{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "6fcff3e8",
   "metadata": {},
   "source": [
    "# zShim_Gc_220 Images"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "0f60b9b5",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-latest.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import plotly.graph_objects as go\n",
    "from plotly.subplots import make_subplots\n",
    "import numpy as np\n",
    "import math\n",
    "import nibabel as nib\n",
    "import matplotlib.pyplot as plt\n",
    "from math import ceil\n",
    "from scipy.interpolate import interp1d\n",
    "import time\n",
    "from ipywidgets import interactive, HBox, widgets, interact\n",
    "from plotly.offline import download_plotlyjs, init_notebook_mode, plot, iplot\n",
    "from IPython.core.display import display, HTML\n",
    "init_notebook_mode(connected=True)\n",
    "config={'showLink': False, 'displayModeBar': False}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "0f183e1f",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "def load_image(path):\n",
    "    nii_img = nib.load(path)\n",
    "    nii_data = nii_img.get_fdata()\n",
    "\n",
    "    number_of_slices = nii_data.shape[2]\n",
    "    number_of_frames = nii_data.shape[3]\n",
    "\n",
    "    layers = []\n",
    "\n",
    "    for frame in range(number_of_frames):\n",
    "        for s in range(number_of_slices):\n",
    "                layers.append(nii_data[:,:,s,frame])\n",
    "    \n",
    "    return layers\n",
    "\n",
    "def mapp(list_value, range_1,range_2):\n",
    "    m = interp1d(range_1,range_2)\n",
    "    return m(list_value)\n",
    "\n",
    "def compare_scans(scans,nb_frames,file_name):\n",
    "    newmap = np.concatenate((scans[0],scans[1],scans[2]), axis=1)\n",
    "    new_title = \"Echo1\\t\\t\\tEcho2\\t\\t\\tEcho3\"\n",
    "    \n",
    "    data = []\n",
    "    for i in range(nb_frames):\n",
    "        current = np.rot90(newmap[i],3)\n",
    "        data_c = go.Heatmap(z = current, \n",
    "                            visible = False,\n",
    "                            xtype = \"scaled\", \n",
    "                            ytype = \"scaled\",\n",
    "                            colorscale = \"gray\",\n",
    "                            showscale = False,\n",
    "                            hoverinfo = \"skip\"\n",
    "                            #colorbar = dict(title = dict(text = \"B<sub>0</sub> (Hz)\"))\n",
    "                           )\n",
    "        data.append(data_c)\n",
    "    data[0]['visible'] = True\n",
    "\n",
    "    # Create steps and slider\n",
    "    steps = []\n",
    "    for i in range(nb_frames):\n",
    "        step = dict(\n",
    "            method = 'restyle',  \n",
    "            args = ['visible', [False]*n],\n",
    "            label = str(i+1)\n",
    "        )\n",
    "        step['args'][1][i] = True # Toggle i'th trace to \"visible\"\n",
    "        steps.append(step)\n",
    "\n",
    "    sliders = [dict(\n",
    "        active = 0,\n",
    "        currentvalue = {'prefix':\"Current slice is: <b>\"},\n",
    "        pad = {\"t\": 50, \"b\": 10},\n",
    "        steps = steps\n",
    "    )]\n",
    "\n",
    "    # Setup the layout of the figure\n",
    "    layout = go.Layout(\n",
    "        title = new_title, \n",
    "        width=800,\n",
    "        height=500,\n",
    "        margin=go.layout.Margin(\n",
    "            l=50,\n",
    "            r=50,\n",
    "            b=60,\n",
    "            t=35,\n",
    "        ),\n",
    "        showlegend = False,\n",
    "        autosize = False,\n",
    "        sliders=sliders,\n",
    "        xaxis = dict(showgrid = False,\n",
    "                     showticklabels= False),\n",
    "        yaxis = dict(showgrid = False,\n",
    "                     showticklabels = False),\n",
    "        font = dict(family=\"Courier New, monospace\",\n",
    "                    size=14),\n",
    "    )\n",
    "    \n",
    "\n",
    "    # Plot function saves as html or with ipplot\n",
    "    fig = dict(data=data, layout=layout)\n",
    "    plot(fig, filename = file_name, config = config)\n",
    "\n",
    "    #display(HTML('fig2.html'))\n",
    "    "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "f60634ba",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "raw_images_path = [\"data/mag_echo1_zShim_off_alpha_60deg.nii\", \"data/mag_echo2_zShim_off_alpha_60deg.nii\",\"data/mag_echo3_zShim_off_alpha_60deg.nii\"]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "43cdbed0",
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>                        <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.58.4\n",
       "* Copyright 2012-2020, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}((function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,(function(t){return i(e[o][1][t]||t)}),u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans', verdana, arial, sans-serif;position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":778}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1365}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":929}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":942}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":952}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":641}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":961}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":980}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":994}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":1001}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":1007}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":1022}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":1033}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":755}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":1041}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1366}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":1051}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":1060}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1367}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1073}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1083}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1095}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1101}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1105}],25:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/image\")},{\"../src/traces/image\":1113}],26:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./image\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./treemap\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./image\":25,\"./indicator\":27,\"./isosurface\":28,\"./mesh3d\":29,\"./ohlc\":30,\"./parcats\":31,\"./parcoords\":32,\"./pie\":33,\"./pointcloud\":34,\"./sankey\":35,\"./scatter3d\":36,\"./scattercarpet\":37,\"./scattergeo\":38,\"./scattergl\":39,\"./scattermapbox\":40,\"./scatterpolar\":41,\"./scatterpolargl\":42,\"./scatterternary\":43,\"./sort\":44,\"./splom\":45,\"./streamtube\":46,\"./sunburst\":47,\"./surface\":48,\"./table\":49,\"./treemap\":50,\"./violin\":51,\"./volume\":52,\"./waterfall\":53}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1121}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1127}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1132}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1137}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1146}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1156}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1167}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1176}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1182}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1220}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1227}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1235}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1248}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1258}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1266}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1273}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1281}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1369}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1290}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1298}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1306}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1315}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1323}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/treemap\")},{\"../src/traces/treemap\":1332}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1344}],52:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1352}],53:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1360}],54:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),f=i(),h=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),new o({turntable:u,orbit:f,matrix:h},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map((function(e){return t[e]})),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach((function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))})),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":480,\"orbit-camera-controller\":501,\"turntable-camera-controller\":581}],55:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return f(t.source,e.source)||t.index-e.index}function u(t,e){return f(t.target,e.target)||t.index-e.index}function f(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function h(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function m(t){return t.index}function v(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}function _(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort((function(t,e){return t.length-e.length}));var f={};for(o=0;o<u.length;o++){var h=u[o].slice(-2);f[h[0]]||(f[h[0]]={}),f[h[0]][h[1]]=!0}t.links.forEach((function(t){var e=t.target.index,r=t.source.index;e===r||f[r]&&f[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1}))}else t.links.forEach((function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)}))}function w(t,e){var r=0,n=0;t.links.forEach((function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach((function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)})))})),t.links.forEach((function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),H(t,e)&&(t.circularLinkType=t.source.circularLinkType))}))}function T(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function k(t,e){var r=0;t.sourceLinks.forEach((function(t){r=t.circular&&!H(t,e)?r+1:r}));var n=0;return t.targetLinks.forEach((function(t){n=t.circular&&!H(t,e)?n+1:n})),r+n}function M(t){var e=t.source.sourceLinks,r=0;e.forEach((function(t){r=t.circular?r+1:r}));var n=t.target.targetLinks,i=0;return n.forEach((function(t){i=t.circular?i+1:i})),!(r>1||i>1)}function A(t,e,r){return t.sort(E),t.forEach((function(n,i){var a,o,s=0;if(H(n,r)&&M(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}})),t}function S(t,r,i,a){var o=e.min(t.links,(function(t){return t.source.y0}));t.links.forEach((function(t){t.circular&&(t.circularPathData={})})),A(t.links.filter((function(t){return\"top\"==t.circularLinkType})),r,a),A(t.links.filter((function(t){return\"bottom\"==t.circularLinkType})),r,a),t.links.forEach((function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+10,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,H(e,a)&&M(e))e.circularPathData.leftSmallArcRadius=10+e.width/2,e.circularPathData.leftLargeArcRadius=10+e.width/2,e.circularPathData.rightSmallArcRadius=10+e.width/2,e.circularPathData.rightLargeArcRadius=10+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter((function(t){return t.source.column==s&&t.circularLinkType==l}));\"bottom\"==e.circularLinkType?c.sort(L):c.sort(C);var u=0;c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=10+e.width/2+u,e.circularPathData.leftLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),s=e.target.column,c=t.links.filter((function(t){return t.target.column==s&&t.circularLinkType==l})),\"bottom\"==e.circularLinkType?c.sort(P):c.sort(I),u=0,c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=10+e.width/2+u,e.circularPathData.rightLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var f=n.linkHorizontal().source((function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]})).target((function(t){return[t.target.x0,t.y1]}));e.path=f(e)}}))}function E(t,e){return z(t)==z(e)?\"bottom\"==t.circularLinkType?L(t,e):C(t,e):z(e)-z(t)}function C(t,e){return t.y0-e.y0}function L(t,e){return e.y0-t.y0}function I(t,e){return t.y1-e.y1}function P(t,e){return e.y1-t.y1}function z(t){return t.target.column-t.source.column}function O(t){return t.target.x0-t.source.x1}function D(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1+n:t.y1-n}function R(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1-n:t.y1+n}function F(t,e,r,n){t.links.forEach((function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach((function(o){if(o.column==a){var c,u=s/(l+1),f=Math.pow(1-u,3),h=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=f*i.y0+h*i.y0+p*i.y1+d*i.y1,m=g-i.width/2,v=g+i.width/2;m>o.y0&&m<o.y1?(c=o.y1-m+10,c=\"bottom\"==o.circularLinkType?c:-c,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&B(o,t)&&N(t,c,e,r)}))):(v>o.y0&&v<o.y1||m<o.y0&&v>o.y1)&&(c=v-o.y0+10,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&N(t,c,e,r)})))}}))}}))}function B(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function N(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach((function(t){t.y1=t.y1+e})),t.sourceLinks.forEach((function(t){t.y0=t.y0+e}))),t}function j(t,e,r,n){t.nodes.forEach((function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter((function(t){return b(t.source,r)==b(i,r)})),o=a.length;o>1&&a.sort((function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!V(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=R(e,t);return t.y1-r}if(e.target.column>t.target.column)return R(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0}));var s=i.y0;a.forEach((function(t){t.y0=s+t.width/2,s+=t.width})),a.forEach((function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}}))}))}function U(t,e,r){t.nodes.forEach((function(e){var n=t.links.filter((function(t){return b(t.target,r)==b(e,r)})),i=n.length;i>1&&n.sort((function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!V(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=D(e,t);return t.y0-r}if(t.source.column<e.source.column)return D(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0}));var a=e.y0;n.forEach((function(t){t.y1=a+t.width/2,a+=t.width})),n.forEach((function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}}))}))}function V(t,e){return q(t)==q(e)}function q(t){return t.y0-t.y1>0?\"up\":\"down\"}function H(t,e){return b(t.source,e)==b(t.target,e)}function G(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach((function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)})),0==o||0==s){var l=e.min(i,(function(t){return t.y0})),c=(n-r)/(e.max(i,(function(t){return t.y1}))-l);i.forEach((function(t){var e=(t.y1-t.y0)*c;t.y0=(t.y0-l)*c,t.y1=t.y0+e})),a.forEach((function(t){t.y0=(t.y0-l)*c,t.y1=(t.y1-l)*c,t.width=t.width*c}))}}t.sankeyCircular=function(){var t,n,i=0,a=0,b=1,T=1,M=24,A=m,E=o,C=v,L=y,I=32,P=2,z=null;function O(){var t={nodes:C.apply(null,arguments),links:L.apply(null,arguments)};D(t),_(t,A,z),R(t),B(t),w(t,A),N(t,I,A),V(t);for(var e=4,r=0;r<e;r++)j(t,T,A),U(t,T,A),F(t,a,T,A),j(t,T,A),U(t,T,A);return G(t,a,T),S(t,P,T,A),t}function D(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,A);return t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})),t}function R(t){t.nodes.forEach((function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,h),e.sum(t.targetLinks,h)),t.sourceLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})),t.targetLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}))}))}function B(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.depth=n,t.sourceLinks.forEach((function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)}))}));for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.height=n,t.targetLinks.forEach((function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)}))}));t.nodes.forEach((function(t){t.column=Math.floor(E.call(null,t,n))}))}function N(o,s,l){var c=r.nest().key((function(t){return t.column})).sortKeys(e.ascending).entries(o.nodes).map((function(t){return t.values}));!function(r){if(n){var s=1/0;c.forEach((function(t){var e=T*n/(t.length+1);s=e<s?e:s})),t=s}var l=e.min(c,(function(r){return(T-a-(r.length-1)*t)/e.sum(r,h)}));l*=.3,o.links.forEach((function(t){t.width=t.value*l}));var u=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,(function(t){return t.column}));return t.links.forEach((function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))})),{top:r=r>0?r+25+10:r,bottom:n=n>0?n+25+10:n,left:a=a>0?a+25+10:a,right:i=i>0?i+25+10:i}}(o),f=function(t,r){var n=e.max(t.nodes,(function(t){return t.column})),o=b-i,s=T-a,l=o/(o+r.right+r.left),c=s/(s+r.top+r.bottom);return i=i*l+r.left,b=0==r.right?b:b*l,a=a*c+r.top,T*=c,t.nodes.forEach((function(t){t.x0=i+t.column*((b-i-M)/n),t.x1=t.x0+M})),c}(o,u);l*=f,o.links.forEach((function(t){t.width=t.value*l})),c.forEach((function(t){var e=t.length;t.forEach((function(t,n){t.depth==c.length-1&&1==e||0==t.depth&&1==e?(t.y0=T/2-t.value*l,t.y1=t.y0+t.value*l):t.partOfCycle?0==k(t,r)?(t.y0=T/2+n,t.y1=t.y0+t.value*l):\"top\"==t.circularLinkType?(t.y0=a+n,t.y1=t.y0+t.value*l):(t.y0=T-t.value*l-n,t.y1=t.y0+t.value*l):0==u.top||0==u.bottom?(t.y0=(T-a)/e*n,t.y1=t.y0+t.value*l):(t.y0=(T-a)/2-e/2+n,t.y1=t.y0+t.value*l)}))}))}(l),y();for(var u=1,m=s;m>0;--m)v(u*=.99,l),y();function v(t,r){var n=c.length;c.forEach((function(i){var a=i.length,o=i[0].depth;i.forEach((function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&k(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}}))}))}function y(){c.forEach((function(e){var r,n,i,o=a,s=e.length;for(e.sort(f),i=0;i<s;++i)(n=o-(r=e[i]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+t;if((n=o-t-T)>0)for(o=r.y0-=n,r.y1-=n,i=s-2;i>=0;--i)(n=(r=e[i]).y1+t-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}function V(t){t.nodes.forEach((function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)})),t.nodes.forEach((function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach((function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)})),t.targetLinks.forEach((function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)}))}))}return O.nodeId=function(t){return arguments.length?(A=\"function\"==typeof t?t:s(t),O):A},O.nodeAlign=function(t){return arguments.length?(E=\"function\"==typeof t?t:s(t),O):E},O.nodeWidth=function(t){return arguments.length?(M=+t,O):M},O.nodePadding=function(e){return arguments.length?(t=+e,O):t},O.nodes=function(t){return arguments.length?(C=\"function\"==typeof t?t:s(t),O):C},O.links=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),O):L},O.size=function(t){return arguments.length?(i=a=0,b=+t[0],T=+t[1],O):[b-i,T-a]},O.extent=function(t){return arguments.length?(i=+t[0][0],b=+t[1][0],a=+t[0][1],T=+t[1][1],O):[[i,a],[b,T]]},O.iterations=function(t){return arguments.length?(I=+t,O):I},O.circularLinkGap=function(t){return arguments.length?(P=+t,O):P},O.nodePaddingRatio=function(t){return arguments.length?(n=+t,O):n},O.sortNodes=function(t){return arguments.length?(z=t,O):z},O.update=function(t){return w(t,A),V(t),t.links.forEach((function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<T?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)})),j(t,T,A,!1),U(t,T,A),S(t,P,T,A),t},O},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165,\"elementary-circuits-directed-graph\":179}],56:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)}(this,(function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function f(t){return(t.y0+t.y1)/2}function h(t){return f(t.source)*t.value}function p(t){return f(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function m(t){return t.links}function v(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,T=g,k=m,M=32;function A(){var t={nodes:T.apply(null,arguments),links:k.apply(null,arguments)};return S(t),E(t),C(t),L(t),I(t),t}function S(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,_);t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=v(e,n)),\"object\"!=typeof i&&(i=t.target=v(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)}))}function E(t){t.nodes.forEach((function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))}))}function C(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.depth=a,t.sourceLinks.forEach((function(t){n.indexOf(t.target)<0&&n.push(t.target)}))}));for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.height=a,t.targetLinks.forEach((function(t){n.indexOf(t.source)<0&&n.push(t.source)}))}));var o=(i-t-x)/(a-1);e.nodes.forEach((function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x}))}function L(t){var i=r.nest().key((function(t){return t.x0})).sortKeys(e.ascending).entries(t.nodes).map((function(t){return t.values}));!function(){var r=e.max(i,(function(t){return t.length})),a=2/3*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,(function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)}));i.forEach((function(t){t.forEach((function(t,e){t.y1=(t.y0=e)+t.value*o}))})),t.links.forEach((function(t){t.width=t.value*o}))}(),d();for(var a=1,o=M;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach((function(r){r.forEach((function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,h)/e.sum(r.targetLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function l(t){i.slice().reverse().forEach((function(r){r.forEach((function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function d(){i.forEach((function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)(r=a-(e=t[i]).y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)(r=(e=t[i]).y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0}))}}function I(t){t.nodes.forEach((function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)})),t.nodes.forEach((function(t){var e=t.y0,r=e;t.sourceLinks.forEach((function(t){t.y0=e+t.width/2,e+=t.width})),t.targetLinks.forEach((function(t){t.y1=r+t.width/2,r+=t.width}))}))}return A.update=function(t){return I(t),t},A.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),A):_},A.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),A):w},A.nodeWidth=function(t){return arguments.length?(x=+t,A):x},A.nodePadding=function(t){return arguments.length?(b=+t,A):b},A.nodes=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),A):T},A.links=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),A):k},A.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],A):[i-t,y-n]},A.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],A):[[t,n],[i,y]]},A.iterations=function(t){return arguments.length?(M=+t,A):M},A},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165}],57:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":58}],58:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),f=t(\"dtype\"),h=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(f(e.dtype))(m):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=m));for(var v=0;v<m;++v)d[v]=v;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]),c=b[o]||(b[o]=[]),u=x[o]||(x[o]=[]),f=l.length;if(++o>r||s>1073741824){for(var h=0;h<a.length;h++)l.push(a[h]),c.push(s),u.push(null,null,null,null);return f}if(l.push(a[0]),c.push(s),a.length<=1)return u.push(null,null,null,null),f;for(var p=.5*i,d=e+p,m=n+p,v=[],_=[],w=[],T=[],k=1,M=a.length;k<M;k++){var A=a[k],S=g[2*A],E=g[2*A+1];S<d?E<m?v.push(A):_.push(A):E<m?w.push(A):T.push(A)}return s<<=2,u.push(t(e,n,p,v,o,s),t(e,m,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,m,p,T,o,s+3)),f}(0,0,1,d,0,1);for(var w=0,T=0;T<y.length;T++){var k=y[T];if(d.set)d.set(k,w);else for(var M=0,A=k.length;M<A;M++)d[M+w]=k[M];var S=w+y[T].length;_[T]=[w,S],w=S}return d.range=function(){var e,r=[],n=arguments.length;for(;n--;)r[n]=arguments[n];if(u(r[r.length-1])){var o=r.pop();r.length||null==o.x&&null==o.l&&null==o.left||(r=[o],e={}),e=s(o,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var c=a.apply(void 0,r),f=[Math.min(c.x,c.x+c.width),Math.min(c.y,c.y+c.height),Math.max(c.x,c.x+c.width),Math.max(c.y,c.y+c.height)],d=f[0],g=f[1],m=f[2],v=f[3],b=p([d,g,m,v],i),_=b[0],w=b[1],T=b[2],k=b[3],M=l(e.level,y.length);if(null!=e.d){var A;\"number\"==typeof e.d?A=[e.d,e.d]:e.d.length&&(A=e.d),M=Math.min(Math.max(Math.ceil(-h(Math.abs(A[0])/(i[2]-i[0]))),Math.ceil(-h(Math.abs(A[1])/(i[3]-i[1])))),M)}if(M=Math.min(M,y.length),e.lod)return E(_,w,T,k,M);var S=[];function C(e,r,n,i,a,o){if(null!==a&&null!==o&&!(_>e+n||w>r+n||T<e||k<r||i>=M||a===o)){var s=y[i];void 0===o&&(o=s.length);for(var l=a;l<o;l++){var c=s[l],u=t[2*c],f=t[2*c+1];u>=d&&u<=m&&f>=g&&f<=v&&S.push(c)}var h=x[i],p=h[4*a+0],b=h[4*a+1],A=h[4*a+2],E=h[4*a+3],I=L(h,a+1),P=.5*n,z=i+1;C(e,r,P,z,p,b||A||E||I),C(e,r+P,P,z,b,A||E||I),C(e+P,r,P,z,A,E||I),C(e+P,r+P,P,z,E,I)}}function L(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}return C(0,0,1,0,0,1),S},d;function E(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=C(t,e,s),f=C(r,i,s),h=n.ge(l,u),p=n.gt(l,f,h,l.length-1);o[s]=[h+c,p+c]}return o}function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":70,\"binary-search-bounds\":96,clamp:120,defined:170,dtype:175,\"flatten-vertex-data\":244,\"is-obj\":468,\"math-log2\":479,\"parse-rect\":504,\"pick-by-alias\":511}],59:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");function i(t){var e=0;if(t&&t.length>0){e+=Math.abs(a(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(a(t[r]))}return e}function a(t){var e,r,n,i,a,s,l=0,c=t.length;if(c>2){for(s=0;s<c;s++)s===c-2?(n=c-2,i=c-1,a=0):s===c-1?(n=c-1,i=0,a=1):(n=s,i=s+1,a=s+2),e=t[n],r=t[i],l+=(o(t[a][0])-o(e[0]))*Math.sin(o(r[1]));l=6378137*l*6378137/2}return l}function o(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,(function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return i(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=i(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)}),0)}},{\"@turf/meta\":63}],60:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");r.default=function(t){var e=[1/0,1/0,-1/0,-1/0];return n.coordEach(t,(function(t){e[0]>t[0]&&(e[0]=t[0]),e[1]>t[1]&&(e[1]=t[1]),e[2]<t[0]&&(e[2]=t[0]),e[3]<t[1]&&(e[3]=t[1])})),e}},{\"@turf/meta\":63}],61:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,(function(t){r+=t[0],a+=t[1],o++})),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":62,\"@turf/meta\":63}],62:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return i(t,e)})),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return a(t,e)})),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return o(t,e)})),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=f,r.lengthToRadians=h,r.lengthToDegrees=function(t,e){return p(h(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return f(h(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")}))},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],63:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,f,h=0,p=0,d=t.type,g=\"FeatureCollection\"===d,m=\"Feature\"===d,v=g?t.features.length:1,y=0;y<v;y++){l=(f=!!(u=g?t.features[y].geometry:m?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=f?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(h=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-h;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-h;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,f,h=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,f=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,h,c,u,f))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],h,c,u,f))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,h,c,u,f))return!1;h++}}function l(t,e){s(t,(function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,f=0;return!1!==i(t,(function(i,s,h,p,d){if(void 0===l||r>c||p>u||d>f)return l=i,c=r,u=p,f=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}}))}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,(function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)}),n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.coordAll=function(t){var e=[];return i(t,(function(t){e.push(t)})),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)})),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)})),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,(function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0})),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)})),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":62}],64:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":259,\"gl-vao\":358,\"weak-map\":602}],65:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map((function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t}))}},{}],66:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map((function(t,i){var o=i+e,s=String(o).length;return n(o,a-s)+r+t})).join(\"\\n\")}},{\"pad-left\":502}],67:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":548}],68:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter((function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1}))};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:119,\"delaunay-triangulate\":171}],69:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":68,\"simplicial-complex-boundary\":555}],70:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],71:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{\"array-bounds\":70}],72:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],73:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"object-assign\");\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>\n",
       " * @license  MIT\n",
       " */function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function f(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var h=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function m(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function v(t,e,r,n,i){throw new h.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||v(t,!0,e,\"==\",h.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(f(t)&&f(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=T(t),f=T(e);if(u.length!==f.length)return!1;for(u.sort(),f.sort(),c=u.length-1;c>=0;c--)if(u[c]!==f[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&v(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&v(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}h.AssertionError=function(t){this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=function(t){return g(m(t.actual),128)+\" \"+t.operator+\" \"+g(m(t.expected),128)}(this),this.generatedMessage=!0);var e=t.stackStartFunction||v;if(Error.captureStackTrace)Error.captureStackTrace(this,e);else{var r=new Error;if(r.stack){var n=r.stack,i=d(e),a=n.indexOf(\"\\n\"+i);if(a>=0){var o=n.indexOf(\"\\n\",a+1);n=n.substring(o+1)}this.stack=n}}},o.inherits(h.AssertionError,Error),h.fail=v,h.ok=y,h.equal=function(t,e,r){t!=e&&v(t,e,r,\"==\",h.equal)},h.notEqual=function(t,e,r){t==e&&v(t,e,r,\"!=\",h.notEqual)},h.deepEqual=function(t,e,r){x(t,e,!1)||v(t,e,r,\"deepEqual\",h.deepEqual)},h.deepStrictEqual=function(t,e,r){x(t,e,!0)||v(t,e,r,\"deepStrictEqual\",h.deepStrictEqual)},h.notDeepEqual=function(t,e,r){x(t,e,!1)&&v(t,e,r,\"notDeepEqual\",h.notDeepEqual)},h.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&v(e,r,n,\"notDeepStrictEqual\",t)},h.strictEqual=function(t,e,r){t!==e&&v(t,e,r,\"===\",h.strictEqual)},h.notStrictEqual=function(t,e,r){t===e&&v(t,e,r,\"!==\",h.notStrictEqual)},h.throws=function(t,e,r){w(!0,t,e,r)},h.doesNotThrow=function(t,e,r){w(!1,t,e,r)},h.ifError=function(t){if(t)throw t},h.strict=n((function t(e,r){e||v(e,!0,r,\"==\",t)}),h,{equal:h.strictEqual,deepEqual:h.deepStrictEqual,notEqual:h.notStrictEqual,notDeepEqual:h.notDeepStrictEqual}),h.strict.strict=h.strict;var T=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":499,\"util/\":76}],74:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],75:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],76:[function(t,e,r){(function(e,n){(function(){var i=/%[sdj%]/g;r.format=function(t){if(!v(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,(function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}})),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&T(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return v(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(v(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(m(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach((function(t,r){e[t]=!0})),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return f(e);if(0===o.length){if(T(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return f(e)}var c,b=\"\",k=!1,M=[\"{\",\"}\"];(p(e)&&(k=!0,M=[\"[\",\"]\"]),T(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+f(e)),0!==o.length||k&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=k?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)E(e,String(o))?a.push(h(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach((function(i){i.match(/^\\d+$/)||a.push(h(t,e,r,n,i,!0))})),a}(t,e,n,s,o):o.map((function(r){return h(t,e,n,s,r,k)})),t.seen.pop(),function(t,e,r){if(t.reduce((function(t,e){return e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1}),0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,M)):M[0]+b+M[1]}function f(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function h(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),E(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map((function(t){return\"  \"+t})).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map((function(t){return\"   \"+t})).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function m(t){return\"number\"==typeof t}function v(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===k(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===k(t)}function w(t){return b(t)&&(\"[object Error]\"===k(t)||t instanceof Error)}function T(t){return\"function\"==typeof t}function k(t){return Object.prototype.toString.call(t)}function M(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=m,r.isString=v,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=T,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var A=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(){var t=new Date,e=[M(t.getHours()),M(t.getMinutes()),M(t.getSeconds())].join(\":\");return[t.getDate(),A[t.getMonth()],e].join(\" \")}function E(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){console.log(\"%s - %s\",S(),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":75,_process:526,inherits:74}],77:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],78:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(o=0;o<=r;++o)a[r][o]=1;var c=new Array(r+1);for(o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),f=i(u[r+1]);0===f&&(f=1);var h=new Array(r+1);for(o=0;o<=r;++o)h[o]=i(u[o])/f;return h};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":547}],79:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new a(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,f=s>0?o-4:o;for(r=0;r<f;r+=4)e=i[t.charCodeAt(r)]<<18|i[t.charCodeAt(r+1)]<<12|i[t.charCodeAt(r+2)]<<6|i[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=i[t.charCodeAt(r)]<<2|i[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=i[t.charCodeAt(r)]<<10|i[t.charCodeAt(r+1)]<<4|i[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],80:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],81:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],82:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":90}],83:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c,u,f=0;if(i(e))c=e.clone();else if(\"string\"==typeof e)c=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))c=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),f-=256;c=a(e)}}if(n(r))c.mul(r[1]),u=r[0].clone();else if(i(r))u=r.clone();else if(\"string\"==typeof r)u=o(r);else if(r)if(r===Math.floor(r))u=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),f+=256;u=a(r)}else u=a(1);f>0?c=c.ushln(f):f<0&&(u=u.ushln(-f));return s(c,u)}},{\"./div\":82,\"./is-rat\":84,\"./lib/is-bn\":88,\"./lib/num-to-bn\":89,\"./lib/rationalize\":90,\"./lib/str-to-bn\":91}],84:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":88}],85:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":99}],86:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":85}],87:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":97,\"double-bits\":173}],88:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":99}],89:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":99,\"double-bits\":173}],90:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":85,\"./num-to-bn\":89}],91:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":99}],92:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],93:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":85}],94:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],95:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,f=n(l.ushln(u).divRound(r));return c*(s+f*Math.pow(2,-u))}var h=r.bitLength()-l.bitLength()+53;f=n(l.ushln(h).divRound(r));return h<1023?c*f*Math.pow(2,-h):(f*=Math.pow(2,-1023),c*f*Math.pow(2,1023-h))}},{\"./lib/bn-to-num\":86,\"./lib/ctz\":87}],96:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],97:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],98:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,f,h,p,d,g,m=null==e.cutoff?.25:e.cutoff,v=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(f=(h=t).getContext(\"2d\"),r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(h=t.canvas,f=t,r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),T=Array(s+1),k=Array(s);for(d=0,g=r*o;d<g;d++){var M=l[d];x[d]=1===M?0:0===M?i:Math.pow(Math.max(0,.5-M),2),b[d]=1===M?i:0===M?0:Math.pow(Math.max(0,M-.5),2)}a(x,r,o,_,w,k,T),a(b,r,o,_,w,k,T);var A=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)A[d]=n(1-((x[d]-b[d])/v+m),0,1);return A};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:120}],99:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var f=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)f*=e;this.imuln(f),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],f=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function h(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,f=67108863&l,h=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=h;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+f)/67108864|0,f=67108863&o}r.words[c]=0|f,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var h=u[t],p=f[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[h-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],f=8191&u,h=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,m=0|o[2],v=8191&m,y=m>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],T=8191&w,k=w>>>13,M=0|o[5],A=8191&M,S=M>>>13,E=0|o[6],C=8191&E,L=E>>>13,I=0|o[7],P=8191&I,z=I>>>13,O=0|o[8],D=8191&O,R=O>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ft=8191&ut,ht=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var mt=(c+(n=Math.imul(f,U))|0)+((8191&(i=(i=Math.imul(f,V))+Math.imul(h,U)|0))<<13)|0;c=((a=Math.imul(h,V))+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var vt=(c+(n=n+Math.imul(f,H)|0)|0)+((8191&(i=(i=i+Math.imul(f,G)|0)+Math.imul(h,H)|0))<<13)|0;c=((a=a+Math.imul(h,G)|0)+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(v,U),i=(i=Math.imul(v,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(f,W)|0)|0)+((8191&(i=(i=i+Math.imul(f,X)|0)+Math.imul(h,W)|0))<<13)|0;c=((a=a+Math.imul(h,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(v,H)|0,i=(i=i+Math.imul(v,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(f,J)|0)|0)+((8191&(i=(i=i+Math.imul(f,K)|0)+Math.imul(h,J)|0))<<13)|0;c=((a=a+Math.imul(h,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(T,U),i=(i=Math.imul(T,V))+Math.imul(k,U)|0,a=Math.imul(k,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(v,W)|0,i=(i=i+Math.imul(v,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(f,$)|0)|0)+((8191&(i=(i=i+Math.imul(f,tt)|0)+Math.imul(h,$)|0))<<13)|0;c=((a=a+Math.imul(h,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(A,U),i=(i=Math.imul(A,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(T,H)|0,i=(i=i+Math.imul(T,G)|0)+Math.imul(k,H)|0,a=a+Math.imul(k,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(v,J)|0,i=(i=i+Math.imul(v,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,$)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(f,rt)|0)|0)+((8191&(i=(i=i+Math.imul(f,nt)|0)+Math.imul(h,rt)|0))<<13)|0;c=((a=a+Math.imul(h,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(A,H)|0,i=(i=i+Math.imul(A,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(T,W)|0,i=(i=i+Math.imul(T,X)|0)+Math.imul(k,W)|0,a=a+Math.imul(k,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(v,$)|0,i=(i=i+Math.imul(v,tt)|0)+Math.imul(y,$)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(f,at)|0)|0)+((8191&(i=(i=i+Math.imul(f,ot)|0)+Math.imul(h,at)|0))<<13)|0;c=((a=a+Math.imul(h,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(P,U),i=(i=Math.imul(P,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(A,W)|0,i=(i=i+Math.imul(A,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(T,J)|0,i=(i=i+Math.imul(T,K)|0)+Math.imul(k,J)|0,a=a+Math.imul(k,K)|0,n=n+Math.imul(b,$)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,$)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(v,rt)|0,i=(i=i+Math.imul(v,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var Tt=(c+(n=n+Math.imul(f,lt)|0)|0)+((8191&(i=(i=i+Math.imul(f,ct)|0)+Math.imul(h,lt)|0))<<13)|0;c=((a=a+Math.imul(h,ct)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(P,H)|0,i=(i=i+Math.imul(P,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(A,J)|0,i=(i=i+Math.imul(A,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(T,$)|0,i=(i=i+Math.imul(T,tt)|0)+Math.imul(k,$)|0,a=a+Math.imul(k,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(v,at)|0,i=(i=i+Math.imul(v,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var kt=(c+(n=n+Math.imul(f,ft)|0)|0)+((8191&(i=(i=i+Math.imul(f,ht)|0)+Math.imul(h,ft)|0))<<13)|0;c=((a=a+Math.imul(h,ht)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(P,W)|0,i=(i=i+Math.imul(P,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(A,$)|0,i=(i=i+Math.imul(A,tt)|0)+Math.imul(S,$)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(T,rt)|0,i=(i=i+Math.imul(T,nt)|0)+Math.imul(k,rt)|0,a=a+Math.imul(k,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(v,lt)|0,i=(i=i+Math.imul(v,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ft)|0,i=(i=i+Math.imul(d,ht)|0)+Math.imul(g,ft)|0,a=a+Math.imul(g,ht)|0;var Mt=(c+(n=n+Math.imul(f,dt)|0)|0)+((8191&(i=(i=i+Math.imul(f,gt)|0)+Math.imul(h,dt)|0))<<13)|0;c=((a=a+Math.imul(h,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(P,J)|0,i=(i=i+Math.imul(P,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,$)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,$)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(A,rt)|0,i=(i=i+Math.imul(A,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(T,at)|0,i=(i=i+Math.imul(T,ot)|0)+Math.imul(k,at)|0,a=a+Math.imul(k,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(v,ft)|0,i=(i=i+Math.imul(v,ht)|0)+Math.imul(y,ft)|0,a=a+Math.imul(y,ht)|0;var At=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(P,$)|0,i=(i=i+Math.imul(P,tt)|0)+Math.imul(z,$)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(A,at)|0,i=(i=i+Math.imul(A,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(T,lt)|0,i=(i=i+Math.imul(T,ct)|0)+Math.imul(k,lt)|0,a=a+Math.imul(k,ct)|0,n=n+Math.imul(b,ft)|0,i=(i=i+Math.imul(b,ht)|0)+Math.imul(_,ft)|0,a=a+Math.imul(_,ht)|0;var St=(c+(n=n+Math.imul(v,dt)|0)|0)+((8191&(i=(i=i+Math.imul(v,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,$)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,$)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(P,rt)|0,i=(i=i+Math.imul(P,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(A,lt)|0,i=(i=i+Math.imul(A,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(T,ft)|0,i=(i=i+Math.imul(T,ht)|0)+Math.imul(k,ft)|0,a=a+Math.imul(k,ht)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),i=(i=Math.imul(B,tt))+Math.imul(N,$)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(P,at)|0,i=(i=i+Math.imul(P,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(A,ft)|0,i=(i=i+Math.imul(A,ht)|0)+Math.imul(S,ft)|0,a=a+Math.imul(S,ht)|0;var Ct=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(i=(i=i+Math.imul(T,gt)|0)+Math.imul(k,dt)|0))<<13)|0;c=((a=a+Math.imul(k,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(P,lt)|0,i=(i=i+Math.imul(P,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ft)|0,i=(i=i+Math.imul(C,ht)|0)+Math.imul(L,ft)|0,a=a+Math.imul(L,ht)|0;var Lt=(c+(n=n+Math.imul(A,dt)|0)|0)+((8191&(i=(i=i+Math.imul(A,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(P,ft)|0,i=(i=i+Math.imul(P,ht)|0)+Math.imul(z,ft)|0,a=a+Math.imul(z,ht)|0;var It=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(It>>>26)|0,It&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ft)|0,i=(i=i+Math.imul(D,ht)|0)+Math.imul(R,ft)|0,a=a+Math.imul(R,ht)|0;var Pt=(c+(n=n+Math.imul(P,dt)|0)|0)+((8191&(i=(i=i+Math.imul(P,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,ft),i=(i=Math.imul(B,ht))+Math.imul(N,ft)|0,a=Math.imul(N,ht);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var Ot=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,l[0]=mt,l[1]=vt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=Tt,l[8]=kt,l[9]=Mt,l[10]=At,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=It,l[16]=Pt,l[17]=zt,l[18]=Ot,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=h),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?h(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,f=(0|t.words[u])*(0|e.words[c]),h=67108863&f;s=67108863&(h=h+s|0),i+=(o=(o=o+(f/67108864|0)|0)+(h>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var f=l,h=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],m=r[u+p+o],v=n[u+p+o],y=f*m-h*v;v=f*v+h*m,m=y,r[u+p]=d+m,n[u+p]=g+v,r[u+p+o]=d-m,n[u+p+o]=g-v,p!==s&&(y=l*f-c*h,h=l*h+c*f,f=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),f=new Array(n),h=r.words;h.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,f,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*f[p];l[p]=s[p]*f[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,h,a,n,i),this.conjugate(h,a,n),this.normalize13b(h,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var f=0|this.words[c];this.words[c]=u<<26-a|f>>>a,u=f&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var f=l-1;f>=0;f--){var h=67108864*(0|n.words[i.length+f])+(0|n.words[i.length+f-1]);for(h=Math.min(h/o|0,67108863),n._ishlnsubmul(i,h,f);0!==n.negative;)h--,n.negative=0,n._ishlnsubmul(i,1,f),n.isZero()||(n.negative^=1);s&&(s.words[f]=h)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),f=e.clone();!e.isZero();){for(var h=0,p=1;0==(e.words[0]&p)&&h<26;++h,p<<=1);if(h>0)for(e.iushrn(h);h-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(f)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(f)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var f=0,h=1;0==(r.words[0]&h)&&f<26;++f,h<<=1);if(f>0)for(r.iushrn(f);f-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var m={k256:null,p224:null,p192:null,p25519:null};function v(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){v.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){v.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){v.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){v.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function T(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}v.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},v.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},v.prototype.split=function(t,e){t.iushrn(this.n,0,e)},v.prototype.imulK=function(t){return t.imul(this.k)},i(y,v),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,v),i(b,v),i(_,v),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(m[t])return m[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return m[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var f=this.pow(u,i),h=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,m=0;0!==g.cmp(s);m++)g=g.redSqr();n(m<d);var v=this.pow(f,new a(1).iushln(d-m-1));h=h.redMul(v),f=v.redSqr(),p=p.redMul(f),d=m}return h},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var f=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==f||0!==o?(o<<=1,o|=f,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new T(t)},i(T,w),T.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},T.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},T.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},T.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},T.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:108}],100:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),f=0;for(n=0;n<c;++n)n!==r&&(u[f++]=l[n]);if(1&r){var h=u[1];u[1]=u[0],u[0]=h}}}return o}},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return f(t);case 2:return\"function\"==typeof e?c(t,t,e,!0):h(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var f,h=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,h,p))>0){if(1===u&&n)a.init(s),f=a.sweepComplete(u,r,0,s,h,p,0,s,h,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),f=1===u?a.sweepBipartite(u,r,0,s,h,p,0,c,d,g):o(u,r,n,s,h,p,c,d,g),i.free(d),i.free(g))}i.free(h),i.free(p)}return f}}}function u(t,e){n.push([t,e])}function f(t){return n=[],c(t,t,u,!0),n}function h(t,e){return n=[],c(t,e,u,!1),n}},{\"./lib/intersect\":103,\"./lib/sweep\":107,\"typedarray-pool\":595}],102:[function(t,e,r){\"use strict\";var n=[\"d\",\"ax\",\"vv\",\"rs\",\"re\",\"rb\",\"ri\",\"bs\",\"be\",\"bb\",\"bi\"];function i(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],i=n.slice();t||i.splice(3,0,\"fp\");var a=[\"function \"+e+\"(\"+i.join()+\"){\"];function o(e,i){var o=function(t,e,r){var i=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),a=[\"function \",i,\"(\",n.join(),\"){\",\"var \",\"es\",\"=2*\",\"d\",\";\"],o=\"for(var i=rs,rp=es*rs;i<re;++i,rp+=es){var x0=rb[ax+rp],x1=rb[ax+rp+d],xi=ri[i];\",s=\"for(var j=bs,bp=es*bs;j<be;++j,bp+=es){var y0=bb[ax+bp],\"+(r?\"y1=bb[ax+bp+d],\":\"\")+\"yi=bi[j];\";return t?a.push(o,\"Q\",\":\",s):a.push(s,\"Q\",\":\",o),r?a.push(\"if(y1<x0||x1<y0)continue;\"):e?a.push(\"if(y0<=x0||x1<y0)continue;\"):a.push(\"if(y0<x0||x1<y0)continue;\"),a.push(\"for(var k=ax+1;k<d;++k){var r0=rb[k+rp],r1=rb[k+d+rp],b0=bb[k+bp],b1=bb[k+d+bp];if(r1<b0||b1<r0)continue Q;}var rv=vv(\"),e?a.push(\"yi,xi\"):a.push(\"xi,yi\"),a.push(\");if(rv!==void 0)return rv;}}}\"),{name:i,code:a.join(\"\")}}(e,i,t);r.push(o.code),a.push(\"return \"+o.name+\"(\"+n.join()+\");\")}a.push(\"if(re-rs>be-bs){\"),t?(o(!0,!1),a.push(\"}else{\"),o(!1,!1)):(a.push(\"if(fp){\"),o(!0,!0),a.push(\"}else{\"),o(!0,!1),a.push(\"}}else{if(fp){\"),o(!1,!0),a.push(\"}else{\"),o(!1,!1),a.push(\"}\")),a.push(\"}}return \"+e);var s=r.join(\"\")+a.join(\"\");return new Function(s)()}r.partial=i(!1),r.full=i(!0)},{}],103:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,w,T,k,M){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(6*r);v.length<a&&(n.free(v),v=n.mallocInt32(a));var o=i.nextPow2(2*r);y.length<o&&(n.free(y),y=n.mallocDouble(o))}(t,a+T);var A,S=0,E=2*t;x(S++,0,0,a,0,T,r?16:0,-1/0,1/0),r||x(S++,0,0,T,0,a,1,-1/0,1/0);for(;S>0;){var C=6*(S-=1),L=v[C],I=v[C+1],P=v[C+2],z=v[C+3],O=v[C+4],D=v[C+5],R=2*S,F=y[R],B=y[R+1],N=1&D,j=!!(16&D),U=u,V=w,q=k,H=M;if(N&&(U=k,V=M,q=u,H=w),!(2&D&&(P=p(t,L,I,P,U,V,B),I>=P)||4&D&&(I=d(t,L,I,P,U,V,F))>=P)){var G=P-I,Y=O-z;if(j){if(t*G*(G+Y)<1<<22){if(void 0!==(A=l.scanComplete(t,L,e,I,P,U,V,z,O,q,H)))return A;continue}}else{if(t*Math.min(G,Y)<128){if(void 0!==(A=o(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}if(t*G*Y<1<<22){if(void 0!==(A=l.scanBipartite(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}}var W=f(t,L,I,P,U,V,F,B);if(I<W)if(t*(W-I)<128){if(void 0!==(A=s(t,L+1,e,I,W,U,V,z,O,q,H)))return A}else if(L===t-2){if(void 0!==(A=N?l.sweepBipartite(t,e,z,O,q,H,I,W,U,V):l.sweepBipartite(t,e,I,W,U,V,z,O,q,H)))return A}else x(S++,L+1,I,W,z,O,N,-1/0,1/0),x(S++,L+1,z,O,I,W,1^N,-1/0,1/0);if(W<P){var X=c(t,L,z,O,q,H),Z=q[E*X+L],J=h(t,L,X,O,q,H,Z);if(J<O&&x(S++,L,W,P,J,O,(4|N)+(j?16:0),Z,B),z<X&&x(S++,L,W,P,z,X,(2|N)+(j?16:0),F,Z),X+1===J){if(void 0!==(A=j?_(t,L,e,W,P,U,V,X,q,H[X]):b(t,L,e,N,W,P,U,V,X,q,H[X])))return A}else if(X<J){var K;if(j){if(K=g(t,L,W,P,U,V,Z),W<K){var Q=h(t,L,W,K,U,V,Z);if(L===t-2){if(W<Q&&void 0!==(A=l.sweepComplete(t,e,W,Q,U,V,X,J,q,H)))return A;if(Q<K&&void 0!==(A=l.sweepBipartite(t,e,Q,K,U,V,X,J,q,H)))return A}else W<Q&&x(S++,L+1,W,Q,X,J,16,-1/0,1/0),Q<K&&(x(S++,L+1,Q,K,X,J,0,-1/0,1/0),x(S++,L+1,X,J,Q,K,1,-1/0,1/0))}}else K=N?m(t,L,W,P,U,V,Z):g(t,L,W,P,U,V,Z),W<K&&(L===t-2?A=N?l.sweepBipartite(t,e,X,J,q,H,W,K,U,V):l.sweepBipartite(t,e,W,K,U,V,X,J,q,H):(x(S++,L+1,W,K,X,J,N,-1/0,1/0),x(S++,L+1,X,J,W,K,1^N,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),f=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),h=u(\"lo===p0\",[\"p0\"]),p=u(\"lo<p0\",[\"p0\"]),d=u(\"hi<=p0\",[\"p0\"]),g=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),m=u(\"lo<p0&&p0<=hi\",[\"p0\"]),v=n.mallocInt32(1024),y=n.mallocDouble(1024);function x(t,e,r,n,i,a,o,s,l){var c=6*t;v[c]=e,v[c+1]=r,v[c+2]=n,v[c+3]=i,v[c+4]=a,v[c+5]=o;var u=2*t;y[u]=s,y[u+1]=l}function b(t,e,r,n,i,a,o,s,l,c,u){var f=2*t,h=l*f,p=c[h+e];t:for(var d=i,g=i*f;d<a;++d,g+=f){var m=o[g+e],v=o[g+e+t];if(!(p<m||v<p)&&(!n||p!==m)){for(var y,x=s[d],b=e+1;b<t;++b){m=o[g+b],v=o[g+b+t];var _=c[h+b],w=c[h+b+t];if(v<_||w<m)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function _(t,e,r,n,i,a,o,s,l,c){var u=2*t,f=s*u,h=l[f+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var m=a[d+e],v=a[d+e+t];if(!(h<m||v<h)){for(var y=e+1;y<t;++y){m=a[d+y],v=a[d+y+t];var x=l[f+y],b=l[f+y+t];if(v<x||b<m)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":102,\"./median\":104,\"./partition\":105,\"./sweep\":107,\"bit-twiddle\":97,\"typedarray-pool\":595}],104:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,o,s){if(a<=r+1)return r;var l=r,c=a,u=a+r>>>1,f=2*t,h=u,p=o[f*u+e];for(;l<c;){if(c-l<8){i(t,e,l,c,o,s),p=o[f*u+e];break}var d=c-l,g=Math.random()*d+l|0,m=o[f*g+e],v=Math.random()*d+l|0,y=o[f*v+e],x=Math.random()*d+l|0,b=o[f*x+e];m<=y?b>=y?(h=v,p=y):m>=b?(h=g,p=m):(h=x,p=b):y>=b?(h=v,p=y):b>=m?(h=g,p=m):(h=x,p=b);for(var _=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){var k=o[_];o[_]=o[w],o[w]=k}var M=s[c-1];s[c-1]=s[h],s[h]=M,h=n(t,e,l,c-1,o,s,p);for(_=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){k=o[_];o[_]=o[w],o[w]=k}M=s[c-1];if(s[c-1]=s[h],s[h]=M,u<h){for(c=h-1;l<c&&o[f*(c-1)+e]===p;)c-=1;c+=1}else{if(!(h<u))break;for(l=h+1;l<c&&o[f*l+e]===p;)l+=1}}return n(t,e,r,u,o,s,o[f*u+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]);function i(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,f=o*(l-1);u>r&&i[f+e]>c;--u,f-=o){for(var h=f,p=f+o,d=0;d<o;++d,++h,++p){var g=i[h];i[h]=i[p],i[p]=g}var m=a[u];a[u]=a[u-1],a[u-1]=m}}},{\"./partition\":105}],105:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),n=[];t.indexOf(\"lo\")>=0&&n.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&n.push(\"hi=e[k+o]\");return r.push(\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\".replace(\"_\",n.join()).replace(\"$\",t)),Function.apply(void 0,r)}},{}],106:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=128?n(0,e-1,t):function t(e,r,u){var f=(r-e+1)/6|0,h=e+f,p=r-f,d=e+r>>1,g=d-f,m=d+f,v=h,y=g,x=d,b=m,_=p,w=e+1,T=r-1,k=0;l(v,y,u)&&(k=v,v=y,y=k);l(b,_,u)&&(k=b,b=_,_=k);l(v,x,u)&&(k=v,v=x,x=k);l(y,x,u)&&(k=y,y=x,x=k);l(v,b,u)&&(k=v,v=b,b=k);l(x,b,u)&&(k=x,x=b,b=k);l(y,_,u)&&(k=y,y=_,_=k);l(y,x,u)&&(k=y,y=x,x=k);l(b,_,u)&&(k=b,b=_,_=k);for(var M=u[2*y],A=u[2*y+1],S=u[2*b],E=u[2*b+1],C=2*v,L=2*x,I=2*_,P=2*h,z=2*d,O=2*p,D=0;D<2;++D){var R=u[C+D],F=u[L+D],B=u[I+D];u[P+D]=R,u[z+D]=F,u[O+D]=B}a(g,e,u),a(m,r,u);for(var N=w;N<=T;++N)if(c(N,M,A,u))N!==w&&i(N,w,u),++w;else if(!c(N,S,E,u))for(;;){if(c(T,S,E,u)){c(T,M,A,u)?(o(N,w,T,u),++w,--T):(i(N,T,u),--T);break}if(--T<N)break}s(e,w-1,M,A,u),s(r,T+1,S,E,u),w-2-e<=32?n(e,w-2,u):t(e,w-2,u);r-(T+2)<=32?n(T+2,r,u):t(T+2,r,u);T-w<=32?n(w,T,u):t(w,T,u)}(0,e-1,t)};function n(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function i(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function a(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function o(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function s(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function l(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function c(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],107:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);o.length<e&&(n.free(o),o=n.mallocInt32(e));s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;h.length<r&&(n.free(h),h=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,u,f,g,m,v){for(var y=0,x=2*t,b=t-1,_=x-1,w=r;w<n;++w){var T=u[w],k=x*w;h[y++]=i[k+b],h[y++]=-(T+1),h[y++]=i[k+_],h[y++]=T}for(w=f;w<g;++w){T=v[w]+(1<<28);var M=x*w;h[y++]=m[M+b],h[y++]=-T,h[y++]=m[M+_],h[y++]=T}var A=y>>>1;a(h,A);var S=0,E=0;for(w=0;w<A;++w){var C=0|h[2*w+1];if(C>=1<<28)p(l,c,E--,C=C-(1<<28)|0);else if(C>=0)p(o,s,S--,C);else if(C<=-(1<<28)){C=-C-(1<<28)|0;for(var L=0;L<S;++L){if(void 0!==(I=e(o[L],C)))return I}d(l,c,E++,C)}else{C=-C-1|0;for(L=0;L<E;++L){var I;if(void 0!==(I=e(C,l[L])))return I}d(o,s,S++,C)}}},sweepComplete:function(t,e,r,n,i,g,m,v,y,x){for(var b=0,_=2*t,w=t-1,T=_-1,k=r;k<n;++k){var M=g[k]+1<<1,A=_*k;h[b++]=i[A+w],h[b++]=-M,h[b++]=i[A+T],h[b++]=M}for(k=m;k<v;++k){M=x[k]+1<<1;var S=_*k;h[b++]=y[S+w],h[b++]=1|-M,h[b++]=y[S+T],h[b++]=1|M}var E=b>>>1;a(h,E);var C=0,L=0,I=0;for(k=0;k<E;++k){var P=0|h[2*k+1],z=1&P;if(k<E-1&&P>>1==h[2*k+3]>>1&&(z=2,k+=1),P<0){for(var O=-(P>>1)-1,D=0;D<I;++D){if(void 0!==(R=e(u[D],O)))return R}if(0!==z)for(D=0;D<C;++D){if(void 0!==(R=e(o[D],O)))return R}if(1!==z)for(D=0;D<L;++D){var R;if(void 0!==(R=e(l[D],O)))return R}0===z?d(o,s,C++,O):1===z?d(l,c,L++,O):2===z&&d(u,f,I++,O)}else{O=(P>>1)-1;0===z?p(o,s,C--,O):1===z?p(l,c,L--,O):2===z&&p(u,f,I--,O)}}},scanBipartite:function(t,e,r,n,i,l,c,u,f,g,m,v){var y=0,x=2*t,b=e,_=e+t,w=1,T=1;n?T=1<<28:w=1<<28;for(var k=i;k<l;++k){var M=k+w,A=x*k;h[y++]=c[A+b],h[y++]=-M,h[y++]=c[A+_],h[y++]=M}for(k=f;k<g;++k){M=k+T;var S=x*k;h[y++]=m[S+b],h[y++]=-M}var E=y>>>1;a(h,E);var C=0;for(k=0;k<E;++k){var L=0|h[2*k+1];if(L<0){var I=!1;if((M=-L)>=1<<28?(I=!n,M-=1<<28):(I=!!n,M-=1),I)d(o,s,C++,M);else{var P=v[M],z=x*M,O=m[z+e+1],D=m[z+e+1+t];t:for(var R=0;R<C;++R){var F=o[R],B=x*F;if(!(D<c[B+e+1]||c[B+e+1+t]<O)){for(var N=e+2;N<t;++N)if(m[z+N+t]<c[B+N]||c[B+N+t]<m[z+N])continue t;var j,U=u[F];if(void 0!==(j=n?r(P,U):r(U,P)))return j}}}}else p(o,s,C--,L-w)}},scanComplete:function(t,e,r,n,i,s,l,c,u,f,p){for(var d=0,g=2*t,m=e,v=e+t,y=n;y<i;++y){var x=y+(1<<28),b=g*y;h[d++]=s[b+m],h[d++]=-x,h[d++]=s[b+v],h[d++]=x}for(y=c;y<u;++y){x=y+1;var _=g*y;h[d++]=f[_+m],h[d++]=-x}var w=d>>>1;a(h,w);var T=0;for(y=0;y<w;++y){var k=0|h[2*y+1];if(k<0){if((x=-k)>=1<<28)o[T++]=x-(1<<28);else{var M=p[x-=1],A=g*x,S=f[A+e+1],E=f[A+e+1+t];t:for(var C=0;C<T;++C){var L=o[C],I=l[L];if(I===M)break;var P=g*L;if(!(E<s[P+e+1]||s[P+e+1+t]<S)){for(var z=e+2;z<t;++z)if(f[A+z+t]<s[P+z]||s[P+z+t]<f[A+z])continue t;var O=r(I,M);if(void 0!==O)return O}}}}else{for(x=k-(1<<28),C=T-1;C>=0;--C)if(o[C]===x){for(z=C+1;z<T;++z)o[z-1]=o[z];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=n.mallocInt32(1024),s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),f=n.mallocInt32(1024),h=n.mallocDouble(8192);function p(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function d(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":106,\"bit-twiddle\":97,\"typedarray-pool\":595}],108:[function(t,e,r){},{}],109:[function(t,e,r){arguments[4][108][0].apply(r,arguments)},{dup:108}],110:[function(t,e,r){\"use strict\";var n,i=\"object\"==typeof Reflect?Reflect:null,a=i&&\"function\"==typeof i.apply?i.apply:function(t,e,r){return Function.prototype.apply.call(t,e,r)};n=i&&\"function\"==typeof i.ownKeys?i.ownKeys:Object.getOwnPropertySymbols?function(t){return Object.getOwnPropertyNames(t).concat(Object.getOwnPropertySymbols(t))}:function(t){return Object.getOwnPropertyNames(t)};var o=Number.isNaN||function(t){return t!=t};function s(){s.init.call(this)}e.exports=s,e.exports.once=function(t,e){return new Promise((function(r,n){function i(){void 0!==a&&t.removeListener(\"error\",a),r([].slice.call(arguments))}var a;\"error\"!==e&&(a=function(r){t.removeListener(e,i),n(r)},t.once(\"error\",a)),t.once(e,i)}))},s.EventEmitter=s,s.prototype._events=void 0,s.prototype._eventsCount=0,s.prototype._maxListeners=void 0;var l=10;function c(t){if(\"function\"!=typeof t)throw new TypeError('The \"listener\" argument must be of type Function. Received type '+typeof t)}function u(t){return void 0===t._maxListeners?s.defaultMaxListeners:t._maxListeners}function f(t,e,r,n){var i,a,o,s;if(c(r),void 0===(a=t._events)?(a=t._events=Object.create(null),t._eventsCount=0):(void 0!==a.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),a=t._events),o=a[e]),void 0===o)o=a[e]=r,++t._eventsCount;else if(\"function\"==typeof o?o=a[e]=n?[r,o]:[o,r]:n?o.unshift(r):o.push(r),(i=u(t))>0&&o.length>i&&!o.warned){o.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+o.length+\" \"+String(e)+\" listeners added. Use emitter.setMaxListeners() to increase limit\");l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=o.length,s=l,console&&console.warn&&console.warn(s)}return t}function h(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,0===arguments.length?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=h.bind(n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(void 0===n)return[];var i=n[e];return void 0===i?[]:\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):m(i,i.length)}function g(t){var e=this._events;if(void 0!==e){var r=e[t];if(\"function\"==typeof r)return 1;if(void 0!==r)return r.length}return 0}function m(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}Object.defineProperty(s,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"defaultMaxListeners\" is out of range. It must be a non-negative number. Received '+t+\".\");l=t}}),s.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},s.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"n\" is out of range. It must be a non-negative number. Received '+t+\".\");return this._maxListeners=t,this},s.prototype.getMaxListeners=function(){return u(this)},s.prototype.emit=function(t){for(var e=[],r=1;r<arguments.length;r++)e.push(arguments[r]);var n=\"error\"===t,i=this._events;if(void 0!==i)n=n&&void 0===i.error;else if(!n)return!1;if(n){var o;if(e.length>0&&(o=e[0]),o instanceof Error)throw o;var s=new Error(\"Unhandled error.\"+(o?\" (\"+o.message+\")\":\"\"));throw s.context=o,s}var l=i[t];if(void 0===l)return!1;if(\"function\"==typeof l)a(l,this,e);else{var c=l.length,u=m(l,c);for(r=0;r<c;++r)a(u[r],this,e)}return!0},s.prototype.addListener=function(t,e){return f(this,t,e,!1)},s.prototype.on=s.prototype.addListener,s.prototype.prependListener=function(t,e){return f(this,t,e,!0)},s.prototype.once=function(t,e){return c(e),this.on(t,p(this,t,e)),this},s.prototype.prependOnceListener=function(t,e){return c(e),this.prependListener(t,p(this,t,e)),this},s.prototype.removeListener=function(t,e){var r,n,i,a,o;if(c(e),void 0===(n=this._events))return this;if(void 0===(r=n[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=Object.create(null):(delete n[t],n.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(i=-1,a=r.length-1;a>=0;a--)if(r[a]===e||r[a].listener===e){o=r[a].listener,i=a;break}if(i<0)return this;0===i?r.shift():function(t,e){for(;e+1<t.length;e++)t[e]=t[e+1];t.pop()}(r,i),1===r.length&&(n[t]=r[0]),void 0!==n.removeListener&&this.emit(\"removeListener\",t,o||e)}return this},s.prototype.off=s.prototype.removeListener,s.prototype.removeAllListeners=function(t){var e,r,n;if(void 0===(r=this._events))return this;if(void 0===r.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==r[t]&&(0==--this._eventsCount?this._events=Object.create(null):delete r[t]),this;if(0===arguments.length){var i,a=Object.keys(r);for(n=0;n<a.length;++n)\"removeListener\"!==(i=a[n])&&this.removeAllListeners(i);return this.removeAllListeners(\"removeListener\"),this._events=Object.create(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(void 0!==e)for(n=e.length-1;n>=0;n--)this.removeListener(t,e[n]);return this},s.prototype.listeners=function(t){return d(this,t,!0)},s.prototype.rawListeners=function(t){return d(this,t,!1)},s.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},s.prototype.listenerCount=g,s.prototype.eventNames=function(){return this._eventsCount>0?n(this._events):[]}},{}],111:[function(t,e,r){(function(e){(function(){\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "\"use strict\";var e=t(\"base64-js\"),n=t(\"ieee754\");r.Buffer=a,r.SlowBuffer=function(t){+t!=t&&(t=0);return a.alloc(+t)},r.INSPECT_MAX_BYTES=50;function i(t){if(t>2147483647)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return e.__proto__=a.prototype,e}function a(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return l(t)}return o(t,e,r)}function o(t,e,r){if(\"string\"==typeof t)return function(t,e){\"string\"==typeof e&&\"\"!==e||(e=\"utf8\");if(!a.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|f(t,e),n=i(r),o=n.write(t,e);o!==r&&(n=n.slice(0,o));return n}(t,e);if(ArrayBuffer.isView(t))return c(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(B(t,ArrayBuffer)||t&&B(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r);return n.__proto__=a.prototype,n}(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return a.from(n,e,r);var o=function(t){if(a.isBuffer(t)){var e=0|u(t.length),r=i(e);return 0===r.length||t.copy(r,0,0,e),r}if(void 0!==t.length)return\"number\"!=typeof t.length||N(t.length)?i(0):c(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return c(t.data)}(t);if(o)return o;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return a.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function s(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function l(t){return s(t),i(t<0?0:0|u(t))}function c(t){for(var e=t.length<0?0:0|u(t.length),r=i(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function u(t){if(t>=2147483647)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+2147483647..toString(16)+\" bytes\");return 0|t}function f(t,e){if(a.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||B(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return D(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return R(t).length;default:if(i)return n?-1:D(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function h(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return A(this,e,r);case\"utf8\":case\"utf-8\":return T(this,e,r);case\"ascii\":return k(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return S(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),N(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=a.from(e,n)),a.isBuffer(e))return 0===e.length?-1:g(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):g(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var f=!0,h=0;h<l;h++)if(c(t,a+h)!==c(e,h)){f=!1;break}if(f)return a}return-1}function m(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(N(s))return o;t[r+o]=s}return o}function v(t,e,r,n){return F(D(e,t.length-r),t,r,n)}function y(t,e,r,n){return F(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return F(R(e),t,r,n)}function _(t,e,r,n){return F(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,r,n){return 0===r&&n===t.length?e.fromByteArray(t):e.fromByteArray(t.slice(r,n))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,f=c>239?4:c>223?3:c>191?2:1;if(i+f<=r)switch(f){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,f=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=f}return function(t){var e=t.length;if(e<=4096)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=4096));return r}(n)}r.kMaxLength=2147483647,a.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),a.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(a.prototype,\"parent\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.buffer}}),Object.defineProperty(a.prototype,\"offset\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&a[Symbol.species]===a&&Object.defineProperty(a,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),a.poolSize=8192,a.from=function(t,e,r){return o(t,e,r)},a.prototype.__proto__=Uint8Array.prototype,a.__proto__=Uint8Array,a.alloc=function(t,e,r){return function(t,e,r){return s(t),t<=0?i(t):void 0!==e?\"string\"==typeof r?i(t).fill(e,r):i(t).fill(e):i(t)}(t,e,r)},a.allocUnsafe=function(t){return l(t)},a.allocUnsafeSlow=function(t){return l(t)},a.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==a.prototype},a.compare=function(t,e){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),B(e,Uint8Array)&&(e=a.from(e,e.offset,e.byteLength)),!a.isBuffer(t)||!a.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,o=Math.min(r,n);i<o;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},a.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},a.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return a.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=a.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var o=t[r];if(B(o,Uint8Array)&&(o=a.from(o)),!a.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(n,i),i+=o.length}return n},a.byteLength=f,a.prototype._isBuffer=!0,a.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},a.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},a.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},a.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?T(this,0,t):h.apply(this,arguments)},a.prototype.toLocaleString=a.prototype.toString,a.prototype.equals=function(t){if(!a.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===a.compare(this,t)},a.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},a.prototype.compare=function(t,e,r,n,i){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),!a.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(n>>>=0),s=(r>>>=0)-(e>>>=0),l=Math.min(o,s),c=this.slice(n,i),u=t.slice(e,r),f=0;f<l;++f)if(c[f]!==u[f]){o=c[f],s=u[f];break}return o<s?-1:s<o?1:0},a.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},a.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},a.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},a.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return m(this,t,e,r);case\"utf8\":case\"utf-8\":return v(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},a.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};function k(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function A(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=O(t[a]);return i}function S(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function E(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function C(t,e,r,n,i,o){if(!a.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<o)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function L(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function I(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,4),n.write(t,e,r,i,23,4),r+4}function P(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,8),n.write(t,e,r,i,52,8),r+8}a.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return n.__proto__=a.prototype,n},a.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},a.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},a.prototype.readUInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),this[t]},a.prototype.readUInt16LE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]|this[t+1]<<8},a.prototype.readUInt16BE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]<<8|this[t+1]},a.prototype.readUInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},a.prototype.readUInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},a.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},a.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},a.prototype.readInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},a.prototype.readInt16LE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt16BE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},a.prototype.readInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},a.prototype.readFloatLE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!0,23,4)},a.prototype.readFloatBE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!1,23,4)},a.prototype.readDoubleLE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!0,52,8)},a.prototype.readDoubleBE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!1,52,8)},a.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},a.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},a.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,255,0),this[e]=255&t,e+1},a.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},a.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},a.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},a.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeFloatLE=function(t,e,r){return I(this,t,e,!0,r)},a.prototype.writeFloatBE=function(t,e,r){return I(this,t,e,!1,r)},a.prototype.writeDoubleLE=function(t,e,r){return P(this,t,e,!0,r)},a.prototype.writeDoubleBE=function(t,e,r){return P(this,t,e,!1,r)},a.prototype.copy=function(t,e,r,n){if(!a.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var o=i-1;o>=0;--o)t[o+e]=this[o+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return i},a.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!a.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t&&(t&=255);if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var o;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(o=e;o<r;++o)this[o]=t;else{var s=a.isBuffer(t)?t:a.from(t,n),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<r-e;++o)this[o+e]=s[o%l]}return this};var z=/[^+/0-9A-Za-z-_]/g;function O(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function D(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function R(t){return e.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(z,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function F(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function B(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function N(t){return t!=t}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":79,buffer:111,ieee754:442}],112:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),f=!!c(r,\"interior\",!0),h=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!f&&!h||0===t.length)return[];var d=n(t,e);if(u||f!==h||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),m=0;m<d.length;++m){var v=d[m];g.addTriangle(v[0],v[1],v[2])}return u&&a(t,g),h?f?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":113,\"./lib/filter\":114,\"./lib/monotone\":115,\"./lib/triangulation\":116}],113:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){if(!((p=l[c])<s)&&!e.isConstraint(s,p)){for(var u=l[c-1],f=-1,h=1;h<l.length;h+=2)if(l[h-1]===p){f=l[h];break}f<0||n(t[s],t[p],t[u],t[f])<0&&r.push(s,p)}}for(;r.length>0;){for(var p=r.pop(),d=(s=r.pop(),u=-1,f=-1,l=o[s],1);d<l.length;d+=2){var g=l[d-1],m=l[d];g===p?f=m:m===p&&(u=g)}u<0||f<0||(n(t[s],t[p],t[u],t[f])>=0||(e.flip(s,p),i(t,e,r,u,s,f),i(t,e,r,s,f,u),i(t,e,r,f,p,u),i(t,e,r,p,u,f)))}}},{\"binary-search-bounds\":96,\"robust-in-sphere\":546}],114:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=(v=r[i])[0],l=v[1],c=v[2];l<c?l<s&&(v[0]=l,v[1]=c,v[2]=s):c<s&&(v[0]=c,v[1]=s,v[2]=l)}r.sort(o);var u=new Array(n);for(i=0;i<u.length;++i)u[i]=0;var f=[],h=[],p=new Array(3*n),d=new Array(3*n),g=null;e&&(g=[]);var m=new a(r,p,d,u,f,h,g);for(i=0;i<n;++i)for(var v=r[i],y=0;y<3;++y){s=v[y],l=v[(y+1)%3];var x=p[3*i+y]=m.locate(l,s,t.opposite(l,s)),b=d[3*i+y]=t.isConstraint(s,l);x<0&&(b?h.push(i):(f.push(i),u[i]=1),e&&g.push([l,s,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,f=n.constraint,h=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=h[3*p+d];g>=0&&0===c[g]&&(f[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var m=l;l=s,s=m,l.length=0,i=-i}var v=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return v.concat(n.boundary);return v},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":96}],115:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3];function a(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function o(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function s(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(0!==t.type&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function l(t,e){return i(t.a,t.b,e)}function c(t,e,r,a,o){for(var s=n.lt(e,a,l),c=n.gt(e,a,l),u=s;u<c;++u){for(var f=e[u],h=f.lowerIds,p=h.length;p>1&&i(r[h[p-2]],r[h[p-1]],a)>0;)t.push([h[p-1],h[p-2],o]),p-=1;h.length=p,h.push(o);var d=f.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function u(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function f(t,e,r){var i=n.le(t,r,u),o=t[i],s=o.upperIds,l=s[s.length-1];o.upperIds=[l],t.splice(i+1,0,new a(r.a,r.b,r.idx,[l],s))}function h(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,u),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],l=0;l<r;++l)i.push(new o(t[l],null,0,l));for(l=0;l<n;++l){var u=e[l],p=t[u[0]],d=t[u[1]];p[0]<d[0]?i.push(new o(p,d,2,l),new o(d,p,1,l)):p[0]>d[0]&&i.push(new o(d,p,2,l),new o(p,d,1,l))}i.sort(s);for(var g=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),m=[new a([g,1],[g,0],-1,[],[],[],[])],v=[],y=(l=0,i.length);l<y;++l){var x=i[l],b=x.type;0===b?c(v,m,t,x.a,x.idx):2===b?f(m,t,x):h(m,t,x)}return v}},{\"binary-search-bounds\":96,\"robust-orientation\":548}],116:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":96}],117:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],118:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,f=c[e+1];for(s=0;s<f.length;++s)u+=f[s];var h=new Array(e);for(s=0;s<e;++s){f=c[s];var p=0;for(l=0;l<f.length;++l)p+=f[l];h[s]=p/u}return h}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:176,\"robust-linear-solve\":547}],119:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:118}],120:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],121:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return v(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(a=0;a<e.length;++a){o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),f=t(\"./lib/rat-seg-intersect\");function h(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],f=h(c[0]),p=h(c[1]);s.push([u(f[0],-1/0),u(p[0],-1/0),u(f[1],1/0),u(p[1],1/0)])}i(s,(function(t,e){o.link(t,e)}));var d=!0,g=new Array(a);for(l=0;l<a;++l){(v=o.find(l))!==l&&(d=!1,t[v]=[Math.min(t[l][0],t[v][0]),Math.min(t[l][1],t[v][1])])}if(d)return null;var m=0;for(l=0;l<a;++l){var v;(v=o.find(l))===l?(g[l]=m,t[m++]=t[l]):g[l]=-1}t.length=m;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function m(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function v(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(m):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),h=function(t,e,r){var n=[];return i(r,(function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],f=t[s[1]];a(l,c,u,f)&&n.push([r,i])}})),n}(t,e,n),g=p(t),m=function(t,e,r,n){var o=[];return i(r,n,(function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}})),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,h=t.map((function(t){return[o(t[0]),o(t[1])]}));for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],m=e[d],v=f(c(t[g[0]]),c(t[g[1]]),c(t[m[0]]),c(t[m[1]]));if(v){var y=t.length;t.push([l(v[0]),l(v[1])]),h.push(v),n.push([u,y],[d,y])}}for(n.sort((function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=h[t[1]],n=h[e[1]];return s(r[0],n[0])||s(r[1],n[1])})),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],T=t[_];if((w[0]-T[0]||w[1]-T[1])<0){var k=b;b=_,_=k}x[0]=b;var M,A=x[1]=S[1];for(i&&(M=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([A,E,M]):e.push([A,E]),A=E}i?e.push([A,_,M]):e.push([A,_])}return h}(t,e,h,m,r));return v(e,y,r),!!y||(h.length>0||m.length>0)}},{\"./lib/rat-seg-intersect\":122,\"big-rat\":83,\"big-rat/cmp\":81,\"big-rat/to-float\":95,\"box-intersect\":101,nextafter:496,\"rat-vec\":530,\"robust-segment-intersect\":551,\"union-find\":596}],122:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),f=s(n,r),h=u(a,f);if(0===o(h))return null;var p=s(t,r),d=u(f,p),g=i(d,h),m=c(a,g);return l(t,m)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":82,\"big-rat/mul\":92,\"big-rat/sign\":93,\"big-rat/sub\":94,\"rat-vec/add\":529,\"rat-vec/muls\":531,\"rat-vec/sub\":532}],123:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:120}],124:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],125:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:120,\"color-rgba\":127,dtype:175}],126:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=(p=t.slice(1)).length;c=1,u<=4?(l=[parseInt(p[0]+p[0],16),parseInt(p[1]+p[1],16),parseInt(p[2]+p[2],16)],4===u&&(c=parseInt(p[3]+p[3],16)/255)):(l=[parseInt(p[0]+p[1],16),parseInt(p[2]+p[3],16),parseInt(p[4]+p[5],16)],8===u&&(c=parseInt(p[6]+p[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var f=e[1],h=\"rgb\"===f,p=f.replace(/a$/,\"\");s=p;u=\"cmyk\"===p?4:\"gray\"===p?1:3;l=e[2].trim().split(/\\s*,\\s*/).map((function(t,e){if(/%$/.test(t))return e===u?parseFloat(t)/100:\"rgb\"===p?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===p[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)})),f===p&&l.push(1),c=h||void 0===l[u]?1:l[u],l=l.slice(0,u)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map((function(t){return parseFloat(t)})),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var d=a(t.r,t.red,t.R,null);null!==d?(s=\"rgb\",l=[d,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":124,defined:170,\"is-plain-obj\":469}],127:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:120,\"color-parse\":126,\"color-space/hsl\":128}],128:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":129}],129:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],130:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],131:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,f,h,p,d,g;t||(t={});p=(t.nshades||72)-1,h=t.format||\"hex\",(f=t.colormap)||(f=\"jet\");if(\"string\"==typeof f){if(f=f.toLowerCase(),!n[f])throw Error(f+\" not a supported colorscale\");u=n[f]}else{if(!Array.isArray(f))throw Error(\"unsupported colormap option\",f);u=f.slice()}if(u.length>p+1)throw new Error(f+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map((function(t){return Math.round(t.index*p)})),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var m=u.map((function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1||(n[3]=d[0]+(d[1]-d[0])*r),n})),v=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=m[g],l=m[g+1];for(var y=0;y<c;y++){var x=y/c;v.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}v.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===h?v=v.map(o):\"rgbaString\"===h?v=v.map(s):\"float\"===h&&(v=v.map(a));return v}},{\"./colorScale\":130,lerp:472}],132:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),f=l(t,e,a);return u===f?0:u?1:-1}return 0}return 0===c?s>0||l(t,e,a)?-1:1:0===s?c>0||l(t,e,r)?1:-1:i(c-s)}var h=n(t,e,r);return h>0?o>0&&n(t,e,a)>0?1:-1:h<0?o>0||n(t,e,a)>0?1:-1:n(t,e,a)>0||l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":548,\"robust-product\":549,\"robust-sum\":553,signum:554,\"two-sum\":583}],133:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],f=t[1],h=t[2],p=t[3],d=e[0],g=e[1],m=e[2],v=e[3];return u+f+h+p-(d+g+m+v)||n(u,f,h,p)-n(d,g,m,v,d)||n(u+f,u+h,u+p,f+h,f+p,h+p)-n(d+g,d+m,d+v,g+m,g+v,m+v)||n(u+f+h,u+f+p,u+h+p,f+h+p)-n(d+g+m,d+g+v,d+m+v,g+m+v);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],134:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":117,\"compare-cell\":133}],135:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":136,\"./lib/ch2d\":137,\"./lib/chnd\":138}],136:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],137:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":482}],138:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(o){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];var a=e.length;for(i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(n(a,!0),r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":67,\"incremental-convex-hull\":459}],139:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],140:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],141:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],142:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],143:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],144:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":146,\"./stringify\":147}],145:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":140}],146:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=h;var f=h.cache={};function h(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(f[t])return f[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return f[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},h=c(t,/\\s+/);e=h.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach((function(t){r[t]=e})),f[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===h[0]&&(h.shift(),r.lineHeight=p(h.shift())),!h.length)throw new Error(\"Missing required font-family.\");return r.family=c(h.join(\" \"),/\\s*,\\s*/).map(n),f[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"string-split-by\":568,unquote:598}],147:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},f={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},h=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=h),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map((function(t){return f[t]?t:'\"'+t+'\"'})).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"pick-by-alias\":511}],148:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],149:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],150:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,f=s*(3-2*i),h=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+f*r[p]+h*n[p];return a}return c*t+u*e+f*r+h*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],151:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":153}],152:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,f=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)f=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",f,\"*t\",i,\"p\",f,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(f=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",f,\"]-=s\",f].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var f=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[f].array,c=\"+q\"+f;case\"array\":c=\"p\"+u+c;var h=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):(i.push([\"var \",h,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\"[\",c,\"]=\",h].join(\"\")));else{for(var d=[s.name],g=[c],m=0;m<Math.abs(e.arrayBlockIndices[u]);m++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(m+1)+\"*t\"+u+\"b\"+m);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}function o(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,s=new Array(t.arrayArgs.length),l=new Array(t.arrayArgs.length),c=0;c<t.arrayArgs.length;++c)l[c]=e[2*c],s[c]=e[2*c+1];var u=[],f=[],h=[],p=[],d=[];for(c=0;c<t.arrayArgs.length;++c){t.arrayBlockIndices[c]<0?(h.push(0),p.push(r),u.push(r),f.push(r+t.arrayBlockIndices[c])):(h.push(t.arrayBlockIndices[c]),p.push(t.arrayBlockIndices[c]+r),u.push(0),f.push(t.arrayBlockIndices[c]));for(var g=[],m=0;m<s[c].length;m++)h[c]<=s[c][m]&&s[c][m]<p[c]&&g.push(s[c][m]-h[c]);d.push(g)}var v=[\"SS\"],y=[\"'use strict'\"],x=[];for(m=0;m<r;++m)x.push([\"s\",m,\"=SS[\",m,\"]\"].join(\"\"));for(c=0;c<t.arrayArgs.length;++c){v.push(\"a\"+c),v.push(\"t\"+c),v.push(\"p\"+c);for(m=0;m<r;++m)x.push([\"t\",c,\"p\",m,\"=t\",c,\"[\",h[c]+m,\"]\"].join(\"\"));for(m=0;m<Math.abs(t.arrayBlockIndices[c]);++m)x.push([\"t\",c,\"b\",m,\"=t\",c,\"[\",u[c]+m,\"]\"].join(\"\"))}for(c=0;c<t.scalarArgs.length;++c)v.push(\"Y\"+c);if(t.shapeArgs.length>0&&x.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var b=new Array(r);for(c=0;c<r;++c)b[c]=\"0\";x.push([\"index=[\",b.join(\",\"),\"]\"].join(\"\"))}for(c=0;c<t.offsetArgs.length;++c){var _=t.offsetArgs[c],w=[];for(m=0;m<_.offset.length;++m)0!==_.offset[m]&&(1===_.offset[m]?w.push([\"t\",_.array,\"p\",m].join(\"\")):w.push([_.offset[m],\"*t\",_.array,\"p\",m].join(\"\")));0===w.length?x.push(\"q\"+c+\"=0\"):x.push([\"q\",c,\"=\",w.join(\"+\")].join(\"\"))}var T=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((x=x.concat(T)).length>0&&y.push(\"var \"+x.join(\",\")),c=0;c<t.arrayArgs.length;++c)y.push(\"p\"+c+\"|=0\");t.pre.body.length>3&&y.push(a(t.pre,t,l));var k=a(t.body,t,l),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(d);M<r?y.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var f=[\"offset\"+u],h=t;h<a;++h)f.push([\"j\",h,\"*t\",u,\"p\",e[h]].join(\"\"));c.push([\"p\",u,\"=(\",f.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(M,d[0],t,k)):y.push(i(d[0],t,k)),t.post.body.length>3&&y.push(a(t.post,t,l)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+y.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",s[0].join(\"s\"),\"m\",M,o(l)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",y.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:597}],153:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var f=t.arrayArgs[u];r.push([\"t\",f,\"=array\",f,\".dtype,\",\"r\",f,\"=array\",f,\".order\"].join(\"\")),a.push(\"t\"+f),a.push(\"r\"+f),o.push(\"t\"+f),o.push(\"r\"+f+\".join()\"),s.push(\"array\"+f+\".data\"),s.push(\"array\"+f+\".stride\"),s.push(\"array\"+f+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+f+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+f+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":152}],154:[function(t,e,r){\"use strict\";var n,i=t(\"type/value/is\"),a=t(\"type/value/ensure\"),o=t(\"type/plain-function/ensure\"),s=t(\"es5-ext/object/copy\"),l=t(\"es5-ext/object/normalize-options\"),c=t(\"es5-ext/object/map\"),u=Function.prototype.bind,f=Object.defineProperty,h=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=a(e)&&o(e.value);return delete(n=s(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&h.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),f(this,t,e),this[t])},n},e.exports=function(t){var e=l(arguments[1]);return i(e.resolveContext)&&o(e.resolveContext),c(t,(function(t,r){return n(r,t,e)}))}},{\"es5-ext/object/copy\":196,\"es5-ext/object/map\":204,\"es5-ext/object/normalize-options\":205,\"type/plain-function/ensure\":589,\"type/value/ensure\":593,\"type/value/is\":594}],155:[function(t,e,r){\"use strict\";var n=t(\"type/value/is\"),i=t(\"type/plain-function/is\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/normalize-options\"),s=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,i,l,c,u;return arguments.length<2||\"string\"!=typeof t?(c=e,e=t,t=null):c=arguments[2],n(t)?(r=s.call(t,\"c\"),i=s.call(t,\"e\"),l=s.call(t,\"w\")):(r=l=!0,i=!1),u={value:e,configurable:r,enumerable:i,writable:l},c?a(o(c),u):u}).gs=function(t,e,r){var l,c,u,f;return\"string\"!=typeof t?(u=r,r=e,e=t,t=null):u=arguments[3],n(e)?i(e)?n(r)?i(r)||(u=r,r=void 0):r=void 0:(u=e,e=r=void 0):e=void 0,n(t)?(l=s.call(t,\"c\"),c=s.call(t,\"e\")):(l=!0,c=!1),f={get:e,set:r,configurable:l,enumerable:c},u?a(o(u),f):f}},{\"es5-ext/object/assign\":193,\"es5-ext/object/normalize-options\":205,\"es5-ext/string/#/contains\":212,\"type/plain-function/is\":590,\"type/value/is\":594}],156:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var f=Array.prototype,h=f.slice,p=f.map;function d(t){return function(){return t}}function g(t){return t}function m(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var v=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=v?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=v?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=v?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function T(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function k(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function M(t){if(!(i=t.length))return[];for(var e=-1,r=k(t,A),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function A(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],f=c[1],h=r(l,u,f);Array.isArray(h)||(h=_(u,f,h),h=m(Math.ceil(u/h)*h,f,h));for(var p=h.length;h[0]<=u;)h.shift(),--p;for(;h[p-1]>f;)h.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?h[a-1]:u,d.x1=a<p?h[a]:f;for(a=0;a<s;++a)u<=(o=l[a])&&o<=f&&g[i(h,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(h.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(T(t,.75)-T(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return T(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=k,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=T,t.range=m,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)===(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=M,t.variance=l,t.zip=function(){return M(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],157:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each((function(t,e){n.set(e,t)}));else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each((function(t){r.add(t)}));else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each},t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,f,h=-1,p=n.length,d=l[i++],g=r(),m=a();++h<p;)(f=g.get(s=d(c=n[h])+\"\"))?f.push(c):g.set(s,[c]);return g.each((function(t,e){o(m,e,u(t,i,a,o))})),m}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each((function(e,r){i.push({key:r,values:t(e,n)})}))),null!=a?i.sort((function(t,e){return a(t.key,e.key)})):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],158:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3,8})$/,l=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),c=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),u=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),h=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),p=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),d={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function g(){return this.rgb().formatHex()}function m(){return this.rgb().formatRgb()}function v(t){var e,r;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?y(e):3===r?new w(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?x(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?x(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=l.exec(t))?new w(e[1],e[2],e[3],1):(e=c.exec(t))?new w(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=u.exec(t))?x(e[1],e[2],e[3],e[4]):(e=f.exec(t))?x(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=h.exec(t))?A(e[1],e[2]/100,e[3]/100,1):(e=p.exec(t))?A(e[1],e[2]/100,e[3]/100,e[4]):d.hasOwnProperty(t)?y(d[t]):\"transparent\"===t?new w(NaN,NaN,NaN,0):null}function y(t){return new w(t>>16&255,t>>8&255,255&t,1)}function x(t,e,r,n){return n<=0&&(t=e=r=NaN),new w(t,e,r,n)}function b(t){return t instanceof n||(t=v(t)),t?new w((t=t.rgb()).r,t.g,t.b,t.opacity):new w}function _(t,e,r,n){return 1===arguments.length?b(t):new w(t,e,r,null==n?1:n)}function w(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function T(){return\"#\"+M(this.r)+M(this.g)+M(this.b)}function k(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}function M(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function A(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new C(t,e,r,n)}function S(t){if(t instanceof C)return new C(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new C;if(t instanceof C)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new C(s,l,c,t.opacity)}function E(t,e,r,n){return 1===arguments.length?S(t):new C(t,e,r,null==n?1:n)}function C(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function L(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:g,formatHex:g,formatHsl:function(){return S(this).formatHsl()},formatRgb:m,toString:m}),e(w,_,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:T,formatHex:T,formatRgb:k,toString:k})),e(C,E,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new C(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new C(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new w(L(t>=240?t-240:t+120,i,n),L(t,i,n),L(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"hsl(\":\"hsla(\")+(this.h||0)+\", \"+100*(this.s||0)+\"%, \"+100*(this.l||0)+\"%\"+(1===t?\")\":\", \"+t+\")\")}}));var I=Math.PI/180,P=180/Math.PI,z=6/29,O=3*z*z;function D(t){if(t instanceof F)return new F(t.l,t.a,t.b,t.opacity);if(t instanceof H)return G(t);t instanceof w||(t=b(t));var e,r,n=U(t.r),i=U(t.g),a=U(t.b),o=B((.2225045*n+.7168786*i+.0606169*a)/1);return n===i&&i===a?e=r=o:(e=B((.4360747*n+.3850649*i+.1430804*a)/.96422),r=B((.0139322*n+.0971045*i+.7141733*a)/.82521)),new F(116*o-16,500*(e-o),200*(o-r),t.opacity)}function R(t,e,r,n){return 1===arguments.length?D(t):new F(t,e,r,null==n?1:n)}function F(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function B(t){return t>.008856451679035631?Math.pow(t,1/3):t/O+4/29}function N(t){return t>z?t*t*t:O*(t-4/29)}function j(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function V(t){if(t instanceof H)return new H(t.h,t.c,t.l,t.opacity);if(t instanceof F||(t=D(t)),0===t.a&&0===t.b)return new H(NaN,0<t.l&&t.l<100?0:NaN,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*P;return new H(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function q(t,e,r,n){return 1===arguments.length?V(t):new H(t,e,r,null==n?1:n)}function H(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}function G(t){if(isNaN(t.h))return new F(t.l,0,0,t.opacity);var e=t.h*I;return new F(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}e(F,R,r(n,{brighter:function(t){return new F(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new F(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new w(j(3.1338561*(e=.96422*N(e))-1.6168667*(t=1*N(t))-.4906146*(r=.82521*N(r))),j(-.9787684*e+1.9161415*t+.033454*r),j(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(H,q,r(n,{brighter:function(t){return new H(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new H(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return G(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,Q=J*W,$=W*X-Z*Y;function tt(t){if(t instanceof rt)return new rt(t.h,t.s,t.l,t.opacity);t instanceof w||(t=b(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=($*n+K*e-Q*r)/($+K-Q),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*P-120:NaN;return new rt(l<0?l+360:l,s,i,t.opacity)}function et(t,e,r,n){return 1===arguments.length?tt(t):new rt(t,e,r,null==n?1:n)}function rt(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(rt,et,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*I,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new w(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.cubehelix=et,t.gray=function(t,e){return new F(t,0,0,null==e?1:e)},t.hcl=q,t.hsl=E,t.lab=R,t.lch=function(t,e,r,n){return 1===arguments.length?V(t):new H(r,e,t,null==n?1:n)},t.rgb=_,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],159:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i||/[\\s.]/.test(t))throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){return t.trim().split(/^|\\s+/).map((function(t){var r=\"\",n=t.indexOf(\".\");if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t&&!e.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:r}}))}function a(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function o(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n=this._,s=i(t+\"\",n),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)n[r]=o(n[r],t.name,e);else if(null==e)for(r in n)n[r]=o(n[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=a(n[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],160:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return function(){return t}}function o(){return 1e-6*(Math.random()-.5)}function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function f(t){return t.x}function h(t){return t.y}var p=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,h,p,d,g,m=r.length,v=0;v<c;++v)for(a=e.quadtree(r,s,l).visitAfter(f),t=0;t<m;++t)u=r[t],d=n[u.index],g=d*d,h=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>h+c||n<h-c||r>p+c||a<p-c;if(s.index>u.index){var f=h-s.x-s.vx,m=p-s.y-s.vy,v=f*f+m*m;v<c*c&&(0===f&&(v+=(f=o())*f),0===m&&(v+=(m=o())*m),v=(c-(v=Math.sqrt(v)))/v*i,u.vx+=(f*=v)*(c=(l*=l)/(g+l)),u.vy+=(m*=v)*c,s.vx-=f*(c=1-c),s.vy-=m*c)}}}function f(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function h(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,h()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),h(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,f=c,h=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,f,h,p,g,m=0;m<a;++m)c=(s=t[m]).source,f=(u=s.target).x+u.vx-c.x-c.vx||o(),h=u.y+u.vy-c.y-c.vy||o(),f*=p=((p=Math.sqrt(f*f+h*h))-n[m])/p*r*e[m],h*=p,u.vx-=f*(g=l[m]),u.vy-=h*g,c.vx+=f*(g=1-g),c.vy+=h*g}function m(){if(i){var a,o,c=i.length,h=t.length,p=r.map(i,f);for(a=0,s=new Array(c);a<h;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(h);a<h;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(h),v(),n=new Array(h),y()}}function v(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+h(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,m()},g.links=function(e){return arguments.length?(t=e,m(),g):t},g.id=function(t){return arguments.length?(f=t,g):f},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(h=\"function\"==typeof t?t:a(+t),v(),g):h},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,f,h).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(m)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function m(t,e,a,s){if(!t.value)return!0;var f=t.x-r.x,h=t.y-r.y,p=s-e,d=f*f+h*h;if(p*p/u<d)return d<c&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)),r.vx+=f*t.value*n/d,r.vy+=h*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=f*p,r.vy+=h*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,f=Math.sqrt(c*c+u*u),h=(o[a]-f)*i[a]*t/f;l.vx+=c*h,l.vy+=u*h}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),f=i.timer(d),h=n.dispatch(\"tick\",\"end\");function d(){g(),h.call(\"tick\",e),a<o&&(f.stop(),h.call(\"end\",e))}function g(r){var n,i,o=t.length;void 0===r&&(r=1);for(var f=0;f<r;++f)for(a+=(l-a)*s,u.each((function(t){t(a)})),n=0;n<o;++n)null==(i=t[n]).fx?i.x+=i.vx*=c:(i.x=i.fx,i.vx=0),null==i.fy?i.y+=i.vy*=c:(i.y=i.fy,i.vy=0);return e}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,null!=e.fx&&(e.x=e.fx),null!=e.fy&&(e.y=e.fy),isNaN(e.x)||isNaN(e.y)){var i=10*Math.sqrt(r),a=r*p;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function v(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:g,restart:function(){return f.restart(d),e},stop:function(){return f.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(v),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,v(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(h.on(t,r),e):h.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-collection\":157,\"d3-dispatch\":159,\"d3-quadtree\":164,\"d3-timer\":168}],161:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),f=+t.value&&(u.value=t.value),h=[u];for(null==e&&(e=o);r=h.pop();)if(f&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)h.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter((function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r}))},sort:function(t){return this.eachBefore((function(e){e.children&&e.children.sort(t)}))},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;t=r.pop(),e=n.pop();for(;t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each((function(e){t.push(e)})),t},leaves:function(){var t=[];return this.eachBefore((function(e){e.children||t.push(e)})),t},links:function(){var t=this,e=[];return t.each((function(r){r!==t&&e.push({source:r.parent,target:r})})),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function f(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=m(a=h(a,e)),n=0);return r}function h(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(v(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(v(t[r],t[n]),e)&&p(v(t[r],e),t[n])&&p(v(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function m(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return v(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function v(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,f=Math.sqrt(l*l+c*c);return{x:(r+a+l/f*u)/2,y:(n+o+c/f*u)/2,r:(f+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,f=r.r,h=n-o,p=n-c,d=i-s,g=i-u,m=l-a,v=f-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+f*f,_=p*d-h*g,w=(d*b-g*x)/(2*_)-n,T=(g*m-d*v)/_,k=(p*x-h*b)/(2*_)-i,M=(h*v-p*m)/_,A=T*T+M*M-1,S=2*(a+w*T+k*M),E=w*w+k*k-a*a,C=-(A?(S+Math.sqrt(S*S-4*A*E))/(2*A):E/S);return{x:n+w+T*C,y:i+k+M*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function T(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,h;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,h=e._.r;do{if(u<=h){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}h+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=f(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function k(t){return null==t?null:M(t)}function M(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function S(t){return function(){return t}}function E(t){return Math.sqrt(t.value)}function C(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function L(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=T(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function I(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function z(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var O={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,f,h,p,d,g,m,v=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(f=h=u,m=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(h/m,m/f);b<_;++b){if(u+=s=y[b].value,s<f&&(f=s),s>h&&(h=s),m=u*u*g,(p=Math.max(h/m,m/f))>d){u-=s;break}d=p}v.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?z(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return v}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,f=-1,h=o.length,p=t.value;++f<h;){for(l=(s=o[f]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?z(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter((function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)}));var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),f=c.x-t(c,u)/2,h=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-f)/(h-f)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(C(t)).eachAfter(L(n,.5)).eachBefore(I(1)):i.eachBefore(C(E)).eachAfter(L(A,1)).eachAfter(L(n,i.r/Math.min(e,r))).eachBefore(I(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=k(e),i):t},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:S(+t),i):n},i},t.packEnclose=f,t.packSiblings=function(t){return T(t),t},t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&z(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,f,h=r.length,p=new Array(h),d={};for(i=0;i<h;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[f=\"$\"+(s.id=u)]=f in d?D:s);for(i=0;i<h;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[\"$\"+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=O,a.eachBefore((function(t){t.depth=t.parent.depth+1,--h})).eachBefore(l),a.parent=null,h>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=M(e),r):t},r.parentId=function(t){return arguments.length?(e=M(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,f=i;i.eachBefore((function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>f.depth&&(f=t)}));var h=c===u?1:t(c,u)/2,p=h-c.x,d=e/(u.x+h+p),g=r/(f.depth||1);i.eachBefore((function(t){t.x=(t.x+p)*d,t.y=t.depth*g}))}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+f-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=f-u),a&&!N(l)&&(l.t=a,l.m+=c-h,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(f),i=[0],e&&t.eachBefore(P),t}function f(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,f=e.x1-r,h=e.y1-r;f<n&&(n=f=(n+f)/2),h<u&&(u=h=(u+h)/2),e.x0=n,e.y0=u,e.x1=f,e.y1=h,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(f-=s(e)-r)<n&&(n=f=(n+f)/2),(h-=l(e)-r)<u&&(u=h=(u+h)/2),t(e,n,u,f,h))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=M(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:S(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:S(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:S(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:S(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:S(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}var f=c[e],h=n/2+f,p=e+1,d=r-1;for(;p<d;){var g=p+d>>>1;c[g]<h?p=g+1:d=g}h-c[p-1]<c[p]-h&&e+1<p&&--p;var m=c[p]-f,v=n-m;if(o-i>l-a){var y=(i*v+o*m)/n;t(e,p,m,i,a,y,l),t(p,r,v,y,a,o,l)}else{var x=(a*v+l*m)/n;t(e,p,m,i,a,o,x),t(p,r,v,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=z,t.treemapResquarify=X,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:z)(t,e,r,n,i)},t.treemapSquarify=W,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],162:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function f(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var h=f(n),p=f(i);function d(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,i=e.slice();return function(a){for(r=0;r<n;++r)i[r]=t[r]*(1-a)+e[r]*a;return i}}function g(t){return ArrayBuffer.isView(t)&&!(t instanceof DataView)}function m(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=T(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function v(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function y(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function x(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=T(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var b=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,_=new RegExp(b.source,\"g\");function w(t,e){var r,n,i,a=b.lastIndex=_.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=b.exec(t))&&(n=_.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:y(r,n)})),a=_.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function T(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?y:\"string\"===i?(n=e.color(r))?(r=n,u):w:r instanceof e.color?u:r instanceof Date?v:g(r)?d:Array.isArray(r)?m:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?x:y)(t,r)}var k,M,A,S,E=180/Math.PI,C={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function L(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*E,skewX:Math.atan(l)*E,scaleX:o,scaleY:s}}function I(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:y(t,i)},{i:l-2,x:y(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:y(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:y(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:y(t,r)},{i:s-2,x:y(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var P=I((function(t){return\"none\"===t?C:(k||(k=document.createElement(\"DIV\"),M=document.documentElement,A=document.defaultView),k.style.transform=t,t=A.getComputedStyle(M.appendChild(k),null).getPropertyValue(\"transform\"),M.removeChild(k),L(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))}),\"px, \",\"px)\",\"deg)\"),z=I((function(t){return null==t?C:(S||(S=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),S.setAttribute(\"transform\",t),(t=S.transform.baseVal.consolidate())?L((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):C)}),\", \",\")\",\")\"),O=Math.SQRT2;function D(t){return((t=Math.exp(t))+1/t)/2}function R(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var F=R(s),B=R(c);function N(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var j=N(s),U=N(c);function V(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var q=V(s),H=V(c);t.interpolate=T,t.interpolateArray=function(t,e){return(g(e)?d:m)(t,e)},t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateCubehelix=q,t.interpolateCubehelixLong=H,t.interpolateDate=v,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHcl=j,t.interpolateHclLong=U,t.interpolateHsl=F,t.interpolateHslLong=B,t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateNumber=y,t.interpolateNumberArray=d,t.interpolateObject=x,t.interpolateRgb=u,t.interpolateRgbBasis=h,t.interpolateRgbBasisClosed=p,t.interpolateRound=function(t,e){return t=+t,e=+e,function(r){return Math.round(t*(1-r)+e*r)}},t.interpolateString=w,t.interpolateTransformCss=P,t.interpolateTransformSvg=z,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<1e-12)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*f,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/O,r=function(t){var e,r=t*n,s=D(m),l=o/(2*p)*(s*(e=O*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/D(O*r+m)]}}return r.duration=1e3*n,r},t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-color\":158}],163:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,f=s-r,h=u*u+f*f;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(h>1e-6)if(Math.abs(f*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,m=p*p+d*d,v=Math.sqrt(g),y=Math.sqrt(h),x=a*Math.tan((e-Math.acos((g+h-m)/(2*v*y)))/2),b=x/y,_=x/v;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*f)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(f*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i,l=!!l;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),f=t+c,h=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+f+\",\"+h:(Math.abs(this._x1-f)>1e-6||Math.abs(this._y1-h)>1e-6)&&(this._+=\"L\"+f+\",\"+h),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=f)+\",\"+(this._y1=h):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],164:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,f,h,p=t._root,d={data:n},g=t._x0,m=t._y0,v=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o,i=p,!(p=p[f=u<<1|c]))return i[f]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[f]=d:t._root=d,t;do{i=i?i[f]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o}while((f=u<<1|c)==(h=(l>=o)<<1|s>=a));return i[h]=p,i[f]=d,t}function r(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i}function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,f=-1/0,h=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>f&&(f=i),a<u&&(u=a),a>h&&(h=a));if(c>f||u>h)return this;for(this.cover(c,u).cover(f,h),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{for(var o,s,l=i-r,c=this._root;r>t||t>=i||n>e||e>=a;)switch(s=(e<n)<<1|t<r,(o=new Array(4))[s]=c,c=o,l*=2,s){case 0:i=r+l,a=n+l;break;case 1:r=i-l,a=n+l;break;case 2:i=r+l,n=a-l;break;case 3:r=i-l,n=a-l}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit((function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)})),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,f=this._x0,h=this._y0,p=this._x1,d=this._y1,g=[],m=this._root;for(m&&g.push(new r(m,f,h,p,d)),null==n?n=1/0:(f=t-n,h=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(m=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<f||(l=c.y1)<h))if(m.length){var v=(a+s)/2,y=(o+l)/2;g.push(new r(m[3],v,y,s,l),new r(m[2],a,y,v,l),new r(m[1],v,o,s,y),new r(m[0],a,o,v,y)),(u=(e>=y)<<1|t>=v)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,m.data),b=e-+this._y.call(null,m.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);f=t-w,h=e-w,p=t+w,d=e+w,i=m.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,f,h,p=this._root,d=this._x0,g=this._y0,m=this._x1,v=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+m)/2))?d=s:m=s,(u=o>=(l=(g+v)/2))?g=l:v=l,e=p,!(p=p[f=u<<1|c]))return this;if(!p.length)break;(e[f+1&3]||e[f+2&3]||e[f+3&3])&&(r=e,h=f)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[f]=i:delete e[f],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[h]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit((function(e){if(!e.length)do{++t}while(e=e.next)})),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,f=(a+s)/2;(n=c[3])&&l.push(new r(n,u,f,o,s)),(n=c[2])&&l.push(new r(n,i,f,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,f)),(n=c[0])&&l.push(new r(n,i,a,u,f))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,f=(s+c)/2,h=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,f,h)),(o=a[1])&&n.push(new r(o,f,l,c,h)),(o=a[2])&&n.push(new r(o,s,h,f,u)),(o=a[3])&&n.push(new r(o,f,h,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],165:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=Math.PI,f=u/2,h=2*u;function p(t){return t>1?0:t<-1?u:Math.acos(t)}function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function m(t){return t.outerRadius}function v(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,u=o-i,f=s-a,h=f*l-u*c;if(!(h*h<1e-12))return[t+(h=(u*(e-a)-f*(t-i))/h)*l,e+h*c]}function _(t,e,r,n,i,a,s){var l=t-r,u=e-n,f=(s?a:-a)/c(l*l+u*u),h=f*u,p=-f*l,d=t+h,g=e+p,m=r+h,v=n+p,y=(d+m)/2,x=(g+v)/2,b=m-d,_=v-g,w=b*b+_*_,T=i-a,k=d*v-m*g,M=(_<0?-1:1)*c(o(0,T*T*w-k*k)),A=(k*_-b*M)/w,S=(-k*b-_*M)/w,E=(k*_+b*M)/w,C=(-k*b+_*M)/w,L=A-y,I=S-x,P=E-y,z=C-x;return L*L+I*I>P*P+z*z&&(A=E,S=C),{cx:A,cy:S,x01:-h,y01:-p,x11:A*(i/T-1),y11:S*(i/T-1)}}function w(t){this._context=t}function T(t){return new w(t)}function k(t){return t[0]}function M(t){return t[1]}function A(){var t=k,n=M,i=r(!0),a=null,o=T,s=null;function l(r){var l,c,u,f=r.length,h=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=f;++l)!(l<f&&i(c=r[l],l,r))===h&&((h=!h)?s.lineStart():s.lineEnd()),h&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function S(){var t=k,n=null,i=r(0),a=M,o=r(!0),s=null,l=T,c=null;function u(r){var u,f,h,p,d,g=r.length,m=!1,v=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===m)if(m=!m)f=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),h=u-1;h>=f;--h)c.point(v[h],y[h]);c.lineEnd(),c.areaEnd()}m&&(v[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):v[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function f(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return f().x(t).y(i)},u.lineY1=function(){return f().x(t).y(a)},u.lineX1=function(){return f().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function E(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function C(t){return t}w.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var L=P(T);function I(t){this._curve=t}function P(t){function e(e){return new I(t(e))}return e._curve=t,e}function z(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function O(){return z(A().curve(L))}function D(){var t=S().curve(L),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return z(r())},delete t.lineX0,t.lineEndAngle=function(){return z(n())},delete t.lineX1,t.lineInnerRadius=function(){return z(i())},delete t.lineY0,t.lineOuterRadius=function(){return z(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function R(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}I.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var F=Array.prototype.slice;function B(t){return t.source}function N(t){return t.target}function j(t){var n=B,i=N,a=k,o=M,s=null;function l(){var r,l=F.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function V(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function q(t,e,r,n,i){var a=R(e,r),o=R(e,r=(r+i)/2),s=R(n,r),l=R(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var H={draw:function(t,e){var r=Math.sqrt(e/u);t.moveTo(r,0),t.arc(0,0,r,0,h)}},G={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},Y=Math.sqrt(1/3),W=2*Y,X={draw:function(t,e){var r=Math.sqrt(e/W),n=r*Y;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},Z=Math.sin(u/10)/Math.sin(7*u/10),J=Math.sin(h/10)*Z,K=-Math.cos(h/10)*Z,Q={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=J*r,i=K*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=h*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},tt=Math.sqrt(3),et={draw:function(t,e){var r=-Math.sqrt(e/(3*tt));t.moveTo(0,2*r),t.lineTo(-tt*r,-r),t.lineTo(tt*r,-r),t.closePath()}},rt=-.5,nt=Math.sqrt(3)/2,it=1/Math.sqrt(12),at=3*(it/2+1),ot={draw:function(t,e){var r=Math.sqrt(e/at),n=r/2,i=r*it,a=n,o=r*it+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(rt*n-nt*i,nt*n+rt*i),t.lineTo(rt*a-nt*o,nt*a+rt*o),t.lineTo(rt*s-nt*l,nt*s+rt*l),t.lineTo(rt*n+nt*i,rt*i-nt*n),t.lineTo(rt*a+nt*o,rt*o-nt*a),t.lineTo(rt*s+nt*l,rt*l-nt*s),t.closePath()}},st=[H,G,X,$,Q,et,ot];function lt(){}function ct(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ut(t){this._context=t}function ft(t){this._context=t}function ht(t){this._context=t}function pt(t,e){this._basis=new ut(t),this._beta=e}ut.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:ct(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},pt.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var dt=function t(e){function r(t){return 1===e?new ut(t):new pt(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function gt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:gt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function yt(t,e){this._context=t,this._k=(1-e)/6}yt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var xt=function t(e){function r(t){return new yt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function bt(t,e){this._context=t,this._k=(1-e)/6}bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var _t=function t(e){function r(t){return new bt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function wt(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>1e-12){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>1e-12){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,u=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/u,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/u}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Mt(t,e):new yt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function St(t,e){this._context=t,this._alpha=e}St.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var Et=function t(e){function r(t){return e?new St(t,e):new bt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Ct(t){this._context=t}function Lt(t){return t<0?-1:1}function It(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Lt(a)+Lt(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function zt(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function Ot(t){this._context=t}function Dt(t){this._context=new Rt(t)}function Rt(t){this._context=t}function Ft(t){this._context=t}function Bt(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Nt(t,e){this._context=t,this._t=e}function jt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function Ut(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function qt(t){var e=t.map(Ht);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Ht(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Gt(t){var e=t.map(Yt);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Yt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Ct.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},Ot.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:zt(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,zt(this,Pt(this,r=It(this,t,e)),r);break;default:zt(this,this._t0,r=It(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(Dt.prototype=Object.create(Ot.prototype)).point=function(t,e){Ot.prototype.point.call(this,e,t)},Rt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Bt(t),i=Bt(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Nt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=m,w=r(0),T=null,k=v,M=y,A=x,S=null;function E(){var r,g,m=+t.apply(this,arguments),v=+o.apply(this,arguments),y=k.apply(this,arguments)-f,x=M.apply(this,arguments)-f,E=n(x-y),C=x>y;if(S||(S=r=e.path()),v<m&&(g=v,v=m,m=g),v>1e-12)if(E>h-1e-12)S.moveTo(v*a(y),v*l(y)),S.arc(0,0,v,y,x,!C),m>1e-12&&(S.moveTo(m*a(x),m*l(x)),S.arc(0,0,m,x,y,C));else{var L,I,P=y,z=x,O=y,D=x,R=E,F=E,B=A.apply(this,arguments)/2,N=B>1e-12&&(T?+T.apply(this,arguments):c(m*m+v*v)),j=s(n(v-m)/2,+w.apply(this,arguments)),U=j,V=j;if(N>1e-12){var q=d(N/m*l(B)),H=d(N/v*l(B));(R-=2*q)>1e-12?(O+=q*=C?1:-1,D-=q):(R=0,O=D=(y+x)/2),(F-=2*H)>1e-12?(P+=H*=C?1:-1,z-=H):(F=0,P=z=(y+x)/2)}var G=v*a(P),Y=v*l(P),W=m*a(D),X=m*l(D);if(j>1e-12){var Z,J=v*a(z),K=v*l(z),Q=m*a(O),$=m*l(O);if(E<u&&(Z=b(G,Y,Q,$,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(p((tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(v-at)/(it+1))}}F>1e-12?V>1e-12?(L=_(Q,$,G,Y,v,V,C),I=_(J,K,W,X,v,V,C),S.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,v,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),!C),S.arc(I.cx,I.cy,V,i(I.y11,I.x11),i(I.y01,I.x01),!C))):(S.moveTo(G,Y),S.arc(0,0,v,P,z,!C)):S.moveTo(G,Y),m>1e-12&&R>1e-12?U>1e-12?(L=_(W,X,J,K,m,-U,C),I=_(G,Y,Q,$,m,-U,C),S.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),C),S.arc(I.cx,I.cy,U,i(I.y11,I.x11),i(I.y01,I.x01),!C))):S.arc(0,0,m,D,O,C):S.lineTo(W,X)}else S.moveTo(0,0);if(S.closePath(),r)return S=null,r+\"\"||null}return E.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +M.apply(this,arguments))/2-u/2;return[a(r)*e,l(r)*e]},E.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),E):t},E.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),E):o},E.cornerRadius=function(t){return arguments.length?(w=\"function\"==typeof t?t:r(+t),E):w},E.padRadius=function(t){return arguments.length?(T=null==t?null:\"function\"==typeof t?t:r(+t),E):T},E.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),E):k},E.endAngle=function(t){return arguments.length?(M=\"function\"==typeof t?t:r(+t),E):M},E.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),E):A},E.context=function(t){return arguments.length?(S=null==t?null:t,E):S},E},t.area=S,t.areaRadial=D,t.curveBasis=function(t){return new ut(t)},t.curveBasisClosed=function(t){return new ft(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBundle=dt,t.curveCardinal=vt,t.curveCardinalClosed=xt,t.curveCardinalOpen=_t,t.curveCatmullRom=kt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=Et,t.curveLinear=T,t.curveLinearClosed=function(t){return new Ct(t)},t.curveMonotoneX=function(t){return new Ot(t)},t.curveMonotoneY=function(t){return new Dt(t)},t.curveNatural=function(t){return new Ft(t)},t.curveStep=function(t){return new Nt(t,.5)},t.curveStepAfter=function(t){return new Nt(t,1)},t.curveStepBefore=function(t){return new Nt(t,0)},t.line=A,t.lineRadial=O,t.linkHorizontal=function(){return j(U)},t.linkRadial=function(){var t=j(q);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.linkVertical=function(){return j(V)},t.pie=function(){var t=C,e=E,n=null,i=r(0),a=r(h),o=r(0);function s(r){var s,l,c,u,f,p=r.length,d=0,g=new Array(p),m=new Array(p),v=+i.apply(this,arguments),y=Math.min(h,Math.max(-h,a.apply(this,arguments)-v)),x=Math.min(Math.abs(y)/p,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<p;++s)(f=m[g[s]=s]=+t(r[s],s,r))>0&&(d+=f);for(null!=e?g.sort((function(t,r){return e(m[t],m[r])})):null!=n&&g.sort((function(t,e){return n(r[t],r[e])})),s=0,c=d?(y-p*b)/d:0;s<p;++s,v=u)l=g[s],u=v+((f=m[l])>0?f*c:0)+b,m[l]={data:r[l],index:s,value:f,startAngle:v,endAngle:u,padAngle:x};return m}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.pointRadial=R,t.radialArea=D,t.radialLine=O,t.stack=function(){var t=r([]),e=Ut,n=jt,i=Vt;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var f,h=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=f=[0,+i(r[d],h,d,r)],f.data=r[d];p.key=h}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(F.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?Ut:\"function\"==typeof t?t:r(F.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?jt:t,a):n},a},t.stackOffsetDiverging=function(t,e){if((s=t.length)>0)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):(n[0]=0,n[1]=i)},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}jt(t,e)}},t.stackOffsetNone=jt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}jt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],f=u[o][1]||0,h=(f-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];h+=(d[o][1]||0)-(d[o-1][1]||0)}l+=f,c+=h*f}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,jt(t,e)}},t.stackOrderAppearance=qt,t.stackOrderAscending=Gt,t.stackOrderDescending=function(t){return Gt(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Yt),a=qt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=Ut,t.stackOrderReverse=function(t){return Ut(t).reverse()},t.symbol=function(){var t=r(H),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbolCircle=H,t.symbolCross=G,t.symbolDiamond=X,t.symbolSquare=$,t.symbolStar=Q,t.symbolTriangle=et,t.symbolWye=ot,t.symbols=st,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-path\":163}],166:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-time\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function n(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function i(t,e,r){return{y:t,m:e,d:r,H:0,M:0,S:0,L:0}}function a(t){var a=t.dateTime,o=t.date,l=t.time,c=t.periods,u=t.days,f=t.shortDays,h=t.months,yt=t.shortMonths,xt=p(c),bt=d(c),_t=p(u),wt=d(u),Tt=p(f),kt=d(f),Mt=p(h),At=d(h),St=p(yt),Et=d(yt),Ct={a:function(t){return f[t.getDay()]},A:function(t){return u[t.getDay()]},b:function(t){return yt[t.getMonth()]},B:function(t){return h[t.getMonth()]},c:null,d:D,e:D,f:j,H:R,I:F,j:B,L:N,m:U,M:V,p:function(t){return c[+(t.getHours()>=12)]},q:function(t){return 1+~~(t.getMonth()/3)},Q:mt,s:vt,S:q,u:H,U:G,V:Y,w:W,W:X,x:null,X:null,y:Z,Y:J,Z:K,\"%\":gt},Lt={a:function(t){return f[t.getUTCDay()]},A:function(t){return u[t.getUTCDay()]},b:function(t){return yt[t.getUTCMonth()]},B:function(t){return h[t.getUTCMonth()]},c:null,d:Q,e:Q,f:nt,H:$,I:tt,j:et,L:rt,m:it,M:at,p:function(t){return c[+(t.getUTCHours()>=12)]},q:function(t){return 1+~~(t.getUTCMonth()/3)},Q:mt,s:vt,S:ot,u:st,U:lt,V:ct,w:ut,W:ft,x:null,X:null,y:ht,Y:pt,Z:dt,\"%\":gt},It={a:function(t,e,r){var n=Tt.exec(e.slice(r));return n?(t.w=kt[n[0].toLowerCase()],r+n[0].length):-1},A:function(t,e,r){var n=_t.exec(e.slice(r));return n?(t.w=wt[n[0].toLowerCase()],r+n[0].length):-1},b:function(t,e,r){var n=St.exec(e.slice(r));return n?(t.m=Et[n[0].toLowerCase()],r+n[0].length):-1},B:function(t,e,r){var n=Mt.exec(e.slice(r));return n?(t.m=At[n[0].toLowerCase()],r+n[0].length):-1},c:function(t,e,r){return Ot(t,a,e,r)},d:M,e:M,f:I,H:S,I:S,j:A,L:L,m:k,M:E,p:function(t,e,r){var n=xt.exec(e.slice(r));return n?(t.p=bt[n[0].toLowerCase()],r+n[0].length):-1},q:T,Q:z,s:O,S:C,u:m,U:v,V:y,w:g,W:x,x:function(t,e,r){return Ot(t,o,e,r)},X:function(t,e,r){return Ot(t,l,e,r)},y:_,Y:b,Z:w,\"%\":P};function Pt(t,e){return function(r){var n,i,a,o=[],l=-1,c=0,u=t.length;for(r instanceof Date||(r=new Date(+r));++l<u;)37===t.charCodeAt(l)&&(o.push(t.slice(c,l)),null!=(i=s[n=t.charAt(++l)])?n=t.charAt(++l):i=\"e\"===n?\" \":\"0\",(a=e[n])&&(n=a(r,i)),o.push(n),c=l+1);return o.push(t.slice(c,l)),o.join(\"\")}}function zt(t,a){return function(o){var s,l,c=i(1900,void 0,1);if(Ot(c,t,o+=\"\",0)!=o.length)return null;if(\"Q\"in c)return new Date(c.Q);if(\"s\"in c)return new Date(1e3*c.s+(\"L\"in c?c.L:0));if(a&&!(\"Z\"in c)&&(c.Z=0),\"p\"in c&&(c.H=c.H%12+12*c.p),void 0===c.m&&(c.m=\"q\"in c?c.q:0),\"V\"in c){if(c.V<1||c.V>53)return null;\"w\"in c||(c.w=1),\"Z\"in c?(l=(s=n(i(c.y,0,1))).getUTCDay(),s=l>4||0===l?e.utcMonday.ceil(s):e.utcMonday(s),s=e.utcDay.offset(s,7*(c.V-1)),c.y=s.getUTCFullYear(),c.m=s.getUTCMonth(),c.d=s.getUTCDate()+(c.w+6)%7):(l=(s=r(i(c.y,0,1))).getDay(),s=l>4||0===l?e.timeMonday.ceil(s):e.timeMonday(s),s=e.timeDay.offset(s,7*(c.V-1)),c.y=s.getFullYear(),c.m=s.getMonth(),c.d=s.getDate()+(c.w+6)%7)}else(\"W\"in c||\"U\"in c)&&(\"w\"in c||(c.w=\"u\"in c?c.u%7:\"W\"in c?1:0),l=\"Z\"in c?n(i(c.y,0,1)).getUTCDay():r(i(c.y,0,1)).getDay(),c.m=0,c.d=\"W\"in c?(c.w+6)%7+7*c.W-(l+5)%7:c.w+7*c.U-(l+6)%7);return\"Z\"in c?(c.H+=c.Z/100|0,c.M+=c.Z%100,n(c)):r(c)}}function Ot(t,e,r,n){for(var i,a,o=0,l=e.length,c=r.length;o<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(o++))){if(i=e.charAt(o++),!(a=It[i in s?e.charAt(o++):i])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}return Ct.x=Pt(o,Ct),Ct.X=Pt(l,Ct),Ct.c=Pt(a,Ct),Lt.x=Pt(o,Lt),Lt.X=Pt(l,Lt),Lt.c=Pt(a,Lt),{format:function(t){var e=Pt(t+=\"\",Ct);return e.toString=function(){return t},e},parse:function(t){var e=zt(t+=\"\",!1);return e.toString=function(){return t},e},utcFormat:function(t){var e=Pt(t+=\"\",Lt);return e.toString=function(){return t},e},utcParse:function(t){var e=zt(t+=\"\",!0);return e.toString=function(){return t},e}}}var o,s={\"-\":\"\",_:\" \",0:\"0\"},l=/^\\s*\\d+/,c=/^%/,u=/[\\\\^$*+?|[\\]().{}]/g;function f(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function h(t){return t.replace(u,\"\\\\$&\")}function p(t){return new RegExp(\"^(?:\"+t.map(h).join(\"|\")+\")\",\"i\")}function d(t){for(var e={},r=-1,n=t.length;++r<n;)e[t[r].toLowerCase()]=r;return e}function g(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function m(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.u=+n[0],r+n[0].length):-1}function v(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.U=+n[0],r+n[0].length):-1}function y(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.V=+n[0],r+n[0].length):-1}function x(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.W=+n[0],r+n[0].length):-1}function b(t,e,r){var n=l.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function _(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.y=+n[0]+(+n[0]>68?1900:2e3),r+n[0].length):-1}function w(t,e,r){var n=/^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(e.slice(r,r+6));return n?(t.Z=n[1]?0:-(n[2]+(n[3]||\"00\")),r+n[0].length):-1}function T(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.q=3*n[0]-3,r+n[0].length):-1}function k(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function M(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function A(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.m=0,t.d=+n[0],r+n[0].length):-1}function S(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function E(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function C(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function L(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function I(t,e,r){var n=l.exec(e.slice(r,r+6));return n?(t.L=Math.floor(n[0]/1e3),r+n[0].length):-1}function P(t,e,r){var n=c.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function z(t,e,r){var n=l.exec(e.slice(r));return n?(t.Q=+n[0],r+n[0].length):-1}function O(t,e,r){var n=l.exec(e.slice(r));return n?(t.s=+n[0],r+n[0].length):-1}function D(t,e){return f(t.getDate(),e,2)}function R(t,e){return f(t.getHours(),e,2)}function F(t,e){return f(t.getHours()%12||12,e,2)}function B(t,r){return f(1+e.timeDay.count(e.timeYear(t),t),r,3)}function N(t,e){return f(t.getMilliseconds(),e,3)}function j(t,e){return N(t,e)+\"000\"}function U(t,e){return f(t.getMonth()+1,e,2)}function V(t,e){return f(t.getMinutes(),e,2)}function q(t,e){return f(t.getSeconds(),e,2)}function H(t){var e=t.getDay();return 0===e?7:e}function G(t,r){return f(e.timeSunday.count(e.timeYear(t)-1,t),r,2)}function Y(t,r){var n=t.getDay();return t=n>=4||0===n?e.timeThursday(t):e.timeThursday.ceil(t),f(e.timeThursday.count(e.timeYear(t),t)+(4===e.timeYear(t).getDay()),r,2)}function W(t){return t.getDay()}function X(t,r){return f(e.timeMonday.count(e.timeYear(t)-1,t),r,2)}function Z(t,e){return f(t.getFullYear()%100,e,2)}function J(t,e){return f(t.getFullYear()%1e4,e,4)}function K(t){var e=t.getTimezoneOffset();return(e>0?\"-\":(e*=-1,\"+\"))+f(e/60|0,\"0\",2)+f(e%60,\"0\",2)}function Q(t,e){return f(t.getUTCDate(),e,2)}function $(t,e){return f(t.getUTCHours(),e,2)}function tt(t,e){return f(t.getUTCHours()%12||12,e,2)}function et(t,r){return f(1+e.utcDay.count(e.utcYear(t),t),r,3)}function rt(t,e){return f(t.getUTCMilliseconds(),e,3)}function nt(t,e){return rt(t,e)+\"000\"}function it(t,e){return f(t.getUTCMonth()+1,e,2)}function at(t,e){return f(t.getUTCMinutes(),e,2)}function ot(t,e){return f(t.getUTCSeconds(),e,2)}function st(t){var e=t.getUTCDay();return 0===e?7:e}function lt(t,r){return f(e.utcSunday.count(e.utcYear(t)-1,t),r,2)}function ct(t,r){var n=t.getUTCDay();return t=n>=4||0===n?e.utcThursday(t):e.utcThursday.ceil(t),f(e.utcThursday.count(e.utcYear(t),t)+(4===e.utcYear(t).getUTCDay()),r,2)}function ut(t){return t.getUTCDay()}function ft(t,r){return f(e.utcMonday.count(e.utcYear(t)-1,t),r,2)}function ht(t,e){return f(t.getUTCFullYear()%100,e,2)}function pt(t,e){return f(t.getUTCFullYear()%1e4,e,4)}function dt(){return\"+0000\"}function gt(){return\"%\"}function mt(t){return+t}function vt(t){return Math.floor(+t/1e3)}function yt(e){return o=a(e),t.timeFormat=o.format,t.timeParse=o.parse,t.utcFormat=o.utcFormat,t.utcParse=o.utcParse,o}yt({dateTime:\"%x, %X\",date:\"%-m/%-d/%Y\",time:\"%-I:%M:%S %p\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});var xt=Date.prototype.toISOString?function(t){return t.toISOString()}:t.utcFormat(\"%Y-%m-%dT%H:%M:%S.%LZ\");var bt=+new Date(\"2000-01-01T00:00:00.000Z\")?function(t){var e=new Date(t);return isNaN(e)?null:e}:t.utcParse(\"%Y-%m-%dT%H:%M:%S.%LZ\");t.isoFormat=xt,t.isoParse=bt,t.timeFormatDefaultLocale=yt,t.timeFormatLocale=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-time\":167}],167:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=new Date,r=new Date;function n(t,i,a,o){function s(e){return t(e=0===arguments.length?new Date:new Date(+e)),e}return s.floor=function(e){return t(e=new Date(+e)),e},s.ceil=function(e){return t(e=new Date(e-1)),i(e,1),t(e),e},s.round=function(t){var e=s(t),r=s.ceil(t);return t-e<r-t?e:r},s.offset=function(t,e){return i(t=new Date(+t),null==e?1:Math.floor(e)),t},s.range=function(e,r,n){var a,o=[];if(e=s.ceil(e),n=null==n?1:Math.floor(n),!(e<r&&n>0))return o;do{o.push(a=new Date(+e)),i(e,n),t(e)}while(a<e&&e<r);return o},s.filter=function(e){return n((function(r){if(r>=r)for(;t(r),!e(r);)r.setTime(r-1)}),(function(t,r){if(t>=t)if(r<0)for(;++r<=0;)for(;i(t,-1),!e(t););else for(;--r>=0;)for(;i(t,1),!e(t););}))},a&&(s.count=function(n,i){return e.setTime(+n),r.setTime(+i),t(e),t(r),Math.floor(a(e,r))},s.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?s.filter(o?function(e){return o(e)%t==0}:function(e){return s.count(0,e)%t==0}):s:null}),s}var i=n((function(){}),(function(t,e){t.setTime(+t+e)}),(function(t,e){return e-t}));i.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?n((function(e){e.setTime(Math.floor(e/t)*t)}),(function(e,r){e.setTime(+e+r*t)}),(function(e,r){return(r-e)/t})):i:null};var a=i.range,o=n((function(t){t.setTime(t-t.getMilliseconds())}),(function(t,e){t.setTime(+t+1e3*e)}),(function(t,e){return(e-t)/1e3}),(function(t){return t.getUTCSeconds()})),s=o.range,l=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds())}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getMinutes()})),c=l.range,u=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds()-6e4*t.getMinutes())}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getHours()})),f=u.range,h=n((function(t){t.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/864e5}),(function(t){return t.getDate()-1})),p=h.range;function d(t){return n((function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+7*e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/6048e5}))}var g=d(0),m=d(1),v=d(2),y=d(3),x=d(4),b=d(5),_=d(6),w=g.range,T=m.range,k=v.range,M=y.range,A=x.range,S=b.range,E=_.range,C=n((function(t){t.setDate(1),t.setHours(0,0,0,0)}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())}),(function(t){return t.getMonth()})),L=C.range,I=n((function(t){t.setMonth(0,1),t.setHours(0,0,0,0)}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t,e){return e.getFullYear()-t.getFullYear()}),(function(t){return t.getFullYear()}));I.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)}),(function(e,r){e.setFullYear(e.getFullYear()+r*t)})):null};var P=I.range,z=n((function(t){t.setUTCSeconds(0,0)}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getUTCMinutes()})),O=z.range,D=n((function(t){t.setUTCMinutes(0,0,0)}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getUTCHours()})),R=D.range,F=n((function(t){t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+e)}),(function(t,e){return(e-t)/864e5}),(function(t){return t.getUTCDate()-1})),B=F.range;function N(t){return n((function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+7*e)}),(function(t,e){return(e-t)/6048e5}))}var j=N(0),U=N(1),V=N(2),q=N(3),H=N(4),G=N(5),Y=N(6),W=j.range,X=U.range,Z=V.range,J=q.range,K=H.range,Q=G.range,$=Y.range,tt=n((function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCMonth(t.getUTCMonth()+e)}),(function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())}),(function(t){return t.getUTCMonth()})),et=tt.range,rt=n((function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)}),(function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()}),(function(t){return t.getUTCFullYear()}));rt.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)}),(function(e,r){e.setUTCFullYear(e.getUTCFullYear()+r*t)})):null};var nt=rt.range;t.timeDay=h,t.timeDays=p,t.timeFriday=b,t.timeFridays=S,t.timeHour=u,t.timeHours=f,t.timeInterval=n,t.timeMillisecond=i,t.timeMilliseconds=a,t.timeMinute=l,t.timeMinutes=c,t.timeMonday=m,t.timeMondays=T,t.timeMonth=C,t.timeMonths=L,t.timeSaturday=_,t.timeSaturdays=E,t.timeSecond=o,t.timeSeconds=s,t.timeSunday=g,t.timeSundays=w,t.timeThursday=x,t.timeThursdays=A,t.timeTuesday=v,t.timeTuesdays=k,t.timeWednesday=y,t.timeWednesdays=M,t.timeWeek=g,t.timeWeeks=w,t.timeYear=I,t.timeYears=P,t.utcDay=F,t.utcDays=B,t.utcFriday=G,t.utcFridays=Q,t.utcHour=D,t.utcHours=R,t.utcMillisecond=i,t.utcMilliseconds=a,t.utcMinute=z,t.utcMinutes=O,t.utcMonday=U,t.utcMondays=X,t.utcMonth=tt,t.utcMonths=et,t.utcSaturday=Y,t.utcSaturdays=$,t.utcSecond=o,t.utcSeconds=s,t.utcSunday=j,t.utcSundays=W,t.utcThursday=H,t.utcThursdays=K,t.utcTuesday=V,t.utcTuesdays=Z,t.utcWednesday=q,t.utcWednesdays=J,t.utcWeek=j,t.utcWeeks=W,t.utcYear=rt,t.utcYears=nt,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],168:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=0,s=0,l=0,c=\"object\"==typeof performance&&performance.now?performance:Date,u=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return s||(u(h),s=c.now()+l)}function h(){s=0}function p(){this._call=this._time=this._next=null}function d(t,e,r){var n=new p;return n.restart(t,e,r),n}function g(){f(),++n;for(var t,r=e;r;)(t=s-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){s=(o=c.now())+l,n=i=0;try{g()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,y(a)}(),s=0}}function v(){var t=c.now(),e=t-o;e>1e3&&(l-=e,o=t)}function y(t){n||(i&&(i=clearTimeout(i)),t-s>24?(t<1/0&&(i=setTimeout(m,t-c.now()-l)),a&&(a=clearInterval(a))):(a||(o=c.now(),a=setInterval(v,1e3)),n=1,u(m)))}p.prototype=d.prototype={constructor:p,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,y()},stop:function(){this._call&&(this._call=null,this._time=1/0,y())}},t.interval=function(t,e,r){var n=new p,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart((function a(o){o+=i,n.restart(a,i+=e,r),t(o)}),e,r),n)},t.now=f,t.timeout=function(t,e,r){var n=new p;return e=null==e?0:+e,n.restart((function(r){n.stop(),t(r+e)}),e,r),n},t.timer=d,t.timerFlush=g,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],169:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,f=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){f.call(this,t,e+\"\",r)}}function h(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=h,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(h),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var m=g(h);function v(t){return t.length}t.bisectLeft=m.left,t.bisect=t.bisectRight=m.right,t.bisector=function(t){return g(1===t.length?function(e,r){return h(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,v),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t){for(var e=1;t*e%1;)e*=10;return e}function b(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function _(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=x(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new _;if(t instanceof _)t.forEach((function(t,e){r.set(t,e)}));else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};function w(t){return\"__proto__\"==(t+=\"\")||\"\\0\"===t[0]?\"\\0\"+t:t}function T(t){return\"\\0\"===(t+=\"\")[0]?t.slice(1):t}function k(t){return w(t)in this._}function M(t){return(t=w(t))in this._&&delete this._[t]}function A(){var t=[];for(var e in this._)t.push(T(e));return t}function S(){var t=0;for(var e in this._)++t;return t}function E(){for(var t in this._)return!1;return!0}function C(){this._=Object.create(null)}function L(t){return t}function I(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function P(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=z.length;r<n;++r){var i=z[r]+e;if(i in t)return i}}b(_,{has:k,get:function(t){return this._[w(t)]},set:function(t,e){return this._[w(t)]=e},remove:M,keys:A,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,f,h=-1,p=a.length,d=i[s++],g=new _;++h<p;)(f=g.get(l=d(c=a[h])))?f.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach((function(e,i){n.push({key:e,values:t(i,r)})})),o?n.sort((function(t,e){return o(t.key,e.key)})):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new C;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},b(C,{has:k,add:function(t){return this._[w(t+=\"\")]=!0,t},remove:M,values:A,size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=I(t,e,e[r]);return t};var z=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function O(){}function D(){}function R(t){var e=[],r=new _;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function F(){t.event.preventDefault()}function B(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function N(e){for(var r=new D,n=0,i=arguments.length;++n<i;)r[arguments[n]]=R(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new D,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=R(t);return t},D.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(j,\"\\\\$&\")};var j=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function V(t){return U(t,Y),t}var q=function(t,e){return e.querySelector(t)},H=function(t,e){return e.querySelectorAll(t)},G=function(t,e){var r=t.matches||t[P(t,\"matchesSelector\")];return(G=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(q=function(t,e){return Sizzle(t,e)[0]||null},H=Sizzle,G=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var Y=t.selection.prototype=[];function W(t){return\"function\"==typeof t?t:function(){return q(t,this)}}function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}Y.select=function(t){var e,r,n,i,a=[];t=W(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return V(a)},Y.selectAll=function(t){var e,r,i=[];t=X(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return V(i)};var Z=\"http://www.w3.org/1999/xhtml\",J={svg:\"http://www.w3.org/2000/svg\",xhtml:Z,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function K(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function $(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function tt(t){return(t+\"\").trim().split(/^|\\s+/)}function et(t,e){var r=(t=tt(t).map(rt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function rt(t){var e=$(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function nt(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function it(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function at(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===Z&&t.documentElement.namespaceURI===Z?t.createElement(e):t.createElementNS(r,e)}}function ot(){var t=this.parentNode;t&&t.removeChild(this)}function st(t){return{__data__:t}}function lt(t){return function(){return G(this,t)}}function ct(t){return arguments.length||(t=h),function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ft(t){return U(t,ht),t}t.ns={prefix:J,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),J.hasOwnProperty(r)?{space:J[r],local:t}:t}},Y.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(K(r,e[r]));return this}return this.each(K(e,r))},Y.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=tt(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!$(t[i]).test(e))return!1;return!0}for(e in t)this.each(et(e,t[e]));return this}return this.each(et(t,e))},Y.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(nt(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(nt(t,e,r))},Y.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(it(e,t[e]));return this}return this.each(it(t,e))},Y.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},Y.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},Y.append=function(t){return t=at(t),this.select((function(){return this.appendChild(t.apply(this,arguments))}))},Y.insert=function(t,e){return t=at(t),e=W(e),this.select((function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)}))},Y.remove=function(){return this.each(ot)},Y.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,f=Math.min(o,u),h=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,m=new _,v=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(m.has(g=e.call(i,i.__data__,n))?d[n]=i:m.set(g,i),v[n]=g);for(n=-1;++n<u;)(i=m.get(g=e.call(r,a=r[n],n)))?!0!==i&&(h[n]=i,i.__data__=a):p[n]=st(a),m.set(g,!0);for(n=-1;++n<o;)n in v&&!0!==m.get(v[n])&&(d[n]=t[n])}else{for(n=-1;++n<f;)i=t[n],a=r[n],i?(i.__data__=a,h[n]=i):p[n]=st(a);for(;n<u;++n)p[n]=st(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=h,p.parentNode=h.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(h),c.push(d)}var s=ft([]),l=V([]),c=V([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},Y.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},Y.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=lt(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return V(i)},Y.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},Y.sort=function(t){t=ct.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},Y.each=function(t){return ut(this,(function(e,r,n){t.call(e,e.__data__,r,n)}))},Y.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},Y.empty=function(){return!this.node()},Y.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},Y.size=function(){var t=0;return ut(this,(function(){++t})),t};var ht=[];function pt(t){var e,r;return function(n,i,a){var o,s=t[a].update,l=s.length;for(a!=r&&(r=a,e=0),i>=e&&(e=i+1);!(o=s[e])&&++e<l;);return o}}function dt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=mt;o>0&&(e=e.slice(0,o));var l=gt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?O:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ft,t.selection.enter.prototype=ht,ht.append=Y.append,ht.empty=Y.empty,ht.node=Y.node,ht.call=Y.call,ht.size=Y.size,ht.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return V(o)},ht.insert=function(t,e){return arguments.length<2&&(e=pt(this)),Y.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[q(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),V([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(H(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,V([e])},Y.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(dt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(dt(t,e,r))};var gt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function mt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=mt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&gt.forEach((function(t){\"on\"+t in i&&gt.remove(t)}));var yt,xt=0;function bt(e){var r=\".dragsuppress-\"+ ++xt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,F).on(\"dragstart\"+r,F).on(\"selectstart\"+r,F);if(null==yt&&(yt=!(\"onselectstart\"in e)&&P(e.style,\"userSelect\")),yt){var s=a(e).style,l=s[yt];s[yt]=\"none\"}return function(t){if(i.on(r,null),yt&&(s[yt]=l),t){var e=function(){i.on(n,null)};i.on(n,(function(){F(),e()}),!0),setTimeout(e,0)}}}t.mouse=function(t){return wt(t,B())};var _t=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function wt(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(_t<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();_t=!(s.f||s.e),n.remove()}}return _t?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function Tt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=B().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return wt(t,n)},t.behavior.drag=function(){var e=N(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(O,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(Tt,t.touch,L,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=this,u=t.event.target.correspondingElement||t.event.target,f=c.parentNode,h=e.of(c,arguments),p=0,d=n(),g=\".drag\"+(null==d?\"\":\"-\"+d),m=t.select(a(u)).on(o+g,x).on(s+g,b),v=bt(u),y=i(f,d);function x(){var t,e,r=i(f,d);r&&(t=r[0]-y[0],e=r[1]-y[1],p|=t|e,y=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e}))}function b(){i(f,d)&&(m.on(o+g,null).on(s+g,null),v(p),h({type:\"dragend\"}))}l=r?[(l=r.apply(c,arguments)).x-y[0],l.y-y[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=B().touches),e?n(e).map((function(e){var r=wt(t,e);return r.identifier=e.identifier,r})):[]};var kt=1e-6,Mt=1e-12,At=Math.PI,St=2*At,Et=St-kt,Ct=At/2,Lt=At/180,It=180/At;function Pt(t){return t>0?1:t<0?-1:0}function zt(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function Ot(t){return t>1?0:t<-1?At:Math.acos(t)}function Dt(t){return t>1?Ct:t<-1?-Ct:Math.asin(t)}function Rt(t){return((t=Math.exp(t))+1/t)/2}function Ft(t){return(t=Math.sin(t/2))*t}var Bt=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<Mt)n=Math.log(c/o)/Bt,r=function(t){return[i+t*u,a+t*f,o*Math.exp(Bt*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/Bt,r=function(t){var e,r=t*n,s=Rt(m),l=o/(2*p)*(s*(e=Bt*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/Rt(Bt*r+m)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,f,h={x:0,y:0,k:1},p=[960,500],d=Ut,g=250,m=0,v=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=N(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(v,I).on(jt+\".zoom\",z).on(\"dblclick.zoom\",O).on(b,P)}function T(t){return[(t[0]-h.x)/h.k,(t[1]-h.y)/h.k]}function k(t){h.k=Math.max(d[0],Math.min(d[1],t))}function M(t,e){e=function(t){return[t[0]*h.k+h.x,t[1]*h.k+h.y]}(e),h.x+=t[0]-e[0],h.y+=t[1]-e[1]}function A(e,n,i,a){e.__chart__={x:h.x,y:h.y,k:h.k},k(Math.pow(2,a)),M(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map((function(t){return(t-h.x)/h.k})).map(l.invert)),f&&f.domain(u.range().map((function(t){return(t-h.y)/h.k})).map(u.invert))}function E(t){m++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:h.k,translate:[h.x,h.y]})}function L(t){--m||(t({type:\"zoomend\"}),r=null)}function I(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,l).on(x,c),a=T(t.mouse(e)),s=bt(e);function l(){n=1,M(t.mouse(e),a),C(r)}function c(){i.on(y,null).on(x,null),s(n),L(r)}vs.call(e),E(r)}function P(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],f=t.select(r),p=bt(r);function d(){var n=t.touches(r);return e=h.k,n.forEach((function(t){t.identifier in i&&(i[t.identifier]=T(t))})),n}function g(){var e=t.event.target;t.select(e).on(l,m).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,f=n.length;o<f;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var v=p[0];A(r,v,i[v.identifier],Math.floor(Math.log(h.k)/Math.LN2)+1),F()}s=g}else if(p.length>1){v=p[0];var x=p[1],b=v[0]-x[0],_=v[1]-x[1];a=b*b+_*_}}function m(){var o,l,c,u,f=t.touches(r);vs.call(r);for(var h=0,p=f.length;h<p;++h,u=null)if(c=f[h],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],k(g*e)}s=null,M(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),f.on(v,I).on(b,P),p(),L(n)}g(),E(n),f.on(v,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(vs.call(this),e=T(r=n||t.mouse(this)),E(i)),a=setTimeout((function(){a=null,L(i)}),50),F(),k(Math.pow(2,.002*Nt())*h.k),M(r,e),C(i)}function O(){var e=t.mouse(this),r=Math.log(h.k)/Math.LN2;A(this,e,T(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return jt||(jt=\"onwheel\"in i?(Nt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Nt=function(){return t.event.wheelDelta},\"mousewheel\"):(Nt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each((function(){var e=_.of(this,arguments),n=h;bs?t.select(this).transition().each(\"start.zoom\",(function(){h=this.__chart__||{x:0,y:0,k:1},E(e)})).tween(\"zoom:zoom\",(function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-h.x)/h.k,(s-h.y)/h.k,i/h.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=h={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}})).each(\"interrupt.zoom\",(function(){L(e)})).each(\"end.zoom\",(function(){L(e)})):(this.__chart__=h,E(e),C(e),L(e))}))},w.translate=function(t){return arguments.length?(h={x:+t[0],y:+t[1],k:h.k},S(),w):[h.x,h.y]},w.scale=function(t){return arguments.length?(h={x:h.x,y:h.y,k:null},k(+t),S(),w):h.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?Ut:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),h={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(f=t,u=t.copy(),h={x:0,y:0,k:1},w):f},t.rebind(w,_,\"on\")};var Nt,jt,Ut=[0,1/0];function Vt(){}function qt(t,e,r){return this instanceof qt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof qt?new qt(t.h,t.s,t.l):le(\"\"+t,ce,qt):new qt(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=qt;var Ht=qt.prototype=new Vt;function Gt(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)||e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ne(a(t+120),a(t),a(t-120))}function Yt(e,r,n){return this instanceof Yt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Yt?new Yt(e.h,e.c,e.l):$t(e instanceof Zt?e.l:(e=ue((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Yt(e,r,n)}Ht.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,this.l/t)},Ht.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,t*this.l)},Ht.rgb=function(){return Gt(this.h,this.s,this.l)},t.hcl=Yt;var Wt=Yt.prototype=new Vt;function Xt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Zt(r,Math.cos(t*=Lt)*e,Math.sin(t)*e)}function Zt(t,e,r){return this instanceof Zt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Zt?new Zt(t.l,t.a,t.b):t instanceof Yt?Xt(t.h,t.c,t.l):ue((t=ne(t)).r,t.g,t.b):new Zt(t,e,r)}Wt.brighter=function(t){return new Yt(this.h,this.c,Math.min(100,this.l+Jt*(arguments.length?t:1)))},Wt.darker=function(t){return new Yt(this.h,this.c,Math.max(0,this.l-Jt*(arguments.length?t:1)))},Wt.rgb=function(){return Xt(this.h,this.c,this.l).rgb()},t.lab=Zt;var Jt=18,Kt=Zt.prototype=new Vt;function Qt(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ne(re(3.2404542*(i=.95047*te(i))-1.5371385*(n=1*te(n))-.4985314*(a=1.08883*te(a))),re(-.969266*i+1.8760108*n+.041556*a),re(.0556434*i-.2040259*n+1.0572252*a))}function $t(t,e,r){return t>0?new Yt(Math.atan2(r,e)*It,Math.sqrt(e*e+r*r),t):new Yt(NaN,NaN,t)}function te(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ee(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function re(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ne(t,e,r){return this instanceof ne?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ne?new ne(t.r,t.g,t.b):le(\"\"+t,ne,Gt):new ne(t,e,r)}function ie(t){return new ne(t>>16,t>>8&255,255&t)}function ae(t){return ie(t)+\"\"}Kt.brighter=function(t){return new Zt(Math.min(100,this.l+Jt*(arguments.length?t:1)),this.a,this.b)},Kt.darker=function(t){return new Zt(Math.max(0,this.l-Jt*(arguments.length?t:1)),this.a,this.b)},Kt.rgb=function(){return Qt(this.l,this.a,this.b)},t.rgb=ne;var oe=ne.prototype=new Vt;function se(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function le(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(he(i[0]),he(i[1]),he(i[2]))}return(a=pe.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function ce(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new qt(n,i,l)}function ue(t,e,r){var n=ee((.4124564*(t=fe(t))+.3575761*(e=fe(e))+.1804375*(r=fe(r)))/.95047),i=ee((.2126729*t+.7151522*e+.072175*r)/1);return Zt(116*i-16,500*(n-i),200*(i-ee((.0193339*t+.119192*e+.9503041*r)/1.08883)))}function fe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function he(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}oe.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ne(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ne(i,i,i)},oe.darker=function(t){return new ne((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},oe.hsl=function(){return ce(this.r,this.g,this.b)},oe.toString=function(){return\"#\"+se(this.r)+se(this.g)+se(this.b)};var pe=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function de(t){return\"function\"==typeof t?t:function(){return t}}function ge(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),me(e,r,t,n)}}function me(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function f(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return this.XDomainRequest&&!(\"withCredentials\"in c)&&/^(http(s)?:)?\\/\\//.test(e)&&(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=f:c.onreadystatechange=function(){c.readyState>3&&f()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach((function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}})),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",(function(t){i(null,t)})),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}pe.forEach((function(t,e){pe.set(t,ie(e))})),t.functor=de,t.xhr=ge(L),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=me(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,(function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map((function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"})).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i}))},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function f(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=f())!==o;){for(var h=[];r!==a&&r!==o;)h.push(r),r=f();e&&null==(h=e(h,u++))||s.push(h)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new C,n=[];return e.forEach((function(t){for(var e in t)r.has(e)||n.push(r.add(e))})),[n.map(l).join(t)].concat(e.map((function(e){return n.map((function(t){return l(e[t])})).join(t)}))).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var ve,ye,xe,be,_e=this[P(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function we(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i=r+e,a={c:t,t:i,n:null};return ye?ye.n=a:ve=a,ye=a,xe||(be=clearTimeout(be),xe=1,_e(Te)),a}function Te(){var t=ke(),e=Me()-t;e>24?(isFinite(e)&&(clearTimeout(be),be=setTimeout(Te,e)),xe=0):(xe=1,_e(Te))}function ke(){for(var t=Date.now(),e=ve;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Me(){for(var t,e=ve,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:ve=e.n;return ye=t,r}function Ae(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){we.apply(this,arguments)},t.timer.flush=function(){ke(),Me()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Se=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map((function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}}));function Ee(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:L;return function(e){var n=Ce.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],f=+n[6],h=n[7],p=n[8],d=n[9],g=1,m=\"\",v=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":h=!0,d=\"g\";break;case\"%\":g=100,v=\"%\",d=\"f\";break;case\"p\":g=100,v=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(m=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(m=a[0],v=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Le.get(d)||Ie;var b=u&&h;return function(e){var n=v;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+v}else e*=g;var _,w,T=(e=d(e,p)).lastIndexOf(\".\");if(T<0){var k=x?e.lastIndexOf(\"e\"):-1;k<0?(_=e,w=\"\"):(_=e.substring(0,k),w=e.substring(k))}else _=e.substring(0,T),w=r+e.substring(T+1);!u&&h&&(_=o(_,1/0));var M=m.length+_.length+w.length+(b?0:a.length),A=M<f?new Array(M=f-M+1).join(i):\"\";return b&&(_=o(A+_,A.length?f-w.length:1/0)),a+=m,e=_+w,(\"<\"===s?a+e+A:\">\"===s?A+a+e:\"^\"===s?A.substring(0,M>>=1)+a+e+A.substring(M):a+(b?e:A+e))+n}}}t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ae(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Se[8+n/3]};var Ce=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Le=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ae(e,r))).toFixed(Math.max(0,Math.min(20,Ae(e*(1+1e-15),r))))}});function Ie(t){return t+\"\"}var Pe=t.time={},ze=Date;function Oe(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}Oe.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){De.setUTCDate.apply(this._,arguments)},setDay:function(){De.setUTCDay.apply(this._,arguments)},setFullYear:function(){De.setUTCFullYear.apply(this._,arguments)},setHours:function(){De.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){De.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){De.setUTCMinutes.apply(this._,arguments)},setMonth:function(){De.setUTCMonth.apply(this._,arguments)},setSeconds:function(){De.setUTCSeconds.apply(this._,arguments)},setTime:function(){De.setTime.apply(this._,arguments)}};var De=Date.prototype;function Re(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new ze(r-1)),1),r}function a(t,r){return e(t=new ze(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Fe(t);return s.floor=s,s.round=Fe(n),s.ceil=Fe(i),s.offset=Fe(a),s.range=function(t,e,r){try{ze=Oe;var n=new Oe;return n._=t,o(n,e,r)}finally{ze=Date}},t}function Fe(t){return function(e,r){try{ze=Oe;var n=new Oe;return n._=e,t(n,r)._}finally{ze=Date}}}function Be(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(f(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&ze!==Oe,i=new(n?Oe:ze);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function f(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(ze=Oe);return r._=t,e(r)}finally{ze=Date}}return r.parse=function(t){try{ze=Oe;var r=e.parse(t);return r&&r._}finally{ze=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var h=t.map(),p=qe(o),d=He(o),g=qe(s),m=He(s),v=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach((function(t,e){h.set(t.toLowerCase(),e)}));var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+Pe.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(Pe.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(Pe.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=m.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){v.lastIndex=0;var n=v.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return f(t,_.c.toString(),e,r)},d:Qe,e:Qe,H:tr,I:tr,j:$e,L:nr,m:Ke,M:er,p:function(t,e,r){var n=h.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return f(t,_.x.toString(),e,r)},X:function(t,e,r){return f(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}Pe.year=Re((function(t){return(t=Pe.day(t)).setMonth(0,1),t}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t){return t.getFullYear()})),Pe.years=Pe.year.range,Pe.years.utc=Pe.year.utc.range,Pe.day=Re((function(t){var e=new ze(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t){return t.getDate()-1})),Pe.days=Pe.day.range,Pe.days.utc=Pe.day.utc.range,Pe.dayOfYear=function(t){var e=Pe.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach((function(t,e){e=7-e;var r=Pe[t]=Re((function(t){return(t=Pe.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t}),(function(t,e){t.setDate(t.getDate()+7*Math.floor(e))}),(function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)-(r!==e)}));Pe[t+\"s\"]=r.range,Pe[t+\"s\"].utc=r.utc.range,Pe[t+\"OfYear\"]=function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)}})),Pe.week=Pe.sunday,Pe.weeks=Pe.sunday.range,Pe.weeks.utc=Pe.sunday.utc.range,Pe.weekOfYear=Pe.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new _,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(t){return{numberFormat:Ee(t),timeFormat:Be(t)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function fr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&hr.hasOwnProperty(t.type)?hr[t.type](t,e):fr(t,e)};var hr={Feature:function(t,e){fr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)fr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)fr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return mr=0,t.geo.stream(e,Cr),mr};var mr,vr,yr,xr,br,_r,wr,Tr,kr,Mr,Ar,Sr,Er=new lr,Cr={sphere:function(){mr+=4*At},point:O,lineStart:O,lineEnd:O,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;mr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=O}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Lt/2+At/4;var a=(t*=Lt)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,f=n*l+u*Math.cos(s),h=u*o*Math.sin(s);Er.add(Math.atan2(h,f)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Lt,n=Math.cos(s=(e=s)*Lt/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Ir(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Pr(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Or(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),Dt(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,f,h={point:p,lineStart:g,lineEnd:m,polygonStart:function(){h.point=v,h.lineStart=x,h.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),h.point=p,h.lineStart=g,h.lineEnd=m,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),f[0]=e,f[1]=n}};function p(t,a){u.push(f=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Ir([t*Lt,o*Lt]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var f=t-a,h=f>0?1:-1,d=u[0]*It*h,g=y(f)>180;if(g^(h*a<d&&d<h*t))(m=u[1]*It)>i&&(i=m);else if(g^(h*a<(d=(d+360)%360-180)&&d<h*t)){var m;(m=-u[1]*It)<r&&(r=m)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){h.point=d}function m(){f[0]=e,f[1]=n,h.point=p,l=null}function v(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){v(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),f[0]=e,f[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function T(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,h),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)T((p=u[o])[0],g)||T(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=f=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){vr=yr=xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,Nr);var r=Mr,n=Ar,i=Sr,a=r*r+n*n+i*i;return a<Mt&&(r=wr,n=Tr,i=kr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Mt)?[NaN,NaN]:[Math.atan2(n,r)*It,Dt(i/Math.sqrt(a))*It]};var Nr={sphere:O,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Lt;var r=Math.cos(e*=Lt);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){++vr,xr+=(t-xr)/vr,br+=(e-br)/vr,_r+=(r-_r)/vr}function Vr(){var t,e,r;function n(n,i){n*=Lt;var a=Math.cos(i*=Lt),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),Tr+=c*(e+(e=s)),kr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Lt;var o=Math.cos(a*=Lt);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Lt;var a=Math.cos(e*=Lt),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,f=r*s-n*o,h=Math.sqrt(c*c+u*u+f*f),p=r*o+n*s+i*l,d=h&&-Ot(p)/h,g=Math.atan2(h,p);Mr+=d*c,Ar+=d*u,Sr+=d*f,yr+=g,wr+=g*(r+(r=o)),Tr+=g*(n+(n=s)),kr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Lt;var l=Math.cos(s*=Lt);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach((function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}})),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,f,h=a[0];;){for(var p=h,d=!0;p.v;)if((p=p.n)===h)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((f=u[s])[0],f[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((f=u[s])[0],f[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:f,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=f,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var f=c[0],h=f[0],p=f[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),m=1;;){m===u&&(m=0);var v=(t=c[m])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=v-h,w=_>=0?1:-1,T=w*_,k=T>At,M=d*x;if(Er.add(Math.atan2(M*w*Math.sin(T),g*b+M*Math.cos(T))),a+=k?_+w*St:_,k^h>=r^v>=r){var A=zr(Ir(f),Ir(t));Rr(A);var S=zr(i,A);Rr(S);var E=(k^_>=0?-1:1)*Dt(S[2]);(n>E||n===E&&(A[0]||A[1]))&&(o+=k^_>=0?1:-1)}if(!m++)break;h=v,d=x,g=b,f=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,$r,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function f(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function h(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=h,l.lineStart()}function d(){u.point=f,l.lineEnd()}var g,m,v=Qr(),y=r(v),x=!1;function b(t,e){m.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),m=[]}function w(){b(m[0][0],m[0][1]),y.lineEnd();var t,e=y.clean(),r=v.buffer(),n=r.length;if(m.pop(),g.push(m),m=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function Qr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:O,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function $r(t,e){return((t=t.x)[0]<0?t[1]-Ct-kt:Ct-t[1])-((e=e.x)[0]<0?e[1]-Ct-kt:Ct-e[1])}var tn=Jr(Yr,(function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Ct:-Ct),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}}),(function(t,e,r,n){var i;if(null==t)i=r*Ct,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])}),[-At,-At/2]);function en(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,(function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(f,h){var p,d=[f,h],g=i(f,h),m=r?g?0:o(f,h):g?o(f+(f<0?At:-At),h):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var v;m&s||!(v=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(v[0][0],v[0][1]),t.point(v[1][0],v[1][1]),t.lineEnd()):(t.point(v[1][0],v[1][1]),t.lineEnd(),t.lineStart(),t.point(v[0][0],v[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=m},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}}),Bn(t,6*Lt),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Ir(t),Ir(r)),o=Pr(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,f=zr(i,a),h=Dr(i,c);Or(h,Dr(a,u));var p=f,d=Pr(h,p),g=Pr(p,p),m=d*d-g*(Pr(h,h)-1);if(!(m<0)){var v=Math.sqrt(m),x=Dr(p,(-d-v)/g);if(Or(x,h),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],T=t[1],k=r[1];w<_&&(b=_,_=w,w=b);var M=w-_,A=y(M-At)<kt;if(!A&&k<T&&(b=T,T=k,k=b),A||M<kt?A?T+k>0^x[1]<(y(x[0]-_)<kt?T:k):T<=x[1]&&x[1]<=k:M>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+v)/g);return Or(S,h),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}function rn(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,f=1,h=s.x-l,p=s.y-c;if(a=t-l,h||!(a>0)){if(a/=h,h<0){if(a<u)return;a<f&&(f=a)}else if(h>0){if(a>f)return;a>u&&(u=a)}if(a=r-l,h||!(a<0)){if(a/=h,h<0){if(a>f)return;a>u&&(u=a)}else if(h>0){if(a<u)return;a<f&&(f=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<f&&(f=a)}else if(p>0){if(a>f)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>f)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<f&&(f=a)}return u>0&&(i.a={x:l+u*h,y:c+u*p}),f<1&&(i.b={x:l+f*h,y:c+f*p}),i}}}}}}function nn(e,r,n,i){return function(l){var c,u,f,h,p,d,g,m,v,y,x,b=l,_=Qr(),w=rn(e,r,n,i),T={point:A,lineStart:function(){T.point=S,u&&u.push(f=[]);y=!0,v=!1,g=m=NaN},lineEnd:function(){c&&(S(h,p),d&&v&&_.rejoin(),c.push(_.buffer()));T.point=A,v&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&zt(c,a,t)>0&&++e:a[1]<=n&&zt(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),k(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,k,l),l.polygonEnd()),c=u=f=null}};function k(t,o,l,c){var u=0,f=0;if(null==t||(u=a(t,l))!==(f=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==f);else c.point(o[0],o[1])}function M(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function A(t,e){M(t,e)&&l.point(t,e)}function S(t,e){var r=M(t=Math.max(-1e9,Math.min(1e9,t)),e=Math.max(-1e9,Math.min(1e9,e)));if(u&&f.push([t,e]),y)h=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&v)l.point(t,e);else{var n={a:{x:g,y:m},b:{x:t,y:e}};w(n)?(v||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,m=e,v=r}return T};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Ln(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,Dt((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],f=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,f-.238*e],[u+.455*e,f+.238*e]]).stream(l).point,n=o.translate([u-.307*e,f+.201*e]).clipExtent([[u-.425*e+kt,f+.12*e+kt],[u-.214*e-kt,f+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,f+.212*e]).clipExtent([[u-.214*e+kt,f+.166*e+kt],[u-.115*e-kt,f+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,fn,hn,pn={point:O,lineStart:O,lineEnd:O,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=O,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>fn&&(fn=t);e<un&&(un=e);e>hn&&(hn=e)},lineStart:O,lineEnd:O,polygonStart:O,polygonEnd:O};function mn(){var t=vn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=vn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function vn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=Tn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,Tr+=o*(e+n)/2,kr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function Tn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,Tr+=o*(n+e)/2,kr+=o,Mr+=(o=n*t-r*e)*(r+t),Ar+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function kn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:O};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,St)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function Mn(t){var e=.5,r=Math.cos(30*Lt),n=16;function i(t){return(n?o:a)(t)}function a(e){return En(e,(function(r,n){r=t(r,n),e.point(r[0],r[1])}))}function o(e){var r,i,a,o,l,c,u,f,h,p,d,g,m={point:v,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),m.lineStart=_},polygonEnd:function(){e.polygonEnd(),m.lineStart=y}};function v(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){f=NaN,m.point=x,e.lineStart()}function x(r,i){var a=Ir([r,i]),o=t(r,i);s(f,h,u,p,d,g,f=o[0],h=o[1],u=r,p=a[0],d=a[1],g=a[2],n,e),e.point(f,h)}function b(){m.point=v,e.lineEnd()}function _(){y(),m.point=w,m.lineEnd=T}function w(t,e){x(r=t,e),i=f,a=h,o=p,l=d,c=g,m.point=x}function T(){s(f,h,u,p,d,g,i,a,r,o,l,c,n,e),m.lineEnd=b,b()}return m}function s(n,i,a,o,l,c,u,f,h,p,d,g,m,v){var x=u-n,b=f-i,_=x*x+b*b;if(_>4*e&&m--){var w=o+p,T=l+d,k=c+g,M=Math.sqrt(w*w+T*T+k*k),A=Math.asin(k/=M),S=y(y(k)-1)<kt||y(a-h)<kt?(a+h)/2:Math.atan2(T,w),E=t(S,A),C=E[0],L=E[1],I=C-n,P=L-i,z=b*I-x*P;(z*z/_>e||y((x*I+b*P)/_-.5)>.3||o*p+l*d+c*g<r)&&(s(n,i,a,o,l,c,C,L,S,w/=M,T/=M,k,m,v),v.point(C,L),s(C,L,S,w,T,k,u,f,h,p,d,g,m,v))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function An(t){var e=Mn((function(e,r){return t([e*It,r*It])}));return function(t){return In(e(t))}}function Sn(t){this.stream=t}function En(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Cn(t){return Ln((function(){return t}))()}function Ln(e){var r,n,i,a,o,s,l=Mn((function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]})),c=150,u=480,f=250,h=0,p=0,d=0,g=0,m=0,v=tn,y=L,x=null,b=null;function _(t){return[(t=i(t[0]*Lt,t[1]*Lt))[0]*c+a,o-t[1]*c]}function w(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*It,t[1]*It]}function T(){i=Gr(n=On(d,g,m),r);var t=r(h,p);return a=u-t[0]*c,o=f+t[1]*c,k()}function k(){return s&&(s.valid=!1,s=null),_}return _.stream=function(t){return s&&(s.valid=!1),(s=In(v(n,l(y(t))))).valid=!0,s},_.clipAngle=function(t){return arguments.length?(v=null==t?(x=t,tn):en((x=+t)*Lt),k()):x},_.clipExtent=function(t){return arguments.length?(b=t,y=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):L,k()):b},_.scale=function(t){return arguments.length?(c=+t,T()):c},_.translate=function(t){return arguments.length?(u=+t[0],f=+t[1],T()):[u,f]},_.center=function(t){return arguments.length?(h=t[0]%360*Lt,p=t[1]%360*Lt,T()):[h*It,p*It]},_.rotate=function(t){return arguments.length?(d=t[0]%360*Lt,g=t[1]%360*Lt,m=t.length>2?t[2]%360*Lt:0,T()):[d*It,g*It,m*It]},t.rebind(_,l,\"precision\"),function(){return r=e.apply(this,arguments),_.invert=r.invert&&w,T()}}function In(t){return En(t,(function(e,r){t.point(e*Lt,r*Lt)}))}function Pn(t,e){return[t,e]}function zn(t,e){return[t>At?t-St:t<-At?t+St:t,e]}function On(t,e,r){return t?e||r?Gr(Rn(t),Fn(e,r)):Rn(t):e||r?Fn(e,r):zn}function Dn(t){return function(e,r){return[(e+=t)>At?e-St:e<-At?e+St:e,r]}}function Rn(t){var e=Dn(t);return e.invert=Dn(-t),e}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),Dt(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),Dt(u*r-s*n)]},o}function Bn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Nn(r,i),a=Nn(r,a),(o>0?i<a:i>a)&&(i+=o*St)):(i=t+o*St,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Nn(t,e){var r=Ir(e);r[0]-=t,Rr(r);var n=Ot(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[t,e]}))}}function Un(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[e,t]}))}}function Vn(t){return t.source}function qn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,n(xn)),Sr?[Mr/Sr,Ar/Sr]:kr?[wr/kr,Tr/kr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return fn=hn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[fn,hn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||An(t):L,l()):e},s.context=function(t){return arguments.length?(i=null==(r=t)?new mn:new kn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Sn(e);for(var n in t)r[n]=t[n];return r}}},Sn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Cn,t.geo.projectionMutator=Ln,(t.geo.equirectangular=function(){return Cn(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e}return t=On(t[0]%360*Lt,t[1]*Lt,t.length>2?t[2]*Lt:0),e.invert=function(e){return(e=t.invert(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e},e},zn.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=On(-t[0]*Lt,-t[1]*Lt,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=It,t[1]*=It}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Bn((t=+r)*Lt,n*Lt),i):t},i.precision=function(r){return arguments.length?(e=Bn(t*Lt,(n=+r)*Lt),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Lt,i=t[1]*Lt,a=e[1]*Lt,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),f=Math.cos(a);return Math.atan2(Math.sqrt((r=f*o)*r+(r=c*u-l*f*s)*r),l*u+c*f*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,f,h,p=10,d=p,g=90,m=360,v=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(f).concat(t.range(Math.ceil(l/m)*m,s,m).map(h)).concat(t.range(Math.ceil(r/p)*p,e,p).filter((function(t){return y(t%g)>kt})).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter((function(t){return y(t%m)>kt})).map(u))}return x.lines=function(){return b().map((function(t){return{type:\"LineString\",coordinates:t}}))},x.outline=function(){return{type:\"Polygon\",coordinates:[f(i).concat(h(s).slice(1),f(n).reverse().slice(1),h(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(v)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(v)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],m=+t[1],x):[g,m]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(v=+t,c=jn(o,a,90),u=Un(r,e,v),f=jn(l,s,90),h=Un(i,n,v),x):v},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,i=qn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Lt,n=t[1]*Lt,i=e[0]*Lt,a=e[1]*Lt,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),f=o*Math.sin(r),h=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Ft(a-n)+o*l*Ft(i-r))),g=1/Math.sin(d),(m=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*h,i=r*f+e*p,a=r*s+e*c;return[Math.atan2(i,n)*It,Math.atan2(a,Math.sqrt(n*n+i*i))*It]}:function(){return[r*It,n*It]}).distance=d,m;var r,n,i,a,o,s,l,c,u,f,h,p,d,g,m},t.geo.length=function(e){return yn=0,t.geo.stream(e,Hn),yn};var Hn={sphere:O,point:O,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Lt),o=Math.cos(i),s=y((n*=Lt)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}Hn.point=function(i,a){t=i*Lt,e=Math.sin(a*=Lt),r=Math.cos(a),Hn.point=n},Hn.lineEnd=function(){Hn.point=Hn.lineEnd=O}},lineEnd:O,polygonStart:O,polygonEnd:O};function Gn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Yn=Gn((function(t){return Math.sqrt(2/(1+t))}),(function(t){return 2*Math.asin(t/2)}));(t.geo.azimuthalEqualArea=function(){return Cn(Yn)}).raw=Yn;var Wn=Gn((function(t){var e=Math.acos(t);return e&&e/Math.sin(e)}),L);function Xn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Kn;function o(t,e){a>0?e<-Ct+kt&&(e=-Ct+kt):e>Ct-kt&&(e=Ct-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Ct]},o}function Zn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return Cn(Wn)}).raw=Wn,(t.geo.conicConformal=function(){return an(Xn)}).raw=Xn,(t.geo.conicEquidistant=function(){return an(Zn)}).raw=Zn;var Jn=Gn((function(t){return 1/t}),Math.atan);function Kn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Qn(t){var e,r=Cn(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Cn(Jn)}).raw=Jn,Kn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ct]},(t.geo.mercator=function(){return Qn(Kn)}).raw=Kn;var $n=Gn((function(){return 1}),Math.asin);(t.geo.orthographic=function(){return Cn($n)}).raw=$n;var ti=Gn((function(t){return 1/(1+t)}),(function(t){return 2*Math.atan(t)}));function ei(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ri(t){return t[0]}function ni(t){return t[1]}function ii(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&zt(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ai(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Cn(ti)}).raw=ti,ei.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ct]},(t.geo.transverseMercator=function(){var t=Qn(ei),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ei,t.geom={},t.geom.hull=function(t){var e=ri,r=ni;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=de(e),a=de(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ai),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ii(s),u=ii(l),f=u[0]===c[0],h=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+f;n<u.length-h;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,oi),t};var oi=t.geom.polygon.prototype=[];function si(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function li(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,f=n[1]-c,h=(s*(l-c)-f*(i-a))/(f*o-s*u);return[i+h*o,l+h*u]}function ci(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}oi.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},oi.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},oi.clip=function(t){for(var e,r,n,i,a,o,s=ci(t),l=-1,c=this.length-ci(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)si(o=e[r],u,i)?(si(a,u,i)||t.push(li(a,o,u,i)),t.push(o)):si(a,u,i)&&t.push(li(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ui,fi,hi,pi,di,gi=[],mi=[];function vi(){Ri(this),this.edge=this.site=this.circle=null}function yi(t){var e=gi.pop()||new vi;return e.site=t,e}function xi(t){Ei(t),hi.remove(t),gi.push(t),Ri(t)}function bi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];xi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),xi(l),l=a;s.unshift(l),Ei(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),xi(c),c=o;s.push(c),Ei(c);var u,f=s.length;for(u=1;u<f;++u)c=s[u],l=s[u-1],zi(c.edge,l.site,c.site,i);l=s[0],(c=s[f-1]).edge=Ii(l.site,c.site,null,i),Si(l),Si(c)}function _i(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=wi(s,o)-a)>kt)s=s.L;else{if(!((i=a-Ti(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=yi(t);if(hi.insert(e,l),e||r){if(e===r)return Ei(e),r=yi(e.site),hi.insert(l,r),l.edge=r.edge=Ii(e.site,l.site),Si(e),void Si(r);if(r){Ei(e),Ei(r);var c=e.site,u=c.x,f=c.y,h=t.x-u,p=t.y-f,d=r.site,g=d.x-u,m=d.y-f,v=2*(h*m-p*g),y=h*h+p*p,x=g*g+m*m,b={x:(m*y-p*x)/v+u,y:(h*x-g*y)/v+f};zi(r.edge,c,d,b),l.edge=Ii(c,t,null,b),r.edge=Ii(t,d,null,b),Si(e),Si(r)}else l.edge=Ii(e.site,l.site)}}function wi(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,f=1/a-1/c,h=u/c;return f?(-h+Math.sqrt(h*h-2*f*(u*u/(-2*c)-l+c/2+i-a/2)))/f+n:(n+s)/2}function Ti(t,e){var r=t.N;if(r)return wi(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Mi(t,e){return e.angle-t.angle}function Ai(){Ri(this),this.x=this.y=this.arc=this.site=this.cy=null}function Si(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,f=2*(l*(m=a.y-s)-c*u);if(!(f>=-Mt)){var h=l*l+c*c,p=u*u+m*m,d=(m*h-c*p)/f,g=(l*p-u*h)/f,m=g+s,v=mi.pop()||new Ai;v.arc=t,v.site=i,v.x=d+o,v.y=m+Math.sqrt(d*d+g*g),v.cy=m,t.circle=v;for(var y=null,x=di._;x;)if(v.y<x.y||v.y===x.y&&v.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}di.insert(y,v),y||(pi=v)}}}}function Ei(t){var e=t.circle;e&&(e.P||(pi=e.N),di.remove(e),mi.push(e),Ri(e),t.circle=null)}function Ci(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,f=t.r,h=u.x,p=u.y,d=f.x,g=f.y,m=(h+d)/2,v=(p+g)/2;if(g===p){if(m<o||m>=s)return;if(h>d){if(a){if(a.y>=c)return}else a={x:m,y:l};r={x:m,y:c}}else{if(a){if(a.y<l)return}else a={x:m,y:c};r={x:m,y:l}}}else if(i=v-(n=(h-d)/(g-p))*m,n<-1||n>1)if(h>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Li(t,e){this.l=t,this.r=e,this.a=this.b=null}function Ii(t,e,r,n){var i=new Li(t,e);return ui.push(i),r&&zi(i,t,e,r),n&&zi(i,e,t,n),fi[t.i].edges.push(new Oi(i,t,e)),fi[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r){var n=new Li(t,null);return n.a=e,n.b=r,ui.push(n),n}function zi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function Di(){this._=null}function Ri(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Fi(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Bi(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Ni(t){for(;t.L;)t=t.L;return t}function ji(t,e){var r,n,i,a=t.sort(Ui).pop();for(ui=[],fi=new Array(t.length),hi=new Di,di=new Di;;)if(i=pi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(fi[a.i]=new ki(a),_i(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;bi(i.arc)}e&&(function(t){for(var e,r=ui,n=rn(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ci(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,f=t[0][0],h=t[1][0],p=t[0][1],d=t[1][1],g=fi,m=g.length;m--;)if((a=g[m])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi(Pi(a.site,u,y(n-f)<kt&&d-i>kt?{x:f,y:y(e-f)<kt?r:d}:y(i-d)<kt&&h-n>kt?{x:y(r-d)<kt?e:h,y:d}:y(n-h)<kt&&i-p>kt?{x:h,y:y(e-h)<kt?r:p}:y(i-p)<kt&&n-f>kt?{x:y(r-p)<kt?e:f,y:p}:null),a.site,null)),++l)}(e));var o={cells:fi,edges:ui};return hi=di=ui=fi=null,o}function Ui(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Mi),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Di.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Ni(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Fi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Bi(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Bi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Fi(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Ni(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Fi(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Bi(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Fi(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Bi(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Fi(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Bi(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ri,r=ni,n=e,i=r,a=Vi;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return ji(s(t),a).cells.forEach((function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map((function(t){var e=t.start();return[e.x,e.y]})):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]})),e}function s(t){return t.map((function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}}))}return o.links=function(t){return ji(s(t)).edges.filter((function(t){return t.l&&t.r})).map((function(e){return{source:t[e.l.i],target:t[e.r.i]}}))},o.triangles=function(t){var e=[];return ji(s(t)).cells.forEach((function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Mi),u=-1,f=c.length,h=c[f-1].edge,p=h.l===l?h.r:h.l;++u<f;)h,i=p,p=(h=c[u].edge).l===l?h.r:h.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])})),e},o.x=function(t){return arguments.length?(n=de(e=t),o):e},o.y=function(t){return arguments.length?(i=de(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?Vi:t,o):a===Vi?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===Vi?null:a&&a[1]},o};var Vi=[[-1e6,-1e6],[1e6,1e6]];function qi(t){return t.x}function Hi(t){return t.y}function Gi(t,e,r,n,i,a){if(!t(e,r,n,i,a)){var o=.5*(r+i),s=.5*(n+a),l=e.nodes;l[0]&&Gi(t,l[0],r,n,o,s),l[1]&&Gi(t,l[1],o,n,i,s),l[2]&&Gi(t,l[2],r,s,o,a),l[3]&&Gi(t,l[3],o,s,i,a)}}function Yi(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,f,h,p){if(!(u>a||f>o||h<n||p<i)){if(d=c.point){var d,g=e-c.x,m=r-c.y,v=g*g+m*m;if(v<l){var y=Math.sqrt(l=v);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+h),_=.5*(f+p),w=(r>=_)<<1|e>=b,T=w+4;w<T;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,f,b,_);break;case 1:t(c,b,f,h,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,h,p)}}}(t,n,i,a,o),s}function Wi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+se(Math.round(n+o*t))+se(Math.round(i+s*t))+se(Math.round(a+l*t))}}function Xi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=$i(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Zi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Ji(t,e){var r,n,i,a=Ki.lastIndex=Qi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Ki.exec(t))&&(n=Qi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Zi(r,n)})),a=Qi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ri,s=ni;if(a=arguments.length)return o=qi,s=Hi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,f,h,p,d,g,m,v=de(o),x=de(s);if(null!=e)p=e,d=r,g=n,m=i;else if(g=m=-(p=d=1/0),c=[],u=[],h=t.length,a)for(f=0;f<h;++f)(l=t[f]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>m&&(m=l.y),c.push(l.x),u.push(l.y);else for(f=0;f<h;++f){var b=+v(l=t[f],f),_=+x(l,f);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>m&&(m=_),c.push(b),u.push(_)}var w=g-p,T=m-d;function k(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)M(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,M(t,u,l,c,i,a,o,s),M(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else M(t,e,r,n,i,a,o,s)}function M(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,f=n>=c,h=f<<1|u;t.leaf=!1,u?i=l:o=l,f?a=c:s=c,k(t=t.nodes[h]||(t.nodes[h]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,i,a,o,s)}w>T?m=d+w:g=p+T;var A={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){k(A,t,+v(t,++f),+x(t,f),p,d,g,m)},visit:function(t){Gi(t,A,p,d,g,m)},find:function(t){return Yi(A,t[0],t[1],p,d,g,m)}};if(f=-1,null==e){for(;++f<h;)k(A,t[f],c[f],u[f],p,d,g,m);--f}else t.forEach(A.add);return c=u=t=l=null,A}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=Wi,t.interpolateObject=Xi,t.interpolateNumber=Zi,t.interpolateString=Ji;var Ki=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Qi=new RegExp(Ki.source,\"g\");function $i(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function ta(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push($i(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=$i,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?pe.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?Wi:Ji:e instanceof Vt?Wi:Array.isArray(e)?ta:\"object\"===r&&isNaN(e)?Xi:Zi)(t,e)}],t.interpolateArray=ta;var ea=function(){return L},ra=t.map({linear:ea,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return sa},cubic:function(){return la},sin:function(){return ua},exp:function(){return fa},circle:function(){return ha},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/St*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*St/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return pa}}),na=t.map({in:L,out:aa,\"in-out\":oa,\"out-in\":function(t){return oa(aa(t))}});function ia(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function aa(t){return function(e){return 1-t(1-e)}}function oa(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function sa(t){return t*t}function la(t){return t*t*t}function ca(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function ua(t){return 1-Math.cos(t*Ct)}function fa(t){return Math.pow(2,10*(t-1))}function ha(t){return 1-Math.sqrt(1-t*t)}function pa(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function da(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ga(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=va(i),s=ma(i,a),l=va(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*It,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*It:0}function ma(t,e){return t[0]*e[0]+t[1]*e[1]}function va(t){var e=Math.sqrt(ma(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e=t.indexOf(\"-\"),n=e>=0?t.slice(0,e):t,i=e>=0?t.slice(e+1):\"in\";return n=ra.get(n)||ea,ia((i=na.get(i)||L)(n.apply(null,r.call(arguments,1))))},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Xt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Gt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return Qt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=da,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ga(e?e.matrix:ya)})(e)},ga.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var ya={a:1,b:0,c:0,d:1,e:0,f:0};function xa(t){return t.length?t.pop()+\",\":\"\"}function ba(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(xa(r)+\"rotate(\",null,\")\")-2,x:Zi(t,e)})):e&&r.push(xa(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(xa(r)+\"skewX(\",null,\")\")-2,x:Zi(t,e)}):e&&r.push(xa(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(xa(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(xa(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function _a(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function wa(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function Ta(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=ka(t),n=ka(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function ka(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function Ma(t){t.fixed|=2}function Aa(t){t.fixed&=-7}function Sa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Ea(t){t.fixed&=-5}t.interpolateTransform=ba,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(Ta(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,h,p,d,g={},m=[],v=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];m.push(u),y.push(t.range(i)),l+=u}for(a&&v.sort((function(t,e){return a(m[t],m[e])})),o&&y.forEach((function(t,e){t.sort((function(t,r){return o(n[e][t],n[e][r])}))})),l=(St-c*i)/l,u=0,p=-1;++p<i;){for(h=u,d=-1;++d<i;){var x=v[p],b=y[x][d],_=n[x][b],w=u,T=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:T,value:_}}r[x]={index:x,startAngle:h,endAngle:u,value:m[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var k=g[p+\"-\"+d],M=g[d+\"-\"+p];(k.value||M.value)&&e.push(k.value<M.value?{source:M,target:k}:{source:k,target:M})}s&&f()}function f(){e.sort((function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)}))}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&f(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,f=Ca,h=La,p=-30,d=Ia,g=.1,m=.64,v=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/m<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,f,h,d,m,b,_,w,T=v.length,k=y.length;for(s=0;s<k;++s)h=(f=y[s]).source,(m=(_=(d=f.target).x-h.x)*_+(w=d.y-h.y)*w)&&(_*=m=n*a[s]*((m=Math.sqrt(m))-i[s])/m,w*=m,d.x-=_*(b=h.weight+d.weight?h.weight/(h.weight+d.weight):.5),d.y-=w*b,h.x+=_*(b=1-b),h.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<T;)(f=v[s]).x+=(_-f.x)*b,f.y+=(w-f.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;if(e.charge=0,!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge,e.cy=a/e.charge}(r=t.geom.quadtree(v),n,o),s=-1;++s<T;)(f=v[s]).fixed||r.visit(x(f));for(s=-1;++s<T;)(f=v[s]).fixed?(f.x=f.px,f.y=f.py):(f.x-=(f.px-(f.px=f.x))*u,f.y-=(f.py-(f.py=f.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(v=t,s):v},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(m=t*t,s):Math.sqrt(m)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=we(s.tick)),s):n},s.start=function(){var t,e,r,n=v.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=v[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=v[r.source]),\"number\"==typeof r.target&&(r.target=v[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=v[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(a=[],\"function\"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,v[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(L).on(\"dragstart.force\",Ma).on(\"drag.force\",b).on(\"dragend.force\",Aa)),!arguments.length)return r;this.on(\"mouseover.force\",Sa).on(\"mouseout.force\",Ea).call(r)},t.rebind(s,l,\"on\")};var Ca=20,La=1,Ia=1/0;function Pa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=Ba,e}function za(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Oa(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function Da(t){return t.children}function Ra(t){return t.value}function Fa(t,e){return e.value-t.value}function Ba(e){return t.merge(e.map((function(t){return(t.children||[]).map((function(e){return{source:t,target:e}}))})))}t.layout.hierarchy=function(){var t=Fa,e=Da,r=Ra;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Oa(i,(function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)})),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(za(t,(function(t){t.children&&(t.value=0)})),Oa(t,(function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)}))),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Pa(n,e)},t.layout.pie=function(){var e=Number,r=Na,n=0,i=St,a=0;function o(s){var l,c=s.length,u=s.map((function(t,r){return+e.call(o,t,r)})),f=+(\"function\"==typeof n?n.apply(this,arguments):n),h=(\"function\"==typeof i?i.apply(this,arguments):i)-f,p=Math.min(Math.abs(h)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(h<0?-1:1),g=t.sum(u),m=g?(h-c*d)/g:0,v=t.range(c),y=[];return null!=r&&v.sort(r===Na?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),v.forEach((function(t){y[t]={data:s[t],value:l=u[t],startAngle:f,endAngle:f+=l*m+d,padAngle:p}})),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Na={};function ja(t){return t.x}function Ua(t){return t.y}function Va(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=L,r=Ga,n=Ya,i=Va,a=ja,o=Ua;function s(l,c){if(!(p=l.length))return l;var u=l.map((function(t,r){return e.call(s,t,r)})),f=u.map((function(t){return t.map((function(t,e){return[a.call(s,t,e),o.call(s,t,e)]}))})),h=r.call(s,f,c);u=t.permute(u,h),f=t.permute(f,h);var p,d,g,m,v=n.call(s,f,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],m=v[g],f[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],m+=f[d-1][g][1],f[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:qa.get(t)||Ga,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Ha.get(t)||Ya,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var qa=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Wa),o=e.map(Xa),s=t.range(i).sort((function(t,e){return a[t]-a[e]})),l=0,c=0,u=[],f=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],f.push(n));return f.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:Ga}),Ha=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,f=t[0],h=f.length,p=[];for(p[0]=l=c=0,r=1;r<h;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=f[r][0]-f[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<h;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ya});function Ga(e){return t.range(e.length)}function Ya(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Wa(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function Xa(t){return t.reduce(Za,0)}function Za(t,e){return t+e[1]}function Ja(t,e){return Ka(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ka(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Qa(e){return[t.min(e),t.max(e)]}function $a(t,e){return t.value-e.value}function to(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function eo(t,e){t._pack_next=e,e._pack_prev=t}function ro(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function no(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,f=1/0,h=-1/0;if(e.forEach(io),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(oo(r,n,i=e[2]),x(i),to(r,i),r._pack_prev=i,to(i,n),n=r._pack_next,a=3;a<l;a++){oo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(ro(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!ro(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?eo(r,n=o):eo(r=s,n),a--):(to(r,i),n=i,x(i))}var m=(c+u)/2,v=(f+h)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=m,i.y-=v,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(ao)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),f=Math.min(t.y-t.r,f),h=Math.max(t.y+t.r,h)}}function io(t){t._pack_next=t._pack_prev=t}function ao(t){delete t._pack_next,delete t._pack_prev}function oo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function so(t,e){return t.parent==e.parent?1:2}function lo(t){var e=t.children;return e.length?e[0]:t.t}function co(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function uo(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function fo(t,e,r){return t.a.parent===e.parent?t.a:r}function ho(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function po(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function go(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function mo(t){return t.rangeExtent?t.rangeExtent():go(t.range())}function vo(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function yo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function xo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:bo}t.layout.histogram=function(){var e=!0,r=Number,n=Qa,i=Ja;function a(a,o){for(var s,l,c=[],u=a.map(r,this),f=n.call(this,u,o),h=i.call(this,f,u,o),p=(o=-1,u.length),d=h.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=h[o+1]-(s.x=h[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=f[0]&&l<=f[1]&&((s=c[t.bisect(h,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=de(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ka(e,t)}:de(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort($a),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Oa(s,(function(t){t.r=+u(t.value)})),Oa(s,no),n){var f=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Oa(s,(function(t){t.r+=f})),Oa(s,no),Oa(s,(function(t){t.r-=f}))}return function t(e,r,n,i){var a=e.children;if(e.x=r+=i*e.x,e.y=n+=i*e.y,e.r*=i,a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Pa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],f=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Oa(f,o),f.parent.m=-f.z,za(f,s),i)za(u,l);else{var h=u,p=u,d=u;za(u,(function(t){t.x<h.x&&(h=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)}));var g=r(h,p)/2-h.x,m=n[0]/(p.x+r(p,h)/2+g),v=n[1]/(d.depth||1);za(u,(function(t){t.x=(t.x+g)*m,t.y=t.depth*v}))}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=co(s),a=lo(a),s&&a;)l=lo(l),(o=co(o)).a=t,(i=s.z+f-a.z-c+r(s._,a._))>0&&(uo(fo(s,t,n),t,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!co(o)&&(o.t=s,o.m+=f-u),a&&!lo(l)&&(l.t=a,l.m+=c-h,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Pa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Oa(c,(function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce((function(t,e){return t+e.x}),0)/t.length}(n),e.y=function(e){return 1+t.max(e,(function(t){return t.y}))}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)}));var f=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),h=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=f.x-r(f,h)/2,d=h.x+r(h,f)/2;return Oa(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Pa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=ho,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function f(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),h=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=h?(c.pop(),h=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,h=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(f)}}function h(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(h)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?h:f)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){var r=t.call(g,e,e.depth);return null==r?ho(e):po(e,\"number\"==typeof r?[r,r,r,r]:r)}function r(e){return po(e,t)}var n;return o=null==(a=t)?ho:\"function\"==(n=typeof t)?e:\"number\"===n?(t=[t,t,t,t],r):r,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Pa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var bo={floor:L,ceil:L};function _o(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function wo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function To(t,e){return yo(t,xo(ko(t,e)[2])),yo(t,xo(ko(t,e)[2])),t}function ko(t,e){null==e&&(e=10);var r=go(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function Mo(e,r){return t.range.apply(t,ko(e,r))}function Ao(e,r,n){var i=ko(e,r);if(n){var a=Ce.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+Eo(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=Eo(e[2]);return t in So?Math.abs(r-Eo(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+Eo(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?_o:vo,s=i?wa:_a;return a=t(e,r,s,n),o=t(r,e,s,$i),l}function l(t){return a(t)}return l.invert=function(t){return o(t)},l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e},l.range=function(t){return arguments.length?(r=t,s()):r},l.rangeRound=function(t){return l.range(t).interpolate(da)},l.clamp=function(t){return arguments.length?(i=t,s()):i},l.interpolate=function(t){return arguments.length?(n=t,s()):n},l.ticks=function(t){return Mo(e,t)},l.tickFormat=function(t,r){return Ao(e,t,r)},l.nice=function(t){return To(e,t),s()},l.copy=function(){return t(e,r,n,i)},s()}([0,1],[0,1],$i,!1)};var So={s:1,g:1,p:1,r:1,e:1};function Eo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}return l.invert=function(t){return s(r.invert(t))},l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a},l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n},l.nice=function(){var t=yo(a.map(o),i?Math:Lo);return r.domain(t),a=t.map(s),l},l.ticks=function(){var t=go(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),f=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var h=1;h<f;h++)e.push(s(c)*h);e.push(s(c))}else for(e.push(s(c));c++<u;)for(h=f-1;h>0;h--)e.push(s(c)*h);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e},l.tickFormat=function(e,r){if(!arguments.length)return Co;arguments.length<2?r=Co:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}},l.copy=function(){return e(r.copy(),n,i,a)},wo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Co=t.format(\".0e\"),Lo={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Io(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Io(r),a=Io(1/r);function o(t){return e(i(t))}return o.invert=function(t){return a(e.invert(t))},o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n},o.ticks=function(t){return Mo(n,t)},o.tickFormat=function(t,e){return Ao(n,t,e)},o.nice=function(t){return o.domain(To(n,t))},o.exponent=function(t){return arguments.length?(i=Io(r=t),a=Io(1/r),e.domain(n.map(i)),o):r},o.copy=function(){return t(e.copy(),r,n)},wo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map((function(t){return e+n*t}))}return s.domain=function(t){if(!arguments.length)return r;r=[],i=new _;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)},s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a},s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s},s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s},s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=(f-u)/(r.length-e+2*i);return a=l(u+h*i,h),c&&a.reverse(),o=h*(1-e),n={t:\"rangeBands\",a:arguments},s},s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=Math.floor((f-u)/(r.length-e+2*i));return a=l(u+Math.round((f-u-(r.length-e)*h)/2),h),c&&a.reverse(),o=Math.round(h*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s},s.rangeBand=function(){return o},s.rangeExtent=function(){return go(n.a[0])},s.copy=function(){return e(r,n)},s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(Po)},t.scale.category20=function(){return t.scale.ordinal().range(zo)},t.scale.category20b=function(){return t.scale.ordinal().range(Oo)},t.scale.category20c=function(){return t.scale.ordinal().range(Do)};var Po=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(ae),zo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(ae),Oo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(ae),Do=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(ae);function Ro(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}return o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(h),a()):r},o.range=function(t){return arguments.length?(n=t,a()):n},o.quantiles=function(){return i},o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]},o.copy=function(){return e(r,n)},a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}return o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]},o.range=function(t){return arguments.length?(n=t,s()):n},o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]},o.copy=function(){return t(e,r,n)},s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}return i.domain=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=t,i):n},i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]},i.copy=function(){return e(r,n)},i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}return r.invert=r,r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e},r.ticks=function(t){return Mo(e,t)},r.tickFormat=function(t,r){return Ao(e,t,r)},r.copy=function(){return t(e)},r}([0,1])},t.svg={},t.svg.arc=function(){var t=Bo,e=No,r=Ro,n=Fo,i=jo,a=Uo,o=Vo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Ct,f=a.apply(this,arguments)-Ct,h=Math.abs(f-u),p=u>f?0:1;if(c<s&&(d=c,c=s,s=d),h>=Et)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,m,v,y,x,b,_,w,T,k,M,A=0,S=0,E=[];if((v=(+o.apply(this,arguments)||0)/2)&&(m=n===Fo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Dt(m/c*Math.sin(v))),s&&(A=Dt(m/s*Math.sin(v)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(f-S),_=c*Math.sin(f-S);var C=Math.abs(f-u-2*S)<=At?0:1;if(S&&qo(y,x,b,_)===p^C){var L=(u+f)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(f-A),T=s*Math.sin(f-A),k=s*Math.cos(u+A),M=s*Math.sin(u+A);var I=Math.abs(u-f+2*A)<=At?0:1;if(A&&qo(w,T,k,M)===1-p^I){var P=(u+f)/2;w=s*Math.cos(P),T=s*Math.sin(P),k=M=null}}else w=T=0;if(h>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,O=d;if(h<At){var D=null==k?[w,T]:null==b?[y,x]:li([y,x],[k,M],[b,_],[w,T]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);O=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=Ho(null==k?[w,T]:[k,M],[y,x],c,z,p),q=Ho([b,_],[w,T],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^qo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=k){var H=Ho([y,x],[k,M],s,-O,p),G=Ho([w,T],null==b?[y,x]:[b,_],s,-O,p);d===O?E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^qo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",T)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",T),null!=k&&E.push(\"A\",s,\",\",s,\" 0 \",I,\",\",1-p,\" \",k,\",\",M);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=de(e),s):t},s.outerRadius=function(t){return arguments.length?(e=de(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=de(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Fo?Fo:de(t),s):n},s.startAngle=function(t){return arguments.length?(i=de(t),s):i},s.endAngle=function(t){return arguments.length?(a=de(t),s):a},s.padAngle=function(t){return arguments.length?(o=de(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Ct;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Fo=\"auto\";function Bo(t){return t.innerRadius}function No(t){return t.outerRadius}function jo(t){return t.startAngle}function Uo(t){return t.endAngle}function Vo(t){return t&&t.padAngle}function qo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function Ho(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,f=t[1]+c,h=e[0]+l,p=e[1]+c,d=(u+h)/2,g=(f+p)/2,m=h-u,v=p-f,y=m*m+v*v,x=r-n,b=u*p-h*f,_=(v<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*v-m*_)/y,T=(-b*m-v*_)/y,k=(b*v+m*_)/y,M=(-b*m+v*_)/y,A=w-d,S=T-g,E=k-d,C=M-g;return A*A+S*S>E*E+C*C&&(w=k,T=M),[[w-l,T-c],[w*r/x,T*r/x]]}function Go(t){var e=ri,r=ni,n=Yr,i=Wo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,f=a.length,h=de(e),p=de(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<f;)n.call(this,s=a[u],u)?c.push([+h.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Yo.get(t)||Wo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return Go(L)};var Yo=t.map({linear:Wo,\"linear-closed\":Xo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Zo,\"step-after\":Jo,basis:$o,\"basis-open\":function(t){if(t.length<4)return Wo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(ts(ns,a)+\",\"+ts(ns,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),is(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[ts(ns,o),\",\",ts(ns,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),is(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return $o(t)},cardinal:function(t,e){return t.length<3?Wo(t):t[0]+Ko(t,Qo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Wo(t):t[1]+Ko(t.slice(1,-1),Qo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?Xo(t):t[0]+Ko((t.push(t[0]),t),Qo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Wo(t):t[0]+Ko(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=as(i,a);for(;++e<r;)n[e]=(o+(o=as(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=as(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Wo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function Xo(t){return t.join(\"L\")+\"Z\"}function Zo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Jo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Ko(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Wo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Qo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function $o(t){if(t.length<3)return Wo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",ts(ns,o),\",\",ts(ns,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),is(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function ts(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Yo.forEach((function(t,e){e.key=t,e.closed=/-closed$/.test(t)}));var es=[0,2/3,1/3,0],rs=[0,1/3,2/3,0],ns=[0,1/6,2/3,1/6];function is(t,e,r){t.push(\"C\",ts(es,e),\",\",ts(es,r),\",\",ts(rs,e),\",\",ts(rs,r),\",\",ts(ns,e),\",\",ts(ns,r))}function as(t,e){return(e[1]-t[1])/(e[0]-t[0])}function os(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Ct,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function ss(t){var e=ri,r=ri,n=0,i=ni,a=Yr,o=Wo,s=o.key,l=o,c=\"L\",u=.7;function f(s){var f,h,p,d=[],g=[],m=[],v=-1,y=s.length,x=de(e),b=de(n),_=e===r?function(){return h}:de(r),w=n===i?function(){return p}:de(i);function T(){d.push(\"M\",o(t(m),u),c,l(t(g.reverse()),u),\"Z\")}for(;++v<y;)a.call(this,f=s[v],v)?(g.push([h=+x.call(this,f,v),p=+b.call(this,f,v)]),m.push([+_.call(this,f,v),+w.call(this,f,v)])):g.length&&(T(),g=[],m=[]);return g.length&&T(),d.length?d.join(\"\"):null}return f.x=function(t){return arguments.length?(e=r=t,f):r},f.x0=function(t){return arguments.length?(e=t,f):e},f.x1=function(t){return arguments.length?(r=t,f):r},f.y=function(t){return arguments.length?(n=i=t,f):i},f.y0=function(t){return arguments.length?(n=t,f):n},f.y1=function(t){return arguments.length?(i=t,f):i},f.defined=function(t){return arguments.length?(a=t,f):a},f.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Yo.get(t)||Wo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",f):s},f.tension=function(t){return arguments.length?(u=t,f):u},f}function ls(t){return t.radius}function cs(t){return[t.x,t.y]}function us(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Ct;return[r*Math.cos(n),r*Math.sin(n)]}}function fs(){return 64}function hs(){return\"circle\"}function ps(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=Go(os);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Zo.reverse=Jo,Jo.reverse=Zo,t.svg.area=function(){return ss(L)},t.svg.area.radial=function(){var t=ss(os);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=qn,r=ls,n=jo,i=Uo;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,((i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\")}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Ct,u=i.call(t,s,o)-Ct;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=de(t),a):r},a.source=function(e){return arguments.length?(t=de(e),a):t},a.target=function(t){return arguments.length?(e=de(t),a):e},a.startAngle=function(t){return arguments.length?(n=de(t),a):n},a.endAngle=function(t){return arguments.length?(i=de(t),a):i},a},t.svg.diagonal=function(){var t=Vn,e=qn,r=cs;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=de(e),n):t},n.target=function(t){return arguments.length?(e=de(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=cs,n=e.projection;return e.projection=function(t){return arguments.length?n(us(r=t)):r},e},t.svg.symbol=function(){var t=hs,e=fs;function r(r,n){return(ds.get(t.call(this,r,n))||ps)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=de(e),r):t},r.size=function(t){return arguments.length?(e=de(t),r):e},r};var ds=t.map({circle:ps,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*ms)),r=e*ms;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ds.keys();var gs=Math.sqrt(3),ms=Math.tan(30*Lt);Y.transition=function(t){for(var e,r,n=bs||++Ts,i=As(t),a=[],o=_s||{time:Date.now(),ease:ca,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(r=c[u])&&Ss(r,u,i,n,o),e.push(r)}return xs(a,i,n)},Y.interrupt=function(t){return this.each(null==t?vs:ys(As(t)))};var vs=ys(As());function ys(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function xs(t,e,r){return U(t,ws),t.namespace=e,t.id=r,t}var bs,_s,ws=[],Ts=0;function ks(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function Ms(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function As(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function Ss(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),f=u[n];function h(r){var i=u.active,h=u[i];for(var d in h&&(h.timer.c=null,h.timer.t=NaN,--u.count,delete u[i],h.event&&h.event.interrupt.call(t,t.__data__,h.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,we((function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1}),0,a),u.active=n,f.event&&f.event.start.call(t,t.__data__,e),c=[],f.tween.forEach((function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)})),l=f.ease,s=f.duration}function p(i){for(var a=i/s,o=l(a),h=c.length;h>0;)c[--h].call(t,o);if(a>=1)return f.event&&f.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}f||(a=i.time,o=we((function(t){var e=f.delay;if(o.t=e+a,e<=t)return h(t-e);o.c=h}),0,a),f=u[n]={tween:new _,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}ws.call=Y.call,ws.empty=Y.empty,ws.node=Y.node,ws.size=Y.size,t.transition=function(e,r){return e&&e.transition?bs?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=ws,ws.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=W(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),Ss(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return xs(o,a,i)},ws.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=X(t);for(var c=-1,u=this.length;++c<u;)for(var f=this[c],h=-1,p=f.length;++h<p;)if(n=f[h]){a=n[s][o],r=t.call(n,n.__data__,h,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&Ss(i,d,s,o,a),e.push(i)}return xs(l,s,o)},ws.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=lt(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return xs(n,this.namespace,this.id)},ws.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},ws.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ba:$i,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}function s(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})}function l(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}return ks(this,\"attr.\"+e,r,i.local?l:s)},ws.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},ws.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}function a(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=$i(i,e),function(e){this.style.setProperty(t,n(e),r)})})}return ks(this,\"style.\"+t,e,a)},ws.styleTween=function(t,e,r){function n(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}}return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,n)},ws.text=function(t){return ks(this,\"text\",t,Ms)},ws.remove=function(){var t=this.namespace;return this.each(\"end.transition\",(function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)}))},ws.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,(function(t){t[n][r].ease=e})))},ws.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},ws.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ws.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=_s,o=bs;try{bs=n,ut(this,(function(t,r,a){_s=t[i][n],e.call(t,t.__data__,r,a)}))}finally{_s=a,bs=o}}else ut(this,(function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)}));return this},ws.transition=function(){for(var t,e,r,n=this.id,i=++Ts,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,f=(c=this[s]).length;u<f;u++)(e=c[u])&&Ss(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return xs(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=Es,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each((function(){var n,u=t.select(this),f=this.__chart__||r,h=this.__chart__=r.copy(),p=null==c?h.ticks?h.ticks.apply(h,l):h.domain():c,d=null==e?h.tickFormat?h.tickFormat.apply(h,l):L:e,g=u.selectAll(\".tick\").data(p,h),m=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),v=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=mo(h),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));m.append(\"line\"),m.append(\"text\");var T,k,M,A,S=m.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),I=m.select(\"text\"),P=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ls,T=\"x\",M=\"y\",k=\"x2\",A=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=Is,T=\"y\",M=\"x\",k=\"y2\",A=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(A,z*a),I.attr(M,z*x),E.attr(k,0).attr(A,z*a),P.attr(T,0).attr(M,z*x),h.rangeBand){var O=h,D=O.rangeBand()/2;f=h=function(t){return O(t)+D}}else f.rangeBand?f=h:v.call(n,h,f);m.call(n,f,h),y.call(n,h,h)}))}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in Cs?t+\"\":Es,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var Es=\"bottom\",Cs={top:1,right:1,bottom:1,left:1};function Ls(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"}))}function Is(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"}))}t.svg.brush=function(){var e,r,n=N(h,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,f=zs[0];function h(e){e.each((function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",m).on(\"touchstart.brush\",m),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(f,L);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",(function(t){return\"resize \"+t})).style(\"cursor\",(function(t){return Ps[t]})).append(\"rect\").attr(\"x\",(function(t){return/[ew]$/.test(t)?-3:null})).attr(\"y\",(function(t){return/^[ns]/.test(t)?-3:null})).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",h.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=mo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=mo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)}))}function p(t){t.selectAll(\".resize\").attr(\"transform\",(function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"}))}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function m(){var f,m,v=this,y=t.select(t.event.target),x=n.of(v,arguments),b=t.select(v),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,T=!/^(e|w)$/.test(_)&&a,k=y.classed(\"extent\"),M=bt(v),A=t.mouse(v),S=t.select(o(v)).on(\"keydown.brush\",L).on(\"keyup.brush\",I);if(t.event.changedTouches?S.on(\"touchmove.brush\",P).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",P).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),k)A[0]=s[0]-A[0],A[1]=l[0]-A[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);m=[s[1-E]-A[0],l[1-C]-A[1]],A[0]=s[E],A[1]=l[C]}else t.event.altKey&&(f=A.slice());function L(){32==t.event.keyCode&&(k||(f=null,A[0]-=s[1],A[1]-=l[1],k=2),F())}function I(){32==t.event.keyCode&&2==k&&(A[0]+=s[1],A[1]+=l[1],k=0,F())}function P(){var e=t.mouse(v),r=!1;m&&(e[0]+=m[0],e[1]+=m[1]),k||(t.event.altKey?(f||(f=[(s[0]+s[1])/2,(l[0]+l[1])/2]),A[0]=s[+(e[0]<f[0])],A[1]=l[+(e[1]<f[1])]):f=null),w&&z(e,i,0)&&(d(b),r=!0),T&&z(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:k?\"move\":\"resize\"}))}function z(t,n,i){var a,o,h=mo(n),p=h[0],d=h[1],g=A[i],m=i?l:s,v=m[1]-m[0];if(k&&(p-=g,d-=v+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],k?o=(a+=g)+v:(f&&(g=Math.max(p,Math.min(d,2*f[i]-a))),g<a?(o=a,a=g):o=g),m[0]!=a||m[1]!=o)return i?r=null:e=null,m[0]=a,m[1]=o,!0}function O(){P(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",h.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),M(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),P()}return h.event=function(i){i.each((function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,bs?t.select(this).transition().each(\"start.brush\",(function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})})).tween(\"brush:brush\",(function(){var t=ta(s,a.x),n=ta(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}})).each(\"end.brush\",(function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})})):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))}))},h.x=function(t){return arguments.length?(f=zs[!(i=t)<<1|!a],h):i},h.y=function(t){return arguments.length?(f=zs[!i<<1|!(a=t)],h):a},h.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),h):i&&a?[c,u]:i?c:a?u:null},h.extent=function(t){var n,o,c,u,f;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(f=n,n=o,o=f),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(f=c,c=u,u=f),c==l[0]&&u==l[1]||(l=[c,u])),h):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(f=n,n=o,o=f))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(f=c,c=u,u=f))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},h.clear=function(){return h.empty()||(s=[0,0],l=[0,0],e=r=null),h},h.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(h,n,\"on\")};var Ps={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},zs=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Os=Pe.format=sr.timeFormat,Ds=Os.utc,Rs=Ds(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Fs(t){return t.toISOString()}function Bs(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(js,i);return a==js.length?[r.year,ko(e.map((function(t){return t/31536e6})),n)[2]]:a?r[i/js[a-1]<js[a]/i?a-1:a]:[qs,ko(e,n)[2]]}return i.invert=function(t){return Ns(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(Ns)},i.nice=function(t,e){var r=i.domain(),n=go(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,Ns(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(yo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Ns(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Ns(+e+1);return e}}:t))},i.ticks=function(t,e){var r=go(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Ns(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Bs(e.copy(),r,n)},wo(i,e)}function Ns(t){return new Date(t)}Os.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Fs:Rs,Fs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Fs.toString=Rs.toString,Pe.second=Re((function(t){return new ze(1e3*Math.floor(t/1e3))}),(function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))}),(function(t){return t.getSeconds()})),Pe.seconds=Pe.second.range,Pe.seconds.utc=Pe.second.utc.range,Pe.minute=Re((function(t){return new ze(6e4*Math.floor(t/6e4))}),(function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))}),(function(t){return t.getMinutes()})),Pe.minutes=Pe.minute.range,Pe.minutes.utc=Pe.minute.utc.range,Pe.hour=Re((function(t){var e=t.getTimezoneOffset()/60;return new ze(36e5*(Math.floor(t/36e5-e)+e))}),(function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))}),(function(t){return t.getHours()})),Pe.hours=Pe.hour.range,Pe.hours.utc=Pe.hour.utc.range,Pe.month=Re((function(t){return(t=Pe.day(t)).setDate(1),t}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t){return t.getMonth()})),Pe.months=Pe.month.range,Pe.months.utc=Pe.month.utc.range;var js=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Us=[[Pe.second,1],[Pe.second,5],[Pe.second,15],[Pe.second,30],[Pe.minute,1],[Pe.minute,5],[Pe.minute,15],[Pe.minute,30],[Pe.hour,1],[Pe.hour,3],[Pe.hour,6],[Pe.hour,12],[Pe.day,1],[Pe.day,2],[Pe.week,1],[Pe.month,1],[Pe.month,3],[Pe.year,1]],Vs=Os.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),qs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Ns)},floor:L,ceil:L};Us.year=Pe.year,Pe.scale=function(){return Bs(t.scale.linear(),Us,Vs)};var Hs=Us.map((function(t){return[t[0].utc,t[1]]})),Gs=Ds.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function Ys(t){return JSON.parse(t.responseText)}function Ws(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Hs.year=Pe.year.utc,Pe.scale.utc=function(){return Bs(t.scale.linear(),Hs,Gs)},t.text=ge((function(t){return t.responseText})),t.json=function(t,e){return me(t,\"application/json\",Ys,e)},t.html=function(t,e){return me(t,\"text/html\",Ws,e)},t.xml=ge((function(t){return t.responseXML})),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],170:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],171:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map((function(t,e){return[t[0],e]}));n.sort((function(t,e){return t[0]-e[0]}));for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var f=t[u],h=new Array(s+1),p=0,d=0;d<s;++d){var g=f[d];h[d]=g,p+=g*g}h[s]=p,l[u]=new a(h,u),c=Math.max(p,c)}i(l,o),r=l.length;var m=new Array(r+s+1),v=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1);for(u=0;u<=s;++u)x[u]=0;x[s]=y,m[0]=x.slice(),v[0]=-1;for(u=0;u<=s;++u){(h=x.slice())[u]=1,m[u+1]=h,v[u+1]=-1}for(u=0;u<r;++u){var b=l[u];m[u+s+1]=b.point,v[u+s+1]=b.index}var _=n(m,!1);_=e?_.filter((function(t){for(var e=0,r=0;r<=s;++r){var n=v[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0})):_.filter((function(t){for(var e=0;e<=s;++e){var r=v[t[e]];if(r<0)return!1;t[e]=r}return!0}));if(1&s)for(u=0;u<_.length;++u){h=(b=_[u])[0];b[0]=b[1],b[1]=h}return _}},{\"incremental-convex-hull\":459,uniq:597}],172:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],f=n.measureText(u[0]).width+n.measureText(u[1]).width,h=n.measureText(u).width;if(Math.abs(f-h)>s*l){var p=(h-f)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],173:[function(t,e,r){(function(t){(function(){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this)}).call(this,t(\"buffer\").Buffer)},{buffer:111}],174:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach((function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)})),t.closePath()}},{\"abs-svg-path\":65,\"normalize-svg-path\":497}],175:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],176:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],177:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,m=e&&e.length,v=m?e[0]*r:t.length,y=i(t,0,v,r,!0),x=[];if(!y||y.next===y.prev)return x;if(m&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(g(u));for(p.sort(f),o=0;o<p.length;o++)h(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<v;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function i(t,e,r,n,i){var a,o;if(i===E(t,e,r,n)>0)for(a=e;a<r;a+=n)o=M(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=M(a,t[a],t[a+1],o);return o&&x(o,o.next)&&(A(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(A(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,f,h){if(t){!h&&f&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=d(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,f);for(var p,g,m=t;t.prev!==t.next;)if(p=t.prev,g=t.next,f?l(t,n,i,f):s(t))e.push(p.i/r),e.push(t.i/r),e.push(g.i/r),A(t),t=g.next,m=g.next;else if((t=g)===m){h?1===h?o(t=c(a(t),e,r),e,r,n,i,f,2):2===h&&u(t,e,r,n,i,f):o(a(t),e,r,n,i,f,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(m(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&y(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(y(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=d(s,l,e,r,n),h=d(c,u,e,r,n),p=t.prevZ,g=t.nextZ;p&&p.z>=f&&g&&g.z<=h;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}for(;p&&p.z>=f;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;g&&g.z<=h;){if(g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,o=n.next.next;!x(i,o)&&b(i,n,n.next,o)&&T(i,o)&&T(o,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(o.i/r),A(n),A(n.next),n=t=o),n=n.next}while(n!==t);return a(n)}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=k(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function f(t,e){return t.x-e.x}function h(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&m(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),T(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=k(e,t);a(e,e.next),a(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function g(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function m(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(T(t,e)&&T(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var i=w(y(t,e,r)),a=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return i!==a&&o!==s||(!(0!==i||!_(t,r,e))||(!(0!==a||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function T(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function k(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function M(t,e,r,n){var i=new S(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function A(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(E(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],178:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;var o=new Array(e);for(i=0;i<e;++i)o[i]=[];for(i=0;i<r;++i){a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],(function(t,e){return t-e}));return o};var n=t(\"uniq\")},{uniq:597}],179:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t,e){var r,i=[],a=[],o=[],s={},l=[];function c(t){var e,n,i=!1;for(a.push(t),o[t]=!0,e=0;e<l[t].length;e++)(n=l[t][e])===r?(u(r,a),i=!0):o[n]||(i=c(n));if(i)!function t(e){o[e]=!1,s.hasOwnProperty(e)&&Object.keys(s[e]).forEach((function(r){delete s[e][r],o[r]&&t(r)}))}(t);else for(e=0;e<l[t].length;e++){n=l[t][e];var f=s[n];f||(f={},s[n]=f),f[n]=!0}return a.pop(),i}function u(t,r){var n=[].concat(r).concat(t);e?e(c):i.push(n)}function f(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter((function(t){return t>=e}))}(e);for(var r,i=n(t).components.filter((function(t){return t.length>1})),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map((function(t,e){return-1===l.indexOf(e)?[]:t.filter((function(t){return-1!==l.indexOf(t)}))}))}}r=0;for(var h=t.length;r<h;){var p=f(r);if(r=p.leastVertex,l=p.adjList){for(var d=0;d<l.length;d++)for(var g=0;g<l[d].length;g++){var m=l[d][g];o[+m]=!1,s[m]={}}c(r),r+=1}else r=h}return e?void 0:i}},{\"strongly-connected-components\":569}],180:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":211}],181:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":182,\"./shim\":183}],182:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),f=Array.isArray,h=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,m,v,y,x,b,_,w,T=arguments[1],k=arguments[2];if(t=Object(l(t)),c(T)&&s(T),this&&this!==Array&&a(this))e=this;else{if(!T){if(i(t))return 1!==(v=t.length)?Array.apply(null,t):((m=new Array(1))[0]=t[0],m);if(f(t)){for(m=new Array(v=t.length),r=0;r<v;++r)m[r]=t[r];return m}}m=[]}if(!f(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(m=new e),b=x.next(),r=0;!b.done;)w=T?h.call(T,k,b.value,r):b.value,e?(p.value=w,d(m,r,p)):m[r]=w,b=x.next(),++r;v=r}else if(u(t)){for(v=t.length,e&&(m=new e),r=0,g=0;r<v;++r)w=t[r],r+1<v&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=T?h.call(T,k,w,g):w,e?(p.value=w,d(m,g,p)):m[g]=w,++g;v=g}if(void 0===v)for(v=o(t.length),e&&(m=new e(v)),r=0;r<v;++r)w=T?h.call(T,k,t[r],r):t[r],e?(p.value=w,d(m,r,p)):m[r]=w;return e&&(p.value=null,m.length=v),m}},{\"../../function/is-arguments\":184,\"../../function/is-function\":185,\"../../number/to-pos-integer\":191,\"../../object/is-value\":200,\"../../object/valid-callable\":209,\"../../object/valid-value\":211,\"../../string/is-string\":215,\"es6-symbol\":225}],184:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],185:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=RegExp.prototype.test.bind(/^[object [A-Za-z0-9]*Function]$/);e.exports=function(t){return\"function\"==typeof t&&i(n.call(t))}},{}],186:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],187:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":188,\"./shim\":189}],188:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],189:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],190:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":187}],191:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":190}],192:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,f=arguments[2],h=arguments[3];return r=Object(i(r)),n(c),u=s(r),h&&u.sort(\"function\"==typeof h?a.call(h,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,(function(t,n){return l.call(r,t)?o.call(c,f,r[t],t,r,n):e}))}}},{\"./valid-callable\":209,\"./valid-value\":211}],193:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":194,\"./shim\":195}],194:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],195:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)n(e=arguments[o]).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":201,\"../valid-value\":211}],196:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,(function(e){(o.ensure||e in t)&&(s[e]=t[e])})):i(s,t),s}},{\"../array/from\":181,\"./assign\":193,\"./valid-value\":211}],197:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach((function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}})),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":207,\"./set-prototype-of/shim\":208}],198:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":192}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":200}],200:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":186}],201:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":202,\"./shim\":203}],202:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],203:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":200}],204:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,(function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)})),r}},{\"./for-each\":198,\"./valid-callable\":209}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create,o=function(t,e){var r;for(r in t)e[r]=t[r]};e.exports=function(t){var e=a(null);return i.call(arguments,(function(t){n(t)&&o(Object(t),e)})),e}},{\"./is-value\":200}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],208:[function(t,e,r){\"use strict\";var n,i=t(\"../is-object\"),a=t(\"../valid-value\"),o=Object.prototype.isPrototypeOf,s=Object.defineProperty,l={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(a(t),null===e||i(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=function(t){var e,r;return t?(2===t.level?t.set?(r=t.set,e=function(t,e){return r.call(n(t,e),e),t}):e=function(t,e){return n(t,e).__proto__=e,t}:e=function t(e,r){var i;return n(e,r),(i=o.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&s(t.nullPolyfill,\"__proto__\",l),e},Object.defineProperty(e,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:t.level})):null}(function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}()),t(\"../create\")},{\"../create\":197,\"../is-object\":199,\"../valid-value\":211}],209:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],210:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":199}],211:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":200}],212:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":213,\"./shim\":214}],213:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],214:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],215:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],216:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],217:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o((function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t}))}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/string/#/contains\":212,\"es6-symbol\":225}],218:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,f,h,p,d,g,m,v=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),f=function(){h=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,v,u.value,f),h)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(m=g.charCodeAt(0))>=55296&&m<=56319&&(g+=t[++p]),l.call(e,v,g,f),!h);++p);else c.call(t,(function(t){return l.call(e,v,t,f),h}))}},{\"./get\":219,\"es5-ext/function/is-arguments\":184,\"es5-ext/object/valid-callable\":209,\"es5-ext/string/is-string\":215}],219:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":217,\"./string\":222,\"./valid-iterable\":223,\"es5-ext/function/is-arguments\":184,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],220:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),f=Object.defineProperty,h=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");h(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,h(n.prototype,a({_next:l((function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()})),next:l((function(){return this._createResult(this._next())})),_createResult:l((function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}})),_resolve:l((function(t){return this.__list__[t]})),_unBind:l((function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)})),toString:l((function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"}))},c({_onAdd:l((function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach((function(e,r){e>=t&&(this.__redo__[r]=++e)}),this),this.__redo__.push(t)):f(this,\"__redo__\",l(\"c\",[t])))})),_onDelete:l((function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach((function(e,r){e>t&&(this.__redo__[r]=--e)}),this)))})),_onClear:l((function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0}))}))),f(n.prototype,u.iterator,l((function(){return this})))},{d:155,\"d/auto-bind\":154,\"es5-ext/array/#/clear\":180,\"es5-ext/object/assign\":193,\"es5-ext/object/valid-callable\":209,\"es5-ext/object/valid-value\":211,\"es6-symbol\":225}],221:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":184,\"es5-ext/object/is-value\":200,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],222:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a((function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()})),_resolve:a((function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r}))}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es6-symbol\":225}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":221}],224:[function(t,e,r){(function(n,i){(function(){\n",
       "/*!\n",
       " * @overview es6-promise - a tiny implementation of Promises/A+.\n",
       " * @copyright Copyright (c) 2014 Yehuda Katz, Tom Dale, Stefan Penner and contributors (Conversion to ES6 API by Jake Archibald)\n",
       " * @license   Licensed under MIT license\n",
       " *            See https://raw.githubusercontent.com/stefanpenner/es6-promise/master/LICENSE\n",
       " * @version   v4.2.8+1e68dce6\n",
       " */\n",
       "!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,(function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(m):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},f=u.MutationObserver||u.WebKitMutationObserver,h=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(m,1)}}var g=new Array(1e3);function m(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var v,y,x,b,_=void 0;function w(t,e){var r=this,n=new this.constructor(M);void 0===n[k]&&D(n);var i=r._state;if(i){var a=arguments[i-1];l((function(){return z(i,n,a,r._result)}))}else I(r,n,t,e);return n}function T(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(M);return S(e,t),e}h?_=function(){return n.nextTick(m)}:f?(y=0,x=new f(m),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((v=new MessageChannel).port1.onmessage=m,_=function(){return v.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var t=Function(\"return this\")().require(\"vertx\");return\"undefined\"!=typeof(o=t.runOnLoop||t.runOnContext)?function(){o(m)}:d()}catch(t){return d()}}():d();var k=Math.random().toString(36).substring(2);function M(){}function A(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===T?function(t,e){1===e._state?C(t,e._result):2===e._state?L(t,e._result):I(e,void 0,(function(e){return S(t,e)}),(function(e){return L(t,e)}))}(t,r):void 0===n?C(t,r):e(n)?function(t,e,r){l((function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,(function(r){n||(n=!0,e!==r?S(t,r):C(t,r))}),(function(e){n||(n=!0,L(t,e))}),t._label);!n&&i&&(n=!0,L(t,i))}),t)}(t,r,n):C(t,r)}function S(t,e){if(t===e)L(t,new TypeError(\"You cannot resolve a promise with itself\"));else if(i=typeof(n=e),null===n||\"object\"!==i&&\"function\"!==i)C(t,e);else{var r=void 0;try{r=e.then}catch(e){return void L(t,e)}A(t,e,r)}var n,i}function E(t){t._onerror&&t._onerror(t._result),P(t)}function C(t,e){void 0===t._state&&(t._result=e,t._state=1,0!==t._subscribers.length&&l(P,t))}function L(t,e){void 0===t._state&&(t._state=2,t._result=e,l(E,t))}function I(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+1]=r,i[a+2]=n,0===a&&t._state&&l(P,t)}function P(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?z(r,n,i,a):i(a);t._subscribers.length=0}}function z(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=!0;if(a){try{o=n(i)}catch(t){l=!1,s=t}if(r===o)return void L(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i;void 0!==r._state||(a&&l?S(r,o):!1===l?L(r,s):1===t?C(r,o):2===t&&L(r,o))}var O=0;function D(t){t[k]=O++,t._state=void 0,t._result=void 0,t._subscribers=[]}var R=function(){function t(t,e){this._instanceConstructor=t,this.promise=new t(M),this.promise[k]||D(this.promise),r(e)?(this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?C(this.promise,this._result):(this.length=this.length||0,this._enumerate(e),0===this._remaining&&C(this.promise,this._result))):L(this.promise,new Error(\"Array Methods must be provided an Array\"))}return t.prototype._enumerate=function(t){for(var e=0;void 0===this._state&&e<t.length;e++)this._eachEntry(t[e],e)},t.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===T){var i=void 0,a=void 0,o=!1;try{i=t.then}catch(t){o=!0,a=t}if(i===w&&void 0!==t._state)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===F){var s=new r(M);o?L(s,a):A(s,t,i),this._willSettleAt(s,e)}else this._willSettleAt(new r((function(e){return e(t)})),e)}else this._willSettleAt(n(t),e)},t.prototype._settledAt=function(t,e,r){var n=this.promise;void 0===n._state&&(this._remaining--,2===t?L(n,r):this._result[e]=r),0===this._remaining&&C(n,this._result)},t.prototype._willSettleAt=function(t,e){var r=this;I(t,void 0,(function(t){return r._settledAt(1,e,t)}),(function(t){return r._settledAt(2,e,t)}))},t}();var F=function(){function t(e){this[k]=O++,this._result=this._state=void 0,this._subscribers=[],M!==e&&(\"function\"!=typeof e&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof t?function(t,e){try{e((function(e){S(t,e)}),(function(e){L(t,e)}))}catch(e){L(t,e)}}(this,e):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}return t.prototype.catch=function(t){return this.then(null,t)},t.prototype.finally=function(t){var r=this.constructor;return e(t)?this.then((function(e){return r.resolve(t()).then((function(){return e}))}),(function(e){return r.resolve(t()).then((function(){throw e}))})):this.then(t,t)},t}();return F.prototype.then=w,F.all=function(t){return new R(this,t).promise},F.race=function(t){var e=this;return r(t)?new e((function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)})):new e((function(t,e){return e(new TypeError(\"You must pass an array to race.\"))}))},F.resolve=T,F.reject=function(t){var e=new this(M);return L(e,t),e},F._setScheduler=function(t){s=t},F._setAsap=function(t){l=t},F._asap=l,F.polyfill=function(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=F},F.Promise=F,F}))}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:526}],225:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?t(\"ext/global-this\").Symbol:t(\"./polyfill\")},{\"./is-implemented\":226,\"./polyfill\":231,\"ext/global-this\":238}],226:[function(t,e,r){\"use strict\";var n=t(\"ext/global-this\"),i={object:!0,symbol:!0};e.exports=function(){var t,e=n.Symbol;if(\"function\"!=typeof e)return!1;t=e(\"test symbol\");try{String(t)}catch(t){return!1}return!!i[typeof e.iterator]&&(!!i[typeof e.toPrimitive]&&!!i[typeof e.toStringTag])}},{\"ext/global-this\":238}],227:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],228:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=Object.create,a=Object.defineProperty,o=Object.prototype,s=i(null);e.exports=function(t){for(var e,r,i=0;s[t+(i||\"\")];)++i;return s[t+=i||\"\"]=!0,a(o,e=\"@@\"+t,n.gs(null,(function(t){r||(r=!0,a(this,e,n(t)),r=!1)}))),e}},{d:155}],229:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"ext/global-this\").Symbol;e.exports=function(t){return Object.defineProperties(t,{hasInstance:n(\"\",i&&i.hasInstance||t(\"hasInstance\")),isConcatSpreadable:n(\"\",i&&i.isConcatSpreadable||t(\"isConcatSpreadable\")),iterator:n(\"\",i&&i.iterator||t(\"iterator\")),match:n(\"\",i&&i.match||t(\"match\")),replace:n(\"\",i&&i.replace||t(\"replace\")),search:n(\"\",i&&i.search||t(\"search\")),species:n(\"\",i&&i.species||t(\"species\")),split:n(\"\",i&&i.split||t(\"split\")),toPrimitive:n(\"\",i&&i.toPrimitive||t(\"toPrimitive\")),toStringTag:n(\"\",i&&i.toStringTag||t(\"toStringTag\")),unscopables:n(\"\",i&&i.unscopables||t(\"unscopables\"))})}},{d:155,\"ext/global-this\":238}],230:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"../../../validate-symbol\"),a=Object.create(null);e.exports=function(t){return Object.defineProperties(t,{for:n((function(e){return a[e]?a[e]:a[e]=t(String(e))})),keyFor:n((function(t){var e;for(e in i(t),a)if(a[e]===t)return e}))})}},{\"../../../validate-symbol\":232,d:155}],231:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"d\"),s=t(\"./validate-symbol\"),l=t(\"ext/global-this\").Symbol,c=t(\"./lib/private/generate-name\"),u=t(\"./lib/private/setup/standard-symbols\"),f=t(\"./lib/private/setup/symbol-registry\"),h=Object.create,p=Object.defineProperties,d=Object.defineProperty;if(\"function\"==typeof l)try{String(l()),a=!0}catch(t){}else l=null;i=function(t){if(this instanceof i)throw new TypeError(\"Symbol is not a constructor\");return n(t)},e.exports=n=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return a?l(e):(r=h(i.prototype),e=void 0===e?\"\":String(e),p(r,{__description__:o(\"\",e),__name__:o(\"\",c(e))}))},u(n),f(n),p(i.prototype,{constructor:o(n),toString:o(\"\",(function(){return this.__name__}))}),p(n.prototype,{toString:o((function(){return\"Symbol (\"+s(this).__description__+\")\"})),valueOf:o((function(){return s(this)}))}),d(n.prototype,n.toPrimitive,o(\"\",(function(){var t=s(this);return\"symbol\"==typeof t?t:t.toString()}))),d(n.prototype,n.toStringTag,o(\"c\",\"Symbol\")),d(i.prototype,n.toStringTag,o(\"c\",n.prototype[n.toStringTag])),d(i.prototype,n.toPrimitive,o(\"c\",n.prototype[n.toPrimitive]))},{\"./lib/private/generate-name\":228,\"./lib/private/setup/standard-symbols\":229,\"./lib/private/setup/symbol-registry\":230,\"./validate-symbol\":232,d:155,\"ext/global-this\":238}],232:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":227}],233:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":234,\"./polyfill\":236}],234:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],235:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],236:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),f=t(\"es6-iterator/for-of\"),h=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,m=Object.prototype.hasOwnProperty,v=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,v(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(f(e,(function(e){s(e),t.set(e[0],e[1])})),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c((function(t){return!!m.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)})),get:c((function(t){if(m.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]})),has:c((function(t){return m.call(o(t),this.__weakMapData__)})),set:c((function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this})),toString:c((function(){return\"[object WeakMap]\"}))}),g(n.prototype,h,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":235,d:155,\"es5-ext/object/is-value\":200,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/object/valid-object\":210,\"es5-ext/object/valid-value\":211,\"es5-ext/string/random-uniq\":216,\"es6-iterator/for-of\":218,\"es6-iterator/get\":219,\"es6-symbol\":225}],237:[function(t,e,r){var n=function(){if(\"object\"==typeof self&&self)return self;if(\"object\"==typeof window&&window)return window;throw new Error(\"Unable to resolve global `this`\")};e.exports=function(){if(this)return this;try{Object.defineProperty(Object.prototype,\"__global__\",{get:function(){return this},configurable:!0})}catch(t){return n()}try{return __global__||n()}finally{delete Object.prototype.__global__}}()},{}],238:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?globalThis:t(\"./implementation\")},{\"./implementation\":237,\"./is-implemented\":239}],239:[function(t,e,r){\"use strict\";e.exports=function(){return\"object\"==typeof globalThis&&(!!globalThis&&globalThis.Array===Array)}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],241:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":470}],242:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:return\"number\"==typeof t?new o(n=l(t),n,0):new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,f=this.bounds;if(o<0)for(var h=u-1,p=0;p<u;++p,--h)s[p]=l[h];else if(o>=r-1){h=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--h)s[p]=l[h]+d*c[h]}else{h=u*(o+1)-1;var g=e[o],m=e[o+1]-g||1,v=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--h)v[p]=l[h],x[p]=c[h]*m,y[p]=l[h+u],b[p]=c[h+u]*m,_=_&&v[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=v[p];else n(v,x,y,b,(t-g)/m,s)}var w=f[0],T=f[1];for(p=0;p<u;++p)s[p]=a(w[p],T[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,f=(e[r-1],0);f<c;++f,--u)o[f]=l[u];else{u=c*(a+1)-1;var h=e[a],p=e[a+1]-h||1,d=this._scratch[1],g=this._scratch[2],m=this._scratch[3],v=this._scratch[4],y=!0;for(f=0;f<c;++f,--u)d[f]=s[u],m[f]=l[u]*p,g[f]=s[u+c],v[f]=l[u+c]*p,y=y&&d[f]===g[f]&&m[f]===v[f]&&0===m[f];if(y)for(f=0;f<c;++f)o[f]=0;else{n.derivative(d,m,g,v,(t-h)/p,o);for(f=0;f<c;++f)o[f]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var f=0;f<r;++f)n.push(n[o++]),i.push(0);this._time.push(t);for(f=r;f>0;--f)n.push(a(l[f-1],c[f-1],arguments[f])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],f=s>1e-6?1/s:0;this._time.push(t);for(var h=r;h>0;--h){var p=a(c[h-1],u[h-1],arguments[h]);n.push(p),i.push((p-n[o++])*f)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,f=u>1e-6?1/u:0;this._time.push(t);for(var h=r;h>0;--h){var p=arguments[h];n.push(a(l[h-1],c[h-1],n[o++]+p)),i.push(p*f)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var f=r-1;f>=0;--f)n.push(a(l[f],c[f],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":243,\"cubic-hermite\":150}],243:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],244:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var f=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new f(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new f(t):(e=new f(t.length+r)).set(t,r)}return e}},{dtype:175}],245:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var f=r.getContext(\"2d\");f.fillStyle=\"#000\",f.fillRect(0,0,r.width,r.height),f.font=a,f.textAlign=\"center\",f.textBaseline=\"middle\",f.fillStyle=\"#fff\";var h=o[0]/2,p=o[1]/2;for(c=0;c<s.length;c++)f.fillText(s[c],h,p),(h+=o[0])>e[0]-o[0]/2&&(h=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":147}],246:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,f=u.getContext(\"2d\"),h={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,f.font=t;var d={top:0};f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillStyle=\"black\",f.fillText(\"H\",0,0);var g=a(f.getImageData(0,0,p,p));f.clearRect(0,0,p,p),f.textBaseline=\"bottom\",f.fillText(\"H\",0,p);var m=a(f.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-m+g,f.clearRect(0,0,p,p),f.textBaseline=\"alphabetic\",f.fillText(\"H\",0,p);var v=p-a(f.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=v,f.clearRect(0,0,p,p),f.textBaseline=\"middle\",f.fillText(\"H\",0,.5*p);var y=a(f.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"hanging\",f.fillText(\"H\",0,.5*p);var x=a(f.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"ideographic\",f.fillText(\"H\",0,p);var b=a(f.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,h.upper&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.upper,0,0),d.upper=a(f.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),h.lower&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.lower,0,0),d.lower=a(f.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),h.tittle&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.tittle,0,0),d.tittle=a(f.getImageData(0,0,p,p))),h.ascent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.ascent,0,0),d.ascent=a(f.getImageData(0,0,p,p))),h.descent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.descent,0,0),d.descent=o(f.getImageData(0,0,p,p))),h.overshoot){f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.overshoot,0,0);var _=o(f.getImageData(0,0,p,p));d.overshoot=_-v}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],247:[function(t,e,r){\"use strict\";e.exports=function(t){return new s(t||g,null)};function n(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function i(t){return new n(t._color,t.key,t.value,t.left,t.right,t._count)}function a(t,e){return new n(t,e.key,e.value,e.left,e.right,e._count)}function o(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function s(t,e){this._compare=t,this.root=e}var l=s.prototype;function c(t,e){var r;if(e.left&&(r=c(t,e.left)))return r;return(r=t(e.key,e.value))||(e.right?c(t,e.right):void 0)}function u(t,e,r,n){if(e(t,n.key)<=0){var i;if(n.left)if(i=u(t,e,r,n.left))return i;if(i=r(n.key,n.value))return i}if(n.right)return u(t,e,r,n.right)}function f(t,e,r,n,i){var a,o=r(t,i.key),s=r(e,i.key);if(o<=0){if(i.left&&(a=f(t,e,r,n,i.left)))return a;if(s>0&&(a=n(i.key,i.value)))return a}if(s>0&&i.right)return f(t,e,r,n,i.right)}function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(l,\"keys\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(e)})),t}}),Object.defineProperty(l,\"values\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(r)})),t}}),Object.defineProperty(l,\"length\",{get:function(){return this.root?this.root._count:0}}),l.insert=function(t,e){for(var r=this._compare,i=this.root,l=[],c=[];i;){var u=r(t,i.key);l.push(i),c.push(u),i=u<=0?i.left:i.right}l.push(new n(0,t,e,null,null,1));for(var f=l.length-2;f>=0;--f){i=l[f];c[f]<=0?l[f]=new n(i._color,i.key,i.value,l[f+1],i.right,i._count+1):l[f]=new n(i._color,i.key,i.value,i.left,l[f+1],i._count+1)}for(f=l.length-1;f>1;--f){var h=l[f-1];i=l[f];if(1===h._color||1===i._color)break;var p=l[f-2];if(p.left===h)if(h.left===i){if(!(d=p.right)||0!==d._color){if(p._color=0,p.left=h.right,h._color=1,h.right=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).left===p?g.left=h:g.right=h;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else{if(!(d=p.right)||0!==d._color){if(h.right=i.left,p._color=0,p.left=i.right,i._color=1,i.left=h,i.right=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).left===p?g.left=i:g.right=i;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else if(h.right===i){if(!(d=p.left)||0!==d._color){if(p._color=0,p.right=h.left,h._color=1,h.left=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).right===p?g.right=h:g.left=h;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}else{var d;if(!(d=p.left)||0!==d._color){var g;if(h.left=i.right,p._color=0,p.right=i.left,i._color=1,i.right=h,i.left=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).right===p?g.right=i:g.left=i;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}}return l[0]._color=1,new s(r,l[0])},l.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return c(t,this.root);case 2:return u(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return f(e,r,this._compare,t,this.root)}},Object.defineProperty(l,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(l,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),l.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},l.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},l.remove=function(t){var e=this.find(t);return e?e.remove():this},l.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var p=h.prototype;function d(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function g(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(p,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(p,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),p.clone=function(){return new h(this.tree,this._stack.slice())},p.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new n(r._color,r.key,r.value,r.left,r.right,r._count);for(var l=t.length-2;l>=0;--l){(r=t[l]).left===t[l+1]?e[l]=new n(r._color,r.key,r.value,e[l+1],r.right,r._count):e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count)}if((r=e[e.length-1]).left&&r.right){var c=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var u=e[c-1];e.push(new n(r._color,u.key,u.value,r.left,r.right,r._count)),e[c-1].key=r.key,e[c-1].value=r.value;for(l=e.length-2;l>=c;--l)r=e[l],e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count);e[c-1].left=e[c]}if(0===(r=e[e.length-1])._color){var f=e[e.length-2];f.left===r?f.left=null:f.right===r&&(f.right=null),e.pop();for(l=0;l<e.length;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(r.left||r.right){r.left?d(r,r.left):r.right&&d(r,r.right),r._color=1;for(l=0;l<e.length-1;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(1===e.length)return new s(this.tree._compare,null);for(l=0;l<e.length;++l)e[l]._count--;var h=e[e.length-2];return function(t){for(var e,r,n,s,l=t.length-1;l>=0;--l){if(e=t[l],0===l)return void(e._color=1);if((r=t[l-1]).left===e){if((n=r.right).right&&0===n.right._color){if(s=(n=r.right=i(n)).right=i(n.right),r.right=n.left,n.left=r,n.right=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).left===r?c.left=n:c.right=n;return void(t[l-1]=n)}if(n.left&&0===n.left._color){if(s=(n=r.right=i(n)).left=i(n.left),r.right=s.left,n.left=s.right,s.left=r,s.right=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).left===r?c.left=s:c.right=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.right=a(0,n));r.right=a(0,n);continue}n=i(n),r.right=n.left,n.left=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).left===r?c.left=n:c.right=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}else{if((n=r.left).left&&0===n.left._color){if(s=(n=r.left=i(n)).left=i(n.left),r.left=n.right,n.right=r,n.left=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).right===r?c.right=n:c.left=n;return void(t[l-1]=n)}if(n.right&&0===n.right._color){if(s=(n=r.left=i(n)).right=i(n.right),r.left=s.right,n.right=s.left,s.right=r,s.left=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).right===r?c.right=s:c.left=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.left=a(0,n));r.left=a(0,n);continue}var c;n=i(n),r.left=n.right,n.right=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).right===r?c.right=n:c.left=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}}}(e),h.left===r?h.left=null:h.right=null,new s(this.tree._compare,e[0])},Object.defineProperty(p,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(p,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(p,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),p.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),p.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),i=e[e.length-1];r[r.length-1]=new n(i._color,i.key,t,i.left,i.right,i._count);for(var a=e.length-2;a>=0;--a)(i=e[a]).left===e[a+1]?r[a]=new n(i._color,i.key,i.value,r[a+1],i.right,i._count):r[a]=new n(i._color,i.key,i.value,i.left,r[a+1],i._count);return new s(this.tree._compare,r[0])},p.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],248:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function a(t){if(t<0)return Number(\"0/0\");for(var e=i[0],r=i.length-1;r>0;--r)e+=i[r]/(t+r);var n=t+607/128+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(a(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var o=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(o,e+.5)*Math.exp(-o)*r},e.exports.log=a},{}],249:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],250:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var f=u.prototype;function h(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}f.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,(function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]})),u=!1,f=!1;if(\"bounds\"in t)for(var h=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)h[p][d]!==this.bounds[p][d]&&(f=!0),this.bounds[p][d]=h[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,f=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),f=!0,u=!0,this._firstInit=!1),f&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort((function(t,e){return t.x-e.x}));s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new h,new h,new h];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var f=a,h=s,p=o,d=l;c&1<<u&&(f=s,h=a,p=l,d=o),f[u]=r[0][u],h[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],m={model:l,view:l,projection:l,_ortho:!1};f.isOpaque=function(){return!0},f.isTransparent=function(){return!1},f.drawTransparent=function(t){};var v=[0,0,0],y=[0,0,0],x=[0,0,0];f.draw=function(t){t=t||m;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),f=u.cubeEdges,h=u.axis,b=n[12],_=n[13],w=n[14],T=n[15],k=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*T)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=f[M],this.lastCubeProps.axis[M]=h[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,f,h);e=this.gl;var S,E=g;for(M=0;M<3;++M)this.backgroundEnable[M]?E[M]=h[M]:E[M]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(M=0;M<3;++M){var C=[0,0,0];h[M]>0?C[M]=a[1][M]:C[M]=a[0][M];for(var L=0;L<2;++L){var I=(M+1+L)%3,P=(M+1+(1^L))%3;this.gridEnable[I]&&this._lines.drawGrid(I,P,this.bounds,C,this.gridColor[I],this.gridWidth[I]*this.pixelRatio)}for(L=0;L<2;++L){I=(M+1+L)%3,P=(M+1+(1^L))%3;this.zeroEnable[P]&&Math.min(a[0][P],a[1][P])<=0&&Math.max(a[0][P],a[1][P])>=0&&this._lines.drawZero(I,P,this.bounds,C,this.zeroLineColor[P],this.zeroLineWidth[P]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var z=c(v,A[M].primalMinor),O=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=k/r[5*L];z[L]*=D[L]*R,O[L]*=D[L]*R}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,z,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,O,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0||a>0&&l<0||a<0&&l>0||a<0&&l<0?N(n):(o>0&&s>0||o>0&&s<0||o<0&&s>0||o<0&&s<0)&&N(i)}for(M=0;M<3;++M){var U=A[M].primalMinor,V=A[M].mirrorMinor,q=c(x,A[M].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[M]&&(q[L]+=k*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this.tickAlign[M]=\"auto\"):this.tickAlign[M]=-1,F=1,\"auto\"===(S=[this.tickAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(M,U,V);for(L=0;L<3;++L)q[L]+=k*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],q,this.tickColor[M],H,B,S)}if(this.labelEnable[M]){F=0,B=[0,0,0],this.labels[M].length>4&&(N(M),F=1),\"auto\"===(S=[this.labelAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=k*U[L]*this.labelPad[L]/r[5*L];q[M]+=.5*(a[0][M]+a[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],q,this.labelColor[M],[0,0,0],B,S)}}this._text.unbind()},f.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":251,\"./lib/cube.js\":252,\"./lib/lines.js\":253,\"./lib/text.js\":255,\"./lib/ticks.js\":256}],251:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,f=[0,0,0],h=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),f[l]=p,h[l]=p;for(var d=-1;d<=1;d+=2){f[c]=d;for(var g=-1;g<=1;g+=2)f[u]=g,e.push(f[0],f[1],f[2],h[0],h[1],h[2]),s+=1}var m=c;c=u,u=m}var v=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:v,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:v,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,v,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],252:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],h(l[y],u,s),y+=1}}var w=-1;for(x=0;x<8;++x){for(var T=l[x][3],k=0;k<3;++k)c[x][k]=l[x][k]/T;p&&(c[x][2]*=-1),T<0&&(w<0||c[x][2]<c[w][2])&&(w=x)}if(w<0){w=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,S=(M+1)%3,E=-1,C=-1,L=0;L<2;++L){var I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);o(c[z],c[I],c[P],f)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<M);else{for(L=0;L<2;++L){I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);var z,O=d([l[z],l[I],l[P],l[z+(1<<A)+(1<<S)]]);L?E=O:C=O}C>E&&(w|=1<<M)}}}var D=7^w,R=-1;for(x=0;x<8;++x)x!==w&&x!==D&&(R<0||c[R][1]>c[x][1])&&(R=x);var F=-1;for(x=0;x<3;++x){if((N=R^1<<x)!==w&&N!==D)F<0&&(F=N),(S=c[N])[0]<c[F][0]&&(F=N)}var B=-1;for(x=0;x<3;++x){var N;if((N=R^1<<x)!==w&&N!==D&&N!==F)B<0&&(B=N),(S=c[N])[0]>c[B][0]&&(B=N)}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^B)]=R&B;var U=7^B;U===w||U===D?(U=7^F,j[n.log2(B^U)]=U&B):j[n.log2(F^U)]=U&F;var V=m,q=w;for(M=0;M<3;++M)V[M]=q&1<<M?-1:1;return v};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),f=[0,0,0];function h(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,f=l[0]/l[3]-n,h=l[1]/l[3]-i;o+=Math.abs(c*h-u*f)}return o}var g=[1,1,1],m=[0,0,0],v={cubeEdges:g,axis:m}},{\"bit-twiddle\":97,\"gl-mat4/multiply\":295,\"robust-orientation\":548,\"split-polygon\":566}],253:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var f=0;f<3;++f){for(var h=o.length/3|0,d=0;d<r[f].length;++d){var g=+r[f][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var m=o.length/3|0;s[f]=h,l[f]=m-h;h=o.length/3|0;for(var v=0;v<r[f].length;++v){g=+r[f][v].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}m=o.length/3|0;c[f]=h,u[f]=m-h}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function f(t){return t[0]=t[1]=t[2]=0,t}function h(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=f(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=h(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=f(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=f(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=f(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=f(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=f(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=h(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=f(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=f(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=f(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=h(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=f(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],254:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:257}],255:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),f=i(t,[{buffer:u,size:3}]),h=o(t);h.attributes.position.location=0;var p=new c(t,h,u,f);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,f=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,f[0]=this.gl.drawingBufferWidth,f[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=f},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var f=(n||12)/12,h=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var m=p[d],v=2;v>=0;--v){var y=h[m[v]];o.push(f*y[0],-f*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],f=[0,0,0],h=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){f[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),h[d]=(o.length/3|0)-f[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=f,this.labelCount=h},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this)}).call(this,t(\"_process\"))},{\"./shaders\":254,_process:526,\"gl-buffer\":259,\"gl-vao\":358,\"vectorize-text\":600}],256:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var f=\"\"+c;f.length<i;)f=\"0\"+f;return u+\".\"+f}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],257:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],258:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,f){var h=e.model||c,p=e.view||c,v=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(f=f||a(h,p,v,x,y)).axis;o(u,p,h),o(u,v,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var T=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var M=(k+1)%3,A=(k+2)%3,S=m;t:for(w=0;w<2;++w){var E=[];if(b[k]<0!=!!w){S[k]=x[w][k];for(var C=0;C<2;++C){S[M]=x[C^w][M];for(var L=0;L<2;++L)S[A]=x[L^C^w][A],E.push(S.slice())}var I=y?5:4;for(C=I;C===I;++C){if(0===E.length)continue t;E=i.positive(E,T[C])}for(C=0;C<E.length;++C){A=E[C];var P=d(m,u,A,r,l);for(L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,A[L]),_[L].hi=Math.max(_[L].hi,A[L]),L!==k&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(P[L])))}}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function f(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var h=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=h,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,f=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+f*f)}return t}var g=[new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0)],m=[0,0,0]},{\"./lib/cube.js\":252,\"extract-frustum-planes\":240,\"gl-mat4/multiply\":295,\"gl-mat4/transpose\":306,\"gl-vec4/transformMat4\":429,\"split-polygon\":566}],259:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var f;f=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?f:f.subarray(0,t.length),e),n.free(f)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],260:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\");e.exports=function(t,e){var r=t.positions,i=t.vectors,a={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),a;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,f=1/0,h=-1/0,p=null,d=null,g=[],m=1/0,v=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),f=Math.min(x[2],f),h=Math.max(x[2],h);var b=i[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(m=Math.min(m,_),v=!1):v=!0}v||(p=x,d=b),g.push(b)}var w=[s,c,f],T=[l,u,h];e&&(e[0]=w,e[1]=T),0===o&&(o=1);var k=1/o;isFinite(m)||(m=1),a.vectorScale=m;var M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*k),a.coneScale=M;y=0;for(var A=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],C=x[2],L=g[y],I=n.length(L)*k,P=0;P<8;P++){a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vertexIntensity.push(I,I,I),a.vertexIntensity.push(I,I,I);var z=a.positions.length;a.cells.push([z-6,z-5,z-4],[z-3,z-2,z-1])}return a};var i=t(\"./lib/shaders\");e.exports.createMesh=t(\"./create_mesh\"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:i,traceType:\"cone\"})}},{\"./create_mesh\":261,\"./lib/shaders\":262,\"gl-vec3\":377}],261:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"gl-mat4/multiply\"),l=t(\"gl-mat4/invert\"),c=t(\"ndarray\"),u=t(\"colormap\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e,r,n,i,a,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=f,this._view=f,this._projection=f,this._resolution=[1,1]}var p=h.prototype;function d(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}function g(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],o=[],s=[],l=[],f=[];this.cells=r,this.positions=n,this.vectors=i;var h=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,g=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],g=+t.vertexIntensityBounds[1];else for(var m=0;m<p.length;++m){var v=p[m];d=Math.min(d,v),g=Math.max(g,v)}else for(m=0;m<n.length;++m){v=n[m][2];d=Math.min(d,v),g=Math.max(g,v)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(m=0;m<n.length;++m)for(var y=n[m],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(m=0;m<r.length;++m){var _=r[m];switch(_.length){case 3:for(x=0;x<3;++x){y=n[T=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var T;y=n[T=_[2-x]];a.push(y[0],y[1],y[2],y[3]);var k=i[T];o.push(k[0],k[1],k[2],k[3]||0);var M,A=h;3===A.length?s.push(A[0],A[1],A[2],1):s.push(A[0],A[1],A[2],A[3]),M=p?[(p[T]-d)/(g-d),0]:[(y[2]-d)/(g-d),0],l.push(M[0],M[1]),f.push(m)}b+=1}}this.triangleCount=b,this.trianglePositions.update(a),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(f))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:i,inverseModel:f.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/h}if(this.triangleCount>0){var g=this.triShader;g.bind(),g.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),i={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return\"cone\"===this.traceType?i.index=Math.floor(r[1]/48):\"streamtube\"===this.traceType&&(i.intensity=this.intensity[r[1]],i.velocity=this.vectors[r[1]].slice(0,3),i.divergence=this.vectors[r[1]][3],i.index=e),i},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var n=r.shaders;1===arguments.length&&(t=(e=t).gl);var s=d(t,n),l=g(t,n),u=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));u.generateMipmap(),u.minFilter=t.LINEAR_MIPMAP_LINEAR,u.magFilter=t.LINEAR;var f=i(t),p=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:f,type:t.FLOAT,size:4},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:p,type:t.FLOAT,size:4}]),b=new h(t,u,s,l,f,p,y,m,v,x,r.traceType||\"cone\");return b.update(e),b}},{colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],262:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, coneScale, coneOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float vectorScale, coneScale, coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:263}],263:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],264:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34e3:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],265:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":264}],266:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var f=0;f<3;++f)e.lineWidth(this.lineWidth[f]*this.pixelRatio),r.capSize=this.capSize[f]*u,this.lineCount[f]&&e.drawArrays(e.LINES,this.lineOffset[f],this.lineCount[f]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function f(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],h=0;h<3;++h)if(isNaN(u[h])||!isFinite(u[h]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":268,\"gl-buffer\":259,\"gl-vao\":358}],267:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],268:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:267}],269:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var f=1;if(\"color\"in(n=n||{})){if((f=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(f>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(f>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+f+\" draw buffers\")}}var h=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&f>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");h=t.FLOAT}else n.preferFloat&&f>0&&p&&(h=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var m=!1;\"stencil\"in n&&(m=!!n.stencil);return new d(t,e,r,h,f,g,m,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function f(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function h(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,m=[0|e,0|r];Object.defineProperties(m,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=m,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,m=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var v=0;v<o;++v)t.color[v]=h(r,i,a,m,r.RGBA,r.COLOR_ATTACHMENT0+v);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=h(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=h(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null);for(v=0;v<t.color.length;++v)t.color[v].dispose(),t.color[v]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),f(x)}u(r,e)}(this)}var g=d.prototype;function m(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),f(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return m(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return m(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,m(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":353}],270:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),f=t.split(\"\\n\"),h={},p=0;p<f.length;p++){var d=f[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));h[g]=d}}var m=o(e).split(\"\\n\");for(p=0;p<m.length;p++)if(h[p+3]||h[p+2]||h[p+1]){var v=m[p];if(c+=v+\"\\n\",h[p+1]){var y=h[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":66,\"gl-constants/lookup\":265,\"glsl-shader-name\":431,\"sprintf-js\":567}],271:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),f=s(r),h=s(r),p=new c(t,n,i,a,u,f,h);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,f=c.prototype,h=[0,0,1,0,0,1,1,0,1,1,0,1];f.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var f=e.uniforms;f.viewTransform=u,f.shape=this.shape;var h=e.attributes;this.positionBuffer.bind(),h.position.pointer(),this.weightBuffer.bind(),h.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),h.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),f.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],f=l[2]-l[0],h=l[3]-l[1];t[0]=2*c/f,t[4]=2*u/h,t[6]=2*(a[0]-l[0])/f-1,t[7]=2*(a[1]-l[1])/h-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),f.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},f.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]),l=!1!==t.zsmooth;this.xData=r,this.yData=o;var c,u,f,p,d=t.colorLevels||[0],g=t.colorValues||[0,0,0,1],m=d.length,v=this.bounds;l?(c=v[0]=r[0],u=v[1]=o[0],f=v[2]=r[r.length-1],p=v[3]=o[o.length-1]):(c=v[0]=r[0]+(r[1]-r[0])/2,u=v[1]=o[0]+(o[1]-o[0])/2,f=v[2]=r[r.length-1]+(r[r.length-1]-r[r.length-2])/2,p=v[3]=o[o.length-1]+(o[o.length-1]-o[o.length-2])/2);var y=1/(f-c),x=1/(p-u),b=e[0],_=e[1];this.shape=[b,_];var w=(l?(b-1)*(_-1):b*_)*(h.length>>>1);this.numVertices=w;for(var T=a.mallocUint8(4*w),k=a.mallocFloat32(2*w),M=a.mallocUint8(2*w),A=a.mallocUint32(w),S=0,E=l?b-1:b,C=l?_-1:_,L=0;L<C;++L){var I,P;l?(I=x*(o[L]-u),P=x*(o[L+1]-u)):(I=L<_-1?x*(o[L]-(o[L+1]-o[L])/2-u):x*(o[L]-(o[L]-o[L-1])/2-u),P=L<_-1?x*(o[L]+(o[L+1]-o[L])/2-u):x*(o[L]+(o[L]-o[L-1])/2-u));for(var z=0;z<E;++z){var O,D;l?(O=y*(r[z]-c),D=y*(r[z+1]-c)):(O=z<b-1?y*(r[z]-(r[z+1]-r[z])/2-c):y*(r[z]-(r[z]-r[z-1])/2-c),D=z<b-1?y*(r[z]+(r[z+1]-r[z])/2-c):y*(r[z]+(r[z]-r[z-1])/2-c));for(var R=0;R<h.length;R+=2){var F,B,N,j,U=h[R],V=h[R+1],q=s[l?(L+V)*b+(z+U):L*b+z],H=n.le(d,q);if(H<0)F=g[0],B=g[1],N=g[2],j=g[3];else if(H===m-1)F=g[4*m-4],B=g[4*m-3],N=g[4*m-2],j=g[4*m-1];else{var G=(q-d[H])/(d[H+1]-d[H]),Y=1-G,W=4*H,X=4*(H+1);F=Y*g[W]+G*g[X],B=Y*g[W+1]+G*g[X+1],N=Y*g[W+2]+G*g[X+2],j=Y*g[W+3]+G*g[X+3]}T[4*S]=255*F,T[4*S+1]=255*B,T[4*S+2]=255*N,T[4*S+3]=255*j,k[2*S]=.5*O+.5*D,k[2*S+1]=.5*I+.5*P,M[2*S]=U,M[2*S+1]=V,A[S]=L*b+z,S+=1}}}this.positionBuffer.update(k),this.weightBuffer.update(M),this.colorBuffer.update(T),this.idBuffer.update(A),a.free(k),a.free(T),a.free(M),a.free(A)},f.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":272,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"iota-array\":463,\"typedarray-pool\":595}],272:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:273}],273:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],274:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\\nvec4 packFloat(float v) {\\n  float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  float e = floor(log2(av));\\n  float m = av * pow(2.0, -e) - 1.0;\\n\\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n\\n  //Unpack exponent\\n  float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0;\\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":335,glslify:276}],275:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=f(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=a(e,u);d.wrap=e.REPEAT;var g=new v(e,r,o,s,l,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=new Uint8Array(4),s=new Float32Array(o.buffer);var l=t(\"binary-search-bounds\"),c=t(\"ndarray\"),u=t(\"./lib/shaders\"),f=u.createShader,h=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function g(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function m(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var y=v.prototype;y.isTransparent=function(){return this.hasAlpha},y.isOpaque=function(){return!this.hasAlpha},y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.drawTransparent=y.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:g(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:g(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],s=0,u=0,f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],h=t.position||t.positions;if(h){var p=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,m=!1;t:for(e=1;e<h.length;++e){var v,y,x,b=h[e-1],_=h[e];for(a.push(s),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,m=!0}continue t}f[0][r]=Math.min(f[0][r],b[r],_[r]),f[1][r]=Math.max(f[1][r],b[r],_[r])}Array.isArray(p[0])?(v=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],y=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):v=y=p,3===v.length&&(v=[v[0],v[1],v[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&v[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var T=s;if(s+=d(b,_),m){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3]);u+=2,m=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3],b[0],b[1],b[2],_[0],_[1],_[2],T,-x,v[0],v[1],v[2],v[3],_[0],_[1],_[2],b[0],b[1],b[2],s,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],s,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(s),o.push(h[h.length-1].slice()),this.bounds=f,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var k=t.dashes.slice();for(k.unshift(0),e=1;e<k.length;++e)k[e]=k[e-1]+k[e];var M=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)M.set(e,0,r,0);1&l.le(k,k[k.length-1]*e/255)?M.set(e,0,0,0):M.set(e,0,0,255)}this.texture.setPixels(M)}},y.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=n,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2],0),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new m(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-a,u=[0,0,0],f=0;f<3;++f)u[f]=c*n[f]+a*i[f];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new m(e,u,h,this.points[h])}},{\"./lib/shaders\":274,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],276:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],277:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15];return t[0]=s*(h*v-p*m)-f*(l*v-c*m)+g*(l*p-c*h),t[1]=-(n*(h*v-p*m)-f*(i*v-a*m)+g*(i*p-a*h)),t[2]=n*(l*v-c*m)-s*(i*v-a*m)+g*(i*c-a*l),t[3]=-(n*(l*p-c*h)-s*(i*p-a*h)+f*(i*c-a*l)),t[4]=-(o*(h*v-p*m)-u*(l*v-c*m)+d*(l*p-c*h)),t[5]=r*(h*v-p*m)-u*(i*v-a*m)+d*(i*p-a*h),t[6]=-(r*(l*v-c*m)-o*(i*v-a*m)+d*(i*c-a*l)),t[7]=r*(l*p-c*h)-o*(i*p-a*h)+u*(i*c-a*l),t[8]=o*(f*v-p*g)-u*(s*v-c*g)+d*(s*p-c*f),t[9]=-(r*(f*v-p*g)-u*(n*v-a*g)+d*(n*p-a*f)),t[10]=r*(s*v-c*g)-o*(n*v-a*g)+d*(n*c-a*s),t[11]=-(r*(s*p-c*f)-o*(n*p-a*f)+u*(n*c-a*s)),t[12]=-(o*(f*m-h*g)-u*(s*m-l*g)+d*(s*h-l*f)),t[13]=r*(f*m-h*g)-u*(n*m-i*g)+d*(n*h-i*f),t[14]=-(r*(s*m-l*g)-o*(n*m-i*g)+d*(n*l-i*s)),t[15]=r*(s*h-l*f)-o*(n*h-i*f)+u*(n*l-i*s),t}},{}],278:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],279:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],280:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],281:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],f=t[10],h=t[11],p=t[12],d=t[13],g=t[14],m=t[15];return(e*o-r*a)*(f*m-h*g)-(e*s-n*a)*(u*m-h*d)+(e*l-i*a)*(u*g-f*d)+(r*s-n*o)*(c*m-h*p)-(r*l-i*o)*(c*g-f*p)+(n*l-i*s)*(c*d-u*p)}},{}],282:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,f=n*s,h=i*o,p=i*s,d=i*l,g=a*o,m=a*s,v=a*l;return t[0]=1-f-d,t[1]=u+v,t[2]=h-m,t[3]=0,t[4]=u-v,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=h+m,t[9]=p-g,t[10]=1-c-f,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],283:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o=r[0],s=r[1],l=r[2],c=Math.sqrt(o*o+s*s+l*l);if(Math.abs(c)<1e-6)return null;return o*=c=1/c,s*=c,l*=c,n=Math.sin(e),i=Math.cos(e),a=1-i,t[0]=o*o*a+i,t[1]=s*o*a+l*n,t[2]=l*o*a-s*n,t[3]=0,t[4]=o*s*a-l*n,t[5]=s*s*a+i,t[6]=l*s*a+o*n,t[7]=0,t[8]=o*l*a+s*n,t[9]=s*l*a-o*n,t[10]=l*l*a+i,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],284:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,f=n*l,h=n*c,p=i*l,d=i*c,g=a*c,m=o*s,v=o*l,y=o*c;return t[0]=1-(p+g),t[1]=f+y,t[2]=h-v,t[3]=0,t[4]=f-y,t[5]=1-(u+g),t[6]=d+m,t[7]=0,t[8]=h+v,t[9]=d-m,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],285:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=e[1],t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=e[2],t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],286:[function(t,e,r){e.exports=function(t,e){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=e[0],t[13]=e[1],t[14]=e[2],t[15]=1,t}},{}],287:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=n,t[6]=r,t[7]=0,t[8]=0,t[9]=-r,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],288:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=0,t[2]=-r,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=r,t[9]=0,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],289:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=0,t[4]=-r,t[5]=n,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],290:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(r-e),l=1/(i-n),c=1/(a-o);return t[0]=2*a*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=2*a*l,t[6]=0,t[7]=0,t[8]=(r+e)*s,t[9]=(i+n)*l,t[10]=(o+a)*c,t[11]=-1,t[12]=0,t[13]=0,t[14]=o*a*2*c,t[15]=0,t}},{}],291:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],292:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),copy:t(\"./copy\"),identity:t(\"./identity\"),transpose:t(\"./transpose\"),invert:t(\"./invert\"),adjoint:t(\"./adjoint\"),determinant:t(\"./determinant\"),multiply:t(\"./multiply\"),translate:t(\"./translate\"),scale:t(\"./scale\"),rotate:t(\"./rotate\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),fromRotation:t(\"./fromRotation\"),fromRotationTranslation:t(\"./fromRotationTranslation\"),fromScaling:t(\"./fromScaling\"),fromTranslation:t(\"./fromTranslation\"),fromXRotation:t(\"./fromXRotation\"),fromYRotation:t(\"./fromYRotation\"),fromZRotation:t(\"./fromZRotation\"),fromQuat:t(\"./fromQuat\"),frustum:t(\"./frustum\"),perspective:t(\"./perspective\"),perspectiveFromFieldOfView:t(\"./perspectiveFromFieldOfView\"),ortho:t(\"./ortho\"),lookAt:t(\"./lookAt\"),str:t(\"./str\")}},{\"./adjoint\":277,\"./clone\":278,\"./copy\":279,\"./create\":280,\"./determinant\":281,\"./fromQuat\":282,\"./fromRotation\":283,\"./fromRotationTranslation\":284,\"./fromScaling\":285,\"./fromTranslation\":286,\"./fromXRotation\":287,\"./fromYRotation\":288,\"./fromZRotation\":289,\"./frustum\":290,\"./identity\":291,\"./invert\":293,\"./lookAt\":294,\"./multiply\":295,\"./ortho\":296,\"./perspective\":297,\"./perspectiveFromFieldOfView\":298,\"./rotate\":299,\"./rotateX\":300,\"./rotateY\":301,\"./rotateZ\":302,\"./scale\":303,\"./str\":304,\"./translate\":305,\"./transpose\":306}],293:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t}},{}],294:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g=e[0],m=e[1],v=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],T=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(m-w)<1e-6&&Math.abs(v-T)<1e-6)return n(t);f=g-_,h=m-w,p=v-T,d=1/Math.sqrt(f*f+h*h+p*p),a=x*(p*=d)-b*(h*=d),o=b*(f*=d)-y*p,s=y*h-x*f,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=h*s-p*o,c=p*a-f*s,u=f*o-h*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=f,t[3]=0,t[4]=o,t[5]=c,t[6]=h,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*m+s*v),t[13]=-(l*g+c*m+u*v),t[14]=-(f*g+h*m+p*v),t[15]=1,t}},{\"./identity\":291}],295:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}},{}],296:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],297:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],298:[function(t,e,r){e.exports=function(t,e,r,n){var i=Math.tan(e.upDegrees*Math.PI/180),a=Math.tan(e.downDegrees*Math.PI/180),o=Math.tan(e.leftDegrees*Math.PI/180),s=Math.tan(e.rightDegrees*Math.PI/180),l=2/(o+s),c=2/(i+a);return t[0]=l,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=c,t[6]=0,t[7]=0,t[8]=-(o-s)*l*.5,t[9]=(i-a)*c*.5,t[10]=n/(r-n),t[11]=-1,t[12]=0,t[13]=0,t[14]=n*r/(r-n),t[15]=0,t}},{}],299:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E=n[0],C=n[1],L=n[2],I=Math.sqrt(E*E+C*C+L*L);if(Math.abs(I)<1e-6)return null;E*=I=1/I,C*=I,L*=I,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],f=e[4],h=e[5],p=e[6],d=e[7],g=e[8],m=e[9],v=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,T=C*C*o+a,k=L*C*o+E*i,M=E*L*o+C*i,A=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+f*b+g*_,t[1]=l*x+h*b+m*_,t[2]=c*x+p*b+v*_,t[3]=u*x+d*b+y*_,t[4]=s*w+f*T+g*k,t[5]=l*w+h*T+m*k,t[6]=c*w+p*T+v*k,t[7]=u*w+d*T+y*k,t[8]=s*M+f*A+g*S,t[9]=l*M+h*A+m*S,t[10]=c*M+p*A+v*S,t[11]=u*M+d*A+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],300:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t}},{}],301:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-f*n,t[3]=l*i-h*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+f*i,t[11]=l*n+h*i,t}},{}],302:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t}},{}],303:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],304:[function(t,e,r){e.exports=function(t){return\"mat4(\"+t[0]+\", \"+t[1]+\", \"+t[2]+\", \"+t[3]+\", \"+t[4]+\", \"+t[5]+\", \"+t[6]+\", \"+t[7]+\", \"+t[8]+\", \"+t[9]+\", \"+t[10]+\", \"+t[11]+\", \"+t[12]+\", \"+t[13]+\", \"+t[14]+\", \"+t[15]+\")\"}},{}],305:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]);return t}},{}],306:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],307:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}e.exports=function(t,e,r,a,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),f=0;f<t.length;++f)u[f]=o(t[f],r,a,l,c);var h=0,p=1/0;for(f=0;f<u.length;++f){for(var d=0,g=0;g<2;++g)d+=Math.pow(u[f][g]-e[g],2);d<p&&(p=d,h=f)}var m=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),v=0;for(f=0;f<3;++f){if(m[f]<-.001||m[f]>1.0001)return null;v+=m[f]}if(Math.abs(v-1)>.001)return null;return[h,s(t,m),m]}},{barycentric:78,\"polytope-closest-point/lib/closest_point_2d.js\":525}],308:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:h,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:310}],309:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),m=d.meshShader,v=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function T(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,T,k,M,A,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=h,this.triangleUVs=f,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=m,this.edgeUVs=v,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=T,this.pointSizes=k,this.pointIds=b,this.pointVAO=M,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=A,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var k=T.prototype;function M(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function A(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}function S(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}function E(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function L(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function I(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}k.isOpaque=function(){return!this.hasAlpha},k.isTransparent=function(){return this.hasAlpha},k.pickSlots=1,k.setPickBase=function(t){this.pickId=t},k.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],g=n[f][1],m=i[f],v=1-m,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=m*y[b]+v*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},k.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=f({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*M(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],h=[],p=[],d=[],g=[],m=[],v=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,T=t.cellNormals,k=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!T&&(T=s.faceNormals(r,n,A)),T||w||(w=s.vertexNormals(r,n,k));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,I=t.vertexIntensity,P=t.cellUVs,z=t.cellIntensity,O=1/0,D=-1/0;if(!L&&!P)if(I)if(t.vertexIntensityBounds)O=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<I.length;++R){var F=I[R];O=Math.min(O,F),D=Math.max(D,F)}else if(z)if(t.cellIntensityBounds)O=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<z.length;++R){F=z[R];O=Math.min(O,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];O=Math.min(O,F),D=Math.max(D,F)}this.intensity=I||(z||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n)),this.pickVertex=!(z||E);var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;v.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],g.push(Z[0],Z[1]),m.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),(X=S?S[W]:E?E[R]:C)?this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)):a.push(.5,.5,.5,1),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],c.push(Z[0],Z[1]),J=w?w[W]:T[R],l.push(J[0],J[1],J[2]),h.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(v),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(m)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(h))}},k.drawTransparent=k.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},k.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},k.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],f=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:f}}var h=g(i,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!h)return null;var p=h[2],d=0;for(a=0;a<r.length;++a)d+=p[a]*this.intensity[r[a]];return{position:h[1],index:r[h[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[h[0]]]}},k.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\");if(!r)throw new Error(\"derivatives not supported\");var n=A(t),s=S(t),l=E(t),c=C(t),f=L(t),h=I(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:m,type:t.FLOAT,size:2},{buffer:v,type:t.FLOAT,size:3}]),b=i(t),_=i(t),w=i(t),k=i(t),M=a(t,[{buffer:b,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),P=i(t),z=i(t),O=i(t),D=i(t),R=i(t),F=a(t,[{buffer:P,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:O,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=a(t,[{buffer:B,type:t.FLOAT,size:3}]),j=new T(t,p,n,s,l,c,f,h,d,y,g,m,v,x,b,k,_,w,M,P,R,z,O,D,F,B,N);return j.update(e),j}},{\"./lib/closest-point\":307,\"./lib/shaders\":308,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,normals:498,\"simplicial-complex-contour\":556,\"typedarray-pool\":595}],310:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],311:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],312:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,f,h,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],f=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,h=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var m=a[g],v=a[g+2]-m,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*v/x,c[g]=2*(m-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){f[0]=f[1]=0,f[g]=1,r.uniforms.dataAxis=f,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=h[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,f=this.ticks,h=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,m=s.pixelRatio,v=s.screenBox,y=v[2]-v[0],x=v[3]-v[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var T=p[w],k=p[w+2]-T,M=.5*(d[w+2]+d[w]),A=d[w+2]-d[w];e[w]=2*k/A,t[w]=2*(T-M)/A}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,I=6*f[0].length,P=Math.min(a.ge(f[0],(d[0]-p[0])/(p[2]-p[0]),l),f[0].length),z=Math.min(a.gt(f[0],(d[2]-p[0])/(p[2]-p[0]),l),f[0].length),O=0+6*P,D=6*Math.max(0,z-P),R=Math.min(a.ge(f[1],(d[1]-p[1])/(p[3]-p[1]),l),f[1].length),F=Math.min(a.gt(f[1],(d[3]-p[1])/(p[3]-p[1]),l),f[1].length),B=I+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*m/y,o[1]=C[1]*m/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*m/y,o[1]=E[0]*m/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*m/y,o[1]=C[3]*m/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*m/y,o[1]=E[2]*m/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D))}}(),d.update=(h=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],f=0;f<l.length;++f){var d=(l[f].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=h[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335}],313:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],314:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:316}],315:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,f,h,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],f=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,h=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,m=e.tickColor,v=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],T=this.labelCount[t],k=o.lt(n,l[t]),M=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(h[2+t]-h[t])-1;var A=2/h[2+(1^t)]-h[1^t];u[1^t]=A*s[1^t]-1,d[t]&&(u[1^t]-=A*p*g[t],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t],r.uniforms.angle=v[t],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t]&&T&&(u[1^t]-=A*p*x[t],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,T)),u[1^t]=A*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=A*p*g[t+2],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t+2],r.uniforms.angle=v[t+2],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t+2]&&T&&(u[1^t]+=A*p*x[t+2],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,T))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(h=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],f=a[o],g=a[o+2]-f,m=i[o],v=i[o+2]-m;p[o]=2*l/u*g/v,h[o]=2*(s-c)/u*g/v}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=h,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],f=[-1/0],h=l[o];for(e=0;e<h.length;++e){var p=h[e],d=p.x,g=p.text,m=p.font||\"sans-serif\";i=p.fontSize||12;for(var v=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(m,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*v);u.push(Math.floor(s.length/3)),f.push(d)}this.tickOffset[o]=u,this.tickX[o]=f}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"text-cache\":575}],316:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],317:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function f(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var f=this.zeroLineEnable,h=this.zeroLineColor,p=this.zeroLineWidth;if(f[0]||f[1]){o.bind();for(var d=0;d<2;++d)if(f[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],h[d]):o.drawLine(e[0],g,e[2],g,p[d],h[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var m=this.borderLineEnable,v=this.borderLineWidth,y=this.borderLineColor;for(m[1]&&o.drawLine(r[0],r[1]-.5*v[1]*i,r[0],r[3]+.5*v[3]*i,v[1],y[1]),m[0]&&o.drawLine(r[0]-.5*v[0]*i,r[1],r[2]+.5*v[2]*i,r[1],v[0],y[0]),m[3]&&o.drawLine(r[2],r[1]-.5*v[1]*i,r[2],r[3]+.5*v[3]*i,v[3],y[3]),m[2]&&o.drawLine(r[0]-.5*v[0]*i,r[3],r[2]+.5*v[2]*i,r[3],v[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var f=c[u].pick(a,o,l);if(f)return f}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t)||!!t.titleEnable,this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(f),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":311,\"./lib/grid\":312,\"./lib/line\":313,\"./lib/text\":315,\"gl-select-static\":334}],318:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],f=0,h=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===h&&t.clientHeight===p;return h=t.clientWidth,p=t.clientHeight,a?!l:(f=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return f},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",(function(t){return t.preventDefault(),!1})),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,h=!!a.control,p=!!a.alt,g=!!a.shift,m=!!(1&e),v=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,T=d.flipY?1:-1,k=Math.PI*d.rotateSpeed,M=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&m&&!h&&!p&&!g||m&&!h&&!p&&g)&&c.rotate(M,w*k*b,-T*k*_,0),(l&&m&&!h&&!p&&!g||v||m&&h&&!p&&!g)&&c.pan(M,-d.translateSpeed*b*f,d.translateSpeed*_*f,0),u&&m&&!h&&!p&&!g||y||m&&!h&&p&&!g)){var A=-d.zoomSpeed*_/window.innerHeight*(M-c.lastT())*100;c.pan(M,0,0,f*(Math.exp(A)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",(function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods)}),!!l&&{passive:!0}),t.addEventListener(\"touchmove\",(function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchend\",(function(t){e(0,d._lastX,d._lastY,d._lastMods)}),!!l&&{passive:!0}),d.wheelListener=o(t,(function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,f*(Math.exp(o)-1))}}}),!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":54,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486,\"right-now\":542}],319:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":335,glslify:320}],320:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],321:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),f=t(\"gl-mat4/perspective\"),h=t(\"gl-mat4/ortho\"),p=t(\"./lib/shader\"),d=t(\"is-mobile\")({tablet:!0,featureDetect:!0});function g(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function v(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e){if(e=document.createElement(\"canvas\"),t.container)t.container.appendChild(e);else document.body.appendChild(e)}var r=t.gl;r||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),r=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!r)throw new Error(\"webgl not supported\");var y=t.bounds||[[-10,-10,-10],[10,10,10]],x=new g,b=l(r,r.drawingBufferWidth,r.drawingBufferHeight,{preferFloat:!d}),_=p(r),w=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:w},k=t.axes||{},M=i(r,k);M.enable=!k.disable;var A=t.spikes||{},S=o(r,A),E=[],C=[],L=[],I=[],P=!0,z=!0,O=new Array(16),D=new Array(16),R={view:null,projection:O,model:D,_ortho:!1},F=(z=!0,[r.drawingBufferWidth,r.drawingBufferHeight]),B=t.cameraObject||n(e,T),N={gl:r,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:x,camera:B,axes:M,axesPixels:null,spikes:S,bounds:y,objects:E,shape:F,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:v(t.autoResize),autoBounds:v(t.autoBounds),autoScale:!!t.autoScale,autoCenter:v(t.autoCenter),clipToBounds:v(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:R,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,z=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},j=[r.drawingBufferWidth/N.pixelRatio|0,r.drawingBufferHeight/N.pixelRatio|0];function U(){if(!N._stopped&&N.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*N.pixelRatio),a=0|Math.ceil(n*N.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",P=!0}}}N.autoResize&&U();function V(){for(var t=E.length,e=I.length,n=0;n<e;++n)L[n]=0;t:for(n=0;n<t;++n){var i=E[n],a=i.pickSlots;if(a){for(var o=0;o<e;++o)if(L[o]+a<255){C[n]=o,i.setPickBase(L[o]+1),L[o]+=a;continue t}var l=s(r,F);C[n]=e,I.push(l),L.push(a),i.setPickBase(1),e+=1}else C[n]=-1}for(;e>0&&0===L[e-1];)L.pop(),I.pop().dispose()}function q(){if(N.contextLost)return!0;r.isContextLost()&&(N.contextLost=!0,N.mouseListener.enabled=!1,N.selection.object=null,N.oncontextloss&&N.oncontextloss())}window.addEventListener(\"resize\",U),N.update=function(t){N._stopped||(t=t||{},P=!0,z=!0)},N.add=function(t){N._stopped||(t.axes=M,E.push(t),C.push(-1),P=!0,z=!0,V())},N.remove=function(t){if(!N._stopped){var e=E.indexOf(t);e<0||(E.splice(e,1),C.pop(),P=!0,z=!0,V())}},N.dispose=function(){if(!N._stopped&&(N._stopped=!0,window.removeEventListener(\"resize\",U),e.removeEventListener(\"webglcontextlost\",q),N.mouseListener.enabled=!1,!N.contextLost)){M.dispose(),S.dispose();for(var t=0;t<E.length;++t)E[t].dispose();b.dispose();for(t=0;t<I.length;++t)I[t].dispose();_.dispose(),r=null,M=null,S=null,E=[]}},N._mouseRotating=!1,N._prevButtons=0,N.enableMouseListeners=function(){N.mouseListener=u(e,(function(t,e,r){if(!N._stopped){var n=I.length,i=E.length,a=x.object;x.distance=1/0,x.mouse[0]=e,x.mouse[1]=r,x.object=null,x.screen=null,x.dataCoordinate=x.dataPosition=null;var o=!1;if(t&&N._prevButtons)N._mouseRotating=!0;else{N._mouseRotating&&(z=!0),N._mouseRotating=!1;for(var s=0;s<n;++s){var l=I[s].query(e,j[1]-r-1,N.pickRadius);if(l){if(l.distance>x.distance)continue;for(var c=0;c<i;++c){var u=E[c];if(C[c]===s){var f=u.pick(l);f&&(x.buttons=t,x.screen=l.coord,x.distance=l.distance,x.object=u,x.index=f.distance,x.dataPosition=f.position,x.dataCoordinate=f.dataCoordinate,x.data=f,o=!0)}}}}}a&&a!==x.object&&(a.highlight&&a.highlight(null),P=!0),x.object&&(x.object.highlight&&x.object.highlight(x.data),P=!0),(o=o||x.object!==a)&&N.onselect&&N.onselect(x),1&t&&!(1&N._prevButtons)&&N.onclick&&N.onclick(x),N._prevButtons=t}}))},e.addEventListener(\"webglcontextlost\",q);var H=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],G=[H[0].slice(),H[1].slice()];function Y(){if(!q()){U();var t=N.camera.tick();R.view=N.camera.matrix,P=P||t,z=z||t,M.pixelRatio=N.pixelRatio,S.pixelRatio=N.pixelRatio;var e=E.length,n=H[0],i=H[1];n[0]=n[1]=n[2]=1/0,i[0]=i[1]=i[2]=-1/0;for(var o=0;o<e;++o){(L=E[o]).pixelRatio=N.pixelRatio,L.axes=N.axes,P=P||!!L.dirty,z=z||!!L.dirty;var s=L.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)n[p]=Math.min(n[p],l[p]),i[p]=Math.max(i[p],u[p])}var d=N.bounds;if(N.autoBounds)for(p=0;p<3;++p){if(i[p]<n[p])n[p]=-1,i[p]=1;else{n[p]===i[p]&&(n[p]-=1,i[p]+=1);var g=.05*(i[p]-n[p]);n[p]=n[p]-g,i[p]=i[p]+g}d[0][p]=n[p],d[1][p]=i[p]}var v=!1;for(p=0;p<3;++p)v=v||G[0][p]!==d[0][p]||G[1][p]!==d[1][p],G[0][p]=d[0][p],G[1][p]=d[1][p];if(z=z||v,P=P||v){if(v){var y=[0,0,0];for(o=0;o<3;++o)y[o]=m((d[1][o]-d[0][o])/10);M.autoTicks?M.update({bounds:d,tickSpacing:y}):M.update({bounds:d})}var T=r.drawingBufferWidth,k=r.drawingBufferHeight;F[0]=T,F[1]=k,j[0]=0|Math.max(T/N.pixelRatio,1),j[1]=0|Math.max(k/N.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,i=n.projection,a=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(h(i,-p,p,-1,1,l,c),n._ortho=!0):(f(i,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)a[d]=0;a[15]=1;var g=0;for(d=0;d<3;++d)g=Math.max(g,r[1][d]-r[0][d]);for(d=0;d<3;++d)t.autoScale?a[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):a[5*d]=1/g,t.autoCenter&&(a[12+d]=.5*-a[5*d]*(r[0][d]+r[1][d]))}(N,w);for(o=0;o<e;++o){(L=E[o]).axesBounds=d,N.clipToBounds&&(L.clipBounds=d)}x.object&&(N.snapToData?S.position=x.dataCoordinate:S.position=x.dataPosition,S.bounds=d),z&&(z=!1,function(){if(!q()){r.colorMask(!0,!0,!0,!0),r.depthMask(!0),r.disable(r.BLEND),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL);for(var t=E.length,e=I.length,n=0;n<e;++n){var i=I[n];i.shape=j,i.begin();for(var a=0;a<t;++a)if(C[a]===n){var o=E[a];o.drawPick&&(o.pixelRatio=1,o.drawPick(R))}i.end()}}}()),N.axesPixels=a(N.axes,R,T,k),N.onrender&&N.onrender(),r.bindFramebuffer(r.FRAMEBUFFER,null),r.viewport(0,0,T,k),N.clearRGBA(),r.depthMask(!0),r.colorMask(!0,!0,!0,!0),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL),r.disable(r.BLEND),r.disable(r.CULL_FACE);var A=!1;M.enable&&(A=A||M.isTransparent(),M.draw(R)),S.axes=M,x.object&&S.draw(R),r.disable(r.CULL_FACE);for(o=0;o<e;++o){(L=E[o]).axes=M,L.pixelRatio=N.pixelRatio,L.isOpaque&&L.isOpaque()&&L.draw(R),L.isTransparent&&L.isTransparent()&&(A=!0)}if(A){b.shape=F,b.bind(),r.clear(r.DEPTH_BUFFER_BIT),r.colorMask(!1,!1,!1,!1),r.depthMask(!0),r.depthFunc(r.LESS),M.enable&&M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){(L=E[o]).isOpaque&&L.isOpaque()&&L.draw(R)}r.enable(r.BLEND),r.blendEquation(r.FUNC_ADD),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.colorMask(!0,!0,!0,!0),r.depthMask(!1),r.clearColor(0,0,0,0),r.clear(r.COLOR_BUFFER_BIT),M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){var L;(L=E[o]).isTransparent&&L.isTransparent()&&L.drawTransparent(R)}r.bindFramebuffer(r.FRAMEBUFFER,null),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.disable(r.DEPTH_TEST),_.bind(),b.color[0].bind(0),_.uniforms.accumBuffer=0,c(r),r.disable(r.BLEND)}P=!1;for(o=0;o<e;++o)E[o].dirty=!1}}}return N.enableMouseListeners(),function t(){if(N._stopped||N.contextLost)return;Y(),requestAnimationFrame(t)}(),N.redraw=function(){N._stopped||(P=!0,Y())},N},createCamera:n}},{\"./camera.js\":318,\"./lib/shader\":319,\"a-big-triangle\":64,\"gl-axes3d\":250,\"gl-axes3d/properties\":258,\"gl-fbo\":269,\"gl-mat4/ortho\":296,\"gl-mat4/perspective\":297,\"gl-select-static\":334,\"gl-spikes3d\":345,\"is-mobile\":467,\"mouse-change\":483}],322:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:323}],323:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],324:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),f=new s(t,a,l,c,u);return f.update(e),t.addObject(f),f};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var f=n.getParameter(n.BLEND),h=n.getParameter(n.DITHER);return f&&!this.blend&&n.disable(n.BLEND),h&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),f&&!this.blend&&n.enable(n.BLEND),h&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":322,\"gl-buffer\":259,\"gl-shader\":335,\"typedarray-pool\":595}],325:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],f=e[2],h=e[3],p=r[0],d=r[1],g=r[2],m=r[3];(a=c*p+u*d+f*g+h*m)<0&&(a=-a,p=-p,d=-d,g=-g,m=-m);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*f+l*g,t[3]=s*h+l*m,t}},{}],326:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],327:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var f=[[1/0,1/0],[-1/0,-1/0]],h=u.positions.length;for(l=0;l<h;++l){var p=u.positions[l];for(c=0;c<2;++c)f[0][c]=Math.min(f[0][c],p[c]),f[1][c]=Math.max(f[1][c],p[c])}return a[t]=[s,u,f]};var i={}},{\"vectorize-text\":600}],328:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],f={vertex:a,fragment:l,attributes:u},h={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},m={vertex:s,fragment:c,attributes:u};function v(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return v(t,f)},r.createOrtho=function(t){return v(t,h)},r.createProject=function(t){return v(t,p)},r.createPickPerspective=function(t){return v(t,d)},r.createPickOrtho=function(t){return v(t,g)},r.createPickProject=function(t){return v(t,m)}},{\"gl-shader\":335,glslify:329}],329:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],330:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return h(n,n),h(n,n),h(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t||t>1?1:t}function m(t,e,r,n,i,a,o,s,l,c,u,f){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=f,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),f=i(e),h=i(e),p=i(e),d=i(e),g=a(e,[{buffer:f,size:3,type:e.FLOAT},{buffer:h,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),v=new m(e,r,n,o,f,h,p,d,g,s,c,u);return v.update(t),v};var v=m.prototype;v.pickSlots=1,v.setPickBase=function(t){this.pickId=t},v.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},v.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],T=f.slice(),k=[0,0,0],M=[[0,0,0],[0,0,0]];function A(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||f,u=r.view||f,h=r.projection||f,d=e.axesBounds,g=function(t){for(var e=M,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=h,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var m=0;m<3;++m)if(a[m]){l.scale=e.projectScale[m],l.opacity=e.projectOpacity[m];for(var v=T,C=0;C<16;++C)v[C]=0;for(C=0;C<4;++C)v[5*C]=1;v[5*m]=0,i[m]<0?v[12+m]=d[0][m]:v[12+m]=d[1][m],s(v,c,v),l.model=v;var L=(m+1)%3,I=(m+2)%3,P=A(x),z=A(b);P[L]=1,z[I]=1;var O=p(0,0,0,S(_,P)),D=p(0,0,0,S(w,z));if(Math.abs(O[1])>Math.abs(D[1])){var R=O;O=D,D=R,R=P,P=z,z=R;var F=L;L=I,I=F}O[0]<0&&(P[L]=-1),D[1]>0&&(z[I]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*I+C],2);P[L]/=Math.sqrt(B),z[I]/=Math.sqrt(N),l.axes[0]=P,l.axes[1]=z,l.fragClipBounds[0]=E(k,g[0],m,-1e8),l.fragClipBounds[1]=E(k,g[1],m,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function I(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||f,l.view=n.view||f,l.projection=n.projection||f,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function P(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}v.draw=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},v.drawTransparent=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},v.drawPick=function(t){I(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},v.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},v.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},v.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],f=[-1/0,-1/0,-1/0],h=t.glyph,p=t.color,d=t.size,m=t.angle,v=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],T=0;T<3;++T)if(isNaN(w[T])||!isFinite(w[T]))continue t;var k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;x+=3*k.cells.length,b+=2*M.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),I=o.mallocUint32(S);if(S>0){var z=0,O=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(v)&&Array.isArray(v[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],T=0;T<3;++T){if(isNaN(w[T])||!isFinite(w[T]))continue t;f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T])}k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(T=0;T<3;++T)D[T]=U[T];D[3]=1}else if(4===U.length){for(T=0;T<4;++T)D[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(v)){var U;if(3===(U=B?n<v.length?v[n]:[0,0,0,0]:v).length){for(T=0;T<3;++T)R[T]=U[T];R[T]=1}else if(4===U.length){for(T=0;T<4;++T)R[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(m)?q=n<m.length?+m[n]:0:m&&(q=+m);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],T=0;T<3;++T)f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-A[0][0]:Y<0?1+A[1][0]:1,W*=W>0?1-A[0][1]:W<0?1+A[1][1]:1],Z=k.cells||[],J=k.positions||[];for(T=0;T<Z.length;++T)for(var K=Z[T],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)C[4*z+$]=D[$];I[z]=y;var tt=J[K[Q]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=M.edges,J=M.positions,T=0;T<Z.length;++T)for(K=Z[T],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*O+$]=w[$];for($=0;$<4;++$)C[4*O+$]=R[$];I[O]=y;tt=J[K[Q]];L[2*O]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*O+1]=V*(G*tt[0]+H*tt[1]+X[1]),O+=1}}}this.bounds=[u,f],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(I),o.free(E),o.free(C),o.free(L),o.free(I)},v.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":326,\"./lib/glyphs\":327,\"./lib/shaders\":328,\"gl-buffer\":259,\"gl-mat4/multiply\":295,\"gl-vao\":358,\"is-string-blank\":470,\"typedarray-pool\":595}],331:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:332}],332:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],333:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,f=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],h=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(f=Math.max(f,c[0]),h=Math.max(h,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<f||d<h)){o.bind();var g=s[2]-s[0],m=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,h,i),o.drawBox(0,h,f,d,i),o.drawBox(0,d,g,m,i),o.drawBox(p,h,g,d,i)),this.innerFill&&o.drawBox(f,h,p,d,n),r>0){var v=r*u;o.drawBox(f-v,h-v,p+v,h+v,a),o.drawBox(f-v,d-v,p+v,d+v,a),o.drawBox(f-v,h-v,f+v,d+v,a),o.drawBox(p-v,h-v,p+v,d+v,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":331,\"gl-buffer\":259,\"gl-shader\":335}],334:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=e[0],a=e[1],o=n(t,r,a,{}),s=i.mallocUint8(r*a*4);return new l(t,o,s)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2;function s(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function l(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var c=l.prototype;Object.defineProperty(c,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),c.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},c.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},c.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),l=0|Math.min(Math.max(e-r,0),n[1]),c=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||c<=l)return null;var u=[o-i,c-l],f=a(this.buffer,[u[0],u[1],4],[4,4*n[0],1],4*(i+n[0]*l)),h=function(t,e,r){for(var n=1e8,i=-1,a=-1,o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++){var u=t.get(l,c,0),f=t.get(l,c,1),h=t.get(l,c,2),p=t.get(l,c,3);if(u<255||f<255||h<255||p<255){var d=e-l,g=r-c,m=d*d+g*g;m<n&&(n=m,i=l,a=c)}}return[i,a,n]}(f.hi(u[0],u[1],1),r,r),p=h[0],d=h[1];return p<0||Math.pow(this.radius,2)<h[2]?null:new s(p+i|0,d+l|0,f.get(p,d,0),[f.get(p,d,1),f.get(p,d,2),f.get(p,d,3)],Math.sqrt(h[2]))},c.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":97,\"gl-fbo\":269,ndarray:495,\"typedarray-pool\":595}],335:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function f(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var h=this,p=h.gl,d=h._vref;h._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),h.vertShader=h._vref.shader;var g=this._fref;if(h._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),h.fragShader=h._fref.shader,!r||!c){var m=p.createProgram();if(p.attachShader(m,h.fragShader),p.attachShader(m,h.vertShader),p.linkProgram(m),!p.getProgramParameter(m,p.LINK_STATUS)){var v=p.getProgramInfoLog(m);throw new l(v,\"Error linking program:\"+v)}r=r||s.uniforms(p,m),c=c||s.attributes(p,m),p.deleteProgram(m)}(c=c.slice()).sort(f);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var T=0|w.type.charAt(w.type.length-1),k=new Array(T),M=0;M<T;++M)k[M]=_.length,b.push(w.name+\"[\"+M+\"]\"),\"number\"==typeof w.location?_.push(w.location+M):Array.isArray(w.location)&&w.location.length===T&&\"number\"==typeof w.location[M]?_.push(0|w.location[M]):_.push(-1);x.push({name:w.name,type:w.type,locations:k})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var A=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(A)>=0;)A+=1;_[y]=A}var S=new Array(r.length);function E(){h.program=o.program(p,h._vref,h._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(h.program,r[t].name)}E(),h._relink=E,h.types={uniforms:a(r),attributes:a(c)},h.attributes=i(p,h,x,_),Object.defineProperty(h,\"uniforms\",n(p,h,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":336,\"./lib/create-attributes\":337,\"./lib/create-uniforms\":338,\"./lib/reflect\":339,\"./lib/runtime-reflect\":340,\"./lib/shader-cache\":341}],336:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],337:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],f=u.name,h=u.type,p=u.locations;switch(h){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,f);break;default:if(h.indexOf(\"vec\")>=0){if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);o(t,e,p[0],i,d,a,f)}else{if(!(h.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+f+\": \"+h);var d;if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);s(t,e,p,i,d,a,f)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var f=Function.apply(null,l),h=new i(t,e,r,n,a,f);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),f(t,n[r],e),e},get:function(){return h},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var f=new Array(i),h=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))h.call(t,o,e[a]);else{for(var s=0;s<i;++s)f[s]=e[i*a+s];h.call(t,o,f)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":336}],338:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a;if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}return n.push(\"return obj}\"),new Function(\"gl\",\"locations\",n.join(\"\\n\"))(t,s)}function u(n,l,u){if(\"object\"==typeof u){var h=f(u);Object.defineProperty(n,l,{get:a(h),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r;if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function f(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var h=n(r,!0);return{get:a(f(h)),set:c(h),enumerable:!0,configurable:!0}}},{\"./GLError\":336,\"./reflect\":339}],339:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name.split(\".\"),a=r,o=0;o<i.length;++o){var s=i[o].split(\"[\");if(s.length>1){s[0]in a||(a[s[0]]=[]),a=a[s[0]];for(var l=1;l<s.length;++l){var c=parseInt(s[l]);l<s.length-1||o<i.length-1?(c in a||(l<s.length-1?a[c]=[]:a[c]={}),a=a[c]):a[c]=e?n:t[n].type}}else o<i.length-1?(s[0]in a||(a[s[0]]={}),a=a[s[0]]):a[s[0]]=e?n:t[n].type}return r}},{}],340:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],341:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":336,\"gl-format-compiler-error\":270,\"weakmap-shim\":605}],342:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map((function(t){return t.slice()})),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],343:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],344:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":335,glslify:343}],345:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var f=new s(t,l,c,u);return f.update(e),f};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],f=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var h=c,p=u,d=0;d<3;++d)i&&i[d]<0?(h[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(h[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);f[0]=e.drawingBufferWidth,f[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,h,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=f;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":344,\"gl-buffer\":259,\"gl-vao\":358}],346:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, tubeScale;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:347}],347:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],348:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"],o=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map((function(t){return function(t,e,r,a){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],f=[],h=[],p=[],d=[],g=0,m=0,v=i.create(),y=i.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),m=n.length(_)/a,v=i.create(),n.copy(v,_),v[3]=w;for(var T=0;T<8;T++)p[T]=[b[0],b[1],b[2],T];if(h.length>0)for(T=0;T<8;T++){var k=(T+1)%8;c.push(h[T],p[T],p[k],p[k],h[k],h[T]),f.push(y,v,v,v,y,y),d.push(g,m,m,m,g,g);var M=c.length;u.push([M-6,M-5,M-4],[M-3,M-2,M-1])}var A=h;h=p,p=A;var S=y;y=v,v=S;var E=g;g=m,m=E}return{positions:c,cells:u,vectors:f,vertexIntensity:d}}(t,r,a,o)})),f=[],h=[],p=[],d=[];for(s=0;s<u.length;s++){var g=u[s],m=f.length;f=f.concat(g.positions),p=p.concat(g.vectors),d=d.concat(g.vertexIntensity);for(c=0;c<g.cells.length;c++){var v=g.cells[c],y=[];h.push(y);for(var x=0;x<v.length;x++)y.push(v[x]+m)}}return{positions:f,cells:h,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var i=t[r];if(i===e)return r;if(i>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort((function(t,e){return t-e}));for(var r=t.length,n=1;n<r;n++){var i=Math.abs(t[n]-t[n-1]);i<e&&(e=i)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,u=t.tubeSize||1,f=t.absoluteTubeSize,h=t.gridFill||\"+x+y+z\",p={};-1!==h.indexOf(\"-x\")&&(p.reversedX=!0),-1!==h.indexOf(\"-y\")&&(p.reversedY=!0),-1!==h.indexOf(\"-z\")&&(p.reversedZ=!0),p.filled=a.indexOf(h.replace(/-/g,\"\").replace(/\\+/g,\"\"));var d=t.getVelocity||function(e){return function(t,e,r){var i=e.vectors,a=e.meshgrid,o=t[0],c=t[1],u=t[2],f=a[0].length,h=a[1].length,p=a[2].length,d=s(a[0],o),g=s(a[1],c),m=s(a[2],u),v=d+1,y=g+1,x=m+1;if(d=l(d,0,f-1),v=l(v,0,f-1),g=l(g,0,h-1),y=l(y,0,h-1),m=l(m,0,p-1),x=l(x,0,p-1),d<0||g<0||m<0||v>f-1||y>h-1||x>p-1)return n.create();var b,_,w,T,k,M,A=a[0][d],S=a[0][v],E=a[1][g],C=a[1][y],L=a[2][m],I=(o-A)/(S-A),P=(c-E)/(C-E),z=(u-L)/(a[2][x]-L);switch(isFinite(I)||(I=.5),isFinite(P)||(P=.5),isFinite(z)||(z=.5),r.reversedX&&(d=f-1-d,v=f-1-v),r.reversedY&&(g=h-1-g,y=h-1-y),r.reversedZ&&(m=p-1-m,x=p-1-x),r.filled){case 5:k=m,M=x,w=g*p,T=y*p,b=d*p*h,_=v*p*h;break;case 4:k=m,M=x,b=d*p,_=v*p,w=g*p*f,T=y*p*f;break;case 3:w=g,T=y,k=m*h,M=x*h,b=d*h*p,_=v*h*p;break;case 2:w=g,T=y,b=d*h,_=v*h,k=m*h*f,M=x*h*f;break;case 1:b=d,_=v,k=m*f,M=x*f,w=g*f*p,T=y*f*p;break;default:b=d,_=v,w=g*f,T=y*f,k=m*f*h,M=x*f*h}var O=i[b+w+k],D=i[b+w+M],R=i[b+T+k],F=i[b+T+M],B=i[_+w+k],N=i[_+w+M],j=i[_+T+k],U=i[_+T+M],V=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(V,O,B,I),n.lerp(q,D,N,I),n.lerp(H,R,j,I),n.lerp(G,F,U,I);var Y=n.create(),W=n.create();n.lerp(Y,V,H,P),n.lerp(W,q,G,P);var X=n.create();return n.lerp(X,Y,W,z),X}(e,t,p)},g=t.getDivergence||function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=d(r);n.subtract(a,a,e),n.scale(a,a,1/i),n.add(r,t,[0,i,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1/i),n.add(r,t,[0,0,i]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1/i),n.add(r,a,o),n.add(r,r,s),r},m=[],v=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],T=function(t){var e=t[0],r=t[1],n=t[2];return!(e<v||e>b||r<y||r>_||n<x||n>w)},k=10*n.distance(e[0],e[1])/i,M=k*k,A=1,S=0,E=r.length;E>1&&(A=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=t.length,l=0;l<s;l++){var u=t[l],f=u[0],h=u[1],p=u[2];i[f]||(e.push(f),i[f]=!0),a[h]||(r.push(h),a[h]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),g=c(r),m=c(n),v=Math.min(d,g,m);return isFinite(v)?v:1}(r));for(var C=0;C<E;C++){var L=n.create();n.copy(L,r[C]);var I=[L],P=[],z=d(L),O=L;P.push(z);var D=[],R=g(L,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),m.push({points:I,velocities:P,divergences:D});for(var B=0;B<100*i&&I.length<i&&T(L);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;if(j>M&&n.scale(N,N,k/Math.sqrt(j)),n.add(N,N,L),z=d(N),n.squaredDistance(O,N)-M>-1e-4*M){I.push(N),O=N,P.push(z);R=g(N,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}L=N}}var U=o(m,t.colormap,S,A);return f?U.tubeScale=f:(0===S&&(S=1),U.tubeScale=.5*u*A/S),U};var u=t(\"./lib/shaders\"),f=t(\"gl-cone3d\").createMesh;e.exports.createTubeMesh=function(t,e){return f(t,e,{shaders:u,traceType:\"streamtube\"})}},{\"./lib/shaders\":346,\"gl-cone3d\":260,\"gl-vec3\":377,\"gl-vec4\":413}],349:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if (\\n    kill > 0.0 ||\\n    vColor.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\\n  ) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":335,glslify:350}],350:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],351:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:40,offset:0},{buffer:c,size:3,stride:40,offset:16},{buffer:c,size:3,stride:40,offset:28}]),f=i(e),h=a(e,[{buffer:f,size:4,stride:20,offset:0},{buffer:f,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,256,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var m=new A(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,f,h,p,d,[0,0,0]),v={levels:[[],[],[]]};for(var w in t)v[w]=t[w];return v.colormap=v.colormap||\"jet\",m.update(v),m};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),f=t(\"ndarray\"),h=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),m=t(\"ndarray-gradient\"),v=t(\"./lib/shaders\"),y=v.createShader,x=v.createContourShader,b=v.createPickShader,_=v.createPickContourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],k=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=k[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();function A(t,e,r,n,i,a,o,l,c,u,h,p,d,g,m){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=m,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=h,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var S=A.prototype;S.genColormap=function(t,e){var r=!1,n=u([l({colormap:t,nshades:256,format:\"rgba\"}).map((function(t,n){var i=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(n/255,e):t[3];return i<1&&(r=!0),[t[0],t[1],t[2],255*i]}))]);return c.divseq(n,255),this.hasAlphaScale=r,n},S.isTransparent=function(){return this.opacity<1||this.hasAlphaScale},S.isOpaque=function(){return!this.isTransparent()},S.pickSlots=1,S.setPickBase=function(t){this.pickId=t};var E=[0,0,0],C={showSurface:!1,showContour:!1,projections:[w.slice(),w.slice(),w.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function L(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||E,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=C.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=C.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return C.showSurface=o,C.showContour=s,C}var I={model:w,view:w,projection:w,inverseModel:w.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},P=w.slice(),z=[1,0,0,0,1,0,0,0,1];function O(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=I;n.model=t.model||w,n.view=t.view||w,n.projection=t.projection||w,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=z,n.vertexColor=this.vertexColor;var s=P;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=L(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var f=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,f.bind(),f.uniforms=n;var h=this._contourVAO;for(h.bind(),i=0;i<3;++i)for(f.uniforms.permutation=k[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(f.uniforms.contourColor=this.highlightColor[i],f.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(f.uniforms.contourColor=this.contourColor[i],f.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(f.uniforms.height=this.contourLevels[i][o],h.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(f.uniforms.model=u.projections[i],f.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){f.uniforms.permutation=k[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(f.uniforms.contourColor=this.highlightColor[o],f.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(f.uniforms.contourColor=this.contourColor[o],f.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(f.uniforms.height=this.contourLevels[o][g],h.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(h.unbind(),(h=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(f.uniforms.model=n.model,f.uniforms.clipBounds=n.clipBounds,f.uniforms.permutation=k[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),f.uniforms.contourColor=this.dynamicColor[i],f.uniforms.contourTint=this.dynamicTint[i],f.uniforms.height=this.dynamicLevel[i],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(f.uniforms.model=u.projections[o],f.uniforms.clipBounds=u.clipBounds[o],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));h.unbind()}}S.draw=function(t){return O.call(this,t,!1)},S.drawTransparent=function(t){return O.call(this,t,!0)};var D={model:w,view:w,projection:w,inverseModel:w,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function R(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function F(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function B(t){if(Array.isArray(t)){if(Array.isArray(t))return[F(t[0]),F(t[1]),F(t[2])];var e=F(t);return[e.slice(),e.slice(),e.slice()]}}S.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=D;r.model=t.model||w,r.view=t.view||w,r.projection=t.projection||w,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=z;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=L(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=k[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=k[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},S.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var f=u?a:1-a,h=0;h<2;++h)for(var p=i+u,d=s+h,m=f*(h?l:1-l),v=0;v<3;++v)c[v]+=this._field[v].get(p,d)*m;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],v=0;v<3;++v)r.dataCoordinate[v]=this._field[v].get(r.index[0],r.index[1]);return r},S.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},S.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=R(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=R(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=R(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=B(t.contourColor)),\"contourProject\"in t&&(this.contourProject=R(t.contourProject,(function(t){return R(t,Boolean)}))),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=B(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=R(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=R(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0),\"colormap\"in t&&this._colorMap.setPixels(this.genColormap(t.colormap,this.opacityscale));var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=f(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var l=t.coords;if(!Array.isArray(l)||3!==l.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var c=l[o];for(v=0;v<2;++v)if(c.shape[v]!==a[v])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],c)}}else if(t.ticks){var u=t.ticks;if(!Array.isArray(u)||2!==u.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var p=u[o];if((Array.isArray(p)||p.length)&&(p=f(p)),p.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var d=f(p.data,a);d.stride[o]=p.stride[0],d.stride[1^o]=0,this.padField(this._field[o],d)}}else{for(o=0;o<2;++o){var g=[0,0];g[o]=1,this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2],g,0)}this._field[0].set(0,0,0);for(var v=0;v<a[0];++v)this._field[0].set(v+1,0,v);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),v=0;v<a[1];++v)this._field[1].set(0,v+1,v);this._field[1].set(0,a[1]+1,a[1]-1)}var y=this._field,x=f(s.mallocFloat(3*y[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)m(x.pick(o),y[o],\"mirror\");var b=f(s.mallocFloat(3*y[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(v=0;v<a[1]+2;++v){var _=x.get(0,o,v,0),w=x.get(0,o,v,1),k=x.get(1,o,v,0),M=x.get(1,o,v,1),A=x.get(2,o,v,0),S=x.get(2,o,v,1),E=k*S-M*A,C=A*w-S*_,L=_*M-w*k,I=Math.sqrt(E*E+C*C+L*L);I<1e-8?(I=Math.max(Math.abs(E),Math.abs(C),Math.abs(L)))<1e-8?(L=1,C=E=0,I=1):I=1/I:I=1/Math.sqrt(I),b.set(o,v,0,E*I),b.set(o,v,1,C*I),b.set(o,v,2,L*I)}s.free(x.data);var P=[1/0,1/0,1/0],z=[-1/0,-1/0,-1/0],O=1/0,D=-1/0,F=(a[0]-1)*(a[1]-1)*6,N=s.mallocFloat(n.nextPow2(10*F)),j=0,U=0;for(o=0;o<a[0]-1;++o)t:for(v=0;v<a[1]-1;++v){for(var V=0;V<2;++V)for(var q=0;q<2;++q)for(var H=0;H<3;++H){var G=this._field[H].get(1+o+V,1+v+q);if(isNaN(G)||!isFinite(G))continue t}for(H=0;H<6;++H){var Y=o+T[H][0],W=v+T[H][1],X=this._field[0].get(Y+1,W+1),Z=this._field[1].get(Y+1,W+1);G=this._field[2].get(Y+1,W+1),E=b.get(Y+1,W+1,0),C=b.get(Y+1,W+1,1),L=b.get(Y+1,W+1,2),t.intensity&&(J=t.intensity.get(Y,W));var J=t.intensity?t.intensity.get(Y,W):G+this.objectOffset[2];N[j++]=Y,N[j++]=W,N[j++]=X,N[j++]=Z,N[j++]=G,N[j++]=0,N[j++]=J,N[j++]=E,N[j++]=C,N[j++]=L,P[0]=Math.min(P[0],X+this.objectOffset[0]),P[1]=Math.min(P[1],Z+this.objectOffset[1]),P[2]=Math.min(P[2],G+this.objectOffset[2]),O=Math.min(O,J),z[0]=Math.max(z[0],X+this.objectOffset[0]),z[1]=Math.max(z[1],Z+this.objectOffset[1]),z[2]=Math.max(z[2],G+this.objectOffset[2]),D=Math.max(D,J),U+=1}}for(t.intensityBounds&&(O=+t.intensityBounds[0],D=+t.intensityBounds[1]),o=6;o<j;o+=10)N[o]=(N[o]-O)/(D-O);this._vertexCount=U,this._coordinateBuffer.update(N.subarray(0,j)),s.freeFloat(N),s.free(b.data),this.bounds=[P,z],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===O&&this.intensityBounds[1]===D||(r=!0),this.intensityBounds=[O,D]}if(\"levels\"in t){var K=t.levels;for(K=Array.isArray(K[0])?K.slice():[[],[],K],o=0;o<3;++o)K[o]=K[o].slice(),K[o].sort((function(t,e){return t-e}));for(o=0;o<3;++o)for(v=0;v<K[o].length;++v)K[o][v]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(K[o].length!==this.contourLevels[o].length){r=!0;break}for(v=0;v<K[o].length;++v)if(K[o][v]!==this.contourLevels[o][v]){r=!0;break t}}this.contourLevels=K}if(r){y=this._field,a=this.shape;for(var Q=[],$=0;$<3;++$){var tt=this.contourLevels[$],et=[],rt=[],nt=[0,0,0];for(o=0;o<tt.length;++o){var it=h(this._field[$],tt[o]);et.push(Q.length/5|0),U=0;t:for(v=0;v<it.cells.length;++v){var at=it.cells[v];for(H=0;H<2;++H){var ot=it.positions[at[H]],st=ot[0],lt=0|Math.floor(st),ct=st-lt,ut=ot[1],ft=0|Math.floor(ut),ht=ut-ft,pt=!1;e:for(var dt=0;dt<3;++dt){nt[dt]=0;var gt=($+dt+1)%3;for(V=0;V<2;++V){var mt=V?ct:1-ct;for(Y=0|Math.min(Math.max(lt+V,0),a[0]),q=0;q<2;++q){var vt=q?ht:1-ht;if(W=0|Math.min(Math.max(ft+q,0),a[1]),G=dt<2?this._field[gt].get(Y,W):(this.intensity.get(Y,W)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(G)||isNaN(G)){pt=!0;break e}var yt=mt*vt;nt[dt]+=yt*G}}}if(pt){if(H>0){for(var xt=0;xt<5;++xt)Q.pop();U-=1}continue t}Q.push(nt[0],nt[1],ot[0],ot[1],nt[2]),U+=1}}rt.push(U)}this._contourOffsets[$]=et,this._contourCounts[$]=rt}var bt=s.mallocFloat(Q.length);for(o=0;o<Q.length;++o)bt[o]=Q[o];this._contourBuffer.update(bt),s.freeFloat(bt)}},S.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},S.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],f=this._field[l],p=this._field[c],d=h(u,r[o]),g=d.cells,m=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var v=g[e],y=0;y<2;++y){var x=m[v[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),T=b-_,k=1-T,M=+x[1],A=0|M,S=0|Math.min(A+1,i[1]),E=M-A,C=1-E,L=k*C,I=k*E,P=T*C,z=T*E,O=L*f.get(_,A)+I*f.get(_,S)+P*f.get(w,A)+z*f.get(w,S),D=L*p.get(_,A)+I*p.get(_,S)+P*p.get(w,A)+z*p.get(w,S);if(isNaN(O)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=O,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":349,\"binary-search-bounds\":96,\"bit-twiddle\":97,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,\"ndarray-gradient\":488,\"ndarray-ops\":490,\"ndarray-pack\":491,\"surface-nets\":570,\"typedarray-pool\":595}],352:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),f=t(\"parse-rect\"),h=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),m=t(\"object-assign\"),v=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var T=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(h(t)?t:{})};T.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(T.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(T.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},T.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map((function(t){return parseFloat(t)})):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=f(t.viewport),T.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=T.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach((function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(T.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:T.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=T.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:v(c,{origin:\"top\",fontSize:T.baseFontSize,fontStyle:u.join(\" \")})},T.fonts[i]=e.font[r]}})),(a||o)&&this.font.forEach((function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)})),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),h=0;h<s.length;h++)s[h]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach((function(t,n){T.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=T.atlasContext.measureText(o).width/T.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);m(t.kerning,g(t.family,{pairs:s}))}}}))}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,k=u.mallocFloat(2*this.count),M=0,A=0;M<this.counts.length;M++){var S=this.counts[M];if(w)for(var E=0;E<S;E++)k[A++]=t.position[2*M],k[A++]=t.position[2*M+1];else for(var C=0;C<S;C++)k[A++]=t.position[M][0],k[A++]=t.position[M][1]}this.position.call?this.position({type:\"float\",data:k}):this.position=this.regl.buffer({type:\"float\",data:k}),u.freeFloat(k)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),I=u.mallocFloat(2*this.count);this.textWidth=[];for(var P=0,z=0;P<this.counts.length;P++){for(var O=this.counts[P],D=this.font[P]||this.font[0],R=this.fontAtlas[P]||this.fontAtlas[0],F=0;F<O;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],I[2*z]=D.width[B],F){var j=I[2*z-2],U=I[2*z],V=I[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}I[2*z+1]=V}else I[2*z+1]=.5*I[2*z];z++}this.textWidth.push(I.length?.5*I[2*z-2]+I[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:I,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(I),r.length&&this.font.forEach((function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(T.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:T.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})}))}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map((function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0}))),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map((function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],T.normalViewport||(i*=-1),i}))),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},T.prototype.destroy=function(){},T.prototype.kerning=!0,T.prototype.position={constant:new Float32Array(2)},T.prototype.translate=null,T.prototype.scale=null,T.prototype.font=null,T.prototype.text=\"\",T.prototype.positionOffset=[0,0],T.prototype.opacity=1,T.prototype.color=new Uint8Array([0,0,0,255]),T.prototype.alignOffset=[0,0],T.normalViewport=!1,T.maxAtlasSize=1024,T.atlasCanvas=document.createElement(\"canvas\"),T.atlasContext=T.atlasCanvas.getContext(\"2d\",{alpha:!1}),T.baseFontSize=64,T.fonts={},e.exports=T},{\"bit-twiddle\":97,\"color-normalize\":125,\"css-font\":144,\"detect-kerning\":172,\"es6-weak-map\":233,\"flatten-vertex-data\":244,\"font-atlas\":245,\"font-measure\":246,\"gl-util/context\":354,\"is-plain-obj\":469,\"object-assign\":499,\"parse-rect\":504,\"parse-unit\":506,\"pick-by-alias\":511,regl:540,\"to-px\":578,\"typedarray-pool\":595}],353:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||c(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=u(e)?e:e.raw;if(r)return y(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return x(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}function u(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var f=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function p(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var d=p.prototype;function g(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function m(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new p(t,o,e,r,n,i)}function y(t,e,r,n,i,a){var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new p(t,o,r,n,i,a)}function x(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=g(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var u,h,d=0;if(2===o.length)d=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])d=t.ALPHA;else if(2===o[2])d=t.LUMINANCE_ALPHA;else if(3===o[2])d=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");d=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var v=e.size;if(l)u=0===e.offset&&e.data.length===v?e.data:e.data.subarray(e.offset,e.offset+v);else{var y=[o[2],o[2]*o[0],1];h=a.malloc(v,r);var x=n(h,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):f(x,e),u=h.subarray(0,v)}var b=m(t);return t.texImage2D(t.TEXTURE_2D,0,d,o[0],o[1],0,d,c,u),l||a.free(h),new p(t,b,o[0],o[1],d,c)}Object.defineProperties(d,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),d.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},d.dispose=function(){this.gl.deleteTexture(this.handle)},d.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},d.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=u(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,u){var h=u.dtype,p=u.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var d=0,m=0,v=g(p,u.stride.slice());\"float32\"===h?d=t.FLOAT:\"float64\"===h?(d=t.FLOAT,v=!1,h=\"float32\"):\"uint8\"===h?d=t.UNSIGNED_BYTE:(d=t.UNSIGNED_BYTE,v=!1,h=\"uint8\");if(2===p.length)m=t.LUMINANCE,p=[p[0],p[1],1],u=n(u.data,p,[u.stride[0],u.stride[1],1],u.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])m=t.ALPHA;else if(2===p[2])m=t.LUMINANCE_ALPHA;else if(3===p[2])m=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");m=t.RGBA}p[2]}m!==t.LUMINANCE&&m!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(m=s);if(m!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=u.size,x=c.indexOf(o)<0;x&&c.push(o);if(d===l&&v)0===u.offset&&u.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data.subarray(u.offset,u.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data.subarray(u.offset,u.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);d===t.FLOAT&&l===t.UNSIGNED_BYTE?f(_,u):i.assign(_,u),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],354:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":511}],355:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,f=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,f)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else{t.bindBuffer(t.ARRAY_BUFFER,null);for(i=0;i<n;++i)t.disableVertexAttribArray(i)}}},{}],356:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":355}],357:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":355}],358:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":356,\"./lib/vao-native.js\":357}],359:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],360:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":370,\"./fromValues\":376,\"./normalize\":387}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],363:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],364:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],365:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],366:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":367}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],368:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":369}],369:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],370:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],371:[function(t,e,r){e.exports=1e-6},{}],372:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":371}],373:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],374:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],375:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":364}],376:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],377:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":359,\"./angle\":360,\"./ceil\":361,\"./clone\":362,\"./copy\":363,\"./create\":364,\"./cross\":365,\"./dist\":366,\"./distance\":367,\"./div\":368,\"./divide\":369,\"./dot\":370,\"./epsilon\":371,\"./equals\":372,\"./exactEquals\":373,\"./floor\":374,\"./forEach\":375,\"./fromValues\":376,\"./inverse\":378,\"./len\":379,\"./length\":380,\"./lerp\":381,\"./max\":382,\"./min\":383,\"./mul\":384,\"./multiply\":385,\"./negate\":386,\"./normalize\":387,\"./random\":388,\"./rotateX\":389,\"./rotateY\":390,\"./rotateZ\":391,\"./round\":392,\"./scale\":393,\"./scaleAndAdd\":394,\"./set\":395,\"./sqrDist\":396,\"./sqrLen\":397,\"./squaredDistance\":398,\"./squaredLength\":399,\"./sub\":400,\"./subtract\":401,\"./transformMat3\":402,\"./transformMat4\":403,\"./transformQuat\":404}],378:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],379:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":380}],380:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],382:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],383:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],384:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":385}],385:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],386:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],387:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],388:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],389:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],390:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],391:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],392:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],393:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],395:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],396:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":398}],397:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":399}],398:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],399:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],400:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":401}],401:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],402:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],403:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],404:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t}},{}],405:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],406:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],407:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],408:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],409:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],410:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],411:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],412:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],413:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":405,\"./clone\":406,\"./copy\":407,\"./create\":408,\"./distance\":409,\"./divide\":410,\"./dot\":411,\"./fromValues\":412,\"./inverse\":414,\"./length\":415,\"./lerp\":416,\"./max\":417,\"./min\":418,\"./multiply\":419,\"./negate\":420,\"./normalize\":421,\"./random\":422,\"./scale\":423,\"./scaleAndAdd\":424,\"./set\":425,\"./squaredDistance\":426,\"./squaredLength\":427,\"./subtract\":428,\"./transformMat4\":429,\"./transformQuat\":430}],414:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],415:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],416:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],417:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],418:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],419:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],420:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],421:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],422:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":421,\"./scale\":423}],423:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],424:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],425:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],426:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],427:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],428:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],429:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],430:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t[3]=e[3],t}},{}],431:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":77,\"glsl-tokenizer\":438}],432:[function(t,e,r){e.exports=function(t){var e,r,c,u=0,f=0,h=999,p=[],d=[],g=1,m=0,v=0,y=!1,x=!1,b=\"\",_=a,w=n;\"300 es\"===(t=t||{}).version&&(_=s,w=o);var T={},k={};for(u=0;u<_.length;u++)T[_[u]]=!0;for(u=0;u<w.length;u++)k[w[u]]=!0;return function(t){return d=[],null!==t?function(t){u=0,t.toString&&(t=t.toString());var r;b+=t.replace(/\\r\\n/g,\"\\n\"),c=b.length;for(;e=b[u],u<c;){switch(r=u,h){case 0:u=C();break;case 1:case 2:u=E();break;case 3:u=L();break;case 4:u=z();break;case 11:u=P();break;case 5:u=O();break;case 9999:u=D();break;case 9:u=S();break;case 999:u=A()}if(r!==u)switch(b[r]){case\"\\n\":m=0,++g;break;default:++m}}return f+=u,b=b.slice(u),d}(t):function(t){p.length&&M(p.join(\"\"));return h=10,M(\"(eof)\"),d}()};function M(t){t.length&&d.push({type:l[h],data:t,position:v,line:g,column:m})}function A(){return p=p.length?[]:p,\"/\"===r&&\"*\"===e?(v=f+u-1,h=0,r=e,u+1):\"/\"===r&&\"/\"===e?(v=f+u-1,h=1,r=e,u+1):\"#\"===e?(h=2,v=f+u,u):/\\s/.test(e)?(h=9,v=f+u,u):(y=/\\d/.test(e),x=/[^\\w_]/.test(e),v=f+u,h=y?4:x?3:9999,u)}function S(){return/[^\\s]/g.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function E(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(p.push(e),r=e,u+1):(M(p.join(\"\")),h=999,u)}function C(){return\"/\"===e&&\"*\"===r?(p.push(e),M(p.join(\"\")),h=999,u+1):(p.push(e),r=e,u+1)}function L(){if(\".\"===r&&/\\d/.test(e))return h=5,u;if(\"/\"===r&&\"*\"===e)return h=0,u;if(\"/\"===r&&\"/\"===e)return h=1,u;if(\".\"===e&&p.length){for(;I(p););return h=5,u}if(\";\"===e||\")\"===e||\"(\"===e){if(p.length)for(;I(p););return M(e),h=999,u+1}var t=2===p.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;I(p););return h=999,u}return p.push(e),r=e,u+1}function I(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return M(r),v+=r.length,(p=p.slice(r.length)).length}}function P(){return/[^a-fA-F0-9]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function z(){return\".\"===e||/[eE]/.test(e)?(p.push(e),h=5,r=e,u+1):\"x\"===e&&1===p.length&&\"0\"===p[0]?(h=11,p.push(e),r=e,u+1):/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function O(){return\"f\"===e&&(p.push(e),r=e,u+=1),/[eE]/.test(e)?(p.push(e),r=e,u+1):(\"-\"!==e&&\"+\"!==e||!/[eE]/.test(r))&&/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function D(){if(/[^\\d\\w_]/.test(e)){var t=p.join(\"\");return h=k[t]?8:T[t]?7:6,M(p.join(\"\")),h=999,u}return p.push(e),r=e,u+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":434,\"./lib/builtins-300es\":433,\"./lib/literals\":436,\"./lib/literals-300es\":435,\"./lib/operators\":437}],433:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter((function(t){return!/^(gl\\_|texture)/.test(t)})),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":434}],434:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],435:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":436}],436:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"uint\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],437:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],438:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":432}],439:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],440:[function(t,e,r){(function(r){(function(){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":464}],441:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":464}],442:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],443:[function(t,e,r){\"use strict\";var n=t(\"./types\");e.exports=function(t,e){var r;for(r in n)if(n[r].detect(t,e))return r}},{\"./types\":446}],444:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"path\"),a=t(\"./types\"),o=t(\"./detector\");function s(t,e){var r=o(t,e);if(r in a){var n=a[r].calculate(t,e);if(!1!==n)return n.type=r,n}throw new TypeError(\"unsupported file type: \"+r+\" (file: \"+e+\")\")}e.exports=function(t,e){if(r.isBuffer(t))return s(t);if(\"string\"!=typeof t)throw new TypeError(\"invalid invocation\");var a=i.resolve(t);if(\"function\"!=typeof e)return s(function(t){var e=n.openSync(t,\"r\"),i=n.fstatSync(e).size,a=Math.min(i,524288),o=r.alloc(a);return n.readSync(e,o,0,a,0),n.closeSync(e),o}(a),a);!function(t,e){n.open(t,\"r\",(function(i,a){if(i)return e(i);n.fstat(a,(function(i,o){if(i)return e(i);var s=o.size;if(s<=0)return e(new Error(\"File size is not greater than 0 \\u2014\\u2014 \"+t));var l=Math.min(s,524288),c=r.alloc(l);n.read(a,c,0,l,0,(function(t){if(t)return e(t);n.close(a,(function(t){e(t,c)}))}))}))}))}(a,(function(t,r){if(t)return e(t);var n;try{n=s(r,a)}catch(e){t=e}e(t,n)}))},e.exports.types=Object.keys(a)}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"./detector\":443,\"./types\":446,buffer:111,fs:109,path:507}],445:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){return r=r||0,t[\"readUInt\"+e+(n?\"BE\":\"LE\")].call(t,r)}},{}],446:[function(t,e,r){\"use strict\";var n={bmp:t(\"./types/bmp\"),cur:t(\"./types/cur\"),dds:t(\"./types/dds\"),gif:t(\"./types/gif\"),icns:t(\"./types/icns\"),ico:t(\"./types/ico\"),jpg:t(\"./types/jpg\"),png:t(\"./types/png\"),psd:t(\"./types/psd\"),svg:t(\"./types/svg\"),tiff:t(\"./types/tiff\"),webp:t(\"./types/webp\")};e.exports=n},{\"./types/bmp\":447,\"./types/cur\":448,\"./types/dds\":449,\"./types/gif\":450,\"./types/icns\":451,\"./types/ico\":452,\"./types/jpg\":453,\"./types/png\":454,\"./types/psd\":455,\"./types/svg\":456,\"./types/tiff\":457,\"./types/webp\":458}],447:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"BM\"===t.toString(\"ascii\",0,2)},calculate:function(t){return{width:t.readUInt32LE(18),height:Math.abs(t.readInt32LE(22))}}}},{}],448:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&2===t.readUInt16LE(2)},calculate:t(\"./ico\").calculate}},{\"./ico\":452}],449:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 542327876===t.readUInt32LE(0)},calculate:function(t){return{height:t.readUInt32LE(12),width:t.readUInt32LE(16)}}}},{}],450:[function(t,e,r){\"use strict\";var n=/^GIF8[79]a/;e.exports={detect:function(t){var e=t.toString(\"ascii\",0,6);return n.test(e)},calculate:function(t){return{width:t.readUInt16LE(6),height:t.readUInt16LE(8)}}}},{}],451:[function(t,e,r){\"use strict\";var n={ICON:32,\"ICN#\":32,\"icm#\":16,icm4:16,icm8:16,\"ics#\":16,ics4:16,ics8:16,is32:16,s8mk:16,icp4:16,icl4:32,icl8:32,il32:32,l8mk:32,icp5:32,ic11:32,ich4:48,ich8:48,ih32:48,h8mk:48,icp6:64,ic12:32,it32:128,t8mk:128,ic07:128,ic08:256,ic13:256,ic09:512,ic14:512,ic10:1024};function i(t,e){var r=e+4;return[t.toString(\"ascii\",e,r),t.readUInt32BE(r)]}function a(t){var e=n[t];return{width:e,height:e,type:t}}e.exports={detect:function(t){return\"icns\"===t.toString(\"ascii\",0,4)},calculate:function(t){var e,r,n,o=t.length,s=8,l=t.readUInt32BE(4);if(r=a((e=i(t,s))[0]),(s+=e[1])===l)return r;for(n={width:r.width,height:r.height,images:[r]};s<l&&s<o;)r=a((e=i(t,s))[0]),s+=e[1],n.images.push(r);return n}}},{}],452:[function(t,e,r){\"use strict\";function n(t,e){var r=t.readUInt8(e);return 0===r?256:r}function i(t,e){var r=6+16*e;return{width:n(t,r),height:n(t,r+1)}}e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&1===t.readUInt16LE(2)},calculate:function(t){var e,r=t.readUInt16LE(4),n=i(t,0);if(1===r)return n;for(n.images=[{width:n.width,height:n.height}],e=1;e<r;e+=1)n.images.push(i(t,e));return n}}},{}],453:[function(t,e,r){\"use strict\";var n=t(\"../readUInt\");function i(t){return\"45786966\"===t.toString(\"hex\",2,6)}function a(t,e){return{height:t.readUInt16BE(e),width:t.readUInt16BE(e+2)}}function o(t,e){var r=t.slice(2,e),i=r.toString(\"hex\",6,8),a=\"4d4d\"===i;if(a||\"4949\"===i)return function(t,e){for(var r,i,a=n(t,16,14,e),o=0;o<a;o++){if(i=(r=16+12*o)+12,r>t.length)return;var s=t.slice(r,i);if(274===n(s,16,0,e)){if(3!==n(s,16,2,e))return;if(1!==n(s,32,4,e))return;return n(s,16,8,e)}}}(r,a)}function s(t,e){if(e>t.length)throw new TypeError(\"Corrupt JPG, exceeded buffer limits\");if(255!==t[e])throw new TypeError(\"Invalid JPG, marker table corrupted\")}e.exports={detect:function(t){return\"ffd8\"===t.toString(\"hex\",0,2)},calculate:function(t){var e,r,n;for(t=t.slice(4);t.length;){if(r=t.readUInt16BE(0),i(t)&&(e=o(t,r)),s(t,r),192===(n=t[r+1])||193===n||194===n){var l=a(t,r+5);return e?{width:l.width,height:l.height,orientation:e}:l}t=t.slice(r+2)}throw new TypeError(\"Invalid JPG, no size found\")}}},{\"../readUInt\":445}],454:[function(t,e,r){\"use strict\";e.exports={detect:function(t){if(\"PNG\\r\\n\\x1a\\n\"===t.toString(\"ascii\",1,8)){var e=t.toString(\"ascii\",12,16);if(\"CgBI\"===e&&(e=t.toString(\"ascii\",28,32)),\"IHDR\"!==e)throw new TypeError(\"invalid png\");return!0}},calculate:function(t){return\"CgBI\"===t.toString(\"ascii\",12,16)?{width:t.readUInt32BE(32),height:t.readUInt32BE(36)}:{width:t.readUInt32BE(16),height:t.readUInt32BE(20)}}}},{}],455:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"8BPS\"===t.toString(\"ascii\",0,4)},calculate:function(t){return{width:t.readUInt32BE(18),height:t.readUInt32BE(14)}}}},{}],456:[function(t,e,r){\"use strict\";var n=/<svg\\s([^>\"']|\"[^\"]*\"|'[^']*')*>/;var i={root:n,width:/\\swidth=(['\"])([^%]+?)\\1/,height:/\\sheight=(['\"])([^%]+?)\\1/,viewbox:/\\sviewBox=(['\"])(.+?)\\1/},a={cm:96/2.54,mm:96/2.54/10,m:96/2.54*100,pt:96/72,pc:96/72/12,em:16,ex:8};function o(t){var e=/([0-9.]+)([a-z]*)/.exec(t);if(e)return Math.round(parseFloat(e[1])*(a[e[2]]||1))}function s(t){var e=t.split(\" \");return{width:o(e[2]),height:o(e[3])}}e.exports={detect:function(t){return n.test(t)},calculate:function(t){var e=t.toString(\"utf8\").match(i.root);if(e){var r=function(t){var e=t.match(i.width),r=t.match(i.height),n=t.match(i.viewbox);return{width:e&&o(e[2]),height:r&&o(r[2]),viewbox:n&&s(n[2])}}(e[0]);if(r.width&&r.height)return function(t){return{width:t.width,height:t.height}}(r);if(r.viewbox)return function(t){var e=t.viewbox.width/t.viewbox.height;return t.width?{width:t.width,height:Math.floor(t.width/e)}:t.height?{width:Math.floor(t.height*e),height:t.height}:{width:t.viewbox.width,height:t.viewbox.height}}(r)}throw new TypeError(\"invalid svg\")}}},{}],457:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"../readUInt\");function a(t,e){var r=i(t,16,8,e);return(i(t,16,10,e)<<16)+r}function o(t){if(t.length>24)return t.slice(12)}e.exports={detect:function(t){var e=t.toString(\"hex\",0,4);return\"49492a00\"===e||\"4d4d002a\"===e},calculate:function(t,e){if(!e)throw new TypeError(\"Tiff doesn't support buffer\");var s=\"BE\"===function(t){var e=t.toString(\"ascii\",0,2);return\"II\"===e?\"LE\":\"MM\"===e?\"BE\":void 0}(t),l=function(t,e){for(var r,n,s,l={};t&&t.length&&(r=i(t,16,0,e),n=i(t,16,2,e),s=i(t,32,4,e),0!==r);)1!==s||3!==n&&4!==n||(l[r]=a(t,e)),t=o(t);return l}(function(t,e,a){var o=i(t,32,4,a),s=1024,l=n.statSync(e).size;o+s>l&&(s=l-o-10);var c=r.alloc(s),u=n.openSync(e,\"r\");return n.readSync(u,c,0,s,o),c.slice(2)}(t,e,s),s),c=l[256],u=l[257];if(!c||!u)throw new TypeError(\"Invalid Tiff, missing tags\");return{width:c,height:u}}}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"../readUInt\":445,buffer:111,fs:109}],458:[function(t,e,r){\"use strict\";e.exports={detect:function(t){var e=\"RIFF\"===t.toString(\"ascii\",0,4),r=\"WEBP\"===t.toString(\"ascii\",8,12),n=\"VP8\"===t.toString(\"ascii\",12,15);return e&&r&&n},calculate:function(t){var e=t.toString(\"ascii\",12,16);if(t=t.slice(20,30),\"VP8X\"===e){var r=t[0];return!(!(0==(192&r))||!(0==(1&r)))&&function(t){return{width:1+t.readUIntLE(4,3),height:1+t.readUIntLE(7,3)}}(t)}if(\"VP8 \"===e&&47!==t[0])return function(t){return{width:16383&t.readInt16LE(6),height:16383&t.readInt16LE(8)}}(t);var n=t.toString(\"hex\",3,6);return\"VP8L\"===e&&\"9d012a\"!==n&&function(t){return{width:1+((63&t[2])<<8|t[1]),height:1+((15&t[4])<<10|t[3]<<2|(192&t[2])>>6)}}(t)}}},{}],459:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);var f=new a(l,new Array(i+1),!1),h=f.adjacent,p=new Array(i+2);for(u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var m=d[0];d[0]=d[1],d[1]=m;var v=new a(d,new Array(i+1),!0);h[u]=v,p[u]=v}p[i+1]=f;for(u=0;u<=i;++u){d=h[u].vertices;var y=h[u].adjacent;for(g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=f;else for(var b=0;b<=i;++b)h[b].vertices.indexOf(x)<0&&(y[g]=h[b])}}var _=new c(i,o,p),w=!!e;for(u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter((function(t){return!t.boundary})),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,f=0;f<=r;++f){var h=u[f];i[f]=h<0?e:a[h]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var f=c[u];if(!(f.lastVisited>=r)){var h=a[u];a[u]=t;var p=this.orient();if(a[u]=h,p<0){s=f;continue t}f.boundary?f.lastVisited=-r:f.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,f=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var h=[];f.length>0;){var p=(e=f.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var m=0;m<=n;++m)if(m!==g){var v=d[m];if(v.boundary&&!(v.lastVisited>=r)){var y=v.vertices;if(v.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,v.boundary=!1,c.push(v),f.push(v),v.lastVisited=r;continue}v.lastVisited=-r}var _=v.adjacent,w=p.slice(),T=d.slice(),k=new a(w,T,!0);u.push(k);var M=_.indexOf(e);if(!(M<0)){_[M]=k,T[g]=v,w[m]=-1,T[m]=e,d[m]=k,k.flip();for(b=0;b<=n;++b){var A=w[b];if(!(A<0||A===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}h.push(new o(S,k,b))}}}}}}h.sort(s);for(m=0;m+1<h.length;m+=2){var I=h[m],P=h[m+1],z=I.index,O=P.index;z<0||O<0||(I.cell.adjacent[I.index]=P.cell,P.cell.adjacent[P.index]=I.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var f=o[0];o[0]=o[1],o[1]=f}e.push(o)}}return e}},{\"robust-orientation\":548,\"simplicial-complex\":558}],460:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new v(null);return new v(m(t))};var a=i.prototype;function o(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function s(t,e){var r=m(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function l(t,e){var r=t.intervals([]);r.push(e),s(t,r)}function c(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?0:(r.splice(n,1),s(t,r),1)}function u(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function f(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function h(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function p(t,e){return t-e}function d(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function g(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function m(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(p);var n=e[e.length>>1],a=[],o=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?o.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(d),u.sort(g),new i(n,m(a),m(o),c,u)}function v(t){this.root=t}a.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},a.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?l(this,t):this.left.insert(t):this.left=m([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?l(this,t):this.right.insert(t):this.right=m([t]);else{var r=n.ge(this.leftPoints,t,d),i=n.ge(this.rightPoints,t,g);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},a.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?c(this,t):2===(s=this.left.remove(t))?(this.left=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?c(this,t):2===(s=this.right.remove(t))?(this.right=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(1===this.count)return this.leftPoints[0]===t?2:0;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,i=this.left;i.right;)r=i,i=i.right;if(r===this)i.right=this.right;else{var a=this.left,s=this.right;r.count-=i.count,r.right=i.left,i.left=a,i.right=s}o(this,i),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?o(this,this.left):o(this,this.right);return 1}for(a=n.ge(this.leftPoints,t,d);a<this.leftPoints.length&&this.leftPoints[a][0]===t[0];++a)if(this.leftPoints[a]===t){this.count-=1,this.leftPoints.splice(a,1);for(s=n.ge(this.rightPoints,t,g);s<this.rightPoints.length&&this.rightPoints[s][1]===t[1];++s)if(this.rightPoints[s]===t)return this.rightPoints.splice(s,1),1}return 0},a.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return u(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return f(this.rightPoints,t,e)}return h(this.leftPoints,e)},a.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?u(this.leftPoints,e,r):t>this.mid?f(this.rightPoints,t,r):h(this.leftPoints,r)};var y=v.prototype;y.insert=function(t){this.root?this.root.insert(t):this.root=new i(t[0],null,null,[t],[t])},y.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),0!==e}return!1},y.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},y.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(y,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(y,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":461}],461:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],462:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],463:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],464:[function(t,e,r){e.exports=!0},{}],465:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}\n",
       "/*!\n",
       " * Determine if an object is a Buffer\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],466:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],467:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a,e.exports.default=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;if(e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"!=typeof e)return!1;var r=t.tablet?i.test(e):n.test(e);return!r&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==e.indexOf(\"Macintosh\")&&-1!==e.indexOf(\"Safari\")&&(r=!0),r}},{}],468:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],469:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],470:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],471:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],472:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],473:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():(t=t||self).mapboxgl=n()}(this,(function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,(function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[2]*this.x+t[3]*this.y;return this.x=t[0]*this.x+t[1]*this.y,this.y=e,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=r*this.x+e*this.y;return this.x=e*this.x-r*this.y,this.y=n,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=e.x+r*(this.x-e.x)-n*(this.y-e.y),this.y=i,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var s=o(.25,.1,.25,1);function l(t,e,r){return Math.min(r,Math.max(e,t))}function c(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function u(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function h(){return f++}function p(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function d(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function g(t,e){t.forEach((function(t){e[t]&&(e[t]=e[t].bind(e))}))}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function v(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function y(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function x(t){return Array.isArray(t)?t.map(x):\"object\"==typeof t&&t?v(t,x):t}var b={};function _(t){b[t]||(\"undefined\"!=typeof console&&console.warn(t),b[t]=!0)}function w(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)e+=((o=t[i]).x-(a=t[r]).x)*(a.y+o.y);return e}function k(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}function M(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,(function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"})),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}var A=null;function S(t){if(null==A){var e=t.navigator?t.navigator.userAgent:null;A=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return A}function E(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var C,L,I,P,z=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),O=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,D=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,R={now:z,frame:function(t){var e=O(t);return{cancel:function(){return D(e)}}},getImageData:function(t,e){void 0===e&&(e=0);var r=self.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=t.width,r.height=t.height,n.drawImage(t,0,0,t.width,t.height),n.getImageData(-e,-e,t.width+2*e,t.height+2*e)},resolveURL:function(t){return C||(C=self.document.createElement(\"a\")),C.href=t,C.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==L&&(L=self.matchMedia(\"(prefers-reduced-motion: reduce)\")),L.matches)}},F={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},B={supported:!1,testSupport:function(t){!N&&P&&(j?U(t):I=t)}},N=!1,j=!1;function U(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,P),t.isContextLost())return;B.supported=!0}catch(t){}t.deleteTexture(e),N=!0}self.document&&((P=self.document.createElement(\"img\")).onload=function(){I&&U(I),I=null,j=!0},P.onerror=function(){N=!0,I=null},P.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var V=\"01\",q=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function H(t){return 0===t.indexOf(\"mapbox:\")}q.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",V,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},q.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},q.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},q.prototype.normalizeStyleURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/styles/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeGlyphsURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/fonts/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSourceURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSpriteURL=function(t,e,r,n){var i=X(t);return H(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,this._makeAPIURL(i,this._customAccessToken||n)):(i.path+=\"\"+e+r,Z(i))},q.prototype.normalizeTileURL=function(t,e){if(this._isSkuTokenExpired()&&this._createSkuToken(),t&&!H(t))return t;var r=X(t);r.path=r.path.replace(/(\\.(png|jpg)\\d*)(?=$)/,(R.devicePixelRatio>=2||512===e?\"@2x\":\"\")+(B.supported?\".webp\":\"$1\")),r.path=r.path.replace(/^.+\\/v4\\//,\"/\"),r.path=\"/v4\"+r.path;var n=this._customAccessToken||function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e].match(/^access_token=(.*)$/);if(n)return n[1]}return null}(r.params)||F.ACCESS_TOKEN;return F.REQUIRE_ACCESS_TOKEN&&n&&this._skuToken&&r.params.push(\"sku=\"+this._skuToken),this._makeAPIURL(r,n)},q.prototype.canonicalizeTileURL=function(t,e){var r=X(t);if(!r.path.match(/(^\\/v4\\/)/)||!r.path.match(/\\.[\\w]+$/))return t;var n=\"mapbox://tiles/\";n+=r.path.replace(\"/v4/\",\"\");var i=r.params;return e&&(i=i.filter((function(t){return!t.match(/^access_token=/)}))),i.length&&(n+=\"?\"+i.join(\"&\")),n},q.prototype.canonicalizeTileset=function(t,e){for(var r=!!e&&H(e),n=[],i=0,a=t.tiles||[];i<a.length;i+=1){var o=a[i];Y(o)?n.push(this.canonicalizeTileURL(o,r)):n.push(o)}return n},q.prototype._makeAPIURL=function(t,e){var r=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\",n=X(F.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,\"/\"!==n.path&&(t.path=\"\"+n.path+t.path),!F.REQUIRE_ACCESS_TOKEN)return Z(t);if(!(e=e||F.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+r);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+r);return t.params=t.params.filter((function(t){return-1===t.indexOf(\"access_token\")})),t.params.push(\"access_token=\"+e),Z(t)};var G=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function Y(t){return G.test(t)}var W=/^(\\w+):\\/\\/([^/?]*)(\\/[^?]+)?\\??(.+)?/;function X(t){var e=t.match(W);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function Z(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function J(t){if(!t)return null;var e=t.split(\".\");if(!e||3!==e.length)return null;try{return JSON.parse(decodeURIComponent(self.atob(e[1]).split(\"\").map((function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)})).join(\"\")))}catch(t){return null}}var K=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};K.prototype.getStorageKey=function(t){var e,r=J(F.ACCESS_TOKEN);return e=r&&r.u?self.btoa(encodeURIComponent(r.u).replace(/%([0-9A-F]{2})/g,(function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):F.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+e:\"mapbox.eventData:\"+e},K.prototype.fetchEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){_(\"Unable to read from LocalStorage\")}},K.prototype.saveEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){_(\"Unable to write to LocalStorage\")}},K.prototype.processRequests=function(t){},K.prototype.postEvent=function(t,e,r,n){var i=this;if(F.EVENTS_URL){var a=X(F.EVENTS_URL);a.params.push(\"access_token=\"+(n||F.ACCESS_TOKEN||\"\"));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.10.1\",skuId:V,userId:this.anonId},s=e?u(o,e):o,l={url:Z(a),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([s])};this.pendingRequest=xt(l,(function(t){i.pendingRequest=null,r(t),i.saveEventData(),i.processRequests(n)}))}},K.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var Q,$,tt=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(F.EVENTS_URL&&n||F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)})))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,i=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),d(this.anonId)||(this.anonId=p()),this.postEvent(i,{skuToken:this.skuToken},(function(t){t||n&&(e.success[n]=!0)}),t))}},e}(K),et=new(function(t){function e(e){t.call(this,\"appUserTurnstile\"),this._customAccessToken=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postTurnstileEvent=function(t,e){F.EVENTS_URL&&F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)}))&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=J(F.ACCESS_TOKEN),n=r?r.u:F.ACCESS_TOKEN,i=n!==this.eventData.tokenU;d(this.anonId)||(this.anonId=p(),i=!0);var a=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(a),l=(a-this.eventData.lastSuccess)/864e5;i=i||l>=1||l<-1||o.getDate()!==s.getDate()}else i=!0;if(!i)return this.processRequests();this.postEvent(a,{\"enabled.telemetry\":!1},(function(t){t||(e.eventData.lastSuccess=a,e.eventData.tokenU=n)}),t)}},e}(K)),rt=et.postTurnstileEvent.bind(et),nt=new tt,it=nt.postMapLoadEvent.bind(nt),at=500,ot=50;function st(){self.caches&&!Q&&(Q=self.caches.open(\"mapbox-tiles\"))}function lt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var ct,ut=1/0;function ft(){return null==ct&&(ct=self.OffscreenCanvas&&new self.OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof self.createImageBitmap),ct}var ht={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(ht);var pt,dt,gt=function(t){function e(e,r,n){401===r&&Y(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error),mt=k()?function(){return self.worker&&self.worker.referrer}:function(){return(\"blob:\"===self.location.protocol?self.parent:self).location.href},vt=function(t,e){if(!(/^file:/.test(r=t.url)||/^file:/.test(mt())&&!/^\\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return function(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:mt(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&Y(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&_(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then((function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new gt(r.statusText,r.status,t.url))})).catch((function(t){20!==t.code&&e(new Error(t.message))}))}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then((function(t){o||(n&&s&&function(t,e,r){if(st(),Q){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach((function(t,e){return n.headers.set(e,t)}));var i=M(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<42e4||function(t,e){if(void 0===$)try{new Response(new ReadableStream),$=!0}catch(t){$=!1}$?e(t.body):t.blob().then(e)}(e,(function(e){var r=new self.Response(e,n);st(),Q&&Q.then((function(e){return e.put(lt(t.url),r)})).catch((function(t){return _(t.message)}))})))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))})).catch((function(t){o||e(new Error(t.message))}))};return s?function(t,e){if(st(),!Q)return e(null);var r=lt(t.url);Q.then((function(t){t.match(r).then((function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")||0),r=M(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})).catch(e)})).catch(e)}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}(t,e);if(k()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e,void 0,!0)}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&(r.responseType=\"text\",r.setRequestHeader(\"Accept\",\"application/json\")),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new gt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},yt=function(t,e){return vt(u(t,{type:\"arrayBuffer\"}),e)},xt=function(t,e){return vt(u(t,{method:\"POST\"}),e)};pt=[],dt=0;var bt=function(t,e){if(B.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),dt>=F.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return pt.push(r),r}dt++;var n=!1,i=function(){if(!n)for(n=!0,dt--;pt.length&&dt<F.MAX_PARALLEL_IMAGE_REQUESTS;){var t=pt.shift();t.cancelled||(t.cancel=bt(t.requestParameters,t.callback).cancel)}},a=yt(t,(function(t,r,n,a){i(),t?e(t):r&&(ft()?function(t,e){var r=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});self.createImageBitmap(r).then((function(t){e(null,t)})).catch((function(t){e(new Error(\"Could not load image because of \"+t.message+\". Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))}))}(r,e):function(t,e,r,n){var i=new self.Image,a=self.URL;i.onload=function(){e(null,i),a.revokeObjectURL(i.src)},i.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var o=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});i.cacheControl=r,i.expires=n,i.src=t.byteLength?a.createObjectURL(o):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}(r,e,n,a))}));return{cancel:function(){a.cancel(),i()}}};function _t(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function wt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Tt=function(t,e){void 0===e&&(e={}),u(this,e),this.type=t},kt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",u({error:e},r))}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Tt),Mt=function(){};Mt.prototype.on=function(t,e){return this._listeners=this._listeners||{},_t(t,e,this._listeners),this},Mt.prototype.off=function(t,e){return wt(t,e,this._listeners),wt(t,e,this._oneTimeListeners),this},Mt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},_t(t,e,this._oneTimeListeners),this},Mt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Tt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];wt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(u(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof kt&&console.error(t.error);return this},Mt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},Mt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var At={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{},within:{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},in:{group:\"Lookup\"},\"index-of\":{group:\"Lookup\"},slice:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},image:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},distance:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},within:{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}},St=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Et(t){var e=t.value;return e?[new St(t.key,e,\"constants have been deprecated as of v8\")]:[]}function Ct(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Lt(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function It(t){if(Array.isArray(t))return t.map(It);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){var e={};for(var r in t)e[r]=It(t[r]);return e}return Lt(t)}var Pt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Error),zt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r];this.bindings[i[0]]=i[1]}};zt.prototype.concat=function(t){return new zt(this,t)},zt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},zt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var Ot={kind:\"null\"},Dt={kind:\"number\"},Rt={kind:\"string\"},Ft={kind:\"boolean\"},Bt={kind:\"color\"},Nt={kind:\"object\"},jt={kind:\"value\"},Ut={kind:\"collator\"},Vt={kind:\"formatted\"},qt={kind:\"resolvedImage\"};function Ht(t,e){return{kind:\"array\",itemType:t,N:e}}function Gt(t){if(\"array\"===t.kind){var e=Gt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var Yt=[Ot,Dt,Rt,Ft,Bt,Vt,Nt,Ht(jt),qt];function Wt(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!Wt(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=Yt;r<n.length;r+=1)if(!Wt(n[r],e))return null}return\"Expected \"+Gt(t)+\" but found \"+Gt(e)+\" instead.\"}function Xt(t,e){return e.some((function(e){return e.kind===t.kind}))}function Zt(t,e){return e.some((function(e){return\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t}))}var Jt=e((function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return n(\"%\"===t[t.length-1]?parseFloat(t)/100*255:parseInt(t))}function a(t){return(e=\"%\"===t[t.length-1]?parseFloat(t)/100:parseFloat(t))<0?0:e>1?1:e;var e}function o(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,s=t.replace(/ /g,\"\").toLowerCase();if(s in r)return r[s].slice();if(\"#\"===s[0])return 4===s.length?(e=parseInt(s.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===s.length&&(e=parseInt(s.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=s.indexOf(\"(\"),c=s.indexOf(\")\");if(-1!==l&&c+1===s.length){var u=s.substr(0,l),f=s.substr(l+1,c-(l+1)).split(\",\"),h=1;switch(u){case\"rgba\":if(4!==f.length)return null;h=a(f.pop());case\"rgb\":return 3!==f.length?null:[i(f[0]),i(f[1]),i(f[2]),h];case\"hsla\":if(4!==f.length)return null;h=a(f.pop());case\"hsl\":if(3!==f.length)return null;var p=(parseFloat(f[0])%360+360)%360/360,d=a(f[1]),g=a(f[2]),m=g<=.5?g*(d+1):g+d-g*d,v=2*g-m;return[n(255*o(v,m,p+1/3)),n(255*o(v,m,p)),n(255*o(v,m,p-1/3)),h];default:return null}}return null}}catch(t){}})).parseCSSColor,Kt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};Kt.parse=function(t){if(t){if(t instanceof Kt)return t;if(\"string\"==typeof t){var e=Jt(t);if(e)return new Kt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},Kt.prototype.toString=function(){var t=this.toArray(),e=t[1],r=t[2],n=t[3];return\"rgba(\"+Math.round(t[0])+\",\"+Math.round(e)+\",\"+Math.round(r)+\",\"+n+\")\"},Kt.prototype.toArray=function(){var t=this.a;return 0===t?[0,0,0,0]:[255*this.r/t,255*this.g/t,255*this.b/t,t]},Kt.black=new Kt(0,0,0,1),Kt.white=new Kt(1,1,1,1),Kt.transparent=new Kt(0,0,0,0),Kt.red=new Kt(1,0,0,1);var Qt=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};Qt.prototype.compare=function(t,e){return this.collator.compare(t,e)},Qt.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var $t=function(t,e,r,n,i){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=i},te=function(t){this.sections=t};te.fromString=function(t){return new te([new $t(t,null,null,null,null)])},te.prototype.isEmpty=function(){return 0===this.sections.length||!this.sections.some((function(t){return 0!==t.text.length||t.image&&0!==t.image.name.length}))},te.factory=function(t){return t instanceof te?t:te.fromString(t)},te.prototype.toString=function(){return 0===this.sections.length?\"\":this.sections.map((function(t){return t.text})).join(\"\")},te.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];if(n.image)t.push([\"image\",n.image.name]);else{t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),n.textColor&&(i[\"text-color\"]=[\"rgba\"].concat(n.textColor.toArray())),t.push(i)}}return t};var ee=function(t){this.name=t.name,this.available=t.available};function re(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function ne(t){if(null===t)return!0;if(\"string\"==typeof t)return!0;if(\"boolean\"==typeof t)return!0;if(\"number\"==typeof t)return!0;if(t instanceof Kt)return!0;if(t instanceof Qt)return!0;if(t instanceof te)return!0;if(t instanceof ee)return!0;if(Array.isArray(t)){for(var e=0,r=t;e<r.length;e+=1)if(!ne(r[e]))return!1;return!0}if(\"object\"==typeof t){for(var n in t)if(!ne(t[n]))return!1;return!0}return!1}function ie(t){if(null===t)return Ot;if(\"string\"==typeof t)return Rt;if(\"boolean\"==typeof t)return Ft;if(\"number\"==typeof t)return Dt;if(t instanceof Kt)return Bt;if(t instanceof Qt)return Ut;if(t instanceof te)return Vt;if(t instanceof ee)return qt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=ie(i[n]);if(e){if(e===a)continue;e=jt;break}e=a}return Ht(e||jt,r)}return Nt}function ae(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof Kt||t instanceof te||t instanceof ee?t.toString():JSON.stringify(t)}ee.prototype.toString=function(){return this.name},ee.fromString=function(t){return t?new ee({name:t,available:!1}):null},ee.prototype.serialize=function(){return[\"image\",this.name]};var oe=function(t,e){this.type=t,this.value=e};oe.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!ne(t[1]))return e.error(\"invalid value\");var r=t[1],n=ie(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new oe(n,r)},oe.prototype.evaluate=function(){return this.value},oe.prototype.eachChild=function(){},oe.prototype.outputDefined=function(){return!0},oe.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof Kt?[\"rgba\"].concat(this.value.toArray()):this.value instanceof te?this.value.serialize():this.value};var se=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};se.prototype.toJSON=function(){return this.message};var le={string:Rt,number:Dt,boolean:Ft,object:Nt},ce=function(t,e){this.type=t,this.args=e};ce.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in le)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=le[s],n++}else a=jt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=Ht(a,o)}else r=le[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,jt);if(!c)return null;l.push(c)}return new ce(r,l)},ce.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Wt(this.type,ie(r)))return r;if(e===this.args.length-1)throw new se(\"Expected value to be of type \"+Gt(this.type)+\", but found \"+Gt(ie(r))+\" instead.\")}return null},ce.prototype.eachChild=function(t){this.args.forEach(t)},ce.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ce.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map((function(t){return t.serialize()})))};var ue=function(t){this.type=Vt,this.sections=t};ue.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");for(var n=[],i=!1,a=1;a<=t.length-1;++a){var o=t[a];if(i&&\"object\"==typeof o&&!Array.isArray(o)){i=!1;var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Dt)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,Ht(Rt))))return null;var c=null;if(o[\"text-color\"]&&!(c=e.parse(o[\"text-color\"],1,Bt)))return null;var u=n[n.length-1];u.scale=s,u.font=l,u.textColor=c}else{var f=e.parse(t[a],1,jt);if(!f)return null;var h=f.type.kind;if(\"string\"!==h&&\"value\"!==h&&\"null\"!==h&&\"resolvedImage\"!==h)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");i=!0,n.push({content:f,scale:null,font:null,textColor:null})}}return new ue(n)},ue.prototype.evaluate=function(t){return new te(this.sections.map((function(e){var r=e.content.evaluate(t);return ie(r)===qt?new $t(\"\",r,null,null,null):new $t(ae(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))},ue.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.content),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},ue.prototype.outputDefined=function(){return!1},ue.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.content.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),n.textColor&&(i[\"text-color\"]=n.textColor.serialize()),t.push(i)}return t};var fe=function(t){this.type=qt,this.input=t};fe.parse=function(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Rt);return r?new fe(r):e.error(\"No image name provided.\")},fe.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=ee.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r},fe.prototype.eachChild=function(t){t(this.input)},fe.prototype.outputDefined=function(){return!1},fe.prototype.serialize=function(){return[\"image\",this.input.serialize()]};var he={\"to-boolean\":Ft,\"to-color\":Bt,\"to-number\":Dt,\"to-string\":Rt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=he[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,jt);if(!o)return null;i.push(o)}return new pe(n,i)},pe.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof Kt)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":re(e[0],e[1],e[2],e[3])))return new Kt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new se(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new se(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?te.fromString(ae(this.args[0].evaluate(t))):\"resolvedImage\"===this.type.kind?ee.fromString(ae(this.args[0].evaluate(t))):ae(this.args[0].evaluate(t))},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},pe.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new ue([{content:this.args[0],scale:null,font:null,textColor:null}]).serialize();if(\"resolvedImage\"===this.type.kind)return new fe(this.args[0]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild((function(e){t.push(e.serialize())})),t};var de=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ge=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null};ge.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ge.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?de[this.feature.type]:this.feature.type:null},ge.prototype.geometry=function(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null},ge.prototype.canonicalID=function(){return this.canonical},ge.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ge.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Kt.parse(t)),e};var me=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};me.prototype.evaluate=function(t){return this._evaluate(t,this.args)},me.prototype.eachChild=function(t){this.args.forEach(t)},me.prototype.outputDefined=function(){return!1},me.prototype.serialize=function(){return[this.name].concat(this.args.map((function(t){return t.serialize()})))},me.parse=function(t,e){var r,n=t[0],i=me.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter((function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1})),l=null,c=0,u=s;c<u.length;c+=1){var f=u[c],h=f[0],p=f[1];l=new Be(e.registry,e.path,null,e.scope);for(var d=[],g=!1,m=1;m<t.length;m++){var v=t[m],y=Array.isArray(h)?h[m-1]:h.type,x=l.parse(v,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(h)&&h.length!==d.length)l.error(\"Expected \"+h.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(h)?h[b]:h.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new me(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var T=(s.length?s:o).map((function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Gt).join(\", \")+\")\":\"(\"+Gt(e.type)+\"...)\"})).join(\" | \"),k=[],M=1;M<t.length;M++){var A=e.parse(t[M],1+k.length);if(!A)return null;k.push(Gt(A.type))}e.error(\"Expected arguments of type \"+T+\", but found (\"+k.join(\", \")+\") instead.\")}return null},me.register=function(t,e){for(var r in me.definitions=e,e)t[r]=me};var ve=function(t,e,r){this.type=Ut,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function ye(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function xe(t,e){return!(t[0]<=e[0]||t[2]>=e[2]||t[1]<=e[1]||t[3]>=e[3])}function be(t,e){var r=(180+t[0])/360,n=(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t[1]*Math.PI/360)))/360,i=Math.pow(2,e.z);return[Math.round(r*i*8192),Math.round(n*i*8192)]}function _e(t,e,r){return e[1]>t[1]!=r[1]>t[1]&&t[0]<(r[0]-e[0])*(t[1]-e[1])/(r[1]-e[1])+e[0]}function we(t,e){for(var r,n,i,a,o,s,l,c=!1,u=0,f=e.length;u<f;u++)for(var h=e[u],p=0,d=h.length;p<d-1;p++){if((a=(r=t)[0]-(n=h[p])[0])*(l=r[1]-(i=h[p+1])[1])-(s=r[0]-i[0])*(o=r[1]-n[1])==0&&a*s<=0&&o*l<=0)return!1;_e(t,h[p],h[p+1])&&(c=!c)}return c}function Te(t,e){for(var r=0;r<e.length;r++)if(we(t,e[r]))return!0;return!1}function ke(t,e,r,n){var i=n[0]-r[0],a=n[1]-r[1],o=(t[0]-r[0])*a-i*(t[1]-r[1]),s=(e[0]-r[0])*a-i*(e[1]-r[1]);return o>0&&s<0||o<0&&s>0}function Me(t,e,r){for(var n=0,i=r;n<i.length;n+=1)for(var a=i[n],o=0;o<a.length-1;++o)if(0!=(f=[(u=a[o+1])[0]-(c=a[o])[0],u[1]-c[1]])[0]*(h=[(l=e)[0]-(s=t)[0],l[1]-s[1]])[1]-f[1]*h[0]&&ke(s,l,c,u)&&ke(c,u,s,l))return!0;var s,l,c,u,f,h;return!1}function Ae(t,e){for(var r=0;r<t.length;++r)if(!we(t[r],e))return!1;for(var n=0;n<t.length-1;++n)if(Me(t[n],t[n+1],e))return!1;return!0}function Se(t,e){for(var r=0;r<e.length;r++)if(Ae(t,e[r]))return!0;return!1}function Ee(t,e,r){for(var n=[],i=0;i<t.length;i++){for(var a=[],o=0;o<t[i].length;o++){var s=be(t[i][o],r);ye(e,s),a.push(s)}n.push(a)}return n}function Ce(t,e,r){for(var n=[],i=0;i<t.length;i++){var a=Ee(t[i],e,r);n.push(a)}return n}function Le(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){var i=.5*n,a=t[0]-r[0]>i?-n:r[0]-t[0]>i?n:0;0===a&&(a=t[0]-r[2]>i?-n:r[2]-t[0]>i?n:0),t[0]+=a}ye(e,t)}function Ie(t,e,r,n){for(var i=8192*Math.pow(2,n.z),a=[8192*n.x,8192*n.y],o=[],s=0,l=t;s<l.length;s+=1)for(var c=0,u=l[s];c<u.length;c+=1){var f=u[c],h=[f.x+a[0],f.y+a[1]];Le(h,e,r,i),o.push(h)}return o}function Pe(t,e,r,n){for(var i,a=8192*Math.pow(2,n.z),o=[8192*n.x,8192*n.y],s=[],l=0,c=t;l<c.length;l+=1){for(var u=[],f=0,h=c[l];f<h.length;f+=1){var p=h[f],d=[p.x+o[0],p.y+o[1]];ye(e,d),u.push(d)}s.push(u)}if(e[2]-e[0]<=a/2){(i=e)[0]=i[1]=1/0,i[2]=i[3]=-1/0;for(var g=0,m=s;g<m.length;g+=1)for(var v=0,y=m[g];v<y.length;v+=1)Le(y[v],e,r,a)}return s}ve.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Ft);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Ft);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Rt))?null:new ve(n,i,a)},ve.prototype.evaluate=function(t){return new Qt(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},ve.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},ve.prototype.outputDefined=function(){return!1},ve.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var ze=function(t,e){this.type=Ft,this.geojson=t,this.geometries=e};function Oe(t){if(t instanceof me){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof ze)return!1;var e=!0;return t.eachChild((function(t){e&&!Oe(t)&&(e=!1)})),e}function De(t){if(t instanceof me&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild((function(t){e&&!De(t)&&(e=!1)})),e}function Re(t,e){if(t instanceof me&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild((function(t){r&&!Re(t,e)&&(r=!1)})),r}ze.parse=function(t,e){if(2!==t.length)return e.error(\"'within' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(ne(t[1])){var r=t[1];if(\"FeatureCollection\"===r.type)for(var n=0;n<r.features.length;++n){var i=r.features[n].geometry.type;if(\"Polygon\"===i||\"MultiPolygon\"===i)return new ze(r,r.features[n].geometry)}else if(\"Feature\"===r.type){var a=r.geometry.type;if(\"Polygon\"===a||\"MultiPolygon\"===a)return new ze(r,r.geometry)}else if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type)return new ze(r,r)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")},ze.prototype.evaluate=function(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!we(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Te(h[f],c))return!1}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!Ae(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Se(h[f],c))return!1}return!0}(t,this.geometries)}return!1},ze.prototype.eachChild=function(){},ze.prototype.outputDefined=function(){return!0},ze.prototype.serialize=function(){return[\"within\",this.geojson]};var Fe=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Fe.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Fe(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Fe.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Fe.prototype.eachChild=function(){},Fe.prototype.outputDefined=function(){return!1},Fe.prototype.serialize=function(){return[\"var\",this.name]};var Be=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new zt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map((function(t){return\"[\"+t+\"]\"})).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Ne(t,e){for(var r,n=t.length-1,i=0,a=n,o=0;i<=a;)if((r=t[o=Math.floor((i+a)/2)])<=e){if(o===n||e<t[o+1])return o;i=o+1}else{if(!(r>e))throw new se(\"Input is not a number.\");a=o-1}return 0}Be.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Be.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new ce(e,[t]):\"coerce\"===r?new pe(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind&&\"resolvedImage\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof oe)&&\"resolvedImage\"!==a.type.kind&&function t(e){if(e instanceof Fe)return t(e.boundExpression);if(e instanceof me&&\"error\"===e.name)return!1;if(e instanceof ve)return!1;if(e instanceof ze)return!1;var r=e instanceof pe||e instanceof ce,n=!0;return e.eachChild((function(e){n=r?n&&t(e):n&&e instanceof oe})),!!n&&Oe(e)&&Re(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}(a)){var l=new ge;try{a=new oe(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return this.error(void 0===t?\"'undefined' value invalid. Use null instead.\":\"object\"==typeof t?'Bare objects invalid. Use [\"literal\", {...}] instead.':\"Expected an array, but found \"+typeof t+\" instead.\")},Be.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Be(this.registry,n,e||null,i,this.errors)},Be.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map((function(t){return\"[\"+t+\"]\"})).join(\"\");this.errors.push(new Pt(n,t))},Be.prototype.checkSubtype=function(t,e){var r=Wt(t,e);return r&&this.error(r),r};var je=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[1];this.labels.push(a[0]),this.outputs.push(o)}};function Ue(t,e,r){return t*(1-r)+e*r}je.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new je(i,r,n)},je.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Ne(e,n)].evaluate(t)},je.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},je.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},je.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ve=Object.freeze({__proto__:null,number:Ue,color:function(t,e,r){return new Kt(Ue(t.r,e.r,r),Ue(t.g,e.g,r),Ue(t.b,e.b,r),Ue(t.a,e.a,r))},array:function(t,e,r){return t.map((function(t,n){return Ue(t,e[n],r)}))}}),qe=6/29*3*(6/29),He=Math.PI/180,Ge=180/Math.PI;function Ye(t){return t>.008856451679035631?Math.pow(t,1/3):t/qe+4/29}function We(t){return t>6/29?t*t*t:qe*(t-4/29)}function Xe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ze(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Je(t){var e=Ze(t.r),r=Ze(t.g),n=Ze(t.b),i=Ye((.4124564*e+.3575761*r+.1804375*n)/.95047),a=Ye((.2126729*e+.7151522*r+.072175*n)/1);return{l:116*a-16,a:500*(i-a),b:200*(a-Ye((.0193339*e+.119192*r+.9503041*n)/1.08883)),alpha:t.a}}function Ke(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=1*We(e),r=.95047*We(r),n=1.08883*We(n),new Kt(Xe(3.2404542*r-1.5371385*e-.4985314*n),Xe(-.969266*r+1.8760108*e+.041556*n),Xe(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function Qe(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var $e={forward:Je,reverse:Ke,interpolate:function(t,e,r){return{l:Ue(t.l,e.l,r),a:Ue(t.a,e.a,r),b:Ue(t.b,e.b,r),alpha:Ue(t.alpha,e.alpha,r)}}},tr={forward:function(t){var e=Je(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Ge;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*He,r=t.c;return Ke({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:Qe(t.h,e.h,r),c:Ue(t.c,e.c,r),l:Ue(t.l,e.l,r),alpha:Ue(t.alpha,e.alpha,r)}}},er=Object.freeze({__proto__:null,lab:$e,hcl:tr}),rr=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[1];this.labels.push(s[0]),this.outputs.push(l)}};function nr(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}rr.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=nr(e,t.base,n,i);else if(\"linear\"===t.name)a=nr(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(nr(e,1,n,i))}return a},rr.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some((function(t){return\"number\"!=typeof t||t<0||t>1})))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Dt)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Bt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var f=a[u],h=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof f)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=f)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(h,d,c);if(!g)return null;c=c||g.type,l.push([f,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new rr(c,r,n,i,l):e.error(\"Type \"+Gt(c)+\" is not interpolatable.\")},rr.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Ne(e,n),o=rr.interpolationFactor(this.interpolation,n,e[a],e[a+1]),s=r[a].evaluate(t),l=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ve[this.type.kind.toLowerCase()](s,l,o):\"interpolate-hcl\"===this.operator?tr.reverse(tr.interpolate(tr.forward(s),tr.forward(l),o)):$e.reverse($e.interpolate($e.forward(s),$e.forward(l),o))},rr.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},rr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},rr.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var ir=function(t,e){this.type=t,this.args=e};ir.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=e.parse(o[a],1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!s)return null;r=r||s.type,i.push(s)}var l=n&&i.some((function(t){return Wt(n,t.type)}));return new ir(l?jt:r,i)},ir.prototype.evaluate=function(t){for(var e,r=null,n=0,i=0,a=this.args;i<a.length&&(n++,(r=a[i].evaluate(t))&&r instanceof ee&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null===r);i+=1);return r},ir.prototype.eachChild=function(t){this.args.forEach(t)},ir.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ir.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var ar=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};ar.prototype.evaluate=function(t){return this.result.evaluate(t)},ar.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},ar.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new ar(r,o):null},ar.prototype.outputDefined=function(){return this.result.outputDefined()},ar.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e];t.push(n[0],n[1].serialize())}return t.push(this.result.serialize()),t};var or=function(t,e,r){this.type=t,this.index=e,this.input=r};or.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Dt),n=e.parse(t[2],2,Ht(e.expectedType||jt));return r&&n?new or(n.type.itemType,r,n):null},or.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new se(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new se(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new se(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},or.prototype.eachChild=function(t){t(this.index),t(this.input)},or.prototype.outputDefined=function(){return!1},or.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var sr=function(t,e){this.type=Ft,this.needle=t,this.haystack=e};sr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);return r&&n?Xt(r.type,[Ft,Rt,Dt,Ot,jt])?new sr(r,n):e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\"):null},sr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");return r.indexOf(e)>=0},sr.prototype.eachChild=function(t){t(this.needle),t(this.haystack)},sr.prototype.outputDefined=function(){return!0},sr.prototype.serialize=function(){return[\"in\",this.needle.serialize(),this.haystack.serialize()]};var lr=function(t,e,r){this.type=Dt,this.needle=t,this.haystack=e,this.fromIndex=r};lr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);if(!r||!n)return null;if(!Xt(r.type,[Ft,Rt,Dt,Ot,jt]))return e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new lr(r,n,i):null}return new lr(r,n)},lr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");if(this.fromIndex){var n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)},lr.prototype.eachChild=function(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)},lr.prototype.outputDefined=function(){return!1},lr.prototype.serialize=function(){if(null!=this.fromIndex&&void 0!==this.fromIndex){var t=this.fromIndex.serialize();return[\"index-of\",this.needle.serialize(),this.haystack.serialize(),t]}return[\"index-of\",this.needle.serialize(),this.haystack.serialize()]};var cr=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};cr.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,f=s;u<f.length;u+=1){var h=f[u];if(\"number\"!=typeof h&&\"string\"!=typeof h)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof h&&Math.abs(h)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof h&&Math.floor(h)!==h)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,ie(h)))return null}else r=ie(h);if(void 0!==i[String(h)])return c.error(\"Branch labels must be unique.\");i[String(h)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,jt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new cr(r,n,d,i,a,g):null},cr.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(ie(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},cr.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},cr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))&&this.otherwise.outputDefined()},cr.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(f=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[f][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],f=u[0],h=u[1];e.push(1===h.length?s(h[0]):h.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var ur=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};ur.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Ft);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new ur(r,n,s):null},ur.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];if(n[0].evaluate(t))return i.evaluate(t)}return this.otherwise.evaluate(t)},ur.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];t(n[0]),t(i)}t(this.otherwise)},ur.prototype.outputDefined=function(){return this.branches.every((function(t){return t[1].outputDefined()}))&&this.otherwise.outputDefined()},ur.prototype.serialize=function(){var t=[\"case\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var fr=function(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n};function hr(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function pr(t,e,r,n){return 0===n.compare(e,r)}function dr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Ft,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,jt);if(!a)return null;if(!hr(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(a.type)+\"'.\");var o=e.parse(t[2],2,jt);if(!o)return null;if(!hr(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Gt(a.type)+\"' and '\"+Gt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new ce(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new ce(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Ut)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=ie(a),l=ie(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new se('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=ie(a),u=ie(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.outputDefined=function(){return!0},i.prototype.serialize=function(){var e=[t];return this.eachChild((function(t){e.push(t.serialize())})),e},i}()}fr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,Dt);if(!r||!n)return null;if(!Xt(r.type,[Ht(jt),Rt,jt]))return e.error(\"Expected first argument to be of type array or string, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new fr(r.type,r,n,i):null}return new fr(r.type,r,n)},fr.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!Zt(e,[\"string\",\"array\"]))throw new se(\"Expected first argument to be of type array or string, but found \"+Gt(ie(e))+\" instead.\");if(this.endIndex){var n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)},fr.prototype.eachChild=function(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)},fr.prototype.outputDefined=function(){return!1},fr.prototype.serialize=function(){if(null!=this.endIndex&&void 0!==this.endIndex){var t=this.endIndex.serialize();return[\"slice\",this.input.serialize(),this.beginIndex.serialize(),t]}return[\"slice\",this.input.serialize(),this.beginIndex.serialize()]};var gr=dr(\"==\",(function(t,e,r){return e===r}),pr),mr=dr(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!pr(0,e,r,n)})),vr=dr(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),yr=dr(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),xr=dr(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),br=dr(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0})),_r=function(t,e,r,n,i){this.type=Rt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};_r.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Rt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Rt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Dt)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Dt))?null:new _r(r,i,a,o,s)},_r.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},_r.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},_r.prototype.outputDefined=function(){return!1},_r.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var wr=function(t){this.type=Dt,this.input=t};wr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Gt(r.type)+\" instead.\"):new wr(r):null},wr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new se(\"Expected value to be of type string or array, but found \"+Gt(ie(e))+\" instead.\")},wr.prototype.eachChild=function(t){t(this.input)},wr.prototype.outputDefined=function(){return!1},wr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Tr={\"==\":gr,\"!=\":mr,\">\":yr,\"<\":vr,\">=\":br,\"<=\":xr,array:ce,at:or,boolean:ce,case:ur,coalesce:ir,collator:ve,format:ue,image:fe,in:sr,\"index-of\":lr,interpolate:rr,\"interpolate-hcl\":rr,\"interpolate-lab\":rr,length:wr,let:ar,literal:oe,match:cr,number:ce,\"number-format\":_r,object:ce,slice:fr,step:je,string:ce,\"to-boolean\":pe,\"to-color\":pe,\"to-number\":pe,\"to-string\":pe,var:Fe,within:ze};function kr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=re(r,n,i,o);if(s)throw new se(s);return new Kt(r/255*o,n/255*o,i/255*o,o)}function Mr(t,e){return t in e}function Ar(t,e){var r=e[t];return void 0===r?null:r}function Sr(t){return{type:t}}function Er(t){return{result:\"success\",value:t}}function Cr(t){return{result:\"error\",value:t}}function Lr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function Ir(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function Pr(t){return!!t.expression&&t.expression.interpolated}function zr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function Or(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Dr(t){return t}function Rr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Fr(t,e,r,n,i){return Rr(typeof r===i?n[r]:void 0,t.default,e.default)}function Br(t,e,r){if(\"number\"!==zr(r))return Rr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Ne(t.stops.map((function(t){return t[0]})),r);return t.stops[i][1]}function Nr(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==zr(r))return Rr(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Ne(t.stops.map((function(t){return t[0]})),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ve[e.type]||Dr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=er[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function jr(t,e,r){return\"color\"===e.type?r=Kt.parse(r):\"formatted\"===e.type?r=te.fromString(r.toString()):\"resolvedImage\"===e.type?r=ee.fromString(r.toString()):zr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Rr(r,t.default,e.default)}me.register(Tr,{error:[{kind:\"error\"},[Rt],function(t,e){throw new se(e[0].evaluate(t))}],typeof:[Rt,[jt],function(t,e){return Gt(ie(e[0].evaluate(t)))}],\"to-rgba\":[Ht(Dt,4),[Bt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Bt,[Dt,Dt,Dt],kr],rgba:[Bt,[Dt,Dt,Dt,Dt],kr],has:{type:Ft,overloads:[[[Rt],function(t,e){return Mr(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Mr(e[0].evaluate(t),r.evaluate(t))}]]},get:{type:jt,overloads:[[[Rt],function(t,e){return Ar(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Ar(e[0].evaluate(t),r.evaluate(t))}]]},\"feature-state\":[jt,[Rt],function(t,e){return Ar(e[0].evaluate(t),t.featureState||{})}],properties:[Nt,[],function(t){return t.properties()}],\"geometry-type\":[Rt,[],function(t){return t.geometryType()}],id:[jt,[],function(t){return t.id()}],zoom:[Dt,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Dt,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Dt,[],function(t){return t.globals.lineProgress||0}],accumulated:[jt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Dt,Sr(Dt),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Dt,Sr(Dt),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Dt,overloads:[[[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)-r.evaluate(t)}],[[Dt],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)/r.evaluate(t)}],\"%\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)%r.evaluate(t)}],ln2:[Dt,[],function(){return Math.LN2}],pi:[Dt,[],function(){return Math.PI}],e:[Dt,[],function(){return Math.E}],\"^\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return Math.pow(e[0].evaluate(t),r.evaluate(t))}],sqrt:[Dt,[Dt],function(t,e){return Math.sqrt(e[0].evaluate(t))}],log10:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN10}],ln:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))}],log2:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN2}],sin:[Dt,[Dt],function(t,e){return Math.sin(e[0].evaluate(t))}],cos:[Dt,[Dt],function(t,e){return Math.cos(e[0].evaluate(t))}],tan:[Dt,[Dt],function(t,e){return Math.tan(e[0].evaluate(t))}],asin:[Dt,[Dt],function(t,e){return Math.asin(e[0].evaluate(t))}],acos:[Dt,[Dt],function(t,e){return Math.acos(e[0].evaluate(t))}],atan:[Dt,[Dt],function(t,e){return Math.atan(e[0].evaluate(t))}],min:[Dt,Sr(Dt),function(t,e){return Math.min.apply(Math,e.map((function(e){return e.evaluate(t)})))}],max:[Dt,Sr(Dt),function(t,e){return Math.max.apply(Math,e.map((function(e){return e.evaluate(t)})))}],abs:[Dt,[Dt],function(t,e){return Math.abs(e[0].evaluate(t))}],round:[Dt,[Dt],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Dt,[Dt],function(t,e){return Math.floor(e[0].evaluate(t))}],ceil:[Dt,[Dt],function(t,e){return Math.ceil(e[0].evaluate(t))}],\"filter-==\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Ft,[jt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Ft,[Rt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Ft,[jt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Ft,[],function(t){return null!==t.id()&&void 0!==t.id()}],\"filter-type-in\":[Ft,[Ht(Rt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Ft,[Ht(jt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)&&r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)||r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Ft,[Ft],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Ft,[Rt],function(t,e){var r=t.globals&&t.globals.isSupportedScript;return!r||r(e[0].evaluate(t))}],upcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Rt,Sr(jt),function(t,e){return e.map((function(e){return ae(e.evaluate(t))})).join(\"\")}],\"resolved-locale\":[Rt,[Ut],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Ur=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new ge,this._defaultValue=e?function(t){return\"color\"===t.type&&Or(t.default)?new Kt(0,0,0,0):\"color\"===t.type?Kt.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Vr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Tr}function qr(t,e){var r=new Be(Tr,[],e?function(t){var e={color:Bt,string:Rt,number:Dt,enum:Rt,boolean:Ft,formatted:Vt,resolvedImage:qt};return\"array\"===t.type?Ht(e[t.value]||jt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?Er(new Ur(n,e)):Cr(r.errors)}Ur.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a,this.expression.evaluate(this._evaluator)},Ur.prototype.evaluate=function(t,e,r,n,i,a){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a||null;try{var o=this.expression.evaluate(this._evaluator);if(null==o||\"number\"==typeof o&&o!=o)return this._defaultValue;if(this._enumValues&&!(o in this._enumValues))throw new se(\"Expected value to be one of \"+Object.keys(this._enumValues).map((function(t){return JSON.stringify(t)})).join(\", \")+\", but found \"+JSON.stringify(o)+\" instead.\");return o}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var Hr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!De(e.expression)};Hr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Hr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)};var Gr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!De(e.expression),this.interpolationType=n};function Yr(t,e){if(\"error\"===(t=qr(t,e)).result)return t;var r=t.value.expression,n=Oe(r);if(!n&&!Lr(e))return Cr([new Pt(\"\",\"data expressions not supported\")]);var i=Re(r,[\"zoom\"]);if(!i&&!Ir(e))return Cr([new Pt(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof ar)r=t(e.result);else if(e instanceof ir)for(var n=0,i=e.args;n<i.length&&!(r=t(i[n]));n+=1);else(e instanceof je||e instanceof rr)&&e.input instanceof me&&\"zoom\"===e.input.name&&(r=e);return r instanceof Pt||e.eachChild((function(e){var n=t(e);n instanceof Pt?r=n:!r&&n?r=new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Pt(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),r}(r);return a||i?a instanceof Pt?Cr([a]):a instanceof rr&&!Pr(e)?Cr([new Pt(\"\",'\"interpolate\" expressions cannot be used with this property')]):Er(a?new Gr(n?\"camera\":\"composite\",t.value,a.labels,a instanceof rr?a.interpolation:void 0):new Hr(n?\"constant\":\"source\",t.value)):Cr([new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Gr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Gr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)},Gr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?rr.interpolationFactor(this.interpolationType,t,e,r):0};var Wr=function(t,e){this._parameters=t,this._specification=e,Ct(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||!(s||void 0!==e.property),c=e.type||(Pr(r)?\"exponential\":\"interval\");if(o&&((e=Ct({},e)).stops&&(e.stops=e.stops.map((function(t){return[t[0],Kt.parse(t[1])]}))),e.default=Kt.parse(e.default?e.default:r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!er[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===c)n=Nr;else if(\"interval\"===c)n=Br;else if(\"categorical\"===c){n=Fr,i=Object.create(null);for(var u=0,f=e.stops;u<f.length;u+=1){var h=f[u];i[h[0]]=h[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==c)throw new Error('Unknown function type \"'+c+'\"');n=jr}if(s){for(var p={},d=[],g=0;g<e.stops.length;g++){var m=e.stops[g],v=m[0].zoom;void 0===p[v]&&(p[v]={zoom:v,type:e.type,property:e.property,default:e.default,stops:[]},d.push(v)),p[v].stops.push([m[0].value,m[1]])}for(var y=[],x=0,b=d;x<b.length;x+=1){var _=b[x];y.push([p[_].zoom,t(p[_],r)])}var w={name:\"linear\"};return{kind:\"composite\",interpolationType:w,interpolationFactor:rr.interpolationFactor.bind(void 0,w),zoomStops:y.map((function(t){return t[0]})),evaluate:function(t,n){var i=t.zoom;return Nr({stops:y,base:e.base},r,i).evaluate(i,n)}}}if(l){var T=\"exponential\"===c?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:rr.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map((function(t){return t[0]})),evaluate:function(t){return n(e,r,t.zoom,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Rr(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Xr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=zr(r);if(\"object\"!==l)return[new St(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],f=n[u]||n[\"*\"],h=void 0;if(i[u])h=i[u];else if(n[u])h=bn;else if(i[\"*\"])h=i[\"*\"];else{if(!n[\"*\"]){s.push(new St(e,r[c],'unknown property \"'+c+'\"'));continue}h=bn}s=s.concat(h({key:(e?e+\".\":e)+c,value:r[c],valueSpec:f,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new St(e,r,'missing required property \"'+p+'\"'));return s}function Zr(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||bn;if(\"array\"!==zr(e))return[new St(a,e,\"array expected, \"+zr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new St(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new St(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===zr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Jr(t){var e=t.key,r=t.value,n=t.valueSpec,i=zr(r);return\"number\"===i&&r!=r&&(i=\"NaN\"),\"number\"!==i?[new St(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new St(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new St(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function Kr(t){var e,r,n,i=t.valueSpec,a=Lt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===zr(t.value.stops)&&\"array\"===zr(t.value.stops[0])&&\"object\"===zr(t.value.stops[0][0]),u=Xr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new St(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Zr({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:f})),\"array\"===zr(r)&&0===r.length&&e.push(new St(t.key,r,\"array must have at least one stop\")),e},default:function(t){return bn({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new St(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new St(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!Pr(t.valueSpec)&&u.push(new St(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!Lr(t.valueSpec)?u.push(new St(t.key,t.value,\"property functions not supported\")):s&&!Ir(t.valueSpec)&&u.push(new St(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new St(t.key,t.value,'\"property\" property is required')),u;function f(t){var e=[],a=t.value,s=t.key;if(\"array\"!==zr(a))return[new St(s,a,\"array expected, \"+zr(a)+\" found\")];if(2!==a.length)return[new St(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==zr(a[0]))return[new St(s,a,\"object expected, \"+zr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new St(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new St(s,a,\"object stop key must have value\")];if(n&&n>Lt(a[0].zoom))return[new St(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Lt(a[0].zoom)!==n&&(n=Lt(a[0].zoom),r=void 0,o={}),e=e.concat(Xr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Jr,value:h}}))}else e=e.concat(h({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Vr(It(a[1]))?e.concat([new St(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(bn({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function h(t,n){var s=zr(t.value),l=Lt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new St(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new St(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return Lr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new St(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new St(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new St(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new St(t.key,c,\"integer expected, found \"+l)]}}function Qr(t){var e=(\"property\"===t.expressionContext?Yr:qr)(It(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((function(e){return new St(\"\"+t.key+e.key,t.value,e.message)}));var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new St(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!Re(r,[\"zoom\",\"feature-state\"]))return[new St(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!Oe(r))return[new St(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function $r(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function tn(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!tn(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Wr.deserialize=function(t){return new Wr(t._parameters,t._specification)},Wr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var en={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function rn(t){if(null==t)return{filter:function(){return!0},needGeometry:!1};tn(t)||(t=an(t));var e=qr(t,en);if(\"error\"===e.result)throw new Error(e.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return{filter:function(t,r,n){return e.value.evaluate(t,r,{},n)},needGeometry:function t(e){if(!Array.isArray(e))return!1;if(\"within\"===e[0])return!0;for(var r=1;r<e.length;r++)if(t(e[r]))return!0;return!1}(t)}}function nn(t,e){return t<e?-1:t>e?1:0}function an(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?on(t[1],t[2],\"==\"):\"!=\"===r?cn(on(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?on(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(an))):\"all\"===r?[\"all\"].concat(t.slice(1).map(an)):\"none\"===r?[\"all\"].concat(t.slice(1).map(an).map(cn)):\"in\"===r?sn(t[1],t.slice(2)):\"!in\"===r?cn(sn(t[1],t.slice(2))):\"has\"===r?ln(t[1]):\"!has\"===r?cn(ln(t[1])):\"within\"!==r||t}function on(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function sn(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((function(t){return typeof t!=typeof e[0]}))?[\"filter-in-large\",t,[\"literal\",e.sort(nn)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function ln(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function cn(t){return[\"!\",t]}function un(t){return tn(It(t.value))?Qr(Ct({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==zr(r))return[new St(n,r,\"array expected, \"+zr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new St(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat($r({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Lt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Lt(r[1])&&o.push(new St(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new St(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=zr(r[1]))&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=zr(r[s]),\"$type\"===Lt(r[1])?o=o.concat($r({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new St(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));break;case\"within\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"object\"!==i&&o.push(new St(n+\"[1]\",r[1],\"object expected, \"+i+\" found\"))}return o}(t)}function fn(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return bn({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new St(r,a,'unknown property \"'+o+'\"')];if(\"string\"===zr(a)&&Lr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new St(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var f=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&f.push(new St(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&Or(It(a))&&\"identity\"===Lt(a.type)&&f.push(new St(r,a,'\"text-font\" does not support identity functions'))),f.concat(bn({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function hn(t){return fn(t,\"paint\")}function pn(t){return fn(t,\"layout\")}function dn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new St(n,r,'either \"type\" or \"ref\" is required'));var o,s=Lt(r.type),l=Lt(r.ref);if(r.id)for(var c=Lt(r.id),u=0;u<t.arrayIndex;u++){var f=i.layers[u];Lt(f.id)===c&&e.push(new St(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+f.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((function(t){t in r&&e.push(new St(n,r[t],'\"'+t+'\" is prohibited for ref layers'))})),i.layers.forEach((function(t){Lt(t.id)===l&&(o=t)})),o?o.ref?e.push(new St(n,r.ref,\"ref cannot reference another ref layer\")):s=Lt(o.type):e.push(new St(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var h=i.sources&&i.sources[r.source],p=h&&Lt(h.type);h?\"vector\"===p&&\"raster\"===s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new St(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&h.lineMetrics||e.push(new St(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new St(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new St(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new St(n,r,'missing required property \"source\"'));return e=e.concat(Xr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return bn({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:un,layout:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return pn(Ct({layerType:s},t))}}})},paint:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return hn(Ct({layerType:s},t))}}})}}}))}function gn(t){var e=t.value,r=t.key,n=zr(e);return\"string\"!==n?[new St(r,e,\"string expected, \"+n+\" found\")]:[]}var mn={promoteId:function(t){var e=t.key,r=t.value;if(\"string\"===zr(r))return gn({key:e,value:r});var n=[];for(var i in r)n.push.apply(n,gn({key:e+\".\"+i,value:r[i]}));return n}};function vn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new St(r,e,'\"type\" is required')];var a,o=Lt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":return Xr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n,objectElementValidators:mn});case\"geojson\":if(a=Xr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n,objectElementValidators:mn}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=\"string\"==typeof c?[c,[\"accumulated\"],[\"get\",s]]:c;a.push.apply(a,Qr({key:r+\".\"+s+\".map\",value:l[1],expressionContext:\"cluster-map\"})),a.push.apply(a,Qr({key:r+\".\"+s+\".reduce\",value:u,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Xr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Xr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new St(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return $r({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function yn(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=zr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new St(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=a.concat(l&&n[l[1]]&&n[l[1]].transition?bn({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r}):n[s]?bn({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r}):[new St(s,e[s],'unknown property \"'+s+'\"')])}return a}var xn={\"*\":function(){return[]},array:Zr,boolean:function(t){var e=t.value,r=t.key,n=zr(e);return\"boolean\"!==n?[new St(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Jr,color:function(t){var e=t.key,r=t.value,n=zr(r);return\"string\"!==n?[new St(e,r,\"color expected, \"+n+\" found\")]:null===Jt(r)?[new St(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Et,enum:$r,filter:un,function:Kr,layer:dn,object:Xr,source:vn,light:yn,string:gn,formatted:function(t){return 0===gn(t).length?[]:Qr(t)},resolvedImage:function(t){return 0===gn(t).length?[]:Qr(t)}};function bn(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&Or(Lt(e))?Kr(t):r.expression&&Vr(It(e))?Qr(t):r.type&&xn[r.type]?xn[r.type](t):Xr(Ct({},t,{valueSpec:r.type?n[r.type]:r}))}function _n(t){var e=t.value,r=t.key,n=gn(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function wn(t,e){void 0===e&&(e=At);var r=[];return r=r.concat(bn({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:_n,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Et({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),Tn(r)}function Tn(t){return[].concat(t).sort((function(t,e){return t.line-e.line}))}function kn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return Tn(t.apply(this,e))}}wn.source=kn(vn),wn.light=kn(yn),wn.layer=kn(dn),wn.filter=kn(un),wn.paintProperty=kn(hn),wn.layoutProperty=kn(pn);var Mn=wn,An=Mn.light,Sn=Mn.paintProperty,En=Mn.layoutProperty;function Cn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1)t.fire(new kt(new Error(i[n].message))),r=!0;return r}var Ln=In;function In(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],this.d=(e=i[1])+2*(r=i[2]);for(var a=0;a<this.d*this.d;a++){var o=i[3+a],s=i[3+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[3+n.length+1];this.keys=i.subarray(i[3+n.length],l),this.bboxes=i.subarray(l),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var c=0;c<this.d*this.d;c++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var u=r/e*t;this.min=-u,this.max=t+u}In.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},In.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},In.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},In.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},In.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,f=0;f<l.length;f++){var h=l[f];if(void 0===o[h]){var p=4*h;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[h]=!0,a.push(c[h])):o[h]=!1}}},In.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),f=this._convertToCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++){var d=this.d*p+h;if((!s||s(this._convertFromCellCoord(h),this._convertFromCellCoord(p),this._convertFromCellCoord(h+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},In.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},In.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},In.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=3+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[3+o]=a,i.set(s,a),a+=s.length}return i[3+t.length]=a,i.set(this.keys,a),i[3+t.length+1]=a+=this.keys.length,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var Pn=self.ImageData,zn=self.ImageBitmap,On={};function Dn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),On[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Rn in Dn(\"Object\",Object),Ln.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},Ln.deserialize=function(t){return new Ln(t.buffer)},Dn(\"Grid\",Ln),Dn(\"Color\",Kt),Dn(\"Error\",Error),Dn(\"ResolvedImage\",ee),Dn(\"StylePropertyFunction\",Wr),Dn(\"StyleExpression\",Ur,{omit:[\"_evaluator\"]}),Dn(\"ZoomDependentExpression\",Gr),Dn(\"ZoomConstantExpression\",Hr),Dn(\"CompoundExpression\",me,{omit:[\"_evaluate\"]}),Tr)Tr[Rn]._classRegistryKey||Dn(\"Expression_\"+Rn,Tr[Rn]);function Fn(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function Bn(t){return zn&&t instanceof zn}function Nn(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(Fn(t)||Bn(t))return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof Pn)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1)n.push(Nn(a[i],e));return n}if(\"object\"==typeof t){var o=t.constructor,s=o._classRegistryKey;if(!s)throw new Error(\"can't serialize object of unregistered class\");var l=o.serialize?o.serialize(t,e):{};if(!o.serialize){for(var c in t)if(t.hasOwnProperty(c)&&!(On[s].omit.indexOf(c)>=0)){var u=t[c];l[c]=On[s].shallow.indexOf(c)>=0?u:Nn(u,e)}t instanceof Error&&(l.message=t.message)}if(l.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==s&&(l.$name=s),l}throw new Error(\"can't serialize object of type \"+typeof t)}function jn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||Fn(t)||Bn(t)||ArrayBuffer.isView(t)||t instanceof Pn)return t;if(Array.isArray(t))return t.map(jn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=On[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=On[e].shallow.indexOf(o)>=0?s:jn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Un=function(){this.first=!0};Un.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var Vn={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function qn(t){for(var e=0,r=t;e<r.length;e+=1)if(Hn(r[e].charCodeAt(0)))return!0;return!1}function Hn(t){return!(746!==t&&747!==t&&(t<4352||!(Vn[\"Bopomofo Extended\"](t)||Vn.Bopomofo(t)||Vn[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||Vn[\"CJK Compatibility Ideographs\"](t)||Vn[\"CJK Compatibility\"](t)||Vn[\"CJK Radicals Supplement\"](t)||Vn[\"CJK Strokes\"](t)||!(!Vn[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||Vn[\"CJK Unified Ideographs Extension A\"](t)||Vn[\"CJK Unified Ideographs\"](t)||Vn[\"Enclosed CJK Letters and Months\"](t)||Vn[\"Hangul Compatibility Jamo\"](t)||Vn[\"Hangul Jamo Extended-A\"](t)||Vn[\"Hangul Jamo Extended-B\"](t)||Vn[\"Hangul Jamo\"](t)||Vn[\"Hangul Syllables\"](t)||Vn.Hiragana(t)||Vn[\"Ideographic Description Characters\"](t)||Vn.Kanbun(t)||Vn[\"Kangxi Radicals\"](t)||Vn[\"Katakana Phonetic Extensions\"](t)||Vn.Katakana(t)&&12540!==t||!(!Vn[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!Vn[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||Vn[\"Unified Canadian Aboriginal Syllabics\"](t)||Vn[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||Vn[\"Vertical Forms\"](t)||Vn[\"Yijing Hexagram Symbols\"](t)||Vn[\"Yi Syllables\"](t)||Vn[\"Yi Radicals\"](t))))}function Gn(t){return!(Hn(t)||function(t){return!!(Vn[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||Vn[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||Vn[\"Letterlike Symbols\"](t)||Vn[\"Number Forms\"](t)||Vn[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||Vn[\"Control Pictures\"](t)&&9251!==t||Vn[\"Optical Character Recognition\"](t)||Vn[\"Enclosed Alphanumerics\"](t)||Vn[\"Geometric Shapes\"](t)||Vn[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||Vn[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||Vn[\"CJK Symbols and Punctuation\"](t)||Vn.Katakana(t)||Vn[\"Private Use Area\"](t)||Vn[\"CJK Compatibility Forms\"](t)||Vn[\"Small Form Variants\"](t)||Vn[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function Yn(t){return t>=1424&&t<=2303||Vn[\"Arabic Presentation Forms-A\"](t)||Vn[\"Arabic Presentation Forms-B\"](t)}function Wn(t,e){return!(!e&&Yn(t)||t>=2304&&t<=3583||t>=3840&&t<=4255||Vn.Khmer(t))}function Xn(t){for(var e=0,r=t;e<r.length;e+=1)if(Yn(r[e].charCodeAt(0)))return!0;return!1}var Zn=null,Jn=\"unavailable\",Kn=null,Qn=function(t){t&&\"string\"==typeof t&&t.indexOf(\"NetworkError\")>-1&&(Jn=\"error\"),Zn&&Zn(t)};function $n(){ti.fire(new Tt(\"pluginStateChange\",{pluginStatus:Jn,pluginURL:Kn}))}var ti=new Mt,ei=function(){return Jn},ri=function(){if(\"deferred\"!==Jn||!Kn)throw new Error(\"rtl-text-plugin cannot be downloaded unless a pluginURL is specified\");Jn=\"loading\",$n(),Kn&&yt({url:Kn},(function(t){t?Qn(t):(Jn=\"loaded\",$n())}))},ni={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return\"loaded\"===Jn||null!=ni.applyArabicShaping},isLoading:function(){return\"loading\"===Jn},setState:function(t){Jn=t.pluginStatus,Kn=t.pluginURL},isParsed:function(){return null!=ni.applyArabicShaping&&null!=ni.processBidirectionalText&&null!=ni.processStyledBidirectionalText},getPluginURL:function(){return Kn}},ii=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Un,this.transition={})};ii.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!Wn(n[r].charCodeAt(0),e))return!1;return!0}(t,ni.isLoaded())},ii.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},ii.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var ai=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(Or(t))return new Wr(t,e);if(Vr(t)){var r=Yr(t,e);if(\"error\"===r.result)throw new Error(r.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=Kt.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};ai.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},ai.prototype.possiblyEvaluate=function(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)};var oi=function(t){this.property=t,this.value=new ai(t,void 0)};oi.prototype.transitioned=function(t,e){return new li(this.property,this.value,e,u({},t.transition,this.transition),t.now)},oi.prototype.untransitioned=function(){return new li(this.property,this.value,null,{},0)};var si=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};si.prototype.getValue=function(t){return x(this._values[t].value.value)},si.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].value=new ai(this._values[t].property,null===e?void 0:x(e))},si.prototype.getTransition=function(t){return x(this._values[t].transition)},si.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].transition=x(e)||void 0},si.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},si.prototype.transitioned=function(t,e){for(var r=new ci(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},si.prototype.untransitioned=function(){for(var t=new ci(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var li=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};li.prototype.possiblyEvaluate=function(t,e,r){var n=t.now||0,i=this.value.possiblyEvaluate(t,e,r),a=this.prior;if(a){if(n>this.end)return this.prior=null,i;if(this.value.isDataDriven())return this.prior=null,i;if(n<this.begin)return a.possiblyEvaluate(t,e,r);var o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(a.possiblyEvaluate(t,e,r),i,function(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}return i};var ci=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};ci.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n},ci.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1)if(this._values[e[t]].prior)return!0;return!1};var ui=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};ui.prototype.getValue=function(t){return x(this._values[t].value)},ui.prototype.setValue=function(t,e){this._values[t]=new ai(this._values[t].property,null===e?void 0:x(e))},ui.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},ui.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n};var fi=function(t,e,r){this.property=t,this.value=e,this.parameters=r};fi.prototype.isConstant=function(){return\"constant\"===this.value.kind},fi.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},fi.prototype.evaluate=function(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)};var hi=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};hi.prototype.get=function(t){return this._values[t]};var pi=function(t){this.specification=t};pi.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},pi.prototype.interpolate=function(t,e,r){var n=Ve[this.specification.type];return n?n(t,e,r):t};var di=function(t,e){this.specification=t,this.overrides=e};di.prototype.possiblyEvaluate=function(t,e,r,n){return new fi(this,\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)}:t.expression,e)},di.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new fi(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ve[this.specification.type];return n?new fi(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},di.prototype.evaluate=function(t,e,r,n,i,a){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,i,a)};var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0===t.value)return new fi(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n),a=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof i?i.name:i,o=this._calculate(a,a,a,e);return new fi(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){var s=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new fi(this,{kind:\"constant\",value:s},e)}return new fi(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n,i,a){if(\"source\"===t.kind){var o=t.evaluate(e,r,n,i,a);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(di),mi=function(t){this.specification=t};mi.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n);return this._calculate(i,i,i,e)}return this._calculate(t.expression.evaluate(new ii(Math.floor(e.zoom-1),e)),t.expression.evaluate(new ii(Math.floor(e.zoom),e)),t.expression.evaluate(new ii(Math.floor(e.zoom+1),e)),e)}},mi.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},mi.prototype.interpolate=function(t){return t};var vi=function(t){this.specification=t};vi.prototype.possiblyEvaluate=function(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)},vi.prototype.interpolate=function(){return!1};var yi=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new ai(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new oi(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};Dn(\"DataDrivenProperty\",di),Dn(\"DataConstantProperty\",pi),Dn(\"CrossFadedDataDrivenProperty\",gi),Dn(\"CrossFadedProperty\",mi),Dn(\"ColorRampProperty\",vi);var xi=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter={filter:function(){return!0},needGeometry:!1},\"custom\"!==e.type&&(this.metadata=(e=e).metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new ui(r.layout)),r.paint)){for(var n in this._transitionablePaint=new si(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new hi(r.paint)}}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){void 0===r&&(r={}),null!=e&&this._validate(En,\"layers.\"+this.id+\".layout.\"+t,t,e,r)||(\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e)},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e&&this._validate(Sn,\"layers.\"+this.id+\".paint.\"+t,t,e,r))return!1;if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var n=this._transitionablePaint._values[t],i=\"cross-faded-data-driven\"===n.property.specification[\"property-type\"],a=n.value.isDataDriven(),o=n.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var s=this._transitionablePaint._values[t].value;return s.isDataDriven()||a||i||this._handleOverridablePaintPropertyUpdate(t,o,s)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),y(t,(function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)}))},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&Cn(this,t.call(Mn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:At,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof fi&&Lr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(Mt),bi={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},_i=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},wi=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Ti(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map((function(t){var i=bi[t.type].BYTES_PER_ELEMENT,a=r=ki(r,Math.max(e,i)),o=t.components||1;return n=Math.max(n,i),r+=i*o,{name:t.name,type:t.type,components:o,offset:a}})),size:ki(r,Math.max(n,e)),alignment:e}}function ki(t,e){return Math.ceil(t/e)*e}wi.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},wi.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},wi.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},wi.prototype.clear=function(){this.length=0},wi.prototype.resize=function(t){this.reserve(t),this.length=t},wi.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},wi.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(wi);Mi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2i4\",Mi);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(wi);Ai.prototype.bytesPerElement=8,Dn(\"StructArrayLayout4i8\",Ai);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Si.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i4i12\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(wi);Ei.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2i4ub8\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c){var u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,i,a,o,s,l,c)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u){var f=9*t,h=18*t;return this.uint16[f+0]=e,this.uint16[f+1]=r,this.uint16[f+2]=n,this.uint16[f+3]=i,this.uint16[f+4]=a,this.uint16[f+5]=o,this.uint16[f+6]=s,this.uint16[f+7]=l,this.uint8[h+16]=c,this.uint8[h+17]=u,t},e}(wi);Ci.prototype.bytesPerElement=18,Dn(\"StructArrayLayout8ui2ub18\",Ci);var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u,f)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=i,this.uint16[p+4]=a,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=f,this.int16[p+11]=h,t},e}(wi);Li.prototype.bytesPerElement=24,Dn(\"StructArrayLayout4i4ui4i24\",Li);var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(wi);Ii.prototype.bytesPerElement=12,Dn(\"StructArrayLayout3f12\",Ii);var Pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint32[1*t+0]=e,t},e}(wi);Pi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1ul4\",Pi);var zi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l){var c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,i,a,o,s,l)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c){var u=10*t,f=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=i,this.int16[u+4]=a,this.int16[u+5]=o,this.uint32[f+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t},e}(wi);zi.prototype.bytesPerElement=20,Dn(\"StructArrayLayout6i1ul2ui20\",zi);var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Oi.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i2i2i12\",Oi);var Di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n,i)},e.prototype.emplace=function(t,e,r,n,i,a){var o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=i,this.int16[s+7]=a,t},e}(wi);Di.prototype.bytesPerElement=16,Dn(\"StructArrayLayout2f1f2i16\",Di);var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(wi);Ri.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2ub2f12\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(wi);Fi.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3ui6\",Fi);var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v){var y=24*t,x=12*t,b=48*t;return this.int16[y+0]=e,this.int16[y+1]=r,this.uint16[y+2]=n,this.uint16[y+3]=i,this.uint32[x+2]=a,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[y+10]=l,this.uint16[y+11]=c,this.uint16[y+12]=u,this.float32[x+7]=f,this.float32[x+8]=h,this.uint8[b+36]=p,this.uint8[b+37]=d,this.uint8[b+38]=g,this.uint32[x+10]=m,this.int16[y+22]=v,t},e}(wi);Bi.prototype.bytesPerElement=48,Dn(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S){var E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E){var C=34*t,L=17*t;return this.int16[C+0]=e,this.int16[C+1]=r,this.int16[C+2]=n,this.int16[C+3]=i,this.int16[C+4]=a,this.int16[C+5]=o,this.int16[C+6]=s,this.int16[C+7]=l,this.uint16[C+8]=c,this.uint16[C+9]=u,this.uint16[C+10]=f,this.uint16[C+11]=h,this.uint16[C+12]=p,this.uint16[C+13]=d,this.uint16[C+14]=g,this.uint16[C+15]=m,this.uint16[C+16]=v,this.uint16[C+17]=y,this.uint16[C+18]=x,this.uint16[C+19]=b,this.uint16[C+20]=_,this.uint16[C+21]=w,this.uint16[C+22]=T,this.uint32[L+12]=k,this.float32[L+13]=M,this.float32[L+14]=A,this.float32[L+15]=S,this.float32[L+16]=E,t},e}(wi);Ni.prototype.bytesPerElement=68,Dn(\"StructArrayLayout8i15ui1ul4f68\",Ni);var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.float32[1*t+0]=e,t},e}(wi);ji.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1f4\",ji);var Ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(wi);Ui.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3i6\",Ui);var Vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=4*t;return this.uint32[2*t+0]=e,this.uint16[i+2]=r,this.uint16[i+3]=n,t},e}(wi);Vi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout1ul2ui8\",Vi);var qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(wi);qi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2ui4\",qi);var Hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint16[1*t+0]=e,t},e}(wi);Hi.prototype.bytesPerElement=2,Dn(\"StructArrayLayout1ui2\",Hi);var Gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(wi);Gi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2f8\",Gi);var Yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(wi);Yi.prototype.bytesPerElement=16,Dn(\"StructArrayLayout4f16\",Yi);var Wi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(_i);Wi.prototype.size=20;var Xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Wi(this,t)},e}(zi);Dn(\"CollisionBoxArray\",Xi);var Zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0},associatedIconIndex:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},r.associatedIconIndex.get=function(){return this._structArray.int16[this._pos2+22]},Object.defineProperties(e.prototype,r),e}(_i);Zi.prototype.size=48;var Ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Zi(this,t)},e}(Bi);Dn(\"PlacedSymbolArray\",Ji);var Ki=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},placedIconSymbolIndex:{configurable:!0},verticalPlacedIconSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},verticalIconBoxStartIndex:{configurable:!0},verticalIconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},numVerticalIconVertices:{configurable:!0},useRuntimeCollisionCircles:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},textOffset0:{configurable:!0},textOffset1:{configurable:!0},collisionCircleDiameter:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.placedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+6]},r.verticalPlacedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+7]},r.key.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+14]},r.verticalIconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+15]},r.verticalIconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+16]},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+17]},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+18]},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+19]},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+20]},r.numVerticalIconVertices.get=function(){return this._structArray.uint16[this._pos2+21]},r.useRuntimeCollisionCircles.get=function(){return this._structArray.uint16[this._pos2+22]},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+12]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+12]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+13]},r.textOffset0.get=function(){return this._structArray.float32[this._pos4+14]},r.textOffset1.get=function(){return this._structArray.float32[this._pos4+15]},r.collisionCircleDiameter.get=function(){return this._structArray.float32[this._pos4+16]},Object.defineProperties(e.prototype,r),e}(_i);Ki.prototype.size=68;var Qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Ki(this,t)},e}(Ni);Dn(\"SymbolInstanceArray\",Qi);var $i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e}(ji);Dn(\"GlyphOffsetArray\",$i);var ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e}(Ui);Dn(\"SymbolLineVertexArray\",ta);var ea=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},Object.defineProperties(e.prototype,r),e}(_i);ea.prototype.size=8;var ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new ea(this,t)},e}(Vi);Dn(\"FeatureIndexArray\",ra);var na=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,ia=function(t){void 0===t&&(t=[]),this.segments=t};function aa(t,e){return 256*(t=l(Math.floor(t),0,255))+l(Math.floor(e),0,255)}ia.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>ia.MAX_VERTEX_ARRAY_LENGTH&&_(\"Max vertices per segment is \"+ia.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>ia.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},ia.prototype.get=function(){return this.segments},ia.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},ia.simpleSegment=function(t,e,r,n){return new ia([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},ia.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,Dn(\"SegmentVector\",ia);var oa=Ti([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint8\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint8\"}]),sa=e((function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(n=t.length-(r=3&t.length),i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}})),la=e((function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}})),ca=sa,ua=la;ca.murmur3=sa,ca.murmur2=ua;var fa=function(){this.ids=[],this.positions=[],this.indexed=!1};fa.prototype.add=function(t,e,r,n){this.ids.push(pa(t)),this.positions.push(e,r,n)},fa.prototype.getPositions=function(t){for(var e=pa(t),r=0,n=this.ids.length-1;r<n;){var i=r+n>>1;this.ids[i]>=e?n=i:r=i+1}for(var a=[];this.ids[r]===e;)a.push({index:this.positions[3*r],start:this.positions[3*r+1],end:this.positions[3*r+2]}),r++;return a},fa.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){for(;n<i;){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;da(e,o,s),da(r,3*o,3*s),da(r,3*o+1,3*s+1),da(r,3*o+2,3*s+2)}s-n<i-s?(t(e,r,n,s),n=s+1):(t(e,r,s+1,i),i=s)}}(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}},fa.deserialize=function(t){var e=new fa;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e};var ha=Math.pow(2,53)-1;function pa(t){var e=+t;return!isNaN(e)&&e<=ha?e:ca(String(t))}function da(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Dn(\"FeaturePositionMap\",fa);var ga=function(t,e){this.gl=t.gl,this.location=e},ma=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(ga),va=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(ga),ya=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(ga),xa=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(ga),ba=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(ga),_a=function(t){function e(e,r){t.call(this,e,r),this.current=Kt.transparent}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(ga),wa=new Float32Array(16),Ta=function(t){function e(e,r){t.call(this,e,r),this.current=wa}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(ga);function ka(t){return[aa(255*t.r,255*t.g),aa(255*t.b,255*t.a)]}var Ma=function(t,e,r){this.value=t,this.uniformNames=e.map((function(t){return\"u_\"+t})),this.type=r};Ma.prototype.setUniform=function(t,e,r){t.set(r.constantOr(this.value))},Ma.prototype.getBinding=function(t,e,r){return\"color\"===this.type?new _a(t,e):new va(t,e)};var Aa=function(t,e){this.uniformNames=e.map((function(t){return\"u_\"+t})),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1};Aa.prototype.setConstantPatternPositions=function(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr},Aa.prototype.setUniform=function(t,e,r,n){var i=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;i&&t.set(i)},Aa.prototype.getBinding=function(t,e,r){return\"u_pattern\"===r.substr(0,9)?new ba(t,e):new va(t,e)};var Sa=function(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}})),this.paintVertexArray=new n};Sa.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.paintVertexArray.length,o=this.expression.evaluate(new ii(0),e,{},n,[],i);this.paintVertexArray.resize(t),this._setPaintValue(a,t,o)},Sa.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,i)},Sa.prototype._setPaintValue=function(t,e,r){if(\"color\"===this.type)for(var n=ka(r),i=t;i<e;i++)this.paintVertexArray.emplace(i,n[0],n[1]);else{for(var a=t;a<e;a++)this.paintVertexArray.emplace(a,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}},Sa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Sa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()};var Ea=function(t,e,r,n,i,a){this.expression=t,this.uniformNames=e.map((function(t){return\"u_\"+t+\"_t\"})),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}})),this.paintVertexArray=new a};Ea.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.expression.evaluate(new ii(this.zoom),e,{},n,[],i),o=this.expression.evaluate(new ii(this.zoom+1),e,{},n,[],i),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,a,o)},Ea.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:this.zoom},r,n),a=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,i,a)},Ea.prototype._setPaintValue=function(t,e,r,n){if(\"color\"===this.type)for(var i=ka(r),a=ka(n),o=t;o<e;o++)this.paintVertexArray.emplace(o,i[0],i[1],a[0],a[1]);else{for(var s=t;s<e;s++)this.paintVertexArray.emplace(s,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}},Ea.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Ea.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Ea.prototype.setUniform=function(t,e){var r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=l(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)},Ea.prototype.getBinding=function(t,e,r){return new va(t,e)};var Ca=function(t,e,r,n,i,a){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=a,this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};Ca.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)},Ca.prototype.updatePaintArray=function(t,e,r,n,i){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],i)},Ca.prototype._setPaintValues=function(t,e,r,n){if(n&&r){var i=n[r.min],a=n[r.mid],o=n[r.max];if(i&&a&&o)for(var s=t;s<e;s++)this.zoomInPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],i.tl[0],i.tl[1],i.br[0],i.br[1],a.pixelRatio,i.pixelRatio),this.zoomOutPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],o.tl[0],o.tl[1],o.br[0],o.br[1],a.pixelRatio,o.pixelRatio)}},Ca.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,oa.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,oa.members,this.expression.isStateDependent))},Ca.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()};var La=function(t,e,r,n){this.binders={},this.layoutAttributes=n,this._buffers=[];var i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof fi&&Lr(o.property.specification)){var s=Pa(a,t.type),l=o.value,c=o.property.specification.type,u=o.property.useIntegerZoom,f=o.property.specification[\"property-type\"],h=\"cross-faded\"===f||\"cross-faded-data-driven\"===f;if(\"constant\"===l.kind)this.binders[a]=h?new Aa(l.value,s):new Ma(l.value,s,c),i.push(\"/u_\"+a);else if(\"source\"===l.kind||h){var p=za(a,c,\"source\");this.binders[a]=h?new Ca(l,c,u,e,p,t.id):new Sa(l,s,c,p),i.push(\"/a_\"+a)}else{var d=za(a,c,\"composite\");this.binders[a]=new Ea(l,s,c,u,e,d),i.push(\"/z_\"+a)}}}this.cacheKey=i.sort().join(\"\")};La.prototype.getMaxValue=function(t){var e=this.binders[t];return e instanceof Sa||e instanceof Ea?e.maxValue:0},La.prototype.populatePaintArrays=function(t,e,r,n,i){for(var a in this.binders){var o=this.binders[a];(o instanceof Sa||o instanceof Ea||o instanceof Ca)&&o.populatePaintArray(t,e,r,n,i)}},La.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders){var n=this.binders[r];n instanceof Aa&&n.setConstantPatternPositions(t,e)}},La.prototype.updatePaintArrays=function(t,e,r,n,i){var a=!1;for(var o in t)for(var s=0,l=e.getPositions(o);s<l.length;s+=1){var c=l[s],u=r.feature(c.index);for(var f in this.binders){var h=this.binders[f];if((h instanceof Sa||h instanceof Ea||h instanceof Ca)&&!0===h.expression.isStateDependent){var p=n.paint.get(f);h.expression=p.value,h.updatePaintArray(c.start,c.end,u,t[o],i),a=!0}}}return a},La.prototype.defines=function(){var t=[];for(var e in this.binders){var r=this.binders[e];(r instanceof Ma||r instanceof Aa)&&t.push.apply(t,r.uniformNames.map((function(t){return\"#define HAS_UNIFORM_\"+t})))}return t},La.prototype.getPaintVertexBuffers=function(){return this._buffers},La.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders){var i=this.binders[n];if(i instanceof Ma||i instanceof Aa||i instanceof Ea)for(var a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s],s);r.push({name:s,property:n,binding:l})}}}return r},La.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property;this.binders[l].setUniform(o.binding,n,r.get(l),s)}},La.prototype.updatePaintBuffers=function(t){for(var e in this._buffers=[],this.binders){var r=this.binders[e];if(t&&r instanceof Ca){var n=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;n&&this._buffers.push(n)}else(r instanceof Sa||r instanceof Ea)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}},La.prototype.upload=function(t){for(var e in this.binders){var r=this.binders[e];(r instanceof Sa||r instanceof Ea||r instanceof Ca)&&r.upload(t)}this.updatePaintBuffers()},La.prototype.destroy=function(){for(var t in this.binders){var e=this.binders[t];(e instanceof Sa||e instanceof Ea||e instanceof Ca)&&e.destroy()}};var Ia=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=new La(o,r,n,t)}this.needsUpload=!1,this._featureMap=new fa,this._bufferOffset=0};function Pa(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function za(t,e,r){var n={color:{source:Gi,composite:Yi},number:{source:ji,composite:Gi}},i=function(t){return{\"line-pattern\":{source:Ci,composite:Ci},\"fill-pattern\":{source:Ci,composite:Ci},\"fill-extrusion-pattern\":{source:Ci,composite:Ci}}[t]}(t);return i&&i[r]||n[e][r]}Ia.prototype.populatePaintArrays=function(t,e,r,n,i,a){for(var o in this.programConfigurations)this.programConfigurations[o].populatePaintArrays(t,e,n,i,a);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0},Ia.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,this._featureMap,e,o,n)||this.needsUpload}},Ia.prototype.get=function(t){return this.programConfigurations[t]},Ia.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Ia.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},Dn(\"ConstantBinder\",Ma),Dn(\"CrossFadedConstantBinder\",Aa),Dn(\"SourceExpressionBinder\",Sa),Dn(\"CrossFadedCompositeBinder\",Ca),Dn(\"CompositeExpressionBinder\",Ea),Dn(\"ProgramConfiguration\",La,{omit:[\"_buffers\"]}),Dn(\"ProgramConfigurationSet\",Ia);var Oa={min:-1*Math.pow(2,14),max:Math.pow(2,14)-1};function Da(t){for(var e=8192/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<Oa.min||o.x>Oa.max||o.y<Oa.min||o.y>Oa.max)&&(_(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\"),o.x=l(o.x,Oa.min,Oa.max),o.y=l(o.y,Oa.min,Oa.max))}return r}function Ra(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var Fa=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.segments=new ia,this.programConfigurations=new Ia(na,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function Ba(t,e){for(var r=0;r<t.length;r++)if(Wa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Wa(t,e[n]))return!0;return!!Va(t,e)}function Na(t,e,r){return!!Wa(t,e)||!!Ha(e,t,r)}function ja(t,e){if(1===t.length)return Ya(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Wa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ya(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(Va(t,e[o]))return!0;return!1}function Ua(t,e,r){if(t.length>1){if(Va(t,e))return!0;for(var n=0;n<e.length;n++)if(Ha(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(Ha(t[i],e,r))return!0;return!1}function Va(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(qa(n,i,e[a],e[a+1]))return!0;return!1}function qa(t,e,r,n){return w(t,r,n)!==w(e,r,n)&&w(t,e,r)!==w(t,e,n)}function Ha(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(Ga(t,e[i-1],e[i])<n)return!0;return!1}function Ga(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return t.distSqr(i<0?e:i>1?r:r.sub(e)._mult(i)._add(e))}function Ya(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)(n=r[s]).y>e.y!=(i=r[l]).y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Wa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Xa(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=w(t,e,r[0]);return a!==w(t,e,r[1])||a!==w(t,e,r[2])||a!==w(t,e,r[3])}function Za(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function Ja(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ka(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++)s.push(t[l].sub(o));return s}Fa.prototype.populate=function(t,e,r){var n=this.layers[0],i=[],a=null;\"circle\"===n.type&&(a=n.layout.get(\"circle-sort-key\"));for(var o=0,s=t;o<s.length;o+=1){var l=s[o],c=l.feature,u=l.id,f=l.index,h=l.sourceLayerIndex,p=this.layers[0]._featureFilter.needGeometry,d={type:c.type,id:u,properties:c.properties,geometry:p?Da(c):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),d,r)){p||(d.geometry=Da(c));var g=a?a.evaluate(d,{},r):void 0;i.push({id:u,properties:c.properties,type:c.type,sourceLayerIndex:h,index:f,geometry:d.geometry,patterns:{},sortKey:g})}}a&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var m=0,v=i;m<v.length;m+=1){var y=v[m],x=y.geometry,b=y.index,_=y.sourceLayerIndex,w=t[b].feature;this.addFeature(y,x,b,r),e.featureIndex.insert(w,x,b,_,this.index)}},Fa.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Fa.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Fa.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Fa.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,na),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Fa.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Fa.prototype.addFeature=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1)for(var o=0,s=a[i];o<s.length;o+=1){var l=s[o],c=l.x,u=l.y;if(!(c<0||c>=8192||u<0||u>=8192)){var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),h=f.vertexLength;Ra(this.layoutVertexArray,c,u,-1,-1),Ra(this.layoutVertexArray,c,u,1,-1),Ra(this.layoutVertexArray,c,u,1,1),Ra(this.layoutVertexArray,c,u,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),f.vertexLength+=4,f.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)},Dn(\"CircleBucket\",Fa,{omit:[\"layers\"]});var Qa=new yi({\"circle-sort-key\":new di(At.layout_circle[\"circle-sort-key\"])}),$a={paint:new yi({\"circle-radius\":new di(At.paint_circle[\"circle-radius\"]),\"circle-color\":new di(At.paint_circle[\"circle-color\"]),\"circle-blur\":new di(At.paint_circle[\"circle-blur\"]),\"circle-opacity\":new di(At.paint_circle[\"circle-opacity\"]),\"circle-translate\":new pi(At.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new pi(At.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new pi(At.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new pi(At.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new di(At.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new di(At.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new di(At.paint_circle[\"circle-stroke-opacity\"])}),layout:Qa},to=\"undefined\"!=typeof Float32Array?Float32Array:Array;function eo(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function ro(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,t[4]=(x=r[4])*n+(b=r[5])*s+(_=r[6])*f+(w=r[7])*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,t[8]=(x=r[8])*n+(b=r[9])*s+(_=r[10])*f+(w=r[11])*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,t[12]=(x=r[12])*n+(b=r[13])*s+(_=r[14])*f+(w=r[15])*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)});var no,io=ro;function ao(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}no=new to(3),to!=Float32Array&&(no[0]=0,no[1]=0,no[2]=0),function(){var t=new to(4);to!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var oo=(function(){var t=new to(2);to!=Float32Array&&(t[0]=0,t[1]=0)}(),function(t){function e(e){t.call(this,e,$a)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new Fa(t)},e.prototype.queryRadius=function(t){var e=t;return Za(\"circle-radius\",this,e)+Za(\"circle-stroke-width\",this,e)+Ja(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ka(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),f=u?l:function(t,e){return t.map((function(t){return so(t,e)}))}(l,s),h=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,m=d[p];g<m.length;g+=1){var v=m[g],y=u?v:so(v,s),x=h,b=ao([],[v.x,v.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),Na(f,y,x))return!0}return!1},e}(xi));function so(t,e){var r=ao([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var lo=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Fa);function co(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function uo(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=co({},{width:n,height:i},r);fo(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function fo(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,f=0;f<i.width*a;f++)s[u+f]=o[c+f];return e}Dn(\"HeatmapBucket\",lo,{omit:[\"layers\"]});var ho=function(t,e){co(this,t,1,e)};ho.prototype.resize=function(t){uo(this,t,1)},ho.prototype.clone=function(){return new ho({width:this.width,height:this.height},new Uint8Array(this.data))},ho.copy=function(t,e,r,n,i){fo(t,e,r,n,i,1)};var po=function(t,e){co(this,t,4,e)};po.prototype.resize=function(t){uo(this,t,4)},po.prototype.replace=function(t,e){e?this.data.set(t):this.data=t instanceof Uint8ClampedArray?new Uint8Array(t.buffer):t},po.prototype.clone=function(){return new po({width:this.width,height:this.height},new Uint8Array(this.data))},po.copy=function(t,e,r,n,i){fo(t,e,r,n,i,4)},Dn(\"AlphaImage\",ho),Dn(\"RGBAImage\",po);var go={paint:new yi({\"heatmap-radius\":new di(At.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new di(At.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new pi(At.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new vi(At.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new pi(At.paint_heatmap[\"heatmap-opacity\"])})};function mo(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new po({width:256,height:1},r)}var vo=function(t){function e(e){t.call(this,e,go),this._updateColorRamp()}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new lo(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){this.colorRamp=mo(this._transitionablePaint._values[\"heatmap-color\"].value.expression,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(xi),yo={paint:new yi({\"hillshade-illumination-direction\":new pi(At.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new pi(At.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new pi(At.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new pi(At.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new pi(At.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new pi(At.paint_hillshade[\"hillshade-accent-color\"])})},xo=function(t){function e(e){t.call(this,e,yo)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(xi),bo=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,_o=To,wo=To;function To(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,f=u?e[0]*r:t.length,h=ko(t,0,f,r,!0),p=[];if(!h||h.next===h.prev)return p;if(u&&(h=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=ko(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(Do(o));for(s.sort(Io),i=0;i<s.length;i++)Po(s[i],r),r=Mo(r,r.next);return r}(t,e,h,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<f;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return Ao(h,p,r,n,i,c),p}function ko(t,e,r,n,i){var a,o;if(i===Xo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=Go(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=Go(a,t[a],t[a+1],o);return o&&No(o,o.next)&&(Yo(o),o=o.next),o}function Mo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!No(n,n.next)&&0!==Bo(n.prev,n,n.next))n=n.next;else{if(Yo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function Ao(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=Oo(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?Eo(t,n,i,a):So(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),Yo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?Ao(t=Co(Mo(t),e,r),e,r,n,i,a,2):2===o&&Lo(t,e,r,n,i,a):Ao(Mo(t),e,r,n,i,a,1);break}}}function So(t){var e=t.prev,r=t,n=t.next;if(Bo(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(Ro(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&Bo(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function Eo(t,e,r,n){var i=t.prev,a=t,o=t.next;if(Bo(i,a,o)>=0)return!1;for(var s=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,l=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,c=Oo(i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,e,r,n),u=Oo(s,l,e,r,n),f=t.prevZ,h=t.nextZ;f&&f.z>=c&&h&&h.z<=u;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;if(f=f.prevZ,h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}for(;f&&f.z>=c;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;f=f.prevZ}for(;h&&h.z<=u;){if(h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}return!0}function Co(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!No(i,a)&&jo(i,n,n.next,a)&&qo(i,a)&&qo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),Yo(n),Yo(n.next),n=t=a),n=n.next}while(n!==t);return Mo(n)}function Lo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&Fo(o,s)){var l=Ho(o,s);return o=Mo(o,o.next),l=Mo(l,l.next),Ao(o,e,r,n,i,a),void Ao(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function Io(t,e){return t.x-e.x}function Po(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&Ro(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),qo(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&zo(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=Ho(e,t);Mo(e,e.next),Mo(r,r.next)}}function zo(t,e){return Bo(t.prev,t,e.prev)<0&&Bo(e.next,t,t.next)<0}function Oo(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Do(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function Ro(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function Fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&jo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(qo(t,e)&&qo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(Bo(t.prev,t,e.prev)||Bo(t,e.prev,e))||No(t,e)&&Bo(t.prev,t,t.next)>0&&Bo(e.prev,e,e.next)>0)}function Bo(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function No(t,e){return t.x===e.x&&t.y===e.y}function jo(t,e,r,n){var i=Vo(Bo(t,e,r)),a=Vo(Bo(t,e,n)),o=Vo(Bo(r,n,t)),s=Vo(Bo(r,n,e));return i!==a&&o!==s||!(0!==i||!Uo(t,r,e))||!(0!==a||!Uo(t,n,e))||!(0!==o||!Uo(r,t,n))||!(0!==s||!Uo(r,e,n))}function Uo(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function Vo(t){return t>0?1:t<0?-1:0}function qo(t,e){return Bo(t.prev,t,t.next)<0?Bo(t,e,t.next)>=0&&Bo(t,t.prev,e)>=0:Bo(t,e,t.prev)<0||Bo(t,t.next,e)<0}function Ho(t,e){var r=new Wo(t.i,t.x,t.y),n=new Wo(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function Go(t,e,r,n){var i=new Wo(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function Yo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function Wo(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function Xo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function Zo(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var f=e[r],h=n,p=i;for(Jo(e,n,r),a(e[i],f)>0&&Jo(e,n,i);h<p;){for(Jo(e,h,p),h++,p--;a(e[h],f)<0;)h++;for(;a(e[p],f)>0;)p--}0===a(e[n],f)?Jo(e,n,p):Jo(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ko)}function Jo(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ko(t,e){return t<e?-1:t>e?1:0}function Qo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(Zo(a[l],e,1,a[l].length-1,$o),a[l]=a[l].slice(0,e));return a}function $o(t,e){return e.area-t.area}function ts(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function es(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{},i.availableImages),f=c.evaluate({zoom:n},r,{},i.availableImages),h=c.evaluate({zoom:n+1},r,{},i.availableImages);f=f&&f.name?f.name:f,h=h&&h.name?h.name:h,a[u=u&&u.name?u.name:u]=!0,a[f]=!0,a[h]=!0,r.patterns[l.id]={min:u,mid:f,max:h}}}return r}To.deviation=function(t,e,r,n){var i=e&&e.length,a=Math.abs(Xo(t,0,i?e[0]*r:t.length,r));if(i)for(var o=0,s=e.length;o<s;o++)a-=Math.abs(Xo(t,e[o]*r,o<s-1?e[o+1]*r:t.length,r));var l=0;for(o=0;o<n.length;o+=3){var c=n[o]*r,u=n[o+1]*r,f=n[o+2]*r;l+=Math.abs((t[c]-t[f])*(t[u+1]-t[c+1])-(t[c]-t[u])*(t[f+1]-t[c+1]))}return 0===a&&0===l?0:Math.abs((l-a)/a)},To.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&r.holes.push(n+=t[i-1].length)}return r},_o.default=wo;var rs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.indexArray2=new qi,this.programConfigurations=new Ia(bo,t.layers,t.zoom),this.segments=new ia,this.segments2=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};rs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"fill\",this.layers,e);for(var n=this.layers[0].layout.get(\"fill-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r,e.availableImages):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"fill\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},rs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},rs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},rs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},rs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},rs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,bo),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},rs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},rs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray),h=f.vertexLength,p=[],d=[],g=0,m=s;g<m.length;g+=1){var v=m[g];if(0!==v.length){v!==s[0]&&d.push(p.length/2);var y=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),x=y.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(x+v.length-1,x),p.push(v[0].x),p.push(v[0].y);for(var b=1;b<v.length;b++)this.layoutVertexArray.emplaceBack(v[b].x,v[b].y),this.indexArray2.emplaceBack(x+b-1,x+b),p.push(v[b].x),p.push(v[b].y);y.vertexLength+=v.length,y.primitiveLength+=v.length}}for(var _=_o(p,d),w=0;w<_.length;w+=3)this.indexArray.emplaceBack(h+_[w],h+_[w+1],h+_[w+2]);f.vertexLength+=l,f.primitiveLength+=_.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillBucket\",rs,{omit:[\"layers\",\"patternFeatures\"]});var ns=new yi({\"fill-sort-key\":new di(At.layout_fill[\"fill-sort-key\"])}),is={paint:new yi({\"fill-antialias\":new pi(At.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new di(At.paint_fill[\"fill-opacity\"]),\"fill-color\":new di(At.paint_fill[\"fill-color\"]),\"fill-outline-color\":new di(At.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new pi(At.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new pi(At.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new gi(At.paint_fill[\"fill-pattern\"])}),layout:ns},as=function(t){function e(e){t.call(this,e,is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r);var n=this.paint._values[\"fill-outline-color\"];\"constant\"===n.value.kind&&void 0===n.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new rs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ja(Ka(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(xi),os=Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,ss=ls;function ls(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(cs,this,e)}function cs(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function us(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)n+=((r=t[o]).x-(e=t[i]).x)*(e.y+r.y);return n}ls.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ls.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},ls.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},ls.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=ls.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e];t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp((180-360*(r.y+s)/a)*Math.PI/180))-90]}}switch(this.type){case 1:var f=[];for(n=0;n<l.length;n++)f[n]=l[n][0];u(l=f);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=us(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var h={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(h.id=this.id),h};var fs=hs;function hs(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(ps,this,e),this.length=this._features.length}function ps(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function ds(t,e,r){if(3===t){var n=new fs(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}hs.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new ss(this._pbf,e,this.extent,this._keys,this._values)};var gs={VectorTile:function(t,e){this.layers=t.readFields(ds,{},e)},VectorTileFeature:ss,VectorTileLayer:fs},ms=gs.VectorTileFeature.types,vs=Math.pow(2,13);function ys(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*vs)+o,i*vs*2,a*vs*2,Math.round(s))}var xs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Si,this.indexArray=new Fi,this.programConfigurations=new Ia(os,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function bs(t,e){return t.x===e.x&&(t.x<0||t.x>8192)||t.y===e.y&&(t.y<0||t.y>8192)}xs.prototype.populate=function(t,e,r){this.features=[],this.hasPattern=ts(\"fill-extrusion\",this.layers,e);for(var n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.feature,s=a.id,l=a.index,c=a.sourceLayerIndex,u=this.layers[0]._featureFilter.needGeometry,f={type:o.type,id:s,properties:o.properties,geometry:u?Da(o):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),f,r)){var h={id:s,sourceLayerIndex:c,index:l,geometry:u?f.geometry:Da(o),properties:o.properties,type:o.type,patterns:{}};void 0!==o.id&&(h.id=o.id),this.hasPattern?this.features.push(es(\"fill-extrusion\",this.layers,h,this.zoom,e)):this.addFeature(h,h.geometry,l,r,{}),e.featureIndex.insert(o,h.geometry,l,c,this.index,!0)}}},xs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.features;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},xs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},xs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},xs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},xs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,os),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},xs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},xs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,p=s;h<p.length;h+=1){var d=p[h];if(0!==d.length&&!((P=d).every((function(t){return t.x<0}))||P.every((function(t){return t.x>8192}))||P.every((function(t){return t.y<0}))||P.every((function(t){return t.y>8192}))))for(var g=0,m=0;m<d.length;m++){var v=d[m];if(m>=1){var y=d[m-1];if(!bs(v,y)){f.vertexLength+4>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var x=v.sub(y)._perp()._unit(),b=y.dist(v);g+b>32768&&(g=0),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,0,g),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,1,g),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,0,g+=b),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,1,g);var _=f.vertexLength;this.indexArray.emplaceBack(_,_+2,_+1),this.indexArray.emplaceBack(_+1,_+2,_+3),f.vertexLength+=4,f.primitiveLength+=2}}}}if(f.vertexLength+l>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray)),\"Polygon\"===ms[t.type]){for(var w=[],T=[],k=f.vertexLength,M=0,A=s;M<A.length;M+=1){var S=A[M];if(0!==S.length){S!==s[0]&&T.push(w.length/2);for(var E=0;E<S.length;E++){var C=S[E];ys(this.layoutVertexArray,C.x,C.y,0,0,1,1,0),w.push(C.x),w.push(C.y)}}}for(var L=_o(w,T),I=0;I<L.length;I+=3)this.indexArray.emplaceBack(k+L[I],k+L[I+2],k+L[I+1]);f.primitiveLength+=L.length/3,f.vertexLength+=l}}var P;this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillExtrusionBucket\",xs,{omit:[\"layers\",\"features\"]});var _s={paint:new yi({\"fill-extrusion-opacity\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new gi(At[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},ws=function(t){function e(e){t.call(this,e,_s)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new xs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ka(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),f=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),h=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];ao(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,f=n[8]*r,h=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,m=t;g<m.length;g+=1){for(var v=[],y=[],x=0,b=m[g];x<b.length;x+=1){var _=b[x],w=_.x,T=_.y,k=n[0]*w+n[4]*T+n[12],M=n[1]*w+n[5]*T+n[13],A=n[2]*w+n[6]*T+n[14],S=n[3]*w+n[7]*T+n[15],E=A+c,C=S+u,L=k+f,I=M+h,P=A+p,z=S+d,O=new i((k+s)/C,(M+l)/C);O.z=E/C,v.push(O);var D=new i(L/z,I/z);D.z=P/z,y.push(D)}a.push(v),o.push(y)}return[a,o]}(n,f,u,l);return function(t,e,r){var n=1/0;ja(r,e)&&(n=ks(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=[l,a[s+1],o[s+1],o[s],l];Ba(r,c)&&(n=Math.min(n,ks(r,c)))}return n!==1/0&&n}(p[0],p[1],h)},e}(xi);function Ts(t,e){return t.x*e.x+t.y*e.y}function ks(t,e){if(1===t.length){for(var r,n=0,i=e[n++];!r||i.equals(r);)if(!(r=e[n++]))return 1/0;for(;n<e.length;n++){var a=e[n],o=t[0],s=r.sub(i),l=a.sub(i),c=o.sub(i),u=Ts(s,s),f=Ts(s,l),h=Ts(l,l),p=Ts(c,s),d=Ts(c,l),g=u*h-f*f,m=(h*p-f*d)/g,v=(u*d-f*p)/g,y=i.z*(1-m-v)+r.z*m+a.z*v;if(isFinite(y))return y}return 1/0}for(var x=1/0,b=0,_=e;b<_.length;b+=1)x=Math.min(x,_[b].z);return x}var Ms=Ti([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,As=gs.VectorTileFeature.types,Ss=Math.cos(Math.PI/180*37.5),Es=Math.pow(2,14)/.5,Cs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Ei,this.indexArray=new Fi,this.programConfigurations=new Ia(Ms,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};Cs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"line\",this.layers,e);for(var n=this.layers[0].layout.get(\"line-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"line\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},Cs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Cs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},Cs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Cs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Cs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ms),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Cs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Cs.prototype.addFeature=function(t,e,r,n,i){for(var a=this.layers[0].layout,o=a.get(\"line-join\").evaluate(t,{}),s=a.get(\"line-cap\"),l=a.get(\"line-miter-limit\"),c=a.get(\"line-round-limit\"),u=0,f=e;u<f.length;u+=1)this.addLine(f[u],t,o,s,l,c);this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Cs.prototype.addLine=function(t,e,r,n,i,a){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var o=0;o<t.length-1;o++)this.totalDistance+=t[o].dist(t[o+1]);this.updateScaledDistance()}for(var s=\"Polygon\"===As[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){\"bevel\"===r&&(i=1.05);var u,f=this.overscaling<=16?122880/(512*this.overscaling):0,h=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray),p=void 0,d=void 0,g=void 0,m=void 0;this.e1=this.e2=-1,s&&(m=t[c].sub(u=t[l-2])._unit()._perp());for(var v=c;v<l;v++)if(!(d=v===l-1?s?t[c+1]:void 0:t[v+1])||!t[v].equals(d)){m&&(g=m),u&&(p=u),u=t[v],m=d?d.sub(u)._unit()._perp():g;var y=(g=g||m).add(m);0===y.x&&0===y.y||y._unit();var x=g.x*m.x+g.y*m.y,b=y.x*m.x+y.y*m.y,_=0!==b?1/b:1/0,w=2*Math.sqrt(2-2*b),T=b<Ss&&p&&d,k=g.x*m.y-g.y*m.x>0;if(T&&v>c){var M=u.dist(p);if(M>2*f){var A=u.sub(u.sub(p)._mult(f/M)._round());this.updateDistance(p,A),this.addCurrentVertex(A,g,0,0,h),p=A}}var S=p&&d,E=S?r:s?\"butt\":n;if(S&&\"round\"===E&&(_<a?E=\"miter\":_<=2&&(E=\"fakeround\")),\"miter\"===E&&_>i&&(E=\"bevel\"),\"bevel\"===E&&(_>2&&(E=\"flipbevel\"),_<i&&(E=\"miter\")),p&&this.updateDistance(p,u),\"miter\"===E)y._mult(_),this.addCurrentVertex(u,y,0,0,h);else if(\"flipbevel\"===E){if(_>100)y=m.mult(-1);else{var C=_*g.add(m).mag()/g.sub(m).mag();y._perp()._mult(C*(k?-1:1))}this.addCurrentVertex(u,y,0,0,h),this.addCurrentVertex(u,y.mult(-1),0,0,h)}else if(\"bevel\"===E||\"fakeround\"===E){var L=-Math.sqrt(_*_-1),I=k?L:0,P=k?0:L;if(p&&this.addCurrentVertex(u,g,I,P,h),\"fakeround\"===E)for(var z=Math.round(180*w/Math.PI/20),O=1;O<z;O++){var D=O/z;if(.5!==D){var R=D-.5;D+=D*R*(D-1)*((1.0904+x*(x*(3.55645-1.43519*x)-3.2452))*R*R+(.848013+x*(.215638*x-1.06021)))}var F=m.sub(g)._mult(D)._add(g)._unit()._mult(k?-1:1);this.addHalfVertex(u,F.x,F.y,!1,k,0,h)}d&&this.addCurrentVertex(u,m,-I,-P,h)}else if(\"butt\"===E)this.addCurrentVertex(u,y,0,0,h);else if(\"square\"===E){var B=p?1:-1;this.addCurrentVertex(u,y,B,B,h)}else\"round\"===E&&(p&&(this.addCurrentVertex(u,g,0,0,h),this.addCurrentVertex(u,g,1,1,h,!0)),d&&(this.addCurrentVertex(u,m,-1,-1,h,!0),this.addCurrentVertex(u,m,0,0,h)));if(T&&v<l-1){var N=u.dist(d);if(N>2*f){var j=u.add(d.sub(u)._mult(f/N)._round());this.updateDistance(u,j),this.addCurrentVertex(j,m,0,0,h),u=j}}}}},Cs.prototype.addCurrentVertex=function(t,e,r,n,i,a){void 0===a&&(a=!1);var o=e.y*n-e.x,s=-e.y-e.x*n;this.addHalfVertex(t,e.x+e.y*r,e.y-e.x*r,a,!1,r,i),this.addHalfVertex(t,o,s,a,!0,-n,i),this.distance>Es/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,i,a))},Cs.prototype.addHalfVertex=function(t,e,r,n,i,a,o){var s=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((t.x<<1)+(n?1:0),(t.y<<1)+(i?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===a?0:a<0?-1:1)|(63&s)<<2,s>>6);var l=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,l),o.primitiveLength++),i?this.e2=l:this.e1=l},Cs.prototype.updateScaledDistance=function(){this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(Es-1):this.distance},Cs.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.updateScaledDistance()},Dn(\"LineBucket\",Cs,{omit:[\"layers\",\"patternFeatures\"]});var Ls=new yi({\"line-cap\":new pi(At.layout_line[\"line-cap\"]),\"line-join\":new di(At.layout_line[\"line-join\"]),\"line-miter-limit\":new pi(At.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new pi(At.layout_line[\"line-round-limit\"]),\"line-sort-key\":new di(At.layout_line[\"line-sort-key\"])}),Is={paint:new yi({\"line-opacity\":new di(At.paint_line[\"line-opacity\"]),\"line-color\":new di(At.paint_line[\"line-color\"]),\"line-translate\":new pi(At.paint_line[\"line-translate\"]),\"line-translate-anchor\":new pi(At.paint_line[\"line-translate-anchor\"]),\"line-width\":new di(At.paint_line[\"line-width\"]),\"line-gap-width\":new di(At.paint_line[\"line-gap-width\"]),\"line-offset\":new di(At.paint_line[\"line-offset\"]),\"line-blur\":new di(At.paint_line[\"line-blur\"]),\"line-dasharray\":new mi(At.paint_line[\"line-dasharray\"]),\"line-pattern\":new gi(At.paint_line[\"line-pattern\"]),\"line-gradient\":new vi(At.paint_line[\"line-gradient\"])}),layout:Ls},Ps=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new ii(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=u({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(di))(Is.paint.properties[\"line-width\"].specification);Ps.useIntegerZoom=!0;var zs=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){this.gradient=mo(this._transitionablePaint._values[\"line-gradient\"].value.expression,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r),this.paint._values[\"line-floorwidth\"]=Ps.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new Cs(t)},e.prototype.queryRadius=function(t){var e=t,r=Os(Za(\"line-width\",this,e),Za(\"line-gap-width\",this,e)),n=Za(\"line-offset\",this,e);return r/2+Math.abs(n)+Ja(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ka(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*Os(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l],u=o[l+1],f=0===l?n:c.sub(o[l-1])._unit()._perp(),h=l===o.length-1?n:u.sub(c)._unit()._perp(),p=f._add(h)._unit();p._mult(1/(p.x*h.x+p.y*h.y)),s.push(p._mult(e)._add(c))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Wa(t,i[a]))return!0;if(Ua(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(xi);function Os(t,e){return e>0?e+2*t:t}var Ds=Ti([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),Rs=Ti([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),Fs=(Ti([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),Ti([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),Bs=(Ti([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]),Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),Ns=Ti([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);function js(t,e,r){return t.sections.forEach((function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),ni.applyArabicShaping&&(t=ni.applyArabicShaping(t)),t}(t.text,e,r)})),t}Ti([{name:\"triangle\",components:3,type:\"Uint16\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",components:2,name:\"textOffset\"},{type:\"Float32\",name:\"collisionCircleDiameter\"}]),Ti([{type:\"Float32\",name:\"offsetX\"}]),Ti([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var Us={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},Vs=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},qs=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Hs=Gs;function Gs(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}Gs.Varint=0,Gs.Fixed64=1,Gs.Bytes=2,Gs.Fixed32=5;var Ys=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf8\");function Ws(t){return t.type===Gs.Bytes?t.readVarint()+t.pos:t.pos+1}function Xs(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function Zs(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function Js(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function Ks(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function Qs(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function $s(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function tl(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function el(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function rl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function nl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function il(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function al(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function ol(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function sl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}function ll(t,e,r){1===t&&r.readMessage(cl,e)}function cl(t,e,r){if(3===t){var n=r.readMessage(ul,{}),i=n.width,a=n.height,o=n.left,s=n.top,l=n.advance;e.push({id:n.id,bitmap:new ho({width:i+6,height:a+6},n.bitmap),metrics:{width:i,height:a,left:o,top:s,advance:l}})}}function ul(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}function fl(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort((function(t,e){return e.h-t.h}));for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var f=u[c],h=o.length-1;h>=0;h--){var p=o[h];if(!(f.w>p.w||f.h>p.h)){if(f.x=p.x,f.y=p.y,l=Math.max(l,f.y+f.h),s=Math.max(s,f.x+f.w),f.w===p.w&&f.h===p.h){var d=o.pop();h<o.length&&(o[h]=d)}else f.h===p.h?(p.x+=f.w,p.w-=f.w):f.w===p.w?(p.y+=f.h,p.h-=f.h):(o.push({x:p.x+f.w,y:p.y,w:p.w-f.w,h:f.h}),p.y+=f.h,p.h-=f.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}Gs.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=al(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=sl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=al(this.buf,this.pos)+4294967296*al(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=al(this.buf,this.pos)+4294967296*sl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Vs(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Vs(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return Xs(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return Xs(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&Ys?function(t,e,r){return Ys.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(o=t[i+2],128==(192&(a=t[i+1]))&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(o=t[i+2],s=t[i+3],128==(192&(a=t[i+1]))&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==Gs.Bytes)return t.push(this.readVarint(e));var r=Ws(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSVarint());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==Gs.Bytes)return t.push(this.readBoolean());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFloat());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==Gs.Bytes)return t.push(this.readDouble());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===Gs.Varint)for(;this.buf[this.pos++]>127;);else if(e===Gs.Bytes)this.pos=this.readVarint()+this.pos;else if(e===Gs.Fixed32)this.pos+=4;else{if(e!==Gs.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,r.buf[r.pos]=127&(t>>>=7)}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&Zs(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),qs(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),qs(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&Zs(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,Gs.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,Js,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,Ks,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,tl,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,Qs,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,$s,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,el,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,rl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,nl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,il,e)},writeBytesField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var hl=function(t,e){var r=e.pixelRatio,n=e.version,i=e.stretchX,a=e.stretchY,o=e.content;this.paddedRect=t,this.pixelRatio=r,this.stretchX=i,this.stretchY=a,this.content=o,this.version=n},pl={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};pl.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},pl.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},pl.tlbr.get=function(){return this.tl.concat(this.br)},pl.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(hl.prototype,pl);var dl=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=fl(i),o=new po({width:a.w||1,height:a.h||1});for(var s in t){var l=t[s],c=r[s].paddedRect;po.copy(l.data,o,{x:0,y:0},{x:c.x+1,y:c.y+1},l.data)}for(var u in e){var f=e[u],h=n[u].paddedRect,p=h.x+1,d=h.y+1,g=f.data.width,m=f.data.height;po.copy(f.data,o,{x:0,y:0},{x:p,y:d},f.data),po.copy(f.data,o,{x:0,y:m-1},{x:p,y:d-1},{width:g,height:1}),po.copy(f.data,o,{x:0,y:0},{x:p,y:d+m},{width:g,height:1}),po.copy(f.data,o,{x:g-1,y:0},{x:p-1,y:d},{width:1,height:m}),po.copy(f.data,o,{x:0,y:0},{x:p+g,y:d},{width:1,height:m})}this.image=o,this.iconPositions=r,this.patternPositions=n};dl.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new hl(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},dl.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},dl.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl;r.update(e.data,void 0,{x:n[0],y:n[1]})}},Dn(\"ImagePosition\",hl),Dn(\"ImageAtlas\",dl);var gl={horizontal:1,vertical:2,horizontalOnly:3},ml=function(){this.scale=1,this.fontStack=\"\",this.imageName=null};ml.forText=function(t,e){var r=new ml;return r.scale=t||1,r.fontStack=e,r},ml.forImage=function(t){var e=new ml;return e.imageName=t,e};var vl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null};function yl(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=vl.fromFeature(t,i);f===gl.vertical&&v.verticalizePunctuation();var y=ni.processBidirectionalText,x=ni.processStyledBidirectionalText;if(y&&1===v.sections.length){m=[];for(var b=0,_=y(v.toString(),Ml(v,c,a,e,n,p,d));b<_.length;b+=1){var w=_[b],T=new vl;T.text=w,T.sections=v.sections;for(var k=0;k<w.length;k++)T.sectionIndex.push(0);m.push(T)}}else if(x){m=[];for(var M=0,A=x(v.text,v.sectionIndex,Ml(v,c,a,e,n,p,d));M<A.length;M+=1){var S=A[M],E=new vl;E.text=S[0],E.sectionIndex=S[1],E.sections=v.sections,m.push(E)}}else m=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(v,Ml(v,c,a,e,n,p,d));var C=[],L={positionedLines:C,text:v.toString(),top:u[1],bottom:u[1],left:u[0],right:u[0],writingMode:f,iconsInText:!1,verticalizable:!1};return function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=0,p=-17,d=0,g=0,m=\"right\"===s?1:\"left\"===s?0:.5,v=0,y=0,x=i;y<x.length;y+=1){var b=x[y];b.trim();var _=b.getMaxScale(),w=24*(_-1),T={positionedGlyphs:[],lineOffset:0};t.positionedLines[v]=T;var k=T.positionedGlyphs,M=0;if(b.length()){for(var A=0;A<b.length();A++){var S=b.getSection(A),E=b.getSectionIndex(A),C=b.getCharCode(A),L=0,I=null,P=null,z=null,O=24,D=!(l===gl.horizontal||!u&&!Hn(C)||u&&(xl[C]||(H=C,Vn.Arabic(H)||Vn[\"Arabic Supplement\"](H)||Vn[\"Arabic Extended-A\"](H)||Vn[\"Arabic Presentation Forms-A\"](H)||Vn[\"Arabic Presentation Forms-B\"](H))));if(S.imageName){var R=n[S.imageName];if(!R)continue;z=S.imageName,t.iconsInText=t.iconsInText||!0,P=R.paddedRect;var F=R.displaySize;S.scale=24*S.scale/f,L=w+(24-F[1]*S.scale),O=(I={width:F[0],height:F[1],left:1,top:-3,advance:D?F[1]:F[0]}).advance;var B=D?F[0]*S.scale-24*_:F[1]*S.scale-24*_;B>0&&B>M&&(M=B)}else{var N=r[S.fontStack],j=N&&N[C];if(j&&j.rect)P=j.rect,I=j.metrics;else{var U=e[S.fontStack],V=U&&U[C];if(!V)continue;I=V.metrics}L=24*(_-S.scale)}D?(t.verticalizable=!0,k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=O*S.scale+c):(k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=I.advance*S.scale+c)}0!==k.length&&(d=Math.max(h-c,d),Sl(k,0,k.length-1,m,M)),h=0;var q=a*_+M;T.lineOffset=Math.max(M,w),p+=q,g=Math.max(q,g),++v}else p+=a,++v}var H,G=p- -17,Y=Al(o),W=Y.horizontalAlign,X=Y.verticalAlign;(function(t,e,r,n,i,a,o,s,l){var c,u=(e-r)*i;c=a!==o?-s*n- -17:(-n*l+.5)*o;for(var f=0,h=t;f<h.length;f+=1)for(var p=0,d=h[f].positionedGlyphs;p<d.length;p+=1){var g=d[p];g.x+=u,g.y+=c}})(t.positionedLines,m,W,X,d,g,a,G,i.length),t.top+=-X*G,t.bottom=t.top+G,t.left+=-W*d,t.right=t.left+d}(L,e,r,n,m,o,s,l,f,c,h,g),!function(t){for(var e=0,r=t;e<r.length;e+=1)if(0!==r[e].positionedGlyphs.length)return!1;return!0}(C)&&L}vl.fromFeature=function(t,e){for(var r=new vl,n=0;n<t.sections.length;n++){var i=t.sections[n];i.image?r.addImageSection(i):r.addTextSection(i,e)}return r},vl.prototype.length=function(){return this.text.length},vl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},vl.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},vl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},vl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;e+=n&&Gn(n)&&!Us[t[r+1]]||i&&Gn(i)&&!Us[t[r-1]]||!Us[t[r]]?t[r]:Us[t[r]]}return e}(this.text)},vl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&xl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&xl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},vl.prototype.substring=function(t,e){var r=new vl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},vl.prototype.toString=function(){return this.text},vl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce((function(e,r){return Math.max(e,t.sections[r].scale)}),0)},vl.prototype.addTextSection=function(t,e){this.text+=t.text,this.sections.push(ml.forText(t.scale,t.fontStack||e));for(var r=this.sections.length-1,n=0;n<t.text.length;++n)this.sectionIndex.push(r)},vl.prototype.addImageSection=function(t){var e=t.image?t.image.name:\"\";if(0!==e.length){var r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(ml.forImage(e)),this.sectionIndex.push(this.sections.length-1)):_(\"Reached maximum number of images 6401\")}else _(\"Can't add FormattedSection with an empty image.\")},vl.prototype.getNextImageSectionCharCode=function(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)};var xl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},bl={};function _l(t,e,r,n,i,a){if(e.imageName){var o=n[e.imageName];return o?o.displaySize[0]*e.scale*24/a+i:0}var s=r[e.fontStack],l=s&&s[t];return l?l.metrics.advance*e.scale+i:0}function wl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function Tl(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function kl(t,e,r,n,i,a){for(var o=null,s=wl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],f=wl(e-u.x,r,i,a)+u.badness;f<=s&&(o=u,s=f)}return{index:t,x:e,priorBreak:o,badness:s}}function Ml(t,e,r,n,i,a,o){if(\"point\"!==a)return[];if(!t)return[];for(var s,l=[],c=function(t,e,r,n,i,a){for(var o=0,s=0;s<t.length();s++){var l=t.getSection(s);o+=_l(t.getCharCode(s),l,n,i,e,a)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,i,o),u=t.text.indexOf(\"\\u200b\")>=0,f=0,h=0;h<t.length();h++){var p=t.getSection(h),d=t.getCharCode(h);if(xl[d]||(f+=_l(d,p,n,i,e,o)),h<t.length()-1){var g=!((s=d)<11904||!(Vn[\"Bopomofo Extended\"](s)||Vn.Bopomofo(s)||Vn[\"CJK Compatibility Forms\"](s)||Vn[\"CJK Compatibility Ideographs\"](s)||Vn[\"CJK Compatibility\"](s)||Vn[\"CJK Radicals Supplement\"](s)||Vn[\"CJK Strokes\"](s)||Vn[\"CJK Symbols and Punctuation\"](s)||Vn[\"CJK Unified Ideographs Extension A\"](s)||Vn[\"CJK Unified Ideographs\"](s)||Vn[\"Enclosed CJK Letters and Months\"](s)||Vn[\"Halfwidth and Fullwidth Forms\"](s)||Vn.Hiragana(s)||Vn[\"Ideographic Description Characters\"](s)||Vn[\"Kangxi Radicals\"](s)||Vn[\"Katakana Phonetic Extensions\"](s)||Vn.Katakana(s)||Vn[\"Vertical Forms\"](s)||Vn[\"Yi Radicals\"](s)||Vn[\"Yi Syllables\"](s)));(bl[d]||g||p.imageName)&&l.push(kl(h+1,f,c,l,Tl(d,t.getCharCode(h+1),g&&u),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(kl(t.length(),f,c,l,0,!0))}function Al(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function Sl(t,e,r,n,i){if(n||i)for(var a=t[r],o=(t[r].x+a.metrics.advance*a.scale)*n,s=e;s<=r;s++)t[s].x-=o,t[s].y+=i}function El(t,e,r,n,i,a){var o,s=t.image;if(s.content){var l=s.content,c=s.pixelRatio||1;o=[l[0]/c,l[1]/c,s.displaySize[0]-l[2]/c,s.displaySize[1]-l[3]/c]}var u,f,h,p,d=e.left*a,g=e.right*a;\"width\"===r||\"both\"===r?(p=i[0]+d-n[3],f=i[0]+g+n[1]):f=(p=i[0]+(d+g-s.displaySize[0])/2)+s.displaySize[0];var m=e.top*a,v=e.bottom*a;return\"height\"===r||\"both\"===r?(u=i[1]+m-n[0],h=i[1]+v+n[2]):h=(u=i[1]+(m+v-s.displaySize[1])/2)+s.displaySize[1],{image:s,top:u,right:f,bottom:h,left:p,collisionPadding:o}}bl[10]=!0,bl[32]=!0,bl[38]=!0,bl[40]=!0,bl[41]=!0,bl[43]=!0,bl[45]=!0,bl[47]=!0,bl[173]=!0,bl[183]=!0,bl[8203]=!0,bl[8208]=!0,bl[8211]=!0,bl[8231]=!0;var Cl=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);function Ll(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new ii(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new ii(s)),maxSize:r.evaluate(new ii(l)),interpolationType:i}}function Il(t,e,r){var n=e.uSize,i=r.lowerSize;return\"source\"===t.kind?i/128:\"composite\"===t.kind?Ue(i/128,r.upperSize/128,e.uSizeT):n}function Pl(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=i?l(rr.interpolationFactor(i,e,t.minZoom,t.maxZoom),0,1):0;\"camera\"===t.kind?n=Ue(t.minSize,t.maxSize,a):r=a}return{uSizeT:r,uSize:n}}Dn(\"Anchor\",Cl);var zl=Object.freeze({__proto__:null,getSizeData:Ll,evaluateSizeForFeature:Il,evaluateSizeForZoom:Pl,SIZE_PACK_FACTOR:128});function Ol(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o],f=t[o+1];if(!f)return!1;var h=t[o-1].angleTo(u)-u.angleTo(f);for(h=Math.abs((h+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:h}),c+=h;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=u.dist(f)}return!0}function Dl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Rl(t,e,r){return t?.6*e*r:0}function Fl(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Bl(t,e,r,n,i,a){for(var o=Rl(r,i,a),s=Fl(r,n)*a,l=0,c=Dl(t)/2,u=0;u<t.length-1;u++){var f=t[u],h=t[u+1],p=f.dist(h);if(l+p>c){var d=(c-l)/p,g=Ue(f.x,h.x,d),m=Ue(f.y,h.y,d),v=new Cl(g,m,h.angleTo(f),u);return v._round(),!o||Ol(t,v,s,o,e)?v:void 0}l+=p}}function Nl(t,e,r,n,i,a,o,s,l){var c=Rl(n,a,o),u=Fl(n,i),f=u*o,h=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-f<e/4&&(e=f+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,f=Dl(e),h=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var m=e[g],v=e[g+1],y=m.dist(v),x=v.angleTo(m);p+n<h+y;){var b=((p+=n)-h)/y,_=Ue(m.x,v.x,b),w=Ue(m.y,v.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=f){var T=new Cl(_,w,x,g);T._round(),i&&!Ol(e,T,o,i,a)||d.push(T)}}h+=y}return l||d.length||s||(d=t(e,h/2,n,i,a,o,s,!0,c)),d}(t,h?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,f,h,!1,l)}function jl(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var f=l[u],h=l[u+1];f.x<e&&h.x<e||(f.x<e?f=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x<e&&(h=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y<r&&h.y<r||(f.y<r?f=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round():h.y<r&&(h=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round()),f.x>=n&&h.x>=n||(f.x>=n?f=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x>=n&&(h=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y>=a&&h.y>=a||(f.y>=a?f=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round():h.y>=a&&(h=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round()),c&&f.equals(c[c.length-1])||o.push(c=[f]),c.push(h)))))}return o}function Ul(t,e,r,n){var a=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2,c=o.paddedRect.h-2,u=t.right-t.left,f=t.bottom-t.top,h=o.stretchX||[[0,l]],p=o.stretchY||[[0,c]],d=function(t,e){return t+e[1]-e[0]},g=h.reduce(d,0),m=p.reduce(d,0),v=l-g,y=c-m,x=0,b=g,_=0,w=m,T=0,k=v,M=0,A=y;if(o.content&&n){var S=o.content;x=Vl(h,0,S[0]),_=Vl(p,0,S[1]),b=Vl(h,S[0],S[2]),w=Vl(p,S[1],S[3]),T=S[0]-x,M=S[1]-_,k=S[2]-S[0]-b,A=S[3]-S[1]-w}var E=function(n,a,l,c){var h=Hl(n.stretch-x,b,u,t.left),p=Gl(n.fixed-T,k,n.stretch,g),d=Hl(a.stretch-_,w,f,t.top),v=Gl(a.fixed-M,A,a.stretch,m),y=Hl(l.stretch-x,b,u,t.left),S=Gl(l.fixed-T,k,l.stretch,g),E=Hl(c.stretch-_,w,f,t.top),C=Gl(c.fixed-M,A,c.stretch,m),L=new i(h,d),I=new i(y,d),P=new i(y,E),z=new i(h,E),O=new i(p/s,v/s),D=new i(S/s,C/s),R=e*Math.PI/180;if(R){var F=Math.sin(R),B=Math.cos(R),N=[B,-F,F,B];L._matMult(N),I._matMult(N),z._matMult(N),P._matMult(N)}var j=n.stretch+n.fixed,U=a.stretch+a.fixed;return{tl:L,tr:I,bl:z,br:P,tex:{x:o.paddedRect.x+1+j,y:o.paddedRect.y+1+U,w:l.stretch+l.fixed-j,h:c.stretch+c.fixed-U},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:O,pixelOffsetBR:D,minFontScaleX:k/s/u,minFontScaleY:A/s/f,isSDF:r}};if(n&&(o.stretchX||o.stretchY))for(var C=ql(h,v,g),L=ql(p,y,m),I=0;I<C.length-1;I++)for(var P=C[I],z=C[I+1],O=0;O<L.length-1;O++)a.push(E(P,L[O],z,L[O+1]));else a.push(E({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return a}function Vl(t,e,r){for(var n=0,i=0,a=t;i<a.length;i+=1){var o=a[i];n+=Math.max(e,Math.min(r,o[1]))-Math.max(e,Math.min(r,o[0]))}return n}function ql(t,e,r){for(var n=[{fixed:-1,stretch:0}],i=0,a=t;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=n[n.length-1];n.push({fixed:s-c.stretch,stretch:c.stretch}),n.push({fixed:s-c.stretch,stretch:c.stretch+(l-s)})}return n.push({fixed:e+1,stretch:r}),n}function Hl(t,e,r,n){return t/e*r+n}function Gl(t,e,r,n){return t-e*r/n}var Yl=function(t,e,r,n,a,o,s,l,c,u){if(this.boxStartIndex=t.length,c){var f=o.top,h=o.bottom,p=o.collisionPadding;p&&(f-=p[1],h+=p[3]);var d=h-f;d>0&&(d=Math.max(10,d),this.circleDiameter=d)}else{var g=o.top*s-l,m=o.bottom*s+l,v=o.left*s-l,y=o.right*s+l,x=o.collisionPadding;if(x&&(v-=x[0]*s,g-=x[1]*s,y+=x[2]*s,m+=x[3]*s),u){var b=new i(v,g),_=new i(y,g),w=new i(v,m),T=new i(y,m),k=u*Math.PI/180;b._rotate(k),_._rotate(k),w._rotate(k),T._rotate(k),v=Math.min(b.x,_.x,w.x,T.x),y=Math.max(b.x,_.x,w.x,T.x),g=Math.min(b.y,_.y,w.y,T.y),m=Math.max(b.y,_.y,w.y,T.y)}t.emplaceBack(e.x,e.y,v,g,y,m,r,n,a)}this.boxEndIndex=t.length},Wl=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=Xl),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function Xl(t,e){return t<e?-1:t>e?1:0}function Zl(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var f=Math.min(o-n,s-a),h=f/2,p=new Wl([],Jl);if(0===f)return new i(n,a);for(var d=n;d<o;d+=f)for(var g=a;g<s;g+=f)p.push(new Kl(d+h,g+h,h,t));for(var m=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new Kl(r/e,n/e,0,t)}(t),v=p.length;p.length;){var y=p.pop();(y.d>m.d||!m.d)&&(m=y,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*y.d)/1e4,v)),y.max-m.d<=e||(p.push(new Kl(y.p.x-(h=y.h/2),y.p.y-h,h,t)),p.push(new Kl(y.p.x+h,y.p.y-h,h,t)),p.push(new Kl(y.p.x-h,y.p.y+h,h,t)),p.push(new Kl(y.p.x+h,y.p.y+h,h,t)),v+=4)}return r&&(console.log(\"num probes: \"+v),console.log(\"best distance: \"+m.d)),m.p}function Jl(t,e){return e.max-t.max}function Kl(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,Ga(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}Wl.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},Wl.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},Wl.prototype.peek=function(){return this.data[0]},Wl.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},Wl.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var Ql=Number.POSITIVE_INFINITY;function $l(t,e){return e[1]!==Ql?function(t,e,r){var n=0,i=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":i=r-7;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":i=7-r}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,i]}(t,e[0],e[1]):function(t,e){var r=0,n=0;e<0&&(e=0);var i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-7;break;case\"bottom-right\":case\"bottom-left\":n=7-i;break;case\"bottom\":n=7-e;break;case\"top\":n=e-7}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function tc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function ec(t,e,r,n,a,o,s,l,c,u,f,h,p,d,g){var m=function(t,e,r,n,a,o,s,l){for(var c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[],f=0,h=e.positionedLines;f<h.length;f+=1)for(var p=h[f],d=0,g=p.positionedGlyphs;d<g.length;d+=1){var m=g[d];if(m.rect){var v=m.rect||{},y=4,x=!0,b=1,_=0,w=(a||l)&&m.vertical,T=m.metrics.advance*m.scale/2;if(l&&e.verticalizable&&(_=p.lineOffset/2-(m.imageName?-(24-m.metrics.width*m.scale)/2:24*(m.scale-1))),m.imageName){var k=s[m.imageName];x=k.sdf,y=1/(b=k.pixelRatio)}var M=a?[m.x+T,m.y]:[0,0],A=a?[0,0]:[m.x+T+r[0],m.y+r[1]-_],S=[0,0];w&&(S=A,A=[0,0]);var E=(m.metrics.left-y)*m.scale-T+A[0],C=(-m.metrics.top-y)*m.scale+A[1],L=E+v.w*m.scale/b,I=C+v.h*m.scale/b,P=new i(E,C),z=new i(L,C),O=new i(E,I),D=new i(L,I);if(w){var R=new i(-T,T- -17),F=-Math.PI/2,B=12-T,N=new i(22-B,-(m.imageName?B:0)),j=new(Function.prototype.bind.apply(i,[null].concat(S)));P._rotateAround(F,R)._add(N)._add(j),z._rotateAround(F,R)._add(N)._add(j),O._rotateAround(F,R)._add(N)._add(j),D._rotateAround(F,R)._add(N)._add(j)}if(c){var U=Math.sin(c),V=Math.cos(c),q=[V,-U,U,V];P._matMult(q),z._matMult(q),O._matMult(q),D._matMult(q)}var H=new i(0,0),G=new i(0,0);u.push({tl:P,tr:z,bl:O,br:D,tex:v,writingMode:e.writingMode,glyphOffset:M,sectionIndex:m.sectionIndex,isSDF:x,pixelOffsetTL:H,pixelOffsetBR:G,minFontScaleX:0,minFontScaleY:0})}}return u}(0,r,l,a,o,s,n,t.allowVerticalPlacement),v=t.textSizeData,y=null;\"source\"===v.kind?(y=[128*a.layout.get(\"text-size\").evaluate(s,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'):\"composite\"===v.kind&&((y=[128*d.compositeTextSizes[0].evaluate(s,{},g),128*d.compositeTextSizes[1].evaluate(s,{},g)])[0]>32640||y[1]>32640)&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'),t.addSymbols(t.text,m,y,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,g);for(var x=0,b=f;x<b.length;x+=1)h[b[x]]=t.text.placedSymbolArray.length-1;return 4*m.length}function rc(t){for(var e in t)return t[e];return null}function nc(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}var ic=gs.VectorTileFeature.types,ac=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function oc(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=s?Math.min(32640,Math.round(s[0])):0,d=s?Math.min(32640,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,(p<<1)+(l?1:0),d,16*c,16*u,256*f,256*h)}function sc(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function lc(t){for(var e=0,r=t.sections;e<r.length;e+=1)if(Xn(r[e].text))return!0;return!1}var cc=function(t){this.layoutVertexArray=new Li,this.indexArray=new Fi,this.programConfigurations=t,this.segments=new ia,this.dynamicLayoutVertexArray=new Ii,this.opacityVertexArray=new Pi,this.placedSymbolArray=new Ji};cc.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length},cc.prototype.upload=function(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ds.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,Rs.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,ac,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))},cc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},Dn(\"SymbolBuffers\",cc);var uc=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new ia,this.collisionVertexArray=new Ri};uc.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,Fs.members,!0)},uc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},Dn(\"CollisionBuffers\",uc);var fc=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=eo([]),this.placementViewportMatrix=eo([]);var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Ll(this.zoom,e[\"text-size\"]),this.iconSizeData=Ll(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1),this.sortFeaturesByY=(\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey)&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),\"point\"===r.get(\"symbol-placement\")&&(this.writingModes=r.get(\"text-writing-mode\").map((function(t){return gl[t]}))),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id})),this.sourceID=t.sourceID};fc.prototype.createArrays=function(){this.text=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^text/.test(t)}))),this.icon=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^icon/.test(t)}))),this.glyphOffsetArray=new $i,this.lineVertexArray=new ta,this.symbolInstances=new Qi},fc.prototype.calculateGlyphDependencies=function(t,e,r,n,i){for(var a=0;a<t.length;a++)if(e[t.charCodeAt(a)]=!0,(r||n)&&i){var o=Us[t.charAt(a)];o&&(e[o.charCodeAt(0)]=!0)}},fc.prototype.populate=function(t,e,r){var n=this.layers[0],i=n.layout,a=i.get(\"text-font\"),o=i.get(\"text-field\"),s=i.get(\"icon-image\"),l=(\"constant\"!==o.value.kind||o.value.value instanceof te&&!o.value.value.isEmpty()||o.value.value.toString().length>0)&&(\"constant\"!==a.value.kind||a.value.value.length>0),c=\"constant\"!==s.value.kind||!!s.value.value||Object.keys(s.parameters).length>0,u=i.get(\"symbol-sort-key\");if(this.features=[],l||c){for(var f=e.iconDependencies,h=e.glyphDependencies,p=e.availableImages,d=new ii(this.zoom),g=0,m=t;g<m.length;g+=1){var v=m[g],y=v.feature,x=v.id,b=v.index,_=v.sourceLayerIndex,w=n._featureFilter.needGeometry,T={type:y.type,id:x,properties:y.properties,geometry:w?Da(y):[]};if(n._featureFilter.filter(d,T,r)){w||(T.geometry=Da(y));var k=void 0;if(l){var M=n.getValueAndResolveTokens(\"text-field\",T,r,p),A=te.factory(M);lc(A)&&(this.hasRTLText=!0),(!this.hasRTLText||\"unavailable\"===ei()||this.hasRTLText&&ni.isParsed())&&(k=js(A,n,T))}var S=void 0;if(c){var E=n.getValueAndResolveTokens(\"icon-image\",T,r,p);S=E instanceof ee?E:ee.fromString(E)}if(k||S){var C=this.sortFeaturesByKey?u.evaluate(T,{},r):void 0,L={id:x,text:k,icon:S,index:b,sourceLayerIndex:_,geometry:Da(y),properties:y.properties,type:ic[y.type],sortKey:C};if(this.features.push(L),S&&(f[S.name]=!0),k){var I=a.evaluate(T,{},r).join(\",\"),P=\"map\"===i.get(\"text-rotation-alignment\")&&\"point\"!==i.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(gl.vertical)>=0;for(var z=0,O=k.sections;z<O.length;z+=1){var D=O[z];if(D.image)f[D.image.name]=!0;else{var R=qn(k.toString()),F=D.fontStack||I,B=h[F]=h[F]||{};this.calculateGlyphDependencies(D.text,B,P,this.allowVerticalPlacement,R)}}}}}}\"line\"===i.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.text?u.text.toString():null;if(h){var p=l(h,f),d=l(h,f,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,f),m=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(h,n[m].geometry,!0)]=m,n[g].geometry=null}else p in r?o(p,d,f):d in e?s(p,d,f):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter((function(t){return t.geometry}))}(this.features)),this.sortFeaturesByKey&&this.features.sort((function(t,e){return t.sortKey-e.sortKey}))}},fc.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},fc.prototype.isEmpty=function(){return 0===this.symbolInstances.length&&!this.hasRTLText},fc.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},fc.prototype.upload=function(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},fc.prototype.destroyDebugData=function(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()},fc.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()},fc.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},fc.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=t.indexArray,p=t.layoutVertexArray,d=t.segments.prepareSegment(4*e.length,p,h,a.sortKey),g=this.glyphOffsetArray.length,m=d.vertexLength,v=this.allowVerticalPlacement&&o===gl.vertical?Math.PI/2:0,y=a.text&&a.text.sections,x=0;x<e.length;x++){var b=e[x],_=b.tl,w=b.tr,T=b.bl,k=b.br,M=b.tex,A=b.pixelOffsetTL,S=b.pixelOffsetBR,E=b.minFontScaleX,C=b.minFontScaleY,L=b.glyphOffset,I=b.isSDF,P=b.sectionIndex,z=d.vertexLength,O=L[1];oc(p,s.x,s.y,_.x,O+_.y,M.x,M.y,r,I,A.x,A.y,E,C),oc(p,s.x,s.y,w.x,O+w.y,M.x+M.w,M.y,r,I,S.x,A.y,E,C),oc(p,s.x,s.y,T.x,O+T.y,M.x,M.y+M.h,r,I,A.x,S.y,E,C),oc(p,s.x,s.y,k.x,O+k.y,M.x+M.w,M.y+M.h,r,I,S.x,S.y,E,C),sc(t.dynamicLayoutVertexArray,s,v),h.emplaceBack(z,z+1,z+2),h.emplaceBack(z+1,z+2,z+3),d.vertexLength+=4,d.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(L[0]),x!==e.length-1&&P===e[x+1].sectionIndex||t.programConfigurations.populatePaintArrays(p.length,a,a.index,{},f,y&&y[P])}t.placedSymbolArray.emplaceBack(s.x,s.y,g,this.glyphOffsetArray.length-g,m,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0,u)},fc.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},fc.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s){var l=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),c=l.vertexLength,u=a.layoutVertexArray,f=a.collisionVertexArray,h=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,f,o,h,p,new i(t,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,n)),this._addCollisionDebugVertex(u,f,o,h,p,new i(t,n)),l.vertexLength+=4;var d=a.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4},fc.prototype.addDebugCollisionBoxes=function(t,e,r,n){for(var i=t;i<e;i++){var a=this.collisionBoxArray.get(i);this.addCollisionDebugVertices(a.x1,a.y1,a.x2,a.y2,n?this.textCollisionBox:this.iconCollisionBox,a.anchorPoint,r)}},fc.prototype.generateCollisionDebugBuffers=function(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new uc(Oi,Bs.members,qi),this.iconCollisionBox=new uc(Oi,Bs.members,qi);for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}},fc.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i,a,o,s,l){for(var c={},u=e;u<r;u++){var f=t.get(u);c.textBox={x1:f.x1,y1:f.y1,x2:f.x2,y2:f.y2,anchorPointX:f.anchorPointX,anchorPointY:f.anchorPointY},c.textFeatureIndex=f.featureIndex;break}for(var h=n;h<i;h++){var p=t.get(h);c.verticalTextBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},c.verticalTextFeatureIndex=p.featureIndex;break}for(var d=a;d<o;d++){var g=t.get(d);c.iconBox={x1:g.x1,y1:g.y1,x2:g.x2,y2:g.y2,anchorPointX:g.anchorPointX,anchorPointY:g.anchorPointY},c.iconFeatureIndex=g.featureIndex;break}for(var m=s;m<l;m++){var v=t.get(m);c.verticalIconBox={x1:v.x1,y1:v.y1,x2:v.x2,y2:v.y2,anchorPointX:v.anchorPointX,anchorPointY:v.anchorPointY},c.verticalIconFeatureIndex=v.featureIndex;break}return c},fc.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}},fc.prototype.hasTextData=function(){return this.text.segments.get().length>0},fc.prototype.hasIconData=function(){return this.icon.segments.get().length>0},fc.prototype.hasDebugData=function(){return this.textCollisionBox&&this.iconCollisionBox},fc.prototype.hasTextCollisionBoxData=function(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0},fc.prototype.hasIconCollisionBoxData=function(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0},fc.prototype.addIndicesForPlacedSymbol=function(t,e){for(var r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs,i=r.vertexStartIndex;i<n;i+=4)t.indexArray.emplaceBack(i,i+1,i+2),t.indexArray.emplaceBack(i+1,i+2,i+3)},fc.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort((function(t,e){return n[t]-n[e]||i[e]-i[t]})),a},fc.prototype.addToSortKeyRanges=function(t,e){var r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})},fc.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=this.symbolInstances.get(n[r]);this.featureSortOrder.push(i.featureIndex),[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach((function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedSymbol(e.text,t)})),i.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,i.verticalPlacedTextSymbolIndex),i.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.placedIconSymbolIndex),i.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},Dn(\"SymbolBucket\",fc,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),fc.MAX_GLYPHS=65535,fc.addDynamicAttributes=sc;var hc=new yi({\"symbol-placement\":new pi(At.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new pi(At.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new pi(At.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new di(At.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new pi(At.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new pi(At.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new pi(At.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new pi(At.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new pi(At.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new di(At.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new pi(At.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new pi(At.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new di(At.layout_symbol[\"icon-image\"]),\"icon-rotate\":new di(At.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new pi(At.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new pi(At.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new di(At.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new di(At.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new pi(At.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new pi(At.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new pi(At.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new di(At.layout_symbol[\"text-field\"]),\"text-font\":new di(At.layout_symbol[\"text-font\"]),\"text-size\":new di(At.layout_symbol[\"text-size\"]),\"text-max-width\":new di(At.layout_symbol[\"text-max-width\"]),\"text-line-height\":new pi(At.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new di(At.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new di(At.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new di(At.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new pi(At.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new di(At.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new pi(At.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new pi(At.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new di(At.layout_symbol[\"text-rotate\"]),\"text-padding\":new pi(At.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new pi(At.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new di(At.layout_symbol[\"text-transform\"]),\"text-offset\":new di(At.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new pi(At.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new pi(At.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new pi(At.layout_symbol[\"text-optional\"])}),pc={paint:new yi({\"icon-opacity\":new di(At.paint_symbol[\"icon-opacity\"]),\"icon-color\":new di(At.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new di(At.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new di(At.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new di(At.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new pi(At.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new pi(At.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new di(At.paint_symbol[\"text-opacity\"]),\"text-color\":new di(At.paint_symbol[\"text-color\"],{runtimeType:Bt,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),\"text-halo-color\":new di(At.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new di(At.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new di(At.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new pi(At.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new pi(At.paint_symbol[\"text-translate-anchor\"])}),layout:hc},dc=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:Ot,this.defaultValue=t};dc.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},dc.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},dc.prototype.outputDefined=function(){return!1},dc.prototype.serialize=function(){return null},Dn(\"FormatSectionOverride\",dc,{omit:[\"defaultValue\"]});var gc=function(t){function e(e){t.call(this,e,pc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){if(t.prototype.recalculate.call(this,e,r),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(this.layout._values[\"icon-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(this.layout._values[\"text-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){var n=this.layout.get(\"text-writing-mode\");if(n){for(var i=[],a=0,o=n;a<o.length;a+=1){var s=o[a];i.indexOf(s)<0&&i.push(s)}this.layout._values[\"text-writing-mode\"]=i}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e,r,n){var i=this.layout.get(t).evaluate(e,{},r,n),a=this._unevaluatedLayout._values[t];return a.isDataDriven()||Vr(a.value)||!i?i:function(t,e){return e.replace(/{([^{}]+)}/g,(function(e,r){return r in t?String(t[r]):\"\"}))}(e.properties,i)},e.prototype.createBucket=function(t){return new fc(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=pc.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var i,a=this.paint.get(n),o=new dc(a),s=new Ur(o,a.property.specification);i=\"constant\"===a.value.kind||\"source\"===a.value.kind?new Hr(\"source\",s):new Gr(\"composite\",s,a.value.zoomStops,a.value._interpolationType),this.paint._values[n]=new fi(a.property,i,a.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get(\"text-field\"),n=pc.paint.properties[e],i=!1,a=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n.overrides&&n.overrides.hasOverride(r[e]))return void(i=!0)};if(\"constant\"===r.value.kind&&r.value.value instanceof te)a(r.value.value.sections);else if(\"source\"===r.value.kind){var o=function(t){i||(t instanceof oe&&ie(t.value)===Vt?a(t.value.sections):t instanceof ue?a(t.sections):t.eachChild(o))},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return i},e}(xi),mc={paint:new yi({\"background-color\":new pi(At.paint_background[\"background-color\"]),\"background-pattern\":new mi(At.paint_background[\"background-pattern\"]),\"background-opacity\":new pi(At.paint_background[\"background-opacity\"])})},vc=function(t){function e(e){t.call(this,e,mc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),yc={paint:new yi({\"raster-opacity\":new pi(At.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new pi(At.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new pi(At.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new pi(At.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new pi(At.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new pi(At.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new pi(At.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new pi(At.paint_raster[\"raster-fade-duration\"])})},xc=function(t){function e(e){t.call(this,e,yc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),bc=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(xi),_c={circle:oo,heatmap:vo,hillshade:xo,fill:as,\"fill-extrusion\":ws,line:zs,symbol:gc,background:vc,raster:xc},wc=self.HTMLImageElement,Tc=self.HTMLCanvasElement,kc=self.HTMLVideoElement,Mc=self.ImageData,Ac=self.ImageBitmap,Sc=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Sc.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Sc.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Sc.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Sc.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ec=function(t){var e=this;this._callback=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};Ec.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((function(){t._triggered=!1,t._callback()}),0))},Ec.prototype.remove=function(){delete this._channel,this._callback=function(){}};var Cc=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},g([\"receive\",\"process\"],this),this.invoker=new Ec(this.process),this.target.addEventListener(\"message\",this.receive,!1),this.globalScope=k()?t:self};function Lc(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}Cc.prototype.send=function(t,e,r,n,i){var a=this;void 0===i&&(i=!1);var o=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[o]=r);var s=S(this.globalScope)?void 0:[];return this.target.postMessage({id:o,type:t,hasCallback:!!r,targetMapId:n,mustQueue:i,sourceMapId:this.mapId,data:Nn(e,s)},s),{cancel:function(){r&&delete a.callbacks[o],a.target.postMessage({id:o,type:\"<cancel>\",targetMapId:n,sourceMapId:a.mapId})}}},Cc.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if(\"<cancel>\"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else k()||e.mustQueue?(this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()):this.processTask(r,e)},Cc.prototype.process=function(){if(this.taskQueue.length){var t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length&&this.invoker.trigger(),e&&this.processTask(t,e)}},Cc.prototype.processTask=function(t,e){var r=this;if(\"<response>\"===e.type){var n=this.callbacks[t];delete this.callbacks[t],n&&(e.error?n(jn(e.error)):n(null,jn(e.data)))}else{var i=!1,a=S(this.globalScope)?void 0:[],o=e.hasCallback?function(e,n){i=!0,delete r.cancelCallbacks[t],r.target.postMessage({id:t,type:\"<response>\",sourceMapId:r.mapId,error:e?Nn(e):null,data:Nn(n,a)},a)}:function(t){i=!0},s=null,l=jn(e.data);if(this.parent[e.type])s=this.parent[e.type](e.sourceMapId,l,o);else if(this.parent.getWorkerSource){var c=e.type.split(\".\");s=this.parent.getWorkerSource(e.sourceMapId,c[0],l.source)[c[1]](l,o)}else o(new Error(\"Could not find function \"+e.type));!i&&s&&s.cancel&&(this.cancelCallbacks[t]=s.cancel)}},Cc.prototype.remove=function(){this.invoker.remove(),this.target.removeEventListener(\"message\",this.receive,!1)};var Ic=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Ic.prototype.setNorthEast=function(t){return this._ne=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.setSouthWest=function(t){return this._sw=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Pc)e=t,r=t;else{if(!(t instanceof Ic))return Array.isArray(t)?4===t.length||t.every(Array.isArray)?this.extend(Ic.convert(t)):this.extend(Pc.convert(t)):this;if(r=t._ne,!(e=t._sw)||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Pc(e.lng,e.lat),this._ne=new Pc(r.lng,r.lat)),this},Ic.prototype.getCenter=function(){return new Pc((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Ic.prototype.getSouthWest=function(){return this._sw},Ic.prototype.getNorthEast=function(){return this._ne},Ic.prototype.getNorthWest=function(){return new Pc(this.getWest(),this.getNorth())},Ic.prototype.getSouthEast=function(){return new Pc(this.getEast(),this.getSouth())},Ic.prototype.getWest=function(){return this._sw.lng},Ic.prototype.getSouth=function(){return this._sw.lat},Ic.prototype.getEast=function(){return this._ne.lng},Ic.prototype.getNorth=function(){return this._ne.lat},Ic.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Ic.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},Ic.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Ic.prototype.contains=function(t){var e=Pc.convert(t),r=e.lng,n=e.lat,i=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(i=this._sw.lng>=r&&r>=this._ne.lng),this._sw.lat<=n&&n<=this._ne.lat&&i},Ic.convert=function(t){return!t||t instanceof Ic?t:new Ic(t)};var Pc=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};Pc.prototype.wrap=function(){return new Pc(c(this.lng,-180,180),this.lat)},Pc.prototype.toArray=function(){return[this.lng,this.lat]},Pc.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Pc.prototype.distanceTo=function(t){var e=Math.PI/180,r=this.lat*e,n=t.lat*e,i=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return 6371008.8*Math.acos(Math.min(i,1))},Pc.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Ic(new Pc(this.lng-r,this.lat-e),new Pc(this.lng+r,this.lat+e))},Pc.convert=function(t){if(t instanceof Pc)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Pc(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Pc(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var zc=2*Math.PI*6371008.8;function Oc(t){return zc*Math.cos(t*Math.PI/180)}function Dc(t){return(180+t)/360}function Rc(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Fc(t,e){return t/Oc(e)}function Bc(t){return 360/Math.PI*Math.atan(Math.exp((180-360*t)*Math.PI/180))-90}var Nc=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Nc.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Pc.convert(t);return new Nc(Dc(r.lng),Rc(r.lat),Fc(e,r.lat))},Nc.prototype.toLngLat=function(){return new Pc(360*this.x-180,Bc(this.y))},Nc.prototype.toAltitude=function(){return this.z*Oc(Bc(this.y))},Nc.prototype.meterInMercatorCoordinateUnits=function(){return 1/zc*(t=Bc(this.y),1/Math.cos(t*Math.PI/180));var t};var jc=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=qc(0,t,t,e,r)};jc.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},jc.prototype.url=function(t,e){var r,n,i,a,o,s=(n=this.y,i=this.z,a=Lc(256*(r=this.x),256*(n=Math.pow(2,i)-n-1),i),o=Lc(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},jc.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i(8192*(t.x*e-this.x),8192*(t.y*e-this.y))},jc.prototype.toString=function(){return this.z+\"/\"+this.x+\"/\"+this.y};var Uc=function(t,e){this.wrap=t,this.canonical=e,this.key=qc(t,e.z,e.z,e.x,e.y)},Vc=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new jc(r,+n,+i),this.key=qc(e,t,r,n,i)};function qc(t,e,r,n,i){(t*=2)<0&&(t=-1*t-1);var a=1<<r;return(a*a*t+a*i+n).toString(36)+r.toString(36)+e.toString(36)}Vc.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Vc.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Vc(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Vc(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Vc.prototype.calculateScaledKey=function(t,e){var r=this.canonical.z-t;return t>this.canonical.z?qc(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):qc(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)},Vc.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Vc.prototype.children=function(t){if(this.overscaledZ>=t)return[new Vc(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Vc(e,this.wrap,e,r,n),new Vc(e,this.wrap,e,r+1,n),new Vc(e,this.wrap,e,r,n+1),new Vc(e,this.wrap,e,r+1,n+1)]},Vc.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Vc.prototype.wrapped=function(){return new Vc(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.unwrapTo=function(t){return new Vc(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Vc.prototype.toUnwrapped=function(){return new Uc(this.wrap,this.canonical)},Vc.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},Vc.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Nc(t.x-this.wrap,t.y))},Dn(\"CanonicalTileID\",jc),Dn(\"OverscaledTileID\",Vc,{omit:[\"posMatrix\"]});var Hc=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return _('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');this.stride=e.height;var n=this.dim=e.height-2;this.data=new Uint32Array(e.data.buffer),this.encoding=r||\"mapbox\";for(var i=0;i<n;i++)this.data[this._idx(-1,i)]=this.data[this._idx(0,i)],this.data[this._idx(n,i)]=this.data[this._idx(n-1,i)],this.data[this._idx(i,-1)]=this.data[this._idx(i,0)],this.data[this._idx(i,n)]=this.data[this._idx(i,n-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(n,-1)]=this.data[this._idx(n-1,0)],this.data[this._idx(-1,n)]=this.data[this._idx(0,n-1)],this.data[this._idx(n,n)]=this.data[this._idx(n-1,n-1)]};Hc.prototype.get=function(t,e){var r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return(\"terrarium\"===this.encoding?this._unpackTerrarium:this._unpackMapbox)(r[n],r[n+1],r[n+2])},Hc.prototype.getUnpackVector=function(){return\"terrarium\"===this.encoding?[256,1,1/256,32768]:[6553.6,25.6,.1,1e4]},Hc.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Hc.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Hc.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Hc.prototype.getPixels=function(){return new po({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Hc.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.data[this._idx(u,c)]=t.data[this._idx(u+s,c+l)]},Dn(\"DEMData\",Hc);var Gc=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Gc.prototype.encode=function(t){return this._stringToNumber[t]},Gc.prototype.decode=function(t){return this._numberToString[t]};var Yc=function(t,e,r,n,i){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=i},Wc={geometry:{configurable:!0}};Wc.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Wc.geometry.set=function(t){this._geometry=t},Yc.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Yc.prototype,Wc);var Xc=function(){this.state={},this.stateChanges={},this.deletedStates={}};Xc.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},u(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},Xc.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},Xc.prototype.getState=function(t,e){var r=String(e),n=u({},(this.state[t]||{})[r],(this.stateChanges[t]||{})[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var i=this.deletedStates[t][e];if(null===i)return{};for(var a in i)delete n[a]}return n},Xc.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},Xc.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),u(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var f=0,h=Object.keys(this.deletedStates[o][c]);f<h.length;f+=1)delete this.state[o][c][h[f]];s[c]=this.state[o][c]}r[o]=r[o]||{},u(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var p in t)t[p].setFeatureState(r,e)};var Zc=function(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new Ln(8192,16,0),this.grid3D=new Ln(8192,16,0),this.featureIndexArray=new ra,this.promoteId=e};function Jc(t,e,r,n,i){return v(t,(function(t,a){var o=e instanceof hi?e.get(a):null;return o&&o.evaluate?o.evaluate(r,n,i):o}))}function Kc(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function Qc(t,e){return e-t}Zc.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],f=0;f<c.length;f++){var h=c[f];u[0]=Math.min(u[0],h.x),u[1]=Math.min(u[1],h.y),u[2]=Math.max(u[2],h.x),u[3]=Math.max(u[3],h.y)}u[0]<8192&&u[1]<8192&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Zc.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new gs.VectorTile(new Hs(this.rawTileData)).layers,this.sourceLayerCoder=new Gc(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Zc.prototype.query=function(t,e,r,n){var a=this;this.loadVTLayers();for(var o=t.params||{},s=8192/t.tileSize/t.scale,l=rn(o.filter),c=t.queryGeometry,u=t.queryPadding*s,f=Kc(c),h=this.grid.query(f.minX-u,f.minY-u,f.maxX+u,f.maxY+u),p=Kc(t.cameraQueryGeometry),d=0,g=this.grid3D.query(p.minX-u,p.minY-u,p.maxX+u,p.maxY+u,(function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,f=c;u<f.length;u+=1)if(Wa(t,f[u]))return!0;for(var h=0;h<t.length-1;h++)if(Xa(t[h],t[h+1],c))return!0;return!1}(t.cameraQueryGeometry,e-u,r-u,n+u,a+u)}));d<g.length;d+=1)h.push(g[d]);h.sort(Qc);for(var m,v={},y=function(i){var u=h[i];if(u!==m){m=u;var f=a.featureIndexArray.get(u),p=null;a.loadMatchingFeature(v,f.bucketIndex,f.sourceLayerIndex,f.featureIndex,l,o.layers,o.availableImages,e,r,n,(function(e,r,n){return p||(p=Da(e)),r.queryIntersectsFeature(c,e,n,p,a.z,t.transform,s,t.pixelPosMatrix)}))}},x=0;x<h.length;x++)y(x);return v},Zc.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s,l,c,u){var f=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,f)){var h=this.sourceLayerCoder.decode(r),p=this.vtLayers[h].feature(n);if(i.filter(new ii(this.tileID.overscaledZ),p))for(var d=this.getId(p,h),g=0;g<f.length;g++){var m=f[g];if(!(a&&a.indexOf(m)<0)){var v=s[m];if(v){var y={};void 0!==d&&c&&(y=c.getState(v.sourceLayer||\"_geojsonTileLayer\",d));var x=l[m];x.paint=Jc(x.paint,v.paint,p,y,o),x.layout=Jc(x.layout,v.layout,p,y,o);var b=!u||u(p,v,y);if(b){var _=new Yc(p,this.z,this.x,this.y,d);_.layer=x;var w=t[m];void 0===w&&(w=t[m]=[]),w.push({featureIndex:n,feature:_,intersectionZ:b})}}}}}},Zc.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a,o,s){var l={};this.loadVTLayers();for(var c=rn(i),u=0,f=t;u<f.length;u+=1)this.loadMatchingFeature(l,r,n,f[u],c,a,o,s,e);return l},Zc.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},Zc.prototype.getId=function(t,e){var r=t.id;return this.promoteId&&\"boolean\"==typeof(r=t.properties[\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e]])&&(r=Number(r)),r},Dn(\"FeatureIndex\",Zc,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var $c=function(t,e){this.tileID=t,this.uid=h(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.expiredRequestCount=0,this.state=\"loading\"};$c.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<R.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},$c.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},$c.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map((function(t){return e.getLayer(t)})).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map((function(t){return n.filter((function(e){return e.id===t}))[0]})));for(var o=0,s=n;o<s.length;o+=1)r[s[o].id]=t}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof fc){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(var a in this.buckets){var o=this.buckets[a];if(o instanceof fc&&o.hasRTLText){this.hasRTLText=!0,ni.isLoading()||ni.isLoaded()||\"deferred\"!==ei()||ri();break}}for(var s in this.queryPadding=0,this.buckets){var l=this.buckets[s];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(s).queryRadius(l))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Xi},$c.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},$c.prototype.getBucket=function(t){return this.buckets[t.id]},$c.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Sc(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Sc(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},$c.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},$c.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:i,scale:a,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}},$c.prototype.querySourceFeatures=function(t,e){var r=this.latestFeatureIndex;if(r&&r.rawTileData){var n=r.loadVTLayers(),i=e?e.sourceLayer:\"\",a=n._geojsonTileLayer||n[i];if(a)for(var o=rn(e&&e.filter),s=this.tileID.canonical,l=s.z,c=s.x,u=s.y,f={z:l,x:c,y:u},h=0;h<a.length;h++){var p=a.feature(h);if(o.filter(new ii(this.tileID.overscaledZ),p)){var d=r.getId(p,i),g=new Yc(p,l,c,u,d);g.tile=f,t.push(g)}}}},$c.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},$c.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},$c.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=M(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},$c.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},$c.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets)if(e.style.hasLayer(n)){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];if(o&&s&&0!==Object.keys(s).length){i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});var l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(i)))}}}},$c.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},$c.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<R.now()},$c.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},$c.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=R.now()+t},$c.prototype.setDependencies=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1)r[i[n]]=!0;this.dependencies[t]=r},$c.prototype.hasDependency=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=this.dependencies[n[r]];if(i)for(var a=0,o=e;a<o.length;a+=1)if(i[o[a]])return!0}return!1};var tu=self.performance,eu=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},tu.mark(this._marks.start)};eu.prototype.finish=function(){tu.mark(this._marks.end);var t=tu.getEntriesByName(this._marks.measure);return 0===t.length&&(tu.measure(this._marks.measure,this._marks.start,this._marks.end),t=tu.getEntriesByName(this._marks.measure),tu.clearMarks(this._marks.start),tu.clearMarks(this._marks.end),tu.clearMeasures(this._marks.measure)),t},t.Actor=Cc,t.AlphaImage=ho,t.CanonicalTileID=jc,t.CollisionBoxArray=Xi,t.Color=Kt,t.DEMData=Hc,t.DataConstantProperty=pi,t.DictionaryCoder=Gc,t.EXTENT=8192,t.ErrorEvent=kt,t.EvaluationParameters=ii,t.Event=Tt,t.Evented=Mt,t.FeatureIndex=Zc,t.FillBucket=rs,t.FillExtrusionBucket=xs,t.ImageAtlas=dl,t.ImagePosition=hl,t.LineBucket=Cs,t.LngLat=Pc,t.LngLatBounds=Ic,t.MercatorCoordinate=Nc,t.ONE_EM=24,t.OverscaledTileID=Vc,t.Point=i,t.Point$1=i,t.Properties=yi,t.Protobuf=Hs,t.RGBAImage=po,t.RequestManager=q,t.RequestPerformance=eu,t.ResourceType=ht,t.SegmentVector=ia,t.SourceFeatureState=Xc,t.StructArrayLayout1ui2=Hi,t.StructArrayLayout2f1f2i16=Di,t.StructArrayLayout2i4=Mi,t.StructArrayLayout3ui6=Fi,t.StructArrayLayout4i8=Ai,t.SymbolBucket=fc,t.Texture=Sc,t.Tile=$c,t.Transitionable=si,t.Uniform1f=va,t.Uniform1i=ma,t.Uniform2f=ya,t.Uniform3f=xa,t.Uniform4f=ba,t.UniformColor=_a,t.UniformMatrix4f=Ta,t.UnwrappedTileID=Uc,t.ValidationError=St,t.WritingMode=gl,t.ZoomHistory=Un,t.add=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t},t.addDynamicAttributes=sc,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach((function(t,o){e(t,(function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)}))}))},t.bezier=o,t.bindAll=g,t.browser=R,t.cacheEntryPossiblyAdded=function(t){++ut>ot&&(t.getActor().send(\"enforceCacheSizeLimit\",at),ut=0)},t.clamp=l,t.clearTileCache=function(t){var e=self.caches.delete(\"mapbox-tiles\");t&&e.catch(t).then((function(){return t()}))},t.clipLine=jl,t.clone=function(t){var e=new to(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=x,t.clone$2=function(t){var e=new to(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e},t.collisionCircleLayout=Ns,t.config=F,t.create=function(){var t=new to(16);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new to(9);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new to(4);return to!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=qr,t.createLayout=Ti,t.createStyleLayer=function(t){return\"custom\"===t.type?new bc(t):new _c[t.type](t)},t.cross=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t},t.deepEqual=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var i in e)if(!t(e[i],r[i]))return!1;return!0}return e===r},t.dot=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]},t.dot$1=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.ease=s,t.emitValidationErrors=Cn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){st(),Q&&Q.then((function(e){e.keys().then((function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])}))}))},t.evaluateSizeForFeature=Il,t.evaluateSizeForZoom=Pl,t.evaluateVariableOffset=$l,t.evented=ti,t.extend=u,t.featureFilter=rn,t.filterObject=y,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=Al,t.getAnchorJustification=tc,t.getArrayBuffer=yt,t.getImage=bt,t.getJSON=function(t,e){return vt(u(t,{type:\"json\"}),e)},t.getRTLTextPluginStatus=ei,t.getReferrer=mt,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=eo,t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;return L?(t[0]=(s*C-l*E+c*S)*(L=1/L),t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t):null},t.isChar=Vn,t.isMapboxURL=H,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=vt,t.mapObject=v,t.mercatorXfromLng=Dc,t.mercatorYfromLat=Rc,t.mercatorZfromAltitude=Fc,t.mul=io,t.multiply=ro,t.mvt=gs,t.normalize=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a)),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a,t},t.number=Ue,t.offscreenCanvasSupported=ft,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Hs(t).readFields(ll,[])},t.pbf=Hs,t.performSymbolLayout=function(t,e,r,n,i,a,o){t.createArrays(),t.tilePixelRatio=8192/(512*t.overscaling),t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new ii(u.minZoom),o),l[\"text-size\"].possiblyEvaluate(new ii(f),o)]}if(\"composite\"===t.iconSizeData.kind){var h=t.iconSizeData,p=h.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new ii(h.minZoom),o),l[\"icon-size\"].possiblyEvaluate(new ii(p),o)]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new ii(18));for(var d=24*s.get(\"text-line-height\"),g=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),m=s.get(\"text-keep-upright\"),v=s.get(\"text-size\"),y=function(){var a=b[x],l=s.get(\"text-font\").evaluate(a,{},o).join(\",\"),u=v.evaluate(a,{},o),f=c.layoutTextSize.evaluate(a,{},o),h=c.layoutIconSize.evaluate(a,{},o),p={horizontal:{},vertical:void 0},y=a.text,w=[0,0];if(y){var T=y.toString(),k=24*s.get(\"text-letter-spacing\").evaluate(a,{},o),M=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n=r[e].charCodeAt(0),Vn.Arabic(n)||Vn[\"Arabic Supplement\"](n)||Vn[\"Arabic Extended-A\"](n)||Vn[\"Arabic Presentation Forms-A\"](n)||Vn[\"Arabic Presentation Forms-B\"](n))return!1;var n;return!0}(T)?k:0,A=s.get(\"text-anchor\").evaluate(a,{},o),S=s.get(\"text-variable-anchor\");if(!S){var E=s.get(\"text-radial-offset\").evaluate(a,{},o);w=E?$l(A,[24*E,Ql]):s.get(\"text-offset\").evaluate(a,{},o).map((function(t){return 24*t}))}var C=g?\"center\":s.get(\"text-justify\").evaluate(a,{},o),L=s.get(\"symbol-placement\"),I=\"point\"===L?24*s.get(\"text-max-width\").evaluate(a,{},o):0,P=function(){t.allowVerticalPlacement&&qn(T)&&(p.vertical=yl(y,e,r,i,l,I,d,A,\"left\",M,w,gl.vertical,!0,L,f,u))};if(!g&&S){for(var z=\"auto\"===C?S.map((function(t){return tc(t)})):[C],O=!1,D=0;D<z.length;D++){var R=z[D];if(!p.horizontal[R])if(O)p.horizontal[R]=p.horizontal[0];else{var F=yl(y,e,r,i,l,I,d,\"center\",R,M,w,gl.horizontal,!1,L,f,u);F&&(p.horizontal[R]=F,O=1===F.positionedLines.length)}}P()}else{\"auto\"===C&&(C=tc(A));var B=yl(y,e,r,i,l,I,d,A,C,M,w,gl.horizontal,!1,L,f,u);B&&(p.horizontal[C]=B),P(),qn(T)&&g&&m&&(p.vertical=yl(y,e,r,i,l,I,d,A,C,M,w,gl.vertical,!1,L,f,u))}}var N=void 0,j=!1;if(a.icon&&a.icon.name){var U=n[a.icon.name];U&&(N=function(t,e,r){var n=Al(r),i=e[0]-t.displaySize[0]*n.horizontalAlign,a=e[1]-t.displaySize[1]*n.verticalAlign;return{image:t,top:a,bottom:a+t.displaySize[1],left:i,right:i+t.displaySize[0]}}(i[a.icon.name],s.get(\"icon-offset\").evaluate(a,{},o),s.get(\"icon-anchor\").evaluate(a,{},o)),j=U.sdf,void 0===t.sdfIcons?t.sdfIcons=U.sdf:t.sdfIcons!==U.sdf&&_(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(U.pixelRatio!==t.pixelRatio||0!==s.get(\"icon-rotate\").constantOr(1))&&(t.iconsNeedLinear=!0))}var V=rc(p.horizontal)||p.vertical;t.iconsInText=!!V&&V.iconsInText,(V||N)&&function(t,e,r,n,i,a,o,s,l,c,u){var f=a.textMaxSize.evaluate(e,{});void 0===f&&(f=o);var h,p=t.layers[0].layout,d=p.get(\"icon-offset\").evaluate(e,{},u),g=rc(r.horizontal),m=o/24,v=t.tilePixelRatio*m,y=t.tilePixelRatio*f/24,x=t.tilePixelRatio*s,b=t.tilePixelRatio*p.get(\"symbol-spacing\"),w=p.get(\"text-padding\")*t.tilePixelRatio,T=p.get(\"icon-padding\")*t.tilePixelRatio,k=p.get(\"text-max-angle\")/180*Math.PI,M=\"map\"===p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),A=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=p.get(\"symbol-placement\"),E=b/2,C=p.get(\"icon-text-fit\");n&&\"none\"!==C&&(t.allowVerticalPlacement&&r.vertical&&(h=El(n,r.vertical,C,p.get(\"icon-text-fit-padding\"),d,m)),g&&(n=El(n,g,C,p.get(\"icon-text-fit-padding\"),d,m)));var L=function(s,f){f.x<0||f.x>=8192||f.y<0||f.y>=8192||function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,w,T,k,M){var A,S,E,C,L,I=t.addToLineVertexArray(e,r),P=0,z=0,O=0,D=0,R=-1,F=-1,B={},N=ca(\"\"),j=0,U=0;if(void 0===s._unevaluatedLayout.getValue(\"text-radial-offset\")?(j=(A=s.layout.get(\"text-offset\").evaluate(b,{},k).map((function(t){return 24*t})))[0],U=A[1]):(j=24*s.layout.get(\"text-radial-offset\").evaluate(b,{},k),U=Ql),t.allowVerticalPlacement&&n.vertical){var V=s.layout.get(\"text-rotate\").evaluate(b,{},k)+90;C=new Yl(l,e,c,u,f,n.vertical,h,p,d,V),o&&(L=new Yl(l,e,c,u,f,o,m,v,d,V))}if(i){var q=s.layout.get(\"icon-rotate\").evaluate(b,{}),H=\"none\"!==s.layout.get(\"icon-text-fit\"),G=Ul(i,q,T,H),Y=o?Ul(o,q,T,H):void 0;E=new Yl(l,e,c,u,f,i,m,v,!1,q),P=4*G.length;var W=t.iconSizeData,X=null;\"source\"===W.kind?(X=[128*s.layout.get(\"icon-size\").evaluate(b,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'):\"composite\"===W.kind&&((X=[128*w.compositeIconSizes[0].evaluate(b,{},k),128*w.compositeIconSizes[1].evaluate(b,{},k)])[0]>32640||X[1]>32640)&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'),t.addSymbols(t.icon,G,X,x,y,b,!1,e,I.lineStartIndex,I.lineLength,-1,k),R=t.icon.placedSymbolArray.length-1,Y&&(z=4*Y.length,t.addSymbols(t.icon,Y,X,x,y,b,gl.vertical,e,I.lineStartIndex,I.lineLength,-1,k),F=t.icon.placedSymbolArray.length-1)}for(var Z in n.horizontal){var J=n.horizontal[Z];if(!S){N=ca(J.text);var K=s.layout.get(\"text-rotate\").evaluate(b,{},k);S=new Yl(l,e,c,u,f,J,h,p,d,K)}var Q=1===J.positionedLines.length;if(O+=ec(t,e,J,a,s,d,b,g,I,n.vertical?gl.horizontal:gl.horizontalOnly,Q?Object.keys(n.horizontal):[Z],B,R,w,k),Q)break}n.vertical&&(D+=ec(t,e,n.vertical,a,s,d,b,g,I,gl.vertical,[\"vertical\"],B,F,w,k));var $=S?S.boxStartIndex:t.collisionBoxArray.length,tt=S?S.boxEndIndex:t.collisionBoxArray.length,et=C?C.boxStartIndex:t.collisionBoxArray.length,rt=C?C.boxEndIndex:t.collisionBoxArray.length,nt=E?E.boxStartIndex:t.collisionBoxArray.length,it=E?E.boxEndIndex:t.collisionBoxArray.length,at=L?L.boxStartIndex:t.collisionBoxArray.length,ot=L?L.boxEndIndex:t.collisionBoxArray.length,st=-1,lt=function(t,e){return t&&t.circleDiameter?Math.max(t.circleDiameter,e):e};st=lt(S,st),st=lt(C,st),st=lt(E,st);var ct=(st=lt(L,st))>-1?1:0;ct&&(st*=M/24),t.glyphOffsetArray.length>=fc.MAX_GLYPHS&&_(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),void 0!==b.sortKey&&t.addToSortKeyRanges(t.symbolInstances.length,b.sortKey),t.symbolInstances.emplaceBack(e.x,e.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,$,tt,et,rt,nt,it,at,ot,c,O,D,P,z,ct,0,h,j,U,st)}(t,f,s,r,n,i,h,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,v,w,M,l,x,T,A,d,e,a,c,u,o)};if(\"line\"===S)for(var I=0,P=jl(e.geometry,0,0,8192,8192);I<P.length;I+=1)for(var z=P[I],O=0,D=Nl(z,b,k,r.vertical||g,n,24,y,t.overscaling,8192);O<D.length;O+=1){var R=D[O];g&&nc(t,g.text,E,R)||L(z,R)}else if(\"line-center\"===S)for(var F=0,B=e.geometry;F<B.length;F+=1){var N=B[F];if(N.length>1){var j=Bl(N,k,r.vertical||g,n,24,y);j&&L(N,j)}}else if(\"Polygon\"===e.type)for(var U=0,V=Qo(e.geometry,0);U<V.length;U+=1){var q=V[U],H=Zl(q,16);L(q[0],new Cl(H.x,H.y,0))}else if(\"LineString\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1){var W=Y[G];L(W,new Cl(W[0].x,W[0].y,0))}else if(\"Point\"===e.type)for(var X=0,Z=e.geometry;X<Z.length;X+=1)for(var J=0,K=Z[X];J<K.length;J+=1){var Q=K[J];L([Q],new Cl(Q.x,Q.y,0))}}(t,a,p,N,n,c,f,h,w,j,o)},x=0,b=t.features;x<b.length;x+=1)y();a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(t[10]=(i+n)*(a=1/(n-i)),t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=ni,t.polygonIntersectsPolygon=Ba,t.postMapLoadEvent=it,t.postTurnstileEvent=rt,t.potpack=fl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=Dn,t.registerForPluginStateChange=function(t){return t({pluginStatus:Jn,pluginURL:Kn}),ti.on(\"pluginStateChange\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.scale$1=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t},t.scale$2=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t},t.setCacheLimits=function(t,e){at=t,ot=e},t.setRTLTextPlugin=function(t,e,r){if(void 0===r&&(r=!1),\"deferred\"===Jn||\"loading\"===Jn||\"loaded\"===Jn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Kn=R.resolveURL(t),Jn=\"deferred\",Zn=e,$n(),r||ri()},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.sqrLen=function(t){var e=t[0],r=t[1];return e*e+r*r},t.styleSpec=At,t.sub=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t},t.symbolSize=zl,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=ao,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];return e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n=e[0],t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]),t},t.triggerPluginCompletionEvent=Qn,t.uniqueId=h,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=An,t.validateStyle=Mn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=gs,t.version=\"1.10.1\",t.warnOnce=_,t.webpSupported=B,t.window=self,t.wrap=c})),n(0,(function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var f=u[c];delete this.keyCache[f],delete this._layerConfigs[f],delete this._layers[f]}this.familiesBySource={};for(var h=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);h<p.length;h+=1){var d=p[h].map((function(t){return i._layers[t.id]})),g=d[0];if(\"none\"!==g.visibility){var m=g.source||\"\",v=this.familiesBySource[m];v||(v=this.familiesBySource[m]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=v[y];x||(x=v[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),f=new t.AlphaImage({width:u.w||1,height:u.h||1});for(var h in e){var p=e[h];for(var d in p){var g=p[+d];if(g&&0!==g.bitmap.width&&0!==g.bitmap.height){var m=r[h][d].rect;t.AlphaImage.copy(g.bitmap,f,{x:0,y:0},{x:m.x+1,y:m.y+1},g.bitmap)}}}this.image=f,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId};function o(e,r,n){for(var i=new t.EvaluationParameters(r),a=0,o=e;a<o.length;a+=1)o[a].recalculate(i,n)}function s(e,r){var n=t.getArrayBuffer(e.request,(function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})}));return function(){n.cancel(),r()}}a.prototype.parse=function(e,r,n,a,s){var l=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var c=new t.DictionaryCoder(Object.keys(e.layers).sort()),u=new t.FeatureIndex(this.tileID,this.promoteId);u.bucketLayerIDs=[];var f,h,p,d,g={},m={featureIndex:u,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:n},v=r.familiesBySource[this.source];for(var y in v){var x=e.layers[y];if(x){1===x.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+y+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var b=c.encode(y),_=[],w=0;w<x.length;w++){var T=x.feature(w),k=u.getId(T,y);_.push({feature:T,id:k,index:w,sourceLayerIndex:b})}for(var M=0,A=v[y];M<A.length;M+=1){var S=A[M],E=S[0];E.minzoom&&this.zoom<Math.floor(E.minzoom)||E.maxzoom&&this.zoom>=E.maxzoom||\"none\"!==E.visibility&&(o(S,this.zoom,n),(g[E.id]=E.createBucket({index:u.bucketLayerIDs.length,layers:S,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:b,sourceID:this.source})).populate(_,m,this.tileID.canonical),u.bucketLayerIDs.push(S.map((function(t){return t.id}))))}}}var C=t.mapObject(m.glyphDependencies,(function(t){return Object.keys(t).map(Number)}));Object.keys(C).length?a.send(\"getGlyphs\",{uid:this.uid,stacks:C},(function(t,e){f||(f=t,h=e,P.call(l))})):h={};var L=Object.keys(m.iconDependencies);L.length?a.send(\"getImages\",{icons:L,source:this.source,tileID:this.tileID,type:\"icons\"},(function(t,e){f||(f=t,p=e,P.call(l))})):p={};var I=Object.keys(m.patternDependencies);function P(){if(f)return s(f);if(h&&p&&d){var e=new i(h),r=new t.ImageAtlas(p,d);for(var a in g){var l=g[a];l instanceof t.SymbolBucket?(o(l.layers,this.zoom,n),t.performSymbolLayout(l,h,e.positions,p,r.iconPositions,this.showCollisionBoxes,this.tileID.canonical)):l.hasPattern&&(l instanceof t.LineBucket||l instanceof t.FillBucket||l instanceof t.FillExtrusionBucket)&&(o(l.layers,this.zoom,n),l.addFeatures(m,this.tileID.canonical,r.patternPositions))}this.status=\"done\",s(null,{buckets:t.values(g).filter((function(t){return!t.isEmpty()})),featureIndex:u,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?p:null,glyphPositions:this.returnDependencies?e.positions:null})}}I.length?a.send(\"getImages\",{icons:I,source:this.source,tileID:this.tileID,type:\"patterns\"},(function(t,e){f||(f=t,d=e,P.call(l))})):d={},P.call(this)};var l=function(t,e,r,n){this.actor=t,this.layerIndex=e,this.availableImages=r,this.loadVectorData=n||s,this.loading={},this.loaded={}};l.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.RequestPerformance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,(function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var f=o.finish();f&&(u.resourceTiming=JSON.parse(JSON.stringify(f)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.availableImages,n.actor,(function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))})),n.loaded=n.loaded||{},n.loaded[i]=s}))},l.prototype.reloadTile=function(t,e){var r=this,n=this.loaded,i=t.uid,a=this;if(n&&n[i]){var o=n[i];o.showCollisionBoxes=t.showCollisionBoxes;var s=function(t,n){var i=o.reloadCallback;i&&(delete o.reloadCallback,o.parse(o.vectorTile,a.layerIndex,r.availableImages,a.actor,i)),e(t,n)};\"parsing\"===o.status?o.reloadCallback=s:\"done\"===o.status&&(o.vectorTile?o.parse(o.vectorTile,this.layerIndex,this.availableImages,this.actor,s):s())}},l.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},l.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var c=t.window.ImageBitmap,u=function(){this.loaded={}};function f(t,e){if(0!==t.length){h(t[0],e);for(var r=1;r<t.length;r++)h(t[r],!e)}}function h(t,e){for(var r=0,n=0,i=t.length,a=i-1;n<i;a=n++)r+=(t[n][0]-t[a][0])*(t[a][1]+t[n][1]);r>=0!=!!e&&t.reverse()}u.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=c&&a instanceof c?this.getImageData(a):a,s=new t.DEMData(n,o,i);this.loaded=this.loaded||{},this.loaded[n]=s,r(null,s)},u.prototype.getImageData=function(e){this.offscreenCanvas&&this.offscreenCanvasContext||(this.offscreenCanvas=new OffscreenCanvas(e.width,e.height),this.offscreenCanvasContext=this.offscreenCanvas.getContext(\"2d\")),this.offscreenCanvas.width=e.width,this.offscreenCanvas.height=e.height,this.offscreenCanvasContext.drawImage(e,0,0,e.width,e.height);var r=this.offscreenCanvasContext.getImageData(-1,-1,e.width+2,e.height+2);return this.offscreenCanvasContext.clearRect(0,0,this.offscreenCanvas.width,this.offscreenCanvas.height),new t.RGBAImage({width:r.width,height:r.height},r.data)},u.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,d=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};d.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var f=u[c];l.push(new t.Point$1(f[0],f[1]))}a.push(l)}return a},d.prototype.toGeoJSON=function(t,e,r){return p.call(this,t,e,r)};var g=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};g.prototype.feature=function(t){return new d(this._features[t])};var m=t.vectorTile.VectorTileFeature,v=y;function y(t,e){this.options=e||{},this.features=t,this.length=t.length}function x(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}y.prototype.feature=function(t){return new x(this.features[t],this.options.extent)},x.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},x.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},x.prototype.toGeoJSON=m.prototype.toGeoJSON;var b=w,_=v;function w(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,T,t.layers[r])}(e,r),r.finish()}function T(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,k,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,C,a[r])}function k(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,M,t),e.writeVarintField(3,r.type),e.writeMessage(4,E,r)}function M(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),a[s]=l=n.length-1),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var f=u+\":\"+c,h=o[f];void 0===h&&(i.push(c),o[f]=h=i.length-1),e.writeVarint(h)}}function A(t,e){return(e<<3)+(7&t)}function S(t){return t<<1^t>>31}function E(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(A(1,c));for(var u=3===n?l.length-1:l.length,f=0;f<u;f++){1===f&&1!==n&&e.writeVarint(A(2,u-1));var h=l[f].x-i,p=l[f].y-a;e.writeVarint(S(h)),e.writeVarint(S(p)),i+=h,a+=p}3===n&&e.writeVarint(A(7,1))}}function C(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function L(t,e,r,n){I(t,r,n),I(e,2*r,2*n),I(e,2*r+1,2*n+1)}function I(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function P(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}b.fromVectorTileJs=w,b.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new v(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return w({layers:r})},b.GeoJSONWrapper=_;var z=function(t){return t[0]},O=function(t){return t[1]},D=function(t,e,r,n,i){void 0===e&&(e=z),void 0===r&&(r=O),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),f=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+f)),Math.min(a,Math.floor(n+(s-l)*u/s+f)),o)}var h=r[2*n+o],p=i,d=a;for(L(e,r,i,n),r[2*a+o]>h&&L(e,r,i,a);p<d;){for(L(e,r,p,d),p++,d--;r[2*p+o]<h;)p++;for(;r[2*d+o]>h;)d--}r[2*i+o]===h?L(e,r,i,d):L(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};D.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var f=c.pop(),h=c.pop(),p=c.pop();if(h-p<=o)for(var d=p;d<=h;d++)l=e[2*d+1],(s=e[2*d])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+h)/2);l=e[2*g+1],(s=e[2*g])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var m=(f+1)%2;(0===f?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(m)),(0===f?i>=s:a>=l)&&(c.push(g+1),c.push(h),c.push(m))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},D.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),f=o.pop();if(u-f<=a)for(var h=f;h<=u;h++)P(e[2*h],e[2*h+1],r,n)<=l&&s.push(t[h]);else{var p=Math.floor((f+u)/2),d=e[2*p],g=e[2*p+1];P(d,g,r,n)<=l&&s.push(t[p]);var m=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(f),o.push(p-1),o.push(m)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(m))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var R={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:function(t){return t}},F=function(t){this.options=H(Object.create(R),t),this.trees=new Array(this.options.maxZoom+1)};function B(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function N(t,e){var r=t.geometry.coordinates,n=r[1];return{x:V(r[0]),y:q(n),zoom:1/0,index:e,parentId:-1}}function j(t){return{type:\"Feature\",id:t.id,properties:U(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function U(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return H(H({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function V(t){return t/360+.5}function q(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function H(t,e){for(var r in e)t[r]=e[r];return t}function G(t){return t.x}function Y(t){return t.y}function W(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function X(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)Z(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)Z(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)Z(t,e[n][i])}(i),i}function Z(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function J(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)K(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)K(i[c],s);else if(\"LineString\"===a)Q(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)Q(i[c],s=[],o,!1),t.push(X(l,\"LineString\",s,e.properties));return}$(i,s,o,!1)}else if(\"Polygon\"===a)$(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)J(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];$(i[c],u,o,!0),s.push(u)}}t.push(X(l,a,s,e.properties))}}function K(t,e){e.push(tt(t[0])),e.push(et(t[1])),e.push(0)}function Q(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=tt(t[s][0]),c=et(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],f=e[n],h=e[n+1],p=r+3;p<n;p+=3){var d=W(e[p],e[p+1],c,u,f,h);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function $(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];Q(t[i],a,r,n),e.push(a)}}function tt(t){return t/360+.5}function et(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function rt(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===h||\"MultiPoint\"===h)nt(f,g,r,n,i);else if(\"LineString\"===h)it(f,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===h)ot(f,g,r,n,i,!1);else if(\"Polygon\"===h)ot(f,g,r,n,i,!0);else if(\"MultiPolygon\"===h)for(var m=0;m<f.length;m++){var v=[];ot(f[m],v,r,n,i,!0),v.length&&g.push(v)}if(g.length){if(s.lineMetrics&&\"LineString\"===h){for(m=0;m<g.length;m++)l.push(X(u.id,h,g[m],u.tags));continue}\"LineString\"!==h&&\"MultiLineString\"!==h||(1===g.length?(h=\"LineString\",g=g[0]):h=\"MultiLineString\"),\"Point\"!==h&&\"MultiPoint\"!==h||(h=3===g.length?\"Point\":\"MultiPoint\"),l.push(X(u.id,h,g,u.tags))}}}return l.length?l:null}function nt(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function it(t,e,r,n,i,a,o){for(var s,l,c=at(t),u=0===i?lt:ct,f=t.start,h=0;h<t.length-3;h+=3){var p=t[h],d=t[h+1],g=t[h+2],m=t[h+3],v=t[h+4],y=0===i?p:d,x=0===i?m:v,b=!1;o&&(s=Math.sqrt(Math.pow(p-m,2)+Math.pow(d-v,2))),y<r?x>r&&(l=u(c,p,d,m,v,r),o&&(c.start=f+s*l)):y>n?x<n&&(l=u(c,p,d,m,v,n),o&&(c.start=f+s*l)):st(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,m,v,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,m,v,n),b=!0),!a&&b&&(o&&(c.end=f+s*l),e.push(c),c=at(t)),o&&(f+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&st(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&st(c,c[0],c[1],c[2]),c.length&&e.push(c)}function at(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function ot(t,e,r,n,i,a){for(var o=0;o<t.length;o++)it(t[o],e,r,n,i,a,!1)}function st(t,e,r,n){t.push(e),t.push(r),t.push(n)}function lt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function ct(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function ut(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=ft(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(ft(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(ft(a.geometry[s][c],e));i.push(l)}r.push(X(a.id,o,i,a.tags))}return r}function ft(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function ht(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(pt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var f=[];for(i=0;i<c[n].length;i+=2)f.push(pt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(f)}}return t.transformed=!0,t}function pt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function dt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,gt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,f=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),f>o.maxY&&(o.maxY=f)}return o}function gt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)mt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)mt(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)mt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var f in u={},e.tags)u[f]=e.tags[f];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var h={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(h.id=e.id),t.features.push(h)}}function mt(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function vt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)J(r,t.features[n],e,n);else J(r,\"Feature\"===t.type?t:{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=rt(t,1,-1-r,r,0,-1,2,e),a=rt(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=rt(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=ut(i,1).concat(n)),a&&(n=n.concat(ut(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function yt(t,e,r){return 32*((1<<t)*r+e)+t}function xt(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new g(n.features),a=b(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}F.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(N(t[l],l));this.trees[i+1]=new D(s,G,Y,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new D(s,G,Y,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},F.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,f=l.range(V(r),q(a),V(i),q(n));u<f.length;u+=1){var h=l.points[f[u]];c.push(h.numPoints?j(h):this.points[h.index])}return c},F.prototype.getChildren=function(t){var e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=i.points[c[l]];u.parentId===t&&s.push(u.numPoints?j(u):this.points[u.index])}if(0===s.length)throw new Error(n);return s},F.prototype.getLeaves=function(t,e,r){var n=[];return this._appendLeaves(n,t,e=e||10,r=r||0,0),n},F.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.radius/a.extent,s=(r-o)/i,l=(r+1+o)/i,c={features:[]};return this._addTileFeatures(n.range((e-o)/i,s,(e+1+o)/i,l),n.points,e,r,i,c),0===e&&this._addTileFeatures(n.range(1-o/i,s,1,l),n.points,i,r,i,c),e===i-1&&this._addTileFeatures(n.range(0,s,o/i,l),n.points,-1,r,i,c),c.features.length?c:null},F.prototype.getClusterExpansionZoom=function(t){for(var e=this._getOriginZoom(t)-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},F.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},F.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c=l.numPoints,u={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:c?U(l):this.points[l.index].properties},f=void 0;c?f=l.id:this.options.generateId?f=l.index:this.points[l.index].id&&(f=this.points[l.index].id),void 0!==f&&(u.id=f),a.features.push(u)}},F.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},F.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.reduce,a=n.radius/(n.extent*Math.pow(2,e)),o=0;o<t.length;o++){var s=t[o];if(!(s.zoom<=e)){s.zoom=e;for(var l=this.trees[e+1],c=l.within(s.x,s.y,a),u=s.numPoints||1,f=s.x*u,h=s.y*u,p=i&&u>1?this._map(s,!0):null,d=(o<<5)+(e+1)+this.points.length,g=0,m=c;g<m.length;g+=1){var v=l.points[m[g]];if(!(v.zoom<=e)){v.zoom=e;var y=v.numPoints||1;f+=v.x*y,h+=v.y*y,u+=y,v.parentId=d,i&&(p||(p=this._map(s,!0)),i(p,this._map(v)))}}1===u?r.push(s):(s.parentId=d,r.push(B(f/u,h/u,d,u,p)))}}return r},F.prototype._getOriginId=function(t){return t-this.points.length>>5},F.prototype._getOriginZoom=function(t){return(t-this.points.length)%32},F.prototype._map=function(t,e){if(t.numPoints)return e?H({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?H({},n):n},vt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},vt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,f=yt(e,r,n),h=this.tiles[f];if(!h&&(c>1&&console.time(\"creation\"),h=this.tiles[f]=dt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,h.numFeatures,h.numPoints,h.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(h.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||h.numPoints<=l.indexMaxPoints)continue;if(h.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,m,v,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,T=.5+_,k=1+_;g=m=v=y=null,x=rt(t,u,r-_,r+T,0,h.minX,h.maxX,l),b=rt(t,u,r+w,r+k,0,h.minX,h.maxX,l),t=null,x&&(g=rt(x,u,n-_,n+T,1,h.minY,h.maxY,l),m=rt(x,u,n+w,n+k,1,h.minY,h.maxY,l),x=null),b&&(v=rt(b,u,n-_,n+T,1,h.minY,h.maxY,l),y=rt(b,u,n+w,n+k,1,h.minY,h.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(m||[],e+1,2*r,2*n+1),s.push(v||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},vt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=yt(t,e=(e%o+o)%o,r);if(this.tiles[s])return ht(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,f=r;!l&&c>0;)c--,u=Math.floor(u/2),f=Math.floor(f/2),l=this.tiles[yt(c,u,f)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,f),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,f,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?ht(this.tiles[s],i):null):null};var bt=function(e){function r(t,r,n,i){e.call(this,t,r,n,xt),i&&(this.loadGeoJSON=i)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new t.RequestPerformance(n.request);this.loadGeoJSON(n,(function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){var n,i=e&&e.type;if(\"FeatureCollection\"===i)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===i)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===i)t(e.geometry,r);else if(\"Polygon\"===i)f(e.coordinates,r);else if(\"MultiPolygon\"===i)for(n=0;n<e.coordinates.length;n++)f(e.coordinates[n],r);return e}(o,!0);try{e._geoJSONIndex=n.cluster?new F(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var f=u[c],h=n[f],p=h[0],d=t.createExpression(h[1]),g=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",f]]:p);i[f]=d.value,a[f]=g.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):function(t,e){return new vt(t,e)}(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)}))}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded;return n&&n[t.uid]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){try{e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterChildren=function(t,e){try{e(null,this._geoJSONIndex.getChildren(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterLeaves=function(t,e){try{e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))}catch(t){e(t)}},r}(l),_t=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.availableImages={},this.workerSourceTypes={vector:l,geojson:bt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isParsed())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return _t.prototype.setReferrer=function(t,e){this.referrer=e},_t.prototype.setImages=function(t,e,r){for(var n in this.availableImages[t]=e,this.workerSources[t]){var i=this.workerSources[t][n];for(var a in i)i[a].availableImages=e}r()},_t.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},_t.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},_t.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},_t.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},_t.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},_t.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},_t.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},_t.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},_t.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},_t.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},_t.prototype.syncRTLPluginState=function(e,r,n){try{t.plugin.setState(r);var i=t.plugin.getPluginURL();if(t.plugin.isLoaded()&&!t.plugin.isParsed()&&null!=i){this.self.importScripts(i);var a=t.plugin.isParsed();n(a?void 0:new Error(\"RTL Text Plugin failed to import scripts from \"+i),a)}}catch(t){n(t.toString())}},_t.prototype.getAvailableImages=function(t){var e=this.availableImages[t];return e||(e=[]),e},_t.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},_t.prototype.getWorkerSource=function(t,e,r){var n=this;return this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),this.workerSources[t][e][r]||(this.workerSources[t][e][r]=new this.workerSourceTypes[e]({send:function(e,r,i){n.actor.send(e,r,i,t)}},this.getLayerIndex(t),this.getAvailableImages(t))),this.workerSources[t][e][r]},_t.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new u),this.demWorkerSources[t][e]},_t.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new _t(t.window)),_t})),n(0,(function(t){var e=t.createCommonjsModule((function(t){function e(t){return!r(t)}function r(t){return\"undefined\"==typeof window||\"undefined\"==typeof document?\"not a browser\":Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray?Function.prototype&&Function.prototype.bind?Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions?\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON?function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()?\"Uint8ClampedArray\"in window?ArrayBuffer.isView?function(){var t=document.createElement(\"canvas\");t.width=t.height=1;var e=t.getContext(\"2d\");if(!e)return!1;var r=e.getImageData(0,0,1,1);return r&&r.width===t.width}()?(void 0===n[r=t&&t.failIfMajorPerformanceCaveat]&&(n[r]=function(t){var r=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t);if(!r)return!1;var n=r.createShader(r.VERTEX_SHADER);return!(!n||r.isContextLost())&&(r.shaderSource(n,\"void main() {}\"),r.compileShader(n),!0===r.getShaderParameter(n,r.COMPILE_STATUS))}(r)),n[r]?void 0:\"insufficient WebGL support\"):\"insufficient Canvas/getImageData support\":\"insufficient ArrayBuffer support\":\"insufficient Uint8ClampedArray support\":\"insufficient worker support\":\"insufficient JSON support\":\"insufficient Object support\":\"insufficient Function support\":\"insufficent Array support\";var r}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e,window.mapboxgl.notSupportedReason=r);var n={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}})),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),t.addEventListener(e,r,\"passive\"in n&&l?n:n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),t.removeEventListener(e,r,\"passive\"in n&&l?n:n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function f(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout((function(){t.window.removeEventListener(\"click\",u,!0)}),0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect();return new t.Point(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=0;a<r.length;a++)i.push(new t.Point(r[a].clientX-n.left-e.clientLeft,r[a].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var h=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e];this._notify(n.ids,n.callback)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this._validate(t,e)&&(this.images[t]=e)},r.prototype._validate=function(e,r){var n=!0;return this._validateStretch(r.stretchX,r.data&&r.data.width)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchX\" value'))),n=!1),this._validateStretch(r.stretchY,r.data&&r.data.height)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchY\" value'))),n=!1),this._validateContent(r.content,r)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"content\" value'))),n=!1),n},r.prototype._validateStretch=function(t,e){if(!t)return!0;for(var r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];if(a[0]<r||a[1]<a[0]||e<a[1])return!1;r=a[1]}return!0},r.prototype._validateContent=function(t,e){return!(t&&(4!==t.length||t[0]<0||e.data.width<t[0]||t[1]<0||e.data.height<t[1]||t[2]<0||e.data.width<t[2]||t[3]<0||e.data.height<t[3]||t[2]<t[0]||t[3]<t[1]))},r.prototype.updateImage=function(t,e){e.version=this.images[t].version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1)this.images[i[n]]||(r=!1);this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,stretchX:s.stretchX,stretchY:s.stretchY,content:s.content,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,f=this.images[s].data,h=f.width,p=f.height;t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u},{width:h,height:p}),t.RGBAImage.copy(f,o,{x:0,y:p-1},{x:c,y:u-1},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u+p},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:h-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c+h,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];f(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=m,d=m,g=1e20;function m(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function y(t,e,r,n,i){r[0]=0,n[0]=-g,n[1]=+g;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+g}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}m.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?g:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?g:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++)r[n]=Math.max(0,Math.min(255,Math.round(255-255*((this.gridOuter[n]-this.gridInner[n])/this.radius+this.cutoff))));return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1)i.push({stack:a,id:s[o]});t.asyncAll(i,(function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{},ranges:{}});var o=a.glyphs[i];if(void 0===o){if(o=n._tinySDF(a,r,i))return a.glyphs[i]=o,void e(null,{stack:r,id:i,glyph:o});var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else if(a.ranges[s])e(null,{stack:r,id:i,glyph:o});else{var l=a.requests[s];l||(l=a.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,(function(t,e){if(e){for(var r in e)n._doesCharSupportLocalGlyph(+r)||(a.glyphs[+r]=e[+r]);a.ranges[s]=!0}for(var i=0,o=l;i<o.length;i+=1)(0,o[i])(t,e);delete a.requests[s]}))),l.push((function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})}))}}else e(null,{stack:r,id:i,glyph:o})}),(function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}}))},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar[\"CJK Unified Ideographs\"](e)||t.isChar[\"Hangul Syllables\"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&this._doesCharSupportLocalGlyph(n)){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new x.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,(function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}}))},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),T=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}};T.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]},T.prototype.getDashRanges=function(t,e,r){var n=[],i=t.length%2==1?-t[t.length-1]*r:0,a=t[0]*r,o=!0;n.push({left:i,right:a,isDash:o,zeroLength:0===t[0]});for(var s=t[0],l=1;l<t.length;l++){var c=t[l];n.push({left:i=s*r,right:a=(s+=c)*r,isDash:o=!o,zeroLength:0===c})}return n},T.prototype.addRoundDash=function(t,e,r){for(var n=e/2,i=-r;i<=r;i++)for(var a=this.width*(this.nextRow+r+i),o=0,s=t[o],l=0;l<this.width;l++){l/s.right>1&&(s=t[++o]);var c=Math.abs(l-s.left),u=Math.abs(l-s.right),f=Math.min(c,u),h=void 0,p=i/r*(n+1);if(s.isDash){var d=n-Math.abs(p);h=Math.sqrt(f*f+d*d)}else h=n-Math.sqrt(f*f+p*p);this.data[a+l]=Math.max(0,Math.min(255,h+128))}},T.prototype.addRegularDash=function(t){for(var e=t.length-1;e>=0;--e){var r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}var i=t[0],a=t[t.length-1];i.isDash===a.isDash&&(i.left=a.left-this.width,a.right=i.right+this.width);for(var o=this.width*this.nextRow,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),f=Math.abs(c-l.right),h=Math.min(u,f);this.data[o+c]=Math.max(0,Math.min(255,(l.isDash?h:-h)+128))}},T.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];if(0!==a){var s=this.width/a,l=this.getDashRanges(e,this.width,s);r?this.addRoundDash(l,s,n):this.addRegularDash(l)}var c={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,c},T.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=new e.Actor(i[a],n,this.id);o.name=\"Worker \"+a,this.actors.push(o)}};function M(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(t.extend(a,e),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map((function(t){return t.id}))),o.tiles=r.canonicalizeTileset(o,e.url),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame((function(){return i(null,e)}))}k.prototype.broadcast=function(e,r,n){t.asyncAll(this.actors,(function(t,n){t.send(e,r,n)}),n=n||function(){})},k.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},k.prototype.remove=function(){this.actors.forEach((function(t){t.remove()})),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var S=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme)),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};function a(n,i){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,e.actor&&\"expired\"!==e.state?\"loading\"===e.state?e.reloadCallback=r:e.request=e.actor.send(\"reloadTile\",i,a.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send(\"loadTile\",i,a.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:\"raster\"},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),(function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}}))},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),C=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({type:\"raster-dem\"},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);function i(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=t.window.ImageBitmap&&a instanceof t.window.ImageBitmap&&t.offscreenCanvasSupported()?a:t.browser.getImageData(a,1),s={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:o,encoding:this.encoding};e.actor&&\"expired\"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send(\"loadDEMTile\",s,i.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&t.actor.send(\"removeDEMTile\",{uid:t.uid,source:this.id})},r}(E),L=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=i.getActor(),this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution),this.promoteId=n.promoteId;var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1,generateId:n.generateId||!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}}))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}})),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.actor.send(this.type+\".loadData\",n,(function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.actor.send(r.type+\".coalesce\",{source:n.source},null),e(t))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,i=e.actor?\"reloadTile\":\"loadTile\";e.actor=this.actor,e.request=this.actor.send(i,{type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId},(function(t,a){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))}))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send(\"removeSource\",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),I=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),P=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),(function(i,a){n._loaded=!0,i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())}))},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,(function(){e.texture=null})),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=Math.max(i-r,a-n),u=Math.max(0,Math.floor(-Math.log(c)/Math.LN2)),f=Math.pow(2,u);return new t.CanonicalTileID(u,Math.floor((r+i)/2*f),Math.floor((n+a)/2*f))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map((function(t){return r.tileID.getTilePoint(t)._round()}));return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),z=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1)this.urls.push(this.map._requestManager.transformRequest(i[n],t.ResourceType.Source).url);t.getVideo(this.urls,(function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",(function(){e.map.triggerRepaint()})),e.map&&e.video.play(),e._finishLoading())}))},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+this.id,null,\"Playback for this video can be set only between the \"+r.start(0)+\" and \"+r.end(0)+\"-second mark.\"))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(P),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some((function(t){return!Array.isArray(t)||2!==t.length||t.some((function(t){return\"number\"!=typeof t}))}))||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(P),D={vector:S,raster:E,\"raster-dem\":C,geojson:L,video:z,image:P,canvas:O};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,i,a){var o=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(i&&i.layers,e,t.id),s=a.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(B);for(var c=[],u=0,f=l;u<f.length;u+=1){var h=f[u];c.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,r,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,i,a,s,R(t.transform,h.tileID))})}var p=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],f=l[c]=l[c]||{},h=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];f[g.featureIndex]||(f[g.featureIndex]=!0,h.push(g))}}return e}(c);for(var d in p)p[d].forEach((function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return p}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout((function(){n.remove(t,a)}),r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.getByKey=function(t){var e=this.data[t];return e?e[0].value:null},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this},N.prototype.filter=function(t){var e=[];for(var r in this.data)for(var n=0,i=this.data[r];n<i.length;n+=1){var a=i[n];t(a.value)||e.push(a)}for(var o=0,s=e;o<s.length;o+=1){var l=s[o];this.remove(l.value.tileID,l)}};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var U={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},V=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};V.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},V.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},V.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=e.attributes[this.attributes[r].name];void 0!==n&&t.enableVertexAttribArray(n)}},V.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[U[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},V.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),it=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),kt=function(t,e,r,n){this.context=t,this.width=e,this.height=r;var i=this.framebuffer=t.gl.createFramebuffer();this.colorAttachment=new wt(t,i),n&&(this.depthAttachment=new Tt(t,i))};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r)}t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Ct=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new X(this),this.stencilMask=new Z(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new it(this),this.blendEquation=new at(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ft(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new mt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&(t.getExtension(\"OES_texture_half_float_linear\"),this.extRenderToTextureHalfFloat=t.getExtension(\"EXT_color_buffer_half_float\")),this.extTimerQuery=t.getExtension(\"EXT_disjoint_timer_query\")};Ct.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Ct.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Ct.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Ct.prototype.createVertexBuffer=function(t,e,r){return new V(this,t,e,r)},Ct.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Ct.prototype.createFramebuffer=function(t,e,r){return new kt(this,t,e,r)},Ct.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Ct.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Ct.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Ct.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Ct.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Ct.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Lt=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",(function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))})),this.on(\"error\",(function(){a._sourceErrored=!0})),this._source=function(e,r,n,i){var a=new D[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a}(r,n,i,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,(function(){}))},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,(function(){}))},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return t.values(this._tiles).map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(i,e)&&n.push(this._tiles[i]);return e?n.sort((function(e,n){var i=e.tileID,a=n.tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x})).map((function(t){return t.tileID.key})):n.map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){if(t.key in this._loadedParentTiles){var r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(var n=t.overscaledZ-1;n>=e;n--){var i=t.scaledTo(n),a=this._getLoadedTile(i);if(a)return a}},r.prototype._getLoadedTile=function(t){var e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)},r.prototype.updateCacheSize=function(t){var e=Math.ceil(t.width/this._source.tileSize)+1,r=Math.ceil(t.height/this._source.tileSize)+1,n=Math.floor(e*r*5),i=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,n):n;this._cache.setMaxSize(i)},r.prototype.handleWrapJump=function(t){var e=Math.round((t-(void 0===this._prevLng?t:this._prevLng))/360);if(this._prevLng=t,e){var r={};for(var n in this._tiles){var i=this._tiles[n];i.tileID=i.tileID.unwrapTo(i.tileID.wrap+e),r[i.tileID.key]=i}for(var a in this._tiles=r,this._timers)clearTimeout(this._timers[a]),delete this._timers[a];for(var o in this._tiles)this._setTileReloadTimer(o,this._tiles[o])}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map((function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)})):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter((function(t){return n._source.hasTile(t)})))):i=[];var a=e.coveringZoomLevel(this._source),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},f=0,h=Object.keys(l);f<h.length;f+=1){var p=h[f],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var m=this.findLoadedParent(d,o);m&&(this._addTile(m.tileID),c[m.tileID.key]=m.tileID),u[p]=d}}for(var v in this._retainLoadedChildren(u,a,s,l),c)l[v]||(this._coveredTiles[v]=!0,l[v]=c[v])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}this._updateLoadedParentTileCache()}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],f=this._addTile(u);n[u.key]=u,f.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var h=0,p=t;h<p.length;h+=1){var d=p[h],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var m=d.children(this._source.maxzoom)[0],v=this.getTile(m);if(v&&v.hasData()){n[m.key]=m;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._updateLoadedParentTileCache=function(){for(var t in this._loadedParentTiles={},this._tiles){for(var e=[],r=void 0,n=this._tiles[t].tileID;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);var i=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(i))break;n=i}for(var a=0,o=e;a<o.length;a+=1)this._loadedParentTiles[o[a]]=r}},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout((function(){r._reloadTile(t,\"expired\"),delete r._timers[t]}),n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map((function(t){return o.pointCoordinate(t)})),c=s.map((function(t){return o.pointCoordinate(t)})),u=this.getIds(),f=1/0,h=1/0,p=-1/0,d=-1/0,g=0,m=c;g<m.length;g+=1){var v=m[g];f=Math.min(f,v.x),h=Math.min(h,v.y),p=Math.max(p,v.x),d=Math.max(d,v.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),m=r*n.queryPadding*t.EXTENT/n.tileSize/g,v=[s.getTilePoint(new t.MercatorCoordinate(f,h)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(v[0].x-m<t.EXTENT&&v[0].y-m<t.EXTENT&&v[1].x+m>=0&&v[1].y+m>=0){var y=l.map((function(t){return s.getTilePoint(t)})),x=c.map((function(t){return s.getTilePoint(t)}));a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map((function(t){return e._tiles[t].tileID})),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){this._state.updateState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.removeFeatureState=function(t,e,r){this._state.removeFeatureState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.getFeatureState=function(t,e){return this._state.getState(t=t||\"_geojsonTileLayer\",e)},r.prototype.setDependencies=function(t,e,r){var n=this._tiles[t];n&&n.setDependencies(e,r)},r.prototype.reloadTilesForDependencies=function(t,e){for(var r in this._tiles)this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\");this._cache.filter((function(r){return!r.hasDependency(t,e)}))},r}(t.Evented);function It(t,e){var r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function zt(){return new t.window.Worker(Yi.workerUrl)}Lt.maxOverzooming=10,Lt.maxUnderzooming=3;var Ot=\"mapboxgl_preloaded_worker_pool\",Dt=function(){this.active={}};Dt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<Dt.workerCount;)this.workers.push(new zt);return this.active[t]=!0,this.workers.slice()},Dt.prototype.release=function(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((function(t){t.terminate()})),this.workers=null)},Dt.prototype.isPreloaded=function(){return!!this.active[Ot]},Dt.prototype.numActive=function(){return Object.keys(this.active).length};var Rt,Ft=Math.floor(t.browser.hardwareConcurrency/2);function Bt(){return Rt||(Rt=new Dt),Rt}function Nt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach((function(t){t in r&&(n[t]=r[t])})),n}function jt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Nt(t[n],e[t[n].ref]));return t}Dt.workerCount=Math.max(Math.min(Ft,6),1);var Ut={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Vt(t,e,r){r.push({command:Ut.addSource,args:[t,e[t]]})}function qt(t,e,r){e.push({command:Ut.removeSource,args:[t]}),r[t]=!0}function Ht(t,e,r,n){qt(t,r,n),Vt(t,e,r)}function Gt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function Yt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Wt(t){return t.id}function Xt(t,e){return t[e.id]=e,t}var Zt=function(t,e){this.reset(t,e)};Zt.prototype.reset=function(t,e){this.points=t||[],this._distances=[0];for(var r=1;r<this.points.length;r++)this._distances[r]=this._distances[r-1]+this.points[r].dist(this.points[r-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding},Zt.prototype.lerp=function(e){if(1===this.points.length)return this.points[0];e=t.clamp(e,0,1);for(var r=1,n=this._distances[r],i=e*this.paddedLength+this.padding;n<i&&r<this._distances.length;)n=this._distances[++r];var a=r-1,o=this._distances[a],s=n-o,l=s>0?(i-o)/s:0;return this.points[a].mult(1-l).add(this.points[r].mult(l))};var Jt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Kt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Qt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function $t(e,r){var n=[e.x,e.y,0,1];ue(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function te(t,e){return.5+t/e*.5}function ee(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function re(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),f=[256/n.width*2+1,256/n.height*2+1],h=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;h.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,m=!1,v=0;v<d.length;v++){var y=d.get(v);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!m)ce(y.numGlyphs,h);else{m=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),ee(x,f)){var b=te(n.transform.cameraToCenterDistance,x[3]),_=t.evaluateSizeForFeature(c,u,y),w=s?_/b:_*b,T=new t.Point(y.anchorX,y.anchorY),k=$t(T,a).point,M={},A=ae(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g);m=A.useVertical,(A.notEnoughRoom||m||A.needsFlipping&&ae(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g).notEnoughRoom)&&ce(y.numGlyphs,h)}else ce(y.numGlyphs,h)}}i?e.text.dynamicLayoutVertexBuffer.updateData(h):e.icon.dynamicLayoutVertexBuffer.updateData(h)}function ne(t,e,r,n,i,a,o,s,l,c,u){var f=s.glyphStartIndex+s.numGlyphs,h=s.lineStartIndex,p=s.lineStartIndex+s.lineLength,d=e.getoffsetX(s.glyphStartIndex),g=e.getoffsetX(f-1),m=se(t*d,r,n,i,a,o,s.segment,h,p,l,c,u);if(!m)return null;var v=se(t*g,r,n,i,a,o,s.segment,h,p,l,c,u);return v?{first:m,last:v}:null}function ie(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ae(e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=r/24,v=e.lineOffsetX*m,y=e.lineOffsetY*m;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=ne(m,l,v,y,n,f,h,e,c,o,p);if(!w)return{notEnoughRoom:!0};var T=$t(w.first.point,s).point,k=$t(w.last.point,s).point;if(i&&!n){var M=ie(e.writingMode,T,k,d);if(M)return M}g=[w.first];for(var A=e.glyphStartIndex+1;A<x-1;A++)g.push(se(m*l.getoffsetX(A),v,y,n,f,h,e.segment,b,_,c,o,p));g.push(w.last)}else{if(i&&!n){var S=$t(h,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=$t(C,a),I=L.signedDistanceFromCamera>0?L.point:oe(h,C,S,1,a),P=ie(e.writingMode,S,I,d);if(P)return P}var z=se(m*l.getoffsetX(e.glyphStartIndex),v,y,n,f,h,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p);if(!z)return{notEnoughRoom:!0};g=[z]}for(var O=0,D=g;O<D.length;O+=1){var R=D[O];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function oe(t,e,r,n,i){var a=$t(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function se(e,r,n,i,a,o,s,l,c,u,f,h){var p=i?e-r:e+r,d=p>0?1:-1,g=0;i&&(d*=-1,g=Math.PI),d<0&&(g+=Math.PI);for(var m=d>0?l+s:l+s+1,v=a,y=a,x=0,b=0,_=Math.abs(p),w=[];x+b<=_;){if((m+=d)<l||m>=c)return null;if(y=v,w.push(v),void 0===(v=h[m])){var T=new t.Point(u.getx(m),u.gety(m)),k=$t(T,f);if(k.signedDistanceFromCamera>0)v=h[m]=k.point;else{var M=m-d;v=oe(0===x?o:new t.Point(u.getx(M),u.gety(M)),T,y,_-x+1,f)}}x+=b,b=y.dist(v)}var A=(_-x)/b,S=v.sub(y),E=S.mult(A)._add(y);E._add(S._unit()._perp()._mult(n*d));var C=g+Math.atan2(v.y-y.y,v.x-y.x);return w.push(E),{point:E,angle:C,path:w}}Jt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Jt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Jt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Jt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Jt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Jt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],f=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-f,y1:u-f,x2:c+f,y2:u+f})}return a?o.filter(a):o}return this._forEachCell(t,e,r,n,this._queryCell,o,{hitTest:i,seenUids:{box:{},circle:{}}},a),i?o.length>0:o},Jt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[];return this._forEachCell(a,s,o,l,this._queryCellCircle,c,{hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}},i),n?c.length>0:c},Jt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Jt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Jt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Jt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,f=0,h=c;f<h.length;f+=1){var p=h[f];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var m=this.circles,v=0,y=g;v<y.length;v+=1){var x=y[v];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(m[b],m[b+1],m[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=m[b],w=m[b+1],T=m[b+2];a.push({key:this.circleKeys[x],x1:_-T,y1:w-T,x2:_+T,y2:w+T})}}}},Jt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var f=this.bboxes,h=0,p=u;h<p.length;h+=1){var d=p[h];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,f[g+0],f[g+1],f[g+2],f[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var m=this.circleCells[i];if(null!==m)for(var v=this.circles,y=0,x=m;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(v[_],v[_+1],v[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Jt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),f=this._convertToYCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++)if(i.call(this,t,e,r,n,this.xCellCount*p+h,a,o,s))return},Jt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Jt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Jt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Jt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var f=l-s,h=u-c;return f*f+h*h<=r*r};var le=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ce(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(le,3*n)}}function ue(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var fe=function(t,e,r){void 0===e&&(e=new Jt(t.width+200,t.height+200,25)),void 0===r&&(r=new Jt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function he(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}fe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},fe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,f,h,p){var d=[],g=new t.Point(r.anchorX,r.anchorY),m=$t(g,o),v=te(this.transform.cameraToCenterDistance,m.signedDistanceFromCamera),y=(u?a/v:a*v)/t.ONE_EM,x=$t(g,s).point,b=ne(y,i,r.lineOffsetX*y,r.lineOffsetY*y,!1,x,g,r,n,s,{}),_=!1,w=!1,T=!0;if(b){for(var k=.5*h*v+p,M=new t.Point(-100,-100),A=new t.Point(this.screenRightBoundary,this.screenBottomBoundary),S=new Zt,E=b.first,C=b.last,L=[],I=E.path.length-1;I>=1;I--)L.push(E.path[I]);for(var P=1;P<C.path.length;P++)L.push(C.path[P]);var z=2.5*k;if(l){var O=L.map((function(t){return $t(t,l)}));L=O.some((function(t){return t.signedDistanceFromCamera<=0}))?[]:O.map((function(t){return t.point}))}var D=[];if(L.length>0){for(var R=L[0].clone(),F=L[0].clone(),B=1;B<L.length;B++)R.x=Math.min(R.x,L[B].x),R.y=Math.min(R.y,L[B].y),F.x=Math.max(F.x,L[B].x),F.y=Math.max(F.y,L[B].y);D=R.x>=M.x&&F.x<=A.x&&R.y>=M.y&&F.y<=A.y?[L]:F.x<M.x||R.x>A.x||F.y<M.y||R.y>A.y?[]:t.clipLine([L],M.x,M.y,A.x,A.y)}for(var N=0,j=D;N<j.length;N+=1){var U;S.reset(j[N],.25*k),U=S.length<=.5*k?1:Math.ceil(S.paddedLength/z)+1;for(var V=0;V<U;V++){var q=V/Math.max(U-1,1),H=S.lerp(q),G=H.x+100,Y=H.y+100;d.push(G,Y,k,0);var W=G-k,X=Y-k,Z=G+k,J=Y+k;if(T=T&&this.isOffscreen(W,X,Z,J),w=w||this.isInsideGrid(W,X,Z,J),!e&&this.grid.hitTestCircle(G,Y,k,f)&&(_=!0,!c))return{circles:[],offscreen:!1,collisionDetected:_}}}}return{circles:!c&&_||!w?[]:d,offscreen:T,collisionDetected:_}},fe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var f={},h={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],m=g.key;if(void 0===f[m.bucketInstanceId]&&(f[m.bucketInstanceId]={}),!f[m.bucketInstanceId][m.featureIndex]){var v=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,v)&&(f[m.bucketInstanceId][m.featureIndex]=!0,void 0===h[m.bucketInstanceId]&&(h[m.bucketInstanceId]=[]),h[m.bucketInstanceId].push(m.featureIndex))}}return h},fe.prototype.insertCollisionBox=function(t,e,r,n,i){(e?this.ignoredGrid:this.grid).insert({bucketInstanceId:r,featureIndex:n,collisionGroupID:i},t[0],t[1],t[2],t[3])},fe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},fe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ue(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},fe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},fe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary},fe.prototype.getViewportMatrix=function(){var e=t.identity([]);return t.translate(e,e,[-100,-100,0]),e};var pe=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};pe.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var de=function(t,e,r,n,i){this.text=new pe(t?t.text:null,e,r,i),this.icon=new pe(t?t.icon:null,e,n,i)};de.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var ge=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},me=function(){this.invProjMatrix=t.create(),this.viewportMatrix=t.create(),this.circles=[]},ve=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},ye=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function xe(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateVariableOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}function be(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,f=e.anchorPointX,h=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:f,anchorPointY:h}}ye.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var _e=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new fe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new ye(r),this.collisionCircleArrays={},this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function we(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}_e.prototype.getBucketParts=function(e,r,n,i){var a=n.getBucket(r),o=n.latestFeatureIndex;if(a&&o&&r.id===a.layerIds[0]){var s=n.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),u=n.tileSize/t.EXTENT,f=this.transform.calculatePosMatrix(n.tileID.toUnwrapped()),h=\"map\"===l.get(\"text-pitch-alignment\"),p=\"map\"===l.get(\"text-rotation-alignment\"),d=he(n,1,this.transform.zoom),g=Kt(f,h,p,this.transform,d),m=null;if(h){var v=Qt(f,h,p,this.transform,d);m=t.multiply([],this.transform.labelPlaneMatrix,v)}this.retainedQueryData[a.bucketInstanceId]=new ve(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,n.tileID);var y={bucket:a,layout:l,posMatrix:f,textLabelPlaneMatrix:g,labelToScreenMatrix:m,scale:c,textPixelRatio:u,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:t.evaluateSizeForZoom(a.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(a.sourceID)};if(i)for(var x=0,b=a.sortKeyRanges;x<b.length;x+=1){var _=b[x];e.push({sortKey:_.sortKey,symbolInstanceStart:_.symbolInstanceStart,symbolInstanceEnd:_.symbolInstanceEnd,parameters:y})}else e.push({symbolInstanceStart:0,symbolInstanceEnd:a.symbolInstances.length,parameters:y})}},_e.prototype.attemptAnchorPlacement=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=[f.textOffset0,f.textOffset1],v=xe(t,r,n,m,i),y=this.collisionIndex.placeCollisionBox(be(e,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate);if(!d||0!==this.collisionIndex.placeCollisionBox(be(d,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate).box.length)return y.box.length>0?(this.prevPlacement&&this.prevPlacement.variableOffsets[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID].text&&(g=this.prevPlacement.variableOffsets[f.crossTileID].anchor),this.variableOffsets[f.crossTileID]={textOffset:m,width:r,height:n,anchor:t,textBoxScale:i,prevAnchor:g},this.markUsedJustification(h,t,f,p),h.allowVerticalPlacement&&(this.markUsedOrientation(h,p,f),this.placedOrientations[f.crossTileID]=p),{shift:v,placedGlyphBoxes:y}):void 0},_e.prototype.placeLayerBucketPart=function(e,r,n){var i=this,a=e.parameters,o=a.bucket,s=a.layout,l=a.posMatrix,c=a.textLabelPlaneMatrix,u=a.labelToScreenMatrix,f=a.textPixelRatio,h=a.holdingForFade,p=a.collisionBoxArray,d=a.partiallyEvaluatedTextSize,g=a.collisionGroup,m=s.get(\"text-optional\"),v=s.get(\"icon-optional\"),y=s.get(\"text-allow-overlap\"),x=s.get(\"icon-allow-overlap\"),b=\"map\"===s.get(\"text-rotation-alignment\"),_=\"map\"===s.get(\"text-pitch-alignment\"),w=\"none\"!==s.get(\"icon-text-fit\"),T=\"viewport-y\"===s.get(\"symbol-z-order\"),k=y&&(x||!o.hasIconData()||v),M=x&&(y||!o.hasTextData()||m);!o.collisionArrays&&p&&o.deserializeCollisionBoxes(p);var A=function(e,a){if(!r[e.crossTileID])if(h)i.placements[e.crossTileID]=new ge(!1,!1,!1);else{var p,T=!1,A=!1,S=!0,E=null,C={box:null,offscreen:null},L={box:null,offscreen:null},I=null,P=null,z=0,O=0,D=0;a.textFeatureIndex?z=a.textFeatureIndex:e.useRuntimeCollisionCircles&&(z=e.featureIndex),a.verticalTextFeatureIndex&&(O=a.verticalTextFeatureIndex);var R=a.textBox;if(R){var F=function(r){var n=t.WritingMode.horizontal;if(o.allowVerticalPlacement&&!r&&i.prevPlacement){var a=i.prevPlacement.placedOrientations[e.crossTileID];a&&(i.placedOrientations[e.crossTileID]=a,i.markUsedOrientation(o,n=a,e))}return n},B=function(r,n){if(o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&a.verticalTextBox)for(var i=0,s=o.writingModes;i<s.length&&(s[i]===t.WritingMode.vertical?(C=n(),L=C):C=r(),!(C&&C.box&&C.box.length));i+=1);else C=r()};if(s.get(\"text-variable-anchor\")){var N=s.get(\"text-variable-anchor\");if(i.prevPlacement&&i.prevPlacement.variableOffsets[e.crossTileID]){var j=i.prevPlacement.variableOffsets[e.crossTileID];N.indexOf(j.anchor)>0&&(N=N.filter((function(t){return t!==j.anchor}))).unshift(j.anchor)}var U=function(t,r,n){for(var a=t.x2-t.x1,s=t.y2-t.y1,c=e.textBoxScale,u=w&&!x?r:null,h={box:[],offscreen:!1},p=y?2*N.length:N.length,d=0;d<p;++d){var m=i.attemptAnchorPlacement(N[d%N.length],t,a,s,c,b,_,f,l,g,d>=N.length,e,o,n,u);if(m&&(h=m.placedGlyphBoxes)&&h.box&&h.box.length){T=!0,E=m.shift;break}}return h};B((function(){return U(R,a.iconBox,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&!(C&&C.box&&C.box.length)&&e.numVerticalGlyphVertices>0&&r?U(r,a.verticalIconBox,t.WritingMode.vertical):{box:null,offscreen:null}})),C&&(T=C.box,S=C.offscreen);var V=F(C&&C.box);if(!T&&i.prevPlacement){var q=i.prevPlacement.variableOffsets[e.crossTileID];q&&(i.variableOffsets[e.crossTileID]=q,i.markUsedJustification(o,q.anchor,e,V))}}else{var H=function(t,r){var n=i.collisionIndex.placeCollisionBox(t,y,f,l,g.predicate);return n&&n.box&&n.box.length&&(i.markUsedOrientation(o,r,e),i.placedOrientations[e.crossTileID]=r),n};B((function(){return H(R,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&r?H(r,t.WritingMode.vertical):{box:null,offscreen:null}})),F(C&&C.box&&C.box.length)}}if(T=(p=C)&&p.box&&p.box.length>0,S=p&&p.offscreen,e.useRuntimeCollisionCircles){var G=o.text.placedSymbolArray.get(e.centerJustifiedTextSymbolIndex),Y=t.evaluateSizeForFeature(o.textSizeData,d,G),W=s.get(\"text-padding\");I=i.collisionIndex.placeCollisionCircles(y,G,o.lineVertexArray,o.glyphOffsetArray,Y,l,c,u,n,_,g.predicate,e.collisionCircleDiameter,W),T=y||I.circles.length>0&&!I.collisionDetected,S=S&&I.offscreen}if(a.iconFeatureIndex&&(D=a.iconFeatureIndex),a.iconBox){var X=function(t){var e=w&&E?be(t,E.x,E.y,b,_,i.transform.angle):t;return i.collisionIndex.placeCollisionBox(e,x,f,l,g.predicate)};A=L&&L.box&&L.box.length&&a.verticalIconBox?(P=X(a.verticalIconBox)).box.length>0:(P=X(a.iconBox)).box.length>0,S=S&&P.offscreen}var Z=m||0===e.numHorizontalGlyphVertices&&0===e.numVerticalGlyphVertices,J=v||0===e.numIconVertices;if(Z||J?J?Z||(A=A&&T):T=A&&T:A=T=A&&T,T&&p&&p.box&&i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,L&&L.box&&O?O:z,g.ID),A&&P&&i.collisionIndex.insertCollisionBox(P.box,s.get(\"icon-ignore-placement\"),o.bucketInstanceId,D,g.ID),I&&(T&&i.collisionIndex.insertCollisionCircles(I.circles,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,g.ID),n)){var K=o.bucketInstanceId,Q=i.collisionCircleArrays[K];void 0===Q&&(Q=i.collisionCircleArrays[K]=new me);for(var $=0;$<I.circles.length;$+=4)Q.circles.push(I.circles[$+0]),Q.circles.push(I.circles[$+1]),Q.circles.push(I.circles[$+2]),Q.circles.push(I.collisionDetected?1:0)}i.placements[e.crossTileID]=new ge(T||k,A||M,S||o.justReloaded),r[e.crossTileID]=!0}};if(T)for(var S=o.getSortedSymbolIndexes(this.transform.angle),E=S.length-1;E>=0;--E){var C=S[E];A(o.symbolInstances.get(C),o.collisionArrays[C])}else for(var L=e.symbolInstanceStart;L<e.symbolInstanceEnd;L++)A(o.symbolInstances.get(L),o.collisionArrays[L]);if(n&&o.bucketInstanceId in this.collisionCircleArrays){var I=this.collisionCircleArrays[o.bucketInstanceId];t.invert(I.invProjMatrix,l),I.viewportMatrix=this.collisionIndex.getViewportMatrix()}o.justReloaded=!1},_e.prototype.markUsedJustification=function(e,r,n,i){var a;a=i===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:{left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex}[t.getAnchorJustification(r)];for(var o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];o<s.length;o+=1){var l=s[o];l>=0&&(e.text.placedSymbolArray.get(l).crossTileID=a>=0&&l!==a?0:n.crossTileID)}},_e.prototype.markUsedOrientation=function(e,r,n){for(var i=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,a=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1)e.text.placedSymbolArray.get(s[o]).placedOrientation=i;n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=a)},_e.prototype.commit=function(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;var e=this.prevPlacement,r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;var n=e?e.symbolFadeChange(t):1,i=e?e.opacities:{},a=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=i[s];c?(this.opacities[s]=new de(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new de(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in i){var f=i[u];if(!this.opacities[u]){var h=new de(f,n,!1,!1);h.isHidden()||(this.opacities[u]=h,r=r||f.text.placed||f.icon.placed)}}for(var p in a)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=a[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},_e.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},_e.prototype.updateBucketOpacities=function(e,r,n){var i=this;e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexArray.clear(),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexArray.clear();var a=e.layers[0].layout,o=new de(null,0,!1,!1,!0),s=a.get(\"text-allow-overlap\"),l=a.get(\"icon-allow-overlap\"),c=a.get(\"text-variable-anchor\"),u=\"map\"===a.get(\"text-rotation-alignment\"),f=\"map\"===a.get(\"text-pitch-alignment\"),h=\"none\"!==a.get(\"icon-text-fit\"),p=new de(null,0,s&&(l||!e.hasIconData()||a.get(\"icon-optional\")),l&&(s||!e.hasTextData()||a.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData())&&e.deserializeCollisionBoxes(n);for(var d=function(t,e,r){for(var n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r)},g=function(n){var a=e.symbolInstances.get(n),s=a.numHorizontalGlyphVertices,l=a.numVerticalGlyphVertices,g=a.crossTileID,m=i.opacities[g];r[g]?m=o:m||(i.opacities[g]=m=p),r[g]=!0;var v=a.numIconVertices>0,y=i.placedOrientations[a.crossTileID],x=y===t.WritingMode.vertical,b=y===t.WritingMode.horizontal||y===t.WritingMode.horizontalOnly;if(s>0||l>0){var _=Le(m.text);d(e.text,s,x?Ie:_),d(e.text,l,b?Ie:_);var w=m.text.isHidden();[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=w||x?1:0)})),a.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(a.verticalPlacedTextSymbolIndex).hidden=w||b?1:0);var T=i.variableOffsets[a.crossTileID];T&&i.markUsedJustification(e,T.anchor,a,y);var k=i.placedOrientations[a.crossTileID];k&&(i.markUsedJustification(e,\"left\",a,k),i.markUsedOrientation(e,k,a))}if(v){var M=Le(m.icon),A=!(h&&a.verticalPlacedIconSymbolIndex&&x);a.placedIconSymbolIndex>=0&&(d(e.icon,a.numIconVertices,A?M:Ie),e.icon.placedSymbolArray.get(a.placedIconSymbolIndex).hidden=m.icon.isHidden()),a.verticalPlacedIconSymbolIndex>=0&&(d(e.icon,a.numVerticalIconVertices,A?Ie:M),e.icon.placedSymbolArray.get(a.verticalPlacedIconSymbolIndex).hidden=m.icon.isHidden())}if(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData()){var S=e.collisionArrays[n];if(S){var E=new t.Point(0,0);if(S.textBox||S.verticalTextBox){var C=!0;if(c){var L=i.variableOffsets[g];L?(E=xe(L.anchor,L.width,L.height,L.textOffset,L.textBoxScale),u&&E._rotate(f?i.transform.angle:-i.transform.angle)):C=!1}S.textBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||x,E.x,E.y),S.verticalTextBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||b,E.x,E.y)}var I=Boolean(!b&&S.verticalIconBox);S.iconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,I,h?E.x:0,h?E.y:0),S.verticalIconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,!I,h?E.x:0,h?E.y:0)}}},m=0;m<e.symbolInstances.length;m++)g(m);if(e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexBuffer&&e.iconCollisionBox.collisionVertexBuffer.updateData(e.iconCollisionBox.collisionVertexArray),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexBuffer&&e.textCollisionBox.collisionVertexBuffer.updateData(e.textCollisionBox.collisionVertexArray),e.bucketInstanceId in this.collisionCircleArrays){var v=this.collisionCircleArrays[e.bucketInstanceId];e.placementInvProjMatrix=v.invProjMatrix,e.placementViewportMatrix=v.viewportMatrix,e.collisionCircleArray=v.circles,delete this.collisionCircleArrays[e.bucketInstanceId]}},_e.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment},_e.prototype.zoomAdjustment=function(t){return Math.max(0,(this.transform.zoom-t)/1.5)},_e.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},_e.prototype.stillRecent=function(t,e){var r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t},_e.prototype.setStale=function(){this.stale=!0};var Te=Math.pow(2,25),ke=Math.pow(2,24),Me=Math.pow(2,17),Ae=Math.pow(2,16),Se=Math.pow(2,9),Ee=Math.pow(2,8),Ce=Math.pow(2,1);function Le(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Te+e*ke+r*Me+e*Ae+r*Se+e*Ee+r*Ce+e}var Ie=0,Pe=function(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&void 0!==t.layout.get(\"symbol-sort-key\").constantOr(1),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]};Pe.prototype.continuePlacement=function(t,e,r,n,i){for(var a=this._bucketParts;this._currentTileIndex<t.length;)if(e.getBucketParts(a,n,t[this._currentTileIndex],this._sortAcrossTiles),this._currentTileIndex++,i())return!0;for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,a.sort((function(t,e){return t.sortKey-e.sortKey})));this._currentPartIndex<a.length;)if(e.placeLayerBucketPart(a[this._currentPartIndex],this._seenCrossTileIDs,r),this._currentPartIndex++,i())return!0;return!1};var ze=function(t,e,r,n,i,a,o){this.placement=new _e(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};ze.prototype.isDone=function(){return this._done},ze.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Pe(s)),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},ze.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Oe=512/t.EXTENT/2,De=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};De.prototype.getScaledCoordinates=function(e,r){var n=Oe/Math.pow(2,r.canonical.z-this.tileID.canonical.z);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*n),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*n)}},De.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Re=function(){this.maxCrossTileID=0};Re.prototype.generate=function(){return++this.maxCrossTileID};var Fe=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Fe.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Fe.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var f=e.symbolInstances.get(u);f.crossTileID||(f.crossTileID=r.generate(),i[f.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new De(t,e.symbolInstances,e.bucketInstanceId),!0},Fe.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1)delete this.usedCrossTileIDs[t][i[n].crossTileID]},Fe.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Be=function(){this.layerIndexes={},this.crossTileIDs=new Re,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Be.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Fe);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Be.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach((function(t){e[t]=!0})),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Ne=function(e,r){return t.emitValidationErrors(e,r&&r.filter((function(t){return\"source.canvas\"!==t.identifier})))},je=t.pick(Ut,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ue=t.pick(Ut,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),Ve=function(){var e={},r=t.styleSpec.$version;for(var n in t.styleSpec.$root){var i,a=t.styleSpec.$root[n];a.required&&null!=(i=\"version\"===n?r:\"array\"===a.type?[]:{})&&(e[n]=i)}return e}(),qe=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k(Bt(),this),this.imageManager=new h,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new T(256,512),this.crossTileSymbolIndex=new Be,this._layers={},this._serializedLayers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginStateChange((function(e){o.dispatcher.broadcast(\"syncRTLPluginState\",{pluginStatus:e.pluginStatus,pluginURL:e.pluginURL},(function(e,r){if(t.triggerPluginCompletionEvent(e),r&&r.every((function(t){return t})))for(var n in o.sourceCaches)o.sourceCaches[n].reload()}))})),this.on(\"data\",(function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}}))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,(function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)}))},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame((function(){n._request=null,n._load(e,!1!==r.validate)}))},r.prototype.loadEmpty=function(){this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._load(Ve,!1)},r.prototype._load=function(e,r){if(!r||!Ne(this,t.validateStyle(e))){for(var n in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(n,e.sources[n],{validate:!1});e.sprite?this._loadSprite(e.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=jt(this.stylesheet.layers);this._order=i.map((function(t){return t.id})),this._layers={},this._serializedLayers={};for(var a=0,o=i;a<o.length;a+=1){var s=o[a];(s=t.createStyleLayer(s)).setEventedParent(this,{layer:{id:s.id}}),this._layers[s.id]=s,this._serializedLayers[s.id]=s.serialize()}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._loadSprite=function(e){var r=this;this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),(function(t,e){l=null,o||(o=t,i=e,u())})),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),(function(t,e){c=null,o||(o=t,a=e,u())}));function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,f=l.x,h=l.y,p=l.sdf,d=l.pixelRatio,g=l.stretchX,m=l.stretchY,v=l.content,y=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,y,{x:f,y:h},{x:0,y:0},{width:c,height:u}),r[s]={data:y,pixelRatio:d,sdf:p,stretchX:g,stretchY:m,content:v}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e,this.map._requestManager,(function(e,n){if(r._spriteRequest=null,e)r.fire(new t.ErrorEvent(e));else if(n)for(var i in n)r.imageManager.addImage(i,n[i]);r.imageManager.setLoaded(!0),r._availableImages=r.imageManager.listImages(),r.dispatcher.broadcast(\"setImages\",r._availableImages),r.fire(new t.Event(\"data\",{dataType:\"style\"}))}))},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=this._layers[n[r]];\"custom\"!==i.type&&e.push(i.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updateTilesForChangedImages(),this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];f.recalculate(e,this._availableImages),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateTilesForChangedImages=function(){var t=Object.keys(this._changedImages);if(t.length){for(var e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Ne(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=jt(e.layers);var n=function(e,r){if(!e)return[{command:Ut.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Ut.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Ut.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Ut.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Ut.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Ut.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Ut.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Ut.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Ut.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Ut.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||qt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Gt(e,r,a)?n.push({command:Ut.setGeoJSONSourceData,args:[a,r[a].data]}):Ht(a,r,n,i)):Vt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach((function(t){i[t.source]?n.push({command:Ut.removeLayer,args:[t.id]}):o.push(t)})),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,f=(e=e||[]).map(Wt),h=r.map(Wt),p=e.reduce(Xt,{}),d=r.reduce(Xt,{}),g=f.slice(),m=Object.create(null);for(i=0,a=0;i<f.length;i++)d.hasOwnProperty(o=f[i])?a++:(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<h.length;i++)g[g.length-1-i]!==(o=h[h.length-1-i])&&(p.hasOwnProperty(o)?(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,n.push({command:Ut.addLayer,args:[d[o],c=g[g.length-i]]}),g.splice(g.length-i,0,o),m[o]=!0);for(i=0;i<h.length;i++)if(s=p[o=h[i]],l=d[o],!m[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in Yt(s.layout,l.layout,n,o,null,Ut.setLayoutProperty),Yt(s.paint,l.paint,n,o,null,Ut.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Ut.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Ut.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Ut.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Ut.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Ut.setStyle,args:[r]}]}return n}(this.serialize(),e).filter((function(t){return!(t.command in Ue)}));if(0===n.length)return!1;var i=n.filter((function(t){return!(t.command in je)}));if(i.length>0)throw new Error(\"Unimplemented: \"+i.map((function(t){return t.command})).join(\", \")+\".\");return n.forEach((function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)})),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Lt(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,(function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}})),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Ne(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}}),this._serializedLayers[a.id]=a.serialize()}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._serializedLayers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.hasLayer=function(t){return t in this._layers},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n];if(void 0!==a){var o=a.getSource().type;\"geojson\"===o&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||i?(void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),a.setFeatureState(i,e.id,r)):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0;\"vector\"!==a||o?r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,e.id,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r];if(void 0!==i){if(\"vector\"!==i.getSource().type||n)return void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),i.getFeatureState(n,e.id);this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,(function(t){return t.serialize()})),layers:this._serializeLayers(this._order)},(function(t){return void 0!==t}))},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,f=c;u<f.length;u+=1)i.push(f[u])}}}i.sort((function(t,e){return e.intersectionZ-t.intersectionZ}));for(var h=[],p=this._order.length-1;p>=0;p--){var d=this._order[p];if(r(d))for(var g=i.length-1;g>=0;g--){var m=i[g].feature;if(n[m.layer.id]<p)break;h.push(m),i.pop()}else for(var v=0,y=t;v<y.length;v+=1){var x=y[v][d];if(x)for(var b=0,_=x;b<_.length;b+=1)h.push(_[b].feature)}}return h},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in r.availableImages=this._availableImages,this.sourceCaches)r.layers&&!i[u]||c.push(F(this.sourceCaches[u],this._layers,this._serializedLayers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a,o){for(var s={},l=a.queryRenderedSymbols(n),c=[],u=0,f=Object.keys(l).map(Number);u<f.length;u+=1)c.push(o[f[u]]);c.sort(B);for(var h=function(){var r=d[p],n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,i.filter,i.layers,i.availableImages,t);for(var a in n){var o=s[a]=s[a]||[],c=n[a];c.sort((function(t,e){var n=r.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-i}return e.featureIndex-t.featureIndex}));for(var u=0,f=c;u<f.length;u+=1)o.push(f[u])}},p=0,d=c;p<d.length;p+=1)h();var g=function(e){s[e].forEach((function(n){var i=n.feature,a=r[t[e].source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=a}))};for(var m in s)g(m);return s}(this._layers,this._serializedLayers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map((function(e){return t.getTileByID(e)})),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Ne(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginStateChange\",this._rtlTextPluginCallback),this._layers)this._layers[e].setEventedParent(null);for(var r in this.sourceCaches)this.sourceCaches[r].clearTiles(),this.sourceCaches[r].setEventedParent(null);this.imageManager.setEventedParent(null),this.setEventedParent(null),this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i,a){void 0===a&&(a=!1);for(var o=!1,s=!1,l={},c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];if(\"symbol\"===f.type){if(!l[f.source]){var h=this.sourceCaches[f.source];l[f.source]=h.getRenderableIds(!0).map((function(t){return h.getTileByID(t)})).sort((function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)}))}var p=this.crossTileSymbolIndex.addLayer(f,l[f.source],e.center.lng);o=o||p}}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((a=a||this._layerOrderChanged||0===n)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now(),e.zoom))&&(this.pauseablePlacement=new ze(e,this._order,a,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(var d=0,g=this._order;d<g.length;d+=1){var m=this._layers[g[d]];\"symbol\"===m.type&&this.placement.updateLayerOpacities(m,l[m.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r),this._updateTilesForChangedImages();var n=this.sourceCaches[e.source];n&&n.setDependencies(e.tileID.key,e.type,e.icons)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);qe.getSourceType=function(t){return D[t]},qe.setSourceType=function(t,e){D[t]=e},qe.registerForPluginStateChange=t.registerForPluginStateChange;var He=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Ge=vr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Ye=vr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=vr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),Xe=vr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ze=vr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Je=vr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),Ke=vr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),Qe=vr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),$e=vr(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),tr=vr(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,0,1);}\"),er=vr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),rr=vr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),nr=vr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),ir=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),ar=vr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),or=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),sr=vr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),lr=vr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),cr=vr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),ur=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),fr=vr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),hr=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),pr=vr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),dr=vr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),gr=vr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),mr=vr(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\");function vr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,(function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})),vertexSource:e=e.replace(r,(function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}))}}var yr=Object.freeze({__proto__:null,prelude:Ge,background:Ye,backgroundPattern:We,circle:Xe,clippingMask:Ze,heatmap:Je,heatmapTexture:Ke,collisionBox:Qe,collisionCircle:$e,debug:tr,fill:er,fillOutline:rr,fillOutlinePattern:nr,fillPattern:ir,fillExtrusion:ar,fillExtrusionPattern:or,hillshadePrepare:sr,hillshade:lr,line:cr,lineGradient:ur,linePattern:fr,lineSDF:hr,raster:pr,symbolIcon:dr,symbolSDF:gr,symbolTextAndIcon:mr}),xr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};xr.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);t.extVertexArrayObject&&this.vao&&this.boundProgram===e&&this.boundLayoutVertexBuffer===r&&!l&&this.boundIndexBuffer===i&&this.boundVertexOffset===a&&this.boundDynamicVertexBuffer===o&&this.boundDynamicVertexBuffer2===s?(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind()):this.freshBind(e,r,n,i,a,o,s)},xr.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var f=l;f<s;f++)u.disableVertexAttribArray(f)}e.enableAttributes(u,t);for(var h=0,p=r;h<p.length;h+=1)p[h].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var m=g[d];m.bind(),m.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},xr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var br=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r?r.defines():[];i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Ge.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Ge.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var f=r?r.layoutAttributes:[],h=0;h<f.length;h++)a.bindAttribLocation(this.program,h,f[h].name);a.linkProgram(this.program),a.deleteShader(u),a.deleteShader(c),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var m=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),v=0;v<m;v++){var y=a.getActiveUniform(this.program,v);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r?r.getUniforms(t,p):[]}}};function _r(t,e,r){var n=1/he(r,1,e.transform.tileZoom),i=Math.pow(2,r.tileID.overscaledZ),a=r.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(r.tileID.canonical.x+r.tileID.wrap*i),s=a*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}br.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=t.gl;if(!this.failedToCreate){for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,f,{zoom:h});for(var x=(m={},m[v.LINES]=2,m[v.TRIANGLES]=3,m[v.LINE_STRIP]=1,m)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],T=w.vaos||(w.vaos={});(T[s]||(T[s]=new xr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),v.drawElements(e,w.primitiveLength*x,v.UNSIGNED_SHORT,w.primitiveOffset*x*2)}}};var wr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},Tr=function(e,r,n,i,a,o,s){return t.extend(wr(e,r,n,i),_r(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},kr=function(t){return{u_matrix:t}},Mr=function(e,r,n,i){return t.extend(kr(e),_r(n,r,i))},Ar=function(t,e){return{u_matrix:t,u_world:e}},Sr=function(e,r,n,i,a){return t.extend(Mr(e,r,n,i),{u_world:a})},Er=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=he(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},Cr=function(t,e,r){var n=he(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},Lr=function(t,e,r){return{u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}},Ir=function(t,e,r){return void 0===r&&(r=1),{u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}},Pr=function(t){return{u_matrix:t}},zr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:he(e,1,r),u_intensity:n}},Or=function(e,r,n){var i=e.transform;return{u_matrix:Nr(e,r,n),u_ratio:1/he(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Dr=function(e,r,n){return t.extend(Or(e,r,n),{u_image:0})},Rr=function(e,r,n,i){var a=e.transform,o=Br(r,a);return{u_matrix:Nr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/he(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Fr=function(e,r,n,i,a){var o=e.lineAtlas,s=Br(r,e.transform),l=\"round\"===n.layout.get(\"line-cap\"),c=o.getDash(i.from,l),u=o.getDash(i.to,l),f=c.width*a.fromScale,h=u.width*a.toScale;return t.extend(Or(e,r,n),{u_patternscale_a:[s/f,-c.height/2],u_patternscale_b:[s/h,-u.height/2],u_sdfgamma:o.width/(256*Math.min(f,h)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:c.y,u_tex_y_b:u.y,u_mix:a.t})};function Br(t,e){return 1/he(t,1,e.tileZoom)}function Nr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var jr=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:Ur(i.paint.get(\"raster-hue-rotate\"))};var a,o};function Ur(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var Vr,qr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Hr=function(e,r,n,i,a,o,s,l,c,u,f){var h=a.transform;return t.extend(qr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(h._pitch)*h.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+f})},Gr=function(e,r,n,i,a,o,s,l,c,u){return t.extend(Hr(e,r,n,i,a,o,s,l,!0,c,!0),{u_texsize_icon:u,u_texture_icon:1})},Yr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Wr=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from.toString()),a=r.imageManager.getPattern(t.to.toString()),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,f=u*(n.tileID.canonical.x+n.tileID.wrap*c),h=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/he(n,1,r.transform.tileZoom),u_pixel_coord_upper:[f>>16,h>>16],u_pixel_coord_lower:[65535&f,65535&h]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Xr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},collisionCircle:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_inv_matrix:new t.UniformMatrix4f(e,r.u_inv_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_viewport_size:new t.Uniform2f(e,r.u_viewport_size)}},debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_overlay:new t.Uniform1i(e,r.u_overlay),u_overlay_scale:new t.Uniform1f(e,r.u_overlay_scale)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom),u_unpack:new t.Uniform4f(e,r.u_unpack)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},symbolTextAndIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texsize_icon:new t.Uniform2f(e,r.u_texsize_icon),u_texture:new t.Uniform1i(e,r.u_texture),u_texture_icon:new t.Uniform1i(e,r.u_texture_icon),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Zr(e,r,n,i,a,o,s){for(var l=e.context,c=l.gl,u=e.useProgram(\"collisionBox\"),f=[],h=0,p=0,d=0;d<i.length;d++){var g=i[d],m=r.getTile(g),v=m.getBucket(n);if(v){var y=g.posMatrix;0===a[0]&&0===a[1]||(y=e.translatePosMatrix(g.posMatrix,m,a,o));var x=s?v.textCollisionBox:v.iconCollisionBox,b=v.collisionCircleArray;if(b.length>0){var _=t.create(),w=y;t.mul(_,v.placementInvProjMatrix,e.transform.glCoordMatrix),t.mul(_,_,v.placementViewportMatrix),f.push({circleArray:b,circleOffset:p,transform:w,invTransform:_}),p=h+=b.length/4}x&&u.draw(l,c.LINES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,Cr(y,e.transform,m),n.id,x.layoutVertexBuffer,x.indexBuffer,x.segments,null,e.transform.zoom,null,null,x.collisionVertexBuffer)}}if(s&&f.length){var T=e.useProgram(\"collisionCircle\"),k=new t.StructArrayLayout2f1f2i16;k.resize(4*h),k._trim();for(var M=0,A=0,S=f;A<S.length;A+=1)for(var E=S[A],C=0;C<E.circleArray.length/4;C++){var L=4*C,I=E.circleArray[L+0],P=E.circleArray[L+1],z=E.circleArray[L+2],O=E.circleArray[L+3];k.emplace(M++,I,P,z,O,0),k.emplace(M++,I,P,z,O,1),k.emplace(M++,I,P,z,O,2),k.emplace(M++,I,P,z,O,3)}(!Vr||Vr.length<2*h)&&(Vr=function(e){var r=2*e,n=new t.StructArrayLayout3ui6;n.resize(r),n._trim();for(var i=0;i<r;i++){var a=6*i;n.uint16[a+0]=4*i+0,n.uint16[a+1]=4*i+1,n.uint16[a+2]=4*i+2,n.uint16[a+3]=4*i+2,n.uint16[a+4]=4*i+3,n.uint16[a+5]=4*i+0}return n}(h));for(var D=l.createIndexBuffer(Vr,!0),R=l.createVertexBuffer(k,t.collisionCircleLayout.members,!0),F=0,B=f;F<B.length;F+=1){var N=B[F],j=Lr(N.transform,N.invTransform,e.transform);T.draw(l,c.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,j,n.id,R,D,t.SegmentVector.simpleSegment(0,2*N.circleOffset,N.circleArray.length,N.circleArray.length/2),null,e.transform.zoom,null,null,null)}R.destroy(),D.destroy()}}var Jr=t.identity(new Float32Array(16));function Kr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateVariableOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Qr(e,r,n,i,a,o,s,l,c,u,f){var h=e.text.placedSymbolArray,p=e.text.dynamicLayoutVertexArray,d=e.icon.dynamicLayoutVertexArray,g={};p.clear();for(var m=0;m<h.length;m++){var v=h.get(m),y=v.hidden||!v.crossTileID||e.allowVerticalPlacement&&!v.placedOrientation?null:i[v.crossTileID];if(y){var x=new t.Point(v.anchorX,v.anchorY),b=$t(x,n?l:s),_=te(o.cameraToCenterDistance,b.signedDistanceFromCamera),w=a.evaluateSizeForFeature(e.textSizeData,u,v)*_/t.ONE_EM;n&&(w*=e.tilePixelRatio/c);for(var T=Kr(y.anchor,y.width,y.height,y.textOffset,y.textBoxScale,w),k=n?$t(x.add(T),s).point:b.point.add(r?T.rotate(-o.angle):T),M=e.allowVerticalPlacement&&v.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,A=0;A<v.numGlyphs;A++)t.addDynamicAttributes(p,k,M);f&&v.associatedIconIndex>=0&&(g[v.associatedIconIndex]={shiftedAnchor:k,angle:M})}else ce(v.numGlyphs,p)}if(f){d.clear();for(var S=e.icon.placedSymbolArray,E=0;E<S.length;E++){var C=S.get(E);if(C.hidden)ce(C.numGlyphs,d);else{var L=g[E];if(L)for(var I=0;I<C.numGlyphs;I++)t.addDynamicAttributes(d,L.shiftedAnchor,L.angle);else ce(C.numGlyphs,d)}}e.icon.dynamicLayoutVertexBuffer.updateData(d)}e.text.dynamicLayoutVertexBuffer.updateData(p)}function $r(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function tn(e,r,n,i,a,o,s,l,c,u,f,h){for(var p=e.context,d=p.gl,g=e.transform,m=\"map\"===l,v=\"map\"===c,y=m&&\"point\"!==n.layout.get(\"symbol-placement\"),x=m&&!v&&!y,b=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),_=e.depthModeForSublayer(0,Mt.ReadOnly),w=n.layout.get(\"text-variable-anchor\"),T=[],k=0,M=i;k<M.length;k+=1){var A=M[k],S=r.getTile(A),E=S.getBucket(n);if(E){var C=a?E.text:E.icon;if(C&&C.segments.get().length){var L=C.programConfigurations.get(n.id),I=a||E.sdfIcons,P=a?E.textSizeData:E.iconSizeData,z=v||0!==g.pitch,O=e.useProgram($r(I,a,E),L),D=t.evaluateSizeForZoom(P,g.zoom),R=void 0,F=[0,0],B=void 0,N=void 0,j=null,U=void 0;if(a)B=S.glyphAtlasTexture,N=d.LINEAR,R=S.glyphAtlasTexture.size,E.iconsInText&&(F=S.imageAtlasTexture.size,j=S.imageAtlasTexture,U=z||e.options.rotating||e.options.zooming||\"composite\"===P.kind||\"camera\"===P.kind?d.LINEAR:d.NEAREST);else{var V=1!==n.layout.get(\"icon-size\").constantOr(0)||E.iconsNeedLinear;B=S.imageAtlasTexture,N=I||e.options.rotating||e.options.zooming||V||z?d.LINEAR:d.NEAREST,R=S.imageAtlasTexture.size}var q=he(S,1,e.transform.zoom),H=Kt(A.posMatrix,v,m,e.transform,q),G=Qt(A.posMatrix,v,m,e.transform,q),Y=w&&E.hasTextData(),W=\"none\"!==n.layout.get(\"icon-text-fit\")&&Y&&E.hasIconData();y&&re(E,A.posMatrix,e,a,H,G,v,u);var X=e.translatePosMatrix(A.posMatrix,S,o,s),Z=y||a&&w||W?Jr:H,J=e.translatePosMatrix(G,S,o,s,!0),K=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Q={program:O,buffers:C,uniformValues:I?E.iconsInText?Gr(P.kind,D,x,v,e,X,Z,J,R,F):Hr(P.kind,D,x,v,e,X,Z,J,a,R,!0):qr(P.kind,D,x,v,e,X,Z,J,a,R),atlasTexture:B,atlasTextureIcon:j,atlasInterpolation:N,atlasInterpolationIcon:U,isSDF:I,hasHalo:K};if(b)for(var $=0,tt=C.segments.get();$<tt.length;$+=1){var et=tt[$];T.push({segments:new t.SegmentVector([et]),sortKey:et.sortKey,state:Q})}else T.push({segments:C.segments,sortKey:0,state:Q})}}}b&&T.sort((function(t,e){return t.sortKey-e.sortKey}));for(var rt=0,nt=T;rt<nt.length;rt+=1){var it=nt[rt],at=it.state;if(p.activeTexture.set(d.TEXTURE0),at.atlasTexture.bind(at.atlasInterpolation,d.CLAMP_TO_EDGE),at.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),at.atlasTextureIcon&&at.atlasTextureIcon.bind(at.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),at.isSDF){var ot=at.uniformValues;at.hasHalo&&(ot.u_is_halo=1,en(at.buffers,it.segments,n,e,at.program,_,f,h,ot)),ot.u_is_halo=0}en(at.buffers,it.segments,n,e,at.program,_,f,h,at.uniformValues)}}function en(t,e,r,n,i,a,o,s,l){var c=n.context;i.draw(c,c.gl.TRIANGLES,a,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function rn(t,e,r,n,i,a,o){var s,l,c,u,f,h=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=h.LINES):(l=d?\"fillPattern\":\"fill\",s=h.TRIANGLES);for(var m=0,v=n;m<v.length;m+=1){var y=v[m],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(h.TEXTURE0),x.imageAtlasTexture.bind(h.LINEAR,h.CLAMP_TO_EDGE),_.updatePaintBuffers(g));var T=p.constantOr(null);if(T&&x.imageAtlas){var k=x.imageAtlas,M=k.patternPositions[T.to.toString()],A=k.patternPositions[T.from.toString()];M&&A&&_.setConstantPatternPositions(M,A)}var S=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,f=b.segments2;var E=[h.drawingBufferWidth,h.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?Sr(S,t,g,x,E):Ar(S,E)}else u=b.indexBuffer,f=b.segments,c=d?Mr(S,t,g,x):kr(S);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,Et.disabled,c,r.id,b.layoutVertexBuffer,u,f,r.paint,t.transform.zoom,_)}}}}function nn(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),f=r.getCrossfadeParameters(),h=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],m=e.getTile(g),v=m.getBucket(r);if(v){var y=v.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),m.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePaintBuffers(f));var b=c.constantOr(null);if(b&&m.imageAtlas){var _=m.imageAtlas,w=_.patternPositions[b.to.toString()],T=_.patternPositions[b.from.toString()];w&&T&&y.setConstantPatternPositions(w,T)}var k=t.translatePosMatrix(g.posMatrix,m,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),M=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?Tr(k,t,M,h,g,f,m):wr(k,t,M,h);x.draw(s,s.gl.TRIANGLES,i,a,o,Et.backCCW,A,r.id,v.layoutVertexBuffer,v.indexBuffer,v.segments,r.paint,t.transform.zoom,y)}}}function an(e,r,n,i,a,o){var s=e.context,l=s.gl,c=r.fbo;if(c){var u=e.useProgram(\"hillshade\");s.activeTexture.set(l.TEXTURE0),l.bindTexture(l.TEXTURE_2D,c.colorAttachment.get());var f=function(e,r,n){var i=n.paint.get(\"hillshade-shadow-color\"),a=n.paint.get(\"hillshade-highlight-color\"),o=n.paint.get(\"hillshade-accent-color\"),s=n.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===n.paint.get(\"hillshade-illumination-anchor\")&&(s-=e.transform.angle);var l,c,u,f=!e.options.moving;return{u_matrix:e.transform.calculatePosMatrix(r.tileID.toUnwrapped(),f),u_image:0,u_latrange:(l=r.tileID,c=Math.pow(2,l.canonical.z),u=l.canonical.y,[new t.MercatorCoordinate(0,u/c).toLngLat().lat,new t.MercatorCoordinate(0,(u+1)/c).toLngLat().lat]),u_light:[n.paint.get(\"hillshade-exaggeration\"),s],u_shadow:i,u_highlight:a,u_accent:o}}(e,r,n);u.draw(s,l.TRIANGLES,i,a,o,Et.disabled,f,n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments)}}function on(e,r,n,i,a,o,s){var l=e.context,c=l.gl,u=r.dem;if(u&&u.data){var f=u.dim,h=u.stride,p=u.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var d=r.demTexture;d.update(p,{premultiply:!1}),d.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,p,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var g=r.fbo;if(!g){var m=new t.Texture(l,{width:f,height:f,data:null},c.RGBA);m.bind(c.LINEAR,c.CLAMP_TO_EDGE),(g=r.fbo=l.createFramebuffer(f,f,!0)).colorAttachment.set(m.texture)}l.bindFramebuffer.set(g.framebuffer),l.viewport.set([0,0,f,f]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,Et.disabled,function(e,r,n){var i=r.stride,a=t.create();return t.ortho(a,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(a,a,[0,-t.EXTENT,0]),{u_matrix:a,u_image:1,u_dimension:[i,i],u_zoom:e.overscaledZ,u_maxzoom:n,u_unpack:r.getUnpackVector()}}(r.tileID,u,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function sn(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),f=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),h=!r||Math.abs(r.tileID.overscaledZ-f)>Math.abs(e.tileID.overscaledZ-f),p=h&&e.refreshedUponExpiration?1:t.clamp(h?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}var ln=new t.Color(1,0,0,1),cn=new t.Color(0,1,0,1),un=new t.Color(0,0,1,1),fn=new t.Color(1,0,1,1),hn=new t.Color(0,1,1,1);function pn(t,e,r,n){gn(t,0,e+r/2,t.transform.width,r,n)}function dn(t,e,r,n){gn(t,e-r/2,0,r,t.transform.height,n)}function gn(e,r,n,i,a,o){var s=e.context,l=s.gl;l.enable(l.SCISSOR_TEST),l.scissor(r*t.browser.devicePixelRatio,n*t.browser.devicePixelRatio,i*t.browser.devicePixelRatio,a*t.browser.devicePixelRatio),s.clear({color:o}),l.disable(l.SCISSOR_TEST)}function mn(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Mt.disabled,c=At.disabled,u=e.colorModeForRenderPass();i.activeTexture.set(a.TEXTURE0),e.emptyTexture.bind(a.LINEAR,a.CLAMP_TO_EDGE),s.draw(i,a.LINE_STRIP,l,c,u,Et.disabled,Ir(o,t.Color.red),\"$debug\",e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);var f=r.getTileByID(n.key).latestRawTileData,h=Math.floor((f&&f.byteLength||0)/1024),p=r.getTile(n).tileSize,d=512/Math.min(p,512)*(n.overscaledZ/e.transform.zoom)*.5,g=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(g+=\" => \"+n.overscaledZ),function(t,e){t.initDebugOverlayCanvas();var r=t.debugOverlayCanvas,n=t.context.gl,i=t.debugOverlayCanvas.getContext(\"2d\");i.clearRect(0,0,r.width,r.height),i.shadowColor=\"white\",i.shadowBlur=2,i.lineWidth=1.5,i.strokeStyle=\"white\",i.textBaseline=\"top\",i.font=\"bold 36px Open Sans, sans-serif\",i.fillText(e,5,5),i.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(e,g+\" \"+h+\"kb\"),s.draw(i,a.TRIANGLES,l,c,St.alphaBlended,Et.disabled,Ir(o,t.Color.transparent,d),\"$debug\",e.debugBuffer,e.quadTriangleIndexBuffer,e.debugSegments)}var vn={symbol:function(e,r,n,i,a){if(\"translucent\"===e.renderPass){var o=At.disabled,s=e.colorModeForRenderPass();n.layout.get(\"text-variable-anchor\")&&function(e,r,n,i,a,o,s){for(var l=r.transform,c=\"map\"===a,u=\"map\"===o,f=0,h=e;f<h.length;f+=1){var p=h[f],d=i.getTile(p),g=d.getBucket(n);if(g&&g.text&&g.text.segments.get().length){var m=t.evaluateSizeForZoom(g.textSizeData,l.zoom),v=he(d,1,r.transform.zoom),y=Kt(p.posMatrix,u,c,r.transform,v),x=\"none\"!==n.layout.get(\"icon-text-fit\")&&g.hasIconData();if(m){var b=Math.pow(2,l.zoom-d.tileID.overscaledZ);Qr(g,c,u,s,t.symbolSize,l,y,p.posMatrix,b,m,x)}}}}(i,e,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),a),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&tn(e,r,n,i,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&tn(e,r,n,i,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(Zr(e,r,n,i,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),!0),Zr(e,r,n,i,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),!1))}},circle:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=void 0!==n.layout.get(\"circle-sort-key\").constantOr(1);if(0!==a.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,f=e.depthModeForSublayer(0,Mt.ReadOnly),h=At.disabled,p=e.colorModeForRenderPass(),d=[],g=0;g<i.length;g++){var m=i[g],v=r.getTile(m),y=v.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram(\"circle\",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:Er(e,m,v,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var T=w[_];d.push({segments:new t.SegmentVector([T]),sortKey:T.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort((function(t,e){return t.sortKey-e.sortKey}));for(var k=0,M=d;k<M.length;k+=1){var A=M[k],S=A.state;S.program.draw(c,u.TRIANGLES,f,h,p,Et.disabled,S.uniformValues,n.id,S.layoutVertexBuffer,S.indexBuffer,A.segments,n.paint,e.transform.zoom,S.programConfiguration)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=At.disabled,l=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1),function(t,e,r,n){var i=t.gl;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,e.width/4,e.height/4,0,i.RGBA,t.extRenderToTextureHalfFloat?t.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE,null),n.colorAttachment.set(r)}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var c=0;c<i.length;c++){var u=i[c];if(!r.hasRenderableParent(u)){var f=r.getTile(u),h=f.getBucket(n);if(h){var p=h.programConfigurations.get(n.id);e.useProgram(\"heatmap\",p).draw(a,o.TRIANGLES,Mt.disabled,s,l,Et.disabled,zr(u.posMatrix,f,e.transform.zoom,n.paint.get(\"heatmap-intensity\")),n.id,h.layoutVertexBuffer,h.indexBuffer,h.segments,n.paint,e.transform.zoom,p)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:0,u_color_ramp:1,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),f=u.constantOr(1),h=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=f?\"linePattern\":c?\"lineSDF\":h?\"lineGradient\":\"line\",g=e.context,m=g.gl,v=!0;if(h){g.activeTexture.set(m.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,m.RGBA)),y.bind(m.LINEAR,m.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!f||w.patternsLoaded()){var T=w.getBucket(n);if(T){var k=T.programConfigurations.get(n.id),M=e.context.program.get(),A=e.useProgram(d,k),S=v||A.program!==M,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas,L=C.patternPositions[E.to.toString()],I=C.patternPositions[E.from.toString()];L&&I&&k.setConstantPatternPositions(L,I)}var P=f?Rr(e,w,n,p):c?Fr(e,w,n,c,p):h?Dr(e,w,n):Or(e,w,n);f?(g.activeTexture.set(m.TEXTURE0),w.imageAtlasTexture.bind(m.LINEAR,m.CLAMP_TO_EDGE),k.updatePaintBuffers(p)):c&&(S||e.lineAtlas.dirty)&&(g.activeTexture.set(m.TEXTURE0),e.lineAtlas.bind(g)),A.draw(g,m.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,P,n.id,T.layoutVertexBuffer,T.indexBuffer,T.segments,n.paint,e.transform.zoom,k),v=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);rn(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var f=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Mt.ReadOnly);rn(e,r,n,i,f,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))nn(t,e,r,n,a,At.disabled,St.disabled),nn(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();nn(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Mt.ReadOnly),s=t.colorModeForRenderPass(),l=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n],c=l[0],u=0,f=l[1];u<f.length;u+=1){var h=f[u],p=e.getTile(h);p.needsHillshadePrepare&&\"offscreen\"===t.renderPass?on(t,p,r,a,o,At.disabled,s):\"translucent\"===t.renderPass&&an(t,p,r,o,c[h.overscaledZ],s)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")&&n.length)for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),c=o instanceof P?[{},n]:t.stencilConfigForOverlap(n),u=c[0],f=c[1],h=f[f.length-1].overscaledZ,p=!t.options.moving,d=0,g=f;d<g.length;d+=1){var m=g[d],v=t.depthModeForSublayer(m.overscaledZ-h,1===r.paint.get(\"raster-opacity\")?Mt.ReadWrite:Mt.ReadOnly,a.LESS),y=e.getTile(m),x=t.transform.calculatePosMatrix(m.toUnwrapped(),p);y.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var b=e.findLoadedParent(m,0),_=sn(y,b,e,r,t.transform),w=void 0,T=void 0,k=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),b?(b.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),w=Math.pow(2,b.tileID.overscaledZ-y.tileID.overscaledZ),T=[y.tileID.canonical.x*w%1,y.tileID.canonical.y*w%1]):y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var M=jr(x,T||[0,0],w||1,_,r);o instanceof P?s.draw(i,a.TRIANGLES,v,At.disabled,l,Et.disabled,M,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(i,a.TRIANGLES,v,u[m.overscaledZ],l,Et.disabled,M,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===i&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass===u){var f=At.disabled,h=t.depthModeForSublayer(0,\"opaque\"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var m=r.getCrossfadeParameters(),v=0,y=g;v<y.length;v+=1){var x=y[v],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Wr(b,i,t,c,{tileID:x,tileSize:l},m):Yr(b,i,n);d.draw(a,o.TRIANGLES,h,f,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)mn(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},yn=function(t,e){this.context=new Ct(t),this.transform=e,this._tileTextures={},this.setup(),this.numSublayers=Lt.maxUnderzooming+Lt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new Be,this.gpuTimers={}};yn.prototype.resize=function(e,r){if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,i=this.style._order;n<i.length;n+=1)this.style._layers[i[n]].resize()},yn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,He.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,He.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,I.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,He.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s),this.emptyTexture=new t.Texture(e,{width:1,height:1,data:new Uint8Array([0,0,0,0])},e.gl.RGBA);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},yn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,St.disabled,Et.disabled,Pr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},yn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(Mt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Mt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Pr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},yn.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilConfigForOverlap=function(t){var e,r=this.context.gl,n=t.sort((function(t,e){return e.overscaledZ-t.overscaledZ})),i=n[n.length-1].overscaledZ,a=n[0].overscaledZ-i+1;if(a>1){this.currentStencilSource=void 0,this.nextStencilID+a>256&&this.clearStencil();for(var o={},s=0;s<a;s++)o[s+i]=new At({func:r.GEQUAL,mask:255},s+this.nextStencilID,255,r.KEEP,r.KEEP,r.REPLACE);return this.nextStencilID+=a,[o,n]}return[(e={},e[i]=At.disabled,e),n]},yn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?St.unblended:St.alphaBlended},yn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},yn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},yn.prototype.render=function(e,r){var n=this;this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var i=this.style._order,a=this.style.sourceCaches;for(var o in a){var s=a[o];s.used&&s.prepare(this.context)}var l,c,u={},f={},h={};for(var p in a){var d=a[p];u[p]=d.getVisibleCoordinates(),f[p]=u[p].slice().reverse(),h[p]=d.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(var g=0;g<i.length;g++)if(this.style._layers[i[g]].is3D()){this.opaquePassCutoff=g;break}this.renderPass=\"offscreen\";for(var m=0,v=i;m<v.length;m+=1){var y=this.style._layers[v[m]];if(y.hasOffscreenPass()&&!y.isHidden(this.transform.zoom)){var x=f[y.source];(\"custom\"===y.type||x.length)&&this.renderLayer(this,a[y.source],y,x)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=i.length-1;this.currentLayer>=0;this.currentLayer--){var b=this.style._layers[i[this.currentLayer]],_=a[b.source],w=u[b.source];this._renderTileClippingMasks(b,w),this.renderLayer(this,_,b,w)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<i.length;this.currentLayer++){var T=this.style._layers[i[this.currentLayer]],k=a[T.source],M=(\"symbol\"===T.type?h:f)[T.source];this._renderTileClippingMasks(T,u[T.source]),this.renderLayer(this,k,T,M)}this.options.showTileBoundaries&&(t.values(this.style._layers).forEach((function(t){t.source&&!t.isHidden(n.transform.zoom)&&(t.source!==(c&&c.id)&&(c=n.style.sourceCaches[t.source]),(!l||l.getSource().maxzoom<c.getSource().maxzoom)&&(l=c))})),l&&vn.debug(this,l,l.getVisibleCoordinates())),this.options.showPadding&&function(t){var e=t.transform.padding;pn(t,t.transform.height-(e.top||0),3,ln),pn(t,e.bottom||0,3,cn),dn(t,e.left||0,3,un),dn(t,t.transform.width-(e.right||0),3,fn);var r=t.transform.centerPoint;!function(t,e,r,n){gn(t,e-1,r-10,2,20,n),gn(t,e-10,r-1,20,2,n)}(t,r.x,t.transform.height-r.y,hn)}(this),this.context.setDefault()},yn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,this.gpuTimingStart(r),vn[r.type](t,e,r,n,this.style.placement.variableOffsets),this.gpuTimingEnd())},yn.prototype.gpuTimingStart=function(t){if(this.options.gpuTiming){var e=this.context.extTimerQuery,r=this.gpuTimers[t.id];r||(r=this.gpuTimers[t.id]={calls:0,cpuTime:0,query:e.createQueryEXT()}),r.calls++,e.beginQueryEXT(e.TIME_ELAPSED_EXT,r.query)}},yn.prototype.gpuTimingEnd=function(){if(this.options.gpuTiming){var t=this.context.extTimerQuery;t.endQueryEXT(t.TIME_ELAPSED_EXT)}},yn.prototype.collectGpuTimers=function(){var t=this.gpuTimers;return this.gpuTimers={},t},yn.prototype.queryGpuTimers=function(t){var e={};for(var r in t){var n=t[r],i=this.context.extTimerQuery,a=i.getQueryObjectEXT(n.query,i.QUERY_RESULT_EXT)/1e6;i.deleteQueryEXT(n.query),e[r]=a}return e},yn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:he(r,n[0],this.transform.zoom),a?n[1]:he(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},yn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},yn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},yn.prototype.isPatternMissing=function(t){if(!t)return!1;if(!t.from||!t.to)return!0;var e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r},yn.prototype.useProgram=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new br(this.context,yr[t],e,Xr[t],this._showOverdrawInspector)),this.cache[r]},yn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},yn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)},yn.prototype.initDebugOverlayCanvas=function(){null==this.debugOverlayCanvas&&(this.debugOverlayCanvas=t.window.document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512,this.debugOverlayTexture=new t.Texture(this.context,this.debugOverlayCanvas,this.context.gl.RGBA))},yn.prototype.destroy=function(){this.emptyTexture.destroy(),this.debugOverlayTexture&&this.debugOverlayTexture.destroy()};var xn=function(t,e){this.points=t,this.planes=e};xn.fromInvProjectionMatrix=function(e,r,n){var i=Math.pow(2,n),a=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((function(r){return t.transformMat4([],r,e)})).map((function(e){return t.scale$1([],e,1/e[3]/r*i)})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((function(e){var r=t.sub([],a[e[0]],a[e[1]]),n=t.sub([],a[e[2]],a[e[1]]),i=t.normalize([],t.cross([],r,n)),o=-t.dot(i,a[e[1]]);return i.concat(o)}));return new xn(a,o)};var bn=function(e,r){this.min=e,this.max=r,this.center=t.scale$2([],t.add([],this.min,this.max),.5)};bn.prototype.quadrant=function(e){for(var r=[e%2==0,e<2],n=t.clone$2(this.min),i=t.clone$2(this.max),a=0;a<r.length;a++)n[a]=r[a]?this.min[a]:this.center[a],i[a]=r[a]?this.center[a]:this.max[a];return i[2]=this.max[2],new bn(n,i)},bn.prototype.distanceX=function(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]},bn.prototype.distanceY=function(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]},bn.prototype.intersects=function(e){for(var r=[[this.min[0],this.min[1],0,1],[this.max[0],this.min[1],0,1],[this.max[0],this.max[1],0,1],[this.min[0],this.max[1],0,1]],n=!0,i=0;i<e.planes.length;i++){for(var a=e.planes[i],o=0,s=0;s<r.length;s++)o+=t.dot$1(a,r[s])>=0;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(var l=0;l<3;l++){for(var c=Number.MAX_VALUE,u=-Number.MAX_VALUE,f=0;f<e.points.length;f++){var h=e.points[f][l]-this.min[l];c=Math.min(c,h),u=Math.max(u,h)}if(u<0||c>this.max[l]-this.min[l])return 0}return 1};var _n=function(t,e,r,n){if(void 0===t&&(t=0),void 0===e&&(e=0),void 0===r&&(r=0),void 0===n&&(n=0),isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n};_n.prototype.interpolate=function(e,r,n){return null!=r.top&&null!=e.top&&(this.top=t.number(e.top,r.top,n)),null!=r.bottom&&null!=e.bottom&&(this.bottom=t.number(e.bottom,r.bottom,n)),null!=r.left&&null!=e.left&&(this.left=t.number(e.left,r.left,n)),null!=r.right&&null!=e.right&&(this.right=t.number(e.right,r.right,n)),this},_n.prototype.getCenter=function(e,r){var n=t.clamp((this.left+e-this.right)/2,0,e),i=t.clamp((this.top+r-this.bottom)/2,0,r);return new t.Point(n,i)},_n.prototype.equals=function(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right},_n.prototype.clone=function(){return new _n(this.top,this.bottom,this.left,this.right)},_n.prototype.toJSON=function(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}};var wn=function(e,r,n,i,a){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===a||a,this._minZoom=e||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==i?60:i,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new _n,this._posMatrixCache={},this._alignedPosMatrixCache={}},Tn={minZoom:{configurable:!0},maxZoom:{configurable:!0},minPitch:{configurable:!0},maxPitch:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerOffset:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},padding:{configurable:!0},centerPoint:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};wn.prototype.clone=function(){var t=new wn(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._edgeInsets=this._edgeInsets.clone(),t._calcMatrices(),t},Tn.minZoom.get=function(){return this._minZoom},Tn.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},Tn.maxZoom.get=function(){return this._maxZoom},Tn.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},Tn.minPitch.get=function(){return this._minPitch},Tn.minPitch.set=function(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))},Tn.maxPitch.get=function(){return this._maxPitch},Tn.maxPitch.set=function(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))},Tn.renderWorldCopies.get=function(){return this._renderWorldCopies},Tn.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},Tn.worldSize.get=function(){return this.tileSize*this.scale},Tn.centerOffset.get=function(){return this.centerPoint._sub(this.size._div(2))},Tn.size.get=function(){return new t.Point(this.width,this.height)},Tn.bearing.get=function(){return-this.angle/Math.PI*180},Tn.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},Tn.pitch.get=function(){return this._pitch/Math.PI*180},Tn.pitch.set=function(e){var r=t.clamp(e,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},Tn.fov.get=function(){return this._fov/Math.PI*180},Tn.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},Tn.zoom.get=function(){return this._zoom},Tn.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},Tn.center.get=function(){return this._center},Tn.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},Tn.padding.get=function(){return this._edgeInsets.toJSON()},Tn.padding.set=function(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())},Tn.centerPoint.get=function(){return this._edgeInsets.getCenter(this.width,this.height)},wn.prototype.isPaddingEqual=function(t){return this._edgeInsets.equals(t)},wn.prototype.interpolatePadding=function(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()},wn.prototype.coveringZoomLevel=function(t){var e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)},wn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},wn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=[a*i.x,a*i.y,0],s=xn.fromInvProjectionMatrix(this.invProjMatrix,this.worldSize,r),l=e.minzoom||0;this.pitch<=60&&this._edgeInsets.top<.1&&(l=r);var c=function(t){return{aabb:new bn([t*a,0,0],[(t+1)*a,a,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}},u=[],f=[],h=r,p=e.reparseOverscaled?n:r;if(this._renderWorldCopies)for(var d=1;d<=3;d++)u.push(c(-d)),u.push(c(d));for(u.push(c(0));u.length>0;){var g=u.pop(),m=g.x,v=g.y,y=g.fullyVisible;if(!y){var x=g.aabb.intersects(s);if(0===x)continue;y=2===x}var b=g.aabb.distanceX(o),_=g.aabb.distanceY(o),w=Math.max(Math.abs(b),Math.abs(_));if(g.zoom===h||w>3+(1<<h-g.zoom)-2&&g.zoom>=l)f.push({tileID:new t.OverscaledTileID(g.zoom===h?p:g.zoom,g.wrap,g.zoom,m,v),distanceSq:t.sqrLen([o[0]-.5-m,o[1]-.5-v])});else for(var T=0;T<4;T++){var k=(m<<1)+T%2,M=(v<<1)+(T>>1);u.push({aabb:g.aabb.quadrant(T),zoom:g.zoom+1,x:k,y:M,wrap:g.wrap,fullyVisible:y})}}return f.sort((function(t,e){return t.distanceSq-e.distanceSq})).map((function(t){return t.tileID}))},wn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},Tn.unmodified.get=function(){return this._unmodified},wn.prototype.zoomScale=function(t){return Math.pow(2,t)},wn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},wn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},wn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},Tn.point.get=function(){return this.project(this.center)},wn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},wn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},wn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},wn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},wn.prototype.coordinateLocation=function(t){return t.toLngLat()},wn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[1]/i,s=n[1]/a,l=r[2]/i,c=n[2]/a,u=l===c?0:(0-l)/(c-l);return new t.MercatorCoordinate(t.number(r[0]/i,n[0]/a,u)/this.worldSize,t.number(o,s,u)/this.worldSize)},wn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},wn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},wn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},wn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},wn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},wn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},wn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var f=this.latRange;a=t.mercatorYfromLat(f[1])*this.worldSize,e=(o=t.mercatorYfromLat(f[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var h=this.lngRange;s=t.mercatorXfromLng(h[0])*this.worldSize,r=(l=t.mercatorXfromLng(h[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,m=c.y/2;g-m<a&&(i=a+m),g+m>o&&(i=o-m)}if(this.lngRange){var v=p.x,y=c.x/2;v-y<s&&(n=s+y),v+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},wn.prototype._calcMatrices=function(){if(this.height){var e=this.centerOffset;this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var r=Math.PI/2+this._pitch,n=this._fov*(.5+e.y/this.height),i=Math.sin(n)*this.cameraToCenterDistance/Math.sin(t.clamp(Math.PI-r-n,.01,Math.PI-.01)),a=this.point,o=a.x,s=a.y,l=1.01*(Math.cos(Math.PI/2-this._pitch)*i+this.cameraToCenterDistance),c=this.height/50,u=new Float64Array(16);t.perspective(u,this._fov,this.width/this.height,c,l),u[8]=2*-e.x/this.width,u[9]=2*e.y/this.height,t.scale(u,u,[1,-1,1]),t.translate(u,u,[0,0,-this.cameraToCenterDistance]),t.rotateX(u,u,this._pitch),t.rotateZ(u,u,this.angle),t.translate(u,u,[-o,-s,0]),this.mercatorMatrix=t.scale([],u,[this.worldSize,this.worldSize,this.worldSize]),t.scale(u,u,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=u,this.invProjMatrix=t.invert([],this.projMatrix);var f=this.width%2/2,h=this.height%2/2,p=Math.cos(this.angle),d=Math.sin(this.angle),g=o-Math.round(o)+p*f+d*h,m=s-Math.round(s)+p*h+d*f,v=new Float64Array(u);if(t.translate(v,v,[g>.5?g-1:g,m>.5?m-1:m,0]),this.alignedProjMatrix=v,u=t.create(),t.scale(u,u,[this.width/2,-this.height/2,1]),t.translate(u,u,[1,-1,0]),this.labelPlaneMatrix=u,u=t.create(),t.scale(u,u,[1,-1,1]),t.translate(u,u,[-1,-1,0]),t.scale(u,u,[2/this.width,2/this.height,1]),this.glCoordMatrix=u,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(u=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=u,this._posMatrixCache={},this._alignedPosMatrixCache={}}},wn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},wn.prototype.getCameraPoint=function(){var e=Math.tan(this._pitch)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,e))},wn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(wn.prototype,Tn);var kn=function(e){var r,n,i,a;this._hashName=e&&encodeURIComponent(e),t.bindAll([\"_getCurrentHash\",\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(r=this._updateHashUnthrottled.bind(this),n=!1,i=null,a=function(){i=null,n&&(r(),i=setTimeout(a,300),n=!1)},function(){return n=!0,i||a(),i})};kn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},kn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},kn.prototype.getHashString=function(e){var r=this._map.getCenter(),n=Math.round(100*this._map.getZoom())/100,i=Math.ceil((n*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,i),o=Math.round(r.lng*a)/a,s=Math.round(r.lat*a)/a,l=this._map.getBearing(),c=this._map.getPitch(),u=\"\";if(u+=e?\"/\"+o+\"/\"+s+\"/\"+n:n+\"/\"+s+\"/\"+o,(l||c)&&(u+=\"/\"+Math.round(10*l)/10),c&&(u+=\"/\"+Math.round(c)),this._hashName){var f=this._hashName,h=!1,p=t.window.location.hash.slice(1).split(\"&\").map((function(t){var e=t.split(\"=\")[0];return e===f?(h=!0,e+\"=\"+u):t})).filter((function(t){return t}));return h||p.push(f+\"=\"+u),\"#\"+p.join(\"&\")}return\"#\"+u},kn.prototype._getCurrentHash=function(){var e,r=this,n=t.window.location.hash.replace(\"#\",\"\");return this._hashName?(n.split(\"&\").map((function(t){return t.split(\"=\")})).forEach((function(t){t[0]===r._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")):n.split(\"/\")},kn.prototype._onHashChange=function(){var t=this._getCurrentHash();if(t.length>=3&&!t.some((function(t){return isNaN(t)}))){var e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},kn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var Mn={linearity:.3,easing:t.bezier(0,0,.3,1)},An=t.extend({deceleration:2500,maxSpeed:1400},Mn),Sn=t.extend({deceleration:20,maxSpeed:1400},Mn),En=t.extend({deceleration:1e3,maxSpeed:360},Mn),Cn=t.extend({deceleration:1e3,maxSpeed:90},Mn),Ln=function(t){this._map=t,this.clear()};function In(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function Pn(e,r,n){var i=n.maxSpeed,a=n.linearity,o=n.deceleration,s=t.clamp(e*a/(r/1e3),-i,i),l=Math.abs(s)/(o*a);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}Ln.prototype.clear=function(){this._inertiaBuffer=[]},Ln.prototype.record=function(e){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:t.browser.now(),settings:e})},Ln.prototype._drainInertiaBuffer=function(){for(var e=this._inertiaBuffer,r=t.browser.now();e.length>0&&r-e[0].time>160;)e.shift()},Ln.prototype._onMoveEnd=function(e){if(this._drainInertiaBuffer(),!(this._inertiaBuffer.length<2)){for(var r={zoom:0,bearing:0,pitch:0,pan:new t.Point(0,0),pinchAround:void 0,around:void 0},n=0,i=this._inertiaBuffer;n<i.length;n+=1){var a=i[n].settings;r.zoom+=a.zoomDelta||0,r.bearing+=a.bearingDelta||0,r.pitch+=a.pitchDelta||0,a.panDelta&&r.pan._add(a.panDelta),a.around&&(r.around=a.around),a.pinchAround&&(r.pinchAround=a.pinchAround)}var o=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,s={};if(r.pan.mag()){var l=Pn(r.pan.mag(),o,t.extend({},An,e||{}));s.offset=r.pan.mult(l.amount/r.pan.mag()),s.center=this._map.transform.center,In(s,l)}if(r.zoom){var c=Pn(r.zoom,o,Sn);s.zoom=this._map.transform.zoom+c.amount,In(s,c)}if(r.bearing){var u=Pn(r.bearing,o,En);s.bearing=this._map.transform.bearing+t.clamp(u.amount,-179,179),In(s,u)}if(r.pitch){var f=Pn(r.pitch,o,Cn);s.pitch=this._map.transform.pitch+f.amount,In(s,f)}if(s.zoom||s.bearing){var h=void 0===r.pinchAround?r.around:r.pinchAround;s.around=h?this._map.unproject(h):this._map.getCenter()}return this.clear(),t.extend(s,{noMoveStart:!0})}};var zn=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),On=function(e){function n(n,i,a){var o=\"touchend\"===n?a.changedTouches:a.touches,s=r.touchPos(i.getCanvasContainer(),o),l=s.map((function(t){return i.unproject(t)})),c=s.reduce((function(t,e,r,n){return t.add(e.div(n.length))}),new t.Point(0,0)),u=i.unproject(c);e.call(this,n,{points:s,point:c,lngLats:l,lngLat:u,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),Dn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Rn=function(t,e){this._map=t,this._clickTolerance=e.clickTolerance};Rn.prototype.reset=function(){delete this._mousedownPos},Rn.prototype.wheel=function(t){return this._firePreventable(new Dn(t.type,this._map,t))},Rn.prototype.mousedown=function(t,e){return this._mousedownPos=e,this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseup=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.click=function(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.dblclick=function(t){return this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseover=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.mouseout=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.touchstart=function(t){return this._firePreventable(new On(t.type,this._map,t))},Rn.prototype.touchmove=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchend=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchcancel=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype._firePreventable=function(t){if(this._map.fire(t),t.defaultPrevented)return{}},Rn.prototype.isEnabled=function(){return!0},Rn.prototype.isActive=function(){return!1},Rn.prototype.enable=function(){},Rn.prototype.disable=function(){};var Fn=function(t){this._map=t};Fn.prototype.reset=function(){this._delayContextMenu=!1,delete this._contextMenuEvent},Fn.prototype.mousemove=function(t){this._map.fire(new zn(t.type,this._map,t))},Fn.prototype.mousedown=function(){this._delayContextMenu=!0},Fn.prototype.mouseup=function(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new zn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)},Fn.prototype.contextmenu=function(t){this._delayContextMenu?this._contextMenuEvent=t:this._map.fire(new zn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()},Fn.prototype.isEnabled=function(){return!0},Fn.prototype.isActive=function(){return!1},Fn.prototype.enable=function(){},Fn.prototype.disable=function(){};var Bn=function(t,e){this._map=t,this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1};function Nn(t,e){for(var r={},n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}Bn.prototype.isEnabled=function(){return!!this._enabled},Bn.prototype.isActive=function(){return!!this._active},Bn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Bn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Bn.prototype.mousedown=function(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(r.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)},Bn.prototype.mousemoveWindow=function(t,e){if(this._active){var n=e;if(!(this._lastPos.equals(n)||!this._box&&n.dist(this._startPos)<this._clickTolerance)){var i=this._startPos;this._lastPos=n,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var a=Math.min(i.x,n.x),o=Math.max(i.x,n.x),s=Math.min(i.y,n.y),l=Math.max(i.y,n.y);r.setTransform(this._box,\"translate(\"+a+\"px,\"+s+\"px)\"),this._box.style.width=o-a+\"px\",this._box.style.height=l-s+\"px\"}}},Bn.prototype.mouseupWindow=function(e,n){var i=this;if(this._active&&0===e.button){var a=this._startPos,o=n;if(this.reset(),r.suppressClick(),a.x!==o.x||a.y!==o.y)return this._map.fire(new t.Event(\"boxzoomend\",{originalEvent:e})),{cameraAnimation:function(t){return t.fitScreenCoordinates(a,o,i._map.getBearing(),{linear:!0})}};this._fireEvent(\"boxzoomcancel\",e)}},Bn.prototype.keydown=function(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))},Bn.prototype.reset=function(){this._active=!1,this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},Bn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var jn=function(t){this.reset(),this.numTouches=t.numTouches};jn.prototype.reset=function(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1},jn.prototype.touchstart=function(e,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=e.timeStamp),n.length===this.numTouches&&(this.centroid=function(e){for(var r=new t.Point(0,0),n=0,i=e;n<i.length;n+=1)r._add(i[n]);return r.div(e.length)}(r),this.touches=Nn(n,r)))},jn.prototype.touchmove=function(t,e,r){if(!this.aborted&&this.centroid){var n=Nn(r,e);for(var i in this.touches){var a=n[i];(!a||a.dist(this.touches[i])>30)&&(this.aborted=!0)}}},jn.prototype.touchend=function(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){var n=!this.aborted&&this.centroid;if(this.reset(),n)return n}};var Un=function(t){this.singleTap=new jn(t),this.numTaps=t.numTaps,this.reset()};Un.prototype.reset=function(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()},Un.prototype.touchstart=function(t,e,r){this.singleTap.touchstart(t,e,r)},Un.prototype.touchmove=function(t,e,r){this.singleTap.touchmove(t,e,r)},Un.prototype.touchend=function(t,e,r){var n=this.singleTap.touchend(t,e,r);if(n){var i=t.timeStamp-this.lastTime<500,a=!this.lastTap||this.lastTap.dist(n)<30;if(i&&a||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}};var Vn=function(){this._zoomIn=new Un({numTouches:1,numTaps:2}),this._zoomOut=new Un({numTouches:2,numTaps:1}),this.reset()};Vn.prototype.reset=function(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()},Vn.prototype.touchstart=function(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)},Vn.prototype.touchmove=function(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)},Vn.prototype.touchend=function(t,e,r){var n=this,i=this._zoomIn.touchend(t,e,r),a=this._zoomOut.touchend(t,e,r);return i?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()+1,around:e.unproject(i)},{originalEvent:t})}}):a?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()-1,around:e.unproject(a)},{originalEvent:t})}}):void 0},Vn.prototype.touchcancel=function(){this.reset()},Vn.prototype.enable=function(){this._enabled=!0},Vn.prototype.disable=function(){this._enabled=!1,this.reset()},Vn.prototype.isEnabled=function(){return this._enabled},Vn.prototype.isActive=function(){return this._active};var qn=function(t){this.reset(),this._clickTolerance=t.clickTolerance||1};qn.prototype.reset=function(){this._active=!1,this._moved=!1,delete this._lastPoint,delete this._eventButton},qn.prototype._correctButton=function(t,e){return!1},qn.prototype._move=function(t,e){return{}},qn.prototype.mousedown=function(t,e){if(!this._lastPoint){var n=r.mouseButton(t);this._correctButton(t,n)&&(this._lastPoint=e,this._eventButton=n)}},qn.prototype.mousemoveWindow=function(t,e){var r=this._lastPoint;if(r&&(t.preventDefault(),this._moved||!(e.dist(r)<this._clickTolerance)))return this._moved=!0,this._lastPoint=e,this._move(r,e)},qn.prototype.mouseupWindow=function(t){r.mouseButton(t)===this._eventButton&&(this._moved&&r.suppressClick(),this.reset())},qn.prototype.enable=function(){this._enabled=!0},qn.prototype.disable=function(){this._enabled=!1,this.reset()},qn.prototype.isEnabled=function(){return this._enabled},qn.prototype.isActive=function(){return this._active};var Hn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.mousedown=function(e,r){t.prototype.mousedown.call(this,e,r),this._lastPoint&&(this._active=!0)},e.prototype._correctButton=function(t,e){return 0===e&&!t.ctrlKey},e.prototype._move=function(t,e){return{around:e,panDelta:e.sub(t)}},e}(qn),Gn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=.8*(e.x-t.x);if(r)return this._active=!0,{bearingDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Yn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=-.5*(e.y-t.y);if(r)return this._active=!0,{pitchDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Wn=function(t){this._minTouches=1,this._clickTolerance=t.clickTolerance||1,this.reset()};Wn.prototype.reset=function(){this._active=!1,this._touches={},this._sum=new t.Point(0,0)},Wn.prototype.touchstart=function(t,e,r){return this._calculateTransform(t,e,r)},Wn.prototype.touchmove=function(t,e,r){if(this._active)return t.preventDefault(),this._calculateTransform(t,e,r)},Wn.prototype.touchend=function(t,e,r){this._calculateTransform(t,e,r),this._active&&r.length<this._minTouches&&this.reset()},Wn.prototype.touchcancel=function(){this.reset()},Wn.prototype._calculateTransform=function(e,r,n){n.length>0&&(this._active=!0);var i=Nn(n,r),a=new t.Point(0,0),o=new t.Point(0,0),s=0;for(var l in i){var c=i[l],u=this._touches[l];u&&(a._add(c),o._add(c.sub(u)),s++,i[l]=c)}if(this._touches=i,!(s<this._minTouches)&&o.mag()){var f=o.div(s);if(this._sum._add(f),!(this._sum.mag()<this._clickTolerance))return{around:a.div(s),panDelta:f}}},Wn.prototype.enable=function(){this._enabled=!0},Wn.prototype.disable=function(){this._enabled=!1,this.reset()},Wn.prototype.isEnabled=function(){return this._enabled},Wn.prototype.isActive=function(){return this._active};var Xn=function(){this.reset()};function Zn(t,e,r){for(var n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}function Jn(t,e){return Math.log(t/e)/Math.LN2}Xn.prototype.reset=function(){this._active=!1,delete this._firstTwoTouches},Xn.prototype._start=function(t){},Xn.prototype._move=function(t,e,r){return{}},Xn.prototype.touchstart=function(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))},Xn.prototype.touchmove=function(t,e,r){if(this._firstTwoTouches){t.preventDefault();var n=this._firstTwoTouches,i=n[1],a=Zn(r,e,n[0]),o=Zn(r,e,i);if(a&&o){var s=this._aroundCenter?null:a.add(o).div(2);return this._move([a,o],s,t)}}},Xn.prototype.touchend=function(t,e,n){if(this._firstTwoTouches){var i=this._firstTwoTouches,a=i[1],o=Zn(n,e,i[0]),s=Zn(n,e,a);o&&s||(this._active&&r.suppressClick(),this.reset())}},Xn.prototype.touchcancel=function(){this.reset()},Xn.prototype.enable=function(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around},Xn.prototype.disable=function(){this._enabled=!1,this.reset()},Xn.prototype.isEnabled=function(){return this._enabled},Xn.prototype.isActive=function(){return this._active};var Kn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._distance,delete this._startDistance},e.prototype._start=function(t){this._startDistance=this._distance=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs(Jn(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:Jn(this._distance,r),pinchAround:e}},e}(Xn);function Qn(t,e){return 180*t.angleWith(e)/Math.PI}var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._minDiameter,delete this._startVector,delete this._vector},e.prototype._start=function(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:Qn(this._vector,r),pinchAround:e}},e.prototype._isBelowThreshold=function(t){this._minDiameter=Math.min(this._minDiameter,t.mag());var e=25/(Math.PI*this._minDiameter)*360,r=Qn(t,this._startVector);return Math.abs(r)<e},e}(Xn);function ti(t){return Math.abs(t.y)>Math.abs(t.x)}var ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),this._valid=void 0,delete this._firstMove,delete this._lastPoints},e.prototype._start=function(t){this._lastPoints=t,ti(t[0].sub(t[1]))&&(this._valid=!1)},e.prototype._move=function(t,e,r){var n=t[0].sub(this._lastPoints[0]),i=t[1].sub(this._lastPoints[1]);if(this._valid=this.gestureBeginsVertically(n,i,r.timeStamp),this._valid)return this._lastPoints=t,this._active=!0,{pitchDelta:(n.y+i.y)/2*-.5}},e.prototype.gestureBeginsVertically=function(t,e,r){if(void 0!==this._valid)return this._valid;var n=t.mag()>=2,i=e.mag()>=2;if(n||i){if(!n||!i)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;var a=t.y>0==e.y>0;return ti(t)&&ti(e)&&a}},e}(Xn),ri={panStep:100,bearingStep:15,pitchStep:10},ni=function(){var t=ri;this._panStep=t.panStep,this._bearingStep=t.bearingStep,this._pitchStep=t.pitchStep};function ii(t){return t*(2-t)}ni.prototype.reset=function(){this._active=!1},ni.prototype.keydown=function(t){var e=this;if(!(t.altKey||t.ctrlKey||t.metaKey)){var r=0,n=0,i=0,a=0,o=0;switch(t.keyCode){case 61:case 107:case 171:case 187:r=1;break;case 189:case 109:case 173:r=-1;break;case 37:t.shiftKey?n=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?n=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?i=1:(t.preventDefault(),o=-1);break;case 40:t.shiftKey?i=-1:(t.preventDefault(),o=1);break;default:return}return{cameraAnimation:function(s){var l=s.getZoom();s.easeTo({duration:300,easeId:\"keyboardHandler\",easing:ii,zoom:r?Math.round(l)+r*(t.shiftKey?2:1):l,bearing:s.getBearing()+n*e._bearingStep,pitch:s.getPitch()+i*e._pitchStep,offset:[-a*e._panStep,-o*e._panStep],center:s.getCenter()},{originalEvent:t})}}}},ni.prototype.enable=function(){this._enabled=!0},ni.prototype.disable=function(){this._enabled=!1,this.reset()},ni.prototype.isEnabled=function(){return this._enabled},ni.prototype.isActive=function(){return this._active};var ai=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._handler=r,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};ai.prototype.setZoomRate=function(t){this._defaultZoomRate=t},ai.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},ai.prototype.isEnabled=function(){return!!this._enabled},ai.prototype.isActive=function(){return!!this._active||void 0!==this._finishTimeout},ai.prototype.isZooming=function(){return!!this._zooming},ai.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},ai.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},ai.prototype.wheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this._active||this._start(e)),e.preventDefault()}},ai.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},ai.prototype._start=function(e){if(this._delta){this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._handler._triggerRenderFrame())}},ai.prototype.renderFrame=function(){return this._onScrollFrame()},ai.prototype._onScrollFrame=function(){var e=this;if(this._frameId&&(this._frameId=null,this.isActive())){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o,s=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,l=this._startZoom,c=this._easing,u=!1;if(\"wheel\"===this._type&&l&&c){var f=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=c(f);o=t.number(l,s,h),f<1?this._frameId||(this._frameId=!0):u=!0}else o=s,u=!0;return this._active=!0,u&&(this._active=!1,this._finishTimeout=setTimeout((function(){e._zooming=!1,e._handler._triggerRenderFrame(),delete e._targetZoom,delete e._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!u,zoomDelta:o-r.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}},ai.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r},ai.prototype.reset=function(){this._active=!1};var oi=function(t,e){this._clickZoom=t,this._tapZoom=e};oi.prototype.enable=function(){this._clickZoom.enable(),this._tapZoom.enable()},oi.prototype.disable=function(){this._clickZoom.disable(),this._tapZoom.disable()},oi.prototype.isEnabled=function(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()},oi.prototype.isActive=function(){return this._clickZoom.isActive()||this._tapZoom.isActive()};var si=function(){this.reset()};si.prototype.reset=function(){this._active=!1},si.prototype.dblclick=function(t,e){return t.preventDefault(),{cameraAnimation:function(r){r.easeTo({duration:300,zoom:r.getZoom()+(t.shiftKey?-1:1),around:r.unproject(e)},{originalEvent:t})}}},si.prototype.enable=function(){this._enabled=!0},si.prototype.disable=function(){this._enabled=!1,this.reset()},si.prototype.isEnabled=function(){return this._enabled},si.prototype.isActive=function(){return this._active};var li=function(){this._tap=new Un({numTouches:1,numTaps:1}),this.reset()};li.prototype.reset=function(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,this._tap.reset()},li.prototype.touchstart=function(t,e,r){this._swipePoint||(this._tapTime&&t.timeStamp-this._tapTime>500&&this.reset(),this._tapTime?r.length>0&&(this._swipePoint=e[0],this._swipeTouch=r[0].identifier):this._tap.touchstart(t,e,r))},li.prototype.touchmove=function(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;var n=e[0],i=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:i/128}}}else this._tap.touchmove(t,e,r)},li.prototype.touchend=function(t,e,r){this._tapTime?this._swipePoint&&0===r.length&&this.reset():this._tap.touchend(t,e,r)&&(this._tapTime=t.timeStamp)},li.prototype.touchcancel=function(){this.reset()},li.prototype.enable=function(){this._enabled=!0},li.prototype.disable=function(){this._enabled=!1,this.reset()},li.prototype.isEnabled=function(){return this._enabled},li.prototype.isActive=function(){return this._active};var ci=function(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r};ci.prototype.enable=function(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"mapboxgl-touch-drag-pan\")},ci.prototype.disable=function(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"mapboxgl-touch-drag-pan\")},ci.prototype.isEnabled=function(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()},ci.prototype.isActive=function(){return this._mousePan.isActive()||this._touchPan.isActive()};var ui=function(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r};ui.prototype.enable=function(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()},ui.prototype.disable=function(){this._mouseRotate.disable(),this._mousePitch.disable()},ui.prototype.isEnabled=function(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())},ui.prototype.isActive=function(){return this._mouseRotate.isActive()||this._mousePitch.isActive()};var fi=function(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0};fi.prototype.enable=function(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.disable=function(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.isEnabled=function(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()},fi.prototype.isActive=function(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()},fi.prototype.disableRotation=function(){this._rotationDisabled=!0,this._touchRotate.disable()},fi.prototype.enableRotation=function(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()};var hi=function(t){return t.zoom||t.drag||t.pitch||t.rotate},pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(t.Event);function di(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}var gi=function(e,n){this._map=e,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new Ln(e),this._bearingSnap=n.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(n),t.bindAll([\"handleEvent\",\"handleWindowEvent\"],this);var i=this._el;this._listeners=[[i,\"touchstart\",{passive:!1}],[i,\"touchmove\",{passive:!1}],[i,\"touchend\",void 0],[i,\"touchcancel\",void 0],[i,\"mousedown\",void 0],[i,\"mousemove\",void 0],[i,\"mouseup\",void 0],[t.window.document,\"mousemove\",{capture:!0}],[t.window.document,\"mouseup\",void 0],[i,\"mouseover\",void 0],[i,\"mouseout\",void 0],[i,\"dblclick\",void 0],[i,\"click\",void 0],[i,\"keydown\",{capture:!1}],[i,\"keyup\",void 0],[i,\"wheel\",{passive:!1}],[i,\"contextmenu\",void 0],[t.window,\"blur\",void 0]];for(var a=0,o=this._listeners;a<o.length;a+=1){var s=o[a],l=s[0];r.addEventListener(l,s[1],l===t.window.document?this.handleWindowEvent:this.handleEvent,s[2])}};gi.prototype.destroy=function(){for(var e=0,n=this._listeners;e<n.length;e+=1){var i=n[e],a=i[0];r.removeEventListener(a,i[1],a===t.window.document?this.handleWindowEvent:this.handleEvent,i[2])}},gi.prototype._addDefaultHandlers=function(t){var e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Rn(e,t));var n=e.boxZoom=new Bn(e,t);this._add(\"boxZoom\",n);var i=new Vn,a=new si;e.doubleClickZoom=new oi(a,i),this._add(\"tapZoom\",i),this._add(\"clickZoom\",a);var o=new li;this._add(\"tapDragZoom\",o);var s=e.touchPitch=new ei;this._add(\"touchPitch\",s);var l=new Gn(t),c=new Yn(t);e.dragRotate=new ui(t,l,c),this._add(\"mouseRotate\",l,[\"mousePitch\"]),this._add(\"mousePitch\",c,[\"mouseRotate\"]);var u=new Hn(t),f=new Wn(t);e.dragPan=new ci(r,u,f),this._add(\"mousePan\",u),this._add(\"touchPan\",f,[\"touchZoom\",\"touchRotate\"]);var h=new $n,p=new Kn;e.touchZoomRotate=new fi(r,p,h,o),this._add(\"touchRotate\",h,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",p,[\"touchPan\",\"touchRotate\"]);var d=e.scrollZoom=new ai(e,this);this._add(\"scrollZoom\",d,[\"mousePan\"]);var g=e.keyboard=new ni;this._add(\"keyboard\",g),this._add(\"blockableMapEvent\",new Fn(e));for(var m=0,v=[\"boxZoom\",\"doubleClickZoom\",\"tapDragZoom\",\"touchPitch\",\"dragRotate\",\"dragPan\",\"touchZoomRotate\",\"scrollZoom\",\"keyboard\"];m<v.length;m+=1){var y=v[m];t.interactive&&t[y]&&e[y].enable(t[y])}},gi.prototype._add=function(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e},gi.prototype.stop=function(){if(!this._updatingCamera){for(var t=0,e=this._handlers;t<e.length;t+=1)e[t].handler.reset();this._inertia.clear(),this._fireEvents({},{}),this._changes=[]}},gi.prototype.isActive=function(){for(var t=0,e=this._handlers;t<e.length;t+=1)if(e[t].handler.isActive())return!0;return!1},gi.prototype.isZooming=function(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()},gi.prototype.isRotating=function(){return!!this._eventsInProgress.rotate},gi.prototype.isMoving=function(){return Boolean(hi(this._eventsInProgress))||this.isZooming()},gi.prototype._blockedByActive=function(t,e,r){for(var n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1},gi.prototype.handleWindowEvent=function(t){this.handleEvent(t,t.type+\"Window\")},gi.prototype._getMapTouches=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r];this._el.contains(i.target)&&e.push(i)}return e},gi.prototype.handleEvent=function(t,e){if(\"blur\"!==t.type){this._updatingCamera=!0;for(var n=\"renderFrame\"===t.type?void 0:t,i={needsRenderFrame:!1},a={},o={},s=t.touches?this._getMapTouches(t.touches):void 0,l=s?r.touchPos(this._el,s):r.mousePos(this._el,t),c=0,u=this._handlers;c<u.length;c+=1){var f=u[c],h=f.handlerName,p=f.handler,d=f.allowed;if(p.isEnabled()){var g=void 0;this._blockedByActive(o,d,h)?p.reset():p[e||t.type]&&(g=p[e||t.type](t,l,s),this.mergeHandlerResult(i,a,g,h,n),g&&g.needsRenderFrame&&this._triggerRenderFrame()),(g||p.isActive())&&(o[h]=p)}}var m={};for(var v in this._previousActiveHandlers)o[v]||(m[v]=n);this._previousActiveHandlers=o,(Object.keys(m).length||di(i))&&(this._changes.push([i,a,m]),this._triggerRenderFrame()),(Object.keys(o).length||di(i))&&this._map._stop(!0),this._updatingCamera=!1;var y=i.cameraAnimation;y&&(this._inertia.clear(),this._fireEvents({},{}),this._changes=[],y(this._map))}else this.stop()},gi.prototype.mergeHandlerResult=function(e,r,n,i,a){if(n){t.extend(e,n);var o={handlerName:i,originalEvent:n.originalEvent||a};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}},gi.prototype._applyChanges=function(){for(var e={},r={},n={},i=0,a=this._changes;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=o[2];s.panDelta&&(e.panDelta=(e.panDelta||new t.Point(0,0))._add(s.panDelta)),s.zoomDelta&&(e.zoomDelta=(e.zoomDelta||0)+s.zoomDelta),s.bearingDelta&&(e.bearingDelta=(e.bearingDelta||0)+s.bearingDelta),s.pitchDelta&&(e.pitchDelta=(e.pitchDelta||0)+s.pitchDelta),void 0!==s.around&&(e.around=s.around),void 0!==s.pinchAround&&(e.pinchAround=s.pinchAround),s.noInertia&&(e.noInertia=s.noInertia),t.extend(r,l),t.extend(n,c)}this._updateMapTransform(e,r,n),this._changes=[]},gi.prototype._updateMapTransform=function(t,e,r){var n=this._map,i=n.transform;if(!di(t))return this._fireEvents(e,r);var a=t.panDelta,o=t.zoomDelta,s=t.bearingDelta,l=t.pitchDelta,c=t.around,u=t.pinchAround;void 0!==u&&(c=u),n._stop(!0),c=c||n.transform.centerPoint;var f=i.pointLocation(a?c.sub(a):c);s&&(i.bearing+=s),l&&(i.pitch+=l),o&&(i.zoom+=o),i.setLocationAtPoint(f,c),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r)},gi.prototype._fireEvents=function(e,r){var n=this,i=hi(this._eventsInProgress),a=hi(e),o={};for(var s in e)this._eventsInProgress[s]||(o[s+\"start\"]=e[s].originalEvent),this._eventsInProgress[s]=e[s];for(var l in!i&&a&&this._fireEvent(\"movestart\",a.originalEvent),o)this._fireEvent(l,o[l]);for(var c in e.rotate&&(this._bearingChanged=!0),a&&this._fireEvent(\"move\",a.originalEvent),e)this._fireEvent(c,e[c].originalEvent);var u,f={};for(var h in this._eventsInProgress){var p=this._eventsInProgress[h],d=p.handlerName,g=p.originalEvent;this._handlersById[d].isActive()||(delete this._eventsInProgress[h],f[h+\"end\"]=u=r[d]||g)}for(var m in f)this._fireEvent(m,f[m]);var v=hi(this._eventsInProgress);if((i||a)&&!v){this._updatingCamera=!0;var y=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),x=function(t){return 0!==t&&-n._bearingSnap<t&&t<n._bearingSnap};y?(x(y.bearing||this._map.getBearing())&&(y.bearing=0),this._map.easeTo(y,{originalEvent:u})):(this._map.fire(new t.Event(\"moveend\",{originalEvent:u})),x(this._map.getBearing())&&this._map.resetNorth()),this._bearingChanged=!1,this._updatingCamera=!1}},gi.prototype._fireEvent=function(e,r){this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},gi.prototype._triggerRenderFrame=function(){var t=this;void 0===this._frameId&&(this._frameId=this._map._requestRenderFrame((function(e){delete t._frameId,t.handleEvent(new pi(\"renderFrame\",{timeStamp:e})),t._applyChanges()})))};var mi=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.getPadding=function(){return this.transform.padding},r.prototype.setPadding=function(t,e){return this.jumpTo({padding:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){var a={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(i=t.extend({padding:a,offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var o=i.padding;i.padding={top:o,bottom:o,right:o,left:o}}i.padding=t.extend(a,i.padding);var s=this.transform,l=s.padding,c=s.project(t.LngLat.convert(e)),u=s.project(t.LngLat.convert(r)),f=c.rotate(-n*Math.PI/180),h=u.rotate(-n*Math.PI/180),p=new t.Point(Math.max(f.x,h.x),Math.max(f.y,h.y)),d=new t.Point(Math.min(f.x,h.x),Math.min(f.y,h.y)),g=p.sub(d),m=(s.width-(l.left+l.right+i.padding.left+i.padding.right))/g.x,v=(s.height-(l.top+l.bottom+i.padding.top+i.padding.bottom))/g.y;if(!(v<0||m<0)){var y=Math.min(s.scaleZoom(s.scale*Math.min(m,v)),i.maxZoom),x=t.Point.convert(i.offset),b=new t.Point(x.x+(i.padding.left-i.padding.right)/2,x.y+(i.padding.top-i.padding.bottom)/2).mult(s.scale/s.zoomScale(y));return{center:s.unproject(c.add(u).div(2).sub(b)),zoom:y,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(delete(r=t.extend(e,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),null==e.padding||n.isPaddingEqual(e.padding)||(n.padding=e.padding),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this._stop(!1,e.easeId),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||!e.essential&&t.browser.prefersReducedMotion)&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=this.getPadding(),c=\"zoom\"in e?+e.zoom:a,u=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,f=\"pitch\"in e?+e.pitch:s,h=\"padding\"in e?e.padding:i.padding,p=t.Point.convert(e.offset),d=i.centerPoint.add(p),g=i.pointLocation(d),m=t.LngLat.convert(e.center||g);this._normalizeCenter(m);var v,y,x=i.project(g),b=i.project(m).sub(x),_=i.zoomScale(c-a);e.around&&(v=t.LngLat.convert(e.around),y=i.locationPoint(v));var w={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||c!==a,this._rotating=this._rotating||o!==u,this._pitching=this._pitching||f!==s,this._padding=!i.isPaddingEqual(h),this._easeId=e.easeId,this._prepareEase(r,e.noMoveStart,w),clearTimeout(this._easeEndTimeoutID),this._ease((function(e){if(n._zooming&&(i.zoom=t.number(a,c,e)),n._rotating&&(i.bearing=t.number(o,u,e)),n._pitching&&(i.pitch=t.number(s,f,e)),n._padding&&(i.interpolatePadding(l,h,e),d=i.centerPoint.add(p)),v)i.setLocationAtPoint(v,y);else{var g=i.zoomScale(i.zoom-a),m=c>a?Math.min(2,_):Math.max(.5,_),w=Math.pow(m,1-e),T=i.unproject(x.add(b.mult(e*w)).mult(g));i.setLocationAtPoint(i.renderWorldCopies?T.wrap():T,d)}n._fireMoveEvents(r)}),(function(t){n._afterEase(r,t)}),e),this},r.prototype._prepareEase=function(e,r,n){void 0===n&&(n={}),this._moving=!0,r||n.moving||this.fire(new t.Event(\"movestart\",e)),this._zooming&&!n.zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&!n.rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&!n.pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e,r){if(!this._easeId||!r||this._easeId!==r){delete this._easeId;var n=this._zooming,i=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new t.Event(\"zoomend\",e)),i&&this.fire(new t.Event(\"rotateend\",e)),a&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))}},r.prototype.flyTo=function(e,r){var n=this;if(!e.essential&&t.browser.prefersReducedMotion){var i=t.pick(e,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(i,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var a=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c=this.getPadding(),u=\"zoom\"in e?t.clamp(+e.zoom,a.minZoom,a.maxZoom):o,f=\"bearing\"in e?this._normalizeBearing(e.bearing,s):s,h=\"pitch\"in e?+e.pitch:l,p=\"padding\"in e?e.padding:a.padding,d=a.zoomScale(u-o),g=t.Point.convert(e.offset),m=a.centerPoint.add(g),v=a.pointLocation(m),y=t.LngLat.convert(e.center||v);this._normalizeCenter(y);var x=a.project(v),b=a.project(y).sub(x),_=e.curve,w=Math.max(a.width,a.height),T=w/d,k=b.mag();if(\"minZoom\"in e){var M=t.clamp(Math.min(e.minZoom,o,u),a.minZoom,a.maxZoom),A=w/a.zoomScale(M-o);_=Math.sqrt(A/k*2)}var S=_*_;function E(t){var e=(T*T-w*w+(t?-1:1)*S*S*k*k)/(2*(t?T:w)*S*k);return Math.log(Math.sqrt(e*e+1)-e)}function C(t){return(Math.exp(t)-Math.exp(-t))/2}function L(t){return(Math.exp(t)+Math.exp(-t))/2}var I=E(0),P=function(t){return L(I)/L(I+_*t)},z=function(t){return w*((L(I)*(C(e=I+_*t)/L(e))-C(I))/S)/k;var e},O=(E(1)-I)/_;if(Math.abs(k)<1e-6||!isFinite(O)){if(Math.abs(w-T)<1e-6)return this.easeTo(e,r);var D=T<w?-1:1;O=Math.abs(Math.log(T/w))/_,z=function(){return 0},P=function(t){return Math.exp(D*_*t)}}return e.duration=\"duration\"in e?+e.duration:1e3*O/(\"screenSpeed\"in e?+e.screenSpeed/_:+e.speed),e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==f,this._pitching=h!==l,this._padding=!a.isPaddingEqual(p),this._prepareEase(r,!1),this._ease((function(e){var i=e*O,d=1/P(i);a.zoom=1===e?u:o+a.scaleZoom(d),n._rotating&&(a.bearing=t.number(s,f,e)),n._pitching&&(a.pitch=t.number(l,h,e)),n._padding&&(a.interpolatePadding(c,p,e),m=a.centerPoint.add(g));var v=1===e?y:a.unproject(x.add(b.mult(z(i))).mult(d));a.setLocationAtPoint(a.renderWorldCopies?v.wrap():v,m),n._fireMoveEvents(r)}),(function(){return n._afterEase(r)}),e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){return this._stop()},r.prototype._stop=function(t,e){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var r=this._onEaseEnd;delete this._onEaseEnd,r.call(this,e)}if(!t){var n=this.handlers;n&&n.stop()}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),vi=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};vi.prototype.getDefaultPosition=function(){return\"bottom-right\"},vi.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},vi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._attribHTML=void 0},vi.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce((function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t}),\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},vi.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},vi.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((function(t){return\"string\"!=typeof t?\"\":t}))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort((function(t,e){return t.length-e.length}));var o=(t=t.filter((function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}))).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},vi.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var yi=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};yi.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},yi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},yi.prototype.getDefaultPosition=function(){return\"bottom-left\"},yi.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},yi.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},yi.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var xi=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};xi.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},xi.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},xi.prototype.run=function(t){void 0===t&&(t=0);var e=this._currentlyRunning=this._queue;this._queue=[];for(var r=0,n=e;r<n.length;r+=1){var i=n[r];if(!i.cancelled&&(i.callback(t),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},xi.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var bi={\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"Mapbox logo\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\"},_i=t.window.HTMLImageElement,wi=t.window.HTMLElement,Ti=t.window.ImageBitmap,ki={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:60,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,bearingSnap:7,clickTolerance:3,pitchWithRotate:!0,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Mi=function(n){function i(e){var r=this;if(null!=(e=t.extend({},ki,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=e.minPitch&&null!=e.maxPitch&&e.minPitch>e.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=e.minPitch&&e.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=e.maxPitch&&e.maxPitch>60)throw new Error(\"maxPitch must be less than or equal to 60\");var i=new wn(e.minZoom,e.maxZoom,e.minPitch,e.maxPitch,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new xi,this._controls=[],this._mapId=t.uniqueId(),this._locale=t.extend({},bi,e.locale),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof wi))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",(function(){return r._update(!1)})),this.on(\"moveend\",(function(){return r._update(!1)})),this.on(\"zoom\",(function(){return r._update(!0)})),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),this.handlers=new gi(this,e),this._hash=e.hash&&new kn(\"string\"==typeof e.hash&&e.hash||void 0).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new vi({customAttribution:e.customAttribution})),this.addControl(new yi,e.logoPosition),this.on(\"style.load\",(function(){r.transform.unmodified&&r.jumpTo(r.style.stylesheet)})),this.on(\"data\",(function(e){r._update(\"style\"===e.dataType),r.fire(new t.Event(e.dataType+\"data\",e))})),this.on(\"dataloading\",(function(e){r.fire(new t.Event(e.dataType+\"dataloading\",e))}))}n&&(i.__proto__=n),(i.prototype=Object.create(n&&n.prototype)).constructor=i;var a={showTileBoundaries:{configurable:!0},showPadding:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i);var a=!this._moving;return a&&(this.stop(),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e))),this.fire(new t.Event(\"resize\",e)),a&&this.fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.setMinPitch=function(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")},i.prototype.getMinPitch=function(){return this.transform.minPitch},i.prototype.setMaxPitch=function(t){if((t=null==t?60:t)>60)throw new Error(\"maxPitch must be less than or equal to 60\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")},i.prototype.getMaxPitch=function(){return this.transform.maxPitch},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.handlers.isMoving()},i.prototype.isZooming=function(){return this._zooming||this.handlers.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.handlers.isRotating()},i.prototype._createDelegatedListener=function(t,e,r){var n,i=this;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new zn(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new zn(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new zn(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}},i.prototype.on=function(t,e,r){if(void 0===r)return n.prototype.on.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(a,i.delegates[a]);return this},i.prototype.once=function(t,e,r){if(void 0===r)return n.prototype.once.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in i.delegates)this.once(a,i.delegates[a]);return this},i.prototype.off=function(t,e,r){var i=this;return void 0===r?n.prototype.off.call(this,t,e):(this._delegatedListeners&&this._delegatedListeners[t]&&function(n){for(var a=n[t],o=0;o<a.length;o++){var s=a[o];if(s.layer===e&&s.listener===r){for(var l in s.delegates)i.off(l,s.delegates[l]);return a.splice(o,1),i}}}(this._delegatedListeners),this)},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._getUIString=function(t){var e=this._locale[t];if(null==e)throw new Error(\"Missing UI string '\"+t+\"'\");return e},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new qe(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._lazyInitEmptyStyle=function(){this.style||(this.style=new qe(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,(function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)}))}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this._lazyInitEmptyStyle(),this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;void 0===a&&(a=!1);var o=n.stretchX,s=n.stretchY,l=n.content;if(this._lazyInitEmptyStyle(),r instanceof _i||Ti&&r instanceof Ti){var c=t.browser.getImageData(r);this.style.addImage(e,{data:new t.RGBAImage({width:c.width,height:c.height},c.data),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r;this.style.addImage(e,{data:new t.RGBAImage({width:r.width,height:r.height},new Uint8Array(r.data)),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0,userImage:u}),u.onAdd&&u.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof _i||Ti&&r instanceof Ti?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;return void 0===a||void 0===o?this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\"))):a!==n.data.width||o!==n.data.height?this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\"))):(n.data.replace(s,!(r instanceof _i||Ti&&r instanceof Ti)),void this.style.updateImage(e,n))},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)}))},i.prototype._resizeCanvas=function(e,r){var n=t.browser.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new yn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(e){var r,n=this,i=0,a=this.painter.context.extTimerQuery;if(this.listens(\"gpu-timing-frame\")&&(r=a.createQueryEXT(),a.beginQueryEXT(a.TIME_ELAPSED_EXT,r),i=t.browser.now()),this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(e),!this._removed){var o=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var s=this.transform.zoom,l=t.browser.now();this.style.zoomHistory.update(s,l);var c=new t.EvaluationParameters(s,{now:l,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),u=c.crossFadingFactor();1===u&&u===this._crossFadingFactor||(o=!0,this._crossFadingFactor=u),this.style.update(c)}if(this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration,showPadding:this.showPadding,gpuTiming:!!this.listens(\"gpu-timing-layer\")}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||o)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this.listens(\"gpu-timing-frame\")){var f=t.browser.now()-i;a.endQueryEXT(a.TIME_ELAPSED_EXT,r),setTimeout((function(){var e=a.getQueryObjectEXT(r,a.QUERY_RESULT_EXT)/1e6;a.deleteQueryEXT(r),n.fire(new t.Event(\"gpu-timing-frame\",{cpuTime:f,gpuTime:e}))}),50)}if(this.listens(\"gpu-timing-layer\")){var h=this.painter.collectGpuTimers();setTimeout((function(){var e=n.painter.queryGpuTimers(h);n.fire(new t.Event(\"gpu-timing-layer\",{layerTimes:e}))}),50)}return this._sourcesDirty||this._styleDirty||this._placementDirty||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&(this._fullyLoaded||(this._fullyLoaded=!0),this.fire(new t.Event(\"idle\"))),this}},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),Ai(this._canvasContainer),Ai(this._controlContainer),Ai(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this._removed=!0,this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame((function(t){e._frame=null,e._render(t)})))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(t){this._trackResize&&this.resize({originalEvent:t})._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showPadding.get=function(){return!!this._showPadding},a.showPadding.set=function(t){this._showPadding!==t&&(this._showPadding=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},a.version.get=function(){return t.version},Object.defineProperties(i.prototype,a),i}(mi);function Ai(t){t.parentNode&&t.parentNode.removeChild(t)}var Si={showCompass:!0,showZoom:!0,visualizePitch:!1},Ei=function(e){var n=this;this.options=t.extend({},Si,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this.options.showZoom&&(t.bindAll([\"_setButtonTitle\",\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-zoom-in\",(function(t){return n._map.zoomIn({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",!0),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-zoom-out\",(function(t){return n._map.zoomOut({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",!0)),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-compass\",(function(t){n.options.visualizePitch?n._map.resetNorthPitch({},{originalEvent:t}):n._map.resetNorth({},{originalEvent:t})})),this._compassIcon=r.create(\"span\",\"mapboxgl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",!0))};Ei.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.disabled=t===this._map.getMaxZoom(),this._zoomOutButton.disabled=t===this._map.getMinZoom()},Ei.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?\"scale(\"+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+\") rotateX(\"+this._map.transform.pitch+\"deg) rotateZ(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\":\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassIcon.style.transform=t},Ei.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Ci(this._map,this._compass,this.options.visualizePitch)),this._container},Ei.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map},Ei.prototype._createButton=function(t,e){var n=r.create(\"button\",t,this._container);return n.type=\"button\",n.addEventListener(\"click\",e),n},Ei.prototype._setButtonTitle=function(t,e){var r=this._map._getUIString(\"NavigationControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)};var Ci=function(e,n,i){void 0===i&&(i=!1),this._clickTolerance=10,this.element=n,this.mouseRotate=new Gn({clickTolerance:e.dragRotate._mouseRotate._clickTolerance}),this.map=e,i&&(this.mousePitch=new Yn({clickTolerance:e.dragRotate._mousePitch._clickTolerance})),t.bindAll([\"mousedown\",\"mousemove\",\"mouseup\",\"touchstart\",\"touchmove\",\"touchend\",\"reset\"],this),r.addEventListener(n,\"mousedown\",this.mousedown),r.addEventListener(n,\"touchstart\",this.touchstart,{passive:!1}),r.addEventListener(n,\"touchmove\",this.touchmove),r.addEventListener(n,\"touchend\",this.touchend),r.addEventListener(n,\"touchcancel\",this.reset)};function Li(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Ci.prototype.down=function(t,e){this.mouseRotate.mousedown(t,e),this.mousePitch&&this.mousePitch.mousedown(t,e),r.disableDrag()},Ci.prototype.move=function(t,e){var r=this.map,n=this.mouseRotate.mousemoveWindow(t,e);if(n&&n.bearingDelta&&r.setBearing(r.getBearing()+n.bearingDelta),this.mousePitch){var i=this.mousePitch.mousemoveWindow(t,e);i&&i.pitchDelta&&r.setPitch(r.getPitch()+i.pitchDelta)}},Ci.prototype.off=function(){var t=this.element;r.removeEventListener(t,\"mousedown\",this.mousedown),r.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),r.removeEventListener(t,\"touchmove\",this.touchmove),r.removeEventListener(t,\"touchend\",this.touchend),r.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()},Ci.prototype.offTemp=function(){r.enableDrag(),r.removeEventListener(t.window,\"mousemove\",this.mousemove),r.removeEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousedown=function(e){this.down(t.extend({},e,{ctrlKey:!0,preventDefault:function(){return e.preventDefault()}}),r.mousePos(this.element,e)),r.addEventListener(t.window,\"mousemove\",this.mousemove),r.addEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousemove=function(t){this.move(t,r.mousePos(this.element,t))},Ci.prototype.mouseup=function(t){this.mouseRotate.mouseupWindow(t),this.mousePitch&&this.mousePitch.mouseupWindow(t),this.offTemp()},Ci.prototype.touchstart=function(t){1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.down({type:\"mousedown\",button:0,ctrlKey:!0,preventDefault:function(){return t.preventDefault()}},this._startPos))},Ci.prototype.touchmove=function(t){1!==t.targetTouches.length?this.reset():(this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.move({preventDefault:function(){return t.preventDefault()}},this._lastPos))},Ci.prototype.touchend=function(t){0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),this.reset()},Ci.prototype.reset=function(){this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()};var Ii={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Pi(t,e,r){var n=t.classList;for(var i in Ii)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var zi,Oi=function(e){function n(n,i){var a=this;if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\",\"_onKeyPress\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",this._rotation=n&&n.rotation||0,this._rotationAlignment=n&&n.rotationAlignment||\"auto\",this._pitchAlignment=n&&n.pitchAlignment&&\"auto\"!==n.pitchAlignment?n.pitchAlignment:this._rotationAlignment,n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\"),this._element.setAttribute(\"aria-label\",\"Map marker\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");o.setAttributeNS(null,\"display\",\"block\"),o.setAttributeNS(null,\"height\",\"41px\"),o.setAttributeNS(null,\"width\",\"27px\"),o.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"stroke\",\"none\"),s.setAttributeNS(null,\"stroke-width\",\"1\"),s.setAttributeNS(null,\"fill\",\"none\"),s.setAttributeNS(null,\"fill-rule\",\"evenodd\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"fill-rule\",\"nonzero\");var c=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");c.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),c.setAttributeNS(null,\"fill\",\"#000000\");for(var u=0,f=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];u<f.length;u+=1){var h=f[u],p=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");p.setAttributeNS(null,\"opacity\",\"0.04\"),p.setAttributeNS(null,\"cx\",\"10.5\"),p.setAttributeNS(null,\"cy\",\"5.80029008\"),p.setAttributeNS(null,\"rx\",h.rx),p.setAttributeNS(null,\"ry\",h.ry),c.appendChild(p)}var d=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");d.setAttributeNS(null,\"fill\",this._color);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");g.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),d.appendChild(g);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"opacity\",\"0.25\"),m.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),m.appendChild(v);var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),y.setAttributeNS(null,\"fill\",\"#FFFFFF\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");x.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#000000\"),b.setAttributeNS(null,\"opacity\",\"0.25\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\");var _=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");_.setAttributeNS(null,\"fill\",\"#FFFFFF\"),_.setAttributeNS(null,\"cx\",\"5.5\"),_.setAttributeNS(null,\"cy\",\"5.5\"),_.setAttributeNS(null,\"r\",\"5.4999962\"),x.appendChild(b),x.appendChild(_),l.appendChild(c),l.appendChild(d),l.appendChild(m),l.appendChild(y),l.appendChild(x),o.appendChild(l),this._element.appendChild(o),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",(function(t){t.preventDefault()})),this._element.addEventListener(\"mousedown\",(function(t){t.preventDefault()})),this._element.addEventListener(\"focus\",(function(){var t=a._map.getContainer();t.scrollTop=0,t.scrollLeft=0})),Pi(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat),this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this},n.prototype._onKeyPress=function(t){var e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){if(this._map){this._map.transform.renderWorldCopies&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset);var e=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?e=\"rotateZ(\"+this._rotation+\"deg)\":\"map\"===this._rotationAlignment&&(e=\"rotateZ(\"+(this._rotation-this._map.getBearing())+\"deg)\");var n=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?n=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(n=\"rotateX(\"+this._map.getPitch()+\"deg)\"),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Ii[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px) \"+n+\" \"+e)}},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n.prototype.setRotation=function(t){return this._rotation=t||0,this._update(),this},n.prototype.getRotation=function(){return this._rotation},n.prototype.setRotationAlignment=function(t){return this._rotationAlignment=t||\"auto\",this._update(),this},n.prototype.getRotationAlignment=function(){return this._rotationAlignment},n.prototype.setPitchAlignment=function(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this},n.prototype.getPitchAlignment=function(){return this._pitchAlignment},n}(t.Evented),Di={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0},Ri=0,Fi=!1,Bi=function(e){function n(r){e.call(this),this.options=t.extend({},Di,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_onZoom\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==zi?n(zi):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then((function(t){n(zi=\"denied\"!==t.state)})):n(zi=!!t.window.navigator.geolocation),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),r.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Ri=0,Fi=!1},n.prototype._isOutOfMapMaxBounds=function(t){var e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())},n.prototype._setErrorState=function(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}},n.prototype._onSuccess=function(e){if(this._map){if(this._isOutOfMapMaxBounds(e))return this._setErrorState(),this.fire(new t.Event(\"outofmaxbounds\",e)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()}},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(e){if(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=e.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},n.prototype._updateCircleRadius=function(){var t=this._map._container.clientHeight/2,e=this._map.unproject([0,t]),r=this._map.unproject([1,t]),n=e.distanceTo(r),i=Math.ceil(2*this._accuracy/n);this._circleElement.style.width=i+\"px\",this._circleElement.style.height=i+\"px\"},n.prototype._onZoom=function(){this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},n.prototype._onError=function(e){if(this._map){if(this.options.trackUserLocation)if(1===e.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;var r=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=r,this._geolocateButton.setAttribute(\"aria-label\",r),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===e.code&&Fi)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()}},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;if(this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-geolocate\",this._container),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",!0),this._geolocateButton.type=\"button\",!1===e){t.warnOnce(\"Geolocation support is not available so the GeolocateControl will be disabled.\");var i=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=i,this._geolocateButton.setAttribute(\"aria-label\",i)}else{var a=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.title=a,this._geolocateButton.setAttribute(\"aria-label\",a)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new Oi(this._dotElement),this._circleElement=r.create(\"div\",\"mapboxgl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Oi({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||e.originalEvent&&\"resize\"===e.originalEvent.type||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))}))},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Ri--,Fi=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){var e;this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),++Ri>1?(e={maximumAge:6e5,timeout:0},Fi=!0):(e=this.options.positionOptions,Fi=!1),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,e)}}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Ni={maxWidth:100,unit:\"metric\"},ji=function(e){this.options=t.extend({},Ni,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Ui(t,e,r){var n=r&&r.maxWidth||100,i=t._container.clientHeight/2,a=t.unproject([0,i]),o=t.unproject([n,i]),s=a.distanceTo(o);if(r&&\"imperial\"===r.unit){var l=3.2808*s;l>5280?Vi(e,n,l/5280,t._getUIString(\"ScaleControl.Miles\")):Vi(e,n,l,t._getUIString(\"ScaleControl.Feet\"))}else r&&\"nautical\"===r.unit?Vi(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\")):s>=1e3?Vi(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):Vi(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function Vi(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o)));t.style.width=e*(s/r)+\"px\",t.innerHTML=s+\"&nbsp;\"+n}ji.prototype.getDefaultPosition=function(){return\"bottom-left\"},ji.prototype._onMove=function(){Ui(this._map,this._container,this.options)},ji.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},ji.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},ji.prototype.setUnit=function(t){this.options.unit=t,Ui(this._map,this._container,this.options)};var qi=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\")};qi.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},qi.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},qi.prototype._setupUI=function(){var e=this._fullscreenButton=r.create(\"button\",\"mapboxgl-ctrl-fullscreen\",this._controlContainer);r.create(\"span\",\"mapboxgl-ctrl-icon\",e).setAttribute(\"aria-hidden\",!0),e.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._updateTitle=function(){var t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},qi.prototype._getTitle=function(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")},qi.prototype._isFullscreen=function(){return this._fullscreen},qi.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-fullscreen\"),this._updateTitle())},qi.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Hi={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Gi=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Hi),r),t.bindAll([\"_update\",\"_onClose\",\"remove\",\"_onMouseMove\",\"_onMouseUp\",\"_onDrag\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(e){return this._map&&this.remove(),this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this},n.prototype.trackPointer=function(){return this._trackPointer=!0,this._pos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container&&this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype.addClassName=function(t){this._container&&this._container.classList.add(t)},n.prototype.removeClassName=function(t){this._container&&this._container.classList.remove(t)},n.prototype.toggleClassName=function(t){if(this._container)return this._container.classList.toggle(t)},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))},n.prototype._onMouseUp=function(t){this._update(t.point)},n.prototype._onMouseMove=function(t){this._update(t.point)},n.prototype._onDrag=function(t){this._update(t.point)},n.prototype._update=function(e){var n=this;if(this._map&&(this._lngLat||this._trackPointer)&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach((function(t){return n._container.classList.add(t)})),this._trackPointer&&this._container.classList.add(\"mapboxgl-popup-track-pointer\")),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var i=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),a=this.options.anchor,o=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!a){var s,l=this._container.offsetWidth,c=this._container.offsetHeight;s=i.y+o.bottom.y<c?[\"top\"]:i.y>this._map.transform.height-c?[\"bottom\"]:[],i.x<l/2?s.push(\"left\"):i.x>this._map.transform.width-l/2&&s.push(\"right\"),a=0===s.length?\"bottom\":s.join(\"-\")}var u=i.add(o[a]).round();r.setTransform(this._container,Ii[a]+\" translate(\"+u.x+\"px,\"+u.y+\"px)\"),Pi(this._container,a,\"popup\")}},n.prototype._onClose=function(){this.remove()},n}(t.Evented),Yi={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,getRTLTextPluginStatus:t.getRTLTextPluginStatus,Map:Mi,NavigationControl:Ei,GeolocateControl:Bi,AttributionControl:vi,ScaleControl:ji,FullscreenControl:qi,Popup:Gi,Marker:Oi,Style:qe,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,prewarm:function(){Bt().acquire(Ot)},clearPrewarmedResources:function(){var t=Rt;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(Ot),Rt=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return Dt.workerCount},set workerCount(t){Dt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Yi})),r}))},{}],474:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],f=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;f.push(a[u[s]].slice())}c.push(f)}return c}},{\"convex-hull\":135}],475:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),f=i(),h=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,m,v){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),m||(m=[0,0,0,1]),v||(v=[0,0,0,1]),!n(u,t))return!1;if(a(f,u),f[3]=0,f[7]=0,f[11]=0,f[15]=1,Math.abs(o(f)<1e-8))return!1;var y,x,b,_,w,T,k,M=u[3],A=u[7],S=u[11],E=u[12],C=u[13],L=u[14],I=u[15];if(0!==M||0!==A||0!==S){if(h[0]=M,h[1]=A,h[2]=S,h[3]=I,!s(f,f))return!1;l(f,f),y=m,b=f,_=(x=h)[0],w=x[1],T=x[2],k=x[3],y[0]=b[0]*_+b[4]*w+b[8]*T+b[12]*k,y[1]=b[1]*_+b[5]*w+b[9]*T+b[13]*k,y[2]=b[2]*_+b[6]*w+b[10]*T+b[14]*k,y[3]=b[3]*_+b[7]*w+b[11]*T+b[15]*k}else m[0]=m[1]=m[2]=0,m[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var P=0;P<3;P++)r[P]*=-1,p[P][0]*=-1,p[P][1]*=-1,p[P][2]*=-1;return v[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),v[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),v[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),v[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(v[0]=-v[0]),p[0][2]>p[2][0]&&(v[1]=-v[1]),p[1][0]>p[0][1]&&(v[2]=-v[2]),!0}},{\"./normalize\":476,\"gl-mat4/clone\":278,\"gl-mat4/create\":280,\"gl-mat4/determinant\":281,\"gl-mat4/invert\":293,\"gl-mat4/transpose\":306,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/length\":380,\"gl-vec3/normalize\":387}],476:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],477:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=f(),c=f(),u=f();function f(){return{translate:h(),scale:h(1),skew:h(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function h(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,f){if(0===o(e)||0===o(r))return!1;var h=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!h||!p)&&(n(u.translate,l.translate,c.translate,f),n(u.skew,l.skew,c.skew,f),n(u.scale,l.scale,c.scale,f),n(u.perspective,l.perspective,c.perspective,f),s(u.quaternion,l.quaternion,c.quaternion,f),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),!0)}},{\"gl-mat4/determinant\":281,\"gl-vec3/lerp\":381,\"mat4-decompose\":475,\"mat4-recompose\":478,\"quat-slerp\":527}],478:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":280,\"gl-mat4/fromRotationTranslation\":284,\"gl-mat4/identity\":291,\"gl-mat4/multiply\":295,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305}],479:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],480:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),f=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),h=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],h=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)h[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&h[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=h[c];else i(o,h,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],f(g,g);var m=this.computedInverse;a(m,o);var v=this.computedEye,y=m[15];v[0]=m[12]/y,v[1]=m[13]/y,v[2]=m[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=v[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||h,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":481,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294,\"gl-mat4/rotateX\":300,\"gl-mat4/rotateY\":301,\"gl-mat4/rotateZ\":302,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305,\"gl-vec3/normalize\":387,\"mat4-interpolate\":477}],481:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],482:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}var a=new Array(e);for(i=0;i<e;++i)a[i]=i;a.sort((function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]}));var o=[a[0],a[1]],s=[a[0],a[1]];for(i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}r=new Array(s.length+o.length-2);for(var f=0,h=(i=0,o.length);i<h;++i)r[f++]=o[i];for(var p=s.length-2;p>0;--p)r[f++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],483:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function f(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function h(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function m(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",f),t.addEventListener(\"keyup\",h),t.addEventListener(\"keydown\",h),t.addEventListener(\"keypress\",h),t!==window&&(window.addEventListener(\"blur\",f),window.addEventListener(\"keyup\",h),window.addEventListener(\"keydown\",h),window.addEventListener(\"keypress\",h)))}m();var v={element:t};return Object.defineProperties(v,{enabled:{get:function(){return s},set:function(e){e?m():function(){if(!s)return;s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",f),t.removeEventListener(\"keyup\",h),t.removeEventListener(\"keydown\",h),t.removeEventListener(\"keypress\",h),t!==window&&(window.removeEventListener(\"blur\",f),window.removeEventListener(\"keyup\",h),window.removeEventListener(\"keydown\",h),window.removeEventListener(\"keypress\",h))}()},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),v};var n=t(\"mouse-event\")},{\"mouse-event\":485}],484:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],485:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],486:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=i;break;case 2:s=window.innerHeight}if(a*=s,o*=s,(n*=s)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":578}],487:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function f(t){return\"p\"+t}function h(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function m(t){return\"y\"+t}function v(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var b=t.arrayArguments||1;b<1&&e(\"Must have at least one array argument\");var _=t.scalarArguments||0;_<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var w=t.getters||[],T=new Array(b),k=0;k<b;++k)w.indexOf(k)>=0?T[k]=!0:T[k]=!1;return function(t,e,r,b,_,w){var T=w.length,k=_.length;if(k<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var M=\"extractContour\"+_.join(\"_\"),A=[],S=[],E=[],C=0;C<T;++C)E.push(i(C));for(C=0;C<b;++C)E.push(u(C));for(C=0;C<k;++C)S.push(s(C)+\"=\"+i(0)+\".shape[\"+C+\"]|0\");for(C=0;C<T;++C){S.push(a(C)+\"=\"+i(C)+\".data\",c(C)+\"=\"+i(C)+\".offset|0\");for(var L=0;L<k;++L)S.push(l(C,L)+\"=\"+i(C)+\".stride[\"+L+\"]|0\")}for(C=0;C<T;++C){S.push(f(C)+\"=\"+c(C)),S.push(o(C,0));for(L=1;L<1<<k;++L){for(var I=[],P=0;P<k;++P)L&1<<P&&I.push(\"-\"+l(C,P));S.push(h(C,L)+\"=(\"+I.join(\"\")+\")|0\"),S.push(o(C,L)+\"=0\")}}for(C=0;C<T;++C)for(L=0;L<k;++L){var z=[l(C,_[L])];L>0&&z.push(l(C,_[L-1])+\"*\"+s(_[L-1])),S.push(d(C,_[L])+\"=(\"+z.join(\"-\")+\")|0\")}for(C=0;C<k;++C)S.push(p(C)+\"=0\");S.push(\"N=0\");var O=[\"2\"];for(C=k-2;C>=0;--C)O.push(s(_[C]));S.push(\"Q=(\"+O.join(\"*\")+\")|0\",\"P=mallocUint32(Q)\",\"V=mallocUint32(Q)\",\"X=0\"),S.push(g(0)+\"=0\");for(L=1;L<1<<k;++L){var D=[],R=[];for(P=0;P<k;++P)L&1<<P&&(0===R.length?D.push(\"1\"):D.unshift(R.join(\"*\"))),R.push(s(_[P]));var F=\"\";D[0].indexOf(s(_[k-2]))<0&&(F=\"-\");var B=x(k,L,_);S.push(v(B)+\"=(-\"+D.join(\"-\")+\")|0\",m(B)+\"=(\"+F+D.join(\"-\")+\")|0\",g(B)+\"=0\")}function N(t,e){A.push(\"for(\",p(_[t]),\"=\",e,\";\",p(_[t]),\"<\",s(_[t]),\";\",\"++\",p(_[t]),\"){\")}function j(t){for(var e=0;e<T;++e)A.push(f(e),\"+=\",d(e,_[t]),\";\");A.push(\"}\")}function U(){for(var t=1;t<1<<k;++t)A.push(\"T\",\"=\",v(t),\";\",v(t),\"=\",m(t),\";\",m(t),\"=\",\"T\",\";\")}S.push(y(0)+\"=0\",\"T=0\"),function t(e,r){if(e<0)!function(t){for(var e=0;e<T;++e)w[e]?A.push(o(e,0),\"=\",a(e),\".get(\",f(e),\");\"):A.push(o(e,0),\"=\",a(e),\"[\",f(e),\"];\");var r=[];for(e=0;e<T;++e)r.push(o(e,0));for(e=0;e<b;++e)r.push(u(e));A.push(g(0),\"=\",\"P\",\"[\",\"X\",\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<k;++n)A.push(g(n),\"=\",\"P\",\"[\",\"X\",\"+\",v(n),\"];\");var i=[];for(n=1;n<1<<k;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");A.push(\"if(\",i.join(\"||\"),\"){\");var s=[];for(e=0;e<k;++e)s.push(p(e));for(e=0;e<T;++e){s.push(o(e,0));for(n=1;n<1<<k;++n)w[e]?A.push(o(e,n),\"=\",a(e),\".get(\",f(e),\"+\",h(e,n),\");\"):A.push(o(e,n),\"=\",a(e),\"[\",f(e),\"+\",h(e,n),\"];\"),s.push(o(e,n))}for(e=0;e<1<<k;++e)s.push(g(e));for(e=0;e<b;++e)s.push(u(e));A.push(\"vertex(\",s.join(),\");\",y(0),\"=\",\"V\",\"[\",\"X\",\"]=\",\"N\",\"++;\");var l=(1<<k)-1,c=g(l);for(n=0;n<k;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,m=g(d),x=[],_=d;_>0;_=_-1&d)x.push(\"V[X+\"+v(_)+\"]\");x.push(y(0));for(_=0;_<T;++_)1&n?x.push(o(_,l),o(_,d)):x.push(o(_,d),o(_,l));1&n?x.push(c,m):x.push(m,c);for(_=0;_<b;++_)x.push(u(_));A.push(\"if(\",c,\"!==\",m,\"){\",\"face(\",x.join(),\")}\")}A.push(\"}\",\"X\",\"+=1;\")}(r);else{!function(t){for(var e=t-1;e>=0;--e)N(e,0);var r=[];for(e=0;e<T;++e)w[e]?r.push(a(e)+\".get(\"+f(e)+\")\"):r.push(a(e)+\"[\"+f(e)+\"]\");for(e=0;e<b;++e)r.push(u(e));for(A.push(\"P\",\"[\",\"X\",\"++]=phase(\",r.join(),\");\"),e=0;e<t;++e)j(e);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[t]),\";\")}(e),A.push(\"if(\",s(_[e]),\">0){\",p(_[e]),\"=1;\"),t(e-1,r|1<<_[e]);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[e]),\";\");e===k-1&&(A.push(\"X\",\"=0;\"),U()),N(e,2),t(e-1,r),e===k-1&&(A.push(\"if(\",p(_[k-1]),\"&1){\",\"X\",\"=0;}\"),U()),j(e),A.push(\"}\")}}(k-1,0),A.push(\"freeUint32(\",\"V\",\");freeUint32(\",\"P\",\");\");var V=[\"'use strict';\",\"function \",M,\"(\",E.join(),\"){\",\"var \",S.join(),\";\",A.join(\"\"),\"}\",\"return \",M].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",V)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,_,r,T)};function x(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":595}],488:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(v=o[e])return v;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(l=0;l<e.length;++l){var u=Math.abs(e[l])-1,f=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var h=s.slice(),p=s.slice();e[l]<0?h[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",h.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",f,\",src.pick(\",h.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",f,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",f,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",f,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",f,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var f=[],h=0;h<r;++h)s&1<<h&&f.push(h+1);for(var p=0;p<1<<f.length;++p){var d=f.slice();for(h=0;h<f.length;++h)p&1<<h&&(d[h]=-d[h]);i(d)}}n.push(\"return dst;};return gradient\");var g=[\"diff\",\"zero\"],m=[l,c];for(s=1;s<=r;++s)g.push(\"grad\"+s),m.push(u(s));g.push(n.join(\"\"));var v=Function.apply(void 0,g).apply(void 0,m);return a[e]=v,v}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map((function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}})),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":151,dup:176}],489:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],f=a&&c?t.get(n,s):0,h=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*f+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*h+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],f=0<=l+1&&l+1<t.shape[1],h=Math.floor(n),p=n-h,d=0<=h&&h<t.shape[2],g=0<=h+1&&h+1<t.shape[2],m=o&&u&&d?t.get(i,l,h):0,v=o&&f&&d?t.get(i,l+1,h):0,y=s&&u&&d?t.get(i+1,l,h):0,x=s&&f&&d?t.get(i+1,l+1,h):0,b=o&&u&&g?t.get(i,l,h+1):0,_=o&&f&&g?t.get(i,l+1,h+1):0;return(1-p)*((1-c)*((1-a)*m+a*y)+c*((1-a)*v+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,h+1):0))+c*((1-a)*_+a*(s&&f&&g?t.get(i+1,l+1,h+1):0)))}function o(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,f=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}f+=c*t.data[u]}return f}e.exports=function(t,e,r,s){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,s);default:return o.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],490:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var f=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var h=[\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":151}],491:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":492,ndarray:495}],492:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":151}],493:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l){0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p))}var f=-1,h=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(f>0?s.push([\"d\",d,\"=s\",d,\"-d\",f,\"*n\",f].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),f=d),0!==(p=t.length-1-l)&&(h>0?s.push([\"e\",p,\"=s\",p,\"-e\",h,\"*n\",h,\",f\",p,\"=\",c[p],\"-f\",h,\"*n\",h].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),h=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var m=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),v=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function f(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function h(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){r.push(\"dptr=0;sptr=ptr\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(\"scratch[dptr++]=\",f(\"sptr\"));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\")}r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\");for(u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));r.push([\"a=\",f(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\"));for(u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");r.push(\"dptr=cptr;sptr=cptr-s0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",f(\"sptr\")));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\")}r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",\"scratch[sptr++]\"));for(u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+f(\"ptr\"),\"while((j--\\x3eleft)&&(\"+f(\"cptr-s0\")+\">scratch)){\",h(\"cptr\",f(\"cptr-s0\")),\"cptr-=s0\",\"}\",h(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var f=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var h=[],p=1;p<t.length;++p)h.push(\"n\"+p),f.push(\"i\"+p);for(p=0;p<8;++p)f.push(\"b_ptr\"+p);f.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+h.join(\"*\")),c?f.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):f.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else f.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function m(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function v(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\");for(a=t.length-1;a>=0;--a){0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"))}if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));n.push(i),r&&n.push(\"++pivot_ptr\");for(a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\");for(o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));n.push(a);for(o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?v([e,r],!1,m(\"ptr0\",g(\"ptr1\"))):n.push(m(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function T(e,r){t.length>1?v([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\"))}function k(e,r,i){t.length>1?(v([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\"))}function M(t,e){T(t,e),n.push(\"--\"+e)}function A(e,r,i){t.length>1?v([e,r],!0,[m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(m(d(e),g(d(r))),m(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),v([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+f.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?v([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",m(\"ptr5\",\"x\"),\"\\n\",m(\"ptr6\",\"y\"),\"\\n\",m(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",m(d(\"index1\"),\"x\"),\"\\n\",m(d(\"index3\"),\"y\"),\"\\n\",m(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),A(\"left\",\"(less-1)\",1),A(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,v);return m(v,y)}},{\"typedarray-pool\":595}],494:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":493}],495:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map((function(t){return\"i\"+t})),u=\"this.offset+\"+o.map((function(t){return\"this.stride[\"+t+\"]*i\"+t})).join(\"+\"),f=o.map((function(t){return\"b\"+t})).join(\",\"),h=o.map((function(t){return\"c\"+t})).join(\",\");a.push(\"function \"+r+\"(a,\"+f+\",\"+h+\",d){this.data=a\",\"this.shape=[\"+f+\"]\",\"this.stride=[\"+h+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map((function(t){return\"this.shape[\"+t+\"]\"})).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map((function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")})).join(\",\")+\",\"+o.map((function(t){return\"this.stride[\"+t+\"]\"})).join(\",\")+\",this.offset)}\");var p=o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})),d=o.map((function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"}));a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"c\"+t})).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"})).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t})).join(\",\")+\",c)}\");var m=new Array(e),v=new Array(e);for(g=0;g<e;++g)m[g]=\"a[i\"+g+\"]\",v[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map((function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"})).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+m.join(\",\")+\",\"+v.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map((function(t){return\"shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"stride[\"+t+\"]\"})).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],bigint64:[],biguint64:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n){n=0;for(s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s])}for(var f=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\";case\"[object BigInt64Array]\":return\"bigint64\";case\"[object BigUint64Array]\":return\"biguint64\"}return Array.isArray(t)?\"array\":\"generic\"}(t),h=c[f];h.length<=o+1;)h.push(l(f,h.length-1));return(0,h[o+1])(t,e,r,n)}},{\"iota-array\":463,\"is-buffer\":465}],496:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074);e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),a=n.lo(t);e>t==t>0?a===-1>>>0?(r+=1,a=0):a+=1:0===a?(a=-1>>>0,r-=1):a-=1;return n.pack(a,r)}},{\"double-bits\":173}],497:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,f,h,p){if(p)T=p[0],k=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(f=(d=l(f,h,-o)).x))/2,m=(e-(h=d.y))/2,v=g*g/(r*r)+m*m/(a*a);v>1&&(r*=v=Math.sqrt(v),a*=v);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*m*m-x*g*g)/(y*m*m+x*g*g)));b==1/0&&(b=1);var _=b*r*m/a+(t+f)/2,w=b*-a*g/r+(e+h)/2,T=Math.asin(((e-w)/a).toFixed(9)),k=Math.asin(((h-w)/a).toFixed(9));(T=t<_?n-T:T)<0&&(T=2*n+T),(k=f<_?n-k:k)<0&&(k=2*n+k),u&&T>k&&(T-=2*n),!u&&k>T&&(k-=2*n)}if(Math.abs(k-T)>i){var M=k,A=f,S=h;k=T+i*(u&&k>T?1:-1);var E=s(f=_+r*Math.cos(k),h=w+a*Math.sin(k),r,a,o,0,u,A,S,[k,M,_,w])}var C=Math.tan((k-T)/4),L=4/3*r*C,I=4/3*a*C,P=[2*t-(t+L*Math.sin(T)),2*e-(e-I*Math.cos(T)),f+L*Math.sin(k),h-I*Math.cos(k),f,h];if(p)return P;E&&(P=P.concat(E));for(var z=0;z<P.length;){var O=l(P[z],P[z+1],o);P[z++]=O.x,P[z++]=O.y}return P}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,f=null,h=null,p=0,d=0,g=0,m=t.length;g<m;g++){var v=t[g],y=v[0];switch(y){case\"M\":l=v[1],u=v[2];break;case\"A\":(v=s(p,d,v[1],v[2],c(v[3]),v[4],v[5],v[6],v[7])).unshift(\"C\"),v.length>7&&(r.push(v.splice(0,7)),v.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),v=[\"C\",x,b,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(f=2*p-f,h=2*d-h):(f=p,h=d),v=o(p,d,f,h,v[1],v[2]);break;case\"Q\":f=v[1],h=v[2],v=o(p,d,v[1],v[2],v[3],v[4]);break;case\"L\":v=a(p,d,v[1],v[2]);break;case\"H\":v=a(p,d,v[1],d);break;case\"V\":v=a(p,d,p,v[1]);break;case\"Z\":v=a(p,d,l,u)}e=y,p=v[v.length-2],d=v[v.length-1],v.length>4?(n=v[v.length-4],i=v[v.length-3]):(n=p,i=d),r.push(v)}return r}},{}],498:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],f=0;f<s.length;++f){l=c,c=u,u=s[(f+1)%s.length];for(var h=e[l],p=e[c],d=e[u],g=new Array(3),m=0,v=new Array(3),y=0,x=0;x<3;++x)g[x]=h[x]-p[x],m+=g[x]*g[x],v[x]=d[x]-p[x],y+=v[x]*v[x];if(m*y>a){var b=i[c],_=1/Math.sqrt(m*y);for(x=0;x<3;++x){var w=(x+1)%3,T=(x+2)%3;b[x]+=_*(v[w]*g[T]-v[T]*g[w])}}}for(o=0;o<n;++o){b=i[o];var k=0;for(x=0;x<3;++x)k+=b[x]*b[x];if(k>a)for(_=1/Math.sqrt(k),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),f=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],f[c]=l[2][c]-l[0][c];var h=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;h[c]=u[d]*f[g]-u[g]*f[d],p+=h[c]*h[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)h[c]*=p;i[o]=h}return i}},{}],499:[function(t,e,r){\n",
       "/*\n",
       "object-assign\n",
       "(c) Sindre Sorhus\n",
       "@license MIT\n",
       "*/\n",
       "\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;function o(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map((function(t){return e[t]})).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach((function(t){n[t]=t})),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,s,l=o(t),c=1;c<arguments.length;c++){for(var u in r=Object(arguments[c]))i.call(r,u)&&(l[u]=r[u]);if(n){s=n(r);for(var f=0;f<s.length;f++)a.call(r,s[f])&&(l[s[f]]=r[s[f]])}}return l}},{}],500:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(f>0){var f=Math.sqrt(u+1);t[0]=.5*(o-l)/f,t[1]=.5*(s-n)/f,t[2]=.5*(r-a)/f,t[3]=.5*f}else{var h=Math.max(e,a,c);f=Math.sqrt(2*h-u+1);e>=h?(t[0]=.5*f,t[1]=.5*(i+r)/f,t[2]=.5*(s+n)/f,t[3]=.5*(o-l)/f):a>=h?(t[0]=.5*(r+i)/f,t[1]=.5*f,t[2]=.5*(l+o)/f,t[3]=.5*(s-n)/f):(t[0]=.5*(n+s)/f,t[1]=.5*(o+l)/f,t[2]=.5*f,t[3]=.5*(r-i)/f)}return t}},{}],501:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new f(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function f(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var h=f.prototype;h.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},h.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,f=0;f<3;++f)c+=r[l+4*f]*i[f];r[12+l]=-c}},h.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},h.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},h.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},h.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=l(u-=a*p,f-=o*p,h-=s*p);u/=d,f/=d,h/=d;var g=i[2],m=i[6],v=i[10],y=g*a+m*o+v*s,x=g*u+m*f+v*h,b=l(g-=y*a+x*u,m-=y*o+x*f,v-=y*s+x*h);g/=b,m/=b,v/=b;var _=u*e+a*r,w=f*e+o*r,T=h*e+s*r;this.center.move(t,_,w,T);var k=Math.exp(this.computedRadius[0]);k=Math.max(1e-4,k+n),this.radius.set(t,Math.log(k))},h.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],f=i[5],h=i[9],p=i[2],d=i[6],g=i[10],m=e*a+r*u,v=e*o+r*f,y=e*s+r*h,x=-(d*y-g*v),b=-(g*m-p*y),_=-(p*v-d*m),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),T=c(x,b,_,w);T>1e-6?(x/=T,b/=T,_/=T,w/=T):(x=b=_=0,w=1);var k=this.computedRotation,M=k[0],A=k[1],S=k[2],E=k[3],C=M*w+E*x+A*_-S*b,L=A*w+E*b+S*x-M*_,I=S*w+E*_+M*b-A*x,P=E*w-M*x-A*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,P=P*(w=Math.cos(e))-(C=C*w+P*x+L*_-I*b)*x-(L=L*w+P*b+I*x-C*_)*b-(I=I*w+P*_+C*b-L*x)*_}var O=c(C,L,I,P);O>1e-6?(C/=O,L/=O,I/=O,P/=O):(C=L=I=0,P=1),this.rotation.set(t,C,L,I,P)},h.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},h.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},h.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var f=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*f,l-n[6]*f,c-n[10]*f),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},h.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},h.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},h.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},h.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},h.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":500,\"filtered-vector\":242,\"gl-mat4/fromQuat\":282,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294}],502:[function(t,e,r){\n",
       "/*!\n",
       " * pad-left <https://github.com/jonschlinkert/pad-left>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT license.\n",
       " */\n",
       "\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":541}],503:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach((function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach((function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t})),n=n.reverse(),r=r.map((function(e){return n.forEach((function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])})),e}))}));var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce((function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r}),\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],504:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":511}],505:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,(function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}})),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],506:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],507:[function(t,e,r){(function(t){(function(){\"use strict\";function r(t){if(\"string\"!=typeof t)throw new TypeError(\"Path must be a string. Received \"+JSON.stringify(t))}function n(t,e){for(var r,n=\"\",i=0,a=-1,o=0,s=0;s<=t.length;++s){if(s<t.length)r=t.charCodeAt(s);else{if(47===r)break;r=47}if(47===r){if(a===s-1||1===o);else if(a!==s-1&&2===o){if(n.length<2||2!==i||46!==n.charCodeAt(n.length-1)||46!==n.charCodeAt(n.length-2))if(n.length>2){var l=n.lastIndexOf(\"/\");if(l!==n.length-1){-1===l?(n=\"\",i=0):i=(n=n.slice(0,l)).length-1-n.lastIndexOf(\"/\"),a=s,o=0;continue}}else if(2===n.length||1===n.length){n=\"\",i=0,a=s,o=0;continue}e&&(n.length>0?n+=\"/..\":n=\"..\",i=2)}else n.length>0?n+=\"/\"+t.slice(a+1,s):n=t.slice(a+1,s),i=s-a-1;a=s,o=0}else 46===r&&-1!==o?++o:o=-1}return n}var i={resolve:function(){for(var e,i=\"\",a=!1,o=arguments.length-1;o>=-1&&!a;o--){var s;o>=0?s=arguments[o]:(void 0===e&&(e=t.cwd()),s=e),r(s),0!==s.length&&(i=s+\"/\"+i,a=47===s.charCodeAt(0))}return i=n(i,!a),a?i.length>0?\"/\"+i:\"/\":i.length>0?i:\".\"},normalize:function(t){if(r(t),0===t.length)return\".\";var e=47===t.charCodeAt(0),i=47===t.charCodeAt(t.length-1);return 0!==(t=n(t,!e)).length||e||(t=\".\"),t.length>0&&i&&(t+=\"/\"),e?\"/\"+t:t},isAbsolute:function(t){return r(t),t.length>0&&47===t.charCodeAt(0)},join:function(){if(0===arguments.length)return\".\";for(var t,e=0;e<arguments.length;++e){var n=arguments[e];r(n),n.length>0&&(void 0===t?t=n:t+=\"/\"+n)}return void 0===t?\".\":i.normalize(t)},relative:function(t,e){if(r(t),r(e),t===e)return\"\";if((t=i.resolve(t))===(e=i.resolve(e)))return\"\";for(var n=1;n<t.length&&47===t.charCodeAt(n);++n);for(var a=t.length,o=a-n,s=1;s<e.length&&47===e.charCodeAt(s);++s);for(var l=e.length-s,c=o<l?o:l,u=-1,f=0;f<=c;++f){if(f===c){if(l>c){if(47===e.charCodeAt(s+f))return e.slice(s+f+1);if(0===f)return e.slice(s+f)}else o>c&&(47===t.charCodeAt(n+f)?u=f:0===f&&(u=0));break}var h=t.charCodeAt(n+f);if(h!==e.charCodeAt(s+f))break;47===h&&(u=f)}var p=\"\";for(f=n+u+1;f<=a;++f)f!==a&&47!==t.charCodeAt(f)||(0===p.length?p+=\"..\":p+=\"/..\");return p.length>0?p+e.slice(s+u):(s+=u,47===e.charCodeAt(s)&&++s,e.slice(s))},_makeLong:function(t){return t},dirname:function(t){if(r(t),0===t.length)return\".\";for(var e=t.charCodeAt(0),n=47===e,i=-1,a=!0,o=t.length-1;o>=1;--o)if(47===(e=t.charCodeAt(o))){if(!a){i=o;break}}else a=!1;return-1===i?n?\"/\":\".\":n&&1===i?\"//\":t.slice(0,i)},basename:function(t,e){if(void 0!==e&&\"string\"!=typeof e)throw new TypeError('\"ext\" argument must be a string');r(t);var n,i=0,a=-1,o=!0;if(void 0!==e&&e.length>0&&e.length<=t.length){if(e.length===t.length&&e===t)return\"\";var s=e.length-1,l=-1;for(n=t.length-1;n>=0;--n){var c=t.charCodeAt(n);if(47===c){if(!o){i=n+1;break}}else-1===l&&(o=!1,l=n+1),s>=0&&(c===e.charCodeAt(s)?-1==--s&&(a=n):(s=-1,a=l))}return i===a?a=l:-1===a&&(a=t.length),t.slice(i,a)}for(n=t.length-1;n>=0;--n)if(47===t.charCodeAt(n)){if(!o){i=n+1;break}}else-1===a&&(o=!1,a=n+1);return-1===a?\"\":t.slice(i,a)},extname:function(t){r(t);for(var e=-1,n=0,i=-1,a=!0,o=0,s=t.length-1;s>=0;--s){var l=t.charCodeAt(s);if(47!==l)-1===i&&(a=!1,i=s+1),46===l?-1===e?e=s:1!==o&&(o=1):-1!==e&&(o=-1);else if(!a){n=s+1;break}}return-1===e||-1===i||0===o||1===o&&e===i-1&&e===n+1?\"\":t.slice(e,i)},format:function(t){if(null===t||\"object\"!=typeof t)throw new TypeError('The \"pathObject\" argument must be of type Object. Received type '+typeof t);return function(t,e){var r=e.dir||e.root,n=e.base||(e.name||\"\")+(e.ext||\"\");return r?r===e.root?r+n:r+t+n:n}(\"/\",t)},parse:function(t){r(t);var e={root:\"\",dir:\"\",base:\"\",ext:\"\",name:\"\"};if(0===t.length)return e;var n,i=t.charCodeAt(0),a=47===i;a?(e.root=\"/\",n=1):n=0;for(var o=-1,s=0,l=-1,c=!0,u=t.length-1,f=0;u>=n;--u)if(47!==(i=t.charCodeAt(u)))-1===l&&(c=!1,l=u+1),46===i?-1===o?o=u:1!==f&&(f=1):-1!==o&&(f=-1);else if(!c){s=u+1;break}return-1===o||-1===l||0===f||1===f&&o===l-1&&o===s+1?-1!==l&&(e.base=e.name=0===s&&a?t.slice(1,l):t.slice(s,l)):(0===s&&a?(e.name=t.slice(1,o),e.base=t.slice(1,l)):(e.name=t.slice(s,o),e.base=t.slice(s,l)),e.ext=t.slice(o,l)),s>0?e.dir=t.slice(0,s-1):a&&(e.dir=\"/\"),e},sep:\"/\",delimiter:\":\",win32:null,posix:null};i.posix=i,e.exports=i}).call(this)}).call(this,t(\"_process\"))},{_process:526}],508:[function(t,e,r){(function(t){(function(){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this)}).call(this,t(\"_process\"))},{_process:526}],509:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<32){for(var r=1,i=0;i<e;++i)for(var a=0;a<i;++a)if(t[i]<t[a])r=-r;else if(t[i]===t[a])return 0;return r}var o=n.mallocUint8(e);for(i=0;i<e;++i)o[i]=0;for(r=1,i=0;i<e;++i)if(!o[i]){var s=1;o[i]=1;for(a=t[i];a!==i;a=t[a]){if(o[a])return n.freeUint8(o),0;s+=1,o[a]=1}1&s||(r=-r)}return n.freeUint8(o),r};var n=t(\"typedarray-pool\")},{\"typedarray-pool\":595}],510:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":462,\"typedarray-pool\":595}],511:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var f=a;f<c.length;f++)l[c[f]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],512:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}var l=[];for(o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var f=0;f<2;++f)for(var h=a[f][r],p=0;p<h.length;++p){var d=h[p],g=d[1^f];n(e[t],e[r],e[s],e[g])>0&&(o=d,s=g,l=f)}return i||o&&c(o,l),s}function f(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],f=t,h=o[1],p=u(l,f,!0);if(n(e[l],e[f],e[h],e[p])<0)break;o.push(t),s=u(l,f)}return o}function h(t,e){return e[1]===e[e.length-1]}for(o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=f(o,p);h(0,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":132}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;var u=r[c];for(s=0;s<u.length;++s){var f=u[s];0==--a[f]&&o.push(f)}}var h=new Array(e.length),p=[];for(s=0;s<e.length;++s)if(i[s]){c=p.length;h[s]=c,p.push(e[s])}else h[s]=-1;var d=[];for(s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([h[g[0]],h[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":178}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var f=(e=r[1]).length,h=(t.length,n(t,e.length)),p=0;p<f;++p)if(h[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);var g=(d=d.filter((function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),f=o(l[0],a[1]),h=o(l[0],l[1]);n=s(n,s(s(c,u),s(f,h)))}return n[n.length-1]>0}))).length,m=new Array(g),v=new Array(g);for(p=0;p<g;++p){m[p]=p;var y=new Array(g),x=d[p].map((function(t){return e[t]})),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var T=(q=d[w]).length,k=0;k<T;++k){var M=b(e[q[k]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}v[p]=[_,p,y]}v.sort((function(t,e){return e[0]-t[0]}));for(p=0;p<g;++p){var A=(y=v[p])[1],S=y[2];for(w=0;w<g;++w)S[w]&&(m[w]=A)}var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g);for(p=0;p<g;++p)E[p].push(m[p]),E[m[p]].push(p);var C={},L=u(f,!1);for(p=0;p<g;++p)for(T=(q=d[p]).length,w=0;w<T;++w){var I=q[w],P=q[(w+1)%T],z=Math.min(I,P)+\":\"+Math.max(I,P);if(z in C){var O=C[z];E[O].push(p),E[p].push(O),L[I]=L[P]=!0}else C[z]=p}function D(t){for(var e=t.length,r=0;r<e;++r)if(!L[t[r]])return!1;return!0}var R=[],F=u(g,-1);for(p=0;p<g;++p)m[p]!==p||D(d[p])?F[p]=-1:(R.push(p),F[p]=0);r=[];for(;R.length>0;){var B=R.pop(),N=E[B];l(N,(function(t,e){return t-e}));var j,U=N.length,V=F[B];if(0===V){var q=d[B];j=[q]}for(p=0;p<U;++p){var H=N[p];if(!(F[H]>=0))if(F[H]=1^V,R.push(H),0===V)D(q=d[H])||(q.reverse(),j.push(q))}0===V&&r.push(j)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":513,\"edges-to-adjacency-list\":178,\"planar-dual\":512,\"point-in-big-polygon\":516,\"robust-sum\":553,\"two-product\":582,uniq:597}],515:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],516:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],f=u.length,h=f-1,p=0;p<f;h=p++){var d=u[h],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(m=l(a),function(t){return m(t[0],t[1])?0:1});var m;var v=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(v.slabs,v.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},f=Object.keys(e);for(r=0;r<f.length;++r){var h=e[f[r]];u[f[r]]=a(h)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":515,\"interval-tree-1d\":460,\"robust-orientation\":548,\"slab-decomposition\":565}],517:[function(t,e,r){\n",
       "/*\n",
       " * @copyright 2016 Sean Connelly (@voidqk), http://syntheti.cc\n",
       " * @license MIT\n",
       " * @preserve Project Home: https://github.com/voidqk/polybooljs\n",
       " */\n",
       "var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,f=a();function h(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return f.epsilon(t)},segments:function(t){var e=o(!0,f,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,f,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,f,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,f,t)},union:function(t,e){return h(t,e,n.selectUnion)},intersect:function(t,e){return h(t,e,n.selectIntersect)},difference:function(t,e){return h(t,e,n.selectDifference)},differenceRev:function(t,e){return h(t,e,n.selectDifferenceRev)},xor:function(t,e){return h(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":518,\"./lib/epsilon\":519,\"./lib/geojson\":520,\"./lib/intersecter\":521,\"./lib/segment-chainer\":523,\"./lib/segment-selector\":524}],518:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],519:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t)&&!(l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],f=e[1]-n[1],h=(s*f-l*u)/c,p=(a*f-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+h*a,e[1]+h*o]};return d.alongA=h<=-t?-2:h<t?-1:h-1<=-t?0:h-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],520:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function f(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(h(t.children[r]))}function h(t){for(var e=0;e<t.children.length;e++)f(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)f(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],521:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,(function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0}))}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition((function(r){var n,i,a,o,s,l;return(n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)||e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0}))}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var f=e.linesIntersect(o,s,c,u);if(!1===f){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var h=e.pointsSame(o,c),p=e.pointsSame(s,u);if(h&&p)return n;var d=!h&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(h)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===f.alongA&&(-1===f.alongB?l(t,c):0===f.alongB?l(t,f.pt):1===f.alongB&&l(t,u)),0===f.alongB&&(-1===f.alongA?l(n,o):0===f.alongA?l(n,f.pt):1===f.alongA&&l(n,s));return!1}for(var f=[];!a.isEmpty();){var h=a.getHead();if(r&&r.vert(h.pt[0]),h.isStart){r&&r.segmentNew(h.seg,h.primary);var p=c(h),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function m(){if(d){var t=u(h,d);if(t)return t}return!!g&&u(h,g)}r&&r.tempStatus(h.seg,!!d&&d.seg,!!g&&g.seg);var v,y=m();if(y){var x;if(t)(x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below)&&(y.seg.myFill.above=!y.seg.myFill.above);else y.seg.otherFill=h.seg.myFill;r&&r.segmentUpdate(y.seg),h.other.remove(),h.remove()}if(a.getHead()!==h){r&&r.rewind(h.seg);continue}if(t)x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below,h.seg.myFill.below=g?g.seg.myFill.above:i,h.seg.myFill.above=x?!h.seg.myFill.below:h.seg.myFill.below;else if(null===h.seg.otherFill)v=g?h.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:h.primary?o:i,h.seg.otherFill={above:v,below:v};r&&r.status(h.seg,!!d&&d.seg,!!g&&g.seg),h.other.status=p.insert(n.node({ev:h}))}else{var b=h.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!h.primary){var _=h.seg.myFill;h.seg.myFill=h.seg.otherFill,h.seg.otherFill=_}f.push(h.seg)}a.getHead().remove()}return r&&r.done(),f}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach((function(t){s(i(t.start,t.end,t),!0)})),r.forEach((function(t){s(i(t.start,t.end,t),!1)})),c(e,n)}}}},{\"./linked-list\":522}],522:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],523:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach((function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var f=(m=n[u])[0],h=(m[1],m[m.length-1]);m[m.length-2];if(e.pointsSame(f,a)){if(k(u,!0,!0))break}else if(e.pointsSame(f,o)){if(k(u,!0,!1))break}else if(e.pointsSame(h,a)){if(k(u,!1,!0))break}else if(e.pointsSame(h,o)&&k(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,m=n[p],v=g?m[0]:m[m.length-1],y=g?m[1]:m[m.length-2],x=g?m[m.length-1]:m[0],b=g?m[m.length-2]:m[1];return e.pointsCollinear(y,v,d)&&(g?(r&&r.chainRemoveHead(s.index,d),m.shift()):(r&&r.chainRemoveTail(s.index,d),m.pop()),v=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,v)&&(g?(r&&r.chainRemoveTail(s.index,v),m.pop()):(r&&r.chainRemoveHead(s.index,v),m.shift())),r&&r.chainClose(s.index),void i.push(m)):void(g?(r&&r.chainAddHead(s.index,d),m.unshift(d)):(r&&r.chainAddTail(s.index,d),m.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var T=n[_].length<n[w].length;s.matches_head?l.matches_head?T?(M(_),A(_,w)):(M(w),A(w,_)):A(w,_):l.matches_head?A(_,w):T?(M(_),A(w,_)):(M(w),A(_,w))}function k(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function M(t){r&&r.chainReverse(t),n[t].reverse()}function A(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}})),i}},{}],524:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach((function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})})),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],525:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,f=0,h=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],m=a[l],v=n[l];c+=g*g,u+=g*m,f+=m*m,h+=v*g,p+=v*m,d+=v*v}var y,x,b,_,w,T=Math.abs(c*f-u*u),k=u*p-f*h,M=u*h-c*p;if(k+M<=T)if(k<0)M<0&&h<0?(M=0,-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d):(k=0,p>=0?(M=0,y=d):-p>=f?(M=1,y=f+2*p+d):y=p*(M=-p/f)+d);else if(M<0)M=0,h>=0?(k=0,y=d):-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d;else{var A=1/T;y=(k*=A)*(c*k+u*(M*=A)+2*h)+M*(u*k+f*M+2*p)+d}else k<0?(b=f+p)>(x=u+h)?(_=b-x)>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d:(k=0,b<=0?(M=1,y=f+2*p+d):p>=0?(M=0,y=d):y=p*(M=-p/f)+d):M<0?(b=c+h)>(x=u+p)?(_=b-x)>=(w=c-2*u+f)?(M=1,k=0,y=f+2*p+d):y=(k=1-(M=_/w))*(c*k+u*M+2*h)+M*(u*k+f*M+2*p)+d:(M=0,b<=0?(k=1,y=c+2*h+d):h>=0?(k=0,y=d):y=h*(k=-h/c)+d):(_=f+p-u-h)<=0?(k=0,M=1,y=f+2*p+d):_>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d;var S=1-k-M;for(l=0;l<o.length;++l)s[l]=S*t[l]+k*e[l]+M*r[l];return y<0?0:y}},{}],526:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],f=!1,h=-1;function p(){f&&c&&(f=!1,c.length?u=c.concat(u):h=-1,u.length&&d())}function d(){if(!f){var t=l(p);f=!0;for(var e=u.length;e;){for(c=u,u=[];++h<e;)c&&c[h].run();h=-1,e=u.length}c=null,f=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function m(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||f||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=m,a.addListener=m,a.once=m,a.off=m,a.removeListener=m,a.removeAllListeners=m,a.emit=m,a.prependListener=m,a.prependOnceListener=m,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],527:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":325}],528:[function(t,e,r){(function(r){(function(){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,f=0,h=[];s=function(t){if(0===h.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout((function(){var t=h.slice(0);h.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout((function(){throw t}),0)}}),Math.round(r))}return h.push({handle:++f,callback:t,cancelled:!1}),f},l=function(t){for(var e=0;e<h.length;e++)h[e].handle===t&&(h[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":508}],529:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":80}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":83}],531:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":83,\"big-rat/mul\":92}],532:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":94}],533:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":117,\"compare-cell\":133,\"compare-oriented-cell\":134}],534:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,f=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,m,v=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),m=t.buffer({usage:\"static\",type:\"float\",data:h}),T(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:m,stride:24,offset:0},lineOffset:{buffer:m,stride:24,offset:8},capOffset:{buffer:m,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:h.length}),s(b,{update:T,draw:_,destroy:k,regl:t,gl:v,canvas:v.canvas,groups:x}),b;function b(t){t?T(t):null===t&&k(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach((function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)}))}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function T(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map((function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=f(e.scale),e.translateFract=f(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:v.drawingBufferWidth,height:v.drawingBufferHeight},e}}]),u):u})),e||r){var h=x.reduce((function(t,e,r){return t+(e?e.count:0)}),0),m=new Float64Array(2*h),_=new Uint8Array(4*h),w=new Float32Array(4*h);x.forEach((function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),m.set(r,2*i))}})),c(u(m)),p(f(m)),d(_),g(w)}}}function k(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),m.destroy()}};var h=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":70,\"color-normalize\":125,\"flatten-vertex-data\":244,\"object-assign\":499,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],535:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),f=t(\"to-float32\"),h=f.float32,p=f.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function m(t,e){if(!(this instanceof m))return new m(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=m.shaders.has(t)?m.shaders.get(t):m.shaders.set(t,m.createShaders(t)).get(t),this.update(e)}e.exports=m,m.dashMult=2,m.maxPatternLength=256,m.precisionThreshold=3e6,m.maxPoints=1e4,m.maxLines=2048,m.shaders=new d,m.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},m.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},m.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},m.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach((function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>m.precisionThreshold||e.scale[1]*e.viewport.height>m.precisionThreshold||\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=m.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))})),this},m.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach((function(t,f){var d=e.passes[f];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[f]=d={id:f,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},m.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,f<m.maxLines&&(d.depth=2*(m.maxLines-1-f%m.maxLines)/m.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var v,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),v=new Float64Array(2*y);for(var _=0;_<y;_++)v[2*_]=x[_],v[2*_+1]=b[_]}else v=l(t.positions,\"float64\"),y=d.count=Math.floor(v.length/2);var w=d.bounds=i(v,2);if(d.fill){for(var T=[],k={},M=0,A=0,S=0,E=d.count;A<E;A++){var C=v[2*A],L=v[2*A+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=v[2*M],L=v[2*M+1],k[A]=M):M=A,T[S++]=C,T[S++]=L}for(var I=c(T,d.hole||[]),P=0,z=I.length;P<z;P++)null!=k[I[P]]&&(I[P]=k[I[P]]);d.triangles=I}var O=new Float64Array(v);u(O,2,w);var D=new Float64Array(2*y+6);d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[0]=O[2*y-4],D[1]=O[2*y-3]):(D[0]=O[2*y-2],D[1]=O[2*y-1]):(D[0]=O[0],D[1]=O[1]),D.set(O,2),d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[2*y+2]=O[2],D[2*y+3]=O[3],d.count-=1):(D[2*y+2]=O[0],D[2*y+3]=O[1],D[2*y+4]=O[2],D[2*y+5]=O[3]):(D[2*y+2]=O[2*y-2],D[2*y+3]=O[2*y-1],D[2*y+4]=O[2*y-2],D[2*y+5]=O[2*y-1]),d.positionBuffer(h(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*m.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*m.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var Q=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var $=0;$<J;$++){var tt=n(K[$],\"uint8\");Q.set(tt,4*$)}Q.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)Q.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:Q})}}else e.passes[f]=null})),t.length<this.passes.length){for(var f=t.length;f<this.passes.length;f++){var d=this.passes[f];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var v=[],y=0;y<this.passes.length;y++)null!==this.passes[y]&&v.push(this.passes[y]);return this.passes=v,this}},m.prototype.destroy=function(){return this.passes.forEach((function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()})),this.passes.length=0,this}},{\"array-bounds\":70,\"array-normalize\":71,\"color-normalize\":125,earcut:177,\"es6-weak-map\":233,\"flatten-vertex-data\":244,glslify:536,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577}],536:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],537:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){if(\"undefined\"==typeof Symbol||!(Symbol.iterator in Object(t)))return;var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||a(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t){return function(t){if(Array.isArray(t))return o(t)}(t)||function(t){if(\"undefined\"!=typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}(t)||a(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function a(t,e){if(t){if(\"string\"==typeof t)return o(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?o(t,e):void 0}}function o(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}var s=t(\"color-normalize\"),l=t(\"array-bounds\"),c=t(\"color-id\"),u=t(\"@plotly/point-cluster\"),f=t(\"object-assign\"),h=t(\"glslify\"),p=t(\"pick-by-alias\"),d=t(\"update-diff\"),g=t(\"flatten-vertex-data\"),m=t(\"is-iexplorer\"),v=t(\"to-float32\"),y=t(\"parse-rect\"),x=b;function b(t,e){var r=this;if(!(this instanceof b))return new b(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=m,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),f(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{constPointSize:!!e.constPointSize,pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=f({},o);s.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pointSizeScale;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=f({},o);l.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pointSizeScale;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),m&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}b.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},b.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},b.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach((function(e,r){t.drawItem(r)}));return this},b.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},b.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,c=e.count;this.regl;if(!a)return r?[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var u=[],h=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(c),g=0;g<r.length;g++){var m=r[g];d[m]=p?p[m]:1}l.subdata(d)}for(var v=h.length;v--;){var y=n(h[v],2),x=y[0],b=y[1];u.push(f({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return u},b.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,o=this.regl,s=this.maxSize,c=this.maxColors,h=this.palette;this.groups=i=r.map((function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=p(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:o.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=f({},b.defaults,e)),e.positions&&!(\"marker\"in e)&&(e.marker=n.marker,delete n.marker),e.marker&&!(\"positions\"in e)&&(e.positions=n.positions,delete n.positions);var m=0,x=0;if(d(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=b.defaults.size),m+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=b.defaults.borderSize),m+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=b.defaults.color),e=t.updateColor(e),x++,e},borderColor:function(e,r){return null==e&&(e=b.defaults.borderColor),e=t.updateColor(e),x++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,s=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:o.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:o.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=g(t,\"float64\");var c=e.count=Math.floor(t.length/2),f=e.bounds=c?l(t,2):null;if(r.range||e.range||(delete e.range,r.range=f),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||c>n)?e.tree=u(t,{bounds:f}):n&&n.length&&(e.tree=n),e.tree){var h={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(h):e.elements=o.elements(h)}return i({data:v.float(t),usage:\"dynamic\"}),a({data:v.fract(t),usage:\"dynamic\"}),s({data:new Uint8Array(c),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach((function(t){return t&&t.destroy&&t.destroy()})),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],s=0,l=Math.min(e.length,r.count);s<l;s++){var c=t.addMarker(e[s]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][s]=1}for(var u=0;u<a.length;u++)if(a[u]){var f={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](f):i[u]=o.buffer(f),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=v.fract(e.scale),e.translateFract=v.fract(e.translate),t},viewport:function(t){return y(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),m){var _=n,w=_.count,T=_.size,k=_.borderSize,M=_.sizeBuffer,A=new Uint8Array(2*w);if(T.length||k.length)for(var S=0;S<w;S++)A[2*S]=Math.round(255*(null==T[S]?T:T[S])/s),A[2*S+1]=Math.round(255*(null==k[S]?k:k[S])/s);M({data:A,usage:\"dynamic\"})}if(x){var E,C=n,L=C.count,I=C.color,P=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(I.length||P.length){E=new Uint8Array(8*L);for(var O=0;O<L;O++){var D=I[O];E[8*O]=h[4*D],E[8*O+1]=h[4*D+1],E[8*O+2]=h[4*D+2],E[8*O+3]=h[4*D+3];var R=P[O];E[8*O+4]=h[4*R],E[8*O+5]=h[4*R+1],E[8*O+6]=h[4*R+2],E[8*O+7]=h[4*R+3]}}}else if(I.length||P.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=I[F]&&(E[4*F]=I[F]%c,E[4*F+1]=Math.floor(I[F]/c)),null!=P[F]&&(E[4*F+2]=P[F]%c,E[4*F+3]=Math.floor(P[F]/c))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n}))}},b.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},b.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var a=[];if(Array.isArray(t))for(var o=0;o<t.length;o+=4)a.push(t.slice(o,o+4));else for(var l=0;l<t.length;l+=4)a.push(t.subarray(l,l+4));t=a}for(var u=0;u<t.length;u++){var f=t[u];f=s(f,\"uint8\");var h=c(f,!1);if(null==e[h]){var p=r.length;e[h]=Math.floor(p/4),r[p]=f[0],r[p+1]=f[1],r[p+2]=f[2],r[p+3]=f[3]}i[u]=e[h]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},b.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},b.prototype.destroy=function(){return this.groups.forEach((function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach((function(t){return t&&t.destroy&&t.destroy()})),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()})),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach((function(t){return t&&t.destroy&&t.destroy()})),this};var _=t(\"object-assign\");e.exports=function(t,e){var r=new x(t,e),n=r.render.bind(r);return _(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"@plotly/point-cluster\":57,\"array-bounds\":70,\"color-id\":123,\"color-normalize\":125,\"flatten-vertex-data\":244,glslify:538,\"is-iexplorer\":466,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],538:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],539:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function f(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function h(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o((function(){e.draw(),e.dirty=!0,e.planned=null}))):(this.draw(),this.dirty=!0,o((function(){e.dirty=!1}))),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,m=s.count,v=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=v/g,w=y/g;s.passes=[];for(var T=0;T<g;T++)for(var k=0;k<g;k++)if((s.diagonal||k!==T)&&(s.upper||!(T>k))&&(s.lower||!(T<k))){var M=f(s.id,T,k),A=this.passes[M]||(this.passes[M]={});if(o.data&&(o.transpose?A.positions={x:{buffer:s.buffer,offset:k,count:m,stride:g},y:{buffer:s.buffer,offset:T,count:m,stride:g}}:A.positions={x:{buffer:s.buffer,offset:k*m,count:m},y:{buffer:s.buffer,offset:T*m,count:m}},A.bounds=h(s.bounds,T,k)),o.domain||o.viewport||o.data){var S=d?h(s.padding,T,k):s.padding;if(s.domain){var E=h(s.domain,T,k),C=E[0],L=E[1],I=E[2],P=E[3];A.viewport=[x+C*v+S[0],b+L*y+S[1],x+I*v-S[2],b+P*y-S[3]]}else A.viewport=[x+k*_+_*S[0],b+T*w+w*S[1],x+(k+1)*_-_*S[2],b+(T+1)*w-w*S[3]]}o.color&&(A.color=s.color),o.size&&(A.size=s.size),o.marker&&(A.marker=s.marker),o.borderSize&&(A.borderSize=s.borderSize),o.borderColor&&(A.borderColor=s.borderColor),o.opacity&&(A.opacity=s.opacity),o.range&&(A.range=n?h(s.range,T,k):s.range||A.bounds),s.passes.push(M)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],f=u.passes,h=u.passOffset;f=f.map((function(t,e){n[h+e]=c}))}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach((function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()})),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":70,\"array-range\":72,\"flatten-vertex-data\":244,\"parse-rect\":504,\"pick-by-alias\":511,raf:528,\"regl-scatter2d\":537}],540:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.createREGL=n()}(this,(function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,f=!1,h=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(h=s.onDone),\"profile\"in s&&(f=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n,U(a.style,{width:e+\"px\",height:n+\"px\"})}var i,a=document.createElement(\"canvas\");return U(a.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(a),t===document.body&&(a.style.position=\"absolute\",U(t.style,{margin:0,padding:0})),t!==document.body&&\"function\"==typeof ResizeObserver?(i=new ResizeObserver((function(){setTimeout(n)}))).observe(t):window.addEventListener(\"resize\",n,!1),n(),{canvas:a,onDestroy:function(){i?i.disconnect():window.removeEventListener(\"resize\",n),t.removeChild(a)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}void 0===t.premultipliedAlpha&&(t.premultipliedAlpha=!0),o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:f,onDone:h,onDestroy:p}:(p(),h(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,(function(){return[]}));return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||X(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|K[Object.prototype.toString.call(t)]}function f(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function h(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=et(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=tt(e,i,t.dtype),r),o?t.persistentData=e:Y.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,f(i=Y.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:Y.freeType(i)):X(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=tt(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:Y.freeType(e))}else if(X(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,m=0;1===i.length?(p=i[0],d=1,g=c[0],m=0):2===i.length&&(p=i[0],d=i[1],g=c[0],m=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,h(i=Y.allocType(t.dtype,p*d),e.data,p,d,g,m,s),a(t,i,r),o?t.persistentData=i:Y.freeType(i)}else e instanceof ArrayBuffer&&(t.dtype=5121,t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e))))}function s(r){e.bufferCount--,n(r),t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach((function(e){t+=p[e].stats.size})),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||X(e)||l(e)||e instanceof ArrayBuffer?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=Q[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),m.bind(),i?o(m,i,n,s,c,d):(a&&t.bufferData(m.type,a,n),m.dtype=s||5121,m.usage=n,m.dimension=c,m.byteLength=a),r.profile&&(m.stats.size=m.byteLength*rt[m.dtype]),g}e.bufferCount++;var m=new i(a);return p[m.id]=m,c||g(n),g._reglType=\"buffer\",g._buffer=m,g.subdata=function(e,r){var n,i=0|(r||0);if(m.bind(),X(e)||e instanceof ArrayBuffer)t.bufferSubData(m.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=Y.allocType(m.dtype,e.length);f(a,e),t.bufferSubData(m.type,i,a),Y.freeType(a)}else(Array.isArray(e[0])||X(e[0]))&&(n=et(e),a=tt(e,n,m.dtype),t.bufferSubData(m.type,i,a),Y.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?m.dtype:u(e.data),h(n=Y.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(m.type,i,n),Y.freeType(n)}return g},r.profile&&(g.stats=m.stats),g.destroy=function(){s(m)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){Z(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){Z(p).forEach((function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)}))},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){var f;if(n.buffer.bind(),i?((f=u)||X(i)&&(!l(i)||X(i.data))||(f=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,f,3)):(t.bufferData(34963,c,a),n.buffer.dtype=f||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c),f=u,!u){switch(n.buffer.dtype){case 5121:case 5120:f=5121;break;case 5123:case 5122:f=5123;break;case 5125:case 5124:f=5125}n.buffer.dtype=f}n.type=f,0>(i=s)&&(i=n.buffer.byteLength,5123===f?i>>=1:5125===f&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var f=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),f.primType=4,f.vertCount=0|t,f.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,h=0;Array.isArray(t)||X(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=nt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(h=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===h||5122===h?o*=2:5125!==h&&5124!==h||(o*=4))),a(f,e,r,n,i,o,h)}else c(),f.primType=4,f.vertCount=0,f.type=5121;return s}var c=r.create(null,34963,!0),f=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=f,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(f)},s},createStream:function(t){var e=f.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){f.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){Z(s).forEach(o)}}}function g(t){for(var e=Y.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{it[0]=t[r];var n=(a=at[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function m(t){return Array.isArray(t)||X(t)}function v(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!m(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=gt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),Y.freeType(e)):t.data=e}function T(t,e,r,n,i,a){if(t=\"undefined\"!=typeof vt[t]?vt[t]:lt[t]*mt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function k(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=G[r],t.format=at[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in W&&(t.compressed=!0),r=!0),!a&&r?t.channels=lt[t.format]:a&&!r&&t.channels!==st[t.format]&&(t.format=t.internalformat=st[t.channels])}}function f(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function h(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(X(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=Y.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,f,h=r.stride;3===a.length?(c=a[2],f=h[2]):f=c=1,o=a[0],s=a[1],a=h[0],h=h[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=st[c],t.needsFree=!0,o=f,r=r.offset,c=t.width,f=t.height,s=t.channels;for(var p=Y.allocType(36193===t.type?5126:t.type,c*f*s),d=0,v=0;v<f;++v)for(var T=0;T<c;++T)for(var k=0;k<s;++k)p[d++]=n[a*T+h*v+o*k+r];w(t,p)}else if(b(r)===ct||b(r)===ut||b(r)===ft)b(r)===ct||b(r)===ut?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===pt)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===dt)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,h=t.channels,h=m(r[0][0])?h||r[0][0].length:h||1,o=J.shape(r),c=1,f=0;f<o.length;++f)c*=o[f];c=Y.allocType(36193===t.type?5126:t.type,c),J.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=h,t.format=t.internalformat=st[h],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,h=e.type,p=e.width,d=e.height;f(e),s?t.texSubImage2D(r,o,i,a,u,h,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,h,l)}function v(){return gt.pop()||new h}function k(t){t.needsFree&&Y.freeType(t.data),h.call(t),gt.push(t)}function M(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function A(t,e,r){var n=t.images[0]=v();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=v(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,h=o.internalformat,p=o.format,d=o.type,g=o.width,m=o.height;f(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,h,g,m,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,m,0)):t.texImage2D(s,l,p,g,m,0,p,d,u||null)}}function C(){var t=mt.pop()||new M;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&k(e[r]),e[r]=null;mt.push(t)}function I(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function P(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=ot.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=j[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function O(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new I,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=bt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),bt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete yt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},j={nearest:9728,linear:9729},V=U({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},j),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},G={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},W={};e.ext_srgb&&(G.srgb=35904,G.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(U(G,{depth:6402,\"depth stencil\":34041}),U(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&U(W,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&U(W,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&U(W,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(W[\"rgb etc1\"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(W).forEach((function(t){var e=W[t];0<=Q.indexOf(e)&&(G[t]=e)}));var $=Object.keys(G);r.textureFormats=$;var tt=[];Object.keys(G).forEach((function(t){tt[G[t]]=t}));var et=[];Object.keys(H).forEach((function(t){et[H[t]]=t}));var rt=[];Object.keys(j).forEach((function(t){rt[j[t]]=t}));var nt=[];Object.keys(V).forEach((function(t){nt[V[t]]=t}));var it=[];Object.keys(N).forEach((function(t){it[N[t]]=t}));var at=$.reduce((function(t,r){var n=G[r];return 6409===n||6406===n||6409===n||6410===n||6402===n||34041===n||e.ext_srgb&&(35904===n||35906===n)?t[n]=n:32855===n||0<=r.indexOf(\"rgba\")?t[n]=6408:t[n]=6407,t}),{}),gt=[],mt=[],vt=0,yt={},xt=r.maxTextureUnits,bt=Array(xt).map((function(){return null}));return U(O.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<xt;++r){var n=bt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}bt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(yt).forEach((function(e){t+=yt[e].stats.size})),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;I.call(r);var a=C();return\"number\"==typeof t?A(a,0|t,\"number\"==typeof e?0|e:0|t):t?(P(r,t),S(a,t)):A(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=T(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new O(3553);return yt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=v();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),k(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l=0;i.mipmask>>l;++l){var c=a>>l,u=s>>l;if(!c||!u)break;t.texImage2D(3553,l,i.format,c,u,0,i.format,i.type,null)}return R(),o.profile&&(i.stats.size=T(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function f(t,e,r,n,i,a){var s,l=h.texInfo;for(I.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(P(l,t),u(h,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],h),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)A(g[s],t,t);for(c(h,g[0]),h.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,h.internalformat=g[0].internalformat,f.width=g[0].width,f.height=g[0].height,D(h),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,l.genMipmaps,!0)),f.format=tt[h.internalformat],f.type=et[h.type],f.mag=rt[l.magFilter],f.min=nt[l.minFilter],f.wrapS=it[l.wrapS],f.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return f}var h=new O(34067);yt[h.id]=h,a.cubeCount++;var g=Array(6);return f(e,r,n,i,s,l),f.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=v();return c(a,h),a.width=0,a.height=0,p(a,e),a.width=a.width||(h.width>>i)-r,a.height=a.height||(h.height>>i)-n,D(h),d(a,34069+t,r,n,i),R(),k(a),f},f.resize=function(e){if((e|=0)!==h.width){f.width=h.width=e,f.height=h.height=e,D(h);for(var r=0;6>r;++r)for(var n=0;h.mipmask>>n;++n)t.texImage2D(34069+r,n,h.format,e>>n,e>>n,0,h.format,h.type,null);return R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,!1,!0)),f}},f._reglType=\"textureCube\",f._texture=h,o.profile&&(f.stats=h.stats),f.destroy=function(){h.decRef()},f},clear:function(){for(var e=0;e<xt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),bt[e]=null;Z(yt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<xt;++e){var r=bt[e];r&&(r.bindCount=0,r.unit=-1,bt[e]=null)}Z(yt).forEach((function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)}))}}}function M(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)||\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function f(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function h(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=T++,k[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function m(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete k[e.id]}function v(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",m=\"uint8\",y=1,x=null,w=null,T=null,k=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(m=t.colorType,!p)&&(\"half float\"===m||\"float16\"===m?d=\"rgba16f\":\"float\"!==m&&\"float32\"!==m||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(k=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(T=t.depthStencil,c=s=!1))):a=o=1;var M=null,A=null,S=null,E=null;if(Array.isArray(i))M=i.map(u);else if(i)M=[u(i)];else for(M=Array(y),i=0;i<y;++i)M[i]=f(a,o,p,d,m);for(a=a||M[0].width,o=o||M[0].height,x?A=u(x):s&&!c&&(A=f(a,o,k,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=f(a,o,!1,\"stencil\",\"uint8\")),T?E=u(T):!x&&!w&&c&&s&&(E=f(a,o,k,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<M.length;++i)l(M[i]),M[i]&&M[i].texture&&(c=bt[M[i].texture._texture.format]*_t[M[i].texture._texture.type],null===s&&(s=c));return l(A),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=M,n.depthAttachment=A,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=M.map(h),r.depth=h(A),r.stencil=h(S),r.depthStencil=h(E),r.width=n.width,r.height=n.height,v(n),r}var n=new d;return a.framebufferCount++,r(t,e),U(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,v(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){m(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var T=0,k={};return U(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return U(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),U(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach((function(t){t.destroy()}))}})},clear:function(){Z(k).forEach(m)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,Z(k).forEach((function(e){e.framebuffer=t.createFramebuffer(),v(e)}))}})}function A(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n,i){function a(){this.id=++c,this.attributes=[];var t=e.oes_vertex_array_object;this.vao=t?t.createVertexArrayOES():null,u[this.id]=this,this.buffers=[]}var o=r.maxAttributes,s=Array(o);for(r=0;r<o;++r)s[r]=new A;var c=0,u={},f={Record:A,scope:{},state:s,currentVAO:null,targetVAO:null,restore:e.oes_vertex_array_object?function(){e.oes_vertex_array_object&&Z(u).forEach((function(t){t.refresh()}))}:function(){},createVAO:function(t){function e(t){for(var n=0;n<r.buffers.length;++n)r.buffers[n].destroy();r.buffers.length=0,(n=r.attributes).length=t.length;for(var a=0;a<t.length;++a){var o=t[a],s=n[a]=new A;Array.isArray(o)||X(o)||l(o)?(o=i.create(o,34962,!1,!0),s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1,r.buffers.push(o)):i.getBuffer(o)?(s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1):i.getBuffer(o.buffer)?(s.buffer=i.getBuffer(o.buffer),s.size=0|(+o.size||s.buffer.dimension),s.normalized=!!o.normalized||!1,s.type=\"type\"in o?Q[o.type]:s.buffer.dtype,s.offset=0|(o.offset||0),s.stride=0|(o.stride||0),s.divisor=0|(o.divisor||0),s.state=1):\"x\"in o&&(s.x=+o.x||0,s.y=+o.y||0,s.z=+o.z||0,s.w=+o.w||0,s.state=2)}return r.refresh(),e}var r=new a;return n.vaoCount+=1,e.destroy=function(){r.destroy()},e._vao=r,e._reglType=\"vao\",e(t)},getVAO:function(t){return\"function\"==typeof t&&t._vao?t._vao:null},destroyBuffer:function(e){for(var r=0;r<s.length;++r){var n=s[r];n.buffer===e&&(t.disableVertexAttribArray(r),n.buffer=null)}},setVAO:e.oes_vertex_array_object?function(t){if(t!==f.currentVAO){var r=e.oes_vertex_array_object;t?r.bindVertexArrayOES(t.vao):r.bindVertexArrayOES(null),f.currentVAO=t}}:function(r){if(r!==f.currentVAO){if(r)r.bindAttrs();else for(var n=e.angle_instanced_arrays,i=0;i<s.length;++i){var a=s[i];a.buffer?(t.enableVertexAttribArray(i),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offfset),n&&n.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}f.currentVAO=r}},clear:e.oes_vertex_array_object?function(){Z(u).forEach((function(t){t.destroy()}))}:function(){}};return a.prototype.bindAttrs=function(){for(var r=e.angle_instanced_arrays,n=this.attributes,i=0;i<n.length;++i){var a=n[i];a.buffer?(t.enableVertexAttribArray(i),t.bindBuffer(34962,a.buffer.buffer),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offset),r&&r.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}for(r=n.length;r<o;++r)t.disableVertexAttribArray(r)},a.prototype.refresh=function(){var t=e.oes_vertex_array_object;t&&(t.bindVertexArrayOES(this.vao),this.bindAttrs(),f.currentVAO=this)},a.prototype.destroy=function(){if(this.vao){var t=e.oes_vertex_array_object;this===f.currentVAO&&(f.currentVAO=null,t.bindVertexArrayOES(null)),t.deleteVertexArrayOES(this.vao),this.vao=null}u[this.id]&&(delete u[this.id],--n.vaoCount)},f}function E(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s,l){var c;c=o(35632,r.fragId);var u=o(35633,r.vertId);if(s=r.program=t.createProgram(),t.attachShader(s,c),t.attachShader(s,u),l)for(c=0;c<l.length;++c)u=l[c],t.bindAttribLocation(s,u[0],u[1]);t.linkProgram(s),u=t.getProgramParameter(s,35718),n.profile&&(r.stats.uniformsCount=u);var f=r.uniforms;for(c=0;c<u;++c)if(l=t.getActiveUniform(s,c))if(1<l.size)for(var h=0;h<l.size;++h){var p=l.name.replace(\"[0]\",\"[\"+h+\"]\");a(f,new i(p,e.id(p),t.getUniformLocation(s,p),l))}else a(f,new i(l.name,e.id(l.name),t.getUniformLocation(s,l.name),l));for(u=t.getProgramParameter(s,35721),n.profile&&(r.stats.attributesCount=u),r=r.attributes,c=0;c<u;++c)(l=t.getActiveAttrib(s,c))&&a(r,new i(l.name,e.id(l.name),t.getAttribLocation(s,l.name),l))}var c={},u={},f={},h=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return h.forEach((function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)})),t},r.getMaxAttributesCount=function(){var t=0;return h.forEach((function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)})),t}),{clear:function(){var e=t.deleteShader.bind(t);Z(c).forEach(e),c={},Z(u).forEach(e),u={},h.forEach((function(e){t.deleteProgram(e.program)})),h.length=0,f={},r.shaderCount=0},program:function(t,e,n,i){var a=f[e];a||(a=f[e]={});var o=a[t];return o&&!i?o:(e=new s(e,t),r.shaderCount++,l(e,n,i),o||(a[t]=e),h.push(e),e)},restore:function(){c={},u={};for(var t=0;t<h.length;++t)l(h[t],null,h[t].attributes.map((function(t){return[t.location,t.name]})))},shader:o,frag:-1,vert:-1}}function C(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return X(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},(function(){r=s(t)})),r}(t):s(t)}}function L(t){return Array.prototype.slice.call(t)}function I(t){return L(t).join(\"\")}function P(){function t(){var t=[],e=[];return U((function(){t.push.apply(t,L(arguments))}),{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,L(arguments)),t.push(\";\")),n},toString:function(){return I([0<e.length?\"var \"+e.join(\",\")+\";\":\"\",I(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return U((function(){r.apply(r,L(arguments))}),{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=U(a,{arg:n,toString:function(){return I([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=I(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return U(r,{then:function(){return r.apply(r,L(arguments)),this},else:function(){return n.apply(n,L(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),I([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach((function(e){t.push('\"',e,'\":',o[e].toString(),\",\")})),t.push(\"}\");var e=I(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function z(t){return Array.isArray(t)||X(t)||l(t)}function O(t){return t.sort((function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1}))}function D(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function R(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function F(t){return new D(!1,!1,!1,t)}function B(t,e){var r=t.type;return 0===r?new D(!0,1<=(r=t.data.length),2<=r,e):4===r?new D((r=t.data).thisDep,r.contextDep,r.propDep,e):new D(3===r,2===r,1===r,e)}function N(t,e,r,n,i,o,s,l,c,u,f,h,p,d,g){function v(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=v(t);rt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=v(t);rt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach((function(t){a[t]=n.def(i,\".\",t)}));var o=t.next={},s=t.current={};Object.keys(at).forEach((function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))}));var l=t.constants={};Object.keys(st).forEach((function(t){l[t]=n.def(JSON.stringify(st[t]))})),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),F((function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r}))):F((function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"}))}if(\"framebuffer\"in n){var a=n.framebuffer;return B(a,(function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r}))}return null}function w(t,r,n){function i(t){if(t in a){var r=e.id(a[t]);return(t=F((function(){return r}))).id=r,t}if(t in o){var n=o[t];return B(n,(function(t,e){var r=t.invoke(e,n);return e.def(t.shared.strings,\".id(\",r,\")\")}))}return null}var a=t.static,o=t.dynamic,s=i(\"frag\"),l=i(\"vert\"),c=null;return R(s)&&R(l)?(c=f.program(l.id,s.id,null,n),t=F((function(t,e){return t.link(c)}))):t=new D(s&&s.thisDep||l&&l.thisDep,s&&s.contextDep||l&&l.contextDep,s&&s.propDep||l&&l.propDep,(function(t,e){var r,n,i=t.shared.shader;return r=s?s.append(t,e):e.def(i,\".\",\"frag\"),n=l?l.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")})),{frag:s,vert:l,progVar:t,program:c}}function T(t,e){function r(t,e){if(t in n){var r=0|n[t];return F((function(t,n){return e&&(t.OFFSET=r),r}))}if(t in i){var o=i[t];return B(o,(function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n}))}return e&&a?F((function(t,e){return t.OFFSET=\"0\",0})):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;z(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=F((function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null}));return e.value=t,e}if(\"elements\"in i){var r=i.elements;return B(r,(function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o}))}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return F((function(e,r){return nt[t]}))}if(\"primitive\"in i){var e=i.primitive;return B(e,(function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")}))}return a?R(a)?a.value?F((function(t,e){return e.def(t.ELEMENTS,\".primType\")})):F((function(){return 4})):new D(a.thisDep,a.contextDep,a.propDep,(function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)})):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return F((function(){return t}))}if(\"count\"in i){var e=i.count;return B(e,(function(t,r){return t.invoke(r,e)}))}return a?R(a)?a?s?new D(s.thisDep,s.contextDep,s.propDep,(function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)})):F((function(t,e){return e.def(t.ELEMENTS,\".vertCount\")})):F((function(){return-1})):new D(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,(function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")})):null}(),instances:r(\"instances\",!1),offset:s}}function k(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach((function(t){var r=n[t],a=e.id(t),s=new Z;if(z(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:wt.forEach((function(t,e){e<l.length&&(s[t]=l[e])}))}else{var c=z(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,f=0|r.stride,h=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=Q[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=h,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=f,s.divisor=r}o[t]=F((function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach((function(t){n[t]=s[t]})),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n}))})),Object.keys(a).forEach((function(t){var e=a[t];o[t]=B(e,(function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=t.constants,s=a.isBufferArgs,l=(a=a.buffer,{isStream:r.def(!1)}),c=new Z;c.state=1,Object.keys(c).forEach((function(t){l[t]=r.def(\"\"+c[t])}));var u=l.buffer,f=l.type;return r(\"if(\",s,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",a,\".createStream(\",34962,\",\",i,\");\",f,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",f,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[wt[0]],\"=\",i,\".constant;\",wt.slice(1).map((function(t){return l[t]})).join(\"=\"),\"=0;\",\"}else{\",wt.map((function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"})).join(\"\"),\"}}else{\",\"if(\",s,\"(\",i,\".buffer)){\",u,\"=\",a,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\".buffer);\",\"}\",f,'=\"type\" in ',i,\"?\",o.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",a,\".destroyStream(\",u,\");\",\"}\"),l}))})),o}function M(t,e,n,i,o){function s(t){var e=c[t];e&&(h[t]=e)}var l=function(t,e){if(\"string\"==typeof(r=t.static).frag&&\"string\"==typeof r.vert){if(0<Object.keys(e.dynamic).length)return null;var r=e.static,n=Object.keys(r);if(0<n.length&&\"number\"==typeof r[n[0]]){for(var i=[],a=0;a<n.length;++a)i.push([0|r[n[a]],n[a]]);return i}}return null}(t,e),c=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new D(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,(function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]}))}if(t in a){var c=a[t];return t=B(c,(function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]})),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new D(e.thisDep,e.contextDep,e.propDep,(function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]})):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new D(t.thisDep,t.contextDep,t.propDep,(function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r}))}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,d=_(t)),f=T(t),h=function(t,e){var r=t.static,n=t.dynamic,i={};return rt.forEach((function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=F((function(){return s}))}else if(t in n){var l=n[t];i[o]=B(l,(function(t,e){return a(t,e,t.invoke(e,l))}))}}var o=v(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e((function(t){return t}),(function(t,e,r){return r}));case\"depth.func\":return e((function(t){return Mt[t]}),(function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")}));case\"depth.range\":return e((function(t){return t}),(function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]}));case\"blend.func\":return e((function(t){return[kt[\"srcRGB\"in t?t.srcRGB:t.src],kt[\"dstRGB\"in t?t.dstRGB:t.dst],kt[\"srcAlpha\"in t?t.srcAlpha:t.src],kt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]}),(function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]}));case\"blend.equation\":return e((function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0}),(function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]}));case\"blend.color\":return e((function(t){return a(4,(function(e){return+t[e]}))}),(function(t,e,r){return a(4,(function(t){return e.def(\"+\",r,\"[\",t,\"]\")}))}));case\"stencil.mask\":return e((function(t){return 0|t}),(function(t,e,r){return e.def(r,\"|0\")}));case\"stencil.func\":return e((function(t){return[Mt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]}),(function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]}));case\"stencil.opFront\":case\"stencil.opBack\":return e((function(e){return[\"stencil.opBack\"===t?1029:1028,At[e.fail||\"keep\"],At[e.zfail||\"keep\"],At[e.zpass||\"keep\"]]}),(function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]}));case\"polygonOffset.offset\":return e((function(t){return[0|t.factor,0|t.units]}),(function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]}));case\"cull.face\":return e((function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e}),(function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)}));case\"lineWidth\":return e((function(t){return t}),(function(t,e,r){return r}));case\"frontFace\":return e((function(t){return St[t]}),(function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')}));case\"colorMask\":return e((function(t){return t.map((function(t){return!!t}))}),(function(t,e,r){return a(4,(function(t){return\"!!\"+r+\"[\"+t+\"]\"}))}));case\"sample.coverage\":return e((function(t){return[\"value\"in t?t.value:1,!!t.invert]}),(function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]}))}})),i}(t),p=w(t,0,l);s(\"viewport\"),s(v(\"scissor.box\"));var d,g=0<Object.keys(h).length;if((d={framebuffer:d,draw:f,shader:p,state:h,dirty:g,scopeVAO:null,drawVAO:null,useVAO:!1,attributes:{}}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=F((function(t,e){return n}))).enable=n}else if(\"profile\"in t){var i=t.profile;e=B(i,(function(t,e){return t.invoke(e,i)}))}return e}(t),d.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach((function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=F((function(){return n}));else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=F((function(t){return t.link(n)})):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=F((function(t){return t.link(n.color[0])})))}else m(n)&&(e=F((function(t){return t.global.def(\"[\",a(n.length,(function(t){return n[t]})),\"]\")})));e.value=n,i[t]=e})),Object.keys(n).forEach((function(t){var e=n[t];i[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),i}(n),d.drawVAO=d.scopeVAO=function(t,e){var r=t.static,n=t.dynamic;if(\"vao\"in r){var i=r.vao;return null!==i&&null===u.getVAO(i)&&(i=u.createVAO(i)),F((function(t){return t.link(u.getVAO(i))}))}if(\"vao\"in n){var a=n.vao;return B(a,(function(t,e){var r=t.invoke(e,a);return e.def(t.shared.vao+\".getVAO(\"+r+\")\")}))}return null}(t),!d.drawVAO&&p.program&&!l&&r.angle_instanced_arrays){var y=!0;if(t=p.program.attributes.map((function(t){return t=e.static[t],y=y&&!!t,t})),y&&0<t.length){var x=u.getVAO(u.createVAO(t));d.drawVAO=new D(null,null,null,(function(t,e){return t.link(x)})),d.useVAO=!0}}return l?d.useVAO=!0:d.attributes=k(e),d.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach((function(t){var r=e[t];n[t]=F((function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)}))})),Object.keys(r).forEach((function(t){var e=r[t];n[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),n}(i),d}function A(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach((function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")})),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;$&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),$&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),$&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");rt.forEach((function(e){var n,f;if(!((e=v(e))in r.state))if(e in s){n=s[e],f=o[e];var h=a(tt[e].length,(function(t){return u.def(n,\"[\",t,\"]\")}));u(t.cond(h.map((function(t,e){return t+\"!==\"+f+\"[\"+e+\"]\"})).join(\"||\")).then(i,\".\",at[e],\"(\",h,\");\",h.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\"))}else n=u.def(c,\".\",e),h=t.cond(n,\"!==\",l,\".\",e),u(h),e in it?h(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):h(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")})),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;O(Object.keys(r)).forEach((function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];R(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(m(c)){var f=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}}))}function L(t,e){K&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function I(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(h,\".count+=\",i,\";\"):t(h,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",h,\");\"))}function s(t){t(h,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",h,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,f=t.shared,h=t.stats,p=f.current,g=f.timer;if(r=r.profile){if(R(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(f=t.block()),e(\"if(\",r,\"){\",f,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map((function(t){return u+\".\"+t+\"!==\"+i[t]})).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",f,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map((function(t){return u+\".\"+t+\"=\"+i[t]+\";\"})).join(\"\"),\"}\"),K&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",u,\".buffer=null;\",\"}if(\",wt.map((function(t,e){return u+\".\"+t+\"!==\"+h[e]})).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",h,\");\",wt.map((function(t,e){return u+\".\"+t+\"=\"+h[e]+\";\"})).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var f=i.buffer,h=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach((function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Et))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach((function(t){o[t]=e.def(c,\".\",t)}))}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)}))}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var f,h=(g=i[u]).name,p=g.info.type,d=n.uniforms[h],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(R(d)){if(h=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(h._texture||h.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",h=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(h)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",m(h)?Array.prototype.slice.call(h):h,\");\")}continue}f=d.append(t,r)}else{if(!o(Et))continue;f=r.def(l.uniforms,\"[\",e.id(h),\"]\")}switch(35678===p?r(\"if(\",f,\"&&\",f,'._reglType===\"framebuffer\"){',f,\"=\",f,\".color[0];\",\"}\"):35680===p&&r(\"if(\",f,\"&&\",f,'._reglType===\"framebufferCube\"){',f,\"=\",f,\".color[0];\",\"}\"),h=1,p){case 35678:case 35680:p=r.def(f,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",h=2;break;case 35668:case 35672:s=\"3i\",h=3;break;case 35669:case 35673:s=\"4i\",h=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",h=2;break;case 35665:s=\"3f\",h=3;break;case 35666:s=\"4f\",h=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var v=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",f,\")||\",f,\" instanceof Float32Array)?\",f,\":(\",a(g,(function(t){return v+\"[\"+t+\"]=\"+f+\"[\"+t+\"]\"})),\",\",v,\")\")}else r(1<h?a(h,(function(t){return f+\"[\"+t+\"]\"})):f);r(\");\")}}function U(t,e,r,n){function i(i){var a=h[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(f,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,m,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,m]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,f=c.draw,h=n.draw,p=function(){var i=h.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),m=function(){var i=h.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"count\"),i}();if(\"number\"==typeof m){if(0===m)return}else r(\"if(\",m,\"){\"),r.exit(\"}\");K&&(s=i(\"instances\"),l=t.instancing);var v=p+\".type\",y=h.elements&&R(h.elements);K&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function V(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),K&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),r.useVAO?r.drawVAO?e(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,e),\");\"):e(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(e(t.shared.vao,\".setVAO(null);\"),N(t,e,r,n.attributes,(function(){return!0}))),j(t,e,r,n.uniforms,(function(){return!0})),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&A(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&I(t,u,r,!1,!0),n?(r.useVAO?r.drawVAO?i(r.drawVAO)?u(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,u),\");\"):c(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,c),\");\"):c(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(c(t.shared.vao,\".setVAO(null);\"),N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i)),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link((function(e){return V(G,t,r,e,2)})),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;A(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),O(Object.keys(r.state)).forEach((function(e){var n=r.state[e].append(t,i);m(n)?n.forEach((function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)})):i.set(a.next,\".\"+e,n)})),I(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach((function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))})),Object.keys(r.uniforms).forEach((function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))})),Object.keys(r.attributes).forEach((function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach((function(t){i.set(a,\".\"+t,n[t])}))})),r.scopeVAO&&i.set(a.vao,\".targetVAO\",r.scopeVAO.append(t,i)),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!m(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(q.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach((function(e){var r=n[e];if(q.isDynamic(r))\"function\"==typeof r&&(r=n[e]=q.unbox(r)),e=B(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}})),e.dynamic[r]=new q.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach((function(r){var i=n[r];q.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))}))}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var K=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},rt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:h,elements:o,buffer:i,shader:f,attributes:u.state,vao:u,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:z},st={primTypes:nt,compareFuncs:Mt,blendFuncs:kt,blendEquations:J,stencilOps:At,glTypes:Q,orientationType:St};$&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,(function(t){return 0===t?[0]:a(t,(function(t){return 36064+t}))})));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),i=t.proc(\"refresh\"),o=t.block();e(o),i(o);var s,l=t.shared,c=l.gl,u=l.next,f=l.current;o(f,\".dirty=false;\"),S(t,e),S(t,i,null,!0),K&&(s=t.link(K)),r.oes_vertex_array_object&&i(t.link(r.oes_vertex_array_object),\".bindVertexArrayOES(null);\");for(var h=0;h<n.maxAttributes;++h){var p=i.def(l.attributes,\"[\",h,\"]\"),d=t.cond(p,\".buffer\");d.then(c,\".enableVertexAttribArray(\",h,\");\",c,\".bindBuffer(\",34962,\",\",p,\".buffer.buffer);\",c,\".vertexAttribPointer(\",h,\",\",p,\".size,\",p,\".type,\",p,\".normalized,\",p,\".stride,\",p,\".offset);\").else(c,\".disableVertexAttribArray(\",h,\");\",c,\".vertexAttrib4f(\",h,\",\",p,\".x,\",p,\".y,\",p,\".z,\",p,\".w);\",p,\".buffer=null;\"),i(d),K&&i(s,\".vertexAttribDivisorANGLE(\",h,\",\",p,\".divisor);\")}return i(t.shared.vao,\".currentVAO=null;\",t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"),Object.keys(it).forEach((function(r){var n=it[r],a=o.def(u,\".\",r),s=t.block();s(\"if(\",a,\"){\",c,\".enable(\",n,\")}else{\",c,\".disable(\",n,\")}\",f,\".\",r,\"=\",a,\";\"),i(s),e(\"if(\",a,\"!==\",f,\".\",r,\"){\",s,\"}\")})),Object.keys(at).forEach((function(r){var n,s,l=at[r],h=tt[r],p=t.block();p(c,\".\",l,\"(\"),m(h)?(l=h.length,n=t.global.def(u,\".\",r),s=t.global.def(f,\".\",r),p(a(l,(function(t){return n+\"[\"+t+\"]\"})),\");\",a(l,(function(t){return s+\"[\"+t+\"]=\"+n+\"[\"+t+\"];\"})).join(\"\")),e(\"if(\",a(l,(function(t){return n+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"})).join(\"||\"),\"){\",p,\"}\")):(n=o.def(u,\".\",r),s=o.def(f,\".\",r),p(n,\");\",f,\".\",r,\"=\",n,\";\"),e(\"if(\",n,\"!==\",s,\"){\",p,\"}\")),i(p)})),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach((function(t){X(a,e,t)})),Tt.forEach((function(e){X(a,t,e)})),r=M(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),A(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),I(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{r(t.shared.vao,\".setVAO(null);\");var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link((function(r){return V(H,t,e,r,1)})),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach((function(t){i=i||e.context[t].propDep})),i||(A(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,(function(t){return!r(t)})),e.profile&&r(e.profile)||I(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{n(t.shared.vao,\".setVAO(null);\");var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link((function(r){return V(Y,t,e,r,2)})),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function j(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var U=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,q={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},H={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},G=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},Y=s();Y.zero=s();var W=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=Y.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),Y.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=Y.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),Y.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter((function(t){return!!e[t]})),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},X=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},Z=function(t){return Object.keys(t).map((function(e){return t[e]}))},J={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||Y.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],f=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,f,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},K={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},Q={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},tt=J.flatten,et=J.shape,rt=[];rt[5120]=1,rt[5122]=2,rt[5124]=4,rt[5121]=1,rt[5123]=2,rt[5125]=4,rt[5126]=4;var nt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},it=new Float32Array(1),at=new Uint32Array(it.buffer),ot=[9984,9986,9985,9987],st=[0,6409,6410,6407,6408],lt={};lt[6409]=lt[6406]=lt[6402]=1,lt[34041]=lt[6410]=2,lt[6407]=lt[35904]=3,lt[6408]=lt[35906]=4;var ct=v(\"HTMLCanvasElement\"),ut=v(\"OffscreenCanvas\"),ft=v(\"CanvasRenderingContext2D\"),ht=v(\"ImageBitmap\"),pt=v(\"HTMLImageElement\"),dt=v(\"HTMLVideoElement\"),gt=Object.keys(K).concat([ct,ut,ft,ht,pt,dt]),mt=[];mt[5121]=1,mt[5126]=4,mt[36193]=2,mt[5123]=2,mt[5125]=4;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[34041]=4,vt[33776]=.5,vt[33777]=.5,vt[33778]=1,vt[33779]=1,vt[35986]=.5,vt[35987]=1,vt[34798]=1,vt[35840]=.5,vt[35841]=.25,vt[35842]=.5,vt[35843]=.25,vt[36196]=.5;var yt=[];yt[32854]=2,yt[32855]=2,yt[36194]=2,yt[33189]=2,yt[36168]=1,yt[34041]=4,yt[35907]=4,yt[34836]=16,yt[34842]=8,yt[34843]=6;var xt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach((function(t){l[s[t]]=t}));var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height||(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height)),o},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){Z(u).forEach(o)},restore:function(){Z(u).forEach((function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)})),t.bindRenderbuffer(36161,null)}}},bt=[];bt[6408]=4,bt[6407]=3;var _t=[];_t[5121]=1,_t[5126]=4,_t[36193]=2;var wt=[\"x\",\"y\",\"z\",\"w\"],Tt=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),kt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},Mt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},At={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},St={cw:2304,ccw:2305},Et=new D(!1,!1,!1,(function(){}));return function(t){function e(){if(0===J.length)w&&w.update(),tt=null;else{tt=H.next(e),f();for(var t=J.length-1;0<=t;--t){var r=J[t];r&&r(I,null,0)}m.flush(),w&&w.update()}}function r(){!tt&&0<J.length&&(tt=H.next(e))}function n(){tt&&(H.cancel(e),tt=null)}function a(t){t.preventDefault(),n(),K.forEach((function(t){t()}))}function o(t){m.getError(),y.restore(),R.restore(),z.restore(),F.restore(),B.restore(),V.restore(),O.restore(),w&&w.restore(),Y.procs.refresh(),r(),Q.forEach((function(t){t()}))}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach((function(n){var i=t[n];q.isDynamic(i)?r[n]=q.unbox(i,n):e[n]=i})),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach((function(n){r[t+\".\"+n]=e[n]}))}}var r=U({},t);return delete r.uniforms,delete r.attributes,delete r.context,delete r.vao,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),\"vao\"in t&&(r.vao=t.vao),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=Y.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return U((function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}}),{stats:t})}function l(t,e){var r=0;Y.procs.poll();var n=e.color;n&&(m.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(m.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(m.clearStencil(0|e.stencil),r|=1024),m.clear(r)}function c(t){return J.push(t),r(),{cancel:function(){var e=j(J,t);J[e]=function t(){var e=j(J,t);J[e]=J[J.length-1],--J.length,0>=J.length&&n()}}}}function u(){var t=X.viewport,e=X.scissor_box;t[0]=t[1]=e[0]=e[1]=0,I.viewportWidth=I.framebufferWidth=I.drawingBufferWidth=t[2]=e[2]=m.drawingBufferWidth,I.viewportHeight=I.framebufferHeight=I.drawingBufferHeight=t[3]=e[3]=m.drawingBufferHeight}function f(){I.tick+=1,I.time=g(),u(),Y.procs.poll()}function h(){u(),Y.procs.refresh(),w&&w.update()}function g(){return(G()-T)/1e3}if(!(t=i(t)))return null;var m=t.gl,v=m.getContextAttributes();m.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach((function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)}))}}}(m,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={vaoCount:0,bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var f=(n=s[r]).startQueryIndex;u=n.endQueryIndex;n.sum+=l[u]-l[f],f=c[f],(u=c[u])===f?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=f,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),T=G(),A=m.drawingBufferWidth,L=m.drawingBufferHeight,I={tick:0,time:0,viewportWidth:A,viewportHeight:L,framebufferWidth:A,framebufferHeight:L,drawingBufferWidth:A,drawingBufferHeight:L,pixelRatio:t.pixelRatio},P=W(m,_),z=p(m,b,t,(function(t){return O.destroyBuffer(t)})),O=S(m,_,P,b,z),D=d(m,_,z,b),R=E(m,x,b,t),F=k(m,_,P,(function(){Y.procs.poll()}),I,b,t),B=xt(m,_,0,b,t),V=M(m,_,P,F,B,b),Y=N(m,x,_,P,z,D,0,V,{},O,R,{elements:null,primitive:4,count:-1,offset:0,instances:-1},I,w,t),X=(x=C(m,V,Y.procs.poll,I),Y.next),Z=m.canvas,J=[],K=[],Q=[],$=[t.onDestroy],tt=null;Z&&(Z.addEventListener(\"webglcontextlost\",a,!1),Z.addEventListener(\"webglcontextrestored\",o,!1));var et=V.setFBO=s({framebuffer:q.define.call(null,1,\"framebuffer\")});return h(),v=U(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)et(U({framebuffer:t.framebuffer.faces[e]},t),l);else et(t,l);else l(0,t)},prop:q.define.bind(null,1),context:q.define.bind(null,2),this:q.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:F.create2D,cube:F.createCube,renderbuffer:B.create,framebuffer:V.create,framebufferCube:V.createCube,vao:O.createVAO,attributes:v,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=K;break;case\"restore\":r=Q;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:P,hasExtension:function(t){return 0<=P.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){J.length=0,n(),Z&&(Z.removeEventListener(\"webglcontextlost\",a),Z.removeEventListener(\"webglcontextrestored\",o)),R.clear(),V.clear(),B.clear(),F.clear(),D.clear(),z.clear(),O.clear(),w&&w.clear(),$.forEach((function(t){t()}))},_gl:m,_refresh:h,poll:function(){f(),w&&w.update()},now:g,stats:b}),t.onDone(null,v),v}}))},{}],541:[function(t,e,r){\n",
       "/*!\n",
       " * repeat-string <https://github.com/jonschlinkert/repeat-string>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT License.\n",
       " */\n",
       "\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],542:[function(t,e,r){(function(t){(function(){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],543:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i];(l=o-((r=a+o)-a))&&(t[--n]=r,r=l)}var s=0;for(i=n;i<e;++i){var l;a=t[i];(l=(o=r)-((r=a+o)-a))&&(t[s++]=l)}return t[s++]=r,t.length=s,t}},{}],544:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(s(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(l(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;f.length<6;)f.push(u(f.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<6;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,f.concat([f,u])),n=0;n<f.length;++n)e.exports[n]=f[n]}()},{\"robust-compress\":543,\"robust-scale\":550,\"robust-sum\":553,\"two-product\":582}],545:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":553,\"two-product\":582}],546:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return c(e,t)}function u(t){if(2===t.length)return[[\"diff(\",c(t[0][0],t[1][1]),\",\",c(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(u(s(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return l(r)}function h(t){for(var e=[],r=[],c=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),h=0;h<t;++h)c[0][h]=\"1\",c[t-1][h]=\"w\"+h;for(h=0;h<t;++h)0==(1&h)?e.push.apply(e,u(s(c,h))):r.push.apply(r,u(s(c,h)));var p=l(e),d=l(r),g=\"exactInSphere\"+t,m=[];for(h=0;h<t;++h)m.push(\"m\"+h);var v=[\"function \",g,\"(\",m.join(),\"){\"];for(h=0;h<t;++h){v.push(\"var w\",h,\"=\",f(h,t),\";\");for(var y=0;y<t;++y)y!==h&&v.push(\"var w\",h,\"m\",y,\"=scale(w\",h,\",m\",y,\"[0]);\")}return v.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",v.join(\"\"))(i,a,n,o)}var p=[function(){return 0},function(){return 0},function(){return 0}];function d(t){var e=p[t.length];return e||(e=p[t.length]=h(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=6;)p.push(h(p.length));for(var t=[],r=[\"slow\"],n=0;n<=6;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=6;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=6;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],547:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\");function i(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var a=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;a.length<6;)a.push(i(a.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<6;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var o=Function.apply(void 0,t);for(e.exports=o.apply(void 0,a.concat([a,i])),n=0;n<6;++n)e.exports[n]=a[n]}()},{\"robust-determinant\":544}],548:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(c(s(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function u(t){for(var e=[],r=[],u=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),f=[],h=0;h<t;++h)0==(1&h)?e.push.apply(e,c(s(u,h))):r.push.apply(r,c(s(u,h))),f.push(\"m\"+h);var p=l(e),d=l(r),g=\"orientation\"+t+\"Exact\",m=[\"function \",g,\"(\",f.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",m)(i,n,a,o)}var f=u(3),h=u(4),p=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=33306690738754716e-32*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],f=e[2]-n[2],p=r[2]-n[2],d=a*c,g=o*l,m=o*s,v=i*c,y=i*l,x=a*s,b=u*(d-g)+f*(m-v)+p*(y-x),_=7771561172376103e-31*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(m)+Math.abs(v))*Math.abs(f)+(Math.abs(y)+Math.abs(x))*Math.abs(p));return b>_||-b>_?b:h(t,e,r,n)}];function d(t){var e=p[t.length];return e||(e=p[t.length]=u(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=5;)p.push(u(p.length));for(var t=[],r=[\"slow\"],n=0;n<=5;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=5;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=5;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],549:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":550,\"robust-sum\":553}],550:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var f=s[1];i(f,l[0],s),s[0]&&(o[c++]=s[0]);var h=l[1],p=s[1],d=h+p,g=p-(d-h);s[1]=d,g&&(o[c++]=g)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":582,\"two-sum\":583}],551:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],f=Math.min(c,u);if(Math.max(c,u)<s||l<f)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],552:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=-e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],553:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],554:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],555:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":100,\"reduce-simplicial-complex\":533}],556:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],f=(e=u.length,0);f<e;++f)for(var h=0;h<f;++h){var p=u[h],d=u[f];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));var g=2;for(c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var f=o[2*u],h=o[2*u+1];if(r[f]!==r[h]){var p=e[f],d=e[h];o[2*c]=f,o[2*c+1]=h,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),f=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),h=o(s)(t,c.data,f,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(f),{cells:h,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":557,ndarray:495,\"ndarray-sort\":494,\"typedarray-pool\":595}],557:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");var u=[];for(s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":474,\"typedarray-pool\":595}],558:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var f=e.slice(0);f.sort();for(var h=0;h<r;++h)if(n=u[h]-f[h])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],f=u.length,h=1,p=1<<f;h<p;++h){s.length=n.popCount(h);for(var d=0,g=0;g<f;++g)h&1<<g&&(s[d++]=u[g]);var m=c(t,s);if(!(m<0))for(;r[m++].push(i),!(m>=t.length||0!==a(t[m],s)););}return r}function f(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,f=0;f<o.length;++f)l&1<<f&&(c[u++]=o[f]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(f(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=f,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(f(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),h=o+1;h<a.length;++h)r.link(u,c(e,[a[h]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":97,\"union-find\":596}],559:[function(t,e,r){arguments[4][97][0].apply(r,arguments)},{dup:97}],560:[function(t,e,r){arguments[4][558][0].apply(r,arguments)},{\"bit-twiddle\":559,dup:558,\"union-find\":561}],561:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],562:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),f=0;f<a;++f)s[f]=l[f]=-1,c[f]=1/0,u[f]=!1;for(f=0;f<o;++f){var h=t[f];if(2!==h.length)throw new Error(\"Input must be a graph\");var p=h[1],d=h[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,f=s[t],h=l[t];return f<0||h<0?1/0:(r=e[t],i=e[f],a=e[h],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function m(t,e){var r=k[t],n=k[e];k[t]=n,k[e]=r,M[r]=e,M[n]=t}function v(t){return c[k[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=v(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<A){var o=v(n);o<r&&(a=n,r=o)}if(i<A)v(i)<r&&(a=i);if(a===t)return t;m(t,a),t=a}}function b(t){for(var e=v(t);t>0;){var r=y(t);if(r>=0)if(e<v(r)){m(t,r),t=r;continue}return t}}function _(){if(A>0){var t=k[0];return m(0,A-1),A-=1,x(0),t}return-1}function w(t,e){var r=k[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((A+=1)-1))}function T(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),M[e]>=0&&w(M[e],g(e)),M[r]>=0&&w(M[r],g(r))}}var k=[],M=new Array(a);for(f=0;f<a;++f){(c[f]=g(f))<1/0?(M[f]=k.length,k.push(f)):M[f]=-1}var A=k.length;for(f=A>>1;f>=0;--f)x(f);for(;;){var S=_();if(S<0||c[S]>r)break;T(S)}var E=[];for(f=0;f<a;++f)u[f]||(M[f]=E.length,E.push(e[f].slice()));E.length;function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var L=[];return t.forEach((function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=M[e],i=M[r];n!==i&&L.push([n,i])}})),i.unique(i.normalize(L)),{positions:E,edges:L}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":548,\"simplicial-complex\":560}],563:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var f=n(i,r,a);return f||((f=n(i,r,o))||o-i)}},{\"robust-orientation\":548}],564:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],565:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new f(l[0][0],l,c,a),n[2*a+1]=new f(l[1][0],l,!c,a)}n.sort((function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))}));var h=i(o),p=[],d=[],g=[];for(a=0;a<r;){for(var m=n[a].x,v=[];a<r;){var y=n[a];if(y.x!==m)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(v.push(new u(y.segment[0][1],y.index,!0,!0)),v.push(new u(y.segment[1][1],y.index,!1,!1))):(v.push(new u(y.segment[1][1],y.index,!0,!1)),v.push(new u(y.segment[0][1],y.index,!1,!0)))):h=y.create?h.insert(y.segment,y.index):h.remove(y.segment)}p.push(h.root),d.push(m),g.push(v)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function f(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var f=this.horizontal[e];if(f.length>0){var h=n.ge(f,t[1],l);if(h<f.length){var p=f[h];if(t[1]===p.y){if(p.closed)return p.index;for(;h<f.length-1&&f[h+1].y===t[1];)if((p=f[h+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((h+=1)>=f.length)return i;p=f[h]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":563,\"binary-search-bounds\":564,\"functional-red-black-tree\":247,\"robust-orientation\":548}],566:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var f=o(s,u,l,i);r.push(f),n.push(f.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":545,\"robust-sum\":553}],567:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(t){return i(o(t),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}function i(r,n){var i,a,o,s,l,c,u,f,h,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(f=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||f&&!s.sign?h=\"\":(h=f?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(h+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?h+i+l:\"0\"===c?h+l+i:l+h+i)}return g}var a=Object.create(null);function o(e){if(a[e])return a[e];for(var r,n=e,i=[],o=0;n;){if(null!==(r=t.text.exec(n)))i.push(r[0]);else if(null!==(r=t.modulo.exec(n)))i.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");i.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return a[e]=i}\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],568:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map((function(t){return 1===t.length&&(t+=t),t})));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:503}],569:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,f=[],h=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){var m=[],v=[],y=0;for(d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,m.push(x),v.push(s[x]),y+=s[x].length,o[x]=f.length,x===e){l.length=d;break}}f.push(m);var b=new Array(y);for(d=0;d<v.length;d++)for(var _=0;_<v[d].length;_++)b[--y]=v[d][_];h.push(b)}c.pop()}}}for(l=0;l<e;++l)r[l]<0&&p(l);for(l=0;l<h.length;l++){var d=h[l];if(0!==d.length){d.sort((function(t,e){return t-e})),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);h[l]=c}}return{components:f,adjacencyList:h}}},{}],570:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r];e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");var u=[];for(c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var f=[],h=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),h=a):a.push(\"switch(m>>>7){\");for(c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){f.length>0&&h.push(\"}}\");var p=\"vExtra\"+f.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),h=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],f.push(h)}h.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),m=new Array(r),v=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],m[x]=0,v[x]=0;for(x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),m[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),m[b]-=2),y+=1;for(var T=0;T<r;++T)T!==b&&(_&1<<T?v[T]+=1:v[T]-=1)}}var k=[];for(b=0;b<r;++b)if(0===d[b].length)k.push(\"d\"+b+\"-0.5\");else{var M=\"\";m[b]<0?M=m[b]+\"*c\":m[b]>0&&(M=\"+\"+m[b]+\"*c\");var A=d[b].length/y*.5,S=.5+v[b]/y*.5;k.push(\"d\"+b+\"-\"+S+\"-\"+A+\"*(\"+d[b].join(\"+\")+M+\")/(\"+g[b].join(\"+\")+\")\")}h.push(\"a.push([\",k.join(),\"]);\",\"break;\")}a.push(\"}},\"),f.length>0&&h.push(\"}}\");var E=[];for(c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map((function(t){return\"[\"+t.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}else{b.push(\",C.map((function(t){var e=t.slice();return e.reverse(),\"[\"+e.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(c=0;c<f.length;++c)a.push(f[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":487,\"triangulate-hypercube\":580,\"zero-crossings\":624}],571:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")},i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=1.5707963267948966===e?.551915024494:-1.5707963267948966===e?-.551915024494:4/3*Math.tan(e/4),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*r+e*n;return i>1&&(i=1),i<-1&&(i=-1),(t*n-e*r<0?-1:1)*Math.acos(i)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,f=t.ry,h=t.xAxisRotation,p=void 0===h?0:h,d=t.largeArcFlag,g=void 0===d?0:d,m=t.sweepFlag,v=void 0===m?0:m,y=[];if(0===u||0===f)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),f=Math.abs(f);var T=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(f,2);T>1&&(u*=Math.sqrt(T),f*=Math.sqrt(T));var k=function(t,e,r,n,a,o,l,c,u,f,h,p){var d=Math.pow(a,2),g=Math.pow(o,2),m=Math.pow(h,2),v=Math.pow(p,2),y=d*g-d*v-g*m;y<0&&(y=0),y/=d*v+g*m;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*h,_=f*x-u*b+(t+r)/2,w=u*x+f*b+(e+n)/2,T=(h-x)/a,k=(p-b)/o,M=(-h-x)/a,A=(-p-b)/o,S=s(1,0,T,k),E=s(T,k,M,A);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,f,g,v,x,b,_,w),M=n(k,4),A=M[0],S=M[1],E=M[2],C=M[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var I=Math.max(Math.ceil(L),1);C/=I;for(var P=0;P<I;P++)y.push(o(E,C)),E+=C;return y.map((function(t){var e=a(t[0],u,f,b,x,A,S),r=e.x,n=e.y,i=a(t[1],u,f,b,x,A,S),o=i.x,s=i.y,l=a(t[2],u,f,b,x,A,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}}))},e.exports=r.default},{}],572:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":65,assert:73,\"is-svg-path\":471,\"normalize-svg-path\":573,\"parse-svg-path\":505}],573:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,f=null,h=0,p=0,d=0,g=t.length;d<g;d++){var m=t[d],v=m[0];switch(v){case\"M\":l=m[1],c=m[2];break;case\"A\":var y=n({px:h,py:p,cx:m[6],cy:m[7],rx:m[1],ry:m[2],xAxisRotation:m[3],largeArcFlag:m[4],sweepFlag:m[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],m=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(m);break;case\"S\":var _=h,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),m=[\"C\",_,w,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*h-u,f=2*p-f):(u=h,f=p),m=a(h,p,u,f,m[1],m[2]);break;case\"Q\":u=m[1],f=m[2],m=a(h,p,m[1],m[2],m[3],m[4]);break;case\"L\":m=i(h,p,m[1],m[2]);break;case\"H\":m=i(h,p,m[1],p);break;case\"V\":m=i(h,p,h,m[1]);break;case\"Z\":m=i(h,p,l,c)}e=v,h=m[m.length-2],p=m[m.length-1],m.length>4?(o=m[m.length-4],s=m[m.length-3]):(o=h,s=p),r.push(m)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":571}],574:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,f;e.shape?(r=e.shape[0],f=e.shape[1]):(r=c.width=e.w||e.width||200,f=c.height=e.h||e.height||200);var h=Math.min(r,f),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),f/(d[3]-d[1])],m=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,f),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*f),u.scale(m,m),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var v=new Path2D(t);u.fill(v),p&&u.stroke(v)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*h})}},{\"bitmap-sdf\":98,\"draw-svg-path\":174,\"is-svg-path\":471,\"parse-svg-path\":505,\"svg-path-bounds\":572}],575:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function t(e,r,i){i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,f=0,h=0;h<l.length;++h)c[h]=t(e,l[h]),u+=c[h].data.length,f+=c[h].shape,h>0&&(f+=.02);var p=new Float32Array(u),d=0,g=-.5*f;for(h=0;h<c.length;++h){for(var m=c[h].data,v=0;v<m.length;v+=2)p[d++]=m[v]+g,p[d++]=m[v+1];g+=c[h].shape+.02}s=o[r]={data:p,shape:f}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this)}).call(this,t(\"_process\"))},{_process:526,\"vectorize-text\":600}],576:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,f=!1,h=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},f=!0,h=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=O(e.s),c=O(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),f=!0,h=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=O(e.s),u=O(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),f=!0,h=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:f,format:e.format||h,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function f(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function h(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=I(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=I(r.s),c(r)}function m(t){return c(t).desaturate(100)}function v(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=I(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=I(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function M(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function A(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=f(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=f(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return h(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[h(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(v,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(m,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(M,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(A,arguments)},splitcomplement:function(){return this._applyCombination(k,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(T,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:O(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function I(t){return o(1,s(0,t))}function P(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function O(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return P(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],577:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],578:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=a;function i(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*a(r[1],t)}function a(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=i(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return i(e,\"font-size\");case\"rem\":return i(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return 96;case\"cm\":return 96/2.54;case\"mm\":return 96/25.4;case\"pt\":return 96/72;case\"pc\":return 16}return 1}},{\"parse-unit\":506}],579:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).topojson=t.topojson||{})}(this,(function(t){\"use strict\";function e(t){return t}function r(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c);for(u[0]=(r+=t[0])*i+o,u[1]=(n+=t[1])*a+s;l<c;)u[l]=t[l],++l;return u}}function n(t){var e,n=r(t.transform),i=1/0,a=i,o=-i,s=-i;function l(t){(t=n(t))[0]<i&&(i=t[0]),t[0]>o&&(o=t[0]),t[1]<a&&(a=t[1]),t[1]>s&&(s=t[1])}function c(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(c);break;case\"Point\":l(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(l)}}for(e in t.arcs.forEach((function(t){for(var e,r=-1,l=t.length;++r<l;)(e=n(t[r],r))[0]<i&&(i=e[0]),e[0]>o&&(o=e[0]),e[1]<a&&(a=e[1]),e[1]>s&&(s=e[1])})),t.objects)c(t.objects[e]);return[i,a,o,s]}function i(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,o=a(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:o}:null==n?{type:\"Feature\",id:r,properties:i,geometry:o}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:o}}function a(t,e){var n=r(t.transform),i=t.arcs;function a(t,e){e.length&&e.pop();for(var r=i[t<0?~t:t],a=0,o=r.length;a<o;++a)e.push(n(r[a],a));t<0&&function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r}(e,o)}function o(t){return n(t)}function s(t){for(var e=[],r=0,n=t.length;r<n;++r)a(t[r],e);return e.length<2&&e.push(e[0]),e}function l(t){for(var e=s(t);e.length<4;)e.push(e[0]);return e}function c(t){return t.map(l)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=o(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(o);break;case\"LineString\":r=s(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(s);break;case\"Polygon\":r=c(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(c);break;default:return null}return{type:n,coordinates:r}}(e)}function o(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach((function(t){r[t<0?~t:t]=1})),a.push(i)}}return e.forEach((function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)})),e.forEach((function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach((function(t){r[0]+=t[0],r[1]+=t[1]}))):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r})),s(i,n),s(n,i),e.forEach((function(t){r[t<0?~t:t]||a.push([t])})),a}function s(t,e,r){var n,i,a;if(arguments.length>1)n=l(t,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:o(t,n)}}function l(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":!function(t){t.forEach(l)}(e.arcs)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}function c(t,e){var r={},n=[],i=[];function s(t){t.forEach((function(e){e.forEach((function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)}))})),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(a(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach((function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":s(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(s)}})),n.forEach((function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].forEach((function(t){t._||(t._=1,n.push(t))}))}))}))}})),n.forEach((function(t){delete t._})),{type:\"MultiPolygon\",arcs:i.map((function(e){var n,i=[];if(e.forEach((function(t){t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].length<2&&i.push(t)}))}))})),(n=(i=o(t,i)).length)>1)for(var a,s,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(s=i[0],i[0]=i[c],i[c]=s,u=a);return i})).filter((function(t){return t.length>0}))}}function u(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r}function f(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c),f=Math.round((t[0]-o)/i),h=Math.round((t[1]-s)/a);for(u[0]=f-r,r=f,u[1]=h-n,n=h;l<c;)u[l]=t[l],++l;return u}}t.bbox=n,t.feature=function(t,e){return\"string\"==typeof e&&(e=t.objects[e]),\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map((function(e){return i(t,e)}))}:i(t,e)},t.merge=function(t){return a(t,c.apply(this,arguments))},t.mergeArcs=c,t.mesh=function(t){return a(t,s.apply(this,arguments))},t.meshArcs=s,t.neighbors=function(t){var e={},r=t.map((function(){return[]}));function n(t,r){t.forEach((function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]}))}function i(t,e){t.forEach((function(t){n(t,e)}))}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach((function(t){i(t,e)}))}};for(var o in t.forEach((function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach((function(e){t(e,r)})):e.type in a&&a[e.type](e.arcs,r)})),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var f=c+1;f<l;++f){var h,p=s[c],d=s[f];(h=r[p])[o=u(h,d)]!==d&&h.splice(o,0,d),(h=r[d])[o=u(h,p)]!==p&&h.splice(o,0,p)}return r},t.quantize=function(t,e){if(t.transform)throw new Error(\"already quantized\");if(e&&e.scale)l=t.bbox;else{if(!((r=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");var r,i=(l=t.bbox||n(t))[0],a=l[1],o=l[2],s=l[3];e={scale:[o-i?(o-i)/(r-1):1,s-a?(s-a)/(r-1):1],translate:[i,a]}}var l,c,u=f(e),h=t.objects,p={};function d(t){return u(t)}function g(t){var e;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(g)};break;case\"Point\":e={type:\"Point\",coordinates:d(t.coordinates)};break;case\"MultiPoint\":e={type:\"MultiPoint\",coordinates:t.coordinates.map(d)};break;default:return t}return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),null!=t.properties&&(e.properties=t.properties),e}for(c in h)p[c]=g(h[c]);return{type:\"Topology\",bbox:l,transform:e,objects:p,arcs:t.arcs.map((function(t){var e,r=0,n=1,i=t.length,a=new Array(i);for(a[0]=u(t[0],0);++r<i;)((e=u(t[r],r))[0]||e[1])&&(a[n++]=e);return 1===n&&(a[n++]=[0,0]),a.length=n,a}))}},t.transform=r,t.untransform=f,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],580:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:248,\"permutation-parity\":509,\"permutation-rank\":510}],581:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||f(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=f(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,m=l(n,d)/i;u=Math.acos(g),a=Math.acos(m)}return i=Math.log(i),new h(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function f(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function h(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=h.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var f=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=f;var h=this.computedToward;o(h,e,r),s(h,h);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],m=Math.cos(d),v=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=m*y,w=v*y,T=x,k=-m*x,M=-v*x,A=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*h[a]+T*e[a];E[4*a+1]=k*r[a]+M*h[a]+A*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],I=E[5],P=E[9],z=E[2],O=E[6],D=E[10],R=I*D-P*O,F=P*z-L*D,B=L*O-I*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=c(u-=a*p,f-=o*p,h-=s*p),g=(u/=d)*e+a*r,m=(f/=d)*e+o*r,v=(h/=d)*e+s*r;this.center.move(t,g,m,v);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],f=e[a+8];if(n){var h=Math.abs(s),p=Math.abs(l),d=Math.abs(f),g=Math.max(h,p,d);h===g?(s=s<0?-1:1,l=f=0):d===g?(f=f<0?-1:1,s=l=0):(l=l<0?-1:1,s=f=0)}else{var m=c(s,l,f);s/=m,l/=m,f/=m}var v,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*f,T=c(x-=s*w,b-=l*w,_-=f*w),k=l*(_/=T)-f*(b/=T),M=f*(x/=T)-s*_,A=s*b-l*x,S=c(k,M,A);if(k/=S,M/=S,A/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,f),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],I=E*x+C*b+L*_,P=E*k+C*M+L*A;v=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(P,I)}else{var z=e[2],O=e[6],D=e[10],R=z*s+O*l+D*f,F=z*x+O*b+D*_,B=z*k+O*M+D*A;v=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,v),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],f=e[1]-r[1],h=e[2]-r[2],p=c(l,f,h);if(!(p<1e-6)){l/=p,f/=p,h/=p;var d=this.computedRight,g=d[0],m=d[1],v=d[2],y=i*g+a*m+o*v,x=c(g-=y*i,m-=y*a,v-=y*o);if(!(x<.01&&(x=c(g=a*h-o*f,m=o*l-i*h,v=i*f-a*l))<1e-6)){g/=x,m/=x,v/=x,this.up.set(t,i,a,o),this.right.set(t,g,m,v),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*v-o*m,_=o*g-i*v,w=i*m-a*g,T=c(b,_,w),k=i*l+a*f+o*h,M=g*l+m*f+v*h,A=(b/=T)*l+(_/=T)*f+(w/=T)*h,S=Math.asin(u(k)),E=Math.atan2(A,M),C=this.angle._state,L=C[C.length-1],I=C[C.length-2];L%=2*Math.PI;var P=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),O=Math.abs(L-2*Math.PI-E);P<z&&(L+=2*Math.PI),O<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,I),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":242,\"gl-mat4/invert\":293,\"gl-mat4/rotate\":299,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/normalize\":387}],582:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,f=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=f,r[1]=i,r;return[f,i]};var n=+(Math.pow(2,27)+1)},{}],583:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],584:[function(t,e,r){\"use strict\";var n=t(\"../prototype/is\");e.exports=function(t){if(\"function\"!=typeof t)return!1;if(!hasOwnProperty.call(t,\"length\"))return!1;try{if(\"number\"!=typeof t.length)return!1;if(\"function\"!=typeof t.call)return!1;if(\"function\"!=typeof t.apply)return!1}catch(t){return!1}return!n(t)}},{\"../prototype/is\":591}],585:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=t(\"../string/coerce\"),o=t(\"./to-short-string\"),s=function(t,e){return t.replace(\"%v\",o(e))};e.exports=function(t,e,r){if(!i(r))throw new TypeError(s(e,t));if(!n(t)){if(\"default\"in r)return r.default;if(r.isOptional)return null}var o=a(r.errorMessage);throw n(o)||(o=e),new TypeError(s(o,t))}},{\"../object/is\":588,\"../string/coerce\":592,\"../value/is\":594,\"./to-short-string\":587}],586:[function(t,e,r){\"use strict\";e.exports=function(t){try{return t.toString()}catch(e){try{return String(t)}catch(t){return null}}}},{}],587:[function(t,e,r){\"use strict\";var n=t(\"./safe-to-string\"),i=/[\\n\\r\\u2028\\u2029]/g;e.exports=function(t){var e=n(t);return null===e?\"<Non-coercible to string value>\":(e.length>100&&(e=e.slice(0,99)+\"\\u2026\"),e=e.replace(i,(function(t){switch(t){case\"\\n\":return\"\\\\n\";case\"\\r\":return\"\\\\r\";case\"\\u2028\":return\"\\\\u2028\";case\"\\u2029\":return\"\\\\u2029\";default:throw new Error(\"Unexpected character\")}})))}},{\"./safe-to-string\":586}],588:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i={object:!0,function:!0,undefined:!0};e.exports=function(t){return!!n(t)&&hasOwnProperty.call(i,typeof t)}},{\"../value/is\":594}],589:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"%v is not a plain function\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":590}],590:[function(t,e,r){\"use strict\";var n=t(\"../function/is\"),i=/^\\s*class[\\s{/}]/,a=Function.prototype.toString;e.exports=function(t){return!!n(t)&&!i.test(a.call(t))}},{\"../function/is\":584}],591:[function(t,e,r){\"use strict\";var n=t(\"../object/is\");e.exports=function(t){if(!n(t))return!1;try{return!!t.constructor&&t.constructor.prototype===t}catch(t){return!1}}},{\"../object/is\":588}],592:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=Object.prototype.toString;e.exports=function(t){if(!n(t))return null;if(i(t)){var e=t.toString;if(\"function\"!=typeof e)return null;if(e===a)return null}try{return\"\"+t}catch(t){return null}}},{\"../object/is\":588,\"../value/is\":594}],593:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"Cannot use %v\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":594}],594:[function(t,e,r){\"use strict\";e.exports=function(t){return null!=t}},{}],595:[function(t,e,r){(function(e){(function(){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"dup\"),a=t(\"buffer\").Buffer;e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),BIGUINT64:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),BIGINT64:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=e.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=i([32,0])),c.BIGUINT64||(c.BIGUINT64=i([32,0])),c.BIGINT64||(c.BIGINT64=i([32,0])),c.BUFFER||(c.BUFFER=i([32,0]));var u=c.DATA,f=c.BUFFER;function h(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function g(t){return new Uint16Array(p(2*t),0,t)}function m(t){return new Uint32Array(p(4*t),0,t)}function v(t){return new Int8Array(p(t),0,t)}function y(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function b(t){return new Float32Array(p(4*t),0,t)}function _(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function M(t){return new DataView(p(t),0,t)}function A(t){t=n.nextPow2(t);var e=n.log2(t),r=f[e];return r.length>0?r.pop():new a(t)}r.free=function(t){if(a.isBuffer(t))f[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeBigUint64=r.freeInt8=r.freeInt16=r.freeInt32=r.freeBigInt64=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){h(t.buffer)},r.freeArrayBuffer=h,r.freeBuffer=function(t){f[n.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return g(t);case\"uint32\":return m(t);case\"int8\":return v(t);case\"int16\":return y(t);case\"int32\":return x(t);case\"float\":case\"float32\":return b(t);case\"double\":case\"float64\":return _(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return A(t);case\"data\":case\"dataview\":return M(t);default:return null}return null},r.mallocArrayBuffer=p,r.mallocUint8=d,r.mallocUint16=g,r.mallocUint32=m,r.mallocInt8=v,r.mallocInt16=y,r.mallocInt32=x,r.mallocFloat32=r.mallocFloat=b,r.mallocFloat64=r.mallocDouble=_,r.mallocUint8Clamped=w,r.mallocBigUint64=T,r.mallocBigInt64=k,r.mallocDataView=M,r.mallocBuffer=A,r.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,f[t].length=0}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"bit-twiddle\":97,buffer:111,dup:176}],596:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],597:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],598:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],599:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],600:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":601}],601:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter((function(t){return t})).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",h(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(p=0;p<r.length;++p)l[p]=s;!0===o.bolds&&(l=c(\"b\",\"b|\",r,l));!0===o.italics&&(l=c(\"i\",\"i|\",r,l));!0===o.superscripts&&(l=c(\"sup\",\"+1\",r,l));!0===o.subscripts&&(l=c(\"sub\",\"-1\",r,l));var u=[],f=\"\";for(p=0;p<r.length;++p)null!==l[p]&&(f+=r[p],u.push(l[p]));var h,p,d,g,m,v=f.split(\"\\n\"),y=v.length,x=Math.round(a*n),b=n,_=2*n,w=0,T=y*x+_;t.height<T&&(t.height=T);e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var k=0,M=\"\";function A(){if(\"\"!==M){var t=e.measureText(M).width;e.fillText(M,b+d,_+g),d+=t}}function S(){return Math.round(m)+\"px \"}function E(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(\"-\"),a=r.indexOf(\"-\"),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,l-s),n=n.replace(\"?px \",S())),g+=.25*x*(l-s)}if(!0===o.superscripts){var c=t.indexOf(\"+\"),u=r.indexOf(\"+\"),f=c>-1?parseInt(t[1+c]):0,h=u>-1?parseInt(r[1+u]):0;f!==h&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,h-f),n=n.replace(\"?px \",S())),g-=.25*x*(h-f)}if(!0===o.bolds){var p=t.indexOf(\"b|\")>-1,d=r.indexOf(\"b|\")>-1;!p&&d&&(n=v?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),p&&!d&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var v=t.indexOf(\"i|\")>-1,y=r.indexOf(\"i|\")>-1;!v&&y&&(n=\"italic \"+n),v&&!y&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(h=0;h<y;++h){var C=v[h]+\"\\n\";for(d=0,g=h*x,m=n,M=\"\",p=0;p<C.length;++p){var L=p+k<u.length?u[p+k]:u[u.length-1];s===L?M+=C[p]:(A(),M=C[p],void 0!==L&&(E(s,L),s=L))}A(),k+=C.length;var I=0|Math.round(d+2*b);w<I&&(w=I)}var P=w,z=_+x*y;return i(e.getImageData(0,0,P,z).data,[z,P,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=h;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\");function c(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=\"+\"===e[0]||\"-\"===e[0],c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var f=c;f<u+s;++f)if(f<c+o||f>=u)n[f]=null,r=r.substr(0,f)+\" \"+r.substr(f+1);else if(null!==n[f]){var h=n[f].indexOf(e[0]);-1===h?n[f]+=e:l&&(n[f]=n[f].substr(0,h+1)+(1+parseInt(n[f][h+1]))+n[f].substr(h+2))}var p=c+o,d=r.substr(p,u-p).indexOf(i);c=-1!==d?d:u+s}return n}function u(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function f(t,e,r,n){var i=u(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var f=0;switch(n){case\"center\":f=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":f=-o[0];break;case\"left\":case\"start\":f=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var h=0;switch(i){case\"hanging\":case\"top\":h=-a[1];break;case\"middle\":h=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":h=-3*r;break;case\"bottom\":h=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map((function(t){return[p*(t[0]+f),p*(t[1]+h)]}))}(i.positions,e,r),c=i.edges,f=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),p=new Array(h.length),d=0;d<h.length;++d){for(var g=h[d],m=new Array(g.length),v=0;v<g.length;++v){for(var y=g[v],x=new Array(y.length),b=0;b<y.length;++b)x[b]=a[y[b]].slice();f&&x.reverse(),m[v]=x}p[d]=m}return p}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function h(t,e,r){try{return f(t,e,r,!0)}catch(t){}try{return f(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:112,\"clean-pslg\":121,ndarray:495,\"planar-graph-to-polyline\":514,\"simplify-planar-graph\":562,\"surface-nets\":570}],602:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=g);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var c=new ArrayBuffer(25),u=new Uint8Array(c);crypto.getRandomValues(u),l=\"weakmap:rand:\"+Array.prototype.map.call(u,(function(t){return(t%36).toString(36)})).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return v(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return v(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return v(t),r(t)}})}();var h=!1,p=0,d=function(){this instanceof d||x();var t=[],e=[],r=p++;return Object.create(d.prototype,{get___:{value:y((function(n,i){var a,o=v(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i}))},has___:{value:y((function(e){var n=v(e);return n?r in n:t.indexOf(e)>=0}))},set___:{value:y((function(n,i){var a,o=v(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this}))},delete___:{value:y((function(n){var i,a,o=v(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0)&&(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,!0)}))}})};d.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof d||x();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new d),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new d),i.set___(t,e)}else n.set(t,e);return this},Object.create(d.prototype,{get___:{value:y((function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)}))},has___:{value:y((function(t){return n.has(t)||!!i&&i.has___(t)}))},set___:{value:y(e)},delete___:{value:y((function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e}))},permitHostObjects___:{value:y((function(t){if(t!==g)throw new Error(\"bogus call to permitHostObjects___\");a=!0}))}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=d.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=d)}function g(t){t.permitHostObjects___&&t.permitHostObjects___(g)}function m(t){return!(\"weakmap:\"==t.substr(0,\"weakmap:\".length)&&\"___\"===t.substr(t.length-3))}function v(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[l];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,l,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function y(t){return t.prototype=null,Object.freeze(t)}function x(){h||\"undefined\"==typeof console||(h=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],603:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":604}],604:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],605:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":603}],606:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":249}],607:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),f[t-f[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=h[o-h[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var f=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(f/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=f[t-f[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l;if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Lunar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Lunar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=30))throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(l=!1,a=n):(l=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:l}}s=o.day-1;var c,u=f[o.year-f[0]],p=u>>13;c=p&&(o.month>p||o.isIntercalary)?o.month:o.month-1;for(var d=0;d<c;d++){s+=u&1<<12-d?30:29}var g=h[o.year-h[0]],m=new Date(g>>9&4095,(g>>5&15)-1,(31&g)+s);return a.year=m.getFullYear(),a.month=1+m.getMonth(),a.day=m.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Solar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Solar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=31))throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var o=h[i.year-h[0]],s=i.year<<9|i.month<<5|i.day;a.year=s>=o?i.year:i.year-1,o=h[a.year-h[0]];var l,c=new Date(o>>9&4095,(o>>5&15)-1,31&o),u=new Date(i.year,i.month-1,i.day);l=Math.round((u-c)/864e5);var p,d=f[a.year-f[0]];for(p=0;p<13;p++){var g=d&1<<12-p?30:29;if(l<g)break;l-=g}var m=d>>13;!m||p<m?(a.isIntercalary=!1,a.month=1+p):p===m?(a.isIntercalary=!0,a.month=p):(a.isIntercalary=!1,a.month=p);return a.day=1+l,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),f=this.isIntercalaryMonth(c,s),h=a&&f?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);h!==u&&l.month(h)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-/](\\d?\\d)([iI]?)[-/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var f=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],h=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":621,\"object-assign\":499}],608:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":621,\"object-assign\":499}],609:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":621,\"object-assign\":499}],610:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":621,\"object-assign\":499}],611:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)||8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":621,\"object-assign\":499}],612:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":621,\"object-assign\":499}],613:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":621,\"object-assign\":499}],614:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":621,\"object-assign\":499}],615:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":621,\"object-assign\":499}],616:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2e3:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":621,\"object-assign\":499}],617:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),f=t-this.toJD(l,u,1)+1;return this.newDate(l,u,f)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":621,\"object-assign\":499}],618:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":621,\"object-assign\":499}],619:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":621,\"object-assign\":499}],620:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":621,\"object-assign\":499}],621:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,(function(e){return t[e]}))}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":499}],622:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,f=r.monthNamesShort||this.local.monthNamesShort,h=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,m=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},v=function(t,e){return e?\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]:\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=m(e);break;case\"M\":b+=v(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,f=-1,h=-1,p=-1,d=-1,g=-1,m=!1,v=!1,y=function(e,r){for(var n=1;A+n<t.length&&t.charAt(A+n)===e;)n++;return A+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(M).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,M);return M+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(M));return M+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(M,o[s].length).toLowerCase()===o[s].toLowerCase())return M+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,M)},T=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(M)):c.call(b,e.substring(M));return M+=t.length,t}return w(\"M\",c,u)},k=function(){if(e.charAt(M)!==t.charAt(A))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,M);M++},M=0,A=0;A<t.length;A++)if(v)\"'\"!==t.charAt(A)||y(\"'\")?k():v=!1;else switch(t.charAt(A)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=T();break;case\"y\":var S=A;m=!y(\"y\",2),A=S,h=x(\"y\",2);break;case\"Y\":h=x(\"Y\",2);break;case\"J\":f=x(\"J\")+.5,\".\"===e.charAt(M)&&(M++,x(\"J\"));break;case\"@\":f=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":f=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":M=e.length;break;case\"'\":y(\"'\")?k():v=!0;break;default:k()}if(M<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===h?h=this.today().year():h<100&&m&&(h+=-1===n?1900:this.today().year()-this.today().year()%100-(h<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,h,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(h,p);d>E;E=this.daysInMonth(h,p))p++,d-=E}return f>-1?this.fromJD(f):this.newDate(h,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":621,\"object-assign\":499}],623:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":151}],624:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":623}],625:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],626:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/font_attributes\":856,\"./arrow_paths\":625}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach((function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref),a=i.getRefType(e.xref),o=i.getRefType(e.yref);e._extremes={},\"range\"===a&&s(e,r),\"range\"===o&&s(e,n)}))}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],f=t[\"_\"+a+\"padminus\"],h={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+h,g=p-h,m=3*t.startarrowsize*t.arrowwidth||0,v=m+h,y=m-h;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,v),ppadminus:Math.max(f,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else v=s?v+s:v,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,v),ppadminus:Math.max(f,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./draw\":632}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,f=[],h=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?h:p:f).push(r);break}n===d&&i.visible&&\"onout\"===a&&h.push(r)}return{on:f,off:h,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),f={},h=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",h[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(f,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",h[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(f,s.getUpdateObj());return i.call(\"update\",t,{},f)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911}],629:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var f,h,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(f=a(\"arrowhead\"),h=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",f),a(\"startarrowsize\",h)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var m=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),v=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(m));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||v})}a(\"captureevents\",!!d)}},{\"../../lib\":778,\"../color\":643}],630:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,f=e._id.charAt(0),h=0;h<u.length;h++)l=u[h],c=\"annotations[\"+h+\"].\",l[f+\"ref\"]===e._id&&p(f),l[\"a\"+f+\"ref\"]===e._id&&p(\"a\"+f);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],631:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,f=[\"x\",\"y\"],h=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=f[d],m=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==m)i.getFromId(p,m)._annIndices.push(e._index);if(i.coercePosition(e,p,a,m,g,.5),u){var v=\"a\"+g,y=i.coerceRef(t,e,p,v,\"pixel\",[\"pixel\",\"paper\"]);\"pixel\"!==y&&y!==m&&(y=e[v]=\"pixel\");var x=\"pixel\"===y?h[d]:.4;i.coercePosition(e,p,a,y,v,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":626,\"./common_defaults\":629}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../plots/cartesian/axes\"),c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),p=t(\"../../lib/setcursor\"),d=t(\"../dragelement\"),g=t(\"../../plot_api/plot_template\").arrayEditor,m=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=l.getFromId(t,r.xref),i=l.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),x(t,r,e,!1,n,i)}function y(t,e,r,n,i){var a=i[r],o=i[r+\"ref\"],s=-1!==r.indexOf(\"y\"),c=\"domain\"===l.getRefType(o),u=s?n.h:n.w;return t?c?a+(s?-e:e)/t._length:t.p2r(t.r2p(a)+e):a+(s?-e:e)/u}function x(t,e,r,a,v,x){var b,_,w=t._fullLayout,T=t._fullLayout._size,k=t._context.edits;a?(b=\"annotation-\"+a,_=a+\".annotations\"):(b=\"annotation\",_=\"annotations\");var M=g(t.layout,_,e),A=M.modifyBase,S=M.modifyItem,E=M.getUpdateObj;w._infolayer.selectAll(\".\"+b+'[data-index=\"'+r+'\"]').remove();var C=\"clip\"+w._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var L={x:{},y:{}},I=+e.textangle||0,P=w._infolayer.append(\"g\").classed(b,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),z=P.append(\"g\").classed(\"annotation-text-g\",!0),O=k[e.showarrow?\"annotationTail\":\"annotationPosition\"],D=e.captureevents||k.annotationText||O,R=z.append(\"g\").style(\"pointer-events\",D?\"all\":null).call(p,\"pointer\").on(\"click\",(function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",Y(n.event))}));e.hovertext&&R.on(\"mouseover\",(function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();f.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:w._hoverlayer.node(),outerContainer:w._paper.node(),gd:t})})).on(\"mouseout\",(function(){f.loneUnhover(w._hoverlayer.node())}));var F=e.borderwidth,B=e.borderpad,N=F+B,j=R.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",F+\"px\").call(c.stroke,e.bordercolor).call(c.fill,e.bgcolor),U=e.width||e.height,V=w._topclips.selectAll(\"#\"+C).data(U?[0]:[]);V.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",C).append(\"rect\"),V.exit().remove();var q=e.font,H=w._meta?o.templateString(e.text,w._meta):e.text,G=R.append(\"text\").classed(\"annotation-text\",!0).text(H);k.annotationText?G.call(h.makeEditable,{delegate:R,gd:t}).call(W).on(\"edit\",(function(r){e.text=r,this.call(W),S(\"text\",r),v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,E())})):G.call(W)}else n.selectAll(\"#\"+C).remove();function Y(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function W(r){return r.call(u.font,q).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,X),r}function X(){var r=G.selectAll(\"a\");1===r.size()&&r.text()===G.text()&&R.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(j.node());var n=R.select(\".annotation-text-math-group\"),f=!n.empty(),g=u.bBox((f?n:G).node()),b=g.width,_=g.height,M=e.width||b,D=e.height||_,B=Math.round(M+2*N),q=Math.round(D+2*N);function H(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var W=!1,X=[\"x\",\"y\"],Z=0;Z<X.length;Z++){var J,K,Q,$,tt,et=X[Z],rt=e[et+\"ref\"]||et,nt=e[\"a\"+et+\"ref\"],it={x:v,y:x}[et],at=(I+(\"x\"===et?0:-90))*Math.PI/180,ot=B*Math.cos(at),st=q*Math.sin(at),lt=Math.abs(ot)+Math.abs(st),ct=e[et+\"anchor\"],ut=e[et+\"shift\"]*(\"x\"===et?1:-1),ft=L[et],ht=l.getRefType(rt);if(it&&\"domain\"!==ht){var pt=it.r2fraction(e[et]);(pt<0||pt>1)&&(nt===rt?((pt=it.r2fraction(e[\"a\"+et]))<0||pt>1)&&(W=!0):W=!0),J=it._offset+it.r2p(e[et]),$=.5}else{var dt=\"domain\"===ht;\"x\"===et?(Q=e[et],J=dt?it._offset+it._length*Q:J=T.l+T.w*Q):(Q=1-e[et],J=dt?it._offset+it._length*Q:J=T.t+T.h*Q),$=e.showarrow?.5:Q}if(e.showarrow){ft.head=J;var gt=e[\"a\"+et];if(tt=ot*H(.5,e.xanchor)-st*H(.5,e.yanchor),nt===rt){var mt=l.getRefType(nt);\"domain\"===mt?(\"y\"===et&&(gt=1-gt),ft.tail=it._offset+it._length*gt):\"paper\"===mt?\"y\"===et?(gt=1-gt,ft.tail=T.t+T.h*gt):ft.tail=T.l+T.w*gt:ft.tail=it._offset+it.r2p(gt),K=tt}else ft.tail=J+gt,K=tt+gt;ft.text=ft.tail+tt;var vt=w[\"x\"===et?\"width\":\"height\"];if(\"paper\"===rt&&(ft.head=o.constrain(ft.head,1,vt-1)),\"pixel\"===nt){var yt=-Math.max(ft.tail-3,ft.text),xt=Math.min(ft.tail+3,ft.text)-vt;yt>0?(ft.tail+=yt,ft.text+=yt):xt>0&&(ft.tail-=xt,ft.text-=xt)}ft.tail+=ut,ft.head+=ut}else K=tt=lt*H($,ct),ft.text=J+tt;ft.text+=ut,tt+=ut,K+=ut,e[\"_\"+et+\"padplus\"]=lt/2+K,e[\"_\"+et+\"padminus\"]=lt/2-K,e[\"_\"+et+\"size\"]=lt,e[\"_\"+et+\"shift\"]=tt}if(W)R.remove();else{var bt=0,_t=0;if(\"left\"!==e.align&&(bt=(M-b)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(_t=(D-_)*(\"middle\"===e.valign?.5:1)),f)n.select(\"svg\").attr({x:N+bt-1,y:N+_t}).call(u.setClipUrl,U?C:null,t);else{var wt=N+_t-g.top,Tt=N+bt-g.left;G.call(h.positionText,Tt,wt).call(u.setClipUrl,U?C:null,t)}V.select(\"rect\").call(u.setRect,N,N,M,D),j.call(u.setRect,F/2,F/2,B-F,q-F),R.call(u.setTranslate,Math.round(L.x.text-B/2),Math.round(L.y.text-q/2)),z.attr({transform:\"rotate(\"+I+\",\"+L.x.text+\",\"+L.y.text+\")\"});var kt,Mt=function(r,n){P.selectAll(\".annotation-arrow-g\").remove();var l=L.x.head,f=L.y.head,h=L.x.tail+r,p=L.y.tail+n,g=L.x.text+r,b=L.y.text+n,_=o.rotationXYMatrix(I,g,b),w=o.apply2DTransform(_),M=o.apply2DTransform2(_),C=+j.attr(\"width\"),O=+j.attr(\"height\"),D=g-.5*C,F=D+C,B=b-.5*O,N=B+O,U=[[D,B,D,N],[D,N,F,N],[F,N,F,B],[F,B,D,B]].map(M);if(!U.reduce((function(t,e){return t^!!o.segmentsIntersect(l,f,l+1e6,f+1e6,e[0],e[1],e[2],e[3])}),!1)){U.forEach((function(t){var e=o.segmentsIntersect(h,p,l,f,t[0],t[1],t[2],t[3]);e&&(h=e.x,p=e.y)}));var V=e.arrowwidth,q=e.arrowcolor,H=e.arrowside,G=P.append(\"g\").style({opacity:c.opacity(q)}).classed(\"annotation-arrow-g\",!0),Y=G.append(\"path\").attr(\"d\",\"M\"+h+\",\"+p+\"L\"+l+\",\"+f).style(\"stroke-width\",V+\"px\").call(c.stroke,c.rgb(q));if(m(Y,H,e),k.annotationPosition&&Y.node().parentNode&&!a){var W=l,X=f;if(e.standoff){var Z=Math.sqrt(Math.pow(l-h,2)+Math.pow(f-p,2));W+=e.standoff*(h-l)/Z,X+=e.standoff*(p-f)/Z}var J,K,Q=G.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(h-W)+\",\"+(p-X),transform:s(W,X)}).style(\"stroke-width\",V+6+\"px\").call(c.stroke,\"rgba(0,0,0,0)\").call(c.fill,\"rgba(0,0,0,0)\");d.init({element:Q.node(),gd:t,prepFn:function(){var t=u.getTranslate(R);J=t.x,K=t.y,v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(J,K),i=n[0]+t,a=n[1]+r;R.call(u.setTranslate,i,a),S(\"x\",y(v,t,\"x\",T,e)),S(\"y\",y(x,r,\"y\",T,e)),e.axref===e.xref&&S(\"ax\",y(v,t,\"ax\",T,e)),e.ayref===e.yref&&S(\"ay\",y(x,r,\"ay\",T,e)),G.attr(\"transform\",s(t,r)),z.attr({transform:\"rotate(\"+I+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&Mt(0,0),O)d.init({element:R.node(),gd:t,prepFn:function(){kt=z.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?S(\"ax\",y(v,t,\"ax\",T,e)):S(\"ax\",e.ax+t),e.ayref===e.yref?S(\"ay\",y(x,r,\"ay\",T.w,e)):S(\"ay\",e.ay+r),Mt(t,r);else{if(a)return;var i,o;if(v)i=y(v,t,\"x\",T,e);else{var l=e._xsize/T.w,c=e.x+(e._xshift-e.xshift)/T.w-l/2;i=d.align(c+t/T.w,l,0,1,e.xanchor)}if(x)o=y(x,r,\"y\",T,e);else{var u=e._ysize/T.h,f=e.y-(e._yshift+e.yshift)/T.h-u/2;o=d.align(f-r/T.h,u,0,1,e.yanchor)}S(\"x\",i),S(\"y\",o),v&&x||(n=d.getCursor(v?.5:i,x?.5:o,e.xanchor,e.yanchor))}z.attr({transform:s(t,r)+kt}),p(R,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",Y(n))},doneFn:function(){p(R),i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:x}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../fx\":683,\"./draw_arrow_head\":633,d3:169}],633:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\"),o=t(\"../../lib\"),s=o.strScale,l=o.strRotate,c=o.strTranslate;e.exports=function(t,e,r){var o,u,f,h,p=t.node(),d=a[r.arrowhead||0],g=a[r.startarrowhead||0],m=(r.arrowwidth||1)*(r.arrowsize||1),v=(r.arrowwidth||1)*(r.startarrowsize||1),y=e.indexOf(\"start\")>=0,x=e.indexOf(\"end\")>=0,b=d.backoff*m+r.standoff,_=g.backoff*v+r.startstandoff;if(\"line\"===p.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},u={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var w=o.x-u.x,T=o.y-u.y;if(h=(f=Math.atan2(T,w))+Math.PI,b&&_&&b+_>Math.sqrt(w*w+T*T))return void O();if(b){if(b*b>w*w+T*T)return void O();var k=b*Math.cos(f),M=b*Math.sin(f);u.x+=k,u.y+=M,t.attr({x2:u.x,y2:u.y})}if(_){if(_*_>w*w+T*T)return void O();var A=_*Math.cos(f),S=_*Math.sin(f);o.x-=A,o.y-=S,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===p.nodeName){var E=p.getTotalLength(),C=\"\";if(E<b+_)return void O();var L=p.getPointAtLength(0),I=p.getPointAtLength(.1);f=Math.atan2(L.y-I.y,L.x-I.x),o=p.getPointAtLength(Math.min(_,E)),C=\"0px,\"+_+\"px,\";var P=p.getPointAtLength(E),z=p.getPointAtLength(E-.1);h=Math.atan2(P.y-z.y,P.x-z.x),u=p.getPointAtLength(Math.max(0,E-b)),C+=E-(C?_+b:b)+\"px,\"+E+\"px\",t.style(\"stroke-dasharray\",C)}function O(){t.style(\"stroke-dasharray\",\"0px,100px\")}function D(e,a,o,u){e.path&&(e.noRotate&&(o=0),n.select(p.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:c(a.x,a.y)+l(180*o/Math.PI)+s(u)}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}y&&D(g,o,f,v),x&&D(d,u,h,m)}},{\"../../lib\":778,\"../color\":643,\"./arrow_paths\":625,d3:169}],634:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":626,\"./calc_autorange\":627,\"./click\":628,\"./convert_coords\":630,\"./defaults\":631,\"./draw\":632}],635:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../annotations/attributes\":626}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],637:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../annotations/common_defaults\":629,\"./attributes\":635}],638:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var f=a[u],h=l[f],p=e[f+\"axis\"].r2fraction(h);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":879,\"../annotations/draw\":632}],639:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":635,\"./convert\":636,\"./defaults\":637,\"./draw\":638}],640:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":607,\"world-calendars/dist/calendars/coptic\":608,\"world-calendars/dist/calendars/discworld\":609,\"world-calendars/dist/calendars/ethiopian\":610,\"world-calendars/dist/calendars/hebrew\":611,\"world-calendars/dist/calendars/islamic\":612,\"world-calendars/dist/calendars/julian\":613,\"world-calendars/dist/calendars/mayan\":614,\"world-calendars/dist/calendars/nanakshahi\":615,\"world-calendars/dist/calendars/nepali\":616,\"world-calendars/dist/calendars/persian\":617,\"world-calendars/dist/calendars/taiwan\":618,\"world-calendars/dist/calendars/thai\":619,\"world-calendars/dist/calendars/ummalqura\":620,\"world-calendars/dist/main\":621,\"world-calendars/dist/plus\":622}],641:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:\"##\",w:\"##\",c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function h(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function p(t){return i.extendFlat({},l,{description:t})}function d(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var g={xcalendar:p(d(\"x\"))},m=i.extendFlat({},g,{ycalendar:p(d(\"y\"))}),v=i.extendFlat({},m,{zcalendar:p(d(\"z\"))}),y=p([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:v,surface:v,mesh3d:v,scattergl:m,ohlc:g,candlestick:g},layout:{calendar:p([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:y},yaxis:{calendar:y},scene:{xaxis:{calendar:y},yaxis:{calendar:y},zaxis:{calendar:y}},polar:{radialaxis:{calendar:y}}},transforms:{filter:{valuecalendar:p([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:p([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:h,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,p=h(r).fromJD(f),d=0;-1!==(d=t.indexOf(\"%\",d));)\"0\"===(n=t.charAt(d+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(d+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=u[i])?(c=\"##\"===l?\"##\":p.formatDate(l[n]),t=t.substr(0,d)+c+t.substr(d+a),d+=c.length):d+=a;return t}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./calendars\":640}],642:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],643:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":642,\"fast-isnumeric\":241,tinycolor2:576}],644:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\"},ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,minexponent:n.minexponent,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],645:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],646:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function f(t,e){return n.coerce(u,c,l,t,e)}var h=f(\"thicknessmode\");f(\"thickness\",\"fraction\"===h?30/(r.width-r.margin.l-r.margin.r):30);var p=f(\"lenmode\");f(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),f(\"x\"),f(\"xanchor\"),f(\"xpad\"),f(\"y\"),f(\"yanchor\"),f(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),f(\"outlinecolor\"),f(\"outlinewidth\"),f(\"bordercolor\"),f(\"borderwidth\"),f(\"bgcolor\");var d=f(\"ticklabelposition\");a(u,c,f,\"linear\");var g={outerTicks:!1,font:r.font};-1!==d.indexOf(\"inside\")&&(g.bgColor=\"black\"),s(u,c,f,\"linear\",g),o(u,c,f,\"linear\",g),f(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(f,\"title.font\",r.font),f(\"title.side\")}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"./attributes\":644}],647:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),p=t(\"../drawing\"),d=t(\"../color\"),g=t(\"../titles\"),m=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,y=t(\"../../plots/cartesian/axis_defaults\"),x=t(\"../../plots/cartesian/position_defaults\"),b=t(\"../../plots/cartesian/layout_attributes\"),_=t(\"../../constants/alignment\"),w=_.LINE_SPACING,T=_.FROM_TL,k=_.FROM_BR,M=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+M.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return f(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var u=0;u<o.length;u++){var h=o[u],p=(n=h[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),(function(t){return t._id}));e.enter().append(\"g\").attr(\"class\",(function(t){return t._id})).classed(M.colorbar,!0),e.each((function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",M.cbbg),c.ensureSingle(r,\"g\",M.cbfills),c.ensureSingle(r,\"g\",M.cblines),c.ensureSingle(r,\"g\",M.cbaxis,(function(t){t.classed(M.crisp,!0)})),c.ensureSingle(r,\"g\",M.cbtitleunshift,(function(t){t.append(\"g\").classed(M.cbtitle,!0)})),c.ensureSingle(r,\"rect\",M.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,_=e.title,A=_.side,S=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),E=\"function\"==typeof v.color?v.color:function(){return v.color},C=\"function\"==typeof h?h:function(){return h},L=e._levels,I=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],f=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<f&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var h=e._filllevels;if(h)for(l=h.end+h.size/100,c=h.size,i=0;i<1e5&&(n=h.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map((function(t){return t-a.size/2}))).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);a.size<0&&(o.reverse(),s.reverse());return{line:o,fill:s}}(0,e,S),P=I.fill,z=I.line,O=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),D=O/l.w,R=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),F=R/l.h,B=e.xpad/l.w,N=(e.borderwidth+e.outlinewidth)/2,j=e.ypad/l.h,U=Math.round(e.x*l.w+e.xpad),V=e.x-D*({middle:.5,right:1}[e.xanchor]||0),q=e.y+F*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),H=Math.round(l.h*(1-q)),G=H-R;e._lenFrac=F,e._thickFrac=D,e._xLeftFrac=V,e._yBottomFrac=q;var Y=e._axis=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,ticklabelposition:e.ticklabelposition,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,minexponent:e.minexponent,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,noTicklabelmode:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,b,t,e)}return y(i,a,s,o,n),x(i,a,s,o),a}(r,e,S);Y.position=e.x+B+D,-1!==[\"top\",\"bottom\"].indexOf(A)&&(Y.title.side=A,Y.titlex=e.x+B,Y.titley=q+(\"top\"===_.side?F-j:j));if(v.color&&\"auto\"===e.tickmode){Y.tickmode=\"linear\",Y.tick0=L.start;var W=L.size,X=c.constrain((H-G)/50,4,15)+1,Z=(S[1]-S[0])/((e.nticks||X)*W);if(Z>1){var J=Math.pow(10,Math.floor(Math.log(Z)/Math.LN10));W*=J*c.roundUp(Z/J,[2,5,10]),(Math.abs(L.start)/L.size+1e-6)%1<2e-6&&(Y.tick0=0)}Y.dtick=W}Y.domain=[q+j,q+F-j],Y.setScale(),t.attr(\"transform\",u(Math.round(l.l),Math.round(l.t)));var K,Q=t.select(\".\"+M.cbtitleunshift).attr(\"transform\",u(-Math.round(l.l),-Math.round(l.t))),$=t.select(\".\"+M.cbaxis),tt=0;function et(n,i){var a={propContainer:Y,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+M.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),g.draw(r,n,f(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+B)*l.w,n=Y.title.font.size;t=\"top\"===A?(1-(q+F-j))*l.h+l.t+3+.75*n:(1-(q+j))*l.h+l.t-3-.25*n,et(Y._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+M.cbtitle),o=a.select(\"text\"),f=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+Y._id+\"title-math-group\").node(),d=15.6;if(o.node()&&(d=parseInt(o.node().style.fontSize,10)*w),h?(tt=p.bBox(h).height)>d&&(f[1]-=(tt-d)/2):o.node()&&!o.classed(M.jsPlaceholder)&&(tt=p.bBox(o.node()).height),tt){if(tt+=5,\"top\"===A)Y.domain[1]-=tt/l.h,f[1]*=-1;else{Y.domain[0]+=tt/l.h;var g=m.lineCount(o);f[1]+=(1-g)*d}a.attr(\"transform\",u(f[0],f[1])),Y.setScale()}}t.selectAll(\".\"+M.cbfills+\",.\"+M.cblines).attr(\"transform\",u(0,Math.round(l.h*(1-Y.domain[1])))),$.attr(\"transform\",u(0,Math.round(-l.t)));var y=t.select(\".\"+M.cbfills).selectAll(\"rect.\"+M.cbfill).attr(\"style\",\"\").data(P);y.enter().append(\"rect\").classed(M.cbfill,!0).style(\"stroke\",\"none\"),y.exit().remove();var x=S.map(Y.c2p).map(Math.round).sort((function(t,e){return t-e}));y.each((function(t,a){var o=[0===a?S[0]:(P[a]+P[a-1])/2,a===P.length-1?S[1]:(P[a]+P[a+1])/2].map(Y.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,x[0],x[1]);var s=n.select(this).attr({x:U,width:Math.max(O,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)p.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=C(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}}));var b=t.select(\".\"+M.cblines).selectAll(\"path.\"+M.cbline).data(v.color&&v.width?z:[]);b.enter().append(\"path\").classed(M.cbline,!0),b.exit().remove(),b.each((function(t){n.select(this).attr(\"d\",\"M\"+U+\",\"+(Math.round(Y.c2p(t))+v.width/2%1)+\"h\"+O).call(p.lineGroupStyle,v.width,E(t),v.dash)})),$.selectAll(\"g.\"+Y._id+\"tick,path\").remove();var _=U+O+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),T=s.calcTicks(Y),k=s.getTickSigns(Y)[2];return s.drawTicks(r,Y,{vals:\"inside\"===Y.ticks?s.clipEnds(Y,T):T,layer:$,path:s.makeTickPath(Y,_,k),transFn:s.makeTransTickFn(Y)}),s.drawLabels(r,Y,{vals:T,layer:$,transFn:s.makeTransTickLabelFn(Y),labelFns:s.makeLabelFns(Y,_)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=Y.title.font.size,e=Y._offset+Y._length/2,i=l.l+(Y.position||0)*l.w+(\"right\"===Y.side?10+t*(Y.showticklabels?1:.5):-10-t*(Y.showticklabels?.5:0));et(\"h\"+Y._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+Y._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=O+e.outlinewidth/2;if(-1===Y.ticklabelposition.indexOf(\"inside\")&&(n+=p.bBox($.node()).width),(K=Q.select(\"text\")).node()&&!K.classed(M.jsPlaceholder)){var i,o=Q.select(\".h\"+Y._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?p.bBox(o).width:p.bBox(Q.node()).right-U-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=H-G;t.select(\".\"+M.cbbg).attr({x:U-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:G-N,width:Math.max(s,2),height:Math.max(c+2*N,2)}).call(d.fill,e.bgcolor).call(d.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+M.cboutline).attr({x:U,y:G+e.ypad+(\"top\"===A?tt:0),width:Math.max(O,2),height:Math.max(c-2*e.ypad-tt,2)}).call(d.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var f=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",u(l.l-f,l.t));var h={},g=T[e.yanchor],m=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*g,h.b=c*m):(h.t=h.b=0,h.yt=e.y+e.len*g,h.yb=e.y-e.len*m);var v=T[e.xanchor],y=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*y;else{var x=s-O;h.l=x*v,h.r=x*y,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*y}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+u(r,o)),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)})),e.exit().each((function(e){a.autoMargin(t,e._id)})).remove(),e.order()}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/extend\":768,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../colorscale/helpers\":654,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":645,d3:169,tinycolor2:576}],648:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":778}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":644,\"./defaults\":646,\"./draw\":647,\"./has_colorbar\":648}],650:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,f=e.editTypeOverride||\"\",h=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(h+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",m=s+\"mid\",v=(o(h+p),o(h+d),o(h+g),{});v[d]=v[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:f||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:v},x[d]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[m]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:v},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":795,\"../colorbar/attributes\":644,\"./scales.js\":658}],651:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,f=a(u),h=!1!==f.auto,p=f.min,d=f.max,g=f.mid,m=function(){return i.aggNums(Math.min,null,l)},v=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=m():h&&(p=u._colorAx&&n(p)?Math.min(p,m()):m()),void 0===d?d=v():h&&(d=u._colorAx&&n(d)?Math.max(d,v()):v()),h&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),f._sync(\"min\",p),f._sync(\"max\",d),f.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,f._sync(\"colorscale\",o))}},{\"../../lib\":778,\"./helpers\":654,\"fast-isnumeric\":241}],652:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var f in e._colorAxes)o(e[f],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":778,\"./helpers\":654}],653:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,f,h){var p=h.prefix,d=h.cLetter,g=\"_module\"in r,m=c(e,p),v=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,f,h)};if(g){var b=u._colorAxes||{},_=f(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",T=b[_];return void(T?(T[2].push(x),T[0]!==w&&(T[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var k=m[d+\"min\"],M=m[d+\"max\"],A=n(k)&&n(M)&&k<M;f(p+d+\"auto\",!A)?f(p+d+\"mid\"):(f(p+d+\"min\"),f(p+d+\"max\"));var S,E,C=m.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),f(p+\"autocolorscale\",S),f(p+\"colorscale\"),f(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(m)),f(p+\"showscale\",E)&&(p&&y&&(v._template=y),o(m,v,u)))}},{\"../../lib\":778,\"../../registry\":911,\"../colorbar/defaults\":646,\"../colorbar/has_colorbar\":648,\"./scales\":658,\"fast-isnumeric\":241}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function f(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)((s=\"c\"+(n=u[r]))in a||(s=\"z\"+n)in a)&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function h(t){for(var e=f(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var f=i(o[u]).toRgb();c[u]=[f.r,f.g,f.b,f.a]}var h,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,m=e.returnArray;return(h=d&&m?p:d?function(t){return g(p(t))}:m?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,h.range=function(){return o},h}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,i=n[r||\"color\"],s=!1;if(o.isArrayOrTypedArray(i))for(var c=0;c<i.length;c++)if(a(i[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||a(n.cmin)&&a(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:f,extractScale:h,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(h(t),e)}}},{\"../../lib\":778,\"../color\":643,\"./scales\":658,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],655:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":650,\"./calc\":651,\"./cross_trace_defaults\":652,\"./defaults\":653,\"./helpers\":654,\"./layout_attributes\":656,\"./layout_defaults\":657,\"./scales\":658}],656:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":768,\"./attributes\":650,\"./scales\":658}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var f in c){var h=c[f];if(h[0])s=t[f]||{},(l=i.newContainer(e,f,\"coloraxis\"))._name=f,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<h[2].length;p++)h[2][p]();delete e._colorAxes[f]}}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"./defaults\":653,\"./layout_attributes\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:576}],659:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],660:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":778}],661:[function(t,e,r){\"use strict\";r.selectMode=function(t){return\"lasso\"===t||\"select\"===t},r.drawMode=function(t){return\"drawclosedpath\"===t||\"drawopenpath\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.openMode=function(t){return\"drawline\"===t||\"drawopenpath\"===t},r.rectMode=function(t){return\"select\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.freeMode=function(t){return\"lasso\"===t||\"drawclosedpath\"===t||\"drawopenpath\"===t},r.selectingOrDrawing=function(t){return r.freeMode(t)||r.rectMode(t)}},{}],662:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function f(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,h,p,d,g,m=t.gd,v=1,y=m._context.doubleClickDelay,x=t.element;m._mouseDownTime||(m._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){m._dragged=!1,m._dragging=!0;var o=f(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-m._mouseDownTime<y?v+=1:(v=1,m._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(h=u()).style.cursor=window.getComputedStyle(x).cursor:i||(h=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",T),document.addEventListener(\"touchend\",T),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w,{passive:!1}))}function w(n){n.preventDefault();var i=f(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(m._dragged=!0,l.unhover(m)),m._dragged&&t.moveFn&&!g&&(m._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function T(e){if(delete m._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",T),document.removeEventListener(\"touchend\",T),i?o(h):c&&(h.documentElement.style.cursor=c,c=null),m._dragging){if(m._dragging=!1,(new Date).getTime()-m._mouseDownTime>y&&(v=Math.max(v-1,1)),m._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(v,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=f(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}m._dragging=!1,m._dragged=!1}else m._dragged=!1}},l.coverSlip=u},{\"../../lib\":778,\"../../plots/cartesian/constants\":834,\"./align\":659,\"./cursor\":660,\"./unhover\":663,\"has-hover\":440,\"has-passive-events\":441,\"mouse-event-offset\":484}],663:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":766,\"../../lib/events\":767,\"../../lib/throttle\":804,\"../fx/constants\":677}],664:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),p=t(\"../../constants/alignment\").LINE_SPACING,d=t(\"../../constants/interactions\").DESELECTDIM,g=t(\"../../traces/scatter/subtypes\"),m=t(\"../../traces/scatter/make_bubble_size_func\"),v=t(\"../../components/fx/helpers\").appendArrayPointValue,y=e.exports={};y.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},y.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},y.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},y.setRect=function(t,e,r,n,i){t.call(y.setPosition,e,r).call(y.setSize,n,i)},y.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",u(a,o)),!0)},y.translatePoints=function(t,e,r){t.each((function(t){var i=n.select(this);y.translatePoint(t,i,e,r)}))},y.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},y.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each((function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each((function(t){y.hideOutsideRangePoint(t,n.select(this),r,i,s,l)}))}))}},y.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},y.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),y.dashLine(e,l,o)},y.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each((function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(y.dashLine,l,o)}))},y.dashLine=function(t,e,r){r=+r||0,e=y.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},y.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},y.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},y.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each((function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)}))};var x=t(\"./symbol_defs\");y.symbolNames=[],y.symbolFuncs=[],y.symbolNeedLines={},y.symbolNoDot={},y.symbolNoFill={},y.symbolList=[],Object.keys(x).forEach((function(t){var e=x[t],r=e.n;y.symbolList.push(r,String(r),t,r+100,String(r+100),t+\"-open\"),y.symbolNames[r]=t,y.symbolFuncs[r]=e.f,e.needLine&&(y.symbolNeedLines[r]=!0),e.noDot?y.symbolNoDot[r]=!0:y.symbolList.push(r+200,String(r+200),t+\"-dot\",r+300,String(r+300),t+\"-open-dot\"),e.noFill&&(y.symbolNoFill[r]=!0)}));var b=y.symbolNames.length;function _(t,e){var r=t%100;return y.symbolFuncs[r](e)+(t>=200?\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\":\"\")}y.symbolNumber=function(t){if(i(t))t=+t;else if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=y.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=b||t>=400?0:Math.floor(Math.max(t,0))};var w={x1:1,x2:0,y1:0,y2:0},T={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),M={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:w},horizontalreversed:{node:\"linearGradient\",attrs:w,reversed:!0},vertical:{node:\"linearGradient\",attrs:T},verticalreversed:{node:\"linearGradient\",attrs:T,reversed:!0}};y.gradient=function(t,e,r,i,o,l){for(var u=o.length,f=M[i],h=new Array(u),p=0;p<u;p++)f.reversed?h[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:h[p]=[k(100*o[p][0]),o[p][1]];var d=e._fullLayout,g=\"g\"+d._uid+\"-\"+r,m=d._defs.select(\".gradients\").selectAll(\"#\"+g).data([i+h.join(\";\")],c.identity);m.exit().remove(),m.enter().append(f.node).each((function(){var t=n.select(this);f.attrs&&t.attr(f.attrs),t.attr(\"id\",g);var e=t.selectAll(\"stop\").data(h);e.exit().remove(),e.enter().append(\"stop\"),e.each((function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})}))})),t.style(l,O(g,e)).style(l+\"-opacity\",null);var v=function(t){return\".\"+t.attr(\"class\").replace(/\\s/g,\".\")},y=v(n.select(t.node().parentNode))+\">\"+v(t);d._gradientUrlQueryParts[y]=1},y.initGradients=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove(),e._gradientUrlQueryParts={}},y.pointStyle=function(t,e,r){if(t.size()){var i=y.makePointStyleFns(e);t.each((function(t){y.singlePointStyle(t,n.select(this),e,i,r)}))}},y.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=y.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",_(u,l))}var f,h,p,d=!1;if(t.so)p=o.outlierwidth,h=o.outliercolor,f=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,h=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(f=s.defaultLine,d=!0),f=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(f=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,f).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",(t.isBlank?0:p)+\"px\");var m=a.gradient,v=t.mgt;if(v?d=!0:v=m&&m.type,Array.isArray(v)&&(v=v[0],M[v]||(v=0)),v&&\"none\"!==v){var x=t.mgc;x?d=!0:x=m.color;var b=r.uid;d&&(b+=\"-\"+t.i),y.gradient(e,i,b,v,[[0,x],[1,f]],\"fill\")}else s.fill(e,f);p&&s.stroke(e,h)}},y.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=y.tryColorscale(r,\"\"),e.lineScale=y.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=g.isBubble(t)?m(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,y.makeSelectedPointStyleFns(t)),e},y.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,f=s.opacity,h=void 0!==u,p=void 0!==f;(c.isArrayOrTypedArray(l)||h||p)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?h?u:e:p?f:d*e});var g=i.color,m=a.color,v=s.color;(m||v)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?m||e:v||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},y.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,d))},e},y.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push((function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))})),r.selectedColorFn&&a.push((function(t,e){s.fill(t,r.selectedColorFn(e))})),r.selectedSizeFn&&a.push((function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",_(y.symbolNumber(n),a)),e.mrc2=a})),a.length&&t.each((function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)}))}},y.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function S(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(f.lineCount(t)-1)*p+1,h=A[s]*l,d=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",u(h,d))}function E(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}y.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=y.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each((function(t){var a=n.select(this),l=o?c.extractOption(t,e,\"txt\",\"texttemplate\"):c.extractOption(t,e,\"tx\",\"text\");if(l||0===l){if(o){var u=e._module.formatLabels?e._module.formatLabels(t,e,s):{},h={};v(h,e,t.i);var p=e._meta||{};l=c.texttemplateString(l,u,s._d3locale,h,t,p)}var d=t.tp||e.textposition,g=E(t,e),m=i?i(t):t.tc||e.textfont.color;a.call(y.font,t.tf||e.textfont.family,g,m).text(l).call(f.convertToTspans,r).call(S,d,g,t.mrc)}else a.remove()}))}},y.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedTextStyleFns(e);t.each((function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=E(t,e);s.fill(i,a),S(i,o,l,t.mrc2||t.mrc)}))}};function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,.25),u=Math.pow(s*s+l*l,.25),f=(u*u*a-c*c*s)*i,h=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&f/p),2),n.round(e[1]+(p&&h/p),2)],[n.round(e[0]-(d&&f/d),2),n.round(e[1]-(d&&h/d),2)]]}y.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},y.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},I=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};y.steps=function(t){var e=L[t]||I;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},y.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",(function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})})),e=c.ensureSingle(t,\"path\",\"js-reference-point\",(function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})}));y.tester=t,y.testref=e},y.savedBBoxes={};var P=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function O(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}y.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=y.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,u=+s.getAttribute(\"y\")||0,h=s.getAttribute(\"transform\");if(!h){var p=y.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),u&&(p.top+=u,p.bottom+=u),p}if(r+=\"~\"+l+\"~\"+u+\"~\"+h,i=y.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=y.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(f.positionText,0,0);var d=a.getBoundingClientRect(),g=y.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return P>=1e4&&(y.savedBBoxes={},P=0),r&&(y.savedBBoxes[r]=m),P++,c.extendFlat({},m)},y.setClipUrl=function(t,e,r){t.attr(\"clip-path\",O(e,r))},y.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},y.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=u(e,r)).trim(),t[i](\"transform\",a),a},y.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},y.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\"scale(\"+e+\",\"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;y.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\"scale(\"+e+\",\"+r+\")\";t.each((function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)}))}};var R=/translate\\([^)]*\\)\\s*$/;y.setTextPointsScale=function(t,e,r){t&&t.each((function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[u(o,s),\"scale(\"+e+\",\"+r+\")\",u(-o,-s)],l&&t.push(l),i.attr(\"transform\",t.join(\"\"))}}))}},{\"../../components/fx/helpers\":679,\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../registry\":911,\"../../traces/scatter/make_bubble_size_func\":1204,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale\":655,\"./symbol_defs\":666,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],666:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0},\"arrow-up\":{n:45,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-down\":{n:46,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-left\":{n:47,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-right\":{n:48,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-bar-up\":{n:49,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-down\":{n:50,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-left\":{n:51,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-right\":{n:52,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0}}},{d3:169}],667:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],668:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),f=0;f<t.length;f++){var h=t[f],p=h.i;if(void 0===p)p=f;else if(null===p)continue;var d=h[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var m=h[i+\"s\"]=d-g[0],v=h[i+\"h\"]=d+g[1];c.push(m,v)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./compute_error\":669,\"fast-isnumeric\":241}],669:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],670:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),f=t[c]||{};function h(t,e){return a.coerce(f,u,s,t,e)}if(!1!==h(\"visible\",void 0!==f.array||void 0!==f.value||\"sqrt\"===f.type)){var p=h(\"type\",\"array\"in f?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=h(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in f))),\"data\"===p?(h(\"array\"),h(\"traceref\"),d||(h(\"arrayminus\"),h(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(h(\"value\"),d||h(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&h(g,!(f.color||n(f.thickness)||n(f.width)));l.inherit&&u[g]||(h(\"color\",r),h(\"thickness\"),h(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"./attributes\":667,\"fast-isnumeric\":241}],671:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":778,\"../../plot_api/edit_types\":810,\"./attributes\":667,\"./calc\":668,\"./compute_error\":669,\"./defaults\":670,\"./plot\":672,\"./style\":673}],672:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each((function(e){var f,h=e[0].trace,p=h.error_x||{},d=h.error_y||{};h.ids&&(f=function(t){return t.id});var g=o.hasMarkers(h)&&h.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var m=n.select(this).selectAll(\"g.errorbar\").data(e,f);if(m.exit().remove(),e.length){p.visible||m.selectAll(\"path.xerror\").remove(),d.visible||m.selectAll(\"path.yerror\").remove(),m.style(\"opacity\",1);var v=m.enter().append(\"g\").classed(\"errorbar\",!0);u&&v.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(m,r.layerClipId,t),m.each((function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var f=d.width;a=\"M\"+(r.x-f)+\",\"+r.yh+\"h\"+2*f+\"m-\"+f+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+f+\",0h\"+2*f),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var h=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var m=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-m)+\"v\"+2*m+\"m0,-\"+m+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+m+\"v\"+2*m),!h.size()?h=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(h=h.transition().duration(s.duration).ease(s.easing)),h.attr(\"d\",a)}else h.remove()}}))}}))}},{\"../../traces/scatter/subtypes\":1212,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],673:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each((function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)}))}},{\"../color\":643,d3:169}],674:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"./layout_attributes\":684}],675:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":778,\"../../registry\":911}],676:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":911,\"./hover\":680}],677:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,(function(r,a){return n.coerce(t,e,i,r,a)}),s)}},{\"../../lib\":778,\"./attributes\":674,\"./hoverlabel_defaults\":681}],679:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t.charAt(0)?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),f=new Array(r.length),h=0;h<r.length;h++)f[h]=o(u,r[h]);t[c]=f}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={\"x unified\":!0,\"y unified\":!0};r.isUnifiedHover=function(t){return\"string\"==typeof t&&!!l[t]},r.isXYhover=function(t){return\"string\"==typeof t&&!!s[t]}},{\"../../lib\":778}],680:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=o.strTranslate,l=o.strRotate,c=t(\"../../lib/events\"),u=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/override_cursor\"),h=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../dragelement\"),g=t(\"../../plots/cartesian/axes\"),m=t(\"../../registry\"),v=t(\"./helpers\"),y=t(\"./constants\"),x=t(\"../legend/defaults\"),b=t(\"../legend/draw\"),_=y.YANGLE,w=Math.PI*_/180,T=1/Math.sin(w),k=Math.cos(w),M=Math.sin(w),A=y.HOVERARROWSIZE,S=y.HOVERTEXTPAD;function E(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")}r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+y.HOVERID,y.HOVERMINTIME,(function(){!function(t,e,r,a){r||(r=\"xy\");var s=Array.isArray(r)?r:[r],l=t._fullLayout,u=l._plots||[],h=u[r],g=l._has(\"cartesian\");if(h){var y=h.overlays.map((function(t){return t.id}));s=s.concat(y)}for(var x=s.length,b=new Array(x),_=new Array(x),w=!1,k=0;k<x;k++){var M=s[k];if(u[M])w=!0,b[k]=u[M].xaxis,_[k]=u[M].yaxis;else{if(!l[M]||!l[M]._subplot)return void o.warn(\"Unrecognized subplot: \"+M);var A=l[M]._subplot;b[k]=A.xaxis,_[k]=A.yaxis}}var S=e.hovermode||l.hovermode;S&&!w&&(S=\"closest\");if(-1===[\"x\",\"y\",\"closest\",\"x unified\",\"y unified\"].indexOf(S)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return d.unhoverRaw(t,e);var C,I,R,F,B,N,j,U,V,q,H,G,Y,W=-1===l.hoverdistance?1/0:l.hoverdistance,X=-1===l.spikedistance?1/0:l.spikedistance,Z=[],J=[],K={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(S=\"array\",R=0;R<e.length;R++)(B=t.calcdata[e[R].curveNumber||0])&&(N=B[0].trace,\"skip\"!==B[0].trace.hoverinfo&&(J.push(B),\"h\"===N.orientation&&(Q=!0)));else{for(F=0;F<t.calcdata.length;F++)B=t.calcdata[F],\"skip\"!==(N=B[0].trace).hoverinfo&&v.isTraceInSubplots(N,s)&&(J.push(B),\"h\"===N.orientation&&(Q=!0));var $,tt;if(!e.target)$=\"xpx\"in e?e.xpx:b[0]._length/2,tt=\"ypx\"in e?e.ypx:_[0]._length/2;else{if(!1===c.triggerHandler(t,\"plotly_beforehover\",e))return;var et=e.target.getBoundingClientRect();$=e.clientX-et.left,tt=e.clientY-et.top,l._calcInverseTransform(t);var rt=o.apply3DTransform(l._invTransform)($,tt);if($=rt[0],tt=rt[1],$<0||$>b[0]._length||tt<0||tt>_[0]._length)return d.unhoverRaw(t,e)}if(e.pointerX=$+b[0]._offset,e.pointerY=tt+_[0]._offset,C=\"xval\"in e?v.flat(s,e.xval):v.p2c(b,$),I=\"yval\"in e?v.flat(s,e.yval):v.p2c(_,tt),!i(C[0])||!i(I[0]))return o.warn(\"Fx.hover failed\",e,t),d.unhoverRaw(t,e)}var nt=1/0;function it(t,r){for(F=0;F<J.length;F++)if((B=J[F])&&B[0]&&B[0].trace&&!0===(N=B[0].trace).visible&&0!==N._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(N._module.name)){if(\"splom\"===N.type?j=s[U=0]:(j=v.getSubplot(N),U=s.indexOf(j)),V=S,v.isUnifiedHover(V)&&(V=V.charAt(0)),G={cd:B,trace:N,xa:b[U],ya:_[U],maxHoverDistance:W,maxSpikeDistance:X,index:!1,distance:Math.min(nt,W),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:p.defaultLine,name:N.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},l[j]&&(G.subplot=l[j]._subplot),l._splomScenes&&l._splomScenes[N.uid]&&(G.scene=l._splomScenes[N.uid]),Y=Z.length,\"array\"===V){var n=e[F];\"pointNumber\"in n?(G.index=n.pointNumber,V=\"closest\"):(V=\"\",\"xval\"in n&&(q=n.xval,V=\"x\"),\"yval\"in n&&(H=n.yval,V=V?\"closest\":\"y\"))}else void 0!==t&&void 0!==r?(q=t,H=r):(q=C[U],H=I[U]);if(0!==W)if(N._module&&N._module.hoverPoints){var a=N._module.hoverPoints(G,q,H,V,l._hoverlayer);if(a)for(var c,u=0;u<a.length;u++)c=a[u],i(c.x0)&&i(c.y0)&&Z.push(z(c,S))}else o.log(\"Unrecognized trace type in hover:\",N);if(\"closest\"===S&&Z.length>Y&&(Z.splice(0,Y),nt=Z[0].distance),g&&0!==X&&0===Z.length){G.distance=X,G.index=!1;var f=N._module.hoverPoints(G,q,H,\"closest\",l._hoverlayer);if(f&&(f=f.filter((function(t){return t.spikeDistance<=X}))),f&&f.length){var h,d=f.filter((function(t){return t.xa.showspikes&&\"hovered data\"!==t.xa.spikesnap}));if(d.length){var m=d[0];i(m.x0)&&i(m.y0)&&(h=ot(m),(!K.vLinePoint||K.vLinePoint.spikeDistance>h.spikeDistance)&&(K.vLinePoint=h))}var y=f.filter((function(t){return t.ya.showspikes&&\"hovered data\"!==t.ya.spikesnap}));if(y.length){var x=y[0];i(x.x0)&&i(x.y0)&&(h=ot(x),(!K.hLinePoint||K.hLinePoint.spikeDistance>h.spikeDistance)&&(K.hLinePoint=h))}}}}}function at(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<=i&&r<=e&&(n=t[a],i=r);return n}function ot(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}it();var st={fullLayout:l,container:l._hoverlayer,outerContainer:l._paperdiv,event:e},lt=t._spikepoints,ct={vLinePoint:K.vLinePoint,hLinePoint:K.hLinePoint};if(t._spikepoints=ct,g&&0!==X&&0!==Z.length){var ut=at(Z.filter((function(t){return t.ya.showspikes})),X);K.hLinePoint=ot(ut);var ft=at(Z.filter((function(t){return t.xa.showspikes})),X);K.vLinePoint=ot(ft)}if(0===Z.length){var ht=d.unhoverRaw(t,e);return!g||null===K.hLinePoint&&null===K.vLinePoint||D(lt)&&O(t,K,st),ht}g&&D(lt)&&O(t,K,st);if(Z.sort((function(t,e){return t.distance-e.distance})),v.isXYhover(V)&&0!==Z[0].length&&\"splom\"!==Z[0].trace.type){var pt=Z[0],dt=pt.cd[pt.index],gt=\"group\"===l.boxmode||\"group\"===l.violinmode,mt=pt.xVal,vt=pt.xa;\"category\"===vt.type&&(mt=vt._categoriesMap[mt]),\"date\"===vt.type&&(mt=vt.d2c(mt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(mt+=dt.t.dPos);var yt=pt.yVal;\"category\"===(vt=pt.ya).type&&(yt=vt._categoriesMap[yt]),\"date\"===vt.type&&(yt=vt.d2c(yt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(yt+=dt.t.dPos),it(mt,yt);var xt={};Z=Z.filter((function(t){var e=E(t);if(!xt[e])return xt[e]=!0,xt[e]}))}var bt=t._hoverdata,_t=[];for(R=0;R<Z.length;R++){var wt=Z[R],Tt=v.makeEventData(wt,wt.trace,wt.cd);if(!1!==wt.hovertemplate){var kt=!1;wt.cd[wt.index]&&wt.cd[wt.index].ht&&(kt=wt.cd[wt.index].ht),wt.hovertemplate=kt||wt.trace.hovertemplate||!1}wt.eventData=[Tt],_t.push(Tt)}t._hoverdata=_t;var Mt=\"y\"===S&&(J.length>1||Z.length>1)||\"closest\"===S&&Q&&Z.length>1,At=p.combine(l.plot_bgcolor||p.background,l.paper_bgcolor),St={hovermode:S,rotateLabels:Mt,bgColor:At,container:l._hoverlayer,outerContainer:l._paperdiv,commonLabelOpts:l.hoverlabel,hoverdistance:l.hoverdistance},Et=L(Z,St,t);v.isUnifiedHover(S)||(!function(t,e,r){var n,i,a,o,s,l,c,u=0,f=1,h=t.size(),p=new Array(h),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}t.each((function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(f=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?T:1)/2,pmin:0,pmax:i?r.width:r.height}]})),p.sort((function(t,e){return t[0].posref-e[0].posref||f*(e[0].traceIndex-t[0].traceIndex)}));for(;!n&&u<=h;){for(u++,n=!0,o=0;o<p.length-1;){var m=p[o],v=p[o+1],y=m[m.length-1],x=v[0];if((i=y.pos+y.dp+y.size-x.pos-x.dp+x.size)>.01&&y.pmin===x.pmin&&y.pmax===x.pmax){for(s=v.length-1;s>=0;s--)v[s].dp+=i;for(m.push.apply(m,v),p.splice(o+1,1),c=0,s=m.length-1;s>=0;s--)c+=m[s].dp;for(a=c/m.length,s=m.length-1;s>=0;s--)m[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var b=p[o];for(s=b.length-1;s>=0;s--){var _=b[s],w=_.datum;w.offset=_.dp,w.del=_.del}}}(Et,Mt?\"xa\":\"ya\",l),P(Et,Mt,l._invScaleX,l._invScaleY));if(e.target&&e.target.tagName){var Ct=m.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,_t);f(n.select(e.target),Ct?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,bt))return;bt&&t.emit(\"plotly_unhover\",{event:e,points:bt});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:b,yaxes:_,xvals:C,yvals:I})}(t,e,r,a)}))},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map((function(t){return{color:t.color||p.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}})),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||p.background,container:a,outerContainer:o},l=L(i,s,e.gd),c=0,u=0;l.sort((function(t,e){return t.y0-e.y0})).each((function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)})).each((function(t){t.offset-=u}));var f=e.gd._fullLayout._invScaleX,h=e.gd._fullLayout._invScaleY;return P(l,s.rotateLabels,f,h),r?l:l.node()};var C=/<extra>([\\s\\S]*)<\\/extra>/;function L(t,e,r){var i=r._fullLayout,a=e.hovermode,c=e.rotateLabels,f=e.bgColor,d=e.container,g=e.outerContainer,m=e.commonLabelOpts||{},w=e.fontFamily||y.HOVERFONT,T=e.fontSize||y.HOVERFONTSIZE,k=t[0],M=k.xa,C=k.ya,L=\"y\"===a.charAt(0)?\"yLabel\":\"xLabel\",P=k[L],z=(String(P)||\"\").split(\" \")[0],O=g.node().getBoundingClientRect(),D=O.top,R=O.width,F=O.height,B=void 0!==P&&k.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(B){var N,j,U=!0;for(N=0;N<t.length;N++)if(U&&void 0===t[N].zLabel&&(U=!1),j=t[N].hoverinfo||t[N].trace.hoverinfo){var V=Array.isArray(j)?j:j.split(\"+\");if(-1===V.indexOf(\"all\")&&-1===V.indexOf(a)){B=!1;break}}U&&(B=!1)}var q=d.selectAll(\"g.axistext\").data(B?[0]:[]);function H(t){return t.filter((function(t){return void 0!==t.zLabelVal||(t[L]||\"\").split(\" \")[0]===z}))}if(q.enter().append(\"g\").classed(\"axistext\",!0),q.exit().remove(),q.each((function(){var e=n.select(this),l=o.ensureSingle(e,\"path\",\"\",(function(t){t.style({\"stroke-width\":\"1px\"})})),c=o.ensureSingle(e,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),f=m.bgcolor||p.defaultLine,d=m.bordercolor||p.contrast(f),g=p.contrast(f),v={family:m.font.family||w,size:m.font.size||T,color:m.font.color||g};l.style({fill:f,stroke:d}),c.text(P).call(h.font,v).call(u.positionText,0,0).call(u.convertToTspans,r),e.attr(\"transform\",\"\");var y,x,b=c.node().getBoundingClientRect();if(\"x\"===a){var _=\"top\"===M.side?\"-\":\"\";c.attr(\"text-anchor\",\"middle\").call(u.positionText,0,\"top\"===M.side?D-b.bottom-A-S:D-b.top+A+S),y=M._offset+(k.x0+k.x1)/2,x=C._offset+(\"top\"===M.side?0:C._length);var E=b.width/2+S;y<E?(y=E,l.attr(\"d\",\"M-\"+(E-A)+\",0L-\"+(E-2*A)+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"Z\")):y>i.width-E?(y=i.width-E,l.attr(\"d\",\"M\"+(E-A)+\",0L\"+E+\",\"+_+A+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"H\"+(E-2*A)+\"Z\")):l.attr(\"d\",\"M0,0L\"+A+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+(S+b.width/2)+\"V\"+_+A+\"H-\"+A+\"Z\")}else{var L,I,z;\"right\"===C.side?(L=\"start\",I=1,z=\"\",y=M._offset+M._length):(L=\"end\",I=-1,z=\"-\",y=M._offset),x=C._offset+(k.y0+k.y1)/2,c.attr(\"text-anchor\",L),l.attr(\"d\",\"M0,0L\"+z+A+\",\"+A+\"V\"+(S+b.height/2)+\"h\"+z+(2*S+b.width)+\"V-\"+(S+b.height/2)+\"H\"+z+A+\"V-\"+A+\"Z\");var O,R=b.height/2,F=D-b.top-R,B=\"clip\"+i._uid+\"commonlabel\"+C._id;if(y<b.width+2*S+A){O=\"M-\"+(A+S)+\"-\"+R+\"h-\"+(b.width-S)+\"V\"+R+\"h\"+(b.width-S)+\"Z\";var N=b.width-y+S;u.positionText(c,N,F),\"end\"===L&&c.selectAll(\"tspan\").each((function(){var t=n.select(this),e=h.tester.append(\"text\").text(t.text()).call(h.font,v),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(b.width)&&t.attr(\"x\",N-r.width),e.remove()}))}else u.positionText(c,I*(S+A),F),O=null;var j=i._topclips.selectAll(\"#\"+B).data(O?[0]:[]);j.enter().append(\"clipPath\").attr(\"id\",B).append(\"path\"),j.exit().remove(),j.select(\"path\").attr(\"d\",O),h.setClipUrl(c,O?B:null,r)}e.attr(\"transform\",s(y,x)),t=H(t)})),v.isUnifiedHover(a)){if(d.selectAll(\"g.hovertext\").remove(),void 0!==P&&k.distance<=e.hoverdistance&&(t=H(t)),0===t.length)return;var G={showlegend:!0,legend:{title:{text:P,font:i.hoverlabel.font},font:i.hoverlabel.font,bgcolor:i.hoverlabel.bgcolor,bordercolor:i.hoverlabel.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:i.legend?i.legend.traceorder:void 0,orientation:\"v\"}},Y={};x(G,Y,r._fullData);var W=Y.legend;W.entries=[];for(var X=0;X<t.length;X++){var Z=I(t[X],!0,a,i,P),J=Z[0],K=Z[1],Q=t[X];Q.name=K,Q.text=\"\"!==K?K+\" : \"+J:J;var $=Q.cd[Q.index];$&&($.mc&&(Q.mc=$.mc),$.mcc&&(Q.mc=$.mcc),$.mlc&&(Q.mlc=$.mlc),$.mlcc&&(Q.mlc=$.mlcc),$.mlw&&(Q.mlw=$.mlw),$.mrc&&(Q.mrc=$.mrc),$.dir&&(Q.dir=$.dir)),Q._distinct=!0,W.entries.push([Q])}W.entries.sort((function(t,e){return t[0].trace.index-e[0].trace.index})),W.layer=d,b(r,W);var tt=o.mean(t.map((function(t){return(t.y0+t.y1)/2}))),et=o.mean(t.map((function(t){return(t.x0+t.x1)/2}))),rt=d.select(\"g.legend\"),nt=rt.node().getBoundingClientRect();et+=M._offset,tt+=C._offset-nt.height/2;var it=nt.width+2*S;!(et+it<=R)&&et-it>=0?et-=it:et+=2*S;var at=nt.height+2*S,ot=tt+at>=F;return at<=F&&(tt<=D?tt=C._offset+2*S:ot&&(tt=F-at)),rt.attr(\"transform\",s(et,tt)),rt}var st=d.selectAll(\"g.hovertext\").data(t,(function(t){return E(t)}));return st.enter().append(\"g\").classed(\"hovertext\",!0).each((function(){var t=n.select(this);t.append(\"rect\").call(p.fill,p.addOpacity(f,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(h.font,w,T)})),st.exit().remove(),st.each((function(t){var e=n.select(this).attr(\"transform\",\"\"),o=t.color;Array.isArray(o)&&(o=o[t.eventData[0].pointNumber]);var d=t.bgcolor||o,g=p.combine(p.opacity(d)?d:p.defaultLine,f),m=p.combine(p.opacity(o)?o:p.defaultLine,f),v=t.borderColor||p.contrast(g),y=I(t,B,a,i,P,e),x=y[0],b=y[1],k=e.select(\"text.nums\").call(h.font,t.fontFamily||w,t.fontSize||T,t.fontColor||v).text(x).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r),M=e.select(\"text.name\"),E=0,C=0;if(b&&b!==x){M.call(h.font,t.fontFamily||w,t.fontSize||T,m).text(b).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r);var L=M.node().getBoundingClientRect();E=L.width+2*S,C=L.height+2*S}else M.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:g,stroke:v});var z,O,N=k.node().getBoundingClientRect(),j=t.xa._offset+(t.x0+t.x1)/2,U=t.ya._offset+(t.y0+t.y1)/2,V=Math.abs(t.x1-t.x0),q=Math.abs(t.y1-t.y0),H=N.width+A+S+E;if(t.ty0=D-N.top,t.bx=N.width+2*S,t.by=Math.max(N.height+2*S,C),t.anchor=\"start\",t.txwidth=N.width,t.tx2width=E,t.offset=0,c)t.pos=j,z=U+q/2+H<=F,O=U-q/2-H>=0,\"top\"!==t.idealAlign&&z||!O?z?(U+=q/2,t.anchor=\"start\"):t.anchor=\"middle\":(U-=q/2,t.anchor=\"end\");else if(t.pos=U,z=j+V/2+H<=R,O=j-V/2-H>=0,\"left\"!==t.idealAlign&&z||!O)if(z)j+=V/2,t.anchor=\"start\";else{t.anchor=\"middle\";var G=H/2,Y=j+G-R,W=j-G;Y>0&&(j-=Y),W<0&&(j+=-W)}else j-=V/2,t.anchor=\"end\";k.attr(\"text-anchor\",t.anchor),E&&M.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",s(j,U)+(c?l(_):\"\"))})),st}function I(t,e,r,n,i,a){var s=\"\",l=\"\";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=R(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(l+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(l+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(l+=(l?\"z: \":\"\")+t.zLabel)):e&&t[r.charAt(0)+\"Label\"]===i?l=t[(\"x\"===r.charAt(0)?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(l+=(l?\"<br>\":\"\")+t.extraText),a&&\"\"===l&&!t.hovertemplate&&(\"\"===s&&a.remove(),l=s);var c=n._d3locale,u=t.hovertemplate||!1,f=t.hovertemplateLabels||t,h=t.eventData[0]||{};return u&&(l=(l=o.hovertemplateString(u,f,c,h,t.trace._meta)).replace(C,(function(e,r){return s=R(r,t.nameLength),\"\"}))),[l,s]}function P(t,e,r,i){var a=function(t){return t*r},o=function(t){return t*i};t.each((function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),s=t.anchor,l=\"end\"===s?-1:1,c={start:1,end:-1,middle:0}[s],f=c*(A+S),p=f+c*(t.txwidth+S),d=0,g=t.offset,m=\"middle\"===s;m&&(f-=t.tx2width/2,p+=t.txwidth/2+S),e&&(g*=-M,d=t.offset*k),r.select(\"path\").attr(\"d\",m?\"M-\"+a(t.bx/2+t.tx2width/2)+\",\"+o(g-t.by/2)+\"h\"+a(t.bx)+\"v\"+o(t.by)+\"h-\"+a(t.bx)+\"Z\":\"M0,0L\"+a(l*A+d)+\",\"+o(A+g)+\"v\"+o(t.by/2-A)+\"h\"+a(l*t.bx)+\"v-\"+o(t.by)+\"H\"+a(l*A+d)+\"V\"+o(g-A)+\"Z\");var v=d+f,y=g+t.ty0-t.by/2+S,x=t.textAlign||\"auto\";\"auto\"!==x&&(\"left\"===x&&\"start\"!==s?(i.attr(\"text-anchor\",\"start\"),v=m?-t.bx/2-t.tx2width/2+S:-t.bx-S):\"right\"===x&&\"end\"!==s&&(i.attr(\"text-anchor\",\"end\"),v=m?t.bx/2-t.tx2width/2-S:t.bx+S)),i.call(u.positionText,a(v),o(y)),t.tx2width&&(r.select(\"text.name\").call(u.positionText,a(p+c*S+d),o(g+t.ty0-t.by/2+S)),r.select(\"rect\").call(h.setRect,a(p+(c-1)*t.tx2width/2+d),o(g-t.by/2-1),a(t.tx2width),o(t.by+2)))}))}function z(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:g.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:g.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var f=g.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+f+\" / -\"+g.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+f,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var h=g.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+h+\" / -\"+g.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+h,\"y\"===e&&(t.distance+=1)}var p=t.hoverinfo||t.trace.hoverinfo;return p&&\"all\"!==p&&(-1===(p=Array.isArray(p)?p:p.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===p.indexOf(\"y\")&&(t.yLabel=void 0),-1===p.indexOf(\"z\")&&(t.zLabel=void 0),-1===p.indexOf(\"text\")&&(t.text=void 0),-1===p.indexOf(\"name\")&&(t.name=void 0)),t}function O(t,e,r){var n,i,o=r.container,s=r.fullLayout,l=s._size,c=r.event,u=!!e.hLinePoint,f=!!e.vLinePoint;if(o.selectAll(\".spikeline\").remove(),f||u){var d=p.combine(s.plot_bgcolor,s.paper_bgcolor);if(u){var m,v,y=e.hLinePoint;n=y&&y.xa,\"cursor\"===(i=y&&y.ya).spikesnap?(m=c.pointerX,v=c.pointerY):(m=n._offset+y.x,v=i._offset+y.y);var x,b,_=a.readability(y.color,d)<1.5?p.contrast(d):y.color,w=i.spikemode,T=i.spikethickness,k=i.spikecolor||_,M=g.getPxPosition(t,i);if(-1!==w.indexOf(\"toaxis\")||-1!==w.indexOf(\"across\")){if(-1!==w.indexOf(\"toaxis\")&&(x=M,b=m),-1!==w.indexOf(\"across\")){var A=i._counterDomainMin,S=i._counterDomainMax;\"free\"===i.anchor&&(A=Math.min(A,i.position),S=Math.max(S,i.position)),x=l.l+A*l.w,b=l.l+S*l.w}o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T,stroke:k,\"stroke-dasharray\":h.dashStyle(i.spikedash,T)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==w.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:M+(\"right\"!==i.side?T:-T),cy:v,r:T,fill:k}).classed(\"spikeline\",!0)}if(f){var E,C,L=e.vLinePoint;n=L&&L.xa,i=L&&L.ya,\"cursor\"===n.spikesnap?(E=c.pointerX,C=c.pointerY):(E=n._offset+L.x,C=i._offset+L.y);var I,P,z=a.readability(L.color,d)<1.5?p.contrast(d):L.color,O=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=g.getPxPosition(t,n);if(-1!==O.indexOf(\"toaxis\")||-1!==O.indexOf(\"across\")){if(-1!==O.indexOf(\"toaxis\")&&(I=F,P=C),-1!==O.indexOf(\"across\")){var B=n._counterDomainMin,N=n._counterDomainMax;\"free\"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),I=l.t+(1-N)*l.h,P=l.t+(1-B)*l.h}o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D,stroke:R,\"stroke-dasharray\":h.dashStyle(n.spikedash,D)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==O.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:E,cy:F-(\"top\"!==n.side?D:-D),r:D,fill:R}).classed(\"spikeline\",!0)}}}function D(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function R(t,e){return u.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":778,\"../../lib/events\":767,\"../../lib/override_cursor\":789,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../legend/defaults\":695,\"../legend/draw\":696,\"./constants\":677,\"./helpers\":679,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],681:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"./helpers\").isUnifiedHover;e.exports=function(t,e,r,o){function s(t){o.font[t]||(o.font[t]=e.legend?e.legend.font[t]:e.font[t])}o=o||{},e&&a(e.hovermode)&&(o.font||(o.font={}),s(\"size\"),s(\"family\"),s(\"color\"),e.legend?(o.bgcolor||(o.bgcolor=i.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r(\"hoverlabel.bgcolor\",o.bgcolor),r(\"hoverlabel.bordercolor\",o.bordercolor),r(\"hoverlabel.namelength\",o.namelength),n.coerceFont(r,\"hoverlabel.font\",o.font),r(\"hoverlabel.align\",o.align)}},{\"../../lib\":778,\"../color\":643,\"./helpers\":679}],682:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return void 0!==e[r]?e[r]:n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");return e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=(r[a]||{})[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==o.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)}},{\"../../lib\":778,\"./layout_attributes\":684}],683:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",(function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)}))},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":778,\"../dragelement\":662,\"./attributes\":674,\"./calc\":675,\"./click\":676,\"./constants\":677,\"./defaults\":678,\"./helpers\":679,\"./hover\":680,\"./layout_attributes\":684,\"./layout_defaults\":685,\"./layout_global_defaults\":686,d3:169}],684:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"drawclosedpath\",\"drawopenpath\",\"drawline\",\"drawrect\",\"drawcircle\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1,\"x unified\",\"y unified\"],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":856,\"./constants\":677}],685:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").isUnifiedHover,a=t(\"./layout_attributes\"),o=t(\"./hovermode_defaults\"),s=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r){function l(r,i){return n.coerce(t,e,a,r,i)}var c=o(t,e,r);c&&(l(\"hoverdistance\"),l(\"spikedistance\",i(c)?-1:void 0)),\"select\"===l(\"dragmode\")&&l(\"selectdirection\");var u=e._has(\"mapbox\"),f=e._has(\"geo\"),h=e._basePlotModules.length;\"zoom\"===e.dragmode&&((u||f)&&1===h||u&&f&&2===h)&&(e.dragmode=\"pan\"),s(t,e,l)}},{\"../../lib\":778,\"./helpers\":679,\"./hoverlabel_defaults\":681,\"./hovermode_defaults\":682,\"./layout_attributes\":684}],686:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,(function(r,i){return n.coerce(t,e,a,r,i)}))}},{\"../../lib\":778,\"./hoverlabel_defaults\":681,\"./layout_attributes\":684}],687:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),f=u*(1-o),h=0;h<i;h++){var p=c+u*h;l[a?i-1-h:h]=[p,p+f]}return l}function f(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,f,h=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;h?(o=r.subplots.length,f=r.subplots[0].length):(d&&(o=a.length),p&&(f=i.length));var m=s.newContainer(e,\"grid\"),v=k(\"rows\",o),y=k(\"columns\",f);if(v*y>1){if(!h&&!p&&!d)\"independent\"===k(\"pattern\")&&(h=!0);m._hasSubplotGrid=h;var x,b,_=\"top to bottom\"===k(\"roworder\"),w=h?.2:.1,T=h?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),m._domains={x:u(\"x\",k,w,x,y),y:u(\"y\",k,T,b,v,_)}}else delete e.grid}function k(t,e){return n.coerce(r,m,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,h=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,m=r.columns,v=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=h.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(m),w=x[n]||[];for(i=0;i<m;i++)if(v?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var T=c(e,h,\"x\"),k=c(e,h,\"y\");r.xaxes=f(T,p.xaxis,m,y,\"x\"),r.yaxes=f(k,p.yaxis,g,y,\"y\")}var M=r._anchors={},A=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,I=S.charAt(0),P=r[I+\"side\"];if(P.length<8)M[S]=\"free\";else if(\"x\"===I){if(\"t\"===P.charAt(0)===A?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){M[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){M[S]=o;break}}else if(\"l\"===P.charAt(0)?(E=0,C=1,L=m):(E=m-1,C=-1,L=-1),d){var O=y[S];for(n=E;n!==L;n+=C)if((s=l[O][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){M[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){M[S]=a;break}}}}}},{\"../../lib\":778,\"../../lib/regex\":795,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/domain\":855}],688:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834}],689:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,f=e._id.charAt(0),h=0;h<u.length;h++)if(c=\"images[\"+h+\"].\",(l=u[h])[f+\"ref\"]===e._id){var p=l[f],d=l[\"size\"+f],g=null,m=null;if(o){g=i(p,e.range);var v=d/Math.pow(10,g)/2;m=2*Math.log(v+Math.sqrt(1+v*v))/Math.LN10}else m=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(m)||(m=null):(g=null,m=null),a(c+f,g),a(c+\"size\"+f,m)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],690:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var f=c[u],h=i.coerceRef(t,e,l,f,\"paper\",void 0);if(\"paper\"!==h)i.getFromId(l,h)._imgIndices.push(e._index);i.coercePosition(e,l,a,h,f,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":688}],691:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/axis_ids\"),s=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,l=t._fullLayout,c=[],u={},f=[];for(r=0;r<l.images.length;r++){var h=l.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=o.ref2id(h.xref)+o.ref2id(h.yref);var p=l._plots[e];if(!p){f.push(h);continue}p.mainplot&&(e=p.mainplot.id),u[e]||(u[e]=[]),u[e].push(h)}else\"above\"===h.layer?c.push(h):f.push(h)}var d={left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},g={top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}};function m(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr(\"xmlns\",s.svg),e.source&&\"data:\"===e.source.slice(0,5))r.attr(\"xlink:href\",e.source),this._imgSrc=e.source;else{var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(i)}}function v(e){var r,o,s=n.select(this),c=a.getFromId(t,e.xref),u=a.getFromId(t,e.yref),f=\"domain\"===a.getRefType(e.xref),h=\"domain\"===a.getRefType(e.yref),p=l._size;r=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.sizex:Math.abs(c.l2p(e.sizex)-c.l2p(0)):e.sizex*p.w,o=void 0!==u?\"string\"==typeof e.yref&&h?u._length*e.sizey:Math.abs(u.l2p(e.sizey)-u.l2p(0)):e.sizey*p.h;var m,v,y=r*d[e.xanchor].offset,x=o*g[e.yanchor].offset,b=d[e.xanchor].sizing+g[e.yanchor].sizing;switch(m=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.x+c._offset:c.r2p(e.x)+c._offset:e.x*p.w+p.l,m+=y,v=void 0!==u?\"string\"==typeof e.yref&&h?u._length*(1-e.y)+u._offset:u.r2p(e.y)+u._offset:p.h-e.y*p.h+p.t,v+=x,e.sizing){case\"fill\":b+=\" slice\";break;case\"stretch\":b=\"none\"}s.attr({x:m,y:v,width:r,height:o,preserveAspectRatio:b,opacity:e.opacity});var _=(c&&\"domain\"!==a.getRefType(e.xref)?c._id:\"\")+(u&&\"domain\"!==a.getRefType(e.yref)?u._id:\"\");i.setClipUrl(s,_?\"clip\"+l._uid+_:null,t)}var y=l._imageLowerLayer.selectAll(\"image\").data(f),x=l._imageUpperLayer.selectAll(\"image\").data(c);y.enter().append(\"image\"),x.enter().append(\"image\"),y.exit().remove(),x.exit().remove(),y.each((function(t){m.bind(this)(t),v.bind(this)(t)})),x.each((function(t){m.bind(this)(t),v.bind(this)(t)}));var b=Object.keys(l._plots);for(r=0;r<b.length;r++){e=b[r];var _=l._plots[e];if(_.imagelayer){var w=_.imagelayer.selectAll(\"image\").data(u[e]||[]);w.enter().append(\"image\"),w.exit().remove(),w.each((function(t){m.bind(this)(t),v.bind(this)(t)}))}}}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../drawing\":665,d3:169}],692:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":688,\"./convert_coords\":689,\"./defaults\":690,\"./draw\":691}],693:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemwidth:{valType:\"number\",min:30,dflt:30,editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"legend\"},font:n({editType:\"legend\"}),side:{valType:\"enumerated\",values:[\"top\",\"left\",\"top left\"],editType:\"legend\"},editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":856,\"../color/attributes\":642}],694:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,itemGap:5}},{}],695:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,f=!1,h=\"normal\",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend&&!(d._module&&d._module.attributes&&d._module.attributes.showlegend&&!1===d._module.attributes.showlegend.dflt))&&(u++,d.showlegend&&(f=!0,(n.traceIs(d,\"pie-like\")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(d.fill))&&(h=l.isGrouped({traceorder:h})?\"grouped+reversed\":\"reversed\"),void 0!==d.legendgroup&&\"\"!==d.legendgroup&&(h=l.isReversed({traceorder:h})?\"reversed+grouped\":\"grouped\"))}var g=i.coerce(t,e,s,\"showlegend\",f&&u>1);if(!1!==g||c.uirevision){var m=a.newContainer(e,\"legend\");if(_(\"uirevision\",e.uirevision),!1!==g){_(\"bgcolor\",e.paper_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),i.coerceFont(_,\"font\",e.font);var v,y,x,b=_(\"orientation\");\"h\"===b?(v=0,n.getComponentMethod(\"rangeslider\",\"isVisible\")(t.xaxis)?(y=1.1,x=\"bottom\"):(y=-.1,x=\"top\")):(v=1.02,y=1,x=\"auto\"),_(\"traceorder\",h),l.isGrouped(e.legend)&&_(\"tracegroupgap\"),_(\"itemsizing\"),_(\"itemwidth\"),_(\"itemclick\"),_(\"itemdoubleclick\"),_(\"x\",v),_(\"xanchor\"),_(\"y\",y),_(\"yanchor\",x),_(\"valign\"),i.noneOrAll(c,m,[\"x\",\"y\"]),_(\"title.text\")&&(_(\"title.side\",\"h\"===b?\"left\":\"top\"),i.coerceFont(_,\"title.font\",e.font))}}function _(t,e){return i.coerce(c,m,o,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/layout_attributes\":882,\"../../registry\":911,\"./attributes\":693,\"./helpers\":699}],696:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,m=d.FROM_TL,v=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout((function(){h(r,t,n)}),t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&h(r,t,n)}}function w(t,e,r){var n,a=t.data()[0][0],s=a.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,h=r._main&&e._context.edits.legendText&&!l,d=r._maxNameLength;r.entries?n=a.text:(n=l?a.label:s.name,s._meta&&(n=i.templateString(n,s._meta)));var g=i.ensureSingle(t,\"text\",\"legendtext\");g.attr(\"text-anchor\",\"start\").call(c.font,r.font).text(h?T(n,d):n);var m=r.itemwidth+2*p.itemGap;f.positionText(g,m,0),h?g.call(f.makeEditable,{gd:e,text:n}).call(M,t,e,r).on(\"edit\",(function(n){this.text(T(n,d)).call(M,t,e,r);var s=a.trace._fullInput||{},l={};if(o.hasTransform(s,\"groupby\")){var c=o.getTransformIndices(s,\"groupby\"),f=c[c.length-1],h=i.keyedContainer(s,\"transforms[\"+f+\"].styles\",\"target\",\"value.name\");h.set(a.trace._group,n),l=h.constructUpdate()}else l.name=n;return o.call(\"_guiRestyle\",e,l,u)})):M(g,t,e,r)}function T(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function k(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",(function(t){e._context.staticPlot||t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\"),t.call(u.fill,\"rgba(0,0,0,0)\")}));e._context.staticPlot||(s.on(\"mousedown\",(function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)})),s.on(\"mouseup\",(function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})))}function M(t,e,r,n){n._main||t.attr(\"data-notex\",!0),f.convertToTspans(t,r,(function(){!function(t,e,r){var n=t.data()[0][0];if(r._main&&n&&!n.trace.showlegend)return void t.remove();var i=t.select(\"g[class*=math-group]\"),a=i.node();r||(r=e._fullLayout.legend);var o,s,l=r.borderwidth,u=(n?r:r.title).font.size*g;if(a){var h=c.bBox(a);o=h.height,s=h.width,n?c.setTranslate(i,0,.25*o):c.setTranslate(i,l,.75*o+l)}else{var d=t.select(n?\".legendtext\":\".legendtitletext\"),m=f.lineCount(d),v=d.node();o=u*m,s=v?c.bBox(v).width:0;var y=u*((m-1)/2-.3);if(n){var x=r.itemwidth+2*p.itemGap;f.positionText(d,x,-y)}else f.positionText(d,p.titlePad+l,u+l)}n?(n.lineHeight=u,n.height=Math.max(o,16)+3,n.width=s):(r._titleWidth=s,r._titleHeight=o)}(e,r,n)}))}function A(t){return i.isRightAnchor(t)?\"right\":i.isCenterAnchor(t)?\"center\":\"left\"}function S(t){return i.isBottomAnchor(t)?\"bottom\":i.isMiddleAnchor(t)?\"middle\":\"top\"}e.exports=function(t,e){var r,s=t._fullLayout,f=\"legend\"+s._uid;if(e?(r=e.layer,f+=\"-hover\"):((e=s.legend||{})._main=!0,r=s._infolayer),r){var h;if(t._legendMouseDownTime||(t._legendMouseDownTime=0),e._main){if(!t.calcdata)return;h=s.showlegend&&y(t.calcdata,e)}else{if(!e.entries)return;h=y(e.entries,e)}var d=s.hiddenlabels||[];if(e._main&&(!s.showlegend||!h.length))return r.selectAll(\".legend\").remove(),s._topdefs.select(\"#\"+f).remove(),a.autoMargin(t,\"legend\");var g=i.ensureSingle(r,\"g\",\"legend\",(function(t){e._main&&t.attr(\"pointer-events\",\"all\")})),T=i.ensureSingleById(s._topdefs,\"clipPath\",f,(function(t){t.append(\"rect\")})),E=i.ensureSingle(g,\"rect\",\"bg\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));E.call(u.stroke,e.bordercolor).call(u.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\");var C=i.ensureSingle(g,\"g\",\"scrollbox\"),L=e.title;if(e._titleWidth=0,e._titleHeight=0,L.text){var I=i.ensureSingle(C,\"text\",\"legendtitletext\");I.attr(\"text-anchor\",\"start\").call(c.font,L.font).text(L.text),M(I,C,t,e)}else C.selectAll(\".legendtitletext\").remove();var P=i.ensureSingle(g,\"rect\",\"scrollbar\",(function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)})),z=C.selectAll(\"g.groups\").data(h);z.enter().append(\"g\").attr(\"class\",\"groups\"),z.exit().remove();var O=z.selectAll(\"g.traces\").data(i.identity);O.enter().append(\"g\").attr(\"class\",\"traces\"),O.exit().remove(),O.style(\"opacity\",(function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==d.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1})).each((function(){n.select(this).call(w,t,e)})).call(x,t,e).each((function(){e._main&&n.select(this).call(k,t)})),i.syncOrAsync([a.previousPromises,function(){return function(t,e,r,i){var a=t._fullLayout;i||(i=a.legend);var o=a._size,s=b.isVertical(i),l=b.isGrouped(i),u=i.borderwidth,f=2*u,h=p.itemGap,d=i.itemwidth+2*h,g=2*(u+h),m=S(i),v=i.y<0||0===i.y&&\"top\"===m,y=i.y>1||1===i.y&&\"bottom\"===m;i._maxHeight=Math.max(v||y?a.height/2:o.h,30);var x=0;i._width=0,i._height=0;var _=function(t){var e=0,r=0,n=t.title.side;n&&(-1!==n.indexOf(\"left\")&&(e=t._titleWidth),-1!==n.indexOf(\"top\")&&(r=t._titleHeight));return[e,r]}(i);if(s)r.each((function(t){var e=t[0].height;c.setTranslate(this,u+_[0],u+_[1]+i._height+e/2+h),i._height+=e,i._width=Math.max(i._width,t[0].width)})),x=d+i._width,i._width+=h+d+f,i._height+=g,l&&(e.each((function(t,e){c.setTranslate(this,0,e*i.tracegroupgap)})),i._height+=(i._lgroupsLength-1)*i.tracegroupgap);else{var w=A(i),T=i.x<0||0===i.x&&\"right\"===w,k=i.x>1||1===i.x&&\"left\"===w,M=y||v,E=a.width/2;i._maxWidth=Math.max(T?M&&\"left\"===w?o.l+o.w:E:k?M&&\"right\"===w?o.r+o.w:E:o.w,2*d);var C=0,L=0;r.each((function(t){var e=t[0].width+d;C=Math.max(C,e),L+=e})),x=null;var I=0;if(l){var P=0,z=0,O=0;e.each((function(){var t=0,e=0;n.select(this).selectAll(\"g.traces\").each((function(r){var n=r[0].height;c.setTranslate(this,_[0],_[1]+u+h+n/2+e),e+=n,t=Math.max(t,d+r[0].width)})),P=Math.max(P,e);var r=t+h;r+u+z>i._maxWidth&&(I=Math.max(I,z),z=0,O+=P+i.tracegroupgap,P=e),c.setTranslate(this,z,O),z+=r})),i._width=Math.max(I,z)+u,i._height=O+P+g}else{var D=r.size(),R=L+f+(D-1)*h<i._maxWidth,F=0,B=0,N=0,j=0;r.each((function(t){var e=t[0].height,r=d+t[0].width,n=(R?r:C)+h;n+u+B-h>=i._maxWidth&&(I=Math.max(I,j),B=0,N+=F,i._height+=F,F=0),c.setTranslate(this,_[0]+u+B,_[1]+u+N+e/2+h),j=B+r+h,B+=n,F=Math.max(F,e)})),R?(i._width=B+f,i._height=F+g):(i._width=Math.max(I,j)+f,i._height+=F+g)}}i._width=Math.ceil(Math.max(i._width+_[0],i._titleWidth+2*(u+p.titlePad))),i._height=Math.ceil(Math.max(i._height+_[1],i._titleHeight+2*(u+p.itemGap))),i._effHeight=Math.min(i._height,i._maxHeight);var U=t._context.edits,V=U.legendText||U.legendPosition;r.each((function(t){var e=n.select(this).select(\".legendtoggle\"),r=t[0].height,i=V?d:x||d+t[0].width;s||(i+=h/2),c.setRect(e,0,-r/2,i,r)}))}(t,z,O,e)},function(){if(!e._main||!function(t){var e=t._fullLayout.legend,r=A(e),n=S(e);return a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*m[r],r:e._width*v[r],b:e._effHeight*v[n],t:e._effHeight*m[n]})}(t)){var u,h,d,y,x=s._size,b=e.borderwidth,w=x.l+x.w*e.x-m[A(e)]*e._width,k=x.t+x.h*(1-e.y)-m[S(e)]*e._effHeight;if(e._main&&s.margin.autoexpand){var M=w,L=k;w=i.constrain(w,0,s.width-e._width),k=i.constrain(k,0,s.height-e._effHeight),w!==M&&i.log(\"Constrain legend.x to make legend fit inside graph\"),k!==L&&i.log(\"Constrain legend.y to make legend fit inside graph\")}if(e._main&&c.setTranslate(g,w,k),P.on(\".drag\",null),g.on(\"wheel\",null),!e._main||e._height<=e._maxHeight||t._context.staticPlot){var I=e._effHeight;e._main||(I=e._height),E.attr({width:e._width-b,height:I-b,x:b/2,y:b/2}),c.setTranslate(C,0,0),T.select(\"rect\").attr({width:e._width-2*b,height:I-2*b,x:b,y:b}),c.setClipUrl(C,f,t),c.setRect(P,0,0,0,0),delete e._scrollY}else{var z,O,D,R=Math.max(p.scrollBarMinHeight,e._effHeight*e._effHeight/e._height),F=e._effHeight-R-2*p.scrollBarMargin,B=e._height-e._effHeight,N=F/B,j=Math.min(e._scrollY||0,B);E.attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-b,x:b/2,y:b/2}),T.select(\"rect\").attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-2*b,x:b,y:b+j}),c.setClipUrl(C,f,t),q(j,R,N),g.on(\"wheel\",(function(){q(j=i.constrain(e._scrollY+n.event.deltaY/F*B,0,B),R,N),0!==j&&j!==B&&n.event.preventDefault()}));var U=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;z=\"touchstart\"===t.type?t.changedTouches[0].clientY:t.clientY,D=j})).on(\"drag\",(function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(O=\"touchmove\"===t.type?t.changedTouches[0].clientY:t.clientY,q(j=function(t,e,r){var n=(r-e)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));P.call(U);var V=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;\"touchstart\"===t.type&&(z=t.changedTouches[0].clientY,D=j)})).on(\"drag\",(function(){var t=n.event.sourceEvent;\"touchmove\"===t.type&&(O=t.changedTouches[0].clientY,q(j=function(t,e,r){var n=(e-r)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));C.call(V)}if(t._context.edits.legendPosition)g.classed(\"cursor-move\",!0),l.init({element:g.node(),gd:t,prepFn:function(){var t=c.getTranslate(g);d=t.x,y=t.y},moveFn:function(t,r){var n=d+t,i=y+r;c.setTranslate(g,n,i),u=l.align(n,0,x.l,x.l+x.w,e.xanchor),h=l.align(i,0,x.t+x.h,x.t,e.yanchor)},doneFn:function(){void 0!==u&&void 0!==h&&o.call(\"_guiRelayout\",t,{\"legend.x\":u,\"legend.y\":h})},clickFn:function(e,n){var i=r.selectAll(\"g.traces\").filter((function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom}));i.size()>0&&_(t,g,i,e,n)}})}function q(r,n,i){e._scrollY=t._fullLayout.legend._scrollY=r,c.setTranslate(C,0,-r),c.setRect(P,e._width,p.scrollBarMargin+r*i,p.scrollBarWidth,n),T.select(\"rect\").attr(\"y\",b+r)}}],t)}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/events\":767,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":694,\"./get_legend_data\":697,\"./handle_click\":698,\"./helpers\":699,\"./style\":701,d3:169}],697:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0,f=0,h=e._main;function p(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var d=t[r],g=d[0],m=g.trace,v=m.legendgroup;if(!h||m.visible&&m.showlegend)if(n.traceIs(m,\"pie-like\"))for(c[v]||(c[v]={}),a=0;a<d.length;a++){var y=d[a].label;c[v][y]||(p(v,{label:y,color:d[a].color,i:d[a].i,trace:m,pts:d[a].pts}),c[v][y]=!0,f=Math.max(f,(y||\"\").length))}else p(v,g),f=Math.max(f,(m.name||\"\").length)}if(!s.length)return[];var x,b,_=s.length;if(l&&i.isGrouped(e))for(b=new Array(_),r=0;r<_;r++)x=o[s[r]],b[r]=i.isReversed(e)?x.reverse():x;else{for(b=[new Array(_)],r=0;r<_;r++)x=o[s[r]][0],b[0][i.isReversed(e)?_-r-1:r]=x;_=1}return e._lgroupsLength=_,e._maxNameLength=f,b}},{\"../../registry\":911,\"./helpers\":699}],698:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,f,h,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],m=t.data()[0][0],v=e._fullData,y=m.trace,x=y.legendgroup,b={},_=[],w=[],T=[];if(i.traceIs(y,\"pie-like\")){var k=m.label,M=g.indexOf(k);\"toggle\"===s?-1===M?g.push(k):g.splice(M,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach((function(t){k!==t.label&&g.push(t.label)})),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===M&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var A,S=x&&x.length,E=[];if(S)for(u=0;u<v.length;u++)(A=v[u]).visible&&A.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<v.length;u++)!1!==v[u].visible&&v[u].legendgroup===x&&B(v[u],C);else B(y,C)}else if(\"toggleothers\"===s){var L,I,P,z,O=!0;for(u=0;u<v.length;u++)if(L=v[u]===y,P=!0!==v[u].showlegend,!(L||P||(I=S&&v[u].legendgroup===x)||!0!==v[u].visible||i.traceIs(v[u],\"notLegendIsolatable\"))){O=!1;break}for(u=0;u<v.length;u++)if(!1!==v[u].visible&&!i.traceIs(v[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":B(v[u],!0);break;case!0:z=!!O||\"legendonly\",L=v[u]===y,P=!0!==v[u].showlegend&&!v[u].legendgroup,I=L||S&&v[u].legendgroup===x,B(v[u],!(!I&&!P)||z)}}for(u=0;u<w.length;u++)if(h=w[u]){var D=h.constructUpdate(),R=Object.keys(D);for(f=0;f<R.length;f++)p=R[f],(b[p]=b[p]||[])[T[u]]=D[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],f=0;f<_.length;f++)b[p].hasOwnProperty(f)||(b[p][f]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function F(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function B(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),T[r.index]=F(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;F(r.index,\"visible\",c)}}}},{\"../../lib\":778,\"../../registry\":911}],699:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],700:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":693,\"./defaults\":695,\"./draw\":696,\"./style\":701}],701:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../colorscale/helpers\").extractOpts,u=t(\"../../traces/scatter/subtypes\"),f=t(\"../../traces/pie/style_one\"),h=t(\"../../traces/pie/helpers\").castOption,p=t(\"./constants\");function d(t,e){return(e?\"radial\":\"horizontal\")+(t?\"\":\"reversed\")}e.exports=function(t,e,r){var g=e._fullLayout;r||(r=g.legend);var m=\"constant\"===r.itemsizing,v=r.itemwidth,y=(v+2*p.itemGap)/2,x=o(y,0),b=function(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return m?n:Math.min(i,r)};function _(t,e,r){var a=t[0].trace,o=a.marker||{},s=o.line||{},c=r?a.visible&&a.type===r:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),u.exit().remove(),u.each((function(t){var e=n.select(this),r=t[0],i=b(r.mlw,o.line,5,2);e.style(\"stroke-width\",i+\"px\").call(l.fill,r.mc||o.color),i&&l.stroke(e,r.mlc||s.color)}))}function w(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:i.traceIs(s,r),c=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(c.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),c.exit().remove(),c.size()){var u=(s.marker||{}).line,p=b(h(u.width,o.pts),u,5,2),d=a.minExtend(s,{marker:{line:{width:p}}});d.marker.line.color=u.color;var g=a.minExtend(o,{trace:d});f(c,g,d)}}t.each((function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var s=r.valign,l=t[0].lineHeight,c=t[0].height;if(\"middle\"!==s&&l&&c){var u={top:1,bottom:-1}[s]*(.5*(l-c+3));i.attr(\"transform\",o(0,u))}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var f=i.selectAll(\"g.legendsymbols\").data([t]);f.enter().append(\"g\").classed(\"legendsymbols\",!0),f.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)})).each((function(t){var r,i=t[0].trace,o=[];if(i.visible)switch(i.type){case\"histogram2d\":case\"heatmap\":o=[[\"M-15,-2V4H15V-2Z\"]],r=!0;break;case\"choropleth\":case\"choroplethmapbox\":o=[[\"M-6,-6V6H6V-6Z\"]],r=!0;break;case\"densitymapbox\":o=[[\"M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0\"]],r=\"radial\";break;case\"cone\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 L6,0Z\"]],r=!1;break;case\"streamtube\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z\"]],r=!1;break;case\"surface\":o=[[\"M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z\"],[\"M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z\"]],r=!0;break;case\"mesh3d\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!1;break;case\"volume\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!0;break;case\"isosurface\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6 A12,24 0 0,0 6,-6 L0,6Z\"]],r=!1}var u=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legend3dandfriends\").data(o);u.enter().append(\"path\").classed(\"legend3dandfriends\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),u.exit().remove(),u.each((function(t,o){var u,f=n.select(this),h=c(i),p=h.colorscale,g=h.reversescale;if(p){if(!r){var m=p.length;u=0===o?p[g?m-1:0][1]:1===o?p[g?0:m-1][1]:p[Math.floor((m-1)/2)][1]}}else{var v=i.vertexcolor||i.facecolor||i.color;u=a.isArrayOrTypedArray(v)?v[o]||v[0]:v}f.attr(\"d\",t[0]),u?f.call(l.fill,u):f.call((function(t){if(t.size()){var n=\"legendfill-\"+i.uid;s.gradient(t,e,n,d(g,\"radial\"===r),p,\"fill\")}}))}))})).each((function(t){var e=t[0].trace,r=\"waterfall\"===e.type;if(t[0]._distinct&&r){var i=t[0].trace[t[0].dir].marker;return t[0].mc=i.color,t[0].mlw=i.line.width,t[0].mlc=i.line.color,_(t,this,\"waterfall\")}var a=[];e.visible&&r&&(a=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(a);o.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),o.exit().remove(),o.each((function(t){var r=n.select(this),i=e[t[0]].marker,a=b(void 0,i.line,5,2);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(l.fill,i.color),a&&r.call(l.stroke,i.line.color)}))})).each((function(t){_(t,this,\"funnel\")})).each((function(t){_(t,this)})).each((function(t){var r=t[0].trace,o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(r.visible&&i.traceIs(r,\"box-violin\")?[t]:[]);o.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),o.exit().remove(),o.each((function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==l.opacity(r.fillcolor)||0!==l.opacity((r.line||{}).color)){var i=b(void 0,r.line,5,2);t.style(\"stroke-width\",i+\"px\").call(l.fill,r.fillcolor),i&&l.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:m?12:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});o.call(s.pointStyle,c,e)}}))})).each((function(t){w(t,this,\"funnelarea\")})).each((function(t){w(t,this,\"pie\")})).each((function(t){var r,i,o=t[0],l=o.trace,f=l.visible&&l.fill&&\"none\"!==l.fill,h=u.hasLines(l),p=l.contours,g=!1,m=!1,y=c(l),x=y.colorscale,_=y.reversescale;if(p){var w=p.coloring;\"lines\"===w?g=!0:h=\"none\"===w||\"heatmap\"===w||p.showlines,\"constraint\"===p.type?f=\"=\"!==p._operation:\"fill\"!==w&&\"heatmap\"!==w||(m=!0)}var T=u.hasMarkers(l)||u.hasText(l),k=f||m,M=h||g,A=T||!k?\"M5,0\":M?\"M5,-2\":\"M5,-3\",S=n.select(this),E=S.select(\".legendfill\").selectAll(\"path\").data(f||m?[t]:[]);if(E.enter().append(\"path\").classed(\"js-fill\",!0),E.exit().remove(),E.attr(\"d\",A+\"h\"+v+\"v6h-\"+v+\"z\").call(f?s.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+l.uid;s.gradient(t,e,r,d(_),x,\"fill\")}}),h||g){var C=b(void 0,l.line,10,5);i=a.minExtend(l,{line:{width:C}}),r=[a.minExtend(o,{trace:i})]}var L=S.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);L.enter().append(\"path\").classed(\"js-line\",!0),L.exit().remove(),L.attr(\"d\",A+(g?\"l\"+v+\",0.0001\":\"h\"+v)).call(h?s.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+l.uid;s.lineGroupStyle(t),s.gradient(t,e,r,d(_),x,\"stroke\")}})})).each((function(t){var r,i,o=t[0],l=o.trace,c=u.hasMarkers(l),f=u.hasText(l),h=u.hasLines(l);function p(t,e,r,n){var i=a.nestedProperty(l,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(m&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function d(t){return o._distinct&&o.index&&t[o.index]?t[o.index]:t[0]}if(c||f||h){var g={},v={};if(c){g.mc=p(\"marker.color\",d),g.mx=p(\"marker.symbol\",d),g.mo=p(\"marker.opacity\",a.mean,[.2,1]),g.mlc=p(\"marker.line.color\",d),g.mlw=p(\"marker.line.width\",a.mean,[0,5],2),v.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var y=p(\"marker.size\",a.mean,[2,16],12);g.ms=y,v.marker.size=y}h&&(v.line={width:p(\"line.width\",d,[0,10],5)}),f&&(g.tx=\"Aa\",g.tp=p(\"textposition\",d),g.ts=10,g.tc=p(\"textfont.color\",d),g.tf=p(\"textfont.family\",d)),r=[a.minExtend(o,g)],(i=a.minExtend(l,v)).selectedpoints=null,i.texttemplate=null}var b=n.select(this).select(\"g.legendpoints\"),_=b.selectAll(\"path.scatterpts\").data(c?r:[]);_.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",x),_.exit().remove(),_.call(s.pointStyle,i,e),c&&(r[0].mrc=3);var w=b.selectAll(\"g.pointtext\").data(f?r:[]);w.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",x),w.exit().remove(),w.selectAll(\"text\").call(s.textPointStyle,i,e)})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(e.visible&&\"candlestick\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"stroke-width\",o+\"px\").call(l.fill,a.fillcolor),o&&l.stroke(i,a.line.color)}))})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(e.visible&&\"ohlc\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"fill\",\"none\").call(s.dashLine,a.line.dash,o),o&&l.stroke(i,a.line.color)}))}))}},{\"../../lib\":778,\"../../registry\":911,\"../../traces/pie/helpers\":1166,\"../../traces/pie/style_one\":1172,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale/helpers\":654,\"../drawing\":665,\"./constants\":694,d3:169}],702:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../fonts/ploticon\"),s=t(\"../shapes/draw\").eraseActiveShape,l=t(\"../../lib\"),c=l._,u=e.exports={};function f(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},f=a.list(t,null,!0),h=c._cartesianSpikesEnabled;if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,m=(1-d)/2;for(i=0;i<f.length;i++)if(!(r=f[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var v=r._rangeInitial.slice();u[p+\".range[0]\"]=v[0],u[p+\".range[1]\"]=v[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==h||r._showSpikeInitial||(h=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+m*y[1],g*y[1]+m*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}}else\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l||(l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l)),u[s]=l;c._cartesianSpikesEnabled=h,n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function p(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=\"resetLastSave\"===r,a=\"resetDefault\"===r,o=t._fullLayout,s=o._subplots.gl3d||[],l={},c=0;c<s.length;c++){var u,f=s[c],h=f+\".camera\",p=f+\".aspectratio\",d=f+\".aspectmode\",g=o[f]._scene;i?(l[h+\".up\"]=g.viewInitial.up,l[h+\".eye\"]=g.viewInitial.eye,l[h+\".center\"]=g.viewInitial.center,u=!0):a&&(l[h+\".up\"]=null,l[h+\".eye\"]=null,l[h+\".center\"]=null,u=!0),u&&(l[p+\".x\"]=g.viewInitial.aspectratio.x,l[p+\".y\"]=g.viewInitial.aspectratio.y,l[p+\".z\"]=g.viewInitial.aspectratio.z,l[d]=g.viewInitial.aspectmode)}n.call(\"_guiRelayout\",t,l)}function d(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d||[],o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],f=i[u],h=u+\".hovermode\";s[h]=f.hovermode,l[h]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=f[d].showspikes}}r._previousVal=s}return l}function g(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var f=u.projection.scale,h=\"in\"===a?2*f:.5*f;n.call(\"_guiRelayout\",t,c+\".projection.scale\",h)}}\"reset\"===i&&x(t,\"geo\")}function m(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=m(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function y(t,e){for(var r=e.currentTarget.getAttribute(\"data-val\"),i=t._fullLayout,a=i._subplots.mapbox||[],o={},s=0;s<a.length;s++){var l=a[s],c=i[l].zoom,u=\"in\"===r?1.05*c:c/1.05;o[l+\".zoom\"]=u}n.call(\"_guiRelayout\",t,o)}function x(t,e){for(var r=t._fullLayout,i=r._subplots[e]||[],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var f=c[u];a[s+\".\"+f]=l[f]}n.call(\"_guiRelayout\",t,a)}u.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return c(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:o.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};l.notifier(c(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&l.isIE()&&(l.notifier(c(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach((function(t){t in e&&(r[t]=e[t])})),n.call(\"downloadImage\",t,r).then((function(e){l.notifier(c(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")})).catch((function(){l.notifier(c(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")}))}},u.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.disk,click:function(t){i.sendDataToCloud(t)}},u.editInChartStudio={name:\"editInChartStudio\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.pencil,click:function(t){i.sendDataToCloud(t)}},u.zoom2d={name:\"zoom2d\",title:function(t){return c(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:o.zoombox,click:f},u.pan2d={name:\"pan2d\",title:function(t){return c(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:o.pan,click:f},u.select2d={name:\"select2d\",title:function(t){return c(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:o.selectbox,click:f},u.lasso2d={name:\"lasso2d\",title:function(t){return c(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:o.lasso,click:f},u.drawclosedpath={name:\"drawclosedpath\",title:function(t){return c(t,\"Draw closed freeform\")},attr:\"dragmode\",val:\"drawclosedpath\",icon:o.drawclosedpath,click:f},u.drawopenpath={name:\"drawopenpath\",title:function(t){return c(t,\"Draw open freeform\")},attr:\"dragmode\",val:\"drawopenpath\",icon:o.drawopenpath,click:f},u.drawline={name:\"drawline\",title:function(t){return c(t,\"Draw line\")},attr:\"dragmode\",val:\"drawline\",icon:o.drawline,click:f},u.drawrect={name:\"drawrect\",title:function(t){return c(t,\"Draw rectangle\")},attr:\"dragmode\",val:\"drawrect\",icon:o.drawrect,click:f},u.drawcircle={name:\"drawcircle\",title:function(t){return c(t,\"Draw circle\")},attr:\"dragmode\",val:\"drawcircle\",icon:o.drawcircle,click:f},u.eraseshape={name:\"eraseshape\",title:function(t){return c(t,\"Erase active shape\")},icon:o.eraseshape,click:s},u.zoomIn2d={name:\"zoomIn2d\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:f},u.zoomOut2d={name:\"zoomOut2d\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:f},u.autoScale2d={name:\"autoScale2d\",title:function(t){return c(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:o.autoscale,click:f},u.resetScale2d={name:\"resetScale2d\",title:function(t){return c(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:o.home,click:f},u.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return c(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:f},u.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return c(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:o.tooltip_compare,gravity:\"ne\",click:f},u.zoom3d={name:\"zoom3d\",title:function(t){return c(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:o.zoombox,click:h},u.pan3d={name:\"pan3d\",title:function(t){return c(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:o.pan,click:h},u.orbitRotation={name:\"orbitRotation\",title:function(t){return c(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:o[\"3d_rotate\"],click:h},u.tableRotation={name:\"tableRotation\",title:function(t){return c(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:o[\"z-axis\"],click:h},u.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return c(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:o.home,click:p},u.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return c(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:o.movie,click:p},u.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);n.call(\"_guiRelayout\",t,r)}},u.zoomInGeo={name:\"zoomInGeo\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:g},u.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:g},u.resetGeo={name:\"resetGeo\",title:function(t){return c(t,\"Reset\")},attr:\"reset\",val:null,icon:o.autoscale,click:g},u.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:v},u.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return c(t,\"Reset view\")},icon:o.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},u.toggleHover={name:\"toggleHover\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);r.hovermode=m(t),n.call(\"_guiRelayout\",t,r)}},u.resetViews={name:\"resetViews\",title:function(t){return c(t,\"Reset views\")},icon:o.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),f(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),p(t,e),x(t,\"geo\"),x(t,\"mapbox\")}},u.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return c(t,\"Toggle Spike Lines\")},icon:o.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled=\"on\"===r?\"off\":\"on\",n.call(\"_guiRelayout\",t,function(t){for(var e=\"on\"===t._fullLayout._cartesianSpikesEnabled,r=a.list(t,null,!0),n={},i=0;i<r.length;i++){var o=r[i];n[o._name+\".showspikes\"]=!!e||o._showSpikeInitial}return n}(t))}},u.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){x(t,\"mapbox\")}},u.zoomInMapbox={name:\"zoomInMapbox\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:y},u.zoomOutMapbox={name:\"zoomOutMapbox\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:y}},{\"../../fonts/ploticon\":757,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../shapes/draw\":724}],703:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":704}],704:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"../fx/helpers\").isUnifiedHover,s=t(\"./modebar\"),l=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,u=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var f,h=r.modeBarButtons;f=Array.isArray(h)&&h.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===l[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=l[i]}}return t}(h):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context,u=s.modeBarButtonsToRemove,f=s.modeBarButtonsToAdd,h=e._has(\"cartesian\"),p=e._has(\"gl3d\"),d=e._has(\"geo\"),g=e._has(\"pie\"),m=e._has(\"funnelarea\"),v=e._has(\"gl2d\"),y=e._has(\"ternary\"),x=e._has(\"mapbox\"),b=e._has(\"polar\"),_=e._has(\"sankey\"),w=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),T=o(e.hovermode),k=[];function M(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===u.indexOf(n)&&e.push(l[n])}k.push(e)}}var A=[\"toImage\"];s.showEditInChartStudio?A.push(\"editInChartStudio\"):s.showSendToCloud&&A.push(\"sendDataToCloud\");M(A);var S=[],E=[],C=[],L=[];(h||v||g||m||y)+d+p+x+b>1?(E=[\"toggleHover\"],C=[\"resetViews\"]):d?(S=[\"zoomInGeo\",\"zoomOutGeo\"],E=[\"hoverClosestGeo\"],C=[\"resetGeo\"]):p?(E=[\"hoverClosest3d\"],C=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):x?(S=[\"zoomInMapbox\",\"zoomOutMapbox\"],E=[\"toggleHover\"],C=[\"resetViewMapbox\"]):v?E=[\"hoverClosestGl2d\"]:g?E=[\"hoverClosestPie\"]:_?(E=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],C=[\"resetViewSankey\"]):E=[\"toggleHover\"];h&&(E=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0}(r)||T)&&(E=[]);!h&&!v||w||(S=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==C[0]&&(C=[\"resetScale2d\"]));p?L=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(h||v)&&!w||y?L=[\"zoom2d\",\"pan2d\"]:x||d?L=[\"pan2d\"]:b&&(L=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&L.push(\"select2d\",\"lasso2d\");if(Array.isArray(f)){for(var I=[],P=0;P<f.length;P++){var z=f[P];\"string\"==typeof z?-1!==c.indexOf(z)&&(e._has(\"mapbox\")||e._has(\"cartesian\"))&&L.push(z):I.push(z)}f=I}return M(L),M(S.concat(C)),M(E),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(k,f)}(t),u?u.update(t,f):e._modeBar=s(t,f)}else u&&(u.destroy(),delete e._modeBar)};var c=[\"drawline\",\"drawopenpath\",\"drawclosedpath\",\"drawcircle\",\"drawrect\",\"eraseshape\"]},{\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../../traces/scatter/subtypes\":1212,\"../fx/helpers\":679,\"./buttons\":702,\"./modebar\":705}],705:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var f=this.getLogo();r.watermark&&(f.className=f.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(f,this.element.childNodes[0]):this.element.appendChild(f),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach((function(t){var r=e.createGroup();t.forEach((function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)})),e.element.appendChild(r)}))},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",(function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)})),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach((function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}}))},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plotly.com/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":757,\"../../lib\":778,d3:169,\"fast-isnumeric\":241}],706:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../color/attributes\":642}],707:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],708:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,f){var h=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(h,p,s,t,e)}if(d(\"visible\",o(h,p,{name:\"buttons\",handleItemDefaults:c,calendar:f}).length>0)){var g=function(t,e,r){for(var n=r.filter((function(r){return e[r].anchor===t._id})),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var m=d(\"bgcolor\");d(\"activecolor\",i.contrast(m,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../color\":643,\"./attributes\":706,\"./constants\":707}],709:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=l.strTranslate,u=t(\"../../lib/svg_text_utils\"),f=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR,m=t(\"./constants\"),v=t(\"./get_update_object\");function y(t){return t._id}function x(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));n.attr({rx:m.rx,ry:m.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",(function(t){t.attr(\"text-anchor\",\"middle\")})).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call((function(t){u.convertToTspans(t,n)}))}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=f.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),y);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each((function(e){var r=n.select(this),o=e,f=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(f.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each((function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(x,f,e),r.call(b,f,e,t),r.on(\"click\",(function(){t._dragged||i.call(\"_guiRelayout\",t,a)})),r.on(\"mouseover\",(function(){e._isHovered=!0,r.call(x,f,e)})),r.on(\"mouseout\",(function(){e._isHovered=!1,r.call(x,f,e)}))})),function(t,e,r,i,o){var f=0,h=0,v=r.borderwidth;e.each((function(){var t=n.select(this).select(\".selector-text\"),e=r.font.size*p,i=Math.max(e*u.lineCount(t),16)+3;h=Math.max(h,i)})),e.each((function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*p,l=u.lineCount(i),d=Math.max(a+10,m.minButtonWidth);t.attr(\"transform\",c(v+f,v)),e.attr({x:0,y:0,width:d,height:h}),u.positionText(i,d/2,h/2-(l-1)*o/2+3),f+=d+5}));var y=t._fullLayout._size,x=y.l+y.w*r.x,b=y.t+y.h*(1-r.y),_=\"left\";l.isRightAnchor(r)&&(x-=f,_=\"right\");l.isCenterAnchor(r)&&(x-=f/2,_=\"center\");var w=\"top\";l.isBottomAnchor(r)&&(b-=h,w=\"bottom\");l.isMiddleAnchor(r)&&(b-=h/2,w=\"middle\");f=Math.ceil(f),h=Math.ceil(h),x=Math.round(x),b=Math.round(b),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:f*d[_],r:f*g[_],b:h*g[w],t:h*d[w]}),o.attr(\"transform\",c(x,b))}(t,h,f,o._name,r)}))}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,\"./constants\":707,\"./get_update_object\":710,d3:169}],710:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:169}],711:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":706,\"./defaults\":708,\"./draw\":709}],712:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":642}],713:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],714:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],715:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,f,h=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(h.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter((function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)})).map((function(t){return t.substr(t.indexOf(\"y\"),t.length)})),m=n.simpleMap(g,a.id2name),v=0;v<m.length;v++){var y=m[v];u=h[y]||{},f=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=h}}function _(t,e){return n.coerce(h,p,o,t,e)}function w(t,e){return n.coerce(u,f,s,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axis_ids\":831,\"./attributes\":712,\"./oppaxis_attributes\":719}],716:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../titles\"),f=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),p=t(\"../dragelement\"),d=t(\"../../lib/setcursor\"),g=t(\"./constants\");function m(t,e,r,n){var i=o.ensureSingle(t,\"rect\",g.bgClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,c=-n._offsetShift,u=l.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:s(c,c),fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":u})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,(function(t){t.append(\"rect\").attr({x:0,y:0})})).select(\"rect\").attr({width:n._width,height:n._height})}function y(t,e,r,i){var s,c=e.calcdata,u=t.selectAll(\"g.\"+g.rangePlotClassName).data(r._subplotsWith,o.identity);u.enter().append(\"g\").attr(\"class\",(function(t){return g.rangePlotClassName+\" \"+t})).call(l.setClipUrl,i._clipId,e),u.order(),u.exit().remove(),u.each((function(t,o){var l=n.select(this),u=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],m={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(m.layout.xaxis.rangebreaks=r.rangebreaks),m.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(m.layout[d].rangebreaks=p.rangebreaks),a.supplyDefaults(m);var v=m._fullLayout.xaxis,y=m._fullLayout[d];v.clearCalc(),v.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:l,xaxis:v,yaxis:y,isRangePlot:!0};u?s=x:(x.mainplot=\"xy\",x.mainplotinfo=s),f.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))}))}function x(t,e,r,n,i){(o.ensureSingle(t,\"rect\",g.maskMinClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),o.ensureSingle(t,\"rect\",g.maskMaxClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",g.maskMinOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).call(c.fill,g.maskOppAxisColor),o.ensureSingle(t,\"rect\",g.maskMaxOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).style(\"border-top\",g.maskOppBorder).call(c.fill,g.maskOppAxisColor))}function b(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",g.slideBoxClassName,(function(t){t.attr({y:0,cursor:g.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})})).attr({height:n._height,fill:g.slideBoxFill})}function _(t,e,r,n){var i=o.ensureSingle(t,\"g\",g.grabberMinClassName),a=o.ensureSingle(t,\"g\",g.grabberMaxClassName),s={x:0,width:g.handleWidth,rx:g.handleRadius,fill:c.background,stroke:c.defaultLine,\"stroke-width\":g.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},l={y:Math.round(n._height/4),height:Math.round(n._height/2)};o.ensureSingle(i,\"rect\",g.handleMinClassName,(function(t){t.attr(s)})).attr(l),o.ensureSingle(a,\"rect\",g.handleMaxClassName,(function(t){t.attr(s)})).attr(l);var u={width:g.grabAreaWidth,x:0,y:0,fill:g.grabAreaFill,cursor:e._context.staticPlot?void 0:g.grabAreaCursor};o.ensureSingle(i,\"rect\",g.grabAreaMinClassName,(function(t){t.attr(u)})).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",g.grabAreaMaxClassName,(function(t){t.attr(u)})).attr(\"height\",n._height)}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var l=r[a][g.name];l._clipId=l._id+\"-\"+e._uid}var c=e._infolayer.selectAll(\"g.\"+g.containerClassName).data(r,(function(t){return t._name}));c.exit().each((function(t){var r=t[g.name];e._topdefs.select(\"#\"+r._clipId).remove()})).remove(),0!==r.length&&(c.enter().append(\"g\").classed(g.containerClassName,!0).attr(\"pointer-events\",\"all\"),c.each((function(r){var a=n.select(this),l=r[g.name],c=e[h.id2name(r.anchor)],f=l[h.id2name(r.anchor)];if(l.range){var w,T=o.simpleMap(l.range,r.r2l),k=o.simpleMap(r.range,r.r2l);w=k[0]<k[1]?[Math.min(T[0],k[0]),Math.max(T[1],k[1])]:[Math.max(T[0],k[0]),Math.min(T[1],k[1])],l.range=l._input.range=o.simpleMap(w,r.l2r)}r.cleanRange(\"rangeslider.range\");var M=e._size,A=r.domain;l._width=M.w*(A[1]-A[0]);var S=Math.round(M.l+M.w*A[0]),E=Math.round(M.t+M.h*(1-r._counterDomainMin)+(\"bottom\"===r.side?r._depth:0)+l._offsetShift+g.extraPad);a.attr(\"transform\",s(S,E)),l._rl=o.simpleMap(l.range,r.r2l);var C=l._rl[0],L=l._rl[1],I=L-C;if(l.p2d=function(t){return t/l._width*I+C},l.d2p=function(t){return(t-C)/I*l._width},r.rangebreaks){var P=r.locateBreaks(C,L);if(P.length){var z,O,D=0;for(z=0;z<P.length;z++)D+=(O=P[z]).max-O.min;var R=l._width/(L-C-D),F=[-R*C];for(z=0;z<P.length;z++)O=P[z],F.push(F[F.length-1]-R*(O.max-O.min));for(l.d2p=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.max)e=F[r+1];else if(t<n.min)break}return e+R*t},z=0;z<P.length;z++)(O=P[z]).pmin=l.d2p(O.min),O.pmax=l.d2p(O.max);l.p2d=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.pmax)e=F[r+1];else if(t<n.pmin)break}return(t-e)/R}}}if(\"match\"!==f.rangemode){var B=c.r2l(f.range[0]),N=c.r2l(f.range[1])-B;l.d2pOppAxis=function(t){return(t-B)/N*l._height}}a.call(m,t,r,l).call(v,t,r,l).call(y,t,r,l).call(x,t,r,l,f).call(b,t,r,l).call(_,t,r,l),function(t,e,r,a){if(e._context.staticPlot)return;var s=t.select(\"rect.\"+g.slideBoxClassName).node(),l=t.select(\"rect.\"+g.grabAreaMinClassName).node(),c=t.select(\"rect.\"+g.grabAreaMaxClassName).node();function u(){var u=n.event,f=u.target,h=u.clientX||u.touches[0].clientX,g=h-t.node().getBoundingClientRect().left,m=a.d2p(r._rl[0]),v=a.d2p(r._rl[1]),y=p.coverSlip();function x(t){var u,p,x,b=+(t.clientX||t.touches[0].clientX)-h;switch(f){case s:x=\"ew-resize\",u=m+b,p=v+b;break;case l:x=\"col-resize\",u=m+b,p=v;break;case c:x=\"col-resize\",u=m,p=v+b;break;default:x=\"ew-resize\",u=g,p=g+b}if(p<u){var _=p;p=u,u=_}a._pixelMin=u,a._pixelMax=p,d(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame((function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])}))}(0,e,r,a)}function b(){y.removeEventListener(\"mousemove\",x),y.removeEventListener(\"mouseup\",b),this.removeEventListener(\"touchmove\",x),this.removeEventListener(\"touchend\",b),o.removeElement(y)}this.addEventListener(\"touchmove\",x),this.addEventListener(\"touchend\",b),y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",b)}t.on(\"mousedown\",u),t.on(\"touchstart\",u)}(a,t,r,l),function(t,e,r,n,i,a){var l=g.handleWidth/2;function c(t){return o.constrain(t,0,n._width)}function u(t){return o.constrain(t,0,n._height)}function f(t){return o.constrain(t,-l,n._width+l)}var h=c(n.d2p(r._rl[0])),p=c(n.d2p(r._rl[1]));if(t.select(\"rect.\"+g.slideBoxClassName).attr(\"x\",h).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+g.maskMaxClassName).attr(\"x\",p).attr(\"width\",n._width-p),\"match\"!==a.rangemode){var d=n._height-u(n.d2pOppAxis(i._rl[1])),m=n._height-u(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+g.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",d).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",m).attr(\"height\",n._height-m).attr(\"width\",p-h),t.select(\"rect.\"+g.slideBoxClassName).attr(\"y\",d).attr(\"height\",m-d)}var v=Math.round(f(h-l))-.5,y=Math.round(f(p-l))+.5;t.select(\"g.\"+g.grabberMinClassName).attr(\"transform\",s(v,.5)),t.select(\"g.\"+g.grabberMaxClassName).attr(\"transform\",s(y,.5))}(a,0,r,l,c,f),\"bottom\"===r.side&&u.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:E+l._height+l._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})})))}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plots/cartesian\":841,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":714,d3:169}],717:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../lib/svg_text_utils\"),a=t(\"./constants\"),o=t(\"../../constants/alignment\").LINE_SPACING,s=a.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var a=0;a<e.length;a++){var o=e[a];if(l(o)){i.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;\"bottom\"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(i.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:a.extraPad+2*n._offsetShift}}},{\"../../constants/alignment\":745,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],718:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":778,\"./attributes\":712,\"./calc_autorange\":713,\"./defaults\":715,\"./draw\":716,\"./helpers\":717,\"./oppaxis_attributes\":719}],719:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],720:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"arraydraw\"},editable:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../annotations/attributes\":626,\"../drawing/attributes\":664}],721:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var f=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],h=n.aggNums(Math.max,null,f),p=n.aggNums(Math.min,null,f),d=p<0?Math.abs(p)+c:c,g=h>0?h+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,f,h=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((f=s(u[c]))<h&&(h=f),f>p&&(p=f)));return p>=h?[h,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,f,h=r[o];h._extremes={};var p=i.getRefType(h.xref),d=i.getRefType(h.yref);if(\"paper\"!==h.xref&&\"domain\"!==p){var g=\"pixel\"===h.xsizemode?h.xanchor:h.x0,m=\"pixel\"===h.xsizemode?h.xanchor:h.x1;(f=u(c=i.getFromId(t,h.xref),g,m,h.path,a.paramIsX))&&(h._extremes[c._id]=i.findExtremes(c,f,s(h)))}if(\"paper\"!==h.yref&&\"domain\"!==d){var v=\"pixel\"===h.ysizemode?h.yanchor:h.y0,y=\"pixel\"===h.ysizemode?h.yanchor:h.y1;(f=u(c=i.getFromId(t,h.yref),v,y,h.path,a.paramIsY))&&(h._extremes[c._id]=i.findExtremes(c,f,l(h)))}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":722,\"./helpers\":731}],722:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],723:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){var l=a(\"path\"),c=a(\"type\",l?\"path\":\"rect\");\"path\"!==e.type&&delete e.path,a(\"editable\"),a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"fillrule\"),a(\"line.width\")&&(a(\"line.color\"),a(\"line.dash\"));for(var u=a(\"xsizemode\"),f=a(\"ysizemode\"),h=[\"x\",\"y\"],p=0;p<2;p++){var d,g,m,v=h[p],y=v+\"anchor\",x=\"x\"===v?u:f,b={_fullLayout:r},_=i.coerceRef(t,e,b,v,void 0,\"paper\");if(\"range\"===i.getRefType(_)?((d=i.getFromId(b,_))._shapeIndices.push(e._index),m=s.rangeToShapePosition(d),g=s.shapePositionToRange(d)):g=m=n.identity,\"path\"!==c){var w=v+\"0\",T=v+\"1\",k=t[w],M=t[T];t[w]=g(t[w],!0),t[T]=g(t[T],!0),\"pixel\"===x?(a(w,0),a(T,10)):(i.coercePosition(e,b,a,_,w,.25),i.coercePosition(e,b,a,_,T,.75)),e[w]=m(e[w]),e[T]=m(e[T]),t[w]=k,t[T]=M}if(\"pixel\"===x){var A=t[y];t[y]=g(t[y],!0),i.coercePosition(e,b,a,_,y,.25),e[y]=m(e[y]),t[y]=A}}\"path\"===c?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":720,\"./helpers\":731}],724:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"./draw_newshape/helpers\").readPaths,s=t(\"./draw_newshape/display_outlines\"),l=t(\"../../plots/cartesian/handle_outline\").clearOutlineControllers,c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../../plot_api/plot_template\").arrayEditor,h=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\"),g=t(\"./helpers\");function m(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&x(t,i)}function v(t){return!!t._fullLayout._drawing}function y(t){return!t._context.edits.shapePosition}function x(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=g.makeOptionsAndPlotinfo(t,e),l=r.options,x=r.plotinfo;if(l._input&&!1!==l.visible)if(\"below\"!==l.layer)k(t._fullLayout._shapeUpperLayer);else if(\"paper\"===l.xref||\"paper\"===l.yref)k(t._fullLayout._shapeLowerLayer);else{if(x._hadPlotinfo)k((x.mainplotinfo||x).shapelayer);else k(t._fullLayout._shapeLowerLayer)}function k(r){var k=_(t,l),M={\"data-index\":e,\"fill-rule\":l.fillrule,d:k},A=l.opacity,S=l.fillcolor,E=l.line.width?l.line.color:\"rgba(0,0,0,0)\",C=l.line.width,L=l.line.dash;C||!0!==l.editable||(C=5,L=\"solid\");var I=\"Z\"!==k[k.length-1],P=y(t)&&l.editable&&t._fullLayout._activeShapeIndex===e;P&&(S=I?\"rgba(0,0,0,0)\":t._fullLayout.activeshape.fillcolor,A=t._fullLayout.activeshape.opacity);var z,O=r.append(\"path\").attr(M).style(\"opacity\",A).call(c.stroke,E).call(c.fill,S).call(u.dashLine,L,C);if(b(O,t,l),(P||t._context.edits.shapePosition)&&(z=f(t.layout,\"shapes\",l)),P){O.style({cursor:\"move\"});var D={element:O.node(),plotinfo:x,gd:t,editHelpers:z,isActiveShape:!0},R=o(k,t);s(R,O,D)}else t._context.edits.shapePosition?function(t,e,r,o,s,l){var c,f,m,y,x,T,k,M,A,S,E,C,L,I,P,z,O=\"pixel\"===r.xsizemode,D=\"pixel\"===r.ysizemode,R=\"line\"===r.type,F=\"path\"===r.type,B=l.modifyItem,N=a.getFromId(t,r.xref),j=a.getRefType(r.xref),U=a.getFromId(t,r.yref),V=a.getRefType(r.yref),q=g.getDataToPixel(t,N,!1,j),H=g.getDataToPixel(t,U,!0,V),G=g.getPixelToData(t,N,!1,j),Y=g.getPixelToData(t,U,!0,V),W=R?function(){var t=Math.max(r.line.width,10),n=s.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=Math.max(t/2,10);return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:O?q(r.xanchor)+r.x0:q(r.x0),cy:D?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:O?q(r.xanchor)+r.x1:q(r.x1),cy:D?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){if(v(t))return;O&&(x=q(r.xanchor));D&&(T=H(r.yanchor));\"path\"===r.type?P=r.path:(c=O?r.x0:q(r.x0),f=D?r.y0:H(r.y0),m=O?r.x1:q(r.x1),y=D?r.y1:H(r.y1));c<m?(A=c,L=\"x0\",S=m,I=\"x1\"):(A=m,L=\"x1\",S=c,I=\"x0\");!D&&f<y||D&&f>y?(k=f,E=\"y0\",M=y,C=\"y1\"):(k=y,E=\"y1\",M=f,C=\"y0\");Z(n),Q(s,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),s=a.getFromId(r,i),l=\"\";\"paper\"===n||o.autorange||(l+=n);\"paper\"===i||s.autorange||(l+=i);u.setClipUrl(t,l?\"clip\"+r._fullLayout._uid+l:null,r)}(e,r,t),X.moveFn=\"move\"===z?J:K,X.altKey=n.altKey},doneFn:function(){if(v(t))return;p(e),$(s),b(e,t,r),n.call(\"_guiRelayout\",t,l.getUpdateObj())},clickFn:function(){if(v(t))return;$(s)}};function Z(r){if(v(t))z=null;else if(R)z=\"path\"===r.target.tagName?\"move\":\"start-point\"===r.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var n=X.element.getBoundingClientRect(),i=n.right-n.left,a=n.bottom-n.top,o=r.clientX-n.left,s=r.clientY-n.top,l=!F&&i>10&&a>10&&!r.shiftKey?h.getCursor(o/i,1-s/a):\"move\";p(e,l),z=l.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else O?B(\"xanchor\",r.xanchor=G(x+n)):(B(\"x0\",r.x0=G(c+n)),B(\"x1\",r.x1=G(m+n))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(B(\"y0\",r.y0=Y(f+i)),B(\"y1\",r.y1=Y(y+i)));e.attr(\"d\",_(t,r)),Q(s,r)}function K(n,i){if(F){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else if(R){if(\"resize-over-start-point\"===z){var u=c+n,h=D?f-i:f+i;B(\"x0\",r.x0=O?u:G(u)),B(\"y0\",r.y0=D?h:Y(h))}else if(\"resize-over-end-point\"===z){var p=m+n,d=D?y-i:y+i;B(\"x1\",r.x1=O?p:G(p)),B(\"y1\",r.y1=D?d:Y(d))}}else{var v=function(t){return-1!==z.indexOf(t)},b=v(\"n\"),j=v(\"s\"),V=v(\"w\"),W=v(\"e\"),X=b?k+i:k,Z=j?M+i:M,J=V?A+n:A,K=W?S+n:S;D&&(b&&(X=k-i),j&&(Z=M-i)),(!D&&Z-X>10||D&&X-Z>10)&&(B(E,r[E]=D?X:Y(X)),B(C,r[C]=D?Z:Y(Z))),K-J>10&&(B(L,r[L]=O?J:G(J)),B(I,r[I]=O?K:G(K)))}e.attr(\"d\",_(t,r)),Q(s,r)}function Q(t,e){(O||D)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(O?e.xanchor:i.midRange(r?[e.x0,e.x1]:g.extractPathCoords(e.path,d.paramIsX))),o=H(D?e.yanchor:i.midRange(r?[e.y0,e.y1]:g.extractPathCoords(e.path,d.paramIsY)));if(a=g.roundPositionForSharpStrokeRendering(a,1),o=g.roundPositionForSharpStrokeRendering(o,1),O&&D){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(O){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function $(t){t.selectAll(\".visual-cue\").remove()}h.init(X),W.node().onmousemove=Z}(t,O,l,e,r,z):!0===l.editable&&O.style(\"pointer-events\",I||c.opacity(S)*A<=.5?\"stroke\":\"all\");O.node().addEventListener(\"click\",(function(){return function(t,e){if(!y(t))return;var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeShapeIndex)return void T(t);t._fullLayout._activeShapeIndex=r,t._fullLayout._deactivateShape=T,m(t)}}(t,O)}))}}function b(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\").replace(/[xyz][1-9]* *domain/g,\"\");u.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function _(t,e){var r,n,o,s,l,c,u,f,h=e.type,p=a.getRefType(e.xref),m=a.getRefType(e.yref),v=a.getFromId(t,e.xref),y=a.getFromId(t,e.yref),x=t._fullLayout._size;if(v?\"domain\"===p?n=function(t){return v._offset+v._length*t}:(r=g.shapePositionToRange(v),n=function(t){return v._offset+v.r2p(r(t,!0))}):n=function(t){return x.l+x.w*t},y?\"domain\"===m?s=function(t){return y._offset+y._length*(1-t)}:(o=g.shapePositionToRange(y),s=function(t){return y._offset+y.r2p(o(t,!0))}):s=function(t){return x.t+x.h*(1-t)},\"path\"===h)return v&&\"date\"===v.type&&(n=g.decodeDate(n)),y&&\"date\"===y.type&&(s=g.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(d.segmentRE,(function(t){var n=0,c=t.charAt(0),u=d.paramIsX[c],f=d.paramIsY[c],h=d.numParams[c],p=t.substr(1).replace(d.paramRE,(function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>h&&(t=\"X\"),t}));return n>h&&(p=p.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+p}))}(e,n,s);if(\"pixel\"===e.xsizemode){var b=n(e.xanchor);l=b+e.x0,c=b+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var _=s(e.yanchor);u=_-e.y0,f=_-e.y1}else u=s(e.y0),f=s(e.y1);if(\"line\"===h)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+f;if(\"rect\"===h)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+f+\"H\"+l+\"Z\";var w=(l+c)/2,T=(u+f)/2,k=Math.abs(w-l),M=Math.abs(T-u),A=\"A\"+k+\",\"+M,S=w+k+\",\"+T;return\"M\"+S+A+\" 0 1,1 \"+(w+\",\"+(T-M))+A+\" 0 0,1 \"+S+\"Z\"}function w(t,e,r){return t.replace(d.segmentRE,(function(t){var n=0,i=t.charAt(0),a=d.paramIsX[i],o=d.paramIsY[i],s=d.numParams[i];return i+t.substr(1).replace(d.paramRE,(function(t){return n>=s||(a[n]?t=e(t):o[n]&&(t=r(t)),n++),t}))}))}function T(t){y(t)&&(t._fullLayout._activeShapeIndex>=0&&(l(t),delete t._fullLayout._activeShapeIndex,m(t)))}e.exports={draw:m,drawOne:x,eraseActiveShape:function(t){if(!y(t))return;l(t);var e=t._fullLayout._activeShapeIndex,r=(t.layout||{}).shapes||[];if(e<r.length){for(var i=[],a=0;a<r.length;a++)a!==e&&i.push(r[a]);delete t._fullLayout._activeShapeIndex,n.call(\"_guiRelayout\",t,{shapes:i})}}}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/handle_outline\":838,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":722,\"./draw_newshape/display_outlines\":728,\"./draw_newshape/helpers\":729,\"./helpers\":731}],725:[function(t,e,r){\"use strict\";var n=t(\"../../drawing/attributes\").dash,i=t(\"../../../lib/extend\").extendFlat;e.exports={newshape:{line:{color:{valType:\"color\",editType:\"none\"},width:{valType:\"number\",min:0,dflt:4,editType:\"none\"},dash:i({},n,{dflt:\"solid\",editType:\"none\"}),editType:\"none\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"none\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"none\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"none\"},drawdirection:{valType:\"enumerated\",values:[\"ortho\",\"horizontal\",\"vertical\",\"diagonal\"],dflt:\"diagonal\",editType:\"none\"},editType:\"none\"},activeshape:{fillcolor:{valType:\"color\",dflt:\"rgb(255,0,255)\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"none\"},editType:\"none\"}}},{\"../../../lib/extend\":768,\"../../drawing/attributes\":664}],726:[function(t,e,r){\"use strict\";e.exports={CIRCLE_SIDES:32,i000:0,i090:8,i180:16,i270:24,cos45:Math.cos(Math.PI/4),sin45:Math.sin(Math.PI/4),SQRT2:Math.sqrt(2)}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"../../color\");e.exports=function(t,e,r){if(r(\"newshape.drawdirection\"),r(\"newshape.layer\"),r(\"newshape.fillcolor\"),r(\"newshape.fillrule\"),r(\"newshape.opacity\"),r(\"newshape.line.width\")){var i=(t||{}).plot_bgcolor||\"#FFF\";r(\"newshape.line.color\",n.contrast(i)),r(\"newshape.line.dash\")}r(\"activeshape.fillcolor\"),r(\"activeshape.opacity\")}},{\"../../color\":643}],728:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement\"),i=t(\"../../dragelement/helpers\").drawMode,a=t(\"../../../registry\"),o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=t(\"../../../plots/cartesian/handle_outline\").clearOutlineControllers,h=t(\"./helpers\"),p=h.pointsShapeRectangle,d=h.pointsShapeEllipse,g=h.writePaths,m=t(\"./newshapes\");e.exports=function t(e,r,o,h){h||(h=0);var v=o.gd;function y(){t(e,r,o,h++),d(e[0])&&x({redrawing:!0})}function x(t){o.isActiveShape=!1;var e=m(r,o);Object.keys(e).length&&a.call((t||{}).redrawing?\"relayout\":\"_guiRelayout\",v,e)}var b,_,w,T,k,M=o.isActiveShape,A=v._fullLayout._zoomlayer,S=o.dragmode;(i(S)?v._fullLayout._drawing=!0:v._fullLayout._activeShapeIndex>=0&&f(v),r.attr(\"d\",g(e)),M&&!h)&&(k=function(t,e){for(var r=0;r<e.length;r++){var n=e[r];t[r]=[];for(var i=0;i<n.length;i++){t[r][i]=[];for(var a=0;a<n[i].length;a++)t[r][i][a]=n[i][a]}}return t}([],e),function(t){b=[];for(var r=0;r<e.length;r++){var i=e[r],a=!p(i)&&d(i);b[r]=[];for(var o=0;o<i.length;o++)if(\"Z\"!==i[o][0]&&(!a||o===s||o===l||o===c||o===u)){var f=i[o][1],h=i[o][2],g=t.append(\"circle\").classed(\"cursor-grab\",!0).attr(\"data-i\",r).attr(\"data-j\",o).attr(\"cx\",f).attr(\"cy\",h).attr(\"r\",4).style({\"mix-blend-mode\":\"luminosity\",fill:\"black\",stroke:\"white\",\"stroke-width\":1});b[r][o]={element:g.node(),gd:v,prepFn:E,doneFn:L,clickFn:I},n.init(b[r][o])}}}(A.append(\"g\").attr(\"class\",\"outline-controllers\")),function(){if(_=[],!e.length)return;_[0]={element:r[0][0],gd:v,prepFn:z,doneFn:O},n.init(_[0])}());function E(t){w=+t.srcElement.getAttribute(\"data-i\"),T=+t.srcElement.getAttribute(\"data-j\"),b[w][T].moveFn=C}function C(t,r){if(e.length){var n=k[w][T][1],i=k[w][T][2],a=e[w],o=a.length;if(p(a)){for(var s=0;s<o;s++)if(s!==T){var l=a[s];l[1]===a[T][1]&&(l[1]=n+t),l[2]===a[T][2]&&(l[2]=i+r)}if(a[T][1]=n+t,a[T][2]=i+r,!p(a))for(var c=0;c<o;c++)for(var u=0;u<a[c].length;u++)a[c][u]=k[w][c][u]}else a[T][1]=n+t,a[T][2]=i+r;y()}}function L(){x()}function I(t,r){if(2===t){w=+r.srcElement.getAttribute(\"data-i\"),T=+r.srcElement.getAttribute(\"data-j\");var n=e[w];p(n)||d(n)||function(){if(e.length&&e[w]&&e[w].length){for(var t=[],r=0;r<e[w].length;r++)r!==T&&t.push(e[w][r]);t.length>1&&(2!==t.length||\"Z\"!==t[1][0])&&(0===T&&(t[0][0]=\"M\"),e[w]=t,y(),x())}}()}}function P(t,r){!function(t,r){if(e.length)for(var n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)for(var a=0;a+2<e[n][i].length;a+=2)e[n][i][a+1]=k[n][i][a+1]+t,e[n][i][a+2]=k[n][i][a+2]+r}(t,r),y()}function z(t){(w=+t.srcElement.getAttribute(\"data-i\"))||(w=0),_[w].moveFn=P}function O(){x()}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../registry\":911,\"../../dragelement\":662,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729,\"./newshapes\":730}],729:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"./constants\"),a=i.CIRCLE_SIDES,o=i.SQRT2,s=t(\"../../../plots/cartesian/helpers\"),l=s.p2r,c=s.r2p,u=[0,3,4,5,6,1,2],f=[0,3,4,1,2];function h(t,e){return Math.abs(t-e)<=1e-6}function p(t,e){var r=e[1]-t[1],n=e[2]-t[2];return Math.sqrt(r*r+n*n)}r.writePaths=function(t){var e=t.length;if(!e)return\"M0,0Z\";for(var r=\"\",n=0;n<e;n++)for(var i=t[n].length,a=0;a<i;a++){var o=t[n][a][0];if(\"Z\"===o)r+=\"Z\";else for(var s=t[n][a].length,l=0;l<s;l++){var c=l;\"Q\"===o||\"S\"===o?c=f[l]:\"C\"===o&&(c=u[l]),r+=t[n][a][c],l>0&&l<s-1&&(r+=\",\")}}return r},r.readPaths=function(t,e,r,i){var o,s,u,f=n(t),h=[],p=-1,d=0,g=0,m=function(){s=d,u=g};m();for(var v=0;v<f.length;v++){var y,x,b,_,w=[],T=f[v][0],k=T;switch(T){case\"M\":p++,h[p]=[],d=+f[v][1],g=+f[v][2],w.push([k,d,g]),m();break;case\"Q\":case\"S\":y=+f[v][1],b=+f[v][2],d=+f[v][3],g=+f[v][4],w.push([k,d,g,y,b]);break;case\"C\":y=+f[v][1],b=+f[v][2],x=+f[v][3],_=+f[v][4],d=+f[v][5],g=+f[v][6],w.push([k,d,g,y,b,x,_]);break;case\"T\":case\"L\":d=+f[v][1],g=+f[v][2],w.push([k,d,g]);break;case\"H\":k=\"L\",d=+f[v][1],w.push([k,d,g]);break;case\"V\":k=\"L\",g=+f[v][1],w.push([k,d,g]);break;case\"A\":k=\"L\";var M=+f[v][1],A=+f[v][2];+f[v][4]||(M=-M,A=-A);var S=d-M,E=g;for(o=1;o<=a/2;o++){var C=2*Math.PI*o/a;w.push([k,S+M*Math.cos(C),E+A*Math.sin(C)])}break;case\"Z\":d===s&&g===u||(d=s,g=u,w.push([k,d,g]))}for(var L=(r||{}).domain,I=e._fullLayout._size,P=r&&\"pixel\"===r.xsizemode,z=r&&\"pixel\"===r.ysizemode,O=!1===i,D=0;D<w.length;D++){for(o=0;o+2<7;o+=2){var R=w[D][o+1],F=w[D][o+2];void 0!==R&&void 0!==F&&(d=R,g=F,r&&(r.xaxis&&r.xaxis.p2r?(O&&(R-=r.xaxis._offset),R=P?c(r.xaxis,r.xanchor)+R:l(r.xaxis,R)):(O&&(R-=I.l),L?R=L.x[0]+R/I.w:R/=I.w),r.yaxis&&r.yaxis.p2r?(O&&(F-=r.yaxis._offset),F=z?c(r.yaxis,r.yanchor)-F:l(r.yaxis,F)):(O&&(F-=I.t),F=L?L.y[1]-F/I.h:1-F/I.h)),w[D][o+1]=R,w[D][o+2]=F)}h[p].push(w[D].slice())}}return h},r.pointsShapeRectangle=function(t){if(5!==t.length)return!1;for(var e=1;e<3;e++){if(!h(t[0][e]-t[1][e],t[3][e]-t[2][e]))return!1;if(!h(t[0][e]-t[3][e],t[1][e]-t[2][e]))return!1}return!(!h(t[0][1],t[1][1])&&!h(t[0][1],t[3][1]))&&!!(p(t[0],t[1])*p(t[0],t[3]))},r.pointsShapeEllipse=function(t){var e=t.length;if(e!==a+1)return!1;e=a;for(var r=0;r<e;r++){var n=(2*e-r)%e,i=(e/2+n)%e,o=(e/2+r)%e;if(!h(p(t[r],t[o]),p(t[n],t[i])))return!1}return!0},r.handleEllipse=function(t,e,n){if(!t)return[e,n];var i=r.ellipseOver({x0:e[0],y0:e[1],x1:n[0],y1:n[1]}),s=(i.x1+i.x0)/2,l=(i.y1+i.y0)/2,c=(i.x1-i.x0)/2,u=(i.y1-i.y0)/2;c||(c=u/=o),u||(u=c/=o);for(var f=[],h=0;h<a;h++){var p=2*h*Math.PI/a;f.push([s+c*Math.cos(p),l+u*Math.sin(p)])}return f},r.ellipseOver=function(t){var e=t.x0,r=t.y0,n=t.x1,i=t.y1,a=n-e,s=i-r,l=((e-=a)+n)/2,c=((r-=s)+i)/2;return{x0:l-(a*=o),y0:c-(s*=o),x1:l+a,y1:c+s}}},{\"../../../plots/cartesian/helpers\":839,\"./constants\":726,\"parse-svg-path\":505}],730:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement/helpers\"),i=n.drawMode,a=n.openMode,o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=o.cos45,h=o.sin45,p=t(\"../../../plots/cartesian/helpers\"),d=p.p2r,g=p.r2p,m=t(\"../../../plots/cartesian/handle_outline\").clearSelect,v=t(\"./helpers\"),y=v.readPaths,x=v.writePaths,b=v.ellipseOver;e.exports=function(t,e){if(t.length){var r=t[0][0];if(r){var n=r.getAttribute(\"d\"),o=e.gd,p=o._fullLayout.newshape,v=e.plotinfo,_=v.xaxis,w=v.yaxis,T=!!v.domain||!v.xaxis,k=!!v.domain||!v.yaxis,M=e.isActiveShape,A=e.dragmode,S=(o.layout||{}).shapes||[];if(!i(A)&&void 0!==M){var E=o._fullLayout._activeShapeIndex;if(E<S.length)switch(o._fullLayout.shapes[E].type){case\"rect\":A=\"drawrect\";break;case\"circle\":A=\"drawcircle\";break;case\"line\":A=\"drawline\";break;case\"path\":var C=S[E].path||\"\";A=\"Z\"===C[C.length-1]?\"drawclosedpath\":\"drawopenpath\"}}var L,I=a(A),P=y(n,o,v,M),z={editable:!0,xref:T?\"paper\":_._id,yref:k?\"paper\":w._id,layer:p.layer,opacity:p.opacity,line:{color:p.line.color,width:p.line.width,dash:p.line.dash}};if(I||(z.fillcolor=p.fillcolor,z.fillrule=p.fillrule),1===P.length&&(L=P[0]),L&&\"drawrect\"===A)z.type=\"rect\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[2][1],z.y1=L[2][2];else if(L&&\"drawline\"===A)z.type=\"line\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[1][1],z.y1=L[1][2];else if(L&&\"drawcircle\"===A){z.type=\"circle\";var O=L[s][1],D=L[l][1],R=L[c][1],F=L[u][1],B=L[s][2],N=L[l][2],j=L[c][2],U=L[u][2],V=v.xaxis&&(\"date\"===v.xaxis.type||\"log\"===v.xaxis.type),q=v.yaxis&&(\"date\"===v.yaxis.type||\"log\"===v.yaxis.type);V&&(O=g(v.xaxis,O),D=g(v.xaxis,D),R=g(v.xaxis,R),F=g(v.xaxis,F)),q&&(B=g(v.yaxis,B),N=g(v.yaxis,N),j=g(v.yaxis,j),U=g(v.yaxis,U));var H=(D+F)/2,G=(B+j)/2,Y=b({x0:H,y0:G,x1:H+(F-D+R-O)/2*f,y1:G+(U-N+j-B)/2*h});V&&(Y.x0=d(v.xaxis,Y.x0),Y.x1=d(v.xaxis,Y.x1)),q&&(Y.y0=d(v.yaxis,Y.y0),Y.y1=d(v.yaxis,Y.y1)),z.x0=Y.x0,z.y0=Y.y0,z.x1=Y.x1,z.y1=Y.y1}else z.type=\"path\",_&&w&&function(t,e,r){var n=\"date\"===e.type,i=\"date\"===r.type;if(!n&&!i)return t;for(var a=0;a<t.length;a++)for(var o=0;o<t[a].length;o++)for(var s=0;s+2<t[a][o].length;s+=2)n&&(t[a][o][s+1]=t[a][o][s+1].replace(\" \",\"_\")),i&&(t[a][o][s+2]=t[a][o][s+2].replace(\" \",\"_\"))}(P,_,w),z.path=x(P),L=null;m(o);for(var W=e.editHelpers,X=(W||{}).modifyItem,Z=[],J=0;J<S.length;J++){var K=o._fullLayout.shapes[J];if(Z[J]=K._input,void 0!==M&&J===o._fullLayout._activeShapeIndex){var Q=z;switch(K.type){case\"line\":case\"rect\":case\"circle\":X(\"x0\",Q.x0),X(\"x1\",Q.x1),X(\"y0\",Q.y0),X(\"y1\",Q.y1);break;case\"path\":X(\"path\",Q.path)}}}return void 0===M?(Z.push(z),Z):W?W.getUpdateObj():{}}}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../plots/cartesian/helpers\":839,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729}],731:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach((function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}})),r},r.getDataToPixel=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){return e._length*(n?1-t:t)+e._offset};else{var s=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(s(t,!0))},\"date\"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return o.t+o.h*(1-t)}:function(t){return o.l+o.w*t};return a},r.getPixelToData=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){var r=(t-e._offset)/e._length;return n?1-r:r};else{var s=r.rangeToShapePosition(e);a=function(t){return s(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-o.t)/o.h}:function(t){return(t-o.l)/o.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n},r.makeOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.shapes[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return!!n?n._hadPlotinfo=!0:(n={},r.xref&&\"paper\"!==r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&\"paper\"!==r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),n.xsizemode=r.xsizemode,n.ysizemode=r.ysizemode,n.xanchor=r.xanchor,n.yanchor=r.yanchor,{options:r,plotinfo:n}}},{\"../../lib\":778,\"./constants\":722}],732:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),supplyDrawNewShapeDefaults:t(\"./draw_newshape/defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":720,\"./calc_autorange\":721,\"./defaults\":723,\"./draw\":724,\"./draw_newshape/defaults\":727}],733:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/animation_attributes\":822,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"./constants\":734}],734:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],735:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var f=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=f[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":733,\"./constants\":734}],736:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plot_api/plot_template\").arrayEditor,f=t(\"./constants\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR;function m(t){return f.autoMarginIdRoot+t._index}function v(t){return t._index}function y(t,e){var r=o.tester.selectAll(\"g.\"+f.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(f.labelGroupClass,!0);var a=0,l=0;r.each((function(t){var r=_(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);l=Math.max(l,i.height),a=Math.max(a,i.width)}})),r.remove();var u=e._dims={};u.inputAreaWidth=Math.max(f.railWidth,f.gripHeight);var h=t._fullLayout._size;u.lx=h.l+h.w*e.x,u.ly=h.t+h.h*(1-e.y),\"fraction\"===e.lenmode?u.outerLength=Math.round(h.w*e.len):u.outerLength=e.len,u.inputAreaStart=0,u.inputAreaLength=Math.round(u.outerLength-e.pad.l-e.pad.r);var p=(u.inputAreaLength-2*f.stepInset)/(e._stepCount-1),v=a+f.labelPadding;if(u.labelStride=Math.max(1,Math.ceil(v/p)),u.labelHeight=l,u.currentValueMaxWidth=0,u.currentValueHeight=0,u.currentValueTotalHeight=0,u.currentValueMaxLines=1,e.currentvalue.visible){var y=o.tester.append(\"g\");r.each((function(t){var r=x(y,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=c.lineCount(r);u.currentValueMaxWidth=Math.max(u.currentValueMaxWidth,Math.ceil(n.width)),u.currentValueHeight=Math.max(u.currentValueHeight,Math.ceil(n.height)),u.currentValueMaxLines=Math.max(u.currentValueMaxLines,i)})),u.currentValueTotalHeight=u.currentValueHeight+e.currentvalue.offset,y.remove()}u.height=u.currentValueTotalHeight+f.tickOffset+e.ticklen+f.labelOffset+u.labelHeight+e.pad.t+e.pad.b;var b=\"left\";s.isRightAnchor(e)&&(u.lx-=u.outerLength,b=\"right\"),s.isCenterAnchor(e)&&(u.lx-=u.outerLength/2,b=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(u.ly-=u.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(u.ly-=u.height/2,w=\"middle\"),u.outerLength=Math.ceil(u.outerLength),u.height=Math.ceil(u.height),u.lx=Math.round(u.lx),u.ly=Math.round(u.ly);var T={y:e.y,b:u.height*g[w],t:u.height*d[w]};\"fraction\"===e.lenmode?(T.l=0,T.xl=e.x-e.len*d[b],T.r=0,T.xr=e.x+e.len*g[b]):(T.x=e.x,T.l=u.outerLength*d[b],T.r=u.outerLength*g[b]),i.autoMargin(t,m(e),T)}function x(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-f.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=f.currentValueInset,i=\"left\"}var l=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":i,\"data-notex\":1})})),u=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)u+=r;else{var h=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(h=s.templateString(h,d)),u+=h}e.currentvalue.suffix&&(u+=e.currentvalue.suffix),l.call(o.font,e.currentvalue.font).text(u).call(c.convertToTspans,e._gd);var g=c.lineCount(l),m=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*p;return c.positionText(l,n,m),l}}function b(t,e,r){s.ensureSingle(t,\"rect\",f.gripRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")})).attr({width:f.gripWidth,height:f.gripHeight,rx:f.gripRadius,ry:f.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function _(t,e,r){var n=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":\"middle\",\"data-notex\":1})})),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(c.convertToTspans,r._gd),n}function w(t,e){var r=s.ensureSingle(t,\"g\",f.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+f.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(f.labelGroupClass,!0),a.exit().remove(),a.each((function(t){var r=n.select(this);r.call(_,t,e),o.setTranslate(r,E(e,t.fraction),f.tickOffset+e.ticklen+e.font.size*p+f.labelOffset+i.currentValueTotalHeight)}))}function T(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,u(t.layout,f.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(S,r,o),e.call(x,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame((function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)}))))}function M(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",(function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+f.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=C(t,n.mouse(i)[0]);T(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",(function(){var t=s(),a=C(t,n.mouse(i)[0]);T(e,r,t,a,!1)})),o.on(\"mouseup\",(function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})}))}))}function A(t,e){var r=t.selectAll(\"rect.\"+f.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(f.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each((function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,E(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?f.tickOffset:f.minorTickOffset)+i.currentValueTotalHeight)}))}function S(t,e,r){for(var n=t.select(\"rect.\"+f.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=E(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",l(o-.5*f.gripWidth,e._dims.currentValueTotalHeight))}}function E(t,e){var r=t._dims;return r.inputAreaStart+f.stepInset+(r.inputAreaLength-2*f.stepInset)*Math.min(1,Math.max(0,e))}function C(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-f.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*f.stepInset-2*r.inputAreaStart)))}function L(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",f.railTouchRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")}));i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,f.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function I(t,e){var r=e._dims,n=r.inputAreaLength-2*f.railInset,i=s.ensureSingle(t,\"rect\",f.railRectClass);i.attr({width:n,height:f.railWidth,rx:f.railRadius,ry:f.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,f.railInset,.5*(r.inputAreaWidth-f.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[f.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,m(e))}if(a.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each((function(){n.select(this).selectAll(\"g.\"+f.groupClassName).each(s)})).remove(),0!==r.length){var l=a.selectAll(\"g.\"+f.groupClassName).data(r,v);l.enter().append(\"g\").classed(f.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var u=r[c];y(t,u)}l.each((function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,(function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))})),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(x,r).call(I,r).call(w,r).call(A,r).call(L,t,r).call(b,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(S,r,!1),e.call(x,r)}(t,n.select(this),e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":734,d3:169}],737:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":733,\"./constants\":734,\"./defaults\":735,\"./draw\":736}],738:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\"),p=t(\"../../constants/alignment\").OPPOSITE_SIDE,d=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var g,m=r.propContainer,v=r.propName,y=r.placeholder,x=r.traceIndex,b=r.avoid||{},_=r.attributes,w=r.transform,T=r.containerGroup,k=t._fullLayout,M=1,A=!1,S=m.title,E=(S&&S.text?S.text:\"\").trim(),C=S&&S.font?S.font:{},L=C.family,I=C.size,P=C.color;\"title.text\"===v?g=\"titleText\":-1!==v.indexOf(\"axis\")?g=\"axisTitleText\":v.indexOf(!0)&&(g=\"colorbarTitleText\");var z=t._context.edits[g];\"\"===E?M=0:E.replace(d,\" % \")===y.replace(d,\" % \")&&(M=.2,A=!0,z||(E=\"\")),r._meta?E=s.templateString(E,r._meta):k._meta&&(E=s.templateString(E,k._meta));var O=E||z;T||(T=s.ensureSingle(k._infolayer,\"g\",\"g-\"+e));var D=T.selectAll(\"text\").data(O?[0]:[]);if(D.enter().append(\"text\"),D.text(E).attr(\"class\",e),D.exit().remove(),!O)return T;function R(t){s.syncOrAsync([F,B],t)}function F(e){var r;return w?(r=\"\",w.rotate&&(r+=\"rotate(\"+[w.rotate,_.x,_.y]+\")\"),w.offset&&(r+=l(0,w.offset))):r=null,e.attr(\"transform\",r),e.style({\"font-family\":L,\"font-size\":n.round(I,2)+\"px\",fill:u.rgb(P),opacity:M*u.opacity(P),\"font-weight\":a.fontWeight}).attr(_).call(f.convertToTspans,t),a.previousPromises(t)}function B(t){var e=n.select(t.node().parentNode);if(b&&b.selection&&b.side&&E){e.attr(\"transform\",null);var r=p[b.side],a=\"left\"===b.side||\"top\"===b.side?-1:1,o=i(b.pad)?b.pad:2,u=c.bBox(e.node()),f={left:0,top:0,right:k.width,bottom:k.height},h=b.maxShift||a*(f[b.side]-u[b.side]),d=0;if(h<0)d=h;else{var g=b.offsetLeft||0,m=b.offsetTop||0;u.left-=g,u.right-=g,u.top-=m,u.bottom-=m,b.selection.each((function(){var t=c.bBox(this);s.bBoxIntersect(u,t,o)&&(d=Math.max(d,a*(t[b.side]-u[r])+o))})),d=Math.min(h,d)}if(d>0||h<0){var v={left:[-d,0],right:[d,0],top:[0,-d],bottom:[0,d]}[b.side];e.attr(\"transform\",l(v[0],v[1]))}}}return D.call(R),z&&(E?D.on(\".opacity\",null):(M=0,A=!0,D.text(y).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)}))),D.call(f.makeEditable,{gd:t}).on(\"edit\",(function(e){void 0!==x?o.call(\"_guiRestyle\",t,v,e,x):o.call(\"_guiRelayout\",t,v,e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(R)})).on(\"input\",(function(t){this.text(t||\" \").call(f.positionText,_.x,_.y)}))),D.classed(\"js-placeholder\",A),T}}},{\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],739:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},args2:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"../color/attributes\":642}],740:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],741:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"args2\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":739,\"./constants\":740}],742:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,f=t(\"./constants\"),h=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(f.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,f.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?v(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(f.menuIndexAttrName,\"-1\"),m(t,n,i,a,e),s||v(t,n,i,a,e))}function m(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",f.headerClassName,(function(t){t.style(\"pointer-events\",\"all\")})),l=i._dims,c=i.active,u=i.buttons[c]||f.blankHeaderOpts,h={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(A,i,h,p),s.ensureSingle(e,\"text\",f.headerArrowClassName,(function(t){t.attr(\"text-anchor\",\"end\").call(o.font,i.font).text(f.arrowSymbol[i.direction])})).attr({x:l.headerWidth-f.arrowOffsetX+i.pad.l,y:l.headerHeight/2+f.textOffsetY+i.pad.t}),a.on(\"click\",(function(){r.call(S,String(d(r,i)?-1:i._index)),v(t,e,r,n,i)})),a.on(\"mouseover\",(function(){a.call(w)})),a.on(\"mouseout\",(function(){a.call(T,i)})),o.setTranslate(e,l.lx,l.ly)}function v(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(f.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?f.dropdownButtonClassName:f.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),h=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(h.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,m=0,v=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?m=v.headerHeight+f.gapButtonHeader:d=v.headerWidth+f.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(m=-f.gapButtonHeader+f.gapButton-v.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-f.gapButtonHeader+f.gapButton-v.openWidth);var b={x:v.lx+d+o.pad.l,y:v.ly+m+o.pad.t,yPad:f.gapButton,xPad:f.gapButton,index:0},k={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each((function(s,l){var c=n.select(this);c.call(y,o,s,t).call(A,o,b),c.on(\"click\",(function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(g(t,o,0,e,r,a,-1),i.executeAPICommand(t,s.method,s.args2)):(g(t,o,0,e,r,a,l),i.executeAPICommand(t,s.method,s.args))),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))})),c.on(\"mouseover\",(function(){c.call(w)})),c.on(\"mouseout\",(function(){c.call(T,o),u.call(_,o)}))})),u.call(_,o),x?(k.w=Math.max(v.openWidth,v.headerWidth),k.h=b.y-k.t):(k.w=b.x-k.l,k.h=Math.max(v.openHeight,v.headerHeight)),k.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,h=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=h.heights[l]+f.gapButton;else for(o=0,l=0;l<p;l++)o+=h.widths[l]+f.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,k):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){e=!1,r||t.disable()}));r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){r=!1,e||t.disable()}))}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",f.itemRectClassName,(function(t){t.attr({rx:f.rx,ry:f.ry,\"shape-rendering\":\"crispEdges\"})})).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",f.itemTextClassName,(function(t){t.attr({\"text-anchor\":\"start\",\"data-notex\":1})})),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each((function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.activeColor)}))}function w(t){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.hoverColor)}function T(t,e){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,e.bgcolor)}function k(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+f.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(f.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each((function(i,a){var s=n.select(this);s.call(y,e,i,t);var h=s.select(\".\"+f.itemTextClassName),p=h.node()&&o.bBox(h.node()).width,d=Math.max(p+f.textPadX,f.minWidth),g=e.font.size*u,m=l.lineCount(h),v=Math.max(g*m,f.minHeight)+f.textOffsetY;v=Math.ceil(v),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=v,r.height1=Math.max(r.height1,v),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=v+f.gapButton,r.openHeight+=v+f.gapButton):(r.totalWidth+=d+f.gapButton,r.openWidth+=d+f.gapButton,r.totalHeight=Math.max(r.totalHeight,v),r.openHeight=r.totalHeight)})),c?r.totalHeight-=f.gapButton:r.totalWidth-=f.gapButton,r.headerWidth=r.width1+f.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=f.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=f.arrowPadX),a.remove();var h=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=h,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=h/2,g=\"center\");var m=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,m=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,m=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,M(e),{x:e.x,y:e.y,l:h*({right:1,center:.5}[g]||0),r:h*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[m]||0),t:p*({bottom:1,middle:.5}[m]||0)})}function M(t){return f.autoMarginIdRoot+t._index}function A(t,e,r,n){n=n||{};var i=t.select(\".\"+f.itemRectClassName),a=t.select(\".\"+f.itemTextClassName),s=e.borderwidth,c=r.index,h=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?h.heights[c]:h.height1);i.attr({x:0,y:0,width:n.width||(p?h.width1:h.widths[c]),height:d});var g=e.font.size*u,m=(l.lineCount(a)-1)*g/2;l.positionText(a,f.textOffsetX,d/2-m+f.textOffsetY),p?r.y+=h.heights[c]+r.yPad:r.x+=h.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(f.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+f.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[f.name]);function a(e){i.autoMargin(t,M(e))}var o=e._menulayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each((function(){n.select(this).selectAll(\"g.\"+f.headerGroupClassName).each(a)})).remove(),0!==r.length){var l=o.selectAll(\"g.\"+f.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(f.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",f.dropdownButtonGroupClassName,(function(t){t.style(\"pointer-events\",\"all\")})),u=0;u<r.length;u++){var y=r[u];k(t,y)}var x=\"updatemenus\"+e._uid,b=new h(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each((function(t){c.call(S),a(t)})).remove(),l.each((function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,(function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)})),\"dropdown\"===e.type?(m(t,r,c,b,e),d(c,e)&&v(t,r,c,b,e)):v(t,r,null,null,e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":740,\"./scrollbox\":744,d3:169}],743:[function(t,e,r){arguments[4][737][0].apply(r,arguments)},{\"./attributes\":739,\"./constants\":740,\"./defaults\":741,\"./draw\":742,dup:737}],744:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,f,h,p,d=this.position.l,g=this.position.w,m=this.position.t,v=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,T=v;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(f=(u=d)+w,x?(h=m,T=(p=Math.min(h+T,c))-h):T=(p=m+T)-(h=Math.max(p-T,0))):(p=(h=m)+T,b?w=(f=d+w)-(u=Math.max(f-w,0)):(u=d,w=(f=Math.min(u+w,l))-u)),this._box={l:u,t:h,w:w,h:T};var k=g>w,M=s.barLength+2*s.barPad,A=s.barWidth+2*s.barPad,S=d,E=m+v;E+A>c&&(E=c-A);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(k?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),k?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:M,height:A}),this._hbarXMin=S+M/2,this._hbarTranslateMax=w-M):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=v>T,I=s.barWidth+2*s.barPad,P=s.barLength+2*s.barPad,z=d+g,O=m;z+I>l&&(z=l-I);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:O,width:I,height:P}),this._vbarYMin=O+P/2,this._vbarTranslateMax=T-P):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?f+I+.5:f+.5,N=h-.5,j=k?p+A+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(k||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),k||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:m,width:g,height:v})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),k||L){var V=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault()})).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()})).on(\"drag\",this._onBarDrag.bind(this));k&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":778,\"../color\":643,\"../drawing\":665,d3:169}],745:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],746:[function(t,e,r){\"use strict\";e.exports={axisRefDescription:function(t,e,r){return[\"If set to a\",t,\"axis id (e.g. *\"+t+\"* or\",\"*\"+t+\"2*), the `\"+t+\"` position refers to a\",t,\"coordinate. If set to *paper*, the `\"+t+\"`\",\"position refers to the distance from the\",e,\"of the plotting\",\"area in normalized coordinates where *0* (*1*) corresponds to the\",e,\"(\"+r+\"). If set to a\",t,\"axis ID followed by\",\"*domain* (separated by a space), the position behaves like for\",\"*paper*, but refers to the distance in fractions of the domain\",\"length from the\",e,\"of the domain of that axis: e.g.,\",\"*\"+t+\"2 domain* refers to the domain of the second\",t,\" axis and a\",t,\"position of 0.5 refers to the\",\"point between the\",e,\"and the\",r,\"of the domain of the\",\"second\",t,\"axis.\"].join(\" \")}}},{}],747:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-time-format#locale_format\"}},{}],749:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],750:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],751:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],752:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],753:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEMAXYEAR:316224e5,ONEAVGYEAR:315576e5,ONEMINYEAR:31536e6,ONEMAXQUARTER:79488e5,ONEAVGQUARTER:78894e5,ONEMINQUARTER:76896e5,ONEMAXMONTH:26784e5,ONEAVGMONTH:26298e5,ONEMINMONTH:24192e5,ONEWEEK:6048e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:.999999,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],754:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],755:[function(t,e,r){\"use strict\";r.version=t(\"./version\").version,t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/legend\"),t(\"./components/fx\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(i(window.PlotlyLocales),delete window.PlotlyLocales),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":634,\"./components/annotations3d\":639,\"./components/colorbar\":649,\"./components/colorscale\":655,\"./components/errorbars\":671,\"./components/fx\":683,\"./components/grid\":687,\"./components/images\":692,\"./components/legend\":700,\"./components/rangeselector\":711,\"./components/rangeslider\":718,\"./components/shapes\":732,\"./components/sliders\":737,\"./components/updatemenus\":743,\"./fonts/mathjax_config\":756,\"./fonts/ploticon\":757,\"./lib/queue\":794,\"./locale-en\":808,\"./locale-en-us\":807,\"./plot_api\":812,\"./plot_api/plot_schema\":816,\"./plots/plots\":891,\"./registry\":911,\"./snapshot\":916,\"./traces/scatter\":1199,\"./version\":1370,d3:169,\"es6-promise\":224}],756:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],757:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawopenpath:{width:70,height:70,path:\"M33.21,85.65a7.31,7.31,0,0,1-2.59-.48c-8.16-3.11-9.27-19.8-9.88-41.3-.1-3.58-.19-6.68-.35-9-.15-2.1-.67-3.48-1.43-3.79-2.13-.88-7.91,2.32-12,5.86L3,32.38c1.87-1.64,11.55-9.66,18.27-6.9,2.13.87,4.75,3.14,5.17,9,.17,2.43.26,5.59.36,9.25a224.17,224.17,0,0,0,1.5,23.4c1.54,10.76,4,12.22,4.48,12.4.84.32,2.79-.46,5.76-3.59L43,80.07C41.53,81.57,37.68,85.64,33.21,85.65ZM74.81,69a11.34,11.34,0,0,0,6.09-6.72L87.26,44.5,74.72,32,56.9,38.35c-2.37.86-5.57,3.42-6.61,6L38.65,72.14l8.42,8.43ZM55,46.27a7.91,7.91,0,0,1,3.64-3.17l14.8-5.3,8,8L76.11,60.6l-.06.19a6.37,6.37,0,0,1-3,3.43L48.25,74.59,44.62,71Zm16.57,7.82A6.9,6.9,0,1,0,64.64,61,6.91,6.91,0,0,0,71.54,54.09Zm-4.05,0a2.85,2.85,0,1,1-2.85-2.85A2.86,2.86,0,0,1,67.49,54.09Zm-4.13,5.22L60.5,56.45,44.26,72.7l2.86,2.86ZM97.83,35.67,84.14,22l-8.57,8.57L89.26,44.24Zm-13.69-8,8,8-2.85,2.85-8-8Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawclosedpath:{width:90,height:90,path:\"M88.41,21.12a26.56,26.56,0,0,0-36.18,0l-2.07,2-2.07-2a26.57,26.57,0,0,0-36.18,0,23.74,23.74,0,0,0,0,34.8L48,90.12a3.22,3.22,0,0,0,4.42,0l36-34.21a23.73,23.73,0,0,0,0-34.79ZM84,51.24,50.16,83.35,16.35,51.25a17.28,17.28,0,0,1,0-25.47,20,20,0,0,1,27.3,0l4.29,4.07a3.23,3.23,0,0,0,4.44,0l4.29-4.07a20,20,0,0,1,27.3,0,17.27,17.27,0,0,1,0,25.46ZM66.76,47.68h-33v6.91h33ZM53.35,35H46.44V68h6.91Z\",transform:\"matrix(1 0 0 1 -5 -5)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawline:{width:70,height:70,path:\"M60.64,62.3a11.29,11.29,0,0,0,6.09-6.72l6.35-17.72L60.54,25.31l-17.82,6.4c-2.36.86-5.57,3.41-6.6,6L24.48,65.5l8.42,8.42ZM40.79,39.63a7.89,7.89,0,0,1,3.65-3.17l14.79-5.31,8,8L61.94,54l-.06.19a6.44,6.44,0,0,1-3,3.43L34.07,68l-3.62-3.63Zm16.57,7.81a6.9,6.9,0,1,0-6.89,6.9A6.9,6.9,0,0,0,57.36,47.44Zm-4,0a2.86,2.86,0,1,1-2.85-2.85A2.86,2.86,0,0,1,53.32,47.44Zm-4.13,5.22L46.33,49.8,30.08,66.05l2.86,2.86ZM83.65,29,70,15.34,61.4,23.9,75.09,37.59ZM70,21.06l8,8-2.84,2.85-8-8ZM87,80.49H10.67V87H87Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawrect:{width:80,height:80,path:\"M78,22V79H21V22H78m9-9H12V88H87V13ZM68,46.22H31V54H68ZM53,32H45.22V69H53Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},drawcircle:{width:80,height:80,path:\"M50,84.72C26.84,84.72,8,69.28,8,50.3S26.84,15.87,50,15.87,92,31.31,92,50.3,73.16,84.72,50,84.72Zm0-60.59c-18.6,0-33.74,11.74-33.74,26.17S31.4,76.46,50,76.46,83.74,64.72,83.74,50.3,68.6,24.13,50,24.13Zm17.15,22h-34v7.11h34Zm-13.8-13H46.24v34h7.11Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},eraseshape:{width:80,height:80,path:\"M82.77,78H31.85L6,49.57,31.85,21.14H82.77a8.72,8.72,0,0,1,8.65,8.77V69.24A8.72,8.72,0,0,1,82.77,78ZM35.46,69.84H82.77a.57.57,0,0,0,.49-.6V29.91a.57.57,0,0,0-.49-.61H35.46L17,49.57Zm32.68-34.7-24,24,5,5,24-24Zm-19,.53-5,5,24,24,5-5Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #3f4f75;} .cls-2 {fill: #80cfbe;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],758:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],759:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function f(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,f,h,p,d,g=l([r,n]);function m(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,f=o,h=s):r<n?(u=r,h=n):(u=n,h=r),t<e?(p=t,d=e):(p=e,d=t);var v,y=Math.abs(h-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+m(t,e)}return g?v=null===p?\"M\"+m(d,u)+x(d,f,0)+x(d,h,0)+\"Z\":\"M\"+m(p,u)+x(p,f,0)+x(p,h,0)+\"ZM\"+m(d,u)+x(d,f,1)+x(d,h,1)+\"Z\":null===p?(v=\"M\"+m(d,u)+x(d,h,0),c&&(v+=\"L0,0Z\")):v=\"M\"+m(p,u)+\"L\"+m(d,u)+x(d,h,0)+\"L\"+m(p,h)+x(p,u,1)+\"Z\",v}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return f(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return f(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return f(t,e,r,n,i,a,1)}}},{\"./mod\":785}],760:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,f=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,f?t!==i.constructor&&(t=!1):t=i.constructor),f+=o);if(!f)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(f)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(f),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],761:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":753,\"fast-isnumeric\":241}],762:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each((function(t){t.regl&&t.regl.clear({color:!0,depth:!0})}))}},{}],763:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],764:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,f=t(\"./array\").isArrayOrTypedArray;function h(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&f(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){f(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every((function(t){return i(t).isValid()}))?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,f,h,p=i.items,d=[],g=Array.isArray(p),m=g&&o&&Array.isArray(p[0]),v=o&&g&&!m,y=g&&!v?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],f=v?p.length:g?p[s].length:c.length,l=0;l<f;l++)u=v?p[l]:g?p[s][l]:p,void 0!==(h=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=h);else for(s=0;s<y;s++)void 0!==(h=a(t[s],g?p[s]:p,n[s]))&&(d[s]=h);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!h(t[a][o],n?r[a][o]:r))return!1}else if(!h(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&f(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!h(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)f(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=h},{\"../components/colorscale/scales\":658,\"../constants/interactions\":752,\"../plots/attributes\":824,\"./array\":760,\"./mod\":785,\"./nested_property\":786,\"./regex\":795,\"fast-isnumeric\":241,tinycolor2:576}],765:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3-time-format\").timeFormat,o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,f=c.ONEDAY,h=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,m=t(\"../registry\"),v=t(\"d3-time-format\").utcFormat,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&m.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){var n=function(t,e){return _(t)?e?m.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:m.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"}(t,!!e);if(e<2)return n;var i=r.dateTime2ms(n,t);return i+=f*(e-1),r.ms2DateTime(i,0,t)},r.dfltRange=function(t){return _(t)?m.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),v=t.charAt(0);!c||\"G\"!==v&&\"g\"!==v||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),T=t.match(w?x:y);if(!T)return u;var k=T[1],M=T[3]||\"1\",A=Number(T[5]||1),S=Number(T[7]||0),E=Number(T[9]||0),C=Number(T[11]||0);if(c){if(2===k.length)return u;var L;k=Number(k);try{var I=m.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var P=\"i\"===M.charAt(M.length-1);M=parseInt(M,10),L=I.newDate(k,I.toMonthIndex(k,M,P),A)}else L=I.newDate(k,Number(M),A)}catch(t){return u}return L?(L.toJD()-g)*f+S*h+E*p+C*d:u}k=2===k.length?(Number(k)+2e3-b)%100+b:Number(k),M-=1;var z=new Date(Date.UTC(2e3,M,A,S,E));return z.setUTCFullYear(k),z.getUTCMonth()!==M||z.getUTCDate()!==A?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var T=90*f,k=3*h,M=5*p;function A(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/f)+g,E=Math.floor(l(t,f));try{a=m.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=v(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<T?Math.floor(E/h):0,s=e<T?Math.floor(E%h/p):0,c=e<k?Math.floor(E%p/d):0,y=e<M?E%d*10+b:0}else x=new Date(w),a=v(\"%Y-%m-%d\")(x),o=e<T?x.getUTCHours():0,s=e<T?x.getUTCMinutes():0,c=e<k?x.getUTCSeconds():0,y=e<M?10*x.getUTCMilliseconds()+b:0;return A(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+f&&t<=i-f))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return A(a(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,(function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"}));var i=new Date(Math.floor(e+.05));if(_(n))try{t=m.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,f),n=w(Math.floor(r/h),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*f;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,f);if(t=Math.round(t-n),r)try{var i=Math.round(t/f)+g,a=m.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*f+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&m.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%f))if(c)try{1===(r=c.fromJD(n/f+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var h=t.length-l;return{exactYears:i/h,exactMonths:a/h,exactDays:s/h}}},{\"../constants/numerical\":753,\"../registry\":911,\"./loggers\":782,\"./mod\":785,\"d3-time-format\":166,\"fast-isnumeric\":241}],766:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\"),a=t(\"./matrix\"),o=t(\"gl-mat4\");function s(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function l(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}function c(t){var e=window.getComputedStyle(t,null),r=e.getPropertyValue(\"-webkit-transform\")||e.getPropertyValue(\"-moz-transform\")||e.getPropertyValue(\"-ms-transform\")||e.getPropertyValue(\"-o-transform\")||e.getPropertyValue(\"transform\");return\"none\"===r?null:r.replace(\"matrix\",\"\").replace(\"3d\",\"\").slice(1,-1).split(\",\").map((function(t){return+t}))}function u(t){for(var e=[];f(t);)e.push(t),t=t.parentNode;return e}function f(t){return t&&(t instanceof Element||t instanceof HTMLElement)}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:s,addStyleRule:function(t,e){l(\"global\",t,e)},addRelatedStyleRule:l,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&s(r)},getFullTransformMatrix:function(t){var e=u(t),r=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];return e.forEach((function(t){var e=c(t);if(e){var n=a.convertCssMatrix(e);r=o.multiply(r,r,n)}})),r},getElementTransformMatrix:c,getElementAndAncestors:u,equalDomRects:function(t,e){return t&&e&&t.x===e.x&&t.y===e.y&&t.top===e.top&&t.left===e.left&&t.right===e.right&&t.bottom===e.bottom}}},{\"./loggers\":782,\"./matrix\":784,d3:169,\"gl-mat4\":292}],767:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:110}],768:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,f,h,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(f=i(u)))?(f?(f=!1,h=c&&i(c)?c:[]):h=c&&n(c)?c:{},p[l]=a([h,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":779}],769:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],770:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],771:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"country-regex\"),a=t(\"@turf/area\"),o=t(\"@turf/centroid\"),s=t(\"@turf/bbox\"),l=t(\"./identity\"),c=t(\"./loggers\"),u=t(\"./is_plain_object\"),f=t(\"./nested_property\"),h=t(\"./polygon\"),p=Object.keys(i),d={\"ISO-3\":l,\"USA-states\":l,\"country names\":function(t){for(var e=0;e<p.length;e++){var r=p[e];if(new RegExp(i[r]).test(t.trim().toLowerCase()))return r}return c.log(\"Unrecognized country name: \"+t+\".\"),!1}};function g(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n=\"string\"==typeof e?r[e]:e;return u(n)?n:(c.error(\"Oops ... something went wrong when fetching \"+e),!1)}e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,i,a,o=d[t](e);if(o){if(\"USA-states\"===t)for(n=[],a=0;a<r.length;a++)(i=r[a]).properties&&i.properties.gu&&\"USA\"===i.properties.gu&&n.push(i);else n=r;for(a=0;a<n.length;a++)if((i=n[a]).id===o)return i;c.log([\"Location with id\",o,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1},feature2polygons:function(t){var e,r,n,i,a=t.geometry,o=a.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===s||\"FJI\"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];l.push(h.tester(e))}:\"ATA\"===s?function(t){var e=c(t);if(null===e)return l.push(h.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var a=h.tester(r);a.pts.pop(),l.push(a)}:function(t){l.push(h.tester(t))},a.type){case\"MultiPolygon\":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case\"Polygon\":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:g,extractTraceFeature:function(t){var e=t[0].trace,r=g(e);if(!r)return!1;var n,i={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(i[l.loc]=l)}function u(t){var r=f(t,e.featureidkey||\"id\").get(),n=i[r];if(n){var l=t.geometry;if(\"Polygon\"===l.type||\"MultiPolygon\"===l.type){var u={type:\"Feature\",id:r,geometry:l,properties:{}};u.properties.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,i=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=a.default(l);c>i&&(i=c,e=l)}else e=r;return o.default(e).geometry.coordinates}(u),n.fIn=t,n.fOut=u,s.push(u)}else c.log([\"Location\",n.loc,\"does not have a valid GeoJSON geometry.\",\"Traces with locationmode *geojson-id* only support\",\"*Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete i[r]}switch(r.type){case\"FeatureCollection\":var h=r.features;for(n=0;n<h.length;n++)u(h[n]);break;case\"Feature\":u(r);break;default:return c.warn([\"Invalid GeoJSON type\",(r.type||\"none\")+\".\",\"Traces with locationmode *geojson-id* only support\",\"*FeatureCollection* and *Feature* types.\"].join(\" \")),!1}for(var p in i)c.log([\"Location *\"+p+\"*\",\"does not have a matching feature with id-key\",\"*\"+e.featureidkey+\"*.\"].join(\" \"));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function i(t){return new Promise((function(r,i){n.json(t,(function(n,a){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return i(new Error(o))}return e[t]=a,r(a)}))}))}function a(t){return new Promise((function(r,n){var i=0,a=setInterval((function(){return e[t]&&\"pending\"!==e[t]?(clearInterval(a),r(e[t])):i>100?(clearInterval(a),n(\"Unexpected error while fetching from \"+t)):void i++}),50)}))}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;\"string\"==typeof s&&(e[s]?\"pending\"===e[s]&&r.push(a(s)):(e[s]=\"pending\",r.push(i(s))))}return r},computeBbox:function(t){return s.default(t)}}},{\"./identity\":776,\"./is_plain_object\":779,\"./loggers\":782,\"./nested_property\":786,\"./polygon\":790,\"@turf/area\":59,\"@turf/bbox\":60,\"@turf/centroid\":61,\"country-regex\":139,d3:169}],772:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":753}],773:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,f=n-e,h=a-e,p=s-a,d=l*p-u*f;if(0===d)return null;var g=(c*p-u*h)/d,m=(c*f-l*h)/d;return m<0||m>1||g<0||g>1?null:{x:t+l*g,y:e+f*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,f=n-e,h=o-i,p=c-a,d=u*u+f*f,g=h*h+p*p,m=Math.min(l(u,f,d,i-t,a-e),l(u,f,d,o-t,c-e),l(h,p,g,t-i,e-a),l(h,p,g,r-i,n-a));return Math.sqrt(m)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),f=t.getPointAtLength(o(r,e)),h={x:(4*f.x+l.x+c.x)/6,y:(4*f.y+l.y+c.y)/6,theta:u};return n[r]=h,h},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),f=u;function h(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,f=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+f*f)}for(var p=h(c);p;){if((c+=p+r)>f)return;p=h(c)}for(p=h(f);p;){if(c>(f-=p+r))return;p=h(f)}return{min:c,max:f,len:f-c,total:u,isClosed:0===c&&f===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,f=0,h=0,p=s;f<c;){if(i=(h+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:h=i,f++}return a}},{\"./mod\":785}],774:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s);function u(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function h(t){return n(t)?t:1}e.exports={formatColor:function(t,e,r){var n,i,s,p,d,g=t.color,m=l(g),v=l(e),y=o.extractOpts(t),x=[];if(n=void 0!==y.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=v?function(t,e){return void 0===t[e]?1:h(t[e])}:h,m||v)for(var b=0;b<r;b++)p=i(g,b),d=s(e,b),x[b]=u(p,d);else x=u(a(g),e);return x},parseColorScale:function(t){var e=o.extractOpts(t),r=e.colorscale;return e.reversescale&&(r=o.flipScale(e.colorscale)),r.map((function(t){var e=t[0],r=i(t[1]).toRgb();return{index:e,rgb:[r.r,r.g,r.b,r.a]}}))}}},{\"../components/color/attributes\":642,\"../components/colorscale\":655,\"./array\":760,\"color-normalize\":125,\"fast-isnumeric\":241,tinycolor2:576}],775:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":776}],776:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],777:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!e)return t;var r=1/Math.abs(e),n=r>1?(r*t+r*e)/r:t+e,i=String(n).length;if(i>16){var a=String(e).length;if(i>=String(t).length+a){var o=parseFloat(n).toPrecision(12);-1===o.indexOf(\"e+\")&&(n=+o)}}return n}},{}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../constants/numerical\"),s=o.FP_SAFE,l=o.BADNUM,c=e.exports={};c.nestedProperty=t(\"./nested_property\"),c.keyedContainer=t(\"./keyed_container\"),c.relativeAttr=t(\"./relative_attr\"),c.isPlainObject=t(\"./is_plain_object\"),c.toLogRange=t(\"./to_log_range\"),c.relinkPrivateKeys=t(\"./relink_private\");var u=t(\"./array\");c.isTypedArray=u.isTypedArray,c.isArrayOrTypedArray=u.isArrayOrTypedArray,c.isArray1D=u.isArray1D,c.ensureArray=u.ensureArray,c.concat=u.concat,c.maxRowLength=u.maxRowLength,c.minRowLength=u.minRowLength;var f=t(\"./mod\");c.mod=f.mod,c.modHalf=f.modHalf;var h=t(\"./coerce\");c.valObjectMeta=h.valObjectMeta,c.coerce=h.coerce,c.coerce2=h.coerce2,c.coerceFont=h.coerceFont,c.coerceHoverinfo=h.coerceHoverinfo,c.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,c.validate=h.validate;var p=t(\"./dates\");c.dateTime2ms=p.dateTime2ms,c.isDateTime=p.isDateTime,c.ms2DateTime=p.ms2DateTime,c.ms2DateTimeLocal=p.ms2DateTimeLocal,c.cleanDate=p.cleanDate,c.isJSDate=p.isJSDate,c.formatDate=p.formatDate,c.incrementMonth=p.incrementMonth,c.dateTick0=p.dateTick0,c.dfltRange=p.dfltRange,c.findExactDates=p.findExactDates,c.MIN_MS=p.MIN_MS,c.MAX_MS=p.MAX_MS;var d=t(\"./search\");c.findBin=d.findBin,c.sorterAsc=d.sorterAsc,c.sorterDes=d.sorterDes,c.distinctVals=d.distinctVals,c.roundUp=d.roundUp,c.sort=d.sort,c.findIndexOfMin=d.findIndexOfMin;var g=t(\"./stats\");c.aggNums=g.aggNums,c.len=g.len,c.mean=g.mean,c.median=g.median,c.midRange=g.midRange,c.variance=g.variance,c.stdev=g.stdev,c.interp=g.interp;var m=t(\"./matrix\");c.init2dArray=m.init2dArray,c.transposeRagged=m.transposeRagged,c.dot=m.dot,c.translationMatrix=m.translationMatrix,c.rotationMatrix=m.rotationMatrix,c.rotationXYMatrix=m.rotationXYMatrix,c.apply3DTransform=m.apply3DTransform,c.apply2DTransform=m.apply2DTransform,c.apply2DTransform2=m.apply2DTransform2,c.convertCssMatrix=m.convertCssMatrix,c.inverseTransformMatrix=m.inverseTransformMatrix;var v=t(\"./angles\");c.deg2rad=v.deg2rad,c.rad2deg=v.rad2deg,c.angleDelta=v.angleDelta,c.angleDist=v.angleDist,c.isFullCircle=v.isFullCircle,c.isAngleInsideSector=v.isAngleInsideSector,c.isPtInsideSector=v.isPtInsideSector,c.pathArc=v.pathArc,c.pathSector=v.pathSector,c.pathAnnulus=v.pathAnnulus;var y=t(\"./anchor_utils\");c.isLeftAnchor=y.isLeftAnchor,c.isCenterAnchor=y.isCenterAnchor,c.isRightAnchor=y.isRightAnchor,c.isTopAnchor=y.isTopAnchor,c.isMiddleAnchor=y.isMiddleAnchor,c.isBottomAnchor=y.isBottomAnchor;var x=t(\"./geometry2d\");c.segmentsIntersect=x.segmentsIntersect,c.segmentDistance=x.segmentDistance,c.getTextLocation=x.getTextLocation,c.clearLocationCache=x.clearLocationCache,c.getVisibleSegment=x.getVisibleSegment,c.findPointOnPath=x.findPointOnPath;var b=t(\"./extend\");c.extendFlat=b.extendFlat,c.extendDeep=b.extendDeep,c.extendDeepAll=b.extendDeepAll,c.extendDeepNoArrays=b.extendDeepNoArrays;var _=t(\"./loggers\");c.log=_.log,c.warn=_.warn,c.error=_.error;var w=t(\"./regex\");c.counterRegex=w.counter;var T=t(\"./throttle\");c.throttle=T.throttle,c.throttleDone=T.done,c.clearThrottle=T.clear;var k=t(\"./dom\");function M(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}c.getGraphDiv=k.getGraphDiv,c.isPlotDiv=k.isPlotDiv,c.removeElement=k.removeElement,c.addStyleRule=k.addStyleRule,c.addRelatedStyleRule=k.addRelatedStyleRule,c.deleteRelatedStyleRule=k.deleteRelatedStyleRule,c.getFullTransformMatrix=k.getFullTransformMatrix,c.getElementTransformMatrix=k.getElementTransformMatrix,c.getElementAndAncestors=k.getElementAndAncestors,c.equalDomRects=k.equalDomRects,c.clearResponsive=t(\"./clear_responsive\"),c.preserveDrawingBuffer=t(\"./preserve_drawing_buffer\"),c.makeTraceGroups=t(\"./make_trace_groups\"),c._=t(\"./localize\"),c.notifier=t(\"./notifier\"),c.filterUnique=t(\"./filter_unique\"),c.filterVisible=t(\"./filter_visible\"),c.pushUnique=t(\"./push_unique\"),c.increment=t(\"./increment\"),c.cleanNumber=t(\"./clean_number\"),c.ensureNumber=function(t){return a(t)?(t=Number(t))<-s||t>s?l:a(t)?Number(t):l:l},c.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(a(t)&&t>=0&&t%1==0)},c.noop=t(\"./noop\"),c.identity=t(\"./identity\"),c.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},c.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=c.nestedProperty(t,a.replace(\"?\",r)),s=c.nestedProperty(t,a.replace(\"?\",n)),l=o.get();o.set(s.get()),s.set(l)}},c.raiseToTop=function(t){t.parentNode.appendChild(t)},c.cancelTransition=function(t){return t.transition().duration(0)},c.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},c.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},c.simpleMap=function(t,e,r,n,i){for(var a=t.length,o=new Array(a),s=0;s<a;s++)o[s]=e(t[s],r,n,i);return o},c.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),l=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)l=Math.floor(Math.random()*n).toString(n)+l;u&&(o=Math.pow(n,u),l=Math.floor(Math.random()*o).toString(n)+l);var f=parseInt(l,n);return e&&e[l]||f!==1/0&&f>=Math.pow(2,r)?i>10?(c.warn(\"randstr failed uniqueness\"),l):t(e,r,n,(i||0)+1):l},c.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},c.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},c.syncOrAsync=function(t,e,r){var n;function i(){return c.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,c.promiseError);return r&&r(e)},c.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},c.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},c.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(c.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},c.mergeArrayCastPositive=function(t,e,r){return c.mergeArray(t,e,r,(function(t){var e=+t;return isFinite(e)&&e>0?e:0}))},c.fillArray=function(t,e,r,n){if(n=n||c.identity,c.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},c.castOption=function(t,e,r,n){n=n||c.identity;var i=c.nestedProperty(t,r).get();return c.isArrayOrTypedArray(i)?Array.isArray(e)&&c.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},c.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=c.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},c.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=M(o));for(var s=0;s<a.length;s++){var l=a[s];if(c.isIndex(l)||c.isArrayOrTypedArray(l)&&c.isIndex(l[0])&&c.isIndex(l[1])){var u=n?n[l]:l,f=r?r[u]:u;void 0!==(i=f)&&i<t.length&&(t[f].selected=1)}}},c.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=M(r),i=[],a=0;a<e.length;a++){var o=e[a];if(c.isIndex(o)){var s=n[o];c.isIndex(s)&&i.push(s)}}return i}return e},c.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=c.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},c.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):c.isTypedArray(a)?r[i]=a.subarray(0,3):r[i]=a&&\"object\"==typeof a?c.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},c.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},c.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},c.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;c.isIE9orBelow=function(){return c.isIE()&&A.test(window.navigator.userAgent)};var S=/Version\\/[\\d\\.]+.*Safari/;c.isSafari=function(){return S.test(window.navigator.userAgent)};var E=/iPad|iPhone|iPod/;c.isIOS=function(){return E.test(window.navigator.userAgent)},c.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},c.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},c.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},c.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var C=/^([^\\[\\.]+)\\.(.+)?/,L=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;c.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(C))?(i=t[r],n=e[1],delete t[r],t[n]=c.extendDeepNoArrays(t[n]||{},c.objectFromPath(r,c.expandObjectPaths(i))[n])):(e=r.match(L))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},c.extendDeepNoArrays(o,c.objectFromPath(s,c.expandObjectPaths(i)))):t[n][a]=c.expandObjectPaths(i)):t[r]=c.expandObjectPaths(t[r]));return t},c.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},c.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)([:|\\|][^}]*)?}/g;var I=/^\\w*$/;c.templateString=function(t,e){var r={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,n){var i;return I.test(n)?i=e[n]:(r[n]=r[n]||c.nestedProperty(e,n).get,i=r[n]()),c.isValidTextValue(i)?i:\"\"}))};var P={max:10,count:0,name:\"hovertemplate\"};c.hovertemplateString=function(){return D.apply(P,arguments)};var z={max:10,count:0,name:\"texttemplate\"};c.texttemplateString=function(){return D.apply(z,arguments)};var O=/^[:|\\|]/;function D(t,e,r){var a=this,o=arguments;e||(e={});var s={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,l,u){var f,h,p,d;for(p=3;p<o.length;p++)if(f=o[p]){if(f.hasOwnProperty(l)){h=f[l];break}if(I.test(l)||(h=s[l]||c.nestedProperty(f,l).get())&&(s[l]=h),void 0!==h)break}if(void 0===h&&a)return a.count<a.max&&(c.warn(\"Variable '\"+l+\"' in \"+a.name+\" could not be found!\"),h=t),a.count===a.max&&c.warn(\"Too many \"+a.name+\" warnings - additional warnings will be suppressed\"),a.count++,t;if(u){if(\":\"===u[0]&&(h=(d=r?r.numberFormat:n.format)(u.replace(O,\"\"))(h)),\"|\"===u[0]){d=r?r.timeFormat:i;var g=c.dateTime2ms(h);h=c.formatDate(g,u.replace(O,\"\"),!1,d)}}else e.hasOwnProperty(l+\"Label\")&&(h=e[l+\"Label\"]);return h}))}c.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var R=2e9;c.seedPseudoRandom=function(){R=2e9},c.pseudoRandom=function(){var t=R;return R=(69069*R+1)%4294967296,Math.abs(R-t)<429496729?c.pseudoRandom():R/4294967296},c.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=c.extractOption(t,e,\"htx\",\"hovertext\");if(c.isValidTextValue(i))return n(i);var a=c.extractOption(t,e,\"tx\",\"text\");return c.isValidTextValue(a)?n(a):void 0},c.isValidTextValue=function(t){return t||0===t},c.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},c.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e},c.strTranslate=function(t,e){return t||e?\"translate(\"+t+\",\"+e+\")\":\"\"},c.strRotate=function(t){return t?\"rotate(\"+t+\")\":\"\"},c.strScale=function(t){return 1!==t?\"scale(\"+t+\")\":\"\"},c.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,u=t.scale;return u?u>1&&(u=1):u=0,c.strTranslate(i-u*(r+o),a-u*(n+s))+c.strScale(u)+(l?\"rotate(\"+l+(e?\"\":\" \"+r+\" \"+n)+\")\":\"\")},c.ensureUniformFontSize=function(t,e){var r=c.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r},c.join2=function(t,e,r){var n=t.length;return n>1?t.slice(0,-1).join(e)+r+t[n-1]:t.join(e)}},{\"../constants/numerical\":753,\"./anchor_utils\":758,\"./angles\":759,\"./array\":760,\"./clean_number\":761,\"./clear_responsive\":763,\"./coerce\":764,\"./dates\":765,\"./dom\":766,\"./extend\":768,\"./filter_unique\":769,\"./filter_visible\":770,\"./geometry2d\":773,\"./identity\":776,\"./increment\":777,\"./is_plain_object\":779,\"./keyed_container\":780,\"./localize\":781,\"./loggers\":782,\"./make_trace_groups\":783,\"./matrix\":784,\"./mod\":785,\"./nested_property\":786,\"./noop\":787,\"./notifier\":788,\"./preserve_drawing_buffer\":792,\"./push_unique\":793,\"./regex\":795,\"./relative_attr\":796,\"./relink_private\":797,\"./search\":798,\"./stats\":801,\"./throttle\":804,\"./to_log_range\":805,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],779:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],780:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var f=i.test(a),h={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(f?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,f?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,h},get:function(t){if(s){var e=u[t];return void 0===e?void 0:f?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n||(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e),h},remove:function(t){var e=u[t];if(void 0===e)return h;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],h.set(t,null);if(f){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return h},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=f?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return h}},{\"./nested_property\":786}],781:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":911}],782:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=t(\"./notifier\"),a=e.exports={};function o(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}a.log=function(){var t;if(n.logging>1){var e=[\"LOG:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"long\")}},a.warn=function(){var t;if(n.logging>0){var e=[\"WARN:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}},a.error=function(){var t;if(n.logging>0){var e=[\"ERROR:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.error,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}}},{\"../plot_api/plot_config\":815,\"./notifier\":788}],783:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,(function(t){return t[0].trace.uid}));i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each((function(t){t[0][a]=n.select(this)})),i}},{d3:169}],784:[function(t,e,r){\"use strict\";var n=t(\"gl-mat4\");r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply3DTransform=function(t){return function(){var e=arguments,n=1===arguments.length?e[0]:[e[0],e[1],e[2]||0];return r.dot(t,[n[0],n[1],n[2],1]).slice(0,3)}},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}},r.convertCssMatrix=function(t){if(t){var e=t.length;if(16===e)return t;if(6===e)return[t[0],t[1],0,0,t[2],t[3],0,0,0,0,1,0,t[4],t[5],0,1]}return[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]},r.inverseTransformMatrix=function(t){var e=[];return n.invert(e,t),[[e[0],e[1],e[2],e[3]],[e[4],e[5],e[6],e[7]],[e[8],e[9],e[10],e[11]],[e[12],e[13],e[14],e[15]]]}},{\"gl-mat4\":292}],785:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],786:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;function a(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=a(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if(\"number\"==typeof r&&!i(c))return;if(\"object\"!=typeof(c=c[r])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,i,o,s=0,c=e.split(\".\");s<c.length;){if(r=String(c[s]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw\"bad property string\";c.splice(0,1)}for(i=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<i.length;o++)s++,c.splice(s,0,Number(i[o]))}s++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:a(t,c),astr:e,parts:c,obj:t}};var o=/(^|\\.)args\\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var a,o,l=t,h=\"\",p=[[t,h]],d=s(n,r);for(o=0;o<e.length-1;o++){if(\"number\"==typeof(a=e[o])&&!i(l))throw\"array index but container is not an array\";if(-1===a){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!f(l,a,e[o+1],d))break;if(\"object\"!=typeof(l=l[a])||null===l)throw\"container is not an object\";h=c(h,a),p.push([l,h])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function u(t,e,r,n){var a,o=i(r),c=!0,u=r,h=n.replace(\"-1\",0),p=!o&&s(r,h),d=e[0];for(a=0;a<t.length;a++)h=n.replace(\"-1\",a),o&&(p=s(u=r[a%r.length],h)),p&&(c=!1),f(t,a,d,p)&&l(t[a],e,n.replace(\"-1\",a))(u);return c}function f(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":760,\"fast-isnumeric\":241}],787:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],788:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each((function(t){var i=n.select(this);i.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",(function(){i.transition().call(s)}));for(var a=i.append(\"p\"),o=t.split(/<br\\s*\\/?>/g),l=0;l<o.length;l++)l&&a.append(\"br\"),a.append(\"span\").text(o[l]);\"stick\"===e?i.transition().duration(350).style(\"opacity\",1):i.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)}))}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",(function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()}))}}},{d3:169,\"fast-isnumeric\":241}],789:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":799}],790:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,f=r[0];for(e=1;e<r.length;e++)if(f[0]!==r[e][0]||f[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s)&&(!e||!l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,f,h,p,d,g=r.length,m=r[0][0],v=r[0][1],y=0;for(u=1;u<g;u++)if(f=m,h=v,m=r[u][0],v=r[u][1],!(l<(p=Math.min(f,m))||l>Math.max(f,m)||c>Math.max(h,v)))if(c<Math.min(h,v))l!==p&&y++;else{if(c===(d=m===f?c:h+(l-f)*(v-h)/(m-f)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),f=Math.sqrt(u),h=[-c[1]/f,c[0]/f];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,h))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":753,\"./matrix\":784}],791:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each((function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}n.regl||(o=!1),o&&this.addEventListener(\"webglcontextlost\",(function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})}),!1)}})),o||n({container:a._glcontainer.node()}),o}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":800,regl:540}],792:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"is-mobile\");e.exports=function(t){var e;if(\"string\"!=typeof(e=t&&t.hasOwnProperty(\"userAgent\")?t.userAgent:function(){var t;\"undefined\"!=typeof navigator&&(t=navigator.userAgent);t&&t.headers&&\"string\"==typeof t.headers[\"user-agent\"]&&(t=t.headers[\"user-agent\"]);return t}()))return!0;var r=i({ua:{headers:{\"user-agent\":e}},tablet:!0,featureDetect:!1});if(!r)for(var a=e.split(\" \"),o=1;o<a.length;o++){if(-1!==a[o].indexOf(\"Safari\"))for(var s=o-1;s>-1;s--){var l=a[s];if(\"Version/\"===l.substr(0,8)){var c=l.substr(8).split(\".\")[0];if(n(c)&&(c=+c),c>=13)return!0}}}return r}},{\"fast-isnumeric\":241,\"is-mobile\":467}],793:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],794:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":778,\"../plot_api/plot_config\":815}],795:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],796:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],797:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":760,\"./is_plain_object\":779}],798:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\"),o=t(\"../constants/numerical\").BADNUM;function s(t,e){return t<e}function l(t,e){return t<=e}function c(t,e){return t>e}function u(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,o,f=0,h=e.length,p=0,d=h>1?(e[h-1]-e[0])/(h-1):1;for(o=d>=0?r?s:l:r?u:c,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);f<h&&p++<100;)o(e[a=Math.floor((f+h)/2)],t)?f=a+1:h=a;return p>90&&i.log(\"Long binary search...\"),f-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t,e){var n,i=(e||{}).unitMinDiff,a=t.slice();for(a.sort(r.sorterAsc),n=a.length-1;n>-1&&a[n]===o;n--);var s=1;i||(s=a[n]-a[0]||1);for(var l,c=s/(n||1)/1e4,u=[],f=0;f<=n;f++){var h=a[f],p=h-l;void 0===l?(u.push(h),l=h):p>c&&(s=Math.min(s,p),u.push(h),l=h)}return{vals:u,minDiff:s}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"../constants/numerical\":753,\"./identity\":776,\"./loggers\":782,\"fast-isnumeric\":241}],799:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach((function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)})),e&&t.classed(\"cursor-\"+e,!0)}},{}],800:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":643}],801:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums((function(t){return t+1}),0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums((function(t,e){return t+e}),0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums((function(t,e){return t+Math.pow(e-i,2)}),0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":760,\"fast-isnumeric\":241}],802:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":125}],803:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=i.strTranslate,o=t(\"../constants/xmlns_namespaces\"),s=t(\"../constants/alignment\").LINE_SPACING;function l(t,e){return t.node().getBoundingClientRect()[e]}var c=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,A){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(c),L=n.select(t.node().parentNode);if(!L.empty()){var I=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return I+=\"-math\",L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise((function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),o={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue((function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})}),(function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")}),(function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(u,\"\\\\lt \").replace(f,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())}),(function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)}),(function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)}))}(C[2],o,(function(n,i,o){L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove();var s=n&&n.select(\"svg\");if(!s||!s.node())return P(),void e();var c=L.append(\"g\").classed(I+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});c.node().appendChild(s.node()),i&&i.node()&&s.node().insertBefore(i.node().cloneNode(!0),s.node().firstChild),s.attr({class:I,height:o.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var u=t.node().style.fill||\"black\",f=s.select(\"g\");f.attr({fill:u,stroke:u});var h=l(f,\"width\"),p=l(f,\"height\"),d=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],g=-(r||l(t,\"height\"))/4;\"y\"===I[0]?(c.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\")\"+a(-h/2,g-p/2)}),s.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===I[0]?s.attr({x:t.attr(\"x\"),y:g-p/2}):\"a\"===I[0]&&0!==I.indexOf(\"atitle\")?s.attr({x:0,y:g}):s.attr({x:d,y:+t.attr(\"y\")+g-p/2}),A&&A.call(t,c),e(c)}))}))):P(),t}function P(){L.empty()||(I=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+I).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(m,\" \");var r,a=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(o.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*s+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var a=1;a<i.length;a++)f(i[a])}function f(t){var e,i=t.type,a={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(a={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(a.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(a.style=t.style);var f=document.createElementNS(o.svg,e);if(\"sup\"===i||\"sub\"===i){A(r,\"\\u200b\"),r.appendChild(f);var h=document.createElementNS(o.svg,\"tspan\");A(h,\"\\u200b\"),n.select(h).attr(\"dy\",d[i]),a.dy=p[i],r.appendChild(f),r.appendChild(h)}else r.appendChild(f);n.select(f).attr(a),r=t.node=f,l.push(t)}function A(t,e){t.appendChild(document.createTextNode(e))}function S(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var C=e.split(v),L=0;L<C.length;L++){var I=C[L],P=I.match(y),z=P&&P[2].toLowerCase(),O=h[z];if(\"br\"===z)u();else if(void 0===O)A(r,E(I));else if(P[1])S(z);else{var D=P[4],R={type:z},F=k(D,b);if(F?(F=F.replace(M,\"$1 fill:\"),O&&(F+=\";\"+O)):O&&(F=O),F&&(R.style=F),\"a\"===z){a=!0;var B=k(D,_);if(B){var N=document.createElement(\"a\");N.href=B,-1!==g.indexOf(N.protocol)&&(R.href=encodeURI(decodeURI(B)),R.target=k(D,w)||\"_blank\",R.popup=k(D,T))}}f(R)}}return a}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),A&&A.call(t)}};var u=/(<|&lt;|&#60;)/g,f=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},p={sub:\"0.3em\",sup:\"-0.6em\"},d={sub:\"-0.21em\",sup:\"0.42em\"},g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],m=r.NEWLINES=/(\\r\\n?|\\n)/g,v=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i;r.BR_TAG_ALL=/<br(\\s+.*)?>/gi;var b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,T=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function k(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var M=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(v),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],f=u.match(y),h=f&&f[2].toLowerCase();if(h)-1!==n.indexOf(h)&&(o.push(u),s=h);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var A={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,(function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):A[e])||t}))}function C(t,e,r){var n,a,o,s=r.horizontalAlign,l=r.verticalAlign||\"top\",c=t.node().getBoundingClientRect(),u=e.node().getBoundingClientRect();return a=\"bottom\"===l?function(){return c.bottom-n.height}:\"middle\"===l?function(){return c.top+(c.height-n.height)/2}:function(){return c.top},o=\"right\"===s?function(){return c.right-n.width}:\"center\"===s?function(){return c.left+(c.width-n.width)/2}:function(){return c.left},function(){n=this.node().getBoundingClientRect();var t=o()-u.left,e=a()-u.top,s=r.gd||{};if(r.gd){s._fullLayout._calcInverseTransform(s);var l=i.apply3DTransform(s._fullLayout._invTransform)(t,e);t=l[0],e=l[1]}return this.style({top:e+\"px\",left:t+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.sanitizeHTML=function(t){t=t.replace(m,\" \");for(var e=document.createElement(\"p\"),r=e,i=[],a=t.split(v),o=0;o<a.length;o++){var s=a[o],l=s.match(y),c=l&&l[2].toLowerCase();if(c in h)if(l[1])i.length&&(r=i.pop());else{var u=l[4],f=k(u,b),p=f?{style:f}:{};if(\"a\"===c){var d=k(u,_);if(d){var x=document.createElement(\"a\");if(x.href=d,-1!==g.indexOf(x.protocol)){p.href=encodeURI(decodeURI(d));var T=k(u,w);T&&(p.target=T)}}}var M=document.createElement(c);r.appendChild(M),n.select(M).attr(p),r=M,i.push(M)}else r.appendChild(document.createTextNode(E(s)))}return e.innerHTML},r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each((function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})}))},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",(function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)})).on(\"focus\",(function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",(function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()}))})).on(\"keyup\",(function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",(function(){return!1})).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))})).on(\"keydown\",(function(){13===n.event.which&&this.blur()})).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":745,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],804:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout((function(){l(),a.timer=null}),e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise((function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}})):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],805:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":241}],806:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":858,\"topojson-client\":579}],807:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],808:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":911}],810:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function f(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=h(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function h(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=h(t.items[o],e,\"from-root\")}return a}return f(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:f}},{\"../lib\":778}],811:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,f=l.getFromTrace,h=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n,!0))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function m(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function v(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,f=(s.subplotsRegistry.ternary||{}).attrRegex,h=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var m=g[e];if(a&&a.test(m)){var v=t[m];v.anchor&&\"free\"!==v.anchor&&(v.anchor=u(v.anchor)),v.overlaying&&(v.overlaying=u(v.overlaying)),v.type||(v.isdate?v.type=\"date\":v.islog?v.type=\"log\":!1===v.isdate&&!1===v.islog&&(v.type=\"linear\")),\"withzero\"!==v.autorange&&\"tozero\"!==v.autorange||(v.autorange=!0,v.rangemode=\"tozero\"),delete v.islog,delete v.isdate,delete v.categories,y(v,\"domain\")&&delete v.domain,void 0!==v.autotick&&(void 0===v.tickmode&&(v.tickmode=v.autotick?\"auto\":\"linear\"),delete v.autotick),d(v)}else if(l&&l.test(m)){d(t[m].radialaxis)}else if(f&&f.test(m)){var x=t[m];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(h&&h.test(m)){var b=t[m],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],T=_[1],k=_[2],M=i([],w),A=[];for(n=0;n<3;++n)A[n]=T[n]+k*M[2+4*n];b.camera={eye:{x:A[0],y:A[1],z:A[2]},center:{x:T[0],y:T[1],z:T[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var I=Array.isArray(t.images)?t.images.length:0;for(e=0;e<I;e++){var P=t.images[e];o.isPlainObject(P)&&(p(P,\"xref\"),p(P,\"yref\"))}var z=t.legend;return z&&(z.x>3?(z.x=1.02,z.xanchor=\"left\"):z.x<-2&&(z.x=-.02,z.xanchor=\"right\"),z.y>3?(z.y=1.02,z.yanchor=\"bottom\"):z.y<-2&&(z.y=-.02,z.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,f=i.error_y.color||(h(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(f),c.opacity(f)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!h(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),h(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!h(i,\"pie-like\")&&!h(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=v(i.textposition[n]);else i.textposition&&(i.textposition=v(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var T=!1!==(i.increasing||{}).showlegend,k=!1!==(i.decreasing||{}).showlegend,M=g(i.increasing),A=g(i.decreasing);if(!1!==M&&!1!==A){var S=m(M,A,T,k);S&&(i.name=S)}else!M&&!A||i.name||(i.name=M||A)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,I=Object.keys(L);C.styles=[];for(var P=0;P<I.length;P++)C.styles.push({target:I[P],value:L[I[P]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map((function(t,e){return e}));if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=f(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":643,\"../lib\":778,\"../plots/cartesian/axis_ids\":831,\"../plots/plots\":891,\"../registry\":911,\"fast-isnumeric\":241,\"gl-mat4/fromQuat\":282}],812:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":913,\"./plot_api\":814,\"./template_api\":819,\"./to_image\":820,\"./validate\":821}],813:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var f=e.astr,h=s.getComponentMethod(f,\"supplyLayoutDefaults\"),p=s.getComponentMethod(f,\"draw\"),d=s.getComponentMethod(f,\"drawOne\"),g=n.replot||n.recalc||h===i||p===i,m=t.layout,v=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",f);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",f,y),!0;e.set(y)}return!g&&(h(m,v),p(t),!0)}var x,b,_,w,T,k,M,A,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(v,f).get(),I=[],P=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],T=Object.keys(w),k=w[\"\"],M=l(k),_<0||_>C.length-(M?0:1))a.warn(\"index out of range\",f,_);else if(void 0!==k)T.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",f,_),c(k)?I.push(_):M?(\"add\"===k&&(k={}),C.splice(_,0,k),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",f,_,k),-1===P&&(P=_);else for(b=0;b<T.length;b++)A=f+\"[\"+_+\"].\",u(C[_],T[b],A).set(w[T[b]]);for(x=I.length-1;x>=0;x--)C.splice(I[x],1),L&&L.splice(I[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(h(m,v),d!==i){var O;if(-1===P)O=S;else{for(z=Math.max(C.length,z),O=[],x=0;x<S.length&&!((_=S[x])>=P);x++)O.push(_);for(x=P;x<z;x++)O.push(x)}for(x=0;x<O.length;x++)d(t,O[x])}else p(t);return!0}},{\"../lib/is_plain_object\":779,\"../lib/loggers\":782,\"../lib/noop\":787,\"../lib/search\":798,\"../registry\":911,\"./container_array_match\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),f=t(\"./plot_schema\"),h=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),m=t(\"../components/color\"),v=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),T=t(\"./helpers\"),k=t(\"./subroutines\"),M=t(\"./edit_types\"),A=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0;function E(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function C(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function L(t,e){C(t,m.combine(e,\"white\"))}function I(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=L:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var f=c.scrollZoom,h=c._scrollZoom={};if(!0===f)h.cartesian=1,h.gl3d=1,h.geo=1,h.mapbox=1;else if(\"string\"==typeof f){var p=f.split(\"+\");for(i=0;i<p.length;i++)h[p[i]]=1}else!1!==f&&(h.gl3d=1,h.geo=1,h.mapbox=1)}function P(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function z(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function O(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),z(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&z(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function D(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in z(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,f,h=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=P(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);f=h?n[d][g]:n,i(f)||(f=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(f)})}return p}(t,e,r,n),c={},u={},f=0;f<l.length;f++){var h=l[f].prop,p=l[f].maxp,d=a(l[f].target,l[f].insert,p);h.set(d[0]),Array.isArray(c[h.astr])||(c[h.astr]=[]),c[h.astr].push(d[1]),Array.isArray(u[h.astr])||(u[h.astr]=[]),u[h.astr].push(l[f].target.length)}return{update:c,maxPoints:u}}function R(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function F(t,e,n,i){t=o.getGraphDiv(t),T.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=T.coerceTraceIndices(t,i),l=U(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&T.clearAxisTypes(t,s,{});var f=[];u.fullReplot?f.push(r.plot):(f.push(h.previousPromises),h.supplyDefaults(t),u.markerSize&&(h.doCalcdata(t),G(f)),u.style&&f.push(k.doTraceStyle),u.colorbars&&f.push(k.doColorBars),f.push(E)),f.push(h.rehover,h.redrag),c.add(t,F,[t,l.undoit,l.traces],F,[t,l.redoit,l.traces]);var p=o.syncOrAsync(f,t);return p&&p.then||(p=Promise.resolve()),p.then((function(){return t.emit(\"plotly_restyle\",l.eventData),t}))}function B(t){return void 0===t?null:t}function N(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){j((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function j(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)j(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},f=o.extendFlat({},c,u);for(var h in f)j(t+\".\"+h,c[h],u[h],n)}else void 0===n[t]&&(n[t]=B(e))}function U(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=N(i._preGUI,c),g=o.extendDeepAll({},e);V(e);var m,v=M.traceFlags(),y={},x={};function b(){return r.map((function(){}))}function _(t){var e=d.id2name(t);-1===m.indexOf(e)&&m.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function k(t){return\"LAYOUT\"+t+\".range\"}function A(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach((function(t){S(t,a,o)}));else if(!(n in e)&&!T.hasParent(e,n)){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=N(i._tracePreGUI[A(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=B(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(T.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var I,P,z,O,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(I=l[r[n]],P=A(r[n]),O=(z=N(i._tracePreGUI[P._fullInput.uid],c)(I,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var j=z.parts[z.parts.length-1],U=L.substr(0,L.length-j.length-1),q=U?U+\".\":\"\",H=U?s(P,U).get():P;if((R=f.getTraceValObject(P,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==j&&\"lenmode\"!==j||O===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===O)||\"funnelarea\"===D!=(\"funnelarea\"===O))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==O||\"h\"!==I.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(I,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(I,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(I,[\"?\",\"?src\"],\"values\",W),\"pie\"===O||\"funnelarea\"===O?(s(I,\"marker.color\").set(s(I,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(I,\"cartesian\")&&s(I,\"marker.colors\").set(s(I,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===j){var K=J?X.h:X.w;S(q+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var Q=J?X.w:X.h;S(q+\"len\",H.len*(\"fraction\"===D?1/Q:Q),n)}}x[L][n]=B(O);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var $=I.x&&!I.y?\"h\":\"v\";if((z.get()||$)===P.orientation)continue}else\"orientationaxes\"===L&&(I.orientation={v:\"h\",h:\"v\"}[P.orientation]);T.swapXYData(I),v.calc=v.clearAxisTypes=!0}else-1!==h.dataArrayContainers.indexOf(z.parts[0])?(T.manageArrayContainers(z,D,x),v.calc=!0):(R?R.arrayOk&&!u.traceIs(P,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(O))?v.calc=!0:M.update(v,R):v.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\"),et=tt.get();\"x\"===et?tt.set(\"y\"):\"y\"===et?tt.set(\"x\"):\"x unified\"===et?tt.set(\"y unified\"):\"y unified\"===et&&tt.set(\"x unified\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(m=[],n=0;n<r.length;n++){var rt=l[r[n]];u.traceIs(rt,\"cartesian\")&&(_(rt.xaxis||\"x\"),_(rt.yaxis||\"y\"))}S(m.map(w),!0,0),S(m.map(k),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[B(z.get())],z.set(Array.isArray(F)?F[0]:F),v.calc=!0}return(v.calc||v.plot)&&(v.fullReplot=!0),{flags:v,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function V(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function q(t,e,r){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=Z(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[h.previousPromises];a.layoutReplot?s.push(k.layoutReplot):Object.keys(n).length&&(H(t,a,i)||h.supplyDefaults(t),a.legend&&s.push(k.doLegend),a.layoutstyle&&s.push(k.layoutStyles),a.axrange&&G(s,i.rangesAltered),a.ticks&&s.push(k.doTicksRelayout),a.modebar&&s.push(k.doModeBar),a.camera&&s.push(k.doCamera),a.colorbars&&s.push(k.doColorBars),s.push(E)),s.push(h.rehover,h.redrag),c.add(t,q,[t,i.undoit],q,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then((function(){return t.emit(\"plotly_relayout\",i.eventData),t}))}function H(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,s.range&&(l.range=s.range.slice()),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function G(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")&&a._anchorAxis&&r.push(a._anchorAxis._id),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,k.doAutoRangeAndConstraints,r,k.drawData,k.finalDraw)}var Y=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,W=/^[xyz]axis[0-9]*\\.autorange$/,X=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function Z(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,h=N(l._preGUI,c),p=Object.keys(e),g=d.list(t),m=o.extendDeepAll({},e),v={};for(V(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=M.layoutFlags(),k={},S={};function E(t,r){if(Array.isArray(t))t.forEach((function(t){E(t,r)}));else if(!(t in e)&&!T.hasParent(e,t)){var n=h(a,t);t in S||(S[t]=B(n.get())),void 0!==r&&n.set(r)}}var C,L={};function I(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var P in e){if(T.hasParent(e,P))throw new Error(\"cannot set \"+P+\" and a parent attribute simultaneously\");for(var z=h(a,P),O=e[P],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,j=z.parts.slice(0,D).join(\".\"),U=s(t.layout,j).get(),q=s(l,j).get(),H=z.get();if(void 0!==O){k[P]=O,S[P]=\"reverse\"===R?O:B(H);var G=f.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==O)for(var Z in G.impliedEdits)E(o.relativeAttr(P,Z),G.impliedEdits[Z]);if(-1!==[\"width\",\"height\"].indexOf(P))if(O){E(\"autosize\",null);var K=\"height\"===P?\"width\":\"height\";E(K,l[K])}else l[P]=t._initialAutoSize[P];else if(\"autosize\"===P)E(\"width\",O?null:l.width),E(\"height\",O?null:l.height);else if(F.match(Y))I(F),s(l,j+\"._inputRange\").set(null);else if(F.match(W)){I(F),s(l,j+\"._inputRange\").set(null);var Q=s(l,j).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else F.match(X)&&s(l,j+\"._inputDomain\").set(null);if(\"type\"===R){C=U;var $=\"linear\"===q.type&&\"log\"===O,tt=\"log\"===q.type&&\"linear\"===O;if($||tt){if(C&&C.range)if(q.autorange)$&&(C.range=C.range[1]>C.range[0]?[1,2]:[2,1]);else{var et=C.range[0],rt=C.range[1];$?(et<=0&&rt<=0&&E(j+\".autorange\",!0),et<=0?et=rt/1e6:rt<=0&&(rt=et/1e6),E(j+\".range[0]\",Math.log(et)/Math.LN10),E(j+\".range[1]\",Math.log(rt)/Math.LN10)):(E(j+\".range[0]\",Math.pow(10,et)),E(j+\".range[1]\",Math.pow(10,rt)))}else E(j+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,O,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,O,E)}else E(j+\".autorange\",!0),E(j+\".range\",null);s(l,j+\"._inputRange\").set(null)}else if(R.match(A)){var nt=s(l,P).get(),it=(O||{}).type;it&&\"-\"!==it||(it=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,nt,it,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,nt,it,E)}var at=w.containerArrayMatch(P);if(at){r=at.array,n=at.index;var ot=at.property,st=G||{editType:\"calc\"};\"\"!==n&&\"\"===ot&&(w.isAddVal(O)?S[P]=null:w.isRemoveVal(O)?S[P]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),M.update(_,st),v[r]||(v[r]={});var lt=v[r][n];lt||(lt=v[r][n]={}),lt[ot]=O,delete e[P]}else\"reverse\"===R?(U.range?U.range.reverse():(E(j+\".autorange\",!0),U.range=[1,0]),q.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===P&&(\"lasso\"===O||\"select\"===O)&&\"lasso\"!==H&&\"select\"!==H||l._has(\"gl2d\")?_.plot=!0:G?M.update(_,G):_.calc=!0,z.set(O))}}for(r in v){w.applyContainerArrayChanges(t,h(a,r),v[r],_,h)||(_.plot=!0)}for(var ct in L){var ut=(C=d.getFromId(t,ct))&&C._constraintGroup;if(ut)for(var ft in _.calc=!0,ut)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(J(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:k,eventData:m}}function J(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&h.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function K(t,e,n,i){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=T.coerceTraceIndices(t,i),s=U(t,o.extendFlat({},e),a),l=s.flags,u=Z(t,o.extendFlat({},n)),f=u.flags;(l.calc||f.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&T.clearAxisTypes(t,a,n);var p=[];f.layoutReplot?p.push(k.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(h.previousPromises),H(t,f,u)||h.supplyDefaults(t),l.style&&p.push(k.doTraceStyle),(l.colorbars||f.colorbars)&&p.push(k.doColorBars),f.legend&&p.push(k.doLegend),f.layoutstyle&&p.push(k.layoutStyles),f.axrange&&G(p,u.rangesAltered),f.ticks&&p.push(k.doTicksRelayout),f.modebar&&p.push(k.doModeBar),f.camera&&p.push(k.doCamera),p.push(E)),p.push(h.rehover,h.redrag),c.add(t,K,[t,s.undoit,u.undoit,s.traces],K,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then((function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t}))}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var $=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center|fitbounds)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],tt=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function et(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function rt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function nt(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function at(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function ot(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,f=n.immutable,h=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;h&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[h],p):(M.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(Y.test(l)||W.test(l))&&(u.rangesAltered[r[0]]=1),X.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var m=t[a],v=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof m&&m!==v){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(m)!==JSON.stringify(v))){var b,_=i.valType,w=g(i),T=Array.isArray(m),k=Array.isArray(v);if(T&&k){var A=\"_input_\"+a,S=t[A],E=e[A];if(Array.isArray(S)&&S===E)continue}if(void 0===v)w&&T?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;h||(u.arrays[a]=C);var I=Math.min(m.length,v.length),P=Math.max(m.length,v.length);if(I!==P){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<I;b++)ot(m[b],v[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=I;b<P;b++)C.push(b)}else!_&&o.isPlainObject(m)?ot(m,v,y,n):w?T&&k?(f&&(u.calc=!0),(f||n.newDataRevision)&&d()):T!==k?u.calc=!0:d():T&&k&&m.length===v.length&&String(m)===String(v)||d()}}}for(a in e)if(!(a in t)&&\"_\"!==a.charAt(0)&&\"function\"!=typeof e[a]){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function st(t){var e=t._fullLayout,r=t.getBoundingClientRect();if(!o.equalDomRects(r,e._lastBBox)){var n=e._invTransform=o.inverseTransformMatrix(o.getFullTransformMatrix(t));e._invScaleX=Math.sqrt(n[0][0]*n[0][0]+n[0][1]*n[0][1]+n[0][2]*n[0][2]),e._invScaleY=Math.sqrt(n[1][0]*n[1][0]+n[1][1]*n[1][1]+n[1][2]*n[1][2]),e._lastBBox=r}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._calcInverseTransform=st,r._calcInverseTransform(t),r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"user-select-none\",!0).classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),delete r._modeBar,r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each((function(){this.id&&(i[this.id.split(\"-\")[1]]=1)})),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._treemaplayer=r._paper.append(\"g\").classed(\"treemaplayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=h.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise((function(a,u){function f(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,h.transition(t,e.frame.data,e.frame.layout,T.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then((function(){e.onComplete&&e.onComplete()})),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&f()};e()}var d,g,m=0;function v(t){return Array.isArray(i)?m>=i.length?t.transitionOpts=i[m]:t.transitionOpts=i[0]:t.transitionOpts=i,m++,t}var y=[],x=null==e,b=Array.isArray(e);if(!x&&!b&&o.isPlainObject(e))y.push({type:\"object\",data:v(o.extendFlat({},e))});else if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:v({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:v({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:v(o.extendFlat({},_))})}for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var k=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){k=d;break}if(k>0&&k<y.length-1){var M=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>k)&&M.push(g);y=M}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?h.computeFrame(t,e[i].name):e[i].data;var f=l(i),d=s(i);d.duration=Math.min(d.duration,f.duration);var g={frame:o,name:e[i].name,frameOpts:f,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())}))},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var f=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,m=(u[g]||d[g]||{}).name,v=e[n].name,y=u[m]||d[m];m&&v&&\"number\"==typeof v&&y&&S<5&&(S++,o.warn('addFrames: overwriting frame \"'+(u[m]||d[m]).name+'\" with a frame whose name of type \"number\" also equates to \"'+m+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===S&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:h.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:f+n})}p.sort((function(t,e){return t.index>e.index?-1:t.index<e.index?1:0}));var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=h.modifyFrames,T=h.modifyFrames,k=[t,b],M=[t,x];return c&&c.add(t,w,k,T,M),h.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=h.modifyFrames,u=h.modifyFrames,f=[t,s],p=[t,a];return c&&c.add(t,l,f,u,p),h.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,f=t,h=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map((function(t){return o.extendFlat({},t)})),T.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,h,f,p),s;Array.isArray(i)||(i=[i]);try{O(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,h,f,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,f=[e,s,n],h=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),z(e,n,\"indices\"),(n=P(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,f,u,h),p},r.extendTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=R(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.prependTraces,f,t,arguments),u},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,f=t,h=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(O(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=P(n,e.data.length-1),i=P(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort((function(t,e){return t.newIndex-e.newIndex})),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,h,f,p),d},r.prependTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=R(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.extendTraces,f,t,arguments),u},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),h.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),h.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),I(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var f=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(T.cleanData(e),f?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!f||(t.layout=T.cleanLayout(i)),h.supplyDefaults(t);var m=t._fullLayout,y=m._has(\"cartesian\");if(!m._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e);r&&(t.layout=r);p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},f=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,f.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(100).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)})));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",(function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)})).on(\"cancel\",(function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)}))};f.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),h.addLinks(t),Promise.resolve()}(t,e,i);m._replotting=!0,(f||m._shouldCreateBgLayer)&&(lt(t),m._shouldCreateBgLayer&&delete m._shouldCreateBgLayer),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),f&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&h.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||h.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},m._size),M=0;function A(){if(h.clearAutoMarginIds(t),k.drawMarginPushers(t),d.allowAutoMargin(t),m._has(\"pie\"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];\"pie\"===n.type&&n.automargin&&h.allowAutoMargin(t,\"pie.\"+n.uid+\".automargin\")}return h.doAutoMargin(t),h.previousPromises(t)}function S(){t._transitioning||(k.doAutoRangeAndConstraints(t),f&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var C=[h.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=m._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!m._glcanvas&&m._has(\"gl\")&&(m._glcanvas=m._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],(function(t){return t.key})),m._glcanvas.enter().append(\"canvas\").attr(\"class\",(function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")})).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),m._glcanvas){m._glcanvas.attr(\"width\",m.width).attr(\"height\",m.height);var i=m._glcanvas.data()[0].regl;if(i&&(Math.floor(m.width)!==i._gl.drawingBufferWidth||Math.floor(m.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!M)return o.log(a+\" Clearing graph and plotting again.\"),h.cleanPlot([],{},t._fullData,m),h.supplyDefaults(t),m=t._fullLayout,h.doCalcdata(t),M++,e();o.error(a)}}return\"h\"===m.modebar.orientation?m._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):m._modebardiv.style(\"width\",null).style(\"height\",m.height+\"px\"),h.previousPromises(t)},A,function(){if(h.didMarginChange(w,m._size))return o.syncOrAsync([A,k.layoutStyles],t)}];y&&C.push((function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()})),C.push(k.layoutStyles),y&&C.push((function(){return d.draw(t,f?\"\":\"redraw\")}),(function(t){t._fullLayout._insideTickLabelsAutorange&&q(t,t._fullLayout._insideTickLabelsAutorange).then((function(){t._fullLayout._insideTickLabelsAutorange=void 0}))})),C.push(k.drawData,k.finalDraw,v,h.addLinks,h.rehover,h.redrag,h.doAutoMargin,(function(t){t._fullLayout._insideTickLabelsAutorange&&f&&d.saveRangeInitial(t,!0)}),h.previousPromises);var L=o.syncOrAsync(C,t);return L&&L.then||(L=Promise.resolve()),L.then((function(){return E(t),t}))},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return h.cleanPlot([],{},r,e),h.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l;t=o.getGraphDiv(t),T.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var m=o.extendDeep({},t._context);t._context=void 0,I(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(m,t._context)}t.data=e||[],T.cleanData(t.data),t.layout=n||{},T.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,f,h,p,d=n._preGUI,g=[],m={};for(i in d){if(u=et(i,$)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&rt(a,e))&&c===l&&(null===(f=d[i])&&(f=void 0),at(p=(h=s(e,i)).get(),f))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),h.set(B(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(m[i.substr(0,i.length-9)]=1)}for(var v=0;v<g.length;v++){var y=g[v];if(m[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,T=b[_],k=null;for(i in T){if(!k){var M=nt(_,r);if(M<0){delete b[_];break}var A=it(_,t,(w=r[M]._fullInput).index);if(A<0){delete b[_];break}k=t[A]}if(u=et(i,tt)){if(u.attr?c=(l=s(n,u.attr).get())&&rt(u.attr,e):(l=w.uirevision,void 0===(c=k.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(f=T[i])&&(f=void 0),at(p=(h=s(k,i)).get(),f))){h.set(B(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete T[i]}}}(t.data,t.layout,c,p),h.supplyDefaults(t,{skipUpdateCalc:!0});var v=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=M.layoutFlags();function o(t){return f.getLayoutValObject(r,t)}a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,ot(e,r,[],{getValObject:o,flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0);i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\");return a}(t,p,y,x,b),w=_.newDataRevision,A=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=M.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=f.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,h.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,ot(e[s]._fullInput,l,[],u)}(c.calc||c.plot)&&(c.fullReplot=!0);i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\");return c}(t,c,v,x,b,w);if(J(t)&&(_.layoutReplot=!0),A.calc||_.calc){t.calcdata=void 0;for(var S=Object.getOwnPropertyNames(y),C=0;C<S.length;C++){var L=S[C],P=L.substring(0,5);if(\"xaxis\"===P||\"yaxis\"===P){var z=y[L]._emptyCategories;z&&z()}}}else h.supplyDefaultsUpdateCalc(t.calcdata,v);var O=[];if(a&&(t._transitionData={},h.createTransitionData(t),O.push((function(){return r.addFrames(t,a)}))),y.transition&&!g&&(A.anim||_.anim))_.ticks&&O.push(k.doTicksRelayout),h.doCalcdata(t),k.doAutoRangeAndConstraints(t),O.push((function(){return h.transitionFromReact(t,A,_,p)}));else if(A.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,O.push(r.plot);else{for(var D in _.arrays){var R=_.arrays[D];if(R.length){var F=u.getComponentMethod(D,\"drawOne\");if(F!==o.noop)for(var N=0;N<R.length;N++)F(t,R[N]);else{var j=u.getComponentMethod(D,\"draw\");if(j===o.noop)throw new Error(\"cannot draw components: \"+D);j(t)}}}O.push(h.previousPromises),A.style&&O.push(k.doTraceStyle),(A.colorbars||_.colorbars)&&O.push(k.doColorBars),_.legend&&O.push(k.doLegend),_.layoutstyle&&O.push(k.layoutStyles),_.axrange&&G(O),_.ticks&&O.push(k.doTicksRelayout),_.modebar&&O.push(k.doModeBar),_.camera&&O.push(k.doCamera),O.push(E)}O.push(h.rehover,h.redrag),(l=o.syncOrAsync(O,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then((function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t}))},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return T.cleanData(t.data),T.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then((function(){return t.emit(\"plotly_redraw\"),t}))},r.relayout=q,r.restyle=F,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=K,r._guiRelayout=Q(q),r._guiRestyle=Q(F),r._guiUpdate=Q(K),r._storeDirectGUIEdit=function(t,e,r){for(var n in r){j(n,s(t,n).get(),r[n],e)}}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,\"../lib/events\":767,\"../lib/queue\":794,\"../lib/svg_text_utils\":803,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constants\":834,\"../plots/cartesian/graph_interact\":837,\"../plots/cartesian/select\":847,\"../plots/plots\":891,\"../plots/polar/legacy\":899,\"../registry\":911,\"./edit_types\":810,\"./helpers\":811,\"./manage_arrays\":813,\"./plot_config\":815,\"./plot_schema\":816,\"./subroutines\":818,d3:169,\"fast-isnumeric\":241,\"has-hover\":440}],815:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"integer\",min:0,max:2,dflt:1},notifyOnLogging:{valType:\"integer\",min:0,max:2,dflt:0},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],816:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),f=t(\"../plots/polar/legacy/axis_attributes\"),h=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,m=i.isArrayOrTypedArray,v=i.nestedProperty,y=i.valObjectMeta,x=[\"_isSubplotObj\",\"_isLinkedToArray\",\"_arrayAttrRegexps\",\"_deprecated\"];function b(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(_(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!_(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!_(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!_(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function _(t){return t===Math.round(t)&&t>=0}function w(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry){if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)M(r,e,e.attr[i]);else M(r,e,\"subplot\"===e.attr?e.name:e.attr)}for(t in r=function(t){return p(t,{radialaxis:f.radialaxis,angularaxis:f.angularaxis}),p(t,f.layout),t}(r),n.componentsRegistry){var a=(e=n.componentsRegistry[t]).schema;if(a&&(a.subplots||a.layout)){var s=a.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&A(r,e.layoutAttributes,e.name)}return{layoutAttributes:k(r)}}function T(){var t={frames:d({},s)};return k(t),t.frames}function k(t){return function(t){r.crawl(t,(function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")}))}(t),function(t){r.crawl(t,(function(t,e,r){if(t){var n=t._isLinkedToArray;n&&(delete t._isLinkedToArray,r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\")}}))}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function M(t,e,r){var n=v(t,r),i=d({},e.layoutAttributes);i._isSubplotObj=!0,n.set(i)}function A(t,e,r){var n=v(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=\"_isSubplotObj\",r.IS_LINKED_TO_ARRAY=\"_isLinkedToArray\",r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=x,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach((function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,(function(t,e,r,n,i){v(s,i).set(void 0),void 0===t&&v(l,i).set(void 0)})),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:k(o)};if(e.layoutAttributes){var f={};d(f,e.layoutAttributes),c.layoutAttributes=k(f)}e.animatable||r.crawl(c,(function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim}));return c}(e)}));var e={};return Object.keys(n.transformsRegistry).forEach((function(t){e[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach((function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach((function(e){A(r,i.schema.transforms[t][e],e)}))})),{attributes:k(r)}}(t)})),{defs:{valObjects:y,metaKeys:x.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:h.traces,layout:h.layout},impliedEdits:{}},traces:t,layout:w(),transforms:e,frames:T(),animation:k(l),config:k(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach((function(n){var o=t[n];if(-1===x.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}}))},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]],c=a+o[r];if(r===o.length-1)m(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var f=c[u],h=f._module;h&&(n=\"transforms[\"+u+\"].\",e=f,r.crawl(h.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!_(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var f=t._module;if(f||(f=(n.modules[t.type||a.type.dflt]||{})._module),!f)return!1;if(!(i=(r=f.attributes)&&r[o])){var h=f.basePlotModule;h&&h.attributes&&(i=h.attributes[o])}i||(i=a[o])}return b(i,e,s)},r.getLayoutValObject=function(t,e){return b(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var h=t._modules;if(h)for(r=0;r<h.length;r++)if((s=h[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return f[e];return f.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":778,\"../plots/animation_attributes\":822,\"../plots/attributes\":824,\"../plots/frame_attributes\":857,\"../plots/layout_attributes\":882,\"../plots/polar/legacy/area_attributes\":897,\"../plots/polar/legacy/axis_attributes\":898,\"../registry\":911,\"./edit_types\":810,\"./plot_config\":815}],817:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a={name:{valType:\"string\",editType:\"none\"}};function o(t){return t&&\"string\"==typeof t}function s(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}a.templateitemname={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=a.name,e.templateitemname=a.templateitemname,e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[s(e)],a=n&&n[e];Array.isArray(a)&&a.length||(a=[]);var l={};return{newItem:function(t){var e={name:t.name,_input:t},n=e.templateitemname=t.templateitemname;if(!o(n))return e._template=i,e;for(var s=0;s<a.length;s++){var c=a[s];if(c.name===n)return l[n]=1,e._template=c,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<a.length;e++){var r=a[e],n=r.name;if(o(n)&&!l[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i.templateitemname=r.templateitemname,t.push(i),l[n]=1}}return t}}},r.arrayDefaultKey=s,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,a=r._index,o=a>=i&&(r._input||{})._templateitemname;o&&(a=i);var s,l=e+\"[\"+a+\"]\";function c(){s={},o&&(s[l]={},s[l].templateitemname=o)}function u(t,e){o?n.nestedProperty(s[l],t).set(e):s[l+\".\"+t]=e}function f(){var t=s;return c(),t}return c(),{modifyBase:function(t,e){s[t]=e},modifyItem:u,getUpdateObj:f,applyUpdate:function(e,r){e&&u(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":778,\"../plots/attributes\":824}],818:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),f=t(\"../components/modebar\"),h=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,m=d.clean,v=t(\"../plots/cartesian/autorange\").doAutoRange;function y(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function x(t){var e,i,s,u,d,g,m=t._fullLayout,v=m._size,x=v.p,_=h.list(t,\"\",!0);if(m._paperdiv.style({width:t._context.responsive&&m.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":m.width+\"px\",height:t._context.responsive&&m.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":m.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,m.width,m.height),t._context.setBackground(t,m.paper_bgcolor),r.drawMainTitle(t),f.manage(t),!m._has(\"cartesian\"))return a.previousPromises(t);function T(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-x-n:e._offset+e._length+x+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+x+n:e._offset-x-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<_.length;e++){var k=(u=_[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=T(u,k,u.side),u._mainMirrorPosition=u.mirror&&k?T(u,k,p.OPPOSITE_SIDE[u.side]):null}var M=[],A=[],S=[],E=1===l.opacity(m.paper_bgcolor)&&1===l.opacity(m.plot_bgcolor)&&m.paper_bgcolor===m.plot_bgcolor;for(i in m._plots)if((s=m._plots[i]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var C=s.xaxis.domain,L=s.yaxis.domain,I=s.plotgroup;if(y(C,L,S)){var P=I.node(),z=s.bg=o.ensureSingle(I,\"rect\",\"bg\");P.insertBefore(z.node(),P.childNodes[0]),A.push(i)}else I.select(\"rect.bg\").remove(),S.push([C,L]),E||(M.push(i),A.push(i))}var O,D,R,F,B,N,j,U,V,q,H,G,Y,W=m._bgLayer.selectAll(\".bg\").data(M);for(W.enter().append(\"rect\").classed(\"bg\",!0),W.exit().remove(),W.each((function(t){m._plots[t].bg=n.select(this)})),e=0;e<A.length;e++)s=m._plots[A[e]],d=s.xaxis,g=s.yaxis,s.bg&&void 0!==d._offset&&void 0!==g._offset&&s.bg.call(c.setRect,d._offset-x,g._offset-x,d._length+2*x,g._length+2*x).call(l.fill,m.plot_bgcolor).style(\"stroke-width\",0);if(!m._hasOnlyLargeSploms)for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var X,Z,J=s.clipId=\"clip\"+m._uid+i+\"plot\",K=o.ensureSingleById(m._clips,\"clipPath\",J,(function(t){t.classed(\"plotclip\",!0).append(\"rect\")}));s.clipRect=K.select(\"rect\").attr({width:d._length,height:g._length}),c.setTranslate(s.plot,d._offset,g._offset),s._hasClipOnAxisFalse?(X=null,Z=J):(X=J,Z=null),c.setClipUrl(s.plot,X,t),s.layerClipId=Z}function Q(t){return\"M\"+O+\",\"+t+\"H\"+D}function $(t){return\"M\"+d._offset+\",\"+t+\"h\"+d._length}function tt(t){return\"M\"+t+\",\"+U+\"V\"+j}function et(t){return\"M\"+t+\",\"+g._offset+\"v\"+g._length}function rt(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var nt=\"M0,0\";b(d,i)&&(B=w(d,\"left\",g,_),O=d._offset-(B?x+B:0),N=w(d,\"right\",g,_),D=d._offset+d._length+(N?x+N:0),R=T(d,g,\"bottom\"),F=T(d,g,\"top\"),!(Y=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),s.xlines.attr(\"d\",nt);var it=\"M0,0\";b(g,i)&&(H=w(g,\"bottom\",d,_),j=g._offset+g._length+(H?x:0),G=w(g,\"top\",d,_),U=g._offset-(G?x:0),V=T(g,d,\"left\"),q=T(g,d,\"right\"),!(Y=!g._anchorAxis||i!==g._mainSubplot)||\"allticks\"!==g.mirror&&\"all\"!==g.mirror||(g._linepositions[i]=[V,q]),it=rt(g,tt,et),Y&&g.showline&&(\"all\"===g.mirror||\"allticks\"===g.mirror)&&(it+=tt(V)+tt(q)),s.ylines.style(\"stroke-width\",g._lw+\"px\").call(l.stroke,g.showline?g.linecolor:\"rgba(0,0,0,0)\")),s.ylines.attr(\"d\",it)}return h.makeClipPaths(t),a.previousPromises(t)}function b(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function _(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function w(t,e,r,n){if(_(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&_(t,e,a))return a._lw}return 0}function T(t,e){var r=t.title,n=t._size,i=0;switch(\"start\"===e?i=r.pad.l:\"end\"===e&&(i=-r.pad.r),r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}function k(t,e){var r=t.title,n=t._size,i=0;if(\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b,\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,x],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=\"middle\";o.isRightAnchor(e)?r=\"end\":o.isLeftAnchor(e)&&(r=\"start\");return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:T(e,r),y:k(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},f=u._module||{},h=f.arraysToCalcdata;h&&h(l,u);var p=f.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return h.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;f.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]];i._scene.setViewport(i)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r=h.list(t,\"\",!0),n={},i=0;i<r.length;i++)if(!n[(e=r[i])._id]){n[e._id]=1,m(t,e),v(t,e);var a=e._matchGroup;if(a)for(var o in a){var s=h.getFromId(t,o);v(t,s,e.range),n[o]=1}}g(t)},r.finalDraw=function(t){i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":643,\"../components/drawing\":665,\"../components/modebar\":703,\"../components/titles\":738,\"../constants/alignment\":745,\"../lib\":778,\"../lib/clear_gl_canvases\":762,\"../plots/cartesian/autorange\":827,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constraints\":835,\"../plots/plots\":891,\"../registry\":911,d3:169}],819:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var f=o.defaultItems();for(a=0;a<f.length;a++)r.push(f[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],h=t[c];if(c in e?s(h,e[c],c):e[c]=h,f(c)===c)for(var p in e){var d=f(p);p===d||d!==c||p in t||s(h,e[p],c)}}}function f(t){return t.replace(/[0-9]+$/,\"\")}function h(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],p=g(t,c,a),d=g(t,c,o),m=r(d);if(!m){var v=f(c);v!==c&&(m=r(d=g(t,v,o)))}if((!s||s!==m)&&!(!m||m._noTemplating||\"data_array\"===m.valType||m.arrayOk&&Array.isArray(u)))if(!m.valType&&i(u))h(u,e,r,p,d);else if(m._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var T=w.name;if(T)b[T]||(h(w,e,r,g(u,x,p),g(u,x,d)),x++,b[T]=1);else if(!y){var k=g(t,l.arrayDefaultKey(c),a),M=g(u,x,p);h(w,e,r,M,g(u,x,d));var A=n.nestedProperty(e,M);n.nestedProperty(e,k).set(A.get()),A.set(null),y=!0}}}else{n.nestedProperty(e,p).set(u)}}}function p(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}function d(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}function g(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function m(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function v(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var a={data:{},layout:{}};e.forEach((function(t){var e={};h(t,e,d.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=a.data[r];i||(i=a.data[r]=[]),i.push(e)})),h(r,a.layout,p.bind(null,r)),delete a.layout.template;var l=r.template;if(i(l)){var f,g,m,v,y,x,b=l.layout;i(b)&&u(b,a.layout);var _=l.data;if(i(_)){for(g in a.data)if(m=_[g],Array.isArray(m)){for(x=(y=a.data[g]).length,v=m.length,f=0;f<x;f++)u(m[f%v],y[f]);for(f=x;f<v;f++)y.push(n.extendDeep({},m[f]))}for(g in _)g in a.data||(a.data[g]=n.extendDeep([],_[g]))}}return a},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var h=r._fullLayout,p=r._fullData,d={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=f(n),s=[];for(a=0;a<r.length;a++)s.push(g(e,n,r[a])),o!==n&&s.push(g(e,o,r[a]));for(a=0;a<s.length;a++)d[s[a]]=1;t(e[n],s)}}(h,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=g(e,n,r);d[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<p.length;b++){var _=p[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,T=x[y]||0;w>T?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:T}):T>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:T})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=g(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&m(a)&&t(a,o)}}({data:p,layout:h},\"\"),u.length)return u.map(v)}},{\"../lib\":778,\"../plots/attributes\":824,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816,\"./plot_template\":817}],820:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../snapshot/helpers\"),l=t(\"../snapshot/tosvg\"),c=t(\"../snapshot/svgtoimg\"),u=t(\"../version\").version,f={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\",\"full-json\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,h,p,d;function g(t){return!(t in e)||o.validate(e[t],f[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],h=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),h=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!g(\"width\")&&null!==e.width||!g(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!g(\"format\"))throw new Error(\"Export format is not \"+o.join2(f.format.values,\", \",\" or \")+\".\");var m={};function v(t,r){return o.coerce(e,m,f,t,r)}var y=v(\"format\"),x=v(\"width\"),b=v(\"height\"),_=v(\"scale\"),w=v(\"setBackground\"),T=v(\"imageDataOnly\"),k=document.createElement(\"div\");k.style.position=\"absolute\",k.style.left=\"-5000px\",document.body.appendChild(k);var M=o.extendFlat({},h);x?M.width=x:null===e.width&&n(d.width)&&(M.width=d.width),b?M.height=b:null===e.height&&n(d.height)&&(M.height=d.height);var A=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(k);function E(){return new Promise((function(t){setTimeout(t,s.getDelay(k._fullLayout))}))}function C(){return new Promise((function(t,e){var r=l(k,y,_),n=k._fullLayout.width,f=k._fullLayout.height;function h(){i.purge(k),document.body.removeChild(k)}if(\"full-json\"===y){var p=a.graphJson(k,!1,\"keepdata\",\"object\",!0,!0);return p.version=u,p=JSON.stringify(p),h(),t(T?p:s.encodeJSON(p))}if(h(),\"svg\"===y)return t(T?r:s.encodeSVG(r));var d=document.createElement(\"canvas\");d.id=o.randstr(),c({format:y,width:n,height:f,scale:_,canvas:d,svg:r,promise:!0}).then(t).catch(e)}))}return new Promise((function(t,e){i.plot(k,r,M,A).then(S).then(E).then(C).then((function(e){t(function(t){return T?t.replace(s.IMAGE_URL_PREFIX,\"\"):t}(e))})).catch((function(t){e(t)}))}))}},{\"../lib\":778,\"../plots/plots\":891,\"../snapshot/helpers\":915,\"../snapshot/svgtoimg\":917,\"../snapshot/tosvg\":919,\"../version\":1370,\"./plot_api\":814,\"fast-isnumeric\":241}],821:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var f=Object.keys(t),h=0;h<f.length;h++){var p=f[h];if(\"transforms\"!==p){var v=o.slice();v.push(p);var y=t[p],x=e[p],b=m(r,p),_=(b||{}).valType,w=\"info_array\"===_,T=\"colorscale\"===_,k=(b||{}).items;if(g(r,p))if(s(y)&&s(x)&&\"any\"!==_)u(y,x,b,i,a,v);else if(w&&l(y)){y.length>x.length&&i.push(d(\"unused\",a,v.concat(x.length)));var M,A,S,E,C,L=x.length,I=Array.isArray(k);if(I&&(L=Math.min(L,k.length)),2===b.dimensions)for(A=0;A<L;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(d(\"unused\",a,v.concat(A,x[A].length)));var P=x[A].length;for(M=0;M<(I?Math.min(P,k[A].length):P);M++)S=I?k[A][M]:k,E=y[A][M],C=x[A][M],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A,M),E,C)):i.push(d(\"value\",a,v.concat(A,M),E))}else i.push(d(\"array\",a,v.concat(A),y[A]));else for(A=0;A<L;A++)S=I?k[A]:k,E=y[A],C=x[A],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A),E,C)):i.push(d(\"value\",a,v.concat(A),E))}else if(b.items&&!w&&l(y)){var z,O,D=k[Object.keys(k)[0]],R=[];for(z=0;z<x.length;z++){var F=x[z]._index||z;if((O=v.slice()).push(F),s(y[F])&&s(x[z])){R.push(F);var B=y[F],N=x[z];s(B)&&!1!==B.visible&&!1===N.visible?i.push(d(\"invisible\",a,O)):u(B,N,D,i,a,O)}}for(z=0;z<y.length;z++)(O=v.slice()).push(z),s(y[z])?-1===R.indexOf(z)&&i.push(d(\"unused\",a,O)):i.push(d(\"object\",a,O,y[z]))}else!s(y)&&s(x)?i.push(d(\"object\",a,v,y)):c(y)||!c(x)||w||T?p in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(d(\"dynamic\",a,v,y,x)):i.push(d(\"value\",a,v,y)):i.push(d(\"unused\",a,v,y)):i.push(d(\"array\",a,v,y));else i.push(d(\"schema\",a,v))}}return i}function f(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}e.exports=function(t,e){void 0===t&&(t=[]),void 0===e&&(e={});var r,c,h=a.get(),p=[],g={_context:n.extendFlat({},o)};l(t)?(g.data=n.extendDeep([],t),r=t):(g.data=[],r=[],p.push(d(\"array\",\"data\"))),s(e)?(g.layout=n.extendDeep({},e),c=e):(g.layout={},c={},arguments.length>1&&p.push(d(\"object\",\"layout\"))),i.supplyDefaults(g);for(var m=g._fullData,v=r.length,y=0;y<v;y++){var x=r[y],b=[\"data\",y];if(s(x)){var _=m[y],w=_.type,T=h.traces[w].attributes;T.type={valType:\"enumerated\",values:[w]},!1===_.visible&&!1!==x.visible&&p.push(d(\"invisible\",b)),u(x,_,T,p,b);var k=x.transforms,M=_.transforms;if(k){l(k)||p.push(d(\"array\",b,[\"transforms\"])),b.push(\"transforms\");for(var A=0;A<k.length;A++){var S=[\"transforms\",A],E=k[A].type;if(s(k[A])){var C=h.transforms[E]?h.transforms[E].attributes:{};C.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],M[A],C,p,b,S)}else p.push(d(\"object\",b,S))}}}else p.push(d(\"object\",b))}var L=g._fullLayout,I=f(h,m);return u(c,L,I,p,\"layout\"),0===p.length?void 0:p};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":p(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":p(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return p(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return p(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[p(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?p(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[p(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function p(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function d(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function g(t,e){var r=y(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function m(t,e){return e in t?t[e]:t[y(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function y(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":778,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816}],822:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],823:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],f=e[s]=[],h=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=h.newItem(p):(o=h.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),f.push(o)}var d=h.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=f.length,r.handleItemDefaults({},o,e,r,{}),f.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,f.length);for(a=0;a<g;a++)n.relinkPrivateKeys(f[a],c[a])}return f}},{\"../lib\":778,\"../plot_api/plot_template\":817}],824:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":674}],825:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i.dateTime2ms,o=i.incrementMonth,s=t(\"../../constants/numerical\").ONEAVGMONTH;e.exports=function(t,e,r,i){if(\"date\"!==e.type)return i;var l=t[r+\"periodalignment\"];if(!l)return i;var c,u=t[r+\"period\"];if(n(u)){if((u=+u)<=0)return i}else if(\"string\"==typeof u&&\"M\"===u.charAt(0)){var f=+u.substring(1);if(!(f>0&&Math.round(f)===f))return i;c=f}for(var h=e.calendar,p=\"start\"===l,d=\"end\"===l,g=t[r+\"period0\"],m=a(g,h)||0,v=[],y=i.length,x=0;x<y;x++){var b,_,w,T=i[x];if(c){for(b=Math.round((T-m)/(c*s)),w=o(m,c*b,h);w>T;)w=o(w,-c,h);for(;w<=T;)w=o(w,c,h);_=o(w,-c,h)}else{for(w=m+(b=Math.round((T-m)/u))*u;w>T;)w-=u;for(;w<=T;)w+=u;_=w-u}v[x]=p?_:d?w:(_+w)/2}return v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],826:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],827:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\"),s=t(\"./axis_ids\"),l=s.getFromId,c=s.isLinked;function u(t,e){var r,n,a=[],o=t._fullLayout,s=h(o,e,0),l=h(o,e,1),c=p(t,e),u=c.min,d=c.max;if(0===u.length||0===d.length)return i.simpleMap(e.range,e.r2l);var g=u[0].val,m=d[0].val;for(r=1;r<u.length&&g===m;r++)g=Math.min(g,u[r].val);for(r=1;r<d.length&&g===m;r++)m=Math.max(m,d[r].val);var v=!1;if(e.range){var y=i.simpleMap(e.range,e.r2l);v=y[1]<y[0]}\"reversed\"===e.autorange&&(v=!0,e.autorange=!0);var x,b,_,w,T,k,M=e.rangemode,A=\"tozero\"===M,S=\"nonnegative\"===M,E=e._length,C=E/10,L=0;for(r=0;r<u.length;r++)for(x=u[r],n=0;n<d.length;n++)(k=(b=d[n]).val-x.val-f(e,x.val,b.val))>0&&((T=E-s(x)-l(b))>C?k/T>L&&(_=x,w=b,L=k/T):k/E>L&&(_={val:x.val,nopad:1},w={val:b.val,nopad:1},L=k/E));if(g===m){var I=g-1,P=g+1;if(A)if(0===g)a=[0,1];else{var z=(g>0?d:u).reduce((function(t,e){return Math.max(t,l(e))}),0),O=g/(1-Math.min(.5,z/E));a=g>0?[0,O]:[O,0]}else a=S?[Math.max(0,I),Math.max(1,P)]:[I,P]}else A?(_.val>=0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:0,nopad:1})):S&&(_.val-L*s(_)<0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:1,nopad:1})),L=(w.val-_.val-f(e,x.val,b.val))/(E-s(_)-l(w)),a=[_.val-L*s(_),w.val+L*l(w)];return v&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function f(t,e,r){var n=0;if(t.rangebreaks)for(var i=t.locateBreaks(e,r),a=0;a<i.length;a++){var o=i[a];n+=o.max-o.min}return n}function h(t,e,r){var n=.05*e._length,a=e._anchorAxis||{};if(-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")||-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")){var o=\"reversed\"===e.autorange;if(!o){var s=i.simpleMap(e.range,e.r2l);o=s[1]<s[0]}o&&(r=!r)}var l=0;return c(t,e._id)||(l=function(t,e){var r=0,n=t._anchorAxis||{};if(-1!==(n.ticklabelposition||\"\").indexOf(\"inside\")&&(!e&&(\"left\"===n.side||\"bottom\"===n.side)||e&&(\"top\"===n.side||\"right\"===n.side))){var a=\"x\"===t._id.charAt(0);if(n._vals){var o=i.deg2rad(n._tickAngles[n._id+\"tick\"]||0),s=Math.abs(Math.cos(o)),l=Math.abs(Math.sin(o));n._vals.forEach((function(t){if(t.bb){var e=6+t.bb.width,n=6+t.bb.height;r=Math.max(r,a?Math.max(e*s,n*l):Math.max(n*s,e*l))}}))}\"inside\"===n.ticks&&\"inside\"===n.ticklabelposition&&(r+=n.ticklen||0)}return r}(e,r)),n=Math.max(l,n),\"domain\"===e.constrain&&e._inputDomain&&(n*=(e._inputDomain[1]-e._inputDomain[0])/(e.domain[1]-e.domain[0])),function(t){return t.nopad?0:t.pad+(t.extrapad?n:l)}}e.exports={getAutoRange:u,makePadFn:h,doAutoRange:function(t,e,r){if(e.setScale(),e.autorange){e.range=r?r.slice():u(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var n=e._input,a={};a[e._attr+\".range\"]=e.range,a[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,a),n.range=e.range.slice(),n.autorange=e.autorange}var s=e._anchorAxis;if(s&&s.rangeslider){var l=s.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=u(t,e)),s._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,u,f,h,p,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,T=!1,k=r.vpadLinearized||!1;function M(t){if(Array.isArray(t))return T=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=M(r.vpadplus||r.vpad),C=M(r.vpadminus||r.vpad);if(!T){if(h=1/0,p=-1/0,w)for(i=0;i<x;i++)(o=e[i])<h&&o>0&&(h=o),o>p&&o<a&&(p=o);else for(i=0;i<x;i++)(o=e[i])<h&&o>-a&&(h=o),o>p&&o<a&&(p=o);e=[h,p],x=2}var L={tozero:_,extrapad:b};function I(r){s=e[r],n(s)&&(u=A(r),f=S(r),k?(l=t.c2l(s)-C(r),c=t.c2l(s)+E(r)):(h=s-C(r),p=s+E(r),w&&h<p/10&&(h=p/10),l=t.c2l(h),c=t.c2l(p)),_&&(l=Math.min(0,l),c=Math.max(0,c)),v(l)&&d(m,l,f,L),v(c)&&g(y,c,u,L))}var P=Math.min(6,x);for(i=0;i<P;i++)I(i);for(i=x-1;i>=P;i--)I(i);return{min:m,max:y,opts:r}},concatExtremes:p};function p(t,e,r){var n,i,a,o=e._id,s=t._fullData,c=t._fullLayout,u=[],f=[];function h(t,e){for(n=0;n<e.length;n++){var r=t[e[n]],s=(r._extremes||{})[o];if(!0===r.visible&&s){for(i=0;i<s.min.length;i++)a=s.min[i],d(u,a.val,a.pad,{extrapad:a.extrapad});for(i=0;i<s.max.length;i++)a=s.max[i],g(f,a.val,a.pad,{extrapad:a.extrapad})}}}if(h(s,e._traceIndices),h(c.annotations||[],e._annIndices||[]),h(c.shapes||[],e._shapeIndices||[]),e._matchGroup&&!r)for(var m in e._matchGroup)if(m!==e._id){var v=l(t,m),y=p(t,v,!0),x=e._length/v._length;for(i=0;i<y.min.length;i++)a=y.min[i],d(u,a.val,a.pad*x,{extrapad:a.extrapad});for(i=0;i<y.max.length;i++)a=y.max[i],g(f,a.val,a.pad*x,{extrapad:a.extrapad})}return{min:u,max:f}}function d(t,e,r,n){m(t,e,r,n,y)}function g(t,e,r,n){m(t,e,r,n,x)}function m(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function v(t){return n(t)&&Math.abs(t)<a}function y(t,e){return t<=e}function x(t,e){return t>=e}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831,\"fast-isnumeric\":241}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/titles\"),f=t(\"../../components/color\"),h=t(\"../../components/drawing\"),p=t(\"./layout_attributes\"),d=t(\"./clean_ticks\"),g=t(\"../../constants/numerical\"),m=g.ONEMAXYEAR,v=g.ONEAVGYEAR,y=g.ONEMINYEAR,x=g.ONEMAXQUARTER,b=g.ONEAVGQUARTER,_=g.ONEMINQUARTER,w=g.ONEMAXMONTH,T=g.ONEAVGMONTH,k=g.ONEMINMONTH,M=g.ONEWEEK,A=g.ONEDAY,S=A/2,E=g.ONEHOUR,C=g.ONEMIN,L=g.ONESEC,I=g.MINUS_SIGN,P=g.BADNUM,z=t(\"../../constants/alignment\"),O=z.MID_SHIFT,D=z.CAP_SHIFT,R=z.LINE_SPACING,F=z.OPPOSITE_SIDE,B=e.exports={};B.setConvert=t(\"./set_convert\");var N=t(\"./axis_autotype\"),j=t(\"./axis_ids\"),U=j.idSort,V=j.isLinked;B.id2name=j.id2name,B.name2id=j.name2id,B.cleanId=j.cleanId,B.list=j.list,B.listIds=j.listIds,B.getFromId=j.getFromId,B.getFromTrace=j.getFromTrace;var q=t(\"./autorange\");B.getAutoRange=q.getAutoRange,B.findExtremes=q.findExtremes;function H(t){var e=1e-4*(t[1]-t[0]);return[t[0]-e,t[1]+e]}B.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||(\"string\"==typeof a?a:a[0])),a||(a=i),l=l.concat(l.map((function(t){return t+\" domain\"}))),u[c]={valType:\"enumerated\",values:l.concat(a?\"string\"==typeof a?[a]:a:[]),dflt:i},s.coerce(t,e,u,c)},B.getRefType=function(t){return void 0===t?t:\"paper\"===t?\"paper\":\"pixel\"===t?\"pixel\":/( domain)$/.test(t)?\"domain\":\"range\"},B.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"range\"!==B.getRefType(n))o=s.ensureNumber,l=r(i,a);else{var c=B.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},B.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:B.getFromId(e,r).cleanPos)(t)},B.redrawComponents=function(t,e){e=e||B.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var f=r[B.id2name(e[u])][a],h=0;h<f.length;h++){var p=f[h];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var G=B.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:N(n,void 0,{autotypenumbers:t._fullLayout.autotypenumbers}),_categories:[]},B.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=B.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:W,c2d:W}:{d2c:Y,c2d:Y}};function Y(t){return+t}function W(t){return String(t)}function X(t){return+t.substring(1)}B.getDataToCoordFunc=function(t,e,r,n){return G(t,e,r,n).d2c},B.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},B.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},B.saveRangeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},B.saveShowSpikeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},B.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},B.setConvert(l),o=o&&d.dtick(o,l.type))l.dtick=o,l.tick0=d.tick0(void 0,l.type,a);else{var f;if(r)f=(u-c)/r;else{var h=s.distinctVals(t),p=Math.pow(10,Math.floor(Math.log(h.minDiff)/Math.LN10)),g=p*s.roundUp(h.minDiff/p,[.9,1.9,4.9,9.9],!0);f=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(f)||(f=1)}B.autoTicks(l,f)}var m,v=l.dtick,y=B.tickIncrement(B.tickFirst(l),v,\"reverse\",a);if(\"number\"==typeof v)m=(y=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var f=0;f<e.length;f++)e[f]%1==0?l++:i(e[f])||c++,u(e[f])&&o++,u(e[f]+r.dtick/2)&&s++;var h=e.length-c;if(l===h&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*h&&(o>.3*h||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(y,t,l,c,u))+(1+Math.floor((u-y)/v))*v;else for(\"M\"===l.dtick.charAt(0)&&(y=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=B.tickIncrement(t,\"M6\",\"reverse\")+1.5*A:a.exactMonths>.8?t=B.tickIncrement(t,\"M1\",\"reverse\")+15.5*A:t-=S;var l=B.tickIncrement(t,r);if(l<=n)return l}return t}(y,t,v,c,a)),m=y,0;m<=u;)m=B.tickIncrement(m,v,!1,a);return{start:e.c2r(y,0,a),end:e.c2r(m,0,a),size:v,_dataSpan:u-c}},B.prepTicks=function(t,e){var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(t._dtickInit=t.dtick,t._tick0Init=t.tick0,\"auto\"===t.tickmode||!t.dtick){var n,a=t.nticks;a||(\"category\"===t.type||\"multicategory\"===t.type?(n=t.tickfont?1.2*(t.tickfont.size||12):15,a=t._length/n):(n=\"y\"===t._id.charAt(0)?40:80,a=s.constrain(t._length/n,4,9)+1),\"radialaxis\"===t._name&&(a*=2)),\"array\"===t.tickmode&&(a*=100),t._roughDTick=Math.abs(r[1]-r[0])/a,B.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}\"period\"===t.ticklabelmode&&function(t){var e;function r(){return!(i(t.dtick)||\"M\"!==t.dtick.charAt(0))}var n=r(),a=B.getTickFormat(t);if(a){var o=t._dtickInit!==t.dtick;/%[fLQsSMX]/.test(a)||(/%[HI]/.test(a)?(e=E,o&&!n&&t.dtick<E&&(t.dtick=E)):/%p/.test(a)?(e=S,o&&!n&&t.dtick<S&&(t.dtick=S)):/%[Aadejuwx]/.test(a)?(e=A,o&&!n&&t.dtick<A&&(t.dtick=A)):/%[UVW]/.test(a)?(e=M,o&&!n&&t.dtick<M&&(t.dtick=M)):/%[Bbm]/.test(a)?(e=T,o&&(n?X(t.dtick)<1:t.dtick<k)&&(t.dtick=\"M1\")):/%[q]/.test(a)?(e=b,o&&(n?X(t.dtick)<3:t.dtick<_)&&(t.dtick=\"M3\")):/%[Yy]/.test(a)&&(e=v,o&&(n?X(t.dtick)<12:t.dtick<y)&&(t.dtick=\"M12\")))}(n=r())&&t.tick0===t._dowTick0&&(t.tick0=t._rawTick0);t._definedDelta=e}(t),t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),nt(t)},B.calcTicks=function(t,e){B.prepTicks(t,e);var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=H(s.simpleMap(t.range,t.r2l)),a=Math.min(i[0],i[1]),o=Math.max(i[0],i[1]),l=0;Array.isArray(r)||(r=[]);var c=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var u=0;u<e.length;u++){var f=c(e[u]);f>a&&f<o&&(void 0===r[u]?n[l]=B.tickText(t,f):n[l]=it(t,f,String(r[u])),l++)}l<e.length&&n.splice(l,e.length-l);t.rangebreaks&&(n=n.filter((function(e){return t.maskBreaks(e.x)!==P})));return n}(t);var n=H(r),a=n[0],o=n[1],l=r[1]<r[0],c=Math.min(r[0],r[1]),u=Math.max(r[0],r[1]),f=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),h=\"period\"===t.ticklabelmode;if(t._tmin=B.tickFirst(t,e),t._tmin<a!==l)return[];\"category\"!==t.type&&\"multicategory\"!==t.type||(o=l?Math.max(-.5,o):Math.min(t._categories.length-.5,o));var p=t._tmin;t.rangebreaks&&t._tick0Init!==t.tick0&&(p=wt(p,t),l||(p=B.tickIncrement(p,t.dtick,!l,t.calendar))),h&&(p=B.tickIncrement(p,t.dtick,!l,t.calendar));for(var d,g=Math.max(1e3,t._length||0),C=[],L=null;l?p>=o:p<=o;p=B.tickIncrement(p,t.dtick,l,t.calendar)){if(t.rangebreaks&&!l){if(p<a)continue;if(t.maskBreaks(p)===P&&wt(p,t)>=u)break}if(C.length>g||p===L)break;L=p;var I=!1;f&&p!==(0|p)&&(I=!0),C.push({minor:I,value:p})}if(h&&function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n].value,a=n,o=n+1;n<t.length-1?(a=n,o=n+1):n>0?(a=n-1,o=n):(a=n,o=n);var s,l=t[a].value,c=t[o].value,u=Math.abs(c-l),f=r||u,h=0;f>=y?h=u>=y&&u<=m?u:v:r===b&&f>=_?h=u>=_&&u<=x?u:b:f>=k?h=u>=k&&u<=w?u:T:r===M&&f>=M?h=M:f>=A?h=A:r===S&&f>=S?h=S:r===E&&f>=E&&(h=E),h>=u&&(h=u,s=!0);var p=i+h;if(e.rangebreaks&&h>0){for(var d=0,g=0;g<84;g++){var C=(g+.5)/84;e.maskBreaks(i*(1-C)+C*p)!==P&&d++}(h*=d/84)||(t[n].drop=!0),s&&u>M&&(h=u)}(h>0||0===n)&&(t[n].periodX=i+h/2)}}(C,t,t._definedDelta),t.rangebreaks){var z=\"y\"===t._id.charAt(0),O=1;\"auto\"===t.tickmode&&(O=t.tickfont?t.tickfont.size:12);var D=NaN;for(d=C.length-1;d>-1;d--)if(C[d].drop)C.splice(d,1);else{C[d].value=wt(C[d].value,t);var R=t.c2p(C[d].value);(z?D>R-O:D<R+O)?C.splice(l?d+1:d,1):D=R}}_t(t)&&360===Math.abs(r[1]-r[0])&&C.pop(),t._tmax=(C[C.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;var F,N,j=[];for(d=0;d<C.length;d++){var U=C[d].minor,V=C[d].value;F=B.tickText(t,V,!1,U),void 0!==(N=C[d].periodX)&&(F.periodX=N,(N>u||N<c)&&(N>u&&(F.periodX=u),N<c&&(F.periodX=c),F.text=\" \",t._prevDateHead=\"\")),j.push(F)}return t._inCalcTicks=!1,j};var Z=[2,5,10],J=[1,2,3,6,12],K=[1,2,5,10,15,30],Q=[1,2,3,7,14],$=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],tt=[-.301,0,.301,.699,1],et=[15,30,45,90,180];function rt(t,e,r){return e*s.roundUp(t/e,r)}function nt(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=A&&a<=10||e>=15*A)t._tickround=\"d\";else if(e>=C&&a<=16||e>=E)t._tickround=\"M\";else if(e>=L&&a<=19||e>=C)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01),u=void 0===t.minexponent?3:t.minexponent;Math.abs(c)>u&&(ot(t.exponentformat)&&!st(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function it(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}B.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar,0);var a=2*e;if(a>v)e/=v,r=n(10),t.dtick=\"M\"+12*rt(e,r,Z);else if(a>T)e/=T,t.dtick=\"M\"+rt(e,1,J);else if(a>A){t.dtick=rt(e,A,t._hasDayOfWeekBreaks?[1,2,7,14]:Q);var o=B.getTickFormat(t),l=\"period\"===t.ticklabelmode;l&&(t._rawTick0=t.tick0),/%[uVW]/.test(o)?t.tick0=s.dateTick0(t.calendar,2):t.tick0=s.dateTick0(t.calendar,1),l&&(t._dowTick0=t.tick0)}else a>E?t.dtick=rt(e,E,J):a>C?t.dtick=rt(e,C,K):a>L?t.dtick=rt(e,L,K):(r=n(10),t.dtick=rt(e,r,Z))}else if(\"log\"===t.type){t.tick0=0;var c=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(c[1]-c[0])<1){var u=1.5*Math.abs((c[1]-c[0])/e);e=Math.abs(Math.pow(10,c[1])-Math.pow(10,c[0]))/u,r=n(10),t.dtick=\"L\"+rt(e,r,Z)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):_t(t)?(t.tick0=0,r=1,t.dtick=rt(e,r,et)):(t.tick0=0,r=n(10),t.dtick=rt(e,r,Z));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var f=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(f)}},B.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return s.increment(t,o*e);var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?tt:$,f=t+.01*o,h=s.roundUp(s.mod(f,1),u,r);return Math.floor(f)+Math.log(n.round(Math.pow(10,h),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},B.tickFirst=function(t,e){var r=t.r2l||Number,a=s.simpleMap(t.range,r,void 0,void 0,e),o=a[1]<a[0],l=o?Math.floor:Math.ceil,c=H(a)[0],u=t.dtick,f=r(t.tick0);if(i(u)){var h=l((c-f)/u)*u+f;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var p=u.charAt(0),d=Number(u.substr(1));if(\"M\"===p){for(var g,m,v,y=0,x=f;y<10;){if(((g=B.tickIncrement(x,u,o,t.calendar))-c)*(x-c)<=0)return o?Math.min(x,g):Math.max(x,g);m=(c-(x+g)/2)/(g-x),v=p+(Math.abs(Math.round(m))||1)*d,x=B.tickIncrement(x,v,m<0?!o:o,t.calendar),y++}return s.error(\"tickFirst did not converge\",t),x}if(\"L\"===p)return Math.log(l((Math.pow(10,c)-f)/d)*d+f)/Math.LN10;if(\"D\"===p){var b=\"D2\"===u?tt:$,_=s.roundUp(s.mod(c,1),b,o);return Math.floor(c)+Math.log(n.round(Math.pow(10,_),1))/Math.LN10}throw\"unrecognized dtick \"+String(u)},B.tickText=function(t,e,r,n){var a,o=it(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,f=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var h=s.simpleMap(t.range,t.r2l),p=(Math.abs(h[1]-h[0])-(t._lBreaks||0))/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-f(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||B.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));if(l)if(r)\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\");else if(t._inCalcTicks&&t._prevDateHead===l){var f=-1!==(t.ticklabelposition||\"\").indexOf(\"inside\"),h=t._realSide||t.side;(!f&&\"top\"===h||f&&\"bottom\"===h)&&(c+=\"<br> \")}else t._prevDateHead=l,c+=\"<br>\"+l;e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=lt(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var f=Math.round(l),h=Math.abs(f),p=t.exponentformat;\"power\"===p||ot(p)&&st(f)?(e.text=0===f?1:1===f?\"10\":\"10<sup>\"+(f>1?\"\":I)+h+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&h>2?e.text=\"1\"+p+(f>0?\"+\":I)+h:(e.text=lt(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):_t(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=lt(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){for(var r=1;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=lt(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=I+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=lt(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var m=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[m(o.x-.5),m(o.x+t.dtick-.5)]}return o},B.hoverLabelText=function(t,e,r){if(r!==P&&r!==e)return B.hoverLabelText(t,e)+\" - \"+B.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=B.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":I+i:i};var at=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function ot(t){return\"SI\"===t||\"B\"===t}function st(t){return t>14||t<-15}function lt(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=B.getTickFormat(e),f=e.separatethousands;if(n){var h={exponentformat:l,minexponent:e.minexponent,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};nt(h),o=(Number(h._tickround)||0)+4,c=h._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,I);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var m=(t=String(t)).indexOf(\".\")+1;m&&(t=t.substr(0,m+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,f)}c&&\"hide\"!==l&&(ot(l)&&st(c)&&(l=\"power\"),p=c<0?I+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":ot(l)&&(t+=at[c/3+5]));return a?I+t:t}function ct(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(it(t,s.interp(n[o],.5),o));return r}function ut(t){return void 0!==t.periodX?t.periodX:t.x}function ft(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function ht(t){var e=t.title.font.size,r=(t.title.text.match(c.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty(\"standoff\")?r?e*(D+r*R):e*D:r?e*(r+1)*R:e}function pt(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function dt(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function gt(t){return t._id+\".automargin\"}function mt(t){return gt(t)+\".mirror\"}function vt(t){return t._id+\".rangeslider\"}function yt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function xt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(B.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(B.getFromId(t,r[n]));var c=Object.keys(p),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],f=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var h=c[n],d=a[0][h],g=o[0][h],m=!0,v=!1,y=!1;if(\"_\"!==h.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(h)){for(i=1;i<a.length&&m;i++){var x=a[i][h];\"type\"===h&&-1!==f.indexOf(d)&&-1!==f.indexOf(x)&&d!==x?v=!0:x!==d&&(m=!1)}for(i=1;i<o.length&&m;i++){var b=o[i][h];\"type\"===h&&-1!==f.indexOf(g)&&-1!==f.indexOf(b)&&g!==b?y=!0:o[i][h]!==g&&(m=!1)}m&&(v&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),bt(l,h,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function bt(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function _t(t){return\"angularaxis\"===t._id}function wt(t,e){for(var r=e._rangebreaks.length,n=0;n<r;n++){var i=e._rangebreaks[n];if(t>=i.min&&t<i.max)return i.max}return t}B.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*T}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function f(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&f(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},B.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?B.findSubplotsWithAxis(n,e):n;return i.sort((function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]})),i},B.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},B.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=B.list(t,\"x\",!0),l=B.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,(function(t){return t.x._id+t.y._id}));u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",(function(t){return\"clip\"+e._uid+t.x._id+t.y._id})).append(\"rect\"),u.exit().remove(),u.each((function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})}))}},B.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each((function(t){var e=t[0],r=n._plots[e];if(r){var i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()}}));var i=e&&\"redraw\"!==e?e:B.listIds(t);return s.syncOrAsync(i.map((function(e){return function(){if(e){var n=B.getFromId(t,e),i=B.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}})))},B.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var c=t._fullLayout,p=e._id,d=p.charAt(0),g=B.counterLetter(p),m=c._plots[e._mainSubplot];if(m){var v=m[d+\"axislayer\"],y=e._mainLinePosition,x=e._mainMirrorPosition,b=e._vals=B.calcTicks(e),_=[e.mirror,y,x].join(\"_\");for(n=0;n<b.length;n++)b[n].axInfo=_;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var w={};if(e.visible){var T,k,M=B.makeTransTickFn(e),A=B.makeTransTickLabelFn(e),S=\"inside\"===e.ticks,E=\"outside\"===e.ticks;if(\"boundaries\"===e.tickson){var C=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,b);k=B.clipEnds(e,C),T=S?k:C}else k=B.clipEnds(e,b),T=S&&\"period\"!==e.ticklabelmode?k:b;var L=e._gridVals=k,I=function(t,e){var r,n,i=[],a=e.length&&e[e.length-1].x<e[0].x,o=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var l=e[r];l.text2!==n&&o(l,a?1:0),n=l.text2}o(e[r-1],a?0:1)}return i}(e,b);if(!c._hasOnlyLargeSploms){var P=e._subplotsWith,z={};for(n=0;n<P.length;n++){i=P[n];var O=(l=c._plots[i])[g+\"axis\"],D=O._mainAxis._id;if(!z[D]){z[D]=1;var N=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;B.drawGrid(t,e,{vals:L,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:N,transFn:M}),B.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:N,transFn:M})}}}var j=B.getTickSigns(e),U=[];if(e.ticks){var V,q,H,G=B.makeTickPath(e,y,j[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(V=B.makeTickPath(e,x,j[3]),q=G+V):(V=\"\",q=G),e.showdividers&&E&&\"boundaries\"===e.tickson){var Y={};for(n=0;n<I.length;n++)Y[I[n].x]=1;H=function(t){return Y[t.x]?V:q}}else H=q;B.drawTicks(t,e,{vals:T,layer:v,path:H,transFn:M}),\"allticks\"===e.mirror&&(U=Object.keys(e._linepositions||{}))}for(n=0;n<U.length;n++){i=U[n],l=c._plots[i];var W=e._linepositions[i]||[],X=B.makeTickPath(e,W[0],j[0])+B.makeTickPath(e,W[1],j[1]);B.drawTicks(t,e,{vals:T,layer:l[d+\"axislayer\"],path:X,transFn:M})}var Z=[];if(Z.push((function(){return B.drawLabels(t,e,{vals:b,layer:v,transFn:A,labelFns:B.makeLabelFns(e,y)})})),\"multicategory\"===e.type){var J={x:2,y:10}[d];Z.push((function(){var r={x:\"height\",y:\"width\"}[d],n=Q()[r]+J+(e._tickAngles[p+\"tick\"]?e.tickfont.size*R:0);return B.drawLabels(t,e,{vals:ct(e,b),layer:v,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:M,labelFns:B.makeLabelFns(e,y+n*j[4])})})),Z.push((function(){return e._depth=j[4]*(Q(\"tick2\")[e.side]-y),function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,ft);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(f.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:I,layer:v,path:B.makeTickPath(e,y,j[4],e._depth),transFn:M})}))}else e.title.hasOwnProperty(\"standoff\")&&Z.push((function(){e._depth=j[4]*(Q()[e.side]-y)}));var K=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return Z.push((function(){var r,n,i,s,l=e.side.charAt(0),u=F[e.side].charAt(0),f=B.getPxPosition(t,e),h=E?e.ticklen:0;if((e.automargin||K)&&(\"multicategory\"===e.type?r=Q(\"tick2\"):(r=Q(),\"x\"===d&&\"b\"===l&&(e._depth=Math.max(r.width>0?r.bottom-f:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if(\"x\"===d){if(\"b\"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?f-r.top:0,h),p.reverse()),r.width>0){var m=r.right-(e._offset+e._length);m>0&&(n.xr=1,n.r=m);var v=e._offset-r.left;v>0&&(n.xl=0,n.l=v)}}else if(\"l\"===l?n[l]=e._depth=Math.max(r.height>0?f-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-f:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==c._dfltTitle[d]&&(n[l]+=ht(e)+(e.title.standoff||0)),e.mirror&&\"free\"!==e.anchor&&((i={x:0,y:0,r:0,l:0,t:0,b:0})[u]=e.linewidth,e.mirror&&!0!==e.mirror&&(i[u]+=h),!0===e.mirror||\"ticks\"===e.mirror?i[g]=e._anchorAxis.domain[p[1]]:\"all\"!==e.mirror&&\"allticks\"!==e.mirror||(i[g]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}K&&(s=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,gt(e),n),a.autoMargin(t,mt(e),i),a.autoMargin(t,vt(e),s)})),r.skipTitle||K&&\"bottom\"===e.side||Z.push((function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty(\"standoff\"))r=e._depth+e.title.standoff+ht(e);else{var s=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");if(\"multicategory\"===e.type)r=e._depth;else{var l=1.5*o;s&&(l=.5*o,\"outside\"===e.ticks&&(l+=e.ticklen)),r=10+l+(e.linewidth?e.linewidth-1:0)}s||(r+=\"x\"===a?\"top\"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):\"right\"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0))}var c,f,p,d,g=B.getPxPosition(t,e);\"x\"===a?(f=e._offset+e._length/2,p=\"top\"===e.side?g-r:g+r):(p=e._offset+e._length/2,f=\"right\"===e.side?g+r:g-r,c={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var m=e._selections[e._id+\"tick\"];if(d={selection:m,side:e.side},m&&m.node()&&m.node().parentNode){var v=h.getTranslate(m.node().parentNode);d.offsetLeft=v.x,d.offsetTop=v.y}e.title.hasOwnProperty(\"standoff\")&&(d.pad=0)}return u.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:d,transform:c,attributes:{x:f,y:p,\"text-anchor\":\"middle\"}})}(t,e)})),s.syncOrAsync(Z)}}function Q(t){var r=p+(t||\"tick\");return w[r]||(w[r]=function(t,e){var r,n,i,a;t._selections[e].size()?(r=1/0,n=-1/0,i=1/0,a=-1/0,t._selections[e].each((function(){var t=dt(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),i=Math.min(i,e.left),a=Math.max(a,e.right)}))):(r=0,n=0,i=0,a=0);return{top:r,bottom:n,left:i,right:a,height:n-r,width:a-i}}(e,r)),w[r]}},B.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map((function(t){return-t}))),t.side&&i.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),i},B.makeTransTickFn=function(t){return\"x\"===t._id.charAt(0)?function(e){return l(t._offset+t.l2p(e.x),0)}:function(e){return l(0,t._offset+t.l2p(e.x))}},B.makeTransTickLabelFn=function(t){var e=function(t){var e=t.ticklabelposition||\"\",r=function(t){return-1!==e.indexOf(t)},n=r(\"top\"),i=r(\"left\"),a=r(\"right\"),o=r(\"bottom\"),s=r(\"inside\"),l=o||i||n||a;if(!l&&!s)return[0,0];var c=t.side,u=l?(t.tickwidth||0)/2:0,f=3,h=t.tickfont?t.tickfont.size:12;(o||n)&&(u+=h*D,f+=(t.linewidth||0)/2);(i||a)&&(u+=(t.linewidth||0)/2,f+=3);s&&\"top\"===c&&(f-=h*(1-D));(i||n)&&(u=-u);\"bottom\"!==c&&\"right\"!==c||(f=-f);return[l?u:0,s?f:0]}(t),r=e[0],n=e[1];return\"x\"===t._id.charAt(0)?function(e){return l(r+t._offset+t.l2p(ut(e)),n)}:function(e){return l(n,r+t._offset+t.l2p(ut(e)))}},B.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},B.makeLabelFns=function(t,e,r){var n=t.ticklabelposition||\"\",a=function(t){return-1!==n.indexOf(t)},o=a(\"top\"),l=a(\"left\"),c=a(\"right\"),u=a(\"bottom\")||l||o||c,f=a(\"inside\"),h=\"inside\"===n&&\"inside\"===t.ticks||!f&&\"outside\"===t.ticks&&\"boundaries\"!==t.tickson,p=0,d=0,g=h?t.ticklen:0;if(f?g*=-1:u&&(g=0),h&&(p+=g,r)){var m=s.deg2rad(r);p=g*Math.cos(m)+1,d=g*Math.sin(m)}t.showticklabels&&(h||t.showline)&&(p+=.2*t.tickfont.size);var v,y,x,b,_,w={labelStandoff:p+=(t.linewidth||1)/2*(f?-1:1),labelShift:d},T=0,k=t.side,M=t._id.charAt(0),A=t.tickangle;if(\"x\"===M)b=(_=!f&&\"bottom\"===k||f&&\"top\"===k)?1:-1,f&&(b*=-1),v=d*b,y=e+p*b,x=_?1:-.2,90===Math.abs(A)&&(f?x+=O:x=-90===A&&\"bottom\"===k?D:90===A&&\"top\"===k?O:.5,T=O/2*(A/90)),w.xFn=function(t){return t.dx+v+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*x},w.anchorFn=function(t,e){if(u){if(l)return\"end\";if(c)return\"start\"}return i(e)&&0!==e&&180!==e?e*b<0!==f?\"end\":\"start\":\"middle\"},w.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side!==f?-n:0};else if(\"y\"===M){if(b=(_=!f&&\"left\"===k||f&&\"right\"===k)?1:-1,f&&(b*=-1),v=p,y=d*b,x=0,f||90!==Math.abs(A)||(x=-90===A&&\"left\"===k||90===A&&\"right\"===k?D:.5),f){var S=i(A)?+A:0;if(0!==S){var E=s.deg2rad(S);T=Math.abs(Math.sin(E))*D*b,x=0}}w.xFn=function(t){return t.dx+e-(v+t.fontSize*x)*b+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*O},w.anchorFn=function(t,e){return i(e)&&90===Math.abs(e)?\"middle\":_?\"end\":\"start\"},w.heightFn=function(e,r,n){return\"right\"===t.side&&(r*=-1),r<-30?-n:r<30?-.5*n:0}}return w},B.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.vals;\"period\"===e.ticklabelmode&&(i=i.slice()).shift();var a=r.layer.selectAll(\"path.\"+n).data(e.ticks?i:[],ft);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(f.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),a.attr(\"transform\",r.transFn)},B.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&B.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,ft);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},B.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=B.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each((function(){r.layer.selectAll(\"path\").sort((function(t,e){return U(t.id,e.id)}))})),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.zerolinecolor||f.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},B.drawLabels=function(t,e,r){r=r||{};var a=t._fullLayout,o=e._id,u=o.charAt(0),f=r.cls||o+\"tick\",p=r.vals,d=r.labelFns,g=r.secondary?0:e.tickangle,m=(e._prevTickAngles||{})[f],v=r.layer.selectAll(\"g.\"+f).data(e.showticklabels?p:[],ft),y=[];function x(t,a){var o=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");t.each((function(t){var s=n.select(this),u=s.select(\".text-math-group\"),f=d.anchorFn(t,a),p=r.transFn.call(s.node(),t)+(i(a)&&0!=+a?\" rotate(\"+a+\",\"+d.xFn(t)+\",\"+(d.yFn(t)-t.fontSize/2)+\")\":\"\"),g=c.lineCount(s),m=R*t.fontSize,v=d.heightFn(t,i(a)?+a:0,(g-1)*m);if(v&&(p+=l(0,v)),u.empty()){var y=s.select(\"text\");y.attr({transform:p,\"text-anchor\":f}),o&&(y.style({opacity:100}),e._hideOutOfRangeInsideTickLabels&&e._hideOutOfRangeInsideTickLabels())}else{var x=h.bBox(u.node()).width*{end:-.5,start:.5}[f];u.attr(\"transform\",p+l(x,0))}}))}v.enter().append(\"g\").classed(f,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),i=t._promises.length;r.call(c.positionText,d.xFn(e),d.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(c.convertToTspans,t),t._promises[i]?y.push(t._promises.pop().then((function(){x(r,g)}))):x(r,g)})),v.exit().remove(),r.repositionOnUpdate&&v.each((function(t){n.select(this).select(\"text\").call(c.positionText,d.xFn(t),d.yFn(t))})),e._hideOutOfRangeInsideTickLabels=void 0,-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&(e._hideOutOfRangeInsideTickLabels=function(){var t=s.simpleMap(e.range,e.r2l),r=e.l2p(t[0]),i=e.l2p(t[1]),a=Math.min(r,i)+e._offset,o=Math.max(r,i)+e._offset,l=\"x\"===e._id.charAt(0);v.each((function(t){var r=n.select(this);if(r.select(\".text-math-group\").empty()){var i=h.bBox(r.node()),s=!1;l?(i.right>o||i.left<a)&&(s=!0):(i.bottom>o||i.top+(e.tickangle?0:t.fontSize/4)<a)&&(s=!0),s&&r.select(\"text\").style({opacity:0})}}))}),x(v,m+1?m:g);var b=null;e._selections&&(e._selections[f]=v);var _=[function(){return y.length&&Promise.all(y)}];e.automargin&&a._redrawFromAutoMarginCount&&90===m?(b=90,_.push((function(){x(v,m)}))):_.push((function(){if(x(v,g),p.length&&\"x\"===u&&!i(g)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){b=0;var t,n=0,a=[];if(v.each((function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),i=dt(this),o=h.bBox(i.node());a.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})})),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var o=p.length,l=Math.abs((p[o-1].x-p[0].x)*e._m)/(o-1),c=e.ticklabelposition||\"\",f=function(t){return-1!==c.indexOf(t)},d=f(\"top\"),m=f(\"left\"),y=f(\"right\"),_=f(\"bottom\")||m||d||y?(e.tickwidth||0)+6:0,w=l<2.5*n||\"multicategory\"===e.type;for(t=0;t<a.length-1;t++)if(s.bBoxIntersect(a[t],a[t+1],_)){b=w?90:30;break}}else{var T=2;for(e.ticks&&(T+=e.tickwidth/2),t=0;t<a.length;t++){var k=p[t].xbnd,M=a[t];if(null!==k[0]&&M.left-e.l2p(k[0])<T||null!==k[1]&&e.l2p(k[1])-M.right<T){b=90;break}}}b&&x(v,b)}})),e._tickAngles&&_.push((function(){e._tickAngles[f]=null===b?i(g)?g:0:b}));var w=e._anchorAxis;w&&w.autorange&&-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&!V(a,e._id)&&(a._insideTickLabelsAutorange||(a._insideTickLabelsAutorange={}),a._insideTickLabelsAutorange[w._name+\".autorange\"]=w.autorange,_.push((function(){v.each((function(t,r){var n=dt(this);e._vals[r].bb=h.bBox(n.node())}))})));var T=s.syncOrAsync(_);return T&&T.then&&t._promises.push(T),T},B.getPxPosition=function(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=e._anchorAxis:\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0},B.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===P)&&(pt(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=B.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var f=B.list(t,s),h=0;h<f.length;h++){var p=f[h];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},B.clipEnds=function(t,e){return e.filter((function(e){return pt(t,e.x)}))},B.allowAutoMargin=function(t){for(var e=B.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(a.allowAutoMargin(t,gt(n)),n.mirror&&a.allowAutoMargin(t,mt(n))),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,vt(n))}},B.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],yt(c.x,l.x),yt(c.y,l.y);yt(c.x,[o]),yt(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)xt(t,r[n].x,r[n].y)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"./autorange\":827,\"./axis_autotype\":829,\"./axis_ids\":831,\"./clean_ticks\":833,\"./layout_attributes\":842,\"./set_convert\":848,d3:169,\"fast-isnumeric\":241}],829:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=i.isArrayOrTypedArray,s=i.isDateTime,l=i.cleanNumber,c=Math.round;function u(t,e){return e?n(t):\"number\"==typeof t}function f(t){return Math.max(1,(t-1)/1e3)}e.exports=function(t,e,r){var i=t,h=r.noMultiCategory;if(o(i)&&!i.length)return\"-\";if(!h&&function(t){return o(t[0])&&o(t[1])}(i))return\"multicategory\";if(h&&Array.isArray(i[0])){for(var p=[],d=0;d<i.length;d++)if(o(i[d]))for(var g=0;g<i[d].length;g++)p.push(i[d][g]);i=p}if(function(t,e){for(var r=t.length,i=f(r),a=0,o=0,l={},u=0;u<r;u+=i){var h=c(u),p=t[h],d=String(p);l[d]||(l[d]=1,s(p,e)&&a++,n(p)&&o++)}return a>2*o}(i,e))return\"date\";var m=\"strict\"!==r.autotypenumbers;return function(t,e){for(var r=t.length,n=f(r),i=0,o=0,s={},u=0;u<r;u+=n){var h=c(u),p=t[h],d=String(p);if(!s[d]){s[d]=1;var g=typeof p;\"boolean\"===g?o++:(e?l(p)!==a:\"number\"===g)?i++:\"string\"===g&&o++}}return o>2*i}(i,m)?\"category\":function(t,e){for(var r=t.length,n=0;n<r;n++)if(u(t[n],e))return!0;return!1}(i,m)?\"linear\":\"-\"}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],830:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../array_container_defaults\"),s=t(\"./layout_attributes\"),l=t(\"./tick_value_defaults\"),c=t(\"./tick_mark_defaults\"),u=t(\"./tick_label_defaults\"),f=t(\"./category_order_defaults\"),h=t(\"./line_grid_defaults\"),p=t(\"./set_convert\"),d=t(\"./constants\").WEEKDAY_PATTERN,g=t(\"./constants\").HOUR_PATTERN;function m(t,e,r){function i(r,n){return a.coerce(t,e,s.rangebreaks,r,n)}if(i(\"enabled\")){var o=i(\"bounds\");if(o&&o.length>=2){var l,c,u=\"\";if(2===o.length)for(l=0;l<2;l++)if(c=y(o[l])){u=d;break}var f=i(\"pattern\",u);if(f===d)for(l=0;l<2;l++)(c=y(o[l]))&&(e.bounds[l]=o[l]=c-1);if(f)for(l=0;l<2;l++)switch(c=o[l],f){case d:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[l]=o[l]=c;break;case g:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[l]=o[l]=c}if(!1===r.autorange){var h=r.range;if(h[0]<h[1]){if(o[0]<h[0]&&o[1]>h[1])return void(e.enabled=!1)}else if(o[0]>h[0]&&o[1]<h[1])return void(e.enabled=!1)}}else{var p=i(\"values\");if(!p||!p.length)return void(e.enabled=!1);i(\"dvalue\")}}}e.exports=function(t,e,r,n,g){var v,y=n.letter,x=n.font||{},b=n.splomStash||{},_=r(\"visible\",!n.visibleDflt),w=e._template||{},T=e.type||w.type||\"-\";\"date\"===T&&(i.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",n.calendar),n.noTicklabelmode||(v=r(\"ticklabelmode\")));n.noTicklabelposition&&\"multicategory\"!==T||a.coerce(t,e,{ticklabelposition:{valType:\"enumerated\",dflt:\"outside\",values:\"period\"===v?[\"outside\",\"inside\"]:\"x\"===y?[\"outside\",\"inside\",\"outside left\",\"inside left\",\"outside right\",\"inside right\"]:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"]}},\"ticklabelposition\"),p(e,g);var k=!e.isValidRange(t.range);k&&n.reverseDflt&&(k=\"reversed\"),!r(\"autorange\",k)||\"linear\"!==T&&\"-\"!==T||r(\"rangemode\"),r(\"range\"),e.cleanRange(),f(t,e,r,n),\"category\"===T||n.noHover||r(\"hoverformat\");var M=r(\"color\"),A=M!==s.color.dflt?M:x.color,S=b.label||g._dfltTitle[y];if(u(t,e,r,T,n,{pass:1}),!_)return e;r(\"title.text\",S),a.coerceFont(r,\"title.font\",{family:x.family,size:Math.round(1.2*x.size),color:A}),l(t,e,r,T),u(t,e,r,T,n,{pass:2}),c(t,e,r,n),h(t,e,r,{dfltColor:M,bgColor:n.bgColor,showGrid:n.showGrid,attributes:s}),(e.showline||e.ticks)&&r(\"mirror\"),n.automargin&&r(\"automargin\");var E,C=\"multicategory\"===T;n.noTickson||\"category\"!==T&&!C||!e.ticks&&!e.showgrid||(C&&(E=\"boundaries\"),\"boundaries\"===r(\"tickson\",E)&&delete e.ticklabelposition);C&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));if(\"date\"===T)if(o(t,e,{name:\"rangebreaks\",inclusionAttr:\"enabled\",handleItemDefaults:m}),e.rangebreaks.length){for(var L=0;L<e.rangebreaks.length;L++)if(e.rangebreaks[L].pattern===d){e._hasDayOfWeekBreaks=!0;break}if(p(e,g),g._has(\"scattergl\")||g._has(\"splom\"))for(var I=0;I<n.data.length;I++){var P=n.data[I];\"scattergl\"!==P.type&&\"splom\"!==P.type||(P.visible=!1,a.warn(P.type+\" traces do not work on axes with rangebreaks. Setting trace \"+P.index+\" to `visible: false`.\"))}}else delete e.rangebreaks;return e};var v={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function y(t){if(\"string\"==typeof t)return v[t.substr(0,3).toLowerCase()]}},{\"../../lib\":778,\"../../registry\":911,\"../array_container_defaults\":823,\"./category_order_defaults\":832,\"./constants\":834,\"./layout_attributes\":842,\"./line_grid_defaults\":844,\"./set_convert\":848,\"./tick_label_defaults\":849,\"./tick_mark_defaults\":850,\"./tick_value_defaults\":851,\"fast-isnumeric\":241}],831:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");function a(t,e){if(e&&e.length)for(var r=0;r<e.length;r++)if(e[r][t])return!0;return!1}r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.split(\" \")[0].substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e,r){var n=/( domain)$/.test(t);if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)&&(!n||r)){var a=t.split(\" \")[0].substr(1).replace(/^0+/,\"\");return\"1\"===a&&(a=\"\"),t.charAt(0)+a+(n&&r?\" domain\":\"\")}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return e=void 0===e||\"string\"!=typeof e?e:e.replace(\" domain\",\"\"),\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.ref2id=function(t){return!!/^[xyz]/.test(t)&&t.split(\" \")[0]},r.isLinked=function(t,e){return a(e,t._axisMatchGroups)||a(e,t._axisConstraintGroups)}},{\"../../registry\":911,\"./constants\":834}],832:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],833:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.ONEDAY,s=a.ONEWEEK;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,a=\"category\"===e,s=i?o:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:a?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r,a%s==0?1:0)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],834:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\",\"( domain)?\"),y:n(\"y\",\"( domain)?\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*( domain)?$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:\"hour\",WEEKDAY_PATTERN:\"day of week\",MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"imagelayer\",\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":795}],835:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./autorange\"),a=t(\"./axis_ids\").id2name,o=t(\"./layout_attributes\"),s=t(\"./scale_zoom\"),l=t(\"./set_convert\"),c=t(\"../../constants/numerical\").ALMOST_EQUAL,u=t(\"../../constants/alignment\").FROM_BL;function f(t,e,r){var i=r.axIds,s=r.layoutOut,l=r.hasImage,c=s._axisConstraintGroups,u=s._axisMatchGroups,f=e._id,g=f.charAt(0),m=((s._splomAxes||{})[g]||{})[f]||{},v=e._id,y=\"x\"===v.charAt(0);function x(r,i){return n.coerce(t,e,o,r,i)}e._matchGroup=null,e._constraintGroup=null,x(\"constrain\",l?\"domain\":\"range\"),n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:y?\"center\":\"middle\"}},\"constraintoward\");var b,_,w=e.type,T=[];for(b=0;b<i.length;b++){if((_=i[b])!==v)s[a(_)].type===w&&T.push(_)}var k=p(c,v);if(k){var M=[];for(b=0;b<T.length;b++)k[_=T[b]]||M.push(_);T=M}var A,S,E=T.length;E&&(t.matches||m.matches)&&(A=n.coerce(t,e,{matches:{valType:\"enumerated\",values:T,dflt:-1!==T.indexOf(m.matches)?m.matches:void 0}},\"matches\"));var C=l&&!y?e.anchor:void 0;if(E&&!A&&(t.scaleanchor||C)&&(S=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:T}},\"scaleanchor\",C)),A){e._matchGroup=d(u,v,A,1);var L=s[a(A)],I=h(s,e)/h(s,L);y!==(\"x\"===A.charAt(0))&&(I=(y?\"x\":\"y\")+I),d(c,v,A,I)}else t.matches&&-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid an infinite loop');if(S){var P=x(\"scaleratio\");P||(P=e.scaleratio=1),d(c,v,S,P)}else t.scaleanchor&&-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because this axis declares a *matches* constraint.')}function h(t,e){var r=e.domain;return r||(r=t[a(e.overlaying)].domain),r[1]-r[0]}function p(t,e){for(var r=0;r<t.length;r++)if(t[r][e])return t[r];return null}function d(t,e,r,n){var i,a,o,s,l,c=p(t,e);null===c?((c={})[e]=1,l=t.length,t.push(c)):l=t.indexOf(c);var u=Object.keys(c);for(i=0;i<t.length;i++)if(o=t[i],i!==l&&o[r]){var f=o[r];for(a=0;a<u.length;a++)o[s=u[a]]=g(f,g(n,c[s]));return void t.splice(l,1)}if(1!==n)for(a=0;a<u.length;a++){var h=u[a];c[h]=g(n,c[h])}c[r]=1}function g(t,e){var r,n,i=\"\",a=\"\";\"string\"==typeof t&&(r=(i=t.match(/^[xy]*/)[0]).length,t=+t.substr(r)),\"string\"==typeof e&&(n=(a=e.match(/^[xy]*/)[0]).length,e=+e.substr(n));var o=t*e;return r||n?r&&n&&i.charAt(0)!==a.charAt(0)?r===n?o:(r>n?i.substr(n):a.substr(r))+o:i+a+t*e:o}function m(t,e){for(var r=e._size,n=r.h/r.w,i={},a=Object.keys(t),o=0;o<a.length;o++){var s=a[o],l=t[s];if(\"string\"==typeof l){var c=l.match(/^[xy]*/)[0],u=c.length;l=+l.substr(u);for(var f=\"y\"===c.charAt(0)?n:1/n,h=0;h<u;h++)l*=f}i[s]=l}return i}function v(t,e){var r=t._inputDomain,n=u[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleDefaults=function(t,e,r){var i,o,s,c,u,h,p,d,g=r.axIds,m=r.axHasImage,v=e._axisConstraintGroups=[],y=e._axisMatchGroups=[];for(i=0;i<g.length;i++)f(u=t[c=a(g[i])],h=e[c],{axIds:g,layoutOut:e,hasImage:m[c]});function x(t,r){for(i=0;i<t.length;i++)for(s in o=t[i])e[a(s)][r]=o}for(x(y,\"_matchGroup\"),i=0;i<v.length;i++)for(s in o=v[i])if((h=e[a(s)]).fixedrange){for(var b in o){var _=a(b);!1===(t[_]||{}).fixedrange&&n.warn(\"fixedrange was specified as false for axis \"+_+\" but was overridden because another axis in its constraint group has fixedrange true\"),e[_].fixedrange=!0}break}for(i=0;i<v.length;){for(s in o=v[i]){(h=e[a(s)])._matchGroup&&Object.keys(h._matchGroup).length===Object.keys(o).length&&(v.splice(i,1),i--);break}i++}x(v,\"_constraintGroup\");var w=[\"constrain\",\"range\",\"autorange\",\"rangemode\",\"rangebreaks\",\"categoryorder\",\"categoryarray\"],T=!1,k=!1;function M(){d=h[p],\"rangebreaks\"===p&&(k=h._hasDayOfWeekBreaks)}for(i=0;i<y.length;i++){o=y[i];for(var A=0;A<w.length;A++){var S;for(s in p=w[A],d=null,o)if(u=t[c=a(s)],h=e[c],p in h){if(!h.matches&&(S=h,p in u)){M();break}null===d&&p in u&&M()}if(\"range\"===p&&d&&(T=!0),\"autorange\"===p&&null===d&&T&&(d=!1),null===d&&p in S&&(d=S[p]),null!==d)for(s in o)(h=e[a(s)])[p]=\"range\"===p?d.slice():d,\"rangebreaks\"===p&&(h._hasDayOfWeekBreaks=k,l(h,e))}}},r.enforce=function(t){var e,r,n,o,l,u,f,h,p=t._fullLayout,d=p._axisConstraintGroups||[];for(e=0;e<d.length;e++){n=m(d[e],p);var g=Object.keys(n),y=1/0,x=0,b=1/0,_={},w={},T=!1;for(r=0;r<g.length;r++)w[o=g[r]]=l=p[a(o)],l._inputDomain?l.domain=l._inputDomain.slice():l._inputDomain=l.domain.slice(),l._inputRange||(l._inputRange=l.range.slice()),l.setScale(),_[o]=u=Math.abs(l._m)/n[o],y=Math.min(y,u),\"domain\"!==l.constrain&&l._constraintShrinkable||(b=Math.min(b,u)),delete l._constraintShrinkable,x=Math.max(x,u),\"domain\"===l.constrain&&(T=!0);if(!(y>c*x)||T)for(r=0;r<g.length;r++)if(u=_[o=g[r]],f=(l=w[o]).constrain,u!==b||\"domain\"===f)if(h=u/b,\"range\"===f)s(l,h);else{var k=l._inputDomain,M=(l.domain[1]-l.domain[0])/(k[1]-k[0]),A=(l.r2l(l.range[1])-l.r2l(l.range[0]))/(l.r2l(l._inputRange[1])-l.r2l(l._inputRange[0]));if((h/=M)*A<1){l.domain=l._input.domain=k.slice(),s(l,h);continue}if(A<1&&(l.range=l._input.range=l._inputRange.slice(),h*=A),l.autorange){var S=l.r2l(l.range[0]),E=l.r2l(l.range[1]),C=(S+E)/2,L=C,I=C,P=Math.abs(E-C),z=C-P*h*1.0001,O=C+P*h*1.0001,D=i.makePadFn(p,l,0),R=i.makePadFn(p,l,1);v(l,h);var F,B,N=Math.abs(l._m),j=i.concatExtremes(t,l),U=j.min,V=j.max;for(B=0;B<U.length;B++)(F=U[B].val-D(U[B])/N)>z&&F<L&&(L=F);for(B=0;B<V.length;B++)(F=V[B].val+R(V[B])/N)<O&&F>I&&(I=F);h/=(I-L)/(2*P),L=l.l2r(L),I=l.l2r(I),l.range=l._input.range=S<E?[L,I]:[I,L]}v(l,h)}}},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"./autorange\":827,\"./axis_ids\":831,\"./layout_attributes\":842,\"./scale_zoom\":846,\"./set_convert\":848}],836:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/color\"),f=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),p=t(\"./axes\"),d=t(\"../../lib/setcursor\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/dragelement/helpers\"),v=m.selectingOrDrawing,y=m.freeMode,x=t(\"../../constants/alignment\").FROM_TL,b=t(\"../../lib/clear_gl_canvases\"),_=t(\"../../plot_api/subroutines\").redrawReglTraces,w=t(\"../plots\"),T=t(\"./axis_ids\").getFromId,k=t(\"./select\").prepSelect,M=t(\"./select\").clearSelect,A=t(\"./select\").selectOnClick,S=t(\"./scale_zoom\"),E=t(\"./constants\"),C=E.MINDRAG,L=E.MINZOOM,I=!0;function P(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,(function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)}));return i.call(d,n),i.node()}function z(t,e,r,i,a,o,s){var l=P(t,\"rect\",e,r);return n.select(l).call(f.setRect,i,a,o,s),l}function O(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function D(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange)if(o.rangebreaks){var s=\"y\"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+\".range[0]\"]=o.l2r(o.p2l(l*o._length)),n[o._name+\".range[1]\"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],f=o._rl[1]-u;n[o._name+\".range[0]\"]=o.l2r(u+f*e),n[o._name+\".range[1]\"]=o.l2r(u+f*r)}}if(i&&i.length){var h=(e+(1-r))/2;D(i,h,1-h,n,[])}}function R(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange)if(n.rangebreaks){var i=n._length,a=(n.p2l(0+e)-n.p2l(0)+(n.p2l(i+e)-n.p2l(i)))/2;n.range=[n.l2r(n._rl[0]-a),n.l2r(n._rl[1]-a)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)]}}function F(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function B(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",l(r,n)).attr(\"d\",i+\"Z\")}function N(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:u.background,stroke:u.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",l(e,r)).attr(\"d\",\"M0,0Z\")}function j(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),U(t,e,i,a)}function U(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function V(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function q(t){I&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),I=!1)}function H(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,L)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function G(t,e,r,n,i){for(var a,o,l,c,u=!1,f={},h={},p=(i||{}).xaHash,d=(i||{}).yaHash,g=0;g<e.length;g++){var m=e[g];for(a in r)if(m[a]){for(l in m)i&&(p[l]||d[l])||(\"x\"===l.charAt(0)?r:n)[l]||(f[l]=a);for(o in n)i&&(p[o]||d[o])||!m[o]||(u=!0)}for(o in n)if(m[o])for(c in m)i&&(p[c]||d[c])||(\"x\"===c.charAt(0)?r:n)[c]||(h[c]=o)}u&&(s.extendFlat(f,h),h={});var v={},y=[];for(l in f){var x=T(t,l);y.push(x),v[x._id]=x}var b={},_=[];for(c in h){var w=T(t,c);_.push(w),b[w._id]=w}return{xaHash:v,yaHash:b,xaxes:y,yaxes:_,xLinks:f,yLinks:h,isSubplotConstrained:u}}function Y(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel?t.onmousewheel=e:t.isAddedWheelEvent||(t.isAddedWheelEvent=!0,t.addEventListener(\"wheel\",e,{passive:!1}))}function W(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,l,u,d,m){var I,P,U,X,Z,J,K,Q,$,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ft,ht,pt,dt=t._fullLayout._zoomlayer,gt=d+m===\"nsew\",mt=1===(d+m).length;function vt(){if(I=e.xaxis,P=e.yaxis,$=I._length,tt=P._length,K=I._offset,Q=P._offset,(U={})[I._id]=I,(X={})[P._id]=P,d&&m)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;U[i._id]=i;var a=r[n].yaxis;X[a._id]=a}Z=W(U),J=W(X),nt=O(Z,m),it=O(J,d),at=!it&&!nt,rt=G(t,t._fullLayout._axisMatchGroups,U,X);var o=(et=G(t,t._fullLayout._axisConstraintGroups,U,X,rt)).isSubplotConstrained||rt.isSubplotConstrained;ot=m||o,st=d||o;var s=t._fullLayout;lt=s._has(\"scattergl\"),ct=s._has(\"splom\"),ut=s._has(\"svg\")}vt();var yt=function(t,e,r){if(!t)return\"pointer\";if(\"nsew\"===t)return r?\"\":\"pan\"===e?\"move\":\"crosshair\";return t.toLowerCase()+\"-resize\"}(it+nt,t._fullLayout.dragmode,gt),xt=z(e,d+m+\"drag\",yt,r,a,l,u);if(at&&!gt)return xt.onmousedown=null,xt.style.pointerEvents=\"none\",xt;var bt,_t,wt,Tt,kt,Mt,At,St,Et,Ct,Lt={element:xt,gd:t,plotinfo:e};function It(){Lt.plotinfo.selection=!1,M(t)}function Pt(t,r){var i=Lt.gd;if(i._fullLayout._activeShapeIndex>=0)i._fullLayout._deactivateShape(i);else{var a=i._fullLayout.clickmode;if(V(i),2!==t||mt||qt(),gt)a.indexOf(\"select\")>-1&&A(r,i,Z,J,e.id,Lt),a.indexOf(\"event\")>-1&&h.click(i,r,e.id);else if(1===t&&mt){var s=d?P:I,l=\"s\"===d||\"w\"===m?0:1,u=s._name+\".range[\"+l+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,l),p=\"left\",g=\"middle\";if(s.fixedrange)return;d?(g=\"n\"===d?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===m&&(p=\"right\"),i._context.showAxisRangeEntryBoxes&&n.select(xt).call(c.makeEditable,{gd:i,immediate:!0,background:i._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:g}).on(\"edit\",(function(t){var e=s.d2r(t);void 0!==e&&o.call(\"_guiRelayout\",i,u,e)}))}}}function zt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,ht*e+bt)),i=Math.max(0,Math.min(tt,pt*r+_t)),a=Math.abs(n-bt),o=Math.abs(i-_t);function s(){At=\"\",wt.r=wt.l,wt.t=wt.b,Et.attr(\"d\",\"M0,0Z\")}if(wt.l=Math.min(bt,n),wt.r=Math.max(bt,n),wt.t=Math.min(_t,i),wt.b=Math.max(_t,i),et.isSubplotConstrained)a>L||o>L?(At=\"xy\",a/$>o/tt?(o=a*tt/$,_t>i?wt.t=_t-o:wt.b=_t+o):(a=o*$/tt,bt>n?wt.l=bt-a:wt.r=bt+a),Et.attr(\"d\",H(wt))):s();else if(rt.isSubplotConstrained)if(a>L||o>L){At=\"xy\";var l=Math.min(wt.l/$,(tt-wt.b)/tt),c=Math.max(wt.r/$,(tt-wt.t)/tt);wt.l=l*$,wt.r=c*$,wt.b=(1-l)*tt,wt.t=(1-c)*tt,Et.attr(\"d\",H(wt))}else s();else!it||o<Math.min(Math.max(.6*a,C),L)?a<C||!nt?s():(wt.t=0,wt.b=tt,At=\"x\",Et.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-L-.5)+\"h-3v\"+(2*L+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-L-.5)+\"h3v\"+(2*L+1)+\"h-3Z\"}(wt,_t))):!nt||a<Math.min(.6*o,L)?(wt.l=0,wt.r=$,At=\"y\",Et.attr(\"d\",function(t,e){return\"M\"+(e-L-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*L+1)+\"v3ZM\"+(e-L-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*L+1)+\"v-3Z\"}(wt,bt))):(At=\"xy\",Et.attr(\"d\",H(wt)));wt.w=wt.r-wt.l,wt.h=wt.b-wt.t,At&&(Ct=!0),t._dragged=Ct,j(St,Et,wt,kt,Mt,Tt),Ot(),t.emit(\"plotly_relayouting\",ft),Mt=!0}function Ot(){ft={},\"xy\"!==At&&\"x\"!==At||(D(Z,wt.l/$,wt.r/$,ft,et.xaxes),Ut(\"x\",ft)),\"xy\"!==At&&\"y\"!==At||(D(J,(tt-wt.b)/tt,(tt-wt.t)/tt,ft,et.yaxes),Ut(\"y\",ft))}function Dt(){Ot(),V(t),Ht(),q(t)}Lt.prepFn=function(e,r,n){var a=Lt.dragmode,o=t._fullLayout.dragmode;o!==a&&(Lt.dragmode=o),vt(),ht=t._fullLayout._invScaleX,pt=t._fullLayout._invScaleY,at||(gt?e.shiftKey?\"pan\"===o?o=\"zoom\":v(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),y(o)?Lt.minDrag=1:Lt.minDrag=void 0,v(o)?(Lt.xaxes=Z,Lt.yaxes=J,k(e,r,n,Lt,o)):(Lt.clickFn=Pt,v(a)&&It(),at||(\"zoom\"===o?(Lt.moveFn=zt,Lt.doneFn=Dt,Lt.minDrag=1,function(e,r,n){var a=xt.getBoundingClientRect();bt=r-a.left,_t=n-a.top,t._fullLayout._calcInverseTransform(t);var o=s.apply3DTransform(t._fullLayout._invTransform)(bt,_t);bt=o[0],_t=o[1],wt={l:bt,r:bt,w:0,t:_t,b:_t,h:0},Tt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),Mt=!1,At=\"xy\",Ct=!1,St=B(dt,Tt,K,Q,kt=\"M0,0H\"+$+\"V\"+tt+\"H0V0\"),Et=N(dt,K,Q)}(0,r,n)):\"pan\"===o&&(Lt.moveFn=jt,Lt.doneFn=Ht))),t._fullLayout._redrag=function(){var e=t._dragdata;if(e&&e.element===xt){var r=t._fullLayout.dragmode;v(r)||(vt(),Gt([0,0,$,tt]),Lt.moveFn(e.dx,e.dy))}}},g.init(Lt);var Rt=[0,0,$,tt],Ft=null,Bt=E.REDRAWDELAY,Nt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function jt(e,r){if(e*=ht,r*=pt,!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===nt||\"ns\"===it){var n=nt?-e:0,i=it?-r:0;if(rt.isSubplotConstrained){if(nt&&it){var a=(e/$-r/tt)/2;n=-(e=a*$),i=-(r=-a*tt)}it?n=-i*$/tt:i=-n*tt/$}return nt&&(R(Z,e),Ut(\"x\")),it&&(R(J,r),Ut(\"y\")),Gt([n,i,$,tt]),Vt(),void t.emit(\"plotly_relayouting\",ft)}var o,s,l=\"w\"===nt==(\"n\"===it)?1:-1;if(nt&&it&&(et.isSubplotConstrained||rt.isSubplotConstrained)){var c=(e/$+l*r/tt)/2;e=c*$,r=l*c*tt}if(\"w\"===nt?e=p(Z,0,e):\"e\"===nt?e=p(Z,1,-e):nt||(e=0),\"n\"===it?r=p(J,1,r):\"s\"===it?r=p(J,0,-r):it||(r=0),o=\"w\"===nt?e:0,s=\"n\"===it?r:0,et.isSubplotConstrained&&!rt.isSubplotConstrained||rt.isSubplotConstrained&&nt&&it&&l>0){var u;if(rt.isSubplotConstrained||!nt&&1===it.length){for(u=0;u<Z.length;u++)Z[u].range=Z[u]._r.slice(),S(Z[u],1-r/tt);o=(e=r*$/tt)/2}if(rt.isSubplotConstrained||!it&&1===nt.length){for(u=0;u<J.length;u++)J[u].range=J[u]._r.slice(),S(J[u],1-e/$);s=(r=e*tt/$)/2}}rt.isSubplotConstrained&&it||Ut(\"x\"),rt.isSubplotConstrained&&nt||Ut(\"y\");var f=$-e,h=tt-r;!rt.isSubplotConstrained||nt&&it||(nt?(s=o?0:e*tt/$,h=f*tt/$):(o=s?0:r*$/tt,f=h*$/tt)),Gt([o,s,f,h]),Vt(),t.emit(\"plotly_relayouting\",ft)}function p(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/F(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Ut(t,e){for(var r=rt.isSubplotConstrained?{x:J,y:Z}[t]:rt[t+\"axes\"],n=rt.isSubplotConstrained?{x:Z,y:J}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=rt.xLinks[o]||rt.yLinks[o],l=n[0]||U[s]||X[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Vt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(ot&&(n(Z),n(et.xaxes),n(rt.xaxes)),st&&(n(J),n(et.yaxes),n(rt.yaxes)),ft={},e=0;e<r.length;e++){var i=r[e],a=T(t,i);p.drawOne(t,a,{skipTitle:!0}),ft[a._name+\".range[0]\"]=a.range[0],ft[a._name+\".range[1]\"]=a.range[1]}p.redrawComponents(t,r)}function qt(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];nt&&(r=r.concat(Z)),it&&(r=r.concat(J)),rt.xaxes&&(r=r.concat(rt.xaxes)),rt.yaxes&&(r=r.concat(rt.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((nt||et.isSubplotConstrained)&&(r=r.concat(et.xaxes)),it&&!et.isSubplotConstrained&&(r=r.concat(et.yaxes)),et.isSubplotConstrained&&(nt?it||(r=r.concat(J)):r=r.concat(Z)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}function Ht(){Gt([0,0,$,tt]),s.syncOrAsync([w.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ft)}],t)}function Gt(e){var r,n,i,a,l=t._fullLayout,c=l._plots,u=l._subplots.cartesian;if(ct&&o.subplotsRegistry.splom.drag(t),lt)for(r=0;r<u.length;r++)if(i=(n=c[u[r]]).xaxis,a=n.yaxis,n._scene){var h=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[h[0],p[0],h[1],p[1]]})}if((ct||lt)&&(b(t),_(t)),ut){var g=e[2]/I._length,v=e[3]/P._length;for(r=0;r<u.length;r++){i=(n=c[u[r]]).xaxis,a=n.yaxis;var y,x,w,T,k=(ot||rt.isSubplotConstrained)&&!i.fixedrange&&U[i._id],M=(st||rt.isSubplotConstrained)&&!a.fixedrange&&X[a._id];if(k?(y=g,w=m||rt.isSubplotConstrained?e[0]:Xt(i,y)):rt.xaHash[i._id]?(y=g,w=e[0]*i._length/I._length):rt.yaHash[i._id]?(y=v,w=\"ns\"===it?-e[1]*i._length/P._length:Xt(i,y,{n:\"top\",s:\"bottom\"}[it])):w=Wt(i,y=Yt(i,g,v)),M?(x=v,T=d||rt.isSubplotConstrained?e[1]:Xt(a,x)):rt.yaHash[a._id]?(x=v,T=e[1]*a._length/P._length):rt.xaHash[a._id]?(x=g,T=\"ew\"===nt?-e[0]*a._length/I._length:Xt(a,x,{e:\"right\",w:\"left\"}[nt])):T=Wt(a,x=Yt(a,g,v)),y||x){y||(y=1),x||(x=1);var A=i._offset-w/y,S=a._offset-T/x;n.clipRect.call(f.setTranslate,w,T).call(f.setScale,y,x),n.plot.call(f.setTranslate,A,S).call(f.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(f.setPointGroupScale(n.zoomScalePts,y,x),f.setTextPointsScale(n.zoomScaleTxt,y,x)),f.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Yt(t,e,r){return t.fixedrange?0:ot&&et.xaHash[t._id]?e:st&&(et.isSubplotConstrained?et.xaHash:et.yaHash)[t._id]?r:0}function Wt(t,e){return e?(t.range=t._r.slice(),S(t,e),Xt(t,e)):0}function Xt(t,e,r){return t._length*(1-e)*x[r||t.constraintoward||\"middle\"]}return d.length*m.length!=1&&Y(xt,(function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(It(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();vt(),clearTimeout(Ft);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Nt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(ot){for(m||(o=.5),n=0;n<Z.length;n++)c(Z[n],o,i);Ut(\"x\"),Rt[2]*=i,Rt[0]+=Rt[2]*o*(1/i-1)}if(st){for(d||(l=.5),n=0;n<J.length;n++)c(J[n],l,i);Ut(\"y\"),Rt[3]*=i,Rt[1]+=Rt[3]*(1-l)*(1/i-1)}Gt(Rt),Vt(),t.emit(\"plotly_relayouting\",ft),Ft=setTimeout((function(){Rt=[0,0,$,tt],Ht()}),Bt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map((function(e){return t.l2r(i+(e-i)*r)}))}}})),xt},makeDragger:P,makeRectDragger:z,makeZoombox:B,makeCorners:N,updateZoombox:j,xyCorners:H,transitionZoombox:U,removeZoombox:V,showDoubleClickNotifier:q,attachWheelEventHandler:Y}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"../plots\":891,\"./axes\":828,\"./axis_ids\":831,\"./constants\":834,\"./scale_zoom\":846,\"./select\":847,d3:169,\"has-passive-events\":441,tinycolor2:576}],837:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort((function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1})).forEach((function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var f=o._mainLinePosition;\"top\"===o.side&&(f-=l),s(t,n,o._offset+.1*o._length,f,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,f,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,f,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var h=c._mainLinePosition;\"right\"!==c.side&&(h-=l),s(t,n,h,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,h,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,h,c._offset,l,.1*c._length,\"n\",\"\")}}}));var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":662,\"../../components/fx\":683,\"../../lib/setcursor\":799,\"./constants\":834,\"./dragbox\":836,d3:169}],838:[function(t,e,r){\"use strict\";e.exports={clearOutlineControllers:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".outline-controllers\").remove()},clearSelect:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".select-outline\").remove(),t._fullLayout._drawing=!1}}},{}],839:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").strTranslate;function i(t,e){switch(t.type){case\"log\":return t.p2d(e);case\"date\":return t.p2r(e,0,t.calendar);default:return t.p2r(e)}}e.exports={p2r:i,r2p:function(t,e){switch(t.type){case\"log\":return t.d2p(e);case\"date\":return t.r2p(e,0,t.calendar);default:return t.r2p(e)}},axValue:function(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return i(t,r[e])}},getTransform:function(t){return n(t.xaxis._offset,t.yaxis._offset)}}},{\"../../lib\":778}],840:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./axis_ids\");e.exports=function(t){return function(e,r){var o=e[t];if(Array.isArray(o))for(var s=n.subplotsRegistry.cartesian,l=s.idRegex,c=r._subplots,u=c.xaxis,f=c.yaxis,h=c.cartesian,p=r._has(\"cartesian\")||r._has(\"gl2d\"),d=0;d<o.length;d++){var g=o[d];if(i.isPlainObject(g)){var m=a.cleanId(g.xref,\"x\",!1),v=a.cleanId(g.yref,\"y\",!1),y=l.x.test(m),x=l.y.test(v);if(y||x){p||i.pushUnique(r._basePlotModules,s);var b=!1;y&&-1===u.indexOf(m)&&(u.push(m),b=!0),x&&-1===f.indexOf(v)&&(f.push(v),b=!0),b&&y&&x&&h.push(m+v)}}}}}},{\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831}],841:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),f=t(\"../../constants/xmlns_namespaces\"),h=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,(function(t){t.datum(r)}))}function d(t,e,r,a,o){for(var c,f,h,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,m=[],v=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;h=(f=l(r,w))[0],r=f[1],h.length&&m.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:h}),b.zoomScale&&v.push(\".\"+_)}}m.sort((function(t,e){return t.i-e.i}));var T=e.plot.selectAll(\"g.mlayer\").data(m,(function(t){return t.className}));if(T.enter().append(\"g\").attr(\"class\",(function(t){return t.className})).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),T.exit().remove(),T.order(),T.each((function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)})),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),h=l(r,c)[0],c.plot(t,e,h)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),v.length)){var k=e.plot.selectAll(v.join(\",\")).selectAll(\".trace\");e.zoomScalePts=k.selectAll(\"path.point\"),e.zoomScaleTxt=k.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,f=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,h(s.overlinesBelow,\"path\",f),h(s.overlinesBelow,\"path\",d),h(s.overaxesBelow,\"g\",f),h(s.overaxesBelow,\"g\",d),e.plot=h(s.overplot,\"g\",n),h(s.overlinesAbove,\"path\",f),h(s.overlinesAbove,\"path\",d),h(s.overaxesAbove,\"g\",f),h(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+f),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+f),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.xaxislayer=h(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=h(r,\"g\",\"yaxislayer-above\");else{var g=h(r,\"g\",\"layer-subplot\");e.shapelayer=h(g,\"g\",\"shapelayer\"),e.imagelayer=h(g,\"g\",\"imagelayer\"),e.gridlayer=h(r,\"g\",\"gridlayer\"),e.zerolinelayer=h(r,\"g\",\"zerolinelayer\"),h(r,\"path\",\"xlines-below\"),h(r,\"path\",\"ylines-below\"),e.overlinesBelow=h(r,\"g\",\"overlines-below\"),h(r,\"g\",\"xaxislayer-below\"),h(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=h(r,\"g\",\"overaxes-below\"),e.plot=h(r,\"g\",\"plot\"),e.overplot=h(r,\"g\",\"overplot\"),e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.overlinesAbove=h(r,\"g\",\"overlines-above\"),h(r,\"g\",\"xaxislayer-above\"),h(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=h(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function m(t,e){if(t){var r={};for(var i in t.each((function(t){var i=t[0];n.select(this).remove(),v(i,e),r[i]=!0})),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function v(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,f=o.cartesian,h=f.concat(o.gl2d||[]),p={},d={};for(r=0;r<h.length;r++){var g=h[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),f.push(n+i),h.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),f.push(n+i),h.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!h.length){for(var m in n=\"\",i=\"\",t){if(u.attrRegex.test(m))\"x\"===m.charAt(0)?(!n||+m.substr(5)<+n.substr(5))&&(n=m):(!i||+m.substr(5)<+i.substr(5))&&(i=m)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),f.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],f=[],h=0;h<s.length;h++){var p=s[h],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===f.indexOf(l)&&f.push(l),f.push(p)),l=p)}d(t,u,f,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var f=n._has&&n._has(\"gl\"),h=e._has&&e._has(\"gl\");if(f&&!h)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)m(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups,delete n._axisMatchGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),v(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],f=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var h=a._mainAxis,p=o._mainAxis,d=h._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,f.push(n)):(i.mainplot=void 0,i.mainplotinfo=void 0,u.push(n))}for(e=0;e<f.length;e++)n=f[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var m=u.concat(f),v=new Array(c);for(e=0;e<c;e++){n=m[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);v[e]=y}return v}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",(function(t){return\"subplot \"+t[0]})),i.order(),i.exit().call(m,e),i.each((function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=h(e._draggers,\"g\",i)}))},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:f.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}))},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,\"../get_data\":865,\"../plots\":891,\"./attributes\":826,\"./axis_ids\":831,\"./constants\":834,\"./graph_interact\":837,\"./layout_attributes\":842,\"./layout_defaults\":843,\"./transition_axes\":852,d3:169}],842:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"../../constants/numerical\").ONEDAY),c=t(\"./constants\"),u=c.HOUR_PATTERN,f=c.WEEKDAY_PATTERN;e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),standoff:{valType:\"number\",min:0,editType:\"ticks\"},editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"calc\"},rangebreaks:s(\"rangebreak\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},bounds:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},pattern:{valType:\"enumerated\",values:[f,u,\"\"],editType:\"calc\"},values:{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"any\",editType:\"calc\"}},dvalue:{valType:\"number\",editType:\"calc\",min:0,dflt:l},editType:\"calc\"}),tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},ticklabelmode:{valType:\"enumerated\",values:[\"instant\",\"period\"],dflt:\"instant\",editType:\"ticks\"},ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside left\",\"inside left\",\"outside right\",\"inside right\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\",editType:\"calc\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\",\"hovered data\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":642,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/numerical\":753,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../font_attributes\":856,\"./constants\":834}],843:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../components/fx/helpers\").isUnifiedHover,o=t(\"../../components/fx/hovermode_defaults\"),s=t(\"../../plot_api/plot_template\"),l=t(\"../layout_attributes\"),c=t(\"./layout_attributes\"),u=t(\"./type_defaults\"),f=t(\"./axis_defaults\"),h=t(\"./constraints\"),p=t(\"./position_defaults\"),d=t(\"./axis_ids\"),g=d.id2name,m=d.name2id,v=t(\"./constants\").AX_ID_PATTERN,y=t(\"../../registry\"),x=y.traceIs,b=y.getComponentMethod;function _(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var y,w,T=e.autotypenumbers,k={},M={},A={},S={},E={},C={},L={},I={},P={},z={};for(y=0;y<r.length;y++){var O=r[y];if(x(O,\"cartesian\")||x(O,\"gl2d\")){var D,R;if(O.xaxis)D=g(O.xaxis),_(k,D,O);else if(O.xaxes)for(w=0;w<O.xaxes.length;w++)_(k,g(O.xaxes[w]),O);if(O.yaxis)R=g(O.yaxis),_(k,R,O);else if(O.yaxes)for(w=0;w<O.yaxes.length;w++)_(k,g(O.yaxes[w]),O);if(\"funnel\"===O.type?\"h\"===O.orientation?(D&&(M[D]=!0),R&&(L[R]=!0)):R&&(A[R]=!0):\"image\"===O.type?(R&&(I[R]=!0),D&&(I[D]=!0)):(R&&(E[R]=!0,C[R]=!0),x(O,\"carpet\")&&(\"carpet\"!==O.type||O._cheater)||D&&(S[D]=!0)),\"carpet\"===O.type&&O._cheater&&D&&(M[D]=!0),x(O,\"2dMap\")&&(P[D]=!0,P[R]=!0),x(O,\"oriented\"))z[\"h\"===O.orientation?R:D]=!0}}var F=e._subplots,B=F.xaxis,N=F.yaxis,j=n.simpleMap(B,g),U=n.simpleMap(N,g),V=j.concat(U),q=i.background;B.length&&N.length&&(q=n.coerce(t,e,l,\"plot_bgcolor\"));var H,G,Y,W,X,Z=i.combine(q,e.paper_bgcolor);function J(){var t=k[H]||[];X._traceIndices=t.map((function(t){return t._expandedIndex})),X._annIndices=[],X._shapeIndices=[],X._imgIndices=[],X._subplotsWith=[],X._counterAxes=[],X._name=X._attr=H,X._id=G}function K(t,e){return n.coerce(W,X,c,t,e)}function Q(t,e){return n.coerce2(W,X,c,t,e)}function $(t){return\"x\"===t?N:B}function tt(e,r){for(var n=\"x\"===e?j:U,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(m(o))}return i}var et={x:$(\"x\"),y:$(\"y\")},rt=et.x.concat(et.y),nt={},it=[];function at(){var t=W.matches;v.test(t)&&-1===rt.indexOf(t)&&(nt[t]=W.type,it=Object.keys(nt))}var ot=o(t,e,r),st=a(ot);for(y=0;y<V.length;y++){H=V[y],G=m(H),Y=H.charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var lt=\"x\"===Y&&!S[H]&&M[H]||\"y\"===Y&&!E[H]&&A[H],ct=\"y\"===Y&&(!C[H]&&L[H]||I[H]),ut={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:k[H]||[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:lt,reverseDflt:ct,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),u(W,X,K,ut),f(W,X,K,ut,e);var ft=st&&Y===ot.charAt(0),ht=Q(\"spikecolor\",st?X.color:void 0),pt=Q(\"spikethickness\",st?1.5:void 0),dt=Q(\"spikedash\",st?\"dot\":void 0),gt=Q(\"spikemode\",st?\"across\":void 0),mt=Q(\"spikesnap\",st?\"hovered data\":void 0);K(\"showspikes\",!!(ft||ht||pt||dt||gt||mt))||(delete X.spikecolor,delete X.spikethickness,delete X.spikedash,delete X.spikemode,delete X.spikesnap),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"title.standoff\"),at(),X._input=W}for(y=0;y<it.length;){G=it[y++],Y=(H=g(G)).charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var vt={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),X.type=nt[G]||\"linear\",f(W,X,K,vt,e),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"fixedrange\"),at(),X._input=W}var yt=b(\"rangeslider\",\"handleDefaults\"),xt=b(\"rangeselector\",\"handleDefaults\");for(y=0;y<j.length;y++)H=j[y],W=t[H],X=e[H],yt(t,e,H),\"date\"===X.type&&xt(W,X,e,U,X.calendar),K(\"fixedrange\");for(y=0;y<U.length;y++){H=U[y],W=t[H],X=e[H];var bt=e[g(X.anchor)];K(\"fixedrange\",b(\"rangeslider\",\"isVisible\")(bt))}h.handleDefaults(t,e,{axIds:rt.concat(it).sort(d.idSort),axHasImage:I})}},{\"../../components/color\":643,\"../../components/fx/helpers\":679,\"../../components/fx/hovermode_defaults\":682,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"../layout_attributes\":882,\"./axis_defaults\":830,\"./axis_ids\":831,\"./constants\":834,\"./constraints\":835,\"./layout_attributes\":842,\"./position_defaults\":845,\"./type_defaults\":853}],844:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var f=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),h=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!f||!!h)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":642,\"../../lib\":778,tinycolor2:576}],845:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],f=a.overlayableAxes||[],h=a.letter,p=a.grid;p&&(s=p._domains[h][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[h+\"side\"].split(\" \")[0],c=p.domain[h][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===h?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===h?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(f.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(f),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":778,\"fast-isnumeric\":241}],846:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)],t.setScale()}},{\"../../constants/alignment\":745}],847:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\").dashStyle,o=t(\"../../components/color\"),s=t(\"../../components/fx\"),l=t(\"../../components/fx/helpers\").makeEventData,c=t(\"../../components/dragelement/helpers\"),u=c.freeMode,f=c.rectMode,h=c.drawMode,p=c.openMode,d=c.selectMode,g=t(\"../../components/shapes/draw_newshape/display_outlines\"),m=t(\"../../components/shapes/draw_newshape/helpers\").handleEllipse,v=t(\"../../components/shapes/draw_newshape/newshapes\"),y=t(\"../../lib\"),x=t(\"../../lib/polygon\"),b=t(\"../../lib/throttle\"),_=t(\"./axis_ids\").getFromId,w=t(\"../../lib/clear_gl_canvases\"),T=t(\"../../plot_api/subroutines\").redrawReglTraces,k=t(\"./constants\"),M=k.MINSELECT,A=x.filter,S=x.tester,E=t(\"./handle_outline\").clearSelect,C=t(\"./helpers\"),L=C.p2r,I=C.axValue,P=C.getTransform;function z(t,e,r,n,i,a,o){var s,l,c,u,f,h,d,m,v,y=e._hoverdata,x=e._fullLayout.clickmode.indexOf(\"event\")>-1,b=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(y)){F(t,e,a);var _=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(y,s=N(e,r,n,i));if(_.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,_):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(h=j(_))){for(o&&o.remove(),v=0;v<s.length;v++)(l=s[v])._module.selectPoints(l,!1);U(e,s),B(a),x&&e.emit(\"plotly_deselect\",null)}else{for(d=t.shiftKey&&(void 0!==h?h:j(_)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(_.pointNumber,_.searchInfo,d),u=R(a.selectionDefs.concat([c])),v=0;v<s.length;v++)if(f=V(s[v]._module.selectPoints(s[v],u),s[v]),b.length)for(var w=0;w<f.length;w++)b.push(f[w]);else b=f;if(U(e,s,m={points:b}),c&&a&&a.selectionDefs.push(c),o){var T=a.mergedPolygons,k=p(a.dragmode);g(q(T,k),o,a)}x&&e.emit(\"plotly_selected\",m)}}}function O(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function D(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function R(t){for(var e=[],r=O(t[0])?0:t[0][0][0],n=r,i=O(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(O(t[o]))e.push(D(t[o]));else{var s=x.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function F(t,e,r){e._fullLayout._drawing=!1;var n=e._fullLayout,i=r.plotinfo,a=r.dragmode,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,s=(t.shiftKey||t.altKey)&&!(h(a)&&p(a));o&&s&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):s&&i.selection||B(r),o||(E(e),n._lastSelectedSubplot=i.id)}function B(t){var e=t.dragmode,r=t.plotinfo,n=t.gd;if(n._fullLayout._activeShapeIndex>=0&&n._fullLayout._deactivateShape(n),h(e)){var a=n._fullLayout._zoomlayer.selectAll(\".select-outline-\"+r.id);if(a&&n._fullLayout._drawing){var o=v(a,t);o&&i.call(\"_guiRelayout\",n,{shapes:o}),n._fullLayout._drawing=!1}}r.selection={},r.selection.selectionDefs=t.selectionDefs=[],r.selection.mergedPolygons=t.mergedPolygons=[]}function N(t,e,r,n){var i,a,o,s=[],l=e.map((function(t){return t._id})),c=r.map((function(t){return t._id}));for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=h(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=h(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(h(a._module,i,_(t,a.xaxis),_(t,a.yaxis)))}else s.push(h(a._module,i,e[0],r[0]));return s;function h(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function j(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function U(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var f=u[n],h=f.data,p=f.fullData;f.pointIndices?([].push.apply(h.selectedpoints,f.pointIndices),s._fullInput!==s&&[].push.apply(p.selectedpoints,f.pointIndices)):(h.selectedpoints.push(f.pointIndex),s._fullInput!==s&&p.selectedpoints.push(f.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var d=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(d=!0);var g=a._module,m=g.styleOnSelect||g.style;m&&(m(t,o,o[0].node3),o[0].nodeRangePlot3&&m(t,o,o[0].nodeRangePlot3))}d&&(w(t),T(t))}function V(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=l(t[i],n,r);return t}function q(t,e){for(var r=[],n=0;n<t.length;n++){r[n]=[];for(var i=0;i<t[n].length;i++){r[n][i]=[],r[n][i][0]=i?\"L\":\"M\";for(var a=0;a<t[n][i].length;a++)r[n][i].push(t[n][i][a])}e||r[n].push([\"Z\",r[n][0][1],r[n][0][2]])}return r}e.exports={prepSelect:function(t,e,r,i,l){var c=u(l),v=f(l),x=p(l),_=h(l),w=d(l),T=\"drawcircle\"===l,E=\"drawline\"===l||T,C=i.gd,O=C._fullLayout,D=O._zoomlayer,j=i.element.getBoundingClientRect(),H=i.plotinfo,G=P(H),Y=e-j.left,W=r-j.top;O._calcInverseTransform(C);var X=y.apply3DTransform(O._invTransform)(Y,W);Y=X[0],W=X[1];var Z,J,K,Q,$,tt,et,rt=O._invScaleX,nt=O._invScaleY,it=Y,at=W,ot=\"M\"+Y+\",\"+W,st=i.xaxes[0]._length,lt=i.yaxes[0]._length,ct=i.xaxes.concat(i.yaxes),ut=t.altKey&&!(h(l)&&x);F(t,C,i),c&&(Z=A([[Y,W]],k.BENDPX));var ft=D.selectAll(\"path.select-outline-\"+H.id).data(_?[0]:[1,2]),ht=O.newshape;ft.enter().append(\"path\").attr(\"class\",(function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+H.id})).style(_?{opacity:ht.opacity/2,fill:x?void 0:ht.fillcolor,stroke:ht.line.color,\"stroke-dasharray\":a(ht.line.dash,ht.line.width),\"stroke-width\":ht.line.width+\"px\"}:{}).attr(\"fill-rule\",ht.fillrule).classed(\"cursor-move\",!!_).attr(\"transform\",G).attr(\"d\",ot+\"Z\");var pt,dt=D.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:o.background,stroke:o.defaultLine,\"stroke-width\":1}).attr(\"transform\",G).attr(\"d\",\"M0,0Z\"),gt=O._uid+k.SELECTID,mt=[],vt=N(C,i.xaxes,i.yaxes,i.subplot);function yt(t,e){return t-e}pt=H.fillRangeItems?H.fillRangeItems:v?function(t,e){var r=t.range={};for($=0;$<ct.length;$++){var n=ct[$],i=n._id.charAt(0);r[n._id]=[L(n,e[i+\"min\"]),L(n,e[i+\"max\"])].sort(yt)}}:function(t,e,r){var n=t.lassoPoints={};for($=0;$<ct.length;$++){var i=ct[$];n[i._id]=r.filtered.map(I(i))}},i.moveFn=function(t,e){it=Math.max(0,Math.min(st,rt*t+Y)),at=Math.max(0,Math.min(lt,nt*e+W));var r=Math.abs(it-Y),a=Math.abs(at-W);if(v){var o,s,l;if(w){var u=O.selectdirection;switch(o=\"any\"===u?a<Math.min(.6*r,M)?\"h\":r<Math.min(.6*a,M)?\"v\":\"d\":u){case\"h\":s=T?lt/2:0,l=lt;break;case\"v\":s=T?st/2:0,l=st}}if(_)switch(O.newshape.drawdirection){case\"vertical\":o=\"h\",s=T?lt/2:0,l=lt;break;case\"horizontal\":o=\"v\",s=T?st/2:0,l=st;break;case\"ortho\":r<a?(o=\"h\",s=W,l=at):(o=\"v\",s=Y,l=it);break;default:o=\"d\"}\"h\"===o?((Q=E?m(T,[it,s],[it,l]):[[Y,s],[Y,l],[it,l],[it,s]]).xmin=E?it:Math.min(Y,it),Q.xmax=E?it:Math.max(Y,it),Q.ymin=Math.min(s,l),Q.ymax=Math.max(s,l),dt.attr(\"d\",\"M\"+Q.xmin+\",\"+(W-M)+\"h-4v\"+2*M+\"h4ZM\"+(Q.xmax-1)+\",\"+(W-M)+\"h4v\"+2*M+\"h-4Z\")):\"v\"===o?((Q=E?m(T,[s,at],[l,at]):[[s,W],[s,at],[l,at],[l,W]]).xmin=Math.min(s,l),Q.xmax=Math.max(s,l),Q.ymin=E?at:Math.min(W,at),Q.ymax=E?at:Math.max(W,at),dt.attr(\"d\",\"M\"+(Y-M)+\",\"+Q.ymin+\"v-4h\"+2*M+\"v4ZM\"+(Y-M)+\",\"+(Q.ymax-1)+\"v4h\"+2*M+\"v-4Z\")):\"d\"===o&&((Q=E?m(T,[Y,W],[it,at]):[[Y,W],[Y,at],[it,at],[it,W]]).xmin=Math.min(Y,it),Q.xmax=Math.max(Y,it),Q.ymin=Math.min(W,at),Q.ymax=Math.max(W,at),dt.attr(\"d\",\"M0,0Z\"))}else c&&(Z.addPt([it,at]),Q=Z.filtered);i.selectionDefs&&i.selectionDefs.length?(K=function(t,e,r){if(r)return n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions;return n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,Q,ut),Q.subtract=ut,J=R(i.selectionDefs.concat([Q]))):(K=[Q],J=S(Q)),g(q(K,x),ft,i),w&&b.throttle(gt,k.SELECTDELAY,(function(){var t;mt=[];var e,r=[];for($=0;$<vt.length;$++)if(e=(tt=vt[$])._module.selectPoints(tt,J),r.push(e),t=V(e,tt),mt.length)for(var n=0;n<t.length;n++)mt.push(t[n]);else mt=t;U(C,vt,et={points:mt}),pt(et,Q,Z),i.gd.emit(\"plotly_selecting\",et)}))},i.clickFn=function(t,e){if(dt.remove(),C._fullLayout._activeShapeIndex>=0)C._fullLayout._deactivateShape(C);else if(!_){var r=O.clickmode;b.done(gt).then((function(){if(b.clear(gt),2===t){for(ft.remove(),$=0;$<vt.length;$++)(tt=vt[$])._module.selectPoints(tt,!1);U(C,vt),B(i),C.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&z(e,C,i.xaxes,i.yaxes,i.subplot,i,ft),\"event\"===r&&C.emit(\"plotly_selected\",void 0);s.click(C,e)})).catch(y.error)}},i.doneFn=function(){dt.remove(),b.done(gt).then((function(){b.clear(gt),i.gd.emit(\"plotly_selected\",et),Q&&i.selectionDefs&&(Q.subtract=ut,i.selectionDefs.push(Q),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,K)),i.doneFnCompleted&&i.doneFnCompleted(mt)})).catch(y.error),_&&B(i)}},clearSelect:E,clearSelectionsCache:B,selectOnClick:z}},{\"../../components/color\":643,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../components/shapes/draw_newshape/display_outlines\":728,\"../../components/shapes/draw_newshape/helpers\":729,\"../../components/shapes/draw_newshape/newshapes\":730,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/polygon\":790,\"../../lib/throttle\":804,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"./axis_ids\":831,\"./constants\":834,\"./handle_outline\":838,\"./helpers\":839,polybooljs:517}],848:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=o.cleanNumber,l=o.ms2DateTime,c=o.dateTime2ms,u=o.ensureNumber,f=o.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),p=h.FP_SAFE,d=h.BADNUM,g=h.LOG_CLIP,m=h.ONEWEEK,v=h.ONEDAY,y=h.ONEHOUR,x=h.ONEMIN,b=h.ONESEC,_=t(\"./axis_ids\"),w=t(\"./constants\"),T=w.HOUR_PATTERN,k=w.WEEKDAY_PATTERN;function M(t){return Math.pow(10,t)}function A(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function S(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*g*Math.abs(n-i))}return d}function E(e,r,n,i){if((i||{}).msUTC&&a(e))return+e;var s=c(e,n||t.calendar);if(s===d){if(!a(e))return d;e=+e;var l=Math.floor(10*o.mod(e+.05,1)),u=Math.round(e-l/10);s=c(new Date(u))+l/10}return s}function C(e,r,n){return l(e,r,n||t.calendar)}function L(e){return t._categories[Math.round(e)]}function I(e){if(A(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return d}function P(e){if(t._categoriesMap)return t._categoriesMap[e]}function z(t){var e=P(t);return void 0!==e?e:a(t)?+t:void 0}function O(t){return a(t)?+t:P(t)}function D(t,e,r){return n.round(r+e*t,2)}function R(t,e,r){return(t-r)/e}var F=function(e){return a(e)?D(e,t._m,t._b):d},B=function(e){return R(e,t._m,t._b)};if(t.rangebreaks){var N=\"y\"===h;F=function(e){if(!a(e))return d;var r=t._rangebreaks.length;if(!r)return D(e,t._m,t._b);var n=N;t.range[0]>t.range[1]&&(n=!n);for(var i=n?-1:1,o=i*e,s=0,l=0;l<r;l++){var c=i*t._rangebreaks[l].min,u=i*t._rangebreaks[l].max;if(o<c)break;if(!(o>u)){s=o<(c+u)/2?l:l+1;break}s=l+1}var f=t._B[s]||0;return isFinite(f)?D(e,t._m2,f):0},B=function(e){var r=t._rangebreaks.length;if(!r)return R(e,t._m,t._b);for(var n=0,i=0;i<r&&!(e<t._rangebreaks[i].pmin);i++)e>t._rangebreaks[i].pmax&&(n=i+1);return R(e,t._m2,t._B[n])}}t.c2l=\"log\"===t.type?S:u,t.l2c=\"log\"===t.type?M:u,t.l2p=F,t.p2l=B,t.c2p=\"log\"===t.type?function(t,e){return F(S(t,e))}:F,t.p2c=\"log\"===t.type?function(t){return M(B(t))}:B,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=s,t.c2d=t.c2r=t.l2d=t.l2r=u,t.d2p=t.r2p=function(e){return t.l2p(s(e))},t.p2d=t.p2r=B,t.cleanPos=u):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return S(s(t),e)},t.r2d=t.r2c=function(t){return M(s(t))},t.d2c=t.r2l=s,t.c2d=t.l2r=u,t.c2r=S,t.l2d=M,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return M(B(t))},t.r2p=function(e){return t.l2p(s(e))},t.p2r=B,t.cleanPos=u):\"date\"===t.type?(t.d2r=t.r2d=o.identity,t.d2c=t.r2c=t.d2l=t.r2l=E,t.c2d=t.c2r=t.l2d=t.l2r=C,t.d2p=t.r2p=function(e,r,n){return t.l2p(E(e,0,n))},t.p2d=t.p2r=function(t,e,r){return C(B(t),e,r)},t.cleanPos=function(e){return o.cleanDate(e,d,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=I,t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=O(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=u,t.r2l=O,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:u(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=z(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=P,t.l2r=t.c2r=u,t.r2l=z,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:u(t)},t.setupMultiCategory=function(n){var i,a,s=t._traceIndices,l=t._matchGroup;if(l&&0===t._categories.length)for(var c in l)if(c!==r){var u=e[_.id2name(c)];s=s.concat(u._traceIndices)}var p=[[0,{}],[0,{}]],d=[];for(i=0;i<s.length;i++){var g=n[s[i]];if(h in g){var m=g[h],v=g._length||o.minRowLength(m);if(f(m[0])&&f(m[1]))for(a=0;a<v;a++){var y=m[0][a],x=m[1][a];A(y)&&A(x)&&(d.push([y,x]),y in p[0][1]||(p[0][1][y]=p[0][0]++),x in p[1][1]||(p[1][1][x]=p[1][0]++))}}}for(d.sort((function(t,e){var r=p[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=p[1][1];return i[t[1]]-i[e[1]]})),i=0;i<d.length;i++)I(d[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,i,s=o.nestedProperty(t,e).get();if(i=(i=\"date\"===t.type?o.dfltRange(t.calendar):\"y\"===h?w.DFLTRANGEY:r.dfltRange||w.DFLTRANGEX).slice(),\"tozero\"!==t.rangemode&&\"nonnegative\"!==t.rangemode||(i[0]=0),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=o.cleanDate(s[0],d,t.calendar),s[1]=o.cleanDate(s[1],d,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!o.isDateTime(s[n],t.calendar)){t[e]=i;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=o.constrain(t.r2l(s[0]),o.MIN_MS+1e3,o.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!a(s[n])){if(!a(s[1-n])){t[e]=i;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-p?s[n]=-p:s[n]>p&&(s[n]=p),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else o.nestedProperty(t,e).set(i)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=_.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s,l,c=t.r2l(t[a][0],o),u=t.r2l(t[a][1],o),f=\"y\"===h;if((f?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks)&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var p=f;c>u&&(p=!p),p&&t._rangebreaks.reverse();var d=p?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(f?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=F(l.min),l.pmax=F(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.maskBreaks=function(e){for(var r,n,i,a,l,c=t.rangebreaks||[],u=0;u<c.length;u++){var f=c[u];if(f.enabled)if(f.bounds){var h=f.pattern;switch(n=(r=o.simpleMap(f.bounds,h?s:t.d2c))[0],i=r[1],h){case k:a=(l=new Date(e)).getUTCDay(),n>i&&(i+=7,a<n&&(a+=7));break;case T:a=(l=new Date(e)).getUTCHours()+(l.getUTCMinutes()/60+l.getUTCSeconds()/3600+l.getUTCMilliseconds()/36e5),n>i&&(i+=24,a<n&&(a+=24));break;case\"\":a=e}if(a>=n&&a<i)return d}else for(var p=o.simpleMap(f.values,t.d2c).sort(o.sorterAsc),g=0;g<p.length;g++)if(i=(n=p[g])+f.dvalue,e>=n&&e<i)return d}return e},t.locateBreaks=function(e,r){var n,i,a,l,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort((function(t,e){return t.pattern===k&&e.pattern===T?-1:e.pattern===k&&t.pattern===T?1:0})),f=function(t,n){if((t=o.constrain(t,e,r))!==(n=o.constrain(n,e,r))){for(var i=!0,a=0;a<c.length;a++){var s=c[a];t<s.max&&n>=s.min&&(t<s.min&&(s.min=t),n>s.max&&(s.max=n),i=!1)}i&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var h=u[n];if(h.enabled)if(h.bounds){var p=e,d=r;h.pattern&&(p=Math.floor(p)),a=(i=o.simpleMap(h.bounds,h.pattern?s:t.r2l))[0],l=i[1];var g,_,w=new Date(p);switch(h.pattern){case k:_=m,g=(l-a+(l<a?7:0))*v,p+=a*v-(w.getUTCDay()*v+w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;case T:_=v,g=(l-a+(l<a?24:0))*y,p+=a*y-(w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;default:p=Math.min(i[0],i[1]),g=_=(d=Math.max(i[0],i[1]))-p}for(var M=p;M<d;M+=_)f(M,M+g)}else for(var A=o.simpleMap(h.values,t.d2c),S=0;S<A.length;S++)f(a=A[S],l=a+h.dvalue)}return c.sort((function(t,e){return t.min-e.min})),c},t.makeCalcdata=function(e,r,n){var i,a,s,l,c=t.type,u=\"date\"===c&&e[r+\"calendar\"];if(r in e){if(i=e[r],l=e._length||o.minRowLength(i),o.isTypedArray(i)&&(\"linear\"===c||\"log\"===c)){if(l===i.length)return i;if(i.subarray)return i.subarray(0,l)}if(\"multicategory\"===c)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=P([i,a])}return r}(i,l);for(a=new Array(l),s=0;s<l;s++)a[s]=t.d2c(i[s],0,u,n)}else{var f=r+\"0\"in e?t.d2c(e[r+\"0\"],0,u):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(i=e[{x:\"y\",y:\"x\"}[r]],l=e._length||i.length,a=new Array(l),s=0;s<l;s++)a[s]=f+s*h}if(t.rangebreaks)for(s=0;s<l;s++)a[s]=t.maskBreaks(a[s]);return a},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&a(t.r2l(e[0]))&&a(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t._emptyCategories=function(){t._categories=[],t._categoriesMap={}},t.clearCalc=function(){var r=t._matchGroup;if(r){var n=null,i=null;for(var a in r){var o=e[_.id2name(a)];if(o._categories){n=o._categories,i=o._categoriesMap;break}}n&&i?(t._categories=n,t._categoriesMap=i):t._emptyCategories()}else t._emptyCategories();if(t._initialCategories)for(var s=0;s<t._initialCategories.length;s++)I(t._initialCategories[s])},t.sortByInitialCategories=function(){var n=[];if(t._emptyCategories(),t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)I(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[_.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var j=e._d3locale;\"date\"===t.type&&(t._dateFormat=j?j.timeFormat:i,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=j?j.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./axis_ids\":831,\"./constants\":834,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],849:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").contrast,a=t(\"./layout_attributes\"),o=t(\"../array_container_defaults\");function s(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter((function(e){return void 0!==t[e]}));if(e.every((function(r){return t[r]===t[e[0]]}))||1===e.length)return t[e[0]]}function l(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,c,u,f){f&&1!==f.pass||function(t,e,r,n,i){var a=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,u),f&&2!==f.pass||function(t,e,r,c,u){var f=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",f);r(\"ticksuffix\",u.tickSuffixDflt)&&r(\"showticksuffix\",f);if(r(\"showticklabels\")){var h=u.font||{},p=e.color,d=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")?i(u.bgColor):p&&p!==a.color.dflt?p:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:d}),r(\"tickangle\"),\"category\"!==c){var g=r(\"tickformat\");o(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:l}),e.tickformatstops.length||delete e.tickformatstops,g||\"date\"===c||(r(\"showexponent\",f),r(\"exponentformat\"),r(\"minexponent\"),r(\"separatethousands\"))}}}(t,e,r,c,u)}},{\"../../components/color\":643,\"../../lib\":778,\"../array_container_defaults\":823,\"./layout_attributes\":842}],850:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":778,\"./layout_attributes\":842}],851:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){function o(r){var n=t[r];return void 0!==n?n:(e._template||{})[r]}var s=o(\"tick0\"),l=o(\"dtick\"),c=o(\"tickvals\"),u=r(\"tickmode\",i(c)?\"array\":l?\"linear\":\"auto\");if(\"auto\"===u)r(\"nticks\");else if(\"linear\"===u){var f=e.dtick=n.dtick(l,a);e.tick0=n.tick0(s,a,e.calendar,f)}else if(\"multicategory\"!==a){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"../../lib\":778,\"./clean_ticks\":833}],852:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"./axes\");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,f,h,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push((function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr0&&(r[o._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[s._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}()})),f=Date.now(),p=window.requestAnimationFrame((function n(){h=Date.now();for(var a=Math.min(1,(h-f)/r.duration),o=d(a),s=0;s<e.length;s++)m(e[s],o);h-f>r.duration?(!function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr1&&(r[o._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[s._name+\".range\"]=a.yr1.slice())}u&&u(),i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)})),Promise.resolve()}function g(t){var e=t.xaxis,r=t.yaxis;c._defs.select(\"#\"+t.clipId+\"> rect\").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(o.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function m(e,r){var n=e.plotinfo,i=n.xaxis,l=n.yaxis,c=i._length,u=l._length,f=!!e.xr1,h=!!e.yr1,p=[];if(f){var d=a.simpleMap(e.xr0,i.r2l),g=a.simpleMap(e.xr1,i.r2l),m=d[1]-d[0],v=g[1]-g[0];p[0]=(d[0]*(1-r)+r*g[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*v/m),i.range[0]=i.l2r(d[0]*(1-r)+r*g[0]),i.range[1]=i.l2r(d[1]*(1-r)+r*g[1])}else p[0]=0,p[2]=c;if(h){var y=a.simpleMap(e.yr0,l.r2l),x=a.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=i.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,i,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[i._id,l._id]);var w=f?c/p[2]:1,T=h?u/p[3]:1,k=f?p[0]:0,M=h?p[1]:0,A=f?p[0]/p[2]*c:0,S=h?p[1]/p[3]*u:0,E=i._offset-A,C=l._offset-S;n.clipRect.call(o.setTranslate,k,M).call(o.setScale,1/w,1/T),n.plot.call(o.setTranslate,E,C).call(o.setScale,w,T),o.setPointGroupScale(n.zoomScalePts,1/w,1/T),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/T)}s.redrawComponents(t)}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./axes\":828,d3:169}],853:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){r(\"autotypenumbers\",s.autotypenumbersDflt),\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r,s=t._id,l=s.charAt(0);-1!==s.indexOf(\"scene\")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,s,l);if(!c)return;if(\"histogram\"===c.type&&l==={v:\"y\",h:\"x\"}[c.orientation||\"v\"])return void(t.type=\"linear\");var u=l+\"calendar\",f=c[u],h={noMultiCategory:!n(c,\"cartesian\")||n(c,\"noMultiCategory\")};\"box\"===c.type&&c._hasPreCompStats&&l==={h:\"x\",v:\"y\"}[c.orientation||\"v\"]&&(h.noMultiCategory=!0);if(h.autotypenumbers=t.autotypenumbers,o(c,l)){var p=a(c),d=[];for(r=0;r<e.length;r++){var g=e[r];n(g,\"box-violin\")&&(g[l+\"axis\"]||l)===s&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==f&&(f=void 0))}t.type=i(d,f,h)}else if(\"splom\"===c.type){var m=c.dimensions[c._axesDim[s]];m.visible&&(t.type=i(m.values,f,h))}else t.type=i(c[l]||[c[l+\"0\"]],f,h)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":911,\"./axis_autotype\":829}],854:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,(function(t,e,n){r.push({type:\"layout\",prop:t,value:n})}),\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,(function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var f=0;f<a.length;f++)o[f]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})}),\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach((function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}}))}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],f=0;f<u.length;f++)t._internalOn(u[f],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var f=r.computeAPICommandBindings(t,c,u);if(1!==f.length)return!1;if(a){if((s=f[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var h=0;h<a.traces.length;h++)if(a.traces[h]!==s.traces[h])return!1}else if(s.prop!==a.prop)return!1}else a=f[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=f[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch((function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)}))},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":778,\"../registry\":911}],855:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}var c=r(\"domain.x\",i),u=r(\"domain.y\",a);c[0]<c[1]||(t.domain.x=i.slice()),u[0]<u[1]||(t.domain.y=a.slice())}},{\"../lib/extend\":768}],856:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],857:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],858:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],859:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../components/fx\"),u=t(\"../plots\"),f=t(\"../cartesian/axes\"),h=t(\"../cartesian/autorange\").getAutoRange,p=t(\"../../components/dragelement\"),d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").selectOnClick,v=t(\"./zoom\"),y=t(\"./constants\"),x=t(\"../../lib/geo_location_utils\"),b=t(\"../../lib/topojson_utils\"),_=t(\"topojson-client\").feature;function w(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var T=w.prototype;function k(t,e){var r=y.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}e.exports=function(t){return new w(t)},T.plot=function(t,e,r){var n=this,i=e[this.id],a=[],o=!1;for(var s in y.layerNameToAdjective)if(\"frame\"!==s&&i[\"show\"+s]){o=!0;break}for(var l=0;l<t.length;l++)if(t[0][0].trace.locationmode){o=!0;break}if(o){var c=b.getTopojsonName(i);null!==n.topojson&&c===n.topojsonName||(n.topojsonName=c,void 0===PlotlyGeoAssets.topojson[n.topojsonName]&&a.push(n.fetchTopojson()))}a=a.concat(x.fetchTraceGeoData(t)),r.push(new Promise((function(r,i){Promise.all(a).then((function(){n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e),r()})).catch(i)})))},T.fetchTopojson=function(){var t=this,e=b.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise((function(r,i){n.json(e,(function(n,a){if(n)return 404===n.status?i(new Error([\"plotly.js could not find topojson file at\",e,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):i(new Error([\"unexpected error while fetching topojson file at\",e].join(\" \")));PlotlyGeoAssets.topojson[t.topojsonName]=a,r()}))}))},T.update=function(t,e){var r=e[this.id];this.hasChoropleth=!1;for(var n=0;n<t.length;n++){var i=t[n],a=i[0].trace;\"choropleth\"===a.type&&(this.hasChoropleth=!0),!0===a.visible&&a._length>0&&a._module.calcGeoJSON(i,e)}if(!this.updateProjection(t,e)){this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),u.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var o=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=o.selectAll(\".point\"),this.dataPoints.text=o.selectAll(\"text\"),this.dataPaths.line=o.selectAll(\".js-line\");var s=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=s.selectAll(\"path\"),this.render()}},T.updateProjection=function(t,e){var r=this.graphDiv,o=e[this.id],s=e._size,l=o.domain,c=o.projection,u=o.lonaxis,f=o.lataxis,p=u._ax,d=f._ax,g=this.projection=function(t){for(var e=t.projection.type,r=n.geo[y.projNames[e]](),i=t._isClipped?y.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(y.precision),i&&r.clipAngle(i-y.clipPad);return r}(o),m=[[s.l+s.w*l.x[0],s.t+s.h*(1-l.y[1])],[s.l+s.w*l.x[1],s.t+s.h*(1-l.y[0])]],v=o.center||{},x=c.rotation||{},b=u.range||[],_=f.range||[];if(o.fitbounds){p._length=m[1][0]-m[0][0],d._length=m[1][1]-m[0][1],p.range=h(r,p),d.range=h(r,d);var w=(p.range[0]+p.range[1])/2,T=(d.range[0]+d.range[1])/2;if(o._isScoped)v={lon:w,lat:T};else if(o._isClipped){v={lon:w,lat:T},x={lon:w,lat:T,roll:x.roll};var M=c.type,A=y.lonaxisSpan[M]/2||180,S=y.lataxisSpan[M]/2||90;b=[w-A,w+A],_=[T-S,T+S]}else v={lon:w,lat:T},x={lon:w,lat:x.lat,roll:x.roll}}g.center([v.lon-x.lon,v.lat-x.lat]).rotate([-x.lon,-x.lat,x.roll]).parallels(c.parallels);var E=k(b,_);g.fitExtent(m,E);var C=this.bounds=g.getBounds(E),L=this.fitScale=g.scale(),I=g.translate();if(!isFinite(C[0][0])||!isFinite(C[0][1])||!isFinite(C[1][0])||!isFinite(C[1][1])||isNaN(I[0])||isNaN(I[0])){for(var P=[\"fitbounds\",\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],z=\"Invalid geo settings, relayout'ing to default view.\",O={},D=0;D<P.length;D++)O[this.id+\".\"+P[D]]=null;return this.viewInitial=null,a.warn(z),r._promises.push(i.call(\"relayout\",r,O)),z}if(o.fitbounds){var R=g.getBounds(k(p.range,d.range)),F=Math.min((C[1][0]-C[0][0])/(R[1][0]-R[0][0]),(C[1][1]-C[0][1])/(R[1][1]-R[0][1]));isFinite(F)?g.scale(F*L):a.warn(\"Something went wrong during\"+this.id+\"fitbounds computations.\")}else g.scale(c.scale*L);var B=this.midPt=[(C[0][0]+C[1][0])/2,(C[0][1]+C[1][1])/2];if(g.translate([I[0]+(B[0]-I[0]),I[1]+(B[1]-I[1])]).clipExtent(C),o._isAlbersUsa){var N=g([v.lon,v.lat]),j=g.translate();g.translate([j[0]-(N[0]-j[0]),j[1]-(N[1]-j[1])])}},T.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,o=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function u(t){return Boolean(y.lineLayers[t])}function h(t){return Boolean(y.fillLayers[t])}var p=(this.hasChoropleth?y.layersForChoropleth:y.layers).filter((function(t){return u(t)||h(t)?e[\"show\"+t]:!c(t)||e[t].showgrid})),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each((function(t){delete a[t],delete o[t],n.select(this).remove()})),d.enter().append(\"g\").attr(\"class\",(function(t){return\"layer \"+t})).each((function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):u(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):h(t)&&(o[t]=e.append(\"path\").style(\"stroke\",\"none\"))})),d.order(),d.each((function(r){var n=o[r],a=y.layerNameToAdjective[r];\"frame\"===r?n.datum(y.sphereSVG):u(r)||h(r)?n.datum(_(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=y.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};f.setConvert(l,r);var c=f.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var u=c.length,h=new Array(u),p=0;p<u;p++)for(var d=c[p].x,g=h[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)g.push(a(d,m));return{type:\"MultiLineString\",coordinates:h}}(r,e,t)).call(s.stroke,e[r].gridcolor).call(l.dashLine,\"\",e[r].gridwidth),u(r)?n.call(s.stroke,e[a+\"color\"]).call(l.dashLine,\"\",e[a+\"width\"]):h(r)&&n.call(s.fill,e[a+\"color\"])}))},T.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,o=r[1][0]-i+n,c=r[1][1]-a+n;l.setRect(this.clipRect,i,a,o,c),this.bgRect.call(l.setRect,i,a,o,c).call(s.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=o,this.yaxis._offset=a,this.yaxis._length=c},T.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,l=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[h([e.xmin,e.ymin]),h([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(h)});var f={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(t){2===t&&g(a)}};\"pan\"===s?(o.node().onmousedown=null,o.call(v(r,e)),o.on(\"dblclick.zoom\",(function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)})),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),f.prepFn=function(t,e,r){d(t,e,r,f,s)},p.init(f)),o.on(\"mousemove\",(function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return p.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},c.hover(a,n.event,r.id)})),o.on(\"mouseout\",(function(){a._dragging||p.unhover(a,n.event)})),o.on(\"click\",(function(){\"select\"!==s&&\"lasso\"!==s&&(l.indexOf(\"select\")>-1&&m(n.event,a,[r.xaxis],[r.yaxis],r.id,f),l.indexOf(\"event\")>-1&&c.click(a,n.event))}))}function h(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},T.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(l.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},f.setConvert(t.mockAxis,r)},T.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,i=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,\"projection.scale\":n.scale},e=t._isScoped?{\"center.lon\":r.lon,\"center.lat\":r.lat}:t._isClipped?{\"projection.rotation.lon\":i.lon,\"projection.rotation.lat\":i.lat}:{\"center.lon\":r.lon,\"center.lat\":r.lat,\"projection.rotation.lon\":i.lon},a.extendFlat(this.viewInitial,e)},T.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?o(r[0],r[1]):null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",(function(t){return r(t.geojson)}));for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"../plots\":891,\"./constants\":858,\"./projections\":863,\"./zoom\":864,d3:169,\"topojson-client\":579}],860:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l.geo={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.geo,s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots.geo,n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots.geo||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.framework.remove(),s.clipDef.remove())}}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./geo\":859,\"./layout_attributes\":861,\"./layout_defaults\":862}],861:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),fitbounds:{valType:\"enumerated\",values:[!1,\"locations\",\"geojson\"],dflt:!1,editType:\"plot\"},resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},visible:{valType:\"boolean\",dflt:!0},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../plot_api/edit_types\":810,\"../domain\":855,\"./constants\":858}],862:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../get_data\").getSubplotData,o=t(\"./constants\"),s=t(\"./layout_attributes\"),l=o.axesNames;function c(t,e,r,i){var s=a(i.fullData,\"geo\",i.id).map((function(t){return t._expandedIndex})),c=r(\"resolution\"),u=r(\"scope\"),f=o.scopeDefaults[u],h=r(\"projection.type\",f.projType),p=e._isAlbersUsa=\"albers usa\"===h;p&&(u=e.scope=\"usa\");var d=e._isScoped=\"world\"!==u,g=e._isConic=-1!==h.indexOf(\"conic\"),m=e._isClipped=!!o.lonaxisSpan[h];if(!1===t.visible){var v=n.extendDeep({},e._template);v.showcoastlines=!1,v.showcountries=!1,v.showframe=!1,v.showlakes=!1,v.showland=!1,v.showocean=!1,v.showrivers=!1,v.showsubunits=!1,v.lonaxis&&(v.lonaxis.showgrid=!1),v.lataxis&&(v.lataxis.showgrid=!1),e._template=v}for(var y=r(\"visible\"),x=0;x<l.length;x++){var b,_=l[x],w=[30,10][x];if(d)b=f[_+\"Range\"];else{var T=o[_+\"Span\"],k=(T[h]||T[\"*\"])/2,M=r(\"projection.rotation.\"+_.substr(0,3),f.projRotate[x]);b=[M-k,M+k]}var A=r(_+\".range\",b);r(_+\".tick0\"),r(_+\".dtick\",w),r(_+\".showgrid\",!!y&&void 0)&&(r(_+\".gridcolor\"),r(_+\".gridwidth\")),e[_]._ax={type:\"linear\",_id:_.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:A.slice(),_m:1,_input:{}}}var S=e.lonaxis.range,E=e.lataxis.range,C=S[0],L=S[1];C>0&&L<0&&(L+=360);var I,P,z,O=(C+L)/2;if(!p){var D=d?f.projRotate:[O,0,0];I=r(\"projection.rotation.lon\",D[0]),r(\"projection.rotation.lat\",D[1]),r(\"projection.rotation.roll\",D[2]),r(\"showcoastlines\",!d&&y)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\",!!y&&void 0)&&r(\"oceancolor\")}(p?(P=-96.6,z=38.7):(P=d?O:I,z=(E[0]+E[1])/2),r(\"center.lon\",P),r(\"center.lat\",z),g)&&r(\"projection.parallels\",f.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\",!!y&&void 0)&&r(\"landcolor\"),r(\"showlakes\",!!y&&void 0)&&r(\"lakecolor\"),r(\"showrivers\",!!y&&void 0)&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",d&&\"usa\"!==u&&y)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===u||\"north america\"===u&&50===c)&&(r(\"showsubunits\",y),r(\"subunitcolor\"),r(\"subunitwidth\")),d||r(\"showframe\",y)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\"),r(\"fitbounds\")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):m?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}e.exports=function(t,e,r){i(t,e,r,{type:\"geo\",attributes:s,handleDefaults:c,fullData:r,partition:\"y\"})}},{\"../../lib\":778,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":858,\"./layout_attributes\":861}],863:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map((function(t){return r(t,n)}))};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map((function(t){return e(t,r)}))}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach((function(r){!function(t){if((e=t.length)<4)return!1;var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];for(;++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])})),e.forEach((function(e){var r=e[0];t.some((function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],f=t[s],h=f[0],p=f[1];u>n^p>n&&r<(h-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0}))||t.push([e])})),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var f=1e-6,h=Math.PI,p=h/2,d=(Math.sqrt(h),h/180),g=180/h;function m(t){return t>1?p:t<-1?-p:Math.asin(t)}function v(t){return t>1?0:t<-1?h:Math.acos(t)}var y=t.geo.projection,x=t.geo.projectionMutator;function b(t,e){var r=(2+p)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>f;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(h*(4+h))*t*(1+Math.cos(e)),2*Math.sqrt(h/(4+h))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-h,0],[0,p],[h,0]]],[[[-h,0],[0,-p],[h,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}function a(){r=n.map((function(t){return t.map((function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]}))}))}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],l=0,u=o.length;l<u;++l){var f=o[l];if(f[0][0]<=t&&t<f[1][0]&&f[0][1]<=a&&a<f[1][1]){var h=e.invert(t-e(s[l][1][0],0)[0],a);return h[0]+=s[l][1][0],c(i(h[0],h[1]),[t,a])?h:null}}});var o=t.geo.projection(i),s=o.stream;function l(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function c(t,e){return Math.abs(t[0]-e[0])<f&&Math.abs(t[1]-e[1])<f}return o.stream=function(e){var r=o.rotate(),i=s(e),a=(o.rotate([0,0]),s(e));return o.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=180*(p=n[0][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[o+e,s+e],[o+e,c-e],[u-e,c-e],[u-e,f+e]],30))}for(i=n[1].length-1;i>=0;--i){var p;o=180*(p=n[1][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[u-e,f-e],[u-e,c+e],[o+e,c+e],[o+e,s-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),a)},i},o.lobes=function(t){return arguments.length?(n=t.map((function(t){return t.map((function(t){return[[t[0][0]*h/180,t[0][1]*h/180],[t[1][0]*h/180,t[1][1]*h/180],[t[2][0]*h/180,t[2][1]*h/180]]}))})),a(),o):n.map((function(t){return t.map((function(t){return[[180*t[0][0]/h,180*t[0][1]/h],[180*t[1][0]/h,180*t[1][1]/h],[180*t[2][0]/h,180*t[2][1]/h]]}))}))},o},b.invert=function(t,e){var r=.5*e*Math.sqrt((4+h)/h),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(h*(4+h))*(1+i)),m((n+r*(i+2))/(2+p))]},(t.geo.eckert4=function(){return y(b)}).raw=b;var _=t.geo.azimuthalEqualArea.raw;function w(t,e){if(arguments.length<2&&(e=t),1===e)return _;if(e===1/0)return T;function r(r,n){var i=_(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=_.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function k(t,e){return[3*t/(2*h)*Math.sqrt(h*h/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(h/4+.4*e))]}function A(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>f&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=x(w),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=w,k.invert=function(t,e){return[2/3*h*t/Math.sqrt(h*h/3-e*e),e]},(t.geo.kavrayskiy7=function(){return y(k)}).raw=k,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*h]},(t.geo.miller=function(){return y(M)}).raw=M,A(h);var S=function(t,e,r){var n=A(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/p,Math.SQRT2,h);function E(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return y(S)}).raw=S,E.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>f&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return y(E)}).raw=E;var C=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function L(t,e){var r,n=Math.min(18,36*Math.abs(e)/h),i=Math.floor(n),a=n-i,o=(r=C[i])[0],s=r[1],l=(r=C[++i])[0],c=r[1],u=(r=C[Math.min(19,++i)])[0],f=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?p:-p)*(c+a*(f-s)/2+a*a*(f-2*c+s)/2)]}function I(t,e){return[t*Math.cos(e),e]}function P(t,e){var r,n=Math.cos(e),i=(r=v(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function z(t,e){var r=P(t,e);return[(r[0]+t/p)/2,(r[1]+e)/2]}C.forEach((function(t){t[1]*=1.0144})),L.invert=function(t,e){var r=e/p,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,f=2*(Math.abs(r)-s)/c,h=u/c,m=f*(1-h*f*(1-2*h*f));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var v,y=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],n-=(v=(e>=0?p:-p)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*g}while(Math.abs(v)>1e-12&&--y>0);break}}while(--a>=0);var x=C[a][0],b=C[a+1][0],_=C[Math.min(19,a+2)][0];return[t/(b+m*(_-x)/2+m*m*(_-2*b+x)/2),n*d]},(t.geo.robinson=function(){return y(L)}).raw=L,I.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return y(I)}).raw=I,P.invert=function(t,e){if(!(t*t+4*e*e>h*h+f)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),p=Math.sin(2*n),d=c*c,g=u*u,m=s*s,y=1-g*l*l,x=y?v(u*l)*Math.sqrt(a=1/y):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*m+x*u*l*d),T=a*(.5*o*p-2*x*c*s),k=.25*a*(p*s-x*c*g*o),M=a*(d*l+x*m*u),A=T*k-M*w;if(!A)break;var S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return y(P)}).raw=P,z.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,h=Math.sin(r),d=Math.cos(r/2),g=Math.sin(r/2),m=g*g,y=1-u*d*d,x=y?v(o*d)*Math.sqrt(a=1/y):a=0,b=.5*(2*x*o*g+r/p)-t,_=.5*(x*s+n)-e,w=.5*a*(u*m+x*o*d*c)+.5/p,T=a*(h*l/4-x*s*g),k=.125*a*(l*g-x*s*u*h),M=.5*a*(c*d+x*m*o)+.5,A=T*k-M*w,S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return y(z)}).raw=z}},{}],864:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function f(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],f={},h={};function p(t,e){f[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,f);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),h[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),p(\"fitbounds\",!1),o.emit(\"plotly_relayout\",h)}function h(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",(function(){n.select(this).style(l)})).on(\"zoom\",(function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})})).on(\"zoomend\",(function(){n.select(this).style(c),f(t,e,i)})),r}function p(t,e){var r,i,a,o,s,h,p,d,g,m=u(0,e);function v(t){return e.invert(t)}function y(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return m.on(\"zoomstart\",(function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=v(r)})).on(\"zoom\",(function(){if(h=n.mouse(this),function(t){var r=v(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>2||Math.abs(n[1]-t[1])>2}(r))return m.scale(e.scale()),void m.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?v(h)&&(d=v(h),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=v(r=h),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})})).on(\"zoomend\",(function(){n.select(this).style(c),g&&f(t,e,y)})),m}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),o=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),s=0,h=a.on;function p(t){s++||t({type:\"zoomstart\"})}function d(t){t({type:\"zoom\"})}function b(t){--s||t({type:\"zoomend\"})}function _(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",(function(){n.select(this).style(l);var t=n.mouse(this),s=e.rotate(),c=s,u=e.translate(),f=m(s);r=g(e,t),h.call(a,\"zoom\",(function(){var a=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,a)){e.rotate(s).translate(u);var l=g(e,a),h=y(r,l),p=T(v(f,h)),m=i.r=x(p,r,c);isFinite(m[0])&&isFinite(m[1])&&isFinite(m[2])||(m=c),e.rotate(m),c=m}}else r=g(e,t=a);d(o.of(this,arguments))})),p(o.of(this,arguments))})).on(\"zoomend\",(function(){n.select(this).style(c),h.call(a,\"zoom\",null),b(o.of(this,arguments)),f(t,e,_)})).on(\"zoom.redraw\",(function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})})),n.rebind(a,o,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function m(t){var e=.5*t[0]*o,r=.5*t[1]*o,n=.5*t[2]*o,i=Math.sin(e),a=Math.cos(e),s=Math.sin(r),l=Math.cos(r),c=Math.sin(n),u=Math.cos(n);return[a*l*u+i*s*c,i*l*u-a*s*c,a*s*u+i*l*c,a*l*c-i*s*u]}function v(t,e){var r=t[0],n=t[1],i=t[2],a=t[3],o=e[0],s=e[1],l=e[2],c=e[3];return[r*o-n*s-i*l-a*c,r*s+n*o+i*c-a*l,r*l-n*c+i*o+a*s,r*c+n*l-i*s+a*o]}function y(t,e){if(t&&e){var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(k(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,k(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}}function x(t,e,r){var n=w(e,2,t[0]);n=w(n,1,t[1]),n=w(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],f=n[1],h=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(f)>d?(a=(f>0?90:-90)-p,i=0):(a=Math.asin(f/d)*s-p,i=Math.sqrt(d*d-f*f));var g=180-a-2*p,m=(Math.atan2(h,u)-Math.atan2(c,i))*s,v=(Math.atan2(h,u)-Math.atan2(c,-i))*s;return b(r[0],r[1],a,m)<=b(r[0],r[1],g,v)?[a,m,r[2]]:[g,v,r[2]]}function b(t,e,r,n){var i=_(r-t),a=_(n-e);return Math.sqrt(i*i+a*a)}function _(t){return(t%360+540)%360-180}function w(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function T(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}function k(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?h:e._isClipped?d:p)(t,r)}},{\"../../lib\":778,\"../../registry\":911,d3:169}],865:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var f=0;f<t.length;f++)a=t[f],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":911,\"./cartesian/constants\":834}],866:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function f(e,n,i){var a,s,l=t.calcDataBox(),f=r.viewBox,h=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function m(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=f[3]-f[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var v=n/(f[2]-f[0])*(l[2]-l[0])+l[0],y=i/(f[3]-f[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=v,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=v,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(m(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(m(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(h-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,f),e.addEventListener(\"touchstart\",(function(t){var r=a(t.changedTouches[0],e);f(0,r[0],r[1]),f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchmove\",(function(t){t.preventDefault();var r=a(t.changedTouches[0],e);f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchend\",(function(t){f(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()}),!!s&&{passive:!1}),c.wheelListener=i(e,(function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),f=o/(a[2]-a[0])*(i[2]-i[0])+i[0],h=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-f)*l+f,i[2]=(i[2]-f)*l+f,i[1]=(i[1]-h)*l+h,i[3]=(i[3]-h)*l+h,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0}),!0),c}},{\"../cartesian/constants\":834,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486}],867:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,f,h,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),h=0;h<2;++h){var d=(e=s[h]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[h+p]=!1,this.labels[h+p]=n,this.labelColor[h+p]=i(r.title.font.color),this.labelFont[h+p]=r.title.font.family,this.labelSize[h+p]=r.title.font.size,this.labelPad[h+p]=this.getLabelPad(e,r),this.tickEnable[h+p]=!1,this.tickColor[h+p]=i((r.tickfont||{}).color),this.tickAngle[h+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[h+p]=this.getTickPad(r),this.tickMarkLength[h+p]=0,this.tickMarkWidth[h+p]=r.tickwidth||0,this.tickMarkColor[h+p]=i(r.tickcolor),this.borderLineEnable[h+p]=!1,this.borderLineColor[h+p]=i(r.linecolor),this.borderLineWidth[h+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,f=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[h]=!0:l&&(this.labelEnable[h+2]=!0),o?this.tickEnable[h]=r.showticklabels:l&&(this.tickEnable[h+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[h]=r.showline),(l||u)&&(this.borderLineEnable[h+2]=r.showline),(o||f)&&(this.tickMarkLength[h]=this.getTickMarkLength(r)),(l||f)&&(this.tickMarkLength[h+2]=this.getTickMarkLength(r)),this.gridLineEnable[h]=r.showgrid,this.gridLineColor[h]=i(r.gridcolor),this.gridLineWidth[h]=r.gridwidth,this.zeroLineEnable[h]=r.zeroline,this.zeroLineColor[h]=i(r.zerolinecolor),this.zeroLineWidth[h]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":802,\"../cartesian/axes\":828}],868:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d){var c=u(t,\"gl2d\",o);0===c.length&&(s._scene2d.destroy(),delete n._plots[o])}}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../plot_api/edit_types\":810,\"../cartesian\":841,\"../cartesian/attributes\":826,\"../cartesian/constants\":834,\"../get_data\":865,\"../layout_attributes\":882,\"./scene2d\":869}],869:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),f=t(\"webgl-context\"),h=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),m=g.enforce,v=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=t(\"../../components/dragelement/helpers\"),b=x.drawMode,_=x.selectMode,w=[\"xaxis\",\"yaxis\"],T=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function k(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=h(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=k;var M=k.prototype;M.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=f({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=f({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r);var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",(function(){l.isMouseOver=!1,l.unhover()})),o.addEventListener(\"mouseover\",(function(){l.isMouseOver=!0}))},M.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var f=document.createElement(\"canvas\");f.width=r,f.height=i;var h,p=f.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":h=f.toDataURL(\"image/jpeg\");break;case\"webp\":h=f.toDataURL(\"image/webp\");break;default:h=f.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),h},M.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},M.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},M.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(T),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},M.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},M.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},M.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},M.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map((function(e){t[e].dispose(),delete t[e]})),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},M.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};v(s,this.xaxis),v(s,this.yaxis);var l,c,u=r._size,f=this.xaxis.domain,h=this.yaxis.domain;for(o.viewBox=[u.l+f[0]*u.w,u.b+h[0]*u.h,i-u.r-(1-f[1])*u.w,a-u.t-(1-h[1])*u.h],this.mouseContainer.style.width=u.w*(f[1]-f[0])+\"px\",this.mouseContainer.style.height=u.h*(h[1]-h[0])+\"px\",this.mouseContainer.height=u.h*(h[1]-h[0]),this.mouseContainer.style.left=u.l+f[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-h[1])*u.h+\"px\",c=0;c<2;++c)(l=this[w[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();m(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},M.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},M.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},M.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort((function(t,e){return t._trace.index-e._trace.index}))},M.updateFx=function(t){_(t)||b(t)?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},M.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},M.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var f=i._size,h=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+f.l+h[0]*f.w,l/t.pixelRatio-(f.t+(1-p[1])*f.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var m=this.fullData[g.trace.index]||{},v=g.pointIndex,y=s.castHoverinfo(m,i,v);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(m,v,\"bgcolor\")||g.color,borderColor:s.castHoverOption(m,v,\"bordercolor\"),fontFamily:s.castHoverOption(m,v,\"font.family\"),fontSize:s.castHoverOption(m,v,\"font.size\"),fontColor:s.castHoverOption(m,v,\"font.color\"),nameLength:s.castHoverOption(m,v,\"namelength\"),textAlign:s.castHoverOption(m,v,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},M.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},M.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib/show_no_webgl_msg\":800,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/constants\":834,\"../cartesian/constraints\":835,\"./camera\":866,\"./convert\":867,\"gl-plot2d\":317,\"gl-select-box\":333,\"gl-spikes2d\":342,\"webgl-context\":606}],870:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,f=c._scene;f||(f=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=f),f.viewInitial||(f.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),f.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../get_data\":865,\"./layout/attributes\":871,\"./layout/defaults\":875,\"./layout/layout_attributes\":876,\"./scene\":880}],871:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],872:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:{text:i.title.text,font:i.title.font},type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":643,\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],873:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,f;function h(t,e){return i.coerce(u,f,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(f=a.newContainer(e,d))._id=d[0]+r.scene,f._name=d,s(u,f,h,r),l(u,f,h,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,noTicklabelmode:!0,noTicklabelposition:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),h(\"gridcolor\",n(f.color,r.bgColor,13600/187).toRgbString()),h(\"title.text\",d[0]),f.setScale=i.noop,h(\"showspikes\")&&(h(\"spikesides\"),h(\"spikethickness\"),h(\"spikecolor\",f.color)),h(\"showaxeslabels\"),h(\"showbackground\")&&h(\"backgroundcolor\")}}},{\"../../../lib\":778,\"../../../plot_api/plot_template\":817,\"../../cartesian/axis_defaults\":830,\"../../cartesian/type_defaults\":853,\"./axis_attributes\":872,tinycolor2:576}],874:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":778,\"../../../lib/str2rgbarray\":802}],875:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData;function u(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),u=[\"up\",\"center\",\"eye\"],f=0;f<u.length;f++)r(\"camera.\"+u[f]+\".x\"),r(\"camera.\"+u[f]+\".y\"),r(\"camera.\"+u[f]+\".z\");r(\"camera.projection.type\");var h=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),p=r(\"aspectmode\",h?\"manual\":\"auto\");h||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===p&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var d=c(n.fullData,\"gl3d\",n.id);s(t,e,{font:n.font,scene:n.id,data:d,bgColor:l,calendar:n.calendar,autotypenumbersDflt:n.autotypenumbersDflt,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var g=n.getDfltFromLayout(\"dragmode\");if(!1!==g&&!g)if(g=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,v=t.camera.up.y,y=t.camera.up.z;0!==y&&(m&&v&&y?y/Math.sqrt(m*m+v*v+y*y)>.999&&(g=\"turntable\"):g=\"turntable\")}else g=\"turntable\";r(\"dragmode\",g),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:\"gl3d\",attributes:l,handleDefaults:u,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":643,\"../../../lib\":778,\"../../../registry\":911,\"../../get_data\":865,\"../../subplot_defaults\":905,\"./axis_defaults\":873,\"./layout_attributes\":876}],876:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":778,\"../../../lib/extend\":768,\"../../domain\":855,\"./axis_attributes\":872}],877:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":802}],878:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var f=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var h=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/h)}for(var p=n.calcTicks(u,{msUTC:!0}),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=f}}e.ticks=l;for(c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":778,\"../../cartesian/axes\":828}],879:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],880:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\"),o=a.createCamera,s=a.createScene,l=t(\"webgl-context\"),c=t(\"has-passive-events\"),u=t(\"../../registry\"),f=t(\"../../lib\"),h=f.preserveDrawingBuffer(),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../components/fx\"),g=t(\"../../lib/str2rgbarray\"),m=t(\"../../lib/show_no_webgl_msg\"),v=t(\"./project\"),y=t(\"./layout/convert\"),x=t(\"./layout/spikes\"),b=t(\"./layout/tick_marks\");function _(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=y(e,e[this.id]),this.spikeOptions=x(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=u.getComponentMethod(\"annotations3d\",\"draw\"),this.initializeGLPlot()}var w=_.prototype;w.prepareOptions=function(){var t={canvas:this.canvas,gl:this.gl,glOptions:{preserveDrawingBuffer:h,premultipliedAlpha:!0,antialias:!0},container:this.container,axes:this.axesOptions,spikes:this.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:this.camera,pixelRatio:this.pixelRatio};if(this.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");t.gl=i,t.canvas=n}return t};var T=!0;w.tryCreatePlot=function(){var t=this.prepareOptions(),e=!0;try{this.glplot=s(t)}catch(r){if(this.staticMode||!T||h)e=!1;else{f.warn([\"webgl setup failed possibly due to\",\"false preserveDrawingBuffer config.\",\"The mobile/tablet device may not be detected by is-mobile module.\",\"Enabling preserveDrawingBuffer in second attempt to create webgl scene...\"].join(\" \"));try{h=t.glOptions.preserveDrawingBuffer=!0,this.glplot=s(t)}catch(r){h=t.glOptions.preserveDrawingBuffer=!1,e=!1}}}return T=!1,e},w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},w.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return m(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+\".camera\"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+\".aspectratio\"]=t.glplot.getAspectratio(),\"manual\"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+\".aspectmode\"]=\"manual\")),e},i=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas&&(t.glplot.canvas.addEventListener(\"mouseup\",(function(){i(t)})),t.glplot.canvas.addEventListener(\"wheel\",(function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,a=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*a.x,y:n*a.y,z:n*a.z})}i(t)}}),!!c&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",(function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit(\"plotly_relayouting\",e)}})),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",(function(r){e&&e.emit&&e.emit(\"plotly_webglcontextlost\",{event:r,layer:t.id})}),!1)),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},w.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,i=e.container.getBoundingClientRect();r._fullLayout._calcInverseTransform(r);var a=r._fullLayout._invScaleX,o=r._fullLayout._invScaleY,s=i.width*a,l=i.height*o;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+s+\" \"+l),n.setAttributeNS(null,\"width\",s),n.setAttributeNS(null,\"height\",l),b(e),e.glplot.axes.update(e.axesOptions);for(var c,u=Object.keys(e.traces),h=null,g=e.glplot.selection,m=0;m<u.length;++m)\"skip\"!==(t=e.traces[u[m]]).data.hoverinfo&&t.handlePick(g)&&(h=t),t.setContourLevels&&t.setContourLevels();function y(t,r){var n=e.fullSceneLayout[t];return p.tickText(n,n.d2l(r),\"hover\").text}if(null!==h){var x=v(e.glplot.cameraParams,g.dataCoordinate);t=h.data;var _,w=r._fullData[t.index],T=g.index,k={xLabel:y(\"xaxis\",g.traceCoordinate[0]),yLabel:y(\"yaxis\",g.traceCoordinate[1]),zLabel:y(\"zaxis\",g.traceCoordinate[2])},M=d.castHoverinfo(w,e.fullLayout,T),A=(M||\"\").split(\"+\"),S=M&&\"all\"===M;w.hovertemplate||S||(-1===A.indexOf(\"x\")&&(k.xLabel=void 0),-1===A.indexOf(\"y\")&&(k.yLabel=void 0),-1===A.indexOf(\"z\")&&(k.zLabel=void 0),-1===A.indexOf(\"text\")&&(g.textLabel=void 0),-1===A.indexOf(\"name\")&&(h.name=void 0));var E=[];\"cone\"===t.type||\"streamtube\"===t.type?(k.uLabel=y(\"xaxis\",g.traceCoordinate[3]),(S||-1!==A.indexOf(\"u\"))&&E.push(\"u: \"+k.uLabel),k.vLabel=y(\"yaxis\",g.traceCoordinate[4]),(S||-1!==A.indexOf(\"v\"))&&E.push(\"v: \"+k.vLabel),k.wLabel=y(\"zaxis\",g.traceCoordinate[5]),(S||-1!==A.indexOf(\"w\"))&&E.push(\"w: \"+k.wLabel),k.normLabel=g.traceCoordinate[6].toPrecision(3),(S||-1!==A.indexOf(\"norm\"))&&E.push(\"norm: \"+k.normLabel),\"streamtube\"===t.type&&(k.divergenceLabel=g.traceCoordinate[7].toPrecision(3),(S||-1!==A.indexOf(\"divergence\"))&&E.push(\"divergence: \"+k.divergenceLabel)),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):\"isosurface\"===t.type||\"volume\"===t.type?(k.valueLabel=p.tickText(e._mockAxis,e._mockAxis.d2l(g.traceCoordinate[3]),\"hover\").text,E.push(\"value: \"+k.valueLabel),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):_=g.textLabel;var C={x:g.traceCoordinate[0],y:g.traceCoordinate[1],z:g.traceCoordinate[2],data:w._input,fullData:w,curveNumber:w.index,pointNumber:T};d.appendArrayPointValue(C,w,T),t._module.eventData&&(C=w._module.eventData(C,g,w,{},T));var L={points:[C]};e.fullSceneLayout.hovermode&&d.loneHover({trace:w,x:(.5+.5*x[0]/x[3])*s,y:(.5-.5*x[1]/x[3])*l,xLabel:k.xLabel,yLabel:k.yLabel,zLabel:k.zLabel,text:_,name:h.name,color:d.castHoverOption(w,T,\"bgcolor\")||h.color,borderColor:d.castHoverOption(w,T,\"bordercolor\"),fontFamily:d.castHoverOption(w,T,\"font.family\"),fontSize:d.castHoverOption(w,T,\"font.size\"),fontColor:d.castHoverOption(w,T,\"font.color\"),nameLength:d.castHoverOption(w,T,\"namelength\"),textAlign:d.castHoverOption(w,T,\"align\"),hovertemplate:f.castOption(w,T,\"hovertemplate\"),hovertemplateLabels:f.extendFlat({},C,k),eventData:[C]},{container:n,gd:r}),g.buttons&&g.distance<5?r.emit(\"plotly_click\",L):r.emit(\"plotly_hover\",L),c=L}else d.loneUnhover(n),r.emit(\"plotly_unhover\",c);e.drawAnnotations(e)},w.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):f.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")};requestAnimationFrame(e)};var k=[\"xaxis\",\"yaxis\",\"zaxis\"];function M(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=k[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],u=e[\"_\"+o+\"length\"];if(f.isArrayOrTypedArray(l))for(var h,p=0;p<(u||l.length);p++)if(f.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)h=s.d2l(l[p][d],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else h=s.d2l(l[p],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];this.fullLayout=e,this.fullSceneLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.setClearColor(g(c.bgcolor)),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&M(this,n,f);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=k[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,f);var h=[1,1,1];for(o=0;o<3;++o)f[1][o]===f[0][o]?h[o]=1:h[o]=1/(f[1][o]-f[0][o]);for(this.dataScale=h,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var p=Object.keys(this.traces);t:for(a=0;a<p.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===p[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[p[a]]).dispose(),delete this.traces[p[a]]}this.glplot.objects.sort((function(t,e){return t._trace.data.index-e._trace.data.index}));var d,m=[[0,0,0],[0,0,0]],v=[],y={};for(a=0;a<3;++a){if((l=(s=c[k[a]]).type)in y?(y[l].acc*=h[a],y[l].count+=1):y[l]={acc:h[a],count:1},s.autorange){m[0][a]=1/0,m[1][a]=-1/0;var x=this.glplot.objects,b=this.fullSceneLayout.annotations||[],_=s._name.charAt(0);for(o=0;o<x.length;o++){var w=x[o],T=w.bounds,A=w._trace.data._pad||0;\"ErrorBars\"===w.constructor.name&&s._lowerLogErrorBound?m[0][a]=Math.min(m[0][a],s._lowerLogErrorBound):m[0][a]=Math.min(m[0][a],T[0][a]/h[a]-A),m[1][a]=Math.max(m[1][a],T[1][a]/h[a]+A)}for(o=0;o<b.length;o++){var S=b[o];if(S.visible){var E=s.r2l(S[_]);m[0][a]=Math.min(m[0][a],E),m[1][a]=Math.max(m[1][a],E)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(m[0][a]=Math.min(m[0][a],0),m[1][a]=Math.max(m[1][a],0)),m[0][a]>m[1][a])m[0][a]=-1,m[1][a]=1;else{var C=m[1][a]-m[0][a];m[0][a]-=C/32,m[1][a]+=C/32}if(\"reversed\"===s.autorange){var L=m[0][a];m[0][a]=m[1][a],m[1][a]=L}}else{var I=s.range;m[0][a]=s.r2l(I[0]),m[1][a]=s.r2l(I[1])}m[0][a]===m[1][a]&&(m[0][a]-=1,m[1][a]+=1),v[a]=m[1][a]-m[0][a],this.glplot.setBounds(a,{min:m[0][a]*h[a],max:m[1][a]*h[a]})}var P=c.aspectmode;if(\"cube\"===P)d=[1,1,1];else if(\"manual\"===P){var z=c.aspectratio;d=[z.x,z.y,z.z]}else{if(\"auto\"!==P&&\"data\"!==P)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var O=[1,1,1];for(a=0;a<3;++a){var D=y[l=(s=c[k[a]]).type];O[a]=Math.pow(D.acc,1/D.count)/h[a]}d=\"data\"===P||Math.max.apply(null,O)/Math.min.apply(null,O)<=4?O:[1,1,1]}c.aspectratio.x=u.aspectratio.x=d[0],c.aspectratio.y=u.aspectratio.y=d[1],c.aspectratio.z=u.aspectratio.z=d[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z}),this.viewInitial.aspectmode||(this.viewInitial.aspectmode=c.aspectmode);var R=c.domain||null,F=e._size||null;if(R&&F){var B=this.container.style;B.position=\"absolute\",B.left=F.l+R.x[0]*F.w+\"px\",B.top=F.t+(1-R.y[1])*F.h+\"px\",B.width=F.w*(R.x[1]-R.x[0])+\"px\",B.height=F.h*(R.y[1]-R.y[0])+\"px\"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){var t;return this.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}},w.setViewport=function(t){var e,r=t.camera;this.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio),\"orthographic\"===r.projection.type!==this.camera._ortho&&(this.glplot.redraw(),this.glplot.clearRGBA(),this.glplot.dispose(),this.initializeGLPlot())},w.isCameraChanged=function(t){var e=this.getCamera(),r=f.nestedProperty(t,this.id+\".camera\").get();function n(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}var i=!1;if(void 0===r)i=!0;else{for(var a=0;a<3;a++)for(var o=0;o<3;o++)if(!n(e,r,a,o)){i=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(i=!0)}return i},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=f.nestedProperty(t,this.id+\".aspectratio\").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,i,a,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),h=l||c;if(h){var p={};if(l&&(e=this.getCamera(),n=(r=f.nestedProperty(t,this.id+\".camera\")).get(),p[this.id+\".camera\"]=n),c&&(i=this.glplot.getAspectratio(),o=(a=f.nestedProperty(t,this.id+\".aspectratio\")).get(),p[this.id+\".aspectratio\"]=o),u.call(\"_storeDirectGUIEdit\",t,s._preGUI,p),l)r.set(e),f.nestedProperty(s,this.id+\".camera\").set(e);if(c)a.set(i),f.nestedProperty(s,this.id+\".aspectratio\").set(i),this.glplot.redraw()}return h},w.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+\".camera.up\",h={x:0,y:0,z:1},p={};p[c]=h;var d=n.layout;u.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=h,f.nestedProperty(d,c).set(h)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a),function(t,e,r){for(var n=0,i=r-1;n<i;++n,--i)for(var a=0;a<e;++a)for(var o=0;o<4;++o){var s=4*(e*n+a)+o,l=4*(e*i+a)+o,c=t[s];t[s]=t[l],t[l]=c}}(a,r,i),function(t,e,r){for(var n=0;n<r;++n)for(var i=0;i<e;++i){var a=4*(e*n+i),o=t[a+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[a+l]=Math.min(s*t[a+l],255)}}(a,r,i);var o=document.createElement(\"canvas\");o.width=r,o.height=i;var s,l=o.getContext(\"2d\"),c=l.createImageData(r,i);switch(c.data.set(a),l.putImageData(c,0,0),t){case\"jpeg\":s=o.toDataURL(\"image/jpeg\");break;case\"webp\":s=o.toDataURL(\"image/webp\");break;default:s=o.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),s},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[k[t]];p.setConvert(e,this.fullLayout),e.setScale=f.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this._mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},p.setConvert(this._mockAxis,t)},e.exports=_},{\"../../components/fx\":683,\"../../lib\":778,\"../../lib/show_no_webgl_msg\":800,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout/convert\":874,\"./layout/spikes\":877,\"./layout/tick_marks\":878,\"./project\":879,\"gl-plot3d\":321,\"has-passive-events\":441,\"webgl-context\":606}],881:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],882:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"../components/shapes/draw_newshape/attributes\"),s=t(\"./pad_attributes\"),l=t(\"../lib/extend\").extendFlat,c=n({editType:\"calc\"});c.family.dflt='\"Open Sans\", verdana, arial, sans-serif',c.size.dflt=12,c.color.dflt=a.defaultLine,e.exports={font:c,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:l(s({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},uniformtext:{mode:{valType:\"enumerated\",values:[!1,\"hide\",\"show\"],dflt:!1,editType:\"plot\"},minsize:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},computed:{valType:\"any\",editType:\"none\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},newshape:o.newshape,activeshape:o.activeshape,meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:l({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":642,\"../components/shapes/draw_newshape/attributes\":725,\"../lib/extend\":768,\"./animation_attributes\":822,\"./font_attributes\":856,\"./pad_attributes\":890}],883:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.10.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.10.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],884:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":778}],885:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=i.strTranslate,o=i.strScale,s=t(\"../../plots/get_data\").getSubplotCalcData,l=t(\"../../constants/xmlns_namespaces\"),c=t(\"d3\"),u=t(\"../../components/drawing\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./mapbox\"),p=r.constants=t(\"./constants\");function d(t){return\"string\"==typeof t&&(-1!==p.styleValuesMapbox.indexOf(t)||0===t.indexOf(\"mapbox://\"))}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,a=e._subplots.mapbox;if(n.version!==p.requiredVersion)throw new Error(p.wrongVersionErrorMsg);var o=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;d(c.style)&&(u?i.pushUnique(n,u):(d(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var f=o?p.noAccessTokenErrorMsg:p.missingStyleErrorMsg;throw i.error(f),new Error(f)}return n.length?(n.length>1&&i.warn(p.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,a);n.accessToken=o;for(var l=0;l<a.length;l++){var c=a[l],u=s(r,\"mapbox\",c),f=e[c],g=f._subplot;g||(g=new h(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},f.center),zoom:f.zoom,bearing:f.bearing,pitch:f.pitch}),g.plot(u,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var s=e[r[i]],h=s.domain,d=s._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":d,x:n.l+n.w*h.x[0],y:n.t+n.h*(1-h.y[1]),width:n.w*(h.x[1]-h.x[0]),height:n.h*(h.y[1]-h.y[0]),preserveAspectRatio:\"none\"});var g=c.select(s._subplot.div);if(!(null===g.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var m=e._glimages.append(\"g\");m.attr(\"transform\",a(n.l+n.w*h.x[0]+10,n.t+n.h*(1-h.y[0])-31)),m.append(\"path\").attr(\"d\",p.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),m.append(\"path\").attr(\"d\",p.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"path\").attr(\"d\",p.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"polygon\").attr(\"points\",p.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var v=g.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),y=e._glimages.append(\"g\"),x=y.append(\"text\");x.text(v).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":v});var b=u.bBox(x.node()),_=n.w*(h.x[1]-h.x[0]);if(b.width>_/2){var w=v.split(\"|\").join(\"<br>\");x.text(w).attr(\"data-unformatted\",w).call(f.convertToTspans,t),b=u.bBox(x.node())}x.attr(\"transform\",a(-3,8-b.height)),y.insert(\"rect\",\".static-attribution\").attr({x:-b.width-6,y:-b.height-3,width:b.width+6,height:b.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var T=1;b.width+6>_&&(T=_/(b.width+6));var k=[n.l+n.w*h.x[1],n.t+n.h*(1-h.y[0])];y.attr(\"transform\",a(k[0],k[1])+o(T))}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/get_data\":865,\"./constants\":883,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./mapbox\":889,d3:169,\"mapbox-gl\":473}],886:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/svg_text_utils\").sanitizeHTML,a=t(\"./convert_text_opts\"),o=t(\"./constants\");function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{\"icon-image\":i.icon+\"-15\",\"icon-size\":i.iconsize/10,\"text-field\":i.text,\"text-size\":i.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":i.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":i.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||JSON.stringify(this.source)!==JSON.stringify(t.source)||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.lookupBelow=function(){return this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates});var e=this.findFollowingMapboxLayerId(this.lookupBelow());null!==e&&this.subplot.map.moveLayer(this.idLayer,e)},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",a.tileSize=256):\"image\"===r&&(e=\"url\",a.coordinates=t.coordinates);a[e]=n,t.sourceattribution&&(a.attribution=i(t.sourceattribution));return a}(t);e.addSource(this.idSource,r)}},l.findFollowingMapboxLayerId=function(t){if(\"traces\"===t)for(var e=this.subplot.getMapLayers(),r=0;r<e.length;r++){var n=e[r].id;if(\"string\"==typeof n&&0===n.indexOf(o.traceLayerPrefix)){t=n;break}}return t},l.updateLayer=function(t){var e=this.subplot,r=u(t),n=this.lookupBelow(),i=this.findFollowingMapboxLayerId(n);this.removeLayer(),c(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:r.layout,paint:r.paint},i),this.layerType=t.type,this.below=n},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},{\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./constants\":883,\"./convert_text_opts\":884}],887:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),f=o({});f.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:f,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../domain\":855,\"../font_attributes\":856,\"./constants\":883}],888:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":778,\"../array_container_defaults\":823,\"../subplot_defaults\":905,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../registry\"),s=t(\"../cartesian/axes\"),l=t(\"../../components/dragelement\"),c=t(\"../../components/fx\"),u=t(\"../../components/dragelement/helpers\"),f=u.rectMode,h=u.drawMode,p=u.selectMode,d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").clearSelectionsCache,v=t(\"../cartesian/select\").selectOnClick,y=t(\"./constants\"),x=t(\"./layers\");function b(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=b.prototype;_.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash={},i.layerList=[]),n=i.map?new Promise((function(r,n){i.updateMap(t,e,r,n)})):new Promise((function(r,n){i.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,i){var o=this,s=e[o.id],l=o.styleObj=T(s.style);o.accessToken=s.accesstoken;var c=o.map=new n.Map({container:o.div,style:l.style,center:M(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));c._canvas.style.left=\"0px\",c._canvas.style.top=\"0px\",o.rejectOnError(i),o.isStatic||o.initFx(t,e);var u=[];u.push(new Promise((function(t){c.once(\"load\",t)}))),u=u.concat(a.fetchTraceGeoData(t)),Promise.all(u).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(i)},_.updateMap=function(t,e,r,n){var i=this,o=i.map,s=e[this.id];i.rejectOnError(n);var l=[],c=T(s.style);JSON.stringify(i.styleObj)!==JSON.stringify(c)&&(i.styleObj=c,o.setStyle(c.style),i.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(a.fetchTraceGeoData(t)),Promise.all(l).then((function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,f,h={};for(u in a)h[n=a[u]]?h[n].push(u):h[n]=[u];for(n in h){var p=h[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(f=u.split(\"trace-\")[1],this.traceHash[f]&&(this.traceHash[f].below=null)):0===u.indexOf(\"layout-\")&&(f=u.split(\"layout-\")[1],this.layerList[f]&&(this.layerList[f].below=null))}};var w={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function T(t){var e={};return i.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==y.styleValuesMapbox.indexOf(t)?e.style=k(t):y.stylesNonMapbox[t]?e.style=y.stylesNonMapbox[t]:e.style=t):(e.id=y.styleValueDflt,e.style=k(y.styleValueDflt)),e.transition={duration:0,delay:0},e}function k(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}function M(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort((function(t,e){return w[t[0].trace.type]-w[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=a[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(a[r.uid]=r._module.plot(this,s))}var c=Object.keys(a);t:for(n=0;n<c.length;n++){var u=c[n];for(i=0;i<t.length;i++)if(u===(r=t[i][0].trace).uid)continue t;(e=a[u]).dispose(),delete a[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(M(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function a(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}i.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var i=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}})),i.on(\"wheel\",(function(){r.wheeling=!0})),i.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect(),a=[t.originalEvent.offsetX,t.originalEvent.offsetY];t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return i.unproject(a).lng},r.yaxis.p2c=function(){return i.unproject(a).lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),i.on(\"dragstart\",(function(){r.dragging=!0,a()})),i.on(\"zoomstart\",a),i.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),i.on(\"drag\",s),i.on(\"zoom\",s),i.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(M(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))})),r.clearSelect=function(){m(r.dragOptions),g(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&v(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a=f(o)?function(t,r){(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(c)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),p(o)||h(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){d(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(x(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),i=n.width,a=n.height;return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([i,0]).toArray(),t.unproject([i,a]).toArray(),t.unproject([0,a]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},e.exports=b},{\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"./constants\":883,\"./layers\":886,\"mapbox-gl\":473}],890:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").timeFormatLocale,a=t(\"fast-isnumeric\"),o=t(\"../registry\"),s=t(\"../plot_api/plot_schema\"),l=t(\"../plot_api/plot_template\"),c=t(\"../lib\"),u=t(\"../components/color\"),f=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),p=t(\"./cartesian/handle_outline\").clearSelect,d=t(\"./animation_attributes\"),g=t(\"./frame_attributes\"),m=t(\"../plots/get_data\").getModuleCalcData,v=c.relinkPrivateKeys,y=c._,x=e.exports={};c.extendFlat(x,o),x.attributes=t(\"./attributes\"),x.attributes.type.values=x.allTypes,x.fontAttrs=t(\"./font_attributes\"),x.layoutAttributes=t(\"./layout_attributes\"),x.fontWeight=\"normal\";var b=x.transformsRegistry,_=t(\"./command\");x.executeAPICommand=_.executeAPICommand,x.computeAPICommandBindings=_.computeAPICommandBindings,x.manageCommandObserver=_.manageCommandObserver,x.hasSimpleAPICommandBindings=_.hasSimpleAPICommandBindings,x.redrawText=function(t){var e=(t=c.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise((function(e){setTimeout((function(){o.getComponentMethod(\"annotations\",\"draw\")(t),o.getComponentMethod(\"legend\",\"draw\")(t),o.getComponentMethod(\"colorbar\",\"draw\")(t),e(x.previousPromises(t))}),300)}))},x.resize=function(t){var e;t=c.getGraphDiv(t);var r=new Promise((function(r,n){t&&!c.isHidden(t)||n(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout((function(){if(!t.layout||t.layout.width&&t.layout.height||c.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,o.call(\"relayout\",t,{autosize:!0}).then((function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))}))}}),100)}));return e&&e(r),r},x.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then((function(){t._promises=[]}))},x.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=c.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",(function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:u.defaultLine,\"pointer-events\":\"all\"}).each((function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)}))})),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),l=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",(function(){x.sendDataToCloud(t)}));else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&l.text()?\" - \":\"\")}},x.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit(\"plotly_beforeexport\");var r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=x.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1}};var w=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],T=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function k(t,e){var r=t._context.locale;r||(r=\"en-US\");var n=!1,i={};function a(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(a(u),n))break;l=o.localeRegistry}var f=r.split(\"-\")[0];if(n||f===r)break;r=f}return n||a(o.localeRegistry.en.format),i}function M(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function A(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||b[n.type];if(i&&i.makesData)return!0}return!1}function S(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=b[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function E(t){return\"string\"==typeof t&&\"px\"===t.substr(t.length-2)&&parseFloat(t)}function C(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}x.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,a=t._fullLayout||{};if(a._skipDefaults)delete a._skipDefaults;else{var s,l=t._fullLayout={},u=t.layout||{},f=t._fullData||[],h=t._fullData=[],d=t.data||[],g=t.calcdata||[],m=t._context||{};t._transitionData||x.createTransitionData(t),l._dfltTitle={plot:y(t,\"Click to enter Plot title\"),x:y(t,\"Click to enter X axis title\"),y:y(t,\"Click to enter Y axis title\"),colorbar:y(t,\"Click to enter Colorscale title\"),annotation:y(t,\"new text\")},l._traceWord=y(t,\"trace\");var b=k(t,w);if(l._mapboxAccessToken=m.mapboxAccessToken,a._initialAutoSizeIsDone){var _=a.width,M=a.height;x.supplyLayoutGlobalDefaults(u,l,b),u.width||(l.width=_),u.height||(l.height=M),x.sanitizeMargins(l)}else{x.supplyLayoutGlobalDefaults(u,l,b);var A=!u.width||!u.height,S=l.autosize,E=m.autosizable;A&&(S||E)?x.plotAutoSize(t,u,l):A&&x.sanitizeMargins(l),!S&&A&&(u.width=l.width,u.height=l.height)}l._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),{numberFormat:n.locale(t).numberFormat,timeFormat:i(t).utcFormat}}(b,l.separators),l._extraFormat=k(t,T),l._initialAutoSizeIsDone=!0,l._dataLength=d.length,l._modules=[],l._visibleModules=[],l._basePlotModules=[];var L=l._subplots=function(){var t,e,r=o.collectableSubplotTypes,n={};if(!r){r=[];var i=o.subplotsRegistry;for(var a in i){var s=i[a].attr;if(s&&(r.push(a),Array.isArray(s)))for(e=0;e<s.length;e++)c.pushUnique(r,s[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),I=l._splomAxes={x:{},y:{}},P=l._splomSubplots={};l._splomGridDflt={},l._scatterStackOpts={},l._firstScatter={},l._alignmentOpts={},l._colorAxes={},l._requestRangeslider={},l._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,l=new Array(i),u={};function f(t,e){l[e]=t,u[t]=1}function h(t,e){if(t&&\"string\"==typeof t&&!u[t])return f(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),h(p,r)||(r<s&&h(a[r].uid,r)||f(c.randstr(u),r))}return l}(f,d),l._globalTransforms=(t._context||{}).globalTransforms,x.supplyDataDefaults(d,h,u,l);var z=Object.keys(I.x),O=Object.keys(I.y);if(z.length>1&&O.length>1){for(o.getComponentMethod(\"grid\",\"sizeDefaults\")(u,l),s=0;s<z.length;s++)c.pushUnique(L.xaxis,z[s]);for(s=0;s<O.length;s++)c.pushUnique(L.yaxis,O[s]);for(var D in P)c.pushUnique(L.cartesian,D)}if(l._has=x._hasPlotType.bind(l),f.length===h.length)for(s=0;s<h.length;s++)v(h[s],f[s]);x.supplyLayoutModuleDefaults(u,l,h,t._transitionData);var R=l._visibleModules,F=[];for(s=0;s<R.length;s++){var B=R[s].crossTraceDefaults;B&&c.pushUnique(F,B)}for(s=0;s<F.length;s++)F[s](h,l);l._hasOnlyLargeSploms=1===l._basePlotModules.length&&\"splom\"===l._basePlotModules[0].name&&z.length>15&&O.length>15&&0===l.shapes.length&&0===l.images.length,l._hasCartesian=l._has(\"cartesian\"),l._hasGeo=l._has(\"geo\"),l._hasGL3D=l._has(\"gl3d\"),l._hasGL2D=l._has(\"gl2d\"),l._hasTernary=l._has(\"ternary\"),l._hasPie=l._has(\"pie\"),x.linkSubplots(h,l,f,a),x.cleanPlot(h,l,f,a);var N=!(!a._has||!a._has(\"gl2d\")),j=!(!l._has||!l._has(\"gl2d\")),U=!(!a._has||!a._has(\"cartesian\"))||N,V=!(!l._has||!l._has(\"cartesian\"))||j;U&&!V?a._bgLayer.remove():V&&!U&&(l._shouldCreateBgLayer=!0),a._zoomlayer&&!t._dragging&&p({_fullLayout:a}),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,l),v(l,a),o.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,l),l._preGUI||(l._preGUI={}),l._tracePreGUI||(l._tracePreGUI={});var q,H=l._tracePreGUI,G={};for(q in H)G[q]=\"old\";for(s=0;s<h.length;s++)G[q=h[s]._fullInput.uid]||(H[q]={}),G[q]=\"new\";for(q in G)\"old\"===G[q]&&delete H[q];C(l),o.getComponentMethod(\"rangeslider\",\"makeData\")(l),r||g.length!==h.length||x.supplyDefaultsUpdateCalc(g,h)}},x.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,l,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],l=c.nestedProperty(a,s).get().slice(),c.nestedProperty(n,s).set(l)}i.trace=n}}},x.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},x._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var a=o.modules[i];if(a&&a.categories[t])return!0}return!1},x.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var f=r[i].uid;for(a=0;a<t.length;a++){if(f===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+f).remove()}},x.linkSubplots=function(t,e,r,n){var i,a,s=n._plots||{},l=e._plots={},u=e._subplots,f={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(i=0;i<p.length;i++){var d,g=p[i],m=s[g],v=h.getFromId(f,g,\"x\"),y=h.getFromId(f,g,\"y\");for(m?d=l[g]=m:(d=l[g]={}).id=g,v._counterAxes.push(y._id),y._counterAxes.push(v._id),v._subplotsWith.push(g),y._subplotsWith.push(g),d.xaxis=v,d.yaxis=y,d._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var x=t[a];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=h.list(f,null,!0);for(i=0;i<_.length;i++){var w=null;(b=_[i]).overlaying&&(w=h.getFromId(f,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis=\"free\"===b.anchor?null:h.getFromId(f,b.anchor)}for(i=0;i<_.length;i++)if((b=_[i])._counterAxes.sort(h.idSort),b._subplotsWith.sort(c.subplotSort),b._mainSubplot=M(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf(\"across\")||b.automargin&&b.mirror&&\"free\"!==b.anchor||o.getComponentMethod(\"rangeslider\",\"isVisible\")(b))){var T=1,k=0;for(a=0;a<b._counterAxes.length;a++){var A=h.getFromId(f,b._counterAxes[a]);T=Math.min(T,A.domain[0]),k=Math.max(k,A.domain[1])}T<k&&(b._counterDomainMin=T,b._counterDomainMax=k)}},x.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],s.crawl(t._module.attributes,(function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))}))),n=0;n<e.length;n++){c.nestedProperty(t,\"_input.\"+e[n]).get()||c.nestedProperty(t,e[n]).set(null)}},x.supplyDataDefaults=function(t,e,r,n){var i,a,s,u=n._modules,f=n._visibleModules,h=n._basePlotModules,p=0,d=0;function g(t){e.push(t);var r=t._module;r&&(c.pushUnique(u,r),!0===t.visible&&c.pushUnique(f,r),c.pushUnique(h,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var m={},y=[],b=(r.template||{}).data||{},_=l.traceTemplater(b);for(i=0;i<t.length;i++){if(s=t[i],(a=_.newTrace(s)).uid=n._traceUids[i],x.supplyTraceDefaults(s,a,d,n,i),a.index=i,a._input=s,a._expandedIndex=p,a.transforms&&a.transforms.length)for(var w=!1!==s.visible&&!1===a.visible,T=S(a,e,r,n),k=0;k<T.length;k++){var M=T[k],A={_template:a._template,type:a.type,uid:a.uid+k};w&&!1===M.visible&&delete M.visible,x.supplyTraceDefaults(M,A,p,n,i),v(A,M),A.index=i,A._input=s,A._fullInput=a,A._expandedIndex=p,A._expandedInput=M,g(A)}else a._fullInput=a,a._expandedInput=a,g(a);o.traceIs(a,\"carpetAxis\")&&(m[a.carpet]=a),o.traceIs(a,\"carpetDependent\")&&y.push(i)}for(i=0;i<y.length;i++)if((a=e[y[i]]).visible){var E=m[a.carpet];a._carpet=E,E&&E.visible?(a.xaxis=E.xaxis,a.yaxis=E.yaxis):a.visible=!1}},x.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return c.coerce(t||{},r,d,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=x.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=x.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=x.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=x.supplyAnimationTransitionDefaults(t.transition||{});return r},x.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},x.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},x.supplyFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t,e,g,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},x.supplyTraceDefaults=function(t,e,r,n,i){var a,s=n.colorway||u.defaults,l=s[r%s.length];function f(r,n){return c.coerce(t,e,x.attributes,r,n)}var h=f(\"visible\");f(\"type\"),f(\"name\",n._traceWord+\" \"+i),f(\"uirevision\",n.uirevision);var p=x.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var v=n._subplots,y=\"\";if(h||\"gl2d\"!==d.name){if(Array.isArray(g))for(a=0;a<g.length;a++){var b=g[a],_=c.coerce(t,e,m,b);v[b]&&c.pushUnique(v[b],_),y+=_}else y=c.coerce(t,e,m,g);v[d.name]&&c.pushUnique(v[d.name],y)}}}return h&&(f(\"customdata\"),f(\"ids\"),f(\"meta\"),o.traceIs(e,\"showLegend\")?(c.coerce(t,e,p.attributes.showlegend?p.attributes:x.attributes,\"showlegend\"),f(\"legendgroup\"),e._dfltShowLegend=!0):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,l,n),o.traceIs(e,\"noOpacity\")||f(\"opacity\"),o.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),o.traceIs(e,\"noHover\")||(e.hovertemplate||c.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&o.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,l,n)),p&&p.selectPoints&&f(\"selectedpoints\"),x.supplyTransformDefaults(t,e,n)),e},x.hasMakesDataTransform=A,x.supplyTransformDefaults=function(t,e,r){if(e._length||A(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],l=0;l<o.length;l++){var u,f=o[l],h=f.type,p=b[h],d=!(f._module&&f._module===p),g=p&&\"function\"==typeof p.transform;p||c.warn(\"Unrecognized transform type \"+h+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(f,e,r,t)).type=h,u._module=p,c.pushUnique(i,p)):u=c.extendFlat({},f),s.push(u)}}},x.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return c.coerce(t,e,x.layoutAttributes,r,n)}var i=t.template;c.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data),n(\"autotypenumbers\");var a=c.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),c.coerceFont(n,\"title.font\",{family:a.family,size:Math.round(1.4*a.size),color:a.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"uniformtext.mode\")&&n(\"uniformtext.minsize\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&x.sanitizeMargins(e),o.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",u.addOpacity(e.paper_bgcolor,.5));var l=u.contrast(u.rgb(e.modebar.bgcolor));n(\"modebar.color\",u.addOpacity(l,.3)),n(\"modebar.activecolor\",u.addOpacity(l,.7)),n(\"modebar.uirevision\",s),o.getComponentMethod(\"shapes\",\"supplyDrawNewShapeDefaults\")(t,e,n),n(\"meta\"),c.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),o.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),o.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},x.plotAutoSize=function(t,e,r){var n,i,o=t._context||{},s=o.frameMargins,l=c.isPlotDiv(t);if(l&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=l?window.getComputedStyle(t):{};if(n=E(u.width)||E(u.maxWidth)||r.width,i=E(u.height)||E(u.maxHeight)||r.height,a(s)&&s>0){var f=1-2*s;n=Math.round(f*n),i=Math.round(f*i)}}var h=x.layoutAttributes.width.min,p=x.layoutAttributes.height.min;n<h&&(n=h),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-i)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),x.sanitizeMargins(r)},x.supplyLayoutModuleDefaults=function(t,e,r,n){var i,a,s,l=o.componentsRegistry,u=e._basePlotModules,f=o.subplotsRegistry.cartesian;for(i in l)(s=l[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var h in u.length||u.push(f),e._has(\"cartesian\")&&(o.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),f.finalizeSubplots(t,e)),e._subplots)e._subplots[h].sort(c.subplotSort);for(a=0;a<u.length;a++)(s=u[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(a=0;a<p.length;a++)(s=p[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(a=0;a<d.length;a++)(s=d[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in l)(s=l[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},x.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),c.clearThrottle(),c.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},x.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&c.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},x.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},x.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},x.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1};x.autoMargin=function(t,e,r){var n=t._fullLayout,i=n.width,a=n.height,o=n.margin,s=c.constrain(i-o.l-o.r,2,64),l=c.constrain(a-o.t-o.b,2,64),u=Math.max(0,i-s),f=Math.max(0,a-l),h=n._pushmargin,p=n._pushmarginIds;if(!1!==o.autoexpand){if(r){var d=r.pad;if(void 0===d&&(d=Math.min(12,o.l,o.r,o.t,o.b)),u){var g=(r.l+r.r)/u;g>1&&(r.l/=g,r.r/=g)}if(f){var m=(r.t+r.b)/f;m>1&&(r.t/=m,r.b/=m)}var v=void 0!==r.xl?r.xl:r.x,y=void 0!==r.xr?r.xr:r.x,b=void 0!==r.yt?r.yt:r.y,_=void 0!==r.yb?r.yb:r.y;h[e]={l:{val:v,size:r.l+d},r:{val:y,size:r.r+d},b:{val:_,size:r.b+d},t:{val:b,size:r.t+d}},p[e]=1}else delete h[e],delete p[e];if(!n._replotting)return x.doAutoMargin(t)}},x.doAutoMargin=function(t){var e=t._fullLayout,r=e.width,n=e.height;e._size||(e._size={}),C(e);var i=e._size,s=e.margin,l=c.extendFlat({},i),u=s.l,f=s.r,p=s.t,d=s.b,g=e._pushmargin,m=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var v in g)m[v]||delete g[v];for(var y in g.base={l:{val:0,size:u},r:{val:1,size:f},t:{val:1,size:p},b:{val:0,size:d}},g){var b=g[y].l||{},_=g[y].b||{},w=b.val,T=b.size,k=_.val,M=_.size;for(var A in g){if(a(T)&&g[A].r){var S=g[A].r.val,E=g[A].r.size;if(S>w){var L=(T*S+(E-r)*w)/(S-w),I=(E*(1-w)+(T-r)*(1-S))/(S-w);L+I>u+f&&(u=L,f=I)}}if(a(M)&&g[A].t){var P=g[A].t.val,z=g[A].t.size;if(P>k){var O=(M*P+(z-n)*k)/(P-k),D=(z*(1-k)+(M-n)*(1-P))/(P-k);O+D>d+p&&(d=O,p=D)}}}}}var R=c.constrain(r-s.l-s.r,2,64),F=c.constrain(n-s.t-s.b,2,64),B=Math.max(0,r-R),N=Math.max(0,n-F);if(B){var j=(u+f)/B;j>1&&(u/=j,f/=j)}if(N){var U=(d+p)/N;U>1&&(d/=U,p/=U)}if(i.l=Math.round(u),i.r=Math.round(f),i.t=Math.round(p),i.b=Math.round(d),i.p=Math.round(s.pad),i.w=Math.round(r)-i.l-i.r,i.h=Math.round(n)-i.t-i.b,!e._replotting&&x.didMarginChange(l,i)){\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var V=3*(1+Object.keys(m).length);if(e._redrawFromAutoMarginCount<V)return o.call(\"plot\",t);e._size=l,c.warn(\"Too many auto-margin redraws.\")}!function(t){for(var e=h.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r]._hideOutOfRangeInsideTickLabels;n&&n()}}(t)};var L=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function I(t,e,r){var n=!1;var i=[x.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,x.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise((function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push((function(){n=!0})),r.redraw&&t._transitionData._interruptCallbacks.push((function(){return o.call(\"redraw\",t)})),t._transitionData._interruptCallbacks.push((function(){t.emit(\"plotly_transitioninterrupted\",[])}));var a=0,s=0;function l(){return a++,function(){s++,n||s!==a||function(e){if(!t._transitionData)return;(function(t){if(t)for(;t.length;)t.shift()})(t._transitionData._interruptCallbacks),Promise.resolve().then((function(){if(r.redraw)return o.call(\"redraw\",t)})).then((function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])})).then(e)}(i)}}r.runFn(l),setTimeout(l())}))}],a=c.syncOrAsync(i,t);return a&&a.then||(a=Promise.resolve()),a.then((function(){return t}))}x.didMarginChange=function(t,e){for(var r=0;r<L.length;r++){var n=L[r],i=t[n],o=e[n];if(!a(i)||Math.abs(o-i)>1)return!0}return!1},x.graphJson=function(t,e,r,n,i,a){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&x.supplyDefaults(t);var o=i?t._fullData:t.data,s=i?t._fullLayout:t.layout,l=(t._transitionData||{})._frames;function u(t,e){if(\"function\"==typeof t)return e?\"_function_\":null;if(c.isPlainObject(t)){var n,i={};return Object.keys(t).sort().forEach((function(a){if(-1===[\"_\",\"[\"].indexOf(a.charAt(0)))if(\"function\"!=typeof t[a]){if(\"keepdata\"===r){if(\"src\"===a.substr(a.length-3))return}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0&&!c.isPlainObject(t.stream))return}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0)return;i[a]=u(t[a],e)}else e&&(i[a]=\"_function\")})),i}return Array.isArray(t)?t.map((function(t){return u(t,e)})):c.isTypedArray(t)?c.simpleMap(t,c.identity):c.isJSDate(t)?c.ms2DateTimeLocal(+t):t}var f={data:(o||[]).map((function(t){var r=u(t);return e&&delete r.fit,r}))};if(!e&&(f.layout=u(s),i)){var h=s._size;f.layout.computed={margin:{b:h.b,l:h.l,r:h.r,t:h.t}}}return t.framework&&t.framework.isPolar&&(f=t.framework.getConfig()),l&&(f.frames=u(l)),a&&(f.config=u(t._context,!0)),\"object\"===n?f:JSON.stringify(f)},x.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},x.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=x.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=x.extendTrace(u.data[a],s.data[r]))}return u},x.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},x.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,l,u,f=c.extendDeepNoArrays({},e||{}),h=c.expandObjectPaths(f),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=c.nestedProperty(h,r[a])).get())?c.nestedProperty(p,r[a]).set(null):(n.set(null),c.nestedProperty(p,r[a]).set(i));if(t=c.extendDeepNoArrays(t||{},h),r&&r.length)for(a=0;a<r.length;a++)if(l=c.nestedProperty(p,r[a]).get()){for(u=(s=c.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<l.length;o++){var d=l[o];u[o]=null===d?null:x.extendObjectWithContainers(u[o],d)}s.set(u)}return t},x.dataArrayContainers=[\"transforms\",\"dimensions\"],x.layoutArrayContainers=o.layoutArrayContainers,x.extendTrace=function(t,e){return x.extendObjectWithContainers(t,e,x.dataArrayContainers)},x.extendLayout=function(t,e){return x.extendObjectWithContainers(t,e,x.layoutArrayContainers)},x.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},l=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],f=t._fullData[u]._module;if(f){if(f.animatable){var h=f.basePlotModule.name;s[h]||(s[h]=[]),s[h].push(u)}t.data[a[o]]=x.extendTrace(t.data[a[o]],e[o])}}var p=c.expandObjectPaths(c.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;x.extendLayout(t.layout,p),delete t.calcdata,x.supplyDefaults(t),x.doCalcdata(t);var m=c.expandObjectPaths(r);if(m){var v=t._fullLayout._plots;for(var y in v){var b=v[y],_=b.xaxis,w=b.yaxis,T=_.range.slice(),k=w.range.slice(),M=null,A=null,S=null,E=null;Array.isArray(m[_._name+\".range\"])?M=m[_._name+\".range\"].slice():Array.isArray((m[_._name]||{}).range)&&(M=m[_._name].range.slice()),Array.isArray(m[w._name+\".range\"])?A=m[w._name+\".range\"].slice():Array.isArray((m[w._name]||{}).range)&&(A=m[w._name].range.slice()),T&&M&&(_.r2l(T[0])!==_.r2l(M[0])||_.r2l(T[1])!==_.r2l(M[1]))&&(S={xr0:T,xr1:M}),k&&A&&(w.r2l(k[0])!==w.r2l(A[0])||w.r2l(k[1])!==w.r2l(A[1]))&&(E={yr0:k,yr1:A}),(S||E)&&l.push(c.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=l.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,l,a,e);for(var f in u?((n=c.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var h=s[f];t._fullData[h[0]]._module.basePlotModule.plot(t,h,n,e)}},I(t,a,o)},x.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var l=t[a],u=l.xaxis,f=l.yaxis,h=n[u._name].range.slice(),p=n[f._name].range.slice(),d=u.range.slice(),g=f.range.slice();u.setScale(),f.setScale();var m=null,v=null;u.r2l(h[0])===u.r2l(d[0])&&u.r2l(h[1])===u.r2l(d[1])||(m={xr0:h,xr1:d}),f.r2l(p[0])===f.r2l(g[0])&&f.r2l(p[1])===f.r2l(g[1])||(v={yr0:p,yr1:g}),(m||v)&&s.push(c.extendFlat({plotinfo:l},m,v))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,l=t._fullData,u=t._fullLayout._basePlotModules,f=[],h=0;h<l.length;h++)f.push(h);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=c.extendFlat({},a,{duration:0}),o=f,i=a,setTimeout(p,a.duration),d()):(n=a,o=null,i=c.extendFlat({},a,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=a,p()):e.anim&&(o=f,i=a,d())},I(t,a,o)},x.doCalcdata=function(t,e){var r,n,i,a,l=h.list(t),u=t._fullData,p=t._fullLayout,d=new Array(u.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._funnelareacolormap={},i=0;i<u.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<u.length;i++)(r=u[i])._arrayAttrs=s.findArrayAttributes(r),r._extremes={};var m=p._subplots.polar||[];for(i=0;i<m.length;i++)l.push(p[m[i]].radialaxis,p[m[i]].angularaxis);for(var v in p._colorAxes){var y=p[v];!1!==y.cauto&&(delete y.cmin,delete y.cmax)}var x=!1;function _(e){if(r=u[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(a=0;a<r.transforms.length;a++){var o=r.transforms[a];(n=b[o.type])&&n.calcTransform&&(r._hasCalcTransform=!0,x=!0,n.calcTransform(t,r,o))}}}function w(e,i){if(r=u[e],!!(n=r._module).isContainer===i){var o=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var s=r.transforms||[];for(a=s.length-1;a>=0;a--)if(s[a].enabled){r._indexToPoints=s[a]._indexToPoints;break}n&&n.calc&&(o=n.calc(t,r))}Array.isArray(o)&&o[0]||(o=[{x:f,y:f}]),o[0].t||(o[0].t={}),o[0].trace=r,d[e]=o}}for(z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)_(i);for(x&&z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)w(i,!1);O(t);var T=function(t,e){var r,n,i,a,s,l=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e||s&&t===n[e].length-1||l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return c.aggNums(Math.min,null,t)},max:function(t){return c.aggNums(Math.max,null,t)},sum:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},total:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},mean:function(t){return c.mean(t)},median:function(t){return c.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(P);if(d){var g=d[1],m=d[2],v=p._id.charAt(0),y=\"x\"===v,x=[];for(n=0;n<p._categories.length;n++)x.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var b=p._traceIndices[n],_=e._fullData[b];if(!0===_.visible){var w=_.type;o.traceIs(_,\"histogram\")&&(delete _._xautoBinFinished,delete _._yautoBinFinished);var T=\"splom\"===w,k=\"scattergl\"===w,M=e.calcdata[b];for(i=0;i<M.length;i++){var A,S,E=M[i];if(T){var C=_._axesDim[p._id];if(!y){var L=_._diag[C][0];L&&(p=e._fullLayout[h.id2name(L)])}var I=E.trace.dimensions[C].values;for(a=0;a<I.length;a++)for(A=p._categoriesMap[I[a]],s=0;s<E.trace.dimensions.length;s++)if(s!==C){var z=E.trace.dimensions[s];x[A][1].push(z.values[a])}}else if(k){for(a=0;a<E.t.x.length;a++)y?(A=E.t.x[a],S=E.t.y[a]):(A=E.t.y[a],S=E.t.x[a]),x[A][1].push(S);E.t&&E.t._scene&&delete E.t._scene.dirty}else if(E.hasOwnProperty(\"z\")){S=E.z;var O=u(_.type,p,S);for(a=0;a<S.length;a++)for(s=0;s<S[a].length;s++)(A=O(s,a))+1&&x[A][1].push(S[a][s])}else for(void 0===(A=E.p)&&(A=E[v]),void 0===(S=E.s)&&(S=E.v),void 0===S&&(S=y?E.y:E.x),Array.isArray(S)||(S=void 0===S?[]:[S]),a=0;a<S.length;a++)x[A][1].push(S[a])}}}p._categoriesValue=x;var D=[];for(n=0;n<x.length;n++)D.push([x[n][0],f[g](x[n][1])]);D.sort((function(t,e){return t[1]-e[1]})),p._categoriesAggregatedValue=D,p._initialCategories=D.map((function(t){return t[0]})),\"descending\"===m&&p._initialCategories.reverse(),l=l.concat(p.sortByInitialCategories())}}}return l}(l,t);if(T.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<T.length;i++)w(T[i],!0);for(i=0;i<T.length;i++)w(T[i],!1);O(t)}o.getComponentMethod(\"fx\",\"calc\")(t),o.getComponentMethod(\"errorbars\",\"calc\")(t)};var P=/(total|sum|min|max|mean|median) (ascending|descending)/;function z(t,e,r){var n={};function i(t){t.clearCalc(),\"multicategory\"===t.type&&t.setupMultiCategory(e),n[t._id]=1}c.simpleMap(t,i);for(var a=r._axisMatchGroups||[],o=0;o<a.length;o++)for(var s in a[o])n[s]||i(r[h.id2name(s)])}function O(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],l=s.crossTraceCalc;if(l){var u=s.basePlotModule.name;o[u]?c.pushUnique(o[u],l):o[u]=[l]}}for(n in o){var f=o[n],h=i._subplots[n];if(Array.isArray(h))for(e=0;e<h.length;e++){var p=h[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<f.length;r++)f[r](t,d,p)}else for(r=0;r<f.length;r++)f[r](t)}}x.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},x.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},x.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],l=s[0].trace;l.visible&&(o[l.type]=o[l.type]||[],o[l.type].push(s))}for(var u in a)if(!o[u]){var f=a[u][0];f[0].trace.visible=!1,o[u]=[f]}for(var h in o){var p=o[h];p[0][0].trace._module.plot(t,e,c.filterVisible(p),n)}e.traceHash=o},x.plotBasePlot=function(t,e,r,n,i){var a=o.getModule(t),s=m(e.calcdata,a)[0];a.plot(e,s,n,i)},x.cleanBasePlot=function(t,e,r,n,i){var a=i._has&&i._has(t),o=r._has&&r._has(t);a&&!o&&i[\"_\"+t+\"layer\"].selectAll(\"g.trace\").remove()}},{\"../components/color\":643,\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plot_api/plot_template\":817,\"../plots/get_data\":865,\"../registry\":911,\"./animation_attributes\":822,\"./attributes\":824,\"./cartesian/axis_ids\":831,\"./cartesian/handle_outline\":838,\"./command\":854,\"./font_attributes\":856,\"./frame_attributes\":857,\"./layout_attributes\":882,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],892:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=f(Math.sin(e)-Math.sin(t)),c=f(Math.cos(e)-Math.cos(t)),u=Math.tan(r),h=f(1/u),p=l/c,d=s-p*o;return h?l&&c?a=u*(i=d/(u-p)):c?(i=s*h,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,f=i.length,h=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,f)}function m(t){return o(t,[e,r])}var v=a(i,(function(t){return m(t)?l(t,e):1/0})),y=d(i[v],i[g(v-1)],e);for(h.push(y),s=v,u=0;u<f;s++,u++){var x=i[g(s)];if(!m(x))break;h.push(p(x))}var b=a(i,(function(t){return m(t)?l(t,r):1/0})),_=d(i[b],i[g(b+1)],r);return h.push(_),h.push([0,0]),h.push(h[0].slice()),h}(t,e,r,i)}function f(t){return Math.abs(t)>1e-10?t:0}function h(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),f=i(u(l,n[0],n[1],a)),h=[t*Math.cos(e),t*Math.sin(e)];return f.contains(h)&&!c.contains(h)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,(function(e){var r=s(e,t);return r>0?r:1/0})),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:f,pathPolygon:function(t,e,r,n,i,a){return\"M\"+h(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=h(u(s,r,n,i),a,o);return\"M\"+h(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":778,\"../../lib/polygon\":790}],894:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],f=n[u]._subplot;if(!e[u]&&f)for(var h in f.framework.remove(),f.layers[\"radial-axis-title\"].remove(),f.clipPaths)f.clipPaths[h].remove();s&&f._scene&&(f._scene.destroy(),f._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":778,\"../cartesian\":841,\"../get_data\":865,\"./constants\":892,\"./layout_attributes\":895,\"./layout_defaults\":896,\"./polar\":903}],895:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:{text:o({},i.title.text,{editType:\"plot\",dflt:\"\"}),font:o({},i.title.font,{editType:\"plot\"}),editType:\"plot\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};o(u,l,c);var f={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:i.autotypenumbers,categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(f,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:f,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],896:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),f=t(\"../cartesian/category_order_defaults\"),h=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),m=t(\"./constants\"),v=m.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,m.name,o.id),w=o.layoutOut;function T(t,e){return r(b+\".\"+t,e)}for(var k=0;k<v.length;k++){b=v[k],n.isPlainObject(t[b])||(t[b]={});var M=t[b],A=a.newContainer(e,b);A._id=A._name=b,A._attr=o.id+\".\"+b,A._traceIndices=_.map((function(t){return t._expandedIndex}));var S=m.axisName2dataArray[b],E=x(M,A,T,_,S,o);f(M,A,T,{axData:_,dataAttr:S});var C,L,I=T(\"visible\");switch(g(A,e,w),T(\"uirevision\",e.uirevision),I&&(L=(C=T(\"color\"))===M.color?C:o.font.color),A._m=1,b){case\"radialaxis\":var P=T(\"autorange\",!A.isValidRange(M.range));M.autorange=P,!P||\"linear\"!==E&&\"-\"!==E||T(\"rangemode\"),\"reversed\"===P&&(A._m=-1),T(\"range\"),A.cleanRange(\"range\",{dfltRange:[0,1]}),I&&(T(\"side\"),T(\"angle\",y[0]),T(\"title.text\"),n.coerceFont(T,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=M.type=A.type=\"linear\"}T(\"linear\"===E?\"thetaunit\":\"period\");var O=T(\"direction\");T(\"rotation\",{counterclockwise:0,clockwise:90}[O])}if(I)l(M,A,T,A.type),u(M,A,T,A.type,{tickSuffixDflt:\"degrees\"===A.thetaunit?\"\\xb0\":void 0}),c(M,A,T,{outerTicks:!0}),T(\"showticklabels\")&&(n.coerceFont(T,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),T(\"tickangle\"),T(\"tickformat\")),h(M,A,T,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),T(\"layer\");\"category\"!==E&&T(\"hoverformat\"),A._input=M}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i,a){var o=r(\"autotypenumbers\",a.autotypenumbersDflt);if(\"-\"===r(\"type\")){for(var s,l=0;l<n.length;l++)if(n[l].visible){s=n[l];break}s&&s[i]&&(e.type=p(s[i],\"gregorian\",{noMultiCategory:!0,autotypenumbers:o})),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:m.name,attributes:d,handleDefaults:y,font:e.font,autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/axis_autotype\":829,\"../cartesian/category_order_defaults\":832,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":892,\"./layout_attributes\":895,\"./set_convert\":904}],897:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":768,\"../../../traces/scatter/attributes\":1187}],898:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],899:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":900,\"./micropolar_manager\":901}],900:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},f=n.dispatch(\"hover\"),h={};return h.render=function(c){return function(c){e=c||e;var f=l.data,h=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(f).each((function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(h)};var f=0;c.forEach((function(t,e){t.color||(t.color=h.defaultColorRange[f],f=(f+1)%h.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize}));var p=c.filter((function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r})),d=!1,g=p.map((function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t}));if(d){var m=n.nest().key((function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"})).entries(g),v=[],y=m.map((function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map((function(t,e){return 0}));return t.values.forEach((function(t,e,n){t.yStack=[r],v.push(r),r=o.util.sumArrays(t.r,r)})),t.values}));p=n.merge(y)}p.forEach((function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]}));var x=Math.min(h.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2;x=Math.max(10,x);var b,_=[h.margin.left+x,h.margin.top+x];d?b=[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(v)))]:b=n.extent(o.util.flattenArray(p.map((function(t,e){return t.r}))));h.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(h.radialAxis.domain!=o.DATAEXTENT&&h.radialAxis.domain?h.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,T=o.util.flattenArray(p.map((function(t,e){return t.t}))),k=\"string\"==typeof T[0];k&&(T=o.util.deduplicate(T),w=T.slice(),T=n.range(T.length),p=p.map((function(t,e){var r=t;return t.t=[T],d&&(r.yStack=t.yStack),r})));var M=p.filter((function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry})).length===p.length,A=null===h.needsEndSpacing?k||!M:h.needsEndSpacing,S=h.angularAxis.domain&&h.angularAxis.domain!=o.DATAEXTENT&&!k&&h.angularAxis.domain[0]>=0?h.angularAxis.domain:n.extent(T),E=Math.abs(T[1]-T[0]);M&&!k&&(E=0);var C=S.slice();A&&k&&(C[1]+=E);var L=h.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),h.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var I=h.angularAxis.ticksStep||(C[1]-C[0])/(L*(h.minorTicks+1));w&&(I=Math.max(Math.round(I),1)),C[2]||(C[2]=I);var P=n.range.apply(this,C);if(P=P.map((function(t,e){return parseFloat(t.toPrecision(12))})),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===h.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=A?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),O=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(O)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:h.tickColor},B={\"font-size\":h.font.size,\"font-family\":h.font.family,fill:h.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map((function(t,e){return\" \"+t+\" 0 \"+h.font.outlineColor})).join(\",\")};if(h.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,h.margin.top]+\")\"}).style({display:\"block\"});var N=p.map((function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r}));o.Legend().config({data:p.map((function(t,e){return t.name||\"Element\"+e})),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:h.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(h.width-j.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2,x=Math.max(10,x),_=[h.margin.left+x,h.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:h.width,height:h.height}).style({opacity:h.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(h.width-(h.margin.left+h.margin.right+2*x+(j?j.width:0)))/2,(h.height-(h.margin.top+h.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),h.title&&h.title.text){var V=t.select(\"g.title-group text\").style(B).text(h.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(h.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:h.backgroundColor,stroke:h.stroke});function W(t,e){return s(t)%360+h.orientation}if(h.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+h.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text((function(t,e){return this.textContent+h.radialAxis.ticksSuffix})).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===h.radialAxis.tickOrientation?\"rotate(\"+-h.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(P),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:h.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",(function(t,e){return e%(h.minorTicks+1)==0})).classed(\"minor\",(function(t,e){return!(e%(h.minorTicks+1)==0)})).style(F),J.selectAll(\".minor\").style({stroke:h.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:h.tickLength?x-h.tickLength:0,x2:x}).style({display:h.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+h.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+h.labelOffset,i=h.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:h.angularAxis.labelsVisible?\"block\":\"none\"}).text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":w?w[t]+h.angularAxis.ticksSuffix:t+h.angularAxis.ticksSuffix})).style(B);h.angularAxis.rewriteTicks&&K.text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":h.angularAxis.rewriteTicks(this.textContent,e)}));var Q=n.max(R.selectAll(\".angular-tick text\")[0].map((function(t,e){return t.getCTM().e+t.getBBox().width})));D.attr({transform:\"translate(\"+[x+Q,h.margin.top]+\")\"});var $=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||$){var et=[];p.forEach((function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter((function(t,r){return r==e})),n.geometry=t.geometry,n.orientation=h.orientation,n.direction=h.direction,n.index=e,et.push({data:t,geometryConfig:n})}));var rt=n.nest().key((function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"})).entries(et),nt=[];rt.forEach((function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map((function(t,e){return[t]}))):nt.push(t.values)})),nt.forEach((function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map((function(t,e){return i(o[r].defaultConfig(),t)}));o[r]().config(n)()}))}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!k){var ft=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",(function(t,e){var r=o.util.getMousePos(Y).angle;ft.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-h.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.angular-guide\",(function(t,e){ot.select(\"line\").style({opacity:0})}))}var ht=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",(function(t,e){var n=o.util.getMousePos(Y).radius;ht.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,h.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.radial-guide\",(function(t,e){ht.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()})),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",(function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};k&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,f=this.getBoundingClientRect(),h=t.node().getBoundingClientRect(),p=[f.left+f.width/2-U[0]-h.left,f.top+f.height/2-U[1]-h.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})})).on(\"mousemove.tooltip\",(function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()})).on(\"mouseout.tooltip\",(function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})}))}))}(c),this},h.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach((function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)})),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},h.getLiveConfig=function(){return u},h.getinputConfig=function(){return c},h.radialScale=function(t){return r},h.angularScale=function(t){return s},h.svg=function(){return t},n.rebind(h,f,\"on\"),h},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map((function(e,r){var n=e*Math.PI/180;return[e,t(n)]}))},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach((function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)}));var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map((function(t,e){return r[e]||r[0]}))},o.util.fillArrays=function(t,e,r){return e.forEach((function(e,n){t[e]=o.util.ensureArray(t[e],r)})),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map((function(t,e){return n.sum(t)}))},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter((function(t,e,r){return r.indexOf(t)==e}))},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce((function(t,e){if(\"undefined\"!=typeof t)return t[e]}),t);\"undefined\"!=typeof a&&(e.reduce((function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]}),t),r.reduce((function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]}),t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each((function(t,i){var a=!!t[0].data.yStack,o=t.map((function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])})),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius((function(t){return e.radialScale(t[1])})).angle((function(t){return e.angularScale(t[0])*Math.PI/180}));c.line=function(r,i,a){var s=r[2]?o[a].map((function(t,e){return[t[0],t[1]+t[2]]})):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var f=e.angularScale.range(),h=Math.abs(f[1]-f[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle((function(t){return-h/2})).endAngle((function(t){return h/2})).innerRadius((function(t){return e.radialScale(l+(t[2]||0))})).outerRadius((function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])}));c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var m=g.selectAll(\"path.mark\").data((function(t,e){return t}));m.enter().append(\"path\").attr({class:\"mark\"}),m.style(d).each(c[e.geometryType]),m.exit().remove(),g.exit().remove()}))}return a.config=function(e){return arguments.length?(e.forEach((function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)})),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map((function(t,r){return[].concat(t).map((function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a}))})),o=n.merge(a);o=o.filter((function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)})),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map((function(t,e){return t.color})),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,f=u?e.height:c*o.length,h=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=h.enter().append(\"svg\").attr({width:300,height:f+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),m=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,f]);if(u){var v=h.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);v.enter().append(\"stop\"),v.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),h.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=h.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,m(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(m).orient(\"right\"),b=h.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text((function(t,e){return o[e].name})),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",f=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(f);var h=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*h+l,m=p.height+2*h;return r.attr({d:\"M\"+[[l,-m/2],[l,-m/4],[a.hasTick?0:l,0],[l,m/4],[l,m/2],[g,m/2],[g,-m/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-m/2+2*h]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map((function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n})),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map((function(t,e){return t.geometry})));r.data.forEach((function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)}))}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach((function(t,e){u[c[l.indexOf(t.key)]]=t.value})),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":745,\"../../../lib\":778,d3:169}],901:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,f=new s;function h(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return h.isPolar=!0,h.svg=function(){return i.svg()},h.getConfig=function(){return e},h.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},h.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},h.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,f.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},h.undo=function(){f.undo()},h.redo=function(){f.redo()},h},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":643,\"../../../lib\":778,\"./micropolar\":900,\"./undo_manager\":902,d3:169}],902:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n||(e.splice(r+1,e.length-r),e.push(t),r=e.length-1),this},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],903:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../plots\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../cartesian/set_convert\"),d=t(\"./set_convert\"),g=t(\"../cartesian/autorange\").doAutoRange,m=t(\"../cartesian/dragbox\"),v=t(\"../../components/dragelement\"),y=t(\"../../components/fx\"),x=t(\"../../components/titles\"),b=t(\"../cartesian/select\").prepSelect,_=t(\"../cartesian/select\").selectOnClick,w=t(\"../cartesian/select\").clearSelect,T=t(\"../../lib/setcursor\"),k=t(\"../../lib/clear_gl_canvases\"),M=t(\"../../plot_api/subroutines\").redrawReglTraces,A=t(\"../../constants/alignment\").MID_SHIFT,S=t(\"./constants\"),E=t(\"./helpers\"),C=o._,L=o.mod,I=o.deg2rad,P=o.rad2deg;function z(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=z.prototype;function D(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function R(t,e){return e[o.findIndexOfMin(e,(function(e){return o.angleDist(t,e)}))]}function F(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}e.exports=function(t,e){return new z(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),f.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=S.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var f=this.framework.selectAll(\".polarsublayer\").data(l,String);f.enter().append(\"g\").attr(\"class\",(function(t){return\"polarsublayer \"+t})).each((function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}})),f.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,s=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-s[1]);var f=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(s[1]-s[0]),p=e.sector;this.sectorInRad=p.map(I);var d,g,m,v,y,x=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=L(a,360),l=s+o,c=Math.cos(I(s)),u=Math.sin(I(s)),f=Math.cos(I(l)),h=Math.sin(I(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&h<=0?0:Math.max(u,h);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&f>=0?0:Math.min(c,f);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&h>=0?0:Math.min(u,h);n=l>=360?1:c<=0&&f<=0?0:Math.max(c,f);return[e,r,n,i]}(p),b=x[2]-x[0],_=x[3]-x[1],w=h/f,T=Math.abs(_/b);w>T?(d=f,y=(h-(g=f*T))/n.h/2,m=[o[0],o[1]],v=[s[0]+y,s[1]-y]):(g=h,y=(f-(d=h/T))/n.w/2,m=[o[0]+y,o[1]-y],v=[s[0],s[1]]),this.xLength2=d,this.yLength2=g,this.xDomain2=m,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*m[0],M=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=d/b,S=this.innerRadius=e.hole*A,E=this.cx=k-A*x[0],C=this.cy=M+A*x[3],P=this.cxx=E-k,z=this.cyy=C-M;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],_realSide:i.side,domain:[S/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:m}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var O=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",O).attr(\"transform\",l(P,z)),r.frontplot.attr(\"transform\",l(k,M)).call(u.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",O).attr(\"transform\",l(E,C)).call(c.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({},r,n);return d(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);p(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),g(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.radialaxis,g=L(e.sector[0],360),m=r.radialAxis,v=u<a;r.fillViewInitialKey(\"radialaxis.angle\",d.angle),r.fillViewInitialKey(\"radialaxis.range\",m.range.slice()),m.setGeometry(),\"auto\"===m.tickangle&&g>90&&g<=270&&(m.tickangle=180);var y=function(t){return l(m.l2p(t.x)+u,0)},x=D(d);if(r.radialTickLayout!==x&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=x),v){m.setScale();var b=h.calcTicks(m),_=h.clipEnds(m,b),w=h.getTickSigns(m)[2];h.drawTicks(n,m,{vals:b,layer:i[\"radial-axis\"],path:h.makeTickPath(m,0,w),transFn:y,crisp:!1}),h.drawGrid(n,m,{vals:_,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(m.r2p(t.x)+u)},transFn:o.noop,crisp:!1}),h.drawLabels(n,m,{vals:b,layer:i[\"radial-axis\"],transFn:y,labelFns:h.makeLabelFns(m,0)})}var T=r.radialAxisAngle=r.vangles?P(R(I(d.angle),r.vangles)):d.angle,k=l(f,p),M=k+s(-T);F(i[\"radial-axis\"],v&&(d.showticklabels||d.ticks),{transform:M}),F(i[\"radial-grid\"],v&&d.showgrid,{transform:k}),F(i[\"radial-line\"].select(\"line\"),v&&d.showline,{x1:u,y1:0,x2:a,y2:0,transform:M}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,l=this.id+\"title\",c=void 0!==r?r:this.radialAxisAngle,f=I(c),h=Math.cos(f),p=Math.sin(f),d=0;if(s.title){var g=u.bBox(this.layers[\"radial-axis\"].node()).height,m=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*m:g+.8*m}this.layers[\"radial-axis-title\"]=x.draw(n,l,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:C(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*h+d*p,y:o-i/2*p+d*h,\"text-anchor\":\"middle\"},transform:{rotate:-c}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.angularaxis,g=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",d.rotation),g.setGeometry(),g.setScale();var m=function(t){return g.t2g(t.x)};\"linear\"===g.type&&\"radians\"===g.thetaunit&&(g.tick0=P(g.tick0),g.dtick=P(g.dtick));var v=function(t){return l(f+a*Math.cos(t),p-a*Math.sin(t))},y=h.makeLabelFns(g,0).labelStandoff,x={xFn:function(t){var e=m(t);return Math.cos(e)*y},yFn:function(t){var e=m(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(y+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*A)},anchorFn:function(t){var e=m(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=m(t);return-.5*(1+Math.sin(n))*r}},b=D(d);r.angularTickLayout!==b&&(i[\"angular-axis\"].selectAll(\".\"+g._id+\"tick\").remove(),r.angularTickLayout=b);var _,w=h.calcTicks(g);if(\"linear\"===e.gridshape?(_=w.map(m),o.angleDelta(_[0],_[1])<0&&(_=_.slice().reverse())):_=null,r.vangles=_,\"category\"===g.type&&(w=w.filter((function(t){return o.isAngleInsideSector(m(t),r.sectorInRad)}))),g.visible){var T=\"inside\"===g.ticks?-1:1,k=(g.linewidth||1)/2;h.drawTicks(n,g,{vals:w,layer:i[\"angular-axis\"],path:\"M\"+T*k+\",0h\"+T*g.ticklen,transFn:function(t){var e=m(t);return v(e)+s(-P(e))},crisp:!1}),h.drawGrid(n,g,{vals:w,layer:i[\"angular-grid\"],path:function(t){var e=m(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[f+u*r,p-u*n]+\"L\"+[f+a*r,p-a*n]},transFn:o.noop,crisp:!1}),h.drawLabels(n,g,{vals:w,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return v(m(t))},labelFns:x})}F(i[\"angular-line\"].select(\"path\"),d.showline,{d:r.pathSubplot(),transform:l(f,p)}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e,r,s=this,c=s.gd,u=s.layers,f=t._zoomlayer,h=S.MINZOOM,p=S.OFFEDGE,d=s.radius,g=s.innerRadius,x=s.cx,T=s.cy,k=s.cxx,M=s.cyy,A=s.sectorInRad,C=s.vangles,L=s.radialAxis,I=E.clampTiny,P=E.findXYatLength,z=E.findEnclosingVertexAngles,O=S.cornerHalfWidth,D=S.cornerLen/2,R=m.makeDragger(u,\"path\",\"maindrag\",\"crosshair\");n.select(R).attr(\"d\",s.pathSubplot()).attr(\"transform\",l(x,T));var F,B,N,j,U,V,q,H,G,Y={element:R,gd:c,subplot:s.id,plotinfo:{id:s.id,xaxis:s.xaxis,yaxis:s.yaxis},xaxes:[s.xaxis],yaxes:[s.yaxis]};function W(t,e){return Math.sqrt(t*t+e*e)}function X(t,e){return W(t-k,e-M)}function Z(t,e){return Math.atan2(M-e,t-k)}function J(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function K(t,e){if(0===t)return s.pathSector(2*O);var r=D/t,n=e-r,i=e+r,a=Math.max(0,Math.min(t,d)),o=a-O,l=a+O;return\"M\"+J(o,n)+\"A\"+[o,o]+\" 0,0,0 \"+J(o,i)+\"L\"+J(l,i)+\"A\"+[l,l]+\" 0,0,1 \"+J(l,n)+\"Z\"}function Q(t,e,r){if(0===t)return s.pathSector(2*O);var n,i,a=J(t,e),o=J(t,r),l=I((a[0]+o[0])/2),c=I((a[1]+o[1])/2);if(l&&c){var u=c/l,f=-1/u,h=P(O,u,l,c);n=P(D,f,h[0][0],h[0][1]),i=P(D,f,h[1][0],h[1][1])}else{var p,d;c?(p=D,d=O):(p=O,d=D),n=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return\"M\"+n.join(\"L\")+\"L\"+i.reverse().join(\"L\")+\"Z\"}function $(t,e){return e=Math.max(Math.min(e,d),g),t<p?t=0:d-t<p?t=d:e<p?e=0:d-e<p&&(e=d),Math.abs(e-t)>h?(t<e?(N=t,j=e):(N=e,j=t),!0):(N=null,j=null,!1)}function tt(t,e){t=t||U,e=e||\"M0,0Z\",H.attr(\"d\",t),G.attr(\"d\",e),m.transitionZoombox(H,G,V,q),V=!0;var r={};at(r),c.emit(\"plotly_relayouting\",r)}function et(t,n){var i,a,o=F+(t*=e),l=B+(n*=r),c=X(F,B),u=Math.min(X(o,l),d),f=Z(F,B);$(c,u)&&(i=U+s.pathSector(j),N&&(i+=s.pathSector(N)),a=K(N,f)+K(j,f)),tt(i,a)}function rt(t,e,r,n){var i=E.findIntersectionXY(r,n,r,[t-k,M-e]);return W(i[0],i[1])}function nt(t,e){var r,n,i=F+t,a=B+e,o=Z(F,B),l=Z(i,a),c=z(o,C),u=z(l,C);$(rt(F,B,c[0],c[1]),Math.min(rt(i,a,u[0],u[1]),d))&&(r=U+s.pathSector(j),N&&(r+=s.pathSector(N)),n=[Q(N,c[0],c[1]),Q(j,c[0],c[1])].join(\" \")),tt(r,n)}function it(){if(m.removeZoombox(c),null!==N&&null!==j){var t={};at(t),m.showDoubleClickNotifier(c),a.call(\"_guiRelayout\",c,t)}}function at(t){var e=L._rl,r=(e[1]-e[0])/(1-g/d)/d,n=[e[0]+(N-g)*r,e[0]+(j-g)*r];t[s.id+\".radialaxis.range\"]=n}function ot(t,e){var r=c._fullLayout.clickmode;if(m.removeZoombox(c),2===t){var n={};for(var i in s.viewInitial)n[s.id+\".\"+i]=s.viewInitial[i];c.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",c,n)}r.indexOf(\"select\")>-1&&1===t&&_(e,c,[s.xaxis],[s.yaxis],s.id,Y),r.indexOf(\"event\")>-1&&y.click(c,e,s.id)}Y.prepFn=function(t,n,a){var l=c._fullLayout.dragmode,u=R.getBoundingClientRect();c._fullLayout._calcInverseTransform(c);var h=c._fullLayout._invTransform;e=c._fullLayout._invScaleX,r=c._fullLayout._invScaleY;var p=o.apply3DTransform(h)(n-u.left,a-u.top);if(F=p[0],B=p[1],C){var g=E.findPolygonOffset(d,A[0],A[1],C);F+=k+g[0],B+=M+g[1]}switch(l){case\"zoom\":Y.moveFn=C?nt:et,Y.clickFn=ot,Y.doneFn=it,function(){N=null,j=null,U=s.pathSubplot(),V=!1;var t=c._fullLayout[s.id];q=i(t.bgcolor).getLuminance(),(H=m.makeZoombox(f,q,x,T,U)).attr(\"fill-rule\",\"evenodd\"),G=m.makeCorners(f,x,T),w(c)}();break;case\"select\":case\"lasso\":b(t,n,a,Y,l)}},R.onmousemove=function(t){y.hover(c,t,s.id),c._fullLayout._lasthover=R,c._fullLayout._hoversubplot=s.id},R.onmouseout=function(t){c._dragging||v.unhover(c,t)},v.init(Y)},O.updateRadialDrag=function(t,e,r){var i=this,c=i.gd,u=i.layers,f=i.radius,h=i.innerRadius,p=i.cx,d=i.cy,g=i.radialAxis,y=S.radialDragBoxSize,x=y/2;if(g.visible){var b,_,T,A=I(i.radialAxisAngle),E=g._rl,C=E[0],L=E[1],z=E[r],O=.75*(E[1]-E[0])/(1-e.hole)/f;r?(b=p+(f+x)*Math.cos(A),_=d-(f+x)*Math.sin(A),T=\"radialdrag\"):(b=p+(h-x)*Math.cos(A),_=d-(h-x)*Math.sin(A),T=\"radialdrag-inner\");var D,B,N,j=m.makeRectDragger(u,T,\"crosshair\",-x,-x,y,y),U={element:j,gd:c};F(n.select(j),g.visible&&h<f,{transform:l(b,_)}),U.prepFn=function(){D=null,B=null,N=null,U.moveFn=V,U.doneFn=q,w(c)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<S.MINDRAG&&(t=0,e=0),[t,e]},v.init(U)}function V(t,e){if(D)D(t,e);else{var n=[t,-e],a=[Math.cos(A),Math.sin(A)],s=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(s)||(D=s<.5?H:G)}var l={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(l),c.emit(\"plotly_relayouting\",l)}function q(){null!==B?a.call(\"_guiRelayout\",c,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",c,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=b+t,a=_+e;B=Math.atan2(d-a,n-p),i.vangles&&(B=R(B,i.vangles)),B=P(B);var o=l(p,d)+s(-B);u[\"radial-axis\"].attr(\"transform\",o),u[\"radial-line\"].select(\"line\").attr(\"transform\",o);var c=i.gd._fullLayout,f=c[i.id];i.updateRadialAxisTitle(c,f,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(A),Math.sin(A)]);if(N=z-O*n,O>0==(r?N>C:N<L)){var s=c._fullLayout,l=s[i.id];g.range[r]=N,g._rl[r]=N,i.updateRadialAxis(s,l),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var f in i.traceHash){var h=i.traceHash[f],p=o.filterVisible(h);h[0][0].trace._module.plot(c,i,p,l),a.traceIs(f,\"gl\")&&p.length&&(u=!0)}u&&(k(c),M(c))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,c=e.radius,f=e.angularAxis,h=e.cx,p=e.cy,d=e.cxx,g=e.cyy,y=S.angularDragBoxSize,x=m.makeDragger(i,\"path\",\"angulardrag\",\"move\"),b={element:x,gd:r};function _(t,e){return Math.atan2(g+y-e,t-d-y)}n.select(x).attr(\"d\",e.pathAnnulus(c,c+y)).attr(\"transform\",l(h,p)).call(T,\"move\");var A,E,C,L,I,z,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),D=O.selectAll(\".point\"),R=O.selectAll(\".textpoint\");function F(c,m){var v=e.gd._fullLayout,y=v[e.id],x=_(A+c*t._invScaleX,E+m*t._invScaleY),b=P(x-z);if(L=C+b,i.frontplot.attr(\"transform\",l(e.xOffset2,e.yOffset2)+s([-b,d,g])),e.vangles){I=e.radialAxisAngle+b;var w=l(h,p)+s(-b),T=l(h,p)+s(-I);i.bg.attr(\"transform\",w),i[\"radial-grid\"].attr(\"transform\",w),i[\"radial-axis\"].attr(\"transform\",T),i[\"radial-line\"].select(\"line\").attr(\"transform\",T),e.updateRadialAxisTitle(v,y,I)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",l(d,g)+s(b));D.each((function(){var t=n.select(this),e=u.getTranslate(t);t.attr(\"transform\",l(e.x,e.y)+s([b]))})),R.each((function(){var t=n.select(this),e=t.select(\"text\"),r=u.getTranslate(t);t.attr(\"transform\",s([b,e.attr(\"x\"),e.attr(\"y\")])+l(r.x,r.y))})),f.rotation=o.modHalf(L,360),e.updateAngularAxis(v,y),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(u.hideOutsideRangePoints,e);var S=!1;for(var F in e.traceHash)if(a.traceIs(F,\"gl\")){var N=e.traceHash[F],j=o.filterVisible(N);N[0][0].trace._module.plot(r,e,j,y),j.length&&(S=!0)}S&&(k(r),M(r));var U={};B(U),r.emit(\"plotly_relayouting\",U)}function B(t){t[e.id+\".angularaxis.rotation\"]=L,e.vangles&&(t[e.id+\".radialaxis.angle\"]=I)}function N(){R.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}b.prepFn=function(n,i,a){var s=t[e.id];C=s.angularaxis.rotation;var l=x.getBoundingClientRect();A=i-l.left,E=a-l.top,r._fullLayout._calcInverseTransform(r);var c=o.apply3DTransform(t._invTransform)(A,E);A=c[0],E=c[1],z=_(A,E),b.moveFn=F,b.doneFn=N,w(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(b.prepFn=o.noop,T(n.select(x),null)),v.init(b)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?E.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?E.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../plot_api/subroutines\":818,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/dragbox\":836,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,\"./constants\":892,\"./helpers\":893,\"./set_convert\":904,d3:169,tinycolor2:576}],904:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",f=\"d\"+i,h=u in e?c(e[u]):0,p=e[f]?c(e[f]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=h+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,f=u.map(a),h={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return h*t+p},g=function(t){return(t-p)/h};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(f)?[u[0],u[0]+360]:f.map(g).map(o);break;case\"category\":var m=t._categories.length,v=t.period?Math.max(t.period,m):m;0===v&&(v=1),s=c=function(t){return 2*t*Math.PI/v},i=l=function(t){return t*v/Math.PI/2},t.range=[0,v]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":778,\"../cartesian/set_convert\":848}],905:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,f=o.handleDefaults,h=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function m(t,e){return n.coerce(s,l,u,t,e)}for(var v=0;v<d;v++){var y=p[v];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),m(\"uirevision\",e.uirevision);var x={};x[h]=[v/d,(v+1)/d],a(l,e,m,x),o.id=y,f(s,l,m,o)}}},{\"../lib\":778,\"../plot_api/plot_template\":817,\"./domain\":855}],906:[function(t,e,r){\"use strict\";['Variables are inserted using %{variable}, for example \"y: %{y}\".','Numbers are formatted using d3-format\\'s syntax %{variable:d3-format}, for example \"Price: %{y:$.2f}\".',t(\"../constants/docs\").FORMAT_LINK,\"for details on the formatting syntax.\",'Dates are formatted using d3-time-format\\'s syntax %{variable|d3-time-format}, for example \"Day: %{2019-01-01|%A}\".',t(\"../constants/docs\").DATE_FORMAT_LINK,\"for details on the date formatting syntax.\"].join(\" \");function n(t){var e=t.description?\" \"+t.description:\"\",r=t.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";e+=\"Finally, the template string has access to \",e=1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return e}r.hovertemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"calc\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{\"../constants/docs\":748}],907:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./layout_attributes\":908,\"./layout_defaults\":909,\"./ternary\":910}],908:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:{text:a.title.text,font:a.title.font},color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],909:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),f=t(\"./layout_attributes\"),h=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var f=0;f<h.length;f++)s=t[o=h[f]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,m=e.caxis;p.min+g.min+m.min>=u&&(p.min=0,g.min=0,m.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=f[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var h=o(\"color\"),p=h!==i.color.dflt?h:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,m=o(\"title.text\",g);e._hovertitle=m===g?m:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:h,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:f,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../subplot_defaults\":905,\"./layout_attributes\":908}],910:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strTranslate,l=o._,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,p=t(\"../plots\"),d=t(\"../cartesian/axes\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/fx\"),v=t(\"../../components/dragelement/helpers\"),y=v.freeMode,x=v.rectMode,b=t(\"../../components/titles\"),_=t(\"../cartesian/select\").prepSelect,w=t(\"../cartesian/select\").selectOnClick,T=t(\"../cartesian/select\").clearSelect,k=t(\"../cartesian/select\").clearSelectionsCache,M=t(\"../cartesian/constants\");function A(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=A;var S=A.prototype;S.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},S.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),p.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(c.fill,r.bgcolor)},S.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),u.setClipUrl(this.layers.backplot,n,e),u.setClipUrl(this.layers.grids,n,e)},S.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",(function(t){return\"toplevel \"+t})).each((function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach((function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)}))})),i.order()};var E=Math.sqrt(4/3);S.adjustLayout=function(t,e){var r,n,i,a,o,l,p=this,d=t.domain,g=(d.x[0]+d.x[1])/2,m=(d.y[0]+d.y[1])/2,v=d.x[1]-d.x[0],y=d.y[1]-d.y[0],x=v*e.w,b=y*e.h,_=t.sum,w=t.aaxis.min,T=t.baxis.min,k=t.caxis.min;x>E*b?i=(a=b)*E:a=(i=x)/E,o=v*i/x,l=y*a/b,r=e.l+e.w*g-i/2,n=e.t+e.h*(1-m)-a/2,p.x0=r,p.y0=n,p.w=i,p.h=a,p.sum=_,p.xaxis={type:\"linear\",range:[w+2*k-_,_-w-2*T],domain:[g-o/2,g+o/2],_id:\"x\"},f(p.xaxis,p.graphDiv._fullLayout),p.xaxis.setScale(),p.xaxis.isPtWithinRange=function(t){return t.a>=p.aaxis.range[0]&&t.a<=p.aaxis.range[1]&&t.b>=p.baxis.range[1]&&t.b<=p.baxis.range[0]&&t.c>=p.caxis.range[1]&&t.c<=p.caxis.range[0]},p.yaxis={type:\"linear\",range:[w,_-T-k],domain:[m-l/2,m+l/2],_id:\"y\"},f(p.yaxis,p.graphDiv._fullLayout),p.yaxis.setScale(),p.yaxis.isPtWithinRange=function(){return!0};var M=p.yaxis.domain[0],A=p.aaxis=h({},t.aaxis,{range:[w,_-T-k],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(A,p.graphDiv._fullLayout),A.setScale();var S=p.baxis=h({},t.baxis,{range:[_-w-k,T],side:\"bottom\",domain:p.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});f(S,p.graphDiv._fullLayout),S.setScale();var C=p.caxis=h({},t.caxis,{range:[_-w-T,k],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(C,p.graphDiv._fullLayout),C.setScale();var L=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDef.select(\"path\").attr(\"d\",L),p.layers.plotbg.select(\"path\").attr(\"d\",L);var I=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDefRelative.select(\"path\").attr(\"d\",I);var P=s(r,n);p.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),p.clipDefRelative.select(\"path\").attr(\"transform\",null);var z=s(r-S._offset,n+a);p.layers.baxis.attr(\"transform\",z),p.layers.bgrid.attr(\"transform\",z);var O=s(r+i/2,n)+\"rotate(30)\"+s(0,-A._offset);p.layers.aaxis.attr(\"transform\",O),p.layers.agrid.attr(\"transform\",O);var D=s(r+i/2,n)+\"rotate(-30)\"+s(0,-C._offset);p.layers.caxis.attr(\"transform\",D),p.layers.cgrid.attr(\"transform\",D),p.drawAxes(!0),p.layers.aline.select(\"path\").attr(\"d\",A.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(c.stroke,A.linecolor||\"#000\").style(\"stroke-width\",(A.linewidth||0)+\"px\"),p.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(c.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),p.layers.cline.select(\"path\").attr(\"d\",C.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(c.stroke,C.linecolor||\"#000\").style(\"stroke-width\",(C.linewidth||0)+\"px\"),p.graphDiv._context.staticPlot||p.initInteractions(),u.setClipUrl(p.layers.frontplot,p._hasClipOnAxisFalse?null:p.clipId,p.graphDiv)},S.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var s=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=b.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:l(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-s,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=b.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:l(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=b.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:l(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},S.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=d.calcTicks(t),f=d.clipEnds(t,u),h=d.makeTransTickFn(t),p=d.getTickSigns(t)[2],g=o.deg2rad(30),m=p*(t.linewidth||1)/2,v=p*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+m+\"l\"+Math.sin(g)*v+\",\"+Math.cos(g)*v:\"M\"+m+\",0l\"+Math.cos(g)*v+\",\"+-Math.sin(g)*v,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];d.drawTicks(r,t,{vals:\"inside\"===t.ticks?f:u,layer:s,path:b,transFn:h,crisp:!1}),d.drawGrid(r,t,{vals:f,layer:this.layers[i+\"grid\"],path:_,transFn:h,crisp:!1}),d.drawLabels(r,t,{vals:u,layer:s,transFn:h,labelFns:d.makeLabelFns(t,0,30)})};var C=M.MINZOOM/2+.87,L=\"m-0.87,.5h\"+C+\"v3h-\"+(C+5.2)+\"l\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l2.6,1.5l-\"+C/2+\",\"+.87*C+\"Z\",I=\"m0.87,.5h-\"+C+\"v3h\"+(C+5.2)+\"l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-2.6,1.5l\"+C/2+\",\"+.87*C+\"Z\",P=\"m0,1l\"+C/2+\",\"+.87*C+\"l2.6,-1.5l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-\"+(C/2+2.6)+\",\"+(.87*C+4.5)+\"l2.6,1.5l\"+C/2+\",-\"+.87*C+\"Z\",z=!0;function O(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}S.clearSelect=function(){k(this.dragOptions),T(this.dragOptions.gd)},S.initInteractions=function(){var t,e,r,n,f,h,p,d,v,b,T,k,A=this,S=A.layers.plotbg.select(\"path\").node(),C=A.graphDiv,D=C._fullLayout._zoomlayer;function R(t){var e={};return e[A.id+\".aaxis.min\"]=t.a,e[A.id+\".baxis.min\"]=t.b,e[A.id+\".caxis.min\"]=t.c,e}function F(t,e){var r=C._fullLayout.clickmode;O(C),2===t&&(C.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",C,R({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&w(e,C,[A.xaxis],[A.yaxis],A.id,A.dragOptions),r.indexOf(\"event\")>-1&&m.click(C,e,A.id)}function B(t,e){return 1-e/A.h}function N(t,e){return 1-(t+(A.h-e)/Math.sqrt(3))/A.w}function j(t,e){return(t-(A.h-e)/Math.sqrt(3))/A.w}function U(i,a){var o=r+i*t,s=n+a*e,l=Math.max(0,Math.min(1,B(0,n),B(0,s))),c=Math.max(0,Math.min(1,N(r,n),N(o,s))),u=Math.max(0,Math.min(1,j(r,n),j(o,s))),g=(l/2+u)*A.w,m=(1-l/2-c)*A.w,y=(g+m)/2,x=m-g,_=(1-l)*A.h,w=_-x/E;x<M.MINZOOM?(p=f,T.attr(\"d\",v),k.attr(\"d\",\"M0,0Z\")):(p={a:f.a+l*h,b:f.b+c*h,c:f.c+u*h},T.attr(\"d\",v+\"M\"+g+\",\"+_+\"H\"+m+\"L\"+y+\",\"+w+\"L\"+g+\",\"+_+\"Z\"),k.attr(\"d\",\"M\"+r+\",\"+n+\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2ZM\"+g+\",\"+_+L+\"M\"+m+\",\"+_+I+\"M\"+y+\",\"+w+P)),b||(T.transition().style(\"fill\",d>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),k.transition().style(\"opacity\",1).duration(200),b=!0),C.emit(\"plotly_relayouting\",R(p))}function V(){O(C),p!==f&&(a.call(\"_guiRelayout\",C,R(p)),z&&C.data&&C._context.showTips&&(o.notifier(l(C,\"Double-click to zoom back out\"),\"long\"),z=!1))}function q(t,e){var r=t/A.xaxis._m,n=e/A.yaxis._m,i=[(p={a:f.a-n,b:f.b+(r+n)/2,c:f.c-(r-n)/2}).a,p.b,p.c].sort(o.sorterAsc),a=i.indexOf(p.a),l=i.indexOf(p.b),c=i.indexOf(p.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),p={a:i[a],b:i[l],c:i[c]},e=(f.a-p.a)*A.yaxis._m,t=(f.c-p.c-f.b+p.b)*A.xaxis._m);var h=s(A.x0+t,A.y0+e);A.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var d=s(-t,-e);A.clipDefRelative.select(\"path\").attr(\"transform\",d),A.aaxis.range=[p.a,A.sum-p.b-p.c],A.baxis.range=[A.sum-p.a-p.c,p.b],A.caxis.range=[A.sum-p.a-p.b,p.c],A.drawAxes(!1),A._hasClipOnAxisFalse&&A.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(u.hideOutsideRangePoints,A),C.emit(\"plotly_relayouting\",R(p))}function H(){a.call(\"_guiRelayout\",C,R(p))}this.dragOptions={element:S,gd:C,plotinfo:{id:A.id,domain:C._fullLayout[A.id].domain,xaxis:A.xaxis,yaxis:A.yaxis},subplot:A.id,prepFn:function(a,l,u){A.dragOptions.xaxes=[A.xaxis],A.dragOptions.yaxes=[A.yaxis],t=C._fullLayout._invScaleX,e=C._fullLayout._invScaleY;var g=A.dragOptions.dragmode=C._fullLayout.dragmode;y(g)?A.dragOptions.minDrag=1:A.dragOptions.minDrag=void 0,\"zoom\"===g?(A.dragOptions.moveFn=U,A.dragOptions.clickFn=F,A.dragOptions.doneFn=V,function(t,e,a){var l=S.getBoundingClientRect();r=e-l.left,n=a-l.top,C._fullLayout._calcInverseTransform(C);var u=C._fullLayout._invTransform,g=o.apply3DTransform(u)(r,n);r=g[0],n=g[1],f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,h=A.aaxis.range[1]-f.a,d=i(A.graphDiv._fullLayout[A.id].bgcolor).getLuminance(),v=\"M0,\"+A.h+\"L\"+A.w/2+\", 0L\"+A.w+\",\"+A.h+\"Z\",b=!1,T=D.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",s(A.x0,A.y0)).style({fill:d>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",v),k=D.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",s(A.x0,A.y0)).style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),A.clearSelect(C)}(0,l,u)):\"pan\"===g?(A.dragOptions.moveFn=q,A.dragOptions.clickFn=F,A.dragOptions.doneFn=H,f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,A.clearSelect(C)):(x(g)||y(g))&&_(a,l,u,A.dragOptions,g)}},S.onmousemove=function(t){m.hover(C,t,A.id),C._fullLayout._lasthover=S,C._fullLayout._hoversubplot=A.id},S.onmouseout=function(t){C._dragging||g.unhover(C,t)},g.init(this.dragOptions)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../lib\":778,\"../../lib/extend\":768,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/constants\":834,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,d3:169,tinycolor2:576}],911:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),f=l.extendFlat,h=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in v(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&f(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,h=u.name;if(\"mapbox\"===h){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==h&&\"mapbox\"!==h||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),v(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&h(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function m(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function v(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&h(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&h(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&h(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":m(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":766,\"./lib/extend\":768,\"./lib/is_plain_object\":779,\"./lib/loggers\":782,\"./lib/noop\":787,\"./lib/push_unique\":793,\"./plots/attributes\":824,\"./plots/layout_attributes\":882}],912:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),f=o({},c,s(e.tileClass)),h=t._context||{};if(e.width&&(f.width=e.width),e.height&&(f.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){f.annotations=[];var p=Object.keys(f);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(f[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)f.annotations.push(e.annotations[r]);var g=Object.keys(f).filter((function(t){return t.match(/^scene\\d*$/)}));if(g.length){var m={};for(\"thumbnail\"===e.tileClass&&(m={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var v=f[g[r]];v.xaxis||(v.xaxis={}),v.yaxis||(v.yaxis={}),v.zaxis||(v.zaxis={}),a(v.xaxis,m),a(v.yaxis,m),a(v.zaxis,m),v._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:f,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:h.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":778,\"../registry\":911}],913:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.width=e.width||null,e.height=e.height||null,e.imageDataOnly=!0,new Promise((function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format.replace(\"-\",\".\"),c.then((function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)})).then((function(t){s(t)})).catch((function(t){r&&(r._snapshotInProgress=!1),l(t)}))}))}},{\"../lib\":778,\"../plot_api/to_image\":820,\"./filesaver\":914,\"./helpers\":915}],914:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise((function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var f=\"svg\"===r?\",\":\";base64,\";return i.octetStream(f+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))}))}},{\"../lib\":778,\"./helpers\":915}],915:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)},r.encodeJSON=function(t){return\"data:application/json,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});if(\"full-json\"===e)return new window.Blob([t],{type:\"application/json;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":911}],916:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":912,\"./download\":913,\"./helpers\":915,\"./svgtoimg\":917,\"./toimage\":918,\"./tosvg\":919}],917:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise((function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var f,h,p=t.canvas,d=t.scale||1,g=t.width||300,m=t.height||150,v=d*g,y=d*m,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?h=a.encodeSVG(l):(f=a.createBlob(l,\"svg\"),h=a.createObjectURL(f)),p.width=v,p.height=y,b.onload=function(){var r;switch(f=null,a.revokeObjectURL(h),\"svg\"!==c&&x.drawImage(b,0,0,v,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=h;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(f=null,a.revokeObjectURL(h),o(r),!t.promise)return e.emit(\"error\",r)},b.src=h}));return t.promise?r:e}},{\"../lib\":778,\"./helpers\":915,events:110}],918:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),f=u.gd;f.style.position=\"absolute\",f.style.left=\"-5000px\",document.body.appendChild(f);var h=o.getRedrawFunc(f);return i.call(\"plot\",f,u.data,u.layout,u.config).then(h).then((function(){var t=o.getDelay(f._fullLayout);setTimeout((function(){var t=l(f),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:f._fullLayout.width,height:f._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){f&&document.body.removeChild(f)}}),t)})).catch((function(t){r.emit(\"error\",t)})),r}},{\"../lib\":778,\"../registry\":911,\"./cloneplot\":912,\"./helpers\":915,\"./svgtoimg\":917,\"./tosvg\":919,events:110}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,f=t._fullLayout,h=f._paper,p=f._toppaper,d=f.width,g=f.height;h.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,f.paper_bgcolor);var m=f._basePlotModules||[];for(u=0;u<m.length;u++){var v=m[u];v.toSVG&&v.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&h.node().appendChild(b)}}if(f._draggers&&f._draggers.remove(),h.node().style.background=\"\",h.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each((function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()})),f._gradientUrlQueryParts){var _=[];for(var w in f._gradientUrlQueryParts)_.push(w);_.length&&h.selectAll(_.join(\",\")).each((function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}))}\"pdf\"!==e&&\"eps\"!==e||h.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),h.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),h.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(h.attr(\"width\",r*d),h.attr(\"height\",r*g),h.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var T=(new window.XMLSerializer).serializeToString(h.node());return T=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,(function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()}));return e.remove(),r}(T),T=(T=T.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(T=(T=(T=T.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),T}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],920:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],921:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/font_attributes\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=s({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),f=c({},n.marker.line.width,{dflt:0}),h=c({width:f,editType:\"calc\"},o(\"marker.line\")),p=c({line:h,editType:\"calc\"},o(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,texttemplate:a({editType:\"plot\"},{keys:l.eventDataKeys}),hovertext:n.hovertext,hovertemplate:i({},{keys:l.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:p,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"./constants\":923}],922:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,o=t(\"../../components/colorscale/calc\"),s=t(\"./arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,c,u,f,h=n.getFromId(t,e.xaxis||\"x\"),p=n.getFromId(t,e.yaxis||\"y\"),d={msUTC:!(!e.base&&0!==e.base)};\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\",d),u=p.makeCalcdata(e,\"y\"),c=i(e,p,\"y\",u),f=!!e.yperiodalignment):(r=p.makeCalcdata(e,\"y\",d),u=h.makeCalcdata(e,\"x\"),c=i(e,h,\"x\",u),f=!!e.xperiodalignment);for(var g=Math.min(c.length,r.length),m=new Array(g),v=0;v<g;v++)m[v]={p:c[v],s:r[v]},f&&(m[v].orig_p=u[v]),e.ids&&(m[v].id=String(e.ids[v]));return a(e,\"marker\")&&o(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),a(e,\"marker.line\")&&o(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),s(m,e),l(m,e),m}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":920}],923:[function(t,e,r){\"use strict\";e.exports={TEXTPAD:3,eventDataKeys:[\"value\",\"label\"]}},{}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,T;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,f=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=f(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=f(c,0,u);var h=n(o);for(o=h?o:0,a=0;a<s.length;a++)s[a].b=o,h&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":f(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.offset?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,f=a.length!==o.length,h=s*(1-n.gap),m=l(i,e._id)+c[0][0].trace.orientation,v=i._alignmentOpts[m]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,T=v[w.alignmentgroup]||{},k=Object.keys(T.offsetGroups||{}).length,M=(x=k?h/k:f?h/u:h)*(1-(n.groupgap||0));b=k?((2*w._offsetIndex+1-k)*x-M)/2:f?((2*y+1-u)*x-M)/2:-M/2;var A=_[0].t;A.barwidth=M,A.poffset=b,A.bargroupwidth=h,A.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,f)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r];if(void 0===n[0].trace.base)for(var i=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),o=0;o<n.length;o++){var s=n[o];if(s.p!==a){var l=i.put(s.p,s.b+s.s);l&&(s.b=l)}}}}(o),i.norm?(v(o),y(r,o,i)):m(r,o)}(t,e,r,_,u),b.length&&f(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.base?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});h(e,o,i),function(t,e,r){var n,i,o,l,c,u,f=x(t),h=e.traces;for(l=0;l<h.length;l++)if(n=h[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<h.length;l++){n=h[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),m=g+d;u.b=g,u[f]=m,r.norm||(p.push(m),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],f=0;f<u.length;f++){var p=u[f];if(p.s!==a)p.b+p.s===o.get(p.p,p.s)&&(p._outmost=!0)}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&f(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var f=1e4/(c-l),h=s.round=function(t){return String(Math.round(f*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],m=g[o]-g.w/2;if(n(m)){var v=g[o]+g.w/2,y=h(g.p);s[y]?s[y]=[Math.min(m,s[y][0]),Math.max(v,s[y][1])]:s[y]=[m,v]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function f(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{unitMinDiff:n.xCat||n.yCat,sepNegVal:!1,overlapNoMerge:!n.norm});h(t,o,n),n.norm?(v(o),y(e,o,n)):m(e,o)}}function h(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,f=c._offset||c.offset,h=u.poffset;if(i(f)){for(o=Array.prototype.slice.call(f,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=h);for(r=o.length;r<s.length;r++)o.push(h);u.poffset=o}else void 0!==f&&(u.poffset=f);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===f){for(o=[],r=0;r<s.length;r++)o.push(h+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===f&&(u.poffset=h+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),f=0;f<a.length;f++){var h=a[f],p=h.w=u?c[f]:c;h[n]=h.p+(l?s[f]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,f=n[a],h=f[0],p=h.trace,d=[];for(u=0;u<f.length;u++)l=(o=f[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=h.t,m=g.poffset,v=g.barwidth,y=Array.isArray(m),x=Array.isArray(v);for(u=0;u<f.length;u++){o=f[u];var b=y?m[u]:m,_=x?v[u]:v;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function m(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!1,u=0;u<a.length;u++){var f=a[u],h=f.b,p=h+f.s;f[n]=p,l.push(p),f.hasB&&l.push(h),f.hasB&&f.b||(c=!0)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:c,padded:!0})}}function v(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),f=\"stack\"===r.mode?l:u;function h(e){return n(t.c2l(e))&&(e<u-c||e>f+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,m=[],v=!1,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var T=_.b,k=T+_.s;_[o]=k,m.push(k),y=y||h(k),_.hasB&&(m.push(T),y=y||h(T)),_.hasB&&_.b||(v=!0)}}g._extremes[t._id]=s.findExtremes(t,m,{tozero:v,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],f=0;f<a.length;f++){var h=a[f];if(!0===h.visible&&o.traceIs(h,\"bar\")&&h.xaxis===r._id&&h.yaxis===n._id&&(\"h\"===h.orientation?l.push(s[f]):c.push(s[f]),h._computePh))for(var p=t.calcdata[f],d=0;d<p.length;d++)\"function\"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),\"function\"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var g={xCat:\"category\"===r.type||\"multicategory\"===r.type,yCat:\"category\"===n.type||\"multicategory\"===n.type,mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,g),u(t,n,r,l,g)},setGroupPositions:u}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"./sieve.js\":934,\"fast-isnumeric\":241}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./style_defaults\"),c=t(\"../../plots/cartesian/constraints\").getAxisGroup,u=t(\"./attributes\"),f=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=c(r,a)+i,s=r._alignmentOpts||{},l=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var f=u[l];f?f.traces.push(e):f=u[l]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var h=n(\"offsetgroup\"),p=f.offsetGroups,d=p[h];h&&(d||(d=p[h]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function p(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),u=!(!1===o.moduleHasCliponaxis),h=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,g=Array.isArray(a)||\"auto\"===a,m=g||\"inside\"===a,v=g||\"outside\"===a;if(m||v){var y=f(i,\"textfont\",r.font),x=n.extendFlat({},y),b=!(t.textfont&&t.textfont.color);if(b&&delete x.color,f(i,\"insidetextfont\",x),d){var _=n.extendFlat({},y);b&&delete _.color,f(i,\"pathbar.textfont\",_)}v&&f(i,\"outsidetextfont\",y),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),u&&i(\"cliponaxis\"),h&&i(\"textangle\"),i(\"texttemplate\")}m&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,c){function f(r,i){return n.coerce(t,e,u,r,i)}if(o(t,e,c,f)){s(t,e,c,f),f(\"orientation\",e.x&&!e.y?\"h\":\"v\"),f(\"base\"),f(\"offset\"),f(\"width\"),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\");var h=f(\"textposition\");p(t,e,c,f,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),l(t,e,f,r,c);var d=(e.marker.line||{}).color,g=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");g(t,e,d||i.defaultLine,{axis:\"y\"}),g(t,e,d||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,u,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:p}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":921,\"./style_defaults\":936}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),\"h\"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":778,\"fast-isnumeric\":241,tinycolor2:576}],928:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth,l=t(\"../../plots/cartesian/axes\").hoverLabelText,c=t(\"../../constants/numerical\").BADNUM;function u(t,e,r,i){var a,s,u,f,h,p,d,g=t.cd,m=g[0].trace,v=g[0].t,y=\"closest\"===i,x=\"waterfall\"===m.type,b=t.maxHoverDistance;function _(t){return t[u]-t.w/2}function w(t){return t[u]+t.w/2}var T=y?_:function(t){return Math.min(_(t),t.p-v.bardelta/2)},k=y?w:function(t){return Math.max(w(t),t.p+v.bardelta/2)};function M(t,e){return n.inbox(t-a,e-a,b+Math.min(1,Math.abs(e-t)/d)-1)}function A(t){return M(T(t),k(t))}function S(t){var e=s,r=t.b,i=t[f];if(x){var a=Math.abs(t.rawS)||0;e>0?i+=a:e<0&&(i-=a)}return n.inbox(r-e,i-e,b+(i-e)/(i-r)-1)}\"h\"===m.orientation?(a=r,s=e,u=\"y\",f=\"x\",h=S,p=A):(a=e,s=r,u=\"x\",f=\"y\",p=S,h=A);var E=t[u+\"a\"],C=t[f+\"a\"];d=Math.abs(E.r2c(E.range[1])-E.r2c(E.range[0]));var L=n.getDistanceFunction(i,h,p,(function(t){return(h(t)+p(t))/2}));if(n.getClosest(g,L,t),!1!==t.index&&g[t.index].p!==c){y||(T=function(t){return Math.min(_(t),t.p-v.bargroupwidth/2)},k=function(t){return Math.max(w(t),t.p+v.bargroupwidth/2)});var I=g[t.index],P=m.base?I.b+I.s:I.s;t[f+\"0\"]=t[f+\"1\"]=C.c2p(I[f],!0),t[f+\"LabelVal\"]=P;var z=v.extents[v.extents.round(I.p)];t[u+\"0\"]=E.c2p(y?T(I):z[0],!0),t[u+\"1\"]=E.c2p(y?k(I):z[1],!0);var O=void 0!==I.orig_p;return t[u+\"LabelVal\"]=O?I.orig_p:I.p,t.labelLabel=l(E,t[u+\"LabelVal\"]),t.valueLabel=l(C,t[f+\"LabelVal\"]),t.baseLabel=l(C,I.b),t.spikeDistance=(S(I)+function(t){return M(_(t),w(t))}(I))/2-b,t[u+\"Spike\"]=E.c2p(I.p,!0),o(I,m,t),t.hovertemplate=m.hovertemplate,t}}function f(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=u(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,l=o[a.index];return a.color=f(s,l),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(l,s,a),[a]}},hoverOnBars:u,getTraceColor:f}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./helpers\":927}],929:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],animatable:!0,meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"./arrays_to_calcdata\":920,\"./attributes\":921,\"./calc\":922,\"./cross_trace_calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":928,\"./layout_attributes\":930,\"./layout_defaults\":931,\"./plot\":932,\"./select\":933,\"./style\":935}],930:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,f={},h=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===h){var g=d.xaxis+d.yaxis;f[g]&&(u=!0),f[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==h&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout_attributes\":930}],932:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,f=t(\"./uniform_text\"),h=f.recordMinTextSize,p=f.clearMinTextSize,d=t(\"./style\"),g=t(\"./helpers\"),m=t(\"./constants\"),v=t(\"./attributes\"),y=v.text,x=v.textposition,b=t(\"../../components/fx/helpers\").appendArrayPointValue,_=m.TEXTPAD;function w(t){return t.id}function T(t){if(t.ids)return w}function k(t,e){return t<e?1:-1}function M(t,e,r,n){var i;return!e.uniformtext.mode&&A(r)?(n&&(i=n()),t.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){i&&i()})).each(\"interrupt\",(function(){i&&i()}))):t}function A(t){return t&&t.duration>0}function S(t){return\"auto\"===t?0:t}function E(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),i=Math.abs(Math.cos(r));return{x:t.width*i+t.height*n,y:t.width*n+t.height*i}}function C(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||\"end\",u=\"end\"===c,f=\"start\"===c,h=((a.leftToRight||0)+1)/2,p=1-h,d=i.width,g=i.height,m=Math.abs(e-t),v=Math.abs(n-r),y=m>2*_&&v>2*_?_:0;m-=2*y,v-=2*y;var x=S(l);\"auto\"!==l||d<=m&&g<=v||!(d>m||g>v)||(d>v||g>m)&&d<g==m<v||(x+=90);var b=E(i,x),w=1;s&&(w=Math.min(1,m/b.x,v/b.y));var T=i.left*p+i.right*h,M=(i.top+i.bottom)/2,A=(t+_)*p+(e-_)*h,C=(r+n)/2,L=0,I=0;if(f||u){var P=(o?b.x:b.y)/2,z=o?k(t,e):k(r,n);o?f?(A=t+z*y,L=-z*P):(A=e-z*y,L=z*P):f?(C=r+z*y,I=-z*P):(C=n-z*y,I=z*P)}return{textX:T,textY:M,targetX:A,targetY:C,anchorX:L,anchorY:I,scale:w,rotate:x}}e.exports={plot:function(t,e,r,f,m,v){var w=e.xaxis,L=e.yaxis,I=t._fullLayout;m||(m={mode:I.barmode,norm:I.barmode,gap:I.bargap,groupgap:I.bargroupgap},p(\"bar\",I));var P=a.makeTraceGroups(f,r,\"trace bars\").each((function(r){var c=n.select(this),f=r[0].trace,p=\"waterfall\"===f.type,P=\"funnel\"===f.type,z=\"bar\"===f.type||P,O=0;p&&f.connector.visible&&\"between\"===f.connector.mode&&(O=f.connector.line.width/2);var D=\"h\"===f.orientation,R=A(m),F=a.ensureSingle(c,\"g\",\"points\"),B=T(f),N=F.selectAll(\"g.point\").data(a.identity,B);N.enter().append(\"g\").classed(\"point\",!0),N.exit().remove(),N.each((function(c,p){var T,A,P=n.select(this),F=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,L,D),B=F[0][0],N=F[0][1],j=F[1][0],U=F[1][1],V=0==(D?N-B:U-j);if(V&&z&&g.getLineWidth(f,c)&&(V=!1),V||(V=!(i(B)&&i(N)&&i(j)&&i(U))),c.isBlank=V,V&&(D?N=B:U=j),O&&!V&&(D?(B-=k(B,N)*O,N+=k(B,N)*O):(j-=k(j,U)*O,U+=k(j,U)*O)),\"waterfall\"===f.type){if(!V){var q=f[c.dir].marker;T=q.line.width,A=q.color}}else T=g.getLineWidth(f,c),A=c.mc||f.marker.color;function H(t){var e=n.round(T/2%1,2);return 0===m.gap&&0===m.groupgap?n.round(Math.round(t)-e,2):t}if(!t._context.staticPlot){var G=s.opacity(A)<1||T>.01?H:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?H(t):t>e?Math.ceil(t):Math.floor(t)};B=G(B,N,D),N=G(N,B,D),j=G(j,U,!D),U=G(U,j,!D)}var Y=M(a.ensureSingle(P,\"path\"),I,m,v);if(Y.style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",isNaN((N-B)*(U-j))||V&&t._context.staticPlot?\"M0,0Z\":\"M\"+B+\",\"+j+\"V\"+U+\"H\"+N+\"V\"+j+\"Z\").call(l.setClipUrl,e.layerClipId,t),!I.uniformtext.mode&&R){var W=l.makePointStyleFns(f);l.singlePointStyle(c,Y,f,W,t)}!function(t,e,r,n,i,s,c,f,p,m,v){var w,T=e.xaxis,A=e.yaxis,L=t._fullLayout;function I(e,r,n){return a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t)}var P=n[0].trace,z=\"h\"===P.orientation,O=function(t,e,r,n,i){var o,s=e[0].trace;o=s.texttemplate?function(t,e,r,n,i){var o=e[0].trace,s=a.castOption(o,r,\"texttemplate\");if(!s)return\"\";var l,c,f,h,p=\"waterfall\"===o.type,d=\"funnel\"===o.type;\"h\"===o.orientation?(l=\"y\",c=i,f=\"x\",h=n):(l=\"x\",c=n,f=\"y\",h=i);function g(t){return u(h,+t,!0).text}var m=e[r],v={};v.label=m.p,v.labelLabel=v[l+\"Label\"]=(y=m.p,u(c,y,!0).text);var y;var x=a.castOption(o,m.i,\"text\");(0===x||x)&&(v.text=x);v.value=m.s,v.valueLabel=v[f+\"Label\"]=g(m.s);var _={};b(_,o,m.i),p&&(v.delta=+m.rawS||m.s,v.deltaLabel=g(v.delta),v.final=m.v,v.finalLabel=g(v.final),v.initial=v.final-v.delta,v.initialLabel=g(v.initial));d&&(v.value=m.s,v.valueLabel=g(v.value),v.percentInitial=m.begR,v.percentInitialLabel=a.formatPercent(m.begR),v.percentPrevious=m.difR,v.percentPreviousLabel=a.formatPercent(m.difR),v.percentTotal=m.sumR,v.percenTotalLabel=a.formatPercent(m.sumR));var w=a.castOption(o,m.i,\"customdata\");w&&(v.customdata=w);return a.texttemplateString(s,v,t._d3locale,_,v,o._meta||{})}(t,e,r,n,i):s.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){return u(o?r:n,+t,!0).text}var f,h=i.textinfo,p=t[e],d=h.split(\"+\"),g=[],m=function(t){return-1!==d.indexOf(t)};m(\"label\")&&g.push((v=t[e].p,u(o?n:r,v,!0).text));var v;m(\"text\")&&(0===(f=a.castOption(i,p.i,\"text\"))||f)&&g.push(f);if(s){var y=+p.rawS||p.s,x=p.v,b=x-y;m(\"initial\")&&g.push(c(b)),m(\"delta\")&&g.push(c(y)),m(\"final\")&&g.push(c(x))}if(l){m(\"value\")&&g.push(c(p.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(f=a.formatPercent(p.begR),w&&(f+=\" of initial\"),g.push(f)),m(\"percent previous\")&&(f=a.formatPercent(p.difR),w&&(f+=\" of previous\"),g.push(f)),m(\"percent total\")&&(f=a.formatPercent(p.sumR),w&&(f+=\" of total\"),g.push(f))}return g.join(\"<br>\")}(e,r,n,i):g.getValue(s.text,r);return g.coerceString(y,o)}(L,n,i,T,A);w=function(t,e){var r=g.getValue(t.textposition,e);return g.coerceEnumerated(x,r)}(P,i);var D=\"stack\"===m.mode||\"relative\"===m.mode,R=n[i],F=!D||R._outmost;if(!O||\"none\"===w||(R.isBlank||s===c||f===p)&&(\"auto\"===w||\"inside\"===w))return void r.select(\"text\").remove();var B=L.font,N=d.getBarColor(n[i],P),j=d.getInsideTextFont(P,i,B,N),U=d.getOutsideTextFont(P,i,B),V=r.datum();z?\"log\"===T.type&&V.s0<=0&&(s=T.range[0]<T.range[1]?0:T._length):\"log\"===A.type&&V.s0<=0&&(f=A.range[0]<A.range[1]?A._length:0);var q,H,G,Y,W,X=Math.abs(c-s)-2*_,Z=Math.abs(p-f)-2*_;\"outside\"===w&&(F||R.hasB||(w=\"inside\"));if(\"auto\"===w)if(F){w=\"inside\",W=a.ensureUniformFontSize(t,j),q=I(r,O,W),H=l.bBox(q.node()),G=H.width,Y=H.height;var J=G<=X&&Y<=Z,K=G<=Z&&Y<=X,Q=z?X>=G*(Z/Y):Z>=Y*(X/G);G>0&&Y>0&&(J||K||Q)?w=\"inside\":(w=\"outside\",q.remove(),q=null)}else w=\"inside\";if(!q){W=a.ensureUniformFontSize(t,\"outside\"===w?U:j);var $=(q=I(r,O,W)).attr(\"transform\");if(q.attr(\"transform\",\"\"),H=l.bBox(q.node()),G=H.width,Y=H.height,q.attr(\"transform\",$),G<=0||Y<=0)return void q.remove()}var tt,et,rt=P.textangle;\"outside\"===w?(et=\"both\"===P.constraintext||\"outside\"===P.constraintext,tt=function(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,f=i.height,h=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*_?_:0:h>2*_?_:0;var d=1;l&&(d=s?Math.min(1,p/f):Math.min(1,h/u));var g=S(c),m=E(i,g),v=(s?m.x:m.y)/2,y=(i.left+i.right)/2,x=(i.top+i.bottom)/2,b=(t+e)/2,w=(r+n)/2,T=0,M=0,A=s?k(e,t):k(r,n);s?(b=e-A*o,T=A*v):(w=n+A*o,M=-A*v);return{textX:y,textY:x,targetX:b,targetY:w,anchorX:T,anchorY:M,scale:d,rotate:g}}(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt})):(et=\"both\"===P.constraintext||\"inside\"===P.constraintext,tt=C(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt,anchor:P.insidetextanchor}));tt.fontSize=W.size,h(P.type,tt,L),R.transform=tt,M(q,L,m,v).attr(\"transform\",a.getTextTransform(tt))}(t,e,P,r,p,B,N,j,U,m,v),e.layerClipId&&l.hideOutsideRangePoint(c,P.select(\"text\"),w,L,f.xcalendar,f.ycalendar)}));var j=!1===f.cliponaxis;l.setClipUrl(c,j?null:e.layerClipId,t)}));c.getComponentMethod(\"errorbars\",\"plot\")(t,P,e,m)},toMoveInsideBar:C}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./attributes\":921,\"./constants\":923,\"./helpers\":927,\"./style\":935,\"./uniform_text\":937,d3:169,\"fast-isnumeric\":241}],933:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var f=i[r],h=\"ct\"in f?f.ct:n(f,a,o,c,l);e.contains(h,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(f.x),y:o.c2d(f.y)}),f.selected=1):f.selected=0}return u}},{}],934:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a,{unitMinDiff:e.unitMinDiff});this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":753,\"../../lib\":778}],935:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./uniform_text\").resizeText,c=t(\"./attributes\"),u=c.textfont,f=c.insidetextfont,h=c.outsidetextfont,p=t(\"./helpers\");function d(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),g(t,e,r)}function g(t,e,r){t.selectAll(\"text\").each((function(t){var i=n.select(this),s=o.ensureUniformFontSize(r,m(i,t,e,r));a.font(i,s)}))}function m(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=_(e,r);a=y(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=x(r,e.i,i));return a}function v(t,e,r){return b(u,t.textfont,e,r)}function y(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),b(f,t.insidetextfont,e,a)}function x(t,e,r){var n=v(t,e,r);return b(h,t.outsidetextfont,e,n)}function b(t,e,r,n){e=e||{};var i=p.getValue(e.family,r),a=p.getValue(e.size,r),o=p.getValue(e.color,r);return{family:p.coerceString(t.family,i,n.family),size:p.coerceNumber(t.size,a,n.size),color:p.coerceColor(t.color,o,n.color)}}function _(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\");l(t,e,\"bar\");var r=e.size(),i=t._fullLayout;e.style(\"opacity\",(function(t){return t[0].trace.opacity})).each((function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")})),e.selectAll(\"g.points\").each((function(e){d(n.select(this),e[0].trace,t)})),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:g,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each((function(t){var i,s=n.select(this);if(t.selected){i=o.ensureUniformFontSize(r,m(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)}))}(t.selectAll(\"text\"),e,r)}(r,i,t):(d(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:y,getOutsideTextFont:x,getBarColor:_,resizeText:l}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./attributes\":921,\"./helpers\":927,\"./uniform_text\":937,d3:169}],936:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654}],937:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");function a(t){return\"_\"+t+\"Text_minsize\"}e.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=a(t),i=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<i,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,i)))}},clearMinTextSize:function(t,e){e[a(t)]=void 0},resizeText:function(t,e,r){var a=t._fullLayout,o=a[\"_\"+r+\"Text_minsize\"];if(o){var s,l=\"hide\"===a.uniformtext.mode;switch(r){case\"funnelarea\":case\"pie\":case\"sunburst\":s=\"g.slice\";break;case\"treemap\":s=\"g.slice, g.pathbar\";break;default:s=\"g.points > g.point\"}e.selectAll(s).each((function(t){var e=t.transform;e&&(e.scale=l&&e.hide?0:o/e.fontSize,n.select(this).select(\"text\").attr(\"transform\",i.getTextTransform(e)))}))}}}},{\"../../lib\":778,d3:169}],938:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatterpolar/attributes\":1261}],939:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),f=c.makeCalcdata(e,\"theta\"),h=e._length,p=new Array(h),d=u,g=f,m=0;m<h;m++)p[m]={p:g[m],s:d[m]};function v(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(v(\"width\"),v(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var f=c({},e.radialaxis,{_id:\"x\"}),h=e.angularaxis;o(t,h,f,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"../bar/cross_trace_calc\":924,\"../scatter/calc_selection\":1189}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":778,\"../bar/style_defaults\":936,\"../scatterpolar/defaults\":1263,\"./attributes\":938}],941:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,f=t.subplot,h=f.radialAxis,p=f.angularAxis,d=f.vangles,g=d?l:i.isPtInsideSector,m=t.maxHoverDistance,v=p._period||2*Math.PI,y=Math.abs(h.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);h.range[0]>h.range[1]&&(x+=Math.PI);if(n.getClosest(c,(function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?m+Math.min(1,Math.abs(t.thetag1-t.thetag0)/v)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0}),t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,f,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":683,\"../../lib\":778,\"../../plots/polar/helpers\":893,\"../bar/hover\":928,\"../scatterpolar/hover\":1265}],942:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"../scatterpolar/format_labels\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":894,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"../scatterpolar/format_labels\":1264,\"./attributes\":938,\"./calc\":939,\"./defaults\":940,\"./hover\":941,\"./layout_attributes\":943,\"./layout_defaults\":944,\"./plot\":945}],943:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],944:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":778,\"./layout_attributes\":943}],945:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,f=e.angularAxis,h=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var f=[s.findEnclosingVertexAngles(c,t.vangles)[0],(c+u)/2,s.findEnclosingVertexAngles(u,t.vangles)[1]];return s.pathPolygonAnnulus(n,i,c,u,f,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each((function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each((function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=f.c2g(t.p0),d=t.thetag1=f.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),m=(p+d)/2;t.ct=[l.c2p(g*Math.cos(m)),c.c2p(g*Math.sin(m))],e=h(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)})),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../plots/polar/helpers\":893,d3:169,\"fast-isnumeric\":241}],946:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",editType:\"calc\"},dy:{valType:\"number\",editType:\"calc\"},xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},q1:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},median:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},q3:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},lowerfence:{valType:\"data_array\",editType:\"calc\"},upperfence:{valType:\"data_array\",editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},notchspan:{valType:\"data_array\",editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],editType:\"calc\"},mean:{valType:\"data_array\",editType:\"calc\"},sd:{valType:\"data_array\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},quartilemethod:{valType:\"enumerated\",values:[\"linear\",\"exclusive\",\"inclusive\"],dflt:\"linear\",editType:\"calc\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../../lib\"),s=t(\"../../constants/numerical\").BADNUM,l=o._;e.exports=function(t,e){var r,c,y,x,b,_,w,T=t._fullLayout,k=i.getFromId(t,e.xaxis||\"x\"),M=i.getFromId(t,e.yaxis||\"y\"),A=[],S=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(y=k,x=\"x\",b=M,_=\"y\",w=!!e.yperiodalignment):(y=M,x=\"y\",b=k,_=\"x\",w=!!e.xperiodalignment);var E,C,L,I,P,z,O=function(t,e,r,i){var s,l=e+\"0\"in t,c=\"d\"+e in t;if(e in t||l&&c){var u=r.makeCalcdata(t,e);return[a(t,r,e,u),u]}s=l?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||o.isDateTime(t.name)&&\"date\"===r.type)?t.name:i;for(var f=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]),h=t._length,p=new Array(h),d=0;d<h;d++)p[d]=f;return[p]}(e,_,b,T[S]),D=O[0],R=O[1],F=o.distinctVals(D),B=F.vals,N=F.minDiff/2,j=\"all\"===(e.boxpoints||e.points)?o.identity:function(t){return t.v<E.lf||t.v>E.uf};if(e._hasPreCompStats){var U=e[x],V=function(t){return y.d2c((e[t]||[])[r])},q=1/0,H=-1/0;for(r=0;r<e._length;r++){var G=D[r];if(n(G)){if((E={}).pos=E[_]=G,w&&R&&(E.orig_p=R[r]),E.q1=V(\"q1\"),E.med=V(\"median\"),E.q3=V(\"q3\"),C=[],U&&o.isArrayOrTypedArray(U[r]))for(c=0;c<U[r].length;c++)(z=y.d2c(U[r][c]))!==s&&(u(P={v:z,i:[r,c]},e,[r,c]),C.push(P));if(E.pts=C.sort(f),I=(L=E[x]=C.map(h)).length,E.med!==s&&E.q1!==s&&E.q3!==s&&E.med>=E.q1&&E.q3>=E.med){var Y=V(\"lowerfence\");E.lf=Y!==s&&Y<=E.q1?Y:p(E,L,I);var W=V(\"upperfence\");E.uf=W!==s&&W>=E.q3?W:d(E,L,I);var X=V(\"mean\");E.mean=X!==s?X:I?o.mean(L,I):(E.q1+E.q3)/2;var Z=V(\"sd\");E.sd=X!==s&&Z>=0?Z:I?o.stdev(L,I,E.mean):E.q3-E.q1,E.lo=g(E),E.uo=m(E);var J=V(\"notchspan\");J=J!==s&&J>0?J:v(E,I),E.ln=E.med-J,E.un=E.med+J;var K=E.lf,Q=E.uf;e.boxpoints&&L.length&&(K=Math.min(K,L[0]),Q=Math.max(Q,L[I-1])),e.notched&&(K=Math.min(K,E.ln),Q=Math.max(Q,E.un)),E.min=K,E.max=Q}else{var $;o.warn([\"Invalid input - make sure that q1 <= median <= q3\",\"q1 = \"+E.q1,\"median = \"+E.med,\"q3 = \"+E.q3].join(\"\\n\")),$=E.med!==s?E.med:E.q1!==s?E.q3!==s?(E.q1+E.q3)/2:E.q1:E.q3!==s?E.q3:0,E.med=$,E.q1=E.q3=$,E.lf=E.uf=$,E.mean=E.sd=$,E.ln=E.un=$,E.min=E.max=$}q=Math.min(q,E.min),H=Math.max(H,E.max),E.pts2=C.filter(j),A.push(E)}}e._extremes[y._id]=i.findExtremes(y,[q,H],{padded:!0})}else{var tt=y.makeCalcdata(e,x),et=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(B,N),rt=B.length,nt=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(rt);for(r=0;r<e._length;r++)if(z=tt[r],n(z)){var it=o.findBin(D[r],et);it>=0&&it<rt&&(u(P={v:z,i:r},e,r),nt[it].push(P))}var at=1/0,ot=-1/0,st=e.quartilemethod,lt=\"exclusive\"===st,ct=\"inclusive\"===st;for(r=0;r<rt;r++)if(nt[r].length>0){var ut,ft;if((E={}).pos=E[_]=B[r],C=E.pts=nt[r].sort(f),I=(L=E[x]=C.map(h)).length,E.min=L[0],E.max=L[I-1],E.mean=o.mean(L,I),E.sd=o.stdev(L,I,E.mean),E.med=o.interp(L,.5),I%2&&(lt||ct))lt?(ut=L.slice(0,I/2),ft=L.slice(I/2+1)):ct&&(ut=L.slice(0,I/2+1),ft=L.slice(I/2)),E.q1=o.interp(ut,.5),E.q3=o.interp(ft,.5);else E.q1=o.interp(L,.25),E.q3=o.interp(L,.75);E.lf=p(E,L,I),E.uf=d(E,L,I),E.lo=g(E),E.uo=m(E);var ht=v(E,I);E.ln=E.med-ht,E.un=E.med+ht,at=Math.min(at,E.ln),ot=Math.max(ot,E.un),E.pts2=C.filter(j),A.push(E)}e._extremes[y._id]=i.findExtremes(y,e.notched?tt.concat([at,ot]):tt,{padded:!0})}return function(t,e){if(o.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],i={},a=0;a<n.length;a++)i[n[a].i]=a;o.tagSelected(n,e,i)}}(A,e),A.length>0?(A[0].t={num:T[S],dPos:N,posLetter:_,valLetter:x,labels:{med:l(t,\"median:\"),min:l(t,\"min:\"),q1:l(t,\"q1:\"),q3:l(t,\"q3:\"),max:l(t,\"max:\"),mean:\"sd\"===e.boxmean?l(t,\"mean \\xb1 \\u03c3:\"):l(t,\"mean:\"),lf:l(t,\"lower fence:\"),uf:l(t,\"upper fence:\")}},T[S]++,A):[{t:{empty:!0}}]};var c={text:\"tx\",hovertext:\"htx\"};function u(t,e,r){for(var n in c)o.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?o.isArrayOrTypedArray(e[n][r[0]])&&(t[c[n]]=e[n][r[0]][r[1]]):t[c[n]]=e[n][r])}function f(t,e){return t.v-e.v}function h(t){return t.v}function p(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(o.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function d(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(o.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function g(t){return 4*t.q1-3*t.q3}function m(t){return 4*t.q3-3*t.q1}function v(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"fast-isnumeric\":241}],948:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/constraints\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,f=e._fullLayout,h=o._id,p=h.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),g+=(c[l].pts2||[]).length;if(d.length){var m=i.distinctVals(d,{unitMinDiff:\"category\"===o.type||\"multicategory\"===o.type}),v=m.minDiff/2;n.minDtick(o,m.minDiff,m.vals[0],!0);var y=f[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===f[t+\"mode\"]&&y>1,b=1-f[t+\"gap\"],_=1-f[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,T,k,M,A,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,I=E.side;if(L)w=T=M=L/2,k=0;else if(w=v,x){var P=a(f,o._id)+E.orientation,z=(f._alignmentOpts[P]||{})[E.alignmentgroup]||{},O=Object.keys(z.offsetGroups||{}).length,D=O||y;T=w*b*_/D,k=2*w*(((O?E._offsetIndex:C.num)+.5)/D-.5)*b,M=w*b/D}else T=w*b*_,k=0,M=w;C.dPos=w,C.bPos=k,C.bdPos=T,C.wHover=M;var R,F,B,N,j,U,V=k+T,q=Boolean(L);if(\"positive\"===I?(A=w*(L?1:.5),R=V,S=R=k):\"negative\"===I?(A=R=k,S=w*(L?1:.5),F=V):(A=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>A?(q=!0,j=Y,B=W):W>R&&(j=Y,B=A)),W<=A&&(B=A);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=A,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[h]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(f)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835}],949:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../scatter/period_defaults\"),s=t(\"../bar/defaults\").handleGroupingDefaults,l=t(\"../../plots/cartesian/axis_autotype\"),c=t(\"./attributes\");function u(t,e,r,a){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function s(e){return n.validate(t[e],c[e])}var u,f=r(\"y\"),h=r(\"x\");if(\"box\"===e.type){var p=r(\"q1\"),d=r(\"median\"),g=r(\"q3\");e._hasPreCompStats=p&&p.length&&d&&d.length&&g&&g.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(g))}var m,v,y=o(f),x=o(h),b=y&&n.minRowLength(f),_=x&&n.minRowLength(h),w=a.calendar,T={autotypenumbers:a.autotypenumbers};if(e._hasPreCompStats)switch(String(x)+String(y)){case\"00\":var k=s(\"x0\")||s(\"dx\");m=(s(\"y0\")||s(\"dy\"))&&!k?\"h\":\"v\",v=u;break;case\"10\":m=\"v\",v=Math.min(u,_);break;case\"20\":m=\"h\",v=Math.min(u,h.length);break;case\"01\":m=\"h\",v=Math.min(u,b);break;case\"02\":m=\"v\",v=Math.min(u,f.length);break;case\"12\":m=\"v\",v=Math.min(u,_,f.length);break;case\"21\":m=\"h\",v=Math.min(u,h.length,b);break;case\"11\":v=0;break;case\"22\":var M,A=!1;for(M=0;M<h.length;M++)if(\"category\"===l(h[M],w,T)){A=!0;break}if(A)m=\"v\",v=Math.min(u,_,f.length);else{for(M=0;M<f.length;M++)if(\"category\"===l(f[M],w,T)){A=!0;break}A?(m=\"h\",v=Math.min(u,h.length,b)):(m=\"v\",v=Math.min(u,_,f.length))}}else y>0?(m=\"v\",v=x>0?Math.min(_,b):Math.min(b)):x>0?(m=\"h\",v=Math.min(_)):v=0;if(v){e._length=v;var S=r(\"orientation\",m);e._hasPreCompStats?\"v\"===S&&0===x?(r(\"x0\",0),r(\"dx\",1)):\"h\"===S&&0===y&&(r(\"y0\",0),r(\"dy\",1)):\"v\"===S&&0===x?r(\"x0\"):\"h\"===S&&0===y&&r(\"y0\"),i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a)}else e.visible=!1}function f(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,c,\"marker.outliercolor\"),s=r(\"marker.line.outliercolor\"),l=\"outliers\";e._hasPreCompStats?l=\"all\":(o||s)&&(l=\"suspectedoutliers\");var u=r(a+\"points\",l);u?(r(\"jitter\",\"all\"===u?.3:0),r(\"pointpos\",\"all\"===u?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===u&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var f=r(\"hoveron\");\"all\"!==f&&-1===f.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function s(r,i){return n.coerce(t,e,c,r,i)}if(u(t,e,s,i),!1!==e.visible){o(t,e,i,s);var l=e._hasPreCompStats;l&&(s(\"lowerfence\"),s(\"upperfence\")),s(\"line.color\",(t.marker||{}).color||r),s(\"line.width\"),s(\"fillcolor\",a.addOpacity(e.line.color,.5));var h=!1;if(l){var p=s(\"mean\"),d=s(\"sd\");p&&p.length&&(h=!0,d&&d.length&&(h=\"sd\"))}s(\"boxmean\",h),s(\"whiskerwidth\"),s(\"width\"),s(\"quartilemethod\");var g=!1;if(l){var m=s(\"notchspan\");m&&m.length&&(g=!0)}else n.validate(t.notchwidth,c.notchwidth)&&(g=!0);s(\"notched\",g)&&s(\"notchwidth\"),f(t,e,s,{prefix:\"box\"})}},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,c,t)}for(var o=0;o<t.length;o++){var l=(i=t[o]).type;\"box\"!==l&&\"violin\"!==l||(r=i._input,\"group\"===e[l+\"mode\"]&&s(r,i,e,a))}},handleSampleDefaults:u,handlePointsDefaults:f}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../registry\":911,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"./attributes\":946}],950:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],951:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w=t.cd,T=t.xa,k=t.ya,M=w[0].trace,A=w[0].t,S=\"violin\"===M.type,E=[],C=A.bdPos,L=A.wHover,I=function(t){return u.c2l(t.pos)+A.bPos-u.c2l(p)};S&&\"both\"!==M.side?(\"positive\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e,e+L,v)},x=C,b=0),\"negative\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e-L,e,v)},x=0,b=C)):(m=function(t){var e=I(t);return a.inbox(e-L,e+L,v)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-h,t.span[1]-h,v)}:function(t){return a.inbox(t.min-h,t.max-h,v)},\"h\"===M.orientation?(h=e,p=r,d=_,g=m,l=\"y\",u=k,c=\"x\",f=T):(h=r,p=e,d=m,g=_,l=\"x\",u=T,c=\"y\",f=k);var P=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}v=t.maxHoverDistance-P,y=t.maxSpikeDistance-P;var O=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,O,t),!1===t.index)return[];var D=w[t.index],R=M.line.color,F=(M.marker||{}).color;o.opacity(R)&&M.line.width?t.color=R:o.opacity(F)&&M.boxpoints?t.color=F:t.color=M.fillcolor,t[l+\"0\"]=u.c2p(D.pos+A.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+A.bPos+x,!0),t[l+\"LabelVal\"]=void 0!==D.orig_p?D.orig_p:D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/v,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(M.boxmean||(M.meanline||{}).visible)&&j.push(\"mean\"),(M.boxpoints||M.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=f.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(A.labels?A.labels[V]+\" \":\"\")+n.hoverLabelText(f,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===M.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,f=t.ya,h=c[0].trace,p=u.c2p(e),d=f.c2p(r),g=a.quadrature((function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)}),(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(f.c2p(t.y)-d)-e,1-3/e)})),m=!1,v=0;v<c.length;v++){o=c[v];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,m=[v,y])}}if(!m)return!1;l=(o=c[m[0]]).pts[m[1]];var b=u.c2p(l.x,!0),_=f.c2p(l.y,!0),w=l.mrc||1;n=i.extendFlat({},t,{index:l.i,color:(h.marker||{}).color,name:h.name,x0:b-w,x1:b+w,y0:_-w,y1:_+w,spikeDistance:t.distance,hovertemplate:h.hovertemplate});var T,k=o.orig_p,M=void 0!==k?k:o.pos;return\"h\"===h.orientation?(T=f,n.xLabelVal=l.x,n.yLabelVal=M):(T=u,n.xLabelVal=M,n.yLabelVal=l.y),n[T._id.charAt(0)+\"Spike\"]=T.c2p(o.pos,!0),s(l,h,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],952:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":946,\"./calc\":947,\"./cross_trace_calc\":948,\"./defaults\":949,\"./event_data\":950,\"./hover\":951,\"./layout_attributes\":953,\"./layout_defaults\":954,\"./plot\":955,\"./select\":956,\"./style\":957}],953:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,(function(r,n){return i.coerce(t,e,a,r,n)}),\"box\")},_supply:o}},{\"../../lib\":778,\"../../registry\":911,\"./layout_attributes\":953}],955:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\");function o(t,e,r,a){var o,s,l=\"h\"===r.orientation,c=e.val,u=e.pos,f=!!u.rangebreaks,h=a.bPos,p=a.wdPos||0,d=a.bPosPxOffset||0,g=r.whiskerwidth||0,m=r.notched||!1,v=m?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var y=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);y.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),y.exit().remove(),y.each((function(t){if(t.empty)return\"M0,0Z\";var e=u.c2l(t.pos+h,!0),a=u.l2p(e-o)+d,y=u.l2p(e+s)+d,x=f?(a+y)/2:u.l2p(e)+d,b=r.whiskerwidth,_=f?a*b+(1-b)*x:u.l2p(e-p)+d,w=f?y*b+(1-b)*x:u.l2p(e+p)+d,T=u.l2p(e-o*v)+d,k=u.l2p(e+s*v)+d,M=c.c2p(t.q1,!0),A=c.c2p(t.q3,!0),S=i.constrain(c.c2p(t.med,!0),Math.min(M,A)+1,Math.max(M,A)-1),E=void 0===t.lf||!1===r.boxpoints,C=c.c2p(E?t.min:t.lf,!0),L=c.c2p(E?t.max:t.uf,!0),I=c.c2p(t.ln,!0),P=c.c2p(t.un,!0);l?n.select(this).attr(\"d\",\"M\"+S+\",\"+T+\"V\"+k+\"M\"+M+\",\"+a+\"V\"+y+(m?\"H\"+I+\"L\"+S+\",\"+k+\"L\"+P+\",\"+y:\"\")+\"H\"+A+\"V\"+a+(m?\"H\"+P+\"L\"+S+\",\"+T+\"L\"+I+\",\"+a:\"\")+\"ZM\"+M+\",\"+x+\"H\"+C+\"M\"+A+\",\"+x+\"H\"+L+(0===g?\"\":\"M\"+C+\",\"+_+\"V\"+w+\"M\"+L+\",\"+_+\"V\"+w)):n.select(this).attr(\"d\",\"M\"+T+\",\"+S+\"H\"+k+\"M\"+a+\",\"+M+\"H\"+y+(m?\"V\"+I+\"L\"+k+\",\"+S+\"L\"+y+\",\"+P:\"\")+\"V\"+A+\"H\"+a+(m?\"V\"+P+\"L\"+T+\",\"+S+\"L\"+a+\",\"+I:\"\")+\"ZM\"+x+\",\"+M+\"V\"+C+\"M\"+x+\",\"+A+\"V\"+L+(0===g?\"\":\"M\"+_+\",\"+C+\"H\"+w+\"M\"+_+\",\"+L+\"H\"+w))}))}function s(t,e,r,n){var o=e.x,s=e.y,l=n.bdPos,c=n.bPos,u=r.boxpoints||r.points;i.seedPseudoRandom();var f=t.selectAll(\"g.points\").data(u?function(t){return t.forEach((function(t){t.t=n,t.trace=r})),t}:[]);f.enter().append(\"g\").attr(\"class\",\"points\"),f.exit().remove();var h=f.selectAll(\"path\").data((function(t){var e,n,a=t.pts2,o=Math.max((t.max-t.min)/10,t.q3-t.q1),s=1e-9*o,f=.01*o,h=[],p=0;if(r.jitter){if(0===o)for(p=1,h=new Array(a.length),e=0;e<a.length;e++)h[e]=1;else for(e=0;e<a.length;e++){var d=Math.max(0,e-5),g=a[d].v,m=Math.min(a.length-1,e+5),v=a[m].v;\"all\"!==u&&(a[e].v<t.lf?v=Math.min(v,t.lf):g=Math.max(g,t.uf));var y=Math.sqrt(f*(m-d)/(v-g+s))||0;y=i.constrain(Math.abs(y),0,1),h.push(y),p=Math.max(y,p)}n=2*r.jitter/(p||1)}for(e=0;e<a.length;e++){var x=a[e],b=x.v,_=r.jitter?n*h[e]*(i.pseudoRandom()-.5):0,w=t.pos+c+l*(r.pointpos+_);\"h\"===r.orientation?(x.y=w,x.x=b):(x.x=w,x.y=b),\"suspectedoutliers\"===u&&b<t.uo&&b>t.lo&&(x.so=!0)}return a}));h.enter().append(\"path\").classed(\"point\",!0),h.exit().remove(),h.call(a.translatePoints,o,s)}function l(t,e,r,a){var o,s,l=e.val,c=e.pos,u=!!c.rangebreaks,f=a.bPos,h=a.bPosPxOffset||0,p=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var d=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);d.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),d.exit().remove(),d.each((function(t){var e=c.c2l(t.pos+f,!0),i=c.l2p(e-o)+h,a=c.l2p(e+s)+h,d=u?(i+a)/2:c.l2p(e)+h,g=l.c2p(t.mean,!0),m=l.c2p(t.mean-t.sd,!0),v=l.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+g+\",\"+i+\"V\"+a+(\"sd\"===p?\"m0,0L\"+m+\",\"+d+\"L\"+g+\",\"+i+\"L\"+v+\",\"+d+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+g+\"H\"+a+(\"sd\"===p?\"m0,0L\"+d+\",\"+m+\"L\"+i+\",\"+g+\"L\"+d+\",\"+v+\"Z\":\"\"))}))}e.exports={plot:function(t,e,r,a){var c=e.xaxis,u=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each((function(t){var e,r,i=n.select(this),a=t[0],f=a.t,h=a.trace;(f.wdPos=f.bdPos*h.whiskerwidth,!0!==h.visible||f.empty)?i.remove():(\"h\"===h.orientation?(e=u,r=c):(e=c,r=u),o(i,{pos:e,val:r},h,f),s(i,{x:c,y:u},h,f),l(i,{pos:e,val:r},h,f))}))},plotBoxAndWhiskers:o,plotPoints:s,plotBoxMean:l}},{\"../../components/drawing\":665,\"../../lib\":778,d3:169}],956:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],957:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each((function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}}));else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}}))},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],958:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":778,\"../box/attributes\":946,\"../ohlc/attributes\":1133}],959:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../ohlc/calc\").calcCommon;function s(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,l=i.getFromId(t,e.xaxis),c=i.getFromId(t,e.yaxis),u=l.makeCalcdata(e,\"x\"),f=a(e,l,\"x\",u),h=o(t,e,u,f,c,s);return h.length?(n.extendFlat(h[0].t,{num:r._numBoxes,dPos:n.distinctVals(f).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,h):[{t:{empty:!0}}]}},{\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../ohlc/calc\":1134}],960:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"../scatter/period_defaults\"),s=t(\"./attributes\");function l(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}a(t,e,c,i)?(o(t,e,i,c,{x:!0}),c(\"line.width\"),l(t,e,c,\"increasing\"),l(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../ohlc/ohlc_defaults\":1138,\"../scatter/period_defaults\":1207,\"./attributes\":958}],961:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":841,\"../box/cross_trace_calc\":948,\"../box/layout_attributes\":953,\"../box/layout_defaults\":954,\"../box/plot\":955,\"../box/style\":957,\"../ohlc/hover\":1136,\"../ohlc/select\":1140,\"./attributes\":958,\"./calc\":959,\"./defaults\":960}],962:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach((function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,autotypenumbersDflt:r.autotypenumbers,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})}))}(t,e,r,o)}},{\"../../plot_api/plot_template\":817,\"./axis_defaults\":967}],963:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;for(var i=1/0,a=-1/0,o=e.length,s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":778}],964:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":642,\"../../plots/font_attributes\":856,\"./axis_attributes\":966}],965:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g,m,v,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,T=\"a\"===y?e.a.length:e.b.length,k=\"a\"===y?e.b.length:e.a.length,M=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),A=\"a\"===y?function(e){return t.evalxy([],e,M)}:function(e){return t.evalxy([],M,e)};x&&(s=Math.max(0,Math.min(k-2,M)),l=M-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),I=C>0?Math.floor:Math.ceil,P=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,O=C>0?Math.max:Math.min,D=I(S+L),R=P(E-L),F=[[f=A(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=O(S,a),v=(m=z(E,a+C))-g,u=Math.max(0,Math.min(T-2,Math.floor(.5*(g+m)))),h=A(m),x&&(p=o(u,g-u),d=o(u,m-u),c.push([f[0]+p[0]/3*v,f[1]+p[1]/3*v]),c.push([h[0]-d[0]/3*v,h[1]-d[1]/3*v])),c.push(h),F.push(c),f=h;return F}},{\"../../lib\":778}],966:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autotypenumbers:a.autotypenumbers,autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../constants/docs\":748,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],967:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),f=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var h=r.letter,p=r.font||{},d=n[h+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function m(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name),g(\"autotypenumbers\",r.autotypenumbersDflt);var v=g(\"type\");(\"-\"===v&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=f(e,n,{autotypenumbers:t.autotypenumbers})}(e,r.data),\"-\"===e.type?e.type=\"linear\":v=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",h+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"minexponent\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=h,\"date\"===v)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,v),l(t,e,g,v,r),c(t,e,g,{data:r.data,dataAttr:h});var b=m(\"gridcolor\",i(y,.3)),_=m(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var T=m(\"startlinecolor\",y),k=m(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!T||!!k)||(delete e.startlinecolor,delete e.startlinewidth);var M=m(\"endlinecolor\",y),A=m(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!M||!!A)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.minexponent,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../plots/cartesian/category_order_defaults\":832,\"../../plots/cartesian/set_convert\":848,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_value_defaults\":851,\"../../registry\":911,\"./attributes\":964}],968:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),f=t(\"./smooth_fill_2d_array\"),h=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,m=e.baxis,v=e.x,y=e.y,x=[];v&&i(v)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&h(e,g,m,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;v=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var T=\"index\"===g.cheatertype?b.length:b,k=\"index\"===m.cheatertype?_.length:_;v=a(T,k,e.cheaterslope)}e._x=v=u(v),e._y=y=u(y),f(v,b,_),f(y,b,_),p(e),e.setScale();var M=o(v),A=o(y),S=.5*(M[1]-M[0]),E=.5*(M[1]+M[0]),C=.5*(A[1]-A[0]),L=.5*(A[1]+A[0]);return M=[E-1.3*S,E+1.3*S],A=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,M,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,A,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,m),w.clipsegments=c(e._xctrl,e._yctrl,g,m),w.x=v,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"./array_minmax\":963,\"./calc_clippath\":969,\"./calc_gridlines\":970,\"./calc_labels\":971,\"./cheater_basis\":973,\"./set_convert\":986,\"./smooth_fill_2d_array\":987}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,f=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=f;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[f][i],o[u-i]=e[f][i];for(s.push({x:a,y:o,bicubic:l}),i=f,a=[],o=[];i>=0;i--)a[f-i]=t[i][0],o[f-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,f,h,p,d,g,m,v,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],T=b._boundarylines=[],k=t[\"_\"+r],M=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var A=t._xctrl,S=t._yctrl,E=A[0].length,C=A.length,L=t._a.length,I=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var P=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,f,p,d,g,m,v=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(I-2,a))),s=a-o,x.length=I,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,f=t.evalxy([],i,a),M.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),v.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),v.push(f[0]-d[0]/3),y.push(f[1]-d[1]/3)),v.push(f[0]),y.push(f[1]),l=f;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=I,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<I;a++)o=Math.min(I-2,a),s=a-o,f=t.evalxy([],i,a),M.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),v.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),m=t.dxydj([],c,a-1,u,1),v.push(f[0]-m[0]/3),y.push(f[1]-m[1]/3)),v.push(f[0]),y.push(f[1]),l=f;return x.axisLetter=e,x.axis=b,x.crossAxis=M,x.value=n,x.constvar=r,x.index=h,x.x=v,x.y=y,x.smoothing=M.smoothing,x}function O(n){var i,a,o,s,l,c=[],u=[],f={};if(f.length=x.length,f.crossLength=k.length,\"b\"===e)for(o=Math.max(0,Math.min(I-2,n)),l=Math.min(1,Math.max(0,n-o)),f.xy=function(e){return t.evalxy([],e,n)},f.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=A[n*P][i],u[i]=S[n*P][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),f.xy=function(e){return t.evalxy([],n,e)},f.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=A[i][n*P],u[i]=S[i][n*P];return f.axisLetter=e,f.axis=b,f.crossAxis=M,f.value=x[n],f.constvar=r,f.index=n,f.x=c,f.y=u,f.smoothing=M.smoothing,f}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort((function(t,e){return t-e})))[0]-1,f=c[1]+1,h=u;h<f;h++)(o=b.arraytick0+b.arraydtick*h)<0||o>x.length-1||_.push(i(O(o),{color:b.gridcolor,width:b.gridwidth}));for(h=u;h<f;h++)if(s=b.arraytick0+b.arraydtick*h,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(m=x[s],v=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=m+(v-m)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(O(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(O(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort((function(t,e){return t-e})))[0],f=c[1],h=u;h<=f;h++)p=b.tick0+b.dtick*h,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(h=u-1;h<f+1;h++)for(p=b.tick0+b.dtick*h,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],971:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],972:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,f=(c*c*a-l*l*s)*n,h=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(h&&u/h),e[1]+(h&&f/h)],[e[0]-(p&&u/p),e[1]-(p&&f/p)]]}},{}],973:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],f=n(t)?t.length:t,h=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(f-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(h-1));var g=1/0,m=-1/0;for(a=0;a<h;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(h-1),i=0;i<f;i++)c=(p?(p[i]-p[0])*o:i/(f-1))-l*r,g=Math.min(c,g),m=Math.max(c,m),u[a][i]=c;var v=1/(m-g),y=-g*v;for(a=0;a<h;a++)for(i=0;i<f;i++)u[a][i]=v*u[a][i]+y;return u}},{\"../../lib\":778}],974:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,f,h,p,d,g,m,v,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),f=0;f<w;f++)t[f]=i(t[f],_),e[f]=i(e[f],_);for(u=0,h=0;u<b;u++,h+=l?3:1)for(p=t[h],d=e[h],g=r[u],m=o[u],c=0,f=0;c<x;c++,f+=s?3:1)p[f]=g[c],d[f]=m[c];if(s)for(u=0,h=0;u<b;u++,h+=l?3:1){for(c=1,f=3;c<x-1;c++,f+=3)v=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[h][f-1]=v[0][0],e[h][f-1]=v[0][1],t[h][f+1]=v[1][0],e[h][f+1]=v[1][1];y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=y[0],e[h][1]=y[1],y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=y[0],e[h][_-2]=y[1]}if(l)for(f=0;f<_;f++){for(h=3;h<w-3;h+=3)v=n([t[h-3][f],e[h-3][f]],[t[h][f],e[h][f]],[t[h+3][f],e[h+3][f]],l),t[h-1][f]=v[0][0],e[h-1][f]=v[0][1],t[h+1][f]=v[1][0],e[h+1][f]=v[1][1];y=a([t[0][f],e[0][f]],[t[2][f],e[2][f]],[t[3][f],e[3][f]]),t[1][f]=y[0],e[1][f]=y[1],y=a([t[w-1][f],e[w-1][f]],[t[w-3][f],e[w-3][f]],[t[w-4][f],e[w-4][f]]),t[w-2][f]=y[0],e[w-2][f]=y[1]}if(s&&l)for(h=1;h<w;h+=(h+1)%3==0?2:1){for(f=3;f<_-3;f+=3)v=n([t[h][f-3],e[h][f-3]],[t[h][f],e[h][f]],[t[h][f+3],e[h][f+3]],s),t[h][f-1]=.5*(t[h][f-1]+v[0][0]),e[h][f-1]=.5*(e[h][f-1]+v[0][1]),t[h][f+1]=.5*(t[h][f+1]+v[1][0]),e[h][f+1]=.5*(e[h][f+1]+v[1][1]);y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=.5*(t[h][1]+y[0]),e[h][1]=.5*(e[h][1]+y[1]),y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=.5*(t[h][_-2]+y[0]),e[h][_-2]=.5*(e[h][_-2]+y[1])}return[t,e]}},{\"../../lib\":778,\"./catmull_rom\":972}],975:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],976:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=1-i,d=p*p,g=p*i*2,m=-3*d,v=3*(d-g),y=3*(g-h),x=3*h,b=a*a,_=b*a,w=1-a,T=w*w,k=T*w;for(f=0;f<t.length;f++)o=m*(u=t[f])[n][r]+v*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=m*u[n+1][r]+v*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=m*u[n+2][r]+v*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=m*u[n+3][r]+v*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[f]=k*o+3*(T*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,f=1-i,h=f*f,p=f*i*2,d=-3*h,g=3*(h-p),m=3*(p-u),v=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+m*c[n][r+2]+v*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+m*c[n+1][r+2]+v*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),n*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n][r+1]-f[n][r],s=f[n+1][r+1]-f[n+1][r],l=f[n+2][r+1]-f[n+2][r],c=f[n+3][r+1]-f[n+3][r],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],977:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=h*i,d=1-i,g=d*d,m=g*d,v=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),T=3*(b-v),k=3*v;for(f=0;f<t.length;f++)o=_*(u=t[f])[n][r]+w*u[n+1][r]+T*u[n+2][r]+k*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+T*u[n+2][r+1]+k*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+T*u[n+2][r+2]+k*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+T*u[n+2][r+3]+k*u[n+3][r+3],e[f]=m*o+3*(g*i*s+d*h*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n+1][r]-f[n][r],s=f[n+1][r+1]-f[n][r+1],l=f[n+1][r+2]-f[n][r+2],c=f[n+1][r+3]-f[n][r+3],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,f=a*a,h=1-a,p=h*h,d=h*a*2,g=-3*p,m=3*(p-d),v=3*(d-f),y=3*f;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+m*c[n+1][r]+v*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+m*c[n+1][r+1]+v*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],978:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,f;e||(e=[]);var h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3,p*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,T=1-g,k=T*T,M=k*T;for(f=0;f<t.length;f++)i=b*(u=t[f])[p][h]+3*(x*d*u[p][h+1]+y*m*u[p][h+2])+v*u[p][h+3],s=b*u[p+1][h]+3*(x*d*u[p+1][h+1]+y*m*u[p+1][h+2])+v*u[p+1][h+3],l=b*u[p+2][h]+3*(x*d*u[p+2][h+1]+y*m*u[p+2][h+2])+v*u[p+2][h+3],c=b*u[p+3][h]+3*(x*d*u[p+3][h+1]+y*m*u[p+3][h+2])+v*u[p+3][h+3],e[f]=M*i+3*(k*g*s+T*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+g*f[p+1][h],s=_*f[p][h+1]+g*f[p+1][h+1],l=_*f[p][h+2]+g*f[p+1][h+1],c=_*f[p][h+3]+g*f[p+1][h+1],e[u]=b*i+3*(x*d*s+y*m*l)+v*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));p*=3;var m=g*g,v=m*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+d*f[p][h+1],s=_*f[p+1][h]+d*f[p+1][h+1],l=_*f[p+2][h]+d*f[p+2][h+1],c=_*f[p+3][h]+d*f[p+3][h+1],e[u]=b*i+3*(x*g*s+y*m*l)+v*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),f=Math.max(0,Math.min(Math.floor(n),o)),h=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-f)),d=1-p,g=1-h;for(l=0;l<t.length;l++)i=g*(c=t[l])[f][u]+h*c[f][u+1],s=g*c[f+1][u]+h*c[f+1][u+1],e[l]=d*i+p*s;return e}}},{}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"./ab_defaults\":962,\"./attributes\":964,\"./xy_defaults\":988}],980:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":964,\"./calc\":968,\"./defaults\":979,\"./plot\":985}],981:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],982:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":778}],984:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=(i[0]*a[0]+i[1]*a[1])/u/f;c=Math.max(0,h)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],985:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=c.strRotate,f=c.strTranslate,h=t(\"../../constants/alignment\");function p(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each((function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),f=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",f).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")})),u.exit().remove()}function d(t,e,r,a,o,c,h,p){var d=c.selectAll(\"text.\"+p).data(h);d.enter().append(\"text\").classed(p,!0);var g=0,m={};return d.each((function(o,c){var h;if(\"auto\"===o.axis.tickangle)h=s(a,e,r,o.xy,o.dxy);else{var p=(o.axis.tickangle+180)*Math.PI/180;h=s(a,e,r,o.xy,[Math.cos(p),Math.sin(p)])}c||(m={angle:h.angle,flip:h.flip});var d=(o.endAnchor?-1:1)*h.flip,v=n.select(this).attr({\"text-anchor\":d>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),y=i.bBox(this);v.attr(\"transform\",f(h.p[0],h.p[1])+u(h.angle)+f(o.axis.labelpadding*d,.3*y.height)),g=Math.max(g,y.width+o.axis.labelpadding)})),d.exit().remove(),m.maxExtent=g,m}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,f=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each((function(e){var r=n.select(this),i=e[0],h=i.trace,g=h.aaxis,m=h.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",h.opacity),p(l,u,x,g,\"a\",g._gridlines),p(l,u,x,m,\"b\",m._gridlines),p(l,u,y,g,\"a\",g._minorgridlines),p(l,u,y,m,\"b\",m._minorgridlines),p(l,u,b,g,\"a-boundary\",g._boundarylines),p(l,u,b,m,\"b-boundary\",m._boundarylines);var w=d(t,l,u,h,i,_,g._labels,\"a-label\"),T=d(t,l,u,h,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,f,h,p,d=c.aggNums(Math.min,null,r.a),g=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+g),f=m,h=r.ab2xy(u,f,!0),p=r.dxyda_rough(u,f),void 0===o.angle&&c.extendFlat(o,s(r,i,a,h,r.dxydb_rough(u,f)));v(t,e,r,n,h,p,r.aaxis,i,a,o,\"a-title\"),u=d,f=.5*(m+y),h=r.ab2xy(u,f,!0),p=r.dxydb_rough(u,f),void 0===l.angle&&c.extendFlat(l,s(r,i,a,h,r.dxyda_rough(u,f)));v(t,e,r,n,h,p,r.baxis,i,a,l,\"b-title\")}(t,_,h,i,l,u,w,T),function(t,e,r,n,i){var s,l,u,f,h=r.select(\"#\"+t._clipPathId);h.size()||(h=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(h,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(f=0;f<d.length;f++)s=d[f],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var m=\"M\"+g.join(\"L\")+\"Z\";h.attr(\"id\",t._clipPathId),p.attr(\"d\",m)}(h,i,f,l,u)}))};var g=h.LINE_SPACING,m=(1-h.MID_SHIFT)/g+1;function v(t,e,r,a,o,c,h,p,d,v,y){var x=[];h.title.text&&x.push(h.title.text);var b=e.selectAll(\"text.\"+y).data(x),_=v.maxExtent;b.enter().append(\"text\").classed(y,!0),b.each((function(){var e=s(r,p,d,o,c);-1===[\"start\",\"both\"].indexOf(h.showticklabels)&&(_=0);var a=h.title.font.size;_+=a+h.title.offset;var y=(v.angle+(v.flip<0?180:0)-e.angle+450)%360,x=y>90&&y<270,b=n.select(this);b.text(h.title.text).call(l.convertToTspans,t),x&&(_=(-l.lineCount(b)+m)*g*a-_),b.attr(\"transform\",f(e.p[0],e.p[1])+u(e.angle)+f(0,_)).attr(\"text-anchor\",\"middle\").call(i.font,h.title.font)})),b.exit().remove()}},{\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./makepath\":982,\"./map_1d_array\":983,\"./orient_text\":984,d3:169}],986:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,f=t.aaxis,h=t.baxis,p=e[0],d=e[c-1],g=r[0],m=r[u-1],v=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=v*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,m+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<m},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>m},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,f.smoothing,h.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,f.smoothing,h.smoothing),t.dxydi=s([t._xctrl,t._yctrl],f.smoothing,h.smoothing),t.dxydj=l([t._xctrl,t._yctrl],f.smoothing,h.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var f,h,p,d,g=0,m=0,v=[];n<e[0]?(f=0,h=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(f=c-2,h=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):h=o-(f=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,m=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,m=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(v,f,p,h,d),l[0]+=v[0]*g,l[1]+=v[1]*g),m&&(t.dxydj(v,f,p,h,d),l[0]+=v[0]*m,l[1]+=v[1]*m)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=v*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":798,\"./compute_control_points\":974,\"./constants\":975,\"./create_i_derivative_evaluator\":976,\"./create_j_derivative_evaluator\":977,\"./create_spline_evaluator\":978}],987:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function f(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var h,p,d,g,m,v,y,x,b,_,w,T=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=f(i,a)),T=Math.max(T,Math.abs(t[a][i]));if(!s.length)return t;var k=0,M=0,A=s.length;do{for(k=0,o=0;o<A;o++){i=s[o],a=l[o];var S,E,C,L,I,P,z=0,O=0;0===i?(C=e[I=Math.min(c-1,2)],L=e[1],S=t[a][I],O+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[I=Math.max(0,c-3)],L=e[c-2],S=t[a][I],O+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(h=r[a+1]-r[a],O+=((p=r[a]-r[a-1])*t[a+1][i]+h*t[a-1][i])/(p+h),z++),0===a?(C=r[P=Math.min(u-1,2)],L=r[1],S=t[P][i],O+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[P=Math.max(0,u-3)],L=r[u-2],S=t[P][i],O+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(h=e[i+1]-e[i],O+=((p=e[i]-e[i-1])*t[a][i+1]+h*t[a][i-1])/(p+h),z++),z?O/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(m=r[a+1]-r[a])*(v=r[a]-r[a-1])*(m+v),O=((y=d*g*(d+g))*(v*t[a+1][i]+m*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(v+m))),k+=(_=(b=O-t[a][i])/T)*_,w=z?0:.85,t[a][i]+=b*(1+w)}k=Math.sqrt(k)}while(M++<100&&k>1e-5);return n.log(\"Smoother converged to\",k,\"after\",M,\"iterations\"),t}},{\"../../lib\":778}],988:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":778}],989:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},geojson:l({},i.geojson,{}),featureidkey:i.featureidkey,text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattergeo/attributes\":1229}],990:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var f=0;f<c;f++){var h=u[f]={},p=e.locations[f],d=e.z[f];r(p)&&n(d)?(h.loc=p,h.z=d):(h.loc=null,h.z=i),h.index=f}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"fast-isnumeric\":241}],991:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,f=s(\"geojson\");(\"string\"==typeof f&&\"\"!==f||n.isPlainObject(f))&&(u=\"geojson-id\"),\"geojson-id\"===s(\"locationmode\",u)&&s(\"featureidkey\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":989}],992:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t.ct=a.ct,t}},{}],993:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,f=u[0].trace,h=t.subplot,p=[e,r],d=[e+360,r];for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains(p)&&(c=!c),o._polygons[l].contains(d)&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(h.mockAxis,h.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),l=-1!==s.indexOf(\"name\"),c=-1!==s.indexOf(\"location\"),u=-1!==s.indexOf(\"z\"),f=-1!==s.indexOf(\"text\"),h=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&h.push(o));u&&h.push(t.zLabel);f&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,f,o),[t]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./attributes\":989}],994:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\",\"showLegend\"],meta:{}}},{\"../../plots/geo\":860,\"../heatmap/colorbar\":1068,\"./attributes\":989,\"./calc\":990,\"./defaults\":991,\"./event_data\":992,\"./hover\":993,\"./plot\":995,\"./select\":996,\"./style\":997}],995:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../plots/cartesian/autorange\").findExtremes,l=t(\"./style\").style;e.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],i=n._subplot,l=r.locationmode,c=r._length,u=\"geojson-id\"===l?a.extractTraceFeature(t):o(r,i.topojson),f=[],h=[],p=0;p<c;p++){var d=t[p],g=\"geojson-id\"===l?d.fOut:a.locationToFeature(l,d.loc,u);if(g){d.geojson=g,d.ct=g.properties.ct,d._polygons=a.feature2polygons(g);var m=a.computeBbox(g);f.push(m[0],m[2]),h.push(m[1],m[3])}else d.geojson=null}if(\"geojson\"===n.fitbounds&&\"geojson-id\"===l){var v=a.computeBbox(a.getTraceGeojson(r));f=[v[0],v[2]],h=[v[1],v[3]]}var y={padded:!0};r._extremes.lon=s(n.lonaxis._ax,f,y),r._extremes.lat=s(n.lataxis._ax,h,y)},plot:function(t,e,r){var a=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(a,r,\"trace choropleth\").each((function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)}))}}},{\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"./style\":997,d3:169}],996:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],997:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each((function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)})),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../components/drawing\":665,d3:169}],998:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../choropleth/attributes\":989}],999:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/geojson_utils\").makeBlank,l=t(\"../../lib/geo_location_utils\");function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=a.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=i.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return i.extendFlat(n.fill.paint,{\"fill-opacity\":e}),i.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},f=e._opts={fill:o,line:u,geojson:s()};if(!r)return f;var h=l.extractTraceFeature(t);if(!h)return f;var p,d,g,m=a.makeColorScaleFuncFromTrace(e),v=e.marker,y=v.line||{};i.isArrayOrTypedArray(v.opacity)&&(p=function(t){var e=t.mo;return n(e)?+i.constrain(e,0,1):0}),i.isArrayOrTypedArray(y.color)&&(d=function(t){return t.mlc}),i.isArrayOrTypedArray(y.width)&&(g=function(t){return t.mlw});for(var x=0;x<t.length;x++){var b=t[x],_=b.fOut;if(_){var w=_.properties;w.fc=m(b.z),p&&(w.mo=p(b)),d&&(w.mlc=d(b)),g&&(w.mlw=g(b)),b.ct=w.ct,b._polygons=l.feature2polygons(_)}}var T=p?{type:\"identity\",property:\"mo\"}:v.opacity;return i.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),i.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:y.color,\"line-width\":g?{type:\"identity\",property:\"mlw\"}:y.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",f.geojson={type:\"FeatureCollection\",features:h},c(t),f},convertOnSelect:c}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1e3:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":998}],1001:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":885,\"../choropleth/calc\":990,\"../choropleth/event_data\":992,\"../choropleth/hover\":993,\"../choropleth/select\":996,\"../heatmap/colorbar\":1068,\"./attributes\":998,\"./defaults\":1e3,\"./plot\":1002}],1002:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.type=\"choroplethmapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":999}],1003:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1004:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],f=i[c],h=a[c],p=Math.sqrt(u*u+f*f+h*h);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1005:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var f={xaxis:0,yaxis:1,zaxis:2},h={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[f[e]];return a(t,(function(t){return n.d2l(t)*o}))}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=h[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),m=e.lightposition;return g.lightPosition=[m.x,m.y,m.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-cone3d\":260}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1003}],1007:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1003,\"./calc\":1004,\"./convert\":1005,\"./defaults\":1006}],1008:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,f=c.INTERVAL_OPS,h=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:l({},n.connectgaps,{}),fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(f),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},h.color,{editType:\"style+colorbars\"}),width:{valType:\"number\",min:0,editType:\"style+colorbars\"},dash:o,smoothing:l({},h.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/filter_ops\":749,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../heatmap/attributes\":1065,\"../scatter/attributes\":1187}],1009:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var f=c.start,h=o(c),p=c.size||1,d=Math.floor((h-f)/p)+1;isFinite(p)||(p=1,d=1);var g=f-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":655,\"../heatmap/calc\":1066,\"./end_plus\":1019,\"./set_contours\":1027}],1010:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t[0],i=n.z;switch(e.type){case\"levels\":var a=Math.min(i[0][0],i[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(a>o.level||o.starts.length&&a===o.level)}break;case\"constraint\":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,i[r][0]),u=Math.min(u,i[r][s-1]),c=Math.max(c,i[r][0]),c=Math.max(c,i[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,i[0][r]),u=Math.min(u,i[l-1][r]),c=Math.max(c,i[0][r]),c=Math.max(c,i[l-1][r]);var f,h,p=e.value;switch(e._operation){case\">\":p>c&&(n.prefixBoundary=!0);break;case\"<\":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case\"[]\":f=Math.min(p[0],p[1]),((h=Math.max(p[0],p[1]))<u||f>c||n.starts.length&&h===u)&&(n.prefixBoundary=!0);break;case\"][\":f=Math.min(p[0],p[1]),h=Math.max(p[0],p[1]),f<u&&h>c&&(n.prefixBoundary=!0)}}}},{}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var f=n.extractOpts(e);r._fillgradient=f.reversescale?n.flipScale(f.colorscale):f.colorscale,r._zrange=[f.min,f.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":655,\"./end_plus\":1019,\"./make_color_map\":1024}],1012:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],1013:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,f){var h,p,d,g=e.contours,m=r(\"contours.operation\");(g._operation=c[m],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===m?h=g.showlines=!0:(h=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),h)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,f)}},{\"../../components/color\":643,\"../../constants/filter_ops\":749,\"./label_defaults\":1023,\"fast-isnumeric\":241}],1014:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":749,\"fast-isnumeric\":241}],1015:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],1016:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));for(;o.starts.length;)a.starts.push(l(o.starts.shift()));return[a]}}},{\"../../lib\":778}],1017:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./constraint_defaults\"),s=t(\"./contours_defaults\"),l=t(\"./style_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(i(t,e,f,u)){a(t,e,u,f),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"hoverongaps\");var h=\"constraint\"===f(\"contours.type\");f(\"connectgaps\",n.isArray1D(e.z)),h?o(t,e,f,u,r):(s(t,e,f,(function(r){return n.coerce2(t,e,c,r)})),l(t,e,f,u))}else e.visible=!1}},{\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"../scatter/period_defaults\":1207,\"./attributes\":1008,\"./constraint_defaults\":1013,\"./contours_defaults\":1015,\"./style_defaults\":1029}],1018:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,f=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},h=o.start;h<c;h+=s)if(l.push(n.extendFlat({level:h,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},f)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":778,\"./constraint_mapping\":1014,\"./end_plus\":1019}],1019:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],1020:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),f=t.crossings[u],h=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),p=[s(t,e,[-h[0],-h[1]])],d=t.z.length,g=t.z[0].length,m=e.slice(),v=h.slice();for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(h[0]||h[1])<0?0:1],t.crossings[u]=i.SADDLEREMAINDER[f]):delete t.crossings[u],!(h=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}p.push(s(t,e,h)),e[0]+=h[0],e[1]+=h[1],u=e.join(\",\"),a(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=h[0]&&(e[0]<0||e[0]>g-2)||h[1]&&(e[1]<0||e[1]>d-2);if(e[0]===m[0]&&e[1]===m[1]&&h[0]===v[0]&&h[1]===v[1]||r&&y)break;f=t.crossings[u]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,T,k,M,A,S,E,C,L,I,P,z,O=a(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)L=p[c],I=p[c-1],P=void 0,z=void 0,P=L[2]-I[2],z=L[3]-I[3],D+=M=Math.sqrt(P*P+z*z),F.push(M);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(O&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];T=c-b+_+1,k=Math.floor((c+b+_+2)/2),w=O||c!==p.length-2?O||-1!==b?T%2?j(k):[(j(k)[0]+j(k+1)[0])/2,(j(k)[1]+j(k+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),O&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(O)p.pop(),t.paths.push(p);else{r||n.log(\"Unclosed interior contour?\",t.level,m.join(\",\"),p.join(\"L\"));var U=!1;for(A=0;A<t.edgepaths.length;A++)if(E=t.edgepaths[A],!U&&a(E[0],p[p.length-1],o,l)){p.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],p[0],o,l)){V=!0,p.shift(),t.edgepaths.splice(A,1),S===A?t.paths.push(p.concat(C)):(S>A&&S--,t.edgepaths[S]=C.concat(p,E));break}V||(t.edgepaths[A]=p.concat(E))}for(A=0;A<t.edgepaths.length&&!U;A++)a((E=t.edgepaths[A])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[A]=E.concat(p),U=!0);U||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":778,\"./constants\":1012}],1021:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach((function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))})),s}},{\"../../components/color\":643,\"../heatmap/hover\":1072}],1022:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1008,\"./calc\":1009,\"./colorbar\":1011,\"./defaults\":1017,\"./hover\":1021,\"./plot\":1026,\"./style\":1028}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":778}],1024:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var f,h,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),m=new Array(d);if(\"heatmap\"===e.coloring){var v=u.min,y=u.max;for(h=0;h<d;h++)f=p[h],g[h]=f[0]*(y-v)+v,m[h]=f[1];var x=n.extent([v,y,e.start,e.start+s*(l-1)]),b=x[v<y?0:1],_=x[v<y?1:0];b!==v&&(g.splice(0,0,b),m.splice(0,0,m[0])),_!==y&&(g.push(_),m.push(m[m.length-1]))}else for(h=0;h<d;h++)f=p[h],g[h]=(f[0]*(l+c-1)-c/2)*s+r,m[h]=f[1];return i.makeColorScaleFunc({domain:g,range:m},{noNumericCheck:!0})}},{\"../../components/colorscale\":655,\"./end_plus\":1019,d3:169}],1025:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,f,h=t[0].z,p=h.length,d=h[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[h[r][e],h[r][e+1]],[h[r+1][e],h[r+1][e+1]]],f=0;f<t.length;f++)(c=i((u=t[f]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":1012}],1026:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"../../plots/cartesian/set_convert\"),u=t(\"../heatmap/plot\"),f=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),p=t(\"./empty_pathinfo\"),d=t(\"./convert_to_constraints\"),g=t(\"./close_boundaries\"),m=t(\"./constants\"),v=m.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,f=\"\",h=0,p=t.edgepaths.map((function(t,e){return e})),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function m(t){return Math.abs(t[0]-e[0][0])<.01}function v(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[h],t.smoothing),f+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(h),1),r=t.edgepaths[h][t.edgepaths[h].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",h,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!v(r)?n=e[1]:m(r)?n=e[0]:g(r)?n=e[3]:v(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;f+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}h=s,(d=-1===p.indexOf(h))&&(h=p[0],f+=\"Z\")}for(h=0;h<t.paths.length;h++)f+=a.smoothclosed(t.paths[h],t.smoothing);return f}function x(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,f=Math.sin(c)*a,h=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(f)+Math.cos(c)*o);if(h<1||p<1)return 1/0;var d=v.EDGECOST*(1/(h-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-f,y=s+u,x=l+f,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,T=Math.sin(_.theta)*_.width/2,k=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-T,_.x+w,_.y+T)/(e.height+_.height),M=_.level===e.level,A=M?v.SAMELEVELDISTANCE:1;if(k<=A)return 1/0;d+=v.NEIGHBORCOST*(M?v.SAMELEVELFACTOR:1)/(k-A)}return d}function b(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)i[(r=n[e])[0]][r[1]]=0;return t.zmask=i,i}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each((function(o){var s=n.select(this),v=o[0],x=v.trace,_=v.x,w=v.y,T=x.contours,k=p(T,e,v),M=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===T.coloring&&(A=[o]),u(t,e,A,M),f(k),h(k);var S=l.c2p(_[0],!0),E=l.c2p(_[_.length-1],!0),C=c.c2p(w[0],!0),L=c.c2p(w[w.length-1],!0),I=[[S,L],[E,L],[E,C],[S,C]],P=k;\"constraint\"===T.type&&(P=d(k,T._operation)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,I,T),function(t,e,r,a){var o=\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation,s=\"M\"+r.join(\"L\")+\"Z\";o&&g(e,a);var l=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(o?e:[]);l.enter().append(\"path\"),l.exit().remove(),l.each((function(t){var e=(t.prefixBoundary?s:\"\")+y(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(s,P,I,T),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,f=l.showlabels,h=u&&f,p=r.createLines(c,u||f,e),d=r.createLineClip(c,h,o,s.trace.uid),g=t.selectAll(\"g.contourlabels\").data(f?[0]:[]);if(g.exit().remove(),g.enter().append(\"g\").classed(\"contourlabels\",!0),f){var v=[],y=[];i.clearLocationCache();var x=r.labelFormatter(o,s),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,T=_._length,k=w._length,M=_.range,A=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),I=Math.max(_.c2p(S,!0),0),P=Math.min(_.c2p(E,!0),T),z=Math.max(w.c2p(L,!0),0),O=Math.min(w.c2p(C,!0),k),D={};M[0]<M[1]?(D.left=I,D.right=P):(D.left=P,D.right=I),A[0]<A[1]?(D.top=z,D.bottom=O):(D.top=O,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,v.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(T*T+k*k),F=m.LABELDISTANCE*R/Math.max(1,e.length/m.LABELINCREASE);p.each((function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each((function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*m.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),m.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,v)}}))})),b.remove(),r.drawLabels(g,y,o,d,h?v:null)}f&&!u&&p.remove()}(s,k,t,v,T),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c=\"clip\"+s.uid,u=l.selectAll(\"#\"+c).data(s.connectgaps?[]:[0]);if(u.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:b(n),smoothing:0};f([p]),h([p]),g([p],{type:\"levels\"}),i.ensureSingle(u,\"path\",\"\").attr(\"d\",(p.prefixBoundary?\"M\"+o.join(\"L\")+\"Z\":\"\")+y(p,o))}else c=null;a.setClipUrl(t,c,r)}(s,e,t,v,I)}))},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data((function(t){return t.pedgepaths||t.edgepaths}));o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",(function(t){return a.smoothopen(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data((function(t){return t.ppaths||t.paths}));s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",(function(t){return a.smoothclosed(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,i=n.contours,a={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"};if(i.labelformat)a.tickformat=i.labelformat,c(a,r);else{var s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)a=s.colorbar._axis;else{if(\"constraint\"===i.type){var u=i.value;Array.isArray(u)?a.range=[u[0],u[u.length-1]]:a.range=[u,u]}else a.range=[i.start,i.end],a.nticks=(i.end-i.start)/i.size;a.range[0]===a.range[1]&&(a.range[1]+=a.range[0]||1),a.nticks||(a.nticks=1e3),c(a,r),l.prepTicks(a),a._tmin=null,a._tmax=null}}return function(t){return l.tickText(a,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(s.convertToTspans,n);var o=r.node(),l=a.bBox(o,!0);return{text:i,width:l.width,height:l.height,fontSize:+o.style[\"font-size\"].replace(\"px\",\"\"),level:t,dy:(l.top+l.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,f=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-f)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+f/2,l=e.max-(s+f)/2);for(var h=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,f),m=x(g,r,n,a);m<h&&(h=m,u=g,c=d)}if(h>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(h<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.fontSize,a=e.width+i/3,o=Math.max(0,e.height-i/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),f=Math.cos(c),h=function(t,e){return[s+t*f-e*u,l+t*u+e*f]},p=[h(-a/2,-o/2),h(-a/2,o/2),h(a/2,o/2),h(a/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:a,height:o}),n.push(p)},r.drawLabels=function(t,e,r,a,o){var l=t.selectAll(\"text\").data(e,(function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta}));if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each((function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(s.convertToTspans,r)})),o){for(var c=\"\",u=0;u<o.length;u++)c+=\"M\"+o[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/set_convert\":848,\"../heatmap/plot\":1076,\"./close_boundaries\":1010,\"./constants\":1012,\"./convert_to_constraints\":1016,\"./empty_pathinfo\":1018,\"./find_all_paths\":1020,\"./make_crossings\":1025,d3:169}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,f=r.end,h=t._input.contours;if(u>f&&(r.start=h.start=f,f=r.end=h.end=u,u=r.start),!(r.size>0))c=u===f?1:a(u,f,t.ncontours).dtick,h.size=r.size=c}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1028:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,f=!u&&\"lines\"===a.coloring,h=!u&&\"fill\"===a.coloring,p=f||h?o(r):null;e.selectAll(\"g.contourlevel\").each((function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,f?p(t.level):s.color,s.dash)}));var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each((function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(f?p(t.level):s.color)})})),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(h){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",(function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)})),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}})),a(t)}},{\"../../components/drawing\":665,\"../heatmap/style\":1077,\"./make_color_map\":1024,d3:169}],1029:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":653,\"./label_defaults\":1023}],1030:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=i.contours;e.exports=o({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:i.line.color,width:i.line.width,dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../heatmap/attributes\":1065}],1031:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),f=t(\"../carpet/lookup_carpetid\"),h=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=f(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,f,h,p,d,g,m=e._carpetTrace,v=m.aaxis,y=m.baxis;v._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,v,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,h=e._b=e._b||e.b,r=r?v.makeCalcdata(e,\"_a\"):[],h=h?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,f=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,f,x,v),w=\"scaled\"===e.ytype?\"\":h,T=c(e,w,p,d,g.length,y),k={a:_,b:T,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[k]}(t,e);return h(e,e._z),g}}},{\"../../components/colorscale/calc\":651,\"../../lib\":778,\"../carpet/lookup_carpetid\":981,\"../contour/set_contours\":1027,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"../heatmap/make_bound_array\":1075,\"./defaults\":1032}],1032:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,(function(r){return n.coerce2(t,e,a,r)})),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":778,\"../contour/constraint_defaults\":1013,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1030}],1033:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/colorbar\":1011,\"../contour/style\":1028,\"./attributes\":1030,\"./calc\":1031,\"./defaults\":1032,\"./plot\":1034}],1034:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),f=t(\"../contour/constants\"),h=t(\"../contour/convert_to_constraints\"),p=t(\"../contour/empty_pathinfo\"),d=t(\"../contour/close_boundaries\"),g=t(\"../carpet/lookup_carpetid\"),m=t(\"../carpet/axis_aligned_line\");function v(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,\"contour\").each((function(r){var b=n.select(this),T=r[0],k=T.trace,M=k._carpetTrace=g(t,k),A=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var S=T.a,E=T.b,C=k.contours,L=p(C,e,T),I=\"constraint\"===C.type,P=C._operation,z=I?\"=\"===P?\"lines\":\"fill\":C.coloring,O=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(L);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(L,D,R);var F,B,N,j,U=L;\"constraint\"===C.type&&(U=h(L,P)),function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(a=t[r],o=a.pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}(L,H);var V=[];for(j=A.clipsegments.length-1;j>=0;j--)F=A.clipsegments[j],B=i([],F.x,_.c2p),N=i([],F.y,w.c2p),B.reverse(),N.reverse(),V.push(a(B,N,F.bicubic));var q=\"M\"+V.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,f,h,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(h=0;h<e.length;h++)c=e[h],u=i([],c.x,r.c2p),f=i([],c.y,n.c2p),d.push(a(u,f,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(b,A.clipsegments,_,w,I,z),function(t,e,r,i,a,l,c,u,f,h,p){var g=\"fill\"===h;g&&d(a,t.contours);var v=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(g?a:[]);v.enter().append(\"path\"),v.exit().remove(),v.each((function(t){var e=(t.prefixBoundary?p:\"\")+function(t,e,r,n,i,a,l,c){var u,f,h,p,d,g,v,y=\"\",x=e.edgepaths.map((function(t,e){return e})),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function T(t){return Math.abs(t[1]-r[0][1])<w}function k(t){return Math.abs(t[1]-r[2][1])<w}function M(t){return Math.abs(t[0]-r[0][0])<_}function A(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u=\"\";for(T(t)&&!A(t)||k(t)&&!M(t)?(s=i.aaxis,o=m(i,a,[t[0],e[0]],.5*(t[1]+e[1]))):(s=i.baxis,o=m(i,a,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?\"C\":\"L\",n=0;n<o[r].length;n++){var f=o[r][n];u+=[l.c2p(f[0]),c.c2p(f[1])]+\" \"}return u}u=0,f=null;for(;x.length;){var E=e.edgepaths[u][0];for(f&&(y+=S(f,E)),v=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?v:v.replace(/^M/,\"L\"),x.splice(x.indexOf(u),1),f=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!f){s.log(\"Missing end?\",u,e);break}for(T(f)&&!A(f)?h=r[1]:M(f)?h=r[0]:k(f)?h=r[3]:A(f)&&(h=r[2]),g=0;g<e.edgepaths.length;g++){var C=e.edgepaths[g][0];Math.abs(f[0]-h[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(h[1]-C[1])>=0&&(h=C,d=g):Math.abs(f[1]-h[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(h[0]-C[0])>=0&&(h=C,d=g):s.log(\"endpt to newendpt is not vert. or horz.\",f,h,C)}if(d>=0)break;y+=S(f,h),f=h}if(d===e.edgepaths.length){s.log(\"unclosed perimeter path\");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(f,h)+\"Z\",f=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,f,r,i);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(k,b,_,w,U,O,H,M,A,z,q),function(t,e,r,i,a,l,c){var h=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,m=u.createLines(h,p||d,e),b=u.createLineClip(h,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,T=l.yaxis,k=w._length,M=T._length,A=[[[0,0],[k,0],[k,M],[0,M]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,i),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:k,center:k/2,top:0,bottom:M,middle:M/2},I=Math.sqrt(k*k+M*M),P=f.LABELDISTANCE*I/Math.max(1,e.length/f.LABELINCREASE);m.each((function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each((function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],f=i.b[i.b.length-1];function h(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-f)<.1)&&(r=y(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),n}var p=v(t,0,1),d=v(t,n.total,n.total-1),g=h(o[0],p),m=n.total-h(o[o.length-1],d);n.min<g&&(n.min=g);n.max>m&&(n.max=m);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*f.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/P),f.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,A)}}))})),C.remove(),u.drawLabels(_,S,r,b,g?A:null)}d&&!p&&m.remove()}(b,L,t,T,C,e,M),o.setClipUrl(b,M._clipPathId,t)}function H(t){var e=M.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../carpet/axis_aligned_line\":965,\"../carpet/lookup_carpetid\":981,\"../carpet/makepath\":982,\"../carpet/map_1d_array\":983,\"../contour/close_boundaries\":1010,\"../contour/constants\":1012,\"../contour/convert_to_constraints\":1016,\"../contour/empty_pathinfo\":1018,\"../contour/find_all_paths\":1020,\"../contour/make_crossings\":1025,\"../contour/plot\":1026,d3:169}],1035:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattermapbox/attributes\":1252}],1036:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,f=0;f<r;f++){var h=l[f]={},p=e.lon[f],d=e.lat[f];if(h.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[f];h.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1037:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,f=[],h=e.z,p=e.radius,d=i.isArrayOrTypedArray(h)&&h.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var m=t[u],v=m.lonlat;if(v[0]!==s){var y={};if(d){var x=m.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),f.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:v},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)T.push(_[u][0],_[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(b.max-b.min),\"heatmap-color\":T,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:f},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1038:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1035}],1039:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],1040:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var f=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(f,f.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../scattermapbox/hover\":1257}],1041:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),formatLabels:t(\"../scattermapbox/format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":885,\"../heatmap/colorbar\":1068,\"../scattermapbox/format_labels\":1256,\"./attributes\":1035,\"./calc\":1036,\"./defaults\":1038,\"./event_data\":1039,\"./hover\":1040,\"./plot\":1042}],1042:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.type=\"densitymapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1037}],1043:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],1044:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\",\"value\"])}),text:n.text,textposition:c({},n.textposition,{dflt:\"auto\"}),insidetextanchor:c({},n.insidetextanchor,{dflt:\"middle\"}),textangle:c({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:c({},n.orientation,{}),offset:c({},n.offset,{arrayOk:!1}),width:c({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1046}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"./arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return t===s?0:t}e.exports=function(t,e){var r,c,u,f,h,p,d=n.getFromId(t,e.xaxis||\"x\"),g=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=d.makeCalcdata(e,\"x\"),u=g.makeCalcdata(e,\"y\"),c=i(e,g,\"y\",u),p=!!e.yperiodalignment):(r=g.makeCalcdata(e,\"y\"),u=d.makeCalcdata(e,\"x\"),c=i(e,d,\"x\",u),p=!!e.xperiodalignment);var m,v=Math.min(c.length,r.length),y=new Array(v);for(e._base=[],f=0;f<v;f++){r[f]<0&&(r[f]=s);var x=!1;r[f]!==s&&f+1<v&&r[f+1]!==s&&(x=!0),h=y[f]={p:c[f],s:r[f],cNext:x},e._base[f]=-.5*h.s,p&&(y[f].orig_p=u[f]),e.ids&&(h.id=String(e.ids[f])),0===f&&(y[0].vTotal=0),y[0].vTotal+=l(h.s),h.begR=l(h.s)/l(y[0].s)}for(f=0;f<v;f++)(h=y[f]).s!==s&&(h.sumR=h.s/y[0].vTotal,h.difR=void 0!==m?h.s/m:1,m=h.s);return a(y,e),o(y,e),y}},{\"../../constants/numerical\":753,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":1043}],1046:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],1047:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?h.push(r):f.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,f,g),n(t,c,l,h,g),i=0;i<u.length;i++){r=u[i];for(var m=0;m<r.length;m++)m+1<r.length&&(r[m].nextP0=r[m+1].p0,r[m].nextS0=r[m+1].s0,r[m].nextP1=r[m+1].p1,r[m].nextS1=r[m+1].s1)}}},{\"../bar/cross_trace_calc\":924}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function u(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,u)){s(t,e,i,u),u(\"orientation\",e.y&&!e.x?\"v\":\"h\"),u(\"offset\"),u(\"width\");var f=u(\"text\");u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");a(t,e,i,u,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"===e.textposition||e.texttemplate||u(\"textinfo\",Array.isArray(f)?\"text+value\":\"value\");var p=u(\"marker.color\",r);if(u(\"marker.line.color\",c.defaultLine),u(\"marker.line.width\"),u(\"connector.visible\"))u(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return c.addOpacity(e,.5*c.opacity(e))}(p)),u(\"connector.line.width\")&&(u(\"connector.line.color\"),u(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.funnelmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1044}],1049:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1050:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,f=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=f.s,s.percentInitial=f.begR,s.percentInitialLabel=a(f.begR,1),s.percentPrevious=f.difR,s.percentPreviousLabel=a(f.difR,1),s.percentTotal=f.sumR,s.percentTotalLabel=a(f.sumR,1);var h=f.hi||c.hoverinfo,p=[];if(h&&\"none\"!==h&&\"skip\"!==h){var d=\"all\"===h,g=h.split(\"+\"),m=function(t){return d||-1!==g.indexOf(t)};m(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),m(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),m(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,f),[s]}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/hover\":928}],1051:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1044,\"./calc\":1045,\"./cross_trace_calc\":1047,\"./defaults\":1048,\"./event_data\":1049,\"./hover\":1050,\"./layout_attributes\":1052,\"./layout_defaults\":1053,\"./plot\":1054,\"./style\":1055}],1052:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1052}],1054:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;function c(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,u){var f=t._fullLayout;l(\"funnel\",f),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),f=r[0].trace,h=i.ensureSingle(s,\"g\",\"regions\");if(f.connector&&f.connector.visible){var p=\"h\"===f.orientation,d=h.selectAll(\"g.region\").data(i.identity);d.enter().append(\"g\").classed(\"region\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var f=c(r,l,u,p),h=f[0],d=f[1],m=\"\";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&h[2]!==o&&d[2]!==o&&h[3]!==o&&d[3]!==o&&(m+=p?\"M\"+h[0]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+d[1]+\"Z\":\"M\"+h[1]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[3]+\"V\"+d[2]+\"L\"+h[1]+\",\"+d[0]+\"Z\"),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each((function(r){var o=n.select(this),u=r[0].trace,f=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var h=\"h\"===u.orientation,p=f.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each((function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,h),f=u[0],p=u[1],g=\"\";void 0!==f[3]&&void 0!==p[3]&&(h?(g+=\"M\"+f[0]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[2],g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[3]+\",\"+p[2]):(g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[3],g+=\"M\"+f[1]+\",\"+p[0]+\"L\"+f[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,u),s.plot(t,e,r,u,{mode:f.funnelmode,norm:f.funnelmode,gap:f.funnelgap,groupgap:f.funnelgroupgap})}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1055:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l(t,s,\"funnel\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".regions\").each((function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,s.connector.fillcolor)})),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1056:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),texttemplate:s({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),hoverinfo:l({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),textposition:l({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161}],1057:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"funnelarea\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1058:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1163}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../pie/defaults\").handleLabelsAndValues;e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,i,r,a)}var u=c(\"labels\"),f=c(\"values\"),h=s(u,f),p=h.len;if(e._hasLabels=h.hasLabels,e._hasValues=h.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),p){e._length=p,c(\"marker.line.width\")&&c(\"marker.line.color\",l.paper_bgcolor),c(\"marker.colors\"),c(\"scalegroup\");var d,g=c(\"text\"),m=c(\"texttemplate\");if(m||(d=c(\"textinfo\",Array.isArray(g)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),m||d&&\"none\"!==d){var v=c(\"textposition\");o(t,e,l,c,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,l,c),c(\"title.text\")&&(c(\"title.position\"),n.coerceFont(c,\"title.font\",l.font)),c(\"aspectratio\"),c(\"baseratio\")}else e.visible=!1}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"../pie/defaults\":1164,\"./attributes\":1056}],1060:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1172,\"./attributes\":1056,\"./base_plot\":1057,\"./calc\":1058,\"./defaults\":1059,\"./layout_attributes\":1061,\"./layout_defaults\":1062,\"./plot\":1063,\"./style\":1064}],1061:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1168}],1062:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":778,\"./layout_attributes\":1061}],1063:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=a.strScale,s=a.strTranslate,l=t(\"../../lib/svg_text_utils\"),c=t(\"../bar/plot\").toMoveInsideBar,u=t(\"../bar/uniform_text\"),f=u.recordMinTextSize,h=u.clearMinTextSize,p=t(\"../pie/helpers\"),d=t(\"../pie/plot\"),g=d.attachFxHandlers,m=d.determineInsideTextFont,v=d.layoutAreas,y=d.prerenderTitles,x=d.positionTitleOutside,b=d.formatSliceLabel;function _(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;h(\"funnelarea\",r),y(e,t),v(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each((function(e){var u=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var f,h,p=[];for(p.push(u()),f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var d=h.v/l;c+=d,p.push(u())}var g=1/0,m=-1/0;for(f=0;f<p.length;f++)a=p[f],g=Math.min(g,a[1]),m=Math.max(m,a[1]);for(f=0;f<p.length;f++)p[f][1]-=(m+g)/2;var v=p[p.length-1][0],y=e.r,x=(m-g)/2,b=y/v,_=y/x*n;for(e.r=_*x,f=0;f<p.length;f++)p[f][0]*=b,p[f][1]*=_;var w=[-(a=p[0])[0],a[1]],T=[a[0],a[1]],k=0;for(f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var M=p[k+=1][0],A=p[k][1];h.TL=[-M,A],h.TR=[M,A],h.BL=w,h.BR=T,h.pxmid=(S=h.TR,E=h.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=h.TL,T=h.TR}var S,E}(e),u.each((function(){var u=n.select(this).selectAll(\"g.slice\").data(e);u.enter().append(\"g\").classed(\"slice\",!0),u.exit().remove(),u.each((function(o,s){if(o.hidden)n.select(this).selectAll(\"path,g\").remove();else{o.pointNumber=o.i,o.curveNumber=d.index;var u=h.cx,v=h.cy,y=n.select(this),x=y.selectAll(\"path.surface\").data([o]);x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),y.call(g,t,e);var w=\"M\"+(u+o.TR[0])+\",\"+(v+o.TR[1])+_(o.TR,o.BR)+_(o.BR,o.BL)+_(o.BL,o.TL)+\"Z\";x.attr(\"d\",w),b(t,o,h);var T=p.castOption(d.textposition,o.pts),k=y.selectAll(\"g.slicetext\").data(o.text&&\"none\"!==T?[0]:[]);k.enter().append(\"g\").classed(\"slicetext\",!0),k.exit().remove(),k.each((function(){var h=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),p=a.ensureUniformFontSize(t,m(d,o,r.font));h.text(o.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p).call(l.convertToTspans,t);var g,y,x,b=i.bBox(h.node()),_=Math.min(o.BL[1],o.BR[1])+v,w=Math.max(o.TL[1],o.TR[1])+v;y=Math.max(o.TL[0],o.BL[0])+u,x=Math.min(o.TR[0],o.BR[0])+u,(g=c(y,x,_,w,b,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})).fontSize=p.size,f(d.type,g,r),e[s].transform=g,h.attr(\"transform\",a.getTextTransform(g))}))}}));var v=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);v.enter().append(\"g\").classed(\"titletext\",!0),v.exit().remove(),v.each((function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),c=d.title.text;d._meta&&(c=a.templateString(c,d._meta)),e.text(c).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(l.convertToTspans,t);var u=x(h,r._size);e.attr(\"transform\",s(u.x,u.y)+o(Math.min(1,u.scale))+s(u.tx,u.ty))}))}))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/plot\":932,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,d3:169}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(\".trace\");a(t,e,\"funnelarea\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"../pie/style_one\":1172,d3:169}],1065:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=s({z:{valType:\"data_array\",editType:\"calc\"},x:s({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:s({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:s({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:s({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:s({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:s({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),xperiod:s({},n.xperiod,{impliedEdits:{xtype:\"scaled\"}}),yperiod:s({},n.yperiod,{impliedEdits:{ytype:\"scaled\"}}),xperiod0:s({},n.xperiod0,{impliedEdits:{xtype:\"scaled\"}}),yperiod0:s({},n.yperiod0,{impliedEdits:{ytype:\"scaled\"}}),xperiodalignment:s({},n.xperiodalignment,{impliedEdits:{xtype:\"scaled\"}}),yperiodalignment:s({},n.yperiodalignment,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},hoverongaps:{valType:\"boolean\",dflt:!0,editType:\"none\"},connectgaps:{valType:\"boolean\",editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:a(),showlegend:s({},i.showlegend,{dflt:!1})},{transforms:void 0},o(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1066:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../histogram2d/calc\"),l=t(\"../../components/colorscale/calc\"),c=t(\"./convert_column_xyz\"),u=t(\"./clean_2d_array\"),f=t(\"./interp2d\"),h=t(\"./find_empties\"),p=t(\"./make_bound_array\"),d=t(\"../../constants/numerical\").BADNUM;function g(t){for(var e=[],r=t.length,n=0;n<r;n++){var i=t[n];i!==d&&e.push(i)}return e}e.exports=function(t,e){var r,m,v,y,x,b,_,w,T,k,M,A=a.getFromId(t,e.xaxis||\"x\"),S=a.getFromId(t,e.yaxis||\"y\"),E=n.traceIs(e,\"contour\"),C=n.traceIs(e,\"histogram\"),L=n.traceIs(e,\"gl2d\"),I=E?\"best\":e.zsmooth;if(A._minDtick=0,S._minDtick=0,C)y=(M=s(t,e)).orig_x,r=M.x,m=M.x0,v=M.dx,w=M.orig_y,x=M.y,b=M.y0,_=M.dy,T=M.z;else{var P=e.z;i.isArray1D(P)?(c(e,A,S,\"x\",\"y\",[\"z\"]),r=e._x,x=e._y,P=e._z):(y=e.x?A.makeCalcdata(e,\"x\"):[],w=e.y?S.makeCalcdata(e,\"y\"):[],r=o(e,A,\"x\",y),x=o(e,S,\"y\",w),e._x=r,e._y=x),m=e.x0,v=e.dx,b=e.y0,_=e.dy,T=u(P,e,A,S)}function z(t){I=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if((A.rangebreaks||S.rangebreaks)&&(T=function(t,e,r){for(var n=[],i=-1,a=0;a<r.length;a++)if(e[a]!==d){i++,n[i]=[];for(var o=0;o<r[a].length;o++)t[o]!==d&&n[i].push(r[a][o])}return n}(r,x,T),C||(r=g(r),x=g(x),e._x=r,e._y=x)),C||!E&&!e.connectgaps||(e._emptypoints=h(T),f(T,e._emptypoints)),\"fast\"===I)if(\"log\"===A.type||\"log\"===S.type)z(\"log axis found\");else if(!C){if(r.length){var O=(r[r.length-1]-r[0])/(r.length-1),D=Math.abs(O/100);for(k=0;k<r.length-1;k++)if(Math.abs(r[k+1]-r[k]-O)>D){z(\"x scale is not linear\");break}}if(x.length&&\"fast\"===I){var R=(x[x.length-1]-x[0])/(x.length-1),F=Math.abs(R/100);for(k=0;k<x.length-1;k++)if(Math.abs(x[k+1]-x[k]-R)>F){z(\"y scale is not linear\");break}}}var B=i.maxRowLength(T),N=\"scaled\"===e.xtype?\"\":r,j=p(e,N,m,v,B,A),U=\"scaled\"===e.ytype?\"\":x,V=p(e,U,b,_,T.length,S);L||(e._extremes[A._id]=a.findExtremes(A,j),e._extremes[S._id]=a.findExtremes(S,V));var q={x:j,y:V,z:T,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(e.xperiodalignment&&y&&(q.orig_x=y),e.yperiodalignment&&w&&(q.orig_y=w),N&&N.length===j.length-1&&(q.xCenter=N),U&&U.length===V.length-1&&(q.yCenter=U),C&&(q.xRanges=M.xRanges,q.yRanges=M.yRanges,q.pts=M.pts),E||l(t,e,{vals:T,cLetter:\"z\"}),E&&e.contours&&\"heatmap\"===e.contours.coloring){var H={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};q.xfill=p(H,N,m,v,B,A),q.yfill=p(H,U,b,_,T.length,S)}return[q]}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../histogram2d/calc\":1098,\"./clean_2d_array\":1067,\"./convert_column_xyz\":1069,\"./find_empties\":1071,\"./interp2d\":1074,\"./make_bound_array\":1075}],1067:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,f,h;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,f=0;f<t.length;f++)s=Math.max(s,t[f].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(f=0;f<o.length;f++)n[o[f]]=f;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var m=g(r),v=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(f=0;f<s;f++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,f),y[f]=new Array(l),h=0;h<l;h++)y[f][h]=p(d(t,v(f),m(h)));return y}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1068:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/align_period\");e.exports=function(t,e,r,o,s,l){var c=t._length,u=e.makeCalcdata(t,o),f=r.makeCalcdata(t,s);u=a(t,e,o,u),f=a(t,r,s,f);var h,p,d,g,m=t.text,v=void 0!==m&&n.isArray1D(m),y=t.hovertext,x=void 0!==y&&n.isArray1D(y),b=n.distinctVals(u),_=b.vals,w=n.distinctVals(f),T=w.vals,k=[],M=T.length,A=_.length;for(h=0;h<l.length;h++)k[h]=n.init2dArray(M,A);v&&(d=n.init2dArray(M,A)),x&&(g=n.init2dArray(M,A));var S=n.init2dArray(M,A);for(h=0;h<c;h++)if(u[h]!==i&&f[h]!==i){var E=n.findBin(u[h]+b.minDiff/2,_),C=n.findBin(f[h]+w.minDiff/2,T);for(p=0;p<l.length;p++){var L=t[l[p]];k[p][C][E]=L[h],S[C][E]=h}v&&(d[C][E]=m[h]),x&&(g[C][E]=y[h])}for(t[\"_\"+o]=_,t[\"_\"+s]=T,p=0;p<l.length;p++)t[\"_\"+l[p]]=k[p];v&&(t._text=d),x&&(t._hovertext=g),e&&\"category\"===e.type&&(t[\"_\"+o+\"CategoryMap\"]=_.map((function(t){return e._categories[t]}))),r&&\"category\"===r.type&&(t[\"_\"+s+\"CategoryMap\"]=T.map((function(t){return r._categories[t]}))),t._after2before=S}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./style_defaults\"),s=t(\"../../components/colorscale/defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}i(t,e,u,c)?(a(t,e,c,u),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\"),o(t,e,u,c),u(\"hoverongaps\"),u(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),s(t,e,c,u,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1065,\"./style_defaults\":1078,\"./xyz_defaults\":1079}],1071:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],f={},h=[],p=t[0],d=[],g=[0,0,0],m=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<m;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(f[[r,i]]=[r,i,s]),u.push([r,i,s])):h.push([r,i]));for(;h.length;){for(l={},c=!1,o=h.length-1;o>=0;o--)(s=((f[[(r=(a=h[o])[0])-1,i=a[1]]]||g)[2]+(f[[r+1,i]]||g)[2]+(f[[r,i-1]]||g)[2]+(f[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],h.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)f[a]=l[a],u.push(l[a])}return u.sort((function(t,e){return e[2]-t[2]}))}},{\"../../lib\":778}],1072:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,f,h,p,d=t.cd[0],g=d.trace,m=t.xa,v=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,T=d.zmask,k=g.zhoverformat,M=y,A=x;if(!1!==t.index){try{h=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(h<0||h>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(M=[2*y[0]-y[1]],S=1;S<y.length;S++)M.push((y[S]+y[S-1])/2);for(M.push([2*y[y.length-1]-y[y.length-2]]),A=[2*x[0]-x[1]],S=1;S<x.length;S++)A.push((x[S]+x[S-1])/2);A.push([2*x[x.length-1]-x[x.length-2]])}h=Math.max(0,Math.min(M.length-2,i.findBin(e,M))),p=Math.max(0,Math.min(A.length-2,i.findBin(r,A)))}var E,C,L=m.c2p(y[h]),I=m.c2p(y[h+1]),P=v.c2p(x[p]),z=v.c2p(x[p+1]);c?(E=d.orig_x||y,C=d.orig_y||x,I=L,u=E[h],z=P,f=C[p]):(E=d.orig_x||_||y,C=d.orig_y||w||x,u=_?E[h]:(E[h]+E[h+1])/2,f=w?C[p]:(C[p]+C[p+1])/2,m&&\"category\"===m.type&&(u=y[h]),v&&\"category\"===v.type&&(f=x[p]),g.zsmooth&&(L=I=m.c2p(u),P=z=v.c2p(f)));var O=b[p][h];if(T&&!T[p][h]&&(O=void 0),void 0!==O||g.hoverongaps){var D;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?D=d.hovertext[p][h]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(D=d.text[p][h]);var R=o(g),F={type:\"linear\",range:[R.min,R.max],hoverformat:k,_separators:m._separators,_numFormat:m._numFormat},B=a.tickText(F,O,\"hover\").text;return[i.extendFlat(t,{index:g._after2before?g._after2before[p][h]:[p,h],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:L,x1:I,y0:P,y1:z,xLabelVal:u,yLabelVal:f,zLabelVal:O,zLabel:B,text:D})]}}},{\"../../components/colorscale\":655,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1073:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1065,\"./calc\":1066,\"./colorbar\":1068,\"./defaults\":1070,\"./hover\":1072,\"./plot\":1076,\"./style\":1077}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,f,h,p,d,g,m,v=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,h=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(f=u[o+c[1]])&&(0===p?g=m=f:(g=Math.min(g,f),m=Math.max(m,f)),h++,p+=f);if(0===h)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/h,void 0===d?h<4&&(v=1):(t[a][o]=(1+r)*t[a][o]-r*d,m>g&&(v=Math.max(v,Math.abs(t[a][o]-d)/(m-g))))}return v}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":778}],1075:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,f=[],h=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return h?e.slice(0,o):e.slice(0,o+1);if(h||d)f=e.slice(0,o);else if(1===o)f=[e[0]-.5,e[0]+.5];else{for(f=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)f.push(.5*(e[u-1]+e[u]));f.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var m=f[f.length-1],v=m-f[f.length-2];for(u=g;u<o;u++)m+=v,f.push(m)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=h||d?0:-.5;u<o;u++)f.push(l+c*u)}return f}},{\"../../lib\":778,\"../../registry\":911}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function f(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,h){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(h,r,\"hm\").each((function(e){var r,h,g,m,v,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,T=b.x,k=b.y,M=b.xCenter,A=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),I=!1,P=!1;for(y=0;void 0===r&&y<T.length-1;)r=p.c2p(T[y]),y++;for(y=T.length-1;void 0===h&&y>0;)h=p.c2p(T[y]),y--;for(h<r&&(g=h,h=r,r=g,I=!0),y=0;void 0===m&&y<k.length-1;)m=d.c2p(k[y]),y++;for(y=k.length-1;void 0===v&&y>0;)v=d.c2p(k[y]),y--;if(v<m&&(g=m,m=v,v=g,P=!0),S&&(M=T,A=k,T=b.xfill,k=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),h=Math.min((1+z)*p._length,h),m=Math.max(-z*d._length,m),v=Math.min((1+z)*d._length,v)}var O=Math.round(h-r),D=Math.round(v-m);if(O<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=O,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=I?function(t){return L-1-t}:o.identity,j=P?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(T[t])-r),0,O)},j=function(t){return o.constrain(Math.round(d.c2p(k[t])-m),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=I?0:1,K=P?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(O*D*4)}catch(t){rt=new Array(O*D*4)}if(\"best\"===E){var it,at,ot,st=M||T,lt=A||k,ct=new Array(st.length),ut=new Array(lt.length),ft=new Array(O),ht=M?u:c,pt=A?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-m);for(y=0;y<O;y++)ft[y]=ht(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<O;y++,nt+=4)f(rt,nt,W=kt(at,ot,ft[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<O;y++)W=Tt(Y[y],1),f(rt,nt=4*(Z*O+N(y)),W);var dt=U.createImageData(O,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,mt=gt.length;for(H=0;H<mt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var vt=_.xgap,yt=_.ygap,xt=Math.floor(vt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=Tt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-vt,Z[1]-Z[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=i(\"rgb(\"+$+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:O,x:r,y:m,\"xlink:href\":B.toDataURL(\"image/png\")})}function Tt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function kt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return Tt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,Tt(i+r.frac*c+n.frac*(u+r.frac*a))}}))}},{\"../../components/colorscale\":655,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,d3:169,tinycolor2:576}],1077:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",(function(t){return t.trace.opacity}))}},{d3:169}],1078:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,f,h=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===h||!h.length)return 0;if(i.isArray1D(t.z)){u=r(l),f=r(c);var p=i.minRowLength(u),d=i.minRowLength(f);if(0===p||0===d)return 0;e._length=Math.min(p,d,h.length)}else{if(u=o(l,r),f=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(h))return 0;r(\"transpose\"),e._length=null}return\"heatmapgl\"===t.type||\"contourgl\"===t.type||a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":778,\"../../registry\":911,\"fast-isnumeric\":241}],1080:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}l.zsmooth={valType:\"enumerated\",values:[\"fast\",!1],dflt:\"fast\",editType:\"calc\"},a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../heatmap/attributes\":1065}],1081:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={zsmooth:\"fast\",z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y,this.options.zsmooth=t.zsmooth;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var f=0;f<4;f++)s[4*l+f]=u[f]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c,u,f=this.scene.xaxis,h=this.scene.yaxis;!1===t.zsmooth&&(c={ppad:r.x[1]-r.x[0]},u={ppad:r.y[1]-r.y[0]}),t._extremes[f._id]=i.findExtremes(f,r.x,c),t._extremes[h._id]=i.findExtremes(h,r.y,u)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"gl-heatmap2d\":271}],1082:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,l,s)?(l(\"text\"),l(\"zsmooth\"),a(t,e,s,l,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1080}],1083:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":868,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"./attributes\":1080,\"./convert\":1081,\"./defaults\":1082}],1084:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"./bin_attributes\":1086,\"./constants\":1090}],1085:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1086:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1087:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":241}],1088:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function f(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=h(i,a),s=0;s<10;s++){var l=h(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function h(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,h=-.1*e,p=t-h,d=r[0],g=r[1],m=Math.min(f(d+h,d+p,n,a),f(g+h,g+p,n,a)),v=Math.min(f(d+c,d+h,n,a),f(g+c,g+h,n,a));if(m>v&&v<Math.abs(g-d)/4e3?(s=m,l=!1):(s=Math.min(m,v),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var f=u(c,x,!1,a);(c+f)/2<e+t&&(c=f)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828}],1089:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),f=t(\"./bin_label_vals\");function h(t,e,r,s,l){var c,u,f,p,d,g,m,v=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},T=function(t){return r.c2r(t,0,p)},k=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function M(t,e,r){e[t+\"Found\"]?(e[t]=k(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],v+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var A=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((f=u[c]).visible){var L=b.dirs[c];d=f[\"_\"+L+\"pos0\"]=r.makeCalcdata(f,L),A=i.concat(A,d),delete f[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete f._autoBin,f[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(f,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===f.type&&(C=!0))}p=u[0][s+\"calendar\"];var I=o.autoBin(A,r,b.nbins,E,p,b.sizeFound&&b.size),P=u[0]._autoBin={};if(g=P[b.dirs[0]]={},C&&(b.size||(I.start=T(o.tickIncrement(w(I.start),I.size,!0,p))),void 0===b.end&&(I.end=T(o.tickIncrement(w(I.end),I.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===I._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[I,d,!0];I=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),f=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)f=!0;else if(f){var g=h(t,s,r,n,!0),m=g[0],v=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],v?d.push(s):p=Math.min(p,m.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,v)}(m=f.cumulative||{}).enabled&&\"include\"!==m.currentbin&&(\"decreasing\"===m.direction?I.start=T(o.tickIncrement(w(I.start),I.size,!0,p)):I.end=T(o.tickIncrement(w(I.end),I.size,!1,p))),b.size=I.size,b.sizeFound||(g.size=I.size,i.nestedProperty(u[0],v+\".size\").set(I.size)),M(\"start\",b,I),M(\"end\",b,I)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[v]||{},O=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),O.start=r.l2r(j),F||i.nestedProperty(e,v+\".start\").set(O.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);O.end=r.l2r(H),q||i.nestedProperty(e,v+\".start\").set(O.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[v]=i.extendFlat({},e[v]||{}),delete e._input[G],delete e[G]),[O,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],m=[],v=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=h(t,e,v,y),T=w[0],k=w[1],M=\"string\"==typeof T.size,A=[],S=M?A:T,E=[],C=[],L=[],I=0,P=e.histnorm,z=e.histfunc,O=-1!==P.indexOf(\"density\");_.enabled&&O&&(P=P.replace(/ ?density$/,\"\"),O=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[P],N=!1,j=function(t){return v.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(T.start),p=j(T.end)+(r-o.tickIncrement(r,T.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,T.size,!1,b),g.push((r+a)/2),m.push(R),L.push([]),A.push(r),O&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;A.push(r),M||\"date\"!==v.type||(S={start:j(S.start),end:j(S.end),size:S.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var U=e[\"_\"+y+\"bingroup\"],V={leftGap:1/0,rightGap:1/0};U&&(t._fullLayout._roundFnOpts[U]||(t._fullLayout._roundFnOpts[U]=V),V=t._fullLayout._roundFnOpts[U]);var q,H=m.length,G=!0,Y=V.leftGap,W=V.rightGap,X={};for(r=0;r<k.length;r++){var Z=k[r];(d=i.findBin(Z,S))>=0&&d<H&&(I+=F(d,r,m,D,C),G&&L[d].length&&Z!==k[L[d][0]]&&(G=!1),L[d].push(r),X[r]=d,Y=Math.min(Y,Z-A[d]),W=Math.min(W,A[d+1]-Z))}V.leftGap=Y,V.rightGap=W,G||(q=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[U];return f(n.leftGap,n.rightGap,A,v,b)(e,r)}}),N&&(I=u(m,C)),B&&B(m,I,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(m,_.direction,_.currentbin);var J=Math.min(g.length,m.length),K=[],Q=0,$=J-1;for(r=0;r<J;r++)if(m[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(m[r]){$=r;break}for(r=Q;r<=$;r++)if(n(g[r])&&n(m[r])){var tt={p:g[r],s:m[r],b:0};_.enabled||(tt.pts=L[r],G?tt.ph0=tt.ph1=L[r].length?k[L[r][0]]:g[r]:(e._computePh=!0,tt.ph0=q(A[r]),tt.ph1=q(A[r+1],!0))),K.push(tt)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,T.size,!1,b)-K[0].p),s(K,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(K,e,X),K},calcAllAutoBins:h}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"./average\":1085,\"./bin_functions\":1087,\"./bin_label_vals\":1088,\"./norm_functions\":1096,\"fast-isnumeric\":241}],1090:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,f,h,p,d,g,m,v=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function T(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"]||\"\",c=v[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(v[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var k=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],h=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var M=r[p+\"axis\"],A=l(e,M)+r.orientation;(k[A]||{})[r.alignmentgroup]&&(h=A)}h||\"overlay\"===e.barmode||(h=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}h?(x[h]||(x[h]=[]),x[h].push(r)):b.push(r)}for(h in x)if(1!==(f=x[h]).length){var S=!1;for(f.length&&(r=f[0],S=_(\"bingroup\")),h=S||h,d=0;d<f.length;d++){var E=(r=f[d])._input.bingroup;E&&E!==h&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",h+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=h,T(r,h,w(r))}}else b.push(f[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(m=0;m<2;m++){var L=_((p=u[m])+\"bingroup\",C?C+\"__\"+p:null);T(r,L,p)}else T(r,C,w(r))}for(h in v){var I=v[h];for(f=I.traces,g=0;g<c.length;g++){var P,z,O=c[g],D=O.name;if(\"nbins\"!==D||!I.sizeFound){for(d=0;d<f.length;d++){if(r=f[d],p=I.dirs[d],P=O.aStr[p],void 0!==s(r._input,P).get()){I[D]=_(P),I[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,P).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<f.length;d++)(r=f[d])[\"_\"+p+\"bingroup\"]&&_(P,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||I.sizeFound||I.nbinsFound||(r=f[0],I[D]=_(P))}}}}},{\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../bar/defaults\":925}],1092:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),f=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"orientation\",f&&!u?\"h\":\"v\"),p=\"v\"===h?\"x\":\"y\",d=\"v\"===h?\"y\":\"x\",g=u&&f?Math.min(i.minRowLength(u)&&i.minRowLength(f)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var m=(e.marker.line||{}).color,v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,m||a.defaultLine,{axis:\"y\"}),v(t,e,m||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../../registry\":911,\"../bar/style_defaults\":936,\"./attributes\":1084}],1093:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return o}}},{\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1095:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/cross_trace_calc\":924,\"../bar/layout_attributes\":930,\"../bar/layout_defaults\":931,\"../bar/plot\":932,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"./attributes\":1084,\"./calc\":1089,\"./cross_trace_defaults\":1091,\"./defaults\":1092,\"./event_data\":1093,\"./hover\":1094}],1096:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1097:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat;e.exports=c({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:c({},n.bingroup,{}),xbingroup:c({},n.bingroup,{}),ybingroup:c({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:s({},{keys:\"z\"}),showlegend:c({},o.showlegend,{dflt:!1})},l(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../heatmap/attributes\":1065,\"../histogram/attributes\":1084,\"../histogram/bin_attributes\":1086}],1098:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function f(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function h(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var f=(e||[])[o];c[o]=void 0===f?[u(t[o]),u(t[o+1],!0)]:[f,f]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),m=i.getFromId(t,e.yaxis),v=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,v)},b=function(t){return m.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],T=_[1],k=c(t,e,m,\"y\"),M=k[0],A=k[1],S=e._length;T.length>S&&T.splice(S,T.length-S),A.length>S&&A.splice(S,A.length-S);var E=[],C=[],L=[],I=\"string\"==typeof w.size,P=\"string\"==typeof M.size,z=[],O=[],D=I?z:w,R=P?O:M,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-i.tickIncrement(K,J,!1,v))/1e6;for(r=K;r<Q;r=i.tickIncrement(r,J,!1,v))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var $,tt=C.length,et=(r-K)/tt,rt=($=K+et/2,g.c2r($,0,v)),nt=M.size,it=b(M.start),at=b(M.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),O.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}O.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return m.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,I),X=u(E.length,R,lt,P)),I||\"date\"!==g.type||(D=f(x,D)),P||\"date\"!==m.type||(R=f(b,R));var ut=!0,ft=!0,ht=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,mt=1/0,vt=1/0;for(r=0;r<S;r++){var yt=T[r],xt=A[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ht[p]?ht[p]=yt:ht[p]!==yt&&(ut=!1)),ft&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ft=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),mt=Math.min(mt,xt-O[d]),vt=Math.min(vt,O[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:T,xRanges:h(z,ut&&ht,dt,gt,g,v),x0:rt,dx:et,y:A,yRanges:h(O,ft&&pt,mt,vt,m,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../histogram/average\":1085,\"../histogram/bin_functions\":1087,\"../histogram/bin_label_vals\":1088,\"../histogram/calc\":1089,\"../histogram/norm_functions\":1096}],1099:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/style_defaults\":1078,\"./attributes\":1097,\"./sample_defaults\":1102}],1100:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],f=c[1],h=t.cd[0],p=h.xRanges[f],d=h.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":828,\"../heatmap/hover\":1072}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"../heatmap/plot\":1076,\"../heatmap/style\":1077,\"../histogram/cross_trace_defaults\":1091,\"../histogram/event_data\":1093,\"./attributes\":1097,\"./defaults\":1099,\"./hover\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":778,\"../../registry\":911}],1103:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:{color:i.line.color,width:o({},i.line.width,{dflt:.5}),dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../histogram2d/attributes\":1097}],1104:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,(function(r){return n.coerce2(t,e,s,r)})),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":778,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../histogram2d/sample_defaults\":1102,\"./attributes\":1103}],1105:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/calc\":1009,\"../contour/colorbar\":1011,\"../contour/hover\":1021,\"../contour/plot\":1026,\"../contour/style\":1028,\"../histogram/cross_trace_defaults\":1091,\"./attributes\":1103,\"./defaults\":1104}],1106:[function(t,e,r){\"use strict\";for(var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"./constants\").colormodel,s=[\"rgb\",\"rgba\",\"rgba256\",\"hsl\",\"hsla\"],l=[],c=[],u=0;u<s.length;u++){var f=o[s[u]];l.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zminDflt||f.min).join(\", \")+\"].\"),c.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zmaxDflt||f.max).join(\", \")+\"].\")}e.exports=a({source:{valType:\"string\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},colormodel:{valType:\"enumerated\",values:s,editType:\"calc\"},zmin:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},zmax:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",dflt:1,editType:\"calc\"},dy:{valType:\"number\",dflt:1,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"data_array\",editType:\"plot\"},hoverinfo:a({},n.hoverinfo,{flags:[\"x\",\"y\",\"z\",\"color\",\"name\",\"text\"],dflt:\"x+y+z+text+name\"}),hovertemplate:i({},{keys:[\"z\",\"color\",\"colormodel\"]}),transforms:void 0})},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"./constants\":1108}],1107:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\"),a=t(\"fast-isnumeric\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../lib\").maxRowLength,l=t(\"./helpers\").getImageSize;function c(t,e,r,i){return function(a){return n.constrain((a-t)*e,r,i)}}function u(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n;if(e._hasZ)r=e.z.length,n=s(e.z);else if(e._hasSource){var f=l(e.source);r=f.height,n=f.width}var h,p=o.getFromId(t,e.xaxis||\"x\"),d=o.getFromId(t,e.yaxis||\"y\"),g=p.d2c(e.x0)-e.dx/2,m=d.d2c(e.y0)-e.dy/2,v=[g,g+n*e.dx],y=[m,m+r*e.dy];if(p&&\"log\"===p.type)for(h=0;h<n;h++)v.push(g+h*e.dx);if(d&&\"log\"===d.type)for(h=0;h<r;h++)y.push(m+h*e.dy);return e._extremes[p._id]=o.findExtremes(p,v),e._extremes[d._id]=o.findExtremes(d,y),e._scaler=function(t){var e=i.colormodel[t.colormodel],r=(e.colormodel||t.colormodel).length;t._sArray=[];for(var n=0;n<r;n++)e.min[n]!==t.zmin[n]||e.max[n]!==t.zmax[n]?t._sArray.push(c(t.zmin[n],(e.max[n]-e.min[n])/(t.zmax[n]-t.zmin[n]),e.min[n],e.max[n])):t._sArray.push(u(e.min[n],e.max[n]));return function(e){for(var n=e.slice(0,r),i=0;i<r;i++){var o=n[i];if(!a(o))return!1;n[i]=t._sArray[i](o)}return n}}(e),[{x0:g,y0:m,z:e.z,w:n,h:r}]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":1108,\"./helpers\":1111,\"fast-isnumeric\":241}],1108:[function(t,e,r){\"use strict\";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:[\"\",\"\",\"\"]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},rgba256:{colormodel:\"rgba\",zminDflt:[0,0,0,0],zmaxDflt:[255,255,255,255],min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\",\"\"]}}}},{}],1109:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./constants\"),o=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX;e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"source\"),e.source&&!e.source.match(o)&&delete e.source,e._hasSource=!!e.source;var s,l=r(\"z\");(e._hasZ=!(void 0===l||!l.length||!l[0]||!l[0].length),e._hasZ||e._hasSource)?(r(\"x0\"),r(\"y0\"),r(\"dx\"),r(\"dy\"),e._hasZ?(r(\"colormodel\",\"rgb\"),r(\"zmin\",(s=a.colormodel[e.colormodel]).zminDflt||s.min),r(\"zmax\",s.zmaxDflt||s.max)):e._hasSource&&(e.colormodel=\"rgba256\",s=a.colormodel[e.colormodel],e.zmin=s.zminDflt,e.zmax=s.zmaxDflt),r(\"text\"),r(\"hovertext\"),r(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../lib\":778,\"../../snapshot/helpers\":915,\"./attributes\":1106,\"./constants\":1108}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){return\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t.z||(t.z=e.color),t}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"image-size\"),i=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX,a=t(\"buffer/\").Buffer;r.getImageSize=function(t){var e=t.replace(i,\"\"),r=new a(e,\"base64\");return n(r)}},{\"../../snapshot/helpers\":915,\"buffer/\":111,\"image-size\":444}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"./constants\");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u,f=Math.floor((e-o.x0)/s.dx),h=Math.floor(Math.abs(r-o.y0)/s.dy);if(s._hasZ?u=o.z[h][f]:s._hasSource&&(u=s._canvas.el.getContext(\"2d\").getImageData(f,h,1,1).data),u){var p,d=o.hi||s.hoverinfo;if(d){var g=d.split(\"+\");-1!==g.indexOf(\"all\")&&(g=[\"color\"]),-1!==g.indexOf(\"color\")&&(p=!0)}var m,v=a.colormodel[s.colormodel],y=v.colormodel||s.colormodel,x=y.length,b=s._scaler(u),_=v.suffix,w=[];(s.hovertemplate||p)&&(w.push(\"[\"+[b[0]+_[0],b[1]+_[1],b[2]+_[2]].join(\", \")),4===x&&w.push(\", \"+b[3]+_[3]),w.push(\"]\"),w=w.join(\"\"),t.extraText=y.toUpperCase()+\": \"+w),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[h])?m=s.hovertext[h][f]:Array.isArray(s.text)&&Array.isArray(s.text[h])&&(m=s.text[h][f]);var T=c.c2p(o.y0+(h+.5)*s.dy),k=o.x0+(f+.5)*s.dx,M=o.y0+(h+.5)*s.dy,A=\"[\"+u.slice(0,s.colormodel.length).join(\", \")+\"]\";return[i.extendFlat(t,{index:[h,f],x0:l.c2p(o.x0+f*s.dx),x1:l.c2p(o.x0+(f+1)*s.dx),y0:T,y1:T,color:b,xVal:k,xLabelVal:k,yVal:M,yLabelVal:M,zLabelVal:A,text:m,hovertemplateLabels:{zLabel:A,colorLabel:w,\"color[0]Label\":b[0]+_[0],\"color[1]Label\":b[1]+_[1],\"color[2]Label\":b[2]+_[2],\"color[3]Label\":b[3]+_[3]}})]}}}},{\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1108}],1113:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"image\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"noSortingByValue\"],animatable:!1,meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1106,\"./calc\":1107,\"./defaults\":1109,\"./event_data\":1110,\"./hover\":1112,\"./plot\":1114,\"./style\":1115}],1114:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strTranslate,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"./constants\"),l=i.isIOS()||i.isSafari()||i.isIE();e.exports=function(t,e,r,c){var u=e.xaxis,f=e.yaxis,h=!(l||t._context._exportedPlot);i.makeTraceGroups(c,r,\"im\").each((function(e){var r=n.select(this),l=e[0],c=l.trace,p=h&&!c._hasZ&&c._hasSource&&\"linear\"===u.type&&\"linear\"===f.type;c._fastImage=p;var d,g,m,v,y,x,b=l.z,_=l.x0,w=l.y0,T=l.w,k=l.h,M=c.dx,A=c.dy;for(x=0;void 0===d&&x<T;)d=u.c2p(_+x*M),x++;for(x=T;void 0===g&&x>0;)g=u.c2p(_+x*M),x--;for(x=0;void 0===v&&x<k;)v=f.c2p(w+x*A),x++;for(x=k;void 0===y&&x>0;)y=f.c2p(w+x*A),x--;if(g<d&&(m=g,g=d,d=m),y<v&&(m=v,v=y,y=m),!p){d=Math.max(-.5*u._length,d),g=Math.min(1.5*u._length,g),v=Math.max(-.5*f._length,v),y=Math.min(1.5*f._length,y)}var S=Math.round(g-d),E=Math.round(y-v);if(S<=0||E<=0){r.selectAll(\"image\").data([]).exit().remove()}else{var C=r.selectAll(\"image\").data([e]);C.enter().append(\"svg:image\").attr({xmlns:o.svg,preserveAspectRatio:\"none\"}),C.exit().remove();var L=\"image-rendering: optimizeSpeed; image-rendering: -moz-crisp-edges; image-rendering: -o-crisp-edges; image-rendering: -webkit-optimize-contrast; image-rendering: optimize-contrast; image-rendering: crisp-edges; image-rendering: pixelated;\";if(p){var I=i.simpleMap(u.range,u.r2l),P=i.simpleMap(f.range,f.r2l),z=I[1]<I[0],O=P[1]>P[0];if(z||O){var D=d+S/2,R=v+E/2;L+=\"transform:\"+a(D+\"px\",R+\"px\")+\"scale(\"+(z?-1:1)+\",\"+(O?-1:1)+\")\"+a(-D+\"px\",-R+\"px\")+\";\"}}C.attr(\"style\",L);var F=new Promise((function(t){if(c._hasZ)t();else if(c._hasSource)if(c._canvas&&c._canvas.el.width===T&&c._canvas.el.height===k&&c._canvas.source===c.source)t();else{var e=document.createElement(\"canvas\");e.width=T,e.height=k;var r=e.getContext(\"2d\");c._image=c._image||new Image;var n=c._image;n.onload=function(){r.drawImage(n,0,0),c._canvas={el:e,source:c.source},t()},n.setAttribute(\"src\",c.source)}})).then((function(){var t;if(c._hasZ)t=B((function(t,e){return b[e][t]})).toDataURL(\"image/png\");else if(c._hasSource)if(p)t=c.source;else{var e=c._canvas.el.getContext(\"2d\").getImageData(0,0,T,k).data;t=B((function(t,r){var n=4*(r*T+t);return[e[n],e[n+1],e[n+2],e[n+3]]})).toDataURL(\"image/png\")}C.attr({\"xlink:href\":t,height:E,width:S,x:d,y:v})}));t._promises.push(F)}function B(t){var e=document.createElement(\"canvas\");e.width=S,e.height=E;var r,n=e.getContext(\"2d\"),a=function(t){return i.constrain(Math.round(u.c2p(_+t*M)-d),0,S)},o=function(t){return i.constrain(Math.round(f.c2p(w+t*A)-v),0,E)},h=s.colormodel[c.colormodel],p=h.colormodel||c.colormodel,g=h.fmt;for(x=0;x<l.w;x++){var m=a(x),y=a(x+1);if(y!==m&&!isNaN(y)&&!isNaN(m))for(var b=0;b<l.h;b++){var T=o(b),k=o(b+1);k===T||isNaN(k)||isNaN(T)||!t(x,b)||(r=c._scaler(t(x,b)),n.fillStyle=r?p+\"(\"+g(r).join(\",\")+\")\":\"rgba(0,0,0,0)\",n.fillRect(m,T,y-m,k-T))}}return e}}))}},{\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"./constants\":1108,d3:169}],1115:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".im image\").style(\"opacity\",(function(t){return t[0].trace.opacity}))}},{d3:169}],1116:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../constants/delta.js\"),h=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"step\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},h,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},h,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:f.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:f.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},h,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,minexponent:c.minexponent,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":642,\"../../constants/delta.js\":747,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1117:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"indicator\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1118:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1119:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),f=t(\"../../plots/cartesian/tick_label_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var m,v,y,x,b,_,w=new Array(2);function T(t,e){return n.coerce(y,x,i.gauge,t,e)}function k(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),m=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(m||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),v=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(m||v||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),T(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),T(\"bgcolor\",p.paper_bgcolor),T(\"borderwidth\"),T(\"bordercolor\"),T(\"bar.color\"),T(\"bar.line.color\"),T(\"bar.line.width\"),T(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:h}),T(\"threshold.value\"),T(\"threshold.thickness\"),T(\"threshold.line.width\"),T(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),k(\"visible\"),e._range=k(\"range\",e._range);var M={outerTicks:!0};c(b,_,k,\"linear\"),f(b,_,k,\"linear\",M),u(b,_,k,M)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"../../plots/domain\":855,\"./attributes\":1116,\"./constants.js\":1119}],1121:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1116,\"./base_plot\":1117,\"./calc\":1118,\"./defaults\":1120,\"./plot\":1122}],1122:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strScale,o=i.strTranslate,s=i.rad2deg,l=t(\"../../constants/alignment\").MID_SHIFT,c=t(\"../../components/drawing\"),u=t(\"./constants\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../../plots/cartesian/axis_defaults\"),d=t(\"../../plots/cartesian/position_defaults\"),g=t(\"../../plots/cartesian/layout_attributes\"),m=t(\"../../components/color\"),v={left:\"start\",center:\"middle\",right:\"end\"},y={left:0,center:.5,right:1},x=/[yzafpn\\xb5mkMGTPEZY]/;function b(t){return t&&t.duration>0}function _(t){t.each((function(t){m.stroke(n.select(this),t.line.color)})).each((function(t){m.fill(n.select(this),t.color)})).style(\"stroke-width\",(function(t){return t.line.width}))}function w(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,g,t,e)}return p(a,o,l,s,n),d(a,o,l,s),o}function T(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(f.convertToTspans,i).call(c.font,e),c.bBox(o.node())}function M(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,p){var d,g=t._fullLayout;b(r)&&p&&(d=p()),i.makeTraceGroups(g._indicatorlayer,e,\"trace\").each((function(e){var p,A,S,E,C,L=e[0].trace,I=n.select(this),P=L._hasGauge,z=L._isAngular,O=L._isBullet,D=L.domain,R={w:g._size.w*(D.x[1]-D.x[0]),h:g._size.h*(D.y[1]-D.y[0]),l:g._size.l+g._size.w*D.x[0],r:g._size.r+g._size.w*(1-D.x[1]),t:g._size.t+g._size.h*(1-D.y[1]),b:g._size.b+g._size.h*D.y[0]},F=R.l+R.w/2,B=R.t+R.h/2,N=Math.min(R.w/2,R.h),j=u.innerRadius*N,U=L.align||\"center\";if(A=B,P){if(z&&(p=F,A=B+N/2,S=function(t){return function(t,e){var r=Math.sqrt(t.width/2*(t.width/2)+t.height*t.height);return[e/r,t,e]}(t,.9*j)}),O){var V=u.bulletPadding,q=1-u.bulletNumberDomainSize+V;p=R.l+(q+(1-q)*y[U])*R.w,S=function(t){return T(t,(u.bulletNumberDomainSize-V)*R.w,R.h)}}}else p=R.l+y[U]*R.w,S=function(t){return T(t,R.w,R.h)};!function(t,e,r,s){var l,u,p,d=r[0].trace,g=s.numbersX,_=s.numbersY,T=d.align||\"center\",A=v[T],S=s.transitionOpts,E=s.onComplete,C=i.ensureSingle(e,\"g\",\"numbers\"),L=[];d._hasNumber&&L.push(\"number\");d._hasDelta&&(L.push(\"delta\"),\"left\"===d.delta.position&&L.reverse());var I=C.selectAll(\"text\").data(L);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(x)||r(i).slice(-1).match(x))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,(function(t){return parseInt(t)-1})),o=w(t,{tickformat:a});return function(t){return Math.abs(t)<1?h.tickText(o,t).text:r(t)}}I.enter().append(\"text\"),I.attr(\"text-anchor\",(function(){return A})).attr(\"class\",(function(t){return t})).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),I.exit().remove();var z,O=d.mode+d.align;d._hasDelta&&(z=function(){var e=w(t,{tickformat:d.delta.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=function(t){return d.delta.relative?t.relativeDelta:t.delta},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?d.delta.increasing.symbol:d.delta.decreasing.symbol)+e(t)},s=function(t){return t.delta>=0?d.delta.increasing.color:d.delta.decreasing.color};void 0===d._deltaLastValue&&(d._deltaLastValue=a(r[0]));var l=C.select(\"text.delta\");function p(){l.text(o(a(r[0]),i)).call(m.fill,s(r[0])).call(f.convertToTspans,t)}return l.call(c.font,d.delta.font).call(m.fill,s({delta:d._deltaLastValue})),b(S)?l.transition().duration(S.duration).ease(S.easing).tween(\"text\",(function(){var t=n.select(this),e=a(r[0]),l=d._deltaLastValue,c=P(d.delta.valueformat,i,l,e),u=n.interpolateNumber(l,e);return d._deltaLastValue=e,function(e){t.text(o(u(e),c)),t.call(m.fill,s({delta:u(e)}))}})).each(\"end\",(function(){p(),E&&E()})).each(\"interrupt\",(function(){p(),E&&E()})):p(),u=k(o(a(r[0]),i),d.delta.font,A,t),l}(),O+=d.delta.position+d.delta.font.size+d.delta.font.family+d.delta.valueformat,O+=d.delta.increasing.symbol+d.delta.decreasing.symbol,p=u);d._hasNumber&&(!function(){var e=w(t,{tickformat:d.number.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=d.number.suffix,o=d.number.prefix,s=C.select(\"text.number\");function u(){var e=\"number\"==typeof r[0].y?o+i(r[0].y)+a:\"-\";s.text(e).call(c.font,d.number.font).call(f.convertToTspans,t)}b(S)?s.transition().duration(S.duration).ease(S.easing).each(\"end\",(function(){u(),E&&E()})).each(\"interrupt\",(function(){u(),E&&E()})).attrTween(\"text\",(function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);d._lastValue=r[0].y;var s=P(d.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(o+s(e(r))+a)}})):u(),l=k(o+i(r[0].y)+a,d.number.font,A,t)}(),O+=d.number.font.size+d.number.font.family+d.number.valueformat+d.number.suffix+d.number.prefix,p=l);if(d._hasDelta&&d._hasNumber){var D,R,F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=[(u.left+u.right)/2,(u.top+u.bottom)/2],N=.75*d.delta.font.size;\"left\"===d.delta.position&&(D=M(d,\"deltaPos\",0,-1*(l.width*y[d.align]+u.width*(1-y[d.align])+N),O,Math.min),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:u.left+D,right:l.right,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"right\"===d.delta.position&&(D=M(d,\"deltaPos\",0,l.width*(1-y[d.align])+u.width*y[d.align]+N,O,Math.max),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:l.left,right:u.right+D,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"bottom\"===d.delta.position&&(D=null,R=u.height,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height,bottom:l.bottom+u.height}),\"top\"===d.delta.position&&(D=null,R=l.top,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height-u.height,bottom:l.bottom}),z.attr({dx:D,dy:R})}(d._hasNumber||d._hasDelta)&&C.attr(\"transform\",(function(){var t=s.numbersScaler(p);O+=t[2];var e,r=M(d,\"numbersScale\",1,t[0],O,Math.min);d._scaleNumbers||(r=1),e=d._isAngular?_-r*p.bottom:_-r*(p.top+p.bottom)/2,d._numbersTop=r*p.top+e;var n=p[T];\"center\"===T&&(n=(p.left+p.right)/2);var i=g-r*n;return i=M(d,\"numbersTranslate\",0,i,O,Math.max),o(i,e)+a(r)}))}(t,I,e,{numbersX:p,numbersY:A,numbersScaler:S,transitionOpts:r,onComplete:d}),P&&(E={range:L.gauge.axis.range,color:L.gauge.bgcolor,line:{color:L.gauge.bordercolor,width:0},thickness:1},C={range:L.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:L.gauge.bordercolor,width:L.gauge.borderwidth},thickness:1});var H=I.selectAll(\"g.angular\").data(z?e:[]);H.exit().remove();var G=I.selectAll(\"g.angularaxis\").data(z?e:[]);G.exit().remove(),z&&function(t,e,r,i){var a,c,u,f,p=r[0].trace,d=i.size,g=i.radius,m=i.innerRadius,v=i.gaugeBg,y=i.gaugeOutline,x=[d.l+d.w/2,d.t+d.h/2+g/2],T=i.gauge,k=i.layer,M=i.transitionOpts,A=i.onComplete,S=Math.PI/2;function E(t){var e=p.gauge.axis.range[0],r=(t-e)/(p.gauge.axis.range[1]-e)*Math.PI-S;return r<-S?-S:r>S?S:r}function C(t){return n.svg.arc().innerRadius((m+g)/2-t/2*(g-m)).outerRadius((m+g)/2+t/2*(g-m)).startAngle(-S)}function L(t){t.attr(\"d\",(function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()}))}T.enter().append(\"g\").classed(\"angular\",!0),T.attr(\"transform\",o(x[0],x[1])),k.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),k.selectAll(\"g.xangularaxistick,path,text\").remove(),(a=w(t,p.gauge.axis)).type=\"linear\",a.range=p.gauge.axis.range,a._id=\"xangularaxis\",a.setScale();var I=function(t){return(a.range[0]-t.x)/(a.range[1]-a.range[0])*Math.PI+Math.PI},P={},z=h.makeLabelFns(a,0).labelStandoff;P.xFn=function(t){var e=I(t);return Math.cos(e)*z},P.yFn=function(t){var e=I(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*l)},P.anchorFn=function(t){var e=I(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},P.heightFn=function(t,e,r){var n=I(t);return-.5*(1+Math.sin(n))*r};var O=function(t){return o(x[0]+g*Math.cos(t),x[1]-g*Math.sin(t))};u=function(t){return O(I(t))};if(c=h.calcTicks(a),f=h.getTickSigns(a)[2],a.visible){f=\"inside\"===a.ticks?-1:1;var D=(a.linewidth||1)/2;h.drawTicks(t,a,{vals:c,layer:k,path:\"M\"+f*D+\",0h\"+f*a.ticklen,transFn:function(t){var e=I(t);return O(e)+\"rotate(\"+-s(e)+\")\"}}),h.drawLabels(t,a,{vals:c,layer:k,transFn:u,labelFns:P})}var R=[v].concat(p.gauge.steps),F=T.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(_),F.exit().remove();var B=C(p.gauge.bar.thickness),N=T.selectAll(\"g.value-arc\").data([p.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");b(M)?(j.transition().duration(M.duration).ease(M.easing).each(\"end\",(function(){A&&A()})).each(\"interrupt\",(function(){A&&A()})).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),p._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(_),N.exit().remove(),R=[];var H=p.gauge.threshold.value;H&&R.push({range:[H,H],color:p.gauge.threshold.color,line:{color:p.gauge.threshold.line.color,width:p.gauge.threshold.line.width},thickness:p.gauge.threshold.thickness});var G=T.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(_),G.exit().remove();var Y=T.selectAll(\"g.gauge-outline\").data([y]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(_),Y.exit().remove()}(t,0,e,{radius:N,innerRadius:j,gauge:H,layer:G,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var Y=I.selectAll(\"g.bullet\").data(O?e:[]);Y.exit().remove();var W=I.selectAll(\"g.bulletaxis\").data(O?e:[]);W.exit().remove(),O&&function(t,e,r,n){var i,a,s,l,c,f=r[0].trace,p=n.gauge,d=n.layer,g=n.gaugeBg,v=n.gaugeOutline,y=n.size,x=f.domain,T=n.transitionOpts,k=n.onComplete;p.enter().append(\"g\").classed(\"bullet\",!0),p.attr(\"transform\",o(y.l,y.t)),d.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),d.selectAll(\"g.xbulletaxistick,path,text\").remove();var M=y.h,A=f.gauge.bar.thickness*M,S=x.x[0],E=x.x[0]+(x.x[1]-x.x[0])*(f._hasNumber||f._hasDelta?1-u.bulletNumberDomainSize:1);(i=w(t,f.gauge.axis))._id=\"xbulletaxis\",i.domain=[S,E],i.setScale(),a=h.calcTicks(i),s=h.makeTransTickFn(i),l=h.getTickSigns(i)[2],c=y.t+y.h,i.visible&&(h.drawTicks(t,i,{vals:\"inside\"===i.ticks?h.clipEnds(i,a):a,layer:d,path:h.makeTickPath(i,c,l),transFn:s}),h.drawLabels(t,i,{vals:a,layer:d,transFn:s,labelFns:h.makeLabelFns(i,c)}));function C(t){t.attr(\"width\",(function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))})).attr(\"x\",(function(t){return i.c2p(t.range[0])})).attr(\"y\",(function(t){return.5*(1-t.thickness)*M})).attr(\"height\",(function(t){return t.thickness*M}))}var L=[g].concat(f.gauge.steps),I=p.selectAll(\"g.bg-bullet\").data(L);I.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),I.select(\"rect\").call(C).call(_),I.exit().remove();var P=p.selectAll(\"g.value-bullet\").data([f.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(M-A)/2).call(_),b(T)?P.select(\"rect\").transition().duration(T.duration).ease(T.easing).each(\"end\",(function(){k&&k()})).each(\"interrupt\",(function(){k&&k()})).attr(\"width\",Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var z=r.filter((function(){return f.gauge.threshold.value})),O=p.selectAll(\"g.threshold-bullet\").data(z);O.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),O.select(\"line\").attr(\"x1\",i.c2p(f.gauge.threshold.value)).attr(\"x2\",i.c2p(f.gauge.threshold.value)).attr(\"y1\",(1-f.gauge.threshold.thickness)/2*M).attr(\"y2\",(1-(1-f.gauge.threshold.thickness)/2)*M).call(m.stroke,f.gauge.threshold.line.color).style(\"stroke-width\",f.gauge.threshold.line.width),O.exit().remove();var D=p.selectAll(\"g.gauge-outline\").data([v]);D.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),D.select(\"rect\").call(C).call(_),D.exit().remove()}(t,0,e,{gauge:Y,layer:W,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var X=I.selectAll(\"text.title\").data(e);X.exit().remove(),X.enter().append(\"text\").classed(\"title\",!0),X.attr(\"text-anchor\",(function(){return O?v.right:v[L.title.align]})).text(L.title.text).call(c.font,L.title.font).call(f.convertToTspans,t),X.attr(\"transform\",(function(){var t,e=R.l+R.w*y[L.title.align],r=u.titlePadding,n=c.bBox(X.node());if(P){if(z)if(L.gauge.axis.visible)t=c.bBox(G.node()).top-r-n.bottom;else t=R.t+R.h/2-N/2-n.bottom-r;O&&(t=A-(n.top+n.bottom)/2,e=R.l-u.bulletPadding*R.w)}else t=L._numbersTop-r-n.bottom;return o(e,t)}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"./constants\":1119,d3:169}],1123:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i(),showlegend:s({},o.showlegend,{dflt:!1})},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../streamtube/calc\").processGrid,a=t(\"../streamtube/calc\").filter;e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=a(e.x,e._len),e._y=a(e.y,e._len),e._z=a(e.z,e._len),e._value=a(e.value,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651,\"../streamtube/calc\":1295}],1125:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=h(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[c.min,c.max],l.colormap=i(t),this.mesh.update(l)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var f=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"];function h(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,i,a,o,s,c=t.surface.show,u=t.spaceframe.show,h=t.surface.fill,p=t.spaceframe.fill,d=!1,g=!1,m=0,v=t._Xs,y=t._Ys,x=t._Zs,b=v.length,_=y.length,w=x.length,T=f.indexOf(t._gridFill.replace(/-/g,\"\").replace(/\\+/g,\"\")),k=function(t,e,r){switch(T){case 5:return r+w*e+w*_*t;case 4:return r+w*t+w*b*e;case 3:return e+_*r+_*w*t;case 2:return e+_*t+_*b*r;case 1:return t+b*r+b*w*e;default:return t+b*e+b*_*r}},M=t._minValues,A=t._maxValues,S=t._vMin,E=t._vMax;function C(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===i[c]&&s===a[c])return c;return-1}function L(){r=e}function I(){n=[],i=[],a=[],o=[],e=0,L()}function P(t,r,s,l){return n.push(t),i.push(r),a.push(s),o.push(l),++e-1}function z(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function O(t){s=t}function D(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){L();var i,a,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-s),l=z(a,r,o),c=z(a,n,o),u=z(a,i,o),f=e[0],h=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,i,u],[u,c,n],[i,r,l],[l,u,i]],abc:[[f,h,-1],[-1,-1,f],[h,p,-1],[-1,-1,h],[p,f,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var f=0;f<l.length;f++){r=l[f],n=c[f];for(var h=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],y=r[p][3],x=n[p]>-1?n[p]:C(d,g,v);h[p]=x>-1?x:P(d,g,v,R(e,y))}i=h[0],a=h[1],o=h[2],t._meshI.push(i),t._meshJ.push(a),t._meshK.push(o),++m}}function B(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function U(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t._x[i],t._y[i],t._z[i],t._value[i]])}return r}function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,i),N(e[1][3],n,i),N(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):a<3&&V(t,e,r,S,E,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach((function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(h,u,n,i),d=B(h,f,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,f,d],[r[a[0]],r[a[1]],-1])||o,c=!0}})),c||[[0,1,2],[1,2,0],[2,0,1]].forEach((function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(f,u,n,i),d=B(h,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}})),o}function q(t,e,r,n){var i=!1,a=U(e),o=[N(a[0][3],r,n),N(a[1][3],r,n),N(a[2][3],r,n),N(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return g&&(i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]];if(g)i=F(t,[c,u,f],[e[l[0]],e[l[1]],e[l[2]]])||i;else{var p=B(h,c,r,n),d=B(h,u,r,n),m=B(h,f,r,n);i=F(null,[p,d,m],[-1,-1,-1])||i}s=!0}})),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(f,c,r,n),d=B(f,u,r,n),m=B(h,u,r,n),v=B(h,c,r,n);g?(i=F(t,[c,v,p],[e[l[0]],-1,-1])||i,i=F(t,[u,d,m],[e[l[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[p,d,m,v],[-1,-1,-1,-1])||i,s=!0}})),s||[[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach((function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(u,c,r,n),d=B(f,c,r,n),m=B(h,c,r,n);g?(i=F(t,[c,p,d],[e[l[0]],-1,-1])||i,i=F(t,[c,d,m],[e[l[0]],-1,-1])||i,i=F(t,[c,m,p],[e[l[0]],-1,-1])||i):i=F(null,[p,d,m],[-1,-1,-1])||i,s=!0}})),i)}function H(t,e,r,n,i,a,o,s,l,c,u){var f=!1;return d&&(D(t,\"A\")&&(f=q(null,[e,r,n,a],c,u)||f),D(t,\"B\")&&(f=q(null,[r,n,i,l],c,u)||f),D(t,\"C\")&&(f=q(null,[r,a,o,l],c,u)||f),D(t,\"D\")&&(f=q(null,[n,a,s,l],c,u)||f),D(t,\"E\")&&(f=q(null,[r,n,a,l],c,u)||f)),g&&(f=q(t,[r,n,a,l],c,u)||f),f}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,U([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,U([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,f=!1,h=function(){f=V(t,[s,l,c],[-1,-1,-1],i,a)||f,f=V(t,[c,u,s],[-1,-1,-1],i,a)||f},p=o[0],d=o[1],g=o[2];return p&&(s=z(U([k(e,r-0,n-0)])[0],U([k(e-1,r-0,n-0)])[0],p),l=z(U([k(e,r-0,n-1)])[0],U([k(e-1,r-0,n-1)])[0],p),c=z(U([k(e,r-1,n-1)])[0],U([k(e-1,r-1,n-1)])[0],p),u=z(U([k(e,r-1,n-0)])[0],U([k(e-1,r-1,n-0)])[0],p),h()),d&&(s=z(U([k(e-0,r,n-0)])[0],U([k(e-0,r-1,n-0)])[0],d),l=z(U([k(e-0,r,n-1)])[0],U([k(e-0,r-1,n-1)])[0],d),c=z(U([k(e-1,r,n-1)])[0],U([k(e-1,r-1,n-1)])[0],d),u=z(U([k(e-1,r,n-0)])[0],U([k(e-1,r-1,n-0)])[0],d),h()),g&&(s=z(U([k(e-0,r-0,n)])[0],U([k(e-0,r-0,n-1)])[0],g),l=z(U([k(e-0,r-1,n)])[0],U([k(e-0,r-1,n-1)])[0],g),c=z(U([k(e-1,r-1,n)])[0],U([k(e-1,r-1,n-1)])[0],g),u=z(U([k(e-1,r-0,n)])[0],U([k(e-1,r-0,n-1)])[0],g),h()),f}function X(t,e,r,n,i,a,o,s,l,c,u,f){var h=t;return f?(d&&\"even\"===t&&(h=null),H(h,e,r,n,i,a,o,s,l,c,u)):(d&&\"odd\"===t&&(h=null),H(h,l,s,o,a,i,n,r,e,c,u))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<_;u++)a.push(Y(t,k(l,u-1,c-1),k(l,u-1,c),k(l,u,c-1),k(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<w;u++)a.push(Y(t,k(c-1,l,u-1),k(c,l,u-1),k(c-1,l,u),k(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<b;u++)a.push(Y(t,k(u-1,c-1,l),k(u-1,c,l),k(u,c-1,l),k(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function Q(t,e,r){for(var n=1;n<w;n++)for(var i=1;i<_;i++)for(var a=1;a<b;a++)X(t,k(a-1,i-1,n-1),k(a-1,i-1,n),k(a-1,i,n-1),k(a-1,i,n),k(a,i-1,n-1),k(a,i-1,n),k(a,i,n-1),k(a,i,n),e,r,(a+i+n)%2)}function $(t,e,r){d=!0,Q(t,e,r),d=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var f=1;f<_;f++)o.push(W(t,c,f,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var f=1;f<w;f++)o.push(W(t,u,c,f,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var f=1;f<b;f++)o.push(W(t,f,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(I(),function(){for(var e=0;e<b;e++)for(var r=0;r<_;r++)for(var n=0;n<w;n++){var i=k(e,r,n);P(t._x[i],t._y[i],t._z[i],t._value[i])}}(),u&&p&&(O(p),g=!0,Q(null,S,E),g=!1),c&&h){O(h);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var f=1===r?.5:s/(r-1),d=(1-f)*S+f*E,T=Math.abs(d-M)>Math.abs(d-A)?[M,d]:[d,A];$(e,T[0],T[1])}}var C=[[Math.min(S,A),Math.max(S,A)],[Math.min(M,E),Math.max(M,E)]];[\"x\",\"y\",\"z\"].forEach((function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){O(s.fill);var c=[],u=[],f=[];if(s.locations.length)for(var h=0;h<s.locations.length;h++){var p=l(s.locations[h],\"x\"===e?v:\"y\"===e?y:x);0===p.distRatio?c.push(p.id):p.id>0&&(u.push(p.id),\"x\"===e?f.push([p.distRatio,0,0]):\"y\"===e?f.push([0,p.distRatio,0]):f.push([0,0,p.distRatio]))}else c=nt(1,\"x\"===e?b-1:\"y\"===e?_-1:w-1);u.length>0&&(r[i]=\"x\"===e?tt(null,u,a,o,f,r[i]):\"y\"===e?et(null,u,a,o,f,r[i]):rt(null,u,a,o,f,r[i]),i++),c.length>0&&(r[i]=\"x\"===e?Z(null,c,a,o,r[i]):\"y\"===e?J(null,c,a,o,r[i]):K(null,c,a,o,r[i]),i++)}var d=t.caps[e];d.show&&d.fill&&(O(d.fill),r[i]=\"x\"===e?Z(null,[0,b-1],a,o,r[i]):\"y\"===e?J(null,[0,_-1],a,o,r[i]):K(null,[0,w-1],a,o,r[i]),i++)}})),0===m&&I(),t._meshX=n,t._meshY=i,t._meshZ=a,t._meshIntensity=o,t._Xs=v,t._Ys=y,t._Zs=x}(),t}e.exports={findNearestOnAxis:l,generateIsoMeshes:h,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new c(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"gl-mesh3d\":309}],1126:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),f=a(\"z\"),h=a(\"value\");c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach((function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))})),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach((function(t){a(t)})),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,r,i,(function(r,i){return n.coerce(t,e,a,r,i)}))},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1123}],1127:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1123,\"./calc\":1124,\"./convert\":1125,\"./defaults\":1126}],1128:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},intensitymode:{valType:\"enumerated\",values:[\"vertex\",\"cell\"],dflt:\"vertex\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"}),showlegend:s({},o.showlegend,{dflt:!1})})},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../surface/attributes\":1311}],1129:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1130:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function f(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var h=f.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function m(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}h.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,f=t.x.length,h=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!m(t.i,f)||!m(t.j,f)||!m(t.k,f))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(h):t.alphahull>0?a(t.alphahull,h):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,h);var v={positions:h,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\";var x=t.intensitymode;v[x+\"Intensity\"]=t.intensity,v[x+\"IntensityBounds\"]=[y.min,y.max],v.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],v.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],v.cellColors=p(t.facecolor)):(this.color=t.color,v.meshColor=l(t.color));this.mesh.update(v)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new f(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"alpha-shape\":69,\"convex-hull\":135,\"delaunay-triangulate\":171,\"gl-mesh3d\":309}],1131:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map((function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null}));return e.every((function(t){return t&&t.length===e[0].length}))&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach((function(t){l(t)})),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),\"intensity\"in t?(l(\"intensity\"),l(\"intensitymode\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1128}],1132:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1128,\"./calc\":1129,\"./convert\":1130,\"./defaults\":1131}],1133:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function f(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:f(l),decreasing:f(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":664,\"../../components/fx/attributes\":674,\"../../constants/delta.js\":747,\"../../lib\":778,\"../scatter/attributes\":1187}],1134:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r,n){return{o:t,h:e,l:r,c:n}}function c(t,e,r,o,l,c){for(var u=l.makeCalcdata(e,\"open\"),f=l.makeCalcdata(e,\"high\"),h=l.makeCalcdata(e,\"low\"),p=l.makeCalcdata(e,\"close\"),d=Array.isArray(e.text),g=Array.isArray(e.hovertext),m=!0,v=null,y=!!e.xperiodalignment,x=[],b=0;b<o.length;b++){var _=o[b],w=u[b],T=f[b],k=h[b],M=p[b];if(_!==s&&w!==s&&T!==s&&k!==s&&M!==s){M===w?null!==v&&M!==v&&(m=M>v):m=M>w,v=M;var A=c(w,T,k,M);A.pos=_,A.yc=(w+M)/2,A.i=b,A.dir=m?\"increasing\":\"decreasing\",A.x=A.pos,A.y=[k,T],y&&(A.orig_p=r[b]),d&&(A.tx=e.text[b]),g&&(A.htx=e.hovertext[b]),x.push(A)}else x.push({pos:_,empty:!0})}return e._extremes[l._id]=a.findExtremes(l,n.concat(h,f),{padded:!0}),x.length&&(x[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),x}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),s=function(t,e,r){var i=r._minDiff;if(!i){var a,s=t._fullData,l=[];for(i=1/0,a=0;a<s.length;a++){var c=s[a];if(\"ohlc\"===c.type&&!0===c.visible&&c.xaxis===e._id){l.push(c);var u=e.makeCalcdata(c,\"x\");c._origX=u;var f=o(r,e,\"x\",u);c._xcalc=f;var h=n.distinctVals(f).minDiff;h&&isFinite(h)&&(i=Math.min(i,h))}}for(i===1/0&&(i=1),a=0;a<l.length;a++)l[a]._minDiff=i}return i*r.tickwidth}(t,r,e),u=e._minDiff;e._minDiff=null;var f=e._origX;e._origX=null;var h=e._xcalc;e._xcalc=null;var p=c(t,e,f,h,i,l);return e._extremes[r._id]=a.findExtremes(r,h,{vpad:u/2}),p.length?(n.extendFlat(p[0].t,{wHover:u/2,tickLen:s}),p):[{t:{empty:!0}}]},calcCommon:c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}i(t,e,c,l)?(a(t,e,l,c,{x:!0}),c(\"line.width\"),c(\"line.dash\"),s(t,e,c,\"increasing\"),s(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"tickwidth\"),l._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1133,\"./ohlc_defaults\":1138}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,f=l[0].t,h=u.type,p=\"ohlc\"===h?\"l\":\"min\",d=\"ohlc\"===h?\"h\":\"max\",g=f.bPos||0,m=f.bdPos||f.tickLen,v=f.wHover,y=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function x(t){var r=function(t){return t.pos+g-e}(t);return a.inbox(r-v,r+v,i)}function b(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function _(t){return(x(t)+b(t))/2}i=t.maxHoverDistance-y,s=t.maxSpikeDistance-y;var w=a.getDistanceFunction(n,x,b,_);if(a.getClosest(l,w,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var k=u[T.dir],M=k.line.color;return o.opacity(M)&&k.line.width?t.color=M:t.color=k.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=void 0!==T.orig_p?T.orig_p:T.pos,t.spikeDistance=_(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function f(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,f=[],h=u(t,e,r,a);if(!h)return[];var p=o[h.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],m={},v=0;v<g.length;v++){var y,x=g[v],b=l[x][h.index],_=s.c2p(b,!0);b in m?(y=m[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},h)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",f.push(y),m[b]=y)}return f}function h(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,f=a[0].t,h=u(t,e,r,i);if(!h)return[];var p=a[h.index],d=h.index=p.i,g=p.dir;function m(t){return f.labels[t]+n.hoverLabelText(o,l[t][d])}var v=p.hi||l.hoverinfo,y=v.split(\"+\"),x=\"all\"===v,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[m(\"open\"),m(\"high\"),m(\"low\"),m(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),h.extraText=w.join(\"<br>\"),h.y0=h.y1=o.c2p(p.yc,!0),[h]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?f(t,e,r,n):h(t,e,r,n)},hoverSplit:f,hoverOnPoints:h}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/delta.js\":747,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1137:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":841,\"./attributes\":1133,\"./calc\":1134,\"./defaults\":1135,\"./hover\":1136,\"./plot\":1139,\"./select\":1140,\"./style\":1141}],1138:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var f=Math.min(s.length,l.length,c.length,u.length);return o&&(f=Math.min(f,i.minRowLength(o))),e._length=f,f}}},{\"../../lib\":778,\"../../registry\":911}],1139:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.yaxis,s=e.xaxis,l=!!s.rangebreaks;i.makeTraceGroups(a,r,\"trace ohlc\").each((function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var c=a.tickLen,u=e.selectAll(\"path\").data(i.identity);u.enter().append(\"path\"),u.exit().remove(),u.attr(\"d\",(function(t){if(t.empty)return\"M0,0Z\";var e=s.c2p(t.pos-c,!0),r=s.c2p(t.pos+c,!0),n=l?(e+r)/2:s.c2p(t.pos,!0);return\"M\"+e+\",\"+o.c2p(t.o,!0)+\"H\"+n+\"M\"+n+\",\"+o.c2p(t.h,!0)+\"V\"+o.c2p(t.l,!0)+\"M\"+r+\",\"+o.c2p(t.c,!0)+\"H\"+n}))}}))}},{\"../../lib\":778,d3:169}],1140:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1141:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each((function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1143:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1148}],1144:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=t(\"fast-isnumeric\");function u(t,e,r){t.valueInds.push(e),t.count+=r}function f(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function h(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var p,d,g,m=r.map((function(t){var e;if(\"trace\"===t.categoryorder)e=null;else if(\"array\"===t.categoryorder)e=t.categoryarray;else{e=o(t.values);for(var r=!0,n=0;n<e.length;n++)if(!c(e[n])){r=!1;break}e.sort(r?l.sorterAsc:void 0),\"category descending\"===t.categoryorder&&(e=e.reverse())}return function(t,e){e=null==e?[]:e.map((function(t){return t}));var r={},n={},i=[];e.forEach((function(t,e){r[t]=0,n[t]=e}));for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map((function(t){return r[t]}));return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)}));p=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map((function(t){return t.displayindex}))))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach((function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,m[e])}));var v,y=e.line;y?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),v=s.tryColorscale(y)):v=l.identity;var x,b,_,w,T,k=r[0].values.length,M={},A=m.map((function(t){return t.inds}));for(g=0,x=0;x<k;x++){var S=[];for(b=0;b<A.length;b++)S.push(A[b][x]);d=p[x%p.length],g+=d;var E=(_=x,w=void 0,T=void 0,l.isArrayOrTypedArray(y.color)?T=w=y.color[_%y.color.length]:w=y.color,{color:v(w),rawColor:T}),C=S+\"-\"+E.rawColor;void 0===M[C]&&(M[C]=f(S,E.color,E.rawColor)),h(M[C],x,d)}var L,I=r.map((function(t,e){return function(t,e,r,n,i){return{dimensionInd:t,containerInd:e,displayInd:r,dimensionLabel:n,count:i,categories:[],dragX:null}}(e,t._index,t._displayindex,t.label,g)}));for(x=0;x<k;x++)for(d=p[x%p.length],b=0;b<I.length;b++){var P=I[b].containerInd,z=m[b].inds[x],O=I[b].categories;if(void 0===O[z]){var D=e.dimensions[P]._categoryarray[z],R=e.dimensions[P]._ticktext[z];O[z]={dimensionInd:b,categoryInd:L=z,categoryValue:D,displayInd:L,categoryLabel:R,valueInds:[],count:0,dragY:null}}u(O[z],x,d)}return n(function(t,e,r){var n=t.map((function(t){return t.categories.length})).reduce((function(t,e){return Math.max(t,e)}));return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(I,M,g))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/filter_unique.js\":769,\"../../lib/gup\":775,\"fast-isnumeric\":241}],1145:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,f,h);o(e,f,h),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),h(\"hoveron\"),h(\"hovertemplate\"),h(\"arrangement\"),h(\"bundlecolors\"),h(\"sortpaths\"),h(\"counts\");var g={family:f.font.family,size:Math.round(f.font.size),color:f.font.color};n.coerceFont(h,\"labelfont\",g);var m={family:f.font.family,size:Math.round(f.font.size/1.2),color:f.font.color};n.coerceFont(h,\"tickfont\",m)}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"../parcoords/merge_length\":1158,\"./attributes\":1142}],1146:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1142,\"./base_plot\":1143,\"./calc\":1144,\"./defaults\":1145,\"./plot\":1148}],1147:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../components/drawing\"),c=t(\"tinycolor2\"),u=t(\"../../lib/svg_text_utils\");function f(t,e,r,i){var a=t.map(R.bind(0,e,r)),c=i.selectAll(\"g.parcatslayer\").data([null]);c.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var f=c.selectAll(\"g.trace.parcats\").data(a,h),v=f.enter().append(\"g\").attr(\"class\",\"trace parcats\");f.attr(\"transform\",(function(t){return s(t.x,t.y)})),v.append(\"g\").attr(\"class\",\"paths\");var y=f.select(\"g.paths\").selectAll(\"path.path\").data((function(t){return t.paths}),h);y.attr(\"fill\",(function(t){return t.model.color}));var _=y.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",0);b(_),y.attr(\"d\",(function(t){return t.svgD})),_.empty()||y.sort(d),y.exit().remove(),y.on(\"mouseover\",g).on(\"mouseout\",m).on(\"click\",x),v.append(\"g\").attr(\"class\",\"dimensions\");var k=f.select(\"g.dimensions\").selectAll(\"g.dimension\").data((function(t){return t.dimensions}),h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",(function(t){return s(t.x,0)})),k.exit().remove();var M=k.selectAll(\"g.category\").data((function(t){return t.categories}),h),A=M.enter().append(\"g\").attr(\"class\",\"category\");M.attr(\"transform\",(function(t){return s(0,t.y)})),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),M.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),w(A);var S=M.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h);S.each((function(){o.raiseToTop(this)})),S.attr(\"fill\",(function(t){return t.color}));var z=S.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);S.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})).attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"})),T(z),S.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var O=e._fullLayout.paper_bgcolor;M.select(\"text.catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",O+\" -1px  1px 2px, \"+O+\" 1px  1px 2px, \"+O+\"  1px -1px 2px, \"+O+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",(function(t){return p(t)?t.width+5:-5})).attr(\"y\",(function(t){return t.height/2})).text((function(t){return t.model.categoryLabel})).each((function(t){l.font(n.select(this),t.parcatsViewModel.categorylabelfont),u.convertToTspans(n.select(this),e)})),A.append(\"text\").attr(\"class\",\"dimlabel\"),M.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"})).attr(\"x\",(function(t){return t.width/2})).attr(\"y\",-5).text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})).each((function(t){l.font(n.select(this),t.parcatsViewModel.labelfont)})),M.selectAll(\"rect.bandrect\").on(\"mouseover\",E).on(\"mouseout\",C),M.exit().remove(),k.call(n.behavior.drag().origin((function(t){return{x:t.x,y:0}})).on(\"dragstart\",L).on(\"drag\",I).on(\"dragend\",P)),f.each((function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")})),f.exit().remove()}function h(t){return t.key}function p(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function d(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function g(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),_(n.select(this));var e=v(t),r=y(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var i,s,l,u=n.mouse(this)[0],f=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,p=f._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),g=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(l=0;l<t.leftXs.length-1;l++)if(t.leftXs[l]+t.dimWidths[l]-2<=u&&u<=t.leftXs[l+1]+2){var m=t.parcatsViewModel.dimensions[l],x=t.parcatsViewModel.dimensions[l+1];i=(m.x+m.width+x.x)/2,s=(t.topYs[l]+t.topYs[l+1]+t.height)/2;break}var b=t.parcatsViewModel.x+i,w=t.parcatsViewModel.y+s,T=c.mostReadable(t.model.color,[\"black\",\"white\"]),k=t.model.count,M=k/t.parcatsViewModel.model.count,A={countLabel:k,probabilityLabel:M.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&S.push([\"Count:\",A.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&S.push([\"P:\",A.probabilityLabel].join(\" \"));var E=S.join(\"<br>\"),C=n.mouse(f)[0];a.loneHover({trace:h,x:b-d.left+g.left,y:w-d.top+g.top,text:E,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:T,idealAlign:C<b?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:A,eventData:[{data:h._input,fullData:h,count:k,probability:M}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:f})}}}function m(t){if(!t.parcatsViewModel.dragDimension&&(b(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(d),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=z(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function y(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var i=r[n],a=i.categories[t.model.categoryInds[n]];e[i.containerInd]=a.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function x(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event,constraints:r})}}function b(t){t.attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",(function(t){return c.mostReadable(t.model.color,[\"black\",\"white\"])})).attr(\"stroke-width\",.3)}function w(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function T(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function k(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter((function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color}))}function M(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll(\"rect.bandrect\"),l=[];s.each((function(t){k(t).each((function(t){Array.prototype.push.apply(l,v(t))}))}));var c={};c[a.dimensionInd]=a.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function A(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=k(i),l=[];s.each((function(t){Array.prototype.push.apply(l,v(t))}));var c={};c[a.dimensionInd]=a.categoryValue,void 0!==i.rawColor&&(c.color=i.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function S(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=n.select(r.parentNode).select(\"rect.catrect\"),c=l.node().getBoundingClientRect(),u=l.datum(),f=u.parcatsViewModel,h=f.model.dimensions[u.model.dimensionInd],p=f.trace,d=c.top+c.height/2;f.dimensions.length>1&&h.displayInd===f.dimensions.length-1?(i=c.left,a=\"left\"):(i=c.left+c.width,a=\"right\");var g=u.model.count,m=u.model.categoryLabel,v=g/u.parcatsViewModel.model.count,y={countLabel:g,categoryLabel:m,probabilityLabel:v.toFixed(3)},x=[];-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&x.push([\"Count:\",y.countLabel].join(\" \")),-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&x.push([\"P(\"+y.categoryLabel+\"):\",y.probabilityLabel].join(\" \"));var b=x.join(\"<br>\");return{trace:p,x:o*(i-e.left),y:s*(d-e.top),text:b,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:a,hovertemplate:p.hovertemplate,hovertemplateLabels:y,eventData:[{data:p._input,fullData:p,count:g,category:m,probability:v}]}}function E(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),l=t.parcatsViewModel.hoveron;if(\"color\"===l?(!function(t){var e=n.select(t).datum(),r=k(e);_(r),r.each((function(){o.raiseToTop(this)})),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter((function(t){return t.color===e.color})).each((function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)}))}(this),A(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each((function(t){var e=k(t);_(e),e.each((function(){o.raiseToTop(this)}))})),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),M(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===l?e=S(r,s,this):\"color\"===l?e=function(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=r.getBoundingClientRect(),u=n.select(r).datum(),f=u.categoryViewModel,h=f.parcatsViewModel,p=h.model.dimensions[f.model.dimensionInd],d=h.trace,g=l.y+l.height/2;h.dimensions.length>1&&p.displayInd===h.dimensions.length-1?(i=l.left,a=\"left\"):(i=l.left+l.width,a=\"right\");var m=f.model.categoryLabel,v=u.parcatsViewModel.model.count,y=0;u.categoryViewModel.bands.forEach((function(t){t.color===u.color&&(y+=t.count)}));var x=f.model.count,b=0;h.pathSelection.each((function(t){t.model.color===u.color&&(b+=t.model.count)}));var _=y/v,w=y/b,T=y/x,k={countLabel:v,categoryLabel:m,probabilityLabel:_.toFixed(3)},M=[];-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&M.push([\"Count:\",k.countLabel].join(\" \")),-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(M.push(\"P(color \\u2229 \"+m+\"): \"+k.probabilityLabel),M.push(\"P(\"+m+\" | color): \"+w.toFixed(3)),M.push(\"P(color | \"+m+\"): \"+T.toFixed(3)));var A=M.join(\"<br>\"),S=c.mostReadable(u.color,[\"black\",\"white\"]);return{trace:d,x:o*(i-e.left),y:s*(g-e.top),text:A,color:u.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:S,fontSize:10,idealAlign:a,hovertemplate:d.hovertemplate,hovertemplateLabels:k,eventData:[{data:d._input,fullData:d,category:m,count:v,probability:_,categorycount:x,colorcount:b,bandcolorcount:y}]}}(r,s,this):\"dimension\"===l&&(e=function(t,e,r){var i=[];return n.select(r.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each((function(){i.push(S(t,e,this))})),i}(r,s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function C(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(b(e.pathSelection),w(e.dimensionSelection.selectAll(\"g.category\")),T(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(d),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?A(this,\"plotly_unhover\",n.event):M(this,\"plotly_unhover\",n.event)}}function L(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each((function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map((function(t){return t.displayInd})),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each((function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)})))})),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function I(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],f=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==f&&s+o.height>f.y+f.height/2&&(o.model.displayInd=f.model.displayInd,f.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var h=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==h&&a.model.dragX<h.x+h.width&&(a.model.displayInd=h.model.displayInd,h.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}N(t.parcatsViewModel),B(t.parcatsViewModel),D(t.parcatsViewModel),O(t.parcatsViewModel)}}function P(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=z(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),o=t.initialDragDimensionDisplayInds.some((function(t,e){return t!==a[e]}));o&&a.forEach((function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r}));var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map((function(t){return t.displayInd}));if(s=t.initialDragCategoryDisplayInds.some((function(t,e){return t!==l[e]}))){var c=t.model.categories.slice().sort((function(t,e){return t.displayInd-e.displayInd})),u=c.map((function(t){return t.categoryValue})),f=c.map((function(t){return t.categoryLabel}));e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[f],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?A(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,N(t.parcatsViewModel),B(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each((function(){D(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)})).each(\"end\",(function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])}))}}function z(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data((function(t){return t.paths}),h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",(function(t){return t.svgD}))}function D(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data((function(t){return t.dimensions}),h);var i=t.dimensionSelection.selectAll(\"g.category\").data((function(t){return t.categories}),h);r(t.dimensionSelection).attr(\"transform\",(function(t){return s(t.x,0)})),r(i).attr(\"transform\",(function(t){return s(0,t.y)})),i.select(\".dimlabel\").text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})),i.select(\".catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"x\",(function(t){return p(t)?t.width+5:-5})).each((function(t){var e,r;p(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)}));var a=i.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h),l=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);a.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})),T(l),a.each((function(){o.raiseToTop(this)})),a.exit().remove()}function R(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),f=Math.floor(c*(s.y[1]-s.y[0])),h=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:h,y:p,width:u,height:f,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};return i.dimensions&&(N(g),B(g)),g}function F(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function B(t){var e=t.dimensions,r=t.model,n=e.map((function(t){return t.categories.map((function(t){return t.y}))})),i=t.model.dimensions.map((function(t){return t.categories.map((function(t){return t.displayInd}))})),a=t.model.dimensions.map((function(t){return t.displayInd})),o=t.dimensions.map((function(t){return t.model.dimensionInd})),s=e.map((function(t){return t.x})),l=e.map((function(t){return t.width})),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function f(t){var e=t.categoryInds.map((function(t,e){return i[e][t]}));return o.map((function(t){return e[t]}))}c.sort((function(e,r){var n=f(e),i=f(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0}));for(var h=new Array(c.length),p=e[0].model.count,d=e[0].categories.map((function(t){return t.height})).reduce((function(t,e){return t+e})),g=0;g<c.length;g++){var m,v=c[g];m=p>0?d*(v.count/p):0;for(var y,x=new Array(n.length),b=0;b<v.categoryInds.length;b++){var _=v.categoryInds[b],w=i[b][_],T=a[b];x[T]=n[T][w],n[T][w]+=m;var k=t.dimensions[T].categories[w],M=k.bands.length,A=k.bands[M-1];if(void 0===A||v.rawColor!==A.rawColor){var S=void 0===A?0:A.y+A.height;k.bands.push({key:S,color:v.color,rawColor:v.rawColor,height:m,width:k.width,count:v.count,y:S,categoryViewModel:k,parcatsViewModel:t})}else{var E=k.bands[M-1];E.height+=m,E.count+=v.count}}y=\"hspline\"===t.pathShape?F(s,x,l,m,.5):F(s,x,l,m,0),h[g]={key:v.valueInds[0],model:v,height:m,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=h}function N(t){var e=t.model.dimensions.map((function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}}));e.sort((function(t,e){return t.displayInd-e.displayInd}));var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(j(t,a))}t.dimensions=r}function j(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],f=t.model.maxCats,h=e.categories.length,p=e.count,d=t.height-8*(f-1),g=8*(f-h)/2,m=e.categories.map((function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}}));for(m.sort((function(t,e){return t.displayInd-e.displayInd})),c=0;c<h;c++)l=m[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){f(r,t,n,e)}},{\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_api\":814,d3:169,tinycolor2:576}],1148:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1147}],1149:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1150:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=t(\"../../lib\").strTranslate,c=n.bar.snapRatio;function u(t,e){return t*(1-c)+e*c}var f=n.bar.snapClose;function h(t,e){return t*(1-f)+e*f}function p(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],c=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return u(l,c);if(i*r<i*d||p===o)return u(d,l);c=l,l=d}}function d(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function g(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function m(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map((function(t){return t.map((function(t){return Math.max(0,t*e)})).sort(s)}))}function y(){i.select(document.body).style(\"cursor\",null)}function x(t){t.attr(\"stroke-dasharray\",m)}function b(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");x(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function _(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,f=NaN,h=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(f=r?r-1:NaN,p&&p[0]>e){h=r;break}}if(a=u,isNaN(a)&&(a=isNaN(f)||isNaN(h)?isNaN(f)?h:f:e-c[f][1]<c[h][0]-e?f:h),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function w(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),b(t.parentNode)}function T(t,e){var r=_(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",(function(t){i.event.preventDefault(),t.parent.inBrushDrag||T(this,t)})).on(\"mouseleave\",(function(t){t.parent.inBrushDrag||y()})).call(i.behavior.drag().on(\"dragstart\",(function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=_(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter((function(t){return t[0]!==l[0]&&t[1]!==l[1]}))),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)})).on(\"drag\",(function(t){w(this,t)})).on(\"dragend\",(function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(T(t,e),w(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,y(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),b(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[p(0,l,a.newExtent[0],a.stayingIntervals),p(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?b(t.parentNode,s):(s(),b(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)})))}function M(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function S(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return 1===n.length&&n[0][0]>n[0][1]&&(n=[]),n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map((function(t){return t.slice().sort(s)})).sort(M)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=S(r),e=r.reduce((function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]}),[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map((function(t){return t.slice()}))}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(d).call(g).style(\"pointer-events\",\"auto\").attr(\"transform\",l(0,n.verticalPadding)),e.call(k).attr(\"height\",(function(t){return t.height-n.verticalPadding}));var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",(function(t){return t.height})).call(x);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",(function(t){return t.height})).call(x)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map((function(t){return t.sort(s)})),t=e.multiselect?S(t.sort(M)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map((function(t){var e=[p(0,r,t[0],[]),p(1,r,t[1],[])];if(e[1]>e[0])return e})).filter((function(t){return t}))).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":778,\"../../lib/gup\":775,\"./constants\":1153,d3:169}],1151:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})),window.setTimeout((function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")}),60)}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/get_data\":865,\"./plot\":1160,d3:169}],1152:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775}],1153:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1154:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),f=t(\"./constants\").maxDimensionCount,h=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var f=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:f},l.setConvert(e._ax,i.layout),a(\"multiselect\");var h=a(\"constraintrange\");h&&(e.constraintrange=u.cleanRanges(h,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>f&&(n.log(\"parcoords traces support up to \"+f+\" dimensions at the moment\"),d.splice(f));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),m=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),h(e,g,\"values\",m);var v={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",v),n.coerceFont(u,\"tickfont\",v),n.coerceFont(u,\"rangefont\",v),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../../plots/domain\":855,\"./attributes\":1149,\"./axisbrush\":1150,\"./constants\":1153,\"./merge_length\":1158}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":778}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1149,\"./base_plot\":1151,\"./calc\":1152,\"./defaults\":1154,\"./plot\":1160}],1157:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=new Uint8Array(4),c=new Uint8Array(4),u={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function f(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function h(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:l})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],f(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame((function(){s(l+1)}))),r.drawCompleted=!1)}(0)}function p(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function d(t,e){return(t>>>8*e)%256/255}function g(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function v(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function y(t,e,r,n,i,a,o,l,c,u,f,h,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var m=t.lines.canvasOverdrag,v=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:f,resolution:[y,x],viewBoxPos:[o+m,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:h,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+m)+(t.pad.l-m)+t.layoutWidth*v.x[0],scissorWidth:(n===r?y-o+m:c+.5)+(n===e?o+m:0),scissorY:l+t.pad.b+t.layoutHeight*v.y[0],scissorHeight:u,viewportX:t.pad.l-m+t.layoutWidth*v.x[0],viewportY:t.pad.b+t.layoutHeight*v.y[0],viewportWidth:y,viewportHeight:x},p)}function x(t){var e=Math.max(0,Math.floor(2047*t[0]),0),r=Math.min(2047,Math.ceil(2047*t[1]),2047);return[Math.min(e,r),Math.max(e,r)]}e.exports=function(t,e){var r,n,l,m,b,_=e.context,w=e.pick,T=e.regl,k={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[v(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),A=T.texture(u),S=[];C(e);var E=T({profile:!1,blend:{enable:_,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!_,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:A,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function C(t){r=t.model,n=t.viewModel,l=n.dimensions.slice(),m=l[0]?l[0].values.length:0;var e=r.lines,i=w?e.color.map((function(t,r){return r/e.color.length})):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var l=0;l<o;l++)i[a++]=l<e.length?e[l].paddedUnitValues[s]:.5;i[a++]=d(s,2),i[a++]=d(s,1),i[a++]=d(s,0),i[a++]=(n=r[s],Math.max(1e-6,Math.min(.999999,n)))}return i}(m,l,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[v(n)](g(n/4,e,r))}(M,m,a),_||w||(A=T.texture(s.extendFlat({data:p(r.unitToColor,255)},u)))}return{render:function(t,e,n){var i,a,o,s=t.length,c=1/0,u=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<c&&(c=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>u&&(u=t[i].dim1.canvasX,o=i);0===s&&f(T,0,0,r.canvasWidth,r.canvasHeight);var p=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<l.length?l[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=new Array(16384);for(e=0;e<16384;e++)o[e]=255;if(!t)for(e=0;e<l.length;e++){var s=e%8,c=(e-s)/8,u=Math.pow(2,s),f=l[e].brush.filter.get();if(!(f.length<2)){var h=x(f[0])[1];for(r=1;r<f.length;r++){var p=x(f[r]);for(n=h+1;n<p[0];n++)o[8*n+c]&=~u;h=Math.max(h,p[1])}}}var d={shape:[8,2048],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:o};return b?b(d):b=T.texture(d),{maskTexture:b,maskHeight:2048,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(_);for(i=0;i<s;i++){var d=t[i],g=d.dim0.crossfilterDimensionIndex,v=d.dim1.crossfilterDimensionIndex,M=d.canvasX,A=d.canvasY,C=M+d.panelSizeX;if(e||!S[g]||S[g][0]!==M||S[g][1]!==C){S[g]=[M,C];var L=y(r,a,o,i,g,v,M,A,d.panelSizeX,d.panelSizeY,d.dim0.crossfilterDimensionIndex,_?0:w?2:1,p);k.clearOnly=n;var I=e?r.lines.blockLineCount:m;h(T,E,k,I,m,L)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:c}),c},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",A.destroy(),b&&b.destroy(),M)M[e].destroy()},update:C}}},{\"../../lib\":778,\"./constants\":1153,glslify:439}],1158:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/drawing\"),f=t(\"../../components/colorscale\"),h=t(\"../../lib/gup\"),p=h.keyFun,d=h.repeat,g=h.unwrap,m=t(\"./helpers\"),v=t(\"./constants\"),y=t(\"./axisbrush\"),x=t(\"./lines\");function b(t,e,r){return o.aggNums(t,null,e,r)}function _(t,e){return T(b(Math.min,t,e),b(Math.max,t,e))}function w(t){var e=t.range;return e?T(e[0],e[1]):_(t.values,t._length)}function T(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function k(t,e,r,i,a){var o,s,l=w(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map((function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)}))):n.scale.linear().domain(l).range([t-e,e])}function M(t){if(t.tickvals){var e=w(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map((function(t){return(t-e[0])/(e[1]-e[0])})))}}function A(t){var e=t.map((function(t){return t[0]})),r=t.map((function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")})),a=\"rgb\".split(\"\").map((function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i}));return function(t){return a.map((function(e){return e(t)}))}}function S(t){return t.dimensions.some((function(t){return t.brush.filterSpecified}))}function E(t,e,r){var a=g(e),s=a.trace,l=m.convertTypedArray(a.lineColor),c=s.line,u={color:i(v.deselectedLineColor)},h=f.extractOpts(c),p=h.reversescale?f.flipScale(a.cscale):a.cscale,d=s.domain,y=s.dimensions,x=t.width,b=s.labelangle,_=s.labelside,T=s.labelfont,k=s.tickfont,M=s.rangefont,S=o.extendDeepNoArrays({},c,{color:l.map(n.scale.linear().domain(w({values:l,range:[h.min,h.max],_length:s._length}))),blockLineCount:v.blockLineCount,canvasOverdrag:v.overdrag*v.canvasPixelRatio}),E=Math.floor(x*(d.x[1]-d.x[0])),C=Math.floor(t.height*(d.y[1]-d.y[0])),L=t.margin||{l:80,r:80,t:100,b:80},I=E,P=C;return{key:r,colCount:y.filter(m.isVisible).length,dimensions:y,tickDistance:v.tickDistance,unitToColor:A(p),lines:S,deselectedLines:u,labelAngle:b,labelSide:_,labelFont:T,tickFont:k,rangeFont:M,layoutWidth:x,layoutHeight:t.height,domain:d,translateX:d.x[0]*x,translateY:t.height-d.y[1]*t.height,pad:L,canvasWidth:I*v.canvasPixelRatio+2*S.canvasOverdrag,canvasHeight:P*v.canvasPixelRatio,width:I,height:P,canvasPixelRatio:v.canvasPixelRatio}}function C(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=v.verticalPadding/a,f=function(t,e){return n.scale.linear().range([e,t-e])}(a,v.verticalPadding),h={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return h.dimensions=s.filter(m.isVisible).map((function(i,s){var d=function(t,e){return n.scale.linear().domain(w(t)).range([e,1-e])}(i,u),g=p[i.label];p[i.label]=(g||0)+1;var x=i.label+(g?\"__\"+g:\"\"),b=i.constraintrange,_=b&&b.length;_&&!Array.isArray(b[0])&&(b=[b]);var T=_?b.map((function(t){return t.map(d)})):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var E,C=i.tickvals;function L(t,e){return{val:t,text:E[e]}}function I(t,e){return t.val-e.val}if(Array.isArray(C)&&C.length){E=i.ticktext,Array.isArray(E)&&E.length?E.length>C.length?E=E.slice(0,C.length):C.length>E.length&&(C=C.slice(0,E.length)):E=C.map(n.format(i.tickformat));for(var P=1;P<C.length;P++)if(C[P]<C[P-1]){for(var z=C.map(L).sort(I),O=0;O<C.length;O++)C[O]=z[O].val,E[O]=z[O].text;break}}else C=void 0;return A=m.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:C,ticktext:E,ordinal:m.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(d),unitTickvals:C&&C.map(d),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:f,domainScale:k(a,v.verticalPadding,i,C,E),ordinalScale:M(i),parent:h,model:r,brush:y.makeBrush(t,_,T,(function(){t.linePickActive(!1)}),(function(){var e=h;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=S(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))}),(function(r){if(h.focusLayer.render(h.panels,!0),h.pickLayer&&h.pickLayer.render(h.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=d.invert,a=r.map((function(t){return t.map(n).sort(o.sorterAsc)})).sort((function(t,e){return t[0]-e[0]}));e.filterChanged(h.key,i._index,a)}}))}})),h}function L(t){t.classed(v.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\")}function I(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function P(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function z(t,e){return a.tickText(t._ax,e,!1).text}function O(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return z(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var f=t._fullLayout,h=f._toppaper,b=f._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=T(l.range[0],l.range[1]):l.range=_(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var w,k,M=(w=!0,k=!1,{linePickActive:function(t){return arguments.length?w=!!t:w},contextShown:function(t){return arguments.length?k=!!t:k}}),A=e.filter((function(t){return g(t).trace.visible})).map(E.bind(0,r)).map(C.bind(0,M,i));b.each((function(t,e){return o.extendFlat(t,A[e])}));var D=b.selectAll(\".gl-canvas\").each((function(t){t.viewModel=A[0],t.model=t.viewModel?t.viewModel.model:null})),R=null;D.filter((function(t){return t.pick})).style(\"pointer-events\",\"auto\").on(\"mousemove\",(function(t){if(M.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],f=u?c[2]+256*(c[1]+256*c[0]):null,h={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:f};f!==R&&(u?i.hover(h):i.unhover&&i.unhover(h),R=f)}})),D.style(\"opacity\",(function(t){return t.pick?0:1})),h.style(\"background\",\"rgba(255, 255, 255, 0)\");var F=h.selectAll(\".\"+v.cn.parcoords).data(A,p);F.exit().remove(),F.enter().append(\"g\").classed(v.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),F.attr(\"transform\",(function(t){return l(t.model.translateX,t.model.translateY)}));var B=F.selectAll(\".\"+v.cn.parcoordsControlView).data(d,p);B.enter().append(\"g\").classed(v.cn.parcoordsControlView,!0),B.attr(\"transform\",(function(t){return l(t.model.pad.l,t.model.pad.t)}));var N=B.selectAll(\".\"+v.cn.yAxis).data((function(t){return t.dimensions}),p);N.enter().append(\"g\").classed(v.cn.yAxis,!0),B.each((function(t){P(N,t)})),D.each((function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=x(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}})),N.attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),N.call(n.behavior.drag().origin((function(t){return t})).on(\"drag\",(function(t){var e=t.parent;M.linePickActive(!1),t.x=Math.max(-v.overdrag,Math.min(t.model.width+v.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,N.sort((function(t,e){return t.x-e.x})).each((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio})),P(N,e),N.filter((function(e){return 0!==Math.abs(t.xIndex-e.xIndex)})).attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),n.select(this).attr(\"transform\",l(t.x,0)),N.each((function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)})).on(\"dragend\",(function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,P(N,e),n.select(this).attr(\"transform\",(function(t){return l(t.x,0)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),M.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map((function(t){return t.crossfilterDimensionIndex})))}))),N.exit().remove();var j=N.selectAll(\".\"+v.cn.axisOverlays).data(d,p);j.enter().append(\"g\").classed(v.cn.axisOverlays,!0),j.selectAll(\".\"+v.cn.axis).remove();var U=j.selectAll(\".\"+v.cn.axis).data(d,p);U.enter().append(\"g\").classed(v.cn.axis,!0),U.each((function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat((function(e){return m.isOrdinal(t)?e:z(t.model.dimensions[t.visibleIndex],e)})).scale(r)),u.font(U.selectAll(\"text\"),t.model.tickFont)})),U.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),U.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\");var V=j.selectAll(\".\"+v.cn.axisHeading).data(d,p);V.enter().append(\"g\").classed(v.cn.axisHeading,!0);var q=V.selectAll(\".\"+v.cn.axisTitle).data(d,p);q.enter().append(\"text\").classed(v.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"pointer-events\",\"auto\"),q.text((function(t){return t.label})).each((function(e){var r=n.select(this);u.font(r,e.model.labelFont),c.convertToTspans(r,t)})).attr(\"transform\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide),r=v.axisTitleOffset;return(e.dir>0?\"\":l(0,2*r+t.model.height))+s(e.degrees)+l(-r*e.dx,-r*e.dy)})).attr(\"text-anchor\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"}));var H=j.selectAll(\".\"+v.cn.axisExtent).data(d,p);H.enter().append(\"g\").classed(v.cn.axisExtent,!0);var G=H.selectAll(\".\"+v.cn.axisExtentTop).data(d,p);G.enter().append(\"g\").classed(v.cn.axisExtentTop,!0),G.attr(\"transform\",l(0,-v.axisExtentOffset));var Y=G.selectAll(\".\"+v.cn.axisExtentTopText).data(d,p);Y.enter().append(\"text\").classed(v.cn.axisExtentTopText,!0).call(L),Y.text((function(t){return O(t,!0)})).each((function(t){u.font(n.select(this),t.model.rangeFont)}));var W=H.selectAll(\".\"+v.cn.axisExtentBottom).data(d,p);W.enter().append(\"g\").classed(v.cn.axisExtentBottom,!0),W.attr(\"transform\",(function(t){return l(0,t.model.height+v.axisExtentOffset)}));var X=W.selectAll(\".\"+v.cn.axisExtentBottomText).data(d,p);X.enter().append(\"text\").classed(v.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(L),X.text((function(t){return O(t,!1)})).each((function(t){u.font(n.select(this),t.model.rangeFont)})),y.ensureAxisBrush(j)}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"./axisbrush\":1150,\"./constants\":1153,\"./helpers\":1155,\"./lines\":1157,\"color-rgba\":127,d3:169}],1160:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},f=r._size;e.forEach((function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()}));n(t,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map((function(t){return t.slice()})),s=\"dimensions[\"+n+\"].constraintrange\",f=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===f[s]){var h=a.constraintrange;f[s]=h||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter((function(t){return!a(t)})).sort((function(t){return l[e].indexOf(t)})).forEach((function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)})),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":791,\"./helpers\":1155,\"./parcoords\":1159}],1161:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/template_attributes\").texttemplateAttrs,c=t(\"../../lib/extend\").extendFlat,u=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:c({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),texttemplate:l({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:c({},u,{}),insidetextorientation:{valType:\"enumerated\",values:[\"horizontal\",\"radial\",\"tangential\",\"auto\"],dflt:\"auto\",editType:\"plot\"},insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:c({},u,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:c({},u,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1162:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"pie\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../components/color\"),o={};function s(t){return function(e,r){return!!e&&(!!(e=i(e)).isValid()&&(e=a.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function l(t,e){var r,n=JSON.stringify(t),a=e[n];if(!a){for(a=t.slice(),r=0;r<t.length;r++)a.push(i(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)a.push(i(t[r]).darken(20).toHexString());e[n]=a}return a}e.exports={calc:function(t,e){var r,i,a=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],f=e.values,h=e._length,p=e._hasValues&&h;if(e.dlabel)for(c=new Array(h),r=0;r<h;r++)c[r]=String(e.label0+r*e.dlabel);var d={},g=s(o[\"_\"+e.type+\"colormap\"]),m=0,v=!1;for(r=0;r<h;r++){var y,x,b;if(p){if(y=f[r],!n(y))continue;if((y=+y)<0)continue}else y=1;void 0!==(x=c[r])&&\"\"!==x||(x=r);var _=d[x=String(x)];void 0===_?(d[x]=a.length,(b=-1!==l.indexOf(x))||(m+=y),a.push({v:y,label:x,color:g(u[r],x),i:r,pts:[r],hidden:b})):(v=!0,(i=a[_]).v+=y,i.pts.push(r),i.hidden||(m+=y),!1===i.color&&u[r]&&(i.color=g(u[r],x)))}return(\"funnelarea\"===e.type?v:e.sort)&&a.sort((function(t,e){return e.v-t.v})),a[0]&&(a[0].vTotal=m),a},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],s=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=l(a,o));for(var c=0,u=0;u<i.length;u++){var f=i[u];if(f[0].trace.type===r)for(var h=0;h<f.length;h++){var p=f[h];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=a[c%a.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},{\"../../components/color\":643,\"fast-isnumeric\":241,tinycolor2:576}],1164:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./attributes\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText;function l(t,e){var r=Array.isArray(t),a=i.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,a?e.length:1/0);if(isFinite(o)||(o=0),o&&a){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:a,len:o}}e.exports={handleLabelsAndValues:l,supplyDefaults:function(t,e,r,n){function c(r,n){return i.coerce(t,e,a,r,n)}var u=l(c(\"labels\"),c(\"values\")),f=u.len;if(e._hasLabels=u.hasLabels,e._hasValues=u.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),f){e._length=f,c(\"marker.line.width\")&&c(\"marker.line.color\"),c(\"marker.colors\"),c(\"scalegroup\");var h,p=c(\"text\"),d=c(\"texttemplate\");if(d||(h=c(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),d||h&&\"none\"!==h){var g=c(\"textposition\");s(t,e,n,c,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(g)||\"auto\"===g||\"outside\"===g)&&c(\"automargin\"),(\"inside\"===g||\"auto\"===g||Array.isArray(g))&&c(\"insidetextorientation\")}o(e,n,c);var m=c(\"hole\");if(c(\"title.text\")){var v=c(\"title.position\",m?\"middle center\":\"top center\");m||\"middle center\"!==v||(e.title.position=\"top center\"),i.coerceFont(c,\"title.font\",n.font)}c(\"sort\"),c(\"direction\"),c(\"rotation\"),c(\"pull\")}else e.visible=!1}}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1161,\"fast-isnumeric\":241}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":679}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return-1!==t.indexOf(\"e\")?t.replace(/[.]?0+e/,\"e\"):-1!==t.indexOf(\".\")?t.replace(/[.]?0+$/,\"\"):t}r.formatPiePercent=function(t,e){var r=i((100*t).toPrecision(3));return n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=i(t.toPrecision(10));return n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||\"\"===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0},r.getRotationAngle=function(t){return(\"auto\"===t?0:t)*Math.PI/180}},{\"../../lib\":778}],1167:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1161,\"./base_plot\":1162,\"./calc\":1163,\"./defaults\":1164,\"./layout_attributes\":1168,\"./layout_defaults\":1169,\"./plot\":1170,\"./style\":1171,\"./style_one\":1172}],1168:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":778,\"./layout_attributes\":1168}],1170:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=l.strScale,u=l.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../bar/uniform_text\"),p=h.recordMinTextSize,d=h.clearMinTextSize,g=t(\"../bar/constants\").TEXTPAD,m=t(\"./helpers\"),v=t(\"./event_data\"),y=t(\"../../lib\").isValidTextValue;function x(t,e,r){var i=r[0],o=i.trace,s=i.cx,c=i.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",(function(t){var r=e._fullLayout,u=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var f=u.hoverinfo;if(Array.isArray(f)&&(f=a.castHoverinfo({hoverinfo:[m.castOption(f,t.pts)],_module:o._module},r,0)),\"all\"===f&&(f=\"label+text+value+percent+name\"),u.hovertemplate||\"none\"!==f&&\"skip\"!==f&&f){var h=t.rInscribed||0,p=s+t.pxmid[0]*(1-h),d=c+t.pxmid[1]*(1-h),g=r.separators,y=[];if(f&&-1!==f.indexOf(\"label\")&&y.push(t.label),t.text=m.castOption(u.hovertext||u.text,t.pts),f&&-1!==f.indexOf(\"text\")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=m.formatPieValue(t.v,g),f&&-1!==f.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/i.vTotal,t.percentLabel=m.formatPiePercent(t.percent,g),f&&-1!==f.indexOf(\"percent\")&&y.push(t.percentLabel);var b=u.hoverlabel,_=b.font;a.loneHover({trace:o,x0:p-h*i.r,x1:p+h*i.r,y:d,text:y.join(\"<br>\"),name:u.hovertemplate||-1!==f.indexOf(\"name\")?u.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:m.castOption(b.bgcolor,t.pts)||t.color,borderColor:m.castOption(b.bordercolor,t.pts),fontFamily:m.castOption(_.family,t.pts),fontSize:m.castOption(_.size,t.pts),fontColor:m.castOption(_.color,t.pts),nameLength:m.castOption(b.namelength,t.pts),textAlign:m.castOption(b.align,t.pts),hovertemplate:m.castOption(u.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[v(t,u)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[v(t,u)],event:n.event})}})),t.on(\"mouseout\",(function(t){var r=e._fullLayout,i=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[v(s,i)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(a.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)})),t.on(\"click\",(function(t){var r=e._fullLayout,i=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[v(t,i)],a.click(e,n.event))}))}function b(t,e,r){var n=m.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=m.castOption(t._input.textfont.color,e.pts));var i=m.castOption(t.insidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.insidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:i,size:a}}function _(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=l.templateString(a,n._meta));var o=s.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(s.font,n.title.font).call(f.convertToTspans,e),c=s.bBox(o.node(),!0);r.titleBox={width:c.width,height:c.height},o.remove()}}function w(t,e,r){var n=r.r||e.rpx1,i=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-i,scale:0,rotate:0,textPosAngle:0};var a,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,f=\"horizontal\"===u,h=\"tangential\"===u,p=\"radial\"===u,d=\"auto\"===u,g=[];if(!d){var m,v=function(r,i){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(a=\"tan\"===i?k(t,n,o,c,0):T(t,n,o,c,Math.PI/2)).textPosAngle=r,g.push(a)}};if(f||h){for(m=4;m>=-4;m-=2)v(Math.PI*m,\"tan\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+1),\"tan\")}if(f||p){for(m=4;m>=-4;m-=2)v(Math.PI*(m+1.5),\"rad\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+.5),\"rad\")}}if(s||d||f){var y=Math.sqrt(t.width*t.width+t.height*t.height);if((a={scale:i*n*2/y,rCenter:1-i,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,a.scale>=1)return a;g.push(a)}(d||p)&&((a=T(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a)),(d||h)&&((a=k(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a));for(var x=0,b=0,_=0;_<g.length;_++){var w=g[_].scale;if(b<w&&(b=w,x=_),!d&&b>=1)break}return g[x]}function T(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.width/t.height,o=S(a,n,e,r);return{scale:2*o/t.height,rCenter:M(a,o/e),rotate:A(i)}}function k(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.height/t.width,o=S(a,n,e,r);return{scale:2*o/t.width,rCenter:M(a,o/e),rotate:A(i+Math.PI/2)}}function M(t,e){return Math.cos(e)-t*e}function A(t){return(180/Math.PI*t+720)%180-90}function S(t,e,r,n){var i=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(i*i+.5)+i),n/(Math.sqrt(t*t+n/2)+t))}function E(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function C(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function L(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=P(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),f=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(f+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?f*=2:-1!==a.title.position.indexOf(\"right\")&&(f+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=f/t.titleBox.width,n=I(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function I(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function P(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function z(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=I(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+P(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=I(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var f=o*r.vTotal;\"funnelarea\"===i.type&&(f/=(1+i.baseratio)/2,f/=i.aspectratio),r.r=Math.sqrt(f)}}}(t,r)}function O(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function D(t,e,r){var n=t._fullLayout,i=r.trace,a=i.texttemplate,o=i.textinfo;if(!a&&o&&\"none\"!==o){var s,c=o.split(\"+\"),u=function(t){return-1!==c.indexOf(t)},f=u(\"label\"),h=u(\"text\"),p=u(\"value\"),d=u(\"percent\"),g=n.separators;if(s=f?[e.label]:[],h){var v=m.getFirstFilled(i.text,e.pts);y(v)&&s.push(v)}p&&s.push(m.formatPieValue(e.v,g)),d&&s.push(m.formatPiePercent(e.v/r.vTotal,g)),e.text=s.join(\"<br>\")}if(a){var x=l.castOption(i,e.i,\"texttemplate\");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:m.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:m.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(i,t.i,\"customdata\")}}(e),_=m.getFirstFilled(i.text,e.pts);(y(_)||\"\"===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,i._meta||{})}else e.text=\"\"}}function R(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),i=Math.sin(r),a=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=a*n-o*i,t.textY=a*i+o*n,t.noCenter=!0}e.exports={plot:function(t,e){var r=t._fullLayout,a=r._size;d(\"pie\",r),_(e,t),z(e,a);var h=l.makeTraceGroups(r._pielayer,e,\"trace\").each((function(e){var h=n.select(this),d=e[0],g=d.trace;!function(t){var e,r,n,i=t[0],a=i.r,o=i.trace,s=m.getRotationAngle(o.rotation),l=2*Math.PI/i.vTotal,c=\"px0\",u=\"px1\";if(\"counterclockwise\"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c=\"px1\",u=\"px0\"}for(n=O(a,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=O(a,s),r.midangle=s,s+=l*r.v/2,n=O(a,s),r.stopangle=s,r[u]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-o.hole,r.rInscribed=E(r,i))}(e),h.attr(\"stroke-linejoin\",\"round\"),h.each((function(){var v=n.select(this).selectAll(\"g.slice\").data(e);v.enter().append(\"g\").classed(\"slice\",!0),v.exit().remove();var y=[[[],[]],[[],[]]],_=!1;v.each((function(i,a){if(i.hidden)n.select(this).selectAll(\"path,g\").remove();else{i.pointNumber=i.i,i.curveNumber=g.index,y[i.pxmid[1]<0?0:1][i.pxmid[0]<0?0:1].push(i);var o=d.cx,c=d.cy,u=n.select(this),h=u.selectAll(\"path.surface\").data([i]);if(h.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),u.call(x,t,e),g.pull){var v=+m.castOption(g.pull,i.pts)||0;v>0&&(o+=v*i.pxmid[0],c+=v*i.pxmid[1])}i.cxFinal=o,i.cyFinal=c;var T=g.hole;if(i.v===d.vTotal){var k=\"M\"+(o+i.px0[0])+\",\"+(c+i.px0[1])+L(i.px0,i.pxmid,!0,1)+L(i.pxmid,i.px0,!0,1)+\"Z\";T?h.attr(\"d\",\"M\"+(o+T*i.px0[0])+\",\"+(c+T*i.px0[1])+L(i.px0,i.pxmid,!1,T)+L(i.pxmid,i.px0,!1,T)+\"Z\"+k):h.attr(\"d\",k)}else{var M=L(i.px0,i.px1,!0,1);if(T){var A=1-T;h.attr(\"d\",\"M\"+(o+T*i.px1[0])+\",\"+(c+T*i.px1[1])+L(i.px1,i.px0,!1,T)+\"l\"+A*i.px0[0]+\",\"+A*i.px0[1]+M+\"Z\")}else h.attr(\"d\",\"M\"+o+\",\"+c+\"l\"+i.px0[0]+\",\"+i.px0[1]+M+\"Z\")}D(t,i,d);var S=m.castOption(g.textposition,i.pts),E=u.selectAll(\"g.slicetext\").data(i.text&&\"none\"!==S?[0]:[]);E.enter().append(\"g\").classed(\"slicetext\",!0),E.exit().remove(),E.each((function(){var u=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),h=l.ensureUniformFontSize(t,\"outside\"===S?function(t,e,r){var n=m.castOption(t.outsidetextfont.color,e.pts)||m.castOption(t.textfont.color,e.pts)||r.color,i=m.castOption(t.outsidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.outsidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(g,i,r.font):b(g,i,r.font));u.text(i.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,h).call(f.convertToTspans,t);var v,y=s.bBox(u.node());if(\"outside\"===S)v=C(y,i);else if(v=w(y,i,d),\"auto\"===S&&v.scale<1){var x=l.ensureUniformFontSize(t,g.outsidetextfont);u.call(s.font,x),v=C(y=s.bBox(u.node()),i)}var T=v.textPosAngle,k=void 0===T?i.pxmid:O(d.r,T);if(v.targetX=o+k[0]*v.rCenter+(v.x||0),v.targetY=c+k[1]*v.rCenter+(v.y||0),R(v,y),v.outside){var M=v.targetY;i.yLabelMin=M-y.height/2,i.yLabelMid=M,i.yLabelMax=M+y.height/2,i.labelExtraX=0,i.labelExtraY=0,_=!0}v.fontSize=h.size,p(g.type,v,r),e[a].transform=v,u.attr(\"transform\",l.getTextTransform(v))}))}function L(t,e,r,n){var a=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return\"a\"+n*d.r+\",\"+n*d.r+\" 0 \"+i.largeArc+(r?\" 1 \":\" 0 \")+a+\",\"+o}}));var T=n.select(this).selectAll(\"g.titletext\").data(g.title.text?[0]:[]);if(T.enter().append(\"g\").classed(\"titletext\",!0),T.exit().remove(),T.each((function(){var e,r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),i=g.title.text;g._meta&&(i=l.templateString(i,g._meta)),r.text(i).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,g.title.font).call(f.convertToTspans,t),e=\"middle center\"===g.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(d):L(d,a),r.attr(\"transform\",u(e.x,e.y)+c(Math.min(1,e.scale))+u(e.tx,e.ty))})),_&&function(t,e){var r,n,i,a,o,s,l,c,u,f,h,p,d;function g(t,e){return t.pxmid[1]-e.pxmid[1]}function v(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,c,u,h,p=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),d=n?t.yLabelMin:t.yLabelMax,g=n?t.yLabelMax:t.yLabelMin,v=t.cyFinal+o(t.px0[1],t.px1[1]),y=p-d;if(y*l>0&&(t.labelExtraY=y),Array.isArray(e.pull))for(c=0;c<f.length;c++)(u=f[c])===t||(m.castOption(e.pull,t.pts)||0)>=(m.castOption(e.pull,u.pts)||0)||((t.pxmid[1]-u.pxmid[1])*l>0?(y=u.cyFinal+o(u.px0[1],u.px1[1])-d-t.labelExtraY)*l>0&&(t.labelExtraY+=y):(g+t.labelExtraY-v)*l>0&&(i=3*s*Math.abs(c-f.indexOf(t)),(h=u.cxFinal+a(u.px0[0],u.px1[0])+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=h)))}for(n=0;n<2;n++)for(i=n?g:v,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(i),u=t[1-n][r],f=u.concat(c),p=[],h=0;h<c.length;h++)void 0!==c[h].yLabelMid&&p.push(c[h]);for(d=!1,h=0;n&&h<u.length;h++)if(void 0!==u[h].yLabelMid){d=u[h];break}for(h=0;h<p.length;h++){var x=h&&p[h-1];d&&!h&&(x=d),y(p[h],x)}}}(y,g),function(t,e){t.each((function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,i.attr(\"transform\",l.getTextTransform(t.transform));var a=t.cxFinal+t.pxmid[0],s=\"M\"+a+\",\"+(t.cyFinal+t.pxmid[1]),c=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var u=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(u)>Math.abs(f)?s+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(a+t.labelExtraX+c):s+=\"l\"+t.labelExtraX+\",\"+u+\"v\"+(f-u)+\"h\"+c}else s+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+c;l.ensureSingle(r,\"path\",\"textline\").call(o.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:s,fill:\"none\"})}else r.select(\"path.textline\").remove()}))}(v,g),_&&g.automargin){var k=s.bBox(h.node()),M=g.domain,A=a.w*(M.x[1]-M.x[0]),S=a.h*(M.y[1]-M.y[0]),E=(.5*A-d.r)/a.w,I=(.5*S-d.r)/a.h;i.autoMargin(t,\"pie.\"+g.uid+\".automargin\",{xl:M.x[0]-E,xr:M.x[1]+E,yb:M.y[0]-I,yt:M.y[1]+I,l:Math.max(d.cx-d.r-k.left,0),r:Math.max(k.right-(d.cx+d.r),0),b:Math.max(k.bottom-(d.cy+d.r),0),t:Math.max(d.cy-d.r-k.top,0),pad:5})}}))}));setTimeout((function(){h.selectAll(\"tspan\").each((function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))}))}),0)},formatSliceLabel:D,transformInsideText:w,determineInsideTextFont:b,positionTitleOutside:L,prerenderTitles:_,layoutAreas:z,attachFxHandlers:x,computeTransform:R}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../bar/constants\":923,\"../bar/uniform_text\":937,\"./event_data\":1165,\"./helpers\":1166,d3:169}],1171:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._pielayer.selectAll(\".trace\");a(t,e,\"pie\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"./style_one\":1172,d3:169}],1172:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":643,\"./helpers\":1166}],1173:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1187}],1174:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,f=this.pickXYData=t.xy,h=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(f){if(n=f,e=f.length>>>1,h)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),m=i(t.marker.border.color),v=t.opacity*t.marker.opacity;g[3]*=v,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,m[3]*=v,this.pointcloudOptions.borderColor=m;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,T=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:T}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:T})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/autorange\":827,\"../scatter/get_trace_color\":1197,\"gl-pointcloud2d\":324}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":778,\"./attributes\":1173}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":868,\"../scatter3d/calc\":1216,\"./attributes\":1173,\"./convert\":1174,\"./defaults\":1175}],1177:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=h({hoverinfo:f({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),customdata:void 0,node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:f(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../components/fx/attributes\":674,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),f=t(\"../../registry\");function h(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var h={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:h,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[h],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),f.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)h(t,e)}},{\"../../components/dragelement\":662,\"../../components/fx/layout_attributes\":684,\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/select\":847,\"../../plots/get_data\":865,\"../../registry\":911,\"./plot\":1183}],1179:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),f=o(a.customdata),h={},p={},d=a.colorscales.length;for(e=0;e<d;e++){var g=a.colorscales[e],m=l.extractScale(g,{cLetter:\"c\"}),v=l.makeColorScaleFunc(m);p[g.label]=v}var y=0;for(e=0;e<a.value.length;e++)a.source[e]>y&&(y=a.source[e]),a.target[e]>y&&(y=a.target[e]);var x,b=y+1;t.node._count=b;var _=t.node.groups,w={};for(e=0;e<_.length;e++){var T=_[e];for(x=0;x<T.length;x++){var k=T[x],M=b+e;w.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):w[k]=M}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var S=a.value[e],E=a.source[e],C=a.target[e];if(S>0&&s(E,b)&&s(C,b)&&(!w.hasOwnProperty(E)||!w.hasOwnProperty(C)||w[E]!==w[C])){w.hasOwnProperty(C)&&(C=w[C]),w.hasOwnProperty(E)&&(E=w[E]),C=+C,h[E=+E]=h[C]=!0;var L=\"\";a.label&&a.label[e]&&(L=a.label[e]);var I=null;L&&p.hasOwnProperty(L)&&(I=p[L]),c.push({pointNumber:e,label:L,color:u?a.color[e]:a.color,customdata:f?a.customdata[e]:a.customdata,concentrationscale:I,source:E,target:C,value:+S}),A.source.push(E),A.target.push(C)}}var P=b+_.length,z=o(r.color),O=o(r.customdata),D=[];for(e=0;e<P;e++)if(h[e]){var R=r.label[e];D.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:R,color:z?r.color[e]:r.color,customdata:O?r.customdata[e]:r.customdata})}var F=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some((function(t){return t.length>1}))}(P,A.source,A.target)&&(F=!0),{circular:F,links:c,nodes:D,groups:_,groupLookup:w}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775,\"strongly-connected-components\":569}],1180:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,h){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(h.hoverlabel,t.hoverlabel),g=t.node,m=c.newContainer(e,\"node\");function v(t,e){return n.coerce(g,m,i.node,t,e)}v(\"label\"),v(\"groups\"),v(\"x\"),v(\"y\"),v(\"pad\"),v(\"thickness\"),v(\"line.color\"),v(\"line.width\"),v(\"hoverinfo\",t.hoverinfo),l(g,m,v,d),v(\"hovertemplate\");var y=h.colorway;v(\"color\",m.label.map((function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}))),v(\"customdata\");var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,T=o(h.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(T,b.value.length)),_(\"customdata\"),u(x,b,{name:\"colorscales\",handleItemDefaults:f}),s(e,h,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),m.x.length&&m.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},h.font)),e._length=null}},{\"../../components/color\":643,\"../../components/fx/hoverlabel_defaults\":681,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"./attributes\":1177,tinycolor2:576}],1182:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1177,\"./base_plot\":1178,\"./calc\":1179,\"./defaults\":1181,\"./plot\":1183,\"./select.js\":1185}],1183:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function f(t,e){return t.filter((function(t){return t.key===e.traceId}))}function h(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function m(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function v(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),r&&f(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(m)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),r&&f(e,t).selectAll(l.sankeyNode).filter(g(t)).call(v)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,f=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",T=c(t,\"concentration:\")+\" \",k=c(t,\"incoming flow count:\")+\" \",M=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,f=0;f<i.flow.links.length;f++){var d=i.flow.links[f];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=f),d.fullData=d.trace,s=i.link.trace.link;var g=v(d),m={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:m.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?T+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:m,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each((function(){i.link.concentrationscale||h(this,.65),p(this)}))}}function v(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return\"v\"===t.trace.orientation&&n.reverse(),n[0]+=i.parent.translateX,n[1]+=i.parent.translateY,n}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),f=s.node().getBoundingClientRect(),d=f.left-2-c.left,g=f.right+2-c.left,m=f.top+f.height/4-c.top,v={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace,t._fullLayout._calcInverseTransform(t);var y=t._fullLayout._invScaleX,x=t._fullLayout._invScaleY,_=a.loneHover({x0:y*d,x1:y*g,y:x*m,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,k+i.node.targetLinks.length,M+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:v,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});h(_,.85),p(_)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(v,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1180,\"./render\":1184,d3:169}],1184:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),f=t(\"../../lib\"),h=f.strTranslate,p=t(\"../../lib/gup\"),d=p.keyFun,g=p.repeat,m=p.unwrap,v=t(\"d3-interpolate\").interpolateNumber,y=t(\"../../registry\");function x(t,e,r){var i,o=m(e),s=o.trace,u=s.domain,h=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,g=t.width*(u.x[1]-u.x[0]),v=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(h?[g,v]:[v,g]).nodeWidth(d).nodePadding(p).nodeId((function(t){return t.pointNumber})).nodes(y).links(x);var _,w,T,k=i();for(var M in i.nodePadding()<p&&f.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var A,S=parseInt(o._groupLookup[M]);for(_=0;_<k.nodes.length;_++)if(k.nodes[_].pointNumber===S){A=k.nodes[_];break}if(A){var E={pointNumber:parseInt(M),x0:A.x0,x1:A.x1,y0:A.y0,y1:A.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};k.nodes.unshift(E),A.childrenNodes.unshift(E)}}if(function(){for(_=0;_<k.nodes.length;_++){var t,e,r=k.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(T=0;T<o.length;T++)l[(e=o[T]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(T=0;T<o.length;T++)(e=o[T]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,k.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*g,s.node.y[_]*v];k.nodes[_].x0=C[0]-d/2,k.nodes[_].x1=C[0]+d/2;var L=k.nodes[_].y1-k.nodes[_].y0;k.nodes[_].y0=C[1]-L/2,k.nodes[_].y1=C[1]+L/2}if(\"snap\"===s.arrangement)!function(t){t.forEach((function(t){var e,r,n,i=0,a=t.length;for(t.sort((function(t,e){return t.y0-e.y0})),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p}))}(function(t){var e,r,n=t.map((function(t,e){return{x0:t.x0,index:e}})).sort((function(t,e){return t.x0-e.x0})),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=k.nodes));i.update(k)}return{circular:b,key:r,trace:s,guid:f.randstr(),horizontal:h,width:g,height:v,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:h?v:g,dragPerpendicular:h?g:v,arrangement:s.arrangement,sankey:i,graph:k,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}function b(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:_,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}function _(){return function(t){if(t.link.circular)return e=t.link,r=e.width/2,n=e.circularPathData,\"top\"===e.circularLinkType?\"M \"+n.targetX+\" \"+(n.targetY+r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 1 \"+(n.rightFullExtent-r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 1 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 0 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 0 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"L\"+n.targetX+\" \"+(n.targetY-r)+\"Z\":\"M \"+n.targetX+\" \"+(n.targetY-r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 0 \"+(n.rightFullExtent-r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 0 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 1 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 1 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"L\"+n.targetX+\" \"+(n.targetY+r)+\"Z\";var e,r,n,i=t.link.source.x1,a=t.link.target.x0,o=v(i,a),s=o(.5),l=o(.5),c=t.link.y0-t.link.width/2,u=t.link.y0+t.link.width/2,f=t.link.y1-t.link.width/2,h=t.link.y1+t.link.width/2;return\"M\"+i+\",\"+c+\"C\"+s+\",\"+c+\" \"+l+\",\"+f+\" \"+a+\",\"+f+\"L\"+a+\",\"+h+\"C\"+l+\",\"+h+\" \"+s+\",\"+u+\" \"+i+\",\"+u+\"Z\"}}function w(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=f.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}function T(t){t.attr(\"transform\",(function(t){return h(t.node.x0.toFixed(3),t.node.y0.toFixed(3))}))}function k(t){t.call(T)}function M(t,e){t.call(k),e.attr(\"d\",_())}function A(t){t.attr(\"width\",(function(t){return t.node.x1-t.node.x0})).attr(\"height\",(function(t){return t.visibleHeight}))}function S(t){return t.link.width>1||t.linkLineWidth>0}function E(t){return h(t.translateX,t.translateY)+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function C(t){return h(t.horizontal?0:t.labelY,t.horizontal?t.labelY:0)}function L(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function I(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function P(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function z(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function O(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function D(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])})).on(\"mousemove.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])})).on(\"mouseout.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)})).on(\"click.basic\",(function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)}))}function R(t,e,r,a){var o=i.behavior.drag().origin((function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}})).on(\"dragstart\",(function(i){if(\"fixed\"!==i.arrangement&&(f.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",(function(t){a._fullLayout._dragCover=t})),f.raiseToTop(this),i.interactionState.dragInProgress=i.node,B(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter((function(t){return t.originalX===r.node.originalX})).filter((function(t){return!t.partOfGroup}));r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius((function(t){return t.dy/2+r.nodePad/2})).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame((function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(r.graph.nodes),r.sankey.update(r.graph),M(t.filter(N(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var l=r.node.originalX;r.node.x0=l-r.visibleWidth/2,r.node.x1=l+r.visibleWidth/2,F(r,a)}}))}(t,e,i,o,a)}})).on(\"drag\",(function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),B(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),M(t.filter(N(r)),e))}})).on(\"dragend\",(function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&F(t,a)}}));t.on(\".drag\",null).call(o)}function F(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}y.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then((function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()}))}function B(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function N(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,l,c){var u=!1;f.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",(function(){u=!0}));var h=t._fullLayout._dragCover,p=r.filter((function(t){return m(t).trace.visible})).map(x.bind(null,l)),v=e.selectAll(\".\"+n.cn.sankey).data(p,d);v.exit().remove(),v.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",E),v.each((function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;f.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})})),v.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var y=v.selectAll(\".\"+n.cn.sankeyLinks).data(g,d);y.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var k=y.selectAll(\".\"+n.cn.sankeyLink).data((function(t){return t.graph.links.filter((function(t){return t.value})).map(b.bind(null,t))}),d);k.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(D,v,c.linkEvents),k.style(\"stroke\",(function(t){return S(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue})).style(\"stroke-opacity\",(function(t){return S(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})).style(\"stroke-width\",(function(t){return S(t)?t.linkLineWidth:1})).attr(\"d\",_()),k.style(\"opacity\",(function(){return t._context.staticPlot||u||h?1:0})).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),k.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var M=v.selectAll(\".\"+n.cn.sankeyNodeSet).data(g,d);M.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),M.style(\"cursor\",(function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}}));var F=M.selectAll(\".\"+n.cn.sankeyNode).data((function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort((function(t,e){return t-e})),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(w.bind(null,t))}),d);F.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(T).style(\"opacity\",(function(e){return!t._context.staticPlot&&!u||e.partOfGroup?0:1})),F.call(D,v,c.nodeEvents).call(R,k,c,t),F.transition().ease(n.ease).duration(n.duration).call(T).style(\"opacity\",(function(t){return t.partOfGroup?0:1})),F.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var B=F.selectAll(\".\"+n.cn.nodeRect).data(g);B.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(A),B.style(\"stroke-width\",(function(t){return t.nodeLineWidth})).style(\"stroke\",(function(t){return o.tinyRGB(a(t.nodeLineColor))})).style(\"stroke-opacity\",(function(t){return o.opacity(t.nodeLineColor)})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),B.transition().ease(n.ease).duration(n.duration).call(A);var N=F.selectAll(\".\"+n.cn.nodeCapture).data(g);N.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),N.attr(\"x\",(function(t){return t.zoneX})).attr(\"y\",(function(t){return t.zoneY})).attr(\"width\",(function(t){return t.zoneWidth})).attr(\"height\",(function(t){return t.zoneHeight}));var j=F.selectAll(\".\"+n.cn.nodeCentered).data(g);j.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",C),j.transition().ease(n.ease).duration(n.duration).attr(\"transform\",C);var U=j.selectAll(\".\"+n.cn.nodeLabelGuide).data(g);U.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",(function(t){return t.uniqueNodeLabelPathId})).attr(\"d\",L).attr(\"transform\",I),U.transition().ease(n.ease).duration(n.duration).attr(\"d\",L).attr(\"transform\",I);var V=j.selectAll(\".\"+n.cn.nodeLabel).data(g);V.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",P).style(\"cursor\",\"default\").style(\"fill\",\"black\"),V.style(\"text-shadow\",(function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"})).each((function(t){s.font(V,t.textFont)})),V.transition().ease(n.ease).duration(n.duration).attr(\"transform\",P);var q=V.selectAll(\".\"+n.cn.nodeLabelTextPath).data(g);q.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",(function(t){return\"#\"+t.uniqueNodeLabelPathId})).attr(\"startOffset\",O).style(\"fill\",z),q.text((function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"})).attr(\"text-anchor\",(function(t){return t.horizontal&&t.left?\"end\":\"start\"})),q.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",O).style(\"fill\",z)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../registry\":911,\"./constants\":1180,\"@plotly/d3-sankey\":56,\"@plotly/d3-sankey-circular\":55,d3:169,\"d3-force\":160,\"d3-interpolate\":162,tinycolor2:576}],1185:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1186:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.texttemplate,t,\"txt\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":778}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../components/drawing\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},xperiod:{valType:\"any\",dflt:0,editType:\"calc\"},yperiod:{valType:\"any\",dflt:0,editType:\"calc\"},xperiod0:{valType:\"any\",editType:\"calc\"},yperiod0:{valType:\"any\",editType:\"calc\"},xperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},yperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},texttemplate:n({},{}),hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:i({},{keys:c.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:u({},s,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:u({symbol:{valType:\"enumerated\",values:l.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:u({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},a(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},a(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:o({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing\":665,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"./constants\":1191}],1188:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"./subtypes\"),c=t(\"./colorscale_calc\"),u=t(\"./arrays_to_calcdata\"),f=t(\"./calc_selection\");function h(t,e,r,n,i,o,s){var c=e._length,u=t._fullLayout,f=r._id,h=n._id,p=u._firstScatter[g(e)]===e.uid,d=(m(e,u,r,n)||{}).orientation,v=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};s&&(y.ppad=x.ppad=s);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===v||\"tonextx\"===v&&(p||\"h\"===d))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==v&&\"tozeroy\"!==v&&(l.hasMarkers(e)||l.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===v||\"tonexty\"===v&&(p||\"v\"===d))?x.tozero=!0:\"tonextx\"!==v&&\"tozerox\"!==v||(x.padded=!1),f&&(e._extremes[f]=a.findExtremes(r,i,y)),h&&(e._extremes[h]=a.findExtremes(n,o,x))}function p(t,e){if(l.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var s={type:\"linear\"};a.setConvert(s);for(var c=s.makeCalcdata(t.marker,\"size\"),u=new Array(e),f=0;f<e;f++)u[f]=r(c[f]);return u}return r(n.size)}}function d(t,e){var r=g(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function g(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function m(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,l,g,v,y,x,b=t._fullLayout,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),T=_.makeCalcdata(e,\"x\"),k=w.makeCalcdata(e,\"y\"),M=o(e,_,\"x\",T),A=o(e,w,\"y\",k),S=e._length,E=new Array(S),C=e.ids,L=m(e,b,_,w),I=!1;d(b,e);var P,z=\"x\",O=\"y\";L?(i.pushUnique(L.traceIndices,e._expandedIndex),(r=\"v\"===L.orientation)?(O=\"s\",P=\"x\"):(z=\"s\",P=\"y\"),y=\"interpolate\"===L.stackgaps):h(t,e,_,w,M,A,p(e,S));var D=!!e.xperiodalignment,R=!!e.yperiodalignment;for(l=0;l<S;l++){var F=E[l]={},B=n(M[l]),N=n(A[l]);B&&N?(F[z]=M[l],F[O]=A[l],D&&(F.orig_x=T[l]),R&&(F.orig_y=k[l])):L&&(r?B:N)?(F[P]=r?M[l]:A[l],F.gap=!0,y?(F.s=s,I=!0):F.s=0):F[z]=F[O]=s,C&&(F.id=String(C[l]))}if(u(E,e),c(t,e),f(E,e),L){for(l=0;l<E.length;)E[l][P]===s?E.splice(l,1):l++;if(i.sort(E,(function(t,e){return t[P]-e[P]||t.i-e.i})),I){for(l=0;l<E.length-1&&E[l].gap;)l++;for((x=E[l].s)||(x=E[l].s=0),g=0;g<l;g++)E[g].s=x;for(v=E.length-1;v>l&&E[v].gap;)v--;for(x=E[v].s,g=E.length-1;g>v;g--)E[g].s=x;for(;l<v;)if(E[++l].gap){for(g=l+1;E[g].gap;)g++;for(var j=E[l-1][P],U=E[l-1].s,V=(E[g].s-U)/(E[g][P]-j);l<g;)E[l].s=U+(E[l][P]-j)*V,l++}}}return E},calcMarkerSize:p,calcAxisExpansion:h,setFirstScatter:d,getStackOpts:m}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"./arrays_to_calcdata\":1186,\"./calc_selection\":1189,\"./colorscale_calc\":1190,\"./subtypes\":1212,\"fast-isnumeric\":241}],1189:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":778}],1190:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1191:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1192:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T=t.calcdata;for(var k in s){var M=(v=s[k]).traceIndices;if(M.length){for(y=\"interpolate\"===v.stackgaps,x=v.groupnorm,\"v\"===v.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(M.length),l=0;l<w.length;l++)w[l]=!1;p=T[M[0]];var A=new Array(p.length);for(l=0;l<p.length;l++)A[l]=p[l][b];for(l=1;l<M.length;l++){for(h=T[M[l]],c=u=0;c<h.length;c++){for(d=h[c][b];d>A[u]&&u<A.length;u++)i(h,c,A[u],l,w,y,b),c++;if(d!==A[u]){for(f=0;f<l;f++)i(T[M[f]],u,d,f,w,y,b);A.splice(u,0,d)}u++}for(;u<A.length;u++)i(h,c,A[u],l,w,y,b),c++}var S=A.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<M.length;l++)(h=T[M[l]])[0].trace._rawLength=h[0].trace._length,h[0].trace._length=S,g+=h[c].s,h[c][_]=g;if(x)for(m=(\"fraction\"===x?g:g/100)||1,l=0;l<M.length;l++){var E=T[M[l]][c];E[_]/=m,E.sNorm=E.s/m}}for(l=0;l<M.length;l++){var C=(h=T[M[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),I=Array.isArray(L);if(L&&w[l]||I){var P=L;for(L=new Array(S),c=0;c<S;c++)L[c]=h[c].gap?0:I?P[h[c].i]:P}var z=new Array(S),O=new Array(S);for(c=0;c<S;c++)z[c]=h[c].x,O[c]=h[c].y;n.calcAxisExpansion(t,C,r,a,z,O,L),h[0].t.orientation=v.orientation}}}}}},{\"./calc\":1188}],1193:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1194:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./period_defaults\"),u=t(\"./stack_defaults\"),f=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),p=t(\"./line_shape_defaults\"),d=t(\"./text_defaults\"),g=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,m){function v(r,i){return n.coerce(t,e,a,r,i)}var y=l(t,e,m,v);if(y||(e.visible=!1),e.visible){c(t,e,m,v);var x=u(t,e,m,v),b=!x&&y<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",b),s.hasLines(e)&&(h(t,e,r,m,v),p(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&f(t,e,r,m,v,{gradient:!0}),s.hasText(e)&&(v(\"texttemplate\"),d(t,e,m,v));var _=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),_.push(\"points\")),v(\"fill\",x?x.fillDflt:\"none\"),\"none\"!==e.fill&&(g(t,e,r,v),s.hasLines(e)||p(t,e,v));var w=(e.line||{}).color,T=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||_.push(\"fills\"),v(\"hoveron\",_.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,w||T||r,{axis:\"y\"}),k(t,e,w||T||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":1187,\"./constants\":1191,\"./fillcolor_defaults\":1195,\"./line_defaults\":1200,\"./line_shape_defaults\":1202,\"./marker_defaults\":1206,\"./period_defaults\":1207,\"./stack_defaults\":1210,\"./subtypes\":1212,\"./text_defaults\":1213,\"./xy_defaults\":1214}],1195:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":643,\"../../lib\":778}],1196:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a={_fullLayout:r},o=n.getFromTrace(a,e,\"x\"),s=n.getFromTrace(a,e,\"y\");return i.xLabel=n.tickText(o,t.x,!0).text,i.yLabel=n.tickText(s,t.y,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1197:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":643,\"./subtypes\":1212}],1198:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,f=u[0].trace,h=t.xa,p=t.ya,d=h.c2p(e),g=p.c2p(r),m=[d,g],v=f.hoveron||\"\",y=-1!==f.mode.indexOf(\"markers\")?3:.5;if(-1!==v.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=h.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(h.c2p(t.x)-d);return n<e?r*n/e:n-e+r}),(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r}),x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=h.c2p(_.x,!0),T=p.c2p(_.y,!0),k=_.mrc||1;t.index=_.i;var M=u[0].t.orientation,A=M&&(_.sNorm||_.s),S=\"h\"===M?A:void 0!==_.orig_x?_.orig_x:_.x,E=\"v\"===M?A:void 0!==_.orig_y?_.orig_y:_.y;return n.extendFlat(t,{color:o(f,_),x0:w-k,x1:w+k,xLabelVal:S,y0:T-k,y1:T+k,yLabelVal:E,spikeDistance:x(_),hovertemplate:f.hovertemplate}),l(_,f,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,f,t),[t]}}if(-1!==v.indexOf(\"fills\")&&f._polygons){var C,L,I,P,z,O,D,R,F,B=f._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(I=B[C]).contains(m)&&(j=!j,N.push(I),q=Math.min(q,I.ymin),H=Math.max(H,I.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(P=N[C].pts,L=1;L<P.length;L++)(R=P[L-1][1])>G!=(F=P[L][1])>=G&&(O=P[L-1][0],D=P[L][0],F-R&&(z=O+(D-O)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,h._length);var Y=s.defaultLine;return s.opacity(f.fillcolor)?Y=f.fillcolor:s.opacity((f.line||{}).color)&&(Y=f.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,f.text&&!Array.isArray(f.text)?t.text=String(f.text):t.text=f.name,[t]}}}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../registry\":911,\"./get_trace_color\":1197}],1199:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),formatLabels:t(\"./format_labels\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./arrays_to_calcdata\":1186,\"./attributes\":1187,\"./calc\":1188,\"./cross_trace_calc\":1192,\"./cross_trace_defaults\":1193,\"./defaults\":1194,\"./format_labels\":1196,\"./hover\":1198,\"./marker_colorbar\":1205,\"./plot\":1208,\"./select\":1209,\"./style\":1211,\"./subtypes\":1212}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,f=t(\"./constants\");e.exports=function(t,e){var r,n,a,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,I=S._length,P=E._length,z=e.connectGaps,O=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=f.minTolerance,j=t.length,U=new Array(j),V=0;function q(r){var n=t[r];if(!n)return!1;var a=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(a===i){if(C&&(a=S.c2p(n.x,!0)),a===i)return!1;L&&l===i&&(a*=Math.abs(S._m*P*(S._m>0?o:s)/(E._m*I*(E._m>0?o:s)))),a*=1e3}if(l===i){if(L&&(l=E.c2p(n.y,!0)),l===i)return!1;l*=1e3}return[a,l]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/I,n=t[1]/P,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==M&&H(r,n,M,A)&&(i=0),i&&e&&H(r,n,e[0]/I,e[1]/P)&&(i=0),(1+f.toleranceGrowth*i)*O}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,Q,$,tt=f.maxScreensAway,et=-I*tt,rt=I*(1+tt),nt=-P*tt,it=P*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ft(t){if(M=t[0]/I,A=t[1]/P,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else Q=$(U[V-1],t)[0],U[V++]=Q;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut($(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?$=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?$=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)||(n&&r.push(n),i&&r.push(i)),r}:\"hvh\"===D?$=lt(0,et,rt):\"vhv\"===D&&($=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ft(n),r++;r<j;r++){if(!(h=q(r))){if(z)continue;break}if(R&&e.simplify){var ht=q(r+1);if(y=Y(h,n),F&&(0===V||V===j-1)||!(y<G(h,ht)*N)){for(m=[(h[0]-n[0])/y,(h[1]-n[1])/y],p=n,x=y,b=w=T=0,g=!1,a=h,r++;r<t.length;r++){if(d=ht,ht=q(r+1),!d){if(z)continue;break}if(k=(v=[d[0]-n[0],d[1]-n[1]])[0]*m[1]-v[1]*m[0],w=Math.min(w,k),(T=Math.max(T,k))-w>G(d,ht))break;a=d,(_=v[0]*m[0]+v[1]*m[1])>x?(x=_,h=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ft(h),a!==p&&ft(p)):(p!==n&&ft(p),a!==h&&ft(h)),ft(a),r>=t.length||!d)break;ft(d),n=d}}else ft(h)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./constants\":1191}],1202:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1203:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,f=-1,h=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=h,h++):i.fill in n&&p>=0?l=p:(l=p=h,h++),l<f&&(u=!0),i._groupIndex=f=l;var d=r.slice();u&&d.sort((function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index}));var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":241}],1205:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1206:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),f=(t.line||{}).color;(c=c||{},f&&(r=f),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",f&&!Array.isArray(f)&&e.marker.color!==f?f:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").dateTick0,i=t(\"../../constants/numerical\").ONEWEEK;function a(t,e){return n(e,t%i==0?1:0)}e.exports=function(t,e,r,n,i){if(i||(i={x:!0,y:!0}),i.x){var o=n(\"xperiod\");o&&(n(\"xperiod0\",a(o,e.xcalendar)),n(\"xperiodalignment\"))}if(i.y){var s=n(\"yperiod\");s&&(n(\"yperiod0\",a(s,e.ycalendar)),n(\"yperiodalignment\"))}}},{\"../../constants/numerical\":753,\"../../lib\":778}],1208:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),f=t(\"./link_traces\"),h=t(\"../../lib/polygon\").tester;function p(t,e,r,f,p,d,g){var m;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),f=n.extent(a.simpleMap(l.range,l.r2c)),h=i[0].trace;if(!c.hasMarkers(h))return;var p=h.marker.maxdisplayed;if(0===p)return;var d=i.filter((function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=f[0]&&t.y<=f[1]})),g=Math.ceil(d.length/p),m=0;o.forEach((function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&m++}));var v=Math.round(m*g/3+Math.floor(m/3)*g/7.1);i.forEach((function(t){delete t.vis})),d.forEach((function(t,e){0===Math.round((e+v)%g)&&(t.vis=!0)}))}(0,e,r,f,p);var v=!!g&&g.duration>0;function y(t){return v?t.transition():t}var x=r.xaxis,b=r.yaxis,_=f[0].trace,w=_.line,T=n.select(d),k=o(T,\"g\",\"errorbars\"),M=o(T,\"g\",\"lines\"),A=o(T,\"g\",\"points\"),S=o(T,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,k,r,g),!0===_.visible){var E,C;y(T).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),f[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=T;var I,P,z=\"\",O=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,O=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(f),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(f,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),m=0;m<G.length;m++)_._polygons[m]=h(G[m]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(I=R(e),P=B(e),q?L?(q+=\"L\"+I.substr(1),H=P+\"L\"+H.substr(1)):(q+=\"Z\"+I,H=P+\"Z\"+H):(q=I,H=P),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(f),t)y(r.style(\"opacity\",0).attr(\"d\",I).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",I),l.singleLineStyle(f,i)}}}}}var W=M.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(f),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(O)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),A.datum(f),S.datum(f),function(e,i,a){var o,u=a[0].trace,f=c.hasMarkers(u),h=c.hasText(u),p=tt(u),d=et,g=et;if(f||h){var m=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?m=w?K:J:_&&!w&&(m=Q),f&&(d=m),h&&(g=m)}var T,k=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);v&&k.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),f&&(T=l.makePointStyleFns(u)),o.each((function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,T,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()})),v?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each((function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()})),o.selectAll(\"text\").call(l.textPointStyle,u,t).each((function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each((function(){y(n.select(this)).attr({x:e,y:r})}))})),o.exit().remove()}(A,S,f);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(A,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter((function(t){return!t.gap&&t.vis}))}function K(t){return t.filter((function(t){return t.vis}))}function Q(t){return t.filter((function(t){return!t.gap}))}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,h,d=!a,g=!!a&&a.duration>0,m=f(t,e,r);((u=i.selectAll(\"g.trace\").data(m,(function(t){return t[0].trace.uid}))).enter().append(\"g\").attr(\"class\",(function(t){return\"trace scatter trace\"+t[0].trace.uid})).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each((function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each((function(t){a[t]=null})).remove(),u.order().each((function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")}))}))}(t,u,e),g)?(c&&(h=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",(function(){h&&h()})).each(\"interrupt\",(function(){h&&h()})).each((function(){i.selectAll(\"g.trace\").each((function(r,n){p(t,n,e,r,m,this,a)}))}))):u.each((function(r,n){p(t,n,e,r,m,this,a)}));d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/polygon\":790,\"../../registry\":911,\"./line_points\":1201,\"./link_traces\":1203,\"./subtypes\":1212,d3:169}],1209:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],f=s[0].trace;if(!n.hasMarkers(f)&&!n.hasText(f))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1212}],1210:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var f={orientation:e.x&&!e.y?\"h\":\"v\"},h=0;h<n.length;h++){var p=n[h],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],m=\"orientation\"===p;if((g||u)&&(c[p]=i(p,f[p]),m&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],m))))for(var v=0;v<c.traces.length-1;v++){var y=c.traces[v];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1211:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.selectAll(\"g.points\").each((function(e){o(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.text\").each((function(e){s(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":665,\"../../registry\":911,d3:169}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":778}],1213:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":778}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":778,\"../../registry\":911}],1215:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../plots/attributes\"),l=t(\"../../constants/gl3d_dashes\"),c=t(\"../../constants/gl3d_markers\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,p=n.marker,d=p.line,g=u({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},i(\"line\"));var m=e.exports=f({x:n.x,y:n.y,z:{valType:\"data_array\"},text:u({},n.text,{}),texttemplate:o({},{}),hovertext:u({},n.hovertext,{}),hovertemplate:a(),mode:u({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:u({symbol:{valType:\"enumerated\",values:Object.keys(c),dflt:\"circle\",arrayOk:!0},size:u({},p.size,{dflt:8}),sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode,opacity:u({},p.opacity,{arrayOk:!1}),colorbar:p.colorbar,line:u({width:u({},d.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:u({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:u({},n.textfont.family,{arrayOk:!1})},hoverinfo:u({},s.hoverinfo)},\"calc\",\"nested\");m.x.editType=m.y.editType=m.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":650,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1216:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/colorscale_calc\":1190}],1217:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],f=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(f,!0)-c)*r],u>0){var h=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=h),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,h)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":911}],1218:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/make_bubble_size_func\"),h=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"../../plots/cartesian/axes\"),g=t(\"../../components/fx/helpers\").appendArrayPointValue,m=t(\"./calc_errors\");function v(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=v.prototype;function x(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function b(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function T(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function k(t,e){var r,n,i,a,o,s,h=[],p=t.fullSceneLayout,v=t.dataScale,y=p.xaxis,k=p.yaxis,M=p.zaxis,A=e.marker,S=e.line,E=e.x||[],C=e.y||[],L=e.z||[],I=E.length,P=e.xcalendar,z=e.ycalendar,O=e.zcalendar;for(o=0;o<I;o++)r=y.d2l(E[o],0,P)*v[0],n=k.d2l(C[o],0,z)*v[1],i=M.d2l(L[o],0,O)*v[2],h[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(I),o=0;o<I;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,I):I,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var U={x:E[o],y:C[o],z:L[o]},V={xLabel:D(\"xaxis\",E[o]),yLabel:D(\"yaxis\",C[o]),zLabel:D(\"zaxis\",L[o])},q={};g(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),V,F,q,U,H)}}if(a={position:h,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(S,1,I),a.lineWidth=S.width,a.lineDashes=S.dash),\"marker\"in e){var G=f(e);a.scatterColor=u(A,1,I),a.scatterSize=T(A.size,I,_,20,G),a.scatterMarker=T(A.symbol,I,w,\"\\u25cf\"),a.scatterLineWidth=A.line.width,a.scatterLineColor=u(A.line,1,I),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),a.textColor=u(e.textfont,1,I),a.textSize=T(e.textfont.size,I,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var Y=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(a.project[o]=W.show)&&(a.projectOpacity[o]=W.opacity,a.projectScale[o]=W.scale)}a.errorBounds=m(e,v,p);var X=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=X.color,a.errorLineWidth=X.lineWidth,a.errorCapSize=X.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function M(t){if(l.isArrayOrTypedArray(t)){var e=t[0];return l.isArrayOrTypedArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map((function(t){return Math.round(255*t)}))+\")\"}return null}function A(t){return l.isArrayOrTypedArray(t)?4===t.length&&\"number\"==typeof t[0]?M(t):t.map(M):null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,f=h.solid;this.data=t;var p=k(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in h&&(f=h[p.lineDashes]),this.color=A(p.scatterColor)||A(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:f[0],dashScale:f[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var f=u[n],h=0;h<f.length;++h)f[h]=l[f[h]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new v(t,e.uid);return r.update(e),r}},{\"../../components/fx/helpers\":679,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../scatter/make_bubble_size_func\":1204,\"./calc_errors\":1217,\"delaunay-triangulate\":171,\"gl-error3d\":266,\"gl-line3d\":275,\"gl-mesh3d\":309,\"gl-scatter3d\":330}],1219:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,f,u)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),a.hasLines(e)&&(f(\"connectgaps\"),s(t,e,r,u,f)),a.hasMarkers(e)&&o(t,e,r,u,f,{noSelect:!0}),a.hasText(e)&&(f(\"texttemplate\"),l(t,e,u,f,{noSelect:!0}));var h=(e.line||{}).color,p=(e.marker||{}).color;f(\"surfaceaxis\")>=0&&f(\"surfacecolor\",h||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var m=\"projection.\"+d[g];f(m+\".show\")&&(f(m+\".opacity\"),f(m+\".scale\"))}var v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,h||p||r,{axis:\"z\"}),v(t,e,h||p||r,{axis:\"y\",inherit:\"z\"}),v(t,e,h||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1215}],1220:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../constants/gl3d_markers\":751,\"../../plots/gl3d\":870,\"./attributes\":1215,\"./calc\":1216,\"./convert\":1218,\"./defaults\":1219}],1221:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=n.line,f=c.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:l({},n.mode,{dflt:\"markers\"}),text:l({},n.text,{}),texttemplate:o({editType:\"plot\"},{keys:[\"a\",\"b\",\"text\"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:f.width,editType:\"calc\"},s(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},s(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1222:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,f,h=e._length,p=new Array(h),d=!1;for(c=0;c<h;c++)if(u=e.a[c],f=e.b[c],n(u)&&n(f)){var g=r.ab2xy(+u,+f,!0),m=r.isVisible(+u,+f);m||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:f,vis:m}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,h),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":981,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1223:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),m=Math.min(d.length,g.length);if(m){e._length=m,p(\"text\"),p(\"texttemplate\"),p(\"hovertext\"),p(\"mode\",m<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&c(t,e,h,p);var v=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),v.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),\"fills\"!==p(\"hoveron\",v.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1221}],1224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1225:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r={},n=e._carpet,i=n.ab2ij([t.a,t.b]),a=Math.floor(i[0]),o=i[0]-a,s=Math.floor(i[1]),l=i[1]-s,c=n.evalxy([],a,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1226:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,f=c-u;return s.x0=Math.max(Math.min(s.x0,f),u),s.x1=Math.max(Math.min(s.x1,f),u),o}var h=s.cd[s.index];s.a=h.a,s.b=h.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=p._module.formatLabels(h,p);s.yLabel=g.yLabel,delete s.text;var m=[];if(!p.hovertemplate){var v=(h.hi||p.hoverinfo).split(\"+\");-1!==v.indexOf(\"all\")&&(v=[\"a\",\"b\",\"text\"]),-1!==v.indexOf(\"a\")&&y(d.aaxis,h.a),-1!==v.indexOf(\"b\")&&y(d.baxis,h.b),m.push(\"y: \"+s.yLabel),-1!==v.indexOf(\"text\")&&i(h,p,m),s.extraText=m.join(\"<br>\")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,m.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":778,\"../scatter/hover\":1198}],1227:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1221,\"./calc\":1222,\"./defaults\":1223,\"./event_data\":1224,\"./format_labels\":1225,\"./hover\":1226,\"./plot\":1228}],1228:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,f={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,f,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":665,\"../../plots/cartesian/axes\":828,\"../scatter/plot\":1208}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,f=a.marker,h=a.line,p=f.line;e.exports=u({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\",\"geojson-id\"],dflt:\"ISO-3\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:{valType:\"string\",editType:\"calc\",dflt:\"id\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"location\",\"text\"]}),hovertext:c({},a.hovertext,{}),textfont:a.textfont,textposition:a.textposition,line:{color:h.color,width:h.width,dash:l},connectgaps:a.connectgaps,marker:c({symbol:f.symbol,opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,colorbar:f.colorbar,line:c({width:p.width},s(\"marker.line\")),gradient:f.gradient},s(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:a.fillcolor,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1230:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;function c(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,u=Array.isArray(e.locations),f=u?e.locations.length:e._length,h=new Array(f);r=e.geojson?function(t){return c(t)||n(t)}:c;for(var p=0;p<f;p++){var d=h[p]={};if(u){var g=e.locations[p];d.loc=r(g)?g:null}else{var m=e.lon[p],v=e.lat[p];n(m)&&n(v)?d.lonlat=[+m,+v]:d.lonlat=[i,i]}}return o(h,e),a(t,e),s(h,e),f&&(h[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),h}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}var h,p=f(\"locations\");if(p&&p.length){var d,g=f(\"geojson\");(\"string\"==typeof g&&\"\"!==g||n.isPlainObject(g))&&(d=\"geojson-id\"),\"geojson-id\"===f(\"locationmode\",d)&&f(\"featureidkey\"),h=p.length}else{var m=f(\"lon\")||[],v=f(\"lat\")||[];h=Math.min(m.length,v.length)}h?(e._length=h,f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,f),f(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,f,{gradient:!0}),i.hasText(e)&&(f(\"texttemplate\"),s(t,e,u,f)),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)):e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1229}],1232:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.geo]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/get_trace_color\"),o=t(\"../../lib\").fillText,s=t(\"./attributes\");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=h.projection.isLonLatOverEdges,d=h.project;if(n.getClosest(l,(function(t){var n=t.lonlat;if(n[0]===i)return 1/0;if(p(n))return 1/0;var a=d(n),o=d([e,r]),s=Math.abs(a[0]-o[0]),l=Math.abs(a[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[u.c2p(m),f.c2p(m)],y=g.mrc||1;t.x0=v[0]-y,t.x1=v[0]+y,t.y0=v[1]-y,t.y1=v[1]+y,t.loc=g.loc,t.lon=m[0],t.lat=m[1];var x={};x[c.geo]={_subplot:h};var b=c._module.formatLabels(g,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=a(c,g),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?s.hoverinfo.flags:i.split(\"+\"),l=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),f=-1!==a.indexOf(\"text\"),h=[];function p(t){return t+\"\\xb0\"}l?h.push(e.loc):c&&u?h.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?h.push(n.lon+p(r.lonLabel)):u&&h.push(n.lat+p(r.latLabel));f&&o(e,t,h);return h.join(\"<br>\")}(c,g,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197,\"./attributes\":1229}],1235:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":860,\"../scatter/marker_colorbar\":1205,\"../scatter/style\":1211,\"./attributes\":1229,\"./calc\":1230,\"./defaults\":1231,\"./event_data\":1232,\"./format_labels\":1233,\"./hover\":1234,\"./plot\":1236,\"./select\":1237,\"./style\":1238}],1236:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/topojson_utils\").getTopojsonFeatures,o=t(\"../../lib/geojson_utils\"),s=t(\"../../lib/geo_location_utils\"),l=t(\"../../plots/cartesian/autorange\").findExtremes,c=t(\"../../constants/numerical\").BADNUM,u=t(\"../scatter/calc\").calcMarkerSize,f=t(\"../scatter/subtypes\"),h=t(\"./style\");e.exports={calcGeoJSON:function(t,e){var r,n,i=t[0].trace,o=e[i.geo],f=o._subplot,h=i._length;if(Array.isArray(i.locations)){var p=i.locationmode,d=\"geojson-id\"===p?s.extractTraceFeature(t):a(i,f.topojson);for(r=0;r<h;r++){n=t[r];var g=\"geojson-id\"===p?n.fOut:s.locationToFeature(p,n.loc,d);n.lonlat=g?g.properties.ct:[c,c]}}var m,v,y={padded:!0};if(\"geojson\"===o.fitbounds&&\"geojson-id\"===i.locationmode){var x=s.computeBbox(s.getTraceGeojson(i));m=[x[0],x[2]],v=[x[1],x[3]]}else{for(m=new Array(h),v=new Array(h),r=0;r<h;r++)n=t[r],m[r]=n.lonlat[0],v[r]=n.lonlat[1];y.ppad=u(i,h)}i._extremes.lon=l(o.lonaxis._ax,m,y),i._extremes.lat=l(o.lataxis._ax,v,y)},plot:function(t,e,r){var a=e.layers.frontplot.select(\".scatterlayer\"),s=i.makeTraceGroups(a,r,\"trace scattergeo\");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll(\"*\").remove(),s.each((function(e){var r=n.select(this),a=e[0].trace;if(f.hasLines(a)||\"none\"!==a.fill){var s=o.calcTraceToLineCoords(e),c=\"none\"!==a.fill?o.makePolygon(s):o.makeLine(s);r.selectAll(\"path.js-line\").data([{geojson:c,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}f.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each((function(t){l(t,this)})),f.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each((function(t){l(t,this)})),h(t,e)}))}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"../scatter/calc\":1188,\"../scatter/subtypes\":1212,\"./style\":1238,d3:169}],1237:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,f=t.yaxis,h=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=f.c2p(a),e.contains([o,s],null,l,t)?(h.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return h}},{\"../../constants/numerical\":753,\"../scatter/subtypes\":1212}],1238:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each((function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)}))}(t,e)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../scatter/style\":1211,d3:169}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,f=u.line,h=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:f.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");h.x.editType=h.y.editType=h.x0.editType=h.y0.editType=\"calc+clearAxisTypes\",h.hovertemplate=i.hovertemplate,h.texttemplate=i.texttemplate},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../scatter/attributes\":1187,\"./constants\":1241}],1240:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../../plots/cartesian/align_period\"),l=t(\"../scatter/calc\"),c=l.calcMarkerSize,u=l.calcAxisExpansion,f=l.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),p=t(\"./convert\"),d=t(\"./scene_update\"),g=t(\"../../constants/numerical\").BADNUM,m=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,l,y=t._fullLayout,x=a.getFromId(t,e.xaxis),b=a.getFromId(t,e.yaxis),_=y._plots[e.xaxis+e.yaxis],w=e._length,T=w>=m,k=2*w,M={},A=x.makeCalcdata(e,\"x\"),S=b.makeCalcdata(e,\"y\"),E=s(e,x,\"x\",A),C=s(e,b,\"y\",S);e._x=E,e._y=C,e.xperiodalignment&&(e._origX=A),e.yperiodalignment&&(e._origY=S);var L=new Array(k);for(r=0;r<w;r++)o=E[r],l=C[r],L[2*r]=o===g?NaN:o,L[2*r+1]=l===g?NaN:l;if(\"log\"===x.type)for(r=0;r<k;r+=2)L[r]=x.c2l(L[r]);if(\"log\"===b.type)for(r=1;r<k;r+=2)L[r]=b.c2l(L[r]);if(T&&\"log\"!==x.type&&\"log\"!==b.type)M.tree=n(L);else{var I=M.ids=new Array(w);for(r=0;r<w;r++)I[r]=r}h(t,e);var P,z=function(t,e,r,n,a,o){var s=p.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,p.linePositions(t,r,n));if(s.errorX||s.errorY){var l=p.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},p.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},p.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},p.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,L,E,C),O=d(t,_);return f(y,e),T?z.marker&&(P=2*(z.marker.sizeAvg||Math.max(z.marker.size,3))):P=c(e,w),u(t,e,x,b,E,C,P),z.errorX&&v(e,x,z.errorX),z.errorY&&v(e,b,z.errorY),z.fill&&!O.fill2d&&(O.fill2d=!0),z.marker&&!O.scatter2d&&(O.scatter2d=!0),z.line&&!O.line2d&&(O.line2d=!0),!z.errorX&&!z.errorY||O.error2d||(O.error2d=!0),z.text&&!O.glText&&(O.glText=!0),z.marker&&(z.marker.snap=w),O.lineOptions.push(z.line),O.errorXOptions.push(z.errorX),O.errorYOptions.push(z.errorY),O.fillOptions.push(z.fill),O.markerOptions.push(z.marker),O.markerSelectedOptions.push(z.markerSel),O.markerUnselectedOptions.push(z.markerUnsel),O.textOptions.push(z.text),O.textSelectedOptions.push(z.textSel),O.textUnselectedOptions.push(z.textUnsel),O.selectBatch.push([]),O.unselectBatch.push([]),M._scene=O,M.index=O.count,M.x=E,M.y=C,M.positions=L,O.count++,[{x:!1,y:!1,t:M,trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"./constants\":1241,\"./convert\":1242,\"./scene_update\":1250,\"@plotly/point-cluster\":57}],1241:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1242:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/subtypes\"),h=t(\"../scatter/make_bubble_size_func\"),p=t(\"./helpers\"),d=t(\"./constants\"),g=t(\"../../constants/interactions\").DESELECTDIM,m={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=t(\"../../components/fx/helpers\").appendArrayPointValue;function y(t,e){var r,i=t._fullLayout,a=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,f=o.size,h=o.family,p={},d=e.texttemplate;if(d){p.text=[];var g=i._d3locale,m=Array.isArray(d),y=m?Math.min(d.length,a):a,x=m?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,i),w={};v(w,e,r);var T=e._meta||{};p.text.push(s.texttemplateString(x(r),_,g,w,b,T))}}else Array.isArray(e.text)&&e.text.length<a?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<a;r++)p.text[r]=\"\";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var k=c[r].split(/\\s+/);switch(k[1]){case\"left\":p.align.push(\"right\");break;case\"right\":p.align.push(\"left\");break;default:p.align.push(k[1])}switch(k[0]){case\"top\":p.baseline.push(\"bottom\");break;case\"bottom\":p.baseline.push(\"top\");break;default:p.baseline.push(k[0])}}if(Array.isArray(u))for(p.color=new Array(a),r=0;r<a;r++)p.color[r]=u[r];else p.color=u;if(s.isArrayOrTypedArray(f)||Array.isArray(h))for(p.font=new Array(a),r=0;r<a;r++){var M=p.font[r]={};M.size=s.isTypedArray(f)?f[r]:Array.isArray(f)?n(f[r])?f[r]:0:f,M.family=Array.isArray(h)?h[r]:h}else p.font={size:f,family:h};return p}function x(t){var e,r,n=t._length,i=t.marker,o={},l=s.isArrayOrTypedArray(i.symbol),c=s.isArrayOrTypedArray(i.color),f=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),m=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.isOpenSymbol(i.symbol)),l||c||f||d){o.colors=new Array(n),o.borderColors=new Array(n);var v=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(v[0])){var b=v;for(v=Array(n),e=0;e<n;e++)v[e]=b}for(o.colors=v,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.isOpenSymbol(_)}r&&(y[e]=v[e].slice(),v[e]=v[e].slice(),v[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=E(i.symbol[e]);else o.marker=E(i.symbol);var w,T=h(t);if(g||m){var k,M=o.sizes=new Array(n),A=o.borderSizes=new Array(n),S=0;if(g){for(e=0;e<n;e++)M[e]=T(i.size[e]),S+=M[e];k=S/n}else for(w=T(i.size),e=0;e<n;e++)M[e]=w;if(m)for(e=0;e<n;e++)A[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)A[e]=w;o.sizeAvg=k}else o.size=T(i&&i.size||10),o.borderSizes=T(i.line.width);return o}function b(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=x(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function _(t,e,r){var n={};if(!r)return n;if(r.textfont){var i={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(i.textfont,r.textfont),n=y(t,i)}return n}function w(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var T=d.SYMBOL_SDF_SIZE,k=d.SYMBOL_SIZE,M=d.SYMBOL_STROKE,A={},S=l.symbolFuncs[0](.05*k);function E(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.isDotSymbol(t);return A[t]?A[t]:(e=c&&!o?a(1.1*k)+S:a(k),r=i(e,{w:T,h:T,viewBox:[-k,-k,k,k],stroke:s?M:-M}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(f.hasText(e)&&(n.text=y(t,e),n.textSel=_(t,e,e.selected),n.textUnsel=_(t,e,e.unselected)),f.hasMarkers(e)&&(n.marker=x(e),n.markerSel=b(e,e.selected),n.markerUnsel=b(e,e.unselected),!e.unselected&&s.isArrayOrTypedArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=g*i[r]}if(f.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(d.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=w(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=w(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:x,markerSelection:b,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(f.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>d.TOO_MANY_POINTS||f.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var h=n[0],p=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=h,n[i+1]=p):(h=n[i],p=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),f=r.length/2,h={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*f),d=1/0,g=-1/0,m=0,v=0;m<f;m++,v+=4){var y=t[m];if(n(y)){var x=r[2*m+c],b=l(y,m),_=b[0],w=b[1];if(n(_)&&n(w)){var T=y-_,k=y+w;p[v+u[0]]=x-i.c2l(T),p[v+u[1]]=i.c2l(k)-x,p[v+u[2]]=0,p[v+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}h[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),h},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(f.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,h=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,g=m[p],v=m[d],y=u?u/.8+1:0,x=-v*y-.5*v;o.offset[i]=[g*y/h,x/h]}}return o}}},{\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"./constants\":1241,\"./helpers\":1246,\"color-normalize\":125,\"fast-isnumeric\":241,\"svg-path-sdf\":574}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./helpers\"),o=t(\"./attributes\"),s=t(\"../scatter/constants\"),l=t(\"../scatter/subtypes\"),c=t(\"../scatter/xy_defaults\"),u=t(\"../scatter/period_defaults\"),f=t(\"../scatter/marker_defaults\"),h=t(\"../scatter/line_defaults\"),p=t(\"../scatter/fillcolor_defaults\"),d=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,g){function m(r,i){return n.coerce(t,e,o,r,i)}var v=!!t.marker&&a.isOpenSymbol(t.marker.symbol),y=l.isBubble(t),x=c(t,e,g,m);if(x){u(t,e,g,m);var b=x<s.PTS_LINESONLY?\"lines+markers\":\"lines\";m(\"text\"),m(\"hovertext\"),m(\"hovertemplate\"),m(\"mode\",b),l.hasLines(e)&&(m(\"connectgaps\"),h(t,e,r,g,m),m(\"line.shape\")),l.hasMarkers(e)&&(f(t,e,r,g,m),m(\"marker.line.width\",v||y?1:0)),l.hasText(e)&&(m(\"texttemplate\"),d(t,e,g,m));var _=(e.line||{}).color,w=(e.marker||{}).color;m(\"fill\"),\"none\"!==e.fill&&p(t,e,r,m);var T=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");T(t,e,_||w||r,{axis:\"y\"}),T(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,m)}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/period_defaults\":1207,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatter/xy_defaults\":1214,\"./attributes\":1239,\"./helpers\":1246}],1244:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,f=c.selectBatch[u],h=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},m=n.extendFlat({},p);if(f.length||h.length){var v=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(m.color=new Array(s._length),e=0;e<f.length;e++)r=f[e],m.color[r]=v||(b?x[r]:x);for(e=0;e<h.length;e++){r=h[e];var _=b?x[r]:x;m.color[r]=y||(v?_:i.addOpacity(_,a))}}c.glText[u].update(m)}}},{\"../../components/color\":643,\"../../constants/interactions\":752,\"../../lib\":778}],1245:[function(t,e,r){\"use strict\";var n=t(\"../scatter/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"x\"in t||(t.x=e._x[i]),\"y\"in t||(t.y=e._y[i]),n(t,e,r)}},{\"../scatter/format_labels\":1196}],1246:[function(t,e,r){\"use strict\";var n=t(\"./constants\");r.isOpenSymbol=function(t){return\"string\"==typeof t?n.OPEN_RE.test(t):t%200>100},r.isDotSymbol=function(t){return\"string\"==typeof t?n.DOT_RE.test(t):t>200}},{\"./constants\":1241}],1247:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,f=t.index,h={pointNumber:f,x:e[f],y:r[f]};h.tx=Array.isArray(o.text)?o.text[f]:o.text,h.htx=Array.isArray(o.hovertext)?o.hovertext[f]:o.hovertext,h.data=Array.isArray(o.customdata)?o.customdata[f]:o.customdata,h.tp=Array.isArray(o.textposition)?o.textposition[f]:o.textposition;var p=o.textfont;p&&(h.ts=i.isArrayOrTypedArray(p.size)?p.size[f]:p.size,h.tc=Array.isArray(p.color)?p.color[f]:p.color,h.tf=Array.isArray(p.family)?p.family[f]:p.family);var d=o.marker;d&&(h.ms=i.isArrayOrTypedArray(d.size)?d.size[f]:d.size,h.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[f]:d.opacity,h.mx=i.isArrayOrTypedArray(d.symbol)?d.symbol[f]:d.symbol,h.mc=i.isArrayOrTypedArray(d.color)?d.color[f]:d.color);var g=d&&d.line;g&&(h.mlc=Array.isArray(g.color)?g.color[f]:g.color,h.mlw=i.isArrayOrTypedArray(g.width)?g.width[f]:g.width);var m=d&&d.gradient;m&&\"none\"!==m.type&&(h.mgt=Array.isArray(m.type)?m.type[f]:m.type,h.mgc=Array.isArray(m.color)?m.color[f]:m.color);var v=s.c2p(h.x,!0),y=l.c2p(h.y,!0),x=h.mrc||1,b=o.hoverlabel;b&&(h.hbg=Array.isArray(b.bgcolor)?b.bgcolor[f]:b.bgcolor,h.hbc=Array.isArray(b.bordercolor)?b.bordercolor[f]:b.bordercolor,h.hts=i.isArrayOrTypedArray(b.font.size)?b.font.size[f]:b.font.size,h.htc=Array.isArray(b.font.color)?b.font.color[f]:b.font.color,h.htf=Array.isArray(b.font.family)?b.font.family[f]:b.font.family,h.hnl=i.isArrayOrTypedArray(b.namelength)?b.namelength[f]:b.namelength);var _=o.hoverinfo;_&&(h.hi=Array.isArray(_)?_[f]:_);var w=o.hovertemplate;w&&(h.ht=Array.isArray(w)?w[f]:w);var T={};T[t.index]=h;var k=o._origX,M=o._origY,A=i.extendFlat({},t,{color:a(o,h),x0:v-x,x1:v+x,xLabelVal:k?k[f]:h.x,y0:y-x,y1:y+x,yLabelVal:M?M[f]:h.y,cd:T,distance:c,spikeDistance:u,hovertemplate:h.ht});return h.htx?A.text=h.htx:h.tx?A.text=h.tx:o.text&&(A.text=o.text),i.fillText(h,o,A),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(h,o,A),A}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,f,h,p,d=t.cd,g=d[0].t,m=d[0].trace,v=t.xa,y=t.ya,x=g.x,b=g.y,_=v.c2p(e),w=y.c2p(r),T=t.distance;if(g.tree){var k=v.p2c(_-T),M=v.p2c(_+T),A=y.p2c(w-T),S=y.p2c(w+T);i=\"x\"===n?g.tree.range(Math.min(k,M),Math.min(y._rl[0],y._rl[1]),Math.max(k,M),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(k,M),Math.min(A,S),Math.max(k,M),Math.max(A,S))}else i=g.ids;var E=T;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(v.c2p(s)-_))<E&&(E=u,f=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+f*f),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=v.c2p(s)-_,f=y.c2p(l)-w,(h=Math.sqrt(u*u+f*f))<E&&(E=p=h,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:[o(t,x,b,m)]},calcHover:o}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/get_trace_color\":1197}],1248:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/cross_trace_defaults\":1193,\"../scatter/marker_colorbar\":1205,\"./attributes\":1239,\"./calc\":1240,\"./defaults\":1243,\"./format_labels\":1245,\"./hover\":1247,\"./plot\":1249,\"./select\":1251}],1249:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../components/dragelement/helpers\").selectMode,c=t(\"../../lib/prepare_regl\"),u=t(\"../scatter/subtypes\"),f=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;function p(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}e.exports=function(t,e,r){if(r.length){var d,g,m=t._fullLayout,v=e._scene,y=e.xaxis,x=e.yaxis;if(v)if(c(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var b=v.count,_=m._glcanvas.data()[0].regl;if(f(t,e,r),v.dirty){if(!0===v.error2d&&(v.error2d=a(_)),!0===v.line2d&&(v.line2d=i(_)),!0===v.scatter2d&&(v.scatter2d=n(_,{constPointSize:!0})),!0===v.fill2d&&(v.fill2d=i(_)),!0===v.glText)for(v.glText=new Array(b),d=0;d<b;d++)v.glText[d]=new o(_);if(v.glText){if(b>v.glText.length){var w=b-v.glText.length;for(d=0;d<w;d++)v.glText.push(new o(_))}else if(b<v.glText.length){var T=v.glText.length-b;v.glText.splice(b,T).forEach((function(t){t.destroy()}))}for(d=0;d<b;d++)v.glText[d].update(v.textOptions[d])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map((function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t})),v.line2d.update(v.lineOptions)),v.error2d){var k=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(k)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,b),v.fill2d&&(v.fillOptions=v.fillOptions.map((function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var f,h,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(f=0;f<d.length&&isNaN(d[f+1]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h+1]);)h-=2;0!==d[f+1]&&(p=[d[f],0]),p=p.concat(d.slice(f,h+2)),0!==d[h+1]&&(p=p.concat([d[h],0]))}else if(\"tozerox\"===s.fill){for(f=0;f<d.length&&isNaN(d[f]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h]);)h-=2;0!==d[f]&&(p=[0,d[f+1]]),p=p.concat(d.slice(f,h+2)),0!==d[h]&&(p=p.concat([0,d[h+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var g=s._nexttrace;if(g){var m=v.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=g.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=v.lineOptions[e-1].positions,w=p.length/2,T=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(T.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=T}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}})),v.fill2d.update(v.fillOptions))}var M=m.dragmode,A=l(M),S=m.clickmode.indexOf(\"select\")>-1;for(d=0;d<b;d++){var E=r[d][0],C=E.trace,L=E.t,I=L.index,P=C._length,z=L.x,O=L.y;if(C.selectedpoints||A||S){if(A||(A=!0),C.selectedpoints){var D=v.selectBatch[I]=s.selIndices2selPoints(C),R={};for(g=0;g<D.length;g++)R[D[g]]=1;var F=[];for(g=0;g<P;g++)R[g]||F.push(g);v.unselectBatch[I]=F}var B=L.xpx=new Array(P),N=L.ypx=new Array(P);for(g=0;g<P;g++)B[g]=y.c2p(z[g]),N[g]=x.c2p(O[g])}else L.xpx=L.ypx=null}if(A){if(v.select2d||(v.select2d=n(m._glcanvas.data()[1].regl)),v.scatter2d){var j=new Array(b);for(d=0;d<b;d++)j[d]=v.selectBatch[d].length||v.unselectBatch[d].length?v.markerUnselectedOptions[d]:{};v.scatter2d.update(j)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach((function(t){var e=((t||[])[0]||{}).trace||{};u.hasText(e)&&h(t)}))}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var U={viewport:p(m,y,x),range:[(y._rl||y.range)[0],(x._rl||x.range)[0],(y._rl||y.range)[1],(x._rl||x.range)[1]]},V=s.repeat(U,v.count);v.fill2d&&v.fill2d.update(V),v.line2d&&v.line2d.update(V),v.error2d&&v.error2d.update(V.concat(V)),v.scatter2d&&v.scatter2d.update(V),v.select2d&&v.select2d.update(V),v.glText&&v.glText.forEach((function(t){t.update(U)}))}else v.init()}}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../lib/prepare_regl\":791,\"../scatter/link_traces\":1203,\"../scatter/subtypes\":1212,\"./edit_style\":1244,\"gl-text\":352,\"regl-error2d\":534,\"regl-line2d\":535,\"regl-scatter2d\":537}],1250:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,f=0;f<t;f++){if(e&&r.fillOrder[f]&&e.draw(r.fillOrder[f]),a&&r.lineOptions[f]&&a.draw(f),i&&(r.errorXOptions[f]&&i.draw(f),r.errorYOptions[f]&&i.draw(f+t)),o&&r.markerOptions[f])if(u[f].length){var h=n.repeat([],r.count);h[f]=u[f],o.draw(h)}else c[f].length||o.draw(f);s[f]&&r.textOptions[f]&&s[f].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach((function(t){t.destroy&&t.destroy()})),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":778}],1251:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,f=s._scene,h=s.index;if(!f)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var m=[],v=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(m.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):v.push(y);if(d){var x=f.scatter2d;if(m.length||v.length){if(!f.selectBatch[h].length&&!f.unselectBatch[h].length){var b=new Array(f.count);b[h]=f.markerUnselectedOptions[h],x.update.apply(x,b)}}else{var _=new Array(f.count);_[h]=f.markerOptions[h],x.update.apply(x,_)}}return f.selectBatch[h]=m,f.unselectBatch[h]=v,p&&i(r),a}},{\"../scatter/subtypes\":1212,\"./edit_style\":1244}],1252:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scattergeo/attributes\"),o=t(\"../scatter/attributes\"),s=t(\"../../plots/mapbox/layout_attributes\"),l=t(\"../../plots/attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=a.line,p=a.marker;e.exports=f({lon:a.lon,lat:a.lat,mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:u({},o.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c(\"marker\")),fill:a.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/mapbox/layout_attributes\":887,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergeo/attributes\":1229}],1253:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),f=t(\"../../plots/mapbox/convert_text_opts\"),h=t(\"../../components/fx/helpers\").appendArrayPointValue,p=t(\"../../lib/svg_text_utils\").NEWLINES,d=t(\"../../lib/svg_text_utils\").BR_TAG_ALL;function g(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function m(t,e){return i.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function y(t){return t[0]===a}e.exports=function(t,e){var r,a=e[0].trace,x=!0===a.visible&&0!==a._length,b=\"none\"!==a.fill,_=u.hasLines(a),w=u.hasMarkers(a),T=u.hasText(a),k=w&&\"circle\"===a.marker.symbol,M=w&&\"circle\"!==a.marker.symbol,A=g(),S=g(),E=g(),C=g(),L={fill:A,line:S,circle:E,symbol:C};if(!x)return L;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(A.geojson=o.makePolygon(r),A.layout.visibility=\"visible\",i.extendFlat(A.paint,{\"fill-color\":a.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility=\"visible\",i.extendFlat(S.paint,{\"line-width\":a.line.width,\"line-color\":a.line.color,\"line-opacity\":a.opacity})),k){var I=function(t){var e,r,a,o,u=t[0].trace,f=u.marker,h=u.selectedpoints,p=i.isArrayOrTypedArray(f.color),d=i.isArrayOrTypedArray(f.size),g=i.isArrayOrTypedArray(f.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(f):i.identity);d&&(a=c(u));g&&(o=function(t){return m(n(t)?+i.constrain(t,0,1):0)});var v,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),h&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(h)for(v=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var T=x[e].properties;v.selectedOpacityFn&&(T.mo=m(v.selectedOpacityFn(T))),v.selectedColorFn&&(T.mcc=v.selectedColorFn(T)),v.selectedSizeFn&&(T.mrc=v.selectedSizeFn(T))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||v&&v.selectedColorFn?{type:\"identity\",property:\"mcc\"}:f.color,mrc:d||v&&v.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(k=f.size,k/2),mo:g||v&&v.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(f.opacity)};var k}(e);E.geojson=I.geojson,E.layout.visibility=\"visible\",i.extendFlat(E.paint,{\"circle-color\":I.mcc,\"circle-radius\":I.mrc,\"circle-opacity\":I.mo})}if((M||T)&&(C.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,a=n.marker||{},o=a.symbol,s=a.angle,l=\"circle\"!==o?m(o):v,c=\"auto\"!==s?m(s,!0):v,f=u.hasText(n)?m(n.text):v,g=[],x=0;x<t.length;x++){var b=t[x];if(!y(b.lonlat)){var _,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[x]||\"\":w,k=n._module.formatLabels(b,n,r),M={};h(M,n,b.i);var A=n._meta||{};_=i.texttemplateString(T,k,r._d3locale,M,b,A)}else _=f(x);_&&(_=_.replace(p,\"\").replace(d,\"\\n\")),g.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:b.lonlat},properties:{symbol:l(x),angle:c(x),text:_}})}}return{type:\"FeatureCollection\",features:g}}(e,t),i.extendFlat(C.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),M&&(i.extendFlat(C.layout,{\"icon-size\":a.marker.size/10}),\"angle\"in a.marker&&\"auto\"!==a.marker.angle&&i.extendFlat(C.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),C.layout[\"icon-allow-overlap\"]=a.marker.allowoverlap,i.extendFlat(C.paint,{\"icon-opacity\":a.opacity*a.marker.opacity,\"icon-color\":a.marker.color})),T)){var P=(a.marker||{}).size,z=f(a.textposition,P);i.extendFlat(C.layout,{\"text-size\":a.textfont.size,\"text-anchor\":z.anchor,\"text-offset\":z.offset}),i.extendFlat(C.paint,{\"text-color\":a.textfont.color,\"text-opacity\":a.opacity})}return L}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"../../lib/svg_text_utils\":803,\"../../plots/mapbox/convert_text_opts\":884,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"fast-isnumeric\":241}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f)){if(f(\"text\"),f(\"texttemplate\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),f(\"below\"),i.hasLines(e)&&(o(t,e,r,u,f,{noDash:!0}),f(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,f,{noLine:!0}),f(\"marker.allowoverlap\"),f(\"marker.angle\");var h=e.marker;\"circle\"!==h.symbol&&(n.isArrayOrTypedArray(h.size)&&(h.size=h.size[0]),n.isArrayOrTypedArray(h.color)&&(h.color=h.color[0]))}i.hasText(e)&&s(t,e,u,f,{noSelect:!0}),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1252}],1255:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=h.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-f.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[i.modHalf(m[0],360)+p,m[1]],y=u.c2p(v),x=f.c2p(v),b=g.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:h};var w=c._module.formatLabels(g,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197}],1258:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/mapbox\":885,\"../scatter/marker_colorbar\":1205,\"../scattergeo/calc\":1230,\"./attributes\":1252,\"./defaults\":1254,\"./event_data\":1255,\"./format_labels\":1256,\"./hover\":1257,\"./plot\":1259,\"./select\":1260}],1259:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.type=\"scattermapbox\",this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(t.gd,e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],f=s[u];i.addSource(u,f),i.addLayer(u,f,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1253}],1260:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var f=o[r],h=f.lonlat;if(h[0]!==a){var p=[n.modHalf(h[0],360),h[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:h[0],lat:h[1]}),f.selected=1):f.selected=0}}return c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/subtypes\":1212}],1261:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"../scatter/attributes\"),s=t(\"../../plots/attributes\"),l=o.line;e.exports={mode:o.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:o.text,texttemplate:i({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:a({},l.shape,{values:[\"linear\",\"spline\"]}),smoothing:l.smoothing,editType:\"calc\"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:a({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:a({},o.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o.fillcolor,hoverinfo:a({},s.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1262:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,f=r[u].radialaxis,h=r[u].angularaxis,p=f.makeCalcdata(e,\"r\"),d=h.makeCalcdata(e,\"theta\"),g=e._length,m=new Array(g),v=0;v<g;v++){var y=p[v],x=d[v],b=m[v]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(f,p,{ppad:_}),o(t,e),s(m,e),l(m,e),m}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1263:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");function h(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:h,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,f,r,i)}var g=h(t,e,p,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&(d(\"texttemplate\"),l(t,e,p,d));var m=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),m.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),d(\"hoveron\",m.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1261}],1264:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a,o,s={},l=r[e.subplot]._subplot;l?(a=l.radialAxis,o=l.angularAxis):(a=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=a.c2l(t.r);s.rLabel=i.tickText(a,c,!0).text;var u=\"degrees\"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=i.tickText(o,u,!0).text,s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1265:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");function i(t,e,r,n){var i=r.radialAxis,a=r.angularAxis;i._hovertitle=\"r\",a._hovertitle=\"\\u03b8\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var f=l.split(\"+\");-1!==f.indexOf(\"all\")&&(f=[\"r\",\"theta\",\"text\"]),-1!==f.indexOf(\"r\")&&u(i,n.rLabel),-1!==f.indexOf(\"theta\")&&u(a,n.thetaLabel),-1!==f.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,i(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:i}},{\"../scatter/hover\":1198}],1266:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1261,\"./calc\":1262,\"./defaults\":1263,\"./format_labels\":1264,\"./hover\":1265,\"./plot\":1267}],1267:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],f=0;f<u.length;f++){var h=u[f],p=h.r;if(p===i)h.x=h.y=i;else{var d=s.c2g(p),g=l.c2g(h.theta);h.x=d*Math.cos(g),h.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":753,\"../scatter/plot\":1208}],1268:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\"),a=t(\"../../plots/template_attributes\").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:a({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../../plots/template_attributes\":906,\"../scattergl/attributes\":1239,\"../scatterpolar/attributes\":1261}],1269:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,f=e._r=c.makeCalcdata(e,\"r\"),h=e._theta=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<f.length&&(f=f.slice(0,p)),p<h.length&&(h=h.slice(0,p)),d.r=f,d.theta=h,n(t,e);var g,m=d.opts=a.style(t,e);return p<s?g=i(e,p):m.marker&&(g=2*(m.marker.sizeAvg||Math.max(m.marker.size,3))),e._extremes.x=o.findExtremes(c,f,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":828,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242}],1270:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d=a(t,e,h,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,h,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,h,p),i.hasText(e)&&(p(\"texttemplate\"),l(t,e,h,p)),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatterpolar/defaults\":1263,\"./attributes\":1268}],1271:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"r\"in t||(t.r=e._r[i]),\"theta\"in t||(t.theta=e._theta[i]),n(t,e,r)}},{\"../scatterpolar/format_labels\":1264}],1272:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var f=t.subplot,h=u.cd[u.index],p=u.trace;if(h.r=s[u.index],h.theta=l[u.index],f.isPtInside(h))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(h,p,f,u),c}}}},{\"../scattergl/hover\":1247,\"../scatterpolar/hover\":1265}],1273:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scattergl/select\":1251,\"./attributes\":1268,\"./calc\":1269,\"./defaults\":1270,\"./format_labels\":1271,\"./hover\":1272,\"./plot\":1274}],1274:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,f=e.angularAxis,h=o(t,e);return r.forEach((function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,m=d.r,v=d.theta,y=d.opts,x=m.slice(),b=v.slice();for(a=0;a<m.length;a++)e.isPtInside({r:m[a],theta:v[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),T=Array(g);for(a=0;a<g;a++){var k,M,A=x[a];if(i(A)){var S=u.c2g(A),E=f.c2g(b[a],p.thetaunit);k=S*Math.cos(E),M=S*Math.sin(E)}else k=M=NaN;w[a]=_[2*a]=k,T[a]=_[2*a+1]=M}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!h.fill2d&&(h.fill2d=!0),y.marker&&!h.scatter2d&&(h.scatter2d=!0),y.line&&!h.line2d&&(h.line2d=!0),y.text&&!h.glText&&(h.glText=!0),h.lineOptions.push(y.line),h.fillOptions.push(y.fill),h.markerOptions.push(y.marker),h.markerSelectedOptions.push(y.markerSel),h.markerUnselectedOptions.push(y.markerUnsel),h.textOptions.push(y.text),h.textSelectedOptions.push(y.textSel),h.textUnselectedOptions.push(y.textUnsel),h.selectBatch.push([]),h.unselectBatch.push([]),d.x=w,d.y=T,d.rawx=w,d.rawy=T,d.r=m,d.theta=v,d.positions=_,d._scene=h,d.index=h.count,h.count++}})),a(t,e,r)}}},{\"../../lib\":778,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"../scattergl/plot\":1249,\"../scattergl/scene_update\":1250,\"@plotly/point-cluster\":57,\"fast-isnumeric\":241}],1275:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=a.marker,f=a.line,h=u.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"a\",\"b\",\"c\",\"text\"]}),hovertext:c({},a.hovertext,{}),line:{color:f.color,width:f.width,dash:l,shape:c({},f.shape,{values:[\"linear\",\"spline\"]}),smoothing:f.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,cliponaxis:a.cliponaxis,fill:c({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:h.width,editType:\"calc\"},s(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},s(\"marker\")),textfont:a.textfont,textposition:a.textposition,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1276:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,f,h,p,d,g=t._fullLayout[e.subplot].sum,m=e.sum||g,v={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!v[f=l[r]]){for(p=v[c[f][0]],d=v[c[f][1]],h=new Array(p.length),u=0;u<p.length;u++)h[u]=m-p[u]-d[u];v[f]=h}var y,x,b,_,w,T,k=e._length,M=new Array(k);for(r=0;r<k;r++)y=v.a[r],x=v.b[r],b=v.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),T=y,w=b-x,M[r]={x:w,y:T,a:y,b:x,c:b}):M[r]={x:!1,y:!1};return s(e,k),i(t,e),a(M,e),o(M,e),M}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1277:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d,g=p(\"a\"),m=p(\"b\"),v=p(\"c\");if(g?(d=g.length,m?(d=Math.min(d,m.length),v&&(d=Math.min(d,v.length))):d=v?Math.min(d,v.length):0):m&&v&&(d=Math.min(m.length,v.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&(p(\"texttemplate\"),c(t,e,h,p));var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1275}],1278:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1279:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot;return i.aLabel=n.tickText(a.aaxis,t.a,!0).text,i.bLabel=n.tickText(a.baxis,t.b,!0).text,i.cLabel=n.tickText(a.caxis,t.c,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1280:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");e.exports=function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var o=a[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),a}var f=o.cd[o.index],h=o.trace,p=o.subplot;o.a=f.a,o.b=f.b,o.c=f.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[h.subplot]={_subplot:p};var g=h._module.formatLabels(f,h,d);o.aLabel=g.aLabel,o.bLabel=g.bLabel,o.cLabel=g.cLabel;var m=f.hi||h.hoverinfo,v=[];if(!h.hovertemplate){var y=m.split(\"+\");-1!==y.indexOf(\"all\")&&(y=[\"a\",\"b\",\"c\"]),-1!==y.indexOf(\"a\")&&x(p.aaxis,o.aLabel),-1!==y.indexOf(\"b\")&&x(p.baxis,o.bLabel),-1!==y.indexOf(\"c\")&&x(p.caxis,o.cLabel)}return o.extraText=v.join(\"<br>\"),o.hovertemplate=h.hovertemplate,a}function x(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../scatter/hover\":1198}],1281:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":907,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1275,\"./calc\":1276,\"./defaults\":1277,\"./event_data\":1278,\"./format_labels\":1279,\"./hover\":1280,\"./plot\":1282}],1282:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1208}],1283:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,f=u.line,h=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},f.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:h,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergl/attributes\":1239}],1284:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine;function u(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var f=l(t,e._diag[s][1]);f&&(c[1]=f.r2l(f.range[0]),c[3]=f.r2l(f.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],f=u.xaxis,h=u.yaxis,p=f._gridVals,d=h._gridVals,g=n.b+h.domain[0]*n.h,m=-h._m,v=-m*h.r2l(h.range[0],h.calendar);if(f.showgrid)for(e=0;e<p.length;e++)s=f._offset+f.l2p(p[e].x),o(\"grid\",f,s,g,s,g+h._length);if(h.showgrid)for(e=0;e<d.length;e++)l=g+v+m*d[e].x,o(\"grid\",h,f._offset,l,f._offset+f._length,l);c(t,f,h)&&(s=f._offset+f.l2p(0),o(\"zeroline\",f,s,g,s,g+h._length)),c(t,h,f)&&(l=g+v+0,o(\"zeroline\",h,f._offset,l,f._offset+f._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:\"splom\",attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(\"splom\"),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&u(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":791,\"../../plots/cartesian\":841,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../../plots/get_data\":865,\"../../registry\":911,\"regl-line2d\":535}],1285:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),f=t(\"../../constants/numerical\").BADNUM,h=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,m,v,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],T=e._visibleDims=[];function k(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===f?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),m=i.getFromId(t,e._diag[r][1]),g&&m&&g.type!==m.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(k(g,d),m&&\"category\"===m.type&&(m._categories=g._categories.slice())):k(m,d),T.push(r)}for(s(t,e),n.extendFlat(b,c(e)),v=_.length*x>h?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<T.length;p++)d=y[r=T[p]],g=i.getFromId(t,e._diag[r][0])||{},m=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,m,_[p],_[p],v);var M=u(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=b,M.selectedOptions=l(e,e.selected),M.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"./scene_update\":1292}],1286:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=t(\"../scattergl/helpers\").isOpenSymbol;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=h(\"diagonal.visible\"),g=h(\"showupperhalf\"),m=h(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||m)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),s(t,e,r,f,h);var v=c(e.marker.symbol),y=o.isBubble(e);h(\"marker.line.width\",v||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,f=new Array(s),h=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";f[i]=\"x\"+p,h[i]=\"y\"+p}var d=n(\"xaxes\",f),g=n(\"yaxes\",h),m=e._diag=new Array(s);e._xaxes={},e._yaxes={};var v=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],T=0===i,k=i===s-1,M=T&&b||k&&_?void 0:d[i],A=T&&_||k&&b?void 0:g[i];x(M,A,w,v),x(A,M,w,y),m[i]=[M,A],e._axesDim[M]=i,e._axesDim[A]=i}for(i=0;i<v.length;i++)for(a=0;a<y.length;a++){var S=v[i]+y[a];i>a&&l||i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,f,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../parcoords/merge_length\":1158,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scattergl/helpers\":1246,\"./attributes\":1283}],1287:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":778,\"../scatter/colorscale_calc\":1190,\"../scattergl/convert\":1242}],1288:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1289:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),f=t.distance,h=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===h||!1===p)return[t];for(var d,g,m=o[h],v=o[p],y=f,x=0;x<m.length;x++){var b=m[x],_=v[x],w=s.c2p(b)-c,T=l.c2p(_)-u,k=Math.sqrt(w*w+T*T);k<y&&(y=g=k,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:[i(t,m,v,a)]}}},{\"../scattergl/hover\":1247,\"./helpers\":1288}],1290:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":687,\"../../registry\":911,\"../scatter/marker_colorbar\":1205,\"./attributes\":1283,\"./base_plot\":1284,\"./calc\":1285,\"./defaults\":1286,\"./edit_style\":1287,\"./hover\":1289,\"./plot\":1291,\"./select\":1293}],1291:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../components/dragelement/helpers\").selectMode;function s(t,e){var r,s,l,c,u,f=t._fullLayout,h=f._size,p=e.trace,d=e.t,g=f._splomScenes[p.uid],m=g.matrixOptions,v=m.cdata,y=f._glcanvas.data()[0].regl,x=f.dragmode;if(0!==v.length){m.lower=p.showupperhalf,m.upper=p.showlowerhalf,m.diagonal=p.diagonal.visible;var b=p._visibleDims,_=v.length,w=g.viewOpts={};for(w.ranges=new Array(_),w.domains=new Array(_),u=0;u<b.length;u++){l=b[u];var T=w.ranges[u]=new Array(4),k=w.domains[u]=new Array(4);(r=a.getFromId(t,p._diag[l][0]))&&(T[0]=r._rl[0],T[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(s=a.getFromId(t,p._diag[l][1]))&&(T[1]=s._rl[0],T[3]=s._rl[1],k[1]=s.domain[0],k[3]=s.domain[1])}w.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===g.matrix&&(g.matrix=n(y));var M=f.clickmode.indexOf(\"select\")>-1,A=!0;if(o(x)||!!p.selectedpoints||M){var S=p._length;if(p.selectedpoints){g.selectBatch=p.selectedpoints;var E=p.selectedpoints,C={};for(l=0;l<E.length;l++)C[E[l]]=!0;var L=[];for(l=0;l<S;l++)C[l]||L.push(l);g.unselectBatch=L}var I=d.xpx=new Array(_),P=d.ypx=new Array(_);for(u=0;u<b.length;u++){if(l=b[u],r=a.getFromId(t,p._diag[l][0]))for(I[u]=new Array(S),c=0;c<S;c++)I[u][c]=r.c2p(v[u][c]);if(s=a.getFromId(t,p._diag[l][1]))for(P[u]=new Array(S),c=0;c<S;c++)P[u][c]=s.c2p(v[u][c])}if(g.selectBatch.length||g.unselectBatch.length){var z=i.extendFlat({},m,g.unselectedOptions,w),O=i.extendFlat({},m,g.selectedOptions,w);g.matrix.update(z,O),A=!1}}else d.xpx=d.ypx=null;if(A){var D=i.extendFlat({},m,w);g.matrix.update(D,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)s(t,r[n][0])}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"regl-splom\":539}],1292:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":778}],1293:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,f=t.yaxis,h=[];if(!l)return h;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return h;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,f);if(!1===d||!1===g)return h;var m=s.xpx[d],v=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([m[w],v[w]],null,w,t)?(b.push(w),h.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var T=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},T,l.selectedOptions,l.viewOpts)):l.matrix.update(T,null),l.selectBatch=b,l.unselectBatch=_,h}},{\"../../lib\":778,\"../scatter/subtypes\":1212,\"./helpers\":1288}],1294:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1295:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/calc\");function a(t){var e,r,i,a,s,l,c,u,f,h,p,d,g=t._x,m=t._y,v=t._z,y=t._len,x=-1/0,b=1/0,_=-1/0,w=1/0,T=-1/0,k=1/0,M=\"\";for(y&&(c=g[0],f=m[0],p=v[0]),y>1&&(u=g[y-1],h=m[y-1],d=v[y-1]),e=0;e<y;e++)x=Math.max(x,g[e]),b=Math.min(b,g[e]),_=Math.max(_,m[e]),w=Math.min(w,m[e]),T=Math.max(T,v[e]),k=Math.min(k,v[e]),a||g[e]===c||(a=!0,M+=\"x\"),s||m[e]===f||(s=!0,M+=\"y\"),l||v[e]===p||(l=!0,M+=\"z\");a||(M+=\"x\"),s||(M+=\"y\"),l||(M+=\"z\");var A=o(t._x),S=o(t._y),E=o(t._z);M=(M=(M=M.replace(\"x\",(c>u?\"-\":\"+\")+\"x\")).replace(\"y\",(f>h?\"-\":\"+\")+\"y\")).replace(\"z\",(p>d?\"-\":\"+\")+\"z\");var C=function(){y=0,A=[],S=[],E=[]};(!y||y<A.length*S.length*E.length)&&C();var L=function(t){return\"x\"===t?g:\"y\"===t?m:v},I=function(t){return\"x\"===t?A:\"y\"===t?S:E},P=function(t){return t[y-1]<t[0]?-1:1},z=L(M[1]),O=L(M[3]),D=L(M[5]),R=I(M[1]).length,F=I(M[3]).length,B=I(M[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},U=P(L(M[1])),V=P(L(M[3])),q=P(L(M[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(i=0;i<R-1;i++){var H=j(e,r,i),G=j(e,r,i+1),Y=j(e,r+1,i),W=j(e+1,r,i);if(z[H]*U<z[G]*U&&O[H]*V<O[Y]*V&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn(\"Encountered arbitrary coordinates! Unable to input data grid.\"),C()),{xMin:b,yMin:w,zMin:k,xMax:x,yMax:_,zMax:T,Xs:A,Ys:S,Zs:E,len:y,fill:M}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],i=0;i<e;i++)r[i]=+t[i];return r}e.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,f=0,h=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],g=e._w[u],m=Math.sqrt(p*p+d*d+g*g);f=Math.max(f,m),h=Math.min(h,m)}for(i(t,e,{vals:[h,f],containerStr:\"\",cLetter:\"c\"}),u=0;u<c;u++){var v=n[u];r.xMax=Math.max(r.xMax,v),r.xMin=Math.min(r.xMin,v);var y=o[u];r.yMax=Math.max(r.yMax,y),r.yMin=Math.min(r.yMin,y);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=f,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:a}},{\"../../components/colorscale/calc\":651,\"../../lib\":778}],1296:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var f=u.prototype;function h(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,f={};function d(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,(function(t){return n.d2l(t)*o}))}if(f.vectors=l(d(e._u,\"xaxis\"),d(e._v,\"yaxis\"),d(e._w,\"zaxis\"),u),!u)return{positions:[],cells:[]};var g=d(e._Xs,\"xaxis\"),m=d(e._Ys,\"yaxis\"),v=d(e._Zs,\"zaxis\");if(f.meshgrid=[g,m,v],f.gridFill=e._gridFill,e._slen)f.startingPositions=l(d(e._startsX,\"xaxis\"),d(e._startsY,\"yaxis\"),d(e._startsZ,\"zaxis\"));else{for(var y=m[0],x=h(g),b=h(v),_=new Array(x.length*b.length),w=0,T=0;T<x.length;T++)for(var k=0;k<b.length;k++)_[w++]=[x[T],y,b[k]];f.startingPositions=_}f.colormap=o(e),f.tubeSize=e.sizeref,f.maxLength=e.maxdisplayed;var M=d(e._xbnds,\"xaxis\"),A=d(e._ybnds,\"yaxis\"),S=d(e._zbnds,\"zaxis\"),E=p(g),C=p(m),L=p(v),I=[[M[0]-E[0],A[0]-C[0],S[0]-L[0]],[M[1]+E[1],A[1]+C[1],S[1]+L[1]]],P=n(f,I),z=s(e);P.vertexIntensityBounds=[z.min/e._normMax,z.max/e._normMax];var O=e.lightposition;return P.lightPosition=[O.x,O.y,O.z],P.ambient=e.lighting.ambient,P.diffuse=e.lighting.diffuse,P.specular=e.lighting.specular,P.roughness=e.lighting.roughness,P.fresnel=e.lighting.fresnel,P.opacity=e.opacity,e._pad=P.tubeScale*e.sizeref*2,P}f.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},f.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-streamtube3d\":348}],1297:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1294}],1298:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\").calc,plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1294,\"./calc\":1295,\"./convert\":1296,\"./defaults\":1297}],1299:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../pie/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},count:{valType:\"flaglist\",flags:[\"branches\",\"leaves\"],dflt:\"leaves\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:u({colors:{valType:\"data_array\",editType:\"calc\"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},o(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1},editType:\"plot\"},text:l.text,textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],extras:[\"none\"],editType:\"plot\"},texttemplate:a({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],dflt:\"label+text+value+name\"}),hovertemplate:i({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),rotation:{valType:\"angle\",dflt:0,editType:\"plot\"},sort:l.sort,root:{color:{valType:\"color\",editType:\"calc\",dflt:\"rgba(0,0,0,0)\"},editType:\"calc\"},domain:s({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"./constants\":1302}],1300:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"sunburst\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1301:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,s=t(\"../pie/calc\").makePullColorFn,l=t(\"../pie/calc\").generateExtendedColors,c=t(\"../../components/colorscale\").calc,u=t(\"../../constants/numerical\").ALMOST_EQUAL,f={},h={};r.calc=function(t,e){var r,l,f,h,p,d,g=t._fullLayout,m=e.ids,v=a.isArrayOrTypedArray(m),y=e.labels,x=e.parents,b=e.values,_=a.isArrayOrTypedArray(b),w=[],T={},k={},M=function(t){return t||\"number\"==typeof t},A=function(t){return!_||i(b[t])&&b[t]>=0};v?(r=Math.min(m.length,x.length),l=function(t){return M(m[t])&&A(t)},f=function(t){return String(m[t])}):(r=Math.min(y.length,x.length),l=function(t){return M(y[t])&&A(t)},f=function(t){return String(y[t])}),_&&(r=Math.min(r,b.length));for(var S=0;S<r;S++)if(l(S)){var E=f(S),C=M(x[S])?String(x[S]):\"\",L={i:S,id:E,pid:C,label:M(y[S])?String(y[S]):\"\"};_&&(L.v=+b[S]),w.push(L),p=E,T[h=C]?T[h].push(p):T[h]=[p],k[p]=1}if(T[\"\"]){if(T[\"\"].length>1){for(var I=a.randstr(),P=0;P<w.length;P++)\"\"===w[P].pid&&(w[P].pid=I);w.unshift({hasMultipleRoots:!0,id:I,pid:\"\",label:\"\"})}}else{var z,O=[];for(z in T)k[z]||O.push(z);if(1!==O.length)return a.warn([\"Multiple implied roots, cannot build\",e.type,\"hierarchy of\",e.name+\".\",\"These roots include:\",O.join(\", \")].join(\" \"));z=O[0],w.unshift({hasImpliedRoot:!0,id:z,pid:\"\",label:z})}try{d=n.stratify().id((function(t){return t.id})).parentId((function(t){return t.pid}))(w)}catch(t){return a.warn([\"Failed to build\",e.type,\"hierarchy of\",e.name+\".\",\"Error:\",t.message].join(\" \"))}var D=n.hierarchy(d),R=!1;if(_)switch(e.branchvalues){case\"remainder\":D.sum((function(t){return t.data.v}));break;case\"total\":D.each((function(t){var r=t.data.data,n=r.v;if(t.children){var i=t.children.reduce((function(t,e){return t+e.data.data.v}),0);if((r.hasImpliedRoot||r.hasMultipleRoots)&&(n=i),n<i*u)return R=!0,a.warn([\"Total value for node\",t.data.data.id,\"of\",e.name,\"is smaller than the sum of its children.\",\"\\nparent value =\",n,\"\\nchildren sum =\",i].join(\" \"))}t.value=n}))}else!function t(e,r,n){var i=0,a=e.children;if(a){for(var o=a.length,s=0;s<o;s++)i+=t(a[s],r,n);n.branches&&i++}else n.leaves&&i++;e.value=e.data.data.value=i,r._values||(r._values=[]);return r._values[e.data.data.i]=i,i}(D,e,{branches:-1!==e.count.indexOf(\"branches\"),leaves:-1!==e.count.indexOf(\"leaves\")});if(!R){var F,B;e.sort&&D.sort((function(t,e){return e.value-t.value}));var N=e.marker.colors||[],j=!!N.length;return e._hasColorscale?(j||(N=_?e.values:e._values),c(t,e,{vals:N,containerStr:\"marker\",cLetter:\"c\"}),B=o(e.marker)):F=s(g[\"_\"+e.type+\"colormap\"]),D.each((function(t){var r=t.data.data;r.color=e._hasColorscale?B(N[r.i]):F(N[r.i],r.id)})),w[0].hierarchy=D,w}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,i=r[t+\"colorway\"],a=r[\"_\"+t+\"colormap\"];r[\"extend\"+t+\"colors\"]&&(i=l(i,\"treemap\"===t?h:f));var o,s=0;function c(t){var e=t.data.data,r=e.id;!1===e.color&&(a[r]?e.color=a[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(a[r]=e.color=i[s%i.length],s++):e.color=o)}for(var u=0;u<n.length;u++){var p=n[u][0];p.trace.type===t&&p.hierarchy&&(o=p.trace.root.color,p.hierarchy.each(c))}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc(\"sunburst\",t)}},{\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../pie/calc\":1163,\"d3-hierarchy\":161,\"fast-isnumeric\":241}],1302:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"]}},{}],1303:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../../components/colorscale\"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,a){return n.coerce(t,e,i,r,a)}var f=u(\"labels\"),h=u(\"parents\");if(f&&f.length&&h&&h.length){var p=u(\"values\");p&&p.length?u(\"branchvalues\"):u(\"count\"),u(\"level\"),u(\"maxdepth\"),u(\"marker.line.width\")&&u(\"marker.line.color\",s.paper_bgcolor),u(\"marker.colors\");var d=e._hasColorscale=l(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;d&&c(t,e,s,u,{prefix:\"marker.\",cLetter:\"c\"}),u(\"leaf.opacity\",d?1:.7);var g=u(\"text\");u(\"texttemplate\"),e.texttemplate||u(\"textinfo\",Array.isArray(g)?\"text+label\":\"label\"),u(\"hovertext\"),u(\"hovertemplate\");o(t,e,s,u,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),u(\"insidetextorientation\"),u(\"sort\"),u(\"rotation\"),u(\"root.color\"),a(e,s,u),e._length=null}else e.visible=!1}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1299}],1304:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/fx/helpers\").appendArrayPointValue,o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/events\"),c=t(\"./helpers\"),u=t(\"../pie/helpers\").formatPieValue;function f(t,e,r){for(var n=t.data.data,i={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(i[s]=t[s])}return\"parentString\"in t&&!c.isHierarchyRoot(t)&&(i.parent=t.parentString),a(i,e,n.i),i}e.exports=function(t,e,r,a,h){var p=a[0],d=p.trace,g=p.hierarchy,m=\"sunburst\"===d.type,v=\"treemap\"===d.type;\"_hasHoverLabel\"in d||(d._hasHoverLabel=!1),\"_hasHoverEvent\"in d||(d._hasHoverEvent=!1);t.on(\"mouseover\",(function(i){var a=r._fullLayout;if(!r._dragging&&!1!==a.hovermode){var l=r._fullData[d.index],y=i.data.data,x=y.i,b=c.isHierarchyRoot(i),_=c.getParent(g,i),w=c.getValue(i),T=function(t){return s.castOption(l,x,t)},k=T(\"hovertemplate\"),M=o.castHoverinfo(l,a,x),A=a.separators;if(k||M&&\"none\"!==M&&\"skip\"!==M){var S,E;m&&(S=p.cx+i.pxmid[0]*(1-i.rInscribed),E=p.cy+i.pxmid[1]*(1-i.rInscribed)),v&&(S=i._hoverX,E=i._hoverY);var C,L={},I=[],P=[],z=function(t){return-1!==I.indexOf(t)};M&&(I=\"all\"===M?l._module.attributes.hoverinfo.flags:M.split(\"+\")),L.label=y.label,z(\"label\")&&L.label&&P.push(L.label),y.hasOwnProperty(\"v\")&&(L.value=y.v,L.valueLabel=u(L.value,A),z(\"value\")&&P.push(L.valueLabel)),L.currentPath=i.currentPath=c.getPath(i.data),z(\"current path\")&&!b&&P.push(L.currentPath);var O=[],D=function(){-1===O.indexOf(C)&&(P.push(C),O.push(C))};L.percentParent=i.percentParent=w/c.getValue(_),L.parent=i.parentString=c.getPtLabel(_),z(\"percent parent\")&&(C=c.formatPercent(L.percentParent,A)+\" of \"+L.parent,D()),L.percentEntry=i.percentEntry=w/c.getValue(e),L.entry=i.entry=c.getPtLabel(e),!z(\"percent entry\")||b||i.onPathbar||(C=c.formatPercent(L.percentEntry,A)+\" of \"+L.entry,D()),L.percentRoot=i.percentRoot=w/c.getValue(g),L.root=i.root=c.getPtLabel(g),z(\"percent root\")&&!b&&(C=c.formatPercent(L.percentRoot,A)+\" of \"+L.root,D()),L.text=T(\"hovertext\")||T(\"text\"),z(\"text\")&&(C=L.text,s.isValidTextValue(C)&&P.push(C));var R={trace:l,y:E,text:P.join(\"<br>\"),name:k||z(\"name\")?l.name:void 0,color:T(\"hoverlabel.bgcolor\")||y.color,borderColor:T(\"hoverlabel.bordercolor\"),fontFamily:T(\"hoverlabel.font.family\"),fontSize:T(\"hoverlabel.font.size\"),fontColor:T(\"hoverlabel.font.color\"),nameLength:T(\"hoverlabel.namelength\"),textAlign:T(\"hoverlabel.align\"),hovertemplate:k,hovertemplateLabels:L,eventData:[f(i,l,h.eventDataKeys)]};m&&(R.x0=S-i.rInscribed*i.rpx1,R.x1=S+i.rInscribed*i.rpx1,R.idealAlign=i.pxmid[0]<0?\"left\":\"right\"),v&&(R.x=S,R.idealAlign=S<0?\"left\":\"right\"),o.loneHover(R,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r}),d._hasHoverLabel=!0}if(v){var F=t.select(\"path.surface\");h.styleOne(F,i,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit(\"plotly_hover\",{points:[f(i,l,h.eventDataKeys)],event:n.event})}})),t.on(\"mouseout\",(function(e){var i=r._fullLayout,a=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit(\"plotly_unhover\",{points:[f(s,a,h.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(i._hoverlayer.node()),d._hasHoverLabel=!1),v){var l=t.select(\"path.surface\");h.styleOne(l,s,a,{hovered:!1})}})),t.on(\"click\",(function(t){var e=r._fullLayout,a=r._fullData[d.index],s=m&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(g,u):c.findEntryWithLevel(g,u),v=c.getPtId(p),y={points:[f(t,a,h.eventDataKeys)],event:n.event};s||(y.nextLevel=v);var x=l.triggerHandler(r,\"plotly_\"+d.type+\"click\",y);if(!1!==x&&e.hovermode&&(r._hoverdata=[f(t,a,h.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){i.call(\"_storeDirectGUIEdit\",a,e._tracePreGUI[a.uid],{level:a.level});var b={data:[{level:v}],traces:[d.index]},_={frame:{redraw:!1,duration:h.transitionTime},transition:{duration:h.transitionTime,easing:h.transitionEasing},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),i.call(\"animate\",r,b,_)}}))}},{\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/events\":767,\"../../registry\":911,\"../pie/helpers\":1166,\"./helpers\":1305,d3:169}],1305:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../lib/setcursor\"),o=t(\"../pie/helpers\");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter((function(t){if(r.getPtId(t)===e)return n=t.copy()})),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter((function(t){for(var i=t.children||[],a=0;a<i.length;a++){var o=i[a];if(r.getPtId(o)===e)return n=t.copy()}})),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return\"\"===s(t)},r.setSliceCursor=function(t,e,n){var i=n.isTransitioning;if(!i){var o=t.datum();i=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}a(t,i?null:\"pointer\")},r.getInsideTextFontKey=function(t,e,r,i,a){var o=(a||{}).onPathbar?\"pathbar.textfont\":\"insidetextfont\",s=r.data.data.i;return n.castOption(e,s,o+\".\"+t)||n.castOption(e,s,\"textfont.\"+t)||i.size},r.getOutsideTextFontKey=function(t,e,r,i){var a=r.data.data.i;return n.castOption(e,a,\"outsidetextfont.\"+t)||n.castOption(e,a,\"textfont.\"+t)||i.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,a,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey(\"color\",t,e,n),family:r.getOutsideTextFontKey(\"family\",t,e,n),size:r.getOutsideTextFontKey(\"size\",t,e,n)}}(t,e,a):function(t,e,a,o){var s=(o||{}).onPathbar,l=e.data.data,c=l.i,u=n.castOption(t,c,(s?\"pathbar.textfont\":\"insidetextfont\")+\".color\");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,\"textfont.color\")),{color:u||i.contrast(l.color),family:r.getInsideTextFontKey(\"family\",t,e,a,o),size:r.getInsideTextFontKey(\"size\",t,e,a,o)}}(t,e,a,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var i=e?[n.data[e]]:[n];return r.listPath(n,e).concat(i)},r.getPath=function(t){return r.listPath(t,\"label\").join(\"/\")+\"/\"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return\"0%\"===r&&(r=o.formatPiePercent(t,e)),r}},{\"../../components/color\":643,\"../../lib\":778,\"../../lib/setcursor\":799,\"../pie/helpers\":1166}],1306:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1299,\"./base_plot\":1300,\"./calc\":1301,\"./defaults\":1303,\"./layout_attributes\":1307,\"./layout_defaults\":1308,\"./plot\":1309,\"./style\":1310}],1307:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1308:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1307}],1309:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../pie/plot\"),h=t(\"../pie/helpers\").getRotationAngle,p=f.computeTransform,d=f.transformInsideText,g=t(\"./style\").styleOne,m=t(\"../bar/style\").resizeText,v=t(\"./fx\"),y=t(\"./constants\"),x=t(\"./helpers\");function b(t,e,l,u){var f=t._fullLayout,m=!f.uniformtext.mode&&x.hasTransition(u),b=n.select(l).selectAll(\"g.slice\"),w=e[0],T=w.trace,k=w.hierarchy,M=x.findEntryWithLevel(k,T.level),A=x.getMaxDepth(T),S=f._size,E=T.domain,C=S.w*(E.x[1]-E.x[0]),L=S.h*(E.y[1]-E.y[0]),I=.5*Math.min(C,L),P=w.cx=S.l+S.w*(E.x[1]+E.x[0])/2,z=w.cy=S.t+S.h*(1-E.y[0])-L/2;if(!M)return b.remove();var O=null,D={};m&&b.each((function(t){D[x.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!O&&x.isEntry(t)&&(O=t)}));var R=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(M).descendants(),F=M.height+1,B=0,N=A;w.hasMultipleRoots&&x.isHierarchyRoot(M)&&(R=R.slice(1),F-=1,B=1,N+=1),R=R.filter((function(t){return t.y1<=N}));var j=h(T.rotation);j&&R.forEach((function(t){t.x0+=j,t.x1+=j}));var U=Math.min(F,A),V=function(t){return(t-B)/U*I},q=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},H=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,z)},G=function(t){return P+_(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},Y=function(t){return z+_(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(b=b.data(R,x.getPtId)).enter().append(\"g\").classed(\"slice\",!0),m?b.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=x.getPtId(t),i=D[r],a=D[x.getPtId(M)];if(a){var o=(t.x1>a.x1?2*Math.PI:0)+j;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=x.getPtId(t.parent);b.each((function(t){if(x.getPtId(t)===l)return s=t}));var c,u=s.children;u.forEach((function(t,e){if(x.getPtId(t)===r)return c=e}));var f=u.length,h=n.interpolate(s.x0,s.x1);e={rpx0:I,rpx1:I,x0:h(c/f),x1:h((c+1)/f)}}return n.interpolate(i,e)}(t);return function(t){return H(e(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():b.exit().remove(),b.order();var W=null;if(m&&O){var X=x.getPtId(O);b.each((function(t){null===W&&x.getPtId(t)===X&&(W=t.x1)}))}var Z=b;function J(t){var e=t.parent,r=D[x.getPtId(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}m&&(Z=Z.transition().each(\"end\",(function(){var e=n.select(this);x.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})}))),Z.each((function(i){var l=n.select(this),u=o.ensureSingle(l,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));i.rpx0=V(i.y0),i.rpx1=V(i.y1),i.xmid=(i.x0+i.x1)/2,i.pxmid=q(i.rpx1,i.xmid),i.midangle=-(i.xmid-Math.PI/2),i.startangle=-(i.x0-Math.PI/2),i.stopangle=-(i.x1-Math.PI/2),i.halfangle=.5*Math.min(o.angleDelta(i.x0,i.x1)||Math.PI,Math.PI),i.ring=1-i.rpx0/i.rpx1,i.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(i),m?u.transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(O)if(t.parent)if(W){var a=(t.x1>W?2*Math.PI:0)+j;e={x0:a,x1:a}}else e={rpx0:I,rpx1:I},o.extendFlat(e,J(t));else e={rpx0:0,rpx1:0};else e={x0:j,x1:j};return n.interpolate(e,i)}(t);return function(t){return H(e(t))}})):u.attr(\"d\",H),l.call(v,M,t,e,{eventDataKeys:y.eventDataKeys,transitionTime:y.CLICK_TRANSITION_TIME,transitionEasing:y.CLICK_TRANSITION_EASING}).call(x.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),u.call(g,i,T);var h=o.ensureSingle(l,\"g\",\"slicetext\"),b=o.ensureSingle(h,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),_=o.ensureUniformFontSize(t,x.determineTextFont(T,i,f.font));b.text(r.formatSliceLabel(i,M,T,e,f)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(a.font,_).call(s.convertToTspans,t);var k=a.bBox(b.node());i.transform=d(k,i,w),i.transform.targetX=G(i),i.transform.targetY=Y(i);var A=function(t,e){var r=t.transform;return p(r,e),r.fontSize=_.size,c(T.type,r,f),o.getTextTransform(r)};m?b.transition().attrTween(\"transform\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:i.textPosAngle,scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},O)if(t.parent)if(W){var a=t.x1>W?2*Math.PI:0;e.x0=e.x1=a}else o.extendFlat(e,J(t));else e.x0=e.x1=j;else e.x0=e.x1=j;var s=n.interpolate(e.transform.textPosAngle,t.transform.textPosAngle),l=n.interpolate(e.rpx1,t.rpx1),u=n.interpolate(e.x0,t.x0),h=n.interpolate(e.x1,t.x1),p=n.interpolate(e.transform.scale,i.scale),d=n.interpolate(e.transform.rotate,i.rotate),g=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,m=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=l(t),r=u(t),n=h(t),a=function(t){return m(Math.pow(t,g))}(t),o={pxmid:q(e,(r+n)/2),rpx1:e,transform:{textPosAngle:s(t),rCenter:a,x:i.x,y:i.y}};return c(T.type,i,f),{transform:{targetX:G(o),targetY:Y(o),scale:p(t),rotate:d(t),rCenter:a}}}}(t);return function(t){return A(e(t),k)}})):b.attr(\"transform\",A(i,k))}))}function _(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}r.plot=function(t,e,r,i){var a,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,f=!s.uniformtext.mode&&x.hasTransition(r);(u(\"sunburst\",s),(a=l.selectAll(\"g.trace.sunburst\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),f)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){o&&o()})).each(\"interrupt\",(function(){o&&o()})).each((function(){l.selectAll(\"g.trace\").each((function(e){b(t,e,this,r)}))}))):(a.each((function(e){b(t,e,this,r)})),s.uniformtext.mode&&m(t,s._sunburstlayer.selectAll(\".trace\"),\"sunburst\"));c&&a.exit().remove()},r.formatSliceLabel=function(t,e,r,n,i){var a=r.texttemplate,s=r.textinfo;if(!(a||s&&\"none\"!==s))return\"\";var l=i.separators,c=n[0],u=t.data.data,f=c.hierarchy,h=x.isHierarchyRoot(t),p=x.getParent(f,t),d=x.getValue(t);if(!a){var g,m=s.split(\"+\"),v=function(t){return-1!==m.indexOf(t)},y=[];if(v(\"label\")&&u.label&&y.push(u.label),u.hasOwnProperty(\"v\")&&v(\"value\")&&y.push(x.formatValue(u.v,l)),!h){v(\"current path\")&&y.push(x.getPath(t.data));var b=0;v(\"percent parent\")&&b++,v(\"percent entry\")&&b++,v(\"percent root\")&&b++;var _=b>1;if(b){var w,T=function(t){g=x.formatPercent(w,l),_&&(g+=\" of \"+t),y.push(g)};v(\"percent parent\")&&!h&&(w=d/x.getValue(p),T(\"parent\")),v(\"percent entry\")&&(w=d/x.getValue(e),T(\"entry\")),v(\"percent root\")&&(w=d/x.getValue(f),T(\"root\"))}}return v(\"text\")&&(g=o.castOption(r,u.i,\"text\"),o.isValidTextValue(g)&&y.push(g)),y.join(\"<br>\")}var k=o.castOption(r,u.i,\"texttemplate\");if(!k)return\"\";var M={};u.label&&(M.label=u.label),u.hasOwnProperty(\"v\")&&(M.value=u.v,M.valueLabel=x.formatValue(u.v,l)),M.currentPath=x.getPath(t.data),h||(M.percentParent=d/x.getValue(p),M.percentParentLabel=x.formatPercent(M.percentParent,l),M.parent=x.getPtLabel(p)),M.percentEntry=d/x.getValue(e),M.percentEntryLabel=x.formatPercent(M.percentEntry,l),M.entry=x.getPtLabel(e),M.percentRoot=d/x.getValue(f),M.percentRootLabel=x.formatPercent(M.percentRoot,l),M.root=x.getPtLabel(f),u.hasOwnProperty(\"color\")&&(M.color=u.color);var A=o.castOption(r,u.i,\"text\");return(o.isValidTextValue(A)||\"\"===A)&&(M.text=A),M.customdata=o.castOption(r,u.i,\"customdata\"),o.texttemplateString(k,M,i._d3locale,M,r._meta||{})}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,\"./constants\":1302,\"./fx\":1304,\"./helpers\":1305,\"./style\":1310,d3:169,\"d3-hierarchy\":161}],1310:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../bar/uniform_text\").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(\".trace\");o(t,e,\"sunburst\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(s,t,r)}))}))},styleOne:s}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,d3:169}],1311:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},opacityscale:{valType:\"any\",editType:\"calc\"},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":643,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906}],1312:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1313:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-linear-interpolate\").d2,o=t(\"../heatmap/interp2d\"),s=t(\"../heatmap/find_empties\"),l=t(\"../../lib\").isArrayOrTypedArray,c=t(\"../../lib/gl_format_color\").parseColorScale,u=t(\"../../lib/str2rgbarray\"),f=t(\"../../components/colorscale\").extractOpts;function h(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var p=h.prototype;p.getXat=function(t,e,r,n){var i=l(this.data.x)?l(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},p.getYat=function(t,e,r,n){var i=l(this.data.y)?l(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},p.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},p.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var d=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function g(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<d.length;r++){var n=d[r];e.push(g(t,n))}return e}function v(t){for(var e=m(t),r=t,n=0;n<d.length;n++)if(e[n]>0){r=d[n];break}return r}function y(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<d.length;a++)i*=Math.pow(d[a],Math.max(r[a],n[a]));return i}}p.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},p.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var x=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],b=x[9],_=x[13];function w(t,e,r){var n=r[8]+r[2]*e[0]+r[5]*e[1];return t[0]=(r[6]+r[0]*e[0]+r[3]*e[1])/n,t[1]=(r[7]+r[1]*e[0]+r[4]*e[1])/n,t}function T(t,e,r){return function(t,e,r,n){for(var i=[0,0],o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++)r(i,[l,c],n),t.set(l,c,a(e,i[0],i[1]))}(t,e,w,r),t}function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}p.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=y(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<b;)r*=2;for(;r>_;)r--,r/=v(r),++r<b&&(r=_);var n=Math.round(r/t);return n>1?n:1},p.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],a=t[0].shape[1],o=0|Math.floor(t[0].shape[0]*e+1),s=0|Math.floor(t[0].shape[1]*r+1),l=1+n+1,c=1+a+1,u=i(new Float32Array(l*c),[l,c]),f=[1/e,0,0,0,1/r,0,0,0,1],h=0;h<t.length;++h){this.surface.padField(u,t[h]);var p=i(new Float32Array(o*s),[o,s]);T(p,u,f),t[h]=p}},p.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},p.update=function(t){var e,r,n,a,l=this.scene,h=l.fullSceneLayout,p=this.surface,d=c(t),g=l.dataScale,m=t.z[0].length,v=t._ylength,y=l.contourLevels;this.data=t;var x=[];for(e=0;e<3;e++)for(x[e]=[],r=0;r<m;r++)x[e][r]=[];for(r=0;r<m;r++)for(n=0;n<v;n++)x[0][r][n]=this.getXat(r,n,t.xcalendar,h.xaxis),x[1][r][n]=this.getYat(r,n,t.ycalendar,h.yaxis),x[2][r][n]=this.getZat(r,n,t.zcalendar,h.zaxis);if(t.connectgaps)for(t._emptypoints=s(x[2]),o(x[2],t._emptypoints),t._interpolatedZ=[],r=0;r<m;r++)for(t._interpolatedZ[r]=[],n=0;n<v;n++)t._interpolatedZ[r][n]=x[2][r][n];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null==(a=x[e][r][n])?x[e][r][n]=NaN:a=x[e][r][n]*=g[e];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(x[e][r][n]-=this.objectOffset[e]);var b=[i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v])];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)b[e].set(r,n,x[e][r][n]);x=[];var w={colormap:d,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},T=f(t);if(w.intensityBounds=[T.min,T.max],t.surfacecolor){var k=i(new Float32Array(m*v),[m,v]);for(r=0;r<m;r++)for(n=0;n<v;n++)k.set(r,n,t.surfacecolor[n][r]);b.push(k)}else w.intensityBounds[0]*=g[2],w.intensityBounds[1]*=g[2];(_<b[0].shape[0]||_<b[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(b[0].shape[0],0),this.dataScaleY=this.estimateScale(b[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(b)),t.surfacecolor&&(w.intensity=b.pop());var M=[!0,!0,!0],A=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var S=t.contours[A[e]];M[e]=S.highlight,w.showContour[e]=S.show||S.highlight,w.showContour[e]&&(w.contourProject[e]=[S.project.x,S.project.y,S.project.z],S.show?(this.showContour[e]=!0,w.levels[e]=y[e],p.highlightColor[e]=w.contourColor[e]=u(S.color),S.usecolormap?p.highlightTint[e]=w.contourTint[e]=0:p.highlightTint[e]=w.contourTint[e]=1,w.contourWidth[e]=S.width,this.contourStart[e]=S.start,this.contourEnd[e]=S.end,this.contourSize[e]=S.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),S.highlight&&(w.dynamicColor[e]=u(S.highlightcolor),w.dynamicWidth[e]=S.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(d)&&(w.vertexColor=!0),w.objectOffset=this.objectOffset,w.coords=b,p.update(w),p.visible=t.visible,p.enableDynamic=M,p.enableHighlight=M,p.snapToData=!0,\"lighting\"in t&&(p.ambientLight=t.lighting.ambient,p.diffuseLight=t.lighting.diffuse,p.specularLight=t.lighting.specular,p.roughness=t.lighting.roughness,p.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(p.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z])},p.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"gl-surface3d\":351,ndarray:495,\"ndarray-linear-interpolate\":489}],1314:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var i=n(\"opacityscale\");\"max\"===i?e.opacityscale=[[0,.1],[1,1]]:\"min\"===i?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===i?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(0,Math.min(1,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(i)||(e.opacityscale=void 0)}function l(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports={supplyDefaults:function(t,e,r,c){var u,f;function h(r,n){return i.coerce(t,e,o,r,n)}var p=h(\"x\"),d=h(\"y\"),g=h(\"z\");if(!g||!g.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&i.isArrayOrTypedArray(p[0])?g.length:g[0].length,e._ylength=g.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],c),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach((function(t){h(t)}));var m=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(u=0;u<3;++u){var y=\"contours.\"+v[u],x=h(y+\".show\"),b=h(y+\".highlight\");if(x||b)for(f=0;f<3;++f)h(y+\".project.\"+v[f]);x&&(h(y+\".color\"),h(y+\".width\"),h(y+\".usecolormap\")),b&&(h(y+\".highlightcolor\"),h(y+\".highlightwidth\")),h(y+\".start\"),h(y+\".end\"),h(y+\".size\")}m||(l(t,\"zmin\",\"cmin\"),l(t,\"zmax\",\"cmax\"),l(t,\"zauto\",\"cauto\")),a(t,e,c,h,{prefix:\"\",cLetter:\"c\"}),s(t,e,c,h),e._length=null}},opacityscaleDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1311}],1315:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1311,\"./calc\":1312,\"./convert\":1313,\"./defaults\":1314}],1316:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":626,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1317:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1324}],1318:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":775}],1319:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1320:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce((function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e}),0)}function f(t,e){return Object.keys(t).map((function(r){return i({},t[r],{auxiliaryBlocks:e})}))}function h(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map((function(){return c((d[0]||[\"\"]).length)}))),m=e.domain,v=Math.floor(t._fullLayout._size.w*(m.x[1]-m.x[0])),y=Math.floor(t._fullLayout._size.h*(m.y[1]-m.y[0])),x=e.header.values.length?g[0].map((function(){return e.header.height})):[n.emptyHeaderHeight],b=r.length?r[0].map((function(){return e.cells.height})):[],_=x.reduce(s,0),w=h(b,y-_+n.uplift),T=f(h(x,_),[]),k=f(w,T),M={},A=e._fullInput.columnorder.concat(p(r.map((function(t,e){return e})))),S=g.map((function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1})),E=S.reduce(s,0);S=S.map((function(t){return t/E*v}));var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:m.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-m.y[1]),size:t._fullLayout._size,width:v,maxLineWidth:C,height:y,columnOrder:A,groupHeight:y,rowBlocks:k,headerRowBlocks:T,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map((function(t){return t[0]})),gdColumnsOriginalOrder:g.map((function(t){return t[0]})),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map((function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+\"__\"+M[t],label:t,specIndex:e,xIndex:A[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}}))};return L.columns.forEach((function(t){t.calcdata=L,t.x=u(t)})),L}},{\"../../lib/extend\":768,\"./constants\":1319,\"fast-isnumeric\":241}],1321:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map((function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}}))}},{\"../../lib/extend\":768}],1322:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort((function(t,e){return t-e})),o=i.map((function(t){return a.indexOf(t)})),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":778,\"../../plots/domain\":855,\"./attributes\":1316}],1323:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1316,\"./base_plot\":1317,\"./calc\":1318,\"./defaults\":1322,\"./plot\":1324}],1324:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").strTranslate,u=t(\"../../lib\").cancelTransition,f=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),p=t(\"../../components/color\");function d(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function m(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map((function(t){return t}))).map((function(t){return t.__data__}))}function y(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each((function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return O(e,e.length-1)+(e.length?D(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom})).attr(\"transform\",(function(t){var e=t.width+n.scrollbarWidth/2+n.scrollbarOffset;return c(e,A(t))}));var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",(function(t){return c(0,t.scrollbarState.topY||0)}));var u=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),u.attr(\"y2\",(function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2})).attr(\"stroke-opacity\",(function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4})),u.transition().delay(0).duration(0),u.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var f=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);f.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",(function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||E(e,t,null,l(s-o.barLength/2))(r)})).call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t})).on(\"drag\",E(e,t)).on(\"dragend\",(function(){}))),f.attr(\"y2\",(function(t){return t.scrollbarState.scrollableAreaHeight})),e._context.staticPlot&&(u.remove(),f.remove())}function x(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each((function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:w(r.size,n,e),color:w(r.color,n,e),family:w(r.family,n,e)};t.rowNumber=t.key,t.align=w(t.calcdata.cells.align,n,e),t.cellBorderWidth=w(t.calcdata.cells.line.width,n,e),t.font=i}))}(l),function(t){t.attr(\"width\",(function(t){return t.column.columnWidth})).attr(\"stroke-width\",(function(t){return t.cellBorderWidth})).each((function(t){var e=i.select(this);p.stroke(e,w(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),p.fill(e,w(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))}))}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",(function(){return\"auto\"})).on(\"mousedown\",(function(){i.event.stopPropagation()})),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each((function(t){o.font(i.select(this),t.font)}))}(c),b(c,e,s,t),z(l)}function b(t,e,r,a){t.text((function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var f,h,p=u?\"\":w(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":w(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:w(t.calcdata.cells.format,e,r)||null,m=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(f=_(m)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===f?_(m):f),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var v=(\" \"===n.wrapSplitCharacter?m.replace(/<a href=/gi,\"<a_href=\"):m).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?v.map((function(t){return t.replace(/<a_href=/gi,\"<a href=\")})):v;t.fragments=y.map((function(t){return{text:t,width:null}})),t.fragments.push({fragment:n.wrapSpacer,width:null}),h=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,h=m;return h})).attr(\"dy\",(function(t){return t.needsConvertToTspans?0:\"0.75em\"})).each((function(t){var o=i.select(this),l=t.wrappingNeeded?L:I;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",(function(t){return c(P(t),n.cellPad)})).attr(\"text-anchor\",(function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]}))}))}function _(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function w(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function T(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",c(e.x,r))}function k(t){return\"cells\"===t.type}function M(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce((function(t,e){return t+D(e,1/0)}),0)}function S(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=O(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),u=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l;e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===u.length&&(u[0]===i.length-1?u.unshift(u[0]-1):u.push(u[0]+1)),u[0]%2&&u.reverse(),e.each((function(t,e){t.page=u[e],t.scrollY=l})),e.attr(\"transform\",(function(t){var e=O(t.rowBlocks,t.page)-t.scrollY;return c(0,e)})),t&&(C(t,r,e,u,n.prevPages,n,0),C(t,r,e,u,n.prevPages,n,1),y(r,t))}}function E(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter((function(t){return s.key===t.key})),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var f=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return S(t,f,l),s.scrollY===u}}function C(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout((function(){var a=r.filter((function(t,e){return e===o&&n[e]!==i[e]}));x(t,e,a,r),i[o]=n[o]})))}function L(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each((function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each((function(t,r){e[r].width=this.getComputedTextLength()}));var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0})),o.selectAll(\"tspan.line\").remove(),b(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(z)}}function I(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=F(o),u=o.key-l.firstRowIndex,f=l.rows[u].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:f,p=Math.max(h,f);p-l.rows[u].rowHeight&&(l.rows[u].rowHeight=p,t.selectAll(\".\"+n.cn.columnCell).call(z),S(null,t.filter(k),0),y(r,a,!0)),s.attr(\"transform\",(function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return c(P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width),a)})),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function z(t){t.attr(\"transform\",(function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce((function(t,e){return t+D(e,1/0)}),0),r=D(F(t),t.key);return c(0,r+e)})).selectAll(\".\"+n.cn.cellRect).attr(\"height\",(function(t){return(e=F(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r}))}function O(t,e){for(var r=0,n=e-1;n>=0;n--)r+=R(t[n]);return r}function D(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function R(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function F(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map((function(e){var r=a.unwrap(e).trace;return f(t,r)})),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",(function(t){return t.width+t.size.l+t.size.r})).attr(\"height\",(function(t){return t.height+t.size.t+t.size.b})).attr(\"transform\",(function(t){return c(t.translateX,t.translateY)}));var p=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),b=p.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");if(r){var _=\"onwheel\"in document?\"wheel\":\"mousewheel\";b.on(\"mousemove\",(function(e){p.filter((function(t){return e===t})).call(y,t)})).on(_,(function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;E(t,p,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}})).call(y,t,!0)}p.attr(\"transform\",(function(t){return c(t.size.l,t.size.t)}));var w=p.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);w.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),w.attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),p.each((function(e){o.setClipUrl(i.select(this),g(t,e),t)}));var A=p.selectAll(\".\"+n.cn.yColumn).data((function(t){return t.columns}),a.keyFun);A.enter().append(\"g\").classed(n.cn.yColumn,!0),A.exit().remove(),A.attr(\"transform\",(function(t){return c(t.x,0)})),r&&A.call(i.behavior.drag().origin((function(e){return T(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,y(p.filter((function(t){return e.calcdata.key===t.key})),t),e})).on(\"drag\",(function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(A).filter((function(e){return e.calcdata.key===t.calcdata.key})).sort((function(t,e){return r(t)-r(e)})).forEach((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)})),A.filter((function(e){return t!==e})).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",(function(t){return c(t.x,0)})),e.call(u).attr(\"transform\",c(t.x,-n.uplift))})).on(\"dragend\",(function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,T(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort((function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]})),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map((function(t){return t.xIndex})))}))),A.each((function(e){o.setClipUrl(i.select(this),m(t,e),t)}));var C=A.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);C.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",(function(t){return t.key})),C.style(\"cursor\",(function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"}));var L=C.filter(M),I=C.filter(k);r&&I.call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t})).on(\"drag\",E(t,p,-1)).on(\"dragend\",(function(){}))),x(t,p,L,C),x(t,p,I,C);var P=p.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);P.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",(function(e){return g(t,e)}));var z=P.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),z.attr(\"width\",(function(t){return t.width+2*n.overdrag})).attr(\"height\",(function(t){return t.height+n.uplift})),A.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=A.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",(function(e){return m(t,e)}));var D=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);D.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),D.attr(\"width\",(function(t){return t.columnWidth+2*d(t)})).attr(\"height\",(function(t){return t.calcdata.height+2*d(t)+n.uplift})).attr(\"x\",(function(t){return-d(t)})).attr(\"y\",(function(t){return-d(t)})),S(null,I,p)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"./constants\":1319,\"./data_preparation_helper\":1320,\"./data_split_helpers\":1321,d3:169}],1325:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../pie/attributes\"),l=t(\"../sunburst/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:\"enumerated\",values:[\"squarify\",\"binary\",\"dice\",\"slice\",\"slice-dice\",\"dice-slice\"],dflt:\"squarify\",editType:\"plot\"},squarifyratio:{valType:\"number\",min:1,dflt:1,editType:\"plot\"},flip:{valType:\"flaglist\",flags:[\"x\",\"y\"],dflt:\"\",editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:3,editType:\"plot\"},editType:\"calc\"},marker:u({pad:{t:{valType:\"number\",min:0,editType:\"plot\"},l:{valType:\"number\",min:0,editType:\"plot\"},r:{valType:\"number\",min:0,editType:\"plot\"},b:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\"},colors:l.marker.colors,depthfade:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],editType:\"style\"},line:l.marker.line,editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),pathbar:{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},edgeshape:{valType:\"enumerated\",values:[\">\",\"<\",\"|\",\"/\",\"\\\\\"],dflt:\">\",editType:\"plot\"},thickness:{valType:\"number\",min:12,editType:\"plot\"},textfont:u({},s.textfont,{}),editType:\"calc\"},text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"top left\",editType:\"plot\"},sort:s.sort,root:l.root,domain:o({name:\"treemap\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"../sunburst/attributes\":1299,\"./constants\":1328}],1326:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"treemap\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1327:[function(t,e,r){\"use strict\";var n=t(\"../sunburst/calc\");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc(\"treemap\",t)}},{\"../sunburst/calc\":1301}],1328:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"poly\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"],gapWithPathbar:1}},{}],1329:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText,l=t(\"../bar/constants\").TEXTPAD,c=t(\"../../components/colorscale\"),u=c.hasColorscale,f=c.handleDefaults;e.exports=function(t,e,r,c){function h(r,a){return n.coerce(t,e,i,r,a)}var p=h(\"labels\"),d=h(\"parents\");if(p&&p.length&&d&&d.length){var g=h(\"values\");g&&g.length?h(\"branchvalues\"):h(\"count\"),h(\"level\"),h(\"maxdepth\"),\"squarify\"===h(\"tiling.packing\")&&h(\"tiling.squarifyratio\"),h(\"tiling.flip\"),h(\"tiling.pad\");var m=h(\"text\");h(\"texttemplate\"),e.texttemplate||h(\"textinfo\",Array.isArray(m)?\"text+label\":\"label\"),h(\"hovertext\"),h(\"hovertemplate\");var v=h(\"pathbar.visible\");s(t,e,c,h,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),h(\"textposition\");var y=-1!==e.textposition.indexOf(\"bottom\");h(\"marker.line.width\")&&h(\"marker.line.color\",c.paper_bgcolor);var x=h(\"marker.colors\"),b=e._hasColorscale=u(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;b?f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}):h(\"marker.depthfade\",!(x||[]).length);var _=2*e.textfont.size;h(\"marker.pad.t\",y?_/4:_),h(\"marker.pad.l\",_/4),h(\"marker.pad.r\",_/4),h(\"marker.pad.b\",y?_:_/4),b&&f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}),e._hovered={marker:{line:{width:2,color:a.contrast(c.paper_bgcolor)}}},v&&(h(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),h(\"pathbar.side\"),h(\"pathbar.edgeshape\")),h(\"sort\"),h(\"root.color\"),o(e,c,h),e._length=null}else e.visible=!1}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/constants\":923,\"../bar/defaults\":925,\"./attributes\":1325}],1330:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\");e.exports=function(t,e,r,h,p){var d=p.barDifY,g=p.width,m=p.height,v=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,T=p.handleSlicesExit,k=p.makeUpdateSliceInterpolator,M=p.makeUpdateTextInterpolator,A={},S=t._fullLayout,E=e[0],C=E.trace,L=E.hierarchy,I=g/C._entryDepth,P=u.listPath(r.data,\"id\"),z=s(L.copy(),[g,m],{packing:\"dice\",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(z=z.filter((function(t){var e=P.indexOf(t.data.id);return-1!==e&&(t.x0=I*e,t.x1=I*(e+1),t.y0=d,t.y1=d+m,t.onPathbar=!0,!0)}))).reverse(),(h=h.data(z,u.getPtId)).enter().append(\"g\").classed(\"pathbar\",!0),T(h,!0,A,[g,m],x),h.order();var O=h;w&&(O=O.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})}))),O.each((function(s){s._hoverX=v(s.x1-Math.min(g,m)/2),s._hoverY=y(s.y1-m/2);var h=n.select(this),p=i.ensureSingle(h,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?p.transition().attrTween(\"d\",(function(t){var e=k(t,!0,A,[g,m]);return function(t){return x(e(t))}})):p.attr(\"d\",x),h.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,C,{hovered:!1}),s._text=(u.getPtLabel(s)||\"\").split(\"<br>\").join(\" \")||\"\";var d=i.ensureSingle(h,\"g\",\"slicetext\"),T=i.ensureSingle(d,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),E=i.ensureUniformFontSize(t,u.determineTextFont(C,s,S.font,{onPathbar:!0}));T.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",\"start\").call(a.font,E).call(o.convertToTspans,t),s.textBB=a.bBox(T.node()),s.transform=b(s,{fontSize:E.size,onPathbar:!0}),s.transform.fontSize=E.size,w?T.transition().attrTween(\"transform\",(function(t){var e=M(t,!0,A,[g,m]);return function(t){return _(e(t))}})):T.attr(\"transform\",_(s))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1331:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\"),h=t(\"../sunburst/plot\").formatSliceLabel;e.exports=function(t,e,r,p,d){var g=d.width,m=d.height,v=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,T=d.handleSlicesExit,k=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,C=-1!==E.textposition.indexOf(\"left\"),L=-1!==E.textposition.indexOf(\"right\"),I=-1!==E.textposition.indexOf(\"bottom\"),P=!I&&!E.marker.pad.t||I&&!E.marker.pad.b,z=s(r,[g,m],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),O=1/0,D=-1/0;z.forEach((function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(O=Math.min(O,e),D=Math.max(D,e))})),p=p.data(z,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-O+1:0,p.enter().append(\"g\").classed(\"slice\",!0),T(p,!1,{},[g,m],x),p.order();var R=null;if(w&&A){var F=u.getPtId(A);p.each((function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var B=function(){return R||{x0:0,x1:g,y0:0,y1:m}},N=p;return w&&(N=N.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),N.each((function(s){var p=u.isHeader(s,E);s._hoverX=v(s.x1-E.marker.pad.r),s._hoverY=y(I?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),T=i.ensureSingle(d,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?T.transition().attrTween(\"d\",(function(t){var e=k(t,!1,B(),[g,m]);return function(t){return x(e(t))}})):T.attr(\"d\",x),d.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),T.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=p?P?\"\":u.getPtLabel(s)||\"\":h(s,r,E,e,S)||\"\";var A=i.ensureSingle(d,\"g\",\"slicetext\"),z=i.ensureSingle(A,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),O=i.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));z.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",L?\"end\":C||p?\"start\":\"middle\").call(a.font,O).call(o.convertToTspans,t),s.textBB=a.bBox(z.node()),s.transform=b(s,{fontSize:O.size,isHeader:p}),s.transform.fontSize=O.size,w?z.transition().attrTween(\"transform\",(function(t){var e=M(t,!1,B(),[g,m]);return function(t){return _(e(t))}})):z.attr(\"transform\",_(s))})),R}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"../sunburst/plot\":1309,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1332:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"treemap\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1325,\"./base_plot\":1326,\"./calc\":1327,\"./defaults\":1329,\"./layout_attributes\":1333,\"./layout_defaults\":1334,\"./plot\":1336,\"./style\":1337}],1333:[function(t,e,r){\"use strict\";e.exports={treemapcolorway:{valType:\"colorlist\",editType:\"calc\"},extendtreemapcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1334:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"treemapcolorway\",e.colorway),r(\"extendtreemapcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1333}],1335:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\");e.exports=function(t,e,r){var i,a=r.flipX,o=r.flipY,s=\"dice-slice\"===r.packing,l=r.pad[o?\"bottom\":\"top\"],c=r.pad[a?\"right\":\"left\"],u=r.pad[a?\"left\":\"right\"],f=r.pad[o?\"top\":\"bottom\"];s&&(i=c,c=l,l=i,i=u,u=f,f=i);var h=n.treemap().tile(function(t,e){switch(t){case\"squarify\":return n.treemapSquarify.ratio(e);case\"binary\":return n.treemapBinary;case\"dice\":return n.treemapDice;case\"slice\":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(c).paddingRight(u).paddingTop(l).paddingBottom(f).size(s?[e[1],e[0]]:e)(t);return(s||a||o)&&function t(e,r,n){var i;n.swapXY&&(i=e.x0,e.x0=e.y0,e.y0=i,i=e.x1,e.x1=e.y1,e.y1=i);n.flipX&&(i=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-i);n.flipY&&(i=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-i);var a=e.children;if(a)for(var o=0;o<a.length;o++)t(a[o],r,n)}(h,e,{swapXY:s,flipX:a,flipY:o}),h}},{\"d3-hierarchy\":161}],1336:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../sunburst/helpers\"),a=t(\"../../lib\"),o=t(\"../bar/constants\").TEXTPAD,s=t(\"../bar/plot\").toMoveInsideBar,l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../bar/style\").resizeText,h=t(\"./constants\"),p=t(\"./draw_descendants\"),d=t(\"./draw_ancestors\");function g(t){return i.isHierarchyRoot(t)?\"\":i.getPtId(t)}function m(t,e,r,l){var u=t._fullLayout,f=e[0],m=f.trace,v=f.hierarchy,y=i.findEntryWithLevel(v,m.level),x=n.select(r),b=x.selectAll(\"g.pathbar\"),_=x.selectAll(\"g.slice\");if(!y)return b.remove(),void _.remove();var w=i.isHierarchyRoot(y),T=!u.uniformtext.mode&&i.hasTransition(l),k=i.getMaxDepth(m),M=u._size,A=m.domain,S=M.w*(A.x[1]-A.x[0]),E=M.h*(A.y[1]-A.y[0]),C=S,L=m.pathbar.thickness,I=m.marker.line.width+h.gapWithPathbar,P=m.pathbar.visible?m.pathbar.side.indexOf(\"bottom\")>-1?E+I:-(L+I):0,z={x0:C,x1:C,y0:P,y1:P+L},O=function(t,e,r){var n=m.tiling.pad,i=function(t){return t-n<=e.x0},a=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return{x0:i(t.x0-n)?0:a(t.x0-n)?r[0]:t.x0,x1:i(t.x1+n)?0:a(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},D=null,R={},F={},B=null,N=function(t,e){return e?R[g(t)]:F[g(t)]},j=function(t,e,r,n){if(e)return R[g(v)]||z;var i=F[m.level]||r;return function(t){return t.data.depth-y.data.depth<k}(t)?O(t,i,n):{}};f.hasMultipleRoots&&w&&k++,m._maxDepth=k,m._backgroundColor=u.paper_bgcolor,m._entryDepth=y.data.depth,m._atRootLevel=w;var U=-S/2+M.l+M.w*(A.x[1]+A.x[0])/2,V=-E/2+M.t+M.h*(1-(A.y[1]+A.y[0])/2),q=function(t){return U+t},H=function(t){return V+t},G=H(0),Y=q(0),W=function(t){return Y+t},X=function(t){return G+t};function Z(t,e){return t+\",\"+e}var J=W(0),K=function(t){t.x=Math.max(J,t.x)},Q=m.pathbar.edgeshape,$=function(t,e){var r=t.x0,n=t.x1,i=t.y0,a=t.y1,l=t.textBB,f=function(t){return-1!==m.textposition.indexOf(t)},h=f(\"bottom\"),p=f(\"top\")||e.isHeader&&!h?\"start\":h?\"end\":\"middle\",d=f(\"right\"),g=f(\"left\")||e.onPathbar?-1:d?1:0,v=m.marker.pad;if(e.isHeader){if((r+=v.l-o)>=(n-=v.r-o)){var y=(r+n)/2;r=y,n=y}var x;h?i<(x=a-v.b)&&x<a&&(i=x):i<(x=i+v.t)&&x<a&&(a=x)}var b=s(r,n,i,a,l,{isHorizontal:!1,constrained:!0,angle:0,anchor:p,leftToRight:g});return b.fontSize=e.fontSize,b.targetX=q(b.targetX),b.targetY=H(b.targetY),isNaN(b.targetX)||isNaN(b.targetY)?{}:(r!==n&&i!==a&&c(m.type,b,u),{scale:b.scale,rotate:b.rotate,textX:b.textX,textY:b.textY,anchorX:b.anchorX,anchorY:b.anchorY,targetX:b.targetX,targetY:b.targetY})},tt=function(t,e){for(var r,n=0,i=t;!r&&n<k;)n++,(i=i.parent)?r=N(i,e):n=k;return r||{}},et=function(t,e,r,i){var o,s=N(t,e);if(s)o=s;else if(e)o=z;else if(D)if(t.parent){var l=B||r;l&&!e?o=O(t,l,i):(o={},a.extendFlat(o,tt(t,e)))}else o=t;else o={};return n.interpolate(o,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},rt=function(t,e,r,o){var s=N(t,e),l={},f=j(t,e,r,o);a.extendFlat(l,{transform:$({x0:f.x0,x1:f.x1,y0:f.y0,y1:f.y1,textBB:t.textBB,_text:t._text},{isHeader:i.isHeader(t,m)})}),s?l=s:t.parent&&a.extendFlat(l,tt(t,e));var h=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,h,u),n.interpolate(l,{transform:{scale:h.scale,rotate:h.rotate,textX:h.textX,textY:h.textY,anchorX:h.anchorX,anchorY:h.anchorY,targetX:h.targetX,targetY:h.targetY}})},nt=function(t,e,r,i,a){var o=i[0],s=i[1];T?t.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var r=function(t,e,r,i){var a,o=N(t,e);if(e)a=z;else{var s=N(y,e);a=s?O(t,s,i):{}}return n.interpolate(o,a)}(t,e,0,[o,s]);return function(t){return a(r(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():t.exit().remove()},it=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,e,u),a.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};T&&(b.each((function(t){R[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(R[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})})),_.each((function(t){F[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(F[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!D&&i.isEntry(t)&&(D=t)}))),B=p(t,e,y,_,{width:S,height:E,viewX:q,viewY:H,pathSlice:function(t){var e=q(t.x0),r=q(t.x1),n=H(t.y0),i=H(t.y1),a=r-e,o=i-n;if(!a||!o)return\"\";return\"M\"+Z(e,n+0)+\"L\"+Z(r-0,n)+\"L\"+Z(r,i-0)+\"L\"+Z(e+0,i)+\"Z\"},toMoveInsideSlice:$,prevEntry:D,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}),m.pathbar.visible?d(t,e,y,b,{barDifY:P,width:C,height:L,viewX:W,viewY:X,pathSlice:function(t){var e=W(Math.max(Math.min(t.x0,t.x0),0)),r=W(Math.min(Math.max(t.x1,t.x1),C)),n=X(t.y0),i=X(t.y1),a=L/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+i)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:i},f={x:e,y:i};return\">\"===Q?(l.x-=a,c.x-=a,u.x-=a,f.x-=a):\"/\"===Q?(u.x-=a,f.x-=a,o.x-=a/2,s.x-=a/2):\"\\\\\"===Q?(l.x-=a,c.x-=a,o.x-=a/2,s.x-=a/2):\"<\"===Q&&(o.x-=a,s.x-=a),K(l),K(f),K(o),K(c),K(u),K(s),\"M\"+Z(l.x,l.y)+\"L\"+Z(c.x,c.y)+\"L\"+Z(s.x,s.y)+\"L\"+Z(u.x,u.y)+\"L\"+Z(f.x,f.y)+\"L\"+Z(o.x,o.y)+\"Z\"},toMoveInsideSlice:$,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}):b.remove()}e.exports=function(t,e,r,a){var o,s,l=t._fullLayout,c=l._treemaplayer,h=!r;(u(\"treemap\",l),(o=c.selectAll(\"g.trace.treemap\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"treemap\",!0),o.order(),!l.uniformtext.mode&&i.hasTransition(r))?(a&&(s=a()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){s&&s()})).each(\"interrupt\",(function(){s&&s()})).each((function(){c.selectAll(\"g.trace\").each((function(e){m(t,e,this,r)}))}))):(o.each((function(e){m(t,e,this,r)})),l.uniformtext.mode&&f(t,l._treemaplayer.selectAll(\".trace\"),\"treemap\"));h&&o.exit().remove()}},{\"../../lib\":778,\"../bar/constants\":923,\"../bar/plot\":932,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./draw_ancestors\":1330,\"./draw_descendants\":1331,d3:169}],1337:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../sunburst/helpers\"),s=t(\"../bar/uniform_text\").resizeText;function l(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,f=u.i,h=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&h===r.root.color)d=100,s=\"rgba(0,0,0,0)\",l=0;else if(s=a.castOption(r,f,\"marker.line.color\")||i.defaultLine,l=a.castOption(r,f,\"marker.line.width\")||0,!r._hasColorscale&&!e.onPathbar){var g=r.marker.depthfade;if(g){var m,v=i.combine(i.addOpacity(r._backgroundColor,.75),h);if(!0===g){var y=o.getMaxDepth(r);m=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else m=e.data.depth-r._entryDepth,r._atRootLevel||m++;if(m>0)for(var x=0;x<m;x++){var b=.5*x/m;h=i.combine(i.addOpacity(v,b),h)}}}t.style(\"stroke-width\",l).call(i.fill,h).call(i.stroke,s).style(\"opacity\",d)}e.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(\".trace\");s(t,e,\"treemap\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(l,t,r,{hovered:!1})}))}))},styleOne:l}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,d3:169}],1338:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":768,\"../box/attributes\":946}],1339:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function f(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var h={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[f(0),f(1)]};return i.setConvert(h),h.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),f=1/0,h=-1/0,p=0,d=0,g=0;g<r.length;g++){var m=r[g],v=m.pts.map(o.extractVal),y=m.bandwidth=l(e,m,v),x=m.span=c(e,m,u,y);if(m.min===m.max&&0===y)x=m.span=[m.min,m.max],m.density=[{v:1,t:x[0]}],m.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var T=o.makeKDE(m,e,v);m.density=new Array(_);for(var k=0,M=x[0];M<x[1]+w/2;k++,M+=w){var A=T(M);m.density[k]={v:A,t:M},p=Math.max(p,A)}}d=Math.max(d,v.length),f=Math.min(f,x[0]),h=Math.max(h,x[1])}var S=i.findExtremes(u,[f,h],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/calc\":947,\"./helpers\":1342}],1340:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(f)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":948}],1341:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,f=l(\"span\");Array.isArray(f)&&(u=\"manual\"),l(\"spanmode\",u);var h=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),m=c(\"box.fillcolor\",d),v=c(\"box.line.color\",h),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||m||v||y))||(e.box={visible:!1});var x=c(\"meanline.color\",h),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":643,\"../../lib\":778,\"../box/defaults\":949,\"./attributes\":1338}],1342:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":778}],1343:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,f=t.cd,h=f[0].trace,p=h.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),m=[];if(d||g){var v=a.hoverOnBoxes(t,e,r,s);if(g&&v.length>0){var y,x,b,_,w,T=t.xa,k=t.ya;\"h\"===h.orientation?(w=e,y=\"y\",b=k,x=\"x\",_=T):(w=r,y=\"x\",b=T,x=\"y\",_=k);var M=f[t.index];if(w>=M.span[0]&&w<=M.span[1]){var A=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(M,h,w),C=o.getPositionOnKdePath(M,h,S),L=b._offset,I=b._length;A[y+\"0\"]=C[0],A[y+\"1\"]=C[1],A[x+\"0\"]=A[x+\"1\"]=S,A[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+f[0].t.labels.kde+\" \"+E.toFixed(3),A.spikeDistance=v[0].spikeDistance;var P=y+\"Spike\";A[P]=v[0][P],v[0].spikeDistance=void 0,v[0][P]=void 0,A.hovertemplate=!1,m.push(A),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+I),u[y+\"2\"]=n.constrain(L+C[1],L,L+I),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(m=m.concat(v))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+h.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+h.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:m:c?(m.push(c),m):m}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/hover\":951,\"./helpers\":1342}],1344:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../box/defaults\":949,\"../box/select\":956,\"../scatter/style\":1211,\"./attributes\":1338,\"./calc\":1339,\"./cross_trace_calc\":1340,\"./defaults\":1341,\"./hover\":1343,\"./layout_attributes\":1345,\"./layout_defaults\":1346,\"./plot\":1347,\"./style\":1348}],1345:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":778,\"../box/layout_attributes\":953}],1346:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,(function(r,a){return n.coerce(t,e,i,r,a)}),\"violin\")}},{\"../../lib\":778,\"../box/layout_defaults\":954,\"./layout_attributes\":1345}],1347:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,f=e.xaxis,h=e.yaxis;function p(t){var e=s(t,{xaxis:f,yaxis:h,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0,linearized:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each((function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,m=e[s.valLetter+\"axis\"],v=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each((function(t){var e,r,i,a,o,l,f,h,_=n.select(this),w=t.density,T=w.length,k=v.c2l(t.pos+d,!0),M=v.l2p(k);if(c.width)e=s.maxKDE/g;else{var A=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?A.maxKDE/g*(A.maxCount/t.pts.length):A.maxKDE/g}if(x){for(f=new Array(T),o=0;o<T;o++)(h=f[o]={})[s.posLetter]=k+w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);r=p(f)}if(b){for(f=new Array(T),l=0,o=T-1;l<T;l++,o--)(h=f[l]={})[s.posLetter]=k-w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);i=p(f)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[M,m.c2p(w[0].t)],E=[M,m.c2p(w[T-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=M,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)}));var w,T,k,M=c.box,A=M.width,S=(M.line||{}).width;y?(w=g*A,T=0):x?(w=[0,g*A/2],T=S*{x:1,y:-1}[s.posLetter]):(w=[g*A/2,0],T=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),o.plotBoxMean(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),!c.box.visible&&c.meanline.visible&&(k=i.identity);var E=r.selectAll(\"path.meanline\").data(k||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each((function(t){var e=m.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])})),o.plotPoints(r,{x:f,y:h},c,s)}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../box/plot\":955,\"../scatter/line_points\":1201,\"./helpers\":1342,d3:169}],1348:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var f={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(f).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(f).call(i.stroke,c.color),a(o,r,t)}))}},{\"../../components/color\":643,\"../scatter/style\":1211,d3:169}],1349:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll,c=e.exports=l(s({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:a.opacityscale,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../isosurface/attributes\":1123,\"../surface/attributes\":1311}],1350:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=u.prototype;f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=c(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"../isosurface/convert\":1125,\"gl-mesh3d\":309}],1351:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults,o=t(\"../surface/defaults\").opacityscaleDefaults;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,s,l),o(t,e,s,l)}},{\"../../lib\":778,\"../isosurface/defaults\":1126,\"../surface/defaults\":1314,\"./attributes\":1349}],1352:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"../isosurface/calc\":1124,\"./attributes\":1349,\"./convert\":1350,\"./defaults\":1351}],1353:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");function f(t){return{marker:{color:c({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:c({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:c({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:f(),decreasing:f(),totals:f(),connector:{line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1355}],1354:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../lib\").mergeArray,o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return\"a\"===t||\"absolute\"===t}function c(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,u,f,h,p=n.getFromId(t,e.xaxis||\"x\"),d=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=p.makeCalcdata(e,\"x\"),f=d.makeCalcdata(e,\"y\"),u=i(e,d,\"y\",f),h=!!e.yperiodalignment):(r=d.makeCalcdata(e,\"y\"),f=p.makeCalcdata(e,\"x\"),u=i(e,p,\"x\",f),h=!!e.xperiodalignment);for(var g,m=Math.min(u.length,r.length),v=new Array(m),y=0,x=!1,b=0;b<m;b++){var _=r[b]||0,w=!1;(r[b]!==s||c(e.measure[b])||l(e.measure[b]))&&b+1<m&&(r[b+1]!==s||c(e.measure[b+1])||l(e.measure[b+1]))&&(w=!0);var T=v[b]={i:b,p:u[b],s:_,rawS:_,cNext:w};l(e.measure[b])?(y=T.s,T.isSum=!0,T.dir=\"totals\",T.s=y):c(e.measure[b])?(T.isSum=!0,T.dir=\"totals\",T.s=y):(T.isSum=!1,T.dir=T.rawS<0?\"decreasing\":\"increasing\",g=T.s,T.s=y+g,y+=g),\"totals\"===T.dir&&(x=!0),h&&(v[b].orig_p=f[b]),e.ids&&(T.id=String(e.ids[b])),T.v=(e.base||0)+y}return v.length&&(v[0].hasTotals=x),a(e.text,v,\"tx\"),a(e.hovertext,v,\"htx\"),o(v,e),v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189}],1355:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1356:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?h.push(r):f.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,f,d),n(t,c,l,h,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var m=r[g];!1===m.isSum&&(m.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":924}],1357:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\"),u=t(\"../../constants/delta.js\"),f=u.INCREASING.COLOR,h=u.DECREASING.COLOR;function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",c.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,c)){s(t,e,i,c),c(\"measure\"),c(\"orientation\",e.x&&!e.y?\"h\":\"v\"),c(\"base\"),c(\"offset\"),c(\"width\"),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var u=c(\"textposition\");if(a(t,e,i,c,u,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&(c(\"texttemplate\"),e.texttemplate||c(\"textinfo\")),p(c,\"increasing\",f),p(c,\"decreasing\",h),p(c,\"totals\",\"#4499FF\"),c(\"connector.visible\"))c(\"connector.mode\"),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.waterfallmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1353}],1358:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1359:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,f=u[0].trace,h=\"h\"===f.orientation,p=h?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var m=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+m+\")\":m,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var v=d.hi||f.hoverinfo,y=[];if(v&&\"none\"!==v&&\"skip\"!==v){var x=\"all\"===v,b=v.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(h?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(f,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1360:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1353,\"./calc\":1354,\"./cross_trace_calc\":1356,\"./defaults\":1357,\"./event_data\":1358,\"./hover\":1359,\"./layout_attributes\":1361,\"./layout_defaults\":1362,\"./plot\":1363,\"./style\":1364}],1361:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1362:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1361}],1363:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;e.exports=function(t,e,r,c){var u=t._fullLayout;l(\"waterfall\",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),u=r[0].trace,f=i.ensureSingle(s,\"g\",\"lines\");if(u.connector&&u.connector.visible){var h=\"h\"===u.orientation,p=u.connector.mode,d=f.selectAll(\"g.line\").data(i.identity);d.enter().append(\"g\").classed(\"line\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var u=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,l,c,h),f=u[0],d=u[1],m=\"\";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&(\"spanning\"===p&&!r.isSum&&s>0&&(m+=h?\"M\"+f[0]+\",\"+d[1]+\"V\"+d[0]:\"M\"+f[1]+\",\"+d[0]+\"H\"+f[0]),\"between\"!==p&&(r.isSum||s<g-1)&&(m+=h?\"M\"+f[1]+\",\"+d[0]+\"V\"+d[1]:\"M\"+f[0]+\",\"+d[1]+\"H\"+f[1]),f[2]!==o&&d[2]!==o&&(m+=h?\"M\"+f[1]+\",\"+d[1]+\"V\"+d[2]:\"M\"+f[1]+\",\"+d[1]+\"H\"+f[2])),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,c)}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1364:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l(t,s,\"waterfall\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1365:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case\"count\":return f;case\"first\":return h;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case\"avg\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case\"min\":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case\"max\":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case\"range\":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case\"median\":return function(t,e){for(var r=[],o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&r.push(l)}if(!r.length)return s;r.sort(i.sorterAsc);var c=(r.length-1)/2;return a((r[Math.floor(c)]+r[Math.ceil(c)])/2)};case\"mode\":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case\"rms\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var f=u-c;a+=f,o+=f*f,l++}}var h=\"sample\"===t.funcmode?l-1:l;return h?Math.sqrt((o-a*a/l)/h):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function f(t,e){return e.length}function h(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var f=o(\"groups\");if(!Array.isArray(f)){if(!u[f])return n.enabled=!1,n;u[f]=0}var h,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],h,c,t,e)}for(r=0;r<p.length;r++){h={_index:r};var m=g(\"target\"),v=g(\"func\");g(\"enabled\")&&m&&(u[m]||\"count\"===v&&void 0===u[m])?(\"stddev\"===v&&g(\"funcmode\"),u[m]=0,d[r]=h):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,f,h={},p={},d=[],g=o(e.transforms,r),m=a.length;for(e._length&&(m=Math.min(m,e._length)),s=0;s<m;s++)void 0===(c=h[l=a[s]])?(h[l]=d.length,f=[s],d.push(f),p[h[l]]=g(s)):(d[c].push(s),p[h[l]]=(p[h[l]]||[]).concat(g(s)));r._indexToPoints=p;var v=r.aggregations;for(s=0;s<v.length;s++)u(t,e,d,v[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1366:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,f=i.length;e._length&&(f=Math.min(f,e._length));var h=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(h=g)}var m,v,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,f=function(r){return e(r,0,t.valuecalendar)},h=function(t){return e(t,0,r)};o(l)?s=f(a?i[0]:i):o(c)?s=a?[f(i[0]),f(i[1])]:[f(i),f(i)]:o(u)&&(s=a?i.map(f):[f(i)]);switch(n){case\"=\":return function(t){return h(t)===s};case\"!=\":return function(t){return h(t)!==s};case\"<\":return function(t){return h(t)<s};case\"<=\":return function(t){return h(t)<=s};case\">\":return function(t){return h(t)>s};case\">=\":return function(t){return h(t)>=s};case\"[]\":return function(t){var e=h(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=h(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=h(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=h(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=h(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=h(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=h(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=h(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(h(t))};case\"}{\":return function(t){return-1===s.indexOf(h(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),h),x={},b={},_=0;d?(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(f))},v=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},v=function(t,e){var r=x[t.astr][e];t.get().push(r)}),k(m);for(var w=o(e.transforms,r),T=0;T<f;T++){y(i[T])?(k(v,T),b[_++]=w(T)):d&&_++}r._indexToPoints=b,e._length=_}}function k(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":749,\"../lib\":778,\"../plots/cartesian/axes\":828,\"../registry\":911,\"./helpers\":1368}],1367:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,f,h,p,d,g,m=e.transform,v=e.transformIndex,y=t.transforms[v].groups,x=o(t.transforms,m);if(!n.isArrayOrTypedArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,T=i.findArrayAttributes(t),k=m.styles||[],M={};for(r=0;r<k.length;r++)M[k[r].target]=k[r].value;m.styles&&(g=n.keyedContainer(m,\"styles\",\"target\",\"value.name\"));var A={},S={};for(r=0;r<b.length;r++){A[f=b[r]]=r,S[f]=0,(h=_[r]=n.extendDeepNoArrays({},t))._group=f,h.transforms[v]._indexToPoints={};var E=null;for(g&&(E=g.get(f)),h.name=E||\"\"===E?E:n.templateString(m.nameformat,{trace:t.name,group:f}),p=h.transforms,h.transforms=[],s=0;s<p.length;s++)h.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<T.length;s++)n.nestedProperty(h,T[s]).set([])}for(l=0;l<T.length;l++){for(c=T[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[A[y[s]]].push(u[s])}for(s=0;s<w;s++){(h=_[A[y[s]]]).transforms[v]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)f=b[r],h=_[r],a.clearExpandedTraceDefaultColors(h),h=n.extendDeepNoArrays(h,M[f]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var f=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(f)?u.value=n.extendDeep({},f):f&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/plots\":891,\"./helpers\":1368}],1368:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1369:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction,o=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var s=n.getTargetArray(e,r);if(s){var l=r.target,c=s.length;e._length&&(c=Math.min(c,e._length));var u,f,h=e._arrayAttrs,p=function(t,e,r,n){var i,a=new Array(n),s=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:n-i};case\"descending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:i-n}}}(t,r)),i=0;i<n;i++)s[i]=a[i].i;return s}(r,s,i.getDataToCoordFunc(t,e,l,s),c),d=a(e.transforms,r),g={};for(u=0;u<h.length;u++){var m=n.nestedProperty(e,h[u]),v=m.get(),y=new Array(c);for(f=0;f<c;f++)y[f]=v[p[f]];m.set(y)}for(f=0;f<c;f++)g[f]=d(p[f]);r._indexToPoints=g,e._length=c}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1370:[function(t,e,r){\"use strict\";r.version=\"1.58.4\"},{}]},{},[26])(26)}));</script>                <div id=\"0db67ef0-324f-491c-aa4d-7eb97afbd48c\" class=\"plotly-graph-div\" style=\"height:500px; width:800px;\"></div>            <script type=\"text/javascript\">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"0db67ef0-324f-491c-aa4d-7eb97afbd48c\")) {                    Plotly.newPlot(                        \"0db67ef0-324f-491c-aa4d-7eb97afbd48c\",                        [{\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": true, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03413023987377528, 0.01557639210659545, 0.126616865163669, 0.0365888266969705, 0.02111386762408074, 0.031019418420328293, 0.03276846568041947, 0.04248334575095214, 0.05971519844024442, 0.054660697787767276, 0.013412867428996833, 0.03352815030666534, 0.05024024358135648, 0.0304563361351029, 0.03051031810173299, 0.010706121265684487, 0.03175519661454018, 0.044217934118933044, 0.0414948978141183, 0.0581653046538122, 0.00812658292488777, 0.02589594998426037, 0.025442965306865517, 0.0262167674372904, 0.04444607773621101, 0.03646748555183876, 0.02454746951116249, 0.025233132328139618, 0.019646203800220974, 0.0426018481812207, 0.03893507462635171, 0.02380063888267614, 0.013527384526241804, 0.06355474397423677, 0.041247495464631356, 0.06583621725440025, 0.029619993219967, 0.061404812659020536, 0.05991626108880155, 0.07438223328790627, 0.03468611590506043, 0.023309773132496048, 0.053070950671099126, 0.048754092858871445, 0.01149658461145009, 0.03195299010258168, 0.0292028283001855, 0.09714149055071175, 0.018545311213529203, 0.03714915190357715, 0.03302772754977923, 0.06878851039800793, 0.02350570011913078, 0.010813043409143575, 0.027420749902375974, 0.015143410164455418, 0.04150493165070657, 0.06922763175680302, 0.03332373686134815, 0.04774696135427803, 0.021120663841429632, 0.02380362417170545, 0.034611214650794864, 0.07188771909568459, 0.03920591399946716, 0.050599417081684805, 0.03365092008607462, 0.055088694352889434, 0.042763209639815614, 0.03766992063901853, 0.06947697853320278, 0.04985381099686492, 0.02063227500912035, 0.042712903159554116, 0.05917109658184927, 0.040733272471698, 0.02693867303605657, 0.06435721341404133, 0.027082443739345763, 0.03306300925032701, 0.13028141227550805, 0.01211212838825304, 0.07668843492865562, 0.0382114286912838, 0.03751025869860314, 0.044229756531422026, 0.04138702293857932, 0.04392318274767604, 0.12968796130735427, 0.04267778102075681, 0.040936305522336625, 0.04944151827658061, 0.010992434417858021, 0.05180302476219367, 0.003644764005912293, 0.022327470178424846, 0.013302586139616324, 0.027860938098456245, 0.01669593115366297, 0.01659186906181276, 0.10248450853396207, 0.018240279241581447, 0.006856604049971793, 0.026493330624361988, 0.022350500876200385, 0.0456449876219267, 0.04344743640103843, 0.03369993151864037, 0.03767752023122739, 0.0521527692762902, 0.048626951829646714, 0.048114513701875694, 0.04713048896519467, 0.06147800697362982, 0.049024553736671805, 0.05916020556469448, 0.057509209000272676, 0.041883779485942796, 0.02906630095822038, 0.03823744467808865, 0.043616846451186575, 0.0806163702509366, 0.032112028638948686, 0.019352895906195045, 0.03916863221093081, 0.04634653982066084, 0.02682837690372253, 0.04389026107673999, 0.01482580992160365, 0.039267226529773325, 0.019075894851994235, 0.05493245742400177, 0.1256843120791018, 0.06716457995935343, 0.037383384842542, 0.025647560578363482, 0.034881538231275044, 0.025617815299483482, 0.02903397115005646, 0.07147175274440087, 0.04414362287207041, 0.030581152386730537, 0.046766365339863114, 0.017513273232907522, 0.079360604431713, 0.04275968072761316, 0.10858358204131946, 0.06128662564151455, 0.0340885385958245, 0.012569341452035587, 0.06876988991280086, 0.06482973141828552, 0.05099463669466786, 0.009894566082948586, 0.028364548379613552, 0.016916078129725065, 0.054010331514291465, 0.02110842953698011, 0.015406153634103248, 0.037824769751750864, 0.027948736023972742, 0.036378561417222954, 0.018649295379873365, 0.04018290688691195, 0.020966260017303284, 0.016288159968098626, 0.028362759803712834, 0.040355036908295006, 0.01463741851694067, 0.010631287732394412, 0.04152863213676028, 0.019629119560704567, 0.04413708455103915, 0.03697226842632517, 0.011851916569867171, 0.021832760103279725, 0.023709812994638924, 0.02993854712258326, 0.09240233586751856, 0.012388821451168042, 0.030474687591777183, 0.041558028606232256, 0.03158013510983437, 0.03505073305859696, 0.037886876380071044, 0.044695109099848196, 0.026179830747423694, 0.033596368521102704, 0.029867586672480684, 0.08495731075527146, 0.05121338472235948, 0.0389650202851044, 0.0644029445538763, 0.04205888180877082, 0.04982797683624085, 0.12253654465894215, 0.004979893010386149, 0.037947561795590445, 0.047050381544977427, 0.035477048659231514, 0.04742343691759743, 0.016104619426187128, 0.043439142900751904, 0.021031318538007326, 0.01833430378610501, 0.01819813267502468, 0.04571423742163461, 0.06263880015467294, 0.008003186030691722, 0.029681908745260444, 0.022869618333061226, 0.03959891459089704, 0.0259062788245501, 0.06092201962019317, 0.054335841196007095, 0.08802820651908405, 0.019527651274984237, 0.02786589193419786, 0.014278814614954172, 0.03975022365921177, 0.030806913709966466, 0.03692199163197074, 0.04858778869675007, 0.06583992799278349, 0.06380330407409929, 0.015459830392501317, 0.014785137445869623, 0.005233966339801555, 0.06922769112861715, 0.024562139915360603, 0.013279505346872611, 0.057155649847118184, 0.05781625775853172, 0.026256169912812766, 0.0860976280819159, 0.04353734759206418, 0.014748746234545251, 0.04404599705594592, 0.011828776405309327, 0.014081631543376716, 0.03191444666299503, 0.023676065684412606, 0.039788214198779315, 0.04169635380094405, 0.041725193659658544, 0.0734303992066998, 0.038712604728061706, 0.037014778645243496, 0.06503687225631438, 0.05185329784580972, 0.02190793409681646, 0.06314038066193461, 0.02086866388708586, 0.021096169257361908, 0.007519669397879625, 0.019454273278824985, 0.08543950636521913, 0.04451984350453131, 0.02263997001136886, 0.05763883993495256, 0.019662560735014267, 0.03847349958959967, 0.03461726686509792, 0.10251245039398782, 0.014667610012111254, 0.05622449200018309, 0.06182274199090898, 0.04057184050907381, 0.02166348735045176, 0.06366827772581019, 0.03683756120153703, 0.03871306857035961, 0.013164808278816054, 0.054242508704192005, 0.016633191844448447, 0.021935870390734635, 0.08890965531463735, 0.00419018387219694, 0.03343629097798839, 0.022289872977125924, 0.03247818574891426, 0.04065101653395686, 0.07045559672405943, 0.04893633464234881, 0.10052849669591524, 0.019250384902989026, 0.04447489161975682, 0.032853912853170186, 0.049753205457818694, 0.04559221721137874, 0.048429811431560665, 0.021068455607746728, 0.033383746922481805, 0.012315003732510377, 0.05231842034845613, 0.03473567281616852, 0.1001827375148423, 0.028185681512695737, 0.029871028382331133, 0.04268264950951561, 0.041261792939621955, 0.022202190084499307, 0.029900135414209217, 0.04592382363625802, 0.05182897766644601, 0.026639940042514354, 0.08550319005735219, 0.018785646461765282, 0.08500576557707973, 0.01413005760696251, 0.015607074346917216, 0.006046614334991318, 0.056728603231022134, 0.022548619053850416, 0.037336169407353736, 0.07022316349321045, 0.08421035396168008, 0.028687686899502296, 0.11044649887480773, 0.019844611415464897, 0.031332639991887845, 0.05339189614460338, 0.09987139172153547, 0.05926217665546574, 0.06537872774060816, 0.015190049507509684, 0.048758890843600966, 0.11463689472293481, 0.04300183238228783, 0.003945792323065689, 0.01343166695733089, 0.057605777255957946, 0.05889852429390885, 0.0568588130408898, 0.09940137475496158, 0.03534581097483169, 0.00571249945096497, 0.020567019819281995, 0.030665367594338022, 0.07612244342453778, 0.03501124338072259, 0.07522074141888879, 0.030959263640397694, 0.07791752796038054, 0.03153404773911461, 0.034799968780134805, 0.03171302407281473, 0.03532861912390217, 0.0206374644767493, 0.012568471283884719, 0.025765409918676596, 0.045283123836270534, 0.19742860371479765, 0.13670959859155118, 0.1506576852989383, 0.12691210635239258, 0.1515126394224353, 0.11071652930695564, 0.15400138712720945, 0.08893245409126393, 0.1337974556372501, 0.09705831806058995, 0.14004374155774713, 0.1570555177750066, 0.17634041811106727, 0.14856665453407913, 0.10602076799841598, 0.1224962757260073, 0.17947014392120764, 0.17386876948876306, 0.14097262843279168, 0.22496118413982913, 0.12613249506102875, 0.11326606632792391, 0.11891231100889854, 0.14784828526899219, 0.1435017489711754, 0.12466987041989341, 0.12288424084545113, 0.11908278233022429, 0.11920053148060106, 0.05239970036200248, 0.09471325756749138, 0.15183421201072633, 0.061648637856706046, 0.15473605395527557, 0.09183607719023712, 0.14206268009729683, 0.1044508584891446, 0.16293533117277548, 0.135927805386018, 0.12690524890786037, 0.19533525744918734, 0.10059694497613236, 0.09516429781797342, 0.19224044226575643, 0.09033672366058454, 0.12099509651307017, 0.1091622568492312, 0.2142061581253074, 0.11345873528625816, 0.14220307959476486, 0.14218911237549037, 0.18007079372182488, 0.1442732708528638, 0.09703765666927211, 0.17606819834327325, 0.14859911607345566, 0.1657210270059295, 0.15938480762997642, 0.09022068144986406, 0.09523293905658647, 0.1330953394062817, 0.10700938291847706, 0.1450883864890784, 0.16428826638730243, 0.26165179267991334, 0.14184281142661348, 0.22230499307624996, 0.173945359128993, 0.1050864634453319, 0.13105637772241607, 0.09932577217114158, 0.13247376104118302, 0.11551245086593553, 0.14852821128442883, 0.16736406774725765, 0.1373757651890628, 0.09323792735813186, 0.12308251301874407, 0.12224856167449616, 0.1289346517296508, 0.1812846356187947, 0.1543191005475819, 0.10167492931941524, 0.1284837376442738, 0.13264390581753105, 0.2379800722701475, 0.14621051377616823, 0.15289922361262143, 0.1615337110706605, 0.1758359803352505, 0.10337500410969369, 0.1743743650149554, 0.08898370680981316, 0.153609310509637, 0.19488165678922087, 0.25577445805538446, 0.08187842948245816, 0.1456619330565445, 0.10870314203202724, 0.09503445908194408, 0.1781339367153123, 0.09050637119798921, 0.10996286349836737, 0.12970314564881846, 0.21945504209725186, 0.09562451101373881, 0.1759256169316359, 0.10890592646319419, 0.17352620896417648, 0.13658491778187454, 0.13375841866945848, 0.121219462598674, 0.13579153222963214, 0.15223399212118238, 0.17180285300128162, 0.1009215677913744, 0.17554603808093816, 0.08803677832474932, 0.14424018590943888, 0.13578589190728962, 0.1904403037042357, 0.13005698681809008, 0.12667313480051234, 0.1686427733511664, 0.12892481085145846, 0.1133137418946717, 0.14302675961516798, 0.12719507241854444, 0.1358558764331974, 0.08503355158609338, 0.11664677906082943, 0.12358734413282946, 0.12829918036004528, 0.20716417115181684, 0.06433696020394564, 0.15327510656788945, 0.1421097174170427, 0.06233492778846994, 0.07793439697707072, 0.08869378681993112, 0.21979806275339797, 0.09957671456504613, 0.22023693920345977, 0.1262906170450151, 0.14131661388091743, 0.116465746978065, 0.23190177889773622, 0.14141662570182234, 0.12258993476280011, 0.13610033987788484, 0.1438945677364245, 0.18574874295154586, 0.12450636786525138, 0.13905597268603742, 0.10912771729636006, 0.14260125666623935, 0.18893018161179498, 0.17942044971277937, 0.15105368045624346, 0.1780276166391559, 0.10746705796918832, 0.0870880315778777, 0.13285513588925824, 0.17363766470225528, 0.058633740845834836, 0.13088776177028194, 0.10973074196954258, 0.14208596869139, 0.08783269513514824, 0.08515506342519075, 0.12910660734632984, 0.11281653263722546, 0.1207620844070334, 0.11748424818506464, 0.14414738776395097, 0.09160581845208071], [0.014851879714115057, 0.031585957258357666, 0.01726272046653321, 0.1036062573257368, 0.039259010954992846, 0.034333985386183485, 0.03290113199909683, 0.07114134117728099, 0.036094997922191396, 0.028333370755717624, 0.01909183061798103, 0.011405230870877858, 0.12631124875042588, 0.023001004446996376, 0.010501919332455145, 0.016586583114985842, 0.04114914234378375, 0.006366928055285825, 0.08787917584413663, 0.023586555253132246, 0.029131737974239513, 0.018610252845974173, 0.010391575888206717, 0.011720876482286258, 0.025421754726266954, 0.01987965191801777, 0.018080910449498333, 0.056801589744281955, 0.007628884313817252, 0.044953988763154484, 0.025280581539846025, 0.024695661559235305, 0.05758316401625052, 0.016542981938982848, 0.012974211767868837, 0.017233034559467342, 0.014598963207390625, 0.07993323073606007, 0.047135105123743415, 0.03398158398340456, 0.05754865786002483, 0.07631529049831443, 0.04373541196400765, 0.031593679304933175, 0.01257972966413945, 0.015576306759612635, 0.04814170970348641, 0.04570206248899922, 0.07281268743099645, 0.04915720892313402, 0.041647342368378304, 0.02886981179472059, 0.04600114429194946, 0.03460763749899343, 0.039680480331298895, 0.0588793471979443, 0.0487848660122836, 0.05628403079754207, 0.030637232775916345, 0.007332423683692468, 0.027495055583131034, 0.09456807121750899, 0.02736353959335247, 0.025168003303406294, 0.021115871422807686, 0.037060498652863316, 0.028139822352386545, 0.030724860007467214, 0.024704930983716622, 0.030695112873218022, 0.01971298781427322, 0.06518689740914851, 0.01741525778925279, 0.02420759185042698, 0.015267474063875852, 0.06606247581657954, 0.005848443279319326, 0.05127136129885912, 0.02873518991691526, 0.07399748908937909, 0.020144559675827622, 0.024033697372942697, 0.031013627813081257, 0.02835728089848999, 0.014760829326405656, 0.040987109241541475, 0.034257225051987916, 0.03687327334773727, 0.021524920957745053, 0.01970324712601723, 0.05960869282716885, 0.023608784431417007, 0.03657396890048403, 0.04063262982526794, 0.038318665319820866, 0.05969981000816915, 0.02678651420865208, 0.03339024442539085, 0.053678417098126374, 0.0466521896305494, 0.033095934632001445, 0.02110607507347595, 0.06530929240398109, 0.0070444972880068235, 0.009799702911550412, 0.028412201681931037, 0.07625363286933862, 0.05644007105729543, 0.041092182509601116, 0.04757152506499551, 0.011748845245165285, 0.03961561662435997, 0.03754995617782697, 0.05372657877160236, 0.06247834040550515, 0.01013339291603188, 0.014894295309204608, 0.04032506898511201, 0.008577464541303925, 0.04643540087272413, 0.02029633444180945, 0.012029739791614702, 0.05221513936703559, 0.04048112779855728, 0.03825364947260823, 0.05171224896912463, 0.03055891578696901, 0.07828725851140916, 0.05406069365562871, 0.053407967352541164, 0.029286447934282478, 0.027231010571995284, 0.013538189268729184, 0.02946823700767709, 0.017825394570536446, 0.028529527808132116, 0.002195793490500364, 0.022590344451600686, 0.047982118267100304, 0.10240727322525345, 0.006765433063264936, 0.07270687201526016, 0.047593848867109045, 0.05116734188050032, 0.07529464448452927, 0.03917180860298686, 0.016178656078409404, 0.009986995937651955, 0.05560015284572728, 0.1428708789171651, 0.08948735048761591, 0.039694881706964225, 0.0937357525981497, 0.050917683402076364, 0.004048409546157927, 0.0396734855894465, 0.015223373793560313, 0.03561261677532457, 0.08544341006199829, 0.10161420679651201, 0.03136195482511539, 0.033205928339157254, 0.06018451778800227, 0.03381855640327558, 0.03266283209086396, 0.05676685723301489, 0.015540821896138368, 0.027281563816359267, 0.032023434760048985, 0.02693037582503166, 0.019532529040588997, 0.03239083496737294, 0.02097013217280619, 0.08844692623824812, 0.041429566554143094, 0.0617068333667703, 0.05285844410536811, 0.04519221074588131, 0.05045664271165151, 0.044447588006732985, 0.02632259584061103, 0.050981422755285166, 0.02673651571967639, 0.016441749285149854, 0.01509296638687374, 0.004128707141717314, 0.01913728345243726, 0.08518251546774991, 0.004477526290429523, 0.06500029179733247, 0.0035196397629988496, 0.06086063658585772, 0.026939548770315014, 0.05657783964124974, 0.025970161041186657, 0.02579415144282393, 0.0055245644671231275, 0.00929142173845321, 0.055122424964793026, 0.0328707076550927, 0.045326962499530055, 0.030994691915111616, 0.0412068294826895, 0.012857765086664585, 0.0342559448472457, 0.004889216015726561, 0.0824261418893002, 0.024964884905784857, 0.03656621716800146, 0.04385906118841376, 0.046210745349526405, 0.01908687307150103, 0.025424513660254888, 0.06082018582674209, 0.03205649372830521, 0.023655881122977007, 0.08814645290840417, 0.031236980867106467, 0.06254390173126012, 0.020634449501812924, 0.036436675291042775, 0.038528199584106915, 0.0492973523796536, 0.026756629777082708, 0.04306689646909945, 0.04160378943197429, 0.024908173691073898, 0.025925389127223752, 0.03675510859466158, 0.07956102883326821, 0.03708329000801314, 0.04775490233441815, 0.021223429030214902, 0.07625539175933227, 0.04056438563566189, 0.0295831659968826, 0.08300231565954164, 0.08525070399628021, 0.039682235510554165, 0.08800009396509267, 0.01821174366341438, 0.02331073977984488, 0.04162308156082872, 0.014718927668582182, 0.07203774424851872, 0.032984619901981205, 0.013454960189847043, 0.03398486056539696, 0.019071451242780313, 0.01492595903982874, 0.018814822142303456, 0.03284139653260354, 0.008488166549796006, 0.0495800661155954, 0.02513203140551923, 0.09005835891002789, 0.122490056528477, 0.09447918419027701, 0.025577885899110697, 0.018441098836774472, 0.03748619456018787, 0.05522539053345099, 0.037650120139005594, 0.006409701272787061, 0.04242741008056328, 0.03583258934668265, 0.03632651460065972, 0.004567094701997121, 0.04584782029269263, 0.053737644193461165, 0.10758934906334616, 0.03745978152437601, 0.05018425596063025, 0.012820436913898448, 0.02933612729975721, 0.05243185762083158, 0.022619976552959997, 0.015871282630541828, 0.024524858126824256, 0.00738609765903675, 0.046851482256897725, 0.021484423814399634, 0.050017677203868516, 0.016378989566874225, 0.03986391326179728, 0.02420109620288713, 0.01652380855375668, 0.06354837634717114, 0.027419660800660495, 0.0656052386329975, 0.04671478978707455, 0.021685044885089155, 0.06394185562385246, 0.008804077478998806, 0.020974937579012476, 0.03368338162545115, 0.06667308523901738, 0.046384122179006226, 0.030362363540916704, 0.0681078273919411, 0.035920474474551156, 0.052933686747564934, 0.024558893019275274, 0.06567782809725031, 0.0065406773501308635, 0.01773143496393459, 0.036573419711203314, 0.048370183576480485, 0.03749087751202751, 0.024604151039966382, 0.03515874152071774, 0.017750137085386086, 0.06155528681119904, 0.03051193412829889, 0.06224163240403868, 0.06099090205680113, 0.023901869681139942, 0.033967334748012945, 0.044958337748539634, 0.05081750459794421, 0.06557852873811498, 0.03608937986427918, 0.033126897033071145, 0.009153926821454661, 0.030367265426320955, 0.019419429445406422, 0.05664664044161327, 0.04119904806429986, 0.05440555854875129, 0.0651219001156278, 0.017746454177540727, 0.05643012627842836, 0.029887793498346582, 0.03666803982923739, 0.032948469888651744, 0.06569843011675403, 0.04311874661652837, 0.014529614145430969, 0.010749563807621598, 0.09297709955717437, 0.022177697355800774, 0.0566567930218298, 0.05160389540833421, 0.0744234818557743, 0.008399810158152832, 0.02371908241912024, 0.03694163628097158, 0.08252110710600391, 0.014553257115039742, 0.0355153842974687, 0.0596168490301352, 0.023963391868164763, 0.1586495025549084, 0.1463242108002305, 0.1668257435085252, 0.22749354044208303, 0.18947414617286995, 0.14441588195040822, 0.09818161051953211, 0.19315941404784098, 0.10253830681904219, 0.11639894626569003, 0.05822341481689364, 0.09994335036026314, 0.176067411666736, 0.12730949674732983, 0.05903232980926987, 0.1511198206571862, 0.12430961709469557, 0.17008182738209143, 0.22025010490324348, 0.11103453216492198, 0.1388214688631706, 0.07717457134276628, 0.11283988802460954, 0.21146893937839195, 0.15315351309254766, 0.13488513242918998, 0.13238007231848314, 0.1283708866685629, 0.08288264434668235, 0.12945454102009535, 0.17738671274855733, 0.1277183904312551, 0.13513462763512507, 0.15108832390978932, 0.097805126424646, 0.12664171226788312, 0.10785466685774736, 0.13847369846189395, 0.13237781618954614, 0.10320396133465692, 0.12849727441789582, 0.1426872270531021, 0.11863949752296321, 0.15049114736029878, 0.14343407994601876, 0.09086924430448562, 0.21544505492784083, 0.1729440683266148, 0.1555478002410382, 0.09881485544610769, 0.09053256158949807, 0.1309465547092259, 0.18792189977830276, 0.14060053043067455, 0.1737251490703784, 0.16918633715249598, 0.17931123526068404, 0.15496065752813593, 0.21541608148254454, 0.15051160095026717, 0.15768192010000348, 0.17604534019483253, 0.07958977221278474, 0.1514449852402322, 0.1547283653053455, 0.18372799357166514, 0.22361178154824302, 0.12016356457024813, 0.13415488880127668, 0.09562272985931486, 0.14157589059323072, 0.1257193711353466, 0.11538964026840404, 0.10499006588361226, 0.14070788951357827, 0.12580961629282683, 0.13547631242545322, 0.12447914588847198, 0.20309445593738928, 0.2487484272569418, 0.21828265656949952, 0.19356854521902278, 0.12736699834931642, 0.08977769350167364, 0.07319179130718112, 0.07741629626252688, 0.10058369764010422, 0.15117785660549998, 0.10348892377805896, 0.13015089818509296, 0.0622942580957897, 0.10594167732051574, 0.1921470949309878, 0.1122906467935536, 0.13053920469246805, 0.1753950258716941, 0.12366350332740694, 0.11815960257081315, 0.11831100069684908, 0.22297375719062984, 0.09479494576225989, 0.07912812667200342, 0.23236682347487658, 0.08507499311235733, 0.16154093958903104, 0.11910563305718824, 0.17334741074591875, 0.1434135966701433, 0.20132999983616173, 0.13938015763415024, 0.11549688802915625, 0.1743966739741154, 0.16768958856118843, 0.0889958928746637, 0.15848741750232875, 0.09963455755496398, 0.10427485074615106, 0.09568511479301378, 0.17273601464694366, 0.18925755779491737, 0.1688352567725815, 0.12344079223112203, 0.15237372368574142, 0.16335367981810123, 0.09295965908677317, 0.1514566072728485, 0.1284961760393344, 0.16942992486292496, 0.1463022135430947, 0.14147090638289228, 0.20922259194776416, 0.14735351025592536, 0.14523727615596727, 0.09885808554827236, 0.12475310970330611, 0.11111954518128186, 0.10953223973046988, 0.13340564619284123, 0.18379775545326993, 0.1987158291740343, 0.08692402436281554, 0.25549083889927715, 0.16634327330393717, 0.08586426716647111, 0.21089800517074764, 0.14995809237007052, 0.11210988188395277, 0.11477151289000176, 0.08159033517586067, 0.1348133964347653, 0.23829072044463828, 0.14428852940909564, 0.1918390442733653, 0.16608286852715537, 0.13233321311417967, 0.18189983151387423, 0.08179893804481253, 0.17160781659185886, 0.2029524534009397, 0.1782925336738117, 0.1282940446981229, 0.07689550155191682, 0.11980227223830298, 0.24443475325824693, 0.10381042957305908, 0.20908183621941134, 0.16453264077426866, 0.11770987592171878, 0.1206601652665995, 0.11060963777708821, 0.19204130920115858, 0.1690726401284337, 0.09736039442941546, 0.19154193287249655, 0.1583181187743321, 0.13157991837942973], [0.06722525795339607, 0.03583117555535864, 0.07186759205069393, 0.024937618400144856, 0.024028270418057218, 0.07410751990391873, 0.05299839460349176, 0.037419746367959306, 0.03566690858860966, 0.02570249434938887, 0.036041611529071815, 0.054235588177107275, 0.06372329313308, 0.03273613030614797, 0.029855335669708438, 0.024465976130159106, 0.04033434212033171, 0.013060923374723643, 0.02038053295109421, 0.029836824651283678, 0.014379716085386463, 0.054496030061272904, 0.08243124786531553, 0.048455986980115995, 0.02902102809457574, 0.06398965735570528, 0.004622323940566275, 0.01611497238627635, 0.006436893099817098, 0.019341366642038338, 0.050237104296684265, 0.05266878826660104, 0.04687149797973689, 0.007098593359842198, 0.04417185416969005, 0.007563948247479857, 0.005746658189309528, 0.007815174976713024, 0.018404516522423364, 0.005438997623059549, 0.08310644640005194, 0.02907817532104673, 0.025423020088055637, 0.06989965389948338, 0.02421074783342192, 0.04580660883220844, 0.022252186718105804, 0.046772254281677306, 0.023412970622302964, 0.03899157432897482, 0.06657488425844349, 0.04495888693782035, 0.02701911813346669, 0.02148813826352125, 0.06493416643934324, 0.020334441869636066, 0.05331390755600296, 0.04634263241314329, 0.07514196244301274, 0.07506894253310747, 0.027718228666344658, 0.010336135601392016, 0.04035905934870243, 0.050867914978880435, 0.01817543223296525, 0.018866063728637528, 0.05759517567639705, 0.017998654511757195, 0.0888779730303213, 0.062436780135612935, 0.06485867517767474, 0.021252617698337417, 0.03202527528628707, 0.04723779609776102, 0.16737969737732783, 0.022506181194330566, 0.05986188763927203, 0.04437973344465718, 0.054642645045532845, 0.0366247021156596, 0.06357969497912563, 0.04033543307741638, 0.0435091905092122, 0.03269059583544731, 0.0540400693716947, 0.053896582539891824, 0.0029748330962320324, 0.040939815880847163, 0.030889631634636316, 0.034086694358848035, 0.0070046912696852814, 0.039043654542183504, 0.05398668297857512, 0.019688346656039357, 0.04361863873782568, 0.042416585856699385, 0.096739476575749, 0.018331242426938843, 0.023409564164467156, 0.01787706289178459, 0.059388523586676456, 0.028430388010747265, 0.022881199547555298, 0.14797779003856704, 0.06729502725647762, 0.08582701135310344, 0.03424589987844229, 0.041806499648373574, 0.02168741233617766, 0.03820555088168476, 0.023039640655042604, 0.02012440665566828, 0.043120486952830106, 0.05415691681264434, 0.07513410309911706, 0.03367803816217929, 0.02766534136753762, 0.0992480618879199, 0.022280097036855295, 0.06547363358549774, 0.04144615355471615, 0.04857335392443929, 0.0863193224358838, 0.035423035151325166, 0.006892959545439226, 0.02415249666228192, 0.06521255345433019, 0.01853642585047055, 0.02647441884619184, 0.03166813527059276, 0.04828715209441725, 0.027253115440544207, 0.024879263328330126, 0.031080107546586078, 0.03979979912401177, 0.0509356693510199, 0.034958346805069596, 0.044059834399376996, 0.0909419970412273, 0.04386147316836286, 0.050289444261579774, 0.03825186089670751, 0.014333373601402855, 0.03517115765134804, 0.01978412637981819, 0.013684852492588107, 0.021934473297733348, 0.04638590704416856, 0.022916496091056615, 0.043900781020056456, 0.0913857197156176, 0.014759341320313979, 0.02883312186895637, 0.04526095959590748, 0.08252975312643684, 0.04923307125864085, 0.060797364785685204, 0.026787083806993905, 0.02603494682261953, 0.014550551986758364, 0.0376040847186232, 0.029511400316550862, 0.035086805146420375, 0.06752001674612984, 0.07741475259535946, 0.018449639101163484, 0.018523887265473604, 0.057445699712843634, 0.0887279404560104, 0.05527294735657051, 0.07022776480880566, 0.08892293233657256, 0.07839285870431922, 0.05719495769881178, 0.04583339294185862, 0.04259431909304112, 0.003241738158976659, 0.013722185303777223, 0.05351148211047985, 0.0473369730025297, 0.02251278445328353, 0.03703675734868739, 0.023454579131794162, 0.016985621077765245, 0.0795463120448403, 0.010745757517724996, 0.020244575207470916, 0.060738553293049335, 0.07667664962355047, 0.09720878850203007, 0.037949728866806254, 0.02126953680999577, 0.0018238106372336915, 0.061962922554812394, 0.02374438594415551, 0.01707698687823722, 0.019713075016625226, 0.03853965463349596, 0.043828403067891486, 0.04981779457011726, 0.0612443640420679, 0.01694554139248794, 0.059678525212802924, 0.02666629370651208, 0.059559785295277834, 0.14872073923470452, 0.019044613327423576, 0.03865387487167027, 0.03565766142855864, 0.017672790454525966, 0.027387047121010255, 0.010614735056151403, 0.01924964461068157, 0.04689404071541503, 0.10210609485511668, 0.028913531714351848, 0.02970803605421679, 0.03446495589741971, 0.06635797675698996, 0.039337674897979014, 0.023055329656926915, 0.008188659867300885, 0.06621797801926732, 0.05952348314167466, 0.01019343915686477, 0.0465456023812294, 0.016151209601957817, 0.07927850063424557, 0.010235518930130638, 0.029287845027283765, 0.020528973618638702, 0.01672892518399749, 0.062298258271766827, 0.04432636189449113, 0.038837563843117096, 0.051394008623901755, 0.04443606987479143, 0.007520419894717634, 0.017206647498824168, 0.05825727901537903, 0.051343126979190856, 0.020774698714376427, 0.043497843071236275, 0.011193147329322528, 0.09677115886006504, 0.0511567662761081, 0.03213997420971282, 0.009429096626263345, 0.02159023923013592, 0.03406772877497133, 0.07141560927266255, 0.09229924413375556, 0.017457226240367163, 0.07544859559857287, 0.002947312173091632, 0.03378949761099648, 0.04367080058727879, 0.010025734191003721, 0.023785202211001888, 0.02173342178139137, 0.06684892970952205, 0.02852007655747002, 0.030450163321802393, 0.03607394319260493, 0.0326178727846127, 0.015110122058104025, 0.06138393233413808, 0.04626066962373443, 0.05128234508447349, 0.020233823343005497, 0.02693893464311259, 0.036176036737742834, 0.02895860976423137, 0.027865880801982712, 0.044425267915357836, 0.036856114893453196, 0.04461099779291544, 0.021834207291249186, 0.0187945837751613, 0.06399638863513246, 0.027872458085766993, 0.041774323835852556, 0.0964851128810551, 0.023864498834882397, 0.04858488689933438, 0.07510418712627143, 0.022708494361722842, 0.03446851820626762, 0.0249341785456636, 0.017413022069376893, 0.04184357363556046, 0.0362350263458211, 0.05207852853345685, 0.0635426543885842, 0.01022880805976456, 0.026927095532300882, 0.04083418600203004, 0.039511281793238595, 0.062227360904216766, 0.10677372876671143, 0.04698103526607156, 0.011429251408117125, 0.054220106976572424, 0.04025288770208135, 0.050942586167366244, 0.0727311847731471, 0.01827892287110444, 0.00397045806494134, 0.011988250025751768, 0.06301272384007461, 0.08675068092998117, 0.026767288873088546, 0.07016264135017991, 0.04231672617606819, 0.06843017181381583, 0.09030478162458166, 0.018727567839960102, 0.023477053218812216, 0.013062343659839826, 0.035034624743275344, 0.016903214855119586, 0.028021429388900287, 0.01581485899805557, 0.05676089407643303, 0.027192667512281332, 0.040493317574146204, 0.07758021441986784, 0.02688997887162259, 0.028570423855853733, 0.021410073604783975, 0.015345855990744894, 0.013931669473095099, 0.04997144511435181, 0.03403979433642235, 0.026353070279583335, 0.01557925123051973, 0.029559437680291012, 0.034841087472159415, 0.03772770425712224, 0.05073793152405415, 0.05701297566702124, 0.032641335783409886, 0.08912613237043843, 0.06396574535756372, 0.034310986229684204, 0.015374549275293248, 0.0246403325945721, 0.06374629971105605, 0.04630841198377311, 0.032009916540118866, 0.08061433676630259, 0.07078979324433021, 0.1714074070332572, 0.15858408965868875, 0.1818748062942177, 0.1432403942453675, 0.12095497600967064, 0.17002279695589095, 0.20577846269588917, 0.1081443419388961, 0.13308193621924147, 0.07226618472486734, 0.10655269492417574, 0.17258428997593, 0.17369442415656522, 0.2327797099133022, 0.06416395815904252, 0.07183781708590686, 0.12570424616569653, 0.1783720325329341, 0.09224203939083964, 0.1375581108732149, 0.11944212281377986, 0.20664472714997828, 0.21042626642156392, 0.11779747903347015, 0.16740340157411993, 0.24683046533027664, 0.130741989123635, 0.10345937145757489, 0.16105884045828134, 0.11459120069048367, 0.14553849905496463, 0.10530127066886052, 0.10141893289983273, 0.08328451731358655, 0.14836217800620943, 0.10366164380684495, 0.12536741502117366, 0.14167131594149396, 0.19705665414221585, 0.09241940526408143, 0.2557835419429466, 0.0893254361290019, 0.1193590319599025, 0.12348853459116071, 0.11048212938476354, 0.1640740380389616, 0.13342109770746902, 0.11577812489122152, 0.0602050270390464, 0.10665970519767143, 0.17624175699893385, 0.121421482617734, 0.09988070567487739, 0.22780209576012567, 0.16035046050092205, 0.15244170441292226, 0.1443411922082305, 0.12620008987141773, 0.13741932925768197, 0.14773470698855817, 0.15749274665722623, 0.06526010285597295, 0.11441368638770655, 0.10860042879357934, 0.11861883613164537, 0.15547101764241233, 0.15589184506097808, 0.1161634479649365, 0.2553693641675636, 0.18298032431630418, 0.22192001139046624, 0.09385189870954491, 0.11197398722288199, 0.1387763165985234, 0.22578202915610746, 0.15264494897564873, 0.09244146931450814, 0.12023767543723807, 0.183130995137617, 0.11030050358385779, 0.1457343072979711, 0.12481090816436335, 0.08404521868214943, 0.10514913039514795, 0.14253952482249588, 0.10479661767021753, 0.11525341906235553, 0.12199875476653688, 0.1735353670665063, 0.1375978157739155, 0.15132782980799675, 0.11269524344243109, 0.17468053061747923, 0.16239412740105763, 0.14810943219345063, 0.18026722536887974, 0.16580848168814555, 0.1290352424257435, 0.20213051000609994, 0.11705068551236764, 0.14259097049944103, 0.1768311855266802, 0.134318858908955, 0.18644541181856766, 0.14484365587122738, 0.1301715595764108, 0.1907032317831181, 0.172190610319376, 0.13717814610572532, 0.1313929565367289, 0.22832979244412854, 0.08273850442492403, 0.0909963519370649, 0.10179307180806063, 0.18665444513317198, 0.15150640538195148, 0.10208021616563201, 0.20566749677527696, 0.09052232737303711, 0.11239433966693468, 0.15435292763868347, 0.13820783147821203, 0.12676335027208552, 0.1661639110534452, 0.09142949900706299, 0.12382454195176251, 0.21143558726180345, 0.10465682673384435, 0.08809663995634764, 0.13362561876419932, 0.09792861237656325, 0.10033375714556314, 0.0843497812456917, 0.19683789869304746, 0.19587842049077153, 0.12221117969602346, 0.17322776169748977, 0.076183388591744, 0.1769758597947657, 0.15296977217076346, 0.10322689369786531, 0.13081204786431044, 0.07844429695978761, 0.1701290873461403, 0.1518290169769898, 0.11569204318220727, 0.07193435565568507, 0.14813509566010907, 0.208717753412202, 0.14338368811877444, 0.19093228824203834, 0.10343393063521944, 0.10983125845086761, 0.11627574975136667, 0.10684726075851358, 0.20258013275451958, 0.1227615267271176, 0.13092175213387236, 0.10174509938224219, 0.11566427943762392, 0.11307267006486654, 0.20628226222470403, 0.12311850718106143, 0.1727110191131942, 0.1698016666341573, 0.08252273983089253, 0.1587585685774684, 0.14471029193373397, 0.14348629745654762, 0.12900542293209583, 0.11993117586825974, 0.1948060467839241, 0.1476334928884171, 0.1435138756642118, 0.1655213299090974, 0.18056289700325578], [0.041908474449883215, 0.036634676580433734, 0.03207262801879551, 0.03825260304438416, 0.07865478488383815, 0.018483449493942317, 0.04207005484204274, 0.038234364765230566, 0.0015358138534793397, 0.006515254153782735, 0.028643323166761547, 0.03840063181996811, 0.05954088279395364, 0.06532970888656564, 0.011481579313112888, 0.01958596181793837, 0.02572274755948456, 0.03129389246169012, 0.03833830625808332, 0.018143102424801327, 0.02589900206658058, 0.03640418406575918, 0.07167363175540231, 0.01667822722083656, 0.006539041842188453, 0.05159973938134499, 0.019398248550714925, 0.06648873575613834, 0.02225671381893335, 0.045383551259874366, 0.039411626203218475, 0.025217678958142642, 0.06372759758960456, 0.021211450766713824, 0.02993332796904724, 0.02628054760862142, 0.026043639227282256, 0.017491450380475726, 0.025669125534477644, 0.02583938719908474, 0.0193620243226178, 0.052159040424157865, 0.01614353765035048, 0.0197205391668831, 0.044585983705474064, 0.034522657879278995, 0.042143371611018665, 0.07552094757556915, 0.0479345132043818, 0.017362923390464857, 0.007307526020667865, 0.02610723200632492, 0.021003066831326578, 0.013471587080857717, 0.019732639884750824, 0.03718031097378116, 0.024509707182005513, 0.020241209567757323, 0.022912212043593172, 0.00872659262313391, 0.04578315325488802, 0.03438179825025145, 0.056896217283792794, 0.0169770659704227, 0.029634088459715713, 0.008183531626855256, 0.0226973714234191, 0.03787191097217146, 0.05712349258828908, 0.09323211634182371, 0.013851043477188796, 0.03931857201678213, 0.032301651081070304, 0.01733610959490761, 0.016018149945011828, 0.037805113970534876, 0.02439839987346204, 0.03746837559447158, 0.0030572592640965013, 0.06632368953432888, 0.0366478311480023, 0.022283011821855325, 0.06172284520289395, 0.04687814762291964, 0.03148327370581683, 0.055682360543869436, 0.030789695883868262, 0.03503968990116846, 0.0241339986314415, 0.024764664594840724, 0.03774993529077619, 0.04115518713661004, 0.07822481420589611, 0.03210058101103641, 0.03658465211628936, 0.07111316182999872, 0.04074837146617938, 0.03601590353355277, 0.039759114588378, 0.01494823924076627, 0.02629154252645094, 0.01841502533352468, 0.035343851704965346, 0.07158191714552231, 0.008257977387984283, 0.023565715746372007, 0.03964420786360279, 0.06629971816437319, 0.04328657960286364, 0.026312836598663125, 0.05753380748501513, 0.026330525688536, 0.010046505976788467, 0.007168217944126809, 0.01898504669952672, 0.04682433820562437, 0.04823349852813408, 0.09922718527377583, 0.049107050872407854, 0.03188779985066503, 0.054766550310887396, 0.00997623201328679, 0.08113979216432199, 0.06773613757104613, 0.03822440514340997, 0.024946132689365186, 0.05892147892154753, 0.04036603182612453, 0.0038227442382776644, 0.05680386813764926, 0.06284377392148599, 0.04809328085684683, 0.0318258602055721, 0.03827830732916482, 0.054346661709132604, 0.09365546706249006, 0.033255069647566415, 0.09881391291855834, 0.05302389479766134, 0.04498210873862263, 0.02277475330629386, 0.012987930367671652, 0.03040564559341874, 0.023574231890961528, 0.04776309564476833, 0.04763529410411138, 0.09754039492690936, 0.04248690063832328, 0.039141246961662546, 0.0715822511119768, 0.026920065538433846, 0.03099698144069407, 0.0292301615991164, 0.03865073558699805, 0.0549077290634159, 0.06430260618799366, 0.04455254253116436, 0.03680360794533044, 0.019835816965496633, 0.05615651869447902, 0.06020333123160526, 0.019731380089069717, 0.0353628506854875, 0.06414789808331989, 0.04193555912934244, 0.04336498379416298, 0.0817197360447608, 0.0031444187106899335, 0.05153700192749966, 0.04692972688644659, 0.02236588374216808, 0.038336751458700746, 0.015028381912998157, 0.011223035471630283, 0.055078115037758835, 0.12611555925104767, 0.006720339242747286, 0.04465908154088538, 0.02361475500947563, 0.020063739793840796, 0.030868287467455957, 0.058735392813105136, 0.006259086576392292, 0.023435765688191168, 0.03985084033047315, 0.01039784054228221, 0.03766495196032338, 0.05284969047352206, 0.08402573730563745, 0.04385209613246843, 0.0456680498609785, 0.02126698938809568, 0.04902345535811037, 0.056469586270395666, 0.03356800363690127, 0.027379093153285794, 0.04585308954119682, 0.013570804803748615, 0.03196261575794779, 0.01276925191632472, 0.015831549899303354, 0.0282754127329099, 0.06836613189079799, 0.04994791903300211, 0.008851208494888851, 0.060528878020704724, 0.062160396919352934, 0.045498502513510175, 0.014348153472383274, 0.014112594872131012, 0.047014045994728804, 0.009964811288227793, 0.025831305210886057, 0.044762343968614005, 0.010887545759032946, 0.058369807156850584, 0.004302570541767636, 0.0321481229912024, 0.031801517761778086, 0.06864217371912673, 0.026972106788889505, 0.019192406471120194, 0.07411906772176735, 0.016828458319650963, 0.040535241496399976, 0.019657039156300016, 0.0605277981958352, 0.038960493184276856, 0.05230428243521601, 0.036743571909028105, 0.021778189984615892, 0.0673629337688908, 0.03522159029671457, 0.059264262090437114, 0.021744646765000653, 0.029000353715673555, 0.049370936321793124, 0.07509765622671694, 0.03942259143514093, 0.025122465121967252, 0.024260293612314854, 0.05473731711390428, 0.05063990494818427, 0.07664108590688556, 0.04027451388537884, 0.054738192848162726, 0.09886445317533799, 0.02353055650019087, 0.02510442165657878, 0.007281319858520874, 0.02382901860983111, 0.016104845781228505, 0.09799309016671032, 0.01713885230856249, 0.031214861155604012, 0.1144031404692214, 0.016210089743253775, 0.051059099641861394, 0.02251465652079787, 0.03655381216958631, 0.018373773054918274, 0.04095134143426549, 0.030743487914151046, 0.04218059402774088, 0.03516214055707678, 0.05033257788454648, 0.014712971933477093, 0.06368450849549845, 0.05305995946400799, 0.02786186021694448, 0.025067865317396354, 0.03392712889763061, 0.02709649630560307, 0.01927929712110199, 0.041246942564612255, 0.03126203577267006, 0.057313029683427885, 0.03427537056268193, 0.04182709424640052, 0.08206823375076056, 0.04011335280665662, 0.06679102734779008, 0.03359577851369977, 0.049964320496656, 0.010372832948633004, 0.027459872217150405, 0.06211514075403102, 0.02844065376848448, 0.02888797771447571, 0.022769042479922064, 0.11844846128951758, 0.031138260383158922, 0.08056372229475528, 0.08713953662663698, 0.034447663856553845, 0.022689423021802213, 0.041851280839182436, 0.015568284143228084, 0.01334193759248592, 0.061714518305961974, 0.0710121555312071, 0.05120453832205385, 0.03061218529182952, 0.043194378886255436, 0.03461491796770133, 0.058976312502636574, 0.046918809894123115, 0.04408385400893167, 0.016064849587564822, 0.019512296239554416, 0.022726892202626914, 0.10149426088901237, 0.07040071490337141, 0.08879062967025675, 0.031118918159336317, 0.061032981830067, 0.01443134358851239, 0.04063662629050668, 0.026938943919958547, 0.05602727738732938, 0.03349309496115893, 0.02742463504546322, 0.04987849482859019, 0.06548757854034193, 0.0237472209482803, 0.05019398551667109, 0.025796266563702375, 0.06672231189440936, 0.04955789816449396, 0.019420843236730434, 0.008684305048518581, 0.027074528734374326, 0.05500905077497009, 0.011196012019354384, 0.07583301325212233, 0.03319205388834234, 0.07643847959116101, 0.021498641508514993, 0.04058557766256854, 0.047029401030158624, 0.03658605106465984, 0.05278855605865829, 0.06286652816925198, 0.02462677912262734, 0.027897225409105886, 0.0425697354512522, 0.035038250134675764, 0.07688394631259143, 0.03481638879748061, 0.05654670654621441, 0.04165050391748082, 0.04611845186445862, 0.1957683451473713, 0.15615331853041425, 0.11378896131645888, 0.16120986751047894, 0.12059297863743268, 0.0961742494837381, 0.1716088259126991, 0.1380573387723416, 0.0914416479645297, 0.08820760587695986, 0.13052700378466398, 0.1368557126261294, 0.15139633003855124, 0.17863855260657147, 0.08423157938523218, 0.07191959433839656, 0.12224005666212179, 0.18865570571506396, 0.10897879794356413, 0.10096234138472937, 0.19795901665929705, 0.045659715542569757, 0.17733538581524044, 0.1947588610346429, 0.13081759912893176, 0.11188516698894091, 0.18491948198061436, 0.16577998321736231, 0.08048322153626941, 0.16937116160988808, 0.11025791172869503, 0.13683009368833154, 0.12190634253784083, 0.12524757301434875, 0.20425949420314282, 0.06108298402978107, 0.1317649061093107, 0.26983907679095864, 0.04219181901135016, 0.16591269406490028, 0.1330099330516532, 0.12180012636235915, 0.16548849729588255, 0.09543054329697043, 0.2187448216136545, 0.07788567498209886, 0.16103951493278146, 0.15739319496788085, 0.12493144779000431, 0.14267363090766594, 0.08967772620962933, 0.07658851216547191, 0.08948665286879987, 0.09763377194758505, 0.10505259924684651, 0.18935602594865486, 0.15926403051707894, 0.14889840938849375, 0.14582321658963338, 0.07660036426386796, 0.11896767522557639, 0.09945313213393092, 0.28111595136579126, 0.11266865971265361, 0.1143449783558026, 0.16624376614345238, 0.13867688365280628, 0.19116487732389942, 0.1932162477169186, 0.2831464970950037, 0.15344520681537688, 0.15660973935155198, 0.18575611989945173, 0.1402948101167567, 0.10465447412570938, 0.15363755665021017, 0.16992138989735395, 0.17939555807970464, 0.05480018815433141, 0.2409095666371286, 0.1026839978294447, 0.15564044995699078, 0.1148875179933384, 0.22101113281678408, 0.1731604043743573, 0.1304591418011114, 0.15466547571122646, 0.18055062188068405, 0.07050333908409812, 0.09420971779036336, 0.16590488667134196, 0.11387683902285062, 0.1647678719018586, 0.13169317011488602, 0.10360372660215944, 0.10065806825878099, 0.14118448190856725, 0.12414132768753916, 0.18353178456891328, 0.09585443578544073, 0.14184767991537228, 0.15223041496938094, 0.21019394451286644, 0.14494613162241876, 0.0805329973809421, 0.09103293239604682, 0.1181762341002468, 0.18089031771523878, 0.15155224042246118, 0.12822226417483762, 0.12974301382200792, 0.13289782422361895, 0.1308298297226429, 0.13981855910969898, 0.19916104356525466, 0.10502646080567501, 0.1690208530635573, 0.22000298456987366, 0.15684522280935198, 0.09837572666583583, 0.12440947306458838, 0.09378212940646335, 0.17362632468575612, 0.19212051120121032, 0.13053721573669463, 0.18455879820976406, 0.0968505983473733, 0.13527639268431813, 0.17621984879951924, 0.22366156481439248, 0.1512333395658061, 0.08517614784068428, 0.11153411629493348, 0.1494318651384674, 0.11250799958361313, 0.21501091337995604, 0.17761968774721026, 0.20975876395823434, 0.08945067354943603, 0.08634822166641243, 0.05894975474802777, 0.1223486996605061, 0.1297947415150702, 0.13099638250423595, 0.15079881210112944, 0.10543989643338136, 0.18855127069400623, 0.17823900998337194, 0.12541348754893988, 0.10112481235410087, 0.15277574508218095, 0.12079594118404202, 0.13655309448949993, 0.1533648173790425, 0.09144185576587915, 0.17954072216525674, 0.20633262436604127, 0.09096173074794933, 0.11471471632830799, 0.1345767849124968, 0.13479681685566902, 0.051906732478528284, 0.08183406389434822, 0.07784013680065982, 0.11544089298695326, 0.12984076951397583, 0.1338593359105289, 0.08339117877767421, 0.20237947086570784, 0.168248692934867, 0.1923343981616199, 0.1677682710578665, 0.14065749768633395, 0.2940036723157391, 0.14189643901772797, 0.21599013271043077], [0.06982359118410386, 0.017285070243815426, 0.02114207665727008, 0.01171949701529229, 0.014086285736993887, 0.015597977471770719, 0.08070955431321636, 0.06047434129868634, 0.009320061217295006, 0.08034282203880139, 0.03543660161085427, 0.039257103635463864, 0.050381388937239535, 0.023899758270999882, 0.043028208310715854, 0.008777391703915782, 0.012150814691267442, 0.04157648952968884, 0.027609587523329537, 0.031801139266463, 0.02982867958053248, 0.02345136377698509, 0.024483592860633507, 0.027719991267076693, 0.02478039255947806, 0.04282934984075837, 0.046155637173797004, 0.03777342055400368, 0.02293231682415353, 0.023911330208647996, 0.09021885576657951, 0.003771566894101852, 0.015613740688422695, 0.028640803575399332, 0.012190773777547292, 0.010702954150474397, 0.010494779871805804, 0.05161060813406948, 0.03837493495666422, 0.022495566627185326, 0.06112729024607688, 0.012383878747641575, 0.014578925220121164, 0.06129780238552485, 0.02133010348188691, 0.017607563095225487, 0.049979827672359534, 0.022095600979810115, 0.015407265000249026, 0.043166882314835675, 0.10603915099636652, 0.04062878550030291, 0.0054444723537017126, 0.05347196645743679, 0.033260383424931206, 0.060995206513325684, 0.09071375694475137, 0.05169098272745032, 0.04077942663570866, 0.04452667497389484, 0.042537333283689804, 0.07783041466609575, 0.06555348125402816, 0.02012777786148945, 0.008989802718133433, 0.016642080918245483, 0.03289289044914767, 0.033634295978117734, 0.05180657964956481, 0.010626673429214861, 0.028504014626378193, 0.049853354576043785, 0.006052036651453818, 0.04144066166190896, 0.05703611583157908, 0.017879717925097793, 0.05400515874498524, 0.03705734823597595, 0.050640706467675045, 0.028127395089541096, 0.020812416514672805, 0.04514036059845239, 0.027328853466315195, 0.08570892823627219, 0.024221405074058566, 0.03299854630313348, 0.04015975559013896, 0.02996375973452814, 0.06554517662152648, 0.050550713640404865, 0.04570628902001772, 0.0247699598185136, 0.03261436984757893, 0.03068085807171883, 0.07389182210317813, 0.03554584203811828, 0.07295883857295848, 0.10569610807579011, 0.004975591800757684, 0.014413057997444412, 0.046392864678637125, 0.054801412697997876, 0.08206407030229457, 0.024909661697165575, 0.027620176115306094, 0.03204188084055204, 0.06424387262086384, 0.025864455092232674, 0.03966642776504159, 0.00691320487021585, 0.01737012222292833, 0.033612276456551626, 0.01565115606354084, 0.08992878734716214, 0.012528556726465467, 0.06780813331715763, 0.04281255503883585, 0.0565545881545404, 0.03021942775376374, 0.037635466433130205, 0.07306465398869477, 0.036222639901097864, 0.020432422061276156, 0.0314062610414112, 0.023468698491342366, 0.054032788902986795, 0.017184002717840485, 0.04954706280841492, 0.01582348832016578, 0.01575782494910527, 0.06764731733710505, 0.02623493335704552, 0.04673317649576347, 0.04314930825785268, 0.017955391012947075, 0.07406106888083741, 0.05877761730516795, 0.06323507128399797, 0.043353781074984, 0.02782270821626298, 0.0738099186855834, 0.0496574832504848, 0.06002530855766963, 0.09381078372825868, 0.03261232151999138, 0.03766466623346787, 0.036703911537188105, 0.06569737626705319, 0.03989972930867225, 0.03779415987082757, 0.007647898137292941, 0.06689142508548684, 0.03509496134938672, 0.07012790141743608, 0.07409482917864807, 0.03261679295974318, 0.03032585544133326, 0.036989942673244514, 0.04903293629467953, 0.08602264148066752, 0.0738472561351955, 0.03855891336570494, 0.07741006222204305, 0.052246899576857686, 0.062453040591208264, 0.025987300941778813, 0.02863143581635086, 0.04357321187853813, 0.011925595135835465, 0.006548779747390654, 0.009636437844164902, 0.03475884637737181, 0.0404030204663286, 0.01593798129761126, 0.023999701443244703, 0.08323877875227481, 0.045557625708170235, 0.0387505173421232, 0.019920818849641364, 0.0314125247678021, 0.042997821074095555, 0.038979759337962605, 0.024298122734762728, 0.045185190028860234, 0.02365361200645566, 0.028700411021418404, 0.04054518256452866, 0.028099987575842533, 0.01443656923584058, 0.04068967871717177, 0.02059137710602954, 0.013021281556575559, 0.014696483267471194, 0.009190276286972221, 0.046734820352867246, 0.07606661907630041, 0.04814654850633815, 0.0318685967795318, 0.1357833982910961, 0.018156459227611776, 0.02541079134971369, 0.04043688466481399, 0.041269492721767165, 0.02574706588347908, 0.02360532231250545, 0.04255317813658621, 0.022959852358326316, 0.04906418813334312, 0.032584264627075754, 0.03260375713580288, 0.03635178101831116, 0.051381521989242174, 0.025958856276702136, 0.02375889122049557, 0.056319253126275726, 0.0436258041736437, 0.013127143356541637, 0.023522394731116947, 0.03033383167348802, 0.06355972378514707, 0.07568564498797059, 0.027159768105775584, 0.06190552485350054, 0.04236653170664795, 0.07003337406786159, 0.07777820457704365, 0.06381192040862516, 0.03758963510335889, 0.00291760492928006, 0.060505504079628736, 0.03518407844239846, 0.03394101819139905, 0.023989342917047907, 0.024473431003571022, 0.02965530460642185, 0.07610997534357011, 0.0830816215602681, 0.045538322447100654, 0.010191486380790593, 0.07674411084735766, 0.03310137086373288, 0.0268579514886369, 0.05055479545262642, 0.06511691288324073, 0.059456630478962325, 0.0289865330705652, 0.014832578308414668, 0.034683948833844624, 0.02595524758362444, 0.07648749844520353, 0.07024803286185488, 0.05950494058197364, 0.01746280162478797, 0.02787534689559834, 0.054708907700842246, 0.028074235051462892, 0.07106953838956542, 0.029930116324976552, 0.00981253557256423, 0.08348773219040595, 0.05242159000772517, 0.036729938656208105, 0.06294593054917641, 0.009566579483362148, 0.05523784006072674, 0.033278306291322224, 0.04020629567094147, 0.011633155554591212, 0.0610205656994367, 0.003999201444457867, 0.07835350261302665, 0.016318836642312817, 0.058508128640824, 0.021491400002560113, 0.03882066514051985, 0.027172097034053877, 0.0380880206648726, 0.017777817338355817, 0.02443978017254267, 0.055135817019618116, 0.07640881594852544, 0.018894207823905163, 0.04772940956172533, 0.013122038308210904, 0.05174880716367625, 0.030081850272836164, 0.043278690573060885, 0.08467815932817757, 0.07491506563383155, 0.02673675506230211, 0.05755995705840178, 0.04195898502075579, 0.01975618266442325, 0.06883421185193583, 0.04775870213052258, 0.013286151279316982, 0.03929633356165141, 0.0160619997404865, 0.07425562289427035, 0.01646786360652186, 0.03228660032618791, 0.04909431932901498, 0.04329388975747861, 0.0379460886324523, 0.03052250416658353, 0.031120361636567395, 0.006959453194212983, 0.04527488970779814, 0.06470109496149234, 0.026036523886432406, 0.04335148412792478, 0.023298537016671617, 0.07511083676945418, 0.02444846701109782, 0.012404221943143057, 0.031033602717798203, 0.01395784223859664, 0.05155994542292319, 0.04884364410827402, 0.057666240027174354, 0.05197336620767601, 0.0033651835246928385, 0.016526808685739525, 0.0035689264859684044, 0.07509356699301861, 0.08065358153544366, 0.009653350462031085, 0.03350065373524558, 0.03403501490538474, 0.00965491639362881, 0.008441528134426335, 0.04077969380887225, 0.03178058919729665, 0.008353906468983041, 0.00775847164732113, 0.03268330794526264, 0.010323874394089216, 0.037794861200382, 0.04622541760909371, 0.028311776113696396, 0.030142467039695475, 0.004136244579058257, 0.013845274206687463, 0.029920973065600265, 0.05152513498615008, 0.025507214886602014, 0.0514194939751178, 0.04024267203931231, 0.03260248064179905, 0.05348799313651398, 0.05444618371257093, 0.02960430421808269, 0.206885494699236, 0.09799109378946014, 0.10489642168977298, 0.09932320434018038, 0.1178489692392759, 0.16696850303560495, 0.18763495580060408, 0.0930032751057297, 0.058920220981235616, 0.1660356085631065, 0.15447377896634862, 0.10178874508710578, 0.10042393550975248, 0.09321846824605018, 0.09159742476185784, 0.08188877502107061, 0.06356536410748959, 0.14399833482457325, 0.14021860639331862, 0.1284039716119878, 0.15660157572710887, 0.12062644949764945, 0.23811451974324882, 0.13375349080888554, 0.09451699661440216, 0.1578717614756897, 0.10956540631013922, 0.12968499271664768, 0.07476462487829849, 0.2032743376912549, 0.1874557271366939, 0.1133232562278863, 0.16532878711586818, 0.13317868259036914, 0.07162948881159537, 0.09461922745686024, 0.1674568362068385, 0.12457876437110826, 0.12921496090712026, 0.17533384321723133, 0.07573312017484568, 0.08759025775361806, 0.27238108101300895, 0.1681667598313652, 0.12132000134442933, 0.07852331342292018, 0.1686261492432095, 0.19626298657385632, 0.11986537705524825, 0.14585219003492966, 0.2677479124395177, 0.2020834875293076, 0.17887698981212452, 0.09529048518743366, 0.11742530681658536, 0.11709495462127961, 0.18705082620726898, 0.15510361001361161, 0.12648936419282109, 0.13727149344049394, 0.12824961973819882, 0.2558961109025404, 0.17253906349651515, 0.11780228815041482, 0.10501643439056352, 0.08556599059375003, 0.1569359132554382, 0.1386447189725004, 0.11239197963732295, 0.12065782750141807, 0.14181066158926114, 0.13731106475461274, 0.14185624429956079, 0.19243492948589846, 0.1422485287184827, 0.1855982799315825, 0.12588457320816815, 0.1565677486360073, 0.13010172348003834, 0.09856551609118469, 0.08714167401194572, 0.17219288129126653, 0.14413868979318067, 0.18695946782827377, 0.15296278113964945, 0.14393333753105253, 0.17039238649886101, 0.08563624971429817, 0.20152687677182257, 0.05553903327381704, 0.15235981583828107, 0.13107904291246086, 0.22343782213283703, 0.12380923144519329, 0.13941315351985395, 0.10813484244863503, 0.16595771274296567, 0.15599025384290144, 0.06283802227699198, 0.09716888322145678, 0.15000269544543698, 0.10173704707995057, 0.12958128500031307, 0.21679902914911509, 0.2118814250570722, 0.09389498780365102, 0.17426748090656474, 0.15843923727516085, 0.16569649160373956, 0.12974066863534972, 0.10625827009789646, 0.10762004429125227, 0.18007563252467662, 0.11666501362924464, 0.14633139478974044, 0.14858307084068656, 0.11949838502914645, 0.15582249878207222, 0.2063015877502039, 0.15044805826619267, 0.1728461790480651, 0.22297972405795008, 0.10991414892487228, 0.1342675616615452, 0.13358763564610854, 0.20666414173319936, 0.11053017602534965, 0.13545112393330783, 0.09921748540364206, 0.08096381410723552, 0.1545230724150315, 0.11418161680921912, 0.0960242391738575, 0.11188734890311025, 0.08606802381109446, 0.1805807976052165, 0.22799354017479345, 0.1406161897466518, 0.08965114247985184, 0.1147465396206826, 0.1718791012535803, 0.18543852522270754, 0.11593726361752488, 0.20841235964326188, 0.08814061220618896, 0.1076275177183561, 0.08029985168832354, 0.18779551202896982, 0.14779833873035386, 0.1783809531480074, 0.08957764759543352, 0.10774731519632041, 0.10209105152171105, 0.16671819146722555, 0.1124361448455602, 0.14054742234293371, 0.12309320736676455, 0.09292212867876515, 0.12325643532676622, 0.15256562823196873, 0.15083666163263842, 0.12399744751746766, 0.1206565806933213, 0.10673680691979825, 0.14295866014435887, 0.12066429902915843, 0.08515691879438236, 0.20220870268531144, 0.11042200058000162, 0.15846108610276133, 0.11904823535587639, 0.239708905282896, 0.07650858286069706, 0.1129712036345154, 0.10546346704359166, 0.14501069847028702], [0.047116284258663654, 0.016238964853982907, 0.07141788024455309, 0.04827305871003773, 0.08555521460948512, 0.028117042129451875, 0.10547830257564783, 0.02176922298531281, 0.007883607486292021, 0.05147547788510565, 0.015707223465142306, 0.006394428337443969, 0.027694318523572292, 0.0451194209017558, 0.044965844572288916, 0.03222792242013384, 0.012887422235507984, 0.06236569723114371, 0.051485964431776665, 0.11423300311435014, 0.06257089364225976, 0.06280976871494204, 0.01789749978343025, 0.012422864692780422, 0.017650924928602763, 0.06159053882583976, 0.027285888681944925, 0.025915822843671776, 0.044361658437992446, 0.029219508069218136, 0.0029622351394209545, 0.01542204394354485, 0.025354924327984918, 0.09323885504272766, 0.026158430919167586, 0.011354867801856017, 0.03659738737042062, 0.035719946172321215, 0.02962872458738275, 0.02645328062499175, 0.0409471111925086, 0.04227935532981064, 0.021502571180462837, 0.0423199545184616, 0.03789583410252817, 0.022876859839016106, 0.10819974326295778, 0.03132442070636898, 0.05415751053078566, 0.04935692828439642, 0.06163247388030868, 0.016149615839822218, 0.05039053219661582, 0.016686240560375154, 0.05623508244752884, 0.059194926943746395, 0.03165129222907126, 0.032308215377270244, 0.02704652193642687, 0.007545539274360635, 0.03144513844745234, 0.019815426458080765, 0.012663327033806127, 0.06303232396021485, 0.014407939033844741, 0.07007403633906506, 0.04209780745441094, 0.04420811921590939, 0.05316324044542853, 0.03202445150236599, 0.04015349557448644, 0.032324694766430184, 0.03272630427090917, 0.03218611724150833, 0.026616298928274773, 0.02947422985016601, 0.06340088933939114, 0.028254808858036995, 0.03152390258037485, 0.04609838790202048, 0.017006176713039167, 0.02252873691759305, 0.015001474421296734, 0.047626358646084554, 0.030561730382032692, 0.035290157320559956, 0.06172783985675778, 0.02167349521187134, 0.04927335503452923, 0.032603063227725215, 0.06500605086330324, 0.017024973458319437, 0.04356003504653927, 0.048673866695025936, 0.0289335492925602, 0.054575762696913444, 0.05094559186545666, 0.042709322297014296, 0.05170184405869804, 0.05303582853230182, 0.008577626886108192, 0.019265598930360284, 0.016900264818104915, 0.009250191724277101, 0.03828871966106817, 0.013326236530701863, 0.05713604601623956, 0.05243008017714601, 0.0022746137483409257, 0.008983352527138777, 0.045860459067625925, 0.03579120348149445, 0.02371316935750656, 0.052310082319309004, 0.02982521560625173, 0.016590683480899315, 0.04645486369554419, 0.05479511557496153, 0.02252882783068344, 0.06360126179060899, 0.08420197511441074, 0.05220852683123667, 0.0295574264600873, 0.044150068424642086, 0.03278189484262839, 0.027623692039924208, 0.031106800743145868, 0.04364630971394945, 0.01823049216909567, 0.04557344829663634, 0.06838486369815655, 0.015630435300408863, 0.05321722426742781, 0.003363274581715814, 0.05146334748133086, 0.036442998389247805, 0.04414318500494119, 0.016604671109234914, 0.020541632802633103, 0.08093398719211109, 0.07487376511562616, 0.02480406892573228, 0.03243368286348414, 0.027448305845609866, 0.05854810071468819, 0.09400437294971198, 0.03374288702616468, 0.03613740424043499, 0.008227410180552397, 0.038586806986131705, 0.04487022255489137, 0.03137495725241024, 0.07161987799918279, 0.008345434853254119, 0.06064990746381227, 0.08642515269457363, 0.009868748620647239, 0.004123948583583115, 0.03330378051032312, 0.0572369818110019, 0.04293815240089316, 0.06848753982922062, 0.02617461715999525, 0.006269088871704298, 0.02786851913697319, 0.02852093930414412, 0.06331885975669138, 0.014297675370471552, 0.006762709845133941, 0.037773888107039966, 0.03818806217168458, 0.03521989820001181, 0.030254920966399368, 0.013443099742289633, 0.07040876720566303, 0.008763924506638432, 0.023804882112017367, 0.012672905377257848, 0.02699756616493687, 0.05595703682047315, 0.04665696164011024, 0.019168101134710014, 0.04007895797258243, 0.09168386270175688, 0.04570329445414245, 0.01630504753848072, 0.036608731097658165, 0.034592601587064564, 0.0338933352031745, 0.016875430701475125, 0.052093890990363434, 0.03701852649101056, 0.029704217704420444, 0.01933290986926295, 0.03633703825471457, 0.04386257896840107, 0.041113214974757284, 0.025596255909476895, 0.04264893745130394, 0.028960014278709423, 0.03143136789731216, 0.06009119642840233, 0.029556478366430383, 0.030103348435659427, 0.02094605875754496, 0.053273920639185235, 0.020784153675776906, 0.03424477923545055, 0.03620810493885074, 0.03379724563274067, 0.06233589258044958, 0.023348051254288293, 0.03617131296778098, 0.0552003578923177, 0.06232932457351126, 0.035953051046817563, 0.06389197587850504, 0.03629288788943086, 0.018309690458409023, 0.04996099567506462, 0.015130651718209265, 0.010597141517791897, 0.0851195739232935, 0.045522210421040654, 0.02527254036976956, 0.010892496811720775, 0.023519708156527486, 0.02182691383495694, 0.0060145428869873285, 0.060702989576384425, 0.026843409104913007, 0.030876328637532424, 0.04309101255785208, 0.12215951879625209, 0.027036818355554715, 0.05633939501421992, 0.032526336290175095, 0.06977807526709512, 0.05050968400610145, 0.03342223099025432, 0.04759635732625611, 0.028259432438062504, 0.0332141513354145, 0.02277348052302841, 0.0426055663410807, 0.045924506412120536, 0.05858086653461214, 0.02962440157716628, 0.01694837639661273, 0.03337881535117049, 0.05284063627186697, 0.03823997169092763, 0.043840544603881426, 0.07057366499793716, 0.03580217242415529, 0.056049905469990335, 0.05775223638920579, 0.036587305294233374, 0.0821250154695008, 0.019909412039851304, 0.06159457239846233, 0.03143821420962922, 0.11352871981216595, 0.047222032881109044, 0.01623512423975626, 0.031986724425223656, 0.05186296060855966, 0.05529533424123656, 0.06954723765375093, 0.04387944056361448, 0.02012664237554418, 0.010217172111879336, 0.028835526427428704, 0.03159737891110126, 0.03217046905774623, 0.06294948543654755, 0.03772649826714769, 0.027533122192835435, 0.019730585991055705, 0.02300493226357503, 0.040210429433500394, 0.029318929882720113, 0.044330224773148075, 0.09912893976434134, 0.059511657018447295, 0.08887236239388585, 0.050679483683779836, 0.03607330123486463, 0.03124194212432485, 0.04124995197344106, 0.09655789530370384, 0.046946213697083294, 0.018877246038755402, 0.027514095381775405, 0.01875431484222645, 0.04677771277783904, 0.053597066580550745, 0.09997780827688985, 0.06817696586949751, 0.03569962616893463, 0.04052427626447752, 0.09663965771324001, 0.03457571772742085, 0.017453853179176804, 0.02184503522585146, 0.0918442259717267, 0.0531344302726211, 0.03909882580046542, 0.03260528224927839, 0.015764726922498085, 0.0678883223736193, 0.04015923979750369, 0.029611358331749216, 0.017509260069346055, 0.020092930317332502, 0.06330141186481342, 0.07344061115873046, 0.03531270376697648, 0.03821522477664985, 0.04695514544437174, 0.02718623865803238, 0.028413589498086367, 0.02402009195066057, 0.026127414712391328, 0.021240392670733854, 0.056687762844376266, 0.027468182415759657, 0.08162637386703864, 0.03587311060982756, 0.07386839992250316, 0.023647394664294552, 0.05026480866945349, 0.045673827480641194, 0.05407874639786314, 0.05204570334171876, 0.05327933089574799, 0.03058012265682919, 0.06253212384763174, 0.046109553513815627, 0.04325359113863669, 0.05906040154513903, 0.034434409099048935, 0.044628846444538794, 0.04557527026918251, 0.07388751022517681, 0.03929191778297536, 0.0205963439293555, 0.005205915012993501, 0.0331750661280239, 0.09798785060411319, 0.0694902110262774, 0.014996080863056704, 0.18305115489056334, 0.07784121291479096, 0.13119719282258302, 0.14170008158544078, 0.1400544581701979, 0.07571979862404987, 0.21150800603209063, 0.16703350032912567, 0.11884030041983351, 0.08196143127861433, 0.216085780702997, 0.10719008845626377, 0.1408081388217397, 0.10066257309517823, 0.128461072454229, 0.17286268441239372, 0.12677932129008695, 0.12708461115835235, 0.20167490554740652, 0.12402178253978491, 0.1608654367737472, 0.21098642464494333, 0.16294221830321476, 0.08955560580943711, 0.0991837918991223, 0.13791201141430065, 0.10685341316275299, 0.10884201270528138, 0.09674384782556444, 0.10916930725215934, 0.1228121634630952, 0.15386720682727173, 0.12613253958988935, 0.18384390219580382, 0.17451620427891612, 0.13253360782982782, 0.19440120522631332, 0.08526375837391242, 0.14442061685258523, 0.14952040335629135, 0.1763206472969614, 0.1381609871168621, 0.0966252080979757, 0.1781236653914675, 0.1052589385653846, 0.10295720465364866, 0.19859997992170975, 0.13524418347515166, 0.20357919711386785, 0.11885184823768213, 0.25260605150833726, 0.1497359378845431, 0.18556691677076742, 0.11099846378783695, 0.1249789007124491, 0.19059162761550397, 0.11830860355985351, 0.28449212957639247, 0.09731634054332972, 0.11534977209521458, 0.10164030813029967, 0.1311639742925763, 0.16381946654291824, 0.10569313206360675, 0.09963535907445475, 0.09898094067466445, 0.11307004286209121, 0.16378785105189309, 0.2815725206164643, 0.1337709609651938, 0.16603072523139417, 0.10605466188280843, 0.08310560035170056, 0.14102462329901755, 0.13006575900362805, 0.07739855893305503, 0.14326764590805396, 0.21008047013310716, 0.13073761045234278, 0.14576308778487146, 0.13622730650240555, 0.21413176524220034, 0.19766511133639142, 0.10835344946826808, 0.18500154867069796, 0.1179098105058074, 0.21649186906870455, 0.18255541508551687, 0.20990766846807674, 0.15354989416664466, 0.1606714542140253, 0.2553657128009945, 0.1735341944731772, 0.10931637123576365, 0.10612399331876077, 0.12838388909585774, 0.1288429816486314, 0.15002858155639842, 0.16482424543937668, 0.22521542909089476, 0.07964328848174773, 0.1381380102247931, 0.09004526742501184, 0.15823431545868516, 0.155713788990397, 0.15537020430201665, 0.21442457218654454, 0.13668397965375334, 0.09871439091512002, 0.18555542832473293, 0.10432433715322986, 0.11425695221987553, 0.1482794136973098, 0.11706944700563326, 0.127115098584909, 0.14713663986185566, 0.1227330208348576, 0.16973846533801407, 0.09918466021190397, 0.19816359708784148, 0.27284171723295003, 0.21325617941329256, 0.13480806781444699, 0.14847097685560584, 0.09965748249669559, 0.31047961791045964, 0.10997105680871755, 0.10266205252264626, 0.13084112521028146, 0.18749336886685342, 0.24169428390450776, 0.045034823488094844, 0.19779320602538064, 0.1037141952838283, 0.18620290764374658, 0.25440302852075547, 0.12095149533706717, 0.07236349512822926, 0.13682580407476053, 0.16263326222542673, 0.134383529657498, 0.07208588736830279, 0.16283658100292087, 0.08136465548886918, 0.1478346297517419, 0.23439218901330605, 0.20875521702691913, 0.14393207588000223, 0.13207828538725153, 0.16618902533082291, 0.1621413222164847, 0.11380148134776391, 0.1825054982327856, 0.2444799500517547, 0.16497049306053668, 0.1534194394480437, 0.12366908427793533, 0.16921327711315826, 0.20133532845648006, 0.15218572283629328, 0.12231109503773041, 0.17798323620809242, 0.16255860216915607, 0.1178019838698674, 0.11097845548647456, 0.0772745163703803, 0.13596676813904196, 0.1141229945642408, 0.12739000492729247, 0.1570758971502073, 0.15384066762635484, 0.1381750137079507, 0.10882136615691707, 0.17751998762832955, 0.2027234563138336, 0.08670965500641614], [0.09917332761688158, 0.023001564768492244, 0.007974557684065076, 0.056591513712191954, 0.016623022565909196, 0.05902919052459765, 0.06646033376455307, 0.046544047581846826, 0.07549447516794316, 0.04199906099529471, 0.06084149288653862, 0.017335873963020276, 0.03125763854768593, 0.03597122253268026, 0.01162350670711021, 0.030493105841742363, 0.06719957964378409, 0.01646958538913168, 0.02580581058282405, 0.037567645267699845, 0.007486092781618936, 0.01967116964806337, 0.02380116766289575, 0.031931846315274015, 0.021117352007422596, 0.03404879658774007, 0.013204604092607042, 0.08463043923256919, 0.03295756490842905, 0.02526327094528824, 0.037780738130095415, 0.01932610623043729, 0.02598175524326507, 0.02527005046431441, 0.04562553593132179, 0.009061584169103298, 0.12173324401373975, 0.027488083105708938, 0.020036181995237712, 0.047539096922264434, 0.05992096630507149, 0.015804110844328534, 0.09921794553520158, 0.03467619710136205, 0.02744062090641819, 0.04308268937165849, 0.0035115605578539544, 0.019678140270116273, 0.04706142841314431, 0.02690238758077612, 0.050326098935329355, 0.0690797291463241, 0.03429550131841097, 0.0436439088662155, 0.0477010224130936, 0.02270470569783356, 0.02775113178358879, 0.036652258058893494, 0.018043983036477584, 0.013702314299735008, 0.045660713731194846, 0.055317914084298536, 0.04954506643116474, 0.07215449149953201, 0.04435997376276646, 0.02169562048948137, 0.0465932742372388, 0.03288192150648683, 0.08831215222016908, 0.03399201486899983, 0.04558383094263263, 0.016730964234739076, 0.06862751630251296, 0.023073564225342125, 0.06342450447846204, 0.053612766714650206, 0.0791199185186997, 0.06643383909249678, 0.051073033464490436, 0.01990324293728918, 0.018451694850227796, 0.05296912058838643, 0.07053604553220794, 0.034213341859867796, 0.0369451058213599, 0.026083147458848543, 0.030982283205958083, 0.023518914058513474, 0.026122750314243603, 0.01974440849153325, 0.03637330330093391, 0.06909862422617152, 0.010011163976741955, 0.030851887859171256, 0.028852434406871907, 0.05106712967972271, 0.06207865306350868, 0.02768018988717813, 0.03780000428378116, 0.030482185138680506, 0.05055973073467612, 0.047688832637504674, 0.050569133745739236, 0.027370027819415554, 0.02900172483350616, 0.07530447051976807, 0.01557389106892515, 0.007311418121389579, 0.05076283428934403, 0.07678604961256497, 0.014811875171290012, 0.06446529238019139, 0.08434568459051661, 0.02272255063871853, 0.049299534293822944, 0.016882599848031532, 0.039866937513579614, 0.05170802614884451, 0.07805504792486317, 0.11474694038042799, 0.022733753357897513, 0.08332443001563661, 0.03251395726692863, 0.05451840210298542, 0.057602689921623096, 0.08134863252053037, 0.019133767527819145, 0.025555370993970428, 0.06379495491273701, 0.0401786024303874, 0.03683509727125056, 0.016395346501667518, 0.02139237338269595, 0.030932987901906017, 0.04436417431861628, 0.040223224059445783, 0.050875959859695286, 0.015245706872519804, 0.056154425838030875, 0.027104902983410284, 0.04972674789314624, 0.0934731807501521, 0.021607941307593137, 0.015001699848653516, 0.04233477149682585, 0.0617464937386103, 0.031581125876982696, 0.01082448454326368, 0.03852224013826344, 0.04213847714709118, 0.021760495328635443, 0.025232540465367492, 0.04638528364012018, 0.04677717843151186, 0.07043784455163404, 0.047436298336833715, 0.03432361387240235, 0.07540878679719754, 0.029043390859442297, 0.022478250466519967, 0.047361315446323715, 0.01704664231510833, 0.03674369065265637, 0.013299705678946339, 0.05850864814419765, 0.053392018598970026, 0.03733799880137667, 0.041528980946168303, 0.014108911964285653, 0.034010275412583724, 0.04768994214828126, 0.01846007740823552, 0.03439930180320516, 0.06418942866730504, 0.023040711203066166, 0.03566016617696732, 0.061529404410975985, 0.015111246411834145, 0.056495394455851056, 0.07873544891481288, 0.07084774013492279, 0.008232173840951873, 0.047299012148869224, 0.05116566833748948, 0.03368712204974145, 0.10368998642661609, 0.046499051168211736, 0.01906234694615705, 0.034446940262569115, 0.019974320275650825, 0.018115394341293722, 0.018476848090358544, 0.03319397605082486, 0.03854505004710518, 0.02677549888176145, 0.016185084932658356, 0.05219324229983613, 0.029252628264657687, 0.010469857625139412, 0.02346384855627548, 0.042545816031633876, 0.051962000216008164, 0.06341799584333785, 0.02880201103835134, 0.043136068343301304, 0.052926250427844934, 0.04682588929426856, 0.029139155740267597, 0.0369817567843711, 0.03358894704433624, 0.030572161267627962, 0.0598350701329764, 0.07755075115710497, 0.06026589428074658, 0.030809704185230657, 0.022213322299649008, 0.0027620999435384874, 0.04598021572746802, 0.10908227559411898, 0.055033808821463026, 0.06443184378440492, 0.025777043083508033, 0.027304193754389416, 0.028770657154382206, 0.022534889321832452, 0.03268312240834348, 0.028060497897968162, 0.056542283346061595, 0.06383346495567821, 0.049017725978046656, 0.04577585794322658, 0.04376061158836819, 0.021055173019703943, 0.027488834530231543, 0.06534238476888277, 0.06765375175746158, 0.019439356110524386, 0.05339346949767787, 0.08100515173282474, 0.011073889763792977, 0.005022810018999735, 0.00780257609221735, 0.01674188122706255, 0.020886720340058673, 0.02347394918615464, 0.054303787837852724, 0.01749580307659926, 0.03472025469818618, 0.028060193617420737, 0.04215073000523262, 0.08155305709806271, 0.01999715059355367, 0.05666102697432507, 0.043637214694172144, 0.0663102937687654, 0.037342388604884036, 0.006606420038224314, 0.014140161019895459, 0.039789063957869075, 0.04196246569335926, 0.012781604964402504, 0.012718805355689256, 0.015390214157378068, 0.04416109302837867, 0.06795641442295164, 0.039071162245818414, 0.019739237577596214, 0.04435019596712664, 0.028822000786021817, 0.0030339811064550304, 0.0038631082588835852, 0.008601682675362099, 0.01948505756445229, 0.07485415015253238, 0.050148154186899774, 0.011533936904015718, 0.07833046634914353, 0.0831787167408038, 0.049440928269177675, 0.02628835314681055, 0.02810837384458864, 0.06808475402067415, 0.04487401121878065, 0.003020653525709349, 0.009646905837144004, 0.10181575926253572, 0.021044649365649093, 0.07300367171410471, 0.01141340841058991, 0.02589168077975046, 0.008032008263398893, 0.008379332448384957, 0.03996946521510836, 0.0680310744792223, 0.06812842941144481, 0.04725262049760204, 0.015850665768084582, 0.02187848567700712, 0.025125773245235905, 0.05109216974233277, 0.08110429524094798, 0.011116707973997109, 0.03019732845132239, 0.012971368414582685, 0.07618147385073826, 0.07582678663311526, 0.058120349058299325, 0.036873098943033256, 0.0321158766746521, 0.024815420074446592, 0.013754442752542673, 0.07378059643087909, 0.02779081441985909, 0.049346805390086956, 0.006333079163596267, 0.05850308574736118, 0.005409901723396615, 0.017399789576302283, 0.030934010210330598, 0.03903180615452584, 0.06975052674533799, 0.03767985799640883, 0.04589434924128, 0.060716058796970174, 0.03902135300450027, 0.046062122855801135, 0.024089098697004374, 0.07406081655062735, 0.014608108322136104, 0.06338614286505617, 0.0634136913868133, 0.013597494289570022, 0.029032815255050082, 0.015718838076281827, 0.08954587625339627, 0.04076378216268495, 0.041286510167992674, 0.04836733372940216, 0.07104865435394458, 0.06323167224763893, 0.06323372799670324, 0.005722732275899034, 0.01541053972687223, 0.054618937138002366, 0.057226502685807645, 0.06321326698525809, 0.04573945188894868, 0.021316227175702807, 0.0482123361871345, 0.0334620731882751, 0.08663643471663818, 0.08781333250226453, 0.10171337999054231, 0.14205798972398043, 0.1315515089663677, 0.12375339225400239, 0.2454507237416692, 0.0909220332687255, 0.19062754756305367, 0.14351381629239768, 0.1685517415171489, 0.23848298122175038, 0.16256774542853236, 0.15096717572305351, 0.11454741397756152, 0.07245860135299154, 0.12340877598035149, 0.1297677421825938, 0.1203503186115995, 0.07479354637325741, 0.10078971041366458, 0.13418738002656028, 0.11811462100013159, 0.13116438989527524, 0.1583283010404557, 0.11951215929002501, 0.11881741258548573, 0.09376703412272036, 0.1102703352808021, 0.1739971461938694, 0.08006418269360438, 0.06137991360446904, 0.08775559341302142, 0.08017709304112941, 0.15535484184511006, 0.20264113729353994, 0.12696773774223402, 0.12005087686702609, 0.2490876184310764, 0.11924937221920118, 0.11372487686458044, 0.0991427808185108, 0.14558485359884799, 0.2018268231768161, 0.2084235957590863, 0.12168230299721472, 0.09808566566789523, 0.06781872376450337, 0.08502722106641158, 0.11707542129443027, 0.15894670301349834, 0.13741566304815933, 0.13344005215913057, 0.20114986575208604, 0.12936589890159667, 0.24141876900102943, 0.11767342904931866, 0.12451520684408024, 0.12931826786370948, 0.1771438226569444, 0.08773370005656034, 0.14901693037245423, 0.09171331112156622, 0.1455880151479505, 0.134678948961664, 0.2694818959571421, 0.17389521963195875, 0.1071155619865749, 0.14406796311959624, 0.19420520402491093, 0.18480731378076598, 0.10296882668626495, 0.18170234601711854, 0.13065025967080146, 0.17563436849741265, 0.08187037718016654, 0.27415074699092656, 0.08682701824000105, 0.19401092460611835, 0.17428515886422247, 0.13721580267883837, 0.2799360256176442, 0.10312899699783884, 0.11826099478639662, 0.16675920254783705, 0.18878614559071139, 0.10193145266384818, 0.16492725553689525, 0.08309609343996271, 0.1266454378492199, 0.15687118313508108, 0.13560391729697585, 0.09172991296509281, 0.21121741068782285, 0.07168779193307273, 0.1032839722756762, 0.18694342259550467, 0.12360238746623509, 0.12205642706248909, 0.15109366737306118, 0.16825507540488616, 0.09484232446993701, 0.1679278476512991, 0.20305757119785994, 0.16075270454166457, 0.17078216245863587, 0.11539650513441302, 0.1511506940005347, 0.1272074069129303, 0.1332523036398925, 0.07372735475655645, 0.23313197772949934, 0.11185740324435756, 0.13646942476043478, 0.23319556494243443, 0.15253674384439364, 0.10745834515546449, 0.14123920787824318, 0.1307557782274671, 0.13524330774089321, 0.14722131891176105, 0.1778634387301281, 0.19471774605335668, 0.1380389928817749, 0.0746379402698949, 0.18964022397994995, 0.16832016175612807, 0.1946884609060362, 0.1429822901263833, 0.12398875696817413, 0.16025368444388732, 0.13314804673427716, 0.16454412922030315, 0.11688788799801841, 0.11394513145205565, 0.11200615932466462, 0.1266110615688376, 0.157952789159026, 0.12037686523399316, 0.17125488084275275, 0.1795907280757092, 0.1038777052599471, 0.18592908483697101, 0.11082235214416869, 0.0886228152376134, 0.12232392677105963, 0.21355345408665016, 0.10417759971460328, 0.10169184286496602, 0.2782902092440054, 0.09306853957241401, 0.15408585837576538, 0.11145146330818534, 0.10782435012515634, 0.14101580658461899, 0.16871363361133263, 0.152473809721414, 0.10779798161820509, 0.10290430436725728, 0.12607646291144192, 0.22797222569352016, 0.10244627308566123, 0.17191086517414078, 0.11105808051070198, 0.13818372652167454, 0.14743777370313182, 0.18432773795211688, 0.17436743335565552, 0.17856874619610608, 0.11122128620627336, 0.16362766589736566, 0.10047239033156075, 0.27205346734263003, 0.19043211039388552, 0.132692561019212, 0.17333811905700713, 0.1005449278454762, 0.14085594797506928], [0.032142619966180064, 0.02999564982019365, 0.02506729942979291, 0.022575295552087482, 0.005080835762782954, 0.02086460248392541, 0.07463363581337035, 0.05209000955801457, 0.04541737092949916, 0.0930380447243806, 0.029925021481176373, 0.04000101762358099, 0.013604496452899184, 0.01345374585071113, 0.04434090056747664, 0.04967031127307564, 0.021185848527238704, 0.02978042328322772, 0.03052971042052377, 0.025926496782631148, 0.021516453052754514, 0.008029822638491169, 0.00987121162324911, 0.03376027183549013, 0.031368615600513294, 0.058421356734470464, 0.018897987210948486, 0.04095691125257872, 0.01753961947542848, 0.07493566023185849, 0.04849479388212785, 0.023313684250751976, 0.0325435095874127, 0.03756512938707601, 0.013923272999818437, 0.05346129066310823, 0.020237355965946335, 0.03141445806249976, 0.030666532766190358, 0.055741791729815304, 0.04066557747137267, 0.04876829756540246, 0.027722839258785825, 0.023609665731783025, 0.016211497968470212, 0.032340313264285214, 0.039222690247697756, 0.03966954107454512, 0.039425478389603086, 0.07302139420062304, 0.09706781755085103, 0.03724269590748008, 0.05647195743222255, 0.013140973278495949, 0.03489125665510073, 0.023747996492602397, 0.06307932417257689, 0.06074428638385143, 0.030970312363933772, 0.0631943867483642, 0.014795457936997991, 0.009680568728072103, 0.05813949275761843, 0.10306902404408902, 0.023595364546054043, 0.06455894399550743, 0.007407356479234295, 0.04161994598689489, 0.07152843798394315, 0.003915833676728653, 0.04322436165239196, 0.007608666355736204, 0.006842942038929323, 0.02458394978020806, 0.012387871502141934, 0.06537493536598049, 0.021207869904174004, 0.011011455662810476, 0.08072847165749408, 0.03134446611511521, 0.023030120755720418, 0.056080867871060036, 0.036498978588497266, 0.011891521280631423, 0.05840842110046651, 0.023571667770738713, 0.03942885516153183, 0.028669958846876398, 0.01780972412234405, 0.05769463088654447, 0.04444907230208628, 0.04260621943103615, 0.029011138976784423, 0.017034164957294706, 0.009077616414288059, 0.050862831267295405, 0.08737677155295387, 0.07563269275124185, 0.0012978424615539552, 0.0460039458994288, 0.05532875315111596, 0.002456694114698621, 0.02410908473393647, 0.059234472282696515, 0.04196887413854711, 0.029592426144517958, 0.032065032137325034, 0.044252911538933404, 0.03870036300213542, 0.05360728224331979, 0.023376538592856377, 0.06924361761775799, 0.04294800812203903, 0.06673253868939355, 0.04763309363625012, 0.05054189321526792, 0.036427183222258464, 0.0340941603644751, 0.032735710992710665, 0.06412103975890204, 0.051929846667917445, 0.03912269326974638, 0.08477935116388835, 0.03995172417489812, 0.011826735499198548, 0.023712074689683504, 0.031769612833159044, 0.03290225264208857, 0.014082924735703273, 0.07275401323568076, 0.050469856651034206, 0.06360706538544036, 0.009812594016693765, 0.028382530617818702, 0.009756232539075427, 0.014119279767328408, 0.06109690300945658, 0.01965494444448268, 0.019577718412620015, 0.0657341793703381, 0.023351793533947784, 0.02333402280783048, 0.018196000855823513, 0.019719800729944836, 0.01145986963820178, 0.04209762191749178, 0.05994491541059688, 0.03182593442033976, 0.053980515731382184, 0.026827554975170642, 0.00541783945664065, 0.05911667118198238, 0.062375820125453174, 0.013882877901778556, 0.02612946118460968, 0.050061834990628995, 0.08424475250649266, 0.01591249594639521, 0.09226186957675964, 0.04740928045066539, 0.0486230592650827, 0.029761262885585893, 0.053707405386376195, 0.007399132555292454, 0.02102074107824592, 0.07020873614237644, 0.037655159321730025, 0.05741055530961603, 0.0898012715333607, 0.02737749196967343, 0.016328117199009284, 0.03301001248473767, 0.09203787456499413, 0.03290973349066917, 0.06210805324371904, 0.04497814195929095, 0.015943504731694702, 0.12770908389938995, 0.020280335593270138, 0.0361116183194099, 0.11732418919564225, 0.02630405142554082, 0.10222728757071309, 0.0690960192878265, 0.05642646377964411, 0.02824012732162373, 0.021933836906100623, 0.0247147180562024, 0.015683487727073953, 0.026435990439495072, 0.01674548620940186, 0.04973969465936534, 0.046601667927461676, 0.0635426766530145, 0.028282336970733013, 0.02542360824008938, 0.06307736490271054, 0.05212412608671002, 0.051085631421301514, 0.014683905719721224, 0.012350251108728116, 0.02092114486003993, 0.02757557675067801, 0.041262067534262314, 0.03282786718045827, 0.05806926703371573, 0.039711175559205, 0.024816021214064676, 0.028153739476692863, 0.05989709512505215, 0.015499376659136033, 0.026241250889142975, 0.04943243067828007, 0.058279183504055254, 0.017340460435661953, 0.033722303560352884, 0.005307171322783688, 0.07903733232524246, 0.054203790859901346, 0.043120887712575495, 0.05741499335272238, 0.08034667378524318, 0.01705099315586267, 0.026157545908063184, 0.028269375361560378, 0.031216928036883473, 0.08368253111257218, 0.014427257137867855, 0.05546900050831027, 0.049890821901499294, 0.03719039304996841, 0.05635337336570956, 0.03477863203443121, 0.021876975406485144, 0.028749203520419542, 0.03416692423343193, 0.049613017472438514, 0.0291309884050861, 0.05026862330851145, 0.053470489583560266, 0.012631846057047369, 0.08629602642031386, 0.027531259402167052, 0.05275535979308188, 0.012627179803530453, 0.02958443135867128, 0.0722181009768974, 0.024658125585119706, 0.023314383724937215, 0.03458558829152025, 0.02009999556321418, 0.049958999297814444, 0.041651784122223035, 0.01608414913789602, 0.05131931888172403, 0.029242182536108885, 0.03392213795450516, 0.04632506948837545, 0.03739744111953769, 0.09208808085531928, 0.030971420019341167, 0.03752119424461853, 0.0462387428706279, 0.01034812592479284, 0.07659828625037335, 0.02229500863904832, 0.024536272358091082, 0.05013880683691241, 0.02017408416577382, 0.022847136824566405, 0.062239602630143054, 0.054257255178526975, 0.0422270673152525, 0.02356740784307476, 0.012657538281928282, 0.003907825903297635, 0.03808188681432512, 0.029066492061247118, 0.026787471579154953, 0.03255676063417923, 0.02441103308228776, 0.0755983313138131, 0.08154142022249289, 0.046295275969896466, 0.008147562512021977, 0.04690109853981994, 0.08082149986876175, 0.07506143199861981, 0.053315017066779546, 0.049668021747493185, 0.0527446209162008, 0.05388753204897512, 0.03000493594299769, 0.04079722704773303, 0.041784936547628604, 0.004775033348778379, 0.048610071680741385, 0.030000316073710565, 0.01724219080642797, 0.04294004487746861, 0.0532238887535641, 0.08234858745709062, 0.02632544383232016, 0.02298814673849847, 0.053239343978930265, 0.038590124386246316, 0.032740267779445276, 0.014718012971570715, 0.02930401828052709, 0.03625382865720894, 0.041291619854746386, 0.026741569745354354, 0.03868886713462416, 0.07567355540231802, 0.030027964785404038, 0.022597597089770716, 0.0250286595110083, 0.11410167266149074, 0.005291995794323157, 0.030830506584607065, 0.04270637597073801, 0.02317997335921973, 0.06227533333003521, 0.035683614332810976, 0.01984468563023256, 0.00949355029661092, 0.03244221014028881, 0.05762012297054753, 0.05111205187859014, 0.0027856387805513805, 0.03670496167615056, 0.037133655860088766, 0.018987647927133366, 0.03328520084323827, 0.04336217476520687, 0.07779445018968545, 0.03773393829760607, 0.025557365515851416, 0.044024764210917056, 0.01262417503312463, 0.08477852737996727, 0.024331608437933028, 0.02988876571180299, 0.0782339129364118, 0.01824965627747588, 0.024758753388596233, 0.052272674365667626, 0.024853371651261114, 0.031959743646439165, 0.06982547623920254, 0.05418218694103416, 0.05095757755043451, 0.1145232719136402, 0.1836402717162855, 0.11393391017918475, 0.1897188025759533, 0.1768024347256869, 0.08530080638593063, 0.21470854757353663, 0.2043545781634748, 0.14541061216732487, 0.113502150925342, 0.09096224282984622, 0.10203551661106758, 0.13071395078441128, 0.08491750195389614, 0.18722312321187928, 0.15225551440380514, 0.07996886124601588, 0.1828572020167485, 0.05752260847657453, 0.10596835010801442, 0.1460155812674202, 0.1368700509192422, 0.11891279340488836, 0.1211460493505001, 0.2252217521890998, 0.12995764293009415, 0.1442917503300123, 0.12716452562017366, 0.15913192823063582, 0.1832671940792352, 0.2504558418877423, 0.15474767598789185, 0.16686147049767897, 0.1183968003897462, 0.11690993720549159, 0.14486597967334092, 0.319722889107652, 0.13213017635280266, 0.09831910821958445, 0.15675773844122887, 0.21585348848020658, 0.21388612920418382, 0.10175017567235045, 0.14665859285742044, 0.16077986714662984, 0.29744694067630917, 0.16961926157819107, 0.14369406912010163, 0.11980502560618334, 0.13630270870635286, 0.2161151252221316, 0.07693571853451431, 0.10827411388163455, 0.09911512097460218, 0.11661224692943506, 0.11876411896082573, 0.13111782755004242, 0.10467463827808388, 0.11307955719530582, 0.16838514420669526, 0.06342070468235761, 0.0773438329633791, 0.17913709772983566, 0.17555031285155565, 0.10975498051266186, 0.18401872250251472, 0.11732045619282871, 0.15253022778779268, 0.17199950729263946, 0.17556221690028906, 0.11721749804564752, 0.07519406863139011, 0.13558178645325825, 0.10514258465263993, 0.07401475886581466, 0.1481029309798032, 0.0682279365719296, 0.14470589841948822, 0.23165575694292784, 0.1257150963647291, 0.0568155013024807, 0.11793168901931494, 0.22153764206450433, 0.16126912058098242, 0.13340051053091884, 0.1255912022315897, 0.10570353697403334, 0.17834798694821075, 0.17111744993599132, 0.14641052257502452, 0.23346787376794964, 0.1755744474940002, 0.13341331999981776, 0.12006934150122106, 0.19860042521031573, 0.09259593251044862, 0.13987306243507192, 0.18411815544823185, 0.14334344887174666, 0.13042390462942421, 0.15625174215529114, 0.1229361021250952, 0.053971750967320986, 0.17444218246964738, 0.19660565099911764, 0.15086271101608872, 0.16668647207552567, 0.13249142415588722, 0.14043847506400198, 0.13257458922453225, 0.12676035199547186, 0.12229876796482131, 0.1332415870274417, 0.16790452937129885, 0.11596116819418967, 0.18225300475023687, 0.08137050361256115, 0.115617783885682, 0.1358550600707531, 0.19540211011189967, 0.1137869204103481, 0.09812948206672445, 0.2165580537985079, 0.2046220630290918, 0.17168495542136952, 0.14312291226815432, 0.1294993667397648, 0.12035388834192418, 0.15304024651413783, 0.25858295266516507, 0.11223439942114055, 0.12479692610213533, 0.0772397690161597, 0.11130383529234678, 0.13372612040257081, 0.08339828113093972, 0.1440710059250705, 0.17186811746796593, 0.10294243591488339, 0.32550606003496796, 0.1437334920046851, 0.2420901009463705, 0.12895234453026205, 0.11934882000787184, 0.086686492577428, 0.09559322948916815, 0.22322304459521547, 0.07808847425621934, 0.10517060072743334, 0.10751175752375275, 0.19650428846944124, 0.1648562023183331, 0.12270100458408706, 0.08274283856735565, 0.13665177044458687, 0.2161625336157158, 0.14304972166428342, 0.1999876179615967, 0.1521878453786485, 0.13464083225699142, 0.19578157021896914, 0.2253038782509975, 0.13907013286370784, 0.09264472129871137, 0.22220613900572062, 0.13066191138932481, 0.08483326819259673, 0.15507436939515173, 0.14804176316829398, 0.08730187400942668, 0.111103269882733, 0.08483684534439817, 0.12317374523263425, 0.16959414730081335, 0.1701937580946833, 0.19252784637501463], [0.04917061953165103, 0.14168942434480414, 0.018945416013593785, 0.027352444485586602, 0.02748060225712834, 0.08272804756416008, 0.06980250676861033, 0.031206396961351857, 0.005864662452950142, 0.05676323555235285, 0.03797702505835332, 0.017372673355566803, 0.01680860215856228, 0.03951392754970584, 0.03594575202441774, 0.013715454024350038, 0.018842624849639833, 0.04474095898331143, 0.036793893232243136, 0.12911322730360553, 0.04556883955956437, 0.043649322833516635, 0.009582453094481025, 0.027755454793805256, 0.006671652035947773, 0.019795629668806214, 0.06212462540133856, 0.03547960164723918, 0.05295091941661667, 0.07574300558189861, 0.03454428406257648, 0.06783062781323679, 0.07496034406358376, 0.030815439131401945, 0.06259156245505437, 0.006722359275954659, 0.05247804889222607, 0.04960382968420163, 0.018734620098257437, 0.025781063668546267, 0.08495168527588248, 0.024585161336290184, 0.04847466312639881, 0.06021504603268113, 0.051616523051052354, 0.04368712783616502, 0.018414871337881777, 0.07329229294555262, 0.04643096282961778, 0.030688630213262513, 0.02517000710213324, 0.027894813429156784, 0.04293622652767226, 0.019746584839595016, 0.060370422070263885, 0.02748721479292726, 0.044574450730578974, 0.03902213597029913, 0.03754807483346667, 0.03640410985099152, 0.028733379076584242, 0.11799908344983123, 0.0066646957930061035, 0.03695050494570751, 0.08492283799569122, 0.007633348332092282, 0.08598603133577853, 0.06469514293712564, 0.04107414461032022, 0.047054441092768684, 0.0660714929108508, 0.009153181890724227, 0.056610987667227164, 0.05912620035815053, 0.06431138579500839, 0.0052183432035235455, 0.024394195606873836, 0.040436743656755425, 0.02435465583403129, 0.03002774770720862, 0.004262799311618437, 0.014825472244410776, 0.03745888723642565, 0.0412842466175789, 0.03030258354556281, 0.05682648508809507, 0.04758698029036168, 0.022648391532129608, 0.05159031781658996, 0.021714723370678257, 0.06454880625824444, 0.08183286903658882, 0.03412196121644229, 0.04008958552731201, 0.04819871777726803, 0.005555563047892065, 0.033040841299225576, 0.007498931008740328, 0.022306986902549397, 0.053981721721356735, 0.05160238142707385, 0.030692277869093232, 0.01546137684272253, 0.01688799155090237, 0.04135701419727411, 0.09362764394609258, 0.055385219457093626, 0.026780610423884355, 0.05093802566989325, 0.03261121571995318, 0.02983402860991191, 0.0460244403075194, 0.010255152446916327, 0.0671423452149611, 0.02906634548708098, 0.03294922316854354, 0.06577935389941558, 0.08326810842845589, 0.0419059325940907, 0.06737993637216277, 0.02518264031095896, 0.08923171772039495, 0.022188601360539906, 0.013895332067477284, 0.027625441653071903, 0.030441790040640626, 0.016071610552899074, 0.018353909472352825, 0.06088812202506233, 0.04211498446238693, 0.0504123364953557, 0.030130420127534308, 0.04640385217498988, 0.018848051804525312, 0.04133610789722297, 0.06648719951044768, 0.06121306767454371, 0.058136461084359325, 0.025006105643115006, 0.028746724747179542, 0.05389410747739021, 0.042019707543659024, 0.045266748347785324, 0.0060633590419456596, 0.06257746907067485, 0.012524086214398267, 0.04864796945184935, 0.050141133469878696, 0.024469868694723118, 0.039076821121852845, 0.04262936330633238, 0.08773527340963483, 0.05765002038970124, 0.04454519526916556, 0.007068361510391696, 0.05814162643218879, 0.023877143175923266, 0.009318328302470036, 0.015466937384189805, 0.032991069165291265, 0.028730317717418075, 0.011588782545004506, 0.034116346869268455, 0.061451334186131135, 0.00594118854678527, 0.03619380004238337, 0.06942752181203105, 0.08731667985557579, 0.005368622078094631, 0.01648575493163662, 0.02261170531710377, 0.03528403089148924, 0.07214983823359944, 0.07098335277987644, 0.033759934158297256, 0.0271117826923728, 0.0865028852422256, 0.07302342768525705, 0.022927064273972064, 0.0909688627871219, 0.04913627293717582, 0.05286128282023128, 0.05231336261203978, 0.06446382292779163, 0.03387997654499486, 0.034354375893599354, 0.026312834743293934, 0.0026824197220776114, 0.1616528703016229, 0.03019389416294871, 0.038206879326025955, 0.029064838927297387, 0.04077677345776465, 0.043190360156586394, 0.061111378599889576, 0.0698186262161471, 0.0430400381446816, 0.016646467011014465, 0.0401693738240283, 0.04171359018073417, 0.04053787612065207, 0.022856808864162304, 0.02870537598937517, 0.02066027809632942, 0.009239389764843509, 0.03981765890785027, 0.04201241594273597, 0.04886384165729396, 0.07588851847685874, 0.08740595279959962, 0.13419533584965393, 0.03962529051932506, 0.06451532055507414, 0.04400091158458963, 0.007936145975691034, 0.0453333486802876, 0.051259457250125706, 0.01570497846842045, 0.04762854427099228, 0.05561014957493171, 0.058110044337809086, 0.012086469560017576, 0.012760155968862819, 0.003144444685858616, 0.026813302029040642, 0.07315586393815465, 0.07808504553395323, 0.07140432120650075, 0.024880307901185006, 0.09707856384920888, 0.09185329501633532, 0.016973592719295993, 0.04406836538692005, 0.010725600786827272, 0.05392147046222817, 0.0468009382893797, 0.026566417327558156, 0.04901195949059911, 0.01586895599757554, 0.05609360683592968, 0.03346418830915354, 0.03759103034099098, 0.05485541136295069, 0.07424682102282532, 0.04610892268829048, 0.038502127936226316, 0.04780809205840342, 0.07794047516654246, 0.03729923642822541, 0.017164972196042072, 0.05362154632166494, 0.038486372141051106, 0.021066501903987955, 0.04898091545328498, 0.01976268016733229, 0.02104900577251101, 0.026668926475394983, 0.0472670812450815, 0.06308085299679078, 0.033261990174651146, 0.041182153072441, 0.02101379828673089, 0.04217640460410621, 0.01197454997964087, 0.021063876556581818, 0.038582743727602065, 0.04607958187989425, 0.05766534202848561, 0.023145658306020778, 0.040869794247555546, 0.05059280454588588, 0.026323874189984053, 0.017401149561919738, 0.03547220243490301, 0.01985116643481888, 0.029497574105334934, 0.021073246170999482, 0.02443259618303273, 0.02264492755784886, 0.04114423303690273, 0.04866349889198318, 0.01733872566546779, 0.006236714998522075, 0.008936276244639885, 0.06408808840205893, 0.018068579665850848, 0.0691765348892659, 0.049569501643418334, 0.06166187406051904, 0.08701387618202716, 0.019423299745540135, 0.03906438643753063, 0.06275949563132599, 0.034704042482189834, 0.03354664833750576, 0.02677070275240112, 0.05611150372715201, 0.03899129973433446, 0.0622868663049303, 0.012923840349685634, 0.0562718521541683, 0.062473939469782636, 0.04989151580957696, 0.0622681641834788, 0.04282903813873418, 0.03841571226075757, 0.024808753732941113, 0.06748485378921032, 0.028219842570251785, 0.04307216942834202, 0.010818979662872152, 0.04488784114073496, 0.05100304522784427, 0.04825154384889174, 0.03161324231768958, 0.035957481668447144, 0.09014689712785184, 0.03613972345192451, 0.02807628523441963, 0.10982488340232521, 0.031330758647527546, 0.03075849042943446, 0.10688286158256233, 0.029309231867955532, 0.0713321844523307, 0.03971863043261692, 0.013206883413658943, 0.04363570442365017, 0.01166125048257527, 0.011753415947168833, 0.009313515474786982, 0.05332330685632769, 0.09037596842972562, 0.02340944171010051, 0.021438254807435442, 0.04728352723759599, 0.032841574648045935, 0.03521525606629439, 0.025642547370807733, 0.023644355569558684, 0.028787110568373464, 0.02393137005128665, 0.0889546146208886, 0.07155283237807453, 0.04350730174337514, 0.04166454906226136, 0.09545986555167474, 0.01572635788761545, 0.07433540376950987, 0.0759433260827791, 0.013063636852166383, 0.013016136617807206, 0.1446098496671766, 0.18097829190082848, 0.09041148761752993, 0.15504729584790766, 0.12382915068883449, 0.15123498713364825, 0.1885070386924781, 0.18227317632408813, 0.2526853425661102, 0.06437759278924204, 0.09957468108041212, 0.10093580960528925, 0.19393849099287763, 0.13754758721916005, 0.15670097898691893, 0.10123059066245332, 0.12170210349722765, 0.12704223452601582, 0.13827897375449538, 0.24977395660243928, 0.14112025644863024, 0.13518585066776723, 0.09912516223266721, 0.10383766639279202, 0.10225761914625764, 0.08281746151624247, 0.1623468822799623, 0.10509722458664328, 0.18254545546369627, 0.15400012547615916, 0.19934114796342328, 0.08085751629550941, 0.1972925680456683, 0.14784417377086356, 0.21991720714140683, 0.36244105780497193, 0.1791525344015099, 0.08176343369996175, 0.1565259211929515, 0.13814034056849778, 0.2815913414815441, 0.09078755610971712, 0.130836182506755, 0.1401885345694609, 0.13806823350023478, 0.11657660899800248, 0.11996465414995328, 0.16777233802713454, 0.1816627153311856, 0.14865219447528943, 0.20140528329648077, 0.20909115759423003, 0.16587870370130986, 0.20411879784660414, 0.2050607168348506, 0.08487746308674105, 0.142058479541447, 0.1202537355129607, 0.11575532611459494, 0.12162232262198813, 0.10280732050887309, 0.19141417957143858, 0.0922284135594964, 0.07557044140412472, 0.12444580119336024, 0.12755859119351953, 0.25185511680319905, 0.2284779993351549, 0.1612085464876145, 0.1542707867338322, 0.14641987363575026, 0.2348976954817772, 0.228285827615764, 0.1225358247756958, 0.1333233420155011, 0.10748988643172197, 0.14742842264240608, 0.18856010225135833, 0.1209850849409122, 0.18344781798077747, 0.20254185277735814, 0.10269831385812722, 0.11954798275837675, 0.058759030216606334, 0.08442637830739841, 0.269676546449773, 0.14791110064834356, 0.17268315888941288, 0.11620150529779494, 0.1472585301962681, 0.14903776987921447, 0.15758578228997067, 0.09157519743894227, 0.15440407645655796, 0.1431451173266396, 0.07466717346687801, 0.13464958959957585, 0.08232044521719217, 0.0915653417177964, 0.21505544224055484, 0.21864028269192204, 0.11176075335242786, 0.14518341107759625, 0.09905414612148888, 0.17511323239887133, 0.13453849009238183, 0.08090478368103504, 0.15371899993624538, 0.19872621924150735, 0.12337413252680562, 0.13338312943233177, 0.1484025953686796, 0.17490059224655852, 0.2036974806105718, 0.1410323119489476, 0.08683771258802153, 0.12227752027683891, 0.22948530153371394, 0.12629563396330923, 0.10732625029049814, 0.0954962159448769, 0.10618573258398101, 0.15571984491543844, 0.08158223834470846, 0.34888166352175176, 0.18997585284523666, 0.09477170169702731, 0.18718153325608, 0.20895712572382763, 0.11677602407871746, 0.160437187878415, 0.13687472644960508, 0.1745716723962687, 0.1825416408246383, 0.06867895455798134, 0.14052083861315623, 0.13507730414858088, 0.22484996588900685, 0.15599487000145018, 0.10792460685479455, 0.17998978088144213, 0.14025989949004725, 0.10598775726975873, 0.1530411370913498, 0.15788231481565163, 0.11957515278481878, 0.2069964457768947, 0.13680422242032364, 0.1614035086822696, 0.1497116993414238, 0.15244752285070717, 0.15445285040186718, 0.11961974101723172, 0.22349579870933667, 0.06939995844732039, 0.15508781711105257, 0.16431476105935872, 0.1014360690896865, 0.2060985955176875, 0.10572854735073633, 0.14638907450716943, 0.10196769173489884, 0.1587325191940181, 0.1599433776573278, 0.13029361318331212, 0.1302195171592757, 0.20265822153305635, 0.2137506427243352, 0.11605703883105889, 0.1631790673127398, 0.22763686400139704, 0.055026992195053026, 0.21746457234257832, 0.22299015865428373, 0.09985917597077787, 0.12012867620796897], [0.03470381612714846, 0.08024469527299516, 0.06482381650130264, 0.04502448166022077, 0.018914915599452797, 0.018907926423707977, 0.03705557079229038, 0.06881015142425895, 0.03144552065350581, 0.0629473035223782, 0.009569333778927103, 0.05093820007459726, 0.06400791418855079, 0.027797146794910077, 0.026441614063514862, 0.04216318695398513, 0.02415949882561108, 0.06213363507413305, 0.037311782434699126, 0.09434040999622084, 0.04604625944921281, 0.017723750024742913, 0.02481222883943701, 0.029970242394483648, 0.009469898977840785, 0.02644620239152573, 0.0076922586231376044, 0.015495171464863233, 0.03170064876030665, 0.08094395423540846, 0.09126361415837891, 0.06044277404726017, 0.017017457357724197, 0.023822220537113026, 0.023191317086457275, 0.11431083214120008, 0.04671520538977347, 0.026439595421834383, 0.028375511756166816, 0.003026090685125382, 0.012604985877260333, 0.12739577883621678, 0.07856380500015803, 0.032395488233305514, 0.0353430650284281, 0.03607898237532936, 0.0876336956571322, 0.019311491487314925, 0.017580534076842014, 0.021657205070368946, 0.015343373506766511, 0.036865321235382, 0.011078902971348725, 0.04460286385437939, 0.05570344495936297, 0.05282562262436841, 0.049065765197156, 0.015647892469132785, 0.022996468069322873, 0.025078082835534588, 0.020861995690211188, 0.02178168921091128, 0.06166800048958976, 0.07619145573698916, 0.03372863408003468, 0.035971883044112474, 0.0621562000742415, 0.0912408005387988, 0.02565147169661941, 0.01778239824488992, 0.057409542278037407, 0.1274052931694314, 0.04175920628767926, 0.04755035159178078, 0.07750717224553227, 0.016476593118568417, 0.023347327660303563, 0.014617315591749502, 0.0448206619330449, 0.04611414740793407, 0.027125896485813428, 0.0904583022929728, 0.03001237226271769, 0.023307029041461647, 0.03388166122022085, 0.015059360084705986, 0.018811319205269683, 0.06869987570098601, 0.04495061199122574, 0.03800664417212829, 0.017809536730055697, 0.04985729909094516, 0.015462686733371811, 0.07914104746305384, 0.01317965958151035, 0.04911218653433025, 0.05116983920743223, 0.04824841940717306, 0.09269425223465078, 0.004426376081028138, 0.016046123346313834, 0.04192364765913226, 0.07796417194185778, 0.018551335597294383, 0.011201613378943875, 0.06597934785531834, 0.009799404197110562, 0.03273285743489396, 0.036262968205846846, 0.045924001751700416, 0.03099604076851392, 0.02663562074303627, 0.030394702625926584, 0.10044306807685643, 0.02478390477335779, 0.037047737423563376, 0.09765654103830457, 0.040095834410749376, 0.07071082131005824, 0.039199520397232845, 0.05008014748455025, 0.009397356825502357, 0.014873350974085042, 0.039887595194159076, 0.02096777028782526, 0.04257588414475322, 0.018082211063301656, 0.03392355174582917, 0.06016367828124203, 0.014692757686134428, 0.0275505032914225, 0.031800942597328685, 0.06693280723993666, 0.010491530192666687, 0.01833042420912534, 0.08657788668642752, 0.03529658060870133, 0.029330410907277837, 0.017308160313405097, 0.04763229582749773, 0.02946970646007685, 0.012859597263741307, 0.04574461352603976, 0.037857728530070744, 0.04895026846497785, 0.03182068743626587, 0.05042627773946151, 0.06915602192748338, 0.052393844816833735, 0.0238829337831703, 0.04149302018049639, 0.05263310951704625, 0.0548173428978771, 0.01701786182820797, 0.107309062150307, 0.034378833370283246, 0.01285029444261454, 0.03181732550729066, 0.018065889380523004, 0.03752894226636272, 0.013766320826107403, 0.03317767477710731, 0.11791944358265027, 0.05165221664356068, 0.009052281347976532, 0.014583787215087796, 0.03774495176912751, 0.07795148863806389, 0.0354602315928787, 0.0304108554701088, 0.003630879350566829, 0.11827079113572836, 0.03474087156064343, 0.05367547077185009, 0.05234472206211649, 0.031444010382983834, 0.025179823860526085, 0.0686110406240914, 0.0626027540420182, 0.028190856137371156, 0.020504117237578612, 0.08498708572005853, 0.07008096799836494, 0.015892062765487935, 0.0350039814657066, 0.014653280068159802, 0.028038778946211096, 0.032909822548390366, 0.08185185317415744, 0.0562897787312977, 0.027779058800661005, 0.029579329093394335, 0.07552776049124077, 0.006439734597734059, 0.0452638317074161, 0.06886857328936458, 0.02665826366865076, 0.015014242144388845, 0.014257456532504875, 0.03264271617808845, 0.009601181191101205, 0.014509213433484547, 0.0441081482131267, 0.021108501896378584, 0.0450592883862555, 0.04814637781237252, 0.05007691172068007, 0.04176454975095112, 0.07588561667944305, 0.004837081069126725, 0.034694023488555104, 0.03559614851837978, 0.007614167989231646, 0.06884029746288434, 0.03801400256634224, 0.02513066770916339, 0.039383591574733146, 0.08512365573551506, 0.03825705964118242, 0.04066094275913201, 0.08291736201499589, 0.039550459769088775, 0.04045203560963273, 0.03245005093049258, 0.014633571408921853, 0.01131772980443202, 0.004229596552249859, 0.025438302764086984, 0.060514246579259634, 0.05052648994023912, 0.01660470265051117, 0.015379855631181272, 0.032779583052615635, 0.04157505347393453, 0.08166282073943876, 0.022332928674586583, 0.05423751033958979, 0.10614756392897107, 0.05598884526989423, 0.03780981547606643, 0.04233449319144711, 0.021266512558213435, 0.09439498753636144, 0.08687168810865842, 0.047924876416800544, 0.010860668880923185, 0.04819624271476641, 0.05747877723479178, 0.03477743717667181, 0.035926842101616785, 0.00974690095972619, 0.024498762359144166, 0.027430551817815285, 0.0332092383177951, 0.024412237216893118, 0.03550247092789505, 0.010065449296234874, 0.07216267738840543, 0.05149223557964433, 0.03467146590992343, 0.03728041185240727, 0.08417159158852883, 0.022646781071671285, 0.05501574865775183, 0.061631653807125986, 0.01361849150271155, 0.024761029926594347, 0.07616674221935682, 0.05342719639884308, 0.042469890613574535, 0.047454017112613656, 0.03707560506882146, 0.0195670760149369, 0.00861006616105442, 0.07120889888028614, 0.045739377674181014, 0.04229417230817489, 0.056719274434726685, 0.050304695396334864, 0.029112176816852298, 0.0642315529694315, 0.032721584211685695, 0.0360434520553099, 0.02295880036399467, 0.10047170755569823, 0.032577770834905095, 0.05355610002879985, 0.08027325311559252, 0.01027636302751489, 0.04861711466219276, 0.07751912824460305, 0.018282496312167495, 0.07187254217569716, 0.009498138624621788, 0.007963803036545869, 0.07491672062315047, 0.03365005919476971, 0.09531473857350647, 0.05472940953040961, 0.05032298562582582, 0.024686733522685245, 0.023569157456222456, 0.03761302759812679, 0.06643351996899582, 0.05759378786024172, 0.007780870591886924, 0.08221942407544702, 0.022570560649910476, 0.058519728409009986, 0.08563002309529111, 0.07189505893620662, 0.03630469916970469, 0.05500532148289494, 0.009729082921694499, 0.00883538219568436, 0.006100980826886371, 0.003881636671394517, 0.02330868588614976, 0.04408164611959364, 0.04694246585131623, 0.03772088391997386, 0.03871158056426793, 0.0785202335100621, 0.05948612713837065, 0.03189995994034689, 0.02767499114270322, 0.05841678510478232, 0.0373785163537832, 0.013758047734881984, 0.008018972439458594, 0.043772582430392504, 0.0694663064496126, 0.034839848085539415, 0.04800837916263845, 0.07222437212476507, 0.029187202380853705, 0.0248009444840136, 0.05653281354170758, 0.09714305648230948, 0.017501968468423, 0.013868567439203616, 0.03236654447391629, 0.027220062038395554, 0.07692617451539263, 0.04120870340557303, 0.07373021202511154, 0.0382245535729453, 0.020053915613971185, 0.04872485966188833, 0.050482250517234206, 0.05605959420790896, 0.03151805074594449, 0.09132889346801676, 0.2100225380854681, 0.09420861199032515, 0.09254510281607509, 0.10199582655332051, 0.14972899138228968, 0.14873737818561494, 0.09753552643815055, 0.08394433854846284, 0.149578157288488, 0.07317233219509944, 0.11010074711521156, 0.17845197668066248, 0.1279553581844084, 0.09420115340617485, 0.07607616309542209, 0.15573811659123749, 0.12651621509576216, 0.10084429537528194, 0.16249546024482697, 0.11148671532282606, 0.14179949968820438, 0.13259087194455788, 0.1459700134000741, 0.1261668564984575, 0.1343967398861423, 0.12514589878264815, 0.10455818788614124, 0.17100235767429695, 0.22851249435916543, 0.15038175479276106, 0.1566159733920358, 0.14392020151717588, 0.18738142331130803, 0.18225515697849914, 0.175103168876376, 0.16033273801440373, 0.15356552379671484, 0.15891854593064636, 0.09337919516838156, 0.10604181530652568, 0.27378658996894956, 0.17377006384776905, 0.08258429355919361, 0.1659000330255367, 0.1463651328231208, 0.21190131461480632, 0.10560562543105334, 0.1390619098674506, 0.14132911164779216, 0.12435687705874443, 0.09491009739576839, 0.15147055964916945, 0.10937129016383551, 0.15092668414581567, 0.11808840834419243, 0.14582434465410188, 0.11262593427090906, 0.19733166438527405, 0.1504293264588341, 0.11531464624567889, 0.1648453966481611, 0.12676332058617845, 0.17783520743250847, 0.12319488159846514, 0.17571720702107996, 0.24101861781673506, 0.2700567932333797, 0.10393579315859824, 0.11186335526872426, 0.17092907801270485, 0.15326235647080466, 0.1280792077886872, 0.13416058849543333, 0.20253873575711623, 0.09487162446021102, 0.157804062764626, 0.0742609886219725, 0.15113732049940154, 0.20064933167304844, 0.13777778658550233, 0.20262911450117826, 0.11813173492555507, 0.10474617389263585, 0.13684906298294663, 0.22505138476844877, 0.10136086726561189, 0.1288516796194017, 0.12469446519389749, 0.15739230439066887, 0.10984269494656473, 0.30084297875873744, 0.16880689188838005, 0.24831817456288263, 0.121788563701557, 0.19773227570112795, 0.14434888085816056, 0.21515073400223628, 0.2639500459190458, 0.17755046021193266, 0.15204238443402573, 0.13620066340081394, 0.121074231719831, 0.1412705858820118, 0.1169142045546323, 0.11674975947244093, 0.12396580976201221, 0.14395641832379624, 0.16536723036551848, 0.1738119951914996, 0.20884653087705374, 0.14324808289529756, 0.10468105785548687, 0.17933159979293123, 0.1538030555821024, 0.13438937778118998, 0.16116453713038936, 0.1699281731271185, 0.16581146512180567, 0.13716590066906065, 0.15129177627386525, 0.16606164310360327, 0.14334000530652702, 0.11460445544798858, 0.11664383273455314, 0.09811592302867211, 0.10441074540722184, 0.13401068950770423, 0.1308645770768635, 0.09700250855530612, 0.15429152233991772, 0.16123701527249068, 0.24816833494696766, 0.13796005805488676, 0.20828073233133182, 0.13547129550715908, 0.13990003208164126, 0.11975679342867807, 0.06922755012055859, 0.11198394684470259, 0.07974895546794869, 0.08989158348413184, 0.12216990144224837, 0.11670485211652704, 0.12947134324349463, 0.14163845364237204, 0.22187085152836516, 0.22175111342221498, 0.12318994631641544, 0.08044739064644091, 0.14249507017666474, 0.20599983050487936, 0.204227581853047, 0.060736267478205264, 0.18355195614276454, 0.19073132949415594, 0.13990058127092198, 0.11310934700304642, 0.18029541213763878, 0.17257281637284905, 0.1660379982786253, 0.10878612898522988, 0.3084214049158618, 0.14662412751931697, 0.044984995693084784, 0.13492845901055261, 0.11996564862783998, 0.1442500267876312, 0.10991303570335731, 0.16816860035760328, 0.15716036839876324, 0.2725651633227244, 0.1845212306943722, 0.13980160845676437, 0.10550880484515801, 0.11836571182357147], [0.05999376728141215, 0.02322089538211003, 0.01084106133930618, 0.057967674438259564, 0.016486921958858147, 0.05542231199797243, 0.021119771408848464, 0.018227113541797735, 0.03097033277299488, 0.061566756703541614, 0.0812026001221966, 0.029767804917355534, 0.06804568736697547, 0.04332657394115813, 0.03596702568756882, 0.035321839604876004, 0.03096348274993943, 0.083306239976082, 0.03523661878716666, 0.021327366812329274, 0.04541726331808604, 0.02788348268950358, 0.019089184861513786, 0.04473735214560293, 0.040242527320515364, 0.01227087655934156, 0.028591506415978074, 0.00868980065206415, 0.07523491643951274, 0.02921526483987691, 0.054570404390688054, 0.03543801911291666, 0.005652321942761773, 0.06485814083134755, 0.051968635016237386, 0.051692893757717684, 0.09214636171236634, 0.03642360235971864, 0.06086941619287245, 0.059657466772478074, 0.026800212399393786, 0.02572597219113959, 0.03179595907568, 0.09653628396335989, 0.03192419477272779, 0.03625497527536936, 0.0344109794968972, 0.08928123381338082, 0.05882767516595777, 0.02241691752715269, 0.06075543715269305, 0.017690243912511505, 0.0027516481850398122, 0.04814793632249348, 0.032665559483575635, 0.03262157981225755, 0.038236487307585776, 0.029510070016840473, 0.04984569561202079, 0.04628933878848329, 0.02744466190051753, 0.09472136182012036, 0.08513733351719566, 0.049574036165722646, 0.05590458182268776, 0.04144776401517447, 0.016972225312201772, 0.05407832708442584, 0.04805313437827863, 0.04079313039255794, 0.031099592633836437, 0.022346977530105505, 0.026646077603800222, 0.02186125857406296, 0.012585390395543072, 0.0652480503777042, 0.06548932258738205, 0.01672888065513689, 0.04808519886864815, 0.033350984813296236, 0.03024007244675886, 0.058394105071784, 0.04747223312733695, 0.017273028897761833, 0.10056813480332494, 0.10312455895473249, 0.06158594122098293, 0.05491296491527464, 0.019900292900274508, 0.053242431313265115, 0.029002383489569183, 0.06841244190582074, 0.02425712278636638, 0.002092418812935648, 0.10829516118974425, 0.06961230916203931, 0.032508765943930484, 0.04432595371326897, 0.0769645361287985, 0.09061326272785664, 0.012635579987545498, 0.029918494292360265, 0.04422599384270143, 0.04592586825310718, 0.0492491498880554, 0.038523642797372304, 0.07085532488417812, 0.03474887562333606, 0.028957925132999662, 0.033497989425086416, 0.01911388539156178, 0.08212920118239708, 0.010633347192197107, 0.026041778291983064, 0.05463379493448883, 0.045617862124345265, 0.0395675402978668, 0.03559240067261271, 0.029723834522883408, 0.1115051873784978, 0.0445356252748752, 0.06761981334420852, 0.04156177645199932, 0.05980627851386089, 0.026884869184868876, 0.01866214381152531, 0.015895836586423684, 0.03640495961008128, 0.022003676713211462, 0.07427299657138065, 0.036808929144172, 0.01787860284821363, 0.029175932868383825, 0.03818701945419889, 0.07243482294143178, 0.04813559069589246, 0.08816657995339483, 0.027090687144664116, 0.049859217542689294, 0.021885602873226162, 0.024618546849524137, 0.0394193222746253, 0.021480547948158346, 0.0811950524803251, 0.04288507399905939, 0.05495551595231518, 0.0280547128568287, 0.12147177796578035, 0.09301022902945988, 0.036221849513822235, 0.034304366272408515, 0.07158199878176674, 0.01929111582285259, 0.028985584976908285, 0.03975655788963195, 0.022928255420993082, 0.02314756748091895, 0.039033420325722545, 0.07069181490805931, 0.03942733004805632, 0.03519465033605229, 0.045753322629025206, 0.055965167048270814, 0.05246011118288152, 0.04531062411842868, 0.023791554995113984, 0.09189832853735425, 0.019341878723935224, 0.05097085457236972, 0.06478137307567522, 0.03348606682266109, 0.05986420685076155, 0.06334963662084192, 0.01581320586410584, 0.02290517648361856, 0.05880988959688693, 0.02715626331337262, 0.03851380191917997, 0.023342991662502754, 0.0672188309545163, 0.03312839246063959, 0.02949391902802745, 0.04156883056566585, 0.054516940072062425, 0.04077284749655519, 0.0477814934856724, 0.04560555360512808, 0.052485548294498585, 0.08077965016127564, 0.02551424302509986, 0.0968198585906066, 0.028104600023652893, 0.06768666600692086, 0.07850810681702569, 0.04955138952936977, 0.07656915695406497, 0.045570524234790355, 0.011798003251897171, 0.022003912345098797, 0.06013670121319592, 0.015059007564559579, 0.053462867726921104, 0.030509566677210387, 0.044822316922363825, 0.0645443459507078, 0.04655141710827593, 0.023473732107959222, 0.017185583492391743, 0.03144554662867449, 0.038206363533390686, 0.02801940147037385, 0.03818637749645859, 0.08146696796757169, 0.031198622964438982, 0.06628410337725654, 0.06463666912168264, 0.03556857402145397, 0.03889710635121446, 0.09243123509804718, 0.06352679469273426, 0.03430628472415265, 0.02115644278092077, 0.010199243679380743, 0.024668398764333688, 0.0131082287953177, 0.05277305630443152, 0.03620594899985008, 0.04081997387402225, 0.009828179117903346, 0.04568862590531353, 0.03332936605147552, 0.0026336323253417504, 0.02519716970709851, 0.06528079393319786, 0.015098684634722304, 0.08304550123284571, 0.037627273122780025, 0.06082689113100059, 0.028889820096082985, 0.06355022429488599, 0.033789757362683304, 0.03123309201328084, 0.038948615110712126, 0.03130377044726629, 0.024460614113195334, 0.03746686903468799, 0.03395613945031073, 0.05074729742773343, 0.061199419578770176, 0.03748097355128266, 0.049350902045262046, 0.034883445550804026, 0.02902591513702646, 0.047106873826123774, 0.025748295993253123, 0.07239741127705202, 0.03042342188564362, 0.07598271185997874, 0.08209586390876211, 0.02792166247672867, 0.030045253115531523, 0.06810265462263487, 0.02096974440064514, 0.06225909513887018, 0.10383801520220004, 0.01209796171679045, 0.0014905580360391468, 0.05020837204938289, 0.021183429125812836, 0.02840527373336954, 0.053658909746445715, 0.023000323526503053, 0.0066763391623680945, 0.005152458115844638, 0.12739188998239115, 0.011676954327413114, 0.02930739319708664, 0.032163173746084794, 0.0022416106730815955, 0.022008842061040923, 0.05902746874198783, 0.06208876111486461, 0.06454303234932013, 0.026917468021565583, 0.039487080357503146, 0.05647917481837794, 0.025241576113330666, 0.03788377049204428, 0.02606217807624489, 0.010377703292760998, 0.09637836235924624, 0.03536720709234942, 0.037566301980405115, 0.023697183496551588, 0.027105570916319266, 0.042292339203413576, 0.052395796665223315, 0.06971421345951967, 0.03652221894299146, 0.10852623629034497, 0.012419725408108206, 0.005535005557248951, 0.00478191398542549, 0.055437718983739614, 0.024258300945803057, 0.021830513251188677, 0.024789485723886173, 0.026898283504124265, 0.05019133604946546, 0.04128379761823453, 0.02077411798381945, 0.09031494162627496, 0.0307601194435847, 0.02391300931776641, 0.07708578079473227, 0.05058285234554205, 0.02633414180309046, 0.04878604973782785, 0.062204866408137605, 0.022617562717641704, 0.03073201616643928, 0.0577660885755904, 0.041473197416053154, 0.12586971541168168, 0.02497734185453737, 0.034006698260782287, 0.005998540327709634, 0.014090693166508572, 0.10884198301937431, 0.04614282770489808, 0.02982785208587302, 0.015710320076323114, 0.029659026477020234, 0.032854758901521564, 0.031324320516432635, 0.006909108678883058, 0.035237783959019, 0.010967704201902961, 0.06104760213929694, 0.030527600865752902, 0.0459035110543482, 0.042173116889898665, 0.09182141235214658, 0.06772523542167619, 0.02031812575296499, 0.03227178334782366, 0.049070203240262344, 0.06354319615638815, 0.03604911093134433, 0.04612958036886994, 0.053245381350279786, 0.10072049029986374, 0.1604589624912478, 0.13639617478474975, 0.1817747944733128, 0.3094625490484759, 0.06514999040518887, 0.11236941092647612, 0.12032855142024346, 0.1832588523393497, 0.13975739129818976, 0.3266294638160616, 0.22496611200040206, 0.1274061985895969, 0.20960061228834093, 0.18769417918520048, 0.24323207326233387, 0.15018242876976728, 0.10964195884298533, 0.09926354308845475, 0.0962981213524472, 0.21887995186261833, 0.12483308353694156, 0.08744138292968273, 0.12300822403631173, 0.12387422873871401, 0.133624579757452, 0.16140168299898505, 0.21490524639375508, 0.16198927100049332, 0.11348888874636032, 0.08003776965779252, 0.13981182040879503, 0.10570856131380424, 0.18140752043109387, 0.17236734536709264, 0.22292998532066122, 0.18276818882441148, 0.25005953502841294, 0.13645137572893873, 0.18754015385638922, 0.24779598461464047, 0.12766891886712983, 0.05870606684766244, 0.1297012754366733, 0.19695569237228483, 0.12580813199747354, 0.05809765789308585, 0.15857076068641618, 0.21005522226914763, 0.11099734314484522, 0.12806035723770037, 0.14900545676937327, 0.16963699890766293, 0.14022154529811814, 0.17581571970367804, 0.18185466440627351, 0.08614644655608572, 0.09771666242158972, 0.13693127810256556, 0.11652246190351434, 0.2404518990078941, 0.12191065441584215, 0.20589532126905397, 0.12776974705047905, 0.14253342436859384, 0.2278903519618325, 0.08695792566868477, 0.09816451143706217, 0.14010654209414497, 0.26222223707009107, 0.11349324515322223, 0.10790424974402413, 0.09559354861266911, 0.19026460766326636, 0.1783928571967408, 0.11143038631416857, 0.18113855127012357, 0.1387783352402039, 0.14044031559024006, 0.16008992213755846, 0.1572737834067084, 0.15395118825836107, 0.16121988650411367, 0.1751354819862172, 0.17536050116177648, 0.1864773835404776, 0.39518146659247577, 0.20415513339685276, 0.12657686340389773, 0.23876036633737385, 0.2008561830734834, 0.12683091539656743, 0.16344824427505955, 0.10650460375472903, 0.11426219920394942, 0.19664847292006016, 0.17271824763156474, 0.07957235400681384, 0.11358730494976044, 0.230027959914878, 0.165635843295604, 0.1542208401951939, 0.12288669735426083, 0.11417575384257361, 0.08032949306652881, 0.17890207440359518, 0.19625084503786638, 0.1392316835699603, 0.09891699723084457, 0.15578185877529904, 0.10928036223049276, 0.1008620772336144, 0.12878086388809606, 0.08893208301742561, 0.10148226036108099, 0.17804008472012356, 0.21149187174160033, 0.20479709113715217, 0.14087791554629803, 0.13047269341768697, 0.231503497925587, 0.11989858074230142, 0.15808861702680588, 0.08236575333285145, 0.24813241499941796, 0.0859613623470068, 0.05636012319882866, 0.23266780888661742, 0.11945968202780932, 0.14465160289546475, 0.10927119670668617, 0.1197991477965843, 0.09097819158341736, 0.09091938380151987, 0.1831527252215892, 0.18243030383018777, 0.13985122845042497, 0.1583138736896217, 0.1843605557223782, 0.1749127040966414, 0.15609347174176946, 0.07469570904504508, 0.19973629707237706, 0.11956783520872705, 0.07104375617927872, 0.1343143021222204, 0.14964627160225064, 0.17222109774593264, 0.33508380234707147, 0.1347665223875083, 0.13196435087593272, 0.08466759114526212, 0.16977478604530916, 0.13522579305572435, 0.061966662979102693, 0.11066914317780174, 0.1387328267446719, 0.13082818215480074, 0.14256266498705372, 0.15546791546512395, 0.13120721181621775, 0.07880383782321587, 0.0814159082074184, 0.24301794881466776, 0.11770863653509878, 0.12249909588717856, 0.11372714041499421, 0.18408363073831424, 0.2132480900036171, 0.11470040772110224, 0.12321575821260922, 0.11531484662555158, 0.2593723306199536, 0.18485929380403832, 0.17227616510353982, 0.2380029155756347, 0.23855621635448188], [0.03279170603491366, 0.07905083199148066, 0.08620918772066943, 0.02058796693745535, 0.0296029293895117, 0.049547088783583604, 0.02423117359285243, 0.02382844715612009, 0.02834634349710541, 0.07034846028545871, 0.03794699034187943, 0.03392104328668211, 0.04504092765273526, 0.06769501516828313, 0.03898195980582386, 0.04800249764230102, 0.03706347466504667, 0.036254348160582595, 0.0706998523673974, 0.06917375925695524, 0.013932109195593512, 0.010069596046378138, 0.03410498829907738, 0.024638718423375394, 0.03918044349120464, 0.07823410589480773, 0.05952926447207574, 0.010881309863179922, 0.06206149460922461, 0.04404538849485107, 0.015103489113243995, 0.024097638961393386, 0.010182982296100818, 0.07419731235131621, 0.04680474921769928, 0.06884753340273164, 0.02511799924832303, 0.06862499300041236, 0.1156080691725947, 0.02678818960703211, 0.09474760416196659, 0.038055514596635476, 0.04810006408661138, 0.027149773231940344, 0.053755489134346135, 0.023348889881162904, 0.046246205165516585, 0.040793260268401355, 0.08492628898238763, 0.03608468206948601, 0.03377171575266402, 0.029799951043969486, 0.08644113113405183, 0.0640421271964442, 0.01991282591916388, 0.019918727848562412, 0.09226524634868838, 0.05094780346553307, 0.03911602878361009, 0.042669866015785374, 0.023503204647568054, 0.03706981260620523, 0.007914078214525944, 0.03760714978852775, 0.02409080563666066, 0.03989505748904776, 0.08719028468476608, 0.03962405855418183, 0.05394407256972045, 0.06642040621954948, 0.01733981476718327, 0.038011319702491164, 0.1128263735154178, 0.03748113682377152, 0.05649005470331758, 0.06880253698909655, 0.02281721157487482, 0.014187261422193842, 0.028994410968152806, 0.008984186515590409, 0.013647880550706759, 0.053690261775045656, 0.03821288701146841, 0.06481830976554193, 0.017059822857845575, 0.024790496900095604, 0.023362079700746108, 0.043315334114595316, 0.05447879739222117, 0.02636590757902013, 0.026342362943978515, 0.041109786252491176, 0.0584127181355143, 0.05746541857661214, 0.053617204757756554, 0.04965724947396666, 0.049895931588253006, 0.06284096860326827, 0.050696593898464926, 0.07967379075125791, 0.009992634404625278, 0.04942238942021504, 0.07060095376800746, 0.1026395357621368, 0.03772674688661937, 0.04028389463201165, 0.024061535332293715, 0.03477414575172588, 0.030518973399011884, 0.015207776632450987, 0.05575869414315093, 0.07319005468161777, 0.04805043667147402, 0.061381011983030476, 0.023269561716006137, 0.022773346936446615, 0.036070852147531696, 0.022171326017996762, 0.020598729934135918, 0.04439494376129005, 0.04834322135138791, 0.053872792996116914, 0.053224849834805354, 0.04487306498049293, 0.05342867327271961, 0.13356437673792243, 0.03818376884737518, 0.031014266060083173, 0.026160212073591538, 0.04152586763666477, 0.017625805085117463, 0.07469639924238436, 0.03943971278204117, 0.027725045292754658, 0.03252877795603126, 0.07418494074954651, 0.035423413646640256, 0.05263192950224038, 0.04095051765034441, 0.040477940274286084, 0.030688309234392364, 0.05975779400614556, 0.04427943960763514, 0.01496035201853374, 0.030561478051822633, 0.05128901328134816, 0.05316026814398356, 0.05680913367541507, 0.03012862227478763, 0.0344194993522251, 0.023209996943478473, 0.061448877677321434, 0.04287358184228651, 0.0065720836482796585, 0.06985715110204183, 0.032691827800590545, 0.03050886905839434, 0.050438445250620134, 0.06423553088097833, 0.024784698871371802, 0.035135783182340674, 0.04430505112395622, 0.03385829841136001, 0.05244776184554212, 0.02450884072459303, 0.05765754576714244, 0.03328518971102312, 0.012885248670500005, 0.019269409858679865, 0.03392214908672031, 0.009455774979869602, 0.0717138487379998, 0.019996469673060346, 0.013602619746961864, 0.08020919092814438, 0.06830719794379547, 0.021330545059754513, 0.021290459808369633, 0.06514458757010289, 0.030554488876077812, 0.04025348513096105, 0.007890653250797186, 0.059051054195151664, 0.018278856077813543, 0.05198347796977032, 0.011987146081082756, 0.009232280917785829, 0.031428210058948025, 0.03909236169420183, 0.042344267276348546, 0.05677671295416076, 0.022984773677308112, 0.035601996642071754, 0.0872852053726092, 0.03697083979204763, 0.10158458768273704, 0.04424774619110394, 0.020164176494290587, 0.013094822825223673, 0.04316573940741364, 0.049442798481322825, 0.06960108788916841, 0.03352170475409366, 0.050786779684131034, 0.046191007932065986, 0.06414190895156935, 0.06207574384461623, 0.02502284107322339, 0.1026778008963447, 0.11570425151148811, 0.06986403823248111, 0.05272201138723176, 0.005892224889976205, 0.04889163879852276, 0.11665831945720129, 0.0387493447487941, 0.07377451824140735, 0.010306788299203617, 0.07277574331965297, 0.04227004879794549, 0.013082649747957475, 0.040106142841978, 0.016823500773170963, 0.03778352118388284, 0.01257148996955948, 0.022457854392996524, 0.014560927211277885, 0.030017404023965355, 0.1190540760580916, 0.05682833303580992, 0.019119768767268397, 0.028487607596616726, 0.04555324703687802, 0.06902881039422937, 0.06547042750753462, 0.014657409192295745, 0.08341828201082535, 0.012785242415702669, 0.05236115321167745, 0.024860692938091233, 0.04122094513149932, 0.0021725997521571117, 0.07332033128477633, 0.015270130952558247, 0.11194275022717193, 0.02821395919454517, 0.048929132099146955, 0.0422611504473025, 0.052596818495658226, 0.05594150738033932, 0.04071690811542794, 0.018896118854172528, 0.012081881232006708, 0.015746008102723863, 0.02178025315515697, 0.025108058180194348, 0.04764546894875821, 0.06355496661853977, 0.04971745249349624, 0.035492507595336065, 0.029733042720181402, 0.036303315064287744, 0.015783085800649133, 0.018317920876143035, 0.015553649918729207, 0.02104036717355484, 0.05559047524002381, 0.03405074472539127, 0.09316349736764096, 0.04420520999701694, 0.010458295892021852, 0.10497146024135873, 0.040683507759240456, 0.032867497866391204, 0.018624691329023335, 0.031003128278825898, 0.014249484938773094, 0.04849737655604258, 0.053254836311680265, 0.040344490989809856, 0.021392657254182268, 0.012153928000770975, 0.011763871880248189, 0.02094968600431457, 0.05509563343366608, 0.02981363624712685, 0.03192217613104731, 0.043993148719891906, 0.03814864299783949, 0.06633763448917307, 0.029914490405644756, 0.01242858850673656, 0.11994906162726693, 0.0557858790125465, 0.012820160463888897, 0.03781921106565278, 0.1068404181569349, 0.0226464675142779, 0.058800827973755077, 0.08695958065800369, 0.013878776608180488, 0.024536042292311322, 0.07595767179736868, 0.02157375798560679, 0.03672642458695918, 0.05185362810152583, 0.03198910300852731, 0.02119938344549155, 0.021396529409685172, 0.023942815823829733, 0.023807151228538714, 0.0622049109369982, 0.0060206141188245965, 0.017262750152440276, 0.007002473175816704, 0.041232255462091416, 0.050651126221055165, 0.04416861840581987, 0.05929051556449849, 0.06972714167204686, 0.02867843046260532, 0.022676713742839638, 0.014119319657766027, 0.07612130793859251, 0.03370479629666079, 0.07482172572053969, 0.02361718925385503, 0.025040992150024977, 0.03841212768747937, 0.03694441562402062, 0.009782017532415921, 0.07818303871317767, 0.027537790301721543, 0.038507404606207274, 0.03575092712708283, 0.08353116267244332, 0.009688463323982432, 0.007845747750252485, 0.11317668948322535, 0.04571841942379251, 0.03231356626201887, 0.07902315730461851, 0.04023782581498381, 0.025388914691575337, 0.04242771065037232, 0.05199531151447445, 0.03367795281519648, 0.07433795675751753, 0.018999572384927887, 0.012610753292392474, 0.027919679087062832, 0.03184673310897779, 0.14422381413169205, 0.2554247580701485, 0.13899961399147287, 0.10862904600799084, 0.07460794266080484, 0.08633838820969686, 0.18610537459608167, 0.15160120732616633, 0.11970926629146561, 0.13563582964707166, 0.08000064000952989, 0.10610857891151682, 0.11381162650650367, 0.20172376855043694, 0.20470141345867887, 0.14504096325254068, 0.14615256688557565, 0.21777838206617162, 0.20224793261149898, 0.2478831572807394, 0.17804820381570607, 0.162298969225958, 0.08378580838325433, 0.24689608602784574, 0.19410492503084242, 0.15773913968587294, 0.09614644863177091, 0.1536435235175304, 0.08613429017714225, 0.10975161858368665, 0.14320126821985468, 0.11956092581385747, 0.16301472613122314, 0.18716090155066922, 0.1245749942609109, 0.12367913295747712, 0.08215707624913193, 0.15784271381562576, 0.1998293772339821, 0.09571611430146731, 0.18582355143735185, 0.17325033782981336, 0.14056060288567096, 0.10574989893939346, 0.167739876487758, 0.07344678582740016, 0.09429009980522096, 0.18907818070147187, 0.13574580108979717, 0.1252394390758127, 0.17138440045528114, 0.09899755736114457, 0.3545296151423827, 0.0964307134563569, 0.1269844063790515, 0.09111588224186562, 0.2540716150542721, 0.1359234712435864, 0.15997288544895127, 0.11432196435634978, 0.16815086302813143, 0.13524617243092507, 0.12270148698007688, 0.09155659179668874, 0.19660686812130734, 0.11642840210697614, 0.13003825501073152, 0.1266777509590611, 0.2297779155196622, 0.18013022490777075, 0.08882166628609411, 0.07914635381894186, 0.17120665608672425, 0.13331802823813632, 0.07783373206621036, 0.14403327513718978, 0.08375978126423433, 0.13890697911847383, 0.10498083356651478, 0.19907179288566113, 0.09399336689966731, 0.21865895512746647, 0.12499041884439066, 0.0936304937931709, 0.07486214308300987, 0.10596515887300484, 0.11448666176875122, 0.1549493323545903, 0.10292037928593345, 0.10720951788243838, 0.06997386866714805, 0.10864229334401898, 0.1287592525477521, 0.1991993235424161, 0.1772003000951372, 0.08260989765403792, 0.16395234066294506, 0.13646293838974088, 0.22584146034205332, 0.14817113435128704, 0.1049773751583416, 0.171624559443444, 0.1948679270572029, 0.1496807369403541, 0.146451533655636, 0.09421817085240036, 0.07650784813449718, 0.08903499663574621, 0.12228259656694718, 0.09853594150627032, 0.11921777899260633, 0.16379545064410195, 0.19891825737431645, 0.1542653690557927, 0.15207949181785807, 0.07959932365338318, 0.2656821592245251, 0.09488614086876623, 0.0819064826646354, 0.14219463395420462, 0.11287868750514463, 0.1456805906491354, 0.1504569046664983, 0.1867377883172594, 0.13508056959835812, 0.17056987853720784, 0.10030157762230374, 0.23789251368725672, 0.06498417977127247, 0.1559630170231685, 0.09382708129123785, 0.12804221914848313, 0.11031807021936402, 0.09773027340997942, 0.14062077621929348, 0.1760008855490014, 0.1601419021608308, 0.12551587424241006, 0.17425900558009744, 0.14837463124422356, 0.10121317987795919, 0.14544328150805086, 0.10886704534641467, 0.15989904175512493, 0.11072894543758593, 0.20385230745887384, 0.21909230999881402, 0.16843688674271107, 0.13910358888097107, 0.27070091804489493, 0.061586850351886824, 0.14244420337490737, 0.15784247632836923, 0.10956658632494509, 0.15764220035634935, 0.15221671492327005, 0.16554482630454004, 0.14799362746998668, 0.11182321250089444, 0.23881679924670607, 0.279249984305352, 0.0880352346575819, 0.1568900782149285, 0.22388830577256158, 0.07786911766743287, 0.13924170256359503, 0.135025309282355, 0.10459874625666998, 0.0971558214223478, 0.1785330637358129, 0.1383648402406834, 0.15674068388761953, 0.1385906312498264, 0.1714749721577391, 0.19175524095771834, 0.09373851338750683], [0.022809619404142722, 0.04463296907488257, 0.06672059011179954, 0.0071128583658719435, 0.009164522834907984, 0.022202099171408918, 0.023968911591509823, 0.06727215426508337, 0.06187441773363389, 0.0636453676270321, 0.030525541405950207, 0.025043849418580066, 0.020868224164587446, 0.12974785262485966, 0.03347525744175073, 0.03216392702597659, 0.01575760601554066, 0.014031725822860608, 0.028731076563417446, 0.031193093964247964, 0.019218609850213397, 0.014663154342997586, 0.0639502567355521, 0.044323912807158194, 0.08206104233977385, 0.06084115520934574, 0.04304199741454795, 0.0381173021014547, 0.06538110261317343, 0.04375955402792897, 0.0705361420114059, 0.014674056492367527, 0.05975282903818879, 0.07482617860659957, 0.06206203266629018, 0.03328728627820965, 0.020828118504141457, 0.01612305066373665, 0.053448236285476014, 0.04996331117581576, 0.02025146604864858, 0.06888363146572374, 0.0340998266619863, 0.05251894493994769, 0.038461332078441046, 0.01447192051273305, 0.08953249533078633, 0.046908460644772276, 0.054756104582338594, 0.030690149760630447, 0.025319520173070487, 0.06568245909875259, 0.059255115120322444, 0.05793414049549028, 0.06010549019265454, 0.06391380986315198, 0.05590165405010339, 0.029018439854553435, 0.03958718865760602, 0.03331200350658037, 0.020188133021292742, 0.014549400730174966, 0.1756101002683863, 0.052769423491554335, 0.011642957470030524, 0.048024279676610604, 0.080228175065713, 0.01859197003795998, 0.021371064467530232, 0.04561977315461263, 0.01463290811443585, 0.03645712145953439, 0.062081376745481975, 0.050235464150318876, 0.035937480788561516, 0.045555480901384726, 0.02705734244955238, 0.035627277902676724, 0.05643951444653794, 0.05118082670378499, 0.040293549973284826, 0.016505761377629824, 0.04467534941795748, 0.030376661015907302, 0.07271317284903489, 0.011676339272526093, 0.011163229501107708, 0.00658208687127626, 0.038512536557391286, 0.037972820791765116, 0.09904267993988469, 0.06615688442252576, 0.04836302556213923, 0.017233040125574917, 0.022354918510245625, 0.07046495520626195, 0.021615895275317598, 0.03632022489910014, 0.021538556065934245, 0.0178863119072048, 0.01401521489242441, 0.01599178143806057, 0.0016168588149412244, 0.028772545920219272, 0.0190097064114525, 0.07174090744229034, 0.054609971994068474, 0.07319962096516974, 0.017098735515901353, 0.006199895660756738, 0.02447092625516234, 0.038929712609387934, 0.05032180190028157, 0.02405868177447701, 0.03861588062136434, 0.019707345636561513, 0.018970923629240133, 0.06724326245603152, 0.10518156967009418, 0.06493245207821019, 0.02472285385010764, 0.03770194802200422, 0.02881860546040116, 0.04945033499097917, 0.036631982584367506, 0.014931399909983156, 0.03159375351970084, 0.010113977405126207, 0.02954760228021769, 0.05609989653748926, 0.033344086550641805, 0.0037818676719325595, 0.010859599260584218, 0.03814614567090757, 0.05593143272562884, 0.09695160464616492, 0.021044512068328913, 0.04548954850179143, 0.06196042893861886, 0.02293529840244446, 0.05393689971242566, 0.04332962416810915, 0.057144050078932196, 0.009757003444974544, 0.0028465002242228366, 0.03617624824983068, 0.05480944273585919, 0.03148137380776461, 0.04720555720268749, 0.021125589846633375, 0.046660330990562215, 0.03533453033014666, 0.008286589963972801, 0.0111491110692441, 0.08698931851540692, 0.03428848802286666, 0.04239569439960178, 0.04458525269001257, 0.03664232441224158, 0.014025815544300713, 0.06271420235862024, 0.015664279089833144, 0.02049412050837418, 0.034181644732598215, 0.05111368460347876, 0.008561270878999494, 0.020305208672652952, 0.049458921639597975, 0.06451912777265534, 0.016323892523359973, 0.020170007919659838, 0.015315117161662783, 0.04441796147148125, 0.03417225285375025, 0.09001642014482059, 0.02521346355933929, 0.07522569896536879, 0.0633890372409951, 0.0649186407099478, 0.009160461431747535, 0.06889945405418985, 0.023585074668517336, 0.04948581707139965, 0.03747894006664865, 0.06381866653100587, 0.09562965409713797, 0.06489547828095965, 0.08193643574486487, 0.09982795381802134, 0.06440473312977701, 0.0721562874969095, 0.01264084459762671, 0.03982545145845506, 0.032343608399969526, 0.049317668672301807, 0.002914709625656542, 0.03990924735262524, 0.014932412013877183, 0.027766334678744897, 0.04973355709807947, 0.06048226001439616, 0.07068527658702806, 0.028487396084528882, 0.04540445384918712, 0.07560763042420149, 0.02176603546104161, 0.08534601060091518, 0.031100711421458982, 0.04990341985831037, 0.01756468180246884, 0.052119472820777446, 0.06905629954417236, 0.04942328741890378, 0.013878460267733317, 0.024862544596544467, 0.03641091905592475, 0.030711224899278022, 0.029317180269572418, 0.04401158366817981, 0.058279599106754176, 0.020449899639061186, 0.10819702700246125, 0.02923813597590197, 0.031601642549503595, 0.059591218960122205, 0.07412242965074256, 0.05817818833747879, 0.05601813412795309, 0.026031545930891298, 0.06813979169237427, 0.07408826859318651, 0.04422063553647604, 0.026187695657426957, 0.023138273936638143, 0.04231495986459777, 0.009272743736801203, 0.03982777438068297, 0.05284511513309553, 0.04499612048675772, 0.03717431070981547, 0.017989299740293063, 0.013592674968094798, 0.0406311343976995, 0.027122280371258967, 0.014897059809300117, 0.012652197601710213, 0.06486105005024001, 0.021203157266427297, 0.06175692462420557, 0.04944777458149474, 0.015518801446887664, 0.021556558713200502, 0.016352960592485033, 0.04462882789084688, 0.02523726609069854, 0.029378431572695263, 0.05709886441763956, 0.010263613858114695, 0.04797186178620905, 0.014625709281972377, 0.013261491567391204, 0.02130284068698529, 0.05082853291241918, 0.03230363261536695, 0.04993037466192618, 0.08649612427689135, 0.060356870453688316, 0.054780892314738594, 0.09932051776559092, 0.00727196323168755, 0.020781199928023852, 0.0372841671196511, 0.007738568174318061, 0.050133489348809235, 0.04449051382835023, 0.009797723232622957, 0.028371930893626995, 0.03655951557448134, 0.020622426709451247, 0.008626322905911366, 0.014975501107983291, 0.042560195142868906, 0.053949130306136794, 0.0802888827456627, 0.032075544659164734, 0.029335127255762927, 0.032084038539323956, 0.005387800101743778, 0.05549123525270261, 0.0352724199910881, 0.06955439937883057, 0.00869888361194171, 0.04951165494276211, 0.04951919887389522, 0.08190217820811085, 0.058737389190355316, 0.01623743046366144, 0.07703365976340137, 0.024487379669153597, 0.04070204289746471, 0.07870707660913467, 0.012016698401566828, 0.024657296235091053, 0.06263320436119102, 0.0384556546487147, 0.09813265103730373, 0.024490830655850004, 0.02199157970608212, 0.01842710749770049, 0.023604424313816708, 0.08245037301094271, 0.03678801913338248, 0.030927662992326077, 0.05968967598164454, 0.04720313780126162, 0.03620902891270816, 0.027198704883630853, 0.05452984230942093, 0.011369040039426181, 0.03625208089943044, 0.055630536371609196, 0.0450575628929073, 0.05199506660574116, 0.054227109139901586, 0.03933679916372057, 0.06294197490205988, 0.028761450812453404, 0.06395152580807917, 0.008473510988551425, 0.049060781675507315, 0.020698428197647445, 0.0413654264411889, 0.0223933673260035, 0.057932210911531, 0.03062747167859925, 0.01179759414299042, 0.050896294706035405, 0.02439887113723671, 0.013230772219685605, 0.06603117944905534, 0.04783964075613767, 0.028970506391488016, 0.06141114317870233, 0.02034507127973484, 0.0236549311739509, 0.04798171008587815, 0.06474992085713893, 0.0297712651808979, 0.04419024829985574, 0.0333039400720736, 0.027731169866456185, 0.08578507258789614, 0.14757168682990596, 0.15202690323349088, 0.11451280020992272, 0.07687072124099359, 0.19030619761906564, 0.14042633352801204, 0.18780382408294827, 0.15652175032300875, 0.123040344187757, 0.11173536448040977, 0.14913055318174884, 0.1376800605794415, 0.12019689442240633, 0.17573820980032906, 0.1598900172393769, 0.0626847539388109, 0.08363417276996188, 0.059026025264756754, 0.18320651608519256, 0.09169952201773413, 0.10310676967492327, 0.07949747130624019, 0.10322801434085704, 0.18937814194941893, 0.1558126727468334, 0.1631467987317592, 0.09903401907649823, 0.10147158085601404, 0.132290999754332, 0.14942572015570477, 0.14426099573029205, 0.17486198572441936, 0.16056900814874098, 0.15639276505680755, 0.15991698688594624, 0.15521674300543964, 0.12960674066562206, 0.13391811400651932, 0.12441041559213772, 0.14171250513754785, 0.10440819984069094, 0.2786516648484394, 0.1190365687943995, 0.15824795613298193, 0.11120555267552845, 0.22513379284646362, 0.12402686625136994, 0.13155760942026973, 0.17383727274136618, 0.18262110999785364, 0.1886378347990103, 0.22325186961097643, 0.09059943651664071, 0.17170190607430413, 0.14680209453217685, 0.14882906310958788, 0.09464774077059701, 0.0944063720817212, 0.20555767376208678, 0.08610427030362189, 0.10294285151758231, 0.0923462220816873, 0.2591496566310525, 0.12228280436829664, 0.1457066845614463, 0.1377807551762089, 0.31331854057498276, 0.08481380165903829, 0.1379809420905076, 0.12650689372094348, 0.10204756908933632, 0.05835398827912286, 0.18518287019105628, 0.14557076763594523, 0.13670502696186304, 0.16613612504443154, 0.05898477669688873, 0.09007732078316621, 0.10290283491485752, 0.12563780910568312, 0.1268410828197375, 0.10536709174630232, 0.13852554489858449, 0.03897891328961123, 0.14570849540177733, 0.11961688374867663, 0.12685545079875737, 0.06916722835740075, 0.16214286588365212, 0.16914689942495897, 0.16584322904236615, 0.14345791772939265, 0.16379129461711273, 0.12038117711199448, 0.14762215287191793, 0.13017622026382014, 0.14714714867295697, 0.11043607169995084, 0.13160372647689655, 0.1496958322240971, 0.149349664861802, 0.12933376390719786, 0.11149556914460845, 0.10329695986001752, 0.12743025901727378, 0.09332845453172922, 0.08613798607257195, 0.21805817174026743, 0.10316948857507668, 0.10689011236536317, 0.18553127883933485, 0.07992064391146414, 0.14424043823964894, 0.10209621686954051, 0.1659711604588665, 0.1054507317894604, 0.11573444950045086, 0.1208921086799819, 0.20872637716820464, 0.16641153604723513, 0.09172525969916023, 0.10966847577947192, 0.1582641201093793, 0.18086118099745363, 0.16754994605435058, 0.11278539212071337, 0.10505491474759765, 0.16836455703014508, 0.15154979133512825, 0.20121138979448006, 0.12549197708722204, 0.1216049786307849, 0.11108174017863348, 0.09012458816869184, 0.2516844228375703, 0.11602757556829602, 0.10870864876778796, 0.1695817831205204, 0.130580868863035, 0.10253498199745081, 0.18620690039824694, 0.20057890185853466, 0.08806054189335555, 0.1456967249396257, 0.10490078551811166, 0.21343184576835483, 0.20299879310186952, 0.1305426927865483, 0.08661532061523758, 0.1104168278106954, 0.13967026316095144, 0.12632344965822995, 0.0842867283790838, 0.13622500584460795, 0.20211826456943527, 0.0941932198475115, 0.0831967954582069, 0.14186357671860605, 0.09552298521157354, 0.07301615463802591, 0.14445505250478163, 0.134001353289932, 0.08568501623813063, 0.11973274042247795, 0.2293135240324773, 0.17480429116403684, 0.16071771970018744, 0.10200016069575213, 0.0931679576751776, 0.10018488974310458, 0.2132418708060868, 0.10514833629713394, 0.14131391246337444, 0.12672750453930348, 0.12115874749724753, 0.16008573642466217], [0.05241839506197721, 0.028605488478206098, 0.05198748556722421, 0.06309517644695006, 0.01797598375560483, 0.058312164546805434, 0.028142859591753222, 0.019238146887801122, 0.10286245465977117, 0.08033403501030989, 0.05941176394117065, 0.08681446110131219, 0.05185288595384918, 0.021906529582338408, 0.07173600926762447, 0.0747691148717422, 0.023551837584818713, 0.02000639033212792, 0.031513497669948265, 0.004417116397235077, 0.010162103826587554, 0.043169112468604, 0.038986657600617036, 0.031084686597750988, 0.004951761902702856, 0.035872528023901395, 0.02454305187711725, 0.018067991513817105, 0.0305564388690982, 0.047329607186838984, 0.029039236687822267, 0.06528241923660971, 0.05137522115546744, 0.037333527361624874, 0.027497545488586184, 0.0332650329801254, 0.032851434079930186, 0.01766844703524839, 0.007158928110584384, 0.02798025874653831, 0.042452045672689565, 0.033878236208693124, 0.023005464754533023, 0.08997323457151651, 0.05144951013789978, 0.0536334615026135, 0.03407834519748576, 0.0546326074982062, 0.04063814769324381, 0.028147336597612593, 0.06388646914274432, 0.04584541202348191, 0.04223356481816154, 0.05913630098802969, 0.026318042764614802, 0.041585076178307645, 0.026731847610790282, 0.01894196502689738, 0.07754894031677395, 0.048315053136320785, 0.035398314212216064, 0.015763376213726588, 0.06877963431179523, 0.04101518468814902, 0.016812314752314705, 0.0606467793113552, 0.028889658678963315, 0.01127106912463205, 0.035873526212526485, 0.16871514759259298, 0.058772871270775795, 0.07371732834144495, 0.04579105712764431, 0.04136702205869369, 0.027250959501543548, 0.05489814793691039, 0.025912169621733483, 0.036521332076517865, 0.03135988052235916, 0.049284754422842525, 0.032967854785965756, 0.03414418482861947, 0.03255018520576414, 0.04108175162400585, 0.02310187901457539, 0.05769192204752471, 0.011091776450484758, 0.02083104813209502, 0.06763543555280194, 0.020373250627017114, 0.02161504922696622, 0.024807059780869167, 0.016573020366195124, 0.01820650781155564, 0.029127541129128076, 0.05471889700856991, 0.055241884765564464, 0.07724796232650988, 0.0609914846427273, 0.05513678181159776, 0.020123961367062293, 0.061357771628536284, 0.07106872202712111, 0.009052267432707595, 0.09339162614196539, 0.031431078459718265, 0.05122899208799936, 0.05889232736080885, 0.042223586642649025, 0.006290978981269291, 0.025273842838942073, 0.0476184473518515, 0.01752621628838824, 0.10809912288095802, 0.02539224507927429, 0.026631676228134893, 0.013615213065349963, 0.03315535839647055, 0.021109628105477896, 0.07671727478737012, 0.05723087764636148, 0.060542247811099514, 0.0904843516764231, 0.03544394887285307, 0.023306465009227395, 0.045471900230040774, 0.0477952157962136, 0.021619826802634634, 0.04280288485460915, 0.009452512313146144, 0.015711860032752156, 0.04311600067012478, 0.03132070996798575, 0.03434722158999648, 0.042373782489448786, 0.03878168383380398, 0.04523325893387664, 0.0712314824340865, 0.02589207226264989, 0.048042261914815754, 0.07419801739160903, 0.03808986490184907, 0.02175561570766149, 0.05581824778346345, 0.03943128940591123, 0.014094011494307779, 0.010542226300458424, 0.047813446653890423, 0.009250377261196263, 0.12547462567454204, 0.021334068405849393, 0.06946839930606075, 0.03049023373023374, 0.051976368195028044, 0.006900815178596531, 0.03542533580912277, 0.04562205525871832, 0.09507522525382228, 0.0196827156105428, 0.031618225839338265, 0.07138238332117908, 0.05164562266145367, 0.012625365252461052, 0.010640367909218185, 0.0056603914072184125, 0.051438912269077264, 0.0240416197993909, 0.029694361983274575, 0.016327120865753386, 0.02498318255675258, 0.03482880492811091, 0.017753174324752763, 0.025494234723737463, 0.06719960932969116, 0.03125358642137144, 0.0310482545683044, 0.09388085731188767, 0.028511948185041547, 0.016964681381068658, 0.07215406847535633, 0.0268127584058675, 0.035490603986545466, 0.014989476676419144, 0.04811250248167198, 0.03037174614291871, 0.11127942605526187, 0.03959479567129165, 0.08557794659282081, 0.04656190736568533, 0.026251199378748424, 0.018297675087524112, 0.07894028909504414, 0.007819691873010015, 0.016752638657635543, 0.027122508581669535, 0.0030882817327437806, 0.054226890206336975, 0.024233823060058057, 0.021345313798519783, 0.0695470669597853, 0.01040243536408525, 0.013192656442697626, 0.015317832494474715, 0.034906029104604386, 0.0021811655278725084, 0.043008541397284716, 0.019311020223540254, 0.04911545569484588, 0.05960393194982316, 0.046731951952097006, 0.04070934191986453, 0.08924284993554465, 0.02518897454137914, 0.02322165237274021, 0.05018097937863786, 0.005181589731364511, 0.0037800220434291987, 0.038463625314761885, 0.025559682871971745, 0.03551273483026307, 0.04556357402179856, 0.04623660548531916, 0.005919428776905988, 0.006677644414594397, 0.019206169599783607, 0.025819321381277405, 0.026366874226368964, 0.0903048632608261, 0.07581974365166388, 0.01650663896725746, 0.021502508097910322, 0.07274084753589705, 0.03090968446485931, 0.08412267663516104, 0.03412395388295408, 0.02501219125406351, 0.03258884738897905, 0.013221364570199512, 0.13023976294789463, 0.02968748041894287, 0.021662452054442838, 0.025991892980528064, 0.028243721171747893, 0.04880487060290761, 0.0666277325944975, 0.04684131854446605, 0.014347904852911597, 0.008065736092248699, 0.031856933928793296, 0.07580313438666053, 0.05265878411591984, 0.057877325380104594, 0.009860370701062493, 0.02043025870079873, 0.049032516981242225, 0.06395022704964504, 0.030051878638914786, 0.07062875461997464, 0.04546932868834119, 0.009592842234269483, 0.028597361961146817, 0.041538669684086926, 0.005849273557032575, 0.008562948132748716, 0.028845050037489273, 0.006465466713052592, 0.04751200111059006, 0.02433784247841686, 0.03373983308847528, 0.02554890317696845, 0.01024790351948468, 0.027318498650856782, 0.04682544771640096, 0.061485198384616524, 0.022931585808692034, 0.03215371507394593, 0.027788632505689748, 0.04574238708300982, 0.024108208999678027, 0.01582812488777563, 0.15588133624987677, 0.04755534253490623, 0.0957439151534345, 0.02911154970206553, 0.0519842349604005, 0.00999919591777143, 0.027786129612650257, 0.019128910171275493, 0.03419722241233103, 0.014206069299689261, 0.02418336629489204, 0.0380082360788947, 0.03580090335162822, 0.04061108898895327, 0.044408272733562626, 0.05859335316927172, 0.08358721708646044, 0.009962238818843616, 0.04237938941514585, 0.036956412441213615, 0.021076175798953045, 0.027114554613945074, 0.03476270183455199, 0.03177351281919982, 0.03302856988739222, 0.014294864486146253, 0.04120795383641962, 0.05916625035752077, 0.03115558582067024, 0.04185483943729196, 0.03493203766993247, 0.06739075688528828, 0.04823396979190875, 0.029133244534023106, 0.09167235199129209, 0.03576527284167241, 0.030862120220263023, 0.07873869952163659, 0.042881608169409446, 0.061297961947275326, 0.052806007661274634, 0.14584668329916894, 0.03559091637725942, 0.033660668195807375, 0.046043866022955626, 0.03477506972558331, 0.03019070478330832, 0.03530520807544235, 0.01832560395996552, 0.09480666427407414, 0.005717631402148982, 0.014807722855039174, 0.05746692142565735, 0.027962519561697263, 0.04015530641481746, 0.02284989575855434, 0.0007181787418630847, 0.072775869484758, 0.021626174020639155, 0.01321619272857788, 0.009676801400928525, 0.05936729445238598, 0.024336870264960453, 0.038039528735680506, 0.04115224081033375, 0.014253121462388663, 0.014884862612234429, 0.037238313525449485, 0.0772585379309021, 0.08332428900757805, 0.036315823963377625, 0.0666340185853187, 0.10932906938251108, 0.15196206921245903, 0.08886507450370118, 0.18518258817493916, 0.09282883329433389, 0.18997310689883307, 0.12777480849763379, 0.11267161346040666, 0.19753087166463956, 0.20575704431394115, 0.09884572878945619, 0.17540866654599085, 0.19298008148325607, 0.1526683266274631, 0.1565713554737158, 0.23918518651043996, 0.06611887904000469, 0.1256785381701775, 0.10081175962113775, 0.07872806454543024, 0.10423798084957525, 0.16559895855607465, 0.14961784734623507, 0.12815150781534612, 0.08685643697390333, 0.1531194188282825, 0.15169201651588082, 0.08583428440033458, 0.14443345600739121, 0.14908642508089542, 0.08566434000385925, 0.13541949359932914, 0.1337530603632331, 0.19838545471429825, 0.15172392886597663, 0.14236661925679073, 0.1373933837749064, 0.1115721365204081, 0.11467398726381361, 0.13023532490478829, 0.18893597036367282, 0.11366605423972942, 0.08552376239094883, 0.10364043322624639, 0.1540369211579673, 0.127845891402103, 0.19985348219051957, 0.17094058130169287, 0.10075208352645859, 0.14071158540900797, 0.13756547297816724, 0.24747129500610754, 0.15714600041974336, 0.1271732384338975, 0.1301229340606369, 0.14737203426193446, 0.11898485594429076, 0.1850275238393806, 0.18737799458904192, 0.1498444250319153, 0.1336940744658932, 0.12249821273144335, 0.15264545363606885, 0.15945489605655894, 0.20903335913317278, 0.11968038932536729, 0.09182421024888754, 0.06850949255749583, 0.13404126599198207, 0.22817547025624663, 0.18262385594425723, 0.190696656354703, 0.16157550882780924, 0.11405447949073277, 0.21427789411973208, 0.1304912767955102, 0.11826072019175626, 0.1193006026733201, 0.18366372358286753, 0.16532179608475417, 0.135791695502121, 0.1508256926899776, 0.14818744675721973, 0.09516578953480348, 0.2002749775419943, 0.12015678876196034, 0.1089822786161676, 0.0994254054967314, 0.16617954068351537, 0.08244128170190379, 0.13047006621491164, 0.10923477209871635, 0.1374563475837931, 0.10386615002062172, 0.11548650538315997, 0.13685664773220196, 0.15051547496113926, 0.07607395149534568, 0.11689890146953985, 0.14873950072797015, 0.11072083376348019, 0.09814943099627271, 0.15594875294482335, 0.1121745006821584, 0.21955834905384108, 0.10918624306214042, 0.2690642449306324, 0.1678525938768871, 0.08350574411451817, 0.06588229720364325, 0.10745198494987562, 0.1471100264461711, 0.11730665966751985, 0.1554722644505091, 0.06637166196014732, 0.18504385108826682, 0.12168127883342095, 0.14860631490591913, 0.150021857698448, 0.15183487994363531, 0.17553300596773624, 0.14233601308660582, 0.17683356039924547, 0.12791188317351043, 0.13784536655293778, 0.13209731405368075, 0.16219156561419368, 0.11012720467988402, 0.11675829417072237, 0.19722849101526663, 0.09217001395882107, 0.23663633968681097, 0.09526937850750983, 0.14909130841260776, 0.09920515090925619, 0.15148519480135292, 0.1707375593832694, 0.19596752274082974, 0.18160810810513794, 0.24050150415860116, 0.09062765297130682, 0.19177134556230158, 0.14345864503411576, 0.22527016990352422, 0.14319979876745492, 0.26006799016613513, 0.17861554602859542, 0.21685399260604754, 0.15667994652176276, 0.2687994169536978, 0.11907028456334956, 0.14060476067243144, 0.10105202250997536, 0.1875933658448048, 0.07787934446241707, 0.13724593387451023, 0.19109168672002852, 0.13528878655051813, 0.1952103094663471, 0.1593089452944696, 0.14450412330916151, 0.15568481554510072, 0.10103843378601596, 0.18705717899138108, 0.10773225701996125, 0.15151640953263268, 0.1257980684749782, 0.1711293836706318, 0.10959955252474174, 0.08284077979624271, 0.0867185385141056, 0.11329781540553086, 0.11880271806148812, 0.21693689050152898, 0.14527744118822739, 0.11558881786186248], [0.08919069921830669, 0.0656882552721072, 0.03457715378317516, 0.015589546674164012, 0.016829354462970514, 0.038087415814516135, 0.019132019770040642, 0.02907987669459544, 0.01645832886424614, 0.019461878437141422, 0.03894032532116398, 0.036190705286571756, 0.03651286788226571, 0.03847820851660799, 0.025283646609750576, 0.015045015297801001, 0.08754615933867171, 0.04463023797143251, 0.062337651470443234, 0.03043590666493401, 0.04335622274084017, 0.032358102544094436, 0.024293803435284644, 0.12302656250540167, 0.07501306623453274, 0.009137019769696053, 0.030363653022504877, 0.008101979801722337, 0.020084937386855017, 0.10840814575203694, 0.04812984276213683, 0.02546948780945968, 0.06272729384363629, 0.07223738197353669, 0.041326905266032554, 0.059536823246162385, 0.03323972203361336, 0.04029731637274381, 0.021896362159168348, 0.04183397766610142, 0.046086509828455746, 0.04564179638691712, 0.042748511405079626, 0.056593120461911894, 0.052048723882762715, 0.012895622039650334, 0.029191529101808555, 0.010036110343207838, 0.018494533469493035, 0.002983821200359671, 0.01045018050717772, 0.014749493948329473, 0.0328794946835842, 0.06142840182292275, 0.055854104648460634, 0.03731597556907218, 0.013175512831367087, 0.015570902069157455, 0.017789326193451416, 0.04135584160394501, 0.01232907670782879, 0.021046300644229632, 0.05514736854820512, 0.032857204278116114, 0.049508667798363604, 0.012584426531248027, 0.012233469533384778, 0.06340963183902204, 0.0799792364705354, 0.06894881429616362, 0.04273946091416292, 0.01967270774912322, 0.06387809029547498, 0.015257075647241436, 0.0631064570916351, 0.06031432683812454, 0.049713430053088814, 0.03490326460450888, 0.025494945330137853, 0.019033809512620792, 0.03919156457413919, 0.04036191661725752, 0.0582080412277719, 0.040335228986805305, 0.04027571987535339, 0.02305748002982, 0.040054693454294465, 0.023272073885891587, 0.043222610183875076, 0.08446704057860188, 0.043982769784634, 0.019884544526576065, 0.08780892414506525, 0.05523601437744219, 0.038984546190476976, 0.06606165203265846, 0.029664720605069306, 0.0609525107574882, 0.06279744164203294, 0.036643318890128285, 0.05767492315499112, 0.07855310323066078, 0.05479767598444596, 0.007542479306721361, 0.0636504364956636, 0.03600607749831397, 0.008941089072322939, 0.011094466735812603, 0.03425620459893253, 0.068671592453029, 0.09740406982018612, 0.047302400053013116, 0.050501687364885584, 0.024351679821847938, 0.04834756662603468, 0.054749020782765, 0.04178478069661651, 0.024992001126520336, 0.0336449272435857, 0.026980556140188128, 0.02590879284980474, 0.0266773331532022, 0.012612420341611141, 0.04133172180445399, 0.018010977873927914, 0.04571415207465179, 0.042737390322145075, 0.062245090812211856, 0.01173838467366295, 0.004548416700345115, 0.055400537385139614, 0.04111835434741806, 0.05203561384405475, 0.0456226786627667, 0.036206642907927744, 0.05413811821199488, 0.03265807121351827, 0.04669790963816922, 0.007401075126836076, 0.01677277497947216, 0.030222131026675925, 0.10569425270659849, 0.02492129300662782, 0.03766874062421266, 0.032744672425906174, 0.02852691544831032, 0.045666164805879816, 0.03220586208044551, 0.04990583183825947, 0.05958425761491526, 0.032385194645030424, 0.01827903419325594, 0.012220004191476619, 0.05062752963567618, 0.0664255121955648, 0.0294591605415917, 0.053928980996715836, 0.021502450581465382, 0.024891974462661892, 0.02682244714378612, 0.08799532195553184, 0.022268376669671852, 0.03567575869965367, 0.024059811694314703, 0.031342944712378085, 0.08754066002438776, 0.060826846602139995, 0.07014370916294865, 0.014410013336600969, 0.054540510682272725, 0.030921198886062484, 0.009138976256508613, 0.07121456146705896, 0.055853715020930395, 0.04038646315166261, 0.07745733702904545, 0.032399265764979646, 0.03341203017043881, 0.1212864785338752, 0.00929364354306017, 0.033742857340257615, 0.009278667930630036, 0.06276434185565449, 0.02121450841514161, 0.020092184458917473, 0.0173951381657389, 0.0380657117057126, 0.03157503284455743, 0.015728873768239282, 0.007467873983841855, 0.03320997675473336, 0.022384665644494817, 0.023546100783278234, 0.035773699928540736, 0.08331429969985038, 0.03339613336720504, 0.023042169523250777, 0.05344724551832769, 0.0522172841738211, 0.037843902318854816, 0.031064062313816976, 0.05409460609371308, 0.012959560845047235, 0.019106536274193786, 0.0325998126209015, 0.07734438215265982, 0.05262693855911493, 0.005365816759876907, 0.023703206024947576, 0.0390847769449465, 0.0499902585579548, 0.06738111638696864, 0.062189351810957305, 0.024116088752634823, 0.05563346785493195, 0.04940706778143067, 0.058120705289184116, 0.04603336834406946, 0.01753043725329917, 0.01584382502187509, 0.046433983370661736, 0.05986076699628029, 0.027231903004576452, 0.012817061997338897, 0.011850063056044746, 0.04258843015122693, 0.02723547087953193, 0.11025475760106929, 0.07709828598308377, 0.03473502343695145, 0.016241404664469883, 0.04485342033149209, 0.09748791766469367, 0.033274302404606715, 0.03388064076716546, 0.08864715025993064, 0.08553252715501003, 0.015027342906250851, 0.04526193923084065, 0.1486362679861486, 0.07268969129654579, 0.062281790014822036, 0.037768195834360085, 0.010455137125973124, 0.018094393417413812, 0.04523846509982832, 0.042594964761519805, 0.07264108062372543, 0.026469563345017377, 0.06585861527128145, 0.03855288712657057, 0.06290776931564324, 0.04986022686352953, 0.10346569455577992, 0.07811656454578042, 0.05478820989083033, 0.03259484023146797, 0.06404678046237677, 0.041287923959316686, 0.09230712574208155, 0.031129978015087545, 0.02394492352323141, 0.06914730169228278, 0.00796770673332503, 0.07339433825109154, 0.06687913511996157, 0.0743438494100701, 0.04177498434728477, 0.06292100923019461, 0.034164649550803006, 0.007525577821070328, 0.047540714804199524, 0.03252419519412797, 0.050607473094714805, 0.03302548255305737, 0.03006961411301745, 0.03126961310044862, 0.02689264318178175, 0.012705058925348567, 0.0121510011558712, 0.02711776254727738, 0.04252726605045609, 0.01765124405210372, 0.08395177486818284, 0.011510799522511661, 0.04769804640091024, 0.04137656607781537, 0.05427175674412865, 0.024900412681745365, 0.028492372184700798, 0.011691095023707021, 0.07249499627505429, 0.02322772314073518, 0.0272992844475084, 0.017093540482164826, 0.0348956241941778, 0.0553602832951583, 0.1256830058991909, 0.005783760470876587, 0.025438169177505188, 0.04716247181931976, 0.017602972911845427, 0.08816154819214717, 0.03772940377530176, 0.024133924416673835, 0.02849361342668999, 0.05141521920450032, 0.03146016693790443, 0.02539464592700824, 0.03363460025866516, 0.0591482495656237, 0.017727826270856895, 0.028953123437531758, 0.01099466549931094, 0.08185327067621984, 0.02047560948994942, 0.01612515279703075, 0.07217815116746351, 0.025657870864961296, 0.02503532585251378, 0.0286829501419561, 0.07278003293322399, 0.04624495093594305, 0.010798899002111284, 0.07034940281300806, 0.01652890154218767, 0.009339019379694946, 0.014227495103114052, 0.025141991027339827, 0.04035226498672273, 0.03992860256403219, 0.012455414362193551, 0.0301936307005235, 0.013241669730632566, 0.008782162785792025, 0.01099313203667407, 0.12946126487804577, 0.029134320648154244, 0.037446129717864096, 0.05003305079299025, 0.05098586821986828, 0.02546240772062447, 0.02292272271006368, 0.07101135401171632, 0.03910899322363548, 0.0252170462772483, 0.039246557716978714, 0.03823633145657368, 0.03931112456484698, 0.07005044346442446, 0.025250177604903, 0.008728940592845902, 0.14924466580851004, 0.1405767520191148, 0.14248074672650546, 0.12968095543328673, 0.10674542325432412, 0.1291725249029696, 0.11978700626059435, 0.11350569839123636, 0.12080605665687472, 0.22208053793292493, 0.14223346312064677, 0.17237484105862677, 0.09133936517173424, 0.09485360511462204, 0.16695881058694795, 0.11162108858115971, 0.11374311885447241, 0.12868527526734397, 0.136520900123287, 0.09934873422025703, 0.11586374646867625, 0.12775000592228025, 0.20552484114887193, 0.2305745071498677, 0.13316044060047716, 0.10000036214478314, 0.11300375423161313, 0.10516881957300939, 0.18414657970424742, 0.24203016510000452, 0.23458246083464473, 0.1348406184115447, 0.12536132941022515, 0.10468044187291525, 0.07960100832860917, 0.18956468818942085, 0.1079894631402567, 0.10247840808006003, 0.10016895583248697, 0.10635283455485478, 0.17437727423384786, 0.24225629749707878, 0.18542374164098874, 0.11875611860887147, 0.13053573144134134, 0.16885027784155682, 0.11976097914157435, 0.10427790097310208, 0.06942977051949129, 0.19479429116472602, 0.1320842225686647, 0.1729273551609367, 0.16006215097149834, 0.14612544880947098, 0.21835982508491725, 0.10629291355144233, 0.14385348244104534, 0.10126376466359943, 0.07753879515803419, 0.20572945126332343, 0.2433051451225765, 0.11586781343794428, 0.12771214154781774, 0.21929743961663917, 0.21454377594636753, 0.21546915988437831, 0.09544428787194192, 0.13169670273782685, 0.1639325253199786, 0.14478478871751577, 0.16707301227143034, 0.1522477070102468, 0.08376557743758895, 0.12606366828549653, 0.13911521091358736, 0.2108278128434904, 0.1652462751371786, 0.17795467836549506, 0.12245349833392538, 0.11512335026054643, 0.09549596361466683, 0.08976693236036226, 0.18934723892016336, 0.14824248442891985, 0.16566576668992639, 0.12260298171895556, 0.1491850268212147, 0.08670372524647973, 0.14312399580376223, 0.2181729522999376, 0.1263720158021897, 0.17322722735116258, 0.15868896996835247, 0.2058019590913318, 0.12725006556138396, 0.154013350547757, 0.1454737244057469, 0.18937170010758564, 0.16046043194364756, 0.09346955906949006, 0.13971557869808748, 0.15568619593977928, 0.11335418152157217, 0.10718910139985383, 0.16177718003746122, 0.22190334275364876, 0.06196520465891808, 0.14757136028492823, 0.0629423237114679, 0.1925207514432259, 0.2716801076894626, 0.15779873414430767, 0.14892030274495482, 0.1463089374010451, 0.08140804144204594, 0.1821312034735456, 0.1733699275064282, 0.09698258931166492, 0.0744286175176967, 0.14312800340121612, 0.08158217155141756, 0.20156527549261227, 0.138040388119407, 0.10758888893178664, 0.212994527828414, 0.11873077426571399, 0.22495259006973356, 0.2202341190422885, 0.11380729978554882, 0.16060262743849307, 0.09570348294801079, 0.17708777566440403, 0.14173340401612222, 0.0725900950783398, 0.23824924923246726, 0.17069674126105383, 0.15104695659829304, 0.11053940092097037, 0.12817647366318852, 0.1080029628064949, 0.17536188155645505, 0.19185636600013822, 0.09011420552269556, 0.12359368949546479, 0.10133981253602542, 0.19472105603199452, 0.1371786804520525, 0.14033044804818928, 0.28862503124400973, 0.09668066879385151, 0.07785656052874401, 0.07690713100600988, 0.10217132221441716, 0.16830824286444113, 0.1432578792446293, 0.11718013091012836, 0.1449382203281857, 0.11453339480794966, 0.11953098015510477, 0.10289879763149656, 0.18744391214568168, 0.1468054490396753, 0.18874039960792288, 0.129393091192469, 0.21511325554456562, 0.16206878470256925, 0.09069316234672442, 0.2356425445759669, 0.09759301319718361, 0.12619997112778947, 0.0917609644238837, 0.1723808969836682, 0.13187318545533344, 0.20416785380803049, 0.12142701161792502, 0.22510005481308326], [0.061002093643764965, 0.010688726251828484, 0.052171296993037686, 0.09701608243631199, 0.033661217385088094, 0.020734370409627445, 0.029563437856268138, 0.053694588496000506, 0.04330286603362765, 0.025876286781567615, 0.02219612302724272, 0.0540072701551253, 0.052452177624218166, 0.01706563572952291, 0.018916091903520282, 0.040917840888141654, 0.02412874422589084, 0.0038885145249878406, 0.05204176624829415, 0.008559375619370257, 0.020947598713974003, 0.03265047533204779, 0.026386982717667706, 0.07136183325201273, 0.018804307765094563, 0.033078022897825576, 0.045049569962429814, 0.041899913776433095, 0.055094869021559134, 0.05138587839610409, 0.05482867178216111, 0.04590994547470473, 0.09917656338075176, 0.0424439822381828, 0.042878368694800884, 0.007677560852243914, 0.019977888150606304, 0.04581404886266682, 0.0391299477632856, 0.05146237526787445, 0.0692358028027229, 0.034975056260009296, 0.01802642011170974, 0.025422396684007253, 0.056270330751431175, 0.02256792602565838, 0.06676330813206732, 0.014575900040654233, 0.0480336418695515, 0.05429525313957129, 0.09133716841461137, 0.013015839758736547, 0.06075904027966317, 0.04313905177696142, 0.0311842995142797, 0.030307695087685715, 0.001059419055309263, 0.005091155790069024, 0.008058219063968863, 0.05651231171214022, 0.02303980949363904, 0.04950346163241193, 0.05028103943914175, 0.04409465967910364, 0.0171425686130533, 0.05338079732609913, 0.03708124168042559, 0.03126174633507617, 0.009861781709332718, 0.060881242316099815, 0.03416242681851145, 0.015234035672619939, 0.025954642733267974, 0.013461598700814648, 0.025201995522365905, 0.04256187239661813, 0.06071789932320826, 0.005870196555406437, 0.025704377549118362, 0.024351310603378806, 0.031500565746682696, 0.0805070593196433, 0.01127314713812666, 0.03801155347900931, 0.056107614873326384, 0.017939551726158243, 0.05529484071303159, 0.02689292890863726, 0.02449764171615243, 0.026607771651470102, 0.03674062558275182, 0.040618176499265246, 0.04511938008363359, 0.03894042551110033, 0.03391652731806971, 0.02904027383920038, 0.022667655830446165, 0.05057056980149355, 0.028946603670192417, 0.04786764569871593, 0.07349662104388699, 0.10315590727259405, 0.009011617221403867, 0.04549698111077305, 0.035123597117490135, 0.03046077417820925, 0.037089783800183795, 0.05520799088117201, 0.025981545586546417, 0.004672038558055647, 0.034294900178792886, 0.04319143255997915, 0.07119749207049608, 0.0161465210840106, 0.06117992707004305, 0.07608505402458832, 0.03134726401185617, 0.02456532558426261, 0.009610744691599393, 0.015701748270657845, 0.008615564547653776, 0.07562226557638496, 0.05866762359801214, 0.059053681397926994, 0.019140873591823038, 0.054260765537037514, 0.03032196658750763, 0.010669813545973739, 0.012740295169351157, 0.04431629095051903, 0.06614575962885283, 0.03745195557712577, 0.023015793594822753, 0.007944270637381123, 0.04688293447543401, 0.012555942903418327, 0.05196694291953463, 0.028247765876585618, 0.07513164659030735, 0.03062138977838913, 0.02051074832706945, 0.07771276941639371, 0.05067095269623678, 0.06739395554177463, 0.029443005842040293, 0.008648704224469839, 0.02245637195301242, 0.020897540853184182, 0.017834426507761236, 0.0439556146011455, 0.08411200455157086, 0.03889540683303494, 0.04650369330192916, 0.029439000099955592, 0.09144351075519808, 0.022864386191940866, 0.059287546973791905, 0.023520927134086378, 0.054312945940182544, 0.03591907552618068, 0.03224606050935108, 0.05911667860345915, 0.04136812414799351, 0.06315278937108815, 0.05187338036193978, 0.023792692336428445, 0.04785801262187306, 0.06397730059688911, 0.026315601098758634, 0.06994051655055955, 0.02976245217723772, 0.03863096848363057, 0.04606511000019964, 0.05629839877656195, 0.02174672106775688, 0.009558104156894842, 0.0387085340480553, 0.04359772130555939, 0.03273939204518683, 0.03941915158065967, 0.03275643175584264, 0.034594037642818876, 0.0377577909239335, 0.09686773453722708, 0.06797884954721667, 0.027587851873249747, 0.028826945344917476, 0.04568189091514796, 0.01416299412085209, 0.08839309826726094, 0.06133758150099311, 0.03340009643579833, 0.05620836513116956, 0.02541345194913447, 0.06025533723004628, 0.04147070379985962, 0.017816112158470787, 0.02090247427986469, 0.06008146687236149, 0.023392082875943743, 0.004178273329671356, 0.009389306378579931, 0.012915680435980903, 0.09527976857498288, 0.0441118663729867, 0.05313618174113799, 0.060869813241879456, 0.014825968555669533, 0.04791129882505629, 0.02555979048338486, 0.030776251878705807, 0.08302174508571625, 0.04785856552189216, 0.047450287820538506, 0.028714513682643883, 0.014215544670150848, 0.056210335533251055, 0.008732849855732638, 0.06670167276752181, 0.02099723911669571, 0.020453543584153522, 0.03609987754316535, 0.06743504825863056, 0.02711662706133211, 0.0770523321989458, 0.08120692684315145, 0.021440440432343166, 0.03823659862973727, 0.009019653753057355, 0.05504858498170506, 0.022033746681699995, 0.06913761666510254, 0.10029684272012673, 0.02317507332918467, 0.05706238043785561, 0.006812975043430924, 0.05058553520939313, 0.10909370466833934, 0.050381021574139595, 0.05896940681850538, 0.01695228009339189, 0.03190245355654042, 0.07825461143511347, 0.01278547248148243, 0.012804670914192684, 0.050505624458310194, 0.08556889239116572, 0.025825277116382495, 0.05184281872061547, 0.04001340777904261, 0.08562550341594033, 0.09896283969283104, 0.023501894756918773, 0.013670330517925322, 0.03253483017033432, 0.029454703944793437, 0.04569953176542185, 0.09267555011319928, 0.0198739355255384, 0.03810245914792176, 0.07896533657913096, 0.019741451033041812, 0.07140952366171405, 0.04236346292600501, 0.03747194161405787, 0.030291293624031823, 0.04562760281260125, 0.08444087987300009, 0.029330813522392418, 0.07203314293292351, 0.12019585541565903, 0.03551927686203271, 0.026709852209023666, 0.03407424483157229, 0.046730104004382156, 0.011023253955499968, 0.03620369287091307, 0.07215836551040411, 0.012253349814272951, 0.03921977731806692, 0.038510365775437094, 0.04029028823424596, 0.012991263538424391, 0.028878641496703494, 0.026398883055662736, 0.038284088659565896, 0.03363327923580073, 0.12439353173249401, 0.05869595137482975, 0.04890536853054073, 0.05132848069479223, 0.07098386486177333, 0.048466109874425456, 0.052437041522352956, 0.0633863135590218, 0.03953634040954057, 0.03345232136780396, 0.04658922953240108, 0.0804586564481724, 0.014061060137464665, 0.01019496612570947, 0.032359111864934675, 0.03666762793727685, 0.03838595213892404, 0.047475531973759644, 0.02127541090885643, 0.04010354161437135, 0.03137737665383611, 0.07741815905319527, 0.03742779867025092, 0.002499483566680283, 0.016937453838181682, 0.030939318421587814, 0.03141927831165958, 0.03622955671744421, 0.027824081189464778, 0.013074485195829766, 0.05226670749834739, 0.03724030619196128, 0.10686480512958951, 0.038897076665307395, 0.04356370867753867, 0.07029391985270195, 0.026079234485223424, 0.051110259591951035, 0.036535173130687326, 0.043296364819980226, 0.05008433319744654, 0.03417885796807241, 0.03045832138013793, 0.03817790588072967, 0.008011355221242411, 0.07575247538625263, 0.06348987284582108, 0.04017425344500225, 0.016582260104769375, 0.016004349708964583, 0.018558267256594263, 0.046795813759672455, 0.06630963325733319, 0.03330283798277378, 0.02586850165243959, 0.03977987616963219, 0.041412515711272135, 0.016601793431618717, 0.05288418920827098, 0.05124150469782762, 0.051332176590221934, 0.01950022706296295, 0.025953587028197944, 0.03357551046065055, 0.047508078860118985, 0.09713176841614768, 0.1709790839231573, 0.1083512749755755, 0.21839081717189401, 0.1812971185427159, 0.12671315140323713, 0.23387670808006078, 0.1878395362291485, 0.1506915272329934, 0.20914791704853997, 0.10755217488622293, 0.13650276203406975, 0.11432832456193864, 0.1527688282658346, 0.1365245514898561, 0.11391659587388858, 0.19997317576780915, 0.08062722044996917, 0.06848345801699907, 0.10774638009024784, 0.09906608727760613, 0.14406950678676367, 0.16419466672232375, 0.09438228938961402, 0.14926973555702716, 0.13482265843776986, 0.14446041081100702, 0.30886161723174155, 0.13679775089258328, 0.1480351877398789, 0.12681538966717198, 0.11526492235134356, 0.18231957539683208, 0.1245713428943418, 0.09052381908986717, 0.18172735639382154, 0.15972726425388828, 0.1792950415983796, 0.13474964594934136, 0.0842619406466838, 0.14980537322117016, 0.12558382528368384, 0.17437696253182366, 0.13990579114761204, 0.11629300468484871, 0.12418253172654659, 0.1354294383781962, 0.16030232480261475, 0.1459188645821996, 0.15188743884209543, 0.19077839649980888, 0.1598272760747932, 0.1931251268251799, 0.1097870635567233, 0.10785955761093646, 0.18017847934970632, 0.19364651525393128, 0.13658067269716412, 0.1065814308822155, 0.1065730000846088, 0.28285961248911917, 0.18754655116936192, 0.19484411895973608, 0.14846990816295147, 0.14533181092701852, 0.2747278707101941, 0.1946918450994417, 0.08426651227637194, 0.08626360940979794, 0.15821264474652708, 0.2063262418960221, 0.08395285098231398, 0.1069720825762488, 0.09426659598830156, 0.12139167796703987, 0.23782154952641577, 0.11589710600674152, 0.07571078152977861, 0.10710861548432149, 0.15438806090969592, 0.12463680031942204, 0.18223890394438058, 0.12987413647351786, 0.19889679446350783, 0.22736059210728854, 0.16857032489497215, 0.18841017357772216, 0.10422446634038351, 0.19483356561977416, 0.1892427445272915, 0.1202193666540552, 0.16574421169934794, 0.14419807645026594, 0.10286992066539824, 0.18741988140391186, 0.10283958166837692, 0.09258707868866622, 0.16979871288640425, 0.2697864139918238, 0.20934895001119003, 0.12455023621441796, 0.2471104182768613, 0.11673161396174692, 0.13441284449072555, 0.17675066250376403, 0.11053946771426126, 0.14833931985776871, 0.19910597620764747, 0.10349949196097441, 0.22633299959124997, 0.11006969565642066, 0.18575699563371018, 0.15401599259348586, 0.13140294584445655, 0.15366725740022957, 0.1551152320462279, 0.163709613843821, 0.16960716457106173, 0.13304649124620482, 0.13539069826947525, 0.14754827949218452, 0.24744759080931544, 0.19587775255786255, 0.21559330634772778, 0.07936027788673528, 0.19817354186670855, 0.15240680862916633, 0.08252346713561565, 0.06849202982266434, 0.18135212652850896, 0.08490703025017865, 0.09155736363027245, 0.12039760084007867, 0.18152865377487615, 0.0821533655107487, 0.08820800663670525, 0.17358522454742342, 0.08840863141813315, 0.1867389163817279, 0.19820656743831933, 0.09076527683646418, 0.1767113435198553, 0.09359150877571665, 0.2694103232352063, 0.12348328018561006, 0.11099160634330474, 0.1688226847909391, 0.16936394793447107, 0.11650791580905207, 0.18107423675246537, 0.1977651083143428, 0.1674340374302119, 0.17920256999786943, 0.10410774135380052, 0.13960547366878018, 0.09015403658850119, 0.1827836997108534, 0.14824808022240177, 0.14824983169091865, 0.10272957311826758, 0.10452988237375394, 0.12156838332884945, 0.13269609364215285, 0.18559491058113053, 0.08135806521750055, 0.1716824172763154, 0.0751385411422234, 0.19623312255134806, 0.1573952432954684, 0.12141990926465951, 0.09979262758861296, 0.11168026001541875, 0.1724598021246493, 0.088626355282031, 0.15845387242734432, 0.13617268443340436], [0.07924349352833815, 0.031663062691222876, 0.074148093117401, 0.07001072372077033, 0.07627131824847311, 0.056197815501946025, 0.05749568706960417, 0.03094673989835428, 0.031867305442574434, 0.021203776959737297, 0.02059914739220403, 0.01513474930106895, 0.030742615890630987, 0.011818298207799671, 0.024545985215809196, 0.011898400061909342, 0.08366903144633397, 0.03412509679037612, 0.03077209956245497, 0.014855333483865252, 0.012302006871323101, 0.007257439401655574, 0.0583759558503516, 0.0235365252228803, 0.04512605941272341, 0.020355246124381665, 0.021353477422962897, 0.04175421163381543, 0.025451169749430846, 0.011640642896963982, 0.06146957246528473, 0.02873777259082999, 0.06370139235514216, 0.03710160992341116, 0.034542580833658576, 0.050078199346899055, 0.0799223805370275, 0.03581096316338517, 0.009159142264252296, 0.09936305767041631, 0.04056673453305848, 0.014487883181573125, 0.0378160643595038, 0.02203858548455173, 0.03187900540069677, 0.035654225284815766, 0.04856317536905408, 0.02043260017671855, 0.022855331990285777, 0.027624480571830645, 0.05720766326703597, 0.020776914025191218, 0.05285573897708673, 0.012902164071419975, 0.05376456188969314, 0.012465278432500781, 0.03272158792242408, 0.030435797198151704, 0.0531005252560135, 0.031267709491658024, 0.02835542181855999, 0.023140583871281706, 0.0761759968008846, 0.08381471503525972, 0.05097347435366828, 0.043414874671725556, 0.025749043707037345, 0.02524500112485839, 0.018667830518097617, 0.03347686790220905, 0.04220905539114028, 0.024505482506356202, 0.04675093980040401, 0.03793822928855661, 0.045492053250200115, 0.0881600787397474, 0.037103943977854215, 0.05294831076753326, 0.04808869067346677, 0.029191594039730262, 0.04635323028196581, 0.0224707844608929, 0.020534096292976756, 0.047786710783839226, 0.030014133008080535, 0.026215485377178993, 0.020440017942746636, 0.01177025898869033, 0.022062759089749306, 0.04116975178476423, 0.04089320900675375, 0.01611072730156593, 0.04943710249790456, 0.026435522886458784, 0.0321814305789303, 0.021192026906646788, 0.025917999191733543, 0.050318569847149774, 0.015861849933571648, 0.00275480695108854, 0.034816240367945284, 0.02744504967267858, 0.03031789219676284, 0.05967299250187352, 0.036864801732008345, 0.01032656467941706, 0.019092338989139535, 0.017032317009579856, 0.038777371955802664, 0.06944209017092362, 0.06434625189285725, 0.026933717344945762, 0.06027488168911077, 0.06323936089756899, 0.009775669386726804, 0.06347048794850707, 0.039647785015404224, 0.012041153095196933, 0.07212416734546423, 0.05650965482345782, 0.04896128193649929, 0.048965590103762224, 0.020095540821785107, 0.04893437908322085, 0.03684993280330673, 0.09299125231336802, 0.048745751118985936, 0.03983070586400572, 0.045462319103535265, 0.11214630649192259, 0.03971349105995614, 0.06945685148821212, 0.02356029250222491, 0.017186297809530515, 0.0052688635150843766, 0.01941902683029184, 0.05186629656236619, 0.031183523969957605, 0.044603439018828794, 0.053904594024061225, 0.06390259601175785, 0.044329400989227, 0.06874744736705907, 0.029247448073874693, 0.0656522907956969, 0.04303302113839891, 0.020395570718392264, 0.04592540441080928, 0.04155886352236848, 0.04154048794589471, 0.04470507243240718, 0.022556775256816763, 0.07886735824286006, 0.021106130734551698, 0.025823187970672734, 0.027163250633748248, 0.03603596007451415, 0.04984861967386678, 0.026471537457837258, 0.02596247610199498, 0.0603754204348661, 0.03582452962291427, 0.09224113397067413, 0.028083266988687683, 0.036545336843119, 0.06252742605283856, 0.014113908473518677, 0.03678060136735439, 0.025358111852256116, 0.0534784045885317, 0.06275881285546347, 0.04175640468019992, 0.043867362110177055, 0.005715718052670127, 0.02045403340162011, 0.026383431541034952, 0.0363911890599411, 0.05679978261468932, 0.07799395432812162, 0.04623722888936754, 0.0286258938285755, 0.01920586531923618, 0.025918182873283513, 0.02875148376915604, 0.010430450511194067, 0.05099080350191798, 0.08769534586463124, 0.059178952215006575, 0.029962065782456193, 0.028255781071493402, 0.05164810885617044, 0.050928448254126124, 0.08522092161001638, 0.055069624868337996, 0.061992690098122694, 0.004710636731033446, 0.03286592080257833, 0.03685423725983128, 0.07731239558779635, 0.06861046174890362, 0.023794887238182127, 0.0244234176716418, 0.03608258921303786, 0.01759301514539402, 0.03801138649578206, 0.026466303461347707, 0.05559033794270363, 0.05776479352789465, 0.010160839392483467, 0.11997869558399543, 0.025676691730041057, 0.07980262016644701, 0.0343085965141654, 0.03420609478780534, 0.026953558663080912, 0.015482288708881242, 0.011773182122851722, 0.01732824839564273, 0.012909797060274286, 0.07124547933926806, 0.04388449087855406, 0.04751499567646533, 0.034737105161184445, 0.007370351604549796, 0.04968889836163726, 0.028787019655283075, 0.03834306342469063, 0.01726388007227797, 0.04309564355935436, 0.03511812748911325, 0.06913198376423679, 0.03482393272861373, 0.04228441677696537, 0.030906706597306766, 0.05427158605016302, 0.04164654455962591, 0.016841620308696292, 0.018632825267559383, 0.04444901293027215, 0.01661001271713758, 0.033862881173263304, 0.030320361693156883, 0.03308237559394911, 0.04313716672186274, 0.04001808702014387, 0.05073930078651756, 0.044709350913763046, 0.06791760009946302, 0.03490954688459169, 0.056750351868686266, 0.011578164267120883, 0.07398745525279082, 0.05535244621569291, 0.024609511201560963, 0.040039349551079795, 0.020094666942895856, 0.035453318487270735, 0.05123751194332726, 0.03021759464900242, 0.02928980058641173, 0.04028500785352662, 0.03275949311500881, 0.052203209343133494, 0.06019841450324748, 0.01251068024430424, 0.04634675133274868, 0.0936886559065897, 0.016679227264830843, 0.02547062700614333, 0.03903285258274991, 0.011160728463437408, 0.04024733272672165, 0.06619315317948349, 0.07735451246844605, 0.029437064949888736, 0.09619228367228061, 0.021804820098623168, 0.04045844034408219, 0.01798902143491432, 0.03069380298256874, 0.02881978918594541, 0.024121745773300063, 0.04410176203236915, 0.030266233152360655, 0.027048314223065972, 0.0522871759312693, 0.04097063356311992, 0.05050185805885121, 0.02858722051314544, 0.05566494604863692, 0.042010115284938365, 0.03569320288079325, 0.031106728383747395, 0.049997134556178935, 0.057778256086749025, 0.038088632936705835, 0.06595663071493618, 0.04216641158564016, 0.05615735732135363, 0.044345854403218254, 0.05203550623264164, 0.07098082205629908, 0.038124367347336374, 0.020173011762381066, 0.03272926915087737, 0.03977712280175183, 0.050444471489754505, 0.022232987357710954, 0.030208085881895386, 0.02955810366984224, 0.03755823112442158, 0.04605860507581383, 0.058981292313546874, 0.02572951780166477, 0.019724834346561693, 0.016545299295103177, 0.08640885513159446, 0.023580015076731797, 0.06831769933342002, 0.09279548859922215, 0.05536998687603045, 0.06018819141900167, 0.06032103585312143, 0.07260318656335585, 0.04615242738509551, 0.02279765783896437, 0.057533399303792976, 0.01614071377844084, 0.044773201589123346, 0.04232712737575639, 0.03145744325593114, 0.031483429556828924, 0.0626971255405806, 0.02186385423556203, 0.0019330653276483645, 0.0878257337899413, 0.11227056427742355, 0.03043718315893784, 0.015711572450527456, 0.038091627502581105, 0.03823934086540248, 0.04271501828043256, 0.03225359701900743, 0.006119085983300465, 0.029258385475259274, 0.044441725040087476, 0.03998456049885135, 0.037798134071636014, 0.07201783242635429, 0.04890967298706528, 0.01458798034946085, 0.06526271521579474, 0.16931024612858891, 0.22940995870158076, 0.19028552138479427, 0.1349198500975035, 0.21438614377984777, 0.22311022330541164, 0.11858794052386656, 0.11197569416253828, 0.17798000044422224, 0.08864024828653783, 0.17400036711478606, 0.08057595288846642, 0.2388195600360632, 0.12901723792310804, 0.12172521397587843, 0.08776541202678345, 0.22527520166477188, 0.14217780204489827, 0.1753138200729154, 0.1265309244627133, 0.13268741051433608, 0.13377156952628866, 0.24088195874355733, 0.12376133323414251, 0.12314990002778359, 0.08939431485487148, 0.07903005927801132, 0.11726883982191794, 0.1122435278375633, 0.0952876650262624, 0.1398217206588015, 0.20212069881381467, 0.29538694652728736, 0.2187524360488169, 0.08543353207642213, 0.15534758364083245, 0.13408800645265728, 0.0867139149340801, 0.11889182031154633, 0.19274786347523332, 0.07361595096881501, 0.10466470834217034, 0.09284706044127233, 0.17200143687659875, 0.15133281704038382, 0.15293380769435316, 0.08594756582169794, 0.17587890615686774, 0.15140394447371364, 0.12929809628985822, 0.2585144969634712, 0.09174052567686886, 0.17623095132876188, 0.08300356988911517, 0.2198622585274279, 0.11596033698879182, 0.11998760135611519, 0.12029905105009675, 0.13884370360756293, 0.16103314730571583, 0.1738509876304306, 0.11156395063153468, 0.11547878704732284, 0.14476212352747098, 0.13198986591305584, 0.13284851593198255, 0.2471877945936285, 0.13964191311970353, 0.07678113659494556, 0.21864616050152108, 0.12596270651556551, 0.15740419359644875, 0.0911080080550164, 0.17831644567195326, 0.1032479855348356, 0.1499187437002547, 0.11371422704542056, 0.10747962995083071, 0.1925109699368477, 0.08823934753309004, 0.11046686340705492, 0.09200117536238395, 0.12530169042292982, 0.14260685245972127, 0.15406350488774478, 0.13796271494356915, 0.14875447726808488, 0.1439659029711038, 0.1092660981521476, 0.11916452247533016, 0.21524491254240274, 0.13003837375435978, 0.10860027294256724, 0.14593534026062116, 0.20861784549197182, 0.07630736436112784, 0.12874359323177487, 0.11756060033803806, 0.09689686383353546, 0.12769124266924337, 0.14012105850270018, 0.11433233215939254, 0.08874004488461651, 0.12152985844295472, 0.09215534169925377, 0.10087785529321991, 0.1168351064552553, 0.12126451838412322, 0.10100393134052865, 0.12812268279958516, 0.21215935936197639, 0.17384601524099708, 0.08450387336779386, 0.17288416216615587, 0.11660476608085446, 0.16201705700950697, 0.1203118530975189, 0.2019911346724257, 0.1397764348075725, 0.14279555092798546, 0.13143778225639835, 0.1257546231499873, 0.1544995463336818, 0.1262496504932642, 0.12594054598594084, 0.25015016610268503, 0.07931027197628282, 0.17064158484572545, 0.1503638393478468, 0.19328109658090398, 0.14224756392650306, 0.1722919728490524, 0.09166670424747281, 0.13544165412895381, 0.06672499104752205, 0.14045544055989012, 0.09014332739752717, 0.1045955327572301, 0.090721141314134, 0.18295783724170178, 0.12197770003695041, 0.13203706650529057, 0.16126876435009763, 0.12701652653049678, 0.22737101186066866, 0.24486110225552693, 0.10415995886432938, 0.1827638695249334, 0.12145790722570382, 0.11042862053727731, 0.15288461814634502, 0.06967482026084326, 0.11958229966694489, 0.14029366720933467, 0.11940556461922824, 0.13124366611009464, 0.20837646938161924, 0.18544786144047976, 0.09595780953532085, 0.16849210252985358, 0.1928849084652029, 0.13528347277315333, 0.14292858832050115, 0.17361250589601696, 0.14222719939425588, 0.16460222454043105, 0.16868381411768496, 0.11031385482056066, 0.09541124745737761, 0.13010424678213894, 0.10551892773946747, 0.1424605306237936, 0.15026618755655363, 0.13655950664542615, 0.08467823354294524, 0.16571180953178555], [0.08055350292124785, 0.036642710329033434, 0.05741168337408453, 0.06513678017654456, 0.04588878313370515, 0.048995669349096715, 0.021761046373285353, 0.026159245426242705, 0.04679239988035988, 0.006099793854446034, 0.09132592487731017, 0.027910712087759748, 0.06869584583910182, 0.031087336064956617, 0.03405705669138115, 0.08583663700846955, 0.067359304666752, 0.05639754599542357, 0.05781380124972202, 0.04877957078861073, 0.04788777274370659, 0.015323626812460134, 0.06803969081374817, 0.04995897332264576, 0.050967006536666304, 0.027808069353341125, 0.010387565507699037, 0.036172893742332235, 0.03500461971270852, 0.06432064779801294, 0.007904420090198983, 0.006815030792495236, 0.015245346003212035, 0.057811823426163755, 0.08855155421770178, 0.008954608219937654, 0.01210467444252572, 0.018805916370183695, 0.012670329197135288, 0.043743067217292264, 0.054021716059651226, 0.04439049087523017, 0.018620271839608904, 0.01865944424935151, 0.01604764289368177, 0.011348889802320627, 0.02593036708276486, 0.018064330870402046, 0.03410825003811624, 0.03735571757715661, 0.10606650655972771, 0.014917786138539668, 0.0912318353948649, 0.08866244592354633, 0.08504101759172045, 0.018506482047087047, 0.05355133915145416, 0.035268456922494806, 0.02906478326622164, 0.04508069563598838, 0.017010985829983838, 0.03112811151368078, 0.05345784709788859, 0.06325331327388994, 0.06609989490243606, 0.021320702326192986, 0.050083123496733606, 0.030306630105769727, 0.08730798188480549, 0.028387091115291696, 0.04091872775461525, 0.013237039656814886, 0.02174566350731766, 0.030189537756086793, 0.058484806650085375, 0.024688813391549047, 0.00424303267209325, 0.030822417174931616, 0.040380522259511054, 0.07408448364003561, 0.026335394177294802, 0.018173133430536836, 0.035683681126101874, 0.021530865560634993, 0.03654521067801397, 0.09773852609214373, 0.045518562765209936, 0.03278063319157809, 0.044818954993388616, 0.054181927189347334, 0.027818188536912203, 0.05031052125559654, 0.03926652891095728, 0.02591450738691492, 0.0349291544262087, 0.009519460527371848, 0.030927982115827035, 0.029190219211159274, 0.021684516104869545, 0.040460199234075844, 0.14251709711970761, 0.011673713925119955, 0.014791757403145311, 0.06638083490543067, 0.062105281322146766, 0.00904753438589978, 0.032804749280330725, 0.003889994181918155, 0.029057736574031878, 0.06762658915249631, 0.021002894281991757, 0.01569823049067054, 0.030857667334203143, 0.049652425514068455, 0.052555492002284154, 0.04496791516430676, 0.03528268760419451, 0.025348634626425337, 0.02547754567785887, 0.06740985976648517, 0.11861316612339579, 0.04337779697380029, 0.028517842692963313, 0.025281661364715546, 0.07654434695723467, 0.02972328533360269, 0.09802201166166924, 0.040441367236780934, 0.029105204339430202, 0.014134144057607045, 0.0800892969709821, 0.03884124489559326, 0.030994725311757065, 0.026925483216473367, 0.06131373258540407, 0.03956011511036195, 0.03837241165456362, 0.09032193265738897, 0.11290893002296798, 0.056528742861701176, 0.07896207855083048, 0.015337774930230808, 0.011552311552804895, 0.06812599516706541, 0.04232634812069591, 0.02362034338148078, 0.021351583091018256, 0.06668604313745163, 0.019995976144855376, 0.11507669143611565, 0.033270502608502284, 0.038954938208917156, 0.020247491847840138, 0.05399878369644284, 0.03382955874258187, 0.009846486045717029, 0.05244703825155739, 0.020824263046961278, 0.04108033412194345, 0.03311014676000923, 0.0468116289266618, 0.017657836178841535, 0.006115161877460196, 0.03329940926050767, 0.02771754217974376, 0.04300174332456663, 0.028838808575528674, 0.020635996879718732, 0.047192313577397726, 0.06945770495804027, 0.02104081431753002, 0.04035240228404291, 0.022788297501392663, 0.06996089592576027, 0.03282720295828767, 0.018226141328341328, 0.04679195459175389, 0.009019832796184346, 0.037117313768249005, 0.03700985078467056, 0.05990914760332089, 0.004491267618504935, 0.011397301022952888, 0.012120579594920855, 0.054723654175177217, 0.018831772795238066, 0.04740195916383527, 0.03472806580248289, 0.024634913061163388, 0.05512640287633985, 0.10010110869188793, 0.020160866515652742, 0.04453495734196622, 0.05522670042410027, 0.08556392000173219, 0.06961326653254218, 0.016775663789303508, 0.09871545218629763, 0.07110459002433345, 0.0332723357132636, 0.04264719340426382, 0.0936912460019812, 0.02075830281683011, 0.02940517857496161, 0.047378781891893595, 0.021211506427789573, 0.017117641727963928, 0.008344689922523685, 0.05333856170182116, 0.03517430435749702, 0.026460666849743575, 0.04553338345431257, 0.0064182030382653465, 0.020003481113235466, 0.05735630060371477, 0.04532671759079676, 0.012290875583857996, 0.0703078722290229, 0.02448140538035659, 0.06420460558729246, 0.03597875162085984, 0.024675851782376412, 0.018671773177629802, 0.040346279565710574, 0.04524197174760047, 0.055514034029329196, 0.04499511116591748, 0.03587110681110062, 0.05216380872298032, 0.06721750251017511, 0.04824522817216348, 0.03982527705375105, 0.03762307627766859, 0.021366925138863735, 0.031845731209614314, 0.05376389395678416, 0.043241267776465975, 0.012929197728226427, 0.016237827512668446, 0.07745917013380677, 0.025553832892910577, 0.030271921714302152, 0.053395862923935056, 0.06590154851437546, 0.058378323301440105, 0.06010557925037574, 0.08958567763329484, 0.02704959628317738, 0.028006597567582503, 0.02145586968254065, 0.03998950320237782, 0.035848530678777024, 0.03805843494774308, 0.03907440543116536, 0.030218906395020895, 0.0360866970004281, 0.027838007590617053, 0.05371006598579697, 0.04836813524889294, 0.026853973577090073, 0.04980343030183576, 0.04542494825727772, 0.05045158868597355, 0.01564344700454967, 0.055862943627289496, 0.04418902375618927, 0.01512509767053416, 0.08515964989783242, 0.01620153278054204, 0.009066305156011367, 0.02835495241015451, 0.023297184452530928, 0.03561874691513367, 0.02672947088285582, 0.008837531640892848, 0.01585623002029024, 0.05943635129369795, 0.08537635701941326, 0.05207912596233655, 0.012482561196520692, 0.014788155203859787, 0.05958568995993119, 0.017594100536371116, 0.04558847678708844, 0.02696347190067172, 0.02650099700986175, 0.020527578381006606, 0.049247149800066836, 0.11542732652742416, 0.016240762706729583, 0.036715993701363914, 0.05182943037652876, 0.017274038218602072, 0.02897108712204499, 0.0609699289634591, 0.03756686972337775, 0.021238084591459483, 0.05137145104527008, 0.028089786756027024, 0.01584815174282994, 0.029084745183354244, 0.02477742025803309, 0.05856435374880675, 0.040759396069915965, 0.027573034894885495, 0.03283185251348186, 0.02631243027281016, 0.04573092832288239, 0.017344798288831953, 0.027688641093845945, 0.0031139271095526055, 0.028105197452532593, 0.006559221301358775, 0.02857385257811984, 0.05761371452535968, 0.03866363040287979, 0.02286841790919425, 0.04091287963092327, 0.019825660674541723, 0.009675613036961295, 0.028671192667388823, 0.04006928407761734, 0.02657544369867537, 0.03075195025303401, 0.055327116715488955, 0.046775397277087905, 0.021220104208623525, 0.03916314773960039, 0.048477698510396294, 0.0397837242053356, 0.010284140735166147, 0.02289638388901949, 0.0519964952400187, 0.01741401840263279, 0.05887126149900723, 0.029649113239429425, 0.024985815325635485, 0.02022765424044337, 0.029257804744702298, 0.051894809876102954, 0.009941802854882553, 0.0145197806887154, 0.02723737448832253, 0.09493993173236959, 0.03328630293253809, 0.06174121706862934, 0.027689524249581154, 0.03957301734772045, 0.04919642029562965, 0.02415913146251114, 0.02785634234896861, 0.047215286758728325, 0.2930290246149525, 0.10458474935148843, 0.16485654370626435, 0.1441066586994566, 0.14544711099006236, 0.22387215663911775, 0.1397587123210542, 0.09043190410011448, 0.2031301977694966, 0.06347635091515258, 0.18959223671117797, 0.12781044642906636, 0.10156060889130458, 0.1619424860109575, 0.20220148900989443, 0.1801716664340347, 0.13280309649417177, 0.13946120016044006, 0.13904535997426137, 0.1348234005854465, 0.1292854204075411, 0.13524452486308292, 0.15174012252828106, 0.054335106469807215, 0.136790641117841, 0.22475014702649787, 0.14725504210218787, 0.13757394830463454, 0.13323418039362878, 0.1281449175439775, 0.08503401913912967, 0.11382025768398307, 0.14380197739228606, 0.11163855873746797, 0.17814701335737482, 0.1269768364727497, 0.0604689718602458, 0.13452646730002016, 0.11470995916170068, 0.21759119757916778, 0.16901588067412376, 0.18369452271144837, 0.12432027433533221, 0.19025387620786205, 0.1631811007973738, 0.08524587261490524, 0.12005469150608405, 0.08728415894438513, 0.1266882597701624, 0.14828885381575674, 0.230811697547324, 0.1917889344622381, 0.227053209382575, 0.15375408867839724, 0.1708599246921949, 0.0911391485715285, 0.14028740348294377, 0.11215226593776606, 0.12948569637956098, 0.11612329035415314, 0.17975196707993746, 0.14431628573220223, 0.1716506978846155, 0.2122756390599534, 0.07963298005051911, 0.09258634396246634, 0.15052206523250788, 0.1689066068502143, 0.17998488270677626, 0.16124660382047296, 0.0946123774338048, 0.08855767693603411, 0.1645953522529453, 0.08405390180996619, 0.11954765621339902, 0.11284094929578714, 0.15168671758146957, 0.08243411255534738, 0.19249922916060314, 0.14424049761146307, 0.15710050676716492, 0.08783486962784082, 0.16254077578196302, 0.12854158063419163, 0.12004379677819088, 0.18639078974956647, 0.08766807193751447, 0.10442615239298902, 0.13816655322443694, 0.18105495575582609, 0.12409950766596012, 0.20295318070566282, 0.1422012984403409, 0.12472161295590922, 0.11563935811864212, 0.10953932724078186, 0.14733274496393278, 0.13036668504355475, 0.19835190963931382, 0.138942661578767, 0.2910514979157597, 0.1360555735300295, 0.1166901427495759, 0.18991406162967905, 0.10371699318056926, 0.14098251383984461, 0.23472949513234198, 0.2099837237619795, 0.1298732013674453, 0.11019781260984018, 0.17155493114842102, 0.11989435050054453, 0.1736589049687609, 0.11424481068388559, 0.21551220444962382, 0.14854064967948943, 0.06338477731333114, 0.13178826891817153, 0.07026240084087476, 0.15365803992608562, 0.2719546132721007, 0.18918971065431833, 0.1537110292701982, 0.0895488151581958, 0.12941302527906373, 0.10841115145012736, 0.196887489000801, 0.20173500466626137, 0.1444276375696063, 0.14954771439079195, 0.23384491447359324, 0.09528246257104911, 0.1099222902848851, 0.13274179509608075, 0.14335226558614522, 0.12405662637320347, 0.07612967936438508, 0.20178642065729946, 0.23920736188301817, 0.1168166269781068, 0.1467515542753972, 0.20205791312037036, 0.06506893303594552, 0.104347722226521, 0.09922145589371212, 0.11174863408086821, 0.15867195994360372, 0.13284792221384123, 0.15304737113183364, 0.1567366614472121, 0.11673234126647003, 0.1446560854674317, 0.17032589006703347, 0.14268221013480797, 0.1161895196128171, 0.06312288081971928, 0.1617633760906756, 0.1235287515737582, 0.14315800101030618, 0.12398204053170048, 0.12840820185374469, 0.09318428492406383, 0.12638207932468504, 0.13305835076607764, 0.08578418943216093, 0.11561607694602571, 0.13361184450332075, 0.1347971285576932, 0.11923735684831627, 0.21254581050015986, 0.17871376185212284, 0.09677694761194289, 0.15564632776658982, 0.1265385834267363, 0.11417515270295553, 0.22870052489452064], [0.03095631174801383, 0.052727881775354035, 0.026233000062347855, 0.07252885305206291, 0.02899276154494146, 0.0489732527785236, 0.009209727049892535, 0.11930818742257543, 0.012391042328090407, 0.025108149093284737, 0.06720085613778792, 0.06205209530889988, 0.029481437959475443, 0.018202223764092196, 0.05064836914243642, 0.028125944190833252, 0.011775402072089491, 0.030004600121174008, 0.05257325530692469, 0.0329872990550939, 0.03149213865981437, 0.03556202456820756, 0.03846467916446272, 0.05941568990238011, 0.025571742771717254, 0.009838080295594409, 0.05582023302849848, 0.03671030513942242, 0.035217953773099, 0.06945679953787476, 0.0043430347523099044, 0.034684924758039415, 0.05091535305837169, 0.037515097501454875, 0.07273221635841765, 0.05567392974626273, 0.011946173035539687, 0.009017204665724421, 0.03547616179275792, 0.025622926841606386, 0.040727012456045486, 0.025780364194361027, 0.019379277400730643, 0.0053091690915607614, 0.03936577260901686, 0.055645798638579436, 0.06424666309612803, 0.07844864594517276, 0.02452319757139776, 0.04030766191135626, 0.03205394074029755, 0.03604565994464792, 0.05109441473905463, 0.02702086032513762, 0.01218528559547849, 0.04018618717964273, 0.037476999350474216, 0.05803939187899232, 0.02546030744269956, 0.0336268225510139, 0.0355339083034778, 0.05621316311589908, 0.02911152372689685, 0.027317619205859955, 0.007223787179100327, 0.0845741992816329, 0.0500008601375157, 0.027370981479180045, 0.024907656043069437, 0.040203809476224706, 0.04269380027835723, 0.04082501676748507, 0.039313785164267756, 0.01561003922688542, 0.028907449814141728, 0.009265815788239706, 0.04588076422805898, 0.02517598695703782, 0.07250384267535992, 0.06399344230885617, 0.026294349700037856, 0.028611427514988463, 0.035839487609337084, 0.080102997017093, 0.02999970380187733, 0.02940578528068727, 0.01728833383822348, 0.06121802893176209, 0.03720584456459619, 0.02370735277509084, 0.07248119974974543, 0.06967988912947476, 0.10001045535318553, 0.057150154243572615, 0.02927280540461652, 0.0517717246839311, 0.048371215161751024, 0.06728785810992122, 0.03451151824265253, 0.019541820729500614, 0.012066923245583894, 0.0158642507813056, 0.04789440012245905, 0.027784598933067173, 0.07322405988816172, 0.037868322688154876, 0.010219756641163258, 0.04276843064872082, 0.04803409457963426, 0.04598835337674245, 0.08096216653939337, 0.08677635923959315, 0.020385702009662054, 0.03451664648309816, 0.008617684306955198, 0.032127851227414794, 0.11493650716147386, 0.04347676978795789, 0.08032439451199025, 0.012994447351957206, 0.06742915560607798, 0.03437766819843091, 0.015686999940953683, 0.052178043115418404, 0.02964808722026646, 0.053383995982585475, 0.0493129337701248, 0.028752578436979093, 0.030734619249415118, 0.029085414971632417, 0.03038143302546814, 0.037589954226859845, 0.05325440957676619, 0.03175794627168216, 0.0296228041042923, 0.01780581114871893, 0.027455512099550106, 0.040838431086740457, 0.036865350921289064, 0.03542029291565996, 0.08074876939645037, 0.026529556707828306, 0.05123507398820948, 0.009271672261093045, 0.01288375138756237, 0.035325272037880495, 0.039541943624499254, 0.013942928781034425, 0.06716660602251068, 0.03892859567713458, 0.016947881013038568, 0.05666092678438872, 0.033346520795021206, 0.053596009020111524, 0.03157635757816024, 0.01733213724946836, 0.05285597646434326, 0.007303972524823621, 0.03179461207764689, 0.022564547398360446, 0.0179244230457698, 0.02666358672286151, 0.029358911233430263, 0.027263982337899506, 0.032353946517105214, 0.012756912783515872, 0.03988402917457279, 0.04581084649544209, 0.01897227433801163, 0.029920895140094217, 0.025548908743076026, 0.02198266094637802, 0.045545209577539936, 0.012581581322592683, 0.05971515391138382, 0.07702439033892006, 0.0617891189904185, 0.03792962037550751, 0.01280724338357686, 0.03041725834918907, 0.008932962555263657, 0.03236335323890671, 0.045284801090019755, 0.025251958759326953, 0.048581461887806654, 0.09571787319146097, 0.027595403225859627, 0.005216509171077632, 0.0246998231523321, 0.011750913054129342, 0.08073862423771061, 0.06946209847228602, 0.0293552951188758, 0.037160165375098586, 0.017117202005465515, 0.05271307221846655, 0.02922342475358164, 0.023637138183403295, 0.01455442599763046, 0.04119582343264483, 0.049364936057827435, 0.003912753763870569, 0.035068719007540494, 0.04695262585300952, 0.03152257784677204, 0.015829945004952606, 0.024747610041231383, 0.008029269738472067, 0.02255662126117386, 0.05739281798014417, 0.03279635559010785, 0.020008633473480586, 0.03879289026372135, 0.07061501004500315, 0.053912857838440686, 0.022509151640406344, 0.042820714952540584, 0.045209599265945144, 0.056676871827221476, 0.0180225999065442, 0.04585907867294736, 0.021791344552184455, 0.05414996288891416, 0.026682639509090222, 0.04235793763655238, 0.057763487347983755, 0.01877100017736666, 0.027129792761115823, 0.03846341751341242, 0.06342143198708072, 0.03174668046995066, 0.028422150171536487, 0.03605944162700325, 0.026011507943621837, 0.07890045060776174, 0.02236008942418266, 0.036888613540213555, 0.024444815644528717, 0.06588951087906025, 0.07214942263090052, 0.04911583790089935, 0.047929607608239166, 0.004392733599161147, 0.034029452508548275, 0.03509483147354331, 0.005580803954217117, 0.04806608485523611, 0.07358389018918388, 0.010651781212800415, 0.008925809179345379, 0.051175739281461574, 0.014404076155187795, 0.016208701927098446, 0.014968922896514414, 0.015774894345668145, 0.07815359771484509, 0.050153894699178636, 0.02006724644161295, 0.042717916367109865, 0.04577480780426413, 0.04064106062287465, 0.008055138223426184, 0.040733528512646444, 0.04190083403955214, 0.041313205219921656, 0.01453093980671838, 0.013361557194002671, 0.05809863381728064, 0.03074413543799892, 0.03583453377359547, 0.002157952540073893, 0.03876117458275985, 0.025366464724356774, 0.05197307305934373, 0.024551709029765334, 0.00783729468821548, 0.019045912085857708, 0.003953012028432568, 0.06140640085504856, 0.027764039587054867, 0.059007274903706275, 0.014560027357219951, 0.015210979927360313, 0.05854250121046789, 0.020748873830598313, 0.044301180823822506, 0.025015820356202312, 0.010771274410217302, 0.08995425043394789, 0.06498682181700133, 0.034494942374294624, 0.05005318897019606, 0.06457874449552037, 0.053578887673211284, 0.04429963715665508, 0.048797553026815876, 0.019347648922121152, 0.032748427693150006, 0.024617307462904137, 0.011681423911795719, 0.02918946778663667, 0.056049883205560036, 0.06028927193256095, 0.023109074136300478, 0.0023970219626789913, 0.028789832394977566, 0.0050393891342537245, 0.03889240855642129, 0.024302148885908537, 0.06672340285149403, 0.055619344784645364, 0.07830745234969072, 0.018816655247064773, 0.04197816211672034, 0.02306260084878886, 0.058582569763530046, 0.06842864298960194, 0.046504168276442215, 0.03447325681918301, 0.023410170870192815, 0.019521506292221602, 0.015954911541484762, 0.017847484596131835, 0.04961389691743534, 0.025209073755831923, 0.024138227017829195, 0.019698066935234237, 0.014764274746994488, 0.05246340631856583, 0.025474371141172014, 0.03545855804986786, 0.02420837296085665, 0.023532949926448055, 0.04333890101406723, 0.06230506376596168, 0.03266346662712749, 0.03543262369930744, 0.012696509384113597, 0.03709030701429583, 0.008698731471667998, 0.029451568370859604, 0.08092463613138534, 0.027559088084672112, 0.06822715731686912, 0.04095995034731459, 0.025765361679077614, 0.003576974149837042, 0.03639086993644014, 0.0874597139772959, 0.08557863679016009, 0.09937725495547056, 0.015205392483039759, 0.1117614732356742, 0.1392903132364154, 0.18297098809853196, 0.15251047181664035, 0.12217943061841652, 0.17467192170443013, 0.0765045010484755, 0.13111048028804362, 0.10731730741099454, 0.25895025639329106, 0.14259683346608654, 0.17978766438318416, 0.211392795026768, 0.12935859616845846, 0.1659836433827877, 0.17870859650429338, 0.11073365807533264, 0.08881995192496106, 0.1626655604923144, 0.20668560464400798, 0.16435258090496063, 0.10705097287427634, 0.15873487922362983, 0.12778712814906612, 0.19184907810995355, 0.03430906406720169, 0.09581772173987702, 0.24670593295013532, 0.17371676280163229, 0.10544591525103897, 0.14377209852682427, 0.08550029568141326, 0.10960525221889839, 0.1606017368612811, 0.10709622903959826, 0.1493590307654813, 0.13540554122300819, 0.1475362418568693, 0.08639155566925183, 0.11088958330219612, 0.19797096523689106, 0.11648278668872081, 0.06423882601666264, 0.13484421040629968, 0.08763657519011758, 0.15748338075354695, 0.14275796856964007, 0.12196909112390131, 0.08777681883657351, 0.1363720401423052, 0.11087564576882869, 0.09129153375397436, 0.1189487727242522, 0.19766056939261034, 0.10970180563163012, 0.08792254695435986, 0.09808300877921283, 0.21030624629929662, 0.10873156628804281, 0.10615037666866556, 0.14354344282764941, 0.14995847828686237, 0.19477978959912434, 0.11408473685150966, 0.0945715222042054, 0.18674344348255545, 0.178009181690868, 0.13945701444754377, 0.11506126218591817, 0.15192497667158023, 0.11125880177132785, 0.1373347986373119, 0.10134337484487332, 0.07570085159386508, 0.15065735875396058, 0.06321121123619378, 0.1456969921127893, 0.10681639483664185, 0.23110876441933215, 0.2440833018044941, 0.10649425821611658, 0.1064935234899167, 0.15643683378584683, 0.2522739552659914, 0.10052978061139584, 0.10681269894121215, 0.11617236858000979, 0.15733506996184587, 0.1856776452041231, 0.1553756813518703, 0.13311518443515524, 0.1941806240938604, 0.17435153655242175, 0.17074732604669407, 0.15804592869244516, 0.15265159861883149, 0.22870966815389693, 0.19003822293598205, 0.1431112753925845, 0.08572192324209027, 0.10640196473104879, 0.09203184832585976, 0.14837013382930309, 0.1444649527547881, 0.19397310476051643, 0.09422986709978431, 0.11830496703623794, 0.17333041556412354, 0.09482459456194192, 0.19755258690565825, 0.17381408804794773, 0.2037370519246906, 0.1856288712588139, 0.09886716943583451, 0.13306584645761177, 0.12856397865107283, 0.23371273797238246, 0.16388213349273428, 0.12328268509008922, 0.1201507773657795, 0.19407626328757033, 0.10445892563438974, 0.0835774207371287, 0.11949060732149519, 0.062370758678298444, 0.1486028268118389, 0.15758956724312156, 0.1399405236588791, 0.20173965051071718, 0.08958135091233999, 0.15213316393783316, 0.10377750790212303, 0.09440333669772372, 0.11509387957630679, 0.18619875161675736, 0.13346973806619644, 0.14969048876082525, 0.1799336151452735, 0.1549437959329225, 0.15818108862731606, 0.1678343370440416, 0.10133469171705656, 0.1673153234878555, 0.13184136216295883, 0.11150295351399109, 0.12806777871446684, 0.148103509854991, 0.2067676861770451, 0.13097296032356098, 0.17017193895298988, 0.08779771771514788, 0.1020060310838744, 0.08972791765700094, 0.13197049585869536, 0.10240753297694027, 0.07313161055208184, 0.12123543361667544, 0.1281451401882805, 0.12457552860723808, 0.11685175282764249, 0.12139597500208765, 0.06926462039700709, 0.1378895837115124, 0.14543369296006858, 0.20115955820074305, 0.13883344712667167, 0.09262351813958958, 0.14882750459946692, 0.14075286366278306, 0.10732944894698448, 0.11621520534390584, 0.1223659620154649, 0.19239814864704385, 0.16929332516156137, 0.13012257782975212, 0.10738407843746245], [0.012288897760299733, 0.020481991959968582, 0.02082681417959975, 0.055363036663038656, 0.0680953889968805, 0.011246437243244145, 0.02820382702338975, 0.06013917627569754, 0.011344047288730508, 0.06437274656491354, 0.03427129988267552, 0.04071900468261447, 0.03028776842256775, 0.08133663941407576, 0.014699508446938125, 0.010034744791482808, 0.04325104928284418, 0.04160982309258543, 0.04301212225982454, 0.049440950533607975, 0.016770264664955903, 0.07518833182984963, 0.04300073400372639, 0.05133542719704565, 0.04413007125549484, 0.09014209543238394, 0.03782296633289661, 0.0197548876167275, 0.028702550262096338, 0.03292878442152869, 0.02303042132552946, 0.014007374102220638, 0.0651713642582763, 0.04139880453294609, 0.005665767339451122, 0.03619989307480864, 0.054048982565291226, 0.029696885285375174, 0.04434119371580891, 0.03356712419190444, 0.04228557081660256, 0.06348620663629845, 0.02892108677770011, 0.07272334769368172, 0.0778930148226209, 0.04460187308723107, 0.035445481407805346, 0.011075389829784399, 0.05754758916737046, 0.06524106676806696, 0.04770858860865701, 0.0070975886774249375, 0.01489944952481892, 0.04928191570797935, 0.02470599596563261, 0.07712737075053155, 0.006204933915796573, 0.04542268841760233, 0.024192977107304614, 0.005910001182201086, 0.07136238244129345, 0.016320237446052488, 0.036568209834513254, 0.03633442218415439, 0.024732255005801562, 0.0875320214254316, 0.03929182872525416, 0.07584021950606257, 0.04035482168546878, 0.009085561105166562, 0.03483280510408804, 0.01978313932340825, 0.06815288317739032, 0.037324818258639425, 0.012592431521625258, 0.019932522518502083, 0.029041598572803196, 0.031620786248822697, 0.15714540670160204, 0.025902464185492136, 0.007557208155049011, 0.04727275496406946, 0.026959601600538008, 0.04194289525912609, 0.025238967464247253, 0.03910431398253422, 0.028331441171758343, 0.03507665256620385, 0.09603605416486971, 0.06018517087795772, 0.04587732066283934, 0.04112020229513291, 0.09546732413582504, 0.049377582254237495, 0.0403192282828968, 0.0552826212515356, 0.04441183504241053, 0.05086984456283972, 0.03975316998548806, 0.11449736353824846, 0.02437135044601746, 0.09256974954041652, 0.0649148112279363, 0.027855600201291963, 0.05146784118551295, 0.030705981625942513, 0.013352290552575141, 0.04531530707026832, 0.09412291619810276, 0.028188950673211366, 0.020435865626495797, 0.03789357426285278, 0.03765809451579116, 0.037531105626840144, 0.05815203505335376, 0.0379392274771817, 0.10034105987870134, 0.05638477363390848, 0.05015307091525756, 0.06030677177477628, 0.01591837190062506, 0.012214804519317113, 0.03923446070984937, 0.04443442972842604, 0.03609494597185403, 0.024513327007298358, 0.027033617843699176, 0.015363322436314775, 0.015925160696497187, 0.03316622714919504, 0.03342263174999971, 0.04737659255624749, 0.031952904755598865, 0.02455331206874689, 0.016094951097329613, 0.049294428317807615, 0.024003998478292488, 0.03552905094693415, 0.09050691296579316, 0.025859592169581447, 0.08295063249533996, 0.04389633555547334, 0.027217228889639955, 0.02189113001804799, 0.07632019609445706, 0.018636266977409832, 0.0811556370172184, 0.045557866906165145, 0.0500176363857463, 0.03618309827288613, 0.0691901236132253, 0.05601781129371375, 0.018206689637736417, 0.045221981999929994, 0.026759923057397828, 0.04885954091150779, 0.05635297260596417, 0.03999213411589153, 0.03689946002850775, 0.03978208405897021, 0.0836779223755002, 0.031785828759893775, 0.01115891112931422, 0.0310108521807706, 0.019168136386724655, 0.01023631952193682, 0.0070697405135433655, 0.029475532319338527, 0.024148776647052728, 0.007136483245631098, 0.002099444632222003, 0.03307590035547037, 0.047765986309968866, 0.041515703924233094, 0.03858419462630991, 0.06950705777853727, 0.04872428820817731, 0.039454477810068056, 0.04644522319722455, 0.013734801814280218, 0.06957515724934638, 0.034635820557014085, 0.008981761548056966, 0.032865776083781384, 0.007120181971913553, 0.02399594432063168, 0.010067765724670608, 0.039780607185093686, 0.0256896069549839, 0.08267219353001565, 0.03418365595280193, 0.03963918723457027, 0.031787906773388386, 0.04120487763429992, 0.09627248015021905, 0.05811569208162837, 0.01242390091647394, 0.02597308139229426, 0.03603630146244541, 0.02696605271921726, 0.031209513981593773, 0.07116007298463956, 0.02473416789143812, 0.05575783325184602, 0.06844034665846266, 0.044412495553842746, 0.00933725677896291, 0.031232320179697126, 0.02787915782391792, 0.039677886525169015, 0.06118294390034862, 0.04083104671735782, 0.00929192176045035, 0.05907362290599849, 0.036316536425147206, 0.03930628205125686, 0.0475800931599224, 0.06108478002715856, 0.05319834403053392, 0.033399261519662105, 0.09948749357135966, 0.043830443974002264, 0.0476469977729721, 0.025938013059203513, 0.04606926602718886, 0.0931282082456164, 0.027057197730755433, 0.03036081059690332, 0.03883891455188859, 0.022644725322606973, 0.021723775716964155, 0.03142750501865521, 0.05314490197633859, 0.016394962440244853, 0.010112951385963243, 0.03904268603946548, 0.06868576005217619, 0.07667692421819083, 0.025136927724815905, 0.013205369432398584, 0.0303222615912091, 0.09320121331256814, 0.053427949678734876, 0.021669862398994155, 0.008124269279505825, 0.07308304440812208, 0.0782027278910391, 0.047533738616039045, 0.05280123194097541, 0.006259626024984755, 0.03571678091248032, 0.051920562400482595, 0.08469627515296452, 0.10054900965769775, 0.0908960506785661, 0.012631036188395228, 0.07784039655234665, 0.040508375750505365, 0.0397143630834762, 0.03600774361984804, 0.08776207236223854, 0.020423317764652893, 0.06211796462594066, 0.02705764301936142, 0.056770501178107224, 0.05356563662644476, 0.05757203922257759, 0.04282145710021723, 0.04034570440126117, 0.007727584852545988, 0.03661156239104457, 0.024082465752144344, 0.06995592353632674, 0.10503840938326903, 0.03610194442444481, 0.036371666865306906, 0.027666538080666214, 0.05474671270349063, 0.039250105182873085, 0.04522775219811592, 0.016976184670056682, 0.05198298815230373, 0.01781851300620474, 0.051118979827151634, 0.034872105534304865, 0.016302021431329194, 0.06836857355665416, 0.07153585946070962, 0.05592384797637351, 0.028929229993082117, 0.07402418414130807, 0.02341924177017063, 0.028049888896930497, 0.03644715070549864, 0.04893345510936342, 0.054736608362873085, 0.06235404551262036, 0.05276793919620104, 0.034561475913506, 0.023251002457982395, 0.01652836534049129, 0.03470214258413762, 0.02845364320819499, 0.0755723487236537, 0.042410548485349864, 0.02886144593503559, 0.0290693289207411, 0.03249867273552809, 0.0222086096619023, 0.018316328969376627, 0.08819100403343327, 0.061763611374772154, 0.030636173360107932, 0.039445412476197816, 0.052985789225203916, 0.03320335679745767, 0.031826761914999224, 0.03530243244313169, 0.01663053124502767, 0.016901582130230963, 0.04416894866153598, 0.06340775420540012, 0.015133015458559385, 0.03445607238973025, 0.04857615924265701, 0.021736869057349395, 0.012434289128577802, 0.07722781301708892, 0.08692164949025027, 0.0680456799454987, 0.012550669944175752, 0.03315428228233941, 0.03314610381494276, 0.018513343202357646, 0.040999963239300996, 0.04895633181149606, 0.08857391512719914, 0.02376499538513599, 0.03591216984204948, 0.06792466534534469, 0.06405243562767282, 0.006165588029034552, 0.06780319803510793, 0.11282193547231145, 0.021505831064132508, 0.03372717204911169, 0.05247769266134128, 0.013891585149394814, 0.022231098591873888, 0.025299678854935337, 0.04391185757413041, 0.067103991023032, 0.11724409661837853, 0.17581954918568954, 0.13988150807563215, 0.12864971155067906, 0.22252695460338145, 0.10982473497278988, 0.06995072108111344, 0.18454575125360861, 0.09053956004208885, 0.10508288629353046, 0.1071441792009864, 0.09774836697033606, 0.09488805560977198, 0.18277089024195448, 0.10826157900737599, 0.1800321723567322, 0.11510281503433362, 0.1588590256869793, 0.16094535123556852, 0.1497248947271146, 0.061508093640441075, 0.12991351482924074, 0.1485282854991965, 0.10481293749762699, 0.17397486692061648, 0.17824381910031661, 0.11501084067276679, 0.16025310556869954, 0.23261622962309048, 0.16117445222334936, 0.13817551836837083, 0.14620895526604727, 0.13144800905138254, 0.12188940672785975, 0.18397544045001268, 0.18556164752226323, 0.13662629993632436, 0.05889817919523921, 0.2210257382830605, 0.13133276836015284, 0.15107333252672106, 0.12633372098207474, 0.14352390950080007, 0.2714511106023565, 0.21058795071439818, 0.1125265755399596, 0.13578342797700316, 0.09424560063052922, 0.16593543346971273, 0.22953821666305885, 0.0951822058414109, 0.13880423619411886, 0.07309636595891789, 0.13421057956293225, 0.0812036391289439, 0.314316016738303, 0.2319086214993149, 0.11444729083450511, 0.09316094437963329, 0.1703255932079628, 0.20370119134895504, 0.20722240005852655, 0.10547353056608699, 0.10536057568970136, 0.1600956218317151, 0.10771118002594449, 0.17055974079994485, 0.13842151063727215, 0.08298245578771457, 0.14252287102863193, 0.1653786891256459, 0.11371190412319265, 0.15834437595913187, 0.13794558617519215, 0.21694944764021784, 0.1042929888353683, 0.08709561632713303, 0.13216443388955668, 0.27698284189682454, 0.12494718132074922, 0.15714494657004252, 0.13212976075010374, 0.12020377413136885, 0.15957263036398217, 0.13947864063084126, 0.10274616011884063, 0.1565581897739321, 0.11113121174275875, 0.20208666392136365, 0.10415281940368004, 0.1472455871407874, 0.23534170759376138, 0.1391241909004748, 0.1003228995250538, 0.1218021524255164, 0.1304912767955102, 0.1670071986154653, 0.20908453763695434, 0.13507469178875908, 0.15827183844521642, 0.11795784972491674, 0.18776140292175114, 0.19092191301751882, 0.17770598467905074, 0.1065655192360282, 0.14120319887297228, 0.05657257039274555, 0.1740346840233542, 0.13047790329437703, 0.09692211911897175, 0.15368310967460275, 0.1911664952058345, 0.13843215303495526, 0.12542709853732958, 0.12418944854289293, 0.12081233522621915, 0.19871964381309226, 0.1721184141933918, 0.10457758020493202, 0.19048530753934756, 0.15954900038195774, 0.24943503260146827, 0.13548858754802495, 0.12756543379509822, 0.1437159624765627, 0.19442590390099213, 0.09582892816979438, 0.1782207828364335, 0.0893577047099825, 0.12648970558075234, 0.10842375311767682, 0.09551630588248372, 0.1349079015199095, 0.10126682973350398, 0.11376491573173553, 0.12494847265770659, 0.21950746740913019, 0.06945492932572961, 0.2563362935325131, 0.09134551015449688, 0.1629533208324574, 0.091702735517174, 0.10449304216308519, 0.14742842264240608, 0.18699899461353198, 0.13722665287787095, 0.1704487155075185, 0.12337333100731485, 0.12391262745950371, 0.10198181480518542, 0.13002213556319475, 0.14832287386525422, 0.20485644810833037, 0.13875725824618712, 0.11007305758539587, 0.1018537869094871, 0.15554539568256587, 0.21974679519189522, 0.18322751886444166, 0.1444421539781615, 0.18861031596316025, 0.16853805631399155, 0.12112720622099005, 0.11158493114635348, 0.10236790229100734, 0.05262742837658152, 0.16383690701331943, 0.15405550453579053, 0.08945230627432466, 0.09678696660557762, 0.13173014391213655, 0.14714818767970428, 0.12260999501449987, 0.11503455229103565, 0.1276303717168048, 0.21106387517647818], [0.05434998653072398, 0.015006669455033261, 0.0033687859558995115, 0.048665179856470786, 0.026299730270693544, 0.019115327013423666, 0.03185325287631713, 0.04395557378302328, 0.02740985331911361, 0.027410513830545824, 0.08377895093872212, 0.05905173697101418, 0.005144975411894848, 0.011635004429990659, 0.03117078129434958, 0.032866729743545875, 0.019443909186520614, 0.06639182611252181, 0.028791726726922207, 0.04638503130991012, 0.02269528227770934, 0.003261671549807943, 0.03473289718385786, 0.05433702863228973, 0.03659350593807176, 0.013386109294515336, 0.006297398094829987, 0.07090268874890171, 0.039501871360698715, 0.03590150889067445, 0.07346079015405849, 0.05777021862741094, 0.03233918148907833, 0.022280191660684068, 0.019360378610144835, 0.04664004438382108, 0.050001164418063127, 0.06999731311225332, 0.025366626141476445, 0.020411467521626037, 0.005374483189370949, 0.04287827221560292, 0.030473093829641584, 0.05456021841382608, 0.028623203543247655, 0.06298345353570767, 0.05063914795755409, 0.04342668966273777, 0.0135828034763108, 0.009990328180720098, 0.02678977594769094, 0.022261506237555295, 0.043011673260480165, 0.028140690665168222, 0.03564480743079912, 0.04769329294504132, 0.030156065040500835, 0.03712015248311218, 0.022589266482100356, 0.014901130489306524, 0.03761332816793583, 0.03480824001599103, 0.014213436970749171, 0.03060170802200446, 0.05866244340722915, 0.029171032838348765, 0.05919431467191316, 0.027054390557168517, 0.02916271707363194, 0.007369214263235335, 0.09512035525403917, 0.05515594777534716, 0.039494308875873685, 0.03166366012010258, 0.11816594793344848, 0.09755601713550277, 0.028902605445182417, 0.0685443586553447, 0.035661294241435826, 0.04617193102603778, 0.01226376771228388, 0.03706330397108104, 0.036632383344112895, 0.05213876494963188, 0.047024617888382636, 0.03730392680154182, 0.027477876719785854, 0.0561479580210289, 0.04876333630818408, 0.02824260609486373, 0.031133595985011198, 0.019514706364134327, 0.058732131074066274, 0.03309863976028282, 0.033820615863078274, 0.019972472327935975, 0.028181764828332234, 0.026311736364732496, 0.06582094385521486, 0.01854667305451585, 0.015197175052890088, 0.023348893591901287, 0.010665675144991837, 0.0424134391505504, 0.052467198693193495, 0.03345230652485043, 0.1007886862498708, 0.030198035346984398, 0.02270570388645865, 0.07568219400127418, 0.010115400473296177, 0.028756250212609302, 0.008882023394107819, 0.09744730734382756, 0.026425034484418575, 0.03473306045634672, 0.09076811184058897, 0.01875257265055552, 0.0037103260274307104, 0.03476306548691355, 0.0707730429712683, 0.045384916811599396, 0.18188167858170345, 0.060198651990504004, 0.026450304612808395, 0.03602911747293547, 0.059663296342478134, 0.03259207573137246, 0.03176056605298072, 0.08857754422933795, 0.01721274424198782, 0.10026394331362098, 0.04349965391156729, 0.04894237201369833, 0.02337177771551069, 0.0308455703270738, 0.041186179223586805, 0.028573544586834032, 0.018530557317717467, 0.02799152454826981, 0.038323964254232123, 0.0887566912570037, 0.010008150857174769, 0.031117584148887545, 0.026369779734523036, 0.023933336742629763, 0.048083644069265574, 0.036714928719447926, 0.012739413868985139, 0.03940282062103506, 0.054017812362872064, 0.03895236295647919, 0.026011192530859262, 0.02916626453952631, 0.01682546004303731, 0.029095840291120112, 0.025090851486311294, 0.038597534730797634, 0.023525869837612845, 0.025346254187752493, 0.06874443424749188, 0.011875407399202231, 0.0338536080380436, 0.018123236986866686, 0.05726480492739938, 0.0769808930635918, 0.047088294159038924, 0.06062831467716023, 0.04294080186809879, 0.02164789111702703, 0.02319470684597036, 0.01904145177832106, 0.03247306864068378, 0.004064933928020764, 0.05658838555973489, 0.023676835662627127, 0.02237739445263287, 0.05375806809752248, 0.025530074890411925, 0.029007513585384004, 0.028959697010577656, 0.027503423298185226, 0.014772806662222138, 0.07006250336416997, 0.029532840962929185, 0.0234952710889047, 0.0720101734623313, 0.020881469645246398, 0.0358480928116478, 0.08016694788238965, 0.021481030344148166, 0.02269258642627392, 0.01665389776462689, 0.024528370340703987, 0.04232734259858262, 0.02506781336705899, 0.05436415412987117, 0.036316640325821936, 0.01858995881775627, 0.031077239145815838, 0.024035369060584344, 0.060589025379158556, 0.003964687866755412, 0.07537254772614688, 0.028919906762894243, 0.03304384328657761, 0.05758113053161651, 0.042198535447823815, 0.015049467256176285, 0.030759388428123202, 0.03569017120753415, 0.09012701499159448, 0.03645741831860505, 0.06011288940499071, 0.030701541727466974, 0.07140839559724554, 0.02284557089296868, 0.03052542822842952, 0.01681733538134722, 0.013005639866605634, 0.007141226033127168, 0.019736486065085046, 0.04759458730404731, 0.021654056508850772, 0.01493776197094121, 0.02613348733575549, 0.03795398137299344, 0.004673505691243918, 0.027629300820990466, 0.029648276467924006, 0.016446330191683955, 0.021864171503693797, 0.04397042786877137, 0.04638091239030473, 0.005167897106730379, 0.01305075873460737, 0.03268507054599468, 0.058827426546486095, 0.04948339024849702, 0.03707190175191499, 0.03568171072402038, 0.043884620754397474, 0.017861197629827075, 0.009576604970789049, 0.05672257328114938, 0.02673178638360696, 0.06380858074408025, 0.04484295233851299, 0.010014380259235622, 0.029307729018910322, 0.05292976078635547, 0.04464023841137532, 0.004112381748200278, 0.028554237615026068, 0.03974420855229255, 0.08242900657933205, 0.04691763730079401, 0.02928030109615065, 0.03887298284098506, 0.06951625298825093, 0.034473850537324324, 0.027188045787625015, 0.04183228185866028, 0.05669496538757812, 0.03847925123409368, 0.05701936184777878, 0.05200260682613589, 0.032562656997470185, 0.013690646810573526, 0.03778017038712278, 0.029136192715668585, 0.033982114618993364, 0.03342006020830013, 0.037213032264844514, 0.006958720323382295, 0.028662116201303434, 0.02551271976699354, 0.022451039621955715, 0.017285483991145156, 0.05387603989220224, 0.09035769675392658, 0.027534105538506992, 0.022080429625930265, 0.03506232540530618, 0.0213710496245767, 0.03471019859716762, 0.08147395157720894, 0.05580538636422716, 0.01689203254500171, 0.14398913219338283, 0.03733035839104559, 0.03040267329197377, 0.013112504493619781, 0.01996760012843879, 0.013940331264166161, 0.022290147571766283, 0.048330638237530366, 0.00984160364168929, 0.03744760659174062, 0.03335365283419378, 0.04588691663229838, 0.037181646839599125, 0.03844604754704051, 0.029852611987735145, 0.004885063699475722, 0.022020055912435055, 0.04976143958629109, 0.04980426521797199, 0.0223213938443223, 0.018511003581807017, 0.047101159289013594, 0.01268591615371406, 0.006579151677215123, 0.012623459788301261, 0.015232973473757738, 0.04183676814136561, 0.035510423040250316, 0.06147457825136371, 0.049357340176356956, 0.022171270356921013, 0.027286200383969117, 0.05819909834826831, 0.04654072276025545, 0.06246743825613521, 0.006995880585236591, 0.05967175311525352, 0.07332377484999597, 0.0440645915659843, 0.05354585468012374, 0.014523650988849113, 0.04280629502318334, 0.02354297634155955, 0.02039409755525412, 0.049241546585108154, 0.06737027360941283, 0.03325503254018258, 0.059515660905162804, 0.03721735527506098, 0.023324506619246677, 0.014625284402427496, 0.03477259095234331, 0.029012127888563555, 0.042535934335319325, 0.08238690454163589, 0.04944057574903127, 0.0025723682665557135, 0.010362084794905968, 0.01143978062827955, 0.017223674221895635, 0.0256232997708139, 0.037412310048239306, 0.042608241783455014, 0.12358841282548383, 0.08042937872232869, 0.17170398408779874, 0.1610136139788665, 0.1173421714338474, 0.103849488805281, 0.13698302063858137, 0.16071495891083032, 0.11731011807569303, 0.10076751277665608, 0.20939408743288368, 0.08918765641283244, 0.12518772622570395, 0.12219195064972155, 0.10641244385624304, 0.13519993663066998, 0.05204636756388936, 0.12329757999395952, 0.12100937543436885, 0.18382101436145604, 0.15580453880829737, 0.12199830947793089, 0.08001782072824426, 0.10403734122519381, 0.1767826935974881, 0.13964418409159407, 0.08651269643451087, 0.16767643770435825, 0.17508414020994678, 0.10366279413574375, 0.12008359815808944, 0.0808703331858851, 0.10816665831953287, 0.17508115677628666, 0.11430862054112367, 0.17858639446785673, 0.1943429169477895, 0.12606164964381605, 0.1351487878127955, 0.13515761937014759, 0.10817992791999131, 0.1929630120866932, 0.10094689729157835, 0.18545514933066443, 0.09005214713397436, 0.17774371546693146, 0.1397327074664645, 0.1601949063478969, 0.11713838510331698, 0.09722490794956684, 0.128895303059835, 0.19451464992016554, 0.13454297266434878, 0.10922395158559084, 0.09752230878802948, 0.08122220024233684, 0.17488784214947373, 0.25128116947598755, 0.16399136278778315, 0.13840871601132676, 0.13044281455222517, 0.13735698885284364, 0.0933790096314624, 0.14053185208467767, 0.22590213833609596, 0.11210646058316343, 0.13902017148211598, 0.12756433541653678, 0.08776318558375351, 0.188585186842829, 0.22545144689502195, 0.10915834573097527, 0.07435420237015933, 0.14102155080763623, 0.16216113755945116, 0.11718259484041482, 0.12177256299764849, 0.11659518495434895, 0.13155419554095715, 0.2215488039655611, 0.10133732634130865, 0.07798090737196617, 0.1640498885535635, 0.12639070308068767, 0.07693446430494078, 0.1036756407120265, 0.1814205080154352, 0.15601306746248156, 0.19301350781461224, 0.19608677102951333, 0.14747287728823721, 0.08997172801173292, 0.1589634013362229, 0.152641921013128, 0.09735609739436768, 0.10883256516535766, 0.12087106879334897, 0.11782127970946021, 0.16660746303386986, 0.12845495715737343, 0.1786975236609578, 0.1023941817402374, 0.06551019920152612, 0.09994556938181631, 0.22698579268762842, 0.18296197842573747, 0.16857369424542412, 0.14918205823050812, 0.10086499387398362, 0.19143398007145151, 0.11791304626967758, 0.17846039263531566, 0.11693647640640847, 0.21115606476087123, 0.10186164625338279, 0.10128224414074793, 0.16992030636174604, 0.1846889709122479, 0.14588310790713876, 0.15324807754950598, 0.15544587367912754, 0.15804512717295438, 0.3041849291184917, 0.17186785029480234, 0.11361935830791481, 0.12204178448882885, 0.2540773741202429, 0.08672564828884788, 0.11510870026540942, 0.3158389334566891, 0.13105962832923979, 0.19905571796698496, 0.15295515186153352, 0.16625516553176567, 0.14412065560463816, 0.10949906572932377, 0.09570222871843725, 0.1396614167606458, 0.15870694478508085, 0.11233944300329313, 0.14215357834473252, 0.23253107559867203, 0.21186386584304273, 0.08256533910753205, 0.0859177611710038, 0.09504435933195055, 0.1601438465877436, 0.17102790239732713, 0.0805643828061875, 0.12293967185541987, 0.2446481355582364, 0.08878403197741136, 0.1974414725555107, 0.08138014411088079, 0.1649124125833623, 0.0831126952834893, 0.11777560794143938, 0.20152352226432413, 0.17351768910884857, 0.23225103359436616, 0.13452758052153513, 0.07648514583706856, 0.09024304978083819, 0.1362314773723483, 0.09979883936466649, 0.11707149533322081, 0.10755935887573287, 0.12441831204341725, 0.10486671351827681, 0.14136028185021132, 0.07763675122987479, 0.1860397242126055, 0.14376798702869564, 0.10428685127408244, 0.23825668555218726, 0.08754159513046034], [0.05016912728024181, 0.07171579316491261, 0.026863949897233397, 0.011987113612121902, 0.02000125838094391, 0.006873457296023844, 0.013155067590560066, 0.058111487815040164, 0.031002187606645748, 0.03446337141213007, 0.05935156463237945, 0.04647277542972006, 0.0799119533621706, 0.0424043218663428, 0.034578177946968935, 0.030234857003961224, 0.03814368916209787, 0.026419930363772437, 0.07679108137381263, 0.03559585165930912, 0.08408627429162152, 0.05800789513159543, 0.03115594205155503, 0.044317864303593524, 0.054602435484412126, 0.03478761202131864, 0.017507465927337762, 0.030787962969043292, 0.06458678937633522, 0.041392626153538004, 0.019800151203526184, 0.024679306479811203, 0.02108438580762595, 0.015624012012267485, 0.03715691847901326, 0.03071327693760395, 0.057375997203052975, 0.08292314334539697, 0.025139762728940696, 0.025184313853969797, 0.01734636607579887, 0.0184729184184107, 0.04277821586583741, 0.04877711056906264, 0.024676397260918748, 0.025181920427712612, 0.03974080580519512, 0.060209383445908315, 0.05738858031691052, 0.02744833367614774, 0.027493367197166663, 0.031101440581551287, 0.00673749073939689, 0.029019760877417866, 0.05734476762881968, 0.0802232397836633, 0.028079791882191785, 0.02188731166825164, 0.04465924110263586, 0.04302887253288645, 0.017093438436859287, 0.024393587045778986, 0.11433809864684008, 0.015357709944510134, 0.03566901257727295, 0.1149299911048729, 0.060522669955389574, 0.04363596046459861, 0.030640132717962842, 0.029221951590443496, 0.055389163971995004, 0.03572668487322517, 0.04338143720815424, 0.018022431067947764, 0.011717719571606722, 0.03729337717231829, 0.02187935584515799, 0.018935786647489294, 0.02467141930537764, 0.06149882792669814, 0.03119831126241479, 0.022931010644242633, 0.03697359315992799, 0.06241818191483617, 0.05223992709943559, 0.04255669591657352, 0.06565137053257786, 0.03723069909028709, 0.015788538730703294, 0.044951810559723526, 0.01660938374698162, 0.02805408203130355, 0.03266598992922809, 0.005335783434929908, 0.03523892315570265, 0.014391713830264052, 0.02560938821261516, 0.048680738982511684, 0.07793090146151371, 0.06978099190746434, 0.00795219028077554, 0.03521836566505954, 0.02512184171791887, 0.046861007722327486, 0.052760335893253796, 0.052897677742294036, 0.03352538951730821, 0.013937097355665173, 0.03321106771181803, 0.021718367315770593, 0.013771611411357298, 0.028706175653496757, 0.07553371251560748, 0.08891594130545855, 0.017102086312661413, 0.04370028982521035, 0.017180609247589018, 0.0598745746538043, 0.0369620156561723, 0.04650482878787443, 0.038865932438056916, 0.04776523674081545, 0.05861032237589825, 0.03339654525916558, 0.023419108183588833, 0.06963397245272063, 0.04603085988492239, 0.01821489779104013, 0.0712354900315404, 0.02916323657700559, 0.10293053928762674, 0.02351863575313473, 0.009858011599135352, 0.041186201488017105, 0.03161090084176976, 0.03800273305387236, 0.02460644427628722, 0.05479262938024476, 0.015204775572783547, 0.029885696931160055, 0.0387259077251656, 0.040566352327005006, 0.03248717686801683, 0.09424435382243246, 0.08379794249776751, 0.05080052054836415, 0.08967270186985843, 0.023086175169737544, 0.11226366230403073, 0.005461031059894594, 0.05465495356475003, 0.048478696699021384, 0.014848734863335267, 0.05258416858850978, 0.006301882058323827, 0.04074227843375411, 0.01799800698790932, 0.06333376950351521, 0.05471708245750051, 0.07603823192766868, 0.028729677615046967, 0.01739506951707881, 0.04807331337360665, 0.018353792584093753, 0.017042796134774107, 0.020910641615046188, 0.08273628540337086, 0.012480455352488207, 0.04986228632333223, 0.046795160669717006, 0.03410519610042684, 0.022365291879395954, 0.03192385338479653, 0.08037871972192079, 0.03608241109759547, 0.048726689055911265, 0.005513962887562229, 0.0515740425180411, 0.026091275831277017, 0.03735364327440038, 0.010185315422859276, 0.011960092015215196, 0.017930749854713213, 0.03493309523037169, 0.05616684567939956, 0.012530882431747159, 0.05168834439245984, 0.024123413750203326, 0.015268552961060777, 0.03801815488259308, 0.01715831513138255, 0.09499360385234468, 0.05317640614521224, 0.06747240797267295, 0.03531727539666463, 0.09078653936740011, 0.06150808621896431, 0.011540895466168877, 0.026263309373462107, 0.06679726880975068, 0.05480945386807434, 0.02879448380554095, 0.0165045275571174, 0.08625331582152285, 0.018032769185083453, 0.0284467579331249, 0.04164212878094986, 0.09741276036947966, 0.044709981739288196, 0.02059114889561897, 0.06866872776299715, 0.04985907653463073, 0.01808344302844489, 0.020854475878877565, 0.053646582673536614, 0.03886198050167877, 0.045391674066195264, 0.04698633048974443, 0.02825174935424002, 0.04922309308312833, 0.02518144730856875, 0.020635744549508672, 0.05100395435874816, 0.021316481361282058, 0.036513955128612, 0.04810174876183737, 0.025001719550346024, 0.0139160880826239, 0.07240887003717944, 0.018555133538029622, 0.07421118309139274, 0.0787802820559591, 0.048469033936271444, 0.021547231772274245, 0.03414255581446923, 0.060356146859703586, 0.04623363689461257, 0.008536575915059075, 0.03149780124658719, 0.0678859549225308, 0.035836585811921395, 0.038386393716791645, 0.05912067135795951, 0.018985996648552828, 0.04143100632063579, 0.02859270498447586, 0.013100748874421697, 0.019399617813178338, 0.014396819806279382, 0.01745996476529399, 0.039864161881268956, 0.02019515373831382, 0.046977806923678145, 0.05447765448479913, 0.005192800335862557, 0.007383648571703816, 0.025136306176136713, 0.011705595661624102, 0.05239486898062751, 0.05691955411748495, 0.03620288392994553, 0.05244543150183745, 0.024042473269219045, 0.014481719645118574, 0.011973205764661543, 0.022356560511980206, 0.014482120404863963, 0.014334726165543543, 0.027072309712821152, 0.07319453725358471, 0.05314761452609673, 0.04145745646383148, 0.04325532405346166, 0.06321022417978384, 0.0808019665419124, 0.10255640037939884, 0.039603994591743685, 0.04623877626727335, 0.04080425147549249, 0.038761638425057754, 0.060391009246814065, 0.08740757810301147, 0.02600523494038498, 0.004760557758345385, 0.05039862160629127, 0.006844116487627616, 0.03708975782501511, 0.019583390276238788, 0.04510368737101089, 0.05108353856485337, 0.01576817419845611, 0.02876110200304538, 0.029927926989330444, 0.02609367667901097, 0.04241682334395591, 0.0473805741785327, 0.0474387362919515, 0.0704181999026332, 0.17203806928591803, 0.03788762594922446, 0.034721152696874924, 0.026855866053665522, 0.03406694209843408, 0.021200873306952417, 0.020499899983406067, 0.06033313286025077, 0.0481533985293936, 0.018783445993904024, 0.01763144726282917, 0.027074435965914745, 0.045257983583724126, 0.05820349557325244, 0.015605458320351318, 0.06108462046540808, 0.019265945884399116, 0.03121572946838569, 0.02556950148573378, 0.03803119070653338, 0.0356597505742684, 0.12927905278047547, 0.02788589281408349, 0.06928327056812122, 0.06852535967482254, 0.009144817886408418, 0.015836253260204103, 0.04040459381940309, 0.03425859802518971, 0.02224253137683263, 0.017757710702426266, 0.07546498964074999, 0.021565251117863227, 0.043138513719895855, 0.056134261685656384, 0.03394755280169193, 0.03299706200778019, 0.02609413866593968, 0.05162550303793978, 0.03122137721220497, 0.027192682355234865, 0.0655148302030284, 0.017799011220631655, 0.07451209428836592, 0.0355624809890287, 0.07063564175041392, 0.036912417926942, 0.035920311202062294, 0.04624185246939305, 0.02630893846799154, 0.009824372828006744, 0.031751975693623535, 0.14395986188901588, 0.029451213995344006, 0.1414577555260621, 0.1981457558576949, 0.10391519113909453, 0.06688270485028625, 0.17148304672446102, 0.06015252380166203, 0.1422334334347397, 0.1797915977658704, 0.19976703682914376, 0.1708080485695973, 0.1749165335786529, 0.10647719624103047, 0.11045634717447683, 0.17872254888061434, 0.15681166289141402, 0.29348630632739514, 0.18115611048415303, 0.1883744020597078, 0.11875732088810764, 0.1392447156831622, 0.21719698357628658, 0.16543386038392782, 0.14310078142443672, 0.21261641843011603, 0.1306458216276951, 0.12924573034979403, 0.11254814235144295, 0.21179505391046405, 0.153435351094231, 0.1236430423159618, 0.09647602899349295, 0.14380922075361013, 0.12347433730610646, 0.08219035415095277, 0.15791845740750432, 0.11925156897632405, 0.24392626335611567, 0.17904827749589458, 0.1924065052298829, 0.0876299107039813, 0.12241505508427508, 0.15252386016072705, 0.09036139264935628, 0.11814792116638273, 0.1276624176534824, 0.1258078054524958, 0.1642785590956919, 0.2618042001267895, 0.26239322789479047, 0.11173603241331875, 0.14671713346615434, 0.10726365755544975, 0.1127062865998596, 0.07271487978869118, 0.1818052670569159, 0.2071095787687227, 0.10390938012278639, 0.20110696961637586, 0.15650389424990863, 0.10679524362785742, 0.07947819773107767, 0.09631332053686492, 0.23530391743406653, 0.12429276292095892, 0.10638741121510975, 0.16332941158907488, 0.13129116356140003, 0.08698850215296261, 0.0971248144924175, 0.0952765773399733, 0.10608321230392903, 0.15874476463068277, 0.09892919071717188, 0.12728646048344672, 0.14094269019551575, 0.10529298830078915, 0.19544067210517824, 0.11358630305039696, 0.18409531214274466, 0.19228314544307068, 0.1370498733012937, 0.06911645803484134, 0.10713089475757442, 0.14712181175127625, 0.18796063988702372, 0.1374342167400755, 0.11599770412431099, 0.12938562518684193, 0.13860173377906904, 0.1378569143707864, 0.07741617751889862, 0.16986840055324137, 0.19397077441681176, 0.18826934363460168, 0.1682079044985585, 0.3329393221065402, 0.11745563839212991, 0.3466832736739889, 0.18392444006167352, 0.14381187764229253, 0.11702778283506632, 0.11456013438873924, 0.11285281623713672, 0.10613085076329298, 0.21366207482060418, 0.21893730503506958, 0.11163099625264294, 0.08917390441638418, 0.15064187755342573, 0.17339548707241192, 0.12987403257284313, 0.095011548983166, 0.16717253427486867, 0.25885077891871333, 0.1390082822763361, 0.09141462636762299, 0.17524969851365313, 0.20723225577967241, 0.1306986773852259, 0.14626452728407457, 0.15030108334030956, 0.19063176296185702, 0.26844375010114163, 0.13298530859174207, 0.11593449540669098, 0.13839569874107838, 0.12363860427285545, 0.10856286869966425, 0.22877399751450866, 0.15640376368537545, 0.21389654895756394, 0.11423035364714451, 0.06038845254806802, 0.09615131712052971, 0.1340108082513325, 0.1664097697357647, 0.11075032671215013, 0.17715728521579877, 0.12136004763306119, 0.09174626247840934, 0.216083301929757, 0.105333034589421, 0.25957161211408675, 0.18372852791799232, 0.14694314711960033, 0.27988256129901856, 0.19458392198430374, 0.10189490931225009, 0.2578047662973404, 0.12895489751826972, 0.11504189213155769, 0.16548870509723201, 0.11209733958821744, 0.12111155432648957, 0.1543616404524073, 0.12611018610186875, 0.15825649083126336, 0.15450917941052467, 0.17577317979885265, 0.16223849903326482, 0.0906667864182964, 0.15388583473395556, 0.18522440077504143, 0.21141026518307626, 0.17423941288143396, 0.21988516120472923, 0.17098171112593263, 0.15709964587586, 0.11510834403452463, 0.18424041685648263, 0.15928193111903965, 0.10396565718110651, 0.17418171832105145, 0.194425176596269, 0.2723683457588777, 0.14683887537103146], [0.03083179606619524, 0.04904592387902085, 0.024457610270474106, 0.023871361845522188, 0.04612633347278461, 0.012876172204414615, 0.01724163976177806, 0.006389159088939778, 0.03368812394910492, 0.01973456390260253, 0.030344474071171135, 0.017320828774245456, 0.013459721067192731, 0.06118662866356317, 0.04659675862058066, 0.027248131918895524, 0.03916228684829548, 0.06800029019359499, 0.01312605611019535, 0.02267074873088859, 0.04256459236785304, 0.03699015789607074, 0.033325792610412464, 0.04872222874837462, 0.027393312702770345, 0.08635717196739279, 0.0324903272849042, 0.045775297621730715, 0.009439418045076309, 0.02022843164013466, 0.03830469438980799, 0.0335270073992433, 0.04942551386193372, 0.03693326856591739, 0.03308278748590965, 0.03722279150679242, 0.04993511327484157, 0.032104922574944794, 0.05357358502806164, 0.04311525481170975, 0.03404350878554396, 0.042831375903915614, 0.021711864246753976, 0.0856921260128729, 0.07120001537259668, 0.05120604117109906, 0.0479359084420139, 0.031034348576213233, 0.01691871275397716, 0.036655794392572716, 0.010947446353384294, 0.08877950487658381, 0.09116170243942179, 0.10185169405303895, 0.05412061836977955, 0.049963648853008635, 0.058536998185445555, 0.041489138748147525, 0.0359764138556784, 0.04552451107883826, 0.011109246606793022, 0.03747685463167727, 0.01087750357328332, 0.027642678032862023, 0.05125402101839427, 0.004977440212314832, 0.014453922503889771, 0.02336863472010009, 0.03381560636626091, 0.10778565454529598, 0.0198859750162228, 0.02921711464296095, 0.04420948476763442, 0.06472545224823989, 0.04981057718396187, 0.07370997365796939, 0.07114963096682914, 0.01968934855540283, 0.03791567542066332, 0.03754198922251817, 0.07937768124975264, 0.061705018815700896, 0.015482191301998682, 0.021136902032594662, 0.05332641274435446, 0.051760544229182415, 0.021631777235597838, 0.0005425586550700245, 0.012971213491255185, 0.027835493565362412, 0.022428099837270565, 0.05197950747970026, 0.04726965278678108, 0.022990918660070747, 0.038626834721071646, 0.1250803522998467, 0.058519843441899866, 0.0384526229754556, 0.061169926630100235, 0.140308465634007, 0.0438966101501137, 0.043993078215862624, 0.04755449277581647, 0.10492167697520927, 0.044178514945087954, 0.022606616039411165, 0.05388732053688727, 0.04253294719092082, 0.05603031277132686, 0.04177395276201423, 0.03032966636965284, 0.05059893839643337, 0.02029469429544406, 0.08642751272418536, 0.029777998315694276, 0.08942805288825184, 0.02314554512850009, 0.007025248296486097, 0.017040807179000694, 0.06380169361364096, 0.03169816256558988, 0.05676614848198369, 0.04088128640432842, 0.007881867149990285, 0.013605411149910651, 0.022035915608284995, 0.020231730486557353, 0.07269845606060699, 0.03239227102312725, 0.03963523900893051, 0.04369712827610783, 0.06167119172459934, 0.03968022429035045, 0.007150656874728156, 0.03226199441996869, 0.05566307583649177, 0.04160790835157968, 0.052390920754987746, 0.02767972975561861, 0.020490363385761157, 0.06804145712521859, 0.0996993767330423, 0.05782367181382142, 0.04503967342316173, 0.022597851275349967, 0.04912328164209612, 0.06119319295976311, 0.008475242975691799, 0.019999065334559418, 0.019517552500474267, 0.09058588490006514, 0.020544317521853372, 0.02681123329239199, 0.05669347367074806, 0.007271203921845881, 0.02052324609394418, 0.01472003717935877, 0.03521903359796852, 0.022935211200092454, 0.05615974703687243, 0.08921307497075759, 0.08263780240667984, 0.0645565617014654, 0.005938549747952493, 0.06363634311128408, 0.03554840986907948, 0.05974224230158143, 0.02784157175483415, 0.03833748247416224, 0.02537967866373947, 0.038495552507811226, 0.05132947517267894, 0.016362105707230512, 0.029797941679134965, 0.04486902769713197, 0.0727848791575525, 0.04653659641917329, 0.0633182586170733, 0.029701386411034036, 0.04605663467373233, 0.028934278452652507, 0.03309301057015546, 0.027566747048695106, 0.05274786781228613, 0.07424234587233514, 0.1440077749430202, 0.058161018750979565, 0.007967302262841258, 0.02925907938333694, 0.09092909851460718, 0.06942648280528374, 0.08891667603165843, 0.0322676347423112, 0.05486018337251153, 0.04419207027240191, 0.0591407241881825, 0.030535441655956674, 0.024118313340295572, 0.020204428728902712, 0.03579677329980768, 0.009686345420050202, 0.062451422709273174, 0.027619565698842052, 0.05472065960930195, 0.031393759563798085, 0.022932094179850537, 0.01863325942395022, 0.05458020074001979, 0.017999708361458033, 0.02331022213184042, 0.020618571252271067, 0.01720603151625255, 0.028622472527786158, 0.0208125723656849, 0.025590530240151566, 0.018635363412613515, 0.011383643650333397, 0.009889365483104484, 0.05685798554623034, 0.11638066716841422, 0.013650861201313091, 0.050969062285730615, 0.09482722918619402, 0.033851763801067136, 0.019746373327507172, 0.07340075782849453, 0.04811645812878851, 0.027084135836048517, 0.06492579501355067, 0.03397596963623073, 0.09458753032959066, 0.05019780757720582, 0.029030694568064064, 0.016926110110944137, 0.029903163376729935, 0.031482535268878564, 0.013139731108822161, 0.006672452163911657, 0.035027084522880614, 0.05688032790203579, 0.03824017578153871, 0.021729223080910742, 0.024237468860519584, 0.05185935377085116, 0.09695750472019427, 0.07293857794138603, 0.027995092423225287, 0.04467339014809113, 0.05468719617056195, 0.008829435737425229, 0.08015225335839204, 0.050029518170049414, 0.08287934921099804, 0.03508335415972397, 0.025395864904567134, 0.031071737976162694, 0.07080302573740482, 0.100019338860875, 0.05881406417756807, 0.038445561440312304, 0.018531585192249622, 0.048104346278705634, 0.04893938486929983, 0.0571048535493901, 0.0855844329635147, 0.07320258213439956, 0.07410150850773789, 0.02808778666803846, 0.10220186159131117, 0.04894956713542342, 0.05919411800277885, 0.01217418213855126, 0.038768466183682904, 0.06856351348687895, 0.04945574524754193, 0.0755936186760664, 0.021360271784942597, 0.02562475438026013, 0.06157410396554042, 0.02616013414808549, 0.012993682012165664, 0.08077835882431827, 0.0277030369034037, 0.013805993257847149, 0.04940196551615372, 0.03794685675529763, 0.0594272674061358, 0.02447107654006686, 0.024846766536938958, 0.04522514725977089, 0.05259139339614194, 0.013948467058071401, 0.04744586462038569, 0.027645713416859508, 0.04757702066854108, 0.030572337527701166, 0.027948094066232443, 0.04952254967065528, 0.02588259503681911, 0.03231466092984192, 0.04487282378249802, 0.03500466424156912, 0.030745116928301286, 0.023848846940381918, 0.0370108823699411, 0.012825813773815753, 0.007634589110239176, 0.07538259640568867, 0.13450884871417657, 0.035123103589285165, 0.02256737312563928, 0.027265897078905255, 0.048620020170346834, 0.024007083957258146, 0.06136760508525185, 0.06706436775857583, 0.07346867176238447, 0.03373089391971007, 0.050706460751825944, 0.06626946822507307, 0.03127673771814443, 0.03036398884432856, 0.07981875445693731, 0.021723180143453646, 0.038850139535497874, 0.03776191355427727, 0.027475407223391812, 0.05470717107527889, 0.03516852673783433, 0.010404934546386357, 0.031097664905246347, 0.02816745065501891, 0.07081671094056219, 0.08570940321078524, 0.0232021338888444, 0.06535263382829726, 0.04834008577745408, 0.06174015208671335, 0.09615001836209558, 0.007113460433174623, 0.07657606634893455, 0.022196850331965834, 0.017829064490797464, 0.06257596251089126, 0.01803587507311022, 0.06515004235552624, 0.03257674296037294, 0.03583761368645355, 0.07005566818406805, 0.03773373791773338, 0.04762008749821689, 0.11622578094829805, 0.17273231875151396, 0.12759704928612337, 0.1570689061190933, 0.11294969619484618, 0.08975258664577268, 0.07476596816559322, 0.09075654175831005, 0.13489718490745872, 0.09761462453752756, 0.2399792696814984, 0.12044578848872334, 0.10254092660034075, 0.11204864727915265, 0.20295153313782066, 0.12524206627858803, 0.20117627136642113, 0.12144989203079604, 0.19145383994327858, 0.13632191548822448, 0.12845408142311499, 0.10887799944612198, 0.09511870768619701, 0.12967182701686397, 0.13710247672861442, 0.13385700556682423, 0.24803353124298155, 0.09654076653532684, 0.12945810332894325, 0.13457512250170112, 0.07953656764584593, 0.15012419986305758, 0.11185712122824043, 0.221498055907432, 0.11563100895727985, 0.1465198557707481, 0.12941744847921655, 0.11342700105160475, 0.12235576490638778, 0.18131853692466393, 0.11393742795917206, 0.10085431436891668, 0.1544802653370425, 0.15830444841412827, 0.14636379695730284, 0.24330895976163447, 0.10934504040051252, 0.1552935701329261, 0.12199546705232933, 0.0979650740919169, 0.13272264768602327, 0.11023936545825563, 0.2414446254260838, 0.16629935300443321, 0.1220014487626031, 0.16381004126742482, 0.07139700363040902, 0.09493030607700348, 0.09344021455035545, 0.10938842635368928, 0.08924346591811627, 0.07274693314684555, 0.09061336662853137, 0.10795513138873503, 0.09106016179430299, 0.2990806451998651, 0.1170307514257729, 0.0816725502954796, 0.1062492975324858, 0.23816479282686487, 0.12905666080769151, 0.18780652550049126, 0.18804947496391833, 0.14050666359253228, 0.12083744950359687, 0.15388858068035915, 0.14262027048971504, 0.13497125124558806, 0.11766099807573482, 0.0899612859939225, 0.12122279484174214, 0.13603655970655382, 0.17022996005835012, 0.14419196115341038, 0.10646411217749119, 0.12721761886496097, 0.1754850780707784, 0.17680115823168308, 0.12056649138685316, 0.23629426897969097, 0.12037203385261819, 0.15836248436244205, 0.09534354132483713, 0.21897938480833545, 0.23957957862876356, 0.1903565597604029, 0.1707119998172857, 0.1617189808166586, 0.1392375910654664, 0.17766108474461362, 0.2790541760623455, 0.1023298894870095, 0.13064429280348122, 0.11828462476842105, 0.16267572791548446, 0.08930021795094945, 0.1617794213234447, 0.17877322272397578, 0.12153371761087328, 0.14775201387237757, 0.11417671121307649, 0.0812399821006693, 0.10783179386635311, 0.18439024162944406, 0.15173678286373615, 0.11076184484409168, 0.17706300277495757, 0.10967813112074509, 0.13924401806434616, 0.10214320966042578, 0.19399370678002015, 0.16355162544641644, 0.1522749735158868, 0.073269145359518, 0.16394787293393165, 0.14595655084121972, 0.12151303395512514, 0.12062390393111855, 0.11771932346164249, 0.17530294018797576, 0.0775879253342282, 0.0763487168296706, 0.15074224560521543, 0.1950171432690695, 0.08266242686659098, 0.09948427265044302, 0.12518582632765174, 0.12179528755950741, 0.11366854785592295, 0.08921729036956094, 0.1286777647328563, 0.17020120925735682, 0.2283187789726071, 0.07825447784853168, 0.10276016444549896, 0.1255006156861782, 0.1329338035429828, 0.22822167637059465, 0.0828895166341681, 0.09986552875488997, 0.1526736404048279, 0.1198049217055086, 0.22299225151073188, 0.10858580106287263, 0.09235931356670335, 0.09361643009469844, 0.0992617841984611, 0.12137771816924214, 0.12330650803050958, 0.05245736152573954, 0.12407945483573712, 0.19019775500055403, 0.12965788948349655, 0.18901147646829486, 0.11502377630677074, 0.17995072907069698, 0.12370425465633161, 0.33309086866211146, 0.18443678913172334, 0.06174047492095269, 0.18578283721581101, 0.15480422764085233, 0.172396125853993, 0.15873167314566672, 0.11235980011406355, 0.10377947459346615, 0.14017283072462305], [0.044429765330278315, 0.02802181159495376, 0.11814087818493135, 0.046269983577076346, 0.06058095081243664, 0.07176658575190231, 0.02486781384504866, 0.02080788941384526, 0.033400133543182164, 0.05086038217996247, 0.05347000347683206, 0.01271841480047442, 0.05005434672057163, 0.03250436871894635, 0.05696651722246315, 0.01686641731794225, 0.007875082992541138, 0.035444357054075226, 0.002353865843360836, 0.02378453798883129, 0.027103880674985703, 0.025002740003401414, 0.028170840414531995, 0.04263402028300334, 0.017909017915371805, 0.039308894411078654, 0.017545753325975966, 0.029300925380084664, 0.042684041036409326, 0.02928280027845176, 0.026970143808284774, 0.037578317351290025, 0.01719503474305384, 0.02585759764770046, 0.06676580174826086, 0.011506017308420269, 0.0465984321635915, 0.0287170110095758, 0.06104339787270874, 0.040988556429510936, 0.033648077660473064, 0.013482253598340321, 0.10767367930384353, 0.0232436533406144, 0.050790212117135525, 0.025612199096940458, 0.06571495774551295, 0.024137928303389344, 0.05318498166161589, 0.07724041468463838, 0.048778628261061385, 0.058218316262355074, 0.0271130220789928, 0.09172536359983496, 0.01109208165871678, 0.0367394567001611, 0.00944953630096279, 0.08569271230953746, 0.028808803544961847, 0.01129527890952886, 0.04806192882824689, 0.023261466740223113, 0.079539076104993, 0.004914642922813073, 0.04963141902408097, 0.12941191205754876, 0.042862212139880285, 0.04904085129965097, 0.03839409720967524, 0.0018892859202424006, 0.009765902723302133, 0.04671497161325533, 0.04854821367189288, 0.00977794314167113, 0.06395641656126827, 0.0245315986830974, 0.04043330751301255, 0.04335056015406735, 0.06844687013654038, 0.014078029344091192, 0.04781479365192354, 0.03733898585778661, 0.02392851278273156, 0.032719265000196174, 0.02324651060916949, 0.05343242111848667, 0.049284260894637555, 0.0349593858118169, 0.06584023227333091, 0.024045857462624554, 0.0730402595945634, 0.049735338252503425, 0.021129833075974602, 0.04563337301078718, 0.0334508964442648, 0.005543012402995373, 0.031398683713632636, 0.0260745478226454, 0.03540221048751846, 0.0456710815342376, 0.05477020538819488, 0.008204151272366289, 0.03247802618716378, 0.08598639498814009, 0.041201233689207584, 0.049182356597157195, 0.06253694038605317, 0.05746163733419962, 0.04308330164349172, 0.04328267961682286, 0.029643515590578318, 0.03243256593123078, 0.01810950354411034, 0.028006289576296695, 0.014025547443452524, 0.019493634936225135, 0.012971748765266966, 0.11780316388467327, 0.029185931452957448, 0.02834882598108379, 0.02408972581179114, 0.03704599708726164, 0.01646377993893111, 0.06411456823116168, 0.0022582449855690356, 0.012713385822280543, 0.06435546194552444, 0.03429407639487181, 0.03008290041179862, 0.03735871956450865, 0.0092271304129099, 0.02775693723378936, 0.03297658244264312, 0.022204266242624726, 0.030116076268313918, 0.06824976313509978, 0.03565883031114936, 0.024840977785061114, 0.03991447578300722, 0.018331253559153993, 0.04259926179656759, 0.054114265585667454, 0.02100332101690583, 0.020610481842595618, 0.01812893297028495, 0.012922031364723807, 0.004746365111714113, 0.01677354495768668, 0.057953280484071, 0.09268233334296383, 0.019868456620315555, 0.04481367832340766, 0.02277294061059365, 0.025596281884645578, 0.04148055952100549, 0.021763445365650114, 0.04347755646449514, 0.0570086897641886, 0.07136653846828267, 0.027400357539590914, 0.02003834906645352, 0.0016355136244783353, 0.00683670150465332, 0.041015466704266146, 0.0588104276539525, 0.044232532163732685, 0.056841227851691656, 0.0708497290906962, 0.04115386982448399, 0.050066206240444444, 0.03848558546451386, 0.04946961969835684, 0.07532173287472688, 0.036881637352053076, 0.0665920798201114, 0.04760543008160312, 0.019109365712211, 0.05116533808177337, 0.03331814477860462, 0.00470347407826921, 0.05299408272549044, 0.03936344597605057, 0.09738111519254744, 0.0321548950887518, 0.04031043383292854, 0.0044050922133465065, 0.020444541332835797, 0.022476137201010715, 0.030800529384578113, 0.016452961281174794, 0.014822955436102347, 0.033330623991787434, 0.036007528397021815, 0.05499586652149446, 0.06098460864450317, 0.02072744617180433, 0.06466589489718899, 0.01812433165468974, 0.07070192295941524, 0.07818574755219743, 0.022355341534421314, 0.01039416227285983, 0.028357633418636397, 0.015902239465503953, 0.03647480683866888, 0.015321482005674625, 0.07520702652982436, 0.05791826966742519, 0.07286505337106064, 0.027731236659747083, 0.09002153354231268, 0.016052869468694553, 0.06424041421269067, 0.04850920639000833, 0.03723390145751182, 0.060243351545068435, 0.037538404649239965, 0.0519816893938696, 0.004817307471967069, 0.021215781198407058, 0.01804573264962528, 0.03666303775389679, 0.06737471165251918, 0.0766535168804694, 0.016945867937465664, 0.043449518125271425, 0.02310423533344874, 0.018596055560919922, 0.03664320014650002, 0.03176357175107114, 0.0026844757030630717, 0.04447173749213107, 0.06537974448292516, 0.03318383460282348, 0.011214485002710717, 0.021683653358195443, 0.04313436882512178, 0.048422846375615336, 0.04100966682017315, 0.05510806440724991, 0.010495531296328409, 0.041309279258712195, 0.04788197657035198, 0.012183000708319014, 0.07522744301240891, 0.042043886714964174, 0.03213932483049575, 0.054740419291192666, 0.0907758747052867, 0.05093348372611217, 0.04510480059252586, 0.05288324296998326, 0.023649832619412336, 0.020676759340858553, 0.015481549344258383, 0.041445474489592016, 0.025182015051541384, 0.03579204581910744, 0.04730192507850006, 0.0324908356560627, 0.04460606993234251, 0.013690483538084663, 0.005059490204075701, 0.03312106004159432, 0.020036207970406394, 0.07848427645512857, 0.019571725570131093, 0.025745718885445967, 0.03367282828548923, 0.034056867443723604, 0.06984722116612829, 0.060225001943763345, 0.02833471960911993, 0.05907885504711885, 0.017318246100330725, 0.03818977282207925, 0.02492701867595315, 0.039395180210703984, 0.08809302569716237, 0.08644584377179854, 0.008272119939647382, 0.009767677383933915, 0.04763072247442324, 0.016994827419694047, 0.09430442325538024, 0.05481119791511446, 0.09422973351320252, 0.02631226885569049, 0.11619137498200871, 0.02827861695550382, 0.04212975691189058, 0.038740398158552125, 0.02270878008857835, 0.014496558887913125, 0.054508275497937575, 0.09944444900611416, 0.06456401286413893, 0.053753585525555536, 0.03948922145355027, 0.02987457213748712, 0.04026172297017183, 0.013207107913331129, 0.07393657360807993, 0.04368450434412807, 0.028797313243558165, 0.010179184355365578, 0.05268540124234278, 0.012389483817969449, 0.026469288750377018, 0.02203801959694829, 0.05540283062146045, 0.03617776223109104, 0.03447897506703157, 0.06873039281344973, 0.06361030857078731, 0.05197771519306116, 0.02474996079399716, 0.024358125374419615, 0.010513052475289442, 0.06348300055833533, 0.041150099714286625, 0.03825341569609009, 0.01087912145521841, 0.010047481900983257, 0.06185396414366551, 0.046037817519390956, 0.05297783711284865, 0.05434351129224524, 0.023815915992599912, 0.015469684258277994, 0.019423539088165853, 0.07373270564130507, 0.021501239025383256, 0.032928539512795396, 0.055402511497959495, 0.03971070058469195, 0.010167090131290024, 0.02330195089598419, 0.022797689380240627, 0.06323288194835186, 0.031246561993611977, 0.012800090007658582, 0.010040736706287134, 0.10439143472467549, 0.02302850658452371, 0.02517237084248336, 0.045254517754074186, 0.04060132603626698, 0.06193519220687449, 0.030909827328287065, 0.03415846746065654, 0.027462074540380854, 0.09405097982380539, 0.12463436607504264, 0.21762321382993832, 0.1228483951126691, 0.13533240999095142, 0.16601283947238699, 0.1351306348806247, 0.11203514019143768, 0.14116653677774593, 0.10397970603662543, 0.14839201234281063, 0.09118335088714957, 0.1852192947990261, 0.07211679781903513, 0.1923694572178647, 0.15274199220584705, 0.11456385997007601, 0.14822198631009087, 0.13391498214332387, 0.07493750817957334, 0.11474134458694607, 0.10809328960021958, 0.0980963600159157, 0.1486777837271802, 0.12119003644329496, 0.11334777678712271, 0.08597616077167913, 0.1067286952456925, 0.09143311326624826, 0.15756476466776803, 0.1467162132030353, 0.08013631944777444, 0.10279480047756806, 0.11190729783265851, 0.177746209083125, 0.18031068553682417, 0.12042313072015531, 0.1543107142788358, 0.1256417276454158, 0.08606167102698237, 0.10812627064296976, 0.11943699457333423, 0.2115196132217534, 0.10648927098372951, 0.08692317831446417, 0.07819002232281491, 0.18024317978415638, 0.1148309292329941, 0.09016875337692909, 0.15654398506740108, 0.1421305420808494, 0.1050792497699149, 0.12148974536103196, 0.11518798390170559, 0.142245055467356, 0.16523192200111225, 0.11631017056060955, 0.2302647495525889, 0.0866341266373638, 0.09543392749037594, 0.11594751267693937, 0.20749861258082092, 0.25097920442931354, 0.1118642977962736, 0.1430077457916923, 0.20036121510202065, 0.08849836449371651, 0.12571604631375521, 0.1427457231329754, 0.1100160161149688, 0.11054091490223072, 0.17907725094119087, 0.3138072893489152, 0.07640191397513263, 0.16945805225986987, 0.1167918392457068, 0.15739212627522647, 0.08277957487734966, 0.1980069445562549, 0.12260030256584287, 0.1293300828547217, 0.15908181841950864, 0.11497598941787146, 0.15920207602903247, 0.12544866534881294, 0.09093976317672059, 0.1339363114675507, 0.10716109274653718, 0.17539771244628355, 0.18079348228638992, 0.09472432298935018, 0.09139668123680167, 0.12931650155223906, 0.09224638837622479, 0.19740160438232124, 0.16745083965361118, 0.08733179740374908, 0.14177681965520605, 0.2851292188279331, 0.1993265128112398, 0.09669955645222217, 0.10836701592779718, 0.1841860471176915, 0.20466020941967145, 0.11217300154385157, 0.1556382086710073, 0.12910160527098924, 0.11792584831709974, 0.1350450949394144, 0.07503746062866412, 0.1804891275241971, 0.10527585211093538, 0.23125473002437502, 0.13028086308622733, 0.09917342409607954, 0.09037629497470334, 0.1471414341358468, 0.15406473685288802, 0.09775024460395798, 0.2694774727569893, 0.13558402773924172, 0.0994255613477435, 0.10938447812804952, 0.20247096283128485, 0.11030732392100617, 0.07537690413300879, 0.15481743786949664, 0.1285442226799205, 0.20454446406802163, 0.10856321750907227, 0.12804217461962253, 0.13721034047193825, 0.15274680132279173, 0.06115936586866155, 0.09250797316781245, 0.12173463925137185, 0.13033604918746278, 0.12483225233154371, 0.15690018626628444, 0.11204208669369109, 0.14907367498381063, 0.1328454285976477, 0.12716755358269438, 0.12247678692801856, 0.14936094550648704, 0.12523606972536072, 0.05987015145365149, 0.12257463167770766, 0.23155593808041885, 0.13108208571793512, 0.08299159162561409, 0.11074367706896737, 0.10221883450867608, 0.05365227123547811, 0.09991469603846781, 0.12393463955959305, 0.06517922360217199, 0.12321575821260922, 0.21184296696446836, 0.15896276308922097, 0.10876580156036653, 0.09837102887104265, 0.06774604524252936, 0.18551833578385413, 0.16538605123059824, 0.22697368083754554, 0.14905958902090788, 0.24886072904337198, 0.06795573164708912, 0.2082620598957874, 0.1420563569990918, 0.12260099276318215, 0.18577091832412407, 0.1339455586276017, 0.22148055606521666, 0.10310929297702387], [0.02681586058315588, 0.07759649713989347, 0.05686382624844555, 0.04483725264435634, 0.04498600501392502, 0.05486297013703734, 0.06944367836695164, 0.0236211578885559, 0.023720371900708415, 0.06447264706366695, 0.018453711636539083, 0.032800296394270845, 0.040259763700305484, 0.02413298931060126, 0.06535917214932851, 0.01298725130254752, 0.1137955961166881, 0.015375720940937754, 0.054430632008006796, 0.028433495754143223, 0.007469201964340755, 0.057047559748752974, 0.027285430405754596, 0.027972686984867323, 0.05662213843606878, 0.08710102658369578, 0.017302649866905995, 0.07904166646767408, 0.01890346611617133, 0.035266675768070854, 0.08598660278948955, 0.029093114753777627, 0.014189819048624486, 0.024318489122379106, 0.018092643804266118, 0.06241290524485521, 0.02487744321115315, 0.026148090946662705, 0.013467629578371998, 0.017248448966711294, 0.020596637077687774, 0.04182373973890208, 0.0298787597057526, 0.03891029060469009, 0.04631780015188269, 0.1047269300033804, 0.056860126642277464, 0.008287706896226155, 0.0661803140246775, 0.026224884677503724, 0.01683479069470195, 0.04747539838717785, 0.06797263034968637, 0.028051916815456934, 0.0485395787836751, 0.024827424313116353, 0.02716239345318172, 0.024483013985445723, 0.09452262209379114, 0.04522219722275622, 0.03485463166725822, 0.023940016071719583, 0.0541485157009447, 0.02421893186692614, 0.08883124741259962, 0.004469906753001851, 0.04687425876909401, 0.028848324764112476, 0.03293472160294186, 0.03730122167326044, 0.03123478039924521, 0.023342132626567036, 0.08245486300438643, 0.02490628306986764, 0.020568546788126696, 0.06308086041826755, 0.07431899488437921, 0.04100122117961291, 0.01815965231799055, 0.03589323765481822, 0.03256824908021372, 0.054580961441388354, 0.02491476210707333, 0.07187340306700207, 0.09017584088724107, 0.03225854714401066, 0.01916057019116124, 0.056419227839796804, 0.03721376328030601, 0.018935857151518576, 0.0288693887705449, 0.04763137927511707, 0.02831085213983897, 0.013411172549240291, 0.05519676589756273, 0.0742649739549961, 0.021572448094957508, 0.03250000489060767, 0.05835946161823813, 0.040506483273929916, 0.021048796115792356, 0.05947700985416304, 0.025801353986025788, 0.021387122687883675, 0.09984707154217176, 0.02495228694897378, 0.059122526727151126, 0.038006295362720266, 0.006184767444210593, 0.01740271363814827, 0.03197388527041767, 0.035913153187721036, 0.01771172166627366, 0.0035914833688366343, 0.022149894648464397, 0.024568464868934825, 0.04786692952620797, 0.041580760589567944, 0.0237841594935162, 0.08352392673259601, 0.1320170285180211, 0.039811187380109914, 0.043009079454350285, 0.038839742046548054, 0.028906462757731788, 0.05800426231871825, 0.0862698137643747, 0.022964817326283082, 0.05490074174304027, 0.05645335178996902, 0.03105437172052916, 0.05236762102867942, 0.05786705034552142, 0.05694661282177549, 0.04335919875302352, 0.04354326993052382, 0.0037912736979706096, 0.04202108793833759, 0.07250850336276926, 0.021424599290185142, 0.0015582311198159005, 0.007200281970654032, 0.05291637615300715, 0.05951582788839005, 0.07405681637465023, 0.015114813359105028, 0.030733574676560238, 0.013651402969117044, 0.00795253537944518, 0.0431157520506531, 0.07859159843064845, 0.05744911359215621, 0.06036462960764766, 0.01592932785570156, 0.04467556835152209, 0.013626238596771145, 0.026397196525067557, 0.04954755262588151, 0.09332663626992144, 0.06446653918828815, 0.03826236599707045, 0.014231934073904995, 0.030478502230835147, 0.08229462589952163, 0.043714839630411007, 0.01742495209327899, 0.02796960707200924, 0.04228119214531034, 0.026054255649796687, 0.020096698572160676, 0.0035654996190714883, 0.04294436046620831, 0.04261553338437807, 0.08197864910471253, 0.00588630347920116, 0.04093976764124818, 0.031207528736558743, 0.07867893436923623, 0.04923513813992031, 0.05473282712046057, 0.019927075154555496, 0.012619402095879195, 0.025438844531890936, 0.014521056255034637, 0.03885959449689835, 0.040294778227689676, 0.03859690761601087, 0.04425896375323646, 0.04675321819377132, 0.031379243155242875, 0.01725764788716333, 0.011046875588363037, 0.08986171946162358, 0.021225729688012507, 0.02762241925665876, 0.048865956778172404, 0.008516668731317623, 0.03125456234556623, 0.03706704439537134, 0.03188165857864078, 0.015582804262521677, 0.03411052101000678, 0.07262811530381441, 0.06469192943768576, 0.023493729277106468, 0.03302928977063857, 0.06598964144359343, 0.0025720683925101184, 0.03812900205957703, 0.09393762418767437, 0.04091496877663303, 0.008614350208517862, 0.010410114737169351, 0.08265758064226247, 0.02651563030667603, 0.05194794022827409, 0.0430704921745928, 0.027096208723378368, 0.06552477498189546, 0.055086011489038356, 0.005115228741487954, 0.09103038682951592, 0.03304160571133252, 0.03342945950862486, 0.024736438863328658, 0.04628421054803766, 0.015818321116967127, 0.023632043339603115, 0.01563950991112506, 0.06591974597540684, 0.061138277742429636, 0.018333172010898124, 0.03846147308649961, 0.03684067080030218, 0.02336665133043425, 0.01908937225380214, 0.017940804100362584, 0.03432379940932151, 0.06043101100658532, 0.052176002209307626, 0.07999085108167492, 0.08225652403780259, 0.02309437775693368, 0.056432174606015906, 0.02627095720526995, 0.05340562216588296, 0.011156402670167154, 0.0623921028454788, 0.07733408114290796, 0.021911531657679006, 0.057953915020334534, 0.026200503270956688, 0.09617436080588959, 0.04080273007275537, 0.07282162288902327, 0.030553060241800267, 0.03975930383603554, 0.06850506193586625, 0.03703470159962308, 0.06871989142382517, 0.04232451872667298, 0.055631475188420154, 0.008574689836677862, 0.028856312128482386, 0.02153315879695583, 0.02062023737380514, 0.017193771236634348, 0.016843770681589376, 0.05153734331543092, 0.01917377856443636, 0.07181509994552471, 0.11181849244167097, 0.0465709430136485, 0.04531363352725748, 0.028986247343709692, 0.023238267203851137, 0.037068187302793376, 0.050343966140644625, 0.061334683414315805, 0.01887093221739633, 0.013554095348808914, 0.07541840503108688, 0.04529736936092377, 0.04570686418446712, 0.022912406857358292, 0.023746836886857636, 0.030709542079421226, 0.037991099889040925, 0.018685911090869922, 0.03389542434888426, 0.07764262903947383, 0.025332118129881565, 0.11781983252149075, 0.03757629499887116, 0.02868885207135463, 0.02652011658938136, 0.061765162463416345, 0.018265233957208693, 0.013969866886327509, 0.0484409139608033, 0.02893942339142086, 0.020947784250893164, 0.020688848926511128, 0.014351171230373438, 0.06880136439576745, 0.01425146647306974, 0.03225621680030599, 0.03844464117719326, 0.09574431591317989, 0.03245783977035899, 0.026829484559129924, 0.04953856150677893, 0.02197259927925188, 0.06081207044189796, 0.07461360524757765, 0.020124764741922263, 0.018136009348381776, 0.03965271658671554, 0.03048062662855955, 0.002754147831183218, 0.02249588018457871, 0.0570081145997392, 0.014901273352734279, 0.029356033555814065, 0.023603066183568444, 0.0608935285708867, 0.05023020974476822, 0.0370153315452626, 0.04686118583776988, 0.050547982536954805, 0.0458701589377597, 0.04198962458758615, 0.013376231308939168, 0.06401175851351582, 0.009353750083391787, 0.011109407096228097, 0.05598131989245303, 0.03174290293827653, 0.04849270102567971, 0.06829950187238865, 0.0631273040198721, 0.043710650206776336, 0.0614557907829294, 0.06611903489101678, 0.061643324079341255, 0.04560105247946922, 0.017873990400403272, 0.06028479678207077, 0.04765269375639036, 0.07617926967213862, 0.02088129895128077, 0.020697186955658253, 0.14555225847288966, 0.15761971328174695, 0.31835517031140625, 0.1804519459255971, 0.0820665193896275, 0.1054299961833749, 0.07758109757560305, 0.08955378012615256, 0.07559898440376855, 0.11481528475997038, 0.11034897324861959, 0.0977398396935314, 0.09584404571796767, 0.09304581501055509, 0.15784333721967414, 0.11726057229680009, 0.29106073023285717, 0.09924042518832721, 0.23795348854037002, 0.1849661036976613, 0.09409853664692491, 0.10502500619622879, 0.1201867863710504, 0.10188898697379045, 0.11284988475381397, 0.27602731192018837, 0.14122345950454473, 0.13853171956725419, 0.15944692539051175, 0.09841569873970002, 0.22061461815610528, 0.12553453183500096, 0.13279395323479548, 0.20170131116174161, 0.1291610809857957, 0.12381434484268539, 0.11997098466963507, 0.17792240978451446, 0.11636622497462668, 0.22088611061917618, 0.1148333412129432, 0.17599852551938966, 0.18807279324391857, 0.13412371859885752, 0.08550944636226632, 0.2139808124047704, 0.12665579823078588, 0.14289051614468917, 0.10828914237208664, 0.21047967136837542, 0.1511110336286947, 0.1813298324123025, 0.15780238551087677, 0.17324054148048162, 0.18718598614213988, 0.1179953504470177, 0.15768577926792204, 0.18749688664684072, 0.17801731562940404, 0.16123930108733475, 0.17974758840864524, 0.08525946133886464, 0.11988883634330705, 0.08633145655039698, 0.2219232768402435, 0.3337267704773694, 0.2000619811587967, 0.09879387493128888, 0.17254991369554773, 0.14048172743059695, 0.1288402802310884, 0.11114530512713827, 0.15788405144121498, 0.07514818164054304, 0.16397686122218147, 0.22082299838075414, 0.27586433629039675, 0.09305856510763988, 0.1373636384960264, 0.1731475503765978, 0.19633126416010782, 0.22344374447129667, 0.17426172184059396, 0.36165889352560043, 0.15768628392834216, 0.09821447281865403, 0.17483666364569217, 0.1896599354222417, 0.14756975724594668, 0.14234870381187648, 0.13113397668348625, 0.12243871475220658, 0.11326744672260247, 0.1033399227890186, 0.17534732061903924, 0.2864740794757381, 0.12042393223964609, 0.2432582265464589, 0.16051278304075822, 0.17829934658948332, 0.1441663719015196, 0.09547056732117198, 0.1963368005817756, 0.08447386833722703, 0.1472188698244281, 0.17913917574333027, 0.13955114845884964, 0.1743387567694299, 0.10880562520469539, 0.11967339087277651, 0.07374556706054136, 0.10661168824299239, 0.08250094295362942, 0.07971754035679623, 0.1425884323543869, 0.05945357654127292, 0.1896931094233878, 0.09395480490638874, 0.17773816420231014, 0.20390139310620725, 0.43975806212984025, 0.16286077501717955, 0.1572235400089994, 0.19576610386138782, 0.13952190784038976, 0.06752282206434757, 0.11139018417452462, 0.16892766900127754, 0.11425274424254894, 0.16748632915550843, 0.10240020797937177, 0.1558084721909836, 0.1581564493244514, 0.14970666758017614, 0.14712500298628584, 0.15010200964752585, 0.07919028153992258, 0.18814665178069845, 0.1484118722146377, 0.10645902104442939, 0.16279608942568302, 0.17582861823029816, 0.0827917609422002, 0.1629095192765817, 0.12231899148900993, 0.17218079912709072, 0.13788398791803047, 0.1088619913207367, 0.11912140369531699, 0.17682607955066487, 0.15831273078219965, 0.2299774790299125, 0.12827310129068792, 0.1498058481956832, 0.15231497527565807, 0.16333043575286865, 0.12284258409636095, 0.13524038367904723, 0.16361401038011536, 0.0980134992278181, 0.10242458753054962, 0.12962606619112194, 0.14449630107264966, 0.1400090238894336, 0.08388481830479577, 0.10908499185461551, 0.18199187266873196, 0.15562746237264946, 0.09334270376712084, 0.1206801513035316, 0.0956608094566036, 0.15418431168654934, 0.09802112108445726, 0.17255504935747012, 0.08487280982080847, 0.09372539963806048], [0.005233663914623321, 0.052028537465957925, 0.019727441140275914, 0.04687792497861665, 0.04625348934496287, 0.06173929861688521, 0.03494734817650169, 0.04082779611053411, 0.023159208067227155, 0.05289953311148565, 0.06961947830859572, 0.03309659143269528, 0.03530371264787391, 0.021916290679655503, 0.020772759853571188, 0.026999384426744655, 0.021556937208515592, 0.01904990669572726, 0.07506949914386496, 0.03468670962320175, 0.020479617087403312, 0.05605881866358686, 0.06185946716868784, 0.042101358631043695, 0.010759012275229907, 0.027497202245285735, 0.022075379310990684, 0.029923069632786792, 0.02621751144033624, 0.006433901316995616, 0.026520730716583785, 0.014228341151465429, 0.048656812141416594, 0.028858674013463315, 0.07250649956404231, 0.06430730398278683, 0.04633688819012605, 0.026412263978272676, 0.08131450114888139, 0.024204981345974375, 0.04767872087541036, 0.0482021761854412, 0.036959006247343495, 0.05101693081087433, 0.025907720446411986, 0.02839647000655532, 0.05401907030318398, 0.07517052028561011, 0.01849132553616073, 0.07606969156768173, 0.02679895631445106, 0.04103312239749357, 0.029152863207855262, 0.04787124882568605, 0.02375264975853497, 0.05307329956849571, 0.05261988073471002, 0.04948366855387576, 0.061834831576561555, 0.058772926931851543, 0.05604419464361854, 0.04304760062950663, 0.03723056550370529, 0.027383238048059866, 0.04953031624609139, 0.08591304111178033, 0.04204411307000555, 0.04699663149949629, 0.055781578266760334, 0.08101137093035504, 0.0013586117165687028, 0.02766003872238798, 0.03898203773132991, 0.013947108000138542, 0.08513725188095123, 0.024712257836654317, 0.0640096582355909, 0.04602533459546976, 0.020622181800717954, 0.06279429493588395, 0.026852587616303936, 0.05288009255309589, 0.026825386048585642, 0.06616458049393259, 0.06166941799165215, 0.038640787097392604, 0.04534439925919287, 0.03876546419633087, 0.016917927932809107, 0.06792267638957128, 0.01493969619332347, 0.029261632371344604, 0.03778092737775296, 0.04883320951194037, 0.0711311811755877, 0.05560235702432692, 0.057297329549328424, 0.020819795317947865, 0.04752320754050743, 0.04061198327690363, 0.07229997470858507, 0.02177766120439628, 0.022749065719835926, 0.0150213565575541, 0.00683764867062564, 0.04359274149464909, 0.014643618233094458, 0.030660838638141286, 0.04095523770956788, 0.024742724854149856, 0.019356591801624745, 0.02077075419947505, 0.032327563167200424, 0.03558803684427403, 0.016656745756336022, 0.025453603993810248, 0.015473017429030733, 0.04742178934975527, 0.04269039010978304, 0.048627768192091025, 0.025871902544167824, 0.06468076753662899, 0.023228784411912784, 0.017657977186900098, 0.04614113931893371, 0.003311484269943321, 0.03941073933674488, 0.011885873536812142, 0.009720965681481175, 0.009366676440549782, 0.014206008072505938, 0.06824835305451415, 0.02096821743180044, 0.018602174568513874, 0.04325549103668891, 0.027079669962404296, 0.024786207286524586, 0.028273913594603073, 0.057110033740173094, 0.05009931715903804, 0.05114434643473942, 0.025214213128492702, 0.03092020626354497, 0.04583051711961161, 0.036702134093502536, 0.053565532725770026, 0.03733418787305709, 0.04642148189304862, 0.03921888674085494, 0.0347660414990969, 0.03419072862016037, 0.03171407792251557, 0.03750016177946236, 0.05223471722274553, 0.04433515634445939, 0.057861443419824354, 0.04813658517377917, 0.013879993730370188, 0.023931845025799703, 0.08127419510856271, 0.038579853062401526, 0.04359025158919394, 0.043886149578611366, 0.10122089821379632, 0.06789011837099679, 0.024514093274774496, 0.062107849153107964, 0.018548411535448395, 0.02104597780999029, 0.026061933167511597, 0.052497136930469424, 0.043586722676991485, 0.025042738052434288, 0.04236695102008525, 0.019955809257226065, 0.008004925439308863, 0.025888385644066148, 0.05149939730472397, 0.007219380677270237, 0.01892556727398187, 0.026620831595209893, 0.04140428529353812, 0.018212409740954172, 0.05277681899315212, 0.003191333807990304, 0.04752615015604533, 0.04268441211024765, 0.026081666874233633, 0.032823800211190246, 0.08059544910793193, 0.04640506187570281, 0.02512501068849815, 0.07111337705282494, 0.041690112338983454, 0.0908352316764649, 0.005509848142537521, 0.024659010596224107, 0.07913281704531983, 0.034342327126068994, 0.053895068558631465, 0.03169848911056761, 0.023682377650402486, 0.04391747192130424, 0.009931060267263092, 0.031973250734154135, 0.057371692746528424, 0.0635165827407036, 0.020359400296001695, 0.0200276862597093, 0.03588088831747882, 0.018095426858053543, 0.06574673650902696, 0.01193162508570822, 0.03512730785587337, 0.08787186568952166, 0.027501343429321423, 0.03525465297570918, 0.04648550326237455, 0.01635496439121198, 0.041968584700953215, 0.047279104037443176, 0.01802428643713938, 0.0975698878755793, 0.02591711418062914, 0.030187552511051763, 0.10294941210304387, 0.017408665662514977, 0.03597258808440529, 0.030393181223189458, 0.06813711253926158, 0.06263241768465377, 0.0680088100489229, 0.08461445337161422, 0.024164849710359704, 0.08030164026422426, 0.011511929442349356, 0.02235535081126727, 0.030369855521712452, 0.012778132640960393, 0.005214618549871375, 0.028543381849885918, 0.060092216881457716, 0.07729417586233467, 0.022717299943906255, 0.04462423028599005, 0.02448036080750171, 0.05184049950912595, 0.03971556907345075, 0.009510946238151519, 0.024061726435320452, 0.04388101020595059, 0.04261696944013238, 0.06952815703698434, 0.033522053563501686, 0.11134966291137971, 0.038202393043320626, 0.04296705905289855, 0.024581812394899316, 0.05933946020377334, 0.1128894041175954, 0.04388810513773933, 0.023577078027301468, 0.07031595421722159, 0.05302929763274733, 0.022247744964261074, 0.05307325132889673, 0.004965622438248829, 0.009023850598168792, 0.06317186998785473, 0.060461205284809694, 0.02222269933554344, 0.062408482044702396, 0.07660191535251215, 0.026297359108866658, 0.07325096274144016, 0.03191472125763539, 0.04826204523851629, 0.08075656194705516, 0.05677472028764896, 0.004565573763102293, 0.044093342366977595, 0.12222456804011017, 0.044422076680348255, 0.02877832539525116, 0.0290653231786564, 0.015206498283077963, 0.04710466593678575, 0.10774476220831275, 0.003847689908980101, 0.04486604426347185, 0.028462625050451607, 0.024435841223748866, 0.05548569512029644, 0.09822126346989535, 0.05179565152502619, 0.014572737563867122, 0.07395272274152376, 0.01323454232988297, 0.044535332126542926, 0.0518150586867705, 0.013522157951229019, 0.03130652752588503, 0.03747331087652128, 0.05228877525951248, 0.03505899687297642, 0.023813418665667996, 0.046582179129472934, 0.06815701693994924, 0.02161958189390134, 0.04945488064549863, 0.012857335568696726, 0.07498061953810975, 0.06768709645257331, 0.028753532096743584, 0.029914514525444247, 0.04120102588785812, 0.08725599444005638, 0.010974467022606404, 0.03946048178477213, 0.020891852291242685, 0.10540176488575526, 0.01434596320905257, 0.06495441222796217, 0.08843680334393866, 0.04284234113583807, 0.03922533229342662, 0.07173131889430806, 0.05035615591623355, 0.03604833167628385, 0.04247949029377196, 0.05425367802672554, 0.06739379226928577, 0.062222355118137784, 0.042096642282558605, 0.08453164453385398, 0.011158277520735282, 0.027215414338570554, 0.03643376607215032, 0.013842321386619005, 0.037605951220029965, 0.05003483565815259, 0.049778842949308455, 0.020063489318999927, 0.009545167595206294, 0.03481024752545636, 0.06707725886371918, 0.0255533189556445, 0.022630381463386584, 0.022222636252990924, 0.06757415641914122, 0.03769302740693092, 0.03645833487098571, 0.15265213296515867, 0.07591902074636891, 0.14527576393447816, 0.08403951898799278, 0.20871217246167362, 0.1015242213907186, 0.15412925917189568, 0.10637887651682831, 0.2081776925479062, 0.16558585222810507, 0.2885398920625448, 0.1694277726346627, 0.16121933731483296, 0.18314387882128358, 0.12003831972833723, 0.10040273235063069, 0.1365565083688125, 0.10368114744778723, 0.17940391466254368, 0.1193899720965419, 0.2137617304106243, 0.18741042644251138, 0.126866775972303, 0.14064491086173803, 0.1251269443309866, 0.0713656256266404, 0.14868003985611722, 0.08405200191191398, 0.1372312245075591, 0.10304040682967752, 0.15168392710620537, 0.20223375759087503, 0.15538987121544778, 0.13082485733320937, 0.19260767177911475, 0.19905108696548268, 0.12581062561366707, 0.14771374873816967, 0.12796341790817678, 0.1261518948012963, 0.14669279102236032, 0.09134259351412766, 0.1410920251510106, 0.20194280601572245, 0.11933051122468896, 0.11709359649103135, 0.1965888636186719, 0.15837254788493738, 0.09673067470430396, 0.1561007893178612, 0.10395847319159657, 0.11824725763290189, 0.13533374585676938, 0.10975416415021755, 0.14177876408211887, 0.16229309141635895, 0.15605961496476084, 0.13914874114561826, 0.20567030209349468, 0.1648251953884028, 0.12400108404108323, 0.08711117916391231, 0.1508413816918619, 0.12899072840809822, 0.16677710314979777, 0.2132510140654631, 0.145800284226425, 0.11719668080331758, 0.19243774964706972, 0.11376651134924032, 0.10202034711255692, 0.08298785862280056, 0.09413850129931234, 0.10387617643573321, 0.13232656347099692, 0.08901057997718453, 0.14409707015147433, 0.18160352163249627, 0.2411021539592184, 0.11325667073833756, 0.19307737704366446, 0.07869242661399767, 0.15661266341339797, 0.29209219675976783, 0.18004585755988955, 0.14651941048214212, 0.23155715520260856, 0.11356605726177804, 0.08371805772185326, 0.14492052752757445, 0.11280835416982882, 0.09908467807690613, 0.19855098333209753, 0.10577298715361394, 0.1357820921111852, 0.12253350927494466, 0.30131290666759014, 0.17164802615297958, 0.30533600016497076, 0.13952673180028796, 0.14417266531381756, 0.12831633881432936, 0.14647525269538164, 0.08982783299870789, 0.08343431982211769, 0.169723117724061, 0.12323615985224023, 0.1138393086148426, 0.11090641521150246, 0.1097807553014718, 0.15188770601525903, 0.1534600052400492, 0.07710537349339575, 0.13637589931022376, 0.09411132385139354, 0.13379013806115836, 0.15009056573035195, 0.24437561893137172, 0.22908054903382435, 0.1284035708522424, 0.12468735541915521, 0.14907223521731794, 0.0792391668073833, 0.09488241528742947, 0.10396334910183214, 0.10494466128875501, 0.10950720708933659, 0.14430737996008247, 0.08626281531178392, 0.13472401216858998, 0.13633356720674783, 0.1468848588410765, 0.08955927201895975, 0.10773629430332221, 0.13502999965567142, 0.1752507226774469, 0.12367733696009964, 0.1400172320427373, 0.1349056008621119, 0.1810435118386522, 0.1513895913376473, 0.08277816479676403, 0.1982238149503246, 0.1999132992932573, 0.20977117266738787, 0.21968280721921474, 0.13281943858601153, 0.10902008361881599, 0.1021856976149138, 0.17971355351619422, 0.1761209502001293, 0.13404169643763453, 0.1103646845149342, 0.19529947108821943, 0.12472970236558467, 0.15555103600490838, 0.13699712144443765, 0.08259739246568643, 0.1627684963750653, 0.1232708033057861, 0.31702123407740146, 0.12570151506224647, 0.10070968462969176, 0.31534617708530277, 0.12646938557736576, 0.14718854567036033, 0.15802813199115917, 0.16081798385130242, 0.12920820736326277, 0.18295650137588382, 0.12920810346258804, 0.1830721428268589, 0.09797491497010924, 0.20390008692629635, 0.06845340845757164, 0.13476716063451022], [0.024021630051720422, 0.030232688077376224, 0.034862936299759895, 0.051560717256506905, 0.011154273634019773, 0.05639859984512441, 0.07849464425817132, 0.07182125234976411, 0.05831727794429753, 0.03767717884329613, 0.019275241284049116, 0.059919162886217237, 0.029476597301254515, 0.031325801101047546, 0.0768073566723615, 0.043655942790792324, 0.021052881638752297, 0.0202049408107996, 0.019544104688975494, 0.03073498661251506, 0.008859870285959914, 0.04766103549627587, 0.03148505486024078, 0.03203827771358192, 0.05832098868268076, 0.02302902052178979, 0.014559738847310655, 0.043126442687935196, 0.054129494455992244, 0.06128401328169275, 0.039197535152197815, 0.028085851517971605, 0.052007237827638164, 0.03260395009419881, 0.010195512531936402, 0.02425840670184698, 0.027168788910785224, 0.07279791127075441, 0.022459874890046194, 0.10466796637047082, 0.0675825055805035, 0.021979432603984606, 0.05038488445279654, 0.03869472639053129, 0.021993028749420773, 0.05499190345290117, 0.06151508838229347, 0.029712067771470174, 0.012351837449386949, 0.04916074525681324, 0.016161328785528895, 0.03134259219223168, 0.08791418295004405, 0.01817822085286025, 0.0280752517937799, 0.04863300775468815, 0.033848387029138394, 0.02216235159721691, 0.06013657133735251, 0.006634904129896313, 0.046913518381188624, 0.05083780975837726, 0.027526602425496094, 0.046435783078777604, 0.0403111945342971, 0.010871128524740925, 0.023101788101485, 0.04852152233070228, 0.06236890330910683, 0.06385837885318324, 0.09347637940663844, 0.034974321533809416, 0.06876295825350098, 0.07136530650313944, 0.0361637170863105, 0.049893096584128216, 0.03702724301547278, 0.059035034937551245, 0.020025287267344538, 0.035717994323931634, 0.05843988816195633, 0.09270059017580934, 0.05357170739443973, 0.07117715722415596, 0.07802749198162928, 0.14318448083940893, 0.0031705249148217263, 0.012216859340696828, 0.10245540150208399, 0.07119404108379968, 0.023223440948640928, 0.03443668378167786, 0.028520802006823942, 0.05172667260922026, 0.004838300510527915, 0.07009822293184698, 0.04703070721006952, 0.05573881200689357, 0.054879776071175, 0.13540824264055118, 0.05247724366199691, 0.03921088267816231, 0.04110061330720782, 0.05519773068954237, 0.0496563106571557, 0.05710166231438052, 0.007786804526404012, 0.023901008789835032, 0.07717756961937994, 0.027896366373170167, 0.021228022924333345, 0.029504730264307, 0.029107586633472238, 0.026323746169509832, 0.026994373074558098, 0.036138970172032714, 0.01685336850641761, 0.04757824521220755, 0.019403285878070164, 0.04148710155277513, 0.026240980005241, 0.029645760587300174, 0.012310146375966724, 0.0487142877682345, 0.04407573120261077, 0.07582787016872317, 0.011291010632703546, 0.040659785008756444, 0.06507078098366037, 0.0664480883278884, 0.0844825069361832, 0.07431020043441094, 0.05302820667566266, 0.02593219276604941, 0.052800074190599844, 0.12782000529114157, 0.007356923833867768, 0.017393293928762432, 0.07301446996279992, 0.04557459491479676, 0.06259581496124156, 0.12964233406819403, 0.09410751663381234, 0.011859531005029567, 0.028416203713277355, 0.04426666724612005, 0.07058534640236758, 0.04041323241835926, 0.0424600942642428, 0.06360627870890312, 0.03149620933982078, 0.02311087941052392, 0.048522442593821324, 0.028661524338531308, 0.009853500268945936, 0.0322546879760921, 0.01967448890354717, 0.034901149483630434, 0.03207462439604569, 0.0442542845121352, 0.04107579959963914, 0.014470774822257226, 0.047396775262313895, 0.04938365673297085, 0.02320613777555991, 0.010861772825592197, 0.021361590952437837, 0.010770030385174323, 0.0242530020113918, 0.030919443706807215, 0.04865991802944336, 0.03286677798314486, 0.05266302548989188, 0.05219319777097553, 0.04776030888024252, 0.014816097991570132, 0.08059739353484474, 0.05713358950742986, 0.023574009246658534, 0.04239868896547705, 0.044312806567177176, 0.032961219985736534, 0.06835280291852541, 0.06731507266522385, 0.029041563320788555, 0.08571054611820728, 0.026526803339947946, 0.02288409392349422, 0.014759506448172033, 0.051285265435581096, 0.06847288983408362, 0.075424883980304, 0.09406172612216324, 0.02364359486819012, 0.013718776062887628, 0.023092305309546646, 0.07205741116194986, 0.0303379747128929, 0.03482187326881103, 0.08428919230937026, 0.04231801380228717, 0.03541060046700295, 0.008155884770530974, 0.08696836026501842, 0.03716090381203685, 0.028735757659887895, 0.023256945205503143, 0.0536211344297044, 0.06732633846695535, 0.02508327230316354, 0.01379757637550938, 0.023585623857798055, 0.013054347946308553, 0.031024606032588053, 0.04469080835406203, 0.0520958020206308, 0.06022825255058706, 0.011073430559918052, 0.04334795521572232, 0.0425697577156825, 0.048826070051291026, 0.08310623859870248, 0.014194393461366417, 0.05251819908153266, 0.008539550071873236, 0.0374534547154326, 0.01743188375257887, 0.010426531971461372, 0.004565187846310437, 0.07608375526615418, 0.02172841785068158, 0.022019896350684576, 0.05195779594941996, 0.02519561861845432, 0.021603852073894814, 0.05779406754299998, 0.08436687290668488, 0.0360849937715102, 0.011565289860300254, 0.07338408919167705, 0.03150278476823587, 0.06243748517590575, 0.010825068056874443, 0.02076748318359023, 0.04821581685973797, 0.016712082142475992, 0.06395146643626504, 0.03987140524259303, 0.14152710180496797, 0.055815535233705305, 0.0070205778683885, 0.042705878731794655, 0.051218624284956604, 0.09443209492019378, 0.039145009650383145, 0.04478755472518969, 0.06710209112497978, 0.035289812221890315, 0.03828392909781542, 0.07106034317985177, 0.026776092599902768, 0.10527479083975777, 0.06456960123614408, 0.009122686115006218, 0.018550279892224353, 0.07508337730541825, 0.06242222661967389, 0.029087834373058286, 0.04089348360139411, 0.0128563012003724, 0.03002103498147335, 0.025209370614902582, 0.04460150943486951, 0.08376088706427254, 0.03901557167409919, 0.09923621721100062, 0.04084269101440441, 0.043068054219475016, 0.019215236789023038, 0.04674449053709395, 0.10116539298905991, 0.017446969759475905, 0.0046662493423355045, 0.025904291724145878, 0.009489250478509348, 0.017334528820356354, 0.051688006715266965, 0.057258771266788244, 0.01815363906644052, 0.06831213322584517, 0.043481111351866275, 0.041761172979022376, 0.010340820408600848, 0.055950431706150994, 0.02857783234503586, 0.04540588990494143, 0.03285320410213899, 0.03128739866951946, 0.00816966274214792, 0.032339441240765154, 0.0403682063188171, 0.020612012522178702, 0.06351967749651521, 0.07918351315311156, 0.05974430918286089, 0.030492590049107093, 0.052110589313087985, 0.013859590235369978, 0.007297197180378134, 0.0270082271163119, 0.03531995083903894, 0.1036709280742798, 0.0610912107367767, 0.04407876287586987, 0.05867883002792951, 0.02423497338895686, 0.018287659804627765, 0.06187115970533341, 0.03562635763955768, 0.02416879236989189, 0.014808836076554144, 0.08669756542076357, 0.05929247854510322, 0.025531030405545607, 0.03597133756557014, 0.04619412124156952, 0.01889637303975178, 0.055102386977523565, 0.0348677825240884, 0.01766891458828468, 0.02482735195371788, 0.033675425802357495, 0.04033039389469195, 0.03772701777052134, 0.02126978728483664, 0.02438737341435626, 0.037507731685764156, 0.03533360635628924, 0.029030607365712058, 0.04369058624433819, 0.009927490536938421, 0.10794398433063179, 0.04719445096270647, 0.05695642772479914, 0.027949552386417054, 0.017385011560691055, 0.0332376328879036, 0.031532719294773415, 0.02553881367930444, 0.029754038077953737, 0.0431058369576931, 0.021854796323168557, 0.12903022550744936, 0.1592057422385551, 0.10862380644539371, 0.09858381003141403, 0.12645380047615618, 0.13325507927220315, 0.1898476097267121, 0.13895024632802233, 0.1676820038119331, 0.1931572618195787, 0.1539722058805637, 0.1321495315642096, 0.13109773019095883, 0.14233530062483624, 0.1589328990667127, 0.1953185145976022, 0.19273425248684362, 0.11001002698321827, 0.08727960215765052, 0.11944231577217579, 0.1677958047366701, 0.13818129227729514, 0.17216319538420066, 0.20566798659274355, 0.20319170696893707, 0.1800864827237092, 0.10020097950473428, 0.15378514013718814, 0.10113272364833392, 0.1596525448258035, 0.12090178628568538, 0.10616536063025706, 0.25339640909805894, 0.1712322750245221, 0.1341615681303665, 0.18026027886662632, 0.11558535203221254, 0.11208583629922941, 0.12072825731593184, 0.22723377391230315, 0.14626010408392176, 0.10555163418757729, 0.14352074795169756, 0.09767628216650337, 0.11891455229488201, 0.14346004027174786, 0.09142767332377844, 0.06621571446885355, 0.11658606395940296, 0.217196271114517, 0.10793934590765275, 0.1422351849032566, 0.16682995890732855, 0.15896432159934193, 0.16327927209204063, 0.2375988755375147, 0.11532205287949182, 0.07770472453557886, 0.12424641579855233, 0.1395065602264367, 0.19400087592657655, 0.12230739172082394, 0.07807518981280737, 0.1317642381764017, 0.19957986718509346, 0.10128952460945584, 0.09064900455996394, 0.20433595025679097, 0.11318572142045014, 0.10766741557745263, 0.1573565774015151, 0.14070395613089204, 0.2084649630705826, 0.2611243928549811, 0.13986857986310497, 0.17979027674300596, 0.12854085332946852, 0.13475359417498112, 0.1210605316737201, 0.10265250850352459, 0.14117438870016485, 0.15425702731590718, 0.2939431130653247, 0.19874217541655526, 0.21367377106798813, 0.23026194423437119, 0.1397225252003409, 0.0927307881647721, 0.16720406070817262, 0.24537826044252142, 0.184725291619543, 0.13838652579579502, 0.1705764391226694, 0.1432144339196384, 0.07400663977023214, 0.14395546837477013, 0.15880324586760253, 0.2769750345032662, 0.15946043247822672, 0.3279579378431663, 0.1718558868742548, 0.16849863342940807, 0.10311456222552806, 0.17820815148297697, 0.29779180185869336, 0.15914221439743415, 0.11967399943387136, 0.08952004951424897, 0.14151316427160054, 0.1314332551555708, 0.1536257565021515, 0.16062921116827056, 0.12574895314173773, 0.16800234443508089, 0.15634850336937234, 0.11477007312350906, 0.11036057301680557, 0.2354135029600002, 0.11155503001646139, 0.16321182571118698, 0.12966784910531715, 0.10402843545307405, 0.0903442119306419, 0.12907834636280313, 0.101741069520358, 0.17962860729312524, 0.10547990561462939, 0.11710332604707219, 0.1372658382751979, 0.14333982719108462, 0.16864344128407538, 0.1252544898306951, 0.1062651423853822, 0.15683141886256635, 0.238160117296502, 0.27225565805565566, 0.1322653511306271, 0.12503463600296527, 0.12258455419214442, 0.145266902691219, 0.14243603975046426, 0.2013419335708022, 0.2510516974143684, 0.06342264168779366, 0.10479859178303741, 0.24826548207784072, 0.19688909203978255, 0.15506104042287916, 0.07485723748686723, 0.12320602123509161, 0.10884252478717826, 0.13921976467827335, 0.13259735831525177, 0.16793295362731442, 0.1495885621989146, 0.1451071331393905, 0.13825132133206353, 0.14943229558411986, 0.11233329802053049, 0.1632553749368526, 0.10852513049030676, 0.1696403237292543, 0.09169781507807784, 0.17397102259565145, 0.08358802602742799, 0.11915856302948669, 0.08755400383961387, 0.11459204673883505, 0.13076156697934493, 0.08724852101295255, 0.1309621991822496, 0.2204914067988284, 0.22404261311748996, 0.15985771897248924, 0.15175079461187124, 0.12393633907777257], [0.0502407927706372, 0.0376901998242829, 0.07466800467227586, 0.037163341767154634, 0.009729821358632762, 0.02054833068541484, 0.007783517739881063, 0.04438724397914484, 0.1049921364756301, 0.015390328262583353, 0.05169527605175972, 0.10065302165457979, 0.020218646423018072, 0.05944739074038807, 0.04893659810477402, 0.03794452641159296, 0.052477251083473675, 0.07567338470835239, 0.035574214343796484, 0.015865623754507396, 0.08117344856145792, 0.03451041615335271, 0.03213530610082671, 0.04591108838212676, 0.07255234202602878, 0.052490528105408885, 0.06905449612531811, 0.04090161753993016, 0.0488071972358739, 0.02665730815351708, 0.028791756412829272, 0.04457173818082083, 0.02622834679641528, 0.07778374099871144, 0.018108995172951836, 0.05368830250517931, 0.055720518066664226, 0.037521134872804396, 0.025013920458150096, 0.02194165914261248, 0.02289612228196347, 0.02706699408008717, 0.018708646784943994, 0.02189855706092203, 0.07575849420391023, 0.022954180494707543, 0.1163032092154026, 0.053649992842110805, 0.018899080023402348, 0.04034643170598429, 0.08101090337731875, 0.0572171516250819, 0.015545448259217665, 0.024978390138130635, 0.08202700002584606, 0.07573179915198125, 0.009147695564024616, 0.019255136503488757, 0.050221990459249355, 0.05341706237231847, 0.06408740562619641, 0.01104177332308609, 0.06412463175365701, 0.09405873526702635, 0.03041627314814832, 0.059249816185911186, 0.010113061780430144, 0.01227020584337879, 0.02476262739946833, 0.017037460092979018, 0.047191656776703894, 0.049613581504672766, 0.08099292856059037, 0.007854549621697515, 0.01000411821223679, 0.10947999995551072, 0.0773452727298718, 0.03898482449585572, 0.06108841655077413, 0.05967842873360496, 0.07339424177189358, 0.14198083605151623, 0.010018742232205113, 0.08501412215991877, 0.013447342043946264, 0.07264750020112842, 0.03355685286805965, 0.0021861281766177854, 0.05041951677412726, 0.050781202444341034, 0.048235732392640784, 0.082153165130876, 0.030247299109760206, 0.02832216432580026, 0.02479090322594857, 0.07818702404620126, 0.029455496187438257, 0.044447576874517836, 0.10008370532887056, 0.027666194837365765, 0.03426172617764678, 0.02458816146827303, 0.05303871919750236, 0.04551402082142886, 0.029625917413795833, 0.005136664285601, 0.02517894627089845, 0.05865410537808202, 0.010434840314701432, 0.05081642848381307, 0.017314618853561115, 0.08592055906774476, 0.059751982989837416, 0.008313015987368999, 0.06780283438274637, 0.07183595429523848, 0.043194824174861424, 0.03730943353730254, 0.015162158670136705, 0.06623777851928025, 0.018034216373052914, 0.014689609124616254, 0.03490796239930205, 0.03728618576133158, 0.039206967849167995, 0.023664465916226618, 0.038994483547867276, 0.004436300914676394, 0.023355159173661377, 0.0160991590746562, 0.022438209743995685, 0.04163010969932657, 0.02514625281037297, 0.059957914127153344, 0.016072990947577637, 0.02292700119141955, 0.01999509855522774, 0.1068047431181185, 0.05280211509671062, 0.018921236842288636, 0.02596900514618028, 0.025141553160210606, 0.029027174932707567, 0.017743402095220517, 0.03176852558681276, 0.04858317624893971, 0.049335431976942345, 0.04156518290983513, 0.02618127236928558, 0.04517144916462712, 0.012016831988148624, 0.025800122020882554, 0.060609070787904784, 0.07081844756612554, 0.012244123063283041, 0.06043835084710736, 0.04453446752449963, 0.05926369434746448, 0.025808385835262015, 0.017702314944472164, 0.009644321307860082, 0.01199084104882786, 0.020777155223186128, 0.06567282602190971, 0.010895586001424817, 0.009158795310213463, 0.02406671552307671, 0.0697340807528235, 0.030823062843410298, 0.03150115946482401, 0.04650728158594575, 0.03630134466220625, 0.02534121129428968, 0.03277316347521264, 0.01019339926642715, 0.04159594122029375, 0.04986358508176636, 0.04335138393798843, 0.029255368644953705, 0.019040099214180373, 0.03137263061944395, 0.04399823614221532, 0.0220207980601117, 0.05162289809959475, 0.03402702568564564, 0.04492194282647688, 0.052913192339474335, 0.03356159519171342, 0.0201215697961743, 0.06162695601233281, 0.09056546099600382, 0.05226556088018697, 0.08449202869087458, 0.028846714303654153, 0.06970129266846925, 0.025054183824977372, 0.1308965339558199, 0.09136914755799808, 0.05871927336556837, 0.04668550092901569, 0.10052557263406925, 0.002027848718171299, 0.027145136664330494, 0.01744627399602905, 0.030796484679740388, 0.035554888818296604, 0.028381912779877894, 0.01179275812319247, 0.016413764751632698, 0.01687821561063174, 0.04888728981313761, 0.037743545399280265, 0.0888468993071001, 0.07165170871303417, 0.03722089903021697, 0.0028929064865224063, 0.016324848038493656, 0.03637004527263343, 0.03721302484336775, 0.07330142878345214, 0.03822610837232787, 0.02103714254189981, 0.09137825370999053, 0.03203619227861054, 0.04094211653864477, 0.12795267160981894, 0.051693524583242834, 0.01763008356647333, 0.031704845605418086, 0.016501219433848746, 0.04371816816274077, 0.06313377554761246, 0.06306621784460731, 0.0055635865919612115, 0.021653362600773107, 0.10223160687019117, 0.03522629922372289, 0.04489753358939197, 0.0682651626993902, 0.0535429194860626, 0.035032420564675704, 0.07549843823653646, 0.03472041425993666, 0.015706043450336438, 0.019184469201718457, 0.015005102595750941, 0.023319652973441407, 0.01130121701862663, 0.06245813172427006, 0.016538684903935064, 0.05317699244187679, 0.04229682919685729, 0.06322120796539821, 0.025592320671421476, 0.023015029182715807, 0.040078538659145124, 0.04088416593731381, 0.05951095197815448, 0.06119609846791718, 0.06822580660809763, 0.08160945290001109, 0.013115648416714976, 0.0843587686540559, 0.03386187927389983, 0.028753587757819332, 0.013294507862156024, 0.05774676305009052, 0.015507338976021856, 0.12482632999308407, 0.010215485581284156, 0.017577723192516714, 0.04438785996171646, 0.07265083244419657, 0.026882835700234864, 0.08378604587051086, 0.04184666839137208, 0.02787011475447798, 0.03916303641744889, 0.015131445816223277, 0.049898339857463725, 0.06007776355545502, 0.013658804964506999, 0.00772125897128717, 0.059122066595591605, 0.04086492946953513, 0.060563514052773826, 0.028692082269117236, 0.02717725310503738, 0.033552715394762345, 0.019856398575939238, 0.062341198936337605, 0.048870079408516176, 0.015269981595338322, 0.12004526623059064, 0.04759477284096647, 0.020996845778427087, 0.04584359747241251, 0.05057213202235289, 0.018057835222862195, 0.03132588273729198, 0.02984986233059317, 0.03157765262585599, 0.02703926929825684, 0.10005298783653416, 0.01132945944846142, 0.05303678961354308, 0.061884395909146406, 0.057488595848553814, 0.044024029484717175, 0.043500173414940946, 0.06355766061460599, 0.012893256443931023, 0.03539651079336181, 0.04117009688343387, 0.025721586098370608, 0.04651589049899485, 0.010926007562375162, 0.03789178568695206, 0.017832793782872614, 0.04369750677142292, 0.05153191821591463, 0.025913746685546357, 0.027727329252229538, 0.02484087202901719, 0.04019040257844608, 0.11860193742904812, 0.049481275127618574, 0.03145021102682222, 0.03501875762594864, 0.0558515887678368, 0.0536031633237144, 0.006494465205832967, 0.012884355310234241, 0.05005437269574031, 0.07500413077650592, 0.011285059536021436, 0.05263854574877769, 0.08915237471228465, 0.0785710928903427, 0.036392331967363134, 0.055849388299975544, 0.061976533543202095, 0.02392766487901099, 0.05529721558559686, 0.02524814412026899, 0.03150803175230976, 0.05371896804717835, 0.03700098211993463, 0.02526756241422845, 0.005867575382580981, 0.029605140989588108, 0.02144677837350173, 0.15368722117273137, 0.08705971864401363, 0.16922675451496616, 0.0730698712868616, 0.1470334961777553, 0.13678957242518663, 0.1490800129249692, 0.13925130595453084, 0.16782494145445526, 0.10326793446438387, 0.1747827243525535, 0.21080770064145327, 0.11156435881275684, 0.146724866644945, 0.1735399238532409, 0.1870217637042515, 0.1560243926360272, 0.0977681229414884, 0.13020574289839715, 0.24908803403377533, 0.15739782596938312, 0.2265824205824174, 0.13201253110310063, 0.15507546777371317, 0.22214743512449786, 0.13105830730637535, 0.1343128178268671, 0.17079860845115036, 0.19726485625142232, 0.15218403073959053, 0.09222845066688024, 0.0806496110453736, 0.11221027220017277, 0.1258910002070479, 0.13684946374269202, 0.13195133360568434, 0.1115099222806748, 0.18130832497263327, 0.1111491717165336, 0.09500355605268851, 0.11911052381037734, 0.09593764538294636, 0.12661174434470013, 0.15023932181065902, 0.19860369066009298, 0.15961554134264588, 0.3064205154078081, 0.13474882958689705, 0.17522691457998008, 0.1851995091419667, 0.19089776353212073, 0.12473393260734156, 0.13769085140665993, 0.1588865148369223, 0.14989040850196034, 0.1400298930821009, 0.12558756570797414, 0.11120572336949408, 0.13938121148385108, 0.29199548007454723, 0.14279201830504462, 0.10787235965835862, 0.22956103028263897, 0.1423036851338111, 0.1909958160831593, 0.19008049566764385, 0.12918520078528672, 0.09990383841795847, 0.1103892941318918, 0.11631201108684763, 0.14928934309864417, 0.13754444051301107, 0.1792990491958335, 0.175876768771559, 0.16640243731671944, 0.2851199865108356, 0.18676803825655952, 0.1459280078415759, 0.15629803732736036, 0.26702265604399145, 0.19743596581974998, 0.16243674152065068, 0.1855949402670376, 0.16159853024873883, 0.17891624942421913, 0.09516302132396959, 0.20215157215716317, 0.13430490653263405, 0.17306546884356067, 0.11102466902229935, 0.16338875371729955, 0.15679429663578048, 0.3113850677618757, 0.09405457924003713, 0.12337408799794503, 0.14157599449390545, 0.1914268554537557, 0.18469900474883616, 0.22408395074307919, 0.21623183536576107, 0.0994143623393029, 0.13287483248859644, 0.14034339110367, 0.1505712399375625, 0.20535181683953851, 0.08025463263038546, 0.08618593623396009, 0.1278074481524527, 0.13015774078667164, 0.16342854767572135, 0.15273333876393735, 0.15675192000344396, 0.09178763721138239, 0.2326992165762931, 0.18496355070965365, 0.20699530286947265, 0.18278962204931304, 0.1163032760086935, 0.16159174701897427, 0.23644384142244235, 0.12592766230227426, 0.1729062633239664, 0.09802647196920589, 0.08048572257393971, 0.09742017442476936, 0.26680502865929157, 0.13636510848300532, 0.15678157622460276, 0.08496531110722572, 0.12608481949428096, 0.12932172627188265, 0.1669341861270368, 0.2476670587202534, 0.10951439107884653, 0.16470110829686746, 0.12887707591289654, 0.06900503940414637, 0.14120373321929947, 0.12224275807966478, 0.1864265464246273, 0.1016170195362065, 0.09142238923232071, 0.12300269503612071, 0.13721652998356149, 0.14952432189602405, 0.11647656749119051, 0.1992223598062992, 0.07938075374113396, 0.0775815948145464, 0.21178945811698213, 0.12872492079623044, 0.11553035888937302, 0.06653833348536864, 0.1884202371002175, 0.07951759835123084, 0.13861835788702592, 0.14931855403119698, 0.115840873477282, 0.12649620679439977, 0.15414199442602694, 0.11609984590904787, 0.2064087538747117, 0.1413657737430185, 0.14528250263538212, 0.11694963468471542, 0.13795608014333993, 0.06820272581535392, 0.13358499360037968, 0.17410315456800163, 0.218351379444357, 0.18207668530521914, 0.09183058529742993, 0.11261676874710247, 0.0879125353822019, 0.1275773675297387, 0.12148472844273783], [0.07577274343930185, 0.009400345825270051, 0.03508130212139804, 0.0348646840575384, 0.019285074740764685, 0.047139201778918505, 0.027652654353005346, 0.03277570904174354, 0.08365860427147709, 0.06476909053162672, 0.03834136761724949, 0.06457565716118552, 0.037194638134678826, 0.013945731316198362, 0.07794962584739551, 0.026687014469644055, 0.04830354613659438, 0.045988965648575686, 0.019999668329546694, 0.08961485887994058, 0.05782336011179723, 0.016410786884080153, 0.026569597430352587, 0.02691747729841154, 0.09176575869787484, 0.023959029895195272, 0.056018898540060036, 0.03535744042892475, 0.030101062620815355, 0.0447880185674876, 0.05594235713942908, 0.02543191843869863, 0.03795297576289158, 0.07073137880070135, 0.025580370238458272, 0.054037631416576914, 0.01884714452899061, 0.01096837306249654, 0.01521623897133395, 0.027412970339355525, 0.017852158271125518, 0.0270191162780975, 0.07528291112976149, 0.028345031751086935, 0.031041645743243862, 0.022810376394772902, 0.031007221223262604, 0.08171851892257109, 0.031633291437174194, 0.00866300541019882, 0.03407457137655001, 0.053284065797924995, 0.012713689175143372, 0.020496237484621815, 0.008450563782389509, 0.09231093295966275, 0.06889654483529739, 0.04932281546643935, 0.03762671651202254, 0.026869682988035493, 0.04073047457495704, 0.02535725467168959, 0.03774133379920386, 0.04883009249169845, 0.04719802440376952, 0.046055443526711315, 0.07953863823786378, 0.021463780976773705, 0.009645015215937747, 0.05727882780774962, 0.021158322269911878, 0.007592733836645493, 0.048153016323340125, 0.038069607981015, 0.02393526076048147, 0.050669728152570315, 0.0186380444210954, 0.04491514846449718, 0.05179889471037313, 0.05705971612769645, 0.11976579567999579, 0.2654656895902008, 0.36440501804463565, 0.2898716612253338, 0.18379440094577149, 0.2283711449126713, 0.05973298772005364, 0.124866405967623, 0.0644560823275242, 0.07323307698243298, 0.02035046483797487, 0.033716381221893243, 0.32156261382624507, 0.06495283887488768, 0.042886023948085494, 0.0432435424590949, 0.2413869308657013, 0.1852318222518079, 0.30899600533302873, 0.1681683777133003, 0.06391000264557078, 0.07659034527023323, 0.045598284268635325, 0.0969426469237078, 0.046819280469208024, 0.08543997391825542, 0.05714366787287872, 0.023620810934517067, 0.04195787922071759, 0.007626106826137402, 0.01995995600736933, 0.029428333582472987, 0.022968982630118262, 0.045737897089566104, 0.025999548233812675, 0.03630289946158882, 0.005089280475658597, 0.04926086468913127, 0.04065031520440243, 0.028335784591035917, 0.04313364523113705, 0.03536173746397253, 0.05273607137496583, 0.06331450334982947, 0.027921194923692383, 0.01917219407914672, 0.0816700047289487, 0.05291146684612613, 0.0363203659071587, 0.036529722056002356, 0.056619860042701475, 0.038764154305681586, 0.04607804192346521, 0.06361638676025905, 0.02259840417536907, 0.038970211608102545, 0.02830703007930424, 0.05795815639430657, 0.03971953956352081, 0.054780625141575, 0.02823893060849514, 0.06096168370277155, 0.03090622976742452, 0.055312403637799434, 0.05325822421582416, 0.027520164294401184, 0.04777524089149665, 0.05387586177675985, 0.07870911751524545, 0.012496997824200662, 0.007952582691359567, 0.038419949923991226, 0.0031139612019615015, 0.05394192776293494, 0.029409380986180622, 0.05409928904555272, 0.08068766837823205, 0.09819611950661056, 0.08728363201953471, 0.06883048627059907, 0.014228788295440609, 0.019849977143167052, 0.014814328897045925, 0.06024114365573041, 0.025560027970641386, 0.03916127752745524, 0.033889045589603484, 0.039509021953563206, 0.026539872560533695, 0.05959237299975939, 0.05481425927428063, 0.014824999125266913, 0.05276368297927547, 0.017124122532550246, 0.03840639830741566, 0.04998787997465115, 0.02385923515248578, 0.023072809090081137, 0.032122344491654076, 0.06376946956152096, 0.06328427567495964, 0.029453531351464335, 0.014854444762022467, 0.051834814657922834, 0.059857813248527236, 0.058112270780839026, 0.055207170807989314, 0.041331450920552015, 0.0061052569890307495, 0.023507885744038504, 0.03386791664524935, 0.01792728216969408, 0.01781544979166938, 0.08297199150547385, 0.03413771330087911, 0.09323711841716431, 0.044547896686708555, 0.010353141915402375, 0.06156411094707437, 0.03480039180431049, 0.004575930433929898, 0.04638972910470329, 0.02892005148169119, 0.07865843625040725, 0.04035557867609896, 0.03899359668139368, 0.05555999894568231, 0.034275815851287916, 0.017270702264795545, 0.01633204872632632, 0.013403452358033974, 0.017860038024082314, 0.03475479425105732, 0.04688240383984521, 0.040533564242650755, 0.05003079837479163, 0.03382672002771869, 0.011791361957875779, 0.1250916626304388, 0.06496751855593175, 0.034139884082833305, 0.02706637438677717, 0.040437077623209916, 0.0629389172536321, 0.03167577197018545, 0.05528358604351524, 0.007616159264216549, 0.04676779768487904, 0.056365911950706504, 0.04327874994487502, 0.021930766270088498, 0.02840705117705511, 0.07302727943169884, 0.04701937832578551, 0.04678930883528665, 0.06302106557996012, 0.02910172366682673, 0.025725539890117943, 0.03403468836040702, 0.04012728662928566, 0.07910282685770653, 0.03323424498375971, 0.04864366870606318, 0.03738454259291757, 0.0019592805347201647, 0.036899378392263316, 0.026833883639483247, 0.02323828204680467, 0.05136278647114523, 0.09500246509560384, 0.05653170774166938, 0.039897257956909016, 0.014387517912837211, 0.06212080334080383, 0.07851876405766234, 0.04524737087194808, 0.12662062043091282, 0.1860352119547315, 0.19212787330616266, 0.10913585865637287, 0.18629745725775138, 0.2554564329329878, 0.07101849347236566, 0.10894997292780317, 0.1485015088110231, 0.055941080645425245, 0.030114267283352092, 0.059983481114613824, 0.2400030184071511, 0.07986063385033049, 0.08883232352673076, 0.07444038797984831, 0.4009391670115292, 0.28341809345874935, 0.28169812168926, 0.3725908772321418, 0.10648760857293382, 0.1154293748550117, 0.04152662462729495, 0.019604780827648938, 0.017090529217966832, 0.053070178837515414, 0.03189354407368228, 0.029627355324919336, 0.04745205042127054, 0.07285239975317381, 0.024254669988295063, 0.07895757371443324, 0.015741519964649342, 0.020476416575547773, 0.04995663184672594, 0.016227886444539763, 0.038989225431578234, 0.04337408252467867, 0.004894093781331321, 0.029568931604444515, 0.025560373069311026, 0.016431787807960063, 0.04765369936649222, 0.026944446944980882, 0.01905833192722639, 0.03192497773852665, 0.02910213741415646, 0.05378573165216949, 0.013924860268161865, 0.01718386913125869, 0.041301980236312374, 0.042258267203578725, 0.022593786161451135, 0.05740901535318699, 0.07257956400280818, 0.04294775579182897, 0.008905442791729001, 0.05999101391353179, 0.062421677430393174, 0.04371876930235885, 0.023648737951589283, 0.040558878899901174, 0.028916032752022147, 0.03576851602701936, 0.04311489487008657, 0.02501103164831875, 0.009841447790677194, 0.019264947695774026, 0.04957097851729486, 0.019278829568065703, 0.04442234385351185, 0.0536849628406344, 0.006384005337167764, 0.028628229738387745, 0.07157943095080554, 0.05664229887770489, 0.06384874577634037, 0.04909640476398636, 0.05918372422456741, 0.07759919855743647, 0.02922417246736586, 0.03891963424393907, 0.05534259049454704, 0.048552566368016414, 0.012017832032142906, 0.014167744793667225, 0.029937014587630983, 0.026243599786539562, 0.0443800154607743, 0.028442345865187235, 0.009380348656122806, 0.16903927316889167, 0.03782928943110164, 0.04014720587292686, 0.06543523486470804, 0.04600010528520215, 0.19588483264669776, 0.07234908262034878, 0.11197416533832438, 0.20006852690130472, 0.18213486968306825, 0.19813998194877058, 0.0942702176689636, 0.15594522032188252, 0.19778517598751932, 0.20231836242601275, 0.17030279443133622, 0.1964673146721907, 0.13739219633862376, 0.11316772433929145, 0.15073518035933375, 0.061583169299410656, 0.12143113053753041, 0.19601310545112938, 0.04977698758011684, 0.1902726970729418, 0.19952442875364795, 0.08403392319451086, 0.10761117562651634, 0.19413342350162566, 0.2487328866845928, 0.22872126050060615, 0.1088285724108573, 0.1771780356648378, 0.11310966612654738, 0.2027974632801488, 0.12875782762421295, 0.15222660033032298, 0.10363616587710567, 0.13784754846710712, 0.06983856772421859, 0.14167450717650354, 0.09140186142758466, 0.11953204884775914, 0.147877273557242, 0.1643179077655077, 0.08053765064687468, 0.10412477364297956, 0.22115255647804588, 0.09005963540403172, 0.2204165537841618, 0.23897927021607757, 0.2882499201223254, 0.16461108578369021, 0.07256246492033824, 0.11072550929384306, 0.106770945712924, 0.11236161095439456, 0.17166312143672258, 0.14061890600714833, 0.136537583603058, 0.16728412359952927, 0.190174080489669, 0.21417926269350573, 0.12434154428774491, 0.18237013049656525, 0.09335730923339725, 0.2377100195735693, 0.10111066701938398, 0.22433072968851775, 0.21074107062304392, 0.09728320364956744, 0.20995662052882835, 0.13158661255147308, 0.10491245207958855, 0.15067153377458453, 0.11326049279887229, 0.1554612212930806, 0.1700024472665973, 0.18326759483898059, 0.19299759616842493, 0.09184266746160574, 0.08388917471165769, 0.15715673187514767, 0.1942832482745871, 0.24533316754968837, 0.2908444980857894, 0.4851856338791549, 0.5932843708433211, 0.6965254840906709, 0.3087718767346814, 0.49215270846616477, 0.2113749537966214, 0.24943408265244216, 0.1320648376713507, 0.22023802273906767, 0.22610826243180782, 0.233918490994256, 0.5835917440708727, 0.16294456348987296, 0.20487587753450498, 0.16081293724710122, 0.28698093665298074, 0.44479997595772147, 0.6349225365556777, 0.5945014930330217, 0.11160649795783684, 0.29822536453139037, 0.1126837995252572, 0.15186956792604178, 0.16485820611706004, 0.135950782278087, 0.23055035766446963, 0.16476085118483752, 0.14653208636445925, 0.19572017976315692, 0.10612507685436867, 0.31899427820462734, 0.0703628282644786, 0.12794712034519762, 0.2628499752609059, 0.09227959206327796, 0.17083457292756066, 0.15174923610175028, 0.16441377840237692, 0.11260111685260199, 0.14519074349664152, 0.19907453883206472, 0.13775243482086807, 0.11654063710011542, 0.16761771898018196, 0.12810438143787906, 0.16394782840507105, 0.17387684405548498, 0.0897047552280128, 0.08472493689623661, 0.13845931563992053, 0.1964779570698738, 0.14633541723014787, 0.19420051365159452, 0.14867315272567794, 0.09623767342418432, 0.13814627774991095, 0.16632425948046148, 0.13473250233801082, 0.14118848950602114, 0.0982749207469169, 0.136585125583224, 0.197157452639658, 0.27999990968964994, 0.10664435016224161, 0.06840185887995176, 0.11586000604438595, 0.10207879866356961, 0.15584240318275988, 0.19973453076090664, 0.14952056662878022, 0.19107758591417223, 0.12022159309708513, 0.1235858524159994, 0.12322994065470994, 0.137552069791127, 0.25212953332811594, 0.12908613891340792, 0.2737432188587263, 0.1904078124789521, 0.18690031865844503, 0.09799452251172625, 0.0804859452182427, 0.22742742992704734, 0.07515615230659023, 0.08886881492799148, 0.07722306327195838, 0.09390724808326922, 0.16188801237149164, 0.15886712993960828, 0.16015914967283607, 0.2430565404938534, 0.24318442738149315, 0.17035769851645455, 0.1531205023638904, 0.14349095814395696], [0.046330264522111975, 0.052455676850513555, 0.02619144164782483, 0.03615415822423529, 0.021704919599869754, 0.035044413671130314, 0.046345493392436765, 0.07164292910601944, 0.03050371855351841, 0.008148211891239043, 0.025297309548477642, 0.05761082014942076, 0.05923264288867358, 0.05802778840006795, 0.03843760190648027, 0.009567490469635231, 0.030830964860797394, 0.014831636708549922, 0.01089236971893115, 0.04215853368805256, 0.07087315127137117, 0.01679468317888677, 0.07971048995386809, 0.05578148920903914, 0.06482336379121989, 0.031880460010143, 0.07508562601287849, 0.07668010061024688, 0.06473161949543282, 0.022135433900984935, 0.03269899323640857, 0.023340490624832455, 0.03695787818287499, 0.05607227380096447, 0.02644373289513169, 0.07110856793588027, 0.01383004811941646, 0.03336425812449306, 0.013953700126876356, 0.05307958555931691, 0.08031638673855923, 0.07450504388543777, 0.08868390141287819, 0.07509336661314592, 0.037816439144080505, 0.058582384226610884, 0.04990662964701187, 0.03732169010618236, 0.05300425385939889, 0.01916824770887615, 0.055541563997394405, 0.03275938921433408, 0.026216541082249023, 0.07906742641353048, 0.02396677420620108, 0.01286166600038996, 0.0978362892055884, 0.015833130673854612, 0.02267042589664925, 0.11109515820862725, 0.022157067505759187, 0.08663701359182596, 0.02387221531535033, 0.067423530126689, 0.016410723801527638, 0.04158347685006447, 0.03428694806643762, 0.04440832097316161, 0.015259544215950882, 0.08133724797517061, 0.0955024574068375, 0.10516030713915825, 0.034545597663964145, 0.1813270419370383, 0.2991015440784395, 0.18372443126281723, 0.1868705585366115, 0.2182721477583982, 0.5966103204991668, 0.8614448877051473, 1.888860238250345, 6.673983251675963, 10.700921192765236, 12.303326558321714, 7.37560847774148, 6.295100832358003, 3.0319038592278957, 3.7654174491763115, 2.065600985661149, 1.8203392275609076, 2.492374135181308, 2.859794469550252, 4.256785232573748, 6.544277686625719, 17.246695049107075, 29.706228375434875, 28.399919271469116, 24.394303411245346, 8.981710094958544, 2.2475067246705294, 0.6949182297103107, 0.3240425745025277, 0.03732038021553308, 0.05583732468949165, 0.007674442440475104, 0.04253097307810094, 0.032517363724764436, 0.03818016572040506, 0.01106677813368151, 0.09762852496351115, 0.07402958697639406, 0.0342976201500278, 0.01724517424008809, 0.06528960322611965, 0.028968769765924662, 0.07339997115195729, 0.021656125245499425, 0.025808417376538273, 0.056141159948310815, 0.06477125760284252, 0.03636907676991541, 0.03977968321123626, 0.06364398723235354, 0.024425465999229345, 0.040085529690259136, 0.04342863780038897, 0.04147346829995513, 0.02194386332121212, 0.032648816631990485, 0.027607299853116274, 0.09492649885942228, 0.039450644617318176, 0.04359015139925759, 0.06096415876527317, 0.08794213965302333, 0.08705880580237135, 0.02938618701591622, 0.024161582405213267, 0.03560752564226277, 0.0510081289394293, 0.0375277288549114, 0.04726010134618264, 0.06461663855588995, 0.016936542851908598, 0.042190238236798905, 0.08424554660450667, 0.02972112753923284, 0.08454389739199542, 0.009491260771028465, 0.024720610708754975, 0.04417585063492879, 0.030211629637051374, 0.06399336809408851, 0.028149589015811216, 0.035453099553706124, 0.08386675443034619, 0.09026983389048837, 0.054168100978131406, 0.011332622852933127, 0.1341807600692846, 0.04411421898112167, 0.026671054583857767, 0.06676759032416157, 0.02916183577326592, 0.03397924250748474, 0.03863093508698512, 0.032273549659294076, 0.03167122260492761, 0.045999775029486045, 0.012660605207202025, 0.04640275379642844, 0.01169603958260268, 0.06596881677978672, 0.06722849371726625, 0.05000008088245522, 0.044253256637603045, 0.053073336675879546, 0.012547278329293476, 0.030348780383064877, 0.052694177138619125, 0.018022889344138093, 0.0432347331661731, 0.02904814431531122, 0.033260361160500906, 0.052265798367443494, 0.06036684491846245, 0.011722671551979147, 0.04919402315863408, 0.04085788277734537, 0.038601920823566616, 0.13671224063728005, 0.022722532085026614, 0.06981403232202865, 0.02425489448796725, 0.02753297932940768, 0.04082196654053405, 0.043358872208045796, 0.0440262151096249, 0.044747482461389154, 0.0916969170793891, 0.045017093580099754, 0.03354580971063115, 0.06356684840284288, 0.07656259636860341, 0.025726758867676836, 0.08178469623089768, 0.004143755113545922, 0.02600368385174079, 0.04764431490912102, 0.054721186534152366, 0.009032789766934002, 0.06812461477238685, 0.022460429645434488, 0.029216188813734334, 0.03278962059994228, 0.05517429737665225, 0.08311979021527804, 0.06772458233172074, 0.06483684861450456, 0.054908801466808654, 0.06669252208666876, 0.02471203148161294, 0.0027408221058067284, 0.023661378581891768, 0.033943994203582406, 0.06521381510538049, 0.035255268958280794, 0.032868002526811324, 0.042750003121909685, 0.007348676253968733, 0.03141067682008725, 0.033592895269976, 0.08353182318387553, 0.019997985509689897, 0.03725443297298625, 0.04982485610526055, 0.0621065800805809, 0.08223589975386858, 0.013428048059722641, 0.02259582521219272, 0.04630691655620467, 0.03743640387256164, 0.024403893621638417, 0.08765900289290585, 0.05080310322227888, 0.03094682895607548, 0.06720237011904828, 0.18070745252771303, 0.10129050424438901, 0.2981679223012179, 0.10357381062931381, 0.0853661673318129, 0.8387202071025968, 1.8001311994157732, 3.6927159503102303, 4.157696049660444, 8.395399656146765, 18.198903053998947, 25.25430366396904, 27.7366154640913, 18.489507660269737, 13.436398208141327, 7.5371406599879265, 7.929470557719469, 5.13307711109519, 4.738169051706791, 5.684988470748067, 7.15582637116313, 11.644005887210369, 17.25910898298025, 37.464568465948105, 54.60018217563629, 60.46428211033344, 52.540046721696854, 26.51659782975912, 11.675735134631395, 1.058246896136552, 0.2933071518782526, 0.08617452942417003, 0.06709696288453415, 0.03639799455413595, 0.038157040398800746, 0.033621571856201626, 0.01756298413965851, 0.022936960813240148, 0.03589938634831924, 0.025801227820920758, 0.039183534536277875, 0.04745145299239084, 0.03254277486121282, 0.019213926898373757, 0.034498122477089055, 0.022467103408416733, 0.0269224441217375, 0.04021466709673405, 0.16310363542288542, 0.03531678186845966, 0.0721561093814671, 0.03792399489611853, 0.058544939165585674, 0.01952565860847244, 0.025805220575421117, 0.03399807079404127, 0.08221482275985181, 0.018050332109851297, 0.0612896016536979, 0.06833301726146601, 0.06006244191667065, 0.02356127955863485, 0.03515999203955289, 0.058206349131069146, 0.04425448860274628, 0.06262918934226036, 0.04723518744867761, 0.017995110756601207, 0.005349864295567386, 0.028835962439188734, 0.0092508559464477, 0.0432483218901325, 0.02922833591583185, 0.02937894550996134, 0.040601897489978, 0.03692820711876266, 0.031196526397252455, 0.052193583687767386, 0.0046028601900616195, 0.03811502370808739, 0.023476296228182036, 0.028260716353543103, 0.05545581254409626, 0.08713549934327602, 0.051408217041171156, 0.04236986394971609, 0.015939024015096948, 0.04323809880588669, 0.019049043949053157, 0.0369148744357517, 0.044227585749467835, 0.042397479264764115, 0.04807143945072312, 0.03903187665855512, 0.05496280384249985, 0.011114559456473216, 0.027032812613470014, 0.04903966386336833, 0.049711938336258754, 0.019787942874245346, 0.02060661525320029, 0.0456574705458479, 0.03129744734906126, 0.0577995074854698, 0.05310080727213062, 0.1137077777821105, 0.11842379972222261, 0.12900781264761463, 0.1743165368679911, 0.11860345141030848, 0.134918722033035, 0.12933348189108074, 0.1669504094752483, 0.14073794649448246, 0.16846761165652424, 0.12923013040563092, 0.17078158358344808, 0.1408061053371057, 0.130709097138606, 0.22257494187215343, 0.15464456198969856, 0.12022455426631495, 0.14132519310805947, 0.10071933254948817, 0.17175820539705455, 0.14204010396497324, 0.14817928313277662, 0.15728061116533354, 0.15228144504362717, 0.16844549565576017, 0.13681648269994184, 0.14416441263165325, 0.13709073595236987, 0.16963692469289526, 0.2237129065906629, 0.1328042394015938, 0.15181095310254022, 0.12843454809626564, 0.1865144760813564, 0.0998705234087538, 0.1389082259265706, 0.18556708004325628, 0.20609415747458115, 0.11559888138435781, 0.1449619690538384, 0.13350709778023884, 0.28620476892683655, 0.1982252101879567, 0.17293765617068857, 0.09359229545225389, 0.149315184680745, 0.09380867602885701, 0.10258246460580267, 0.08398390244110487, 0.09650786712882109, 0.15063908707816154, 0.12882638722658157, 0.15587872389005497, 0.10571961931418628, 0.09941618802258745, 0.1898023535613902, 0.2674356760689989, 0.11204054302652366, 0.10650588024873286, 0.17791074322303757, 0.2448270673630759, 0.18787619832437485, 0.06998977289185859, 0.10906764044193551, 0.1414083136478439, 0.1784743895404972, 0.08796742462436669, 0.18751894327579066, 0.09476810970227234, 0.15716027934104204, 0.1311647758120671, 0.24310528475325555, 0.19234682171372697, 0.5106061510741711, 0.4989678505808115, 0.22003155725542456, 0.5209643952548504, 1.2573199952021241, 2.973483894020319, 3.177026859484613, 7.601799890398979, 15.388937685638666, 23.762498013675213, 26.171065270900726, 18.722870238125324, 13.413875866681337, 7.088303994387388, 8.744215238839388, 6.27652695402503, 6.207954408600926, 6.441284688189626, 8.00458587706089, 12.021261043846607, 16.018781438469887, 37.797749787569046, 53.07462103664875, 62.229967564344406, 50.19816778600216, 21.86618696898222, 7.381979785859585, 0.8226239739451557, 0.5432190885767341, 0.19585878326324746, 0.22976715437835082, 0.10775201299111359, 0.3059340227628127, 0.16966494818916544, 0.1858470478327945, 0.13809187832521275, 0.2367980536655523, 0.12631218385649845, 0.08434535062406212, 0.0927429816510994, 0.17459509457694367, 0.11610244342591614, 0.09318388416431844, 0.11107147627626546, 0.09408830243046395, 0.10974993390846066, 0.233104562794324, 0.10726515669375658, 0.19379568693693727, 0.17007887363433838, 0.18573723966255784, 0.1321891919360496, 0.15492304548388347, 0.10626489747664891, 0.129997911863029, 0.11738319735741243, 0.1312454917933792, 0.2530950674554333, 0.16563627374125645, 0.09970632323529571, 0.17688867228571326, 0.1422556088073179, 0.1393750961869955, 0.10886790623771958, 0.20433911180589348, 0.15737395850010216, 0.09399896269314922, 0.15387681021820754, 0.11579457088373601, 0.1023247092962265, 0.091397846408654, 0.185284603794571, 0.10717987650423311, 0.10217568604275584, 0.21083977626403794, 0.07259026577230543, 0.15641042817151174, 0.15168009762419388, 0.12966017529834062, 0.10727396598667838, 0.21643522835802287, 0.10647940784110688, 0.15841804153751582, 0.16432871343567967, 0.14530610293149948, 0.08111242917948402, 0.21494011249160394, 0.12471168301999569, 0.21630958275636658, 0.18811200832715258, 0.16192605486139655, 0.10924747766694054, 0.16900477814488113, 0.13215309387305751, 0.18004440295044333, 0.08914013669709675, 0.11507054645335302, 0.20860560005530715, 0.09079476978513412, 0.26246500841807574, 0.1350054345675744, 0.22057614522054791, 0.16808264481369406], [0.04459409166884143, 0.03997493855422363, 0.02968673456052784, 0.03329970240883995, 0.03618850852944888, 0.06735509668942541, 0.02007828588830307, 0.01344977072221809, 0.042086474859388545, 0.06263776114792563, 0.09059680189238861, 0.020352333194750827, 0.026508381379244383, 0.03897719521773979, 0.03790438364376314, 0.02964771985716652, 0.07155798288295045, 0.012318527078605257, 0.015275198893505149, 0.006129540988695226, 0.07089246937539428, 0.01056236726071802, 0.04713158734375611, 0.04470723208214622, 0.013015041949984152, 0.010901287550950656, 0.058521769315120764, 0.0516700727166608, 0.025989991227106657, 0.058203859225613996, 0.10880473462748341, 0.04922634740069043, 0.04056831530760974, 0.019114640526822768, 0.12806378595996648, 0.06719258119119331, 0.08070066338405013, 0.015511911533394596, 0.033920846617547795, 0.02320767773198895, 0.0711264240089804, 0.013748700384894619, 0.06063626307877712, 0.07726934360107407, 0.05156169689144008, 0.07191439930466004, 0.02297010512847919, 0.042606278802850284, 0.05765116700786166, 0.029551615443779156, 0.04959591467923019, 0.054315506349666975, 0.017826678486017045, 0.03582017692679074, 0.04041556276206393, 0.06287010532105342, 0.0650819280417636, 0.023742107550788205, 0.07253144314745441, 0.04558592008834239, 0.08824344418826513, 0.01673205890256213, 0.03923645337636117, 0.06409962879843079, 0.06330731936031953, 0.01466526482545305, 0.05957243520242628, 0.03719585154613014, 0.06025104761647526, 0.24924367724452168, 0.3561893542064354, 0.4292148747481406, 2.2357465932145715, 5.863456344231963, 11.936391647905111, 28.091666512191296, 36.79557256400585, 48.87460380792618, 57.861877754330635, 75.95150247216225, 77.91405156254768, 101.27281174063683, 97.314822524786, 100.79102039337158, 83.3629135787487, 78.9783288538456, 81.3998781144619, 63.94573509693146, 60.777989476919174, 62.86823831498623, 69.01909366250038, 67.81002134084702, 82.1633331477642, 90.33108606934547, 95.95664620399475, 112.88764849305153, 100.15605926513672, 103.44841539859772, 88.11670929193497, 80.18153429031372, 41.390966176986694, 17.8242127597332, 3.415121133439243, 0.40664755913894624, 0.07657228139578365, 0.31891347316559404, 0.060102599527454004, 0.15595866803778335, 0.0484023816534318, 0.06608589057577774, 0.06564739262103103, 0.03649209887953475, 0.06294718477874994, 0.03323165117762983, 0.046723035047762096, 0.04939759797707666, 0.013067297495581442, 0.07780564177664928, 0.05704985298507381, 0.025786004516703542, 0.02044767876213882, 0.042290420751669444, 0.03504290340060834, 0.03579611649911385, 0.027832454470626544, 0.028623832513403613, 0.023623744273209013, 0.0135179351309489, 0.040596795224701054, 0.023476478054362815, 0.0645774976874236, 0.042114591124118306, 0.016651129553792998, 0.0026108813244718476, 0.009606857693142956, 0.04456400500203017, 0.022574265822186135, 0.011705875822372036, 0.07665680459467694, 0.09802711763768457, 0.04400207304570358, 0.039248531829798594, 0.06949621500098146, 0.012950518703291891, 0.03017682105564745, 0.04152536297624465, 0.03598873721784912, 0.03588032428524457, 0.02470859904860845, 0.012238898343639448, 0.06770916050300002, 0.05712824233341962, 0.015088116451806854, 0.04767699538206216, 0.06313964593573473, 0.03788334746786859, 0.06246987250051461, 0.021868724579690024, 0.03477147030935157, 0.004682549688368454, 0.041741535751498304, 0.04777934496814851, 0.013733459454670083, 0.054421013774117455, 0.026259390833729412, 0.045845322965760715, 0.015153841050050687, 0.0793591646652203, 0.019687630483531393, 0.0011819368523902085, 0.003967725106122089, 0.06688134672003798, 0.012987272639293224, 0.03464149427600205, 0.05605947175354231, 0.07390182625385933, 0.083964576915605, 0.013330976071301848, 0.022305719685391523, 0.04636214718630072, 0.01685324419668177, 0.07759248954243958, 0.02618871982122073, 0.012222388340887846, 0.0166346854166477, 0.0770848011597991, 0.02194175005570287, 0.03216305129171815, 0.05192174241528846, 0.03354078537086025, 0.046058690422796644, 0.055762768533895724, 0.011084736252087168, 0.03279111231677234, 0.021196338784648106, 0.016368154210795183, 0.020531033078441396, 0.011636596336757066, 0.005171495131435222, 0.044591319747269154, 0.02956580530735664, 0.010496677914488828, 0.05523759886273183, 0.03940638664062135, 0.041297197094536386, 0.03921758056094404, 0.06390658134478144, 0.07285337938810699, 0.010390786428615684, 0.01312933176450315, 0.0899242825107649, 0.06366192494169809, 0.03797912904701661, 0.03530589827278163, 0.014976234906498576, 0.02942057999462122, 0.06681525104795583, 0.031062834059412125, 0.03322770666272845, 0.031991385112633, 0.018531843088567257, 0.04966982145560905, 0.021211556522757746, 0.03307477600174025, 0.020624994540412445, 0.058162948334938847, 0.009842234467214439, 0.08146279709762894, 0.02362412091315491, 0.03923778182070237, 0.04118870994716417, 0.014255309870350175, 0.023672377210459672, 0.020524676583590917, 0.043054454363300465, 0.0746033265022561, 0.09004733059555292, 0.08793235814664513, 0.034629026195034385, 0.08492218490573578, 0.050491419751779176, 0.04122736099816393, 0.08102867781417444, 0.07976678927661851, 0.081374830333516, 0.2763005410088226, 1.809792893473059, 4.792595906183124, 10.796839445829391, 18.02197314798832, 27.54037879407406, 51.40615716576576, 62.01148308813572, 75.28930440545082, 83.3344379067421, 102.74125054478645, 109.74650144577026, 129.85883742570877, 120.78315362334251, 120.10276973247528, 106.5434405207634, 99.5190766453743, 101.9012600183487, 84.36982154846191, 75.68835899233818, 80.48839062452316, 89.45435911417007, 88.14192473888397, 106.43291965126991, 116.00294172763824, 119.26131248474121, 134.18519407510757, 119.76176083087921, 122.77984008193016, 113.67840886116028, 110.16450181603432, 73.09468656778336, 39.964545518159866, 11.44113952293992, 1.0484085115604103, 0.07556944692623802, 0.15782080561621115, 0.020571136883518193, 0.17223559931153432, 0.030922989317332394, 0.1098066043050494, 0.024261048747575842, 0.04522779301623814, 0.1449275779305026, 0.02892644322855631, 0.055476692868978716, 0.01298613158724038, 0.012978940176253673, 0.09954239023500122, 0.032627632026560605, 0.04684466934122611, 0.05085479380795732, 0.07392373445327394, 0.06156468611152377, 0.01930817037646193, 0.029247542697703466, 0.04967448956449516, 0.10941973014269024, 0.023729264685243834, 0.03763603788684122, 0.013230181284598075, 0.03020851632754784, 0.059267327160341665, 0.017960944132937584, 0.01754813376464881, 0.0634121180337388, 0.02878850580600556, 0.060907740698894486, 0.02326072830328485, 0.05664522293955088, 0.02737051578151295, 0.010078600153065054, 0.026373284526926, 0.08402529201703146, 0.024951075392891653, 0.025210058956872672, 0.033704265661071986, 0.009366412050439976, 0.03558942466042936, 0.0874658663815353, 0.027572828948905226, 0.037491987022804096, 0.030430025144596584, 0.011312780607113382, 0.04409977678733412, 0.02599996754724998, 0.02475698151101824, 0.027592299193202052, 0.02483629112248309, 0.08915312428143807, 0.014846333087916719, 0.047740267182234675, 0.00304686641356966, 0.016209035893552937, 0.04037021011754405, 0.06019041044055484, 0.02157639632059727, 0.04832652673940174, 0.1466564109432511, 0.07079414222971536, 0.017638108038227074, 0.015891201874183025, 0.06734958253218792, 0.04186159298114944, 0.0445901137572946, 0.05401948219514452, 0.03628781902079936, 0.2505963749717921, 0.0794632286124397, 0.05210470779275056, 0.22363391239196062, 0.12051762838382274, 0.21676480129826814, 0.08786578750004992, 0.08397970188525505, 0.15727727150078863, 0.15254041005391628, 0.258695135707967, 0.11613506823778152, 0.15619698649970815, 0.10253705258946866, 0.12570843187859282, 0.10686868656193838, 0.1898540070396848, 0.13815159152727574, 0.08364658147911541, 0.09611862551537342, 0.10182493962929584, 0.06409412948414683, 0.12417703241226263, 0.12392946679028682, 0.11209207776119001, 0.10001237751566805, 0.19613487704191357, 0.13820087013300508, 0.1390137741691433, 0.12363361704046838, 0.16620336362393573, 0.21393721865024418, 0.10426865381305106, 0.1382375619141385, 0.19651442620670423, 0.1740586108644493, 0.17728652281221002, 0.15517444058787078, 0.12561875075334683, 0.06945735614863224, 0.1985644013620913, 0.09153144041192718, 0.2445941072073765, 0.15459040005225688, 0.25748656305950135, 0.23024858557619154, 0.1298873615451157, 0.17223472357727587, 0.19279484142316505, 0.11329518820275553, 0.15118425391847268, 0.31798032636288553, 0.09059177755261771, 0.19613526295870543, 0.1542189106112346, 0.14951899327570572, 0.11344715778250247, 0.060395094769774005, 0.2195155865047127, 0.14336283376906067, 0.19922737672459334, 0.12947926938068122, 0.1794796879403293, 0.1647512477939017, 0.24245551961939782, 0.17673080263193697, 0.16540015203645453, 0.1288684966857545, 0.23595923383254558, 0.3216261713532731, 0.8860007731709629, 2.4644382717087865, 7.71845125593245, 12.468573991209269, 21.16145208477974, 46.6884671151638, 61.05836123228073, 78.2953231036663, 89.99632403254509, 111.04707285761833, 121.51636227965355, 142.99249827861786, 135.10691821575165, 136.91215574741364, 118.70548591017723, 112.79912084341049, 111.03304401040077, 98.64994928240776, 90.44397801160812, 92.68639728426933, 99.42405894398689, 100.4620112478733, 118.63691478967667, 130.80858886241913, 138.54559689760208, 152.36720323562622, 137.7100521326065, 145.84423005580902, 132.79493987560272, 119.40233051776886, 73.12605768442154, 36.137850657105446, 9.924206770956516, 0.7199015922378749, 0.11945112506509759, 0.3744834428653121, 0.2160002852906473, 0.4318706056801602, 0.2046770858578384, 0.13280155282700434, 0.1591312009259127, 0.17142740049166605, 0.19672512193210423, 0.07747117808321491, 0.12847953708842397, 0.12004032352706417, 0.07844474966987036, 0.1802341701113619, 0.1348160978523083, 0.13940156117314473, 0.10194890797720291, 0.2080735395429656, 0.16790904162917286, 0.15010346425697207, 0.1547929915250279, 0.16386908653657883, 0.18084149924106896, 0.1076162741810549, 0.11797083730925806, 0.08695934317074716, 0.15275870537152514, 0.09097899310290813, 0.20665069401729852, 0.08091094350675121, 0.11413437910960056, 0.15193881030427292, 0.10035320883616805, 0.07048595056403428, 0.20389625744428486, 0.1266057329485193, 0.1200255102594383, 0.12670460186200216, 0.17982113524340093, 0.09123135299887508, 0.15386388200568035, 0.10277882203808986, 0.1285961433313787, 0.1071233100083191, 0.1315534088644199, 0.07452137855580077, 0.18060960777802393, 0.12276560111786239, 0.13485244824551046, 0.13924605154898018, 0.15018795034848154, 0.06242956646019593, 0.14047032804228365, 0.16432136617368087, 0.13936767471022904, 0.12266285077203065, 0.09992542749387212, 0.10937858547549695, 0.36937761527951807, 0.14429704926442355, 0.2200676701613702, 0.13783972623059526, 0.09797650316613726, 0.21096223063068464, 0.11504515015985817, 0.182858330081217, 0.23197461327072233, 0.2066026473767124, 0.1506779607734643, 0.21110540576046333, 0.1544938317965716, 0.14503928599879146], [0.05192357552004978, 0.04298898209526669, 0.13551908981753513, 0.018779200909193605, 0.04183823759376537, 0.042938137557939626, 0.025932274402293842, 0.03272522444603965, 0.0313856998400297, 0.0017438001600567077, 0.020805143467441667, 0.02976563042466296, 0.09660990501288325, 0.024050805732258596, 0.011776177616411587, 0.0898619346844498, 0.014842269829387078, 0.022390448830265086, 0.035014601598959416, 0.03889021922077518, 0.03154191821522545, 0.04818761895876378, 0.022170813936099876, 0.03311507833132055, 0.03385214971785899, 0.056696390311117284, 0.051861220272257924, 0.01208774141559843, 0.09956616864656098, 0.10167386062676087, 0.06544719828525558, 0.0436437307507731, 0.06579309105291031, 0.03487447298539337, 0.058420221248525195, 0.04911814598017372, 0.05044873141741846, 0.07578517441288568, 0.047558329679304734, 0.051995946050737984, 0.05323922152456362, 0.06576344967470504, 0.030061331744946074, 0.02842268266249448, 0.03991083554865327, 0.03138722495350521, 0.029152558927307837, 0.042319820931879804, 0.04703937920567114, 0.050142729087383486, 0.029854999847884756, 0.05134688224643469, 0.05136161758855451, 0.024331947970495094, 0.04016643491922878, 0.03566215142200235, 0.08300961097120307, 0.030907920008758083, 0.030185192481440026, 0.10537937429035082, 0.08829412545310333, 0.026467188472452108, 0.029009124045842327, 0.10550578430411406, 0.26134789804928005, 0.1346397932502441, 0.36376688978634775, 0.5983756820205599, 2.3772130021825433, 12.489369325339794, 35.325898826122284, 62.08847835659981, 69.3461725115776, 92.58757218718529, 96.20925664901733, 103.91577512025833, 101.94408372044563, 95.90642809867859, 102.2712841629982, 87.36146941781044, 98.55613991618156, 99.49337482452393, 97.28972107172012, 87.64114201068878, 95.80416798591614, 98.51730599999428, 85.86640924215317, 94.43455427885056, 86.03981673717499, 92.14232727885246, 98.26423957943916, 98.9081834256649, 102.49197632074356, 95.26418656110764, 91.62397429347038, 83.75507533550262, 100.48329770565033, 88.39867696166039, 89.74380478262901, 100.48632234334946, 109.86634701490402, 110.58839946985245, 75.79082429409027, 41.266378462314606, 18.497901409864426, 8.056646883487701, 5.490121152251959, 2.693286929279566, 0.1026298433134798, 0.09902624136884697, 0.011643335965345614, 0.04936303244903684, 0.07168070442276075, 0.04045006149681285, 0.07354069719440304, 0.04966612184944097, 0.01836907340475591, 0.09394486012752168, 0.03714761194714811, 0.09078216811758466, 0.1076918545004446, 0.021435341877804603, 0.04808286852494348, 0.08651947224279866, 0.03625978068157565, 0.07560847647255287, 0.034526672898209654, 0.011055334216507617, 0.025920385196513962, 0.05372115738282446, 0.022024471691111103, 0.03270873763540294, 0.04691416776040569, 0.06049841656931676, 0.035313865228090435, 0.04378466088382993, 0.0481453202519333, 0.06063041866582353, 0.02035153167526005, 0.02147894676454598, 0.030107710408628918, 0.04596000704623293, 0.047567981309839524, 0.09161756664980203, 0.015249009429680882, 0.031658747102483176, 0.03281371442426462, 0.023893728321127128, 0.06957319055800326, 0.04982499340258073, 0.03079867958149407, 0.03969887817220297, 0.02050059018074535, 0.031252907356247306, 0.07643687655217946, 0.03046588015422458, 0.03151805074594449, 0.026296631804143544, 0.0341077268240042, 0.02656209617271088, 0.0266636331070913, 0.057632205134723336, 0.029253852808324154, 0.013640039760502987, 0.07557834527688101, 0.022574853974219877, 0.08847912060446106, 0.05370125669287518, 0.04654916097933892, 0.00277765373539296, 0.014425373938138364, 0.0399741259025177, 0.026426398180774413, 0.02041677387751406, 0.07286581778316759, 0.013457187560561579, 0.02815293239109451, 0.02790638722217409, 0.023973653915163595, 0.04251975922670681, 0.04074392971233465, 0.03333399705297779, 0.03892608350724913, 0.013407187216216698, 0.024325302038050722, 0.04022169523523189, 0.009609604567231145, 0.04391794318507891, 0.05840146717673633, 0.03698183842061553, 0.03641536080976948, 0.09076347341760993, 0.05936929454037454, 0.04780131625011563, 0.08627376199001446, 0.04153254325501621, 0.10487550796824507, 0.09592456131940708, 0.03339751005114522, 0.08673819800605997, 0.03342492869705893, 0.03346518278704025, 0.036122516758041456, 0.006723845890519442, 0.02056600307696499, 0.028435299172997475, 0.03056921123061329, 0.034638436627574265, 0.051056038282695226, 0.05840163787070196, 0.035321954637765884, 0.030735788132005837, 0.05721872868889477, 0.05018110554374289, 0.07111590035492554, 0.04611043295881245, 0.012486106807045871, 0.025437545773456804, 0.03131227917037904, 0.010984378404828021, 0.03640092232672032, 0.058173045254079625, 0.034606728368089534, 0.04730114582343958, 0.009797059938136954, 0.027522251584741753, 0.06978388628340326, 0.036251720957807265, 0.029453304996422958, 0.0506461167242378, 0.045796033227816224, 0.08230036270106211, 0.0439227931201458, 0.003535687083058292, 0.0465208146488294, 0.05470749019877985, 0.0799643860955257, 0.04069311486091465, 0.08751804678468034, 0.11520179526996799, 0.05557423704885878, 0.16006850375561044, 1.533625137526542, 2.4291388783603907, 8.834704533219337, 33.196500688791275, 65.29355317354202, 92.99419596791267, 95.18338769674301, 113.7252451479435, 113.15444737672806, 118.50357994437218, 114.68188941478729, 111.21072247624397, 120.82749724388123, 97.2679254412651, 105.85890725255013, 104.68209519982338, 106.33610844612122, 95.7405138015747, 111.55911058187485, 113.5444812476635, 101.27842783927917, 108.51559549570084, 100.27816951274872, 106.54355451464653, 110.53367480635643, 115.23938030004501, 119.944918602705, 105.81004947423935, 106.98461964726448, 107.30079308152199, 125.04323422908783, 103.5319273173809, 106.68187469244003, 113.96508827805519, 125.85066050291061, 137.46285259723663, 105.92226505279541, 69.91872578859329, 38.26710060238838, 21.455301716923714, 14.99416071921587, 9.16974775493145, 2.1722631622105837, 0.21484096156200394, 0.046271096798591316, 0.025634365192672703, 0.1243791934393812, 0.011379891166143352, 0.10478080250322819, 0.018317829963052645, 0.049317071243422106, 0.16354993334971368, 0.014985344769229414, 0.07060519143124111, 0.0526448948221514, 0.044529777151183225, 0.041428063705097884, 0.038503894247696735, 0.025353833370900247, 0.06230583559954539, 0.03227056993637234, 0.032267901915474795, 0.016617413784842938, 0.014547183563990984, 0.054187816131161526, 0.026905545419140253, 0.0471983398165321, 0.018208778783446178, 0.07752991165034473, 0.029587535391328856, 0.020597982220351696, 0.05801650775538292, 0.02448293977067806, 0.06763197714462876, 0.049884131440194324, 0.037750395422335714, 0.12231473898282275, 0.04206212128337938, 0.03759622537472751, 0.1213980455941055, 0.018346784854657017, 0.029242824493849184, 0.05993238795781508, 0.05313134293828625, 0.028748669174092356, 0.03949176330934279, 0.04691204521805048, 0.03270733497629408, 0.018391653247817885, 0.053601300533046015, 0.02714657828619238, 0.08362353779375553, 0.03413126774830744, 0.026656022382667288, 0.04254587911418639, 0.03121551424555946, 0.04658761165046599, 0.01627759735129075, 0.042574422113830224, 0.046071303222561255, 0.07995468622539192, 0.008923193108785199, 0.03224597516236827, 0.041782320477068424, 0.046142293358570896, 0.04590571523294784, 0.020061004979652353, 0.0343209903803654, 0.04308146111725364, 0.017754309810698032, 0.21119036682648584, 0.12160685626440682, 0.17680003016721457, 0.12581859627971426, 0.09939098468748853, 0.162653211154975, 0.0907631691370625, 0.09821285493671894, 0.09511640702839941, 0.1383797128801234, 0.12272649735677987, 0.11052709611249156, 0.16039080364862457, 0.1187377875612583, 0.19854102371027693, 0.2296453234157525, 0.11507564500789158, 0.183183049375657, 0.17884481028886512, 0.10694903146941215, 0.13099204836180434, 0.13027050270466134, 0.10575798834906891, 0.16718699131160975, 0.1252468753955327, 0.10580565649433993, 0.2082576070097275, 0.08248124635429122, 0.14805676939431578, 0.1799699358525686, 0.18612786167068407, 0.13039662328083068, 0.1787344677723013, 0.29750907327979803, 0.19899873586837202, 0.21103392209624872, 0.20219117315718904, 0.21027498703915626, 0.14645395305706188, 0.13874425581889227, 0.14662714063888416, 0.15268876537447795, 0.10250154824461788, 0.14505194703815505, 0.1553565339418128, 0.18816950992913917, 0.14831649139523506, 0.1503940299153328, 0.08115790798910893, 0.1221690331294667, 0.22857437463244423, 0.11836053905426525, 0.2202866630977951, 0.10447324908454902, 0.1899741162196733, 0.16557405208004639, 0.17985945974942297, 0.10053186604636721, 0.168751438613981, 0.16707112721633166, 0.18298112583579496, 0.18519187986385077, 0.21572269237367436, 0.3313091502059251, 0.3706551482900977, 0.19743283395655453, 0.8224573766347021, 1.740917433053255, 9.614973664283752, 34.17599692940712, 67.81629100441933, 98.58196333050728, 104.39300671219826, 129.06293213367462, 128.98825854063034, 137.0304509997368, 134.33481484651566, 124.46773990988731, 130.16352027654648, 109.4292564690113, 117.59999603033066, 117.55217179656029, 118.79855051636696, 110.65934926271439, 119.5513205230236, 124.94170367717743, 110.95922157168388, 126.78941532969475, 114.07765343785286, 120.62824353575706, 125.6615598499775, 127.01568558812141, 125.90409323573112, 118.75532403588295, 116.25178277492523, 109.82659354805946, 129.02102798223495, 113.34992408752441, 117.76455760002136, 129.9189653992653, 145.81038147211075, 153.1755718588829, 118.3886057138443, 71.90466642379761, 36.81905910372734, 18.721895590424538, 12.956327218562365, 7.655954584479332, 1.8775134533643723, 0.2372790247318335, 0.10704443455324508, 0.11539539191289805, 0.2522777550620958, 0.11329978951835074, 0.13092941109789535, 0.15888048859778792, 0.24102881492581218, 0.330759278149344, 0.09793458666536026, 0.22376944340066984, 0.23340051644481719, 0.17287737893639132, 0.15212595026241615, 0.12720669445116073, 0.09794198587769642, 0.1661738261464052, 0.12479841039748862, 0.10330081160645932, 0.13836365280440077, 0.12596278073033318, 0.1632714646984823, 0.14007877092808485, 0.15411950735142455, 0.208688453421928, 0.14847712183836848, 0.10858663226827048, 0.07977619970915839, 0.11596567303058691, 0.11218062340049073, 0.11471948833786882, 0.19698423537192866, 0.13501272245775908, 0.1474994610180147, 0.12900908914161846, 0.10311802063370124, 0.1382618598290719, 0.18987391144037247, 0.11726049066055566, 0.24287265114253387, 0.20415545994183049, 0.08593942446168512, 0.11100734729552642, 0.18521372869145125, 0.09704171621706337, 0.18864620622480288, 0.15316497185267508, 0.17225287650944665, 0.12991652794880792, 0.15754462277982384, 0.1651697893976234, 0.10792117813252844, 0.12115010889829136, 0.16540034499485046, 0.11582437553443015, 0.14289094659034163, 0.08548631361918524, 0.1676406810292974, 0.13023666077060625, 0.10854989595827647, 0.1410229757311754, 0.20589414867572486, 0.1841943443287164, 0.111669892212376, 0.11735754131223075, 0.16954782244283706, 0.11654803631245159], [0.05072578998806421, 0.03571267312509008, 0.06549036159412935, 0.10930253018159419, 0.043542620551306754, 0.094825640990166, 0.06272242535487749, 0.0211227288673399, 0.02238358953036368, 0.037077319429954514, 0.06596379986149259, 0.026429099598317407, 0.027591647958615795, 0.013719716735067777, 0.02530526166083291, 0.021037808619439602, 0.05462075539981015, 0.03145059323287569, 0.0660886884725187, 0.04449900399777107, 0.10568002573563717, 0.048681829939596355, 0.10708146030083299, 0.026522099979047198, 0.0033008314358085045, 0.05087018966150936, 0.02759413229796337, 0.053556211350951344, 0.03508906127535738, 0.049837669284897856, 0.048863949268707074, 0.04966970642271917, 0.022828833607491106, 0.033987613933277316, 0.07202770299045369, 0.020538578864943702, 0.043840188372996636, 0.044071664233342744, 0.03270236629759893, 0.02279588967212476, 0.009343262609036174, 0.043673194013535976, 0.07381068309769034, 0.10145061518414877, 0.07611520748469047, 0.007715958645349019, 0.053117713396204636, 0.029463913997460622, 0.0630576534604188, 0.037917449153610505, 0.06089375492592808, 0.015849509873078205, 0.014863258693367243, 0.017242415306100156, 0.029072536854073405, 0.058553202979965135, 0.22744996153051034, 0.012857506262662355, 0.04552200261969119, 0.1275597934727557, 0.07229489099700004, 0.15094485192093998, 0.08412115523242392, 0.6144095154013485, 8.597810044884682, 13.494680430740118, 31.981595680117607, 32.13801808655262, 38.85658957064152, 72.80577287077904, 85.82340314984322, 92.27096557617188, 91.62758409976959, 84.6016775071621, 86.4177368581295, 85.54981023073196, 76.7187725007534, 85.43803542852402, 86.05168730020523, 89.35240298509598, 90.37591606378555, 98.6790481209755, 102.65713825821877, 87.60444357991219, 72.05389201641083, 89.89625260233879, 81.67425379157066, 85.0734905898571, 102.36306443810463, 92.87815019488335, 104.68552261590958, 81.28963842988014, 81.13111853599548, 96.25663250684738, 81.98630824685097, 91.31319656968117, 64.07381102442741, 87.47577488422394, 63.31919051706791, 69.58256542682648, 72.69826903939247, 77.8341418504715, 95.59182778000832, 101.82581126689911, 97.64161258935928, 89.4290828704834, 83.54182317852974, 72.46597990393639, 50.76319746673107, 31.066500283777714, 8.357283901423216, 1.1344402888789773, 0.05928304584813304, 0.06312261364655569, 0.03561608631571289, 0.03385575284482911, 0.09457129213842563, 0.07638639566721395, 0.04960254947945941, 0.05666846700478345, 0.03566695682820864, 0.035323698684806004, 0.039371910170302726, 0.0260249278289848, 0.016529231797903776, 0.05663034287863411, 0.04891722433967516, 0.04611541276972275, 0.0606828328454867, 0.07508758528274484, 0.03385954521945678, 0.009637838647904573, 0.027535350491234567, 0.0421799038304016, 0.03294133784947917, 0.02240052905108314, 0.087131655018311, 0.08066931506618857, 0.04195958244963549, 0.011112025949842064, 0.04233227788063232, 0.011956164198636543, 0.02872645854949951, 0.042688664616434835, 0.0270896945221466, 0.05487782051204704, 0.019798783796431962, 0.009378369904879946, 0.01906555116875097, 0.05409739285823889, 0.0512528410035884, 0.09282637678552419, 0.015478142886422575, 0.06365711582475342, 0.03542345446476247, 0.0663846792303957, 0.0611122580448864, 0.03199351136572659, 0.02244979466922814, 0.03996149454906117, 0.03069316102482844, 0.02649082958669169, 0.07448036747518927, 0.08053788071265444, 0.07199673316790722, 0.04035232064779848, 0.046547914171242155, 0.07515493518440053, 0.06434507929952815, 0.05006077743018977, 0.013602038088720292, 0.04267883858119603, 0.028370724903652444, 0.07693400417338125, 0.07219348393846303, 0.080012744438136, 0.04527355013124179, 0.011112223546660971, 0.025610223128751386, 0.005342662680050125, 0.021506367265828885, 0.03650615886726882, 0.06956582103157416, 0.013924185841460712, 0.005790712539237575, 0.027410148322815076, 0.008383002368645975, 0.023665979897486977, 0.02949013221950736, 0.10265307253575884, 0.01873910823633196, 0.03947591845644638, 0.03799265839916188, 0.03291742585133761, 0.02813241571857361, 0.04419779223098885, 0.06616430589929223, 0.07826858607586473, 0.08817949332296848, 0.04897478531347588, 0.011610329875111347, 0.05901899712625891, 0.044669723938568495, 0.07101344686816446, 0.07940826515550725, 0.07422861614031717, 0.03206625297025312, 0.03526339918607846, 0.008853026756696636, 0.05923662451095879, 0.0970663406769745, 0.08025999835808761, 0.08988808796857484, 0.03353377578605432, 0.049389252526452765, 0.01849505668360507, 0.02612987307657022, 0.02523916969948914, 0.007352186612479272, 0.055749458115315065, 0.012561629609990632, 0.03907869504473638, 0.14497641124762595, 0.025816003981162794, 0.03386892225535121, 0.05775843332230579, 0.03363100826391019, 0.05899200892599765, 0.031178622084553353, 0.03256601521570701, 0.05381857910833787, 0.08617208775831386, 0.07331362969125621, 0.04651751951314509, 0.0817035572254099, 0.027054320053139236, 0.0451301338034682, 0.06593331985641271, 0.5857784079853445, 4.080447619780898, 20.748364850878716, 30.158964581787586, 57.284415140748024, 68.42798218131065, 77.25090354681015, 104.5521953701973, 102.01680421829224, 104.80101361870766, 106.32219359278679, 95.58824077248573, 104.36849802732468, 105.58204650878906, 99.94707807898521, 110.96233740448952, 113.73916760087013, 124.40116748213768, 125.7199627161026, 134.6386769413948, 120.5958616733551, 113.44798162579536, 91.398114413023, 115.10758057236671, 108.63306999206543, 108.97667035460472, 131.2037828564644, 121.15671917796135, 135.82321017980576, 111.07554093003273, 113.07123184204102, 134.39486682415009, 108.07340562343597, 126.16823986172676, 99.55333560705185, 113.51405248045921, 98.66356775164604, 91.27838283777237, 92.59150877594948, 92.45105311274529, 105.32283961772919, 114.00603488087654, 116.89144045114517, 112.31913819909096, 109.35792669653893, 99.15842279791832, 79.5117898285389, 52.62662507593632, 18.879007659852505, 4.189761579036713, 0.5489322007633746, 0.017299102401011623, 0.2903573523508385, 0.02888832095777616, 0.027745871811930556, 0.028064692887710407, 0.06934855729923584, 0.18734450888587162, 0.03373830426426139, 0.05572415087954141, 0.01664310879277764, 0.04452437802683562, 0.009746508549142163, 0.04547735501546413, 0.06776612033718266, 0.05685797441401519, 0.04602685970894527, 0.07540794817032292, 0.017759224683686625, 0.025788969396671746, 0.0017851446273198235, 0.05326949372829404, 0.007520105409639655, 0.052177445686538704, 0.028037415249855258, 0.07646338606718928, 0.045650486936210655, 0.06795918263378553, 0.02840267807187047, 0.06461349184974097, 0.05054738881881349, 0.03833782015135512, 0.09439224158995785, 0.03002738219947787, 0.06363948981743306, 0.026844333078770433, 0.005094389234727714, 0.05380837457778398, 0.0550076332729077, 0.05804708423966076, 0.026959659116982948, 0.033881702038343064, 0.017031892130034976, 0.08941859792685136, 0.01116899877160904, 0.004902499995296239, 0.07690437763812952, 0.02484571454260731, 0.04521631941315718, 0.07634997105924413, 0.067377672821749, 0.06546452743350528, 0.12728089437587187, 0.06473092187661678, 0.012655460268433671, 0.01939446545293322, 0.011279640002612723, 0.038953891780693084, 0.043276393626001664, 0.045077022004988976, 0.032518899970455095, 0.0634818131220527, 0.050191707123303786, 0.051436103240121156, 0.13491658464772627, 0.16326523065799847, 0.14989992283517495, 0.15965316822985187, 0.1683732253150083, 0.15392182889627293, 0.2178115857532248, 0.08199064221116714, 0.08406317123444751, 0.09576846539857797, 0.13156869710655883, 0.159378529060632, 0.09664457073085941, 0.15410076070111245, 0.11061180484830402, 0.15376156952697784, 0.1629954599775374, 0.08872295322362334, 0.10459772209287621, 0.13599618687294424, 0.16811489855172113, 0.20320769282989204, 0.146415019989945, 0.12224093239638023, 0.06861263624159619, 0.11990364218945615, 0.12091694836271927, 0.1361552142770961, 0.1941635546972975, 0.1852964039426297, 0.14466341788647696, 0.11850381066324189, 0.09674200729932636, 0.11705070035532117, 0.18335887900320813, 0.15474258485483006, 0.12331841207924299, 0.1961525104707107, 0.14481257472652942, 0.11082135024480522, 0.18267924984684214, 0.18028760474408045, 0.21021870255935937, 0.1906047636293806, 0.2218567210366018, 0.11666375197819434, 0.20638803311157972, 0.12352380144875497, 0.17471220548031852, 0.1900437890435569, 0.15540550084551796, 0.22189495648490265, 0.18984162801643834, 0.134071649517864, 0.11324491511913948, 0.172249432944227, 0.28788217110559344, 0.1403238280909136, 0.0972572507453151, 0.20189026196021587, 0.1753674476640299, 0.27581876842305064, 0.3430414659669623, 2.133643222041428, 15.392123814672232, 28.19921024143696, 58.86606886982918, 75.85116505622864, 91.91687017679214, 124.24987480044365, 119.51914384961128, 116.09837740659714, 114.72693979740143, 104.87357452511787, 107.39995256066322, 105.7436366379261, 96.8684832751751, 108.49072203040123, 106.27563089132309, 113.76893520355225, 116.52517810463905, 127.80811786651611, 127.50244706869125, 114.45203974843025, 96.87555089592934, 114.65731993317604, 107.02678218483925, 110.09448677301407, 127.0656681060791, 119.14329081773758, 128.3334320783615, 104.30267795920372, 103.84943827986717, 122.4886617064476, 104.61800783872604, 117.96063467860222, 89.9863913655281, 115.83039298653603, 91.29554271697998, 95.97616955637932, 94.89892736077309, 96.88286930322647, 116.87222108244896, 129.03399288654327, 129.6079596877098, 123.97622108459473, 118.92795637249947, 108.50308656692505, 84.88387316465378, 52.17376917600632, 17.791760601103306, 3.188412948511541, 0.40535441134124994, 0.18060873204376549, 0.40055880148429424, 0.13002888910705224, 0.22315023990813643, 0.16719653533073142, 0.23365860572084785, 0.27392373885959387, 0.12435905897291377, 0.13077130395686254, 0.1111418244545348, 0.19016134523553774, 0.10614699989673682, 0.13741125469096005, 0.15652694535674527, 0.13142507668817416, 0.2235719727468677, 0.28285815787967294, 0.10758042844827287, 0.18546507926657796, 0.12172700997325592, 0.1705486382707022, 0.16388072341214865, 0.1739840250229463, 0.17444054974475875, 0.1959411468124017, 0.19418203417444602, 0.0984947152028326, 0.16353329439880326, 0.20591509208315983, 0.09812666932702996, 0.2040070600924082, 0.209290572674945, 0.0908377104497049, 0.09731483398354612, 0.09584241299307905, 0.06746542436303571, 0.1416359154973179, 0.1826314110076055, 0.1980037978501059, 0.08194192021619529, 0.16427949420176446, 0.121301039471291, 0.18432781216688454, 0.11564071624889039, 0.1369324210099876, 0.1580482887220569, 0.13271584961330518, 0.09481452361796983, 0.11100806717877276, 0.13333828886970878, 0.13849525043042377, 0.25855584943201393, 0.1468796786502935, 0.14107391674770042, 0.15136990958126262, 0.22089988488005474, 0.1681658989400603, 0.132876435527578, 0.09079908166313544, 0.16120596381369978, 0.11811865828349255, 0.2077571619884111, 0.17959500284632668], [0.07551604940090328, 0.042739282798720524, 0.010114144388353452, 0.015166695047810208, 0.02671981925232103, 0.0505438895925181, 0.023405476786138024, 0.03243103339627851, 0.0703922395769041, 0.08123278326820582, 0.0164923544798512, 0.02704361828364199, 0.04357699312095065, 0.05425669856776949, 0.09267773944884539, 0.05741886365285609, 0.038870407588547096, 0.027065212925663218, 0.015817367457202636, 0.03567440799088217, 0.05206735178944655, 0.08351787822903134, 0.07525428649387322, 0.05077907619124744, 0.020331310006440617, 0.08739505065022968, 0.07369236991507933, 0.004143360383750405, 0.020229422407282982, 0.024839797770255245, 0.04871042488957755, 0.05459182648337446, 0.043706104552256875, 0.03930636368750129, 0.07666289020562544, 0.02708098356379196, 0.037562869547400624, 0.01565688358823536, 0.05896500217204448, 0.04366351269709412, 0.023041674139676616, 0.013256410638859961, 0.027083595923613757, 0.052905229094903916, 0.07934235502034426, 0.027233992150286213, 0.048117166879819706, 0.03580848810088355, 0.03233324801840354, 0.049824388552224264, 0.04618241386197042, 0.01723407542158384, 0.02759750721452292, 0.049139642287627794, 0.02776245881250361, 0.0773448497056961, 0.10820413677720353, 0.03917462505341973, 0.19011623749975115, 0.02273683883686317, 0.914943345123902, 8.999040964990854, 31.28269348293543, 56.06484018266201, 72.88448184728622, 83.73131901025772, 87.97892108559608, 76.8598285317421, 79.76801007986069, 72.90746301412582, 74.70146834850311, 76.50794461369514, 71.90606474876404, 86.71395376324654, 68.21207016706467, 75.22315755486488, 77.93604478240013, 76.4219780266285, 52.12810322642326, 53.01855884492397, 37.243997901678085, 47.47047655284405, 100.69015860557556, 87.58373469114304, 103.61552283167839, 100.4614108800888, 96.25224754214287, 83.02775636315346, 68.1332091987133, 62.455588057637215, 51.41254462301731, 56.55555725097656, 58.95814552903175, 62.34166257083416, 63.37891571223736, 43.13449501991272, 40.40326997637749, 35.614960715174675, 42.25701570510864, 75.1221589744091, 68.29346939921379, 75.00403851270676, 79.97308507561684, 67.20581576228142, 79.56850558519363, 80.40154248476028, 83.49759355187416, 90.83813086152077, 97.3308576643467, 97.47537150979042, 93.4619964659214, 55.31034126877785, 36.86406768858433, 13.97758036851883, 0.22107520984718576, 0.40105316089466214, 0.20314049877924845, 0.05099556809000205, 0.03552531423338223, 0.18936626758659258, 0.022264730869210325, 0.029778786847600713, 0.0624951500503812, 0.013315792657522252, 0.041140229150187224, 0.030069940657995176, 0.053870325355092064, 0.01635393280594144, 0.01997381004912313, 0.02691448273253627, 0.02360236114327563, 0.040487992664566264, 0.024685887474333867, 0.07335836635320447, 0.024720128312765155, 0.024596705443400424, 0.06187599850818515, 0.04108372573682573, 0.05858795404492412, 0.029521638243750203, 0.10346092254621908, 0.05285383165755775, 0.050809077511075884, 0.039886585873318836, 0.04320370026107412, 0.03465391040663235, 0.046574479347327724, 0.031594759129802696, 0.0323494565236615, 0.05218750549829565, 0.07077662012306973, 0.025602684763725847, 0.04402366583235562, 0.038508506695507094, 0.04983787708624732, 0.05110301251988858, 0.046329830365721136, 0.04556787847832311, 0.0028112199152019457, 0.028147006341896486, 0.09087178244953975, 0.019843689296976663, 0.03864625672576949, 0.021203810356382746, 0.04338040933362208, 0.038349223250406794, 0.02653414132510079, 0.02523176863178378, 0.04533984618319664, 0.036203039780957624, 0.027178097298019566, 0.08631619057268836, 0.07309170527150854, 0.04096906392078381, 0.001983114607355674, 0.0528383281925926, 0.056505435713916086, 0.02673906128620729, 0.042758563795359805, 0.020578886760631576, 0.06926803427631967, 0.006696361842841725, 0.06097444493207149, 0.0035971798160971957, 0.05284870341711212, 0.07781023567076772, 0.0267386159976013, 0.09743785238242708, 0.02076670207316056, 0.06935206765774637, 0.05702983355149627, 0.029989037284394726, 0.032741206596256234, 0.03979762092058081, 0.012027095890516648, 0.008117268971545855, 0.04121044374187477, 0.020244254228600767, 0.07202000691904686, 0.044465948740253225, 0.017919664023793302, 0.037428663272294216, 0.0495236294955248, 0.06650199793512002, 0.03418597516429145, 0.034122439901693724, 0.021833600585523527, 0.09925468184519559, 0.026886082596320193, 0.01223511988428072, 0.08793600951321423, 0.035296053683850914, 0.04014935439045075, 0.0015848372299842595, 0.038878107370692305, 0.026121141709154472, 0.029699191509280354, 0.043897819850826636, 0.05942635456449352, 0.049529544412507676, 0.06556669148267247, 0.026082954500452615, 0.046879528017598204, 0.0351539695111569, 0.03483190339466091, 0.08396838413318619, 0.04883903908194043, 0.017476540633651894, 0.027155973875778727, 0.18240596138639376, 0.1044927749899216, 0.020727223527501337, 0.12163536215666682, 0.06709228735417128, 0.17949185916222632, 0.0690225169819314, 4.217875320464373, 21.463140696287155, 54.19996865093708, 80.39626836776733, 92.53692850470543, 107.20667213201523, 105.94722971320152, 94.93938758969307, 97.44875773787498, 89.18129816651344, 95.27015224099159, 103.2425120472908, 97.68537104129791, 119.35392871499062, 96.75239190459251, 112.43407443165779, 112.0852455496788, 107.0408946275711, 70.20912140607834, 55.58260805904865, 58.65772224962711, 57.63845354318619, 116.65773019194603, 119.81484398245811, 118.7523601949215, 106.90458834171295, 111.61864578723907, 100.00266149640083, 92.29647740721703, 87.53152549266815, 70.61840504407883, 87.90759891271591, 79.99340638518333, 87.80945017933846, 81.74693629145622, 65.7758840918541, 54.07522514462471, 60.2954837679863, 70.46715795993805, 107.12288662791252, 104.72939506173134, 111.09865888953209, 107.47450456023216, 98.38631182909012, 102.81485259532928, 96.99713677167892, 101.25116050243378, 106.27368539571762, 112.0579706132412, 114.17280793190002, 115.8066138625145, 80.80974698066711, 59.084690138697624, 28.860399462282658, 4.364923629909754, 1.6371400142088532, 0.1353715211735107, 0.05426530377008021, 0.03704513990669511, 0.3119545028312132, 0.06820063295890577, 0.017202170492964797, 0.02253907689009793, 0.0176768555684248, 0.05358621638151817, 0.056326941776205786, 0.0576782479765825, 0.05642818556225393, 0.059918725019088015, 0.06056127276679035, 0.03063631807890488, 0.06311796780209988, 0.03482270076347049, 0.02113265323714586, 0.10656816870323382, 0.06028723844792694, 0.018568399427749682, 0.040374258533120155, 0.04295196005841717, 0.017815308783610817, 0.08306660049129277, 0.03399361048650462, 0.02870211796107469, 0.024051173095358536, 0.023220260845846497, 0.06376043762429617, 0.08267450160929002, 0.02014483427046798, 0.023308838026423473, 0.008882080910552759, 0.018432194920023903, 0.035814414150081575, 0.05266768246656284, 0.021377771627157927, 0.0817589288635645, 0.032639602868584916, 0.05572769092395902, 0.02318383994861506, 0.05113933322718367, 0.04144742262724321, 0.01811023827031022, 0.03891521104378626, 0.02391014091699617, 0.0222731468238635, 0.09072363493032753, 0.0543611818284262, 0.04544845207419712, 0.026981758419424295, 0.07727530304691754, 0.06883970374474302, 0.09959553543012589, 0.03847180378215853, 0.03346224759297911, 0.03926751596736722, 0.020334065229690168, 0.010609040000417735, 0.10568081241217442, 0.1594939033384435, 0.24149616016075015, 0.18355979322222993, 0.15258073835866526, 0.1683130519813858, 0.13052356021944433, 0.10390813331468962, 0.2177097779349424, 0.187908481748309, 0.14099469990469515, 0.2327666332712397, 0.11410608844016679, 0.19593656033976004, 0.2147778047947213, 0.13219821645179763, 0.14245060068788007, 0.1856309492723085, 0.1335011309129186, 0.10996353143127635, 0.1234061636205297, 0.17372246249578893, 0.1851284856093116, 0.2724494179710746, 0.10072279095766135, 0.26538527046795934, 0.14344080380396917, 0.141592915460933, 0.15224656410282478, 0.1596863570739515, 0.09833638541749679, 0.13819770858390257, 0.1411682288744487, 0.1676399091957137, 0.16119227861054242, 0.15266366594005376, 0.17236540094017982, 0.09433294399059378, 0.14392036478966475, 0.11888375316630118, 0.15801348199602216, 0.09908440348226577, 0.15514450235059485, 0.11601231701206416, 0.19152737193508074, 0.057549841585569084, 0.13374963164096698, 0.1000970639870502, 0.1357845263555646, 0.13940942793851718, 0.19556321552954614, 0.07259522331878543, 0.10949970397632569, 0.3270227723987773, 0.26909639476798475, 0.21585727343335748, 0.2368164886138402, 0.21276613930240273, 0.3078140609432012, 0.1757827535038814, 2.3551862966269255, 17.34451700001955, 51.78593538701534, 82.18894377350807, 103.39273318648338, 123.54774087667465, 123.62263485789299, 107.99725010991096, 107.13491678237915, 91.31338655948639, 95.65376445651054, 100.69164052605629, 95.07270723581314, 108.3156730234623, 88.40028047561646, 96.6236700117588, 100.58925122022629, 95.29113471508026, 67.43361353874207, 66.53271988034248, 49.611380472779274, 59.90730419754982, 118.64968210458755, 103.55366975069046, 119.60669115185738, 116.84620007872581, 111.81499645113945, 100.38909316062927, 82.85124063491821, 82.5852321088314, 68.74480158090591, 71.1488489806652, 76.30907848477364, 77.7299590408802, 81.27624794840813, 56.27851411700249, 56.745877638459206, 54.468606635928154, 59.24893632531166, 100.01675873994827, 94.72879528999329, 106.35859563946724, 109.35518324375153, 95.13392955064774, 100.10084062814713, 100.7956637442112, 104.50442433357239, 112.15605095028877, 120.45019268989563, 127.29172557592392, 125.62334910035133, 86.86166703701019, 59.83044192194939, 25.046876594424248, 2.9540712106972933, 0.9256416710559279, 0.3180009877542034, 0.20163710054475814, 0.12921294226543978, 0.40161015756893903, 0.1574409892782569, 0.09887948908726685, 0.1881720926030539, 0.13568098191171885, 0.2345119568053633, 0.20716534374514595, 0.13948147563496605, 0.13944622362032533, 0.09091692729271017, 0.17484503507148474, 0.14204624894773588, 0.16250850720098242, 0.10453948576468974, 0.1236313757544849, 0.21868084848392755, 0.19880138395819813, 0.16019815695472062, 0.10928446630714461, 0.18540357006713748, 0.09690150967799127, 0.21659103484125808, 0.10015338557423092, 0.09843923224252649, 0.14045741467271, 0.13794897036859766, 0.1013094290101435, 0.14319657784653828, 0.12461416481528431, 0.07752603021799587, 0.11570298243896104, 0.14584059768822044, 0.0900569191435352, 0.18823477439582348, 0.16349728539353237, 0.16121714055771008, 0.11846645837067626, 0.194309564831201, 0.1066419381822925, 0.15196672989986837, 0.14701146923471242, 0.15611266368068755, 0.164822137739975, 0.11599919584114105, 0.14977540529798716, 0.18661257316125557, 0.10112458228832111, 0.13707941077882424, 0.13103261415380985, 0.23684612999204546, 0.11334320515743457, 0.20109421951929107, 0.11308714194456115, 0.16001348092686385, 0.12486995343351737, 0.12037106906063855, 0.09971024177502841], [0.014756588880118215, 0.012505301529017743, 0.08139599638525397, 0.08041778637561947, 0.010234074525214965, 0.05247082037385553, 0.02479463437339291, 0.007980805639817845, 0.06501227748231031, 0.047545123161398806, 0.057206397905247286, 0.017615492943150457, 0.04372125549707562, 0.015377533636637963, 0.038806430748081766, 0.060224256085348316, 0.01083991935956874, 0.029042056848993525, 0.05026924300182145, 0.036065434469492175, 0.040415685216430575, 0.04714274553407449, 0.04819080277229659, 0.014787517884542467, 0.05007685977034271, 0.03803926898399368, 0.02240712859929772, 0.04632007112377323, 0.050501034274930134, 0.018478274869266897, 0.09276719792978838, 0.03854751026665326, 0.06463626094046049, 0.030553678079741076, 0.06752390559995547, 0.038521189999300987, 0.036087847329326905, 0.09985403288737871, 0.057536245440132916, 0.0529745716630714, 0.046127064488246106, 0.0646186868834775, 0.04674353687732946, 0.029781545781588648, 0.010535652727412526, 0.017546920353197493, 0.03918059934221674, 0.020566628336382564, 0.014003101186972344, 0.03000257220264757, 0.03253464092267677, 0.010192778645432554, 0.07171726261731237, 0.04065685352543369, 0.10828293801750988, 0.06630784468143247, 0.24452247511362657, 0.17262360895983875, 3.884284570813179, 14.165608529001474, 48.690397292375565, 66.01756632328033, 81.48359522223473, 84.33606415987015, 84.38865333795547, 72.14085415005684, 65.35388633608818, 70.81510528922081, 65.58446556329727, 75.72549819946289, 62.77984365820885, 49.54746030271053, 43.98534536361694, 47.60136812925339, 40.38000762462616, 37.654774859547615, 35.70545665919781, 33.91166411340237, 51.874064058065414, 55.97869120538235, 54.34313356876373, 51.413046196103096, 30.078633092343807, 27.73292776197195, 39.94132116436958, 69.1403679549694, 69.41041946411133, 54.883912950754166, 56.778118908405304, 42.371283173561096, 46.03921875357628, 37.77372747659683, 49.6393583714962, 34.07480835914612, 38.69522362947464, 37.371055483818054, 55.04565127193928, 26.21887620538473, 34.16398577392101, 23.395173624157906, 21.431249007582664, 38.24836380779743, 37.271892204880714, 47.877434715628624, 55.57719334959984, 71.38467952609062, 65.29943525791168, 61.59448966383934, 65.43091580271721, 65.3003092110157, 75.13061732053757, 81.57997325062752, 90.80974638462067, 91.04340344667435, 62.45242662727833, 41.948867440223694, 20.528102070093155, 3.0211791722103953, 0.23933746037073433, 0.20544578757835552, 0.10298132445313968, 0.05764414629084058, 0.03596323702367954, 0.06554300955031067, 0.044487693667178974, 0.057959343830589205, 0.05424598195531871, 0.05856559313542675, 0.03408663869777229, 0.07041615899652243, 0.04729797314212192, 0.03727086783328559, 0.0656759281991981, 0.056047805192065425, 0.05949407182924915, 0.09166988806100562, 0.04858438594965264, 0.016759262325649615, 0.04651740819099359, 0.06634098899667151, 0.016608357727818657, 0.08968116977484897, 0.0030433490974246524, 0.054310674968292005, 0.09701982286060229, 0.06300421140622348, 0.028307505053817295, 0.03309618325147312, 0.10801993572385982, 0.04056565841892734, 0.0650510992272757, 0.056786108543747105, 0.049712409600033425, 0.030039354896871373, 0.051027291192440316, 0.02687970012630103, 0.014090203349041985, 0.06263816932914779, 0.0900742260273546, 0.02466329464368755, 0.0699213171901647, 0.0505116655403981, 0.01011260907034739, 0.04566436509776395, 0.10191827212111093, 0.012818994364351965, 0.04243923249305226, 0.0795501415268518, 0.07080168245011009, 0.08479800875647925, 0.034049397727358155, 0.05413493810920045, 0.006925069492353941, 0.044728435241268016, 0.055053086107363924, 0.09743869843077846, 0.009785335860215127, 0.05913197797781322, 0.04602334192895796, 0.044382783671608195, 0.06973244802793488, 0.015573354867228772, 0.025140011348412372, 0.05679583438904956, 0.04664199623221066, 0.01781789516826393, 0.02587538692750968, 0.045335615941439755, 0.021885981368541252, 0.01026866324536968, 0.02387844564509578, 0.05111429687531199, 0.026057843933813274, 0.02174216613639146, 0.01182870033517247, 0.07025512779364362, 0.04719625067082234, 0.10279860027367249, 0.05688328164978884, 0.03428086987696588, 0.023375045020657126, 0.04198185430141166, 0.020656999658967834, 0.0693113608576823, 0.07926239602966234, 0.10691059564123861, 0.06798888338380493, 0.056307248887605965, 0.0782212518970482, 0.029377559549175203, 0.07425047981087118, 0.02378946399403503, 0.04744053600006737, 0.07717075670370832, 0.0923883166979067, 0.04795538239704911, 0.03362978000950534, 0.015392769000754924, 0.02534474577259971, 0.02502112114598276, 0.04311322503781412, 0.06485281221102923, 0.017769254809536505, 0.004483009834075347, 0.01184912145618, 0.06788790677092038, 0.031413315155077726, 0.02428812971629668, 0.03183897024428006, 0.08366762878722511, 0.03658061112219002, 0.14376046165125445, 0.20433865167433396, 1.8330328026786447, 12.383393961936235, 32.92020611464977, 73.86931300163269, 83.31134274601936, 94.17591735720634, 91.66016355156898, 100.83971858024597, 85.8262149989605, 86.80496647953987, 100.01537561416626, 98.6660984158516, 116.99399694800377, 101.98373839259148, 78.52643430233002, 73.84340599179268, 77.9100313782692, 63.38680408895016, 53.93734574317932, 48.506091982126236, 46.473463252186775, 47.867103070020676, 51.49406544864178, 44.81071427464485, 52.17234045267105, 56.97082556784153, 43.606452494859695, 63.44296507537365, 94.06432494521141, 91.72681957483292, 74.15034592151642, 64.52418565750122, 47.09385596215725, 45.441902205348015, 29.946677573025227, 43.497383147478104, 32.976693883538246, 41.18640415370464, 33.58225218951702, 51.225290670990944, 34.16512571275234, 31.909346356987953, 36.7555683106184, 30.479897260665894, 53.54526378214359, 58.83567050099373, 71.5775115787983, 91.25339537858963, 110.62239244580269, 94.49946239590645, 101.00957706570625, 98.05354088544846, 90.29792904853821, 90.98399743437767, 98.3523340523243, 109.32547643780708, 108.54650303721428, 90.65583944320679, 68.02171558141708, 39.68462213873863, 7.244175905361772, 0.33424363180529326, 0.384978954680264, 0.04701394951553084, 0.03974305080191698, 0.047776702922419645, 0.1174137886846438, 0.0059085688371851575, 0.055884310058900155, 0.011213600919290911, 0.04485582117922604, 0.0713160056329798, 0.046724159401492216, 0.07549839370767586, 0.06770488573238254, 0.04694795032264665, 0.026207705814158544, 0.0457547623955179, 0.010406563560536597, 0.05271323178021703, 0.022661616603727452, 0.08497269547660835, 0.031681972614023834, 0.046417125486186706, 0.004370826327431132, 0.02405685794656165, 0.1031972597411368, 0.07339289848459885, 0.035029485370614566, 0.07736149607808329, 0.05733239602704998, 0.04000330714916345, 0.0330008432501927, 0.0329793320997851, 0.03800644008151721, 0.07434438375639729, 0.036355577103677206, 0.05881108074390795, 0.040998412150656804, 0.03708164986164775, 0.006778820943509345, 0.04520061927905772, 0.03443467627221253, 0.05417380067228805, 0.026024415747087914, 0.012088822168152547, 0.013285932345752371, 0.045490171905839816, 0.008079920389718609, 0.04225686454446986, 0.031035890388011467, 0.09656110138166696, 0.011507714971230598, 0.034878692094935104, 0.05876367606106214, 0.07067778831697069, 0.045596644122269936, 0.05032778732129373, 0.08267148106824607, 0.0933712616097182, 0.11490711069200188, 0.1588267571059987, 0.1792695710901171, 0.11372139619197696, 0.08940169180277735, 0.094413941988023, 0.1159721148724202, 0.16704424662748352, 0.13198896049289033, 0.16389240481657907, 0.10931257143965922, 0.1051461543829646, 0.07853029703255743, 0.10086361347930506, 0.09742646041559055, 0.11792017830885015, 0.05911633721552789, 0.1585790578974411, 0.11368273029802367, 0.1872087552328594, 0.19637858349597082, 0.19720122450962663, 0.25701829756144434, 0.13164215488359332, 0.15860203478951007, 0.08625234360806644, 0.1307651589740999, 0.14039185334695503, 0.24698824592633173, 0.25786027894355357, 0.14159840735374019, 0.19343334075529128, 0.14490155823295936, 0.18540310993557796, 0.10431998074636795, 0.11819668769021519, 0.2907647914253175, 0.144877957936842, 0.25450743385590613, 0.13953768589999527, 0.15692466229666024, 0.20959283458068967, 0.11419164322433062, 0.13652204303070903, 0.12403641769196838, 0.17908450914546847, 0.22202640568139032, 0.16633996332529932, 0.1168982261151541, 0.10986847715685144, 0.18272328888997436, 0.29709507361985743, 0.10350504322559573, 0.2953922899905592, 0.2533845347352326, 0.29260021168738604, 0.8723804040346295, 8.814203683286905, 29.45381361991167, 77.189552038908, 95.1936699450016, 108.8862732052803, 107.13391363620758, 106.63646712899208, 88.37375029921532, 84.45545375347137, 94.5749719440937, 90.81390336155891, 101.0141672194004, 87.78076931834221, 69.64001834392548, 58.65501679480076, 59.91487719118595, 56.35779686272144, 47.16132514178753, 45.40787123143673, 46.560098603367805, 68.72404709458351, 73.44547614455223, 76.353300511837, 72.31651112437248, 44.468618631362915, 37.44866631925106, 51.133897975087166, 85.4159814119339, 83.41232612729073, 71.46392807364464, 71.54388338327408, 54.586126729846, 64.39567655324936, 50.14495924115181, 65.05262330174446, 51.5784627199173, 54.300594851374626, 54.722167029976845, 80.23162320256233, 40.39896860718727, 52.28398606181145, 38.59812743961811, 32.244689762592316, 54.116802513599396, 54.42147396504879, 65.99536031484604, 78.88517305254936, 95.41923344135284, 88.54606345295906, 86.6629908978939, 87.12794154882431, 85.19003033638, 94.94849190115929, 106.36063233017921, 117.27531865239143, 120.98930016160011, 94.73519414663315, 69.74585026502609, 35.5411496758461, 5.716437958180904, 0.2651817142032087, 0.5557490943465382, 0.2968117513228208, 0.21566867886576802, 0.15098786680027843, 0.25406365923117846, 0.14731514122104272, 0.15502574387937784, 0.19589890376664698, 0.18420592183247209, 0.17082519218092784, 0.18475560093065724, 0.1554427863447927, 0.09786800117581151, 0.11833889060653746, 0.18461196566931903, 0.18177752557676286, 0.14590571372536942, 0.15851112169912085, 0.11249416595092043, 0.3116449381923303, 0.13320430152816698, 0.08561475711758249, 0.1780954044079408, 0.20977341395337135, 0.2658340323250741, 0.1549517665989697, 0.11701807554345578, 0.15387992723844945, 0.14708482311107218, 0.18997597158886492, 0.11073117930209264, 0.2016862455639057, 0.22468559502158314, 0.19856972998240963, 0.09726870950544253, 0.2247878778143786, 0.18855496658943594, 0.15250894299242646, 0.15934649796690792, 0.19207884703064337, 0.08750156368478201, 0.15133039763895795, 0.11449034282122739, 0.0980880850693211, 0.16698454826837406, 0.15228374570142478, 0.12960875930730253, 0.1736365069518797, 0.10754280156106688, 0.13541159714804962, 0.1389087751158513, 0.08057545564952306, 0.10126554581802338, 0.11147934579639696, 0.23869379569077864, 0.16132525663124397, 0.12485755956731737], [0.07543856918346137, 0.018383044334768783, 0.023726524304947816, 0.011860708236781647, 0.037885202837060206, 0.03453021665336564, 0.05032169428886846, 0.031441761675523594, 0.040469576269970275, 0.030240215310186613, 0.08187735336832702, 0.06108632740506437, 0.0806050153914839, 0.029690953670069575, 0.02295528815011494, 0.024431315978290513, 0.13549584575230256, 0.054707263843738474, 0.028161582122265827, 0.01801589645765489, 0.03387025441043079, 0.061254616812220775, 0.08976753349998035, 0.009774343725439394, 0.05654147069435567, 0.009663028067734558, 0.021373146191763226, 0.04784439421200659, 0.033539586802362464, 0.028045666076650377, 0.07567130669485778, 0.04970968220732175, 0.02406871375569608, 0.047348910447908565, 0.042570110235828906, 0.03425780021643732, 0.026254381336912047, 0.05317045041010715, 0.03770890565647278, 0.07340852811466902, 0.022208847149158828, 0.03350885817781091, 0.03318352661153767, 0.057300646949443035, 0.06648279857472517, 0.03709278207679745, 0.048694843499106355, 0.05282840196741745, 0.03596203103370499, 0.04633707743778359, 0.004044468278152635, 0.015777901899127755, 0.027572296457947232, 0.08884547438356094, 0.14573911641491577, 1.6432240814901888, 16.022134758532047, 41.043877601623535, 62.89020113646984, 81.27085983753204, 77.32801660895348, 78.32980245351791, 72.12482661008835, 73.11651259660721, 57.384041994810104, 60.450443252921104, 52.21168354153633, 54.08151000738144, 54.18991059064865, 35.51710456609726, 43.37633304297924, 37.426665499806404, 33.899820148944855, 31.75848115235567, 42.634506449103355, 48.88549022376537, 57.240048721432686, 69.9403390288353, 77.81136587262154, 34.50187124311924, 61.04446157813072, 34.581461772322655, 32.38902881741524, 60.894141644239426, 32.80784994363785, 32.354975044727325, 39.86516945064068, 40.320027843117714, 56.81792177259922, 55.922188237309456, 56.052126064896584, 95.83756819367409, 78.86511012911797, 74.72231402993202, 55.261335298419, 80.81452712416649, 55.82101486623287, 59.68405097723007, 74.29831758141518, 62.11671844124794, 79.02839496731758, 49.553456380963326, 17.39722017198801, 65.89527368545532, 30.95992360264063, 29.849345795810223, 58.36886554956436, 36.97186790406704, 55.1569776982069, 60.90153604745865, 66.10411807894707, 66.08109891414642, 61.49726428091526, 65.65079480409622, 87.44771718978882, 83.85153695940971, 83.59146371483803, 44.288667887449265, 21.32074523717165, 5.3231006395071745, 0.4668699041940272, 0.13043007929809391, 0.0374799902056111, 0.060225484339753166, 0.06625620604609139, 0.02901300733356038, 0.061996319200261496, 0.07532801144407131, 0.057486543810227886, 0.07751825993182138, 0.09498347353655845, 0.03110668942099437, 0.0468078885023715, 0.02666348467755597, 0.03683314913359936, 0.06036619553924538, 0.033202072881977074, 0.04105571708350908, 0.020208265632390976, 0.06707952983560972, 0.050373815320199355, 0.06343443441437557, 0.15033534087706357, 0.08320533757796511, 0.029982563901285175, 0.02679766868823208, 0.07947050165967084, 0.022981192814768292, 0.041352405460202135, 0.007824949989299057, 0.02952193139208248, 0.0582552492414834, 0.07877808529883623, 0.047924234459060244, 0.01904825356177753, 0.007407329112538719, 0.08715698451851495, 0.050814999849535525, 0.024436473904643208, 0.04642985702957958, 0.025138122582575306, 0.047636180970584974, 0.04989821740309708, 0.04380029051390011, 0.01819390799937537, 0.019412321526033338, 0.0484446543850936, 0.06360305778798647, 0.027971508825430647, 0.05130956706125289, 0.03579646159778349, 0.00978985925030429, 0.11840526829473674, 0.004880199849139899, 0.04960757381923031, 0.08633160497993231, 0.0461730776441982, 0.027012130813091062, 0.12035616673529148, 0.045014169518253766, 0.04310751050070394, 0.012238730432727607, 0.05136470863362774, 0.0385981618455844, 0.03511592702125199, 0.019134181275148876, 0.017095982148020994, 0.05621007949230261, 0.020028734543302562, 0.03408387790841516, 0.0512907536176499, 0.022181255953910295, 0.09734453473356552, 0.02897467540606158, 0.013541524294851115, 0.06661231076577678, 0.05029862833907828, 0.08469453852740116, 0.013755314776062733, 0.03942284747608937, 0.04094262119906489, 0.04593627687427215, 0.08023836475331336, 0.05344596160284709, 0.06452981469919905, 0.009077758350031218, 0.02705770981265232, 0.08530750797945075, 0.04818539622647222, 0.042508404367254116, 0.05323301345924847, 0.035028991842409596, 0.060934832799830474, 0.01803167637262959, 0.06434373601223342, 0.04088242931175046, 0.023549061952508055, 0.03897403737937566, 0.039542804515804164, 0.04898372448224109, 0.05780563020380214, 0.06720994002535008, 0.06613228222704493, 0.04751066895551048, 0.10191682493314147, 0.031835645422688685, 0.04733116198622156, 0.1264983887085691, 0.004361922874522861, 0.08002357979421504, 0.22042825003154576, 6.949888346716762, 35.28885081410408, 63.90731155872345, 83.33260640501976, 97.54319787025452, 88.22328597307205, 92.00985878705978, 95.47632917761803, 100.37218406796455, 88.35917428135872, 106.44158318638802, 88.84060844779015, 77.1686227619648, 76.24860852956772, 51.10700301826, 54.85875830054283, 38.62776204943657, 38.53472024202347, 26.183864884078503, 29.608016945421696, 26.48446675390005, 21.313090547919273, 39.40703563392162, 51.08809143304825, 42.95430488884449, 51.84948317706585, 36.061478555202484, 18.174230977892876, 26.944595463573933, 15.596827380359173, 19.503169767558575, 18.12315221875906, 20.796033293008804, 30.76515555381775, 31.72106646001339, 43.31966668367386, 53.953479677438736, 54.131773710250854, 51.64170652627945, 37.1349361538887, 44.832635298371315, 41.74310848116875, 37.57871814072132, 48.98338817059994, 40.27787670493126, 50.53796075284481, 39.37084637582302, 19.695040471851826, 54.8606164008379, 30.985800214111805, 36.70444965362549, 62.57690414786339, 44.978080093860626, 74.21083867549896, 89.46521893143654, 95.10173007845879, 101.5437600016594, 87.43301957845688, 85.05249291658401, 103.66840839385986, 96.20287299156189, 99.24576491117477, 68.14593851566315, 43.70466962456703, 15.053677875548601, 0.9321397973690182, 0.28867790184449404, 0.06900111344293691, 0.15868953400058672, 0.04409038490848616, 0.05932821295573376, 0.036166043719276786, 0.01677891439612722, 0.02713282072363654, 0.02101773723552469, 0.06618526414968073, 0.029227629020169843, 0.05090438782644924, 0.018954071310872678, 0.04268818964192178, 0.030276593533926643, 0.06037213643139694, 0.04388631656183861, 0.06391348331817426, 0.06692224647849798, 0.06651079238508828, 0.028969411723664962, 0.07901013261289336, 0.0343180255003972, 0.04241775845002849, 0.10246510879369453, 0.06825365941040218, 0.05704355957277585, 0.011638178966677515, 0.03338616632390767, 0.0048137437715922715, 0.04208264908811543, 0.05176766142540146, 0.03416672014282085, 0.032472159509779885, 0.019360059486643877, 0.0022509485143018537, 0.032980215255520307, 0.049883741812664084, 0.029301407776074484, 0.015261576772900298, 0.008880294190021232, 0.02681846181076253, 0.035403089932515286, 0.024847644126566593, 0.04407679989526514, 0.042613511031959206, 0.09281839869800024, 0.022325664904201403, 0.031851056119194254, 0.049183573719346896, 0.050466446482460015, 0.08189498679712415, 0.019703631187439896, 0.03707994292199146, 0.05622381664579734, 0.11958408082136884, 0.11742293194402009, 0.17194369778735563, 0.1138351674308069, 0.1155322216800414, 0.16165108914719895, 0.15561322798021138, 0.136572954361327, 0.23602849105373025, 0.09814167555305175, 0.1779200349119492, 0.19814572617178783, 0.10806557038449682, 0.14234275178750977, 0.11570968403248116, 0.10265351782436483, 0.2602032688446343, 0.10460898789460771, 0.13733346277149394, 0.11477618842036463, 0.13009495509322733, 0.21229874953860417, 0.17025710782036185, 0.12312638878938742, 0.11482619433081709, 0.11599603429203853, 0.20102772308746353, 0.17793830658774823, 0.1848194404738024, 0.2240315402741544, 0.16561003139941022, 0.15232371777528897, 0.10794341287692077, 0.12163379622506909, 0.2369525984977372, 0.22425357601605356, 0.146848360018339, 0.1389441458741203, 0.1551066676620394, 0.213244883925654, 0.11526484071509913, 0.12139100261265412, 0.09220574836945161, 0.12096849794033915, 0.11760167079046369, 0.2280931215500459, 0.2279404320870526, 0.15693260327680036, 0.20155004662228748, 0.10068963179946877, 0.17578178871190175, 0.16821909608552232, 0.11914901158888824, 0.272976461565122, 0.17559415893629193, 4.260557005181909, 30.351785235106945, 65.2521961927414, 92.10432931780815, 111.25193506479263, 100.35564735531807, 101.30533799529076, 92.34643712639809, 96.04550823569298, 78.17085698246956, 84.84250098466873, 73.53602528572083, 69.0426903963089, 66.61870926618576, 43.47488075494766, 53.55297736823559, 50.78049413859844, 45.36357320845127, 42.92536944150925, 55.75900599360466, 64.46676313877106, 77.18806251883507, 93.4655910730362, 102.20445334911346, 44.385490491986275, 78.46996933221817, 46.39645658433437, 42.32491426169872, 76.74665540456772, 44.31887246668339, 44.55468401312828, 55.07174827158451, 53.21008376777172, 74.91618722677231, 77.70683348178864, 75.19952282309532, 129.8105952143669, 103.83100926876068, 107.20560058951378, 77.12582185864449, 107.59612083435059, 72.8829999268055, 81.08826443552971, 100.22100538015366, 83.81785556674004, 105.30679687857628, 79.0495066344738, 30.770100988447666, 92.30736002326012, 44.80476759374142, 43.56582507491112, 78.00216883420944, 48.44279497861862, 68.07925209403038, 80.14491945505142, 86.4648999273777, 87.70922675728798, 79.46803137660027, 83.99150624871254, 105.85935562849045, 109.18656349182129, 112.35344275832176, 73.7187422811985, 42.609689980745316, 11.780186779797077, 0.6026991968974471, 0.3233708714833483, 0.1715714661986567, 0.22752062883228064, 0.2195334277348593, 0.13650172302732244, 0.21017965074861422, 0.15822091227164492, 0.15742083254735917, 0.21373381081502885, 0.14718913938850164, 0.09984680436900817, 0.17926756729139015, 0.10043759844847955, 0.13782480906229466, 0.1458950713276863, 0.07980146241607144, 0.14124012814136222, 0.20731663797050714, 0.15578561404254287, 0.1810706002288498, 0.17484890908235684, 0.2887090720469132, 0.13544405868742615, 0.19453219429124147, 0.12331387755693868, 0.16687663999618962, 0.11447289492934942, 0.1578510703984648, 0.11851736970129423, 0.08185702594346367, 0.21135380258783698, 0.2111832273658365, 0.16855640220455825, 0.15888036985415965, 0.12224936319398694, 0.1681774467579089, 0.19502275390550494, 0.08899185559130274, 0.20837326330365613, 0.12836180278100073, 0.12790692562703043, 0.10027477866970003, 0.1818289267248474, 0.0682492510532029, 0.145252030051779, 0.2027477096999064, 0.20220457634422928, 0.1550767887965776, 0.08977475459687412, 0.14468922978267074, 0.15422180498717353, 0.14568902144674212, 0.07224835091619752, 0.15959020442096516, 0.10763943661004305], [0.0064502679924771655, 0.10001439615734853, 0.03845862695015967, 0.03655785687442403, 0.019211180951970164, 0.04124374390812591, 0.05500369989022147, 0.0012632322886929614, 0.016274745648843236, 0.02016641963564325, 0.06251918079215102, 0.05003163700166624, 0.020536864503810648, 0.10844782838830724, 0.03453187535342295, 0.042727957625174895, 0.027391041730879806, 0.022798756217525806, 0.06724750011926517, 0.047608721506549045, 0.01153463359514717, 0.0344220226543257, 0.0319609310827218, 0.016192202128877398, 0.052672658566734754, 0.04877745937847067, 0.05704493996745441, 0.016307940059050452, 0.007761879496683832, 0.02475276982295327, 0.019556591323635075, 0.03459903600742109, 0.027288892524666153, 0.040833506936905906, 0.015816426785022486, 0.015949811131577007, 0.014494686820398783, 0.031203446924337186, 0.05655998356814962, 0.033364903792971745, 0.06352499127388, 0.02179674553190125, 0.026798319922818337, 0.034259792882949114, 0.052523935883073136, 0.026816060963028576, 0.057905682842829265, 0.032323618652299047, 0.043515057186596096, 0.0705485358776059, 0.10917526669800282, 0.04940024002280552, 0.11024895400623791, 3.5383739322423935, 29.12038531154394, 62.896858379244804, 79.76154282689095, 85.75148060917854, 78.78299653530121, 75.36330163478851, 71.17480918765068, 61.364575400948524, 48.375671580433846, 45.28966337442398, 39.54545080661774, 25.269128568470478, 20.69636844098568, 34.10864554345608, 32.87034898996353, 41.99606470763683, 53.859400525689125, 60.17271235585213, 72.2949130833149, 77.25857153534889, 72.74705082178116, 75.86901649832726, 81.26668766140938, 69.90317702293396, 52.15565174818039, 43.14950801432133, 44.93539698421955, 49.83533285558224, 97.07328468561172, 84.72330138087273, 104.37677398324013, 88.93564134836197, 94.91340458393097, 78.04649725556374, 78.37508842349052, 68.52395743131638, 60.76354645192623, 54.281573072075844, 57.57429398596287, 62.0063229650259, 70.93547523021698, 66.97910472750664, 67.03469574451447, 67.2576829791069, 65.51942825317383, 109.01996523141861, 94.85945507884026, 61.32329061627388, 51.320433765649796, 52.24732182919979, 102.5687626004219, 68.46936196088791, 54.6006153523922, 61.31330855190754, 37.8048288077116, 34.66614402830601, 31.01162362843752, 43.42628136277199, 60.63622288405895, 60.61235636472702, 47.14402846992016, 70.31616926193237, 69.23412412405014, 83.0732399225235, 74.69199165701866, 57.884114161133766, 19.720406010746956, 2.1285096975043416, 0.2817352884449065, 0.19636286480817944, 0.022615312154812273, 0.05202501226449385, 0.03171519114403054, 0.0014832638839834544, 0.02922450457845116, 0.06295414612395689, 0.09615297210984863, 0.10196217015618458, 0.023441060911864042, 0.03586960396205541, 0.014917436401447048, 0.08407045170315541, 0.05391620121372398, 0.04479386298044119, 0.03208950445696246, 0.014938730473659234, 0.07121959322830662, 0.06109281748649664, 0.016318742018484045, 0.03818110082647763, 0.017283496890740935, 0.07701135822571814, 0.05583876816672273, 0.043518133388715796, 0.029413126976578496, 0.028993709638598375, 0.016705671841918956, 0.013364207588892896, 0.02194539956690278, 0.04067492482136004, 0.0699659351084847, 0.036586641072062775, 0.021528629840759095, 0.03097595454164548, 0.021967780885461252, 0.05043414821557235, 0.024932185879151803, 0.03041768322873395, 0.03142651425150689, 0.04040205938508734, 0.02849300486559514, 0.027965939007117413, 0.08829370985040441, 0.027414643882366363, 0.03818192089966033, 0.047995005661505274, 0.06389504094840959, 0.04854835096921306, 0.022910640545887873, 0.03126486706605647, 0.07815710065187886, 0.050422496497048996, 0.0522946790442802, 0.09213517754687928, 0.06174859772727359, 0.0471419477253221, 0.025226447432942223, 0.04823321651201695, 0.008421699803875526, 0.03529828383761924, 0.0333119738206733, 0.03953297848056536, 0.0388757844484644, 0.019037854217458516, 0.023224030956043862, 0.05306179999024607, 0.050776901698554866, 0.006430644680222031, 0.0705227091384586, 0.011616438678174745, 0.05560326615523081, 0.01883595479739597, 0.027371133619453758, 0.03259206459915731, 0.02185496145102661, 0.02601245232654037, 0.09269826725358143, 0.042294517406844534, 0.02501527858839836, 0.03307361825136468, 0.06715509531204589, 0.028968645456188824, 0.09898530450300314, 0.050214131115353666, 0.03293943052995019, 0.047239740524673834, 0.04487342121137772, 0.021081730774312746, 0.031167697670753114, 0.06599487358471379, 0.08280572073999792, 0.022418390690290835, 0.042691692578955553, 0.049637037081993185, 0.040298585445270874, 0.03974329199991189, 0.030868012872815598, 0.056391100442851894, 0.05703856120817363, 0.06500428455183282, 0.012502396948548267, 0.024823949206620455, 0.2141651915735565, 0.06744799873558804, 0.4404886916745454, 12.874938435852528, 51.47220142185688, 84.58400085568428, 92.82226279377937, 96.93973705172539, 92.2987648844719, 96.26322135329247, 96.43541291356087, 92.13115587830544, 82.0732931792736, 73.63198533654213, 52.310694828629494, 28.191798739135265, 19.32784527540207, 27.395773753523827, 18.711833730340004, 17.454840280115604, 24.237985499203205, 36.269589588046074, 25.17924629151821, 40.58929659426212, 46.47822439670563, 47.25444674491882, 63.574460819363594, 54.93150159716606, 54.31696057319641, 32.34975792467594, 38.229296430945396, 38.531631007790565, 63.193310871720314, 55.905001759529114, 66.4002437889576, 55.58397218585014, 59.7729168087244, 52.55702421069145, 52.045165076851845, 49.78896014392376, 47.636611238121986, 49.82995234429836, 54.0168184787035, 56.28120817244053, 63.11346955597401, 59.646828174591064, 58.37201938033104, 64.78921383619308, 63.993019759655, 92.2805106639862, 82.94954136013985, 52.359959185123444, 34.01249550282955, 45.12404926121235, 73.90629261732101, 44.79798875749111, 41.248508021235466, 37.92442359030247, 28.33118285983801, 31.776380091905594, 21.753112636506557, 52.26898826658726, 90.81573486328125, 88.0537086725235, 80.37013337016106, 98.82742255926132, 92.55433917045593, 99.82120603322983, 92.03334912657738, 77.96984016895294, 39.82339829206467, 7.229879647493362, 0.40826493641361594, 0.3117084957193583, 0.18702624627621844, 0.09570812137098983, 0.04029796204122249, 0.08005441603017971, 0.028879379933641758, 0.039215550787048414, 0.06635592842940241, 0.04506696219323203, 0.02368208264670102, 0.019789798243436962, 0.08633983539766632, 0.10170214387471788, 0.10279859285219572, 0.019358092795300763, 0.08438480319455266, 0.05720552217098884, 0.05073256579635199, 0.0538832646998344, 0.05097656168800313, 0.01895375404274091, 0.029131932788004633, 0.0288402854494052, 0.06026966810168233, 0.08834813153953291, 0.03345318225910887, 0.02704217295104172, 0.0461793191061588, 0.08610922785010189, 0.07357767099165358, 0.023430720939359162, 0.03813321003690362, 0.028837444879172835, 0.012468322165659629, 0.03162853427056689, 0.05718629683542531, 0.031088870455278084, 0.009848775571299484, 0.06537302062497474, 0.06457671843236312, 0.08038133950321935, 0.06647793008596636, 0.06166378138004802, 0.027155738243891392, 0.057259609893662855, 0.06993224160396494, 0.029462839738698676, 0.03501113948004786, 0.043288446104270406, 0.02464005799993174, 0.033672535137156956, 0.0074623867294576485, 0.05728092808567453, 0.12165632782853208, 0.2677225013030693, 0.16624351381324232, 0.067970322270412, 0.1115275186020881, 0.14229289430659264, 0.1494836967322044, 0.12887032236903906, 0.126480309991166, 0.11729419158655219, 0.14440351777011529, 0.19103981059743091, 0.1376920091570355, 0.25847884418908507, 0.09119999725953676, 0.09357018687296659, 0.1687037927331403, 0.18468114867573604, 0.15730253420770168, 0.2018553068046458, 0.14260397292673588, 0.22862481098854914, 0.200566211133264, 0.1071169349597767, 0.2234327606856823, 0.15664131031371653, 0.14677934028441086, 0.10446551590575837, 0.16433050943305716, 0.14747709268704057, 0.11107417027233168, 0.12417850928613916, 0.14508310239762068, 0.1518498861696571, 0.15779882320202887, 0.10486268365639262, 0.14913935505319387, 0.2032327774213627, 0.16343804716598243, 0.13269958173623309, 0.14775870804442093, 0.11321011581458151, 0.1320938259596005, 0.15305670734960586, 0.17333394818706438, 0.11956536385696381, 0.15472965664230287, 0.136604955769144, 0.10047195988590829, 0.11595527554163709, 0.29193744412623346, 0.09993088227929547, 0.2530059206765145, 8.52662656456232, 44.68362629413605, 90.42390748858452, 107.24023953080177, 108.67012560367584, 97.56199926137924, 95.21969854831696, 90.23347690701485, 81.37479186058044, 65.90212091803551, 58.04658204317093, 50.31856432557106, 31.87746226787567, 29.13326282054186, 50.06087355315685, 50.8965665102005, 61.95970706641674, 76.37419939041138, 82.64331579208374, 93.66020143032074, 107.73485898971558, 99.80061113834381, 104.84952941536903, 116.85883060097694, 99.4542521238327, 73.42098265886307, 63.50683204829693, 66.55726656317711, 71.54472693800926, 139.0445101261139, 120.63628390431404, 145.64246088266373, 119.0901392698288, 131.76767259836197, 110.28055518865585, 112.64398276805878, 98.72086107730865, 90.78529849648476, 80.14321714639664, 82.39860892295837, 86.36216104030609, 102.57393032312393, 93.32696691155434, 90.97637504339218, 92.13956862688065, 86.1961479485035, 142.52867996692657, 119.87146854400635, 89.71827015280724, 74.03731718659401, 76.77475109696388, 131.8840679526329, 93.19936215877533, 76.09034702181816, 83.31610009074211, 54.30212616920471, 47.40419290959835, 45.6978602707386, 57.00069956481457, 77.36083164811134, 84.82316762208939, 66.4492079615593, 89.95790049433708, 90.1687739789486, 108.34912642836571, 105.4500187933445, 87.9895681142807, 39.737215116620064, 5.371224582195282, 0.30688884027767926, 0.3928441466996446, 0.46911736484616995, 0.19320370542118326, 0.14526806044159457, 0.17837178020272404, 0.11384603247279301, 0.17460774077335373, 0.16060702095273882, 0.28325197112280875, 0.07543026455095969, 0.09353058587294072, 0.2629749826155603, 0.3005839989054948, 0.17644510546233505, 0.11686303347232752, 0.1957894369843416, 0.12352725243545137, 0.16408655064878985, 0.1729514155886136, 0.20810203801374882, 0.14195916533935815, 0.04400470024847891, 0.20511136099230498, 0.12867348996223882, 0.17747574078384787, 0.07690815516980365, 0.08812727581243962, 0.15541865170234814, 0.13324762810952961, 0.19717370567377657, 0.08042414658120833, 0.1975355768809095, 0.08580142210121267, 0.08717869233805686, 0.07619987169164233, 0.09840721599175595, 0.16653854720061645, 0.1419448122032918, 0.1585138082737103, 0.13819779764162377, 0.18504742824006826, 0.15265229623764753, 0.2037554868729785, 0.19586158858146518, 0.18015897570876405, 0.15094238799065351, 0.14037481363629922, 0.17808995704399422, 0.15229464042931795, 0.11123674514237791, 0.09555329452268779, 0.15451712039066479, 0.23028720694128424], [0.06976965189096518, 0.08766694387304597, 0.03596173788537271, 0.08593835576903075, 0.03516400705848355, 0.019392957037780434, 0.04030406991660129, 0.015149197988648666, 0.024589681015640963, 0.04593369048961904, 0.03985489616752602, 0.025857146792986896, 0.015243101006490178, 0.06876028652186505, 0.02418404536001617, 0.11039970646379516, 0.02569950906035956, 0.06003741298627574, 0.0045325625706027495, 0.05272851631161757, 0.08481622848194093, 0.031853649925324135, 0.04157361741818022, 0.028890235698781908, 0.026821773644769564, 0.05319463700288907, 0.013366292096179677, 0.034927428932860494, 0.02932406925538089, 0.0194828867824981, 0.046330691257026047, 0.030713007909071166, 0.01067161047103582, 0.04074282020155806, 0.004790028442585026, 0.040966911692521535, 0.0328268207522342, 0.09476727107539773, 0.054492118943016976, 0.03572858477127738, 0.006405432532119448, 0.05590518667304423, 0.08332130557391793, 0.019151252527080942, 0.13064052269328386, 0.09445170988328755, 0.081990805483656, 0.035910752339987084, 0.04136817609833088, 0.03922211137250997, 0.03051436837267829, 1.2059124349616468, 29.441496580839157, 68.00857588648796, 89.53255131840706, 85.01367419958115, 79.68345701694489, 65.10974943637848, 63.468309715390205, 59.427294954657555, 46.64076067507267, 43.926486521959305, 35.84870137274265, 29.628906324505806, 40.21177165210247, 68.33710625767708, 101.42664268612862, 64.21012490987778, 78.66299137473106, 114.28276643157005, 69.68104854226112, 62.12879799306393, 85.79693377017975, 53.816257640719414, 46.11905246973038, 47.002379670739174, 30.44827725738287, 28.62768094986677, 29.187333919107914, 49.16878402233124, 36.788227558135986, 42.011742666363716, 36.61981299519539, 28.580933958292007, 26.220928095281124, 28.839342892169952, 22.13161412626505, 25.286199152469635, 28.472371883690357, 22.97976851463318, 21.323767974972725, 22.26929783821106, 22.35440757125616, 18.6226050183177, 17.576523050665855, 25.153172090649605, 30.88616006076336, 34.69097189605236, 35.177068412303925, 25.822870954871178, 31.16581555455923, 40.25483854115009, 47.30537921190262, 51.227110773324966, 49.28643710911274, 66.75224930047989, 55.841674357652664, 71.80410102009773, 75.57292118668556, 87.22865894436836, 94.61406424641609, 49.65948589146137, 33.533231019973755, 37.84867845475674, 34.69148486852646, 49.207644537091255, 54.36044543981552, 62.179886251688, 68.3156830072403, 71.8306615948677, 69.45216402411461, 48.78240555524826, 22.501615472137928, 1.7650396074168384, 0.26105234515853226, 0.09481105036684312, 0.08709949033800513, 0.03616627007431816, 0.04245072836056352, 0.044013505830662325, 0.050736918492475525, 0.052968504605814815, 0.05671427607012447, 0.02915217115514679, 0.019888192182406783, 0.01830096651247004, 0.04500209106481634, 0.04366000233858358, 0.03300039054010995, 0.024157257539627608, 0.0581889197928831, 0.03682975751871709, 0.051861609899788164, 0.06946153444005176, 0.019196939138055313, 0.03139051637845114, 0.05582178411714267, 0.03592689776269253, 0.06388076944858767, 0.02434538269881159, 0.03133735262963455, 0.048785441176733, 0.04051957104820758, 0.023370454837277066, 0.09028745247633196, 0.005613291468762327, 0.05991278412693646, 0.04239734567818232, 0.07131116683012806, 0.02749375496932771, 0.05462062552396674, 0.015645038911316078, 0.05610280204564333, 0.07299616860109381, 0.047234656813088804, 0.04571152116113808, 0.021268772397888824, 0.02167968101275619, 0.04195347457425669, 0.0878120560082607, 0.02455759055010276, 0.026347203602199443, 0.016313437517965212, 0.0551641930360347, 0.06645765461144038, 0.03729326585016679, 0.03521177168295253, 0.04008530704595614, 0.017691987959551625, 0.07805035013007, 0.07028047213680111, 0.0866130793292541, 0.0305226878481335, 0.03451394135481678, 0.01812231301300926, 0.05705366020265501, 0.012396423826430691, 0.03626888312282972, 0.021539799163292628, 0.06610240336158313, 0.04724810081825126, 0.04775277237058617, 0.03736458624189254, 0.03486763780529145, 0.00692043756316707, 0.07471055199857801, 0.08060718988417648, 0.06593798054382205, 0.0493222736986354, 0.024397876659350004, 0.022180074083735235, 0.04247010583640076, 0.022678051464026794, 0.028246630390640348, 0.08012955848244019, 0.0550144498993177, 0.006075720903027104, 0.051354578317841515, 0.07610122542246245, 0.032775783256511204, 0.019148332175973337, 0.033426594818593, 0.016025283839553595, 0.08295544161228463, 0.004481581199797802, 0.03318610557471402, 0.027605153190961573, 0.05749919742811471, 0.054594205066678114, 0.04060859908349812, 0.11297049117274582, 0.029024705436313525, 0.0764304050244391, 0.0194372947953525, 0.08307134281494655, 0.12482833379181102, 0.059640723920892924, 5.228850021958351, 52.1956218034029, 87.73144036531448, 97.11427688598633, 95.8898837864399, 97.73145496845245, 87.13802620768547, 93.17499026656151, 97.25329622626305, 80.8640156686306, 65.73625981807709, 46.124315187335014, 26.63972072303295, 29.53516535460949, 43.76078121364117, 73.7051922082901, 49.46115933358669, 57.76063218712807, 88.70804876089096, 56.11250102519989, 51.01929612457752, 72.80053675174713, 53.58762010931969, 49.772526025772095, 48.87517757713795, 29.9351204931736, 26.064724177122116, 31.042179688811302, 45.84354065358639, 33.75739239156246, 40.090805143117905, 38.62285651266575, 30.184977985918522, 29.331783168017864, 29.969444051384926, 24.309391267597675, 25.779750868678093, 27.16883473098278, 21.82343926280737, 21.106282845139503, 19.75483026355505, 17.487111948430538, 10.80618504434824, 11.51321405544877, 19.740202948451042, 26.218209341168404, 25.244530588388443, 26.29058215767145, 23.320777416229248, 34.042358100414276, 39.75032441318035, 45.771644711494446, 52.39954546093941, 53.31411458551884, 59.935050308704376, 55.50592057406902, 63.58302555978298, 56.88279949128628, 62.8831373155117, 88.31723973155022, 39.34631869196892, 21.088465601205826, 31.328026950359344, 39.99470070004463, 74.55760806798935, 83.69680166244507, 87.7506597340107, 88.59487563371658, 88.20639207959175, 90.75065955519676, 73.5097686946392, 43.66759121417999, 8.716821558773518, 0.20847553125349805, 0.17652703856583685, 0.08050628006458282, 0.06758772287867032, 0.015946248822729103, 0.04432222442119382, 0.03747283590200823, 0.030806531503912993, 0.041182264394592494, 0.014798971078562317, 0.03155030819470994, 0.03624894903623499, 0.03424374393944163, 0.019084986161033157, 0.016757377270550933, 0.05594040158030111, 0.0875688913220074, 0.06241879047593102, 0.013990101542731281, 0.043984024014207534, 0.04986572988855187, 0.03684299372253008, 0.030829506540612783, 0.01992158140637912, 0.04675423864682671, 0.02598479433800094, 0.03642399198724888, 0.021358631638577208, 0.09330358516308479, 0.014388920571946073, 0.030079647949605715, 0.027303527676849626, 0.10283761497703381, 0.02537109572585905, 0.06816777808126062, 0.0831769875367172, 0.03581212091376074, 0.022402725808206014, 0.03437867380853277, 0.06047276794561185, 0.05795446049887687, 0.020620899740606546, 0.049527180672157556, 0.02539915261877468, 0.06035864047589712, 0.038557061707251705, 0.07563474850030616, 0.006712340746162226, 0.06649063565419056, 0.037440712039824575, 0.04607847236911766, 0.03713047946803272, 0.17469126207288355, 0.17748672456946224, 0.1751281347242184, 0.23531145765446126, 0.166148281423375, 0.24165944749256596, 0.1197715027956292, 0.12663939676713198, 0.17357257835101336, 0.17199426773004234, 0.19349496869836003, 0.09748746495461091, 0.12795691669452935, 0.14577294350601733, 0.13637935771839693, 0.14447497174842283, 0.10805980389704928, 0.19889909512130544, 0.11510547934449278, 0.2834864007309079, 0.2146180352428928, 0.20273579080821946, 0.12357917308690958, 0.07437847802066244, 0.12517605966422707, 0.16477011318784207, 0.08148990775225684, 0.11939469957724214, 0.1552270885440521, 0.12692736490862444, 0.11789939817390405, 0.12009075246169232, 0.16278011840768158, 0.17666561238002032, 0.06553143946803175, 0.10806601567310281, 0.15251614182488993, 0.23846981552196667, 0.20328659797087312, 0.1233887008856982, 0.09576301061315462, 0.3041042428230867, 0.15599613165250048, 0.10364289715653285, 0.30163176299538463, 0.16156170488102362, 0.18421506509184837, 0.13180370558984578, 0.12854520231485367, 0.2188262648996897, 0.14592392602935433, 2.9411709029227495, 48.29763896763325, 97.23055064678192, 111.4644804596901, 103.36910605430603, 97.6330478489399, 84.0454937517643, 84.28709998726845, 77.00951009988785, 65.97580656409264, 53.980834409594536, 46.429351419210434, 39.61789771914482, 60.15467472374439, 97.66539931297302, 142.2286632657051, 89.50149178504944, 102.54540145397186, 145.04352182149887, 99.36482012271881, 84.94133368134499, 120.10610595345497, 78.32450553774834, 67.81425431370735, 76.19661971926689, 46.255157366395, 48.156636133790016, 46.83047689497471, 74.6791635453701, 59.445834159851074, 63.45345251262188, 56.08440153300762, 47.110043093562126, 42.12262071669102, 45.83252124488354, 38.113205060362816, 40.854537561535835, 46.21666543185711, 36.460498943924904, 37.71577678620815, 39.635179191827774, 36.26382529735565, 31.341622620821, 26.444519497454166, 39.69060681760311, 47.64966733753681, 50.50573468208313, 54.03734877705574, 42.21253149211407, 53.925463780760765, 70.66381260752678, 79.35415908694267, 78.53050008416176, 79.43612828850746, 94.23647850751877, 81.26828357577324, 96.1527156829834, 100.98351046442986, 113.67677494883537, 116.10720813274384, 66.30105391144753, 43.43095891177654, 52.810835391283035, 47.07782082259655, 66.26889243721962, 75.73404014110565, 80.81996843218803, 87.42182537913322, 94.7529011964798, 98.8038182258606, 78.90880778431892, 41.58782601356506, 5.193777903914452, 0.34606865665409714, 0.2780334261478856, 0.20651364902732894, 0.1814069415559061, 0.0811131861701142, 0.2302350488025695, 0.1581171154975891, 0.122635064763017, 0.14848725957563147, 0.13151579682016745, 0.09408584592165425, 0.0984249310567975, 0.1448793531744741, 0.12275020155357197, 0.17459044873248786, 0.15555254998616874, 0.1835558598395437, 0.165809357422404, 0.11127383768325672, 0.3134782804409042, 0.094007423176663, 0.07277923883520998, 0.08426955508184619, 0.19361797225428745, 0.14838178554782644, 0.11733249382814392, 0.1071702731132973, 0.15685107093304396, 0.19055020093219355, 0.07223714448628016, 0.2194849803345278, 0.13741070550167933, 0.1608440777636133, 0.108084918174427, 0.2545473020290956, 0.13205959810875356, 0.11685915946145542, 0.1210817125684116, 0.09962293552234769, 0.1971850753761828, 0.16068272001575679, 0.2117621767683886, 0.1726530573796481, 0.1373786001931876, 0.13830806594341993, 0.14804725506110117, 0.2635928650852293, 0.12394738223520108, 0.11388219732907601, 0.1400869493954815, 0.14904971845680848, 0.170710782695096], [0.056926719553302974, 0.058572999769239686, 0.016871233856363688, 0.015906553198874462, 0.0744308736466337, 0.07448803386068903, 0.024277735938085243, 0.048829788211151026, 0.016176353565242607, 0.06370674323989078, 0.05440100547275506, 0.01889671999379061, 0.10092421725858003, 0.041953745458158664, 0.040061691906885244, 0.10801697455463, 0.010111493065778632, 0.030769973309361376, 0.052293985136202537, 0.032913666873355396, 0.013605525255115936, 0.013585672804765636, 0.025596901577955578, 0.054800481302663684, 0.007662023990633315, 0.04246458054694813, 0.03438941639615223, 0.02572358618635917, 0.08195567221264355, 0.03307506543933414, 0.06343772212858312, 0.002840305610334326, 0.08252983476268128, 0.09043335128808394, 0.02438996536511695, 0.05561022007896099, 0.030526595255651046, 0.028303903782216366, 0.03501483537547756, 0.05482415210281033, 0.06521198200061917, 0.021717602903663646, 0.050075676044798456, 0.10675531608285382, 0.07225170542369597, 0.017464894481236115, 0.11637815870926715, 0.07468137075193226, 0.1774630500585772, 1.511763366870582, 12.880747374147177, 47.17014066874981, 78.93141657114029, 79.875468313694, 72.70861208438873, 71.90139099955559, 61.57012157142162, 68.77858936786652, 32.04511307179928, 41.52331307530403, 25.231164805591106, 35.50010807812214, 48.236006274819374, 72.75653511285782, 40.095874071121216, 81.70170351862907, 102.8127171099186, 41.11072361469269, 54.745672568678856, 26.593458205461502, 32.46611528098583, 41.654086858034134, 31.488984413444996, 22.821674197912216, 30.007806792855263, 11.062651332467794, 3.8464041659608483, 0.7905941864009947, 2.631469233892858, 0.25005840696394444, 0.40044112654868513, 0.6716581340879202, 3.0648431042209268, 1.4963963977061212, 2.1975942654535174, 0.3637608635472134, 0.5304505268577486, 0.17129382875282317, 0.19703642319655046, 0.09521738364128396, 0.3477418137481436, 0.5683932127431035, 0.22441998036811128, 0.05986211028357502, 0.07305437524337322, 0.25976712349802256, 1.3797851675190032, 4.3920128513127565, 5.9137119725346565, 5.395813062787056, 5.379918040707707, 4.345997795462608, 7.771859290078282, 19.875126108527184, 18.73358566313982, 17.979386933147907, 21.680152751505375, 25.42188987135887, 39.616434797644615, 48.83420817553997, 53.29562097787857, 91.32835775613785, 89.8099136352539, 51.46497800946236, 51.92403517663479, 33.744739070534706, 30.729598961770535, 42.4369702488184, 55.23348659276962, 50.43771833181381, 56.49870850145817, 75.65140977501869, 78.14909934997559, 56.49870090186596, 15.97571074962616, 1.1295690690167248, 0.10875369713176042, 0.03998008534836117, 0.022132929152576253, 0.023951233633852098, 0.07524826767621562, 0.016278643779514823, 0.021292404235282447, 0.023153597430791706, 0.05863743674126454, 0.06860223875264637, 0.03401709574973211, 0.08008356016944163, 0.02142251942132134, 0.020079875939700287, 0.0069450392948056106, 0.028587619417521637, 0.049938055890379474, 0.014780507372051943, 0.06796975081670098, 0.05674825901223812, 0.007252883542605559, 0.05974535190034658, 0.03783607637160458, 0.07294119772268459, 0.0520789144502487, 0.021961515303701162, 0.03831125497526955, 0.05131294012244325, 0.057775428504101, 0.0386556820012629, 0.11471470148535445, 0.009836985627771355, 0.04024171095807105, 0.045988286583451554, 0.008731143843760947, 0.009122173105424736, 0.0372878407506505, 0.048681484840926714, 0.04603213266818784, 0.022124771094240714, 0.02723061352298828, 0.02465309196850285, 0.02720501128351316, 0.03961351634643506, 0.059980660953442566, 0.023868992539064493, 0.02165010642784182, 0.05773043951194268, 0.0327555114927236, 0.0326991861948045, 0.04431126290000975, 0.03250417204981204, 0.021343985354178585, 0.046995444063213654, 0.07441591937094927, 0.0909789114666637, 0.035372242564335465, 0.02318418690265389, 0.035570518448366784, 0.02374508727370994, 0.06473933783126995, 0.02593424665974453, 0.05744569600210525, 0.027432190108811483, 0.06429080603993498, 0.030188333621481434, 0.04889575400738977, 0.030861801096762065, 0.04152233501372393, 0.08858624220010825, 0.01871974003734067, 0.05007940162613522, 0.0278803359833546, 0.052793268696404994, 0.06665888795396313, 0.014086885948927375, 0.013643060301546939, 0.041650418570498005, 0.06090850140026305, 0.039243700448423624, 0.060460025270003825, 0.07587170141050592, 0.045408153455355205, 0.06726214269292541, 0.04170363426965196, 0.09879587130853906, 0.0631866164621897, 0.04673961462685838, 0.051930648187408224, 0.035021934018004686, 0.10409534748760052, 0.034008624134003185, 0.050209388791699894, 0.11427817022195086, 0.07513967662816867, 0.030842328997096047, 0.1333227482973598, 0.034763455114443786, 0.22018996125552803, 5.755544034764171, 28.72772768139839, 70.45706570148468, 87.78409034013748, 93.0058765411377, 90.85763901472092, 102.27595791220665, 92.11949050426483, 98.60442012548447, 41.95395916700363, 46.36991500854492, 23.818368315696716, 22.310780212283134, 21.504585072398186, 44.00233805179596, 29.55874688923359, 72.83013716340065, 99.25678431987762, 44.45666827261448, 53.98435302078724, 30.077954828739166, 34.30553957819939, 40.93126684427261, 33.874874487519264, 16.439882442355156, 20.841999426484108, 8.427354041486979, 3.021486480720341, 0.2655403793323785, 0.7647174561861902, 0.5216034734621644, 0.09013022849103436, 0.6821105419658124, 0.9280798339750618, 0.44637953338678926, 1.1240548524074256, 0.18286201113369316, 0.13525834365282208, 0.08360459076357074, 0.3146960260346532, 0.2579986449563876, 0.6020224175881594, 0.126004162884783, 0.731224687770009, 0.4588805657112971, 0.6044074427336454, 0.6946150178555399, 0.323064275435172, 0.7387525588274002, 1.8839879496954381, 1.900231009349227, 2.8870292706415057, 2.0855986000970006, 7.194552943110466, 20.470903739333153, 19.154029302299023, 18.851706124842167, 24.085288792848587, 28.225711919367313, 42.740889340639114, 46.8632273375988, 63.0708434432745, 85.12226477265358, 74.10183772444725, 52.32665777206421, 27.28098001331091, 18.181253001093864, 29.773549363017082, 58.25747832655907, 83.44242811203003, 77.23809063434601, 75.58500453829765, 91.55640631914139, 92.77541890740395, 77.75976464152336, 35.52287645637989, 7.528631491586566, 0.23836542502976954, 0.19094916468020529, 0.03243846971599851, 0.04646053370379377, 0.05867226573172957, 0.05525928812858183, 0.025933107463060878, 0.06161970151879359, 0.04322594242694322, 0.006748985679223551, 0.04473815737583209, 0.01367077580653131, 0.07633319110027514, 0.09019524062750861, 0.03454420242633205, 0.05681846247171052, 0.017485136559116654, 0.045869984533055685, 0.026040071352326777, 0.02805741056363331, 0.0588577024609549, 0.09607541025616229, 0.01822926391469082, 0.029389346709649544, 0.01843966278102016, 0.0044173455353302415, 0.02666802662133705, 0.026242581188853364, 0.05203926521062385, 0.04328177048591897, 0.08786955018877052, 0.040508995443815365, 0.026792662902153097, 0.09087164886295795, 0.040813665618770756, 0.03804165869951248, 0.038849234115332365, 0.00853289207952912, 0.055428653649869375, 0.047981268508010544, 0.04217024106765166, 0.02789359074085951, 0.039803112813388, 0.098354397341609, 0.02690327073651133, 0.09875536488834769, 0.06755413327482529, 0.04680763988289982, 0.036882865606457926, 0.04130285597057082, 0.18137871025828645, 0.18409945332678035, 0.1100546820089221, 0.15092482877662405, 0.31226564082317054, 0.18816004012478516, 0.10827536811120808, 0.14562308904714882, 0.1171075711317826, 0.147597172181122, 0.1844731840537861, 0.09202157700201496, 0.20390427263919264, 0.12337107487837784, 0.1324903406202793, 0.21109243301907554, 0.12490113847889006, 0.122713146120077, 0.16486518230522051, 0.3834155760705471, 0.12872578168753535, 0.16942348302109167, 0.12291152219404466, 0.15002870030002668, 0.15025489206891507, 0.06652368349023163, 0.1318942179204896, 0.18485777982277796, 0.19406076724408194, 0.11153045750688761, 0.13550479605328292, 0.12742405466269702, 0.18606673838803545, 0.21721846133004874, 0.14918409171514213, 0.16818558069644496, 0.10480243610800244, 0.08667310423334129, 0.14558187016518787, 0.14597998786484823, 0.1559764053672552, 0.0905300976592116, 0.20734258345328271, 0.18981897766934708, 0.2293486424605362, 0.13007703964831308, 0.24193462100811303, 0.15193653933238238, 0.30265405657701194, 3.266445086337626, 24.51882652938366, 74.7667108476162, 102.32219383120537, 101.28484949469566, 91.30228355526924, 94.01904657483101, 78.97719651460648, 85.03129005432129, 41.10023617744446, 52.602465972304344, 33.34173269569874, 49.8682314902544, 73.51794585585594, 98.72688755393028, 60.04473142325878, 106.55867770314217, 134.03777718544006, 64.06872689723969, 77.90955260396004, 47.97983542084694, 54.00680601596832, 62.44893841445446, 49.292683973908424, 34.575545489788055, 45.8368606120348, 17.85910628736019, 8.53080254048109, 3.2647610642015934, 5.164357982575893, 0.8766545215621591, 0.9619043720886111, 1.8329357891343534, 6.211373750120401, 3.6404618667438626, 4.504520064219832, 1.5423064841888845, 1.3797006220556796, 1.1592604382894933, 0.7112591934856027, 0.36853572295513004, 1.3575253682211041, 2.132374090142548, 2.317090015858412, 1.064328351058066, 1.3879529479891062, 1.743791385088116, 3.7825255561619997, 8.424252457916737, 10.753738358616829, 11.262143477797508, 10.837292075157166, 9.138814564794302, 16.580362804234028, 36.0564324259758, 35.0756898522377, 38.269889652729034, 44.73260946571827, 51.83148734271526, 67.43898645043373, 77.30176001787186, 66.59342542290688, 112.3272393643856, 125.68486019968987, 77.28466093540192, 71.70045018196106, 45.40074661374092, 42.13823787868023, 57.90289655327797, 74.2418298125267, 67.87521064281464, 74.48734983801842, 97.5085437297821, 104.96994495391846, 85.11440679430962, 30.63649445772171, 5.131795154884458, 0.2197673378395848, 0.3415106824832037, 0.20063015457708389, 0.3254475787980482, 0.2005671610822901, 0.0951128669839818, 0.1451236236607656, 0.1918247653520666, 0.2680751995649189, 0.13139938353560865, 0.16228638240136206, 0.16472801857162267, 0.19616695266449824, 0.1834060499095358, 0.10005459087551571, 0.16014715656638145, 0.1131289174372796, 0.08852430255501531, 0.20690669043688104, 0.12092960940208286, 0.12593080900842324, 0.15050520363729447, 0.08389361275476404, 0.1545153243932873, 0.08554457963327877, 0.13836190133588389, 0.11598374432651326, 0.1608993232366629, 0.148856611631345, 0.10996013239491731, 0.18326591758523136, 0.13769333017989993, 0.18209702015155926, 0.19759631424676627, 0.10171307570999488, 0.2024941475247033, 0.1013605110347271, 0.17031456489348784, 0.19405186147196218, 0.1303665217710659, 0.1953701680758968, 0.1606309032649733, 0.12231666856678203, 0.2530696563189849, 0.12905652722110972, 0.18413920275634155, 0.10163014812860638, 0.1312455363222398, 0.17540813219966367, 0.1287919664173387], [0.0440206378698349, 0.02172560511098709, 0.06247085955692455, 0.031757794131408446, 0.014173894414852839, 0.012786010538547998, 0.024474481142533477, 0.1144290117372293, 0.02159361043595709, 0.020457968639675528, 0.02566408264101483, 0.01767410220054444, 0.03822974118520506, 0.04727275496406946, 0.053011322816018946, 0.005931925616096123, 0.047646511666243896, 0.04893691722827498, 0.011537136488186661, 0.04572599304083269, 0.0035558925173972966, 0.06307090079644695, 0.06458077055867761, 0.013090876454953104, 0.027312923266435973, 0.008343090594280511, 0.022374910113285296, 0.005520637114386773, 0.043277796285110526, 0.026856428230530582, 0.05427384217910003, 0.043526990921236575, 0.036575772319338284, 0.0738075067056343, 0.023942507832543924, 0.04927669469907414, 0.06547536278958432, 0.03235192045394797, 0.02914385353506077, 0.0424530995223904, 0.08508647413691506, 0.09238443526555784, 0.06556828710017726, 0.021082478488096967, 0.10206102422671393, 0.030351277709996793, 0.14239176322007552, 0.6341588962823153, 15.333165228366852, 55.90313985943794, 75.91646835207939, 87.15556606650352, 75.34635454416275, 74.94308978319168, 74.20864999294281, 60.23307591676712, 50.22413559257984, 28.365652710199356, 38.63588601350784, 50.93462146818638, 59.47843641042709, 68.30872178077698, 70.1713590323925, 55.56999273598194, 52.70270079374313, 31.088083125650883, 15.936216618865728, 20.348554104566574, 12.689654678106308, 15.628807414323092, 3.667486016638577, 1.1823788727633655, 0.9845283580943942, 2.2311664139851928, 0.8471676881890744, 0.5339084600564092, 0.08323345755343325, 0.0499823361315066, 0.20610258827218786, 0.169552305014804, 0.09402792871696874, 0.00646789724669361, 0.043094448701594956, 0.05198416445637122, 0.1342372375074774, 0.07655306719243526, 0.0651640392607078, 0.08270596867077984, 0.08101583123789169, 0.1252912706695497, 0.07451544137438759, 0.07146433868911117, 0.023196102083602455, 0.10248853839584626, 0.11640363663900644, 0.0786132097709924, 0.04817815657588653, 0.1417216780828312, 0.24516513047274202, 0.38485994387883693, 0.3060029534390196, 0.36963211256079376, 0.12722578248940408, 1.0729753808118403, 1.6099251620471478, 2.001629755832255, 2.6288533117622137, 6.909489864483476, 7.498903311789036, 13.915335908532143, 18.573500253260136, 32.55144350230694, 30.178058557212353, 34.174989983439445, 58.29891890287399, 74.19981926679611, 53.38959753513336, 33.92993353307247, 25.111471228301525, 33.8544125854969, 53.954163640737534, 39.39686357975006, 55.843475461006165, 67.69393756985664, 75.75195237994194, 57.91567526757717, 22.022998854517937, 0.6601056852377951, 0.047096008784137666, 0.038176020825630985, 0.037905812278040685, 0.007701025706410292, 0.012371093398542143, 0.014490673656837316, 0.04161385295446962, 0.01544218397611985, 0.032003983069444075, 0.008227206089941319, 0.039102206283132546, 0.03832232781860512, 0.040761989876045845, 0.034975215821759775, 0.034470380996936, 0.05443564150482416, 0.04024260153528303, 0.11099111652583815, 0.027211339947825763, 0.05683858209522441, 0.03175392383127473, 0.040157577386708, 0.025080682207772043, 0.023202968804980628, 0.029554676802945323, 0.07388202575384639, 0.044040738939656876, 0.042189388477709144, 0.018710680269578006, 0.041589343527448364, 0.035410678392509, 0.0143519764606026, 0.0324009133328218, 0.060557959077414125, 0.012359777501842473, 0.02197349171183305, 0.07304137281607836, 0.055629330381634645, 0.05986302683595568, 0.04079489299328998, 0.012161310514784418, 0.03598494113248307, 0.03673838058602996, 0.009742759775690502, 0.048932323334156536, 0.018244362909172196, 0.061395172160700895, 0.01688339951215312, 0.07562644386780448, 0.058689338839030825, 0.024386423465330154, 0.02019240964727942, 0.05651976287481375, 0.046637688064947724, 0.023493337794207036, 0.044889173295814544, 0.11007035616785288, 0.041055583496927284, 0.017912726798385847, 0.045289988702279516, 0.04612828532117419, 0.034779748966684565, 0.07780610932968557, 0.012071403962181648, 0.036908547626808286, 0.07631218089954928, 0.03459918443695642, 0.11127616802696139, 0.06384168795193546, 0.04324913825257681, 0.018040964350802824, 0.05938273483479861, 0.029656523583980743, 0.028800994296034332, 0.04800436785444617, 0.05246876091405284, 0.016061157402873505, 0.007342049339058576, 0.057419709701207466, 0.075548822642304, 0.009768485397216864, 0.06513568921945989, 0.053740913353976794, 0.045018518503638916, 0.07675309825572185, 0.047420839400729164, 0.032459535577800125, 0.057020890671992674, 0.03662426424853038, 0.06153197224193718, 0.08926691778469831, 0.04489564111281652, 0.23997621203307062, 0.09054190522874705, 0.10388816212071106, 3.3162392769008875, 33.88857275247574, 78.23561310768127, 92.94507220387459, 98.91654297709465, 97.44908452033997, 99.67987641692162, 99.0666501224041, 80.10206535458565, 69.50982213020325, 36.72468736767769, 30.835504978895187, 24.552720710635185, 31.277896240353584, 48.63530404865742, 58.665698021650314, 52.331517711281776, 47.815642431378365, 27.98639316111803, 15.660934690386057, 16.562232077121735, 11.527705527842045, 11.95847986266017, 2.628496130928397, 0.5432217009365559, 0.41023637750186026, 1.1782514629885554, 0.18656510539585724, 0.7398698769975454, 0.02545384704717435, 0.10348513882490806, 0.13691193773411214, 0.19010065239854157, 0.043265973872621544, 0.15911990543827415, 0.1303831161931157, 0.08057205661316402, 0.08754866779781878, 0.21711741050239652, 0.048119782950379886, 0.17765217897249386, 0.1562722254311666, 0.15732598607428372, 0.10159343408304267, 0.061458221316570416, 0.027921298824367113, 0.023831937105569523, 0.056624138524057344, 0.07017192561761476, 0.039433567799278535, 0.05756556769483723, 0.23270963632967323, 0.12796332885045558, 0.08585075265727937, 0.2799720346229151, 0.23858895990997553, 0.3904050635173917, 1.1310297343879938, 1.5004636044614017, 2.1138636209070683, 4.966603768989444, 5.0679519306868315, 12.12802866473794, 17.667951844632626, 29.39076740294695, 33.620801120996475, 46.80853687226772, 70.2947536110878, 74.71778467297554, 41.80426239967346, 22.411108128726482, 30.03957498818636, 51.06906205415726, 76.62183970212936, 67.84567102789879, 78.94719332456589, 80.44453337788582, 90.19388303160667, 84.24895763397217, 41.8171589076519, 3.3937085699290037, 0.0804575729125645, 0.07258145647938363, 0.09243077496648766, 0.029872668528696522, 0.020230192385497503, 0.01350749311313848, 0.02250905516120838, 0.02911026207584655, 0.03868723812047392, 0.04349267401266843, 0.04925586632452905, 0.07051718013826758, 0.04749690582684707, 0.022548212727997452, 0.06235906985239126, 0.09432665057829581, 0.07828316927771084, 0.01360785467113601, 0.08310340359457768, 0.024630137340864167, 0.008061680255195824, 0.02734735891863238, 0.01190004948512069, 0.064855075761443, 0.07006255531450734, 0.029904009425081313, 0.03421945344598498, 0.09919396674376912, 0.05736244929721579, 0.07592817142722197, 0.07380288312560879, 0.0403057286166586, 0.03883688848873135, 0.016692769604560453, 0.03928426252969075, 0.012327694457781035, 0.07178116153227165, 0.043194894678890705, 0.05223878790275194, 0.024649299593875185, 0.07798188700689934, 0.02294566063937964, 0.02107470078044571, 0.01582840133778518, 0.03664288102299906, 0.04165886792179663, 0.010569765545369592, 0.025964936321543064, 0.16867750586243346, 0.09026021565659903, 0.15941569581627846, 0.19403192738536745, 0.1249218443990685, 0.16703934845281765, 0.16579604329308495, 0.19544784125173464, 0.17620855331188068, 0.10875269523239695, 0.1138901234662626, 0.12352141915471293, 0.11323048776830547, 0.15933414862956852, 0.1625276100821793, 0.0978761944861617, 0.1281250873580575, 0.21588106668787077, 0.08584129027440213, 0.27529979939572513, 0.10192110712523572, 0.14478161232545972, 0.16522723162779585, 0.13628664863063022, 0.1375217011081986, 0.12480100791435689, 0.08246911966125481, 0.1739756387542002, 0.1401390481623821, 0.10035182844148949, 0.15292383322957903, 0.22385761054465547, 0.0896265848132316, 0.20903018274111673, 0.11116481618955731, 0.1605331475730054, 0.16340534813934937, 0.16210737638175488, 0.11100448260549456, 0.26400098693557084, 0.14526688784826547, 0.24156289407983422, 0.1437747702584602, 0.14097145583946258, 0.26925607526209205, 0.17226432042662054, 0.2861700364155695, 1.6559856967069209, 29.194754920899868, 82.57067129015923, 106.76844924688339, 108.35311621427536, 96.04307636618614, 94.4616012275219, 92.7374741435051, 72.81926214694977, 62.29003094136715, 37.240654081106186, 58.178609758615494, 77.52275615930557, 86.47110879421234, 93.95482242107391, 100.23431986570358, 77.273238748312, 75.86770176887512, 51.85702957212925, 30.873105861246586, 37.05840066075325, 22.566202506422997, 24.9002006649971, 8.552962001413107, 3.8994692685082555, 3.0476307403296232, 5.138704609125853, 2.8753114119172096, 1.6440037521533668, 0.24245212058303878, 0.2627536148065701, 0.4488970764214173, 0.581200544256717, 0.2086150847026147, 0.34990763815585524, 0.4841619747458026, 0.4244471399579197, 0.3446663834620267, 0.33632799808401614, 0.2649516484234482, 0.25322244968265295, 0.390086118131876, 0.30296949902549386, 0.22719435102771968, 0.1875409108470194, 0.11763628455810249, 0.18995341029949486, 0.18184768821811303, 0.20054031017934904, 0.2661564212758094, 0.2372931849095039, 0.5648918787483126, 0.6514934473671019, 0.3736301214667037, 0.5612272722646594, 0.5600436357781291, 1.9596901000477374, 3.3247365709394217, 4.882716620340943, 6.301031839102507, 13.429423682391644, 16.170319207012653, 28.59715148806572, 37.50883989036083, 52.08076536655426, 44.60905909538269, 48.36140334606171, 86.19018986821175, 108.09327095746994, 72.47043326497078, 45.06726510822773, 34.0391206741333, 47.118341848254204, 71.21026888489723, 57.70591512322426, 72.64830932021141, 87.42450803518295, 102.39226207137108, 93.34019020199776, 39.55226004123688, 1.8324590334668756, 0.18905941920820624, 0.16236889438005164, 0.16871244617505, 0.1255248097004369, 0.10655586389475502, 0.07823688152711838, 0.10706237226258963, 0.25425424275454134, 0.1774871550151147, 0.13981323048938066, 0.10330702338251285, 0.1245093067700509, 0.16120378189953044, 0.1277727898559533, 0.15215620020171627, 0.15432196523761377, 0.19434781512245536, 0.16299810202326626, 0.1774587604450062, 0.10239462702884339, 0.10335944869439118, 0.1633506963844411, 0.11680965821142308, 0.08965678280219436, 0.23697759403148666, 0.1552367809927091, 0.1413767723715864, 0.28254930570255965, 0.19232884689699858, 0.14203100523445755, 0.14649343531345949, 0.0850103075208608, 0.12394988327287138, 0.1658453664276749, 0.11411043000407517, 0.10215122485533357, 0.09348955994937569, 0.27666440117172897, 0.22296295152045786, 0.08737059688428417, 0.17607968678930774, 0.1327793626114726, 0.21879749925574288, 0.1614566909847781, 0.10292250924976543, 0.1198933411797043, 0.10323281603632495, 0.12888057884993032], [0.08371531177544966, 0.029319080167624634, 0.03384488038136624, 0.037293570130714215, 0.06315725710010156, 0.02326858950254973, 0.018272729648742825, 0.02727503662754316, 0.0016795955730231071, 0.09829374903347343, 0.06421359299565665, 0.04305194961489178, 0.033709085910231806, 0.04735966045700479, 0.02822463498887373, 0.030283885134849697, 0.031243222329067066, 0.028975048335269094, 0.015782629379827995, 0.0440942700515734, 0.031925452713039704, 0.030993829168437514, 0.02136711624189047, 0.09591500245733187, 0.06238005778868683, 0.030551438649126794, 0.05689743811672088, 0.02724640642554732, 0.045174922415753826, 0.004108042039661086, 0.08873246755683795, 0.08268189340014942, 0.023353930919256527, 0.0166021292534424, 0.03130926976155024, 0.03355983259098139, 0.024155519058695063, 0.04497732559684664, 0.0631829650956206, 0.07103982279659249, 0.10454729315824807, 0.06340843698126264, 0.024932030028139707, 0.01237138840224361, 0.1459166529821232, 0.19475807435810566, 11.103609334677458, 48.1935815513134, 79.91893798112869, 76.74274161458015, 75.57971522212029, 60.01283973455429, 65.55802658200264, 53.6727849394083, 41.7488157749176, 44.70864035189152, 37.93990395963192, 46.268190667033195, 41.793493777513504, 58.091788217425346, 55.05643129348755, 43.27188804745674, 34.49112921953201, 24.59352672100067, 13.089656364172697, 7.609974201768637, 4.70955278724432, 1.1806310852989554, 1.1568548111245036, 0.16464854939840734, 0.2898289728909731, 0.11365173078957014, 0.0520803542167414, 0.06240646340302192, 0.0258411442337092, 0.026386823155917227, 0.22964168689213693, 0.09836980432737619, 0.025877147672872525, 0.06364327477058396, 0.05124617651745211, 0.10514558292925358, 0.2082701789913699, 0.11723154690116644, 0.18752323288936168, 0.09914320384268649, 0.13727766810916364, 0.07117136105080135, 0.15748076839372516, 0.06565814634086564, 0.08999850469990633, 0.05246843436907511, 0.11259257473284379, 0.042273414437659085, 0.1342002340243198, 0.1407735250541009, 0.19411224260693416, 0.13943555153673515, 0.2129469413193874, 0.4723931156331673, 0.1988854247611016, 0.23212938074721023, 0.1815819993498735, 0.16855508118169382, 0.09745023882715032, 0.15067180094774812, 0.11683598961099051, 0.1495181769132614, 0.3793667152058333, 1.7051066108979285, 9.007839392870665, 28.079636357724667, 39.17607642710209, 20.75575925409794, 9.235569722950459, 18.672399446368217, 47.68047608435154, 52.87411339581013, 51.04751341044903, 34.47476729750633, 26.3487209379673, 37.634939923882484, 50.55880643427372, 59.13319833576679, 50.29243692755699, 72.10176184773445, 69.0195420384407, 45.12713089585304, 7.252634726464748, 0.3080371208488941, 0.07976615845109336, 0.09504495305009186, 0.00805690731795039, 0.01113493790398934, 0.13230285927420482, 0.07919820767710917, 0.022835887721157633, 0.00543593672773568, 0.04143083933740854, 0.0693811004748568, 0.015468680503545329, 0.03929756181605626, 0.005161486806173343, 0.03184480723575689, 0.05257371172774583, 0.059833392879227176, 0.03515088959829882, 0.059448414904181845, 0.040529456455260515, 0.09054743422893807, 0.009488202194916084, 0.009012905775307445, 0.04753229884954635, 0.009315661209257087, 0.018386743940936867, 0.015334239524236182, 0.019429160856816452, 0.06735916365869343, 0.01935243020852795, 0.12226516351802275, 0.0313386254129, 0.053563087349175476, 0.04239756461174693, 0.03455032885540277, 0.04860916254983749, 0.0634297588840127, 0.012628111198864644, 0.015412805132655194, 0.03428475873079151, 0.06169500724354293, 0.03034993071196368, 0.07430068610119633, 0.002324077195225982, 0.03652260114904493, 0.02495738364814315, 0.01951891990756849, 0.09236362544470467, 0.03700608809594996, 0.0370048190234229, 0.01799716836103471, 0.05970171361695975, 0.08736077084904537, 0.03294140835350845, 0.027499899952090345, 0.022686658521706704, 0.03134712671453599, 0.009660823889134917, 0.05684092357114423, 0.036570896409102716, 0.04188169405097142, 0.014163814194034785, 0.04491866995522287, 0.04654134245356545, 0.022192560718394816, 0.021907856171310414, 0.011852655006805435, 0.023596756072947755, 0.02412596673821099, 0.03907934813469183, 0.03412716367165558, 0.030774387232668232, 0.024647347745485604, 0.006069906639822875, 0.02068660392978927, 0.03181011554261204, 0.026079972922161687, 0.04093508468940854, 0.03413380589336157, 0.049734087733668275, 0.03556572046363726, 0.06722422636812553, 0.0195987694314681, 0.03223760373657569, 0.07317162715480663, 0.021000719789299183, 0.07134828163543716, 0.03826265543466434, 0.06733096204698086, 0.09391878847964108, 0.08793643995886669, 0.1257138792425394, 1.8821001634933054, 27.46711492538452, 71.85056492686272, 94.10097017884254, 86.01758033037186, 91.11495360732079, 83.6371448636055, 92.00705453753471, 78.35030615329742, 55.812518522143364, 38.28352712094784, 16.607141867280006, 27.67304677516222, 38.995103538036346, 64.46750789880753, 60.648127645254135, 47.42743246257305, 35.17750158905983, 22.511073164641857, 8.286795783787966, 4.46095397695899, 2.088830564171076, 0.11820921514299698, 0.49591714865528047, 0.15382950572529808, 0.18466136301867664, 0.1203678704041522, 0.08203508943552151, 0.026780165135278367, 0.029501730132324155, 0.08524951655999757, 0.06049975614587311, 0.11181136782397516, 0.04134163689741399, 0.13410166196990758, 0.11442257731687278, 0.12800744210835546, 0.22343630815157667, 0.06102319290221203, 0.31367791816592216, 0.22134190803626552, 0.07590604800498113, 0.10853787316591479, 0.29526728263590485, 0.10532789892749861, 0.11696474481141195, 0.129572008154355, 0.17197565466631204, 0.12013206040137447, 0.20335398497991264, 0.0861238778452389, 0.18713856290560216, 0.16556658607441932, 0.24137136060744524, 0.35059970570728183, 0.3661319363163784, 0.15883965563261881, 0.27818342903628945, 0.0559707479987992, 0.044285985350143164, 0.0523450523178326, 0.12324704715865664, 0.11688046652125195, 0.43907766113989055, 0.882455266546458, 5.865075532346964, 20.293065682053566, 26.99449248611927, 15.402063131332397, 12.305236905813217, 30.227763690054417, 65.32139047980309, 57.745676189661026, 33.69770519435406, 20.471779592335224, 26.37932449579239, 56.80293917655945, 79.23084810376167, 89.35930341482162, 71.83661967515945, 88.17052200436592, 83.39605540037155, 68.84530618786812, 19.949300028383732, 0.8719980495516211, 0.0956002798920963, 0.08009119686903432, 0.009663732180342777, 0.05583588492299896, 0.1947605679742992, 0.06556882144650444, 0.011230181426071795, 0.06659099628450349, 0.0288771794657805, 0.03424678674491588, 0.045585281841340475, 0.04863284819293767, 0.027117816352983937, 0.0641736135003157, 0.05482895008753985, 0.10879804787691683, 0.01506160322605865, 0.01897601661767112, 0.04071790630405303, 0.11178178581758402, 0.009214599249389721, 0.00833833249998861, 0.03746252004930284, 0.019651011061796453, 0.02729761090449756, 0.045155251791584305, 0.027807520164060406, 0.04994770381017588, 0.018221558566438034, 0.06735459945048206, 0.037362218790804036, 0.016342403541784734, 0.03261675585235935, 0.05504998021933716, 0.02804970707074972, 0.022078603942645714, 0.023392248003801797, 0.10528050537686795, 0.017182900628540665, 0.04257253705873154, 0.023300108514376916, 0.03516778459015768, 0.05220449325861409, 0.03181179650709964, 0.020147548675595317, 0.0268668925127713, 0.10317120293620974, 0.12824350444134325, 0.06394032679963857, 0.07275864423718303, 0.20004406571388245, 0.12013433879474178, 0.16041893104556948, 0.15853675547987223, 0.10774920767289586, 0.23918656690511853, 0.15814683109056205, 0.10982762192725204, 0.09571457063429989, 0.13391602115007117, 0.13141958479536697, 0.12810690473997965, 0.1903763454174623, 0.09255062439478934, 0.1268297724891454, 0.140157260466367, 0.18404456408461556, 0.114799788716482, 0.1068414794281125, 0.12714341894024983, 0.14523901278153062, 0.11920051663764752, 0.10838317990419455, 0.13780447421595454, 0.14886474556988105, 0.14602960785850883, 0.14750409201951697, 0.23572703066747636, 0.14102876448305324, 0.09795121819479391, 0.11025967804016545, 0.1172354283335153, 0.15456357883522287, 0.10842148214578629, 0.1849624968599528, 0.1850037305848673, 0.16649765486363322, 0.11110901410575025, 0.23401540063787252, 0.1713215108611621, 0.5032540205866098, 0.8906807564198971, 21.666363291442394, 75.31250596046448, 110.87464570999146, 98.62810805439949, 94.01193335652351, 84.24986958503723, 81.77038103342056, 66.56315624713898, 52.84578211605549, 59.38616216182709, 51.12849846482277, 66.66837260127068, 60.58337152004242, 84.4115737080574, 80.47335863113403, 64.87975537776947, 54.83671948313713, 41.4546849578619, 22.591653540730476, 14.93094826117158, 8.079902585595846, 2.754615400917828, 2.2253494011238217, 0.5030275171156973, 0.9018655156251043, 0.32356774841900915, 0.21403455873951316, 0.233556590101216, 0.1622911766753532, 0.2546494215494022, 0.6273871846497059, 0.32701837888453156, 0.6279261026065797, 0.1642570219701156, 0.44466772524174303, 0.3679927974008024, 0.7323868910316378, 0.7079375779721886, 0.9035539906471968, 0.493341272813268, 0.4077987786149606, 0.21383674669777974, 0.4809327714610845, 0.16961664921836928, 0.2069020297494717, 0.3502073767594993, 0.5362696771044284, 0.44312860001809895, 0.602219175780192, 0.5020047188736498, 0.7848892081528902, 0.9103821648750454, 0.7809013815131038, 1.003946978598833, 1.02301768027246, 0.4541356296977028, 0.5882998101878911, 0.3639135678531602, 0.2634580316953361, 0.2148618604405783, 0.229307304834947, 0.32840919331647456, 1.6867142915725708, 4.140657763928175, 15.377908777445555, 38.65317888557911, 56.55105449259281, 36.87768615782261, 18.385188058018684, 27.255190797150135, 68.41032072901726, 79.36594605445862, 69.24509793519974, 46.8788331001997, 36.86290115118027, 49.712413251399994, 65.10109350085258, 77.53516629338264, 65.28757229447365, 92.11209610104561, 94.80964735150337, 71.69341295957565, 16.666221097111702, 0.5733022524509579, 0.4077789484290406, 0.21292552293743938, 0.057298706233268604, 0.1404347049538046, 0.32437817368190736, 0.3056833252776414, 0.09421142473001964, 0.18141886044759303, 0.20154111116426066, 0.11568812464247458, 0.12852265586843714, 0.13328013417776674, 0.10770386987132952, 0.14619714027503505, 0.09449004181078635, 0.24341888667549938, 0.10478816460818052, 0.1796522075892426, 0.19042189844185486, 0.2725123817799613, 0.1259521531756036, 0.1352739435969852, 0.16516845353180543, 0.1436308232950978, 0.13045678177149966, 0.1887171555426903, 0.10131223432836123, 0.1851925181108527, 0.0827014415699523, 0.22848671214887872, 0.1910538668744266, 0.11843574087833986, 0.12047281008563004, 0.09080632502445951, 0.2157785464078188, 0.1602815743535757, 0.15013675700174645, 0.18273663270520046, 0.15120838856091723, 0.12281456802156754, 0.25594188657123595, 0.19239549175836146, 0.15614111762261018, 0.08931904623750597, 0.1077701362373773, 0.07823926382116042], [0.02122590409271652, 0.01625519376830198, 0.032837926992215216, 0.013998662216181401, 0.05574802948103752, 0.043745178627432324, 0.015010342158348067, 0.05750250740675256, 0.060260313330218196, 0.08668117137858644, 0.03797122888499871, 0.06551750935614109, 0.0685353267181199, 0.023225398363138083, 0.11606117259361781, 0.051911957198171876, 0.037726286755059846, 0.024161420988093596, 0.02197576453909278, 0.01620777609787183, 0.04322922643041238, 0.01908015849039657, 0.08815293927909806, 0.05217550497036427, 0.038221236172830686, 0.012557651698443806, 0.03803194027568679, 0.011256814323132858, 0.0023745673570374493, 0.0295404071584926, 0.04179907817160711, 0.030302722698252182, 0.05219206228503026, 0.028038320670020767, 0.017924953681358602, 0.039403959817718714, 0.012808393712475663, 0.04240944639605004, 0.04862151559791528, 0.07811776682501659, 0.04452215158380568, 0.06120001329691149, 0.005906223186684656, 0.03649732730991673, 7.184794116765261, 35.20025096833706, 78.70867252349854, 79.19171780347824, 73.32211956381798, 63.251056373119354, 60.38438759744167, 61.191323697566986, 43.47228929400444, 39.58687238395214, 28.3428805321455, 49.14766475558281, 76.36529266834259, 76.82139739394188, 44.69116508960724, 28.996107280254364, 24.45191401988268, 26.756133176386356, 15.920181479305029, 2.7846739254891872, 0.5993378616403788, 0.3094109846279025, 0.14806662511546165, 0.07108393605449237, 0.17872481985250488, 0.05477195685671177, 0.07961606650496833, 0.07352023618295789, 0.036857228114968166, 0.04456646893231664, 0.1521424704696983, 0.2766019123373553, 0.015486264765058877, 0.042664715510909446, 0.041971991158789024, 0.114393269905122, 0.10083181245136075, 0.027844065371027682, 0.06521313975099474, 0.09056290058651939, 0.05626210775517393, 0.03802860061114188, 0.07153734375606291, 0.219705680210609, 0.004187070562693407, 0.0679303279321175, 0.05674989544786513, 0.07906991260824725, 0.058606322199921124, 0.03730816075403709, 0.02229691410320811, 0.05424413400760386, 0.01904249449580675, 0.08124506581225432, 0.01819997876737034, 0.009575162421242567, 0.011292635936115403, 0.02010622960369801, 0.01105401226595859, 0.11241191372391768, 0.15426134661538526, 0.140541247674264, 0.08887112300726585, 0.12968560127774253, 0.05852769536431879, 0.03924242395441979, 0.4292381781851873, 0.7032965426333249, 7.57850619032979, 33.062728866934776, 35.12917958199978, 25.80074854195118, 12.066654358059168, 20.028590373694897, 46.26108504831791, 110.11470928788185, 61.763383001089096, 25.384547375142574, 29.517950378358364, 35.598727986216545, 45.73211923241615, 40.527162328362465, 52.46888794004917, 66.41742646694183, 68.45845654606819, 27.980847358703613, 3.431124212220311, 0.2623869641683996, 0.2001199874212034, 0.025057799939531833, 0.03106278210907476, 0.0655321148224175, 0.10189542139414698, 0.059835225983988494, 0.009018277069117175, 0.043600816061371006, 0.1250965311191976, 0.01693640740995761, 0.039519567872048356, 0.048208328589680605, 0.04509942373260856, 0.011581383332668338, 0.014784382310608635, 0.022405494019039907, 0.0130401951901149, 0.046192944937502034, 0.04284385511709843, 0.026770867880259175, 0.03223160718334839, 0.073884326411644, 0.06216161775228102, 0.013215864328230964, 0.06169666594360024, 0.08406383174587972, 0.0006737986586813349, 0.018491672490199562, 0.05352146770746913, 0.00326768990362325, 0.003986135470768204, 0.06101235754613299, 0.06129642570158467, 0.030770628254686017, 0.01668498633080162, 0.02291082237206865, 0.05366132172639482, 0.0663783932395745, 0.03855044174997602, 0.02251548216008814, 0.03371632927155588, 0.02253841081255814, 0.03380260393896606, 0.04667185654398054, 0.02748124421486864, 0.032863449450815096, 0.03951828766730614, 0.040712024783715606, 0.06277386361034587, 0.015646478677808773, 0.03508994814183097, 0.012598433640960138, 0.05236378412519116, 0.041842167265713215, 0.022769330062146764, 0.047825636429479346, 0.03740020933037158, 0.06003105278068688, 0.05771244985226076, 0.04454746995179448, 0.026109104073839262, 0.03622226882725954, 0.0037767797857668484, 0.03691488556796685, 0.021740939737355802, 0.03299192263511941, 0.023786860911059193, 0.058912532331305556, 0.040988118562381715, 0.06391337199602276, 0.023714126728009433, 0.035048580830334686, 0.015383184163511032, 0.03928804748284165, 0.013909969075029949, 0.007194691279437393, 0.032808664109325036, 0.03247927670599893, 0.05334481058525853, 0.03516889410093427, 0.02323036518646404, 0.032994880093610846, 0.09008758468553424, 0.11140156129840761, 0.02716475719353184, 0.10099646533490159, 0.04204983873933088, 0.6290888995863497, 22.442726232111454, 61.62570878863335, 94.63734179735184, 89.38312813639641, 88.04456636309624, 86.00299671292305, 86.71052634716034, 83.88749822974205, 55.014546141028404, 38.09978798031807, 16.162911504507065, 37.093442380428314, 71.81407168507576, 82.5919957458973, 51.7133516818285, 31.50504045188427, 22.501757964491844, 19.98980015516281, 8.933741468936205, 1.497201716993004, 0.7670512434560806, 0.3066446736920625, 0.2714295586338267, 0.02491520925104851, 0.12759572826325893, 0.120859817834571, 0.0551042386359768, 0.052629317142418586, 0.05354522385459859, 0.19032197567867115, 0.24190122436266392, 0.2268666186137125, 0.006583231634067488, 0.07174539743573405, 0.049614854287938215, 0.14068669377593324, 0.016740359824325424, 0.11583700688788667, 0.02978936245199293, 0.20485487475525588, 0.0978461597696878, 0.22280478500761092, 0.17308755515841767, 0.38615793047938496, 0.2037531416863203, 0.1801193895516917, 0.19954859308199957, 0.1460279306047596, 0.06405072126653977, 0.04097716446267441, 0.021804194839205593, 0.04324506015109364, 0.023825350544939283, 0.036313794189481996, 0.03186828507750761, 0.057710572218638845, 0.038024092064006254, 0.0955121275910642, 0.02481793224433204, 0.1835913344984874, 0.20308511971961707, 0.15912324510281906, 0.06875161823700182, 0.13695808447664604, 0.09516437203274108, 0.09074316825717688, 0.3022202564170584, 0.40181401069276035, 4.667320903390646, 19.337618350982666, 16.145202554762363, 9.570769686251879, 9.75250918418169, 28.590878024697304, 55.95922864973545, 110.25507375597954, 47.847363129258156, 7.833282519131899, 25.11365231126547, 47.45858319103718, 68.9369648694992, 71.67592629790306, 74.04078260064125, 81.54928609728813, 89.40243870019913, 50.12223266065121, 9.412758965045214, 0.6816911988426, 0.2028890888323076, 0.015449264992639655, 0.0912826057174243, 0.051563700690167025, 0.021757558279205114, 0.05624505691230297, 0.029102744119882118, 0.02205335236794781, 0.006549165200340212, 0.047244686938938685, 0.016880776020116173, 0.1803011860465631, 0.10814796361955814, 0.030386051039386075, 0.017723627570376266, 0.02463073848048225, 0.00845487937112921, 0.030259119666879997, 0.05827835600939579, 0.005345570043573389, 0.01566328646731563, 0.018956396088469774, 0.061587355012306944, 0.03875931921356823, 0.00802539387223078, 0.020545111619867384, 0.03726129041751847, 0.023968111927388236, 0.025981998296629172, 0.008212716584239388, 0.06216130976099521, 0.09121402385062538, 0.0148784727207385, 0.013512946970877238, 0.053512409795075655, 0.03849606087896973, 0.029426916080410592, 0.022964937925280537, 0.10323765483917668, 0.02649791338626528, 0.016431557742180303, 0.013090559186821338, 0.008806931964500109, 0.021539936460612807, 0.11792898018029518, 0.16011778236133978, 0.15107144747162238, 0.15087601030245423, 0.22852606081869453, 0.13679959141882136, 0.13591327413450927, 0.14099429914494976, 0.17830382916145027, 0.1960113094537519, 0.15958480158587918, 0.14718305377755314, 0.20406132593052462, 0.1486337001551874, 0.18759533995762467, 0.16795256116893142, 0.12146061606472358, 0.16776310571003705, 0.07766927214106545, 0.08211653272155672, 0.15008320362539962, 0.13785508868750185, 0.19016052887309343, 0.16889076941879466, 0.11437381821451709, 0.13962286961032078, 0.13816646416671574, 0.0646816506923642, 0.12638651736779138, 0.12128545437008142, 0.12257830530870706, 0.092003906465834, 0.14809987333137542, 0.1203331230499316, 0.0793777777289506, 0.13597027107607573, 0.07357637965469621, 0.0844503051484935, 0.17883775988593698, 0.20520426303846762, 0.09821868079598062, 0.23533762578153983, 0.1726363887428306, 0.29066857940051705, 17.041456662118435, 61.42558492720127, 109.34870839118958, 103.21726620197296, 90.41326805949211, 86.24334901571274, 81.12250819802284, 74.99278351664543, 52.19046927988529, 53.00429821014404, 43.293003514409065, 70.6725749373436, 105.99052459001541, 108.27535718679428, 65.0567726790905, 47.220533564686775, 40.96537001430988, 39.15266588330269, 23.40742416679859, 6.741023054346442, 2.0921834092587233, 0.6285787769593298, 0.5111910821869969, 0.20143605273915455, 0.2469373939675279, 0.20448454306460917, 0.2521278115455061, 0.3729248733725399, 0.23161210381658748, 0.5610135931055993, 0.7908142183441669, 0.4588614479871467, 0.1788937475066632, 0.24224492779467255, 0.23726994084427133, 0.4707760945893824, 0.21188175160204992, 0.47287806461099535, 0.41085862379986793, 0.4691182554233819, 0.25473892455920577, 0.7454342627897859, 0.44008229160681367, 0.5340977967716753, 0.6165321171283722, 0.37881681346334517, 0.35553157387766987, 0.24774833873379976, 0.28832704410888255, 0.17366098298225552, 0.16246479470282793, 0.09828741109231487, 0.0772808691544924, 0.14632553182309493, 0.1901617756811902, 0.13846854795701802, 0.10378131511970423, 0.24918733339291066, 0.18743347754934803, 0.4287606506841257, 0.2515718835638836, 0.3894911234965548, 0.2382737401057966, 0.3438638843363151, 0.2224248499260284, 0.20236167416442186, 0.5096078140195459, 0.5794762680307031, 10.001295134425163, 46.73493482172489, 58.2151447981596, 40.09319141507149, 21.398432068526745, 31.413951739668846, 69.74290162324905, 141.28926247358322, 79.00335431098938, 36.73057705163956, 39.034332633018494, 48.32123190164566, 59.013018384575844, 57.07260690629482, 68.61862555146217, 86.51319533586502, 96.04521185159683, 49.39149007201195, 7.997485958039761, 0.3783305879915133, 0.432526248623617, 0.09194723606924526, 0.19709249987499788, 0.18521098274504766, 0.18780993937980384, 0.20897035079542547, 0.16461579099996015, 0.10756184507044964, 0.1458889857167378, 0.11470707962871529, 0.13880447368137538, 0.16851801832672209, 0.22821683756774291, 0.08011251877178438, 0.09777613813639618, 0.10426938853925094, 0.1132390447310172, 0.055820722845965065, 0.15498914115596563, 0.1478924133698456, 0.08225179655710235, 0.24864421488018706, 0.1309674684307538, 0.11242221473366953, 0.20235906180460006, 0.12045038980431855, 0.05193914948904421, 0.11030382840544917, 0.10228688202914782, 0.10226892947684973, 0.1571357884677127, 0.21154641959583387, 0.12733654060866684, 0.10637311745085754, 0.12138942183810286, 0.1021911004499998, 0.12287894191103987, 0.10797684662975371, 0.15580039762426168, 0.084785050858045, 0.13236996426712722, 0.14881761919241399, 0.08819931608741172, 0.09790393596631475], [0.059530971411732025, 0.016441498810308985, 0.04039642277348321, 0.043555485681281425, 0.030256895079219248, 0.025517738540656865, 0.04320106563682202, 0.020271401990612503, 0.09542075436911546, 0.02816446722135879, 0.04122139042010531, 0.029051168567093555, 0.03577941075491253, 0.00989344543995685, 0.06520315786474384, 0.028903486745548435, 0.029827597900293767, 0.06828091107308865, 0.0035458804813970346, 0.04310608186642639, 0.0211695825055358, 0.020515331088972744, 0.01115312794354395, 0.037251568282954395, 0.05109977304528002, 0.05164417547348421, 0.014435854918701807, 0.0545136709115468, 0.025523625627101865, 0.07701446040300652, 0.021981304671498947, 0.027656947677314747, 0.055529170131194405, 0.05343332653865218, 0.01810584290069528, 0.022760726715205237, 0.011821863299701363, 0.08581726695410907, 0.020043436488776933, 0.1794675167184323, 0.07270481626619585, 0.10403565654996783, 1.2146465037949383, 25.05449328571558, 76.15223050117493, 84.1129857301712, 75.34053325653076, 69.20701637864113, 62.66204997897148, 54.986290857195854, 38.268825709819794, 27.966474629938602, 33.16120818257332, 49.37322825193405, 60.24371914565563, 56.67275816202164, 26.204910054802895, 20.455924943089485, 23.003568537533283, 25.789717733860016, 17.685966677963734, 5.0158315524458885, 1.0663972212933004, 0.1459924114169553, 0.04943527310388163, 0.11911964480532333, 0.13894886593334377, 0.05750018077378627, 0.08420639089308679, 0.09496597369434312, 0.1282393781002611, 0.14087846473557875, 0.07372080901404843, 0.07264782674610615, 0.023650890179851558, 0.0215612732063164, 0.05417506232333835, 0.04346003806858789, 0.07219539867946878, 0.04772208456415683, 0.09079834693693556, 0.038840981433168054, 0.03648016514489427, 0.08186168663087301, 0.25272093596868217, 0.10088374052429572, 0.1042388565838337, 0.4148020996944979, 0.3986354812514037, 0.1910252496600151, 0.10292157414369285, 0.06737799936672673, 0.1778684408054687, 0.249752642121166, 0.069657127460232, 0.20749470888404176, 0.0691427152196411, 0.058232947703800164, 0.04833119484828785, 0.16599462716840208, 0.14075109735131264, 0.031961224231054075, 0.08172162109985948, 0.05118928347656038, 0.0925817945972085, 0.06291699421126395, 0.048884799907682464, 0.06276388914557174, 0.07476590879377909, 0.19482391769997776, 0.3479868412250653, 0.3470545553136617, 0.46657779486849904, 0.8511808072216809, 2.096516126766801, 14.84117142856121, 39.484935253858566, 25.31816303730011, 11.775531079620123, 13.989543076604605, 50.63650846481323, 81.47293299436569, 65.44894203543663, 41.11736945807934, 24.931708574295044, 32.40123376250267, 47.625462636351585, 55.37960775196552, 57.28258363902569, 66.3638873398304, 43.64231117069721, 25.974458120763302, 2.8064241958782077, 0.3118848300073296, 0.16072534897830337, 0.0357428117422387, 0.05009785141737666, 0.0876508244255092, 0.0238287996762665, 0.041199478509952314, 0.02091095517243957, 0.03804719883191865, 0.05305734710418619, 0.07251360191730782, 0.032537605802644975, 0.036522708760458045, 0.06800833507440984, 0.08751774992560968, 0.027058724699600134, 0.025812771928030998, 0.040679043740965426, 0.013542400029109558, 0.02043117525317939, 0.0924118427792564, 0.04154887421464082, 0.05603747078566812, 0.02324051962204976, 0.01365729747703881, 0.02330604755115928, 0.09187335526803508, 0.02537044078053441, 0.060537531462614425, 0.017006165580824018, 0.06228746002307162, 0.026885726365435403, 0.1371587166795507, 0.026806221940205432, 0.022705522060277872, 0.022348185375449248, 0.09762395333382301, 0.07374982698820531, 0.05506373963726219, 0.034407947823638096, 0.021692449663532898, 0.043238328871666454, 0.007198378825705731, 0.03483698710624594, 0.029004923489992507, 0.027703678861144, 0.05329747269570362, 0.035896362096536905, 0.050378142041154206, 0.04468695289688185, 0.04451510489161592, 0.03259850273025222, 0.05078673886600882, 0.02419645963527728, 0.020559537115332205, 0.038159463510965, 0.032319243691745214, 0.10823141812579706, 0.008565738608012907, 0.02384640341915656, 0.01955176736373687, 0.022471591546491254, 0.07709065670496784, 0.03099354900768958, 0.052333356070448644, 0.042472302593523636, 0.047191920239129104, 0.030881642414897215, 0.024026903010962997, 0.022737336075806525, 0.014295878445409471, 0.026649647334124893, 0.07350069543463178, 0.010608547399897361, 0.034085213774233125, 0.06815978515078314, 0.016631295657134615, 0.03640074792201631, 0.04912591255560983, 0.02030570962233469, 0.05685779258783441, 0.013681636210094439, 0.07347704318817705, 0.14518139243591577, 0.22169561561895534, 6.804629266262054, 48.02973434329033, 94.70361024141312, 94.94710117578506, 93.45763429999352, 97.32858538627625, 92.45654761791229, 79.42709997296333, 57.88590766489506, 27.333525493741035, 17.68588498234749, 29.345536530017853, 70.1446844637394, 74.92251008749008, 32.45239041745663, 18.98553304374218, 14.642233103513718, 14.602413140237331, 9.60829172283411, 2.6146458741277456, 0.7570345653221011, 0.09019576013088226, 0.05324118821590673, 0.12520731892436743, 0.28331971436273307, 0.06575211707968265, 0.22477453399915248, 0.009972910902433796, 0.07802304651704617, 0.22451531665865332, 0.12474570306949317, 0.04668361216317862, 0.009564972733642207, 0.11257669277256355, 0.06216217065230012, 0.04130530134716537, 0.042431343463249505, 0.0957251017098315, 0.1676271145697683, 0.0867868161003571, 0.05564835904806387, 0.03069183814659482, 0.24351076455786824, 0.21905689471168444, 0.22681223403196782, 0.2674298279453069, 0.2674564265180379, 0.157404980272986, 0.20730672287754714, 0.05929897233727388, 0.1208721894363407, 0.07005736770224757, 0.07467236850061454, 0.2023559299414046, 0.07840154183213599, 0.14017719455296174, 0.1552128096227534, 0.2902380743762478, 0.08393018579226919, 0.02383857932727551, 0.19705263170180842, 0.054980400163913146, 0.07057331618852913, 0.08333537669386715, 0.09833558389800601, 0.08028241863939911, 0.06309179225354455, 0.11920071701752022, 0.21763317345175892, 0.15610068541718647, 0.3961240831995383, 0.6522670027334243, 0.9262951172422618, 7.603773884475231, 13.580610919743776, 8.9638140052557, 8.700480535626411, 20.497644804418087, 67.30323493480682, 79.15508016943932, 42.88027346134186, 27.299274131655693, 21.30771953612566, 35.446629747748375, 71.71830922365189, 84.86244231462479, 74.90012168884277, 84.86593052744865, 66.51894941926003, 46.331928446888924, 9.50367383658886, 0.46855802298523486, 0.2874046436045319, 0.09057777322595939, 0.08568411823944189, 0.07479287844034843, 0.04683953367930371, 0.03130852390313521, 0.022347272533806972, 0.016143281609402038, 0.015906547632766888, 0.04374218777229544, 0.05771833508333657, 0.03853411450108979, 0.03481845196802169, 0.05663302574248519, 0.03834538263618015, 0.029510713829949964, 0.014380325574165909, 0.0031418854359799298, 0.018764808810374234, 0.022850535860925447, 0.05107218741613906, 0.03961210255511105, 0.03796765915467404, 0.042115233081858605, 0.0357664046168793, 0.030333696231537033, 0.038267138006631285, 0.03335319270263426, 0.03341884308611043, 0.05346962127077859, 0.033595863860682584, 0.08319004933582619, 0.017627942470426206, 0.044903415109729394, 0.05245437438134104, 0.0927516128285788, 0.11300321988528594, 0.03146662733342964, 0.08306132382131182, 0.05091646627988666, 0.023996719864953775, 0.025827549943642225, 0.16056921595009044, 0.22272323782090098, 0.17478131427196786, 0.12467059772461653, 0.14099771302426234, 0.20537261181743816, 0.11325193583616056, 0.09697755012894049, 0.21622235071845353, 0.09235098666977137, 0.11950913132750429, 0.15021386614535004, 0.15058355958899483, 0.16161818231921643, 0.24107445700792596, 0.20022375450935215, 0.11491111828945577, 0.15251197095494717, 0.14281929965363815, 0.15149580751312897, 0.15319826459744945, 0.10013507679104805, 0.18361076392466202, 0.15084014972671866, 0.0985810715064872, 0.21951662551146, 0.09496337617747486, 0.10962152009597048, 0.18849608459277079, 0.3706789860734716, 0.07264137006131932, 0.08641558641102165, 0.2348348801024258, 0.11759938497561961, 0.12895792548079044, 0.11338390453602187, 0.14803579630097374, 0.1375902903964743, 0.12756206444464624, 0.35617139423266053, 0.27917303843423724, 0.2750949963228777, 4.094115486368537, 46.681505888700485, 109.20848831534386, 108.29146832227707, 98.4184505045414, 91.68157160282135, 87.2286969423294, 70.047447681427, 51.30295090377331, 41.681357994675636, 49.95941519737244, 69.14736717939377, 87.40818411111832, 80.15742838382721, 35.99707581102848, 35.64315140247345, 37.68993817269802, 39.48622338473797, 26.62006627768278, 8.817927483469248, 1.6598537703976035, 0.39199272519908845, 0.156289532314986, 0.47134496562648565, 0.6038580753374845, 0.17918202735017985, 0.4759288555942476, 0.29097134596668184, 0.23421561723807827, 0.48203886835835874, 0.2345566637814045, 0.20550392742734402, 0.18182681902544573, 0.2531706774607301, 0.3205073095159605, 0.22146229923237115, 0.27434020244982094, 0.27798251481726766, 0.38715335831511766, 0.3425930900266394, 0.24456125975120813, 0.292632183409296, 0.8097835723310709, 0.8740314154420048, 0.8319182158447802, 1.055820370092988, 0.7231191289611161, 0.6134684127755463, 0.5624324013479054, 0.3967610833933577, 0.5877844628412277, 0.7001004985067993, 0.2722593687940389, 0.5652108241338283, 0.47094479959923774, 0.4584824776975438, 0.3479599754791707, 0.6126324576325715, 0.3121164988260716, 0.335552305332385, 0.312023819424212, 0.3053324675420299, 0.37397824809886515, 0.2142202589311637, 0.17651091911830008, 0.15141575946472585, 0.3118368872674182, 0.4487006150884554, 0.5058371101040393, 0.3491303126793355, 0.6167811818886548, 1.013458224479109, 3.7819361127913, 27.067104689776897, 56.89789608120918, 35.762780383229256, 19.145394265651703, 21.572021953761578, 67.35502615571022, 112.83027157187462, 85.42038917541504, 57.31528468430042, 35.31284272670746, 40.02910405397415, 61.95378318428993, 73.3569560945034, 73.24411734938622, 90.64228937029839, 72.17913329601288, 44.899428114295006, 7.701304676011205, 0.3835019620601088, 0.29803394980262965, 0.17963788413908333, 0.15929113375023007, 0.2315915166400373, 0.2380293805617839, 0.1311792031629011, 0.14158432139083743, 0.12089440191630274, 0.1694965103524737, 0.1810218411264941, 0.15363812068244442, 0.20287924795411527, 0.16004462144337595, 0.12467862776247784, 0.1806177120306529, 0.11484959424706176, 0.10190253116888925, 0.08996293356176466, 0.15483262221096084, 0.19307886133901775, 0.10278533809469081, 0.3033056325512007, 0.10034176491899416, 0.1392988776206039, 0.11147474448080175, 0.3133427642751485, 0.15284096502000466, 0.0706933882611338, 0.08944756395067088, 0.06043575704097748, 0.16697678540367633, 0.27262705843895674, 0.13206167612224817, 0.11354020083672367, 0.20855480746831745, 0.20290085929445922, 0.24172653764253482, 0.19719444127986208, 0.1816530674113892, 0.09374468805617653, 0.12637548905331641, 0.12361894478090107], [0.03222468665626366, 0.015282554504665313, 0.011368948198651196, 0.05929612620093394, 0.0349154989089584, 0.02289536158059491, 0.01083522713088314, 0.04778465132403653, 0.05449904689157847, 0.03586235688999295, 0.036297578262747265, 0.022428550691984128, 0.06351526171783917, 0.09428946897969581, 0.02244830109702889, 0.013005013679503463, 0.03176839942170773, 0.013580376653408166, 0.04780157600180246, 0.05158547901373822, 0.031325400341302156, 0.08742029109271243, 0.01840161843574606, 0.03768771362956613, 0.045426662618410774, 0.029457511118380353, 0.02449586427246686, 0.028706210905511398, 0.05462111163069494, 0.03462855122052133, 0.07997001899639145, 0.01989775846595876, 0.05399396344728302, 0.030315003386931494, 0.02612282638438046, 0.035534624475985765, 0.06444813392590731, 0.05919144256040454, 0.0520208636589814, 0.2555121830664575, 0.3087759140180424, 18.19062139838934, 58.87891598045826, 83.51286873221397, 80.3706881403923, 67.16714143753052, 62.12404444813728, 47.87723712623119, 24.683695882558823, 29.339244067668915, 32.261720448732376, 58.495729342103004, 83.39122205972672, 57.930813655257225, 30.19487265497446, 14.278876651078463, 32.711608707904816, 36.97038598358631, 13.591575231403112, 2.5329136848449707, 0.4122702480526641, 0.2458890064735897, 0.06426653038943186, 0.08788138744421303, 0.06379419792210683, 0.03458591483649798, 0.025900421424012166, 0.1271437157993205, 0.04153246161877178, 0.07561059901490808, 0.13000310689676553, 0.04140084914979525, 0.1325568073661998, 0.07934199878945947, 0.1110214926302433, 0.19788414880167693, 0.02819999383063987, 0.024129057783284225, 0.018136868384317495, 0.08039088352234103, 0.09977535039070062, 0.06204811368661467, 0.04034070603665896, 0.05844122773851268, 0.154090192518197, 0.049052473332267255, 0.01885885005322052, 0.31748480920214206, 0.06542117116623558, 0.1036992558510974, 0.01969461594853783, 0.1271517903660424, 0.04102139275346417, 0.2254391272435896, 0.06724422724801116, 0.047043483282322995, 0.015982148361217696, 0.05466632697789464, 0.03887619634042494, 0.08604788934462704, 0.016780048026703298, 0.04291693068807945, 0.04144622776948381, 0.0949592275719624, 0.05848524822795298, 0.16070370795205235, 0.10980811828630976, 0.091406522114994, 0.012332559235801455, 0.08852551967720501, 0.0358017939288402, 0.30391170002985746, 0.49092436500359327, 0.47981257375795394, 0.15161311137489974, 0.7882251916453242, 0.40522593073546886, 14.016300290822983, 38.571984842419624, 34.55789923667908, 8.110414948314428, 16.47053349763155, 50.633046850562096, 70.93951061367989, 61.3618129491806, 51.74609832465649, 28.278546184301376, 43.157043009996414, 36.77473448216915, 48.09300094842911, 59.14736017584801, 68.54732617735863, 50.9458726644516, 15.599735174328089, 0.6954104814212769, 0.13730673061218113, 0.03422134221182205, 0.018096840649377555, 0.028967007165192626, 0.022823729486844968, 0.06667189038125798, 0.025057764687517192, 0.036805953131988645, 0.047518327919533476, 0.03329844075778965, 0.03067375200771494, 0.051593813332146965, 0.04809295802260749, 0.02134861635568086, 0.09290672911447473, 0.05994506384013221, 0.01942718488862738, 0.0315065400354797, 0.04307123432226945, 0.02943880157545209, 0.061318812586250715, 0.06906752823852003, 0.05922402284340933, 0.040681221944396384, 0.07732937592663802, 0.05291967871016823, 0.0658876629313454, 0.015750488819321617, 0.05123357484990265, 0.025776182192203123, 0.03333306194690522, 0.01766912424500333, 0.05272136571875308, 0.031884118798188865, 0.05008415879274253, 0.0567603485978907, 0.00932976294279797, 0.05146182236785535, 0.026995517837349325, 0.051515720842871815, 0.058004132442874834, 0.06374232179950923, 0.06812302657635882, 0.016549566644243896, 0.10791550070280209, 0.04845797593588941, 0.08636956583359279, 0.036588808143278584, 0.007515355664509116, 0.03514242169330828, 0.04479119867028203, 0.0322812234662706, 0.029762025442323647, 0.07987196644535288, 0.0345690012909472, 0.037419045038404875, 0.05441042703751009, 0.0202873822854599, 0.05398434521339368, 0.020934768836013973, 0.030286786932265386, 0.10015849155024625, 0.06654438941041008, 0.011265490029472858, 0.04092428644071333, 0.03460586005530786, 0.035059549772995524, 0.02147764986148104, 0.03759625134989619, 0.05131272118887864, 0.040114458606694825, 0.025683807070890907, 0.018390964905847795, 0.039495251403423026, 0.0051498174616426695, 0.080688432790339, 0.039846547006163746, 0.016787881395430304, 0.07594631693791598, 0.10347454837756231, 0.1606539692147635, 3.0600688979029655, 39.016257002949715, 86.56879395246506, 99.63864862918854, 98.65926638245583, 93.41351106762886, 88.8042140007019, 67.90248557925224, 41.76561087369919, 34.22107011079788, 16.388824582099915, 40.33052287995815, 84.5862503349781, 83.05221185088158, 32.585432678461075, 9.570705089718103, 11.528808418661356, 16.28101486712694, 6.207731170579791, 0.8800979086663574, 0.27358309307601303, 0.23843475646572188, 0.05053777058492415, 0.10896172854700126, 0.2494431665400043, 0.04320676904171705, 0.02883098819438601, 0.05273986746033188, 0.0065376150632801, 0.06387213827110827, 0.07543654312030412, 0.01797256245481549, 0.187196628539823, 0.008972852065198822, 0.158506000880152, 0.06425710511393845, 0.029917952524556313, 0.02013438854191918, 0.0914267753250897, 0.030503620218951255, 0.09964013850549236, 0.15745385811896995, 0.19358435296453536, 0.07750748394755647, 0.3309878893196583, 0.1771879952866584, 0.24019498232519254, 0.30132273270282894, 0.22781149134971201, 0.05164184141904116, 0.06087756497436203, 0.11824762870674022, 0.0810390010883566, 0.20150625990936533, 0.04294144382583909, 0.017351501737721264, 0.06070828851079568, 0.06273701597820036, 0.06692004972137511, 0.06481753793195821, 0.04765050071000587, 0.04805049975402653, 0.09500473606749438, 0.09469811033341102, 0.19404392049182206, 0.09697236251668073, 0.04128901862713974, 0.04852607540669851, 0.052485603955574334, 0.1175888761645183, 0.03674513784062583, 0.2486477475031279, 0.5172387545462698, 0.38210031227208674, 0.15414548252010718, 0.8669140411075205, 0.20211200084304437, 6.334810126572847, 13.9203373901546, 9.850314036011696, 4.827541206032038, 19.908165335655212, 64.96091902256012, 71.07447177171707, 40.18320478498936, 32.108360677957535, 24.657412692904472, 57.78401233255863, 65.7716891169548, 78.5647514462471, 80.72321802377701, 84.03950527310371, 74.5291855931282, 31.10360149294138, 2.861349773593247, 0.09429722442291677, 0.018354204476054292, 0.01678104992606677, 0.0271213211453869, 0.00803209732112009, 0.06533990599564277, 0.03888849743816536, 0.033389862219337374, 0.11102596778073348, 0.017384289822075516, 0.08519833805621602, 0.04495289409533143, 0.07007930558756925, 0.06262734881602228, 0.016575007466599345, 0.1055053538584616, 0.02971659672766691, 0.03402019792702049, 0.006509707527584396, 0.022947708966967184, 0.11739107896573842, 0.03897149181284476, 0.02168609316868242, 0.01570062762766611, 0.07326965001993813, 0.02529209781641839, 0.010867528180824593, 0.0014795799324929249, 0.02462022595864255, 0.040495822322554886, 0.03476054218481295, 0.01134989634010708, 0.06811377941630781, 0.07819459395250306, 0.06600101114599966, 0.0656297146633733, 0.0388083937286865, 0.02898924933106173, 0.034456142893759534, 0.03490661911200732, 0.03278042910096701, 0.10451368128997274, 0.11955895912251435, 0.156807595922146, 0.22752738237613812, 0.15172228129813448, 0.2701001346576959, 0.164378882618621, 0.2455252650543116, 0.13340349396457896, 0.10521122589125298, 0.12340546600171365, 0.09861699887551367, 0.1301606945344247, 0.13057326927082613, 0.12382862376398407, 0.1696380676003173, 0.15589499176712707, 0.11039339078706689, 0.1442143294843845, 0.10874605301069096, 0.16869407059857622, 0.20365486649097875, 0.14467275410424918, 0.16889198654098436, 0.07810358438291587, 0.15405759739223868, 0.09851745460764505, 0.13298570935148746, 0.1209443632978946, 0.12122767817345448, 0.11605412219068967, 0.16429723153123632, 0.1569632242899388, 0.10935880723991431, 0.14633307204348966, 0.1826375856762752, 0.12690033589024097, 0.18183220701757818, 0.14697795384563506, 0.36643850267864764, 1.3175226585008204, 31.783654801547527, 91.45519495010376, 109.91876900196075, 103.29434886574745, 87.27732673287392, 82.85386249423027, 61.16984724998474, 33.36066707968712, 38.356122225522995, 47.69046574831009, 76.29671394824982, 111.522366553545, 82.98863366246223, 37.56809011101723, 24.341797828674316, 47.53473870456219, 55.81105940043926, 22.373596541583538, 3.812716123647988, 0.7357063691597432, 0.4145067249191925, 0.20520423335256055, 0.3713085944764316, 0.5013819085434079, 0.11178622386069037, 0.13617976452223957, 0.27879145578481257, 0.1167220996285323, 0.2504219702677801, 0.2570692088920623, 0.17548442498082295, 0.35665607603732497, 0.22874854184919968, 0.38114828523248434, 0.38600065454375, 0.15718422102509066, 0.20764819986652583, 0.2692502271384001, 0.3378707746742293, 0.3534254478290677, 0.23329802585067227, 0.24024424608796835, 0.19839182234136388, 0.5645380227360874, 0.395190134877339, 0.34847576811444014, 1.2227994413115084, 0.5027293518651277, 0.7857193448580801, 0.37605572724714875, 0.3597861877642572, 0.19782826508162543, 0.6178092048503458, 0.2330193790839985, 0.162107658397872, 0.172593982424587, 0.1566087151877582, 0.17925711785210297, 0.24416281550657004, 0.12424361048033461, 0.24491780233802274, 0.2592079300666228, 0.1841194467851892, 0.3344722726615146, 0.3089251450728625, 0.19616588397184387, 0.23622838110895827, 0.09848054760368541, 0.22339565330184996, 0.13862450286978856, 0.488252128707245, 1.0075405170209706, 0.7766905543394387, 0.32310061098542064, 1.468299280386418, 1.5076405880972743, 22.707041949033737, 56.055694073438644, 47.11006969213486, 14.85118294134736, 22.548100277781487, 75.03654196858406, 100.30849948525429, 81.07795178890228, 71.63434132933617, 37.761191949248314, 54.696708396077156, 51.55635930597782, 65.09027928113937, 77.36666813492775, 93.09676766395569, 80.02369076013565, 30.637963078916073, 2.0584884798154235, 0.22862093697767705, 0.19897667923942208, 0.17312035808572546, 0.10417685756692663, 0.16001655341824517, 0.18306990154087543, 0.16907094803173095, 0.0939132520579733, 0.18238359305541962, 0.11917122406885028, 0.1792967040091753, 0.16534924070583656, 0.20488096866756678, 0.18410919030429795, 0.2190435805823654, 0.22109787503723055, 0.14105932612437755, 0.08965207758592442, 0.17615728575037792, 0.08081352920271456, 0.24563413811847568, 0.16967895993730053, 0.1503945791046135, 0.15689601539634168, 0.23650974413612857, 0.11294476091279648, 0.16316845460096374, 0.16852229309733957, 0.13591100316261873, 0.14936904975911602, 0.15658106276532635, 0.16363612638087943, 0.18881577212596312, 0.14564455195795745, 0.148874185688328, 0.16863544093212113, 0.09281690698117018, 0.1808314654044807, 0.08235314424382523, 0.05388962119468488, 0.11284430380328558], [0.02545090814237483, 0.023657413657929283, 0.07533044568845071, 0.05470184245496057, 0.013404513629211579, 0.027675835335685406, 0.03671308819320984, 0.07466934795957059, 0.043137333705089986, 0.04978308432328049, 0.015431531373906182, 0.023892201352282427, 0.04706929888925515, 0.05353325672331266, 0.00795038871729048, 0.013333298065845156, 0.08638026760309003, 0.024686136093805544, 0.01800404250388965, 0.049710034727468155, 0.06276537344092503, 0.08436883959802799, 0.031926784868119285, 0.03711597419169266, 0.009503831824986264, 0.024513154457963537, 0.0103601524278929, 0.03652226347185206, 0.039216445074998774, 0.033968781935982406, 0.042092671792488545, 0.03225445791031234, 0.011174267092428636, 0.06018492596922442, 0.05003033824323211, 0.07177866049460135, 0.0645751302363351, 0.05205509893130511, 0.10770531705929898, 9.83631843701005, 50.48251412808895, 88.4772339463234, 88.71501758694649, 80.04883781075478, 63.14111687242985, 37.25714899599552, 43.38259130716324, 39.4748467952013, 40.98687306046486, 41.41655020415783, 94.9136933684349, 87.18355536460876, 29.51913021504879, 12.48835762962699, 35.823630318045616, 48.66080068051815, 19.606113843619823, 1.5313749457709491, 0.43814780947286636, 0.13890484173316509, 0.17470460588810965, 0.2665777533547953, 0.20535741263302043, 0.0593944236607058, 0.04843278002226725, 0.08865475727361627, 0.1332336905761622, 0.023270153578778263, 0.09334920498076826, 0.03302537865238264, 0.07372188512817957, 0.03147057184833102, 0.13938210206106305, 0.03868944229907356, 0.04351858609879855, 0.06358774728141725, 0.05099243251606822, 0.0451902885833988, 0.026132275779673364, 0.06526139419293031, 0.018849923872039653, 0.12990291696041822, 0.08033182341023348, 0.029291299724718556, 0.06651276649790816, 0.028664324090641458, 0.11412197040044703, 0.03643568452389445, 0.07372286476311274, 0.074451742839301, 0.09473384474404156, 0.11781323482864536, 0.05872441644896753, 0.06057873550162185, 0.10077995859319344, 0.10467420041095465, 0.07506486072088592, 0.024150381541403476, 0.06001855872455053, 0.12342370799160562, 0.06581421999726444, 0.07369002472842112, 0.06389719317667186, 0.03871258988510817, 0.03789949289057404, 0.07467553747119382, 0.028749526354658883, 0.0787457573460415, 0.1605989909148775, 0.2249175458564423, 0.1043823805230204, 0.12563740834593773, 0.08999894256703556, 0.17698197509162128, 0.13555063109379262, 0.2715510630514473, 0.14651676843641326, 0.8524258935358375, 0.25180180091410875, 16.792837902903557, 53.130569234490395, 30.373567566275597, 6.161676216870546, 14.750902522355318, 45.60535803437233, 51.203149259090424, 57.5009161233902, 32.426851987838745, 25.012511238455772, 33.64866882562637, 40.047749653458595, 50.00790819525719, 65.1878048479557, 72.02892735600471, 32.80591204762459, 1.8933173990808427, 0.2647491608513519, 0.04629793285857886, 0.004655725688280654, 0.012123153919674223, 0.030221811903174967, 0.03314597393909935, 0.02139689491741592, 0.028974703236599453, 0.041852943249978125, 0.10137420365936123, 0.03637001558672637, 0.07464496098691598, 0.02258321241242811, 0.06607357834582217, 0.015126278613024624, 0.025538166155456565, 0.02565084087109426, 0.01533053064122214, 0.09479996268055402, 0.07379527611192316, 0.03195186945958994, 0.06202494383614976, 0.0055290136424446246, 0.07577947471872903, 0.0738991767866537, 0.0667630929092411, 0.002973798264065408, 0.04620274128683377, 0.014154205236991402, 0.03266837593400851, 0.014052813021407928, 0.04862825429881923, 0.014988463644840522, 0.021590849646599963, 0.06459319411078468, 0.06360264218528755, 0.05570225010160357, 0.029125585570000112, 0.03958125889766961, 0.015085659942997154, 0.030582989202230237, 0.04079760554304812, 0.11033306160243228, 0.05030229454860091, 0.04487512072955724, 0.05208538226725068, 0.08558638481190428, 0.02619579063320998, 0.030520925247401465, 0.01896138332085684, 0.04894633879303001, 0.02893446770031005, 0.010324934737582225, 0.011304126237519085, 0.05725109003833495, 0.012313249480939703, 0.03586608247132972, 0.03646753008069936, 0.08440675592282787, 0.038872118238941766, 0.0533167091634823, 0.049799500629887916, 0.06132032285677269, 0.05635705812892411, 0.0353535330214072, 0.07795680241542868, 0.06597387080546468, 0.05624241486657411, 0.02492449537385255, 0.04503543575992808, 0.05747563423938118, 0.04538492423307616, 0.05678216773958411, 0.024226807909144554, 0.021024232883064542, 0.029761815785604995, 0.03932259074645117, 0.08154191003995948, 0.2267954614944756, 24.65339820832014, 75.89490070939064, 104.65101286768913, 103.41784223914146, 101.74213215708733, 86.48167222738266, 64.39424023032188, 58.680129647254944, 36.01619638502598, 27.554567232728004, 17.752090729773045, 93.43247205018997, 117.32405483722687, 39.83194783329964, 9.409692529588938, 13.046344388276339, 23.088110201060772, 10.381856113672256, 0.43009090586565435, 0.3035402105888352, 0.010965417459374294, 0.16381919936975464, 0.30930355133023113, 0.18116054852725938, 0.06312137425993569, 0.0409968425083207, 0.06795981345931068, 0.1769646830507554, 0.03977655876951758, 0.12692585092736408, 0.01036278797982959, 0.11294839743641205, 0.11864268875797279, 0.02767333800875349, 0.08545471297111362, 0.11805288173491135, 0.05079992683022283, 0.033858509923447855, 0.06448366795666516, 0.1909498029272072, 0.162358459783718, 0.08120088576106355, 0.23904141766251996, 0.1315221792901866, 0.03589249921787996, 0.12997840822208673, 0.13485813309671357, 0.13033048307988793, 0.07004956773016602, 0.13484082621289417, 0.05161550630873535, 0.14817171322647482, 0.18847383500542492, 0.16635630541713908, 0.07094006330589764, 0.3090584941674024, 0.1430564752081409, 0.4831699311034754, 0.11027070635464042, 0.18151535448851064, 0.07887620464316569, 0.07101242270437069, 0.10619505395879969, 0.041555868956493214, 0.23729112173896283, 0.1212504249997437, 0.07541445680544712, 0.08672406751429662, 0.07121784175978974, 0.16868160251760855, 0.028777525731129572, 0.15932172507746145, 0.09594727845978923, 0.096578133670846, 0.14504180930089206, 0.1630087147350423, 0.34535744169261307, 0.05635357003484387, 0.7938862941227853, 0.24001078127184883, 7.478149300441146, 22.43741411715746, 12.438711393624544, 5.4900655802339315, 20.889230892062187, 51.96951113641262, 49.38676692545414, 42.7346158772707, 16.05269081890583, 24.87634364515543, 46.80660657584667, 64.28814992308617, 76.41189336776733, 83.84975865483284, 86.61597222089767, 55.99121533334255, 7.942566554993391, 0.13752366037806496, 0.09562196544720791, 0.043977266759611666, 0.029457069540512748, 0.12275736327865161, 0.04450212843948975, 0.02602646407467546, 0.02952669412479736, 0.01963792699825717, 0.08335275779245421, 0.03750151248823386, 0.04998139731469564, 0.04974010655132588, 0.04182582888461184, 0.11397608643164858, 0.0397571441862965, 0.027103977154183667, 0.0775892092497088, 0.10518034512642771, 0.019234005703765433, 0.005560783129112679, 0.01208538416904048, 0.017968220890907105, 0.07183322319178842, 0.01971746482013259, 0.018407676216156688, 0.022647218938800506, 0.031990394345484674, 0.028503675093816128, 0.03798352998273913, 0.03500301667372696, 0.010016413743869634, 0.013963789624540368, 0.026628794839780312, 0.04682577426137868, 0.016119501342473086, 0.05434337770566344, 0.03478200509562157, 0.010213814821327105, 0.04055047036672477, 0.13846347166690975, 0.1117865281412378, 0.2862217789515853, 0.17737145419232547, 0.15850859839702025, 0.13666937418747693, 0.1071356816100888, 0.1641433546319604, 0.1237876497907564, 0.09557037134072743, 0.18115524959284812, 0.10229652252746746, 0.09668775630416349, 0.13758396729826927, 0.09015342802740633, 0.08221065188990906, 0.21355633361963555, 0.09980657254345715, 0.17017774254782125, 0.08617640705779195, 0.14989077957579866, 0.13618709694128484, 0.1062020004610531, 0.12486607942264527, 0.11990987622993998, 0.23372689815005288, 0.09287889115512371, 0.21399751072749496, 0.13477804051944986, 0.11276437449851073, 0.11384891942725517, 0.1374262460740283, 0.22124854585854337, 0.10453882525325753, 0.19923052343074232, 0.13759757828665897, 0.11276500532403588, 0.24024065409321338, 0.13633330003358424, 18.452322855591774, 80.29073283076286, 120.50686284899712, 112.56572216749191, 100.67153960466385, 86.04036390781403, 53.235633596777916, 56.721566542983055, 53.926406130194664, 57.14879661798477, 58.886690363287926, 130.04119724035263, 114.29364144802094, 39.926908537745476, 20.24779301136732, 49.51673895120621, 69.92589980363846, 30.042426735162735, 3.2691006688401103, 0.8831594756338745, 0.3436714009149, 0.41245875356253237, 0.7455791893880814, 0.48575328779406846, 0.227380184805952, 0.10810500069055706, 0.23903971072286367, 0.5102485546376556, 0.21750788408098742, 0.2940601349109784, 0.17540164582896978, 0.17892275063786656, 0.34981326665729284, 0.42538634268566966, 0.20334182860096917, 0.25261474947910756, 0.1422935028676875, 0.2785678021609783, 0.139852816646453, 0.32679876254405826, 0.2908463979838416, 0.175242202822119, 0.23279535438632593, 0.26902767189312726, 0.0903144221229013, 0.2750932448543608, 0.21270848927088082, 0.31364173104520887, 0.16515741037437692, 0.24573980510467663, 0.14489023305941373, 0.10910908938967623, 0.256852739257738, 0.24920838070102036, 0.1739930792246014, 0.3498464555013925, 0.27197203889954835, 0.7045091525651515, 0.29328687640372664, 0.3859047987498343, 0.3875876928213984, 0.14325106632895768, 0.13198355765780434, 0.24266149528557435, 0.3066752204904333, 0.1818263143650256, 0.23656846286030486, 0.12936545361299068, 0.35846697574015707, 0.4454341559903696, 0.3497405955567956, 0.22897280403412879, 0.27192949899472296, 0.19343264313647524, 0.3184835915453732, 0.6143217638600618, 1.0334050166420639, 0.272132313111797, 1.4286613510921597, 0.9184308454860002, 26.58819928765297, 72.6618517935276, 40.2009080350399, 11.162207890301943, 25.320862792432308, 69.3304793536663, 68.41803431510925, 77.74798527359962, 43.621682077646255, 32.805592864751816, 43.088734075427055, 53.88078197836876, 66.34539753198624, 85.47390550374985, 98.67086336016655, 58.60101789236069, 5.737191494554281, 0.40703727572690696, 0.17692481487756595, 0.09807477836147882, 0.09514880177448504, 0.1893784833373502, 0.23572354257339612, 0.2017863019136712, 0.23150225111749023, 0.09845612352364697, 0.1985139650059864, 0.11870594942593016, 0.15552448196103796, 0.18539724696893245, 0.17491399543359876, 0.21177414018893614, 0.14152509800624102, 0.1461354232742451, 0.13959477189928293, 0.150163593061734, 0.17376270174281672, 0.08521206778823398, 0.09645876663853414, 0.07984927156940103, 0.227000932500232, 0.23162114317528903, 0.13912818365497515, 0.12351886616670527, 0.14560876559698954, 0.12486547086155042, 0.1409897126723081, 0.19053838594118133, 0.13439095113426447, 0.06763347628293559, 0.13769226148724556, 0.12399608196574263, 0.08352997523616068, 0.1422824151813984, 0.1135466797859408, 0.07957822439493611, 0.17109770880779251], [0.09000502075650729, 0.05109051846375223, 0.04050875795655884, 0.08026569805224426, 0.07551636852440424, 0.07238590056658722, 0.06226802317542024, 0.008288055705634179, 0.062283578590722755, 0.04810681763046887, 0.018641654969542287, 0.07250265523907728, 0.046024540497455746, 0.03197095007635653, 0.017931783295352943, 0.04553074140858371, 0.014569711456715595, 0.03808175322774332, 0.05516697980056051, 0.040112198767019436, 0.02681463232875103, 0.04259220768290106, 0.03967023498262279, 0.037893210610491224, 0.04256576867192052, 0.038850770361023024, 0.01947416840266669, 0.05923587865254376, 0.06967216337216087, 0.02820951001922367, 0.010730767062341329, 0.04856669685977977, 0.01164473769676988, 0.12202975427499041, 0.01754040986270411, 0.04703364240413066, 0.19179169525159523, 0.6862257805187255, 24.510873556137085, 70.56849852204323, 84.36940357089043, 77.19321504235268, 63.12785558402538, 43.354317024350166, 47.770744040608406, 22.4140814691782, 23.85417189449072, 41.35111391544342, 80.81318199634552, 93.62908110022545, 30.689338222146034, 5.327192544937134, 24.647766910493374, 63.39207820594311, 28.17043248564005, 1.3159643858671188, 1.1114939139224589, 0.03713787125889212, 0.30766482988838106, 0.16462790285004303, 0.07615432608872652, 0.10981965868268162, 0.027790393251052592, 0.014480955233011628, 0.13980503717903048, 0.058453959281905554, 0.02983914571814239, 0.03424717637244612, 0.06255495973164216, 0.13296225748490542, 0.07287998538231477, 0.06472316643339582, 0.0984834716655314, 0.06792139247409068, 0.029883056740800384, 0.14765655883820727, 0.04307271861762274, 0.03705214949150104, 0.058805440421565436, 0.05948208243353292, 0.2945424121571705, 0.3443565219640732, 0.25214586057700217, 0.2805587468901649, 0.20312408247264102, 0.02710055028728675, 0.03530317830154672, 0.16524329170351848, 0.07521946492488496, 0.18482815328752622, 0.19026520138140768, 0.01947260618180735, 0.05817858167574741, 0.11328407825203612, 0.030109690087556373, 0.11568255111342296, 0.04327946611738298, 0.120609461737331, 0.031466182044823654, 0.14721094368724152, 0.11575619442737661, 0.08610196964582428, 0.03705405681103002, 0.07468257303116843, 0.07937958856928162, 0.01773313448211411, 0.047643502257415093, 0.08376563680940308, 0.037631462546414696, 0.03269733824708965, 0.04560717519780155, 0.09372295055072755, 0.20121336390729994, 0.09195364822517149, 0.04553900893370155, 0.04036464772070758, 0.09415209002327174, 0.49508932745084167, 0.02202930121711688, 1.1947324848733842, 0.4558029386680573, 20.65219771116972, 48.02742786705494, 26.869142912328243, 10.30855804681778, 17.24665705114603, 44.00141850113869, 76.5978553891182, 54.40567061305046, 33.49080249667168, 28.058821074664593, 42.45986022055149, 46.90276421606541, 55.27546674013138, 76.25157997012138, 51.53093107044697, 8.328270558267832, 0.32976557209622115, 0.027937731829297263, 0.061514854605775326, 0.04776261324877851, 0.06548831326654181, 0.030427624296862632, 0.022537245640705805, 0.017448589496780187, 0.0327809189184336, 0.0151534838914813, 0.03761187726922799, 0.020316951304266695, 0.05935984700045083, 0.020201875740895048, 0.02899228285969002, 0.01271885730602662, 0.017319350044999737, 0.014906896049069474, 0.04340428793511819, 0.02745044323091861, 0.044628720279433765, 0.04170235035417136, 0.022192330652615055, 0.02705892507947283, 0.023115519688872155, 0.033744853717507794, 0.04541208312730305, 0.027586543837969657, 0.01279567515666713, 0.02540204513934441, 0.027303305032546632, 0.03054067008633865, 0.026210665128019173, 0.019139250143780373, 0.03626668265496846, 0.04309935058699921, 0.07949526712764055, 0.017502859045634978, 0.045682458658120595, 0.04647791480238084, 0.044541068928083405, 0.027269871279713698, 0.017954997674678452, 0.08267531055025756, 0.024584424754721113, 0.019788948484347202, 0.03409003031265456, 0.011042681526305387, 0.0371938254829729, 0.029330787547223736, 0.024580259450885933, 0.037956385931465775, 0.02521901853469899, 0.04228729630995076, 0.090356539003551, 0.034580849678604864, 0.024803571686788928, 0.007733038246442447, 0.005146326120666345, 0.04768063561641611, 0.03303413228422869, 0.058145021757809445, 0.023247813078342006, 0.048850178718566895, 0.02575784186774399, 0.03636427878518589, 0.020039414048369508, 0.017409021893399768, 0.05297069023072254, 0.019896185112884268, 0.057807255507213995, 0.046485544080496766, 0.024626530503155664, 0.013155312499293359, 0.06489357096143067, 0.08204947967897169, 4.105901978909969, 50.77141262590885, 91.05353370308876, 100.07849782705307, 100.39186701178551, 89.4872273504734, 72.38978639245033, 72.39711999893188, 26.5089051425457, 14.944270346313715, 29.601196311414242, 61.880948692560196, 116.84177711606026, 50.70037543773651, 6.131704850122333, 10.685904398560524, 27.592755183577538, 16.466205529868603, 0.20203662832500413, 0.9504308283794671, 0.09726295043947175, 0.21966938918922096, 0.10660593659849837, 0.03759270388400182, 0.05804079453810118, 0.042474514193600044, 0.09779558240552433, 0.11697635942255147, 0.11259235951001756, 0.014273932210926432, 0.036051812348887324, 0.11095922644017264, 0.09791955817490816, 0.2175327905570157, 0.1399403455434367, 0.39918936090543866, 0.5123553040903062, 0.31743271043524146, 0.7640917366370559, 0.2117930501117371, 0.34373564121779054, 0.32055833959020674, 0.10066566785098985, 0.5153425375465304, 1.052909370046109, 1.5903032524511218, 1.4746703510172665, 1.1741564702242613, 0.41802584077231586, 0.2697423897916451, 0.6940815027337521, 0.6309357786085457, 0.7761496771126986, 1.3254223158583045, 0.5487924395129085, 0.4307589872041717, 0.6535509182140231, 0.2978712413460016, 0.7589950819965452, 0.2391760580940172, 0.49546794150955975, 0.3075521718710661, 0.7588813256006688, 0.5350382463075221, 0.5815109401009977, 0.5084767215885222, 0.38497586734592915, 0.21965312131214887, 0.11426815122831613, 0.21421677083708346, 0.12509412656072527, 0.03345263306982815, 0.02958471708552679, 0.06134942617791239, 0.14733926102053374, 0.31322069582529366, 0.10290296107996255, 0.06329591255052947, 0.1887426557368599, 0.1081211275595706, 0.4921707574976608, 0.0302602922602091, 0.925225296523422, 0.2978563687065616, 10.211742091923952, 24.350704550743103, 13.170075248926878, 10.285594929009676, 21.842455342411995, 47.56891027092934, 72.05871015787125, 29.621772207319736, 18.299610950052738, 33.02301339805126, 65.69261536002159, 69.32613998651505, 74.25738617777824, 89.04376074671745, 72.66914740204811, 20.466866455972195, 0.7994369056541473, 0.09012576076202095, 0.023794093140168115, 0.0425016359804431, 0.09975617329473607, 0.04030733536637854, 0.02064612719550496, 0.025792223714233842, 0.10119583588675596, 0.009646173893997911, 0.013754441824858077, 0.03681828762637451, 0.04817600805836264, 0.008916495226003462, 0.020675004161603283, 0.06294656879617833, 0.032416513276984915, 0.012564966491481755, 0.043856059201061726, 0.05247447174042463, 0.036544101167237386, 0.0282505359427887, 0.02853543159289984, 0.04688755434472114, 0.021411945672298316, 0.04609867733961437, 0.035807630920317024, 0.003891558490067837, 0.030356498718902003, 0.06879927896079607, 0.005630619225485134, 0.03247715416364372, 0.05593559988483321, 0.08834943771944381, 0.026664340002753306, 0.06179452182550449, 0.05603108831564896, 0.03240914003981743, 0.01432482962627546, 0.21975549316266552, 0.10123036059667356, 0.17355188727378845, 0.09217474886099808, 0.2057858248008415, 0.17374923918396235, 0.14670429431134835, 0.07867480060667731, 0.1593071047682315, 0.15292766271159053, 0.09974575354135595, 0.13901766302296892, 0.079298857745016, 0.12341009700321592, 0.11018630932085216, 0.28739250206854194, 0.12326661017141305, 0.16439090541098267, 0.1161993901769165, 0.14028465753654018, 0.15681139571825042, 0.14019714348251, 0.11289876259979792, 0.09441607195185497, 0.19407091982429847, 0.13560652965679765, 0.1335460605332628, 0.18027898098807782, 0.1302021212177351, 0.15417697926750407, 0.11833523181849159, 0.18533000838942826, 0.12625134258996695, 0.14870110200718045, 0.07436933476128615, 0.17286854737903923, 0.28326206433121115, 1.8156940955668688, 47.05288276076317, 105.27713567018509, 110.53217008709908, 99.9732206761837, 83.4227603673935, 60.975571274757385, 63.79791542887688, 33.48535738885403, 37.35326863825321, 64.64291408658028, 111.38232886791229, 126.92689195275307, 43.17500464618206, 9.4623121060431, 33.311896696686745, 87.45294570922852, 44.80589993298054, 2.1931888768449426, 1.6172894043847919, 0.20072819228516892, 0.749067758442834, 0.4672199010383338, 0.27759852760937065, 0.2043722858070396, 0.1962179085239768, 0.31713718723040074, 0.3759564278880134, 0.3400484734447673, 0.18845234240870923, 0.17332094575976953, 0.21884876681724563, 0.3247990011004731, 0.19583019573474303, 0.11270926261204295, 0.23473690176615492, 0.3321459365542978, 0.3752330713905394, 0.46931053104344755, 0.2476323113660328, 0.18774250784190372, 0.3096714784624055, 0.2515896060504019, 0.5679177038837224, 0.811342973029241, 1.1728542088530958, 1.2009079847484827, 0.5084719124715775, 0.34220782632473856, 0.4430852585937828, 0.6063487229403108, 0.2147177650476806, 0.2786971436580643, 0.5757804319728166, 0.2453752770088613, 0.13605076441308483, 0.20530973706627265, 0.26176988321822137, 0.19792872219113633, 0.17821570654632524, 0.32271294272504747, 0.2702441706787795, 0.5665813037194312, 0.2881839877227321, 0.33494258648715913, 0.41648125334177166, 0.31638102780561894, 0.29171515605412424, 0.26243585685733706, 0.31134092481806874, 0.2317744115134701, 0.17189339501783252, 0.2095073540112935, 0.3043980145594105, 0.40721601457335055, 0.5774075165390968, 0.2464054967276752, 0.23195966641651466, 0.287439851090312, 0.4064212634693831, 1.3081289688125253, 0.2578836417524144, 2.0701125310733914, 1.0481071402318776, 31.812010779976845, 66.48193180561066, 35.905538722872734, 18.079602755606174, 33.242660611867905, 64.22522529959679, 108.49480301141739, 73.96495386958122, 45.35748593509197, 37.33974136412144, 55.94747208058834, 61.510601565241814, 72.31825143098831, 100.42523682117462, 75.96184551715851, 17.295258343219757, 0.5086899257730693, 0.24009171989746392, 0.1944244047626853, 0.272474383818917, 0.1919972404721193, 0.1586881239200011, 0.0933278830780182, 0.21137217816431075, 0.18321907322388142, 0.0801008299458772, 0.1097646432754118, 0.09760334389284253, 0.159509681398049, 0.10311836202163249, 0.12348447504336946, 0.11044312210287899, 0.1037666280171834, 0.16921991191338748, 0.08901840221369639, 0.16423483175458387, 0.1274942173040472, 0.10685607005143538, 0.18765901622828096, 0.19728645274881274, 0.11880645106430165, 0.19390040397411212, 0.11687754988088273, 0.11172142694704235, 0.15008921502158046, 0.10671454991097562, 0.10118373887962662, 0.14007286343257874, 0.09624407815863378, 0.1884227158734575, 0.08673448726767674, 0.16043519892264158, 0.17106009676354006, 0.13604009232949466, 0.10774111826322041], [0.055232578233699314, 0.01916452769364696, 0.012273221745999763, 0.025562766495568212, 0.03616223650169559, 0.07061105439788662, 0.09999985748436302, 0.04281725283362903, 0.035940371453762054, 0.07656632937141694, 0.020688227377831936, 0.02389864319411572, 0.057613807293819264, 0.049970569380093366, 0.050563601034809835, 0.06190554711793084, 0.029075288366584573, 0.023427980559063144, 0.038859115811646916, 0.06268965953495353, 0.01800203313905513, 0.05958000881946646, 0.029448366003634874, 0.040043665139819495, 0.020107040400034748, 0.14773641392821446, 0.03672444676340092, 0.030756738960917573, 0.029217305745987687, 0.048276071829604916, 0.00894028755283216, 0.030926119325158652, 0.16384483315050602, 0.02000833846977912, 0.05657797693856992, 0.02331897761905566, 2.496174406260252, 49.09303888678551, 88.325454890728, 80.39287135004997, 60.251250341534615, 66.9019004702568, 58.60957883298397, 35.135221257805824, 26.589654609560966, 52.93663904070854, 62.10814230144024, 51.12707354128361, 51.44721016287804, 9.684548880904913, 15.699728708714247, 67.66604706645012, 55.139179453253746, 5.959966415539384, 0.9988711634650826, 0.059338202263461426, 0.5470022605732083, 0.06478592986240983, 0.056661572452867404, 0.0650708180910442, 0.15336471347836778, 0.18880987947341055, 0.14982357068220153, 0.08698208257555962, 0.08784112593275495, 0.02089880250423448, 0.06821777657023631, 0.050400632826494984, 0.04452323883015197, 0.0560741254594177, 0.0239003742535715, 0.23974972340511158, 0.26590248802676797, 0.08117704055621289, 0.051099127376801334, 0.18970416742376983, 0.36700600816402584, 0.0888530517113395, 0.2203179817297496, 0.0786552821227815, 0.44366811169311404, 0.7315933867357671, 0.24480343738105148, 0.639204194303602, 0.3127813444007188, 0.17334980046143755, 0.20230096648447216, 0.25774705689400434, 0.4385357449064031, 0.1205203594872728, 0.18304404511582106, 0.2846017596311867, 0.3929725382477045, 0.3312787221511826, 0.7299286010675132, 0.9621868631802499, 2.2440878581255674, 0.456442313734442, 0.3279441932681948, 0.9595195250585675, 0.920069923158735, 0.14808848878601566, 0.016788308130344376, 0.2143406352843158, 0.25146825006231666, 0.0976019338122569, 0.07783124587149359, 0.08860567904775962, 0.10206768129137345, 0.1829001575242728, 0.13577052945038304, 0.03984408678661566, 0.09869909525150433, 0.08793830274953507, 0.02927305959019577, 0.1739747927058488, 0.02707495732465759, 0.08178557938663289, 0.1578388991765678, 0.8030538959428668, 0.17828989162808284, 1.3511261553503573, 0.7132992683909833, 20.052726678550243, 35.168347880244255, 28.4859998524189, 20.65829638391733, 23.66406999528408, 58.09266597032547, 71.71542897820473, 44.23725664615631, 26.553155668079853, 33.97863931953907, 45.04994183778763, 38.20359840989113, 69.39565345644951, 65.6509467959404, 24.019968397915363, 0.9282558714039624, 0.11561736828298308, 0.06962410931009799, 0.07449533659382723, 0.025556512046023272, 0.0756963319145143, 0.015577690865029581, 0.02100645659083966, 0.07220633051474579, 0.0841377125470899, 0.07525195615016855, 0.01817669573938474, 0.013294563523231773, 0.034006008063443005, 0.0354465315467678, 0.021814950414409395, 0.04302783723687753, 0.08357175072887912, 0.024548219080315903, 0.07488458562875167, 0.03904536148183979, 0.1064200879773125, 0.04778800954227336, 0.03276567891589366, 0.02782649502478307, 0.04817346991330851, 0.045586246633320116, 0.031161471051746048, 0.06777875911211595, 0.06315870428807102, 0.015683066558267456, 0.02937407887657173, 0.04000518849352375, 0.029326631520234514, 0.03876837341522332, 0.04426934268849436, 0.03690097772050649, 0.020907468933728524, 0.04054042168718297, 0.03356181783601642, 0.05199077699217014, 0.062190899188863114, 0.012062516743753804, 0.038988720771158114, 0.05092279679956846, 0.030865441331116017, 0.07937622664030641, 0.08286347467219457, 0.07680654773139395, 0.03932810861442704, 0.0557643678621389, 0.04524943775322754, 0.04298707477573771, 0.083503302448662, 0.0509367083577672, 0.03897507267538458, 0.04039935796754435, 0.0069285348581615835, 0.018248021697218064, 0.07641510193934664, 0.030795195198152214, 0.03933328880521003, 0.023440739932993893, 0.09587503780494444, 0.1122188959561754, 0.01787436704034917, 0.004296544766475563, 0.03295127520686947, 0.024481008331349585, 0.0358828401658684, 0.02358310426643584, 0.10886052186833695, 0.04432570880453568, 0.07688142301049083, 9.390886388719082, 76.07017770409584, 104.62684616446495, 93.83068308234215, 82.12557077407837, 102.26290181279182, 82.44182780385017, 46.26980558037758, 24.77622091770172, 24.852655716240406, 51.535969600081444, 64.59249079227448, 71.82812333106995, 12.104462329298258, 5.722781717777252, 36.631824150681496, 31.896339654922485, 2.294026678428054, 0.7896948221605271, 0.08576506428653374, 0.7037847570609301, 0.09233578006387688, 0.012991213443456218, 0.04382224324217532, 0.011791650467785075, 0.18856667767977342, 0.1386574690695852, 0.15110261767404154, 0.01713293924694881, 0.10253950167680159, 0.17924714338732883, 0.03817095566773787, 0.11687157559208572, 0.19178854854544625, 0.6923039699904621, 1.0785068152472377, 0.9163281926885247, 0.4262080485932529, 0.3552158345701173, 1.0302046383731067, 3.120515816845, 1.2893480015918612, 1.6127585037611425, 1.137944650836289, 3.1884321849793196, 3.7801661202684045, 2.175306798890233, 2.9496059753000736, 2.508395737968385, 1.6061873501166701, 2.313110204413533, 2.559239147230983, 2.2346902498975396, 0.7523572538048029, 1.5222612535580993, 1.0255489381961524, 1.5413070190697908, 2.468479829840362, 3.4199057891964912, 3.6493177665397525, 4.717288697138429, 3.690041843801737, 1.4070323179475963, 2.029149541631341, 2.2102219378575683, 0.7205759966745973, 0.4866290814243257, 0.5975237558595836, 0.20938739326084033, 0.44429552333895117, 0.31256796210072935, 0.5557287891861051, 0.23741989920381457, 0.2753347990801558, 0.07136027474189177, 0.10947147267870605, 0.1651577666052617, 0.13235524005722255, 0.11806632202933542, 0.1600542396772653, 0.08748125852434896, 0.10660463784006424, 0.04491276245971676, 0.7765624299645424, 0.14043405186384916, 1.1348359426483512, 0.21551495039602742, 11.289670150727034, 21.773863323032856, 22.47562486678362, 19.0029589086771, 29.79364648461342, 67.8072626888752, 63.7024949491024, 30.818105712532997, 18.600963279604912, 45.89281640946865, 71.64367362856865, 60.865115001797676, 86.77434012293816, 80.99647656083107, 45.1667969673872, 3.539300845004618, 0.14830203435849398, 0.15200872061541304, 0.06705889813019894, 0.07563402861705981, 0.026258466859871987, 0.03955737287469674, 0.025156974988931324, 0.01798791749024531, 0.05829272769915406, 0.023638238417333923, 0.039889810504973866, 0.055467063502874225, 0.03550546178303193, 0.0350504361995263, 0.09898861448164098, 0.02070874033961445, 0.01944540832482744, 0.016456729536002968, 0.031161493316176347, 0.08417121309321374, 0.06367563240928575, 0.043097684465465136, 0.06881864901515655, 0.036296580074122176, 0.052925575073459186, 0.10802939810673706, 0.03876719711115584, 0.048256286172545515, 0.04348293332441244, 0.020016481685161125, 0.05707754993636627, 0.03404840324947145, 0.0070856011370779015, 0.03284000871644821, 0.03350575228978414, 0.02021346994297346, 0.01850767690484645, 0.1445855962811038, 0.11210341777768917, 0.09775137266842648, 0.16840939759276807, 0.11386497208150104, 0.15664813807234168, 0.1915649394504726, 0.15234786726068705, 0.16567525133723393, 0.2723698894260451, 0.12869131634943187, 0.11927850893698633, 0.15781556605361402, 0.18895983783295378, 0.1992342044832185, 0.15226909570628777, 0.12650585471419618, 0.13167195953428745, 0.14772197173442692, 0.17515308572910726, 0.06231693070731126, 0.14961391396354884, 0.0998570460069459, 0.16353468963643536, 0.06470395223004743, 0.1867095273337327, 0.17429192725103348, 0.11485135313705541, 0.12473865266656503, 0.21467555168783292, 0.13967136153951287, 0.12713383039226755, 0.3084995975950733, 0.2220149914501235, 0.16211580717936158, 0.22407114127418026, 6.349989362061024, 80.88663965463638, 119.83401775360107, 101.11984714865685, 80.81767335534096, 90.27473509311676, 72.93355241417885, 49.426843374967575, 35.17741419374943, 81.45371362566948, 87.32603251934052, 70.3227961063385, 72.08916932344437, 11.939426735043526, 22.652096897363663, 93.59529331326485, 83.37264865636826, 11.055344324558973, 1.5917692612856627, 0.14987271570134908, 1.2429621093906462, 0.3071981674293056, 0.10713261654018424, 0.10335696992115118, 0.2452319534495473, 0.3773833403829485, 0.39071044244337827, 0.3242915798909962, 0.1920843092375435, 0.1664704774157144, 0.25912219716701657, 0.22030416294001043, 0.28315759962424636, 0.2932308294111863, 0.4482047416968271, 0.41836506163235754, 0.3524328104685992, 0.2354450590792112, 0.13973198016174138, 0.5182157177478075, 1.2867367104627192, 0.45318330579902977, 0.9976072562858462, 0.7336508575826883, 1.894187789876014, 2.0062320213764906, 0.7254228147212416, 1.0294573847204447, 1.2039834447205067, 0.6120748969260603, 0.9220055036712438, 1.171855099964887, 0.9877843083813787, 0.18533930007833987, 0.33744023996405303, 0.2843388612382114, 1.119629752356559, 1.521035225596279, 2.7373930625617504, 2.6158694084733725, 5.376472100615501, 3.245069570839405, 0.8321161614730954, 2.330401176586747, 2.354353666305542, 0.7568056276068091, 0.4317828838247806, 0.7036928494926542, 0.37752654519863427, 0.5825757735874504, 0.33264210680499673, 0.5695821333210915, 0.539208403788507, 0.3141694871010259, 0.4757399047957733, 0.12736106116790324, 0.2539532573428005, 0.2926780778216198, 0.39851845940575004, 0.41881201264914125, 0.1941527787130326, 0.24860590521711856, 0.4273948021000251, 1.7400187812745571, 0.3226101998006925, 2.221264145337045, 1.1116588488221169, 32.82589137554169, 49.18655186891556, 42.42214344441891, 35.30499614775181, 35.15701308846474, 87.26833641529083, 96.90297022461891, 59.702928364276886, 33.7976398319006, 46.401662304997444, 62.19875603914261, 55.84743104875088, 90.36292836070061, 90.622918009758, 44.14937876164913, 2.332730214111507, 0.2294988086214289, 0.4315857694018632, 0.16782844439148903, 0.2694200602127239, 0.18173744960222393, 0.15069985412992537, 0.16057733504567295, 0.1679486723151058, 0.27013323444407433, 0.1398782871547155, 0.13457602792186663, 0.15702492644777521, 0.12232679146109149, 0.11093279856140725, 0.12949304364155978, 0.09597409967682324, 0.19351629802258685, 0.11916333503904752, 0.11847360525280237, 0.12878832989372313, 0.2437092296895571, 0.12934753816807643, 0.1384155437699519, 0.14113183395238593, 0.15502421505516395, 0.2115850112750195, 0.0878677838773001, 0.1252829289296642, 0.16701988934073597, 0.13154297426808625, 0.11200136505067348, 0.07491782642318867, 0.12640383909456432, 0.12363470799755305, 0.12299332171096466, 0.11364652833435684, 0.09834206284722313], [0.024621530283184256, 0.02275341841595946, 0.07989306570379995, 0.029937083236291073, 0.03480720843072049, 0.05400594542152248, 0.030974794935900718, 0.030536942649632692, 0.008203244924516184, 0.039078186673577875, 0.08855107182171196, 0.058265828556614, 0.08018826236366294, 0.05184740148251876, 0.027462009602459148, 0.07166938667069189, 0.04669157540774904, 0.04869508840783965, 0.013673963330802508, 0.05754762627475429, 0.008393848856940167, 0.04837274398596492, 0.05746592323703226, 0.022100753340055235, 0.020817027107113972, 0.01523831786471419, 0.04069037633598782, 0.04515254666330293, 0.022549823188455775, 0.05291880668664817, 0.1282663774327375, 0.07046681057545356, 0.05976013548206538, 0.10930245596682653, 0.0067957247483718675, 3.850204199552536, 47.98733241856098, 84.0863947570324, 69.64550524950027, 63.484284058213234, 42.7804072201252, 35.14845214784145, 26.69418130069971, 39.197879657149315, 56.75965189933777, 63.499916419386864, 52.65783280134201, 27.688179463148117, 11.53373770415783, 55.636204183101654, 84.04259070754051, 19.105667397379875, 0.6765587429981679, 0.15615769720170647, 0.30129898397717625, 0.08428727014688775, 0.1965766033390537, 0.020718627602036577, 0.06247275945497677, 0.08101147483102977, 0.15223632246488705, 0.09333225432783365, 0.057849717486533336, 0.03527942957589403, 0.050023699732264504, 0.0061704954805463785, 0.06378157399012707, 0.0412403151858598, 0.10267602716339752, 0.13472255755914375, 0.22909723251359537, 0.5407165072392672, 1.7017796519212425, 1.8757594912312925, 1.4021204877644777, 4.402267076075077, 3.95790989510715, 2.932318327948451, 2.7737404871731997, 0.6356366607360542, 3.0000736797228456, 3.6656203167513013, 3.1557952612638474, 5.342636816203594, 3.6592214601114392, 0.1518473628675565, 0.9344362991396338, 2.011845982633531, 1.8721836456097662, 5.898558860644698, 9.257295057177544, 4.40099841915071, 7.981393821537495, 5.118493493646383, 13.181118406355381, 11.255723722279072, 5.880418634042144, 6.787547282874584, 2.510000914335251, 0.5479151615872979, 1.724555273540318, 1.8181595695205033, 1.0629009339027107, 1.0141740110702813, 1.2366894772276282, 0.18210494628874585, 0.4647616407601163, 0.3494111413601786, 0.24963998410385102, 0.3702874289592728, 0.11278552570729516, 0.1465861444012262, 0.22633326676441357, 0.11246598660363816, 0.02499405873095384, 0.17954038077732548, 0.035097132131340913, 0.06140515404695179, 0.0703825025993865, 0.1930151108535938, 0.17665860650595278, 1.055403936188668, 0.13949732790933922, 0.4129225661745295, 2.169650327414274, 23.382429108023643, 47.32047580182552, 48.578816279768944, 29.169611670076847, 30.44008109718561, 63.036531284451485, 68.69440868496895, 29.87078044563532, 21.998949944972992, 40.64194656908512, 41.09466567635536, 49.73311074078083, 69.11715880036354, 35.72566397488117, 1.7471027886494994, 0.15181294205831364, 0.032165400189114735, 0.026002338709076867, 0.0351310631231172, 0.03938706111512147, 0.011334328864904819, 0.08392295727389865, 0.022762032895116135, 0.08829615151626058, 0.028835862249252386, 0.08516488203895278, 0.03162369546771515, 0.08996769072837196, 0.01624130818527192, 0.04528453020611778, 0.05353160173399374, 0.032565673827775754, 0.04739198469906114, 0.028290062728046905, 0.017956713891180698, 0.03597968301619403, 0.052555722068063915, 0.01937467237439705, 0.035925762276747264, 0.0719715298328083, 0.008104979933705181, 0.04467581326025538, 0.021913169948675204, 0.03031622607522877, 0.05518145910173189, 0.017021149542415515, 0.051147430058335885, 0.041147687734337524, 0.02419088239548728, 0.06834385261754505, 0.026063155855808873, 0.06764575882698409, 0.07297925505554304, 0.03404988754482474, 0.038700726654496975, 0.007499780767830089, 0.07139533379813656, 0.02845455048372969, 0.021386640291893855, 0.05146596726262942, 0.035254604736110196, 0.01231270585776656, 0.008530861377948895, 0.014034612777322764, 0.04292405901651364, 0.016879391914699227, 0.057950185728259385, 0.039307966726482846, 0.026005218242062256, 0.02517871806048788, 0.05445590955787338, 0.0892635558557231, 0.012579680496855872, 0.04842953312618192, 0.020219978578097653, 0.04104173873201944, 0.05412447382695973, 0.023939442762639374, 0.06956929428270087, 0.02103278984577628, 0.11448271354311146, 0.024024030899454374, 0.10736641532275826, 0.03705207156599499, 0.07347310980549082, 0.0471091262443224, 16.464408226311207, 75.1825301349163, 98.64008501172066, 95.00206142663956, 95.80878853797913, 70.85152253508568, 43.9279380440712, 28.516943491995335, 18.72028637677431, 27.04383473843336, 76.94393321871758, 73.946243673563, 28.31128142774105, 6.216807458549738, 25.023076571524143, 50.33923901617527, 9.835273493081331, 0.5861984041985124, 0.05986899370327592, 0.5172346578910947, 0.007809464150341228, 0.15264291549101472, 0.04409677851072047, 0.24671932129422203, 0.043317501185811125, 0.1403698412468657, 0.22019088151864707, 0.06872723868582398, 0.14266373065765947, 0.2478795504430309, 0.0417998759803595, 0.17394255381077528, 0.34159831528086215, 0.756052911747247, 0.39921408926602453, 0.5109011102467775, 1.293699718080461, 4.877140894532204, 3.076597061008215, 5.436894558370113, 10.014571622014046, 13.884277325123549, 9.95607091113925, 5.163519652560353, 4.0628422144800425, 9.292770903557539, 9.826134033501148, 8.696326408535242, 11.100282613188028, 8.389015048742294, 6.322943838313222, 5.177705716341734, 8.588945120573044, 7.402345268055797, 10.024572685360909, 6.222350411117077, 10.207612663507462, 13.603799175471067, 10.505421683192253, 19.463946372270584, 19.333552569150925, 20.265716649591923, 14.054097812622786, 10.966068115085363, 5.685291979461908, 4.799350518733263, 6.29606313072145, 3.5179493157193065, 2.103403494693339, 2.4473707750439644, 0.22946084034629166, 0.6612132664304227, 0.1441438848269172, 0.2503118652384728, 0.254867019248195, 0.2536171831889078, 0.10454329298227094, 0.16084332077298313, 0.038302998582366854, 0.09275683012674563, 0.27710808673873544, 0.04833059741940815, 0.21101915335748345, 0.08311611658427864, 0.0522952987375902, 0.11523051638505422, 0.9876625367905945, 0.06794423577957787, 0.5107036989647895, 0.5423722683917731, 14.781468082219362, 36.827217265963554, 41.459997072815895, 34.22400735318661, 44.76651884615421, 62.38420508801937, 48.487526178359985, 21.83408059179783, 25.897364057600498, 63.721414133906364, 71.75543323159218, 71.04451417922974, 82.77855813503265, 58.10381457209587, 5.909510822966695, 0.17779084184439853, 0.05458129911858123, 0.08269735975773074, 0.04825014861125965, 0.09358183117001317, 0.03435947073739953, 0.04102031292859465, 0.009171456349577056, 0.08650848845718428, 0.03799025384068955, 0.04318705017794855, 0.033035631422535516, 0.06068600923754275, 0.008186834184016334, 0.006981875330893672, 0.046336335290106945, 0.02641114333528094, 0.02440916287014261, 0.07868064130889252, 0.05555210620514117, 0.05288598891638685, 0.012508536365203327, 0.07442260612151586, 0.03368245765159372, 0.04366492648841813, 0.023095114338502754, 0.06900382228195667, 0.02332763291633455, 0.0328601728688227, 0.008354165292985272, 0.049780483095673844, 0.08633573132101446, 0.02750749026745325, 0.07813998672645539, 0.01976901254238328, 0.041013570516952313, 0.19348435598658398, 0.12323141752858646, 0.13458172761602327, 0.11562618499738164, 0.1048994273878634, 0.13127566751791164, 0.1820093725109473, 0.2800996840232983, 0.11545224784640595, 0.19323992222780362, 0.17959561140742153, 0.0790058726852294, 0.25132258131634444, 0.12406428533722647, 0.17778015491785482, 0.18051784863928333, 0.22377150657121092, 0.11257215825025924, 0.07966871446114965, 0.19876216887496412, 0.26340970303863287, 0.1514633756596595, 0.13631508772959933, 0.128486082830932, 0.2225998483481817, 0.1582192350178957, 0.12310154168517329, 0.19282029708847404, 0.09436480439035222, 0.15467010671272874, 0.17386784922564402, 0.21110582136316225, 0.18028524471446872, 0.22955556807573885, 0.1322638223064132, 11.943004243075848, 85.15164479613304, 112.4396601319313, 92.76935443282127, 89.02567371726036, 59.49881471693516, 44.533549547195435, 39.95157301425934, 58.90601232647896, 79.56181794404984, 89.24822017550468, 75.86694940924644, 41.71745605766773, 18.290229253470898, 76.47200614213943, 122.59387046098709, 30.971824564039707, 0.8963251754175872, 0.42849448684137315, 0.9043291490525007, 0.30692939122673124, 0.2679272153181955, 0.2957571891602129, 0.44655705511104316, 0.29093777120579034, 0.29683083936106414, 0.3650482225930318, 0.30225353431887925, 0.21108360146172345, 0.2965343068353832, 0.24466737202601507, 0.2300668484531343, 0.2910239790799096, 0.36413131398148835, 0.3516398405190557, 0.4541290394263342, 0.9240173175930977, 3.9984879177063704, 3.968375721015036, 5.250133629888296, 8.963814955204725, 9.642688427120447, 8.626036830246449, 7.062821611762047, 2.6414624601602554, 7.711651520803571, 8.543363716453314, 8.127711620181799, 11.583669874817133, 7.539595328271389, 2.9002478113397956, 2.6899200724437833, 6.020085364580154, 6.286117639392614, 13.418557215481997, 20.517715327441692, 18.2724367082119, 20.99355049431324, 14.70081266015768, 25.45069232583046, 24.75652277469635, 16.115009374916553, 16.28373932093382, 7.49220997095108, 2.013630224391818, 4.253322193399072, 6.749808182939887, 2.961054048500955, 2.177393361926079, 3.654883517883718, 0.4438187676714733, 2.5725028105080128, 1.336273227352649, 0.3686038521118462, 1.0827256576158106, 0.577415709849447, 0.6603614590130746, 0.6342193961609155, 0.2932842343579978, 0.1470599017920904, 0.28241954860277474, 0.22911510342964903, 0.4767950309906155, 0.19156479102093726, 0.5444980761967599, 0.37977370899170637, 1.7242892878130078, 0.23612142278579995, 0.9603270411025733, 4.005609210580587, 35.72738528251648, 68.17312225699425, 66.47226512432098, 43.15832734107971, 46.66886776685715, 86.60808384418488, 95.78380107879639, 39.215639904141426, 29.85084481537342, 56.56581290066242, 56.67044788599014, 69.00340050458908, 92.79127165675163, 63.07715870440006, 4.495327407494187, 0.3971228061709553, 0.23737035342492163, 0.19224783405661583, 0.14636488049291074, 0.17500714980997145, 0.14706373127410188, 0.15363800193881616, 0.15056640113471076, 0.2765660814475268, 0.15273860801244155, 0.15391566907055676, 0.15754711639601737, 0.2651032543508336, 0.09000462741823867, 0.09806939036934637, 0.1463790109846741, 0.12464760598959401, 0.15931577305309474, 0.1538882838212885, 0.1519938331330195, 0.18337866466026753, 0.1290450239321217, 0.2389787507127039, 0.14320995134767145, 0.13285339926369488, 0.12181075391708873, 0.19491092709358782, 0.10190574466832913, 0.08502576645696536, 0.14117217710008845, 0.12294549029320478, 0.1776961438008584, 0.1630054641282186, 0.16961497196462005, 0.0862375451833941, 0.08520014147507027], [0.06360819344990887, 0.03723574569448829, 0.07303430757019669, 0.058637262336560525, 0.08354382371180691, 0.05919120507314801, 0.033035527521860786, 0.0647896777081769, 0.01899679675261723, 0.047578931698808447, 0.034764475567499176, 0.11018397897714749, 0.022193829790921882, 0.0170728753801086, 0.019666972802951932, 0.04113034003239591, 0.07056052898406051, 0.04513870931987185, 0.025342868138977792, 0.004757996421176358, 0.08046074930462055, 0.016724039996915963, 0.012842569612985244, 0.07990901445737109, 0.03842694095510524, 0.04461924676434137, 0.09597577693057247, 0.06750926302629523, 0.005072132689747377, 0.034913487688754685, 0.07499515078961849, 0.07232030955492519, 0.10006047610659152, 0.10142945655388758, 10.019995830953121, 61.34939521551132, 78.67316722869873, 71.0603441298008, 57.34701298177242, 54.99139778316021, 27.53411293029785, 50.15047274529934, 50.8134725689888, 64.0908645093441, 63.33570443093777, 40.10873258113861, 20.957365036010742, 31.761218905448914, 73.86068746447563, 45.51520027220249, 2.488771453499794, 0.2848895051283762, 0.06309590375167318, 0.24600904143881053, 0.11435851512942463, 0.08359646424651146, 0.34506942902226, 0.10848881720448844, 0.1295818787184544, 0.04255450658092741, 0.06036362028680742, 0.0764552150212694, 0.16863901808392256, 0.15637186617823318, 0.11537697180756368, 0.11338745200191624, 0.15404423873405904, 0.10293085098965093, 0.7255510578397661, 0.33874110609758645, 1.7809590906836092, 4.834741344675422, 6.81158859282732, 7.989106457680464, 3.9248032215982676, 3.297662786208093, 8.76984391361475, 5.7149940356612206, 5.335240988060832, 4.111614972352982, 5.238658720627427, 6.5104481019079685, 8.23844812810421, 10.269404947757721, 10.923503749072552, 10.771658197045326, 5.256804646924138, 10.030609611421824, 11.09813667833805, 24.763335809111595, 19.925898984074593, 20.109613426029682, 14.978953935205936, 5.42229431681335, 7.4832396022975445, 11.70803340151906, 2.2468284610658884, 5.188796846196055, 1.8588011199608445, 2.021507676690817, 3.3275902178138494, 1.9813293451443315, 0.7234880060423166, 0.5286314932163805, 0.6923486769665033, 0.044606218361877836, 0.5872387764975429, 0.3572208504192531, 0.023177281218522694, 0.16832862223964185, 0.09249678900232539, 0.3410465730121359, 0.24937287031207234, 0.10017030654125847, 0.11400206902180798, 0.07930073537863791, 0.032746887736720964, 0.07198422055807896, 0.1369502770830877, 0.3613916609901935, 0.09218210354447365, 0.2848599379649386, 0.17989754676818848, 0.6780223769601434, 0.11426053679315373, 0.10678517268388532, 8.125579934567213, 57.38338463008404, 103.05512130260468, 56.80454649031162, 32.62299366295338, 46.12936891615391, 57.33242556452751, 46.46436654031277, 21.431007720530033, 25.05983579903841, 43.544667810201645, 53.10617074370384, 66.74366936087608, 41.07344761490822, 5.701044509187341, 0.14789667329750955, 0.04577652216539718, 0.07323521436774172, 0.012320409350650152, 0.010063767404062673, 0.038425686725531705, 0.031182741004158743, 0.06287830605288036, 0.08174439761205576, 0.021421344972623046, 0.03213516880350653, 0.08479455776978284, 0.02411902209132677, 0.05404071504017338, 0.05955267923127394, 0.027381664694985375, 0.05627906954032369, 0.05174271784198936, 0.033871156119857915, 0.07705300013185479, 0.03774228003749158, 0.03252910450100899, 0.06626447357120924, 0.04095990952919237, 0.04388951892906334, 0.04286933304683771, 0.07118598878150806, 0.08324574751895852, 0.018054792417387944, 0.01701654266071273, 0.0443355756578967, 0.029344315043999813, 0.034656188799999654, 0.03898627168382518, 0.08411949282162823, 0.027482858386065345, 0.045106641118763946, 0.04488743295951281, 0.014993292243161704, 0.041938197464332916, 0.04724775571958162, 0.016692819699528627, 0.0357879602961475, 0.0415117853845004, 0.04504232289036736, 0.005340929301382857, 0.0435990905680228, 0.02487525016476866, 0.0422772847377928, 0.014672093511762796, 0.024952542989922222, 0.09531644551316276, 0.07909487845608965, 0.07502833221224137, 0.04180971685855184, 0.03251091817219276, 0.048042514245025814, 0.11390961226425134, 0.04844432041863911, 0.02474591052305186, 0.05843759121489711, 0.014926497096894309, 0.01443159591872245, 0.03108480534137925, 0.04640138824470341, 0.014314787440525834, 0.024869752705853898, 0.17937578726559877, 0.1766392809804529, 22.00265284627676, 87.29657649993896, 94.55194517970085, 99.27659645676613, 91.83171674609184, 82.62746304273605, 36.38765685260296, 36.18765838444233, 23.804580755531788, 49.50269490480423, 79.72932815551758, 55.05487337708473, 18.332655876874924, 17.301155626773834, 41.80505655705929, 25.543376952409744, 0.6686350400559604, 0.2721500355983153, 0.2743870171252638, 0.08539969014236704, 0.1474084737128578, 0.035231928413850255, 0.3282024903455749, 0.03469536306511145, 0.211697906779591, 0.09484119640546851, 0.015453403393621556, 0.38168666884303093, 0.1782562574953772, 0.1938309834804386, 0.2427293424261734, 0.3285619569942355, 0.1419094711309299, 0.18933349434519187, 0.9299212507903576, 1.1271928902715445, 0.5147313640918583, 0.9995844564400613, 1.6658376180566847, 2.180712246336043, 3.080284050665796, 2.729342244565487, 11.024726517498493, 8.904524836689234, 11.279007922858, 10.738411881029606, 13.92613397911191, 13.04602425545454, 13.350087739527225, 9.311861079186201, 12.863357607275248, 14.757690858095884, 7.35832130536437, 8.806212712079287, 16.35806143283844, 24.510915353894234, 23.447599411010742, 20.775502994656563, 15.539648998528719, 16.446169205009937, 18.191755637526512, 19.039357155561447, 5.828604139387608, 4.0089060086756945, 5.357254631817341, 3.932378590106964, 3.168186158873141, 3.093698755837977, 2.016732282936573, 0.34241553861647844, 1.592327356338501, 0.6427868676837534, 1.8037084699608386, 1.6804405907168984, 0.5417219095397741, 0.8417294081300497, 0.6691928382497281, 0.6983263499569148, 0.6597995641641319, 0.5567373975645751, 0.2272768333205022, 0.21800536051159725, 0.02423942813038593, 0.09306683263275772, 0.24092812032904476, 0.5067278060596436, 0.028644345475186128, 0.211112916294951, 0.06959872785955667, 0.8921841101255268, 0.025387291243532673, 0.09479568048845977, 2.7240325044840574, 42.201519683003426, 81.19264483451843, 50.21854989230633, 42.77550168335438, 52.06882260739803, 32.95350752770901, 21.336672082543373, 17.131872810423374, 33.46749074757099, 68.48963007330894, 79.53008204698563, 84.69630762934685, 61.4224348962307, 16.304469108581543, 0.22248106019105762, 0.062015377552597784, 0.06097914643760305, 0.01185883524158271, 0.06637197366217151, 0.049123875360237435, 0.02365613530855626, 0.09828839814872481, 0.07434119994286448, 0.025565768482920248, 0.034360275967628695, 0.04646973633498419, 0.04519352805800736, 0.09149152028840035, 0.03636240857304074, 0.021648273323080502, 0.04583815381920431, 0.029183517617639154, 0.05268031753075775, 0.06282925009145401, 0.033934732200577855, 0.030130062041280326, 0.04067109905008692, 0.10472026551724412, 0.030419982031162363, 0.03848763008136302, 0.01772067011188483, 0.06157446390716359, 0.009416744505870156, 0.040265604402520694, 0.0548948045616271, 0.011151526759931585, 0.0331056159484433, 0.023771164487698115, 0.05102258226543199, 0.17256821505725384, 0.20912599400617182, 0.17622637969907373, 0.11504050431540236, 0.0972238318354357, 0.11431521823396906, 0.126516823656857, 0.23226767254527658, 0.16318534588208422, 0.09650308769778349, 0.1305623448570259, 0.3377975395414978, 0.15258848638040945, 0.08846819619066082, 0.15119767194846645, 0.13190803671022877, 0.24343145865714177, 0.13366544240852818, 0.17062433733372018, 0.12118015103624202, 0.11102040167315863, 0.11719927832018584, 0.1590777514502406, 0.17865259404061362, 0.142197736131493, 0.15138433693209663, 0.24796210695058107, 0.16488366178236902, 0.1681527035543695, 0.17219810601091012, 0.10626581031829119, 0.09117443769355305, 0.21830998244695365, 0.21204180316999555, 19.84583158046007, 105.47384351491928, 109.71263006329536, 95.90582773089409, 83.77219721674919, 69.92662936449051, 40.00063598155975, 68.65323409438133, 72.02175334095955, 98.8025338947773, 97.08908423781395, 56.240789741277695, 31.10703270882368, 42.569180354475975, 106.5145468711853, 71.17668628692627, 3.785528582520783, 0.5132497404702008, 0.30016691191121936, 0.5489929381292313, 0.28114596381783485, 0.32010242342948914, 0.7217459182720631, 0.3312654822366312, 0.40004461188800633, 0.2060317131690681, 0.16753888805396855, 0.287130672368221, 0.36339768616016954, 0.3146826080046594, 0.4161467822268605, 0.589874469442293, 0.9651018411386758, 0.24120198766468093, 2.1487877843901515, 6.045685540884733, 7.103520277887583, 9.992015082389116, 17.32550662010908, 19.327771179378033, 9.275775365531445, 10.577454417943954, 19.382568039000034, 14.399627521634102, 16.803120151162148, 16.19821161031723, 18.183781765401363, 14.347203634679317, 19.123904518783092, 18.10652621090412, 20.845092460513115, 22.864539697766304, 16.315266229212284, 18.576190508902073, 25.15144508332014, 47.72565945982933, 39.362239837646484, 36.89633555710316, 26.494826897978783, 20.935172326862812, 16.87831051647663, 22.23397683352232, 11.09311144798994, 13.16153235733509, 8.522824868559837, 4.93291050195694, 4.82947482727468, 4.034304320812225, 3.510227892547846, 2.365410360507667, 1.563625002745539, 0.31469371053390205, 1.4237894187681377, 0.8366684359498322, 0.19709251471795142, 1.1657291161827743, 0.7178392529021949, 0.4829233599593863, 0.5108552752062678, 0.5359663465060294, 0.40548087330535054, 0.6575012218672782, 0.18868122075218707, 0.18992623285157606, 0.47757200023625046, 0.6959648954216391, 0.17287898197537288, 0.6502947898115963, 0.4827556642703712, 1.5694878506474197, 0.1272215522476472, 0.24279153440147638, 9.943576231598854, 74.68566879630089, 129.9311399459839, 77.63062477111816, 50.53188867866993, 67.65890344977379, 82.38737672567368, 64.07194152474403, 29.584311917424202, 34.630631133913994, 60.578633174300194, 74.40719693899155, 89.04104009270668, 67.13759422302246, 12.524274252355099, 0.1711901804083027, 0.1783625181997195, 0.1563675023498945, 0.20143050147453323, 0.2225474824081175, 0.14552288426784799, 0.09375904861371964, 0.2011485892580822, 0.13493910140823573, 0.16966986120678484, 0.11740324276615866, 0.11064638893003576, 0.11259782913839445, 0.16652170044835657, 0.10149374138563871, 0.08120908649289049, 0.1664534377050586, 0.10827588019310497, 0.2333917294163257, 0.14612285129260272, 0.10276313303620555, 0.18602405005367473, 0.15122177690500394, 0.2099830558290705, 0.12057644358719699, 0.16999278450384736, 0.2507309115026146, 0.1111209329974372, 0.11880184232722968, 0.10099026840180159, 0.1561479750671424, 0.09986092743929476, 0.0958812866883818, 0.13314703741343692, 0.11524872126756236], [0.040673110270290636, 0.05194068202399649, 0.04915269666526001, 0.07823670341167599, 0.019688363354362082, 0.06565320363733917, 0.029517450675484724, 0.03962873779528309, 0.0663279346190393, 0.05147149997355882, 0.012072564495611005, 0.034462202529539354, 0.019620352941274177, 0.058708482538349926, 0.050960924636456184, 0.01805333038646495, 0.05261046659143176, 0.015479424018849386, 0.039935782842803746, 0.10688942958950065, 0.023325135589402635, 0.00927092083657044, 0.05756364182161633, 0.1259796423255466, 0.03724277012224775, 0.029418290469038766, 0.011792356435762485, 0.0939280133752618, 0.06906167269335128, 0.07382687675999478, 0.04211621642753016, 0.20959025190677494, 0.39434660982806236, 16.224206015467644, 55.69983556866646, 62.850329875946045, 59.980978444218636, 53.59139710664749, 43.15896950662136, 28.846283219754696, 46.53819277882576, 71.7924052476883, 89.33653503656387, 67.27356612682343, 31.321859881281853, 47.76132054626942, 71.37587159872055, 43.57659749686718, 8.591810166835785, 0.34002416068688035, 0.04488072394451592, 0.10268750076647848, 0.018374587561993394, 0.01171170910311048, 0.17706822749460116, 0.03548409164068289, 0.14217757940059528, 0.06637621132540517, 0.13798765110550448, 0.09512317541521043, 0.10570923666818999, 0.09176652310998179, 0.0883819289447274, 0.1692715208628215, 0.23247952602105215, 0.08808472848613746, 0.5817825661506504, 0.9657873481046408, 2.204777542501688, 1.3477668981067836, 1.7977729509584606, 2.1269420441240072, 4.6079604886472225, 3.7539515644311905, 4.550152290612459, 10.93381829559803, 26.367205046117306, 15.983283743262291, 6.429185187444091, 7.739758137613535, 8.516057431697845, 11.151522863656282, 9.537761807441711, 10.55990505963564, 33.145169243216515, 20.797853395342827, 15.006866287440062, 18.135752342641354, 16.80841326713562, 24.55804992467165, 10.112858098000288, 28.676358237862587, 13.800634313374758, 14.581885691732168, 16.238863728940487, 12.467607893049717, 20.884085968136787, 8.598739095032215, 17.421381175518036, 15.577524416148663, 9.085895754396915, 9.529127720743418, 5.062714386731386, 1.9500052509829402, 2.0360772823914886, 0.18617972295032814, 0.2541676489636302, 0.37854910595342517, 0.21111261943588033, 0.05263320228550583, 0.08002001006389037, 0.25207437691278756, 0.10305681571480818, 0.12697659898549318, 0.06121892321971245, 0.08671365518239327, 0.13013997377129272, 0.006901429769641254, 0.06862993570393883, 0.04385800733871292, 0.22975937667069957, 0.5006429075729102, 0.006887312265462242, 0.11287615678156726, 0.37198148493189365, 0.025549482052156236, 0.1996071930625476, 0.05687306969775818, 17.26842038333416, 94.73659247159958, 97.5357274711132, 62.71901272237301, 62.89387933909893, 68.79594683647156, 62.092696130275726, 43.32146018743515, 22.32176922261715, 35.25192439556122, 43.08260880410671, 64.61491718888283, 60.39353750646114, 19.01330955326557, 0.11846919689560309, 0.03928504178475123, 0.07201154643553309, 0.061010413119220175, 0.031535394737147726, 0.014272923817770788, 0.045348481071414426, 0.09199837746564299, 0.07117152432329021, 0.08280425128759816, 0.06794428030843846, 0.039824074774514884, 0.009854286945483182, 0.059878411557292566, 0.02653158091561636, 0.011227127488382393, 0.06606997150811367, 0.05112433813337702, 0.09030183529830538, 0.035167480309610255, 0.0407723354146583, 0.025872145597531926, 0.03127280062471982, 0.04806611454114318, 0.01665744337515207, 0.008499414725520182, 0.014942712095944444, 0.07292270340258256, 0.05340132884157356, 0.0483416962379124, 0.020386457144923043, 0.04468332750548143, 0.01949375739059178, 0.023790044724592008, 0.08285714415251277, 0.03589984647987876, 0.059151926907361485, 0.04947402805555612, 0.034722176860668696, 0.05391201179008931, 0.0714770813647192, 0.05672669220075477, 0.04689353605499491, 0.053294003155315295, 0.027606969597400166, 0.04747080820379779, 0.02863235422410071, 0.017377968579239678, 0.006488571161753498, 0.04023345827590674, 0.06576336061698385, 0.006026266037224559, 0.0590912823099643, 0.07173636549850926, 0.05403468880103901, 0.04852124031458516, 0.012338135547906859, 0.11152674676850438, 0.015715218250988983, 0.023803145486454014, 0.05634482753521297, 0.061592119600391015, 0.0964406508137472, 0.06896556456922553, 0.009264142245228868, 0.2043212705757469, 0.7087729987688363, 38.46106119453907, 82.02422261238098, 80.61905801296234, 92.64847531914711, 81.09556764364243, 52.461816519498825, 24.63017575442791, 16.054271534085274, 48.58561031520367, 77.51061961054802, 77.73988410830498, 44.26321305334568, 28.28074436634779, 49.532447308301926, 30.677203573286533, 3.844268680550158, 0.10974928823998198, 0.15536570688709617, 0.13432497420581058, 0.03715570506756194, 0.020469145383685827, 0.011978423990512965, 0.14451365248532966, 0.41782495623920113, 0.18750709859887138, 0.3463925002142787, 0.43311091256327927, 0.31486532476264983, 0.3121202392503619, 0.031736390592413954, 0.1349661304266192, 0.31762780621647835, 0.11231916010729037, 0.2229070381144993, 0.26762860477901995, 0.15534930542344227, 1.050318859051913, 0.9436291339807212, 1.5067014447413385, 1.2848774227313697, 1.9313195161521435, 3.207472013309598, 1.8743992829695344, 4.6534977201372385, 7.768462272360921, 5.793730560690165, 11.029712799936533, 12.056864183396101, 18.218935579061508, 16.542712524533272, 20.837994441390038, 35.24269089102745, 18.27948722988367, 17.249364405870438, 21.04263436049223, 20.37250231951475, 24.67561561614275, 17.8501957654953, 34.338681399822235, 23.73702798038721, 17.219577804207802, 17.67279278486967, 11.660559698939323, 8.280937448143959, 1.4014535048045218, 1.9151579146273434, 3.4443144919350743, 2.7934051444754004, 2.5573803344741464, 0.8648368588183075, 0.8699498407077044, 0.5222945020068437, 1.6704956931062043, 1.6291129449382424, 0.6695490097627044, 0.6678177870344371, 0.31703245535027236, 0.7851011655293405, 1.2153782020322978, 1.1988279526121914, 0.39979020366445184, 0.2321775906602852, 0.4107190703507513, 0.2569602319272235, 0.38220361922867596, 0.1554040313931182, 0.04490176012041047, 0.20907882309984416, 0.7498240959830582, 0.16931165620917454, 0.06955487435334362, 0.1942186220549047, 0.17298374354140833, 0.09649467916460708, 0.04612014767189976, 9.369024261832237, 63.80920082330704, 78.7842808663845, 71.99472159147263, 66.95959657430649, 56.51648014783859, 31.045439913868904, 19.749417454004288, 21.924150958657265, 60.93304015696049, 65.83048716187477, 82.75868520140648, 78.35547387599945, 36.28232270479202, 0.6764464115258306, 0.09456450148718432, 0.06492876360425726, 0.11522374057676643, 0.04536328691756353, 0.04122163161810022, 0.039109078570618294, 0.07612319299369119, 0.041358717426192015, 0.04472054250072688, 0.040523111092625186, 0.06890042626764625, 0.014311121231003199, 0.04731703520519659, 0.027507013437571004, 0.007986226100911153, 0.06710960908094421, 0.02609617957205046, 0.07637083283043467, 0.02620314717205474, 0.0838551546621602, 0.00842699966597138, 0.03255417053878773, 0.012981435647816397, 0.045688585087191314, 0.05347031146811787, 0.09392912659677677, 0.08807824211544357, 0.03816754920990206, 0.033959289867198095, 0.02891574888053583, 0.04955019096087199, 0.024494322460668627, 0.02439013791445177, 0.1686413781135343, 0.07967016907059588, 0.14369859622092918, 0.15839267492992803, 0.11033079805201851, 0.20462590735405684, 0.17380314879119396, 0.14335000945720822, 0.17387322237482294, 0.13229037635028362, 0.11043569320463575, 0.13488790806150064, 0.11047929438063875, 0.1638931321213022, 0.10075078476802446, 0.13219640561146662, 0.15043248800793663, 0.14073239522986114, 0.13190923898946494, 0.23312247823923826, 0.17367097228998318, 0.15818006446352229, 0.12224428690387867, 0.2333798402105458, 0.17288821429247037, 0.176173776271753, 0.13587955094408244, 0.26639061339665204, 0.3121227031806484, 0.21446181315695867, 0.150180721830111, 0.3545272402698174, 0.515492451377213, 39.979524314403534, 98.99956852197647, 89.38136503100395, 83.83839726448059, 76.68535709381104, 59.49566088616848, 42.67985701560974, 67.45594874024391, 99.54081147909164, 129.8378473520279, 89.1405263543129, 41.11409783363342, 62.647105380892754, 97.68645018339157, 64.79723140597343, 15.271025262773037, 0.41343705262988806, 0.29923985071945935, 0.22273750189924613, 0.11620366494753398, 0.07329095707973465, 0.39322350290603936, 0.25844025250989944, 0.36271161516197026, 0.19385192688787356, 0.29872218787204474, 0.2575779362814501, 0.27077065024059266, 0.3870456281583756, 0.3565144445747137, 0.5459499545395374, 0.8260565553791821, 0.38780635921284556, 2.9023322369903326, 3.237466891296208, 8.350351173430681, 6.525259707123041, 8.864641226828098, 9.939496200531721, 14.029828514903784, 13.008697908371687, 22.217369824647903, 30.014752820134163, 43.68661679327488, 27.876702547073364, 15.702581405639648, 22.053805701434612, 19.692167825996876, 26.08099490404129, 22.691268995404243, 24.899493902921677, 50.18897607922554, 37.40261659026146, 31.33158925920725, 31.231001056730747, 31.986474618315697, 40.96497483551502, 22.874778248369694, 43.736040741205215, 27.877515703439713, 26.59892611205578, 27.78586272150278, 18.795503340661526, 48.08592952787876, 16.688075624406338, 32.444627434015274, 31.627619974315166, 18.049168288707733, 23.40851280838251, 10.497935134917498, 6.53014007024467, 5.85693446919322, 1.6904575657099485, 1.4688952546566725, 0.5596127745229751, 0.3031194128561765, 0.15452982595888898, 0.3632701258175075, 0.5108064715750515, 0.4014224832644686, 0.3567854769062251, 0.35519647935871035, 0.44243255455512553, 0.2329275308875367, 0.29329201206564903, 0.18636910419445485, 0.2405582636129111, 0.43000968522392213, 1.1043945886194706, 0.29810160398483276, 0.19674248818773776, 0.6558378017507493, 0.3332201804732904, 0.2817715349374339, 0.19360495498403907, 19.878557324409485, 115.65238013863564, 117.15538188815117, 84.63777557015419, 85.148004591465, 96.52833312749863, 85.90771302580833, 57.50786975026131, 32.62964330613613, 48.47454607486725, 62.5165443867445, 85.66215500235558, 90.26832863688469, 34.56128865480423, 0.3011068271007389, 0.17056104697985575, 0.09939018316799775, 0.18717841623583809, 0.19394907401874661, 0.11934516864130273, 0.10916508443187922, 0.19085224019363523, 0.17717638809699565, 0.166597607312724, 0.14646664378233254, 0.12362149034743197, 0.08862099697580561, 0.2705271070590243, 0.1523535224259831, 0.04898598803265486, 0.17785417672712356, 0.10668527960660867, 0.15606662083882838, 0.12563884811243042, 0.14473787014139816, 0.11782986635807902, 0.0991900556255132, 0.14766620675800368, 0.08196583963581361, 0.10760590637801215, 0.1765323375002481, 0.2341886327485554, 0.10773006026283838, 0.11895732226548716, 0.11209152115043253, 0.11373505170922726, 0.1429839970660396, 0.12361662185867317], [0.008995150819828268, 0.013501865778380306, 0.003894829969794955, 0.018752426076389384, 0.04291876008210238, 0.0411998792696977, 0.01965592964552343, 0.02014739282458322, 0.039794388867449015, 0.09096329667954706, 0.05969344980258029, 0.04508405756496359, 0.02719143740250729, 0.06404295098036528, 0.04934482385579031, 0.0779240662814118, 0.026806891728483606, 0.06566674041096121, 0.09795708858291619, 0.04087081098987255, 0.05843717932293657, 0.04269565564754885, 0.03846568477456458, 0.06481854725279845, 0.07248738926136866, 0.021553014958044514, 0.04400232166517526, 0.04996193449187558, 0.07504255176172592, 0.012971771029697265, 0.07591334331664257, 1.1867220397107303, 23.312685750424862, 64.03534948825836, 74.73413899540901, 75.13465270400047, 54.989182502031326, 43.22402581572533, 43.60650189220905, 51.514344960451126, 75.90873196721077, 49.07071888446808, 101.88613682985306, 87.93814167380333, 54.08513881266117, 80.60562193393707, 24.312444403767586, 0.5816825840156525, 0.04837004256842192, 0.20981820998713374, 0.09342750898213126, 0.028077268580091186, 0.17023674328811467, 0.038034296594560146, 0.10311425052350387, 0.09031998080899939, 0.3631728154141456, 0.10812040767632425, 0.19552091311197728, 0.17609843343961984, 0.1939919701544568, 0.5047756608109921, 0.3352460655150935, 0.5129589966963977, 0.605218046111986, 0.957914408063516, 0.2785234514158219, 0.4242599703138694, 0.6103120883926749, 2.2330731991678476, 3.9991144090890884, 5.166921420022845, 4.338206788524985, 3.7517198966816068, 2.0530920568853617, 0.7277545239776373, 5.240333955734968, 4.853030238300562, 6.966411285102367, 5.8643497712910175, 14.011701587587595, 17.112345658242702, 25.881957784295082, 25.206863209605217, 23.700785525143147, 28.41771751642227, 19.66995231807232, 15.40092034265399, 18.330111913383007, 19.326515346765518, 21.232439875602722, 24.012611992657185, 16.362419798970222, 20.053809620440006, 17.291312254965305, 6.833183309063315, 3.8278526114299893, 1.0165142104960978, 1.3817328005097806, 2.7480792766436934, 0.923938115593046, 2.5103383837267756, 1.1139218648895621, 0.5511893983930349, 2.08039287943393, 3.6065923841670156, 4.739103801548481, 6.4751161728054285, 3.891381877474487, 0.7923346117604524, 0.2653388713952154, 1.021662934217602, 0.7598750910256058, 0.3724586562020704, 0.4452054260764271, 0.026678732101572677, 0.11042441998142749, 0.04433006892213598, 0.06351303527480923, 0.25009414879605174, 0.03025549613084877, 0.06634793549892493, 0.17129520914750174, 0.2310483090695925, 0.04795592787559144, 0.09056538678123616, 0.21764161909231916, 0.18517166376113892, 0.2430561842629686, 1.7624967126175761, 46.39864146709442, 117.09798216819763, 108.20066839456558, 72.64644742012024, 56.709885969758034, 56.58698156476021, 39.06078301370144, 25.55446855723858, 30.075306370854378, 42.243066653609276, 60.89379206299782, 66.0884553194046, 29.369847625494003, 0.2963303349679336, 0.031244806814356707, 0.03344995762745384, 0.015635971722076647, 0.044431936112232506, 0.01423828685801709, 0.012087004834029358, 0.040918482845881954, 0.006197816719577531, 0.05815016484120861, 0.04618108541762922, 0.03312445907795336, 0.027518557544681244, 0.03654255378933158, 0.09442483671591617, 0.024261360449600033, 0.04366328634205274, 0.02765682336757891, 0.015456969413207844, 0.08126062122755684, 0.0663152735796757, 0.025012900005094707, 0.04288876989448909, 0.056864924627006985, 0.05201035484788008, 0.014890223701513605, 0.07786797476001084, 0.0369185258023208, 0.03063459815166425, 0.043770255797426216, 0.042475341688259505, 0.07542815685155801, 0.09763394264155068, 0.022639044182142243, 0.03485004519461654, 0.044757824289263226, 0.02021177042479394, 0.0256729420289048, 0.066700745082926, 0.042143623941228725, 0.04997339696274139, 0.04751131091325078, 0.012447623666957952, 0.013570021837949753, 0.042165483901044354, 0.09051476488821208, 0.03611702486523427, 0.08055252328631468, 0.023359689985227305, 0.026837184341275133, 0.01292060551350005, 0.07211341362562962, 0.06928200149559416, 0.03753262702957727, 0.0454585267289076, 0.01442728032998275, 0.0917411119735334, 0.04452895336726215, 0.07290261346497573, 0.02752502536168322, 0.07394058862701058, 0.0603362684341846, 0.032724946140660904, 0.03422432564548217, 3.7172828195616603, 45.07199205458164, 92.38190442323685, 100.2064597606659, 114.34666380286217, 83.23892623186111, 48.79091329872608, 28.905383348464966, 32.977412045001984, 67.30397209525108, 51.986321434378624, 112.63082787394524, 94.98539552092552, 40.46565122902393, 52.69118741154671, 15.510821845382452, 0.3485899401130155, 0.08950540694058873, 0.24761021020822227, 0.028050209875800647, 0.10964874207274988, 0.2515109087107703, 0.3734888165490702, 0.4302819346776232, 0.8935396280139685, 1.4755889517255127, 0.6452899239957333, 0.673830786254257, 0.28578408993780613, 0.5591399967670441, 0.6959195947274566, 0.22285346989519894, 0.22424633265472949, 0.6857636303175241, 0.5703919648658484, 0.4268158972263336, 1.5673611522652209, 2.815719684585929, 4.495004899799824, 8.008793201297522, 10.296194460242987, 9.265405721962452, 7.307419711723924, 5.32581084407866, 2.875773087143898, 1.387494478840381, 0.7193535903934389, 3.0793374264612794, 2.7263287687674165, 3.3958523673936725, 10.626673176884651, 26.43069013953209, 30.264625512063503, 28.18865440785885, 32.5092201679945, 23.066244274377823, 19.227376766502857, 20.364779233932495, 20.621483959257603, 24.832376204431057, 31.248314827680588, 20.295497551560402, 14.584599696099758, 3.5832765977829695, 2.399235195480287, 1.2556534283794463, 0.3657743992516771, 1.7832596297375858, 2.5139135168865323, 1.9652205845341086, 2.6279071625322104, 0.980319787049666, 0.6240358832292259, 1.7621567496098578, 3.3288633869960904, 2.534200153313577, 1.2529374053701758, 0.28168844408355653, 1.7234065476804972, 1.3065088307484984, 1.1908805603161454, 1.3720665941946208, 1.4581653429195285, 2.3694348195567727, 1.3865660224109888, 0.6521996750961989, 0.5429652146995068, 0.7389567384961993, 0.6361977243795991, 0.14081659930525348, 0.06955163116799667, 0.08306216244818643, 0.35316902096383274, 0.044768552033929154, 0.035368858370929956, 0.15659348631743342, 0.3061815438559279, 0.1740239970968105, 0.23903902794700116, 24.456908851861954, 92.77090474963188, 113.08486551046371, 88.98123890161514, 65.24425461888313, 41.62178859114647, 16.85300387442112, 21.41406062990427, 52.044059336185455, 63.08063551783562, 78.26386839151382, 83.20025190711021, 49.953118935227394, 2.0359599636867642, 0.04225741373375058, 0.02402386577159632, 0.03030554471479263, 0.11098159477114677, 0.04960650512657594, 0.03202192448952701, 0.024152598707587458, 0.05482972934260033, 0.05330176602001302, 0.05556094889470842, 0.02233797527878778, 0.03926033568859566, 0.0444154270371655, 0.06333726501907222, 0.05136672727530822, 0.033360291345161386, 0.05500975210452452, 0.022622909891651943, 0.023837031949369702, 0.042802502648555674, 0.02550497174524935, 0.01585435980814509, 0.03414062623050995, 0.04579165826726239, 0.04452249668247532, 0.048313780353055336, 0.03361446950293612, 0.04876402279478498, 0.06441579113015905, 0.07661134062800556, 0.04013536490674596, 0.06275109451962635, 0.18061478796880692, 0.2340454130899161, 0.17597571189980954, 0.13394106121268123, 0.12404005421558395, 0.16682743560522795, 0.14072236139327288, 0.221408597426489, 0.13876096898457035, 0.12336086292634718, 0.21026910922955722, 0.12608297896804288, 0.23377372766844928, 0.1566092495340854, 0.19663146289531142, 0.14657450752565637, 0.09582561076967977, 0.11527372422278859, 0.22650198661722243, 0.12872739956947044, 0.15041175240185112, 0.1664811494993046, 0.17384055303409696, 0.19786265620496124, 0.14261031086789444, 0.08818307047476992, 0.1404979804647155, 0.11178046479471959, 0.12773210532031953, 0.17336596443783492, 0.14774527517147362, 3.4781208029016852, 47.579773887991905, 110.42308554053307, 103.58059510588646, 108.10672983527184, 74.53790232539177, 58.290148973464966, 64.9235138297081, 77.93101385235786, 119.21454459428787, 71.90830662846565, 107.00730443000793, 105.15445545315742, 72.4870839715004, 114.5201624929905, 38.367973789572716, 0.8127534098457545, 0.19731069129193202, 0.4504186275880784, 0.3217222646344453, 0.21689754183171317, 0.5414748634211719, 0.20846549741690978, 0.40361437189858407, 0.27995796350296587, 0.8082787343300879, 0.3003383183386177, 0.5798539915122092, 0.3140994580462575, 0.7827775308396667, 2.828219113871455, 1.5668355929665267, 1.5200213924981654, 1.4234561054036021, 2.5685068499296904, 1.6912003071047366, 2.099396134726703, 1.933217158075422, 2.599905040115118, 4.3732846062630415, 6.149125015363097, 5.995313543826342, 4.895355217158794, 3.8878863025456667, 3.2943588634952903, 11.802621725946665, 11.83883948251605, 18.1361361220479, 15.49077982082963, 25.57868655771017, 31.62409946322441, 42.2921372205019, 42.40709625184536, 33.96967940032482, 46.404192969202995, 33.610879853367805, 30.39174199104309, 33.60649108886719, 35.976773500442505, 38.659760132431984, 40.26266232132912, 31.447545737028122, 33.988625183701515, 25.571683533489704, 14.198604058474302, 9.709090813994408, 3.6593784391880035, 5.401935484260321, 5.62630251981318, 2.972557693719864, 5.653643477708101, 4.728764081373811, 2.451700405217707, 6.548235174268484, 10.87173342704773, 12.58127024397254, 15.485910382121801, 9.567153230309486, 4.481265312060714, 1.0115745943039656, 0.91623414773494, 1.141848110128194, 1.1115148128010333, 1.354933907277882, 0.5719046993181109, 0.3741124283988029, 0.4334311938146129, 0.5163661076221615, 0.9344772656913847, 0.20538837503409013, 0.2486302625038661, 0.3908448602305725, 0.705093014985323, 0.104221082146978, 0.2190021242131479, 0.44081508822273463, 0.4176227655261755, 0.360439604264684, 2.6399985887110233, 53.377046808600426, 130.04566580057144, 122.05173075199127, 88.61549332737923, 86.55376955866814, 86.83565363287926, 53.55896204710007, 35.2266101539135, 44.19219106435776, 60.29658190906048, 80.83990976214409, 94.04967293143272, 48.957009986042976, 1.4340346190147102, 0.12329865610809065, 0.08563210853026249, 0.12956859427504241, 0.19354617688804865, 0.0768081507703755, 0.1050654829305131, 0.12845595163526013, 0.09675749592133798, 0.10854055974050425, 0.18158183607738465, 0.12842631025705487, 0.1509455792256631, 0.1182692103611771, 0.16026242694351822, 0.102864970540395, 0.1215034825145267, 0.18909064878243953, 0.0806474439741578, 0.17281518696108833, 0.1349219132680446, 0.09937262395396829, 0.2142752372310497, 0.14973871351685375, 0.14490106841549277, 0.20123271911870688, 0.20745530084241182, 0.14855589339276776, 0.1190256592235528, 0.11985643417574465, 0.17900725157232955, 0.10511349246371537, 0.1699367820401676], [0.004683152219513431, 0.060751359051209874, 0.06892908801091835, 0.03499772145005409, 0.010247171576338587, 0.045732138023595326, 0.0342051745246863, 0.039672390921623446, 0.11142498347908258, 0.0496601401391672, 0.024240763996203896, 0.055589280382264405, 0.034604205065988936, 0.03522556449752301, 0.021337652979127597, 0.006098384237702703, 0.11780060347518884, 0.028154051178717054, 0.04427470841619652, 0.04968358829501085, 0.12909596494864672, 0.041273852839367464, 0.06004776223562658, 0.04368494963273406, 0.0356357161217602, 0.032656690818839706, 0.03324826044263318, 0.05202323853154667, 0.011318134274915792, 0.20970190060324967, 2.9954616772010922, 30.795688815414906, 80.50198629498482, 68.43348428606987, 70.55117905139923, 47.04925015568733, 34.82081472873688, 30.137558430433273, 45.964621156454086, 56.466866210103035, 39.02660384774208, 100.21585285663605, 78.58642548322678, 33.511226400732994, 52.40516155958176, 13.325091730803251, 0.0331088702660054, 0.17099693999625742, 0.096561799000483, 0.0176579103936092, 0.06039043779310305, 0.13757727312622592, 0.048438739468110725, 0.009179892713291338, 0.06342923938063905, 0.6540296331513673, 0.7222634030040354, 2.373071936890483, 3.3503880444914103, 1.9543891469947994, 0.3817170375259593, 1.8520524445921183, 0.27262426796369255, 0.19527069060131907, 4.821521854028106, 14.78766554966569, 25.14773838222027, 49.173138588666916, 68.58878195285797, 78.16041514277458, 91.00454673171043, 90.30115887522697, 84.01295989751816, 79.65599969029427, 67.37071171402931, 42.41963557898998, 18.383603543043137, 4.75982503965497, 4.394275629892945, 8.848798926919699, 8.328979220241308, 11.398977935314178, 13.625567257404327, 22.80339527875185, 24.045761413872242, 22.74320460855961, 13.772076945751905, 11.616964638233185, 18.867456279695034, 19.783400930464268, 20.417964980006218, 12.13773524388671, 18.115233443677425, 6.877855136990547, 2.803575536236167, 2.1425679931417108, 3.592705554328859, 15.10920049622655, 28.802403174340725, 42.419312596321106, 43.95700268447399, 38.7039365619421, 39.33574005961418, 25.0488068908453, 10.09628813713789, 7.658677138388157, 3.3395040035247803, 0.3319343947805464, 1.043819070328027, 2.6730910129845142, 1.8367455597035587, 4.586023315787315, 6.135237710550427, 1.3613876234740019, 0.38610028044786304, 1.2891683424822986, 1.6546700173057616, 0.37773345597088337, 0.19747822370845824, 0.06543454466736875, 0.14066025847569108, 0.6335590034723282, 0.10999214864568785, 0.024402982635365333, 0.2785131800919771, 0.15382790268631652, 0.02271475808811374, 0.02706711838982301, 0.18546147242886946, 0.007906493465270614, 0.02162429824238643, 11.700020581483841, 58.175034150481224, 78.95564407110214, 83.11376854777336, 91.97401151061058, 66.17303878068924, 43.77782329916954, 30.503229908645153, 34.066255018115044, 40.01575917005539, 59.31331247091293, 68.6934207379818, 23.991454727947712, 1.3657355401664972, 0.044415178417693824, 0.12273464613826945, 0.02548244385252474, 0.09151128368102945, 0.03592897206544876, 0.03532557260768954, 0.011637402494670823, 0.022361217488651164, 0.038964445120655, 0.018653085899131838, 0.03718714986462146, 0.03574389156710822, 0.06377211160724983, 0.08401008541113697, 0.08950170362368226, 0.029686994312214665, 0.02957910459372215, 0.02096539541525999, 0.030001740997249726, 0.03157989020110108, 0.030457716529781464, 0.03446221737249289, 0.03331115745822899, 0.02735728514380753, 0.12547921214718372, 0.04058351078128908, 0.05409180077549536, 0.09085674653761089, 0.049755821528378874, 0.02878833511203993, 0.0649593846173957, 0.008859776589815738, 0.023383676198136527, 0.061495113477576524, 0.04765778860019054, 0.021149323729332536, 0.004370391243355698, 0.04549758225039113, 0.03294707836175803, 0.043043886180385016, 0.019382375867280643, 0.021986444044159725, 0.07332446504733525, 0.1649508558330126, 0.027957664060522802, 0.04024480942462105, 0.05701450449123513, 0.03035960646229796, 0.023292612822842784, 0.06832566257799044, 0.03941495844628662, 0.024072997803159524, 0.005317752029441181, 0.0188665127279819, 0.026568868270260282, 0.032411258871434256, 0.057329843039042316, 0.03671596401545685, 0.021961090424156282, 0.03884573117829859, 0.22131971782073379, 6.931292619556189, 53.30056071281433, 99.45422172546387, 94.30109024047852, 98.84188458323479, 80.87880447506905, 35.80867052078247, 14.29457550868392, 35.41885703802109, 50.01507081091404, 46.28130756318569, 103.20772871375084, 84.14061784744263, 26.20942421257496, 32.85633534193039, 5.784364063292742, 0.10962502303300425, 0.2552640385692939, 0.15249791467795148, 0.025598632637411356, 0.10169107845285907, 0.17481192044215277, 0.8910974871832877, 0.7408164418302476, 0.9746167086996138, 1.4280983875505626, 0.8907844789791852, 1.9133805599994957, 0.924602901795879, 0.44267565244808793, 1.0546236718073487, 1.3336586114019156, 0.16897040186449885, 1.2071674363687634, 9.418808240443468, 23.65754384547472, 36.79849460721016, 62.56917916238308, 83.13470542430878, 96.91620871424675, 104.05001431703568, 102.83515870571136, 100.75397238135338, 98.5625995695591, 85.92888548970222, 63.897918462753296, 33.18505570292473, 12.553222049027681, 9.392005428671837, 10.791674572974443, 2.950504864566028, 2.4520096136257052, 6.859858352690935, 22.639390379190445, 25.58575227856636, 22.508299313485622, 14.667912125587463, 14.955726731568575, 19.695990420877934, 21.398946940898895, 23.187505267560482, 6.553757702931762, 4.67975003644824, 1.1420593550428748, 0.19598862942075357, 4.075988559052348, 8.322189934551716, 24.989096894860268, 43.224762976169586, 57.06672482192516, 60.19696645438671, 53.38761404156685, 52.740371972322464, 33.307891711592674, 15.988364070653915, 10.871480740606785, 4.7582851722836494, 1.2516146013513207, 0.5408417817670852, 1.63825620431453, 1.6675590444356203, 2.460788805037737, 0.8362083637621254, 1.2860839767381549, 0.892249122262001, 1.4967696089297533, 3.1085018115118146, 1.8916809931397438, 1.3671458582393825, 0.9600680018775165, 0.8463691966608167, 1.6476758988574147, 0.24504165194230154, 0.014872535539325327, 0.2102064571226947, 0.1138145208824426, 0.03931076091248542, 0.02549621625803411, 0.17395818344084546, 0.058937008361681364, 0.02095899253617972, 5.4386315401643515, 47.873095348477364, 76.48620218038559, 92.79355153441429, 104.14460644125938, 65.06779208779335, 19.59137063473463, 27.001520209014416, 52.37220212817192, 62.17412196099758, 79.92776110768318, 85.96432238817215, 46.140308529138565, 3.9975127950310707, 0.08714051626157016, 0.1491111534414813, 0.046794091977062635, 0.06060232095478568, 0.0020971263484170777, 0.04500250666751526, 0.036376405478222296, 0.041070033112191595, 0.03737062732398044, 0.015870141578488983, 0.0320354056020733, 0.04918453108984977, 0.10748313288786449, 0.07842091188649647, 0.02965389267046703, 0.03314246358058881, 0.04146687802858651, 0.022703026588715147, 0.08592245896579698, 0.05069011123850942, 0.03638709611550439, 0.05336829213774763, 0.020832762493228074, 0.010119851503986865, 0.09185082366457209, 0.0528797585866414, 0.0227335566887632, 0.14111614495050162, 0.08698611243744381, 0.03783985390327871, 0.05610256084764842, 0.1529654677142389, 0.14150235860142857, 0.33576067071408033, 0.1638541099964641, 0.15738301270175725, 0.1346030569402501, 0.1586471128393896, 0.1235013069526758, 0.16745879547670484, 0.1261288733803667, 0.1428559617488645, 0.0998457579407841, 0.26800478459335864, 0.14288600388681516, 0.15463026822544634, 0.1663812415790744, 0.17781041970010847, 0.10343442045268603, 0.125607781810686, 0.22282252233708277, 0.20455593767110258, 0.2101400200626813, 0.11284310152404942, 0.18330369290197268, 0.3398975799791515, 0.13490617973729968, 0.1422991877188906, 0.15713016298832372, 0.1528051489731297, 0.371064041974023, 7.236837074160576, 57.99315690994263, 119.87973690032959, 95.43178036808968, 99.61595624685287, 62.562229335308075, 54.42669488489628, 51.59910321235657, 67.18775913119316, 88.66679057478905, 55.2818313986063, 116.44946336746216, 105.08382484316826, 45.072569623589516, 74.77261573076248, 20.60967229306698, 0.34577066951896995, 0.4987113643437624, 0.40521221584640443, 0.09866159452940337, 0.1877088291803375, 0.25640676787588745, 0.44350546260830015, 0.3111280471784994, 0.40550862962845713, 1.2095979996956885, 1.5242854761891067, 4.884257912635803, 5.049486346542835, 4.1857945919036865, 3.66355465259403, 3.7744046794250607, 0.5182501534000039, 1.014934207778424, 7.1234264597296715, 18.3664645627141, 31.715478859841824, 55.73343716561794, 81.68711990118027, 97.45302870869637, 108.05377587676048, 102.90478616952896, 102.64171108603477, 98.65620374679565, 81.41424894332886, 56.225955337285995, 26.195323169231415, 8.330903816968203, 8.344334196299314, 15.07246121764183, 19.38946656882763, 24.59142353385687, 24.091381765902042, 35.59659630060196, 39.12667527794838, 34.51981008052826, 24.995018877089024, 23.776878342032433, 33.027964532375336, 32.58609764277935, 35.75933776795864, 21.406210251152515, 26.073995679616928, 11.727867387235165, 7.95444424264133, 4.470746526494622, 6.414178842678666, 21.86235297471285, 38.218489810824394, 54.47127789258957, 56.132647544145584, 48.6899147182703, 48.50181341171265, 31.375740990042686, 13.607345335185528, 9.39284898340702, 4.590937402099371, 3.0463860696181655, 6.106456154957414, 10.112874247133732, 14.795893058180809, 19.250167943537235, 17.670229822397232, 7.209052015095949, 2.855423279106617, 2.9182802187278867, 5.12822144664824, 2.828954136930406, 0.7865790487267077, 0.7155209023039788, 0.571474788011983, 1.0214058542624116, 0.21324283559806645, 0.08110691502224654, 0.5034551722928882, 0.5186572659295052, 0.10016239524702542, 0.16991628392133862, 0.47729185433126986, 0.18027684360276908, 0.12715281452983618, 16.788384541869164, 67.35095277428627, 92.43697866797447, 97.33965039253235, 111.2154646217823, 89.48968201875687, 68.18201377987862, 43.02882269024849, 46.026276648044586, 58.139148876070976, 75.5385710299015, 96.63177117705345, 49.975590929389, 3.579378481954336, 0.158597492845729, 0.2071765947039239, 0.11974949069553986, 0.26456683001015335, 0.16158460755832493, 0.08300696150399745, 0.12458680925192311, 0.10574672996881418, 0.17106744402553886, 0.15074846480274573, 0.08701369806658477, 0.12412243260769174, 0.1517966148094274, 0.13350271910894662, 0.18845890299417078, 0.10032117774244398, 0.13678654446266592, 0.11663238881737925, 0.27365074725821614, 0.1393704503425397, 0.24863565049599856, 0.1366026105824858, 0.16745604953030124, 0.1354629240813665, 0.4595534858526662, 0.17312895215582103, 0.09413459760253318, 0.21464470803039148, 0.2717106544878334, 0.166966721881181, 0.17814817110775039], [0.03447151277214289, 0.011828042606794043, 0.020217998899170198, 0.014029400117578916, 0.04284890543203801, 0.05991819438349921, 0.06695785472402349, 0.051538052066462114, 0.09673650056356564, 0.08461217497824691, 0.038827040189062245, 0.020401274123287294, 0.02525802396121435, 0.09392977968673222, 0.039934840315254405, 0.03969339370087255, 0.04969762230757624, 0.053166669167694636, 0.042909720723400824, 0.006216875535756117, 0.09522309075691737, 0.038176343659870327, 0.02225848198577296, 0.05673834391927812, 0.04144596059632022, 0.053703253070125356, 0.031777498152223416, 0.1352169318124652, 0.03356516492203809, 3.50567692425102, 36.386494114995, 70.17329692840576, 75.24566754698753, 59.87222447991371, 59.207092970609665, 53.47273327410221, 50.25515332818031, 50.429392978549004, 47.03815095126629, 39.204362109303474, 86.95821985602379, 74.0597815811634, 25.354825370013714, 31.410759910941124, 6.440826812759042, 0.1519950947840698, 0.14861569565255195, 0.08815909168333746, 0.2552134240977466, 0.2669964137021452, 0.14174337848089635, 0.10420845821499825, 0.3309131402056664, 1.3796459999866784, 1.0433019418269396, 4.6240711491554976, 2.439062758348882, 2.3020342737436295, 0.9903191879857332, 0.08058213497861288, 1.523913333658129, 12.6178945787251, 28.087243549525738, 54.02960479259491, 85.47691494226456, 99.86428812146187, 98.74502778053284, 99.70325276255608, 90.84040313959122, 92.29029133915901, 82.92301878333092, 86.09027802944183, 84.20864939689636, 92.07685679197311, 92.26477950811386, 100.3761738538742, 96.079311221838, 86.64919003844261, 84.1091251373291, 70.77868804335594, 16.760140657424927, 1.0768201807513833, 4.947677459567785, 15.458731390535831, 15.752870757132769, 11.888749804347754, 13.16720925271511, 11.540802475064993, 12.535067573189735, 15.76517354696989, 12.40739157423377, 7.071793405339122, 2.4332996550947428, 2.4993735970929265, 19.281012788414955, 38.68501357734203, 68.98317039012909, 78.6549586057663, 87.94973865151405, 82.96638205647469, 85.03073528409004, 86.06516137719154, 84.3407455086708, 80.6888222694397, 77.09152489900589, 68.95021855831146, 56.79960295557976, 37.496289163827896, 18.793470449745655, 5.681804241612554, 2.0995626132935286, 1.6632892610505223, 1.0789756150916219, 3.2334813801571727, 7.102135727182031, 5.397256035357714, 3.854839000850916, 2.1918154880404472, 2.1197231439873576, 0.33169242495205253, 0.2850257040699944, 0.20041732146637514, 0.15911490336293355, 0.423379605053924, 0.14002297626575455, 0.03469689188932534, 0.2351151595939882, 0.0731145114696119, 0.04236118824337609, 0.12738338497001678, 0.08494890222209506, 0.15894061740254983, 8.038202673196793, 30.389260724186897, 61.71460881829262, 85.09654775261879, 34.95858773589134, 50.82296445965767, 38.888564854860306, 24.514688551425934, 29.054838828742504, 40.80596096813679, 55.72535499930382, 58.102309852838516, 41.88366673886776, 5.4178504552692175, 0.1392814816790633, 0.059476438400452025, 0.0520387457072502, 0.03290622684289701, 0.03432053024880588, 0.029111184194334783, 0.09076253089006059, 0.013390137301030336, 0.019500201087794267, 0.03689157842018176, 0.013575749362644274, 0.06078152735426556, 0.04067899179062806, 0.02402711266768165, 0.054003481491236016, 0.030184745337464847, 0.018700865366554353, 0.040169540807255544, 0.042824306947295554, 0.058806861634366214, 0.027778381590906065, 0.08203469609725289, 0.02239330980955856, 0.07047823222819716, 0.07389807840809226, 0.03016156621015398, 0.049409505736548454, 0.057278523527202196, 0.03178967679559719, 0.035142440247000195, 0.012815386598958867, 0.05105295836983714, 0.03939699847251177, 0.006208580180100398, 0.013901333259127568, 0.01424208479875233, 0.06227321078768, 0.014437208410527091, 0.043945131765212864, 0.026556739721854683, 0.04736030241474509, 0.0701332968310453, 0.012395875564834569, 0.03364445597981103, 0.0429892010288313, 0.03148017523926683, 0.08581265079556033, 0.035637033433886245, 0.055731487009325065, 0.03201094070391264, 0.005223244625085499, 0.03777152065595146, 0.015920800578896888, 0.027928367780987173, 0.03246145774028264, 0.030255375531851314, 0.012507724641181994, 0.1932416736963205, 0.06760546020814218, 6.918369987979531, 59.072496592998505, 92.65425100922585, 98.09031531214714, 92.25945979356766, 94.18851748108864, 44.593430534005165, 33.17708373069763, 45.81797182559967, 43.32615293562412, 48.31272795796394, 90.60751363635063, 71.68446823954582, 25.575519427657127, 25.785669051110744, 1.7961639747954905, 0.06839448193204589, 0.07131664387998171, 0.03144342408631928, 0.24954213935416192, 0.263678360497579, 0.349269361468032, 0.4360182612435892, 1.3191065797582269, 0.7353804772719741, 0.20469405135372654, 2.7516071498394012, 0.26884851744398475, 1.0820595058612525, 0.4398077563382685, 0.46778325049672276, 4.612607639282942, 21.15945339202881, 41.052537336945534, 67.00012519955635, 98.54977905750275, 107.33447447419167, 104.56081330776215, 104.8617571592331, 96.64060190320015, 94.70314666628838, 89.34543415904045, 89.82746109366417, 86.9581438601017, 93.74715596437454, 94.43858206272125, 103.54512020945549, 105.330401211977, 98.15643176436424, 101.95231407880783, 91.48519814014435, 25.979179367423058, 2.5405382132157683, 1.763471954036504, 9.19275552034378, 15.862508174031973, 9.69581052660942, 10.770197175443172, 13.284893687814474, 17.41066575050354, 19.4402926415205, 10.75993487611413, 1.9654827704653144, 1.9404531572945416, 5.653052609413862, 33.790564611554146, 55.36845535039902, 87.12918788194656, 91.5585646033287, 100.86104303598404, 91.67135775089264, 94.05819967389107, 96.10483065247536, 94.84109446406364, 94.74223136901855, 90.71185603737831, 85.72181180119514, 76.0842901468277, 52.938896119594574, 27.953099347651005, 9.914346300065517, 3.067508661188185, 1.5150904445908964, 0.8453388581983745, 1.4583207783289254, 0.983904954046011, 0.41082772077061236, 1.3851533294655383, 0.22037661139620468, 0.9486102510709316, 1.5434813336469233, 1.133446404710412, 0.4461807862389833, 0.76503372984007, 0.6274307635612786, 0.266893106745556, 0.08634502300992608, 0.1746029464993626, 0.28623000194784254, 0.10086623326060362, 0.10351905497373082, 0.07705438052653335, 0.19124127400573343, 6.88964162953198, 27.563331462442875, 53.48582737147808, 85.5715374648571, 39.629965871572495, 53.27465370297432, 21.838482655584812, 23.18776175379753, 44.27393987774849, 57.73066319525242, 76.56370282173157, 72.84005463123322, 66.50134116411209, 10.607037730515003, 0.2485076745506376, 0.059774670444312505, 0.02587121049145935, 0.05384846168453805, 0.02531331396312453, 0.036711095526698045, 0.039088710327632725, 0.04945987901010085, 0.04856926098000258, 0.033399777312297374, 0.03170353942550719, 0.10036311650765128, 0.03795741380599793, 0.04390047302877065, 0.07701071997871622, 0.014530480602843454, 0.04962629078363534, 0.032210467106779106, 0.04931030285661109, 0.04277983003703412, 0.03521445825754199, 0.04883103501924779, 0.03814421237620991, 0.025438323173148092, 0.05450528464280069, 0.027732245980587322, 0.11253698787186295, 0.00993556695902953, 0.036990358275943436, 0.04947548637574073, 0.10677076017600484, 0.09308549764682539, 0.19395306677324697, 0.15336272452259436, 0.23932555632200092, 0.12366693204967305, 0.13458281115163118, 0.11112360472907312, 0.18671449972316623, 0.1617043901933357, 0.12057086263666861, 0.17221084126504138, 0.09149496385361999, 0.1377817348111421, 0.08752426598221064, 0.210152963118162, 0.14862675365293398, 0.1583590407972224, 0.13764890521997586, 0.11937403076444753, 0.12072163735865615, 0.10326678413548507, 0.22936032386496663, 0.1410003550699912, 0.1202114627812989, 0.10302474009222351, 0.1574033178621903, 0.2633923664689064, 0.25820445735007524, 7.435421543195844, 70.56497991085052, 106.89448848366737, 100.2196678519249, 89.02711004018784, 80.76576814055443, 72.49706983566284, 77.46376812458038, 77.78804272413254, 76.04477226734161, 59.21385280787945, 113.58623340725899, 102.71456837654114, 38.4252405166626, 48.14511515200138, 11.518269684165716, 0.2837483194889501, 0.24592742003733292, 0.18754727847408503, 0.6181741040199995, 0.6013557314872742, 0.40117876196745783, 0.39297040086239576, 1.0010998626239598, 3.014836125075817, 7.558801397681236, 17.483410947024822, 7.029106020927429, 7.080690152943134, 2.2472034534439445, 0.4171946056885645, 2.7456452697515488, 16.701517403125763, 36.6971692442894, 61.95190988481045, 95.4819604754448, 109.45716217160225, 105.21998673677444, 109.83367636799812, 103.73676672577858, 98.71154397726059, 90.27722015976906, 94.21306416392326, 90.59517189860344, 98.54954347014427, 101.75009652972221, 106.72622591257095, 112.5374136865139, 94.5976947247982, 105.19814550876617, 86.4829869568348, 19.005421176552773, 3.1113951187580824, 13.33507189527154, 24.69200223684311, 29.222768917679787, 21.741209775209427, 25.354318097233772, 24.391128681600094, 25.82420088350773, 32.518290281295776, 26.91195711493492, 17.239507734775543, 6.411341344937682, 4.260465335100889, 28.101416788995266, 50.64875140786171, 87.40298599004745, 94.88454133272171, 107.23475262522697, 98.31976979970932, 101.4097335934639, 101.88825711607933, 101.45682066679001, 97.92968273162842, 92.48971223831177, 87.51320287585258, 77.00699463486671, 52.80622623860836, 24.86637867987156, 8.121435306966305, 3.1229643104597926, 3.2358591025695205, 6.914209686219692, 11.905541103333235, 20.757041685283184, 17.623598724603653, 9.981879126280546, 6.822577603161335, 5.04314923658967, 1.6223571449518204, 0.871915522729978, 0.2602126792771742, 0.4544294608058408, 0.9071671811398119, 0.3011996252462268, 0.11986674260697328, 0.5107821291312575, 0.5282456951681525, 0.312208614195697, 0.2521008864277974, 0.2488493890268728, 0.3800184989813715, 16.722209192812443, 42.080290988087654, 72.69333690404892, 100.28370961546898, 50.64718969166279, 72.62333706021309, 59.683769792318344, 38.51738177239895, 41.05363167822361, 56.860266700387, 73.45585718750954, 80.229282528162, 71.69108748435974, 10.638970267027617, 0.280246005859226, 0.1329638753668405, 0.0998616027936805, 0.09736893654917367, 0.1693662189063616, 0.11390002371626906, 0.14953395497286692, 0.12201848105178215, 0.12587820558110252, 0.20186419773381203, 0.10544124714215286, 0.2507338800933212, 0.11212286946829408, 0.1261562289437279, 0.18060942966258153, 0.07618606032337993, 0.19928507128497586, 0.14680682943435386, 0.13704371347557753, 0.13785214978270233, 0.169886939402204, 0.14394619152881205, 0.20011108164908364, 0.12992313306313008, 0.19825805764412507, 0.14553674758644775, 0.1810279267374426, 0.1028849788417574, 0.2482995466561988, 0.11754685576306656], [0.05919828516198322, 0.017603024862182792, 0.043877941425307654, 0.03275680654041935, 0.00699025278663612, 0.07797353784553707, 0.07262061961228028, 0.060555157469934784, 0.05510070601303596, 0.019498750189086422, 0.07120129928807728, 0.010659892886906164, 0.03399912835448049, 0.02945305637695128, 0.028291151829762384, 0.05344379453163128, 0.034577031328808516, 0.08741391604417004, 0.044694407770293765, 0.07011518842773512, 0.050990499221370555, 0.016515552160853986, 0.047782510227989405, 0.04633173768525012, 0.03295929040177725, 0.12139622733229771, 0.045966048128320836, 0.016417970873590093, 10.98694609478116, 36.77028112113476, 58.89291822910309, 70.13649210333824, 58.300283029675484, 74.21761751174927, 31.45445566624403, 65.2624860405922, 65.31521201133728, 38.9074270427227, 30.17321951687336, 81.86767101287842, 79.40826058387756, 24.409515894949436, 34.034374728798866, 5.023346599191427, 0.17429176397854462, 0.1775948703289032, 0.03646398261480499, 0.1906606473494321, 0.18672919424716383, 0.04944411579344887, 0.2624005306279287, 0.290229138918221, 1.9598835334181786, 4.838036242872477, 2.398081007413566, 0.5470060009974986, 0.27730149042326957, 0.5682061915285885, 11.42606383189559, 37.08623416721821, 67.95268088579178, 85.80102995038033, 96.84697642922401, 98.83336544036865, 90.7869628071785, 84.36453983187675, 90.439243465662, 81.63804933428764, 84.00111973285675, 91.6441360116005, 89.82214137911797, 91.61106258630753, 88.69362473487854, 89.71881732344627, 88.04610908031464, 83.71207684278488, 85.75132861733437, 100.61201199889183, 83.29548999667168, 92.80138671398163, 86.1749678850174, 39.578927010297775, 9.168299082666636, 0.8767963608261198, 8.627622295171022, 14.238623511046171, 10.043398775160313, 9.031237587332726, 13.143956400454044, 7.85212523303926, 2.4678991734981537, 0.4344124021008611, 18.353442661464214, 58.48708860576153, 83.77884685993195, 85.2004873752594, 78.11183094978333, 74.10150334239006, 75.19550263881683, 72.70054131746292, 72.9440626502037, 70.07732167840004, 74.31738495826721, 73.96829769015312, 74.73210990428925, 76.79360568523407, 83.08069512248039, 85.22154584527016, 92.42142230272293, 82.33376920223236, 55.81746965646744, 24.483594819903374, 9.813079833984375, 2.6484562223777175, 0.516802134225145, 0.19820540968794376, 1.7419984750449657, 1.5709899575449526, 3.4153557708486915, 1.7863935115747154, 1.8772572046145797, 3.843083856627345, 0.7652630831580609, 0.1463602198055014, 0.21738732961239293, 0.21067193214548752, 0.06027218769304454, 0.08884236478479579, 0.13214360922574997, 0.05203471955610439, 0.1055549293232616, 0.048711026029195637, 0.5796607362572104, 11.952403038740158, 33.22694845497608, 35.14910191297531, 30.241251066327095, 12.618896774947643, 52.87310265004635, 42.58459992706776, 28.783753775060177, 41.733741983771324, 37.4312062561512, 54.06583584845066, 62.66814865171909, 44.38108652830124, 6.0305120050907135, 0.06584477421711199, 0.030480749082926195, 0.0632439399487339, 0.023410942703776527, 0.05757683720730711, 0.03709470423927996, 0.0040198489205067744, 0.05457516526803374, 0.02661846414412139, 0.023363220752798952, 0.06376692399499007, 0.04163294470345136, 0.049607911496423185, 0.06119323748862371, 0.05555215073400177, 0.022409598095691763, 0.11034151466446929, 0.03266360021370929, 0.04164463352935854, 0.04292015903047286, 0.06546253847773187, 0.023386999164358713, 0.044041069195372984, 0.01674072162131779, 0.026332011839258485, 0.03639526716142427, 0.025724218867253512, 0.026633752386260312, 0.04918827522487845, 0.0964654608105775, 0.047441129718208686, 0.015269399009412155, 0.027708955531124957, 0.054325536475516856, 0.03156554819724988, 0.02881609329051571, 0.05761002605140675, 0.07111983373761177, 0.05412796192103997, 0.051008503724006005, 0.005020266307838028, 0.06814254506025463, 0.04200409275654238, 0.03032289241673425, 0.024472460645483807, 0.04410912413732149, 0.048871155522647314, 0.036070655478397384, 0.07348672821535729, 0.013773923201370053, 0.0953172767185606, 0.031097236314963084, 0.028242841726751067, 0.03891398650011979, 0.06096758006606251, 0.017194489264511503, 0.4173460928723216, 19.489477202296257, 57.54711404442787, 82.31646493077278, 97.46311336755753, 88.90759885311127, 93.98442283272743, 27.673177868127823, 42.740152180194855, 66.70856684446335, 37.09221884608269, 47.090120762586594, 91.80092319846153, 80.90863287448883, 26.743859834969044, 30.558967217803, 1.1281421268358827, 0.22823135397629812, 0.10918285144725814, 0.06963250300032087, 0.09609837230527773, 0.22108096891315654, 0.1939491630764678, 0.7732165907509625, 0.8214465121272951, 1.9401394366286695, 1.0774668585509062, 0.11277994475676678, 0.6567895319312811, 0.8007734839338809, 1.9283155398443341, 20.62751803547144, 53.60337786376476, 83.23639556765556, 98.15672054886818, 105.78731149435043, 102.21493318676949, 94.91845071315765, 88.63105729222298, 94.27851185202599, 90.46682238578796, 91.11877620220184, 99.0534420311451, 96.42114847898483, 97.93262377381325, 98.78491044044495, 95.46174556016922, 95.78143760561943, 86.90817654132843, 90.52951142191887, 100.36469087004662, 94.44507971405983, 102.24110618233681, 92.91013687849045, 58.510358557105064, 17.725763842463493, 1.2619162048213184, 3.611131003126502, 13.972180858254433, 15.532069355249405, 10.408642776310444, 11.40178693458438, 6.961587918922305, 0.9136941027827561, 1.7658915929496288, 28.50196849554777, 74.47680160403252, 90.60986191034317, 90.91891452670097, 83.20052549242973, 81.640754789114, 80.12887671589851, 78.37375849485397, 77.80947357416153, 75.37909358739853, 80.80033108592033, 81.38603165745735, 81.95110693573952, 82.88865342736244, 91.88274040818214, 95.91867104172707, 105.63648998737335, 96.14641562104225, 71.47095769643784, 38.7537594884634, 17.128046415746212, 4.496198510751128, 1.2169672292657197, 0.4861272411653772, 0.32348824955988675, 0.3588381386362016, 0.5977553059346974, 1.668944782577455, 0.4206315806368366, 1.2635532044805586, 0.752521357499063, 0.30787367024458945, 0.6426168268080801, 0.6600235740188509, 0.05599381765932776, 0.15238730498822406, 0.1508253809879534, 0.026942875447275583, 0.09447508011362515, 0.02908899768954143, 0.22204614680958912, 11.282472386956215, 32.87521652877331, 37.94239282608032, 31.63297388702631, 13.839574623852968, 61.188200265169144, 30.266504511237144, 26.881450451910496, 54.32769499719143, 58.918460458517075, 77.85821735858917, 73.2550835609436, 66.31459638476372, 15.072776600718498, 0.1436608357471414, 0.1133307370764669, 0.0431442356784828, 0.05314553651260212, 0.01739857059874339, 0.03540537945809774, 0.10270616578054614, 0.015948720174492337, 0.014942198158678366, 0.02957980406790739, 0.03885582809743937, 0.02914560871431604, 0.029535538669733796, 0.023736819748592097, 0.058102229522773996, 0.015515125032834476, 0.031190444497042336, 0.02073349096463062, 0.04986722160538193, 0.035551987020880915, 0.015356603216787335, 0.10771853470942006, 0.09898810982122086, 0.02895180427003652, 0.04695354982686695, 0.03452481752901804, 0.042831353639485314, 0.011784335674747126, 0.032362737256335095, 0.23719985241768882, 0.14525266829878092, 0.17745616292813793, 0.08716943775652908, 0.07890163062256761, 0.2085087646264583, 0.19264031143393368, 0.14359916327521205, 0.18565800797659904, 0.1644203093019314, 0.1417394302552566, 0.08489375322824344, 0.19505119300447404, 0.1592577964765951, 0.14879312831908464, 0.06354911107337102, 0.07674064501770772, 0.1492667372804135, 0.10355942038586363, 0.15467616263777018, 0.09826070119743235, 0.19181375188054517, 0.0966114412585739, 0.14880691742291674, 0.10042288166005164, 0.2814760711044073, 0.13981832162244245, 0.4728115978650749, 20.456796996295452, 70.45963436365128, 94.97787192463875, 97.34927907586098, 84.02463287115097, 89.85639274120331, 47.23635211586952, 105.18904119729996, 99.40809220075607, 60.604908764362335, 59.77420873939991, 109.34164837002754, 106.74922227859497, 37.39773765206337, 56.02751858532429, 8.70400009676814, 0.601580097572878, 0.26615063252393156, 0.2396747368038632, 0.4787901317467913, 0.38371810514945537, 0.30067468935158104, 0.9503633226267993, 1.2718643085099757, 4.221499375998974, 10.328120347112417, 5.442924359813333, 3.052681856788695, 1.9811303308233619, 0.9798196982592344, 15.101864039897919, 47.242101207375526, 81.33275091648102, 97.4336801469326, 106.21182471513748, 103.52691918611526, 97.45601534843445, 87.14426547288895, 96.57722130417824, 91.73387199640274, 90.2485316991806, 101.93823203444481, 99.59516376256943, 99.4818614423275, 99.24006521701813, 96.52240544557571, 96.91063061356544, 90.42298033833504, 94.3645316362381, 105.42357981204987, 104.74574938416481, 111.29166573286057, 94.61082682013512, 49.42400112748146, 11.133290491998196, 4.500482305884361, 16.641203239560127, 27.941452972590923, 25.498201176524162, 23.553988002240658, 25.723156705498695, 15.666214507073164, 7.24192357622087, 1.6631001024506986, 22.323984503746033, 70.77185600996017, 95.26395097374916, 98.81815865635872, 90.23773267865181, 84.67952013015747, 80.48805624246597, 81.55818521976471, 81.01878896355629, 76.6909807920456, 82.17014998197556, 80.90064570307732, 83.57560336589813, 85.64877212047577, 95.51324799656868, 99.12345707416534, 111.66115030646324, 92.74744480848312, 65.57044431567192, 32.5978884100914, 14.051429405808449, 2.894817190244794, 2.381862052716315, 4.567270847037435, 8.0262466147542, 8.553028497844934, 9.367106314748526, 9.997894316911697, 8.983967173844576, 8.683528695255518, 2.820797637104988, 0.4935118480352685, 0.480908666504547, 0.5113037105184048, 0.20046039571752772, 0.32597008044831455, 0.2996091730892658, 0.2330396990873851, 0.3420126117998734, 0.2318134781671688, 1.5260958415456116, 24.105952084064484, 48.312359377741814, 47.949794232845306, 45.59702888131142, 24.74606193602085, 74.90107163786888, 61.19319699704647, 44.45859856903553, 55.528624355793, 55.03364771604538, 76.26864865422249, 83.65493550896645, 75.26991784572601, 14.497359227389097, 0.1563512344728224, 0.11513284975080751, 0.24168147443560883, 0.15931743546389043, 0.1956908352440223, 0.11575571945286356, 0.18388347350992262, 0.150522347248625, 0.12333223086898215, 0.1760974241187796, 0.11734766332665458, 0.10841300681931898, 0.12117987644160166, 0.12729714740999043, 0.16069742938270792, 0.10291538463206962, 0.20976867905119434, 0.1013033211347647, 0.18253476853715256, 0.10477534029632807, 0.15024062799056992, 0.15233066427754238, 0.14170235255733132, 0.09257090729079209, 0.1670301309786737, 0.19557014718884602, 0.11969534360105172, 0.2005054589244537, 0.269156004069373], [0.022379188594641164, 0.015504553139180643, 0.09774830017704517, 0.029849398488295265, 0.026686456003517378, 0.056179799867095426, 0.046646560440422036, 0.009812234075070592, 0.03986642914242111, 0.02705341834371211, 0.07337891642237082, 0.08066049093031324, 0.032251778757199645, 0.03282505815150216, 0.06768701481632888, 0.01697885454632342, 0.026694371008488815, 0.036199288224452175, 0.08715427567949519, 0.11347443170961924, 0.10150212023290806, 0.07524705797550268, 0.025361106418131385, 0.08546629789634608, 0.06767942264559679, 0.11345616745529696, 0.5593131843488663, 12.50264011323452, 48.847298473119736, 67.17480942606926, 66.59892752766609, 63.546764105558395, 52.14731119573116, 37.92902514338493, 75.38818269968033, 65.0239272415638, 20.775048919022083, 44.24295634031296, 94.42896097898483, 91.06507748365402, 39.10327233374119, 24.65228296816349, 3.3690364938229322, 0.031765182211529464, 0.208251966687385, 0.0008923075176880957, 0.30303474864922464, 0.049885018306667916, 0.08549469246645458, 0.32020157435908914, 0.14055189007194713, 0.7564115768764168, 0.6940167280845344, 0.13583426509285346, 0.3442003740929067, 3.3384904079139233, 18.905942514538765, 53.78480292856693, 85.45956507325172, 98.82889688014984, 94.96477022767067, 95.78952357172966, 90.31823515892029, 86.79950997233391, 83.59807536005974, 94.94946464896202, 91.43529921770096, 87.5025786459446, 95.95831051468849, 85.89869230985641, 88.9106234908104, 88.1793375313282, 92.03657135367393, 88.33121538162231, 89.27014499902725, 89.98340472579002, 91.20129257440567, 91.23766422271729, 92.27558612823486, 87.81645700335503, 90.45027807354927, 100.15917509794235, 90.30631139874458, 24.592686966061592, 0.7084811269305646, 5.684133991599083, 4.448261233046651, 7.4103291146457195, 8.670567590743303, 1.0335192480124533, 2.606024849228561, 36.04035548865795, 82.17255905270576, 84.8653681576252, 76.35839983820915, 72.21295148134232, 77.22716242074966, 78.85615780949593, 81.84736490249634, 82.22205519676208, 80.53780317306519, 79.00949478149414, 81.22568786144257, 79.95438247919083, 78.51780116558075, 75.13328477740288, 73.82512137293816, 73.70310232043266, 73.15450295805931, 79.68207389116287, 93.45026269555092, 94.52612176537514, 80.4086785018444, 60.699869468808174, 35.75646512210369, 9.059749357402325, 2.8144562523812056, 1.460123306605965, 1.0570900957100093, 1.735391579568386, 1.0911308065988123, 2.2028002236038446, 2.2337177395820618, 1.2104483228176832, 0.34545902686659247, 0.14574684959370643, 0.18145570065826178, 0.1500487234443426, 0.09191005447064526, 0.07961433730088174, 0.024796050020086113, 0.09096679961658083, 0.06853511149529368, 0.179330367827788, 9.303873907774687, 40.298471599817276, 58.15679892897606, 31.58020231872797, 16.042505465447903, 66.49377197027206, 46.16681590676308, 29.105847291648388, 23.855165541172028, 35.4607155919075, 60.20253695547581, 61.42433099448681, 50.611015632748604, 8.623973540961742, 0.2151584523380734, 0.09355934409541078, 0.018537876749178395, 0.026302277692593634, 0.01124538710428169, 0.06593245154363103, 0.034318136822548695, 0.012256734935363056, 0.009690724091342418, 0.04906182068225462, 0.05587579020357225, 0.030093216264504008, 0.010991467770509189, 0.04681025224272162, 0.062129197031026706, 0.04444371399586089, 0.08438423174084164, 0.04742394157801755, 0.03042796754016308, 0.1266188095905818, 0.0616212266322691, 0.0739684711152222, 0.02294251764396904, 0.025685595646791626, 0.11365214639226906, 0.010215568145213183, 0.04289341944968328, 0.007385352264464018, 0.019475964400044177, 0.05562428377743345, 0.02784397074719891, 0.06147206608147826, 0.046986894521978684, 0.054069246907602064, 0.049295541539322585, 0.0732853241788689, 0.06787756865378469, 0.038227833865676075, 0.09145102128968574, 0.03146270137222018, 0.029376333150139544, 0.04903071356238797, 0.04467979488254059, 0.04121434743865393, 0.052371788187883794, 0.033282874210271984, 0.02757083628239343, 0.07637227259692736, 0.031541061034658924, 0.017886582791106775, 0.10353776451665908, 0.0421521066891728, 0.17518290522275493, 0.01888074526505079, 1.4625873556360602, 23.214913196861744, 69.401565939188, 86.9452777504921, 94.22351360321045, 91.21937960386276, 85.14591470360756, 38.081723749637604, 42.55821794271469, 63.42577859759331, 24.49563257396221, 71.4124484360218, 114.58107322454453, 93.61837327480316, 39.492557644844055, 21.88736703246832, 1.3659056997857988, 0.013530150881706504, 0.10680481733288616, 0.05625589226838201, 0.08867504016961902, 0.10110755742061883, 0.17458887537941337, 0.2264071995159611, 0.15354299219325185, 0.5103755509480834, 1.0165532771497965, 0.42999626719392836, 1.0564884217455983, 8.506913222372532, 33.001681342720985, 70.91906011104584, 95.97680792212486, 106.52742817997932, 101.44905388355255, 98.9540545642376, 93.58211562037468, 93.56620207428932, 90.86909160017967, 102.3854148387909, 98.05632993578911, 96.16834804415703, 100.28494074940681, 92.54146546125412, 93.43080013990402, 93.28463718295097, 93.22347566485405, 93.79418224096298, 95.04091054201126, 93.91698405146599, 96.87579408288002, 94.788056910038, 96.77096530795097, 91.10275626182556, 91.55482560396194, 101.98173210024834, 101.96214035153389, 37.38963268697262, 1.4962389436550438, 3.826499409042299, 7.081120954826474, 6.190975494682789, 2.007010029628873, 2.051754528656602, 6.146053830161691, 50.1903136074543, 91.6524575650692, 91.44144728779793, 83.34231868386269, 80.57933494448662, 86.67420789599419, 86.27588286995888, 87.4802814424038, 90.6689715385437, 86.86083108186722, 86.94223791360855, 89.21261608600616, 88.58659207820892, 86.33166387677193, 84.67350125312805, 82.96703562140465, 81.58858358860016, 83.28816398978233, 91.83651208877563, 99.13918823003769, 101.67343944311142, 88.13803374767303, 73.84944766759872, 50.14792688190937, 15.399139188230038, 7.017129538580775, 2.7713670395314693, 2.1642508171498775, 2.302509960718453, 1.3418330415152013, 0.4989685630425811, 0.701230225386098, 1.2601050082594156, 0.3049236035440117, 0.30192318954505026, 0.565876382170245, 0.31152833194937557, 0.20630531333154067, 0.12315238622250035, 0.06497036840301007, 0.017808275079005398, 0.08757164468988776, 0.21793028485262766, 4.234467130154371, 34.53796550631523, 64.98020678758621, 31.447232253849506, 14.440470580011606, 73.14662978053093, 37.339798361063, 28.525707721710205, 37.91700638830662, 55.717626214027405, 77.9547929763794, 76.54796406626701, 68.7323534488678, 20.23372806608677, 0.22591183078475296, 0.05811742499645334, 0.042199934396194294, 0.016229795619437937, 0.034586898182169534, 0.027991418792225886, 0.05512777956028003, 0.011961323052673833, 0.04469774372410029, 0.04490960462135263, 0.07817861551302485, 0.04038856342958752, 0.07617632334586233, 0.04305994625610765, 0.051542423316277564, 0.016754314056015573, 0.036605643763323314, 0.05456664541270584, 0.06807647165260278, 0.05225399450864643, 0.06729055952746421, 0.02724686470173765, 0.01300452757277526, 0.045115212924429215, 0.0789627835911233, 0.07158171676564962, 0.026058927469421178, 0.021352295552787837, 0.1276005373802036, 0.21891086973482743, 0.1754901692038402, 0.23368100373772904, 0.14020739996340126, 0.16675708000548184, 0.14546026184689254, 0.18702186760492623, 0.20105237723328173, 0.21945170243270695, 0.16428506030933931, 0.13219867658335716, 0.11145271753775887, 0.1555276138242334, 0.17078619974199682, 0.11321848724037409, 0.18175716104451567, 0.16849971696501598, 0.1958587535773404, 0.2856720850104466, 0.21345014713006094, 0.1476657169405371, 0.18328712816582993, 0.1955350732896477, 0.18053601641440764, 0.18942258175229654, 2.0336950477212667, 27.40133285522461, 84.45555254817009, 100.81808254122734, 94.05795648694038, 89.65217649936676, 68.82566884160042, 58.38899686932564, 105.13442292809486, 87.93086886405945, 39.788246378302574, 75.09985417127609, 120.12477815151215, 110.23552760481834, 54.762505665421486, 39.23563063144684, 4.700166815891862, 0.10188976622885093, 0.4121306649176404, 0.12048947130097076, 0.472221709205769, 0.15535389189608395, 0.375936419586651, 0.7605310308281332, 0.8770571812056005, 3.9840719662606716, 4.498403817415237, 3.6637767031788826, 1.0070020146667957, 4.6480426378548145, 27.76079546660185, 65.15534698963165, 96.08526170253754, 109.55342620611191, 105.74698805809021, 101.35055556893349, 99.78136137127876, 94.89046901464462, 90.05633041262627, 101.42643749713898, 104.10017922520638, 100.56392177939415, 105.2021124958992, 95.72874963283539, 95.32895788550377, 95.9031830728054, 97.26979494094849, 97.39264994859695, 98.028963804245, 97.23150819540024, 99.67142567038536, 98.59932079911232, 96.7438879609108, 91.21302634477615, 95.35740315914154, 109.90865394473076, 103.01086127758026, 30.402542911469936, 3.345133876428008, 11.388869527727365, 12.400554791092873, 17.972858883440495, 17.210870571434498, 6.457371124997735, 4.57043987698853, 44.97666276991367, 95.71877896785736, 94.42690148949623, 87.83306211233139, 81.13922730088234, 87.89350166916847, 87.7017031610012, 93.21731999516487, 95.6462636590004, 89.41927179694176, 89.68416318297386, 92.00746491551399, 91.44856050610542, 88.0809836089611, 84.24222439527512, 83.23961019515991, 82.49919712543488, 82.93991267681122, 92.29467630386353, 110.14915823936462, 112.15004727244377, 95.39727061986923, 73.72516393661499, 44.11401405930519, 11.313584167510271, 4.568203696981072, 1.5116982953622937, 1.3941587274894118, 2.767418813891709, 4.919246435165405, 8.274585139006376, 9.26399789750576, 5.8033188711851835, 1.3323411508463323, 0.2454939909512177, 0.3320020192768425, 0.2756879723165184, 0.321178151643835, 0.37391849036794156, 0.2005289404769428, 0.22542661463376135, 0.12562764168251306, 0.31870409846305847, 15.243105310946703, 55.08290447294712, 76.13070845603943, 46.98896259069443, 28.022582419216633, 91.12690016627312, 63.601500168442726, 42.71400958299637, 34.82835732400417, 50.069905668497086, 80.47883793711662, 80.64990475773811, 78.5667197406292, 19.09891325980425, 0.4156087548471987, 0.16555068927118555, 0.11071546061430126, 0.13866322813555598, 0.04364050240837969, 0.14941501838620752, 0.16388320218538865, 0.12074741956894286, 0.17128024745034054, 0.10878308617975563, 0.15900466474704444, 0.09169253098662011, 0.16271339933155105, 0.11224934627534822, 0.14530347572872415, 0.23877532803453505, 0.11481319190352224, 0.16826985898660496, 0.1189969752158504, 0.14169635600410402, 0.17713261622702703, 0.2268176368670538, 0.08909004915039986, 0.139111218159087, 0.1820097435847856, 0.26083272881805897, 0.1885539127397351, 0.10529113293159753], [0.09998150417231955, 0.10101448468049057, 0.05922178897890262, 0.056909449776867405, 0.05689325982530136, 0.01841188975959085, 0.0367927503248211, 0.03159703381243162, 0.03306874605186749, 0.037842751989956014, 0.013490674191416474, 0.08037296807742678, 0.021157129267521668, 0.13885228283470497, 0.1196500651712995, 0.028520161904452834, 0.13683307712199166, 0.027160569625266362, 0.024641692580189556, 0.047855107113718987, 0.029273933469085023, 0.039401666581397876, 0.05388438163208775, 0.043102296913275495, 0.07087245365255512, 1.799196449574083, 19.043333642184734, 54.37785230576992, 66.77156746387482, 73.88926193118095, 57.67003744840622, 68.03380653262138, 42.98850305378437, 52.15747185051441, 91.69870868325233, 36.763050109148026, 79.91103440523148, 127.91334182024002, 98.0701231956482, 44.16391298174858, 14.385364037007093, 2.407979001291096, 0.11595396194024943, 0.22027916740626097, 0.04712651847512461, 0.20102430920815095, 0.0336553061788436, 0.09919373667798936, 0.06217292808287311, 0.4225430858787149, 0.30014779418706894, 0.24837358330842108, 0.43003809463698417, 7.477521859109402, 36.78417697548866, 68.14774721860886, 84.46168541908264, 95.60091689229012, 92.51866668462753, 96.24677583575249, 91.6465450823307, 89.90541011095047, 83.53585749864578, 89.64082270860672, 91.78804948925972, 91.18224039673805, 81.91185504198074, 87.79712364077568, 90.92320829629898, 88.92139211297035, 91.0448245704174, 86.35002449154854, 86.44365906715393, 83.9605987071991, 84.67913255095482, 84.05952259898186, 82.89844930171967, 85.69769069552422, 87.54528075456619, 85.36723762750626, 85.8644637465477, 80.81399515271187, 85.68192914128304, 89.19788807630539, 20.850539468228817, 0.8843773102853447, 4.633994791656733, 3.146372241899371, 1.8545882147736847, 3.330485662445426, 49.984934628009796, 81.99820160865784, 80.65457850694656, 77.53672420978546, 81.12945422530174, 89.61084231734276, 83.3692592382431, 81.96375265717506, 77.46137425303459, 75.36872774362564, 76.97202891111374, 81.28024533390999, 80.34155130386353, 80.57200893759727, 81.12785071134567, 81.38931468129158, 82.27016061544418, 80.76155036687851, 84.95325744152069, 80.5516268312931, 68.66389632225037, 57.61928357183933, 61.46494701504707, 80.08535385131836, 90.82703545689583, 76.52632042765617, 57.830286249518394, 44.269452318549156, 37.49557860195637, 24.215619899332523, 10.24371737614274, 2.917759409174323, 0.2635457832366228, 1.084048580378294, 1.9415365741588175, 2.1694693621248007, 0.18307923775864765, 0.0961767059925478, 0.02594403373223031, 0.031979035775293596, 0.06397151184501126, 0.08125387510517612, 0.1049152722407598, 0.11444547999417409, 0.5231468437705189, 3.3401295449584723, 26.898471638560295, 57.680323496460915, 45.48684619367123, 21.866061575710773, 36.93483889102936, 39.02325622737408, 34.08744268119335, 34.66048613190651, 39.794413447380066, 49.14219304919243, 67.01385766267776, 56.95414066314697, 10.532223545014858, 0.053555743797915056, 0.17021186649799347, 0.0358796749060275, 0.08178757576388307, 0.027672881587932352, 0.02467317448463291, 0.02738377239438705, 0.07643089484190568, 0.06480008261860348, 0.04469524268642999, 0.04978985642082989, 0.08212013213778846, 0.10278150861267932, 0.007369040322373621, 0.018255140748806298, 0.13538087223423645, 0.0827136795851402, 0.0071415099046134856, 0.05589243657595944, 0.07664424745598808, 0.042564714822219685, 0.03463092238234822, 0.06126207910710946, 0.07711603815550916, 0.040062463740468957, 0.050593127380125225, 0.0388608450157335, 0.07041916469461285, 0.021874058766115922, 0.03955048945499584, 0.07720801251707599, 0.06243582276511006, 0.026810231393028516, 0.02623549738927977, 0.0403576715325471, 0.0057079876569332555, 0.05879047872440424, 0.02990100001625251, 0.026846618893614504, 0.01523449116575648, 0.08438310367637314, 0.047085574187804013, 0.04421140693011694, 0.07724376177066006, 0.03379064793989528, 0.008824282449495513, 0.019131518820358906, 0.06510120903840289, 0.022355137443810236, 0.03704173715959769, 0.06111885202699341, 0.048432575931656174, 4.110349640250206, 29.809560030698776, 77.7976182103157, 83.82367685437202, 94.69724178314209, 82.05449178814888, 89.4991435110569, 45.76007433235645, 29.982445053756237, 87.85898432135582, 43.53457175195217, 103.38851541280746, 130.08039593696594, 86.86320215463638, 40.83228215575218, 8.300079870969057, 0.5767899309284985, 0.16764966101618484, 0.1566363824531436, 0.04547290955088101, 0.09223162705893628, 0.06255847751162946, 0.03259024633734953, 0.05442311776278075, 0.09449180070078, 0.5442041857168078, 0.2316347393207252, 1.3477324624545872, 16.664760075509548, 56.93637661635876, 83.72089996933937, 95.0243890285492, 100.00620290637016, 98.50585341453552, 101.6038727760315, 100.1759321987629, 96.2682218849659, 91.75017312169075, 92.92031273245811, 97.85855814814568, 92.88500502705574, 88.39239969849586, 94.14649173617363, 95.10639622807503, 94.75040853023529, 93.96605461835861, 91.60050675272942, 91.74910917878151, 91.2838925421238, 91.4891043305397, 89.30382639169693, 87.76803240180016, 89.46396499872208, 90.21417394280434, 89.61086511611938, 89.59044501185417, 84.56585302948952, 88.09804469347, 96.82079583406448, 32.97688387334347, 1.3141379901207983, 1.3706744438968599, 1.269432082772255, 1.7568962881341577, 7.983385864645243, 61.83129295706749, 90.10997593402863, 84.3256451189518, 84.99419644474983, 91.17386564612389, 94.21722874045372, 89.46267306804657, 86.43759459257126, 82.32348695397377, 79.1261637210846, 80.96730172634125, 84.73236009478569, 85.28630197048187, 85.67827373743057, 86.38346269726753, 87.40253001451492, 88.28839927911758, 88.13460633158684, 93.16356807947159, 85.76417192816734, 76.25685408711433, 68.45436796545982, 67.33257696032524, 81.0837122797966, 95.55496975779533, 91.44192606210709, 72.82984837889671, 62.9861231893301, 51.38177007436752, 34.421140775084496, 16.608779579401016, 6.936030490323901, 0.968401845311746, 0.5861834425013512, 1.2754152179695666, 1.3365494250319898, 0.21553651720751077, 0.8970970090012997, 0.38932998839300126, 0.1871356536867097, 0.10747034568339586, 0.20416951621882617, 0.08186034334357828, 0.04299084117519669, 0.4743356129620224, 1.522620809264481, 21.20890013873577, 64.16450455784798, 36.295925974845886, 19.122293405234814, 44.33053784072399, 34.98299762606621, 25.740802958607674, 45.67097291350365, 60.87730474770069, 68.21178138256073, 82.22191080451012, 71.62801086902618, 22.813666127622128, 0.16677636100212112, 0.09841514212894253, 0.08041068402235396, 0.08048113610129803, 0.027558676192711573, 0.06023826412274502, 0.05474705780216027, 0.0630799401551485, 0.0625160192430485, 0.10521139658521861, 0.03514594318403397, 0.019490280428726692, 0.03804249361564871, 0.03369200538145378, 0.0382008939050138, 0.08875059080310166, 0.09091978456126526, 0.04651429859222844, 0.03773212374653667, 0.06260657610255294, 0.19281012966530398, 0.0210385173704708, 0.05332701017323416, 0.06818188630859368, 0.037847895073355176, 0.052129146715742536, 0.06386798224411905, 0.17627784021897241, 0.3240588720655069, 0.15736537927296013, 0.22748341754777357, 0.1099469666951336, 0.088012858905131, 0.1813444378785789, 0.13475442538037896, 0.1511643940466456, 0.2014973689801991, 0.1386389895924367, 0.10820107912877575, 0.16921200061915442, 0.17993251676671207, 0.23572210280690342, 0.13645845581777394, 0.24257122044218704, 0.11982626587268896, 0.05539643330848776, 0.16170346993021667, 0.14911085658241063, 0.06539838723256253, 0.11024583698599599, 0.19529924844391644, 0.14351384597830474, 4.892158163711429, 37.57630906999111, 96.09287649393082, 98.55376124382019, 102.6273250579834, 83.87132629752159, 87.00828596949577, 58.638970255851746, 78.97943839430809, 124.2448590695858, 58.48394237458706, 112.81337007880211, 147.30643719434738, 111.97209522128105, 62.60012470185757, 20.637513399124146, 3.483910267241299, 0.4100971802836284, 0.33105313894338906, 0.17584650398930535, 0.4158352583181113, 0.1093864299764391, 0.23587356030475348, 0.44510395964607596, 1.8317094049416482, 2.0554833160713315, 1.0716399899683893, 0.6575474725104868, 11.109539866447449, 50.53286902606487, 81.35624885559082, 96.56975090503693, 103.75851675868034, 102.58465334773064, 104.36984315514565, 102.37730607390404, 97.99370169639587, 94.27078306674957, 96.23681277036667, 101.14550337195396, 96.8285246193409, 93.91138315200806, 96.79537519812584, 98.12367752194405, 98.11955094337463, 100.786924213171, 95.50842225551605, 98.94660696387291, 95.23830994963646, 94.44482132792473, 90.06069257855415, 90.39176121354103, 91.69753074645996, 96.35014548897743, 94.68726351857185, 94.48914974927902, 89.28680330514908, 93.2204358279705, 98.11862379312515, 26.67009439319372, 3.0441268533468246, 8.453596383333206, 5.4316346906125546, 5.774840349331498, 4.963878840208054, 56.739763766527176, 91.63019075989723, 87.32249110937119, 87.72645503282547, 93.12281146645546, 98.72999578714371, 92.59016364812851, 90.50058737397194, 83.74081090092659, 83.91761541366577, 84.76591989398003, 86.07165902853012, 86.0273914039135, 89.25288632512093, 88.61440658569336, 87.62389853596687, 89.6462032198906, 93.6105988919735, 95.2521488070488, 84.46477845311165, 77.07453221082687, 70.44479995965958, 69.65327203273773, 81.68267413973808, 96.08946427702904, 86.04470327496529, 68.52251350879669, 58.70315261185169, 45.056177303195, 26.03072740137577, 11.258383579552174, 3.201919086277485, 0.48264247190672904, 4.130107630044222, 8.305278941988945, 5.724603720009327, 0.35908868769183755, 0.39749963907524943, 0.24068336002528667, 0.26302616111934185, 0.23492260195780545, 0.3030154528096318, 0.2675654331687838, 0.17212975420989096, 0.559884044341743, 5.833717240020633, 38.28672654926777, 77.82850295305252, 57.99912638962269, 35.438988357782364, 57.177329286932945, 54.69757094979286, 49.58840690553188, 48.40827763080597, 58.47207561135292, 68.66971001029015, 86.36271581053734, 88.13805654644966, 22.798151560127735, 0.2543449035147205, 0.22937849164009094, 0.12072308454662561, 0.22086009092163295, 0.1135007556877099, 0.1215652737300843, 0.1482380909146741, 0.1703685784013942, 0.1708285021595657, 0.2120868070051074, 0.12591308652190492, 0.19110715307760984, 0.28679436072707176, 0.1876834625727497, 0.1337048356072046, 0.21357052348321304, 0.22591929679038003, 0.19174857647158206, 0.12566436314955354, 0.16124780609970912, 0.26211717864498496, 0.1022071902116295, 0.14849261788185686, 0.09012600567075424, 0.12408830123604275, 0.23395838885335252, 0.22885875077918172], [0.041438795160502195, 0.07912062355899252, 0.04818853922188282, 0.03925912227714434, 0.07859001765609719, 0.0719491095514968, 0.017556852144480217, 0.00846009574161144, 0.059229032340226695, 0.04564404138363898, 0.022099534362496343, 0.04893579287454486, 0.04576319319312461, 0.049865002583828755, 0.009939264709828421, 0.04239236586727202, 0.03514335308864247, 0.027654433652060106, 0.04162754557910375, 0.005948227817498264, 0.1579366993973963, 0.018395827828499023, 0.13420305418549106, 0.331880574231036, 4.906057817861438, 39.016693979501724, 60.176500752568245, 71.42352104187012, 69.32056948542595, 62.95779190957546, 60.48726327717304, 47.95245409011841, 56.458841040730476, 79.53621491789818, 41.9583061337471, 81.26397460699081, 113.19681510329247, 57.832558527588844, 37.25562907755375, 8.303175754845142, 0.44213988119736314, 0.044704230094794184, 0.07421304588206112, 0.06148757696792018, 0.3247174242278561, 0.03826617692539003, 0.1994389036553912, 0.031037486005516257, 0.28846000728663057, 0.32135475310496986, 1.142385306302458, 10.60357516631484, 47.164349779486656, 89.83993202447891, 96.34873196482658, 95.21791264414787, 90.4449811577797, 91.47712737321854, 96.17300659418106, 95.6005597114563, 95.53796947002411, 91.2094697356224, 90.29829382896423, 83.99063989520073, 86.47046282887459, 86.43406078219414, 81.60308361053467, 97.96011909842491, 89.06526759266853, 85.87628871202469, 84.0613541007042, 85.95851629972458, 84.79306563735008, 87.0111434161663, 86.73060446977615, 86.12807840108871, 84.06369477510452, 85.04778876900673, 84.38451915979385, 86.75961971282959, 84.25802394747734, 86.20706096291542, 82.87994429469109, 92.75041624903679, 83.54822963476181, 13.451557494699955, 0.09113615029491484, 0.08925663903937675, 4.7724660113453865, 55.25146722793579, 92.08140134811401, 88.06337535381317, 83.56706902384758, 82.41425648331642, 80.64661413431168, 78.672886043787, 77.82218009233475, 80.43926686048508, 77.09557548165321, 76.05421856045723, 74.18479487299919, 77.87500485777855, 79.91095080971718, 79.96752977371216, 80.0827319920063, 79.6421380341053, 80.89765906333923, 74.37536984682083, 81.36623471975327, 87.11951360106468, 82.04674780368805, 76.2697733938694, 73.69639188051224, 72.68798679113388, 82.66308233141899, 86.94748923182487, 87.96061366796494, 81.51737540960312, 83.48929479718208, 80.90156525373459, 71.0804982483387, 60.93834847211838, 36.77843168377876, 11.09372891485691, 0.5475597025360912, 1.0150593635626137, 2.309029223397374, 1.1132149840705097, 0.009965122990251984, 0.08822606308967806, 0.05391190046793781, 0.0899289951485116, 0.04121009122172836, 0.09593043912900612, 0.44774045411031693, 0.08382378407986835, 3.0291789304465055, 27.239396944642067, 35.46398341655731, 28.403230793774128, 25.493694618344307, 46.72660946846008, 57.28359438478947, 30.855098627507687, 34.92847815155983, 45.762133821845055, 53.66213031113148, 65.6837010383606, 54.775546565651894, 10.146607886999846, 0.3409136988921091, 0.047240864878403954, 0.021916476216574665, 0.01907947942527244, 0.06897687489981763, 0.07676452732994221, 0.01874944820883684, 0.04634843600797467, 0.033057446853490546, 0.04278372631233651, 0.048788817948661745, 0.08143344515701756, 0.01087915021344088, 0.12035135019687004, 0.09250030678231269, 0.05784220324130729, 0.06891385171911679, 0.017269921154365875, 0.048366636110586114, 0.03508670495648403, 0.018810103938449174, 0.026907059400400613, 0.03618777009251062, 0.008410096324951155, 0.05915395297051873, 0.049488232762087137, 0.06090002236305736, 0.024775674355623778, 0.06251372600672767, 0.06451842273236252, 0.04718507763755042, 0.032466478369315155, 0.022618839211645536, 0.016169054542842787, 0.06513931090012193, 0.050953317622770555, 0.03661871298390906, 0.07192980629042722, 0.09421627837582491, 0.0033310614298898145, 0.06861303700134158, 0.04670447022363078, 0.07317687413888052, 0.07165923409047537, 0.024794808778096922, 0.011788884112320375, 0.023097442826838233, 0.06396681405021809, 0.09118394460529089, 0.34064474457409233, 9.415929894894361, 53.629224076867104, 80.44775560498238, 90.46388894319534, 90.20096585154533, 81.0662180185318, 75.99724441766739, 62.091932371258736, 35.11909872293472, 63.18990245461464, 50.29414303600788, 94.05370071530342, 103.00507798790932, 54.48391981422901, 41.47341035306454, 6.630083257332444, 0.14983547473093495, 0.1214782494935207, 0.029526898215408437, 0.10566467070020735, 0.28469437966123223, 0.04628711976693012, 0.31392701261211187, 0.03457205151789822, 0.4903760366141796, 0.9013911942020059, 2.7830169769003987, 20.058690458536148, 65.7761500775814, 106.46754339337349, 99.609375, 98.45493614673615, 98.18294674158096, 100.18895789980888, 101.91392853856087, 98.35695460438728, 98.5666273534298, 95.1965805888176, 95.46193554997444, 89.34784322977066, 88.16461712121964, 93.22047382593155, 91.08754187822342, 102.50937178730965, 93.48916500806808, 91.7849488556385, 89.4168171286583, 92.74799957871437, 88.93551215529442, 90.0153686106205, 90.56123971939087, 90.95123559236526, 89.39869210124016, 88.23468536138535, 89.61056873202324, 90.98832160234451, 87.49607339501381, 90.79635590314865, 91.35562509298325, 97.5351271033287, 93.98699149489403, 23.006030805408955, 0.2983842435060069, 0.33580309187527746, 9.824584666639566, 65.84833860397339, 95.79368054866791, 92.58716180920601, 89.70859587192535, 87.50856712460518, 86.09277829527855, 81.78262397646904, 83.94818097352982, 83.84120151400566, 82.36963927745819, 82.54145845770836, 82.67585724592209, 84.66001197695732, 84.45714846253395, 85.61748459935188, 86.16209417581558, 85.67631304264069, 83.93328577280045, 80.05086690187454, 86.2036183476448, 92.11483955383301, 88.48557829856873, 84.41180929541588, 83.65099892020226, 79.63024467229843, 86.08867451548576, 89.5757170021534, 89.56725105643272, 83.49050313234329, 89.12762984633446, 91.81185901165009, 82.73456409573555, 73.9059430360794, 52.40264989435673, 22.90430076420307, 2.317343889735639, 0.1303181634284556, 0.44765979750081897, 0.4602260497631505, 0.8101497776806355, 0.7394088548608124, 0.3528639388969168, 0.037225541163934395, 0.08495812711771578, 0.059928053815383464, 0.3859788354020566, 0.04191770305624232, 2.4302455689758062, 28.837087713181973, 35.82244858145714, 23.269090689718723, 17.128675282001495, 40.19839257001877, 40.515740141272545, 26.525483652949333, 53.465551659464836, 64.2338964343071, 75.47369331121445, 78.74604731798172, 69.5550549030304, 20.830877423286438, 0.5298006429802626, 0.09720938964164816, 0.07091037739883177, 0.040567625110270455, 0.05407446049503051, 0.02548273143474944, 0.019046255329158157, 0.050140651073888876, 0.041883478916133754, 0.0287011197724496, 0.025166227715089917, 0.09683643816970289, 0.08692030620295554, 0.018902300944318995, 0.03161111977533437, 0.02141160799510544, 0.06712162445182912, 0.06431728586903773, 0.019225033138354775, 0.019954295275965706, 0.016650977413519286, 0.05402925256930757, 0.07115270345821045, 0.04789229613379575, 0.012490145945776021, 0.03652466803032439, 0.1604848337592557, 0.20551691501168534, 0.10710920178098604, 0.22789940616348758, 0.1632652900298126, 0.1403987404773943, 0.216020887310151, 0.20145092537859455, 0.2801096288021654, 0.10982135820086114, 0.16406443464802578, 0.10169527158723213, 0.21392978233052418, 0.07968240708578378, 0.16508518456248567, 0.15279551589628682, 0.23149888176703826, 0.14439381047850475, 0.1569507858948782, 0.12305713156820275, 0.2521619206527248, 0.17156805231934413, 0.20722033688798547, 0.3298872249433771, 9.87273758277297, 60.554401874542236, 97.6288528740406, 105.01054957509041, 96.05892911553383, 86.51371970772743, 87.68204301595688, 69.60407227277756, 84.58738267421722, 115.63869327306747, 56.697282046079636, 105.95373496413231, 124.50377717614174, 74.78244200348854, 56.53861775994301, 15.17740873619914, 0.9786121943034232, 0.24934095796197653, 0.17136832553660497, 0.1114665437489748, 0.5422770953737199, 0.2350860822480172, 0.43422282789833844, 0.3495192574337125, 1.0834693489596248, 0.9857571171596646, 1.6227683541364968, 15.533435381948948, 59.04623240232468, 108.73728320002556, 104.51410621404648, 101.20705246925354, 101.63721218705177, 102.23759517073631, 105.99902093410492, 102.47272655367851, 104.11687552928925, 97.16207832098007, 96.75188273191452, 96.65192529559135, 93.19069102406502, 97.01300472021103, 94.35065478086472, 103.75278666615486, 96.51792168617249, 93.96013453602791, 94.36282932758331, 93.9685320854187, 89.98636096715927, 92.84062340855598, 93.87336239218712, 95.94213098287582, 90.37762597203255, 92.67575025558472, 91.90176978707314, 92.41274356842041, 92.40006744861603, 93.26154202222824, 93.17977041006088, 99.97423902153969, 94.71220538020134, 19.588019214570522, 0.43150285666342825, 0.5369933601468801, 7.168075013905764, 63.15405137836933, 97.92396023869514, 98.90547797083855, 92.72275373339653, 89.3322716653347, 87.50803515315056, 87.42364168167114, 87.8306682407856, 89.00516241788864, 87.65319496393204, 85.86590766906738, 84.1743752360344, 89.87315744161606, 87.68784910440445, 87.75622263550758, 88.2226400077343, 87.20693171024323, 84.57428097724915, 77.99569398164749, 87.2756852209568, 95.0710429251194, 91.88478469848633, 88.8271951675415, 86.80634200572968, 80.29834002256393, 85.46552315354347, 92.4664194881916, 93.98792624473572, 87.66375839710236, 94.77785065770149, 95.76903507113457, 81.60889729857445, 71.57599925994873, 45.01467972993851, 15.514954123646021, 0.9273531823419034, 5.311768222600222, 5.877435794100165, 3.164711957797408, 0.6129835231695324, 0.37695123231969774, 0.32663534162566066, 0.2061129783396609, 0.2844580798409879, 0.29955122619867325, 0.8217516238801181, 0.14334425039123744, 7.197063183411956, 41.78425267338753, 48.72852444648743, 38.89395296573639, 38.41249980032444, 64.345633238554, 80.34788176417351, 49.54243317246437, 47.932109981775284, 61.77291288971901, 71.04088917374611, 83.85799661278725, 81.76042556762695, 22.252878919243813, 0.8732111938297749, 0.12351557103102095, 0.13829314877511933, 0.15399458905449137, 0.20858103496721014, 0.20336116896942258, 0.1320851279888302, 0.08088969581876881, 0.11045795021345839, 0.1835823990404606, 0.09883093036478385, 0.15703482669778168, 0.10768518259283155, 0.19974486145656556, 0.1734792161732912, 0.11633322908892296, 0.18729761999566108, 0.08100158942397684, 0.13989026541821659, 0.13426389545202255, 0.1135713116673287, 0.11442438073572703, 0.14411212090635672, 0.1390827790601179, 0.11729701174772345, 0.10250458362861536], [0.014928687360225013, 0.02148774678062182, 0.05280090910673607, 0.027478206975501962, 0.02836012889019912, 0.03298118004749995, 0.03220547616365366, 0.010139587993762689, 0.02696663716051262, 0.058785298533621244, 0.0904645660193637, 0.0765109651547391, 0.10020682020694949, 0.06284186660195701, 0.06126012354798149, 0.027853865431097802, 0.05733771722589154, 0.04511748018558137, 0.05984273651847616, 0.04682201899413485, 0.04742956705740653, 0.06089819667977281, 0.2586298860842362, 8.151037618517876, 41.73736318945885, 77.36673653125763, 73.61101046204567, 68.09973299503326, 52.36347399652004, 53.921416997909546, 59.67925563454628, 32.27945789694786, 57.57877394556999, 52.59564533829689, 82.20927268266678, 65.12705370783806, 34.19714279472828, 40.999799966812134, 16.83128423988819, 1.5062918979674578, 0.19068399531533942, 0.07678292517084628, 0.12497728283051401, 0.1044495300448034, 0.047037972835823894, 0.21030455420259386, 0.03609654901083559, 0.5196608870755881, 1.7807574640028179, 14.126750864088535, 47.63354480266571, 81.60379037261009, 100.37633344531059, 95.83461955189705, 94.12595763802528, 97.58919820189476, 95.34269794821739, 94.7655925154686, 89.50630232691765, 89.92271438241005, 90.66875874996185, 92.12201356887817, 89.8372645676136, 88.41726556420326, 85.00650018453598, 85.90746223926544, 86.37234449386597, 93.01700234413147, 86.08944967389107, 91.11091062426567, 90.65772414207458, 91.93621873855591, 89.28602054715157, 85.30671447515488, 79.79608297348022, 79.48756232857704, 76.89411789178848, 77.9586611688137, 79.36892509460449, 83.65082412958145, 86.44762605428696, 82.9518972337246, 81.23656287789345, 84.88872170448303, 94.61410224437714, 61.23887434601784, 6.210877876728773, 4.630870884284377, 41.03948883712292, 81.34374752640724, 84.40403491258621, 84.66169908642769, 81.31924644112587, 80.12799516320229, 81.61543294787407, 81.46116882562637, 79.99857410788536, 77.07970753312111, 77.29299008846283, 79.49268445372581, 79.05933290719986, 79.58774015307426, 77.67063662409782, 81.52103841304779, 81.8994677066803, 84.43298175930977, 81.37556701898575, 85.1795656979084, 81.5633225440979, 81.85689479112625, 80.02058252692223, 73.16397204995155, 73.23915481567383, 77.07305788993835, 80.78441753983498, 81.55798003077507, 77.17923179268837, 79.64032933115959, 73.18484053015709, 74.04696106910706, 75.21681189537048, 76.62029698491096, 81.48833736777306, 77.05447688698769, 47.57909752428532, 9.552200082689524, 0.5337486905045807, 3.278090273961425, 0.6752130808308721, 0.71091543068178, 1.0104428487829864, 0.12789237953256816, 0.03080746846535476, 0.0265340726764407, 0.10209157844656147, 0.06737264106050134, 0.11830489282147028, 11.668871752917767, 33.6735574901104, 35.04505589604378, 34.89787079393864, 32.58072093129158, 51.64156213402748, 39.32120203971863, 31.20462477207184, 35.170825347304344, 43.795458152890205, 61.51053696870804, 58.638799265027046, 50.98829738795757, 11.28438463434577, 0.5436828418169171, 0.023993139002413955, 0.02527080931031378, 0.01913618321850663, 0.018664464878384024, 0.04221660303301178, 0.15167837584158406, 0.05065319681307301, 0.00893594320586999, 0.011397139605833218, 0.013665657770616235, 0.007969974922161782, 0.02951189198938664, 0.11853075804538094, 0.032465973708895035, 0.02995920665853191, 0.033638210807112046, 0.05814172291138675, 0.020625870274670888, 0.03153749872581102, 0.026321042896597646, 0.06155709765153006, 0.04293120218790136, 0.029251589257910382, 0.065129202848766, 0.022009398671798408, 0.07609807871631347, 0.058474101169849746, 0.07633577377418987, 0.03334455039293971, 0.10193019843427464, 0.03451661679719109, 0.03791583869315218, 0.05761418949987274, 0.07854613446397707, 0.023933383126859553, 0.03166059876093641, 0.08492024790029973, 0.03390220015717205, 0.025056892663997132, 0.06995039453613572, 0.11575813143281266, 0.07336278955335729, 0.07824615837307647, 0.0045956516169098904, 0.04143998630752321, 0.06485836347565055, 0.4234284086851403, 15.442978385835886, 58.76053713262081, 95.68918615579605, 90.86358949542046, 92.71482735872269, 78.05947735905647, 75.01903250813484, 67.89474919438362, 24.26810648292303, 46.81995905935764, 64.74468782544136, 92.75309130549431, 62.75475360453129, 37.54598669707775, 45.29716037213802, 14.09776221960783, 0.5704821506515145, 0.2016410932992585, 0.1158656389452517, 0.17926311440533027, 0.18785406748065725, 0.0885518139693886, 0.1707683436688967, 0.2023837753222324, 0.8274648548103869, 3.806011858396232, 22.392456829547882, 66.64663776755333, 99.11362320184708, 107.9257607460022, 99.09922197461128, 101.00632444024086, 105.87379485368729, 98.20229530334473, 97.1967476606369, 93.73637974262238, 97.24822729825974, 97.65623420476913, 96.75845637917519, 93.85479658842087, 94.19537991285324, 89.61737036705017, 89.31230753660202, 91.40171661973, 93.9517217874527, 91.14973694086075, 96.91996291279793, 99.49234887957573, 95.17920792102814, 94.21124026179314, 89.73653957247734, 84.25329700112343, 81.97265937924385, 79.2916752398014, 81.29732921719551, 82.93820276856422, 87.78698578476906, 90.08473008871078, 87.66100734472275, 86.66364446282387, 91.06104210019112, 97.94068694114685, 76.08279302716255, 11.313566118478775, 8.708566501736641, 51.68812483549118, 89.14665922522545, 88.63662019371986, 87.55981117486954, 85.02182856202126, 85.62321469187737, 86.35473623871803, 85.16093909740448, 85.14541313052177, 81.79884150624275, 79.49941009283066, 81.23635768890381, 81.79040595889091, 84.42171916365623, 81.67489215731621, 84.68990877270699, 86.41654372215271, 90.00830858945847, 88.60974043607712, 90.75502172112465, 86.46479353308678, 84.19199109077454, 83.00431162118912, 79.15602251887321, 76.57992035150528, 80.01529321074486, 87.73375824093819, 86.85503259301186, 82.25264355540276, 85.50197079777718, 81.09495207667351, 75.60594901442528, 78.28419730067253, 81.14149957895279, 86.30695760250092, 86.50729805231094, 67.16396480798721, 20.869274362921715, 1.930852378718555, 1.4362845732830465, 1.256762018892914, 1.7455604276619852, 2.649686406366527, 1.069879496935755, 0.3409759502392262, 0.07895128772361204, 0.12039064691634849, 0.07610685090185143, 0.07904126570792869, 10.844653230160475, 33.54543596506119, 32.05373480916023, 26.14838808774948, 24.980982430279255, 39.29782949388027, 19.109928868710995, 31.754755452275276, 46.89287334680557, 59.80667419731617, 86.55180126428604, 69.55149829387665, 70.8524040877819, 24.82634212821722, 1.8751461803913116, 0.06936271005542949, 0.10324908391339704, 0.048338371416321024, 0.09072461456526071, 0.07036417155177332, 0.10647311442880891, 0.002083492167912482, 0.05647384619805962, 0.04277952575648669, 0.016780367150204256, 0.029756535404885653, 0.11073811838286929, 0.03355683802510612, 0.026929919404210523, 0.0573694848571904, 0.05815466967760585, 0.04640667233616114, 0.07299403863726184, 0.026195310092589352, 0.021188353275647387, 0.1058825058862567, 0.04511894592724275, 0.05124614683154505, 0.02723125733609777, 0.07932166394311935, 0.1231136238493491, 0.23706723062787205, 0.14959917491069064, 0.12947760696988553, 0.17835732316598296, 0.09744279508595355, 0.14380261563928798, 0.16557519498746842, 0.15462927374755964, 0.1528635114664212, 0.15145653305808082, 0.23247216391609982, 0.13355366012547165, 0.17433075641747564, 0.09897564916172996, 0.2461390508688055, 0.13380600517848507, 0.14663088106317446, 0.10334767081076279, 0.25722087419126183, 0.17216381878824905, 0.44793795445002615, 15.691030025482178, 71.05506241321564, 112.08569392561913, 100.86836904287338, 95.19104048609734, 77.42437943816185, 75.48286601901054, 85.72238937020302, 51.92663423717022, 96.35674953460693, 71.87514200806618, 106.9120891392231, 81.64026081562042, 51.27964675426483, 61.5699277818203, 25.43466478586197, 2.3072559060528874, 0.3101257322123274, 0.4039273801026866, 0.26424815179780126, 0.4184814600739628, 0.16568577499128878, 0.5488104885444045, 0.731131830252707, 1.233208745252341, 2.8698936151340604, 18.28088365495205, 60.08274458348751, 96.57998755574226, 110.7931324839592, 102.78706088662148, 103.3923228085041, 108.65029066801071, 102.1643503010273, 102.77432397007942, 98.37516322731972, 100.95153898000717, 102.08249509334564, 99.07396093010902, 94.79358181357384, 94.94383335113525, 89.53725546598434, 95.22653058171272, 93.27126950025558, 96.28696247935295, 92.15919077396393, 98.09187322854996, 101.4367425441742, 96.78424179553986, 99.16745111346245, 93.10987696051598, 87.13090538978577, 86.60335689783096, 84.37590882182121, 88.09858426451683, 87.3493480682373, 94.38372060656548, 93.51182699203491, 91.07927352190018, 88.46160158514977, 92.85202279686928, 100.73925197124481, 72.8694574534893, 8.544709794223309, 6.505951043218374, 52.6309834420681, 86.55755415558815, 92.34547957777977, 88.75732451677322, 85.3563018143177, 88.17689806222916, 88.76284942030907, 89.80585545301437, 86.71351298689842, 83.62826853990555, 81.79830193519592, 84.22424376010895, 85.12050166726112, 85.75164780020714, 83.09012621641159, 87.43150725960732, 87.21124067902565, 94.27120864391327, 91.31638079881668, 93.45312014222145, 90.13525977730751, 87.51194134354591, 81.97847306728363, 79.47813123464584, 78.11265930533409, 81.4976316690445, 88.46581175923347, 88.6811538040638, 84.24404069781303, 88.08129519224167, 80.68328216671944, 78.34828466176987, 80.94027757644653, 86.89376011490822, 91.3118514418602, 92.51897066831589, 65.2875266969204, 13.823476787656546, 2.906456203199923, 9.904443081468344, 3.093874021433294, 2.4147471506148577, 1.8542468268424273, 0.34361683821771294, 0.2087046322412789, 0.21431246335851029, 0.19402092875679955, 0.21587858791463077, 0.4840180277824402, 22.703865319490433, 50.684625282883644, 46.943752616643906, 49.16165940463543, 48.88539142906666, 69.17959704995155, 57.89392523467541, 46.17810510098934, 49.88193355500698, 59.69792403280735, 83.38527157902718, 76.47674828767776, 81.23830318450928, 28.651393577456474, 2.0436217775568366, 0.1774253637995571, 0.1710474950959906, 0.16090475575765595, 0.15901129954727367, 0.15946372761391103, 0.21481458563357592, 0.12444823543773964, 0.18764417327474803, 0.0904809452185873, 0.0748040848702658, 0.13388336665229872, 0.1541086719953455, 0.18590220424812287, 0.1586390531156212, 0.1370788912754506, 0.18579723488073796, 0.2854439488146454, 0.17199214518768713, 0.10565218035480939, 0.0998119382711593, 0.3059795015724376, 0.1121978931769263, 0.1269893639255315, 0.17483164672739804], [0.033135917838080786, 0.01635688098758692, 0.09417313733138144, 0.03228545370802749, 0.02473500466294354, 0.026943406082864385, 0.026185120404988993, 0.031738698671688326, 0.040522869894630276, 0.02150003860151628, 0.027041248977184296, 0.009199524374707835, 0.018445818895997945, 0.03121614507108461, 0.030376790891750716, 0.0313336456019897, 0.03307294289697893, 0.04100921782082878, 0.03454678510024678, 0.02032114629400894, 0.10950357056572102, 0.1238198515784461, 15.284903068095446, 47.77857542037964, 66.2168276309967, 70.75626164674759, 67.03282624483109, 73.21808874607086, 65.48129349946976, 38.678721114993095, 38.90051521360874, 48.323500379920006, 39.433979988098145, 58.96493576467037, 31.433885470032692, 31.621464304625988, 40.68979360163212, 14.527230374515057, 1.5427435794845223, 0.06614146259380504, 0.032897276541916654, 0.08010128265595995, 0.06661276347585954, 0.26636155089363456, 0.4805450438288972, 0.10492731729755178, 0.34410831809509546, 5.107544856145978, 31.811657398939133, 78.27446982264519, 100.2742101252079, 101.59337013959885, 96.28397583961487, 97.89527177810669, 94.20744806528091, 91.13757759332657, 88.23314264416695, 88.86966168880463, 90.3245960175991, 94.4943630695343, 93.26287195086479, 95.16427472233772, 93.093431442976, 88.7860281765461, 83.56385439634323, 84.84587520360947, 90.46065911650658, 88.65649312734604, 95.29670521616936, 93.95983055233955, 90.29206976294518, 85.76012894511223, 84.94922205805779, 84.82570588588715, 81.74529477953911, 80.63343644142151, 78.2953990995884, 76.73057466745377, 76.70215979218483, 74.99484300613403, 80.8472053706646, 83.09851616621017, 80.92376366257668, 87.872344404459, 86.65696442127228, 87.65235900878906, 38.68188634514809, 22.702656984329224, 59.860186725854874, 85.64027577638626, 84.6653164923191, 85.02546116709709, 84.61775064468384, 83.2343664765358, 80.22150054574013, 78.0433738231659, 80.14086127281189, 78.54981824755669, 76.6323271393776, 76.42121806740761, 75.90711325407028, 78.0596749484539, 80.96977159380913, 79.80689719319344, 80.7580317556858, 79.10184502601624, 84.29564952850342, 83.8027323782444, 83.51717010140419, 79.76152002811432, 81.38943627476692, 81.53434529900551, 72.09894239902496, 75.347600877285, 78.29513311386108, 81.56333774328232, 78.23833376169205, 78.30281630158424, 77.61786505579948, 79.85258594155312, 76.2401881814003, 76.09455719590187, 70.80622136592865, 70.0142602622509, 78.35717618465424, 81.56163543462753, 29.521731175482273, 0.02813141567457933, 1.4742647227831185, 1.4656575908884406, 0.6042588350828737, 0.988352318527177, 0.23576403415063396, 0.1523205265402794, 0.15277366706868634, 0.06200925854500383, 0.11919841635972261, 0.374606431578286, 11.506816148757935, 29.485783204436302, 29.740021862089634, 29.20450519770384, 41.85253880918026, 52.996539026498795, 33.853857815265656, 35.602630376815796, 36.37050077319145, 40.383210852742195, 57.43265278637409, 63.61884243786335, 63.5214726626873, 23.75425435602665, 1.253910984378308, 0.042937688558595255, 0.07055304071400315, 0.049644209939287975, 0.009605895684217103, 0.013572507104981923, 0.022164535366755445, 0.04819371199118905, 0.0128195843717549, 0.04532165243290365, 0.03607943137467373, 0.05858166434336454, 0.12633741687750444, 0.027854640975419898, 0.12525342113804072, 0.09037858821102418, 0.023765284822729882, 0.02884098492359044, 0.07366724079474807, 0.0757710068137385, 0.04769328923430294, 0.07175545353675261, 0.09656096779508516, 0.14778502460103482, 0.026365002158854622, 0.006230813996808138, 0.05314781119523104, 0.024429547811450902, 0.04555790772428736, 0.04445004822628107, 0.10203620680840686, 0.013897828466724604, 0.051188593279221095, 0.037664751580450684, 0.07847759712603875, 0.025909442229021806, 0.03701860812725499, 0.07464749171049334, 0.00879511975654168, 0.03153735029627569, 0.03284412021457683, 0.04819671768927947, 0.015487189666600898, 0.0365808597416617, 0.10773763759061694, 0.9153970645274967, 28.309125043451786, 69.69498619437218, 86.05325281620026, 89.53478559851646, 89.47746947407722, 93.51101383566856, 81.2445804476738, 55.809604078531265, 46.35031946003437, 29.039704240858555, 46.38129159808159, 74.64191794395447, 35.175499096512794, 40.08710414171219, 42.809251472353935, 10.15091210603714, 0.6469069747254252, 0.06858823442598805, 0.039169637821032666, 0.017545304326631594, 0.11155840678839013, 0.6185265944804996, 0.3814863780280575, 0.12508182175224647, 0.37887024809606373, 8.984427899122238, 45.559597089886665, 97.37489730119705, 106.7444421350956, 103.4142704308033, 102.10830330848694, 100.62870070338249, 97.04430744051933, 92.73451790213585, 92.04921707510948, 96.45422950387001, 97.24182844161987, 102.54759773612022, 96.34101077914238, 99.72670510411263, 94.28459912538528, 91.07876434922218, 87.02763453125954, 90.88834896683693, 92.49276727437973, 94.48267489671707, 96.52037635445595, 94.33094143867493, 92.73766413331032, 90.68670898675919, 90.31969428062439, 89.81138035655022, 87.31467112898827, 87.5345653295517, 84.59582582116127, 83.46873790025711, 80.05964443087578, 79.11603346467018, 87.1678926050663, 89.99592125415802, 86.536845266819, 90.92269912362099, 91.00308761000633, 94.1932824254036, 49.11917008459568, 29.264287389814854, 64.76862654089928, 91.15523144602776, 88.5969503223896, 90.10173037648201, 87.98427119851112, 87.30607599020004, 82.52246707677841, 80.82123756408691, 84.37653958797455, 83.78570929169655, 80.10388165712357, 80.76869398355484, 81.4242272078991, 81.77745625376701, 84.40159544348717, 82.8802938759327, 84.9947664141655, 82.88897261023521, 87.70078361034393, 86.84407398104668, 86.36972263455391, 82.75684610009193, 86.3759770989418, 88.07402998209, 77.5697672367096, 80.33315375447273, 82.89566025137901, 84.22805115580559, 81.53010472655296, 80.57086899876595, 82.13029012084007, 85.7498162984848, 84.16167631745338, 81.67271867394447, 76.40314623713493, 74.86423641443253, 83.53778019547462, 92.8055664896965, 49.70340773463249, 1.7550843791104853, 1.3576398370787501, 1.205398750025779, 0.872588858474046, 7.66029822640121, 1.645384265575558, 0.24243948922958225, 0.30540463398210704, 0.06551012498675846, 0.00938885088544339, 0.19046149944188073, 8.27645843848586, 28.717329539358616, 30.509902350604534, 28.733932748436928, 45.86999103426933, 44.83518876135349, 15.247929152101278, 35.97095601260662, 47.660329565405846, 54.78570722043514, 73.16728547215462, 77.74661734700203, 81.55300989747047, 45.597781240940094, 2.462957538664341, 0.04988932276319247, 0.13427381054498255, 0.05268193541269284, 0.033595978893572465, 0.011706136501743458, 0.05805047585454304, 0.016174069605767727, 0.051802512680296786, 0.07833740542992018, 0.03457378814346157, 0.05223717002081685, 0.04450797656318173, 0.06245840631891042, 0.10352548197261058, 0.01801440474082483, 0.06564434981555678, 0.019177131216565613, 0.0503319099516375, 0.041860620767693035, 0.07948521844809875, 0.113711607264122, 0.11522679822519422, 0.0792427959095221, 0.14747103676199913, 0.15919680678052828, 0.08797210757620633, 0.1328997389646247, 0.19175620574969798, 0.1225592840637546, 0.13232314959168434, 0.08781980403000489, 0.1097334582300391, 0.06001924521115143, 0.1507245231186971, 0.11712634746800177, 0.07037045754259452, 0.19921517581678927, 0.14530184300383553, 0.10219940508250147, 0.20605810394044966, 0.14802200719714165, 0.1005633405293338, 0.11132848201668821, 0.21025347959948704, 0.7116354920435697, 28.85371182113886, 82.3973473906517, 99.13206741213799, 95.49686327576637, 91.82141169905663, 99.32040810585022, 88.01213130354881, 56.8262243270874, 58.72153602540493, 78.35884049534798, 60.55834226310253, 79.1282232105732, 48.25568921864033, 46.45078606903553, 60.564896911382675, 22.133075147867203, 2.253620121628046, 0.133817924070172, 0.17379486642312258, 0.22410529491025954, 0.3364235570188612, 0.7030890975147486, 2.730063018389046, 0.5553639493882656, 0.576846927870065, 6.904479833319783, 40.015360191464424, 91.39790162444115, 111.8794333934784, 108.54324281215668, 106.17070332169533, 105.07602006196976, 102.34010607004166, 97.83563017845154, 97.07656770944595, 97.23334729671478, 99.74228426814079, 103.74014094471931, 97.70622432231903, 100.37500351667404, 98.59952598810196, 94.12866309285164, 91.68021887540817, 95.2713605761528, 97.34920307993889, 98.72974500060081, 99.22585397958755, 97.5031404197216, 97.14076906442642, 93.0360697209835, 91.50132447481155, 92.50790566205978, 88.63529786467552, 90.5192519724369, 85.56343629956245, 86.79901599884033, 82.7602431178093, 81.03542447090149, 90.80967038869858, 93.60334128141403, 89.19050887227058, 93.42498645186424, 95.05566135048866, 94.99241754412651, 49.73494604229927, 30.658605471253395, 66.42694875597954, 93.7650454044342, 91.5605328977108, 94.02872085571289, 93.0179750919342, 91.76509872078896, 87.53093272447586, 84.72789913415909, 86.77397534251213, 88.11597973108292, 85.82007452845573, 84.42676529288292, 84.87303614616394, 87.62353375554085, 88.04080456495285, 87.57450878620148, 89.06973615288734, 86.13187059760094, 92.51153066754341, 89.06855821609497, 87.21644639968872, 85.22548243403435, 90.1898780465126, 90.29959335923195, 78.62562417984009, 81.2994647026062, 84.23187375068665, 85.7470652461052, 83.5851788520813, 83.00682708621025, 84.5219273865223, 90.63392221927643, 86.96196645498276, 82.73657038807869, 79.86893266439438, 79.12377744913101, 90.0555020570755, 101.24866783618927, 42.113751992583275, 1.045376155525446, 6.415604241192341, 6.60917772911489, 1.4124271972104907, 4.185946583747864, 0.9186964156106114, 0.3882655705092475, 0.9034524648450315, 0.23706354957539588, 0.33159324433654547, 1.0052419966086745, 20.68094316869974, 46.23765930533409, 43.01437586545944, 42.68558330833912, 61.344835460186005, 74.46530342102051, 50.58015748858452, 52.72658251225948, 50.154652521014214, 58.391721323132515, 79.30054396390915, 84.20469760894775, 91.11406445503235, 50.45452482998371, 2.4288192205131054, 0.13974076719023287, 0.24706474650884047, 0.13808194838929921, 0.1759140839567408, 0.08932723954785615, 0.12965036410605535, 0.07986890137544833, 0.1564860381768085, 0.1543283328646794, 0.2156741707585752, 0.11300448895781301, 0.2997721190331504, 0.16301107476465404, 0.1710347004700452, 0.1227017912606243, 0.12313827057369053, 0.22244669875362888, 0.16309023223584518, 0.13921768666477874, 0.12752972164889798, 0.25854189705569297, 0.2342922514071688, 0.16725549154216424], [0.04523234980297275, 0.024591577202954795, 0.003419777763156162, 0.046252572792582214, 0.0361686968972208, 0.037617287525790744, 0.06083776359446347, 0.004166049693594687, 0.03218077377823647, 0.017270572388952132, 0.06194596448040102, 0.034453641856089234, 0.04437644201971125, 0.03998369589680806, 0.04735758244351018, 0.04943477957567666, 0.05756267702963669, 0.07963463503983803, 0.027838655114464927, 0.07926437014248222, 0.11492690377053805, 18.634279891848564, 60.62549605965614, 74.16831135749817, 81.6826057434082, 69.42645460367203, 58.03693816065788, 55.79552203416824, 71.6844530403614, 39.32025969028473, 27.708251886069775, 30.333365723490715, 37.91485570371151, 27.65275776386261, 31.327255591750145, 46.52260221540928, 16.03520605713129, 1.089299542363733, 0.12230965527123772, 0.18458532256772742, 0.039186139474622905, 0.15528895397437736, 0.17197241890244186, 0.7711227249819785, 0.13571969233453274, 0.11443737574154511, 9.575573578476906, 50.696340054273605, 90.38612231612206, 104.02316495776176, 95.37791445851326, 96.23232901096344, 93.39200422167778, 87.7279445528984, 85.40528878569603, 89.81326505541801, 94.63228806853294, 98.40037107467651, 96.75215631723404, 99.04963463544846, 96.76218777894974, 97.18249842524529, 90.02831071615219, 87.65532284975052, 84.35518473386765, 84.12663459777832, 86.03517338633537, 85.53358510136604, 88.75839605927467, 85.26824533939362, 88.96973311901093, 87.74254336953163, 87.07169696688652, 91.37794509530067, 89.74802255630493, 86.06953114271164, 84.77114081382751, 80.46421632170677, 74.55141440033913, 76.61858707666397, 79.78262409567833, 81.8523958325386, 84.37318816781044, 86.990647315979, 86.98291853070259, 83.48620176315308, 48.108089938759804, 29.398080110549927, 67.1896742284298, 84.32999208569527, 80.19443079829216, 81.13055616617203, 78.35479751229286, 76.61259859800339, 71.8678691983223, 74.79406177997589, 74.08842444419861, 74.32832077145576, 74.30370569229126, 77.05079108476639, 78.58509555459023, 78.90908136963844, 78.26516032218933, 81.49148359894753, 81.56575441360474, 79.82155680656433, 80.22992849349976, 80.06861194968224, 81.87020927667618, 78.91668856143951, 77.58550599217415, 77.84780591726303, 71.79821893572807, 76.54339671134949, 75.17632886767387, 79.31613072752953, 80.86176618933678, 76.34941712021828, 73.67514342069626, 71.72688156366348, 76.08670681715012, 74.65182781219482, 75.19775211811066, 74.81652617454529, 71.80995270609856, 70.36742091178894, 87.87114366889, 45.981667041778564, 1.1545494035817683, 1.1795642925426364, 1.8875282909721136, 1.6609434806741774, 1.0026295180432498, 0.27730324189178646, 0.3658458235440776, 0.07566923610283993, 0.05182645807508379, 0.0692531542154029, 0.4046013986226171, 15.616250038146973, 32.00136221945286, 35.10014533996582, 33.130308240652084, 35.74920371174812, 43.26451264321804, 28.20049077272415, 33.01752649247646, 41.875618770718575, 46.57584875822067, 56.86426788568497, 60.842886194586754, 62.95117646455765, 22.488378882408142, 2.5607374543324113, 0.03800843274802901, 0.04058439393702429, 0.050324733383604325, 0.07643927368917502, 0.05354643355531152, 0.08707978631719016, 0.026918534858850762, 0.038918936625123024, 0.03789156304264907, 0.050876349487225525, 0.03197522113623563, 0.039826278953114524, 0.024324947662535124, 0.013302203005878255, 0.04387394496006891, 0.08801303702057339, 0.02509392212232342, 0.1187426783144474, 0.033863790304167196, 0.021636102101183496, 0.024107585595629644, 0.04649791197152808, 0.06959196689422242, 0.02317718659469392, 0.04439811273186933, 0.029893593382439576, 0.05478298517118674, 0.03261635880335234, 0.013657386534760008, 0.04282307498215232, 0.043513661948964, 0.030266448375186883, 0.12742501945467666, 0.028851452916569542, 0.02092302434903104, 0.012254116081749089, 0.01907488924189238, 0.03579205324058421, 0.04684142244514078, 0.03900325944414362, 0.0685170921497047, 0.02557086703745881, 0.2303096791729331, 33.49901765584946, 79.99660581350327, 89.40642088651657, 96.35668113827705, 93.7726753950119, 75.45439034700394, 70.59792414307594, 85.49906775355339, 51.581084579229355, 24.536617174744606, 24.129030145704746, 50.90966820716858, 29.26996238529682, 38.069849386811256, 46.920547261834145, 14.138002060353756, 0.29576000932138413, 0.10845755794434808, 0.10961643638438545, 0.16250846267212182, 0.276336312526837, 0.6606985721737146, 0.8961532940156758, 0.22150881704874337, 0.38772730564232916, 17.227350287139416, 64.63179588317871, 103.03521037101746, 107.00456857681274, 101.94000273942947, 102.38263338804245, 94.36805784702301, 91.06435552239418, 93.4917488694191, 95.55094957351685, 99.75956574082375, 101.9483470916748, 99.93082255125046, 100.17823487520218, 99.41680133342743, 100.38739085197449, 97.09599986672401, 93.10288533568382, 90.43216824531555, 88.36007863283157, 88.31875205039978, 90.09296044707298, 89.87683564424515, 90.33312276005745, 93.15794438123703, 91.92664325237274, 91.43921300768852, 94.79763999581337, 93.65881830453873, 89.84632328152657, 87.41344302892685, 85.58289125561714, 76.88447400927544, 81.07226729393005, 84.39312189817429, 84.78211462497711, 86.33672520518303, 90.4623082280159, 91.33448302745819, 85.90392842888832, 52.48250640928745, 34.86832357943058, 71.73712581396103, 88.12958300113678, 83.64641636610031, 82.82032549381256, 79.63619515299797, 80.20842924714088, 76.54841244220734, 79.73194241523743, 78.34800347685814, 77.48253911733627, 78.38793933391571, 82.28390827775002, 82.49683365225792, 83.92490342259407, 83.33695337176323, 83.34110274910927, 85.00745013356209, 84.02824267745018, 84.8140101134777, 84.27310913801193, 86.98487922549248, 81.41973584890366, 78.98440092802048, 80.55699214339256, 75.98940163850784, 79.6358759701252, 79.57629516720772, 83.2389186322689, 85.5603052675724, 81.96562975645065, 78.5257351398468, 74.25652742385864, 76.61425530910492, 81.71674311161041, 81.81897282600403, 79.75800141692162, 77.16980069875717, 73.42157542705536, 91.21265396475792, 67.66133531928062, 3.932238472625613, 0.36816678650211543, 1.5278894640505314, 1.0146007756702602, 2.0368419913575053, 0.3985466016456485, 0.09316740106442012, 0.08119891906972043, 0.09141260772594251, 0.1787633670028299, 0.22306281491182745, 12.805922739207745, 31.24247834086418, 34.33808483183384, 40.168058797717094, 40.82186311483383, 30.551620312035084, 17.71756198257208, 40.61549238860607, 54.7715225815773, 62.02728644013405, 72.86241263151169, 71.12265318632126, 79.30355340242386, 39.567178040742874, 4.352593291550875, 0.009975018601835473, 0.02928074824012583, 0.014911606831446989, 0.03925925957446452, 0.07900338649051264, 0.05601304670562968, 0.011124060802103486, 0.03673138955491595, 0.038022945445845835, 0.0426137782051228, 0.030559348087990656, 0.0750776553468313, 0.04011605051346123, 0.044949008952244185, 0.0237986554930103, 0.16714085941202939, 0.0145262652040401, 0.031199060831568204, 0.018298272516403813, 0.06819870337494649, 0.04533628758508712, 0.031787791740498506, 0.128976211999543, 0.07838051678845659, 0.12505126011092216, 0.1622304689954035, 0.1420173200313002, 0.12538374227005988, 0.13184205978177488, 0.13796799903502688, 0.11763770948164165, 0.10205243015661836, 0.2277210829197429, 0.15094730100827292, 0.10343489542719908, 0.08831133585772477, 0.1253665392869152, 0.12235077025252394, 0.14360217639477924, 0.14546869264449924, 0.19599890074459836, 0.20073331310413778, 0.5923781788442284, 33.83189119398594, 94.42151337862015, 100.98674029111862, 107.73001044988632, 94.86553475260735, 82.30118975043297, 76.70940220355988, 92.83851832151413, 64.67014342546463, 44.905602782964706, 45.18416963517666, 57.43663117289543, 42.264710292220116, 49.36960704624653, 69.50929015874863, 26.97326112538576, 1.4835072518326342, 0.1811110769631341, 0.312727345735766, 0.41478675208054483, 0.36173889704514295, 1.3854186027310789, 3.0334275774657726, 1.4892373443581164, 0.6182055710814893, 12.537443395704031, 58.789696767926216, 101.56576842069626, 111.70271247625351, 104.26733985543251, 104.58378687500954, 98.39691326022148, 95.1349250972271, 93.93794372677803, 99.4717463850975, 100.19217252731323, 103.44460040330887, 102.3647591471672, 105.04341781139374, 102.7132460474968, 105.42199909687042, 102.2921222448349, 95.76126828789711, 98.43776866793633, 93.91334384679794, 90.84560886025429, 91.8238739669323, 92.92209103703499, 94.22729060053825, 95.91694593429565, 94.24565881490707, 95.83471074700356, 97.28765398263931, 95.1034627854824, 92.56161957979202, 91.4244470000267, 88.70098114013672, 82.82587319612503, 85.72129502892494, 88.05861800909042, 87.51567274332047, 90.7639892399311, 91.60114511847496, 94.47244584560394, 87.58457824587822, 60.86327210068703, 46.814532950520515, 71.92263945937157, 92.84052461385727, 88.79996582865715, 86.85477420687675, 82.79173582792282, 83.69799479842186, 77.63368740677834, 84.95255067944527, 81.46239995956421, 82.16046810150146, 80.12514531612396, 83.3452521264553, 83.5810598731041, 84.22278463840485, 85.16964063048363, 86.05884611606598, 85.04597246646881, 87.15173587203026, 87.15610563755035, 86.59584850072861, 91.452147513628, 82.20118671655655, 82.11645126342773, 81.5376815199852, 77.71743491292, 84.61744666099548, 84.41463634371758, 85.45031636953354, 88.03705036640167, 84.23754304647446, 80.15645563602448, 75.67953586578369, 81.64423540234566, 85.7836040854454, 85.56228116154671, 82.56488040089607, 82.12718188762665, 76.38362288475037, 104.15075451135635, 58.73597905039787, 1.7016198229975998, 5.115561950951815, 8.181138653308153, 3.6999792605638504, 2.0090533699840307, 0.6206860661040992, 0.4423718765610829, 0.1987779320916161, 0.2999413287034258, 0.23694366303971037, 0.9207122074440122, 26.711001098155975, 48.393978998064995, 48.22427250444889, 48.06322954595089, 50.376743003726006, 62.85073645412922, 47.50308260321617, 51.467094495892525, 60.31376838684082, 64.65516462922096, 80.72891011834145, 79.49282884597778, 94.72377955913544, 46.73308812081814, 4.053517514839768, 0.08024848764762282, 0.05999718858220149, 0.1417227170895785, 0.15399344614706933, 0.16935812949668616, 0.17390225519193336, 0.11894917348399758, 0.2501957933418453, 0.1569708387251012, 0.1186771689390298, 0.09665547288022935, 0.15155368018895388, 0.11392414351576008, 0.1850406450103037, 0.09160563291516155, 0.27695760887581855, 0.09869413770502433, 0.15000091429101303, 0.12016585780656897, 0.11395287947379984, 0.08432013244600967, 0.11327795553370379], [0.032580787665210664, 0.017077678930945694, 0.024256760989374015, 0.08523197961039841, 0.0473252878873609, 0.058657047993619926, 0.08801359363133088, 0.07238843129016459, 0.08067779039265588, 0.07162523630540818, 0.014582663789042272, 0.0434932343341643, 0.0528338790172711, 0.026254494514432736, 0.018280394178873394, 0.015868091395532247, 0.07128626777557656, 0.035115426071570255, 0.04939015423587989, 0.14371437428053468, 9.184810146689415, 53.654462322592735, 69.48803409934044, 74.05234917998314, 60.035695508122444, 49.165223613381386, 70.98355785012245, 55.662453174591064, 37.01640531420708, 47.85699561238289, 47.528100460767746, 48.14296826720238, 27.306429147720337, 29.5544246211648, 38.48565727472305, 23.125781379640102, 2.024112199433148, 0.07737872874713503, 0.1932528949691914, 0.08320333377923816, 0.04712724206910934, 0.07301983569050208, 0.6435916526243091, 0.30796344042755663, 0.0725072120258119, 9.788741189986467, 57.36420325934887, 92.56078362464905, 98.34126904606819, 94.63742539286613, 96.263168156147, 90.98794162273407, 92.52924531698227, 91.96303009986877, 92.36089155077934, 93.54593396186829, 93.40972647070885, 90.63250869512558, 94.14579257369041, 97.95900195837021, 92.48790353536606, 90.78514650464058, 91.63009196519852, 83.4601579606533, 79.58278521895409, 82.58169829845428, 88.52117478847504, 88.50780710577965, 86.59705683588982, 89.13562461733818, 90.06102696061134, 88.33340406417847, 87.5551450252533, 85.66804468631744, 85.1768146455288, 85.1492965221405, 82.81219393014908, 78.78387048840523, 72.60203540325165, 72.57384091615677, 79.62178632616997, 82.28249475359917, 82.7974659204483, 86.68557688593864, 79.56372544169426, 81.81451946496964, 49.414076060056686, 21.964728981256485, 71.48894593119621, 82.46590331196785, 82.4169011414051, 78.0200582742691, 77.91996404528618, 81.68229416012764, 76.51772528886795, 68.34748730063438, 71.33374705910683, 72.09740728139877, 77.58555918931961, 78.89399617910385, 80.03475576639175, 83.11674758791924, 83.3773148059845, 79.46356281638145, 80.65344616770744, 78.4745442867279, 80.37764176726341, 79.25225615501404, 78.05773705244064, 81.88054472208023, 80.20266115665436, 74.94505047798157, 78.0033391714096, 71.86193391680717, 73.206377774477, 79.51628878712654, 77.2750398516655, 77.76627749204636, 78.66489127278328, 78.24576616287231, 74.25591945648193, 76.84649124741554, 75.86885690689087, 75.84702327847481, 73.55543464422226, 73.72998967766762, 68.7188945710659, 84.61792543530464, 65.16090989112854, 2.9246610263362527, 0.34881068451795727, 12.494348958134651, 1.0571299935691059, 0.39016523107420653, 0.1183029187086504, 0.030625273066107184, 0.18783184757921845, 0.05273545168165583, 0.03743415145436302, 0.3518403391353786, 19.221815764904022, 37.28067733347416, 20.724120251834393, 22.17227764427662, 30.5858051776886, 35.61796635389328, 33.1544179469347, 32.9349759221077, 42.05499194562435, 58.2720847427845, 57.031903490424156, 56.43418416380882, 55.96211649477482, 30.570416003465652, 2.801913837902248, 0.03735612946911715, 0.04456152251805179, 0.03630891085776966, 0.10683390210033394, 0.047412942949449643, 0.03240880978410132, 0.032109008097904734, 0.015009184407972498, 0.06974710544454865, 0.02769879181869328, 0.04234784442814998, 0.06930874107638374, 0.07672250692849047, 0.03820528741925955, 0.018888023878389504, 0.030330302761285566, 0.032024948741309345, 0.047003982472233474, 0.04443560232175514, 0.026995517837349325, 0.06808568912674673, 0.02202163483161712, 0.05802905376185663, 0.03330315710627474, 0.10724399064201862, 0.015910803849692456, 0.05885196565941442, 0.0332346234790748, 0.004354937873358722, 0.11094510336988606, 0.09953007800504565, 0.025547038530930877, 0.04905150111881085, 0.01408343217917718, 0.02974823633849155, 0.026749536700663157, 0.01925268556078663, 0.06585566894500516, 0.08173030422767624, 0.033646908777882345, 0.022780011422582902, 18.061314336955547, 75.22888004779816, 82.06535160541534, 92.88967877626419, 85.66814348101616, 59.0261010825634, 86.64620339870453, 75.54184645414352, 50.64061604440212, 45.62186814844608, 32.115565091371536, 53.82949233055115, 28.664951249957085, 26.949898079037666, 41.984395533800125, 23.768165409564972, 1.3816857780329883, 0.02658963727299124, 0.1083153772924561, 0.11273055482888594, 0.2500383392907679, 0.08626125680166297, 0.5688718683086336, 0.31095491896849126, 0.24831495364196599, 17.41382908076048, 70.72160750627518, 100.05170926451683, 102.23710119724274, 99.27591249346733, 99.81298327445984, 93.15858274698257, 101.1027480661869, 95.9352457523346, 97.10321947932243, 97.11000591516495, 96.14605844020844, 94.7163699567318, 99.71248626708984, 101.1719423532486, 95.77877774834633, 94.94811192154884, 95.40619254112244, 88.84960636496544, 86.54974177479744, 87.98128455877304, 93.39148744940758, 93.03454220294952, 91.79487392306328, 93.66517156362534, 91.96518078446388, 91.9307242333889, 89.21028301119804, 89.41400527954102, 89.72573295235634, 90.09545311331749, 86.88605412840843, 82.40140557289124, 76.40247747302055, 77.73983851075172, 83.96804630756378, 86.6153110563755, 88.86096015572548, 90.67049905657768, 85.78091382980347, 84.68471065163612, 51.850946098566055, 27.115200608968735, 71.08467042446136, 89.68784138560295, 88.49523738026619, 82.3839721083641, 85.20199209451675, 85.2487675845623, 78.73947367072105, 71.45271107554436, 74.65417608618736, 76.27344399690628, 79.40265968441963, 82.64609724283218, 85.52923053503036, 87.1691769361496, 87.83626154065132, 85.50767809152603, 85.06068527698517, 82.82141223549843, 84.15910765528679, 83.05838271975517, 82.91469722986221, 83.99697035551071, 87.07037463784218, 80.35279110074043, 80.80541521310806, 75.69714412093163, 78.48129272460938, 82.5472341477871, 79.9348059296608, 79.28121820092201, 81.17946714162827, 81.70238748192787, 78.4709420800209, 79.70184803009033, 79.5238807797432, 80.76707527041435, 79.21698644757271, 79.7585941851139, 73.39945301413536, 87.54971891641617, 83.07784527540207, 7.858478492125869, 0.9001952083781362, 2.562890276312828, 1.4928635372780263, 1.7272450542077422, 0.9896346309687942, 0.03582342753361445, 0.30279470840469, 0.059298322958056815, 0.03294070702395402, 0.2569718984887004, 17.528905905783176, 33.79001744091511, 21.773582138121128, 25.83571046590805, 38.4466789662838, 22.986967228353024, 21.71307798475027, 39.62390139698982, 58.80248688161373, 78.75986337661743, 78.51349979639053, 71.89482495188713, 69.36845451593399, 48.599578365683556, 5.985376127064228, 0.1261866866843775, 0.08635832229629159, 0.05559114317293279, 0.031802664379938506, 0.04245675459969789, 0.0528071876760805, 0.029138558311387897, 0.050719889914034866, 0.05005037994123995, 0.04638853424694389, 0.057377028788323514, 0.023243976174853742, 0.05592848268861417, 0.025514593689877074, 0.09991301136324182, 0.022923522374185268, 0.011852410098072141, 0.005846823078172747, 0.06153651418571826, 0.04222369425406214, 0.03171386641042773, 0.0881839165231213, 0.1533427755930461, 0.14890657301293686, 0.2763044595485553, 0.103166364133358, 0.1599791640182957, 0.25553946441505104, 0.17315173608949408, 0.178139888739679, 0.16199920093640685, 0.11663633704301901, 0.19382421509362757, 0.12463824008591473, 0.10028219272498973, 0.1448815202456899, 0.0502396201773081, 0.14867990626953542, 0.1661786055774428, 0.13556001184042543, 0.21073039853945374, 19.444063939154148, 93.29034447669983, 97.47901931405067, 102.56591275334358, 85.77620968222618, 70.89835122227669, 91.16656243801117, 77.52622157335281, 53.409056290984154, 68.71238172054291, 68.77528354525566, 69.44730028510094, 40.7633538544178, 46.60388745367527, 60.47940529882908, 38.164810091257095, 3.8979640742763877, 0.14812400797381997, 0.4397400130983442, 0.16336828528437763, 0.22109624231234193, 0.13549591996707022, 2.0069995801895857, 1.5796215506270528, 0.3721626283368096, 12.842149045318365, 65.4197596013546, 101.77747026085854, 105.80988988280296, 104.3880669772625, 103.54043886065483, 98.7795527279377, 101.44754156470299, 98.09872046113014, 97.89409384131432, 99.12997752428055, 99.64151367545128, 98.13114792108536, 102.5253689289093, 106.27333581447601, 102.8182952105999, 100.85720524191856, 100.20633056759834, 95.39271086454391, 90.54515898227692, 91.25871509313583, 97.14368730783463, 95.4438941180706, 94.88222345709801, 97.19490855932236, 96.8065769970417, 97.24509626626968, 94.56275179982185, 94.38604608178139, 93.4820593893528, 93.80309656262398, 90.14248698949814, 86.171715259552, 80.32994672656059, 80.26744768023491, 87.47983306646347, 89.62992489337921, 91.80181995034218, 93.64132404327393, 88.38980063796043, 86.33302420377731, 59.7563648968935, 38.20362500846386, 76.02756679058075, 91.01659208536148, 91.35919690132141, 87.83371567726135, 86.48763790726662, 87.99186319112778, 84.2491552233696, 74.32683885097504, 79.56707686185837, 79.25790265202522, 84.2257484793663, 86.66017904877663, 87.22479835152626, 90.51192596554756, 92.68807679414749, 86.59163072705269, 87.96242237091064, 85.33191472291946, 84.10634368658066, 83.34400579333305, 83.56429517269135, 87.52131924033165, 90.13999432325363, 82.92443990707397, 83.86471465229988, 78.10731679201126, 81.05107203125954, 85.36604449152946, 84.18846487998962, 82.28179559111595, 87.1417424082756, 87.78834611177444, 81.66938245296478, 83.71542826294899, 83.87145549058914, 84.85865011811256, 83.21516990661621, 83.38761985301971, 75.50880342721939, 97.84359455108643, 79.3143980205059, 3.6896887002512813, 4.541804613545537, 28.947504088282585, 5.969388959929347, 1.7065349780023098, 0.8210686699021608, 0.18061241309624165, 1.019122889265418, 0.15398483723402023, 0.31815894646570086, 1.2245870078913867, 31.564607955515385, 55.79823888838291, 32.36348658800125, 38.5419512540102, 45.85217759013176, 51.936783492565155, 49.8183211684227, 44.57478113472462, 58.106383234262466, 76.1257915198803, 80.06838396191597, 76.14717677235603, 80.35618051886559, 55.816515907645226, 5.730943204835057, 0.1820617978228256, 0.15552489756373689, 0.09616123963496648, 0.20669831021223217, 0.2095619315514341, 0.11760414214222692, 0.10607207266730256, 0.1361702205031179, 0.14010112441610545, 0.05855714378412813, 0.15891474613454193, 0.17646318417973816, 0.22167416755110025, 0.19913163967430592, 0.19566760602174327, 0.1218467258149758, 0.13289645867189392, 0.08012875696294941, 0.16669037577230483, 0.20046244404511526, 0.17875826102681458], [0.05173565630684607, 0.027262306939519476, 0.024020759883569553, 0.1154146580665838, 0.03186050365911797, 0.056516464028391056, 0.12620234600035474, 0.006640158071604674, 0.050901471186080016, 0.05086603734525852, 0.06419642711989582, 0.09801064195926301, 0.02690058230655268, 0.04773985900101252, 0.041044280587811954, 0.01748167629557429, 0.09737328553455882, 0.0976839559734799, 0.09967050718842074, 0.9870926267467439, 39.741949662566185, 64.46072146296501, 66.22452601790428, 54.629983976483345, 48.71656648814678, 59.56317946314812, 43.70049364864826, 38.759755566716194, 43.31536911427975, 52.01741136610508, 49.77208524942398, 29.158736653625965, 25.90323854237795, 30.899934321641922, 32.79953218996525, 10.601678118109703, 0.12672515935264528, 0.12872897292254493, 0.032335804717149585, 0.1622032915474847, 0.3905875427881256, 0.0798873882740736, 0.24012480484088883, 0.6577957060653716, 7.024288829416037, 57.05712653696537, 86.56956151127815, 96.82274892926216, 94.58333909511566, 95.90008243918419, 90.08994340896606, 92.7076381444931, 98.1509980559349, 94.92751702666283, 94.04534116387367, 93.60387325286865, 90.40069073438644, 95.04290923476219, 96.61015793681145, 92.2024704515934, 89.11837354302406, 89.92752492427826, 88.24603915214539, 80.48316970467567, 86.523128002882, 88.00452411174774, 88.1716999411583, 84.60483133792877, 86.4271679520607, 85.61875373125076, 83.29169020056725, 86.19524359703064, 85.11531874537468, 83.84117871522903, 84.58932816982269, 80.57931214570999, 79.65442657470703, 78.37357610464096, 76.78340703248978, 69.3989060819149, 76.13372549414635, 81.9438949227333, 82.46018081903458, 80.8077634871006, 84.27181720733643, 82.25433066487312, 36.97743460536003, 20.208163037896156, 48.77545952796936, 87.71301135420799, 77.00114294886589, 80.49599781632423, 81.00968465209007, 80.03804638981819, 70.24667099118233, 70.9927685558796, 72.60963499546051, 71.16092473268509, 76.77488788962364, 76.41013786196709, 79.73391070961952, 79.85263153910637, 81.15459367632866, 83.4447991847992, 81.20974391698837, 79.51399371027946, 78.40284213423729, 81.27362608909607, 77.27733492851257, 79.10179942846298, 81.15959420800209, 75.89353278279305, 77.40232542157173, 78.16293820738792, 75.45481592416763, 80.3296047449112, 76.17438331246376, 75.27807980775833, 74.03081953525543, 70.93683555722237, 70.51166877150536, 69.22338590025902, 74.21561881899834, 78.5408279299736, 76.22643291950226, 71.6837690770626, 73.75708982348442, 70.31254425644875, 81.72099128365517, 77.3366117477417, 4.592800727114081, 0.9114536480046809, 1.9876818917691708, 0.7278470252640545, 0.06591447672690265, 0.09484694062848575, 0.05300483273458667, 0.13000361155718565, 0.08379537466680631, 0.04477524620597251, 1.33584646275267, 22.29909583926201, 37.64962613582611, 22.174983099102974, 19.713161699473858, 38.65871138870716, 45.68196952342987, 31.321056224405766, 24.108621440827847, 37.01583154499531, 43.24658140540123, 48.32690119743347, 63.37716780602932, 53.32520239055157, 35.771937891840935, 5.760375000536442, 0.26819438848178834, 0.06759568612324074, 0.01088588056518347, 0.03670247919217218, 0.012910516015836038, 0.05437724190414883, 0.06864305687486194, 0.016721321881050244, 0.018762586078082677, 0.02829344321071403, 0.025119437159446534, 0.017847692397481296, 0.04541731526842341, 0.04806575831025839, 0.07650250467122532, 0.039008643725537695, 0.0590007625578437, 0.05590237764408812, 0.05719192231481429, 0.06620527245104313, 0.054537950272788294, 0.05678124747646507, 0.024654301669215783, 0.045118656489648856, 0.04729183187009767, 0.07059166207909584, 0.04777550064318348, 0.005409538071035058, 0.049808988987933844, 0.025042949564522132, 0.06219996452273335, 0.038149763640831225, 0.028064885846106336, 0.015080797020345926, 0.13392967666732147, 0.030742819981242064, 0.020300933902035467, 0.06694334573694505, 0.07696007582126185, 2.200021385215223, 64.70371082425117, 80.94189628958702, 86.98148980736732, 73.09071198105812, 66.98245614767075, 79.65614408254623, 56.21519811451435, 47.80845321714878, 42.951960414648056, 40.87039791047573, 48.10976184904575, 38.09711292386055, 18.717725314199924, 29.20609161257744, 33.22564132511616, 7.893106509000063, 0.12593447521794587, 0.17673494381597266, 0.07377171292318963, 0.6279955082572997, 1.2502830103039742, 0.3921040176646784, 1.1894079018384218, 0.06758198607712984, 12.290570642799139, 68.70060235261917, 92.65245750546455, 103.50880935788155, 100.70479542016983, 99.03622895479202, 93.86985138058662, 100.63266009092331, 98.69390532374382, 97.56729617714882, 97.01382547616959, 98.80366623401642, 94.75414752960205, 100.53739920258522, 98.72751072049141, 93.91546413302422, 92.85098165273666, 96.03242933750153, 95.24616792798042, 88.5769709944725, 90.887041836977, 92.64908328652382, 91.96628272533417, 88.30571115016937, 88.84069964289665, 88.72596099972725, 89.6991191804409, 90.41486397385597, 87.76506096124649, 88.07554230093956, 87.74622917175293, 84.56760093569756, 82.19842046499252, 85.31309813261032, 81.72482147812843, 73.67656454443932, 80.65913826227188, 84.310043156147, 88.32384377717972, 83.31527173519135, 89.93117272853851, 79.53249111771584, 39.64581482112408, 31.684328131377697, 41.11179895699024, 88.22251081466675, 80.49259319901466, 83.46252143383026, 81.2278613448143, 86.08842372894287, 73.38989272713661, 76.18547111749649, 76.94237530231476, 77.66107633709908, 78.944541066885, 81.42799660563469, 81.9153280556202, 82.28045806288719, 84.04339626431465, 86.84297204017639, 83.99905264377594, 85.33874675631523, 81.94507285952568, 85.51320299506187, 82.23254263401031, 83.21964606642723, 82.70652160048485, 79.02467116713524, 80.27620241045952, 82.50691071152687, 80.98234131932259, 84.05145183205605, 82.69057765603065, 81.54447555541992, 77.88451954722404, 74.89495396614075, 74.8799903690815, 74.2007464170456, 77.09739938378334, 80.74531003832817, 81.85042753815651, 78.60461890697479, 80.4310593008995, 77.59578824043274, 84.13078397512436, 91.98399737477303, 11.241592280566692, 0.7504769484512508, 0.8786976244300604, 0.4305027978261933, 0.33797146927099675, 0.4616377630736679, 0.1365951297339052, 0.22228167479624972, 0.29381846194155514, 0.0534029133268632, 0.14757293363800272, 19.649249128997326, 35.81661209464073, 20.55696152150631, 23.045491687953472, 43.71809810400009, 30.07800992578268, 29.729739613831043, 36.225462555885315, 55.97946636378765, 57.780284732580185, 59.65636186301708, 76.21044337749481, 68.02792444825172, 54.892606884241104, 11.410764902830124, 0.2860291471006349, 0.05451812750834506, 0.06345796049572527, 0.04351583273091819, 0.03493961499771103, 0.04468857077881694, 0.07927155413199216, 0.10466677893418819, 0.07395734632154927, 0.10822375916177407, 0.028976428729947656, 0.017325587796221953, 0.06017856576363556, 0.01843044530687621, 0.04291268931410741, 0.03525673469994217, 0.022118577871879097, 0.03281048237113282, 0.045647206643479876, 0.1136640430195257, 0.18580530944745988, 0.12908524833619595, 0.12206133265863173, 0.1335571927484125, 0.18316508940188214, 0.17472641018684953, 0.23743725061649457, 0.12000528673524968, 0.13334061921341345, 0.1331143532297574, 0.13256842939881608, 0.14505528670269996, 0.06015125101839658, 0.1619027365813963, 0.13493405480403453, 0.10604260940453969, 0.15180541668087244, 0.23138563003158197, 0.2432678744662553, 2.602931815199554, 76.77672699093819, 105.37494242191315, 93.60406324267387, 79.89959701895714, 72.07632601261139, 82.44729951024055, 60.20203158259392, 56.0755480080843, 63.58852006494999, 68.04261445999146, 68.29156950116158, 43.986709490418434, 42.64244042336941, 43.523297756910324, 48.95023874938488, 18.524897061288357, 0.2993028442142531, 0.2974493452347815, 0.135394646495115, 0.37130506185349077, 1.3995209522545338, 1.7988321441225708, 1.6656377725303173, 1.564922514371574, 8.536261897534132, 64.87839505076408, 95.8763413131237, 108.58333066105843, 103.60972434282303, 103.89797687530518, 98.71914356946945, 101.84391349554062, 103.17653998732567, 101.52765646576881, 100.42694672942162, 103.50874096155167, 96.8916468322277, 103.30837771296501, 101.31541505455971, 102.1327131986618, 96.48439228534698, 100.33084228634834, 100.00918194651604, 93.62933948636055, 93.94981428980827, 97.97243043780327, 94.3858028948307, 89.7015130519867, 92.17849373817444, 93.60175296664238, 94.10946652293205, 95.45405477285385, 92.70186245441437, 91.89646527171135, 91.32186770439148, 87.90943801403046, 86.5883857011795, 90.3787051141262, 85.73533147573471, 78.64688023924828, 85.5708535015583, 88.97703632712364, 90.75873032212257, 85.81801503896713, 93.6931836605072, 84.08713951706886, 46.212519854307175, 32.398288920521736, 52.90497533977032, 91.76571428775787, 83.77677217125893, 85.53562939167023, 85.72650074958801, 88.08621972799301, 79.02364522218704, 79.5535571873188, 81.16511151194572, 78.67146492004395, 84.21160563826561, 83.97610187530518, 85.92301100492477, 84.87449526786804, 87.91610285639763, 87.84633100032806, 85.36869674921036, 89.34663489460945, 84.48895275592804, 88.49568575620651, 85.3886304795742, 85.02782464027405, 86.01305857300758, 79.89297777414322, 82.54044771194458, 88.45619827508926, 85.35480469465256, 87.62799471616745, 85.44422149658203, 85.23653984069824, 80.38703486323357, 76.60113841295242, 78.67947489023209, 76.91374763846397, 83.21950927376747, 87.19760701060295, 84.95551452040672, 81.07664465904236, 82.94300571084023, 78.97989436984062, 92.19600319862366, 92.45565846562386, 6.394046097993851, 4.658038951456547, 11.52614476159215, 1.262615961022675, 0.12617901287740096, 0.32293745724018663, 0.1663608622038737, 0.5645845702383667, 0.3032869304297492, 0.11858021476655267, 2.1708415634930134, 34.72711555659771, 53.11980441212654, 32.633899077773094, 32.665714770555496, 55.41151084005833, 63.85792940855026, 48.07237945497036, 39.01425451040268, 52.43791580200195, 59.44641932845116, 70.08074149489403, 83.97847294807434, 79.35278356075287, 63.56916390359402, 12.501193340867758, 0.49579888000153005, 0.1740325169521384, 0.09838713347562589, 0.12456533149816096, 0.09603212820366025, 0.1990404148818925, 0.13867731409845874, 0.19897509104339406, 0.17101178294979036, 0.24287146370625123, 0.16347110242350027, 0.09289734836784191, 0.18357554159592837, 0.1355511209112592, 0.10731004920671694, 0.10507401762879454, 0.09122138595557772, 0.1565570617094636, 0.13065538048977032, 0.265326522057876], [0.04343303131463472, 0.04369820439023897, 0.028547730835271068, 0.029210695065557957, 0.037211265953374095, 0.04183246739557944, 0.025052820128621534, 0.05610683190752752, 0.007252188243001001, 0.05284778315399308, 0.05111888334795367, 0.07782323809806257, 0.05613279223325662, 0.02865367612685077, 0.05697490349120926, 0.06136350843007676, 0.018889918210334145, 0.05428415061032865, 0.19248566270107403, 10.378944519907236, 60.15818953514099, 64.64800581336021, 61.43365569412708, 52.43074178695679, 50.43222762644291, 38.78481142222881, 40.81419512629509, 44.38210107386112, 51.672857254743576, 44.808126613497734, 34.78978559374809, 22.00306322425604, 30.96152901649475, 31.148906461894512, 11.220682952553034, 0.25134143186733127, 0.08637701699626632, 0.01567967494338518, 0.2234644503914751, 0.2923447941429913, 0.7896288007032126, 0.7890636997763067, 0.3714313160162419, 2.6371781900525093, 51.10043317079544, 81.07859015464783, 98.91301676630974, 97.46582642197609, 94.43367272615433, 93.16128060221672, 94.73929032683372, 98.16176667809486, 95.19274279475212, 92.90404960513115, 89.77437794208527, 92.76993200182915, 91.68642774224281, 94.04738545417786, 86.53258189558983, 85.51281541585922, 90.85680305957794, 93.14005494117737, 90.61612397432327, 82.17076554894447, 87.4399808049202, 84.02137264609337, 86.76969677209854, 84.46527242660522, 87.45904058218002, 82.62482598423958, 85.33259108662605, 83.54696050286293, 84.25488531589508, 82.3631264269352, 80.56481212377548, 78.05106461048126, 78.07181149721146, 73.72514873743057, 77.2282187640667, 71.26209810376167, 78.616633862257, 80.03312945365906, 84.79366600513458, 76.01546064019203, 84.88129690289497, 60.13591133058071, 38.41104447841644, 63.77910643815994, 22.835858836770058, 77.09600865840912, 81.01311206817627, 76.68949887156487, 76.0830058157444, 83.25840398669243, 73.24520409107208, 75.50180420279503, 68.62129300832748, 71.52583435177803, 71.67791739106178, 78.27681049704552, 76.35862022638321, 81.77072301506996, 78.73610705137253, 80.83778187632561, 76.81104674935341, 80.57103618979454, 76.73973977565765, 80.10654911398888, 77.97905087471008, 76.72759562730789, 74.75140526890755, 77.9974190890789, 73.90965163707733, 71.82537987828255, 77.10385143756866, 80.57759463787079, 81.67690604925156, 79.2929595708847, 78.01647886633873, 78.16479250788689, 71.66591003537178, 72.57089987397194, 69.945567548275, 72.65622049570084, 75.11756882071495, 79.23081770539284, 71.7370118200779, 76.8820421397686, 71.60037115216255, 79.57314133644104, 71.14588513970375, 9.865077193826437, 1.7989026778377593, 0.5502602888736874, 0.5446167010813951, 0.15050475834868848, 0.06768336344975978, 0.11709954109392129, 0.053126893762964755, 0.03601903168600984, 0.06665832392172888, 2.3240764159709215, 29.964289627969265, 35.25430306792259, 22.615514360368252, 22.73285586386919, 37.476659417152405, 34.923766404390335, 30.6974545866251, 24.610734097659588, 47.23565675318241, 49.148356318473816, 47.089983969926834, 59.80508208274841, 54.64013323187828, 40.724949315190315, 11.651458237320185, 0.09311315006925724, 0.03633032181824092, 0.0292016334424261, 0.049313134149997495, 0.08958409685874358, 0.0364300516230287, 0.04517746427154634, 0.009102183357754257, 0.027138869227201212, 0.01489937623773585, 0.047966180645744316, 0.05045028250606265, 0.021638489961333107, 0.0480815363698639, 0.0038412040021285065, 0.04101006757991854, 0.02577148625277914, 0.06979248035349883, 0.05259878518700134, 0.042796031120815314, 0.048109819617820904, 0.018044695498247165, 0.08657896280055866, 0.02702391426282702, 0.0422566790075507, 0.017461771894886624, 0.08252675484982319, 0.01718928680929821, 0.03438141975493636, 0.03259269542468246, 0.05545050618820824, 0.048877756926231086, 0.07492292497772723, 0.03980023328040261, 0.09179187487461604, 0.02850904824299505, 0.11358548668795265, 0.2642228890908882, 20.91929867863655, 85.72096824645996, 77.93302774429321, 79.91899877786636, 67.56856709718704, 70.06010100245476, 55.70582404732704, 41.68051443994045, 42.84757241606712, 43.85386861860752, 33.145940601825714, 44.32893052697182, 23.781491294503212, 24.552604816854, 32.91958674788475, 5.9546134527772665, 0.027036360079364385, 0.05548540568270255, 0.012483950868045213, 0.7152219058480114, 0.7791583437938243, 1.640837809536606, 0.8938348246738315, 0.18746386107522994, 5.998989371582866, 65.68573772907257, 87.90104806423187, 107.58890882134438, 99.63107943534851, 97.82214090228081, 94.55676332116127, 101.13651305437088, 101.65393888950348, 96.49402096867561, 98.20533514022827, 94.83338847756386, 94.04537156224251, 94.72991243004799, 94.60658624768257, 90.49789711833, 90.35899177193642, 95.52523255348206, 97.05993220210075, 94.82201188802719, 89.84290346503258, 93.15756440162659, 87.90824487805367, 89.25292432308197, 88.24329569935799, 91.06198444962502, 88.12227979302406, 90.07077723741531, 85.07944867014885, 87.00579330325127, 85.13457611203194, 86.0168507695198, 81.94555163383484, 80.96222519874573, 76.10737770795822, 78.85364234447479, 73.95847901701927, 82.05166473984718, 86.12651288509369, 86.6886319220066, 78.79081651568413, 89.0221931040287, 58.48180688917637, 45.99924109876156, 75.10806173086166, 24.422353506088257, 72.16356933116913, 86.54134422540665, 77.8991411626339, 80.51923736929893, 84.2475213110447, 78.39614689350128, 78.18422466516495, 71.68940797448158, 76.83528184890747, 76.84067755937576, 80.98806381225586, 80.11412590742111, 84.66217786073685, 83.94637987017632, 81.86504155397415, 80.2888785302639, 82.78128638863564, 83.83056208491325, 83.58219981193542, 80.97613245248795, 81.15891024470329, 78.16341698169708, 79.56752523779869, 75.64770877361298, 73.84631663560867, 82.39304602146149, 84.10299986600876, 83.52411612868309, 82.32787951827049, 81.61338865756989, 82.31452703475952, 77.11367011070251, 77.22818836569786, 73.33557084202766, 74.61743205785751, 78.05128499865532, 82.70294979214668, 77.97952204942703, 80.3851729631424, 77.91991844773293, 80.91405898332596, 85.67745298147202, 21.75614107400179, 0.2848852303577587, 1.1734165786765516, 0.5799893592484295, 0.3801987221231684, 0.20003275538329035, 0.4083674418507144, 0.34753609041217715, 0.046528302918886766, 0.08998317935038358, 0.8927319932263345, 27.391168400645256, 34.969052374362946, 19.127806909382343, 26.770564801990986, 40.88034197688103, 20.674941390752792, 27.61613342911005, 28.644878827035427, 60.14343112707138, 64.91267681121826, 70.03837376832962, 77.45235353708267, 68.68422523140907, 61.49940736591816, 22.53133937716484, 0.2807748899795115, 0.0315352240431821, 0.06721382887917571, 0.12228872670675628, 0.09142706476268359, 0.03270256667747162, 0.020734153331432026, 0.02228511766588781, 0.011062773319281405, 0.050496329058660194, 0.02935368651378667, 0.06455881040892564, 0.00039783142199212307, 0.016657345040584914, 0.018192939496657345, 0.02918215948739089, 0.036442170894588344, 0.04326848233176861, 0.05989773337205406, 0.16149124538060278, 0.1564015817712061, 0.0997589786129538, 0.19400083139771596, 0.09448486904148012, 0.16015910514397547, 0.14605513773858547, 0.20974415849195793, 0.16789906716439873, 0.2147658116882667, 0.12370090757030994, 0.14290016406448558, 0.14555772067978978, 0.17431368702091277, 0.15346327068982646, 0.23926302295876667, 0.22234505420783535, 0.15264557237969711, 0.43700870184693485, 25.067813470959663, 107.4154557287693, 89.20022875070572, 90.84924906492233, 76.78697124123573, 77.31049194931984, 51.72160103917122, 61.436915919184685, 65.53356349468231, 76.86059609055519, 63.837668895721436, 51.058821603655815, 35.10614521801472, 43.79876397550106, 49.38643254339695, 19.181944504380226, 0.4669699753867462, 0.19701248151250184, 0.1561867300188169, 0.5447603214997798, 0.6928168830927461, 5.7790913712233305, 3.8694622786715627, 0.9390860621351749, 3.603577958419919, 63.66304166615009, 90.6735996901989, 111.37990459799767, 107.19805419445038, 102.67448052763939, 99.54422369599342, 102.34647452831268, 107.47515812516212, 101.42468959093094, 101.94811150431633, 96.46792396903038, 96.91421002149582, 98.07738840579987, 100.03045320510864, 93.55003014206886, 93.17777171730995, 96.71605065464973, 100.96278637647629, 97.22048118710518, 95.8046543598175, 98.74403983354568, 94.2113770544529, 93.16780105233192, 92.13377013802528, 95.81706449389458, 91.06764614582062, 93.06510016322136, 91.09049052000046, 91.04295507073402, 93.13893020153046, 90.87661519646645, 86.10502123832703, 85.53093284368515, 82.06427246332169, 85.82844167947769, 78.59138801693916, 85.92060193419456, 89.21034380793571, 92.12484821677208, 84.45735365152359, 92.85147562623024, 68.1605677306652, 46.58053770661354, 66.14308878779411, 29.030064158141613, 78.7180732190609, 89.15541395545006, 83.06353524327278, 82.10557624697685, 89.26094949245453, 81.24828904867172, 82.34677970409393, 75.87346985936165, 78.96034821867943, 80.05421832203865, 84.641043394804, 84.24247518181801, 89.97342646121979, 85.70729658007622, 88.06944742798805, 84.06909048557281, 87.00677365064621, 84.68694493174553, 84.85532909631729, 81.03810712695122, 84.9210199713707, 83.145192861557, 84.99435603618622, 77.88359239697456, 78.32699060440063, 85.57627961039543, 85.987858325243, 87.0585648715496, 83.82927775382996, 85.9188312292099, 85.15659973025322, 80.16200333833694, 80.41884675621986, 78.06836128234863, 80.6994616985321, 81.82293221354485, 85.71419700980186, 82.19585180282593, 85.64110413193703, 79.99081492424011, 86.83112427592278, 88.78440946340561, 14.668344352394342, 3.7051025731489062, 5.871488638222218, 1.5533711342141032, 0.4555492429062724, 0.3458450920879841, 0.39820055302698165, 0.550401178188622, 0.1422689823084511, 0.30475178151391447, 4.3697417713701725, 46.97074256837368, 51.211083233356476, 33.796781077980995, 34.765459299087524, 55.28250016272068, 49.96528588235378, 45.96715562045574, 35.762145817279816, 68.79357576370239, 69.56228211522102, 70.27894645929337, 81.41157388687134, 83.17795470356941, 73.91117915511131, 22.167233414947987, 0.38228519610129297, 0.10006094365962781, 0.19190947408787906, 0.18343149073189124, 0.20986426767194644, 0.14065075898543, 0.17315074161160737, 0.14146404893836007, 0.12704115099040791, 0.20982009504223242, 0.17811841098591685, 0.1632894840440713, 0.17571351112565026, 0.10262432915624231, 0.08721692036488093, 0.1340476781479083, 0.10975442390190437, 0.13146003184374422, 0.19440662290435284], [0.021820904294145294, 0.07965897748363204, 0.03787611523875967, 0.08352537392056547, 0.029394044504442718, 0.01789607857062947, 0.13672319473698735, 0.05231533672485966, 0.03960676651331596, 0.0482805024512345, 0.07283630257006735, 0.06574611310497858, 0.039432272751582786, 0.0698904438468162, 0.007676013010495808, 0.0991851648723241, 0.022953013467486016, 0.10628923992044292, 0.03394882187421899, 23.03561981767416, 71.59538581967354, 62.095276191830635, 60.77069006860256, 51.14918075501919, 64.99398484826088, 44.305250197649, 45.81327527761459, 49.11278262734413, 45.74293725192547, 59.43926811218262, 30.4418708011508, 32.48685456812382, 41.64097376167774, 13.768447190523148, 0.2615038974909112, 0.06845885582151823, 0.06357114543789066, 0.0727450629347004, 0.07916875183582306, 1.4314479078166187, 0.9318894264288247, 0.14262319455156103, 3.0797786777839065, 45.91276153922081, 87.27936342358589, 98.89024838805199, 100.57323887944221, 88.50165903568268, 94.6283058822155, 94.04246091842651, 97.23523199558258, 89.35358092188835, 88.8615833222866, 89.8033855855465, 94.58363547921181, 87.71117225289345, 89.42177206277847, 87.75030255317688, 93.91040280461311, 92.10761234164238, 89.74137291312218, 89.49191629886627, 85.35945564508438, 85.08980691432953, 91.98136791586876, 85.57105109095573, 85.12400507926941, 85.2214090526104, 86.55744016170502, 82.64874950051308, 83.54712769389153, 77.80581817030907, 80.75480952858925, 79.8367027938366, 78.73915448784828, 77.49595239758492, 73.7838251888752, 69.32396650314331, 70.79376563429832, 69.80249002575874, 77.2584955394268, 78.46859380602837, 81.16357639431953, 75.62254652380943, 84.46720272302628, 44.81973499059677, 54.58664730191231, 83.13732728362083, 33.67980055510998, 47.405937016010284, 88.51626545190811, 72.04498529434204, 79.72375005483627, 74.83183935284615, 75.54294839501381, 71.72584801912308, 72.55531311035156, 71.38670101761818, 70.58704912662506, 71.42338424921036, 75.48896089196205, 78.18991675972939, 79.14474472403526, 79.86588522791862, 80.41851237416267, 78.55860337615013, 80.11718854308128, 76.91218212246895, 78.84890779852867, 74.61738646030426, 73.97105634212494, 72.879488915205, 72.70595222711563, 72.5258494913578, 80.02787053585052, 79.41551819443703, 79.60499882698059, 76.58373534679413, 73.64943400025368, 75.37498220801353, 76.13880962133408, 72.90097296237946, 70.33280476927757, 68.39205130934715, 71.76437795162201, 75.48671141266823, 76.15656226873398, 74.77444723248482, 74.24884423613548, 77.95082598924637, 74.1970682144165, 88.8488844037056, 21.977093517780304, 1.4847141620703042, 2.072841734625399, 1.7894294299185276, 0.0269155829664669, 0.020053514854225796, 0.2960830513620749, 0.04228070603858214, 0.2654619194800034, 0.11185231953277253, 5.006468379870057, 31.982982605695724, 27.8434619307518, 17.445148900151253, 24.814709052443504, 42.552354857325554, 40.322524309158325, 43.565505892038345, 27.398773692548275, 33.96792769432068, 37.32073098421097, 38.476587161421776, 49.20321777462959, 58.07360239326954, 51.57248944044113, 4.271325152367353, 0.18488963280105963, 0.05234283329627942, 0.03059989532630425, 0.12322743219556287, 0.04576560517307371, 0.014520284421450924, 0.017619988502701744, 0.0458769087708788, 0.06702012833557092, 0.010203789333900204, 0.0449391346774064, 0.030771314741286915, 0.06475274101831019, 0.014086269038671162, 0.09452666679862887, 0.11539038241608068, 0.029838498194294516, 0.06733589732903056, 0.05511694420420099, 0.04183081982773729, 0.08619546541012824, 0.05617689806967974, 0.04700227924331557, 0.006101428898546146, 0.051309696937096305, 0.058123677590629086, 0.061976006618351676, 0.038860158529132605, 0.036460821065702476, 0.04998805066861678, 0.013929893884778721, 0.02902736418036511, 0.056768597569316626, 0.041122751572402194, 0.021263835260469932, 0.15061055892147124, 0.06255185755435377, 37.12312638759613, 92.35769212245941, 72.56738886237144, 76.15433558821678, 63.78240466117859, 83.5086889564991, 53.778347074985504, 55.654272213578224, 36.98058843612671, 34.66274321079254, 58.77322845160961, 29.792270958423615, 24.824710115790367, 40.230804830789566, 10.458806734532118, 0.1234942936571315, 0.014007813824719051, 0.020600731877493672, 0.21093343530083075, 0.8010779425967485, 0.8974338846746832, 1.402769184205681, 0.20254054659744725, 6.619835682213306, 60.0043585896492, 95.6563027203083, 105.32685220241547, 102.77647465467453, 93.98037225008011, 98.59704092144966, 95.81550657749176, 99.89205703139305, 92.4885419011116, 92.72843062877655, 92.11941450834274, 98.23862135410309, 91.19387537240982, 92.27183192968369, 95.58035999536514, 99.43437919020653, 94.3364891409874, 93.52900967001915, 92.05843538045883, 90.0383497774601, 90.67348569631577, 94.37093049287796, 92.22643956542015, 89.45044532418251, 87.73774802684784, 91.82779535651207, 85.97060725092888, 86.0260158777237, 84.5188495516777, 84.16963309049606, 82.96636685729027, 82.69306272268295, 81.63375556468964, 77.21720695495605, 74.20504778623581, 74.44058194756508, 74.40405830740929, 79.0420514345169, 82.11888313293457, 83.75478655099869, 83.26640635728836, 85.28656035661697, 47.83202715218067, 60.163045674562454, 79.78192493319511, 42.010910511016846, 44.67302106320858, 90.28837636113167, 74.5313210785389, 83.56687903404236, 77.48246312141418, 79.5514976978302, 76.99601322412491, 76.54947638511658, 72.77389258146286, 73.69278967380524, 73.73166158795357, 77.43494287133217, 81.20994910597801, 81.85429573059082, 82.18921735882759, 82.30280846357346, 81.35286703705788, 83.29397767782211, 81.52694329619408, 84.328054189682, 76.26892223954201, 75.2394662797451, 75.28142362833023, 74.84978199005127, 78.29901650547981, 81.96589574217796, 82.891366481781, 83.86248037219048, 79.3191933631897, 77.92668968439102, 75.88090226054192, 78.18364709615707, 76.47730305790901, 76.04378432035446, 72.84957692027092, 74.96778845787048, 77.39281073212624, 80.68252980709076, 76.84107273817062, 78.72761070728302, 83.87541487812996, 79.29565742611885, 93.88737604022026, 36.8388332426548, 0.8499787654727697, 0.616130466805771, 0.5812452512327582, 0.22925167344510555, 0.9756329760421067, 0.4376899340422824, 0.022409052617149428, 0.04255036168615334, 0.12709348724456504, 3.001004629768431, 30.073972642421722, 25.494669266045094, 13.472222685813904, 32.90047377347946, 39.16311152279377, 16.75113134086132, 37.7265378087759, 34.88807491958141, 50.2451104670763, 57.06596106290817, 56.815079525113106, 71.02942898869514, 67.80073463916779, 71.20282888412476, 11.722320634871721, 0.13720326038310304, 0.06341815169434994, 0.003259980612710933, 0.056629259343026206, 0.06843120339908637, 0.10136464479728602, 0.06619920168304816, 0.015409371771966107, 0.07079615344991907, 0.06434093811549246, 0.030207191593945026, 0.046268102232716046, 0.0316733488580212, 0.03710963996127248, 0.047410523548023775, 0.06491081847343594, 0.050839661416830495, 0.04271519268513657, 0.103710677503841, 0.2382120379479602, 0.18997279519680887, 0.15460263064596802, 0.12234267342137173, 0.1377725470229052, 0.2691408048849553, 0.14186811866238713, 0.18491176364477724, 0.10304209150490351, 0.1569296050001867, 0.1894962028018199, 0.16491670219693333, 0.15037396224215627, 0.12667377304751426, 0.23861591471359134, 0.11734795276424848, 0.2553880662890151, 0.1374296154244803, 49.02387119829655, 110.60158476233482, 87.8304934501648, 88.0245490372181, 73.91557931900024, 87.6419323682785, 66.64557382464409, 71.6080467402935, 71.16485372185707, 63.233432918787, 84.21812608838081, 49.319062158465385, 46.2026821821928, 60.96386410295963, 24.66216053813696, 0.5860880319960415, 0.18007708713412285, 0.17137012153398246, 0.29046261857729405, 0.35351150727365166, 6.102329101413488, 5.322225261479616, 0.5885194859001786, 4.2323278449475765, 55.22221639752388, 96.77558586001396, 105.63642919063568, 110.2932845056057, 96.32564440369606, 104.2945995926857, 100.12905031442642, 102.83249124884605, 97.03714862465858, 94.83589634299278, 95.91452166438103, 103.88686627149582, 93.38108360767365, 96.4754931628704, 94.61984753608704, 103.02741318941116, 97.94577106833458, 98.45786958932877, 97.28317022323608, 97.10977032780647, 93.98424804210663, 97.62191444635391, 93.47165554761887, 92.46836498379707, 91.66572645306587, 95.25319755077362, 88.43157559633255, 91.46439045667648, 86.30258023738861, 89.38442766666412, 87.25743100047112, 85.78862741589546, 84.87079426646233, 80.15730679035187, 77.47778937220573, 78.44551384449005, 79.17863130569458, 85.37823423743248, 85.80267906188965, 88.21108862757683, 83.41608792543411, 90.81571206450462, 53.00634630024433, 60.74608638882637, 82.213064879179, 40.70265211164951, 52.550363168120384, 93.72266247868538, 80.18373057246208, 83.01726132631302, 83.27548027038574, 81.19992524385452, 79.81350883841515, 81.25486269593239, 77.78934225440025, 75.77621027827263, 76.97446838021278, 78.25385972857475, 82.66683652997017, 84.35050338506699, 85.34333691000938, 84.03035536408424, 84.62531223893166, 90.00241130590439, 83.92379388213158, 85.32109290361404, 77.31340259313583, 76.92761689424515, 77.06216007471085, 76.66134238243103, 79.48459088802338, 85.85978239774704, 85.6451091170311, 86.76321431994438, 83.59378159046173, 80.11824488639832, 79.64460030198097, 82.0087118446827, 78.98209825158119, 78.41816291213036, 75.7881036400795, 79.43311125040054, 81.47796392440796, 84.62505385279655, 79.65704083442688, 83.46407175064087, 86.8734236061573, 82.67907947301865, 98.84981095790863, 27.887334376573563, 3.6705671763047576, 6.201159423217177, 1.893719108775258, 0.1138227735646069, 0.3863592603011057, 1.1850355239585042, 0.2278195065446198, 0.6228317634668201, 0.2504276402760297, 9.385806061327457, 47.063974365592, 41.253531351685524, 27.755183167755604, 38.13626982271671, 62.34044283628464, 59.72600072622299, 69.29957181215286, 43.80770109593868, 51.771222576498985, 54.56531524658203, 59.28501158952713, 70.72191908955574, 79.79150041937828, 82.99307182431221, 12.435091137886047, 0.32309244736097753, 0.14589661499485373, 0.194636540254578, 0.20643272524466738, 0.1507473218953237, 0.21058504149550572, 0.13945484737632796, 0.14335409126942977, 0.13559207262005657, 0.1589972581132315, 0.11005327934981324, 0.12208602391183376, 0.20734863937832415, 0.10296680804458447, 0.14376010542036965, 0.16797050629975274, 0.12552149972179905, 0.17207387048983946], [0.07375272136414424, 0.05209226568695158, 0.052031580271432176, 0.06914106765179895, 0.12794484937330708, 0.056441744600306265, 0.08132602670229971, 0.03787389250646811, 0.03734062229341362, 0.07187558498117141, 0.050049819619744085, 0.058087345751118846, 0.04008997886558063, 0.006313605208561057, 0.06720950957969762, 0.04946713350364007, 0.03085748179728398, 0.055179629707708955, 0.0820975263195578, 34.694441109895706, 70.99042788147926, 56.64867125451565, 63.95107761025429, 48.794526904821396, 37.62322135269642, 44.90515820682049, 34.80841979384422, 52.445712983608246, 41.89807936549187, 30.809187591075897, 36.36477068066597, 45.08424259722233, 19.740934409201145, 0.7067915832158178, 0.0359771894000005, 0.09180633933283389, 0.02712602636165684, 0.07737488442217, 0.6331645965110511, 0.9253126918338239, 0.19123927020700648, 0.9195654408540577, 45.378582403063774, 91.94128006696701, 105.0611324608326, 99.0854287147522, 93.76808524131775, 96.41317650675774, 93.40785697102547, 95.97797065973282, 90.38315087556839, 87.425237596035, 90.74849367141724, 88.89046177268028, 83.54793325066566, 88.0866377055645, 92.99753218889236, 91.26518994569778, 89.03542399406433, 87.37954884767532, 89.1032275557518, 87.14925080537796, 89.63512301445007, 91.4187853038311, 87.90193721652031, 83.50301206111908, 84.58449482917786, 85.50444826483727, 81.41212865710258, 82.90637567639351, 84.20957654714584, 81.60955086350441, 82.04050093889236, 82.10479348897934, 82.13402152061462, 75.4168863594532, 75.02163916826248, 73.17163243889809, 71.65550619363785, 68.88428449630737, 68.22644859552383, 74.54841256141663, 74.4038151204586, 82.54613980650902, 70.78916788101196, 48.82527865469456, 71.88873007893562, 67.55444705486298, 63.63868497312069, 34.03399474918842, 78.30698847770691, 72.91191637516022, 74.80707988142967, 76.6518884897232, 73.01510363817215, 71.81737750768661, 68.61832916736603, 66.75309285521507, 65.86099192500114, 67.77526840567589, 69.450613707304, 73.79076361656189, 76.90807834267616, 76.55114829540253, 75.76845109462738, 76.42383992671967, 74.91674199700356, 79.99556466937065, 80.48210576176643, 77.21096768975258, 70.57066440582275, 71.01600050926208, 71.46643593907356, 76.22401624917984, 77.02034711837769, 74.19564709067345, 76.98244035243988, 75.3430487215519, 74.23907116055489, 73.05814772844315, 71.33592054247856, 72.64691099524498, 71.65860682725906, 71.22805193066597, 68.836969435215, 71.20245650410652, 76.20364934206009, 77.51750484108925, 74.93077844381332, 72.09313631057739, 81.7729040980339, 74.43577140569687, 85.75486242771149, 17.588847689330578, 0.331163540831767, 0.9545971266925335, 0.27640782587695867, 0.2083160585607402, 0.6200601090677083, 0.01140514645157964, 0.05511928196938243, 0.05928216269239783, 0.062217019076342694, 11.832241136580706, 31.230963058769703, 25.42170748114586, 17.65717562288046, 25.294739194214344, 41.81554779410362, 26.36111967265606, 39.06038023531437, 26.123812906444073, 31.85072310268879, 44.18954640626907, 47.68488384783268, 55.62254771590233, 62.51280918717384, 40.02252280712128, 3.9924015942960978, 0.06364650311297737, 0.09603058453649282, 0.05472889002703596, 0.06292500940617174, 0.012612589180207578, 0.06052916003682185, 0.0077311402037594235, 0.057152633016812615, 0.017536237137392163, 0.01362024853733601, 0.043737434316426516, 0.07584479113575071, 0.12679544073762372, 0.08843573465128429, 0.05083924210339319, 0.03805790431215428, 0.08490833643008955, 0.040807364784996025, 0.0486583372548921, 0.049285292479908094, 0.07604390935739502, 0.08207047503674403, 0.04410418143379502, 0.04677870725572575, 0.04945020882587414, 0.02717264065722702, 0.0794017045700457, 0.03492800038657151, 0.009878198015940143, 0.08099156300886534, 0.05322539531334769, 0.10297801447450183, 0.03417439394979738, 0.059640805557137355, 0.018490828297217377, 0.01770265633240342, 52.273677214980125, 82.34749406576157, 68.21949496865273, 73.02511230111122, 61.729732006788254, 45.59955194592476, 36.149941608309746, 34.9129331856966, 30.50608355551958, 30.12997403740883, 33.536198660731316, 28.333745822310448, 38.0576254427433, 17.25808873772621, 0.6677680928260088, 0.05179044164833613, 0.022670566904707812, 0.06658334474195726, 0.8744366280734539, 1.5748372511006892, 0.7877340086270124, 0.17370517045492306, 2.6736229844391346, 58.75338591635227, 97.77142122387886, 112.17447236180305, 101.28672659397125, 98.68581935763359, 99.62087318301201, 97.32351645827293, 98.63761514425278, 95.38010314106941, 90.18110051751137, 95.76601803302765, 90.7788996398449, 87.5133928656578, 92.20491752028465, 96.32132023572922, 93.10251295566559, 95.05350306630135, 93.06954592466354, 97.58491963148117, 92.18413263559341, 94.51347604393959, 94.74624395370483, 92.12614014744759, 87.81066611409187, 87.23509579896927, 87.84528985619545, 86.76676332950592, 87.40579783916473, 86.91408902406693, 86.99225842952728, 87.36496523022652, 87.48958334326744, 85.05055502057076, 80.16486078500748, 80.21009355783463, 78.82687658071518, 74.9201238155365, 70.20098984241486, 71.100302785635, 78.31038549542427, 78.22822630405426, 84.85109612345695, 73.60733225941658, 53.56617406010628, 75.85957780480385, 66.81938409805298, 68.01065057516098, 37.83409483730793, 77.27683335542679, 77.51808241009712, 77.13400661945343, 79.612036049366, 75.40878519415855, 76.33110970258713, 72.16176062822342, 70.41895374655724, 70.74107006192207, 71.3191406428814, 72.75084301829338, 75.55053278803825, 79.5683079957962, 78.38217884302139, 81.42580032348633, 78.71890917420387, 78.74087199568748, 80.74377492070198, 83.3318692445755, 80.3433296084404, 73.85472938418388, 73.51948857307434, 75.87659329175949, 80.80869063735008, 79.10500645637512, 77.90610998868942, 78.21067124605179, 78.34918141365051, 77.25230947136879, 75.04033416509628, 75.56058704853058, 74.73323464393616, 73.17691415548325, 75.50072506070137, 73.77081468701363, 74.19872492551804, 78.42299625277519, 80.83116263151169, 79.93374958634377, 73.68331298232079, 85.32966524362564, 77.05550283193588, 93.41583654284477, 31.373664401471615, 0.42379443591926247, 1.0559667809866369, 2.207565405406058, 1.640365447383374, 1.4815229270607233, 0.1718813128536567, 0.1828429676243104, 0.04855075181694701, 0.07675449349335395, 9.25049627199769, 29.990170039236546, 17.84022320061922, 14.902235101908445, 33.07300731539726, 33.628484308719635, 13.43294134363532, 37.22691021859646, 34.64973270893097, 42.60568119585514, 58.37302252650261, 65.52270367741585, 73.94285425543785, 70.1564334332943, 60.45765146613121, 9.102877043187618, 0.056737371705821715, 0.07637033559149131, 0.09258468155167066, 0.06847407727036625, 0.1101389380346518, 0.05150936063728295, 0.02084494670270942, 0.021787650512123946, 0.05056552690803073, 0.006000611383569776, 0.07777749953675084, 0.059527056582737714, 0.06192892848048359, 0.03988385105913039, 0.023609159215993714, 0.03986782438005321, 0.037778018158860505, 0.19098348158877343, 0.1614653444266878, 0.1359887357102707, 0.14605604315875098, 0.24650809122249484, 0.12723969033686444, 0.14381337678059936, 0.12993009440833703, 0.21454990608617663, 0.15301731415092945, 0.15470234560780227, 0.11232272983761504, 0.1324186343117617, 0.1376948441611603, 0.21566919836914167, 0.19379062548978254, 0.1530617687967606, 0.23360411723842844, 0.1714826311217621, 69.92925122380257, 101.48591950535774, 80.95509678125381, 89.05450657010078, 70.32120779156685, 57.250973135232925, 67.75072932243347, 50.71136064827442, 76.5793351829052, 62.576987743377686, 47.02365852892399, 55.300366804003716, 57.438770458102226, 34.52563136816025, 2.194505031220615, 0.23018620064249262, 0.2659271570155397, 0.07912194458185695, 0.4107435018522665, 2.3919744975864887, 5.168944336473942, 0.4964538401691243, 1.585091594606638, 54.10959430038929, 98.80714684724808, 114.51422721147537, 108.63624662160873, 101.4484079182148, 104.73834738135338, 99.99402076005936, 105.01348301768303, 99.16010230779648, 93.11385154724121, 98.45128074288368, 96.13120883703232, 90.7301938533783, 95.0828754901886, 98.54791715741158, 98.48914191126823, 97.92197674512863, 95.54271161556244, 99.05507594347, 97.49510005116463, 98.99777501821518, 98.14054861664772, 96.32062867283821, 91.48603409528732, 93.10841023921967, 93.07273775339127, 90.63582971692085, 90.14608159661293, 88.85601282119751, 90.45573458075523, 88.98864850401878, 91.28464490175247, 87.81062051653862, 85.32794773578644, 84.53423872590065, 81.91047191619873, 78.66352334618568, 74.8659311234951, 76.96643561124802, 82.55055516958237, 83.93045112490654, 90.2601058781147, 80.70591375231743, 54.83273349702358, 75.80759659409523, 69.56821739673615, 65.83794996142387, 41.47716835141182, 86.1169981956482, 80.57137057185173, 82.22336992621422, 81.77893817424774, 79.25841182470322, 79.26708295941353, 76.57508701086044, 74.25813093781471, 74.16546151041985, 74.71119582653046, 75.97373127937317, 80.36558881402016, 83.36126446723938, 82.66302913427353, 82.6821269094944, 81.48521393537521, 82.16802209615707, 84.9123640358448, 86.0511477291584, 82.73898705840111, 76.7871156334877, 77.34431013464928, 79.65685844421387, 83.82756024599075, 82.23165348172188, 79.76132243871689, 82.3502679169178, 82.52469375729561, 80.2449680864811, 79.47110161185265, 79.07680436968803, 78.0592493712902, 78.0308572947979, 77.82254487276077, 77.36274674534798, 78.42206910252571, 83.01684334874153, 84.49263095855713, 82.10549265146255, 77.79340043663979, 89.24390360713005, 82.47727990150452, 94.43769291043282, 23.553281240165234, 0.7499074540100992, 1.9899853994138539, 1.711773828137666, 0.28453912236727774, 0.9526226576417685, 0.35101777233649045, 0.2661656239069998, 0.1849640256841667, 0.2074063933105208, 20.05463607609272, 46.66555814445019, 36.06836378574371, 27.077212147414684, 41.487180814146996, 61.86073377728462, 40.10901756584644, 60.256566256284714, 38.30642469227314, 44.918438494205475, 62.28968895971775, 71.29568830132484, 79.43738982081413, 84.35995727777481, 70.81243023276329, 7.763322098180652, 0.18997904408024624, 0.1904656703118235, 0.24634049943415448, 0.18077930726576596, 0.21691628848202527, 0.23102111677872017, 0.12688623508438468, 0.1360635441960767, 0.11707107973052189, 0.1483420658041723, 0.18644600553670898, 0.21336300414986908, 0.23592675745021552, 0.2588606346398592, 0.27283432544209063, 0.1858414668822661, 0.13558815408032387], [0.06926348491106182, 0.05959888163488358, 0.1077652454841882, 0.037164124732953496, 0.05072648389614187, 0.009391997591592371, 0.06434799593989737, 0.09878534765448421, 0.009813456763367867, 0.04386978151160292, 0.11435254826210439, 0.020516960103122983, 0.08495047557516955, 0.04815451546164695, 0.05243567225988954, 0.07089016871759668, 0.04564839036902413, 0.15854132710956037, 0.051731029016082175, 38.786631524562836, 60.84288239479065, 57.72269122302532, 50.10994412004948, 56.680258959531784, 50.21959103643894, 52.52435356378555, 39.74368616938591, 40.604184195399284, 40.7245921343565, 29.45767041295767, 38.88897903263569, 28.326799795031548, 4.784850021824241, 0.039512120420113206, 0.04370836068119388, 0.08405980188399553, 0.1646885511581786, 0.11842297593830153, 2.6181813469156623, 0.07393045831122436, 0.19442412274656817, 31.677739284932613, 98.61304566264153, 100.47723323106766, 100.29004007577896, 90.26763707399368, 96.83834329247475, 90.13778284192085, 93.88109877705574, 87.76964351534843, 87.96047687530518, 85.74987709522247, 84.264597594738, 80.56184828281403, 86.77689358592033, 85.81176057457924, 89.60676893591881, 87.94973105192184, 91.47952124476433, 93.6758641898632, 92.27044880390167, 86.9210958480835, 90.73690429329872, 88.25353235006332, 88.59466284513474, 85.6617446243763, 83.93263220787048, 83.55433210730553, 86.63412004709244, 84.3604664504528, 83.61671715974808, 83.50623428821564, 85.17898052930832, 80.36701753735542, 80.65781593322754, 75.70902988314629, 74.43573340773582, 71.1163379251957, 68.63653779029846, 62.31506019830704, 67.03229427337646, 70.59160128235817, 69.35434207320213, 73.10670912265778, 78.03589582443237, 66.46287202835083, 72.33244746923447, 63.79101499915123, 73.81755217909813, 42.191845402121544, 60.932489186525345, 80.04237815737724, 69.84475135803223, 76.2124040722847, 72.56979793310165, 72.45024874806404, 67.8327365219593, 65.26167288422585, 65.38342595100403, 69.14915308356285, 68.45153331756592, 71.93529278039932, 70.69576129317284, 74.40699175000191, 75.73602363467216, 77.30992197990417, 75.60880646109581, 78.26630786061287, 77.17830464243889, 76.46870031952858, 71.8134181201458, 69.965980052948, 70.40243223309517, 75.11265948414803, 74.88622203469276, 78.13386216759682, 73.60642790794373, 72.39958986639977, 69.69026684761047, 70.30917763710022, 67.86077901721, 67.74538680911064, 64.57137912511826, 67.85727560520172, 71.20803460478783, 67.56455451250076, 72.88305312395096, 75.97070664167404, 75.05474299192429, 77.119400203228, 71.2390485405922, 80.25873094797134, 75.70788234472275, 88.54051575064659, 10.532309040427208, 0.9498249983880669, 3.7301850272342563, 3.23123665060848, 0.7322832278441638, 0.3248086490202695, 0.25022999150678515, 0.0534692873043241, 0.04199146882456262, 0.415263210888952, 22.85042155534029, 35.75409784913063, 34.5080953091383, 20.580031983554363, 24.99253001064062, 51.61277487874031, 39.99830290675163, 42.30989746749401, 63.311229944229126, 34.416638016700745, 36.21114492416382, 39.242033287882805, 50.396346151828766, 55.26015356183052, 36.049911975860596, 2.1102799382060766, 0.06400769896572456, 0.0645987231109757, 0.026221630359941628, 0.024620483854960185, 0.044145786232547835, 0.04900464562524576, 0.05114615356433205, 0.05071157414931804, 0.047288317800848745, 0.05177124599867966, 0.03689797202241607, 0.08216512855142355, 0.06403454244718887, 0.04338546335930005, 0.046742509002797306, 0.02798216235532891, 0.04200804098218214, 0.026050274027511477, 0.0837884949578438, 0.09201494220178574, 0.1650569384219125, 0.05201855929044541, 0.059955758188152686, 0.0325014149711933, 0.0342572955560172, 0.038753686312702484, 0.09156526008155197, 0.07895546601503156, 0.03091217437031446, 0.00546832219697535, 0.0158304774959106, 0.10816861758939922, 0.007091122715792153, 0.13324195810128003, 0.04507266930886544, 48.019972667098045, 74.3034017086029, 67.51086339354515, 57.21693076193333, 58.387940526008606, 55.53967796266079, 45.25089405477047, 24.05855342745781, 35.96252426505089, 47.05527663230896, 25.007943883538246, 33.76036003232002, 24.012026824057102, 4.233107278123498, 0.2245930046774447, 0.17760868911864236, 0.0455045176204294, 0.5127820686902851, 1.1288230028003454, 1.1054838239215314, 0.1502438192255795, 0.548819275572896, 45.489099472761154, 105.52663028240204, 104.13460537791252, 101.89793899655342, 97.0543085038662, 101.74945056438446, 94.45096179842949, 97.67813622951508, 91.07042759656906, 90.59878170490265, 87.36670553684235, 86.63269892334938, 82.73207902908325, 91.37169823050499, 91.11550077795982, 91.52544558048248, 91.36263191699982, 96.15512475371361, 97.52248898148537, 96.0845397412777, 90.59799134731293, 95.48405036330223, 94.06012997031212, 91.85473591089249, 88.48123133182526, 87.95169174671173, 84.97402712702751, 90.54936155676842, 88.7911731004715, 87.30392530560493, 90.44504195451736, 87.92605832219124, 83.00861299037933, 83.05205225944519, 81.1927892267704, 77.74254396557808, 74.04530435800552, 74.21393170952797, 67.6852360367775, 71.08826503157616, 76.32424727082253, 75.736745595932, 75.58747440576553, 82.94554397463799, 68.52233111858368, 70.69738760590553, 64.32408839464188, 76.13199278712273, 50.941119119524956, 62.18308188021183, 86.6574963927269, 74.66223925352097, 77.7201783657074, 75.175242125988, 75.89980244636536, 72.23533987998962, 70.24284839630127, 69.17477130889893, 73.11695337295532, 72.6983830332756, 74.78456228971481, 73.52196604013443, 76.76445364952087, 79.1430576145649, 79.93350639939308, 78.99667426943779, 81.55243992805481, 81.41367137432098, 78.87342408299446, 74.52246755361557, 73.0515056848526, 76.63215234875679, 76.94317325949669, 79.56842198967934, 81.86709344387054, 77.36982196569443, 75.71548953652382, 73.7962657213211, 73.77914384007454, 74.1167177259922, 70.57227551937103, 69.81534093618393, 69.9346013367176, 72.26741015911102, 73.60756024718285, 75.89926287531853, 79.34679508209229, 76.61661118268967, 82.64573246240616, 73.36495086550713, 83.03785622119904, 79.6098929643631, 98.70445355772972, 20.64953215420246, 0.7891214091796428, 1.7696586158126593, 8.951850347220898, 4.621080234646797, 1.5782212070189416, 0.38776696601416916, 0.09827977439272217, 0.037954871950205415, 0.2089897356927395, 19.904620125889778, 33.64296533167362, 24.735312312841415, 19.938822090625763, 24.624409563839436, 44.92489814758301, 34.096489995718, 40.08764751255512, 66.39214262366295, 45.82257717847824, 43.08798171579838, 51.64096936583519, 63.918756544589996, 67.31268122792244, 52.70551644265652, 4.055585078895092, 0.02444869893224677, 0.04868646094109863, 0.028825449917349033, 0.05963834533758927, 0.03471279611403588, 0.08062198830884881, 0.05405938376497943, 0.06983447849052027, 0.05085327982669696, 0.05786204455944244, 0.04618378312443383, 0.04317667866416741, 0.042851584585150704, 0.027928549607167952, 0.04790475679328665, 0.03298545481811743, 0.13776644656900316, 0.17823850532295182, 0.24609260726720095, 0.14812770386924967, 0.24498514481820166, 0.138129623956047, 0.11412787789595313, 0.2495079708751291, 0.10301080255885608, 0.10674868870410137, 0.15874182572588325, 0.22232854884350672, 0.15430704806931317, 0.1319344126386568, 0.10138569210539572, 0.2505272364942357, 0.13625267310999334, 0.193263299879618, 0.18290605017682537, 67.28985965251923, 89.05063837766647, 82.44225338101387, 73.81617665290833, 74.09346297383308, 73.15323382616043, 81.67784079909325, 58.802422285079956, 57.76801899075508, 68.9017103612423, 43.898121044039726, 53.533191829919815, 44.549945667386055, 8.95005114376545, 0.3895392146660015, 0.2699711197055876, 0.17166046454804018, 0.43260735052172095, 0.7515976508148015, 7.289019674062729, 1.1627955548465252, 0.4933656449429691, 37.180199325084686, 105.74503496289253, 107.45669111609459, 107.62768194079399, 97.99575358629227, 105.55208891630173, 97.56966724991798, 103.95843923091888, 95.7516548037529, 94.36604395508766, 93.30344617366791, 90.93992739915848, 87.19780460000038, 96.34284228086472, 92.93377161026001, 95.03418490290642, 93.54662552475929, 97.87191063165665, 100.0287888944149, 100.18670082092285, 93.70058566331863, 99.80884909629822, 99.87070977687836, 96.43092915415764, 92.70706057548523, 92.11687624454498, 90.50927370786667, 92.64146849513054, 91.91110208630562, 92.07903787493706, 93.52113649249077, 91.68073564767838, 87.64634013175964, 87.94036835432053, 83.94183531403542, 81.18370771408081, 79.26592022180557, 75.33474236726761, 69.76073786616325, 76.33797213435173, 76.62786617875099, 77.67635151743889, 79.85148400068283, 85.99471315741539, 70.2572800219059, 73.13024505972862, 66.34165093302727, 74.07248049974442, 50.474241971969604, 66.22817382216454, 88.57786014676094, 76.36434271931648, 81.39804661273956, 77.00952529907227, 79.49554190039635, 76.16919279098511, 74.98081415891647, 71.42249509692192, 75.8165793120861, 75.88053748011589, 78.15560460090637, 74.18364733457565, 80.56798115372658, 81.32788717746735, 84.73413079977036, 83.1017991900444, 87.64326229691505, 84.42559495568275, 81.20801880955696, 74.54775899648666, 77.25243866443634, 79.24800798296928, 82.90487855672836, 81.86713144183159, 86.80472329258919, 79.56396862864494, 78.72413009405136, 75.1462572813034, 76.00961655378342, 76.34582251310349, 74.62415769696236, 70.51470100879669, 75.18850341439247, 77.08722352981567, 77.2379918396473, 80.48984214663506, 84.68293994665146, 80.35947114229202, 83.9482569694519, 74.44203346967697, 88.93672049045563, 82.3139114677906, 101.4406107366085, 13.45381647348404, 4.350543776527047, 11.828198153525591, 9.755048397928476, 1.3152031204663217, 0.9154313220642507, 0.8921829226892442, 0.09886791158351116, 0.205115427961573, 0.5142432684078813, 35.67361056804657, 52.478512823581696, 49.96121630072594, 34.420772194862366, 39.25648011267185, 72.53057643771172, 61.042044907808304, 61.413607969880104, 84.29585471749306, 48.91067907214165, 51.960855200886726, 60.96749670803547, 73.56068596243858, 79.41392987966537, 60.86824603378773, 3.3431204594671726, 0.1178104146674741, 0.20552849251544103, 0.1356093943468295, 0.12433958501787856, 0.12509377032984048, 0.2601474296534434, 0.17103508638683707, 0.18715054116910324, 0.10811865620780736, 0.29081727610901, 0.09733466416946612, 0.1697896289988421, 0.1672733179293573, 0.09506024871370755, 0.10639398664352484, 0.19027654139790684], [0.04772192500240635, 0.08546008612029254, 0.07646563477464952, 0.03782875508477446, 0.11567985711735673, 0.03297998890047893, 0.05038435752794612, 0.11803305897046812, 0.03186881200235803, 0.10125321874511428, 0.02704703587369295, 0.06409841909771785, 0.014884315278322902, 0.029166006643208675, 0.05355922447051853, 0.10481826611794531, 0.022248997338465415, 0.047577506775269285, 0.16901957656955346, 37.520562261343, 72.04661920666695, 50.95500357449055, 66.97148993611336, 59.02474835515022, 42.18967951834202, 36.57422684133053, 51.86289265751839, 24.307077191770077, 23.218680694699287, 32.24191211163998, 26.0535204783082, 11.481838189065456, 0.09759373308042996, 0.03845750630716793, 0.16857713781064376, 0.05220900922722649, 0.12682583910645917, 2.129728482104838, 1.8236761610023677, 0.5856734979897738, 22.65824306756258, 105.99783539772034, 103.26144263148308, 99.03222396969795, 95.88634237647057, 94.57489594817162, 91.33276551961899, 90.22945672273636, 91.41842052340508, 86.73572659492493, 80.82503736019135, 77.66376659274101, 78.93413722515106, 85.22336974740028, 85.23319602012634, 87.52615258097649, 90.45016407966614, 92.10161626338959, 89.28893879055977, 90.95583334565163, 87.40224123001099, 87.30603039264679, 89.45219323039055, 88.43403026461601, 83.4225931763649, 81.49827763438225, 82.03177660703659, 84.76285725831985, 83.3105219900608, 81.19850412011147, 86.81963369250298, 84.92268428206444, 81.9799093902111, 79.93191808462143, 78.80384221673012, 71.73931449651718, 71.62718251347542, 71.22412294149399, 70.03756821155548, 69.01574984192848, 70.25932431221008, 79.75042462348938, 78.7229673564434, 74.79121193289757, 82.49816358089447, 69.96563047170639, 69.33731898665428, 63.31410638988018, 70.28715401887894, 68.34948599338531, 69.22994434833527, 81.74533277750015, 72.4067334830761, 72.41272196173668, 71.34261578321457, 73.17477867007256, 65.97307831048965, 66.92201659083366, 64.04471218585968, 68.4585553407669, 71.02780267596245, 72.02717944979668, 72.13775351643562, 75.57712376117706, 75.03175422549248, 76.55662000179291, 76.12144455313683, 77.45657131075859, 76.92149922251701, 75.05700767040253, 75.09435966610909, 66.02220967411995, 71.65209397673607, 72.44706451892853, 77.39396587014198, 77.06608146429062, 80.2395647764206, 76.81543931365013, 76.19911998510361, 73.13900738954544, 71.42491936683655, 71.57526209950447, 70.39616256952286, 62.92329356074333, 63.61574560403824, 64.20111179351807, 66.19434803724289, 69.3694044649601, 75.36375001072884, 73.94531652331352, 78.8988447189331, 71.16097792983055, 79.33592766523361, 76.5673278272152, 86.52593225240707, 2.2217806801199913, 2.925763917155564, 13.777975179255009, 3.2434940803796053, 0.0548921476729447, 0.5736167449504137, 0.22930988750886172, 0.025544027266732883, 0.041104324045591056, 1.0396192269399762, 26.402938328683376, 25.607868991792202, 34.164373353123665, 28.326300121843815, 30.53737487643957, 41.001635268330574, 52.64632701873779, 70.71431949734688, 32.568736374378204, 51.41113869845867, 43.046191558241844, 48.44512805342674, 44.99598853290081, 49.779232665896416, 22.5090953707695, 0.189298628247343, 0.04644529370125383, 0.08250038634287193, 0.022860402714286465, 0.10658750165021047, 0.04153173431404866, 0.09671193547546864, 0.04320314365031663, 0.034853800461860374, 0.026744080059870612, 0.0430692973168334, 0.020735839862027206, 0.020771744966623373, 0.014560141462425236, 0.08351010794285685, 0.014620740603277227, 0.01456700818380341, 0.05772958975285292, 0.05548888635530602, 0.06224302764167078, 0.0534470228740247, 0.03040698702534428, 0.07551499555120245, 0.037383321759989485, 0.01604947970918147, 0.03527807886712253, 0.06202210883202497, 0.035144607318216003, 0.03427223869948648, 0.046409058340941556, 0.05973463899863418, 0.04775059045641683, 0.04495288296311628, 0.03234714844438713, 0.23800745751941577, 54.83826220035553, 85.86559608578682, 62.64399714767933, 71.6697858273983, 60.783400386571884, 44.680176079273224, 38.554072603583336, 42.05570250749588, 25.92229261994362, 30.950747095048428, 27.494505755603313, 26.68025314807892, 9.787356164306402, 0.0299795266619185, 0.1312807883368805, 0.06157310577691533, 0.46763983787968755, 1.0680057224817574, 0.9076938091311604, 0.8446698565967381, 0.270862735924311, 38.554619774222374, 113.73377948999405, 108.70573729276657, 104.60897952318192, 99.27242428064346, 98.36647689342499, 92.68775001168251, 95.6136006116867, 95.6954862177372, 91.13780558109283, 83.63884717226028, 81.04645907878876, 85.52527114748955, 89.74510431289673, 88.46280992031097, 92.7268423140049, 94.59102988243103, 94.33476403355598, 91.00941807031631, 93.74579563736916, 90.95089361071587, 91.64237290620804, 93.5635270178318, 91.40590399503708, 87.34513029456139, 86.49864211678505, 85.98351135849953, 86.65481373667717, 88.28401431441307, 87.23053604364395, 87.62123107910156, 88.8423715531826, 87.80637994408607, 85.35696297883987, 80.25892093777657, 75.94053626060486, 75.15419885516167, 75.1652866601944, 73.18925589323044, 71.3148620724678, 77.7544829249382, 84.86960873007774, 84.737429022789, 80.79324826598167, 84.07991990447044, 71.07990548014641, 69.81647327542305, 64.03295561671257, 71.42644688487053, 81.28306478261948, 76.28159075975418, 82.75031805038452, 76.25822961330414, 74.53866988420486, 72.64702498912811, 76.2521043419838, 71.81947499513626, 69.65983808040619, 68.74531075358391, 70.89946836233139, 76.07727572321892, 75.53451284766197, 75.89450553059578, 78.89154151082039, 78.20729702711105, 76.47448360919952, 78.93792182207108, 79.03596416115761, 80.83791106939316, 78.90073701739311, 79.72512558102608, 72.17395797371864, 75.48116371035576, 75.90737164020538, 79.86992061138153, 80.70874840021133, 81.97601839900017, 78.33498537540436, 79.72826421260834, 76.47702187299728, 75.10535627603531, 76.49270743131638, 75.66169202327728, 69.04662698507309, 67.91000917553902, 68.58598530292511, 70.39903521537781, 72.26813212037086, 78.64172771573067, 74.55751687288284, 85.13836070895195, 74.54814657568932, 83.92735049128532, 75.87323427200317, 95.3199827671051, 5.801026169210672, 2.9404548788443208, 1.6825794009491801, 5.5038046929985285, 0.3740366402780637, 1.4319290569983423, 0.303254839964211, 0.12179970333818346, 0.020658526627812535, 0.3402704943437129, 24.03557226061821, 19.314454793930054, 27.710565961897373, 33.625311478972435, 32.90227107703686, 28.04719939827919, 30.844145715236664, 54.82623964548111, 31.901021003723145, 63.04155841469765, 55.89810132980347, 63.574521616101265, 58.249776139855385, 63.709847554564476, 36.745187267661095, 0.4518901580013335, 0.05609080893918872, 0.02252001482702326, 0.05626770725939423, 0.04739238545880653, 0.06338904466247186, 0.01568311665323563, 0.0370771895541111, 0.03967446151364129, 0.029678366845473647, 0.023402701153827365, 0.09108388083404861, 0.023978208846529014, 0.031287977544707246, 0.06955369433853775, 0.055584756992175244, 0.25218421476893127, 0.20215887489030138, 0.1638526702299714, 0.15646680170902982, 0.23774021014105529, 0.21918746817391366, 0.1721746986731887, 0.2361119381384924, 0.1098863258084748, 0.1982628073892556, 0.19935266609536484, 0.09238792335963808, 0.25670727831311524, 0.13219259097240865, 0.1419867732329294, 0.2064818108920008, 0.11418899375712499, 0.12688310322118923, 0.47545106092002243, 69.92178842425346, 98.664221316576, 74.3292935192585, 94.44216147065163, 83.59883531928062, 65.5043962597847, 56.55090630054474, 75.35196304321289, 34.716966301202774, 40.977609157562256, 50.2860988676548, 39.37333524227142, 17.77501679956913, 0.3249091061297804, 0.30057176831178367, 0.29048060823697597, 0.21202770236413926, 0.4602465924108401, 4.952122271060944, 6.667932076379657, 1.4807820855639875, 29.469681568443775, 114.02153044939041, 112.51944825053215, 107.72649943828583, 102.37988993525505, 103.35782065987587, 96.35896861553192, 99.19550880789757, 100.07478162646294, 96.25607773661613, 88.72762531042099, 85.07772356271744, 85.89254423975945, 91.88222363591194, 91.73871293663979, 97.3417554795742, 96.65434196591377, 97.24666178226471, 95.38293778896332, 98.79225924611092, 94.89548474550247, 97.00759381055832, 96.82877540588379, 95.11024922132492, 90.58392450213432, 90.6622762978077, 87.91330620646477, 90.91690063476562, 93.11282560229301, 90.41117817163467, 92.70649820566177, 91.97382152080536, 89.97990891337395, 88.90063762664795, 86.68307662010193, 80.92706188559532, 78.00103649497032, 79.79197919368744, 78.33019763231277, 74.91198465228081, 80.25837376713753, 88.2580541074276, 85.64668983221054, 83.22663009166718, 87.50255584716797, 72.46927052736282, 70.08738353848457, 66.49040535092354, 68.38126748800278, 79.73748251795769, 74.9888089299202, 86.96857810020447, 80.69633066654205, 78.17032501101494, 78.56079205870628, 79.67305317521095, 74.72973883152008, 74.8624125123024, 73.53355541825294, 74.41294223070145, 80.4002657532692, 77.75325179100037, 80.03559172153473, 80.9759196639061, 80.59369057416916, 81.75148084759712, 83.80027011036873, 82.13149845600128, 84.24261957406998, 81.14557296037674, 83.1156076490879, 74.42608192563057, 79.56850558519363, 80.17334192991257, 81.2258018553257, 83.2856485247612, 86.64234280586243, 80.55491745471954, 83.87267142534256, 80.88758960366249, 79.37660828232765, 79.6441139280796, 78.58091577887535, 68.10212686657906, 72.11016699671745, 71.49374127388, 72.92406812310219, 75.74532553553581, 82.88697391748428, 76.93922147154808, 90.06231129169464, 76.40290305018425, 89.03135821223259, 80.87237522006035, 97.26053103804588, 2.2079776832833886, 13.391573913395405, 36.677623093128204, 3.5189835727214813, 0.21688787906896323, 2.0270207058638334, 0.5864895042032003, 0.13370485045015812, 0.1617670719861053, 2.0188511442393064, 38.16797912120819, 37.0174540579319, 51.51302643120289, 44.872852340340614, 45.83752557635307, 55.672040060162544, 70.50019338726997, 82.29291379451752, 48.62973354756832, 77.39941477775574, 67.94648721814156, 73.0318683385849, 66.05923488736153, 80.8845953643322, 39.33149188756943, 0.3185404697433114, 0.14308777899714187, 0.1333621414960362, 0.15132441592868418, 0.18483820196706802, 0.2445497119333595, 0.15717904083430767, 0.2111384758609347, 0.0874933555314783, 0.11490095828776248, 0.15562624525045976, 0.14764628751436248, 0.07523850101279095, 0.1332421659026295, 0.14935757615603507, 0.26112044462934136], [0.015236696272040717, 0.012673610417550663, 0.025468636195000727, 0.043896476563531905, 0.038360941762221046, 0.01928481684444705, 0.06420849444111809, 0.070838708197698, 0.008026762207009597, 0.051192367100156844, 0.012657126389967743, 0.030216574195947032, 0.03122253496258054, 0.052078777152928524, 0.025849708617897704, 0.05427859563496895, 0.06110939706559293, 0.04964530831784941, 0.8191500103566796, 49.18578051030636, 67.01100781559944, 56.93595103919506, 43.50873313844204, 39.83769692480564, 39.134347066283226, 25.574028007686138, 31.497891135513783, 31.195197477936745, 27.75649979710579, 27.381915897130966, 23.698349855840206, 1.1067359754815698, 0.13082651974400505, 0.10122044550371356, 0.07161374043789692, 0.21256596723105758, 1.085458304733038, 3.6543325474485755, 0.1373399788280949, 10.421104207634926, 101.11898079514503, 95.90387463569641, 98.26647385954857, 95.02514138817787, 93.98412644863129, 92.92953103780746, 90.02383455634117, 89.52314302325249, 85.06246358156204, 77.82433077692986, 75.97237855195999, 78.45996826887131, 87.95994490385056, 85.403723269701, 85.37035346031189, 87.11819887161255, 89.10092487931252, 87.76768282055855, 87.38875955343246, 88.26794877648354, 90.7607290148735, 89.40148875117302, 87.5708457827568, 85.11307686567307, 85.48897549510002, 86.80946543812752, 84.57001000642776, 81.16321921348572, 83.99836108088493, 85.65519377589226, 85.72488203644753, 83.03459599614143, 82.84828439354897, 76.62103414535522, 71.27279832959175, 68.32978785037994, 65.14557391405106, 64.67107817530632, 64.05239537358284, 64.2690521478653, 74.42346766591072, 79.82417866587639, 83.5254080593586, 80.114885866642, 82.68979489803314, 75.58894872665405, 78.07926669716835, 62.68715523183346, 78.87068063020706, 68.95073533058167, 76.41095101833344, 78.87325689196587, 73.03239271044731, 69.35923621058464, 63.19850519299507, 65.14197170734406, 65.3370912373066, 63.78714680671692, 62.585632279515266, 65.45074313879013, 66.81959688663483, 71.73673063516617, 72.04050153493881, 75.6960953772068, 75.70308700203896, 75.28246477246284, 73.88567492365837, 74.06950905919075, 71.8010687828064, 74.75932404398918, 75.01578748226166, 70.88195130228996, 73.00553575158119, 74.56569403409958, 75.3212682902813, 76.46075874567032, 75.37239074707031, 71.06601342558861, 75.39452835917473, 74.432283192873, 71.3471831381321, 69.30476233363152, 68.5562252998352, 68.76191586256027, 66.63368046283722, 63.58184762299061, 65.96955209970474, 66.38925477862358, 72.80248984694481, 75.02207234501839, 76.1188454926014, 72.01517969369888, 77.41587549448013, 78.69114026427269, 81.85714557766914, 54.50679458677769, 1.2480969401076436, 9.15805958211422, 19.830252416431904, 2.518627163954079, 0.1826722439727746, 0.5036451027262956, 0.1075533326365985, 0.08800795330898836, 0.08598822809290141, 4.73770072683692, 39.04392331838608, 27.931396812200546, 33.2010642439127, 36.244997307658195, 39.98283013701439, 53.15570868551731, 44.988875314593315, 38.98243121802807, 24.118899889290333, 30.712201595306396, 37.22390457987785, 45.75200356543064, 49.75251629948616, 53.21554787456989, 5.726673658937216, 0.1974626534502022, 0.13667271385202184, 0.0073045504723268095, 0.026986532284354325, 0.05608641171420459, 0.05444317059300374, 0.09201416294672526, 0.016519682212674525, 0.016735148092266172, 0.018671578363864683, 0.018978141015395522, 0.06231011779163964, 0.10969157141516916, 0.07910428888862953, 0.023095233082131017, 0.051409363659331575, 0.017197758425027132, 0.04158496485615615, 0.04542148613836616, 0.11155986139783636, 0.04150096116063651, 0.06903821340529248, 0.04777167116117198, 0.03632375010056421, 0.020126134004385676, 0.035796765878330916, 0.014712701977259712, 0.008958960916061187, 0.037147300245123915, 0.023347535461653024, 0.01896552821563091, 0.052306961588328704, 0.029099627099640202, 0.812621129443869, 63.47016021609306, 75.25718092918396, 70.05962982773781, 58.51854331791401, 47.78657019138336, 47.612866312265396, 31.338843069970608, 35.741239339113235, 35.700634717941284, 31.75823986530304, 27.086569145321846, 19.54419806599617, 0.29450661095324904, 0.10203257770626806, 0.044565504140337, 0.24632393469801173, 1.016964486334473, 1.690176143310964, 0.5469548224937171, 0.47344479826278985, 21.852811686694622, 113.00362586975098, 97.4937017261982, 105.12624576687813, 95.54802373051643, 99.28046464920044, 96.93002477288246, 92.6530122756958, 91.64468318223953, 89.33576747775078, 81.18389770388603, 80.16500517725945, 83.21154490113258, 89.74328801035881, 88.40034127235413, 91.54670923948288, 89.5255596935749, 90.69642886519432, 91.24351590871811, 92.15862840414047, 92.75854781270027, 92.26144328713417, 93.72263208031654, 91.8835611641407, 89.98418748378754, 88.60481590032578, 88.56810227036476, 86.45587161183357, 85.10845631361008, 90.237375497818, 89.56536635756493, 89.01128768920898, 85.21079242229462, 85.96309125423431, 79.74990025162697, 76.0236681997776, 72.76041850447655, 70.40590524673462, 67.60873854160309, 66.93603783845901, 66.96198284626007, 73.97626206278801, 83.21060255169868, 85.11546313762665, 82.11927071213722, 85.84899857640266, 78.61813858151436, 78.59135761857033, 65.26655182242393, 77.97170966863632, 73.94171431660652, 80.85625648498535, 79.77280542254448, 77.37329497933388, 74.08968597650528, 69.14840832352638, 67.37842530012131, 66.97231829166412, 67.24470287561417, 67.33548760414124, 70.04516020417213, 70.73540076613426, 73.33116307854652, 74.55180197954178, 79.17303800582886, 78.86444136500359, 78.14643189311028, 80.32500699162483, 78.15685093402863, 77.10273429751396, 77.54363983869553, 79.42247942090034, 74.77054104208946, 76.87239065766335, 78.2687321305275, 77.39378347992897, 78.49998772144318, 77.60529533028603, 75.19577622413635, 76.05764597654343, 76.35367289185524, 75.03107026219368, 72.41594418883324, 73.72276246547699, 72.64184966683388, 70.27535945177078, 68.19232642650604, 68.24740067124367, 68.79914626479149, 74.96649652719498, 78.24169278144836, 75.69633856415749, 76.60559177398682, 78.962042927742, 84.5655870437622, 83.17627519369125, 67.99041286110878, 2.3234238009899855, 3.790524839423597, 7.2878973092883825, 5.5403791554272175, 0.5410030949860811, 0.4676010087132454, 0.13233512785518542, 0.07185546535765752, 0.03902839598595165, 2.765943305566907, 34.604306146502495, 26.84939917176962, 38.47927741706371, 42.386615350842476, 43.87826330959797, 44.18838746845722, 30.50227615982294, 40.22513173520565, 37.44369998574257, 42.56213553249836, 46.35916158556938, 57.77375288307667, 57.9766695946455, 68.88201221823692, 9.496896900236607, 0.3059588698670268, 0.1336319715483114, 0.03180993371643126, 0.05755745973146986, 0.04304238704207819, 0.016231259505730122, 0.015292911175492918, 0.06155652990855742, 0.08677908292156644, 0.05818926860229112, 0.007540633678218001, 0.02445214249746641, 0.05375892898882739, 0.02004314519581385, 0.08114330252283253, 0.11436074157245457, 0.10141892547835596, 0.16009725455660373, 0.1725562071078457, 0.14212182926712558, 0.07547011045971885, 0.2079912056797184, 0.20511458191322163, 0.1257014408474788, 0.13126299163559452, 0.21924768603639677, 0.08852189057506621, 0.14550686872098595, 0.21871946984902024, 0.10683675936888903, 0.15436575195053592, 0.11942514989641495, 0.14796806790400296, 1.9363954500295222, 78.54732558131218, 89.828692227602, 82.57268518209457, 62.95286737382412, 57.72709138691425, 61.099687814712524, 39.220587238669395, 49.636618718504906, 54.19205367565155, 48.3914939314127, 40.196219086647034, 34.625186026096344, 1.4276329125277698, 0.3667346789734438, 0.2713548392057419, 0.2582465222803876, 0.6581677298527211, 2.9900548048317432, 10.044779051095247, 1.0565198888070881, 16.603366769850254, 112.58890092372894, 103.74543026089668, 107.6042751967907, 101.43071606755257, 101.93409025669098, 99.64407473802567, 98.40281054377556, 97.05158784985542, 93.52137207984924, 85.30064240098, 83.2927617430687, 84.18648898601532, 94.48881536722183, 94.01687309145927, 94.85435575246811, 94.2148956656456, 94.8517794907093, 95.60074210166931, 95.75037807226181, 95.29946386814117, 97.14088305830956, 97.54477098584175, 95.37536859512329, 93.5656701028347, 92.97614693641663, 91.2917049229145, 90.15473753213882, 85.92203065752983, 91.35465234518051, 93.70517581701279, 90.72129473090172, 90.61401128768921, 90.47666385769844, 83.41228812932968, 78.77374023199081, 77.84282818436623, 72.34011545777321, 71.86425939202309, 71.4768473803997, 73.25299367308617, 81.0923758149147, 87.20053285360336, 88.70510011911392, 85.83632245659828, 91.12653538584709, 79.32955160737038, 75.3662958741188, 67.25645944476128, 76.11220344901085, 84.02092427015305, 88.30457121133804, 83.59034657478333, 81.13398358225822, 74.28853690624237, 70.63307985663414, 72.18508377671242, 72.87977010011673, 71.54317662119865, 69.56881776452065, 71.73012658953667, 73.50571051239967, 77.39374548196793, 78.09112206101418, 82.67717957496643, 81.39110818505287, 82.44318053126335, 82.28768527507782, 83.99785950779915, 79.13497924804688, 80.41077598929405, 81.09112948179245, 76.93067193031311, 78.39641287922859, 80.88312104344368, 81.19087412953377, 81.58306628465652, 81.59372851252556, 78.2172828912735, 81.66695818305016, 80.73713287711143, 77.94878169894218, 76.28763243556023, 76.93170547485352, 77.5996108353138, 73.14930483698845, 71.19003877043724, 72.87250488996506, 73.39821428060532, 79.02382001280785, 83.13856601715088, 79.08926010131836, 80.50477534532547, 82.93777719140053, 88.56738030910492, 87.7325727045536, 66.98535919189453, 2.633122857660055, 22.232386618852615, 32.3161069303751, 6.892897104844451, 0.730819059535861, 2.789126099087298, 0.3462583792861551, 0.19325584871694446, 0.2436682631378062, 7.956390213221312, 55.55086076259613, 36.57244473695755, 51.551928743720055, 53.10070663690567, 62.288096845149994, 70.42823284864426, 55.59112340211868, 62.24335424602032, 38.999758288264275, 47.115100622177124, 57.4011904746294, 69.33345079421997, 71.25042513012886, 81.3323937356472, 11.326616518199444, 0.3995619487250224, 0.30711759987752885, 0.2273795910878107, 0.37865460966713727, 0.14629848796175793, 0.10584529460174963, 0.13276897254399955, 0.11730070022167638, 0.19572199060348794, 0.19292180804768577, 0.2236607187660411, 0.1357579426257871, 0.17434859764762223, 0.20028548635309562, 0.16650803008815274], [0.03856158880807925, 0.021237316468614154, 0.09078697723452933, 0.05161552115168888, 0.04852001948165707, 0.0375067706045229, 0.034198250286863185, 0.01885589816083666, 0.046700874518137425, 0.08219172712415457, 0.05112950719194487, 0.025845129566732794, 0.04770533058035653, 0.08867619049851783, 0.050226810708409175, 0.017713033412292134, 0.03723023895872757, 0.12501453864388168, 0.5087637843098491, 55.396501645445824, 66.7590281367302, 55.936688259243965, 38.51895488798618, 42.323021963238716, 44.89649087190628, 28.80518652498722, 25.068930611014366, 28.164890483021736, 22.57171791046858, 29.4327000528574, 4.282200168818235, 0.02799531321215909, 0.07531679017120041, 0.06763741708709858, 0.22612788481637836, 3.5948332026600838, 1.1715496913529932, 0.8778535353485495, 2.192603233270347, 79.73194241523743, 98.30450221896172, 98.44987481832504, 93.43482792377472, 94.17610734701157, 97.73062661290169, 87.9097267985344, 87.56533607840538, 85.2870163321495, 81.00675880908966, 75.87672248482704, 77.37272500991821, 82.93067917227745, 81.87188878655434, 83.0603814125061, 85.88823527097702, 85.11355563998222, 84.74959596991539, 86.43196329474449, 86.98401287198067, 87.21459969878197, 87.3608310520649, 89.31424543261528, 83.93609762191772, 83.24295401573181, 84.70619469881058, 83.9854645729065, 80.3815783560276, 85.45099273324013, 85.43585434556007, 82.85796627402306, 81.31751373410225, 80.69852694869041, 77.43606761097908, 75.39819896221161, 73.5672976076603, 68.41098949313164, 68.9086563885212, 63.06656487286091, 66.0024431347847, 68.60897406935692, 68.97171780467033, 78.02960336208344, 79.98988017439842, 76.27626344561577, 75.30885055661201, 81.4649686217308, 82.01756536960602, 65.59356987476349, 79.09373626112938, 62.11798757314682, 66.70208439230919, 73.0338442325592, 73.01972419023514, 75.61179310083389, 72.08906292915344, 65.33700004220009, 60.21010234951973, 60.3058648109436, 61.99628010392189, 65.30499055981636, 65.9402784705162, 68.4804117679596, 70.14941141009331, 70.38850978016853, 73.38820561766624, 74.53810751438141, 75.61284944415092, 74.61684688925743, 70.22520214319229, 73.25611710548401, 72.44185119867325, 75.06871864199638, 76.09237611293793, 74.02256637811661, 74.93618175387383, 75.89768975973129, 75.18677070736885, 73.50457057356834, 70.72536170482635, 67.0493933558464, 67.84968361258507, 69.79148581624031, 67.64350667595863, 67.1137011051178, 64.34184864163399, 63.35822582244873, 63.36919583380222, 67.98138454556465, 67.99178078770638, 73.99811089038849, 72.93413758277893, 76.81054517626762, 68.40950757265091, 79.32078167796135, 75.81072002649307, 86.97207391262054, 12.81360687687993, 2.340667750686407, 14.298476949334145, 7.696814741939306, 0.1931113377213478, 0.058177268074359745, 0.14876083005219698, 0.0569759350764798, 0.04116365875233896, 0.05173671386728529, 12.524838522076607, 42.176650017499924, 24.028341248631477, 29.06119778752327, 18.028702586889267, 32.496464252471924, 34.72657598555088, 26.155638098716736, 25.39562188088894, 27.25250244140625, 41.8941655755043, 47.201298996806145, 45.579371228814125, 60.82060419023037, 9.702527616173029, 0.21349556656787172, 0.0983394579088781, 0.0631693986360915, 0.04143429032410495, 0.044220401759957895, 0.057473712076898664, 0.003360282103130885, 0.08765119549934752, 0.09618058000341989, 0.06643373519182205, 0.03717742773005739, 0.022694128238072153, 0.016325052129104733, 0.06644853361649439, 0.04884701716946438, 0.05823766776302364, 0.054780710488557816, 0.02302426892129006, 0.08182672405382618, 0.02730073163547786, 0.07220267172669992, 0.014278207909228513, 0.03128001801087521, 0.03467028960585594, 0.0443603411258664, 0.016393917867389973, 0.011021453319699503, 0.005683558938471833, 0.07296169584151357, 0.05537268087209668, 0.030037523647479247, 0.09959314571460709, 0.07773519711918198, 1.9551081396639347, 71.09942123293877, 78.82600262761116, 71.94871366024017, 49.22832302749157, 51.9261060655117, 52.73652657866478, 28.347071707248688, 30.035216622054577, 38.083619847893715, 22.477148585021496, 24.64123696088791, 1.6554038529284298, 0.059921856882283464, 0.18735377088887617, 0.07046676604659297, 1.2187647703103721, 3.430957021191716, 10.562982894480228, 0.5455799493938684, 6.215794812887907, 97.6826959848404, 100.78108012676239, 106.72843739390373, 96.71281322836876, 99.46483075618744, 98.94417509436607, 90.5309933423996, 90.35471320152283, 88.07085335254669, 85.19893705844879, 80.36302775144577, 81.07232049107552, 86.53116077184677, 84.37335535883904, 88.22197124361992, 88.09229180216789, 87.83671751618385, 88.00778433680534, 89.74122852087021, 90.73858380317688, 90.73460161685944, 89.6865950524807, 91.46420046687126, 87.22085416316986, 87.51702547073364, 86.74637362360954, 86.04837387800217, 84.64552715420723, 89.47904258966446, 88.70871752500534, 86.66282370686531, 86.57957017421722, 82.40236312150955, 81.25370755791664, 79.09635812044144, 77.70909056067467, 74.93140920996666, 72.1319930255413, 68.74404922127724, 69.98494103550911, 72.42722198367119, 74.66780215501785, 82.64443293213844, 83.89614656567574, 79.86398532986641, 76.76485642790794, 81.83408081531525, 79.90094974637032, 69.78086918592453, 78.81400287151337, 70.53458914160728, 73.2432433962822, 77.90687754750252, 76.47987172007561, 78.66329535841942, 76.73965618014336, 70.0754065811634, 63.862124383449554, 63.95928516983986, 63.845549672842026, 68.4158456325531, 68.82545605301857, 69.95769649744034, 73.4333547949791, 74.50498089194298, 74.17209595441818, 76.82873100042343, 76.57536819577217, 79.1783045232296, 74.62593600153923, 76.44234493374825, 75.25860205292702, 78.99038940668106, 77.59210243821144, 77.78926625847816, 78.11603352427483, 80.2126470208168, 77.80809044837952, 77.72549048066139, 72.29867488145828, 71.52920097112656, 69.80188965797424, 72.71311864256859, 69.92327034473419, 71.22974663972855, 68.00181984901428, 67.84466788172722, 66.08711019158363, 72.4892270565033, 70.69722041487694, 75.12487962841988, 76.97892174124718, 79.70376312732697, 71.52080342173576, 80.75131371617317, 79.01679798960686, 94.41436976194382, 21.7134028673172, 1.7389815556816757, 4.124805964529514, 8.460833095014095, 0.6517669139429927, 0.22758782288292423, 0.09658059760113247, 0.07866224346798845, 0.07876532035879791, 0.06023885041940957, 6.612878255546093, 39.885224774479866, 21.698505766689777, 28.93333274871111, 26.52711946517229, 45.122312754392624, 38.70783135294914, 18.47633946686983, 31.302815303206444, 40.55048547685146, 48.31767909228802, 57.66391597688198, 56.96887627243996, 75.32356336712837, 16.910168007016182, 0.2109957014909014, 0.06467394719948061, 0.08868777542375028, 0.05330161759047769, 0.055737869479344226, 0.06028512703778688, 0.03437982413743157, 0.08731797861400992, 0.059222709242021665, 0.03786064145970158, 0.05625519093882758, 0.004585313499774202, 0.08033551188418642, 0.07121122922399081, 0.10564639902440831, 0.1102651550900191, 0.08905809969292022, 0.18397637555608526, 0.15994596033124253, 0.1566359371645376, 0.12369537857011892, 0.1432761806063354, 0.0800645982963033, 0.14706566085806116, 0.14586465811589733, 0.1384024671278894, 0.11521165841259062, 0.11732313534594141, 0.25314903643447906, 0.16266977589111775, 0.1343063314561732, 0.25637265876866877, 0.25421179190743715, 3.0290518747642636, 87.83126100897789, 87.08243519067764, 81.82874590158463, 57.935684993863106, 63.669767305254936, 63.309292048215866, 42.37889416515827, 36.47196292877197, 49.625762701034546, 35.63536562025547, 38.91594238579273, 7.67195837572217, 0.31146937573794276, 0.5315470648929477, 0.251318336231634, 0.5859429866541177, 6.9989147409796715, 10.269296653568745, 1.343449498526752, 4.882525680586696, 99.79282155632973, 104.61996093392372, 109.40216392278671, 99.66126501560211, 102.47810706496239, 105.47233119606972, 95.68505197763443, 96.27737179398537, 92.53847122192383, 89.55095753073692, 86.45258098840714, 82.44078665971756, 89.38544601202011, 90.11620759963989, 91.50281399488449, 92.88052126765251, 91.90145820379257, 92.51886427402496, 94.54607829451561, 91.79999604821205, 95.00263899564743, 93.16476881504059, 95.53489163517952, 90.60670047998428, 90.64343690872192, 90.68921685218811, 89.28129360079765, 87.21845269203186, 91.40058428049088, 91.62224918603897, 91.87759548425674, 89.80378836393356, 89.086424857378, 85.97594976425171, 83.22651609778404, 81.06070831418037, 78.16093191504478, 78.85979801416397, 71.39762163162231, 72.60057628154755, 74.09264981746674, 77.62367114424706, 85.8027246594429, 86.30458652973175, 82.64172747731209, 83.56016859412193, 86.48597359657288, 85.05823820829391, 69.85346049070358, 82.18239292502403, 71.39593452215195, 79.08587828278542, 80.39614677429199, 79.06833082437515, 81.64469137787819, 78.76119330525398, 72.58815854787827, 66.60341888666153, 66.23451948165894, 68.33945453166962, 73.00685808062553, 72.36562728881836, 74.26025122404099, 77.21111968159676, 77.36647054553032, 79.56799641251564, 81.15190342068672, 79.3016991019249, 80.65675958991051, 77.54341945052147, 79.11700621247292, 80.63698545098305, 81.46871522068977, 83.43844592571259, 81.61385983228683, 82.45653301477432, 83.53073537349701, 80.74051469564438, 81.53448209166527, 76.74540147185326, 77.07005605101585, 73.69443878531456, 76.69307067990303, 74.05855044722557, 73.10948297381401, 71.93319529294968, 71.582922488451, 68.83556351065636, 77.8657865524292, 75.2289180457592, 80.76715126633644, 82.28059485554695, 84.04585093259811, 73.7187422811985, 85.93879535794258, 83.98187756538391, 95.98805531859398, 17.151836939156055, 6.74761570058763, 35.60910522937775, 21.72203980386257, 1.1074151890352368, 0.3270312328822911, 0.3220775455702096, 0.2938282582908869, 0.21547331591136754, 0.15743379044579342, 18.607791513204575, 59.38009388744831, 33.9642570912838, 46.04730471968651, 31.405445896089077, 53.06798279285431, 52.15517297387123, 36.30050852894783, 39.47453521192074, 44.81757290661335, 59.58858110010624, 72.74739280343056, 65.26090532541275, 89.18951332569122, 20.568438805639744, 0.3535178006859496, 0.15198984037851915, 0.240592016489245, 0.14414329110877588, 0.10218829513178207, 0.14907751930877566, 0.13505012670066208, 0.15519467153353617, 0.19103979575447738, 0.1381616698927246, 0.09668720711488277, 0.1612404439947568, 0.21383373357821256, 0.20028882601764053, 0.1635352536686696], [0.086204148537945, 0.018020896677626297, 0.006843304763606284, 0.02680509387573693, 0.12735298660118133, 0.07649928375030868, 0.01862553366663633, 0.0704641240008641, 0.03667142773338128, 0.0665768732142169, 0.084122773114359, 0.05291690307785757, 0.06809125523432158, 0.04281601715774741, 0.055284265108639374, 0.030587380861106794, 0.07254386669956148, 0.10064836838864721, 5.089276861399412, 61.50624319911003, 67.29900196194649, 63.8811157643795, 52.11609207093716, 42.08472155034542, 38.66452507674694, 41.62539839744568, 34.44768235087395, 21.637790724635124, 40.60332544147968, 12.099174913018942, 0.0270249365712516, 0.1398708953638561, 0.0399343542085262, 0.12084304529707879, 1.088609998114407, 2.2069612378254533, 2.687727827578783, 0.10524746496230364, 41.379270404577255, 101.44713878631592, 92.7483643591404, 97.48316869139671, 90.20836785435677, 95.64735800027847, 89.24474716186523, 85.86907669901848, 86.01527005434036, 84.74496781826019, 80.2869938313961, 73.09741482138634, 80.15503451228142, 79.54234018921852, 82.25348711013794, 81.33087381720543, 82.81354665756226, 81.81933000683784, 82.60493785142899, 82.85678833723068, 82.43659168481827, 87.4160572886467, 87.83379927277565, 87.3017518222332, 86.36358976364136, 85.06857365369797, 85.35097450017929, 84.99801144003868, 87.20087483525276, 83.65749657154083, 81.73753559589386, 80.39430767297745, 81.66998282074928, 78.83562371134758, 77.24414750933647, 72.56881758570671, 73.69368642568588, 67.40437790751457, 68.01331043243408, 65.54177105426788, 66.40703782439232, 68.02038565278053, 80.47971189022064, 78.23344722390175, 80.09504333138466, 72.72227615118027, 69.38550040125847, 79.04563084244728, 70.64466923475266, 70.26589795947075, 77.64288291335106, 75.67823633551598, 72.49007061123848, 75.22866725921631, 69.94426801800728, 71.97699174284935, 71.77428022027016, 71.54768317937851, 64.35341522097588, 62.8210524469614, 58.286888748407364, 61.71938136219978, 61.11181676387787, 66.35732889175415, 66.66958093643188, 69.68053176999092, 70.90525165200233, 73.04074466228485, 73.336710780859, 74.95088696479797, 71.75989419221878, 70.53199768066406, 74.09742996096611, 76.42242640256882, 73.45194339752197, 72.6684558391571, 72.5027771294117, 70.97994044423103, 72.798712849617, 71.09304517507553, 67.5205072760582, 68.61571490764618, 65.89571446180344, 66.17841929197311, 64.57386419177055, 68.3649891614914, 67.77774587273598, 62.681356742978096, 60.04649832844734, 65.16237661242485, 65.24301588535309, 70.01995995640755, 70.31613886356354, 72.21218392252922, 73.06361183524132, 74.03394296765327, 74.71000269055367, 83.6376540362835, 54.36130799353123, 0.7663631241302937, 2.5324826454743743, 7.191703096032143, 0.9182017296552658, 0.19306679401779547, 0.06879531589220278, 0.15649929293431342, 0.05648782826028764, 0.14270143175963312, 0.1757820855709724, 12.438132874667645, 37.49807506799698, 26.78064566105604, 24.044211097061634, 14.78447562083602, 25.767063349485397, 39.31364044547081, 31.000001952052116, 30.05947072058916, 43.26943717896938, 55.58861933648586, 50.20539879798889, 60.80448545515537, 17.462437972426414, 0.15350324276369065, 0.07865491847041994, 0.07754923717584461, 0.01860418022261001, 0.060031130706192926, 0.057377585399081, 0.07736059065791778, 0.06469378480687737, 0.026491078206163365, 0.06271333404583856, 0.014461203900282271, 0.0397483794222353, 0.06708609784254804, 0.027908758384000976, 0.10171305344556458, 0.014950230051908875, 0.021917275880696252, 0.05563039165281225, 0.048184424013015814, 0.05954442654910963, 0.025105458807956893, 0.0815088844683487, 0.017239062653970905, 0.030308580098790117, 0.07972731444169767, 0.041422579233767465, 0.03905702804331668, 0.047021345017128624, 0.053408197418320924, 0.04426104176673107, 0.03617594396928325, 0.19083319668425247, 0.08771424836595543, 9.141460172832012, 74.48612630367279, 76.87131151556969, 71.02363049983978, 67.63325482606888, 48.68092060089111, 33.036650866270065, 30.04332158714533, 32.48506486415863, 25.23693099617958, 37.3511977493763, 7.959076194092631, 0.07744438655208796, 0.1417458720970899, 0.02028631730354391, 0.3305286483373493, 0.7322594791185111, 2.181257992051542, 2.2295032907277346, 0.42202797601930797, 59.10728372633457, 105.91818407177925, 98.86398419737816, 99.04782593250275, 94.8391641676426, 100.33164784312248, 92.53765806555748, 89.7595663368702, 90.15697941184044, 87.81021773815155, 79.61133688688278, 79.60531041026115, 85.45692801475525, 84.99555677175522, 86.20698496699333, 84.34359535574913, 85.98728075623512, 84.45816680788994, 85.99502474069595, 86.31642669439316, 85.44057369232178, 91.24155521392822, 92.54775792360306, 90.32155618071556, 90.89610815048218, 90.78568607568741, 89.58996623754501, 88.28983560204506, 90.32533317804337, 86.76329791545868, 85.78416645526886, 84.33914959430695, 85.01933589577675, 81.83430880308151, 82.46674686670303, 77.92732805013657, 73.7612695991993, 70.69794997572899, 70.74369192123413, 66.26728132367134, 68.06850627064705, 71.3859410583973, 83.43040555715561, 79.3841090798378, 81.0642421245575, 75.31663253903389, 76.14724516868591, 78.52565914392471, 72.64477550983429, 75.34266874194145, 79.75854858756065, 78.5721306502819, 73.47385302186012, 80.5812120437622, 71.21412187814713, 72.58782416582108, 74.13529872894287, 77.31520369648933, 70.990891456604, 65.56076243519783, 61.25337056815624, 63.43122750520706, 64.32662665843964, 69.45245280861855, 67.98954650759697, 73.53491574525833, 74.09497529268265, 76.03100180625916, 76.66516497731209, 78.24560657143593, 74.65229898691177, 74.08681333065033, 76.10060647130013, 78.1284512579441, 77.0997628569603, 75.74979409575462, 76.234792470932, 74.27112624049187, 74.65387210249901, 73.83430927991867, 71.35063335299492, 73.18831354379654, 70.32826781272888, 67.76688605546951, 68.21315690875053, 71.91742613911629, 70.12588307261467, 66.41459181904793, 66.12877875566483, 66.28829419612885, 69.35933500528336, 72.77342140674591, 74.66847851872444, 75.34240275621414, 77.34385415911674, 76.83991000056267, 77.58840903639793, 84.83962833881378, 66.63152977824211, 1.1333601968362927, 1.0380532359704375, 3.9454211527481675, 1.4818909135647118, 0.0451051679556258, 0.13766003743512556, 0.13880288548534736, 0.007196965962066315, 0.2765384141821414, 0.2697382337646559, 8.131619710475206, 35.87394341826439, 24.674580171704292, 23.517259173095226, 26.00014664232731, 34.61779922246933, 37.923177257180214, 34.92774099111557, 36.7709194868803, 53.47768060863018, 68.70061755180359, 59.64042171835899, 70.65150126814842, 23.055929727852345, 0.1409419925766997, 0.05979037428915035, 0.016822754914755933, 0.08669204384204932, 0.05019056421588175, 0.0438030809891643, 0.02497838457202306, 0.02887324422772508, 0.11021921614883468, 0.03480089275399223, 0.060229028094909154, 0.03440955828409642, 0.07277286378666759, 0.05424874645541422, 0.06393606687197462, 0.12843215838074684, 0.1109075803833548, 0.22083859832491726, 0.13497034582542256, 0.19547530071577057, 0.1707247202284634, 0.1327697146916762, 0.15631308808224276, 0.09293187307775952, 0.1417733760899864, 0.22778982063755393, 0.145861585624516, 0.18152509146602824, 0.18166832596762106, 0.11950528700253926, 0.12640302273212, 0.30778989661484957, 0.2829877071781084, 12.2715650126338, 92.50956997275352, 88.86075496673584, 92.72697150707245, 75.55991068482399, 62.88996934890747, 61.63598343729973, 62.70766273140907, 52.76700094342232, 36.14656738936901, 58.951613679528236, 17.810463197529316, 0.4473423067247495, 0.45874641509726644, 0.30932459863834083, 0.28367312508635223, 2.7806900767609477, 8.675607070326805, 6.052957400679588, 0.5191583640407771, 55.58448135852814, 109.43512335419655, 101.83476358652115, 104.18242961168289, 98.50601300597191, 103.54045405983925, 97.20269054174423, 92.74525612592697, 92.66014829277992, 93.19064542651176, 87.51937374472618, 82.98253118991852, 89.23655480146408, 88.07276085019112, 90.3792978823185, 89.17799234390259, 90.46506687998772, 90.76272010803223, 89.64776873588562, 91.76855653524399, 89.01371195912361, 95.0032165646553, 94.56564724445343, 92.90753781795502, 94.74468603730202, 93.64503264427185, 91.76660344004631, 92.14309483766556, 93.7608428299427, 91.72686517238617, 90.52899464964867, 89.48922604322433, 88.99339824914932, 87.83740147948265, 86.17701977491379, 80.15954107046127, 79.47959035634995, 76.95154801011086, 75.28718411922455, 74.22242805361748, 72.16467887163162, 75.47703713178635, 87.53787875175476, 83.34896072745323, 83.97748500108719, 81.62325292825699, 77.61389806866646, 82.97452121973038, 81.79486691951752, 78.48983466625214, 84.64534476399422, 80.0590668618679, 76.63716048002243, 81.67208790779114, 76.55326098203659, 75.89536428451538, 76.30068853497505, 80.74531003832817, 72.73625180125237, 68.52825880050659, 65.11287286877632, 67.80549958348274, 67.04266011714935, 74.12720516324043, 72.80834913253784, 77.01013326644897, 77.5367622077465, 80.67582696676254, 80.62395974993706, 82.81544655561447, 77.98902913928032, 76.70716032385826, 79.76174801588058, 82.40390583872795, 79.72583994269371, 79.14663702249527, 79.27037358283997, 75.68525075912476, 78.05776745080948, 77.36536860466003, 72.1410745382309, 74.9594821035862, 72.08280086517334, 71.58014863729477, 72.03150361776352, 77.63317823410034, 74.90146681666374, 69.8617972433567, 68.62397566437721, 70.2555701136589, 72.78292089700699, 75.65443441271782, 75.74457317590714, 78.54050874710083, 80.81991523504257, 80.28805777430534, 83.1927815079689, 89.11490052938461, 67.55332991480827, 0.8696361794136465, 9.080694783478975, 17.08660013973713, 4.233301542699337, 0.3818313282681629, 0.3862260596361011, 0.5425145232584327, 0.13870150811271742, 0.5480352113954723, 0.5499532772228122, 21.49887777864933, 54.925532117486, 39.892554581165314, 40.79169273376465, 26.97792537510395, 40.226731449365616, 64.74559217691422, 48.90073500573635, 43.63717384636402, 60.5237603187561, 78.02926898002625, 67.37796172499657, 86.89469486474991, 30.32405812293291, 0.23390698770526797, 0.21524584764847532, 0.10954220677376725, 0.13548002316383645, 0.18158106424380094, 0.13126682111760601, 0.11480514702270739, 0.13767710683168843, 0.2162405927083455, 0.17142498109024018, 0.243871878774371, 0.12589855527039617, 0.24632524087792262, 0.20053521904628724, 0.14777732110815123], [0.04317231483582873, 0.07547236658865586, 0.06466352744610049, 0.006920896767041995, 0.015183685591182439, 0.07628875129739754, 0.07923422410385683, 0.03672420927614439, 0.0448288515326567, 0.0698332316824235, 0.045431553371599875, 0.05621749354759231, 0.030462282593362033, 0.059532611558097415, 0.06231139428564347, 0.023390674650727306, 0.10698501078877598, 0.03455972073425073, 10.430845934897661, 68.64858314394951, 52.75507338345051, 65.40053263306618, 70.50830215215683, 44.14934076368809, 47.45310388505459, 39.53252010047436, 29.445094987750053, 37.02358692884445, 23.728533536195755, 0.6715870066545904, 0.13495528022758663, 0.08723160746740177, 0.2509103331249207, 0.24861976853571832, 4.111224068328738, 2.6275480818003416, 0.1964571769349277, 8.18562526255846, 93.79840761423111, 93.5813556611538, 98.7071742117405, 90.38429841399193, 96.05981066823006, 90.21473631262779, 87.16091617941856, 86.31572753190994, 86.11867770552635, 76.78886353969574, 76.42719134688377, 77.47307762503624, 81.02258875966072, 77.00438797473907, 80.99419668316841, 77.60521933436394, 80.83208218216896, 79.57162141799927, 81.95175290107727, 83.91003862023354, 86.3063496351242, 84.82673183083534, 85.11686146259308, 85.5707623064518, 85.61718061566353, 84.00314882397652, 83.87069553136826, 81.3609454035759, 82.73749753832817, 83.93345296382904, 84.35065537691116, 82.58242785930634, 78.68667930364609, 77.86909997463226, 79.16204139590263, 70.04030406475067, 67.97734156250954, 63.03750783205032, 62.66725189983845, 64.34558764100075, 64.73526433110237, 71.27958476543427, 75.38635119795799, 78.92527610063553, 73.12617167830467, 65.55369481444359, 76.50777742266655, 75.06861224770546, 68.45841854810715, 71.366136521101, 74.78512465953827, 75.35483568906784, 72.45988503098488, 78.52135017514229, 67.8328125178814, 66.97361022233963, 73.12569290399551, 70.59932246804237, 66.78333923220634, 62.85358630120754, 58.73113431036472, 58.11479218304157, 62.16739632189274, 62.44785167276859, 63.99716153740883, 65.30941352248192, 66.10347971320152, 70.00124216079712, 72.54508405923843, 72.10841909050941, 72.33009919524193, 70.9499904513359, 73.13292771577835, 71.46039426326752, 71.31866186857224, 70.34652203321457, 72.0357745885849, 70.3775055706501, 72.0564378798008, 71.14967733621597, 70.77146843075752, 69.10154923796654, 70.18522828817368, 66.57771706581116, 62.99814194440842, 58.724515065550804, 62.296946570277214, 65.65397143363953, 64.68055486679077, 60.5262453854084, 65.19982740283012, 63.1757178157568, 73.17331954836845, 68.50422129034996, 71.03242322802544, 68.51346239447594, 78.85849088430405, 71.96103259921074, 81.04405000805855, 9.123799670487642, 0.08715999763808213, 7.679774081334472, 0.4204888507956639, 0.0561454569833586, 0.0483592257660348, 0.10086158741614781, 0.051024582353420556, 0.33814700203947723, 0.48452589428052306, 0.3653269732603803, 14.559474494308233, 38.91069486737251, 21.822369620203972, 17.134053893387318, 30.45694839209318, 24.72335435450077, 29.793285503983498, 45.30363142490387, 39.42328356206417, 45.27171313762665, 47.55328930914402, 57.32800640165806, 7.524119708687067, 0.04353134732809849, 0.12488199106883258, 0.0025039575575647177, 0.02153079134586733, 0.1030463217466604, 0.10381066706031561, 0.03972288664954249, 0.016752345509303268, 0.07577066542580724, 0.047526395064778626, 0.09713625840959139, 0.04807500918104779, 0.00822511230580858, 0.09144282797933556, 0.013611053327622358, 0.052812709254794754, 0.11758368855225854, 0.10062002576887608, 0.04435425922565628, 0.03247841581469402, 0.04308183219109196, 0.02368483601458138, 0.03135929051495623, 0.036130409498582594, 0.006641987929469906, 0.09004041377920657, 0.025549495039740577, 0.09274460695451126, 0.0019376972568352357, 0.0769050010421779, 0.012150654201832367, 0.07822048006346449, 0.06139516473922413, 16.510566249489784, 85.10223984718323, 61.63598723709583, 86.80912345647812, 92.10952743887901, 54.69899207353592, 26.17960911244154, 35.03508523106575, 32.034409046173096, 38.376933708786964, 19.650943838059902, 0.2381453337147832, 0.12151969101978466, 0.10793989509693347, 0.34313227515667677, 0.4971051192842424, 2.8834840608760715, 1.6681757988408208, 0.5449136788956821, 16.740391217172146, 103.92078325152397, 98.17263409495354, 101.85912027955055, 94.22926649451256, 99.86898466944695, 92.30055078864098, 91.39389663934708, 89.8230229318142, 88.98565426468849, 79.95028629899025, 82.09793105721474, 80.75711980462074, 83.98456782102585, 80.66828057169914, 86.54033347964287, 78.63388493657112, 82.17858552932739, 85.10483130812645, 86.0977104306221, 86.42524525523186, 88.03455010056496, 87.41950750350952, 88.17344024777412, 87.72251084446907, 88.53270336985588, 87.66496673226357, 87.29402303695679, 86.79760247468948, 87.12469652295113, 89.47869300842285, 86.27257704734802, 82.9888616502285, 81.12480327486992, 80.81593304872513, 81.18308454751968, 73.07359009981155, 72.6767697930336, 65.79203322529793, 65.03682374954224, 68.34063246846199, 70.1608943939209, 73.22150856256485, 78.92726719379425, 81.66603863239288, 72.55848214030266, 74.12567764520645, 81.82498410344124, 76.41145259141922, 73.8631421327591, 75.7087031006813, 77.61765986680984, 78.5939034819603, 77.89547815918922, 78.97161841392517, 74.3686594069004, 69.30480033159256, 72.26316198706627, 72.07466170191765, 70.56469112634659, 65.96517473459244, 62.49566450715065, 60.70104360580444, 65.1405581831932, 65.96902012825012, 67.26362586021423, 69.26083669066429, 68.72881963849068, 70.06376400589943, 73.536177277565, 74.87321153283119, 74.87146362662315, 74.57913771271706, 77.19921112060547, 73.8376758992672, 75.608449280262, 74.09436732530594, 75.40777444839478, 74.366425126791, 74.30182859301567, 73.52100849151611, 74.67680767178535, 70.06763979792595, 71.99611231684685, 70.41422680020332, 67.8515151143074, 64.06309559941292, 64.78224501013756, 67.71592319011688, 68.12649875879288, 65.94496741890907, 68.70578527450562, 66.98397606611252, 74.22043696045876, 70.6661456823349, 74.08711731433868, 70.6125457584858, 80.55991798639297, 74.38476294279099, 88.15579399466515, 14.675525017082691, 0.5798501323442906, 4.845921294763684, 0.8935724012553692, 0.11655112364678644, 0.04646011810109485, 0.07431711725075729, 0.08057878789259121, 0.4590731975622475, 0.6954485387541354, 0.16349566751159728, 10.208921693265438, 36.500966772437096, 19.219021014869213, 13.21547331288457, 43.29628273844719, 25.771991685032845, 19.95453044772148, 53.476054295897484, 54.583197087049484, 60.59684559702873, 53.363420739769936, 68.0877636373043, 8.848333451896906, 0.10687114307074808, 0.02767589656286873, 0.03253244787629228, 0.047252490621758625, 0.06483816221589223, 0.03135573562758509, 0.06153844376967754, 0.028791715594707057, 0.028511289528978523, 0.08257653069449589, 0.04204642857075669, 0.046988215544843115, 0.07701449008891359, 0.07178836036473513, 0.019346838125784416, 0.165962596074678, 0.23097563796909526, 0.2464007172966376, 0.07774721249006689, 0.10984331835061312, 0.12215413080411963, 0.13626951986225322, 0.10429381261928938, 0.11906190571608022, 0.23207386810099706, 0.2031046085176058, 0.1423924311529845, 0.1673184405080974, 0.13443632604321465, 0.120921787165571, 0.1563958523911424, 0.1889801281504333, 0.17113499430706725, 20.779141299426556, 100.35888478159904, 71.26875534653664, 83.46493810415268, 86.58539906144142, 65.98702356219292, 70.42291313409805, 60.13818360865116, 46.305151283741, 53.30879487097263, 36.19138218462467, 1.6229089465923607, 0.4331650596577674, 0.3119514451827854, 0.5056912335567176, 0.4371135524706915, 8.66269251331687, 5.831919936463237, 0.6733555148821324, 13.249779772013426, 106.00839883089066, 102.46050640940666, 106.1228258907795, 99.93695542216301, 104.13145154714584, 96.58159106969833, 96.29518523812294, 95.24866819381714, 96.24411597847939, 83.27129289507866, 85.23866772651672, 84.50008615851402, 88.14374104142189, 83.32942977547646, 93.00555735826492, 83.74719455838203, 88.09615239501, 87.92021423578262, 89.91637632250786, 90.64815625548363, 92.96491473913193, 92.99607306718826, 92.09949597716331, 95.10698899626732, 92.34528958797455, 91.27400547266006, 91.04328945279121, 89.13551822304726, 91.02425247430801, 92.16683596372604, 91.50656059384346, 90.93155264854431, 86.02584108710289, 84.76828336715698, 85.61421677470207, 76.14688038825989, 76.73844024538994, 71.04051679372787, 68.26614126563072, 73.52501347661018, 71.09642699360847, 75.73969423770905, 81.60735458135605, 85.2872747182846, 79.58300560712814, 74.70440939068794, 82.99558728933334, 80.71168184280396, 80.06193190813065, 80.26445344090462, 80.3938364982605, 81.99089840054512, 80.81993043422699, 81.9270846247673, 75.29574126005173, 73.06382462382317, 76.86452507972717, 75.75978755950928, 73.36813509464264, 68.13179567456245, 66.03347986936569, 65.27238070964813, 69.82899740338326, 69.08103033900261, 70.39746969938278, 73.11326757073402, 72.93269366025925, 75.0722448527813, 77.91493311524391, 78.80028560757637, 78.54788795113564, 78.07086154818535, 83.12145933508873, 78.58720824122429, 79.43147733807564, 77.3769199848175, 76.82691469788551, 77.04633012413979, 77.2963947057724, 76.51277035474777, 77.65030011534691, 75.39396598935127, 77.72398576140404, 72.5602376461029, 70.34582287073135, 65.96161812543869, 69.62028980255127, 73.9102292060852, 71.1225999891758, 69.9167574942112, 73.10421645641327, 71.10414817929268, 79.509646743536, 74.84488785266876, 76.48900642991066, 73.22745904326439, 84.56852808594704, 75.81641212105751, 92.53123641014099, 12.629462108016014, 4.259951887652278, 21.38316448777914, 3.4993189154192805, 0.4150386370019987, 0.1807010849006474, 0.47321850259322673, 0.24470410833600909, 1.2324738409370184, 2.0740253711119294, 0.7433387346100062, 23.901357762515545, 56.44574694335461, 33.95090080797672, 27.443843074142933, 51.92294843494892, 32.465758100152016, 39.08677361905575, 66.17721855640411, 56.099273934960365, 67.46954441070557, 64.13420498371124, 83.96020352840424, 17.98702262341976, 0.23650848248507828, 0.20026446873089299, 0.08795011031907052, 0.16179083555471152, 0.15103996556717902, 0.25680930877570063, 0.1750219037057832, 0.16474605276016518, 0.15831348777282983, 0.13426655234070495, 0.1368784817168489, 0.12598644039826468, 0.18517037242418155, 0.17657364543993026, 0.12365522095933557], [0.17251169309020042, 0.02069678062980529, 0.046866584962117486, 0.07933111148304306, 0.03460573760094121, 0.008606798855907982, 0.03433899117226247, 0.010360038322687615, 0.07838774530682713, 0.02188927464885637, 0.08372936063096859, 0.05345185425539967, 0.030792510478931945, 0.051313229560037144, 0.2155362203484401, 0.024669524973433, 0.24391107901465148, 0.19927898567402735, 14.32090999558568, 68.23085635900497, 59.17315699160099, 46.42504245042801, 30.235889554023743, 29.226386323571205, 45.850235894322395, 43.46157766878605, 33.91241267323494, 40.37321358919144, 3.6673943465575576, 0.13377103517996147, 0.07673706786590628, 0.15720471914391965, 0.08521668394678272, 0.4794649517862126, 0.797877861186862, 1.1173651926219463, 0.14314927335362881, 54.22530949115753, 101.2551274895668, 94.99065443873405, 94.8454262316227, 91.73404678702354, 91.21205359697342, 88.4756076335907, 86.2112483382225, 86.36640921235085, 79.12937074899673, 76.57862842082977, 76.52061313390732, 73.77964541316032, 74.55848202109337, 75.19045650959015, 77.15205565094948, 76.76064625382423, 78.59462544322014, 81.22881129384041, 79.54296335577965, 78.58625829219818, 80.86216896772385, 82.31754407286644, 79.86587762832642, 81.44941225647926, 81.30036905407906, 82.14976027607918, 80.35317867994308, 83.81793916225433, 83.46134349703789, 83.34615647792816, 80.81638142466545, 77.63892352581024, 78.85345235466957, 78.94244357943535, 72.32067570090294, 67.49424308538437, 66.31674706935883, 63.52911405265331, 60.28457075357437, 62.63819105923176, 67.89609432220459, 75.96496134996414, 77.73796141147614, 73.93215402960777, 64.79647144675255, 78.88071969151497, 73.52925404906273, 75.07973805069923, 67.97503128647804, 73.71880307793617, 74.8687581717968, 75.23240625858307, 71.93207815289497, 70.86584016680717, 78.38147968053818, 68.36270168423653, 64.62725132703781, 70.6758351624012, 70.43465450406075, 66.366456001997, 60.16041241586208, 57.750133350491524, 57.811044082045555, 60.85515953600407, 64.22082513570786, 64.31760594248772, 66.52679979801178, 68.01819697022438, 66.53303906321526, 70.91994926333427, 69.66337189078331, 70.0308957695961, 70.48292711377144, 70.34400656819344, 70.58912381529808, 70.97108691930771, 71.47546425461769, 69.34897676110268, 66.69358044862747, 65.97759246826172, 65.93731462955475, 67.36910820007324, 66.17123767733574, 65.93095377087593, 64.87205699086189, 64.73956570029259, 60.690206587314606, 59.58784393966198, 62.8097290545702, 61.0437548160553, 61.73247545957565, 64.29149374365807, 66.72760382294655, 66.54424846172333, 72.93390959501266, 68.13907608389854, 69.75816920399666, 70.15828013420105, 80.17984718084335, 32.99461752176285, 0.10162842634599656, 2.4342491291463375, 0.443134032539092, 0.056659679976291955, 0.03256353644246701, 0.1671217120019719, 0.14350758225191385, 0.32509449461940676, 0.10370876276283525, 0.050193106071674265, 0.2282766843563877, 18.21423903107643, 38.55794079601765, 41.72820568084717, 19.121461249887943, 35.526824444532394, 45.653915628790855, 28.24279960244894, 28.071609288454056, 43.731933161616325, 51.431790590286255, 56.76390007138252, 6.22350032441318, 0.28312384674791247, 0.0677532292320393, 0.01999837884795852, 0.04869529620918911, 0.01930673617607681, 0.08051027281908318, 0.06053062577848323, 0.05168613279238343, 0.10788745494210161, 0.04826128082640935, 0.007814748241798952, 0.06376969962730072, 0.047992081599659286, 0.07446229617926292, 0.07284209132194519, 0.005482961523739505, 0.011245266505284235, 0.020373298866616096, 0.06494908360764384, 0.04260658679413609, 0.03529016474203672, 0.057028809387702495, 0.03506402863422409, 0.01063233508830308, 0.06339437328279018, 0.030377514485735446, 0.06780468975193799, 0.0834474187286105, 0.046087563678156585, 0.2835462475195527, 0.005640844628942432, 0.23711747402558103, 0.2996626670937985, 23.88639036566019, 76.9025382399559, 73.9205950498581, 66.33220463991165, 44.94390092790127, 28.92104420810938, 44.03470851480961, 48.393249437212944, 33.54777663946152, 34.56840567290783, 1.3180027389898896, 0.0780032311740797, 0.10254540175083093, 0.2260343890520744, 0.13970352621981874, 0.8117784059140831, 0.867053089896217, 1.0849885549396276, 0.9896382526494563, 68.14657688140869, 103.3725106716156, 100.88419899344444, 97.80875042080879, 96.54026448726654, 94.62169423699379, 90.69018959999084, 88.92515391111374, 90.02001196146011, 83.73185098171234, 81.18372291326523, 79.14856731891632, 79.09463301301003, 78.30250471830368, 78.36960151791573, 77.56674259901047, 78.82493868470192, 81.46244555711746, 82.46652647852898, 80.73251992464066, 83.02605405449867, 81.47110909223557, 82.92173445224762, 83.44743624329567, 83.95007327198982, 83.13121721148491, 83.88803780078888, 83.8981756567955, 86.54628396034241, 84.90630716085434, 85.57010874152184, 84.03188288211823, 83.47395122051239, 81.08466222882271, 82.16182082891464, 75.43276190757751, 71.43438085913658, 69.74794775247574, 66.92141622304916, 65.90525954961777, 67.27115705609322, 71.2496043741703, 79.06860440969467, 80.17337992787361, 72.5782410800457, 71.05073064565659, 81.38767316937447, 76.49918988347054, 80.29327109456062, 71.45757481455803, 76.93283021450043, 78.89607846736908, 78.06718334555626, 74.28508669137955, 73.2146917283535, 77.99206137657166, 76.30977004766464, 69.8703695833683, 71.19436293840408, 73.08090850710869, 69.74890530109406, 64.13783758878708, 61.52841500937939, 60.046536326408386, 62.72419944405556, 64.44962605834007, 67.24296256899834, 68.02368387579918, 69.6275170147419, 67.07637950778008, 71.67186051607132, 70.55215179920197, 73.04588198661804, 72.2671365737915, 71.75262898206711, 72.63975977897644, 73.02839532494545, 73.14422830939293, 73.81194368004799, 67.86030024290085, 68.8193915784359, 68.80948930978775, 71.07336983084679, 69.80332598090172, 68.91039669513702, 68.21925938129425, 67.25192248821259, 65.55633187294006, 64.54241707921028, 66.21104434132576, 64.30611535906792, 64.43128824234009, 69.67484727501869, 67.37676858901978, 72.55072295665741, 73.45267295837402, 72.56312549114227, 73.52198883891106, 74.49930399656296, 84.8040622472763, 44.87917520105839, 0.34233725687954575, 1.1416905373334885, 0.35750628041569144, 0.059780533410958014, 0.009288476339861518, 0.1644341874634847, 0.16815068491268903, 0.32535967882722616, 0.12885553878732026, 0.17228202807018533, 0.10946886774036102, 16.040776558220387, 37.46930681169033, 25.165092051029205, 17.627271227538586, 40.978783294558525, 31.707512587308884, 36.01313754916191, 34.653160125017166, 52.82888062298298, 57.86483779549599, 68.52836519479752, 9.634667057543993, 0.2804496808676049, 0.1293945309589617, 0.05421045163529925, 0.038673768140142784, 0.03969514888012782, 0.04533398321655113, 0.04537090877420269, 0.059781383170047775, 0.06589174474356696, 0.031362730369437486, 0.03595409376430325, 0.016329096833942458, 0.016423696542915422, 0.018474209755368065, 0.07374104738119058, 0.28917027229908854, 0.09810947376536205, 0.12340775181655772, 0.16985968773951754, 0.15279049897799268, 0.1126417717023287, 0.14224472892237827, 0.12043620736221783, 0.13955151953268796, 0.16058601817348972, 0.1814224969712086, 0.13444009615341201, 0.14484940009424463, 0.09739458517287858, 0.2844309766078368, 0.1889755713636987, 0.33112340548541397, 0.45361087191849947, 31.757474206387997, 95.71055620908737, 77.91525989770889, 65.71029961109161, 43.43019515275955, 46.89400188624859, 64.91678819060326, 62.29678317904472, 49.47052963078022, 59.61164966225624, 5.865850215777755, 0.42615710757672787, 0.17815703235100955, 0.27919913234654814, 0.14353012869833037, 0.9070818044710904, 2.661537970416248, 2.359029552899301, 0.8883232204243541, 65.8208204805851, 109.64029714465141, 103.83812248706818, 105.13753116130829, 99.2330963909626, 98.56941640377045, 95.69821447134018, 96.33264362812042, 93.88388782739639, 87.01694950461388, 85.12916520237923, 84.80058923363686, 83.6331094801426, 83.75345662236214, 83.944221585989, 84.49056386947632, 83.08882668614388, 87.11958959698677, 88.04431557655334, 87.50700160861015, 86.34670346975327, 86.4103576540947, 87.87435069680214, 89.86613541841507, 89.33609426021576, 87.07053422927856, 88.32319021224976, 87.10444360971451, 90.32817542552948, 91.23562753200531, 89.61329698562622, 90.71354314684868, 85.82220241427422, 85.36817997694016, 88.19380715489388, 81.38087153434753, 75.71678906679153, 73.55389952659607, 71.35931208729744, 69.27651464939117, 71.28574043512344, 76.27540469169617, 82.74799257516861, 82.54026532173157, 80.47692283987999, 74.22649383544922, 84.4182613492012, 81.06348216533661, 82.76327535510063, 75.7878528535366, 81.35355100035667, 82.81712606549263, 82.01195687055588, 76.7700545489788, 77.61943057179451, 82.25433826446533, 77.07630291581154, 72.62427940964699, 75.93656167387962, 76.29759550094604, 72.45789393782616, 65.86048275232315, 64.44811373949051, 63.34494173526764, 68.75333592295647, 68.38372215628624, 70.78704759478569, 73.32987874746323, 73.45679953694344, 71.33079841732979, 79.05501633882523, 74.56902265548706, 75.52698165178299, 74.70845997333527, 76.7049640417099, 78.88164684176445, 77.25577488541603, 77.35833898186684, 77.30392590165138, 72.1943324804306, 72.29880407452583, 70.87582603096962, 74.28052693605423, 74.14919838309288, 73.56002479791641, 70.54971233010292, 70.90807110071182, 67.88759037852287, 69.72091600298882, 71.93815782666206, 68.77206891775131, 69.23159345984459, 71.57935827970505, 71.66830390691757, 74.77478921413422, 78.97049367427826, 75.7219947874546, 75.73916226625443, 78.404141664505, 88.54535669088364, 44.35281224548817, 0.2915669640060514, 8.184795007109642, 3.6233943700790405, 0.1625919245998375, 0.24690815334906802, 0.3555982484249398, 0.693526198156178, 2.1183205442503095, 0.3553735854802653, 0.2489405099186115, 0.720985543448478, 32.404247000813484, 55.89037634432316, 56.798185631632805, 30.91378077864647, 56.37684904038906, 66.83356493711472, 42.98102505505085, 42.66274653375149, 64.2866300046444, 68.45680743455887, 82.00230538845062, 11.352554876357317, 0.4777382413158193, 0.2429770861635916, 0.17970516724744812, 0.12589981692144647, 0.16011993458960205, 0.12184113744297065, 0.1394592408905737, 0.14870001847157255, 0.12626986659597605, 0.11442747549153864, 0.1314828306203708, 0.18768586713122204, 0.1692565146367997, 0.22666986042167991, 0.12080210100975819], [0.09851643786532804, 0.05419042849098332, 0.06875661289086565, 0.035050807273364626, 0.05633947665046435, 0.06202766380738467, 0.04031703152577393, 0.06465085898526013, 0.0584602341405116, 0.04608168586855754, 0.05713940423447639, 0.03090728547249455, 0.05194700512220152, 0.05450263517559506, 0.03661443079181481, 0.014732616582477931, 0.1686174958012998, 0.1873602721025236, 27.64199484139681, 65.16195103526115, 43.727156817913055, 41.35239824652672, 38.865522891283035, 42.67411932349205, 33.3702577650547, 25.42501710355282, 32.01930105686188, 7.360315723344684, 0.0346074000117369, 0.12084615489584394, 0.10313589897123165, 0.030723177187610418, 0.2444801281671971, 0.9256857249420136, 0.8838457544334233, 0.36452913482207805, 7.493429705500603, 90.74736133217812, 90.05079790949821, 98.5553951561451, 87.64796644449234, 89.06418845057487, 86.30269423127174, 88.05364027619362, 84.17408645153046, 81.94584801793098, 79.90245446562767, 74.42748785018921, 74.28999602794647, 75.59162378311157, 73.40467393398285, 73.56529891490936, 71.4243645966053, 73.87852370738983, 76.51732251048088, 73.7905204296112, 75.17422378063202, 76.02717161178589, 73.96712735295296, 76.07573300600052, 75.74949771165848, 78.54873150587082, 76.83780491352081, 78.46813023090363, 77.94695779681206, 77.43884146213531, 79.50957834720612, 79.23256561160088, 78.53983238339424, 79.06607374548912, 76.23120546340942, 73.16992253065109, 69.9922214448452, 64.63099032640457, 63.48016507923603, 60.55353172123432, 61.24470703303814, 67.75309279561043, 68.32508370280266, 72.29175925254822, 71.54951468110085, 61.64721943438053, 69.62767660617828, 72.20450073480606, 74.02022570371628, 77.03977927565575, 64.89545613527298, 68.61932471394539, 74.01054382324219, 74.21864345669746, 71.03079691529274, 68.18761467933655, 66.68668001890182, 74.226995408535, 69.9626362323761, 64.82260644435883, 65.43181255459785, 65.76154366135597, 60.28885692358017, 56.927344501018524, 55.457419976592064, 56.013565734028816, 57.39992514252663, 57.69787475466728, 58.22419211268425, 60.07663831114769, 62.519705817103386, 62.04923026263714, 63.003294467926025, 61.63836970925331, 63.37545409798622, 63.56685362756252, 65.3933434188366, 64.94355395436287, 65.65901756286621, 65.1380655169487, 63.83304074406624, 68.11546415090561, 67.51774102449417, 68.65279331803322, 67.32159554958344, 66.04528963565826, 64.20956254005432, 62.86500468850136, 61.60572946071625, 61.825939044356346, 59.173084795475006, 61.19789734482765, 59.25199896097183, 63.87192025780678, 65.11377722024918, 67.83978134393692, 68.77132415771484, 69.98221278190613, 68.55908274650574, 74.4865594804287, 77.41637706756592, 62.92439550161362, 2.9775755619630218, 0.47229028365109116, 1.0592278372496367, 0.024333179935638327, 0.019094864146609325, 0.024352787477255333, 0.16959536442300305, 0.10342235313146375, 0.024389143436565064, 0.1669861513073556, 0.013065609109617071, 1.9567563012242317, 24.707674495875835, 39.01002913713455, 33.49437050521374, 24.85236883163452, 31.52359675616026, 33.91723841428757, 51.507467329502106, 58.60448330640793, 51.39383062720299, 51.21049806475639, 6.302945511415601, 0.24313102243468165, 0.15779612178448588, 0.03620237184804864, 0.10293462852132507, 0.029420687606034335, 0.027002607203030493, 0.03787670153542422, 0.03323833050671965, 0.0779883140057791, 0.055088397493818775, 0.047063910897122696, 0.03862656754790805, 0.019624341985036153, 0.11056467847083695, 0.03618704649852589, 0.011592933005886152, 0.04010984986962285, 0.06207330217876006, 0.045989102945895866, 0.032389899861300364, 0.09787373055587523, 0.06807141020544805, 0.05431574012618512, 0.02728171595663298, 0.05749875585024711, 0.04615838683093898, 0.007867375788919162, 0.028283303618081845, 0.08005901734577492, 0.02345272932871012, 0.025824785443546716, 0.04807653800526168, 0.29090951022226363, 41.35136850178242, 78.90053942799568, 62.62465998530388, 61.90800704061985, 46.23551622033119, 33.89708809554577, 39.31365184485912, 28.328137323260307, 28.631055168807507, 4.7668603621423244, 0.14715344208525494, 0.09798973565921187, 0.12573930522194132, 0.10135380201973021, 0.40331056632567197, 0.8845724654383957, 1.073932454455644, 1.4254475547932088, 12.138745039701462, 99.12669450044632, 92.40434601902962, 103.84297862648964, 91.0705491900444, 94.36219096183777, 90.17768830060959, 93.93729016184807, 87.39974096417427, 84.65427428483963, 81.87918439507484, 78.12788888812065, 78.36909234523773, 81.3550329208374, 75.57232081890106, 77.5289498269558, 78.42439457774162, 79.1689570248127, 77.19646766781807, 78.52203413844109, 81.46078884601593, 79.57913741469383, 78.14238891005516, 81.78060248494148, 77.91109532117844, 78.17477837204933, 79.190653860569, 80.20385429263115, 80.93259438872337, 80.8719040453434, 81.54518231749535, 82.12854981422424, 81.501325070858, 82.29578644037247, 77.89704367518425, 74.35589969158173, 71.18997797369957, 69.90813955664635, 66.13703951239586, 63.58679875731468, 63.33034671843052, 71.22546806931496, 71.23813658952713, 75.61462014913559, 73.5161979496479, 69.08407777547836, 74.89717304706573, 75.6411275267601, 77.68783450126648, 77.40268260240555, 72.40074500441551, 72.43369683623314, 77.42444783449173, 78.46426963806152, 74.86114338040352, 73.75344961881638, 70.60189113020897, 76.41335248947144, 74.36440363526344, 68.06523084640503, 66.0605800151825, 66.0302272439003, 62.208905294537544, 59.25983414053917, 58.31669054925442, 57.06432715058327, 59.86227661371231, 59.53265190124512, 58.189929351210594, 59.93329480290413, 61.236290484666824, 62.83024415373802, 63.711150884628296, 62.684160992503166, 62.91339889168739, 66.35493502020836, 69.05571609735489, 66.95667073130608, 66.9499982893467, 67.5223995745182, 67.09188267588615, 71.62620976567268, 69.99190986156464, 70.42393147945404, 70.60828238725662, 70.46418651938438, 67.7577817440033, 66.3628613948822, 66.06831640005112, 66.19628593325615, 62.6805017888546, 65.46473398804665, 62.573651522397995, 67.4614280462265, 68.50492805242538, 71.27716809511185, 68.86371999979019, 73.7799645960331, 71.42437219619751, 76.87073394656181, 79.21185672283173, 70.82511395215988, 7.076243916526437, 0.08870951292919926, 0.4405884363222867, 0.06061303385649808, 0.15411567786941305, 0.04323142689827364, 0.5201678036246449, 0.2643625612836331, 0.15083053149282932, 0.16913437197217718, 0.06231917199329473, 1.2770349998027086, 23.358902670443058, 36.34608708322048, 21.094602271914482, 31.474740877747536, 28.478451557457447, 29.241767898201942, 61.40483424067497, 62.62274868786335, 55.67516349256039, 59.00137580931187, 7.611447097733617, 0.2503416105173528, 0.15413464716402814, 0.07765051064779982, 0.08203889665310271, 0.03834417293546721, 0.042357243728474714, 0.03708804346388206, 0.03367943711054977, 0.07446757284924388, 0.012779851640516426, 0.03836201045487542, 0.11482675836305134, 0.022988517812336795, 0.08975531774922274, 0.09336212577181868, 0.23538856679806486, 0.21670807152986526, 0.14957506995415315, 0.11885295403772034, 0.13564835709985346, 0.2243048435775563, 0.1893269782885909, 0.1153796212747693, 0.1534905965672806, 0.15551848540781066, 0.17165942554129288, 0.09553474825224839, 0.1479609136004001, 0.16717645281460136, 0.1589493450592272, 0.09629985055653378, 0.3404547250829637, 0.40072430041618645, 50.45231334865093, 90.75201988220215, 61.93607613444328, 60.63324764370918, 59.092734307050705, 62.336323857307434, 48.53186599910259, 41.91107086837292, 48.31661514937878, 12.56810775026679, 0.34728753031231463, 0.3047905216226354, 0.39904761069919914, 0.1583526434842497, 1.004846461582929, 3.582662930712104, 3.1996705569326878, 2.277244641445577, 11.164704356342554, 102.17391818761826, 94.64380905032158, 108.99224951863289, 94.53420773148537, 97.62957483530045, 95.50754830241203, 98.29859733581543, 92.14916691184044, 91.2472777068615, 86.7990691959858, 82.23385736346245, 82.34733447432518, 85.19499287009239, 81.09946623444557, 80.60541674494743, 81.58641010522842, 84.78122547268867, 81.77715986967087, 83.41420322656631, 86.3011971116066, 83.33678618073463, 82.70804151892662, 86.05878531932831, 82.89455071091652, 84.51992869377136, 85.11466518044472, 86.81175291538239, 84.75066751241684, 86.08581706881523, 87.64851361513138, 87.70055562257767, 85.97235515713692, 88.33139777183533, 83.16476181149483, 80.46558424830437, 76.08999744057655, 75.19596621394157, 70.34904509782791, 68.37181359529495, 69.35186460614204, 75.14596089720726, 75.5847917497158, 77.86322548985481, 81.58631891012192, 70.28957828879356, 75.84577694535255, 79.7895473241806, 78.26816976070404, 84.83999311923981, 76.98114082217216, 74.29860636591911, 81.46322831511497, 81.18011310696602, 76.88788622617722, 75.46819880604744, 74.01879698038101, 83.15549030900002, 77.50672101974487, 69.8495315015316, 69.93499651551247, 72.26982682943344, 67.78596103191376, 63.3945556730032, 61.69660918414593, 61.52070142328739, 63.990831077098846, 64.13083076477051, 63.6200013756752, 65.75727269053459, 67.85037517547607, 67.06659883260727, 67.38541692495346, 67.5533527135849, 68.20827797055244, 71.26642987132072, 73.22811260819435, 70.82986369729042, 72.40188494324684, 72.56596773862839, 71.9256716966629, 75.45610785484314, 72.5950437784195, 76.00498840212822, 74.69197645783424, 73.3536122739315, 70.01728489995003, 70.9324885904789, 68.53670954704285, 70.59596344828606, 67.72978484630585, 69.96818393468857, 66.61869406700134, 72.55441635847092, 72.66937538981438, 74.59660917520523, 73.12165752053261, 75.71019262075424, 73.81271883845329, 80.50826355814934, 84.63946267962456, 78.63663598895073, 7.387709878385067, 0.6921694334596395, 2.4542479310184717, 0.24940718722064048, 0.3949410404311493, 0.2822142408695072, 0.9670152165926993, 0.7729298248887062, 0.2710446511628106, 0.5710711190477014, 0.18035616434644908, 4.149223929271102, 42.26462669670582, 55.78850381076336, 47.401761040091515, 41.663373559713364, 45.96912771463394, 48.55228990316391, 72.48006194829941, 77.9529918730259, 69.47927936911583, 74.16273325681686, 10.914688222110271, 0.5977496656123549, 0.2973807411035523, 0.2930201782146469, 0.15064536564750597, 0.10997564328135923, 0.1691432183724828, 0.1409309939481318, 0.2122050608159043, 0.1194717938778922, 0.18791369162499905, 0.11616928124567494, 0.15931143891066313, 0.10267575256875716, 0.18015884212218225, 0.14938329899450764], [0.0941957654140424, 0.01030859357342706, 0.020768106587638613, 0.006120508587628137, 0.03421999892452732, 0.0012915962452098029, 0.010562267998466268, 0.011326706080581062, 0.06307583607849665, 0.048200684468611144, 0.02686267896933714, 0.04682167018472683, 0.05761464963143226, 0.011336962561472319, 0.04518527908658143, 0.1911732932785526, 0.27952181815635413, 6.390771623700857, 60.618508234620094, 44.15160924196243, 43.322227746248245, 37.01787583529949, 39.80967342853546, 47.245486825704575, 27.493314519524574, 35.0951562076807, 15.42988808825612, 0.3734220826299861, 0.6977117923088372, 0.1314444318995811, 0.2623472147388384, 0.042590341181494296, 0.4252511530648917, 1.1212017992511392, 0.34413720248267055, 0.8032110531348735, 27.034078761935234, 101.8897770345211, 84.9999189376831, 96.32484644651413, 86.5620531141758, 84.97318357229233, 85.17997607588768, 89.73602280020714, 80.12215107679367, 79.52429875731468, 75.11968150734901, 73.24920907616615, 75.70634722709656, 74.70388501882553, 75.0346040725708, 77.17810705304146, 75.95887407660484, 73.45467925071716, 72.97095760703087, 73.54485601186752, 74.09923106431961, 75.83593547344208, 72.54662677645683, 73.82161036133766, 72.10760593414307, 73.2172679901123, 71.93137139081955, 72.3372808098793, 71.7765448987484, 74.17293190956116, 73.5613015294075, 74.75750774145126, 69.79737550020218, 68.07613626122475, 66.02227807044983, 63.35428923368454, 61.59842625260353, 61.0218869894743, 58.872376531362534, 58.89355279505253, 58.36490236222744, 61.885022073984146, 62.677359357476234, 63.710660710930824, 61.37607358396053, 73.0730353295803, 74.05696973204613, 78.16453412175179, 75.60567542910576, 66.77624881267548, 67.78304278850555, 68.77909854054451, 72.13047310709953, 73.20952400565147, 76.89088046550751, 74.67704325914383, 71.80432140827179, 66.66177615523338, 66.4494739472866, 68.02312150597572, 64.4734051823616, 60.00207111239433, 55.543112978339195, 53.74192602932453, 56.96280039846897, 55.78897498548031, 54.49511781334877, 51.74987152218819, 55.32106429338455, 52.96862952411175, 54.274079874157906, 53.2111781090498, 53.73522698879242, 54.635524079203606, 56.92504942417145, 60.032849460840225, 62.00555540621281, 61.44997201859951, 62.950359508395195, 61.76169589161873, 62.78470739722252, 62.37252451479435, 63.97817015647888, 64.24930840730667, 65.13288259506226, 66.82611733675003, 65.47893762588501, 63.56552369892597, 63.06313745677471, 61.247910261154175, 59.19181019067764, 62.65771061182022, 59.18434739112854, 59.84333463013172, 62.94386945664883, 65.76316237449646, 67.24167063832283, 69.25889119505882, 66.8519939482212, 69.20488089323044, 71.87051385641098, 65.61417236924171, 14.986773915588856, 0.13353783753700554, 0.17673445399850607, 0.13499563821824268, 0.0460683494748082, 0.050366905925329775, 0.017999632291321177, 0.06122530568973161, 0.047407239544554614, 0.0052654018600151176, 0.040288328964379616, 0.016920011512411293, 5.62188858166337, 33.43539007008076, 37.44376838207245, 26.04474674910307, 26.32878340780735, 48.202640265226364, 30.740333385765553, 55.0933463126421, 44.297175630927086, 52.27754160761833, 5.387602178379893, 0.1352493339800276, 0.12545751174911857, 0.04395532887428999, 0.03663229799713008, 0.011433374038460897, 0.022483265529444907, 0.033694855228532106, 0.0657477458298672, 0.03304453719465528, 0.029782644160150085, 0.050181665865238756, 0.06636450765654445, 0.009307691470894497, 0.06359614097164012, 0.10950547788525, 0.0714805100869853, 0.029963203123770654, 0.02133566958946176, 0.014018026704434305, 0.056623886193847284, 0.024285495092044584, 0.04972744922270067, 0.03592926892451942, 0.031168677305686288, 0.056708773045102134, 0.01502453666034853, 0.04011672586784698, 0.04466835467610508, 0.03359520334925037, 0.06241288298042491, 0.09564740626956336, 0.22381676273653284, 11.909128110855818, 75.08976951241493, 52.793033346533775, 57.85340040922165, 45.553224831819534, 22.059911973774433, 42.697575464844704, 26.655022501945496, 28.078323528170586, 12.093048691749573, 0.23710904322797433, 0.9464900242164731, 0.14035026339115575, 0.3097255068132654, 0.03588358231354505, 0.4880373808555305, 0.3670654690358788, 0.8151710301171988, 1.0210276558063924, 35.8626352250576, 106.19225576519966, 91.21842965483665, 98.80525454878807, 91.49337530136108, 86.72440320253372, 89.92285877466202, 93.06129276752472, 84.42561015486717, 82.91404366493225, 77.08596959710121, 77.68418669700623, 79.81996089220047, 78.77890795469284, 79.25875380635262, 80.12375459074974, 80.75449794530869, 77.78528407216072, 76.02888911962509, 78.06854367256165, 75.85631757974625, 76.64740473031998, 76.38720229268074, 77.23287731409073, 76.11538767814636, 79.02628228068352, 73.45866903662682, 74.34495627880096, 75.33053979277611, 77.6259358227253, 76.76906660199165, 74.00847673416138, 71.05284333229065, 69.36362877488136, 68.08347746729851, 63.254126608371735, 62.94983513653278, 64.34587642550468, 61.61153934895992, 61.09964981675148, 61.096043810248375, 64.05683353543282, 61.57015196979046, 65.15554457902908, 66.6274031996727, 78.49291250109673, 79.40873935818672, 81.62536561489105, 77.02071189880371, 71.34961500763893, 72.18027323484421, 73.51253494620323, 77.52831146121025, 75.60702055692673, 79.60756748914719, 78.8220888376236, 75.44839426875114, 73.28292086720467, 68.49152997136116, 69.62885454297066, 68.14245790243149, 63.04328352212906, 60.710117518901825, 57.52203159034252, 59.589812234044075, 58.073420003056526, 57.15423792600632, 56.24188408255577, 58.4904970228672, 56.45081207156181, 55.30133955180645, 55.842977687716484, 57.59221762418747, 55.31335450708866, 56.975905895233154, 62.96437695622444, 63.80217880010605, 64.60744678974152, 66.03994712233543, 64.51223149895668, 65.45282542705536, 64.23011183738708, 66.4883154630661, 67.34676539897919, 67.29899436235428, 69.24912571907043, 67.8865796327591, 67.25186929106712, 66.21029198169708, 65.68947672843933, 62.56745785474777, 65.28580158948898, 63.08143347501755, 64.83568534255028, 65.65091639757156, 69.13371071219444, 69.7480009496212, 72.42567926645279, 70.50377279520035, 70.89778125286102, 74.81091007590294, 73.56454655528069, 26.255434043705463, 0.2620573912281543, 0.10448880449985154, 0.035992941484437324, 0.12787646788638085, 0.039404913477483205, 0.15182643430307508, 0.10437580509460531, 0.015779573586769402, 0.05819091988087166, 0.13084811624139547, 0.0717312001506798, 3.6075893556699157, 32.03980475664139, 33.98680508136749, 24.87595796585083, 29.699782021343708, 34.962801709771156, 38.93813319504261, 69.15599271655083, 55.69916680455208, 62.57275477051735, 9.100746307522058, 0.3218140237731859, 0.1385944607318379, 0.04424047685461119, 0.021921229672443587, 0.052165330125717446, 0.035847959225066006, 0.03381568800250534, 0.03927962781745009, 0.05826709762914106, 0.017084245082514826, 0.011834541965072276, 0.06685738277155906, 0.025228345475625247, 0.0057510229453328066, 0.011420259361329954, 0.2138941889279522, 0.11769139644457027, 0.1787285305908881, 0.0650857575237751, 0.12259086244739592, 0.14604007214074954, 0.1362426986452192, 0.21197912137722597, 0.15421067277202383, 0.16015840752515942, 0.14894069696310908, 0.08150730369379744, 0.11259299775701948, 0.08404921885812655, 0.19732283282792196, 0.31462362210731953, 0.5008056457154453, 11.540107112377882, 86.31343245506287, 61.964692398905754, 63.294541239738464, 52.325704023242, 54.01513136923313, 65.82233279943466, 43.69407579302788, 50.197461023926735, 27.27600608021021, 1.3286941777914762, 1.6287660948000848, 0.35072595987003297, 0.6282131653279066, 0.21829761826666072, 1.150529575534165, 4.852340575307608, 2.9118588007986546, 1.9546941993758082, 33.60923074185848, 112.93745622038841, 95.40040165185928, 105.08583873510361, 96.5674938261509, 92.54005193710327, 93.58447909355164, 98.25678437948227, 88.23119714856148, 88.14936473965645, 83.19952234625816, 82.20408976078033, 84.20605033636093, 83.51071044802666, 85.69914981722832, 88.45443516969681, 84.43134784698486, 81.68173179030418, 81.1168161034584, 82.91918858885765, 81.0155439376831, 83.25927034020424, 79.20853570103645, 80.7955813407898, 79.30920749902725, 83.85575473308563, 78.99098217487335, 80.16597032546997, 78.83876234292984, 83.40919509530067, 81.24079585075378, 81.40009850263596, 76.28319427371025, 76.67538642883301, 71.89270466566086, 68.59537839889526, 68.71513277292252, 67.61480301618576, 67.45122939348221, 65.61489433050156, 65.23909449577332, 69.51339393854141, 68.74382883310318, 70.83349630236626, 66.9411751627922, 80.22355243563652, 84.17220935225487, 82.9998430609703, 80.87316557765007, 77.60845676064491, 75.41950061917305, 78.64452436566353, 79.11238566040993, 77.892886698246, 83.60948234796524, 83.33680897951126, 77.23664671182632, 73.49757894873619, 72.101891040802, 75.2986367046833, 72.21586212515831, 66.06162875890732, 62.77917489409447, 60.42014367878437, 63.73796604573727, 62.02975630760193, 60.67292511463165, 57.87425749003887, 62.366973012685776, 59.850257858633995, 59.42500367760658, 59.192205369472504, 61.71303190290928, 60.1816912740469, 61.295844689011574, 68.57339277863503, 68.48952367901802, 67.22551390528679, 68.7313275039196, 68.06491166353226, 70.73865339159966, 67.9141053557396, 69.13478225469589, 70.97858771681786, 71.9748106598854, 75.18531158566475, 73.60841900110245, 70.72122752666473, 69.99980583786964, 69.80995282530785, 68.24860900640488, 68.38426932692528, 66.13222897052765, 68.21582436561584, 68.79588603973389, 71.85523867607117, 72.38322794437408, 76.6288161277771, 73.42612758278847, 77.13861957192421, 81.30849301815033, 76.92918241024017, 26.146776974201202, 0.3633057785918936, 0.43774363584816456, 0.47065776656381786, 0.5479190207552165, 0.250477809458971, 0.5872220930177718, 0.6714514608029276, 0.2427657225052826, 0.06714412636938505, 0.325799920829013, 0.20123504946241155, 12.191503308713436, 48.006354197859764, 52.217311039566994, 42.23300859332085, 40.93011170625687, 69.8334127664566, 47.10400901734829, 72.99108892679214, 57.005198523402214, 75.51415354013443, 9.107325654476881, 0.5081060039810836, 0.2717528975335881, 0.13205084076616913, 0.2098181951441802, 0.11579617392271757, 0.12994701537536457, 0.13551043637562543, 0.17283372581005096, 0.21901953499764204, 0.08467838939395733, 0.10869241057662293, 0.16008981823688373, 0.07505902001867071, 0.17942644626600668, 0.24937218753620982], [0.11428575497120619, 0.030312893832160626, 0.03626058962254319, 0.04360081977210939, 0.07958309288369492, 0.07091254447004758, 0.16074835555627942, 0.05161763998330571, 0.04310211508709472, 0.03744850087969098, 0.028861661157861818, 0.0515347791952081, 0.07712212376645766, 0.0296903952039429, 0.003966296008002246, 0.09174887483823113, 0.04025591195386369, 30.492780469357967, 62.14607946574688, 49.81559671461582, 45.171835497021675, 35.688433572649956, 70.4399362206459, 29.261958114802837, 34.869691506028175, 29.788265973329544, 0.5829054652713239, 0.11871398688526824, 0.09367598002427258, 0.6867347157094628, 0.0775606810930185, 0.26895669288933277, 0.051491942431312054, 0.494369741063565, 0.5744538875296712, 0.2707650396041572, 54.065163284540176, 92.39128991961479, 86.41485661268234, 87.54584312438965, 84.51131835579872, 81.79799795150757, 85.31857743859291, 83.66821199655533, 78.31434488296509, 79.72014784812927, 72.44553700089455, 77.52091705799103, 72.9864227771759, 72.8367792069912, 74.90059286355972, 75.66972479224205, 74.14650812745094, 69.51387271285057, 67.57514074444771, 70.15400156378746, 70.61750069260597, 71.07076317071915, 70.68632259964943, 67.81526505947113, 71.19649082422256, 70.41630148887634, 68.47943902015686, 70.74739292263985, 67.90155842900276, 69.11521330475807, 64.35010179877281, 63.490451127290726, 59.800761714577675, 60.7032360881567, 59.926732555031776, 59.43429417908192, 57.80969135463238, 58.374751433730125, 58.20958189666271, 57.60957129299641, 57.63315662741661, 57.199976071715355, 55.917077511548996, 57.96895980834961, 70.83091244101524, 79.98783588409424, 77.93017029762268, 74.0905599296093, 62.97365225851536, 64.70435678958893, 69.12059381604195, 65.74174672365189, 74.67718005180359, 69.50160697102547, 72.3448196053505, 69.76123943924904, 73.48203018307686, 72.73572742938995, 68.08806002140045, 68.26196148991585, 63.92909958958626, 62.10992820560932, 57.71944999694824, 56.95773147046566, 55.976665914058685, 52.90465235710144, 52.026960253715515, 52.74731419980526, 53.36977019906044, 54.13462735712528, 53.61624017357826, 51.29919670522213, 54.28237862884998, 52.2698850184679, 52.95498065650463, 54.98482033610344, 57.800058871507645, 57.730461806058884, 60.625359266996384, 57.85148151218891, 60.42400427162647, 60.93748211860657, 61.026800125837326, 61.71980693936348, 62.382681369781494, 64.18751612305641, 63.40252764523029, 63.96047070622444, 62.116422057151794, 61.829282864928246, 58.745592534542084, 62.35662616789341, 59.71522070467472, 58.36919233202934, 62.88771986961365, 65.94586417078972, 66.71361297369003, 66.88499137759209, 69.09812182188034, 66.37241408228874, 67.51259610056877, 75.07871970534325, 44.674483984708786, 1.378974267281592, 0.08130258967867121, 0.028374352150422055, 0.08279822504846379, 0.09508468763669953, 0.12549455976113677, 0.07224970162496902, 0.04370329923403915, 0.08020507200853899, 0.026227062880934682, 0.03618021873990074, 0.08103427360765636, 8.421612549573183, 29.696732684969902, 28.979462273418903, 22.050294689834118, 29.792466647922993, 37.02618218958378, 51.84195578098297, 37.09483690559864, 57.90521442890167, 17.54580929875374, 0.1736936523229815, 0.13744392403168604, 0.06443458230933174, 0.03882946701196488, 0.017214378822245635, 0.026415427382744383, 0.12095787038560957, 0.04354360018623993, 0.05641091207507998, 0.0204691732142237, 0.07997190405149013, 0.020112784623051994, 0.02599083170935046, 0.020390537101775408, 0.11838177932077087, 0.07973174506332725, 0.05119887202454265, 0.039719602646073326, 0.025085274246521294, 0.12422383224475197, 0.02460865958710201, 0.09812461357796565, 0.060096654924564064, 0.0939492165343836, 0.03930332459276542, 0.11994633794529364, 0.02133772348315688, 0.012005056887574028, 0.013195706669648644, 0.02253491158626275, 0.114700637786882, 0.04440573829924688, 41.82162746787071, 72.39305421710014, 72.09879040718079, 56.23658336699009, 19.983904771506786, 43.7873949855566, 26.70119572430849, 28.016565442085266, 22.00971096754074, 0.17681251309113577, 0.21333337761461735, 0.0559998290555086, 1.1920601595193148, 0.33779151330236346, 0.28242789034266025, 0.014890001057210611, 0.3913865686627105, 0.8810717845335603, 0.9844596055336297, 64.89433899521828, 96.58226743340492, 92.43425041437149, 91.35277524590492, 89.7456742823124, 85.26151970028877, 89.06974375247955, 85.4487432539463, 83.58737513422966, 81.22815772891045, 77.58275493979454, 81.968152821064, 76.71037495136261, 77.66853153705597, 79.18202072381973, 80.00694885849953, 75.85263937711716, 73.14339235424995, 72.06071645021439, 74.21279937028885, 72.98095867037773, 74.21460807323456, 72.93709382414818, 70.73829621076584, 73.30305978655815, 71.5845488011837, 71.97072207927704, 73.49573224782944, 68.92225965857506, 71.21196359395981, 67.19517633318901, 67.22687423229218, 62.46493175625801, 62.56415583193302, 62.7785175293684, 64.05511602759361, 62.98190161585808, 61.35943427681923, 61.63560725748539, 61.086422726511955, 61.934028044342995, 60.396402552723885, 60.470741763710976, 65.22405490279198, 75.63231199979782, 82.05017521977425, 79.31342527270317, 72.34643071889877, 66.90796494483948, 70.85081577301025, 71.31162464618683, 70.164245814085, 76.60027205944061, 73.61331313848495, 74.129409044981, 70.94156250357628, 74.64827880263329, 75.93650087714195, 72.64371156692505, 69.89526584744453, 66.09860077500343, 61.66677698493004, 60.160138830542564, 58.47796529531479, 57.59494207799435, 55.52051559090614, 54.550226256251335, 54.64774042367935, 56.340948566794395, 55.534023866057396, 57.27044329047203, 55.84745764732361, 57.09946386516094, 55.96922971308231, 54.00847412645817, 57.15009614825249, 59.14128050208092, 59.36956845223904, 61.92114293575287, 59.399974420666695, 61.824677512049675, 64.4492156803608, 64.01541575789452, 65.11734142899513, 65.34830823540688, 66.57153099775314, 67.31771975755692, 66.4949119091034, 67.31701299548149, 65.97967475652695, 60.91964207589626, 65.75701430439949, 63.57106760144234, 62.865620255470276, 67.75634542107582, 69.42903086543083, 69.97597351670265, 70.11497005820274, 69.02898073196411, 69.77073132991791, 72.27291226387024, 78.80010321736336, 57.02108547091484, 3.2576582953333855, 0.11916272647795267, 0.09593412760295905, 0.09288381901569664, 0.17743064789101481, 0.10577633423963562, 0.05876049224752933, 0.07298393058590591, 0.07631410306203179, 0.07924373101559468, 0.10670308372937143, 0.053064831663505174, 4.196586962789297, 29.412029162049294, 26.700084283947945, 22.863680943846703, 25.708212107419968, 22.60655254125595, 70.22788479924202, 54.903831481933594, 65.67442953586578, 24.666708894073963, 0.17606067296583205, 0.13902867649449036, 0.03498219572065864, 0.05412647391494829, 0.028588625027623493, 0.08304057337227277, 0.057427086649113335, 0.07285425512236543, 0.07003878432442434, 0.11485757233458571, 0.07547595858341083, 0.05328144230588805, 0.03437943822063971, 0.03699131193570793, 0.1531429894384928, 0.1631897542392835, 0.14924720395356417, 0.19023973087314516, 0.10356196595239453, 0.308043384575285, 0.13829022471327335, 0.2751476294361055, 0.1956390927080065, 0.20224331645295024, 0.12173021605121903, 0.19877913437085226, 0.16085397801361978, 0.138526672963053, 0.09972224230295978, 0.08196539434720762, 0.163870066171512, 0.129628352005966, 44.214286878705025, 85.76334357261658, 73.40992525219917, 71.74988552927971, 55.504111871123314, 102.36769258975983, 49.42364774644375, 48.22949342429638, 44.28026273846626, 1.0131055559031665, 0.36349098896607757, 0.6434840115252882, 2.4807049613445997, 0.6080968666356057, 0.39531769522000104, 0.29864476702641696, 1.7336472356691957, 1.9448230415582657, 1.095997632946819, 66.37328043580055, 101.00082233548164, 95.44710874557495, 96.86031371355057, 93.31138774752617, 90.36922842264175, 94.07252490520477, 91.512511074543, 87.96337231993675, 87.22703263163567, 83.3447277545929, 84.92576211690903, 80.58767169713974, 79.6106605231762, 83.160110861063, 84.64415922760963, 81.36752665042877, 78.24125200510025, 74.4091348350048, 78.20883214473724, 76.99580043554306, 79.26823049783707, 79.03531819581985, 75.50282254815102, 80.40174767374992, 77.60642006993294, 75.80552190542221, 77.2969114780426, 72.21599131822586, 75.61803996562958, 72.43849977850914, 71.43254175782204, 67.0569397509098, 69.47767585515976, 66.91521495580673, 66.84639304876328, 64.63952466845512, 65.41882485151291, 65.76881647109985, 64.05790507793427, 66.08961805701256, 64.54269826412201, 61.92278444766998, 65.0379940867424, 77.4216739833355, 88.78761649131775, 85.08485198020935, 79.46472555398941, 69.5087505877018, 70.48896878957748, 72.10912585258484, 72.78750345110893, 79.45910185575485, 73.33904385566711, 75.3796711564064, 74.62004631757736, 78.26712861657143, 78.11158776283264, 75.46667128801346, 73.41070801019669, 70.2643932402134, 67.74841904640198, 64.0024508535862, 60.925972536206245, 61.34304575622082, 59.171420484781265, 57.84312576055527, 59.13947939872742, 59.56826739013195, 60.68118967115879, 58.68793062865734, 57.293633446097374, 61.691513657569885, 58.44841048121452, 60.11856526136398, 61.07177071273327, 64.56899285316467, 62.4972490221262, 67.14870482683182, 63.63465338945389, 67.27570161223412, 66.27542048692703, 68.41453090310097, 70.8919295668602, 70.20602837204933, 71.13002479076385, 71.17514356970787, 70.30754372477531, 71.36932834982872, 68.60746935009956, 65.5881741642952, 71.0551156103611, 67.4017408490181, 65.97734168171883, 71.84861183166504, 73.91792759299278, 74.06710758805275, 73.56770038604736, 72.68781200051308, 73.87207925319672, 76.46686121821404, 81.41481891274452, 55.37640452384949, 3.394952528178692, 0.26806941081304103, 0.24281053338199854, 0.40177669550757855, 0.6807530648075044, 0.5428414244670421, 0.3333963069599122, 0.21452491055242717, 0.4215909994672984, 0.12103319095331244, 0.2840573200955987, 0.15046404412714764, 14.221288841217756, 45.488483905792236, 43.135289177298546, 35.90152993798256, 40.42300991714001, 55.72820104658604, 68.63137766718864, 51.1593946069479, 79.83246222138405, 27.152330316603184, 0.4338194854790345, 0.32573277130723, 0.23073083313647658, 0.1604823549860157, 0.17418676492525265, 0.154390569368843, 0.2972097205929458, 0.13092957437038422, 0.28333669470157474, 0.21674718271242455, 0.17259286920307204, 0.08194482943508774, 0.07740959466900676, 0.17425435973564163, 0.22445395588874817], [0.08970075505203567, 0.018575609392428305, 0.05234592063061427, 0.08677574325702153, 0.04228126636007801, 0.01981116467504762, 0.05410292185842991, 0.08154559109243564, 0.03699487053381745, 0.06194802394020371, 0.003930356579076033, 0.04380646889330819, 0.0056685007621126715, 0.049970454347203486, 0.11256382393185049, 0.21804019692353904, 2.430033730342984, 53.50218929350376, 52.709365636110306, 26.166313625872135, 37.63114012777805, 65.81517398357391, 27.318400405347347, 32.905500903725624, 44.257600754499435, 2.9741407837718725, 0.13145007222192362, 0.12513714144006371, 0.0759654346620664, 0.2043857632088475, 0.31335923995357007, 0.08836662585963495, 0.14261080068536103, 0.10723984203650616, 0.35627921344712377, 4.778622156009078, 79.07628759741783, 84.44640263915062, 86.85902237892151, 80.62227264046669, 83.9111177623272, 79.08570349216461, 82.4811252951622, 80.70248633623123, 76.0182648897171, 72.93922930955887, 74.60908770561218, 72.75100260972977, 73.74861627817154, 76.587915122509, 73.82563814520836, 73.25409561395645, 70.55409729480743, 68.55377823114395, 69.01181325316429, 69.02695164084435, 70.09485393762589, 67.35117316246033, 67.64825642108917, 64.515590518713, 67.51041501760483, 64.06104370951653, 65.58935210108757, 67.02448949217796, 66.84915170073509, 63.93217742443085, 60.70943735539913, 59.31592673063278, 59.905104115605354, 55.5087324231863, 60.13491578400135, 60.276727974414825, 57.39629253745079, 59.07769851386547, 57.374660298228264, 57.636264860630035, 57.28381857275963, 56.99650838971138, 63.78568768501282, 69.45989280939102, 72.70779132843018, 71.62701532244682, 67.71788388490677, 64.08714070916176, 68.07521671056747, 73.11302438378334, 75.11926352977753, 73.37394118309021, 73.42876464128494, 74.80062782764435, 71.23029381036758, 65.26050254702568, 71.2432587146759, 70.24708896875381, 72.37893417477608, 69.96643602848053, 66.32240876555443, 56.03959433734417, 54.49133701622486, 54.2652453482151, 53.858841955661774, 52.34986312687397, 53.435426875948906, 54.335503578186035, 53.21995943784714, 52.83930726349354, 50.79230010509491, 51.78486004471779, 52.55490392446518, 52.148367539048195, 51.06164485216141, 54.285346269607544, 53.42681273818016, 52.64454111456871, 52.42793753743172, 55.378160029649734, 56.05487331748009, 56.246656626462936, 55.994741544127464, 58.25723133981228, 57.73618049919605, 60.03607168793678, 62.05534793436527, 63.37873712182045, 63.158360347151756, 60.449937880039215, 60.055135264992714, 60.11167623102665, 58.15372109413147, 56.75417259335518, 62.12147578597069, 63.90550285577774, 65.79802930355072, 68.39045539498329, 65.10849550366402, 62.738414481282234, 68.83848935365677, 68.11635330319405, 70.73523357510567, 9.721470549702644, 0.2966982324142009, 0.2829322242178023, 0.13660669239470735, 0.24982477887533605, 0.10649885953171179, 0.02862796998670092, 0.02305440753843868, 0.011457733180577634, 0.08237245492637157, 0.04767647587868851, 0.11139790251036175, 0.03514118230668828, 7.3722651321440935, 30.03792777657509, 25.10429911315441, 31.967840418219566, 47.681809812784195, 27.208650894463062, 18.85163962841034, 47.26603992283344, 24.57276463508606, 0.028815378973376937, 0.18278791510965675, 0.07453833663021214, 0.02308822535269428, 0.050129370429203846, 0.06793990905862302, 0.033928639168152586, 0.01795371932530543, 0.06672859788523056, 0.030022020182514098, 0.01587022878084099, 0.096540952072246, 0.10473983595147729, 0.04801524402864743, 0.022833883922430687, 0.022105757270765025, 0.050651367419050075, 0.06625962734688073, 0.08970055467216298, 0.03509758855216205, 0.02954182094981661, 0.05122212722199038, 0.05724395057768561, 0.0540362621541135, 0.037110085249878466, 0.02393188584392192, 0.029511005122913048, 0.05228941350651439, 0.014756817090528784, 0.09868793335044757, 0.1298571561346762, 4.3599596712738276, 68.38644281029701, 66.97345823049545, 50.00502035021782, 47.73663707077503, 45.85685133934021, 30.020053535699844, 33.76533776521683, 38.55475276708603, 1.469654026441276, 0.018391410194453783, 0.08561198890674859, 0.07589307526359335, 0.25592760764993727, 0.4772404383402318, 0.15683440229622647, 0.12965386704308912, 0.14701564010465518, 0.3958741872338578, 7.53779137507081, 88.22319477796555, 89.64415892958641, 92.06984996795654, 87.48043343424797, 88.13850492238998, 86.21877953410149, 86.6633328795433, 86.43023818731308, 80.09563609957695, 77.90398970246315, 79.31024104356766, 77.83621653914452, 80.53350940346718, 78.50437268614769, 78.20170372724533, 78.87871339917183, 73.35917517542839, 71.84206858277321, 73.77918183803558, 71.384656727314, 75.30680626630783, 70.05332976579666, 71.80654048919678, 68.19009214639664, 69.9388799071312, 68.32490891218185, 70.12799575924873, 71.62137642502785, 68.93650129437447, 64.96417924761772, 63.949686884880066, 63.80464106798172, 63.36259938776493, 59.54726591706276, 61.458380967378616, 62.74995066225529, 60.91746859252453, 62.21422880887985, 60.59105470776558, 59.04924564063549, 59.830175936222076, 59.462625458836555, 69.24356281757355, 75.68801701068878, 76.57800525426865, 73.77532884478569, 70.28469935059547, 67.2414730489254, 72.51932144165039, 74.8421747982502, 79.47016686201096, 77.0533749461174, 75.14134794473648, 76.7667031288147, 73.41882437467575, 67.9005628824234, 73.11733335256577, 73.56545090675354, 74.56603601574898, 72.62134596705437, 68.89311522245407, 60.2702759206295, 56.30466051399708, 58.0582170188427, 57.07633450627327, 56.874443739652634, 56.4840716868639, 57.58703850209713, 55.45973785221577, 54.11928378045559, 53.187277391552925, 55.292915403842926, 54.520504251122475, 54.744300842285156, 55.175528302788734, 57.60639846324921, 54.894407987594604, 57.36332170665264, 57.00925290584564, 57.69824333488941, 58.59462283551693, 57.370818704366684, 58.15355770289898, 62.1953172236681, 60.78713558614254, 61.33826941251755, 63.175106048583984, 66.29229918122292, 65.96293285489082, 63.98593693971634, 62.872934862971306, 62.2871582955122, 64.44480791687965, 61.29904791712761, 65.85694894194603, 67.61978074908257, 69.07694175839424, 71.18104085326195, 67.37041532993317, 64.06768575310707, 71.26677945256233, 69.47938576340675, 75.25192961096764, 16.68409153819084, 0.29588201839942485, 0.06568239972693846, 0.06107460147177335, 0.5946658342145383, 0.23589340533362702, 0.018466242800059263, 0.07937488335301168, 0.027351262615411542, 0.0636628080974333, 0.040294937789440155, 0.052685271366499364, 0.009905530387186445, 4.044121094048023, 30.000577680766582, 25.976624004542828, 30.3195458650589, 32.858706414699554, 32.01557345688343, 30.380065217614174, 55.3809604793787, 33.39470185339451, 0.08029208882362582, 0.12282086885534227, 0.029847665573470294, 0.0315134011907503, 0.01704966100078309, 0.06406121523468755, 0.02885294277803041, 0.07376932320767082, 0.06361002655467018, 0.017670298693701625, 0.029015987056482118, 0.024365159079025034, 0.07310780987609178, 0.03885277415974997, 0.040490219107596204, 0.21897009311942384, 0.11308218439808115, 0.13975829671835527, 0.1828767650295049, 0.2277486611274071, 0.09645102603826672, 0.10115553726791404, 0.1737903244793415, 0.1188880650443025, 0.20212619070662186, 0.10635450438712724, 0.10965824898448773, 0.19395130046177655, 0.11985204808297567, 0.35921348724514246, 0.3633625974180177, 4.077835259959102, 78.79332438111305, 74.64225992560387, 41.66706696152687, 57.13992029428482, 98.26858654618263, 50.25877833366394, 51.34897403419018, 65.29854610562325, 4.501414680853486, 0.2198817621683702, 0.19623239524662495, 0.22551144211320207, 0.8116367447655648, 1.356543239671737, 0.8487928728573024, 0.2961748105008155, 0.6496227602474391, 1.0935827437788248, 7.3508053086698055, 93.74427571892738, 95.80221489071846, 97.75629043579102, 93.29431146383286, 92.78003185987473, 87.00168952345848, 92.13418051600456, 90.53898811340332, 85.28678834438324, 82.1929107606411, 83.15983727574348, 81.25544786453247, 83.90327498316765, 81.9683276116848, 83.02055954933167, 82.63011530041695, 78.06750252842903, 76.47423282265663, 76.96645841002464, 76.6048014163971, 77.67789423465729, 74.19985726475716, 76.61267459392548, 72.62203752994537, 74.08418387174606, 72.36638724803925, 74.08218517899513, 77.56812572479248, 74.52963396906853, 68.75210478901863, 67.57489755749702, 67.79696524143219, 68.06904584169388, 63.580567091703415, 65.97858801484108, 68.74133616685867, 65.74706643819809, 66.05481952428818, 64.49257135391235, 63.77719894051552, 64.8637506365776, 62.870730981230736, 72.07435011863708, 77.23819702863693, 80.23426026105881, 78.43464642763138, 73.14899325370789, 69.878691136837, 75.4207469522953, 80.03425419330597, 81.14757925271988, 81.96805402636528, 78.40978056192398, 79.55247044563293, 76.14308059215546, 70.16464099287987, 75.25674015283585, 76.72401621937752, 79.31990012526512, 75.79654678702354, 70.74781849980354, 62.30717942118645, 61.237396225333214, 59.883821457624435, 62.02919773757458, 60.025329664349556, 60.574191212654114, 60.95345266163349, 58.55980150401592, 59.24480974674225, 57.66627945005894, 60.07112480700016, 58.25079068541527, 60.55966079235077, 58.19611541926861, 61.889540031552315, 60.178533643484116, 61.046547666192055, 60.76274089515209, 63.96975740790367, 62.72029705345631, 62.62143395841122, 62.8067272156477, 65.55933371186256, 64.50275480747223, 67.02325075864792, 68.87841761112213, 72.28760987520218, 68.15433606505394, 68.956678211689, 66.98775306344032, 65.90934813022614, 66.5278485417366, 65.5763491988182, 67.76397541165352, 70.27827009558678, 73.91847476363182, 76.88673868775368, 71.486536860466, 68.86071056127548, 75.00771671533585, 75.75952157378197, 78.74685287475586, 16.434881910681725, 0.6238572334405035, 0.5525541782844812, 0.4281220771372318, 1.3732270756736398, 0.8589606522582471, 0.23956682853167877, 0.21917618752922863, 0.08003324997844175, 0.21105452411575243, 0.11414659486035816, 0.27724342478904873, 0.17035247379681095, 11.96702180430293, 48.41095268726349, 42.504618018865585, 48.7257581949234, 68.52891996502876, 38.58502194285393, 27.408345378935337, 66.26952320337296, 37.61280231177807, 0.19271065219072625, 0.2368931079399772, 0.16408557101385668, 0.10728470486355945, 0.12363091562292539, 0.31620647467207164, 0.11088807674241252, 0.1416520943166688, 0.10419145561172627, 0.20658507331972942, 0.09803354463656433, 0.13154965359717607, 0.2388543073902838, 0.10950451309327036, 0.13930919347330928], [0.09280672471504658, 0.048024684147094376, 0.021850406519661192, 0.007865132647566497, 0.020283302328607533, 0.04188152706774417, 0.04148573971178848, 0.08372775017051026, 0.12993343407288194, 0.056901371499407105, 0.04256645144778304, 0.042591465535224415, 0.07753198224236257, 0.019218574598198757, 0.08703474537469447, 0.05566915402596351, 20.87554782629013, 61.842190772295, 32.96338699758053, 40.47500252723694, 23.600983880460262, 27.13452447205782, 26.680895313620567, 39.88618992269039, 9.819666780531406, 0.042808940779650584, 0.0426768978650216, 0.04873457808571402, 0.10497560884687118, 0.15490109275560826, 0.16930169658735394, 0.3930277837207541, 0.10653508375980891, 0.26422294846270233, 0.186628544179257, 15.424938853830099, 86.86935782432556, 81.95545390248299, 83.46612364053726, 78.57683479785919, 81.97252258658409, 84.24749851226807, 81.02190479636192, 80.21002516150475, 75.32479450106621, 75.19865646958351, 76.05961427092552, 73.69672626256943, 75.21803542971611, 74.33868661522865, 76.81137353181839, 74.57359001040459, 66.18976548314095, 67.11140602827072, 65.82981839776039, 65.07640242576599, 67.74369969964027, 67.79010280966759, 67.44070395827293, 65.04060074687004, 66.04962140321732, 63.41498717665672, 64.71558898687363, 63.934464901685715, 62.26071931421757, 58.81289452314377, 60.424965620040894, 60.000794380903244, 58.294530138373375, 58.937592431902885, 58.905529752373695, 56.43780156970024, 57.38165192306042, 56.8167058378458, 56.93748615682125, 57.541972920298576, 57.850497364997864, 58.90547275543213, 66.34975969791412, 71.7070922255516, 75.99436417222023, 69.51164603233337, 68.76017555594444, 67.06093713641167, 68.86368960142136, 69.71951007843018, 73.94759640097618, 70.94978526234627, 73.35855960845947, 71.56287476420403, 70.91498672962189, 66.9800166785717, 66.40327602624893, 69.03740867972374, 71.78024590015411, 70.38340285420418, 71.13043516874313, 62.18633450567722, 53.20175461471081, 54.02065247297287, 53.91090676188469, 52.4102570861578, 52.84892074763775, 52.54723973572254, 51.41636721789837, 51.19013115763664, 51.84008248150349, 50.97584545612335, 51.918217688798904, 51.74377664923668, 51.312682181596756, 51.37706212699413, 51.60576045513153, 51.87270373106003, 52.925262451171875, 54.30723689496517, 53.37663263082504, 54.72893446683884, 53.56253385543823, 55.789202973246574, 55.292554423213005, 54.373345747590065, 56.82882718741894, 54.843908697366714, 58.79973582923412, 59.72577653825283, 59.9712585657835, 59.33455713093281, 61.66877567768097, 57.07966312766075, 62.06610895693302, 66.14815011620522, 63.19677248597145, 64.88810732960701, 64.60705161094666, 60.382871478796005, 65.39813876152039, 66.52714177966118, 70.95935314893723, 43.459259793162346, 1.2642168626189232, 0.06885609778692015, 0.03370682607055642, 0.04423214995767921, 0.06493700144346803, 0.04068518872372806, 0.0667813497420866, 0.08050987948081456, 0.05197985999984667, 0.07832956835045479, 0.10383388143964112, 0.06839800713350996, 0.1794735578005202, 8.103156387805939, 29.29287325590849, 31.469670049846172, 26.78633775562048, 36.56891472637653, 37.85551428794861, 41.7040503770113, 39.25518438220024, 0.25665316090453416, 0.0186724373998004, 0.02582031585916411, 0.04850635654293001, 0.04555326187983155, 0.06391269664163701, 0.022425875249609817, 0.029550630242738407, 0.021015711172367446, 0.01889675339043606, 0.016225090403167997, 0.0641262496355921, 0.04365951623185538, 0.04163472585787531, 0.021504966462089214, 0.07288370354217477, 0.038449465137091465, 0.07029727436020039, 0.04849740995268803, 0.028502777095127385, 0.041936783673008904, 0.06640030143898912, 0.1579822227358818, 0.02409100045042578, 0.008810230810922803, 0.021556334213528316, 0.07977296394528821, 0.07528150847065262, 0.008565860134694958, 0.07329572166781873, 0.04314659941883292, 28.372188359498978, 77.22186550498009, 49.36324618756771, 54.82458673417568, 23.262790627777576, 30.76200932264328, 34.92731161415577, 41.413381174206734, 7.750660702586174, 0.17535304999910295, 0.12183204613393173, 0.11779749387642369, 0.21964463114272803, 0.21615687845041975, 0.11996216053375974, 0.3219302440993488, 0.27654046250972897, 0.15723395976237953, 0.3806392609840259, 18.84766884148121, 94.03442814946175, 84.3296729028225, 88.50285217165947, 84.15441870689392, 87.88790836930275, 88.32113072276115, 85.9449054300785, 81.96985512971878, 81.37314274907112, 78.47911924123764, 80.32632932066917, 77.64336928725243, 79.59107637405396, 77.73999810218811, 79.2593389749527, 78.21608975529671, 71.03931605815887, 69.27869573235512, 69.2002983391285, 68.26022878289223, 69.92951720952988, 69.78422820568085, 70.10642051696777, 70.1249711215496, 68.48809495568275, 67.6602029800415, 69.11422535777092, 68.03916424512863, 65.27463018894196, 63.777145743370056, 65.40068462491035, 62.81322866678238, 63.26379708945751, 62.07631900906563, 61.62775307893753, 59.74026136100292, 61.583998426795006, 60.53806655108929, 59.84775759279728, 59.001580998301506, 61.75288796424866, 61.627954468131065, 71.90416485071182, 77.72742077708244, 79.69057023525238, 74.29663047194481, 74.23141077160835, 67.95804619789124, 69.51409310102463, 73.48770707845688, 75.19557103514671, 75.27609631419182, 74.57653105258942, 75.56956976652145, 75.07542908191681, 67.64231353998184, 66.98960736393929, 72.86312699317932, 73.75848814845085, 73.97993266582489, 74.86374244093895, 66.53431579470634, 58.703600987792015, 57.23775364458561, 55.51157847046852, 56.26839905977249, 56.56363941729069, 53.93068090081215, 55.203627794981, 56.19798123836517, 53.79638850688934, 53.95650431513786, 55.17483294010162, 53.76505918800831, 54.62348632514477, 54.587160274386406, 55.23053415119648, 57.00266785919666, 55.470240488648415, 57.63478294014931, 58.02888259291649, 58.510787934064865, 57.25548729300499, 58.01963768899441, 58.53316493332386, 59.72847059369087, 58.65092821419239, 57.70261690020561, 62.81803160905838, 62.67189905047417, 64.2041364312172, 62.97470860183239, 65.37717908620834, 59.97381202876568, 64.361242800951, 68.17243829369545, 66.27905309200287, 66.20367273688316, 67.63685703277588, 65.25737151503563, 67.98894613981247, 70.28749600052834, 75.22327914834023, 56.94364182651043, 3.6678999569267035, 0.0765544772730209, 0.148358155565802, 0.15976270922692493, 0.05945699413132388, 0.060900419412064366, 0.10392875017714687, 0.08107779314741492, 0.09389619008288719, 0.04658201585698407, 0.043736009392887354, 0.17864729510620236, 0.24894919304642826, 5.4311316926032305, 29.537568725645542, 31.352450139820576, 30.052528493106365, 22.724570408463478, 41.837708204984665, 50.106205120682716, 50.04545398056507, 0.5444891704246402, 0.048133267773664556, 0.004498527678151731, 0.018561263677838724, 0.019773333697230555, 0.016511099274794105, 0.07088167854817584, 0.032287858266499825, 0.029807789978804067, 0.017496988657512702, 0.011970575778832426, 0.014327781518659322, 0.1135975614306517, 0.09168200733256526, 0.06207538390299305, 0.22409074881579727, 0.1961519761243835, 0.13656183698913082, 0.0952085223980248, 0.14141085179289803, 0.11925017373869196, 0.1541462098248303, 0.2993877459084615, 0.19628210429800674, 0.11304262792691588, 0.07485926355002448, 0.28464575414545834, 0.24635595094878227, 0.11184344344655983, 0.17626258166274056, 0.20620199153199792, 31.99192352592945, 87.75127530097961, 48.58290106058121, 58.825008273124695, 40.913012623786926, 45.78179396688938, 45.76022632420063, 62.17328980565071, 15.279283169656992, 0.5527122260536999, 0.24678553570993245, 0.2852462406735867, 0.443174138199538, 0.463236408540979, 0.5787215335294604, 0.8143885689787567, 0.5446077953092754, 0.8211125456728041, 0.5220672860741615, 20.231569781899452, 99.76237758994102, 90.82424640655518, 94.84181642532349, 87.7648177742958, 91.20736464858055, 94.91125389933586, 92.36212268471718, 86.50365024805069, 85.97978755831718, 83.20037350058556, 84.52388048171997, 81.829414665699, 83.12164932489395, 85.59115961194038, 83.69796440005302, 85.28994977474213, 75.72924479842186, 74.22294482588768, 72.92663678526878, 73.46452072262764, 74.37279358506203, 76.35323211550713, 76.34646847844124, 74.31660979986191, 73.16151738166809, 71.13962307572365, 73.31945970654488, 71.79797574877739, 69.46286424994469, 67.31132850050926, 66.9247904419899, 67.14348390698433, 69.11415696144104, 66.78154572844505, 66.94612249732018, 63.196742087602615, 65.9792871773243, 65.69800347089767, 62.69592136144638, 64.69474330544472, 67.79657766222954, 64.34111148118973, 74.40053209662437, 79.32700574398041, 82.04157248139381, 76.9713981449604, 73.17523464560509, 69.6234892308712, 74.42892417311668, 75.12710630893707, 79.15723085403442, 77.31480851769447, 77.61746227741241, 79.27646085619926, 79.21275347471237, 70.00391721725464, 69.2764462530613, 76.67519643902779, 79.01284620165825, 76.82077422738075, 76.6734105348587, 68.76316219568253, 59.179472252726555, 59.31685768067837, 58.63070569932461, 58.6441645771265, 59.10649336874485, 57.284209951758385, 56.678005680441856, 58.876202926039696, 58.78259874880314, 58.16557265818119, 58.81700210273266, 58.67599166929722, 57.58755147457123, 57.24625378847122, 59.64018613100052, 59.7457292675972, 58.34621876478195, 60.54177515208721, 62.205466479063034, 63.175508826971054, 60.945739075541496, 61.825954243540764, 62.11274765431881, 63.6769413203001, 63.304557502269745, 61.01224310696125, 65.57310417294502, 67.61895999312401, 66.535904109478, 67.8748306632042, 67.82739400863647, 64.10486295819283, 69.17930066585541, 73.28825578093529, 68.98373275995255, 70.61462044715881, 69.8599961400032, 67.5610662996769, 71.79555907845497, 74.69223484396935, 77.90316134691238, 54.25973564386368, 2.814284786581993, 0.2102860450395383, 0.35472361254505813, 0.6377577781677246, 0.6074977456592023, 0.21356846031267196, 0.5539172363933176, 0.1985397026874125, 0.2202255991869606, 0.18301337957382202, 0.2847807062789798, 0.2432987032807432, 0.6079985469114035, 13.693547509610653, 44.967463463544846, 49.57728110253811, 41.171372160315514, 55.69149501621723, 56.18115194141865, 57.1017437428236, 59.722341522574425, 0.6171881163027138, 0.1426253467798233, 0.11226686096051708, 0.14004659140482545, 0.14026392193045467, 0.15800603083334863, 0.14550406340276822, 0.12078099432983436, 0.10185738632571883, 0.09201555818435736, 0.08648862116388045, 0.11424342286773026, 0.13733073166804388, 0.1205056426988449, 0.1225358693045564], [0.031251415639417246, 0.029585271840915084, 0.07850356487324461, 0.009108031481446233, 0.06367497189785354, 0.026605459861457348, 0.06168342973978724, 0.06967043416807428, 0.009643190460337792, 0.03489797680231277, 0.09428461533389054, 0.030002459025126882, 0.0806113904400263, 0.06695714226225391, 0.06200573334353976, 0.370713867014274, 37.54684165120125, 50.12988165020943, 45.108705684542656, 47.040043249726295, 27.503345981240273, 32.67871007323265, 33.575720340013504, 20.683504231274128, 1.2596541387028992, 0.02091663445753511, 0.09420532427611761, 0.12496926763560623, 0.07809427785105072, 0.1217547440319322, 0.052681196975754574, 0.04327308364736382, 0.1088859404262621, 0.2628533000824973, 0.2205404033884406, 23.465849831700325, 90.62581345438957, 77.32224091887474, 78.33009883761406, 81.4005620777607, 80.56304901838303, 81.67258188128471, 77.6233671605587, 74.24007430672646, 77.01888799667358, 75.48856571316719, 74.95244488120079, 75.2276337146759, 77.00570270419121, 72.42935746908188, 73.32417145371437, 69.71674382686615, 63.56473334133625, 63.189864456653595, 64.188701659441, 64.48991149663925, 62.29369394481182, 63.390565887093544, 64.90092784166336, 65.07047474384308, 61.90108761191368, 64.08273294568062, 65.65919995307922, 64.84326213598251, 62.115855887532234, 64.64071780443192, 61.32788836956024, 58.70990864932537, 57.07165315747261, 56.89836345613003, 55.8309019356966, 57.28272423148155, 56.74590803682804, 56.06087699532509, 56.66488878428936, 57.74886041879654, 53.66576671600342, 59.314634799957275, 65.33575370907784, 72.65559732913971, 76.32236257195473, 72.63502523303032, 73.45767349004745, 67.30559080839157, 70.49320176243782, 72.39417135715485, 71.44676819443703, 69.9800392985344, 70.16005083918571, 72.29416072368622, 70.50284564495087, 68.29974666237831, 67.95186012983322, 67.02391192317009, 68.07157650589943, 68.7605631351471, 72.47624695301056, 68.11966672539711, 58.80402199923992, 55.79258859157562, 55.7556963711977, 53.36687475442886, 51.181327030062675, 52.44336850941181, 53.16905356943607, 51.71088561415672, 49.328519850969315, 51.02326311171055, 51.53608739376068, 51.36901035904884, 52.25018687546253, 50.759059488773346, 52.09448263049126, 51.73300802707672, 52.11934469640255, 52.92121186852455, 53.888590559363365, 51.16633303463459, 53.30137386918068, 54.01419661939144, 55.84605172276497, 53.383726850152016, 53.75251226127148, 55.975723564624786, 56.15956909954548, 56.82159997522831, 58.09713073074818, 56.88008263707161, 60.30083768069744, 58.76885108649731, 60.10273151099682, 62.78311908245087, 65.33019840717316, 63.180148378014565, 62.30543531477451, 63.20908762514591, 64.60466533899307, 65.05007743835449, 66.92711591720581, 72.37122818827629, 21.410452723503113, 0.1406930317170918, 0.2105328388279304, 0.01014291188766947, 0.11210682423552498, 0.07038720039417967, 0.06499003531644121, 0.03433000747463666, 0.11320382982376032, 0.042417584045324475, 0.07183346810052171, 0.024507612470188178, 0.1525667414534837, 0.05149311131390277, 17.462154887616634, 35.82656756043434, 27.169885374605656, 47.37833149731159, 39.16234776377678, 33.003326654434204, 40.86257793009281, 0.7848930079489946, 0.03197231562808156, 0.039219658574438654, 0.03345750898006372, 0.06464184931246564, 0.045184607442934066, 0.09495268925093114, 0.07600664612255059, 0.0734652801475022, 0.10382637090515345, 0.0077444830913009355, 0.01872538407042157, 0.05310169042786583, 0.03540337194863241, 0.06753046618541703, 0.06567166827153414, 0.03534443058015313, 0.0455602677538991, 0.021599525352939963, 0.016589774349995423, 0.009025463841680903, 0.06128707464085892, 0.09290120753576048, 0.012572246032505063, 0.017918424637173302, 0.08178967604180798, 0.03997568441263866, 0.04758578914334066, 0.054504512809216976, 0.04170143751252908, 0.9902604098897427, 50.76357364654541, 62.29515306651592, 68.61282706260681, 44.85283121466637, 22.44293712079525, 42.45322197675705, 39.40894313156605, 21.571197398006916, 1.1407950916327536, 0.040818140769260935, 0.16389973723562434, 0.16283395380014554, 0.23698906763456762, 0.10828663391293958, 0.050695525205810554, 0.17475306813139468, 0.2552575076697394, 0.3335556312231347, 0.4797884391155094, 26.402926929295063, 93.30640241503716, 82.39200487732887, 83.07446345686913, 85.55880814790726, 85.49595952033997, 86.17223963141441, 83.99282857775688, 78.69767591357231, 82.56862699985504, 80.18381416797638, 79.61724936962128, 78.24154078960419, 79.7193118929863, 77.704226821661, 78.33148196339607, 71.43020108342171, 68.76712158322334, 65.82671016454697, 67.04062342643738, 68.59290853142738, 68.21352168917656, 67.44381219148636, 71.59914761781693, 67.38856315612793, 65.43574154376984, 69.73816707730293, 69.0568408370018, 66.50884196162224, 64.96606394648552, 67.46976479887962, 63.1231514364481, 62.78493918478489, 61.48579649627209, 59.52017717063427, 59.06729467213154, 61.58187434077263, 59.58536647260189, 59.79122422635555, 61.115673556923866, 60.12233465909958, 57.90783628821373, 62.20026075839996, 66.2561023235321, 76.67219460010529, 78.85912165045738, 75.4741720855236, 74.972864985466, 72.6774613559246, 75.14581650495529, 74.83047902584076, 74.5236910879612, 74.09593284130096, 70.10367706418037, 73.02811414003372, 72.15481460094452, 71.78333133459091, 71.02559879422188, 69.59901854395866, 69.12279769778252, 71.46778106689453, 75.70399135351181, 68.66773411631584, 63.454075679183006, 59.134725853800774, 58.97186279296875, 56.46428994834423, 53.16604033112526, 57.066177651286125, 55.90650647878647, 54.316459000110626, 52.620355412364006, 54.71468523144722, 53.075449392199516, 55.14784298837185, 55.854187086224556, 57.20587335526943, 55.571512654423714, 56.20944142341614, 56.539541110396385, 58.20995047688484, 56.38441823422909, 55.96868634223938, 57.30621077120304, 57.365107610821724, 57.77713470160961, 57.90041148662567, 58.9994341135025, 59.33224305510521, 60.14114744961262, 60.58963358402252, 60.72989925742149, 59.481096267700195, 63.51215176284313, 61.98600545525551, 64.1464251279831, 67.18491688370705, 68.86068776249886, 66.4254592359066, 64.96823742985725, 67.86821901798248, 68.56913700699806, 68.30289289355278, 71.88705056905746, 76.45274117588997, 35.05004122853279, 0.07764842521282844, 0.3304123389534652, 0.10325038267183118, 0.26901656936388463, 0.028319679986452684, 0.1013167985365726, 0.09348155217594467, 0.1777520720497705, 0.1750007228110917, 0.0762901316920761, 0.048383816829300486, 0.5065082490909845, 0.5176602944266051, 14.86518518999219, 31.37654084712267, 34.236721470952034, 40.7755284011364, 43.39904062449932, 43.71003493666649, 50.485124588012695, 2.17467175796628, 0.0568487866257783, 0.09523872038698755, 0.03360102178703528, 0.06427452331990935, 0.04623798587999772, 0.06703445920720696, 0.10878856322960928, 0.03560539938916918, 0.10064975620480254, 0.029040437111689243, 0.04011395023553632, 0.034157591726398095, 0.023129177061491646, 0.02184258799388772, 0.16820204153191298, 0.13882304221624509, 0.1507218662300147, 0.0662768303300254, 0.14533357723848894, 0.12973738834261894, 0.10730706577305682, 0.16511734924279153, 0.0933402101509273, 0.19589882955187932, 0.2069443915388547, 0.17373012145981193, 0.15810681448783726, 0.10640868858899921, 0.2208312213770114, 0.9113530721515417, 59.34995770454407, 72.7581538259983, 66.7158168554306, 71.92235067486763, 50.02351015806198, 51.83538593351841, 54.57861453294754, 34.50251340866089, 2.3647332843393087, 0.22129185759695247, 0.4387582407798618, 0.31743220577482134, 0.31067201227415353, 0.20565030863508582, 0.21888235642109066, 0.45007928798440844, 0.9269936860073358, 0.7321448321454227, 0.9502490912564099, 30.744621455669403, 104.19312223792076, 90.11949062347412, 93.01244258880615, 91.254573315382, 89.70298737287521, 93.2355286180973, 87.7003276348114, 85.30648648738861, 87.48313888907433, 82.69547179341316, 83.89441385865211, 83.39006692171097, 82.35102787613869, 79.66804504394531, 81.9937938451767, 77.09596306085587, 72.06905320286751, 68.94329532980919, 72.38277196884155, 72.28902339935303, 69.71357479691505, 71.18379950523376, 74.70431819558144, 73.75677064061165, 70.18518269062042, 72.17712700366974, 71.30376666784286, 71.08897179365158, 68.80353882908821, 72.28721469640732, 69.71366599202156, 66.78208529949188, 64.75539565086365, 61.946145594120026, 63.03567633032799, 64.80309069156647, 62.994486540555954, 62.451119497418404, 66.80138066411018, 64.24218758940697, 60.22043399512768, 64.75236341357231, 71.8394923210144, 79.46919411420822, 81.77044942975044, 78.75309213995934, 79.69858780503273, 74.34607341885567, 77.08559721708298, 79.23763453960419, 78.42135474085808, 75.81446662545204, 75.11243149638176, 78.82316797971725, 76.47899016737938, 75.69910481572151, 71.0591433942318, 71.80068120360374, 73.3572144806385, 74.3767149746418, 77.76919573545456, 74.1481040418148, 65.52512034773827, 63.3915576338768, 62.14299023151398, 59.69887398183346, 55.59236213564873, 60.52683435380459, 60.175660997629166, 57.498127073049545, 57.66283683478832, 58.87000545859337, 57.90842525660992, 58.091358840465546, 58.285893201828, 60.30182182788849, 58.94371770322323, 59.455181658267975, 58.89855332672596, 62.37052582204342, 62.09336869418621, 59.45586942136288, 60.232110768556595, 61.682527139782906, 63.24191406369209, 62.33934849500656, 60.32803662121296, 62.3146878182888, 61.860650181770325, 64.4360987842083, 66.34127855300903, 62.72156998515129, 67.15116709470749, 64.53947603702545, 66.53720363974571, 70.76060101389885, 74.05786648392677, 69.332614839077, 67.51043781638145, 70.63446298241615, 72.27475896477699, 73.04779708385468, 77.14770868420601, 84.8320135474205, 37.181115075945854, 0.3153783269226551, 0.4258300579385832, 0.3111993527272716, 0.538619791623205, 0.36011047661304474, 0.3697490750346333, 0.3654927690513432, 0.5768653331324458, 0.37956133601255715, 0.12075461840140633, 0.15320703678298742, 0.5841611791402102, 2.710053054615855, 26.457070223987103, 52.973899841308594, 42.214818969368935, 69.62509274482727, 60.2976306527853, 44.924673959612846, 66.07619717717171, 2.8272948134690523, 0.09498351064394228, 0.15710674080764875, 0.12757536373101175, 0.16104519978398457, 0.14447298279264942, 0.15230923105264083, 0.17101915989769623, 0.14566646015737206, 0.24565779778640717, 0.13420007075183094, 0.15520589280640706, 0.09938532210071571, 0.11001038321410306, 0.17207366268849], [0.016513310874870513, 0.04472179673030041, 0.04373914867755957, 0.019874673962476663, 0.03366981887666043, 0.09525332585326396, 0.005034081386838807, 0.04155600625381339, 0.046039561566431075, 0.059098473720951006, 0.16897025343496352, 0.0905032541777473, 0.14734246709849685, 0.17480415757745504, 0.5686936341226101, 11.37045856565237, 61.06781892478466, 41.849628165364265, 36.88770242035389, 39.0787598490715, 31.298903413116932, 28.412169814109802, 27.326752357184887, 7.200995972380042, 0.03155106518534012, 0.08792754160822369, 0.06081148785597179, 0.08893437625374645, 0.036672789574367926, 0.032647521584294736, 0.08628839714219794, 0.12648345669731498, 0.1889811671571806, 0.2122787115513347, 0.7480491162277758, 30.14343671500683, 74.86946493387222, 80.46159446239471, 74.13108855485916, 78.84880140423775, 76.09619110822678, 78.3595472574234, 77.97620102763176, 73.11619341373444, 75.63045009970665, 76.502336114645, 74.04119297862053, 75.25566101074219, 76.75788760185242, 73.05110290646553, 70.67312210798264, 65.06738170981407, 63.67811165750027, 64.27330791950226, 63.91725182533264, 65.22145584225655, 64.42665249109268, 66.51440486311913, 64.78593841195107, 62.88907639682293, 62.54191942512989, 68.52701246738434, 64.90305572748184, 64.92853716015816, 64.40168783068657, 63.90136867761612, 60.31331621110439, 61.18129603564739, 57.860703617334366, 57.8166563808918, 55.860300958156586, 58.64473454654217, 57.593045979738235, 56.69813320040703, 53.78985285758972, 55.88834725320339, 59.718507528305054, 60.300978273153305, 60.671108812093735, 65.32888367772102, 73.2880125939846, 72.30508893728256, 70.53278803825378, 71.12992599606514, 71.2743790447712, 68.43878880143166, 67.34982803463936, 66.77491888403893, 68.45047697424889, 66.97597369551659, 67.44185149669647, 70.00098377466202, 72.61633023619652, 70.97259923815727, 67.72913128137589, 71.13517731428146, 71.68644413352013, 65.63734352588654, 58.620575442910194, 57.775515988469124, 56.01464107632637, 52.04573504626751, 52.96946547925472, 52.99729898571968, 49.773065596818924, 51.63184605538845, 49.717352986335754, 51.47639259696007, 50.85592769086361, 49.966144636273384, 50.187007784843445, 50.52305415272713, 50.103708654642105, 50.977589562535286, 52.31080122292042, 53.09545151889324, 53.54853920638561, 53.02197106182575, 52.284730821847916, 53.58396090567112, 52.12255172431469, 55.04238344728947, 55.37496820092201, 56.02955907583237, 56.186380460858345, 56.207963302731514, 56.607017889618874, 58.086077123880386, 59.80287440121174, 59.20238122344017, 59.32973898947239, 65.1207460463047, 63.728933930397034, 63.77149924635887, 65.14079377055168, 62.2218170017004, 64.86248910427094, 64.04373183846474, 66.6858820617199, 63.03247310221195, 49.79718670248985, 2.307463944889605, 0.049727890800568275, 0.2137839057832025, 0.07366071731667034, 0.03705993833136745, 0.17367339169140905, 0.17437866947147995, 0.1990179723361507, 0.06584149392438121, 0.6815788673702627, 0.43348676583264023, 1.8169760517776012, 0.7150921784341335, 1.7109055747278035, 16.871885061264038, 28.53169810026884, 33.70718948543072, 39.84176650643349, 28.29603474587202, 46.393766328692436, 3.160365466028452, 0.1520705860457383, 0.09642761127906851, 0.08111662973533385, 0.06392993673216552, 0.07745872484520078, 0.04693286246038042, 0.05334645073162392, 0.012854656415584031, 0.039842472615418956, 0.07361833326285705, 0.05350320345314685, 0.05098550085676834, 0.02631523930176627, 0.04834606748772785, 0.05490373259817716, 0.04579457861837, 0.01555884124172735, 0.05222393010626547, 0.030991847634140868, 0.03986358300608117, 0.01487361258114106, 0.10209819098236039, 0.05251716007478535, 0.029176463503972627, 0.020600151146936696, 0.0929400218592491, 0.11371721047908068, 0.2376526070293039, 0.527442810125649, 16.279608942568302, 75.71526914834976, 49.31344226002693, 49.35672953724861, 28.099606186151505, 30.58875571936369, 38.262601643800735, 27.60306593030691, 5.140587408095598, 0.07946826037368737, 0.060680714013869874, 0.05705665847926866, 0.045872556074755266, 0.5008150264620781, 0.29492372763343155, 0.3671090479474515, 0.22512128023663536, 0.1182170670654159, 0.4110521759139374, 1.0845514596439898, 42.28273652493954, 90.64240336418152, 86.00159078836441, 81.22516348958015, 83.73718589544296, 82.37065762281418, 82.07605183124542, 81.79903909564018, 76.33647501468658, 80.67550018429756, 79.40155774354935, 78.84137660264969, 80.3441047668457, 79.38135042786598, 75.78978314995766, 75.22389471530914, 67.77438685297966, 67.41730481386185, 69.33276683092117, 67.12380856275558, 70.26772946119308, 70.42396187782288, 69.79368209838867, 68.08898717164993, 65.87306007742882, 65.73831170797348, 70.57127237319946, 68.15330252051353, 66.07652395963669, 68.4381428360939, 66.7655561864376, 60.630325600504875, 63.87933745980263, 60.29684789478779, 62.28523939847946, 60.275097861886024, 62.05415479838848, 61.7512958496809, 59.589880630373955, 58.39609108865261, 58.958396315574646, 61.65583357214928, 62.414899840950966, 64.37337175011635, 67.95927733182907, 77.66210988163948, 76.96524247527122, 73.7236288189888, 74.1659326851368, 73.22623550891876, 70.42109683156013, 69.53766703605652, 70.69861873984337, 69.74823653697968, 68.8453821837902, 69.17711958289146, 72.10047751665115, 73.40024337172508, 74.23116758465767, 72.71449416875839, 72.59860038757324, 74.71764028072357, 68.70471373200417, 60.60937352478504, 62.64768294990063, 57.18753173947334, 53.46622422337532, 55.289047211408615, 54.71643693745136, 51.6344603151083, 54.42892536520958, 53.905115872621536, 54.94126707315445, 54.90270674228668, 53.23368430137634, 52.062169164419174, 53.75290744006634, 52.837426364421844, 54.03196066617966, 55.4718554019928, 56.07267916202545, 57.12090611457825, 56.037816032767296, 54.9970480799675, 56.80938743054867, 56.21168330311775, 56.57858021557331, 55.15233054757118, 60.34996144473553, 58.40348169207573, 60.817564353346825, 60.393195524811745, 59.587950333952904, 64.50253441929817, 62.507048696279526, 64.25918027758598, 67.75373116135597, 66.0607548058033, 65.87597072124481, 70.83652853965759, 65.04976585507393, 71.86746641993523, 67.6540245115757, 73.10661032795906, 66.0593032836914, 63.176443576812744, 6.262347539886832, 0.029619470005854964, 1.2631370080634952, 0.4574145865626633, 0.1147514081094414, 0.10075151207274757, 0.5520054639782757, 0.12237445218488574, 0.02325488574570045, 2.446747845970094, 1.6876179305836558, 1.0779445641674101, 1.006497354246676, 0.9478264837525785, 13.427526634186506, 29.32500623166561, 29.851355887949467, 40.480763018131256, 38.863729387521744, 57.16524973511696, 10.473316255956888, 0.19370928610442206, 0.11889397996128537, 0.0639898057852406, 0.09258937192498706, 0.039340751100098714, 0.023517862064181827, 0.05040360883867834, 0.04735750822874252, 0.08420832789852284, 0.09633793757529929, 0.043595480019575916, 0.0675857561873272, 0.010595295425446238, 0.08301709924126044, 0.19207553705200553, 0.13263440632726997, 0.22075448330724612, 0.25095857272390276, 0.21642080100718886, 0.2695384476101026, 0.1533699085121043, 0.23819885740522295, 0.12884412455605343, 0.12784249236574396, 0.27560583141166717, 0.2956901286961511, 0.3564611286856234, 0.47626730462070554, 0.8459489035885781, 17.256399728357792, 86.69835940003395, 59.90932188928127, 56.2992800027132, 57.52900801599026, 54.56368513405323, 47.94271521270275, 43.95003005862236, 9.751256201416254, 0.2526767336530611, 0.20271981979021803, 0.22756307967938483, 0.1611200676416047, 0.36777790111955255, 0.15198547655018046, 0.2767258509993553, 0.29674498771782964, 0.4508605320006609, 1.1357577494345605, 1.48357659811154, 46.4763168990612, 105.78278973698616, 91.68156400322914, 91.57823994755745, 87.30990618467331, 87.97161787748337, 86.3928709924221, 89.2213024199009, 78.90360966324806, 86.30853071808815, 82.11682364344597, 83.42691734433174, 83.84130790829659, 83.51965516805649, 79.29960161447525, 78.00947204232216, 70.42755648493767, 71.37605398893356, 72.41255477070808, 72.3461951315403, 75.10124489665031, 73.99080768227577, 74.70482736825943, 71.38296201825142, 70.43179705739021, 69.34632450342178, 77.70173415541649, 71.33924156427383, 70.88149532675743, 74.84383910894394, 72.60077387094498, 65.71453258395195, 68.9914919435978, 63.765062391757965, 66.66031703352928, 64.62118685245514, 66.16739988327026, 64.74864721298218, 63.96100267767906, 59.77607063949108, 64.26498636603355, 64.19656723737717, 65.13279899954796, 68.38904947042465, 72.01621323823929, 80.13395324349403, 79.14287522435188, 75.4153360426426, 76.04875445365906, 77.11158782243729, 74.80237573385239, 72.86593124270439, 74.66375917196274, 73.7334018945694, 72.7268435060978, 73.03310707211494, 75.6634171307087, 80.47448337078094, 76.75125315785408, 76.04918003082275, 75.63044250011444, 77.60651886463165, 70.95922395586967, 64.48659047484398, 64.76173371076584, 61.98912128806114, 55.90667746961117, 57.51998730003834, 57.19959229230881, 55.42828693985939, 57.32868276536465, 57.10924834012985, 58.2515050470829, 57.587000504136086, 55.89702218770981, 55.62471739947796, 59.1447839140892, 57.119583785533905, 57.32122756540775, 59.844580963253975, 60.10359026491642, 60.57619370520115, 58.62508960068226, 57.88787595927715, 60.37304900586605, 56.695146560668945, 61.62783667445183, 60.651710852980614, 64.37051430344582, 63.95467981696129, 64.67978730797768, 64.68850404024124, 63.57951074838638, 69.01609942317009, 65.630192309618, 68.61953750252724, 72.64723017811775, 69.95578899979591, 68.6580902338028, 75.20188629627228, 68.0848453938961, 75.74520394206047, 70.41185572743416, 79.50772404670715, 69.3267023563385, 70.92190235853195, 6.689848825335503, 0.17593802564078942, 0.6359788798727095, 0.49560761370230466, 0.1537748984992504, 0.464346423977986, 1.1204876750707626, 0.4452749207848683, 0.19231792248319834, 1.2346174009144306, 2.4321034317836165, 5.204519452527165, 0.918692140839994, 2.4258375680074096, 26.64316713809967, 44.6965342015028, 49.69193235039711, 59.01865728199482, 39.6775621175766, 72.541284263134, 12.316655293107033, 0.3943564655492082, 0.3469945600954816, 0.18540791905252263, 0.1471500875777565, 0.16785859043011442, 0.11938409428694285, 0.1382646503043361, 0.2184920312720351, 0.24470531061524525, 0.20500453625572845, 0.11259278995567001, 0.09780223947018385, 0.10994115567882545, 0.2263852913165465], [0.04873179874266498, 0.008594442097091815, 0.03344299257150851, 0.05466253831400536, 0.004727883779196418, 0.03237555414671078, 0.042709103363449685, 0.053491284561459906, 0.07803664266248234, 0.022296162678685505, 0.06624163768719882, 0.09017499483888969, 0.017000799853121862, 0.13075945927994326, 0.08725721898372285, 36.42775610089302, 58.04205268621445, 54.74806644022465, 50.230355858802795, 38.5353472083807, 24.406574852764606, 30.070752315223217, 8.735100477933884, 0.19823925162199885, 0.19311875919811428, 0.019749874409171753, 0.15271255862899125, 0.068567929265555, 0.2914814685937017, 0.15860197541769594, 0.08343673922354355, 0.16536690382054076, 0.5397662019822747, 0.08720443744095974, 2.389702694490552, 60.20688012242317, 66.56520053744316, 75.36196410655975, 75.7574012875557, 77.46749192476273, 77.63347461819649, 74.9458484351635, 75.6733649969101, 74.62677955627441, 75.57206243276596, 75.69101125001907, 74.55613374710083, 77.20190897583961, 73.39570641517639, 73.1380270421505, 70.16989231109619, 63.75400498509407, 67.68662676215172, 66.01236820220947, 66.50830999016762, 65.29717057943344, 64.95195910334587, 70.44511914253235, 62.06033706665039, 62.97150917351246, 65.11493235826492, 67.41010040044785, 65.26423394680023, 62.82100684940815, 62.3842316865921, 61.23843736946583, 59.2073817551136, 56.966258212924004, 54.85498130321503, 56.743115186691284, 57.35144354403019, 55.726912915706635, 55.54122447967529, 60.48739247024059, 60.22324204444885, 56.54426045715809, 54.975890815258026, 61.20699405670166, 62.66565978527069, 69.46872353553772, 71.7844408750534, 72.78681188821793, 75.25633737444878, 75.379838347435, 70.85487395524979, 64.14742827415466, 64.29290726780891, 69.35136303305626, 69.1636075079441, 66.297178119421, 64.69188585877419, 63.66302266716957, 68.80742222070694, 70.60246869921684, 67.9260291159153, 69.1964453458786, 66.3090106844902, 61.21085464954376, 56.5903177857399, 57.68255777657032, 49.6222934871912, 52.80630603432655, 55.22106125950813, 53.00138756632805, 52.5240495800972, 52.79590219259262, 50.48308029770851, 51.4433229714632, 49.820323660969734, 50.282329469919205, 51.14320367574692, 50.58105044066906, 51.034115329384804, 52.199140414595604, 50.107953026890755, 51.232339292764664, 51.36981971561909, 49.876549243927, 51.84462323784828, 52.21454098820686, 53.310322389006615, 53.32466281950474, 54.71216596662998, 55.44717572629452, 53.24334718286991, 53.34274984896183, 55.85222639143467, 56.02439135313034, 59.9463927000761, 57.522745952010155, 60.26662051677704, 64.40333694219589, 63.9610330760479, 65.44443547725677, 64.30482342839241, 64.44514989852905, 62.897158563137054, 64.22886550426483, 63.28354462981224, 63.308323100209236, 62.175068110227585, 14.977783598005772, 0.09289854322560132, 0.8303333446383476, 0.13906464097090065, 0.20723120192997158, 0.1957433347706683, 0.18760608625598252, 0.685321488417685, 3.3686045045033097, 3.958761286921799, 0.24576959491241723, 1.1200314620509744, 1.4280136045999825, 0.13564691733336076, 3.744805217720568, 22.45290018618107, 17.170429341495037, 31.173548139631748, 22.657245621085167, 46.61629758775234, 13.080044779926538, 0.3038103523431346, 0.10833321852260269, 0.017975358496187255, 0.09539371792925522, 0.06905458518303931, 0.0335350634122733, 0.060713605998898856, 0.015078831256687408, 0.028222070868650917, 0.05371976956666913, 0.03573956484615337, 0.052223165694158524, 0.007924243782326812, 0.037293674031388946, 0.0210301737752161, 0.11999612863291986, 0.034105158993043005, 0.01526515299701714, 0.03013355384609895, 0.036223560164216906, 0.03856824216200039, 0.018596964691823814, 0.01950610487256199, 0.0843236428045202, 0.058188526454614475, 0.11138784640934318, 0.03978897861088626, 0.14887816359987482, 0.026023770078609232, 45.52761420607567, 66.80975541472435, 73.78560349345207, 47.677941620349884, 29.58767283707857, 31.43842052668333, 34.87252235412598, 6.314406646415591, 0.07853042319766246, 0.23973024945007637, 0.04336840138421394, 0.23951410636072978, 0.11831823663669638, 1.60315060056746, 0.5091252992860973, 0.5046443303581327, 0.26715642074123025, 0.7961479446385056, 0.19439445168245584, 4.4411366153508425, 70.83443105220795, 79.77740317583084, 83.4113609790802, 82.36370399594307, 81.84497103095055, 81.83233290910721, 79.62968230247498, 80.03657206892967, 79.93244245648384, 78.86344581842422, 81.43720731139183, 78.04588168859482, 80.99922001361847, 77.21159845590591, 77.46619999408722, 75.06922781467438, 65.49244210124016, 70.38039341568947, 69.69947755336761, 71.87420725822449, 69.82949897646904, 68.91207620501518, 71.88089489936829, 67.92169734835625, 69.36706379055977, 71.29005700349808, 68.37333351373672, 70.50271645188332, 67.47215867042542, 64.84666675329208, 65.06656095385551, 63.17716173827648, 60.65374754369259, 58.586609065532684, 58.87132778763771, 61.02282173931599, 57.43582181632519, 59.29855786263943, 62.31058783829212, 63.71464669704437, 60.44447377324104, 57.68874004483223, 63.75819995999336, 64.84320893883705, 73.00243511795998, 76.99152186512947, 75.5669555068016, 78.31790149211884, 79.26408872008324, 74.33582916855812, 67.8623217344284, 69.2060512304306, 72.33017519116402, 72.033631503582, 71.89221069216728, 66.02440595626831, 67.67449781298637, 71.01108357310295, 73.88615369796753, 68.29721599817276, 68.89148890972137, 70.36359071731567, 66.39160305261612, 60.60454398393631, 61.5300565212965, 50.95390923321247, 57.15399473905563, 57.122114449739456, 56.51928059756756, 56.30994223058224, 54.960893020033836, 52.509914338588715, 53.53668384253979, 54.003222808241844, 52.952548786997795, 54.21912722289562, 54.59606319665909, 53.851458951830864, 55.525652915239334, 54.14961755275726, 54.22220125794411, 55.10114349424839, 54.16292443871498, 55.512790605425835, 55.15737287700176, 56.50406241416931, 55.16999959945679, 56.74370415508747, 58.13162907958031, 55.10607562959194, 56.505076959729195, 58.481856286525726, 57.36651353538036, 63.67403067648411, 61.52961194515228, 63.32848861813545, 68.41742634773254, 68.44014912843704, 68.24718028306961, 68.59878301620483, 67.04823821783066, 68.07023137807846, 68.39373841881752, 67.48245611786842, 66.93125769495964, 72.03413307666779, 23.723360113799572, 0.04815036314539611, 1.5253498940728605, 0.3561883151996881, 0.22086712648160756, 0.10784982063341886, 0.4867934522917494, 2.421690090559423, 4.1057628113776445, 1.2124049803242087, 0.3589548636227846, 1.5425014612264931, 1.7189813288860023, 0.3315967175876722, 2.3333624051883817, 24.147772639989853, 19.47637740522623, 26.695893108844757, 30.118882432579994, 58.13996963202953, 21.442652195692062, 0.33472202019765973, 0.24583027290645987, 0.03530631758621894, 0.1536661887075752, 0.04519723137491383, 0.055308503651758656, 0.04617646925908048, 0.04749600411741994, 0.018921728515124414, 0.01179864984806045, 0.029373778306762688, 0.09688403210020624, 0.04888808020041324, 0.010589947323751403, 0.24106561060762033, 0.2121476928004995, 0.12210114888148382, 0.16918218112550676, 0.11630616296315566, 0.10584496063529514, 0.13850408198777586, 0.2021233705454506, 0.21591205877484754, 0.15138672664761543, 0.18567270250059664, 0.14450801216298714, 0.10236857764539309, 0.47352340654470026, 0.21739029820309952, 52.8152659535408, 79.75329726934433, 80.93682736158371, 76.55980423092842, 62.46331304311752, 45.536023154854774, 47.68340192735195, 12.999680992215872, 0.3191346628591418, 0.4783049749676138, 0.11480223780381493, 0.4680279811145738, 0.24115207081194967, 0.5593989766202867, 0.2868646866409108, 0.21273397462209687, 0.44671064999420196, 1.2367134634405375, 0.4921650281175971, 3.9823399716988206, 74.02426108717918, 90.2830870449543, 94.89629790186882, 86.76390588283539, 90.21597504615784, 89.86754134297371, 86.68634444475174, 85.65465420484543, 83.81334140896797, 83.02793115377426, 85.67527189850807, 84.32686105370522, 86.51150822639465, 81.48437038064003, 80.91291144490242, 80.20524501800537, 69.29688155651093, 75.56966856122017, 74.40996319055557, 76.41355767846107, 74.426971077919, 71.26232609152794, 78.23515713214874, 70.9651592373848, 71.61401242017746, 73.90939325094223, 72.79325634241104, 75.4910659790039, 70.45059084892273, 70.03940731287003, 67.94745236635208, 67.29381904006004, 64.01192754507065, 63.52697476744652, 63.66704665124416, 67.17446744441986, 61.34371072053909, 60.44573150575161, 65.62375545501709, 66.05130091309547, 63.40274803340435, 61.41548506915569, 67.68699914216995, 68.06929662823677, 73.98407444357872, 78.34849745035172, 79.36791434884071, 80.44642567634583, 83.62344279885292, 77.67962694168091, 71.38147249817848, 71.09937563538551, 75.56260854005814, 74.73973229527473, 74.07423600554466, 70.43701037764549, 68.93363624811172, 75.91748669743538, 78.4232622385025, 72.74724081158638, 75.11210471391678, 71.62490263581276, 67.9103435575962, 63.45380589365959, 63.68416093289852, 53.787496984004974, 59.37775321304798, 62.62559853494167, 58.7009297311306, 57.716828137636185, 57.14045226573944, 57.711390629410744, 57.70731344819069, 58.27103979885578, 55.53877741098404, 59.12147976458073, 58.55125196278095, 57.29880876839161, 59.08627085387707, 58.228843063116074, 59.129033759236336, 60.09281024336815, 57.479356080293655, 59.170930311083794, 57.742100581526756, 60.93557462096214, 59.286276921629906, 62.99803175032139, 61.68829523026943, 59.137180522084236, 60.04529759287834, 64.34356614947319, 61.54976226389408, 69.74395036697388, 63.998719453811646, 67.40082129836082, 71.68378427624702, 72.57122665643692, 73.34327682852745, 73.74518126249313, 70.40231063961983, 73.68314579129219, 70.7258328795433, 73.04247736930847, 71.67439118027687, 78.34474325180054, 26.207621209323406, 0.7120955642312765, 1.758642413187772, 0.41777033417019993, 0.9071101248264313, 0.5716319452039897, 0.48012531478889287, 1.2993820756673813, 4.924525776877999, 5.912131732329726, 1.5929923206567764, 2.0981032541021705, 3.16262966953218, 0.2847392944386229, 5.9509737230837345, 39.92438927292824, 29.324316568672657, 50.062427669763565, 34.78772230446339, 65.19462928175926, 25.407918021082878, 0.5055844236630946, 0.39801756909582764, 0.1499645787407644, 0.24492189899319783, 0.18174172437284142, 0.09354890949907713, 0.22227230889257044, 0.19879786617821082, 0.143667648662813, 0.16819982993183658, 0.15302442392567173, 0.24778611405054107, 0.12670270196394995, 0.1511879201279953], [0.08903081834432669, 0.03197370715497527, 0.02939012225397164, 0.04853815757087432, 0.09476211314904504, 0.03378753463039175, 0.04891284195764456, 0.012588195713760797, 0.017348781766486354, 0.06594301230506971, 0.07382243871688843, 0.01951890877535334, 0.056130706798285246, 0.17799658002331853, 1.6586191928945482, 47.07985371351242, 46.87680020928383, 25.160308107733727, 35.9361232817173, 17.663532681763172, 23.21228563785553, 16.81164689362049, 0.3821119788335636, 0.06326617469312623, 0.10876989821554162, 0.08714492461876944, 0.05362642594263889, 0.07290104011190124, 1.169853676110506, 2.739922539331019, 0.5897915863897651, 0.26911177206784487, 0.3771073208190501, 0.25612872967030853, 21.515139006078243, 84.42877158522606, 72.00734451413155, 71.96598753333092, 74.2251943051815, 74.83931735157967, 72.72132620215416, 74.17021125555038, 73.62481132149696, 74.6279726922512, 79.67852488160133, 76.30508109927177, 75.21405324339867, 76.72265589237213, 72.2629339993, 72.44099244475365, 66.28048181533813, 64.46790307760239, 66.67657256126404, 65.84218293428421, 65.9367598593235, 64.69653680920601, 71.1181390285492, 64.38800856471062, 64.68544140458107, 65.82908883690834, 66.53566092252731, 64.29368242621422, 64.46992456912994, 64.80471700429916, 63.12648765742779, 59.431163147091866, 59.36395235359669, 55.35387173295021, 56.71219624578953, 56.965684443712234, 55.657000467181206, 54.14768345654011, 53.44967991113663, 57.745391204953194, 61.683537885546684, 58.28749671578407, 55.0824560970068, 57.33755148947239, 62.36074134707451, 66.46669462323189, 76.62363320589066, 72.78957054018974, 71.72327175736427, 72.2830881178379, 68.00650119781494, 62.514488697052, 66.92459285259247, 68.87597054243088, 70.34537449479103, 64.1207917034626, 65.10952904820442, 61.13159090280533, 65.01350060105324, 69.33897569775581, 66.50878116488457, 67.86533877253532, 69.8623064160347, 61.55198894441128, 55.95867767930031, 56.12720623612404, 51.72391131520271, 50.182489827275276, 52.063833475112915, 55.69344811141491, 51.93299889564514, 55.67330539226532, 52.51166984438896, 49.61179085075855, 51.29598207771778, 50.89294530451298, 49.559562653303146, 47.982765063643456, 51.07263766229153, 50.81959404051304, 50.613641291856766, 50.34987844526768, 48.864431753754616, 52.64467030763626, 51.81690372526646, 48.58988128602505, 51.63683518767357, 52.91610114276409, 52.2867751121521, 50.99523201584816, 54.505438059568405, 52.25138001143932, 55.64367078244686, 51.61065839231014, 56.44914396107197, 59.54900622367859, 60.512930899858475, 63.79029303789139, 65.67988604307175, 64.90766108036041, 66.36135667562485, 65.61076015233994, 65.17278805375099, 65.48772275447845, 64.63263183832169, 59.854373037815094, 64.84437927603722, 34.313906729221344, 0.6724533601664007, 2.6703587220981717, 3.511686776764691, 0.3721639938885346, 1.0327453957870603, 4.473134698346257, 4.219273645430803, 1.228080801665783, 0.07399277645163238, 0.2640734502347186, 1.0231171874329448, 1.4076805394142866, 0.24222846695920452, 0.325930182589218, 13.99892382323742, 28.917884677648544, 25.25676403194666, 26.051540784537792, 43.29523019492626, 26.409796960651875, 0.3484627360012382, 0.19293706660391763, 0.039152950630523264, 0.059757664130302146, 0.06344052002532408, 0.09559206431731582, 0.07328335748752579, 0.018943237810162827, 0.013112279066263, 0.0780378004128579, 0.05386718978115823, 0.1288828646647744, 0.058311292523285374, 0.03361508919624612, 0.01617889171029674, 0.060939389586565085, 0.020579352458298672, 0.05577600473770872, 0.06044255511369556, 0.0390096159389941, 0.08723874692805111, 0.05587004969129339, 0.033012346539180726, 0.07579206154332496, 0.15984847181243822, 0.1427520759170875, 0.10591898986604065, 0.1622437237529084, 2.836481058038771, 59.045981615781784, 58.481563702225685, 45.216452702879906, 32.177254781126976, 20.575025752186775, 31.955225095152855, 15.329030100256205, 0.2050057682208717, 0.1653868379071355, 0.034854546320275404, 0.213948410237208, 0.13057513948297128, 0.7180340518243611, 3.40777731500566, 3.185487105511129, 2.278280798345804, 0.5793694581370801, 0.8084113115910441, 0.5373245954979211, 30.04585985094309, 91.4500804245472, 78.21241155266762, 80.68396613001823, 79.39809992909431, 83.09863775968552, 78.15287634730339, 79.67264279723167, 76.40404298901558, 78.7441398203373, 82.51552104949951, 81.76357939839363, 80.84342077374458, 78.39751482009888, 75.53113862872124, 76.95660173892975, 69.95800048112869, 67.95401841402054, 69.15803700685501, 69.80833411216736, 70.68892925977707, 68.92985925078392, 73.06026801466942, 66.98133900761604, 67.77393087744713, 71.13964587450027, 69.04870927333832, 66.39346495270729, 68.12777549028397, 67.89943054318428, 66.83127745985985, 63.249916434288025, 61.33918136358261, 58.97635415196419, 61.35608285665512, 60.49738973379135, 58.706842213869095, 59.15193513035774, 57.58224315941334, 60.30362293124199, 64.1577561199665, 61.96951054036617, 59.326486364006996, 60.220946967601776, 65.75351849198341, 69.8605889081955, 76.45109966397285, 76.6291581094265, 74.42655310034752, 74.57985207438469, 68.81097123026848, 65.8324858546257, 68.19219723343849, 68.00228342413902, 72.24776521325111, 66.86304375529289, 66.7389652132988, 65.5250595510006, 67.71878823637962, 71.71005606651306, 70.94134211540222, 70.07322549819946, 72.02772662043571, 66.35706290602684, 58.20190250873566, 59.92767870426178, 54.84051167964935, 53.43215525150299, 56.14904746413231, 57.734964564442635, 54.32186610996723, 57.69581526517868, 54.2962858825922, 53.29485721886158, 54.37160924077034, 53.38436521589756, 53.32937456667423, 52.450591921806335, 53.47155153751373, 53.31628806889057, 55.03828726708889, 53.65230783820152, 51.67188070714474, 54.034137949347496, 55.522001311182976, 51.79348178207874, 53.13584715127945, 54.24468845129013, 54.6650180965662, 54.74208936095238, 58.54056693613529, 55.96829496324062, 57.93697312474251, 56.43916569650173, 57.426284328103065, 62.50199496746063, 63.30403693020344, 66.19597434997559, 68.88879865407944, 67.21745073795319, 70.85164412856102, 68.81317511200905, 66.84583827853203, 69.0134471654892, 69.81949031352997, 67.74462684988976, 71.43862903118134, 45.958093106746674, 0.6706750555895269, 2.2973562497645617, 4.833688801154494, 0.43225848174188286, 4.588162126019597, 6.626344257965684, 3.8176145358011127, 0.4417901812121272, 0.11521528009325266, 0.15237531188176945, 1.2543193437159061, 1.3991030934266746, 0.16977708670310676, 0.3365870373090729, 11.552482098340988, 33.88467416167259, 25.05150854587555, 28.652235232293606, 54.20857518911362, 36.73503801226616, 0.016679149339324795, 0.08190556240151636, 0.02455611182085704, 0.022151594166643918, 0.12234908557729796, 0.058672967061284, 0.043792000724351965, 0.16940090688876808, 0.028545055392896757, 0.01820708112063585, 0.020042805663251784, 0.05504747176019009, 0.05544906271097716, 0.05670496582752094, 0.14504936436424032, 0.16025050805183128, 0.10405835884739645, 0.11681889052852057, 0.158599748974666, 0.07113979751011357, 0.1849986839806661, 0.19968293665442616, 0.18175508303102106, 0.17524245515232906, 0.25474913651123643, 0.17866176698589697, 0.3430583869339898, 0.3316462633665651, 3.148471391759813, 69.42860528826714, 67.63068616390228, 38.330876380205154, 57.92095698416233, 37.342526614665985, 43.80178101360798, 27.748822309076786, 0.3710390464402735, 0.2340827728039585, 0.1694296280038543, 0.39405013667419553, 0.2846689982106909, 0.3417164058191702, 4.244980216026306, 6.470260983332992, 1.019593351520598, 0.351825199322775, 1.418506158515811, 0.6562963302712888, 31.614472679793835, 99.65754121541977, 86.78858935832977, 91.0890693962574, 86.87578707933426, 88.79328578710556, 83.9999569952488, 84.68658775091171, 81.50380253791809, 83.62209767103195, 86.63009986281395, 87.75091052055359, 83.3927495777607, 80.85425779223442, 79.40326005220413, 81.4797194302082, 73.04969698190689, 74.89504516124725, 74.88493770360947, 76.10870763659477, 74.99471381306648, 73.393145352602, 77.96101704239845, 72.40658909082413, 72.43494316935539, 72.8491361439228, 72.54936262965202, 70.6333078444004, 69.2396642267704, 70.51550656557083, 70.0212898850441, 65.99285244941711, 66.01377412676811, 62.02059879899025, 63.60008664429188, 63.81915628910065, 63.221360966563225, 61.66938744485378, 59.76189360022545, 63.566614240407944, 69.80317398905754, 66.29302114248276, 61.638878881931305, 65.20879492163658, 69.28406864404678, 72.62675687670708, 81.84310913085938, 79.22324851155281, 78.53224039077759, 76.7447479069233, 73.23502823710442, 67.69384637475014, 72.68399700522423, 75.09182140231133, 77.2554861009121, 71.06594502925873, 71.5742589533329, 69.69152837991714, 73.61752331256866, 75.47978818416595, 72.93605268001556, 73.23297634720802, 73.86577159166336, 67.42745786905289, 61.07555150985718, 64.04298707842827, 57.17080503702164, 55.820357501506805, 59.31806221604347, 63.01329933106899, 58.329792246222496, 61.893347427248955, 58.725939989089966, 56.535897105932236, 57.840165719389915, 58.738407120108604, 57.02322855591774, 54.99351046979427, 58.86517211794853, 58.13294380903244, 57.56899707019329, 56.09225191175938, 56.543390303850174, 59.11779776215553, 59.290787279605865, 55.835655480623245, 59.17851470410824, 58.34554620087147, 58.591419607400894, 56.808946654200554, 62.78783842921257, 58.79152067005634, 61.99635609984398, 58.36755082011223, 63.40104952454567, 67.77806505560875, 69.06770825386047, 68.74380603432655, 73.02158609032631, 71.13238826394081, 74.5906662940979, 73.4668006002903, 72.3431096971035, 72.74848714470863, 76.30204886198044, 71.7804890871048, 76.05158910155296, 50.248021110892296, 1.31109839072451, 9.679881781339645, 10.113260876387358, 1.12126259598881, 2.8187687834724784, 7.187919924035668, 6.199605306610465, 1.58655273495242, 0.14951093355193734, 0.43498088722117245, 1.2014713045209646, 2.254210989922285, 0.2738820598460734, 0.5648293008562177, 21.380552127957344, 42.76380591094494, 39.8299415409565, 39.118045940995216, 59.53913055360317, 44.27384488284588, 0.45245335903018713, 0.30961673764977604, 0.3100313013419509, 0.19403157115448266, 0.2674913371447474, 0.3573625412536785, 0.1321362322778441, 0.17456033237976953, 0.17549710086314008, 0.19929819245589897, 0.11008603032678366, 0.25373506592586637, 0.20156039216089994, 0.2064001894905232], [0.05205224166275002, 0.04259211491444148, 0.012160592486907262, 0.04816374777874444, 0.018546904975664802, 0.028084083351131994, 0.013232634082669392, 0.10770013686851598, 0.05070218598120846, 0.07591389992740005, 0.08292284648632631, 0.06903893328853883, 0.004531737395154778, 0.34200023277662694, 11.064726021140814, 63.946213871240616, 34.98026557266712, 33.05967003107071, 18.461917340755463, 21.335309855639935, 23.0750996991992, 2.376099186949432, 0.09240133396815509, 0.2590668329503387, 0.05524905020138249, 0.1597417361335829, 0.09112455794820562, 0.6898133223876357, 5.615001926198602, 2.8971564397215843, 4.002424031496048, 2.9684541514143348, 0.7759260828606784, 2.897918773815036, 53.40365298092365, 86.01742073893547, 69.50362846255302, 72.04243943095207, 73.74668598175049, 75.21571755409241, 71.9112628698349, 73.63267689943314, 69.98320072889328, 74.46637496352196, 76.61268219351768, 76.59375160932541, 74.45058301091194, 76.45074248313904, 71.80732324719429, 74.13748741149902, 64.86718565225601, 65.95565244555473, 66.44429102540016, 65.09434506297112, 65.71811199188232, 66.04715913534164, 68.3822326362133, 61.835875511169434, 65.1050528883934, 68.13203886151314, 66.57134100794792, 63.08845929801464, 63.83750170469284, 60.17760269343853, 63.19376304745674, 60.975947454571724, 57.54984229803085, 55.2967531979084, 56.20502606034279, 57.14310072362423, 56.164907813072205, 59.00400526821613, 57.855402901768684, 55.75182817876339, 55.23863151669502, 56.930885910987854, 57.32362903654575, 55.92841990292072, 60.67980654537678, 66.95032507181168, 72.2465568780899, 72.24926993250847, 73.5192833840847, 71.39648169279099, 61.19101971387863, 61.178898364305496, 60.65756253898144, 61.24455124139786, 63.95833522081375, 59.20955143868923, 61.05495281517506, 59.48946721851826, 60.994205474853516, 66.34521514177322, 67.90222719311714, 68.37793126702309, 68.68170216679573, 66.09160915017128, 55.55125594139099, 55.51395334303379, 54.130462780594826, 54.74923677742481, 54.877635687589645, 48.29795055091381, 51.17323346436024, 53.06431218981743, 50.22571250796318, 48.51390056312084, 46.99213542044163, 50.77992796897888, 50.41332744061947, 50.34076273441315, 49.34305787086487, 49.50972452759743, 49.29805688560009, 49.85349968075752, 51.380082964897156, 48.98485109210014, 49.953479915857315, 52.08658665418625, 50.36324992775917, 51.91425830125809, 51.67354881763458, 52.37620331346989, 51.2362302839756, 53.46979223191738, 54.121981635689735, 54.09484729170799, 54.45020042359829, 54.88732136785984, 57.24624998867512, 63.43298681080341, 64.47047173976898, 66.81958928704262, 64.52395766973495, 64.65944319963455, 64.32997807860374, 63.92316430807114, 64.5108787715435, 65.14448717236519, 64.7504635155201, 52.38422468304634, 2.6758893253281713, 0.6688740116078407, 1.405501237604767, 2.803020291030407, 9.06806806102395, 1.2629326502792537, 0.05681013557477854, 0.035986859584227204, 0.2594996534753591, 0.05278146483760793, 3.0939851654693484, 1.0190439247526228, 0.13636445539304987, 0.07940168972709216, 3.453150917775929, 27.302815541625023, 27.616530507802963, 35.718995332717896, 33.380798399448395, 40.495107248425484, 0.042846560245379806, 0.014712112897541374, 0.04572359590383712, 0.09018688404466957, 0.02898408583860146, 0.06350985888275318, 0.026562476523395162, 0.03405107127036899, 0.0258483375000651, 0.04778543800057378, 0.020643999087042175, 0.014315761509351432, 0.04860961897065863, 0.07321905039134435, 0.036411234468687326, 0.05265445739496499, 0.022870030225021765, 0.07154987863032147, 0.06626235102885403, 0.09665694975410588, 0.06725832063239068, 0.14239870972232893, 0.08718287062947638, 0.07694486921536736, 0.15823277179151773, 0.10364037385443226, 0.19520190835464746, 0.4676201264373958, 16.300234235823154, 74.40529704093933, 52.98847205936909, 35.78590974211693, 15.688343569636345, 32.5182218849659, 28.48885539919138, 2.3016395699232817, 0.0528802892222302, 0.1654556646826677, 0.12060218869009987, 0.07852948809158988, 0.33525028091389686, 1.248004320077598, 2.689049681648612, 4.391214419156313, 3.093799212947488, 6.6239427868276834, 0.5882404977455735, 4.706728113815188, 64.10619288682938, 92.24742963910103, 76.2142887711525, 78.38192045688629, 80.20799607038498, 80.51949575543404, 76.43829435110092, 79.28622633218765, 75.85757151246071, 79.682697057724, 79.61883008480072, 81.14940315485, 79.51794549822807, 81.31774172186852, 75.82365453243256, 75.131506472826, 67.05112606287003, 69.03082743287086, 67.92061060667038, 70.2075406908989, 68.39056938886642, 70.78004837036133, 69.62618708610535, 67.72352278232574, 70.76406642794609, 72.61750817298889, 69.83694657683372, 66.22336328029633, 68.81232395768166, 64.09195885062218, 65.17650425434113, 63.10256414115429, 61.310021728277206, 59.900517761707306, 60.117793902754784, 59.415709376335144, 59.44909058511257, 63.15995626151562, 62.7612816542387, 61.09452769160271, 59.81693744659424, 61.304215639829636, 61.73440955579281, 60.497469529509544, 64.9777901172638, 71.068756878376, 74.94307458400726, 74.28922086954117, 77.18838930130005, 74.192174077034, 62.43155054748058, 61.515712291002274, 63.11128467321396, 65.47279715538025, 66.75392881035805, 63.35687309503555, 64.75550964474678, 62.93539971113205, 66.19972854852676, 67.13354364037514, 70.08160024881363, 69.58870589733124, 70.50483673810959, 68.85397732257843, 58.11536595225334, 56.22100040316582, 56.533769220113754, 58.18914279341698, 55.88522382080555, 50.291069000959396, 54.370875880122185, 54.412381052970886, 52.30492673814297, 50.908703058958054, 49.9318590760231, 52.255814373493195, 53.04677613079548, 53.7577635794878, 52.3600959777832, 52.236279621720314, 54.29016821086407, 54.08300332725048, 55.46230271458626, 52.04252801835537, 53.72522592544556, 53.828812167048454, 52.75821201503277, 53.661545142531395, 55.044807717204094, 54.92988668382168, 54.984223768115044, 56.905195489525795, 57.18349255621433, 58.84312190115452, 60.36411568522453, 58.43381926417351, 61.15812107920647, 65.33969789743423, 68.94199579954147, 71.34156703948975, 67.12681040167809, 68.61482575535774, 67.82394379377365, 68.47516044974327, 67.39938497543335, 70.04785045981407, 70.98693206906319, 60.29862239956856, 4.268821561709046, 1.7039658408612013, 2.9441399686038494, 5.36564078181982, 6.961400303989649, 0.50202282727696, 0.35767629160545766, 0.37272502784617245, 0.09655693793320097, 0.06627266688155942, 5.01163562759757, 0.48242677410598844, 0.02777822573989397, 0.053500854555750266, 2.4854734679684043, 34.56550642848015, 31.68179366737604, 37.42561295628548, 42.48164065182209, 51.6961158066988, 0.3806004615034908, 0.04454165151400957, 0.004756463422381785, 0.007193451892817393, 0.09125605909503065, 0.019880575891875196, 0.05667402198014315, 0.04895319994830061, 0.05535055373911746, 0.0355910982034402, 0.0414906712830998, 0.04576470346364658, 0.05994831444695592, 0.04741169614135288, 0.17996178707107902, 0.15295006072847173, 0.12337240332271904, 0.15613629366271198, 0.1478751064860262, 0.08623047993751243, 0.18683239730307832, 0.19497795787174255, 0.13431857689283788, 0.21771215280750766, 0.33112168370280415, 0.1608372203190811, 0.4932653362629935, 0.7268952357117087, 17.28764545172453, 87.8497888147831, 56.13967336714268, 52.66289412975311, 31.150021702051163, 44.094080328941345, 43.8866912573576, 3.909311215393245, 0.2135696922778152, 0.42898546205833554, 0.21331653086235747, 0.4962458013324067, 0.24645771423820406, 0.7988142734393477, 10.266322363168001, 16.03543594479561, 11.371674500405788, 8.74914737418294, 2.1698871022090316, 5.837968261912465, 70.30499786138535, 99.23427432775497, 86.1198328435421, 85.940520465374, 86.16814345121384, 89.87180471420288, 84.0319436788559, 83.93621921539307, 81.4023707807064, 84.74509701132774, 83.05589765310287, 86.40686184167862, 83.92848283052444, 84.76257607340813, 79.53034043312073, 81.9492070376873, 72.61179327964783, 73.31600949168205, 71.07058838009834, 75.13624101877213, 73.84491071105003, 74.34569343924522, 75.75737088918686, 72.11613267660141, 73.28572511672974, 77.99349769949913, 74.60323601961136, 68.42498794198036, 72.47797206044197, 68.13451632857323, 70.8757272362709, 67.83801823854446, 63.659929633140564, 63.53645145893097, 62.82236337661743, 64.34208422899246, 62.54856526851654, 66.03598773479462, 65.71810439229012, 66.53673246502876, 64.02673915028572, 66.28837019205093, 64.98981267213821, 63.91093656420708, 69.60789486765862, 72.83880829811096, 77.39486262202263, 78.16228464245796, 77.09265723824501, 77.90337413549423, 67.7710810303688, 67.75558546185493, 67.68925622105598, 67.58935198187828, 69.90056276321411, 65.59455022215843, 68.27122539281845, 66.57193377614021, 68.79299819469452, 71.66681438684464, 74.01228412985802, 72.92822510004044, 74.87083286046982, 70.7560184597969, 61.617432832717896, 59.13537561893463, 58.37760888040066, 61.59704692661762, 60.21164886653423, 54.66246083378792, 58.66184502840042, 59.691384583711624, 56.76478922367096, 53.54123219847679, 51.68396785855293, 57.40011513233185, 57.15591363608837, 57.09003657102585, 55.71283087134361, 56.16089902818203, 55.53041785955429, 57.6250896602869, 60.417901799082756, 55.900704190135, 56.78515613079071, 58.417274951934814, 55.90325005352497, 59.294397085905075, 58.87702748179436, 59.86376233398914, 58.96172493696213, 59.65675324201584, 62.125332579016685, 62.512801587581635, 62.940814420580864, 62.427427768707275, 62.92589642107487, 71.15806728601456, 74.13450837135315, 74.78808090090752, 71.46851062774658, 72.04363256692886, 71.315196454525, 73.79234433174133, 71.36093080043793, 76.91494077444077, 74.67475578188896, 64.6202977001667, 4.169801250100136, 4.921626057475805, 8.502951934933662, 4.692102698609233, 12.360207606106997, 1.5426684147678316, 0.19426285405643284, 0.1205003066570498, 0.6467758817598224, 0.2350011805538088, 4.5481545478105545, 1.8294663378037512, 0.28441316506359726, 0.20043124415678903, 5.189599078148603, 44.02771309018135, 43.404318541288376, 55.33883973956108, 44.070137813687325, 61.745029985904694, 0.3327822539722547, 0.08541182425688021, 0.1666579142329283, 0.19384682091185823, 0.17005600064294413, 0.19190355174941942, 0.16597798821749166, 0.14445076289121062, 0.16419114894233644, 0.16176290111616254, 0.1318023697240278, 0.1433939891285263, 0.17536220810143277, 0.10773453541332856], [0.04751986045448575, 0.03154468642605934, 0.008336726677953266, 0.034190732330898754, 0.020049839367857203, 0.025849087069218513, 0.15647441614419222, 0.01861992117483169, 0.02219863519712817, 0.029393799595709424, 0.053893532312940806, 0.01327826410488342, 0.0321727771370206, 0.1124955908744596, 20.222900547087193, 57.33244836330414, 30.286620631814003, 43.9980024844408, 16.609617434442043, 18.931906521320343, 9.085858706384897, 0.30065251397900283, 0.13377669034525752, 0.02194103944930248, 0.11083370700362138, 0.0072457756232324755, 0.4887619544751942, 1.6873249900527298, 2.0088652800768614, 2.7831371454522014, 4.673061920329928, 3.902105614542961, 0.3681844496168196, 13.282873146235943, 75.21988973021507, 77.275131046772, 70.25215029716492, 70.2232338488102, 71.21002569794655, 72.52502873539925, 69.6415838599205, 73.48442405462265, 72.5645162165165, 75.86970046162605, 75.13136208057404, 77.11559280753136, 75.78238114714622, 77.46862426400185, 73.87666940689087, 67.93919920921326, 64.60142031311989, 65.6091034412384, 64.1611835360527, 66.52189806103706, 66.43123492598534, 68.36754262447357, 64.8946125805378, 64.30865362286568, 67.83965975046158, 65.4935060441494, 63.74531865119934, 65.05440920591354, 64.77829322218895, 62.05717943608761, 59.103590324521065, 56.38473741710186, 59.0043206512928, 56.58090189099312, 56.61663517355919, 56.50325305759907, 54.30755987763405, 57.56532646715641, 56.67890623211861, 56.978470757603645, 53.62062893807888, 55.590542033314705, 59.64790731668472, 56.72720544040203, 57.13667906820774, 64.90605756640434, 72.3566597700119, 70.71626499295235, 69.95756730437279, 66.75859495997429, 54.76969487965107, 56.92652374505997, 64.06400755047798, 66.7030419409275, 67.85332381725311, 65.82997798919678, 58.57920706272125, 55.913954079151154, 58.17086957395077, 65.33318504691124, 66.77751794457436, 66.59168511629105, 68.55889275670052, 63.613640516996384, 55.977163687348366, 55.56885279715061, 54.3498782068491, 56.10055446624756, 47.30008989572525, 50.07595494389534, 50.03275506198406, 50.10019764304161, 50.58756709098816, 47.80320189893246, 50.64136080443859, 50.6522586196661, 50.36921560764313, 48.62964615225792, 48.69157902896404, 48.15551899373531, 48.94471004605293, 48.415193259716034, 51.62214137613773, 49.489030838012695, 49.758067801594734, 49.52818773686886, 49.3231925368309, 50.572307109832764, 50.64825363457203, 49.92143623530865, 52.08041198551655, 50.09519711136818, 56.730458065867424, 55.73868088424206, 54.4590425491333, 54.77708548307419, 55.488445311784744, 59.804303124547005, 62.30088695883751, 65.61022818088531, 64.10498455166817, 65.44013410806656, 63.62489551305771, 64.28612843155861, 65.22251218557358, 64.94167685508728, 63.74271959066391, 57.99863241612911, 4.591780006885529, 0.6227403308730572, 3.8971537677571177, 3.2263852609321475, 0.41634167020674795, 0.3660990740172565, 0.8807022543624043, 0.19871890166541561, 0.027176384792255703, 0.7872261421289295, 6.4950252044945955, 0.2517277345759794, 0.12064754133461975, 0.11312335875118151, 1.050177316647023, 32.83086910843849, 21.62768706679344, 16.250985078513622, 28.341932483017445, 45.2215064316988, 0.7958056661300361, 0.07616300179506652, 0.061939789811731316, 0.06380645078024827, 0.028398783651937265, 0.06016859500959981, 0.00519348357556737, 0.008859390673023881, 0.02394329265371198, 0.05091480015835259, 0.056315200999961235, 0.027711567890946753, 0.0884540360129904, 0.02219597459770739, 0.02637216017319588, 0.1668129934114404, 0.04521228212979622, 0.04120946039620321, 0.018306100319023244, 0.04460922777070664, 0.12547168676974252, 0.05385464377468452, 0.07201707543572411, 0.0061954483408044325, 0.025547251898387913, 0.010668342238204787, 0.033487543696537614, 0.14555702306097373, 28.02288070321083, 64.40621718764305, 50.27219161391258, 43.591257110238075, 16.959177777171135, 28.646795824170113, 10.140273626893759, 0.07219713530503213, 0.13749833829933777, 0.08552110550226644, 0.11018927791155875, 0.2856218861415982, 0.9413867793045938, 0.5586682283319533, 0.30870490532834083, 2.35507111530751, 0.9061047225259244, 3.7251393729820848, 0.05404036994150374, 17.458915561437607, 83.40490132570267, 86.2113319337368, 78.00126448273659, 76.0702233016491, 76.62235647439957, 79.05402079224586, 76.26724272966385, 80.12902110815048, 76.05362579226494, 78.80834117531776, 79.361811876297, 80.41370183229446, 81.3100129365921, 78.86380299925804, 74.42057982087135, 70.57305827736855, 66.90756976604462, 71.39922514557838, 68.50928261876106, 68.53166341781616, 72.25366249680519, 72.11581349372864, 67.61992514133453, 67.22952648997307, 72.95601680874825, 68.11740964651108, 67.33234137296677, 66.788529753685, 67.91858151555061, 63.8337779045105, 62.42076672613621, 60.68284258246422, 60.72760798037052, 60.7790420204401, 58.239794075489044, 58.666195794939995, 57.54670366644859, 59.38940718770027, 58.86905550956726, 59.307498782873154, 59.63637873530388, 59.88820642232895, 63.82080540060997, 62.13029891252518, 62.144909128546715, 66.17284879088402, 73.57807382941246, 72.5478047132492, 71.25378414988518, 68.16627502441406, 56.991435661911964, 62.24947951734066, 68.79596203565598, 71.1658188700676, 71.5857495367527, 68.92788335680962, 63.053888753056526, 58.883129954338074, 61.20523855090141, 68.98364916443825, 70.55291935801506, 71.56338393688202, 70.17474845051765, 64.45180714130402, 57.06451714038849, 59.01666238903999, 56.09979070723057, 57.78640620410442, 50.374649316072464, 55.13990521430969, 52.87934951484203, 53.674012273550034, 54.728942066431046, 51.33999891579151, 51.796141639351845, 52.5015813857317, 54.948748871684074, 50.31749278306961, 52.62165114283562, 51.29811756312847, 53.50730001926422, 50.975530073046684, 54.93370547890663, 52.94485040009022, 52.58027896285057, 53.38899716734886, 53.8696713745594, 53.81422854959965, 52.909622490406036, 51.300306245684624, 54.76493373513222, 52.87030220031738, 58.264397755265236, 60.09295083582401, 59.21494334936142, 58.644046783447266, 58.973899483680725, 63.16307969391346, 65.51861509680748, 68.6129942536354, 68.80998328328133, 69.40849676728249, 67.21616640686989, 69.69561696052551, 68.34952399134636, 71.79489031434059, 71.37840986251831, 63.952301144599915, 6.472656754776835, 1.2773534702137113, 5.712284781038761, 3.809437374584377, 1.0279426909983158, 1.044444136787206, 3.130064941942692, 1.6433866415172815, 0.06760799835319631, 1.6515814955346286, 7.0222787372767925, 0.12715385353658348, 0.1194890339684207, 0.027907322328246664, 0.8322233869694173, 37.53532826900482, 29.397709630429745, 15.081373639404774, 35.178337544202805, 55.86069233715534, 1.237141890451312, 0.10153453724342398, 0.15765937365358695, 0.09205693291733041, 0.06024449445249047, 0.11020636215107515, 0.030911458197806496, 0.08980294878710993, 0.03608670442190487, 0.0653260204126127, 0.07952333515277132, 0.10085686735692434, 0.04947875553625636, 0.03810485628491733, 0.09650601918110624, 0.3098976257024333, 0.17970007611438632, 0.09249734561308287, 0.1210099839954637, 0.1923330474528484, 0.2715582470409572, 0.10616622894303873, 0.11393629989470355, 0.16284324548905715, 0.14003658725414425, 0.1318027704837732, 0.15443291631527245, 0.1746793431811966, 32.916546911001205, 78.46813023090363, 50.98333105444908, 68.84060204029083, 34.08373028039932, 39.34471517801285, 17.766567952930927, 0.31171603593975306, 0.3979225445073098, 0.1411867528804578, 0.2380224340595305, 0.5496653239242733, 0.7014162372797728, 5.019221920520067, 11.606476251035929, 6.982164289802313, 13.259951826184988, 9.463912770152092, 0.5285277706570923, 20.30050378292799, 92.700684517622, 94.1659314930439, 84.99663591384888, 80.51857620477676, 86.21703162789345, 83.34136873483658, 81.93495020270348, 86.2616640329361, 82.42116451263428, 83.18476393818855, 84.78703916072845, 86.2494894862175, 83.5082557797432, 82.15685069561005, 81.51001140475273, 74.53839629888535, 71.37987658381462, 76.35147660970688, 72.80644923448563, 72.74429976940155, 74.14979115128517, 76.56796619296074, 72.48387694358826, 71.86850756406784, 77.32440680265427, 73.15481454133987, 70.9025613963604, 71.48814037442207, 73.5252034664154, 67.52169281244278, 64.4657751917839, 64.53604102134705, 64.1650441288948, 65.4621197283268, 62.409435734152794, 63.535737097263336, 61.16486571729183, 64.91903766989708, 63.98045763373375, 65.3960108757019, 64.25683200359344, 66.12542733550072, 68.65602314472198, 65.32641381025314, 63.58750931918621, 70.09043857455254, 77.77130842208862, 76.67373731732368, 76.47560834884644, 72.18332067131996, 58.993905410170555, 63.04262615740299, 69.17941465973854, 71.1563041806221, 72.11034938693047, 73.1310810148716, 64.00334760546684, 61.0195729136467, 63.252515494823456, 72.09816724061966, 74.3173697590828, 73.7593849003315, 73.19626271724701, 70.08976981043816, 60.92919856309891, 62.24564552307129, 57.66908369958401, 63.640660867094994, 54.776697903871536, 59.986233562231064, 58.05571675300598, 57.01568216085434, 56.90068893134594, 54.28712457418442, 55.362364277243614, 57.35079377889633, 58.78052406013012, 54.31097589433193, 56.14807091653347, 53.76083381474018, 56.22881278395653, 54.85443413257599, 58.05418163537979, 56.50131896138191, 56.87342919409275, 54.96199116110802, 56.72492176294327, 59.045046865940094, 57.181341871619225, 56.71509929001331, 59.21994388103485, 56.96658119559288, 63.54381166398525, 62.89804391562939, 61.84265814721584, 62.60346472263336, 63.481867387890816, 69.69484180212021, 67.70699366927147, 73.34885492920876, 72.13374093174934, 72.96243086457253, 71.52269572019577, 73.79881158471107, 71.15654736757278, 74.81724813580513, 74.13168132305145, 69.64253380894661, 7.419456699863076, 2.5380027992650867, 6.383989462628961, 4.651971152052283, 1.7869371199049056, 0.7439505017828196, 2.65036728233099, 1.4811453223228455, 0.13778540102066472, 0.8033140038605779, 10.090565644204617, 0.2912162250140682, 0.30750865233130753, 0.21828347293194383, 1.5561663592234254, 46.96717455983162, 34.890161007642746, 30.051369555294514, 42.105707824230194, 64.66208025813103, 2.129173236899078, 0.24650319304782897, 0.2569563133874908, 0.19206878350814804, 0.16086902876850218, 0.1458284561522305, 0.1825841807294637, 0.17845070018665865, 0.10000848866184242, 0.13367905339691788, 0.18641704693436623, 0.19755096902372316, 0.23845449759392068, 0.17059143050573766], [0.17184402735438198, 0.006037195553290076, 0.05986583957565017, 0.03311064399895258, 0.07947089499793947, 0.013158375713828718, 0.11425382777815685, 0.15205326431896538, 0.08334405240020715, 0.03305222955532372, 0.10140216778381728, 0.0639530694752466, 0.07323503625229932, 0.03458431179751642, 39.154755771160126, 59.719366282224655, 25.70800881832838, 23.176007084548473, 18.232882730662823, 17.985250018537045, 3.5323576675727963, 0.027579426641750615, 0.3326203767210245, 0.028434590421966277, 0.16208184650167823, 0.20905209094053134, 0.75309868901968, 1.7078421078622341, 0.43066987011116, 2.9422521824017167, 1.9309787219390273, 5.122644770890474, 0.5208591290283948, 27.481272965669632, 77.1784034371376, 73.05592104792595, 73.02426114678383, 68.6907608807087, 73.15649405121803, 70.50571069121361, 73.81107732653618, 71.36172115802765, 73.0052849650383, 76.43704041838646, 75.82009792327881, 76.17900386452675, 79.11414876580238, 74.96440663933754, 72.00407668948174, 67.04128459095955, 64.16539371013641, 67.37682178616524, 66.4234833419323, 68.27832341194153, 66.3781289756298, 65.2077005803585, 64.44643422961235, 67.48735785484314, 64.95273426175117, 65.71506455540657, 63.764720410108566, 63.8757960498333, 62.33320042490959, 59.448330625891685, 57.75157727301121, 58.6697182059288, 57.41921670734882, 55.92150807380676, 56.004955396056175, 54.65780608355999, 55.5522096902132, 54.0494891256094, 50.69388918578625, 50.057651326060295, 52.83634342253208, 55.47076866030693, 58.69951620697975, 62.408090606331825, 62.641276493668556, 58.46490919589996, 58.6866918951273, 63.79606872797012, 68.14489737153053, 66.43473833799362, 56.95268154144287, 68.22809770703316, 71.73867613077164, 69.94725465774536, 69.62931051850319, 71.4453698694706, 65.35271599888802, 60.50576068460941, 58.44171144068241, 63.48789006471634, 66.79391786456108, 67.83164978027344, 63.15787397325039, 55.39007619023323, 55.401407182216644, 56.93823091685772, 55.75358368456364, 50.685818418860435, 51.20562672615051, 49.46307063102722, 46.174404099583626, 48.51291261613369, 48.12216818332672, 49.47302609682083, 48.350452333688736, 50.31822994351387, 50.363458916544914, 49.40196990966797, 47.338604629039764, 49.331529289484024, 49.57608416676521, 51.42438858747482, 49.43386159837246, 48.33588771522045, 49.578785821795464, 51.0781017690897, 52.080727368593216, 49.466083869338036, 48.77517454326153, 50.660169795155525, 50.4910446703434, 49.6979284286499, 52.660211473703384, 56.111972853541374, 56.98483161628246, 56.28794141113758, 58.364134803414345, 58.567667081952095, 61.10017038881779, 64.46477964520454, 63.28413739800453, 67.4657142162323, 61.326824426651, 68.22095409035683, 62.89218083024025, 69.30207207798958, 63.52236181497574, 58.4158044308424, 4.948584185913205, 0.8593267982359976, 3.496326575987041, 1.4153300039470196, 0.05688817982445471, 1.5479351696558297, 5.082811983302236, 2.3454072838649154, 0.07662269548745826, 6.5130656864494085, 2.996512558311224, 0.10094908662722446, 0.12104079796699807, 0.07954743268783204, 0.48329529468901455, 30.193153247237206, 26.939479038119316, 23.771321140229702, 28.10401774942875, 42.789306342601776, 0.9339891700074077, 0.16555667098145932, 0.08629080170067027, 0.012220156331750331, 0.010049140601040563, 0.08538526279153302, 0.04671195478294976, 0.0645451623131521, 0.08996202814159915, 0.055952005059225485, 0.0427537398354616, 0.007701872682446265, 0.03043333697860362, 0.11362018209183589, 0.16120223823236302, 0.061351979165920056, 0.030747972341487184, 0.09000461257528514, 0.07868136861361563, 0.055668749555479735, 0.057476673246128485, 0.07952449290314689, 0.0043526061381271575, 0.08665579734952189, 0.06924988134414889, 0.06603625573916361, 0.021119036682648584, 0.13294420845340937, 45.77847294509411, 73.20211440324783, 41.08848720788956, 29.234274700284004, 26.572675220668316, 24.512271881103516, 2.8654594905674458, 0.07155637242249213, 0.3880439355270937, 0.045671912739635445, 0.254764721612446, 0.4645549674751237, 1.7130360729061067, 0.6130528100766242, 1.2732240417972207, 0.8877435734029859, 2.8000635746866465, 2.068733205087483, 0.41011044988408685, 33.144663870334625, 88.7572181224823, 80.27177944779396, 79.91855800151825, 75.95160886645317, 78.44268679618835, 79.3182510137558, 77.75802433490753, 76.41988053917885, 78.54233264923096, 82.14536771178246, 81.80752784013748, 82.87479177117348, 81.20106518268585, 77.15955644845963, 75.71545913815498, 71.24374508857727, 68.15778627991676, 69.59891974925995, 70.13168156147003, 73.42308014631271, 70.77819406986237, 70.05237981677055, 66.05282083153725, 70.5525241792202, 69.51443508267403, 67.26766884326935, 68.4377932548523, 66.9590114057064, 64.37992259860039, 63.989767134189606, 61.51182509958744, 62.32625439763069, 59.592589884996414, 60.54220452904701, 59.30312141776085, 56.57739847898483, 57.70742744207382, 59.640782698988914, 57.073697447776794, 55.28655834496021, 58.5689552128315, 57.512148320674896, 61.63653440773487, 65.9701980650425, 67.17292472720146, 64.90735709667206, 61.42128735780716, 64.47487190365791, 71.44388034939766, 68.55892315506935, 61.16994224488735, 70.50040617585182, 73.75669464468956, 73.68262141942978, 73.61702933907509, 74.40670296549797, 69.2577588558197, 63.60877677798271, 61.76060155034065, 64.03224125504494, 67.74503722786903, 67.15555965900421, 61.54775597155094, 58.07995185256004, 58.81111241877079, 60.02934604883194, 58.71570333838463, 55.275516137480736, 55.85442267358303, 52.23689138889313, 50.428211241960526, 52.53072202205658, 49.812940657138824, 52.19353571534157, 51.60233683884144, 52.47670792043209, 53.861064836382866, 52.2926077991724, 52.05857835710049, 50.973181799054146, 51.94202721118927, 52.87596769630909, 51.91835828125477, 51.97081446647644, 52.610468342900276, 54.66119170188904, 54.6018160879612, 53.8917101919651, 53.72533231973648, 53.933146968483925, 53.24417933821678, 52.659379318356514, 57.02510565519333, 59.73234638571739, 59.53116238117218, 60.18334038555622, 58.7203124910593, 62.65866436064243, 63.07017847895622, 67.26671129465103, 65.67908808588982, 69.68978807330132, 63.33645299077034, 72.60644316673279, 66.31688386201859, 72.45397254824638, 68.18287253379822, 63.46177026629448, 4.979365384206176, 1.4359737024642527, 2.807277012616396, 0.42173681664280593, 0.19069655245402828, 1.4026243169791996, 4.902498833835125, 0.8904553216416389, 0.2484248360269703, 7.942521907389164, 1.114689779933542, 0.11153781961183995, 0.0405609086737968, 0.07759991101920605, 0.44189764419570565, 33.53929549455643, 32.52752758562565, 23.011768497526646, 34.95538450777531, 50.50256185233593, 1.7696106433868408, 0.18399267311906442, 0.04585923823469784, 0.056102531161741354, 0.12806038692360744, 0.12462109647458419, 0.05335208734322805, 0.05144981812918559, 0.05652131396345794, 0.06924985165824182, 0.03013884535903344, 0.058487285423325375, 0.05130723671754822, 0.16551162261748686, 0.28663886594586074, 0.13127146696206182, 0.15388335596071556, 0.20072604005690664, 0.17106866114772856, 0.16488263761857525, 0.3023004677379504, 0.1978301946655847, 0.15044142346596345, 0.16172914823982865, 0.25427641812711954, 0.22479902487248182, 0.1229265209985897, 0.21150252898223698, 54.044933170080185, 82.67421573400497, 44.93766166269779, 42.101858630776405, 33.8851947337389, 39.98008668422699, 5.108778839930892, 0.12885926436865702, 0.8094901568256319, 0.22376810753485188, 0.5274743959307671, 0.3730521962279454, 1.2020576605573297, 3.878714069724083, 3.231554883532226, 10.23273216560483, 10.39655277505517, 9.617536626756191, 0.9082125406712294, 35.83534128963947, 92.71957710385323, 85.59612974524498, 87.27790430188179, 81.26715883612633, 85.3206293284893, 84.53949004411697, 85.22117346525192, 81.2111346423626, 81.96418583393097, 85.4530218243599, 84.31467890739441, 86.36191785335541, 85.95756635069847, 82.40320667624474, 80.67537859082222, 73.5548646748066, 72.06807285547256, 73.70488062500954, 73.80807548761368, 77.08350732922554, 75.72380349040031, 75.33195331692696, 71.12574622035027, 76.56257808208466, 72.76807129383087, 70.96760630607605, 71.52476280927658, 70.96100986003876, 69.6962933242321, 68.89644384384155, 65.54531246423721, 66.68984144926071, 63.17901223897934, 64.88874569535255, 62.806218042969704, 59.01433691382408, 60.87481588125229, 61.90272532403469, 62.54288077354431, 59.884790405631065, 62.53443002700806, 62.997514978051186, 65.89432373642921, 70.55414289236069, 69.78808119893074, 66.97946950793266, 65.10761395096779, 68.58711004257202, 69.25066083669662, 68.01138773560524, 63.41514676809311, 73.19763824343681, 77.57064118981361, 77.64684230089188, 78.11580553650856, 78.6976683139801, 72.12359547615051, 67.23114520311356, 64.51630488038063, 68.39341163635254, 71.7342759668827, 74.26944673061371, 68.78086924552917, 61.7917674779892, 62.0202150195837, 64.1123865544796, 61.838501170277596, 57.98075057566166, 58.607979118824005, 59.281766563653946, 54.28808972239494, 57.21606060862541, 53.327945843338966, 54.627643302083015, 53.7786016613245, 56.03185415267944, 55.93701884150505, 55.557005032896996, 56.566200479865074, 54.36018705368042, 57.171823382377625, 58.138692900538445, 56.18275165557861, 54.10538412630558, 57.360768243670464, 58.73289741575718, 60.071953162550926, 56.637435257434845, 56.47322706878185, 57.71046727895737, 56.5610745549202, 56.231837421655655, 59.657102823257446, 63.53229448199272, 63.76515358686447, 63.13437603414059, 61.83814778923988, 65.27978271245956, 67.70865797996521, 71.84993416070938, 70.36153122782707, 74.86723065376282, 67.65195742249489, 76.82062223553658, 69.7990170121193, 76.85504078865051, 70.96630677580833, 70.66876754164696, 6.410545287653804, 2.4127919180318713, 7.022108221426606, 1.529052557889372, 0.10685983274015598, 3.1375764263793826, 9.864587970077991, 7.234095996245742, 0.15715734043624252, 9.66138057410717, 3.882658020593226, 0.26344746351242065, 0.19345468492247164, 0.1992421454633586, 0.8958944329060614, 42.01895467936993, 43.01968038082123, 39.398668482899666, 45.70666439831257, 63.73463362455368, 2.6165175111964345, 0.5043567926622927, 0.38880971318576485, 0.12157802382716909, 0.3509410045808181, 0.1979461032897234, 0.12414493452524766, 0.1897172292228788, 0.15048050496261567, 0.23094764415873215, 0.14071676559979096, 0.0999808065535035, 0.15010625473223627, 0.3794025757815689], [0.06687036293442361, 0.038709791988367215, 0.03425238995987456, 0.05397965855081566, 0.017209280267707072, 0.03504578293359373, 0.016820567434479017, 0.1475549885071814, 0.05487554211867973, 0.06181881602969952, 0.0864024726615753, 0.08258655710960738, 0.05109880083182361, 0.6810125790070742, 50.990949645638466, 39.12173554301262, 36.0357691347599, 19.052116870880127, 15.091299656778574, 9.201096072793007, 0.591297255596146, 0.14181092876242474, 0.08440559075097553, 0.09801309104659595, 0.07798305960022844, 0.5151919706258923, 1.7248591384850442, 0.11395270877983421, 0.11025484665879048, 1.0839304304681718, 1.598125845193863, 2.203674651682377, 0.8533836202695966, 43.61642695963383, 77.21851408481598, 77.68460467457771, 72.30455696582794, 70.49239620566368, 71.35903850197792, 69.9959908425808, 72.78383284807205, 71.32503792643547, 77.52993777394295, 76.01657778024673, 76.865064650774, 78.3901660144329, 76.01198762655258, 72.74756759405136, 72.14608266949654, 67.32494696974754, 63.857982605695724, 65.9458489716053, 65.00286117196083, 67.69389197230339, 68.87782484292984, 63.893989473581314, 62.01902188360691, 67.4287497997284, 63.40316221117973, 62.43478037416935, 66.24870032072067, 64.3395459651947, 62.243464440107346, 56.19001306593418, 55.9904857724905, 56.47847458720207, 56.2294739484787, 56.2456838786602, 52.2098558396101, 49.91284489631653, 57.77595296502113, 53.96898664534092, 53.004944175481796, 54.67540293931961, 51.019847095012665, 55.81089600920677, 55.15092462301254, 58.18455643951893, 59.39937025308609, 62.78222233057022, 59.86864887177944, 64.85846891999245, 68.96495416760445, 67.10568353533745, 61.87972895801067, 61.905396580696106, 69.50228333473206, 70.20684152841568, 71.9790968298912, 68.82379174232483, 64.5731346309185, 62.29674518108368, 54.05493803322315, 56.42669856548309, 59.0727511793375, 54.740843027830124, 54.19380158185959, 54.80600193142891, 57.33395308256149, 53.05493429303169, 52.0772809535265, 50.16551993787289, 51.58228151500225, 48.04697781801224, 48.8812268525362, 48.51783335208893, 49.67004552483559, 53.94758999347687, 47.85539589822292, 48.646046072244644, 50.317272394895554, 50.750578343868256, 50.30008591711521, 47.39431343972683, 47.871313244104385, 47.958712354302406, 49.43634286522865, 51.58959612250328, 49.23418611288071, 48.33193212747574, 52.25983075797558, 50.363451316952705, 50.04264213144779, 50.621769055724144, 50.94789415597916, 49.20304678380489, 52.426486015319824, 55.68597391247749, 56.499031484127045, 58.001045286655426, 59.101994410157204, 61.15520663559437, 59.66347508132458, 63.754780143499374, 63.819969445466995, 63.54373946785927, 65.28900101780891, 69.58982303738594, 64.82740178704262, 69.59271088242531, 64.28444892168045, 48.22803430259228, 2.826230158098042, 1.2390674371272326, 5.145876249298453, 0.7718312088400126, 1.8242987338453531, 3.6573752341791987, 5.7276578061282635, 2.5585378473624587, 2.954285186715424, 6.446863738819957, 0.07157734551583417, 0.15203941584331915, 0.11061280674766749, 0.16626839060336351, 0.154201514669694, 30.860558934509754, 30.271315053105354, 17.169739678502083, 38.43442462384701, 31.47958941757679, 3.048761417157948, 0.29336017090827227, 0.21285595401423052, 0.08073333272477612, 0.2243640521191992, 0.0641399274172727, 0.12025897507555783, 0.025651764844951686, 0.01920461108966265, 0.027104201653855853, 0.044544434567797, 0.05729908843932208, 0.049683239485602826, 0.11351147230016068, 0.09277643766836263, 0.05853855669556651, 0.10579298803349957, 0.035363255155971274, 0.058498187572695315, 0.017783346338546835, 0.05757401333539747, 0.011654784520942485, 0.07918382485513575, 0.01181881863885792, 0.18015045585343614, 0.05504340850166045, 0.02643718158651609, 1.4913088269531727, 57.907634899020195, 52.80884809792042, 46.38313449919224, 19.781685322523117, 26.178358979523182, 11.648810729384422, 0.5351090768817812, 0.10022874324931763, 0.12198955955682322, 0.2381898180465214, 0.06378813457558863, 1.0169571242295206, 2.650466077029705, 0.10075327838421799, 0.15813750971574336, 0.5899208388291299, 0.7504047523252666, 2.9174965107813478, 1.0844201291911304, 49.354039281606674, 82.98433989286423, 84.16078716516495, 79.79490503668785, 75.37610694766045, 75.54664179682732, 77.09356158971786, 76.41284331679344, 78.4254053235054, 82.3156289756298, 80.25468036532402, 79.11076694726944, 83.2011030614376, 78.70610386133194, 76.47925615310669, 76.04113206267357, 70.74697494506836, 67.81906485557556, 68.43467742204666, 69.62902933359146, 72.28966176509857, 71.01770281791687, 65.58947369456291, 65.33685564994812, 71.2550076842308, 64.54968988895416, 68.01627427339554, 68.74081179499626, 67.06893190741539, 63.807475715875626, 59.604346454143524, 59.04447689652443, 60.74103266000748, 59.345804527401924, 61.06045112013817, 55.00637277960777, 53.35309289395809, 60.3873248398304, 59.00113262236118, 57.3112379014492, 59.80996862053871, 55.21809741854668, 59.10335473716259, 59.61416132748127, 61.963913440704346, 62.17461593449116, 64.89987149834633, 66.07463926076889, 69.90187749266624, 71.24928519129753, 70.42911440134048, 62.86829151213169, 62.9755749553442, 73.19287329912186, 72.4324581027031, 73.17322835326195, 71.96420922875404, 68.35441052913666, 64.6389091014862, 54.61026683449745, 60.88825576007366, 61.35099872946739, 55.96419118344784, 58.16782973706722, 57.475590482354164, 58.50930981338024, 56.66299268603325, 54.70944531261921, 53.92868600785732, 54.830343425273895, 50.90656757354736, 52.91745766997337, 51.911674439907074, 54.96877759695053, 57.61458322405815, 52.03652434051037, 51.449832022190094, 51.57131150364876, 52.57587879896164, 53.67756888270378, 50.69123312830925, 50.184940695762634, 51.6708167642355, 51.413885951042175, 53.33132766187191, 52.53123119473457, 51.24117001891136, 54.020888060331345, 53.744612485170364, 52.64301739633083, 53.015705198049545, 54.936897307634354, 52.380447685718536, 57.64443062245846, 59.57168720662594, 58.7540128827095, 61.92234367132187, 60.85386760532856, 65.55529832839966, 63.949420899152756, 66.31614670157433, 66.52168527245522, 67.48833060264587, 68.26900631189346, 72.6277220249176, 68.54998603463173, 72.66643434762955, 68.07739779353142, 54.98035557568073, 3.2237505773082376, 0.6803818722255528, 0.2006640558829531, 1.0736220586113632, 1.2988667283207178, 1.0577982827089727, 2.7026213658973575, 1.907479357905686, 4.144126502797008, 7.199805211275816, 0.2149230579379946, 0.25826935074292123, 0.023620727442903444, 0.13320887315785512, 0.1110279122076463, 31.166514717042446, 37.53996022045612, 20.66175039857626, 43.99864844977856, 45.491759330034256, 5.391400074586272, 0.23126902378862724, 0.2472835168009624, 0.11773010686738417, 0.11008629749994725, 0.011856656110467156, 0.10966902496875264, 0.03608460414397996, 0.13165980315534398, 0.06967214110773057, 0.02757119436864741, 0.03659415160655044, 0.029175062700232957, 0.08025627277675085, 0.12241334072314203, 0.2137201849836856, 0.20614554377971217, 0.08626249618828297, 0.11741830094251782, 0.21326642105123028, 0.27338087267708033, 0.3390759037574753, 0.14939524757210165, 0.12156262426287867, 0.37661340669728816, 0.11664961406495422, 0.17605498811462894, 1.6780809173360467, 69.89769011735916, 55.55662505328655, 58.8037484139204, 39.4301687926054, 31.880467906594276, 21.985200382769108, 0.6549867067951709, 0.24997813627123833, 0.3250381804537028, 0.45344982587266713, 0.2998301252955571, 1.2662079557776451, 2.7883796766400337, 0.36976771778427064, 0.2876831270987168, 2.584965666756034, 11.379352938383818, 10.99001633003354, 1.4864056650549173, 55.162802785634995, 87.64611214399338, 92.61543229222298, 84.81384292244911, 84.89105477929115, 83.06747943162918, 82.79350653290749, 84.72205504775047, 85.47098726034164, 87.237269282341, 84.34876307845116, 83.64697113633156, 87.04652711749077, 81.996278911829, 79.4381345808506, 79.22783866524696, 76.3142842054367, 71.12353473901749, 74.34598222374916, 71.89849555492401, 75.7833082973957, 74.53502207994461, 72.00824126601219, 67.62145265936852, 74.66898769140244, 70.49106627702713, 70.46195223927498, 73.27475130558014, 72.28629514575005, 69.01409313082695, 63.38873818516731, 62.8438588231802, 63.415401354432106, 61.978747844696045, 64.2455542087555, 58.19326937198639, 57.009708881378174, 68.68294090032578, 65.19529804587364, 61.29386879503727, 64.67314526438713, 60.45476742088795, 63.71970422565937, 62.43558973073959, 66.64672136306763, 66.98989614844322, 68.54941606521606, 64.94429871439934, 72.28056505322456, 68.90383064746857, 69.39588904380798, 64.56263199448586, 65.17993167042732, 78.2337512075901, 76.25949874520302, 75.94308972358704, 74.03597205877304, 68.89302402734756, 68.39289486408234, 58.92147749662399, 61.875116005539894, 65.62035843729973, 59.12310987710953, 60.31879171729088, 58.834963738918304, 61.33898377418518, 58.905761539936066, 57.9414226859808, 56.385565772652626, 60.32660789787769, 55.67261762917042, 56.57750867307186, 55.46624690294266, 57.129505053162575, 62.14766398072243, 53.77890944480896, 54.255719259381294, 54.800157845020294, 56.098046600818634, 57.662092074751854, 51.14943154156208, 52.5788464397192, 54.46490563452244, 54.71759207546711, 58.93486797809601, 53.71565043926239, 54.71062704920769, 60.278589874506, 57.86600053310394, 57.217246145009995, 56.802688390016556, 58.577485755085945, 55.90690165758133, 59.623915404081345, 61.96503058075905, 62.127490863204, 65.38873806595802, 66.75636827945709, 68.92574787139893, 66.69470518827438, 70.35484358668327, 69.81151074171066, 72.14892491698265, 72.96445995569229, 73.95427644252777, 71.72163024544716, 77.07176595926285, 71.52711868286133, 64.32004541158676, 4.03485719114542, 2.5598998367786407, 12.446155194193125, 2.902297801338136, 8.725842274725437, 9.49975149706006, 23.07740807533264, 5.348777286708355, 2.9793168185278773, 11.405849866569042, 0.27548319892957807, 0.5101798020768911, 0.2576751873129979, 0.3422786865849048, 0.24054551351582631, 41.09161823987961, 45.6151083111763, 32.139325216412544, 54.49096843600273, 54.72820870578289, 6.1934719607234, 0.5290631263051182, 0.4508717532735318, 0.3064756718231365, 0.287067589815706, 0.1234071803628467, 0.35699859203305095, 0.08507202452165075, 0.25133501971140504, 0.17836214712588117, 0.1639433458331041, 0.14279586263000965, 0.19547985750250518, 0.2110605948837474], [0.16842591780005023, 0.13903286220738664, 0.07653220542124473, 0.03266464664193336, 0.032813792349770665, 0.020046167592226993, 0.22626823978498578, 0.07532110204920173, 0.09463841197430156, 0.06365992856444791, 0.0311687849170994, 0.2859993127640337, 0.1698651202605106, 8.385460339486599, 63.975213915109634, 32.58865490555763, 30.948045440018177, 20.306193977594376, 28.646678030490875, 9.202794581651688, 0.28058540483471006, 0.05372507592255715, 0.05311585060553625, 0.1390872467891313, 0.18593748594867066, 1.8612768058665097, 3.7421206617727876, 0.4468128288863227, 0.0486653542611748, 0.15386992308776826, 0.5154867516830564, 0.40570915793068707, 1.7675471166148782, 41.639750227332115, 74.66920807957649, 77.79450237751007, 71.14713907241821, 69.99047353863716, 70.47047898173332, 71.98266103863716, 69.90592047572136, 74.26069959998131, 76.17500647902489, 75.9837931394577, 75.26848152279854, 79.58203285932541, 75.89579746127129, 70.65099969506264, 71.07589289546013, 67.52372950315475, 62.16783329844475, 67.57146254181862, 69.69870999455452, 70.01514181494713, 66.6695049405098, 60.766191110014915, 67.37855449318886, 65.16733154654503, 62.369914054870605, 65.81982493400574, 63.647907078266144, 63.8857439160347, 57.310717329382896, 55.16562983393669, 55.541604459285736, 56.373524218797684, 56.031135991215706, 57.03633405268192, 51.63530007004738, 51.156354770064354, 51.61767281591892, 50.024422109127045, 52.03502342104912, 51.71990253031254, 50.18883928656578, 50.3684214502573, 54.73939910531044, 55.31728729605675, 55.67968524992466, 68.31486225128174, 66.1308154463768, 71.04025080800056, 61.82854190468788, 69.2406065762043, 68.96943792700768, 67.6789815723896, 71.3087671995163, 69.58479210734367, 69.34224352240562, 66.78079336881638, 67.68728032708168, 65.19326135516167, 58.450074791908264, 59.370689392089844, 61.654906421899796, 59.914124831557274, 58.5957095772028, 56.73076204955578, 55.238445326685905, 54.17217314243317, 53.41146156191826, 52.88056544959545, 51.87858201563358, 50.82088977098465, 50.91944508254528, 50.10236732661724, 47.025296241045, 50.63337363302708, 51.242226362228394, 48.90792801976204, 50.09578987956047, 49.401863515377045, 49.12676587700844, 48.919053822755814, 48.28445367515087, 48.63746993243694, 50.150332152843475, 49.34859797358513, 50.85825316607952, 48.77664886415005, 51.15250177681446, 50.21637260913849, 49.90456134080887, 48.659508749842644, 48.28780509531498, 49.02679704129696, 50.443003848195076, 57.23836161196232, 54.50769893825054, 59.93358738720417, 56.85114338994026, 63.21696080267429, 61.83628968894482, 61.09321676194668, 62.46563471853733, 64.71975356340408, 66.9491471350193, 67.625982016325, 65.18146678805351, 66.15194231271744, 64.91851329803467, 38.46890017390251, 2.0980571815744042, 1.1771978507749736, 0.7171161635778844, 0.4804906889330596, 1.1530306725762784, 0.44690340058878064, 4.9221741780638695, 0.24347030266653746, 5.401163650676608, 4.334438340738416, 0.2047578463680111, 0.23697763856034726, 0.053539056607405655, 0.16686203452991322, 0.20294759975513443, 16.090221405029297, 50.55659495294094, 22.058599144220352, 17.786649875342846, 38.02302069962025, 5.882617766037583, 0.3146280156215653, 0.0628906034398824, 0.012666841103055049, 0.11224463363760151, 0.06811000930611044, 0.03053456592169823, 0.06098801510233898, 0.0677158917824272, 0.043136495078215376, 0.04895509242487606, 0.060318564501358196, 0.0338990905584069, 0.08777298193308525, 0.08584143870393746, 0.06155424409371335, 0.029527616243285593, 0.04125003360968549, 0.03729552940058056, 0.036911991192027926, 0.26049042062368244, 0.15382769488496706, 0.12770326546160504, 0.10419020138215274, 0.06971995768253691, 0.33887590980157256, 0.18923973140772432, 13.350893296301365, 73.7344354391098, 46.453518122434616, 36.694946363568306, 23.280890956521034, 37.68806107342243, 10.116466004401445, 0.17199045309098437, 0.0596658938593464, 0.01699416505289264, 0.09483519243076444, 0.16289443883579224, 0.7724746805615723, 3.50084928330034, 0.23317496292293072, 0.20087773504201323, 0.08446727806585841, 0.2811494073830545, 0.782074152957648, 2.738754339516163, 50.239076390862465, 80.5850650370121, 86.49878650903702, 78.59146401286125, 76.78271546959877, 76.79391726851463, 78.64148452877998, 75.66189721226692, 75.11205151677132, 78.6800828576088, 80.82535654306412, 79.3306839466095, 82.85415887832642, 81.13389238715172, 74.65212419629097, 74.02114525437355, 71.12441629171371, 66.48950099945068, 71.5306980907917, 72.27720603346825, 73.87876689434052, 70.01935198903084, 63.84396895766258, 71.11155018210411, 70.74911043047905, 65.03558501601219, 70.11667236685753, 65.01023277640343, 64.99935016036034, 59.96764875948429, 57.80461482703686, 58.83165791630745, 61.70925870537758, 59.28477980196476, 59.40362602472305, 54.914474710822105, 55.32343916594982, 54.391808956861496, 55.12922018766403, 58.2333230227232, 56.16222895681858, 55.44397249817848, 57.50625483691692, 58.40777546167374, 59.22495201230049, 59.52624924480915, 71.62550300359726, 72.09079563617706, 74.49987396597862, 62.374629601836205, 71.72351494431496, 70.13423502445221, 72.72318810224533, 74.95424598455429, 69.73887383937836, 73.28249529004097, 68.18300932645798, 70.49380213022232, 65.4646123945713, 65.49780741333961, 66.04477286338806, 65.90377762913704, 63.723944798111916, 63.412733897566795, 61.02541700005531, 57.3319847881794, 56.7585613578558, 54.938527420163155, 56.21590107679367, 55.25934040546417, 57.4527271091938, 54.158022701740265, 53.038291186094284, 50.97132369875908, 55.17388679087162, 53.56502652168274, 51.9508845359087, 52.36445814371109, 52.43786260485649, 51.60777434706688, 51.1953254789114, 52.52167850732803, 49.315300360322, 50.73951713740826, 50.40114909410477, 53.408319130539894, 52.27645866572857, 53.41865837574005, 53.202316984534264, 53.6619783192873, 54.12463769316673, 53.22466358542442, 51.97786308825016, 54.298098385334015, 59.299439415335655, 58.55895034968853, 61.53859466314316, 60.91540910303593, 66.06652289628983, 65.94618335366249, 65.0435645878315, 65.2509954571724, 67.86736786365509, 69.3026040494442, 71.11649751663208, 67.63119533658028, 71.58080980181694, 68.9230728149414, 47.14196138083935, 2.655705283395946, 1.074084802530706, 0.12958376377355307, 0.34006928326562047, 1.2595767178572714, 1.035540027078241, 2.1474338695406914, 0.4420418286463246, 7.332471292465925, 4.903985504060984, 0.2471899616648443, 0.6930081790778786, 0.2051506651332602, 0.3609337261877954, 0.22570359898963943, 15.575303435325623, 52.05442138016224, 27.532564513385296, 20.758274719119072, 50.01146860420704, 10.62260264530778, 0.33228608372155577, 0.23084755812305957, 0.1299643371021375, 0.08532462190487422, 0.03583776953746565, 0.03554493661795277, 0.02718314019148238, 0.04181573567620944, 0.08777505252510309, 0.0368837561836699, 0.006078702481318032, 0.06024984162650071, 0.10386116278823465, 0.16194647876545787, 0.34609299909789115, 0.10487305888091214, 0.10004157360526733, 0.18693196383537725, 0.09042330260854214, 0.5423304112628102, 0.21743726130807772, 0.2574953797738999, 0.20672493847087026, 0.1293102971976623, 0.4656878113746643, 0.4270478925900534, 15.110204592347145, 85.29992803931236, 52.746033668518066, 49.51881743967533, 35.143204629421234, 49.25506979227066, 18.35088349878788, 0.3117795934667811, 0.1312412170227617, 0.14338622626382858, 0.677281238604337, 0.3777245798846707, 3.9755024760961533, 12.11096853017807, 1.2365315482020378, 0.38815487176179886, 0.8569978200830519, 1.6796974930912256, 1.2590860691852868, 2.8650127770379186, 55.205523893237114, 83.11838150024414, 91.32841855287552, 84.40734073519707, 81.62864103913307, 81.93767845630646, 84.27692413330078, 79.55161929130554, 81.41807153820992, 83.55221182107925, 87.75267362594604, 83.25236231088638, 87.7998898923397, 83.29694151878357, 79.52882811427116, 79.68559250235558, 75.48981964588165, 69.24064457416534, 74.54969689249992, 77.48272150754929, 76.04273557662964, 74.36164498329163, 68.47234100103378, 73.96631419658661, 73.69520634412766, 69.96406495571136, 73.26941639184952, 69.7318822145462, 70.64816504716873, 65.79100728034973, 62.84146495163441, 62.633205726742744, 65.6326773762703, 62.76678755879402, 64.69235703349113, 57.98159413039684, 56.941810324788094, 59.90314722061157, 59.44367967545986, 63.45086105167866, 60.68612180650234, 60.76189734041691, 60.66701263189316, 61.946479976177216, 63.202221393585205, 62.68299825489521, 76.21078535914421, 71.08349248766899, 78.3564618229866, 67.32557773590088, 70.95243752002716, 74.28732857108116, 75.16230002045631, 77.68227159976959, 73.76638412475586, 76.25832840800285, 72.82224118709564, 72.19877064228058, 70.7451206445694, 62.99633324146271, 61.445628851652145, 70.19548773765564, 66.65519490838051, 63.69365282356739, 61.35255664587021, 58.682667911052704, 59.75597731769085, 59.15167294442654, 61.681136414408684, 61.55321627855301, 60.487050488591194, 59.831486865878105, 59.233847334980965, 55.49020081758499, 60.3085208684206, 58.07007998228073, 56.98761686682701, 56.24883010983467, 55.2743723988533, 55.112725272774696, 55.14335922896862, 55.88520862162113, 54.881279692053795, 56.44751384854317, 53.32472741603851, 57.80212216079235, 55.641934275627136, 57.07077540457249, 57.798884734511375, 57.74902381002903, 58.3315971493721, 56.020724549889565, 54.636664018034935, 58.78469243645668, 64.10916432738304, 59.957928881049156, 64.32937771081924, 62.707278952002525, 70.16172274947166, 69.9322758615017, 68.6648690700531, 70.64775466918945, 71.21422827243805, 74.55158159136772, 74.39480200409889, 71.6232231259346, 75.45696660876274, 76.41621753573418, 59.06852200627327, 4.802793608978391, 2.763501461595297, 6.087577817961574, 1.648998821619898, 9.159776140004396, 11.023646425455809, 13.844912387430668, 0.7172232703305781, 9.397687073796988, 8.680677898228168, 0.6302051490638405, 1.0774112865328789, 0.3602626168867573, 0.4726932104676962, 0.34705310070421547, 23.136303015053272, 66.06148436665535, 38.0441589653492, 29.655153416097164, 60.18313519656658, 12.535023875534534, 0.6053358991630375, 0.47892828995827585, 0.29450426576659083, 0.22231780254514888, 0.2303246408700943, 0.11113967222627252, 0.12908115168102086, 0.09483952657319605, 0.24630668718600646, 0.22478600760223344, 0.14969319017836824, 0.18462136125890538, 0.2562134829349816], [0.21877409191802144, 0.08376155499718152, 0.06016566723701544, 0.012938248219143134, 0.05389846017351374, 0.04666598615585826, 0.1469642241136171, 0.18084044539136812, 0.04573758167680353, 0.09472687597735785, 0.28411060629878193, 0.5464760481845587, 0.5757609580177814, 48.9964784681797, 48.78736048936844, 34.70826476812363, 44.25252802670002, 12.44974885135889, 36.60804122686386, 5.3307596035301685, 0.3949940297752619, 0.13122581003699452, 0.160972602898255, 0.044474038149928674, 0.05518262056284584, 1.3043630146421492, 3.5316186072304845, 0.4400083143264055, 0.15766145166708156, 0.039767912749084644, 0.10755411931313574, 0.12731455819448456, 4.961158661171794, 52.2656824439764, 66.26848965883255, 74.67240750789642, 70.33554062247276, 68.89298602938652, 70.00986769795418, 72.30035439133644, 69.13318634033203, 74.76177871227264, 74.63351279497147, 75.55318504571915, 76.55202984809875, 78.65817323327065, 73.92010107636452, 71.20260089635849, 69.78137835860252, 65.71416020393372, 64.88769695162773, 69.87673044204712, 70.32740905880928, 68.38167786598206, 63.159173503518105, 62.309466898441315, 67.14642494916916, 64.25211265683174, 64.674232006073, 65.71412980556488, 62.57903203368187, 58.28593119978905, 55.48488490283489, 55.067146718502045, 55.27939572930336, 54.342354610562325, 56.076934933662415, 57.89807841181755, 52.57210560142994, 57.55975976586342, 53.329701349139214, 54.80732426047325, 52.21932873129845, 52.71791897714138, 52.83995322883129, 52.23255582153797, 52.420869916677475, 54.85923707485199, 60.79777501523495, 69.48982000350952, 70.8232444524765, 68.52112278342247, 55.37409424781799, 59.03492420911789, 67.68996298313141, 63.87071192264557, 70.25717362761497, 64.42575573921204, 68.51973965764046, 65.83387657999992, 67.29664608836174, 62.769740000367165, 60.076976493000984, 53.12210328876972, 62.21331685781479, 59.06860940158367, 63.843558579683304, 63.97874012589455, 58.110308423638344, 50.19302286207676, 52.90687523782253, 48.66820648312569, 50.799542516469955, 49.50885817408562, 48.83889712393284, 44.47394974529743, 48.72314773499966, 50.967280715703964, 47.81344614923, 46.64551801979542, 48.72393049299717, 47.63702541589737, 49.69836540520191, 48.017176017165184, 46.98748826980591, 47.61190876364708, 46.20719633996487, 50.2045514434576, 51.52981773018837, 49.52794834971428, 47.782474011182785, 50.67936636507511, 51.72402910888195, 49.56821098923683, 50.74262157082558, 51.68438583612442, 49.71896789968014, 55.18091261386871, 57.879037633538246, 61.11674889922142, 58.42650845646858, 60.564870312809944, 61.7067888379097, 63.49297799170017, 60.37955045700073, 64.29198011755943, 64.37974780797958, 68.8017301261425, 67.18411892652512, 64.58080261945724, 60.47897972166538, 30.76634109020233, 2.52983869984746, 0.3142563777510077, 0.25306422379799187, 0.14178403333062306, 0.13511513883713633, 0.31415865174494684, 0.21993528585880995, 0.08950381132308394, 3.1381900934502482, 1.4318728912621737, 0.10000596535974182, 0.47435523534659296, 0.2283743509906344, 0.22327339189359918, 0.2506177785107866, 7.080926215276122, 35.31520999968052, 46.99174404144287, 16.9005374237895, 41.817934066057205, 17.456417195498943, 0.3254875063430518, 0.2873849915340543, 0.029544451863330323, 0.1498186873504892, 0.010678383496269817, 0.07274717805557884, 0.01261884548512171, 0.058181216299999505, 0.01931266779138241, 0.08671156974742189, 0.08522943404386751, 0.08780296469922177, 0.12491026689531282, 0.1615191946621053, 0.15264900110196322, 0.1030414309934713, 0.02366445663938066, 0.06435287927160971, 0.04416022842633538, 0.25688592810183764, 0.1657013304065913, 0.019486224591673817, 0.19592912402004004, 0.2266578673152253, 0.7619265653192997, 1.255471631884575, 64.41369518637657, 58.0182583630085, 51.93449601531029, 41.26241147518158, 17.314405515789986, 46.36536665260792, 6.0631209053099155, 0.2730369317578152, 0.12456328317057341, 0.1563921564957127, 0.07450240926118568, 0.0982801454665605, 0.6388095498550683, 0.46540416253264993, 0.2153581494349055, 0.051930477493442595, 0.08224902834626846, 0.08855513136950321, 0.07623649667948484, 5.955749116837978, 60.63178852200508, 67.47176349163055, 81.9273354113102, 74.41025957465172, 75.97476482391357, 75.71616590023041, 78.58188852667809, 76.15947291254997, 80.78311040997505, 79.66821983456612, 80.14137044548988, 77.66353100538254, 82.94351488351822, 77.87960261106491, 76.11750036478043, 72.56198555231094, 70.40513008832932, 70.56776896119118, 74.1321448981762, 72.27351263165474, 71.84165820479393, 64.90278214216232, 66.64734452962875, 69.78089198470116, 67.76940912008286, 67.21750393509865, 68.15110623836517, 63.92692610621452, 59.694694206118584, 59.17157627642155, 60.139129757881165, 58.17780040204525, 58.416237607598305, 59.06826362013817, 62.16234639286995, 56.258557587862015, 61.61101497709751, 58.44437129795551, 60.09016938507557, 57.12107710540295, 59.265036061406136, 56.8483467400074, 58.480362966656685, 58.07068794965744, 58.264739736914635, 63.35401564836502, 71.4157846570015, 72.82779648900032, 69.83124688267708, 60.36720871925354, 61.09275698661804, 67.96365469694138, 64.87075746059418, 73.18205907940865, 70.01879721879959, 69.72217753529549, 67.2696903347969, 70.41964530944824, 64.17294010519981, 62.460261806845665, 55.94513140618801, 62.38839626312256, 59.99136708676815, 66.40871733427048, 67.58543059229851, 60.13233572244644, 53.32476921379566, 54.366589710116386, 52.23078511655331, 52.177018001675606, 52.12737366557121, 51.67919151484966, 49.49346899986267, 52.31992073357105, 54.107360020279884, 50.76542794704437, 50.83212576806545, 51.62393867969513, 49.68278244137764, 52.850581258535385, 52.99762576818466, 50.848016515374184, 52.289548963308334, 49.000863432884216, 55.01592546701431, 53.25307086110115, 51.72078788280487, 50.60607969760895, 55.376951694488525, 54.68279354274273, 53.808171674609184, 53.74993979930878, 55.053083673119545, 51.31047450006008, 57.81342655420303, 59.711527302861214, 64.10881474614143, 63.579571545124054, 65.35169765353203, 62.93781258165836, 65.74992388486862, 64.0059694647789, 67.67941474914551, 67.64263272285461, 72.53653451800346, 68.50255697965622, 70.82748502492905, 63.57951454818249, 39.63414564728737, 3.0852190358564258, 0.311267570941709, 0.19312346441438422, 0.20750218973262236, 0.14976741978898644, 0.11926564751775004, 0.16714335302822292, 0.12939080537762493, 1.3444888615049422, 1.4150468003936112, 0.35268517036456615, 0.3172764735063538, 0.2555766608566046, 0.1596870250068605, 0.22986991214565933, 7.659884998574853, 37.6399252563715, 50.1802821457386, 19.364878088235855, 50.864712819457054, 28.92683319747448, 0.3529032727237791, 0.28230430791154504, 0.03188548063917551, 0.17762823728844523, 0.0040076095137919765, 0.07372754771495238, 0.026063538061862346, 0.06661101200734265, 0.11045352701330557, 0.03578502139134798, 0.07881587545853108, 0.06390474081854336, 0.054628529396723025, 0.2710378234041855, 0.22073456406360492, 0.17989947635214776, 0.14968854433391243, 0.2879400289384648, 0.17439355695387349, 0.49064484250266105, 0.4277553374413401, 0.13375637034187093, 0.25322123256046325, 0.293999130371958, 1.2292365333996713, 1.5410536201670766, 71.44141048192978, 68.3186848461628, 51.532025411725044, 66.11757695674896, 25.30328493565321, 58.097712099552155, 8.691889196634293, 0.4432725172955543, 0.48012985673267394, 0.7490240014158189, 0.17246051458641887, 0.2514973719371483, 3.9408317115157843, 16.342508867383003, 1.1756957438774407, 0.3119257668731734, 0.5077714438084513, 0.3645969374338165, 0.18761104380246252, 10.788034368306398, 70.88217169046402, 75.04311561584473, 88.82963463664055, 81.21917501091957, 80.89267373085022, 83.09533953666687, 84.07459259033203, 80.93541383743286, 83.42504784464836, 84.45566654205322, 82.8898237645626, 82.53307610750198, 86.81352362036705, 79.96623784303665, 79.19240936636925, 76.76978096365929, 74.5392170548439, 70.11256098747253, 79.64380234479904, 76.69798761606216, 76.49389296770096, 69.07318755984306, 70.1174247264862, 74.68845024704933, 70.84602043032646, 71.40577599406242, 73.42219099402428, 70.38129016757011, 65.98378613591194, 62.81289428472519, 63.168091624975204, 62.449215799570084, 61.32430136203766, 64.05526801943779, 64.53970402479172, 57.90791608393192, 65.58714061975479, 61.76569327712059, 63.24850291013718, 61.10674783587456, 62.12689809501171, 62.7071687579155, 63.53335842490196, 60.733098685741425, 62.75367446243763, 65.26187047362328, 76.4406806230545, 76.26202180981636, 73.61110165715218, 61.13381378352642, 64.67154935002327, 67.08679854869843, 70.49602881073952, 76.03183776140213, 71.44730776548386, 73.9631299674511, 71.7561399936676, 74.6174168586731, 69.54487904906273, 65.2556312084198, 61.08810603618622, 66.44040003418922, 61.169961243867874, 68.7802916765213, 71.09385073184967, 62.335123121738434, 54.95910331606865, 58.456739634275436, 54.77936536073685, 56.708145663142204, 55.28351850807667, 57.17249974608421, 53.04328791797161, 56.60458222031593, 59.82852302491665, 54.584519416093826, 53.29557538032532, 54.5687198638916, 53.77702094614506, 56.89395189285278, 55.779855474829674, 53.97048756480217, 55.51170386373997, 51.423814818263054, 58.51638503372669, 59.35268975794315, 55.258679240942, 53.66599850356579, 59.074160903692245, 57.00167991220951, 56.4269607514143, 56.999882608652115, 60.268505215644836, 56.830540895462036, 61.963826045393944, 62.36463613808155, 66.45552322268486, 66.76447704434395, 69.46929350495338, 66.4180040359497, 69.69138398766518, 67.27776110172272, 71.6859121620655, 69.24759060144424, 75.93775480985641, 71.64925172924995, 74.87470105290413, 66.89306974411011, 55.67849211394787, 4.120838502421975, 0.374099425971508, 0.6397545710206032, 0.6456626602448523, 0.609613578999415, 0.7869348046369851, 1.378265367820859, 0.2969480096362531, 6.362940017133951, 2.101782406680286, 0.2694785117637366, 0.7204303576145321, 0.5223291751462966, 0.4495579143986106, 0.500442290212959, 12.392901051789522, 51.113823652267456, 70.84994941949844, 33.613513112068176, 62.47832603752613, 30.20784705877304, 0.5739396682474762, 0.4781826987164095, 0.17922188068041578, 0.2470958128105849, 0.1378419081447646, 0.18096543790306896, 0.11429832695284858, 0.15866102068684995, 0.27824755059555173, 0.11467397984233685, 0.12981598178157583, 0.3062721749302, 0.2929803397273645], [0.6491143594030291, 0.5197872896678746, 0.23644894739845768, 0.04378656820335891, 0.06802537478506565, 0.07000408149906434, 0.23351568292127922, 0.609262929065153, 0.20075002626981586, 1.0834391880780458, 8.510160148143768, 8.771353382617235, 20.44450845569372, 66.9984532892704, 45.98930083215237, 24.964029639959335, 32.652689069509506, 16.354590319097042, 39.46261525154114, 4.073563339188695, 0.20541532983770594, 0.09393829954206012, 0.0303491959857638, 0.22369721758877859, 0.1166663494950626, 0.22906342026544735, 1.3935849582776427, 0.09439484652830288, 0.09350507825729437, 0.07300042852875777, 0.1233550815959461, 0.27664457098580897, 2.0964660169556737, 19.015205651521683, 40.26695229113102, 72.51707196235657, 65.10186105966568, 70.65742895007133, 70.0824362039566, 74.96747687458992, 71.06466069817543, 79.07327815890312, 73.9049930870533, 74.97364014387131, 78.43428924679756, 76.18909612298012, 74.0042969584465, 69.7760358452797, 69.0961155295372, 65.91083005070686, 67.49394670128822, 70.13912156224251, 68.67237746715546, 65.38756772875786, 60.16021482646465, 66.96099489927292, 65.21068722009659, 64.44274082779884, 61.65132321417332, 62.61946566402912, 61.120586693286896, 56.82693488895893, 56.37660965323448, 54.55207675695419, 56.890095099806786, 54.740698635578156, 55.4261514544487, 57.90460646152496, 54.54975128173828, 55.632491782307625, 55.151604786515236, 51.574370339512825, 50.06487473845482, 52.24571071565151, 52.941897958517075, 50.94567507505417, 52.91931577026844, 55.08959211409092, 65.53471863269806, 66.36075630784035, 72.83259943127632, 66.62421897053719, 64.89585131406784, 58.05906817317009, 67.92468398809433, 65.3865721821785, 63.19639250636101, 67.6242645084858, 62.482042238116264, 66.29795327782631, 61.12783670425415, 61.35342679917812, 47.7493853867054, 44.252695217728615, 57.704942375421524, 59.406510069966316, 63.710052743554115, 63.001493364572525, 62.137887105345726, 54.822154864668846, 52.93150931596756, 50.5913744866848, 49.57695052027702, 49.31826040148735, 46.851808950304985, 48.404268845915794, 47.74663433432579, 49.383734688162804, 48.39362941682339, 49.426208809018135, 50.00470116734505, 49.523597583174706, 47.93798066675663, 48.97873342037201, 48.7453081458807, 47.82989166676998, 47.42029644548893, 47.55049645900726, 49.60157319903374, 50.27347594499588, 46.51436425745487, 49.725758135318756, 51.08585715293884, 52.864876091480255, 50.48896238207817, 49.99485969543457, 49.09591533243656, 53.52868527173996, 55.658843368291855, 60.4920320212841, 59.88144278526306, 60.40656320750713, 61.81563399732113, 62.7443877607584, 59.71834793686867, 61.937938034534454, 63.02931547164917, 65.44695854187012, 65.78692629933357, 68.38062152266502, 60.367516502738, 19.961643666028976, 3.883369294926524, 0.4312834481243044, 0.2791738696396351, 0.037944244395475835, 0.15167273551924154, 0.012083481487934478, 0.15587437490466982, 0.06716895120916888, 0.03637981935753487, 0.06300052293227054, 0.03594020818127319, 0.25053338147699833, 0.04680330945120659, 0.03713711426826194, 0.10254626264213584, 2.3003694880753756, 26.19833830744028, 17.715268805623055, 21.444952972233295, 24.888105913996696, 43.85286547243595, 0.48523892008233815, 0.0775160631746985, 0.04614885394403245, 0.022615312154812273, 0.02220965423475718, 0.04174882735242136, 0.04457423179701436, 0.2426480475696735, 0.07881792378611863, 0.1771415665280074, 0.3553190524689853, 0.07339843490626663, 0.194703021843452, 0.42355638463050127, 0.6427965452894568, 0.29115910932887346, 0.09325034348876216, 0.040125256855390035, 0.05775514189735986, 0.41599004063755274, 0.6346633785869926, 0.5745462700724602, 1.8875363655388355, 13.213735856115818, 12.70225765183568, 31.12459536641836, 71.61221891641617, 57.16296225786209, 39.44393925368786, 34.5175302028656, 19.557941928505898, 45.16371913254261, 4.7647196520119905, 0.3028536052443087, 0.19325475033838302, 0.08283703937195241, 0.12281806353712454, 0.07257067307364196, 0.12426114742993377, 1.401695148088038, 0.3475445508956909, 0.12506733502959833, 0.06969410867895931, 0.0716466992162168, 0.35235616145655513, 2.874363362789154, 27.98513922840357, 47.54198111593723, 77.7819250524044, 71.26531273126602, 78.38728576898575, 74.93662253022194, 81.76056236028671, 75.5549481511116, 84.16138753294945, 76.03543236851692, 79.84500154852867, 81.71849861741066, 78.7704648077488, 77.40871667861938, 72.44774848222733, 71.20276048779488, 69.88401085138321, 72.87275567650795, 72.95822069048882, 70.35618111491203, 68.84681090712547, 65.65661609172821, 71.32472634315491, 69.82352569699287, 68.63565623760223, 65.85947200655937, 64.36142519116402, 63.412433713674545, 59.78515215218067, 57.90173001587391, 58.669060841202736, 60.44081836938858, 58.7985160946846, 59.013003185391426, 60.731384977698326, 55.09263575077057, 58.14310446381569, 59.95131343603134, 54.55621853470802, 54.125188663601875, 54.63461212813854, 55.01391917467117, 56.20051570236683, 57.048212215304375, 61.660077944397926, 67.87011131644249, 70.26541158556938, 75.19533544778824, 67.71561160683632, 68.41618001461029, 63.336209803819656, 67.46201321482658, 68.89276564121246, 63.53333182632923, 71.18541821837425, 66.62478893995285, 68.16328838467598, 62.09767006337643, 64.74148079752922, 49.255176186561584, 49.79556418955326, 61.6538804769516, 63.338189497590065, 67.43526265025139, 61.91937603056431, 66.47109478712082, 56.612489596009254, 55.501831993460655, 53.457336500287056, 51.02919079363346, 51.59189499914646, 52.552567049860954, 51.297855377197266, 51.49273172020912, 54.04197692871094, 52.62903414666653, 51.88182324171066, 54.24550160765648, 52.01806493103504, 53.33982780575752, 50.39523661136627, 52.071440666913986, 51.247302889823914, 49.65677283704281, 49.48468767106533, 50.95761023461819, 55.65578833222389, 52.5926548987627, 53.85574132204056, 54.26373302936554, 55.33374421298504, 54.365438371896744, 55.23695960640907, 52.77887150645256, 57.68864884972572, 61.177139058709145, 63.55819009244442, 64.79480713605881, 63.55333395302296, 64.27738130092621, 64.41070094704628, 63.19205693900585, 66.22897937893867, 67.26225793361664, 69.03123021125793, 66.65559768676758, 71.64383322000504, 61.630226746201515, 30.95038041472435, 2.358979443088174, 0.24415739782853052, 0.09168219286948442, 0.04833724335185252, 0.06100433864048682, 0.013891966427763691, 0.11873989526065998, 0.11219264619285241, 0.06093349322327413, 0.1802915974985808, 0.3024380322312936, 1.0607118951156735, 0.015723233445896767, 0.08470193031826057, 0.0388088130421238, 1.7390246596187353, 30.60778509825468, 22.584112845361233, 28.184520229697227, 31.090590991079807, 60.73495298624039, 3.212600313127041, 0.14238272386137396, 0.24084537086309865, 0.060302864367258735, 0.043528081878321245, 0.04003755355370231, 0.10095941732288338, 0.16454179887659848, 0.11539134720806032, 0.36775519140064716, 1.056627589277923, 0.3074314689729363, 0.12640508590266109, 0.49660633667372167, 0.7794171455316246, 0.5281789018772542, 0.1420916832285002, 0.14983966044383124, 0.14105525915510952, 0.5671620194334537, 1.1021373909898102, 0.41478663333691657, 1.3567927200347185, 12.697973381727934, 11.505842451006174, 35.03790467977524, 88.0681174993515, 63.17244619131088, 38.67335960268974, 57.70716145634651, 32.576214373111725, 60.21030753850937, 6.883942410349846, 0.4821498045930639, 0.26161700079683214, 0.328956067096442, 0.4081205144757405, 0.3206639620475471, 0.8056651870720088, 3.8892107689753175, 0.4160693316953257, 0.21212030755123124, 0.3285213466733694, 0.2214943600120023, 0.3405844228109345, 5.608400730416179, 49.28713247179985, 62.99861691892147, 86.4859963953495, 81.75200521945953, 83.91620948910713, 81.21121823787689, 86.07332333922386, 79.33913469314575, 88.3599342405796, 78.51178228855133, 83.68072852492332, 87.78575465083122, 82.5227102637291, 80.67807644605637, 78.74664008617401, 76.84070035815239, 74.54563871026039, 76.51812046766281, 77.94437393546104, 75.2856793999672, 72.80665442347527, 65.10014355182648, 75.97757667303085, 74.33874741196632, 72.63194739818573, 69.67668637633324, 71.44793853163719, 68.51816654205322, 63.94129693508148, 63.57599213719368, 61.860456392169, 63.73314030468464, 62.07851529121399, 62.484941482543945, 66.35218396782875, 59.19296532869339, 64.82647463679314, 65.41940242052078, 60.69383919239044, 57.561857253313065, 59.63717669248581, 59.484413489699364, 60.342164263129234, 61.005240082740784, 64.86772522330284, 67.83328369259834, 72.2635343670845, 78.7372013926506, 69.58264142274857, 69.78214591741562, 65.75662672519684, 72.6965743303299, 69.97467398643494, 70.04870921373367, 74.56071630120277, 70.6114362180233, 71.28495767712593, 65.65847799181938, 69.36538428068161, 53.03923353552818, 48.01517732441425, 61.171127781271935, 65.32075211405754, 67.97440811991692, 65.60522004961967, 68.99003282189369, 58.890129178762436, 60.538682118058205, 58.32901328802109, 56.58668898046017, 56.391645446419716, 55.733782947063446, 55.599315762519836, 54.931873977184296, 56.647614911198616, 55.74662245810032, 53.946609646081924, 56.775231063365936, 55.964069589972496, 55.447532907128334, 55.01373678445816, 55.5963709205389, 53.48271533846855, 55.07402814924717, 51.86347782611847, 54.66457352042198, 58.895410895347595, 53.00600811839104, 58.751991391181946, 58.19317817687988, 58.637815117836, 57.29096978902817, 59.78371202945709, 54.61739905178547, 61.398378387093544, 62.052057310938835, 66.67209640145302, 66.7869034409523, 67.08270236849785, 67.05877885222435, 68.6655530333519, 64.66082632541656, 70.736373513937, 69.31417062878609, 73.43568786978722, 67.71529242396355, 78.68353307247162, 64.67949852347374, 49.85504999756813, 6.3916299026459455, 0.5043740104883909, 0.40632303280290216, 0.22590117354411632, 0.32735792628955096, 0.13254589779535308, 0.3244692203588784, 0.16721124469768256, 0.0654641044093296, 0.14013091422384605, 0.21650671202223748, 0.9422112756874412, 0.1110674612573348, 0.25966455868911, 0.1402752471040003, 3.797178757376969, 41.006035432219505, 30.64646702259779, 42.383089140057564, 36.42191581428051, 63.843292593955994, 1.698344754986465, 0.20407428382895887, 0.23790930106770247, 0.1359639479778707, 0.09742460504639894, 0.1366626948583871, 0.2503553550923243, 0.46954380290117115, 0.3230828291270882, 0.2851700666360557, 0.5859648354817182, 0.16042342846048996, 0.37191163399256766], [22.3250712454319, 9.215597994625568, 5.387648725882173, 0.3619802731554955, 0.12852455576648936, 0.19197144341887906, 6.34281724691391, 20.370781011879444, 32.525483295321465, 46.64621338248253, 52.2953512519598, 57.51314006745815, 50.94776876270771, 48.906081318855286, 34.52812783420086, 37.32416220009327, 29.012579396367073, 22.155731432139874, 44.41028416156769, 1.233436376787722, 0.04636071484128479, 0.13256203208584338, 0.02569166084867902, 0.09321831239503808, 0.04922402076772414, 0.3237059066304937, 0.30606294865719974, 0.3494040761142969, 0.008968039237515768, 0.12513216905063018, 0.07765207657939754, 0.13470642326865345, 0.24082543677650392, 2.304435269907117, 14.361051991581917, 70.74157923460007, 66.73809885978699, 68.41011554002762, 73.87779414653778, 72.28764027357101, 73.14860567450523, 77.7012325823307, 73.81545469164848, 75.68201333284378, 76.42748773097992, 75.19695416092873, 74.90990996360779, 68.51517990231514, 61.655985563993454, 65.56393146514893, 70.06429597735405, 67.0359268784523, 67.93747410178185, 63.54514919221401, 65.51027834415436, 64.17166337370872, 62.7361574023962, 62.776959612965584, 63.358666598796844, 60.38709685206413, 57.53531947731972, 54.73688364028931, 54.62943680584431, 55.02130217850208, 56.598282158374786, 54.60905849933624, 53.85402001440525, 54.72228102385998, 51.779213547706604, 52.29163505136967, 53.05563725531101, 52.72585295140743, 54.569673612713814, 51.7412193864584, 51.8055385351181, 49.978938549757004, 52.7948572486639, 61.30643092095852, 69.14347618818283, 71.09865367412567, 67.86365166306496, 61.58598951995373, 68.21796745061874, 69.73707273602486, 63.00955273211002, 65.91868042945862, 57.09612004458904, 63.78612846136093, 64.62610378861427, 63.76507759094238, 60.629691034555435, 59.65571589767933, 52.96940088272095, 53.07910859584808, 64.69257742166519, 61.09475947916508, 63.80509704351425, 62.89756514132023, 64.7100792825222, 57.31889069080353, 51.26817896962166, 51.412248238921165, 46.27103291451931, 46.18263825774193, 50.89217774569988, 49.41694490611553, 46.952568143606186, 49.27305042743683, 48.74893695116043, 48.13221484422684, 48.44614639878273, 48.78679431974888, 50.139981508255005, 48.20070996880531, 50.11897623538971, 46.561196744441986, 47.348662689328194, 48.91959719359875, 48.66256758570671, 47.894457802176476, 50.47462195158005, 50.42971596121788, 50.73678508400917, 51.23234309256077, 53.051050901412964, 50.42167939245701, 52.047574147582054, 51.59303493797779, 59.57124263048172, 59.96584765613079, 61.417202576994896, 61.095948815345764, 64.56719934940338, 64.20013904571533, 60.918213352561, 61.66704677045345, 62.27879114449024, 68.4634418785572, 65.56972995400429, 72.70399913191795, 53.75523291528225, 24.382934421300888, 1.6207060148008168, 0.30723744188435376, 0.104196739703184, 0.10765084341983311, 0.0957622610440012, 0.09438056018552743, 0.07538330886745825, 0.0808813763433136, 0.12478102929890156, 0.28516062651760876, 1.1163563467562199, 0.1344390126178041, 0.07479413266992196, 0.10678639722755179, 0.02648146739375079, 0.41456823411863297, 19.418630003929138, 27.125004082918167, 11.45622281357646, 16.08135648071766, 36.96189343929291, 31.645285226404667, 0.24179604719392955, 0.047856287128524855, 0.052696574275614694, 0.01801794107450405, 0.10118897102074698, 0.017676493771432433, 8.543371316045523, 23.45329150557518, 33.31857293844223, 36.15107774734497, 37.76671685278416, 29.604228548705578, 32.914514020085335, 17.00150180608034, 10.606114380061626, 0.46930408920161426, 0.10729668312706053, 0.39660986338276416, 13.385122809559107, 33.01280714571476, 49.548919424414635, 67.21922904253006, 75.59938296675682, 75.40649011731148, 63.66942152380943, 53.0729491263628, 46.15924671292305, 35.24559773504734, 26.71515617519617, 27.12394393980503, 51.97887383401394, 1.0950431716628373, 0.07419795059831813, 0.06327067210804671, 0.043099484173581004, 0.04929172318952624, 0.06607311079278588, 0.21234666259260848, 0.09416691071237437, 0.2861679287161678, 0.07335961316130124, 0.031735310767544433, 0.030675596244691405, 0.11537153928657062, 0.3125527035444975, 2.5163629604503512, 25.94868790358305, 79.29093047976494, 69.19590577483177, 77.77244076132774, 77.23467081785202, 78.37293773889542, 77.20560237765312, 84.06793534755707, 74.98551070690155, 80.6795659661293, 76.98784366250038, 78.73989164829254, 77.54661127924919, 72.12074562907219, 66.24457374215126, 70.82690745592117, 72.58796095848083, 72.60289415717125, 70.68189203739166, 66.098912358284, 70.25764480233192, 69.24262806773186, 65.18897518515587, 68.57960164546967, 64.35447156429291, 66.0072460770607, 61.39545634388924, 58.139483258128166, 58.46705608069897, 57.94275641441345, 58.155981972813606, 59.10972319543362, 56.190617233514786, 57.45115399360657, 54.4807355850935, 55.368033573031425, 60.15700399875641, 57.91423514485359, 56.90670020878315, 56.691510155797005, 56.19399145245552, 53.27821411192417, 57.003458216786385, 63.585282638669014, 70.79932853579521, 72.84503236413002, 70.80672293901443, 66.35521620512009, 69.92339193820953, 69.42165166139603, 71.59815207123756, 67.54244729876518, 62.51061290502548, 68.1885190308094, 68.63602861762047, 70.6271293759346, 64.431721419096, 61.554618403315544, 54.48694445192814, 58.317469507455826, 67.50266343355179, 64.34804990887642, 64.88533347845078, 65.81007465720177, 67.24487766623497, 61.249118596315384, 53.89008387923241, 52.45989382266998, 53.00576493144035, 50.9234044700861, 52.259355783462524, 51.68485701084137, 49.872263073921204, 53.14303256571293, 52.04168826341629, 50.325274765491486, 49.40780259668827, 50.69351680576801, 52.98125244677067, 50.26557236909866, 53.857189044356346, 49.28995192050934, 50.31498111784458, 52.015511468052864, 51.75488345324993, 50.20922899246216, 52.44699351489544, 52.62750282883644, 52.063404098153114, 55.29294580221176, 56.07425607740879, 55.76679177582264, 55.03670275211334, 55.608971044421196, 61.83223530650139, 62.892047837376595, 65.022734105587, 64.10756081342697, 65.39864033460617, 67.06073194742203, 65.29543027281761, 64.17720347642899, 65.72115942835808, 68.61562371253967, 66.21505692601204, 76.96094870567322, 55.68386122584343, 39.355122819542885, 7.958264462649822, 0.5661718163173646, 0.2608208841411397, 0.0946828443557024, 0.18717250874033198, 0.07414743260596879, 0.049722966650733724, 0.08290654150187038, 0.26213240751530975, 0.17380665172822773, 1.6139491461217403, 0.8173977106343955, 0.20777292520506307, 0.11457363405497745, 0.004850032473768806, 0.2815936866682023, 20.798159278929234, 31.642855256795883, 17.740917429327965, 21.5829748660326, 39.97853636741638, 48.62751066684723, 0.6134640192613006, 0.08088749164016917, 0.049231208467972465, 0.043979641632176936, 0.019272782919870224, 0.3729938337346539, 14.549840111285448, 35.077604949474335, 47.31827951967716, 49.434663355350494, 51.35075993835926, 42.96658582985401, 28.137759938836098, 15.171937979757786, 9.136143308132887, 0.4848115617642179, 0.22081115370383486, 0.2965716813923791, 11.364392191171646, 32.21000902354717, 48.88458967208862, 70.85235089063644, 83.44295248389244, 86.75385922193527, 73.90424832701683, 67.5758171081543, 52.15799242258072, 60.58393768966198, 54.298364371061325, 37.66341559588909, 70.66440537571907, 1.3356134877540171, 0.25308283686172217, 0.18699725798796862, 0.24044247373240069, 0.23398011893732473, 0.1905807328876108, 0.5386396811809391, 0.8929194894153625, 0.5465484817977995, 0.17214453779160976, 0.1485950787900947, 0.0971262765233405, 0.26152619160711765, 0.7301058853045106, 4.4971878826618195, 46.05763636529446, 86.73606857657433, 76.11693799495697, 84.82623025774956, 83.31888914108276, 83.0174133181572, 80.58517903089523, 91.138466745615, 78.74795481562614, 84.47044014930725, 82.95588701963425, 84.63064715266228, 80.94435855746269, 75.1669205725193, 68.42867374420166, 76.4307251572609, 77.33797207474709, 75.5389966070652, 73.22422921657562, 70.23980855941772, 72.88087204098701, 71.95334941148758, 66.46368518471718, 72.14058056473732, 68.48973646759987, 68.74778062105179, 66.169064193964, 62.75027744472027, 62.09586136043072, 61.13300822675228, 63.05744916200638, 63.57895217835903, 59.640680104494095, 61.73070475459099, 57.40791991353035, 59.62900333106518, 64.00954127311707, 63.48724789917469, 62.934126779437065, 60.635307133197784, 61.405187621712685, 59.914778396487236, 60.689803808927536, 67.21930503845215, 72.16587960720062, 77.48277470469475, 75.98152086138725, 69.76886942982674, 72.43967771530151, 75.18598794937134, 66.09859317541122, 65.87131977081299, 65.06833165884018, 70.21753415465355, 72.25158020853996, 72.00904682278633, 67.29384183883667, 65.45023396611214, 54.821193516254425, 58.894236758351326, 72.43970051407814, 69.42496508359909, 68.83778259158134, 69.92802768945694, 70.28167471289635, 63.49794812500477, 56.4146114140749, 57.31822952628136, 56.19154058396816, 53.29200737178326, 57.380827367305756, 55.99422097206116, 53.35271291434765, 56.08271822333336, 53.75890351831913, 53.241694271564484, 52.06396646797657, 53.45901221036911, 56.739927157759666, 54.18521784245968, 58.52990470826626, 52.12296970188618, 54.216429367661476, 56.128258779644966, 56.747583746910095, 53.25866796076298, 56.493810564279556, 57.18163825571537, 55.15231154859066, 56.91621869802475, 58.84905718266964, 59.444489032030106, 57.803197503089905, 58.03760692477226, 65.75581356883049, 64.78126466274261, 69.34129357337952, 67.69714459776878, 69.11167949438095, 70.29494360089302, 68.17031800746918, 68.68754625320435, 66.37157812714577, 73.03672447800636, 69.76269856095314, 80.1294618844986, 61.97936341166496, 52.64353036880493, 14.75496070459485, 0.7038855704013258, 0.3305548906791955, 0.27319569198880345, 0.29042444250080734, 0.17955050367163494, 0.16233021364314482, 0.2201393319410272, 0.5667702842038125, 0.45994124317076057, 2.983479257673025, 0.6390963750891387, 0.2917204995173961, 0.3175098937936127, 0.18007480131927878, 0.6549098796676844, 30.517285354435444, 44.09392453730106, 23.4440466016531, 28.748723454773426, 53.887629210948944, 49.764432460069656, 0.34733090142253786, 0.1286605023778975, 0.15427620441187173, 0.11674482419039123, 0.17064713611034676, 0.3669024637201801, 12.211604230105877, 33.861780390143394, 47.25000858306885, 50.79425700008869, 53.93494427204132, 41.98020435869694], [38.14178712666035, 44.859062880277634, 52.863983139395714, 19.170961193740368, 0.6454405502881855, 21.485162414610386, 26.72382351011038, 22.427006475627422, 23.169973008334637, 27.320112213492393, 25.593826845288277, 43.83425787091255, 49.792463555932045, 34.06796492636204, 37.351220548152924, 51.369329541921616, 21.25145025551319, 22.212561182677746, 26.272189244627953, 0.45183808892033994, 0.0537097060441738, 0.025654716737335548, 0.028645377060456667, 0.05681291862856597, 0.060718797321897, 0.06768055813154206, 0.016644561546854675, 0.054472637566505, 0.06147330546809826, 0.05519226848264225, 0.007561622542198165, 0.03122921429167036, 0.3303485142532736, 2.2083923360332847, 9.26701683551073, 60.32843939960003, 73.03806960582733, 68.52529495954514, 73.95775705575943, 73.79647091031075, 71.39670208096504, 76.07381790876389, 70.33880084753036, 75.46067520976067, 77.23853901028633, 71.96758344769478, 71.5544544160366, 68.63995760679245, 63.76028224825859, 67.22971647977829, 65.85077047348022, 70.34073114395142, 67.27282136678696, 63.096617460250854, 64.58655551075935, 65.74082717299461, 64.9765893816948, 64.02618438005447, 62.10036791861057, 59.588467106223106, 57.25921489298344, 54.90799605846405, 51.42199091613293, 55.274159610271454, 52.27178491652012, 55.584876537323, 52.56870478391647, 52.8699716180563, 52.039727568626404, 51.1879538744688, 52.714244574308395, 51.65167339146137, 51.8095663189888, 52.93687462806702, 50.745509415864944, 51.85867868363857, 53.377346992492676, 59.88463081419468, 66.46289482712746, 66.25748544931412, 61.89727641642094, 64.81455847620964, 67.01009586453438, 70.17622277140617, 64.32293325662613, 59.30931128561497, 70.87432131171227, 68.01260367035866, 70.03369241952896, 65.3942097723484, 66.4706540107727, 57.568058520555496, 58.25448788702488, 59.32948440313339, 61.44572764635086, 53.292459547519684, 62.790114507079124, 64.97987240552902, 64.21861365437508, 59.89409990608692, 51.173719838261604, 48.09770509600639, 46.40882112085819, 47.49872803688049, 49.80414032936096, 46.42163023352623, 49.643032774329185, 47.65935681760311, 46.261818408966064, 46.35253854095936, 47.26969912648201, 48.91110844910145, 49.12163995206356, 47.99747787415981, 48.495817333459854, 45.98369613289833, 48.45256045460701, 47.03979626297951, 52.49871253967285, 48.83834235370159, 50.68216681480408, 50.78317679464817, 50.86519159376621, 51.321531906723976, 54.366228729486465, 51.66794411838055, 51.644001603126526, 51.47788591682911, 52.375276163220406, 60.371620282530785, 60.48972934484482, 57.40243300795555, 62.59781062602997, 65.01283183693886, 60.6938885897398, 59.40583370625973, 64.25557047128677, 66.8768522143364, 63.63662168383598, 74.4883681833744, 50.70107080042362, 31.26617006957531, 10.808932296931744, 0.21349829767132178, 0.2760065911570564, 0.1680620724800974, 0.03253133094403893, 0.06648038659477606, 0.13216712046414614, 0.13397901464486495, 0.6110641511622816, 2.368196086026728, 2.0147860748693347, 1.1758466670289636, 0.06223220712854527, 0.12253273744136095, 0.05125127878272906, 0.032564148714300245, 9.439671020954847, 29.21692483127117, 15.216257851570845, 26.565370112657547, 23.012545555830002, 43.09550151228905, 11.83204259723425, 0.40345095098018646, 0.12472860398702323, 0.06996684795012698, 0.07980449780006893, 17.564717084169388, 48.42961348593235, 35.173561200499535, 34.315863624215126, 29.73910231143236, 32.51643978059292, 32.82898060977459, 52.63605996966362, 58.09488505125046, 72.36306622624397, 30.44350851327181, 1.7757524200715125, 43.807644098997116, 48.59732508659363, 36.094836965203285, 36.6651863604784, 40.644154250621796, 38.870394229888916, 53.863747492432594, 62.464772164821625, 44.072668477892876, 45.80552749335766, 49.99878868460655, 25.244070813059807, 29.850489534437656, 30.613594986498356, 0.4372379067353904, 0.014108159612078452, 0.04577340143441688, 0.1153350924141705, 0.06393257135641761, 0.1135439338395372, 0.07328240753849968, 0.031244480269378982, 0.040716281000641175, 0.06199765135534108, 0.10744822968263179, 0.039827770669944584, 0.07123689269064926, 1.4724477077834308, 2.7413902105763555, 19.204710982739925, 72.82825246453285, 72.89787992835045, 76.81981667876244, 77.68640577793121, 81.31274119019508, 77.02185943722725, 78.65897119045258, 75.86258724331856, 78.65870520472527, 79.35310274362564, 76.23972460627556, 76.28080800175667, 72.89442971348763, 68.30062821507454, 71.20780661702156, 70.55447727441788, 74.90044087171555, 68.73408615589142, 65.47725051641464, 70.38679227232933, 70.08027032017708, 68.35857510566711, 68.91026750206947, 65.31633675098419, 62.04170286655426, 60.62723256647587, 58.56949858367443, 55.590781420469284, 56.920683458447456, 56.51153661310673, 58.077276796102524, 56.97548791766167, 56.29771068692207, 56.00731886923313, 53.70714649558067, 58.699561804533005, 55.27312986552715, 55.08189372718334, 54.67697225511074, 56.157388016581535, 55.89862570166588, 57.853635996580124, 63.469278663396835, 69.98615697026253, 69.56765502691269, 66.26388430595398, 68.51310521364212, 68.96503016352654, 71.04365542531013, 69.2157331109047, 63.83023649454117, 73.80994498729706, 72.25359410047531, 75.29867470264435, 68.68378445506096, 67.82405778765678, 60.90601980686188, 62.450503930449486, 61.95576287806034, 62.569946721196175, 57.018585205078125, 62.85632215440273, 66.42662957310677, 69.04687777161598, 61.29551790654659, 54.73581589758396, 51.40598237514496, 49.29700434207916, 51.00899487733841, 52.15249791741371, 50.187573954463005, 53.61030489206314, 49.932573437690735, 48.55274587869644, 49.19416666030884, 50.1969176530838, 51.01091757416725, 50.703449472784996, 49.541544020175934, 51.35862171649933, 50.18738396465778, 51.84493862092495, 49.56523574888706, 52.53797583281994, 52.8844640403986, 53.14524404704571, 54.12828929722309, 54.39482979476452, 53.46575304865837, 58.45623806118965, 56.72024801373482, 54.46304373443127, 54.827539175748825, 56.96983762085438, 62.80830793082714, 64.61673349142075, 60.82557052373886, 63.372687846422195, 67.95540913939476, 62.05635868012905, 64.19894590973854, 67.08771049976349, 66.59742280840874, 66.14121168851852, 75.10708138346672, 54.295894503593445, 42.46986888349056, 27.59906094521284, 0.2473313853261061, 0.11078278083004989, 0.10421503364341334, 0.06326405215077102, 0.045886809020885266, 0.0376467990281526, 0.035726773930946365, 0.477922887657769, 0.6638833356555551, 0.5720790149644017, 1.3263891264796257, 0.17223426344571635, 0.24223802582127973, 0.07784467132296413, 0.12314869774854742, 11.072356961667538, 30.711344741284847, 22.335676476359367, 38.292023465037346, 30.998886711895466, 50.91481313109398, 24.240508563816547, 0.23110484587959945, 0.21302958688465878, 0.07415417130687274, 0.5665020423475653, 27.579889073967934, 62.45586544275284, 46.56783118844032, 46.99540704488754, 39.240102991461754, 41.41757994890213, 43.10114420950413, 69.85861301422119, 67.5826795399189, 85.41020572185516, 34.66465450823307, 1.7990714125335217, 52.72412784397602, 58.55168513953686, 50.50756998360157, 50.62073551118374, 51.32510371506214, 45.29956564307213, 64.84613478183746, 74.37862247228622, 56.77913725376129, 56.851599365472794, 80.41277468204498, 45.510503724217415, 37.59680517017841, 41.918168887495995, 0.6149053887929767, 0.22632005653576925, 0.15112967637833208, 0.22956658154726028, 0.21168864477658644, 0.12982923653908074, 0.15931028116028756, 0.09716957341879606, 0.14246094622649252, 0.15473433217266575, 0.2418088269769214, 0.09766836345079355, 0.18923860334325582, 2.491537230089307, 4.458439936861396, 33.642642349004745, 81.91109508275986, 79.7143417596817, 81.47049352526665, 82.30778619647026, 85.51095351576805, 80.7113778591156, 85.06951600313187, 77.05737993121147, 82.2673487663269, 84.32343363761902, 81.13801136612892, 81.04873895645142, 77.15163767337799, 71.19522169232368, 75.49928113818169, 74.01924535632133, 77.91100412607193, 73.58465507626534, 69.54349592328072, 70.48636212944984, 72.26912006735802, 73.14478307962418, 73.59049916267395, 68.50089266896248, 66.04210540652275, 62.653306648135185, 61.67607128620148, 56.843669191002846, 61.08960695564747, 57.66981326043606, 63.263139724731445, 57.63414837419987, 59.12110738456249, 59.38184939324856, 57.66407176852226, 60.179065614938736, 59.15399082005024, 58.528016209602356, 61.30844101309776, 62.38486245274544, 60.30168503522873, 62.85936579108238, 68.92159849405289, 72.187979221344, 72.96461194753647, 68.84401425719261, 70.93195661902428, 72.95963421463966, 75.29256463050842, 59.292485788464546, 64.22905549407005, 80.74039310216904, 73.23404029011726, 79.79775488376617, 71.30676090717316, 72.84016102552414, 63.52812610566616, 61.93325288593769, 63.89173999428749, 66.36169865727425, 59.81269687414169, 70.06808057427406, 69.98805686831474, 71.14368125796318, 64.52773466706276, 58.24049323797226, 54.9124988168478, 53.64935539662838, 56.522062048316, 58.41566003859043, 52.65340983867645, 57.6665036380291, 54.497017711400986, 52.72526778280735, 51.537668108940125, 52.33176849782467, 53.43262642621994, 55.34670531749725, 53.76553796231747, 55.803626999258995, 52.27765940129757, 54.82688181102276, 53.23516622185707, 57.81786851584911, 55.392310470342636, 56.260624676942825, 57.88132891058922, 58.43229554593563, 58.51866111159325, 61.537716910243034, 59.21966269612312, 57.848525270819664, 57.51645728945732, 56.775177866220474, 66.70659855008125, 64.3339754641056, 62.346879690885544, 65.90149015188217, 70.47022059559822, 64.83745604753494, 64.44935247302055, 71.56330034136772, 70.61805546283722, 70.63909113407135, 78.13012316823006, 60.331008061766624, 53.721589520573616, 36.62975326180458, 0.3166359110036865, 0.19729277584701777, 0.24428708071354777, 0.17031110648531467, 0.22062836273107678, 0.22199851577170193, 0.25185197009705007, 2.507875640876591, 7.148461416363716, 4.4766884576529264, 3.1883583264425397, 0.23124586878111586, 0.7025743438862264, 0.10886636257055216, 0.41323468380142003, 14.897602200508118, 47.758824080228806, 29.477552846074104, 45.48620402812958, 37.97806531190872, 67.41956189274788, 24.705751799046993, 0.7025645475368947, 0.38363994215615094, 0.25363235268741846, 0.7331335509661585, 30.060718953609467, 73.32809284329414, 51.751885414123535, 55.379660949110985, 47.43098147213459, 52.216801866889, 49.755719527602196], [27.307620383799076, 20.63799787312746, 37.156796380877495, 29.653568901121616, 8.938889242708683, 13.030820321291685, 10.04191305488348, 40.254093781113625, 44.39522936940193, 48.16516287624836, 41.82581104338169, 52.65265367925167, 48.842734917998314, 29.901914075016975, 44.88685838878155, 28.02481859922409, 23.045436590909958, 38.21683309972286, 20.99201537668705, 0.438031381345354, 0.1268766020075418, 0.06281023626797833, 0.05154722872248385, 0.09275821052142419, 0.07967019133502617, 0.07187198556493968, 0.057908644012059085, 0.042476788876228966, 0.05255607458821032, 0.1352465435047634, 0.0953942300111521, 0.026272651157341897, 2.0527759613469243, 8.32844439893961, 24.928571842610836, 45.92456370592117, 72.53268912434578, 70.8475099503994, 75.43867439031601, 74.62510004639626, 70.95873758196831, 75.33933252096176, 73.69359523057938, 72.69753187894821, 75.06947100162506, 71.28164425492287, 70.48307910561562, 65.71609050035477, 65.4322001338005, 66.45342573523521, 67.10813820362091, 69.2447255551815, 60.991161838173866, 65.05347445607185, 67.09410935640335, 65.42107433080673, 64.88308399915695, 61.40836805105209, 60.752865225076675, 57.786030024290085, 55.532667338848114, 54.085921570658684, 52.69953936338425, 54.28996682167053, 53.32584075629711, 55.10994002223015, 54.351477921009064, 53.937725722789764, 51.47886626422405, 51.279650554060936, 57.41852894425392, 53.96509185433388, 52.37349785864353, 50.96756190061569, 47.60274365544319, 50.875937417149544, 53.41724865138531, 59.885288178920746, 65.52064418792725, 68.51692020893097, 62.71614767611027, 65.98106548190117, 62.31826722621918, 74.40699934959412, 60.984128415584564, 60.215517058968544, 71.5450157225132, 63.559086844325066, 69.84512373805046, 64.08516481518745, 66.7978772521019, 57.04190835356712, 65.91624855995178, 62.65253908932209, 61.99453219771385, 58.61099235713482, 56.95113502442837, 62.79560901224613, 63.7530854344368, 61.02027967572212, 52.4327252805233, 45.529479905962944, 44.4234998524189, 46.50323085486889, 48.97936798632145, 49.605403393507004, 48.72366450726986, 46.437813565135, 46.65768876671791, 48.28665755689144, 47.003607004880905, 47.56369695067406, 48.253329545259476, 48.545150086283684, 46.89211718738079, 46.55521206557751, 48.193482756614685, 48.466490507125854, 47.10966311395168, 48.9968204498291, 51.539195626974106, 49.694398418068886, 51.888058707118034, 49.284358620643616, 52.16198980808258, 52.608040273189545, 55.62700107693672, 53.954114243388176, 56.379022523760796, 58.22634279727936, 61.74422062933445, 60.35283029079437, 62.32783891260624, 62.42133289575577, 64.37985420227051, 62.201051115989685, 66.15492895245552, 63.81044715642929, 67.87424549460411, 71.42053440213203, 45.599772334098816, 41.5942020714283, 33.62272001802921, 2.8258399665355682, 0.6127760780509561, 0.03530853660777211, 0.21752002561697736, 0.0871427427046001, 0.1207560210605152, 0.031095479280338623, 0.2503351686755195, 0.7425936183426529, 0.7763823552522808, 1.5989860240370035, 0.8049010124523193, 0.19530199439032003, 0.08832202278426848, 0.12301212031161413, 3.990730158984661, 17.75972831994295, 18.491211868822575, 16.693735420703888, 24.825899451971054, 33.44991289079189, 26.330168433487415, 0.04771650732436683, 0.058241430451744236, 0.10426414155517705, 7.067999308928847, 39.04999919235706, 40.87520085275173, 77.37429052591324, 94.94048193097115, 97.97347918152809, 89.17540088295937, 48.09233218431473, 32.49246686697006, 27.58270852267742, 50.29667370021343, 33.880809769034386, 22.721308283507824, 27.83545196056366, 20.719302110373974, 60.970221161842346, 66.81798577308655, 65.98455369472504, 50.317257195711136, 64.837167263031, 59.01170365512371, 42.278180569410324, 52.75289610028267, 34.821061715483665, 24.473759047687054, 48.22698175907135, 25.21626390516758, 0.6436685391236097, 0.13354659487958997, 0.17556865874212235, 0.05517135105037596, 0.10084183886647224, 0.018178398968302645, 0.09920291704474948, 0.033671273486106656, 0.06242943287361413, 0.0752069968439173, 0.01624993750738213, 0.07650014464161359, 0.04349990624177735, 3.3736064611002803, 11.928649563342333, 31.911291852593422, 53.990687280893326, 76.37594729661942, 74.88743796944618, 79.0734301507473, 76.57685771584511, 76.19044125080109, 77.3990423977375, 77.29331687092781, 74.80638071894646, 77.50849172472954, 77.64768585562706, 75.2871461212635, 70.23633554577827, 70.6556886434555, 70.29135659337044, 72.5448788702488, 72.08424478769302, 62.97511138021946, 68.44340935349464, 68.69270637631416, 67.89535716176033, 67.47117832303047, 64.77955475449562, 62.83040374517441, 60.92594213783741, 58.446464985609055, 56.59559190273285, 55.6683998554945, 56.93282760679722, 57.56474129855633, 55.821531638503075, 54.239684119820595, 55.436061322689056, 53.214297741651535, 54.75723534822464, 59.134649857878685, 59.06111620366573, 57.48122178018093, 56.054253950715065, 52.66084223985672, 56.5811412781477, 57.45105899870396, 62.564801797270775, 65.34964576363564, 70.96015110611916, 66.6455814242363, 69.55509290099144, 64.55448523163795, 77.00075536966324, 64.35828655958176, 62.15494818985462, 74.564508497715, 69.48093608021736, 72.19557881355286, 67.98183292150497, 70.17030268907547, 57.98782579600811, 65.33636167645454, 65.25987938046455, 65.40851980447769, 63.6677648127079, 59.538283199071884, 65.08424520492554, 65.38922443985939, 61.46004147827625, 54.33438263833523, 50.00977009534836, 47.71940879523754, 51.139943450689316, 52.95493505895138, 53.44393461942673, 52.77912229299545, 51.87869980931282, 49.583725556731224, 51.14758864045143, 49.36853550374508, 49.765975177288055, 50.934651866555214, 49.93543468415737, 49.32201460003853, 49.68994505703449, 52.100543305277824, 50.951416566967964, 50.10364405810833, 51.09892465174198, 54.387082010507584, 52.97812521457672, 54.214464873075485, 50.844570100307465, 56.195727959275246, 56.910830587148666, 56.98122940957546, 58.589705899357796, 60.659960210323334, 61.28232881426811, 63.571151196956635, 64.62119445204735, 65.33699244260788, 65.55200010538101, 67.78858289122581, 65.43308928608894, 68.74329686164856, 65.2022136747837, 71.77779123187065, 71.14600673317909, 51.5632027387619, 51.79318159818649, 56.719070076942444, 3.2019884325563908, 0.7503578485921025, 0.15063978469697759, 0.22696386964526027, 0.05459983796754386, 0.12695624929619953, 0.13158723595552146, 0.12077754334313795, 0.39219758764375, 0.4798651474993676, 0.575181667227298, 2.1060082549229264, 0.4277708928566426, 0.1357755166827701, 0.04179021321760956, 4.030246138572693, 23.421285822987556, 19.253487065434456, 23.968426063656807, 37.622609585523605, 38.52277748286724, 41.22903786599636, 0.4419340688036755, 0.04665797096095048, 0.13974012894323096, 11.003389712423086, 51.53522104024887, 52.797448709607124, 85.67530229687691, 99.74945828318596, 101.52714729309082, 101.14526018500328, 54.003112614154816, 37.112703546881676, 36.85942813754082, 60.08505865931511, 44.78720113635063, 33.29746887087822, 57.3873820155859, 47.9895780980587, 98.76207366585732, 96.71200767159462, 104.90413248538971, 74.82430815696716, 76.04464307427406, 73.62781316041946, 55.24931274354458, 69.58158507943153, 47.94588804244995, 37.21587561070919, 63.912091702222824, 33.55017051100731, 0.636447382858023, 0.2850932098226622, 0.26795431855134666, 0.155305459338706, 0.29728936788160354, 0.13957278948510066, 0.17637850512983277, 0.1906897989101708, 0.17699286981951445, 0.16570553096244112, 0.25183015095535666, 0.15434684202773497, 0.2777855488238856, 4.844638388603926, 13.787421472370625, 43.318712934851646, 63.583473935723305, 80.18851831555367, 77.97041773796082, 84.42534416913986, 82.75110840797424, 78.97617816925049, 81.69560864567757, 79.84598949551582, 77.00700983405113, 82.43700206279755, 80.60582712292671, 79.58920687437057, 73.31324324011803, 73.31173852086067, 73.19085940718651, 75.01832574605942, 76.38575837016106, 67.11493223905563, 70.63655287027359, 74.52179118990898, 72.9015277326107, 70.65137207508087, 68.5194280743599, 68.50513324141502, 64.54571530222893, 64.14148539304733, 61.08291171491146, 58.688173815608025, 61.004605516791344, 59.83760453760624, 60.05195863544941, 59.34567153453827, 60.52330054342747, 57.28509530425072, 58.17577511072159, 66.00856840610504, 62.45143108069897, 60.745052844285965, 60.54714806377888, 54.32339742779732, 60.18984563648701, 61.152717769145966, 68.74468758702278, 71.7059750854969, 72.90798738598824, 70.06440997123718, 72.60536402463913, 70.05437850952148, 75.72402387857437, 60.35215772688389, 68.61254587769508, 78.92807275056839, 71.17144256830215, 74.05614137649536, 70.59311360120773, 74.4775539636612, 60.841069892048836, 69.67474088072777, 69.10496145486832, 68.234823346138, 65.85918322205544, 62.91396886110306, 68.11958312988281, 68.01069617271423, 67.84608140587807, 59.14856091141701, 52.5922255218029, 51.76261983811855, 57.87675775587559, 55.36491014063358, 56.82286150753498, 54.1925248503685, 55.643108412623405, 51.66499927639961, 55.39504632353783, 53.855764120817184, 53.53118933737278, 56.89864844083786, 54.51833076775074, 51.85191124677658, 52.41101324558258, 55.894309133291245, 55.29149807989597, 54.239855110645294, 54.50811691582203, 58.306784480810165, 56.91396921873093, 58.38748835027218, 54.37673136591911, 58.89895610511303, 58.878441005945206, 61.114146038889885, 59.67269338667393, 62.40030102431774, 62.80987724661827, 66.66382804512978, 65.23366838693619, 67.76193872094154, 67.07445681095123, 70.0631408393383, 67.24486246705055, 71.29403918981552, 67.52919360995293, 77.09968686103821, 73.71347576379776, 59.907429590821266, 55.86195766925812, 66.71996623277664, 4.979945803061128, 0.9443340555299073, 0.25748697866220027, 0.3756549971876666, 0.2586754539515823, 0.3593580872984603, 0.26532794698141515, 0.5364401335828006, 2.513925153762102, 1.9840385997667909, 6.038333410397172, 2.046200414188206, 0.6928070273716003, 0.4502007330302149, 0.2028158091707155, 7.71455361507833, 31.804380789399147, 35.05565732717514, 29.780567586421967, 42.737792506814, 48.06882284581661, 54.60831753909588, 0.8236582309473306, 0.12651042634388432, 0.2868997456971556, 12.03343654051423, 62.18828000128269, 58.390383794903755, 98.7753501534462, 122.80083015561104, 122.66602098941803, 121.99254512786865, 66.506068110466], [97.39967957139015, 45.76450489461422, 46.40551909804344, 18.326036632061005, 20.385214537382126, 12.02206090092659, 14.68941517174244, 20.474146865308285, 32.11131691932678, 67.84407511353493, 55.748944133520126, 62.8378551453352, 49.77134808897972, 24.753465838730335, 42.73352533578873, 46.35522119700909, 28.06592669337988, 37.566004022955894, 10.552343465387821, 0.4924839438172057, 0.19980346143711358, 0.20637281908420846, 0.0789974196231924, 0.029403521730273496, 0.03805476131674368, 0.09007399596157484, 0.09237175938324071, 0.015176573961070972, 0.01799915546143893, 0.07867800668464042, 0.05987774733512197, 0.0649632586282678, 5.911776926368475, 24.534789472818375, 43.035172149538994, 30.597103871405125, 75.23484572768211, 72.91079923510551, 78.95657882094383, 74.48439359664917, 71.70852094888687, 70.7168273627758, 76.40215829014778, 74.51606869697571, 71.90179377794266, 72.54026591777802, 70.40509209036827, 66.93548306822777, 70.33876284956932, 69.36811253428459, 71.11133739352226, 66.59822836518288, 62.14345380663872, 67.60370001196861, 64.80883598327637, 63.665975108742714, 64.8080076277256, 63.18911209702492, 58.75221937894821, 59.824841022491455, 56.134775429964066, 53.881747126579285, 53.368763253092766, 54.36811342835426, 54.57608386874199, 54.94546964764595, 52.41537161171436, 50.67692689597607, 51.71356447041035, 50.55086866021156, 50.48568695783615, 50.711208656430244, 52.248001992702484, 50.9194602817297, 51.360745802521706, 49.73249137401581, 50.300321504473686, 58.16250242292881, 61.75020910799503, 64.60301622748375, 62.29872107505798, 68.5690002143383, 65.20770817995071, 82.15864419937134, 52.819795310497284, 57.679715529084206, 70.58263376355171, 68.92717659473419, 66.92472204566002, 69.03765946626663, 65.84833860397339, 58.07812035083771, 63.75408098101616, 61.07011400163174, 60.25268666446209, 60.20625315606594, 56.83332234621048, 58.371707797050476, 61.14849619567394, 56.248875707387924, 51.73254445195198, 47.98894353210926, 46.57815523445606, 47.42388725280762, 50.21812051534653, 49.00449603796005, 49.9809106439352, 46.46950006484985, 45.44099785387516, 45.515922233462334, 45.052529498934746, 46.2103121727705, 46.74016714096069, 48.73211905360222, 47.58718729019165, 46.644176691770554, 47.49035708606243, 48.53112503886223, 46.331278681755066, 51.03297919034958, 51.50483027100563, 52.74085074663162, 51.052646934986115, 49.9176212400198, 51.897201016545296, 55.12458823621273, 56.07378490269184, 53.90118308365345, 53.69075797498226, 56.39457888901234, 58.9985715597868, 64.21659216284752, 59.073568135499954, 60.24696037173271, 63.79908576607704, 63.2349718362093, 64.68870162963867, 62.55594067275524, 65.58926850557327, 68.44229981303215, 42.27135233581066, 71.63659080862999, 49.6548805385828, 5.243931887671351, 0.6623921531718224, 0.09489451229455881, 0.07087506601237692, 0.016800251141830813, 0.08803613265627064, 0.05744736212363932, 0.050800895332940854, 0.06590853954548948, 0.08847829682053998, 1.0707016778178513, 0.7672643288969994, 0.053011779236840084, 0.1465934471343644, 0.04580359942337964, 1.2136483448557556, 14.000818971544504, 14.98294372111559, 13.159132786095142, 15.1680051907897, 29.61351715028286, 30.640005469322205, 0.45645932375919074, 0.07163323665736243, 0.35282867203932256, 24.280121438205242, 50.75939007103443, 84.44116652011871, 77.38774940371513, 58.447631523013115, 52.12462641298771, 69.61598843336105, 101.77455961704254, 103.10507342219353, 45.78745946288109, 57.529118210077286, 24.615620635449886, 33.17635416984558, 23.15598975867033, 31.361883133649826, 34.516496658325195, 51.04390360414982, 87.89591833949089, 69.74369958043098, 72.69300252199173, 58.638506680727005, 34.23951432108879, 54.55660231411457, 47.867369055747986, 31.219086796045303, 45.85296414792538, 12.983220275491476, 0.4188168217660859, 0.3009096533060074, 0.29651483288034797, 0.050501461009844206, 0.040729365064180456, 0.049505847637192346, 0.05266687352559529, 0.03008706942637218, 0.026293063929188065, 0.030788196745561436, 0.052646976546384394, 0.07993890816578642, 0.08078234415734187, 7.810300877317786, 26.64262566715479, 52.45437651872635, 40.501350313425064, 78.29236686229706, 77.15935125946999, 84.34147506952286, 76.9788533449173, 75.809625685215, 71.75554722547531, 79.56572413444519, 77.7991533279419, 76.64438769221306, 74.28715378046036, 74.48312446475029, 72.1525727212429, 72.88259714841843, 70.76323047280312, 73.60496118664742, 67.75544106960297, 67.30181381106377, 71.09712615609169, 66.17047011852264, 66.83459848165512, 67.88244545459747, 65.63065588474274, 62.00444966554642, 61.24395087361336, 57.52619616687298, 56.62258945405483, 56.54553338885307, 56.17798671126366, 57.71979957818985, 58.90626311302185, 55.717899799346924, 53.91071297228336, 54.17274311184883, 54.77147698402405, 52.776595428586006, 52.96055115759373, 54.00596626102924, 54.71135661005974, 53.93342815339565, 53.09634067118168, 52.681239545345306, 59.956633150577545, 63.89427825808525, 66.5172091126442, 65.86265623569489, 69.94148656725883, 68.87400224804878, 80.2038922905922, 57.40235701203346, 62.085381522774696, 70.78190267086029, 74.07654628157616, 69.8791091144085, 72.03047007322311, 66.67660295963287, 59.08119052648544, 67.17936918139458, 65.15935197472572, 61.218188256025314, 62.786512300372124, 60.9601479023695, 60.41030600667, 63.84426534175873, 60.4894595593214, 53.23892422020435, 51.29452295601368, 50.76105818152428, 52.67241261899471, 54.1759767383337, 53.9281540364027, 53.59404556453228, 47.765804305672646, 48.95892508327961, 49.336913600564, 47.7296644449234, 50.049599558115005, 49.462379068136215, 50.324108228087425, 49.63993974030018, 49.88630332052708, 49.57979656755924, 49.40101996064186, 49.02268186211586, 53.667856603860855, 56.659755259752274, 55.94505541026592, 52.12671250104904, 52.48744994401932, 54.90370228886604, 58.38967323303223, 59.78438459336758, 58.003864735364914, 58.025090396404266, 58.20239268243313, 63.30192044377327, 65.84624111652374, 63.24671320617199, 62.71826036274433, 65.4356275498867, 64.58518758416176, 67.55920439958572, 64.84055668115616, 67.88834273815155, 71.45187512040138, 45.0983702391386, 78.2943807542324, 62.58422635495663, 15.555923525243998, 1.3544869562610984, 0.07253262316226028, 0.12321933536441065, 0.15824896545382217, 0.07485495167202316, 0.19683856662595645, 0.010569410242169397, 0.06969835376366973, 0.05585103957855608, 0.9878861310426146, 1.7071314272470772, 0.39716641476843506, 0.09568639128701761, 0.0355996625876287, 1.3833141094073653, 15.923495851457119, 14.029237646609545, 19.323956184089184, 19.36930675059557, 35.29594503343105, 45.51103949546814, 1.8596430122852325, 0.17221380985574797, 0.4782122658798471, 38.57194684445858, 63.55598621070385, 93.1426540017128, 78.12645256519318, 65.2978165447712, 56.237514317035675, 67.09581166505814, 108.31270918250084, 140.22366285324097, 64.81968820095062, 75.50900101661682, 30.298206210136414, 46.14081010222435, 62.582174465060234, 79.66744467616081, 61.552338525652885, 75.4137933254242, 116.34259790182114, 100.31283125281334, 87.68749192357063, 72.55557149648666, 44.459837302565575, 67.5947704911232, 68.92225205898285, 44.89592470228672, 58.730450347065926, 17.92731072753668, 0.7250352948904037, 0.5658255005255342, 0.41284137521870434, 0.15787956886924803, 0.1677030511200428, 0.1561613188823685, 0.26691967563237995, 0.1564922573743388, 0.17244184215087444, 0.13222310808487236, 0.19767869263887405, 0.2304662426467985, 0.23934264056151733, 10.977810434997082, 29.869283325970173, 52.54944361746311, 52.80508249998093, 80.17613857984543, 82.86087691783905, 85.05091220140457, 82.64589965343475, 78.83261427283287, 75.10369196534157, 84.26344245672226, 83.04765209555626, 81.19069173932076, 78.82379874587059, 77.8725577890873, 75.03372251987457, 77.90020510554314, 74.66639623045921, 77.4197056889534, 71.3218080997467, 70.54903596639633, 73.3493185043335, 69.92399990558624, 69.64527726173401, 70.9004183113575, 66.95157140493393, 66.74381375312805, 67.09675401449203, 62.49951370060444, 59.88246113061905, 60.58135382831097, 59.97575372457504, 61.16853632032871, 61.69144906103611, 58.55675406754017, 56.00593954324722, 58.42389799654484, 57.55424626171589, 57.13589251041412, 58.68380784988403, 58.92942287027836, 58.292394652962685, 59.735796600580215, 57.95106656849384, 58.232316076755524, 64.34999540448189, 66.37680664658546, 70.7469217479229, 69.65128853917122, 72.25141301751137, 72.813630849123, 79.75767463445663, 57.716828137636185, 65.17217248678207, 74.31024134159088, 76.74915567040443, 71.79679781198502, 72.79284596443176, 70.24537146091461, 59.46938529610634, 68.05139198899269, 66.70004770159721, 64.08901020884514, 66.40269085764885, 65.54896786808968, 64.41927328705788, 67.52156361937523, 60.744881853461266, 58.50274756550789, 53.396615758538246, 53.66703204810619, 56.226323917508125, 58.6789783090353, 57.71690413355827, 58.638103902339935, 51.00788153707981, 50.91702461242676, 51.94348633289337, 50.482696518301964, 52.05526493489742, 51.4749638736248, 55.07419154047966, 52.476951107382774, 54.02293235063553, 53.80971059203148, 55.662848353385925, 53.11688996851444, 58.48130151629448, 59.01823550462723, 61.300776824355125, 57.00869433581829, 55.12145720422268, 58.7306023389101, 62.53246933221817, 62.9827793687582, 61.29111774265766, 60.71281537413597, 60.323195680975914, 64.54687803983688, 69.47034224867821, 65.78783065080643, 66.27364218235016, 67.65364453196526, 65.57053551077843, 69.7895935177803, 67.8843605518341, 71.00911527872086, 71.48855075240135, 55.25092385709286, 74.49429586529732, 70.0356075167656, 31.06185883283615, 2.1665480313822627, 0.26486244227271527, 0.19525093463016674, 0.2871503244386986, 0.14671262120828032, 0.31559040304273367, 0.12051137950038537, 0.161473315092735, 0.15656426054192707, 3.1616488471627235, 3.4082556143403053, 0.3964990458916873, 0.41122197930235416, 0.18016460118815303, 2.6463893707841635, 24.03867669403553, 27.675110064446926, 26.799846030771732, 31.745261661708355, 48.70292901992798, 61.71782724559307, 3.5622193152084947, 0.3534017287893221, 0.5571468849666417, 41.40616536140442, 71.6740719974041, 107.52112045884132, 98.5965545475483, 76.88302248716354, 68.7094634771347, 84.78483527898788, 137.51439303159714], [90.13175636529922, 79.12665769457817, 63.88781860470772, 12.686218712478876, 26.537850089371204, 17.421090491116047, 4.17407744564116, 7.733984822407365, 15.133115462958813, 52.77113892138004, 52.13969640433788, 61.31491206586361, 42.98287555575371, 28.99641316384077, 49.48467247188091, 44.34791050851345, 21.41801431775093, 32.59286507964134, 5.537342643365264, 0.3122115827864036, 0.05420241046522278, 0.038235730316955596, 0.05468635012221057, 0.06705234496621415, 0.05514099721040111, 0.06656749988906085, 0.03324140670883935, 0.07113560437574051, 0.07652073181816377, 0.022764314999221824, 0.046527475424227305, 0.07085811535944231, 7.658528471365571, 41.187536492943764, 55.62714546918869, 33.20647895336151, 66.0082796216011, 74.62257698178291, 82.04898208379745, 71.37074187397957, 73.09773400425911, 69.12489518523216, 70.77475905418396, 74.82472613453865, 70.87045311927795, 67.17069044709206, 69.57937359809875, 67.89281889796257, 69.05472055077553, 67.25500792264938, 70.12746378779411, 65.55871054530144, 64.98687162995338, 66.95787146687508, 65.64295962452888, 65.08939772844315, 63.69785159826279, 62.42577865719795, 61.93565435707569, 59.62045378983021, 56.51342511177063, 52.294849678874016, 53.67996275424957, 53.169045969843864, 52.994840517640114, 52.500027269124985, 51.665523648262024, 53.53728041052818, 52.0922027528286, 52.01491490006447, 50.79633928835392, 48.08671608567238, 51.165763065218925, 49.31071400642395, 50.57583712041378, 50.91753378510475, 49.59044359624386, 54.485226944088936, 63.025443479418755, 60.952502712607384, 64.58165377378464, 62.98013471066952, 70.12620225548744, 67.69633904099464, 48.3671410381794, 64.06552746891975, 64.44238364696503, 71.30975514650345, 65.05902215838432, 70.60995429754257, 59.35630716383457, 58.16764734685421, 66.40481114387512, 59.98340271413326, 61.38108171522617, 61.054736226797104, 59.87928070127964, 56.75313524901867, 60.601621940732, 58.07249665260315, 48.23040157556534, 47.44270384311676, 46.835473626852036, 47.966338545084, 47.18651778995991, 49.44409064948559, 45.1336969435215, 44.08466063439846, 46.04724012315273, 45.429906249046326, 44.32768799364567, 46.984228044748306, 45.98740853369236, 47.21153944730759, 44.60991404950619, 48.61456476151943, 46.46766856312752, 49.011050686240196, 47.31120049953461, 48.17456357181072, 48.911252841353416, 52.33492232859135, 50.36880902945995, 53.37208427488804, 51.94331534206867, 56.48198559880257, 56.18564710021019, 55.286216363310814, 54.52909559011459, 59.055868685245514, 62.6739851385355, 62.2539746761322, 58.871741965413094, 64.39992472529411, 63.630629405379295, 63.79413843154907, 64.48359623551369, 62.96359799802303, 67.49407589435577, 65.53769767284393, 49.167720079422, 86.61092609167099, 42.05553911626339, 13.336342927068472, 5.089375656098127, 2.429110142402351, 0.8220861840527505, 0.1793924262165092, 1.3944939407519996, 0.09348282124847174, 0.05057569804193918, 0.06702523431158625, 0.12119273786083795, 0.08450159497442655, 2.3743607802316546, 0.6167332688346505, 0.06183090932609048, 0.15963220997946337, 0.3900999517645687, 11.30159106105566, 17.392886504530907, 17.989291101694107, 23.970742039382458, 21.3407264649868, 26.18323791772127, 1.6944112535566092, 0.1053854005294852, 4.221031051129103, 39.92245897650719, 54.53729175031185, 76.31339505314827, 42.05785319209099, 60.63123755156994, 44.43676494061947, 50.24243541061878, 34.4718262553215, 86.35936439037323, 80.60866937041283, 67.09730118513107, 20.057786107063293, 31.312010809779167, 25.716795846819878, 8.677449021488428, 20.427521467208862, 31.793439276516438, 68.23109954595566, 71.71298190951347, 71.48732721805573, 50.043193101882935, 47.24332474172115, 61.123056560754776, 44.412545040249825, 26.702651046216488, 40.68318195641041, 5.195367643609643, 0.17020466766553, 0.1503831648733467, 0.157421663752757, 0.08285341114969924, 0.03397694184968714, 0.008079073413682636, 0.035725994675885886, 0.037537198659265414, 0.04818600107682869, 0.043570232155616395, 0.02369806850765599, 0.12484862410929054, 0.042854694183915854, 8.284892085939646, 45.146882236003876, 62.559254094958305, 43.36165443062782, 66.49954006075859, 78.73199567198753, 84.43059548735619, 74.65138703584671, 76.27643063664436, 74.66017976403236, 73.28292086720467, 77.20836102962494, 76.03680029511452, 71.62586018443108, 70.58308973908424, 69.88257452845573, 72.91297271847725, 70.39746209979057, 73.43287602066994, 67.38084197044373, 69.6654237806797, 69.16925400495529, 67.82541811466217, 68.16794693470001, 68.18069905042648, 65.40368646383286, 65.06387069821358, 61.3267408311367, 58.83052557706833, 55.072728618979454, 56.45358592271805, 55.62244512140751, 55.991458520293236, 53.5266599804163, 54.87420067191124, 54.79835294187069, 55.940366461873055, 53.1611879914999, 53.56673263013363, 53.118333891034126, 57.2273726016283, 53.019451797008514, 54.76861193776131, 53.40693600475788, 53.61431747674942, 57.43609540164471, 64.05130103230476, 66.41562536358833, 67.65243619680405, 66.09616130590439, 69.17078152298927, 67.1080394089222, 52.23688378930092, 64.23944413661957, 64.61962133646011, 72.9000686109066, 68.70142310857773, 72.65887275338173, 61.088995188474655, 60.08517645299435, 66.3066928088665, 63.3319616317749, 62.806252241134644, 63.83922681212425, 62.28843502700329, 59.63164798915386, 63.29427905380726, 59.62910212576389, 50.59941865503788, 52.11137272417545, 50.37229724228382, 51.01093277335167, 52.86760054528713, 52.631390020251274, 48.80542851984501, 48.22352394461632, 47.70004503428936, 48.02975334227085, 46.770774498581886, 49.26004372537136, 47.79093615710735, 49.540335685014725, 47.48751483857632, 52.32308216392994, 50.27004852890968, 52.92036071419716, 50.51760524511337, 50.41381761431694, 52.58885130286217, 58.8302405923605, 53.91347162425518, 55.91179959475994, 55.90757802128792, 60.50670303404331, 58.60976122319698, 59.79183219373226, 58.448060899972916, 63.1445936858654, 64.57238227128983, 64.96367007493973, 61.06599122285843, 65.23384317755699, 65.24942234158516, 64.57395538687706, 66.16423845291138, 65.02423122525215, 68.41408252716064, 64.61122378706932, 54.199733063578606, 84.55315411090851, 51.69552683830261, 38.07738818228245, 3.919385187327862, 1.7082353867590427, 0.5903441004920751, 0.7346154120750725, 1.521457121707499, 0.08305436247610487, 0.03820297191850841, 0.04632839059922844, 0.06631462791119702, 0.06306225477601402, 1.475229396019131, 0.8514159789774567, 0.0729880495055113, 0.17942444246727973, 0.4816071758978069, 15.886737573891878, 21.124113388359547, 20.658229887485504, 27.7976705878973, 28.347007110714912, 38.33262428641319, 3.277699607424438, 0.6110693758819252, 7.659383900463581, 52.800526544451714, 65.92026874423027, 83.05914267897606, 52.666823118925095, 58.856538981199265, 38.518305122852325, 54.39889557659626, 34.452610686421394, 108.8734070956707, 107.10012584924698, 87.86518558859825, 29.08680271357298, 43.3317082375288, 53.56571428477764, 26.207742802798748, 43.71436670422554, 51.7297326028347, 79.47405025362968, 91.56722813844681, 90.47799378633499, 59.33144889771938, 57.7634022384882, 77.15287640690804, 66.67350992560387, 32.34410382807255, 51.56216539442539, 8.973652627319098, 0.5209576268680394, 0.6233730562962592, 0.4483286803588271, 0.24746120179770514, 0.23170386295532808, 0.16359934554202482, 0.25953533593565226, 0.14740960177732632, 0.29637213272508234, 0.2893766190391034, 0.1014348519674968, 0.29397832055110484, 0.17601127561647445, 10.99429965019226, 47.00844794511795, 64.94475468993187, 53.46279680728912, 69.71397757530212, 83.21243405342102, 84.98585969209671, 76.79401606321335, 78.75907301902771, 76.8144665658474, 73.98959174752235, 82.67272621393204, 80.0908787548542, 77.4462890625, 75.53600996732712, 76.53394281864166, 75.11658847332001, 76.03097900748253, 76.50729104876518, 72.71632567048073, 72.74695202708244, 74.802907705307, 70.72511851787567, 72.62611091136932, 70.15701100230217, 70.0591890513897, 66.22566595673561, 66.71875789761543, 63.85280728340149, 60.09734719991684, 61.227509155869484, 60.82633048295975, 59.776948392391205, 58.3281659334898, 56.439142897725105, 58.45167450606823, 60.77126003801823, 56.94906793534756, 55.80505192279816, 56.15557171404362, 59.67134825885296, 56.42240859568119, 59.30987365543842, 58.148674964904785, 58.32781255245209, 62.85134442150593, 67.57471516728401, 68.38722556829453, 70.26843622326851, 70.44980809092522, 75.4388415813446, 69.4326938688755, 56.438310742378235, 65.16965702176094, 69.71443355083466, 77.24707335233688, 70.2838633954525, 78.31423848867416, 62.48114928603172, 60.81996962428093, 73.11673298478127, 65.68423300981522, 66.1365607380867, 68.25144365429878, 65.67772015929222, 62.547417730093, 67.51333326101303, 64.22255024313927, 54.086309149861336, 55.53405046463013, 52.02706664800644, 54.63677041232586, 53.44787880778313, 56.34048879146576, 52.091085612773895, 49.39896807074547, 50.37477470934391, 50.12332320213318, 49.02287185192108, 52.558175548911095, 50.433785542845726, 51.670885160565376, 48.95379535853863, 55.02935774624348, 52.89639540016651, 59.08987686038017, 54.256707206368446, 55.507653281092644, 56.8583820015192, 60.97435534000397, 55.76506286859512, 57.60414518415928, 59.818529561161995, 63.818236738443375, 62.644586116075516, 59.50534276664257, 58.34211878478527, 63.68760734796524, 67.3497748374939, 67.19500914216042, 63.12903732061386, 66.7766135931015, 68.59595596790314, 65.69560199975967, 68.35589244961739, 66.71090751886368, 71.4487136900425, 66.78404599428177, 62.94918917119503, 79.0283265709877, 58.44893105328083, 52.3404586315155, 8.455185648053885, 5.15887962654233, 1.0221151099540293, 2.5060636131092906, 3.2377371517941356, 0.19523943134117872, 0.17917309189215302, 0.12860167975304648, 0.339905476430431, 0.27952042291872203, 5.227979868650436, 1.5203860541805625, 0.4962466919096187, 0.3890146053163335, 0.735146967926994, 22.92736742645502, 28.269483670592308, 34.7057531028986, 51.32980026304722, 38.4233558177948, 61.84200078248978, 6.243145270273089, 0.8671532501466572, 9.334387220442295, 60.26995673775673, 75.3156977891922, 91.8115322291851, 57.70412541925907, 83.30946564674377, 72.14062616229057, 81.13915890455246, 48.91401529312134], [43.2931213080883, 57.41220608353615, 65.55335283279419, 13.608043547719717, 9.02779022231698, 3.1303100287914276, 0.6098482164088637, 4.983810670673847, 24.777982123196125, 51.882142424583435, 52.34844200313091, 51.58488057553768, 50.33200800418854, 46.75684444606304, 47.10752382874489, 15.873780269175768, 25.401971340179443, 30.50297912210226, 0.9643324417993426, 0.029601970163639635, 0.13591014227131382, 0.24886301485821605, 0.05031951979617588, 0.08983944760984741, 0.012809139570890693, 0.0957883326918818, 0.026381522366136778, 0.03558403295755852, 0.06107614884967916, 0.04523728879576083, 0.12304006959311664, 0.1868345495313406, 3.6302354279905558, 44.732639864087105, 56.07013709843159, 46.980504244565964, 50.57789660990238, 82.9530219733715, 73.73856961727142, 70.60825198888779, 70.42450904846191, 74.78396952152252, 73.08630421757698, 72.77253985404968, 69.86030012369156, 72.11429357528687, 66.2481227517128, 66.7528572678566, 67.31059893965721, 68.40693891048431, 69.85188737511635, 66.78461596369743, 69.11367818713188, 68.95732417702675, 66.52186766266823, 68.40154320001602, 64.40484166145325, 63.80739212036133, 62.50867500901222, 56.59265086054802, 54.23316366970539, 53.90767313539982, 53.193949833512306, 50.166203901171684, 50.75837552547455, 51.199205070734024, 52.71597348153591, 50.93487985432148, 51.25288479030132, 49.644199311733246, 51.501121670007706, 51.168411523103714, 53.70385967195034, 50.210889503359795, 51.8146238476038, 51.089751943945885, 52.60933220386505, 50.16941472887993, 58.776002302765846, 63.17875765264034, 65.8621546626091, 60.82180492579937, 70.24614661931992, 57.60387159883976, 54.69352416694164, 66.87006577849388, 62.496329471468925, 69.98703092336655, 64.60431575775146, 69.17027994990349, 63.9883916079998, 59.1390348225832, 59.45793651044369, 66.8095350265503, 58.29785875976086, 62.6679852604866, 56.85468100011349, 60.320117846131325, 60.075338780879974, 52.15452320873737, 48.389134258031845, 48.5007418692112, 48.10603804886341, 48.14319625496864, 50.033306032419205, 47.41173930466175, 45.51269240677357, 47.51263529062271, 46.20748892426491, 46.654348745942116, 43.7348248064518, 47.30352111160755, 46.17078669369221, 48.14913913607597, 46.02856792509556, 47.41758719086647, 45.60988739132881, 47.99561597406864, 48.389005064964294, 47.154607102274895, 51.1806620657444, 55.10251522064209, 53.946643844246864, 53.12819056212902, 54.9508273601532, 54.92858715355396, 55.78787304461002, 57.07628130912781, 54.14397865533829, 61.088436618447304, 56.190822422504425, 62.92670577764511, 65.0278714299202, 66.74275740981102, 58.46449501812458, 63.10523919761181, 64.11597356200218, 65.19064709544182, 63.180509358644485, 66.14571824669838, 54.816424772143364, 59.925744608044624, 44.72406752407551, 28.783518187701702, 8.471089694648981, 3.9722838113084435, 3.204971984960139, 3.9173800824210048, 1.2385482899844646, 0.48005338583607227, 0.11616899180808105, 0.04541407950455323, 0.010944186469714623, 0.20067735516931862, 1.0309469047933817, 0.7281208480708301, 0.13037637749221176, 0.06339704501442611, 0.03148817930195946, 12.096492256969213, 29.79434944689274, 20.634030885994434, 18.7444169819355, 24.444365724921227, 16.56895011663437, 1.925440519116819, 0.4600029601715505, 11.50353217497468, 47.05589219927788, 67.99281433224678, 58.592681139707565, 41.962615102529526, 11.385834440588951, 4.265994988381863, 13.360127750784159, 34.5724980533123, 53.33018012344837, 59.779957830905914, 67.34624102711678, 18.238878808915615, 10.50695775076747, 4.396864715963602, 1.603384881746024, 4.665460428223014, 46.03585593402386, 69.56570953130722, 76.98385387659073, 60.42210057377815, 64.49330851435661, 60.81846110522747, 54.35195289552212, 22.542413882911205, 30.777713879942894, 36.011047661304474, 0.8601629908662289, 0.08212548302253708, 0.30827784386929125, 0.34184227406512946, 0.06000494031468406, 0.06645875299000181, 0.05356057146855164, 0.02069693091470981, 0.01260059329069918, 0.028421161259757355, 0.04494361724937335, 0.03437709303398151, 0.07742060071905144, 0.1734419900458306, 4.927130537107587, 48.72483864426613, 64.73711103200912, 56.70271575450897, 55.10053552687168, 85.61000660061836, 76.77785933017731, 73.82021963596344, 71.57625004649162, 78.2973749935627, 78.23128893971443, 75.81084921956062, 73.92361968755722, 75.26172548532486, 69.88827422261238, 70.40560126304626, 71.11588954925537, 71.9853512942791, 73.14133286476135, 70.61226457357407, 71.31095588207245, 71.8417190015316, 67.97249302268028, 70.63625648617744, 68.65645632147789, 65.79413831233978, 62.9483912140131, 60.718401074409485, 55.64092352986336, 57.001075744628906, 54.287284165620804, 54.56848427653313, 53.54089021682739, 56.54167279601097, 54.555336982011795, 56.30402594804764, 52.852021381258965, 52.54054829478264, 54.28916126489639, 52.99142450094223, 56.62943668663502, 55.5481781065464, 53.23869243264198, 53.17921802401543, 55.99623866379261, 52.2137126326561, 58.50435487926006, 62.63527661561966, 65.02198174595833, 65.6307090818882, 69.6995535492897, 56.120393201708794, 62.2278206795454, 67.35070958733559, 65.54005354642868, 72.40994051098824, 67.05691695213318, 71.10821396112442, 67.62002393603325, 62.04944305121899, 63.35233613848686, 69.58710238337517, 59.36269462108612, 66.44691288471222, 60.21448351442814, 62.78496578335762, 61.606652811169624, 56.95241555571556, 53.768615797162056, 52.03011408448219, 50.50483413040638, 51.29109553992748, 52.108450680971146, 50.628475695848465, 48.481180518865585, 51.12747251987457, 47.84151144325733, 49.792224168777466, 48.02082762122154, 50.1283161342144, 47.96014867722988, 51.15038149058819, 48.99277746677399, 51.50026671588421, 48.37599836289883, 49.590371400117874, 52.27772019803524, 52.82233737409115, 54.34585802257061, 58.144928365945816, 54.859465062618256, 56.91648468375206, 57.749928161501884, 58.34961578249931, 58.034418895840645, 61.9585595279932, 55.92704817652702, 63.03312286734581, 57.6139410585165, 63.6052505671978, 66.32141321897507, 70.46154946088791, 57.366566732525826, 63.11787351965904, 65.09640455245972, 66.70909881591797, 66.46383717656136, 65.00125005841255, 60.15060514211655, 62.93951489031315, 51.9207863509655, 48.00576142966747, 13.835954368114471, 9.3782321177423, 5.0382080767303705, 3.2010577199980617, 3.60427332110703, 0.7542301970534027, 0.15261695516528562, 0.017044330525095575, 0.04596840444719419, 0.14196044183336198, 0.8808213542215526, 1.048926233779639, 0.06649319606367499, 0.0649843504652381, 0.1653793125296943, 14.627890773117542, 35.42119391262531, 23.055494651198387, 26.81324791163206, 33.763320073485374, 27.33131591230631, 2.239312226884067, 0.7115786138456315, 17.524821124970913, 59.39984902739525, 75.16774892807007, 71.9137555360794, 38.53125102818012, 1.8088494753465056, 2.5806460110470653, 1.2762357364408672, 33.942906036973, 76.90861031413078, 78.89596447348595, 97.98673287034035, 22.162821851670742, 12.664474379271269, 5.8759823720902205, 4.41248282790184, 11.825918275862932, 78.38258922100067, 83.39633658528328, 88.36817979812622, 73.78041297197342, 71.64717704057693, 70.39895161986351, 66.27953946590424, 32.169818580150604, 41.051499992609024, 46.05117671191692, 1.406742346007377, 0.15145568700972944, 1.0175191378220916, 0.47171660349704325, 0.10398591781267896, 0.2633121551480144, 0.12828988867113367, 0.18256329669384286, 0.1314939628355205, 0.1273661819868721, 0.15328647627029568, 0.20767065725522116, 0.27445508691016585, 0.19485067954519764, 6.23877028003335, 51.96205973625183, 66.74658760428429, 62.417335510253906, 63.00956033170223, 86.42660558223724, 78.7804202735424, 74.3165186047554, 73.61640617251396, 80.56721359491348, 81.57042816281319, 78.78030627965927, 78.94691973924637, 78.59033167362213, 75.7697582244873, 75.96743881702423, 75.14056518673897, 73.92344489693642, 77.27620258927345, 75.96742361783981, 76.28458499908447, 75.71397721767426, 71.88752174377441, 75.13194724917412, 71.72134906053543, 71.34434849023819, 67.44595527648926, 64.91221323609352, 58.34632135927677, 60.85392080247402, 59.75223831832409, 57.66648083925247, 56.13716930150986, 58.81963536143303, 60.3248143941164, 58.21951076388359, 54.613998234272, 56.40722841024399, 56.69803440570831, 58.49740885198116, 60.72984226047993, 61.71456702053547, 57.14206337928772, 58.07306282222271, 61.26041159033775, 55.56926317512989, 63.54217015206814, 66.8983742594719, 69.55416575074196, 65.97133800387383, 72.8180842101574, 69.406368881464, 61.13637864589691, 70.53426995873451, 67.85103633999825, 75.15497401356697, 66.79431304335594, 73.39818388223648, 69.6995535492897, 66.35150760412216, 63.89357149600983, 65.93742862343788, 63.916233479976654, 68.33869457244873, 61.263979598879814, 65.03503784537315, 65.26477351784706, 59.87006239593029, 56.54246315360069, 54.391242787241936, 54.753766134381294, 55.26589125394821, 56.898918226361275, 55.37406764924526, 50.674240440130234, 54.908573627471924, 50.729003101587296, 52.55087614059448, 49.92441147565842, 53.8041552901268, 51.90069682896137, 53.982411324977875, 52.05124855041504, 56.032507717609406, 51.23636707663536, 53.275577053427696, 54.82448413968086, 55.42867451906204, 58.55437159538269, 62.05057919025421, 57.887465581297874, 61.08536258339882, 62.097643464803696, 59.85149659216404, 60.71989059448242, 63.942414075136185, 60.05991920828819, 66.4468140900135, 61.3791324198246, 66.8729916214943, 70.2366091310978, 74.15422931313515, 63.1308726221323, 64.75336655974388, 71.0402812063694, 67.74957418441772, 68.85905385017395, 69.31609332561493, 62.35385611653328, 64.79135692119598, 61.57141350209713, 57.94105030596256, 28.06975308805704, 16.687874235212803, 9.640094116330147, 5.342963598668575, 6.085193445906043, 1.1242225184105337, 0.3149822575505823, 0.11815375444712117, 0.10561916962615214, 0.575388993602246, 3.2542615151032805, 2.4994911532849073, 0.30930729175452143, 0.28010668989736587, 0.41449511772952974, 20.74054677039385, 46.91119596362114, 42.47971795499325, 40.151620879769325, 49.819955080747604, 51.29607327282429, 4.136171629652381, 0.8120814396534115, 20.28626024723053, 69.93441134691238, 87.7760499715805, 83.67121383547783, 62.52844914793968, 14.558140765875578, 5.227059843018651, 26.06160644441843, 88.8518026471138], [49.360008761286736, 35.280175879597664, 54.02801267802715, 18.471832908689976, 0.46925243572331965, 0.28495677339378744, 0.23022942332318053, 4.428393999114633, 35.68379022181034, 59.225487783551216, 52.028039395809174, 61.767403185367584, 65.58922290802002, 52.295647636055946, 44.66821052134037, 16.577408462762833, 33.82239170372486, 17.73663315922022, 0.25899235100951046, 0.03207441659469623, 0.16565604455536231, 0.24234679498476908, 0.13437232322758064, 0.04426374318427406, 0.0217121907917317, 0.04908374001388438, 0.026323991078243125, 0.029952466102258768, 0.0307238673849497, 0.05731536373787094, 0.05066972444183193, 0.12406007735989988, 3.121401881799102, 42.89065830409527, 55.27400381863117, 58.93733784556389, 35.85278995335102, 79.5198529958725, 75.21667510271072, 70.29081702232361, 66.17962762713432, 78.20361882448196, 77.64267772436142, 71.91225081682205, 68.41153666377068, 70.54358705878258, 67.98134654760361, 66.9403088092804, 68.87954235076904, 69.27200809121132, 67.95931532979012, 65.18871679902077, 69.15960252285004, 66.61139085888863, 66.97717443108559, 69.03056144714355, 62.108807265758514, 61.48362301290035, 60.62866508960724, 55.36802217364311, 53.41229371726513, 50.565414279699326, 49.30705100297928, 50.91971106827259, 49.57619056105614, 51.546339243650436, 51.16077773272991, 52.628783360123634, 52.180061638355255, 47.69464932382107, 52.31984853744507, 49.708358868956566, 50.62481269240379, 52.93289624154568, 50.64916558563709, 51.235367730259895, 53.08467909693718, 49.138613641262054, 55.292478427290916, 54.94532145559788, 58.42468835413456, 70.48815563321114, 61.92328222095966, 44.085994362831116, 65.5226656794548, 67.75322958827019, 66.7865614593029, 63.93069550395012, 68.05689409375191, 64.06295880675316, 68.41679558157921, 56.750866770744324, 68.42077016830444, 73.0659145116806, 55.776143074035645, 62.3123699426651, 63.994722068309784, 60.937531515955925, 54.310428723692894, 51.74322187900543, 48.066740557551384, 48.089182153344154, 48.31667594611645, 48.5074333101511, 47.945633456110954, 46.9953728467226, 45.99218487739563, 45.82442007958889, 48.6347758769989, 46.54887780547142, 45.3740568459034, 47.832407131791115, 45.81826440989971, 46.006852090358734, 46.082099452614784, 47.96152800321579, 45.42382277548313, 46.30115769803524, 48.09601418673992, 49.559870436787605, 52.72602394223213, 54.92020100355148, 57.96470783650875, 56.47393003106117, 56.94002442061901, 58.42716582119465, 60.53037956357002, 56.44976332783699, 55.62350906431675, 58.327329978346825, 55.205824077129364, 61.86687424778938, 64.40519124269485, 64.16488453745842, 60.14758050441742, 60.07486380636692, 61.748434603214264, 66.14189565181732, 61.49754926562309, 56.98102042078972, 48.82053270936012, 45.133468955755234, 44.138207361102104, 34.06654380261898, 6.605263939127326, 12.139283660799265, 11.100751888006926, 3.571580587886274, 0.2864419296383858, 0.7525762170553207, 0.1395425692317076, 0.007550263972007087, 0.08045271184528247, 0.12683845561696216, 0.6308055168483406, 0.7418084261007607, 0.06484858196927235, 0.290968703920953, 0.04459608804609161, 9.77234411984682, 27.619517147541046, 22.30301722884178, 16.48408357053995, 19.841530211269855, 1.3116373680531979, 1.322730160318315, 0.29239092604257166, 18.1393925473094, 59.00685511529446, 61.28190703690052, 76.48369431495667, 14.557020775973797, 0.8543349348474294, 0.21515756176086143, 1.1923823109827936, 1.788157804403454, 56.40031658113003, 45.42126551270485, 66.54595077037811, 23.68766102939844, 0.6235091364942491, 0.4166924685705453, 0.40939864120446146, 10.320010632276535, 61.34828947484493, 78.82634460926056, 71.78886383771896, 67.77762427926064, 79.43445637822151, 59.8104701936245, 51.39022462069988, 23.73167596757412, 39.34287987649441, 19.331213794648647, 0.0970663852058351, 0.047571825634804554, 0.18707812239881605, 0.28248625283595175, 0.05526065368030686, 0.21549137978581712, 0.03232175586163066, 0.05713770471629687, 0.06887824347359128, 0.03471225434623193, 0.021322097563825082, 0.05622724536806345, 0.10112312025739811, 0.19840874330839142, 4.022723017260432, 48.50979298353195, 66.33081391453743, 66.40952289104462, 45.593229085206985, 78.22840869426727, 78.65232154726982, 71.77884757518768, 70.41295766830444, 80.67538619041443, 77.800612449646, 77.24205002188683, 72.17870771884918, 73.57443362474442, 70.17764389514923, 69.8856371641159, 72.47022807598114, 73.2560183107853, 71.50861367583275, 69.71049696207047, 70.4884672164917, 71.85135528445244, 69.85469162464142, 69.12341326475143, 66.18196070194244, 64.03419435024261, 61.318647265434265, 58.326129242777824, 56.281196773052216, 54.312195628881454, 53.878471702337265, 54.917286559939384, 53.06493155658245, 53.14273238182068, 51.29287004470825, 53.68773713707924, 54.314939081668854, 53.12488093972206, 55.41177682578564, 52.40987330675125, 52.78664968907833, 56.19758225977421, 55.85821866989136, 54.74787265062332, 56.101189032197, 53.263269513845444, 55.53709030151367, 56.08771875500679, 59.45428490638733, 73.1027801334858, 62.3703396320343, 48.02954435348511, 67.0216928422451, 68.27374085783958, 68.48962247371674, 66.20705455541611, 68.79792273044586, 66.16200417280197, 71.8122173845768, 58.41705456376076, 59.06221814453602, 69.21278446912766, 60.198417976498604, 64.50783133506775, 64.41356599330902, 62.03199438750744, 54.39785063266754, 53.791809752583504, 52.40206852555275, 50.6062126904726, 49.90686781704426, 50.68928383290768, 51.13223746418953, 49.5973364263773, 49.94122177362442, 50.5247488617897, 50.672370940446854, 47.20036804676056, 46.451280042529106, 49.779232665896416, 49.6771739423275, 47.80430383980274, 49.62760180234909, 50.481127202510834, 48.482852429151535, 48.61720561981201, 50.57402841746807, 53.3521581441164, 56.53859496116638, 58.18766087293625, 59.55633223056793, 59.73481625318527, 58.99930492043495, 61.45524613559246, 64.13580849766731, 62.99886770546436, 59.421105086803436, 61.95060275495052, 60.500976741313934, 63.13041664659977, 66.66853979229927, 65.52354723215103, 63.550297915935516, 62.181140184402466, 62.34577775001526, 66.21102914214134, 63.896664530038834, 57.54556752741337, 54.465992376208305, 50.43141447007656, 49.747846350073814, 44.60367098450661, 25.03051847219467, 15.12708518654108, 13.53702250868082, 5.94756530597806, 1.2098846468143165, 0.6782196694985032, 0.20943178853485733, 0.09964678072719835, 0.098979270842392, 0.07204691719380207, 0.052028734135092236, 0.5989570508245379, 0.15035637334221974, 0.23431692039594054, 0.20501314516877756, 14.120333958417177, 30.08642267435789, 27.617773041129112, 29.558007828891277, 30.781498476862907, 13.435516655445099, 2.0150819839909673, 0.4747445066459477, 24.76496212184429, 69.46084275841713, 71.8183122575283, 92.26997002959251, 17.704659774899483, 1.4876989019103348, 0.09582374055753462, 1.1391829093918204, 2.8960844222456217, 122.05975592136383, 64.1833059489727, 82.9812240600586, 29.29406639188528, 1.0456675523892045, 0.3649655473418534, 0.9846826060675085, 6.841710526496172, 84.24977838993073, 80.99302634596825, 90.93301936984062, 82.08557412028313, 88.03963422775269, 72.62174874544144, 70.78365057706833, 33.00165854394436, 48.217064291238785, 29.163967072963715, 0.40792939660605043, 0.2178371007903479, 0.7252417900599539, 0.8838652283884585, 0.5198878655210137, 0.2776970254490152, 0.20310551393777132, 0.15592035837471485, 0.26433634862769395, 0.12068862662999891, 0.14731154922628775, 0.25163766753394157, 0.26114045293070376, 0.35831085755489767, 4.313021739944816, 49.854187443852425, 70.62633901834488, 69.70630958676338, 56.974841952323914, 79.64793652296066, 84.21822488307953, 72.1760630607605, 71.71956315636635, 82.62847378849983, 84.08394768834114, 77.65617460012436, 75.05862638354301, 80.58979198336601, 74.7096835076809, 72.72112861275673, 77.81351655721664, 77.92901515960693, 75.02351626753807, 72.73949682712555, 76.0073670744896, 77.30672255158424, 73.18032637238503, 75.0926573574543, 70.37965625524521, 66.80065110325813, 65.85964679718018, 62.48458810150623, 59.33826953172684, 58.47658596932888, 57.37731255590916, 58.101048320531845, 57.260028049349785, 57.20592275261879, 56.523977145552635, 59.4626634567976, 57.66279123723507, 56.13255254924297, 60.543295070528984, 55.378384217619896, 57.074890583753586, 59.91317868232727, 57.957602217793465, 60.87031312286854, 63.71545985341072, 54.634201750159264, 58.89436595141888, 58.05852860212326, 60.796445086598396, 74.75071370601654, 71.02234616875648, 53.73433403670788, 64.90541160106659, 73.79296749830246, 71.9734351336956, 71.80492177605629, 73.17895084619522, 71.7098280787468, 77.49737352132797, 60.90579941868782, 65.04247784614563, 79.19634595513344, 60.277233347296715, 66.40706062316895, 68.66428390145302, 64.99068662524223, 56.724534183740616, 57.75936305522919, 54.33529458940029, 53.88789139688015, 54.58623692393303, 52.316774502396584, 52.91287511587143, 52.99625024199486, 53.326976895332336, 53.6671232432127, 54.74406145513058, 52.34479419887066, 48.766169026494026, 53.23230877518654, 53.814080357551575, 51.9534607976675, 53.29968295991421, 55.35244680941105, 51.88126087188721, 52.42783114314079, 55.42121171951294, 55.64232185482979, 57.694850116968155, 59.17791813611984, 60.80395348370075, 62.390949726104736, 62.698292434215546, 64.42670568823814, 66.91534414887428, 63.10708209872246, 60.11894904077053, 63.09066317975521, 62.38575540482998, 67.24994659423828, 68.67923989892006, 68.56502562761307, 65.53147360682487, 66.21327102184296, 64.82769057154655, 69.40572291612625, 67.31519669294357, 64.1349421441555, 54.5262685418129, 61.73194728791714, 55.80420456826687, 57.29900635778904, 40.8831462264061, 28.634579479694366, 22.69241463392973, 5.18183134496212, 0.6874461681582034, 2.0876977499574423, 0.6393165257759392, 0.09019445395097136, 0.2818235446466133, 0.38825497264042497, 2.1845555026084185, 1.722852133680135, 0.3741584118688479, 0.5200535722542554, 0.4779873654479161, 17.014067731797695, 44.6792983263731, 36.61516584455967, 36.78299143910408, 46.94127514958382, 42.4968246370554, 2.3942372761666775, 0.5807270540390164, 30.690181776881218, 85.65498098731041, 75.3668886423111, 104.89356145262718, 24.087587669491768, 1.4602773170918226, 0.4095378384226933, 2.369018979370594, 8.841704707592726], [6.204617712646723, 25.91413825750351, 63.84939506649971, 7.910765111446381, 0.2147194423014298, 0.21623358683427796, 0.1437361934222281, 20.88996235281229, 60.369450598955154, 55.43981932103634, 66.22769504785538, 59.44214455783367, 55.74598789215088, 42.57765769958496, 48.27771283686161, 35.82038529217243, 38.37724529206753, 12.456542886793613, 0.1033161740633659, 0.11382157128537074, 0.13684317033039406, 0.42676498589571565, 0.08808950791717507, 0.012984730783500709, 0.10671742202248424, 0.05766313413914759, 0.03652553634310607, 0.03977851432864554, 0.11528279326739721, 0.05593541805865243, 0.06237294801394455, 0.3469112317543477, 3.7453913362696767, 26.78508762270212, 45.4168501496315, 59.88471440970898, 34.933946058154106, 64.94659379124641, 72.5484050810337, 72.18776643276215, 74.22196447849274, 77.6044137775898, 74.43473026156425, 73.41554895043373, 64.51763480901718, 67.7499009668827, 64.29150134325027, 67.16492995619774, 69.31644290685654, 69.06949415802956, 66.47766843438148, 67.51473918557167, 69.60939958691597, 69.26228061318398, 67.02713415026665, 68.78713130950928, 62.10467308759689, 61.341586634516716, 57.574662566185, 58.54679860174656, 52.40611530840397, 50.8698995411396, 49.450888484716415, 51.24899759888649, 47.88874290883541, 50.85379220545292, 50.38812719285488, 51.01144574582577, 49.766754135489464, 51.53683975338936, 49.02955189347267, 49.43502813577652, 48.4519486874342, 49.62658725678921, 53.4408263862133, 50.05026072263718, 47.4198442697525, 52.09445983171463, 53.56381818652153, 59.39048632979393, 55.19583061337471, 70.1858514547348, 60.668543949723244, 59.18732263147831, 66.57728388905525, 62.723279893398285, 66.57017067074776, 63.070866242051125, 64.25006076693535, 64.84998017549515, 63.008534386754036, 56.416230127215385, 46.756548061966896, 52.24105976521969, 58.69716793298721, 58.51147569715977, 57.20670931041241, 57.48130537569523, 53.60677108168602, 49.1539154201746, 47.961600199341774, 47.41791397333145, 50.408307909965515, 46.32171839475632, 47.117502093315125, 45.42516030371189, 45.42155809700489, 45.879467725753784, 50.36279395222664, 47.52965837717056, 46.085203886032104, 48.36550712585449, 46.15359641611576, 47.84221440553665, 44.008740708231926, 46.90753675997257, 46.41152657568455, 47.32850857079029, 48.21761526167393, 53.3953732252121, 57.21649758517742, 59.751831740140915, 57.91193246841431, 56.87092512845993, 57.17489741742611, 59.23931524157524, 58.88401910662651, 61.91038951277733, 57.50234104692936, 60.62236502766609, 60.06479054689407, 62.54571542143822, 61.16207666695118, 61.56781889498234, 60.95360465347767, 55.30355863273144, 58.593976870179176, 62.37329587340355, 57.59690657258034, 46.24440014362335, 47.11614936590195, 32.37997770309448, 37.16201350092888, 36.10109902918339, 43.49028132855892, 19.004653617739677, 11.724989991635084, 4.449603511020541, 0.8459553751163185, 0.45499785686843097, 0.15616461401805282, 0.0886054860893637, 0.056805237400112674, 0.025667746995168272, 0.11090078231063671, 0.21602986729703844, 0.03329638500872534, 0.028591302325366996, 0.08579929213738069, 12.894909214228392, 16.834863647818565, 16.11212532967329, 13.896426223218441, 19.116337224841118, 3.6493453150615096, 1.5898604574613273, 0.4339815111598, 17.57567949593067, 57.15828850865364, 59.34881776571274, 83.40311542153358, 16.314599364995956, 3.4102951548993587, 0.1332217568415217, 1.6091705462895334, 0.8136711199767888, 3.173240600153804, 30.065347105264664, 62.236613407731056, 5.155750019475818, 0.1447008815011941, 0.19770928396610543, 1.254388689994812, 42.673283368349075, 87.25471794605255, 73.25254529714584, 75.06932660937309, 70.47575309872627, 67.34491109848022, 53.63468438386917, 63.80056768655777, 37.03026317059994, 42.57133103907108, 14.482662566006184, 0.3002017631661147, 0.12796681694453582, 0.18004674813710153, 0.22606613812968135, 0.08640322223072872, 0.06366240733768791, 0.07996717657078989, 0.03726246672158595, 0.026415661159262527, 0.028897460506414063, 0.06734565657097846, 0.01512824252131395, 0.0489565210591536, 0.1807858084794134, 4.897623220458627, 31.79974313825369, 55.86381196975708, 66.73603177070618, 48.07082153856754, 66.96598023176193, 78.59058246016502, 74.44416135549545, 77.03711181879044, 79.1973415017128, 78.03628340363503, 76.97524353861809, 68.91640797257423, 71.08429804444313, 68.20353582501411, 71.77819401025772, 72.67489269375801, 73.67309153079987, 70.70246413350105, 72.09452703595161, 73.81333440542221, 73.91855835914612, 70.59545427560806, 71.44574224948883, 66.79199516773224, 66.99703216552734, 61.3077836483717, 60.31976446509361, 56.953327506780624, 56.01375192403793, 52.33709201216698, 54.743434488773346, 53.41084599494934, 54.30298872292042, 54.41456213593483, 54.07280847430229, 52.177633568644524, 54.884213134646416, 51.56549781560898, 52.71572269499302, 51.99220351874828, 51.41604423522949, 55.040563344955444, 52.72744506597519, 51.37859344482422, 54.10487875342369, 57.20530718564987, 60.736092925071716, 54.3615435808897, 69.34333026409149, 65.3869977593422, 63.692524284124374, 67.85526171326637, 65.20878732204437, 69.54826086759567, 67.31454312801361, 65.7417543232441, 66.4561539888382, 68.77649188041687, 61.67090356349945, 49.52189527451992, 60.41462257504463, 62.94983893632889, 61.648036390542984, 57.83435583114624, 60.19187472760677, 54.505308866500854, 53.091860711574554, 52.578420862555504, 51.45465396344662, 53.52718435227871, 49.48470287024975, 51.03793032467365, 49.735960587859154, 49.33306820690632, 49.080404564738274, 50.56380696594715, 51.67172871530056, 49.598544761538506, 50.296282321214676, 49.17950324714184, 50.486933290958405, 47.15628281235695, 50.73400743305683, 48.44558022916317, 47.98854075372219, 51.12600199878216, 55.49177013337612, 59.98747609555721, 62.09652252495289, 61.49974934756756, 61.47226922214031, 59.846416264772415, 61.98106192052364, 60.67535698413849, 64.8505349457264, 61.97482645511627, 63.6789970099926, 62.06369988620281, 65.92300459742546, 64.87018749117851, 65.1496396958828, 63.60627271234989, 58.456120267510414, 59.308931306004524, 62.30815216898918, 59.97883915901184, 50.64792685210705, 52.96364799141884, 42.69618093967438, 47.03711740672588, 52.25250855088234, 59.48126345872879, 32.6376760751009, 15.626993961632252, 3.9782787021249533, 1.01360107306391, 0.4298669850686565, 0.33787421823944896, 0.06919180086697452, 0.1616626963368617, 0.007842718860047171, 0.04308248528104741, 0.4213892243569717, 0.14119553990894929, 0.17546230898005888, 0.020114630715397652, 15.119725931435823, 18.01399927586317, 24.628959819674492, 25.39173848927021, 35.31695030629635, 14.667655639350414, 1.947261798195541, 0.6168737425468862, 20.378173515200615, 62.87557192146778, 65.90788140892982, 93.97421658039093, 36.81350000202656, 4.60375458933413, 0.29758221935480833, 0.9082451951690018, 0.2954283880535513, 20.209154784679413, 81.34237200021744, 108.31194922327995, 13.074576873332262, 0.5763523606583476, 0.3604103933321312, 0.4612658580299467, 48.315961584448814, 99.3618942797184, 81.52225434780121, 91.21105805039406, 81.65392488241196, 82.70244061946869, 66.78761780261993, 68.25555503368378, 47.01035924255848, 54.97224301099777, 19.49036445468664, 0.3009730624035001, 0.40356577606871724, 0.6431108596734703, 1.3465102342888713, 0.39903309429064393, 0.14012114756042138, 0.3219333611195907, 0.16557535825995728, 0.14553855842677876, 0.15394211921375245, 0.19150325213558972, 0.1233239633438643, 0.3499465266941115, 0.35573049914091825, 5.673780972138047, 36.82345926761627, 66.77484288811684, 71.81241497397423, 56.134053468704224, 70.30193522572517, 78.70104253292084, 72.80904069542885, 78.18458944559097, 80.93583181500435, 81.04490116238594, 80.11423230171204, 71.69065430760384, 72.3444776237011, 69.91276010870934, 74.16242927312851, 77.22682043910027, 75.50391688942909, 75.56708469986916, 76.6858434677124, 75.75357869267464, 75.76566204428673, 74.13795858621597, 74.49773848056793, 70.61372369527817, 68.5247553884983, 64.00574907660484, 64.21086966991425, 60.074533224105835, 58.16147267818451, 56.01051449775696, 58.38931605219841, 55.762072429060936, 57.05051489174366, 57.669364884495735, 57.7701772749424, 54.97959561645985, 59.299842193722725, 54.40775670111179, 56.96679398417473, 55.22013030946255, 54.382529854774475, 59.67780411243439, 56.81217648088932, 53.212633430957794, 57.58982755243778, 63.80334913730621, 64.82591226696968, 58.064004108309746, 75.04187688231468, 67.78071731328964, 66.19646832346916, 68.68136778473854, 65.17701342701912, 71.50910764932632, 69.22944277524948, 71.1545866727829, 70.17356291413307, 72.49654546380043, 61.25185064971447, 56.698756366968155, 63.32359068095684, 61.979709193110466, 64.7252556681633, 61.648765951395035, 61.94897264242172, 58.55015382170677, 56.95069044828415, 56.79640732705593, 53.91686104238033, 56.0717748105526, 53.30849088728428, 55.01547709107399, 54.073899015784264, 51.05513580143452, 52.428545504808426, 54.36457201838493, 52.86365635693073, 50.341002121567726, 54.78124625980854, 53.90755534172058, 53.30851748585701, 49.95056927204132, 55.21895997226238, 51.46202936768532, 53.89542259275913, 56.9225187599659, 59.20064091682434, 62.544203102588654, 63.46990562975407, 63.142245411872864, 64.11626234650612, 65.00992879271507, 63.03093418478966, 64.15419191122055, 66.68647482991219, 64.62368711829185, 67.53847271203995, 64.58425283432007, 71.83178633451462, 69.51060488820076, 67.69592866301537, 65.30827358365059, 59.744148552417755, 59.51529823243618, 66.98055624961853, 57.96619735658169, 56.93146347999573, 56.28565013408661, 50.52846886217594, 50.71997098624706, 63.59793595969677, 69.65232208371162, 46.97802297770977, 24.587980918586254, 7.7543669287115335, 0.9176730830222368, 1.526740500703454, 0.798774256836623, 0.13478926179232076, 0.21295936487149447, 0.08894205006072298, 0.24402741808444262, 0.7360228209290653, 0.29886663949582726, 0.3382873866939917, 0.20493602118222043, 20.13201132416725, 28.796407096087933, 28.454689532518387, 30.795388631522655, 47.33931519091129, 32.19890981912613, 2.6408981904387474, 0.6808383227325976, 26.800885275006294, 80.70016846060753, 75.7870776951313, 112.34427765011787, 39.33501049876213, 4.491273025050759, 0.19711862347321585, 2.1215064357966185, 0.9615045029204339], [0.2724272129125893, 2.372549227438867, 7.039634305983782, 0.047557676589349285, 0.3492558840662241, 0.336174254771322, 15.624378751963377, 60.77122204005718, 66.00898638367653, 49.68336001038551, 74.11623895168304, 43.583608120679855, 50.390068888664246, 42.17286542057991, 33.78679521381855, 40.43317437171936, 34.75762411952019, 5.454091960564256, 0.18350438447669148, 0.16267476312350482, 0.050558676884975284, 0.08480743403197266, 0.22064166201744229, 0.019579768595576752, 0.03533051902195439, 0.1320776471402496, 0.11748354314477183, 0.10034753882791847, 0.02490793620381737, 0.1439119636779651, 0.02040831710473867, 0.13471384474541992, 2.858446966856718, 9.001618176698685, 20.459373258054256, 41.755172833800316, 37.38930970430374, 50.086145997047424, 80.06934151053429, 72.55712181329727, 77.4991974234581, 79.02205690741539, 69.57044407725334, 74.23174515366554, 68.56485083699226, 71.26050978899002, 69.27858173847198, 69.28899317979813, 70.97506150603294, 69.84247148036957, 72.41120964288712, 68.61998587846756, 69.91026744246483, 70.19174113869667, 70.87690517306328, 69.62447717785835, 64.67353284358978, 60.026632994413376, 60.21854169666767, 57.69152529537678, 52.63300113379955, 49.87297743558884, 51.77291348576546, 50.459236577153206, 50.4519409686327, 48.69912162423134, 50.89627392590046, 48.63045550882816, 47.535217478871346, 50.32179035246372, 49.93200346827507, 48.643276020884514, 50.2810413390398, 48.82829189300537, 50.350801795721054, 52.72045724093914, 51.06854908168316, 51.56370051205158, 54.88941125571728, 56.759974882006645, 55.35302817821503, 56.81685023009777, 61.06109328567982, 57.75020554661751, 61.80342525243759, 66.35603696107864, 69.55498650670052, 64.72375854849815, 66.28064900636673, 61.968150213360786, 65.73689058423042, 60.75888030230999, 45.56032285094261, 58.440290316939354, 62.815599739551544, 62.06275753676891, 53.07642214000225, 53.3003631234169, 53.46238262951374, 51.78793027997017, 47.47442074120045, 47.13648587465286, 49.79993015527725, 46.59590408205986, 47.24638357758522, 46.75808697938919, 45.9715785831213, 46.597811579704285, 46.00007705390453, 48.86365659534931, 48.977863267064095, 44.95534211397171, 44.31653559207916, 45.161750838160515, 45.77293284237385, 48.01164351403713, 44.85376596450806, 46.7366561293602, 44.44701299071312, 56.11178666353226, 57.88117311894894, 61.83302566409111, 61.529494151473045, 61.52311809360981, 58.65146018564701, 58.867926970124245, 58.86451095342636, 59.81972649693489, 63.4614434838295, 60.57856097817421, 56.96902446448803, 59.6394869685173, 58.500110507011414, 61.71636052429676, 62.12496779859066, 61.553839445114136, 60.37795074284077, 63.62250164151192, 69.23172265291214, 43.31376940011978, 40.45288771390915, 35.06804086267948, 40.61247535049915, 59.698752388358116, 73.90109449625015, 42.67832189798355, 10.499399956315756, 5.275388974696398, 1.787117135245353, 0.3542185068363324, 0.07100925373379141, 0.0688963444554247, 0.03917975329386536, 0.01987990424822783, 0.03961885238823015, 0.025464775171712972, 0.05635553672618698, 0.09697928675450385, 0.1659089684835635, 9.256124719977379, 17.31461640447378, 19.67822067439556, 14.304468277841806, 18.824719972908497, 4.205487985163927, 0.22813711606431752, 0.18929990474134684, 7.947649732232094, 69.62095856666565, 45.313978269696236, 91.2318505346775, 50.444238781929016, 6.250783810392022, 3.9082589093595743, 0.27144757797941566, 0.023272895814443473, 0.0962694150803145, 0.5139911163132638, 1.8390411115251482, 0.11129478109069169, 0.5061986250802875, 1.33544712793082, 36.550770699977875, 89.15431201457977, 83.30549865961075, 59.64420631527901, 72.57726833224297, 46.417860835790634, 61.96177415549755, 54.55755606293678, 39.80423592031002, 41.86179891228676, 41.15497224032879, 5.1905428525060415, 0.13109765597619116, 0.13745784672209993, 0.10263779913657345, 0.06068662893085275, 0.0793929843348451, 0.012042335893056588, 0.08464273661957122, 0.12395752739394084, 0.043684738120646216, 0.061378600003081374, 0.03484178880171385, 0.07137429391150363, 0.03288394756964408, 0.06629543597227894, 2.362920306622982, 9.693664591759443, 28.72364480048418, 50.80649994313717, 47.120701521635056, 54.00766856968403, 83.09547632932663, 74.2384023964405, 80.584806650877, 79.59649488329887, 72.0779675245285, 74.66888889670372, 74.68193739652634, 72.95973300933838, 73.0276657640934, 72.53746926784515, 74.86376523971558, 72.36638724803925, 74.794502556324, 71.49935737252235, 73.2363809645176, 72.55765378475189, 74.2780190706253, 73.39058429002762, 68.83184731006622, 63.4612762928009, 63.10518600046635, 60.016590133309364, 57.19669684767723, 53.04451525211334, 54.297327026724815, 53.8649558275938, 54.05649594962597, 52.669893354177475, 51.87983974814415, 49.84111234545708, 53.26959237456322, 55.03021650016308, 52.74309642612934, 52.32149384915829, 53.990755677223206, 52.338349744677544, 52.52289064228535, 53.8282535970211, 55.97018726170063, 54.75305177271366, 56.95685751736164, 61.19575425982475, 56.748552694916725, 58.05651471018791, 58.70309181511402, 52.03322991728783, 60.26903338730335, 65.30232310295105, 71.34133905172348, 68.7070544064045, 69.50202494859695, 65.62758564949036, 72.0064477622509, 58.28116625547409, 47.191985696554184, 59.56541754305363, 65.71695685386658, 62.54511505365372, 55.98069749772549, 56.507915407419205, 58.265332505106926, 52.37279109656811, 50.566786006093025, 48.35180126130581, 50.67023545503616, 47.577630802989006, 49.13287974894047, 48.779605105519295, 49.46498952805996, 48.45150411128998, 47.99887239933014, 49.530475214123726, 50.37004776299, 48.30554634332657, 46.98065243661404, 48.00658218562603, 48.92394796013832, 50.24212762713432, 49.13808926939964, 50.62642000615597, 49.01003234088421, 56.71469271183014, 59.093444868922234, 62.751227393746376, 64.70032900571823, 63.8962921500206, 62.382005006074905, 62.37103879451752, 63.25702205300331, 63.83858844637871, 66.77903026342392, 62.86189265549183, 60.17300873994827, 61.824643313884735, 62.4124413728714, 65.13944864273071, 64.82571467757225, 63.943607211112976, 64.42187234759331, 69.9427480995655, 68.75364750623703, 49.52546328306198, 45.7860117405653, 47.11871422827244, 51.854916885495186, 69.85814943909645, 69.95753690600395, 51.08173817396164, 17.90869552642107, 9.187029227614403, 2.933134571649134, 0.3085640456993133, 0.04032915450807195, 0.11579435566090979, 0.13647372921695933, 0.07624133548233658, 0.03524722778820433, 0.036324685206636786, 0.07808065201970749, 0.08030996716115624, 0.09723779163323343, 11.446137204766273, 19.84094314277172, 22.037762962281704, 23.258835040032864, 33.71978580951691, 15.166874751448631, 0.4053370450856164, 0.10729108733357862, 5.841672113165259, 72.1086622774601, 54.60231006145477, 96.74442753195763, 72.98072308301926, 26.068580970168114, 4.857986597344279, 0.12549365434097126, 0.06684545645839535, 0.4650272405706346, 6.625769063830376, 15.5011523142457, 0.18541734432801604, 0.8541748090647161, 0.6744448095560074, 28.01996435970068, 100.89935258030891, 86.667869836092, 74.44260343909264, 95.86206167936325, 74.54120054841042, 76.98297992348671, 62.94351227581501, 48.43182876706123, 53.26915919780731, 50.99268615245819, 9.120594542473555, 0.4710435646120459, 0.42973797011654824, 0.31822523509617895, 0.9086586604826152, 0.23567136959172785, 0.12153288640547544, 0.1498364840517752, 0.26961364201270044, 0.19620846840552986, 0.14646262134192511, 0.16243135352851823, 0.13376232236623764, 0.1622034696629271, 0.31156799232121557, 3.1873102951794863, 26.425697207450867, 54.39703367650509, 67.23385825753212, 55.225146040320396, 61.17310367524624, 85.21982073783875, 75.54272800683975, 80.9070597589016, 82.74401038885117, 73.24446693062782, 78.72435808181763, 75.44536203145981, 76.64429649710655, 73.57789143919945, 74.243805706501, 76.36891007423401, 76.98421105742455, 78.70979726314545, 76.30226165056229, 74.05079886317253, 77.67330408096313, 75.21057263016701, 76.65467754006386, 71.88812971115112, 65.69171100854874, 65.96800938248634, 64.37939822673798, 59.55177627503872, 57.006992027163506, 56.620370373129845, 57.52040147781372, 58.02728667855263, 54.8066820949316, 55.90731963515282, 54.26517315208912, 54.5030327886343, 58.55760142207146, 54.73477855324745, 56.041589230298996, 57.3024033755064, 54.52912978827953, 56.77801251411438, 59.95127163827419, 58.701165318489075, 57.212067022919655, 60.338391065597534, 63.529931008815765, 56.002553924918175, 62.64951825141907, 64.22341659665108, 59.684328362345695, 67.114727050066, 69.62222769856453, 75.87455660104752, 71.20421960949898, 71.71649292111397, 67.57722303271294, 75.25960519909859, 65.10561525821686, 47.07144856452942, 61.110201850533485, 69.66321229934692, 63.55901464819908, 55.91942198574543, 56.5949497371912, 59.539879113435745, 56.94984309375286, 53.6943943798542, 50.76127476990223, 55.01279063522816, 51.04738041758537, 53.51406745612621, 51.898238360881805, 52.53875479102135, 52.57435888051987, 51.81031107902527, 52.9435470700264, 54.36084441840649, 53.21244344115257, 49.29320074617863, 49.02435377240181, 50.62415912747383, 53.8170175999403, 52.41124503314495, 53.63234370946884, 51.476278603076935, 60.96092686057091, 61.464475840330124, 65.0728990137577, 66.94619089365005, 66.84202328324318, 64.98048037290573, 64.82222646474838, 63.71625781059265, 65.75550198554993, 66.00104480981827, 67.38969549536705, 62.84782961010933, 65.5527600646019, 63.09503674507141, 65.69285094738007, 65.65979272127151, 68.16516548395157, 62.93641425669193, 67.86210134625435, 69.85325530171394, 57.42375746369362, 50.81256061792374, 51.70574069023132, 54.04721684753895, 71.15678295493126, 73.82259830832481, 61.336441710591316, 34.7499143332243, 16.098463162779808, 3.2481162948533893, 1.2266907887533307, 0.16587879275903106, 0.13305440254043788, 0.12882963783340529, 0.19156240130541846, 0.25069757422897965, 0.127162417920772, 0.2268869979889132, 0.636237325379625, 0.39447212184313685, 14.898824784904718, 27.672672495245934, 33.8358885794878, 34.008494317531586, 45.08754462003708, 29.96688298881054, 1.1798003548756242, 0.6115315260831267, 14.43689402192831, 92.56788164377213, 60.76646089553833, 105.03692775964737, 85.26388317346573, 27.40557912737131, 4.409015038982034, 0.3775939025217667, 0.15787179116159678], [0.05047707774792798, 0.2785456267884001, 0.47729951329529285, 0.37952734564896673, 0.4175589408259839, 15.35304481163621, 56.704125478863716, 84.15485948324203, 44.529202580451965, 77.18160286545753, 30.653819628059864, 9.919721111655235, 40.16895554959774, 45.16424350440502, 21.045835688710213, 31.02582536637783, 30.78635461628437, 1.7258968390524387, 0.11681436342769302, 0.06754703092155978, 0.18171604606322944, 0.15313660696847364, 0.04763905679283198, 0.09232868513208814, 0.08540464026737027, 0.05651155843224842, 0.05393398678279482, 0.09808738745050505, 0.04433524540218059, 0.05028458690503612, 0.03779213009693194, 0.10188891275902279, 0.3297955251764506, 0.68069250555709, 7.038413621485233, 12.210540287196636, 36.51303492486477, 36.108463034033775, 79.19677913188934, 72.9941363632679, 80.49130886793137, 78.09676095843315, 73.58676016330719, 66.29790768027306, 68.66220161318779, 64.74609375, 73.06152194738388, 69.84780639410019, 72.24760562181473, 69.91557195782661, 72.91531339287758, 65.69418847560883, 70.39167121052742, 68.72707173228264, 71.34736552834511, 67.0037654042244, 69.12611111998558, 63.084990084171295, 64.12307918071747, 57.400943487882614, 55.16856327652931, 47.23473720252514, 51.49956755340099, 49.04697775840759, 51.44793592393398, 51.24104842543602, 52.150195240974426, 48.79478149116039, 50.772966742515564, 50.904314294457436, 49.30894710123539, 48.31504963338375, 50.50992585718632, 52.03356809914112, 48.90436001121998, 47.99173258244991, 46.6329824924469, 48.02313029766083, 52.29028232395649, 58.05474400520325, 52.649260461330414, 49.47546176612377, 48.50334852933884, 43.15014638006687, 46.38925977051258, 52.91513219475746, 59.769394397735596, 67.47122392058372, 65.8348037302494, 64.41450834274292, 62.117022424936295, 44.09681238234043, 54.509477242827415, 56.997275948524475, 61.399039551615715, 60.396558344364166, 57.883111014962196, 55.38231320679188, 55.128106847405434, 47.45135597884655, 48.80613148212433, 44.447985738515854, 46.84221066534519, 47.20046304166317, 44.06363636255264, 45.65298467874527, 45.416055992245674, 47.322071716189384, 48.651757165789604, 48.04880931973457, 47.342438623309135, 44.11544658243656, 45.613937973976135, 45.937437415122986, 47.46790789067745, 45.839174687862396, 45.66241197288036, 45.14912411570549, 52.3665252327919, 56.16825923323631, 62.01028235256672, 61.945689618587494, 64.72739115357399, 58.87342907488346, 60.62730476260185, 56.40961468219757, 62.53324069082737, 61.65695071220398, 63.70059125125408, 55.813221484422684, 57.99358628690243, 58.39263327419758, 61.211610808968544, 56.69589892029762, 58.25326435267925, 59.98551160097122, 66.81802377104759, 67.03860953450203, 64.81428489089012, 39.76928159594536, 41.82029753923416, 44.288857877254486, 62.22973957657814, 73.85830119252205, 66.13088384270668, 45.94524599611759, 30.825676806271076, 12.926966194063425, 5.698395576328039, 0.2192688817740418, 0.1667004986666143, 0.033087993651861325, 0.03165399735735264, 0.10181823061429895, 0.04754900459374767, 0.12260512652574107, 0.1339778717374429, 0.16434236895292997, 0.0990101441857405, 7.8161900863051414, 16.52337346225977, 18.163107074797153, 21.11565314233303, 27.78780821710825, 10.979291405528784, 0.19451344764092937, 0.322924098582007, 0.37273719906806946, 54.95955929160118, 63.107192292809486, 57.84870386123657, 76.46560728549957, 41.23137094080448, 9.544409550726414, 0.5526276212185621, 0.23674700874835253, 0.23835758795030415, 0.11433257706812583, 0.13142065348802134, 0.32789206481538713, 1.1008804896846414, 32.03598216176033, 77.38365322351456, 99.12069082260132, 62.126765102148056, 81.3355703651905, 27.3164739087224, 14.678029082715511, 55.53006827831268, 52.54724733531475, 25.20386517047882, 39.95284214615822, 35.881991386413574, 2.016089642420411, 0.08769105625106022, 0.0841937075892929, 0.037998628977220505, 0.03326261357869953, 0.0647897445014678, 0.10781321791000664, 0.06994496201514266, 0.06504897668492049, 0.008402439216297353, 0.177347126591485, 0.20255552313756198, 0.0619881741295103, 0.04073229283676483, 0.09493654753896408, 0.5296477605588734, 2.049707625992596, 6.007496640086174, 19.17916115373373, 48.071877881884575, 45.27862496674061, 82.88382768630981, 77.88596346974373, 80.83550199866295, 82.29105949401855, 78.08513358235359, 70.6935878098011, 69.68159571290016, 68.10435354709625, 72.97461301088333, 72.66509681940079, 73.98565515875816, 71.5078005194664, 74.31595623493195, 72.21303507685661, 72.26035013794899, 73.27287420630455, 74.74376007914543, 67.25122332572937, 71.90792664885521, 67.72200286388397, 68.30331087112427, 60.57742103934288, 58.15176039934158, 50.8263348788023, 55.595876947045326, 51.79337538778782, 53.494654297828674, 54.816409572958946, 56.177735924720764, 51.93406283855438, 52.11987666785717, 52.15316668152809, 52.9658442735672, 51.8919724971056, 52.96485252678394, 52.11128152906895, 52.12676949799061, 50.820088014006615, 49.352169781923294, 48.63869346678257, 51.419528648257256, 59.84152972698212, 51.45937331020832, 49.029236510396004, 49.250658228993416, 46.31154254078865, 47.51907594501972, 52.80318260192871, 58.50475385785103, 68.19550305604935, 68.84355068206787, 70.71238160133362, 60.17233997583389, 49.503196477890015, 66.95545479655266, 63.35222214460373, 62.42105931043625, 58.48621465265751, 55.64474992454052, 53.78336280584335, 55.61601586639881, 49.19302672147751, 49.525166898965836, 47.56922945380211, 49.662138149142265, 49.797179102897644, 47.95768640935421, 48.890293166041374, 50.426220148801804, 48.82032372057438, 51.1162631213665, 50.04861541092396, 49.72567833960056, 47.62724094092846, 47.4825257062912, 46.754617765545845, 50.535684674978256, 47.94299639761448, 49.396255016326904, 48.954882100224495, 55.04940167069435, 59.486780762672424, 65.50866723060608, 62.948748394846916, 65.2407056093216, 60.13914495706558, 62.452947199344635, 58.483809381723404, 66.77364215254784, 63.77990439534187, 65.37620633840561, 56.48548521101475, 58.564889430999756, 60.966858342289925, 61.81422807276249, 60.95504857599735, 61.21112063527107, 62.22482644021511, 69.99692559242249, 70.60829758644104, 65.46543315052986, 45.67638382315636, 49.25882399082184, 53.66650767624378, 69.15927574038506, 71.39455139636993, 66.5271569788456, 55.31305432319641, 42.71619066596031, 16.833459623157978, 6.823378885164857, 0.06654876808170229, 0.21303921996150166, 0.043160388522665016, 0.04006555849628057, 0.0770338749862276, 0.06781514661270194, 0.04429633088875562, 0.07334520807489753, 0.09659742951043881, 0.05080447248474229, 8.105156030505896, 19.50060300529003, 16.242866814136505, 30.27592420578003, 33.660041615366936, 18.991206139326096, 0.298339209984988, 0.44812610372900963, 0.4576984728919342, 50.667613595724106, 68.88486966490746, 60.104031041264534, 88.75176921486855, 73.81664782762527, 21.90393414348364, 1.2538520875386894, 0.15958929900079966, 0.34235100145451725, 0.4704611864872277, 0.5955302284564823, 0.7703239365946501, 0.7855839177500457, 20.770686753094196, 93.82591813802719, 106.08264684677124, 73.08129608631134, 113.04563641548157, 76.40641406178474, 28.8472293689847, 74.7261518239975, 66.41706928610802, 43.82753223180771, 41.456987634301186, 46.800367310643196, 2.9688191693276167, 0.2712729061022401, 0.19519968191161752, 0.5165094905532897, 0.5232755618635565, 0.2603763673687354, 0.21167273313039914, 0.20211272814776748, 0.13749539939453825, 0.18515180388931185, 0.2691417548339814, 0.31468085653614253, 0.27500484022311866, 0.24243511055829003, 0.14249818719690666, 1.2227552686817944, 8.768526334315538, 25.343754664063454, 47.82582588493824, 61.98854371905327, 58.022954910993576, 81.54358640313148, 76.51783168315887, 81.87805205583572, 81.70263066887856, 82.88837984204292, 70.55573120713234, 73.82620051503181, 69.8264591395855, 75.50131022930145, 75.14718443155289, 78.01536932587624, 75.5591507256031, 79.06978994607925, 73.59724760055542, 75.00514805316925, 75.54950684309006, 79.4437962770462, 72.08710983395576, 74.13529872894287, 68.36420640349388, 72.58915409445763, 62.53591574728489, 62.38537922501564, 51.25855788588524, 57.57062718272209, 56.73036687076092, 57.93753169476986, 58.291254714131355, 59.85238954424858, 55.571307465434074, 58.573815152049065, 57.01699309051037, 54.994711205363274, 54.935859963297844, 56.940525993704796, 57.17302031815052, 55.57513765990734, 53.20468805730343, 52.71753139793873, 51.706272661685944, 56.4162453263998, 66.24672442674637, 54.33360368013382, 49.45736713707447, 49.81091916561127, 43.384476006031036, 46.60747446119785, 52.56859838962555, 62.023030668497086, 74.26889955997467, 71.90224975347519, 71.62775248289108, 64.16856274008751, 51.20740123093128, 66.30263462662697, 66.0720781981945, 66.20795890688896, 63.841081112623215, 58.535372614860535, 59.614662900567055, 63.17403070628643, 52.10917264223099, 54.531455263495445, 48.355528861284256, 52.3877888917923, 54.62568260729313, 49.22125160694122, 52.0873998105526, 53.60191494226456, 52.209544256329536, 54.66548167169094, 54.323807805776596, 54.37614619731903, 51.43417686223984, 47.67101839184761, 49.32815507054329, 55.605403035879135, 52.418092265725136, 52.077725529670715, 53.633821830153465, 60.04229575395584, 62.87796579301357, 68.8403132557869, 67.50818833708763, 68.05171117186546, 63.23533281683922, 63.55090208351612, 60.23787505924702, 67.98029780387878, 65.77775359153748, 67.10853338241577, 59.37317445874214, 59.866798371076584, 66.48826986551285, 65.72641834616661, 63.708175644278526, 61.534433886408806, 62.59548135101795, 71.52073502540588, 71.64369642734528, 69.00728389620781, 49.91535276174545, 52.09007486701012, 55.56737847626209, 68.76746356487274, 71.66397973895073, 71.02027907967567, 63.08719016611576, 51.638393104076385, 20.753988549113274, 10.966153610497713, 0.7479705673176795, 0.4375718138180673, 0.10220135693089105, 0.13370847213082016, 0.29577120090834796, 0.13840448576956987, 0.2358111011562869, 0.18476989469490945, 0.4213899961905554, 0.5022685078438371, 13.820858728140593, 27.666321136057377, 32.78955012559891, 53.74411851167679, 54.265461936593056, 23.31728920340538, 0.26348982530180365, 0.40201272815465927, 0.7485699851531535, 80.77076107263565, 79.37727704644203, 80.62148988246918, 95.31348511576653, 82.66011089086533, 22.112850733101368, 1.1717006145045161, 0.368392844684422], [0.11846272536786273, 0.055301917091128416, 0.3516429872252047, 0.1645867878687568, 9.555504005402327, 64.2939256131649, 90.14869585633278, 53.225795924663544, 79.7783151268959, 49.386573135852814, 6.800627605989575, 3.8956699473783374, 40.52555501461029, 38.44108186662197, 25.05085878074169, 44.62625317275524, 24.23511665314436, 1.1182714439928532, 0.2233126960345544, 0.12227199869812466, 0.08077130842139013, 0.05514659671462141, 0.02583289340691408, 0.037363079682108946, 0.025984874118876178, 0.15407665574457496, 0.021718844145652838, 0.052248413558118045, 0.03371538674400654, 0.20226811902830377, 0.03765068046050146, 0.11901873498572968, 0.20222915627527982, 0.5336130852811038, 2.485908307135105, 6.362037565559149, 22.863470055162907, 30.710839368402958, 67.70791321992874, 77.74480104446411, 71.78372651338577, 85.57667478919029, 73.7827156484127, 72.11681663990021, 68.70009317994118, 70.00805139541626, 70.24322837591171, 72.01540768146515, 70.89344948530197, 70.71419790387154, 69.60634455084801, 69.99776154756546, 63.70966896414757, 71.08720868825912, 69.8585294187069, 65.10927826166153, 67.27510884404182, 64.83428701758385, 60.68251200020313, 58.41695956885815, 52.02193312346935, 54.613219276070595, 53.75367879867554, 54.390874207019806, 53.336510583758354, 47.44193248450756, 49.96574565768242, 48.10348838567734, 48.20185370743275, 47.36370608210564, 46.88599191606045, 45.53236775100231, 45.06313472986221, 46.89167261123657, 47.999503165483475, 50.5483303964138, 49.71256144344807, 44.624851047992706, 45.599445551633835, 45.46663127839565, 51.52413323521614, 46.68597064912319, 52.0786564797163, 57.02850267291069, 57.97328017652035, 57.98446677625179, 57.48094439506531, 50.103974640369415, 58.000357523560524, 61.21905840933323, 57.827542796730995, 64.34067070484161, 68.49137037992477, 68.31106245517731, 56.076995730400085, 48.348248451948166, 48.319297805428505, 43.29828903079033, 39.57954257726669, 42.1659117937088, 44.035441875457764, 43.5823617875576, 45.89282400906086, 46.224850192666054, 44.032151252031326, 45.230147168040276, 47.318898886442184, 49.2262939363718, 48.651449382305145, 48.43040384352207, 46.13972716033459, 42.79621057212353, 43.47678065299988, 42.72533297538757, 44.34202082455158, 42.1780901402235, 41.82880908250809, 46.01949401199818, 51.49098761379719, 60.35300128161907, 62.4024099111557, 62.025097757577896, 61.85533046722412, 54.96751606464386, 62.56453961133957, 57.12457671761513, 61.96236692368984, 60.520477294921875, 62.012645825743675, 51.95890590548515, 54.132039695978165, 57.040460631251335, 54.077657014131546, 55.80451615154743, 60.84464929997921, 62.648461908102036, 66.6157454252243, 64.58366006612778, 59.2345654964447, 33.424857035279274, 47.81021252274513, 57.48938374221325, 65.65679088234901, 60.96940420567989, 58.25308196246624, 55.579556822776794, 34.30249594151974, 18.310191482305527, 2.4105448136106133, 0.021036296493548434, 0.07318442920222878, 0.06411931055481546, 0.07549909132649191, 0.06071393254387658, 0.02781629234959837, 0.03966892138123512, 0.028756506253557745, 0.054520372505066916, 0.09172338948701508, 3.758720071054995, 19.378099478781223, 19.312944374978542, 22.750790901482105, 25.666442848742008, 9.678449258208275, 0.21149549342226237, 0.19041996885789558, 0.31426647095941007, 13.741302397102118, 73.26475784182549, 44.62531462311745, 58.33218611776829, 74.60297763347626, 42.20006436109543, 4.908153405413032, 0.03898960763763171, 0.15752632141811773, 0.14992745651397854, 0.30647311883512884, 0.35085304523818195, 22.730938866734505, 89.80473831295967, 106.17232963442802, 75.35161346197128, 80.79393982887268, 61.38268902897835, 8.709283713251352, 8.514288626611233, 59.393286779522896, 46.47561393678188, 35.2481359988451, 47.7280343323946, 27.212462089955807, 1.0263239778578281, 0.07333931542234495, 0.10175733739743009, 0.06491622872999869, 0.05586803104961291, 0.04668632842367515, 0.07328254112508148, 0.05551437170652207, 0.02678134143934585, 0.026644142453733366, 0.05340991549019236, 0.05575173650868237, 0.16610594931989908, 0.07622622535564005, 0.0624813832109794, 0.20387192984344438, 0.2712589537259191, 0.3747225331608206, 7.2322511952370405, 28.769120760262012, 39.063412472605705, 68.95056053996086, 82.54495427012444, 74.70070838928223, 85.02739146351814, 78.08807462453842, 74.24470245838165, 73.60884457826614, 75.60381352901459, 71.52946695685387, 72.73374393582344, 74.01293009519577, 71.99187934398651, 70.75709000229836, 72.5535500049591, 66.85107439756393, 70.904111713171, 71.4149335026741, 66.39120787382126, 68.23316663503647, 67.01923817396164, 62.43419520556927, 59.27613906562328, 55.41132465004921, 57.57525533437729, 57.82345801591873, 57.760039418935776, 57.34993502497673, 52.07592062652111, 52.49225288629532, 52.07066550850868, 49.70865145325661, 51.00155867636204, 48.462709710001945, 44.31329056620598, 44.95439596474171, 46.62297002971172, 50.30970320105553, 51.80190213024616, 51.81175120174885, 51.27377226948738, 48.46102260053158, 49.04063209891319, 51.55004404485226, 46.049865782260895, 51.22901827096939, 56.433405205607414, 62.065022215247154, 62.07758814096451, 61.02338790893555, 52.52666383981705, 56.70806206762791, 61.4317823946476, 69.7706401348114, 71.09556823968887, 66.99715375900269, 64.289890229702, 55.53140580654144, 47.93810226023197, 48.991344943642616, 41.9320647418499, 39.75673846900463, 42.28875160217285, 43.37307661771774, 47.273004949092865, 49.98222157359123, 49.065167382359505, 49.4302099943161, 50.68636178970337, 51.77969232201576, 53.06836657226086, 52.16202400624752, 52.01630562543869, 49.36209864914417, 44.62110444903374, 44.41426254808903, 46.42001911997795, 48.05212654173374, 45.018160343170166, 45.04353538155556, 47.85318061709404, 54.606805220246315, 60.916685834527016, 65.43134897947311, 64.13738921284676, 64.42200914025307, 55.25747090578079, 62.75668390095234, 60.17922900617123, 61.45240008831024, 61.48115314543247, 64.87733870744705, 54.866684675216675, 55.797247141599655, 58.53134103119373, 57.74114303290844, 60.49807749688625, 65.22181302309036, 65.83244785666466, 67.02578142285347, 67.10222572088242, 62.77713440358639, 40.1667782664299, 53.71974661946297, 62.18683607876301, 67.71580159664154, 64.5354026556015, 62.7243210375309, 59.476456716656685, 38.7866885215044, 21.173503138124943, 2.688360968604684, 0.02981257868668763, 0.14500357385259122, 0.008084877008514013, 0.016010724757506978, 0.04915444442303851, 0.07446273404639214, 0.07363140990491956, 0.04912252465146594, 0.007351001959250425, 0.06759303665603511, 5.295943021774292, 27.93049056082964, 24.49538368731737, 38.955631256103516, 34.667154774069786, 9.51947433874011, 0.10731755231972784, 0.20580333948601037, 0.17526022216770798, 5.685614962130785, 72.07023873925209, 55.37416264414787, 64.73466396331787, 87.28466033935547, 70.30540063977242, 7.656307015568018, 0.09323131482233293, 0.16692900593625382, 0.41334668872877955, 0.3514290112070739, 0.3135182079859078, 12.87220923230052, 99.23894047737122, 110.11855468153954, 82.4179270863533, 88.55271309614182, 115.89276283979416, 10.822944045066833, 16.57617162913084, 77.74103164672852, 56.28683567047119, 45.523168444633484, 56.993263363838196, 37.66537249088287, 1.7417812929488719, 0.3986571222776547, 0.2600787958363071, 0.15432195039466023, 0.13379689160501584, 0.21407341759186238, 0.12519985291874036, 0.29720464430283755, 0.2735722280340269, 0.08937559046898969, 0.16243432211922482, 0.1843327103415504, 0.2814059826778248, 0.18382732261670753, 0.15566342684905976, 0.46453038754407316, 2.603181889280677, 4.714629789814353, 27.130737975239754, 50.43698497116566, 53.40730458498001, 72.7319884300232, 78.60584244132042, 75.46740084886551, 85.87444201111794, 78.1925918161869, 74.16247487068176, 74.01677548885345, 77.77027487754822, 73.97130712866783, 74.06221345067024, 76.21577069163322, 77.34393015503883, 75.89522749185562, 75.26459813117981, 67.45583474636078, 73.99780690670013, 76.0280379652977, 69.16693612933159, 71.75103306770325, 70.62752455472946, 67.38292425870895, 65.99993526935577, 57.52392388880253, 60.85697963833809, 59.97913554310799, 60.25117054581642, 60.07185436785221, 53.69328483939171, 56.08715258538723, 55.09270414710045, 54.27525021135807, 54.09011274576187, 52.570190504193306, 49.52317200601101, 51.70387119054794, 52.042695209383965, 54.82618264853954, 55.28864063322544, 55.17679363489151, 51.27182297408581, 51.12907983362675, 52.06869341433048, 54.71469283103943, 46.91362403333187, 52.94151037931442, 57.374960482120514, 60.00943511724472, 57.03055836260319, 58.0973207205534, 51.928636729717255, 61.67275786399841, 62.032495960593224, 67.51429080963135, 70.34025996923447, 68.39367762207985, 65.83002358675003, 60.902854576706886, 51.30983613431454, 50.979303270578384, 49.38915699720383, 45.0524915009737, 45.796829760074615, 48.7720663100481, 49.019847214221954, 50.92653930187225, 51.974359676241875, 50.034765154123306, 51.81743949651718, 53.396752551198006, 54.712504148483276, 53.50291885435581, 54.56376112997532, 53.092058300971985, 46.42807848751545, 46.37856334447861, 47.86526016891003, 49.7580374032259, 46.64630077779293, 46.283420249819756, 51.399070546031, 58.56345310807228, 65.33854275941849, 68.1583334505558, 66.68967425823212, 66.84269964694977, 57.226551845669746, 63.92721489071846, 61.3165307790041, 68.15148621797562, 64.5644710958004, 65.80484613776207, 54.445161893963814, 55.980412513017654, 60.26815943419933, 59.502610713243484, 60.235652178525925, 66.16598635911942, 68.38258221745491, 69.979188144207, 64.87899541854858, 65.86660042405128, 46.958321034908295, 55.08426859974861, 63.332881182432175, 66.70013889670372, 68.54854971170425, 67.50010997056961, 68.5366715490818, 52.1740997582674, 25.460053123533726, 2.3999258084222674, 0.15129036619327962, 0.2574728481704369, 0.16637386463116854, 0.22269230510573834, 0.12636030471185222, 0.15895744931185618, 0.16359103348804638, 0.24181713903089985, 0.29418653750326484, 0.22214166121557355, 7.355516105890274, 37.21904084086418, 34.11184877157211, 52.00677193701267, 49.91259030997753, 17.074463590979576, 0.529113058000803, 0.5606034526135772, 0.36986962950322777, 23.798438385128975, 95.33221051096916, 59.61079090833664, 84.733317643404, 94.62189182639122, 75.20200788974762, 6.3068213034421206, 0.16631355771096423], [0.07979166606673971, 0.31582524825353175, 0.0398482836317271, 3.7519554840400815, 60.659359842538834, 102.57880926132202, 67.98456877470016, 82.07345277070999, 91.81438967585564, 9.395255204290152, 1.1668749921955168, 7.110424982383847, 43.75473573803902, 27.844364382326603, 18.97639263421297, 44.5894331485033, 18.60725574195385, 0.3732880804454908, 0.05517177407455165, 0.15587799658533186, 0.026050548622151837, 0.02558978994784411, 0.047926839397405274, 0.07955964843858965, 0.07445751674822532, 0.07306315485038795, 0.024043666271609254, 0.05166144524991978, 0.07929675004561432, 0.040825231990311295, 0.1045610748406034, 0.00951588152020122, 0.043592837973847054, 0.009218100331054302, 0.16220174788031727, 1.5462023438885808, 5.485001876950264, 17.65127643942833, 48.08949373662472, 77.52691313624382, 71.73517271876335, 77.82502993941307, 75.37811324000359, 71.18893682956696, 69.61281940340996, 72.6496696472168, 67.96662613749504, 72.43938133120537, 71.40960618853569, 69.7167818248272, 68.33476558327675, 68.19893047213554, 64.80833441019058, 67.2101779282093, 65.10572925209999, 62.761946618556976, 64.75116267800331, 61.82511068880558, 58.77486616373062, 53.41018483042717, 48.51401075720787, 54.00869071483612, 57.00006119906902, 58.32878150045872, 53.45638655126095, 51.176714077591896, 49.351022243499756, 47.451230585575104, 47.896574288606644, 47.70151175558567, 43.758592531085014, 39.55308459699154, 36.60092420876026, 38.563925474882126, 45.78610673546791, 46.680468544363976, 46.91117696464062, 48.989878222346306, 49.77554306387901, 45.90010441839695, 48.001878038048744, 46.27924807369709, 43.919369503855705, 56.503431648015976, 71.13504812121391, 73.54750826954842, 75.70241063833237, 60.157790556550026, 50.927937626838684, 55.245471149683, 60.488688200712204, 62.32621639966965, 53.01539361476898, 51.52746945619583, 42.753314673900604, 48.287793695926666, 46.21935188770294, 36.02102592587471, 34.47503328323364, 34.662754610180855, 37.0665018260479, 42.58579686284065, 47.03427895903587, 45.309380516409874, 47.58307211101055, 47.72961504757404, 49.41603675484657, 49.70304675400257, 50.60244709253311, 49.89825747907162, 47.39319629967213, 43.84379155933857, 44.89497095346451, 46.1553443223238, 46.25529795885086, 41.060307919979095, 41.59230977296829, 44.10785838961601, 51.440081745386124, 58.64777058362961, 58.4551665186882, 66.43419876694679, 62.35009051859379, 50.8582379668951, 61.14086240530014, 58.11399802565575, 55.4943235963583, 64.40611839294434, 59.24120374023914, 56.78336642682552, 56.824742406606674, 59.71353359520435, 61.466603726148605, 61.77997671067715, 57.686129584908485, 62.78569154441357, 61.70505613088608, 65.4209603369236, 51.84912599623203, 32.22535640001297, 53.86993356049061, 58.37506681680679, 55.306138694286346, 51.76656402647495, 53.68113309144974, 31.79717067629099, 12.8201624751091, 8.159015290439129, 0.5656071903649718, 0.024624422803753987, 0.036882119748042896, 0.03939249363611452, 0.04157322779064998, 0.027914964593946934, 0.038021947257220745, 0.026203429188171867, 0.1211858878377825, 0.045229188253870234, 0.035315575878485106, 3.888255120255053, 23.268233835697174, 19.318005703389645, 24.09237541258335, 26.262039989233017, 3.7607223261147738, 0.672309739748016, 1.0309095005504787, 0.4949386417865753, 0.48076973645947874, 33.19571793079376, 66.76733449101448, 32.93179549276829, 68.12405169010162, 75.81670090556145, 20.780545324087143, 0.20994639373384416, 0.07313126174267381, 0.5161102744750679, 0.16014169435948133, 8.969796784222126, 85.70361837744713, 106.78965970873833, 83.7393669784069, 77.12004616856575, 92.28122502565384, 19.054750129580498, 0.6884138693567365, 31.45414788275957, 58.34037847816944, 35.58716520667076, 28.515222184360027, 49.98962737619877, 21.992891170084476, 0.39241646183654666, 0.021271306832204573, 0.10603293179883622, 0.07113060972187668, 0.030735135042050388, 0.03210570925148204, 0.05408304343291093, 0.05985209128994029, 0.08794394307187758, 0.018878795272030402, 0.04339035411248915, 0.028644035628531128, 0.05563184997299686, 0.015596893936162814, 0.08963572065113112, 0.06052990589523688, 0.09501838416326791, 0.1359940494876355, 3.8720112293958664, 11.67030617594719, 23.88418458402157, 52.13058449327946, 80.1472145318985, 78.86092275381088, 79.51938182115555, 76.4538811147213, 74.72734495997429, 71.24409466981888, 72.07168266177177, 71.03695258498192, 72.80371338129044, 73.51784706115723, 72.02530235052109, 69.53695267438889, 68.13317120075226, 65.6531734764576, 67.21318736672401, 64.63555008172989, 62.19629377126694, 65.17160251736641, 67.09296941757202, 62.70594522356987, 55.278498977422714, 49.703255742788315, 55.534365847706795, 58.446620777249336, 61.69669657945633, 55.537170097231865, 57.66093693673611, 51.43407806754112, 49.97214451432228, 52.401969730854034, 50.272339805960655, 48.49346145987511, 43.329200372099876, 38.37678551673889, 39.76541720330715, 46.41773164272308, 48.350459933280945, 47.55293972790241, 49.35056246817112, 52.77037136256695, 50.72470173239708, 48.16186085343361, 48.18205676972866, 43.2048824429512, 53.90230022370815, 69.51846286654472, 76.27705380320549, 76.39261320233345, 61.82964004576206, 49.26705814898014, 57.542083114385605, 55.86516469717026, 50.91996565461159, 51.37013889849186, 49.2365837842226, 42.97271870076656, 48.908661380410194, 48.12689892947674, 39.400518983602524, 38.20452556014061, 37.788368090987206, 39.475116580724716, 45.47645375132561, 48.82755093276501, 48.81329029798508, 49.60669532418251, 52.29635439813137, 53.48088003695011, 50.29402144253254, 51.576779410243034, 53.0166931450367, 49.644233509898186, 47.45888337492943, 47.973219975829124, 49.23287518322468, 50.374436527490616, 45.129422172904015, 43.32944355905056, 48.439272567629814, 56.261977404356, 60.8011644333601, 59.87913250923157, 67.29166075587273, 63.20823647081852, 50.028829872608185, 59.70223680138588, 61.12463727593422, 58.14584791660309, 65.23549988865852, 60.54718606173992, 58.42132553458214, 57.98461116850376, 61.16378277540207, 61.321614906191826, 64.25772875547409, 58.45756039023399, 64.65424507856369, 64.43476125597954, 67.01144859194756, 53.79896096885204, 42.95698754489422, 57.84986659884453, 60.73387384414673, 62.28863261640072, 54.94100108742714, 59.984983429312706, 35.13019412755966, 16.616392470896244, 12.990855015814304, 0.19534647872205824, 0.0302255671704188, 0.12707699672318995, 0.051850180825567804, 0.04370406735688448, 0.05222572981438134, 0.05930817125772592, 0.04458582785446197, 0.18721757194725797, 0.10957044549286366, 0.046955898724263534, 6.573341852054, 27.866722382605076, 22.343855537474155, 38.85415390133858, 40.48823721706867, 3.930524052120745, 0.6022366310935467, 0.8884329989086837, 0.47531708842143416, 0.4432865884155035, 21.043797098100185, 67.00238987803459, 47.27398909628391, 70.1639798283577, 92.98891425132751, 32.130106911063194, 0.17512950027594343, 0.26176353043410927, 0.5300475703552365, 0.16916621010750532, 4.68698532320559, 86.10603958368301, 118.84434565901756, 89.30451035499573, 90.16373544931412, 124.62796211242676, 43.83937619626522, 1.6636497667059302, 45.06763368844986, 73.80910903215408, 45.35555563867092, 32.15814560651779, 58.87057162821293, 31.17310356348753, 0.9616204560734332, 0.19145198457408696, 0.3025817120214924, 0.152377360209357, 0.09565029322402552, 0.1364537060726434, 0.2669305703602731, 0.10851508923224173, 0.177371246390976, 0.13149225589586422, 0.2362536289729178, 0.20166663802228868, 0.1190464393584989, 0.2429878621478565, 0.18436278216540813, 0.17510495003079996, 0.23156954906880856, 0.3165635367622599, 7.65250151976943, 29.32448945939541, 45.329705625772476, 59.55266162753105, 80.03764361143112, 76.87853872776031, 80.27311697602272, 80.62779754400253, 75.58241307735443, 72.78028383851051, 72.75236293673515, 71.12681776285172, 76.97368562221527, 76.68653503060341, 72.89685398340225, 72.32073649764061, 67.92069420218468, 65.55264607071877, 68.04052457213402, 66.41436383128166, 65.68604171276093, 67.29691967368126, 68.5522735118866, 66.1281555891037, 58.75986456871033, 53.75489853322506, 59.54153582453728, 62.98907943069935, 66.05854332447052, 60.18036134541035, 60.211177691817284, 54.84553501009941, 55.33119834959507, 55.80452375113964, 52.692027166485786, 50.26952415704727, 47.72106930613518, 41.07970207929611, 42.10911624133587, 50.3868542611599, 52.209012284874916, 54.38310742378235, 53.95317189395428, 55.62327727675438, 51.82369016110897, 51.29028618335724, 47.788656279444695, 43.35387244820595, 56.09017342329025, 70.64099863171577, 76.6272734105587, 77.6801361143589, 61.1247056722641, 50.212356224656105, 62.33109533786774, 61.12920843064785, 56.43817774951458, 57.20178097486496, 54.8312933743, 44.10577990114689, 50.18013775348663, 52.6838044077158, 43.18267643451691, 39.23617780208588, 39.1353540122509, 42.56819240748882, 47.87850245833397, 48.9603766053915, 51.32864512503147, 52.848745957016945, 55.27851037681103, 55.315698981285095, 54.70725663006306, 53.18946987390518, 54.43921521306038, 54.54416178166866, 50.334021896123886, 49.87314082682133, 50.35672947764397, 53.1815131008625, 45.142311081290245, 46.25863417983055, 51.86225049197674, 58.17983329296112, 64.46154981851578, 62.6203890144825, 70.86258754134178, 67.76222750544548, 53.380622416734695, 61.32424056529999, 62.65028961002827, 59.31732505559921, 66.40800297260284, 60.677462071180344, 58.912073001265526, 58.557050451636314, 64.49217617511749, 64.05200019478798, 67.06819474697113, 60.39968177676201, 66.13219857215881, 68.3764873445034, 70.82810059189796, 58.91023389995098, 48.62231634557247, 60.313145220279694, 62.86057412624359, 65.3473810851574, 59.442995712161064, 64.96899738907814, 40.72726719081402, 21.627225391566753, 17.06711668521166, 0.5309560184832662, 0.19097090960713103, 0.2046097136917524, 0.18996449798578396, 0.11983938704361208, 0.2729142102180049, 0.1390656948206015, 0.07751870522042736, 0.47232483804691583, 0.48229743260890245, 0.14539700117893517, 9.241091776639223, 38.907077461481094, 35.194026902318, 42.0509185642004, 59.2078111320734, 11.090992111712694, 1.4461036026477814, 1.415283337701112, 0.7192254660185426, 1.0724865132942796, 53.02284501492977, 87.0665368437767, 53.20596478879452, 87.65468448400497, 105.16173586249352, 33.23196418583393, 0.49662331701256335], [0.22719586500898004, 0.3860821423586458, 0.563284030649811, 35.03911681473255, 110.70241615176201, 78.8516816496849, 88.58413740992546, 90.78614965081215, 40.74298694729805, 0.6177276279777288, 1.466447829734534, 32.92783610522747, 38.38335156440735, 20.814625695347786, 30.072618015110493, 43.764356821775436, 15.68583570420742, 0.2567378547973931, 0.10345643255277537, 0.07449052747688256, 0.027775251583079807, 0.07803226399119012, 0.007256864237206173, 0.04292101992177777, 0.09920086871716194, 0.0481978828611318, 0.08571163707529195, 0.02806218257319415, 0.0695160822942853, 0.07138076543924399, 0.02624248285428621, 0.010503513094590744, 0.07015283757937141, 0.09514117249636911, 0.08548491096007638, 0.19954528310336173, 0.7161500654183328, 1.3343584863469005, 27.06923447549343, 65.02226293087006, 73.74136626720428, 79.60279494524002, 73.0892376601696, 71.41120210289955, 71.03073611855507, 69.38384369015694, 72.8506788611412, 71.69671878218651, 73.18574488162994, 68.49518537521362, 69.66625973582268, 64.96615514159203, 67.46724933385849, 66.49045094847679, 66.38436824083328, 60.161168575286865, 60.390512868762016, 59.4237345457077, 64.74105522036552, 52.390083968639374, 45.91544799506664, 49.3490881472826, 54.86109137535095, 56.599566489458084, 52.79235698282719, 50.583223924040794, 49.5314821600914, 48.47909063100815, 48.64337481558323, 51.197688952088356, 47.824123576283455, 43.37546668946743, 38.325989842414856, 38.53106863796711, 41.76846832036972, 44.47945185005665, 46.13294832408428, 47.086279168725014, 46.1998475342989, 47.729143872857094, 47.47371397912502, 51.56409949064255, 47.66517050564289, 48.911028653383255, 61.99219152331352, 71.72405451536179, 73.35833922028542, 67.03322142362595, 50.36771088838577, 45.487127378582954, 37.940679118037224, 35.94666011631489, 47.617547661066055, 49.71669182181358, 48.61158572137356, 50.04023306071758, 41.26119554042816, 38.42727340757847, 34.27877001464367, 34.738131165504456, 35.1773875951767, 39.67728093266487, 43.488484025001526, 45.350619703531265, 45.727369487285614, 48.00379313528538, 49.69188675284386, 45.136470794677734, 47.861547768116, 49.018072709441185, 46.00872538983822, 44.34436909854412, 44.932440742850304, 47.44140051305294, 46.64642997086048, 44.22264263033867, 40.27721934020519, 48.65670830011368, 56.97767660021782, 56.74763314425945, 56.78144372999668, 63.80812168121338, 59.85808543860912, 50.01935318112373, 57.48655669391155, 59.98405247926712, 52.45598383247852, 59.31555435061455, 59.44270692765713, 60.88422417640686, 54.65136542916298, 52.7103041857481, 48.60722355544567, 60.74152663350105, 57.71969698369503, 55.64595066010952, 50.38101017475128, 58.71720805764198, 41.40565238893032, 41.75111845135689, 49.920721873641014, 55.96212789416313, 53.54943975806236, 50.069476291537285, 45.01379817724228, 21.461312994360924, 16.80981919169426, 5.139977540820837, 0.15662050049286336, 0.0989867516909726, 0.11294255673419684, 0.144151232088916, 0.06442414029152133, 0.11175341351190582, 0.09359254036098719, 0.06384128719219007, 0.0310575499679544, 0.19028565497137606, 0.15701502619776875, 3.809152627363801, 15.201752129942179, 7.8628297336399555, 23.985933624207973, 15.823269579559565, 0.47702960902825, 9.34878844767809, 7.614741520956159, 2.5962194753810763, 0.8823098649736494, 1.301691757980734, 57.89098039269447, 66.64868965744972, 39.43409018218517, 92.31303691864014, 43.40667821466923, 0.3923464327817783, 0.1507441751891747, 0.429349826881662, 1.3921422231942415, 54.417525976896286, 119.49962049722672, 90.20506203174591, 90.99659755825996, 85.49019142985344, 47.40933023393154, 0.5280650861095637, 5.323191359639168, 63.624659925699234, 47.1878857165575, 29.142726212739944, 37.0079355686903, 48.69425028562546, 19.220805019140244, 0.14810733933700249, 0.13713335007196292, 0.23439989250618964, 0.07873012771597132, 0.038102140024420805, 0.04687751679739449, 0.08910765289328992, 0.038405845407396555, 0.07698061104747467, 0.047091199667192996, 0.022595405898755416, 0.07352926069870591, 0.061583696224261075, 0.03806233864452224, 0.12578148889588192, 0.09986005912651308, 0.0629373884294182, 0.06088118665502407, 0.08053764322539791, 0.8413864765316248, 3.1735172728076577, 22.80310269445181, 68.96389782428741, 76.44371286034584, 82.59102299809456, 74.76782038807869, 71.52977854013443, 74.34643059968948, 70.27493387460709, 73.20188641548157, 71.13484293222427, 77.57197111845016, 69.55203786492348, 71.19158148765564, 65.97164198756218, 64.67050820589066, 67.92427361011505, 65.6057520210743, 60.79457938671112, 60.21008715033531, 62.03611716628075, 64.70663666725159, 55.22208720445633, 47.9302366822958, 51.66442930698395, 57.0657254755497, 59.34859357774258, 57.330001294612885, 55.20510211586952, 52.26480849087238, 50.70050083100796, 50.54015703499317, 54.79976266622543, 51.13674022257328, 48.33195112645626, 42.42671079933643, 41.53239458799362, 43.589429408311844, 47.28131130337715, 46.76651492714882, 49.71998244524002, 49.17087770998478, 48.94328132271767, 49.44737747311592, 50.82579530775547, 51.06086589396, 47.87210740149021, 57.98655666410923, 69.68867853283882, 72.0099663734436, 67.88243785500526, 53.18972826004028, 43.853777423501015, 36.836906746029854, 38.729296401143074, 47.58766986429691, 51.09760992228985, 53.738688603043556, 53.05930785834789, 45.60739852488041, 38.86236906051636, 36.274316534399986, 35.94254873692989, 35.842967480421066, 41.88919544219971, 45.071410685777664, 49.02606748044491, 49.9653884768486, 51.91017732024193, 52.3981699347496, 50.4627475887537, 49.17791113257408, 50.18889628350735, 46.98214575648308, 48.30893576145172, 45.35455249249935, 50.05837708711624, 48.85055109858513, 48.478752449154854, 43.803278133273125, 50.75255423784256, 57.986184284090996, 58.796342611312866, 58.64418737590313, 63.444823175668716, 61.94002792239189, 53.20062607526779, 60.283708199858665, 60.1365002989769, 52.574279084801674, 60.38341484963894, 59.10050868988037, 62.22037687897682, 56.53326004743576, 52.54834167659283, 50.088410675525665, 65.150665640831, 60.76690927147865, 61.31083868443966, 54.296092092990875, 62.32126146554947, 41.68631672859192, 46.82483419775963, 57.58614934980869, 59.31012824177742, 59.6235316246748, 55.34457363188267, 49.70192961394787, 24.559906125068665, 22.194253765046597, 4.6400051191449165, 0.023272942198673263, 0.024277118100144435, 0.12021918111713603, 0.07858056269469671, 0.04673728057241533, 0.10874651314225048, 0.20320166659075767, 0.030515153193846345, 0.014969879339332692, 0.1743000018177554, 0.05055400877608918, 4.451934210956097, 18.797131553292274, 9.47376849129796, 26.249641254544258, 35.102147832512856, 1.506335714366287, 12.159149944782257, 9.720662143081427, 2.675654925405979, 0.9148578497115523, 0.4667856852756813, 52.88533419370651, 73.36166024208069, 50.509770065546036, 101.56896784901619, 57.75139108300209, 0.4891957843210548, 0.35982415603939444, 0.42507743113674223, 1.493839609902352, 46.86644956469536, 133.08085173368454, 97.29808062314987, 104.87884864211082, 105.24560496211052, 87.78600543737411, 0.5347564083058387, 6.942501543089747, 83.01118925213814, 54.92181971669197, 39.32021029293537, 43.028423711657524, 63.355581164360046, 27.303366512060165, 0.6140997726470232, 0.23520261427620426, 0.3597105183871463, 0.2662506443448365, 0.2246898104203865, 0.17509067110950127, 0.1921360517735593, 0.20332168671302497, 0.18155146739445627, 0.3239409893285483, 0.10092009833897464, 0.2499282342614606, 0.18108523538103327, 0.10883410883252509, 0.2506984648061916, 0.2042672867537476, 0.16187567787710577, 0.15620921709341928, 0.2527517202543095, 1.2706122756935656, 10.494235083460808, 44.57462154328823, 73.39213460683823, 80.63147574663162, 85.05451440811157, 73.52330356836319, 72.56547376513481, 74.14150759577751, 73.07933539152145, 76.22644811868668, 71.27568617463112, 77.97995522618294, 72.92243421077728, 72.65037640929222, 66.9015508890152, 66.78822576999664, 71.29055097699165, 66.45816788077354, 63.06127555668354, 63.70751067996025, 65.6949332356453, 67.79331743717194, 58.717937618494034, 52.181357368826866, 55.650886595249176, 60.86612194776535, 62.21642129123211, 58.706815615296364, 57.90801487863064, 54.29727762937546, 54.14319969713688, 54.64687027037144, 58.46453681588173, 51.69515445828438, 49.12840738892555, 45.16639418900013, 43.65517348051071, 46.44368804991245, 51.30599454045296, 52.20890209078789, 51.83278687298298, 51.976065784692764, 52.66201637685299, 51.587190851569176, 57.89895236492157, 50.57844378054142, 50.54537035524845, 61.510396376252174, 73.53734761476517, 73.86048227548599, 68.22424471378326, 51.08815982937813, 46.02737478911877, 39.63073343038559, 41.0467654466629, 48.78522880375385, 50.434591099619865, 53.17065328359604, 55.93369022011757, 47.80603654682636, 41.5231154859066, 37.95385681092739, 38.6532586812973, 38.09314213693142, 43.9739877730608, 46.88599951565266, 52.61922687292099, 53.0200369656086, 53.010301887989044, 53.18320021033287, 51.677831187844276, 52.16151863336563, 55.23088753223419, 50.44212989509106, 48.23541730642319, 48.854620680212975, 52.493655011057854, 50.858530551195145, 49.94758263230324, 46.398576870560646, 53.47356162965298, 60.650160536170006, 62.65605390071869, 61.74518957734108, 68.36898654699326, 62.48265780508518, 51.4776237308979, 59.3093416839838, 63.14058110117912, 53.379824459552765, 63.68092730641365, 61.007641553878784, 64.1215668618679, 58.5005246847868, 56.03449881076813, 52.46921852231026, 67.48250931501389, 61.95817194879055, 64.14055064320564, 59.1862852871418, 65.14900892972946, 54.65170361101627, 61.66234642267227, 66.98741108179092, 60.4669913649559, 61.31706275045872, 56.761107221245766, 55.34765146672726, 34.297324419021606, 32.633427903056145, 4.49574775993824, 0.19987916050013155, 0.26486006740015, 0.21880728076212108, 0.36364565254189074, 0.18605536868562922, 0.20023077522637323, 0.3088320203823969, 0.1644293189747259, 0.07119500587577932, 0.6289492570795119, 0.2713469724403694, 6.806738153100014, 27.61231653392315, 16.695798709988594, 33.674317449331284, 49.29894603788853, 2.1762479608878493, 19.63521458208561, 12.830600515007973, 4.657103251665831, 1.0666108410805464, 2.3037869296967983, 75.58429017663002, 86.92335292696953, 59.24949109554291, 114.65657517313957, 60.942471250891685, 0.6082090793643147], [0.04671760252676904, 0.016967813244264107, 3.160450248979032, 87.51840859651566, 95.56870982050896, 81.7606383562088, 86.97924792766571, 62.74897791445255, 6.322101708501577, 0.39193011762108654, 19.590432085096836, 52.228262051939964, 39.38078664243221, 34.2529010027647, 28.834526650607586, 29.58648920059204, 12.50844145193696, 0.05012211964640301, 0.039818924269638956, 0.045203851332189515, 0.0541039645759156, 0.023796705499989912, 0.024003709040698595, 0.057693506532814354, 0.018876299800467677, 0.019078761397395283, 0.12042042930261232, 0.06951193368877284, 0.03671936676255427, 0.0893105857539922, 0.03872202258207835, 0.007357948925346136, 0.10580573813058436, 0.06725208659190685, 0.061877074622316286, 0.11519225125084631, 0.09056578754098155, 0.46233089931774884, 2.554274001158774, 42.808761298656464, 67.18450650572777, 66.60287171602249, 77.58970856666565, 73.14013212919235, 71.17196694016457, 63.39535742998123, 69.64448690414429, 71.73194289207458, 75.51658540964127, 68.4133605659008, 65.89378416538239, 66.16586476564407, 66.28588512539864, 62.97487959265709, 63.9767262339592, 62.92387492954731, 59.268619269132614, 61.02033667266369, 58.187417685985565, 53.32699969410896, 46.25178314745426, 50.6026066839695, 52.25609935820103, 55.436395704746246, 53.26908700168133, 52.682850658893585, 50.194983556866646, 45.16275018453598, 46.93522587418556, 49.21330623328686, 49.09810021519661, 48.4049604088068, 43.465886637568474, 40.835226997733116, 42.51145005226135, 45.32919265329838, 46.117403358221054, 45.167769715189934, 46.72624088823795, 45.45490890741348, 46.82428702712059, 48.86038117110729, 51.58964551985264, 47.55915239453316, 52.675562649965286, 58.290859535336494, 64.75383013486862, 64.69942465424538, 53.527241349220276, 39.57727409899235, 42.415452003479004, 42.77609825134277, 46.53859555721283, 52.304831743240356, 54.310584515333176, 52.717356607317924, 43.47925052046776, 36.76339589059353, 38.61044257879257, 35.70891447365284, 37.54186771810055, 40.076183527708054, 45.89033134281635, 46.724724769592285, 45.46322666108608, 47.98912592232227, 47.94323578476906, 47.67884977161884, 48.71532015502453, 45.96846655011177, 44.250894114375114, 44.527838453650475, 44.69364635646343, 46.96564324200153, 43.42190779745579, 46.28254249691963, 41.816965118050575, 47.606870234012604, 57.34849110245705, 56.91147655248642, 59.51544262468815, 58.89819994568825, 64.49292853474617, 63.64514462649822, 61.571922674775124, 52.11332581937313, 48.21284271776676, 59.00594316422939, 54.16938029229641, 51.34509824216366, 55.701625272631645, 43.05473729968071, 48.881204053759575, 52.05209210515022, 50.77651955187321, 52.38811567425728, 47.04215593636036, 35.164042711257935, 8.826788607984781, 12.634816970676184, 34.02727670967579, 51.627666279673576, 51.939397752285004, 48.40632073581219, 29.497634768486023, 8.46592292189598, 4.731702273711562, 0.13453664956614375, 0.11058346222853288, 0.16818031144794077, 0.1968085244880058, 0.09595405426807702, 0.10351938894018531, 0.11260514671448618, 0.10654543671989813, 0.08505527424858883, 0.05038355229771696, 0.07221393010695465, 0.1254415704170242, 2.9314180137589574, 14.872291758656502, 26.777681820094585, 31.476532481610775, 17.341311872005463, 7.485124301165342, 11.799597088247538, 23.04700780659914, 13.381444606930017, 1.3638717401772738, 0.1090530572400894, 15.783044937998056, 72.46040940284729, 53.770819678902626, 86.83770552277565, 66.9457121193409, 0.6648541835602373, 0.1324730782653205, 0.05506053727003746, 4.654485667124391, 107.80612796545029, 95.27282729744911, 93.74478489160538, 86.32677733898163, 71.80071160197258, 8.526268433779478, 0.2933446451788768, 34.289580434560776, 69.3604825437069, 48.50096985697746, 45.5360459536314, 37.603416815400124, 36.213740184903145, 17.597342133522034, 0.11375959453289397, 0.08255157968960702, 0.04384655228932388, 0.09137605695286766, 0.028588721506821457, 0.014641691432188964, 0.03285248421889264, 0.08022778172744438, 0.07258453639224172, 0.06471567816333845, 0.11315274779917672, 0.11835918092401698, 0.03276187169831246, 0.07922095450339839, 0.025236136170860846, 0.017020218147081323, 0.047215149461408146, 0.08013606711756438, 0.08355384270544164, 0.05359244671126362, 0.14821523276623338, 0.4047106724465266, 34.959910064935684, 68.42254847288132, 70.89159518480301, 79.31289330124855, 76.79578676819801, 74.34551864862442, 63.11067670583725, 70.65340876579285, 74.3875139951706, 75.55072277784348, 69.67326655983925, 66.66997611522675, 67.6035176217556, 67.62193903326988, 65.36533132195473, 66.07714712619781, 63.79710227251053, 64.0386401116848, 65.68043321371078, 59.621745720505714, 55.294150337576866, 48.41547064483166, 53.22019122540951, 53.068381771445274, 56.987233087420464, 56.585400849580765, 55.34542478621006, 53.2770361751318, 48.63425150513649, 49.08893510699272, 51.99726864695549, 53.21565806865692, 52.22943238914013, 47.104905769228935, 45.103568360209465, 46.11501708626747, 47.59919464588165, 46.91551253199577, 47.450254037976265, 48.58011581003666, 49.195348396897316, 50.16558453440666, 48.47267657518387, 53.156149461865425, 52.97016844153404, 51.92860633134842, 56.66673168540001, 63.57005685567856, 62.12350107729435, 52.004989832639694, 42.372594103217125, 47.157266959548, 46.34886033833027, 48.26026417315006, 54.27002929151058, 55.625804141163826, 54.83106918632984, 45.991846695542336, 40.02767913043499, 42.08311043679714, 38.19073610007763, 39.20364014804363, 42.689842879772186, 46.718645095825195, 47.869470342993736, 47.94294700026512, 49.37752202153206, 49.43858854472637, 50.778438448905945, 50.85845835506916, 47.845398634672165, 47.16974928975105, 45.41199401021004, 47.1125091612339, 49.84915651381016, 46.01377911865711, 48.82253520190716, 46.66838139295578, 51.30756765604019, 60.82990229129791, 62.239835634827614, 61.7708458006382, 62.396968603134155, 64.6683119237423, 67.73276388645172, 63.16152177751064, 50.91249905526638, 48.41048911213875, 59.57391768693924, 54.086008965969086, 51.60644441843033, 54.30923178792, 47.28011056780815, 54.702461287379265, 54.008067548274994, 54.66255582869053, 54.91012014448643, 45.81549055874348, 25.23627743124962, 2.03076065517962, 8.014317154884338, 31.678651235997677, 50.4498016834259, 53.472007513046265, 49.07630078494549, 28.497847616672516, 7.856806581839919, 3.215847476385534, 0.47696857480332255, 0.054345871321856976, 0.21503770491108298, 0.046807105536572635, 0.04821779097255785, 0.09606706109480001, 0.11546968089533038, 0.06376655292115174, 0.07533413416240364, 0.0671558671456296, 0.03945434422348626, 0.10703461593948305, 3.6402113176882267, 21.704026870429516, 26.366046108305454, 30.553345419466496, 34.737006425857544, 8.234659731388092, 14.273198805749416, 24.61455099284649, 13.781653381884098, 2.73739377502352, 0.30822426080703735, 13.07602934539318, 77.2723039984703, 58.30229312181473, 98.42429459095001, 73.74516606330872, 0.9380837471690029, 0.2616341889370233, 0.2666093094740063, 3.7898031156510115, 109.18550714850426, 113.51744189858437, 103.19977954030037, 104.84019711613655, 98.959199488163, 18.25329903513193, 0.752299603773281, 36.90535627305508, 80.80695033073425, 59.93584826588631, 56.831509843468666, 43.27217683196068, 46.30869269371033, 25.587086006999016, 0.2653049404034391, 0.26152574631851166, 0.33910458034370095, 0.14232321846066043, 0.13031500187935308, 0.10520806434215046, 0.1625473066815175, 0.17762422969099134, 0.13065351027762517, 0.24207038950407878, 0.20085327385459095, 0.35694969934411347, 0.17529021977679804, 0.27143107261508703, 0.12244846657267772, 0.17161087424028665, 0.11522070519276895, 0.2510448399698362, 0.4469416360370815, 0.2523616177495569, 0.4362329497234896, 7.149788020178676, 63.41801181435585, 69.70463767647743, 72.7473472058773, 81.96958914399147, 79.05810177326202, 72.68987149000168, 61.945381835103035, 71.47947683930397, 79.31479319930077, 79.13597479462624, 71.70908331871033, 69.46279585361481, 70.2505011856556, 68.58386501669884, 64.27178800106049, 65.86121991276741, 64.41219046711922, 62.896318808197975, 67.44935229420662, 62.95822508633137, 58.86924169957638, 52.032207772135735, 57.366977110505104, 57.64219254255295, 61.90499760210514, 60.470346584916115, 59.243039041757584, 57.50656262040138, 52.46283106505871, 52.6038870960474, 56.3925725966692, 56.97498254477978, 54.832957684993744, 47.63908110558987, 46.884377002716064, 46.23319834470749, 50.20680092275143, 50.609712302684784, 49.66060683131218, 48.95639821887016, 50.280281379818916, 53.55866566300392, 53.402171060442924, 55.494559183716774, 52.64338597655296, 52.78410762548447, 59.15891535580158, 67.35020041465759, 67.98876374959946, 54.00005757808685, 41.394644379615784, 45.06237477064133, 43.80136303603649, 50.254906341433525, 59.46752719581127, 60.629090666770935, 59.01586063206196, 47.39895299077034, 42.33129791915417, 44.210065305233, 39.59762580692768, 41.553681045770645, 44.409072026610374, 50.05931183695793, 51.82388015091419, 50.70510618388653, 52.3647241294384, 54.77660670876503, 54.24484424293041, 55.12439824640751, 50.73573634028435, 52.07354195415974, 48.78539979457855, 50.32660469412804, 51.75634257495403, 47.208571806550026, 52.41215318441391, 47.65246398746967, 52.062229961156845, 61.14730305969715, 62.62361504137516, 65.761908441782, 64.09480109810829, 66.03138238191605, 67.56102070212364, 64.6250094473362, 54.43956099450588, 49.423731341958046, 61.690776497125626, 57.374892085790634, 57.52873823046684, 62.54088968038559, 54.9214131385088, 59.46922950446606, 66.01712554693222, 61.253518760204315, 61.397109255194664, 58.58900673687458, 49.90710720419884, 17.531151585280895, 24.75358173251152, 53.060861974954605, 63.86423707008362, 65.0682632625103, 60.201670601964, 47.11761608719826, 26.87700469046831, 7.906700754538178, 0.4801675578346476, 0.27487377694342285, 0.3034755546832457, 0.4519839951535687, 0.4163748293649405, 0.18599687260575593, 0.17905038519529626, 0.16492884373292327, 0.1902552566025406, 0.2392933174269274, 0.21072024595923722, 0.2028370345942676, 5.0493120308965445, 31.426306776702404, 39.63069163262844, 48.23979467153549, 35.80100253224373, 20.115687400102615, 23.460267931222916, 32.017678543925285, 20.011647082865238, 3.467717911116779, 0.23747906321659684, 29.033607468008995, 91.71663612127304, 71.68197557330132, 112.59479060769081, 85.75062945485115, 1.4723898796364665], [0.21718276402680203, 0.6112686276901513, 10.501373950392008, 106.95356771349907, 80.087960511446, 76.80180564522743, 74.53993141651154, 30.01306191086769, 0.30060388846322894, 0.4666618356714025, 24.75726943463087, 63.68237502872944, 38.79670098423958, 40.98845757544041, 19.563639722764492, 35.751323997974396, 11.38417012989521, 0.16824254795210436, 0.14766691921977326, 0.02921076928032562, 0.13589338457677513, 0.048698068130761385, 0.043654647743096575, 0.033001180927385576, 0.03932329949748237, 0.06320976404822432, 0.0989433508948423, 0.15819321532035246, 0.052868563288939185, 0.047080687145353295, 0.02567621490015881, 0.030368629122676793, 0.06100986021920107, 0.05806779387057759, 0.025525672099320218, 0.06962287734495476, 0.06567644028109498, 0.08674608703586273, 0.28583200299181044, 3.7916609784588218, 50.00449977815151, 70.72122752666473, 70.43432012200356, 67.69150570034981, 69.19722810387611, 64.93592396378517, 65.60050070285797, 75.08856117725372, 69.75561574101448, 63.60232092440128, 62.66185998916626, 69.56472918391228, 72.23581105470657, 67.14330151677132, 69.70084547996521, 65.79086288809776, 64.35400798916817, 66.1877515912056, 61.119883731007576, 53.582687973976135, 47.62955881655216, 49.07122805714607, 51.24064564704895, 50.33021830022335, 47.55760967731476, 50.332228392362595, 49.670113921165466, 47.339094802737236, 46.908946484327316, 49.52434614300728, 48.81216935813427, 48.6034769564867, 48.63175503909588, 46.81244686245918, 48.11195433139801, 45.670209154486656, 45.36860033869743, 42.89541184902191, 45.591956153512, 47.19015799462795, 49.273749589920044, 50.05849488079548, 55.325893834233284, 54.721087887883186, 52.26304918527603, 52.28390246629715, 50.32613351941109, 50.14845885336399, 42.342435121536255, 48.121947795152664, 47.4969345331192, 51.00867949426174, 50.85324123501778, 51.89422197639942, 51.24149300158024, 49.9984885007143, 45.73601022362709, 39.05381798744202, 41.64068877696991, 39.74120870232582, 43.17509204149246, 43.8902972638607, 43.40783715248108, 42.84286066889763, 44.29186351597309, 45.31854182481766, 45.21420322358608, 45.012156665325165, 46.56762219965458, 44.9646820127964, 43.45446065068245, 42.23163686692715, 45.496740862727165, 48.034077510237694, 45.54905645549297, 46.26335732638836, 44.50121708214283, 53.17891404032707, 57.65130065381527, 57.33827345073223, 56.73296973109245, 58.16639341413975, 61.00737936794758, 63.88113856315613, 64.1777354478836, 51.57260723412037, 52.04741455614567, 49.31273929774761, 51.25543065369129, 41.175206154584885, 34.831146374344826, 35.78036583960056, 40.227666199207306, 39.783933609724045, 39.35069985687733, 21.314061395823956, 9.624037127941847, 1.1552267172373831, 0.36534145998302847, 0.17520252760732546, 1.5659811138175428, 12.97720804810524, 29.83126826584339, 27.160775363445282, 2.3348274640738964, 1.9529827474616468, 0.3723518759943545, 0.16102220804896206, 0.08438913733698428, 0.16123029141454026, 0.06849497614894062, 0.15338041732320562, 0.043534174910746515, 0.1404590770835057, 0.08423416948062368, 0.015121008436835837, 0.09891412511933595, 0.02927052144514164, 0.051817600542563014, 2.2699072351679206, 13.578047007322311, 25.065809078514576, 24.331200197339058, 19.17958863079548, 12.183134257793427, 13.070413246750832, 37.50650301575661, 31.981071308255196, 5.446020243689418, 0.7065666234120727, 8.668038826435804, 65.00071808695793, 44.03970904648304, 97.41963610053062, 54.46801386773586, 0.1142690640699584, 0.3284967370564118, 0.7815868291072547, 13.312056530267, 115.77685385942459, 95.60666218400002, 84.45610731840134, 81.65984496474266, 37.05060727894306, 0.23036630504066125, 0.5848831997718662, 30.238539911806583, 74.42903816699982, 47.920904383063316, 53.65418493747711, 22.928733453154564, 43.01822505891323, 16.010495983064175, 0.33284132892731577, 0.08610619988758117, 0.06646213718340732, 0.013754102292296011, 0.03793675983615685, 0.06488588231150061, 0.04827635384572204, 0.06192551460117102, 0.036742354786838405, 0.10204012534813955, 0.08753103436902165, 0.08183900659787469, 0.09110719911404885, 0.054041156618040986, 0.046320694527821615, 0.06467761340900324, 0.08804868237348273, 0.04422186750161927, 0.03737099839781877, 0.13826462061842903, 0.06824108000728302, 0.24507718597305939, 1.1819344153627753, 37.40301176905632, 67.17042446136475, 76.63397625088692, 73.45604717731476, 75.88453486561775, 68.39812338352203, 67.97142148017883, 76.22308149933815, 70.64420565962791, 65.95585003495216, 63.24167847633362, 72.15340107679367, 74.55057084560394, 70.37960305809975, 70.8357609808445, 68.61646726727486, 64.86060440540314, 68.83571550250053, 64.12630140781403, 57.1224108338356, 50.8908212184906, 51.30879499018192, 53.423267528414726, 52.48419351875782, 50.942335054278374, 52.146087661385536, 51.57371297478676, 50.99407307803631, 50.613588094711304, 52.65989989042282, 50.3481837362051, 48.59793685376644, 51.2201951444149, 49.84539091587067, 50.218736082315445, 48.1071437895298, 48.09881843626499, 47.783271968364716, 45.685514733195305, 50.27767091989517, 50.306135192513466, 52.01135069131851, 56.85259111225605, 57.80284412205219, 52.08728201687336, 51.88269339501858, 49.16884861886501, 46.27842351794243, 42.66118101775646, 49.11280542612076, 49.188132584095, 52.950781881809235, 53.546449318528175, 53.66018861532211, 53.107785657048225, 52.239205464720726, 49.64841328561306, 42.29772292077541, 42.80623823404312, 43.41119237244129, 44.41494271159172, 47.179860547184944, 46.12599469721317, 45.97519598901272, 47.141547203063965, 47.39375866949558, 48.55703964829445, 47.94027954339981, 48.19917865097523, 48.499719724059105, 46.67272076010704, 46.1648628115654, 48.80409859120846, 50.4128410667181, 48.761727064847946, 48.356702998280525, 50.19215650856495, 55.44222079217434, 58.228166699409485, 56.139620169997215, 58.16131308674812, 59.94984671473503, 63.499574437737465, 67.16356202960014, 65.53287953138351, 56.70731730759144, 54.83030162751675, 49.755890518426895, 50.27688816189766, 44.85787734389305, 38.377321287989616, 43.3357360213995, 47.5318356603384, 50.316827818751335, 46.316296085715294, 23.390904553234577, 5.5226293578743935, 0.632049118867144, 0.28154963278211653, 0.2178864981397055, 1.2080613384023309, 9.104256369173527, 26.91601149737835, 24.206528887152672, 3.5333425272256136, 2.6057624258100986, 0.32301057362928987, 0.1064341442543082, 0.06970981252379715, 0.015184493604465388, 0.043014081529690884, 0.09324611324700527, 0.010773651138151763, 0.0840907271776814, 0.09612869645934552, 0.03905120960553177, 0.1181686864583753, 0.04509906379098538, 0.05661023809807375, 2.7918047178536654, 19.227604754269123, 32.07315556704998, 29.193892367184162, 40.653741136193275, 30.921538062393665, 28.98702196776867, 51.09318695962429, 34.610378220677376, 6.83717499487102, 2.858690391294658, 17.184714674949646, 73.43499630689621, 52.51476287841797, 109.84899714589119, 57.577018439769745, 0.1457120428676717, 0.32158176123630255, 0.8732762653380632, 13.2884312979877, 127.98429161310196, 104.90091785788536, 91.33951395750046, 96.34965911507607, 56.27673581242561, 0.2656390256015584, 0.6042823463212699, 43.21243643760681, 90.70839062333107, 54.764245972037315, 62.145114317536354, 29.235108755528927, 52.68189691007137, 22.41089913994074, 0.6228966568596661, 0.41408138524275273, 0.2075537689961493, 0.18196341872680932, 0.18467650283128023, 0.16069735516794026, 0.10602522830595262, 0.1571235727169551, 0.21791964245494455, 0.20076774875633419, 0.21006010560085997, 0.17347721237456426, 0.23231871746247634, 0.17551832628669217, 0.16597761714365333, 0.13428552163532004, 0.1732970486045815, 0.11002427621860988, 0.13414613145869225, 0.38523799390532076, 0.2281152969226241, 0.5883203528355807, 9.709027167409658, 62.41153322160244, 73.98484200239182, 74.02879804372787, 71.5827476978302, 76.00007146596909, 67.55640774965286, 71.52259692549706, 75.91791227459908, 73.76923397183418, 67.44090154767036, 63.519682958722115, 72.4435231089592, 76.94182813167572, 72.42013916373253, 73.76102641224861, 68.55850517749786, 69.2556157708168, 72.22666874527931, 65.47588258981705, 58.194827288389206, 51.218869015574455, 55.9127077460289, 56.98853641748428, 55.54809831082821, 54.08452324569225, 57.47240625321865, 55.77257886528969, 53.04114483296871, 52.671025693416595, 55.75822703540325, 53.69690604507923, 52.65171132981777, 55.428651720285416, 51.81380309164524, 52.500053867697716, 51.25438950955868, 51.92829854786396, 47.55758307874203, 48.761837258934975, 53.17905843257904, 52.73039370775223, 55.77187590301037, 59.25770625472069, 61.37928821146488, 56.272286251187325, 57.84706234931946, 52.83180646598339, 49.801689460873604, 42.998127937316895, 51.00583344697952, 50.05515865981579, 56.6631218791008, 52.97186315059662, 55.941422805190086, 58.487274795770645, 56.38064883649349, 53.020523339509964, 43.52283038198948, 45.95039092004299, 48.30730564892292, 47.0273557305336, 50.17696112394333, 50.174574851989746, 49.039218574762344, 49.435366317629814, 50.11878244578838, 50.83095543086529, 49.99807432293892, 52.61307120323181, 50.886975824832916, 48.705653473734856, 49.61427591741085, 50.536661222577095, 54.99792203307152, 50.06351821124554, 50.22543892264366, 51.25014513731003, 57.454710602760315, 63.31742361187935, 58.74965451657772, 61.792519837617874, 63.40794995427132, 66.923338919878, 69.67715755105019, 68.05425703525543, 55.48475190997124, 58.14218491315842, 54.40675735473633, 58.12134303152561, 52.455702647566795, 49.20162186026573, 52.783248871564865, 56.93159267306328, 57.5682333111763, 64.47859570384026, 60.824818164110184, 28.537033013999462, 2.89038781542331, 0.7970005238894373, 0.327426886651665, 3.3471544180065393, 17.34260380268097, 38.06622818112373, 41.383822560310364, 19.894077591598034, 5.370445623993874, 0.7110611291136593, 0.26123672432731837, 0.1675209280801937, 0.2374112606048584, 0.26272853021509945, 0.25685392669402063, 0.20957978762453422, 0.238447432348039, 0.23362299747532234, 0.0976526150770951, 0.177809989254456, 0.17191306193126366, 0.143313629378099, 3.359664296731353, 31.408014558255672, 44.559961929917336, 31.579742543399334, 37.39135779440403, 47.167127430438995, 46.85249291360378, 69.19149041175842, 51.58902235329151, 8.104899544268847, 6.554803121834993, 13.989297039806843, 91.02891102433205, 61.56672075390816, 120.28501555323601, 71.16052955389023, 0.4220029804855585], [0.32252595119643956, 0.4755979764740914, 12.039469666779041, 108.71633112430573, 85.75599476695061, 105.80479815602303, 55.95080450177193, 7.638447023928165, 0.21999954100465402, 5.503676449880004, 12.361147105693817, 41.805953308939934, 45.096082761883736, 45.46733804047108, 27.676120810210705, 24.570391662418842, 10.213728435337543, 0.23816087428713217, 0.031654706108383834, 0.035461845764075406, 0.10738752942415886, 0.06127390151959844, 0.04831183221540414, 0.028077511633455288, 0.04389464716950897, 0.07803642743965611, 0.080202370590996, 0.06413188995793462, 0.039170981108327396, 0.013764328159595607, 0.010819262606673874, 0.02636042125232052, 0.02666130276338663, 0.019129524298477918, 0.08590425408328883, 0.011809763509518234, 0.03773404961975757, 0.04463200057216454, 0.27291518985293806, 0.05280485733237583, 3.4159371396526694, 27.1875012293458, 61.498727202415466, 63.762326538562775, 65.7275278866291, 62.57723852992058, 56.22223533689976, 65.63899263739586, 63.912486881017685, 57.784521505236626, 65.98290458321571, 70.75903549790382, 72.77986586093903, 70.65389513969421, 66.71359777450562, 67.45177656412125, 61.55317448079586, 58.005753234028816, 57.60911151766777, 57.4252849817276, 53.59347179532051, 46.559327244758606, 47.118026465177536, 49.172150641679764, 46.20999678969383, 47.95446418225765, 47.19904571771622, 47.28638023138046, 48.8909163326025, 46.79507419466972, 48.07039216160774, 46.831905618309975, 47.97831550240517, 46.84269703924656, 45.36228887736797, 45.94650372862816, 47.80573636293411, 47.1712502092123, 44.08778786659241, 47.27028049528599, 46.47107698023319, 52.557875365018845, 54.25892248749733, 47.49262176454067, 50.35639509558678, 48.736576214432716, 46.936909183859825, 44.57779057323933, 44.726062417030334, 43.38802121579647, 48.347279503941536, 49.34594951570034, 48.277845829725266, 51.53043329715729, 52.323686331510544, 48.37252154946327, 46.98317550122738, 42.596003115177155, 42.97994591295719, 42.94461540877819, 43.14570061862469, 44.30189497768879, 43.56098413467407, 43.52479487657547, 42.629627510905266, 42.833741158246994, 46.16634093225002, 45.50454564392567, 45.85923761129379, 45.06488263607025, 43.870713114738464, 44.25695478916168, 46.864827051758766, 47.24491685628891, 50.82348883152008, 46.53200291097164, 50.86593255400658, 52.32383072376251, 52.22162380814552, 52.4406972527504, 54.23482798039913, 57.35983729362488, 58.76119829714298, 59.083139821887016, 57.04635411500931, 58.047000020742416, 58.01718682050705, 45.39177529513836, 39.299410209059715, 33.04141581058502, 28.723844289779663, 31.40981376171112, 40.25057137012482, 30.149666480720043, 4.476145086809993, 1.3639482110738754, 0.20530031179077923, 0.12003608586383052, 0.04644703403755557, 0.06939136437722482, 0.07848461042158306, 0.15184656134806573, 0.830388501053676, 0.35413538629654795, 0.2179237242671661, 0.4101743339560926, 0.07218648548587225, 0.06973677474888973, 0.005387223545767483, 0.058807436798815615, 0.04257786196831148, 0.060494876524899155, 0.1151232240954414, 0.028203968031448312, 0.04038759863760788, 0.040886444330681115, 0.08013203725568019, 0.01683180726104183, 0.24596461647888646, 2.425714312121272, 16.247018091380596, 19.20146595686674, 21.843562982976437, 9.932781010866165, 8.36340632289648, 7.789298454299569, 16.247798949480057, 53.849289268255234, 18.28770238906145, 1.6637261188589036, 32.16781608760357, 48.0262765288353, 58.23917470872402, 77.5449849665165, 34.3255303055048, 0.17700263648293912, 0.3823928668862209, 0.46176930132787675, 12.150676399469376, 120.21797955036163, 97.49725833535194, 106.38989835977554, 77.28999584913254, 13.560363706201315, 0.28814343677368015, 12.172320038080215, 18.158178739249706, 52.44655653834343, 57.14905500411987, 58.361125364899635, 28.109375461935997, 27.84090466797352, 15.521008148789406, 0.2647369302576408, 0.017274570709560066, 0.06519861592096277, 0.0362484592187684, 0.02626929108373588, 0.051398680443526246, 0.037135822931304574, 0.02379937723162584, 0.04995160379621666, 0.04183324293990154, 0.02048548005404882, 0.037082243579789065, 0.0622743388521485, 0.04003718990134075, 0.033656812738627195, 0.09136014530668035, 0.045258740574354306, 0.11202621957636438, 0.04948798414261546, 0.02814762974594487, 0.029995980075909756, 0.11861582301207818, 0.042856393702095374, 0.8539662358816713, 12.103772666305304, 46.20185762643814, 64.98997986316681, 70.63918992877007, 67.92846098542213, 59.6676966547966, 67.04546436667442, 67.43148565292358, 59.81499955058098, 69.25410345196724, 73.10554638504982, 73.17082688212395, 72.53237754106522, 68.55457618832588, 68.4857314825058, 62.680121809244156, 61.10360540449619, 58.236450254917145, 58.245402574539185, 56.91451258957386, 49.34126816689968, 50.71570381522179, 50.62581963837147, 49.6247823536396, 50.37553086876869, 49.577965065836906, 51.24086983501911, 51.232365891337395, 49.73420888185501, 50.36360330879688, 48.84956695139408, 50.04182517528534, 49.83623720705509, 48.90415482223034, 49.542634561657906, 51.365100368857384, 47.02464647591114, 48.25462907552719, 49.50631611049175, 50.19824758172035, 57.19001680612564, 55.08491836488247, 51.04013420641422, 53.563058227300644, 50.03486394882202, 51.009549647569656, 48.31360191106796, 47.30208098888397, 45.67712098360062, 51.85476489365101, 52.29100048542023, 51.53407730162144, 53.4500864893198, 55.435400158166885, 50.53238645195961, 48.77454377710819, 46.289800107479095, 45.6369723379612, 46.76654152572155, 46.71433612704277, 44.73079316318035, 46.96645259857178, 45.40843740105629, 47.9742307215929, 46.021739691495895, 48.832874447107315, 47.65403710305691, 49.81028459966183, 47.78987981379032, 50.59398874640465, 47.38837815821171, 48.75179819762707, 48.9644879847765, 51.89722381532192, 48.701751083135605, 54.282336831092834, 54.7164711356163, 53.40428374707699, 54.793633595108986, 58.8535675406456, 59.35549020767212, 60.65964102745056, 61.07056237757206, 60.980784595012665, 61.26052178442478, 59.55329239368439, 45.7354174554348, 44.11377087235451, 39.61254380643368, 38.214743211865425, 44.04063619673252, 51.58947832882404, 30.046534314751625, 3.5305413650348783, 0.6125036207959056, 0.11054726768634282, 0.05820895778015256, 0.015247960218403023, 0.02314865472726524, 0.014159127531456761, 0.05900002783164382, 0.26265850116033107, 0.17780121706891805, 0.15164248557994142, 0.21701647841837257, 0.055019255305523984, 0.006446677853091387, 0.056483093358110636, 0.037765832094009966, 0.04137153802730609, 0.010671894342522137, 0.03417886538954917, 0.009988274287024979, 0.06307356510660611, 0.043330433109076694, 0.028746362950187176, 0.024830591428326443, 0.0849051155091729, 2.855107421055436, 27.830554023385048, 28.37287612259388, 27.85082023590803, 34.16881911456585, 27.623710222542286, 15.509186033159494, 40.20986035466194, 61.06687277555466, 22.2203678637743, 9.601710475981236, 47.5547294318676, 59.52911429107189, 70.23277893662453, 89.52073395252228, 33.75229686498642, 0.24585789564298466, 0.5520463711582124, 0.8334299409762025, 16.85887075960636, 126.75201013684273, 110.7466533780098, 113.36608842015266, 103.07144522666931, 22.130821868777275, 0.2775276970351115, 11.736247837543488, 22.42896717041731, 64.80535537004471, 69.53363925218582, 70.51138758659363, 42.81918413937092, 41.19898147881031, 21.660122126340866, 0.4097658855607733, 0.1630737417144701, 0.22976354754064232, 0.12176954245660454, 0.14545105921570212, 0.1794201973825693, 0.23475940368371084, 0.17733704822603613, 0.08615633938461542, 0.1739082220592536, 0.3284417884424329, 0.12410945986630395, 0.20524993480648845, 0.13311850925674662, 0.13766097254119813, 0.21755070600192994, 0.14515189948724583, 0.19232004502555355, 0.1710769286728464, 0.21817976521560922, 0.1495276764035225, 0.40851376368664205, 0.11432188272010535, 4.986051125451922, 38.19515526294708, 74.5324382185936, 72.84488037228584, 74.43213880062103, 69.68918770551682, 59.3723651021719, 74.57518592476845, 69.21929731965065, 59.30872231721878, 69.52678442001343, 75.21453961730003, 75.36819577217102, 77.70137697458267, 72.11485594511032, 71.8631574511528, 66.1449582874775, 63.8047094643116, 63.094181790947914, 63.92061844468117, 60.696088671684265, 52.54082947969437, 51.97173781692982, 54.28004175424576, 51.43360309302807, 53.837996274232864, 52.58927308022976, 51.984976306557655, 54.73892793059349, 52.38557741045952, 52.23376415669918, 51.56806267797947, 52.89781652390957, 52.97418862581253, 50.23811124265194, 51.76102012395859, 55.239877849817276, 50.391774997115135, 49.7554687410593, 52.43973210453987, 51.59988597035408, 58.0619902163744, 61.62148721516132, 50.54795801639557, 55.31848043203354, 53.419194146990776, 55.36923050880432, 48.35306279361248, 47.803756669163704, 50.775694996118546, 54.42303568124771, 51.93838320672512, 54.76392678916454, 58.716429099440575, 59.90928389132023, 53.33920083940029, 50.98092578351498, 47.959293723106384, 47.40618780255318, 47.5424674898386, 49.932512640953064, 47.74161860346794, 48.508835434913635, 47.604590356349945, 49.42424811422825, 48.315532207489014, 53.656210228800774, 51.28445349633694, 53.033875823020935, 49.86779071390629, 52.36726999282837, 49.866134002804756, 51.41166687011719, 51.295051127672195, 55.33071957528591, 51.8193431943655, 55.747709199786186, 57.552209571003914, 55.56968115270138, 56.89348451793194, 59.913851246237755, 62.16534823179245, 64.0668497979641, 64.08519521355629, 63.038571774959564, 64.97700735926628, 65.57691916823387, 51.042588874697685, 55.07821172475815, 47.907612696290016, 46.657821759581566, 56.63425862789154, 70.76800301671028, 57.4359168112278, 27.25454293191433, 3.800667207688093, 0.39135581406299025, 0.4362613591365516, 0.08813092717900872, 0.18079977569868788, 0.26776444748975337, 0.5318842967972159, 0.9028531657531857, 0.5156199226621538, 0.5598271661438048, 0.5735926993656904, 0.1694071409292519, 0.21354867465561256, 0.11314551928080618, 0.13751289923675358, 0.14614946470828727, 0.12468256114516407, 0.2316494338447228, 0.21598247374640778, 0.12006175675196573, 0.09134019637713209, 0.10789253123220988, 0.10439310455694795, 0.25476807611994445, 3.2036527432501316, 41.791947260499, 35.15018865466118, 29.25462830811739, 35.47994635999203, 45.07121689617634, 31.451527923345566, 60.37983164191246, 69.31414783000946, 33.5473358631134, 10.811006985604763, 57.17166379094124, 70.43216943740845, 87.28313282132149, 118.11112180352211, 54.82401296496391, 0.3569553099805489], [0.3485659835860133, 0.21224371186690405, 6.783120520412922, 92.49021381139755, 91.8967616558075, 102.68489196896553, 68.14909234642982, 23.543152883648872, 6.510975798591971, 13.266761060804129, 34.918826669454575, 51.42285726964474, 67.16512754559517, 52.95316815376282, 21.356218233704567, 28.883840404450893, 10.614783614873886, 0.30262855638284236, 0.032198885892285034, 0.07260795115143992, 0.027007280878024176, 0.05593049761955626, 0.03587635750591289, 0.06477970324340276, 0.010722014358179877, 0.04696157615398988, 0.10744077109848149, 0.04312561890401412, 0.06330972391879186, 0.03821874255663715, 0.05351198306016158, 0.09514589997706935, 0.11976492736721411, 0.02145913884305628, 0.01097541511626332, 0.061231550862430595, 0.08617023238912225, 0.05893423644010909, 0.04858931752096396, 0.06025322581990622, 0.23063476954121143, 0.12899102526716888, 3.3116237120702863, 21.44486177712679, 40.923139080405235, 49.44867320358753, 50.666557252407074, 50.73284089565277, 56.82946175336838, 60.3406785428524, 68.32970425486565, 66.3355940580368, 65.14463156461716, 62.89340816438198, 63.94638106226921, 64.65037688612938, 58.69830787181854, 56.316945254802704, 53.82331766188145, 54.76583808660507, 55.130774304270744, 49.82194997370243, 49.55701678991318, 46.1439411342144, 47.17787325382233, 46.019862592220306, 48.34495782852173, 46.214260160923004, 47.548106387257576, 46.60166077315807, 48.6159972846508, 44.82322700321674, 47.645666152238846, 46.31234809756279, 46.178021505475044, 46.53075657784939, 43.3407973498106, 44.93983894586563, 47.72030174732208, 47.421896159648895, 52.0819167047739, 53.35122339427471, 48.163582161068916, 49.45509485900402, 49.712344855070114, 49.65618006885052, 44.64364103972912, 44.88746635615826, 49.031808972358704, 42.420125752687454, 46.067523434758186, 45.5391313880682, 47.05906502902508, 46.500783786177635, 48.005943819880486, 52.113363817334175, 46.8470174074173, 43.11911344528198, 44.84631836414337, 43.79464119672775, 41.80276907980442, 43.05949084460735, 43.72147612273693, 44.137565195560455, 44.22831952571869, 42.921406254172325, 44.38373498618603, 43.788314536213875, 44.02059227228165, 44.82144109904766, 45.811356380581856, 45.05332365632057, 44.256795197725296, 46.445549950003624, 46.2544734030962, 48.57076831161976, 54.6234293282032, 51.58320486545563, 49.252200946211815, 53.07042606174946, 54.865054562687874, 52.0437553524971, 52.62139655649662, 53.861904591321945, 55.03444567322731, 53.92003767192364, 48.89919228851795, 44.15923163294792, 35.25011569261551, 31.767593063414097, 26.806615367531776, 22.83024273812771, 10.835175588726997, 1.685259563382715, 0.472438950673677, 0.17238523112609982, 0.0642753545253072, 0.04496829737036023, 0.06693064016872086, 0.02667729047971079, 0.06360676110489294, 0.076417855307227, 0.07483522538677789, 0.1658365348703228, 0.01957027652679244, 0.19638355588540435, 0.033698480619932525, 0.08733392736758105, 0.04735431328299455, 0.02109577035298571, 0.05291834655508865, 0.061777727023581974, 0.04650030539778527, 0.05294896385748871, 0.06187517101352569, 0.050916009859065525, 0.062089926286716945, 0.07965948214405216, 0.06493415159638971, 2.756659216247499, 15.11622441932559, 28.948058858513832, 25.77938798815012, 2.1148408809676766, 3.8946036295965314, 0.7556173601187766, 7.348123602569103, 20.018180832266808, 17.17805553227663, 16.30464769899845, 20.546065606176853, 42.55420155823231, 43.80697913467884, 41.04738101363182, 4.4336106441915035, 0.1901764256763272, 0.423653160687536, 0.12903089344035834, 6.444458942860365, 97.70845860242844, 108.64254668354988, 103.65734338760376, 91.70926451683044, 38.5234310477972, 16.10098622739315, 27.492005489766598, 48.142151311039925, 66.20882526040077, 71.91605821251869, 57.16216430068016, 22.974669188261032, 39.17584843933582, 15.071326978504658, 0.4427340446272865, 0.027171007932338398, 0.016996740305330604, 0.08590046170866117, 0.041011952635017224, 0.024464484413329046, 0.09163281778455712, 0.053977888528606854, 0.031493070055148564, 0.010000996553571895, 0.03542937680322211, 0.04616701429768, 0.04652164956496563, 0.11360009215422906, 0.09035147013491951, 0.07767804432660341, 0.03019979423697805, 0.06613309116801247, 0.02467272919602692, 0.037679190063499846, 0.05793967691715807, 0.012149708891229238, 0.04705451901827473, 0.10985160814016126, 0.1017233841412235, 0.7751103141345084, 8.206069115549326, 24.52866230159998, 40.19088797271252, 52.063233107328415, 53.204403072595596, 65.23353919386864, 65.35461589694023, 68.60666379332542, 68.53430807590485, 67.63744220137596, 66.43184289336205, 64.68129962682724, 65.37670031189919, 60.1214113086462, 58.12637396156788, 56.499248072505, 57.731396555900574, 57.1626240760088, 49.783142656087875, 52.14218907058239, 48.48759077489376, 47.643770053982735, 48.316322565078735, 50.10639511048794, 48.982939794659615, 51.32201448082924, 50.68368673324585, 50.87117627263069, 46.45871244370937, 50.17222657799721, 48.190746903419495, 50.83399146795273, 48.28359492123127, 47.63256065547466, 49.72090199589729, 49.604924619197845, 49.39451090991497, 53.59657242894173, 54.27320212125778, 51.91205061972141, 52.06288352608681, 52.44716450572014, 52.56490498781204, 47.632511258125305, 47.24402770400047, 50.10386444628239, 46.589699015021324, 48.89387257397175, 51.375470012426376, 51.13974966108799, 50.347321182489395, 52.405142560601234, 54.293717220425606, 49.10702973604202, 44.103735610842705, 48.57525207102299, 46.11235722899437, 44.52844262123108, 45.554630756378174, 46.33880987763405, 46.49644821882248, 46.63857199251652, 46.937775537371635, 46.45030349493027, 45.79492226243019, 45.52750401198864, 45.0882475823164, 47.86758564412594, 45.60420289635658, 47.210217118263245, 49.09613952040672, 48.960190415382385, 52.47086763381958, 56.29082925617695, 54.05773848295212, 54.184845462441444, 56.6985359787941, 57.54832997918129, 56.70566439628601, 57.28042535483837, 58.20222169160843, 60.846746787428856, 58.28068748116493, 56.27688780426979, 52.52671703696251, 42.03017167747021, 36.75979748368263, 26.007166765630245, 19.49777215719223, 5.544648701325059, 0.30073512985836715, 0.2881480974610895, 0.08262992079835385, 0.048333643935620785, 0.059138753786101006, 0.03588699248211924, 0.045035662114969455, 0.06111777591286227, 0.07764823225443251, 0.04400848149089143, 0.11579006604733877, 0.10213596629910171, 0.16379138367483392, 0.006689210322292638, 0.09968104568542913, 0.0691663971520029, 0.044413000214262865, 0.04722510537249036, 0.04625964917067904, 0.030612812406616285, 0.05578710726695135, 0.029323258459044155, 0.09613677102606744, 0.06797381036449224, 0.08941116902860813, 0.15402923250803724, 5.231458581984043, 29.162112772464752, 29.881537668406963, 29.20615240931511, 19.719925336539745, 10.687922090291977, 3.2934770733118057, 19.7436398640275, 33.87131027877331, 35.189828127622604, 38.42969387769699, 30.81437811255455, 54.20501098036766, 56.11125469207764, 57.92337745428085, 2.641209061257541, 0.1298149724607356, 0.788640616228804, 0.5100941879209131, 9.755199439823627, 113.75075697898865, 115.90975552797318, 113.41936156153679, 106.71713680028915, 50.48011265695095, 20.48340506851673, 39.30379897356033, 60.85600309073925, 78.01999747753143, 85.21027565002441, 68.70703160762787, 33.32199655473232, 53.36323454976082, 21.15762948989868, 0.4152021766640246, 0.11670986903482117, 0.12495740811573341, 0.19167735998053104, 0.20650645019486547, 0.10917553387116641, 0.19921116821933538, 0.14282781950896606, 0.10977299243677408, 0.2822216326603666, 0.086666662391508, 0.16219825978623703, 0.08750307766604237, 0.38679163553752005, 0.1865249700495042, 0.10999634920153767, 0.1695659160031937, 0.23910666728625074, 0.15929833258269355, 0.20085738535271958, 0.13983297161757946, 0.20622761046979576, 0.41292488167528063, 0.488001549965702, 0.22194316639797762, 5.803175903856754, 30.694224759936333, 51.81810826063156, 62.432777881622314, 64.3381704390049, 55.188075229525566, 67.35064879059792, 68.6456649005413, 71.4921909570694, 72.92166665196419, 69.71140131354332, 67.90297955274582, 66.4317212998867, 69.17822912335396, 62.585742473602295, 59.05931130051613, 59.74480211734772, 61.24207377433777, 58.77429619431496, 53.40397596359253, 54.048645570874214, 49.98840384185314, 50.53410395979881, 53.796304911375046, 53.47780600190163, 52.21604570746422, 52.94388145208359, 53.58690954744816, 54.468040466308594, 49.39777873456478, 54.69659820199013, 51.42228350043297, 52.01664760708809, 52.621366158127785, 49.32666935026646, 52.228733226656914, 50.716877952218056, 53.399830386042595, 57.19171151518822, 60.383908823132515, 52.69250214099884, 53.85606810450554, 53.71568463742733, 57.49800927937031, 51.0985142737627, 49.61990341544151, 54.78581361472607, 48.365526124835014, 51.082026958465576, 51.16304621100426, 52.35032670199871, 52.48918265104294, 55.970723032951355, 57.486541494727135, 51.17296367883682, 46.95796765387058, 49.90816354751587, 49.77572925388813, 47.55902700126171, 47.0511120557785, 48.408342227339745, 50.806883722543716, 49.77153807878494, 50.28057016432285, 48.67231786251068, 48.28265257179737, 51.09477527439594, 47.70227551460266, 53.08856248855591, 47.77332790195942, 51.42699904739857, 52.24409960210323, 51.37535601854324, 54.71330590546131, 60.24466909468174, 57.047577649354935, 55.838759914040565, 57.44751758873463, 59.10514444112778, 57.64318808913231, 58.18193458020687, 59.56631429493427, 63.31985168159008, 63.70339170098305, 61.71286851167679, 62.347472459077835, 54.34176944196224, 51.06330156326294, 44.980120584368706, 33.18883270025253, 16.39713853597641, 3.1272929906845093, 0.747416450176388, 0.41581617027986795, 0.15913036972051486, 0.11690549916238524, 0.2975877112476155, 0.10372716060373932, 0.20665146585088223, 0.26184092159383, 0.22851025307318196, 0.2098281102371402, 0.19942824641475454, 0.2910080971196294, 0.2071125473594293, 0.23841654416173697, 0.12027539880364202, 0.12574516818858683, 0.18690689408686012, 0.2181094986735843, 0.11077047602157108, 0.09178596737910993, 0.13031234499067068, 0.2485952925053425, 0.2274830316309817, 0.11925032216822729, 0.3620111761847511, 5.810295771807432, 46.63172855973244, 37.86199674010277, 49.174149334430695, 24.868459068238735, 16.976799331605434, 5.196393588557839, 50.84477908909321, 49.16803926229477, 47.03244365751743, 55.400901809334755, 47.002071887254715, 82.1911096572876, 83.30952644348145, 101.08146920800209, 8.154558129608631, 0.4149317677365616], [0.10403104781289585, 0.15165287564741448, 2.682809941470623, 63.059881031513214, 96.53394922614098, 82.530857026577, 63.82490158081055, 63.04582558572292, 65.64786896109581, 55.15503600239754, 70.98004683852196, 67.76337504386902, 79.54813107848167, 62.55066655576229, 15.747664086520672, 17.674350701272488, 6.819002944976091, 0.47671609616372734, 0.10389111586846411, 0.04573508063913323, 0.041145004870486446, 0.03261695252149366, 0.03938667148759123, 0.032615512755000964, 0.08743464422877878, 0.03129125412669964, 0.11450710793724284, 0.026231482370349113, 0.034084260114468634, 0.040257860091514885, 0.028663658013101667, 0.021781659525004216, 0.0964751755236648, 0.09288614193792455, 0.029147072600608226, 0.024969172663986683, 0.033530762666487135, 0.06009743417962454, 0.05461917462525889, 0.11654803631245159, 0.08520264251274057, 0.16629184246994555, 0.10132745577720925, 0.17292232339968905, 0.4424083308549598, 3.8891340605914593, 14.307143334299326, 28.583990894258022, 44.87622655928135, 55.63260577619076, 58.550336211919785, 63.18263344466686, 64.09904167056084, 64.12359595298767, 60.52583880722523, 62.31552757322788, 57.72130809724331, 56.71076752245426, 56.64962500333786, 60.44528312981129, 58.18190798163414, 52.65374802052975, 47.051967009902, 46.889780312776566, 46.06995150446892, 47.296020314097404, 48.262779638171196, 46.40991546213627, 47.14936338365078, 46.53878554701805, 46.31390601396561, 46.20014391839504, 46.53278946876526, 47.34799012541771, 44.783165752887726, 45.1389292627573, 45.282018184661865, 45.93655966222286, 45.88263675570488, 47.91796334087849, 50.32929114997387, 50.95973812043667, 54.52943377196789, 50.13441860675812, 50.71916922926903, 48.24186936020851, 45.82086347043514, 48.24704848229885, 47.55567938089371, 47.210920080542564, 47.95677825808525, 48.78479182720184, 48.98712337017059, 50.289043709635735, 46.61455348134041, 48.20649705827236, 46.83312155306339, 41.859215050935745, 45.92146307229996, 42.83231623470783, 41.15773469209671, 42.10649438202381, 41.89773738384247, 45.14337882399559, 42.94331207871437, 41.57991483807564, 43.89210596680641, 43.87873828411102, 40.1833301782608, 44.5794814825058, 43.53142932057381, 44.97798889875412, 45.83018057048321, 47.59358614683151, 43.41933913528919, 51.854160726070404, 54.5574838668108, 54.51010800898075, 56.148865073919296, 57.435305044054985, 56.82959474623203, 55.523707419633865, 56.69649928808212, 56.52843050658703, 54.3730341643095, 53.03233690559864, 37.29407921433449, 22.903806790709496, 12.214986998587847, 3.640034389682114, 1.3149117236025631, 0.5416834366042167, 0.19687659427290782, 0.11957754992181435, 0.08607832482084632, 0.03821532867732458, 0.036513977393042296, 0.07961138355312869, 0.02427481929771602, 0.05323391145793721, 0.0597227497928543, 0.030298948877316434, 0.02317702517757425, 0.07007555032032542, 0.03227252920623869, 0.06255576125113294, 0.028036738040100317, 0.0271461979355081, 0.019610421149991453, 0.06074426411942113, 0.012158690733485855, 0.05787237525510136, 0.03972377351601608, 0.011596714248298667, 0.0665411091176793, 0.018819284305209294, 0.07163805319578387, 0.13128169375704601, 0.049288643276668154, 5.066787293180823, 18.557026237249374, 28.61091624945402, 16.373811587691307, 1.9689177861437201, 1.8887052778154612, 2.1479302179068327, 19.026939421892166, 27.491756603121758, 10.866287369281054, 10.244797468185425, 15.786068625748158, 21.307833530008793, 19.458064287900925, 10.966672282665968, 0.09688969468697906, 0.08743563128518872, 0.06764641191693954, 0.1090270301210694, 1.4135730732232332, 61.13781496882439, 107.36225858330727, 89.7766426205635, 67.21393972635269, 80.39044708013535, 78.64747300744057, 61.28987900912762, 86.8316638469696, 91.40702873468399, 90.03125935792923, 78.61464276909828, 20.481949746608734, 32.75474399328232, 12.34986836090684, 0.594272258458659, 0.1074429381696973, 0.029913941216364037, 0.02839454413333442, 0.03665709686174523, 0.03508680143568199, 0.06254289241041988, 0.0574891079304507, 0.04878733365330845, 0.05345897145161871, 0.04799703172466252, 0.013009875674470095, 0.052537454103003256, 0.01582774639246054, 0.09011096233734861, 0.10984728141920641, 0.09330608620075509, 0.016796627605799586, 0.026754952523333486, 0.011721755927283084, 0.024401307236985303, 0.0232291796055506, 0.064202141657006, 0.04005121278169099, 0.09794508805498481, 0.20309703861130401, 0.21048378286650404, 0.4388715815730393, 1.3588285795412958, 4.705726867541671, 19.62472714483738, 47.5055106729269, 63.90071511268616, 65.32461270689964, 65.65740644931793, 67.55882441997528, 68.05855840444565, 63.79410803318024, 63.12207229435444, 61.59792087972164, 61.18412688374519, 61.47634260356426, 65.00409990549088, 60.08606940507889, 57.34906107187271, 50.5026226490736, 49.99750815331936, 50.48080801963806, 49.39090870320797, 50.86846701800823, 50.36793887615204, 49.90082614123821, 50.01286692917347, 49.06007565557957, 48.93337905406952, 48.99823397397995, 50.12663282454014, 47.110822051763535, 49.308874905109406, 45.91893620789051, 48.44409070909023, 48.64611826837063, 51.16461172699928, 53.15466374158859, 54.348092302680016, 57.33708791434765, 51.011837124824524, 53.64509582519531, 52.62246049940586, 47.61967174708843, 52.019174471497536, 52.01552286744118, 47.81753093004227, 49.33618023991585, 50.605597123503685, 50.602785274386406, 54.84255596995354, 51.47913224995136, 47.78862588107586, 49.26193222403526, 44.135695695877075, 46.5630966424942, 45.3492745757103, 43.64609956741333, 44.42074120044708, 44.96666930615902, 46.49709418416023, 46.921371817588806, 45.695128217339516, 45.84270849823952, 45.76928123831749, 45.053737834095955, 47.5442685931921, 46.9881684333086, 46.017339527606964, 48.8129673153162, 49.201359674334526, 46.97734661400318, 57.216406390070915, 59.4881296902895, 56.97512313723564, 59.252413138747215, 58.60902786254883, 58.78018967807293, 60.05133926868439, 59.3270069360733, 60.44103875756264, 60.2919689565897, 56.90728157758713, 35.97129039466381, 19.91256359964609, 8.23278073221445, 1.6800737916491926, 0.6063848803751171, 0.591014705132693, 0.14926636620657519, 0.10570429396466352, 0.06877889216411859, 0.01705655740806833, 0.08446576408459805, 0.04784820142958779, 0.03797548881266266, 0.0034095168757630745, 0.03731933007657062, 0.027870906997122802, 0.04274547602108214, 0.022725999770045746, 0.039251366833923385, 0.06322505229036324, 0.05780619052529801, 0.16018515452742577, 0.010998424477293156, 0.01605390105396509, 0.04889100797299761, 0.0293788657290861, 0.06952115858439356, 0.051158514033886604, 0.22111224301625043, 0.08669804781675339, 0.037873039036639966, 0.16800697543658316, 0.45942099764943123, 9.693742487579584, 28.483113907277584, 36.14806450903416, 24.891181848943233, 5.9068642649799585, 2.7754147723317146, 2.3819190496578813, 28.98849818855524, 31.14158995449543, 15.824299324303865, 13.926023785024881, 32.39022575318813, 32.22756788134575, 20.562161542475224, 4.782714061439037, 0.07713746395893395, 0.1264554777299054, 0.37231800437439233, 0.27312002261169255, 3.3277714205905795, 82.64203906059265, 119.4924920797348, 109.96027797460556, 70.74304595589638, 88.8676705956459, 85.00406831502914, 71.57695680856705, 100.20403549075127, 113.7813301384449, 97.71695494651794, 81.20038121938705, 26.16909507662058, 42.78702266514301, 20.15665490180254, 0.5927434342447668, 0.29225440055597574, 0.19964369188528508, 0.176412629080005, 0.14689354196889326, 0.23266485513886437, 0.23540795169537887, 0.1596484481706284, 0.11605338746448979, 0.12319076267885976, 0.1467299132491462, 0.13469048193655908, 0.18216320488136262, 0.09954459441360086, 0.09064942758413963, 0.2188686266890727, 0.3680497646564618, 0.1230689614021685, 0.21049228787887841, 0.16223049868131056, 0.18421585176838562, 0.08262954230303876, 0.1294114370830357, 0.2017935601179488, 0.20564238249789923, 0.4314507875824347, 0.3256782976677641, 0.9306069952435791, 6.956019792705774, 27.983583211898804, 56.62464514374733, 66.32968917489052, 69.98559460043907, 69.44166898727417, 67.90256157517433, 68.24495360255241, 67.86799103021622, 67.71081626415253, 65.20210728049278, 62.18761503696442, 59.440750032663345, 61.292405873537064, 66.98819383978844, 62.56857119500637, 56.94108836352825, 53.17431628704071, 51.61732703447342, 52.69543178379536, 51.068047508597374, 54.011403769254684, 53.7664233148098, 50.603085458278656, 52.95534163713455, 51.72140344977379, 51.670463383197784, 52.33320862054825, 55.37695549428463, 50.12200467288494, 52.16324754059315, 48.16067151725292, 49.56069119274616, 51.063905730843544, 52.29018732905388, 56.14371255040169, 56.20773911476135, 59.0981338173151, 52.939823269844055, 57.66531050205231, 54.781877025961876, 52.19556100666523, 53.85732203722, 53.36848966777325, 51.61008462309837, 53.281690925359726, 51.44451230764389, 52.640239745378494, 56.471334770321846, 53.446795865893364, 53.180536553263664, 52.374409809708595, 45.65576992928982, 50.43248601257801, 49.407548010349274, 46.45023129880428, 46.2184589356184, 47.661211118102074, 48.59677031636238, 50.354943573474884, 48.81576396524906, 48.665254041552544, 49.39656659960747, 44.835507944226265, 50.83873741328716, 48.266131058335304, 49.16778087615967, 51.98042035102844, 52.12302289903164, 49.172108843922615, 57.64402024447918, 60.87723635137081, 59.69861179590225, 60.14591999351978, 62.92292878031731, 60.93726173043251, 61.39126516878605, 61.75563141703606, 61.63292460143566, 61.272255554795265, 62.36505411565304, 50.43801471590996, 37.949897423386574, 19.664852991700172, 5.262488191947341, 1.5804020524956286, 0.6796589016448706, 0.6118346785660833, 0.3104861784959212, 0.1291936167399399, 0.3528486506547779, 0.2698194544063881, 0.16320152470143512, 0.1739626214839518, 0.09430411897483282, 0.309076810372062, 0.1588204043218866, 0.17785520089091733, 0.15224513917928562, 0.21117289667017758, 0.2013893419643864, 0.27796488138847053, 0.2879171707900241, 0.12644110975088552, 0.19629427551990375, 0.21670735906809568, 0.15328597160987556, 0.15108197112567723, 0.23455506074242294, 0.3246058349031955, 0.2646386402193457, 0.3427125758025795, 0.5638842203188688, 0.7688779360614717, 13.024242874234915, 39.95565019547939, 52.348058223724365, 51.430411264300346, 6.80521965958178, 2.6978751830756664, 3.814653307199478, 43.21441613137722, 57.26222813129425, 27.250013574957848, 36.65356658399105, 62.013143599033356, 75.32053112983704, 65.59768125414848, 27.32128255069256, 0.25523479795083404, 0.31256330141332], [0.10237471520667896, 0.2704416116466746, 0.8463059063069522, 29.689134992659092, 75.5072683095932, 87.2471259534359, 71.8788506090641, 42.98491604626179, 40.65948262810707, 24.43767998367548, 26.41635160893202, 35.07665880024433, 46.47094778716564, 27.725345268845558, 30.13845708221197, 29.405793696641922, 7.606345396488905, 0.6976241001393646, 0.1292307092808187, 0.036807904980378225, 0.050828944804379717, 0.05464113477501087, 0.04825288713618647, 0.08790114341536537, 0.10127257395652123, 0.07484550413209945, 0.023214347784232814, 0.058977874723495916, 0.029179849552747328, 0.046484052363666706, 0.027453810726001393, 0.02491157272743294, 0.05358361144317314, 0.018214556403108872, 0.037023339318693615, 0.05962480485322885, 0.03688617558509577, 0.03479607250483241, 0.023061376305122394, 0.039262773643713444, 0.0790988266817294, 0.05857906311575789, 0.09977524649002589, 0.03835502684523817, 0.11351672670571133, 0.40962312603369355, 0.6399344082456082, 2.891530841588974, 14.663721900433302, 38.73786114156246, 55.136417001485825, 65.15473142266273, 63.84242624044418, 64.67863976955414, 65.54431691765785, 66.0158260166645, 64.47628542780876, 59.70107786357403, 65.03728732466698, 60.69784797728062, 62.64156147837639, 62.7347856760025, 54.71168339252472, 47.570563182234764, 47.031003534793854, 46.545777171850204, 47.2016903758049, 45.981864631175995, 46.82954214513302, 46.428504064679146, 47.229862064123154, 45.19468367099762, 46.04606218636036, 44.33056443929672, 47.13764101266861, 43.358561396598816, 43.55126805603504, 43.90557624399662, 45.960262790322304, 46.794002652168274, 47.610670030117035, 55.182937905192375, 53.61381970345974, 49.80725236237049, 53.04863043129444, 47.69754856824875, 46.66859418153763, 49.93616044521332, 52.077767327427864, 49.29205700755119, 44.82302941381931, 49.04215581715107, 46.909383460879326, 49.6382412314415, 50.01103162765503, 47.74248115718365, 44.763418212533, 45.11296525597572, 42.441119626164436, 40.53654782474041, 40.21318897604942, 41.39364883303642, 43.25296126306057, 44.7346081584692, 42.27959029376507, 42.92334035038948, 43.04574318230152, 41.62659913301468, 42.212881073355675, 43.81979964673519, 42.78147496283054, 44.037706553936005, 45.850106701254845, 45.10697677731514, 49.11591365933418, 57.98691764473915, 57.47616805136204, 56.97546511888504, 52.991394102573395, 52.48216822743416, 55.09679272770882, 56.3900039345026, 55.11071518063545, 54.90581877529621, 42.403114065527916, 32.56961792707443, 9.07232953235507, 1.1389081366360188, 0.511043305741623, 0.5586850899271667, 1.6435658256523311, 0.6791395170148462, 0.26488749717827886, 0.11744093644665554, 0.0555473638814874, 0.08839885733323172, 0.016171394163393416, 0.07097987952874973, 0.06879875945742242, 0.019978763884864748, 0.03257975979067851, 0.06395710675860755, 0.035445229077595286, 0.07256073571625166, 0.0314081646502018, 0.12459406745620072, 0.09173643644317053, 0.031391351294587366, 0.07931777508929372, 0.03254563212976791, 0.00473176521154528, 0.06981963553698733, 0.050191499321954325, 0.030681071439175867, 0.11728455850970931, 0.13241397362435237, 0.028736112035403494, 0.2274489076808095, 0.3880531678441912, 10.525814238935709, 18.42465654015541, 14.143227729946375, 3.266110229305923, 0.6117283436469734, 0.864976798184216, 2.0456867292523384, 11.754539106041193, 30.64071223139763, 19.719478860497475, 9.067584536969662, 5.256301173940301, 9.06841479241848, 8.197757061570883, 0.11096120797446929, 0.11703186464728788, 0.12385771595290862, 0.07144674978917465, 0.35626668599434197, 0.7993614440783858, 16.412176229059696, 85.5354318022728, 90.60119077563286, 87.30996698141098, 47.818651869893074, 56.17911905050278, 54.69026394188404, 41.56318053603172, 51.136067658662796, 62.187254056334496, 33.248706087470055, 29.693708047270775, 42.103538140654564, 13.790147826075554, 1.123058118391782, 0.20320629759225994, 0.07766360213281587, 0.02723677891481202, 0.031047581069287844, 0.03256186289945617, 0.06193341105245054, 0.06773625631467439, 0.0031923677124723326, 0.05094126514450181, 0.019059207661484834, 0.03281420795246959, 0.04529286081378814, 0.013256384663691279, 0.04044311499455944, 0.08955556128057651, 0.05513369447726291, 0.06844468822237104, 0.009370185871375725, 0.07318904536077753, 0.04398585340823047, 0.035644228555611335, 0.04808874633454252, 0.02222710769274272, 0.06350658601149917, 0.08698559293407016, 0.029349949800234754, 0.04147038467635866, 0.31897703069262207, 0.526759143685922, 1.575765588786453, 9.682002067565918, 35.392110273242, 60.536368042230606, 66.91429540514946, 67.54839777946472, 71.10388979315758, 71.17341086268425, 68.50283816456795, 66.11791133880615, 64.28113549947739, 66.04808628559113, 63.73163938522339, 62.66817145049572, 66.27031356096268, 57.77194418013096, 50.576768070459366, 49.33534808456898, 48.58356222510338, 48.66050809621811, 47.9463592171669, 49.853081703186035, 49.51738491654396, 49.73619617521763, 48.4806789457798, 50.73440261185169, 46.86806447803974, 49.23705875873566, 46.157571002840996, 46.990357115864754, 46.19808442890644, 49.721665754914284, 50.59567965567112, 52.14188128709793, 56.362755596637726, 54.76961888372898, 50.233323499560356, 53.88439558446407, 51.26862354576588, 50.39312772452831, 51.83934532105923, 54.004655331373215, 51.31650857627392, 48.34503002464771, 52.367566376924515, 48.28647516667843, 50.92553995549679, 53.2409381121397, 51.48078516125679, 47.75874428451061, 47.06363998353481, 44.499951750040054, 45.32916605472565, 43.16338486969471, 44.0881222486496, 45.59250332415104, 47.0694612711668, 44.92787718772888, 43.579097762703896, 45.83874151110649, 43.762768507003784, 46.735143810510635, 47.13331684470177, 46.558829471468925, 48.08705426752567, 47.382613867521286, 47.317869141697884, 53.884380385279655, 61.457583010196686, 61.665906831622124, 59.82580617070198, 56.86079867184162, 55.142523273825645, 57.961907386779785, 57.393921464681625, 57.48946353793144, 57.2975168377161, 43.53458695113659, 26.149807311594486, 4.39668707549572, 0.5465702712535858, 0.9291277464944869, 0.7224177103489637, 1.616223561577499, 1.1097936239093542, 0.16943964699748904, 0.05851434041687753, 0.08328726325999014, 0.07093599633662961, 0.03796194461756386, 0.016430795185442548, 0.06252373015740886, 0.07708380668191239, 0.0137867493685917, 0.0653471345140133, 0.07851595873944461, 0.01653028193686623, 0.01571581011376111, 0.07438994420226663, 0.07493082142900676, 0.1298193511320278, 0.047491528966929764, 0.08890554381650873, 0.06824588170275092, 0.04675383788708132, 0.1022221296443604, 0.09663090779213235, 0.03549081178789493, 0.016574905421293806, 0.16449131799163297, 0.18352654500631616, 0.8103335928171873, 14.722063019871712, 26.99777740985155, 26.06220491230488, 10.396096799522638, 3.0637499503791332, 0.7021742966026068, 3.246078179217875, 27.417491488158703, 54.16503332555294, 24.98105652630329, 34.57651063799858, 21.222032234072685, 8.52767150849104, 3.1302622938528657, 0.02005890284635825, 0.07690723490668461, 0.1213297902722843, 0.42699712968897074, 0.7728763902559876, 1.323851456400007, 39.20120447874069, 100.6265576183796, 106.37610509991646, 106.70056968927383, 54.592905566096306, 62.786196917295456, 68.60049292445183, 56.95627994835377, 67.53270462155342, 75.72314232587814, 40.40184125304222, 41.758155673742294, 53.16333867609501, 25.39821144193411, 1.2230125861242414, 0.2531878656009212, 0.22718574211467057, 0.23251143837114796, 0.1938409431022592, 0.13410179555648938, 0.13605235260911286, 0.1755778762162663, 0.21122499543707818, 0.17718156828777865, 0.14850441802991554, 0.13556054618675262, 0.18339534814003855, 0.10801852564327419, 0.08450368040939793, 0.16938394139287993, 0.09486127892159857, 0.14549334679031745, 0.16056535678217188, 0.09899430675432086, 0.11939183488721028, 0.11286354027106427, 0.11423412375734188, 0.1865627898951061, 0.2034131935215555, 0.28363022895064205, 0.24856456759152934, 0.21434148133266717, 0.7850047457031906, 0.612561923917383, 4.806815693154931, 27.11587507277727, 54.65468645095825, 68.37677612900734, 72.54677876830101, 68.24861660599709, 69.55226585268974, 70.72374299168587, 70.78898549079895, 67.242840975523, 65.82696855068207, 68.85321736335754, 65.15612974762917, 67.05335274338722, 68.01578789949417, 60.659420639276505, 52.26556085050106, 52.409911304712296, 52.26596362888813, 53.32122780382633, 50.8239334076643, 51.7794643342495, 51.69532164931297, 54.30918999016285, 51.93953074514866, 53.50715182721615, 50.264622420072556, 53.34189489483833, 48.85219261050224, 49.655184522271156, 49.092058539390564, 51.215266808867455, 51.01744182407856, 52.575403824448586, 60.949227288365364, 59.59837697446346, 54.00490611791611, 58.60538765788078, 53.184096962213516, 52.35718913376331, 53.353533670306206, 56.3324636220932, 54.44018796086311, 50.647683665156364, 55.318374037742615, 50.52318334579468, 52.81438060104847, 55.909496918320656, 55.358412489295006, 50.443182438611984, 52.62380562722683, 47.73616589605808, 47.10977330803871, 46.86115264892578, 45.85220418870449, 47.78586342930794, 49.89288456737995, 48.83652985095978, 45.76607421040535, 48.79105769097805, 46.988943591713905, 48.197882920503616, 49.24067996442318, 50.31673662364483, 51.56478725373745, 50.082209408283234, 49.33741137385368, 52.484318912029266, 62.45032534003258, 63.42673234641552, 60.570539608597755, 59.82664592564106, 55.04929907619953, 58.655940145254135, 62.188952565193176, 60.756851211190224, 59.233281165361404, 46.61930322647095, 39.96598944067955, 13.93943801522255, 2.2218056162819266, 0.8924442180432379, 0.5027865862939507, 2.3320220271125436, 1.4902294473722577, 0.2389552246313542, 0.23228014062624425, 0.2262617534142919, 0.21232542232610285, 0.06654850833001547, 0.18384296708973125, 0.24655213026562706, 0.2733203727984801, 0.13171757193049416, 0.1693266921211034, 0.19921980681829154, 0.1281907525844872, 0.09105913763050921, 0.3248210874153301, 0.11571392911719158, 0.31969554838724434, 0.2564409066690132, 0.2208391623571515, 0.1708278342266567, 0.17470473947469145, 0.14320408838102594, 0.1709444701555185, 0.1879242598079145, 0.31224545440636575, 0.2564505545888096, 0.5513183539733291, 0.8467745874077082, 20.761768631637096, 38.71883936226368, 45.09174719452858, 20.430806390941143, 5.540538746863604, 2.008304810151458, 12.210609633475542, 32.48771332204342, 59.63906139135361, 51.384137347340584, 86.08722299337387, 56.062837690114975, 25.729654356837273, 14.896628502756357, 0.3490785404574126, 0.31674554105848074, 0.39569550775922835], [0.0511183007620275, 0.08331472272402607, 0.0682750555279199, 1.8033789563924074, 54.81530383229256, 55.66855564713478, 78.12677934765816, 67.62333735823631, 29.115722961723804, 8.685184456408024, 6.556932432577014, 9.59623496979475, 15.174715630710125, 33.53090934455395, 71.91300317645073, 60.49858666956425, 3.5767155373468995, 1.2949952110648155, 0.15149877610383555, 0.05696607935533393, 0.03824823179456871, 0.01778279158315854, 0.030599893470935058, 0.01656348933465779, 0.040673340336070396, 0.10792759770993143, 0.018597634480101988, 0.062164267219486646, 0.0938782597950194, 0.012461944334063446, 0.0928569606912788, 0.098103818600066, 0.09409711172338575, 0.11391681851819158, 0.08337027989909984, 0.03868536419759039, 0.01885046007373603, 0.037059878959553316, 0.027509102583280765, 0.03140838358376641, 0.08135736017720774, 0.20657121000112966, 0.08982158411527053, 0.04494598470046185, 0.05099194269860163, 0.1337101196986623, 0.0630665963399224, 1.4248152449727058, 1.3856418407522142, 7.896713465452194, 31.39299776405096, 54.35306243598461, 63.82421001791954, 64.32654306292534, 68.05915877223015, 64.72397893667221, 63.046315759420395, 60.49671337008476, 61.69137306511402, 58.61424878239632, 59.81413699686527, 61.43603436648846, 62.076170817017555, 52.185882925987244, 46.93374775350094, 45.156142339110374, 44.640293419361115, 45.93343622982502, 45.764193311333656, 45.169897601008415, 44.58500258624554, 45.6643308699131, 45.92455990612507, 43.31307403743267, 43.113189563155174, 42.41427406668663, 45.11527173221111, 44.97241459786892, 44.84484784305096, 46.63140557706356, 50.17777428030968, 49.78031940758228, 48.991010561585426, 45.64585246145725, 49.20822970569134, 47.22785957157612, 51.86537392437458, 53.342316672205925, 52.126682102680206, 50.07544957101345, 49.20815750956535, 47.52959758043289, 45.78962154686451, 46.57393366098404, 48.495311960577965, 47.176106348633766, 44.99425582587719, 44.370751082897186, 42.54790149629116, 42.04202704131603, 42.841690331697464, 43.41748483479023, 42.68242567777634, 43.1141547113657, 43.65349777042866, 41.83100916445255, 42.31193035840988, 42.907840982079506, 43.62044334411621, 43.67443084716797, 43.89453023672104, 42.64542706310749, 47.536718398332596, 49.3088711053133, 60.4629597812891, 56.33783273398876, 57.287082597613335, 52.28872440755367, 51.0610406845808, 53.26895400881767, 56.000289246439934, 53.39419148862362, 53.51553797721863, 49.51700113713741, 28.5264315828681, 5.045932587236166, 0.3499864542391151, 0.5306490662042052, 0.8223611349239945, 0.6006488506682217, 0.050873733416665345, 0.02374630068516126, 0.061749269370920956, 0.05832292568811681, 0.037372649676399305, 0.052996357408119366, 0.03693264145113062, 0.03855419701721985, 0.041120090972981416, 0.04544722381979227, 0.10226469923509285, 0.02052411626209505, 0.0017595459826225124, 0.03175036523316521, 0.03185355344612617, 0.046280288297566585, 0.05676240434695501, 0.06682052029646002, 0.03445443224336486, 0.12124201646656729, 0.018010200474236626, 0.06149561071651988, 0.025602909263398033, 0.11132298270240426, 0.023315337384701706, 0.08119410995277576, 0.06058664308511652, 0.12783395766746253, 1.1147990240715444, 12.046931516379118, 18.532057777047157, 5.71549323387444, 0.9966418705880642, 0.749044781550765, 0.5504107964225113, 2.7406542375683784, 9.710678178817034, 33.20619396865368, 29.79196697473526, 15.344272032380104, 3.1959424819797277, 0.2952315111178905, 0.1731736442889087, 0.043040876771556213, 0.19831640529446304, 0.03787364388699643, 0.07379785136436112, 0.06926142174052075, 0.0744792542536743, 0.9668900608085096, 36.54100902378559, 63.388646990060806, 83.92783686518669, 76.55578404664993, 34.47137027978897, 26.382202841341496, 25.42900498956442, 26.40213657170534, 39.568200185894966, 48.072444051504135, 66.4842800796032, 70.40802553296089, 16.068980544805527, 2.0731027331203222, 0.2209257858339697, 0.12004603806417435, 0.03589757550798822, 0.08640815751277842, 0.06629399620578624, 0.06795029912609607, 0.019552858320821542, 0.03955163236241788, 0.02083303337713005, 0.015831356940907426, 0.031044952011143323, 0.04470099804166239, 0.04969036039256025, 0.051833668039762415, 0.0509410462109372, 0.14263374789152294, 0.024315271912200842, 0.06579977038200013, 0.046137220779201016, 0.020193962591292802, 0.03821061603957787, 0.03489477443508804, 0.009753302911121864, 0.014536174730892526, 0.06169511114421766, 0.09104421304073185, 0.05244434796622954, 0.1048994941811543, 0.2133247983874753, 1.4015684486366808, 0.6958817155100405, 5.331592708826065, 20.078160613775253, 54.96151998639107, 65.20118772983551, 66.47263750433922, 69.4660484790802, 66.72419160604477, 66.7127314209938, 62.38108925521374, 64.2868123948574, 62.045806646347046, 62.18334786593914, 64.30568218231201, 64.95053797960281, 57.71551340818405, 51.20306186378002, 47.18783251941204, 47.6180986315012, 47.85655863583088, 50.125823467969894, 48.14971290528774, 47.752014845609665, 48.88713173568249, 47.849145233631134, 46.060558408498764, 45.38757272064686, 46.951040625572205, 46.625629886984825, 47.86563254892826, 48.85097287595272, 49.800180941820145, 51.173583045601845, 50.214670300483704, 52.663144916296005, 47.88789555430412, 49.29563261568546, 50.58261215686798, 55.205174311995506, 54.941134080290794, 57.039586678147316, 52.77843452990055, 52.341275587677956, 49.19135861098766, 48.465555757284164, 48.02980273962021, 48.900514617562294, 47.37645819783211, 47.277405112981796, 46.35103762149811, 45.992678850889206, 44.736086279153824, 45.45420594513416, 44.32793118059635, 46.13468863070011, 44.898166581988335, 45.01995384693146, 43.85756962001324, 44.233521446585655, 47.306302562355995, 45.19765891134739, 46.9676723331213, 46.150590777397156, 48.30024562776089, 49.71846252679825, 52.965608686208725, 61.94004312157631, 60.23182198405266, 58.696362376213074, 55.12892000377178, 55.496413484215736, 59.71555508673191, 58.36328364908695, 53.478174582123756, 57.617835849523544, 50.56259483098984, 24.33518998324871, 2.220699400641024, 0.46723869221750647, 0.855311838677153, 0.46414586598984897, 0.0957725101034157, 0.11678819530061446, 0.13817361847031862, 0.05925831377680879, 0.09412591447471641, 0.055926356435520574, 0.05581851124588866, 0.024105104967020452, 0.05125806201249361, 0.07503435102989897, 0.07718847919022664, 0.01465742589061847, 0.0648442997771781, 0.01951501064468175, 0.027773123474617023, 0.035055638654739596, 0.03849849141261075, 0.031003204348962754, 0.054763967636972666, 0.020010915577586275, 0.0568029961141292, 0.05630687410302926, 0.004730508662760258, 0.07089628401445225, 0.028222456785442773, 0.029894795661675744, 0.005814203368572635, 0.05763344081060495, 0.17630783782806247, 2.1857809368520975, 19.741827361285686, 29.17367935180664, 13.524881210178137, 4.377439208328724, 2.7756040496751666, 0.7809398544486612, 4.179428983479738, 24.474541805684566, 51.548626720905304, 44.951899498701096, 32.846151888370514, 5.944880750030279, 1.20578502304852, 0.1339004805777222, 0.020462510583456606, 0.05907619073695969, 0.049964120116783306, 0.21858284046174958, 0.19641848135506734, 0.2823158854153007, 2.4142234912142158, 89.52867552638054, 82.15099900960922, 116.28239393234253, 107.15995743870735, 59.681318923830986, 38.62507939338684, 46.023506596684456, 41.181183233857155, 54.50458690524101, 61.61352664232254, 91.96334928274155, 84.32731702923775, 29.40372660756111, 3.325038654729724, 0.5373942386358976, 0.1429299241863191, 0.20950229256413877, 0.12155703589087352, 0.18306712590856478, 0.14963996334699914, 0.27521445241291076, 0.27916119375731796, 0.09335077833384275, 0.16420047031715512, 0.17875075049232692, 0.11369821149855852, 0.2040503273019567, 0.1949527842225507, 0.23451044282410294, 0.29450859990902245, 0.24803831067401916, 0.13191146543249488, 0.17566914553754032, 0.12055211598635651, 0.1473309934954159, 0.08031496181502007, 0.19920867460314184, 0.20280046155676246, 0.16738646576413885, 0.14824095560470596, 0.21783811011118814, 0.5055546190124005, 1.4249966852366924, 1.8935317313298583, 1.9372325926087797, 11.793067138642073, 36.63889937102795, 61.85158386826515, 68.75115483999252, 68.63565623760223, 72.59214833378792, 68.73797714710236, 68.01223888993263, 63.815972059965134, 65.863097012043, 62.3807168751955, 61.4784324914217, 66.48918941617012, 66.79574936628342, 58.22674937546253, 50.624675899744034, 49.099707528948784, 50.418631955981255, 51.23806178569794, 51.6209976375103, 49.959232807159424, 50.29706887900829, 52.48192884027958, 50.942361652851105, 46.7435147613287, 47.68385410308838, 47.53666900098324, 51.304543018341064, 51.5850705653429, 50.45371927320957, 51.27937316894531, 54.16385158896446, 52.88443364202976, 54.294564574956894, 49.27384838461876, 54.44098971784115, 54.50533926486969, 58.181379809975624, 57.83120200037956, 57.25957967340946, 56.224446818232536, 55.70102870464325, 50.85139073431492, 50.64538858830929, 52.53446102142334, 52.86071911454201, 51.05455823242664, 51.21910460293293, 48.96323025226593, 48.29345919191837, 47.94796273112297, 48.949695378541946, 48.30755263566971, 50.017913058400154, 48.763904348015785, 48.76565225422382, 47.08878703415394, 48.02689969539642, 48.77685405313969, 50.44678084552288, 53.081494867801666, 50.43351195752621, 51.19997262954712, 52.96229526400566, 54.50126588344574, 62.85463124513626, 61.15944340825081, 60.095181316137314, 55.151817575097084, 56.22521437704563, 57.22913570702076, 59.35373090207577, 55.18163837492466, 57.57880814373493, 52.97657109797001, 29.90439534187317, 7.548308735713363, 0.6288472563028336, 0.605719619197771, 1.9668068806640804, 1.2513615586794913, 0.2784943295409903, 0.24668904166901484, 0.18282390927197412, 0.21172601933358237, 0.12265512501471676, 0.10562786759692244, 0.1724022559938021, 0.15715879504568875, 0.12566126097226515, 0.1971303197205998, 0.23612326331203803, 0.09128033474553376, 0.12055480998242274, 0.1581221175729297, 0.15444485004991293, 0.11057207768317312, 0.1336242086836137, 0.23259452922502533, 0.12804787431377918, 0.24547043518396094, 0.1294862010399811, 0.13301564758876339, 0.16041845607105643, 0.14563261822331697, 0.13712251471588388, 0.23979405930731446, 0.1842399121960625, 0.27973122254479676, 1.8570060725323856, 29.162466153502464, 42.783876433968544, 25.076784789562225, 7.313981484621763, 6.111699398607016, 1.6123687871731818, 10.424959100782871, 39.77822631597519, 62.64022774994373, 76.2865000963211, 60.58802627027035, 11.68219193816185, 0.7427975605241954, 0.4136471397941932, 0.22707502852426842, 0.25170134380459785, 0.18341645481996238], [0.07946885409182869, 0.04553992548608221, 0.06300763270701282, 0.15219148190226406, 4.735652636736631, 32.294159308075905, 21.42975378781557, 30.679111070930958, 43.08540165424347, 16.370971240103245, 4.513952108100057, 1.8963751662522554, 4.796316856518388, 12.849449403584003, 76.03316009044647, 50.26487700641155, 11.517375782132149, 0.6837807898409665, 0.08178735311958008, 0.07569161185529083, 0.012721200637315633, 0.03924223841750063, 0.05877665251318831, 0.02638672296598088, 0.038376122392946854, 0.03254100483900402, 0.046777393654338084, 0.03544277999026235, 0.1044754903705325, 0.03425926966883708, 0.06909909920068458, 0.022959635280130897, 0.05324037185346242, 0.04199786613753531, 0.05144516115251463, 0.051934618677478284, 0.0653633133333642, 0.03323190721857827, 0.06005246745189652, 0.06299076369032264, 0.020288755258661695, 0.06285383002250455, 0.06417379903723486, 0.037487875524675474, 0.1430167703074403, 0.04404450533911586, 0.04925443769025151, 0.20786459528608248, 0.6410303525626659, 1.0587136773392558, 2.788534755818546, 23.517671450972557, 57.249179631471634, 60.738999769091606, 62.214547991752625, 62.65596270561218, 63.11968982219696, 62.77114972472191, 60.29890738427639, 60.76024442911148, 64.7848592698574, 59.1428080201149, 64.64883416891098, 61.13406836986542, 57.66262784600258, 51.405138820409775, 43.65263141691685, 44.98785316944122, 46.97420418262482, 45.023784041404724, 44.25093591213226, 43.38321067392826, 44.305774569511414, 44.616738483309746, 44.39173735678196, 43.97992305457592, 43.14726613461971, 45.66336952149868, 47.93599337339401, 49.96600404381752, 42.96898350119591, 49.31344985961914, 45.497436225414276, 45.936168283224106, 43.461266085505486, 44.62442547082901, 44.33675430715084, 48.69300775229931, 49.347017258405685, 46.62350960075855, 42.19839245080948, 42.65670865774155, 43.70873540639877, 43.840983510017395, 47.017035484313965, 44.70889113843441, 44.53433230519295, 46.22412443161011, 42.680848762393, 38.59838582575321, 39.832555800676346, 41.283416748046875, 40.723987966775894, 41.9248603284359, 39.54594098031521, 42.08169311285019, 41.47557623684406, 41.331575363874435, 41.62006348371506, 41.90138898789883, 41.227274760603905, 42.89208322763443, 45.08869595825672, 51.3173521310091, 55.577318742871284, 57.70270809531212, 54.92997407913208, 54.34238500893116, 53.65190885961056, 52.26270340383053, 54.64351125061512, 54.748279228806496, 57.180528715252876, 41.33106239140034, 9.998522233217955, 0.1253550805267878, 0.897669472033158, 1.2906614248640835, 0.1440868730423972, 0.05522302679310087, 0.049415279645472765, 0.05952803621767089, 0.09107431455049664, 0.11378380339010619, 0.06228123340406455, 0.020619968345272355, 0.06380495906341821, 0.025371105002705008, 0.07139963083318435, 0.08536120236385614, 0.05720383007428609, 0.058362233539810404, 0.04294983751606196, 0.06277945198235102, 0.07420323468977585, 0.10056556697236374, 0.005753104205723503, 0.01931417249579681, 0.033000156763591804, 0.0740738189779222, 0.028461615729611367, 0.06118157092714682, 0.11287629778962582, 0.04423272141139023, 0.1014172333816532, 0.09202675719279796, 0.05536733369808644, 0.04441630277142394, 3.493695929646492, 12.225189451128244, 16.160939410328865, 3.2586844777688384, 0.5509436584543437, 0.7130165991839021, 0.7688703364692628, 4.372767833992839, 13.690121993422508, 52.81427800655365, 39.72559913992882, 22.315851040184498, 7.16036950238049, 0.14698794315336272, 0.03618866438046098, 0.047108940707403235, 0.053138426737859845, 0.04512627092481125, 0.048637327054166235, 0.08153423623298295, 0.048341299188905396, 0.17638913268456236, 1.89735610736534, 21.630098037421703, 22.853436693549156, 45.21014504134655, 59.38125282526016, 16.366441883146763, 10.434464290738106, 8.124148361384869, 8.41159913688898, 36.63390263915062, 98.70342761278152, 57.17880740761757, 28.818968385457993, 2.0698961801826954, 0.2546644723042846, 0.04439612377609592, 0.06418278644559905, 0.007728403534201789, 0.08213132372475229, 0.010048606254713377, 0.07978574372828007, 0.039850829198258, 0.07352169079240412, 0.027706532418960705, 0.09624405589420348, 0.01979536249564262, 0.0034605643440954736, 0.02858081763406517, 0.05672754195984453, 0.010498742012714501, 0.01591239019035129, 0.03817762386461254, 0.03663591967779212, 0.009288115470553748, 0.04873979909461923, 0.022092595281719696, 0.08601645939052105, 0.08092673640931025, 0.05031359374697786, 0.0500375111005269, 0.041557067524991, 0.06037036269844975, 0.04606898030033335, 0.08215597044909373, 0.6363156368024647, 0.47124744742177427, 2.3217967757955194, 15.06136866286397, 52.878673151135445, 65.04078313708305, 63.41659069061279, 66.68778195977211, 66.68963626027107, 63.83210599422455, 62.29370914399624, 63.03670607507229, 66.86973139643669, 62.8664144128561, 64.40873265266418, 65.2896773815155, 60.925877541303635, 56.612945571541786, 44.99174416065216, 48.47763530910015, 48.35031174123287, 48.218702003359795, 44.954813942313194, 46.90385475754738, 48.923659175634384, 47.662145867943764, 48.04777577519417, 45.0382536649704, 46.58742293715477, 46.78725801408291, 50.630706176161766, 53.20021949708462, 44.984159767627716, 52.94398784637451, 46.1770411580801, 46.3047219067812, 45.07202625274658, 44.92884233593941, 45.54645739495754, 52.131200060248375, 49.66944135725498, 48.51706199347973, 42.9327030479908, 44.666903391480446, 44.23248030245304, 45.80987446010113, 49.74733717739582, 48.45917209982872, 45.47042727470398, 49.756122305989265, 44.234251007437706, 43.14312435686588, 42.779487669467926, 43.02696458995342, 42.78772182762623, 43.60166855156422, 43.472954258322716, 46.24992124736309, 43.525604233145714, 43.98664489388466, 43.166124522686005, 44.76089894771576, 43.89684431254864, 47.53691218793392, 46.56565010547638, 56.50547593832016, 60.087722316384315, 59.96236704289913, 57.26228132843971, 58.485507890582085, 54.409592002630234, 55.472539365291595, 58.54061633348465, 59.996173828840256, 56.687600165605545, 38.740513399243355, 5.543929114937782, 0.16047364217229187, 2.939654071815312, 1.77982461405918, 0.17755084612872452, 0.06646170673775487, 0.030202000270946883, 0.16880825744010508, 0.037793970623170026, 0.07805454326444305, 0.001960968224921089, 0.05935534958553035, 0.011325209725328023, 0.03495098841085564, 0.05329345025529619, 0.04079425474628806, 0.014123279015620938, 0.05282739264657721, 0.042829012163565494, 0.05891664382943418, 0.0652209397230763, 0.10968227230478078, 0.03466037451289594, 0.02192824482335709, 0.0260283138777595, 0.03533992945449427, 0.04120397592487279, 0.07103385592927225, 0.0258777061389992, 0.01579334413690958, 0.0399574387120083, 0.04811220191186294, 0.04830247002246324, 0.1909469233942218, 6.31445461884141, 23.338414169847965, 22.005451396107674, 7.345077116042376, 1.681042502168566, 1.7880935641005635, 0.7312379870563745, 6.761722918599844, 30.491593033075333, 66.70255556702614, 54.69223603606224, 29.841801300644875, 9.138838313519955, 0.36986069404520094, 0.06631442753132433, 0.05061298725195229, 0.06779469302273355, 0.008506567173753865, 0.16688616917235777, 0.26575898635201156, 0.1282073321635835, 0.44953802484087646, 8.619686421006918, 81.36638671159744, 56.002075150609016, 72.5469383597374, 98.07120993733406, 39.61143046617508, 15.43319771066308, 14.18408788740635, 17.45978381484747, 42.284294441342354, 99.68582689762115, 63.38790982961655, 43.25252428650856, 2.4936021817848086, 0.30245949514210224, 0.17623770487261936, 0.07374859502306208, 0.09565905056660995, 0.16427619906608015, 0.13313358969753608, 0.13346809049835429, 0.1507457930711098, 0.13813073717756197, 0.13213765720138326, 0.17926508851815015, 0.07139476234442554, 0.19682801328599453, 0.09860713573289104, 0.1533477776683867, 0.06785193487303331, 0.08802919357549399, 0.2856370556401089, 0.14072479563765228, 0.13243991910712793, 0.28201389068271965, 0.12165712934802286, 0.14741056656930596, 0.18231639900477603, 0.18100103130564094, 0.08967711764853448, 0.2000298016355373, 0.1218119116674643, 0.1385808497434482, 0.7080996630247682, 0.7646921637933701, 1.007185592316091, 3.757577519863844, 27.095306776463985, 59.1118548810482, 65.28782308101654, 62.883498296141624, 66.672423183918, 66.24491572380066, 67.37698137760162, 63.10970775783062, 65.41677296161652, 68.68692308664322, 65.49878016114235, 68.01093176007271, 68.7075711786747, 58.33359584212303, 53.78255344927311, 48.51275682449341, 50.78556306660175, 52.03997075557709, 53.14449168741703, 48.261578902602196, 51.66189104318619, 51.518665328621864, 49.85402025282383, 51.60294100642204, 49.258675798773766, 49.037983641028404, 50.924054235219955, 54.51874114573002, 55.08235730230808, 46.667537838220596, 54.87567499279976, 49.18780580163002, 49.14720878005028, 48.68722826242447, 48.803479224443436, 49.166705533862114, 54.6764250844717, 55.23255564272404, 53.28726142644882, 44.80162896215916, 49.44117620587349, 47.85202167928219, 48.58033239841461, 50.854149386286736, 50.3545293956995, 47.51664027571678, 53.54041524231434, 48.52271988987923, 45.400286838412285, 45.4531230032444, 45.72277553379536, 45.246079713106155, 48.77667926251888, 46.61936402320862, 50.019550770521164, 47.5338913500309, 48.67831014096737, 49.200766906142235, 49.46078695356846, 47.51094438135624, 48.856395184993744, 48.826186805963516, 57.34844170510769, 61.9408904761076, 63.36615599691868, 59.281037002801895, 59.44821663200855, 56.80952802300453, 56.57617874443531, 59.374694377183914, 60.47670364379883, 61.68018266558647, 46.21951527893543, 11.775092203170061, 0.5565274588298053, 1.8919351045042276, 4.313738476485014, 0.4332842188887298, 0.3017288655973971, 0.13272281095851213, 0.22328062041196972, 0.15874633798375726, 0.16671502991812304, 0.12485024199122563, 0.1610084337880835, 0.17293295095441863, 0.08583760922192596, 0.16444999520899728, 0.22630681662121788, 0.13409706065431237, 0.15758637600811198, 0.10675153855117969, 0.2364501348347403, 0.1509078632807359, 0.23945705004734918, 0.12151676695793867, 0.2103010512655601, 0.11139275200548582, 0.1278520215419121, 0.1297052385052666, 0.2173908325494267, 0.20329725521150976, 0.10179326476645656, 0.2938131778500974, 0.23181953409221023, 0.19237926841014996, 0.589188071899116, 6.473775319755077, 34.106764644384384, 42.387987077236176, 12.065930496901274, 3.2956997165456414, 2.6083636237308383, 1.8621031427755952, 14.9509247392416, 54.4443791359663, 83.4754179418087, 78.77422660589218, 40.48674389719963, 14.02488213032484, 0.35926184558775276, 0.19597979786340147, 0.23852025187807158, 0.31391362426802516, 0.241229061211925], [0.11916880466742441, 0.06726428007823415, 0.01562880257552024, 0.01780162172508426, 0.26698020519688725, 2.522525992244482, 12.298414371907711, 14.746872838586569, 12.6573402620852, 13.621394131332636, 1.3032805477268994, 0.8713280386291444, 3.1957603292539716, 5.249147582799196, 17.16839075088501, 21.882053017616272, 33.06169152259827, 3.2654362404718995, 0.40814559906721115, 0.17962698941119015, 0.05495067343872506, 0.05767178758105729, 0.018010723688348662, 0.006055624935470405, 0.017658190554357134, 0.05682697119482327, 0.02220867831056239, 0.057785232274909504, 0.07495060708606616, 0.08224997829529457, 0.014037944092706311, 0.03728653086000122, 0.027619855136435945, 0.047830913099460304, 0.022958874578762334, 0.02531702099076938, 0.049087680818047374, 0.08573751576477662, 0.038343634878401645, 0.07243998828926124, 0.0714077202428598, 0.11331513713230379, 0.045414535925374366, 0.013022046896367101, 0.006275945852394216, 0.0814070321212057, 0.10451205598656088, 0.06266954733291641, 0.058496844285400584, 0.20834403752814978, 0.3693821275373921, 1.4097244734875858, 21.68339967727661, 64.1839063167572, 63.54530118405819, 63.29202197492123, 61.40978157520294, 57.64125399291515, 56.171109080314636, 63.12896892428398, 59.224887415766716, 61.59901522099972, 59.89252679049969, 62.56058782339096, 57.54043020308018, 53.351132199168205, 45.632648169994354, 44.02430847287178, 45.21771803498268, 43.51191356778145, 44.62607078254223, 41.70717380940914, 41.67161151766777, 41.59086585044861, 42.504891604185104, 42.86610022187233, 42.361567094922066, 48.03630419075489, 43.60406622290611, 51.88313037157059, 48.54956164956093, 46.42197601497173, 42.47083403170109, 41.334892585873604, 40.3596331179142, 39.60581436753273, 41.15460366010666, 44.53682877123356, 45.03635756671429, 43.68736535310745, 40.553616508841515, 39.243002235889435, 37.74330250918865, 38.9914633333683, 45.422059670090675, 45.78612953424454, 45.69090284407139, 45.61458393931389, 43.17736431956291, 42.63491302728653, 40.814122930169106, 40.11262357234955, 40.02277359366417, 39.27724979817867, 38.05723026394844, 39.72642369568348, 40.5397130548954, 44.1733630746603, 39.88451421260834, 41.5272306650877, 41.10731519758701, 45.63096486032009, 44.23221051692963, 52.54090927541256, 56.30575105547905, 56.04771450161934, 53.909675627946854, 55.29544606804848, 52.278958931565285, 52.45702117681503, 54.014842584729195, 55.24183854460716, 48.822018429636955, 19.07818727195263, 0.3528880141675472, 0.294184815720655, 8.796210698783398, 2.150917570106685, 0.06326054179226048, 0.23568974516820163, 0.11294007053948008, 0.017799873967305757, 0.12054678736603819, 0.09255999029846862, 0.02340714661841048, 0.026808921502379235, 0.03526143991621211, 0.012959523737663403, 0.0469974255975103, 0.055987305313465185, 0.06544455623952672, 0.0907684161211364, 0.02816168973367894, 0.025200552045134827, 0.04805837023013737, 0.05387501572840847, 0.06855201761936769, 0.0634038653515745, 0.06903103683725931, 0.07265993117471226, 0.05557910924835596, 0.13580407452536747, 0.015475079671887215, 0.03830967420071829, 0.18668966746190563, 0.03872456443787087, 0.11354121015756391, 0.4141871561296284, 4.96109738945961, 18.42138111591339, 10.320981480181217, 2.7186144702136517, 0.06515583110740408, 0.22381955321179703, 1.4060608763247728, 5.786466775462031, 20.440590865910053, 56.228071823716164, 54.836449697613716, 31.916543170809746, 2.5224927440285683, 0.28268559370189905, 0.16325675533153117, 0.06069947179639712, 0.10683308573788963, 0.09942953183781356, 0.06484275611001067, 0.02437548420857638, 0.034974573864019476, 0.03093015475315042, 0.20582459459546953, 0.4523708618944511, 4.186172196641564, 4.8814750369638205, 22.540671676397324, 12.340057287365198, 0.2967554668430239, 0.6463830184657127, 1.397723292466253, 5.6593388970941305, 43.36809128522873, 31.02862011641264, 43.86083364486694, 11.218637712299824, 0.902970009483397, 0.24479454645188525, 0.06696131313219666, 0.029581562957901042, 0.04908387731120456, 0.006137958334875293, 0.08154265960911289, 0.03739100669918116, 0.022614111730945297, 0.03052047253731871, 0.04371135524706915, 0.07569489214802161, 0.09973773834644817, 0.03528435743646696, 0.03199718128598761, 0.02679981535038678, 0.037911207691649906, 0.027023988477594685, 0.061634210505872034, 0.04093367089808453, 0.06549169745994732, 0.05334052097168751, 0.04308959505578969, 0.10788864237838425, 0.03929952850739937, 0.004617257854988566, 0.0563940875872504, 0.08356127160368487, 0.04037854443595279, 0.1015054747404065, 0.12215881375595927, 0.273993203882128, 0.3020791889866814, 0.6945115921553224, 13.21130683645606, 58.72910141944885, 65.406384319067, 63.6687071621418, 63.5576581209898, 59.44841802120209, 59.229500368237495, 64.04894515872002, 59.89432789385319, 61.60576745867729, 62.31638252735138, 63.038906157016754, 58.699425011873245, 57.30800807476044, 49.814114794135094, 47.13409960269928, 49.03054744005203, 47.58118361234665, 48.33693265914917, 45.280209481716156, 44.660789519548416, 45.18511198461056, 45.971574783325195, 43.560771346092224, 43.83605517446995, 50.09360119700432, 48.66563022136688, 54.87049587070942, 53.30578923225403, 49.39363695681095, 44.70670625567436, 44.11318190395832, 42.66778886318207, 43.39479245245457, 44.05929319560528, 47.174905613064766, 48.188406229019165, 47.05338813364506, 42.11834594607353, 43.20477604866028, 41.88582502305508, 41.55982531607151, 45.263288989663124, 47.64942415058613, 50.07346987724304, 47.73851037025452, 46.421299651265144, 46.08618803322315, 45.24399742484093, 43.03250469267368, 41.55961632728577, 43.216221034526825, 41.77946873009205, 44.21797648072243, 43.961345851421356, 46.63730666041374, 43.209540992975235, 44.9656243622303, 46.245407089591026, 52.0368929207325, 47.77693010866642, 59.481772631406784, 57.44169630110264, 57.44827754795551, 55.21112859249115, 57.209836542606354, 55.118683353066444, 57.57497414946556, 56.77071310579777, 55.169748812913895, 45.76379053294659, 12.562901079654694, 0.15866575558902696, 0.24737753206864, 11.273557115346193, 4.389789970591664, 0.06056289807020221, 0.3171160805504769, 0.2693269355222583, 0.007116803344615619, 0.09977598121622577, 0.0576441425801022, 0.009548631569487043, 0.043016434137825854, 0.020522748855000827, 0.04044837682158686, 0.03502531450067181, 0.11538162507349625, 0.07208244380308315, 0.028563666601257864, 0.05213873526372481, 0.0684600803651847, 0.055445159014198, 0.05841104459250346, 0.09662923053838313, 0.09614163209334947, 0.059351030286052264, 0.0284579124127049, 0.09880193465505727, 0.07077969261445105, 0.0683756907528732, 0.09322935555246659, 0.023050099371175747, 0.02965989478980191, 0.1277026569005102, 0.7638021802995354, 11.522677447646856, 32.73198701441288, 13.851151652634144, 4.955825172364712, 1.1510368483141065, 0.6737899384461343, 2.0678523648530245, 7.389544229954481, 40.23088842630386, 64.70737382769585, 65.45078113675117, 39.89230379462242, 3.965708026662469, 0.31189269677270204, 0.10855424494366162, 0.050691773649305105, 0.07579390949103981, 0.04807241908565629, 0.2252576276077889, 0.21473271190188825, 0.12499102740548551, 0.1733379260986112, 0.32833595818374306, 7.390182595700026, 36.41672149300575, 41.67569249868393, 60.127646774053574, 33.1230316311121, 1.1032930039800704, 0.5849064141511917, 5.913624577224255, 18.993691205978394, 48.488221541047096, 34.18625257909298, 60.64051665365696, 13.514238931238651, 0.9201545873656869, 0.47155368723906577, 0.16984337533358485, 0.13450271857436746, 0.12715199816739187, 0.07311145382118411, 0.1828637477592565, 0.20098110137041658, 0.24837349425069988, 0.14097734849201515, 0.08217571157729253, 0.2243821753654629, 0.1451874483609572, 0.14002512849401683, 0.13064939877949655, 0.2768615452805534, 0.15161147865001112, 0.20637559471651912, 0.23298860964132473, 0.1671139194513671, 0.13329989014891908, 0.29577633657027036, 0.12658008432481438, 0.1193861426145304, 0.1458065479528159, 0.25140110054053366, 0.11703245836542919, 0.20260478690033779, 0.19894353492418304, 0.17468725447542965, 0.17804196977522224, 0.7631549087818712, 0.8853931026533246, 1.8975304230116308, 24.131025038659573, 64.60221827030182, 66.00736007094383, 67.33311653137207, 66.69114857912064, 60.08249759674072, 59.82770226895809, 68.35766315460205, 63.580567091703415, 66.47084400057793, 63.30750234425068, 67.47848153114319, 59.307422786951065, 55.90356923639774, 50.34441813826561, 49.336408227682114, 52.19781428575516, 50.06191469728947, 51.334891989827156, 46.73210397362709, 45.87923973798752, 48.58584210276604, 47.29580372571945, 46.60362906754017, 45.17255365848541, 53.68055932223797, 50.82964450120926, 59.73946340382099, 55.8856076002121, 51.21228016912937, 46.94941811263561, 47.36599735915661, 44.196374639868736, 45.46565093100071, 46.1739557236433, 49.79001648724079, 50.1801073551178, 50.0514804571867, 43.28504294157028, 43.73862460255623, 44.90986615419388, 44.55253712832928, 50.56149668991566, 51.41037113964558, 51.95063754916191, 49.94965732097626, 49.06933195888996, 48.63119646906853, 46.37686103582382, 46.85693867504597, 45.23679681122303, 46.56042918562889, 43.472293093800545, 48.6518369615078, 46.048414260149, 50.229782089591026, 45.643762573599815, 47.38044798374176, 46.99969321489334, 54.47389215230942, 49.30785275995731, 57.17107482254505, 60.598099529743195, 61.37825086712837, 57.621514052152634, 60.51571995019913, 56.26369871199131, 59.09398443996906, 58.46617452800274, 60.43291099369526, 55.01876771450043, 24.633720964193344, 0.3800124430563301, 0.41341279924381524, 18.094188272953033, 6.107461201027036, 0.31358719803392887, 0.43086009740363806, 0.4563422128558159, 0.08169657361577265, 0.1847982150502503, 0.25196819042321295, 0.12200982760987245, 0.17779404792236164, 0.12646352261072025, 0.17822768480982631, 0.22705553972627968, 0.12630691460799426, 0.20671196572948247, 0.2049048658227548, 0.16610522201517597, 0.1659296001889743, 0.2835990587482229, 0.21210764651186764, 0.25495871901512146, 0.2931339346105233, 0.1268209854606539, 0.15729022939922288, 0.23200236959382892, 0.22807827859651297, 0.27233812550548464, 0.16798221739009023, 0.3784753958461806, 0.25741757301148027, 0.3033817175310105, 0.9198830800596625, 17.114131562411785, 43.588589653372765, 35.7017632573843, 10.496267024427652, 2.3848161567002535, 0.49321763101033866, 3.166599743999541, 20.719663091003895, 68.2269349694252, 72.72128820419312, 85.35704657435417, 53.666519075632095, 3.308899258263409, 0.8404065447393805, 0.3514118230668828, 0.23315045720664784, 0.34002816828433424, 0.23321751767070964], [0.042252278071828187, 0.11404442338971421, 0.12535082059912384, 0.02420968285150593, 0.09947751168510877, 0.10196195493335836, 0.9551867481786758, 2.3089465778321028, 9.696974214166403, 6.650013662874699, 4.206914808601141, 1.2644243077374995, 0.38322003500070423, 2.8437562426552176, 7.000864036381245, 28.53644024580717, 40.068519338965416, 21.14087238907814, 0.49981087096966803, 0.06882637477247044, 0.03366180739249103, 0.010764126600406598, 0.03508579211484175, 0.03825012798188254, 0.06069692251912784, 0.039826980282668956, 0.023004848771961406, 0.0350841222825693, 0.037767735702800564, 0.00751891797335702, 0.019379978730285075, 0.06555107669555582, 0.05139778986631427, 0.016362198475690093, 0.030907565633242484, 0.03594548485125415, 0.07623412180691957, 0.05305082362610847, 0.0448665860312758, 0.028611203015316278, 0.02178120495955227, 0.0623164779972285, 0.020861051307292655, 0.11441337468568236, 0.06009839155012742, 0.03326845799165312, 0.06351335439831018, 0.13284106476930901, 0.21967191249132156, 0.07924906705738977, 3.354386854916811, 3.7187431287020445, 1.3905496336519718, 30.579199232161045, 63.00129197537899, 63.2001619040966, 58.45068655908108, 59.499498680233955, 59.31803561747074, 58.923939764499664, 59.157657623291016, 62.64971204102039, 57.742108181118965, 60.54907076060772, 56.843410804867744, 52.0176013559103, 52.44148001074791, 45.874793976545334, 44.94048871099949, 43.04719850420952, 43.12145031988621, 43.87175425887108, 43.79800021648407, 42.99138329923153, 42.70798310637474, 43.31930190324783, 45.01583106815815, 48.37659873068333, 49.45693776011467, 50.20922899246216, 50.928796380758286, 46.43900290131569, 43.475131541490555, 42.98273116350174, 42.317489460110664, 43.42949599027634, 45.54896526038647, 47.66909569501877, 48.495285362005234, 49.02311123907566, 44.2891276627779, 44.56858366727829, 42.13710933923721, 39.126329496502876, 39.96840611100197, 47.5643353164196, 46.98773145675659, 43.52140545845032, 44.03360657393932, 42.251916378736496, 41.98769375681877, 38.37530739605427, 39.09202113747597, 40.53318500518799, 40.76347924768925, 39.92464765906334, 41.101759895682335, 40.690143182873726, 42.04341396689415, 39.36758615076542, 42.3356980830431, 49.72831919789314, 46.66295148432255, 53.09801258146763, 55.29307879507542, 53.1713904440403, 52.24109776318073, 52.919114381074905, 53.33396852016449, 53.39051328599453, 52.94084161520004, 44.9869754165411, 26.012514978647232, 2.0925804879516363, 0.04874657119216863, 0.03720848661032505, 0.2763028268236667, 0.4495405778288841, 0.047461705762543716, 0.14975768281146884, 0.07510239855037071, 0.03915001543646213, 0.029920412744104397, 0.01419055934093194, 0.05695007865142543, 0.04302771849324927, 0.07649407387361862, 0.0145299833639001, 0.033423325658077374, 0.059248484030831605, 0.1182174232963007, 0.05512114476005081, 0.04541086600511335, 0.15047017426695675, 0.09834981829044409, 0.10079310202854685, 0.04599319589033257, 0.11213330406462774, 0.054162327069207095, 0.02721707303862786, 0.04946071763697546, 0.06549071040353738, 0.026040689190267585, 0.022284941405814607, 0.03928501952032093, 0.08316307226778008, 0.1922420007758774, 0.8289226703345776, 12.576358057558537, 19.765585586428642, 6.850346038118005, 2.7896941686049104, 0.06093070645874832, 0.08251092483988032, 1.1341919959522784, 5.545775340870023, 30.313198305666447, 54.222748428583145, 66.39949142932892, 17.660903222858906, 0.19611653115134686, 0.19877698214259, 0.09124243326368742, 0.028440464520826936, 0.06515251370728947, 0.037936693042865954, 0.015078371125127887, 0.027340705564711243, 0.11796527120168321, 0.037207388231763616, 0.011332760150253307, 0.07597723481012508, 1.8537093931809068, 4.195790430530906, 4.274980081245303, 5.14711070805788, 1.401005128864199, 0.4458534100558609, 0.4517526231938973, 0.5179348296951503, 11.147251892834902, 46.503717228770256, 44.56272818148136, 32.32887424528599, 1.2273796205408871, 0.0992951808439102, 0.06680592225166038, 0.02266420669911895, 0.03236972828744911, 0.036155486668576486, 0.06848569188150577, 0.03550466397427954, 0.05301575343764853, 0.020987526258977596, 0.011057094034185866, 0.07799604718456976, 0.030198838721844368, 0.06915536141605116, 0.013814626290695742, 0.0030081367413004045, 0.035494630137691274, 0.017649921173870098, 0.050718409329419956, 0.09048505671671592, 0.08606645045801997, 0.06252413091715425, 0.04866619659878779, 0.05713848026061896, 0.11397570051485673, 0.06932463045814075, 0.044224821249372326, 0.017548250652907882, 0.09826557710766792, 0.11017439785064198, 0.16991842130664736, 0.046633053352707066, 6.185027388855815, 4.893115237355232, 0.7166137592867017, 21.686650402843952, 62.43706785142422, 65.4089529812336, 62.581995874643326, 62.68113635480404, 61.40785127878189, 59.862219616770744, 64.34352055191994, 64.9628721177578, 61.18800647556782, 63.55848267674446, 64.29344683885574, 54.342012628912926, 55.69684512913227, 48.22078049182892, 46.91803939640522, 45.79209141433239, 45.05615830421448, 47.13612489402294, 46.3461434841156, 47.20544457435608, 46.049421206116676, 45.08878715336323, 47.66650803387165, 49.62432257831097, 52.23177686333656, 50.88325582444668, 53.717162758111954, 48.16814951598644, 46.795237585902214, 46.21272884309292, 45.96535071730614, 45.37851780653, 47.43858866393566, 49.34429280459881, 52.03362129628658, 53.509910479187965, 47.23294749855995, 48.21267932653427, 46.717752143740654, 42.53609172999859, 44.951899498701096, 49.607873260974884, 48.85265238583088, 45.58202728629112, 47.1143938601017, 45.466015711426735, 45.08074298501015, 43.640882447361946, 41.622350960969925, 42.61707678437233, 43.88118915259838, 44.14733067154884, 45.21354205906391, 41.77242010831833, 43.581180050969124, 43.193171471357346, 46.683470383286476, 55.43715566396713, 56.71917647123337, 54.14752386510372, 61.623683497309685, 57.17184238135815, 57.68685154616833, 57.42919497191906, 55.20635224878788, 54.631956070661545, 51.8388057500124, 42.88293331861496, 17.580262050032616, 0.6735658692196012, 0.0523145982879214, 0.009747461281222058, 0.23458930343622342, 0.3090708138188347, 0.12910408404422924, 0.14385934540769085, 0.13879035803256556, 0.14673706755274907, 0.09490229742368683, 0.039756390906404704, 0.06256472639506683, 0.029958323502796702, 0.03481426254438702, 0.07632588836713694, 0.01764755001204321, 0.020292831504775677, 0.045065845260978676, 0.09336035946034826, 0.010649826581357047, 0.030789931515755598, 0.06394643467501737, 0.06305872957454994, 0.06563309885677882, 0.03055446475627832, 0.02215097632870311, 0.026202369772363454, 0.008343965400854358, 0.14490636734990403, 0.0405963647790486, 0.05717005864426028, 0.033498078482807614, 0.0754235778003931, 0.10767569052404724, 1.6125098546035588, 22.590179219841957, 33.357175067067146, 10.959515366703272, 3.512977045029402, 0.4235692089423537, 0.7736317778471857, 2.5553911412134767, 8.686955161392689, 52.407536432147026, 57.60575249791145, 88.73607605695724, 26.15695472806692, 0.26316203351598233, 0.15426817437401041, 0.05059875657025259, 0.03258785291109234, 0.041703415336087346, 0.07341589764109813, 0.14195299067068845, 0.37578855408355594, 0.2530383673729375, 0.05234290751104709, 0.11776175946579315, 0.15460914670256898, 3.555268063209951, 4.156916616484523, 34.64940592646599, 23.35951253771782, 3.0430213501676917, 0.5128923221491277, 0.41608334344346076, 3.995522176846862, 16.988856084644794, 62.50669911503792, 57.08345912396908, 38.95155027508736, 1.4505690755322576, 0.30608818167820573, 0.22160088788950816, 0.13872392097255215, 0.18062814662698656, 0.08972511233878322, 0.14808229927439243, 0.19739260955248028, 0.19226344884373248, 0.10498606570763513, 0.09784961075638421, 0.15623948187567294, 0.19123175967251882, 0.13007361092604697, 0.16209416615311056, 0.075498230435187, 0.16886653087567538, 0.16649109427817166, 0.09598323551472276, 0.1856063841842115, 0.12934237282024696, 0.14844497200101614, 0.08936191268730909, 0.18108075280906633, 0.12813371111406013, 0.2396543277427554, 0.2019091125112027, 0.14062386355362833, 0.2334444219013676, 0.2496583596803248, 0.365476441802457, 0.34818630083464086, 7.002406753599644, 6.212932141497731, 1.5095187560655177, 34.404520466923714, 65.16793191432953, 70.11747792363167, 61.722812578082085, 64.55777585506439, 63.626529425382614, 63.570018857717514, 65.92403054237366, 65.03142043948174, 63.823974430561066, 66.7820093035698, 66.26113325357437, 53.38322527706623, 56.34042039513588, 50.78282721340656, 49.12147656083107, 49.68521811068058, 47.297179251909256, 51.94401070475578, 50.75090512633324, 48.8570411503315, 48.05676229298115, 48.825586438179016, 48.803760409355164, 54.296768456697464, 53.66854816675186, 55.56875020265579, 56.92705571651459, 51.08500599861145, 49.96438533067703, 48.90761263668537, 46.70353330671787, 46.65274903178215, 49.7889069467783, 52.63509102165699, 55.86977005004883, 56.107728481292725, 50.49186922609806, 51.287531331181526, 47.67909295856953, 43.300378918647766, 44.907077103853226, 54.53170984983444, 53.56621965765953, 48.071577697992325, 49.11141850054264, 47.58515439927578, 47.262414917349815, 47.4295299500227, 44.30542878806591, 47.137002646923065, 47.536699399352074, 47.16262087225914, 49.32372070848942, 45.69603256881237, 48.51519249379635, 44.92312364280224, 48.74245069921017, 54.753158167004585, 53.181307911872864, 59.54220838844776, 61.27255953848362, 57.14179739356041, 57.821197137236595, 59.64172124862671, 55.74088856577873, 57.31143169105053, 59.07117426395416, 52.15247891843319, 32.04949043691158, 4.419796485453844, 0.15327191533287987, 0.22720579494489357, 0.5064226349350065, 0.7417692407034338, 0.1862876460654661, 0.7727586559485644, 0.2651617059018463, 0.4248846508562565, 0.20787949761142954, 0.1006094650074374, 0.11511514952871948, 0.09432536666281521, 0.15399567259009928, 0.14175771677400917, 0.17053008457878605, 0.10560044524027035, 0.23440707649569958, 0.18722834793152288, 0.1718756725313142, 0.3707892098464072, 0.21784244425361976, 0.11206008377484977, 0.24895536771509796, 0.28081695490982383, 0.21050474111689255, 0.20166412956314161, 0.18315081048058346, 0.24570326175307855, 0.1253710367018357, 0.11478362474008463, 0.1907053097966127, 0.16759541002102196, 0.4147151199867949, 1.4255070453509688, 33.912735655903816, 41.47508226335049, 31.70425806194544, 11.026400327682495, 2.458141059614718, 0.652755395276472, 3.9079143153503537, 17.22568977624178, 76.55714437365532, 62.493335232138634, 109.04841050505638, 26.083080992102623, 0.2700434345752001, 0.3260269883321598, 0.16972814948530868, 0.1282704740879126, 0.2745589875848964, 0.19981024466687813], [0.043541325503611006, 0.0615814549382776, 0.03649479287560098, 0.04993668291717768, 0.04010444332379848, 0.08075286605162546, 0.38522407121490687, 4.283253662288189, 6.628010468557477, 2.0844484493136406, 2.2812379896640778, 1.541086274664849, 0.5113247281406075, 2.439645314589143, 8.45704659819603, 20.298936367034912, 31.71918746083975, 36.88484117388725, 4.124630698934197, 0.2607761771650985, 0.10574959465884604, 0.11077601244323887, 0.051462575647747144, 0.0573671396705322, 0.020629664504667744, 0.006393280327756656, 0.01614009408513084, 0.013626512263726909, 0.0586196957010543, 0.03274146263720468, 0.03524944309901912, 0.1619144922005944, 0.026880820769292768, 0.05331368120096158, 0.041818789613898844, 0.0304369271179894, 0.054689834505552426, 0.020278138836147264, 0.054572894296143204, 0.07465794114978053, 0.05628240549413022, 0.06451915003708564, 0.09650877997046337, 0.0582476793351816, 0.044939691288163885, 0.07974665481015109, 0.09236905054422095, 0.05505005443410482, 0.11894034934812225, 0.012256402824277757, 0.638544395333156, 0.7834840554278344, 0.1263992823078297, 2.9551890632137656, 38.67935948073864, 62.09042765200138, 62.86839410662651, 62.67884507775307, 60.24868167936802, 63.18188488483429, 64.0414747595787, 59.09522697329521, 60.655400454998016, 61.864020600914955, 59.95909921824932, 52.83141128718853, 57.76546932756901, 47.647208869457245, 43.4780003875494, 42.02241249382496, 43.51700149476528, 42.74641804397106, 43.280912563204765, 42.5459636002779, 43.775178641080856, 44.35327962040901, 44.249780774116516, 49.311454966664314, 47.31029614806175, 47.572964653372765, 47.031638100743294, 46.66660688817501, 47.38729141652584, 47.58694030344486, 45.87113477289677, 47.54698924720287, 50.58136962354183, 47.82835274934769, 47.25564368069172, 49.680430367589, 45.785244181752205, 45.95656178891659, 44.9234352260828, 43.36204580962658, 45.15194736421108, 46.93142607808113, 44.884145334362984, 44.688623026013374, 45.337704196572304, 41.197260171175, 40.754017755389214, 39.66949515044689, 38.205688297748566, 40.52554741501808, 41.07882432639599, 38.7883148342371, 40.967953875660896, 40.03196910023689, 41.81499682366848, 41.9673078507185, 50.023247972130775, 55.49821458756924, 60.384851172566414, 51.9893878698349, 58.0405517667532, 56.88974551856518, 51.74961693584919, 55.69109603762627, 57.85191468894482, 48.97424966096878, 40.612467750906944, 22.495155818760395, 2.884458708576858, 0.08441854864940979, 0.21043181768618524, 0.05372098668885883, 0.06110091802838724, 0.03270610672188923, 0.04720485958387144, 0.015685118596593384, 0.06604176989640109, 0.024888595835363958, 0.023428830318152905, 0.05638481816276908, 0.06796263362048194, 0.06539469133713283, 0.049097436349256895, 0.07826082321116701, 0.01841974168200977, 0.022409214034269098, 0.0292434404764208, 0.06926354428287596, 0.062455979496007785, 0.01933489511429798, 0.015966954742907546, 0.10139852383872494, 0.06053163138858508, 0.03539166827977169, 0.031197754651657306, 0.03497228062769864, 0.06815994100179523, 0.011723195693775779, 0.0783467193832621, 0.08052783203311265, 0.10229011037154123, 0.18146560090826824, 0.05133694488904439, 2.3292512632906437, 20.596988573670387, 21.885974407196045, 9.035737495869398, 3.907385431230068, 0.5405790021177381, 0.3649506747024134, 0.8578638173639774, 2.564798011444509, 13.81138488650322, 54.34217981994152, 61.69603921473026, 9.898288361728191, 0.09409436577698216, 0.14838674309430644, 0.01065255026333034, 0.17554611229570583, 0.03136360981443431, 0.03708995078341104, 0.03359121430548839, 0.025242756128136534, 0.03151617682306096, 0.037821845689904876, 0.08180529082892463, 0.11449410550994799, 0.9647124214097857, 8.042510692030191, 10.077071618288755, 2.7028408041223884, 4.2625390738248825, 0.9151534619741142, 1.1039570183493197, 3.64001895301044, 3.1905489088967443, 36.32994554936886, 39.45079408586025, 44.493727684020996, 6.948788305744529, 0.3237934206845239, 0.18202791135990992, 0.062098876587697305, 0.06393221512553282, 0.07121762653696351, 0.04982415106496774, 0.08160804281942546, 0.02291410266479943, 0.03996432955318596, 0.07071464337059297, 0.13194165599998087, 0.03706038733071182, 0.07957473630085588, 0.12086190326954238, 0.023736791918054223, 0.01996556849917397, 0.07734513914329, 0.04503183263295796, 0.0348235616547754, 0.022326548059936613, 0.07062342599965632, 0.04192723965388723, 0.04973206538124941, 0.06110439499025233, 0.007687741726840613, 0.026718375775089953, 0.009199963169521652, 0.06148551750811748, 0.11881748680025339, 0.24688473116839305, 0.1143670424062293, 2.339718989096582, 0.8432657131925225, 0.12708493770333007, 1.2772399513050914, 30.06234336644411, 58.37313652038574, 63.48769247531891, 66.42612040042877, 60.77844925224781, 62.99519330263138, 65.75120821595192, 60.80066666007042, 59.83391873538494, 65.0837816298008, 61.06472589075565, 55.01060575246811, 58.07586707174778, 51.348449662327766, 46.49348057806492, 43.72894272208214, 44.84380289912224, 45.78504279255867, 45.40079601109028, 43.39163862168789, 46.17245100438595, 46.7975402623415, 46.24662682414055, 50.58150261640549, 49.399146661162376, 51.46848522126675, 50.55362731218338, 50.231127217411995, 48.88216160237789, 49.98951718211174, 49.58621442317963, 51.48830495774746, 52.29120187461376, 50.2979352325201, 46.58462628722191, 52.43952691555023, 49.53287288546562, 48.11518415808678, 49.953753501176834, 45.69311812520027, 50.43801091611385, 48.468565195798874, 48.329184874892235, 47.36558698117733, 48.1132310628891, 46.12599469721317, 44.43391129374504, 42.44576297700405, 41.752573773264885, 43.21160048246384, 42.88923338055611, 42.18512736260891, 43.551116064190865, 44.55634072422981, 45.5558542907238, 45.48917546868324, 54.27002169191837, 55.89586704969406, 64.61329087615013, 60.08443169295788, 57.99405746161938, 57.754267528653145, 52.541574239730835, 55.9651867300272, 58.67476053535938, 48.4097595512867, 36.41060762107372, 14.458948988467455, 1.5923398244194686, 0.13761446956777945, 0.2031309250742197, 0.02454111116094282, 0.09827803776715882, 0.11188489981577732, 0.039738419800414704, 0.029906219169788528, 0.03498761339869816, 0.0760660030937288, 0.049462951501482166, 0.04032359582197387, 0.06511370680527762, 0.019717798786587082, 0.06839405148639344, 0.039610878011444584, 0.010442501134093618, 0.0420478423620807, 0.11769800155889243, 0.10063473513582721, 0.06412628674297594, 0.03102221631706925, 0.020255547860870138, 0.11080241063609719, 0.042424181738169864, 0.035077635911875404, 0.06688671244774014, 0.09922766024828888, 0.025570009856892284, 0.07128430108423345, 0.010589358244033065, 0.08760042517678812, 0.06121305654232856, 0.09548938076477498, 0.047243929948308505, 3.594428049400449, 37.65669375658035, 33.57989251613617, 13.687487784773111, 3.7958464538678527, 1.164194354787469, 0.8066477905958891, 1.4169030007906258, 6.274278424680233, 38.1132772564888, 64.74129840731621, 89.27878573536873, 12.250118963420391, 0.10342066845623776, 0.3363784938119352, 0.12143305270001292, 0.019945827370975167, 0.11844194523291662, 0.04541281785350293, 0.12939510983414948, 0.1557921597850509, 0.11018649485777132, 0.23064446198986843, 0.1516306260600686, 0.2300181338796392, 1.2361907539889216, 12.032143659889698, 18.763070181012154, 27.965239696204662, 2.96073985286057, 1.4816245716065168, 0.5406610539648682, 2.454407522454858, 13.68495712056756, 60.28182730078697, 49.86815169453621, 55.63685394823551, 6.832696935161948, 0.5202433245722204, 0.33372822508681566, 0.24800098064588383, 0.1357023260788992, 0.14917445863829926, 0.15817184146726504, 0.31841911375522614, 0.12136400328017771, 0.14286215126048774, 0.24805074906907976, 0.26595443836413324, 0.09933023247867823, 0.25776409660466015, 0.28547173482365906, 0.12281697258003987, 0.0866196547576692, 0.210271944233682, 0.21924982342170551, 0.16479641490150243, 0.09488749157753773, 0.33098661282565445, 0.17990406282478943, 0.20690039702458307, 0.18533054273575544, 0.18088115961290896, 0.11427838544477709, 0.1768634986365214, 0.2661685034399852, 0.38337152218446136, 0.4295953590190038, 0.20823694561840966, 3.7643556436523795, 3.2253144308924675, 0.5455915862694383, 4.924361910670996, 40.89156277477741, 62.389053627848625, 68.47107946872711, 68.67197468876839, 66.27646923065186, 65.54670318961143, 69.72113639116287, 63.49779233336449, 63.79489079117775, 67.2646214067936, 66.78025379776955, 53.54948915541172, 59.096009731292725, 51.625504195690155, 48.43379706144333, 47.07102678716183, 48.20247307419777, 47.246113792061806, 48.77838537096977, 47.50905968248844, 48.19724075496197, 49.3981397151947, 50.15280582010746, 54.93728868663311, 52.34689548611641, 55.22296115756035, 52.97858498990536, 53.29087123274803, 52.97251671552658, 52.92341575026512, 51.790628135204315, 54.593118354678154, 58.13422054052353, 52.75982692837715, 53.633160665631294, 55.1052662730217, 52.700713500380516, 52.00384609401226, 52.40422680974007, 49.063024297356606, 51.998302191495895, 53.089048862457275, 50.14237158000469, 50.29774524271488, 50.3206542134285, 47.883343398571014, 47.65760511159897, 45.09077064692974, 44.593054354190826, 47.217326536774635, 47.92685866355896, 44.7484166175127, 47.96485282480717, 47.492169588804245, 48.55815298855305, 48.03928703069687, 57.26545035839081, 57.30956219136715, 64.24209639430046, 61.177036464214325, 63.44701185822487, 64.01194274425507, 55.873292461037636, 61.80581912398338, 64.28210824728012, 59.42083530128002, 50.06337381899357, 32.49019838869572, 5.433312775567174, 0.19161757256370038, 0.5171478562988341, 0.12752782175084576, 0.1581701048417017, 0.40182045253459364, 0.1314743107650429, 0.13580091297626495, 0.1126826269319281, 0.1693140756106004, 0.15000642102677375, 0.14740198734216392, 0.21704430895624682, 0.12017043685773388, 0.09874308234429918, 0.15222386922687292, 0.14497848926112056, 0.1784807423246093, 0.21878995903534815, 0.19758913025725633, 0.40882190340198576, 0.10368689167080447, 0.0783082538691815, 0.3166724246693775, 0.1815948385046795, 0.11106245176051743, 0.16884628508705646, 0.10992588227964006, 0.15618760575307533, 0.1338716852478683, 0.10400546598248184, 0.19138617091812193, 0.22355735243763775, 0.28839080943726003, 0.1372790485038422, 3.836432076059282, 48.369865491986275, 43.872214034199715, 35.87920993566513, 12.825605683028698, 4.107651310041547, 0.7695846387650818, 3.242346066981554, 12.429887317121029, 53.58478166162968, 62.502481341362, 99.3134468793869, 11.949346102774143, 0.11560114493477158, 0.3486678359331563, 0.22246863663895056, 0.19415022572502494, 0.1979722862597555, 0.16452232492156327], [0.09181650675600395, 0.06505371900857426, 0.09618507741834037, 0.035443759625195526, 0.043857469281647354, 0.020091507249162532, 0.3029094741214067, 9.714184440672398, 15.221863500773907, 3.3882164396345615, 1.908070701174438, 1.0764533816836774, 1.1304617836140096, 1.2720499048009515, 5.601869830861688, 21.098521761596203, 29.059725366532803, 40.70650890469551, 13.131547216325998, 0.28696535155177116, 0.08447918211459182, 0.0838232645764947, 0.03268999840656761, 0.04795654756890144, 0.10017539767432027, 0.0697516102809459, 0.07594014969072305, 0.013211932800913928, 0.03878573224938009, 0.04183690914942417, 0.09020185316330753, 0.08715057236258872, 0.015414097397297155, 0.02045995759544894, 0.07538111953181215, 0.08036749102757312, 0.031032801198307425, 0.04247595396009274, 0.0759529962670058, 0.07325623198994435, 0.024950264596554916, 0.0408397929277271, 0.035725085544981994, 0.030474620798486285, 0.11623686863458715, 0.05105471354909241, 0.059094536627526395, 0.0402623278205283, 0.4350565862841904, 0.07141038455301896, 1.5324838925153017, 0.10280844115186483, 0.053462259165826254, 0.08541433271602727, 5.314027201384306, 39.92952659726143, 54.515298530459404, 57.6231973618269, 59.45990480482578, 58.398864939808846, 57.9646660387516, 56.14525906741619, 52.9692716896534, 58.15938279032707, 56.81947588920593, 50.4476547986269, 57.015036195516586, 54.0626136213541, 44.520497247576714, 43.787611573934555, 44.0094018727541, 44.96594734489918, 44.57091674208641, 43.43582645058632, 42.97761283814907, 44.09783452749252, 41.854267716407776, 45.88784247636795, 46.95409566164017, 44.656115770339966, 45.81862919032574, 44.08470243215561, 47.37114988267422, 45.8969733864069, 47.1485236287117, 48.15618395805359, 46.813005432486534, 45.925962030887604, 45.418905839324, 47.694569528102875, 44.97267298400402, 45.93181371688843, 46.43036976456642, 45.82437068223953, 44.243872091174126, 42.99937427043915, 46.136398538947105, 42.74352639913559, 44.08471003174782, 42.52233646810055, 37.27571479976177, 41.75008490681648, 39.23020452260971, 39.74113650619984, 39.94633309543133, 39.31087799370289, 39.0273068100214, 39.930396750569344, 40.04624493420124, 44.604826122522354, 46.0314329713583, 48.073583990335464, 53.97384278476238, 56.768285036087036, 46.19216054677963, 47.155336663126945, 46.54304891824722, 46.494669914245605, 36.269308403134346, 25.56573875248432, 13.277859315276146, 1.2737233587540686, 0.09595611001714133, 0.13371863955399022, 0.024686494180059526, 0.05590097498497926, 0.06972003189730458, 0.04917746955470648, 0.04946212771756109, 0.060144842573208734, 0.040787144971545786, 0.056376769571215846, 0.003748371764231706, 0.030618909149779938, 0.08627462288131937, 0.09937391529092565, 0.06401804450433701, 0.09279045683797449, 0.05620646152237896, 0.010890885423577856, 0.07473884266801178, 0.0512051023542881, 0.05200462546781637, 0.07323277270188555, 0.05296099036058877, 0.09169420081889257, 0.026093509695783723, 0.06379376747645438, 0.16401422093622386, 0.08741061348700896, 0.07152986290748231, 0.07543715910287574, 0.02377242057264084, 0.07549689456936903, 0.047338913718704134, 0.3032560274004936, 0.07491469455999322, 9.44535456597805, 46.36791251599789, 22.178211025893688, 10.082345735281706, 5.918036140501499, 1.1408961424604058, 0.5366368324030191, 2.661374816671014, 2.2329551680013537, 9.876006357371807, 30.57590290904045, 32.97714225947857, 1.9103568722493947, 1.2718996941111982, 0.14706325629958883, 0.10173706934438087, 0.07457743296981789, 0.10209348576609045, 0.07433509206748568, 0.07450626842910424, 0.06816307286499068, 0.06272318976698443, 0.04331223193730693, 0.09390338891535066, 0.07219319450086914, 0.18211618240457028, 13.75469857826829, 19.00154158473015, 6.499483315274119, 3.6071944143623114, 1.9055905030108988, 3.096255543641746, 3.2807698426768184, 7.443004511296749, 32.981819808483124, 39.503672048449516, 47.601117342710495, 18.04818794131279, 0.35005277255550027, 0.07264632018632255, 0.07462060370016843, 0.02512692728487309, 0.02599972449388588, 0.030682776523462962, 0.04922407271806151, 0.09051912871655077, 0.05097524437587708, 0.0017628076057008002, 0.05343221331713721, 0.03163432302244473, 0.043885492777917534, 0.025661036124802195, 0.01640129295992665, 0.01803366161766462, 0.04740346943435725, 0.06361317326081917, 0.010809064569912152, 0.053225517767714337, 0.07003694379818626, 0.025960270068026148, 0.03129250464553479, 0.1384863891871646, 0.09100907234824263, 0.035906518387491815, 0.017615413162275217, 0.029233733184810262, 0.021544934825215023, 0.2847191970795393, 0.489671797840856, 0.9642021800391376, 0.07413912797346711, 0.05474845675053075, 0.2779394405661151, 3.5052254609763622, 29.44486889988184, 48.476917147636414, 53.283473029732704, 55.262688025832176, 53.54666590690613, 55.48507109284401, 53.629072085022926, 52.56569914519787, 57.45302349328995, 56.845538690686226, 52.934910133481026, 55.873756036162376, 51.883685141801834, 49.60913099348545, 47.756893783807755, 47.13314585387707, 47.782637402415276, 47.947673946619034, 46.700618863105774, 45.63570320606232, 46.84662602841854, 44.36031684279442, 48.15149500966072, 49.75085198879242, 46.86311714351177, 49.62247587740421, 48.75567018985748, 48.2413449883461, 47.61091701686382, 49.957526698708534, 49.798311442136765, 48.72638136148453, 50.76331526041031, 49.01437170803547, 50.064726546406746, 47.979265451431274, 47.906385362148285, 48.45407657325268, 47.64030084013939, 49.367425963282585, 46.40755958855152, 47.37529546022415, 44.943779334425926, 45.53361028432846, 46.27259463071823, 41.69654577970505, 43.204464465379715, 41.75808347761631, 42.66778886318207, 43.99236738681793, 42.57868744432926, 42.354054898023605, 42.35958360135555, 45.08299246430397, 47.461847215890884, 47.56574884057045, 49.73167821764946, 51.964240819215775, 57.04815901815891, 49.571661204099655, 45.71696564555168, 44.4065185636282, 39.54794727265835, 22.899321131408215, 15.803290251642466, 7.178424233570695, 1.5653053438290954, 0.40703154634684324, 0.34654092974960804, 0.07174276281148195, 0.017582419131940696, 0.018978374791913666, 0.03517574041325133, 0.08651993237435818, 0.09149178746156394, 0.09387416313984431, 0.09055620641447604, 0.041868172120302916, 0.041962432296713814, 0.06580448301974684, 0.025064482979360037, 0.019914918775612023, 0.12261979136383161, 0.03193688178726006, 0.08697690980625339, 0.05093183244753163, 0.06048559967894107, 0.06994545183260925, 0.03604833167628385, 0.018621616982272826, 0.0297040061923326, 0.01965712264791364, 0.01381414203933673, 0.10359651292674243, 0.2239641235792078, 0.05466327304020524, 0.055952602488105185, 0.019047674686589744, 0.10800230229506269, 0.12786000705091283, 0.3091157879680395, 0.17414624366210774, 17.735858000814915, 65.69095864892006, 33.25729362666607, 16.903180181980133, 6.816675569862127, 0.5835315410513431, 0.7061180099844933, 3.1496398290619254, 3.983765607699752, 15.464548878371716, 43.66512894630432, 49.41395066678524, 1.522279183845967, 1.4585469849407673, 0.16970201104413718, 0.05411975747847464, 0.019791766790149268, 0.033414456993341446, 0.0761155562940985, 0.1695290461066179, 0.25670502218417823, 0.22076782712247223, 0.14586799778044224, 0.16064255498349667, 0.17870868556201458, 0.2541458001360297, 21.572671718895435, 29.167012609541416, 19.985874965786934, 5.961607452481985, 0.8327684202231467, 2.0556870801374316, 5.731349308043718, 17.067131884396076, 61.5980538725853, 46.99238620698452, 59.07065749168396, 24.036123231053352, 0.8034572086762637, 0.4004823009017855, 0.2187644291552715, 0.15636543917935342, 0.1526733732316643, 0.19429700769251212, 0.18416301085380837, 0.382564629544504, 0.11984669719822705, 0.16025643039029092, 0.18070049118250608, 0.16197252814890817, 0.23873459897004068, 0.13306394655955955, 0.09994687556172721, 0.17696563299978152, 0.1529633006430231, 0.1147837434837129, 0.11451015816419385, 0.1441590691683814, 0.3489442414138466, 0.13936280622147024, 0.16882019117474556, 0.26042065874207765, 0.1960291209979914, 0.16383046517148614, 0.1540220039896667, 0.22768620197894052, 0.11734726998838596, 0.6746349774766713, 0.5327626434154809, 3.220933978445828, 0.3029247623635456, 0.19672098074806854, 0.33240951772313565, 11.653286889195442, 47.56076730787754, 53.1877713650465, 61.61952652037144, 59.90065075457096, 56.79949276149273, 57.59491167962551, 56.73260875046253, 54.991720765829086, 59.14093852043152, 59.41779926419258, 54.275314807891846, 54.22507770359516, 54.93730768561363, 49.960452541708946, 49.16410647332668, 50.29733866453171, 50.970590338110924, 50.51875278353691, 50.308947041630745, 48.807757794857025, 49.77087311446667, 46.8369023501873, 50.79405561089516, 51.28454089164734, 48.86340580880642, 51.389935836195946, 49.69772703945637, 53.065596520900726, 51.58942133188248, 53.633248060941696, 54.835446551442146, 51.859871819615364, 55.12502521276474, 49.792539551854134, 52.835944443941116, 50.739361345767975, 53.08914765715599, 52.98382870852947, 53.54373246431351, 52.24401980638504, 50.09968847036362, 52.55758658051491, 49.79547679424286, 48.90951633453369, 49.189173728227615, 43.21614883840084, 48.11267629265785, 44.056135565042496, 45.65666288137436, 45.95337375998497, 47.201033011078835, 45.22669695317745, 45.924943685531616, 45.77019318938255, 50.06476454436779, 48.10184307396412, 51.75414249300957, 54.77866619825363, 60.57242050766945, 50.24805910885334, 49.591442942619324, 49.34195213019848, 54.73419338464737, 45.52656166255474, 30.173548199236393, 23.606482185423374, 5.073122028261423, 0.48655483697075397, 0.5171007150784135, 0.21459522162331268, 0.1293145868112333, 0.155015220225323, 0.16333502222551033, 0.18449795694323257, 0.14444458822254092, 0.22706331743393093, 0.17855660466011614, 0.14512883353745565, 0.19876574602676556, 0.10792350847623311, 0.177401214314159, 0.1968116415082477, 0.33855723158922046, 0.09387778482050635, 0.18618107365909964, 0.2718212048057467, 0.15774626430356875, 0.16209239984164014, 0.1394554559374228, 0.07332079141633585, 0.2512190071865916, 0.04758104681968689, 0.18826806714059785, 0.2807565144030377, 0.20818181888898835, 0.1649550860747695, 0.2049605268985033, 0.2369406499201432, 0.24088997393846512, 0.17597170430235565, 0.5391139432322234, 0.18289306259248406, 16.76938746124506, 73.77734273672104, 45.11738441884518, 43.77240478992462, 14.152082204818726, 3.0111365485936403, 1.6873958799988031, 4.534191247075796, 6.467614425346255, 41.914182901382446, 50.88686563074589, 63.41477058827877, 7.737734746187925, 2.001726175658405, 0.33695428166538477, 0.1947072966140695, 0.2128173178061843, 0.1951714654569514, 0.22125782270450145], [0.01711518707452342, 0.03725830698385835, 0.025899718239088543, 0.06976105039939284, 0.09742236376041546, 0.12794722424587235, 0.008358318536920706, 12.707039695233107, 25.853096432983875, 3.452484766021371, 2.3145759757608175, 2.840336663648486, 1.334929761942476, 0.3889640502166003, 1.1418288736604154, 12.814694568514824, 23.15653122961521, 34.971366450190544, 24.21940829604864, 0.7157699076924473, 0.19086585118202493, 0.16910133155761287, 0.028463493363233283, 0.02292931854753988, 0.024771995158516802, 0.03880849020788446, 0.04851028250413947, 0.036652269191108644, 0.05951254388492089, 0.008473081470583566, 0.09361268967040814, 0.01787657121894881, 0.03170969554048497, 0.03423206624574959, 0.05764136694779154, 0.021110720917931758, 0.04600604988809209, 0.02601015909021953, 0.0942479755030945, 0.06700427606119774, 0.034275251819053665, 0.046672862154082395, 0.04150541775743477, 0.053266176328179426, 0.04301635992305819, 0.07090890052495524, 0.04172156455751974, 0.1017767445591744, 0.03990845325461123, 0.32396435213740915, 0.25042648252565414, 0.031748016335768625, 0.07227320544188842, 0.29671087861061096, 0.1856722720549442, 2.093195579946041, 23.3588969707489, 35.71280926465988, 45.31563878059387, 50.918308943510056, 50.611300617456436, 58.89634944498539, 55.53635314106941, 53.63287568092346, 53.84323999285698, 49.85330209136009, 54.170543029904366, 48.537356704473495, 48.48141610622406, 45.251156240701675, 41.64253927767277, 44.1347723454237, 45.04267282783985, 42.09023505449295, 43.168301805853844, 45.50857722759247, 45.055538937449455, 44.240030497312546, 48.37379448115826, 45.925585851073265, 48.27877677977085, 45.52314184606075, 44.29779499769211, 42.53125458955765, 45.59426262974739, 45.292273834347725, 48.81128780543804, 44.32643786072731, 43.93258899450302, 47.894894778728485, 42.72610433399677, 43.16835880279541, 41.25752113759518, 43.27884927392006, 43.639715909957886, 42.48814210295677, 43.16720366477966, 43.47856655716896, 44.66890208423138, 41.57641902565956, 38.086028918623924, 41.54190167784691, 40.22065557539463, 38.374851420521736, 40.24933263659477, 39.11910988390446, 40.41634127497673, 41.788983419537544, 44.64975871145725, 44.45220731198788, 45.23624584078789, 47.22180649638176, 41.54919348657131, 45.228251069784164, 44.32321183383465, 38.36013101041317, 33.22089157998562, 11.618258468806744, 2.784685562364757, 4.069506581872702, 1.6284754103980958, 0.8231812971644104, 1.3921543350443244, 1.0701324208639562, 0.8490446687210351, 0.20827619038755074, 0.0934443631558679, 0.25804154109209776, 0.4587608721340075, 0.7935314881615341, 0.1335047822794877, 0.2076897452934645, 0.17171248910017312, 0.048308258774341084, 0.05983475100947544, 0.02211409344454296, 0.009809992789087119, 0.06501539450255223, 0.016782307866378687, 0.18589461949886754, 0.04542061040410772, 0.05388506811868865, 0.0736092493752949, 0.04207595491607208, 0.07999350054888055, 0.012442071474652039, 0.016111074255604763, 0.08656210120534524, 0.035841472854372114, 0.05129420831508469, 0.03734063713636715, 0.1086478668730706, 0.028474733189796098, 0.050795147399185225, 0.1100222798413597, 0.06665436827461235, 0.2639470179565251, 35.755541771650314, 56.82702608406544, 24.902708530426025, 15.264509562402964, 6.032330207526684, 1.3083644374273717, 1.3140078471042216, 2.7652576798573136, 1.4944311906583607, 9.248835761100054, 14.1774638928473, 6.071565002202988, 36.062242314219475, 36.05564966797829, 1.1742657143622637, 0.13629602937726304, 0.054536254465347156, 0.022478293140011374, 0.045968307967996225, 0.04059806058648974, 0.06626042886637151, 0.025882621011987794, 0.050291073275730014, 0.18297818693099543, 0.06987711487454362, 0.1161448349012062, 14.749458599835634, 36.09035700559616, 5.699895545840263, 4.375749249011278, 6.561104133725166, 2.237745998427272, 0.7909684663172811, 2.1755499858409166, 18.211223892867565, 35.25236137211323, 42.258835807442665, 34.54332321882248, 1.6388490912504494, 0.19342183746630326, 0.04775436427735258, 0.08590144134359434, 0.017836396909842733, 0.019921386592614, 0.04681395927036647, 0.06351811898639426, 0.018944785188068636, 0.018604135693749413, 0.03365842319908552, 0.028490620716183912, 0.016730789830035064, 0.07449121767422184, 0.01584365061717108, 0.02283573558088392, 0.1159042380459141, 0.029260001501825172, 0.03773506265133619, 0.05965564851067029, 0.07866523432312533, 0.025154212344205007, 0.01969483488210244, 0.07268736095284112, 0.053712811932200566, 0.09176544699585065, 0.06375421842676587, 0.03203744279744569, 0.10378636172390543, 0.24862221762305126, 0.11820145227829926, 0.032333797207684256, 0.03744257483049296, 0.08435322481091134, 0.09701010814751498, 0.2866546291625127, 1.364605575799942, 16.40136580914259, 29.944857470691204, 42.79261976480484, 46.72668546438217, 48.29290062189102, 55.25804467499256, 54.02186080813408, 53.86185519397259, 54.63624984025955, 51.46894879639149, 52.56182335317135, 47.08080366253853, 50.140015706419945, 47.96468563377857, 45.185659155249596, 46.683246195316315, 47.73061439394951, 46.29266895353794, 44.159277230501175, 45.146091878414154, 47.60504633188248, 48.63448329269886, 51.39617130160332, 50.06305083632469, 51.14480338990688, 48.92800614237785, 44.3330343067646, 42.88375027477741, 48.509530797600746, 47.36168459057808, 52.230697721242905, 47.06294842064381, 48.20251867175102, 50.30018851161003, 45.8586410433054, 45.411845818161964, 46.03248551487923, 46.90485790371895, 48.09027649462223, 44.792384058237076, 44.65856283903122, 45.76248340308666, 47.10002303123474, 44.02037188410759, 42.31661170721054, 46.23450547456741, 42.404956966638565, 41.69309176504612, 40.93736171722412, 42.36542388796806, 43.827049657702446, 44.51462656259537, 48.522400707006454, 50.23526519536972, 50.02490848302841, 48.632138818502426, 45.31629614531994, 44.51512813568115, 43.34601067006588, 37.80267812311649, 31.419140361249447, 3.4515355294570327, 6.120471702888608, 4.6425072848796844, 2.425692225806415, 0.9503861214034259, 1.5342417731881142, 1.4524131640791893, 0.8874083601403981, 0.41116554639302194, 0.12221722077811137, 0.46649203228298575, 0.9661293297540396, 0.7988519745413214, 0.20695709710707888, 0.1942040165886283, 0.33867475809529424, 0.09741164714796469, 0.019740981624636333, 0.01674916726187803, 0.08698546676896513, 0.023479103401768953, 0.04132240414037369, 0.10897786283749156, 0.11083043413236737, 0.07131518184905872, 0.08407563931541517, 0.07241252140374854, 0.06511608167784289, 0.07000140234595165, 0.03007919338415377, 0.10950639072689228, 0.0297672149099526, 0.009085686342586996, 0.03964005925809033, 0.011262095631536795, 0.05279853052343242, 0.07859873789129779, 0.04346706991782412, 0.025499286894046236, 0.23510362661909312, 54.76606607437134, 58.55894275009632, 33.59356798231602, 23.5941556468606, 6.565170865505934, 1.4897307241335511, 2.9527381947264075, 4.058499047532678, 5.5534490291029215, 15.47082044184208, 27.36651912331581, 7.965585719794035, 58.74163314700127, 55.99354840815067, 2.095280005596578, 0.07042231140076183, 0.11465328876511194, 0.01914404441777151, 0.03333996392029803, 0.08750360459089279, 0.15228874777676538, 0.15414888155646622, 0.24855931318597868, 0.2391107936273329, 0.2728108735755086, 0.15257722057867795, 20.812997482717037, 52.529088109731674, 25.828946828842163, 3.97512249648571, 8.759649060666561, 2.3664137441664934, 1.0346596618182957, 9.96974352747202, 49.81799438595772, 47.98759840428829, 48.725591003894806, 49.923647716641426, 0.945173513609916, 0.26261771272402257, 0.32805521856062114, 0.14788739645155147, 0.1229683707060758, 0.10431703442009166, 0.1400792459025979, 0.32311877876054496, 0.0906392972683534, 0.26186529372353107, 0.19779500202275813, 0.1518039620714262, 0.1715423443238251, 0.18543606129242107, 0.14170374779496342, 0.12867093697423115, 0.1672631356632337, 0.1871875298093073, 0.07389617108856328, 0.20594549045199528, 0.147374082589522, 0.16404369904194027, 0.14032192819286138, 0.29414381948299706, 0.10580083253444172, 0.2141531094093807, 0.2952030720189214, 0.2569835650501773, 0.34787311451509595, 0.3401043720077723, 0.884121002163738, 0.3184926457470283, 0.25576430547516793, 0.28761211840901524, 0.5255519365891814, 0.8342131739482284, 12.365240436047316, 30.382495187222958, 39.68899950385094, 49.783921614289284, 51.270466446876526, 54.46879282593727, 59.56848777830601, 53.61356511712074, 54.81037549674511, 54.19634744524956, 54.34984400868416, 59.65685963630676, 47.92540334165096, 54.1288098692894, 50.9262353181839, 47.603997588157654, 48.124022483825684, 50.345512479543686, 47.648109421133995, 47.12735876441002, 49.377286434173584, 50.949816852808, 48.38639460504055, 53.50487194955349, 49.68320041894913, 53.61079506576061, 50.701579973101616, 48.9842165261507, 46.04718692600727, 51.92998945713043, 52.959897592663765, 57.17315711081028, 50.079424157738686, 51.55010484158993, 53.95854860544205, 47.75914706289768, 48.91982898116112, 45.92872068285942, 50.58113023638725, 50.70128358900547, 47.807332277297974, 48.81479121744633, 51.45442597568035, 49.521161913871765, 49.33118350803852, 43.916572853922844, 49.1015238314867, 45.547745525836945, 41.94763630628586, 45.123574286699295, 44.35535050928593, 46.26102805137634, 46.793284490704536, 48.722330778837204, 50.25927230715752, 48.12836945056915, 48.01282525062561, 46.52161046862602, 46.53652086853981, 48.00318896770477, 39.958070665597916, 41.72350533306599, 28.31334851682186, 9.785487614572048, 8.184687662869692, 3.222474083304405, 1.2891542119905353, 1.55612159287557, 1.2596990237943828, 0.6004050699993968, 0.2888239861931652, 0.3684809821425006, 0.7083633332513273, 2.1720890840515494, 1.088035753928125, 0.29936325503513217, 0.2157003091997467, 0.48364119487814605, 0.27427061868365854, 0.1704897711169906, 0.1368093432392925, 0.14051732083316892, 0.1622056367341429, 0.13266971771372482, 0.2026688342448324, 0.2584061730885878, 0.1398563344264403, 0.15150340710533783, 0.1615757166291587, 0.16462055558804423, 0.15178414672845975, 0.1010629914526362, 0.19986831030109897, 0.1610956955119036, 0.12264260498341173, 0.12016345324809663, 0.2395794598851353, 0.15777532680658624, 0.17602182895643637, 0.2250450468272902, 0.21292072866344824, 0.4064578958787024, 55.68938232958317, 72.02923133969307, 48.42402398586273, 44.05603677034378, 17.64374904334545, 4.07483484596014, 2.82755343709141, 5.237046182155609, 5.250050509348512, 31.966176107525826, 36.32082983851433, 17.3673689737916, 74.86789181828499, 64.7308337688446, 2.0005532260984182, 0.21098112571053207, 0.16455385135486722, 0.11854861411848105, 0.23417825752403587], [0.12011768500087783, 0.11346511033480056, 0.044739760414813645, 0.38830935722216964, 4.14116408675909, 1.52005594689399, 0.32670596439857036, 12.489939294755459, 26.54751107096672, 1.6592348786070943, 1.259794612415135, 1.6736063011921942, 3.0522140068933368, 0.5186511506326497, 2.557557262480259, 17.607941664755344, 26.645426116883755, 30.295989029109478, 35.50540119409561, 6.589352292940021, 0.29427847475744784, 0.1358166168211028, 0.13320496946107596, 0.028690714862023015, 0.026598550466587767, 0.019397903452045284, 0.09538350597722456, 0.06948371723410673, 0.028599469660548493, 0.058746350623550825, 0.038974137569312006, 0.08734773873584345, 0.025057271159312222, 0.08235736706410535, 0.10582101152976975, 0.12512841378338635, 0.09890325265587308, 0.09960375100490637, 0.03160064807161689, 0.04119482895475812, 0.09468279240536503, 0.03824160070507787, 0.0848096827394329, 0.07790123781887814, 0.08465506369248033, 0.09407262085005641, 0.05854273869772442, 0.052061704045627266, 0.26097771478816867, 0.014154430664348183, 0.06873198100947775, 0.1165128214051947, 0.050337995562586, 0.07333933026529849, 0.12603128096088767, 0.5054478091187775, 2.3312126705422997, 5.321207391098142, 19.696212708950043, 29.20841708779335, 32.93679982423782, 35.31080983579159, 57.958092391490936, 55.56115061044693, 51.296464651823044, 51.49010606110096, 45.17003059387207, 45.868277326226234, 49.03186596930027, 44.064958691596985, 44.035932049155235, 42.15518116950989, 43.32415044307709, 43.60109098255634, 44.22067813575268, 42.86412052810192, 48.391638323664665, 46.78285785019398, 48.46206374466419, 48.17319184541702, 44.7499593347311, 43.902209624648094, 41.78394868969917, 39.221392795443535, 42.99626983702183, 42.6655887812376, 47.01949395239353, 44.46361429989338, 48.39087076485157, 47.728767693042755, 43.03395241498947, 41.50687895715237, 41.94049648940563, 40.51541715860367, 43.06840896606445, 41.98998123407364, 42.141004130244255, 39.84211228787899, 41.019539907574654, 37.27464705705643, 39.27883431315422, 41.744727194309235, 40.480565428733826, 39.28337886929512, 38.610488176345825, 38.05866278707981, 40.02143606543541, 43.7862778455019, 48.42024698853493, 52.81126856803894, 57.21264839172363, 50.2976730465889, 41.106768026947975, 37.42565095424652, 34.80244651436806, 30.24092048406601, 4.941384997218847, 3.475644998252392, 3.1856564339250326, 2.469836832024157, 1.9330725283361971, 2.0708646532148123, 3.2729301508516073, 4.184255199506879, 3.208877225406468, 1.3556859106756747, 0.31075688428245485, 0.20982037705834955, 0.46890095458365977, 16.677483692765236, 2.942361426539719, 1.200634518172592, 0.24971728620585054, 0.029304738163773436, 0.11094689936726354, 0.0762419292004779, 0.08531187180778943, 0.026617920520948246, 0.12153042247518897, 0.08068254013778642, 0.04473562294151634, 0.1530478015774861, 0.06793740059947595, 0.17716901114908978, 0.020500181999523193, 0.05130403063958511, 0.07889168584370054, 0.06719234370393679, 0.03696039035276044, 0.1335183487390168, 0.07038050622213632, 0.08426029307884164, 0.020588707229762804, 0.10843377211131155, 0.07298925920622423, 0.09342151985038072, 2.084445124492049, 62.555515095591545, 38.04334580898285, 23.275567442178726, 14.910425562411547, 9.996825624257326, 5.51436242647469, 1.4785336749628186, 0.12753254181006923, 0.8738655899651349, 1.3179360050708055, 1.3842090801335871, 4.555253041908145, 52.53407344222069, 65.64791455864906, 6.813528863713145, 0.2335249152383767, 0.059083222586195916, 0.05993914521241095, 0.03559281998605002, 0.09616657567676157, 0.03753746954316739, 0.011862298288178863, 0.3539340861607343, 7.166865253821015, 3.949893512763083, 0.7309670140966773, 15.8617377653718, 42.51824788749218, 3.8110228395089507, 5.126944715157151, 6.953882882371545, 2.3023190209642053, 2.4553493969142437, 4.129273099824786, 20.644391030073166, 43.83945979177952, 37.31446132063866, 45.223945900797844, 13.203634098172188, 0.6571435066871345, 0.49684204277582467, 0.0916994403814897, 0.09338118412415497, 0.0897182771586813, 0.09261224491638131, 0.05267172346066218, 0.0548313954641344, 0.04363857282442041, 0.20027067308546975, 0.026130444530281238, 0.06985604530200362, 0.10472736787050962, 0.07000843790592626, 0.03615500056184828, 0.13131268584402278, 0.07494881108868867, 0.19815633888356388, 0.09394019944011234, 0.028760350578522775, 0.057008404037333094, 0.01753338914568303, 0.015488366898352979, 0.023096242402971257, 0.03427237599680666, 0.15369731438113376, 0.051755460517597385, 0.5359902733471245, 0.3800694103119895, 0.07142193237086758, 0.05847192667715717, 0.06608074749237858, 0.06512788182590157, 0.052332851410028525, 0.14209429558832198, 0.3694031748455018, 2.233606120571494, 3.831918155774474, 14.61358929052949, 27.88429643958807, 31.577048487961292, 35.03209099173546, 54.95071716606617, 54.95105154812336, 48.09901982545853, 52.18162715435028, 48.12882162630558, 48.04215207695961, 49.51703533530235, 47.565889433026314, 45.0729002058506, 45.3958410769701, 45.83441734313965, 46.43434435129166, 47.33102023601532, 46.03602692484856, 48.9818112552166, 49.808422699570656, 48.471464440226555, 49.30726379156113, 45.905906707048416, 47.1260554343462, 42.05468036234379, 40.44555030763149, 44.86307166516781, 45.8206582814455, 48.00315856933594, 47.704053819179535, 47.48487018048763, 51.11200734972954, 46.86747930943966, 44.01145376265049, 44.57415796816349, 42.5410770624876, 45.44834665954113, 45.078725293278694, 44.134453162550926, 43.48953276872635, 43.65329638123512, 41.507760509848595, 42.3264379799366, 43.128548339009285, 44.913703948259354, 41.57367557287216, 41.398846954107285, 41.05153039097786, 43.080921694636345, 45.67621663212776, 52.14674882590771, 56.81940749287605, 59.43288065493107, 52.22752869129181, 42.25334130227566, 36.95561997592449, 34.41250383853912, 27.342960387468338, 6.870774691924453, 4.833871191367507, 4.492919761687517, 3.143462548032403, 2.8430124325677752, 2.5714231934398413, 4.474021000787616, 5.1025789976119995, 3.6182083608582616, 1.8590409820899367, 0.670639966847375, 0.19711397762876004, 0.34751373692415655, 21.050562635064125, 11.423799153417349, 1.6130105964839458, 0.402917138999328, 0.050973125544260256, 0.10184946018853225, 0.00822040245111566, 0.01711967335722875, 0.03702068985148799, 0.027482238692755345, 0.02396040472376626, 0.08765024555032142, 0.06279537847149186, 0.035345272917766124, 0.14864395663607866, 0.06928976436029188, 0.031655797065468505, 0.08609472628450021, 0.13697021116968244, 0.03136149469355587, 0.08287825825391337, 0.04236216416757088, 0.040478077571606264, 0.01477986170357326, 0.017101939738495275, 0.047806322036194615, 0.23353695287369192, 4.495344506576657, 78.70500952005386, 39.30326700210571, 28.92782684415579, 27.845720909535885, 12.523764129728079, 2.9029302299022675, 3.9903269056230783, 0.3065237926784903, 1.628378159366548, 3.8481660839170218, 3.9322178112342954, 15.131333358585835, 70.72897911071777, 82.3602993786335, 7.338108764961362, 0.05054847235442139, 0.052446908375713974, 0.02775077740807319, 0.028387757192831486, 0.3054052573861554, 0.12309569356148131, 0.35555140406358987, 0.6854012841358781, 10.106039363890886, 2.9943229258060455, 0.761913622263819, 17.687553092837334, 55.00469706952572, 24.687564074993134, 3.6235119262710214, 13.824696522206068, 3.052447931841016, 1.2242422951385379, 3.263516630977392, 49.7242534160614, 58.68559755384922, 43.377579376101494, 64.13144633173943, 16.428209468722343, 0.49201636109501123, 0.6571010558400303, 0.21144496800843626, 0.16589154285611585, 0.3508357977261767, 0.17061981023289263, 0.24345471756532788, 0.1984959011315368, 0.14342934504384175, 0.22491594281746075, 0.1579928057617508, 0.23896876140497625, 0.18830259185051546, 0.19620198203483596, 0.2276784391142428, 0.21327736030798405, 0.2920985495438799, 0.26879817014560103, 0.24668025464052334, 0.23337339836871251, 0.20456764876144007, 0.12068362455465831, 0.11907139036338776, 0.14094913203734905, 0.09294713163399138, 0.2337701356736943, 0.2685298689175397, 0.4129004501737654, 0.6784664187580347, 0.18270746630150825, 0.1558517839293927, 0.24489130766596645, 0.18331417202716693, 0.26223452703561634, 0.2153201069450006, 1.401094899047166, 5.487343026325107, 9.93140073493123, 25.808272138237953, 32.555847465991974, 36.01274237036705, 43.5014109313488, 58.84699389338493, 54.517855793237686, 51.61776401102543, 52.30336122214794, 49.29838366806507, 49.35937039554119, 51.06467328965664, 50.253268629312515, 48.46899077296257, 48.419756814837456, 48.35623562335968, 48.16540986299515, 50.534252151846886, 49.719883650541306, 53.91458496451378, 50.9093414247036, 52.14923769235611, 52.393959760665894, 52.054710164666176, 50.540392622351646, 45.5732611566782, 42.88653552532196, 50.00870995223522, 49.66706648468971, 53.87468330562115, 48.9794135838747, 50.719184428453445, 53.84124130010605, 48.956827595829964, 49.101379439234734, 49.65288184583187, 46.50954611599445, 48.42541091144085, 48.67552489042282, 49.17180486023426, 45.53758107125759, 45.44456586241722, 44.4072101265192, 46.25005044043064, 44.934302642941475, 47.39679090678692, 44.22291241586208, 46.14610701799393, 44.47288580238819, 45.84768243134022, 48.79223942756653, 50.25635786354542, 54.262836277484894, 62.07301318645477, 51.220172345638275, 41.33819080889225, 39.55719217658043, 37.8235200047493, 37.56539225578308, 23.538988307118416, 6.118761794641614, 6.734469830989838, 3.608336253091693, 2.6763968355953693, 2.212820998392999, 4.046514015644789, 4.296083673834801, 3.6632497189566493, 1.3419294613413513, 0.5393831944093108, 0.6664366205222905, 1.7391644208692014, 24.963246881961823, 16.15656204521656, 2.2398465732112527, 0.6172405416145921, 0.1453106597182341, 0.18138868472306058, 0.1717984298011288, 0.17831543635111302, 0.19597815029555932, 0.16042801493313164, 0.08026002804399468, 0.15708956751041114, 0.19148002291331068, 0.12535245332401246, 0.2703394030686468, 0.13638346921652555, 0.17463279567891732, 0.2061048147152178, 0.20957005064701661, 0.07445877097779885, 0.16763777181040496, 0.11578449993976392, 0.15309035632526502, 0.08996582793770358, 0.18317473732167855, 0.19476245302939788, 0.3688610211247578, 4.359235810115933, 84.65912282466888, 48.876032531261444, 44.74151998758316, 39.03927616775036, 26.70359719544649, 15.700461119413376, 4.855280667543411, 0.31661064829677343, 2.2772947512567043, 6.832548743113875, 1.0073757008649409, 32.087359204888344, 73.43041375279427, 90.79842299222946, 9.6916763484478, 0.30618121731095016, 0.17693496745778248, 0.17977430572500452, 0.10370111122028902], [0.07492977500078268, 0.043778890685644, 0.1892443624092266, 2.95039395801723, 46.91695645451546, 36.40526130795479, 4.260352766141295, 7.765847537666559, 13.97552277892828, 2.8666785126551986, 2.607745681889355, 3.1137414928525686, 1.4823522325605154, 2.2785075986757874, 2.032026224769652, 9.026138260960579, 25.14615386724472, 34.45459417998791, 29.18324153870344, 14.28659688681364, 0.4107338539324701, 0.2084979144274257, 0.1299383322475478, 0.05501597872353159, 0.08945220979512669, 0.0334290513274027, 0.14706661080708727, 0.05859299322764855, 0.01441506365154055, 0.051324718006071635, 0.01241831254446879, 0.044167256564833224, 0.038725607155356556, 0.04929220558551606, 0.37389598845038563, 0.5456620012409985, 0.4505421209614724, 0.4866816848516464, 0.31070496363099664, 0.08275198182673194, 0.04778742695634719, 0.054721093765692785, 0.05517613419215195, 0.04943637519318145, 0.10339917585952207, 0.06058593062334694, 0.30063648358918726, 2.258801143616438, 0.3347655991092324, 0.0591376257216325, 0.12253010281710885, 0.01505534228272154, 0.01529134153315681, 0.19513135979650542, 0.23792669700924307, 0.2934050263138488, 0.21728169231209904, 0.925405549351126, 1.2052593450061977, 9.969996213912964, 20.020016133785248, 21.12204249948263, 27.49554879963398, 54.690773114562035, 50.29369466006756, 48.31735610961914, 50.26474021375179, 44.75508525967598, 46.83599039912224, 45.08770801126957, 44.3209433555603, 41.57657101750374, 42.45152726769447, 44.94820609688759, 44.285392463207245, 43.30991640686989, 44.46636155247688, 44.87654194235802, 47.01093301177025, 46.13826423883438, 45.28369389474392, 37.32436738908291, 41.00185565650463, 41.11642710864544, 40.14158941805363, 43.866461142897606, 46.630235239863396, 48.613914996385574, 47.345235273242, 45.778537541627884, 40.333509519696236, 38.869527876377106, 37.97441750764847, 40.005997493863106, 41.15863524377346, 41.637751534581184, 42.52140171825886, 40.621507465839386, 41.446910575032234, 39.173336774110794, 40.9785059094429, 39.64292697608471, 41.486341059207916, 37.989232912659645, 38.051857352256775, 36.64746031165123, 40.054729878902435, 46.41921356320381, 56.64098046720028, 58.119519129395485, 58.142663687467575, 50.67230634391308, 43.784909918904305, 30.36103393882513, 27.53227762877941, 9.005881547927856, 5.38978848606348, 3.605632223188877, 2.469747536815703, 2.9706929437816143, 4.5473000686615705, 6.721433205530047, 10.514339804649353, 6.926193768158555, 5.205224314704537, 1.962493162136525, 0.3241240029456094, 0.04600847671099473, 0.27508754516020417, 1.3886056817136705, 3.7935813004150987, 0.41548496461473405, 0.15119329327717423, 0.05728531046770513, 0.03654200460005086, 0.04925086424918845, 0.16016461187973619, 0.05589416206930764, 0.08776374961598776, 0.0859190673509147, 0.06729216998792253, 0.09818794846069068, 0.0655566131172236, 0.06158712494652718, 0.06269751887884922, 0.08749369691940956, 0.18721941247349605, 0.0857591196836438, 0.014579739727196284, 0.09284772095270455, 0.09437347267521545, 0.029362000423134305, 0.13878682540962473, 0.0383713763585547, 0.09466892166528851, 0.45783526555169374, 10.377349555492401, 64.68060806393623, 29.578914307057858, 29.723084270954132, 14.863366987556219, 14.847200755029917, 11.984578762203455, 7.662452710792422, 0.8920500485692173, 0.012716341425402788, 0.7361032103653997, 6.367554869502783, 26.711350679397583, 48.527313843369484, 46.095125153660774, 3.1164785334840417, 0.16596562403719872, 0.06854541250504553, 0.03950312930101063, 0.11656511313049123, 0.06658049489487894, 0.08942620494053699, 0.11324475184665062, 4.256286509335041, 57.355554923415184, 59.650962352752686, 5.134922387078404, 8.726246003061533, 31.316973343491554, 4.1156156826764345, 6.114728786051273, 7.149927187711, 1.1448466242291033, 6.675188262015581, 5.378132136538625, 10.285829566419125, 45.35552144050598, 42.01615422964096, 30.80316871404648, 42.37714625895023, 1.8314347509294748, 0.39429825148545206, 0.11530197036336176, 0.05862490928848274, 0.05513113035704009, 0.04232649655023124, 0.0531011004204629, 0.09120431655901484, 0.04090158414328471, 0.05158514133654535, 0.06413794588297606, 0.043233864853391424, 0.15559743507765234, 0.10923465335508808, 0.3920223517343402, 0.6506186630576849, 0.3391415986698121, 0.3583323204657063, 0.6506875343620777, 0.11786850998760201, 0.1451689243549481, 0.02511832950403914, 0.09539699080050923, 0.011707515968737425, 0.03767863345274236, 0.07218727958388627, 1.3390606152825058, 1.0383885679766536, 0.8468360372353345, 0.05148110707523301, 0.12638944142963737, 0.09421383670996875, 0.07481599634047598, 0.2439217214123346, 0.3926118544768542, 0.21796029730467126, 0.7613559428136796, 0.7510835502762347, 1.557671434711665, 8.270394913852215, 16.66669227182865, 21.20070967823267, 30.92321377247572, 53.11443530023098, 48.93373243510723, 49.31751564145088, 50.085435435175896, 45.25751329958439, 46.87556527554989, 48.07163469493389, 46.705961376428604, 44.08182218670845, 46.01034790277481, 47.08989657461643, 46.78598888218403, 47.7111442387104, 45.94171218574047, 48.64721640944481, 48.79081070423126, 48.26722539961338, 46.31131835281849, 41.06999360024929, 42.73677036166191, 44.35196869075298, 44.31397072970867, 46.95456683635712, 52.6768583804369, 51.21691212058067, 47.529077008366585, 47.89354205131531, 43.37189108133316, 42.38411508500576, 41.91935062408447, 41.80957831442356, 42.874353379011154, 45.164494290947914, 44.79478932917118, 44.674886763095856, 43.85202191770077, 41.96791581809521, 43.99068407714367, 44.01644289493561, 43.324158042669296, 42.85134181380272, 39.33531068265438, 40.702275931835175, 43.09390939772129, 51.614321395754814, 57.75632701814175, 59.1264308989048, 57.858438938856125, 50.68727374076843, 42.494506761431694, 35.03329552710056, 27.79913730919361, 13.121852986514568, 5.270529510453343, 2.425996921956539, 2.6940796617418528, 3.4306138521060348, 5.077595338225365, 8.551016505807638, 11.13109041005373, 8.72141931205988, 4.796128291636705, 1.544529483653605, 0.4336766368942335, 0.0561528265097877, 0.45077646151185036, 0.8602160098962486, 3.6293947231024504, 0.18936454580398276, 0.11071954984799959, 0.11210787808522582, 0.05670854669006076, 0.19979133474407718, 0.19745759200304747, 0.10097071281052195, 0.044305299743427895, 0.06721201803884469, 0.0731588844791986, 0.08187241066480055, 0.08542101946659386, 0.04787294092238881, 0.02911261468398152, 0.02497993194992887, 0.2858067105989903, 0.027803614611912053, 0.10711667520808987, 0.14697425795020536, 0.06567564618308097, 0.021583381785603706, 0.1990257648867555, 0.039915032393764704, 0.14626918797148392, 0.4750363784842193, 21.018175072968006, 68.68784263730049, 27.631596699357033, 40.76088398694992, 31.44296508282423, 17.94078480452299, 9.830130469053984, 3.8995210407301784, 0.9769288846291602, 0.09568510737153701, 1.7747296812012792, 18.055282160639763, 53.15495252609253, 60.6661918759346, 55.86353458464146, 3.302244865335524, 0.038628912734566256, 0.013382921770244138, 0.018707821145653725, 0.0963242152647581, 0.24401391099672765, 0.19317436090204865, 0.40374083386268467, 5.889574242755771, 74.37323436141014, 77.20143020153046, 4.5376585610210896, 12.230132035911083, 52.18111038208008, 20.854173973202705, 3.949863826856017, 13.56513150036335, 0.5982157937251031, 1.9863207335583866, 1.7418217845261097, 31.543650180101395, 60.199603512883186, 44.55557696521282, 43.901309072971344, 44.61362645030022, 0.9127111430279911, 0.2941101259784773, 0.24855303461663425, 0.20010005333460867, 0.30965322162956, 0.18804739695042372, 0.2472288502031006, 0.10343735935748555, 0.146454235073179, 0.12354124191915616, 0.1532202766975388, 0.1741986838169396, 0.20946865843143314, 0.2178483220632188, 0.6731358985416591, 1.0477536404505372, 0.8057112002279609, 0.7968734682071954, 0.9088106523267925, 0.25847400538623333, 0.2488102184724994, 0.1132985798176378, 0.22070988023187965, 0.12009794387267902, 0.20353495026938617, 0.13246102578705177, 1.0062808846123517, 2.781555480323732, 0.6802658597007394, 0.12402371212374419, 0.25150523870252073, 0.24549354566261172, 0.19572356395656243, 0.33118221326731145, 0.32280734390951693, 0.28359543706756085, 0.9948094782885164, 1.740035880357027, 3.920641732402146, 12.644638493657112, 19.24928829073906, 26.568170562386513, 43.85790400207043, 57.559953555464745, 49.15681466460228, 51.29208728671074, 49.087684974074364, 44.6973929554224, 47.92640648782253, 52.20489330589771, 48.38640980422497, 46.93094730377197, 48.159748166799545, 50.1485538482666, 50.625310465693474, 51.29656724631786, 49.92493964731693, 50.77082745730877, 51.86098136007786, 49.55730937421322, 49.14752036333084, 42.068690210580826, 46.100809648633, 46.55767813324928, 47.188128903508186, 51.684150248765945, 54.84700933098793, 51.95126451551914, 50.707728043198586, 50.98490796983242, 46.3433962315321, 47.41638645529747, 44.651073440909386, 45.85386469960213, 48.35468530654907, 47.335553392767906, 48.390129804611206, 46.65929228067398, 47.790252193808556, 44.63937386870384, 50.447179824113846, 48.1702546030283, 47.20455542206764, 45.9168691188097, 44.25041154026985, 43.1586579233408, 46.52574844658375, 51.77461579442024, 59.452833384275436, 60.05064770579338, 60.81590764224529, 50.36457605659962, 46.72091357409954, 31.864955238997936, 32.01551266014576, 22.075272649526596, 7.739346334710717, 5.520966472104192, 3.0592828150838614, 3.422656604088843, 5.400364268571138, 7.302481401711702, 11.923512239009142, 9.386636316776276, 5.4936787113547325, 1.978942716959864, 1.0914834751747549, 0.216509205638431, 0.6862313020974398, 3.1871214928105474, 9.940248560160398, 0.552754676900804, 0.2296747569926083, 0.3210559644503519, 0.19961550511652604, 0.38699237164109945, 0.38261752983089536, 0.18956008687382564, 0.23940866201883182, 0.24504994915332645, 0.09758693500771187, 0.4396814724896103, 0.1428607857087627, 0.21787622681586072, 0.20264128572307527, 0.151288733468391, 0.30178752494975924, 0.21378009114414454, 0.2113596655544825, 0.2945042954524979, 0.15674399386625737, 0.08752813257160597, 0.3234909806633368, 0.1838711093296297, 0.3869812691118568, 0.508856582455337, 20.996176153421402, 85.79001054167747, 40.45356787741184, 50.53755037486553, 37.48355604708195, 32.112468257546425, 28.059026263654232, 19.440089352428913, 3.954665819182992, 0.08987412074930035, 1.5019566868431866, 19.559036269783974, 65.71957111358643, 66.2608140707016, 67.44644165039062, 4.610517276450992, 0.49574363452848047, 0.11776733299484476, 0.21163385943509638, 0.25245082390028983], [0.2971057308604941, 0.0394645153573947, 0.14438843732932582, 3.0506634525954723, 51.31805129349232, 79.48832228779793, 25.663594901561737, 1.5848637255840003, 10.065463241189718, 4.239593055099249, 1.8400727561675012, 2.677523475140333, 1.7405445780605078, 2.817724314518273, 5.9915142226964235, 8.303557634353638, 32.70198382437229, 37.102995067834854, 30.655683428049088, 49.428549483418465, 5.46756936237216, 0.5160685954615474, 0.1662283591576852, 0.049322900813422166, 0.07318415460758843, 0.10446774977026507, 0.01672036636591656, 0.03926627658074722, 0.09918406649376266, 0.059995715419063345, 0.06653983262367547, 0.03648186095233541, 0.08482911958708428, 0.3303133958252147, 0.3943456301931292, 0.7419860665686429, 0.6617957632988691, 1.8608544347807765, 1.2210263614542782, 0.9531462576705962, 0.05392987899540458, 0.027345197413524147, 0.06871446632430889, 0.0388614647090435, 0.10900340013904497, 0.24304785736603662, 1.871197004802525, 3.657578523270786, 0.17650193913141266, 0.2835818112362176, 0.08346236558281817, 0.1081953349057585, 0.08069399147643708, 0.2528243022970855, 0.15827526716748253, 0.5898900842294097, 1.6644827532581985, 0.5281804455444217, 0.8391003054566681, 1.8843301688320935, 5.100078731775284, 9.985547829419374, 11.813743729144335, 27.234250120818615, 52.66169719398022, 45.77912651002407, 47.1265684068203, 45.57618319988251, 46.38117380440235, 44.814612865448, 46.09871596097946, 45.79143404960632, 43.261138424277306, 45.29980503022671, 42.6685906201601, 42.9048315435648, 44.129692018032074, 44.43471685051918, 45.199900791049004, 44.67800259590149, 41.674993336200714, 40.4422140866518, 37.52505362033844, 41.25223182141781, 41.089110374450684, 44.224713519215584, 48.041057735681534, 49.70998138189316, 48.04206468164921, 43.204088285565376, 40.2167683839798, 39.6603262424469, 41.74678288400173, 36.71868748962879, 36.15917131304741, 39.2869658768177, 40.953864231705666, 39.57665093243122, 41.535518020391464, 40.360005497932434, 40.463139563798904, 41.04840695858002, 38.15140061080456, 37.184219509363174, 38.59122321009636, 36.719333454966545, 37.153494358062744, 46.15288205444813, 55.96512213349342, 55.266039445996284, 52.10817329585552, 47.63796016573906, 37.269053757190704, 38.008064702153206, 17.962382845580578, 8.525283336639404, 2.684765411540866, 1.7761971149593592, 1.8001968646422029, 2.61337507981807, 4.8274329118430614, 8.319668769836426, 6.561618056148291, 3.8732682494446635, 1.8404802842997015, 0.26829380658455193, 0.2611724246526137, 0.17512188584078103, 0.15544133173534647, 0.03148962277919054, 0.07515252320445143, 0.06533232124638744, 0.028053686837665737, 0.02280297347169835, 0.03482323882053606, 0.11977908754488453, 0.1757659958093427, 0.08826742297969759, 0.14561765652615577, 0.04180611373158172, 0.02457430000504246, 0.266245478997007, 0.341244013980031, 0.33108386385720223, 0.1408834964968264, 0.6328736152499914, 0.6040165980812162, 0.1921445271000266, 0.006195054538693512, 0.008787440383457579, 0.09962715092115104, 0.04567947151372209, 0.05034373236412648, 0.03696021965879481, 0.11533003096701577, 0.05117021399200894, 29.821101911365986, 44.40244138240814, 27.786886766552925, 37.06503130495548, 43.29218275845051, 31.305638551712036, 21.961810737848282, 10.14636754989624, 2.425127956084907, 0.5282482481561601, 7.472189795225859, 38.901761546730995, 56.94544292986393, 44.68412026762962, 45.01579686999321, 1.3477547862567008, 0.05164533322385978, 0.1647838280769065, 0.05516739911399782, 0.18132674507796764, 0.02988882508361712, 0.04540205671219155, 0.16651145881041884, 6.526557337492704, 72.16038510203362, 90.93000993132591, 41.22130148112774, 2.7763445349410176, 20.115822292864323, 6.2507871352136135, 13.149818535894156, 9.421513695269823, 4.587814444676042, 4.0471557062119246, 8.24734440073371, 6.1141659412533045, 51.17867857217789, 45.6473495811224, 34.98487092554569, 70.71281477808952, 16.827178560197353, 0.5989553884137422, 0.3107716975500807, 0.07574685732834041, 0.028605212028196547, 0.11727687728125602, 0.044010945421177894, 0.04806255965377204, 0.13045056257396936, 0.03070073278649943, 0.07644599754712544, 0.12361969435005449, 0.1359566897735931, 0.5588016367983073, 0.3341157449176535, 0.9877534944098443, 0.9414680593181401, 1.3368657580576837, 0.9768485545646399, 1.3397986069321632, 0.09233227712684311, 0.038434718662756495, 0.04213132655422669, 0.07535776414442807, 0.15559039951767772, 0.4356363520491868, 2.8853283869102597, 6.108143264427781, 0.11193832702701911, 0.04151218614424579, 0.13424986886093393, 0.10300574111170135, 0.06501433323137462, 0.1463159135892056, 0.07398984496830963, 0.6463580823037773, 1.2504320335574448, 0.9079793281853199, 0.6063404702581465, 2.2951122326776385, 3.3545687701553106, 8.750746138393879, 14.046445973217487, 32.240779772400856, 49.38765987753868, 44.08043526113033, 48.24318028986454, 43.12526151537895, 46.64577640593052, 47.49382250010967, 50.30898503959179, 47.305538803339005, 46.62913329899311, 46.6466161608696, 45.18428362905979, 45.71577250957489, 44.68129321932793, 46.95569157600403, 45.90682625770569, 46.130094677209854, 44.78365212678909, 42.45721556246281, 41.3760481774807, 44.767970368266106, 42.43186332285404, 45.54301857948303, 49.22784045338631, 52.05103196203709, 49.83518086373806, 47.48217612504959, 40.731196179986, 40.71161203086376, 42.8636759519577, 41.701713502407074, 39.410569444298744, 41.266025081276894, 40.52975378930569, 41.26869633793831, 43.121062740683556, 42.562568709254265, 41.82532846927643, 43.59615124762058, 41.978376656770706, 41.65391966700554, 41.10225386917591, 39.898147881031036, 42.661329209804535, 45.78542657196522, 56.25580653548241, 56.08550347387791, 53.42095725238323, 45.75563997030258, 40.53565867245197, 33.23806285858154, 11.136478520929813, 3.4057624731212854, 1.102929173503071, 0.8795287704560906, 0.7579535222612321, 1.2591467471793294, 2.665593777783215, 5.31163427978754, 5.31170267611742, 4.0622803196311, 1.072953175753355, 0.1579096555360593, 0.014476527394435834, 0.1270462421234697, 0.0809854180261027, 0.1600910205161199, 0.08125403837766498, 0.08316264924360439, 0.011614351387834176, 0.08865185547620058, 0.12377300721709616, 0.053176651053945534, 0.14344055147375911, 0.05938392598181963, 0.22659209818812087, 0.05116269603604451, 0.052888623540638946, 0.05806030188978184, 0.21378550882218406, 0.22507597954245284, 0.2893968054559082, 1.0792306764051318, 1.1984223243780434, 0.6981307198293507, 0.07121350019588135, 0.05432013364043087, 0.05620727788482327, 0.0929178687511012, 0.1042138016782701, 0.044989541347604245, 0.10180402590776794, 0.08852071056026034, 39.49257664382458, 49.415516182780266, 36.05849951505661, 45.17702981829643, 55.02514757215977, 67.87356153130531, 32.977412045001984, 11.962593141943216, 7.085376251488924, 2.4049130408093333, 14.013363998383284, 63.317978382110596, 67.71007150411606, 63.76888498663902, 49.90242965519428, 1.1620021099224687, 0.08161065517924726, 0.02872629713237984, 0.07705156036536209, 0.08547723715309985, 0.45826829387806356, 0.10942304754280485, 0.45867813751101494, 11.5728148072958, 86.46934568881989, 107.16675147414207, 63.820843398571014, 0.9628191730007529, 38.089779317379, 13.514291178435087, 8.25761429965496, 11.473206002265215, 4.289655368775129, 1.5944881341420114, 6.571809109300375, 31.432945020496845, 56.25693127512932, 52.44006648659706, 41.27601094543934, 76.50982171297073, 17.770474143326283, 0.861735453363508, 0.43188806099351496, 0.23077427846146747, 0.1743901876034215, 0.3152437013341114, 0.06484395838924684, 0.15645970677724108, 0.17463898519054055, 0.1427991726086475, 0.19190616410924122, 0.30881578219123185, 0.2894333191215992, 1.028080671094358, 0.6381092593073845, 1.6048019682057202, 1.4868432353250682, 2.323967646807432, 1.5799378836527467, 2.375440397299826, 0.2695768018020317, 0.18259894946822897, 0.2574667922453955, 0.1467585749924183, 0.5274904856923968, 0.9519367944449186, 6.595593458041549, 11.62488816305995, 0.2323191924369894, 0.2739960537292063, 0.18478356505511329, 0.2566547936294228, 0.5430764774791896, 0.31015832733828574, 0.16311208106344566, 0.8045417536050081, 1.7882169387303293, 2.757996032014489, 1.8143664230592549, 4.285124111920595, 5.685315728187561, 13.66309879347682, 23.735411167144775, 47.220309376716614, 53.37724059820175, 44.05274234712124, 49.73100945353508, 44.968732595443726, 47.812196016311646, 48.46156217157841, 51.44869588315487, 49.60261434316635, 49.64388392865658, 51.18506982922554, 46.95924438536167, 48.154398053884506, 47.28062354028225, 47.86448121070862, 49.43371340632439, 49.67707134783268, 46.96327216923237, 46.525968834757805, 43.71906705200672, 47.63800576329231, 46.62273444235325, 48.64474654197693, 53.15025217831135, 53.35003785789013, 53.96389491856098, 51.08953915536404, 47.353773415088654, 44.69034433364868, 46.203096359968185, 42.4039576202631, 41.2120071798563, 44.65139642357826, 46.114899292588234, 44.26779180765152, 47.937737479805946, 45.83219066262245, 44.968979582190514, 46.1422236263752, 44.480667784810066, 43.16906176507473, 44.8788446187973, 42.51859746873379, 44.0626560151577, 50.98217211663723, 59.295461028814316, 57.3469939827919, 53.53737160563469, 48.95824111998081, 37.68867664039135, 38.337548822164536, 26.25386282801628, 10.431474801152945, 3.902479181997478, 2.8580726869404316, 2.943102386780083, 3.450589142739773, 5.835577715188265, 10.123184993863106, 8.755816966295242, 7.3769008833914995, 2.3078607860952616, 0.44567532429937273, 0.5436564807314426, 0.34947232401464134, 0.2149313551490195, 0.23654236894799396, 0.2559858513996005, 0.24488404946168885, 0.12620448338566348, 0.2839500055415556, 0.17148816754342988, 0.26843965344596654, 0.5205045605544001, 0.21890082105528563, 0.35555532260332257, 0.23711569287115708, 0.11485104143503122, 0.38355287339072675, 0.44542934687342495, 0.5995250015985221, 1.0388023895211518, 1.6646924545057118, 1.0200444585643709, 0.31817723298445344, 0.18417126353597268, 0.1351574857835658, 0.18193824507761747, 0.21925694803940132, 0.17699702584650367, 0.12396683392580599, 0.2571512310532853, 0.17048484325641766, 43.05233582854271, 62.08007700741291, 43.323960453271866, 58.040996342897415, 65.6903050839901, 73.09747561812401, 45.09214997291565, 21.786218360066414, 11.035422943532467, 1.9369502202607691, 9.258944168686867, 64.80255112051964, 76.35139301419258, 72.45530247688293, 65.19167304039001, 1.5598941966891289, 0.15558348270133138, 0.20996291394112632, 0.1390234220889397, 0.3114288247888908], [0.07332613487960771, 0.07570393150672317, 0.16516809730092064, 0.4885166301392019, 25.433665439486504, 61.601078510284424, 75.9885884821415, 4.504992663860321, 6.143297553062439, 4.068763246759772, 1.2156737549230456, 6.439292170107365, 3.3540503354743123, 9.454576671123505, 13.268331326544285, 20.12359857559204, 21.16608403623104, 38.55548992753029, 41.05248413980007, 54.60682421922684, 16.10468152910471, 0.3802767366869375, 0.249293401138857, 0.23019549233140424, 0.044675256649497896, 0.04551230274955742, 0.014413260232686298, 0.05074558677733876, 0.07041387318167835, 0.14025179523741826, 0.010299558853148483, 0.20632600440876558, 0.0558361632283777, 0.9522977750748396, 0.16414289450040087, 0.29358937579672784, 2.9056893568485975, 3.951266664080322, 3.4224395407363772, 3.6156850587576628, 0.533202113583684, 0.015164661563176196, 0.018301905329281, 0.05059138704382349, 0.07566467189462855, 0.018382933012617286, 0.02573557743744459, 0.032523701665923, 0.042333042292739265, 0.00720583091606386, 0.05315996015269775, 0.11224718662560917, 0.1088783037266694, 0.12329904202488251, 0.4560582374688238, 0.5076346511486918, 0.7816872268449515, 0.6268217868637294, 0.13311515474924818, 0.8554684615228325, 0.9392192924860865, 1.4433266641572118, 4.2663022968918085, 6.772269727662206, 31.772249713540077, 49.294811859726906, 47.73680046200752, 44.01391223073006, 45.71653626859188, 46.13327510654926, 45.536813512444496, 47.15345956385136, 44.49119322001934, 39.91614371538162, 41.799626648426056, 42.7559669315815, 46.48173540830612, 45.298311710357666, 44.28762674331665, 44.90605875849724, 41.616278886795044, 38.38375814259052, 41.197674348950386, 39.956638142466545, 42.014964893460274, 41.18225857615471, 45.814308822155, 48.19526486098766, 44.43635456264019, 43.553285747766495, 38.738773092627525, 38.04822474718094, 39.919806718826294, 37.64424182474613, 39.97648447751999, 38.445132449269295, 38.70900548994541, 41.59724950790405, 40.69787196815014, 41.439664363861084, 41.83111935853958, 39.127674624323845, 37.740338668227196, 38.03581081330776, 34.87675532698631, 39.05847653746605, 45.70727236568928, 42.95766390860081, 52.40930333733559, 49.86741453409195, 47.21732273697853, 40.64845182001591, 36.567372009158134, 14.93555361405015, 2.575028487481177, 0.27811437961645424, 0.4006128595210612, 0.014558556977135595, 0.08151360452757217, 0.09290291447541676, 0.1841065482585691, 0.3349248640006408, 0.4768513154704124, 0.09830826544202864, 0.09050024847965688, 0.19409542554058135, 0.17574996541952714, 0.10903184665949084, 0.14181037957314402, 0.10068730887724087, 0.01351449342109845, 0.09911302811815403, 0.21288709453074262, 0.019245032162871212, 0.19066287379246205, 0.04442776524228975, 0.022716246094205417, 0.14628732606070116, 0.07788970484398305, 0.2553309209179133, 0.25749603286385536, 0.8148951886687428, 1.0649597109295428, 0.6517938093747944, 0.8444785606116056, 0.8059967786539346, 4.398390334099531, 3.1414598179981112, 0.05984892231936101, 0.22730136872269213, 0.16125620721140876, 0.08672825322719291, 0.06475202113506384, 0.13103190169204026, 0.16886322089703754, 1.006582137197256, 41.06516405940056, 37.4963803589344, 38.913913294672966, 42.56812781095505, 29.186836145818233, 19.162702336907387, 20.7884394004941, 16.731936670839787, 9.181034099310637, 7.668984085321426, 25.77551979571581, 51.63258321583271, 29.808249101042747, 53.9065407961607, 27.393227890133858, 0.20592214248608798, 0.32136677589733154, 0.014026226508576656, 0.0546072223369265, 0.12150176815339364, 0.057634798940853216, 0.050550735904835165, 0.04942676438076887, 2.0341576728969812, 49.96528208255768, 71.10803157091141, 94.02559742331505, 9.098528176546097, 3.2921628188341856, 6.494881762191653, 9.89809362217784, 15.421617832034826, 7.6398928463459015, 10.443904884159565, 0.8308772498276085, 18.982020132243633, 31.11307818442583, 43.15073534846306, 51.87400326132774, 61.51651404798031, 28.92654061317444, 1.1495903134346008, 0.34072614333126694, 0.13185853546019644, 0.2737635240191594, 0.07410245103528723, 0.08429463225184008, 0.03269970940891653, 0.016736973775550723, 0.10358231564168818, 0.07684356605750509, 0.3213441849220544, 0.16831547138281167, 0.5279210500884801, 0.4141690180404112, 0.4834309592843056, 2.544134482741356, 3.576507023535669, 3.5366398002952337, 2.9061517445370555, 0.9409160201903433, 0.2963714796351269, 0.029005624819546938, 0.07073675194988027, 0.0594835927040549, 0.01224003104653093, 0.04072128307598177, 0.07350904459599406, 0.03732985373062547, 0.024407268538197968, 0.07528447706135921, 0.03259781624365132, 0.052874930916004814, 0.09253227108274586, 0.1296981584164314, 0.475426540360786, 0.1812879604403861, 0.9645711164921522, 0.21146665356354788, 0.8031421818304807, 1.0480345878750086, 1.2121152458712459, 3.49138209130615, 9.672347735613585, 34.37009431421757, 48.78598116338253, 46.781706511974335, 44.73680064082146, 45.958146303892136, 49.07601960003376, 47.07659728825092, 49.04425710439682, 47.127286568284035, 42.7609446644783, 45.47969117760658, 47.70274668931961, 49.252938106656075, 48.45927469432354, 47.2678904235363, 48.035700023174286, 44.62532602250576, 39.84401598572731, 43.50290805101395, 42.80737057328224, 45.098902210593224, 45.06255716085434, 47.27086566388607, 49.132697358727455, 47.75083690881729, 45.58767378330231, 42.71433636546135, 41.375968381762505, 39.98835124075413, 41.25581122934818, 43.07837963104248, 41.16130270063877, 43.05675499141216, 45.37762485444546, 44.9909196048975, 45.19172742962837, 44.59138244390488, 43.15280623733997, 40.640115067362785, 41.027344688773155, 38.14304865896702, 41.91367372870445, 52.33133912086487, 52.60177820920944, 51.72298036515713, 46.93195044994354, 40.960012301802635, 34.902130365371704, 20.536780804395676, 3.5444870917126536, 0.667651902185753, 0.11854274373035878, 0.12890183395938948, 0.08191444590920582, 0.046227773927967064, 0.1817984096123837, 0.13743172312388197, 0.09449094723095186, 0.09556788514601067, 0.053599578750436194, 0.07936595531646162, 0.2993169747060165, 0.39349391183350235, 0.0170433286257321, 0.13711276289541274, 0.14355179941048846, 0.036360145022626966, 0.12164469095296226, 0.09717516179080121, 0.04567338590277359, 0.052855456960969605, 0.035625236996565945, 0.05045216756116133, 0.02000714546738891, 0.044829122416558675, 0.10290267906384543, 0.16263664641883224, 0.7092948176432401, 2.332928515970707, 2.1528663905337453, 2.789394222199917, 3.210888742469251, 10.072095785290003, 3.6900169076398015, 0.40724828315433115, 0.2326756904949434, 0.27310776233207434, 0.018617716996232048, 0.0167368457550765, 0.040722225603531115, 0.30646347091533244, 3.0702696880325675, 53.14888805150986, 45.77507212758064, 47.07678347826004, 54.52336549758911, 36.7883225530386, 39.37148094177246, 64.84394609928131, 44.71070744097233, 15.389482956379652, 9.803441651165485, 44.02570299804211, 59.507919028401375, 42.29337975382805, 66.97683244943619, 28.730423636734486, 0.08979444377473556, 0.11782959918491542, 0.04756946560519282, 0.11319409284624271, 0.029316087457118556, 0.2769153064582497, 0.13370097643928602, 0.2807609969750047, 4.406622592359781, 73.233303129673, 77.63329982757568, 118.12186762690544, 26.307230964303017, 10.187234356999397, 11.283601876348257, 9.687203038483858, 9.767825212329626, 2.3697155294939876, 9.789373856037855, 30.294262021780014, 41.02933578193188, 36.65390096604824, 54.4496950507164, 54.5245548337698, 74.60314482450485, 50.2142371237278, 0.7139419682789594, 0.8852158184163272, 0.26571508089546114, 0.44250065402593464, 0.1265598979080096, 0.1153935662296135, 0.1348526412039064, 0.1347095551318489, 0.25267225108109415, 0.12540121242636815, 0.5862941709347069, 0.7346619595773518, 1.8829500116407871, 1.0240984847769141, 1.6155743901617825, 3.1557453889399767, 4.398109149187803, 4.617842333391309, 4.844258408993483, 1.6683641262352467, 0.4197516309795901, 0.13213923055445775, 0.24573259142925963, 0.17198453075252473, 0.13917908014263958, 0.16755358257796615, 0.21665791718987748, 0.2144917959230952, 0.08141313257510774, 0.24549676658352837, 0.1383340559550561, 0.247778425400611, 0.13276100187795237, 0.6143224763218313, 0.806607655249536, 1.6735430108383298, 1.6240761964581907, 1.4248519367538393, 1.3130112318322062, 1.921479469165206, 1.7244265554472804, 6.059814132750034, 23.29649291932583, 46.5830759704113, 51.788621842861176, 47.965897768735886, 43.87793652713299, 44.62929680943489, 50.61406306922436, 46.9932259619236, 51.16526909172535, 51.069806814193726, 46.78071856498718, 47.86739565432072, 49.67290677130222, 53.19841079413891, 51.05818323791027, 47.69635543227196, 50.055857822299004, 45.35299077630043, 42.418609634041786, 45.82157023251057, 44.391399174928665, 49.54378589987755, 47.413810193538666, 51.31167523562908, 53.16069021821022, 50.11410489678383, 49.8102618008852, 46.711167097091675, 45.56870520114899, 44.806412905454636, 43.2685100287199, 47.08776868879795, 44.728292897343636, 44.98447135090828, 47.60607227683067, 48.00100028514862, 46.33664779365063, 48.66345673799515, 48.40551897883415, 45.25395289063454, 45.09624235332012, 39.9979343265295, 45.86752496659756, 53.84932726621628, 50.01232735812664, 54.85196806490421, 49.13161061704159, 50.00914312899113, 42.71579548716545, 37.07014583051205, 19.354759231209755, 3.176958463154733, 0.3274658048758283, 0.46582736482378095, 0.3973326558480039, 0.19078814832028002, 0.40453552559483796, 0.34982585348188877, 0.5405728868208826, 0.7203659985680133, 0.2893364243209362, 0.27003277733456343, 0.31361139204818755, 0.41104463569354266, 0.2459141207509674, 0.4610786586999893, 0.3861357847927138, 0.18090683792252094, 0.3283177607227117, 0.44903244415763766, 0.15609314519679174, 0.2054995042271912, 0.18416354520013556, 0.17131339176557958, 0.2078827185323462, 0.11735349660739303, 0.26663151453249156, 0.555330344941467, 1.8576108338311315, 3.27356590423733, 2.531627928838134, 3.2394546596333385, 2.924345643259585, 7.380718253552914, 3.7164226407185197, 0.8659314969554543, 0.37252360896673054, 0.34022011735942215, 0.19192719657439739, 0.17871656717034057, 0.41332783817779273, 0.5414901219774038, 2.9170813830569386, 62.68054738640785, 51.608731895685196, 50.7403264939785, 62.693797275424004, 46.439162492752075, 35.83070553839207, 55.15372887253761, 44.98538330197334, 19.459702000021935, 12.600790746510029, 51.50555603206158, 87.64836922287941, 46.46346978843212, 83.04917201399803, 38.05474899709225, 0.20055031433003023, 0.3839057794539258, 0.2134413897874765, 0.25948498863726854, 0.20677072898251936], [0.08216444577556103, 0.05809449634398334, 0.35054748819675297, 0.36462576244957745, 7.5225907657295465, 28.3695076033473, 74.5258417725563, 47.93960317969322, 10.842572841793299, 7.230486664921045, 5.21663605235517, 2.483013574965298, 3.2480633351951838, 10.921004433184862, 29.401304237544537, 45.671527683734894, 43.26426945626736, 32.17003136873245, 50.552225187420845, 54.54897992312908, 23.271131180226803, 2.71435109898448, 0.2009200374595821, 0.08163245947798714, 0.08242724026786163, 0.059969320936943404, 0.10153097493457608, 0.11316045129206032, 0.06857831191155128, 0.17514867737190798, 0.6563679920509458, 1.8052692362107337, 2.0580044807866216, 1.6803626948967576, 0.05398605586378835, 0.27688499714713544, 2.899473365396261, 7.55570693872869, 5.640329467132688, 3.9156096149235964, 1.244892287068069, 0.17109943059040233, 0.21749315987108275, 0.05786357338365633, 0.0997553717752453, 0.19124940794426948, 0.07213321412564255, 0.02042782260105014, 0.04407981672557071, 0.03554840244760271, 0.10411494760774076, 0.04276588137145154, 0.1509319237084128, 0.18212657247204334, 0.09038595031597652, 0.8655903465114534, 0.24163696041796356, 0.06655900971964002, 0.1658498786855489, 0.17088270862586796, 0.1597119463258423, 0.35680515866260976, 0.5087376607116312, 2.0214886777102947, 7.774832155555487, 29.616674780845642, 45.51334597170353, 49.420129135251045, 48.47445107996464, 44.844931438565254, 48.361874520778656, 46.33196264505386, 43.01308013498783, 41.60245142877102, 41.271359995007515, 43.30655358731747, 47.45846539735794, 46.412415727972984, 48.27506437897682, 45.791958421468735, 42.35076047480106, 39.751065373420715, 39.80917185544968, 40.66189929842949, 43.89756627380848, 42.053339034318924, 44.10987228155136, 44.733206033706665, 43.55940721929073, 40.33200100064278, 39.830454513430595, 41.01164773106575, 37.57670424878597, 37.32870675623417, 37.41081275045872, 38.82116787135601, 42.688649743795395, 43.023278787732124, 43.472619876265526, 39.896517768502235, 41.386816799640656, 38.84711667895317, 37.81342014670372, 36.499192267656326, 36.124053597450256, 39.40476715564728, 48.62507879734039, 58.59364628791809, 55.47416187822819, 40.681791231036186, 27.689883671700954, 18.52959930896759, 3.975526699796319, 0.3397261438658461, 0.07453339392668568, 0.026966677978634834, 0.07671549363294616, 0.03225812040909659, 0.0294774414942367, 0.0484911091189133, 0.03367684330441989, 0.21496455883607268, 0.02664926512807142, 0.07636139271198772, 0.16470425500301644, 0.2674873889191076, 0.11982455151155591, 0.19067557936068624, 0.08616972772870213, 0.059158420699532144, 0.07617169976583682, 0.07350068801315501, 0.06606793060200289, 0.028599827746802475, 0.055896095364005305, 0.03581930490327068, 0.11055629962356761, 0.10094622935866937, 0.038785450233262964, 1.1704560625366867, 1.308163998182863, 4.5633399579674006, 6.3541206903755665, 7.92438168078661, 8.316671680659056, 14.156606812030077, 21.652349643409252, 5.3968751057982445, 0.5245605460368097, 0.3799854585668072, 0.11026921463781036, 0.06328204181045294, 0.10681856190785766, 0.06553253784659319, 0.045601097008329816, 5.6115982588380575, 51.83407500386238, 43.65504428744316, 50.56131809949875, 45.455562472343445, 31.890712156891823, 17.685478404164314, 37.75482349097729, 40.45738287270069, 35.57312496006489, 18.75743318349123, 35.783394277095795, 24.817477203905582, 22.106598168611526, 58.427462205290794, 11.223128121346235, 0.2150779590010643, 0.20639673108235002, 0.03013097302755341, 0.16995481622871011, 0.14647930482169613, 0.05232427589362487, 0.05598757619736716, 0.28005827218294144, 0.2360541099915281, 25.506838113069534, 50.29311329126358, 89.20719757676125, 66.23670816421509, 13.696840982884169, 10.569340903311968, 2.5989826396107674, 14.891231842339039, 12.922889962792397, 3.322829785756767, 27.201602272689342, 45.08963070809841, 46.12536013126373, 41.32259264588356, 56.73748768866062, 62.015123292803764, 46.54372148215771, 3.8646678859367967, 0.2724906516959891, 0.0768143922323361, 0.19053776253713295, 0.08174390037311241, 0.06373090014676563, 0.1112060499144718, 0.10492114262888208, 0.22804788022767752, 1.1376148997806013, 2.767825867049396, 2.452523298561573, 1.689185940194875, 0.2207729479414411, 0.9727412718348205, 4.410270871594548, 8.960908111184835, 7.359910095110536, 4.5993230771273375, 2.153529692441225, 1.4157611620612442, 0.5526199622545391, 0.07614804751938209, 0.0425121485022828, 0.013336058855202282, 0.12459141056751832, 0.17169875936815515, 0.05706831761926878, 0.026658601345843635, 0.15630496898666024, 0.08732575632166117, 0.15930073714116588, 0.144322267442476, 0.17011486779665574, 1.3879604288376868, 0.634866786422208, 0.4045511403819546, 0.3409454628126696, 0.4220556135987863, 0.07413690895191394, 0.46901649213396013, 0.5128377000801265, 1.480414574034512, 7.185289990156889, 28.177686296403408, 41.16482891142368, 46.8415305018425, 49.103275537490845, 49.4627932459116, 52.959555611014366, 47.44375258684158, 48.81609074771404, 44.50355015695095, 43.916531056165695, 44.432585164904594, 49.50922295451164, 48.39555971324444, 49.24743980169296, 46.94438338279724, 44.64671887457371, 42.85359129309654, 41.45721182227135, 43.175635412335396, 45.408270210027695, 45.32325737178326, 45.783674865961075, 47.38314963877201, 47.845125049352646, 45.0352518260479, 43.78359138965607, 44.51393119990826, 38.37031826376915, 40.39804145693779, 40.47680363059044, 39.9931275844574, 43.182794228196144, 44.042722284793854, 44.65250976383686, 42.95299015939236, 42.33099393546581, 42.564738392829895, 42.24846236407757, 41.21165379881859, 38.85718993842602, 45.7815507799387, 53.01093265414238, 61.7777956277132, 58.12034368515015, 34.215465411543846, 21.21036686003208, 9.650295618921518, 2.331544440239668, 0.12634311657166108, 0.14412607328267768, 0.05014512993511744, 0.05399847941589542, 0.05326737489667721, 0.02276545976201305, 0.0852026128268335, 0.05384568234148901, 0.11157471177284606, 0.07587700034491718, 0.05165148562809918, 0.07097244320902973, 0.16978194034891203, 0.025383621323271655, 0.11991498962743208, 0.03956110587751027, 0.042456016162759624, 0.012819799594581127, 0.035687113559106365, 0.04159768526733387, 0.07478969462681562, 0.04579096435918473, 0.026852964256249834, 0.07642266442417167, 0.10028381060692482, 0.2544734731782228, 1.3863135734573007, 4.553455263376236, 8.710770383477211, 7.939454521983862, 11.867188811302185, 16.38940405100584, 19.86309975385666, 33.413693234324455, 17.05512262880802, 4.644081350415945, 1.9560661632567644, 0.07788150411215611, 0.37736722093541175, 0.3111867659026757, 0.12639493332244456, 0.08807312129647471, 15.336752235889435, 60.43879687786102, 52.905298322439194, 57.095375284552574, 60.48150658607483, 45.62684208154678, 23.40123999863863, 62.217755019664764, 75.3941559791565, 78.68311509490013, 52.44354709982872, 49.8172078281641, 36.75823576748371, 30.966031774878502, 65.54069191217422, 11.65200350806117, 0.2749902941286564, 0.2741229609819129, 0.06287766780587845, 0.12885457399534062, 0.006628853307120153, 0.24127091834088787, 0.23412786569679156, 0.3979974123649299, 0.26956083078403026, 47.51852497458458, 64.7478948533535, 96.50484278798103, 96.4652869105339, 29.371916614472866, 13.498526774346828, 13.010043986141682, 11.195146422833204, 9.411798566579819, 27.283045202493668, 44.63248483836651, 63.60092639923096, 55.37292391061783, 49.514310881495476, 63.071474209427834, 68.43381866812706, 56.3773126155138, 3.973746495321393, 0.37644110969267786, 0.1813196501461789, 0.30327793559990823, 0.18822278128936887, 0.24403446848737076, 0.2497942914487794, 0.2115769515512511, 0.2776322507997975, 1.6943099652417004, 3.1835283106192946, 2.691688402555883, 3.1795005267485976, 0.3822903911350295, 0.8641443459782749, 5.107247997075319, 9.984513334929943, 8.656966220587492, 5.267165740951896, 2.7889349218457937, 2.4562736973166466, 0.9612619690597057, 0.22283899801550433, 0.3154074784833938, 0.22182905377121642, 0.18123409536201507, 0.5803071765694767, 0.22560897516086698, 0.09714660394820385, 0.21620384155539796, 0.19592381024267524, 0.3922261454863474, 0.46356835635378957, 0.31535499379970133, 1.7523771431297064, 0.32868230366148055, 0.7927824533544481, 0.3231113572837785, 0.3972746792715043, 0.29257462243549526, 0.6520674540661275, 0.769789827754721, 3.0618310533463955, 14.912321660667658, 38.3586148917675, 47.64621712267399, 46.737921461462975, 49.216992035508156, 48.60336296260357, 56.46977685391903, 49.91690307855606, 51.41309179365635, 47.181285470724106, 46.637891829013824, 49.41973015666008, 55.404416620731354, 50.847142562270164, 54.78267498314381, 48.92163768410683, 46.92305512726307, 45.083091259002686, 44.729733020067215, 45.951800644397736, 48.59114281833172, 47.44735099375248, 48.7688022851944, 50.904819667339325, 51.40333391726017, 45.91398887336254, 45.5563672631979, 49.73029889166355, 41.34386010468006, 44.56189222633839, 43.48989374935627, 44.09449450671673, 47.11890421807766, 49.72694747149944, 49.27246145904064, 44.86537054181099, 47.08402208983898, 45.60056649148464, 46.368664875626564, 44.345049262046814, 41.60793453454971, 45.52145093679428, 52.43163853883743, 62.5805177539587, 63.00045982003212, 42.23482109606266, 29.741488583385944, 21.72238938510418, 5.456412686035037, 0.5674290144816041, 0.4963112290715799, 0.15683845442254096, 0.29192874615546316, 0.11494887876324356, 0.09224902300047688, 0.13800374086713418, 0.22450044401921332, 0.29851744417101145, 0.15581549290800467, 0.17457087087677792, 0.293100003618747, 0.6967886199709028, 0.307240262045525, 0.38098005519714206, 0.15700104413554072, 0.12559001479530707, 0.34782015485689044, 0.1487897738115862, 0.16845392645336688, 0.16197634278796613, 0.09984351665480062, 0.12711742892861366, 0.1760454144096002, 0.2636409265687689, 0.9235393151175231, 2.1023811120539904, 4.27787552587688, 7.593409465625882, 9.338828232139349, 11.428128071129322, 14.62289784103632, 19.178146608173847, 31.565158925950527, 16.30023993551731, 4.747606320306659, 1.152281875256449, 0.14366932591656223, 0.4454278328921646, 0.2987085620407015, 0.16573665663599968, 0.23739099997328594, 15.87618364021182, 75.41111826896667, 56.923761293292046, 64.39512938261032, 64.75452929735184, 48.221540451049805, 28.0255975574255, 61.635132282972336, 75.95088690519333, 71.14036783576012, 64.18691575527191, 63.07948037981987, 43.01901541650295, 36.9052878767252, 87.36689552664757, 16.078738421201706, 0.3519898373633623, 0.5155201780144125, 0.25493915600236505, 0.2969209657749161, 0.28234275116119534], [0.024496316982549615, 0.05808995440020226, 0.08253433959907852, 0.06922405460500158, 2.0334361866116524, 20.88518600910902, 21.58036820590496, 61.594193279743195, 23.940613456070423, 23.87290868908167, 29.024339765310287, 20.764168202877045, 18.12229536473751, 65.45739278197289, 94.17474702000618, 40.03027059137821, 30.800738744437695, 31.970542073249817, 45.8276879042387, 58.35307739675045, 51.7489367723465, 8.566335383802652, 0.7448217237833887, 0.33866701007355005, 0.21429600252304226, 0.10611442703520879, 0.009249654594896128, 0.19920227729016915, 0.03589173109503463, 0.6732257874682546, 2.330932910554111, 3.7423279881477356, 2.6088148495182395, 1.3522601570002735, 0.5852831876836717, 2.976363427005708, 4.573365245014429, 6.061579613015056, 9.639277160167694, 2.795949107967317, 0.9043927362654358, 1.3090831926092505, 2.3352767899632454, 1.3103397376835346, 0.12081283988663927, 0.1480403234018013, 0.023169811502157245, 0.15485929499845952, 0.3713147097732872, 0.5072696332354099, 1.0133431619033217, 1.7169667244888842, 0.5461621494032443, 0.5735272716265172, 0.45176755520515144, 1.232245140708983, 2.222753665409982, 0.8046689280308783, 0.2811204636236653, 0.14066245523281395, 0.20090745063498616, 0.3282343136379495, 0.05224247637670487, 0.0972547497076448, 0.28187810734380037, 4.98289966955781, 17.48369213193655, 35.95334775745869, 48.87881778180599, 54.83313627541065, 52.64781653881073, 47.41903871297836, 43.82637709379196, 44.09365855157375, 40.84774732589722, 42.55596086382866, 44.4867854565382, 46.07541561126709, 43.55050049722195, 43.740927278995514, 40.65960802137852, 41.41720376908779, 40.139993503689766, 42.041213884949684, 42.279578894376755, 43.025079891085625, 41.60418413579464, 43.09419058263302, 43.73633712530136, 43.71114827692509, 40.183444172143936, 37.397509664297104, 35.05424000322819, 35.28198078274727, 35.14687143266201, 40.6438122689724, 41.37578219175339, 40.325533747673035, 43.118687868118286, 40.942407846450806, 38.56660433113575, 40.27716614305973, 37.63221547007561, 37.60786257684231, 39.88643690943718, 47.43232659995556, 52.90803037583828, 53.39660435914993, 41.52300909161568, 20.093895569443703, 8.870379868894815, 1.1372485756874084, 0.13799134700093418, 0.11926532839424908, 0.09766236689756624, 0.023050535382935777, 0.11757663814933039, 0.008348844094143715, 0.02436355975078186, 0.07103661671862938, 0.14146651286864653, 0.024234351840277668, 0.05964618983853143, 0.07893907197285444, 0.08155192161211744, 0.06091343668231275, 0.15771401056554168, 0.07738125204923563, 0.05996919848257676, 0.019232363702030852, 0.013508288138837088, 0.0862365507055074, 0.055366305823554285, 0.3980149864219129, 2.175755649805069, 0.9215580183081329, 0.650964385131374, 0.17287807655520737, 0.6878541118931025, 3.1189063657075167, 15.655798316001892, 14.746307618916035, 8.919203449040651, 15.198585949838161, 20.33329412341118, 28.22266448289156, 48.23181889951229, 28.9633796364069, 6.685742195695639, 2.47745827306062, 0.34894718031864613, 0.46437985030934215, 1.343361153267324, 0.12405286368448287, 0.12318202760070562, 16.73222355544567, 56.212268471717834, 45.92426732182503, 58.000691905617714, 39.1958961635828, 58.92244644463062, 47.89131157100201, 32.112468257546425, 17.26530645042658, 20.994188860058784, 23.692433573305607, 9.4244091399014, 12.629518155008554, 32.08427757024765, 47.863337472081184, 2.046440038830042, 0.2838792640250176, 0.10053450067061931, 0.19890767434844747, 0.1297810859978199, 0.019534375132934656, 0.030160267451719847, 0.20319215225754306, 0.11411928382585756, 0.051392988170846365, 8.071467038244009, 50.134297013282776, 43.5708712041378, 81.69114768505096, 31.563589610159397, 32.69150398671627, 15.749482288956642, 6.99568253941834, 5.057724779471755, 43.239441588521004, 78.93690347671509, 42.9780650138855, 29.904209151864052, 42.24518693983555, 48.55769321322441, 64.85612824559212, 66.34127855300903, 17.133217938244343, 0.7037764450069517, 0.16605747223366052, 0.2713571843924001, 0.011562231284187874, 0.04112888913368806, 0.16128216753713787, 0.09481115426751785, 0.96062300959602, 3.176810033619404, 5.796833094209433, 2.785637411288917, 2.207789830863476, 0.5105109780561179, 2.215479905717075, 6.047202134504914, 7.301603648811579, 12.324954997748137, 4.07700595445931, 2.0033634128049016, 0.7577684603165835, 2.0199951203539968, 0.9864753379952163, 0.26747518801130354, 0.13942870893515646, 0.04476888228964526, 0.17074051313102245, 0.5527511145919561, 1.088494104333222, 1.43424182664603, 2.4197272583842278, 1.7938153445720673, 0.733327103080228, 0.9676415892317891, 2.974879606626928, 2.899640081450343, 2.315797135233879, 1.154235564172268, 0.23060968494974077, 0.174634903378319, 0.26359565556049347, 0.16871639440068975, 0.30058420670684427, 0.6945625331718475, 3.365558017976582, 15.035738088190556, 31.61771010607481, 46.00908637046814, 52.33957327902317, 56.47579573094845, 50.839451774954796, 46.33633241057396, 45.97220554947853, 42.473455891013145, 45.11991128325462, 47.17098422348499, 49.076137393713, 47.22849793732166, 46.094517186284065, 46.27982184290886, 45.5561962723732, 42.23025754094124, 46.57040745019913, 43.876192420721054, 46.02765217423439, 44.998101219534874, 46.957488879561424, 47.34380654990673, 46.034028232097626, 42.6316300034523, 42.274426370859146, 38.0576216429472, 39.046982154250145, 38.79459209740162, 41.38509929180145, 44.342039823532104, 44.014125019311905, 46.98282212018967, 46.35365568101406, 40.385714918375015, 43.019893169403076, 39.672439992427826, 43.73470701277256, 43.20682793855667, 54.07061979174614, 56.14591643214226, 46.14682137966156, 31.007793433964252, 14.964512810111046, 4.083737293258309, 1.6608448047190905, 0.10290771824656986, 0.18475086602848023, 0.05107353441417217, 0.07011443143710494, 0.047978574511944316, 0.060330921260174364, 0.0601714077492943, 0.14034771040314808, 0.06732972266036086, 0.08843922274536453, 0.02834547147358535, 0.008788553604972549, 0.037141504071769305, 0.0830059299187269, 0.3554155316669494, 0.07928869032184593, 0.07310864850296639, 0.05609280902717728, 0.06604295733268373, 0.027815616995212622, 0.14815531176282093, 0.4029118549078703, 2.020084890536964, 0.8657394885085523, 0.740930613828823, 0.5033625522628427, 1.1235771467909217, 9.958179797977209, 21.208045184612274, 18.185001499950886, 12.067574858665466, 27.108106389641762, 20.90225089341402, 43.91569510102272, 56.211231127381325, 59.31993171572685, 31.993340849876404, 7.905395524576306, 0.997107345610857, 2.6752606965601444, 4.751483537256718, 0.10865985255804844, 0.18434170517139137, 30.866220630705357, 66.55044972896576, 54.15331095457077, 64.57634165883064, 51.32222346961498, 70.2342076599598, 46.02741278707981, 39.73873883485794, 30.268263816833496, 31.32965136319399, 37.32735022902489, 17.0895753800869, 21.618848741054535, 38.28030489385128, 52.94042743742466, 2.0913289301097393, 0.27575283602345735, 0.04988216474885121, 0.13439305883366615, 0.14428952388698235, 0.16672452940838411, 0.18421714310534298, 0.2845170657383278, 0.22649999766144902, 0.21473382512340322, 13.870984688401222, 82.72434264421463, 41.418218314647675, 95.82323536276817, 46.85406602919102, 48.637857511639595, 52.593350261449814, 50.19198551774025, 48.50358411669731, 87.36843824386597, 104.33075085282326, 56.98221355676651, 40.723740980029106, 50.49760311841965, 58.78029607236385, 74.56981301307678, 80.07719948887825, 20.548449978232384, 0.7062793825753033, 0.4271819244604558, 0.2741818578215316, 0.268233455135487, 0.08515426190569997, 0.35752156865783036, 0.2111384313320741, 1.842717295512557, 4.553125631064177, 8.237164746969938, 5.507820127531886, 2.577012456022203, 0.500350798247382, 3.4081888804212213, 8.022174183279276, 9.38433364033699, 17.61252421885729, 8.188177775591612, 3.3785632951185107, 1.5280427620746195, 4.3261965829879045, 1.7238530237227678, 0.5458242644090205, 0.2464004946523346, 0.15617944212863222, 0.43915273679886013, 0.4526754393009469, 0.9506436763331294, 1.95354666095227, 3.3552565332502127, 2.54918678663671, 1.4991478063166142, 1.5218709432519972, 3.1704947724938393, 2.4667345359921455, 2.0391712663695216, 1.303679645061493, 0.43662768322974443, 0.29908459342550486, 0.4548868315760046, 0.15449754253495485, 0.1688046209164895, 0.585794379003346, 6.250787610188127, 19.230528697371483, 37.41792976856232, 49.983331114053726, 52.60695353150368, 58.25342774391174, 52.688854336738586, 50.91694861650467, 46.50273308157921, 45.70115089416504, 46.85456000268459, 49.88033004105091, 49.712474048137665, 49.27509851753712, 49.230857491493225, 46.277040392160416, 46.269801780581474, 43.70273172855377, 46.042243391275406, 46.86171121895313, 47.46437408030033, 47.134825363755226, 50.85559330880642, 52.437300235033035, 51.91197082400322, 45.54535545408726, 45.30270427465439, 41.49432063102722, 40.241163074970245, 42.847754806280136, 46.11189365386963, 46.93602383136749, 46.72364182770252, 53.09858255088329, 49.86340194940567, 45.09426265954971, 47.3262894898653, 46.340667977929115, 47.26273030042648, 46.1141849309206, 54.54824656248093, 56.073522716760635, 53.26795466244221, 45.173370614647865, 22.05543391406536, 11.729563996195793, 2.845524810254574, 0.13563623040681705, 0.39592797809746116, 0.2629027864895761, 0.18945378164062276, 0.18147115217288956, 0.1733466240693815, 0.11506813447340392, 0.16962847905233502, 0.33241100201848894, 0.20745046203956008, 0.15261229447787628, 0.14938790031010285, 0.16886330995475873, 0.18888909631641582, 0.5972140724770725, 0.3592175542144105, 0.21927646652329713, 0.10587374854367226, 0.11579952843021601, 0.19212873419746757, 0.18230884394142777, 0.5196643900126219, 1.9355939305387437, 1.0427096486091614, 1.508351624943316, 0.6211374700069427, 3.426775108091533, 8.356574289500713, 20.546341091394424, 16.8568454682827, 15.37439301609993, 28.262904323637486, 27.176128439605236, 41.6580006480217, 56.610038727521896, 57.98410199582577, 28.136443309485912, 4.672981174662709, 0.6465997849591076, 0.8785416546743363, 5.065145306289196, 0.15880894556175917, 0.27487864543218166, 37.61956214904785, 77.45478540658951, 60.292386934161186, 71.83215871453285, 53.549751341342926, 78.31523403525352, 60.04127740859985, 46.08556106686592, 30.494216792285442, 35.6708937138319, 41.099719405174255, 22.845914997160435, 31.574227139353752, 57.070045843720436, 76.68451353907585, 2.317799865268171, 0.31757944787386805, 0.37760414415970445, 0.24715049425140023, 0.24338405026355758, 0.3215389541583136], [0.06596129140234552, 0.14293204672867432, 0.10813745480845682, 0.7611992012243718, 4.453447479754686, 33.506469056010246, 31.930632814764977, 23.344358950853348, 66.61313876509666, 43.0976065993309, 59.50298309326172, 58.38135927915573, 34.88205224275589, 51.39224611222744, 27.702565491199493, 33.56509231030941, 33.20964798331261, 25.671454779803753, 40.85993707180023, 62.15013384819031, 51.79883189499378, 19.717882946133614, 0.43680734233930707, 0.4647278581978753, 0.09299298893893138, 0.1214166809222661, 0.034634718467714265, 0.07155034618335776, 0.25288898788858205, 0.6328020722139627, 0.5768740607891232, 1.833186219446361, 4.759878711774945, 1.1827795137651265, 1.7377529153600335, 4.1031305026263, 2.8912083338946104, 13.519530147314072, 25.67268781363964, 12.455946318805218, 6.713363863527775, 1.3616507593542337, 7.64299395494163, 7.910730913281441, 7.012157030403614, 2.2037530224770308, 0.4358495265478268, 0.31849068647716194, 0.26643374701961875, 2.0793849835172296, 2.623600331135094, 3.4007856901735067, 2.947682566009462, 3.0475366953760386, 2.0759601797908545, 2.908465345390141, 5.393009288236499, 3.5541703971102834, 2.2548263194039464, 1.4590413146652281, 0.23447654151823372, 0.430453994194977, 0.5227029207162559, 0.10987248475430533, 0.0902577665692661, 0.19889674993464723, 5.675277141854167, 13.30971110612154, 28.621612675487995, 47.6624346524477, 55.203544199466705, 52.94195495545864, 45.87754502892494, 44.442001059651375, 41.46860361099243, 42.104936465620995, 44.275129213929176, 45.13996280729771, 44.932991713285446, 43.0510438978672, 44.741481989622116, 44.890620186924934, 41.91966600716114, 42.742861434817314, 41.314852461218834, 45.07176786661148, 42.968637719750404, 44.778267815709114, 44.58576254546642, 43.409231677651405, 41.96423381567001, 38.098549246788025, 36.8925965577364, 36.14170365035534, 35.86084932088852, 38.29634763300419, 43.96698474884033, 40.946625620126724, 41.257236152887344, 39.070700481534004, 37.65545502305031, 37.51787580549717, 36.7213549464941, 38.3687299489975, 42.22522281110287, 52.28966675698757, 53.29757787287235, 34.22530688345432, 14.349691551178694, 6.072324486449361, 1.7741465312428772, 0.6348943943157792, 0.3336926019983366, 0.07083397329552099, 0.042366943598608486, 0.03366830860613845, 0.032121093972818926, 0.07397273846436292, 0.12039996829116717, 0.08400227801757865, 0.08008463628357276, 0.12641700479434803, 0.03967459510022309, 0.07903914316557348, 0.8569097716826946, 1.794615676626563, 1.471206599380821, 0.4567218659212813, 0.21452583081554621, 0.08863841518177651, 0.9263878560159355, 6.608094787225127, 6.875490713864565, 7.071397751569748, 7.707342077046633, 1.1529489769600332, 2.0854235719889402, 1.52316928608343, 4.153683939948678, 16.743638142943382, 25.33820316195488, 19.62007999420166, 10.585191752761602, 25.639591589570045, 15.683278441429138, 43.62604044377804, 54.2445782572031, 59.713921174407005, 44.28079850971699, 16.11335076391697, 5.780839277431369, 12.971415258944035, 4.263788256794214, 0.10897470870986581, 0.7741965819150209, 35.1941142976284, 55.261787474155426, 56.08982764184475, 49.699311554431915, 29.849150106310844, 54.897341430187225, 70.9289775788784, 23.968663550913334, 27.271195538342, 26.690607592463493, 19.958356842398643, 37.27244317531586, 22.147767059504986, 45.643359795212746, 30.611603893339634, 0.19930377340642735, 0.20090866775717586, 0.061672817028011195, 0.08856844549882226, 0.026754557329695672, 0.08746445630094968, 0.01785592652595369, 0.05749970208853483, 0.18185951805207878, 0.40963660343550146, 4.485509684309363, 46.351087018847466, 49.48455847799778, 51.777610033750534, 73.68259862065315, 48.176452070474625, 71.62142962217331, 42.937570586800575, 30.80815974622965, 56.774543300271034, 30.569775737822056, 35.30673265457153, 39.6782460808754, 35.73260620236397, 49.987222105264664, 65.4279063642025, 68.64293664693832, 40.14729291200638, 0.418046175618656, 0.4467412264784798, 0.11679167597321793, 0.14799212833167985, 0.10679890241590329, 0.07499165527406149, 0.6371922616381198, 2.493998548015952, 2.263553263619542, 2.563289017416537, 6.069899266585708, 1.4117897814139724, 1.6858029342256486, 6.025093495845795, 3.272267561405897, 15.697408933192492, 28.28896712511778, 14.749526996165514, 7.590840803459287, 1.5907139866612852, 10.34017900004983, 10.248406324535608, 6.742096971720457, 2.1155825536698103, 0.6434096780139953, 1.7964807827956975, 1.3484554924070835, 3.052114974707365, 4.076275443658233, 3.9641282614320517, 4.2539282608777285, 7.704520728439093, 6.119764465838671, 7.439522473141551, 7.984145823866129, 5.480844900012016, 3.5448069870471954, 2.491905097849667, 0.7433962658978999, 0.45863601320888847, 0.09487721283221617, 0.30746629054192454, 0.0737529736943543, 0.31825331796426326, 3.429398867301643, 11.869082059711218, 26.447741724550724, 44.70754601061344, 54.09795932471752, 58.53449106216431, 49.30214546620846, 46.06074079871178, 43.39810587465763, 45.11579230427742, 48.020280450582504, 47.67100319266319, 46.259960308671, 45.16859047114849, 46.49554766714573, 46.39299117028713, 43.11806470155716, 44.94223661720753, 43.94452415406704, 47.01144978404045, 44.4170667976141, 47.50275582075119, 47.340774312615395, 48.521895334124565, 43.97310622036457, 42.21081018447876, 40.627894923090935, 39.40136633813381, 40.59397794306278, 42.361943274736404, 44.99163776636124, 43.61646115779877, 43.21773715317249, 39.68963406980038, 40.50072714686394, 39.9725478887558, 39.37550492584705, 40.92834860086441, 45.736614391207695, 55.593414679169655, 48.81318770349026, 27.85748317837715, 10.838537458330393, 2.5322154723107815, 2.25494506303221, 2.718941015191376, 0.5755705526098609, 0.08794391338597052, 0.023891279233794194, 0.020875599257124122, 0.05627208964142483, 0.03378825822437648, 0.0885955042031128, 0.09087947109946981, 0.03980981440690812, 0.07636952665052377, 0.06358059297781438, 0.896946145221591, 2.74015290196985, 4.191326620057225, 2.273137061856687, 0.6792511360254139, 0.13744975731242448, 0.16256710718153045, 3.0307107232511044, 10.04909846931696, 9.85211418941617, 8.303964212536812, 11.005532797425985, 2.1390147088095546, 4.17839496396482, 1.0096915578469634, 18.731902353465557, 22.554622627794743, 32.55456693470478, 25.82772519439459, 23.30325275659561, 28.480131067335606, 30.672332234680653, 51.131796687841415, 61.110372841358185, 64.88139688968658, 61.13787956535816, 50.040913224220276, 29.11836951971054, 32.61867709457874, 4.856770187616348, 0.15121451870072633, 3.7411448266357183, 54.060033559799194, 68.6484843492508, 67.29645609855652, 59.11374717950821, 38.69523502886295, 67.68372371792793, 63.194914385676384, 28.100379444658756, 37.73246169090271, 33.28423798084259, 33.417835012078285, 58.539719581604004, 31.375045627355576, 51.96636490523815, 33.09707522392273, 0.2898084599291906, 0.34163040574640036, 0.029371514756348915, 0.12518389674369246, 0.0754174699250143, 0.0855448393849656, 0.11163694827700965, 0.3131642332300544, 0.2402932575205341, 0.9271313692443073, 4.321628753095865, 75.70545807480812, 65.44777929782867, 45.66983297467232, 106.00443184375763, 63.96094188094139, 84.88804534077644, 80.63894614577293, 52.49437317252159, 62.48305298388004, 39.141061305999756, 47.12248742580414, 46.18754379451275, 44.30143140256405, 60.631921514868736, 76.5965786576271, 76.95062085986137, 53.10282312333584, 0.2027068322058767, 0.5577850725967437, 0.22340059600537643, 0.28188169933855534, 0.11551659204997122, 0.2947119186865166, 1.0617720382288098, 5.805299989879131, 5.183225395157933, 3.6713895946741104, 7.064190488308668, 2.582400804385543, 2.1772503945976496, 6.617542505264282, 4.393322356045246, 18.51797003298998, 29.331353791058064, 22.465211525559425, 11.456563845276833, 4.644147846847773, 13.67569986730814, 11.356281526386738, 7.808610443025827, 2.7349205827340484, 1.4327695243991911, 3.5968029219657183, 2.04395592212677, 3.906833273358643, 3.979250737465918, 4.42438711412251, 5.17627271823585, 7.497263699769974, 6.1417956836521626, 9.338865280151367, 8.55904832482338, 4.710649028420448, 3.862887443974614, 3.343601608648896, 1.7350894957780838, 0.9229397785384208, 0.965599020710215, 0.37838152900803834, 0.22010813205270097, 0.4927457438316196, 6.355402646586299, 14.592280983924866, 32.97628350555897, 48.40054124593735, 53.99424768984318, 60.65644159913063, 50.56336998939514, 49.61879387497902, 45.094410851597786, 47.74665713310242, 49.939177483320236, 53.04098904132843, 48.54438252747059, 47.298353388905525, 50.74933961033821, 52.07426391541958, 46.162750124931335, 47.696731612086296, 45.211554765701294, 51.067466139793396, 48.695302829146385, 51.14853098988533, 49.729143753647804, 50.849209651350975, 48.928762301802635, 46.786954030394554, 43.5496911406517, 43.11224341392517, 43.07194657623768, 45.899063274264336, 48.78677912056446, 48.06047089397907, 47.68863424658775, 43.58556881546974, 43.272970989346504, 43.76477099955082, 41.1613254994154, 45.179811269044876, 50.18033914268017, 57.90108025074005, 57.10379183292389, 36.36575862765312, 15.352821573615074, 8.29255722463131, 3.2182715088129044, 1.5245207073166966, 0.5724974675104022, 0.22797387326136231, 0.18378040404058993, 0.08211376451072283, 0.11157486762385815, 0.16344125324394554, 0.256139297853224, 0.19477572262985632, 0.21580290369456634, 0.3278554620919749, 0.19914198521291837, 0.7441126462072134, 2.120224004611373, 3.547976966947317, 2.9090735502541065, 0.7977373281028122, 0.30134933127555996, 0.180958921846468, 2.077098456211388, 7.8547038696706295, 9.977186378091574, 7.387695629149675, 12.162604909390211, 6.188829084858298, 7.30783436447382, 3.1180081889033318, 21.481970585882664, 28.933739326894283, 36.75670824944973, 30.17206247895956, 32.50086821615696, 43.15316341817379, 38.611388728022575, 62.26693578064442, 66.43216207623482, 74.00756478309631, 72.90249288082123, 47.71034248173237, 21.06443379074335, 34.73250366747379, 8.768741972744465, 0.37787906534504145, 3.796773129142821, 61.96604132652283, 79.7644154727459, 74.8599274456501, 69.87036198377609, 42.5382424145937, 72.69199937582016, 83.98228034377098, 36.00430682301521, 46.08891248703003, 45.38506865501404, 40.56310459971428, 73.95716428756714, 42.96626664698124, 84.0672817826271, 47.26954713463783, 0.42319276195485145, 0.35646074276883155, 0.1514334077364765, 0.41009094624314457, 0.32988167367875576, 0.3994688537204638], [0.07197359300334938, 0.07868965098168701, 0.10111224037245847, 0.04416895979375113, 0.21032907476183027, 41.11657530069351, 76.14653840661049, 24.280083440244198, 27.08452295511961, 66.35510981082916, 52.81231351196766, 57.27330073714256, 54.696039631962776, 26.529285348951817, 31.867250315845013, 62.604574263095856, 25.394677631556988, 22.513379640877247, 41.39932572841644, 60.692950040102005, 61.63392774760723, 38.090729266405106, 5.413780873641372, 0.43035798997152597, 0.07962739167851396, 0.14910898637026548, 0.21618956263409927, 0.4452035261783749, 2.446729321964085, 3.782399925403297, 2.036919412203133, 0.5161302234046161, 1.3441195688210428, 3.4315953869372606, 3.2509490428492427, 3.619404584169388, 10.27987053617835, 30.799703299999237, 38.93016882240772, 28.784680925309658, 10.274485275149345, 6.246339473873377, 10.87068373337388, 20.977389961481094, 25.505918562412262, 16.752702556550503, 19.84817035496235, 27.137085534632206, 20.897263661026955, 17.220539152622223, 18.38036421686411, 14.515190720558167, 15.82693163305521, 16.38243332505226, 13.469199948012829, 11.087881028652191, 11.318970378488302, 10.310338251292706, 5.203606076538563, 3.8839463889598846, 1.725779757834971, 1.1033566505648196, 0.36010073963552713, 0.1654375859652646, 0.14248764869989827, 0.13980827294290066, 0.4001743096159771, 6.910214200615883, 15.037105064839125, 26.790019758045673, 49.80501048266888, 60.91082274913788, 51.30137398838997, 41.32610745728016, 42.75950834155083, 42.075138464570045, 46.412476524710655, 43.35722766816616, 45.507064908742905, 44.09501127898693, 45.23330099880695, 42.17713639140129, 42.63937018811703, 38.63665357232094, 39.01259779930115, 40.59397414326668, 43.81179727613926, 42.787136659026146, 43.91329362988472, 45.40816381573677, 40.142410174012184, 37.224489748477936, 36.52107909321785, 37.91957885026932, 37.08383649587631, 36.79597154259682, 38.08304987847805, 40.423720479011536, 41.73398897051811, 39.97471757233143, 37.268574982881546, 35.43442100286484, 38.80664125084877, 38.398603945970535, 47.52554699778557, 54.54501673579216, 33.04736629128456, 15.48995241522789, 7.1561322547495365, 0.5426080338656902, 0.5744187987875193, 0.8368506480474025, 0.2826496440684423, 0.08607688505435362, 0.03955896849220153, 0.011981065108557232, 0.040658909274498, 0.08046418544836342, 0.039756505939294584, 0.08963288564700633, 0.04942945466609672, 0.04005115340987686, 0.3163900226354599, 1.706097051501274, 4.458376290276647, 9.838524218648672, 4.789402177557349, 2.510103271342814, 2.0511090382933617, 9.669957663863897, 18.315790481865406, 23.818265721201897, 27.247234024107456, 16.605065278708935, 15.731172021478415, 3.8989154482260346, 4.9899297673255205, 2.4249992379918694, 17.061924263834953, 16.82900246232748, 23.05504247546196, 18.545374162495136, 15.612786523997784, 14.291493874043226, 20.89088760316372, 34.243960082530975, 46.947157233953476, 49.67849247157574, 55.14526292681694, 62.87876754999161, 52.40337945520878, 33.779647797346115, 2.977807824499905, 0.09517216458334588, 7.119675111025572, 57.287941351532936, 58.47346253693104, 56.546023562550545, 28.051671758294106, 33.422045186161995, 48.55336904525757, 101.09029233455658, 46.83515064418316, 35.056827664375305, 68.25509905815125, 66.32557019591331, 29.280592314898968, 22.470856122672558, 39.41652752459049, 7.098089894279838, 0.35890160710550845, 0.35027292324230075, 0.10223369230516255, 0.06470983003964648, 0.06441482633817941, 0.056894001972978, 0.06833200794062577, 0.04522833849478047, 0.08167992724338546, 0.16196534415939823, 1.007638005539775, 45.88099904358387, 69.02170032262802, 37.60446555912495, 57.82104894518852, 88.90930116176605, 59.61369015276432, 62.081984505057335, 58.09843026101589, 36.08362376689911, 34.6019084751606, 63.232414573431015, 30.79500675201416, 34.54757899045944, 52.54272937774658, 69.33977365493774, 71.67060658335686, 62.03280374407768, 9.43443775177002, 0.6644086574669927, 0.08342522851307876, 0.07001154008321464, 0.9170044970232993, 1.431626498233527, 3.2371512707322836, 6.27026061527431, 2.9665782395750284, 0.7771701598539948, 1.4244175725616515, 3.9869688358157873, 5.1622842438519, 3.977209059521556, 16.23475804924965, 35.54561823606491, 41.767537370324135, 36.57681830227375, 10.978934224694967, 7.843709634616971, 13.292003106325865, 25.678360909223557, 32.444756627082825, 20.288144946098328, 24.016512483358383, 31.15731541067362, 28.309210538864136, 22.40785550326109, 25.09855382144451, 21.15978967398405, 24.238870851695538, 24.13891911506653, 17.61831320822239, 15.579322669655085, 14.005230534821749, 11.222783289849758, 8.390381075441837, 6.774783292785287, 2.1827204385772347, 0.19611322117270902, 0.11162424270878546, 0.1056320162024349, 0.4528691101586446, 0.2608024195069447, 0.4551009857095778, 6.504731783643365, 14.374121390283108, 26.5339457988739, 47.88621224462986, 60.621434077620506, 52.26858168840408, 44.835944920778275, 42.94553115963936, 46.13694570958614, 46.6175477206707, 46.459544599056244, 49.017764925956726, 47.66366958618164, 48.37349809706211, 45.70702537894249, 45.04446633160114, 43.22349764406681, 40.65841868519783, 45.045085698366165, 45.31931318342686, 44.643671438097954, 48.45690742135048, 49.84123393893242, 44.205292761325836, 41.166090443730354, 40.023780539631844, 41.96200713515282, 38.70481051504612, 39.601239413022995, 41.0061152279377, 42.64181725680828, 41.69544763863087, 41.392261907458305, 39.121997728943825, 39.54149141907692, 41.67230688035488, 42.50293470919132, 50.07425643503666, 51.90335288643837, 28.326083533465862, 12.554683070629835, 4.339412748813629, 1.544840473216027, 1.9745141733437777, 2.6856441143900156, 0.5333256663288921, 0.06409972527762875, 0.11478945802082308, 0.0756866617302876, 0.2077025844482705, 0.11717918838257901, 0.16985553171252832, 0.10203904181253165, 0.19115561532089487, 0.13047459331573918, 0.3662198659731075, 1.6976357367821038, 6.0557877738028765, 13.737550098448992, 6.146629499271512, 2.2599330078810453, 3.79036049824208, 15.99272433668375, 22.761107347905636, 25.223770402371883, 36.66082799434662, 24.751659035682678, 20.817684531211853, 7.4636036809533834, 3.7920604320243, 19.72276758402586, 29.607237987220287, 28.97050805389881, 33.51502999663353, 33.44771660864353, 33.81898708641529, 31.074382960796356, 37.73754581809044, 46.59511372447014, 54.29518014192581, 59.878684133291245, 63.988763988018036, 73.3810468018055, 66.7368221282959, 37.58028365671635, 3.2028923090547323, 0.11630799606791697, 14.65647853910923, 74.00565728545189, 69.16071206331253, 63.983216285705566, 34.60563987493515, 48.61828476190567, 54.98567149043083, 96.54339551925659, 35.67513428628445, 45.09705550968647, 76.99182584881783, 81.2633666396141, 36.90982103347778, 34.55009825527668, 42.737887501716614, 6.070532882586122, 0.31985662411898375, 0.22214869677554816, 0.11970145147643052, 0.09793218952836469, 0.10661338033969514, 0.1853703663800843, 0.16679390537319705, 0.2244647912448272, 0.2884306776104495, 0.1852116358350031, 0.9228974464349449, 51.31604880094528, 114.06207427382469, 39.215655103325844, 47.78767213225365, 87.92513117194176, 64.48940992355347, 76.89384430646896, 74.57510992884636, 43.328846991062164, 41.07869513332844, 73.61776649951935, 38.261408507823944, 38.25258918106556, 60.49664877355099, 80.1624821126461, 79.80800673365593, 73.37713301181793, 8.911388218402863, 0.7711880339775234, 0.2554667933145538, 0.3053123701829463, 0.7036428584251553, 2.4475460406392813, 4.512701025232673, 7.038446869701147, 5.374998729676008, 2.630581744015217, 3.131830422207713, 3.803593050688505, 6.248756144195795, 7.458187071606517, 21.941951103508472, 38.20449896156788, 41.04639306664467, 42.277682796120644, 16.920887231826782, 13.464704789221287, 18.990320786833763, 28.686895072460175, 32.40645848214626, 22.14005157351494, 23.88344742357731, 33.87688457965851, 32.710803151130676, 26.86673954129219, 27.437098436057568, 21.88626129180193, 24.82217565178871, 24.148589596152306, 16.81394387036562, 16.257211044430733, 14.966174270957708, 11.797423604875803, 7.608000682666898, 5.835561566054821, 2.610803092829883, 1.357015126850456, 0.17460125440265983, 0.2322433449444361, 0.5303402140270919, 0.26065749290864915, 1.2618093355558813, 8.88266745954752, 14.621300026774406, 31.825080178678036, 52.254784628748894, 64.62697774171829, 54.14067663252354, 46.34363181889057, 46.42884224653244, 48.58075797557831, 49.85484100878239, 48.900138437747955, 51.46884240210056, 48.103100806474686, 51.6155943274498, 48.744369596242905, 48.490938395261765, 44.28656280040741, 43.68619881570339, 49.98301953077316, 50.85824556648731, 48.3014577627182, 51.71399384737015, 52.97611132264137, 46.552354618906975, 44.606121852993965, 43.11763912439346, 46.16267792880535, 42.42631562054157, 44.09488208591938, 43.63859876990318, 46.27245783805847, 49.02373440563679, 46.254967376589775, 43.36169622838497, 43.20109784603119, 45.03958359360695, 47.20290631055832, 53.63021582365036, 59.967249780893326, 35.851995795965195, 20.063713788986206, 10.983594674617052, 4.494947427883744, 1.22802629834041, 1.9934839429333806, 0.7637618074659258, 0.22678066306980327, 0.2188765082973987, 0.17041217215592042, 0.24438456923235208, 0.1404619714594446, 0.27668242051731795, 0.1714072289178148, 0.2682593115605414, 0.1829569911933504, 0.5120745941530913, 2.727800952270627, 6.3912860210984945, 14.48712257668376, 6.399575276300311, 3.2516154320910573, 3.674358897842467, 13.201548010110855, 24.4547201693058, 32.34381124377251, 34.22483190894127, 21.7632257938385, 26.33308857679367, 14.887521341443062, 8.257954381406307, 24.09768372774124, 40.35544574260712, 40.2023633569479, 44.0599125623703, 45.242279917001724, 44.93101201951504, 40.94382517039776, 48.73065613210201, 55.29681779444218, 65.12790486216545, 69.64573323726654, 71.08714789152145, 86.71219065785408, 76.05274423956871, 47.382150292396545, 4.0320059191435575, 0.367069625062868, 16.627550572156906, 85.6437411904335, 75.26489451527596, 74.07485917210579, 46.79187476634979, 46.59328982234001, 58.95365037024021, 116.16627216339111, 61.50155045092106, 49.39423732459545, 103.93330737948418, 107.74953380227089, 53.41881796717644, 49.18394900858402, 76.87926068902016, 10.277731250971556, 0.6249874352943152, 0.7579360075760633, 0.25408176763448864, 0.302635146654211, 0.252932685543783, 0.242949329840485], [0.04358289319497999, 0.05379523485316895, 0.08152857364621013, 0.13416036585113034, 1.117423614487052, 11.326391380280256, 82.68760621547699, 56.12484276294708, 17.211503237485886, 16.61234188824892, 48.52598771452904, 63.63943353295326, 32.8481961786747, 35.902692675590515, 49.5722159743309, 65.48109591007233, 27.120605818927288, 22.936794720590115, 41.74642950296402, 63.032594695687294, 65.89300140738487, 64.71026167273521, 22.545434720814228, 0.4500316421035677, 0.11181360910995863, 0.07579959434224293, 1.9214126165024936, 2.478744979016483, 4.189865123480558, 10.33477284014225, 11.597527731209993, 0.9954842389561236, 3.3312660455703735, 4.870994249358773, 10.02183398231864, 6.004723738878965, 16.660470105707645, 29.609671756625175, 37.33649633824825, 41.0378473252058, 32.329087033867836, 11.967237442731857, 13.778769336640835, 23.064163886010647, 38.922846615314484, 43.701166212558746, 29.963345378637314, 28.8815301284194, 43.45593497157097, 37.363167107105255, 32.78329186141491, 34.572551250457764, 39.31713625788689, 46.561907306313515, 46.909854635596275, 31.266472153365612, 20.764407590031624, 19.034020341932774, 10.505386535078287, 6.250580521300435, 1.8909615254960954, 0.5100772669538856, 0.6836802139878273, 0.37189667229540646, 0.0749428071139846, 0.1861759676830843, 0.3610838478198275, 3.02677437197417, 9.82444692403078, 18.251876011490822, 34.184884652495384, 51.27629153430462, 53.31895172595978, 46.48984417319298, 41.05890579521656, 40.531870275735855, 44.86078038811684, 44.58106979727745, 47.50941686332226, 46.172868981957436, 43.76035563647747, 42.19546660780907, 40.27571462094784, 39.153030663728714, 37.611719369888306, 38.213732466101646, 39.91427801549435, 40.73979511857033, 43.45209717750549, 42.37205073237419, 38.798190504312515, 38.437251672148705, 36.54409445822239, 36.62473753094673, 36.04535602033138, 37.48115457594395, 38.04953947663307, 38.4537959843874, 37.96242915093899, 33.85564371943474, 34.35543470084667, 35.53515739738941, 38.77404659986496, 40.61236895620823, 48.81366267800331, 39.84944589436054, 16.019201315939426, 5.704261036589742, 1.0471082688309252, 0.7113218901213259, 2.4197139590978622, 2.1813368378207088, 0.1383481567609124, 0.08634557962068357, 0.055098334851209074, 0.02785619391943328, 0.0901744159637019, 0.06790707644540817, 0.17629808600759134, 0.13697142829187214, 0.16242951300228015, 0.6603024434298277, 0.8219524787273258, 6.651975307613611, 13.275037966668606, 17.03837312757969, 11.163660362362862, 3.72287564445287, 16.045636497437954, 41.06124646961689, 23.710706792771816, 26.17539893835783, 45.00538542866707, 39.39685598015785, 14.013415295630693, 8.892712220549583, 7.541627269238234, 14.327605236321688, 17.11233615875244, 18.30571912229061, 20.292208828032017, 21.21400896459818, 22.187797911465168, 23.602308109402657, 29.290448985993862, 35.65261289477348, 44.48778860270977, 53.866019770503044, 60.553242936730385, 67.17991635203362, 62.660157680511475, 31.163719967007637, 3.1553765712305903, 0.028331973662716337, 22.71683592349291, 65.4652127623558, 65.03164082765579, 41.16763316094875, 28.417738415300846, 38.96806038916111, 43.06477256119251, 94.24208700656891, 64.77624893188477, 49.3558631837368, 72.65389502048492, 25.103957131505013, 24.46885921061039, 26.381268091499805, 27.892602793872356, 0.7164233538787812, 0.0692718118079938, 0.08215369205572642, 0.02725628812186187, 0.06309661621344276, 0.06630209303693846, 0.02888963084842544, 0.03538014643709175, 0.07409770871163346, 0.03007592422363814, 0.05118101224070415, 1.005086679942906, 19.033663161098957, 83.18045496940613, 48.35688158869743, 30.29178835451603, 44.23193693161011, 50.46804450452328, 54.829906448721886, 41.27416804432869, 54.24861364066601, 53.40782515704632, 71.40107184648514, 29.487056136131287, 32.021759524941444, 52.62005142867565, 68.5743199288845, 71.95639684796333, 77.34455332159996, 34.51471075415611, 0.338309146463871, 0.006177242994453991, 0.17820457433117554, 5.225812084972858, 5.392421269789338, 7.83811965957284, 14.08842422068119, 12.26749923080206, 1.364037743769586, 3.440692098811269, 6.335073737427592, 13.597202729433775, 9.333230182528496, 22.863331362605095, 39.93100091814995, 49.40523773431778, 50.35887636244297, 44.854605719447136, 17.077087350189686, 16.318934932351112, 27.013850547373295, 45.05007103085518, 51.215354204177856, 34.28555645048618, 36.26879923045635, 52.696586921811104, 48.8294318318367, 44.480785578489304, 44.54879812896252, 51.35326400399208, 52.91238874197006, 54.47238743305206, 47.41780377924442, 35.11837676167488, 25.46249069273472, 14.342053961008787, 8.429801110178232, 2.3578566033393145, 2.0009512547403574, 0.8957360882777721, 0.8716059580910951, 0.5274030903819948, 0.2201530765159987, 0.9420993004459888, 2.95155574567616, 7.957378635182977, 18.281297832727432, 31.392332799732685, 49.58858169615269, 53.876131027936935, 49.92905102670193, 44.84817646443844, 42.702515199780464, 45.77461615204811, 47.79712602496147, 52.18868337571621, 48.54168467223644, 46.240733340382576, 43.60923774540424, 41.13730698823929, 42.744818329811096, 41.89083695411682, 41.47806890308857, 42.50669650733471, 44.47671219706535, 44.61024463176727, 43.698928132653236, 42.87917912006378, 40.85414998233318, 39.87422436475754, 38.540822714567184, 38.92291881144047, 39.517552703619, 41.158065274357796, 39.69674728810787, 39.79411706328392, 37.24859185516834, 39.01150345802307, 39.879779666662216, 42.689626291394234, 44.257429763674736, 49.65912491083145, 33.68825890123844, 12.744033560156822, 3.9184024650603533, 1.4077163999900222, 1.5839364565908909, 3.4524185070768, 2.618121262639761, 1.1688645416870713, 0.07835861601051874, 0.1410008448874578, 0.04094645439181477, 0.08891231220331974, 0.09568402383592911, 0.22756515769287944, 0.027242704964010045, 0.14575614128261805, 2.159642851911485, 1.0286151361651719, 12.560858689248562, 18.85034579783678, 18.028159216046333, 18.666300773620605, 10.908441357314587, 25.92418871819973, 48.04985426366329, 30.703532360494137, 36.30033753812313, 55.60154624283314, 45.89559406042099, 18.8420432433486, 9.237344227731228, 18.164001926779747, 26.85131996870041, 31.939205154776573, 35.32911345362663, 39.126439690589905, 38.45857612788677, 37.887094393372536, 36.37187249958515, 40.82973249256611, 49.04250919818878, 56.75351142883301, 61.18536941707134, 66.93832531571388, 68.5966931283474, 64.27713051438332, 35.515892431139946, 4.223983017727733, 0.015550658135907724, 37.079105749726295, 75.2223140001297, 73.93175885081291, 51.09080448746681, 44.9976946413517, 54.28163766860962, 45.331255942583084, 95.75475543737411, 55.86006537079811, 55.75644493103027, 79.84771460294724, 39.7687154263258, 33.20824205875397, 38.310938850045204, 30.438996255397797, 0.6606408033985645, 0.165221220231615, 0.09845198233961128, 0.023865174189268146, 0.025725723571667913, 0.07784966597682796, 0.042557070701150224, 0.3903211117722094, 0.1774261356331408, 0.1571154684643261, 0.26258678000885993, 1.2535840831696987, 14.147987924516201, 108.22945564985275, 85.2015969157219, 32.771926671266556, 30.184653103351593, 65.26202246546745, 83.77654418349266, 49.94818679988384, 55.50679452717304, 56.48014269769192, 78.06454628705978, 35.14445096254349, 36.08686879277229, 58.11201833188534, 78.39622288942337, 78.17974090576172, 91.31784752011299, 35.12743167579174, 0.5933305621147156, 0.19316103192977607, 0.4932587163057178, 5.351289426907897, 8.246833328157663, 10.75850235298276, 18.671396300196648, 14.655855372548103, 2.4752890644595027, 3.947083088569343, 8.12911469489336, 16.570967808365822, 16.965679228305817, 32.39882469177246, 44.633408188819885, 50.87774991989136, 48.32639582455158, 45.6730742007494, 26.83104995638132, 20.325506441295147, 33.917553797364235, 44.64468218386173, 50.86961455643177, 39.74310860037804, 44.99959833920002, 62.91770026087761, 57.34506368637085, 56.112375631928444, 55.931379944086075, 58.60433131456375, 58.67489732801914, 57.921758741140366, 46.71362176537514, 36.33453570306301, 28.081416562199593, 16.74368754029274, 9.264653362333775, 2.795058055780828, 3.1091596512123942, 0.8987012947909534, 0.7470565976109356, 1.3358660554513335, 0.4690126032801345, 0.6118228635750711, 4.585521267727017, 11.800676230341196, 19.620581567287445, 36.810984537005424, 51.59195199608803, 55.61701521277428, 50.71174442768097, 46.72129735350609, 45.32598562538624, 50.34859411418438, 48.77997748553753, 54.02130983769894, 50.211885049939156, 48.52057300508022, 48.09423968195915, 44.00566667318344, 45.99024698138237, 45.21690107882023, 44.717402681708336, 46.10922619700432, 47.98201650381088, 49.17994022369385, 47.65860825777054, 44.457496628165245, 44.92690443992615, 43.30038271844387, 42.887432277202606, 42.13985279202461, 43.952442929148674, 45.80278784036636, 44.14928376674652, 46.12564891576767, 41.482651457190514, 42.23096050322056, 43.81130710244179, 48.44983600080013, 45.96387259662151, 54.89310085773468, 41.424392983317375, 17.436971738934517, 8.734362367540598, 3.7396954419091344, 2.2056849813088775, 3.4623252879828215, 4.493635073304176, 1.28391939913854, 0.15079728327691555, 0.33547310333233327, 0.1750650373287499, 0.24172065983293578, 0.5578952666837722, 0.31684329675044864, 0.1294999901438132, 0.6207304168492556, 2.08858001511544, 1.3232275773771107, 12.030142117291689, 20.29877297580242, 19.491800777614117, 18.562106564641, 9.4194352068007, 20.654620081186295, 48.79578463733196, 34.283466562628746, 40.35197652876377, 57.00967848300934, 48.784389048814774, 31.193124689161777, 18.350666910409927, 27.730229906737804, 42.401818335056305, 42.35783189535141, 45.64668841660023, 48.774418383836746, 50.35230651497841, 49.698521196842194, 48.69445167481899, 50.77484764158726, 57.082151994109154, 63.47395621240139, 68.97012189030647, 73.72189611196518, 74.95204210281372, 67.43315756320953, 38.29999163746834, 5.342574594542384, 0.21201017283601686, 36.201436445117, 86.24644964933395, 77.42260873317719, 69.70391571521759, 55.46718165278435, 48.63626539707184, 55.60414910316467, 109.72316309809685, 83.4667620062828, 69.98877882957458, 95.05085840821266, 39.594464376568794, 46.61345154047012, 60.687710121273994, 57.8862040489912, 1.3276048237457871, 0.2825170668074861, 0.27961354760918766, 0.126358850102406, 0.1366243851953186, 0.22542090009665117, 0.1574994853581302], [0.0478422456944827, 0.05040491130785085, 0.05567722117120866, 0.036083969607716426, 0.1282474971958436, 0.20820819481741637, 55.425752475857735, 71.62268355488777, 47.989308312535286, 24.2799998447299, 45.74402019381523, 70.85140094161034, 46.34124554693699, 34.59498904645443, 62.562958896160126, 69.37242150306702, 45.644826516509056, 36.69129855930805, 33.68397653102875, 53.25687825679779, 65.63269257545471, 72.0374009013176, 51.47111088037491, 0.2735625207424164, 0.14901140879373997, 0.2421202024561353, 7.916793487966061, 6.386564774438739, 9.348298273980618, 12.40879274904728, 12.90705906227231, 5.253025274723768, 7.870525745674968, 9.612165614962578, 9.257279857993126, 7.2995123360306025, 13.678285628557205, 38.01120713353157, 50.59656880795956, 44.433717504143715, 41.747660636901855, 23.879945911467075, 15.220013000071049, 20.164925158023834, 43.56226086616516, 52.017449364066124, 31.408082954585552, 35.87245769798756, 46.172602996230125, 53.361327052116394, 51.440066546201706, 45.970313251018524, 43.52025032043457, 45.38225680589676, 57.66405276954174, 66.17252200841904, 62.07969702780247, 48.74384522438049, 28.738528601825237, 6.636102609336376, 2.512843399308622, 2.6506736408919096, 2.2325737634673715, 1.9951062183827162, 0.5167910316959023, 0.20448822411708534, 0.659341273130849, 2.1058261021971703, 4.705625222995877, 12.775887250900269, 20.88317211717367, 41.110035851597786, 48.47820147871971, 44.40821707248688, 47.832809910178185, 40.922101736068726, 40.10163076221943, 44.08190198242664, 44.67668406665325, 45.892949402332306, 44.88121569156647, 40.69797456264496, 39.82259273529053, 37.72163987159729, 38.608979657292366, 40.66424377262592, 43.82394902408123, 41.425928100943565, 40.05396232008934, 40.269760340452194, 38.08885216712952, 36.78867593407631, 35.56111380457878, 36.382576525211334, 42.36738458275795, 37.84900903701782, 34.87838163971901, 37.44039036333561, 35.961551517248154, 33.56363318860531, 33.12070235610008, 34.54793997108936, 38.89826953411102, 44.89800699055195, 41.62090323865414, 16.84706289321184, 5.2113244123756886, 2.694400269538164, 1.4109019353054464, 2.6213002670556307, 4.959394130855799, 7.143039582297206, 1.1648910236544907, 0.09702032009954564, 0.06780332420021296, 0.12802010314771906, 0.12291574501432478, 0.13437021552817896, 0.056430107724736445, 0.22050237574148923, 0.04316175036365166, 1.6053993673995137, 4.14266643114388, 13.211659267544746, 26.247247382998466, 23.539579175412655, 26.346423961222172, 33.55491645634174, 50.30961200594902, 52.39614464342594, 44.55260552465916, 51.80942952632904, 49.02696043252945, 31.787699684500694, 15.823431070894003, 8.3587715215981, 7.806561402976513, 14.998271148651838, 20.693858675658703, 24.565729312598705, 27.16573789715767, 26.130675338208675, 27.520122081041336, 28.16719125956297, 32.60774128139019, 37.91169047355652, 45.92516407370567, 53.8311680406332, 62.35459327697754, 64.82680901885033, 67.546406686306, 37.20030404627323, 3.491820255294442, 1.0065243090502918, 46.13781966269016, 69.60439145565033, 54.915314465761185, 42.19410628080368, 33.04816424846649, 32.092257142066956, 50.69061376154423, 84.33963596820831, 61.49059183895588, 48.950937911868095, 26.105710677802563, 25.323009677231312, 34.55260992050171, 29.793650284409523, 9.323877934366465, 0.22173983277752995, 0.23673296731431037, 0.11987657606368884, 0.01958248671144247, 0.03525781452481169, 0.09803632769035175, 0.04893583740340546, 0.03794272299273871, 0.05330845648131799, 0.059513367668841965, 0.029857315348635893, 0.2556828473461792, 1.2474741297774017, 69.39452111721039, 63.76203015446663, 34.04615789651871, 37.2627042979002, 64.0508222579956, 74.97164905071259, 39.59087356925011, 43.15587267279625, 70.87704956531525, 76.66134998202324, 46.825723350048065, 39.46986146271229, 48.09373810887337, 57.161035761237144, 76.4895612001419, 76.67127504944801, 60.81693358719349, 0.8846983930561692, 0.06500984323793091, 0.9550541709177196, 12.690484933555126, 16.16385955363512, 17.187252938747406, 15.003743804991245, 18.81386585533619, 6.320649236440659, 10.419004820287228, 13.69529826566577, 11.979243848472834, 10.524658150970936, 25.632189586758614, 50.411222353577614, 58.18047545850277, 52.773737981915474, 50.577144250273705, 36.65531449019909, 19.970481991767883, 27.480702996253967, 53.83658654987812, 60.90044170618057, 40.27170963585377, 46.34213849902153, 56.930285543203354, 61.52641251683235, 58.37847903370857, 56.941426545381546, 52.09661811590195, 51.14725425839424, 60.997256711125374, 63.062248304486275, 65.05108058452606, 56.985979154706, 40.551541820168495, 23.623412176966667, 5.750056654214859, 2.402265532873571, 3.3073092810809612, 1.5093829133547843, 0.7987391680944711, 0.7660287420731038, 0.8313955657649785, 2.203111806884408, 4.195289332419634, 12.017466947436333, 18.83017648011446, 34.93596754968166, 47.07895316183567, 48.39780919253826, 47.28453733026981, 44.84735190868378, 42.849434316158295, 46.90543547272682, 47.362307757139206, 47.804984003305435, 44.51201610267162, 44.32932570576668, 42.76184521615505, 42.09471121430397, 41.447871923446655, 45.72533279657364, 46.7306524515152, 45.20102933049202, 42.982153594493866, 42.176866605877876, 42.62325145304203, 41.49789623916149, 39.661325588822365, 40.919270887970924, 41.32241025567055, 40.39284333586693, 40.13028882443905, 40.73268190026283, 37.87950620055199, 38.01134392619133, 37.13580630719662, 41.81220397353172, 43.008478581905365, 47.10027001798153, 34.61751043796539, 13.954497557133436, 4.695788975805044, 2.1415304113179445, 2.023155363276601, 2.079257690347731, 3.9101704442873597, 4.154004072770476, 2.2331841057166457, 0.4156579147092998, 0.18234926130389795, 0.06276881700614467, 0.13417764304904267, 0.13389553787419572, 0.1691493039834313, 0.23744703212287277, 0.7844241487327963, 2.0910009602084756, 10.942446682602167, 17.632020972669125, 31.662169620394707, 29.096404798328876, 31.680769622325897, 44.671455547213554, 55.38514405488968, 60.21535746753216, 57.13721103966236, 64.00633424520493, 57.13280327618122, 39.346273094415665, 28.19116797298193, 21.264033280313015, 22.119192592799664, 30.94627283513546, 35.28448484838009, 40.21389573812485, 39.28198054432869, 39.109838381409645, 39.967999532818794, 39.46611866354942, 43.046081364154816, 46.88716985285282, 51.656597927212715, 63.16884398460388, 66.30135789513588, 72.40001544356346, 73.83812427520752, 42.152897492051125, 2.6323434244841337, 2.5071475049480796, 60.63081957399845, 75.76560124754906, 59.256665110588074, 53.26128602027893, 59.72649849951267, 41.027652472257614, 50.590701922774315, 94.13825377821922, 55.63929341733456, 53.94287824630737, 33.302970975637436, 37.2760795801878, 39.63665351271629, 45.0969111174345, 8.450904227793217, 0.38061910425312817, 0.34104829479474574, 0.15784790884936228, 0.11208179901586846, 0.047911851725075394, 0.08649207957205363, 0.05974951163807418, 0.12993272161111236, 0.3855325374752283, 0.16672476689564064, 0.11943152494495735, 0.24546357773942873, 1.1121854768134654, 68.686733096838, 94.94811952114105, 65.91405227780342, 41.74498178064823, 50.91273844242096, 88.98965924978256, 63.66054520010948, 50.284806936979294, 69.3232673406601, 82.6449117064476, 55.94445124268532, 46.121681928634644, 48.51930387318134, 65.33541932702065, 80.77652156352997, 85.97918719053268, 65.88381350040436, 0.7929197209887207, 0.2591072057839483, 0.6136955693364143, 14.99501757323742, 21.585558727383614, 23.637824803590775, 17.672143019735813, 19.945144951343536, 9.784233681857586, 11.507426016032696, 19.115999042987823, 15.284490790218115, 23.640663251280785, 36.336416602134705, 53.45149241387844, 59.89336654543877, 55.46520575881004, 53.59589226543903, 43.90208043158054, 25.796295180916786, 34.74349267780781, 53.58858525753021, 60.14294855296612, 49.2545872181654, 50.601413547992706, 56.950523257255554, 60.27160584926605, 59.55659061670303, 63.73523399233818, 59.32827606797218, 60.91468334197998, 70.03342643380165, 73.7043334543705, 70.36511063575745, 61.686376333236694, 46.65298841893673, 30.361474715173244, 9.047333523631096, 2.7150296000763774, 5.123191941529512, 4.653327679261565, 1.3341003376990557, 1.002478594891727, 1.1032750736922026, 2.3644979344680905, 5.489758746698499, 15.645476169884205, 20.93456245958805, 40.981716737151146, 47.69281022250652, 48.359773233532906, 51.732419058680534, 46.91874235868454, 45.581635907292366, 49.14595864713192, 49.16771247982979, 51.046491265296936, 49.22422684729099, 47.74660773575306, 46.076946929097176, 45.13686217367649, 45.13549044728279, 47.610806822776794, 51.11925736069679, 49.780912175774574, 46.908764094114304, 46.393002569675446, 45.5857814848423, 43.29213336110115, 42.28737227618694, 43.15349020063877, 47.65928462147713, 45.08509375154972, 44.675357937812805, 45.72130501270294, 45.09746968746185, 41.07745260000229, 40.570388808846474, 43.78088213503361, 48.80969189107418, 49.758926555514336, 45.117426216602325, 18.378853797912598, 8.289705477654934, 4.818221731111407, 3.4785710787400603, 3.822339582256973, 6.569010559469461, 10.646362770348787, 4.091179193928838, 0.34795495856087655, 0.22692551545333117, 0.18839381664292887, 0.3356069274013862, 0.2047863299958408, 0.18308238446479663, 0.4679877567104995, 1.2519454210996628, 2.2742090793326497, 9.826425667852163, 21.056649908423424, 32.980208694934845, 27.624918557703495, 31.73804584890604, 42.6244255900383, 53.34437616169453, 61.3335956633091, 57.70259790122509, 64.37063589692116, 60.64631134271622, 48.04678022861481, 33.76194454729557, 28.144582472741604, 33.60202252864838, 40.83945617079735, 44.54824335873127, 49.12391982972622, 49.40666265785694, 49.189276322722435, 49.558035135269165, 47.97939844429493, 50.5563023686409, 54.991257190704346, 59.45269659161568, 68.33687826991081, 73.50723043084145, 79.97249990701675, 76.34668126702309, 50.09022697806358, 4.264177735894918, 1.5830968203954399, 61.58069260418415, 85.93886375427246, 67.93268635869026, 64.78916063904762, 52.729652747511864, 41.672439873218536, 66.05266883969307, 96.93625643849373, 72.27203831076622, 69.77035135030746, 40.69222167134285, 45.121465399861336, 60.86400546133518, 82.68664866685867, 21.635902225971222, 0.8783415716607124, 0.5229369050357491, 0.2731847972609103, 0.242711590253748, 0.14867671503452584, 0.38124716898892075, 0.13601815444417298], [0.028517744358396158, 0.07838179328246042, 0.04404126215376891, 0.1568379349191673, 0.09512222546618432, 1.25497005879879, 9.208603519946337, 75.81619173288345, 64.07587051391602, 50.35565033555031, 29.503243267536163, 58.575950637459755, 60.21883048117161, 59.81395460665226, 91.02909341454506, 87.01126500964165, 61.41692139208317, 52.47436344623566, 30.53694359958172, 39.03755486011505, 58.743039071559906, 66.77073150873184, 70.63571691513062, 4.080013018101454, 0.22431836550822482, 2.3742322996258736, 15.421110559254885, 15.926760826259851, 8.021309729665518, 2.805331042036414, 12.441192660480738, 14.103779196739197, 10.685336329042912, 10.47457778826356, 12.253097053617239, 8.429854307323694, 17.16976247727871, 38.533329516649246, 47.00671523809433, 45.941157415509224, 34.09089669585228, 22.12610252201557, 16.104293949902058, 22.325084544718266, 44.763023033738136, 55.21943114697933, 50.57170294225216, 57.49703273177147, 57.928214594721794, 55.45860931277275, 55.56230194866657, 59.30636644363403, 50.917210802435875, 46.36071190237999, 47.930970042943954, 51.92076735198498, 55.231465101242065, 49.24758039414883, 35.1061300188303, 21.099173426628113, 10.107724573463202, 1.7739962018094957, 4.555977853015065, 1.6981687769293785, 1.3599137775599957, 2.86155401263386, 1.0687552322633564, 2.421019901521504, 4.337661042809486, 7.5204747542738914, 13.953394666314125, 20.56127618998289, 41.318378672003746, 48.50015290081501, 43.55369232594967, 44.80453960597515, 41.950102373957634, 46.44486218690872, 45.062519162893295, 45.93732722103596, 41.61837637424469, 41.20200231671333, 37.44544789195061, 38.304961770772934, 38.37623454630375, 43.86462964117527, 42.08528012037277, 41.499879732728004, 42.32623279094696, 38.92188906669617, 39.38195697963238, 38.79270359873772, 36.71480409801006, 40.84843888878822, 37.01903477311134, 35.40435701608658, 35.26945285499096, 37.52099543809891, 34.02019388973713, 33.74003492295742, 34.80509877204895, 37.15368814766407, 38.53818565607071, 41.29348240792751, 19.605122096836567, 4.686771109700203, 2.4510751012712717, 2.1783107751980424, 1.1548238201066852, 3.00287626683712, 5.767416497692466, 4.013902740553021, 1.932253078557551, 0.10198171090451069, 0.307047808310017, 0.06408874891349114, 0.11800057516666129, 0.5447536718565971, 1.2893692567013204, 0.75720353750512, 1.7281425185501575, 7.75570398196578, 24.38242144882679, 30.71253787726164, 38.78104582428932, 44.04304526746273, 45.28092764317989, 57.25650943815708, 50.067443400621414, 50.7112542539835, 48.24292190372944, 50.013934671878815, 37.38976188004017, 29.040851779282093, 25.68726383149624, 15.919923093169928, 17.32358392328024, 22.941878847777843, 26.473466344177723, 28.58915861696005, 30.010761134326458, 30.709043964743614, 31.568141765892506, 33.54813002049923, 40.09196028113365, 42.385543808341026, 49.78282727301121, 58.091932609677315, 64.26264569163322, 70.50283044576645, 67.87597060203552, 35.115937292575836, 0.6028936989605427, 10.205667167901993, 59.11883130669594, 64.19519931077957, 40.35656288266182, 50.685218051075935, 31.648737341165543, 29.369712732732296, 53.410713002085686, 62.268478497862816, 65.89493930339813, 31.129041127860546, 34.56001192331314, 27.687691189348698, 32.449772357940674, 24.34793259948492, 0.8975474035833031, 0.024797326514089946, 0.07409787940559909, 0.10099607941810973, 0.06331175740342587, 0.08388240632484667, 0.023308131130761467, 0.024671083483553957, 0.051082855788990855, 0.13720222137635574, 0.03546099971572403, 0.17920736427186057, 0.1574195857392624, 1.2610965175554156, 16.338669173419476, 85.8301667869091, 53.26227396726608, 35.49372062087059, 44.810528084635735, 84.55183938145638, 64.2810595035553, 56.546597331762314, 94.05400469899178, 93.28668907284737, 73.87749016284943, 49.6232358366251, 46.605084389448166, 45.2938811480999, 62.27047719061375, 72.21295148134232, 81.70425698161125, 7.814909080043435, 0.5466752406209707, 1.9003821699880064, 23.356301710009575, 26.58235900104046, 11.054417174309492, 3.392384103499353, 15.049609243869781, 15.08845740929246, 13.028079718351364, 22.472695223987103, 22.02377401292324, 19.83414340764284, 31.798016130924225, 45.31451404094696, 53.84080812335014, 57.0672681927681, 40.947689563035965, 31.08550686389208, 26.113730147480965, 33.02912347018719, 54.12617661058903, 63.24488930404186, 59.74561907351017, 66.76930278539658, 62.882324159145355, 60.36467805504799, 61.57082833349705, 64.5113879442215, 58.732224851846695, 54.45978730916977, 56.2413939088583, 58.13008636236191, 58.8998718559742, 57.04098120331764, 49.63170938193798, 35.21111458539963, 24.189541898667812, 14.792162608355284, 5.240640789270401, 1.7772078607231379, 1.5972824092023075, 3.0107368575409055, 2.6253807730972767, 3.1216531433165073, 4.5735101122409105, 7.918434999883175, 12.613122034817934, 19.5560572296381, 37.82478913664818, 48.041221126914024, 45.558027774095535, 47.993928864598274, 45.29120609164238, 47.00233407318592, 44.63505730032921, 48.617688193917274, 42.536714896559715, 42.45209723711014, 42.78790041804314, 39.52317260205746, 39.07974399626255, 46.33959263563156, 42.169688791036606, 43.19360464811325, 42.84931272268295, 42.52191849052906, 41.220028549432755, 40.35009942948818, 38.58006700873375, 44.03878569602966, 40.7383967936039, 40.42782425880432, 37.59847708046436, 40.10304048657417, 37.47703939676285, 36.78067356348038, 39.41879600286484, 41.80422060191631, 41.6736064106226, 39.18330363929272, 15.664967224001884, 3.135836119763553, 1.7324265511706471, 1.8993982602842152, 0.7931869535241276, 1.2118050875142217, 3.8098501274362206, 1.8049524282105267, 1.1079760151915252, 0.5051285668741912, 0.47118344460614026, 0.2663318649865687, 0.4369139444315806, 1.3893663533963263, 2.0062085101380944, 0.15152924868743867, 5.187856396660209, 27.386333160102367, 40.49310855567455, 40.15426553785801, 48.40003967285156, 51.40064366161823, 54.00195747613907, 61.254316717386246, 55.95109708607197, 56.30569785833359, 55.54781332612038, 51.60683199763298, 40.43686017394066, 39.279814660549164, 37.33966916799545, 34.343989714980125, 37.82713741064072, 38.36968369781971, 39.78254668414593, 40.3387076407671, 42.84663766622543, 44.60742898285389, 45.90904153883457, 45.618148148059845, 51.7908751219511, 53.1057945638895, 57.98506714403629, 64.08818945288658, 67.4443669617176, 72.77141511440277, 67.5788189470768, 34.274461045861244, 0.4112463811179623, 16.756414957344532, 70.52033230662346, 70.58760389685631, 49.28509958088398, 56.10166780650616, 37.22074694931507, 25.456141233444214, 54.45348344743252, 65.20256325602531, 65.63343733549118, 35.59751585125923, 47.075278759002686, 32.90475234389305, 42.62918673455715, 38.85873645544052, 0.9403386886697263, 0.01725290927424794, 0.0561422471946571, 0.08266710239695385, 0.20164041052339599, 0.023393006849801168, 0.07802349180565216, 0.0341420548647875, 0.20221744518494233, 0.2529184066224843, 0.2103870958671905, 0.24660142371430993, 0.45564895786810666, 1.657880845014006, 13.225536122918129, 100.57788982987404, 81.03125229477882, 73.93481388688087, 44.44595284759998, 72.79875844717026, 84.59875926375389, 67.73410901427269, 96.14153668284416, 91.86097517609596, 75.52625969052315, 63.03995870053768, 43.63054320216179, 53.16678509116173, 71.96259811520576, 77.214075922966, 88.56903702020645, 7.006420288234949, 0.5027476977556944, 3.338612476363778, 22.76955809444189, 30.373641662299633, 17.92327344417572, 5.734419543296099, 17.989986464381218, 24.140809513628483, 16.30197264254093, 31.517498083412647, 32.163567915558815, 29.40468605607748, 44.126811772584915, 48.55614669620991, 56.86688594520092, 59.68624725937843, 51.45156092941761, 42.40069359540939, 39.858280420303345, 41.64129674434662, 54.872722551226616, 58.84626433253288, 62.14658863842487, 64.51821237802505, 63.2899434864521, 58.260597959160805, 59.97052140533924, 64.35957849025726, 63.567180410027504, 62.06210017204285, 65.61531990766525, 62.97078341245651, 67.95331925153732, 65.68554773926735, 60.669668689370155, 47.31618583202362, 34.951379522681236, 20.850461572408676, 8.38209182024002, 5.7289093639701605, 3.1318869441747665, 5.969819286838174, 2.704680855385959, 4.16211711242795, 5.369706563651562, 11.06518579646945, 16.02818213403225, 22.56815940141678, 42.29178003966808, 48.34182679653168, 48.83609287440777, 48.6575860530138, 48.23871932923794, 50.24650499224663, 50.62628701329231, 54.045867919921875, 45.5144327133894, 45.21417662501335, 44.344707280397415, 41.98276162147522, 45.062785148620605, 49.16404187679291, 45.963728204369545, 48.203267231583595, 49.895229041576385, 46.687456369400024, 44.98652704060078, 45.79682596027851, 43.136463314294815, 47.935970574617386, 44.27904300391674, 43.61619137227535, 41.843514293432236, 46.09393581748009, 42.892645597457886, 41.5120542794466, 45.77233247458935, 45.48804312944412, 45.97469061613083, 45.94624534249306, 22.149668857455254, 6.038467353209853, 4.150079358369112, 4.06250118277967, 2.162431664764881, 5.494145136326551, 7.186753386631608, 9.890155848115683, 2.1965405344963074, 0.3491952654439956, 0.6951303652022034, 0.3566951130051166, 0.35518368473276496, 1.2041588290594518, 2.4290429335087538, 1.4936879742890596, 3.4633374586701393, 26.146188005805016, 36.92744828760624, 40.52581340074539, 47.51175373792648, 46.29234217107296, 48.68471659719944, 60.60047060251236, 56.29999816417694, 59.930220767855644, 56.36100009083748, 56.05005517601967, 52.5192466378212, 46.51322811841965, 42.90041998028755, 44.9420428276062, 43.87026093900204, 48.29338699579239, 49.38367389142513, 49.61014173924923, 49.69125218689442, 49.76319372653961, 50.24770952761173, 50.97261182963848, 56.87016896903515, 58.61611448228359, 61.50708295404911, 69.23482328653336, 70.39651975035667, 75.300954580307, 73.84220525622368, 42.60859563946724, 1.070920166093856, 14.314709678292274, 77.94669181108475, 75.98158925771713, 58.15544620156288, 65.57578682899475, 39.44708168506622, 41.90511278808117, 68.88776510953903, 76.23071148991585, 79.25491601228714, 44.87475983798504, 49.34541754424572, 51.56924061477184, 57.97101549804211, 73.9017404615879, 2.5303675839677453, 0.21811032987898216, 0.2198002891964279, 0.2278122928692028, 0.31445515458472073, 0.1285196575918235, 0.17946208419743925, 0.17009301896905527], [0.019793700084846932, 0.07361523850704543, 0.03462569395196624, 0.030002401508681942, 0.13133066066075116, 0.0966054224409163, 1.1538101057521999, 38.99209409952164, 64.71224516630173, 64.54865634441376, 42.436195090413094, 31.42106495797634, 64.54664245247841, 65.51394134759903, 87.37187325954437, 84.81302216649055, 49.71300981938839, 60.13093739748001, 27.050750367343426, 33.51308070123196, 44.63403895497322, 59.16440986096859, 78.59586417675018, 20.501127317547798, 0.46406230016145855, 2.715205578133464, 21.567236110568047, 23.547955825924873, 13.809829819947481, 6.305237263441086, 20.922767892479897, 17.303274013102055, 12.528930902481079, 13.883213382214308, 18.399433493614197, 23.266119249165058, 27.429994717240334, 36.187327802181244, 40.84881506860256, 34.86486576497555, 25.945718362927437, 19.61082749068737, 20.75130969285965, 26.907992027699947, 45.0716158747673, 51.07316203415394, 51.88162565231323, 51.42535373568535, 47.97480829060078, 44.49505001306534, 50.42061164975166, 54.131405130028725, 54.422575905919075, 53.000072836875916, 55.04023276269436, 56.08607344329357, 55.64855732023716, 49.49917249381542, 44.00284722447395, 33.520323112607, 28.06837186217308, 35.089654102921486, 21.042364574968815, 5.179527243599296, 1.5376567211933434, 3.211071132682264, 2.6445334078744054, 2.2206310043111444, 3.471235097385943, 6.189476000145078, 7.415130157023668, 13.751490600407124, 23.29943586140871, 43.21243643760681, 44.928960129618645, 47.75730416178703, 44.43858504295349, 43.084162920713425, 41.095387637615204, 43.096918836236, 39.57693211734295, 41.61010801792145, 40.226739048957825, 37.37708196043968, 36.48925580084324, 41.66412591934204, 41.13988324999809, 38.89529049396515, 36.8014432489872, 41.508319079875946, 39.47968013584614, 38.276269510388374, 37.171281203627586, 40.26235073804855, 38.52435439825058, 36.94506414234638, 33.74166123569012, 34.26154933869839, 34.82028275728226, 35.86275301873684, 38.089235946536064, 37.59451389312744, 37.067485973238945, 24.885199069976807, 6.669860947877169, 1.299365689046681, 3.6841376731172204, 2.722027162089944, 1.8018506071530282, 1.5005785482935607, 5.504000382497907, 3.163886214606464, 1.896664306987077, 0.07615676033310592, 0.21705009770812467, 1.9855224201455712, 3.2006917521357536, 4.653719533234835, 4.056637147441506, 3.327763583511114, 11.119810715317726, 36.510861441493034, 50.65021812915802, 50.10516777634621, 54.185882806777954, 59.919262155890465, 60.36532782018185, 56.6488042473793, 53.66512835025787, 46.08379416167736, 42.52837434411049, 34.12988640367985, 29.17022153735161, 29.34007052332163, 26.367647722363472, 25.301780216395855, 25.620186030864716, 26.05533678084612, 28.653878644108772, 31.454869844019413, 36.081845462322235, 39.10334452986717, 43.143101558089256, 43.92414964735508, 49.000175669789314, 51.38104431331158, 60.382263511419296, 62.80435614287853, 69.41758587956429, 65.5628751218319, 66.97614848613739, 19.7727520018816, 0.5931814794894308, 26.243208199739456, 63.50204050540924, 54.71188858151436, 41.66973061859608, 36.508015394210815, 21.136848405003548, 43.18925388157368, 39.69015844166279, 43.65643121302128, 76.34610369801521, 30.07927715778351, 38.62903118133545, 43.673218712210655, 42.984357476234436, 18.50023828446865, 0.35348784760572016, 0.10865332907997072, 0.12702788138994947, 0.10851717466721311, 0.051172080493415706, 0.03022475451871287, 0.0247478493838571, 0.08218185656005517, 0.027766267885454, 0.0732993804558646, 0.04567028001474682, 0.1018463728541974, 0.013108971870678943, 0.21083226572955027, 1.2881707772612572, 52.35082067549229, 69.13817167282104, 40.57840637862682, 21.74436930567026, 42.05030679702759, 73.91163513064384, 72.31518879532814, 97.86896198987961, 89.16629657149315, 56.02879911661148, 58.7061582505703, 32.31735326349735, 46.25475838780403, 50.822120904922485, 64.24088045954704, 81.85154467821121, 33.8727618008852, 0.5624666588846594, 3.4109843429178, 25.332332476973534, 33.50072756409645, 17.951312139630318, 8.936278782784939, 25.273705422878265, 22.992549128830433, 12.445760015398264, 26.193765252828598, 38.68578113615513, 46.161815375089645, 43.26567158102989, 45.14998286962509, 46.90012715756893, 42.0547791570425, 35.959879606962204, 32.21765421330929, 33.64040046930313, 38.791981637477875, 50.16950972378254, 54.343958124518394, 56.42791070044041, 55.019881054759026, 52.349566742777824, 49.06267091631889, 53.722155690193176, 57.36898720264435, 61.68874740600586, 60.703695863485336, 61.66841469705105, 61.66765093803406, 62.90996387600899, 61.167320385575294, 56.67649336159229, 48.10440793633461, 44.30185317993164, 48.6929127573967, 34.87585477530956, 8.967697396874428, 3.612438370473683, 4.6761829778552055, 2.842947361059487, 2.5212214747443795, 4.390045506879687, 6.242199596017599, 7.466064523905516, 12.185115851461887, 22.301869690418243, 39.51830506324768, 45.89386895298958, 48.29299181699753, 47.97701217234135, 43.74165304005146, 45.41216120123863, 44.94477868080139, 43.01232397556305, 42.88694590330124, 41.737241595983505, 40.85747480392456, 40.48421323299408, 46.5841893106699, 43.91871213912964, 42.740315571427345, 42.104191705584526, 43.6008819937706, 41.56242057681084, 42.5563408434391, 41.76663301885128, 43.23311872780323, 41.131656691432, 38.13647881150246, 38.11733923852444, 37.602105885744095, 38.01290564239025, 40.2353759855032, 41.24074503779411, 39.8445213586092, 36.11599802970886, 20.086273178458214, 5.085616707801819, 2.4396590888500214, 2.926213718019426, 2.639010166749358, 1.4998076646588743, 0.43316538620274514, 2.3384956922382116, 2.2439071303233504, 1.2663693283684552, 0.9403462882619351, 0.6776193610858172, 5.193504318594933, 8.88565219938755, 12.335201147943735, 10.868004877120256, 16.946549154818058, 32.06860341131687, 47.07406282424927, 55.464316606521606, 59.092563316226006, 60.429624170064926, 63.44004303216934, 61.91946342587471, 60.859559699893, 59.39965903759003, 51.08902618288994, 48.195789232850075, 41.05352148413658, 40.12508310377598, 39.48439188301563, 38.7065090239048, 40.24799130856991, 38.81079062819481, 39.86280217766762, 39.92491364479065, 42.99555167555809, 47.538424506783485, 49.12336885929108, 54.68115583062172, 54.27868902683258, 58.86256165802479, 59.0783216804266, 65.4161573946476, 67.27459207177162, 71.77196994423866, 67.39643633365631, 69.77815613150597, 14.430999588221312, 1.2668351596221328, 34.74328748881817, 70.31296223402023, 60.170147493481636, 45.573120564222336, 45.37616193294525, 17.879790477454662, 25.188861675560474, 45.584318563342094, 45.092963129282, 73.57533037662506, 27.248991429805756, 48.040278777480125, 43.84878449141979, 57.16980569064617, 25.215471647679806, 0.4711449419846758, 0.31958954001311213, 0.1743393504875712, 0.10846345801837742, 0.08858822373440489, 0.12137379962950945, 0.0267448574595619, 0.05966859156615101, 0.12084141999366693, 0.27315039129462093, 0.2356729281018488, 0.2165771121508442, 0.4181114846142009, 0.19663541112095118, 1.7786557017825544, 55.30456177890301, 85.93510195612907, 86.21164351701736, 58.64420257508755, 37.588453218340874, 82.4419341981411, 79.02085617184639, 90.65248802304268, 87.33177781105042, 58.98496448993683, 76.41511559486389, 36.6725617647171, 46.59466154873371, 65.13642400503159, 69.46361660957336, 93.15869674086571, 31.589791104197502, 0.832071335753426, 3.427719594910741, 28.90092048794031, 42.49071076512337, 21.299405582249165, 10.270733926445246, 27.34702616930008, 29.275270700454712, 21.20120745152235, 37.973239570856094, 46.62781096994877, 52.637135311961174, 47.70712785422802, 50.02433471381664, 51.44471749663353, 48.397923186421394, 45.91216117143631, 41.1940873414278, 42.16468445956707, 46.27080112695694, 56.233235746622086, 54.76640425622463, 55.35333216190338, 54.61834140121937, 53.73864680528641, 53.232776150107384, 57.15490289032459, 61.58151336014271, 60.94920828938484, 61.340857073664665, 61.58155515789986, 64.39859479665756, 66.63343727588654, 64.05247896909714, 63.38547796010971, 59.40858095884323, 52.0388650149107, 50.186380818486214, 36.18429936468601, 10.186193212866783, 5.325908213853836, 8.05483153089881, 5.4328681994229555, 3.2899660617113113, 5.366389341652393, 7.928050383925438, 10.685912948101759, 16.382659412920475, 24.99568574130535, 44.32161591947079, 44.60390277206898, 50.52237778902054, 47.48227871954441, 45.37756405770779, 47.27692633867264, 48.00332196056843, 45.42246624827385, 47.16783419251442, 44.466547742486, 43.94456975162029, 41.779191344976425, 50.18969044089317, 47.13773600757122, 47.52260975539684, 44.651715606451035, 50.033777207136154, 46.76939137279987, 44.56279277801514, 45.04687920212746, 49.06803622841835, 45.58851733803749, 43.52023132145405, 41.74739085137844, 43.3770702034235, 41.85689337551594, 43.90035152435303, 47.63454794883728, 46.43793135881424, 40.4242904484272, 27.87729911506176, 8.513144887983799, 3.4780020592734218, 5.45941642485559, 5.29853068292141, 3.7686280393972993, 3.4137779055163264, 9.131284318864346, 6.80430818349123, 4.301674598827958, 1.4182579843327403, 0.2918045106343925, 3.223710204474628, 5.135990604758263, 7.894726172089577, 8.836657628417015, 15.289411526173353, 34.82516549527645, 52.39475391805172, 57.400506511330605, 61.049188524484634, 61.729827001690865, 62.72403225302696, 63.95994633436203, 63.422054797410965, 61.202282309532166, 55.69209158420563, 55.81509858369827, 50.55040888488293, 46.9069591909647, 47.15691737830639, 49.06482920050621, 47.553798481822014, 46.7282547801733, 46.84534929692745, 49.790024086833, 48.20393979549408, 53.46245102584362, 54.57745559513569, 59.31966952979565, 57.98613868653774, 63.36863726377487, 62.98939101397991, 72.7218733727932, 72.87011101841927, 78.19093510508537, 72.13105827569962, 79.71911430358887, 25.05630198866129, 1.2265789322555065, 33.335109651088715, 81.97736352682114, 66.94617569446564, 59.44121740758419, 48.4371180832386, 31.9343414157629, 57.678978368639946, 56.21024698019028, 53.59202407300472, 90.671965777874, 39.31625470519066, 61.4808339625597, 66.96302399039268, 78.84278252720833, 51.598578840494156, 0.6282160745467991, 0.4728321701986715, 0.5729306442663074, 0.23029605334158987, 0.18309761333512142, 0.20055559842148796, 0.18606696103233844, 0.18160521372919902], [0.021166458063817117, 0.07014340488240123, 0.10958616418065503, 0.10401075749541633, 0.15988137864042073, 0.0378160866239341, 0.4407089907908812, 1.5550293889828026, 70.3607864677906, 65.72145581245422, 64.88224044442177, 34.459625110030174, 48.913703709840775, 34.29953970015049, 38.36162433028221, 62.84701265394688, 55.84528036415577, 73.17178443074226, 44.83042761683464, 23.138972371816635, 38.115880116820335, 45.140905156731606, 71.93546757102013, 55.13202823698521, 2.350953798741102, 4.1220929101109505, 13.99390334263444, 22.020948864519596, 23.227568417787552, 19.93592854589224, 31.301386579871178, 21.83197930455208, 14.545375350862741, 21.142914779484272, 40.34748896956444, 44.79238025844097, 47.523700296878815, 42.371366769075394, 37.21300296485424, 33.17353472113609, 26.366494484245777, 23.651536367833614, 21.841822676360607, 25.882725343108177, 33.120945543050766, 38.700725734233856, 42.24612548947334, 40.645130798220634, 39.30194467306137, 39.61371034383774, 44.85138349235058, 50.646482929587364, 55.05138136446476, 55.73833130300045, 54.850049167871475, 56.341780722141266, 56.73460364341736, 54.916944578289986, 52.68481895327568, 45.49915753304958, 47.60351501405239, 53.38270850479603, 52.98592619597912, 27.344725392758846, 6.340939197689295, 4.6602048352360725, 5.431627565994859, 3.3837984642013907, 3.8447904400527477, 5.244860937818885, 5.622813357040286, 5.272300215438008, 15.143785290420055, 30.846923366189003, 45.7939837127924, 45.86526408791542, 47.234235629439354, 42.78794601559639, 45.18803022801876, 42.69968435168266, 39.60781306028366, 37.13617488741875, 40.116985738277435, 39.19536039233208, 38.63485626876354, 39.40525732934475, 38.27229492366314, 36.112680807709694, 39.71410095691681, 40.37501469254494, 40.39742209017277, 42.312241941690445, 40.5221313983202, 41.955281496047974, 39.03527498245239, 35.878655165433884, 36.23198680579662, 35.06312012672424, 34.33695249259472, 36.062071323394775, 34.559742137789726, 38.345695585012436, 28.463305570185184, 9.12041500210762, 2.240547160618007, 3.18845403380692, 4.3466599099338055, 3.3527907030656934, 2.550221043638885, 1.1691399081610143, 3.0078948475420475, 3.0793352890759706, 1.7634180444292724, 0.8760529663413763, 7.795405201613903, 14.068737477064133, 33.2445415109396, 31.603077091276646, 24.090832695364952, 27.33798075467348, 38.879019767045975, 46.41430802643299, 49.63151179254055, 49.737085327506065, 51.77080079913139, 54.429658725857735, 52.09067143499851, 54.325008541345596, 51.46082103252411, 44.02486324310303, 38.996372669935226, 31.422696970403194, 30.912553444504738, 28.96015550941229, 31.869319304823875, 30.927285254001617, 31.723281741142273, 34.7650071233511, 34.685230404138565, 39.065984934568405, 44.19275723397732, 46.82650990784168, 51.3262702524662, 53.38358245790005, 56.20259419083595, 60.03433138132095, 62.8249966353178, 68.69169563055038, 66.81267365813255, 74.08436626195908, 47.08379790186882, 2.7467011380940676, 3.5161686362698674, 33.30936603248119, 62.38199360668659, 41.1287422478199, 43.02562706172466, 39.85258832573891, 44.58850599825382, 39.68265004456043, 31.43238265067339, 31.683666966855526, 55.24196773767471, 45.09256795048714, 28.147740103304386, 30.592354126274586, 58.679187297821045, 7.79067350551486, 0.392759126261808, 0.15123835648410022, 0.1355349420919083, 0.08781472773989663, 0.007542524763266556, 0.08658929349621758, 0.053218307803035714, 0.08249183680163696, 0.07345790319959633, 0.149184254987631, 0.10264445620123297, 0.12626039679162204, 0.06524141557747498, 0.11756111241993494, 0.3578858741093427, 2.2760073328390718, 83.45683693885803, 61.0463310778141, 44.53534685075283, 24.115597866475582, 61.330833211541176, 41.54433734714985, 47.91620783507824, 66.17816090583801, 55.67803233861923, 78.28921303153038, 34.7803620994091, 31.780523769557476, 43.02841991186142, 51.4938298612833, 78.17474037408829, 72.25783467292786, 6.4364879205822945, 4.247904159128666, 18.32056302577257, 26.243669874966145, 26.568772830069065, 26.735017709434032, 39.42036151885986, 25.694302953779697, 23.696565851569176, 46.5581227093935, 57.202153354883194, 55.30587650835514, 55.48425413668156, 52.11766138672829, 49.15205352008343, 43.78642983734608, 38.01815316081047, 33.204157277941704, 31.89605087041855, 36.69933132827282, 40.990805849432945, 43.600680604577065, 45.500411465764046, 46.22104659676552, 46.152099296450615, 47.27191060781479, 53.33022192120552, 57.80655272305012, 57.555032819509506, 62.28101022541523, 59.36999782919884, 63.01822766661644, 61.780660673975945, 62.421123906970024, 60.965349823236465, 59.184780567884445, 58.0758860707283, 61.54234126210213, 59.83198083937168, 41.56935900449753, 8.872370012104511, 6.273809624835849, 5.336150089278817, 5.111806802451611, 6.003648871555924, 7.3069955594837666, 5.493101142346859, 4.454864803701639, 14.142991192638874, 29.93739277124405, 45.865841656923294, 45.888686031103134, 49.771952256560326, 44.710232466459274, 48.191320672631264, 45.93800738453865, 42.849939689040184, 40.54138496518135, 42.65757501125336, 42.74390637874603, 39.97685685753822, 39.926840141415596, 40.32437480986118, 37.77880020439625, 40.727024003863335, 42.216661870479584, 44.37527284026146, 44.38565008342266, 42.73897424340248, 43.22138875722885, 41.75266496837139, 39.03566636145115, 38.19618880748749, 36.91477216780186, 36.97247587144375, 38.65228213369846, 36.75003960728645, 39.371758326888084, 27.12874498218298, 7.513342062011361, 2.6518252165988088, 3.6093370243906975, 2.7804568642750382, 2.600158676505089, 2.4217632366344333, 2.02332706656307, 0.6225828174501657, 1.6249373252503574, 2.3248461121693254, 4.25711533986032, 11.835489962249994, 27.569777816534042, 46.90948225557804, 48.24003405869007, 45.53580276668072, 45.362171083688736, 48.71989130973816, 49.51584979891777, 51.61150574684143, 50.54754763841629, 55.02120718359947, 55.995600298047066, 58.19691717624664, 56.819099709391594, 57.139426320791245, 50.49792990088463, 49.04567442834377, 42.74701841175556, 41.47534444928169, 40.819438844919205, 44.43830765783787, 43.54238033294678, 44.58626791834831, 42.84063778817654, 45.507057309150696, 47.30945259332657, 55.435761138796806, 56.74789533019066, 58.91022630035877, 60.375754460692406, 64.63371858000755, 65.69488763809204, 68.93032282590866, 69.14029195904732, 71.67608588933945, 75.7922226190567, 32.863680347800255, 1.093363305553794, 6.0599917732179165, 41.27727247774601, 70.51152437925339, 44.94468368589878, 51.19939886033535, 53.541448786854744, 39.11755956709385, 37.24549122154713, 38.779829889535904, 31.271079406142235, 60.5895271897316, 35.46639248728752, 34.237941205501556, 33.66757661104202, 71.91018372774124, 5.35906950943172, 0.20711293327622116, 0.03548872635292355, 0.05802114617836196, 0.12900154892122373, 0.0504434547474375, 0.09158486020169221, 0.01149627662016428, 0.07513247037422843, 0.13914863724494353, 0.2525381895247847, 0.22325574362184852, 0.2993575850268826, 0.1593706029234454, 0.2371781668625772, 0.42155448580160737, 2.0304716331884265, 93.61113086342812, 87.82366901636124, 92.63553321361542, 55.4354153573513, 58.67152690887451, 51.88954822719097, 48.052977696061134, 81.33100301027298, 61.19095131754875, 95.03993779420853, 53.44604350626469, 32.43234269320965, 52.99650102853775, 59.260233119130135, 84.15503427386284, 74.15062710642815, 4.051561094820499, 4.575472231954336, 22.218329273164272, 32.38254256546497, 32.69347608089447, 32.77378477156162, 46.23699814081192, 33.08642439544201, 34.466502740979195, 53.82548354566097, 62.19894602894783, 61.288788467645645, 61.0136566311121, 57.50144809484482, 53.02242323756218, 49.94982451200485, 45.314742028713226, 43.32663930952549, 40.74201799929142, 45.60881964862347, 47.101390957832336, 49.64174844324589, 51.82869829237461, 51.490634232759476, 49.763634502887726, 50.397512689232826, 55.06893642246723, 58.46520557999611, 58.45779597759247, 61.89280405640602, 58.85257199406624, 63.320695236325264, 65.01370579004288, 65.46170935034752, 64.54469695687294, 60.87727814912796, 60.86703769862652, 62.704235315322876, 60.112231001257896, 46.0550183057785, 9.424609579145908, 7.091245511546731, 8.977446723729372, 6.321271928027272, 5.842608287930489, 8.296775948256254, 7.932420149445534, 8.178384751081467, 18.552937656641006, 33.86850222945213, 46.26246437430382, 47.19228208065033, 49.81099896132946, 47.71183580160141, 52.0840597897768, 49.024923741817474, 46.47343285381794, 43.788937702775, 48.12702052295208, 47.09985204041004, 44.51925091445446, 45.31707510352135, 45.85636116564274, 43.69718782603741, 46.91064119338989, 46.62360459566116, 49.06483680009842, 50.70474900305271, 47.120804116129875, 45.38414150476456, 45.67199885845184, 44.26119156181812, 41.474291905760765, 41.45109795033932, 42.222794741392136, 43.80695253610611, 39.545990377664566, 43.634278401732445, 31.986064240336418, 12.692001052200794, 5.358531838282943, 5.669075874611735, 7.158770738169551, 7.543302029371262, 6.975000724196434, 4.336722493171692, 5.139592811465263, 4.704823940992355, 3.3341320417821407, 2.448282251134515, 9.916022960096598, 22.384541854262352, 40.14236457645893, 49.13955219089985, 49.466737434268, 47.62321315705776, 52.12651111185551, 53.093259036540985, 55.60954861342907, 54.928366765379906, 56.42727233469486, 58.201549127697945, 59.567739218473434, 60.26695489883423, 59.97428700327873, 55.30246429145336, 53.750889748334885, 45.75119040906429, 47.09382176399231, 47.55436845123768, 50.745011642575264, 52.24795639514923, 50.75408935546875, 50.38281887769699, 50.055386647582054, 51.61057859659195, 58.78148540854454, 61.2727153301239, 63.74092988669872, 65.21909236907959, 67.94119030237198, 69.87878233194351, 72.35577821731567, 74.78112727403641, 73.67741569876671, 78.26442316174507, 56.68744057416916, 3.606247315183282, 4.576554698869586, 47.93076105415821, 78.16603124141693, 55.07221944630146, 58.19552265107632, 51.419399455189705, 57.21811629831791, 48.77520494163036, 46.167404875159264, 40.38663446903229, 70.05315497517586, 54.247823283076286, 46.01654917001724, 47.70662248134613, 95.15815705060959, 16.533374525606632, 0.8767659030854702, 0.3594401094596833, 0.2731058921199292, 0.31160174519754946, 0.1396433825721033, 0.2025971279363148, 0.16904292453546077, 0.2071163768414408], [0.06866902462206781, 0.04901766289549414, 0.19782461371505633, 0.0862647671601735, 0.02883237972127972, 0.15937554562697187, 0.10784879646962509, 1.3481101859360933, 12.583192940801382, 72.3191025853157, 52.06041365861893, 64.03225645422935, 36.35823883116245, 69.46528851985931, 125.75362130999565, 121.22420355677605, 104.46202620863914, 77.32528075575829, 57.286208644509315, 19.736640639603138, 33.41714344918728, 40.04861980676651, 60.80001689493656, 69.9299655854702, 22.286244928836823, 1.8656399217434227, 15.373228378593922, 18.157492876052856, 24.20012053102255, 30.14034368097782, 29.20400932431221, 23.331097662448883, 22.75428481400013, 44.97068949043751, 59.433545619249344, 53.0316187441349, 54.33968335390091, 46.71900227665901, 47.13949911296368, 39.48378771543503, 34.933661073446274, 25.710583180189133, 24.064057432115078, 25.712644569575787, 32.844179794192314, 32.72138938307762, 35.33423937857151, 35.057838410139084, 38.5903150588274, 42.022598683834076, 45.78212834894657, 47.21834108233452, 49.66677010059357, 55.38753792643547, 58.25382672250271, 59.697791039943695, 56.12756721675396, 56.557008773088455, 54.293664023280144, 56.320015490055084, 54.74316090345383, 57.39404305815697, 56.327014714479446, 55.640874132514, 28.75097293406725, 13.072390090674162, 4.025736730545759, 6.931014759466052, 9.108349699527025, 8.620695266872644, 5.052570356056094, 3.365237172693014, 5.870677856728435, 20.638989619910717, 37.525391802191734, 41.66987121105194, 46.590865552425385, 44.448483511805534, 40.85702642798424, 39.38021667301655, 38.80488574504852, 38.20430137217045, 37.864455208182335, 37.47985504567623, 35.469481721520424, 35.06821945309639, 35.64723238348961, 34.906435534358025, 33.56852352619171, 38.603979125618935, 42.252292558550835, 42.830697521567345, 40.67968614399433, 39.8599561303854, 40.41856035590172, 38.81403185427189, 38.335618525743484, 36.600825414061546, 37.61021085083485, 37.03375518321991, 36.71464450657368, 34.86951671540737, 15.463409889489412, 3.339165346696973, 1.66913453489542, 2.5482085766270757, 2.350931237451732, 1.5828056610189378, 1.748294262215495, 0.9039163962006569, 2.413739492185414, 9.27172003313899, 12.631295509636402, 17.139016427099705, 28.159789256751537, 52.28407725691795, 63.5978789627552, 53.21207106113434, 52.08135813474655, 51.76656402647495, 50.03340482711792, 50.46941623091698, 51.60214684903622, 51.64343163371086, 52.21481077373028, 50.74454806745052, 57.71082065999508, 53.57809402048588, 50.303973108530045, 43.877556547522545, 40.731861144304276, 33.54333847761154, 35.921326875686646, 32.92800709605217, 34.39655989408493, 33.86219456791878, 36.00143417716026, 36.36339135468006, 43.69533732533455, 47.736348286271095, 51.97972498834133, 53.88216890394688, 55.69899961352348, 58.7896853685379, 61.58340185880661, 65.50187319517136, 67.61193796992302, 71.77073881030083, 78.72695714235306, 54.47100430727005, 4.0058832708746195, 0.09667669830378145, 8.536953460425138, 35.31050205230713, 54.58126299083233, 39.88142877817154, 45.160037130117416, 45.95969662070274, 20.72795994579792, 14.482700563967228, 36.132952719926834, 37.36051484942436, 43.64743709564209, 41.07354260981083, 50.24784252047539, 48.24082441627979, 62.1449851244688, 0.29918855347204953, 0.11924205464310944, 0.0716070833732374, 0.06000835419399664, 0.05615869318717159, 0.15354035014752299, 0.04219983791699633, 0.1473087290651165, 0.008418855522904778, 0.0773288712662179, 0.05199380495469086, 0.17870629584649578, 0.06482095923274755, 0.10940609688987024, 0.18663448136067018, 0.06592927515157498, 1.4408438536338508, 15.313974358141422, 82.40474939346313, 56.303953751921654, 58.66879105567932, 45.4921393096447, 57.204729616642, 107.35123917460442, 117.1940790116787, 97.56551027297974, 87.54844978451729, 49.703084751963615, 24.9396900460124, 42.43999868631363, 44.25334498286247, 65.82290276885033, 77.37744435667992, 32.533329874277115, 3.851340813562274, 24.26976889371872, 30.254586450755596, 33.9501940459013, 39.6679562330246, 32.61525347828865, 30.59454470872879, 46.32712550461292, 57.24517464637756, 64.81664836406708, 60.491492450237274, 60.01002408564091, 54.07861836254597, 55.148834735155106, 46.98681190609932, 46.80004432797432, 37.82931849360466, 36.048943027853966, 35.51127567887306, 40.547597631812096, 40.72599045932293, 42.20016695559025, 41.4288729429245, 45.19556142389774, 45.84921754896641, 52.41461545228958, 52.01324678957462, 53.08360755443573, 58.82970102131367, 60.062940046191216, 59.734801054000854, 60.894654616713524, 59.4088089466095, 60.115514025092125, 61.63126029074192, 62.61237524449825, 63.37374418973923, 61.79054394364357, 58.14081698656082, 41.56826466321945, 22.730689980089664, 12.55895309150219, 6.702426625415683, 11.175706665962934, 9.838797803968191, 7.01684882864356, 4.37585991807282, 5.008697435259819, 19.906415529549122, 32.97898896038532, 41.15138903260231, 47.047255262732506, 49.211227744817734, 45.93438617885113, 44.884833097457886, 44.36119459569454, 43.4600805491209, 40.95653548836708, 42.14290402829647, 42.45829090476036, 41.010553389787674, 39.504287615418434, 39.35250096023083, 38.13671059906483, 42.709119245409966, 45.6741039454937, 44.36644211411476, 47.02991299331188, 42.516682371497154, 44.00293841958046, 39.533599242568016, 40.13751603662968, 38.26661042869091, 40.30365452170372, 37.814598083496094, 38.99880453944206, 32.9936333745718, 13.433586359024048, 3.7882869970053434, 2.673420407809317, 2.8937853081151843, 1.9153293804265559, 2.9666076879948378, 2.544762874022126, 2.3277819296345115, 11.719954311847687, 23.177432008087635, 25.746360160410404, 26.15020629018545, 41.09477587044239, 57.572808265686035, 62.38715372979641, 56.844672337174416, 53.01342152059078, 52.77575187385082, 53.710809499025345, 54.62353952229023, 54.12391573190689, 57.81342655420303, 55.306188091635704, 53.73122200369835, 56.67571820318699, 56.710246950387955, 55.229200422763824, 51.283636540174484, 47.91407994925976, 44.3089359998703, 44.036008045077324, 42.7762084454298, 41.52998551726341, 42.25501321256161, 42.2381991147995, 47.71838665008545, 51.53831027448177, 58.18941257894039, 58.53967398405075, 61.62734270095825, 63.04118603467941, 65.02586513757706, 64.46056187152863, 70.30431389808655, 68.9391079545021, 77.00324803590775, 71.3142617046833, 28.631148263812065, 0.016185116473934613, 0.3654416499193758, 10.940472688525915, 44.33558017015457, 57.77263194322586, 46.518088057637215, 54.92597669363022, 48.49044442176819, 22.400349006056786, 24.226570911705494, 46.36877126991749, 47.56041392683983, 49.67300556600094, 38.45761477947235, 44.447909742593765, 56.84635564684868, 53.74735973775387, 0.43194912490434945, 0.17231962527148426, 0.10567565448582172, 0.11788357558543794, 0.18085384857840836, 0.1388997060712427, 0.05023620629799552, 0.05231811977864709, 0.02875732632674044, 0.12439168378477916, 0.10152261093026027, 0.3155276767211035, 0.3427714726421982, 0.3251801978331059, 0.31337387510575354, 0.2800634375307709, 1.7743288027122617, 18.06082036346197, 95.97062185406685, 69.27217528223991, 87.44318023324013, 47.24984519183636, 86.54284134507179, 130.8537608385086, 128.49457383155823, 108.0603951215744, 92.70302519202232, 70.85941091179848, 28.246257416903973, 45.99204048514366, 55.8491675555706, 70.69405898451805, 86.47001445293427, 29.199538864195347, 4.00885091163218, 32.98062287271023, 33.18629443645477, 43.01537521183491, 44.8161555826664, 41.51498392224312, 34.339042380452156, 53.69860455393791, 63.6759951710701, 69.1093236207962, 64.15659338235855, 62.55480073392391, 59.474226236343384, 59.84242267906666, 52.97256991267204, 52.287447676062584, 42.10758492350578, 40.80548979341984, 42.06222675740719, 49.3731826543808, 44.59015130996704, 44.79097433388233, 43.38356405496597, 48.65692488849163, 50.83029046654701, 56.03844299912453, 54.20575954020023, 53.61669234931469, 61.846579536795616, 61.3747588545084, 61.81624956429005, 59.049823209643364, 60.63352882862091, 61.337992027401924, 63.5676059871912, 62.13199362158775, 63.73702369630337, 61.56648136675358, 58.27935375273228, 40.84040232002735, 20.653833523392677, 13.668387159705162, 10.374178625643253, 10.877167135477066, 10.158745385706425, 7.952630314975977, 4.754086397588253, 9.650139827281237, 24.415990747511387, 39.2067863792181, 40.76819859445095, 47.63857193291187, 48.44238460063934, 46.54228895902634, 46.230261102318764, 45.70226803421974, 46.289629116654396, 44.16778117418289, 43.681209683418274, 41.76958546042442, 41.38007216155529, 43.33868846297264, 41.12843066453934, 40.59624262154102, 47.00817435979843, 48.642094284296036, 47.23339967429638, 50.191381350159645, 47.4313348531723, 48.89608025550842, 45.864127948880196, 46.19860120117664, 41.569689586758614, 42.9360506683588, 40.09075574576855, 43.07338289916515, 38.60093928873539, 20.199243016541004, 6.690230229869485, 3.9150358457118273, 4.643743168562651, 6.220740247517824, 3.259547743946314, 1.7254167585633695, 0.8953983813989908, 6.640840955078602, 15.962392464280128, 19.105505906045437, 21.85899205505848, 36.36996880173683, 56.382271349430084, 71.02190539240837, 59.59119535982609, 60.29073782265186, 55.64021296799183, 57.942528426647186, 58.68617132306099, 58.112280517816544, 58.328469917178154, 58.06551642715931, 56.83861926198006, 62.00648635625839, 59.54290375113487, 58.93606871366501, 55.26398375630379, 53.910568580031395, 48.33974830806255, 50.848343297839165, 50.24423271417618, 49.7390878200531, 48.933778032660484, 50.14106445014477, 50.73561854660511, 56.65397956967354, 63.091901913285255, 63.60455900430679, 65.67626103758812, 67.07660749554634, 69.2541566491127, 68.18012908101082, 75.55586010217667, 74.65671434998512, 77.65684336423874, 83.72250348329544, 62.54110246896744, 5.711287809535861, 0.4148026934126392, 12.228526622056961, 50.82149013876915, 66.4990384876728, 56.79910518229008, 56.45554281771183, 56.96835570037365, 31.041195541620255, 19.972393289208412, 51.356474831700325, 46.64733052253723, 59.80127468705177, 59.10973459482193, 77.96752989292145, 63.15896451473236, 88.31935241818428, 0.4347505245823413, 0.24345010140677914, 0.2612632041564211, 0.23963415616890416, 0.2527493453817442, 0.28128833742812276, 0.1285555330105126, 0.15351464215200394, 0.19460259441984817], [0.042277099200873636, 0.037237304204609245, 0.09174434773740359, 0.07770435346174054, 0.1233825930103194, 0.07452473306329921, 0.001930515818457934, 0.05950268074229825, 1.0630138590931892, 28.08414861559868, 75.54977282881737, 62.30618767440319, 40.05481347441673, 89.77064654231071, 132.36653566360474, 87.66865253448486, 73.93650099635124, 77.5636799633503, 57.52873823046684, 26.970494873821735, 29.35715440660715, 40.63078656792641, 54.081608802080154, 71.82692259550095, 49.773133993148804, 7.777230301871896, 16.475220546126366, 32.90401518344879, 27.8234826028347, 29.164823926985264, 24.708694741129875, 33.263874873518944, 43.92232194542885, 58.37839163839817, 59.851166009902954, 57.64427863061428, 54.34831649065018, 50.773095935583115, 44.34785731136799, 42.56746284663677, 39.548973217606544, 36.291362419724464, 32.539907321333885, 29.8929750546813, 30.569507852196693, 32.06910878419876, 33.46435971558094, 34.241627007722855, 36.85541935265064, 41.40590697526932, 45.22078827023506, 49.857584461569786, 52.534035444259644, 53.05557265877724, 55.87613470852375, 53.030026629567146, 57.39971615374088, 55.23582726716995, 55.204513147473335, 56.307814344763756, 58.31127963960171, 58.79907466471195, 60.531565099954605, 57.01629012823105, 52.948775589466095, 41.96304067969322, 24.71628673374653, 10.33553659915924, 20.190685875713825, 13.369768783450127, 10.299790017306805, 3.8599573262035847, 4.651860008016229, 11.023239847272635, 24.143119789659977, 36.1531638354063, 46.575696766376495, 48.999704495072365, 49.711307510733604, 43.530065193772316, 41.35330639779568, 40.490631088614464, 41.00732356309891, 38.91286835074425, 38.96322324872017, 39.65192489326, 38.94289433956146, 40.33115744590759, 39.72484678030014, 42.778560519218445, 45.311911180615425, 45.413483530282974, 45.3286112844944, 43.69771599769592, 42.8023586422205, 41.311010867357254, 38.9202855527401, 42.47021846473217, 43.73455502092838, 39.4751887768507, 36.22182995080948, 17.794547751545906, 5.171864004805684, 0.7670366379898041, 2.6814410649240017, 2.615782250650227, 1.93252393277362, 3.437030757777393, 7.55362275056541, 19.426565878093243, 39.11198526620865, 48.09252217411995, 44.51344482600689, 42.95003391802311, 61.97117105126381, 55.03168322145939, 54.15011152625084, 52.3661794513464, 50.00927612185478, 49.430909156799316, 52.42244303226471, 50.96882343292236, 48.30503337085247, 49.696533903479576, 50.54534375667572, 48.97807225584984, 49.52389016747475, 52.50091262161732, 48.15228916704655, 47.30938419699669, 43.58577400445938, 40.69156050682068, 37.43633598089218, 35.95546804368496, 35.10370574891567, 37.10323445498943, 36.77283078432083, 45.00245198607445, 48.1488199532032, 54.368440210819244, 53.93778271973133, 59.617733135819435, 57.87118725478649, 63.26226957142353, 58.511832877993584, 66.61371633410454, 61.64072938263416, 71.95621445775032, 26.75241317600012, 0.8292357379104942, 0.15375043731182814, 0.3988498728722334, 8.12922203913331, 37.43322014808655, 44.00605045258999, 42.516184598207474, 38.984657898545265, 46.75966389477253, 17.293818220496178, 27.558006048202515, 37.127511352300644, 58.0354068428278, 61.65508881211281, 51.57845892012119, 42.514812871813774, 79.36731398105621, 16.924698427319527, 0.8624849037732929, 0.2996309328591451, 0.15422505559399724, 0.09078150018467568, 0.08957361031207256, 0.07404858595691621, 0.06505665791337378, 0.1770511135691777, 0.007585437133457162, 0.08104903492494486, 0.06846793228760362, 0.01895941106340615, 0.054641164460917935, 0.21063765976577997, 0.03874367102980614, 0.06881758032250218, 0.08416375450906344, 1.3540485547855496, 28.161793649196625, 87.07072421908379, 55.79630859196186, 41.87368467450142, 91.42587572336197, 122.25673735141754, 98.53716373443604, 79.00944158434868, 86.20611101388931, 56.64499305188656, 25.6864582747221, 41.309202164411545, 47.98155292868614, 61.25321477651596, 75.67315980792046, 56.15464076399803, 12.299707252532244, 14.300519339740276, 40.66449075937271, 46.24979965388775, 43.195512145757675, 43.45919519662857, 49.036885499954224, 56.427762508392334, 64.63172748684883, 64.18507665395737, 61.60303920507431, 60.93595840036869, 58.8544262945652, 51.83303005993366, 53.760510832071304, 49.17196445167065, 46.069590523839, 42.07576543092728, 40.93808747828007, 39.323523715138435, 37.85585626959801, 40.10815881192684, 41.27157658338547, 43.28168012201786, 45.363789796829224, 49.52061094343662, 56.10887981951237, 57.78413772583008, 57.467702105641365, 60.13023063540459, 58.89013297855854, 61.39631889760494, 58.259355425834656, 57.12931886315346, 60.737172067165375, 61.11692748963833, 62.40757383406162, 63.64384509623051, 58.90068121254444, 56.36001214385033, 50.02143546938896, 38.49228411912918, 24.84856903553009, 26.8014894425869, 19.36945304274559, 12.9595304466784, 6.907738633453846, 6.8913947604596615, 10.719399601221085, 23.85262157768011, 34.990300834178925, 48.507068529725075, 48.49859498441219, 53.456504344940186, 51.551955342292786, 45.97010426223278, 45.43300308287144, 45.0975950807333, 44.165391102433205, 39.22896198928356, 39.34543713927269, 44.39007304608822, 43.511309400200844, 44.23319086432457, 45.816432908177376, 46.911423951387405, 48.618261963129044, 45.92344656586647, 43.22481997311115, 43.7717018276453, 44.770037457346916, 45.375812351703644, 44.983874782919884, 44.30892460048199, 39.00722108781338, 36.27238243818283, 17.72370435297489, 4.838663684204221, 2.1366372238844633, 3.9607882406562567, 2.3552903160452843, 2.9146454762667418, 5.178563045337796, 10.063757132738829, 28.98811060935259, 48.23965407907963, 51.54540069401264, 50.026025623083115, 53.07709850370884, 63.567472994327545, 57.119610384106636, 58.77118796110153, 54.19154450297356, 53.69296945631504, 54.8490384221077, 55.23070514202118, 52.733794525265694, 51.116867288947105, 51.43593616783619, 51.54185928404331, 55.424046367406845, 54.50329877436161, 57.4229671061039, 54.63508330285549, 53.55338774621487, 53.28623168170452, 49.122149124741554, 45.6795946508646, 43.057039976119995, 42.042270228266716, 44.393439665436745, 47.103507444262505, 53.17275457084179, 56.5019079297781, 62.770176976919174, 62.1764550358057, 66.91005483269691, 62.65603870153427, 67.50188827514648, 63.78119632601738, 68.55206072330475, 62.435145154595375, 60.912585854530334, 15.949794240295887, 1.5320628276094794, 0.06243086521863006, 0.994460015790537, 9.358413331210613, 46.00204534828663, 49.028320759534836, 50.9047968685627, 47.207344472408295, 43.46022114157677, 25.092899724841118, 38.63118566572666, 44.62327793240547, 57.88009397685528, 73.40304762125015, 48.95215384662151, 44.0833231061697, 71.53191402554512, 4.886550614610314, 0.3166742355097085, 0.10856570370378904, 0.14581932773580775, 0.049976098380284384, 0.11210231197765097, 0.11867279026773758, 0.03843665566819254, 0.03744757690583356, 0.032000001447158866, 0.3097629110561684, 0.15930186520563439, 0.17385118058882654, 0.17667675943812355, 0.28981760318856686, 0.19752447435166687, 0.11875654163304716, 0.27769984561018646, 1.3497619098052382, 36.82489559054375, 103.55763673782349, 74.7107170522213, 62.38896243274212, 102.59185016155243, 136.4874905347824, 90.26060745120049, 84.57270786166191, 87.20778286457062, 75.207988768816, 34.245434403419495, 42.198175862431526, 56.637108474969864, 65.73543146252632, 82.21491917967796, 59.38743509352207, 10.45356871560216, 19.758445769548416, 54.81186501681805, 51.99578292667866, 51.5405635535717, 45.74211269617081, 57.326684072613716, 60.61918459832668, 69.49279144406319, 68.63073170185089, 66.53214991092682, 64.67568352818489, 62.693592086434364, 55.139194652438164, 58.87395344674587, 55.05937233567238, 52.04341717064381, 46.99630759656429, 47.18177184462547, 44.47614222764969, 44.319153651595116, 45.63101425766945, 46.073903292417526, 46.851474568247795, 50.742670968174934, 53.84235844016075, 58.5430634021759, 59.57683213055134, 57.26318188011646, 61.26174531877041, 56.605733558535576, 61.656988710165024, 57.62669317424297, 57.80477821826935, 60.50347700715065, 62.94526018202305, 62.7584508061409, 67.13669747114182, 60.883300825953484, 58.02981734275818, 52.58954666554928, 39.73271615803242, 25.637659393250942, 27.50629272311926, 18.52933332324028, 12.609742116183043, 7.44124093092978, 7.278900817036629, 15.700479168444872, 28.55898443609476, 39.576088562607765, 49.80042412877083, 52.82477684319019, 54.30461123585701, 50.555105432868004, 48.23733240365982, 48.10755796730518, 48.18966396152973, 47.09958225488663, 44.63742837309837, 46.91339984536171, 45.54075010120869, 46.55113108456135, 47.73238889873028, 48.81126120686531, 50.03828376531601, 52.103579342365265, 52.75783583521843, 46.375002935528755, 48.7521705776453, 48.39406259357929, 48.27649310231209, 47.772062569856644, 47.95646667480469, 43.25693964958191, 41.42885014414787, 26.763920858502388, 8.061319682747126, 3.2963478192687035, 4.647456519305706, 5.084906620904803, 4.127159463241696, 3.1602878076955676, 7.176242675632238, 21.85690976679325, 46.32902920246124, 55.78979194164276, 54.49791066348553, 50.345854461193085, 67.08698853850365, 62.50952236354351, 62.04544186592102, 57.05165483057499, 54.684830233454704, 57.30897322297096, 59.71787676215172, 55.72749428451061, 54.24591578543186, 55.81693008542061, 54.12356615066528, 57.01645351946354, 56.03978432714939, 60.57319186627865, 55.78594274818897, 57.22418837249279, 57.43679456412792, 53.39964799582958, 51.461273208260536, 49.212284088134766, 47.1744230389595, 50.00332184135914, 48.652855306863785, 58.743217661976814, 59.62903752923012, 68.22763413190842, 66.51698112487793, 70.08945062756538, 66.58077970147133, 72.41016089916229, 65.64774736762047, 74.05890002846718, 64.83826920390129, 76.80973961949348, 32.69227534532547, 2.1950609888881445, 0.24193295859731734, 2.0595823461189866, 12.755653336644173, 52.571330443024635, 59.26225081086159, 57.832490131258965, 49.53818120062351, 61.38311840593815, 25.092339254915714, 40.69215327501297, 54.340960085392, 71.02492243051529, 77.86849200725555, 76.07299715280533, 56.77989721298218, 106.79478943347931, 22.554187551140785, 1.1333626904524863, 0.387212997302413, 0.5308005830738693, 0.20115491235628724, 0.1851929782424122, 0.3800074855098501, 0.09361846357933246, 0.49854126409627497, 0.10620606743032113], [0.07805965666193515, 0.06690554815577343, 0.00770757701502589, 0.04973356451955624, 0.10837075635208748, 0.06123045248386916, 0.1070188675657846, 0.06778850351111032, 0.009614075079298345, 0.9529418405145407, 26.76910948008299, 62.03511781990528, 48.10443073511124, 50.569058284163475, 101.79138511419296, 109.41772028803825, 92.35361874103546, 85.63077628612518, 55.42120411992073, 28.02293960005045, 25.057466626167297, 48.3579683303833, 48.17326784133911, 63.38045842945576, 58.38168606162071, 24.18925691395998, 6.050788192078471, 19.589299745857716, 38.47294695675373, 43.422960340976715, 42.77444913983345, 49.54022169113159, 54.544009789824486, 57.27283716201782, 56.78138293325901, 57.940905913710594, 53.01070086658001, 55.38939982652664, 51.84662953019142, 47.71589018404484, 44.686118960380554, 43.9173936098814, 40.9213911741972, 41.04883253574371, 38.86614605784416, 36.39075368642807, 35.9253166615963, 35.90813398361206, 38.084315210580826, 39.898231476545334, 44.844030886888504, 48.422827050089836, 50.40902987122536, 51.73229746520519, 56.152216494083405, 58.46792623400688, 59.18899454176426, 57.43434749543667, 53.277830332517624, 55.255156829953194, 56.30437172949314, 57.38188751041889, 59.74586986005306, 57.778586223721504, 55.08495256304741, 47.84183442592621, 46.424875259399414, 38.23587387800217, 29.785017147660255, 30.635502710938454, 17.37119346857071, 7.646284578368068, 5.717219291254878, 7.9340569116175175, 15.00270551070571, 24.636888094246387, 35.204328149557114, 42.28560917079449, 50.39233736693859, 51.31150424480438, 43.82424920797348, 40.6087401509285, 40.28129272162914, 37.640875205397606, 27.399406358599663, 25.601696223020554, 46.03925675153732, 45.95191463828087, 48.391775116324425, 44.29198130965233, 49.23790231347084, 47.16474875807762, 47.897528037428856, 39.98919099569321, 40.518817976117134, 41.1038763821125, 50.84445610642433, 51.5017182379961, 52.322880774736404, 41.7184554040432, 30.32321836799383, 6.554555185139179, 1.860501291230321, 1.4570670831017196, 2.640333683229983, 0.6258235685527325, 3.9240852976217866, 11.601329427212477, 23.932854272425175, 46.03316567838192, 41.04316703975201, 43.933664336800575, 43.677497282624245, 56.989429369568825, 54.511449337005615, 53.435065895318985, 55.49367003142834, 53.77158343791962, 49.973246455192566, 52.20183826982975, 50.24650499224663, 49.98669773340225, 49.87574748694897, 50.78333258628845, 51.13475292921066, 53.71272459626198, 54.224712923169136, 55.014435946941376, 53.618831634521484, 47.37867347896099, 46.58499486744404, 43.25240649282932, 38.96434798836708, 37.80056543648243, 38.189653158187866, 39.932558834552765, 42.37333886325359, 49.86692056059837, 54.917012974619865, 57.89667248725891, 59.535095170140266, 60.31000658869743, 62.20111571252346, 64.81545522809029, 64.87546160817146, 62.653401643037796, 61.257333755493164, 27.815390937030315, 10.006796289235353, 1.7706971475854516, 0.276389954960905, 0.4470409353962168, 8.527392223477364, 39.772177040576935, 43.17371651530266, 38.27090419828892, 30.916623026132584, 36.77328675985336, 10.231356639415026, 34.99340146780014, 43.50871413946152, 32.66389086842537, 70.4010871052742, 46.81102953851223, 56.624512150883675, 47.586799710989, 0.09968245576601475, 0.14285520475823432, 0.06741318458807655, 0.13495272723957896, 0.02428997580864234, 0.07558838653494604, 0.1117019826779142, 0.03347290854435414, 0.09910255641443655, 0.0953636238409672, 0.04459518633666448, 0.05732805817387998, 0.029079401720082387, 0.012248103757883655, 0.03563284772098996, 0.05074123779195361, 0.14215421659173444, 0.07428505647112615, 0.07353961365879513, 0.6280615297146142, 30.058070495724678, 73.50363582372665, 38.91598038375378, 57.26057901978493, 107.50610366463661, 109.47138100862503, 97.7350115776062, 90.98815441131592, 66.4543604850769, 24.254774898290634, 34.44201685488224, 57.168513759970665, 52.83489190042019, 66.31186813116074, 61.189632788300514, 29.677336625754833, 7.471913360059261, 15.61603344976902, 40.92218153178692, 57.44193568825722, 56.65752857923508, 60.41338004171848, 61.42915293574333, 59.038754403591156, 60.635941699147224, 62.13254079222679, 59.94797341525555, 59.278369545936584, 56.67886063456535, 54.28562745451927, 55.32001934945583, 52.625971511006355, 52.629786506295204, 52.25780926644802, 49.453837126493454, 43.861023634672165, 41.36511616408825, 41.33147656917572, 41.950588747859, 44.25538927316666, 47.235504761338234, 52.464157193899155, 53.97564008831978, 55.64049415290356, 57.59504087269306, 55.50366349518299, 60.07594674825668, 59.64891046285629, 55.72342850267887, 54.14170637726784, 61.634702906012535, 61.520420238375664, 61.22369036078453, 61.52380205690861, 58.74853357672691, 52.63796366751194, 50.0252428650856, 45.061326026916504, 36.09864816069603, 35.099822357296944, 21.10867291688919, 9.96157681569457, 7.289547845721245, 9.104454908519983, 14.446481857448816, 25.558984614908695, 34.640005230903625, 44.07623648643494, 51.31417170166969, 53.29525999724865, 47.45203614234924, 43.07740308344364, 43.81309300661087, 41.81730329990387, 25.705740340054035, 26.197340860962868, 46.877989545464516, 50.73092579841614, 56.78001880645752, 47.96079084277153, 48.40310990810394, 45.24094618856907, 47.57403239607811, 43.65697078406811, 45.92074491083622, 41.1874794960022, 42.26319797337055, 45.16494266688824, 52.47821643948555, 43.84815372526646, 38.53562839329243, 6.624790141358972, 2.8263118537142873, 2.6922493474557996, 3.5535011580213904, 2.183375428430736, 5.264780893921852, 14.071772564202547, 31.930545419454575, 48.43066982924938, 45.58287464082241, 48.080822601914406, 48.48881050944328, 60.15967145562172, 57.59021133184433, 53.463047593832016, 54.17318008840084, 52.709236443042755, 53.61457206308842, 53.32419164478779, 52.473865672945976, 54.58530597388744, 53.49349536001682, 56.15742601454258, 55.19675396382809, 55.103978142142296, 57.30679973959923, 56.58338315784931, 56.11906707286835, 50.465650632977486, 52.13773190975189, 50.0441088527441, 46.08885169029236, 42.72999532520771, 44.70212370157242, 44.81477625668049, 50.04841022193432, 54.99817281961441, 62.41770029067993, 62.052992060780525, 64.16043117642403, 64.14764106273651, 67.94539287686348, 68.94135743379593, 68.66079568862915, 66.741374284029, 65.09250596165657, 33.876546397805214, 14.206835366785526, 4.784320425242186, 0.9699686081148684, 0.9212877578102052, 12.015690542757511, 49.254344031214714, 49.89010311663151, 48.43346267938614, 31.4113811776042, 35.84380343556404, 18.919937163591385, 37.8607352077961, 57.81706675887108, 38.345327004790306, 79.77871790528297, 49.307750165462494, 60.7632614672184, 39.83502186834812, 0.14467904751654714, 0.23187262733699754, 0.05333807559509296, 0.2957288094330579, 0.033679132830002345, 0.10316515443264507, 0.030696114772581495, 0.15371971239801496, 0.07249613176099956, 0.03291870976681821, 0.1231493879458867, 0.22708852076902986, 0.21813501371070743, 0.11052120345993899, 0.21557064115768299, 0.14594213833333924, 0.2423261632793583, 0.1597892038989812, 0.16997065366012976, 1.0822975868359208, 45.373798459768295, 88.85250180959702, 68.60692217946053, 66.04285776615143, 107.30458527803421, 112.8725329041481, 97.90733993053436, 93.83530363440514, 73.38863119482994, 40.062910839915276, 35.65070539712906, 64.28459331393242, 59.73424628376961, 72.46893614530563, 66.08258083462715, 30.568953081965446, 7.208944670855999, 21.201406940817833, 53.325285986065865, 65.18560096621513, 62.162308394908905, 66.16680711507797, 65.23087933659554, 64.86581012606621, 65.77212229371071, 64.66354697942734, 63.240956515073776, 64.05352771282196, 60.248533487319946, 59.1201726347208, 59.48698975145817, 59.74672481417656, 56.47699646651745, 56.55662879347801, 54.407551512122154, 46.64531663060188, 43.12445215880871, 44.011845141649246, 44.56194922327995, 47.44363859295845, 51.224724501371384, 55.07277421653271, 55.11708743870258, 56.79288111627102, 57.90050648152828, 58.26593667268753, 62.09161318838596, 60.39433926343918, 55.17886832356453, 55.42910769581795, 62.6114708930254, 62.95117646455765, 62.6674684882164, 61.347347125411034, 57.76984669268131, 53.86236056685448, 55.52608609199524, 49.17894467711449, 39.238963052630424, 36.068956553936005, 21.105357594788074, 10.381548330187798, 8.64566182717681, 12.574665248394012, 19.059458076953888, 29.75216031074524, 40.85878573358059, 43.26217956840992, 54.334834814071655, 54.939264580607414, 50.8391971886158, 49.2338403314352, 47.533287182450294, 43.76498758792877, 35.329345241189, 34.77406203746796, 50.74489004909992, 50.58193199336529, 57.113743498921394, 51.024794429540634, 53.753659799695015, 50.1416952162981, 51.41590744256973, 47.64726206660271, 50.34917168319225, 46.27966605126858, 47.00080655515194, 49.70013231039047, 60.435418859124184, 51.09017752110958, 46.88047081232071, 11.053123343735933, 2.4214345542714, 3.7651196401566267, 7.406973419710994, 3.6087903287261724, 3.3561772713437676, 10.994828771799803, 27.465083934366703, 47.776025757193565, 45.467995405197144, 50.51493778824806, 49.82855401933193, 62.980811074376106, 59.01824310421944, 57.89217732846737, 58.96148554980755, 57.926972061395645, 56.07308954000473, 56.070425882935524, 57.15640380978584, 58.02420884370804, 55.70446752011776, 58.937831819057465, 57.07038402557373, 57.739277333021164, 62.68952250480652, 60.7828114181757, 58.53143982589245, 53.40619504451752, 55.906502678990364, 53.426216170191765, 50.40881708264351, 47.56357915699482, 49.280988201498985, 47.97146067023277, 53.929571360349655, 59.724245220422745, 65.89824512600899, 66.14653900265694, 67.35295906662941, 69.18077498674393, 71.52541637420654, 72.59365305304527, 70.29857620596886, 66.64581701159477, 67.34569385647774, 40.33045068383217, 12.186132296919823, 4.2598421685397625, 1.8014004500582814, 1.0190170886926353, 15.146421398967505, 55.484664514660835, 60.829879492521286, 51.28467008471489, 42.83625662326813, 51.7231285572052, 12.737967185676098, 47.86678768694401, 62.34411723911762, 42.50447362661362, 84.3289965391159, 67.81860888004303, 75.52062079310417, 60.37629783153534, 0.1648367432062514, 0.26010895671788603, 0.2612880215747282, 0.31185980478767306, 0.16894364001927897, 0.16941153444349766, 0.1642786036245525, 0.33649159711785614, 0.17114783346187323, 0.21692641137633473], [0.13863107829820365, 0.06540096990647726, 0.020593690751411486, 0.06675752680166624, 0.015609426955052186, 0.10114043456269428, 0.1272054624860175, 0.04922897831420414, 0.08918022009311244, 0.0192956280807266, 0.3945832955650985, 32.89709955453873, 65.67576706409454, 36.207633912563324, 73.80185902118683, 103.16681250929832, 85.0960385799408, 76.67599439620972, 49.104939848184586, 37.69563026726246, 25.83409935235977, 40.04692889750004, 49.05426196753979, 54.21788468956947, 58.20959709584713, 32.322988361120224, 11.636619083583355, 11.55517615377903, 29.24892481416464, 47.724352329969406, 52.97719046473503, 54.95156452059746, 59.73925061523914, 56.26855105161667, 61.11808642745018, 55.554227381944656, 57.517943009734154, 53.65540087223053, 58.39230269193649, 48.14952291548252, 48.69679994881153, 49.879562482237816, 49.515450820326805, 47.87347912788391, 47.856984212994576, 45.401745960116386, 41.273658871650696, 37.67554834485054, 37.0264557749033, 40.932167395949364, 41.606380417943, 43.94332341849804, 49.151726737618446, 51.103336215019226, 52.158520594239235, 51.77173554897308, 55.099080204963684, 59.00174058973789, 53.53368580341339, 48.50012630224228, 55.04788555204868, 61.829282864928246, 62.908280566334724, 62.94032424688339, 60.58250516653061, 56.507315039634705, 48.448844254016876, 38.94664853811264, 34.497159495949745, 35.033375322818756, 26.999635510146618, 10.05742572247982, 6.585881654173136, 8.273007273674011, 8.807899821549654, 19.619929902255535, 28.890083469450474, 43.47550392150879, 46.58469468355179, 48.57958383858204, 40.218060314655304, 38.68778742849827, 44.353017434477806, 36.8209134042263, 10.172235611826181, 13.264420386403799, 36.89090944826603, 54.60873171687126, 66.51288494467735, 53.888256177306175, 48.66489686071873, 44.1911119222641, 41.76460012793541, 43.325339779257774, 37.729345858097076, 42.30716161429882, 43.44221770763397, 34.870462864637375, 35.35589441657066, 37.482628896832466, 16.395538821816444, 2.5254095625132322, 1.237096767872572, 3.778062933124602, 1.509746506344527, 5.987270325422287, 9.48943980038166, 19.344811365008354, 39.977020248770714, 41.96737624704838, 45.46669967472553, 48.36076878011227, 51.27212695777416, 53.99596519768238, 52.57696934044361, 49.670414105057716, 48.95877689123154, 55.081167966127396, 50.569753646850586, 49.62865434587002, 47.96061985194683, 52.01787494122982, 50.083326548337936, 49.31954853236675, 49.07242499291897, 53.225153759121895, 49.182467088103294, 49.030900821089745, 48.06304715573788, 44.53386873006821, 45.75327269732952, 47.32352323830128, 41.44665598869324, 38.463071286678314, 40.561755672097206, 44.13916490972042, 50.11630117893219, 55.36050617694855, 57.137617617845535, 60.910313576459885, 63.12062457203865, 63.94350081682205, 68.95803093910217, 70.59958085417747, 69.49441015720367, 68.68985652923584, 57.10802100598812, 32.17163108289242, 21.993755623698235, 11.309312246739864, 2.028140458278358, 0.8798924228176475, 12.406952697783709, 38.04525710642338, 46.64257697761059, 33.80403868854046, 28.492434807121754, 19.358068853616714, 23.227066844701767, 48.99710163474083, 75.56254014372826, 82.6509153842926, 48.1690538674593, 32.649960815906525, 64.24825206398964, 20.53906638175249, 0.20622287556761876, 0.3248308243928477, 0.18486787303118035, 0.17296170175541192, 0.08394054617383517, 0.03870122760417871, 0.08064178880886175, 0.06879456632304937, 0.08224224511650391, 0.16183389496291056, 0.09997604196541943, 0.05323124714777805, 0.028996969522268046, 0.020131742785451934, 0.0206870399415493, 0.07492348900996149, 0.18109224125510082, 0.028489817341323942, 0.05035815229348373, 0.14760264923097566, 0.25282192742452025, 38.66052769124508, 68.14773201942444, 37.43431828916073, 81.61951392889023, 106.93323120474815, 94.5958024263382, 83.74837249517441, 62.29597382247448, 37.94759474694729, 28.65523897111416, 50.22346682846546, 57.39967055618763, 59.68862593173981, 64.07627329230309, 35.45195326209068, 14.479768071323633, 15.836676210165024, 35.6427676230669, 54.21120084822178, 59.86723534762859, 62.221684008836746, 64.59493026137352, 62.73486167192459, 64.49717670679092, 59.193459302186966, 61.34745351970196, 58.88467267155647, 60.689537823200226, 56.068487986922264, 53.66363883018494, 55.09739309549332, 55.069289803504944, 53.092426881194115, 52.38325193524361, 50.16601391136646, 45.78685909509659, 40.61700090765953, 40.50932228565216, 45.296183824539185, 47.90514662861824, 49.54158581793308, 51.68046824634075, 54.884452521800995, 54.276857525110245, 52.95293636620045, 57.25932128727436, 60.351648554205894, 55.79674556851387, 50.95634110271931, 58.32637242972851, 63.835860192775726, 66.91923514008522, 63.20634037256241, 62.0789560675621, 60.78549027442932, 53.76426123082638, 40.610461458563805, 37.19028778374195, 40.00137694180012, 31.01119615137577, 14.276116099208593, 7.59168435819447, 10.971402078866959, 11.127183269709349, 18.233792781829834, 34.20784302055836, 44.957523196935654, 44.51509013772011, 45.82753211259842, 43.258478567004204, 41.23918332159519, 48.903113678097725, 39.732070192694664, 15.10534655302763, 19.686299040913582, 43.64771448075771, 58.77234689891338, 68.19668099284172, 57.88713879883289, 49.20620061457157, 46.94823257625103, 43.31969328224659, 42.7814369648695, 36.40222147107124, 41.72854006290436, 47.14313551783562, 43.777055740356445, 40.32245971262455, 42.529210299253464, 21.666691973805428, 2.1242456138134003, 2.1844676323235035, 3.3398281736299396, 1.9124904577620327, 9.142409171909094, 12.796089816838503, 25.15826191753149, 44.99593533575535, 44.70609448850155, 51.92712441086769, 54.62569400668144, 56.76682211458683, 59.17191065847874, 55.85884943604469, 51.579686254262924, 50.34993924200535, 55.92431992292404, 52.95531123876572, 53.3435820043087, 51.789830178022385, 53.51707689464092, 53.32487940788269, 50.19409440457821, 52.99132950603962, 55.107656344771385, 53.57857659459114, 53.15538950264454, 51.77051581442356, 50.69015018641949, 52.784681394696236, 51.52810022234917, 48.01066316664219, 43.89493301510811, 46.17312736809254, 49.76920500397682, 54.79981206357479, 59.73785988986492, 61.10424757003784, 62.619674652814865, 67.14823365211487, 67.23071962594986, 70.72824954986572, 71.65578737854958, 71.24908000230789, 71.03315278887749, 62.32392132282257, 38.872647508978844, 29.06065061688423, 14.787056632339954, 3.801098484545946, 1.351170209236443, 17.34098508954048, 46.2980342656374, 55.66281795501709, 40.24082489311695, 26.87395915389061, 26.767629459500313, 29.368170015513897, 46.3030119985342, 77.81873747706413, 86.43369600176811, 64.08201098442078, 34.78499785065651, 65.9458489716053, 18.496049009263515, 0.5432621331419796, 0.31661863380577415, 0.053236739040585235, 0.3016264195321128, 0.05314060123055242, 0.14519708143780008, 0.014738258760189638, 0.08804975848761387, 0.044031773795722984, 0.11528026254381984, 0.3744936845032498, 0.3104380576405674, 0.18526619853219017, 0.1868560866569169, 0.1919187360908836, 0.15697000751970336, 0.3379749722080305, 0.07799646278726868, 0.2103549163439311, 0.19132172281388193, 0.7556395058054477, 56.91806919872761, 85.99966049194336, 53.525850623846054, 82.79373452067375, 110.91931611299515, 92.3623126745224, 89.02515694499016, 62.118112966418266, 52.422876209020615, 36.2699543684721, 52.63968877494335, 66.78341522812843, 63.52068990468979, 74.0265865623951, 37.39161238074303, 15.0801738537848, 15.312795471400023, 40.16332425177097, 61.9965460896492, 66.04123905301094, 67.28129491209984, 70.75254544615746, 64.14827182888985, 69.99863550066948, 62.33760818839073, 64.96624633669853, 63.37244085967541, 67.36599996685982, 58.37646894156933, 60.48392325639725, 59.27631005644798, 62.82727651298046, 58.67064155638218, 58.234136179089546, 55.65366804599762, 50.206686928868294, 45.10239042341709, 45.3664268553257, 49.15244869887829, 49.09890957176685, 53.09925511479378, 55.03840886056423, 56.7538496106863, 54.67748522758484, 54.59799349308014, 58.46411883831024, 63.0614959448576, 55.12895040214062, 51.789898574352264, 58.75700332224369, 64.1835643351078, 65.20111933350563, 66.68200626969337, 64.36250433325768, 60.97184367477894, 56.91714584827423, 44.151233062148094, 39.68062475323677, 42.867365553975105, 31.1692201718688, 13.858457710593939, 12.03302901238203, 14.792037215083838, 13.292954955250025, 23.044644333422184, 37.37696796655655, 44.83325846493244, 47.14073024690151, 54.087449088692665, 47.03108713030815, 44.29005101323128, 48.76608923077583, 42.07479268312454, 13.844705298542976, 20.03475934267044, 43.91077436506748, 58.18064644932747, 70.64171299338341, 57.18085169792175, 52.567515447735786, 48.77442218363285, 47.23422423005104, 47.58347108960152, 43.833368718624115, 46.2368955463171, 53.45513641834259, 56.218272149562836, 52.03933618962765, 49.60198737680912, 31.350981518626213, 4.148934194818139, 2.7521576453000307, 6.67501394636929, 4.759076479822397, 7.911543594673276, 12.992790061980486, 24.304297640919685, 49.9033872038126, 44.92129974067211, 54.03813913464546, 59.0967582911253, 60.388077199459076, 62.787036672234535, 60.12094393372536, 56.24557748436928, 52.616624012589455, 58.26044976711273, 54.536702781915665, 55.87931513786316, 55.99260985851288, 58.545525670051575, 55.00066548585892, 52.74972707033157, 56.46775156259537, 58.35378035902977, 55.210919603705406, 53.947912976145744, 54.27751109004021, 51.980336755514145, 54.240284487605095, 54.45611670613289, 51.45957849919796, 47.068359330296516, 47.737127244472504, 54.0857657790184, 58.856941759586334, 62.28762947022915, 64.29618269205093, 65.28082385659218, 69.94892656803131, 69.04215082526207, 73.9793398976326, 74.03483211994171, 73.55673417448997, 72.03362390398979, 66.79596975445747, 38.986371606588364, 33.001054376363754, 13.638628106564283, 3.8401031540706754, 1.2217096122913063, 20.299635529518127, 55.01825854182243, 64.93494361639023, 44.248055666685104, 38.26828233897686, 25.520196296274662, 32.14258924126625, 65.8655820786953, 93.78788977861404, 89.21803459525108, 59.727022871375084, 43.3313624560833, 82.39360839128494, 25.80733358860016, 0.6716125959064811, 0.36490893631707877, 0.268106815055944, 0.8036214311141521, 0.15299871593015268, 0.33797330979723483, 0.19396914169192314, 0.27831259241793305, 0.17203671857714653, 0.2558227570261806], [0.24372616549953818, 0.13103567180223763, 0.1039363126619719, 0.11136409768369049, 0.07193468962213956, 0.038780173563282005, 0.14237686089472845, 0.14432207448408008, 0.20521551399724558, 0.20842843456193805, 0.4275531764142215, 1.4260932826437056, 37.79433757066727, 50.95721125602722, 28.2759091258049, 77.00412958860397, 60.6103690713644, 71.98419615626335, 46.46059714257717, 35.312360152602196, 38.91750030219555, 28.694963939487934, 53.166731894016266, 52.78286129236221, 62.595861330628395, 37.80110880732536, 19.381633289158344, 25.558386147022247, 41.94223299622536, 54.29711043834686, 60.75829513370991, 59.81460057199001, 64.00645583868027, 58.777013048529625, 59.827208295464516, 58.49226772785187, 59.8531761020422, 55.03258377313614, 57.51140356063843, 58.274653404951096, 52.495243325829506, 53.65124009549618, 50.81826791167259, 48.36170352995396, 48.0804768204689, 44.09688837826252, 39.96447712182999, 37.15900406241417, 36.16810083389282, 39.046571776270866, 43.30612801015377, 46.06304347515106, 44.4435665756464, 49.78816598653793, 55.561386197805405, 51.333520263433456, 53.10670271515846, 56.50836378335953, 50.436323806643486, 48.76266561448574, 55.719822496175766, 62.02244929969311, 71.23484596610069, 67.2864094376564, 59.543523117899895, 53.34179230034351, 50.16642428934574, 40.71288876235485, 37.591318264603615, 42.37842679023743, 33.23261395096779, 21.061133667826653, 10.063953772187233, 6.403655782341957, 6.483035897836089, 11.468976829200983, 23.944930024445057, 45.40408283472061, 35.59667989611626, 34.446086436510086, 32.47408725321293, 37.17092402279377, 46.581039279699326, 43.17264877259731, 31.36403761804104, 36.021424904465675, 56.28184653818607, 66.93646341562271, 74.29795280098915, 70.93533083796501, 57.65174902975559, 53.34627605974674, 38.28434407711029, 33.95487159490585, 32.555900663137436, 37.21154764294624, 32.58021555840969, 16.60120278596878, 21.99372712522745, 24.766542837023735, 9.608281273394823, 1.2390794302336872, 3.0355768371373415, 4.108492014929652, 5.066925510764122, 14.14410738274455, 14.070345740765333, 31.833852007985115, 39.65008579194546, 45.40068581700325, 47.75954604148865, 49.70225639641285, 51.9684661924839, 48.92858371138573, 48.763338178396225, 43.051990047097206, 48.82695056498051, 53.06061118841171, 51.02172799408436, 51.11462540924549, 46.752489879727364, 50.70811562240124, 51.88024252653122, 46.97418138384819, 51.0478325933218, 50.28604567050934, 56.40304483473301, 48.83302643895149, 45.266530215740204, 42.07117147743702, 48.40260453522205, 45.86420774459839, 41.86144933104515, 40.35029701888561, 46.977848187088966, 52.03892961144447, 56.251003593206406, 55.079074278473854, 62.842851877212524, 61.11843220889568, 66.41193956136703, 67.71256417036057, 71.87245935201645, 73.9438346028328, 69.91923496127129, 64.65549901127815, 54.392914697527885, 36.73621214926243, 32.79028348624706, 21.36552583426237, 5.50878195092082, 3.1805533077567816, 18.361545726656914, 38.454487547278404, 45.14820836484432, 30.22221978753805, 38.42611826956272, 18.648584224283695, 28.96221499890089, 49.96645241975784, 69.19808685779572, 80.76206713914871, 58.10983344912529, 35.13093128800392, 65.57426691055298, 10.913230050355196, 0.20082728384295478, 0.7878425403032452, 0.12334289553109556, 0.12429271839209832, 0.06336083562928252, 0.1589929684996605, 0.42990444868337363, 0.2688713459065184, 0.1768982905196026, 0.1395626665907912, 0.23783618467859924, 0.12174433912150562, 0.04538043795037083, 0.1009427932149265, 0.08697304321685806, 0.10335996819776483, 0.1417826084070839, 0.10618883476126939, 0.10683688553399406, 0.4281902656657621, 0.5281407851725817, 1.6245007049292326, 37.611050605773926, 53.69880594313145, 34.41639482975006, 84.7513210773468, 75.70473611354828, 84.83645930886269, 55.27734763920307, 48.4128487855196, 40.83968035876751, 39.6274846047163, 56.29262275993824, 59.47250492870808, 67.66914010047913, 45.89684799313545, 26.77600611001253, 29.379780292510986, 50.1997447013855, 66.565922498703, 66.20836168527603, 67.79537692666054, 70.32348766922951, 64.61820781230927, 66.74103230237961, 61.95179209113121, 59.209460243582726, 57.68808647990227, 64.15470868349075, 61.03207424283028, 58.0817985534668, 60.35640589892864, 57.76245228946209, 54.965274184942245, 52.8669697791338, 49.07992959022522, 47.42399364709854, 43.83158661425114, 43.527800515294075, 43.70185397565365, 48.28144423663616, 47.492435574531555, 44.873076528310776, 49.41363908350468, 55.6825502961874, 55.25973178446293, 57.785927429795265, 59.17363956570625, 51.652353554964066, 54.351341128349304, 59.066641107201576, 62.50088922679424, 68.6296221613884, 67.74784907698631, 62.787431851029396, 56.56019300222397, 53.88931252062321, 45.11834196746349, 41.44081570208073, 47.53919206559658, 40.15433393418789, 28.327510356903076, 17.867313846945763, 6.545515945181251, 9.161980971693993, 13.165731132030487, 24.663486666977406, 50.68657077848911, 38.04255165159702, 37.864147424697876, 34.05367009341717, 38.673488795757294, 40.98989009857178, 44.73138213157654, 61.82829111814499, 68.71954053640366, 68.78032967448235, 66.37201130390167, 75.24413242936134, 70.66147193312645, 52.8350704908371, 49.248051568865776, 33.462684005498886, 35.77755019068718, 37.24399410188198, 47.16415598988533, 46.47567093372345, 30.77908180654049, 28.050170838832855, 31.18386648595333, 12.56207937374711, 2.430322039872408, 1.9245575414970517, 5.3989203460514545, 9.779277797788382, 21.21236365288496, 25.042425133287907, 40.20513340830803, 39.61285538971424, 47.91601024568081, 48.41821789741516, 53.973424807190895, 53.90741094946861, 54.20097939670086, 52.13781550526619, 46.16373807191849, 49.77229803800583, 53.701025024056435, 54.73751820623875, 51.945025250315666, 48.39024379849434, 52.847708612680435, 53.39441567659378, 52.349258959293365, 55.15497140586376, 53.43041494488716, 61.373759508132935, 54.30954337120056, 49.63724948465824, 45.95525085926056, 49.53013703227043, 49.883746057748795, 45.15726327896118, 44.3099619448185, 52.119606882333755, 56.78504213690758, 61.357492581009865, 60.461865440011024, 64.63561847805977, 63.479199931025505, 67.79865235090256, 70.64996615052223, 76.52647241950035, 76.13259315490723, 73.76829922199249, 67.31066733598709, 59.80201184749603, 45.64741797745228, 40.05814589560032, 24.932994805276394, 7.815921250730753, 5.397472148761153, 22.63732898980379, 48.720221891999245, 51.764952912926674, 32.00482003390789, 43.12539830803871, 27.674420401453972, 32.370170429348946, 47.637553587555885, 73.51211696863174, 85.86751118302345, 61.20413661003113, 38.08846078813076, 78.07426616549492, 9.89076666533947, 0.42708149703685194, 0.6129110301844776, 0.13911463203839958, 0.24902409058995545, 0.07086488374625333, 0.22058120666770265, 0.40288772026542574, 0.187191670993343, 0.08607122988905758, 0.09157513806712814, 0.3254529816331342, 0.20583547448040918, 0.17242302128579468, 0.24801379011478275, 0.24440591339953244, 0.220282789086923, 0.21111049689352512, 0.2998444635886699, 0.3963662311434746, 0.9447459771763533, 0.463445961358957, 2.76131515391171, 60.1594814658165, 66.49378716945648, 40.625717639923096, 89.08431217074394, 70.16564413905144, 88.86868134140968, 59.68331001698971, 48.21089342236519, 55.11980049312115, 43.80435347557068, 69.44870620965958, 63.69693584740162, 74.94593963027, 46.783477216959, 28.475008942186832, 30.31176008284092, 53.37499871850014, 71.76630064845085, 73.3455491065979, 72.29796051979065, 75.57178884744644, 69.71012458205223, 70.54022803902626, 66.72785460948944, 65.63427329063416, 61.07063077390194, 67.55522221326828, 65.31724110245705, 62.88928158581257, 67.49935001134872, 63.76538157463074, 59.136929735541344, 58.886355981230736, 55.470764860510826, 51.46930977702141, 44.049489721655846, 42.85168759524822, 47.24610239267349, 52.682318687438965, 51.858036518096924, 45.82467846572399, 49.67431649565697, 56.821235194802284, 55.67709378898144, 59.433701410889626, 63.78365099430084, 52.99409195780754, 54.2308533936739, 59.61089730262756, 64.13384780287743, 70.96564561128616, 68.0593791604042, 65.60312256217003, 57.494817450642586, 57.443562000989914, 49.16577458381653, 40.48259451985359, 49.08918969333172, 39.73350651562214, 28.667506612837315, 17.676871865987778, 9.362881891429424, 12.320674527436495, 16.490182243287563, 35.942567735910416, 57.23031364381313, 38.73347997665405, 41.22360035777092, 39.55333538353443, 39.97997269034386, 50.055713430047035, 44.142702519893646, 48.49689267575741, 55.81350266933441, 58.25189262628555, 64.6546858549118, 76.79883420467377, 72.47606456279755, 54.4497786462307, 50.7314957678318, 37.28787034749985, 44.81465466320515, 46.875063702464104, 66.96066811680794, 63.23321633040905, 48.80060277879238, 35.95834068953991, 43.05056892335415, 18.64564698189497, 3.202847186475992, 3.3812412014231086, 8.00657507032156, 7.7536611165851355, 18.35054911673069, 22.08073105663061, 38.09201739728451, 41.269824877381325, 51.59155301749706, 55.845139771699905, 56.26232698559761, 58.08498278260231, 56.74849569797516, 57.043359875679016, 48.262350261211395, 54.83764283359051, 57.61844381690025, 57.28315360844135, 54.76006619632244, 51.11475080251694, 58.11518356204033, 56.55666299164295, 51.12690635025501, 57.120389342308044, 55.38844607770443, 65.87809100747108, 57.97636181116104, 52.545476630330086, 45.789986327290535, 49.59736682474613, 51.553695648908615, 49.77764435112476, 43.99450287222862, 53.85263688862324, 60.922894701361656, 66.1898110806942, 64.73715662956238, 71.9165825843811, 66.42547443509102, 73.09658646583557, 72.72960215806961, 81.30954936146736, 81.78690254688263, 77.63890072703362, 68.2600311934948, 63.643047139048576, 50.079089775681496, 41.20018981397152, 24.970248006284237, 7.943808138370514, 5.877495165914297, 26.08442611992359, 55.47653675079346, 60.40285460650921, 40.286551639437675, 47.69841492176056, 26.346159875392914, 44.07445818185806, 66.81771218776703, 81.72986000776291, 89.23660799860954, 67.10335046052933, 45.835922062397, 87.50219866633415, 12.307231798768044, 0.7568644650746137, 1.3670985982753336, 0.36058675730600953, 0.5529852770268917, 0.18192610354162753, 0.34868701302912086, 0.7458121643867344, 0.34818074957001954, 0.44951549323741347, 0.31501212157309055], [0.34278777020517737, 0.14497699012281373, 0.2252725002472289, 0.38192409672774374, 0.08294718893012032, 0.2079365390818566, 0.11657163660856895, 0.07494533783756196, 0.29717341472860426, 0.3988416201900691, 0.08342467932379805, 0.14652623824076727, 1.9411245337687433, 53.87537106871605, 42.351885214447975, 35.97292050719261, 7.043841630220413, 41.872719526290894, 57.78804391622543, 23.112001419067383, 58.529551327228546, 26.6092349588871, 43.17935161292553, 53.25173333287239, 72.12055563926697, 45.308970138430595, 35.629194751381874, 43.660637587308884, 52.15276010334492, 57.52969577908516, 56.197133883833885, 61.5447199344635, 63.93494367599487, 59.792136177420616, 66.02059096097946, 55.099372789263725, 52.72095501422882, 49.06845040619373, 57.076741084456444, 56.79219715297222, 56.054219752550125, 54.63539108633995, 57.42294430732727, 50.63933551311493, 47.53384955227375, 43.69016580283642, 46.1566286534071, 42.425297275185585, 39.73992057144642, 40.1028048992157, 43.616073578596115, 49.560546800494194, 43.03513415157795, 47.597317546606064, 56.35740928351879, 45.312321558594704, 51.33342906832695, 47.50825792551041, 46.10647514462471, 50.084971860051155, 60.32878898084164, 64.87906381487846, 67.6155173778534, 65.59404864907265, 58.21478381752968, 54.600999131798744, 50.714871659874916, 41.033990532159805, 42.662890926003456, 43.93709555268288, 40.11747971177101, 34.20689307153225, 26.611410342156887, 7.121123308315873, 6.506165256723762, 5.992628512904048, 9.630470182746649, 36.65233924984932, 37.94619262218475, 31.704915426671505, 27.833973839879036, 37.593693137168884, 34.4354660063982, 47.54859656095505, 68.06221380829811, 75.75983315706253, 75.68884536623955, 62.233550772070885, 68.39196771383286, 68.85452449321747, 57.76454597711563, 48.330944180488586, 33.69064897298813, 26.530157402157784, 20.767540521919727, 17.532350420951843, 11.226552687585354, 3.4704665886238217, 6.1802648194134235, 14.00235028937459, 8.046324737370014, 0.6879891827702522, 4.444888439029455, 5.568437799811363, 16.902044042944908, 28.208179660141468, 35.83713099360466, 43.87605182826519, 40.68392291665077, 45.171603709459305, 49.1122430562973, 52.33331121504307, 46.46305941045284, 47.83483900129795, 50.24057351052761, 42.14282423257828, 44.31019753217697, 48.06240878999233, 49.53901335597038, 49.664984196424484, 46.45838186144829, 48.25019471347332, 48.59373427927494, 49.926657155156136, 50.48849880695343, 51.83370642364025, 55.03490164875984, 50.82251988351345, 48.97627875208855, 46.08821712434292, 50.83209916949272, 40.61652973294258, 40.57621769607067, 39.52316880226135, 48.59702490270138, 53.221904933452606, 57.172913923859596, 59.71750058233738, 66.47671088576317, 61.79059334099293, 67.05156683921814, 67.55666613578796, 70.4324734210968, 74.41766917705536, 69.1235576570034, 64.08908620476723, 55.01741498708725, 41.721111461520195, 39.446910694241524, 27.100219912827015, 10.51114797592163, 5.857160557061434, 17.407498620450497, 46.88456319272518, 41.92075274884701, 46.32799945771694, 41.92756578326225, 16.27639051526785, 41.69723354279995, 47.222266271710396, 76.71264722943306, 68.1140810251236, 56.27877250313759, 32.78004303574562, 67.53555446863174, 5.626830216497183, 0.21224816475296393, 0.10799767871503718, 0.09548944755806588, 0.4351425269851461, 0.07080823561409488, 0.2487078614649363, 0.8874690381344408, 0.23116957599995658, 0.032225499307969585, 0.22324637771816924, 0.16595513006905094, 0.07786011541611515, 0.2560256898868829, 0.25225068151485175, 0.016143780703714583, 0.2260068553732708, 0.11058125062845647, 0.13525455869967118, 0.37911402876488864, 0.4191591893322766, 0.14439836726523936, 0.16987126524327323, 0.8585569832939655, 58.039092645049095, 48.41662958264351, 48.38204383850098, 14.235199894756079, 51.39080598950386, 68.64442616701126, 39.88264091312885, 59.65352341532707, 35.500909835100174, 52.69097462296486, 58.16098250448704, 76.83034211397171, 52.134946659207344, 40.251889899373055, 41.27351447939873, 56.557111367583275, 63.52665178477764, 61.420641392469406, 66.22854620218277, 69.29596960544586, 66.99181124567986, 70.17460405826569, 60.541444569826126, 51.46039165556431, 52.99234785139561, 59.67949882149696, 61.61808639764786, 60.1003984361887, 59.905457496643066, 57.6627304404974, 54.080373868346214, 52.01726317405701, 47.724701911211014, 52.01971784234047, 49.097750633955, 47.76357762515545, 44.95809696614742, 48.535563200712204, 49.8897535353899, 44.89506974816322, 51.28385312855244, 58.19252461194992, 54.22795034945011, 56.91817179322243, 48.99487115442753, 49.55749176442623, 54.80632111430168, 60.00538073480129, 65.49158334732056, 67.44708001613617, 69.18955251574516, 64.42167475819588, 61.0080823302269, 55.322337225079536, 46.825784146785736, 48.56536120176315, 45.995232313871384, 45.48336938023567, 41.713086292147636, 31.276516914367676, 11.347282659262419, 7.967735454440117, 4.028544779866934, 11.26752208918333, 39.52591225504875, 39.102782160043716, 40.2868328243494, 33.91052797436714, 37.034230157732964, 33.04725609719753, 39.15203511714935, 80.80643355846405, 89.25270393490791, 69.85767066478729, 62.24244989454746, 73.37967127561569, 65.21968513727188, 58.52287508547306, 48.28221179544926, 34.64507795870304, 33.29065963625908, 27.110262773931026, 25.983767621219158, 22.22909789532423, 9.691554754972458, 9.939189366996288, 23.039347417652607, 13.674523830413818, 2.3322702012956142, 5.368212768808007, 9.551313780248165, 22.084762640297413, 32.64845609664917, 40.09648583829403, 42.863995134830475, 41.118558794260025, 47.951534539461136, 52.62837678194046, 54.05222497880459, 50.60815818607807, 55.31432345509529, 54.75849688053131, 47.09363177418709, 45.70001855492592, 51.023114919662476, 51.811166033148766, 52.33109213411808, 48.719689920544624, 49.50742185115814, 53.3575576543808, 52.859833762049675, 55.10781593620777, 58.411769047379494, 60.88564909994602, 54.936555325984955, 51.58988870680332, 49.95639055967331, 51.25589422881603, 44.60156969726086, 42.9122069478035, 44.97920863330364, 49.01595242321491, 54.97177183628082, 63.20384010672569, 64.84158262610435, 66.97351142764091, 65.02008944749832, 67.21760272979736, 66.35399267077446, 72.84608870744705, 75.24927735328674, 72.38459587097168, 69.41754788160324, 62.29671858251095, 50.57828038930893, 45.367692187428474, 28.926990889012814, 11.647497899830341, 6.962801953777671, 23.487732857465744, 56.0986165702343, 46.640532687306404, 55.555899292230606, 48.89316201210022, 23.21169476956129, 41.71679109334946, 43.652354031801224, 76.38568997383118, 72.44820445775986, 62.20532588660717, 34.293129444122314, 72.79812008142471, 5.798887833952904, 0.07870269051636569, 0.3222945495508611, 0.09772829929715954, 0.3020243294304237, 0.03690078105137218, 0.16481473110616207, 0.29834627523086965, 0.10868383877095766, 0.3314187505748123, 0.2653268486028537, 0.6010382703971118, 0.1716611918527633, 0.27910660137422383, 0.4998360446188599, 0.06659362348727882, 0.3704418253619224, 0.14645380462752655, 0.1375520252622664, 0.43368931277655065, 0.5354617454577237, 0.16411408432759345, 0.23825068899895996, 2.5621345918625593, 76.07248038053513, 57.27158322930336, 51.27708949148655, 12.625433374196291, 57.45816081762314, 70.9758822619915, 36.914916560053825, 74.82264384627342, 43.079257383942604, 58.93782801926136, 65.6469114124775, 83.69107156991959, 56.047239527106285, 43.491896241903305, 46.315653920173645, 62.155354768037796, 68.93067240715027, 69.8689104616642, 72.46992409229279, 77.3350690305233, 70.7076470553875, 74.61850360035896, 64.07369703054428, 56.24341160058975, 57.35721543431282, 64.49057266116142, 67.89712026715279, 68.00463929772377, 66.800537109375, 64.38424676656723, 58.476289585232735, 55.30074678361416, 51.99808940291405, 55.390638560056686, 50.04032425582409, 47.69548907876015, 46.08455032110214, 49.975989907979965, 53.395190834999084, 42.93627865612507, 50.763569846749306, 58.9051915705204, 57.19563290476799, 60.96090026199818, 51.95999264717102, 50.994027480483055, 52.759264558553696, 62.149856463074684, 65.99954009056091, 68.16144168376923, 73.15570369362831, 69.36507269740105, 64.75573003292084, 56.52633681893349, 44.99431662261486, 47.219268232584, 49.32305574417114, 44.53917324542999, 43.83107744157314, 31.141285970807076, 11.622923668473959, 11.931037735193968, 12.784503288567066, 19.486498162150383, 56.80925823748112, 46.7578399926424, 43.12440276145935, 35.61230845749378, 40.90159423649311, 36.5922074764967, 49.58264261484146, 52.18701146543026, 56.51764288544655, 73.06353583931923, 62.53630332648754, 71.96551635861397, 66.30875989794731, 60.18370896577835, 54.97796170413494, 41.7250632494688, 46.43845573067665, 40.433409959077835, 38.420916348695755, 26.31912052631378, 12.952731661498547, 16.646395660936832, 28.18173687905073, 19.351622499525547, 7.10398337803781, 7.427674233913422, 8.344651479274035, 20.588421933352947, 33.87732535600662, 42.5645712018013, 45.225678607821465, 43.875250071287155, 53.95886778831482, 58.82310077548027, 57.71053947508335, 58.00641059875488, 60.49284137785435, 60.67729867994785, 51.08589895069599, 50.94329260289669, 52.60898642241955, 53.25616009533405, 54.483064860105515, 50.52179642021656, 50.452127158641815, 55.499403923749924, 57.20836982131004, 58.947015926241875, 61.985025107860565, 68.24406445026398, 59.00468163192272, 53.09252567589283, 49.69417043030262, 52.108389884233475, 46.58108867704868, 46.876515224575996, 46.09183073043823, 50.63340403139591, 64.08784747123718, 68.34926560521126, 69.27263125777245, 71.40994057059288, 71.5558223426342, 74.59667757153511, 72.29381114244461, 78.98505449295044, 83.14130187034607, 77.07855999469757, 68.08641850948334, 65.66584959626198, 53.05977143347263, 49.750342816114426, 32.30743959546089, 12.139492649585009, 8.608862701803446, 25.949482060968876, 64.69488009810448, 52.915101796388626, 57.88833573460579, 51.07931010425091, 23.60643658787012, 60.11332914233208, 61.254221722483635, 94.36874181032181, 77.23871380090714, 64.9483796954155, 46.27959005534649, 85.76509147882462, 7.7468884550035, 0.6731382734142244, 0.41207553818821907, 0.20731623721076176, 0.8047475363127887, 0.18440226442180574, 0.48496860021259636, 0.6061828380916268, 0.24267437896924093, 0.5143133271485567, 0.32009728776756674], [0.015274324086931301, 0.0891925768519286, 0.1301078833057545, 0.1146399523713626, 0.06304163791355677, 0.14387093775440007, 0.05426342613645829, 0.10090083218528889, 0.21835848921909928, 0.3905623691389337, 0.03774481076106895, 0.45694566797465086, 0.7207423564977944, 20.282570645213127, 66.52065172791481, 38.11838038265705, 41.20834797620773, 48.77522774040699, 59.692277535796165, 16.863759197294712, 58.230875954031944, 58.21899779140949, 45.796236991882324, 49.08992685377598, 66.01224660873413, 43.1327623128891, 35.06168380379677, 38.37454363703728, 54.487404227256775, 64.49968457221985, 59.82371248304844, 60.772525370121, 59.105098843574524, 60.38382902741432, 57.65860006213188, 51.53320334851742, 46.717581152915955, 46.547046303749084, 54.78248119354248, 52.30052277445793, 53.36459867656231, 51.24516740441322, 56.24377258121967, 50.915736481547356, 48.93074959516525, 49.25759665668011, 52.03015208244324, 49.58440952003002, 46.700850650668144, 43.24168346822262, 45.17550230026245, 49.852010160684586, 44.67538073658943, 49.43189710378647, 52.80503690242767, 51.021082028746605, 49.2813415825367, 40.22605508565903, 46.47670067846775, 54.76506672799587, 59.01777192950249, 60.89823782444, 63.155829682946205, 63.628630712628365, 58.626579120755196, 58.419847413897514, 57.79394879937172, 52.59459659457207, 48.1596227735281, 43.477874994277954, 43.20797547698021, 37.38091215491295, 30.506720021367073, 17.403801418840885, 12.903823535889387, 2.5681418320164084, 5.631511090323329, 29.837019257247448, 29.97513424605131, 32.804357931017876, 33.42009589076042, 35.19398510456085, 34.63979244232178, 27.863285467028618, 63.98999512195587, 78.33524376153946, 54.774699211120605, 55.839633867144585, 64.89835157990456, 43.63114736974239, 24.817112423479557, 20.02440869808197, 16.587356328964233, 8.851220346987247, 3.7222090177237988, 3.5798938293009996, 1.580203038174659, 0.5359725211746991, 3.1626111455261707, 5.647474033758044, 4.8142666183412075, 0.9870935173239559, 3.6074793990701437, 13.628232814371586, 25.843946523964405, 32.41965897381306, 32.89230041205883, 35.270178616046906, 37.80752666294575, 42.80574046075344, 46.93548046052456, 49.02513653039932, 43.39348152279854, 50.533127412199974, 49.41032946109772, 47.58377127349377, 45.296886786818504, 47.869477942585945, 53.692407086491585, 48.89562427997589, 45.9444822371006, 46.2846589833498, 47.77087323367596, 45.54274119436741, 49.65920850634575, 54.557540863752365, 53.09170491993427, 53.52602161467075, 51.10630005598068, 46.76565997302532, 45.359579622745514, 40.15644662082195, 39.95568439364433, 44.221069514751434, 45.55778078734875, 45.2311123162508, 56.720555797219276, 59.09267731010914, 64.93828743696213, 60.90875566005707, 64.29952651262283, 63.15156631171703, 69.57493543624878, 67.0970655977726, 68.52701246738434, 63.19823160767555, 57.319335266947746, 46.75611108541489, 42.320149317383766, 25.956042408943176, 11.83290895074606, 6.195516251027584, 23.289286606013775, 46.286505684256554, 44.33872640132904, 59.34411741793156, 35.984661877155304, 22.14230675250292, 40.96065066754818, 45.485421270132065, 57.0508074760437, 58.12721751630306, 65.24101719260216, 42.700337916612625, 60.30990019440651, 2.321995315141976, 0.10925173017312773, 0.08127662193146534, 0.05475293561175931, 0.09784825262613595, 0.05756637663580477, 0.11584296633373015, 0.03049327653570799, 0.1130692487640772, 0.09329390013590455, 0.16787739645224065, 0.019129203319607768, 0.08199027855880558, 0.099317623389652, 0.07226417350466363, 0.12065016111591831, 0.2992772252764553, 0.0276701486291131, 0.19989688298664987, 0.3545469220262021, 0.4146316135302186, 0.07610698448843323, 0.4080916300881654, 0.9678022493608296, 20.799439810216427, 71.79278522729874, 43.049561977386475, 34.811072051525116, 52.1466576308012, 70.29360607266426, 27.26710505783558, 66.00121960043907, 62.52518892288208, 53.28610248863697, 53.40449273586273, 68.90785843133926, 49.723527655005455, 35.852029994130135, 37.956353276968, 57.4634463340044, 70.24665579199791, 63.755106925964355, 64.1297060251236, 62.61877790093422, 60.07905878126621, 56.26595579087734, 53.83869543671608, 49.812906458973885, 50.618064254522324, 56.10208958387375, 57.341887056827545, 58.90397943556309, 55.264264941215515, 59.412597343325615, 55.42653903365135, 55.57848908007145, 55.0562185049057, 55.64629644155502, 57.18847408890724, 52.17973105609417, 46.83961160480976, 45.64047195017338, 48.089045360684395, 50.67988693714142, 51.936646699905396, 53.921648785471916, 54.29095856845379, 50.46579122543335, 42.387181520462036, 50.412913262844086, 56.95155680179596, 59.44513879716396, 63.31465356051922, 68.67569088935852, 66.04383051395416, 63.61859545111656, 60.01916639506817, 61.275033205747604, 56.8113861232996, 52.64162667095661, 45.80512851476669, 47.966798320412636, 44.40966859459877, 33.84611003100872, 24.012043923139572, 16.281753927469254, 4.771018764004111, 11.373415756970644, 37.323953211307526, 35.96815176308155, 38.44157963991165, 39.22082282602787, 40.54548114538193, 38.93088698387146, 33.727244809269905, 48.46877038478851, 58.848384618759155, 54.3802385777235, 66.62389978766441, 67.46135964989662, 51.65201537311077, 34.147779643535614, 29.80458989739418, 27.196801230311394, 17.007307894527912, 8.736050426959991, 6.766093159094453, 4.312707306817174, 1.13531400449574, 3.8464257773011923, 6.657502586022019, 8.75476822257042, 0.8945572015363723, 4.971927283331752, 16.62908758968115, 29.075992293655872, 36.11133188009262, 33.672603741288185, 35.84156155586243, 42.62563772499561, 45.490790382027626, 52.85474203526974, 53.93770292401314, 49.50785882771015, 53.359860330820084, 55.19771531224251, 50.538488924503326, 45.78848160803318, 51.5931299328804, 55.330970361828804, 50.27309596538544, 47.63697601854801, 49.06581714749336, 51.69358894228935, 51.38911508023739, 53.15863832831383, 55.909812301397324, 56.65984645485878, 52.27390520274639, 53.77595320343971, 50.557560101151466, 45.026690885424614, 43.41238930821419, 44.41142410039902, 46.60310089588165, 47.844224497675896, 49.128897562623024, 59.82471942901611, 64.83817040920258, 65.90266048908234, 64.64207053184509, 66.7558591067791, 67.28184968233109, 71.55343607068062, 69.03526559472084, 70.52626758813858, 67.14060366153717, 63.55203062295914, 53.911298140883446, 44.48404960334301, 26.746954768896103, 12.189190182834864, 8.870267774909735, 30.530740432441235, 52.80287481844425, 54.15579602122307, 63.33623260259628, 46.44125238060951, 26.86199549585581, 42.360845133662224, 41.84570677578449, 64.05842185020447, 69.010711312294, 73.50054278969765, 49.71082113683224, 70.1145900785923, 2.9293601866811514, 0.09985861193854362, 0.09485971299000084, 0.043813667725771666, 0.13172781356843188, 0.07450491772033274, 0.0271003183661378, 0.041155216822517104, 0.15034003125037998, 0.10042064779554494, 0.3220646025147289, 0.08889114615158178, 0.22410769946873188, 0.22002091485774145, 0.1624188112327829, 0.2180922808474861, 0.4674523416906595, 0.18809329136274755, 0.3107457223813981, 0.5785043514333665, 0.6075124104972929, 0.17509427794720978, 0.5829229799564928, 1.4351920131593943, 28.79636909812689, 86.00005567073822, 52.60074086487293, 54.54174891114235, 61.85353696346283, 74.10433799028397, 27.13474676012993, 67.13327005505562, 72.76273638010025, 57.3199812322855, 59.878623336553574, 75.49254789948463, 54.86686706542969, 39.66108240187168, 41.590656861662865, 62.343535870313644, 76.51051327586174, 65.90440079569817, 68.50894063711166, 68.60910326242447, 65.94255074858665, 62.26448871195316, 57.189188450574875, 52.15222053229809, 53.3212848007679, 59.591852724552155, 59.318483993411064, 64.22319620847702, 61.356386840343475, 62.717310413718224, 59.325430020689964, 58.452468663454056, 58.29879730939865, 58.011403530836105, 59.06837001442909, 52.90540091693401, 50.713351741433144, 47.498678639531136, 53.27158726751804, 51.1550248414278, 54.15280558168888, 59.71538409590721, 56.24591946601868, 55.23944467306137, 44.42471578717232, 49.424673691391945, 58.22225421667099, 61.05037786066532, 62.5679974257946, 67.62780591845512, 69.78665247559547, 68.04631546139717, 63.48623335361481, 64.16991546750069, 58.25340874493122, 53.29233795404434, 47.180263325572014, 46.36280559003353, 43.539557084441185, 36.88871696591377, 22.003308311104774, 17.297906801104546, 6.560633908957243, 14.121042620390654, 46.835842207074165, 42.42034614086151, 46.10049806535244, 40.701101794838905, 42.005841583013535, 39.46711800992489, 39.20493967831135, 47.946138828992844, 56.5452978014946, 54.54220488667488, 59.70304235816002, 70.23742988705635, 59.6152138710022, 48.84352147579193, 43.91185350716114, 38.87438401579857, 24.538142792880535, 9.247270245105028, 6.701627718284726, 3.8952766684815288, 1.0830885381437838, 7.481988994404674, 10.431022625416517, 14.34309035539627, 3.448776639997959, 8.8911191560328, 16.48968257009983, 29.389125891029835, 40.42804464697838, 37.54410959780216, 38.28316614031792, 44.922477677464485, 48.45259465277195, 56.90471291542053, 59.14852671325207, 52.35023930668831, 57.93105684220791, 62.2838144749403, 51.409622579813, 48.69658336043358, 54.487077444791794, 58.47032390534878, 53.171610832214355, 49.912772700190544, 49.59281086921692, 53.35094600915909, 52.383662313222885, 55.050777196884155, 62.232779413461685, 62.792105600237846, 59.604946821928024, 57.626651376485825, 53.21062333881855, 48.860726952552795, 47.37341456115246, 46.08128249645233, 50.02504147589207, 49.65334542095661, 51.89573049545288, 63.83762329816818, 68.09391930699348, 70.04550978541374, 70.70069342851639, 70.61501562595367, 70.68994760513306, 76.90429374575615, 75.89803174138069, 74.79337021708488, 70.17001390457153, 68.12695473432541, 59.03189577162266, 49.568119794130325, 31.149979904294014, 13.978608213365078, 10.108171049505472, 30.669296197593212, 58.727611899375916, 57.15013414621353, 69.92013171315193, 46.885501742362976, 31.945117637515068, 56.51439405977726, 59.618094116449356, 72.56421983242035, 74.33550998568535, 79.10766631364822, 58.70702460408211, 79.1252289712429, 3.497248739004135, 0.2630095963831991, 0.2856057963799685, 0.1934993325266987, 0.23477068432839587, 0.3821028058882803, 0.36507645389065146, 0.1784947095438838, 0.28677515394520015, 0.17075158597435802, 0.4137630632612854], [0.13561080442741513, 0.14306123979622498, 0.07041031829430722, 0.040108558532665484, 0.12469464330933988, 0.1623303472297266, 0.03361042479809839, 0.0681969964352902, 0.0791104487143457, 0.20941258175298572, 0.05477435028296895, 0.0848964398028329, 0.2605811704415828, 7.896636044606566, 64.38853293657303, 43.22527974843979, 54.984489753842354, 60.80357350409031, 59.93761897087097, 21.389977522194386, 26.270371042191982, 46.03988751769066, 33.80284555256367, 50.424601435661316, 57.48643510043621, 49.355411008000374, 25.111163444817066, 37.2298626601696, 53.01402948796749, 58.32192286849022, 61.338892579078674, 58.60302418470383, 52.56343446671963, 51.557210460305214, 49.655929282307625, 49.84238527715206, 47.66737438738346, 46.69111557304859, 49.33299981057644, 48.57948884367943, 49.79362629354, 49.641600251197815, 51.845595985651016, 51.15102365612984, 53.26515041291714, 52.86391854286194, 53.5461263358593, 52.81902015209198, 51.69087588787079, 43.33172343671322, 43.95516358315945, 44.36423823237419, 49.36639241874218, 51.31746992468834, 51.31341174244881, 45.613630190491676, 41.28867946565151, 42.78072640299797, 50.44938750565052, 52.2558181732893, 52.180437818169594, 59.70074348151684, 59.20837350189686, 59.66290891170502, 57.62477047741413, 55.08712984621525, 56.222079545259476, 56.74500748515129, 52.00075685977936, 44.51869234442711, 45.397387593984604, 41.14381603896618, 36.69505275785923, 28.625212982296944, 18.633174151182175, 8.183369133621454, 18.29821452498436, 29.578329138457775, 28.814915902912617, 23.74594420194626, 31.81972436606884, 38.68342526257038, 33.319245502352715, 37.25792035460472, 31.481489315629005, 39.72049601376057, 40.25927670300007, 47.40092508494854, 42.02181972563267, 26.571947559714317, 7.02887280844152, 3.5821820190176368, 4.181316057220101, 1.1300321691669524, 0.4578358889557421, 0.4375045752385631, 0.12607132724951953, 0.6855266774073243, 1.4798670471645892, 2.139519131742418, 4.906847225502133, 1.9022890739142895, 6.407790435478091, 19.44475170224905, 25.240649096667767, 29.052781239151955, 30.33108964562416, 33.55648577213287, 35.38899064064026, 37.71543100476265, 47.32429459691048, 47.6628602296114, 44.99185435473919, 53.006357699632645, 49.29667375981808, 51.302209943532944, 48.35820011794567, 50.56820333003998, 49.39717836678028, 48.3429591357708, 45.15692889690399, 46.30568325519562, 47.250658348202705, 49.788595363497734, 50.83060584962368, 47.09688059985638, 45.839345678687096, 44.93002027273178, 45.06425566971302, 43.34683142602444, 35.97570575773716, 43.39397169649601, 40.95195673406124, 43.08634780347347, 44.936806708574295, 47.531049102544785, 57.836153134703636, 60.78177407383919, 58.344653248786926, 62.48933784663677, 66.41969874501228, 67.01752066612244, 62.160165309906006, 63.64033028483391, 63.91002461314201, 61.26265347003937, 53.143929317593575, 50.04649892449379, 38.7438078224659, 24.12964951246977, 8.063863646239042, 11.457976419478655, 29.755173549056053, 47.83649951219559, 46.63314588367939, 52.55061775445938, 28.234470449388027, 29.15850106626749, 41.92479573190212, 47.191035747528076, 50.44840335845947, 87.88068115711212, 41.38029254972935, 56.529019474983215, 69.61643680930138, 1.943564002867788, 0.1310430042212829, 0.05416112850070931, 0.05796427169116214, 0.03863204830850009, 0.03794172480411362, 0.043176452309126034, 0.10243272146908566, 0.06090023758588359, 0.22889076702995226, 0.20501725666690618, 0.10324397793738171, 0.11526500398758799, 0.0644831929821521, 0.05145638613612391, 0.060055205976823345, 0.07974667707458138, 0.10629356664139777, 0.08366119436686859, 0.022645458193437662, 0.18722202483331785, 0.008448800253972877, 0.24711380247026682, 0.24671987048350275, 9.572994466871023, 69.93536129593849, 44.75042290985584, 48.261483907699585, 67.05252438783646, 65.28267055749893, 29.03680119663477, 34.03472810983658, 55.11878974735737, 41.94178082048893, 55.00220060348511, 62.57042169570923, 53.53850394487381, 28.2218836247921, 36.82025603950024, 54.36165377497673, 64.16866153478622, 64.95217189192772, 61.71830601990223, 58.78698371350765, 55.390106588602066, 54.53128047287464, 51.60263702273369, 51.13642863929272, 52.139373421669006, 51.6251166164875, 50.66636726260185, 51.898416951298714, 52.63440325856209, 53.10869000852108, 52.10349954664707, 54.93949256837368, 57.569627836346626, 55.98719134926796, 54.58761245012283, 55.61738759279251, 50.50555229187012, 47.261575162410736, 47.43040770292282, 50.62251001596451, 53.06341923773289, 52.02203191816807, 46.33419692516327, 44.96460601687431, 47.5445231795311, 53.617015331983566, 55.0722536444664, 56.26889303326607, 60.067929178476334, 60.332079604268074, 61.90973974764347, 60.51709167659283, 58.2370962202549, 58.68733786046505, 57.434396892786026, 55.41682295501232, 48.76289360225201, 46.31113976240158, 45.259549990296364, 43.92319589853287, 32.3512664437294, 22.172401137650013, 12.245325520634651, 32.15022303164005, 32.7034505456686, 29.335334077477455, 29.80448730289936, 34.27483722567558, 38.763657957315445, 36.84257984161377, 42.51993499696255, 37.96092063188553, 40.136186107993126, 42.91026525199413, 44.727065563201904, 43.02301660180092, 32.24028579890728, 17.418962605297565, 9.175066519528627, 10.722523033618927, 3.4108907729387283, 1.2679503997787833, 0.45498135150410235, 0.1769191597122699, 1.8862947821617126, 2.2398897958919406, 3.8563774432986975, 4.548770114779472, 5.893482333049178, 11.462857257574797, 20.820061303675175, 31.607507653534412, 32.38720491528511, 32.87033759057522, 36.73778906464577, 42.4861092120409, 43.507631197571754, 49.2281786352396, 50.83955816924572, 49.24117013812065, 56.29041127860546, 54.15341354906559, 54.15500566363335, 54.40829627215862, 53.33699315786362, 52.004511058330536, 52.01873369514942, 49.27192188799381, 47.71916180849075, 51.78180120885372, 50.34640543162823, 51.875469982624054, 49.900047183036804, 48.670281171798706, 45.00494845211506, 45.14250487089157, 45.021101385354996, 42.3545678704977, 45.09533800184727, 44.70581330358982, 45.01677721738815, 47.34100989997387, 51.03680178523064, 58.976506143808365, 63.097620606422424, 62.48766973614693, 65.17418637871742, 68.00561964511871, 70.53582027554512, 67.08966359496117, 67.66347080469131, 66.020537763834, 63.36915783584118, 59.723884239792824, 54.4803062081337, 43.33953581750393, 23.91015999019146, 8.806059770286083, 12.696645352989435, 34.566061198711395, 56.11918106675148, 49.324951842427254, 58.30647669732571, 36.29125602543354, 28.943882882595062, 36.205122247338295, 46.72406740486622, 56.11123189330101, 112.86032035946846, 48.74528534710407, 50.53564667701721, 73.63430321216583, 1.41588180558756, 0.03887563601892907, 0.08734898554394022, 0.02752123855316313, 0.07816427721991204, 0.07486560891265981, 0.026857547018153127, 0.049290721290162764, 0.0884008314460516, 0.13521837157895789, 0.18226565094664693, 0.21678896562661976, 0.2941722882678732, 0.13720204326091334, 0.1508503023069352, 0.18855370493838564, 0.24022316909395158, 0.2520779985934496, 0.13479582237778232, 0.23060885374434292, 0.4131151980254799, 0.17103786201914772, 0.39511425769887865, 0.6517807475756854, 14.95876181870699, 83.91152814030647, 56.96662299335003, 70.91298043727875, 76.09622150659561, 75.91662034392357, 32.51173943281174, 29.841700606048107, 58.906643092632294, 44.93212155997753, 60.256953835487366, 69.64039072394371, 56.96364775300026, 32.18278728425503, 43.27730655670166, 58.02100941538811, 71.05726629495621, 68.71463119983673, 66.63128659129143, 64.22460213303566, 57.91461892426014, 55.290479734539986, 54.4463512301445, 54.050412476062775, 56.300233751535416, 55.223892107605934, 56.26171141862869, 57.46554762125015, 57.408448085188866, 57.87253998219967, 59.05905291438103, 59.184856563806534, 61.42525054514408, 59.08396817743778, 61.03322558104992, 60.4781399667263, 51.77521616220474, 49.851573184132576, 50.77156461775303, 54.817325323820114, 57.96018607914448, 56.279832646250725, 48.30689527094364, 47.06181988120079, 49.18952330946922, 54.376750364899635, 56.597818583250046, 57.065201103687286, 64.94793891906738, 63.84369537234306, 62.80522249639034, 62.75685869157314, 60.747849494218826, 59.256965294480324, 60.07755786180496, 59.634197652339935, 51.922215074300766, 49.014025926589966, 44.31012913584709, 42.315741553902626, 31.996464282274246, 24.87902630120516, 12.941486164927483, 30.178736820816994, 42.77463153004646, 39.33113090693951, 34.83485497534275, 40.154185742139816, 44.390567019581795, 39.3367850035429, 44.599578604102135, 35.98978400230408, 38.87011684477329, 43.557495921850204, 50.1771929115057, 47.67490178346634, 38.05826000869274, 26.333358362317085, 15.465995650738478, 15.51484202966094, 4.087066389620304, 1.1329202516935766, 0.8209471951704472, 0.2780600544065237, 2.0801371056586504, 4.672094872221351, 7.382000209763646, 9.719812888652086, 8.476416058838367, 11.914444025605917, 22.108992040157318, 34.590953662991524, 37.2597024589777, 36.32795065641403, 42.44813784956932, 46.15789778530598, 45.37058383226395, 55.71875475347042, 57.23479360342026, 51.03021293878555, 60.286915227770805, 59.29368272423744, 59.1917721927166, 54.74810063838959, 55.66626816987991, 54.45762142539024, 53.65086391568184, 51.721468046307564, 50.05248740315437, 53.10349188745022, 53.66659887135029, 57.922435104846954, 52.752994894981384, 52.85072185099125, 48.9734061062336, 51.24313451349735, 49.98078145086765, 42.086800038814545, 48.60096909105778, 47.44358919560909, 48.79073850810528, 50.528978034853935, 54.822455048561096, 63.3729500323534, 66.25025823712349, 65.03022730350494, 66.59046918153763, 70.50454795360565, 70.10123759508133, 68.61300185322762, 70.0910921394825, 70.46510607004166, 69.7386534512043, 62.221254631876945, 61.00219264626503, 50.952651500701904, 27.979701720178127, 9.96823025867343, 14.460970479995012, 38.604571893811226, 61.32479913532734, 58.233140632510185, 62.39367038011551, 38.17149393260479, 39.62017759680748, 55.27483977377415, 63.04584078490734, 66.18897512555122, 103.66516336798668, 57.48662129044533, 73.39433088898659, 86.36723756790161, 2.1542689902707934, 0.22710397228365764, 0.231540679524187, 0.24107202276354656, 0.15785573108587414, 0.18366354546742514, 0.13247928261989728, 0.36370428220834583, 0.16050686070229858, 0.25915681093465537, 0.3870260651456192], [0.06007100630085915, 0.06215762499778066, 0.04430572647834197, 0.042693818832049146, 0.05266858046525158, 0.145950821461156, 0.034360275967628695, 0.07273696610354818, 0.05205777066294104, 0.0844699126901105, 0.09237884689355269, 0.08688035639352165, 0.23136642324971035, 1.9703169423155487, 53.47108036279678, 57.57124274969101, 46.769520565867424, 61.93045623600483, 57.195929288864136, 36.181350722908974, 17.90854923427105, 33.67396026849747, 49.01204623281956, 41.49522878229618, 56.400073394179344, 53.18838693201542, 26.31573110818863, 21.6989104449749, 54.669190272688866, 67.39553198218346, 64.02920141816139, 65.39065316319466, 61.90866820514202, 59.86226141452789, 59.73974458873272, 54.28956784307957, 54.91613522171974, 50.45522399246693, 52.04937145113945, 48.37632894515991, 48.21840561926365, 45.94149559736252, 46.15465275943279, 44.21241357922554, 46.83926202356815, 47.13816158473492, 50.42826443910599, 52.42997042834759, 48.33187133073807, 48.563183918595314, 47.991561591625214, 43.932429403066635, 41.1820799857378, 44.92273606359959, 46.15065537393093, 42.62645088136196, 44.91524666547775, 51.14591293036938, 53.69476675987244, 53.8947918266058, 54.06234383583069, 55.17543710768223, 54.02661055326462, 57.08037368953228, 54.464628249406815, 55.805272310972214, 53.309353440999985, 56.28938913345337, 52.485629841685295, 46.126253083348274, 43.490087538957596, 43.46784733235836, 43.60511876642704, 39.64644938707352, 24.249819964170456, 9.66195434331894, 28.87005854398012, 19.4844975695014, 19.4438074529171, 24.040312506258488, 25.216138511896133, 23.24911706149578, 27.43541892617941, 31.580312512815, 34.68514680862427, 33.135909140110016, 24.84350960701704, 21.485665887594223, 22.762625366449356, 13.123049922287464, 4.991451585665345, 2.9102785605937243, 0.7339354860596359, 0.15111637709196657, 0.5014495924115181, 0.24537785968277603, 0.28377079172059894, 0.5789708357769996, 0.5473101628012955, 2.817533374764025, 1.8847551522776484, 5.713404295966029, 15.962198674678802, 18.128361739218235, 23.07829722762108, 27.265051268041134, 26.218785010278225, 31.458010375499725, 35.430602207779884, 41.82938665151596, 43.37779216468334, 43.85626628994942, 44.38678242266178, 49.49834033846855, 49.43524852395058, 50.7308954000473, 51.7294742166996, 51.47608861327171, 51.55064821243286, 50.89671470224857, 45.88363230228424, 45.55835835635662, 46.635045781731606, 47.105008363723755, 47.08397649228573, 46.6058861464262, 43.00178714096546, 41.34768269956112, 40.76354764401913, 41.62503361701965, 42.74545669555664, 43.48471462726593, 43.94884072244167, 45.88141702115536, 46.9253958016634, 46.98856741189957, 52.91467621922493, 58.577896133065224, 61.15429848432541, 62.776720225811005, 63.02558787167072, 65.59150278568268, 64.72819671034813, 64.56503346562386, 58.53986397385597, 55.513725355267525, 49.706702157855034, 47.48257130384445, 37.92540393769741, 19.55338217318058, 8.26368922367692, 10.448040962219238, 27.361241206526756, 48.55183392763138, 41.437179297208786, 48.059494346380234, 23.74059598892927, 36.76428124308586, 37.2748788446188, 43.69030639529228, 26.8033779412508, 45.56812763214111, 38.2966174185276, 35.86995743215084, 57.54201851785183, 0.5799180536996573, 0.056897493777796626, 0.07958230620715767, 0.037044420023448765, 0.10966330301016569, 0.05613155284663662, 0.06690311391139403, 0.0775075210549403, 0.03807111454079859, 0.057900138999684714, 0.20818823104491457, 0.047906942418194376, 0.039612462496734224, 0.0541081243136432, 0.03511457260174211, 0.01578980780323036, 0.07673228843486868, 0.051641611353261396, 0.1307936426019296, 0.07635265763383359, 0.0350808679650072, 0.07882434336352162, 0.10949625298962928, 0.30490920587908477, 1.7020438564941287, 60.999350398778915, 61.2589068710804, 50.253998190164566, 66.64742812514305, 61.24253734946251, 37.67788901925087, 25.707070268690586, 43.197647631168365, 60.48659831285477, 48.27205874025822, 61.338318809866905, 58.73611964285374, 30.642520934343338, 20.822550170123577, 50.784776508808136, 70.36863684654236, 66.21602967381477, 68.43811243772507, 65.62215194106102, 65.85904642939568, 61.82919166982174, 59.7669093310833, 57.180494517087936, 55.67172847688198, 56.44557975232601, 53.80902282893658, 51.16312600672245, 50.88307723402977, 50.26493780314922, 47.82808676362038, 48.64054016768932, 49.08243365585804, 50.47911711037159, 54.88885648548603, 51.77605591714382, 51.34801268577576, 51.01254388689995, 47.069172486662865, 44.92727302014828, 47.12550066411495, 47.913407385349274, 46.183364018797874, 46.30265101790428, 53.00397142767906, 55.63895523548126, 58.29213626682758, 57.27136664092541, 57.11191199719906, 56.09058000147343, 62.36689321696758, 56.26301854848862, 59.2523143440485, 55.905499532818794, 58.18587876856327, 56.289848908782005, 50.278487876057625, 45.80114632844925, 45.03454506397247, 45.325605645775795, 41.9704844802618, 35.31217396259308, 23.90729494392872, 28.212163746356964, 20.876511074602604, 21.09624568372965, 24.496288038790226, 27.373510748147964, 16.596213653683662, 21.247295178472996, 28.5115534812212, 30.172077678143978, 25.270350202918053, 21.868020370602608, 21.209109127521515, 18.133491463959217, 12.550633437931538, 6.859110267832875, 2.6079579954966903, 0.8199372806120664, 0.056725998292677104, 0.45464937400538474, 0.2523191075306386, 0.17705264239339158, 0.240616581577342, 0.5882755864877254, 2.90116926189512, 4.539093933999538, 10.927930511534214, 22.537569142878056, 22.260898388922215, 28.176956735551357, 31.097259633243084, 31.14098198711872, 36.88123896718025, 44.33473661541939, 48.43847841024399, 47.83272251486778, 47.25308261811733, 48.40614594519138, 51.50053270161152, 53.27635981142521, 53.19102019071579, 56.03680908679962, 51.64087817072868, 55.744551569223404, 51.63795992732048, 51.33907176554203, 48.64981546998024, 49.807624742388725, 50.96294514834881, 48.09783808887005, 48.740923181176186, 46.06804400682449, 45.25185540318489, 45.36048397421837, 46.09211191534996, 46.443604454398155, 45.00730812549591, 47.47816354036331, 50.08249059319496, 51.98678120970726, 51.485960483551025, 57.11325712502003, 61.85044772922993, 64.15978521108627, 66.56508654356003, 65.79362154006958, 67.53062233328819, 68.08419182896614, 68.15414607524872, 62.80144929885864, 60.283715799450874, 55.98900765180588, 51.21791526675224, 41.140844598412514, 21.086227521300316, 7.662301668897271, 12.205786742269993, 34.45718564093113, 59.16158281266689, 47.0491361618042, 55.426147654652596, 31.61776900291443, 38.53465564548969, 33.62883009016514, 46.86619497835636, 29.447891637682915, 49.31587032973766, 45.09771287441254, 43.42936299741268, 65.15473142266273, 0.3824611147865653, 0.0299519057807629, 0.03706429102749098, 0.04203312928439118, 0.0473588626482524, 0.02313986398803536, 0.043641816009767354, 0.020032482389069628, 0.012157762121205451, 0.06911518154083751, 0.12462053244234994, 0.19279629603261128, 0.18019235751125962, 0.1459445132059045, 0.08314519393024966, 0.1991821947740391, 0.25108827045187354, 0.11688960235915147, 0.3044758806936443, 0.18039005080936477, 0.21543803421081975, 0.33330570557154715, 0.23797057277988642, 0.5311913089826703, 3.003133228048682, 78.29491272568703, 70.82094937562943, 66.01227700710297, 73.53635966777802, 75.32424733042717, 50.39042226970196, 25.137908309698105, 40.13943873345852, 62.57275477051735, 55.661408230662346, 67.87872925400734, 63.81006717681885, 32.557416781783104, 29.516105577349663, 60.363997891545296, 72.46608629822731, 69.22807484865189, 71.23559072613716, 68.87472420930862, 65.73639661073685, 64.29017901420593, 58.62793944776058, 60.295061990618706, 56.164402440190315, 58.88240039348602, 54.80835780501366, 54.66400355100632, 52.29264199733734, 53.72898392379284, 50.96129983663559, 56.267578303813934, 55.37977114319801, 56.06212332844734, 58.32675240933895, 54.503036588430405, 55.86283542215824, 55.59576295316219, 50.07571555674076, 46.81454434990883, 49.34879556298256, 52.78986431658268, 45.9307611733675, 49.99056212604046, 56.27053454518318, 55.59955134987831, 59.122327119112015, 57.94728957116604, 61.251812651753426, 59.22173358500004, 63.8434673845768, 57.162631675601006, 62.15598553419113, 57.28082813322544, 60.88548190891743, 57.33820505440235, 55.606603771448135, 48.71402822434902, 46.295321211218834, 45.83976365625858, 39.991014897823334, 32.76293635368347, 26.029693856835365, 38.06300975382328, 30.345874652266502, 29.471746757626534, 30.859700180590153, 31.614307388663292, 32.39644981920719, 35.35089388489723, 40.069598481059074, 41.07983887195587, 42.30819135904312, 35.77064976096153, 36.74574963748455, 34.04825538396835, 22.513187751173973, 17.800469733774662, 8.674915507435799, 1.2924136058427393, 0.22026405727956444, 0.7492202252615243, 0.38701695157215, 0.26465179107617587, 0.5595589242875576, 2.5110057229176164, 7.5042235013097525, 7.48297456651926, 20.25235276669264, 25.301546528935432, 27.28955615311861, 36.28912813961506, 37.01469920575619, 34.95343901216984, 45.32638840377331, 47.210612297058105, 52.89745174348354, 49.881500378251076, 51.58421941101551, 50.554292276501656, 57.15160086750984, 56.32726930081844, 55.209281891584396, 57.626890763640404, 57.20604054629803, 58.534738048911095, 54.07131515443325, 52.50993713736534, 53.03725004196167, 52.334774136543274, 55.171352326869965, 53.459574580192566, 52.54245199263096, 47.40838408470154, 48.41602921485901, 47.531307488679886, 48.410701900720596, 47.4639181047678, 49.844231978058815, 52.10650518536568, 52.17226445674896, 54.55659471452236, 53.23013909161091, 61.04777880012989, 62.874716967344284, 68.47902104258537, 68.65182057023048, 67.11020529270172, 68.50238218903542, 71.84092864394188, 71.8265350162983, 67.03650444746017, 64.01113718748093, 60.03093056380749, 58.82257640361786, 46.59545190632343, 23.652752302587032, 10.403842683881521, 12.977685872465372, 36.155968084931374, 63.75862553715706, 53.798542991280556, 58.08216713368893, 34.23142835497856, 50.562275648117065, 51.19708098471165, 59.641022086143494, 38.88117045164108, 48.175973296165466, 52.661909982562065, 54.01447020471096, 76.8773227930069, 1.103270323947072, 0.16422157699707896, 0.17810542340157554, 0.1186719442193862, 0.22133291320642456, 0.31212994654197246, 0.2267905930057168, 0.14176433673128486, 0.19054727687034756, 0.17291326919803396, 0.2839428512379527], [0.06372087373165414, 0.024549378686060663, 0.011963450233452022, 0.010593108872853918, 0.04159051241003908, 0.06130214023869485, 0.057249557503382675, 0.03946910554077476, 0.07871382273151539, 0.07209834802779369, 0.029249592880660202, 0.10966467598336749, 0.12699448474450037, 0.11052727422793396, 37.57342882454395, 63.50762240588665, 30.573813021183014, 47.76740401983261, 63.25396701693535, 45.40675409138203, 25.91641053557396, 27.44056385010481, 34.78337153792381, 34.38917689025402, 47.14695431292057, 54.50949244201183, 28.545612953603268, 6.548425639048219, 18.1138389185071, 56.98059104382992, 75.03181502223015, 65.09189799427986, 66.01339414715767, 62.953661531209946, 65.51573485136032, 63.29231075942516, 61.52064062654972, 59.21289525926113, 59.724442809820175, 58.87275271117687, 54.899313524365425, 51.06672137975693, 49.08443234860897, 47.04360365867615, 44.50399853289127, 45.076684802770615, 44.972213208675385, 47.4270448833704, 48.85905124247074, 49.01781812310219, 45.92035353183746, 44.96902137994766, 45.09856402873993, 42.87788338959217, 44.916166216135025, 43.47160913050175, 44.96494419872761, 53.782542049884796, 56.560344994068146, 54.50725436210632, 57.51023702323437, 50.65584182739258, 55.006699562072754, 54.819263219833374, 53.842499032616615, 52.39598125219345, 51.672701463103294, 51.98317900300026, 52.61129289865494, 47.88843512535095, 44.60276663303375, 40.15378296375275, 42.46381960809231, 43.60253490507603, 41.644218787550926, 30.766268894076347, 25.684248693287373, 20.71017500013113, 16.38283420354128, 22.2916292399168, 17.264079116284847, 7.049074899405241, 11.139179226011038, 15.573315192013979, 15.139055494219065, 14.864126946777105, 11.33524015545845, 12.782257609069347, 8.677410073578358, 4.097107350826263, 1.8607298727147281, 1.1899836896918714, 0.10504899240913801, 0.1474785918253474, 0.18994670128449798, 0.08719504185137339, 0.15857375896302983, 0.24061855569016188, 1.4825132489204407, 1.329382297117263, 1.9589664763770998, 7.073908941820264, 16.532758958637714, 16.669257134199142, 20.31056374311447, 24.459148831665516, 26.458588242530823, 31.742149628698826, 37.270813062787056, 43.4346105158329, 41.632811799645424, 41.93703107535839, 44.352322071790695, 46.08584225177765, 47.376781180500984, 48.348719626665115, 51.902748718857765, 52.39009536802769, 50.57286947965622, 51.02642834186554, 49.00104962289333, 44.95463155210018, 46.015899404883385, 46.2713672965765, 43.65599803626537, 43.921402394771576, 43.852610886096954, 43.5032120347023, 43.51471021771431, 44.342134818434715, 41.05245754122734, 42.72056423127651, 50.25400958955288, 54.93619814515114, 56.63031063973904, 54.650632068514824, 57.70695626735687, 58.67493912577629, 59.86987620592117, 62.824776247143745, 65.23072734475136, 62.71865554153919, 64.11240175366402, 58.22542704641819, 51.148363798856735, 54.53171364963055, 51.442046239972115, 41.398634165525436, 35.69743908941746, 13.64462798461318, 4.065348654985428, 7.1243692841380835, 37.28566266596317, 47.47141890227795, 45.16918323934078, 33.476085886359215, 32.52559348940849, 40.05510985851288, 33.78168448805809, 40.38248509168625, 26.033261865377426, 10.692391600459814, 34.284538105130196, 51.723295748233795, 53.004959374666214, 0.44946072273887694, 0.06414829884306528, 0.02235656422271859, 0.036723960656672716, 0.09982839910662733, 0.12180843099486083, 0.03303978002804797, 0.025032006597029977, 0.01609571736480575, 0.03145399226923473, 0.01073970808647573, 0.0749269177322276, 0.046417938137892634, 0.023625104258826468, 0.013565517001552507, 0.019515734238666482, 0.041218425540137105, 0.05195589976210613, 0.022586008453799877, 0.0787212367868051, 0.015760262904223055, 0.03181851665431168, 0.03223921048629563, 0.06449914173572324, 0.21917182370088995, 40.72061374783516, 68.82193744182587, 34.644010215997696, 53.782154470682144, 65.33287346363068, 43.969602808356285, 31.47718034684658, 35.247060656547546, 37.30183459818363, 42.33997665345669, 52.93380819261074, 62.120031863451004, 31.59385308623314, 9.443323574960232, 10.647369716316462, 47.660200372338295, 75.46967312693596, 67.64977633953094, 68.36986050009727, 67.86736026406288, 68.17778080701828, 66.57557398080826, 63.524580895900726, 63.990838676691055, 63.3451659232378, 62.23799653351307, 58.52358564734459, 55.69866523146629, 52.85070285201073, 51.04050658643246, 48.04155930876732, 46.826787292957306, 46.362938582897186, 49.700048714876175, 52.71431677043438, 50.61589077115059, 49.67117786407471, 48.745064958930016, 47.33127482235432, 47.36399486660957, 46.999165043234825, 46.67250797152519, 50.648740008473396, 57.2891116887331, 56.92693792283535, 56.26554161310196, 58.87372925877571, 54.31229442358017, 57.21400871872902, 57.63222947716713, 56.877977550029755, 54.40525263547897, 54.76171150803566, 56.202913373708725, 55.296103432774544, 52.339972257614136, 49.683815985918045, 43.75647224485874, 45.232780426740646, 42.87394680082798, 43.40717598795891, 43.0567017942667, 39.42226901650429, 34.45308946073055, 28.03090777248144, 35.31114801764488, 22.747084200382233, 7.542441850528121, 6.16384020075202, 9.645105097442865, 9.515855982899666, 6.736112767830491, 6.4571369625627995, 6.084993006661534, 7.020041607320309, 3.3603090746328235, 1.8242372246459126, 1.4360183500684798, 0.15579276834614575, 0.17131955159129575, 0.18695088860113174, 0.06049745177733712, 0.12427305890014395, 0.13417921640211716, 1.7833573557436466, 3.10302488040179, 7.101497361436486, 13.748461212962866, 22.20920406281948, 23.24552435427904, 28.290582038462162, 30.174752734601498, 32.89127826690674, 37.59961701929569, 44.692502617836, 48.66973400115967, 46.79731987416744, 47.366388738155365, 50.46864867210388, 50.70867419242859, 53.47755141556263, 53.9462448656559, 53.94189789891243, 56.36716715991497, 55.50509601831436, 54.79119032621384, 51.7488531768322, 47.624527886509895, 46.85332886874676, 46.859389543533325, 46.08292780816555, 46.13477222621441, 46.638750582933426, 47.71187759935856, 47.06626944243908, 46.589767411351204, 46.874516531825066, 48.46307069063187, 57.827972173690796, 59.28845040500164, 60.0227078050375, 59.61111769080162, 60.969970375299454, 61.30858540534973, 63.696358278393745, 64.01251271367073, 67.25392118096352, 64.94616061449051, 69.1783507168293, 59.55038174986839, 48.503226935863495, 55.034244284033775, 52.79817447066307, 45.23431554436684, 35.97007066011429, 11.676387749612331, 3.929658648557961, 10.815375801175833, 49.923450127243996, 52.58949726819992, 51.60587824881077, 38.177467212080956, 35.02107918262482, 33.99582959711552, 32.527626380324364, 40.782900005578995, 34.40428487956524, 17.07885805517435, 34.58775043487549, 57.706804275512695, 62.147549986839294, 1.2631826056167483, 0.116749789158348, 0.04554391452984419, 0.08085997280431911, 0.06738155425409786, 0.035443529559415765, 0.0839902923326008, 0.03713098783919122, 0.053314030010369606, 0.04036025049572345, 0.03747012706298847, 0.17146290483651683, 0.11269662383710966, 0.10560392591287382, 0.05977221022476442, 0.12314229301409796, 0.26732785685453564, 0.12414396973326802, 0.1426609550253488, 0.2456929162144661, 0.12995525321457535, 0.1631665843888186, 0.21512952342163771, 0.280420885537751, 0.3415863518603146, 55.86021736264229, 76.69183194637299, 41.08866959810257, 63.116220608353615, 77.22469255328178, 64.17357087135315, 34.19528849422932, 36.28543473780155, 43.30211542546749, 45.085405334830284, 59.4619756937027, 65.26902928948402, 37.00683742761612, 10.75469970703125, 21.687336266040802, 64.08513441681862, 77.58776307106018, 68.2103830575943, 73.06432619690895, 69.74733978509903, 70.86478382349014, 66.71811193227768, 65.48860430717468, 65.31287133693695, 65.5600480735302, 66.48146063089371, 59.4782692193985, 57.63073615729809, 54.53808970749378, 53.04138422012329, 50.53026996552944, 51.47430270910263, 50.46747073531151, 54.25117090344429, 55.659101754426956, 56.7549629509449, 53.865309208631516, 51.34104385972023, 50.26023365557194, 49.531881138682365, 50.50329141318798, 50.246949568390846, 51.92988306283951, 59.136253371834755, 58.77188332378864, 56.36587902903557, 60.87478548288345, 55.02060681581497, 59.784236401319504, 60.7879563421011, 60.61948098242283, 57.533404380083084, 59.663182497024536, 60.52601359784603, 57.27815307676792, 56.85998551547527, 52.80707359313965, 45.000590085983276, 46.923651695251465, 45.888112261891365, 41.950360760092735, 42.265952825546265, 40.10419562458992, 34.66403514146805, 31.751022152602673, 35.78174516558647, 25.393499694764614, 12.47028959915042, 16.10260684043169, 28.138546496629715, 27.588516511023045, 30.395220704376698, 24.768302142620087, 23.0281950160861, 15.002923049032688, 11.704896669834852, 9.32397197932005, 4.419235065579414, 0.4471663583535701, 0.2446463395608589, 0.4043506714515388, 0.18021531956037506, 0.1569205359555781, 0.4747878183843568, 6.017319587990642, 9.971715621650219, 13.093426711857319, 24.0613329783082, 28.37276592850685, 29.10873133689165, 36.77933983504772, 35.24712145328522, 37.55328990519047, 44.51956249773502, 49.93463292717934, 53.33965301513672, 49.59321744740009, 51.55224792659283, 57.095067501068115, 51.78467005491257, 54.52274613082409, 56.57261073589325, 57.470703944563866, 58.898215144872665, 58.70575927197933, 58.06183062493801, 53.557734712958336, 51.8731103092432, 50.02774693071842, 49.97791260480881, 48.804816752672195, 49.09106679260731, 50.340382754802704, 48.57174105942249, 49.49514091014862, 50.831783786416054, 46.72548092901707, 49.39145587384701, 58.869059309363365, 62.01061673462391, 61.860676780343056, 61.62080705165863, 64.712473154068, 65.34222096204758, 66.07502683997154, 68.43867480754852, 69.72523257136345, 65.72747468948364, 70.48828482627869, 65.94501301646233, 63.69855836033821, 64.74493861198425, 60.67423224449158, 48.60568463802338, 44.45070259273052, 16.16614893078804, 5.791349513456225, 10.61507049947977, 50.1823378354311, 60.950249433517456, 55.761050283908844, 42.964100763201714, 42.63443045318127, 48.78293752670288, 48.44433009624481, 53.30966502428055, 39.981222823262215, 15.038789324462414, 46.17692716419697, 70.84751754999161, 70.58001950383186, 1.5001289849169552, 0.17284819768974558, 0.13987910351715982, 0.1610994804650545, 0.19570742966607213, 0.3255395754240453, 0.19577910628868267, 0.13832200347678736, 0.1501740128151141, 0.12517402617959306, 0.13272475538542494], [0.029837119654985145, 0.05579324111749884, 0.09542932617478073, 0.06183923251228407, 0.09845328851952218, 0.0381302711321041, 0.01674040249781683, 0.020793163348571397, 0.0078416501673928, 0.03672613514936529, 0.027534291075426154, 0.04597713581460994, 0.2731139963725582, 0.17513272119686007, 22.810172215104103, 72.16709554195404, 36.77735634148121, 46.679036021232605, 59.39465470612049, 39.30086553096771, 29.826985895633698, 20.431452356278896, 28.874984979629517, 31.400768347084522, 48.783849477767944, 55.20053096115589, 37.96489141881466, 6.083502061665058, 0.9522768168244511, 6.5528386272490025, 44.03073772788048, 68.78754928708076, 73.87907847762108, 66.59011200070381, 68.44187423586845, 63.544028252363205, 65.44404029846191, 63.397245928645134, 63.15747119486332, 62.32047490775585, 62.48857028782368, 58.55991169810295, 55.23999944329262, 52.928195893764496, 52.1369681507349, 46.18945889174938, 45.143451020121574, 46.1584335565567, 47.0891822129488, 45.153474882245064, 48.45134451985359, 44.442943409085274, 43.54824721813202, 44.94704715907574, 45.56666851043701, 43.88520173728466, 53.23000989854336, 54.687395095825195, 53.95968474447727, 58.24999272823334, 54.067948535084724, 50.57692006230354, 54.10781979560852, 54.40442807972431, 53.58143784105778, 50.92527776956558, 53.526621982455254, 50.810508728027344, 50.50669223070145, 48.91056887805462, 44.24115903675556, 40.13934753835201, 41.3086511939764, 40.0793981552124, 40.4308070987463, 35.983958914875984, 42.44485102593899, 32.52543389797211, 30.089960284531116, 33.84409613907337, 18.50071705877781, 2.88960553240031, 1.7108141421340406, 2.9388470901176333, 2.0770148606970906, 3.0030351458117366, 1.7479915847070515, 1.429642648436129, 2.4098553881049156, 0.9711705311201513, 0.0875800458015874, 0.11503977701067924, 0.2043007279280573, 0.1315603405237198, 0.14353265200043097, 0.07824954998795874, 0.14275501482188702, 0.8502026565838605, 1.7084237141534686, 2.3253776086494327, 4.9298678152263165, 8.269372768700123, 12.948480639606714, 16.547597162425518, 19.69983771443367, 24.386882409453392, 22.834166027605534, 31.7405404150486, 39.96854290366173, 40.98917953670025, 40.509968250989914, 40.80456644296646, 41.45687364041805, 44.14136879146099, 48.31454046070576, 49.946799874305725, 49.84326682984829, 53.456074967980385, 52.50062383711338, 52.40883596241474, 48.53138342499733, 46.24048635363579, 42.525326907634735, 42.87449397146702, 45.441491827368736, 42.73242339491844, 45.29609642922878, 46.365484446287155, 45.460638999938965, 42.762096002697945, 45.68742983043194, 52.861163690686226, 58.60798291862011, 59.57120083272457, 61.58448860049248, 57.21616320312023, 56.01074628531933, 60.180144757032394, 60.01466363668442, 60.40369436144829, 63.30602042376995, 65.89940786361694, 68.48837614059448, 47.457234263420105, 34.18766990303993, 39.65085335075855, 40.512757301330566, 36.29529520869255, 22.10385661572218, 5.368616497144103, 1.937205281574279, 15.314218495041132, 47.54986569285393, 48.52806240320206, 41.50009632110596, 24.173077382147312, 41.51024557650089, 44.127412140369415, 32.915919944643974, 37.14989975094795, 22.010383531451225, 25.60341753065586, 42.14579567313194, 37.688201665878296, 60.83326891064644, 0.9212945855688304, 0.03312841472506989, 0.08321436209371313, 0.012197388168715406, 0.04786903351487126, 0.1857112199650146, 0.030984927107056137, 0.061113590199965984, 0.033073878003051504, 0.06024613088811748, 0.031657359286327846, 0.0665746838785708, 0.015329063044191571, 0.043375592795200646, 0.06174398156872485, 0.07576306583359838, 0.08578368477174081, 0.014161586823320249, 0.055871582226245664, 0.02705696395423729, 0.014033140541869216, 0.07234570584842004, 0.056253817965625785, 0.269664820516482, 0.16288474638713524, 28.969900086522102, 77.6985727250576, 40.91569148004055, 56.70113883912563, 62.125530168414116, 40.47702021896839, 33.230930641293526, 28.873009085655212, 36.58443309366703, 36.520938500761986, 54.478991478681564, 60.74428528547287, 45.91379888355732, 8.791523650288582, 2.084303582087159, 4.690927611663938, 30.433792434632778, 61.83865316212177, 75.21400764584541, 69.69555616378784, 71.12916603684425, 65.09335711598396, 65.70224404335022, 65.99818736314774, 65.8140416443348, 64.91418153047562, 65.6809575855732, 62.05067798495293, 60.88141232728958, 59.05146472156048, 57.47607685625553, 49.77825611829758, 46.57002367079258, 50.37354737520218, 48.847211077809334, 48.68136137723923, 51.95785716176033, 47.904747650027275, 46.63457840681076, 46.94452777504921, 47.65090987086296, 49.090413227677345, 57.36915439367294, 58.7261413782835, 57.8070542961359, 61.923213824629784, 55.75541138648987, 54.0891095995903, 59.83998700976372, 57.1064592897892, 57.568761482834816, 54.986427649855614, 56.535931304097176, 53.126195669174194, 51.69120267033577, 53.208981826901436, 47.29244090616703, 43.66569511592388, 41.18169620633125, 43.90429191291332, 40.56902468204498, 39.978384375572205, 41.12727552652359, 35.57963401079178, 30.889876261353493, 36.88247390091419, 30.91975025832653, 5.582853276282549, 1.426112400367856, 1.4060814189724624, 3.463894366286695, 0.8939780294895172, 0.329577571246773, 0.5251724319532514, 0.24930711602792144, 1.6274915006943047, 0.2145894180284813, 0.11776269457186572, 0.12118461134377867, 0.12621430942090228, 0.1707979553611949, 0.06020836670359131, 0.09315715200500563, 0.36229265795554966, 1.6700429236516356, 2.574290377087891, 7.392518995329738, 16.006544195115566, 20.67536886781454, 23.603873625397682, 27.596382088959217, 29.416522420942783, 30.982317700982094, 38.15597176551819, 45.567185282707214, 46.75529792904854, 46.10659293830395, 42.88809724152088, 46.64066568017006, 49.340850189328194, 51.442167833447456, 54.366570711135864, 54.669026881456375, 52.79139943420887, 56.40573889017105, 54.62700113654137, 53.30725595355034, 49.723561853170395, 45.45454792678356, 47.72744536399841, 47.580013275146484, 48.346842527389526, 48.34233596920967, 47.55096763372421, 47.057742699980736, 46.443878039717674, 50.33591419458389, 58.45292083919048, 61.22039973735809, 60.32664969563484, 63.501151353120804, 60.76893076300621, 59.45854067802429, 63.260764852166176, 63.893320709466934, 63.51611874997616, 65.5062885582447, 67.12230384349823, 69.6228888630867, 54.06224504113197, 44.56380732357502, 42.92717054486275, 40.925016179680824, 31.88415750861168, 18.57794601470232, 3.8062239345163107, 3.7547407345846295, 20.850554667413235, 51.941464841365814, 54.11628194153309, 47.68546901643276, 24.468999803066254, 39.6571534126997, 35.226161777973175, 35.96897631883621, 36.90913327038288, 26.89881931990385, 23.692832551896572, 40.84216922521591, 47.7665376663208, 64.8738580942154, 1.2194906501099467, 0.14251334185246378, 0.09533474687486887, 0.0051881034687539795, 0.09737335232784972, 0.08961226136307232, 0.06164998485473916, 0.10167304426431656, 0.04430300650710706, 0.10933919227682054, 0.06478187031461857, 0.1574560400331393, 0.09569264759193175, 0.1870350184617564, 0.1639631760190241, 0.16412132768891752, 0.17100790893891826, 0.18892727239290252, 0.1676108912215568, 0.1022241408645641, 0.09485002054134384, 0.26749014970846474, 0.16296515066642314, 0.33155821496620774, 0.43204548535868526, 38.42552550137043, 87.51951053738594, 50.561853870749474, 59.517437517642975, 73.2158924639225, 54.111072421073914, 42.148577123880386, 28.05568054318428, 37.396859899163246, 42.48417891561985, 59.90958407521248, 67.4618536233902, 47.15802691876888, 10.71806587278843, 2.1474875416606665, 10.912663880735636, 55.62907576560974, 74.30741429328918, 75.6005609035492, 69.91674229502678, 75.4421018064022, 71.08817383646965, 69.2371791601181, 68.38155627250671, 67.0115701854229, 67.77069345116615, 68.12134623527527, 65.1511824131012, 59.87208388745785, 59.79295693337917, 59.37914773821831, 51.75201840698719, 49.40993808209896, 52.92882665991783, 52.06846162676811, 54.13952149450779, 54.4111081212759, 51.92294843494892, 50.2709224820137, 49.36847470700741, 51.2182230502367, 48.83417397737503, 58.42238187789917, 61.72475807368755, 58.943569511175156, 63.6043956130743, 57.0986583083868, 53.25464777648449, 61.49279572069645, 59.41444404423237, 60.843942537903786, 57.99529239535332, 60.56411035358906, 57.664083167910576, 53.37751418352127, 54.87989656627178, 51.316538974642754, 47.256977409124374, 42.650214806199074, 46.771553456783295, 43.93708795309067, 43.53495933115482, 51.4554139226675, 41.857714131474495, 36.2710677087307, 42.65485055744648, 29.49022326618433, 6.400315286591649, 4.077722216024995, 9.454931952059269, 12.983525209128857, 11.142003424465656, 8.702141046524048, 5.3750015795230865, 5.031353244557977, 6.003988003358245, 1.2921906053088605, 0.4711996531113982, 0.470849359408021, 0.5100145109463483, 0.39745858346577734, 0.26805842702742666, 0.3834680904401466, 2.399422097951174, 3.909732992760837, 5.862138764932752, 11.507174279540777, 25.475694984197617, 27.90308453142643, 32.6818411052227, 34.602934420108795, 37.16816157102585, 37.246311977505684, 43.81134510040283, 51.650757640600204, 51.24701790511608, 50.91365799307823, 46.561762914061546, 50.243381559848785, 52.70718455314636, 55.77031038701534, 55.54307118058205, 56.059493869543076, 57.41676203906536, 57.94806852936745, 56.45662195980549, 53.42623136937618, 52.76543162763119, 48.16290959715843, 47.80200116336346, 50.625774040818214, 49.004051461815834, 50.518798381090164, 50.40317438542843, 50.93139164149761, 49.98703211545944, 52.76245258748531, 57.91025675833225, 63.97677183151245, 62.90253907442093, 68.0968527495861, 63.43599624931812, 60.81847630441189, 67.15156227350235, 63.66822838783264, 66.97797238826752, 68.1910040974617, 70.41714504361153, 74.19295683503151, 64.46931660175323, 53.147941902279854, 51.50736853480339, 49.86841008067131, 42.504154443740845, 26.82146117091179, 7.297711707651615, 4.007878638803959, 21.211947575211525, 60.19913613796234, 62.69541218876839, 52.076353803277016, 31.766589917242527, 51.57642222940922, 58.4557668864727, 45.51982842385769, 50.115172639489174, 31.976055577397346, 33.791043385863304, 58.267483189702034, 52.804831713438034, 81.38514250516891, 1.3135152985341847, 0.24065922538284212, 0.16140221734531224, 0.1356247568037361, 0.2153156095300801, 0.32287716516293585, 0.15661589917726815, 0.1748737710295245, 0.10090272466186434, 0.29925297189038247, 0.1590525481151417], [0.016656608459015843, 0.00944194969633827, 0.04984127612260636, 0.07060184434521943, 0.011761250243580434, 0.04437116163899191, 0.048038098466349766, 0.0766619699425064, 0.02738942941505229, 0.06512985593872145, 0.05369576480006799, 0.03284497368440498, 0.1360834634397179, 0.06773743632948026, 30.000133104622364, 59.682424664497375, 52.67234042286873, 44.968740195035934, 58.57942745089531, 40.198673754930496, 35.76536804437637, 31.99750542640686, 27.572984844446182, 27.51230400055647, 36.768134236335754, 53.357272669672966, 44.989236295223236, 17.63059224933386, 1.4094064780510962, 5.16459546983242, 6.62622076459229, 16.172885969281197, 44.63433913886547, 67.74026468396187, 67.04930976033211, 69.14894789457321, 63.288761749863625, 67.13756382465363, 65.34998014569283, 63.1766639649868, 61.81838884949684, 63.578868582844734, 61.48445896804333, 61.13805815577507, 58.92043635249138, 54.49079364538193, 46.44781082868576, 46.49723097681999, 47.575331926345825, 45.359298437833786, 46.09074778854847, 46.34976468980312, 42.31370106339455, 44.713876470923424, 43.39608438313007, 48.84051963686943, 51.829199865460396, 54.29289646446705, 55.44578120112419, 53.784221559762955, 47.00259625911713, 53.24310399591923, 56.80114187300205, 53.941491320729256, 52.186407297849655, 51.94262757897377, 52.02028401196003, 49.214795753359795, 48.7210426479578, 49.71536949276924, 47.09948346018791, 40.17285414040089, 37.34936624765396, 39.14436712861061, 35.97553476691246, 36.43882490694523, 25.41383620351553, 19.930774122476578, 18.261271007359028, 22.671565152704716, 25.926713682711124, 5.708913411945105, 0.4841330013005063, 0.5147583188954741, 0.5500178737565875, 0.9601143118925393, 1.7502917675301433, 0.1941558363614604, 0.259513130877167, 0.3375043615233153, 0.2509448875207454, 0.019492633036861662, 0.10606281808577478, 0.27391133015044034, 0.1795054553076625, 0.09487466726568528, 0.5309855856467038, 1.2178491381928325, 3.0238292925059795, 4.257917096838355, 3.237957777455449, 9.818097464740276, 14.442449323832989, 13.105537611991167, 17.446395233273506, 22.697232775390148, 26.408522129058838, 32.927900701761246, 36.481963992118835, 37.65207700431347, 39.07595179975033, 40.283112823963165, 40.57544253766537, 45.88849224150181, 49.19297352433205, 51.43885441124439, 47.623034566640854, 45.48449032008648, 50.83323910832405, 50.534157156944275, 49.73165161907673, 45.90887434780598, 43.04987736046314, 44.588319808244705, 44.7965220361948, 45.482575222849846, 46.672416776418686, 45.57499386370182, 46.1198466271162, 47.2771505266428, 52.00119763612747, 56.804060116410255, 58.36562432348728, 61.231704130768776, 58.90671528875828, 60.069764479994774, 58.26432555913925, 60.62826991081238, 60.727334395051, 60.553311333060265, 59.98625636100769, 64.82900530099869, 60.391899794340134, 47.43752472102642, 39.7561115026474, 37.141164019703865, 31.536128483712673, 18.862208761274815, 8.2355878315866, 1.1182634881697595, 4.417575504630804, 30.561798065900803, 45.51582723855972, 52.652923464775085, 21.59790426492691, 20.029105246067047, 33.26712749898434, 35.0300657004118, 30.935842394828796, 31.947849690914154, 25.648302622139454, 40.30148483812809, 50.38310006260872, 45.0048990547657, 55.46557813882828, 0.6394955317955464, 0.05073575703136157, 0.05988443779642694, 0.028916717383253854, 0.028769161726813763, 0.116769619344268, 0.0345317528990563, 0.03934967542591039, 0.0577468335541198, 0.02515998625312932, 0.028810853727918584, 0.14428245864110067, 0.03868904153932817, 0.05416970401711296, 0.08109056550893001, 0.037959922265144996, 0.08742570134927519, 0.04153269168455154, 0.07950988743687049, 0.10819973584148102, 0.10824770084582269, 0.13794288475764915, 0.03989562152128201, 0.12073787554982118, 0.06349240356939845, 38.80231708288193, 63.667502626776695, 56.46984525024891, 50.565893054008484, 63.49732495844364, 39.785529524087906, 35.22812247276306, 36.76176197826862, 36.637964621186256, 33.451071828603745, 41.29882872104645, 56.96065731346607, 48.74975010752678, 23.93900614231825, 3.7769693043082952, 6.544829132035375, 10.447456743568182, 17.5041426345706, 37.01176576316357, 66.30499050021172, 72.66248255968094, 71.48774519562721, 65.34008547663689, 71.55500158667564, 68.79155427217484, 67.84108847379684, 66.22520238161087, 66.3078099489212, 63.99643957614899, 63.505878299474716, 63.22161175310612, 59.15596291422844, 51.321471109986305, 51.008956879377365, 50.53805194795132, 49.50321927666664, 50.269569754600525, 50.097792372107506, 45.084162801504135, 47.12355136871338, 46.273308992385864, 51.100497767329216, 55.98991200327873, 57.230864614248276, 57.76293866336346, 56.15382760763168, 47.66488932073116, 56.417240872979164, 59.92431588470936, 60.001884922385216, 54.99960534274578, 57.215068861842155, 53.58234599232674, 52.221847996115685, 52.966509237885475, 54.86286208033562, 49.71448794007301, 44.66732516884804, 42.082050293684006, 41.860894560813904, 39.14081051945686, 42.69612394273281, 31.611229553818703, 23.422691747546196, 20.783854946494102, 24.263858310878277, 25.53827192634344, 3.449248527176678, 1.4954130817204714, 0.5313723930157721, 0.19958099524956197, 0.9589651704300195, 0.3781658905791119, 0.11959348383243196, 0.07952182859298773, 0.11542888503754511, 0.5646276741754264, 0.04161118122283369, 0.18424543377477676, 0.2007897905423306, 0.13641358556924388, 0.14611474703997374, 0.3861604240955785, 2.225505905225873, 5.438591167330742, 9.14028413593769, 11.440588552504778, 21.158096864819527, 22.653761208057404, 22.82153930515051, 25.790257304906845, 31.119893118739128, 33.24172966182232, 40.31746678054333, 44.599536806344986, 44.47535566985607, 44.19165909290314, 43.605662137269974, 44.776432514190674, 48.45523551106453, 52.79969438910484, 54.553828462958336, 52.26311758160591, 47.81207822263241, 54.556837901473045, 55.126400738954544, 54.09721456468105, 47.51018442213535, 46.150400787591934, 47.72535167634487, 47.13916093111038, 48.49698767066002, 48.73156048357487, 47.55990095436573, 47.139901891350746, 50.315893068909645, 55.85787668824196, 57.676352709531784, 62.445700988173485, 64.86930593848228, 61.843440905213356, 62.736202999949455, 61.14724986255169, 62.34286330640316, 63.17970000207424, 63.575748950242996, 60.57699926197529, 65.38024172186852, 61.144046634435654, 56.2773247808218, 51.097872108221054, 48.55076998472214, 38.03290776908398, 18.883905597031116, 6.76405219361186, 0.7889868132770061, 5.7265031430870295, 35.664190873503685, 47.80404545366764, 55.059163346886635, 25.17133891582489, 20.916469730436802, 27.1837280318141, 24.68371868133545, 33.933657333254814, 36.50047279894352, 33.63471977412701, 34.69329357147217, 49.05843034386635, 52.81663008034229, 64.95839595794678, 1.6748380288481712, 0.016065085219452158, 0.016198703342524823, 0.061593151185661554, 0.03744496083527338, 0.08816597881377675, 0.08092453223071061, 0.05147348521859385, 0.06281093388679437, 0.07715742030995898, 0.02325831817870494, 0.23452576075214893, 0.10509145809919573, 0.16600418603047729, 0.20524267660221085, 0.11472397833131254, 0.16873536369530484, 0.12280837108846754, 0.1898260132293217, 0.22626467747613788, 0.18340811308007687, 0.22015451628249139, 0.30600066762417555, 0.33876562665682286, 0.21480112307472154, 44.845250621438026, 74.64405342936516, 67.64663770794868, 55.58986186981201, 70.76263770461082, 53.113470152020454, 44.356832429766655, 45.39226546883583, 35.475948974490166, 38.7869469076395, 45.97470961511135, 65.07614403963089, 53.942589461803436, 25.325637236237526, 4.753470830619335, 7.530310051515698, 8.137366902083158, 25.96604347229004, 59.871871098876, 81.17765843868256, 74.43567261099815, 73.96642819046974, 65.69985777139664, 71.79702579975128, 71.39200553297997, 71.10040158033371, 68.36990609765053, 69.06818702816963, 67.50295221805573, 67.70440980792046, 66.49361997842789, 61.44527547061443, 54.848890230059624, 56.95002928376198, 56.32981136441231, 53.47730442881584, 53.730009868741035, 52.8390184789896, 45.90282127261162, 48.53220038115978, 47.98303484916687, 54.904595240950584, 56.36082910001278, 58.81237395107746, 58.55625629425049, 57.66238085925579, 48.48998844623566, 58.38579744100571, 62.232049852609634, 62.762246802449226, 56.84225186705589, 61.27200476825237, 56.12547732889652, 53.13911497592926, 53.700614646077156, 57.14645974338055, 54.50864888727665, 47.806785106658936, 42.326700165867805, 45.516609996557236, 41.45603388547897, 43.82682926952839, 35.91673672199249, 30.053522139787674, 24.32370699942112, 26.611784622073174, 34.75198522210121, 12.004543840885162, 11.07514601200819, 1.6147663397714496, 0.6022448244038969, 3.0542010627686977, 1.9096019002608955, 0.4020531306741759, 0.7021697249729186, 0.42255549458786845, 1.0291461576707661, 0.13784885464701802, 0.3933794132899493, 0.4642828367650509, 0.5747039616107941, 0.4710731317754835, 0.7889127766247839, 3.855430819094181, 9.512101784348488, 12.095657251775265, 14.247354492545128, 30.760265216231346, 31.953306198120117, 29.161113426089287, 35.40604032576084, 37.05634497106075, 40.58732829988003, 45.04787854850292, 49.58750635385513, 48.86548429727554, 48.190233930945396, 47.14343570172787, 50.2723778039217, 55.01430295407772, 56.93519487977028, 57.8589291125536, 53.87729376554489, 50.57657428085804, 57.16750681400299, 57.660188376903534, 57.49290615320206, 50.3531538695097, 47.21493646502495, 50.01819044351578, 50.964571461081505, 51.60284981131554, 51.5975870937109, 49.51013870537281, 51.880136132240295, 55.87861977517605, 56.336848586797714, 60.49432709813118, 64.55605834722519, 67.29948073625565, 63.86213198304176, 64.65067327022552, 63.776355385780334, 65.42983666062355, 64.08378928899765, 63.74504506587982, 61.84102803468704, 67.17215716838837, 66.05210646986961, 57.700268626213074, 52.88050465285778, 49.09351386129856, 41.278511211276054, 24.697175659239292, 11.702444851398468, 2.372622136026621, 5.997827108949423, 40.67342787981033, 56.78460136055946, 66.91507056355476, 31.721936613321304, 27.33968686312437, 41.734779328107834, 47.90010429918766, 42.48285658657551, 47.954749166965485, 39.36231963336468, 52.5130719691515, 67.7597576379776, 60.65963722765446, 76.90473452210426, 2.2783242585137486, 0.15267024136846885, 0.15578114631352946, 0.09870124005828984, 0.09270230453694239, 0.4051611857721582, 0.09909626300213858, 0.2790057583479211, 0.21768105681985617, 0.15941689809551463, 0.0988439105276484], [0.07931860629469156, 0.06519656017189845, 0.05240857644821517, 0.06337568600429222, 0.07113435756764375, 0.058206842659274116, 0.028004857231280766, 0.06608577183214948, 0.04384556523291394, 0.05258583099930547, 0.11777240928495303, 0.07230358896777034, 0.29872696730308235, 0.02014437228353927, 29.216200970113277, 64.85856771469116, 45.47839544713497, 42.95408070087433, 56.37405999004841, 45.32014153897762, 36.149949207901955, 48.60348455607891, 33.34765277802944, 30.06938248872757, 34.99144837260246, 51.33974052965641, 50.94327740371227, 26.923954971134663, 5.869870400056243, 7.42483246140182, 11.599892154335976, 14.238128587603569, 14.011451750993729, 25.98556872457266, 45.672086253762245, 59.819137528538704, 65.0802630186081, 62.401505559682846, 63.556153401732445, 67.40348115563393, 64.54070717096329, 63.94538551568985, 59.65570829808712, 60.77366150915623, 63.568080961704254, 62.636815533041954, 54.08991515636444, 52.511810436844826, 51.69108107686043, 49.94161695241928, 47.00516492128372, 44.00440514087677, 44.057609885931015, 43.682710602879524, 43.56142871081829, 46.36181004345417, 53.911830112338066, 56.302566826343536, 54.483057260513306, 48.16660299897194, 47.92876236140728, 56.180676966905594, 59.85051244497299, 59.844615161418915, 53.38154576718807, 51.343654319643974, 49.762680754065514, 50.73846839368343, 49.29540082812309, 47.67270930111408, 49.16014328598976, 41.940181106328964, 40.783173590898514, 35.289850160479546, 33.82935672998428, 34.61301527917385, 23.140566386282444, 12.878055218607187, 12.108473014086485, 11.701117772608995, 13.715169299393892, 2.917874827980995, 2.1758682187646627, 0.09421593698789366, 0.08232853462686762, 0.07545344182290137, 0.012512717439676635, 0.10796414848300628, 0.13612760638352484, 0.1266006863443181, 0.07541955535998568, 0.38588823401369154, 0.6067123753018677, 0.3127789101563394, 0.05330602594767697, 0.25276766158640385, 1.644730344414711, 3.5030997125431895, 15.756600257009268, 17.280988208949566, 10.366004314273596, 11.677225604653358, 13.064752500504255, 13.693546559661627, 18.482242450118065, 23.98142896592617, 26.504233293235302, 31.68346557766199, 35.373422876000404, 36.7367023229599, 37.24046029150486, 37.93111503124237, 39.29641596972942, 42.66339249908924, 46.87267363071442, 50.17789967358112, 49.00693170726299, 43.81804794073105, 50.33279836177826, 52.29419991374016, 49.573230519890785, 47.31661520898342, 42.4206767231226, 44.75877106189728, 44.7229427844286, 45.11607348918915, 45.46786621212959, 44.09656539559364, 44.531201273202896, 50.73504477739334, 54.9724368005991, 56.76092863082886, 58.6384192854166, 61.84138521552086, 63.16230073571205, 60.861881375312805, 61.52865819633007, 58.14344644546509, 62.9520770162344, 57.84301556646824, 57.380105406045914, 61.18763789534569, 62.75226093828678, 61.266054287552834, 54.3436199426651, 54.9041772633791, 42.259831354022026, 15.130821336060762, 2.753918138332665, 0.5711952655110508, 9.61806669831276, 36.80081628262997, 51.84448644518852, 34.92758899927139, 13.306132648140192, 20.557976067066193, 18.970729038119316, 32.32657536864281, 32.750583216547966, 27.933917976915836, 25.886931717395782, 26.39864455908537, 35.746015682816505, 47.12688758969307, 55.664512664079666, 1.1290087178349495, 0.04827281380130444, 0.056724450914771296, 0.07860292360419407, 0.09389768179971725, 0.012767807511409046, 0.24776971258688718, 0.07908141589723527, 0.283888436970301, 0.07152661972213537, 0.030745291333005298, 0.049848430426209234, 0.014386182974703843, 0.06312184181297198, 0.0390220320696244, 0.16674492362653837, 0.014204674062057165, 0.04997673291654792, 0.07372056410531513, 0.047510579897789285, 0.03093931285548024, 0.01905485310999211, 0.12112212993088178, 0.14398962201084942, 0.12266989375348203, 35.300835371017456, 73.55440869927406, 48.59505660831928, 51.867676600813866, 61.38218365609646, 41.65262013673782, 34.01419021189213, 49.0646506100893, 39.74227264523506, 37.72428072988987, 38.1092494726181, 55.00999018549919, 56.69455759227276, 32.13037669658661, 8.898413814604282, 11.167349014431238, 17.233749143779278, 20.346422418951988, 18.84968463331461, 29.346093200147152, 43.11111867427826, 56.82367846369743, 65.05689427256584, 63.68908166885376, 62.46549412608147, 66.73632815480232, 63.89976516366005, 64.39913436770439, 63.28135974705219, 63.573955446481705, 64.20880258083344, 64.39632251858711, 61.37959599494934, 55.48053793609142, 52.74943068623543, 50.44416658580303, 47.92009882628918, 45.384696274995804, 46.845094710588455, 46.13845802843571, 47.368961200118065, 52.23781853914261, 55.065679997205734, 59.270876348018646, 57.56427392363548, 51.20362043380737, 51.45392060279846, 57.54780560731888, 63.90044912695885, 60.06040558218956, 58.296726420521736, 56.1620731651783, 53.13882239162922, 52.224789038300514, 54.74526599049568, 52.18411602079868, 52.82330632209778, 45.547008365392685, 43.76825161278248, 38.74014101922512, 39.720469415187836, 40.07587194442749, 29.257185570895672, 24.259458146989346, 22.791838198900223, 15.479829758405685, 11.947372108697891, 1.7005068389698863, 0.7446905714459717, 0.47010314476210624, 0.09430621183128096, 0.0741843470314052, 0.017358387012791354, 0.04102445411263034, 0.0627167776110582, 0.0841007313283626, 0.2520028635626659, 0.179007682017982, 0.18825491628376767, 0.10683462940505706, 0.07331223445362411, 0.24484888650476933, 1.8507662136107683, 7.551890993490815, 24.215338714420795, 30.60766350477934, 29.7397368773818, 23.52689165621996, 24.339671842753887, 23.326555006206036, 27.504892498254776, 31.51173759251833, 34.57853592932224, 38.908175602555275, 42.53916956484318, 41.276835501194, 42.551385909318924, 42.770782336592674, 43.81220765411854, 46.69801980257034, 51.7561449855566, 55.57414211332798, 53.86022508144379, 44.632568433880806, 53.25413480401039, 55.14753520488739, 55.093688294291496, 49.20756854116917, 45.25559440255165, 47.872924357652664, 48.469587340950966, 48.04392658174038, 47.62859366834164, 47.00191609561443, 49.9464350938797, 54.87148381769657, 59.360467940568924, 59.81768600642681, 60.97350038588047, 60.46943463385105, 66.285679936409, 64.76454555988312, 63.91685664653778, 59.246633648872375, 65.45281782746315, 61.08351208269596, 59.97280888259411, 63.191665560007095, 65.97109481692314, 62.733235359191895, 61.095245853066444, 59.81183432042599, 50.12902669608593, 22.65518233180046, 4.481644341722131, 0.721182064153254, 11.83377055451274, 40.74218139052391, 55.376256331801414, 35.772032886743546, 18.41709304600954, 21.372895538806915, 18.764115124940872, 27.34731685370207, 33.69461975991726, 36.87398515641689, 30.921458266675472, 23.184849210083485, 43.45262914896011, 53.42536121606827, 63.59442114830017, 1.807612997945398, 0.05098602036014199, 0.020942808150721248, 0.020879781259282026, 0.027023990332963876, 0.15008272865088657, 0.07091470411978662, 0.026505878486204892, 0.16242688579950482, 0.11145205702632666, 0.09827576679526828, 0.1376240878016688, 0.1829084102064371, 0.11138070694869384, 0.20835101371631026, 0.22705083451000974, 0.24354669934837148, 0.12961043656105176, 0.21732015040470287, 0.19251754536526278, 0.14262396638514474, 0.43304961116518825, 0.21956792275886983, 0.5745479324832559, 0.3393584839068353, 43.23524661362171, 80.5099506676197, 59.09986272454262, 53.98472920060158, 70.02442851662636, 55.58749079704285, 45.73835849761963, 62.143176421523094, 42.635167613625526, 38.315225020051, 46.37308023869991, 60.99182300269604, 60.1108630746603, 34.34142105281353, 11.173402089625597, 11.80897118523717, 16.96924913674593, 20.931940600275993, 20.774106569588184, 41.97192840278149, 65.0400459766388, 74.84563261270523, 70.06681144237518, 65.80511212348938, 67.6244468986988, 75.02999871969223, 69.2371791601181, 66.29092365503311, 64.32381480932236, 67.55268394947052, 68.35074752569199, 69.90983426570892, 64.02940660715103, 61.41689859330654, 59.91638571023941, 58.06122645735741, 50.40739595890045, 48.22415471076965, 48.4764763712883, 47.02372692525387, 46.905978843569756, 51.753849908709526, 59.907600581645966, 60.391960591077805, 56.53507634997368, 48.9728969335556, 49.33757856488228, 63.12997967004776, 68.58540773391724, 67.25818455219269, 59.39494349062443, 59.29306335747242, 55.800986140966415, 55.25608018040657, 53.9110853523016, 56.02381378412247, 57.63945668935776, 50.608701556921005, 46.25024423003197, 45.2103616297245, 43.794660195708275, 45.55659905076027, 38.77174012362957, 23.792539201676846, 20.667294301092625, 13.203380461782217, 23.739423751831055, 16.847366876900196, 6.576157500967383, 0.9279389446601272, 0.22413771192077547, 0.17698722949717194, 0.09131727143540047, 0.14247277606045827, 0.09445602176128887, 0.21682353486539796, 0.2599219948751852, 1.3864674651995301, 0.9396962856408209, 0.5510992126073688, 0.1838086056523025, 0.5073731183074415, 2.901134113781154, 8.945981562137604, 26.630840599536896, 34.014881774783134, 36.56821556389332, 32.25673131644726, 35.630072504282, 28.898241631686687, 38.06410409510136, 40.74603818356991, 40.86010426282883, 44.66584324836731, 50.00526733696461, 44.326810240745544, 45.4670150578022, 44.96690109372139, 48.565156012773514, 48.681680560112, 55.013869777321815, 57.43590161204338, 56.1277762055397, 44.919536635279655, 55.27487017214298, 56.04117125272751, 57.72053673863411, 53.64670693874359, 46.99798710644245, 51.45271606743336, 53.634995967149734, 52.75039963424206, 51.30172356963158, 48.04863452911377, 52.50157378613949, 53.846067041158676, 58.14258389174938, 60.50696521997452, 64.43971619009972, 67.7920027077198, 69.16011169552803, 65.96463516354561, 67.68306255340576, 59.03628073632717, 64.82826054096222, 58.80967989563942, 59.29281637072563, 64.04562413692474, 67.69417315721512, 63.02798554301262, 59.42036792635918, 58.01265746355057, 49.72061701118946, 23.654540106654167, 7.071505095809698, 1.4686987339518964, 13.772588018327951, 47.564038932323456, 64.00280803442001, 49.29521843791008, 20.90159732848406, 27.446537129580975, 27.135516218841076, 48.31771329045296, 49.27555449306965, 44.652255177497864, 38.97873021662235, 38.21035824716091, 51.655298396945, 61.680726036429405, 78.58194932341576, 3.43088292516768, 0.49062005477026105, 0.21755444642622024, 0.27702787541784346, 0.272466724854894, 0.29045599862001836, 0.540391446556896, 0.13142687268555164, 0.3618563344934955, 0.21018425206420943, 0.15730544342659414], [0.07559022706118412, 0.018225438143417705, 0.015469165682588937, 0.06087139401643071, 0.05655566797940992, 0.13312266528373584, 0.016613126026641112, 0.07595133385621011, 0.20290359039790928, 0.05946560304437298, 0.04869137024797965, 0.06331286320346408, 0.03518651639751624, 0.04433899695868604, 30.26331838220358, 61.664896085858345, 46.14944323897362, 49.44532938301563, 42.24603049457073, 51.21851563453674, 33.96378591656685, 65.15972435474396, 52.30190970003605, 26.56540621072054, 41.80208891630173, 45.23939207196236, 57.171754986047745, 30.89813891798258, 6.931405188515782, 11.539549492299557, 23.26384697109461, 24.046014100313187, 21.3724547624588, 25.615039207041264, 21.861708909273148, 25.54267778992653, 49.79512721300125, 58.81661832332611, 61.42430819571018, 62.11286544799805, 56.34293965995312, 62.1653900295496, 59.343935027718544, 63.90094310045242, 60.72003498673439, 61.11256152391434, 58.16836170852184, 55.1993378251791, 50.340717136859894, 48.20422478020191, 44.417218789458275, 45.662438571453094, 42.69247613847256, 45.4108464717865, 41.649234518408775, 49.119671657681465, 54.67718504369259, 56.861608028411865, 53.38493898510933, 48.10219265520573, 51.87586136162281, 55.85468865931034, 59.49848413467407, 57.008861526846886, 52.13916823267937, 52.152201533317566, 50.27593441307545, 48.98452430963516, 50.209844559431076, 48.307214453816414, 44.96841721236706, 43.14548023045063, 38.622689321637154, 34.02301333844662, 31.817849166691303, 31.073199324309826, 14.91556953638792, 12.521860431879759, 18.47117554396391, 8.935980498790741, 4.439653744921088, 2.802451984025538, 0.48722413543146104, 0.23096599004929885, 0.3007275896379724, 0.08452682799543254, 0.134944177698344, 0.25402417697478086, 0.1122893851425033, 0.18777994177071378, 0.1750090645509772, 0.22429587843362242, 0.16369428107282147, 0.47456597560085356, 0.07607645995449275, 0.8107465831562877, 0.22211751173017547, 9.44274790585041, 28.36155652999878, 23.20623256266117, 28.079170882701874, 18.96244738250971, 16.052601523697376, 15.175999961793423, 18.165155164897442, 20.768038295209408, 25.19652396440506, 34.448734894394875, 33.29904958605766, 34.70968209207058, 35.58194048702717, 40.12230545282364, 40.76014302670956, 44.6866737306118, 48.73770095407963, 48.67072194814682, 49.90542009472847, 44.122464805841446, 50.45077443122864, 52.06628434360027, 51.71223074197769, 44.61869917809963, 41.13764896988869, 42.02065698802471, 41.72878324985504, 42.18187473714352, 42.807089388370514, 44.523457288742065, 50.411127358675, 55.01478172838688, 54.428879767656326, 59.14184667170048, 56.969313248991966, 58.72034668922424, 65.62112599611282, 58.77711184322834, 61.50028891861439, 59.26039271056652, 61.85165226459503, 61.967067271471024, 66.16613075137138, 65.70695579051971, 66.72048300504684, 66.23584941029549, 70.57778522372246, 66.710846722126, 55.82294896245003, 31.084072440862656, 4.61580041795969, 1.361026642844081, 14.00164732709527, 35.64458392560482, 50.223512426018715, 24.455202743411064, 16.61049898713827, 18.81334338337183, 25.592137835919857, 30.750898718833923, 32.7221455425024, 28.649835661053658, 24.698952063918114, 30.916334241628647, 37.65378311276436, 52.15833060443401, 50.07088601589203, 1.484543289989233, 0.08438775694230571, 0.06767551152734086, 0.12797015660908073, 0.07357024951488711, 0.10564118172624148, 0.24685525306267664, 0.13989123021019623, 0.11791221506427974, 0.05592924710072111, 0.062388466321863234, 0.07975784639711492, 0.11370751803042367, 0.04525306685536634, 0.03498411788314115, 0.09673837077571079, 0.16476137068821117, 0.02198416565079242, 0.06183610807056539, 0.07342935277847573, 0.16071386053226888, 0.11751426063710824, 0.024038781084527727, 0.13425156095763668, 0.09045634302310646, 42.33548529446125, 69.86604541540146, 54.39242832362652, 54.91941824555397, 49.66800883412361, 42.646141424775124, 31.166092939674854, 57.70104758441448, 49.10569220781326, 34.237382635474205, 45.85167981684208, 49.07992199063301, 59.4905311614275, 34.887805134058, 9.42314475774765, 11.212930418550968, 22.938396334648132, 31.453106738626957, 34.793748781085014, 37.58228614926338, 31.28705184906721, 28.017422296106815, 51.58933773636818, 64.67587351799011, 63.74156445264816, 65.00192642211914, 54.77871559560299, 61.95891670882702, 60.67201316356659, 68.94486844539642, 63.156559243798256, 62.80785575509071, 62.634965032339096, 58.58802638947964, 51.054106056690216, 51.022058576345444, 47.19655305147171, 48.7080093473196, 45.68621389567852, 46.56427077949047, 46.04657895863056, 52.856353148818016, 57.40475848317146, 57.9232444614172, 57.483395263552666, 52.62461878359318, 52.95650817453861, 59.563897624611855, 58.581790924072266, 57.47900269925594, 54.66101311147213, 56.57005727291107, 53.16852539777756, 50.460205525159836, 51.865419521927834, 53.10131460428238, 52.77836613357067, 49.97019521892071, 42.89413511753082, 39.001396000385284, 38.42375099658966, 35.33511333167553, 25.61149399727583, 34.46772247552872, 38.66184622049332, 15.746777784079313, 7.135009188205004, 2.331687407568097, 0.5251121695619076, 0.09931588676408865, 0.24348575418116525, 0.08794529378064908, 0.08052818826399744, 0.1960606622742489, 0.0318903083098121, 0.11386759928427637, 0.18449273222358897, 0.06633923010667786, 0.2572955342475325, 0.6100041267927736, 0.061006360992905684, 0.4177495540352538, 2.2033982165157795, 13.738043121993542, 38.010302782058716, 24.49231155216694, 41.87536038458347, 30.740798860788345, 29.862610884010792, 25.266962684690952, 30.803706385195255, 31.748409792780876, 34.358926713466644, 40.84522046148777, 41.99910834431648, 38.80241207778454, 40.263946652412415, 42.5631994754076, 46.044694259762764, 46.80162124335766, 53.129566088318825, 53.421166241168976, 53.40822413563728, 46.54685251414776, 51.81352570652962, 52.66336910426617, 53.20927061140537, 45.67173287272453, 43.12555029988289, 44.31521326303482, 48.17683205008507, 45.026459097862244, 45.129311978816986, 46.019269824028015, 56.80201582610607, 56.94448538124561, 58.55436019599438, 62.06569477915764, 59.20089550316334, 59.864020720124245, 64.673722833395, 59.90914709866047, 64.89632248878479, 60.29149018228054, 61.6667465865612, 62.67276160418987, 65.45141190290451, 67.32826039195061, 67.91995704174042, 65.57947263121605, 68.96176233887672, 67.09950506687164, 61.481643319129944, 37.3623463511467, 7.410561377182603, 1.0744943493045866, 17.54274856299162, 41.62461943924427, 55.76626360416412, 28.09280265122652, 22.00336340814829, 22.9005104675889, 23.262009769678116, 33.703929260373116, 32.07935683429241, 37.28286221623421, 30.689013339579105, 29.963991343975067, 42.327900901436806, 59.16954718530178, 63.07077504694462, 2.6600726740434766, 0.05032345688960049, 0.06336074657156132, 0.06612875702558085, 0.2021440170938149, 0.05826706423249561, 0.0528345877683023, 0.06370519957272336, 0.14408347400603816, 0.05983036491670646, 0.052762009436264634, 0.33424947992898524, 0.22393250808818266, 0.1456227625021711, 0.18753549316897988, 0.1351941775646992, 0.41172132594510913, 0.11313402341329493, 0.19941352220484987, 0.6473518477287143, 0.3698101092595607, 0.6682012102100998, 0.16554369824007154, 0.38399697456043214, 0.4568363050930202, 51.05495721101761, 76.63302630186081, 61.260096207261086, 57.924562990665436, 51.9286747276783, 60.41835397481918, 43.49550984799862, 76.43640205264091, 60.64888000488281, 32.35065087676048, 56.64686635136604, 55.23230865597725, 64.6416525542736, 34.250647723674774, 12.071072570979595, 12.620233353227377, 23.973969966173172, 32.63694271445274, 35.8218178153038, 40.076468512415886, 36.12675905227661, 37.06419914960861, 63.29604975879192, 66.49855211377144, 70.11163383722305, 69.86838608980179, 56.718017533421516, 64.46497723460197, 65.64112812280655, 72.7886813879013, 67.11839765310287, 66.37431398034096, 67.60132893919945, 68.20690244436264, 60.051654651761055, 54.1788037866354, 46.83269217610359, 50.26941396296024, 44.96323049068451, 48.1217198073864, 46.2069683521986, 57.08375170826912, 60.74624218046665, 60.40815532207489, 57.57455617189407, 48.30658368766308, 55.29330298304558, 62.494828552007675, 65.26070013642311, 62.2750673443079, 55.99485173821449, 59.638913199305534, 56.26354672014713, 50.37349037826061, 54.337468072772026, 58.816758915781975, 52.88096442818642, 56.204551085829735, 45.242401510477066, 48.00567403435707, 42.198354452848434, 49.0250339359045, 31.720524989068508, 37.016511708498, 42.74141751229763, 14.457351174205542, 12.920920718461275, 7.506416933611035, 1.2255212827585638, 0.263250230345875, 0.3378136589890346, 0.1935456128558144, 0.31941062305122614, 0.22390889294911176, 0.20307478902395815, 0.319934252765961, 0.3251791885122657, 0.3025942394742742, 0.7060614880174398, 0.832277296576649, 0.45070934167597443, 1.540746430400759, 3.956725071184337, 15.276770554482937, 44.400651678442955, 28.30117207020521, 46.66553154587746, 39.839235842227936, 39.73180040717125, 34.081837981939316, 41.468907594680786, 38.54762054979801, 41.5703621506691, 46.93706877529621, 46.81284584105015, 42.44355529546738, 42.69507899880409, 49.23297397792339, 51.48871533572674, 48.2271109521389, 56.48411348462105, 54.650050699710846, 55.28449885547161, 44.95248846709728, 53.130303248763084, 57.24317215383053, 58.50001931190491, 49.111414700746536, 44.61659409105778, 48.87126378715038, 50.8906502276659, 48.924293741583824, 47.57665805518627, 49.49416056275368, 56.96576423943043, 56.9321246445179, 56.42745852470398, 65.17821416258812, 63.844022154808044, 64.92691844701767, 66.59183710813522, 65.31320571899414, 67.42584675550461, 60.85328243672848, 61.83175653219223, 63.08880887925625, 67.91472092270851, 70.36406949162483, 72.49026820063591, 66.80226221680641, 72.47579097747803, 68.63700896501541, 60.59397295117378, 39.434606954455376, 8.304908461868763, 2.5255294935777783, 20.591636560857296, 45.87714985013008, 65.23386597633362, 37.433603927493095, 23.859313018620014, 27.40920413285494, 36.1013650149107, 48.06522823870182, 47.12695598602295, 45.32861888408661, 35.55139012634754, 42.47076943516731, 53.92006807029247, 68.67336541414261, 76.12709105014801, 3.377971714362502, 0.2372386964270845, 0.22774616751121357, 0.45893043803516775, 0.39201911597047, 0.29744824685622007, 0.24358158028917387, 0.1479073750670068, 0.28389383980538696, 0.18489549576770514, 0.397798249614425], [0.10116540041053668, 0.12334984203334898, 0.06748552914359607, 0.059087541885674, 0.058020545038743876, 0.31605789670720696, 0.11764822571421973, 0.09442289228900336, 0.15092233516043052, 0.1318528357660398, 0.2232546007144265, 0.017427577440685127, 0.13300647464348003, 0.07603939709952101, 41.02933578193188, 60.549667328596115, 37.30046667158604, 43.190143033862114, 32.48841628432274, 50.062898844480515, 26.975829787552357, 57.75539226830006, 59.42852608859539, 26.83209490031004, 36.07973277568817, 44.45604130625725, 49.64294917881489, 38.76680038869381, 10.333980582654476, 10.137190092355013, 18.703850358724594, 33.72365780174732, 45.991941690444946, 45.83743058145046, 38.404307439923286, 24.25822701305151, 34.70621667802334, 63.927511274814606, 64.86379623413086, 65.24642050266266, 62.42275021970272, 64.35979887843132, 64.3615771830082, 65.31140461564064, 63.40657062828541, 58.98011215031147, 58.660511299967766, 58.72992977499962, 51.96028523147106, 48.523164466023445, 48.42238627374172, 44.45824518799782, 41.637907326221466, 43.33307236433029, 42.85304792225361, 44.17052082717419, 51.96502737700939, 52.84233570098877, 52.59403422474861, 52.31341928243637, 53.38644750416279, 60.82772500813007, 55.41679635643959, 54.36115600168705, 47.42856480181217, 52.04853929579258, 50.108595192432404, 48.75237196683884, 47.26937234401703, 48.48583146929741, 48.17102216184139, 43.8376434892416, 37.10420720279217, 29.329186007380486, 30.643151700496674, 25.976954586803913, 15.350890327244997, 34.19357858598232, 31.811976581811905, 6.298343483358622, 0.4314235062338412, 1.117201920133084, 0.2542810491286218, 0.3830727335298434, 0.09188245399855077, 0.04894601966952905, 0.24474146805005148, 0.1451985805761069, 0.0802954581740778, 0.10142544895643368, 0.07165065486333333, 0.04085142609255854, 0.1034703255572822, 0.2548730158014223, 0.20388102857396007, 0.05100920876429882, 0.515285599976778, 11.375936921685934, 45.11760100722313, 33.3397302031517, 45.10182425379753, 29.13457565009594, 16.855374947190285, 15.615802612155676, 20.919089689850807, 22.490981742739677, 29.717065393924713, 31.023176908493042, 35.31055524945259, 34.10893052816391, 32.708599269390106, 37.18362674117088, 38.98626521229744, 42.2476302087307, 46.941411942243576, 48.48440654575825, 49.35216598212719, 46.606969088315964, 48.02306950092316, 50.28775557875633, 46.83353953063488, 42.07605801522732, 40.421980172395706, 43.03846277296543, 43.848925083875656, 42.43318185210228, 41.29121012985706, 45.23206606507301, 58.783761486411095, 51.71134538948536, 56.33831150829792, 55.75021706521511, 55.33202290534973, 59.91522677242756, 61.617261841893196, 56.136952713131905, 59.64906245470047, 54.697384759783745, 57.23505198955536, 59.1735065728426, 62.429418861866, 65.48992663621902, 66.07256457209587, 62.3248028755188, 63.11253480613232, 65.39158791303635, 66.06610491871834, 43.75979706645012, 10.644344128668308, 2.542251921258867, 17.37590331584215, 45.19486606121063, 43.771283850073814, 18.149771690368652, 17.03705459833145, 15.243429243564606, 14.24285363405943, 19.96924325823784, 33.7069159001112, 32.67445810139179, 26.871570982038975, 26.112968288362026, 31.378619335591793, 41.78966358304024, 62.088398560881615, 3.2126430608332157, 0.12120542858610861, 0.055374729199684225, 0.0894545327173546, 0.03373752500920091, 0.10955753954476677, 0.3355696122162044, 0.03397319400392007, 0.12776441843016073, 0.08251052408013493, 0.12363309753709473, 0.06166576662508305, 0.12174312199931592, 0.013493154820025666, 0.06930584670044482, 0.04222261442919262, 0.10622776782838628, 0.027316836240061093, 0.09621232908102684, 0.21401273959781975, 0.08702422172063962, 0.14350943762110546, 0.04197876696707681, 0.18321033072425053, 0.1265962334582582, 49.507801830768585, 70.09999886155128, 44.01621870696545, 47.811895832419395, 36.75636246800423, 44.501642659306526, 27.435227036476135, 51.4963149279356, 52.40906395018101, 34.65500682592392, 42.34678968787193, 49.60739068686962, 55.031132251024246, 43.82158935070038, 13.856211081147194, 11.220991685986519, 19.012095518410206, 34.0179406106472, 47.98303484916687, 53.80644656717777, 49.65524151921272, 39.360765516757965, 37.994472831487656, 65.56001767516136, 65.94426825642586, 65.95512047410011, 63.531063348054886, 64.00889530777931, 65.09414747357368, 67.31288641691208, 66.31249129772186, 60.837707072496414, 60.84861248731613, 62.16773450374603, 53.27911086380482, 48.33463378250599, 49.281383380293846, 46.3706673681736, 44.273362308740616, 44.93151359260082, 45.01443654298782, 49.79329951107502, 56.399507224559784, 54.59059529006481, 55.2417853474617, 53.17049369215965, 53.55629459023476, 61.499000787734985, 57.16104716062546, 55.989193841814995, 51.758436262607574, 53.94064396619797, 51.13215386867523, 52.15413182973862, 52.36458733677864, 53.24120409786701, 54.02002930641174, 48.53974297642708, 42.2739551961422, 38.8816112279892, 38.40778045356274, 32.25847162306309, 31.35744497179985, 53.479656502604485, 39.71739158034325, 18.525470830500126, 3.5521667171269655, 1.737203726079315, 0.2293347049271688, 0.08782559278188273, 0.08808196027530357, 0.11502333101816475, 0.12002140618278645, 0.15496540727326646, 0.12029905105009675, 0.19022444263100624, 0.2516917255707085, 0.03908428341674153, 0.04553802187729161, 0.2678186836419627, 0.04817475753952749, 0.17785367206670344, 0.9470648027490824, 14.733261968940496, 66.16796225309372, 52.35982619225979, 62.42580525577068, 36.97708122432232, 27.535435259342194, 28.0142779648304, 31.592642851173878, 32.9088219255209, 36.25307947397232, 37.8076596558094, 41.32919289171696, 40.332103595137596, 39.3987862765789, 41.91736713051796, 44.367088079452515, 47.23368085920811, 50.727562978863716, 53.719324842095375, 52.10913084447384, 47.06350319087505, 52.041855454444885, 52.38415628671646, 49.398827478289604, 44.40459206700325, 42.56341986358166, 45.85429407656193, 47.27341912686825, 44.606251046061516, 44.862862676382065, 50.36951959133148, 59.44720968604088, 55.819388553500175, 58.98868069052696, 58.40762346982956, 60.811879858374596, 62.74840034544468, 63.41290108859539, 60.02942964434624, 62.42365837097168, 57.020386308431625, 60.13270050287247, 60.95519296824932, 62.4419429898262, 65.20188689231873, 69.74787935614586, 63.91767740249634, 63.69612269103527, 64.06748816370964, 67.5287452340126, 50.9565044939518, 17.242220789194107, 4.10961152985692, 19.245477095246315, 52.92711295187473, 47.142713740468025, 24.763787984848022, 19.0030425041914, 16.428992226719856, 11.499375198036432, 22.753655947744846, 34.94434230029583, 35.79301156103611, 30.06093744188547, 24.198154136538506, 36.647422313690186, 46.179746612906456, 79.45423811674118, 5.661384137347341, 0.1308224379317835, 0.07178976302384399, 0.07542402308899909, 0.2108660779776983, 0.04287026073143352, 0.1226922546629794, 0.0349035688850563, 0.11755236992030405, 0.04569644072034862, 0.058623228323995136, 0.26039898802991956, 0.2167369707603939, 0.13213148253271356, 0.16216907853959128, 0.1708304911153391, 0.5251260031946003, 0.15682862838730216, 0.1992100549978204, 0.6801683711819351, 0.3018121642526239, 0.46870155434589833, 0.11457525193691254, 0.3637855622218922, 0.28744641167577356, 59.52580466866493, 76.3924840092659, 50.26119500398636, 50.91331601142883, 41.58988170325756, 60.32025843858719, 37.85400576889515, 67.06871151924133, 67.82031118869781, 33.217065185308456, 49.74432393908501, 56.0799215734005, 55.67340038716793, 44.74467381834984, 14.891046602278948, 12.698221318423748, 19.79294791817665, 35.652631893754005, 54.14785824716091, 60.422358959913254, 53.108952194452286, 40.483806654810905, 43.44071298837662, 68.96347984671593, 72.68399700522423, 71.45590290427208, 64.71141681075096, 66.23673856258392, 69.72455620765686, 73.29153120517731, 69.53645870089531, 62.41953559219837, 66.32407307624817, 72.05255448818207, 61.67285665869713, 53.12793217599392, 50.236975103616714, 47.958849146962166, 44.47891607880592, 45.76437950134277, 44.312283620238304, 51.554022431373596, 58.469514548778534, 59.02443677186966, 53.90757814049721, 51.36487238109112, 55.176299661397934, 67.28628024458885, 59.908174350857735, 61.24449424445629, 54.62344452738762, 59.58493709564209, 51.753583922982216, 52.844740971922874, 55.29999062418938, 60.104855597019196, 59.08010758459568, 54.220441952347755, 46.13022767007351, 46.98989354074001, 45.71904793381691, 44.94697496294975, 40.480538830161095, 69.1903580725193, 58.2944655418396, 22.03751027584076, 7.090734438970685, 2.706689997576177, 0.5506969685666263, 0.3828998428070918, 0.26267818291671574, 0.4074811394093558, 0.30663226498290896, 0.18791793670970947, 0.19729449762962759, 0.20621787349227816, 0.46945709036663175, 0.21945278596831486, 0.3061839781003073, 1.6996708838269114, 0.6017851084470749, 0.3505597187904641, 1.1255560093559325, 19.488109275698662, 65.92036753892899, 48.58401820063591, 66.74927785992622, 46.77808150649071, 39.635764360427856, 37.33337290585041, 44.77420963346958, 40.83003267645836, 45.782534927129745, 41.886045411229134, 50.61180979013443, 41.2349009513855, 42.065293192863464, 46.75671525299549, 48.470924869179726, 47.9852045327425, 55.71203671395779, 54.331593587994576, 53.67285713553429, 46.35509580373764, 52.44993835687637, 56.338075920939445, 54.65525262057781, 44.75546143949032, 42.82452665269375, 49.49119672179222, 53.49483288824558, 48.793223574757576, 47.35370121896267, 53.696488067507744, 66.45434528589249, 53.353035897016525, 56.176322400569916, 59.89782750606537, 61.32057376205921, 70.16035482287407, 65.9213250875473, 62.22038447856903, 66.38229355216026, 54.929514303803444, 56.74488969147205, 59.27908390760422, 65.2376201748848, 68.63883286714554, 70.81566765904427, 62.5942350178957, 65.50761848688126, 68.83832216262817, 73.9250560104847, 52.7787347137928, 17.840922363102436, 4.719222793355584, 23.409356363117695, 54.99170556664467, 56.52433052659035, 32.8054066747427, 23.152298256754875, 24.031227193772793, 21.899505481123924, 33.25994588434696, 51.470909491181374, 50.167541429400444, 39.60468962788582, 38.232442662119865, 47.52602197229862, 58.762984201312065, 93.46682220697403, 6.403725128620863, 0.6741693243384361, 0.207490983302705, 0.4085734026739374, 0.5981291108764708, 0.1552360091591254, 0.4849190544337034, 0.10749297376605682, 0.3152277896879241, 0.16505542444065213, 0.30130263534374535], [0.12683095992542803, 0.1412747270660475, 0.05892822504392825, 0.136240353458561, 0.05602745550277177, 0.11139593581901863, 0.13368292740778998, 0.07292311158380471, 0.43942477845121175, 0.19259499589679763, 0.2141952485544607, 0.210105643782299, 0.39164370798971504, 1.266186225693673, 49.72377844154835, 61.12391911447048, 44.40782569348812, 45.50643414258957, 29.557749442756176, 31.9655529409647, 26.202474385499954, 59.23968382179737, 50.727372989058495, 22.207961529493332, 33.46708036959171, 47.46256537735462, 52.8398734331131, 42.70148545503616, 12.492000684142113, 6.770941223949194, 16.085595153272152, 31.08267791569233, 45.27843117713928, 54.926170483231544, 55.03087766468525, 43.929188176989555, 34.72430370748043, 66.26498624682426, 64.45769682526588, 62.3725701123476, 66.75643667578697, 61.65616415441036, 58.41981701552868, 64.40675675868988, 61.1776140332222, 58.16358536481857, 55.1390540599823, 54.78817708790302, 49.88613232970238, 44.14555996656418, 43.25664326548576, 43.91357101500034, 41.853237971663475, 43.36662836372852, 44.95819956064224, 44.508098512887955, 48.96723523736, 51.344813257455826, 51.32084034383297, 52.79390349984169, 52.52239286899567, 59.65348161756992, 56.4206150919199, 52.88919098675251, 46.51934579014778, 47.464309483766556, 48.636261597275734, 53.398595452308655, 47.17262953519821, 51.18682913482189, 41.41765594482422, 44.52087722718716, 34.41800594329834, 32.383872494101524, 23.969151824712753, 24.627567194402218, 21.83241058140993, 46.11681059002876, 29.69134457409382, 11.529865711927414, 1.7828941368497908, 1.6028643096797168, 0.32561094034463167, 0.4440334561513737, 0.12435977885616012, 0.36379716941155493, 0.2784257847815752, 0.04667243541916832, 0.09287618231610395, 0.35506253654602915, 0.031648865406168625, 0.03972225582401734, 0.023504970959038474, 0.12613344501005486, 0.28736180684063584, 0.35576312395278364, 0.5506073171272874, 3.530567488633096, 24.49595745652914, 47.411313727498055, 36.77359454333782, 22.605226412415504, 18.41010522097349, 18.95965453237295, 23.22098147124052, 24.969125166535378, 28.5655352845788, 30.015662871301174, 32.88312390446663, 35.79530283808708, 38.018191158771515, 38.95880028605461, 43.61111484467983, 44.78074908256531, 47.512768283486366, 51.24858342111111, 52.77569867670536, 48.04270304739475, 50.02646639943123, 48.05469520390034, 43.21830332279205, 41.121697425842285, 41.83665566146374, 43.42478424310684, 42.97726705670357, 40.54915554821491, 41.1614128947258, 50.36890782415867, 60.09072035551071, 57.32234090566635, 57.37005114555359, 57.327858209609985, 60.4590155929327, 59.55724038183689, 61.191589683294296, 57.97172226011753, 56.35031506419182, 57.461827620863914, 59.00745928287506, 60.33691294491291, 64.6762079000473, 61.45008221268654, 68.48399877548218, 64.19469773769379, 65.3289444744587, 60.76825439929962, 62.52037078142166, 47.919137477874756, 24.797609969973564, 4.9525183998048306, 19.29619487375021, 59.41568277776241, 40.71743331849575, 14.509812109172344, 17.534772790968418, 12.127912770956755, 8.664015792310238, 21.389031372964382, 31.69336024671793, 34.21266496181488, 27.395977042615414, 31.908601596951485, 46.790514439344406, 42.23970003426075, 65.63137784600258, 8.06784013286233, 0.02980586596095236, 0.2574793790699914, 0.04571208148263395, 0.14630605786805972, 0.1738251163624227, 0.3135126270353794, 0.06613296500290744, 0.025028156705957372, 0.09442689988645725, 0.21286111936205998, 0.17839955136878416, 0.09513148746918887, 0.05648419915814884, 0.09241020263289101, 0.06612793324165978, 0.12972618191270158, 0.04475772781006526, 0.053343370818765834, 0.31654237071052194, 0.2272099064430222, 0.09372292086482048, 0.2299598159152083, 0.3907904459629208, 2.5123411137610674, 62.56670169532299, 67.17642813920975, 51.524444818496704, 49.94735464453697, 35.148547142744064, 37.292893677949905, 30.236962996423244, 50.4509150236845, 45.516385808587074, 23.916878029704094, 42.21901774406433, 48.20826396346092, 57.17761807143688, 44.90706570446491, 15.993814878165722, 5.479323556646705, 14.618380833417177, 31.25131666660309, 45.92160366475582, 52.65573151409626, 54.33803804218769, 49.42037992179394, 44.27611716091633, 68.12215179204941, 61.7918548732996, 64.56577062606812, 63.34180690348148, 59.205550253391266, 62.17420935630798, 65.1128500699997, 61.20106637477875, 59.27956648170948, 53.892663940787315, 54.2847952991724, 50.40399134159088, 43.86692471802235, 45.09456284344196, 49.31228332221508, 46.4178304374218, 46.49104490876198, 47.90462985634804, 51.309824734926224, 51.29432916641235, 55.475282818078995, 52.75094300508499, 55.04057854413986, 53.562989830970764, 59.973059669137, 56.92504942417145, 55.2057670801878, 49.334667921066284, 53.78125011920929, 49.641334265470505, 54.111057221889496, 50.08984699845314, 55.79712554812431, 47.05088026821613, 50.00386901199818, 37.74479582905769, 43.828653171658516, 35.678519904613495, 29.25925076007843, 40.278404876589775, 47.870188504457474, 31.626107655465603, 15.84232460707426, 8.219607789069414, 0.19228894903790206, 0.5448894551955163, 0.3019589016912505, 0.1910920874797739, 0.3077541844686493, 0.23842533119022846, 0.13365759048610926, 0.2628207643283531, 0.26795562473125756, 0.22743127425201237, 0.06447545980336145, 0.022326572179736104, 0.2648090076399967, 0.19385259482078254, 0.07200668536825106, 0.4460565507179126, 0.8569683122914284, 31.86794187873602, 65.70114970207214, 38.668438866734505, 29.375545419752598, 28.90429850667715, 29.613144770264626, 30.467190742492676, 32.0744588971138, 35.20255744457245, 38.52015562355518, 40.2442941069603, 41.089102774858475, 43.9529825001955, 45.21526716649532, 46.78243227303028, 48.630782291293144, 51.54676102101803, 53.6413948237896, 52.81472258269787, 50.229953080415726, 53.77283737063408, 50.33945940434933, 46.52609042823315, 43.24547566473484, 46.28722004592419, 45.107333958148956, 44.572565853595734, 43.47557611763477, 47.90582679212093, 56.538735553622246, 62.07382634282112, 61.59580439329147, 61.73899970948696, 60.38332365453243, 61.130671352148056, 60.168551579117775, 62.55082614719868, 62.059029936790466, 62.03168660402298, 61.52690269052982, 61.25089310109615, 62.55817115306854, 65.35891726613045, 61.01843677461147, 66.85946434736252, 64.94464069604874, 66.42423570156097, 64.18925642967224, 66.87400996685028, 50.53936667740345, 29.897437915205956, 6.8417413998395205, 22.862801291048527, 62.86868289113045, 45.03829926252365, 18.90868216753006, 21.119162254035473, 17.643262669444084, 11.517195291817188, 25.336871333420277, 30.249717012047768, 38.479725793004036, 28.495197258889675, 34.248101860284805, 59.186760261654854, 51.117733642458916, 76.38719469308853, 11.407211143523455, 0.29834636428859085, 0.22346499958075583, 0.17668211774434894, 0.12926765339216217, 0.1351408616756089, 0.07493856945075095, 0.098249272123212, 0.09767086448846385, 0.053062033766764216, 0.1243763584352564, 0.5278791929595172, 0.34533188212662935, 0.18535573122790083, 0.16688133036950603, 0.18558496580226347, 0.19694199232617393, 0.15748848672956228, 0.2010458760196343, 0.8564168075099587, 0.49242537352256477, 0.3423951147124171, 0.36509254365228117, 0.6243782804813236, 2.2827139729633927, 71.47566944360733, 76.31542414426804, 58.84801223874092, 58.12685653567314, 42.04049952328205, 39.932197853922844, 36.3329815864563, 68.58658567070961, 55.550625175237656, 27.37448539584875, 45.73778472840786, 57.97637701034546, 61.5531250834465, 47.91560746729374, 16.682491824030876, 7.299394542351365, 15.91210501268506, 33.563785180449486, 51.849616169929504, 57.92136736214161, 62.113351821899414, 56.331198289990425, 49.318161606788635, 71.41915127635002, 67.20706209540367, 67.40669578313828, 68.55500936508179, 60.925638154149055, 67.55400627851486, 72.73518025875092, 66.26152843236923, 62.63653054833412, 59.673635736107826, 65.13680398464203, 59.03045564889908, 47.33492262661457, 45.620610415935516, 50.013858675956726, 45.29942125082016, 46.094661578536034, 47.5276330858469, 52.20343418419361, 55.10828711092472, 57.853062227368355, 51.86717502772808, 53.06279607117176, 54.996075332164764, 66.43011018633842, 62.40054801106453, 60.46170584857464, 51.149306148290634, 55.446582958102226, 50.12417055666447, 57.635801285505295, 51.71753525733948, 62.93053977191448, 50.59219904243946, 54.30160939693451, 44.22629803419113, 51.46277412772179, 43.00978571176529, 46.76279492676258, 55.39539210498333, 74.67584252357483, 57.30199299752712, 32.21040420234203, 7.886188505217433, 1.999978506937623, 1.5448435605503619, 0.3781897877342999, 0.19386969390325248, 0.6053096568211913, 0.3882390906801447, 0.14959509309846908, 0.2532125642756, 0.4615955793997273, 0.5031331395730376, 0.2072838498861529, 0.23884341266239062, 0.8904818014707416, 1.218791725113988, 1.9228431209921837, 0.7352205889765173, 3.7590226298198104, 30.855750292539597, 60.418585762381554, 38.92901748418808, 38.960183411836624, 35.83865851163864, 39.5725167542696, 46.22429542243481, 46.565482914447784, 45.37839621305466, 43.46609942615032, 46.99294477701187, 41.92465513944626, 49.02556970715523, 53.01207259297371, 54.850159361958504, 50.95774322748184, 56.23859725892544, 57.22233787178993, 57.04673409461975, 50.69734700024128, 56.315163150429726, 54.646148309111595, 50.08480466902256, 44.996387511491776, 46.73201657831669, 48.17836716771126, 49.58330377936363, 48.46054382622242, 48.365047350525856, 57.95494236052036, 70.74038609862328, 60.774869844317436, 59.863211363554, 60.762547105550766, 67.91802674531937, 64.0269747376442, 66.72881975769997, 65.94797685742378, 63.221395164728165, 59.36218924820423, 57.343988344073296, 63.20137403905392, 67.19383880496025, 63.06136295199394, 73.6920753121376, 63.997450321912766, 68.04862573742867, 64.99092981219292, 71.744474619627, 55.62270350754261, 34.82336439192295, 9.250425025820732, 25.337296910583973, 68.7350133061409, 57.164713963866234, 24.861486442387104, 26.999643109738827, 20.123197697103024, 14.755112696439028, 35.8303065598011, 45.46115957200527, 51.38365477323532, 39.65238846838474, 42.63927139341831, 66.0952265560627, 59.94339846074581, 93.83318334817886, 13.508505038917065, 0.6151534442324191, 0.4021923872642219, 0.3114605590235442, 0.3502650564769283, 0.2729885734152049, 0.35373789200093597, 0.24350038933334872, 0.39927191741298884, 0.16329240810591727, 0.3919891925761476], [0.040817060944391415, 0.21335865516448393, 0.11780737186199985, 0.03436541162955109, 0.10030993420514278, 0.12283301781280898, 0.03055440538446419, 0.1560640084790066, 0.053542578098131344, 0.19900032406440005, 0.06364230997860432, 0.4567299998598173, 0.4519118880853057, 1.6299531748518348, 46.92701831459999, 56.782321482896805, 31.260941550135612, 31.481924392282963, 36.461657881736755, 20.85797756910324, 22.83537246286869, 25.62398962676525, 24.31187443435192, 22.95623067766428, 23.646684028208256, 48.65685649216175, 43.605688735842705, 44.17652070522308, 18.687792420387268, 3.2725069485604763, 12.855982203036547, 30.20530689507723, 41.48428916931152, 51.09320595860481, 53.42782348394394, 42.796696946024895, 47.889791652560234, 69.3597985804081, 59.608248844742775, 64.362952709198, 61.98029816150665, 60.78451752662659, 58.63276518881321, 56.2215855717659, 54.955626502633095, 53.94522272050381, 47.33007788658142, 46.445242166519165, 41.97402209043503, 42.864124327898026, 41.72726333141327, 46.746565997600555, 45.314913019537926, 45.882237777113914, 46.4425291121006, 47.44695961475372, 46.64351932704449, 50.42414166033268, 53.81368897855282, 55.537865459918976, 52.34718047082424, 54.494658038020134, 52.64682099223137, 50.346823409199715, 45.157198682427406, 51.13235905766487, 47.03362539410591, 50.00250108540058, 45.70207804441452, 46.76952816545963, 40.7678110152483, 47.03146331012249, 34.49811704456806, 30.719968378543854, 15.345788151025772, 22.390270046889782, 34.65564139187336, 35.75902238488197, 19.71619203686714, 1.1041106726042926, 6.698498586192727, 2.372189909219742, 0.1728720057872124, 0.14697994280140847, 0.024132445687428117, 0.15214119397569448, 0.23911873460747302, 0.0671732408227399, 0.09682168427389115, 0.23508064972702414, 0.09576410899171606, 0.14071663201320916, 0.057715129005373456, 0.020797141260118224, 0.031368122072308324, 0.6134548166301101, 0.330033665522933, 0.6474692851770669, 5.850209780037403, 14.016826562583447, 14.246406443417072, 17.097112275660038, 18.39778248220682, 14.35879111289978, 19.389669857919216, 20.420011170208454, 27.935204207897186, 28.790956288576126, 32.57245257496834, 34.96582634747028, 37.22492292523384, 37.52060405910015, 42.51241900026798, 44.136759638786316, 48.343719094991684, 51.37983597815037, 52.55867712199688, 48.66495005786419, 49.23551224172115, 45.643238201737404, 42.66759127378464, 39.291400238871574, 42.09432743489742, 42.669532969594, 43.22416640818119, 39.0609198063612, 49.800720512866974, 56.857766434550285, 55.613181218504906, 54.717732667922974, 59.061306193470955, 57.879516407847404, 58.26332241296768, 57.61094681918621, 57.56771273910999, 59.69743765890598, 61.76521450281143, 58.57139468193054, 58.27892057597637, 59.28123839199543, 55.9681885689497, 53.36629718542099, 60.16186013817787, 62.35741652548313, 63.52503687143326, 61.64768300950527, 62.62678027153015, 47.314517721533775, 24.887942522764206, 5.856644259765744, 27.778840698301792, 60.36325313150883, 33.0932792276144, 15.301365684717894, 37.96088643372059, 20.588319338858128, 13.548533990979195, 15.409305542707443, 30.39167169481516, 31.448738873004913, 29.84213948249817, 28.2614167034626, 49.98714230954647, 43.54568235576153, 65.8545170724392, 15.72496885433793, 0.4746510257245973, 0.4140573990298435, 0.1090070886129979, 0.09753058373462409, 0.09480607055593282, 0.03508933215925936, 0.020931291874148883, 0.19171170657500625, 0.11552229916560464, 0.3473351168213412, 0.07091664854669943, 0.09956006819265895, 0.10644920985214412, 0.059127966669620946, 0.10079541010782123, 0.03003559962962754, 0.05073245076346211, 0.02177519356337143, 0.23429852997651324, 0.07783177279634401, 0.03124107010080479, 0.18443742737872526, 0.4315055283950642, 2.232134649530053, 55.041661486029625, 66.77690997719765, 39.76437605917454, 38.05146597325802, 42.47536338865757, 28.297738954424858, 27.42766924202442, 27.09748785942793, 26.147198751568794, 21.352245546877384, 30.262775011360645, 53.87116849422455, 45.35894885659218, 46.27959005534649, 22.236511297523975, 4.729338325560093, 10.56936465203762, 28.695195727050304, 42.378932163119316, 52.15727046132088, 53.53936269879341, 47.80515119433403, 53.44971030950546, 68.53659555315971, 65.15137240290642, 64.26633149385452, 62.40956112742424, 64.5865099132061, 64.03605625033379, 58.399009332060814, 53.77116546034813, 50.41809618473053, 48.604662492871284, 50.00657066702843, 47.39661231637001, 47.163551822304726, 44.025744795799255, 50.17876222729683, 48.01008179783821, 47.66377218067646, 47.734805569052696, 49.544682651758194, 49.814038798213005, 53.458305448293686, 52.68120154738426, 58.46433162689209, 55.03406189382076, 57.909736186265945, 56.17501147091389, 53.125990480184555, 51.69849067926407, 54.59654197096825, 51.30178056657314, 51.81105203926563, 50.86611494421959, 52.50478841364384, 44.6756125241518, 48.91667515039444, 38.422827646136284, 41.563165336847305, 32.00646534562111, 28.037832900881767, 49.89161543548107, 45.822512581944466, 25.704326815903187, 23.55307225137949, 13.24643025174737, 0.9888177341781557, 0.21069609647383913, 0.054940602494752966, 0.11522581859026104, 0.33722572959959507, 0.24197199556510895, 0.05792471893073525, 0.052384790615178645, 0.10957587801385671, 0.010487732251931448, 0.09609557440853678, 0.14296787761850283, 0.02338505844818428, 0.0470010992285097, 0.264658618834801, 0.18809302418958396, 0.623755173292011, 3.3628271520137787, 18.895730562508106, 14.453599825501442, 27.304686941206455, 25.6676359847188, 21.223436258733273, 27.677568532526493, 28.05695917457342, 38.90822879970074, 37.25417375564575, 39.46725480258465, 40.08301556110382, 42.29456529021263, 43.97326201200485, 48.11958432197571, 45.583744794130325, 53.1332328915596, 51.88289098441601, 52.90092095732689, 51.09948322176933, 52.61565126478672, 47.78637260198593, 43.70903939008713, 43.13659630715847, 46.59037537872791, 49.19163979589939, 45.26509769260883, 43.778898641467094, 54.69174586236477, 60.7424233853817, 59.84738141298294, 56.7263238877058, 59.066116735339165, 61.91925823688507, 61.15063168108463, 60.93094266951084, 60.34276083111763, 63.18023957312107, 63.69368702173233, 60.46225681900978, 60.43907806277275, 59.40749041736126, 57.959695905447006, 55.46511456370354, 63.4623858332634, 63.06816838681698, 65.77176511287689, 65.09923920035362, 66.29968598484993, 52.42096111178398, 26.391309052705765, 9.563611820340157, 32.370645403862, 63.03902015089989, 36.67641095817089, 18.416505977511406, 46.324363052845, 29.37712423503399, 17.255881056189537, 21.888204887509346, 29.676491171121597, 35.16622759401798, 32.94977232813835, 29.174154326319695, 50.04579596221447, 50.54619871079922, 75.48928007483482, 24.60788045078516, 0.6116752058733255, 0.6190550629980862, 0.003341274309605069, 0.046615401370218024, 0.014278972321335459, 0.0929797935532406, 0.05720146633393597, 0.19108763459371403, 0.11699386668624356, 0.12034762461553328, 0.2291355570196174, 0.3328715788666159, 0.23509145539719611, 0.1217014949361328, 0.276594550232403, 0.15059400902828202, 0.1868008411838673, 0.31629633391276, 0.442011370905675, 0.4645511676790193, 0.16201131278648973, 0.5962085514329374, 0.7520016760099679, 3.3119844552129507, 71.24838843941689, 70.52673116326332, 45.651582553982735, 41.24278552830219, 50.60563512146473, 28.5452975705266, 30.93473095446825, 36.21757037937641, 28.140226006507874, 34.16095353662968, 30.095796771347523, 64.22321140766144, 51.23993128538132, 49.86976660788059, 22.457410544157028, 4.748400477692485, 12.897393330931664, 34.70031179487705, 47.05218359827995, 58.08466359972954, 58.20766679942608, 51.523973643779755, 58.27176555991173, 73.50544452667236, 65.97968995571136, 65.96978768706322, 66.20887085795403, 65.41437149047852, 67.50916108489037, 64.37644958496094, 58.78622755408287, 56.961276680231094, 51.25783212482929, 54.82485271990299, 51.96717046201229, 49.467618986964226, 44.71603475511074, 52.002006992697716, 48.871024399995804, 50.78710958361626, 49.3351086974144, 54.78954121470451, 54.5603147149086, 57.00217388570309, 54.19220566749573, 61.16283282637596, 55.65897636115551, 60.82219250500202, 57.09152989089489, 56.32316552102566, 51.92166790366173, 56.41216054558754, 55.02519316971302, 57.02707774937153, 54.03599604964256, 56.888259798288345, 46.031470969319344, 54.93356868624687, 44.33765105903149, 50.8661225438118, 38.604682087898254, 44.777827039361, 67.64425903558731, 67.72253483533859, 51.448323503136635, 31.662029027938843, 18.253500424325466, 4.406014624983072, 0.49144864780828357, 0.23246281285537407, 0.17302594205830246, 0.3411760035669431, 0.47831990697886795, 0.14953667123336345, 0.15327739238273352, 0.19345452164998278, 0.3128272091271356, 0.17595540673937649, 0.28897962940391153, 0.1763909583678469, 0.43315686634741724, 0.8540194330271333, 0.29853902582544833, 1.354452045634389, 8.798359483480453, 23.49133126437664, 15.421288199722767, 33.31859193742275, 36.83698654174805, 32.87199430167675, 40.767370238900185, 39.13316532969475, 48.47005091607571, 44.233597442507744, 45.23267783224583, 46.55409872531891, 48.33240330219269, 50.7860342413187, 53.96278917789459, 48.50958399474621, 55.90598210692406, 56.437478587031364, 56.85841619968414, 53.81770916283131, 58.110574409365654, 52.105019465088844, 45.98398111760616, 44.1463503241539, 44.49614815413952, 49.252903908491135, 48.45288723707199, 44.902008175849915, 55.84879897534847, 64.56771612167358, 64.93009507656097, 57.10101418197155, 60.28382979333401, 65.2380533516407, 66.41021445393562, 66.96514427661896, 64.86810520291328, 67.56828591227531, 68.24679270386696, 62.0708055049181, 61.356455236673355, 62.497264221310616, 60.01320071518421, 57.47937887907028, 65.55763900279999, 66.23749852180481, 68.08780163526535, 67.42286771535873, 73.28010901808739, 58.469377756118774, 32.62720383703709, 10.660049635916948, 34.560049921274185, 67.706248909235, 48.749316930770874, 23.875416554510593, 47.397619262337685, 27.821159027516842, 19.6651778742671, 25.939439199864864, 43.67796465754509, 45.89694678783417, 42.63746649026871, 36.68908327817917, 66.5950745344162, 61.43698051571846, 88.00435692071915, 25.346209332346916, 0.8280508546158671, 0.838559428229928, 0.2677299524657428, 0.3423109254799783, 0.08147332075168379, 0.3397322294767946, 0.2241445248364471, 0.3370476438431069, 0.28405838878825307, 0.5407742760144174], [0.13609588699182495, 0.1636609883280471, 0.1323354840860702, 0.03302471071947366, 0.12417753707268275, 0.14623607334215194, 0.044795247085858136, 0.039464003275497817, 0.12039164881571196, 0.19762033014558256, 0.07684906537178904, 0.18465794913936406, 0.14190147077897564, 0.4077539825811982, 41.97920121252537, 55.23769676685333, 40.17171420156956, 29.40651945769787, 24.622958041727543, 28.586884438991547, 21.49970803409815, 13.62893957644701, 11.977747678756714, 30.151872262358665, 19.994692392647266, 39.25911337137222, 45.50712950527668, 43.60486797988415, 28.674659729003906, 6.161657692864537, 6.1834371741861105, 23.99109184741974, 38.070130571722984, 48.07463273406029, 50.463454350829124, 45.880033895373344, 54.71283473074436, 67.42691069841385, 66.61402031779289, 65.1503312587738, 58.31668294966221, 58.79689358174801, 54.70930092036724, 49.64239440858364, 45.71892634034157, 45.94949796795845, 44.411541894078255, 43.76083441078663, 46.6346126049757, 45.598837584257126, 43.417522832751274, 45.04564806818962, 46.24873571097851, 45.80189868807793, 46.08451992273331, 45.695831179618835, 44.84233617782593, 49.1807571798563, 51.31210081279278, 54.037952944636345, 49.26339514553547, 51.80437579751015, 52.726403921842575, 50.89647151529789, 48.77013601362705, 50.58416247367859, 46.202735379338264, 46.10565818846226, 45.58428816497326, 47.17381127178669, 43.03139515221119, 42.99470812082291, 35.73772072792053, 21.47144515067339, 16.513792276382446, 23.240487724542618, 44.92624707520008, 33.124186769127846, 7.303689261898398, 12.007707171142101, 8.362229336053133, 1.6361913713626564, 0.10523242162889801, 0.2016797591932118, 0.07736798987025395, 0.05669228994520381, 0.07819023754564114, 0.08115502845612355, 0.042678920217440464, 0.1250760181574151, 0.10347239614930004, 0.03258267272030935, 0.06838527930085547, 0.13976113172248006, 0.28419912967365235, 0.13919573393650353, 0.09117282723309472, 0.4012477520154789, 0.9087242663372308, 0.2788451575906947, 7.720259008929133, 14.361888896673918, 16.834065690636635, 15.90909842401743, 17.361484989523888, 20.23360837250948, 27.25847952067852, 26.425395123660564, 30.517182759940624, 32.3657588660717, 34.830124229192734, 35.28323471546173, 40.2099933475256, 43.8297551125288, 48.07968266308308, 48.89789655804634, 48.537835478782654, 45.87886355817318, 47.208716198801994, 39.92806367576122, 41.78092785179615, 43.416109308600426, 46.220503225922585, 44.55610513687134, 41.720853075385094, 42.45855689048767, 51.32372438907623, 58.29881630837917, 54.94091749191284, 55.417366325855255, 60.32827980816364, 58.04404757916927, 57.62663617730141, 54.81395110487938, 55.33145673573017, 57.59356275200844, 57.466961145401, 53.47004681825638, 51.80852137506008, 50.35276249051094, 52.19714552164078, 52.67481788992882, 58.960102424025536, 60.74423208832741, 61.6802054643631, 61.575312092900276, 61.224492117762566, 48.32611083984375, 21.65880549699068, 8.960398938506842, 35.752661526203156, 63.431744277477264, 22.977748923003674, 24.06757604330778, 34.23815779387951, 9.757978990674019, 14.510482773184776, 13.402151595801115, 35.13423331081867, 25.575981102883816, 35.6967893242836, 20.149292796850204, 42.80730977654457, 41.2326704710722, 62.16571681201458, 37.44866631925106, 0.15696690534241498, 0.09880116282147355, 0.04499710754316766, 0.13745897478656843, 0.03419537446461618, 0.08041014225455001, 0.08439615063252859, 0.14522730169119313, 0.06718087010085583, 0.12158154902863316, 0.2007883062469773, 0.05175622121896595, 0.05506120891368482, 0.08161216173903085, 0.019543189991964027, 0.059157240684726276, 0.15731279068859294, 0.0801950233289972, 0.031473206472583115, 0.0509776303806575, 0.012747955988743342, 0.1299016404664144, 0.17058176774298772, 1.6340918652713299, 56.9815219938755, 60.76835319399834, 50.68991459906101, 36.76995813846588, 28.702981509268284, 36.728456765413284, 25.199615098536015, 18.27446009963751, 18.618229553103447, 29.096328802406788, 22.623767517507076, 39.83505606651306, 46.226351112127304, 49.60371248424053, 34.12541024386883, 8.012694641947746, 5.63866563141346, 22.071565948426723, 36.159828677773476, 47.65015751123428, 51.902174949645996, 49.27306942641735, 61.10757239162922, 67.90489464998245, 69.0089862048626, 68.82749274373055, 62.3953802883625, 59.418642818927765, 55.79624019563198, 53.29021006822586, 48.77644367516041, 48.31769049167633, 47.842594385147095, 47.74068005383015, 49.18929912149906, 48.99722322821617, 44.34090368449688, 49.4394700974226, 49.77501109242439, 48.11481557786465, 46.75691284239292, 51.662502810359, 50.01067444682121, 52.71590508520603, 52.55411356687546, 55.503503903746605, 54.11418825387955, 56.29374369978905, 53.496250212192535, 53.4090980887413, 50.84341876208782, 51.249499171972275, 48.365013152360916, 47.41198629140854, 47.176174744963646, 49.317519441246986, 45.66973797976971, 47.67668388783932, 38.452215269207954, 31.166710406541824, 27.92491625994444, 25.67224893718958, 44.84638296067715, 45.262920409440994, 39.22944836318493, 40.899135768413544, 8.798288237303495, 0.8504249446559697, 0.03400030836928636, 0.11607838299823925, 0.0721474782039877, 0.13875633798306808, 0.34908554633148015, 0.08649412789964117, 0.10791524095111527, 0.14377059938851744, 0.20536643714876845, 0.039445891161449254, 0.011556337703950703, 0.12553108826978132, 0.06778566108550876, 0.07810495735611767, 0.07886134684667923, 0.5793534277472645, 0.38562426692806184, 1.798471282236278, 15.996774919331074, 26.50973729789257, 25.06852213293314, 22.318419702351093, 26.436216942965984, 29.242807142436504, 34.02073346078396, 35.53814023733139, 37.65556521713734, 37.68054507672787, 41.183626502752304, 42.18023702502251, 45.566714107990265, 48.07977765798569, 53.91602508723736, 53.624747917056084, 53.74700255692005, 50.462614595890045, 49.54875983297825, 44.71031226217747, 45.61694361269474, 45.519961416721344, 49.08758617937565, 49.59792539477348, 45.405192375183105, 44.64084818959236, 54.56323675811291, 60.676424726843834, 58.71709406375885, 59.92689974606037, 60.38886375725269, 60.04622094333172, 59.33014936745167, 55.214537009596825, 56.09799340367317, 58.3335692435503, 56.755498722195625, 54.597313329577446, 52.852321565151215, 51.686095744371414, 52.723253890872, 55.193075761199, 61.822998002171516, 65.70298880338669, 62.49194070696831, 63.93951863050461, 66.64485946297646, 51.84345670044422, 22.83009834587574, 11.14470412954688, 39.91352565586567, 64.28278461098671, 25.70583913475275, 28.903008475899696, 38.44928942620754, 16.528204903006554, 17.853064611554146, 18.92451971769333, 33.85770320892334, 29.406042583286762, 38.672580644488335, 26.06062039732933, 51.72965280711651, 49.455235451459885, 66.57764866948128, 50.025649443268776, 0.18081173911923543, 0.1591489085694775, 0.07035859802272171, 0.07032793248072267, 0.039084613672457635, 0.032507400392205454, 0.12261157578905113, 0.07339094663620926, 0.09776830847840756, 0.1348885166225955, 0.46535215282347053, 0.1983299569110386, 0.23462446639314294, 0.224457488511689, 0.21817635133629665, 0.13437751826131716, 0.29418852645903826, 0.29129539732821286, 0.25878742919303477, 0.24981023278087378, 0.21828152850503102, 0.3953556338092312, 0.30351432447787374, 2.3228127462789416, 66.18581369519234, 68.55633929371834, 57.65461027622223, 42.68954649567604, 34.6868035197258, 42.091371193528175, 31.584372594952583, 18.657846227288246, 16.14635579288006, 41.60877048969269, 28.285121731460094, 51.913946717977524, 56.009028777480125, 53.0611127614975, 34.63208645582199, 8.033984899520874, 7.702887766063213, 26.589842699468136, 42.4141600728035, 51.372597366571426, 59.097047075629234, 55.63525803387165, 65.99552750587463, 70.8198094367981, 72.29618221521378, 71.38323560357094, 63.49502608180046, 63.26749049127102, 60.717139542102814, 58.47844026982784, 50.926463305950165, 50.075221583247185, 49.88685429096222, 49.64151665568352, 54.58796963095665, 51.66534885764122, 44.64119017124176, 52.12897717952728, 50.25188930332661, 48.86784017086029, 48.23174670338631, 54.209490939974785, 54.8865120112896, 57.55117982625961, 55.525284335017204, 57.182508409023285, 55.20425856113434, 59.50040303170681, 57.12153688073158, 55.62788262963295, 51.61694325506687, 56.142458617687225, 52.81055800616741, 51.46294891834259, 53.545453771948814, 52.840933576226234, 49.395821839571, 53.022582828998566, 43.57161596417427, 40.33867344260216, 34.74690109491348, 41.62821024656296, 65.16826629638672, 69.27891612052917, 48.99544112384319, 52.31480620801449, 29.43033277988434, 2.1100476756691933, 0.24226146284490824, 0.3746473981300369, 0.28236510464921594, 0.24972883402369916, 0.23074497847119346, 0.255045045632869, 0.24651183164678514, 0.46067585062701255, 0.3522427019197494, 0.17217183398315683, 0.1782905892468989, 0.4142709297593683, 1.2797338049858809, 0.4667220386909321, 0.20140684180660173, 0.9193411935120821, 0.691290789982304, 3.7828734749928117, 17.32139904052019, 30.788271613419056, 29.16978646069765, 30.021066181361675, 36.691214963793755, 38.07621784508228, 43.80439147353172, 44.798927307128906, 45.180058255791664, 44.67271327972412, 45.94781085848808, 47.86749064922333, 50.130360424518585, 50.46581022441387, 56.61901004612446, 59.52564887702465, 55.945564582943916, 53.6993683129549, 55.39951868355274, 47.801693379879, 45.60848906636238, 46.6942086070776, 52.53455601632595, 52.86408193409443, 48.84882599115372, 48.057051077485085, 56.81183069944382, 64.57280784845352, 59.829917550086975, 61.198277324438095, 64.21115085482597, 61.78461246192455, 65.08005782961845, 61.500372514128685, 61.97354592382908, 65.14855295419693, 63.565979674458504, 58.10397796332836, 55.57120867073536, 54.47666980326176, 55.97431384027004, 57.08130843937397, 65.12776806950569, 66.76099643111229, 63.758853524923325, 66.41307190060616, 68.12995657324791, 57.97895327210426, 29.451693333685398, 12.33820678666234, 41.2759767472744, 68.3350619673729, 36.44097559154034, 34.503436759114265, 38.46620611846447, 14.299323353916407, 18.442452885210514, 22.854310646653175, 50.39729990065098, 38.914829045534134, 46.650412157177925, 25.854861438274384, 58.75355690717697, 55.81312268972397, 77.86632612347603, 54.08741109073162, 0.19193254003766924, 0.8168450777884573, 0.41826668253634125, 0.26041371223982424, 0.13625273248180747, 0.40262479218654335, 0.2424380197771825, 0.203796275309287, 0.15828982810489833, 0.37405148323159665], [0.17315457109361887, 0.054889913808437996, 0.1684422153630294, 0.05113897699629888, 0.09299156401539221, 0.040049357412499376, 0.07774867452098988, 0.07367111480562016, 0.12101681175408885, 0.08709169778740034, 0.03893388719006907, 0.09641153636039235, 0.44057362305466086, 5.291122505441308, 63.31603288650513, 49.98456224799156, 40.1973932236433, 32.611381486058235, 42.35040709376335, 28.15504901111126, 28.591546788811684, 15.213744286447763, 16.569012813270092, 18.797688223421574, 33.63053999841213, 19.63698908686638, 44.97860446572304, 52.60394029319286, 50.03666125237942, 13.930351752787828, 4.927539015188813, 16.91687274724245, 31.600073352456093, 44.80392783880234, 43.381147384643555, 43.068025186657906, 59.0409354865551, 65.64514830708504, 64.85754936933517, 63.02956245839596, 59.35999296605587, 58.987457156181335, 55.01654103398323, 49.41083863377571, 45.56924857199192, 49.46729600429535, 45.710733979940414, 43.48506420850754, 45.39227306842804, 45.04429534077644, 48.7297859787941, 47.10262589156628, 47.76449337601662, 48.96116316318512, 47.54774160683155, 47.26494938135147, 43.73214974999428, 46.14472009241581, 47.41092994809151, 53.98417443037033, 51.41191005706787, 51.10530450940132, 52.4621395021677, 51.93666569888592, 47.44935728609562, 48.40751767158508, 44.49521340429783, 46.78329482674599, 43.10492880642414, 44.58652250468731, 40.31685881316662, 42.70869366824627, 32.02847756445408, 13.387112952768803, 14.689747653901577, 22.769630290567875, 39.69532996416092, 36.70467384159565, 33.58718432486057, 10.758644845336676, 1.4430925017222762, 0.14681333064800128, 0.03911061110557057, 0.12570512189995497, 0.6437547469977289, 0.20102033129660413, 0.08942678381572478, 0.07342722281464376, 0.255806696950458, 0.14174716343404725, 0.12656466249609366, 0.032337032971554436, 0.18178157770307735, 0.06263025061343797, 0.240212986827828, 0.3911397897172719, 0.6942351569887251, 0.1310252075199969, 0.4059007507748902, 0.8491208427585661, 3.2970481691882014, 10.585045460611582, 17.03853651881218, 18.928232118487358, 12.738006133586168, 17.890598997473717, 24.779087863862514, 25.076682195067406, 29.193698577582836, 28.663435131311417, 35.92894546687603, 36.319317519664764, 39.17935565114021, 45.18033564090729, 47.12655320763588, 47.45093800127506, 47.28190027177334, 45.995422303676605, 42.17361018061638, 41.393960416316986, 44.74317669868469, 46.757026836276054, 47.618516609072685, 48.390566781163216, 42.364652529358864, 43.98508317768574, 53.810968324542046, 57.08955779671669, 56.43943168222904, 58.49378764629364, 56.66714586317539, 58.83653685450554, 51.2150502204895, 49.19326990842819, 49.27546709775925, 46.88223771750927, 47.40250200033188, 47.41790257394314, 48.04230406880379, 46.79572395980358, 50.55636316537857, 56.68040715157986, 60.51971733570099, 61.28038331866264, 60.26739187538624, 61.827789545059204, 62.73815609514713, 42.575791999697685, 13.986500389873981, 9.558330103754997, 45.44741190969944, 50.16134396195412, 22.300355471670628, 16.445644833147526, 18.55277046561241, 23.067653998732567, 22.049050256609917, 18.32255031913519, 30.94983134418726, 29.159608706831932, 31.433767676353455, 27.867510840296745, 43.66748861968517, 47.5778815895319, 54.02561500668526, 56.535091549158096, 2.7482932526618242, 0.28802504937630147, 0.2187135475105606, 0.15064005187014118, 0.08894008336937986, 0.02667602511792211, 0.049878680365509354, 0.058358411479275674, 0.1410893237334676, 0.15818934130948037, 0.13602318620542064, 0.04280048771761358, 0.18990530428709462, 0.06659175327513367, 0.05145043040101882, 0.13564198947278783, 0.2637067105388269, 0.0898026890354231, 0.01214329024151084, 0.007605315095133847, 0.05340460913430434, 0.14576610090443864, 0.4712999617913738, 7.4029522854834795, 75.28073966503143, 62.415644600987434, 47.182030230760574, 37.14021027088165, 52.5472055375576, 35.23797154426575, 30.53680680692196, 23.128370940685272, 23.013552501797676, 23.715610429644585, 33.31265665590763, 26.044556759297848, 50.945500284433365, 58.66290897130966, 62.95574761927128, 19.56362832337618, 6.172114731743932, 14.741105698049068, 28.56224276125431, 42.9328740388155, 45.6072199344635, 47.06830993294716, 63.50042559206486, 66.16990014910698, 66.62769958376884, 65.77814877033234, 63.387377858161926, 58.37394207715988, 56.92974217236042, 53.779935389757156, 51.320939138531685, 50.03301724791527, 46.3953622430563, 49.625230729579926, 49.965741857886314, 50.16941852867603, 53.579891324043274, 53.60188454389572, 53.65174926817417, 53.03751602768898, 50.50551429390907, 47.76746101677418, 48.56185019016266, 51.18697352707386, 55.118717551231384, 56.82372026145458, 55.288260653615, 54.188679456710815, 57.75632321834564, 54.768619537353516, 51.026021763682365, 52.76954300701618, 47.99731068313122, 49.13203999400139, 46.918430775403976, 50.78598104417324, 46.82147517800331, 49.11093592643738, 36.576582714915276, 25.83877120167017, 24.585007578134537, 26.309440545737743, 33.37618164718151, 47.338467836380005, 55.30583471059799, 31.07343301177025, 3.316874555312097, 0.10004751820815727, 0.18389931094134226, 0.1687008686712943, 0.1527323739719577, 0.19276499224361032, 0.10865018237382174, 0.07928023725980893, 0.025198314469889738, 0.08734511153306812, 0.04582958201353904, 0.03441076056333259, 0.06410277550457977, 0.005721791603718884, 0.21211631479673088, 0.22661795461317524, 0.8330579765606672, 0.05460613880131859, 0.35396742343436927, 0.647098864428699, 8.365106731653214, 16.674747839570045, 26.13466702401638, 24.88088820129633, 18.916492648422718, 26.449035555124283, 32.16460905969143, 33.743853718042374, 36.55433110892773, 33.945816680788994, 39.78740282356739, 40.3964227437973, 46.523472368717194, 46.3265061378479, 51.415728852152824, 50.42294852435589, 51.40665873885155, 48.236872628331184, 42.66338869929314, 45.62127538025379, 51.501995623111725, 53.076091557741165, 53.01239177584648, 49.98693712055683, 45.14991067349911, 48.52980650961399, 58.16272661089897, 60.88847614824772, 63.78685042262077, 63.87492209672928, 60.23367628455162, 57.77012027800083, 51.50632359087467, 49.43549931049347, 51.520097851753235, 50.63927471637726, 51.41831651329994, 51.30274571478367, 49.81519013643265, 52.44706191122532, 55.06656914949417, 60.26578836143017, 63.81875351071358, 65.56103602051735, 63.763732463121414, 65.25531202554703, 63.37674982845783, 45.146589651703835, 15.967508889734745, 11.206971388310194, 52.103940322995186, 54.62413989007473, 28.616063073277473, 20.94601694494486, 22.673449851572514, 26.5748905017972, 24.55628491938114, 21.20885644108057, 31.616900749504566, 30.313583984971046, 33.36909122765064, 32.37062260508537, 55.3243663161993, 63.58423389494419, 64.2406752705574, 69.48487266898155, 7.408678578212857, 0.27766986284404993, 0.11693857668433338, 0.09775955113582313, 0.13367958774324507, 0.03843218051770236, 0.0641955439641606, 0.006694963358313544, 0.10741178281023167, 0.1127632093266584, 0.2632305189035833, 0.1609290239866823, 0.39475235680583864, 0.10735141651821323, 0.15093171590706334, 0.22096581727964804, 0.39752145821694285, 0.13846247718902305, 0.14662853587651625, 0.22525387234054506, 0.1611448108451441, 0.5838339810725302, 0.7167224097065628, 8.55330303311348, 89.41826865077019, 65.84970653057098, 57.544921562075615, 49.286091327667236, 64.22783195972443, 40.23192197084427, 39.02519792318344, 20.560335740447044, 23.096038475632668, 25.90245008468628, 43.61490324139595, 32.04765893518925, 58.42142432928085, 60.86610294878483, 56.75542652606964, 17.203818149864674, 7.197990333661437, 16.81223016232252, 33.00196632742882, 47.75942824780941, 52.42399334907532, 50.53918428719044, 69.03623834252357, 68.66313636302948, 68.28647777438164, 68.23116034269333, 64.13360461592674, 60.21896347403526, 57.38375701010227, 56.39476127922535, 51.91158324480057, 53.23255956172943, 47.21856527030468, 52.26040452718735, 52.63350650668144, 50.664011389017105, 54.00503911077976, 56.41328528523445, 54.3942104279995, 55.439180955290794, 53.73676970601082, 52.946142330765724, 53.69998387992382, 54.58797723054886, 53.83824326097965, 58.618029579520226, 53.91566410660744, 55.489406660199165, 58.67556229233742, 57.280170768499374, 52.38852985203266, 55.3464887291193, 49.94798921048641, 53.5719383507967, 48.9656051248312, 54.32770639657974, 52.31681630015373, 56.20113506913185, 42.18951232731342, 32.37052381038666, 32.1998255699873, 44.424601793289185, 51.34778089821339, 63.09094816446304, 69.50859099626541, 52.94985853135586, 12.634932864457369, 0.13575003133155406, 0.34069978224579245, 0.4071479744743556, 1.9783165818080306, 0.4377715406008065, 0.25122628023382276, 0.15072539885295555, 0.2633078506914899, 0.478155892342329, 0.20778076228452846, 0.18924712319858372, 0.24479845014866441, 0.10609364690026268, 0.5004052422009408, 0.8818981214426458, 1.8254161113873124, 0.23580126027809456, 0.8997955766972154, 0.8069389499723911, 11.488922908902168, 23.45614705234766, 35.73304697871208, 37.46161602437496, 34.080310463905334, 37.75566704571247, 42.34729506075382, 40.15115350484848, 44.2299610376358, 37.10043400526047, 46.54173418879509, 44.68510441482067, 49.646479189395905, 51.881971433758736, 55.92924065887928, 54.31588143110275, 54.85880009829998, 50.62649980187416, 48.16145047545433, 47.133487835526466, 53.738472014665604, 53.45727950334549, 54.41592626273632, 52.721566781401634, 48.24353367090225, 50.396327152848244, 62.126909494400024, 63.295631781220436, 67.28231325745583, 66.09360784292221, 63.6344899982214, 62.86710977554321, 57.111307829618454, 53.73642772436142, 55.09772747755051, 52.79441647231579, 56.06883376836777, 53.86793486773968, 52.797201722860336, 51.90746806561947, 54.46949198842049, 63.95193636417389, 66.29392549395561, 66.14724576473236, 65.38261279463768, 67.98306405544281, 67.9898276925087, 52.83557966351509, 20.8355625718832, 13.0828195810318, 55.194436088204384, 61.530523896217346, 37.35332563519478, 23.726439848542213, 23.637946397066116, 32.62295566499233, 29.13647174835205, 27.086438052356243, 42.61286661028862, 42.013095393776894, 43.348039761185646, 37.77352228760719, 55.0960061699152, 68.28255638480186, 67.73581132292747, 82.36656904220581, 8.349115289747715, 0.5468928383197635, 0.5092385807074606, 0.222631077922415, 0.3074933937750757, 0.2216764385229908, 0.10204097139649093, 0.15033780480735004, 0.3099153481889516, 0.20427513867616653], [0.04586123090120964, 0.058214394011883996, 0.052188577901688404, 0.05396788437792566, 0.02155364207283128, 0.07138250206480734, 0.22224311280297115, 0.06423123384593055, 0.014284424323705025, 0.07488275994546711, 0.08372582800802775, 0.049640684737823904, 0.23181563039543107, 14.816802386194468, 60.73566734790802, 44.31255720555782, 38.82820889353752, 37.22792096436024, 26.331367269158363, 29.507943615317345, 29.593539722263813, 17.65381470322609, 27.69337948411703, 19.510336183011532, 31.085143983364105, 23.38217832148075, 40.90755231678486, 45.8534999191761, 40.70913836359978, 27.772542536258698, 3.9116414403542876, 8.315317053347826, 20.377196967601776, 38.650104850530624, 37.153285369277, 43.378833308815956, 58.09545122087002, 66.44340947270393, 64.57105234265327, 62.86982282996178, 58.98329637944698, 58.45170110464096, 56.06579773128033, 52.399055287241936, 47.52287954092026, 46.31567291915417, 45.101261883974075, 47.90392689406872, 47.996991500258446, 49.30928148329258, 49.79366809129715, 49.893154352903366, 52.82261475920677, 49.81582850217819, 49.57482263445854, 48.42320702970028, 44.12819869816303, 43.109047785401344, 47.25361078977585, 53.7780848890543, 52.7891081571579, 51.57358378171921, 55.1702655851841, 53.60384903848171, 49.721281975507736, 46.720719784498215, 45.779061913490295, 44.30506020784378, 43.91814976930618, 44.668651297688484, 41.24582156538963, 37.74252735078335, 32.54472926259041, 7.650323286652565, 13.165329303592443, 19.416080340743065, 25.865639559924603, 42.962147668004036, 32.4952445179224, 2.1309019066393375, 0.33942281326744705, 0.057693439739523456, 0.08805605189991184, 0.06658157843048684, 0.32244161353446543, 0.7971290044952184, 0.257926270714961, 0.03692093407153152, 0.20341172406915575, 0.18523320264648646, 0.057496562803862616, 0.04959569574566558, 0.10960578656522557, 0.010864182950172108, 0.19072178547503427, 0.24622208235086873, 0.42673758580349386, 0.4445317934732884, 0.5005615088157356, 0.5922258901409805, 0.6871917005628347, 4.6496466267853975, 12.321606427431107, 16.062264405190945, 12.525698225945234, 14.109941516071558, 21.21826283633709, 23.016349151730537, 29.015588834881783, 27.942792400717735, 36.290180683135986, 34.90325130522251, 41.84386007487774, 42.41560019552708, 45.767449736595154, 46.07206419110298, 46.89597398042679, 39.936924800276756, 40.13174034655094, 42.81889535486698, 47.11176060140133, 49.10968579351902, 49.33697059750557, 44.581100195646286, 40.389385521411896, 47.099829241633415, 55.00681355595589, 61.18239797651768, 59.45490047335625, 57.07875117659569, 56.19056783616543, 52.440712451934814, 48.437471464276314, 47.23037123680115, 47.152076438069344, 52.302076891064644, 49.13301274180412, 51.02427005767822, 50.62751814723015, 54.98475953936577, 56.86554081737995, 61.80932253599167, 63.01290035247803, 65.77292025089264, 62.24952131509781, 63.93121987581253, 53.61725091934204, 36.13202936947346, 8.257159274071455, 10.375696644186974, 50.31967766582966, 45.62166675925255, 19.144736900925636, 10.781009495258331, 21.227684430778027, 27.330650947988033, 24.103810898959637, 20.273897610604763, 30.628024712204933, 30.10629180818796, 32.58201286196709, 28.937539122998714, 28.198064602911472, 38.733191192150116, 43.730493038892746, 68.94721671938896, 18.92218094319105, 0.7170057320035994, 0.10947955466690473, 0.02130273493094137, 0.037533402573899366, 0.061673518357565627, 0.041219757695216686, 0.09164328206679784, 0.1901333365822211, 0.11732456769095734, 0.059005497460020706, 0.029951885371701792, 0.08341233740793541, 0.04905840309220366, 0.03589541956898756, 0.059633495402522385, 0.23706726031377912, 0.01915885768539738, 0.02928461482952116, 0.07380643059150316, 0.038999990283627994, 0.08085824360023253, 0.4449543129885569, 21.22443750500679, 71.76475793123245, 50.74845425784588, 41.81630775332451, 42.0948252081871, 36.695083156228065, 38.36649566888809, 31.364140212535858, 21.389857828617096, 28.04315071552992, 23.09290934354067, 34.101707115769386, 33.15976805984974, 47.40874506533146, 54.95252586901188, 49.886386916041374, 37.29521535336971, 5.106492787599564, 5.85105855949223, 17.780587300658226, 33.094669952988625, 36.69428899884224, 44.86196592450142, 57.73938372731209, 67.61609494686127, 66.30268022418022, 67.01696589589119, 64.15941283106804, 63.6085943877697, 59.13223698735237, 57.93571539223194, 53.540293648839, 49.73804287612438, 47.13470757007599, 50.49148924648762, 51.39741003513336, 56.44267290830612, 55.7563841342926, 54.79983866214752, 58.5649274289608, 56.99907325208187, 53.325886353850365, 50.367068722844124, 45.430035442113876, 47.84501865506172, 52.43690885603428, 60.10672129690647, 57.66718380153179, 57.498666644096375, 59.17358636856079, 55.73553465306759, 55.1086100935936, 52.07303658127785, 49.84948709607124, 48.84380646049976, 49.614914283156395, 49.49048615992069, 47.31576785445213, 45.55256746709347, 37.6162601262331, 21.19621641933918, 24.79856561869383, 21.1398521438241, 27.50963844358921, 48.85026231408119, 45.28018668293953, 12.521604895591736, 0.9416826290544122, 0.07933902277727611, 0.058371035411255434, 0.03276714836829342, 0.28240954445209354, 0.402228485327214, 0.10026799543993548, 0.11410377293941565, 0.024368118392885663, 0.059834379935637116, 0.05206810878007673, 0.04741197444673162, 0.05337836679245811, 0.031807310224394314, 0.10896699779550545, 0.3041091706836596, 0.3939190140226856, 1.3343572989106178, 0.8003128773998469, 0.5837501480709761, 1.348883444443345, 8.304414488375187, 23.51280391216278, 20.93601018190384, 12.193592246621847, 24.12847727537155, 29.10419438034296, 34.71361108124256, 36.158335357904434, 37.376261204481125, 39.35343571007252, 41.369056552648544, 43.76763604581356, 47.16276906430721, 47.583915665745735, 49.80189085006714, 48.37420865893364, 46.83302275836468, 43.70549418032169, 47.964757829904556, 50.7772833108902, 55.85503824055195, 53.62151049077511, 50.988342985510826, 43.43733876943588, 52.49800197780132, 59.15315106511116, 65.50513342022896, 62.83860370516777, 60.445864498615265, 58.48432995378971, 52.61995643377304, 47.99247734248638, 48.78353409469128, 48.93305987119675, 52.93628565967083, 52.57557861506939, 54.69687178730965, 55.513615161180496, 61.29574969410896, 62.90081776678562, 65.54399773478508, 66.86884984374046, 69.45199683308601, 66.37924611568451, 68.85343015193939, 54.853051006793976, 32.84413419663906, 7.489451793953776, 11.852830331772566, 57.85862132906914, 48.65152917802334, 25.261272490024567, 11.114798784255981, 24.299844279885292, 26.016196981072426, 25.666596740484238, 21.28712274134159, 33.64827744662762, 28.258154578506947, 38.00671577453613, 31.36495526880026, 38.641357719898224, 44.243777096271515, 55.29525987803936, 77.77623295783997, 40.08156783878803, 0.42649172712117434, 0.11744369723601267, 0.0671534551656805, 0.05065130062575918, 0.04822971357498318, 0.06975770331337117, 0.06558981680427678, 0.0628609694831539, 0.054076820524642244, 0.1380536874057725, 0.11992661166004837, 0.31584970944095403, 0.12855159962782636, 0.10594567749649286, 0.2480424815439619, 0.46012606762815267, 0.12921892397571355, 0.14343866641866043, 0.15072464186232537, 0.13675942638656124, 0.2623075543669984, 0.689526794012636, 24.76397417485714, 85.04392817616463, 58.74316066503525, 55.39434716105461, 60.407353565096855, 41.07975907623768, 46.37141212821007, 43.689485639333725, 20.261660367250443, 39.43310223519802, 27.551774382591248, 40.41713543236256, 36.54434144496918, 57.152151837944984, 60.417977795004845, 53.85121576488018, 34.09332096576691, 5.293075125664473, 9.201653692871332, 21.72510053962469, 38.27518656849861, 42.02970810234547, 50.7626198977232, 64.28039073944092, 70.20766228437424, 67.23695129156113, 67.51521036028862, 66.78165972232819, 67.34985083341599, 64.24748450517654, 62.15888097882271, 57.133544236421585, 51.846545934677124, 49.395818039774895, 54.059501588344574, 55.049207881093025, 59.31255251169205, 61.08480021357536, 55.22725872695446, 60.688903257250786, 57.53218464553356, 54.36866819858551, 54.01936814188957, 48.80675844848156, 51.66623421013355, 55.63935041427612, 63.07806685566902, 60.12554548680782, 59.96479511260986, 64.07753482460976, 59.229705557227135, 56.16450123488903, 53.91845315694809, 55.00844366848469, 52.54018351435661, 52.18207933008671, 54.96603414416313, 54.3179789185524, 50.106341913342476, 44.201895743608475, 27.624663971364498, 33.380790799856186, 37.98864774405956, 40.38813158869743, 61.86248928308487, 53.26839543879032, 20.307907685637474, 1.4853033679537475, 0.2167256604298018, 0.2030038248631172, 0.21203815180342644, 0.5213095236103982, 2.1635649539530277, 0.6654452299699187, 0.1978566002799198, 0.3007782041095197, 0.20032140630064532, 0.1719054178101942, 0.16858194692758843, 0.18377961736405268, 0.17508479329990223, 0.27071647346019745, 0.32309494097717106, 0.5606875231023878, 1.8730744603089988, 1.0625228541903198, 1.3828692957758904, 2.105055693536997, 10.017417669296265, 36.1970666795969, 29.287038668990135, 24.075563214719296, 36.07150241732597, 37.77386426925659, 42.44252935051918, 42.21627429127693, 42.57878243923187, 45.64705319702625, 44.30277653038502, 50.41148453950882, 51.22348956763744, 53.300195932388306, 54.32682864367962, 54.17152337729931, 49.18462157249451, 47.920740991830826, 50.041494593024254, 52.94962674379349, 57.01518818736076, 55.07658161222935, 50.36004289984703, 46.59819915890694, 55.21248511970043, 61.2891760468483, 68.20577010512352, 66.55458390712738, 61.88728295266628, 62.04835630953312, 58.59482042491436, 52.441871389746666, 52.09710828959942, 51.399735510349274, 56.44841820001602, 54.714320451021194, 56.58614560961723, 56.120024621486664, 59.54319253563881, 64.14388686418533, 65.84728226065636, 68.6462652683258, 71.26652106642723, 70.45632094144821, 71.050745844841, 59.042945578694344, 40.32487638294697, 11.514443289488554, 13.445888198912144, 61.39206312596798, 54.461086839437485, 32.02131114900112, 16.44015222787857, 33.8197660446167, 38.69118444621563, 32.11074694991112, 28.09819456189871, 45.358796864748, 42.93580748140812, 46.29904121160507, 39.89272937178612, 34.847010523080826, 50.58491863310337, 53.53735260665417, 90.72666004300117, 42.016519010066986, 0.985987123567611, 0.24274528375826776, 0.24086646270006895, 0.17172903899336234, 0.13418326852843165, 0.14930926234228536, 0.2505568036576733, 0.24240389582701027, 0.2650342049309984], [0.0491072401200654, 0.010607816384435864, 0.050701069048955105, 0.004890752725259517, 0.09111651306739077, 0.025478779498371296, 0.1595781816286035, 0.14287950267316774, 0.04866161754762288, 0.05828629327879753, 0.09136344786384143, 0.11892848982824944, 0.13657446834258735, 26.53392679989338, 62.806066051125526, 45.88098384439945, 54.869891703128815, 32.23265960812569, 19.056807719171047, 27.026779353618622, 34.32701222598553, 26.103506796061993, 33.05490888655186, 22.134245485067368, 21.691755428910255, 39.04624879360199, 33.69161792099476, 57.152015045285225, 32.53291189670563, 22.329013533890247, 11.347029972821474, 2.4858173495158553, 9.517882224172354, 24.96354516595602, 30.179492980241776, 36.486835330724716, 48.88687714934349, 62.652029916644096, 62.6935388892889, 65.22695794701576, 59.05961148440838, 58.2514176517725, 55.59703588485718, 52.849319726228714, 49.83482368290424, 46.73463463783264, 44.73896272480488, 48.930134028196335, 49.296027794480324, 52.30535231530666, 53.56976106762886, 53.99814248085022, 53.97210627794266, 52.815687730908394, 51.77635610103607, 48.942722752690315, 43.210851922631264, 46.10635735094547, 46.97817116975784, 55.757037699222565, 54.61478479206562, 53.08299198746681, 53.698220774531364, 56.8646364659071, 51.184363067150116, 50.93340553343296, 45.08612349629402, 49.08796235918999, 44.0581988543272, 40.724341347813606, 41.524901390075684, 37.476214841008186, 36.45255737006664, 4.55801454372704, 15.482231229543686, 14.24177449196577, 23.764059729874134, 41.15911401808262, 25.32179184257984, 4.84710113145411, 0.4980321804760024, 0.021441841236082837, 0.01413319132552715, 0.05740815446188208, 0.08432221045950428, 0.2098784426925704, 0.5928161053452641, 0.174778449581936, 0.029712416580878198, 0.008104017924779328, 0.02275843533425359, 0.03229683454264887, 0.005616203934550867, 0.050553938272059895, 0.043253880576230586, 0.11976264155237004, 0.12128266389481723, 0.36518204666208476, 0.2479549971758388, 0.28357056027743965, 0.3722312324680388, 3.6532370187342167, 7.802491821348667, 12.992654219269753, 8.10484729707241, 9.623978231102228, 18.997439704835415, 22.569109350442886, 27.083749696612358, 30.001043155789375, 32.54216060042381, 35.01969985663891, 37.11858183145523, 38.647988364100456, 42.30841934680939, 41.63818471133709, 41.05475641787052, 37.87445247173309, 41.50616839528084, 47.42701828479767, 50.01496821641922, 53.04334491491318, 53.2899858802557, 48.773483633995056, 39.49587106704712, 49.02490854263306, 57.07354165613651, 61.078781336545944, 60.75603045523167, 60.60549393296242, 52.141516506671906, 46.72016121447086, 44.73610907793045, 46.95879980921745, 48.1080861389637, 49.507794231176376, 49.89820808172226, 58.38783033192158, 60.535965263843536, 64.88531067967415, 63.32987554371357, 66.28288328647614, 66.08084812760353, 67.19750180840492, 63.250087425112724, 62.796547561883926, 46.04301854968071, 22.41567738354206, 2.5005422718822956, 26.18679452687502, 62.20261663198471, 44.11637373268604, 12.616439256817102, 10.071080289781094, 21.27640351653099, 29.5324731990695, 24.944177605211735, 24.022514261305332, 28.748514465987682, 31.13794405013323, 33.711285665631294, 29.007588364183903, 25.46017661690712, 33.09244327247143, 34.703940600156784, 63.921097218990326, 60.20823284983635, 4.417851939797401, 0.26453275058884174, 0.06883485009893775, 0.08826341538224369, 0.13670346845174208, 0.0933217529382091, 0.04511790692049544, 0.01194326196127804, 0.20167025970295072, 0.06467106024501845, 0.04678285957197659, 0.011350828663125867, 0.01837158743001055, 0.09004779814858921, 0.06411018955986947, 0.05206239424296655, 0.07424782292218879, 0.019549568751244806, 0.059090807335451245, 0.02649463123816531, 0.12725417705951259, 0.015295152461476391, 39.783899411559105, 72.8238371014595, 50.65282478928566, 62.14693821966648, 34.56153944134712, 27.64254581183195, 33.28889273107052, 33.30017812550068, 29.234318397939205, 34.97449368238449, 24.05381888151169, 33.336781561374664, 49.34777341783047, 35.634271278977394, 57.87601679563522, 31.939455941319466, 24.47848979383707, 16.84765186160803, 3.204668238759041, 8.477519899606705, 23.383546248078346, 31.889583617448807, 37.13366702198982, 51.17324486374855, 67.41317823529243, 66.67397350072861, 68.09554561972618, 64.5377205312252, 64.42293629050255, 58.32056634128094, 55.82722373306751, 54.867250844836235, 52.27808877825737, 50.63729502260685, 52.518395483493805, 53.3110823482275, 55.87009683251381, 56.75602309405804, 59.30569387972355, 57.42276951670647, 58.209825083613396, 57.363428100943565, 52.66252174973488, 47.94817551970482, 46.782135888934135, 47.92146675288677, 55.841571763157845, 57.0019268989563, 56.677986681461334, 56.617566123604774, 57.57219269871712, 54.382837638258934, 52.163794711232185, 47.76926591992378, 51.38925567269325, 47.12923966348171, 47.31992483139038, 46.12426199018955, 44.63011376559734, 40.65042771399021, 17.74514090269804, 23.036516569554806, 18.344591036438942, 29.927015528082848, 46.322960928082466, 28.4348051995039, 6.515299491584301, 0.32644775637891144, 0.04124123544897884, 0.01322726093349047, 0.05361071838706266, 0.05539351295738015, 0.12298962581553496, 0.17852973891422153, 0.027899878587049898, 0.03261265919718426, 0.06139425931905862, 0.1276666478952393, 0.022901638294570148, 0.09173674814519472, 0.053590639581670985, 0.01810964084143052, 0.18519518984248862, 0.07262294995598495, 0.4704885568935424, 0.2128407548298128, 0.12505860737292096, 0.6308673822786659, 5.0133194122463465, 15.863637663424015, 17.425213269889355, 12.307174801826477, 20.977374762296677, 27.198587134480476, 31.997851207852364, 37.32687525451183, 38.793953731656075, 38.32168087363243, 39.345338344573975, 41.10762298107147, 42.57892683148384, 47.751019299030304, 45.95715835690498, 41.39461398124695, 42.35801048576832, 45.66937319934368, 49.90657143294811, 52.62764722108841, 56.38713888823986, 56.43241725862026, 52.80271142721176, 44.280958101153374, 53.69939871132374, 56.6751254349947, 60.70750705897808, 59.98350910842419, 58.79984602332115, 52.24958650767803, 47.164665162563324, 45.33074676990509, 48.626271933317184, 48.76007795333862, 51.39034241437912, 52.12138518691063, 60.458992794156075, 63.52351315319538, 68.17778080701828, 64.01078760623932, 67.34675019979477, 67.51503556966782, 66.54780507087708, 66.7043186724186, 62.12792783975601, 43.95081661641598, 17.883221693336964, 2.944571007974446, 31.682601124048233, 67.01998293399811, 44.74506139755249, 15.89306328445673, 11.891794390976429, 23.186694011092186, 24.922653660178185, 28.062940053641796, 23.93481496721506, 30.69945327937603, 28.843480870127678, 37.25226245820522, 30.60559071600437, 35.30665285885334, 37.3434803634882, 46.7596372961998, 80.89595675468445, 72.17082694172859, 24.65311322361231, 0.24118946021189913, 0.06817591201979667, 0.08060615087742917, 0.15668404317693785, 0.11207698247744702, 0.03533516115567181, 0.06644557986874133, 0.059118463468621485, 0.11550438372069038, 0.1441701568546705, 0.11868617119034752, 0.12835271889343858, 0.19116573821520433, 0.13273165735881776, 0.20343654148746282, 0.13787036208668724, 0.09737482920172624, 0.17775471409549937, 0.12940569286001846, 0.3535274782916531, 0.28569126210641116, 46.82299889624119, 86.23917683959007, 55.937930792570114, 73.0748288333416, 45.96436657011509, 29.16239395737648, 40.53640343248844, 48.56610216200352, 32.974136620759964, 48.08830440044403, 33.311193734407425, 28.707370273768902, 49.76483903825283, 42.614397928118706, 67.3861388862133, 40.94884850084782, 28.95105879753828, 14.458953738212585, 3.828239240683615, 11.980262193828821, 27.461054250597954, 37.072323113679886, 40.30542902648449, 57.64116659760475, 68.03072109818459, 70.07710129022598, 70.26244014501572, 65.50745889544487, 66.57211616635323, 61.2053981423378, 60.1435337215662, 58.4004532545805, 53.6144694685936, 53.96523244678974, 55.620993599295616, 57.83166937530041, 59.44462962448597, 60.10320648550987, 60.74433848261833, 60.62418133020401, 59.95840385556221, 60.00829517841339, 53.56231726706028, 49.56465817987919, 51.39709085226059, 53.04116003215313, 61.1831883341074, 60.16398422420025, 59.98209938406944, 59.86875906586647, 59.43709082901478, 57.89479158818722, 55.16093708574772, 50.457906648516655, 57.36902140080929, 54.083314910531044, 53.09866614639759, 50.42094223201275, 51.86422258615494, 48.40972915291786, 22.167932577431202, 34.186678156256676, 32.95361012220383, 43.96334834396839, 55.3663844615221, 32.91403524577618, 9.706319812685251, 0.6461052177473903, 0.17403174511855468, 0.12776085612131283, 0.1424563894397579, 0.2677329507423565, 0.4029693565098569, 2.1658317698165774, 0.43541602324694395, 0.11081047035986558, 0.10008091485360637, 0.2631787763675675, 0.19568412622902542, 0.1944218814605847, 0.19329659262439236, 0.09055289643583819, 0.2821702463552356, 0.21076735749375075, 0.5092862562742084, 0.8162462536711246, 0.9161139198113233, 0.40339018392842263, 7.036574045196176, 25.96945758908987, 25.369826965034008, 20.081215649843216, 34.9800755828619, 34.52145159244537, 40.34302040934563, 41.770676001906395, 44.74397845566273, 41.9938076287508, 46.21241346001625, 43.48496921360493, 47.45157636702061, 51.73219107091427, 50.23195557296276, 47.215723022818565, 44.649367332458496, 47.75259621441364, 51.78757309913635, 54.589945524930954, 59.75088179111481, 59.16427306830883, 56.202278807759285, 47.06299401819706, 55.87967611849308, 58.61133433878422, 66.06901556253433, 63.438621908426285, 64.31865468621254, 58.35906207561493, 50.88764078915119, 47.40632839500904, 53.74231740832329, 51.1418167501688, 55.77090695500374, 53.41087259352207, 60.64830623567104, 64.14723068475723, 69.92062568664551, 66.28187254071236, 71.81308373808861, 70.23818224668503, 69.65944290161133, 67.14435026049614, 69.2438668012619, 52.383061945438385, 27.67605621367693, 4.864126117900014, 29.31844588369131, 71.61923334002495, 52.03168720006943, 25.444977432489395, 16.10328510403633, 30.624253414571285, 41.39227710664272, 33.202675357460976, 35.10275200009346, 39.25818242132664, 44.88271661102772, 45.89815512299538, 43.06543752551079, 33.96405190229416, 45.759561359882355, 46.98459282517433, 79.05929490923882, 85.3676176071167, 22.517648711800575, 0.6216038949787617, 0.28678497998043895, 0.19293622055556625, 0.28617190662771463, 0.24467154289595783, 0.1312379218870774, 0.17087233340134844, 0.25942843698430806], [0.10739582663518377, 0.03984203103755135, 0.06283393304329365, 0.04762813608977012, 0.014815101658314234, 0.03098478238825919, 0.06617143051698804, 0.060539976839208975, 0.0611073895561276, 0.14090500393649563, 0.1821907830890268, 0.10561271294136532, 1.0536115011200309, 53.80622237920761, 52.552703842520714, 45.97606614232063, 36.2831624597311, 30.4060273244977, 22.655290625989437, 35.687308833003044, 34.939569756388664, 30.42390536516905, 25.632428973913193, 28.511029109358788, 15.925227608531713, 22.75404542684555, 27.43989508599043, 39.32309053838253, 74.40174043178558, 34.43644255399704, 22.2595988586545, 10.788770578801632, 3.0791783099994063, 14.130285624414682, 23.73816031962633, 30.402102135121822, 38.3465201407671, 62.792079001665115, 65.51970183849335, 66.82854920625687, 62.46164493262768, 62.50472702085972, 58.35605263710022, 56.25424101948738, 48.3918397128582, 48.35040673613548, 46.49335138499737, 47.788717076182365, 50.005043148994446, 50.987913608551025, 50.9892625361681, 53.43347758054733, 54.399431347846985, 56.34849116206169, 53.28348822891712, 49.82317350804806, 46.08110770583153, 44.83726345002651, 42.32895724475384, 45.95795251429081, 54.135702699422836, 52.52365820109844, 52.605631202459335, 54.76335681974888, 53.23387809097767, 46.462341248989105, 45.375109389424324, 41.843761280179024, 43.398770838975906, 40.57475857436657, 40.96116364002228, 33.63802179694176, 32.47532978653908, 1.3947417587041855, 10.743369664996862, 11.090857218950987, 26.0313106700778, 34.79326620697975, 16.069939993321896, 2.195398695766926, 0.055341551487799734, 0.037029361847089604, 0.06902487701154314, 0.07058376562781632, 0.15385936974780634, 0.03786325753026176, 0.1354159164475277, 0.19767302263062447, 0.06504669829155318, 0.03482956934021786, 0.029325599934963975, 0.07824345695553347, 0.020810279129364062, 0.0072522341633884935, 0.023710043060418684, 0.02771000381471822, 0.13725906988838688, 0.10105503562954254, 0.538773505249992, 0.19954575807787478, 1.2551142135635018, 1.097258571535349, 7.405112469568849, 12.987560592591763, 8.032458331435919, 8.721583653241396, 18.882796056568623, 24.653232917189598, 29.507654830813408, 30.881241224706173, 35.84634929895401, 31.4612478017807, 38.888846039772034, 37.605818286538124, 40.34300521016121, 40.136425495147705, 41.70663423836231, 39.643162563443184, 44.78984959423542, 47.605722695589066, 53.00276689231396, 51.526941284537315, 52.861969247460365, 50.59125289320946, 43.51551577448845, 48.45449075102806, 53.28377701342106, 56.665192767977715, 58.14666107296944, 53.38309608399868, 45.39842873811722, 46.78082495927811, 44.95672143995762, 46.74611382186413, 47.957587614655495, 49.94110777974129, 55.91155640780926, 62.51301817595959, 62.90378160774708, 66.5474782884121, 64.63771596550941, 66.71425893902779, 66.90256163477898, 66.60423204302788, 66.3112373650074, 48.912426978349686, 30.61373557895422, 6.031143721193075, 3.9302784902974963, 46.35552518069744, 58.13129089772701, 40.42303651571274, 9.664928633719683, 12.207659091800451, 24.295953288674355, 32.135149240493774, 21.952457539737225, 26.074930429458618, 30.339865274727345, 29.48338743299246, 32.36789435148239, 32.17812493443489, 28.35765413939953, 37.20066122710705, 27.518108189105988, 43.355327770113945, 60.556510761380196, 63.49376454949379, 6.313249608501792, 0.40956660406664014, 0.05831305883475579, 0.043289730019751005, 0.04740481272165198, 0.0697912261239253, 0.03231770002457779, 0.03117997279332485, 0.07564501240267418, 0.005260328816802939, 0.04187504069705028, 0.022878442468936555, 0.03303772056824528, 0.0815695253550075, 0.057990903660538606, 0.05920533927564975, 0.036485608798102476, 0.02561160537879914, 0.1247584680095315, 0.11820195693871938, 3.6926701152697206, 69.68590468168259, 60.38934253156185, 51.464814618229866, 39.04356613755226, 35.623552054166794, 32.48063050210476, 35.54699756205082, 34.92745600640774, 30.392458252608776, 29.270241670310497, 33.96713733673096, 27.212720476090908, 36.76614694297314, 30.30180461704731, 38.033318147063255, 73.54867100715637, 38.58001381158829, 28.586808443069458, 15.8084437251091, 2.7574120508506894, 10.52584083750844, 22.276830933988094, 27.07991000264883, 36.90358556807041, 64.58087861537933, 66.96283400058746, 68.88830468058586, 64.03810814023018, 61.36299468576908, 58.66909123957157, 58.11331406235695, 54.70922872424126, 54.37028311192989, 49.116962403059006, 52.142964228987694, 52.40778721868992, 51.98683060705662, 54.25763815641403, 57.07498177886009, 56.32118962705135, 60.902003422379494, 58.564992025494576, 54.42805141210556, 51.714841201901436, 47.043155282735825, 44.83645409345627, 46.84601806104183, 53.48791345953941, 55.23611605167389, 54.89954151213169, 56.96850389242172, 56.206994354724884, 50.64641833305359, 49.223672077059746, 45.22729732096195, 45.56821882724762, 44.5691954344511, 44.29532513022423, 42.190173491835594, 39.718444123864174, 16.43887549638748, 20.83965875208378, 15.993455797433853, 28.495820425450802, 33.840744718909264, 12.1023971401155, 0.8308375894557685, 0.15942890604492277, 0.02989845259435242, 0.02020092764723813, 0.05783261098258663, 0.14257511822506785, 0.009805992613109993, 0.16598051151959226, 0.30229144322220236, 0.050867777681560256, 0.08584245544625446, 0.04646723158657551, 0.007422442486131331, 0.03720136941410601, 0.0481613654847024, 0.01223856808792334, 0.08638776329462416, 0.12557116424432024, 0.04478684226342011, 0.24230288952821866, 0.46544242766685784, 2.0812390465289354, 1.2973453849554062, 11.34305253624916, 16.47428009659052, 11.19969192892313, 15.708285849541426, 28.283166736364365, 30.581589303910732, 37.39898398518562, 37.64540456235409, 41.60907827317715, 39.845889285206795, 43.344969525933266, 42.82025948166847, 44.18848626315594, 41.82541586458683, 42.69712708890438, 43.64391468465328, 47.28588245809078, 52.695534378290176, 56.20078168809414, 57.36907459795475, 54.115164801478386, 51.54570087790489, 46.106642335653305, 50.88172070682049, 56.39949582517147, 58.69636617600918, 56.97211369872093, 55.7833930850029, 47.7786286175251, 50.0045757740736, 48.85771371424198, 49.8345272988081, 48.61285485327244, 54.96565416455269, 57.69537068903446, 65.01805275678635, 61.866517066955566, 66.41125559806824, 67.13285207748413, 69.15986850857735, 68.74872297048569, 72.46025741100311, 63.71522046625614, 47.96924538910389, 26.259687915444374, 3.479644046165049, 6.453168550506234, 52.1787279099226, 58.02680030465126, 45.8533289283514, 12.38969212397933, 15.667549185454845, 15.592382568866014, 30.028217397630215, 27.019614838063717, 25.030043497681618, 33.12422476708889, 30.581745095551014, 34.21991877257824, 38.311960995197296, 31.62647433578968, 46.16022326052189, 28.363817408680916, 63.03607910871506, 65.79711735248566, 83.09276327490807, 18.645274601876736, 0.49478222674224526, 0.16623270814307034, 0.12349663142231293, 0.08614563761511818, 0.018413097604934592, 0.04249782505212352, 0.07063325203489512, 0.1322578257531859, 0.11919226395548321, 0.11173736085765995, 0.1793225307483226, 0.10047292467788793, 0.12745709507726133, 0.09627143372199498, 0.17552399629494175, 0.1452760904794559, 0.23123868479160592, 0.30291116621810943, 0.2779243601253256, 4.2263350915163755, 78.35080772638321, 70.64656153321266, 61.030976101756096, 49.3933329731226, 41.69731333851814, 35.78741446137428, 47.75252781808376, 49.57735329866409, 42.78270609676838, 35.31651712954044, 35.81544555723667, 22.064200043678284, 28.770716674625874, 40.55936560034752, 48.731104508042336, 86.00593015551567, 41.940773874521255, 28.710410110652447, 13.972969315946102, 5.262331925332546, 14.391884487122297, 28.71326945722103, 32.03253574669361, 45.128153041005135, 69.27339121699333, 71.51724681258202, 71.34988859295845, 68.20648446679115, 65.28875783085823, 64.4038537144661, 61.53190702199936, 55.87254010140896, 56.93895287811756, 54.23247970640659, 56.63026884198189, 56.66309528052807, 54.37905304133892, 57.5983314961195, 57.30709232389927, 59.56897035241127, 63.31201650202274, 58.80888573825359, 55.939184725284576, 54.24855664372444, 49.77314919233322, 47.74240516126156, 50.491211861371994, 58.298079147934914, 57.353438436985016, 57.497218921780586, 58.724936842918396, 59.17898967862129, 54.16775777935982, 52.773901373147964, 50.166770070791245, 50.553528517484665, 51.24571457505226, 51.77589252591133, 48.3169799298048, 46.7221637070179, 18.76031532883644, 32.65539452433586, 31.49645671248436, 41.214507445693016, 38.12178120017052, 14.17502062395215, 1.7122007114812732, 0.40174712834414095, 0.10699347869376652, 0.1021224666328635, 0.22482811706140637, 0.3334545507095754, 0.17970886314287782, 0.5350065417587757, 1.2609789613634348, 0.11565225664526224, 0.14184613624820486, 0.22264718252699822, 0.324230189435184, 0.13656036753673106, 0.1293052951223217, 0.08900936285499483, 0.1923988462658599, 0.2798548643477261, 0.27626503666397184, 0.8640073158312589, 0.4838471853872761, 2.4851941829547286, 4.868412287905812, 18.54523167014122, 24.81452476233244, 19.032376930117607, 29.126827865839005, 38.58867734670639, 41.59367389976978, 45.185469165444374, 44.29759740829468, 48.438322618603706, 44.118623211979866, 48.183303102850914, 47.33895041048527, 48.20699103176594, 46.550458520650864, 46.405032724142075, 46.22561775147915, 50.031995102763176, 56.165466383099556, 58.12112644314766, 59.17040973901749, 58.09431128203869, 56.28279268741608, 49.761328026652336, 56.43074154853821, 57.82835215330124, 62.12996073067188, 62.38686874508858, 60.570212826132774, 51.24115101993084, 52.87862755358219, 49.64289978146553, 53.55618439614773, 50.83669312298298, 56.653307005763054, 58.835685700178146, 67.27771550416946, 65.45021876692772, 71.91655978560448, 68.3229710161686, 72.18525856733322, 71.49462282657623, 72.99922049045563, 67.94345498085022, 56.52512848377228, 33.814453929662704, 8.351003788411617, 5.070850700139999, 51.76723659038544, 65.78379526734352, 52.1975065022707, 19.948564767837524, 17.01033443212509, 32.46247887611389, 46.002075746655464, 28.519962430000305, 36.982119753956795, 41.856042221188545, 42.86604322493076, 43.086708784103394, 46.36262319982052, 38.80569890141487, 52.01736956834793, 37.53188565373421, 63.906338810920715, 74.86793741583824, 89.67589482665062, 15.721249803900719, 0.6975687656085938, 0.2707859978545457, 0.298718239646405, 0.10733643255662173, 0.1548960609943606, 0.1576056718477048, 0.12826490798033774], [0.05635617868392728, 0.03201636951416731, 0.036977136915083975, 0.03393701059394516, 0.044330614400678314, 0.035611258645076305, 0.07068792605423369, 0.025639751329435967, 0.06540183821925893, 0.1260658205137588, 0.12686192232649773, 0.39337570255156606, 13.852657321840525, 68.37224677205086, 52.63959378004074, 47.31644421815872, 41.66375733911991, 25.424335040152073, 23.846802189946175, 35.79516604542732, 30.524455569684505, 28.16866748034954, 28.894635625183582, 18.170036002993584, 20.635001733899117, 9.117238372564316, 12.564233858138323, 22.52512291073799, 48.394940346479416, 66.66032463312149, 37.523556500673294, 26.84957206249237, 4.1011888068169355, 3.661642405204475, 13.01210917532444, 14.5981839671731, 19.944671876728535, 57.751919254660606, 65.21082401275635, 66.62671163678169, 62.76233419775963, 62.93262206017971, 58.2735400646925, 53.813840970396996, 51.11539676785469, 48.188767209649086, 44.30331610143185, 50.290818214416504, 48.30743104219437, 49.35822285711765, 49.74702559411526, 50.245824828743935, 51.982464641332626, 51.85483708977699, 54.782226607203484, 52.30295844376087, 50.861942768096924, 47.228524535894394, 43.123764395713806, 42.20661140978336, 46.50972470641136, 50.2439933270216, 54.5755784958601, 54.1317243129015, 50.89967094361782, 47.838350012898445, 45.44765129685402, 41.477662324905396, 41.87713868916035, 39.08257104456425, 39.19452823698521, 34.36908356845379, 31.392000317573547, 4.475899050012231, 9.289372935891151, 10.001130793243647, 20.976599603891373, 18.95070221275091, 5.210202997550368, 0.10890424920944497, 0.09524916240479797, 0.043106371304020286, 0.08307137992233038, 0.03798450590693392, 0.005774784658569843, 0.041390562982996926, 0.05521547544049099, 0.2962799579836428, 0.14945035945856944, 0.05217117824940942, 0.03446513772360049, 0.04914438090054318, 0.13617664750199765, 0.05037860217271373, 0.023131197558541317, 0.09986075674532913, 0.08197150964406319, 0.041622981370892376, 0.0994426901161205, 0.22417257801862434, 0.19476865738397464, 0.6092955241911113, 7.7003865502774715, 12.492515556514263, 6.389781776815653, 7.232854887843132, 15.49854850396514, 20.77062975615263, 27.382092587649822, 32.60879382491112, 33.02374675869942, 35.58735899627209, 36.5579105168581, 37.0397474616766, 40.27713194489479, 38.24059322476387, 40.07401004433632, 41.28769151866436, 46.94615788757801, 51.548189744353294, 53.409683257341385, 53.68673399090767, 54.117376282811165, 46.60835601389408, 43.70533458888531, 49.44707348942757, 52.90903352200985, 53.24350297451019, 50.093092024326324, 46.84189908206463, 45.47919720411301, 45.91842703521252, 47.06900529563427, 48.404071256518364, 48.342081382870674, 51.49135619401932, 55.52934251725674, 64.3233360350132, 62.8259351849556, 62.61952266097069, 63.28143574297428, 67.09833472967148, 69.8149761557579, 67.60066777467728, 50.77040567994118, 35.73729895055294, 14.324899781495333, 0.9830172860529274, 18.84315088391304, 54.67337004840374, 49.90915149450302, 40.01627214252949, 8.82816793397069, 11.292752735316753, 29.212916046380997, 23.477538004517555, 23.833501003682613, 24.172701202332973, 28.437989428639412, 28.544547110795975, 33.65642040967941, 31.507582515478134, 29.2560513317585, 33.680621311068535, 25.62498327344656, 32.51456268131733, 61.20343744754791, 64.3691311776638, 53.51903758943081, 2.6791901607066393, 0.14208774984581396, 0.04330162293626927, 0.041848260298138484, 0.08854814775986597, 0.02072629769827472, 0.04623267210263293, 0.01628772766707698, 0.045031164700048976, 0.09186021925415844, 0.015924273830023594, 0.0600940574076958, 0.03652504652563948, 0.0604213000042364, 0.058541566104395315, 0.04852038313401863, 0.0035396223211137112, 0.1914970180951059, 0.4764866241021082, 21.299587972462177, 77.92026802897453, 63.6297782510519, 57.92593851685524, 50.60381881892681, 32.01265901327133, 32.49196529388428, 36.15388959646225, 33.55680875480175, 26.285893209278584, 24.750127717852592, 19.788903035223484, 26.95928357541561, 17.895037159323692, 21.256135404109955, 25.078568793833256, 51.886447593569756, 69.66399505734444, 44.62203919887543, 34.34115506708622, 5.780091192573309, 2.5398293137550354, 9.983894918113947, 11.605965178459883, 17.965768463909626, 56.87670461833477, 66.56996548175812, 67.66403317451477, 68.45103934407234, 64.42468419671059, 61.12694755196571, 57.39765666425228, 54.02380630373955, 51.39945812523365, 49.25481520593166, 52.17747397720814, 52.182599902153015, 50.39774067699909, 52.14644864201546, 51.857265159487724, 55.084382593631744, 55.22978559136391, 59.61124308407307, 54.86259989440441, 54.41381357610226, 50.65043471753597, 45.481245294213295, 46.57092422246933, 46.55052311718464, 52.88534939289093, 55.29036954045296, 56.6539491713047, 54.49148140847683, 52.06876561045647, 47.09575966000557, 44.94029872119427, 46.54128961265087, 44.859655648469925, 44.366274923086166, 40.13895995914936, 38.314582854509354, 14.62015438824892, 19.53799869865179, 12.807355262339115, 20.058439671993256, 19.455345533788204, 7.094831569120288, 0.346942461328581, 0.09671700434410013, 0.045085386009304784, 0.05069051570899319, 0.04171008353296202, 0.07297994525288232, 0.0276190684598987, 0.009143106308329152, 0.13886472122976556, 0.10117976096807979, 0.053721498770755716, 0.008191041233658325, 0.03955718733777758, 0.07584555554785766, 0.010269248614349635, 0.008127248074742965, 0.10026907155406661, 0.13304313673870638, 0.034871370808104984, 0.2762103552231565, 0.43422440125141293, 0.3583446401171386, 0.7399268739391118, 10.254317857325077, 15.793418381363153, 10.05200531333685, 13.677646312862635, 26.702381260693073, 27.767946682870388, 36.461194306612015, 40.026277005672455, 44.210616275668144, 41.84184618294239, 42.03152060508728, 40.56948825716972, 43.54446642100811, 41.887314543128014, 42.97252111136913, 45.108739882707596, 53.208715841174126, 55.408113822340965, 55.067944675683975, 54.97383512556553, 56.44596353173256, 50.471559315919876, 45.434948578476906, 51.997040659189224, 55.79295717179775, 57.15949684381485, 51.87899239361286, 49.41985934972763, 47.31400094926357, 49.26686055958271, 51.04334503412247, 52.322675585746765, 50.50310142338276, 55.747709199786186, 58.63633319735527, 65.36096155643463, 65.04792675375938, 65.66135823726654, 65.47063127160072, 69.90395978093147, 72.16284736990929, 69.23276379704475, 49.12182234227657, 33.43938745558262, 9.70869468525052, 1.4330174610950053, 24.888757579028606, 59.05982427299023, 54.853297993540764, 44.93085242807865, 12.877755034714937, 15.964774936437607, 24.188814237713814, 28.110443204641342, 26.153821796178818, 25.78946504741907, 29.210145995020866, 30.35865716636181, 29.900969825685024, 37.12535686790943, 31.72890543937683, 48.87137398123741, 25.966493748128414, 39.15574371814728, 79.90044817328453, 64.63541328907013, 77.6851138472557, 4.96140374802053, 0.18836626812117174, 0.06864155773655511, 0.06781358068110421, 0.01834186627093004, 0.043821757135447115, 0.02547949752624845, 0.10814620472956449, 0.22511068236781284, 0.19259373424574733, 0.21296162100043148, 0.1666999643202871, 0.16976068523945287, 0.1619598819524981, 0.143789331195876, 0.10859861053177156, 0.20852938148891553, 0.2509062661556527, 0.6667061091866344, 26.44720785319805, 91.1254334449768, 66.34881734848022, 62.022627890110016, 60.0369456410408, 35.058697164058685, 36.21356159448624, 49.69068601727486, 44.66611683368683, 37.493819296360016, 40.597032979130745, 25.282819233834743, 30.474957525730133, 11.504510622471571, 21.914282888174057, 35.26952885091305, 60.463898330926895, 75.68517476320267, 46.22362665832043, 32.11872272193432, 5.244025457650423, 4.615838415920734, 15.572673976421356, 15.041761714965105, 24.806794077157974, 62.11577229201794, 69.82940018177032, 70.70298090577126, 70.59626743197441, 68.53958979249, 66.36117428541183, 60.457244887948036, 56.95834323763847, 53.280209004879, 51.711546778678894, 56.5560170263052, 54.10140573978424, 54.247599095106125, 56.01141884922981, 54.83758203685284, 58.96919533610344, 56.837555319070816, 63.60631451010704, 58.94625976681709, 57.79246687889099, 52.84437999129295, 48.59840802848339, 48.30598331987858, 49.727300852537155, 58.39888013899326, 60.1726021617651, 61.766571030020714, 59.01525266468525, 54.34808470308781, 52.152045741677284, 50.44267326593399, 51.61084458231926, 50.14573059976101, 52.54979319870472, 48.5489384829998, 45.859986171126366, 17.537962719798088, 30.434700585901737, 31.145931221544743, 34.0572153031826, 24.917335845530033, 8.238423429429531, 0.8539834537077695, 0.20081977330846712, 0.17541754263220355, 0.2830484742298722, 0.11542703708983026, 0.14264281693613157, 0.19178509013727307, 0.14078097621677443, 0.9901132865343243, 0.3662882326170802, 0.1358798032742925, 0.10927190174697898, 0.09712896309792995, 0.3156096098246053, 0.06162805810163263, 0.10283651659847237, 0.1866245365818031, 0.3334902331698686, 0.19058540841797367, 0.5871942476369441, 0.6944760878104717, 1.5426941821351647, 2.556507093831897, 14.334727004170418, 25.022160820662975, 16.448046304285526, 27.469349205493927, 35.875877514481544, 37.90204659104347, 45.951895639300346, 46.71092011034489, 46.553255170583725, 44.578003361821175, 43.496209010481834, 44.361832961440086, 47.267130464315414, 44.445363879203796, 45.531383603811264, 48.26206147670746, 53.62598665058613, 58.97064305841923, 59.6859622746706, 60.01804165542126, 60.98147615790367, 53.99069868028164, 49.32649455964565, 56.71778194606304, 60.4113395512104, 60.97085192799568, 57.1408474445343, 53.56854893267155, 49.926132783293724, 52.32856146991253, 52.82438926398754, 55.35607561469078, 54.028658643364906, 58.409952744841576, 61.05906039476395, 68.94578039646149, 66.69328406453133, 68.83132293820381, 67.39291772246361, 72.18614771962166, 75.48280522227287, 71.63701638579369, 55.51707677543163, 39.54712271690369, 17.35379610210657, 1.96430625859648, 21.670695059001446, 64.29492875933647, 58.17097216844559, 51.37881003320217, 19.218574538826942, 17.012696005403996, 39.20985281467438, 31.034086123108864, 32.11393117904663, 31.733216308057308, 38.40309150516987, 36.45389869809151, 47.18756653368473, 43.52334715425968, 43.26917119324207, 49.30194407701492, 37.253421396017075, 42.550511956214905, 84.0846848487854, 75.28501823544502, 86.63745626807213, 4.3965692818164825, 0.2476185667910613, 0.17557538260007277, 0.12967951566679403, 0.20158586266916245, 0.1626999961445108, 0.10509785541216843], [0.10865792297408916, 0.029549344471888617, 0.041548009612597525, 0.05253740957414266, 0.01636988341488177, 0.01879004925285699, 0.01289313955567195, 0.07293182439752854, 0.04731149507279042, 0.06041801600076724, 0.1951618620660156, 0.4246254335157573, 35.72469502687454, 62.818259596824646, 44.66249942779541, 40.223300233483315, 37.12988622486591, 25.720909126102924, 27.70889025181532, 37.96470142900944, 30.483647659420967, 30.6116608902812, 30.498979836702347, 34.518939927220345, 33.08449789881706, 23.90353314578533, 7.293980307877064, 18.47694743424654, 39.38526280224323, 56.17392472922802, 43.19017343223095, 44.865940511226654, 7.2539133578538895, 0.9395320632029325, 2.0791064109653234, 3.9929530397057533, 5.497245294973254, 45.43344385921955, 68.16809892654419, 62.50516399741173, 63.55342134833336, 59.85325209796429, 59.62199650704861, 52.66953617334366, 52.68150553107262, 49.291175454854965, 47.43175283074379, 47.51773461699486, 47.82945089042187, 47.1044497936964, 46.834744065999985, 49.195956364274025, 52.40879416465759, 54.79249745607376, 53.83514262735844, 53.82429040968418, 50.15705019235611, 50.35793021321297, 45.693627297878265, 41.105628088116646, 40.51449380815029, 45.74745140969753, 52.35916882753372, 50.85653565824032, 50.775634199380875, 45.77525831758976, 42.302662655711174, 38.878419399261475, 38.686009123921394, 39.415364786982536, 36.04063667356968, 34.045462533831596, 28.926329724490643, 5.823719976469874, 10.76594615355134, 5.396952526643872, 10.70420516654849, 10.104110967367887, 3.291478855535388, 0.1847373292548582, 0.0995074276579544, 0.01701071309071267, 0.03726027367520146, 0.016316834698955063, 0.07112147388397716, 0.023681837737967726, 0.03626363613875583, 0.03350736646098085, 0.3194156102836132, 0.06913102639373392, 0.03904458222677931, 0.031220579403452575, 0.03918630274711177, 0.06772594788344577, 0.045106756151653826, 0.007135372807169915, 0.051803050737362355, 0.025097953839576803, 0.057866942734108306, 0.3362782741896808, 0.15842108434299007, 1.1625289754010737, 7.997203823179007, 12.78990089893341, 7.894025109708309, 6.935347001999617, 13.8455830514431, 20.586998909711838, 24.966113828122616, 31.092965863645077, 37.61018045246601, 38.089057356119156, 38.79383593797684, 38.05568754673004, 40.20919919013977, 39.253455474972725, 41.063659340143204, 46.55801251530647, 49.97845217585564, 50.03455996513367, 51.33590653538704, 52.29470148682594, 50.03112114965916, 45.36326542496681, 42.87908032536507, 46.06614790856838, 49.3911936879158, 50.17210118472576, 46.33450090885162, 44.007813557982445, 44.77047823369503, 47.7628518640995, 51.444523707032204, 50.131355971097946, 50.68827688694, 54.75570023059845, 59.340549409389496, 61.22245542705059, 62.73796230554581, 65.64218446612358, 67.17996194958687, 68.91156703233719, 68.90867158770561, 59.33931067585945, 38.926714807748795, 20.89797232300043, 2.8090042574331164, 1.4272573264315724, 34.49668452143669, 56.38216495513916, 56.03015944361687, 31.32709600031376, 5.177639219909906, 21.4002787694335, 50.51370285451412, 25.63547071069479, 30.821381136775017, 25.494321584701538, 35.47266595065594, 26.908480301499367, 37.30539880692959, 31.753908097743988, 36.37383319437504, 22.574799545109272, 57.683633118867874, 37.39726647734642, 35.15692189335823, 58.88167083263397, 68.70956987142563, 25.472520254552364, 1.098622817080468, 0.1421896170359105, 0.10030675781308673, 0.07096781962900423, 0.03312900473247282, 0.11585947911953554, 0.011086237245763186, 0.10527893944527023, 0.038220545975491405, 0.06283499431447126, 0.010054510967165697, 0.03365839351317845, 0.028732544160448015, 0.04544419585727155, 0.029559432114183437, 0.04031143202155363, 0.18315545632503927, 0.6353270367253572, 50.6845872849226, 72.88082644343376, 53.418396189808846, 51.63533806800842, 42.145180106163025, 32.73497745394707, 32.06107601523399, 41.84173218905926, 33.7689171731472, 30.44527541846037, 22.239366844296455, 35.995734483003616, 36.36512406170368, 26.86226338148117, 11.43160393461585, 23.159054294228554, 42.113151624798775, 59.200447127223015, 46.35311231017113, 51.9405110925436, 10.464226193726063, 1.18458382319659, 1.581606469117105, 3.722649081610143, 3.2306671561673284, 40.12085013091564, 68.85612040758133, 63.68866369128227, 67.67684608697891, 62.19692073762417, 62.01989583671093, 57.12878689169884, 55.85930921137333, 52.17853032052517, 48.75220097601414, 48.745004162192345, 48.20296324789524, 49.60887260735035, 50.84909565746784, 52.09590755403042, 54.93857301771641, 56.13528460264206, 56.425680220127106, 58.05894657969475, 55.62105819582939, 52.6006268709898, 49.252535328269005, 46.00316248834133, 44.34742793440819, 46.828588396310806, 53.9814917743206, 54.7894462198019, 51.64681725203991, 49.78576831519604, 46.762832924723625, 43.46336357295513, 44.32911291718483, 44.54254366457462, 40.6919214874506, 39.26062189042568, 37.69951365888119, 15.16295051202178, 22.502573020756245, 11.639280840754509, 13.140373192727566, 11.798533145338297, 2.6786323031410575, 0.04570330187561922, 0.11558346697711386, 0.035065208649029955, 0.06172392502776347, 0.025749132764758542, 0.05927385063841939, 0.017328812427876983, 0.05709264150937088, 0.03727834497112781, 0.08435058276518248, 0.033657373060123064, 0.056731197037152015, 0.02745393503573723, 0.0504050337622175, 0.03257724019931629, 0.06485909820185043, 0.023093175477697514, 0.1311493688262999, 0.04033220844576135, 0.13237765291705728, 0.7105727959424257, 0.41987274948041886, 1.5109054441563785, 10.539812687784433, 17.70010381937027, 12.009133044630289, 11.781555656343699, 23.932453393936157, 28.830090388655663, 34.63244743645191, 39.965256080031395, 44.357759580016136, 43.330819085240364, 44.401423037052155, 41.27690389752388, 42.932923436164856, 42.39804893732071, 44.06082831323147, 49.8913798481226, 52.59331986308098, 55.88127963244915, 55.01395717263222, 53.91165532171726, 53.4945897012949, 47.74693451821804, 47.72675380110741, 48.54524128139019, 52.05911032855511, 51.259952411055565, 47.1271687746048, 46.842032074928284, 49.28030803799629, 53.17143604159355, 54.81989398598671, 53.81044775247574, 54.57039937376976, 57.50725418329239, 61.303049102425575, 64.70422759652138, 65.28913781046867, 66.16774946451187, 68.17195951938629, 71.89107835292816, 70.33212840557098, 59.224294647574425, 34.733096435666084, 17.339556366205215, 1.9263936742208898, 2.7588106133043766, 42.40517355501652, 60.021469071507454, 58.381028696894646, 33.773207142949104, 8.003726173192263, 18.101214095950127, 44.495578184723854, 26.495444364845753, 22.709990590810776, 22.900822050869465, 31.689079776406288, 28.487914949655533, 35.10756254196167, 35.092492550611496, 35.59547156095505, 32.651898711919785, 69.69070002436638, 39.360731318593025, 52.91235834360123, 66.0769647359848, 79.20462191104889, 42.6564122736454, 0.7324753550346941, 0.0875937903765589, 0.06269196019275114, 0.09987939207348973, 0.05015870752686169, 0.03916406800271943, 0.1689314391114749, 0.1434579474152997, 0.1219655065506231, 0.2065483370097354, 0.17130404070485383, 0.17029157315846533, 0.0983507014461793, 0.16796734475065023, 0.14001999283209443, 0.1360022576409392, 0.1876540289958939, 0.9110780025366694, 63.100417256355286, 82.80731499195099, 58.91502544283867, 54.44954685866833, 48.45394738018513, 35.478160455822945, 39.55952525138855, 55.02044342458248, 40.76247610151768, 42.145772874355316, 45.38398191332817, 47.805113196372986, 43.225868716835976, 30.195999294519424, 10.310465544462204, 31.86744410544634, 49.73889023065567, 64.9362887442112, 52.113002836704254, 55.04106491804123, 9.211078137159348, 1.7376199224963784, 2.6923512294888496, 5.763685097917914, 6.9970020186156034, 49.6818058937788, 70.45471742749214, 69.64011713862419, 69.47386845946312, 65.58236047625542, 66.09449699521065, 60.52871525287628, 58.41518126428127, 55.9096223115921, 52.22446985542774, 52.90092095732689, 52.67839349806309, 51.39888435602188, 53.53111334145069, 54.53663818538189, 60.08166164159775, 60.604574382305145, 59.73537102341652, 61.05985835194588, 58.332862481474876, 56.529448851943016, 52.131226658821106, 48.482654839754105, 46.77997760474682, 51.8590434640646, 56.585495844483376, 58.626791909337044, 55.7562131434679, 52.451902851462364, 49.97325785458088, 50.277321338653564, 47.27493904531002, 51.403873488307, 47.26073540747166, 50.39324551820755, 45.27280367910862, 19.188124872744083, 31.909304559230804, 25.632518269121647, 24.025252014398575, 17.116115055978298, 3.1587712140753865, 0.21213774802163243, 0.2237771320505999, 0.14152527612168342, 0.23666382883675396, 0.18853654648410156, 0.15697460883529857, 0.127876081969589, 0.1385339311673306, 0.2502602414460853, 0.6620701204519719, 0.14001194795127958, 0.18793248280417174, 0.1476949724019505, 0.15683507022913545, 0.11628198379185051, 0.14602836105041206, 0.12876619905000553, 0.1527131671900861, 0.1725257493671961, 0.27623187750577927, 0.8805469970684499, 1.2824265542440116, 1.8841905263252556, 15.913134757429361, 23.424768336117268, 16.68301809579134, 23.40175487101078, 36.683299988508224, 38.4819258749485, 42.394845709204674, 47.35985688865185, 49.923054948449135, 46.96503907442093, 47.75196924805641, 44.67136435210705, 46.77497327327728, 46.86499424278736, 46.61032430827618, 51.78956039249897, 55.56262493133545, 57.96269774436951, 57.8195708245039, 56.72204531729221, 54.37029831111431, 52.20018915832043, 50.49772851169109, 52.815680131316185, 56.31976470351219, 55.316899716854095, 50.0849262624979, 48.57418052852154, 49.91358585655689, 56.16765506565571, 59.06970754265785, 56.362763196229935, 56.28214672207832, 59.48263518512249, 63.448113799095154, 66.41154438257217, 67.2991843521595, 69.22147080302238, 72.9736478626728, 72.73338675498962, 71.56197801232338, 63.94610747694969, 42.952765971422195, 23.73322818428278, 3.7020254507660866, 2.188298776745796, 41.39049880206585, 66.87923088669777, 64.98922750353813, 43.25472816824913, 13.524298891425133, 28.90631429851055, 60.86859181523323, 32.0555929094553, 43.14537763595581, 32.995841056108475, 47.72153668105602, 35.301040560007095, 50.46881586313248, 42.6102789491415, 50.59539847075939, 30.793731920421124, 76.71178847551346, 46.02854132652283, 54.64986450970173, 72.26896047592163, 89.41281974315643, 45.829697996377945, 0.8992364723235369, 0.23377727513434365, 0.19672498834552243, 0.242466636991594, 0.12758438824675977, 0.1773468594183214], [0.024378987145610154, 0.03502697320072912, 0.10949288363917731, 0.07147659896872938, 0.08115279459161684, 0.03182226821081713, 0.0094199218256108, 0.05096897322800942, 0.02601129272079561, 0.0449918086087564, 0.4227476514643058, 2.690489091910422, 58.078196346759796, 65.41304916143417, 51.87141180038452, 39.060600623488426, 39.39988061785698, 20.500449053943157, 30.891800858080387, 33.97923208773136, 33.370345160365105, 26.883711330592632, 30.938492752611637, 52.166777551174164, 31.167926341295242, 37.50175707042217, 12.46976712718606, 12.102503534406424, 33.68011213839054, 63.233254328370094, 42.4841333180666, 50.66699042916298, 26.940877363085747, 1.9912698492407799, 0.2794443379389122, 0.11719969392288476, 0.1250233850441873, 13.30077113583684, 63.477835804224014, 59.24849554896355, 63.810948729515076, 57.35108256340027, 57.978447899222374, 52.15409003198147, 56.050951927900314, 47.083528116345406, 48.92159968614578, 46.83927722275257, 47.16514773666859, 45.40515437722206, 49.23003293573856, 45.30025340616703, 48.37905339896679, 51.512988433241844, 54.9355673789978, 52.15193934738636, 53.295332193374634, 50.681471452116966, 48.6129954457283, 42.479372173547745, 41.272834315896034, 44.18366812169552, 48.12864303588867, 49.86057490110397, 47.178728207945824, 46.15207649767399, 43.26839603483677, 38.93708825111389, 37.00314782559872, 37.77504600584507, 34.035187885165215, 33.05690757930279, 24.79602925479412, 7.053630854934454, 11.861972641199827, 3.0663031758740544, 7.379679959267378, 4.585502268746495, 0.8863824151922017, 0.025551086946506985, 0.13753419887507334, 0.09174697494017892, 0.0373202651826432, 0.056927558180177584, 0.043055623245891184, 0.0720471324166283, 0.05057531954662409, 0.06533612104249187, 0.16952505335211754, 0.13894151867134497, 0.04389209047076292, 0.0415271663950989, 0.07241249171784148, 0.07178669053246267, 0.04878116640611552, 0.07807772053638473, 0.09745749703142792, 0.04732770728878677, 0.005740256701756152, 0.4293382790638134, 0.4667424032231793, 0.8240481850225478, 4.714207537472248, 13.310952689498663, 10.332929939031601, 6.118922811001539, 10.046410113573074, 20.344676412642002, 24.90575596690178, 31.35037925094366, 37.21789710223675, 39.439349099993706, 39.830180928111076, 40.2957509458065, 41.42125055193901, 41.47325076162815, 45.66294014453888, 47.8571742027998, 51.78637236356735, 52.2911486774683, 52.05837316811085, 52.45144307613373, 52.4875183403492, 43.74872446060181, 44.06978443264961, 44.24278914928436, 45.97049944102764, 44.99451421201229, 43.72106194496155, 45.41597239673138, 51.03337436914444, 53.2001169025898, 52.224549651145935, 51.53694234788418, 52.68053278326988, 52.831073105335236, 59.26810249686241, 61.762626841664314, 64.21681255102158, 62.72059343755245, 61.25879667699337, 71.29420638084412, 62.371893748641014, 46.11214064061642, 22.095983438193798, 6.901497468352318, 0.48918390995822847, 10.965810678899288, 50.27118846774101, 61.104790940880775, 51.13708980381489, 21.733507588505745, 5.462948810309172, 23.576549291610718, 41.95912308990955, 28.80245067179203, 32.15580493211746, 23.56357678771019, 36.49560146033764, 33.58534522354603, 31.73394776880741, 30.385063849389553, 41.2486220151186, 27.294311597943306, 27.024347484111786, 50.24401232600212, 26.97788927704096, 50.79198472201824, 60.57046741247177, 54.33810643851757, 2.1709439205005765, 0.1549416288617067, 0.07021180863375776, 0.059661403865902685, 0.05832720788021106, 0.024244311462098267, 0.022631325846305117, 0.05822492137667723, 0.031887848090264015, 0.11257143094553612, 0.04672946946811862, 0.04221008326567244, 0.03875522255839314, 0.08434706498519517, 0.03927551631932147, 0.21971522422973067, 0.3276597132207826, 5.340874660760164, 73.98700788617134, 70.72220787405968, 70.63760161399841, 41.486690640449524, 50.589732974767685, 27.193894386291504, 36.67557120323181, 38.85286197066307, 33.135076984763145, 29.0433444455266, 29.109812378883362, 49.558669701218605, 35.268841087818146, 34.220857322216034, 12.75547094643116, 15.320453010499477, 36.71909026801586, 67.64203995466232, 46.95325970649719, 57.786938175559044, 36.8613014370203, 4.78164441883564, 0.6438649410847574, 1.2071732548065484, 0.32994083769153804, 11.951359044760466, 67.6575355231762, 59.76851664483547, 66.92165181040764, 60.905905812978745, 63.43848891556263, 56.645323634147644, 58.66036310791969, 51.280095130205154, 53.42065326869488, 49.8477353900671, 49.132020995020866, 47.47539348900318, 50.995836183428764, 48.64058956503868, 50.367224514484406, 53.880683183670044, 56.15155912935734, 55.50509221851826, 55.74121154844761, 54.46287654340267, 52.176964804530144, 46.6972104460001, 44.153102561831474, 46.67924501001835, 50.2056609839201, 50.96724271774292, 50.16159474849701, 49.055922478437424, 46.96688197553158, 44.04497556388378, 42.38447226583958, 41.782774552702904, 40.66144712269306, 41.59286454319954, 32.6387932151556, 15.237628854811192, 28.165766336023808, 12.038500718772411, 8.18772654980421, 5.514049418270588, 1.0449404851533473, 0.06841512105893344, 0.08735666677239351, 0.10183719990891404, 0.02566151295468444, 0.018702034249145072, 0.032914149269345216, 0.18745489593129605, 0.06179510812216904, 0.010975442019116599, 0.17672799731371924, 0.16335002845153213, 0.08886445852112956, 0.06210391948116012, 0.05419540830189362, 0.06502795164124109, 0.04999978031264618, 0.04436821531271562, 0.03736370308615733, 0.01865346810518531, 0.04228071717079729, 0.4232397547457367, 0.4719942557858303, 1.2073982739821076, 5.742814717814326, 18.440017215907574, 14.77615311741829, 9.188151117414236, 19.92648035287857, 26.698963344097137, 35.45503869652748, 38.03256958723068, 46.14064671099186, 43.6435005068779, 45.44893182814121, 42.199410796165466, 45.90712644159794, 43.721179738640785, 49.219701290130615, 51.8345195800066, 53.77288296818733, 54.507581144571304, 54.07220430672169, 52.775865867733955, 55.928214713931084, 48.45010578632355, 46.19353227317333, 46.34535312652588, 49.4223216176033, 46.95029206573963, 47.30170860886574, 49.74292941391468, 55.384437292814255, 55.96602648496628, 54.55535978078842, 52.81499616801739, 54.88152667880058, 56.50800660252571, 61.39909654855728, 64.01358425617218, 65.76461389660835, 65.49663707613945, 64.56548944115639, 71.2344279885292, 61.68570376932621, 43.68128947913647, 20.38334123790264, 5.205694064497948, 0.1564436318585649, 16.15573938935995, 56.06742784380913, 66.14938125014305, 53.61470885574818, 24.266540966928005, 4.261254267767072, 15.535309631377459, 43.895324394106865, 20.999806858599186, 20.0967226177454, 23.801035545766354, 33.68064410984516, 31.677657589316368, 32.52556309103966, 36.154759749770164, 42.84033000469208, 31.570292450487614, 43.58726732432842, 44.09492768347263, 37.63665743172169, 60.49839287996292, 66.54794946312904, 71.08931377530098, 3.8073505740612745, 0.2200838489807211, 0.034323242798564024, 0.06231368752196431, 0.02230901111033745, 0.019103439663012978, 0.09248198315617628, 0.11633375601377338, 0.28715635067783296, 0.2484317825292237, 0.20180963503662497, 0.15068461041664705, 0.10592711638309993, 0.17823829752160236, 0.3046005021315068, 0.4746850754600018, 0.8575590024702251, 8.065273370593786, 86.08539909124374, 80.79877316951752, 67.17541739344597, 53.599828854203224, 54.916746988892555, 29.537595324218273, 44.37252178788185, 47.45230592787266, 42.763501927256584, 35.5155124515295, 40.46087488532066, 64.91680338978767, 40.73442220687866, 47.1632744371891, 16.47948581725359, 22.338514924049377, 44.90897700190544, 71.26371681690216, 51.100702956318855, 61.7330302298069, 33.78622904419899, 3.7478638160973787, 0.6429138639941812, 0.8293498505372554, 0.2883147244574502, 18.18442963063717, 69.48818609118462, 63.705018013715744, 72.40539595484734, 65.07533848285675, 66.25873938202858, 57.62386612594128, 62.96747758984566, 51.9214703142643, 57.397934049367905, 50.89432083070278, 50.557438507676125, 50.7844877243042, 53.490839302539825, 52.16136284172535, 56.286755874753, 59.91355486214161, 60.15273682773113, 58.58511194586754, 59.82550598680973, 55.61677202582359, 55.05959652364254, 47.71509222686291, 45.9456829726696, 50.173989683389664, 55.70601783692837, 56.23944081366062, 52.534088641405106, 51.645373329520226, 51.56119264662266, 48.3896092325449, 47.855380699038506, 49.78786960244179, 48.43701548874378, 50.36270275712013, 42.12756425142288, 19.170427322387695, 35.76174683868885, 23.7677189335227, 14.823488127440214, 10.534036047756672, 1.5533488104119897, 0.11747046650270931, 0.20347022014902905, 0.1993084786226973, 0.18031037383479998, 0.10207464263658039, 0.0646695239993278, 0.36048202542588115, 0.2994888857938349, 0.1377068372676149, 0.7742692530155182, 0.17778437031665817, 0.20383234368637204, 0.11936960756429471, 0.17228768323548138, 0.11144266885821708, 0.21835311606992036, 0.13776711450191215, 0.21228843368589878, 0.1470354406046681, 0.08460296492557973, 1.078242373187095, 0.4858494404470548, 1.4040224044583738, 10.587331037968397, 23.129229694604874, 21.176470778882504, 19.279612563550472, 32.24186271429062, 37.75959223508835, 44.33013126254082, 43.29829283058643, 52.19518102705479, 49.802514016628265, 49.80221003293991, 46.22558735311031, 49.45210061967373, 46.75470896065235, 50.28021298348904, 55.26332639157772, 56.31722643971443, 58.452715650200844, 58.807601407170296, 57.05095946788788, 58.239262104034424, 51.010533794760704, 50.58610036969185, 48.777196034789085, 51.72245979309082, 53.15336421132088, 49.14540387690067, 51.13463133573532, 55.67869730293751, 57.34969183802605, 56.49413354694843, 56.523574367165565, 57.38314524292946, 60.71666456758976, 63.94907131791115, 65.24975672364235, 67.39777386188507, 69.4211120903492, 64.91849049925804, 74.01387244462967, 69.21877294778824, 50.9589097648859, 25.951017178595066, 8.070518989115953, 0.9089182340539992, 12.996348571032286, 60.323526263237, 72.10805431008339, 58.30401822924614, 31.63448240607977, 10.930123943835497, 31.33983861654997, 49.659634083509445, 39.01230901479721, 47.20354467630386, 32.85343989729881, 51.05898879468441, 43.99409629404545, 42.12553136050701, 42.828854620456696, 55.259720385074615, 36.000887006521225, 38.243169486522675, 63.89146640896797, 36.253710240125656, 71.38288602232933, 74.85798954963684, 82.6573446393013, 4.784075813367963, 0.31318243069108576, 0.1291827962268144, 0.16671186836902052, 0.06870326731586829, 0.20541786798276007], [0.04315523059631232, 0.015489912420889596, 0.07798693361110054, 0.02684990846319124, 0.03800092963501811, 0.018000285381276626, 0.015699015311838593, 0.051006184512516484, 0.09083230761461891, 0.39277678937651217, 0.46220728720072657, 14.962790552526712, 74.38613086938858, 51.12841486930847, 33.143687322735786, 48.30293208360672, 24.8875929415226, 27.708166390657425, 28.297417871654034, 38.50534401834011, 35.30477195978165, 27.43966329842806, 23.259640596807003, 49.593399837613106, 38.3149666339159, 32.014703303575516, 16.145580634474754, 8.887042924761772, 24.229318164288998, 56.475320756435394, 52.32705295085907, 48.02316069602966, 54.70853716135025, 12.480449303984642, 0.40188377257436514, 0.782547821290791, 0.09594906703568995, 3.177260784432292, 53.2697481662035, 53.62486571073532, 59.57640655338764, 57.68898323178291, 58.599231988191605, 54.54531691968441, 52.98081547021866, 47.22876392304897, 48.8486398011446, 45.73067910969257, 47.610172256827354, 47.894476801157, 50.398154854774475, 48.00389192998409, 45.565615966916084, 50.489437356591225, 51.0229667276144, 52.09354408085346, 50.51083020865917, 51.20391681790352, 51.896197870373726, 45.793451741337776, 41.0052564740181, 42.371127381920815, 43.75470153987408, 46.209176033735275, 45.08219450712204, 44.85976964235306, 40.10071121156216, 40.060133188962936, 38.093362525105476, 39.55031454563141, 32.4673730134964, 31.027185693383217, 19.4263568893075, 8.828854747116566, 20.02979300916195, 6.838044673204422, 4.461601842194796, 2.1870194328948855, 0.3312233282485977, 0.0533197631011717, 0.049225608963752165, 0.06571471283677965, 0.05292436537274625, 0.07520000581280328, 0.0695717656344641, 0.0661556598788593, 0.10622272864566185, 0.029638005144079216, 0.07679079193621874, 0.023180025309557095, 0.026351810483902227, 0.07405001088045537, 0.027572335420700256, 0.06642423570156097, 0.03818447388766799, 0.10189343985985033, 0.13438914029393345, 0.07048111918265931, 0.0659388117492199, 0.1943201627000235, 0.4909398313611746, 0.8207554835826159, 1.1732390569522977, 14.626021273434162, 10.554093271493912, 6.232554763555527, 9.927791878581047, 19.45984449237585, 25.30686244368553, 30.121225006878376, 38.2986731082201, 39.56806339323521, 42.685872092843056, 39.52889509499073, 42.18403682112694, 41.612266302108765, 49.40651826560497, 48.96830677986145, 50.97900688648224, 49.73151482641697, 51.87152199447155, 51.39476157724857, 52.2378983348608, 43.34360919892788, 43.67109842598438, 43.11173424124718, 44.893253445625305, 42.51535624265671, 47.65469066798687, 53.95727947354317, 54.689169600605965, 54.522510543465614, 52.54081808030605, 52.75437042117119, 52.43454918265343, 54.826543629169464, 61.05751387774944, 60.904568284749985, 60.502299070358276, 63.27675439417362, 67.49333873391151, 64.60442215204239, 54.979234635829926, 34.741501584649086, 11.90256966277957, 1.7772812442854047, 0.33633714134339243, 31.743882335722446, 57.48875677585602, 53.48751448094845, 54.16612766683102, 23.552614375948906, 3.3954828372225165, 17.52718649804592, 43.65402974188328, 26.88600640743971, 20.2385139092803, 20.705714039504528, 30.15290390700102, 35.187582448124886, 34.39557574689388, 30.36864683032036, 39.78857696056366, 49.04678776860237, 20.177616477012634, 47.561534866690636, 38.00209142267704, 42.836347818374634, 56.89584419131279, 69.05193910002708, 6.641213810071349, 0.5832604493480176, 0.050325939373578876, 0.024274925053759944, 0.012838373695558403, 0.04571579222101718, 0.040896255522966385, 0.010537778980506118, 0.0964367100095842, 0.04000352979346644, 0.06004289745760616, 0.022020447395334486, 0.04576983170409221, 0.03729926611413248, 0.058282912796130404, 0.5369390349369496, 0.34533612721133977, 22.06094551831484, 85.40953695774078, 64.21334713697433, 38.769110664725304, 46.245825067162514, 38.486208245158195, 32.27875113487244, 34.552708715200424, 37.22250625491142, 35.271911323070526, 28.508203960955143, 28.87210663408041, 49.92825306952, 36.019760593771935, 31.295143514871597, 14.407343957573175, 12.37120896577835, 28.15852962434292, 60.58110684156418, 56.54216676950455, 52.59501077234745, 61.78034909069538, 19.16532799601555, 0.8687606232706457, 2.6138723781332374, 0.14922007103450596, 2.8619864769279957, 57.32554793357849, 58.28364372253418, 61.629831567406654, 61.09050750732422, 61.26907132565975, 58.57963643968105, 56.6735827177763, 50.12663662433624, 51.13031856715679, 49.72070820629597, 49.22823943197727, 49.34730224311352, 53.830769062042236, 49.45101007819176, 49.90456514060497, 52.94024124741554, 54.22998324036598, 53.80808427929878, 54.70578230917454, 56.35667972266674, 53.83570499718189, 48.40762786567211, 45.21303668618202, 44.00441654026508, 46.25395283102989, 47.1516128629446, 48.628939390182495, 47.425008192658424, 45.50951957702637, 44.17825721204281, 44.3503537774086, 41.877283081412315, 40.7614653557539, 38.175103738904, 28.34297552704811, 17.007792368531227, 33.61620716750622, 15.363223515450954, 3.9514300553128123, 3.1866555428132415, 0.22154733451316133, 0.09295253446907736, 0.007903765144874342, 0.017992951106862165, 0.0821422110311687, 0.06041259832272772, 0.052323363051982597, 0.01158158649559482, 0.04239476671500597, 0.08292162194265984, 0.2411245965049602, 0.24874387047020718, 0.037352463259594515, 0.05311478933435865, 0.019947430409956723, 0.06169491447508335, 0.05472723874845542, 0.11364984573447146, 0.033917046821443364, 0.024429241675534286, 0.08463642094284296, 0.3660688834497705, 0.6344442965928465, 1.1851710104383528, 2.3723001033067703, 18.572537004947662, 15.793712865561247, 9.831990469247103, 21.38704977929592, 28.621665872633457, 37.26154536008835, 38.90689127147198, 45.29328837990761, 43.20595018565655, 45.84977611899376, 43.055812641978264, 43.332646787166595, 46.25856198370457, 53.488437831401825, 50.51480479538441, 52.391106113791466, 51.638624891638756, 54.37030591070652, 55.72883941233158, 54.610339030623436, 44.378776252269745, 45.84204353392124, 45.06400488317013, 46.37083075940609, 46.86789348721504, 51.9607488065958, 57.24740892648697, 58.79293039441109, 56.56984828412533, 55.523433834314346, 54.441244304180145, 53.27860929071903, 58.09956260025501, 61.54633864760399, 63.092973455786705, 64.61619392037392, 66.01869866251945, 67.61230275034904, 65.35166725516319, 55.818883180618286, 31.72215510159731, 10.239109173417091, 1.437233928591013, 0.8869269140996039, 40.478239953517914, 62.351279854774475, 58.21330949664116, 56.7199744284153, 27.188057899475098, 4.171604728326201, 13.6637894064188, 43.79958853125572, 15.297485142946243, 20.762454494833946, 23.626300022006035, 29.142640717327595, 35.158855989575386, 31.816253252327442, 29.49719399213791, 46.353256702423096, 39.311998933553696, 32.99465931952, 55.08741483092308, 37.19812296330929, 54.39839020371437, 62.04118229448795, 86.06013044714928, 13.664064891636372, 0.719341894146055, 0.12623032496776432, 0.024686353172000963, 0.0962546092341654, 0.016924867013585754, 0.20860141434241086, 0.1373334479285404, 0.30740964983124286, 0.12308905876125209, 0.28603377810213715, 0.12584476440679282, 0.13989593542646617, 0.1777495042188093, 0.1572275921353139, 0.8277106541208923, 0.5994754261337221, 30.15523888170719, 94.83443722128868, 73.06149914860725, 41.02502681314945, 66.26431748270988, 37.09280401468277, 38.967627212405205, 40.81393674015999, 49.91965793073177, 46.722631081938744, 37.82652944326401, 30.76995089650154, 59.14042554795742, 45.619048699736595, 42.12197095155716, 20.16793079674244, 18.26729368418455, 36.15664444863796, 65.80734640359879, 63.086593598127365, 58.26802656054497, 60.88240787386894, 15.806665420532227, 1.0350934322923422, 2.027478818781674, 0.2115453954320401, 4.449102887883782, 66.17906525731087, 59.10406529903412, 67.56299659609795, 64.11583676934242, 64.05659034848213, 60.91079615056515, 59.98604357242584, 51.51616506278515, 55.03539182245731, 53.227304443717, 52.77535289525986, 52.723128497600555, 57.861235588788986, 53.08198884129524, 52.282287552952766, 59.30464893579483, 57.815125063061714, 57.355984300374985, 56.72766521573067, 58.652801513671875, 60.23850202560425, 50.32285049557686, 47.46384970843792, 48.99687744677067, 48.3532527834177, 53.543173894286156, 51.63278080523014, 52.43419200181961, 47.9488480836153, 50.21528206765652, 48.38001474738121, 50.73451280593872, 47.65463747084141, 48.82343575358391, 36.52493208646774, 23.12601886689663, 40.387823805212975, 24.094216413795948, 9.67788403853774, 5.14055036008358, 0.17004121706122532, 0.27537163929082453, 0.10057672145194374, 0.15195354935713112, 0.14149271068163216, 0.2620877599110827, 0.1544908038340509, 0.09650030464399606, 0.2137049412704073, 0.19177070731529966, 0.8713640773203224, 0.2821627358207479, 0.13375187292695045, 0.2918174536898732, 0.13723633048357442, 0.116472960653482, 0.1654495790717192, 0.24257898330688477, 0.29694233962800354, 0.174753884493839, 0.17171096027595922, 0.50141527550295, 0.7538037293124944, 1.3122905767522752, 6.15475251339376, 25.033712200820446, 23.42600516974926, 17.974088117480278, 30.930042006075382, 37.23732925951481, 44.22440953552723, 41.8863569945097, 52.49613247811794, 48.30732084810734, 49.769053012132645, 47.50908248126507, 46.558270901441574, 46.229611337184906, 56.209532618522644, 52.53263711929321, 55.577455535531044, 54.1753763705492, 56.63026884198189, 57.49438427388668, 58.11282768845558, 48.184891417622566, 48.87407943606377, 48.41818369925022, 47.766583263874054, 49.13159541785717, 53.43524068593979, 58.94348971545696, 60.81996962428093, 60.68690836429596, 57.54351183772087, 58.697829097509384, 57.16668985784054, 60.63905753195286, 63.68562765419483, 65.12449264526367, 65.98369494080544, 66.69305607676506, 69.1753488779068, 69.34383943676949, 59.065679758787155, 39.51992377638817, 13.3560249209404, 3.2832090742886066, 0.7699872390367091, 37.85950407385826, 66.7934162914753, 62.489356845617294, 62.35461227595806, 33.33418630063534, 9.43011263385415, 24.37076937407255, 51.7518550157547, 37.88569226861, 27.900724858045578, 29.48444377630949, 41.78297974169254, 49.34974551200867, 46.534020602703094, 39.26096387207508, 55.36665424704552, 61.791550889611244, 26.58559262752533, 66.71893268823624, 47.922713086009026, 61.58431001007557, 73.44208672642708, 96.9512352347374, 18.3457974717021, 0.8480808266904205, 0.30974937428254634, 0.20031204039696604, 0.17273898323765025, 0.1104290880903136], [0.046803008881397545, 0.07422088296152651, 0.021680302561435383, 0.08450097157037817, 0.040328850227524526, 0.0626291596563533, 0.0480994184181327, 0.07855330361053348, 0.0178918223537039, 0.22603585850447416, 0.08651028445456177, 38.618353754282, 71.87755107879639, 44.98492352664471, 40.4893771559, 36.04380950331688, 33.926361724734306, 30.064191967248917, 28.456806018948555, 44.48233589529991, 30.50257634371519, 35.196800753474236, 17.89385162293911, 41.10932528972626, 52.09084242582321, 29.963875450193882, 13.825030904263258, 9.126084297895432, 21.657969541847706, 54.29051399230957, 49.084162563085556, 45.79648397862911, 50.73975272476673, 19.259534440934658, 3.198334453627467, 3.0189230432733893, 0.7786185946315527, 0.365309696062468, 37.150940895080566, 57.061127722263336, 55.505107417702675, 60.220088213682175, 57.84550443291664, 55.27279168367386, 52.39064633846283, 49.86140325665474, 48.67588587105274, 47.868140414357185, 49.470655024051666, 49.90276403725147, 51.14460580050945, 46.56423658132553, 44.4156988710165, 44.53521005809307, 50.23678131401539, 52.52412557601929, 51.83603569865227, 52.83385455608368, 50.26725187897682, 50.151874870061874, 45.9881266951561, 39.571338817477226, 42.54556842148304, 43.26423145830631, 44.68580737709999, 44.037106186151505, 41.077019423246384, 38.57842169702053, 37.85865291953087, 35.96680283546448, 32.081477120518684, 26.720568984746933, 17.849821485579014, 9.594102334231138, 29.162526950240135, 12.13063532486558, 1.3785856193862855, 0.4855600622249767, 0.09279115445679054, 0.1430978870484978, 0.03253679315093905, 0.06876649829791859, 0.034061116239172406, 0.04230692611599807, 0.04311674281780142, 0.025034769241756294, 0.022260578552959487, 0.01999895401240792, 0.09591377049218863, 0.1314921965240501, 0.052853987508569844, 0.05347611877368763, 0.02811676196870394, 0.02760547045909334, 0.004955466611136217, 0.04416484458488412, 0.07502306296373717, 0.018370869402133394, 0.02088427310809493, 0.32278757309541106, 0.20873317524092272, 0.2292708950699307, 0.36904216452967376, 12.21166217699647, 10.989243071526289, 5.73989599943161, 11.368243284523487, 18.34512870758772, 26.466066241264343, 32.79479764401913, 38.8909625262022, 39.67920362949371, 42.28447303175926, 41.68725147843361, 43.540484234690666, 48.255643621087074, 50.71052469313145, 51.199961230158806, 50.07265292108059, 48.544876500964165, 53.115476444363594, 51.580389216542244, 49.8873520642519, 43.66042099893093, 44.405059441924095, 43.019566386938095, 43.67386467754841, 45.2673015743494, 54.00277063250542, 56.08469411730766, 58.6092634499073, 55.62645770609379, 51.71932116150856, 50.14541141688824, 50.26965714991093, 52.82239057123661, 58.228691071271896, 62.144616544246674, 63.54424484074116, 63.09736222028732, 58.63133266568184, 58.26868772506714, 46.81478373706341, 16.77249949425459, 4.0530244912952185, 0.047786688519408926, 5.011857440695167, 54.6462395042181, 51.93595513701439, 56.509416326880455, 46.37282945215702, 26.673124730587006, 2.483178391121328, 11.212819274514914, 35.965393111109734, 22.355460114777088, 13.649724461138248, 20.982071310281754, 31.161770671606064, 29.263073354959488, 32.70935542881489, 37.38858014345169, 31.16992313414812, 58.54687079787254, 31.457385309040546, 29.845855683088303, 35.82214839756489, 45.07319279015064, 49.32408928871155, 76.8777483701706, 19.491694383323193, 1.2767287599854171, 0.06499868133687414, 0.0777714213472791, 0.009889267148537328, 0.039584175538038835, 0.10144688960281201, 0.07909857435151935, 0.02301476757565979, 0.030881321436027065, 0.0341153635235969, 0.08056508784648031, 0.01448119364795275, 0.09834903161390685, 0.08052150151343085, 0.31628238153643906, 0.0281436388468137, 50.87681517004967, 77.68325194716454, 58.3054431527853, 38.50045748054981, 44.07609209418297, 41.11653350293636, 32.65366941690445, 32.62679345905781, 39.83339175581932, 33.57336446642876, 34.9216765165329, 25.08588720113039, 45.41451707482338, 49.147223979234695, 30.397730469703674, 15.266693495213985, 11.112388763576746, 25.03754809498787, 59.74656142294407, 51.883650943636894, 53.05070511996746, 54.95834715664387, 24.845339208841324, 5.340384962037206, 2.6742069656029344, 2.6068296935409307, 0.6265528919175267, 40.21252781152725, 61.01449638605118, 59.999346658587456, 66.12474337220192, 61.62718690931797, 57.78387174010277, 54.03339698910713, 51.30129039287567, 51.75870984792709, 49.52459692955017, 52.075848430395126, 53.323716670274734, 58.001824244856834, 50.230492651462555, 45.94209596514702, 46.770979687571526, 52.00351931154728, 53.59919808804989, 55.22102706134319, 54.55578915774822, 54.46476884186268, 52.69963055849075, 49.518999829888344, 43.6263520270586, 44.93582636117935, 44.26227070391178, 47.730105221271515, 46.91464997828007, 45.601239055395126, 44.90071624517441, 45.149257108569145, 42.006407752633095, 39.34272788465023, 36.13147459924221, 25.887123607099056, 18.04528869688511, 39.25618372857571, 20.487712137401104, 1.8476127390749753, 1.5457214321941137, 0.24173835263354704, 0.07331801578402519, 0.025898480707837734, 0.06043518929800484, 0.030657845927635208, 0.05685526557499543, 0.05760161751823034, 0.019718804396688938, 0.09807148322579451, 0.018144751848012675, 0.13618386117741466, 0.4590147460112348, 0.11527114897035062, 0.1267259757150896, 0.022944740376260597, 0.04336594487540424, 0.04271280296961777, 0.046783612851868384, 0.07330660155275837, 0.01175888743091491, 0.08423813997069374, 0.28938475297763944, 0.7717529567889869, 0.5028835998382419, 0.3612905804766342, 17.435814701020718, 17.23751474171877, 11.306615341454744, 22.393015399575233, 27.866823077201843, 35.241467356681824, 38.31644095480442, 43.43318559229374, 43.094977140426636, 44.704384580254555, 42.49311983585358, 46.034465208649635, 52.50092402100563, 52.4502195417881, 53.06084677577019, 52.71710962057114, 50.87852127850056, 53.82698446512222, 54.11696210503578, 53.50846275687218, 47.177246287465096, 44.76888231933117, 46.02994345128536, 45.88367410004139, 48.124341666698456, 56.70271575450897, 60.6991209089756, 60.93042589724064, 56.54820844531059, 52.50185117125511, 52.74188429117203, 51.9440259039402, 54.82378877699375, 60.24198643863201, 61.618572771549225, 64.06773895025253, 64.62864205241203, 60.59486210346222, 56.326448544859886, 40.97282141447067, 12.54320863634348, 2.3623197013512254, 0.19847077201120555, 9.068499337881804, 63.66180673241615, 54.28545646369457, 60.393830090761185, 52.095003202557564, 30.288655422627926, 2.6094909757375717, 12.579447291791439, 41.60464771091938, 22.109949588775635, 19.84210018068552, 24.737206511199474, 26.261874698102474, 28.83016638457775, 31.74237761646509, 30.485705249011517, 37.32107676565647, 49.00859221816063, 31.053774766623974, 41.631561666727066, 37.092439234256744, 55.552734062075615, 53.916177079081535, 89.90554690361023, 30.656177401542664, 1.1277724779210985, 0.1630911821848713, 0.024347416183445603, 0.02316762402188033, 0.03581071083317511, 0.24179242551326752, 0.15703936864156276, 0.11255697390879504, 0.09638901217840612, 0.10895596948103048, 0.21909628791036084, 0.1486892721732147, 0.2261215914040804, 0.23478509683627635, 0.4332450038054958, 0.14794434886425734, 63.23564440011978, 87.96029448509216, 64.47061613202095, 53.08249041438103, 54.94317077100277, 45.380383506417274, 42.08531811833382, 38.49791541695595, 60.817366763949394, 42.43578091263771, 46.96830689907074, 24.435764886438847, 47.385349720716476, 62.08879753947258, 39.341162368655205, 17.155954018235207, 19.844283163547516, 31.792753413319588, 66.12239509820938, 56.31243109703064, 55.826866552233696, 60.46869747340679, 26.580801084637642, 4.8622718174010515, 9.044504575431347, 2.9918167227879167, 1.1184788891114295, 48.00776392221451, 65.94476222991943, 63.157965168356895, 68.24464961886406, 63.932527005672455, 62.2410249710083, 56.461584493517876, 55.127103701233864, 55.09105883538723, 52.52522751688957, 54.82328720390797, 55.23004777729511, 56.74112789332867, 53.72726261615753, 49.40861575305462, 50.36406308412552, 58.10107871890068, 58.41972582042217, 58.986659198999405, 58.96563492715359, 56.140030547976494, 57.00380399823189, 49.816672056913376, 46.323774084448814, 47.58856661617756, 48.250867277383804, 53.27340357005596, 52.67829470336437, 48.4419172257185, 49.51520383358002, 48.784674033522606, 49.19232375919819, 47.87931181490421, 47.07885816693306, 37.36442483961582, 27.12047852575779, 47.16441437602043, 25.12754436582327, 3.978167320601642, 3.0570912826806307, 0.3688822465483099, 0.29820710769854486, 0.17938889359356835, 0.15503033035201952, 0.27441952319350094, 0.14132909680483863, 0.25803693977650255, 0.07066511243465357, 0.20807897206395864, 0.0683222190127708, 0.37879048206377774, 0.6514725484885275, 0.13330285873962566, 0.27103307365905493, 0.13003687461605296, 0.25883225491270423, 0.16854803077876568, 0.07839265832444653, 0.1981800133944489, 0.1238487359660212, 0.15932104230159894, 0.738784916466102, 1.186352747026831, 0.5802197812590748, 1.7560899001546204, 22.771433293819427, 25.44475134462118, 20.188514292240143, 36.351285204291344, 35.22816427052021, 45.34982554614544, 43.24666500091553, 50.81730656325817, 47.22352780401707, 49.79884721338749, 47.81388312578201, 48.78317691385746, 55.79098507761955, 55.420143976807594, 58.99210050702095, 55.1010636985302, 53.70423585176468, 57.523775696754456, 58.61794978380203, 55.9065330773592, 50.2031759172678, 46.89460605382919, 49.37350943684578, 48.396559059619904, 50.22252447903156, 60.12254364788532, 62.869974821805954, 63.88760581612587, 62.217584028840065, 55.15733487904072, 57.124284133315086, 55.81412963569164, 57.00416497886181, 62.69024446606636, 64.62678015232086, 65.62982752919197, 68.0830442905426, 62.95647718012333, 62.41675414144993, 51.989847645163536, 20.172650143504143, 5.051262276247144, 0.34102323988918215, 6.546756578609347, 63.58519524335861, 61.15456826984882, 67.93140202760696, 54.30669352412224, 36.473619639873505, 7.504261499270797, 17.35265426337719, 47.89419561624527, 30.684563778340816, 19.797830656170845, 29.50988531112671, 42.16518223285675, 39.88022804260254, 43.422394171357155, 47.81856447458267, 40.87756812572479, 78.66804510354996, 39.17768374085426, 44.304490238428116, 47.09791034460068, 61.24765187501907, 67.24088028073311, 97.8314808011055, 40.14940179884434, 1.461770636960864, 0.33176539291162044, 0.15038525772979483, 0.16677034960594028, 0.13379297306528315], [0.026279117118974682, 0.12365299451630563, 0.03493603042443283, 0.019076390235568397, 0.16142454114742577, 0.1006835165026132, 0.03203083026164677, 0.03758779086638242, 0.08835451400955208, 0.2527752908645198, 0.816428525140509, 50.45007526874542, 62.57413409650326, 41.833129450678825, 41.59104444086552, 25.701142586767673, 38.41141685843468, 27.55534429103136, 32.30790317058563, 41.811151430010796, 33.28877113759518, 32.87903532385826, 23.81358627229929, 28.722193278372288, 40.05090728402138, 31.316682659089565, 12.767677791416645, 7.034892160445452, 15.89133532717824, 53.81579026579857, 48.84612433612347, 47.503496780991554, 69.27515432238579, 53.538834527134895, 17.754013426601887, 3.3801518473774195, 3.0693650990724564, 0.09269387373933569, 23.367148227989674, 57.70141616463661, 53.82697306573391, 59.279228299856186, 57.52605937421322, 55.30856296420097, 49.640460312366486, 48.548349514603615, 47.773719280958176, 47.533518970012665, 53.353936448693275, 56.48407928645611, 58.60120788216591, 54.33989234268665, 46.981389597058296, 44.469416588544846, 45.905150547623634, 48.61270286142826, 51.87664411962032, 52.55820594727993, 53.95784944295883, 52.42128029465675, 49.393245577812195, 46.767206490039825, 43.82410481572151, 42.129049971699715, 43.20766769349575, 42.68271066248417, 42.62873075902462, 38.57338696718216, 39.29926581680775, 34.553130492568016, 31.582459397614002, 23.47467675805092, 13.924326226115227, 9.776007123291492, 33.25439818203449, 18.934632875025272, 0.3385750134475529, 0.5206380877643824, 0.13972481101518497, 0.09503844441496767, 0.046573848521802574, 0.03669254554552026, 0.00852359204145614, 0.00891021016286686, 0.06443536898586899, 0.10052451878436841, 0.09032472313265316, 0.0808901856362354, 0.014658794225397287, 0.3595906466944143, 0.00943106517297565, 0.023890835800557397, 0.04456327769730706, 0.05562253230891656, 0.074561254150467, 0.07527715948526748, 0.044785858917748556, 0.022577011768589728, 0.05828749926877208, 0.013132563817634946, 0.023140470693761017, 0.19298382190754637, 0.4860425472725183, 10.079846419394016, 11.248719748109579, 5.477438857778907, 9.814380314201117, 19.945648424327374, 23.340095579624176, 31.37811206281185, 36.68355457484722, 39.15677726268768, 40.50670802593231, 40.58151461184025, 48.17259147763252, 49.799717366695404, 51.37265436351299, 50.07413104176521, 45.18577694892883, 48.535950779914856, 52.32336714863777, 52.630892246961594, 48.982829600572586, 43.94850634038448, 44.73933510482311, 41.71623632311821, 45.964689552783966, 51.291722506284714, 56.89797967672348, 57.44350500404835, 58.503480926156044, 53.62292781472206, 51.53415709733963, 47.42499679327011, 50.91561868786812, 52.957230135798454, 57.515963315963745, 63.10683511197567, 64.53388273715973, 60.58952338993549, 59.661825969815254, 38.511993661522865, 12.714108265936375, 3.5779013112187386, 0.679904700955376, 0.10741072153905407, 15.209986288100481, 53.24637942016125, 46.82748265564442, 52.921747639775276, 52.07573443651199, 24.038589298725128, 0.19421779084950686, 17.513159550726414, 60.54105319082737, 33.6046177893877, 15.605706553906202, 23.96236728876829, 34.034648314118385, 32.88743667304516, 28.591670282185078, 40.24339735507965, 30.613197907805443, 42.55503751337528, 45.78679829835892, 29.644983261823654, 35.15480540692806, 35.395932868123055, 49.40492235124111, 69.55820873379707, 25.997414588928223, 1.1199915641918778, 0.12151695249485783, 0.141045106574893, 0.134480647102464, 0.0952579197473824, 0.03087365133978892, 0.011417314890422858, 0.07710959631367587, 0.07525064997025765, 0.059466604943736456, 0.015811498924449552, 0.0557946437766077, 0.052762502964469604, 0.16090898599941283, 0.35307159181684256, 1.2946328055113554, 64.55678790807724, 71.17024943232536, 52.50495560467243, 43.70299771428108, 34.1986171156168, 40.84795631468296, 31.930382028222084, 36.6109898686409, 38.075533881783485, 33.354336619377136, 34.30721528828144, 28.67040205746889, 34.04767021536827, 45.12848362326622, 31.482416465878487, 14.300893619656563, 8.907972201704979, 15.729591306298971, 57.06317961215973, 52.87758260965347, 52.35039509832859, 71.55328407883644, 57.26622931659222, 24.81100235134363, 3.720802618190646, 4.05999094247818, 0.46009086014237255, 24.941371455788612, 63.21344219148159, 57.51888915896416, 63.150753155350685, 62.560428231954575, 60.15060134232044, 53.057012781500816, 50.840454921126366, 50.869017988443375, 50.881409123539925, 58.49724546074867, 60.857766196131706, 63.7071269005537, 58.58917012810707, 52.0799446105957, 47.17669911682606, 48.60052451491356, 50.92335507273674, 54.031470492482185, 54.33054104447365, 56.096169501543045, 51.71302109956741, 53.57285410165787, 51.37681134045124, 46.551773250103, 47.31316119432449, 48.64408157765865, 47.13335484266281, 47.683474123477936, 42.84097217023373, 46.36116787791252, 40.86126320064068, 38.55419799685478, 32.96776436269283, 22.811230458319187, 19.09114647656679, 34.952329471707344, 22.004254460334778, 0.8594011911191046, 0.6586152745876461, 0.06709579029120505, 0.010342201730964007, 0.07035323229501955, 0.05370384307752829, 0.03581041768484283, 0.08740075776586309, 0.03809391702816356, 0.025440978206461295, 0.03988499396655243, 0.04674463896662928, 0.072000013460638, 0.6919716659467667, 0.29413746669888496, 0.10196210336289369, 0.03924629054381512, 0.03253399525419809, 0.006558380819114973, 0.016456599660159554, 0.07900281503680162, 0.009655121411924483, 0.04220706643536687, 0.07172932993853465, 0.13696235924726352, 0.26818672951776534, 0.17838864179793745, 13.546616043895483, 16.825474351644516, 13.085677977651358, 21.693326644599438, 28.82117986679077, 32.98691153526306, 38.65526497364044, 42.32133865356445, 43.709430769085884, 43.55966940522194, 46.30588844418526, 52.1245314180851, 51.09017752110958, 54.45073999464512, 52.178815305233, 47.34322518110275, 51.25832609832287, 54.16323982179165, 55.51894627511501, 51.10424816608429, 47.01401084661484, 47.44445934891701, 46.27990163862705, 49.812872260808945, 56.753937005996704, 56.75750881433487, 60.28955228626728, 60.7976496219635, 56.07916161417961, 53.85864816606045, 51.08302630484104, 53.54370206594467, 55.70397734642029, 60.054553896188736, 64.2218054831028, 66.51281654834747, 59.949994906783104, 58.38294379413128, 32.66884200274944, 8.129266686737537, 3.768200562335551, 0.5977763829287142, 0.8961261610966176, 22.860597409307957, 57.30719491839409, 53.058684691786766, 55.41087627410889, 58.62107701599598, 20.978968776762486, 0.712664524326101, 24.48284436017275, 69.08015638589859, 39.64968301355839, 23.40665850788355, 28.889519199728966, 28.579328544437885, 29.972529485821724, 33.015915378928185, 33.33744652569294, 34.605514481663704, 42.41574078798294, 40.60035020112991, 37.34181225299835, 41.392056718468666, 48.49446460604668, 56.147911325097084, 78.9324501156807, 37.087757885456085, 0.8332430978771299, 0.12440384016372263, 0.07677691377466545, 0.05695601212210022, 0.04261888418113813, 0.18908034777268767, 0.14197341457474977, 0.1468444860074669, 0.1552852729219012, 0.32107199484016746, 0.17183498799568042, 0.19795055617578328, 0.17154408094938844, 0.43354622670449317, 0.5326837976463139, 2.010766603052616, 77.37559005618095, 82.4577185511589, 58.345888182520866, 53.64128462970257, 39.76671673357487, 54.426649287343025, 37.24016010761261, 45.32185144722462, 56.03088900446892, 42.87376061081886, 43.413415253162384, 33.49684037268162, 36.28109537065029, 51.092195212841034, 40.3916160017252, 15.550228580832481, 13.481997661292553, 25.90902753174305, 65.54380774497986, 58.879710137844086, 56.86696574091911, 79.12183955311775, 63.70649993419647, 23.580998852849007, 8.723304010927677, 8.866911605000496, 0.38351383642293513, 34.73452515900135, 69.87601608037949, 61.271320804953575, 66.39022752642632, 64.81357052922249, 62.6903660595417, 56.541615799069405, 55.04468612372875, 52.78192274272442, 53.00533935427666, 58.768531903624535, 63.781963884830475, 65.88433787226677, 59.302175268530846, 55.89786194264889, 50.164319202303886, 52.41981737315655, 54.18078348040581, 56.42647437751293, 59.71023917198181, 61.52631372213364, 58.12935680150986, 56.406590044498444, 53.336461186409, 49.289898723363876, 50.09884111583233, 50.017175897955894, 51.46230675280094, 50.23484341800213, 47.678944766521454, 49.55923207104206, 47.67031542956829, 47.1850548684597, 43.492857590317726, 33.31309363245964, 29.534382596611977, 45.23946426808834, 30.10760273784399, 1.6747920750640333, 1.0755326435901225, 0.13225411501480266, 0.2859508356777951, 0.14168126072036102, 0.16916533437324688, 0.10195765789831057, 0.20894986751955003, 0.16015726461773738, 0.14627135504269972, 0.26187574316281825, 0.1536146242870018, 0.1416940553463064, 1.4446100452914834, 0.16535152652068064, 0.17204131989274174, 0.19023238361114636, 0.441857241676189, 0.15735834371298552, 0.22880564269144088, 0.19370165682630613, 0.07676728069782257, 0.1812381623312831, 0.1937783503672108, 0.2166129430406727, 0.4918306757463142, 0.8000894612632692, 17.118974402546883, 23.83206658065319, 19.38936587423086, 31.998082995414734, 38.30386362969875, 40.77367030084133, 43.22075039148331, 49.62792478501797, 47.40327335894108, 48.92729178071022, 48.39980028569698, 54.27539840340614, 55.04038855433464, 56.416264325380325, 55.01297302544117, 50.02669058740139, 53.19971412420273, 57.039491683244705, 58.77134755253792, 54.22935247421265, 50.12620724737644, 48.902152329683304, 48.09897802770138, 52.46219649910927, 57.08894222974777, 58.56335811316967, 64.7045923769474, 62.80164688825607, 58.14061939716339, 56.86179801821709, 51.95930868387222, 57.20479041337967, 57.70345665514469, 61.21180459856987, 67.4421326816082, 69.88603234291077, 63.33901785314083, 64.22890350222588, 45.83562947809696, 14.41597044467926, 5.108158523216844, 0.8648466551676393, 0.7481961802113801, 19.293358325958252, 63.72613348066807, 55.06120763719082, 61.487741991877556, 61.42400041222572, 34.277291893959045, 2.9170046746730804, 27.07090638577938, 64.59024891257286, 40.139290541410446, 21.936293207108974, 37.4180893599987, 46.02394737303257, 43.00097778439522, 37.28272542357445, 51.72418110072613, 41.59451745450497, 59.69601273536682, 53.592909425497055, 43.647459894418716, 46.4614786952734, 47.103043869137764, 69.13999557495117, 87.88248226046562, 51.63659580051899, 1.3501212280243635, 0.24637684982735664, 0.20420415967237204, 0.1902182976482436, 0.11992845218628645], [0.07315223483601585, 0.08099594910163432, 0.05799229518743232, 0.02698442458495265, 0.13715806358959526, 0.04963076222338714, 0.07620770134963095, 0.05137261621712241, 0.13699014525627717, 0.2496966248145327, 3.7842817744240165, 68.79519447684288, 58.43977354466915, 33.660520389676094, 29.542430564761162, 34.96269151568413, 42.16568760573864, 30.126765109598637, 35.740365386009216, 39.075461626052856, 40.06918050348759, 32.712414264678955, 34.1752103716135, 32.75579273700714, 36.415505558252335, 33.8575854152441, 14.889292046427727, 6.3369527366012335, 5.318199852481484, 36.4851900190115, 59.12921994924545, 55.19277937710285, 54.7023168951273, 56.297437101602554, 32.82446265220642, 4.76942902430892, 4.789662938565016, 0.4145071702077985, 10.192161742597818, 56.15415059030056, 54.75549504160881, 59.80885908007622, 56.7716820538044, 53.79946254193783, 50.24172864854336, 49.70579020678997, 49.89466667175293, 54.46584418416023, 60.67904278635979, 60.28149671852589, 60.23072004318237, 61.79054394364357, 50.86812503635883, 44.69144247472286, 45.37425443530083, 45.39073795080185, 49.715878665447235, 50.47996826469898, 53.735933750867844, 49.82358768582344, 51.30465321242809, 48.77989009022713, 47.036296650767326, 41.0002863407135, 45.77275425195694, 41.4827236533165, 43.66804338991642, 40.179617777466774, 37.7608385682106, 34.251882657408714, 27.593904621899128, 23.528909347951412, 11.211728733032942, 11.32581191137433, 23.532365262508392, 9.64764716103673, 0.3369862533872947, 0.1639505595085211, 0.08624424677691422, 0.06108993424277287, 0.029277826033649035, 0.009252776253561024, 0.06341985863400623, 0.02113648828526493, 0.07011063164100051, 0.08445213825325482, 0.04296786057238933, 0.023305557733692694, 0.0251718531944789, 0.1804894392262213, 0.46395498560741544, 0.06789193663280457, 0.0377799662965117, 0.04090154332516249, 0.047374763162224554, 0.08584791765315458, 0.03943013165553566, 0.006379551523423288, 0.07897286937804893, 0.10657832128345035, 0.07190915232058614, 0.11544962064363062, 0.19958838704042137, 7.022099671885371, 10.538213923573494, 7.927022064104676, 12.3258887976408, 21.298087053000927, 27.421783357858658, 33.179728388786316, 35.42038455605507, 38.05010564625263, 40.206056758761406, 45.68509295582771, 48.447084948420525, 48.484687730669975, 51.82493269443512, 46.18153631687164, 45.4861356317997, 49.219727888703346, 51.99047461152077, 52.42376156151295, 47.78867527842522, 44.44040894508362, 43.800808265805244, 42.84307725727558, 50.02192944288254, 54.41618464887142, 55.98920904099941, 57.32106037437916, 56.81336581707001, 58.0070261657238, 50.87301917374134, 50.079492554068565, 50.224317982792854, 51.495022997260094, 56.82027004659176, 62.81243830919266, 63.14835548400879, 59.44737307727337, 40.135798528790474, 6.181293139234185, 1.323321859817952, 1.4131992682814598, 0.10138012599782087, 6.712141754105687, 39.33946765959263, 40.29261991381645, 60.128273740410805, 59.77684199810028, 50.61386168003082, 6.752700302749872, 0.3272203617962077, 13.600109573453665, 36.83455087244511, 32.900614365935326, 26.080850511789322, 25.649136677384377, 28.197648525238037, 29.13348700851202, 31.05362467467785, 33.80491264164448, 39.74791154265404, 28.34308762103319, 41.02788046002388, 38.09866704046726, 30.87839137762785, 28.56811534613371, 44.79726679623127, 65.58951929211617, 33.511226400732994, 0.669096359051764, 0.03695461644383613, 0.0653919082833454, 0.04188748280284926, 0.08662732114316896, 0.09031658177264035, 0.04379714751848951, 0.03876828064676374, 0.08673791598994285, 0.022714832302881405, 0.042500073759583756, 0.07368007252807729, 0.05595088441623375, 0.28750904893968254, 0.27100600011181086, 5.978710809722543, 80.23200318217278, 64.95728641748428, 44.34547483921051, 36.8846245855093, 40.928325802087784, 42.28660851716995, 32.187176048755646, 37.64452300965786, 35.66899001598358, 38.177862390875816, 31.949419006705284, 36.62240445613861, 34.69252601265907, 38.362897261977196, 30.495375730097294, 10.496608056128025, 8.18574495613575, 7.1327065117657185, 39.001483395695686, 61.82226464152336, 56.45976819097996, 58.366844058036804, 57.179362177848816, 40.495741814374924, 5.521581564098597, 2.708318685181439, 0.8933748712297529, 11.255551781505346, 62.898059114813805, 57.79703803360462, 63.53883013129234, 61.335985735058784, 57.21887245774269, 51.678602546453476, 53.5625034570694, 51.468637213110924, 58.434305638074875, 63.107336685061455, 63.87242183089256, 61.76363758742809, 64.49928179383278, 55.76151765882969, 46.212675645947456, 49.27888311445713, 48.591104820370674, 51.406115368008614, 53.235014230012894, 55.94638153910637, 53.498666882514954, 54.24995876848698, 51.25217042863369, 52.2495599091053, 44.53355334699154, 50.79171873629093, 46.22915916144848, 46.33904546499252, 44.72076550126076, 45.68606570363045, 41.69879525899887, 36.83300815522671, 33.60387682914734, 17.721363678574562, 19.36977032572031, 24.320522770285606, 8.971990216523409, 0.25638607679866254, 0.17434404086088762, 0.02058100188151002, 0.03061767161852913, 0.06587002950254828, 0.03082250437728362, 0.05968971308902837, 0.050350485907983966, 0.028834723052568734, 0.08256755812908523, 0.07773719349643216, 0.03300311051134486, 0.06304109614575282, 0.4688419686863199, 0.6926309305708855, 0.11416306311730295, 0.08722014870727435, 0.03164998604916036, 0.024304542312165722, 0.024239340928033926, 0.08203474062611349, 0.038242673108470626, 0.03770767740206793, 0.05680705566192046, 0.03922257150406949, 0.1186113701260183, 0.08446851003100164, 9.954846426844597, 16.901246085762978, 15.163910910487175, 23.62488839775324, 32.0369017124176, 35.71127414703369, 40.587180107831955, 40.85698843002319, 41.67898692190647, 45.557469204068184, 49.998876079916954, 51.95055395364761, 51.65458783507347, 52.62975990772247, 46.6713148355484, 46.23476006090641, 52.74980686604977, 54.88560765981674, 55.47913581132889, 50.846739783883095, 47.6121823489666, 45.13398952782154, 45.71568511426449, 52.18581072986126, 57.34223663806915, 59.72370184957981, 60.015191808342934, 58.74707445502281, 59.35709752142429, 53.73338408768177, 52.81993970274925, 50.89592434465885, 55.96569590270519, 58.69208000600338, 66.8925529718399, 61.40741430222988, 61.35455533862114, 35.505610182881355, 2.2252570185810328, 0.9020991437137127, 1.5376463904976845, 0.7070604781620204, 10.70843243971467, 44.0074297785759, 44.625151231884956, 66.48690953850746, 69.20409813523293, 53.11607301235199, 7.736679827794433, 1.6496007330715656, 14.171893391758204, 35.0224357098341, 38.18975955247879, 33.15360099077225, 27.0886305347085, 29.87982966005802, 27.612280435860157, 32.90406838059425, 30.464538484811783, 38.15287113189697, 34.92328763008118, 36.72635167837143, 41.880927085876465, 34.35034677386284, 32.11187928915024, 52.18809820711613, 72.63924300670624, 42.817303240299225, 0.7231426995713264, 0.044136249634902924, 0.10935072525171563, 0.13183175877202302, 0.09195375212584622, 0.1795136189321056, 0.1932401448721066, 0.13516115199308842, 0.29044792405329645, 0.2596908307168633, 0.1764837119844742, 0.4399802314583212, 0.24766352609731257, 0.4995500505901873, 0.4909181606490165, 7.932998668402433, 89.71614986658096, 76.6247883439064, 47.86234192550182, 42.60752409696579, 47.42485620081425, 56.439887657761574, 39.65157151222229, 47.74403527379036, 52.11128532886505, 55.62078461050987, 43.173070549964905, 47.2641172260046, 43.64220857620239, 46.94024160504341, 42.948665991425514, 19.09331426024437, 13.393691349774599, 12.601398713886738, 50.32105699181557, 66.01460248231888, 61.91091388463974, 64.81407970190048, 66.27120271325111, 41.06515645980835, 8.360912706702948, 11.844708267599344, 0.8458511775825173, 16.91474676132202, 72.82198280096054, 59.56932373344898, 69.940255433321, 62.41406008601189, 59.67365473508835, 55.261365696787834, 56.352473348379135, 54.02721852064133, 59.10797528922558, 66.56551212072372, 66.25579074025154, 64.9225714802742, 68.64886432886124, 57.387146428227425, 49.76972557604313, 53.71487908065319, 52.632127180695534, 56.58141106367111, 58.187014907598495, 60.04708729684353, 55.86165748536587, 55.061238035559654, 54.805158376693726, 53.5996350646019, 47.315813452005386, 54.24885302782059, 47.57832996547222, 51.56484045088291, 49.77519728243351, 48.98030273616314, 46.64794608950615, 47.10042580962181, 43.61083745956421, 29.936598613858223, 30.419940277934074, 38.55193331837654, 19.03071641921997, 0.8722938993014395, 0.40573682519607246, 0.17816198989748955, 0.19978015800006688, 0.1550754826166667, 0.11459587622084655, 0.18245259794639423, 0.20513019670033827, 0.2126568803214468, 0.15483027702430263, 0.15204186493065208, 0.0778816376987379, 0.18110515462467447, 1.5722000738605857, 1.276967078447342, 0.24268993438454345, 0.19957557757152244, 0.17990198481129482, 0.08971165720140561, 0.16911884624278173, 0.23468354134820402, 0.13700388983124867, 0.11642558936728165, 0.1911026705056429, 0.19818949804175645, 0.23724497499642894, 0.1803692409885116, 14.465605281293392, 23.965395726263523, 24.12614230066538, 35.25016129016876, 41.376663744449615, 42.994955107569695, 45.2426864951849, 47.291031181812286, 46.4336071908474, 47.73601770401001, 50.37033274769783, 53.102150559425354, 53.76329988241196, 56.577941849827766, 48.20094555616379, 48.79536285996437, 54.77676250040531, 57.35816538333893, 59.5532163977623, 52.161419838666916, 48.149028941988945, 48.639100044965744, 48.03722754120827, 54.88661080598831, 58.83111074566841, 63.273266181349754, 61.27774626016617, 62.47631594538689, 62.72540017962456, 58.12583439052105, 55.15779845416546, 54.39736805856228, 56.26264996826649, 61.98078453540802, 68.89346480369568, 65.13904586434364, 62.784532606601715, 46.65367238223553, 9.890504479408264, 3.03819727152586, 3.534412169829011, 0.87981874239631, 7.828957876190543, 49.274042174220085, 51.11243672668934, 69.68683183193207, 68.6941047012806, 59.512653574347496, 13.348481375724077, 3.5260108206421137, 19.48942020535469, 42.94951714575291, 40.327464044094086, 33.36696334183216, 36.941910311579704, 39.36871089041233, 40.2729369699955, 39.99042212963104, 44.88349936902523, 51.22770734131336, 42.43376322090626, 51.99997030198574, 52.959726601839066, 42.92591281235218, 38.49275529384613, 68.17141234874725, 80.714121311903, 56.152653470635414, 0.7715215848293155, 0.1462359694414772, 0.28206450515426695, 0.2489192844950594, 0.21901306346990168], [0.046882522583473474, 0.04724954800622072, 0.02895634992455598, 0.07988150304299779, 0.016869024111656472, 0.07861624515498988, 0.03360092159709893, 0.037611331790685654, 0.10950394163955934, 0.24695189553312957, 3.8699493650346994, 66.78722262382507, 48.85770991444588, 35.93933790922165, 32.655903697013855, 30.76848227530718, 37.43790149688721, 31.04614667594433, 41.92685902118683, 32.57613457739353, 38.653482869267464, 32.41716630756855, 35.2926392108202, 36.142239421606064, 34.3643756210804, 34.24845904111862, 15.245877262204885, 6.760547356680036, 4.742663260549307, 21.601236686110497, 50.82141034305096, 57.309060618281364, 58.16939525306225, 57.46751211583614, 55.5874489992857, 8.093368113040924, 2.379453219473362, 0.16014282242394984, 3.9286958752200007, 53.98040883243084, 54.33595575392246, 57.602059096097946, 59.649571627378464, 55.30823618173599, 48.81609454751015, 47.88923688232899, 49.64734934270382, 56.71445332467556, 59.97107237577438, 60.85221849381924, 60.828541964292526, 60.26352748274803, 56.574347242712975, 45.50403647124767, 45.51019214093685, 43.532003089785576, 47.31270141899586, 48.80481295287609, 51.552099734544754, 50.157300978899, 52.99207046627998, 49.710703343153, 49.088380336761475, 42.86038152873516, 45.43748304247856, 43.50016459822655, 42.873916402459145, 40.63700683414936, 39.347439631819725, 35.88768348097801, 26.106535233557224, 20.142586156725883, 7.836818229407072, 10.443741492927074, 18.098065964877605, 1.8185670976527035, 0.35148968920111656, 0.014896454031259054, 0.18329248647205532, 0.02622586802317528, 0.08145508618326858, 0.03853615540720057, 0.05093516840133816, 0.035996822916786186, 0.031230056629283354, 0.025072821008507162, 0.056085205724230036, 0.05340764080756344, 0.16297451657010242, 0.3302952280500904, 0.6806010729633272, 0.058965399221051484, 0.015389115778816631, 0.07809407747117803, 0.06002284091664478, 0.05178835621336475, 0.10365284935687669, 0.04746400270960294, 0.12532220338471234, 0.042421072139404714, 0.049830414791358635, 0.07674180276808329, 0.1286804661503993, 4.491584608331323, 10.851642955094576, 8.964374475181103, 16.324929110705853, 24.555994234979153, 28.800858557224274, 33.34747038781643, 37.196397855877876, 40.19431158900261, 44.58401083946228, 48.253929913043976, 48.920049369335175, 52.816888466477394, 46.211045533418655, 42.84149654209614, 47.08692133426666, 50.01672752201557, 52.33456514775753, 50.910735949873924, 45.81277370452881, 43.43693219125271, 42.81120076775551, 42.49792277812958, 52.65809878706932, 58.67902770638466, 55.80558009445667, 58.16031754016876, 56.83195821940899, 55.84777683019638, 51.9623751193285, 52.304041385650635, 49.14680600166321, 56.21620126068592, 58.714627996087074, 62.297949716448784, 60.97535468637943, 59.53295208513737, 9.372595120221376, 0.12124517059419304, 0.4148204455850646, 0.36217023327481, 0.7911963353399187, 18.381962031126022, 52.70500726997852, 59.875716492533684, 51.52626112103462, 35.98968520760536, 39.28255811333656, 6.192901516333222, 1.3253065408207476, 10.753616765141487, 30.900375097990036, 29.235940910875797, 28.048791512846947, 30.032541565597057, 24.737934172153473, 28.66208240389824, 32.77578346431255, 31.908738389611244, 40.33840365707874, 32.42610342800617, 33.44642847776413, 38.51663701236248, 33.57813701033592, 40.83662152290344, 43.56562748551369, 68.25091168284416, 27.435168139636517, 0.6789274408947676, 0.0709053901664447, 0.16769896930782124, 0.02775532120722346, 0.012262214768270496, 0.061848498226027004, 0.07864774932386354, 0.07167910880525596, 0.08767383842496201, 0.07096329252817668, 0.048439945458085276, 0.15480758214835078, 0.03874784189974889, 0.39167232520412654, 0.31424934219103307, 6.7202704679220915, 78.44885766506195, 58.822659999132156, 42.213318049907684, 34.28007714450359, 38.201485723257065, 39.12794440984726, 32.953393533825874, 38.73846910893917, 32.10334114730358, 36.72402620315552, 31.7405841127038, 36.90532587468624, 36.952724531292915, 34.55172836780548, 30.96302803605795, 10.959782302379608, 6.109911119565368, 7.759133297950029, 25.21352995187044, 51.27642072737217, 59.951058849692345, 63.64980697631836, 66.97205230593681, 65.11262208223343, 11.67452584952116, 2.9151460994035006, 1.8835154687985778, 5.210516480728984, 59.51438628137112, 59.194428250193596, 61.316519379615784, 61.94874465465546, 58.63350234925747, 52.09482841193676, 50.90185962617397, 53.2048362493515, 60.5847242474556, 62.81780742108822, 62.66930378973484, 61.98333039879799, 64.12521466612816, 60.11484146118164, 50.14157362282276, 47.92273968458176, 47.34352916479111, 50.3778525441885, 51.00242123007774, 52.40206092596054, 53.4355104714632, 57.90095865726471, 52.797475308179855, 51.832817271351814, 47.963401302695274, 48.34202438592911, 48.30982871353626, 49.48895864188671, 45.73086529970169, 48.0497782677412, 42.35417649149895, 36.85188174247742, 27.588651403784752, 16.19307618588209, 17.621214352548122, 18.57143886387348, 2.347113867290318, 0.3691432747291401, 0.13438537018373609, 0.060478408267954364, 0.03851350877084769, 0.062184360867831856, 0.049714405977283604, 0.023360231753031258, 0.04467187616683077, 0.0272218005193281, 0.015862228428886738, 0.018968266740557738, 0.04796507484570611, 0.06686118256766349, 0.22873711277497932, 0.6893332418985665, 0.06784260607673787, 0.030189203789632302, 0.13491793535649776, 0.028478583080868702, 0.0746898831857834, 0.00712881407707755, 0.0700290102395229, 0.038206018434721045, 0.055679020879324526, 0.04478738774196245, 0.06527615551021881, 0.04626272537279874, 5.873020431026816, 16.842810921370983, 19.211959093809128, 27.96612124890089, 36.05696439743042, 36.71004295349121, 40.842245221138, 43.485911563038826, 45.5656311661005, 47.802103757858276, 51.788131669163704, 52.24086597561836, 56.666883677244186, 47.68092446029186, 44.207899421453476, 50.53817734122276, 53.80994237959385, 54.061773866415024, 53.290343061089516, 48.771853521466255, 45.156940296292305, 45.2063300460577, 46.18286244571209, 55.291258692741394, 58.70937667787075, 58.401935175061226, 57.73631729185581, 60.08945882320404, 56.75803318619728, 56.10666833817959, 55.1207010447979, 52.603419721126556, 57.18463249504566, 60.684024319052696, 64.74104762077332, 62.36945427954197, 57.84876465797424, 6.033020820468664, 0.18018276896327734, 2.35706505831331, 0.9886946564074606, 1.1983357602730393, 23.86484172195196, 58.43351528048515, 59.28623512387276, 56.429932191967964, 37.19893231987953, 44.993317276239395, 7.118955049663782, 2.26858823094517, 6.977230254560709, 32.30166010558605, 27.356825843453407, 29.801498763263226, 29.67487245798111, 27.65225049108267, 26.61317154765129, 34.04849857091904, 33.43413233757019, 32.161664217710495, 38.28005410730839, 33.37234005331993, 43.114458695054054, 41.21370188891888, 39.50632430613041, 55.19814468920231, 76.08093112707138, 34.725747630000114, 0.6604546727612615, 0.13233869016403332, 0.2242061824654229, 0.08806317651760764, 0.06791264997445978, 0.2620243211276829, 0.18816278607118875, 0.16613472980679944, 0.27186383376829326, 0.18274205038323998, 0.12760028504999354, 0.4031342320377007, 0.24336181551916525, 0.8132707758340985, 0.6629491201601923, 11.279424000531435, 91.13123193383217, 71.13104313611984, 47.55081944167614, 45.31672552227974, 42.81789980828762, 52.527271807193756, 42.36047275364399, 56.6322523355484, 42.79581539332867, 53.34734760224819, 44.1635861992836, 46.88548654317856, 47.11043447256088, 45.78055523335934, 41.27641752362251, 20.71024339646101, 13.738101068884134, 11.488071754574776, 33.048415035009384, 60.29755085706711, 67.563216984272, 67.52020329236984, 67.26091280579567, 66.36625841259956, 10.94145493581891, 6.331738941371441, 2.425867966376245, 9.356341492384672, 69.63640853762627, 62.0075237005949, 66.86280816793442, 67.10613951086998, 62.92774312198162, 54.652562364935875, 54.21398989856243, 53.82039561867714, 64.85944166779518, 64.31266620755196, 65.6554913520813, 63.41683767735958, 68.05975154042244, 63.65831471979618, 50.27129866182804, 51.329112499952316, 50.070540234446526, 54.347062557935715, 54.709673300385475, 57.583937868475914, 56.77625700831413, 62.283605486154556, 57.4981764703989, 53.98793622851372, 50.17934359610081, 51.06021612882614, 51.38471871614456, 51.32365599274635, 49.46128472685814, 52.46847376227379, 51.72583781182766, 45.41126824915409, 37.52914600074291, 29.33496169745922, 28.98297518491745, 30.005665607750416, 4.2025037202984095, 0.6416951981373131, 0.20403159549459815, 0.40870223951060325, 0.1261664112098515, 0.1795585930813104, 0.09471670113271102, 0.12576174776768312, 0.12740955309709534, 0.1627434859983623, 0.10728493492933922, 0.18163317785365507, 0.11304872095934115, 0.21967042819596827, 0.5380259547382593, 0.9873688244260848, 0.18404910602839664, 0.10138805955648422, 0.33846529433503747, 0.17329611349850893, 0.1790761822485365, 0.27221478056162596, 0.1600240491097793, 0.21784533862955868, 0.25235888664610684, 0.1330453483387828, 0.20905210578348488, 0.21908913360675797, 7.340224776417017, 21.705997064709663, 23.18699039518833, 34.080200269818306, 40.9724186360836, 41.07827715575695, 44.893295243382454, 49.26497206091881, 49.95069466531277, 52.35156163573265, 54.66073952615261, 54.98948648571968, 58.61331023275852, 49.47986572980881, 44.85231064260006, 52.119204103946686, 54.64055880904198, 58.52108158171177, 55.256786942481995, 50.87507486343384, 47.87393890321255, 46.89804866909981, 47.3809989541769, 58.449303433299065, 61.83440499007702, 59.95080426335335, 61.6511370241642, 62.23803073167801, 58.96904334425926, 58.83928410708904, 58.23338761925697, 54.5615154504776, 61.56061828136444, 61.91039711236954, 66.1268712580204, 64.06259402632713, 60.73620691895485, 12.726960126310587, 0.2642945805564523, 2.6542767975479364, 1.4594157133251429, 1.640395608264953, 21.730336658656597, 67.67339587211609, 68.99245709180832, 61.89423277974129, 46.28369003534317, 50.464757680892944, 11.344437561929226, 3.668135544285178, 14.925264716148376, 38.60807150602341, 35.488708689808846, 38.13019394874573, 42.19382889568806, 35.06778247654438, 38.16956363618374, 44.343464747071266, 44.13722701370716, 54.83567073941231, 46.543402299284935, 43.24299059808254, 52.648542299866676, 49.436491057276726, 48.60385313630104, 68.56832385063171, 85.2624848484993, 51.61702685058117, 0.858133127912879, 0.34423495817463845, 0.30189095064997673, 0.1974760863231495, 0.1702481129905209], [0.08113573261653073, 0.051884575659641996, 0.026677858222683426, 0.05156995328434277, 0.03799937854637392, 0.03180774438078515, 0.1052960311062634, 0.029837282927474007, 0.061984726853552274, 0.2893783408217132, 2.671993584372103, 67.97813192009926, 50.645601376891136, 32.25824363529682, 37.818124294281006, 30.3315532207489, 36.709412187337875, 32.914343029260635, 42.388921827077866, 35.03799967467785, 33.502103090286255, 33.26373428106308, 34.90751467645168, 35.0537346303463, 39.40019220113754, 32.20172546803951, 9.01646587997675, 4.495325507596135, 4.761054748669267, 23.668479658663273, 55.00205621123314, 62.600637674331665, 57.74996995925903, 47.76611968874931, 45.66316433250904, 21.19445141404867, 2.3334524128586054, 0.7138688815757632, 1.1530400533229113, 46.86849385499954, 58.78721550107002, 58.03667217493057, 60.47072656452656, 54.84539441764355, 48.675589486956596, 49.419433772563934, 54.0811338275671, 59.51818227767944, 61.955637484788895, 59.42753814160824, 60.32834440469742, 61.65468983352184, 57.78765253722668, 50.36845184862614, 43.00347425043583, 46.03815101087093, 45.44316753745079, 49.79499042034149, 49.48951721191406, 52.05116495490074, 54.35289904475212, 51.52377225458622, 48.89085553586483, 47.8562318533659, 44.63386416435242, 43.095509111881256, 42.658756747841835, 42.136486172676086, 41.10057435929775, 32.073520347476006, 26.70844953507185, 15.741120837628841, 7.7880682703107595, 10.1570088788867, 10.409666821360588, 0.2766356652136892, 0.057122602011077106, 0.02313076525751967, 0.0436642028944334, 0.00791761362052057, 0.042375148041173816, 0.07792281205183826, 0.07265795706189238, 0.0422070590138901, 0.06958470126846805, 0.03535508039931301, 0.12487695930758491, 0.03835171686660033, 0.11303396706352942, 0.16783488623332232, 0.4262971063144505, 0.02670934198249597, 0.021036997823102865, 0.0665288043092005, 0.005489959512487985, 0.040203842872870155, 0.026182426408922765, 0.015227529820549535, 0.014548434082826134, 0.08952674368629232, 0.03797807890805416, 0.02278287611261476, 0.12898289132863283, 1.8727697641588748, 12.282957751303911, 19.64691035449505, 22.323617823421955, 31.888705864548683, 30.892287231981754, 35.380129516124725, 37.25480072200298, 41.7528435587883, 45.779198706150055, 49.63272772729397, 49.5187034457922, 49.20571804046631, 42.884426638484, 44.856885597109795, 50.03949590027332, 51.08977094292641, 49.452131018042564, 51.46914638578892, 47.13199071586132, 44.49708290398121, 44.489517509937286, 45.5360459536314, 54.28633041679859, 55.59936136007309, 59.168658033013344, 58.58711823821068, 58.27710047364235, 55.77892832458019, 55.6961003690958, 51.80787540972233, 50.93445427715778, 53.970491364598274, 57.825004532933235, 59.554747715592384, 67.62550324201584, 41.49660810828209, 0.22690595244057477, 0.11277084602625109, 1.63792182225734, 2.280301577411592, 3.0124396411702037, 32.58808113634586, 62.10582822561264, 44.69597563147545, 39.777192771434784, 35.56611053645611, 45.16337335109711, 5.8457806427031755, 2.051878022029996, 6.929623084142804, 52.48442530632019, 44.05242316424847, 26.040156595408916, 31.7023828625679, 24.97343983501196, 31.278452910482883, 32.089582085609436, 29.53434269875288, 39.02981847524643, 32.50674270093441, 36.23113565146923, 42.89038471877575, 30.17039056867361, 44.86429899930954, 49.25541937351227, 64.64005663990974, 12.76504073292017, 0.6751921819522977, 0.052572991844499484, 0.0735287115094252, 0.07923198281787336, 0.019339585487614386, 0.08936094789532945, 0.09971606763429008, 0.06734541166224517, 0.049852311858558096, 0.06900022286572494, 0.04620262254320551, 0.1305213337764144, 0.06412691756850109, 0.37848014559131116, 0.14621576818171889, 7.185302814468741, 77.17040106654167, 63.217382580041885, 35.157001689076424, 38.54187145829201, 38.25286276638508, 40.75351618230343, 36.81139871478081, 39.34228330850601, 33.39871823787689, 32.39877909421921, 31.655797362327576, 35.49834117293358, 36.25672347843647, 39.60307091474533, 32.28401005268097, 15.921616852283478, 4.961849749088287, 6.073502898216248, 25.50042025744915, 61.100124791264534, 67.13193252682686, 62.606458961963654, 48.425844088196754, 47.79171511530876, 24.500937089323997, 6.146980505436659, 1.9553085789084435, 1.9880644837394357, 52.449930757284164, 64.71283793449402, 61.050655245780945, 63.749259039759636, 56.78995907306671, 51.73360839486122, 52.66012407839298, 55.71595050394535, 62.803645581007004, 64.82272043824196, 61.81986317038536, 63.373759388923645, 63.36353413760662, 61.99409142136574, 52.36698120832443, 47.21101887524128, 46.20352193713188, 50.45069083571434, 52.280459851026535, 51.4572986215353, 56.009834334254265, 56.53379961848259, 52.753553465008736, 52.73063689470291, 47.69298121333122, 48.34584318101406, 47.1578673273325, 49.59355182945728, 46.757422015070915, 47.42606833577156, 41.210168078541756, 35.958705469965935, 25.169079937040806, 16.950814425945282, 18.697172217071056, 12.15546129271388, 0.45580664940644056, 0.024956047782325186, 0.021216293280303944, 0.0662137329345569, 0.041154816062771715, 0.07781603184412234, 0.0327827557339333, 0.10203416590229608, 0.06855681189335883, 0.020536285628622863, 0.07079328133841045, 0.06935573386726901, 0.03371039951161947, 0.08970400565885939, 0.4225483105983585, 1.0700662806630135, 0.04000729619292542, 0.01202220420964295, 0.04882393637672067, 0.042240730253979564, 0.04981582045729738, 0.01768554240697995, 0.010858948953682557, 0.019126924926240463, 0.09365033882204443, 0.035871184736606665, 0.03483218541077804, 0.05308143350703176, 1.680738280992955, 18.306796364486217, 28.19295197725296, 33.11120666563511, 41.37129083275795, 39.14240263402462, 42.58483551442623, 43.23696792125702, 47.56036072969437, 48.79483088850975, 51.98429234325886, 51.88513286411762, 50.00772200524807, 45.149891674518585, 46.62119172513485, 52.563423067331314, 53.30382853746414, 52.568062618374825, 54.228417724370956, 51.169304475188255, 48.023445680737495, 46.77116207778454, 48.527469635009766, 56.43723540008068, 56.40980467200279, 62.01490290462971, 58.47208321094513, 61.36398263275623, 57.26780243217945, 59.090906605124474, 54.64307427406311, 55.31832084059715, 56.27555787563324, 61.44431032240391, 61.02988176047802, 70.49573242664337, 35.15550076961517, 0.44326560047920793, 0.08024408671190031, 3.0323949828743935, 1.8533181329257786, 4.327537911012769, 37.88072973489761, 61.81658774614334, 43.237427696585655, 43.38631130754948, 41.52514457702637, 48.31416428089142, 10.015623215585947, 2.187927346676588, 4.596330737695098, 59.43674124777317, 47.04390004277229, 27.060912922024727, 30.857180915772915, 29.19140350073576, 29.187427014112473, 29.844829738140106, 34.44655001163483, 31.166902296245098, 36.56778238713741, 34.817983880639076, 46.7717282474041, 33.61133202910423, 43.303935527801514, 57.8601298481226, 73.43751937150955, 18.798805363476276, 0.7901399920228869, 0.11676990136038512, 0.27096381643787026, 0.07006478175753728, 0.0297405680976226, 0.22405095485737547, 0.3052026510704309, 0.16585372301051393, 0.2583729842444882, 0.24180735752452165, 0.16348095814464614, 0.23124888190068305, 0.2902918355539441, 0.5474389402661473, 0.6328040908556432, 12.79449200257659, 89.00419726967812, 72.92273819446564, 43.653547167778015, 57.230598628520966, 40.525190234184265, 50.85033819079399, 41.90571315586567, 58.058900982141495, 45.09212717413902, 46.23968459665775, 40.62586963176727, 49.222976714372635, 44.77026924490929, 52.8752913326025, 38.83995786309242, 13.218334559351206, 11.153413262218237, 12.115159705281258, 33.25893133878708, 64.47662740945816, 72.75439962744713, 68.6445401608944, 57.10153475403786, 57.00991027057171, 26.352452337741852, 7.014876259490848, 2.3906668927520514, 3.3432213915511966, 61.16017296910286, 65.79036891460419, 67.48681828379631, 65.75010627508163, 61.03258341550827, 53.76122899353504, 54.41820614039898, 58.71988691389561, 64.86765682697296, 66.8345832824707, 63.18193808197975, 65.76811730861664, 67.45483919978142, 65.03622338175774, 56.75353042781353, 49.13883022964001, 49.75476197898388, 53.173240944743156, 57.02236980199814, 55.542383417487144, 60.07002666592598, 59.925976395606995, 56.06933534145355, 57.275645211339, 50.19133575260639, 52.01873369514942, 50.24026572704315, 51.021921783685684, 51.72982759773731, 53.80689114332199, 46.81154631078243, 46.90089091658592, 35.939394906163216, 26.744460202753544, 27.94352576136589, 23.87812200933695, 1.3125976477749646, 0.24108587123919278, 0.12618778506293893, 0.17965810024179518, 0.11168489101692103, 0.16238805663306266, 0.11931837711017579, 0.23224445816595107, 0.18750423390883952, 0.1545906375395134, 0.07980642738402821, 0.3114371665287763, 0.15495718427700922, 0.26205267116893083, 0.5641281197313219, 0.70442104479298, 0.12962588807567954, 0.053955293842591345, 0.1562752533936873, 0.12364350986899808, 0.24220599472755566, 0.11436982546001673, 0.06948742797248997, 0.08491315296851099, 0.23200229537906125, 0.1962602257844992, 0.08244226133683696, 0.21004457987146452, 2.5414211908355355, 21.72017030417919, 31.78050097078085, 38.44721473753452, 45.96740260720253, 44.042551293969154, 48.04002419114113, 47.583444491028786, 49.93733458220959, 51.2596370279789, 53.81704039871693, 54.44982424378395, 53.20116184651852, 44.43073086440563, 47.379406839609146, 54.10193011164665, 54.759279638528824, 54.676983654499054, 57.752922400832176, 54.071277156472206, 49.19393867254257, 49.51967619359493, 52.04081051051617, 58.76063212752342, 61.89630746841431, 66.73638895154, 62.39218086004257, 62.573617324233055, 60.20349070429802, 62.55683742463589, 58.63036371767521, 55.63225619494915, 59.110194370150566, 63.28448697924614, 64.10754561424255, 70.60575932264328, 44.089835956692696, 0.8372956397943199, 0.3597778460243717, 4.774711690843105, 5.61056898906827, 4.6075814589858055, 38.463842645287514, 67.0376367866993, 51.480557173490524, 48.773859813809395, 43.7503507733345, 54.08366069197655, 9.466768316924572, 5.015958370640874, 11.96841822937131, 62.26399093866348, 51.452362686395645, 37.90040887892246, 40.24699956178665, 35.3677573800087, 41.6202686727047, 42.89724335074425, 40.84463529288769, 52.832152247428894, 45.64639203250408, 45.5884413421154, 58.73564086854458, 41.209001541137695, 56.14332117140293, 69.56781461834908, 86.57167419791222, 31.150504276156425, 1.0958778206259012, 0.4651119641494006, 0.24975213746074587, 0.3527796606067568, 0.14221204473869875], [0.028649675950873643, 0.1423705674824305, 0.08511694672051817, 0.1235723750141915, 0.09353111279779114, 0.09788178285816684, 0.047239280393114313, 0.09278663477743976, 0.14506144652841613, 0.3216511075152084, 6.045429054647684, 68.21417525410652, 46.68092451989651, 35.111160948872566, 38.85637678205967, 45.092704743146896, 41.702401265501976, 33.46741855144501, 44.327668994665146, 35.61465673148632, 38.83202388882637, 32.27951869368553, 37.065753266215324, 42.20258742570877, 28.457026407122612, 34.245366007089615, 8.329751528799534, 3.0997021961957216, 1.7757775937207043, 20.034915134310722, 52.525702491402626, 57.33196958899498, 58.52465718984604, 43.258334174752235, 46.935940235853195, 31.74548964947462, 4.083329765126109, 1.0359988524578512, 0.7276663568336517, 38.419141843914986, 60.490652695298195, 56.513626500964165, 60.54511897265911, 55.47542341053486, 52.99348019063473, 52.37920895218849, 56.84614285826683, 60.083458945155144, 60.15131190419197, 60.88223688304424, 61.06347195804119, 61.04923412203789, 58.512064665555954, 52.68808677792549, 44.50982742011547, 45.04861190915108, 45.117639005184174, 47.70730264484882, 46.43934488296509, 51.11687868833542, 51.528844982385635, 50.34366957843304, 48.920588940382004, 47.038747519254684, 46.00085601210594, 43.23461964726448, 46.98248773813248, 40.89030884206295, 42.68840655684471, 31.621969677507877, 24.9429901689291, 13.339813090860844, 8.544987179338932, 7.361182551831007, 1.072102733887732, 0.19004417496034876, 0.016526777144463267, 0.022623865406785626, 0.17054847499821335, 0.06096546865592245, 0.07329135783948004, 0.03890423467964865, 0.013281321753311204, 0.025666897236078512, 0.05685792617441621, 0.008782689710642444, 0.005783072128906497, 0.018452438853273634, 0.009220967804139946, 1.0361298266798258, 1.035955036059022, 0.1632505509769544, 0.09477685962338, 0.054322104042512365, 0.062006876250961795, 0.024192197852244135, 0.051097476098220795, 0.009294472893088823, 0.07054822417558171, 0.04156772105488926, 0.035244311147835106, 0.018602098498377018, 0.026415599932079203, 0.5922536761499941, 10.72541942819953, 23.96592389792204, 28.24694897979498, 35.197195932269096, 36.145739033818245, 34.055459797382355, 39.961783066391945, 41.7549904435873, 46.676961332559586, 49.16554659605026, 48.77994708716869, 50.657631531357765, 49.10435847938061, 48.60692337155342, 51.372373178601265, 51.75435148179531, 51.104510352015495, 51.3868959993124, 48.40802304446697, 43.8222923129797, 42.61907547712326, 43.41807000339031, 52.62130916118622, 56.488981023430824, 56.75331383943558, 55.88710092008114, 59.58861529827118, 54.81187641620636, 57.232338935136795, 51.15850165486336, 52.87485055625439, 50.67555516958237, 59.11369398236275, 53.60378444194794, 64.52868461608887, 15.95203422009945, 0.07110130973160267, 0.20186100649880245, 3.2660330459475517, 1.8292189948260784, 10.204814113676548, 47.812401205301285, 53.63728724420071, 32.462885454297066, 25.842306911945343, 60.441817715764046, 51.055321991443634, 28.148682452738285, 1.3741963799111545, 2.6731475349515676, 38.29166628420353, 33.39767329394817, 25.897985324263573, 29.67538733035326, 27.892405204474926, 28.751970380544662, 36.11692138016224, 28.67488581687212, 32.82381668686867, 34.09003034234047, 38.525121957063675, 39.19029526412487, 31.588489674031734, 35.35981200635433, 49.49762597680092, 66.70459985733032, 8.880285937339067, 0.4819969815434888, 0.15409405168611556, 0.13634927105158567, 0.026150443554797675, 0.15247253322741017, 0.054758401529397815, 0.07972566687385552, 0.08643918670713902, 0.08168639134964906, 0.021808614328620024, 0.09253464595531113, 0.022200774437806103, 0.10667733120499179, 0.20757253048941493, 0.41311953216791153, 8.194349594414234, 79.01539206504822, 54.4917131960392, 37.95107536017895, 46.698202192783356, 39.816836044192314, 41.20357163250446, 35.49788139760494, 41.103731989860535, 35.01876890659332, 38.386015221476555, 34.29809957742691, 38.88905502855778, 35.450832322239876, 26.790363639593124, 28.452932126820087, 16.631707549095154, 6.791026471182704, 2.6644153660163283, 18.88515952974558, 57.7906733751297, 60.190468803048134, 61.755912601947784, 46.93836070597172, 53.74287597835064, 37.3044640570879, 4.055648250505328, 1.110251855570823, 0.5702285142615438, 41.17925673723221, 63.428408056497574, 61.40673413872719, 63.977417796850204, 59.14959445595741, 55.360262989997864, 54.69249442219734, 60.101929754018784, 63.5545688867569, 66.46150410175323, 63.09609308838844, 64.26302567124367, 63.50195690989494, 62.98505924642086, 53.96961361169815, 46.19800463318825, 48.39408539235592, 47.609598487615585, 48.5339292883873, 50.6667510420084, 52.830404341220856, 54.78857986629009, 52.8057436645031, 52.276986837387085, 52.45534926652908, 48.0887907743454, 48.293888568878174, 49.995102882385254, 46.98528438806534, 46.59031458199024, 39.11635123193264, 34.491087421774864, 21.96156945079565, 21.22093979269266, 16.37568298727274, 6.336801219731569, 0.0963154059718363, 0.021147943334653974, 0.038488698774017394, 0.026614289563440252, 0.05671576036547776, 0.09548294634441845, 0.0363569946057396, 0.06774541441700421, 0.06388248380972072, 0.03414651517232414, 0.05321987373463344, 0.04269050514267292, 0.04059917751874309, 0.03369716701854486, 0.24922239244915545, 4.855997879058123, 0.5703575885854661, 0.07534619406214915, 0.034815357212210074, 0.06996854004682973, 0.022635259228991345, 0.08377793419640511, 0.057618193386588246, 0.07231000112369657, 0.010762265665107407, 0.03410810160858091, 0.008200838510674657, 0.06733373025781475, 0.5263624805957079, 11.156072169542313, 27.27296434342861, 32.351030856370926, 40.74415348470211, 42.089965268969536, 40.217110365629196, 46.75872154533863, 46.80344894528389, 48.95826771855354, 52.204482927918434, 52.8563417494297, 52.24282667040825, 51.94504804909229, 50.79916633665562, 56.61701515316963, 54.65872183442116, 54.840257093310356, 51.05423524975777, 49.82652112841606, 45.273803025484085, 45.33851735293865, 45.05754142999649, 56.892469972372055, 59.645714834332466, 58.36974710226059, 58.94478924572468, 61.55474379658699, 56.83580361306667, 61.339948922395706, 53.98302689194679, 59.673540741205215, 54.9550337344408, 61.96132577955723, 58.15636195242405, 64.47792693972588, 14.540002439171076, 0.07014753864496015, 0.12988002912607044, 1.834239475429058, 2.4163352278992534, 17.30710230767727, 57.08538182079792, 56.55702397227287, 37.297130450606346, 29.196208342909813, 61.03879228234291, 56.644689068198204, 36.783588007092476, 1.311066448688507, 5.126035613939166, 42.66162559390068, 29.66459210962057, 26.71470019966364, 28.9950243383646, 31.72614298760891, 28.05905096232891, 35.132280215620995, 30.990593656897545, 29.464726634323597, 35.427053198218346, 34.279890954494476, 44.511237144470215, 32.663989663124084, 35.12647792696953, 59.523790776729584, 78.03520426154137, 10.714044738560915, 0.7175503496546298, 0.045462445268640295, 0.24123887240421027, 0.06500539035187103, 0.15183447918388993, 0.15070233290316537, 0.37534486851654947, 0.18451590207405388, 0.2942244167206809, 0.22777370119001716, 0.22379420144716278, 0.1210892156814225, 0.3677729732589796, 0.45021539786830544, 0.7070437353104353, 12.884547170251608, 94.21966820955276, 67.88957387208939, 47.15627521276474, 55.25135323405266, 54.48954351246357, 54.71725769340992, 43.36085647344589, 60.473743602633476, 44.220571741461754, 51.805857717990875, 41.4345346391201, 52.35276237130165, 54.869025349617004, 39.943775832653046, 46.791798770427704, 11.147443782538176, 6.187014682218432, 7.783550787717104, 28.954623006284237, 63.43984164297581, 64.61838260293007, 67.05773010849953, 51.80175393819809, 55.770431980490685, 39.42259579896927, 6.907494971528649, 2.1373902959749103, 1.2772101466543972, 47.4075823277235, 69.95691373944283, 65.6039509177208, 67.35704004764557, 63.48861962556839, 58.703608587384224, 57.704539597034454, 61.50991380214691, 69.07063409686089, 71.77384704351425, 63.79315808415413, 66.80803030729294, 66.9089224934578, 66.47405102849007, 57.40656718611717, 49.324651658535004, 50.34924387931824, 50.647197291255, 52.08565190434456, 54.529825150966644, 55.801130533218384, 58.146273493766785, 53.44101257622242, 54.58384685218334, 54.347731322050095, 52.14728079736233, 50.25598168373108, 54.81065288186073, 49.351356625556946, 51.792163252830505, 47.38505333662033, 39.79097843170166, 30.63145972788334, 31.416748389601707, 29.34247199445963, 13.688509929925203, 0.7039944583084434, 0.13790240802336484, 0.10631189026753418, 0.23064897424774244, 0.12761582562234253, 0.19222257134970278, 0.12432730989530683, 0.15810549346497282, 0.18634560779901221, 0.2641994075383991, 0.14548455976182595, 0.10858663226827048, 0.1694631137070246, 0.06852602760773152, 1.713972722645849, 2.7218255354091525, 0.2707006805576384, 0.18952808546600863, 0.12342945221462287, 0.18298636539839208, 0.15426247467985377, 0.16228007414611056, 0.11147241413709708, 0.1580873256898485, 0.0801355327712372, 0.12339065273408778, 0.13086416147416458, 0.13730100123211741, 0.6319471774622798, 14.278760757297277, 32.182707488536835, 37.31345817446709, 47.40607760846615, 47.1095909178257, 44.35732260346413, 50.76429940760136, 50.28187349438667, 50.90064749121666, 55.49905054271221, 53.684963285923004, 52.01035134494305, 51.36978931725025, 51.578949093818665, 58.25760751962662, 55.927374958992004, 57.746242359280586, 56.24685801565647, 52.047729939222336, 48.69427688419819, 48.83639305830002, 47.22986966371536, 59.068244621157646, 60.96271276473999, 61.08166538178921, 60.22959150373936, 65.03445267677307, 59.32478405535221, 65.1780317723751, 55.16058750450611, 61.554052233695984, 56.03280410170555, 65.42090713977814, 59.34277608990669, 69.38714191317558, 20.50175618380308, 0.2518565417267382, 0.48349953372962773, 7.15063014999032, 4.733197493478656, 13.94516620784998, 58.36520254611969, 59.53698746860027, 37.04347126185894, 31.521037593483925, 68.37857723236084, 57.812339812517166, 35.04478231072426, 5.083403326570988, 4.970412589609623, 47.38678604364395, 40.797761008143425, 37.234684601426125, 37.96085603535175, 40.261830165982246, 36.42693914473057, 49.30561847984791, 37.12487429380417, 45.31262934207916, 47.47631683945656, 47.981530129909515, 57.179764956235886, 42.08176150918007, 48.57579544186592, 70.75439214706421, 90.30862927436829, 18.212398029863834, 0.8281696576159447, 0.3086930309655145, 0.3751962014939636, 0.17160177550977096, 0.24957313144113868], [0.01621289691684069, 0.007023090502116247, 0.10574439220363274, 0.06861309637315571, 0.020084844618395437, 0.030387270016944967, 0.0690163868421223, 0.09027767096995376, 0.1922068526619114, 0.08869920449797064, 2.5008500553667545, 56.30465671420097, 53.31158772110939, 35.242789685726166, 40.06884232163429, 98.24030846357346, 53.32336708903313, 42.69586555659771, 38.38349975645542, 38.205334916710854, 31.71568974852562, 35.5215959250927, 29.280565716326237, 52.591644152998924, 60.25411158800125, 53.726107478141785, 22.97587562352419, 4.065201412886381, 1.5141890617087483, 7.764834892004728, 43.31848494708538, 54.43267576396465, 60.4060198366642, 65.11709824204445, 64.94311317801476, 37.759839221835136, 7.1853735856711864, 4.678372610360384, 0.3659862675704062, 19.315216653048992, 62.79685914516449, 55.06849944591522, 61.76275223493576, 54.139293506741524, 58.552977070212364, 53.23271155357361, 61.367645636200905, 60.160499811172485, 62.29364454746246, 59.02079276740551, 60.385151356458664, 60.297600254416466, 57.981654927134514, 49.33651842176914, 47.63731800019741, 46.84683881700039, 49.403372034430504, 46.40303023159504, 49.36575785279274, 52.875766307115555, 53.484288454055786, 52.50438943505287, 51.265123933553696, 48.32849331200123, 42.97577753663063, 45.25397568941116, 44.50070410966873, 43.803981095552444, 38.859116435050964, 32.23324857652187, 25.72430234402418, 13.25244152918458, 12.655718699097633, 7.202485017478466, 2.357581830583513, 0.025390506598341744, 0.043058391456725076, 0.011739470992324641, 0.01702003261016216, 0.050547707942314446, 0.04815285305085126, 0.08096029632724822, 0.11463970004115254, 0.01760407685651444, 0.057292739365948364, 0.07329554355237633, 0.06276299856835976, 0.05262109785689972, 0.06791422332753427, 0.20636018773075193, 4.358904752880335, 0.1912922743940726, 0.020375477070047054, 0.04582137014949694, 0.014962752866267692, 0.08566945340135135, 0.045992843370186165, 0.029163921208237298, 0.04067986010340974, 0.05792389143607579, 0.04438269832462538, 0.04502152049099095, 0.0194803412159672, 0.14072568621486425, 5.511310715228319, 23.128228448331356, 24.730572067201138, 28.595870956778526, 33.55603739619255, 33.27878527343273, 37.43530623614788, 43.00339065492153, 44.141611978411674, 49.38677832484245, 52.536395117640495, 54.40619118511677, 50.860168263316154, 51.81803226470947, 51.499293968081474, 51.060759499669075, 50.948631316423416, 48.726875334978104, 48.09486664831638, 43.79498317837715, 43.13261032104492, 46.91859036684036, 54.38037917017937, 56.670132502913475, 54.20940354466438, 57.805728167295456, 58.65062043070793, 54.20382924377918, 57.360015884041786, 54.72642280161381, 55.15244074165821, 52.66923598945141, 57.075205966830254, 58.67690362036228, 52.65521474182606, 9.478182904422283, 0.10508594394195825, 0.17557220620801672, 1.9967584172263741, 6.787001062184572, 26.337395645678043, 54.532276019454, 52.661085426807404, 54.019877314567566, 62.49325543642044, 49.52045135200024, 59.754377603530884, 25.989835895597935, 0.4561586945783347, 6.244887001812458, 24.84353620558977, 28.575291261076927, 29.261080361902714, 27.723540365695953, 32.51134805381298, 28.780191466212273, 33.152100071311, 33.626478016376495, 32.829482182860374, 31.07795286923647, 41.513403207063675, 35.74912391602993, 36.44755303859711, 45.990148186683655, 61.314839869737625, 62.46735602617264, 4.2875944543629885, 0.2548337710322812, 0.17806490213843063, 0.12533012952189893, 0.17054774769349024, 0.021356759571062867, 0.06202855809533503, 0.08576698644901626, 0.04942434126860462, 0.022804548680142034, 0.04883507972408552, 0.08833881016471423, 0.0676229155214969, 0.056568013606010936, 0.1643954325118102, 0.1220785133773461, 3.7314007245004177, 68.6853575706482, 60.13366185128689, 42.385122030973434, 48.228513076901436, 69.1872650384903, 44.31479908525944, 40.84704056382179, 37.44488552212715, 35.85056707262993, 30.104800388216972, 35.818587988615036, 34.73524332046509, 44.87005569040775, 50.94290882349014, 46.02744318544865, 22.45239671319723, 8.684472944587469, 2.119536241516471, 9.517123214900494, 44.13378059864044, 59.14099171757698, 65.43903976678848, 67.20645412802696, 68.19531306624413, 41.55836619436741, 9.367735181003809, 3.788590980693698, 0.18284511985257268, 18.85127294808626, 67.18094989657402, 58.50296415388584, 63.84333819150925, 57.68753930926323, 59.86919604241848, 57.34601363539696, 63.48446264863014, 62.529087513685226, 67.05892324447632, 60.60937352478504, 62.21972331404686, 61.43445365130901, 59.60024647414684, 51.12145744264126, 50.97825072705746, 47.40488067269325, 52.50765725970268, 48.90770003199577, 52.09313750267029, 53.528217896819115, 56.17178164422512, 55.11639207601547, 53.2875008136034, 50.50125852227211, 48.60103368759155, 49.279950857162476, 48.43120940029621, 50.079766139388084, 43.1120952218771, 42.42708697915077, 34.78389970958233, 22.43512474000454, 23.31746969372034, 14.513187278062105, 4.285350199788809, 0.05209963521338068, 0.07585308092529885, 0.05336464448191691, 0.01978718031750759, 0.07598297161166556, 0.009977728368539829, 0.09795739286346361, 0.04936177079798654, 0.06713628186844289, 0.04040191095555201, 0.03835771341982763, 0.04206943514873274, 0.062365400372073054, 0.12269806567928754, 0.19512775295879692, 6.392206996679306, 2.837488716468215, 0.1527700008591637, 0.04241820744937286, 0.0905551303003449, 0.1235262505360879, 0.012898591558041517, 0.0608657759585185, 0.028009575435135048, 0.051578276470536366, 0.028056633163942024, 0.045420157694024965, 0.0541788806731347, 0.09842151717748493, 5.305716097354889, 24.01060190051794, 27.887647859752178, 32.42798812687397, 39.080872535705566, 40.60483016073704, 42.949824929237366, 46.75902932882309, 48.579443246126175, 51.87695950269699, 55.11816658079624, 54.8873707652092, 51.23173512518406, 55.10043293237686, 52.901844307780266, 54.03545267879963, 54.361296594142914, 52.040293738245964, 50.96604198217392, 47.12130568921566, 43.61646495759487, 48.889324218034744, 54.11679111421108, 59.59360063076019, 57.36604616045952, 60.12864992022514, 61.23660586774349, 58.435342982411385, 60.90056709945202, 57.34623022377491, 58.354110941290855, 57.64910437166691, 59.40002001821995, 61.72729633748531, 52.72595554590225, 10.72909478098154, 0.12264506149222143, 0.37091837322805077, 0.7442393456585705, 11.995524074882269, 35.84167554974556, 57.35645927488804, 57.624686881899834, 58.69841806590557, 61.5909406542778, 52.9419207572937, 62.859479784965515, 22.137329019606113, 0.5883466545492411, 14.080926273018122, 27.491522915661335, 27.94721346348524, 28.278825469315052, 27.628743052482605, 30.519550032913685, 27.83280350267887, 32.244997546076775, 34.18931141495705, 30.18731866031885, 33.245723247528076, 35.31238675117493, 40.256202667951584, 36.955262795090675, 46.754883751273155, 73.17725613713264, 68.85222181677818, 3.5400969022884965, 0.17944139312021434, 0.21891826152568683, 0.17003893124638125, 0.06146313433418982, 0.12640912318602204, 0.2744942723074928, 0.226683872169815, 0.15018557547591627, 0.21831909602042288, 0.14556076348526403, 0.20553012524032965, 0.11054421003791504, 0.3535344544798136, 0.41963861673139036, 0.3917749196989462, 6.341540040448308, 85.46388924121857, 70.38502156734467, 48.254245296120644, 55.37466801702976, 119.81398522853851, 65.49963131546974, 54.38164830207825, 51.17724984884262, 48.452017083764076, 44.29530993103981, 46.071448624134064, 39.28115598857403, 71.72456368803978, 66.05251684784889, 72.5406838953495, 27.424359619617462, 9.115744102746248, 3.6444856133311987, 16.8965495377779, 51.32053256034851, 63.742510601878166, 71.0155825316906, 74.36695709824562, 72.52980887889862, 45.9329878538847, 12.329286765307188, 7.565043987706304, 0.48768316861242056, 25.200506150722504, 73.55674177408218, 63.45824405550957, 66.88464179635048, 59.763683304190636, 63.97255405783653, 59.88941855728626, 65.53427785634995, 66.40774458646774, 69.58657041192055, 61.661647260189056, 63.94185930490494, 65.24150356650352, 63.88485476374626, 56.42805889248848, 53.294914215803146, 50.889289900660515, 55.500726252794266, 52.22670793533325, 54.337243884801865, 58.57800252735615, 57.230442836880684, 58.41671258211136, 56.345854103565216, 53.87700878083706, 53.11082549393177, 50.38193352520466, 51.5164690464735, 51.887956112623215, 48.9687779545784, 46.29616096615791, 40.93158222734928, 30.139196142554283, 29.35211967676878, 23.933249451220036, 8.192424047738314, 0.18943694973131642, 0.14879654219839722, 0.11864793574204668, 0.12586193770403042, 0.19063870946411043, 0.08988374640466645, 0.1337268328643404, 0.2838932164013386, 0.14288382197264582, 0.14149559021461755, 0.144141539640259, 0.22079712711274624, 0.24566711916122586, 0.2145237528020516, 0.4015240090666339, 9.527952633798122, 0.7957640464883298, 0.23302764660911635, 0.13309606671100482, 0.10908873227890581, 0.28758183878380805, 0.12655266938963905, 0.1772122783586383, 0.13596900942502543, 0.24046660837484524, 0.15798378124600276, 0.1099914732913021, 0.10880740635911934, 0.20493946474744007, 7.753600794821978, 30.59728816151619, 34.7518028318882, 40.121332705020905, 47.06101432442665, 44.6090666949749, 46.600881814956665, 51.802111119031906, 51.80921293795109, 56.84850253164768, 58.96870896220207, 59.349706918001175, 55.46301327645779, 56.14932484924793, 55.86427554488182, 55.596682503819466, 58.266533240675926, 54.778704196214676, 54.34465728700161, 49.75209832191467, 46.89451865851879, 50.35694606602192, 58.04252006113529, 62.90812477469444, 59.992830008268356, 61.88298538327217, 63.70974875986576, 58.427959978580475, 64.8598824441433, 60.82503095269203, 59.68224607408047, 59.82401266694069, 62.51766912639141, 61.7163073271513, 57.25331000983715, 14.332499373704195, 0.2113146468764171, 1.0961248073726892, 5.423600971698761, 10.41841585189104, 33.97345259785652, 60.83157040178776, 61.38400375843048, 64.10309985280037, 71.24198958277702, 56.698148399591446, 71.98782116174698, 31.430294662714005, 2.8842055471614003, 10.754801351577044, 31.929926052689552, 36.14437870681286, 39.3071161955595, 35.5624171346426, 45.11940211057663, 37.215647622942924, 44.70113955438137, 45.16590781509876, 45.79546943306923, 44.04983930289745, 51.27064883708954, 51.81337371468544, 49.16169360280037, 60.52528403699398, 83.19801762700081, 83.93035233020782, 6.522306790575385, 0.4259037977317348, 0.39592607819940895, 0.2753776655299589, 0.28177192085422575, 0.2927294641267508], [0.07631253713043407, 0.025366843219671864, 0.08348578034201637, 0.09941110431100242, 0.05570515932049602, 0.04137307798373513, 0.04132040776312351, 0.15319813101086766, 0.1522489686612971, 0.13651114830281585, 0.22499242855701596, 49.99451771378517, 56.073401123285294, 28.007681518793106, 65.50277754664421, 122.13316038250923, 43.780760541558266, 47.275319024920464, 36.43201947212219, 39.969922229647636, 35.543950125575066, 39.9459645152092, 31.529670730233192, 33.490654304623604, 75.64997345209122, 73.58122766017914, 48.0683820694685, 7.180792456492782, 2.244549533352256, 7.0054451655596495, 38.25730472803116, 62.33445815742016, 60.5300185829401, 54.97737653553486, 50.88452495634556, 40.71761950850487, 15.685401577502489, 1.6858320264145732, 0.5025482084602118, 9.213107228279114, 47.0752027630806, 57.43398651480675, 61.23181812465191, 60.516008734703064, 56.4443714171648, 58.918984830379486, 61.537838503718376, 59.58951584994793, 61.21831364929676, 60.61206758022308, 62.01969064772129, 59.72276329994202, 57.81214602291584, 49.02222588658333, 49.91887517273426, 47.110624462366104, 50.32763063907623, 47.48814940452576, 49.874432757496834, 49.85044464468956, 54.451389759778976, 53.24408434331417, 53.073321506381035, 47.25825034081936, 45.550808161497116, 43.04299972951412, 47.71575719118118, 44.49088163673878, 40.37402294576168, 38.154391050338745, 24.187596403062344, 16.297293193638325, 16.09055768698454, 8.151287455111742, 1.4087467384524643, 0.09230989395291544, 0.034252048571943305, 0.07475287668057717, 0.17852366814622656, 0.026825356362678576, 0.07310806220630184, 0.1138304102641996, 0.07738965316093527, 0.05036198919697199, 0.04477545400732197, 0.09725964788231067, 0.06879734195536003, 0.007868505708756857, 0.09780945314560086, 0.14681143074994907, 7.0309859700500965, 3.1903439573943615, 0.1706357070361264, 0.05150227683770936, 0.10263209202094004, 0.04655510558222886, 0.0379660301405238, 0.035423024019110017, 0.05108330107759684, 0.07906723345513456, 0.0008785409681877354, 0.04423566031618975, 0.06290736855589785, 0.08078013997874223, 0.8086881623603404, 10.591793898493052, 22.88279201835394, 21.899993754923344, 25.915574580430984, 31.238551251590252, 37.93229676783085, 41.42876274883747, 44.23585072159767, 48.40219795703888, 50.275710225105286, 48.74571852385998, 49.22663971781731, 51.06063410639763, 50.28204068541527, 49.82632353901863, 48.50240238010883, 48.08374464511871, 43.262114971876144, 45.89858070015907, 41.497170478105545, 46.1284189671278, 50.36100424826145, 58.127209916710854, 55.683925822377205, 55.10737136006355, 59.36788894236088, 58.576490208506584, 57.418095767498016, 57.33418487012386, 58.449440225958824, 59.82751987874508, 54.54971328377724, 55.67066453397274, 40.47122173011303, 7.795940022915602, 0.3595674620009959, 0.17392598907463253, 0.933577842079103, 23.96936271339655, 47.84207381308079, 53.5517006367445, 55.810109451413155, 51.868311166763306, 58.32003057003021, 52.9343705624342, 52.57509604096413, 8.596942741423845, 0.37702019268181175, 12.595774065703154, 39.60135720670223, 33.894280046224594, 22.81800739467144, 29.043042361736298, 30.760274715721607, 29.866556972265244, 33.0752719938755, 33.81293021142483, 33.08360114693642, 28.284506164491177, 34.068219512701035, 38.24734166264534, 31.148530282080173, 44.12723354995251, 58.997952193021774, 40.70753864943981, 1.5136076929047704, 0.066423345124349, 0.02271323111926904, 0.05302422505337745, 0.018168333590438124, 0.09492794604739174, 0.04640074257622473, 0.0039094057501642965, 0.154674960358534, 0.023914079865789972, 0.02219345871708356, 0.0446025298879249, 0.06266530224820599, 0.08195339381927624, 0.12746543681714684, 0.2614046278176829, 0.7734809734392911, 60.95253311097622, 68.13324719667435, 27.83165406435728, 66.7019248008728, 128.11631172895432, 36.607117876410484, 41.57245583832264, 37.32685245573521, 37.86198914051056, 34.77492839097977, 41.08721047639847, 32.87037558853626, 36.86243757605553, 56.657501980662346, 65.54226502776146, 45.54941363632679, 11.373535450547934, 3.0132143246009946, 12.030467949807644, 41.425806507468224, 66.5919890999794, 66.98993414640427, 62.134524285793304, 56.51992656290531, 49.37470257282257, 18.96461706608534, 2.984647457487881, 0.619526831433177, 9.223954696208239, 49.50027823448181, 61.79197646677494, 63.740409314632416, 62.45830491185188, 60.592190846800804, 62.26022534072399, 63.30200023949146, 62.346100732684135, 65.43754264712334, 63.11356075108051, 64.35305044054985, 61.80335305631161, 60.899020582437515, 51.96059301495552, 52.363690584897995, 50.681471452116966, 52.10128806531429, 51.15269176661968, 51.484166979789734, 51.42621248960495, 54.450591802597046, 56.36261120438576, 56.510043293237686, 50.845299661159515, 48.624239042401314, 49.40793178975582, 52.13916443288326, 49.101371839642525, 46.24816574156284, 47.90882483124733, 29.52188316732645, 25.311327204108238, 27.255130000412464, 10.687141232192516, 1.1370265251025558, 0.042762371012941, 0.05816759789013304, 0.09230878815287724, 0.0672340375604108, 0.055867485571070574, 0.06505382290924899, 0.09748877113452181, 0.02276052262459416, 0.06522256502648816, 0.019019447099708486, 0.1192732248455286, 0.01919410227856133, 0.04365509303170256, 0.04145312603213824, 0.09183919421047904, 1.268998074810952, 7.810041541233659, 0.6969876342918724, 0.0389961162727559, 0.1182941539445892, 0.032013393501983956, 0.07003323305980302, 0.044101008752477355, 0.06224953627679497, 0.09767478302819654, 0.0563902135763783, 0.1056255520961713, 0.03307813421997707, 0.07816458150045946, 1.1011955165304244, 9.052417650818825, 27.044127322733402, 31.364265605807304, 32.30037197470665, 38.34447585046291, 42.15221352875233, 47.561645060777664, 49.034981802105904, 51.62315592169762, 51.88251480460167, 53.556575775146484, 52.70333915948868, 51.77222192287445, 51.81323692202568, 50.6537139415741, 51.482521668076515, 49.08281743526459, 46.96886166930199, 47.59529985487461, 46.37130193412304, 47.98363521695137, 54.41035956144333, 59.56057660281658, 57.966641932725906, 55.65779462456703, 60.12731999158859, 59.238623678684235, 61.41057953238487, 58.703464195132256, 60.92433862388134, 60.92602953314781, 58.986993581056595, 56.940560191869736, 40.46124346554279, 7.693892698734999, 0.9536259225569665, 0.24175849452149123, 2.4201283743605018, 31.75982628017664, 52.84301206469536, 59.06558856368065, 64.58553716540337, 58.06146964430809, 62.942881509661674, 57.01814062893391, 57.6785945892334, 10.014123246073723, 1.2613798398524523, 19.40293874591589, 40.55927060544491, 40.41035279631615, 22.217687107622623, 26.637091264128685, 29.394981376826763, 29.31259609758854, 34.04882155358791, 33.18747617304325, 29.698264002799988, 33.198909759521484, 32.16178201138973, 39.22371067106724, 36.63560874760151, 47.23974533379078, 70.19713684916496, 49.564756974577904, 1.2264310964383185, 0.048199114826275036, 0.12732423580018803, 0.004659141422962421, 0.05488720868015662, 0.026814246411959175, 0.2552145818481222, 0.16031790990382433, 0.2431326254736632, 0.19205171411158517, 0.13282596948556602, 0.16647991753416136, 0.2108658553333953, 0.5341339542064816, 0.4349223762983456, 0.2943594875978306, 1.7947092466056347, 76.90130710601807, 79.2860895395279, 39.22735467553139, 76.49008557200432, 138.3874949812889, 57.11805246770382, 59.7480471432209, 50.61149060726166, 54.154857471585274, 50.40644221007824, 54.18418049812317, 39.20334756374359, 45.51627181470394, 80.93251839280128, 90.17027109861374, 57.04409323632717, 11.821999736130238, 6.1578787956386805, 14.368615485727787, 48.04644204676151, 73.16252812743187, 70.05874827504158, 62.322663590312004, 63.14486347138882, 49.18207950890064, 20.011856071650982, 3.704841574653983, 0.8787321788258851, 13.784489929676056, 56.7390988022089, 66.08661621809006, 67.3716388642788, 66.7540580034256, 62.74942249059677, 64.79893371462822, 66.15435138344765, 65.31135901808739, 68.97372409701347, 67.48306408524513, 68.72870564460754, 65.30521094799042, 62.96084314584732, 55.58160111308098, 56.36343576014042, 53.408216536045074, 56.40455335378647, 53.52118447422981, 56.00610673427582, 54.8661033064127, 61.74417123198509, 60.104734003543854, 59.525394290685654, 55.4766621440649, 52.48919025063515, 49.913475662469864, 55.10320298373699, 51.73283323645592, 50.53753897547722, 53.539161309599876, 39.10346232354641, 29.092225022614002, 32.45209403336048, 19.53415710479021, 2.9355220310389996, 0.3557039302540943, 0.13159998605260625, 0.2173925840179436, 0.18962094298331067, 0.10742631406174041, 0.1504517244757153, 0.15871540526859462, 0.1599897025153041, 0.21915209741564468, 0.16785634914413095, 0.2041503688087687, 0.17973854904994369, 0.11792761462857015, 0.3823409165488556, 0.4277260968228802, 9.41094171255827, 5.154850417748094, 0.23797452100552619, 0.1153032245929353, 0.4012125445296988, 0.14579376816982403, 0.12666479306062683, 0.2245231982669793, 0.24828577239532024, 0.2555742859840393, 0.2629679470555857, 0.18670486664632335, 0.15524429152719676, 0.48766960215289146, 2.3301765136420727, 19.238743856549263, 33.61083805561066, 36.45530462265015, 39.189603701233864, 43.7923689186573, 46.154914945364, 50.86879000067711, 51.11672289669514, 54.0695558488369, 53.085746839642525, 54.45495776832104, 54.59928162395954, 55.065706595778465, 56.736058965325356, 54.37607780098915, 55.141117349267006, 51.231028363108635, 48.55607070028782, 50.958294197916985, 45.53126960992813, 49.72878277301788, 55.60471527278423, 63.900456726551056, 59.26618739962578, 60.01048766076565, 61.51434436440468, 62.56564915180206, 62.488482892513275, 59.88434962928295, 63.77653017640114, 66.15333303809166, 60.64107522368431, 60.07674850523472, 44.86688286066055, 10.319839641451836, 1.610106008592993, 0.4713921365328133, 1.2181421974673867, 28.28900132328272, 54.92911912500858, 62.62306407094002, 67.16928452253342, 61.76223546266556, 68.38270381093025, 61.751136258244514, 63.38377185165882, 13.410279359668493, 2.262327829375863, 19.243387207388878, 48.44293937087059, 43.98037903010845, 29.629934169352055, 37.04044662415981, 44.843115136027336, 38.45107913017273, 45.89462511241436, 43.25649507343769, 45.179853066802025, 38.828452080488205, 42.836967185139656, 54.14831422269344, 39.945645332336426, 60.92328988015652, 79.430762976408, 65.15060484409332, 1.8421441200189292, 0.2429852943168953, 0.18540052726166323, 0.19755701010581106, 0.1457030331948772, 0.20113978738663718], [0.06736072959029116, 0.09406495446455665, 0.030985535668150987, 0.014218904743756866, 0.08182234538253397, 0.07112497682101093, 0.05529523034056183, 0.03841474375803955, 0.06347952730720863, 0.3462630993453786, 0.5769854423124343, 45.625831335783005, 57.10781201720238, 35.456258431077, 42.1351258456707, 39.21050637960434, 36.698350980877876, 44.50236462056637, 39.7936724871397, 37.63380378484726, 33.016713336110115, 35.11114574968815, 44.03124690055847, 23.2569807395339, 67.6689501106739, 61.96913816034794, 30.028439685702324, 10.401557106524706, 1.10708401305601, 16.973620802164078, 45.45729137957096, 65.74511334300041, 59.97749023139477, 61.75679415464401, 63.82509917020798, 59.820896834135056, 26.418242007493973, 5.760588739067316, 0.49713709100615233, 3.0242795683443546, 36.01783789694309, 58.07338200509548, 63.923909068107605, 61.16301901638508, 61.09231621026993, 62.21283048391342, 62.71587789058685, 64.10670205950737, 63.29891100525856, 59.97725084424019, 61.42374202609062, 58.342430368065834, 56.46959826350212, 47.85118952393532, 49.286931082606316, 50.54158955812454, 51.814768239855766, 49.46493253111839, 50.11501684784889, 49.316387102007866, 51.199634447693825, 52.25262634456158, 49.66612033545971, 46.44093319773674, 46.36760093271732, 45.944220051169395, 46.766169145703316, 47.14777886867523, 41.80014342069626, 34.708770141005516, 18.70831321924925, 25.068742521107197, 21.592109575867653, 5.2227541990578175, 0.2472127604414709, 0.0980865562451072, 0.03913018525054213, 0.16313118394464254, 0.05166434704733547, 0.05433330676169135, 0.014668886506115086, 0.09402221417985857, 0.03735865277121775, 0.04311312484787777, 0.033309175923932344, 0.17046927299816161, 0.05765606518252753, 0.07573478258564137, 0.13310510606970638, 0.2508112712530419, 2.299474161118269, 9.793459586799145, 0.439174763741903, 0.2436193110770546, 0.07701441587414593, 0.07170825294451788, 0.11824877161416225, 0.04668898902309593, 0.06549659563461319, 0.04354111028078478, 0.07594959723064676, 0.05943090764048975, 0.1286917319521308, 0.06286669144174084, 0.5011846160050482, 2.553002731874585, 18.203077130019665, 27.629643604159355, 24.05592206865549, 29.782154001295567, 32.914438024163246, 40.656245201826096, 43.39782848954201, 47.545704916119576, 49.10140983760357, 48.97944398224354, 48.06283816695213, 49.10911962389946, 51.41340337693691, 48.472440987825394, 47.14498221874237, 45.44307254254818, 44.768639132380486, 43.72664764523506, 43.35175596177578, 44.97605860233307, 54.02610518038273, 53.925471380352974, 57.74372309446335, 54.40685994923115, 61.08112581074238, 60.92355586588383, 60.83033166825771, 61.001425087451935, 63.181915283203125, 58.15904460847378, 56.49935066699982, 50.01710370182991, 28.735028989613056, 2.566960332915187, 0.21509614161914214, 1.0319268959574401, 17.1394420042634, 44.56521324813366, 51.860437989234924, 55.85107125341892, 55.87494157254696, 52.55197428166866, 50.42233295738697, 50.3550423681736, 50.09013958275318, 4.659706586971879, 0.82146224565804, 12.04658193513751, 48.06519404053688, 22.88102701306343, 22.22549758851528, 30.392973124980927, 27.518782652914524, 30.78677449375391, 35.339483097195625, 35.5056481808424, 31.337765827775, 26.79233953356743, 35.439546927809715, 37.75615341961384, 24.50001183897257, 37.06255383789539, 62.83561706542969, 33.09975787997246, 0.5477845435962081, 0.11962929245783016, 0.1111862865218427, 0.03005010305059841, 0.019680105106090195, 0.06708177854306996, 0.060373060405254364, 0.04140621116675902, 0.08461572244414128, 0.048202417383436114, 0.061461961740860716, 0.062143438844941556, 0.08244194963481277, 0.04777712965733372, 0.02970805831864709, 0.2991521585499868, 0.3018303617136553, 55.65027862787247, 70.372444242239, 34.75619159638882, 50.48265092074871, 50.60999348759651, 33.15062195062637, 36.654710322618484, 39.82936017215252, 33.40779975056648, 35.90849496424198, 35.76243080198765, 41.96796901524067, 30.317484475672245, 54.882077649235725, 60.905674025416374, 31.891726702451706, 16.546276733279228, 1.1606997298076749, 18.07331409305334, 50.22551491856575, 69.6867710351944, 66.77761673927307, 66.28520876169205, 64.98659804463387, 65.20806536078453, 34.47640500962734, 8.671326600015163, 0.7577309967018664, 2.5546478061005473, 35.99155850708485, 61.261604726314545, 67.05824688076973, 66.1465921998024, 62.905434519052505, 67.09613844752312, 63.320182263851166, 66.83913543820381, 64.88499909639359, 64.90443885326385, 63.21179307997227, 61.01450018584728, 58.37890461087227, 51.27185717225075, 51.896832436323166, 54.574183970689774, 55.12931138277054, 53.165907338261604, 53.58673095703125, 52.479626163840294, 51.33385844528675, 55.131142884492874, 51.35543368756771, 49.797034710645676, 51.10495872795582, 48.29915888607502, 50.10832920670509, 48.04175689816475, 51.56429708003998, 37.22181089222431, 28.50352831184864, 38.63288797438145, 30.43826099485159, 7.683837013319135, 0.20880675176158547, 0.016801913552626502, 0.030079636817390565, 0.06615822028834373, 0.019744460441870615, 0.029337016021599993, 0.07144792238250375, 0.04924098997435067, 0.06966815577470697, 0.03295517148217186, 0.0679650752863381, 0.13792581536108628, 0.05997402244247496, 0.026307875341444742, 0.014767573593417183, 0.18017252732533962, 0.8150943811051548, 8.057058211416006, 1.8216664250940084, 0.5327365198172629, 0.12355305691016838, 0.11794175996328704, 0.08939063380239531, 0.04223478194035124, 0.047425522352568805, 0.050721118168439716, 0.07041385833872482, 0.021516670130949933, 0.07512275566114113, 0.05519374164578039, 0.7147490093484521, 2.7214294066652656, 22.39061202853918, 33.71250160038471, 32.04903446137905, 34.06448431313038, 39.476427510380745, 43.95168296992779, 48.024844005703926, 48.362809270620346, 52.755457162857056, 51.584299206733704, 48.776132091879845, 51.06284558773041, 50.64371667802334, 50.40275640785694, 48.73984023928642, 46.9376615434885, 48.5535704344511, 47.40206502377987, 46.593343019485474, 45.94781845808029, 56.35650873184204, 55.12615755200386, 60.29885418713093, 56.85832880437374, 60.202388763427734, 62.45913326740265, 62.35588140785694, 61.30170777440071, 66.30347058176994, 62.24611669778824, 57.32738323509693, 49.93753597140312, 27.37589132040739, 2.3681944236159325, 0.7746097503695637, 3.6748787574470043, 26.079980358481407, 50.47002799808979, 50.392736345529556, 61.85094930231571, 58.62438663840294, 57.29851998388767, 56.917818412184715, 57.67716966569424, 52.225218415260315, 3.2895487966015935, 1.8675350700505078, 12.685144320130348, 48.912658765912056, 29.63184356689453, 20.755130387842655, 31.28733493387699, 27.45068460702896, 30.912141166627407, 32.59413421154022, 35.41522443294525, 31.509471014142036, 34.58885617554188, 32.145062908530235, 38.769996017217636, 25.800564251840115, 45.75386926531792, 74.08062726259232, 38.743754625320435, 0.5673676240257919, 0.12095769969164394, 0.022773302407586016, 0.04246543030603789, 0.02099492176057538, 0.047621953999623656, 0.156338439846877, 0.19917916681151837, 0.16001785959815606, 0.2248368298751302, 0.23505130520788953, 0.2338445879286155, 0.17905173590406775, 0.29520823736675084, 0.18484091822756454, 0.35519238270353526, 0.7447262539062649, 69.98186320066452, 85.1442351937294, 48.367851600050926, 58.28183501958847, 40.809483379125595, 45.91488942503929, 60.66374480724335, 54.91322457790375, 48.69418948888779, 44.29494895040989, 49.72891956567764, 54.53852668404579, 31.837617605924606, 75.78148439526558, 72.30723962187767, 37.45347686111927, 14.179379940032959, 3.7259446922689676, 23.489338271319866, 56.042926758527756, 73.40636864304543, 71.47462069988251, 72.80389577150345, 73.22256490588188, 68.59148740768433, 34.35114473104477, 9.18816726654768, 1.3711390877142549, 4.692949103191495, 44.72770772874355, 63.39598819613457, 69.32873144745827, 67.24513605237007, 65.5463308095932, 69.30730819702148, 68.4744080901146, 65.20917490124702, 67.39010587334633, 65.47243237495422, 68.1100532412529, 63.569334894418716, 63.13980974256992, 54.39646750688553, 54.4896537065506, 56.06746964156628, 56.88756823539734, 54.576448649168015, 57.653037160634995, 56.33712217211723, 55.29934845864773, 57.63368479907513, 54.81854505836964, 52.69611954689026, 54.60536129772663, 50.087468326091766, 52.84134015440941, 53.732152953743935, 56.403082832694054, 46.84309221804142, 33.10325749218464, 39.460133984684944, 37.88569986820221, 11.246189083904028, 0.6335492664948106, 0.13067383028101176, 0.06253484752960503, 0.22289795422693714, 0.12477665062760934, 0.12668468261836097, 0.16422873130068183, 0.4182754101930186, 0.1135873346356675, 0.22790782211814076, 0.26597539661452174, 0.27663023269269615, 0.17119259980972856, 0.14186246349709108, 0.22943143645534292, 0.2712346409680322, 2.155286385677755, 15.801482498645782, 0.5918957234825939, 0.4203752725152299, 0.22781926905736327, 0.1868151646340266, 0.32638687058351934, 0.1300119681400247, 0.10779579228255898, 0.27434088522568345, 0.14689334901049733, 0.1623765385011211, 0.45326506078708917, 0.20400030654855072, 1.4506530272774398, 14.466733820736408, 31.084809601306915, 39.35868322849274, 37.41495832800865, 41.822668612003326, 42.48067170381546, 48.26540529727936, 50.903611332178116, 52.35701434314251, 55.251512825489044, 54.47512708604336, 51.60188466310501, 55.311864987015724, 55.56084282696247, 53.789100497961044, 52.036771327257156, 51.787025928497314, 52.00480364263058, 49.15870316326618, 49.81838196516037, 49.97838757932186, 61.0914346575737, 58.43586355447769, 62.75588974356651, 56.399005651474, 63.33971321582794, 64.63665962219238, 63.297835662961006, 64.56460028886795, 66.03695288300514, 65.68837478756905, 61.89511053264141, 54.6097956597805, 32.26296678185463, 4.384296415373683, 1.4553056401200593, 3.0480413557961583, 20.780347734689713, 53.942726254463196, 59.53213132917881, 64.41573947668076, 63.30231562256813, 60.354126021265984, 60.8545857667923, 61.65435545146465, 60.03865174949169, 8.32061206921935, 3.1745992647483945, 16.43700409680605, 57.851492911577225, 31.417576745152473, 28.645581789314747, 39.91403482854366, 39.90417055785656, 41.14344745874405, 47.35968589782715, 48.27619291841984, 44.89449977874756, 35.49834497272968, 44.4876404106617, 54.334834814071655, 30.981153063476086, 56.06510616838932, 84.06738817691803, 51.317895501852036, 0.6093355407938361, 0.19471483683446422, 0.26594633411150426, 0.1734201709041372, 0.136753236874938, 0.19630490307463333], [0.11664474557619542, 0.034138128903578036, 0.08643923123599961, 0.028622183090192266, 0.09988090605475008, 0.07796579724526964, 0.07085490186000243, 0.012470376059354749, 0.06380742299370468, 0.6455065123736858, 0.20397493994096294, 32.58703239262104, 67.75681659579277, 35.26585444808006, 30.257628187537193, 31.897631585597992, 23.835001923143864, 43.6176922917366, 40.27853786945343, 42.47152179479599, 31.600907407701015, 35.28241015970707, 43.04968737065792, 25.263449773192406, 24.365877136588097, 17.073640935122967, 30.80171149224043, 14.681305456906557, 0.7740025548264384, 6.442667338997126, 50.72895750403404, 61.78601458668709, 61.39647088944912, 55.96932850778103, 51.159349009394646, 52.82050967216492, 40.50861172378063, 12.297111041843891, 1.0494956094771624, 0.3679984080372378, 16.261920891702175, 53.88351023197174, 63.274835497140884, 64.76422637701035, 61.31569102406502, 61.15529403090477, 61.48575469851494, 59.007041305303574, 60.3499386459589, 63.2450906932354, 59.75949212908745, 58.3146196603775, 55.03332853317261, 49.700212106108665, 51.217744275927544, 53.15354660153389, 54.33644972741604, 54.689598977565765, 49.0114800632, 51.48460395634174, 50.26945196092129, 51.91191382706165, 49.46660444140434, 46.69150695204735, 46.21126212179661, 49.131789207458496, 48.31019729375839, 44.16647024452686, 45.092222169041634, 25.553490109741688, 26.878294721245766, 35.83333119750023, 21.222573705017567, 4.528540950268507, 0.09811806783545762, 0.10669546929420903, 0.05407564422057476, 0.08032058729440905, 0.09566015636664815, 0.05154040838533547, 0.031526440725428984, 0.042115266478504054, 0.03220659680664539, 0.041826066371868365, 0.05942097028309945, 0.05483342152729165, 0.03844628132355865, 0.1318934460869059, 0.029246705926198047, 0.05171113945834804, 0.1705723424674943, 10.246130246669054, 3.2155318558216095, 0.1674028523848392, 0.05134095248649828, 0.04171591310296208, 0.055475141780334525, 0.01691010384092806, 0.04048185139254201, 0.0455998835968785, 0.004047309776069596, 0.01829016826377483, 0.03969187229813542, 0.08889119810191914, 0.29874097905121744, 1.926135050598532, 11.484729833900928, 22.620269805192947, 29.15635798126459, 18.87509386986494, 34.342120215296745, 35.42330659925938, 41.521154791116714, 46.91135935485363, 51.08181796967983, 46.025349497795105, 46.71285040676594, 46.40512391924858, 44.42486397922039, 44.775851145386696, 45.82714453339577, 46.547373086214066, 43.08232381939888, 46.115020886063576, 46.451492831110954, 46.12045079469681, 52.70359754562378, 54.655769392848015, 57.3583971709013, 58.90350066125393, 58.364032208919525, 61.245535388588905, 58.783495500683784, 59.797862470149994, 65.320805311203, 61.812362372875214, 44.25685599446297, 40.566110238432884, 14.752165954560041, 1.5791405201889575, 2.1735142450779676, 15.702835991978645, 25.081610530614853, 33.63604970276356, 38.13526287674904, 40.242903381586075, 44.2217230796814, 46.557457745075226, 44.020941853523254, 58.70511710643768, 32.821225225925446, 0.8484173461329192, 1.0216347919777036, 24.771628864109516, 49.7308574616909, 23.424939326941967, 28.181826174259186, 26.934341713786125, 29.443662464618683, 31.486919224262238, 32.685865089297295, 35.79473666846752, 29.058045856654644, 30.039846673607826, 38.92158508300781, 33.73862899839878, 34.054593443870544, 42.61170767247677, 67.21842348575592, 27.59102627635002, 0.6674150680191815, 0.25580144254490733, 0.13709812774322927, 0.06816583365434781, 0.06888466305099428, 0.0371193286991911, 0.08723734426894225, 0.049072385154431686, 0.0659225438721478, 0.05668255667842459, 0.022950623751967214, 0.01973004051251337, 0.02612960775877582, 0.11247722271946259, 0.07283731931238435, 0.41960165777709335, 0.08530116261681542, 40.17996735870838, 80.1750822365284, 37.45810121297836, 38.037562519311905, 32.84625828266144, 34.449525251984596, 41.257939115166664, 36.34462036192417, 38.87630291283131, 33.66160333156586, 38.897311985492706, 35.80857552587986, 29.15034670382738, 32.730782479047775, 29.169165194034576, 34.21992637217045, 18.4526876360178, 2.705254149623215, 4.803729308769107, 52.24166393280029, 63.28226029872894, 63.88758301734924, 61.888597682118416, 59.823803678154945, 57.19922751188278, 46.09241969883442, 15.579820442944765, 1.6729492926970124, 0.6830062251538038, 13.222573231905699, 52.66660653054714, 65.8013579249382, 69.28122639656067, 65.67016616463661, 65.18724247813225, 64.50522467494011, 60.222850665450096, 61.36538475751877, 65.80345541238785, 64.37268018722534, 60.52048869431019, 57.30615757405758, 51.69335335493088, 54.36104580760002, 56.25740244984627, 53.200979456305504, 54.944170117378235, 51.052114963531494, 53.55531424283981, 53.98323208093643, 52.49830976128578, 50.690020993351936, 50.90461067855358, 47.83113420009613, 52.51550003886223, 49.99964363873005, 49.08630944788456, 49.28441561758518, 27.868418991565704, 39.96219724416733, 40.57777941226959, 29.31984420865774, 5.200643660500646, 0.08629198171547614, 0.014517847394017735, 0.08420367463259026, 0.03953200997784734, 0.027107005116704386, 0.06671939525404014, 0.04541032052657101, 0.03868478161166422, 0.04164524951193016, 0.07715835541603155, 0.03222812280000653, 0.04932749841827899, 0.016240317418123595, 0.06292123929597437, 0.015369951670436421, 0.034300911574973725, 0.3090523788705468, 1.93421496078372, 5.3754504304379225, 0.3886284213513136, 0.02302062126545934, 0.049297033256152645, 0.0344933319138363, 0.047041438665473834, 0.029961357031424996, 0.03585569982533343, 0.06319238294963725, 0.04303169269405771, 0.022568285967281554, 0.03917333742720075, 0.15042300336062908, 2.1792609617114067, 17.345658838748932, 35.02239391207695, 41.49972394108772, 28.51610753685236, 37.58977934718132, 41.746459901332855, 46.45523563027382, 49.42084349691868, 53.431060910224915, 51.22882068157196, 49.1029791533947, 48.81171718239784, 46.08581185340881, 48.11715245246887, 47.20670610666275, 48.04163910448551, 45.561276599764824, 47.06830993294716, 47.22940608859062, 48.265101313591, 54.46820765733719, 55.64775936305523, 58.25125806033611, 57.976510003209114, 59.432835057377815, 64.84923541545868, 62.19776809215546, 62.29986481368542, 64.9379150569439, 64.07333225011826, 43.931563049554825, 38.692259788513184, 14.059886801987886, 2.4213975062593818, 5.871748924255371, 23.199729211628437, 28.89994204044342, 34.78289656341076, 45.26482030749321, 48.773388639092445, 49.04380492866039, 52.4270673841238, 48.12076225876808, 61.008310317993164, 31.24533198773861, 0.35455294826533645, 3.169109271839261, 23.90685986727476, 54.68784347176552, 30.63635766506195, 24.84851583838463, 27.591862231492996, 31.32639303803444, 33.08978721499443, 32.130973264575005, 32.11830474436283, 30.647542364895344, 32.08405718207359, 32.0931500941515, 38.723011538386345, 27.316494807600975, 48.32245163619518, 75.46654209494591, 32.258616015315056, 0.6281998660415411, 0.18036560446489602, 0.09201797758578323, 0.04076139986864291, 0.12778840464306995, 0.07884381731855683, 0.30126288591418415, 0.09432034232304431, 0.18348943762248382, 0.14469910034677014, 0.3305143991019577, 0.14095039368839934, 0.15383468591608107, 0.15658330405130982, 0.14252797700464725, 0.8646954945288599, 0.2682425983948633, 52.07841709256172, 95.06731152534485, 48.51016916334629, 44.894427582621574, 35.60641497373581, 29.4127644225955, 59.41990055143833, 53.314722552895546, 54.479489251971245, 42.538892179727554, 52.00146362185478, 53.581160455942154, 32.5912843644619, 30.833477787673473, 22.17662651091814, 41.703951582312584, 19.520175755023956, 3.82181188557297, 11.06174223124981, 64.57051277160645, 68.6457484960556, 69.51340913772583, 64.84348252415657, 66.17402672767639, 65.82135245203972, 49.09509837627411, 16.391064561903477, 2.078174273483455, 1.353057164233178, 20.646097138524055, 59.896140396595, 68.71776223182678, 71.62370190024376, 65.4616029560566, 67.2167819738388, 67.26988032460213, 61.401406824588776, 65.07345378398895, 68.55715245008469, 67.14254915714264, 63.49146567285061, 60.64253054559231, 54.65715631842613, 55.78400485217571, 58.77974130213261, 59.38920959830284, 58.98521147668362, 54.01421181857586, 57.485511749982834, 55.87588392198086, 55.75215496122837, 53.871784061193466, 52.68405519425869, 51.91428869962692, 54.64793801307678, 56.37103535234928, 53.80444027483463, 57.2715300321579, 38.16102549433708, 39.986770525574684, 50.98922833800316, 36.11745335161686, 8.464685138314962, 0.2570381871191785, 0.16008869017241523, 0.12522262200945988, 0.1035655356827192, 0.13012732757488266, 0.18075538042467088, 0.18612366111483425, 0.2079554193187505, 0.18924528267234564, 0.1299616802134551, 0.12227171668200754, 0.2821353654144332, 0.2044241619296372, 0.18816440395312384, 0.1719142493675463, 0.10893478858633898, 0.47295973054133356, 15.713664460927248, 4.799963710829616, 0.4001110192621127, 0.14580381684936583, 0.17593726865015924, 0.1619698415743187, 0.14093611476710066, 0.23932168231112882, 0.11981595744146034, 0.08017796135391109, 0.15783643524628133, 0.07044772995868698, 0.11962457982008345, 0.22071424406021833, 7.901279395446181, 22.924333289265633, 38.54729376733303, 43.13183516263962, 35.06388008594513, 46.29162400960922, 45.4600690305233, 48.22466388344765, 52.25930258631706, 57.415660098195076, 52.15157076716423, 52.09374167025089, 50.405906438827515, 51.21869042515755, 49.384034872055054, 51.87987394630909, 51.105642691254616, 46.90822072327137, 53.30241121351719, 50.08253239095211, 50.63120014965534, 58.937068060040474, 58.420911356806755, 61.080704033374786, 60.54967872798443, 62.748848721385, 66.30749836564064, 63.88360843062401, 65.54692357778549, 67.13309526443481, 62.28507600724697, 48.564221262931824, 44.27454024553299, 18.65446250885725, 2.80118475202471, 3.6067244270816445, 20.33347461372614, 32.99432873725891, 40.777481496334076, 46.281379759311676, 50.71332134306431, 55.02379484474659, 58.35967004299164, 53.28189991414547, 67.60326683521271, 40.889377892017365, 1.6242074081674218, 2.630938687361777, 29.465845674276352, 61.53172083199024, 32.993439584970474, 34.37228299677372, 35.73137886822224, 39.57644194364548, 43.9010126888752, 42.77851112186909, 48.467588648200035, 41.31221540272236, 39.437323808670044, 52.32817769050598, 50.29475100338459, 45.10828770697117, 63.02806153893471, 87.30069547891617, 43.64465944468975, 0.7285919634159654, 0.2689348143758252, 0.37366696167737246, 0.2322585292859003, 0.26651609572581947, 0.19513404637109488], [0.08778950956184417, 0.05553748218517285, 0.03180175153829623, 0.11427299745264463, 0.09195706952596083, 0.05933102569542825, 0.07089249906130135, 0.05503258427779656, 0.31193556322250515, 0.20913473650580272, 0.3878317406633869, 15.088876336812973, 70.61577558517456, 45.02859838306904, 30.664443857967854, 43.962861970067024, 23.959401547908783, 33.64116042852402, 46.340299397706985, 36.11933425068855, 33.30309256911278, 27.75442510843277, 43.745620027184486, 35.6071787327528, 12.907130308449268, 18.193695433437824, 32.300402373075485, 26.928311437368393, 1.9836802314966917, 2.429442387074232, 33.31167630851269, 71.48546531796455, 62.20746897161007, 65.66428408026695, 64.10370022058487, 60.48463001847267, 34.4818577170372, 32.71933749318123, 11.923825722187757, 2.284553786739707, 3.275240664370358, 26.36177323758602, 59.35186520218849, 67.73080319166183, 66.8842314183712, 66.7997695505619, 60.59900388121605, 54.73063297569752, 60.218442901968956, 62.342559322714806, 61.16326980292797, 58.86391818523407, 50.5087099224329, 47.26314067840576, 54.13552790880203, 55.93691624701023, 56.06305047869682, 52.73413650691509, 48.976183757185936, 50.71984559297562, 51.757767498493195, 50.33545441925526, 49.95316833257675, 49.465620294213295, 48.1411025673151, 50.64044505357742, 42.89310157299042, 47.362581342458725, 27.767963781952858, 21.456008478999138, 43.458959609270096, 25.921095684170723, 20.879383720457554, 4.222297333180904, 0.11727054676157422, 0.04452846354979556, 0.07422410388244316, 0.06957890509511344, 0.08446210529655218, 0.035550599204725586, 0.019681320372910704, 0.06470482054282911, 0.049226777846342884, 0.08062149106990546, 0.03846848267130554, 0.02872820259653963, 0.07990747821168043, 0.07890030959970318, 0.08188058171072043, 0.2768214396201074, 0.28518054576124996, 4.666171940043569, 5.469458810985088, 0.42391362483613193, 0.22831339098047465, 0.22788080794271082, 0.05334120003681164, 0.06457544193835929, 0.09604095976101235, 0.08554824584280141, 0.012336564977886155, 0.09562769482727163, 0.06681933286017738, 0.032196774482144974, 0.5980557866860181, 2.372698844410479, 11.278376206755638, 8.642373103648424, 33.004724979400635, 27.655324526131153, 19.205035865306854, 31.77256129682064, 38.561394810676575, 44.35511492192745, 52.13823348283768, 48.75844024121761, 49.25886578857899, 48.145916908979416, 43.35229933261871, 45.40425002574921, 45.21392963826656, 44.995122179389, 43.157130405306816, 47.47834973037243, 45.193205550312996, 48.77250328660011, 51.52843080461025, 56.63272351026535, 59.549397602677345, 55.141622722148895, 53.03104117512703, 65.54069951176643, 59.165150821208954, 52.54339434206486, 50.29583774507046, 50.84995821118355, 34.284712895751, 23.640826642513275, 8.362078294157982, 4.680213611572981, 24.988160245120525, 45.38156144320965, 42.231112495064735, 55.171147137880325, 35.66615156829357, 47.75673799216747, 58.44865366816521, 54.589208364486694, 54.19156350195408, 59.57682453095913, 13.077089488506317, 0.1777976844459772, 3.321422436274588, 28.733089193701744, 36.6310565918684, 14.83129195868969, 29.991929344832897, 27.11359329521656, 30.297451950609684, 28.837182708084583, 32.767465710639954, 40.97615383565426, 29.061467573046684, 40.84009453654289, 42.09182716906071, 32.25686050951481, 40.34067213535309, 46.2131392210722, 69.73334893584251, 16.439152881503105, 0.5466140282806009, 0.293242881889455, 0.13001159706618637, 0.14461063634371385, 0.025037249870365486, 0.03368187135492917, 0.061977669029147364, 0.0016740047658458934, 0.03891899228619877, 0.06811567931436002, 0.08557028762879781, 0.030393784218176734, 0.03975799394538626, 0.1399952347856015, 0.1439810576266609, 0.3917323501082137, 0.3331605711719021, 21.656504720449448, 86.16930618882179, 42.592590898275375, 27.594736777246, 41.67487934231758, 28.520684391260147, 36.871568486094475, 35.62053121626377, 34.88473489880562, 34.01463858783245, 34.246129766106606, 44.44237343966961, 31.642091497778893, 22.412181571125984, 21.60330567508936, 34.160866141319275, 32.34693847596645, 5.700079835951328, 2.4608232406899333, 37.02955640852451, 82.86882609128952, 70.14894783496857, 67.42599874734879, 66.3900451362133, 61.82334378361702, 41.262476071715355, 43.102257549762726, 20.241424553096294, 4.190830271691084, 3.441503830254078, 21.76985453814268, 56.93605363368988, 66.20397672057152, 68.81640493869781, 66.84665143489838, 60.98866157233715, 55.990155190229416, 63.67159500718117, 64.92333143949509, 64.10139754414558, 62.01176807284355, 52.47723609209061, 51.19286321103573, 56.27102471888065, 55.717162638902664, 55.87314426898956, 55.82828767597675, 52.57329113781452, 50.45891359448433, 53.24312299489975, 50.985177755355835, 55.86606524884701, 51.256103217601776, 51.72760471701622, 51.74575254321098, 47.3077616840601, 51.8232835829258, 25.495792105793953, 37.83064462244511, 54.26885135471821, 30.58854103088379, 27.957936488091946, 7.187111517414451, 0.051311144125065766, 0.11358585034031421, 0.0843646316207014, 0.06856582156615332, 0.015567306363664102, 0.0741731702873949, 0.061036521874484606, 0.05337687507562805, 0.01480484888816136, 0.09055572401848622, 0.057465782228973694, 0.05966598662780598, 0.01485822414906579, 0.053238805921864696, 0.0897293203161098, 0.0533583176729735, 0.09584999032085761, 1.019121939316392, 5.353575954213738, 0.2597250882536173, 0.08823084994219244, 0.06962073995964602, 0.07803301356034353, 0.01850613138230983, 0.19662049395265058, 0.011888926546816947, 0.023271932877833024, 0.07294015129446052, 0.023595961974933743, 0.07210887910332531, 0.30265180044807494, 1.794088336173445, 15.020214021205902, 14.732705298811197, 43.5918802767992, 39.3150881677866, 25.255867280066013, 31.180123686790466, 44.09677818417549, 47.08067826926708, 51.33150637149811, 51.39938212931156, 49.50768403708935, 51.99671767652035, 46.402623653411865, 48.04769217967987, 47.44371838867664, 48.28152783215046, 44.59736332297325, 49.516153782606125, 44.67126935720444, 50.950869396328926, 52.99576386809349, 58.97839844226837, 58.85759152472019, 58.22738394141197, 51.6979169100523, 65.77878713607788, 57.40977801382542, 53.891136422753334, 48.93465958535671, 47.57563591003418, 30.961698107421398, 20.330683663487434, 10.351065415889025, 8.55428148061037, 33.527143746614456, 53.91165912151337, 46.89047187566757, 55.93450337648392, 36.61865405738354, 48.55713464319706, 63.31853695213795, 58.915485218167305, 58.38155306875706, 57.83913217484951, 10.300015155225992, 0.14662908506579697, 8.684823475778103, 30.236628614366055, 43.96487206220627, 21.04696612805128, 28.64044066518545, 25.500414557754993, 33.00009302794933, 30.36846823990345, 32.20356836915016, 33.3237786591053, 33.79559174180031, 34.39746804535389, 36.06429420411587, 43.672025576233864, 39.90498371422291, 49.5512031018734, 76.74504429101944, 21.345685198903084, 0.43978501693345606, 0.34963904006872326, 0.21168474107980728, 0.1927541717304848, 0.030246354726841673, 0.019536080217221752, 0.2229178586276248, 0.193389272026252, 0.13752530794590712, 0.22071868210332468, 0.16636887739878148, 0.20541004574624822, 0.24277440563309938, 0.28199691034387797, 0.4392708867089823, 0.7341233384795487, 0.4103299474809319, 27.295366041362286, 98.3980379998684, 58.329123482108116, 43.118429481983185, 55.18131539225578, 30.99729649722576, 42.75131218135357, 59.63140860199928, 47.349187061190605, 45.244878977537155, 38.12277674674988, 65.11832937598228, 45.53129620850086, 18.25047768652439, 23.355889432132244, 43.13837081193924, 35.79203121364117, 6.043253196403384, 4.511373471468687, 42.593928426504135, 79.9556440114975, 74.04294848442078, 74.2831563949585, 70.04430145025253, 68.59389647841454, 50.65612681210041, 44.922314286231995, 18.571767546236515, 4.62772655300796, 4.93566962890327, 31.127675101161003, 64.03582066297531, 72.25208178162575, 73.0114634335041, 71.28517046570778, 62.33372859656811, 57.248864248394966, 64.1051897406578, 66.65787756443024, 68.73231545090675, 67.55101203918457, 57.76133134961128, 54.5530229061842, 59.95211899280548, 59.43295665085316, 58.50682094693184, 61.0358664393425, 53.10226835310459, 55.590405240654945, 54.10049758851528, 54.355114325881004, 55.33813297748566, 55.741705521941185, 53.566728830337524, 59.117250591516495, 52.38261356949806, 57.408961057662964, 40.30644737184048, 31.556974165141582, 55.44968359172344, 40.299474745988846, 33.42301033437252, 9.301765970885754, 0.14104699162999168, 0.20015733229229227, 0.13435336877591908, 0.17923992971191183, 0.19459594477666542, 0.16563881188631058, 0.18004722311161458, 0.11833875701995566, 0.1997705694520846, 0.24881906487280503, 0.2605210564797744, 0.20142328779911622, 0.23840959765948355, 0.29641152592375875, 0.19702907593455166, 0.4780459654284641, 0.590433751931414, 5.566400634124875, 11.769983377307653, 0.6478220131248236, 0.43800371407996863, 0.22723083500750363, 0.1357412591460161, 0.16635427193250507, 0.32117334252689034, 0.117867715889588, 0.11773828533478081, 0.17769160185707733, 0.13477437430992723, 0.2034939985605888, 1.083084144629538, 8.237125799059868, 20.255911275744438, 17.599266730248928, 45.416504368186, 38.88127684593201, 32.10296116769314, 41.66295178234577, 48.88219200074673, 49.535893723368645, 55.478318855166435, 54.9246771633625, 55.328261107206345, 54.74803984165192, 47.55062185227871, 50.1112474501133, 50.95092259347439, 50.26283271610737, 49.058392345905304, 52.743913382291794, 47.98921711742878, 53.63729864358902, 55.63433088362217, 61.907813251018524, 63.064581379294395, 59.57335151731968, 54.5126348733902, 69.1008272767067, 61.6805512458086, 59.033746272325516, 54.70588870346546, 53.10933977365494, 34.46703851222992, 27.35695693641901, 12.646868024021387, 7.447653561830521, 29.12790320813656, 54.35770198702812, 51.4190498739481, 62.16392710804939, 42.03484922647476, 53.306180611252785, 67.40119367837906, 64.74024206399918, 61.18971258401871, 68.70133191347122, 16.965316347777843, 0.35803219594527036, 6.0045394487679005, 36.03351205587387, 47.454756796360016, 20.338142663240433, 38.09103325009346, 36.313503831624985, 39.48322154581547, 38.80859434604645, 45.1279516518116, 54.33696649968624, 43.46632741391659, 50.78190006315708, 59.33399096131325, 45.72333410382271, 52.64352656900883, 62.72754326462746, 89.48813170194626, 28.312286473810673, 0.8673289907164872, 0.4402983753243461, 0.3897631651489064, 0.2543523843633011, 0.19881808228092268, 0.13475265906890854], [0.1521801418857649, 0.04071677081810776, 0.03105200798017904, 0.021891365649935324, 0.027828229794977233, 0.03180262356181629, 0.07012191228568554, 0.03731570097443182, 0.09765343143953942, 0.26907971128821373, 0.20486171735683456, 6.158449240028858, 77.61433884501457, 46.790351048111916, 36.00762024521828, 34.52971614897251, 51.521572172641754, 45.113155245780945, 53.8763590157032, 38.348678424954414, 37.72609703242779, 36.80928982794285, 31.662338711321354, 42.87508673965931, 23.55815637856722, 37.52300173044205, 32.6545699685812, 28.74347783625126, 5.921863010153174, 0.5305461154785007, 25.0905704498291, 47.4893007427454, 62.477102503180504, 55.6150659173727, 52.3263043910265, 53.07647913694382, 31.53656166046858, 41.37911841273308, 40.6541933119297, 12.37645173445344, 0.9643854014575481, 3.870331719517708, 28.525477834045887, 56.714149340987206, 54.13819156587124, 58.28930541872978, 53.09276506304741, 55.76664738357067, 61.53245039284229, 60.663501620292664, 60.333614721894264, 58.007972314953804, 49.0231454372406, 49.29113745689392, 55.11862255632877, 57.73248329758644, 56.516738533973694, 54.68666173517704, 49.870849549770355, 49.39970903098583, 50.97376696765423, 52.97130838036537, 52.56413742899895, 50.866000950336456, 51.218344643712044, 43.12183789908886, 47.02268958091736, 32.35259637236595, 22.819831296801567, 45.72861962020397, 19.2676318064332, 13.863983564078808, 26.239349506795406, 4.162032566964626, 0.28302140068262815, 0.049021384766092524, 0.12601744732819498, 0.02333350701519521, 0.13685645477380604, 0.06553351748152636, 0.028194732003612444, 0.01666805794229731, 0.03393288054212462, 0.05050353902333882, 0.06402513201464899, 0.12005101045360789, 0.1348753657657653, 0.011881162754434627, 0.05624493816867471, 0.03272578105679713, 0.16230315493885428, 0.22834542207419872, 4.847568981349468, 0.29971779382321984, 0.04800459049874917, 0.06212763852090575, 0.018479278623999562, 0.10154092713491991, 0.06902386026922613, 0.05952406572760083, 0.028742835893353913, 0.04257811429852154, 0.04422681020514574, 0.061593199425260536, 0.22868615691550076, 2.6240444323047996, 12.956084031611681, 6.620560493320227, 3.643810674548149, 26.50161523371935, 22.058164067566395, 17.90128782391548, 34.92061637341976, 42.90471754968166, 48.96971270442009, 48.88913042843342, 49.971711337566376, 49.445055797696114, 48.59169378876686, 46.449452340602875, 47.2770631313324, 47.070570811629295, 43.9346294850111, 48.22363033890724, 47.02353693544865, 46.47985830903053, 52.5319417566061, 56.532336696982384, 56.58866487443447, 57.71774388849735, 51.96938194334507, 61.03939265012741, 48.115054965019226, 39.793588891625404, 34.79913309216499, 28.441732227802277, 17.042623199522495, 7.911655688658357, 16.086129024624825, 24.20175064355135, 42.62827478349209, 48.06653156876564, 54.131473526358604, 49.56066459417343, 44.61261570453644, 55.93410059809685, 50.686897560954094, 48.02313409745693, 46.77828289568424, 43.16527336835861, 1.264319575857371, 0.33295912260655314, 5.194706004112959, 43.253265246748924, 22.409248128533363, 22.870870158076286, 30.05799449980259, 29.50133576989174, 31.510088481009007, 32.28438623249531, 31.429798789322376, 36.02925628423691, 27.457976415753365, 42.66875021159649, 37.45582893490791, 23.310440070927143, 30.20261663943529, 46.944892555475235, 68.34937959909439, 10.048725139349699, 0.23071535193594173, 0.21147492108866572, 0.08441782134468667, 0.10467397776665166, 0.023350155242951587, 0.021689614659408107, 0.16757060744566843, 0.08705265339813195, 0.05383204166719224, 0.014693767006974667, 0.021340690218494274, 0.03475104269455187, 0.04502491210587323, 0.10961275533190928, 0.04904528563201893, 0.50868576974608, 0.36664576968178153, 8.72311782091856, 88.99785920977592, 52.67434671521187, 31.544018760323524, 37.54246808588505, 41.33794002234936, 52.519991397857666, 38.51735517382622, 36.531125754117966, 38.27340446412563, 36.88349224627018, 39.53466698527336, 36.35630093514919, 28.302291110157967, 37.26185694336891, 27.90756069123745, 29.39000364392996, 8.804477155208588, 0.8259584731422365, 26.774995364248753, 55.416070595383644, 66.6653935611248, 61.73146091401577, 57.27104365825653, 60.32567694783211, 43.028613701462746, 45.943087711930275, 46.37640506029129, 17.61738035827875, 1.8900125264190137, 4.351546922698617, 24.66067671775818, 55.67391715943813, 53.17455567419529, 56.40169970691204, 53.461022302508354, 57.74116963148117, 63.68646740913391, 64.03099492192268, 62.88758307695389, 61.479439437389374, 52.34127178788185, 52.406670078635216, 55.70597603917122, 59.29611459374428, 57.5813540071249, 56.875568479299545, 50.59736296534538, 49.49496991932392, 51.95459693670273, 56.94802299141884, 53.59876871109009, 55.214107632637024, 54.669756442308426, 48.47213700413704, 52.33657903969288, 28.777852691709995, 37.794208377599716, 57.93092764914036, 21.512087769806385, 23.2246520742774, 32.669571563601494, 3.4933855338022113, 0.43849344248883426, 0.07585976025438868, 0.05648873368045315, 0.07824550528312102, 0.027764694532379508, 0.06685927524813451, 0.07333801666391082, 0.1182321178202983, 0.014746499382454203, 0.07470485972589813, 0.04599252795742359, 0.033932769219973125, 0.04826658718229737, 0.025062115528271534, 0.07911208886071108, 0.028714214968204033, 0.04279247994418256, 0.07160001070587896, 3.7616988737136126, 0.31385953654535115, 0.06156288269266952, 0.08105556582449935, 0.11053773108869791, 0.06780822979635559, 0.04696364303526934, 0.10505049154744484, 0.044102099709562026, 0.07902764729806222, 0.029577970963146072, 0.08186720820958726, 0.5426973290741444, 3.944513238966465, 23.582636564970016, 15.661517959088087, 12.412562146782875, 35.15846461057663, 35.63868664205074, 21.275436468422413, 37.12612062692642, 48.15903760492802, 51.410910710692406, 50.704957991838455, 52.2897769510746, 52.11464434862137, 52.21420280635357, 48.9319883286953, 48.91412928700447, 48.12186799943447, 46.56836315989494, 49.07198041677475, 47.2578551620245, 48.28510344028473, 54.67214651405811, 57.4523851275444, 59.509659335017204, 60.44818997383118, 52.77773156762123, 59.71135251224041, 47.620891481637955, 37.115070819854736, 33.49977381527424, 25.986780859529972, 14.09311031922698, 8.352815341204405, 23.50084215402603, 33.2972826808691, 45.09145461022854, 49.39655140042305, 55.3683527559042, 52.99949526786804, 44.60148610174656, 55.38875386118889, 56.209251433610916, 51.33415102958679, 52.01290860772133, 42.19509422779083, 0.6267381913494319, 1.8426551925949752, 11.844633221626282, 43.30620400607586, 31.91231019794941, 25.804305151104927, 30.03066446632147, 27.99765955656767, 32.4389885365963, 31.827289760112762, 31.837007738649845, 30.384258292615414, 29.136846028268337, 39.22660991549492, 40.33996157348156, 31.225958727300167, 32.0625389367342, 57.10241250693798, 74.631058126688, 14.01551753282547, 0.48717010708060116, 0.17241300229215994, 0.15073161805048585, 0.03594273148337379, 0.028927780949743465, 0.19520881032804027, 0.3349974163575098, 0.15065462765051052, 0.21119617042131722, 0.12314509091083892, 0.16167565423529595, 0.2577472053235397, 0.15680067910579965, 0.1775822092895396, 0.19159976101946086, 0.9115912718698382, 0.5558394582476467, 11.56469939276576, 104.128328114748, 64.41558748483658, 50.28596967458725, 49.07047189772129, 63.223298862576485, 56.32490962743759, 69.00932058691978, 52.27906912565231, 48.04982006549835, 49.95773188769817, 46.81945748627186, 56.1023023724556, 30.20281422883272, 51.78222298622131, 41.1277125030756, 35.894135534763336, 10.847399532794952, 1.847558117005974, 31.92569687962532, 56.728539168834686, 70.6512200832367, 67.53276541829109, 67.3704381287098, 60.841016694903374, 46.49118930101395, 52.89285399019718, 52.71677523851395, 15.606091283261776, 1.3260699436068535, 6.194664146751165, 34.96583014726639, 63.46132189035416, 57.16397300362587, 62.363765984773636, 56.335381865501404, 59.63015466928482, 64.08104583621025, 66.9265079498291, 68.8760769367218, 64.30983155965805, 54.67787280678749, 52.363390401005745, 61.770500019192696, 63.60767483711243, 63.2805085927248, 58.97502042353153, 55.421473905444145, 54.06944565474987, 54.59833547472954, 58.6170644313097, 56.111475080251694, 59.67556603252888, 56.97387680411339, 54.253876358270645, 55.24928614497185, 43.67133781313896, 33.01595337688923, 57.56390914320946, 29.25765484571457, 23.211854360997677, 36.68489210307598, 9.630629774183035, 0.4367629619082436, 0.20303431228967384, 0.14954357320675626, 0.2452612534398213, 0.2556924062082544, 0.18326590274227783, 0.17568274168297648, 0.19697853567777202, 0.10318329252186231, 0.2859419892774895, 0.12243749763001688, 0.30833273311145604, 0.17935368610778823, 0.14504154212772846, 0.2632798865670338, 0.18673826329177245, 0.4578190273605287, 0.4508358926977962, 12.965696565806866, 0.4141322965733707, 0.16789361980045214, 0.1419762644218281, 0.1498070207890123, 0.10434545125463046, 0.1839598553488031, 0.20342497882666066, 0.22297859599348158, 0.14426004578126594, 0.23380359169095755, 0.16379699431126937, 1.2694231770001352, 5.973760625347495, 25.7957062125206, 12.904864680022001, 11.334805078804493, 38.803928196430206, 34.81404349207878, 29.199460968375206, 46.10750108957291, 48.254435285925865, 55.23828573524952, 53.80657576024532, 55.58623306453228, 54.942198023200035, 53.20305414497852, 51.36750943958759, 53.54399465024471, 51.77696406841278, 50.07050983607769, 52.456010431051254, 50.4686638712883, 50.28831794857979, 55.644480139017105, 58.30143816769123, 60.87467148900032, 63.20803888142109, 54.58006985485554, 66.84051096439362, 54.363021701574326, 40.9501176327467, 39.2428844422102, 31.919875591993332, 21.493273079395294, 11.202993001788855, 24.430722557008266, 30.974594615399837, 49.7308574616909, 58.480001986026764, 62.38015830516815, 59.01235342025757, 48.193980529904366, 63.93487527966499, 58.63868527114391, 58.25573042035103, 54.42976512014866, 53.443718031048775, 2.6994585106149316, 1.932839434593916, 7.857287731021643, 54.04171094298363, 33.30724574625492, 30.117751993238926, 41.44969962537289, 39.96160067617893, 41.05855241417885, 42.11163550615311, 42.79483504593372, 49.093320071697235, 38.366172686219215, 54.033750370144844, 51.46253474056721, 30.6782466173172, 44.34201702475548, 65.50286874175072, 85.38096249103546, 18.44450667500496, 0.8534661470912397, 0.39136946958024055, 0.2631531871156767, 0.21240475791273639, 0.33265626698266715, 0.22053293738281354], [0.051778849301626906, 0.06574888131581247, 0.038795391301391646, 0.04715452712844126, 0.04687014356022701, 0.07210879746708088, 0.0582123345520813, 0.030165885509632062, 0.026819170561793726, 0.06895714861457236, 0.1029125347849913, 0.3418512095231563, 52.4850332736969, 58.97383488714695, 44.64984230697155, 40.69050416350365, 45.73724515736103, 38.18739227950573, 45.514637902379036, 35.737207755446434, 40.721176117658615, 43.39058607816696, 33.196029514074326, 39.17501628398895, 34.86135095357895, 27.01007355004549, 45.93549571931362, 28.382527604699135, 17.990740723907948, 0.22358785470714793, 12.834454458206892, 41.73996224999428, 53.00587132573128, 70.96199780702591, 72.40267530083656, 66.44917756319046, 40.23121140897274, 33.07544678449631, 50.75057454407215, 42.386459559202194, 10.444104373455048, 5.7020647544413805, 10.132184810936451, 32.127671241760254, 38.290032371878624, 34.708477556705475, 40.46522565186024, 53.072721138596535, 64.00907769799232, 62.689989879727364, 59.24720361828804, 58.098912835121155, 50.82811318337917, 47.91647382080555, 53.960570096969604, 56.54136501252651, 56.73543579876423, 53.762707114219666, 50.35901315510273, 52.61814013123512, 49.978991746902466, 56.792071759700775, 52.117566391825676, 53.29211376607418, 45.68951591849327, 45.788356214761734, 37.40484707057476, 17.30319231748581, 23.426839224994183, 7.905249707400799, 2.880130265839398, 27.548067681491375, 24.601246006786823, 3.0090913083404303, 0.28106480254791677, 0.04991897527361289, 0.07094418222550303, 0.10631149692926556, 0.05761948101280723, 0.07516905083321035, 0.06236356726731174, 0.03530673318891786, 0.02420710945443716, 0.03516639306326397, 0.0889289437327534, 0.06462244215072133, 0.0539967576332856, 0.05438517917355057, 0.05636219750158489, 0.04804622869414743, 0.04034189347294159, 0.057751312415348366, 3.0177040211856365, 0.11705005468684249, 0.06886942675919272, 0.02920233106124215, 0.06577565058250912, 0.02297543003805913, 0.07216546044219285, 0.016403005465690512, 0.037318253962439485, 0.006030579770595068, 0.07985865231603384, 0.041210714625776745, 0.253759230254218, 4.636872662231326, 20.26017464697361, 30.043380483984947, 5.441356468945742, 0.9968989505432546, 14.523811507970095, 14.12560997530818, 20.06381068378687, 39.98057685792446, 47.40353934466839, 50.22405579686165, 50.472072288393974, 50.45347988605499, 50.81833630800247, 51.273878663778305, 47.19698242843151, 48.21045644581318, 47.3642760515213, 47.027918100357056, 49.33302640914917, 48.193174973130226, 53.08643080294132, 58.52031782269478, 58.5626133531332, 55.500555261969566, 51.2881924957037, 51.084838807582855, 28.43565445393324, 23.578175604343414, 19.711408093571663, 13.440266400575638, 4.417426837608218, 9.748673290014267, 37.00829274952412, 36.754508167505264, 43.99243198335171, 43.871640264987946, 50.70686548948288, 44.67054359614849, 61.20297387242317, 61.256262212991714, 58.43058943748474, 52.65779860317707, 60.537549778819084, 19.938616901636124, 0.48261061892844737, 0.6933398894034326, 21.043137833476067, 42.83333458006382, 14.708256460726261, 33.58276516199112, 26.032764092087746, 30.79415749758482, 34.46903720498085, 37.17184737324715, 32.97952473163605, 37.493416517972946, 27.690130658447742, 40.19101336598396, 30.504029765725136, 30.023114271461964, 35.82015350461006, 43.14559422433376, 63.53860214352608, 4.591916799545288, 0.04675718126236461, 0.10035058905486949, 0.014135018864180893, 0.08471052438835613, 0.044060773216187954, 0.05437550527858548, 0.025861813046503812, 0.03484537708573043, 0.04939206897688564, 0.06909268704475835, 0.08232839361880906, 0.05636634610709734, 0.07337922070291825, 0.02761110335995909, 0.07611065811943263, 0.08478038274915889, 0.1702566328458488, 0.9499042003881186, 61.18034988641739, 69.77507829666138, 39.990596920251846, 45.43890416622162, 37.180438712239265, 48.837574794888496, 39.4817890226841, 34.81717072427273, 43.774981051683426, 39.87825594842434, 36.14792011678219, 36.292118579149246, 26.74513466656208, 33.583962097764015, 37.83205434679985, 28.673388697206974, 20.715280026197433, 0.817273089196533, 7.464068681001663, 39.08334240317345, 57.326957657933235, 72.22681313753128, 75.7475446164608, 69.66211795806885, 42.906974628567696, 40.478369146585464, 55.42169809341431, 53.84145028889179, 18.45364138484001, 9.18737405911088, 12.121908143162727, 31.98841631412506, 38.1086491048336, 33.5031708329916, 38.856612369418144, 52.0366345345974, 67.33327612280846, 64.88461151719093, 64.06327039003372, 60.748199075460434, 53.24778914451599, 48.8862007856369, 56.27981744706631, 54.49791446328163, 58.00116688013077, 54.09234322607517, 53.690358996391296, 52.04333737492561, 53.19887816905975, 57.032006084918976, 53.443547040224075, 55.02135157585144, 48.90143796801567, 50.98265089094639, 33.71791251003742, 25.191728621721268, 32.88291111588478, 11.577011682093143, 5.183301866054535, 31.840703040361404, 34.463500902056694, 5.735840667039156, 0.20649092446547002, 0.07284604696906172, 0.14723380183568224, 0.11346686180331744, 0.07971021535922773, 0.04836242071178276, 0.0456790707539767, 0.036129481813986786, 0.03539783552696463, 0.08435065697995014, 0.015233699850796256, 0.04771656669618096, 0.06582492176676169, 0.035001309734070674, 0.06544451171066612, 0.07088008293067105, 0.035621047572931275, 0.19553627556888387, 2.1678589610382915, 0.18419410684145987, 0.07451031313394196, 0.05169130927242804, 0.10509125029784627, 0.01630875271075638, 0.0573310416075401, 0.03710775119543541, 0.06782482421840541, 0.037100663685123436, 0.05010709857742768, 0.019476708403090015, 0.7413440197706223, 12.213793862611055, 27.852119766175747, 26.47559802979231, 11.1897611618042, 5.9324929397553205, 24.28304348140955, 22.986334562301636, 21.614304184913635, 40.233221501111984, 50.93415029346943, 52.32454888522625, 51.500992476940155, 53.71920324862003, 50.21928705275059, 53.12712661921978, 48.7584288418293, 50.20952917635441, 49.89872865378857, 48.26070114970207, 48.81047084927559, 49.31884177029133, 54.482764676213264, 58.821303471922874, 60.560059770941734, 58.621046617627144, 49.597249031066895, 50.76686806976795, 26.484356559813023, 21.471494548022747, 17.92041029781103, 12.326480615884066, 4.688914669677615, 17.555170096457005, 45.16271598637104, 40.6525631994009, 47.5850024074316, 49.770246148109436, 55.51088310778141, 52.35835947096348, 57.888187542557716, 60.61818145215511, 60.68155065178871, 61.02775767445564, 62.83274061977863, 15.53648566827178, 0.1470690153655596, 2.8107478888705373, 19.421166367828846, 40.60218170285225, 21.753564812242985, 33.39539721608162, 24.874103665351868, 31.359859742224216, 34.6952048689127, 33.70651312172413, 29.26194291561842, 32.694775611162186, 30.628807470202446, 27.495501302182674, 35.204920917749405, 27.715908475220203, 31.685133688151836, 52.79820866882801, 71.38274163007736, 5.150172868743539, 0.13790933968266472, 0.07834329066099599, 0.1406090206000954, 0.03251471796829719, 0.06543919793330133, 0.03638807946117595, 0.2409716695547104, 0.1301495177904144, 0.17340149846859276, 0.1771620349609293, 0.24710308585781604, 0.23196021560579538, 0.16517021984327585, 0.10095033343532123, 0.14132327836705372, 0.18829230568371713, 0.22685925650876015, 1.5337424562312663, 77.36060366034508, 80.6258824467659, 56.22653670608997, 54.15002033114433, 57.40291178226471, 49.188273176550865, 55.98771572113037, 49.70791049301624, 54.25465911626816, 61.236959248781204, 42.56402023136616, 54.91183005273342, 40.93992657959461, 38.11035141348839, 59.26336035132408, 34.2918299138546, 23.706023544073105, 0.9497411653865129, 18.086943961679935, 48.433116897940636, 64.93847742676735, 76.16252034902573, 75.44315814971924, 69.13818687200546, 51.221441477537155, 54.6635589748621, 66.51376649737358, 55.98078869283199, 14.82240043580532, 6.96786898188293, 13.157682213932276, 39.19562257826328, 44.13243547081947, 41.38809733092785, 41.99116677045822, 57.60343462228775, 67.59510487318039, 66.77250981330872, 66.36113628745079, 64.75994020700455, 58.78426305949688, 52.620336413383484, 59.82298672199249, 59.27427336573601, 60.10819561779499, 57.55329631268978, 55.32636880874634, 57.328097596764565, 57.00582928955555, 60.59727877378464, 55.316196754574776, 58.32500450313091, 57.42583975195885, 55.95995061099529, 46.22801162302494, 26.31550122052431, 34.50061351060867, 13.717256337404251, 4.434661287814379, 36.32871441543102, 35.90678885579109, 7.605805825442076, 0.2114228074788116, 0.07076862719259225, 0.14620340400142595, 0.30196860898286104, 0.16239365242654458, 0.1328654814278707, 0.1847392291529104, 0.18206991691840813, 0.22770668525481597, 0.20625162636861205, 0.20999754255171865, 0.16227066371357068, 0.16808402520837262, 0.12136355799157172, 0.26467539137229323, 0.25008752883877605, 0.1295670951367356, 0.2915139152901247, 6.2988365069031715, 0.20358437730465084, 0.17978266230784357, 0.12856415676651523, 0.18803059472702444, 0.060143339724163525, 0.22050507715903223, 0.22308233339572325, 0.12934232829138637, 0.06813691215938888, 0.13116759597323835, 0.15529351076111197, 0.606960371369496, 10.120023563504219, 34.26376461982727, 51.975218430161476, 12.384963277727365, 3.9103162614628673, 24.3630063906312, 23.500255085527897, 28.292899914085865, 49.31360565125942, 53.62765856087208, 55.18981173634529, 55.22776409983635, 56.22704967856407, 52.46596969664097, 58.05735066533089, 52.819263339042664, 54.22369837760925, 52.200633734464645, 51.06170944869518, 51.851778253912926, 51.64193831384182, 55.804956927895546, 62.252226769924164, 63.22127357125282, 60.61128482222557, 52.80086852610111, 55.85046708583832, 33.53145271539688, 26.582053117454052, 24.681123420596123, 16.963817328214645, 6.470460472628474, 17.88540657609701, 45.44930800795555, 44.54735420644283, 55.64783915877342, 53.6111294478178, 61.03561945259571, 55.25726951658726, 67.8646320104599, 66.42980620265007, 65.6839670240879, 58.19484628736973, 69.97022062540054, 28.716772869229317, 0.8514148509129882, 2.266814913600683, 25.971589274704456, 57.27520823478699, 20.738128200173378, 40.960947051644325, 34.851030707359314, 41.89212888479233, 43.844885900616646, 48.1427288800478, 42.11898431181908, 53.83693613111973, 34.91403132677078, 52.17436574399471, 42.782641500234604, 39.882933497428894, 50.01594476401806, 61.30673490464687, 83.4527787566185, 7.728647533804178, 0.25391475472133607, 0.21484254975803196, 0.2731128386221826, 0.2983641461469233, 0.29599292494822294, 0.11926055638468824], [0.006609102438233094, 0.011574662257771706, 0.13403859426034614, 0.020888718572678044, 0.06394602649379522, 0.03832982351013925, 0.019228224373364355, 0.05893741283216514, 0.08177328942110762, 0.11131953913718462, 0.5844480637460947, 0.2912151860073209, 33.22248749434948, 70.44968649744987, 38.217923641204834, 30.288465432822704, 51.764071360230446, 35.64209505915642, 31.27247393131256, 39.776782393455505, 36.35649472475052, 46.386930495500565, 42.8833094984293, 33.412355706095695, 48.1902377307415, 28.74960120767355, 34.276467338204384, 34.11246433854103, 30.856031477451324, 1.7593159270472825, 0.6669973873067647, 32.06422604620457, 55.78035704791546, 43.04179139435291, 58.49070981144905, 51.14942014217377, 35.30262127518654, 28.270756602287292, 44.73419018089771, 50.8704999089241, 51.5740929543972, 40.27227580547333, 19.22121349722147, 22.840682677924633, 14.487454108893871, 16.522256322205067, 20.222672559320927, 42.91699469089508, 69.31008204817772, 66.58591702580452, 62.59079620242119, 59.63337689638138, 54.62439067661762, 54.0407457947731, 58.450196385383606, 57.44787096977234, 57.38831676542759, 57.12303400039673, 52.73553483188152, 51.64886154234409, 58.144096210598946, 54.47887748479843, 55.31875781714916, 50.963192135095596, 43.046028167009354, 37.5433686375618, 18.473489619791508, 6.394778983667493, 1.3381673069670796, 5.555645311251283, 15.84774311631918, 25.787481553852558, 19.652174971997738, 6.757890349254012, 0.5092813877854496, 0.10085533111123368, 0.03239378871512599, 0.11325950574246235, 0.2054562370176427, 0.09068684666999616, 0.05507142828719225, 0.05380868627980817, 0.10039055370725691, 0.00839342768813367, 0.08077910839347169, 0.010089160914503736, 0.06786377212847583, 0.04796452936716378, 0.06555562606081367, 0.04968433786416426, 0.08363087763427757, 0.06134655406640377, 1.3513789605349302, 0.029380841697275173, 0.04566790143144317, 0.05767353533883579, 0.01804710933356546, 0.047875475356704555, 0.03203355394362006, 0.031015334752737544, 0.015165117983997334, 0.03323866076243576, 0.025882359404931776, 0.08535004046279937, 1.0069703101180494, 8.312476705759764, 13.958285953849554, 12.149847093969584, 20.005335621535778, 10.170140024274588, 1.4787337579764426, 6.859806580469012, 15.400700904428959, 28.646522238850594, 44.68448504805565, 51.0147325694561, 49.614750891923904, 52.14807875454426, 51.71467021107674, 49.67772491276264, 49.754784777760506, 48.647451996803284, 48.26882131397724, 47.56477229297161, 49.44694049656391, 48.9227320253849, 54.51556831598282, 55.335773304104805, 58.29907849431038, 56.37433737516403, 54.742009565234184, 33.26194457709789, 15.287808012217283, 10.235419571399689, 7.526816613972187, 3.781129843555391, 4.02233543805778, 31.829009167850018, 47.0359280705452, 33.2381996512413, 48.178177177906036, 51.26602828502655, 42.33477093279362, 40.86946316063404, 45.12815684080124, 38.52678246796131, 39.895058646798134, 56.48187920451164, 19.761829487979412, 0.309453108930029, 0.1080094046483282, 18.925956040620804, 41.72316715121269, 26.379185803234577, 17.63351049274206, 37.55774326622486, 30.951381660997868, 30.964230671525, 31.11628331243992, 31.47478837519884, 37.30767108500004, 29.977854900062084, 25.296114720404148, 42.83113069832325, 36.217239797115326, 33.79634790122509, 34.98079754412174, 57.97882407903671, 59.1056764125824, 1.4877623110078275, 0.031144780150498264, 0.010070824300782988, 0.006894307471156935, 0.047804852583794855, 0.062055086164036766, 0.062026120140217245, 0.04116562915442046, 0.004208401278447127, 0.03361576083989348, 0.03895939480571542, 0.005466885213536443, 0.05187409282370936, 0.029130019902368076, 0.06179363124829251, 0.0533217557676835, 0.14727325440617278, 0.5172144121024758, 0.18508667300920933, 40.54029442369938, 81.07244968414307, 39.8977755010128, 34.90934617817402, 43.32380846142769, 32.94302389025688, 42.6824826747179, 30.43928124010563, 35.786327719688416, 44.55947935581207, 41.92337080836296, 35.75512759387493, 34.627777487039566, 33.72295863926411, 33.13319988548756, 31.515144109725952, 42.7593145519495, 4.598278608173132, 0.1100548155955039, 19.831316359341145, 59.29479606449604, 43.74683976173401, 58.46873939037323, 48.73880289494991, 41.69866606593132, 37.30088844895363, 57.267635241150856, 57.634421959519386, 52.484102323651314, 47.31084331870079, 26.169210970401764, 26.678174659609795, 14.547923114150763, 13.669140469282866, 18.01349390298128, 42.964229956269264, 71.30608454346657, 70.69663524627686, 65.93859896063805, 62.87613809108734, 57.258595526218414, 53.99268217384815, 60.84998041391373, 59.146079644560814, 59.988669231534004, 58.20547051727772, 55.37660971283913, 55.45339599251747, 58.44328075647354, 55.83103492856026, 58.033879324793816, 55.530687645077705, 45.893865153193474, 41.92680582404137, 20.862309336662292, 12.314769644290209, 3.2086143270134926, 6.324008731171489, 9.038404002785683, 27.13069997727871, 24.812873750925064, 2.8080880315974355, 0.09316422467236407, 0.05437912324850913, 0.023170306885731407, 0.051104589583701454, 0.027843312091135886, 0.07416377469780855, 0.07747828043648042, 0.03526444561430253, 0.07483086897991598, 0.03476513236819301, 0.10643930960213766, 0.0543436968291644, 0.08685185050126165, 0.05675343549228273, 0.07130042053177021, 0.012012224178761244, 0.15714356617536396, 0.18177008925704286, 0.4042093368479982, 0.13898762088501826, 0.02613817028759513, 0.009237141057383269, 0.07417861022986472, 0.04573417150822934, 0.027145103267685045, 0.027316710074956063, 0.043536987650441006, 0.016860994073795155, 0.11271517010754906, 0.023919959530758206, 0.6523181812372059, 5.306104626506567, 19.948711059987545, 9.66120958328247, 14.501640647649765, 10.020675044506788, 5.854860255494714, 12.43992542847991, 23.019632175564766, 31.593790389597416, 45.08474417030811, 52.9169636964798, 51.21100343763828, 54.47817072272301, 54.95275765657425, 50.4345379024744, 51.98742337524891, 50.109917521476746, 53.656134232878685, 49.60038386285305, 50.28102993965149, 50.90970240533352, 56.85678228735924, 55.88839665055275, 59.65119034051895, 56.995201259851456, 54.62213359773159, 32.57983557879925, 14.185223076492548, 7.732776962220669, 6.448163744062185, 4.372087670490146, 9.271214660257101, 39.39143367111683, 54.94520366191864, 37.31248922646046, 55.761111080646515, 54.09496508538723, 46.9751351326704, 45.713564828038216, 49.838726073503494, 41.76248364150524, 45.32687097787857, 58.09710033237934, 9.972761515527964, 0.05674814397934824, 1.3145065703429282, 32.06730008125305, 36.020558550953865, 34.94876526296139, 23.696512654423714, 35.54086089134216, 26.579957529902458, 32.208990678191185, 30.698564127087593, 32.93053776025772, 28.343716487288475, 35.154619216918945, 27.59687416255474, 29.65340171009302, 41.399268731474876, 26.862706057727337, 36.220454424619675, 66.45056828856468, 67.02208042144775, 1.6124904993921518, 0.08767474384512752, 0.055305690912064165, 0.06419744386221282, 0.01322515601714258, 0.018280670628882945, 0.040956421435112134, 0.08606897376012057, 0.05913998946198262, 0.21322720596799627, 0.1121533865807578, 0.10185047693084925, 0.1809164709993638, 0.12002294984995387, 0.12668532086536288, 0.24019216216402128, 0.20317420712672174, 0.6221849075518548, 0.4713064630050212, 51.594710648059845, 95.65886378288269, 53.42868223786354, 39.00448903441429, 69.81268867850304, 45.907578617334366, 41.28113307058811, 55.03372751176357, 45.11326543986797, 67.22625106573105, 53.87237302958965, 48.276474103331566, 60.106364116072655, 38.176669254899025, 46.996695175766945, 38.85222740471363, 39.15050379931927, 4.019211055710912, 2.513808785006404, 38.09354491531849, 66.08324959874153, 48.02467301487923, 67.31060653924942, 60.008564963936806, 45.3873485326767, 46.29690572619438, 58.24137099087238, 63.1782066822052, 61.11205615103245, 50.84138207137585, 24.232675284147263, 27.5801607593894, 17.48061239719391, 21.386709697544575, 20.944060049951077, 48.00726994872093, 75.18608674407005, 74.54567670822144, 68.15600037574768, 65.89338898658752, 57.788800075650215, 59.647367745637894, 61.32839374244213, 64.86493617296219, 62.27449357509613, 63.48704271018505, 56.947247833013535, 58.69884744286537, 61.60245023667812, 60.95249131321907, 58.83634686470032, 63.59435275197029, 49.99466970562935, 55.88624596595764, 25.957248844206333, 13.510835263878107, 2.930295648984611, 6.7635871935635805, 24.230573996901512, 35.886323153972626, 34.869896695017815, 8.963108193129301, 0.4633212508633733, 0.18894169974373654, 0.2482040025643073, 0.27546277502551675, 0.2476132826996036, 0.2704995882231742, 0.20669443620136008, 0.1420436514308676, 0.1707341306610033, 0.17094921990064904, 0.14003229764057323, 0.09953455315553583, 0.20938384579494596, 0.17636709089856595, 0.2081169848679565, 0.10208109189989045, 0.18074506457196549, 0.24221338651841506, 3.9914312213659286, 0.1737015339313075, 0.08773716588621028, 0.10752098984085023, 0.14328507153550163, 0.17848659044830129, 0.06616841739742085, 0.11324390579829924, 0.07375805740593933, 0.15724944096291438, 0.19237480068113655, 0.12577906949445605, 2.0057532470673323, 14.773984383791685, 24.998233504593372, 17.60787896811962, 38.84256452322006, 16.389081068336964, 4.192680297419429, 13.036619760096073, 25.440886951982975, 37.13961370289326, 52.43231490254402, 56.473838835954666, 53.03855337202549, 57.40104988217354, 57.675205171108246, 53.68954963982105, 53.66471417248249, 53.209160417318344, 53.654762506484985, 52.659835293889046, 51.38511009514332, 53.6714094132185, 60.371749475598335, 59.29346613585949, 61.45289786159992, 59.38819885253906, 58.861307725310326, 39.041837230324745, 20.047224573791027, 11.597857363522053, 9.964856039732695, 5.7373876590281725, 9.188917726278305, 39.12504516541958, 56.28224931657314, 42.01381355524063, 59.907034412026405, 59.448330625891685, 52.486272007226944, 50.97500950098038, 54.61389183998108, 45.772150084376335, 49.33077692985535, 71.27059444785118, 27.352836057543755, 1.0185424704104662, 0.44983776344452053, 24.251841455698013, 48.40358108282089, 38.415497839450836, 25.436258800327778, 48.40743027627468, 39.39416192471981, 41.885942816734314, 41.14660508930683, 42.52129912376404, 50.91754138469696, 44.66054253280163, 32.906059473752975, 61.89944989979267, 51.25059351325035, 46.29138842225075, 47.826525047421455, 74.84977439045906, 78.0316324532032, 2.5708406371995807, 0.1789759477833286, 0.16737944504711777, 0.16317062167217955, 0.1360162248602137, 0.10790572661790065, 0.12118306767661124], [0.1047356725030113, 0.04019777952635195, 0.06575947918463498, 0.016723780245229136, 0.025790262588998303, 0.08646588918054476, 0.029779913056700025, 0.011147485765832243, 0.07755280690616928, 0.05208912640227936, 0.29537581431213766, 0.2929651702288538, 16.357776448130608, 80.41824638843536, 44.6668653935194, 36.13058924674988, 40.061873495578766, 63.85070979595184, 18.48416894674301, 38.98978382349014, 46.42785429954529, 36.588639467954636, 45.92437371611595, 30.514737591147423, 41.54227785766125, 32.49300643801689, 31.948358863592148, 23.1200759857893, 41.71862259507179, 21.044405065476894, 0.49312067683786154, 1.5646916767582297, 35.646757408976555, 60.324157029390335, 44.38194528222084, 50.0835507363081, 43.290301859378815, 67.85748079419136, 54.31379534304142, 52.7144193649292, 43.946758434176445, 48.03672216832638, 34.14331488311291, 20.030912049114704, 7.598671708256006, 2.64088227879256, 5.613359464332461, 27.1189434081316, 58.20595309138298, 67.13236570358276, 61.039575040340424, 61.857298761606216, 54.95050437748432, 56.259431540966034, 55.90891554951668, 57.97657459974289, 56.68854631483555, 59.84121814370155, 54.58839140832424, 57.58870281279087, 54.37299616634846, 62.49027639627457, 54.235371351242065, 45.67751616239548, 40.830500051379204, 20.618706308305264, 4.750721678137779, 3.700373014435172, 13.104864098131657, 19.943267852067947, 6.462311334908009, 14.255840387195349, 9.558026120066643, 1.9087141728959978, 0.4487703472841531, 0.0817601682501845, 0.027740821496990975, 0.01393051172271953, 0.12539125280454755, 0.021646215718647, 0.022538848679687362, 0.07031366098090075, 0.06033415331330616, 0.020363934818306006, 0.09557594486977905, 0.054434450357803144, 0.031023331393953413, 0.039942929724929854, 0.039014061403577216, 0.09154640953056514, 0.08640973828732967, 0.1182294831960462, 0.8221002551726997, 0.03936394692573231, 0.049820202839327976, 0.05092313076602295, 0.028082877361157443, 0.11089589897892438, 0.0426305544533534, 0.0558609286963474, 0.044908487689099275, 0.07769976698909886, 0.058777999511221424, 0.04317960643675178, 0.3553370718145743, 1.7898881365545094, 16.495068781077862, 11.362043917179108, 13.354240916669369, 20.54733093827963, 13.282650858163834, 3.3464429061859846, 6.470499420538545, 23.602539896965027, 35.179804265499115, 44.76139672100544, 53.25674146413803, 54.83250550925732, 52.80277222394943, 52.94201195240021, 53.38797502219677, 51.20332404971123, 53.53554010391235, 50.40404453873634, 52.99875810742378, 50.77581658959389, 54.675706923007965, 54.030509144067764, 58.79022873938084, 54.09031793475151, 46.393002569675446, 15.226281713694334, 5.068725189194083, 1.9120135833509266, 2.079718178138137, 3.8443622505292296, 17.859398871660233, 44.83008183538914, 47.12626822292805, 42.04410932958126, 44.634616523981094, 45.86771875619888, 52.42427073419094, 46.668806970119476, 60.19788220524788, 44.33504059910774, 55.358667075634, 16.361308358609676, 0.8407671691384166, 0.26700805057771504, 37.856076657772064, 31.33795391768217, 39.81504254043102, 24.222284741699696, 23.688042908906937, 38.41582462191582, 26.544931009411812, 29.16804425418377, 33.05921025574207, 32.60434426367283, 39.14174906909466, 24.431049339473248, 31.477649621665478, 35.563013702631, 33.86030226945877, 27.39238053560257, 42.41136722266674, 65.77032119035721, 33.17402869462967, 0.29942553606815636, 0.19814768544165418, 0.0521725549333496, 0.02177530674089212, 0.026467299794603605, 0.056524839164922014, 0.07847970482544042, 0.04689007764682174, 0.008727427539270138, 0.08907062714570202, 0.021399514698714484, 0.031724067230243236, 0.05130345918587409, 0.02410961165878689, 0.03964448616898153, 0.07199216895969585, 0.05569247601670213, 0.7362472463864833, 0.22256896016187966, 21.21344469487667, 90.37978425621986, 49.65855874121189, 35.84020122885704, 49.88344207406044, 38.7936307489872, 33.451508805155754, 38.8885610550642, 38.6034319549799, 39.82354648411274, 43.56181249022484, 36.723809614777565, 41.02984115481377, 32.88307450711727, 34.790378361940384, 17.089360691607, 47.98523873090744, 34.13449555635452, 1.167100842576474, 1.5295677864924073, 28.49702686071396, 69.88335728645325, 57.2336270660162, 49.00335229933262, 47.0501659065485, 71.80119037628174, 61.929019913077354, 53.32238294184208, 47.872608974575996, 54.75745193660259, 41.58609330654144, 25.632706359028816, 10.000900905579329, 2.558720475062728, 4.6264241728931665, 24.842546358704567, 57.68198400735855, 70.64425125718117, 64.43295255303383, 63.58418449759483, 58.856238797307014, 58.0752857029438, 59.83940564095974, 58.97291153669357, 56.11211724579334, 58.43658931553364, 58.18723529577255, 57.0808182656765, 54.13910731673241, 61.53900504112244, 55.09727530181408, 49.574560448527336, 44.64636169373989, 25.023076571524143, 8.093797490000725, 4.216963369399309, 9.889191649854183, 7.63827508315444, 7.202051365748048, 16.791868954896927, 11.631816141307354, 1.2432703678496182, 0.08426991873420775, 0.055455920155509375, 0.012716603032458806, 0.03666943506686948, 0.08012976628378965, 0.009906515588227194, 0.05536697375646327, 0.0317174361407524, 0.05226528999628499, 0.06334712074021809, 0.06812551277107559, 0.07073489658068866, 0.05257049451756757, 0.040032499528024346, 0.10335161903640255, 0.05337652255548164, 0.23288261611014605, 0.07674091961234808, 0.6820056913420558, 0.013907837255828781, 0.046433823808911256, 0.0318524179601809, 0.05896776667213999, 0.03777273777814116, 0.07437913853209466, 0.03885406178596895, 0.0768243518541567, 0.03460291372903157, 0.016883030293683987, 0.04878068772086408, 0.4310855915537104, 0.7527729158755392, 13.796703424304724, 14.841919988393784, 8.131226431578398, 8.57663283124566, 9.412538576871157, 5.523448688909411, 13.581470623612404, 29.370527788996696, 35.36429576575756, 46.90770395100117, 55.42166009545326, 55.777704790234566, 53.33129346370697, 53.729443699121475, 53.894636034965515, 51.38609044253826, 54.25582565367222, 50.20587757229805, 53.47075738012791, 53.08694377541542, 53.628110736608505, 54.97722074389458, 60.69658264517784, 54.274292662739754, 45.81743985414505, 13.672851920127869, 5.4152238462120295, 1.6307209711521864, 3.437495995312929, 8.511225041002035, 23.710877783596516, 51.84671692550182, 50.64864121377468, 42.69272692501545, 47.536691799759865, 54.45735923945904, 57.46701434254646, 52.18756623566151, 62.13492326438427, 48.883749917149544, 48.11262309551239, 7.022303910925984, 0.589284966699779, 2.9641663189977407, 52.78424061834812, 29.703978896141052, 35.10940544307232, 34.96716767549515, 23.4200793877244, 35.45064993202686, 24.671686626970768, 28.696405962109566, 32.45893746614456, 31.076035872101784, 31.583861522376537, 32.54775770008564, 25.196658857166767, 33.64956937730312, 37.20294490456581, 19.154741764068604, 45.87238870561123, 73.95219415426254, 40.085215643048286, 0.33275767404120415, 0.10712174407672137, 0.14408166316570714, 0.022891366970725358, 0.039803936597309075, 0.11338202690239996, 0.09129814628977329, 0.22958667890634388, 0.14190216839779168, 0.2062484054476954, 0.09938177463482134, 0.24086290039122105, 0.1849759742617607, 0.12469238718040287, 0.12015816173516214, 0.20502485625911504, 0.18995605234522372, 0.9215722675435245, 0.5740638147108257, 27.25586526095867, 103.53902533650398, 62.94918157160282, 46.02094553411007, 58.78561958670616, 79.4961042702198, 26.530296094715595, 55.60538783669472, 61.33760824799538, 50.965935587882996, 59.28473420441151, 40.98640948534012, 52.564213424921036, 38.04306082427502, 43.018700033426285, 28.556442372500896, 49.79608476161957, 28.88111025094986, 1.2429775460623205, 2.9123017145320773, 41.98884889483452, 72.50563457608223, 57.39541478455067, 59.82094243168831, 55.06601817905903, 73.59099313616753, 65.29856890439987, 67.07799062132835, 54.982483461499214, 59.321751818060875, 41.7981219291687, 24.4829735532403, 10.303483419120312, 3.894799081608653, 7.724325265735388, 30.323930829763412, 62.0859818905592, 73.63868817687035, 66.57760307192802, 68.40417265892029, 63.96322935819626, 60.84433011710644, 61.41399174928665, 63.35779644548893, 60.581471621990204, 63.18600006401539, 60.56796334683895, 60.13698287308216, 56.33259281516075, 65.10037913918495, 61.26766160130501, 51.458168774843216, 57.84979060292244, 34.99703787267208, 7.2117954678833485, 4.331940924748778, 16.022718027234077, 26.549203880131245, 11.546734906733036, 19.974000602960587, 15.577364824712276, 3.5317596746608615, 0.5869491014163941, 0.16169638984138146, 0.13557286583818495, 0.0832382072985638, 0.23449364060070366, 0.17712645640131086, 0.15175426786299795, 0.16219192184507847, 0.2098125102929771, 0.1361632443149574, 0.19969488523202017, 0.21949391579255462, 0.10740393830928952, 0.13457550841849297, 0.31591014994774014, 0.27549323276616633, 0.2537800994468853, 0.2969857701100409, 2.672768267802894, 0.2063513858593069, 0.34932184615172446, 0.08248503872891888, 0.16446430381620303, 0.21764335571788251, 0.20190976560115814, 0.2025718949153088, 0.2102420208393596, 0.10979740909533575, 0.1590717103681527, 0.11395847526728176, 1.456781979650259, 5.660864990204573, 26.54623433947563, 17.962103560566902, 20.24280957877636, 31.463005207479, 18.36162932217121, 4.366793129593134, 16.12462855875492, 37.108793556690216, 45.148622542619705, 51.74354866147041, 56.108233854174614, 60.61058185994625, 55.79095847904682, 58.727809488773346, 56.606033742427826, 54.56403851509094, 59.71723459661007, 53.13489720225334, 55.700261145830154, 53.821900337934494, 57.4240842461586, 60.392853543162346, 62.18063101172447, 57.479895651340485, 49.20986741781235, 18.68284698575735, 7.376793064177036, 2.896256363019347, 4.145816937088966, 7.954078512266278, 25.194377079606056, 55.5484326928854, 54.75755073130131, 50.809266194701195, 54.68094304203987, 55.56571416556835, 60.3967597335577, 53.323553279042244, 65.85029169917107, 52.26339876651764, 65.03085806965828, 21.976244263350964, 0.8067222428508103, 0.7013812672812492, 46.33467189967632, 37.757418751716614, 50.88292524218559, 36.1556451022625, 31.518989503383636, 49.94905315339565, 35.04757136106491, 39.2653526365757, 43.07542718946934, 45.01451633870602, 53.3758270740509, 36.759447902441025, 40.76154135167599, 53.197799026966095, 45.466908663511276, 37.643892243504524, 56.85146637260914, 81.70681804418564, 54.92200590670109, 0.3671387932263315, 0.34867433714680374, 0.16708830051356927, 0.1239573789644055, 0.17316199257038534, 0.21787774079712108, 0.23061345505993813], [0.024818822821544018, 0.06348832917865366, 0.0445969303837046, 0.04689856410550419, 0.04669970934628509, 0.040779040718916804, 0.02572816338215489, 0.07431395570165478, 0.07486269969376735, 0.02042641252046451, 0.1356518897227943, 0.30417679517995566, 6.729340106248856, 76.02240666747093, 51.20365083217621, 41.833273842930794, 21.017103530466557, 67.73194313049316, 33.2576660066843, 31.083610765635967, 47.763642221689224, 37.58021526038647, 44.89437818527222, 30.640966817736626, 30.853785797953606, 43.68345536291599, 22.07578182220459, 28.832596354186535, 23.188168331980705, 59.50015604496002, 6.204216359183192, 0.37857600138522685, 4.412139421328902, 42.09430083632469, 70.34339860081673, 65.65676048398018, 48.51575866341591, 52.96211667358875, 54.87384349107742, 52.53450661897659, 62.91009686887264, 35.3753911703825, 51.44092909991741, 26.977780982851982, 17.96097882091999, 5.740654533728957, 1.0468171094544232, 13.66027744486928, 53.65883208811283, 69.2178837954998, 58.78352589905262, 60.95876857638359, 53.89334790408611, 57.53054313361645, 58.44304516911507, 59.666689708828926, 58.470449298620224, 58.67873892188072, 56.47297628223896, 54.81605239212513, 66.01381972432137, 53.39305154979229, 52.30150692164898, 47.41971507668495, 18.533554896712303, 3.5315060382708907, 2.7155957696959376, 10.202759373933077, 11.768485307693481, 7.029838431626558, 1.1279849102720618, 15.2782610245049, 7.385429050773382, 1.1466313409619033, 0.1985537144355476, 0.025981001963373274, 0.11795133366831578, 0.04502610696363263, 0.041531173992552795, 0.23872273945016786, 0.151782454631757, 0.07958522284752689, 0.036319015198387206, 0.014991837633715477, 0.06855145358713344, 0.1098106564313639, 0.020684724440798163, 0.018630083031894173, 0.053021074636490084, 0.022645417375315446, 0.7885702606290579, 0.21989644184941426, 0.15736592846224084, 0.13770226563792676, 0.052593545624404214, 0.01984143687877804, 0.03437602805206552, 0.07647954262210988, 0.11365195343387313, 0.1393455290235579, 0.033612517654546537, 0.09706801050924696, 0.22106217773398384, 0.09366354905068874, 0.04268728051101789, 1.6380821261554956, 5.750235244631767, 10.217527281492949, 3.673310154117644, 10.397116094827652, 14.53748982399702, 8.55208994820714, 2.4911885987967253, 5.196234472095966, 25.85021998733282, 41.09056569635868, 53.76600153744221, 55.98708875477314, 58.106862008571625, 54.36524078249931, 52.56807401776314, 53.09751860797405, 53.36110666394234, 55.7439474016428, 51.235394328832626, 54.368831589818, 54.785657823085785, 52.736822962760925, 54.565987810492516, 54.12560284137726, 27.666030451655388, 2.8388761170208454, 1.2168729468248785, 0.9372060536406934, 6.671374216675758, 31.835985593497753, 44.3700747191906, 45.6879960000515, 48.465677350759506, 42.49859154224396, 41.125463023781776, 55.277100652456284, 48.337107449769974, 47.03357219696045, 44.47981283068657, 37.89299167692661, 5.0650792848318815, 0.40692577545996755, 0.46642366563901305, 39.91450220346451, 44.94913324713707, 32.38180920481682, 58.0909788608551, 11.963430996984243, 35.567231476306915, 32.048582285642624, 28.267815560102463, 29.224893003702164, 31.387146078050137, 33.42109903693199, 36.578733399510384, 25.460028424859047, 40.64746007323265, 27.680733762681484, 23.958519995212555, 40.523860305547714, 49.282249733805656, 75.87540775537491, 9.602338392287493, 0.2742554194992408, 0.11102491393103264, 0.14476665062829852, 0.04051436859299429, 0.12815863243304193, 0.02643378626089543, 0.023044149202178232, 0.025717574790178332, 0.0792157297837548, 0.025288053111580666, 0.020525453983282205, 0.03498889731417876, 0.04748861974803731, 0.02582788947620429, 0.014130257986835204, 0.1250278379302472, 0.05053150685853325, 0.23817176901502535, 0.23576933308504522, 8.724561743438244, 86.46263524889946, 61.747860834002495, 36.066908463835716, 29.55161277204752, 47.18798831105232, 32.301679104566574, 40.05127586424351, 34.8905485868454, 38.6277886480093, 42.66517460346222, 32.53988832235336, 34.124825075268745, 37.177075892686844, 27.450447119772434, 21.665660329163074, 16.806872449815273, 69.48121726512909, 16.364049911499023, 1.7390720383264124, 2.0853577880188823, 28.310255482792854, 67.87910163402557, 69.42589983344078, 55.30217170715332, 61.635679453611374, 65.31800106167793, 61.59460745751858, 66.44478499889374, 40.250210389494896, 53.9745457470417, 37.1810694783926, 25.761050172150135, 9.542932379990816, 1.2886293651536107, 12.872686106711626, 51.418559700250626, 67.64757245779037, 62.50915378332138, 63.48839543759823, 56.65065094828606, 62.68819637596607, 59.025667905807495, 61.751873418688774, 60.868835002183914, 59.03031125664711, 57.31001056730747, 56.720897778868675, 60.74001431465149, 53.67919519543648, 55.49109376966953, 49.268091693520546, 21.77645668387413, 8.190794885158539, 2.4037928134202957, 7.832207651808858, 6.312960823997855, 9.12518184632063, 7.7017174288630486, 21.795199178159237, 7.944787060841918, 0.7120765652507544, 0.23620651743840426, 0.03530788351781666, 0.13099222647724673, 0.044907649062224664, 0.034875077835749835, 0.18432447250233963, 0.07002452024607919, 0.2560755325248465, 0.11043217542464845, 0.1129662683524657, 0.0742811082454864, 0.03626882746175397, 0.17206030403031036, 0.05584898011875339, 0.06115090538514778, 0.1323643239447847, 1.067114076577127, 0.11022103441064246, 0.0794091854186263, 0.21513612853595987, 0.005635576308122836, 0.048846449426491745, 0.058387986064190045, 0.14509089494822547, 0.03867065111990087, 0.15643588383682072, 0.09418892281246372, 0.08138265999150462, 0.10830713203176856, 0.11171529680723324, 0.03614807632402517, 0.8613048889674246, 7.143936809152365, 14.10469874739647, 8.25534962117672, 9.690852742642164, 6.71039717271924, 8.526019547134638, 3.566632065922022, 10.015915799885988, 26.07770998030901, 42.55080834031105, 53.417693227529526, 54.352967441082, 57.48618431389332, 52.471445202827454, 52.16213420033455, 51.314851865172386, 55.51016874611378, 55.806834027171135, 52.595751732587814, 55.798721462488174, 56.974917948246, 54.68929119408131, 56.26724012196064, 53.030642196536064, 24.716934598982334, 1.3135019992478192, 1.4303107000887394, 1.9550552987493575, 12.509279306977987, 39.14746396243572, 51.32530130445957, 50.49205921590328, 51.948608458042145, 50.39079464972019, 48.279217556118965, 58.17773960530758, 52.620723992586136, 48.611445128917694, 48.530505672097206, 25.941208004951477, 0.9790707228239626, 1.1294211144559085, 2.7075618132948875, 48.46502758562565, 51.13705940544605, 41.883301958441734, 58.337680622935295, 18.851804919540882, 34.27698411047459, 28.703994154930115, 29.456501975655556, 28.889680691063404, 34.26064118742943, 26.8905870616436, 37.06065773963928, 28.40376276522875, 24.805048070847988, 35.310490652918816, 24.5535908639431, 35.13069570064545, 56.28095358610153, 84.44397076964378, 13.016673680394888, 0.5111663835123181, 0.23303793277591467, 0.25008203694596887, 0.03767185022297781, 0.08798578535788693, 0.013973525674373377, 0.02261137135064928, 0.1212726003723219, 0.14736752200406045, 0.16139314830070361, 0.1803896203637123, 0.14800137549173087, 0.17521392699563876, 0.10593472339678556, 0.1377665504696779, 0.2966998057672754, 0.19858541898429394, 0.815128757385537, 0.699761901050806, 12.096448559314013, 98.1214052438736, 76.82191416621208, 50.343589782714844, 31.88578762114048, 90.60412421822548, 44.872339367866516, 43.41275788843632, 68.01422238349915, 47.77567237615585, 62.506053149700165, 37.279738783836365, 47.0881524682045, 51.36641509830952, 30.541562251746655, 39.5535633713007, 28.6608474701643, 65.2762109041214, 11.40252124518156, 1.2994181737303734, 7.385354954749346, 47.37478248775005, 82.06297293305397, 77.9519659280777, 61.086954697966576, 66.62127032876015, 63.839872777462006, 65.01755118370056, 69.80344757437706, 49.128187000751495, 64.93451803922653, 35.52761860191822, 23.01956567913294, 7.692616917192936, 1.3285005069337785, 16.570508033037186, 56.6041262447834, 71.44152447581291, 64.19341340661049, 68.26050996780396, 55.36555230617523, 65.21124958992004, 64.05426487326622, 67.87704974412918, 64.3741849064827, 62.19605438411236, 60.360266491770744, 57.01874479651451, 65.64060375094414, 57.73808039724827, 58.02283711731434, 61.47290758788586, 30.441646613180637, 8.709448054432869, 2.5140942446887493, 10.25125902146101, 12.786413636058569, 10.923097170889378, 6.443437272682786, 23.299715146422386, 10.84465702995658, 2.6630714256316423, 0.3471393679501489, 0.20431543729500845, 0.3968361590523273, 0.1754153607180342, 0.13366136059630662, 0.4485026397742331, 0.2715446805814281, 0.23054522200254723, 0.29044602415524423, 0.26234255405142903, 0.2622129156952724, 0.22900887241121382, 0.19747534417547286, 0.11972473264904693, 0.15505989751545712, 0.21106354863150045, 1.4170264941640198, 0.5348157801199704, 0.4644157999427989, 0.4968469706363976, 0.09170617166091688, 0.15799779299413785, 0.17863828543340787, 0.19498138659400865, 0.2774388174293563, 0.4585723369382322, 0.09230761555954814, 0.26136971719097346, 0.32941922661848366, 0.31377516919746995, 0.18946927768411115, 3.029269650578499, 12.744453437626362, 16.32168408483267, 10.541765782982111, 19.929419495165348, 19.99722495675087, 11.882992163300514, 2.893694587983191, 11.26076890155673, 34.71039645373821, 50.91004058718681, 55.37906438112259, 59.795145615935326, 62.040266543626785, 56.86251237988472, 54.463298320770264, 55.58034338057041, 57.631796300411224, 58.94062466919422, 53.14437389373779, 57.33639635145664, 60.357317849993706, 56.16331569850445, 58.6510194092989, 56.594626754522324, 31.929964050650597, 4.666991271078587, 2.154098474420607, 1.8842553603462875, 10.649617295712233, 41.60747855901718, 55.84482438862324, 54.71667252480984, 55.885322615504265, 54.801624566316605, 51.24629594385624, 65.35480588674545, 56.87388896942139, 55.42164109647274, 51.37528382241726, 44.23976831138134, 6.308563984930515, 0.9533171297516674, 0.8287372521590441, 47.455999329686165, 52.530528232455254, 40.39191238582134, 70.76386123895645, 18.389424830675125, 44.17592413723469, 43.06195691227913, 38.30069079995155, 40.874904468655586, 42.72747606039047, 43.63695725798607, 50.642667934298515, 36.05135589838028, 54.47046473622322, 42.37925514578819, 31.30913246423006, 55.19806869328022, 62.95347534120083, 95.99916592240334, 18.6984109506011, 0.5862596759106964, 0.32185668242163956, 0.30362736841198057, 0.2498903253581375, 0.3753817977849394, 0.16702563356375322, 0.1343070884468034], [0.024125606796587817, 0.01317481057412806, 0.04158086077950429, 0.07124122683308087, 0.06243965224712156, 0.06529124337248504, 0.08924865353037603, 0.028902056255901698, 0.02435783222608734, 0.03967840973928105, 0.1397945432108827, 0.5203045962844044, 0.4817955626640469, 55.973424687981606, 69.70996499061584, 39.66537617146969, 31.74951173365116, 45.32505847513676, 57.1597096323967, 25.444686748087406, 41.651138216257095, 37.79158651828766, 41.426923647522926, 40.248048305511475, 28.610388077795506, 42.43461437523365, 20.09361818432808, 17.6003572717309, 19.300118163228035, 29.70477305352688, 38.204255774617195, 1.794323567301035, 0.41491538111586124, 0.5357787315733731, 13.437794633209705, 51.87714949250221, 72.24301546812057, 41.221434473991394, 52.84857116639614, 59.91974472999573, 51.86657465994358, 43.536916226148605, 47.42649011313915, 56.976874843239784, 48.46700347959995, 30.009566098451614, 4.215260585770011, 2.0637908577919006, 33.93560282886028, 59.147702157497406, 60.45966535806656, 64.29566591978073, 63.45944859087467, 60.58338291943073, 59.12070080637932, 55.81807762384415, 58.449535220861435, 54.991796761751175, 63.06687645614147, 57.99153819680214, 53.31935070455074, 64.32946890592575, 50.24046331644058, 14.559298753738403, 2.600739332847297, 1.5300612850114703, 6.474950881674886, 6.988785909488797, 9.207672569900751, 5.710232416167855, 1.7336817900650203, 13.36489649489522, 4.6218150202184916, 0.4648433066904545, 0.09037496653036214, 0.08678795158630237, 0.036341494851512834, 0.07913241628557444, 0.0821336466469802, 0.0754510446859058, 0.20786876615602523, 0.11075803762651049, 0.09820898834732361, 0.11948118946747854, 0.03261550904426258, 0.14184514177031815, 0.04009891432360746, 0.0377584106172435, 0.01934853022248717, 0.19498310837661847, 0.9683589194901288, 0.05359156355552841, 0.01074226200216799, 0.05915900328545831, 0.07590987006551586, 0.024453630503558088, 0.07224622095236555, 0.1239414450537879, 0.1701317442348227, 0.10212051478447393, 0.0942650152137503, 0.035109091841150075, 0.13386882055783644, 0.165239239577204, 0.24885436141630635, 0.2010983310174197, 0.7939573028124869, 12.474755309522152, 2.276564002968371, 7.916940255090594, 11.037780717015266, 8.71283557265997, 5.259472103789449, 0.7731652935035527, 5.822560088708997, 24.03963804244995, 44.146954491734505, 52.66833543777466, 50.595907643437386, 56.37794718146324, 55.47042287886143, 56.31344184279442, 50.74479505419731, 54.451431557536125, 53.837988674640656, 57.69784815609455, 51.98339559137821, 59.39010635018349, 50.734626799821854, 34.97558802366257, 5.204867608845234, 0.46161736885551363, 2.9834709456190467, 6.619559247046709, 31.08002945780754, 36.2385718524456, 42.48035632073879, 52.21582531929016, 46.89856544137001, 54.5003729313612, 52.031846791505814, 49.956124573946, 46.638157814741135, 42.64808312058449, 24.660251140594482, 1.2142496625892818, 0.40560899768024683, 0.0451479267940158, 19.50344145298004, 43.49965922534466, 17.354056388139725, 61.82567685842514, 46.96900226175785, 17.613295577466488, 30.73476668447256, 30.76975330710411, 26.941202245652676, 29.704298079013824, 32.54912182688713, 36.96499027311802, 27.428453899919987, 34.91482928395271, 36.49533547461033, 21.95238534361124, 34.94586601853371, 41.93127438426018, 58.43691609799862, 60.11357992887497, 2.4486467940732837, 0.09572129449225031, 0.20529253408312798, 0.06986758569837548, 0.0620171883929288, 0.06110385693318676, 0.052319355454528704, 0.11660678472253494, 0.026031232373497915, 0.04546857169771101, 0.036793136241612956, 0.03226221706427168, 0.042945421737385914, 0.012496403178374749, 0.08008508157217875, 0.05035156944359187, 0.04964333049429115, 0.04606759990565479, 0.06712391768814996, 0.3151160222478211, 0.7399175525642931, 65.71144714951515, 81.020088493824, 38.73545587062836, 33.90498407185078, 48.890954330563545, 32.98501543700695, 38.05811941623688, 37.62491226196289, 33.334003910422325, 42.914954200387, 37.17980794608593, 34.05110143125057, 38.02163377404213, 25.073338374495506, 20.406284406781197, 11.420011706650257, 23.917691186070442, 45.631413236260414, 10.506238639354706, 1.714328359812498, 0.35046027100179344, 7.29053626768291, 47.92556293308735, 75.79715475440025, 46.65655642747879, 56.50349624454975, 67.48405203223228, 58.62549617886543, 49.65560629963875, 54.95932750403881, 59.053425416350365, 50.88492393493652, 35.79839587211609, 7.393315052613616, 2.523664031177759, 32.415824979543686, 59.86510746181011, 62.28807024657726, 65.73784053325653, 64.7254228591919, 64.23548474907875, 60.63855975866318, 57.73518115282059, 57.37236142158508, 56.41185276210308, 63.144107311964035, 55.201203525066376, 53.257482424378395, 65.32101809978485, 49.2666819691658, 16.92149329930544, 10.62466973438859, 3.3278065687045455, 8.24514526873827, 5.897189509123564, 8.97236354649067, 16.803393736481667, 9.446612298488617, 21.40793725848198, 7.312510963529348, 0.2608892210992053, 0.27889090357348323, 0.14976105216192082, 0.057699566168594174, 0.04576898936647922, 0.2838395442813635, 0.2262961445376277, 1.0977423330768943, 1.2227646494284272, 0.9312660223804414, 0.8241218654438853, 0.02405961131444201, 0.5544246872887015, 0.26074088062159717, 0.04281820649339352, 0.42668898997362703, 0.3487966727698222, 1.295910724438727, 0.31164012907538563, 0.20170625386526808, 0.04602476314175874, 0.12139213809859939, 0.022800915867264848, 0.035793541246675886, 0.5827709881123155, 0.9297363669611514, 0.23809992911992595, 0.10614599799737334, 0.12774521164828911, 0.3516956203384325, 0.23208969068946317, 0.4641184658976272, 0.4220076708588749, 3.4177831280976534, 17.60417226701975, 9.38321365043521, 16.600486524403095, 14.922132734209299, 8.550676424056292, 9.69140276312828, 2.4501244397833943, 9.220262244343758, 18.478725738823414, 39.10172201693058, 52.754359021782875, 50.88895931839943, 56.612223610281944, 55.82982659339905, 57.688675448298454, 53.05724076926708, 54.09321337938309, 54.314220920205116, 58.28907363116741, 53.16820241510868, 60.884965136647224, 50.21738715469837, 29.415690265595913, 3.555249539203942, 0.8446234278380871, 4.7288847249001265, 12.040381617844105, 43.764843195676804, 40.09923689067364, 45.89229963719845, 55.742074102163315, 49.427588135004044, 55.884893238544464, 51.35641783475876, 52.25737228989601, 50.961828008294106, 45.55723361670971, 18.344243355095387, 0.5157926352694631, 0.960242614382878, 2.5169079937040806, 26.47965431213379, 50.77091485261917, 32.68654525279999, 66.64684295654297, 59.64971981942654, 25.202786028385162, 30.897551849484444, 28.7021379545331, 28.5702071338892, 31.44943043589592, 32.521033734083176, 27.12696097791195, 36.30973823368549, 27.431408241391182, 33.096847236156464, 31.64937760680914, 24.219717979431152, 42.69625313580036, 67.91656002402306, 66.49513989686966, 2.908703307621181, 0.10096024852828123, 0.22958446730626747, 0.1877840532688424, 0.09456144383875653, 0.06756290546036325, 0.04080643710040022, 0.1119948564155493, 0.10656816870323382, 0.1300538401119411, 0.19481973198708147, 0.13313839881448075, 0.18019400507910177, 0.09871066533378325, 0.1408315313165076, 0.13019168662140146, 0.1465521243517287, 0.27199299714993685, 0.27104548236820847, 0.5242892168462276, 1.6735040629282594, 75.76841309666634, 92.50142320990562, 54.63861331343651, 41.91141664981842, 66.72624349594116, 76.64567962288857, 36.028705313801765, 59.347237050533295, 48.757231906056404, 59.931911677122116, 52.47309051454067, 44.52455922961235, 59.82846602797508, 27.33913019299507, 24.147155173122883, 26.584800370037556, 40.359036549925804, 43.630436807870865, 5.93969545327127, 1.0625367471948266, 1.2547881435602903, 15.882332660257816, 60.955557748675346, 81.41478091478348, 50.20482122898102, 63.95954355597496, 69.5384193956852, 65.1303519308567, 56.55725196003914, 65.45352458953857, 65.86014077067375, 53.63544434309006, 34.186317175626755, 5.757673820480704, 4.174497798085213, 38.789504170417786, 64.65904042124748, 65.68271309137344, 71.01663887500763, 71.30972474813461, 67.94228464365005, 63.990709483623505, 57.88642443716526, 61.82871289551258, 56.40445835888386, 66.18932470679283, 59.411810785532, 55.0114569067955, 69.5254696905613, 60.92225633561611, 21.311507932841778, 11.33315596729517, 6.87360031530261, 9.663688950240612, 5.657508345320821, 12.898280583322048, 15.52415817975998, 7.571675581857562, 24.238962046802044, 8.593664467334747, 0.8884563320316374, 0.6528884475119412, 0.24003282305784523, 0.11486523872008547, 0.21533018531044945, 0.5294989747926593, 0.2259574580239132, 0.41070770064834505, 0.7871391030494124, 0.5345281830523163, 1.0628928593359888, 0.12659584754146636, 0.3940866206539795, 0.1841472031082958, 0.181075424188748, 0.22717941901646554, 0.5904120218474418, 2.8100385144352913, 0.5045965360477567, 0.3975933277979493, 0.24238658894319087, 0.22050055005820468, 0.0801268348004669, 0.16108732408611104, 0.35890133993234485, 0.7117175438906997, 0.27628433250356466, 0.30273545533418655, 0.11686592042678967, 0.5296114250086248, 0.227388066414278, 1.683280582074076, 0.5670542002189904, 2.7875021612271667, 20.116133876144886, 9.790722783654928, 17.972260415554047, 21.00480929017067, 12.757843919098377, 9.872933272272348, 2.087607504799962, 7.968448866158724, 28.865808472037315, 46.8792624771595, 56.256524696946144, 55.27908034622669, 62.62804560363293, 60.76280169188976, 60.1255226880312, 52.72368706762791, 56.87819793820381, 58.05122919380665, 59.30982045829296, 53.85850377380848, 66.17400392889977, 53.71316537261009, 37.78731934726238, 9.536828957498074, 1.4907648623920977, 5.020787911489606, 8.747740499675274, 40.54744943976402, 43.936913162469864, 49.18736882507801, 60.67621573805809, 54.81297455728054, 64.22954946756363, 59.941232576966286, 59.55189026892185, 54.80266951024532, 52.313552275300026, 30.69894790649414, 2.6423254888504744, 0.5791583913378417, 1.0270631569437683, 25.063010528683662, 54.338110238313675, 25.772960633039474, 69.4979439675808, 56.142485216259956, 28.182168155908585, 39.975040555000305, 43.87958563864231, 36.317037642002106, 41.96899116039276, 41.776713877916336, 50.19437178969383, 41.95762977004051, 44.55025725066662, 51.51285544037819, 32.59955272078514, 46.52645900845528, 58.32795314490795, 73.77770751714706, 79.06992673873901, 4.488537171855569, 0.20489101734710857, 0.5854865361470729, 0.27236214140430093, 0.2304885516059585, 0.24124990071868524, 0.10851621729671024, 0.30197991931345314], [0.0563288862031186, 0.05158677406143397, 0.009792960499908077, 0.05864522187039256, 0.05279485689243302, 0.04714274553407449, 0.0075523067334870575, 0.11057689422159456, 0.02005312893743394, 0.07747858471702784, 0.0754870982200373, 0.24993506202008575, 0.3996669774642214, 18.088811561465263, 68.21145460009575, 58.36093157529831, 37.62823708355427, 31.035174764692783, 65.46695306897163, 34.006556421518326, 33.77410389482975, 43.936510384082794, 35.01975305378437, 42.09904298186302, 27.3489298671484, 37.877712696790695, 33.94432336091995, 9.209074694663286, 18.93464047461748, 32.184303402900696, 31.773712635040283, 29.210582971572876, 1.9870232208631933, 0.8869976853020489, 0.303241332876496, 7.261031800881028, 45.656632483005524, 70.16771882772446, 56.04636177420616, 49.682273268699646, 48.617011830210686, 51.89002700150013, 46.156643852591515, 49.09950613975525, 45.25821626186371, 45.96358381211758, 10.689693745225668, 2.2546550910919905, 9.093915224075317, 41.14144876599312, 58.27493079006672, 60.345648676157, 55.073765963315964, 60.36051727831364, 59.500509425997734, 60.149016827344894, 57.814688086509705, 61.83600850403309, 53.89094263315201, 61.86641827225685, 70.00710904598236, 34.92448076605797, 7.030982645228505, 13.670448549091816, 4.379563769325614, 3.9905591681599617, 4.318043170496821, 7.612741403281689, 21.408252641558647, 10.250308122485876, 4.158559078350663, 10.272043906152248, 2.7447988651692867, 0.04190188046777621, 0.007392177703877678, 0.007514777717005927, 0.1465413928963244, 0.14707272610394284, 0.2473553566960618, 0.11919834214495495, 0.6874382717069238, 0.12570470629725605, 0.1070399371383246, 1.3882779492996633, 0.6921386194881052, 0.06930002084118314, 0.23470948683097959, 0.12160696758655831, 0.22191885364009067, 0.40326084243133664, 0.21726258943090215, 0.22203675122000277, 0.5743075953796506, 0.15964616235578433, 0.09433387167518958, 0.062455074075842276, 0.1407487373217009, 1.5386712667532265, 0.8974422561004758, 0.5001413344871253, 0.2811242634197697, 0.8069941657595336, 0.28934663627296686, 0.7789259625133127, 0.789445519912988, 1.0482391831465065, 2.8765750816091895, 11.696480121463537, 4.902135953307152, 9.68538198620081, 25.478394739329815, 19.169473573565483, 5.636643189936876, 7.815916026011109, 3.190538459457457, 2.6406941888853908, 12.260746993124485, 33.653027191758156, 43.417317643761635, 44.838885962963104, 46.01504065096378, 53.67023527622223, 55.22296115756035, 55.01457653939724, 52.083136439323425, 58.317838087677956, 53.17282676696777, 42.69896999001503, 26.307743936777115, 5.6170362420380116, 0.23882287001470104, 2.271452802233398, 10.744736641645432, 27.576226070523262, 39.022507667541504, 41.52223013341427, 40.984494388103485, 50.73315627872944, 46.47753283381462, 49.95934680104256, 36.89179480075836, 37.16882273554802, 27.183992117643356, 23.67033775895834, 1.9294924079440534, 1.346867533866316, 0.09656466369051486, 7.688406743109226, 75.16595542430878, 34.9515201151371, 23.389394134283066, 7.934103459119797, 6.755359210073948, 24.75422389805317, 30.236721709370613, 34.39855098724365, 25.20318690687418, 26.905372068285942, 35.62656529247761, 35.05420580506325, 27.26780992001295, 43.15010838210583, 31.521734856069088, 33.02306279540062, 34.50796231627464, 42.92530104517937, 77.57653847336769, 27.693974152207375, 0.5588436126708984, 0.2022207254776731, 0.2974140190053731, 0.06934454970178194, 0.07814216864062473, 0.04378600788186304, 0.07099607319105417, 0.004876375005551381, 0.06673930707620457, 0.09290034664445557, 0.0392732305044774, 0.07346037455135956, 0.0755913180182688, 0.03126955372863449, 0.06835133346612565, 0.045278971520019695, 0.01753389195073396, 0.08297637759824283, 0.06601706380024552, 0.3127087920438498, 0.22523899970110506, 26.745132766664028, 84.36117321252823, 60.485112592577934, 31.32181618362665, 46.144355311989784, 39.89513844251633, 35.5450064688921, 37.188224494457245, 33.41250769793987, 39.0016657859087, 40.03551810979843, 29.697901122272015, 39.867103546857834, 32.42255061864853, 16.709838956594467, 26.161907762289047, 27.695442773401737, 28.667668104171753, 39.686803221702576, 8.813866451382637, 3.645795355550945, 0.3545622993260622, 3.072464307770133, 38.83235067129135, 70.96531882882118, 59.969495460391045, 54.979964196681976, 58.73590685427189, 56.83467127382755, 51.586058512330055, 51.912274807691574, 47.132655680179596, 50.54927654564381, 18.766438700258732, 4.7690115217119455, 9.087611362338066, 39.907461181283, 58.21744367480278, 62.516274601221085, 54.20104779303074, 60.99759869277477, 60.730055049061775, 62.66045406460762, 57.92570672929287, 61.13373398780823, 53.935727030038834, 62.19539701938629, 65.69950059056282, 29.16843943297863, 8.816144429147243, 19.003500379621983, 7.714102389290929, 7.792026232928038, 9.698527380824089, 9.187642894685268, 26.172661185264587, 18.396473452448845, 10.355278439819813, 16.371007338166237, 7.622912507504225, 0.03323867931612767, 0.08350290168891661, 0.050181780898128636, 0.32693288347218186, 0.4621704766759649, 0.3496770380297676, 0.40970366389956325, 0.5667629814706743, 0.11524905523401685, 0.21694900235161185, 1.051873213145882, 0.4238378070294857, 0.004138054491704679, 1.0546803125180304, 0.39466095389798284, 0.6326908094342798, 1.4465097058564425, 0.3520637552719563, 1.2913452694192529, 1.7068279185332358, 1.3492310070432723, 0.19190332910511643, 0.1336418421124108, 0.5473805184010416, 2.2177046863362193, 0.8733007265254855, 0.5707303842063993, 1.0216357419267297, 1.7147292383015156, 0.10673847675207071, 0.5452855839394033, 0.25523972581140697, 1.0340591752901673, 8.059439733624458, 15.578630156815052, 11.884000059217215, 19.191951267421246, 31.2888415530324, 21.63665648549795, 8.053139671683311, 13.292618673294783, 8.00410045310855, 5.569373499602079, 11.738597061485052, 29.466921016573906, 43.78563567996025, 47.84529224038124, 46.9410053640604, 51.377457305788994, 56.107333302497864, 55.49619309604168, 54.10219989717007, 56.392150819301605, 52.627806812524796, 40.87681956589222, 24.683863073587418, 4.87307321280241, 0.6842733384110034, 4.043139321729541, 15.451341737061739, 34.04730163514614, 40.99207118153572, 48.315422013401985, 48.198893666267395, 55.19614979624748, 51.16553507745266, 54.72771853208542, 43.32213655114174, 36.07597857713699, 26.707393191754818, 22.226346842944622, 1.0234713996760547, 1.0681307595223188, 0.29289270692970604, 8.660408835858107, 80.61796367168427, 48.150256276130676, 17.426926977932453, 7.734913872554898, 15.66979106515646, 29.448923282325268, 30.10383903980255, 34.04717244207859, 25.292092636227608, 29.116555117070675, 30.658603571355343, 33.30091528594494, 31.369667015969753, 32.14098572731018, 39.73330892622471, 27.249360010027885, 25.05317285656929, 50.221566930413246, 81.56087547540665, 31.670899651944637, 0.528314447728917, 0.26283709157723933, 0.24200858344556764, 0.03457392173004337, 0.06141248275525868, 0.036252270147087984, 0.09125543569098227, 0.03387296324945055, 0.2241639097337611, 0.15718046575784683, 0.22026824299246073, 0.13774142134934664, 0.19067108194576576, 0.10133803880307823, 0.24938510090578347, 0.2017047250410542, 0.1657733929459937, 0.2861181157641113, 0.2330537702073343, 0.587780544301495, 0.4838004894554615, 37.29651868343353, 98.9229266345501, 79.21036720275879, 45.88184639811516, 46.27879589796066, 89.46540892124176, 45.225036442279816, 48.17489795386791, 56.043158546090126, 49.47087921202183, 57.13943392038345, 40.03430217504501, 59.14435833692551, 45.86467131972313, 12.967054042965174, 27.83793892711401, 39.469036906957626, 42.82274454832077, 36.35881260037422, 5.10030054487288, 1.7310719238594174, 1.2131110299378633, 9.66813376173377, 56.11083671450615, 75.79735994338989, 67.83304050564766, 59.05010059475899, 61.45599849522114, 58.744384199380875, 53.962466195225716, 58.807130232453346, 56.50840938091278, 54.397888630628586, 14.186162576079369, 3.442003740929067, 14.431978035718203, 48.63156504929066, 58.39283846318722, 64.81205061078072, 58.200048208236694, 66.29004970192909, 65.7756333053112, 65.67768976092339, 61.815166622400284, 66.26830726861954, 57.29170694947243, 62.02066719532013, 71.45439058542252, 40.63487134873867, 9.566899593919516, 20.64953025430441, 12.827082853764296, 10.990544501692057, 6.961693838238716, 10.954221300780773, 29.80107508599758, 20.293561555445194, 10.82862189039588, 18.887969478964806, 8.147404063493013, 0.09398547044838779, 0.22895191999850795, 0.17295990575803444, 0.29016201908234507, 0.23394939402351156, 0.7573278027120978, 0.4899285512510687, 1.1377414804883301, 0.35390428151004016, 0.2739753626519814, 5.688808215782046, 2.686862424015999, 0.17208765959367156, 0.9184355952311307, 0.27383251406718045, 0.504868874559179, 1.5071421023458242, 0.89629489579238, 1.8149234494194388, 0.9849354112520814, 1.1627357080578804, 0.33862613257952034, 0.2112623699940741, 0.3350362158380449, 1.7780897696502507, 3.6873461259528995, 2.0516894571483135, 1.5137532725930214, 1.1683597625233233, 1.6427155025303364, 5.50802294164896, 4.962424943223596, 2.415618016384542, 10.004730150103569, 18.674937710165977, 13.187275975942612, 20.62744963914156, 30.31675111502409, 26.659738048911095, 7.427737880498171, 13.775967936962843, 8.656825628131628, 4.5534951612353325, 14.855426363646984, 38.7847164273262, 49.255141988396645, 51.265655905008316, 51.47846728563309, 56.76089063286781, 60.16285188496113, 57.81566463410854, 55.98978281021118, 62.599778920412064, 60.22209070622921, 47.7580451220274, 33.284139186143875, 7.862189467996359, 0.6972139002755284, 4.156091110780835, 13.142307288944721, 33.83762888610363, 47.76056058704853, 48.24245072901249, 49.20879207551479, 59.93194967508316, 55.598422810435295, 57.84618839621544, 45.662465170025826, 42.027990594506264, 32.53475099802017, 27.443339601159096, 2.6856851996853948, 2.18558999709785, 0.248498160217423, 10.093537084758282, 90.97225606441498, 42.57410869002342, 29.501390866935253, 13.520036470144987, 14.443651009351015, 35.44104404747486, 44.03775975108147, 47.24543362855911, 36.826472505927086, 36.91394381225109, 48.22471708059311, 49.97292347252369, 40.46122066676617, 56.59657225012779, 48.850334510207176, 44.048452377319336, 48.504454270005226, 56.699151545763016, 94.33964297175407, 43.262886330485344, 0.533645621035248, 0.3131525369826704, 0.34825181763153523, 0.15156871610088274, 0.17141837597591802, 0.16467666195239872, 0.17698147043120116, 0.0916754244826734], [0.05715903404052369, 0.04884536218014546, 0.03148102870909497, 0.054876017093192786, 0.04981583158951253, 0.012780068718711846, 0.07519383114413358, 0.07152204809244722, 0.042802320822374895, 0.081048871652456, 0.08402115083299577, 0.1729963452089578, 0.46492601162754, 3.5733289690688252, 55.7389772683382, 62.40513816475868, 50.11655196547508, 30.82015000283718, 50.78249283134937, 52.96428635716438, 32.26201683282852, 45.7788073271513, 40.026037618517876, 33.57926554977894, 33.13883118331432, 32.880144864320755, 38.673150613904, 15.812791641801596, 7.050794782117009, 39.5054579526186, 31.617208532989025, 37.651043459773064, 30.99221996963024, 0.6194326677359641, 0.8374384290073067, 0.11686159370583482, 3.791908915154636, 32.12492398917675, 64.36571896076202, 61.802330911159515, 61.672621071338654, 61.894377171993256, 51.91371493041515, 51.38663001358509, 49.129478931427, 45.4082740098238, 22.741929776966572, 13.092658203095198, 4.024392552673817, 10.827890429645777, 39.35500502586365, 58.03975760936737, 67.8236398100853, 59.37068559229374, 60.214266926050186, 54.44725178182125, 59.95478644967079, 54.166830629110336, 65.9509103000164, 53.380964398384094, 10.324995014816523, 2.837997176684439, 17.32679285109043, 9.27075108513236, 3.2567565562203526, 2.0183735573664308, 3.6170432483777404, 21.166587509214878, 17.55727518349886, 9.06512226909399, 10.412957444787025, 6.033133389428258, 2.8036826429888606, 0.8416047866921872, 0.14228064886992797, 0.2612911682808772, 0.1696756944875233, 0.110387127060676, 0.27376248501241207, 0.4468594357604161, 2.0275688264518976, 2.9365648375824094, 0.8874106162693352, 1.6634775884449482, 1.4509590296074748, 1.61572293844074, 0.24485287925926968, 0.04490617218834814, 4.932491099461913, 1.3667348865419626, 0.07255352946231142, 0.11758214488509111, 1.6992599121294916, 0.8702187356539071, 0.5477395991329104, 1.0405976744368672, 0.8032582537271082, 4.406468700617552, 1.358987814746797, 0.0874287293117959, 1.095381947234273, 0.5154109338764101, 0.353887093369849, 0.3047940245596692, 0.4816896136617288, 0.39218687103129923, 2.1656006947159767, 3.4543991507962346, 5.728080533444881, 17.2858614474535, 23.485703766345978, 40.023301765322685, 23.624637611210346, 4.137939959764481, 14.719286318868399, 8.841990642249584, 2.5845239404588938, 4.675616333261132, 14.391230922192335, 23.92585314810276, 35.63876263797283, 41.3202253729105, 45.297240167856216, 43.30336555838585, 41.47692896425724, 31.36783741414547, 21.816318444907665, 15.320149026811123, 5.193073516711593, 0.23895938065834343, 0.7528749760240316, 4.532312722876668, 25.48674289137125, 47.80312970280647, 43.35421442985535, 41.03194624185562, 52.02776961028576, 43.63112457096577, 50.1412658393383, 46.34542532265186, 52.98868864774704, 31.299507580697536, 9.728364329785109, 0.8895107160788029, 0.6624400068540126, 0.9628033207263798, 7.82417630776763, 69.48927283287048, 23.99634126573801, 16.50676265358925, 23.804981634020805, 31.139469668269157, 20.088085681200027, 31.41334567219019, 34.89085637032986, 29.296779446303844, 29.635035395622253, 25.859622582793236, 38.67508850991726, 28.711206167936325, 40.81161126494408, 34.87251855432987, 35.87102137506008, 35.31816244125366, 44.05686892569065, 53.3424686640501, 73.41598212718964, 5.345895616337657, 0.15809977892786264, 0.09777764469617978, 0.11211590070161037, 0.0630256743170321, 0.037751015115645714, 0.011547015401447425, 0.086955439473968, 0.03058968337427359, 0.025417899269086774, 0.007219096341941622, 0.04576325627567712, 0.05175465528736822, 0.11019923753337935, 0.014525613041769248, 0.023252492319443263, 0.05693064922525082, 0.017348941328236833, 0.01610418526979629, 0.01978201496967813, 0.3555209463229403, 0.3474664472742006, 4.763505142182112, 70.00960931181908, 74.0692126750946, 37.84289136528969, 38.42116333544254, 51.0678119212389, 36.73839323222637, 38.770896568894386, 37.34340436756611, 34.241532012820244, 40.13728804886341, 31.61239229142666, 37.749195992946625, 35.07324278354645, 26.256061010062695, 17.531668357551098, 47.746706530451775, 30.5003971606493, 32.77830272912979, 36.774479895830154, 5.741129508242011, 2.5483315950259566, 0.0646137516014278, 2.1599468355998397, 28.030423298478127, 67.40606501698494, 65.04563167691231, 63.1443314999342, 64.25337418913841, 55.512395426630974, 55.021697357296944, 56.780991554260254, 48.494335412979126, 25.117712393403053, 18.074260242283344, 6.260141283273697, 10.221206434071064, 37.81046770513058, 53.56547109782696, 69.13931161165237, 62.73385472595692, 60.117683708667755, 53.78008358180523, 60.18410034477711, 54.192213267087936, 66.37314364314079, 46.6124901920557, 9.262807611376047, 6.1743067391216755, 21.568393148481846, 12.48471837490797, 9.373442474752665, 12.497866619378328, 7.01178465038538, 21.70135371387005, 22.650595977902412, 14.40071141347289, 16.193591058254242, 9.028984308242798, 5.9919108264148235, 0.10968982736812904, 0.5688916391227394, 0.14574820030247793, 0.22799975937232375, 0.45126716955564916, 0.6323341035749763, 0.31978267652448267, 0.43370112776756287, 0.41898769384715706, 0.5091996327973902, 0.8072021452244371, 2.856706897728145, 3.9107615500688553, 0.4959535732632503, 0.2501930622383952, 7.90751438587904, 3.3768267882987857, 0.19629414193332195, 0.27434643649030477, 1.0648371675051749, 0.6422051426488906, 0.17380874458467588, 0.5378267623018473, 0.8151525061111897, 2.0630916953086853, 0.16851939872140065, 0.23489965475164354, 0.6026424968149513, 0.21059709397377446, 0.44402582687325776, 0.17795277846744284, 0.06442973608500324, 0.7524181692861021, 7.145972549915314, 10.620920285582542, 13.052032683044672, 24.857034981250763, 29.791653491556644, 45.75871020555496, 21.667725518345833, 8.576279450207949, 19.379573799669743, 12.259141579270363, 8.11999898403883, 5.894993701949716, 12.336395233869553, 21.98871709406376, 35.010872930288315, 43.996452167630196, 42.38328292965889, 41.86981648206711, 39.70315374433994, 31.360321417450905, 20.776625834405422, 16.51476502418518, 9.512808546423912, 1.8128582602366805, 1.113992517348379, 7.745952755212784, 30.994296558201313, 50.15492990612984, 46.32776387035847, 44.402684569358826, 56.63252592086792, 49.11405935883522, 55.62787503004074, 49.02528092265129, 57.24196381866932, 36.02123871445656, 10.91727303341031, 0.928531950339675, 0.16297132533509284, 0.5012100271414965, 14.498940892517567, 75.76498568058014, 31.453019343316555, 17.240780666470528, 15.596758034080267, 22.82646954059601, 24.333926551043987, 33.79445560276508, 30.452474132180214, 32.48517885804176, 26.50958340615034, 31.606200523674488, 31.275755055248737, 31.782600358128548, 31.12680684775114, 32.44883380830288, 41.604043543338776, 19.903685376048088, 42.29662477970123, 61.13490052521229, 77.73806020617485, 6.129679558798671, 0.08681155188241974, 0.1390766934491694, 0.09594508170266636, 0.04816585547814611, 0.03648268473625649, 0.009394053340656683, 0.04137020216148812, 0.07406299846479669, 0.19190901395631954, 0.1623588753864169, 0.12179152487078682, 0.15049105830257758, 0.17231033358257264, 0.11644061043625697, 0.20111695892410353, 0.21945428510662168, 0.10830696133780293, 0.21079020079923794, 0.13305818749358878, 0.7646066683810204, 0.47263740096241236, 6.916315723210573, 84.88462552428246, 87.40721896290779, 65.0059162080288, 40.431342869997025, 72.45920866727829, 67.28218406438828, 42.56166435778141, 61.22943565249443, 51.55197434127331, 48.98567944765091, 43.56508031487465, 47.87523843348026, 55.86436294019222, 22.86392033100128, 11.821495313197374, 47.237606048583984, 36.180845350027084, 43.84746216237545, 38.79688337445259, 3.0913017969578505, 1.6966045671142638, 0.2860262378817424, 5.170939229428768, 39.65090274810791, 74.65667635202408, 72.53672450780869, 71.5209250152111, 71.24792486429214, 60.86441583931446, 62.33582228422165, 56.94822438061237, 55.38047410547733, 26.814471445977688, 17.687152214348316, 5.538341514766216, 16.84736877679825, 46.666139513254166, 59.1756534576416, 73.2495966553688, 63.5869849473238, 63.400813937187195, 54.00189287960529, 62.802129462361336, 54.558741599321365, 69.4706766307354, 57.92278468608856, 14.460493605583906, 4.99173229560256, 23.58348771929741, 17.61661659926176, 10.623890776187181, 7.853782894089818, 6.318331360816956, 33.31608407199383, 29.818974025547504, 19.16809044778347, 17.334348745644093, 11.001583859324455, 5.794791653752327, 2.820013454183936, 1.6671705152839422, 0.4067495302297175, 0.31643217662349343, 0.7562330458313227, 1.3039028830826283, 1.0981908277608454, 3.6434240452945232, 5.489810518920422, 3.6354506481438875, 6.721477378159761, 16.114017628133297, 9.594652354717255, 0.3993448260007426, 0.31767233507707715, 9.606335777789354, 3.813097053207457, 0.5482436064630747, 0.8295790257398039, 4.869946455582976, 5.567574771121144, 2.156921485438943, 2.387886866927147, 3.9155082078650594, 12.148876246064901, 6.5630529541522264, 2.891950481571257, 2.171524101868272, 0.7574776571709663, 2.820377047173679, 3.3371588168665767, 1.8762219976633787, 1.4776660152710974, 8.1963349878788, 9.419227167963982, 12.08979606628418, 26.667064055800438, 30.944954305887222, 47.534658908843994, 26.35240864008665, 6.279548741877079, 18.224754966795444, 13.721222374588251, 5.325069883838296, 8.807618636637926, 16.05008225888014, 30.641289800405502, 43.250829577445984, 48.5755180567503, 50.254811346530914, 48.360502794384956, 48.352124243974686, 36.344065591692924, 24.7281401976943, 19.669410847127438, 8.214512262493372, 1.552740961778909, 2.173477909527719, 6.308908341452479, 32.31627032160759, 53.41828979551792, 49.31557394564152, 48.44719134271145, 60.37586085498333, 53.29407826066017, 60.68022832274437, 53.27577464282513, 61.109799072146416, 37.88838252425194, 12.632273007184267, 2.0129472110420465, 1.6010582190938294, 0.7830981980077922, 11.480072233825922, 81.4214001595974, 35.51013953983784, 23.51024854928255, 28.527852706611156, 40.73371164500713, 29.188422560691833, 43.15989665687084, 47.4567136913538, 41.0675161331892, 41.210080683231354, 37.857740968465805, 50.854628160595894, 42.82582998275757, 52.1224757283926, 48.46285030245781, 50.88024638593197, 45.926630795001984, 60.454611629247665, 67.2969576716423, 93.83012071251869, 10.922326762229204, 0.2816132496809587, 0.3432727191830054, 0.3379668382694945, 0.23959099286003038, 0.1982729896553792, 0.16613694140687585, 0.15089872002135962, 0.1247623420204036], [0.07885302737122402, 0.030098687748250086, 0.05369918610085733, 0.030735947693756316, 0.06977397861192003, 0.07713439146755263, 0.07805321482010186, 0.029391920106718317, 0.1044804256525822, 0.12241879550856538, 0.08548471800168045, 0.09793405231903307, 0.2557361632352695, 0.2408242048113607, 42.83467970788479, 80.84950044751167, 58.10070253908634, 35.460685193538666, 35.38748972117901, 53.5733936727047, 32.839874625205994, 37.51975670456886, 47.769250720739365, 36.53060898184776, 38.26676242053509, 33.73989053070545, 39.39251661300659, 32.07570143043995, 10.910822879523039, 22.481339760124683, 55.11533573269844, 25.63747890293598, 43.69056858122349, 44.12833169102669, 2.3870767978951335, 1.1775300954468548, 0.5084780871402472, 10.379186756908894, 43.21603864431381, 45.876614078879356, 50.42829483747482, 48.736146837472916, 50.611745193600655, 51.93899877369404, 51.30216434597969, 53.00093159079552, 54.28474210202694, 54.432504773139954, 18.853125348687172, 1.7883951729163527, 7.28050148114562, 17.22458403557539, 36.65242284536362, 47.17353008687496, 56.29120923578739, 60.21945744752884, 54.22993004322052, 50.20700231194496, 23.35345946252346, 0.7644995022565126, 3.98802375420928, 20.10447420179844, 11.249743793159723, 6.290637021884322, 3.2948827603831887, 1.9035570183768868, 19.00976624339819, 9.77825565263629, 6.46779871545732, 8.012019228190184, 11.480396166443825, 10.511072929948568, 6.277942853048444, 0.4083324718521908, 0.8663028082810342, 0.7377948320936412, 0.38555527688004076, 0.6415022991131991, 0.9710238827392459, 1.7071328521706164, 0.39675686799455434, 0.14743317238753662, 0.326127564185299, 0.25199591706041247, 2.18551613856107, 1.0581304086372256, 0.2799696003785357, 1.003417382016778, 3.7060138117522, 0.45604113838635385, 0.15185264695901424, 0.4028361855307594, 0.9983372921124101, 1.0981751536019146, 1.45163289969787, 0.22577337571419775, 0.15537921397481114, 2.386848097667098, 0.7031088089570403, 0.6084229960106313, 1.3619926222600043, 0.1657942176098004, 0.23652914387639612, 0.045702322240686044, 0.04374470365291927, 0.6047325627878308, 1.8889236473478377, 3.404849572107196, 5.28989564627409, 20.796445570886135, 27.51408990472555, 23.873168975114822, 42.63006828725338, 21.015530414879322, 3.509371750988066, 12.862176820635796, 11.526263505220413, 11.208896934986115, 4.193852534517646, 3.4599862759932876, 7.164270943030715, 16.02384276688099, 22.559849247336388, 19.759395718574524, 17.969195879995823, 12.553796768188477, 13.313879482448101, 1.2763675418682396, 0.5455803056247532, 2.0619911793619394, 3.0347634432837367, 31.46798864006996, 50.439941212534904, 45.50393007695675, 62.11986847221851, 59.115210101008415, 43.82323086261749, 52.06790305674076, 43.94924350082874, 51.46092742681503, 46.175517439842224, 52.377324253320694, 17.7693323045969, 8.120603151619434, 0.2409820002503693, 11.437171585857868, 45.975477173924446, 34.59521323442459, 19.340891875326633, 25.4806974157691, 72.85669013857841, 30.05736943334341, 21.096988543868065, 30.597025975584984, 31.71784993261099, 27.96620674431324, 30.586515739560127, 26.35616473853588, 38.440595492720604, 32.155379354953766, 34.9244199693203, 35.5156796425581, 29.3428747728467, 37.97996900975704, 46.664167419075966, 70.42762488126755, 37.20046743750572, 0.9811875654850155, 0.19649603578727692, 0.22030834865290672, 0.014873294385324698, 0.054517685930477455, 0.05312463763402775, 0.004664699645218207, 0.07799117869581096, 0.045011197216808796, 0.019507899014570285, 0.05493925549671985, 0.05778814520454034, 0.0033992346516242833, 0.04842715825361665, 0.07307891064556316, 0.011497933464852395, 0.0404736877680989, 0.013076122559141368, 0.0937396266090218, 0.03345718985656276, 0.09581124279065989, 0.2084000696777366, 0.24881971796276048, 54.99193735420704, 91.85259282588959, 53.12761679291725, 28.443324342370033, 50.35154655575752, 35.47106243669987, 33.80354471504688, 38.448708057403564, 35.483768954873085, 41.14088639616966, 38.5502690076828, 35.767351537942886, 41.71790063381195, 34.87492382526398, 21.79745625704527, 37.603838592767715, 62.224100679159164, 27.475656867027283, 49.83071990311146, 45.282584354281425, 10.042957048863173, 2.4341265857219696, 0.5172779399435967, 8.57160760089755, 46.003500670194626, 46.535111144185066, 53.69812957942486, 55.06101004779339, 54.642280116677284, 55.39019398391247, 56.07630796730518, 57.30269595980644, 49.25608433783054, 53.16047362983227, 24.845838882029057, 3.605031855404377, 8.653187323361635, 17.46800657361746, 31.124150790274143, 42.12155297398567, 52.665082812309265, 58.46674829721451, 52.408847361803055, 43.882925659418106, 21.107760965824127, 1.6030246135778725, 7.137836711481214, 25.310263261198997, 18.008989244699478, 13.013848531991243, 14.573538489639759, 5.859483182430267, 15.385535918176174, 14.861757773905993, 11.305181868374348, 14.611149821430445, 14.15771920233965, 10.1399658434093, 10.654629226773977, 1.535709088202566, 0.8626131468918175, 0.6564039119984955, 0.8292441687081009, 0.4801606113323942, 0.2623731305357069, 0.1374711756943725, 0.3282983461394906, 0.11835656856419519, 0.11573648298508488, 0.033418405218981206, 0.7515167270321399, 0.9285302285570651, 1.3451399328187108, 2.1677138563245535, 7.5885120034217834, 2.232486130669713, 0.2850342832971364, 0.04465681056899484, 1.5870321029797196, 1.95182143477723, 1.2419967236928642, 0.42090896575246006, 0.16995370300719514, 0.41349360428284854, 0.3541984688490629, 0.04542827678960748, 0.2630803675856441, 0.02962768001452787, 0.07491113225114532, 0.021653600088029634, 0.09536556826788001, 0.20937838358804584, 6.151087135076523, 6.557057350873947, 11.767890639603138, 26.388556100428104, 30.709792524576187, 31.202793270349503, 40.18018014729023, 19.64752972126007, 7.6422368455678225, 18.63430079072714, 14.020876195281744, 16.27500928938389, 9.891101997345686, 5.773676186800003, 6.624603476375341, 15.006669647991657, 22.66524989157915, 19.835714623332024, 17.86722455173731, 12.58327653631568, 16.19080390781164, 2.4851580848917365, 2.5608804216608405, 5.002107638865709, 4.329337114468217, 37.39187076687813, 52.579013630747795, 45.857360512018204, 60.499263033270836, 63.076140359044075, 51.04551091790199, 58.2206355035305, 48.616042882204056, 56.315600126981735, 47.02944941818714, 55.899841636419296, 17.3302810639143, 3.306810320354998, 0.3254708822350949, 20.223170332610607, 45.15955835580826, 44.991918951272964, 19.366369508206844, 22.932115271687508, 78.37156221270561, 33.30401971936226, 26.630593612790108, 27.06006556749344, 31.137754060328007, 31.216730922460556, 31.875235587358475, 28.504147678613663, 28.05856268852949, 35.37687309086323, 25.36270994693041, 39.456482380628586, 28.567811362445354, 30.27228780090809, 50.01642353832722, 76.45014971494675, 42.05678924918175, 0.9222391317598522, 0.042389812879264355, 0.11363065379555337, 0.04092952600331046, 0.03831933696346823, 0.022110334466560744, 0.042222621850669384, 0.029867809316783678, 0.07737501058727503, 0.17034572025295347, 0.14549825980793685, 0.20134668331593275, 0.19487695157295093, 0.15543307905318215, 0.40017436898779124, 0.22765394824091345, 0.11660822448902763, 0.1519250063574873, 0.29696475248783827, 0.3271574276732281, 0.16761041624704376, 0.5212284810841084, 0.7622405234724283, 63.601644560694695, 100.02519428730011, 75.92186406254768, 44.486428275704384, 51.85935124754906, 70.59824332594872, 42.39288121461868, 52.49522812664509, 61.943117156624794, 52.95254498720169, 51.71178996562958, 45.83513930439949, 57.12096691131592, 43.31283085048199, 14.425594378262758, 30.074814297258854, 54.900316670536995, 31.618642956018448, 51.22182905673981, 53.35878498852253, 6.676461668685079, 2.3138791881501675, 0.6959099764935672, 11.835746448487043, 50.60057379305363, 54.981548711657524, 57.44434095919132, 60.20497642457485, 56.95818744599819, 63.29836383461952, 61.18801407516003, 64.49234336614609, 63.968404680490494, 61.62098564207554, 23.28954119235277, 3.321613851003349, 10.962990280240774, 24.766482040286064, 40.358899757266045, 48.241143599152565, 60.84501788020134, 65.11766821146011, 60.50598107278347, 56.55168145895004, 31.737700067460537, 2.68993669655174, 5.3077656123787165, 28.87508187443018, 22.015064880251884, 13.778823483735323, 10.449918061494827, 3.504223977215588, 28.698739036917686, 19.386333636939526, 18.199018947780132, 21.04092825204134, 19.007938541471958, 14.872301258146763, 13.838300742208958, 1.2503313389606774, 2.6093634450808167, 3.4588064393028617, 2.0262923324480653, 2.927599693648517, 3.7329852394759655, 4.142162958160043, 1.1015262175351381, 0.3237992094364017, 0.7092593726702034, 0.33277907758019865, 8.242344819009304, 8.292438481003046, 0.8468306344002485, 1.9703311915509403, 12.950134500861168, 1.4440399571321905, 0.24122489034198225, 0.4023571440484375, 5.764824561774731, 3.1856987066566944, 6.321277152746916, 3.3203212078660727, 2.3335863556712866, 3.7404432892799377, 1.740146311931312, 1.2779287830926478, 3.0719152372330427, 1.0633820830844343, 0.6089739664457738, 0.28970298590138555, 0.5595120799262077, 0.9412391216028482, 5.865615103393793, 5.609916374087334, 12.722808849066496, 27.32075247913599, 36.41520917415619, 32.84775160253048, 45.67161127924919, 25.84479197859764, 5.071129035204649, 15.922245718538761, 19.15549222379923, 17.992180846631527, 10.142245721071959, 5.948371337726712, 8.864896763116121, 21.929354779422283, 29.587254859507084, 24.21175930649042, 20.0414127856493, 17.021302543580532, 18.87859158217907, 2.7919512474909425, 0.7966126478277147, 4.092625016346574, 4.201847305521369, 35.670673325657845, 55.12273393571377, 53.321976363658905, 58.601975440979004, 61.74590013921261, 56.35911539196968, 59.97435159981251, 51.53931722044945, 60.15910528600216, 55.022727102041245, 62.7470438182354, 21.72174721956253, 11.336342096328735, 0.35795150964986533, 13.324744999408722, 55.275018364191055, 43.88174772262573, 22.229223288595676, 30.702855996787548, 79.77211385965347, 38.003398552536964, 30.100478120148182, 41.258239299058914, 44.40124064683914, 40.59273920953274, 43.02478350698948, 37.57770739495754, 49.442578330636024, 49.3045849353075, 46.605262979865074, 49.56626549363136, 40.16963951289654, 54.741367399692535, 62.57785029709339, 83.17900344729424, 58.2735438644886, 1.0424770298413932, 0.3266292857006192, 0.3167851420585066, 0.18880141898989677, 0.2397202156134881, 0.16359720815671608, 0.14124320063274354, 0.11911542940651998, 0.27315508166793734], [0.08114210766507313, 0.08241941060987301, 0.06969016045331955, 0.035783429484581575, 0.0894109983346425, 0.11784816771978512, 0.07051183667499572, 0.15872726478846744, 0.03530419875460211, 0.07967429541167803, 0.13670395826920867, 0.050585909993969835, 0.2327577126561664, 0.10222811135463417, 12.844463121145964, 74.94163066148758, 57.64308549463749, 49.511035457253456, 26.330193132162094, 46.40887051820755, 40.775380209088326, 34.089616164565086, 47.15663619339466, 43.1144966930151, 35.6449069082737, 41.847329288721085, 33.490578308701515, 45.620884001255035, 25.627432242035866, 16.73736847937107, 48.321475088596344, 63.42152662575245, 14.234647024422884, 42.27656565606594, 21.251326762139797, 0.1723278037388809, 0.1410718832630664, 1.6343534574843943, 19.604365937411785, 35.01731738448143, 48.29520709812641, 56.12975209951401, 60.50853833556175, 48.752223774790764, 47.019463554024696, 51.2394031137228, 47.28771016001701, 54.92271646857262, 36.210472360253334, 5.636923899874091, 0.9701515920460224, 5.537965809926391, 10.839706845581532, 23.900567404925823, 6.018962049856782, 8.85673575103283, 4.706906229257584, 1.925390053074807, 0.33254016540013254, 12.332527991384268, 19.850936606526375, 17.262534499168396, 8.257028181105852, 7.490861043334007, 2.699706209823489, 15.910267811268568, 10.410713665187359, 0.9672663593664765, 4.759129676967859, 4.047347595915198, 10.255017969757318, 10.998740661889315, 6.42693760804832, 2.8038498340174556, 0.31632189347874373, 0.19361828395631164, 0.19483798881992698, 0.0851853059430141, 0.0911635800730437, 0.2513478440232575, 0.08289692326798104, 0.022686163138132542, 0.04069383845489938, 0.1463234389666468, 0.06393848627340049, 1.6566267935559154, 2.5682059535756707, 0.2218869116040878, 7.187161864712834, 5.0366568099707365, 0.23597755003720522, 0.40828639932442456, 0.8898976421914995, 0.9250037802848965, 0.1509797031758353, 0.25182338256854564, 0.26254320109728724, 0.6632450292818248, 0.1699663937324658, 0.6280833191704005, 0.10962365748127922, 0.12310429505305365, 0.1175776103627868, 0.016362591813958716, 0.1265037470147945, 0.331134686130099, 3.94181942101568, 4.172291066497564, 6.21062234044075, 23.93287517130375, 19.608475416898727, 24.21227987855673, 12.155220955610275, 32.40798220038414, 15.851910542696714, 3.1329694110900164, 12.551673632115126, 11.528176702558994, 15.683860760182142, 14.34568751603365, 5.346056157723069, 0.8307146304287016, 2.592599932104349, 2.085546590387821, 4.134679734706879, 0.6317496474366635, 4.19365257024765, 5.085999062284827, 7.256507193669677, 4.068047935143113, 7.753866305574775, 49.066470712423325, 50.062762051820755, 42.005070224404335, 43.00913214683533, 67.18871667981148, 49.54016849398613, 50.106547102332115, 49.23308417201042, 50.607193037867546, 46.25081039965153, 43.04356589913368, 25.614028461277485, 2.335974290035665, 1.3697436125949025, 15.616396330296993, 33.789637461304665, 20.281537100672722, 44.849160611629486, 60.213176384568214, 77.93938100337982, 33.57171155512333, 19.717105887830257, 35.54579682648182, 30.48286870121956, 29.54072255641222, 33.847006782889366, 31.400563158094883, 44.61416222155094, 28.317799977958202, 51.271777376532555, 61.99272349476814, 25.181391276419163, 35.829588398337364, 51.34534902870655, 65.84936454892159, 9.35535354539752, 0.030873332216287963, 0.2668678143527359, 0.0443399135110667, 0.04926670539134648, 0.013925117236794904, 0.042696479431469925, 0.11808268638560548, 0.10020003697718494, 0.03559140990546439, 0.0652593829727266, 0.04883406298176851, 0.1069817750249058, 0.06902981229359284, 0.026583444050629623, 0.193882547901012, 0.05626315047265962, 0.09508523682598025, 0.06329502939479426, 0.08097582205664366, 0.1699879308580421, 0.16531615576241165, 0.36632263858336955, 0.4450849606655538, 18.708123229444027, 86.22510999441147, 68.03691476583481, 29.85285870730877, 32.74044916033745, 51.75584100186825, 31.050043366849422, 41.30137458443642, 39.94214192032814, 40.184747502207756, 41.24697670340538, 37.48970791697502, 38.977772668004036, 42.44276113808155, 35.685895308852196, 27.305184714496136, 53.889164328575134, 60.11834867298603, 19.052443653345108, 50.60428239405155, 25.715144835412502, 4.501186218112707, 0.34602080297190696, 2.2756169037893414, 20.944221541285515, 39.885266572237015, 52.38418288528919, 63.76090541481972, 65.02440601587296, 54.70269687473774, 52.626571878790855, 55.84877997636795, 50.93008831143379, 57.085378021001816, 41.905416771769524, 8.074776660650969, 4.04154815711081, 17.62499514967203, 23.08549404144287, 32.681320533156395, 11.90812211483717, 13.709277715533972, 5.120134055614471, 1.2130515393801033, 0.839461701689288, 17.91491199284792, 23.794427700340748, 21.192697808146477, 12.134298328310251, 25.07085330784321, 7.559131504967809, 15.423268843442202, 14.184750001877546, 7.3307993821799755, 7.491719322279096, 7.911696536466479, 14.707207717001438, 11.112694647163153, 10.952631086111069, 3.148446218110621, 0.24250726215541363, 0.17708479223074391, 0.03385658776096534, 0.041759863088373095, 0.1363175516598858, 0.5285538942553103, 0.12082740082405508, 0.1098676904803142, 0.08120565034914762, 0.2012464340077713, 0.045881710466346703, 0.8342731394805014, 1.7762352316640317, 1.2107597873546183, 4.415601035580039, 5.867338785901666, 1.2398906867019832, 3.3046824345365167, 4.017736259847879, 1.0121254459954798, 0.16752817144151777, 0.5433483410160989, 0.20406141498824582, 0.19743301207199693, 0.07661340379854664, 0.19532431819243357, 0.05083554620796349, 0.10894138627918437, 0.08156940661137924, 0.05130341094627511, 0.08402543302509002, 0.5378943867981434, 4.795483751222491, 4.67994905076921, 6.990176634863019, 29.288986064493656, 23.426719531416893, 26.213963069021702, 19.410095661878586, 28.307998403906822, 15.045130234211683, 8.779566641896963, 21.057552359998226, 14.213191475719213, 16.61653496325016, 17.565038166940212, 9.723703879863024, 1.4946043188683689, 2.497606216929853, 2.127728364430368, 5.3066042996943, 1.850799461826682, 7.384566022083163, 10.956806112080812, 9.990537911653519, 4.060204206034541, 8.880765661597252, 51.61303326487541, 50.25930270552635, 45.125648975372314, 44.214868247509, 65.99151492118835, 54.55865040421486, 57.26433701813221, 56.03376545011997, 55.91059885919094, 49.82609935104847, 45.28196878731251, 27.502582222223282, 2.098544742912054, 3.022305336780846, 20.02585642039776, 35.8044071495533, 21.729451306164265, 39.88318808376789, 65.09923160076141, 105.5343134701252, 44.34389032423496, 28.346545435488224, 29.24710851162672, 33.08906525373459, 25.862514227628708, 35.29861629009247, 25.52767239511013, 37.83593013882637, 27.586747705936432, 40.33606678247452, 67.16925412416458, 19.365873634815216, 37.920323610305786, 57.61380046606064, 74.1380649805069, 11.034686733037233, 0.04689415203756653, 0.36474302178248763, 0.025372177406097762, 0.0745971295691561, 0.030399650895560626, 0.023907033173600212, 0.10129805930773728, 0.07943268181406893, 0.02339514237974072, 0.22184791916515678, 0.16390077624237165, 0.3239316976396367, 0.2260800014482811, 0.2257241861661896, 0.3649819636484608, 0.1328847772674635, 0.2339800595655106, 0.2012717115576379, 0.20114161306992173, 0.3814405726734549, 0.35221776575781405, 0.6503121857531369, 0.9252729127183557, 24.898152574896812, 94.79703962802887, 78.4789976477623, 64.6232083439827, 35.4910683631897, 67.71751910448074, 52.89925664663315, 49.93008077144623, 65.81046983599663, 56.22307889163494, 50.634760558605194, 53.57674889266491, 49.26926203072071, 60.13482078909874, 35.94972275197506, 22.1112073212862, 48.68552975356579, 66.94561332464218, 20.11994317173958, 52.57372051477432, 28.544524312019348, 3.3221778832376003, 0.32431687228381634, 3.4218641091138124, 24.691768549382687, 46.509599313139915, 57.23773844540119, 69.02752161026001, 72.27800399065018, 59.138062074780464, 59.507345259189606, 57.5744915753603, 56.768285036087036, 59.943546652793884, 44.37100566923618, 6.807319046929479, 2.73392076138407, 12.238896265625954, 21.81736148893833, 32.30733700096607, 11.104202102869749, 15.622274614870548, 8.902115765959024, 4.2231703363358974, 0.6996273645199835, 15.425474625080824, 30.328676775097847, 24.373944103717804, 13.918640781193972, 17.514377385377884, 5.845335591584444, 23.85976519435644, 22.44629994034767, 12.579755075275898, 13.8890384696424, 12.485270295292139, 19.387636967003345, 17.079735808074474, 15.905602611601353, 5.376512473449111, 0.7252780068665743, 0.48717090860009193, 0.31551458523608744, 0.17324604821624234, 0.2080271256272681, 1.0432781931012869, 0.42541914561297745, 0.33723193395417184, 0.29420871287584305, 0.3835728520061821, 0.10206756254774518, 10.670306235551834, 12.410038132220507, 0.8015751221682876, 14.444677904248238, 11.111608855426311, 1.204245036933571, 1.1288024601526558, 6.16162539459765, 5.063956920057535, 2.555320607498288, 1.65600968291983, 0.591810584301129, 0.674403605517, 1.9206938613206148, 1.877378085628152, 0.36180343420710415, 0.42353230935987085, 0.14799727883655578, 0.13005701650399715, 0.26225088397040963, 0.6924958003219217, 4.386066170409322, 8.39636480435729, 12.107832748442888, 29.64294657111168, 28.04017547518015, 32.88132280111313, 20.71231998503208, 38.552750274538994, 19.64288257062435, 4.699043026193976, 16.670777052640915, 19.87593736499548, 22.90936779230833, 23.180872723460197, 8.912287820130587, 2.215164047665894, 3.2950805872678757, 6.875444641336799, 9.304122794419527, 2.422273834235966, 8.657329101115465, 9.394914172589779, 10.891745053231716, 6.572635089978576, 8.716186042875051, 53.4551440179348, 52.760704681277275, 49.15682606399059, 53.073887676000595, 67.20507860183716, 55.134300515055656, 63.605273365974426, 58.59252914786339, 61.55834600329399, 53.55686455965042, 52.97590993344784, 34.31609161198139, 3.319591172039509, 2.8157082851976156, 21.407840363681316, 40.06359480321407, 25.606759451329708, 57.57688544690609, 62.96989805996418, 86.74644201993942, 42.10466668009758, 27.67786491662264, 43.81638742983341, 41.83689884841442, 37.343153581023216, 45.82095846533775, 39.46820855140686, 63.412243723869324, 40.01003287732601, 61.928856521844864, 81.06927305459976, 33.36471006274223, 51.35676361620426, 62.46048219501972, 96.54197439551353, 16.941356733441353, 0.18159412604290992, 0.36263968620914966, 0.2654288790654391, 0.18369645229540765, 0.1415742133394815, 0.22356640663929284, 0.1281210797606036, 0.1334748588851653, 0.26610628177877516], [0.06366821093251929, 0.03614527471654583, 0.062488018011208624, 0.057544023147784173, 0.01349005542579107, 0.01986261962883873, 0.09796576428925619, 0.0696971663273871, 0.01910670140205184, 0.0443299538892461, 0.004371938621261506, 0.05232524068560451, 0.06053122320736293, 0.327817196957767, 0.5553044588305056, 64.20164376497269, 64.81636717915535, 59.079150035977364, 38.72216418385506, 30.24939402937889, 42.194376066327095, 31.61947511136532, 40.68673096597195, 48.20193350315094, 35.169693008065224, 41.62849523127079, 37.115541994571686, 40.20266354084015, 33.835652992129326, 25.242408402264118, 23.065140433609486, 41.09725333750248, 53.10948796570301, 9.053680133074522, 32.27688543498516, 24.112077355384827, 2.310379813425243, 1.6920525301247835, 8.68695991113782, 40.260542035102844, 61.930125653743744, 53.01052987575531, 57.98770420253277, 52.298356890678406, 54.50512647628784, 51.24405026435852, 48.03101867437363, 50.87040111422539, 41.98294021189213, 22.24210649728775, 3.472410896793008, 2.6606067828834057, 11.958229076117277, 11.897963359951973, 2.6293745962902904, 1.4727620221674442, 0.13203259877627715, 4.522768585011363, 18.139901719987392, 20.822151191532612, 13.813681863248348, 9.754080399870872, 9.551046844571829, 4.2759794276207685, 12.699925526976585, 16.92725758999586, 2.8320770943537354, 2.1304359566420317, 3.565632957033813, 6.582683175802231, 13.458028547465801, 8.710722886025906, 11.050434987992048, 0.9484497096855193, 0.3445767913945019, 0.1889883808325976, 0.22736028040526435, 0.03060919072595425, 0.01578815466928063, 0.06038571402314119, 0.04418586220708676, 0.27069987903814763, 0.047010891867103055, 0.039917993562994525, 0.21975527051836252, 0.22733797144610435, 4.490436594933271, 0.6154241203330457, 2.8564511239528656, 4.618579493835568, 0.9714333107694983, 4.367605336010456, 1.711627773474902, 1.7640963080339134, 0.23677915858570486, 0.0741012413345743, 0.11452551319962367, 0.11556702840607613, 0.03863748082949314, 0.12290698025026359, 0.21186892729019746, 0.03271158377174288, 0.010547720976319397, 0.04285829360014759, 0.18116494204150513, 0.5212763941381127, 4.834323842078447, 7.6757272984832525, 5.138489445671439, 16.006441600620747, 20.998560525476933, 15.343231838196516, 18.142992854118347, 9.130140580236912, 19.24361139535904, 9.96112558990717, 3.1325701950117946, 8.550910111516714, 11.13281836733222, 13.655223716050386, 16.7939892411232, 15.045718252658844, 2.4793878570199013, 0.24525822547730058, 1.4480081317014992, 1.8998588668182492, 0.9548159118276089, 4.141452871263027, 19.119112975895405, 6.150697655975819, 9.067947417497635, 52.98262797296047, 42.14194267988205, 56.902999207377434, 40.755435079336166, 50.13453260064125, 53.265800178050995, 48.94658714532852, 51.99348405003548, 52.34246112406254, 47.22536310553551, 27.063905261456966, 7.793017029762268, 0.9494229918345809, 2.6503850938752294, 37.67289988696575, 64.79967847466469, 99.13146704435349, 38.101326897740364, 24.747002385556698, 59.634266048669815, 17.165744192898273, 24.42506466060877, 31.60501878708601, 25.205924659967422, 43.567709773778915, 30.450201854109764, 30.6703582406044, 34.08101722598076, 32.136376574635506, 86.64141565561295, 32.43368022143841, 31.6376818343997, 44.06950704753399, 63.14392492175102, 31.512309461832047, 1.1605476192198694, 0.2358332320000045, 0.21088328096084297, 0.00260221837379504, 0.1002955216972623, 0.03420216882659588, 0.1024127948039677, 0.01371588075926411, 0.10283768177032471, 0.08494803390931338, 0.06086056979256682, 0.06031819342751987, 0.03509808208036702, 0.05578604599577375, 0.050058276392519474, 0.059361899038776755, 0.08100640596239828, 0.01851670884207124, 0.031001378665678203, 0.005491667843671166, 0.05263002960418817, 0.0918133526283782, 0.08909323296393268, 0.31741445360239595, 0.5756832403130829, 71.57634124159813, 76.26316174864769, 52.09120340645313, 26.15325752645731, 40.659896805882454, 34.67609949409962, 30.710594281554222, 39.2646686732769, 39.06674109399319, 38.6812973767519, 38.966426476836205, 40.56538067758083, 38.139237463474274, 34.70256507396698, 35.216369703412056, 22.34431531280279, 36.70487903058529, 45.5109217017889, 11.27043653279543, 29.695562347769737, 32.442989721894264, 6.481592925265431, 2.1522265998646617, 6.763041447848082, 41.34047448635101, 67.20611214637756, 57.388578951358795, 62.085081338882446, 57.038024961948395, 57.414311170578, 54.749445766210556, 53.32500100135803, 58.43057043850422, 45.51144987344742, 26.251398660242558, 3.9917295053601265, 8.240679558366537, 19.779872819781303, 16.190230138599873, 7.399482121691108, 3.3222415298223495, 0.5106523423455656, 6.869078082963824, 23.906282298266888, 27.851338908076286, 19.00060683488846, 15.115527156740427, 24.727870412170887, 10.18436836078763, 11.103094462305307, 22.873537614941597, 4.295265767723322, 8.117429371923208, 4.753881683573127, 11.767101231962442, 17.04201903194189, 10.119270253926516, 13.395932279527187, 1.266418844461441, 0.4082861024653539, 0.06192405257024802, 0.15735147142549977, 0.12268553822650574, 0.017047132132574916, 0.125129378575366, 0.021082118546473794, 0.06903066576342098, 0.04044040615553968, 0.1762402875465341, 0.07728811993729323, 0.2283350913785398, 0.31704533903393894, 0.5265340057667345, 2.2311716387048364, 4.108491539955139, 6.433484656736255, 9.506668075919151, 4.609833313152194, 0.5192439188249409, 0.08583127870224416, 0.017720675677992404, 0.09697147193946876, 0.0699103185615968, 0.030216898885555565, 0.06788943559513427, 0.05641463394567836, 0.04932044059387408, 0.03993361577158794, 0.008150413286784897, 0.41141680791042745, 0.810204102890566, 4.433923652395606, 4.958817036822438, 3.2502085575833917, 20.146178863942623, 27.291963323950768, 16.3673310354352, 25.650629997253418, 13.015329502522945, 23.810582533478737, 11.162055898457766, 11.081630364060402, 20.93138962984085, 16.018633246421814, 16.99192252010107, 19.768178947269917, 22.477652058005333, 5.478346534073353, 0.8372737909667194, 0.6545609515160322, 1.941516031511128, 2.34016427770257, 7.196524562314153, 19.22923106700182, 7.498987857252359, 11.28530703485012, 56.30599424242973, 48.51450473070145, 59.205067679286, 47.12327778339386, 50.84935024380684, 56.52649261057377, 52.674601301550865, 56.97506234049797, 58.56157600879669, 50.74756130576134, 28.13594363629818, 12.265188954770565, 3.5040123760700226, 3.0668387096375227, 42.751540169119835, 66.77353575825691, 86.23687416315079, 40.88343881070614, 23.05718746036291, 72.10236981511116, 20.845297649502754, 27.29291707277298, 28.595319986343384, 29.216875433921814, 34.137911573052406, 30.41691944003105, 21.93464409559965, 35.65354384481907, 26.958232931792736, 88.43490421772003, 33.7595696747303, 23.996892236173153, 50.373748764395714, 69.91424202919006, 39.47239592671394, 1.108350888825953, 0.18018765229498968, 0.3486464620800689, 0.029379446459643077, 0.05894304944376927, 0.07968504171003588, 0.0688281559268944, 0.05264458683086559, 0.10955430378089659, 0.04774617467774078, 0.12974203418707475, 0.1253745099529624, 0.25858244800474495, 0.09618185649742372, 0.10284428688464686, 0.22023950703442097, 0.24151820194674656, 0.1366345229325816, 0.18413523968774825, 0.10248899852740578, 0.10789059422677383, 0.25812905514612794, 0.3321939386660233, 0.4990187322255224, 1.5504209487698972, 84.25259783864021, 84.74258154630661, 78.3016611635685, 53.75367499887943, 41.97258956730366, 59.810451194643974, 44.85816232860088, 59.77892808616161, 62.751337587833405, 48.85849267244339, 58.31553541123867, 53.45689192414284, 58.4490792453289, 45.48427753150463, 36.29762828350067, 30.63865654170513, 50.187349766492844, 60.18130749464035, 13.774126935750246, 37.1146984398365, 34.06565465033054, 4.9598239827901125, 2.2959379758685827, 11.289000436663628, 46.2261763215065, 74.91998702287674, 62.22208298742771, 69.88679990172386, 60.634038001298904, 66.20069369673729, 57.52800866961479, 59.697088077664375, 60.002648681402206, 50.01477062702179, 30.574618577957153, 6.05324856005609, 4.5951551757752895, 14.90992208942771, 16.829526834189892, 5.5069684982299805, 6.010150322690606, 1.0061767464503646, 6.647825455293059, 26.017249524593353, 33.67609575390816, 19.4689754024148, 17.404622174799442, 18.549388647079468, 5.509107308462262, 17.10759211331606, 28.740242309868336, 9.617362786084414, 13.452838025987148, 9.123555533587933, 17.5743305683136, 20.012933313846588, 14.16853817179799, 19.80227831751108, 1.88831354258582, 1.0856004408560693, 0.2446419163607061, 0.32444027659948915, 0.327586003113538, 0.21229183272225782, 0.32454776926897466, 0.17905976594192907, 0.43255759694147855, 0.17015705147059634, 0.3934777033282444, 0.38868334027938545, 0.8925897383596748, 11.806139387190342, 0.47320256126113236, 7.357011325657368, 14.670235700905323, 5.454786848276854, 9.962164834141731, 16.319478303194046, 8.856104034930468, 0.47894865449052304, 0.1384732234873809, 0.35790433874353766, 0.4014919779729098, 0.3127163619501516, 0.27104759006761014, 0.39442533685360104, 0.14479596546152607, 0.11959512397879735, 0.14702996355481446, 0.5995748145505786, 0.7489188539329916, 9.995563142001629, 12.417856212705374, 12.673819977790117, 24.022844843566418, 29.095751233398914, 20.417685694992542, 29.719537161290646, 18.37639532983303, 30.57475347071886, 12.621422689408064, 5.915337335318327, 12.59406890720129, 14.495493527501822, 20.672997795045376, 28.457305692136288, 27.181469053030014, 6.1974408477544785, 0.7071045914199203, 2.5305302627384663, 5.03575530834496, 4.8030035477131605, 6.836503855884075, 30.959176942706108, 10.082719065248966, 12.703554332256317, 63.20199340581894, 49.03875879943371, 61.20600610971451, 51.78239777684212, 59.96807813644409, 58.454987928271294, 57.84740053117275, 62.18707166612148, 61.26803398132324, 55.52514374256134, 34.826712012290955, 12.42762453854084, 2.858622232452035, 4.067361121997237, 46.00258491933346, 81.37457147240639, 115.4376232624054, 49.969043880701065, 27.343602553009987, 62.52999186515808, 23.151576295495033, 30.093853175640106, 42.018171921372414, 35.03578059375286, 54.35034938156605, 41.22840330004692, 40.881531313061714, 50.35371623933315, 42.13497385382652, 104.09435793757439, 45.27165234088898, 42.675092071294785, 62.80473992228508, 78.87838661670685, 60.91717980802059, 1.5147777926176786, 0.3361952130217105, 0.5845891905482858, 0.22932992549613118, 0.16650546225719154, 0.16962223016889766, 0.12489730899687856, 0.22107311699073762, 0.27188122970983386, 0.16286645986838266], [0.025909590658557136, 0.020433600220712833, 0.056260898054460995, 0.014288333586591762, 0.039602239412488416, 0.07284515639184974, 0.07151513127610087, 0.014535318478010595, 0.07223050226457417, 0.07567460925201885, 0.032962990007945336, 0.14580255519831553, 0.06670148723060265, 0.29207328683696687, 0.042579965956974775, 16.993812918663025, 78.69813948869705, 55.42455554008484, 47.809699550271034, 34.3304206430912, 44.49205957353115, 42.2211342304945, 36.52563504874706, 46.20308876037598, 38.04205007851124, 35.26507169008255, 36.82474359869957, 36.659889444708824, 38.9534729719162, 24.96460910886526, 25.58913979679346, 17.770903520286083, 53.759663477540016, 75.40146678686142, 58.03637579083443, 92.60125905275345, 27.37603761255741, 0.9572912415023893, 3.724663923494518, 24.207047559320927, 48.25041130185127, 53.00754323601723, 60.36213219165802, 55.65692447125912, 52.88889840245247, 53.55825908482075, 52.449752166867256, 50.76903775334358, 52.69372567534447, 51.05994634330273, 11.31250312551856, 11.572176441550255, 4.4001211412251, 5.2088687941432, 9.092388655990362, 4.190075537189841, 8.882144037634134, 23.78680530935526, 23.023532666265965, 14.641476944088936, 10.908100325614214, 13.21570985019207, 4.285776726901531, 14.230790231376886, 11.775191947817802, 8.83507976308465, 6.658178949728608, 2.2750419471412897, 1.2716550822369754, 11.003045830875635, 14.810365531593561, 9.765859767794609, 8.073708917945623, 0.8860052854288369, 0.30854329525027424, 0.0728715694276616, 0.16371719859307632, 0.0500679651304381, 0.06101496248447802, 0.09732213671668433, 0.06803036943892948, 0.11465805335319601, 0.06120688558439724, 0.22013853042153642, 0.10579945956123993, 0.19217709254007787, 0.10542449686909094, 2.5818232353776693, 1.4938694145530462, 4.873959515243769, 3.8758872589096427, 11.373562049120665, 2.561334972269833, 0.07531054128776304, 0.05298288000631146, 0.061389869515551254, 0.015450442224391736, 0.09080460324184969, 0.03845482715405524, 0.2736120665213093, 0.0172739435947733, 0.06430659894249402, 0.05755799407779705, 0.10096723213791847, 0.07715301937423646, 0.16036830173106864, 0.8861952752340585, 2.756026550196111, 0.8987876807805151, 10.290963090956211, 11.255492884665728, 12.072566840797663, 8.606629371643066, 9.78919431567192, 4.477018564939499, 20.24715654551983, 13.952045738697052, 4.118881607428193, 7.440800629556179, 15.079744476824999, 16.753122434020042, 19.103797897696495, 25.053020864725113, 15.271311197429895, 2.7901223581284285, 0.6314430513884872, 4.371240790933371, 8.254422470927238, 7.818801021203399, 2.810763088054955, 13.577687926590443, 57.23492279648781, 41.75521083176136, 53.86743329465389, 48.57010714709759, 46.700645461678505, 49.05225567519665, 48.93572732806206, 48.76380555331707, 52.991093918681145, 53.12994606792927, 24.990635812282562, 14.694879278540611, 1.786015669349581, 21.489919759333134, 66.71192586421967, 53.23946759104729, 53.52924384176731, 68.51161569356918, 37.86518096923828, 15.172667540609837, 24.659500680863857, 26.986144334077835, 33.27699176967144, 28.47740851342678, 38.417367339134216, 25.841554552316666, 37.130049616098404, 34.575123712420464, 58.6942382901907, 62.047486156225204, 30.3219036385417, 47.260055243968964, 46.21315062046051, 76.66610732674599, 7.010517893359065, 0.21412257745396346, 0.2078299518325366, 0.22059576760511845, 0.06031519515090622, 0.027917844126932323, 0.07625295751495287, 0.04665570369979832, 0.05597635492449626, 0.10466690509929322, 0.019727797371160705, 0.041361162802786566, 0.03928701960830949, 0.03614307424868457, 0.014407398193725385, 0.06973019932047464, 0.06675875134533271, 0.08918617211747915, 0.05616965841909405, 0.04528036675765179, 0.07878391857957467, 0.12126644054660574, 0.08495433474308811, 0.07112931838491932, 0.4110153653891757, 0.16487652232171968, 21.260681860148907, 86.65325582027435, 63.01657475531101, 38.70663061738014, 35.67737236618996, 45.4338314384222, 37.58405685424805, 38.81285011768341, 36.944140791893005, 37.68595598638058, 36.08640901744366, 34.997444450855255, 37.64547295868397, 35.4049763828516, 32.80040614306927, 29.684869721531868, 21.975355111062527, 45.286125764250755, 60.24623081088066, 59.202153235673904, 81.33614033460617, 39.84842374920845, 2.3314948054030538, 2.4762430507689714, 29.38958566635847, 51.762338653206825, 57.08606198430061, 63.884163200855255, 60.59903807938099, 56.371878907084465, 57.381306141614914, 54.7589186578989, 50.84220662713051, 54.694219529628754, 51.2001284211874, 10.899496637284756, 16.513423696160316, 10.478281639516354, 7.793403184041381, 5.386348720639944, 2.2697481187060475, 11.386415809392929, 28.960178308188915, 27.92882815003395, 20.593735948204994, 18.4833025932312, 29.04245149344206, 13.13963983207941, 15.306153427809477, 13.681598100811243, 12.765015084296465, 5.856501292437315, 8.594754058867693, 6.823617797344923, 16.97910200804472, 19.5699492841959, 10.63819320872426, 8.900427706539631, 0.7135443552397192, 0.14651032659457996, 0.1705539965769276, 0.13922197627834976, 0.06952428302611224, 0.05211105315538589, 0.2833911089692265, 0.010236893758701626, 0.137936279643327, 0.053134905247134157, 0.35298951028380543, 0.051376590417930856, 0.04355479919468053, 0.07862232334446162, 2.529103201813996, 2.2588500659912825, 2.9749299539253116, 13.065108731389046, 10.907880887389183, 2.095283567905426, 0.3129701764555648, 0.10422192819532938, 0.010784692440211074, 0.09783833011169918, 0.038414109221776016, 0.05063023476395756, 0.16006825142540038, 0.08975718796136789, 0.042508597325650044, 0.09124755408265628, 0.16882416908629239, 0.07724563940428197, 0.3691535460529849, 1.6950810863636434, 2.6497538527473807, 2.8887382289394736, 12.400334402918816, 21.81439384818077, 14.569105077534914, 16.335511542856693, 14.45441298186779, 8.789518307894468, 19.835640527307987, 14.378873035311699, 9.74404038861394, 19.998497888445854, 24.250735715031624, 21.159812472760677, 25.24320635944605, 31.024022363126278, 17.615548856556416, 5.483363214880228, 1.562311698216945, 2.675576079636812, 6.243635918945074, 12.339168135076761, 6.614967668429017, 13.179026618599892, 62.41135083138943, 46.61625578999519, 57.49042108654976, 50.94877190887928, 51.80410221219063, 53.29467102885246, 54.143435284495354, 54.967854246497154, 57.558289244771004, 61.27446323633194, 32.566334903240204, 19.43279754370451, 3.95052214153111, 30.197416618466377, 63.84045794606209, 61.339956521987915, 59.6182157099247, 75.365429520607, 27.708141691982746, 4.217525264248252, 28.890927024185658, 25.99446214735508, 30.396847017109394, 26.503131352365017, 34.83533374965191, 21.1796835064888, 27.868413291871548, 36.98321029543877, 48.37526120245457, 84.2203451693058, 26.513426899909973, 42.62450538575649, 55.57790011167526, 82.18680828809738, 7.697093077003956, 0.2455670479685068, 0.2391876355977729, 0.16554960573557764, 0.10815021232701838, 0.0889660808024928, 0.06705880907247774, 0.02931866456492571, 0.016430618925369345, 0.08256568049546331, 0.05076758403447457, 0.08952134085120633, 0.09675004475866444, 0.10413854048238136, 0.07760579625028186, 0.14457669050898403, 0.1646699826233089, 0.24080581439193338, 0.24487107672030106, 0.11805465546785854, 0.23445743863703683, 0.22070146427722648, 0.2361954891239293, 0.31182937673293054, 0.7561983726918697, 0.38412958150729537, 31.48037977516651, 99.66109022498131, 73.31337243318558, 66.1077430844307, 48.97064745426178, 64.05037388205528, 56.44784823060036, 55.741378739476204, 60.59183366596699, 49.196959510445595, 51.52093380689621, 49.919752925634384, 53.00859197974205, 54.31426651775837, 34.33121100068092, 37.92245529592037, 23.885467015206814, 65.06184920668602, 83.90697598457336, 70.52294656634331, 101.30308851599693, 36.73561938107014, 2.236205656081438, 5.084619736298919, 32.44811564683914, 58.9445536583662, 61.857967525720596, 69.55446973443031, 64.89535734057426, 61.97101145982742, 64.89869356155396, 57.95390501618385, 59.731833413243294, 61.3619839400053, 55.46581752598286, 14.939742889255285, 23.929012678563595, 11.44568407908082, 11.136409174650908, 16.642639562487602, 9.234861060976982, 14.362975638359785, 34.59466226398945, 31.97420507669449, 21.865058429539204, 20.696277245879173, 22.66875710338354, 6.916512837633491, 20.05821168422699, 16.921198815107346, 14.938307516276836, 12.984872236847878, 10.045649204403162, 10.631288029253483, 18.681154176592827, 23.10179326683283, 14.116474315524101, 19.34239089488983, 0.6913908908609301, 0.4791189031675458, 0.29813850356731564, 0.3958616004092619, 0.21499523922102526, 0.19855067163007334, 0.4880138102453202, 0.26669717975892127, 0.5291298008523881, 0.2311209059553221, 0.8742711588274688, 0.6382724724244326, 0.21742268552770838, 0.11416347129852511, 9.601486288011074, 6.541068758815527, 14.742871653288603, 11.76704803481698, 16.867407001554966, 4.810957470908761, 0.3998924419283867, 0.4729600570863113, 0.18302442273125052, 0.40402507642284036, 0.20015133573906496, 0.13504990405635908, 0.4921623267000541, 0.2611517038894817, 0.28248031565453857, 0.16587937163421884, 0.3979971451917663, 0.13607086177216843, 0.8692252670880407, 1.7303093522787094, 14.824346881359816, 7.114161606878042, 18.44456747174263, 22.37754262983799, 17.932993322610855, 18.528104089200497, 19.32638805359602, 13.962864708155394, 28.58723971992731, 18.84683098644018, 5.020878156647086, 12.711142525076866, 20.756492614746094, 22.376484386622906, 29.06700387597084, 40.34822233021259, 21.571856662631035, 4.992417208850384, 2.480709236115217, 10.312261898070574, 14.662165883928537, 19.221065305173397, 6.903708474710584, 17.49502882361412, 66.37480795383453, 52.507949844002724, 62.756011337041855, 54.68668453395367, 53.79002004861832, 56.02471813559532, 56.86061628162861, 60.02276100218296, 64.89846557378769, 64.3519788980484, 33.06011840701103, 19.163559190928936, 3.0392666766420007, 27.90709901601076, 80.17648056149483, 64.58252772688866, 66.97091236710548, 77.03799337148666, 44.07476596534252, 16.96158304810524, 32.47154138982296, 34.48709763586521, 43.02276201546192, 37.926144897937775, 48.948965817689896, 34.16587807238102, 48.58980529010296, 52.15573914349079, 70.38189813494682, 87.82116115093231, 38.395765498280525, 64.70608189702034, 58.32904368638992, 103.22042763233185, 16.178030893206596, 0.37195773620624095, 0.4082595038926229, 0.43136707332450897, 0.21166290709516034, 0.1976917841238901, 0.271761417388916, 0.18577339709736407, 0.14810223336098716, 0.18669869197765365, 0.2596303605241701], [0.012916957857669331, 0.04215273009322118, 0.004910470197501127, 0.03905577010300476, 0.07108331265044399, 0.06944629814825021, 0.02148388019122649, 0.05483888373419177, 0.005439269898488419, 0.06369066089973785, 0.05359865848731715, 0.07331828295718879, 0.05017026276618708, 0.13533166784327477, 0.36527321208268404, 0.5266731732990593, 54.28348816931248, 73.88028681278229, 47.48015083372593, 29.0786312520504, 42.099696546792984, 35.60416929423809, 37.78782472014427, 49.45808529853821, 41.21916979551315, 34.804570600390434, 41.21637314558029, 33.999773785471916, 36.07275255024433, 31.73519980162382, 22.92921792715788, 16.287485919892788, 26.972381472587585, 64.79549869894981, 38.94553899765015, 57.34520807862282, 39.082749634981155, 4.54100095666945, 0.9543294191826135, 15.997437983751297, 44.34733293950558, 59.04585242271423, 52.8213532269001, 60.687900111079216, 47.69986264407635, 53.48199337720871, 51.01241089403629, 40.457557663321495, 47.347686141729355, 45.6207662075758, 7.869921578094363, 17.876800037920475, 20.941597782075405, 9.215253163129091, 5.955404285341501, 13.704734109342098, 35.729558765888214, 29.679420813918114, 18.131903149187565, 16.491187289357185, 18.81196405738592, 3.3575342735275626, 13.866663370281458, 22.624983452260494, 9.817011673003435, 14.52515758574009, 7.066770549863577, 3.5713991476222873, 2.595565435476601, 9.727621469646692, 19.72898595035076, 9.84564408659935, 6.130282301455736, 0.6140290014445782, 0.07790081479470246, 0.05890514425118454, 0.49221614724956453, 0.07713152677752078, 0.03585302067222074, 0.153068937943317, 0.09849277819739655, 0.07835486074327491, 0.33424336463212967, 0.5059512227308005, 0.7389937865082175, 0.0443620888836449, 0.031576097826473415, 0.3504513355437666, 0.5281333636958152, 0.9790955996140838, 14.702869299799204, 7.372255157679319, 1.1054434510879219, 0.06646418551099487, 0.047943066456355155, 0.023560743356938474, 0.0743302606861107, 0.06280711924773641, 0.09738940498209558, 0.07446972507750615, 0.1569447893416509, 0.026438972017786, 0.0619863150495803, 0.056065705794026144, 0.11995318054687232, 0.018102891008311417, 0.15036119730211794, 2.655743043869734, 3.411550037562847, 4.105208991095424, 11.047345753759146, 8.0900888890028, 3.41268427670002, 3.233939493075013, 12.978756465017796, 12.012807447463274, 28.054457008838654, 18.371014818549156, 5.687804594635963, 6.208555726334453, 18.477388210594654, 26.552255116403103, 30.27856506407261, 43.11700455844402, 35.898919478058815, 17.87491723895073, 0.7843687548302114, 9.487947430461645, 14.012480545789003, 6.3780480064451694, 4.120942996814847, 43.50350461900234, 42.803737968206406, 57.128030732274055, 48.47992658615112, 47.90386229753494, 46.38798303902149, 50.81332817673683, 52.50615254044533, 51.823188588023186, 48.278685584664345, 48.23952868580818, 41.26803897321224, 8.06348081678152, 39.9261561781168, 37.36579276621342, 49.469651877880096, 58.858476877212524, 39.271447509527206, 93.42858865857124, 63.18794175982475, 21.165743954479694, 35.76984040439129, 31.681846864521503, 28.79009373486042, 30.5781314894557, 27.4114878103137, 37.1027746796608, 35.433372259140015, 74.16472434997559, 29.622138887643814, 28.190075531601906, 45.682949870824814, 69.65774059295654, 34.53533984720707, 1.2792641739360988, 0.2860491257160902, 0.44117194251157343, 0.044775209098588675, 0.06799151058658026, 0.03831639434793033, 0.10532505650189705, 0.042852263650274836, 0.027328636388119776, 0.026918575676972978, 0.12088481336832047, 0.06049408242688514, 0.06390115624526516, 0.05239738486125134, 0.046816734902677126, 0.06731575544108637, 0.0647190326708369, 0.047547290232614614, 0.021127161344338674, 0.04621826701622922, 0.09131882252404466, 0.020575934868247714, 0.09182217676425353, 0.02331231127755018, 0.17296560545219108, 0.34523917303886265, 0.6739725661464036, 62.9518186300993, 82.56475880742073, 45.51316358149052, 23.626041635870934, 50.17432786524296, 32.21906013786793, 43.76702047884464, 38.43418903648853, 37.843172550201416, 38.13352257013321, 34.83908794820309, 37.85163089632988, 35.683889016509056, 33.7202113866806, 30.67755315452814, 16.377130709588528, 29.793437495827675, 64.29799899458885, 41.190443336963654, 62.01371356844902, 40.532478243112564, 5.026361737400293, 2.6988343941047788, 21.2361503764987, 49.521488696336746, 64.90710631012917, 60.20571358501911, 63.57511818408966, 56.535543724894524, 59.3506720662117, 53.56778137385845, 47.71869823336601, 49.864811673760414, 49.78004962205887, 7.43095250800252, 15.153255332261324, 18.453413397073746, 7.203385094180703, 3.428424457088113, 16.333592645823956, 39.214480966329575, 37.285544872283936, 25.79899113625288, 23.98413822054863, 32.25457303225994, 12.697958182543516, 16.994603276252747, 22.01089460402727, 12.15019952505827, 13.606204446405172, 7.70601024851203, 8.230029679834843, 13.020089697092772, 21.451197937130928, 20.503270402550697, 18.09246126562357, 7.036561220884323, 0.538869925076142, 0.17468893172917888, 0.02197181631345302, 0.8996228047180921, 0.17540020606247708, 0.020069751190021634, 0.031934670187183656, 0.05377897068683524, 0.05566240048210602, 0.3188094240613282, 0.8331190701574087, 0.7865962665528059, 0.027177559240953997, 0.16276247013593093, 0.7014119625091553, 1.3352247211150825, 2.668664725497365, 11.563441660255194, 10.528926271945238, 0.9074054996017367, 0.07808915703208186, 0.1638802484376356, 0.0547539560648147, 0.02703373658732744, 0.019941639802709688, 0.09534635406453162, 0.2309957056422718, 0.2723260730272159, 0.12547167192678899, 0.03691027683089487, 0.08476682371110655, 0.09407524805283174, 0.09800717612961307, 0.432350033079274, 1.7945344559848309, 6.2996297143399715, 6.082718353718519, 15.860991105437279, 15.406569689512253, 12.431525029242039, 12.093254830688238, 10.720011368393898, 10.910816229879856, 23.49722284823656, 16.5254994481802, 10.857007317245007, 16.441324464976788, 31.447357647120953, 34.80191074311733, 35.75369507074356, 45.60736432671547, 39.41838942468166, 20.251207128167152, 4.302585124969482, 2.674390780739486, 7.632972942665219, 3.422732837498188, 5.565865337848663, 45.0931379199028, 48.89752417802811, 63.09919372200966, 51.96048282086849, 53.69914032518864, 50.0704300403595, 56.5639092028141, 58.663691729307175, 58.49483259022236, 53.98863539099693, 56.19052603840828, 35.09451784193516, 4.899546392261982, 46.37331582605839, 45.34180797636509, 54.16317142546177, 63.55486147105694, 45.599806532263756, 92.40249171853065, 45.85956819355488, 23.481567688286304, 32.32909083366394, 29.913740940392017, 24.586001224815845, 29.123335853219032, 18.949999250471592, 35.167188942432404, 31.98600724339485, 81.65234416723251, 41.349248215556145, 18.73413473367691, 51.18078365921974, 76.38261213898659, 34.76338841021061, 1.1333489161916077, 0.21833328588400036, 0.4924238595413044, 0.031299451147788204, 0.09222792374202982, 0.06798926187912002, 0.10796098693390377, 0.04200876457616687, 0.037584239689749666, 0.061488252322305925, 0.18313047563424334, 0.1666358724469319, 0.1080603308218997, 0.12680970481596887, 0.18665149138541892, 0.17322706407867372, 0.2406686803442426, 0.1995204805280082, 0.15417926508234814, 0.19146167702274397, 0.1563159973011352, 0.19866275077220052, 0.20956743828719482, 0.25988269073423, 0.27030360186472535, 0.4368838429218158, 1.0999437212012708, 81.49968355894089, 89.45792332291603, 64.74342629313469, 38.689235150814056, 64.79628905653954, 48.377077504992485, 57.60550931096077, 68.84020686149597, 54.47302579879761, 49.51086826622486, 54.992062747478485, 50.24432770907879, 51.53952620923519, 40.6794011592865, 35.55409938097, 23.000597096979618, 33.632128313183784, 72.446099370718, 44.965764954686165, 69.0784540772438, 47.102606892585754, 6.37692516669631, 2.651006360538304, 23.24631091207266, 54.68724310398102, 67.84339115023613, 61.63196325302124, 69.44508880376816, 60.87240681052208, 62.923065572977066, 56.048140078783035, 51.85771353542805, 52.12283670902252, 53.32109101116657, 9.713359884917736, 28.354908786714077, 35.616488233208656, 23.389249742031097, 15.128363817930222, 17.677206248044968, 46.57026305794716, 41.44432291388512, 26.598097756505013, 28.234690837562084, 27.222845032811165, 7.037388626486063, 19.881019592285156, 27.985376715660095, 15.942624025046825, 19.506181105971336, 12.052503917366266, 10.038246251642704, 14.009775090962648, 22.58093811571598, 23.79098318517208, 20.2685683965683, 12.4493489228189, 1.1183036235161126, 0.5355078773573041, 0.20867297222139314, 0.7911173708271235, 0.23723888938548043, 0.2978179551428184, 1.040223988238722, 0.22692348196869716, 0.21768559876363724, 0.558811848750338, 1.4373201364651322, 1.3503222609870136, 0.1394698684453033, 0.3521692589856684, 3.49271890707314, 2.1841930970549583, 2.860847250558436, 26.597282700240612, 14.985629227012396, 2.229849072173238, 0.10275648339302279, 0.406784470542334, 0.3259314887691289, 0.14033366896910593, 0.2361187362112105, 0.47978802351281047, 0.3713106724899262, 0.5766628752462566, 0.29970116971526295, 0.14373899874044582, 0.3046647721203044, 0.21545498486375436, 0.22786152694607154, 1.1320681474171579, 5.775665855035186, 6.865483475849032, 13.73031908646226, 17.383238822221756, 16.486652232706547, 14.342610631138086, 13.975311890244484, 18.692935444414616, 15.354490634053946, 36.06517195701599, 20.253874585032463, 7.026169253513217, 8.378793597221375, 26.13606534898281, 35.868091732263565, 40.64972095191479, 51.07743300497532, 46.05959706008434, 22.035663574934006, 4.799925237894058, 21.906882785260677, 22.95662585645914, 12.951657269150019, 7.8686723951250315, 53.89550618827343, 47.54588730633259, 67.8803251683712, 57.995231598615646, 57.01328828930855, 54.728854671120644, 60.20809605717659, 63.05136948823929, 61.15243658423424, 58.04043397307396, 58.090937063097954, 45.48653461039066, 10.562470871955156, 46.222365126013756, 50.198688358068466, 58.25899064540863, 65.2672129869461, 52.03600376844406, 113.33975583314896, 79.75926294922829, 28.796359598636627, 45.34088082611561, 40.50059795379639, 37.220389768481255, 41.759580597281456, 36.737074702978134, 54.40455727279186, 48.584614768624306, 89.11785677075386, 48.1889533996582, 37.65823267400265, 61.29386119544506, 82.67793193459511, 58.80697064101696, 1.1318607022985816, 0.4524097207468003, 0.5397026741411537, 0.1583274401491508, 0.17771866056136787, 0.126132613804657, 0.20551385736325756, 0.14248092484194785, 0.14910625526681542, 0.16397672763559967, 0.28435429790988564], [0.06077719692257233, 0.023444973885489162, 0.08480631338898093, 0.060473588018794544, 0.02967714415717637, 0.025835516898951028, 0.1352846305235289, 0.08448702661553398, 0.05599638920102734, 0.045933007713756524, 0.09730940888402984, 0.046579310728702694, 0.05858964614162687, 0.1571529172360897, 0.5523744004312903, 0.20540790836093947, 19.51036088168621, 84.94320318102837, 60.39935879409313, 44.60305541753769, 33.049212992191315, 59.95341472327709, 28.319758772850037, 56.03583633899689, 42.573527321219444, 33.99819307029247, 34.46073845028877, 36.50580771267414, 33.024662509560585, 40.16115836799145, 23.956891782581806, 24.18754130601883, 40.84201343357563, 61.33519917726517, 54.46493983268738, 66.19979694485664, 52.69807644188404, 6.0668665543198586, 1.2161245057359338, 18.369519598782063, 54.31144326925278, 64.69209864735603, 60.30143044888973, 58.93689326941967, 51.484166979789734, 55.12154459953308, 45.4984849691391, 50.96423327922821, 56.61332555115223, 48.122008591890335, 9.021742846816778, 11.538693588227034, 14.661356527358294, 4.275569999590516, 24.285045973956585, 50.098590329289436, 42.93492592871189, 30.750978514552116, 29.052285365760326, 20.250222980976105, 3.7972001312300563, 14.854916241019964, 25.4724233597517, 19.287314750254154, 12.097901981323957, 16.053029000759125, 8.975638020783663, 10.804840866476297, 5.556952441111207, 11.731907520443201, 22.70301416516304, 9.39878711476922, 2.7325077122077346, 0.4770307964645326, 1.8643969134427607, 0.7490636024158448, 1.0889910464175045, 0.2159832455799915, 0.025020358589245006, 0.13949967309599742, 0.05468193434353452, 0.03939813766919542, 0.11955835798289627, 0.10570697311777622, 0.5103180196601897, 0.0446037915389752, 0.4038971004774794, 0.6481043854728341, 0.531866307137534, 0.4365158564178273, 12.569906003773212, 6.076530385762453, 0.10219542717095464, 0.10472265523276292, 0.02805265710776439, 0.10439039571792819, 0.10905395523877814, 0.03032692413398763, 0.061431689537130296, 0.12170481975772418, 0.12940014159539714, 0.04114454844966531, 0.07555718664661981, 0.02217717599705793, 0.13412446074653417, 0.02778322967060376, 0.14607397344661877, 2.07388857845217, 5.991671914234757, 2.8213939676061273, 9.955068714916706, 4.902350641787052, 4.665642818436027, 5.5902177561074495, 13.24539765715599, 15.742498263716698, 18.536967113614082, 24.058000557124615, 24.770901203155518, 9.045938048511744, 3.721916670911014, 17.42056041955948, 35.63562020659447, 44.043090865015984, 50.002580881118774, 63.89253795146942, 44.895054548978806, 8.056045565754175, 12.35834950581193, 13.271977230906487, 0.2517058263765648, 37.521971985697746, 50.74412629008293, 44.042387902736664, 54.203882440924644, 45.432949885725975, 46.8686268478632, 46.69828198850155, 41.61687545478344, 44.81314614415169, 46.98185697197914, 43.95268991589546, 17.517483718693256, 10.515948068350554, 58.17963570356369, 56.93072631955147, 47.9523590952158, 64.41698580980301, 62.25568078458309, 65.5864642560482, 70.77798128128052, 20.580258071422577, 37.038603723049164, 24.820712730288506, 34.64680306613445, 30.161217860877514, 32.72299289703369, 36.405455097556114, 64.17763665318489, 68.25482547283173, 16.77923083305359, 41.576286032795906, 48.07479612529278, 63.8228876888752, 3.7769139697775245, 0.13780551322270185, 0.3371718793641776, 0.07740252942312509, 0.1398430796689354, 0.10749527442385443, 0.03574258167645894, 0.047140281603788026, 0.02785567627142882, 0.04126451662159525, 0.08214295317884535, 0.07059725787257776, 0.059493504086276516, 0.03181938867783174, 0.10675115263438784, 0.02949614547105739, 0.07897755232988857, 0.010740238722064532, 0.03537949705787469, 0.055926530840224586, 0.05760271589679178, 0.03892776076099835, 0.1674819504842162, 0.03050008945137961, 0.08422585000516847, 0.19084872241364792, 0.6442020542453974, 0.13750270212767646, 22.13082756847143, 95.23672163486481, 65.64878851175308, 33.2120456546545, 37.416641637682915, 53.0940417945385, 29.091807045042515, 56.84572868049145, 28.816536515951157, 40.670342445373535, 32.6287579536438, 38.46187815070152, 34.42593231797218, 38.070217967033386, 31.544413939118385, 25.32828949391842, 38.47370691597462, 68.34342151880264, 54.22017216682434, 76.70926541090012, 48.259785398840904, 7.865541838109493, 1.821270058862865, 17.23314117640257, 60.53316481411457, 68.48215207457542, 64.49560359120369, 64.41216766834259, 53.94123673439026, 65.1551266014576, 53.142318204045296, 54.331061616539955, 61.02139301598072, 51.197723150253296, 9.546186905354261, 11.585565973073244, 1.6837420198135078, 3.6961457412689924, 26.292164772748947, 51.86411999166012, 49.62728641927242, 40.11476285755634, 32.028234377503395, 37.04331547021866, 15.104838330298662, 17.651892006397247, 21.638968661427498, 20.799637399613857, 12.4122828617692, 10.422014258801937, 9.75253103300929, 15.585921965539455, 16.33690796792507, 15.436782818287611, 29.074185490608215, 16.153915487229824, 4.44244422018528, 0.3246704611228779, 0.13480610854458064, 0.8211284573189914, 0.2517923607956618, 0.2763662952929735, 0.24025475489906967, 0.03835239964246284, 0.03587164857890457, 0.03900187904946506, 0.13092210836475715, 0.1584241123055108, 0.694185106549412, 0.026406432552903425, 0.8177268086001277, 3.0293439840897918, 0.4352017800556496, 0.6333681230898947, 2.5025946367532015, 6.915840273723006, 0.3224302438320592, 0.066755500738509, 0.08247946519986726, 0.0804128882009536, 0.102280202700058, 0.08979100763099268, 0.11034403796656989, 0.1685789634939283, 0.07006449231994338, 0.00541258737030148, 0.051442515396047384, 0.01821857142203953, 0.09606666775653139, 0.142679063428659, 0.11439792317105457, 1.496120437514037, 10.366484988480806, 5.8232806250452995, 12.138490453362465, 13.05952588096261, 11.268097758293152, 8.509078156203032, 13.952771499752998, 13.153112009167671, 18.404090143740177, 20.942042358219624, 21.549675352871418, 13.657504543662071, 12.564049568027258, 31.928884908556938, 43.17161902785301, 48.975161612033844, 53.48797045648098, 62.7172040194273, 45.4570671916008, 12.618035171180964, 9.191842619329691, 4.2370253428816795, 0.7399592315778136, 37.802738919854164, 63.88699024915695, 53.29133100807667, 57.9554895311594, 51.319008842110634, 49.74885709583759, 50.46226501464844, 48.78951117396355, 51.168875098228455, 54.33878280222416, 48.0774749815464, 17.983285523951054, 13.706275876611471, 63.36245119571686, 57.98050358891487, 54.641542956233025, 67.47690081596375, 65.19042670726776, 71.38830453157425, 73.80692034959793, 22.936488837003708, 30.872503593564034, 23.584794849157333, 28.398598842322826, 24.920945651829243, 26.548331826925278, 35.979980528354645, 61.241769790649414, 87.91293382644653, 10.922870133072138, 36.8161066621542, 61.59389689564705, 61.73572048544884, 3.4664043691009283, 0.07540102393249981, 0.3986205789260566, 0.0324586783972336, 0.09328168438514695, 0.06018345651682466, 0.03648112622613553, 0.06633394601522014, 0.07601477263960987, 0.09443708215258084, 0.030730355611012783, 0.0668842188315466, 0.19277846964541823, 0.20740980718983337, 0.21791238425066695, 0.13389175292104483, 0.1882363625918515, 0.0877487582329195, 0.240165222203359, 0.21202644071308896, 0.21854214108316228, 0.261805328191258, 0.3096013603499159, 0.23209354985738173, 0.24605895829154179, 0.39696645049843937, 0.8505369198974222, 0.5378470674622804, 32.119311690330505, 107.18233063817024, 78.56347471475601, 58.56126822531223, 45.44258616864681, 77.042917907238, 37.84512184560299, 84.99323889613152, 57.07425221800804, 48.580180406570435, 49.1439713537693, 50.82617528736591, 50.34479811787605, 53.68398293852806, 35.715317130088806, 33.116176798939705, 48.48635584115982, 74.39392805099487, 59.15955752134323, 86.89122185111046, 60.003256648778915, 9.096998758614063, 2.8420489467680454, 21.85792051255703, 63.95628333091736, 75.5737267434597, 67.60002180933952, 71.42671287059784, 57.58894219994545, 63.4082805365324, 56.50178633630276, 57.087821289896965, 64.831163585186, 53.27188365161419, 11.325496528297663, 23.834623843431473, 22.88588125258684, 11.886125095188618, 31.191709265112877, 62.443652898073196, 53.340637162327766, 41.74108698964119, 36.953298300504684, 32.21821278333664, 8.54026973247528, 18.77647966146469, 30.77462274581194, 27.067043893039227, 17.730644680559635, 20.525763295590878, 13.689136896282434, 19.18634656816721, 15.590764805674553, 18.721642903983593, 30.87016861885786, 17.173490077257156, 6.097173728048801, 1.0306657198816538, 3.4183744713664055, 2.0223403070122004, 3.2149257883429527, 0.8444702485576272, 0.29892455670051277, 0.38803669216576964, 0.13780969893559813, 0.2202961774310097, 0.2455912865116261, 0.3779756336007267, 0.8050915959756821, 0.12031885897158645, 0.5200160492677242, 3.6147294100373983, 2.9906444856896996, 0.382849020534195, 27.355471216142178, 12.696714699268341, 0.262778343167156, 0.15839736530324444, 0.16801963647594675, 0.2310123000643216, 0.22326788515783846, 0.15717935253633186, 0.44279825524426997, 0.2334609569516033, 0.3601923503447324, 0.15511931385844946, 0.25702004902996123, 0.17479014582931995, 0.17316209647106007, 0.22586163191590458, 0.4098320851335302, 4.5904049556702375, 9.945032503455877, 8.347767312079668, 18.491280265152454, 13.987037111073732, 15.6636942923069, 11.125692799687386, 17.299346923828125, 21.66509795933962, 24.88523706793785, 29.740907214581966, 30.725645273923874, 12.272291723638773, 5.7613154500722885, 24.316217601299286, 43.692992851138115, 48.999077528715134, 56.65504731237888, 73.83678674697876, 52.13355973362923, 14.719045031815767, 25.922298319637775, 23.762317523360252, 2.2324151219800115, 47.491508424282074, 60.55730111896992, 52.40011163055897, 65.04097312688828, 54.46748189628124, 53.77735912799835, 52.682542875409126, 50.449262112379074, 55.933549627661705, 59.48013111948967, 53.157145008444786, 22.520055882632732, 14.6731748431921, 70.86830243468285, 63.18334400653839, 56.85601092875004, 77.18847289681435, 73.72418358922005, 78.03084969520569, 88.55145156383514, 28.540498428046703, 43.72190169990063, 34.81297194957733, 42.31476500630379, 40.57086758315563, 45.55659905076027, 54.42476458847523, 78.74547734856606, 93.06722804903984, 21.94361351430416, 54.567804113030434, 63.632601499557495, 89.27066937088966, 7.487101620063186, 0.31949395139236003, 0.5103120231069624, 0.10141631311853416, 0.37161133135668933, 0.2577592874877155, 0.10453455048264004, 0.16654806153383106, 0.1526736404048279, 0.09381035328260623, 0.2490179901360534, 0.18708736955886707], [0.027782457837020047, 0.15744210249977186, 0.05423491653345991, 0.009019326280395035, 0.0340600104391342, 0.02436010505334707, 0.056032609718386084, 0.09568484761985019, 0.09218470848281868, 0.14622534188674763, 0.009219315597874811, 0.03531644419126678, 0.03163966648571659, 0.09012714115669951, 0.08333752150065266, 0.7150391000322998, 0.48624141316395253, 63.25074099004269, 77.3536804318428, 61.34213760495186, 33.534602746367455, 90.63084438443184, 55.080480203032494, 27.618540599942207, 60.50574168562889, 31.74228262156248, 35.38641057908535, 32.62403480708599, 33.890225663781166, 38.794117122888565, 28.456418439745903, 16.43153239041567, 29.209116250276566, 46.96152426302433, 72.41465225815773, 61.120389103889465, 83.44297528266907, 38.993686214089394, 3.5801781015470624, 22.623697221279144, 59.61002714931965, 66.00514099001884, 62.200621739029884, 54.421565160155296, 56.56518593430519, 34.73495073616505, 53.237434700131416, 52.2221177816391, 49.77774694561958, 40.44664844870567, 4.114052066579461, 12.25241119042039, 8.032164797186852, 30.16496255993843, 61.581570357084274, 54.98889371752739, 41.576988995075226, 38.539374992251396, 23.062499575316906, 2.889032713137567, 14.8874899931252, 23.862616941332817, 24.666830487549305, 21.306342110037804, 14.715342130512, 18.61299153417349, 11.619842033833265, 14.981104619801044, 9.675900544971228, 18.40774554759264, 23.637938797473907, 8.224323336035013, 2.129959319718182, 0.1089935666823294, 0.3758101654238999, 0.2950261440128088, 0.6926930928602815, 0.206578349461779, 0.1802032522391528, 0.2637339028296992, 0.3057094191899523, 0.6572753714863211, 0.30517673527356237, 0.5376951943617314, 1.1562676238827407, 0.3759840060956776, 0.15326400403864682, 1.301809789147228, 0.4363398189889267, 0.5779053492005914, 5.76946553774178, 5.210263794288039, 0.10618032974889502, 0.1313700241735205, 0.13614657567813993, 0.021675454481737688, 0.10134105934412219, 0.11170276193297468, 0.15815116523299366, 0.3592174651566893, 0.023486908939958084, 0.06335604135529138, 0.15903350460575894, 0.05143103437148966, 0.11966447767917998, 0.15428499144036323, 0.189283755607903, 2.063580919057131, 7.037464622408152, 7.827520128339529, 10.392050966620445, 4.798911642283201, 8.431649710983038, 10.869230311363935, 12.681086137890816, 14.983242005109787, 18.159692957997322, 18.525858409702778, 22.882685624063015, 27.380012199282646, 13.343053366988897, 5.05687789991498, 15.695843417197466, 38.028051629662514, 46.13769806921482, 44.75732333958149, 58.184784427285194, 53.36354613304138, 17.027769796550274, 2.4948829505592585, 0.3590698371408507, 30.966016575694084, 29.283480159938335, 37.74416506290436, 55.45282982289791, 38.477366119623184, 45.73063351213932, 36.28399081528187, 34.17656309902668, 35.412260591983795, 45.911256819963455, 49.31542955338955, 29.39954873174429, 42.35615238547325, 65.1540094614029, 52.816785871982574, 63.474818766117096, 59.18479196727276, 63.5014895349741, 49.266366586089134, 37.909080013632774, 20.984153598546982, 29.8243298381567, 26.07433956116438, 32.95036509633064, 26.172117814421654, 41.40170820057392, 44.850840121507645, 88.78819406032562, 19.48731131851673, 39.9989602714777, 52.19464525580406, 65.82801729440689, 16.798117719590664, 0.7244091003667563, 0.2060723234899342, 0.21478218346601352, 0.05224315915256739, 0.07063890720019117, 0.08976656128652394, 0.11318447461235337, 0.054063773568486795, 0.01546380923173274, 0.08059246567427181, 0.030762138085265178, 0.011026357988157542, 0.04262889575329609, 0.04835103245568462, 0.059935994795523584, 0.03735890881216619, 0.033054778832593, 0.019221513502998278, 0.06728016945999116, 0.07497544676880352, 0.026838193662115373, 0.08124337371555157, 0.01568247655086452, 0.07792794029228389, 0.0263007136163651, 0.04369890200905502, 0.07352062209974974, 0.5463038105517626, 0.3662515408359468, 67.64532297849655, 85.71076959371567, 57.091389298439026, 28.23026977479458, 90.96632838249207, 44.731929302215576, 42.090280652046204, 39.77424032986164, 32.59509935975075, 37.61080361902714, 34.261222556233406, 37.770471051335335, 31.60571414977312, 38.94637495279312, 18.149954080581665, 32.757502645254135, 54.98099774122238, 72.47637614607811, 64.98803436756134, 84.15503427386284, 39.004595428705215, 2.9302206030115485, 22.368468716740608, 66.2151937186718, 72.92380973696709, 63.664861768484116, 54.226050451397896, 62.822709158062935, 44.418924897909164, 55.65114878118038, 56.23208060860634, 55.706641003489494, 41.398668363690376, 4.620623309165239, 2.6760529540479183, 8.79564642906189, 35.113003849983215, 65.97038805484772, 59.65556390583515, 53.61123964190483, 42.905017733573914, 38.88296015560627, 13.644368648529053, 16.59530360251665, 23.064462170004845, 22.435010746121407, 18.288889825344086, 10.247979797422886, 16.619187220931053, 11.98816291987896, 19.321125335991383, 12.527394834905863, 21.190902404487133, 30.08614718914032, 11.728828735649586, 5.146355498582125, 0.26596200827043504, 0.3962809138465673, 0.2190913155209273, 0.415991970221512, 0.2617188234580681, 0.2528820710722357, 0.29752626141998917, 0.09635941532906145, 0.24818297009915113, 0.2991181385004893, 0.20911138853989542, 1.3587304973043501, 0.135846228513401, 0.9665715310256928, 0.9481686435174197, 0.7818732981104404, 0.857491377973929, 2.070402977988124, 8.157068844884634, 0.22369349200744182, 0.3485180111601949, 0.10162864156882279, 0.012543990615085931, 0.16626082069706172, 0.16709382209228352, 0.09881973877782002, 1.5701165981590748, 0.6254667439498007, 0.09970652361516841, 0.08582528957049362, 0.026371898566139862, 0.06318390762316994, 0.13113172055454925, 0.23365428642136976, 2.7616400364786386, 14.034767299890518, 10.545303393155336, 10.636676140129566, 12.148257829248905, 11.020547691732645, 6.51547190733254, 12.968835197389126, 13.529857993125916, 15.872018113732338, 17.907513789832592, 19.036429412662983, 21.235257424414158, 15.324040967971087, 12.629857286810875, 29.377371221780777, 48.51852111518383, 52.84976810216904, 54.41114231944084, 59.73539002239704, 54.67012122273445, 20.260075852274895, 10.160398297011852, 0.9426978870760649, 27.228128649294376, 42.150591015815735, 42.9750669747591, 62.77322821319103, 40.41632227599621, 52.5629822909832, 39.561193361878395, 38.76864328980446, 40.393124520778656, 52.343889847397804, 55.18299110233784, 33.26244235038757, 47.21122406423092, 68.77567112445831, 56.29214018583298, 63.97436276078224, 62.34844520688057, 64.05348211526871, 57.30903781950474, 49.56767521798611, 21.54688250273466, 26.889072842895985, 20.9414229914546, 28.769723027944565, 17.297581918537617, 39.30161789059639, 46.652452647686005, 91.29111215472221, 25.0312727317214, 30.621283873915672, 60.640007480978966, 71.18821486830711, 14.624867085367441, 0.48408452421426773, 0.27300650370307267, 0.19829203316476196, 0.04293601130484603, 0.18693341844482347, 0.05691582111467142, 0.06914509751368314, 0.05120155488839373, 0.01583508994372096, 0.061664668246521614, 0.054647487559122965, 0.04124237835640088, 0.17173353640828282, 0.23734863818390295, 0.19590587995480746, 0.13297077734023333, 0.20141549524851143, 0.15782224538270384, 0.21148256520973518, 0.17619467515032738, 0.14245604805182666, 0.2638181811198592, 0.12721561506623402, 0.2329521405044943, 0.1551016655866988, 0.16179426427697763, 0.178392723610159, 0.7538588857278228, 1.1752664856612682, 87.1943923830986, 96.12379923462868, 82.65033021569252, 45.60824207961559, 112.0277926325798, 67.13340684771538, 48.053878247737885, 86.39999940991402, 44.23324406147003, 52.81036041676998, 44.21967878937721, 51.84342250227928, 51.91260538995266, 45.8835107088089, 22.52043206244707, 40.07986553013325, 62.995242699980736, 80.41436299681664, 77.74700492620468, 93.63768383860588, 48.31566520035267, 6.187417460605502, 29.28059421479702, 72.29580223560333, 76.96673199534416, 71.11870899796486, 63.339895606040955, 63.065318539738655, 42.208765894174576, 57.67009064555168, 60.788298323750496, 54.34427350759506, 47.20112040638924, 7.70821887999773, 19.92743030190468, 15.990263968706131, 39.91542935371399, 70.44091656804085, 62.40300267934799, 52.114625349640846, 49.45422850549221, 35.4130395501852, 7.424378385767341, 18.07214565575123, 30.88547609746456, 29.62706722319126, 28.24068881571293, 20.805878564715385, 24.838043600320816, 16.500747576355934, 21.245431378483772, 15.848855506628752, 25.665566995739937, 34.65775787830353, 13.426048513501883, 5.813054423779249, 0.251340867835097, 0.7714964705519378, 1.2642891774885356, 1.1423083604313433, 0.6954580382443964, 0.46519324416294694, 0.4687123006442562, 1.114213855471462, 1.3873139885254204, 0.5042554449755698, 1.2513431534171104, 2.311057602055371, 0.7394253008533269, 0.9818421397358179, 3.1293828785419464, 1.2490371521562338, 0.6844936672132462, 20.75221974402666, 15.063146967440844, 0.3433873364701867, 0.4733438364928588, 0.31355582003016025, 0.09204793808748946, 0.2770890877582133, 0.35177010227926075, 0.2782523597124964, 0.6158796208910644, 0.42652423318941146, 0.1596206918475218, 0.2607176959281787, 0.11149569530971348, 0.3667143441271037, 0.32537306717131287, 0.40747998165898025, 6.61905862390995, 15.701486114412546, 13.080647997558117, 16.647934578359127, 12.752907983958721, 16.762017756700516, 12.154537942260504, 15.855735037475824, 19.032931700348854, 25.389718897640705, 24.05521720647812, 26.940850764513016, 34.10126633942127, 19.215059727430344, 7.545285522937775, 18.998596742749214, 42.606095373630524, 54.61992971599102, 56.52095250785351, 65.45807674527168, 63.20664435625076, 23.01158420741558, 9.679535049945116, 0.980962427565828, 36.94829776883125, 34.500761702656746, 48.44939522445202, 65.69696232676506, 46.906757801771164, 57.37531766295433, 45.70816531777382, 40.9676156938076, 42.538823783397675, 57.0022726804018, 57.746618539094925, 36.65992744266987, 49.335568472743034, 78.246009349823, 62.10925184190273, 70.07815763354301, 66.03566855192184, 79.05832976102829, 56.60979174077511, 49.03968594968319, 30.515474751591682, 37.49835625290871, 34.339760541915894, 40.96853144466877, 37.5154173374176, 57.8754810243845, 61.344398483633995, 105.22940263152122, 36.23663015663624, 52.204672917723656, 64.70997288823128, 84.94017854332924, 33.09500053524971, 0.6829654960893095, 0.7197644433472306, 0.3880187321919948, 0.34151552128605545, 0.26482123823370785, 0.15027837362140417, 0.20682588539784774, 0.2408435006509535, 0.16490221547428519, 0.15855514589929953, 0.24093414656817913, 0.07483987865271047], [0.052288990482338704, 0.10668959148460999, 0.0456765697163064, 0.028921157281729393, 0.012269625112821814, 0.12707005022093654, 0.05077597401395906, 0.12417567428201437, 0.049887255881913006, 0.22949552832869813, 0.07553788338555023, 0.17066867323592305, 0.12632637372007594, 0.19781327369855717, 0.08486230843118392, 0.8187165961135179, 0.1517085515661165, 11.947234366089106, 86.95218577980995, 62.80339479446411, 50.14657035470009, 34.67535473406315, 105.30244991183281, 23.31976667046547, 46.510078087449074, 43.97014997899532, 35.454320535063744, 37.012476325035095, 30.65308626741171, 37.082791551947594, 28.71827758848667, 26.99021391570568, 81.45537793636322, 60.24790272116661, 50.69126732647419, 60.722303465008736, 64.0729446709156, 75.58115914463997, 10.635150521993637, 18.609822504222393, 62.74058796465397, 59.68037277460098, 45.52967369556427, 52.908505350351334, 54.73903052508831, 45.092472955584526, 64.71227556467056, 49.012498408555984, 50.58409407734871, 27.679173946380615, 4.31205041706562, 5.024234326556325, 34.89546172320843, 61.246983110904694, 58.69404450058937, 49.846109077334404, 47.117733880877495, 26.333289965987206, 3.850788655690849, 17.84436497837305, 22.761415131390095, 22.767434008419514, 22.88156658411026, 18.78770235925913, 14.821925461292267, 13.18555561825633, 16.76986813545227, 18.27070590108633, 13.529050536453724, 16.842727325856686, 21.6199753805995, 7.364469850435853, 5.24094857275486, 0.4428670374909416, 0.06465456972364336, 0.235353478055913, 0.32931624620687217, 0.2810781908920035, 0.13211123674409464, 0.31997596146538854, 0.25080646213609725, 0.10431600283482112, 0.5261441110633314, 0.1858998293755576, 0.40136616909876466, 0.1267904683481902, 1.3578021596185863, 1.274937631096691, 0.12936946121044457, 0.12832895532483235, 0.9808954561594874, 3.0109508335590363, 0.375009803683497, 0.020019570874865167, 0.02615925099235028, 0.14438155019888654, 0.08626935363281518, 0.07053719586110674, 0.13703302654903382, 1.6323958500288427, 0.21954797382932156, 0.02039747247181367, 0.04969957044522744, 0.0354045259882696, 0.028268820606172085, 0.12028993747662753, 0.10515651476453058, 0.793894249945879, 8.839137945324183, 14.676639307290316, 12.893809173256159, 10.01824602484703, 15.17772126942873, 16.28551572561264, 18.080822490155697, 13.222734723240137, 16.523857936263084, 17.527891360223293, 22.609945759177208, 24.76403307169676, 27.77183387428522, 20.490567684173584, 6.4929538406431675, 12.633567787706852, 34.67044539749622, 45.81314988434315, 41.784499660134315, 50.62820591032505, 58.46174016594887, 19.121343456208706, 1.0045195603743196, 2.437237431295216, 37.13034600019455, 55.28647094964981, 38.47425028681755, 62.29883886873722, 50.293675661087036, 54.038287326693535, 49.778263717889786, 62.134121507406235, 54.64850798249245, 57.263132482767105, 47.45181955397129, 65.9680625796318, 54.879717975854874, 65.81347927451134, 57.5443059951067, 64.92226749658585, 52.53231033682823, 61.48633226752281, 43.312314078211784, 28.10559656471014, 24.90619294345379, 31.467458568513393, 23.44369702041149, 40.94716899096966, 42.11356960237026, 76.11708238720894, 43.659300059080124, 28.427401296794415, 53.136553913354874, 56.89835965633392, 34.21978197991848, 0.9114389831665903, 0.15483268158277497, 0.21537515945965424, 0.03107148193521425, 0.08178219519322738, 0.03486887719191145, 0.1772218817495741, 0.0433115751366131, 0.05579499629675411, 0.05724386894144118, 0.008972355753940064, 0.05739823194744531, 0.06626765738474205, 0.03138952190056443, 0.12073703692294657, 0.08462113270070404, 0.06682434977847151, 0.05585239399806596, 0.028423432231647894, 0.008432142749370541, 0.13473462488036603, 0.026966728073603008, 0.10703725798521191, 0.03676458582049236, 0.14269887877162546, 0.07368284816038795, 0.18509704823372886, 0.18170375609770417, 0.8145997545216233, 0.13938453630544245, 13.109138868749142, 94.9876905977726, 73.2492546737194, 39.89095486700535, 43.09275045990944, 92.55084335803986, 27.15113528072834, 54.10210110247135, 25.86874209344387, 38.09618957340717, 29.52922247350216, 36.200372502207756, 30.50645023584366, 37.6184868067503, 25.274947956204414, 90.28766199946404, 63.08564364910126, 58.84728267788887, 67.54007622599602, 65.64950287342072, 72.82251477241516, 14.225306175649166, 16.24988503754139, 67.95461878180504, 64.113929271698, 51.96224972605705, 57.53695718944073, 58.20980228483677, 41.33391223847866, 66.48320093750954, 51.05264313519001, 55.66725991666317, 26.926288045942783, 1.69327950803563, 8.109285458922386, 43.170087710022926, 62.51495227217674, 63.36023211479187, 59.37061719596386, 51.00043013691902, 44.12097908556461, 14.533185604959726, 17.7936851978302, 24.6132742613554, 23.065550811588764, 18.856170885264874, 15.66444855183363, 11.222190521657467, 11.629598010331392, 13.807708583772182, 15.928104054182768, 16.04319892823696, 19.906892403960228, 28.008350282907486, 10.521417874842882, 7.071276158094406, 1.3374300277791917, 0.2313807763857767, 0.25702978600747883, 0.12843901582527906, 0.6562367803417146, 0.035812636706396006, 0.37361842521931976, 0.3156358818523586, 0.2530589100206271, 0.915067313471809, 0.6328628095798194, 1.0262403823435307, 0.04780434421263635, 1.6629000194370747, 0.8940628718119115, 0.2074604810331948, 0.9505066461861134, 2.0162290474399924, 2.7027564961463213, 0.5742448393721133, 0.1318011526018381, 0.03832940790744033, 0.10137242992641404, 0.01423180883648456, 0.05008429609006271, 0.15175738488323987, 1.952451013494283, 0.7749558880459517, 0.012046190422552172, 0.020351483435661066, 0.02752518677880289, 0.11100802264991216, 0.013003012663830305, 0.0625419795687776, 2.982225799933076, 15.971755161881447, 19.374660663306713, 14.775583148002625, 10.718147568404675, 14.849405586719513, 11.099378261715174, 12.196516189724207, 14.115249831229448, 15.914040058851242, 17.364614121615887, 20.39429794996977, 21.293730586767197, 22.419044002890587, 18.145863600075245, 12.636381536722183, 24.50368244200945, 50.32150536775589, 52.86385014653206, 51.35383017361164, 55.616156458854675, 54.982981234788895, 22.389614582061768, 6.5347895957529545, 5.143979676067829, 24.944682978093624, 61.54164969921112, 41.66080489754677, 66.24757558107376, 50.46710595488548, 60.10664910078049, 53.655294477939606, 59.152417704463005, 57.55362689495087, 62.91849821805954, 53.333664536476135, 66.53167873620987, 61.509651616215706, 70.70288211107254, 60.53034536540508, 65.91741889715195, 57.99749627709389, 67.07327887415886, 48.898208141326904, 27.40511365234852, 18.196790367364883, 28.62893298268318, 18.643900975584984, 31.140360720455647, 50.60580611228943, 80.71074709296227, 50.6016681343317, 23.877517841756344, 56.27133630216122, 67.25731059908867, 29.601593390107155, 0.8231533330399543, 0.14928990713087842, 0.34615753625985235, 0.046948384479037486, 0.03494475437037181, 0.020176037869532593, 0.05891352680919226, 0.08094451084616594, 0.0763460599409882, 0.04475238063605502, 0.033748872447176836, 0.16273346700472757, 0.028321001009317115, 0.22778189450036734, 0.18816097523085773, 0.17473092244472355, 0.16277321643428877, 0.09787715927814133, 0.24968222714960575, 0.13702078111236915, 0.24823183310218155, 0.1648095657583326, 0.4042584076523781, 0.2430857068975456, 0.2107688714750111, 0.21489314938662574, 0.41020698845386505, 0.2916132740210742, 0.9904272446874529, 0.4961502127116546, 23.731373883783817, 108.77215012907982, 82.6892401278019, 62.551038935780525, 56.24148890376091, 125.30051082372665, 36.762054562568665, 75.93163713812828, 57.58571237325668, 52.255848571658134, 48.395685106515884, 48.51950526237488, 54.18635778129101, 42.698726803064346, 35.98006792366505, 101.45805940032005, 73.21961626410484, 64.16998386383057, 73.58103767037392, 73.97851154208183, 87.356978058815, 15.87688660249114, 20.921246074140072, 77.58361369371414, 65.51148667931557, 58.9740514755249, 59.67436149716377, 64.64184254407883, 47.75554485619068, 71.74201235175133, 52.69018046557903, 58.76570105552673, 35.27718544006348, 6.106497477740049, 14.187709093093872, 44.27618935704231, 69.78042840957642, 67.10775822401047, 56.46596185863018, 57.03398957848549, 36.05409935116768, 7.167982393875718, 21.355967447161674, 32.20046393573284, 29.945533834397793, 27.770749032497406, 25.659031346440315, 19.583696946501732, 15.465880706906319, 20.227232314646244, 21.411957442760468, 19.984695129096508, 24.571343511343002, 34.32542771100998, 13.072253298014402, 10.562271382659674, 1.6962496424093843, 0.2326104260282591, 0.28868728259112686, 0.7051920471712947, 1.1742370971478522, 0.9451238787733018, 0.5600442888680845, 0.465203188941814, 0.3571788448607549, 1.179238222539425, 0.5815921013709158, 0.7031675870530307, 0.14897088753059506, 3.330903402529657, 1.8940860265865922, 0.2094991013291292, 0.6613352161366493, 15.301798861473799, 17.144630625844, 0.6452797120437026, 0.20467436959734187, 0.14529983920510858, 0.39797188248485327, 0.2487585204653442, 0.13864405103959143, 0.23971062706550583, 2.173248021863401, 0.7660067151300609, 0.14630354940891266, 0.11151245300425217, 0.06931752068339847, 0.28848369664046913, 0.2452205985900946, 0.4193175339605659, 5.678493669256568, 21.444023922085762, 23.670833632349968, 22.2362320125103, 13.360290192067623, 19.503348357975483, 17.244371473789215, 20.530385747551918, 19.579479172825813, 22.279344499111176, 23.936834558844566, 28.11610870063305, 31.160989813506603, 35.38584440946579, 26.4241810888052, 9.863112699240446, 16.59488182514906, 39.95623916387558, 54.343528747558594, 53.94808776676655, 63.32361727952957, 67.26073801517487, 25.07482599467039, 3.184184250421822, 4.0072939451783895, 45.98903484642506, 65.81409484148026, 51.32188908755779, 64.50894847512245, 52.67553225159645, 63.129546493291855, 62.32661537826061, 67.17277273535728, 63.089671432971954, 69.42811131477356, 59.68855373561382, 71.7025400698185, 66.81859374046326, 74.45568233728409, 67.47478812932968, 69.2349524796009, 62.277077436447144, 70.87454169988632, 56.44159376621246, 33.42523321509361, 32.709412425756454, 42.92219281196594, 31.583844423294067, 56.7385820299387, 61.998161002993584, 91.94669857621193, 62.69454203546047, 36.09456717967987, 68.4579473733902, 72.90919572114944, 63.413512855768204, 1.0225561237893999, 0.28424303513020277, 0.3797710669459775, 0.21187508711591363, 0.13894511066609994, 0.11878601973876357, 0.3196696029044688, 0.18665006646187976, 0.17162029951578006, 0.20333921624114737, 0.21210629580309615, 0.24393513944232836, 0.19956845295382664], [0.028488744937931187, 0.05087555167847313, 0.11526737886015326, 0.04648809335776605, 0.06512751817354001, 0.06508434744318947, 0.17355378717184067, 0.0555002003966365, 0.10750135261332616, 0.05030529653595295, 0.15140103525482118, 0.01858718133007642, 0.09359936811961234, 0.031104399895411916, 0.5017094034701586, 0.030663788675155956, 1.0973750590346754, 0.189918544201646, 48.45820315182209, 84.05858784914017, 67.50305101275444, 43.65151047706604, 76.4240451157093, 83.01111325621605, 22.083924785256386, 63.88989329338074, 26.87491100281477, 46.71552926301956, 26.36207152158022, 33.952325731515884, 26.763654872775078, 38.969238325953484, 39.37651947140694, 49.64105688035488, 57.239558547735214, 71.08197256922722, 56.08427233994007, 64.39643651247025, 40.54507076740265, 6.475535100325942, 32.293121963739395, 59.62531752884388, 45.0606382638216, 45.803038626909256, 50.16854837536812, 56.18309363722801, 58.24292130768299, 54.8629342764616, 57.407513335347176, 6.683475142344832, 1.2070755288004875, 42.413951084017754, 62.81912215054035, 57.2191346436739, 53.47869515419006, 50.07055543363094, 36.29448965191841, 7.68776647746563, 18.70743926614523, 21.808169782161713, 22.310480028390884, 18.55176541954279, 19.099374935030937, 11.148856356739998, 8.91973827034235, 13.81596839055419, 16.667148247361183, 27.29110836982727, 12.642731945961714, 20.621873438358307, 20.50583716481924, 9.650625251233578, 1.3852751604281366, 0.5761816666927189, 0.26082889933604747, 0.2753830386791378, 0.01005687192446203, 0.20059899921761826, 0.20905489625874907, 0.08443946979241446, 0.17219283676240593, 0.0836320428061299, 0.14845460507785901, 0.3041792887961492, 0.17150636500446126, 0.13296225748490542, 1.1796502629294991, 0.25186476472299546, 0.03561616795195732, 0.2912340365583077, 3.606608770787716, 4.95841140858829, 0.14185373584041372, 0.13905576488468796, 0.05885782862605993, 0.12894976185634732, 0.03649621779914014, 0.14329228521091864, 1.0519039677456021, 3.5150294099003077, 1.3219646201469004, 0.21016694518039003, 0.04554648978228215, 0.22201892483280972, 0.14435689605306834, 0.016515967763552908, 0.09440320311114192, 1.3047801610082388, 9.645281787961721, 18.62130928784609, 16.532065495848656, 12.840270046144724, 16.92561987787485, 15.413981191813946, 21.32303461432457, 13.672432042658329, 14.232494439929724, 17.57451105862856, 16.29639644175768, 23.39600957930088, 25.037576593458652, 25.581021532416344, 23.18172387778759, 8.270358815789223, 8.194390442222357, 29.597415514290333, 42.928120493888855, 35.577076748013496, 47.24506884813309, 62.49797098338604, 24.53795090317726, 2.4486192455515265, 23.377312682569027, 45.84362044930458, 44.66912627220154, 31.847801059484482, 52.820695862174034, 54.96036484837532, 55.28228357434273, 55.11274427175522, 53.77536043524742, 54.84631396830082, 60.03503434360027, 57.229508087038994, 61.90935596823692, 56.811948493123055, 66.22241333127022, 57.418213561177254, 65.70778414607048, 61.95765897631645, 50.037113428115845, 26.753363125026226, 31.286156997084618, 22.305403500795364, 30.22834125906229, 51.87271513044834, 58.11183214187622, 64.70629468560219, 31.02466832846403, 53.4139846265316, 53.2465124130249, 50.793326050043106, 1.4991047023795545, 0.18344312760746107, 0.09554872289299965, 0.010412917272333289, 0.1833851361880079, 0.02009562616876792, 0.0693897093879059, 0.02922362142271595, 0.13511162105714902, 0.03611325104429852, 0.07018705800874159, 0.03888594816089608, 0.09004360501421615, 0.05477434286149219, 0.02754488894424867, 0.07002656857366674, 0.028802248525607865, 0.008345586993527832, 0.026223953282169532, 0.07333869201829657, 0.28374006680678576, 0.05042311247962061, 0.10166899955947883, 0.013671184915438062, 0.13965178368380293, 0.03744072688277811, 0.05308117746608332, 0.06288606149610132, 0.38981802470516413, 0.01277221308555454, 1.0098595800809562, 0.29505461279768497, 52.00676053762436, 92.99212887883186, 69.6431265771389, 42.42338217794895, 85.6352524459362, 64.45618450641632, 29.893691316246986, 48.922143056988716, 26.887248940765858, 43.7984523922205, 25.055766217410564, 36.05330139398575, 27.757814526557922, 46.161781176924706, 48.75030867755413, 50.11712573468685, 62.55820535123348, 75.42253285646439, 63.0403196811676, 70.35365045070648, 48.117661625146866, 9.412876758724451, 34.19181168079376, 64.53679338097572, 52.22032427787781, 55.158782601356506, 58.00478808581829, 55.6660021841526, 57.87384711205959, 61.63461931049824, 62.53722287714481, 5.887490529567003, 2.976997043006122, 49.17107529938221, 65.02803862094879, 64.23420801758766, 58.789438381791115, 54.44940626621246, 56.975700706243515, 17.557803355157375, 21.33367784321308, 23.39991956949234, 22.7556299418211, 16.498623490333557, 18.20279784500599, 11.586417127400637, 11.390151008963585, 11.084977984428406, 11.8950498662889, 24.83164854347706, 15.073583107441664, 23.850714080035686, 31.21006228029728, 9.696119260042906, 5.552684795111418, 2.7255291491746902, 0.7192496897187084, 0.36973414302337915, 0.05993616548948921, 0.34742242307402194, 0.27014068560674787, 0.06308865296887234, 0.2628836687654257, 0.12967948598088697, 0.2806812903145328, 0.19498141627991572, 0.12831166328396648, 0.07344727564486675, 0.13210746663389727, 0.17194622108945623, 0.046352113349712454, 0.5227210884913802, 3.3135810820385814, 9.431117679923773, 0.4159683105535805, 0.25585683644749224, 0.08650211340864189, 0.2121406127116643, 0.02409673725196626, 0.18826103158062324, 1.1209760676138103, 1.4468049025163054, 1.0412468458525836, 0.14070634584641084, 0.052732186231878586, 0.08295701496535912, 0.14178919867845252, 0.019040242077608127, 0.022108417870185804, 2.312762998044491, 15.29088394716382, 23.547195866703987, 19.179767221212387, 11.60760099068284, 16.587356328964233, 13.848967719823122, 15.7065493427217, 9.390194825828075, 13.462157975882292, 17.32596829533577, 16.869052313268185, 20.013094805181026, 21.676584742963314, 23.18757176399231, 19.78661935776472, 11.873275134712458, 18.454294949769974, 46.23295895755291, 54.490801244974136, 42.48973801732063, 51.739425882697105, 55.569171980023384, 20.841790437698364, 9.632182940840721, 15.992891527712345, 36.09120815992355, 59.09571334719658, 39.97463017702103, 58.67371939122677, 51.532678976655006, 59.475153386592865, 59.49494652450085, 58.35987903177738, 60.16298107802868, 66.3742683827877, 61.08904458582401, 66.65881991386414, 59.57353390753269, 69.29020911455154, 63.77839207649231, 68.73727038502693, 63.09175752103329, 56.495885252952576, 26.06727574020624, 16.917847394943237, 21.424969844520092, 22.496556043624878, 50.777572095394135, 67.80869141221046, 66.65910109877586, 35.74648305773735, 48.15547339618206, 64.32671785354614, 45.83616524934769, 2.851422568783164, 0.0934111668902915, 0.12116305195377208, 0.05081121860712301, 0.15347661450505257, 0.08540357899619266, 0.015013379397714743, 0.07514559154515155, 0.14347712451126426, 0.0059228700229141396, 0.08882119873305783, 0.04460114207176957, 0.04962971950590145, 0.08267371493275277, 0.14630791323725134, 0.13825421570800245, 0.15043055842397735, 0.21100278157973662, 0.160506148240529, 0.18138541927328333, 0.2925621543545276, 0.18477457022527233, 0.18901926901889965, 0.16788024629931897, 0.25114687043242157, 0.08397292607696727, 0.21905199653701857, 0.13359422591747716, 0.6854997819755226, 0.1603565164259635, 1.0573528753593564, 0.3669387992704287, 72.18480259180069, 100.76602533459663, 86.99315518140793, 59.07277777791023, 99.72048103809357, 90.99573880434036, 40.960688665509224, 90.59040695428848, 40.477392598986626, 67.41440936923027, 37.2094539552927, 54.01514656841755, 37.38159231841564, 57.400677502155304, 52.192391976714134, 57.89525896310806, 70.4773262143135, 83.02198067307472, 68.39451357722282, 79.94786202907562, 48.46519857645035, 10.20448923110962, 38.98810051381588, 66.43877372145653, 55.854829251766205, 55.56096442043781, 60.60987509787083, 62.79696933925152, 64.55008506774902, 65.04160389304161, 70.29473081231117, 8.27629029750824, 2.221405212767422, 50.94569407403469, 67.81767413020134, 71.38926967978477, 61.370852664113045, 57.1627152711153, 49.149933233857155, 10.617490019649267, 27.282338440418243, 33.008498176932335, 27.122264429926872, 25.536780506372452, 25.362052582204342, 16.93282049149275, 15.339002665132284, 20.145768485963345, 19.15232129395008, 30.907665006816387, 18.169882111251354, 28.15570257604122, 38.79857428371906, 13.883463218808174, 9.600811824202538, 2.456532558426261, 0.3893839870579541, 0.3195621696067974, 0.10121468643774278, 0.8260292443446815, 0.6576265557669103, 0.1410685881273821, 0.4315710748778656, 0.1948171789990738, 0.7639877765905112, 1.0431567183695734, 0.6441686279140413, 0.40991571033373475, 2.31598854996264, 0.8358230406884104, 0.21592697594314814, 1.245653077494353, 9.53244874253869, 25.103854537010193, 0.3530012065311894, 0.6031668686773628, 0.1810876844683662, 0.34703101438935846, 0.10925527021754533, 0.2675618411740288, 3.7500318372622132, 13.566982951015234, 2.114369706250727, 0.3522423160029575, 0.17991262720897794, 0.16506179206771776, 0.24603280500741675, 0.17480386071838439, 0.17958565178560093, 5.08152955211699, 20.857198610901833, 25.75289960950613, 24.801390767097473, 17.356077879667282, 21.03432610630989, 18.59176017343998, 25.88181149214506, 19.632613621652126, 20.382263995707035, 23.41161724179983, 22.273547910153866, 26.82637430727482, 32.99900248646736, 32.81905174255371, 30.090292766690254, 13.40077131986618, 11.797225065529346, 35.546154007315636, 51.64794199168682, 45.625899732112885, 61.38914108276367, 67.91146069765091, 28.70976984500885, 5.347192771732807, 28.786417432129383, 54.85664181411266, 54.8920901119709, 44.88893307745457, 63.94173011183739, 56.54155120253563, 58.76912847161293, 63.642078191041946, 62.277594208717346, 63.05184826254845, 74.37152445316315, 66.54956817626953, 72.8022238612175, 66.020537763834, 76.62820056080818, 68.44601601362228, 75.76118588447571, 69.38901141285896, 66.47573813796043, 36.37340001761913, 38.756901919841766, 31.333171874284744, 42.09595374763012, 74.24178421497345, 73.94297584891319, 81.43396988511086, 45.899576246738434, 66.76225796341896, 65.05937173962593, 79.64603662490845, 4.874664377421141, 0.2142116500181146, 0.3168702812399715, 0.19366183318197727, 0.36871959746349603, 0.19412450288655236, 0.16700963285984471, 0.2369960883515887, 0.234706740884576, 0.12372401804896072, 0.1840846994309686, 0.17299659753916785, 0.22223962470889091, 0.1372821506811306], [0.11451547194155864, 0.10576876433333382, 0.05829797839396633, 0.04961342565366067, 0.02557335694291396, 0.07683500909479335, 0.031293105785152875, 0.09350141204777174, 0.020309860083216336, 0.13260518055176362, 0.017320589431619737, 0.031170198708423413, 0.14807177562033758, 0.14549659739714116, 0.11014362840796821, 0.09757678984897211, 0.5850051494780928, 0.3494195721577853, 5.653255898505449, 88.25653418898582, 63.84503290057182, 56.49360537528992, 45.85241697728634, 109.93991866707802, 45.995156317949295, 43.40512789785862, 40.42816624045372, 24.35958657413721, 34.581564366817474, 23.075696267187595, 30.18091980367899, 23.075967952609062, 25.746213868260384, 51.34217619895935, 58.03208962082863, 55.76462209224701, 65.64366638660431, 61.226342618465424, 68.16899567842484, 15.495557114481926, 28.64269394427538, 67.82282665371895, 62.06661053001881, 41.41401953995228, 28.74558862298727, 57.83231534063816, 57.476859614253044, 63.982889503240585, 32.84426338970661, 1.8526639742776752, 30.474693439900875, 72.10211902856827, 62.57360212504864, 46.333885341882706, 54.17749285697937, 42.58423514664173, 9.064437355846167, 21.120826564729214, 24.358739219605923, 23.622133545577526, 21.12090826034546, 21.22307527810335, 13.079234473407269, 15.3001070022583, 6.171008991077542, 9.938789438456297, 16.582093611359596, 22.175264284014702, 16.38903357088566, 23.947559483349323, 24.899611696600914, 12.8360484726727, 4.118954753503203, 0.4219775990350172, 1.564300179015845, 0.5989613849669695, 0.207014168263413, 0.21814175241161138, 0.2478468811023049, 0.28668740240391344, 0.25924482964910567, 0.08480655829771422, 0.23000529472483322, 0.08592369835241698, 0.06658762693405151, 0.10185622857534327, 0.5874995968770236, 0.1299307178123854, 0.08436630145297386, 0.39364444906823337, 5.591914365068078, 5.586237944662571, 0.4782947333296761, 0.14216833224054426, 0.014111672753642779, 0.055195122040458955, 0.01914834887429606, 0.07548361012595706, 0.14584839023882523, 0.4303508950397372, 0.5475677771028131, 0.2169889150536619, 0.030171164034982212, 0.02387488890235545, 0.27967087109573185, 0.037388910131994635, 0.12883238377980888, 1.0341611760668457, 10.00786593183875, 21.683040596544743, 23.277649730443954, 12.20803052186966, 21.531280539929867, 13.955359160900116, 15.189816020429134, 20.006188675761223, 15.070770308375359, 20.842671990394592, 17.264339402318, 17.1870344504714, 22.45350055396557, 23.242191933095455, 23.72525241225958, 25.21103348582983, 14.885231964290142, 7.59037010371685, 23.651581965386868, 39.89296495914459, 30.65640538930893, 45.146829038858414, 65.41986599564552, 22.170791923999786, 3.743922240100801, 12.03503055498004, 42.06419125199318, 49.74284201860428, 41.756122782826424, 45.87145395576954, 57.72582225501537, 57.82237887382507, 57.56504148244858, 51.63603723049164, 54.3828072398901, 57.60564610362053, 59.191023632884026, 56.596830636262894, 58.72194640338421, 62.30377480387688, 56.333709955215454, 58.74683126807213, 59.032853320240974, 24.029606580734253, 32.548730447888374, 17.089600078761578, 44.88897867500782, 46.24048635363579, 68.1375789642334, 28.635385036468506, 39.1850021481514, 47.67682068049908, 60.251618921756744, 8.492234610021114, 0.5762641341425478, 0.11888209817698225, 0.1335348837892525, 0.024351000756723806, 0.09052794543094933, 0.016781411723059136, 0.04624570792657323, 0.012531586544355378, 0.04136327050218824, 0.05504119319084566, 0.05496467034390662, 0.04703748672909569, 0.028382615964801516, 0.013850993382220622, 0.12151623261161149, 0.09274474796256982, 0.07651734762475826, 0.06949030008399859, 0.029186321080487687, 0.10953408025670797, 0.03769525013922248, 0.03573082976799924, 0.03771046787733212, 0.05499533217516728, 0.09680636634584516, 0.006378896114256349, 0.11922614299692214, 0.11391842155717313, 0.15350729489000514, 0.09297824988607317, 0.4385796206770465, 0.295061381184496, 4.861943135038018, 92.06485703587532, 76.76060065627098, 52.77325160801411, 57.88512870669365, 100.0464503467083, 40.75333759188652, 48.70947226881981, 33.02360616624355, 28.449510410428047, 31.55622560530901, 27.68109854310751, 29.142587520182133, 32.74630464613438, 32.71529071033001, 62.8653846681118, 58.726103380322456, 64.85390916466713, 68.81769686937332, 65.53011327981949, 73.92588436603546, 17.10847556591034, 29.229011982679367, 73.75676304101944, 64.4610558450222, 47.68552981317043, 38.004489094018936, 63.94863814115524, 58.466702699661255, 73.6280107498169, 30.11094655841589, 2.3977841483429074, 39.578661024570465, 72.1066103875637, 63.50506894290447, 54.245387613773346, 59.61697697639465, 63.603016287088394, 18.465325757861137, 22.778546512126923, 24.875446893274784, 23.82130365818739, 21.121056452393532, 20.00670164823532, 15.70963192731142, 11.455243416130543, 12.138526551425457, 9.627915769815445, 13.814457971602678, 23.594539426267147, 16.06859676539898, 26.406772322952747, 36.09829097986221, 14.029591977596283, 10.759881678968668, 0.32937549927737564, 0.961876348592341, 0.7085147907491773, 0.3888654039474204, 0.1491490623448044, 0.1649993922910653, 0.23219563969178125, 0.32358793483581394, 0.19684374681673944, 0.41465732152573764, 0.18127519550034776, 0.3669347323011607, 0.13187542674131691, 0.4284210142213851, 0.21455443318700418, 0.10290660502505489, 0.434256877633743, 2.8886068984866142, 5.0284426007419825, 1.4558962709270418, 0.0079606090184825, 0.21333012700779364, 0.17339424026431516, 0.09339154450572096, 0.5115347856190056, 0.7218273170292377, 0.4543145763454959, 0.8995702012907714, 0.15677742019761354, 0.19843396148644388, 0.049789559561759233, 0.2435238560428843, 0.05652442356222309, 0.18381215311819687, 2.195724528282881, 20.04496369510889, 26.62166979163885, 24.107382707297802, 12.964282091706991, 21.170835681259632, 13.466201908886433, 15.9616819024086, 14.581515211611986, 11.117286700755358, 17.165765091776848, 16.195874735713005, 19.09304827451706, 20.659214034676552, 20.904958248138428, 21.568640135228634, 24.32261075824499, 16.035244055092335, 16.458155661821365, 45.65102778375149, 54.42223772406578, 41.849137991666794, 46.95616655051708, 57.3188640922308, 16.200117208063602, 13.469836413860321, 10.806947853416204, 29.13033127784729, 55.399659276008606, 50.63424378633499, 53.69082257151604, 55.86317740380764, 60.30218280851841, 62.570075914263725, 52.493142038583755, 61.575996056199074, 63.617105931043625, 65.63358172774315, 60.225233137607574, 63.0006992071867, 67.25895971059799, 63.12184430658817, 60.036888644099236, 61.36759623885155, 20.59726405888796, 24.695541746914387, 15.653654281049967, 34.35351200401783, 57.80455783009529, 72.29549065232277, 34.73157271742821, 41.64296865463257, 53.964909464120865, 62.27337263524532, 4.754993598908186, 0.18390751909464598, 0.22724647948052734, 0.14096893253736198, 0.06063487526262179, 0.09898439166136086, 0.1332704268861562, 0.022351862717187032, 0.009258485224563628, 0.09357459523016587, 0.006167807514430024, 0.05100939430121798, 0.018804365281539503, 0.06556856911629438, 0.03488201691652648, 0.16549210413359106, 0.16737199388444424, 0.24324133526533842, 0.1506446531857364, 0.16032129409722984, 0.2812405728036538, 0.11550940063898452, 0.2627748402301222, 0.12143044034019113, 0.22163801011629403, 0.3036425675963983, 0.18098535714671016, 0.27934515732340515, 0.2329093631124124, 0.29900387744419277, 0.28138576657511294, 0.6131234625354409, 0.48886995180509984, 10.856953170150518, 114.1334268450737, 83.72892513871193, 73.95641952753067, 66.58451110124588, 129.45707738399506, 61.18292614817619, 74.09702718257904, 59.34696726500988, 41.79918587207794, 51.03393293917179, 40.91742418706417, 43.04590657353401, 38.68526056408882, 31.953765973448753, 68.21919098496437, 68.09438288211823, 73.35015445947647, 78.48507732152939, 72.52304524183273, 84.99870300292969, 20.254868231713772, 33.387280851602554, 80.65004155039787, 67.7628430724144, 54.40812908113003, 36.97379060089588, 64.62069287896156, 65.59327349066734, 78.72321054339409, 38.5524120926857, 1.8946328409947455, 35.845444947481155, 80.66489115357399, 71.70512393116951, 56.99852228164673, 61.17681227624416, 50.58750629425049, 12.144496031105518, 26.853698641061783, 35.856232568621635, 29.514150582253933, 28.765830136835575, 30.310606844723225, 19.667402654886246, 19.784882850944996, 11.050198450684547, 16.372386664152145, 21.233036443591118, 28.24304848909378, 22.507818639278412, 30.30420608818531, 45.68301446735859, 22.515100948512554, 14.971538633108139, 1.0985463461838663, 2.2569653671234846, 2.1265542274340987, 0.8130317449104041, 0.7451416191179305, 1.0078689618967474, 0.3159721044357866, 0.47023438615724444, 0.15488648728933185, 0.4322277271421626, 0.21952679293463007, 0.372448562993668, 0.5689187126699835, 1.538032426033169, 0.3566185530507937, 0.3188137582037598, 2.108731521293521, 12.850236911326647, 19.003735966980457, 1.0379417357034981, 0.3141822520410642, 0.10636870167218149, 0.23442926671123132, 0.21020908432547003, 0.26991272752638906, 2.393322237767279, 0.6795737030915916, 1.3906363165006042, 0.33513575268443674, 0.22525882988702506, 0.17834348953329027, 0.43991931597702205, 0.23634587792912498, 0.3451476513873786, 5.179796079173684, 29.386082254350185, 30.32529305666685, 31.002563014626503, 18.134773895144463, 25.896976478397846, 17.835743241012096, 24.29592479020357, 29.483797810971737, 24.250505827367306, 27.09353607147932, 28.378490321338177, 23.0223186314106, 26.188529133796692, 29.276883713901043, 34.05444525182247, 32.816122099757195, 19.573844075202942, 11.496511101722717, 31.458576545119286, 46.8869798630476, 41.3380616158247, 59.960166960954666, 72.7639751136303, 25.797041840851307, 8.018072303384542, 16.337466537952423, 50.63149273395538, 56.21387578547001, 55.74803218245506, 57.64125019311905, 60.61701871454716, 62.03678973019123, 68.89158010482788, 57.64318808913231, 64.5909632742405, 70.2241761982441, 70.38020342588425, 64.85494270920753, 68.80451157689095, 68.51457193493843, 68.04854214191437, 66.26533582806587, 72.87441238760948, 32.36615404486656, 44.39725086092949, 21.91454127430916, 64.0616212785244, 69.79075625538826, 84.92005482316017, 42.979717925190926, 53.253975212574005, 60.33239498734474, 86.73034608364105, 19.038506001234055, 0.8052304666489363, 0.4942521848715842, 0.23951435869093984, 0.19929687143303454, 0.22109907731646672, 0.27065324247814715, 0.18845640937797725, 0.15679573640227318, 0.3311710513662547, 0.17617144592804834, 0.13950828200904652, 0.2370527439052239, 0.15113047789782286, 0.1291288124048151], [0.03351040184497833, 0.026879581382672768, 0.013222479647083674, 0.008981943374237744, 0.07283273283974268, 0.07973774161655456, 0.04150709130044561, 0.062341028242371976, 0.04848021810175851, 0.11905240622581914, 0.09424321091501042, 0.09200815897202119, 0.033649365286692046, 0.21322477172361687, 0.10120968436240219, 0.29007664241362363, 0.19713411951670423, 1.350400394294411, 0.196299351810012, 35.55193729698658, 89.66556698083878, 56.909766644239426, 27.29587521404028, 66.98071584105492, 78.13257783651352, 36.143972128629684, 56.609221771359444, 25.397850461304188, 34.15129065513611, 27.563462555408478, 22.95271396636963, 40.92277429997921, 87.9622931778431, 58.45267005264759, 65.33968269824982, 57.05541282892227, 68.32387536764145, 65.28319492936134, 70.17278015613556, 32.7142533659935, 44.26034040749073, 72.29884967207909, 57.50672981142998, 61.33097380399704, 48.82879726588726, 43.21109510958195, 53.54797683656216, 60.65014533698559, 4.627986364066601, 11.984364073723555, 59.36907447874546, 57.28750437498093, 36.97521932423115, 48.44265058636665, 42.428667694330215, 9.79645287618041, 23.6200949549675, 23.12756158411503, 25.33155731856823, 21.454154178500175, 21.694951057434082, 15.884327553212643, 19.974469877779484, 17.52272553741932, 6.5292466431856155, 6.660533873364329, 16.506599262356758, 24.91899635642767, 17.44916718453169, 22.341970838606358, 39.00418125092983, 18.55949990451336, 4.913288354873657, 0.3928162716329098, 0.6140845734626055, 0.5753998586442322, 0.5449819564819336, 0.14738423516973853, 0.8448167424649, 0.03630671781138517, 0.14799941622186452, 0.1571941509610042, 0.11227633076487109, 0.23932393844006583, 0.04812718958419282, 0.021099139703437686, 0.11421316550695337, 0.0829939590767026, 0.013860850958735682, 0.272514044190757, 0.6508174992632121, 8.182802014052868, 0.5910093022976071, 0.08499623640091158, 0.020468490438361187, 0.10267891411785968, 0.16213719587540254, 0.9569977666251361, 0.7713984476868063, 0.06672922128927894, 0.11184387389221229, 0.1282724185148254, 0.3493443480692804, 0.059776162161142565, 0.02839774464518996, 0.016847409060574137, 0.1496204300201498, 0.3438709198962897, 13.854904901236296, 28.165891729295254, 30.236723609268665, 16.533858999609947, 18.90612680464983, 18.583051040768623, 13.453813623636961, 10.03620671108365, 11.368780955672264, 15.036333706229925, 19.24573928117752, 19.92037408053875, 18.89750886708498, 22.70231880247593, 24.02192149311304, 18.94260484725237, 26.04912981390953, 21.494388319551945, 7.310783956199884, 12.478044982999563, 27.790952548384666, 28.267019502818584, 40.665626898407936, 69.1382248699665, 15.507013499736786, 1.0864727315492928, 3.8421141961589456, 36.47739663720131, 53.33323135972023, 51.73134371638298, 54.604491144418716, 55.83727419376373, 48.47662076354027, 57.8513865172863, 58.67387518286705, 65.55247887969017, 55.00703774392605, 61.56693734228611, 57.299910709261894, 63.94837215542793, 56.66333086788654, 67.51273289322853, 48.7721499055624, 25.092865526676178, 15.504329893738031, 28.608674369752407, 49.1881287842989, 56.109658777713776, 55.4021405428648, 33.28511193394661, 47.37882927060127, 53.374155163764954, 25.298668183386326, 0.895333606749773, 0.05092362429422792, 0.2666300005512312, 0.05285841070872266, 0.029236570044304244, 0.050580815150169656, 0.09018827928230166, 0.041495187251712196, 0.05261949852865655, 0.1849686269997619, 0.03226788707252126, 0.10637270926963538, 0.030126477468002122, 0.05128723583766259, 0.09086181540624239, 0.00970093511568848, 0.026806429741554894, 0.02011083091929322, 0.016528704873053357, 0.06973893439862877, 0.07720102890743874, 0.029957202859804966, 0.010929927029792452, 0.08222490112530068, 0.19993771595181897, 0.02687920659809606, 0.17023125139530748, 0.08098989317659289, 0.21185669669648632, 0.0800497479212936, 0.2510711713694036, 0.0731998732953798, 1.2787886057049036, 0.24938088550698012, 33.58981378376484, 101.55264392495155, 63.28009821474552, 28.382837288081646, 77.63999506831169, 75.81670090556145, 40.07629752159119, 52.46781639754772, 26.127624101936817, 35.453533977270126, 27.143531888723373, 25.09336329996586, 48.395350724458694, 78.08547556400299, 63.771218061447144, 71.55412003397942, 64.70255568623543, 73.23867604136467, 70.24943724274635, 75.41486486792564, 38.12103644013405, 49.06546376645565, 75.9323439002037, 61.663197576999664, 62.47851982712746, 48.88248838484287, 48.55585031211376, 68.49273070693016, 59.245125129818916, 5.861852830275893, 20.259692072868347, 60.629501044750214, 57.972163036465645, 46.739448979496956, 57.01743386685848, 69.54526662826538, 18.529105335474014, 25.291473269462585, 26.88665997236967, 24.42355614155531, 23.033531829714775, 20.189568735659122, 19.20051410794258, 17.561703845858574, 13.285393361002207, 6.707801911979914, 6.757366452366114, 16.243598274886608, 21.879714243113995, 15.741771552711725, 27.823074124753475, 45.61950087547302, 21.1139964312315, 8.948426730930805, 0.9104716975707561, 0.3983774216612801, 0.81649478408508, 0.6386333936825395, 0.19191901810700074, 0.4210842907195911, 0.4074210551334545, 0.3379298496292904, 0.2565641625551507, 0.18572594417491928, 0.42770501982886344, 0.19787166587775573, 0.04733565197966527, 0.1840660863672383, 0.036163587210467085, 0.052983021014370024, 0.1878768959431909, 4.523344254121184, 4.8211670480668545, 2.0297824451699853, 1.2601887225173414, 0.08151330024702474, 0.27449911111034453, 0.43225491943303496, 0.8464143192395568, 0.1419550835271366, 0.11179905559401959, 0.26629006722941995, 0.13154273678082973, 0.1654909463832155, 0.12148118097684346, 0.08552528379368596, 0.05129072393174283, 0.27992100454866886, 0.8569323923438787, 18.150305561721325, 32.914772406220436, 32.59297527372837, 17.620429694652557, 19.662343226373196, 18.080837689340115, 13.28329112380743, 14.405263569206, 15.55433426052332, 14.441688414663076, 16.916390173137188, 17.43963159620762, 18.56071773916483, 20.60215249657631, 23.40494479984045, 19.191884770989418, 23.799432031810284, 20.37719316780567, 12.13227303698659, 28.42375349253416, 44.99573014676571, 43.5256764292717, 44.295218735933304, 61.178647577762604, 14.123469740152359, 12.887436915189028, 5.959136160090566, 20.171409510076046, 51.622863337397575, 55.44915162026882, 60.968461856245995, 56.484265476465225, 53.18319261074066, 62.75997452437878, 62.167521715164185, 68.22503507137299, 60.83866462111473, 66.19436323642731, 64.21514064073563, 66.24987065792084, 63.417989015579224, 71.64095297455788, 55.33358082175255, 21.480078287422657, 18.503773994743824, 25.417879186570644, 50.73865458369255, 67.60828256607056, 60.52502565085888, 37.225131914019585, 47.99459382891655, 63.97103413939476, 18.337194733321667, 0.8961161272600293, 0.04844577873882372, 0.1599177290336229, 0.06506210527732037, 0.008767420949880034, 0.12921460467623547, 0.05470397984026931, 0.009515908423054498, 0.01572078250319464, 0.06811731203924865, 0.02905084016674664, 0.03391541038581636, 0.1003339426824823, 0.11274117496213876, 0.05100678936287295, 0.24130786245223135, 0.14400090265553445, 0.1295659225434065, 0.168545477790758, 0.14600669033825397, 0.1826568369870074, 0.1718423649435863, 0.2233166145742871, 0.27420694241300225, 0.25993027724325657, 0.21148407919099554, 0.31476424424909055, 0.20200183644192293, 0.4553033842239529, 0.12579366011777893, 0.3944180638063699, 0.2472980332095176, 1.3995528942905366, 0.28797992679756135, 56.94952391088009, 111.46447286009789, 75.40038004517555, 38.48379157483578, 90.36220639944077, 93.05667981505394, 59.10028450191021, 86.40379160642624, 40.40483549237251, 52.43660107254982, 43.58884043991566, 38.9639338105917, 65.49374163150787, 100.74540004134178, 74.34260800480843, 80.92516958713531, 71.11762225627899, 78.53990837931633, 79.08718541264534, 87.61245355010033, 42.873772010207176, 52.9762177169323, 81.14551216363907, 72.29703336954117, 74.06068593263626, 52.35150843858719, 52.693330496549606, 69.06071662902832, 70.29318049550056, 5.932257352396846, 18.45013227313757, 69.24495354294777, 66.35580897331238, 46.954650431871414, 55.60123845934868, 50.77000670135021, 10.543797723948956, 31.33935034275055, 33.815517872571945, 36.41245812177658, 30.146964825689793, 30.712980553507805, 22.206711396574974, 27.987914979457855, 21.00899286568165, 9.574038460850716, 11.413614749908447, 20.141341723501682, 32.05948390066624, 22.95694123953581, 34.18784849345684, 54.72829230129719, 29.11939736455679, 14.594537112861872, 0.7462411257438362, 0.4971357254544273, 0.7195928588043898, 0.9500705008395016, 0.2641940047033131, 2.013665847480297, 0.26933637564070523, 0.23232927080243826, 0.28674707107711583, 0.42698780831415206, 0.2654796122806147, 0.19680264667840675, 0.11973717846558429, 0.7824407739099115, 0.19488642137730494, 0.12070208918885328, 0.705199824878946, 10.866108778864145, 20.59006154537201, 0.6738219992257655, 0.7177255558781326, 0.09246079484000802, 0.4805721470620483, 0.39756346377544105, 2.8320975182577968, 1.751142565626651, 0.39612794236745685, 0.623402742203325, 0.5971507227513939, 0.6004638480953872, 0.19524860428646207, 0.1505144062684849, 0.1366275764303282, 0.3321456100093201, 4.162481417879462, 29.993686750531197, 34.60720159113407, 38.88489045202732, 21.778947450220585, 23.33634328097105, 23.893718272447586, 18.297686353325844, 16.315359324216843, 19.451032765209675, 22.844262085855007, 24.315717928111553, 29.805357456207275, 25.826777145266533, 27.755779735744, 32.584969103336334, 27.05211639404297, 33.348572328686714, 28.920027762651443, 9.560237601399422, 18.125413097441196, 32.82079204916954, 39.744058549404144, 58.14673326909542, 77.1973568201065, 19.923356920480728, 5.897358600050211, 8.497617971152067, 46.044454872608185, 60.838505029678345, 61.058878004550934, 66.44157037138939, 62.37269930541515, 53.67322951555252, 70.20969897508621, 66.45053789019585, 71.2014077603817, 67.53048554062843, 73.60733985900879, 70.75347259640694, 71.06485068798065, 67.0351593196392, 79.70920443534851, 61.9257140904665, 38.93498696386814, 23.20844404399395, 36.32690571248531, 71.55503198504448, 74.16758939623833, 70.87161585688591, 46.41374945640564, 61.59444406628609, 72.42338418960571, 48.29081833362579, 0.9006513026542962, 0.18741833773674443, 0.2919467951869592, 0.15106366976397112, 0.23544992756797, 0.24154496379196644, 0.1715642079943791, 0.20199284161208197, 0.0999917606532108, 0.1690258551388979, 0.14123825792921707, 0.16487917921040207, 0.21583981812000275, 0.1910389051772654, 0.17915985197760165], [0.027917907209484838, 0.062117938650771976, 0.0509660343232099, 0.04868145515501965, 0.09767105002538301, 0.09610920023988001, 0.10805685014929622, 0.028866282882518135, 0.06900358479470015, 0.06401989245205186, 0.050164644708274864, 0.028500357693701517, 0.09359566480270587, 0.04238633962813765, 0.050117503487854265, 0.1931576625793241, 0.19986004277598113, 0.1595665595959872, 0.2215279347728938, 2.159705786034465, 64.29489836096764, 81.06274500489235, 58.30375224351883, 39.75201532244682, 97.07115679979324, 60.22221989929676, 48.50120164453983, 30.3643948584795, 28.335548825562, 30.083897709846497, 28.269289880990982, 34.64676506817341, 76.43437296152115, 67.5498341023922, 79.05828416347504, 63.230837658047676, 70.4146295785904, 62.86286540329456, 69.74854812026024, 59.874063581228256, 59.810021817684174, 62.71469235420227, 59.14614424109459, 57.057886496186256, 80.46199724078178, 42.25777946412563, 49.84616607427597, 14.54081654548645, 4.996764175593853, 44.83480118215084, 56.68133430182934, 36.612897366285324, 41.90862759947777, 33.87557365000248, 10.867572650313377, 25.693829879164696, 29.099231846630573, 24.557631947100163, 24.514793045818806, 25.505747571587563, 23.881942704319954, 15.88354954496026, 22.263788133859634, 10.854803435504436, 9.427510723471642, 6.010271441191435, 14.315322395414114, 23.212916404008865, 17.028354965150356, 29.52014096081257, 47.58117601275444, 28.301717340946198, 4.732786640524864, 0.720720092067495, 0.21632822550600395, 1.1919450969435275, 0.6066274142358452, 0.3140796278603375, 1.0136448894627392, 0.21681289246771485, 0.7054541737306863, 0.7129981345497072, 0.21507810743059963, 0.11998414294794202, 0.14387138304300606, 0.04179090341494884, 0.24063369550276548, 0.1429675510735251, 0.050862957432400435, 0.39728444593492895, 0.5281175707932562, 2.5444980757310987, 3.256762493401766, 0.7594007696025074, 0.6763368705287576, 0.8147658768575639, 0.364075266988948, 1.5546853886917233, 0.28730629419442266, 0.20685126684838906, 0.1801126211648807, 0.14182865124894306, 0.05373967767809518, 0.0946136613492854, 0.09288095432566479, 0.0958753346640151, 0.35009445156902075, 0.7619189063552767, 13.126743324100971, 38.39589849114418, 39.44167457520962, 21.287434324622154, 18.658691681921482, 15.487544294446707, 10.614951755851507, 7.301360936835408, 11.736411228775978, 16.134048253297806, 14.013123661279678, 21.650276854634285, 21.84889029711485, 20.527108423411846, 23.233591094613075, 25.5110539868474, 22.85982985049486, 29.912340715527534, 31.007571145892143, 11.114566046744585, 5.317102186381817, 19.385628774762154, 28.79728674888611, 41.30752645432949, 65.1227143406868, 7.6402362529188395, 4.417855264618993, 1.824203145224601, 10.639198254793882, 28.7306497246027, 27.30951078236103, 48.156275153160095, 59.38753768801689, 52.40589112043381, 47.50301040709019, 50.80660633742809, 53.63467298448086, 57.810101732611656, 55.60565762221813, 63.07173639535904, 60.215251073241234, 73.19947734475136, 38.26267383992672, 16.7160839214921, 13.660399038344622, 44.75592881441116, 51.019771099090576, 53.803053349256516, 44.168529734015465, 36.093206852674484, 52.76246778666973, 47.5323486328125, 1.2155280564911664, 0.26893451751675457, 0.03862200705043506, 0.06714667935739271, 0.01992809931834927, 0.0617507425340591, 0.04870714088610839, 0.042488125181989744, 0.028880956997454632, 0.02511698992748279, 0.019823803449980915, 0.06725153740262613, 0.05873268768482376, 0.12632634403416887, 0.02699173473956762, 0.08774561152677052, 0.023841393922339194, 0.020657806744566187, 0.036550123695633374, 0.04796196524694096, 0.039428116724593565, 0.07282047256012447, 0.02967639644339215, 0.06679422600427642, 0.06834408268332481, 0.07269936890224926, 0.08452388166915625, 0.026555928925517946, 0.06317990744719282, 0.041214970842702314, 0.018541322169767227, 0.3187879314646125, 0.12479293334763497, 0.263136206776835, 0.17139771458460018, 2.0002824906259775, 64.24597978591919, 96.50890856981277, 54.26586091518402, 50.152870416641235, 96.60417705774307, 64.33296471834183, 49.257516860961914, 29.12552073597908, 26.496149227023125, 30.186934880912304, 25.019440166652203, 40.546594485640526, 71.72547563910484, 70.80307513475418, 82.43925914168358, 66.42027631402016, 77.14412167668343, 68.62938657402992, 74.88921627402306, 71.00781574845314, 65.04952266812325, 65.9033976495266, 63.92980635166168, 62.19735011458397, 72.48490288853645, 47.879570201039314, 54.7140696644783, 18.53470243513584, 11.414134372025728, 46.16864360868931, 55.62796622514725, 47.9011682420969, 55.57736434042454, 57.78428211808205, 18.32565475255251, 25.1632434502244, 29.269295521080494, 24.257092773914337, 23.27209062874317, 25.693265609443188, 22.912580519914627, 18.667254522442818, 15.409626625478268, 9.708561692386866, 5.990539574995637, 9.9393062107265, 13.61962627619505, 21.61289446055889, 15.280305314809084, 35.03318153321743, 55.01635484397411, 32.672770991921425, 13.53103592991829, 1.6921964474022388, 0.7233515696134418, 1.9647144991904497, 1.0312577756121755, 0.7766441255807877, 1.6084699588827789, 0.16683933965396136, 1.0973799275234342, 0.9861787164118141, 0.2420425886521116, 0.21791207254864275, 0.09899869284708984, 0.030626184052380268, 0.05881499186216388, 0.07568871747935191, 0.032667730265529826, 0.4234138032188639, 1.2261566799134016, 2.9298235243186355, 6.282888287678361, 1.8479067482985556, 1.1596955149434507, 0.9051357745192945, 0.6344915565568954, 1.0085731116123497, 0.20311165892053396, 0.18828896601917222, 0.07776652317261323, 0.1930323732085526, 0.07184065209003165, 0.02006103466555942, 0.25248332996852696, 0.45343085657805204, 0.17610719078220427, 0.2290036328486167, 20.16803529113531, 41.30638651549816, 40.186685398221016, 19.361484870314598, 18.647033907473087, 18.73182635754347, 13.208993710577488, 10.230475086718798, 11.551770586520433, 15.441998988389969, 12.20960458740592, 18.416684567928314, 18.820534497499466, 20.681435242295265, 20.61373807489872, 26.903907246887684, 22.832862697541714, 30.89496038854122, 26.508711352944374, 15.826462358236313, 15.391702987253666, 40.96868343651295, 46.105380803346634, 44.52153839170933, 52.68567390739918, 9.83969645574689, 21.204152293503284, 3.2469188841059804, 7.415664978325367, 21.483980678021908, 22.102479189634323, 44.0231267362833, 60.824844762682915, 59.4746670126915, 55.031139850616455, 56.000342443585396, 61.40343211591244, 63.649176210165024, 64.04175594449043, 68.37754368782043, 61.19674600660801, 73.23762729763985, 38.771812319755554, 21.77712544798851, 20.756431818008423, 37.32057899236679, 59.64560844004154, 60.393351316452026, 54.3648874014616, 38.88850785791874, 64.3486350774765, 41.08905717730522, 1.8420655117370188, 0.2889899304136634, 0.3013821638887748, 0.03228544628655072, 0.0726741729886271, 0.10311384234228171, 0.06438022741349414, 0.032769942554295994, 0.08757225325098261, 0.05801740204333328, 0.050828221210394986, 0.07532766263466328, 0.05114091400173493, 0.09436976935830899, 0.01910340812173672, 0.07342985001741908, 0.09813855853280984, 0.20452847820706666, 0.23180893622338772, 0.12474067130824551, 0.20049827493494377, 0.24125322554027662, 0.22984938434092328, 0.24323527934029698, 0.24670170270837843, 0.09534309603623115, 0.19147867220453918, 0.24833070201566443, 0.2571155782788992, 0.20124784408835694, 0.07212848664494231, 0.39524297579191625, 0.41840130812488496, 0.5934764980338514, 0.37070415972266346, 3.81995877251029, 95.07738098502159, 102.63994798064232, 77.01016366481781, 58.87415483593941, 112.80526891350746, 78.92539009451866, 82.30189651250839, 44.99788463115692, 42.881428599357605, 46.35671831667423, 43.405450880527496, 53.91920551657677, 94.88615244626999, 84.45638850331306, 94.65613558888435, 76.75414860248566, 87.91421055793762, 77.26940855383873, 84.91546466946602, 74.87269476056099, 72.22133383154869, 70.54058521986008, 71.72671437263489, 63.270959705114365, 90.433748960495, 50.732004940509796, 68.9703118801117, 18.608505874872208, 8.833206463605165, 50.533222407102585, 65.84344446659088, 46.27494290471077, 50.35201773047447, 38.53142201900482, 11.945787593722343, 33.74186262488365, 39.432669058442116, 33.11613120138645, 32.92258098721504, 33.100354447960854, 28.22162713855505, 24.08348958939314, 28.650817908346653, 14.707992374897003, 16.69683415442705, 13.507923670113087, 19.011719338595867, 30.14975007623434, 24.160395562648773, 39.176604598760605, 60.75767956674099, 38.32386955618858, 23.016031868755817, 1.6410093940794468, 0.4688295006053522, 1.3560725399293005, 1.0935866623185575, 0.7683967868797481, 2.5677086552605033, 0.11589159184950404, 0.9596451558172703, 2.145676463842392, 0.3610286914044991, 0.38777489215135574, 0.18050898739602417, 0.1970431618974544, 1.2443416728638113, 0.3846097213681787, 0.20702767535112798, 0.2851490490138531, 1.041122165042907, 10.010212305933237, 8.861911073327065, 1.3720840495079756, 2.532941233366728, 2.9642036044970155, 0.9798140579368919, 4.000439113005996, 0.9367503155954182, 0.44190399697981775, 0.26115446467883885, 0.24839871242875233, 0.08527878686436452, 0.11592097347602248, 0.37197715078946203, 0.48732806579209864, 0.7568540750071406, 0.9419008798431605, 32.97338806092739, 45.177383199334145, 47.642098143696785, 23.613169826567173, 24.61729444563389, 24.123092964291573, 16.031119376420975, 16.39367312192917, 17.138830237090588, 23.677118495106697, 19.47665859013796, 26.87401045113802, 28.656502403318882, 26.809531711041927, 26.86637856066227, 37.55501501262188, 32.84375801682472, 39.0082698315382, 42.99256503582001, 15.704684592783451, 9.017682764679193, 26.31453227251768, 39.36527967453003, 57.04632371664047, 70.91541990637779, 12.31467179954052, 10.662797838449478, 4.050872856751084, 15.032322071492672, 33.305851221084595, 31.92938268184662, 60.89162237942219, 70.7742802798748, 61.84315212070942, 62.22731530666351, 59.789544716477394, 64.8355333507061, 66.50636449456215, 64.04919594526291, 75.06982818245888, 66.98110342025757, 81.29833996295929, 52.554592341184616, 28.416989855468273, 19.80452209711075, 65.60708954930305, 67.7454400062561, 71.97539582848549, 62.65462897717953, 49.70310755074024, 70.6729245185852, 73.75231727957726, 3.309692465700209, 0.6361620419193059, 0.38551534933503717, 0.18950343132019043, 0.2521673828596249, 0.2293389054830186, 0.08992633825982921, 0.2162235084688291, 0.14100724220043048, 0.2371560805477202, 0.18459384242305532, 0.16646311531076208, 0.19040209794184193, 0.25754073983989656, 0.18458052829373628, 0.22935321409022436], [0.0427859638875816, 0.04348973881860729, 0.08140173318679444, 0.13873882329789922, 0.08003583265235648, 0.12167093329480849, 0.028631129680434242, 0.08152784634148702, 0.037161174695938826, 0.0369184812734602, 0.19513962732162327, 0.03071354040002916, 0.252409887034446, 0.06365010995068587, 0.14128004084341228, 0.046649911237182096, 0.25042473105713725, 0.059906917449552566, 0.8853236376307905, 0.3919438028242439, 12.678090948611498, 82.05195352435112, 76.38592556118965, 45.392337664961815, 63.17441448569298, 90.78564047813416, 69.52116072177887, 50.567454770207405, 28.29240784049034, 29.4797358289361, 30.150103457272053, 33.12953308224678, 76.3573206961155, 79.28217574954033, 63.391128256917, 71.396664083004, 68.07256445288658, 68.59282493591309, 63.38243432343006, 65.74634447693825, 63.57245072722435, 64.0279170870781, 57.21538424491882, 58.452202677726746, 59.88746166229248, 63.71465429663658, 22.675047665834427, 1.1094090132974088, 27.803187891840935, 61.48690223693848, 40.39249375462532, 34.403768107295036, 29.241382218897343, 13.768560234457254, 32.55001857876778, 31.320505253970623, 28.605129159986973, 25.294180624186993, 24.02011089026928, 24.197397977113724, 19.117450565099716, 22.238620184361935, 18.699938468635082, 7.467467123642564, 5.57925914414227, 4.487466579303145, 15.295583344995975, 17.502561919391155, 18.644691333174706, 40.84363974630833, 50.2900430560112, 32.1995709836483, 3.305575861595571, 2.8516809549182653, 0.5627469532191753, 1.2380329426378012, 0.6837476009968668, 0.5885239387862384, 0.5514694552402943, 0.4794704436790198, 0.8522420190274715, 1.4322737697511911, 0.06541741589899175, 0.3781937953317538, 0.0558819092111662, 0.5386984592769295, 0.12912189558846876, 0.08899738459149376, 0.49272736825514585, 0.17656019772402942, 0.3613012674031779, 0.31055249681230634, 4.7910878621041775, 3.1556093087419868, 0.7085483358241618, 0.2293343932251446, 0.478482615435496, 0.14470006513874978, 0.1792739942902699, 0.011585387219383847, 0.11593474773690104, 0.3089331305818632, 0.0660511506430339, 0.5823339521884918, 0.38235662039369345, 0.313273121137172, 0.7775053731165826, 0.6771839282009751, 14.613509494811296, 39.9504254758358, 46.11951224505901, 31.469652950763702, 24.07916732132435, 17.41426605731249, 11.658170577138662, 12.725772690027952, 13.736584950238466, 14.497697409242392, 16.36724554002285, 16.707617975771427, 21.509864889085293, 21.4143019169569, 22.932172268629074, 21.027760058641434, 20.507780760526657, 19.287202656269073, 28.6184436455369, 35.01221805810928, 23.031662330031395, 6.792205832898617, 19.498395323753357, 32.047966718673706, 50.57752043008804, 57.143172919750214, 6.057662973180413, 11.381443776190281, 0.717758625978604, 0.562440772773698, 0.395875166868791, 3.068113303743303, 21.583415642380714, 45.35298317670822, 52.390684336423874, 47.483844235539436, 55.69722890853882, 55.592814311385155, 59.95542101562023, 50.87976761162281, 37.167823389172554, 40.31455233693123, 26.227007769048214, 11.482503153383732, 25.01644402742386, 51.84799745678902, 54.986883625388145, 54.631245508790016, 40.518004819750786, 44.64857317507267, 62.051988914608955, 7.354680625721812, 0.906665608054027, 0.07624281235621311, 0.2191426424542442, 0.11516948216012679, 0.020697277868748643, 0.07516652010963298, 0.06942441963474266, 0.03981889458373189, 0.08918450970668346, 0.10033677768660709, 0.0462995618727291, 0.05225035798503086, 0.03210443646821659, 0.013236502527433913, 0.10128550959052518, 0.10968112197588198, 0.03797573743213434, 0.06494653061963618, 0.06322603192529641, 0.10654221579898149, 0.06282616275711916, 0.07136899497709237, 0.029616338142659515, 0.08598842105129734, 0.0651876321353484, 0.018229532943223603, 0.1745787970139645, 0.04488801183470059, 0.11817166989203542, 0.003066546314585139, 0.35258403047919273, 0.07073182408930734, 0.2145664708223194, 0.026514765704632737, 0.7148339110426605, 0.10019698675023392, 10.347154475748539, 94.17898759245872, 83.52471649646759, 49.78960230946541, 73.1783276796341, 90.40873870253563, 73.40751618146896, 40.85592068731785, 22.723403871059418, 28.107540160417557, 23.30220401287079, 38.06604579091072, 81.33603394031525, 80.13997972011566, 69.6810257434845, 76.29516363143921, 73.1144455075264, 69.82630714774132, 71.25664919614792, 70.4631681740284, 66.8212080001831, 69.83098849654198, 62.14517891407013, 62.80426114797592, 65.42247265577316, 63.75246226787567, 22.956527061760426, 7.774862553924322, 31.076947823166847, 58.038579672575, 49.16973777115345, 53.209863379597664, 47.48054601252079, 20.96094634383917, 32.201204895973206, 30.914170257747173, 28.61407957971096, 24.387494176626205, 23.255232833325863, 24.770365431904793, 19.781417436897755, 19.26628477871418, 13.501866795122623, 8.758269734680653, 6.640289984643459, 5.627833837643266, 14.814127329736948, 19.26718533039093, 14.987436980009079, 44.428014010190964, 57.272092401981354, 40.39411626756191, 17.009686566889286, 3.3292713901028037, 0.4586692317388952, 0.9012874716427177, 0.8070041995961219, 1.0341318463906646, 1.2100391322746873, 0.3636334219481796, 0.7649193203542382, 0.512384515022859, 0.15779255947563797, 2.119104489684105, 0.2557296917075291, 0.2679002605145797, 0.035605703669716604, 0.014703170945722377, 0.28202816960401833, 0.15788957301992923, 0.9648138284683228, 1.8852978106588125, 10.852381065487862, 3.5948353400453925, 0.7334409782197326, 0.38498248730320483, 0.7251524354796857, 0.6430013780482113, 0.3099291224498302, 0.07855394185753539, 0.23731700784992427, 0.5039090104401112, 0.21269118238706142, 0.32022419502027333, 0.46788694337010384, 0.22639685397734866, 0.8167287090327591, 1.5528150578029454, 24.205734729766846, 45.437931418418884, 55.192988365888596, 23.491593450307846, 21.7339825630188, 17.523303106427193, 15.300123151391745, 14.044073950499296, 13.63984214141965, 13.043222855776548, 14.977527111768723, 12.367497514933348, 15.699457973241806, 17.698418609797955, 21.62317480891943, 17.50409133732319, 20.565317273139954, 15.624563992023468, 24.47981782257557, 25.996077060699463, 21.586651168763638, 11.101692337542772, 41.12005211412907, 51.47812530398369, 51.91722594201565, 42.286122143268585, 7.64665505848825, 26.06667347252369, 4.030215740203857, 1.561951192561537, 0.21286150527885184, 0.9777488687541336, 14.988765008747578, 41.15816406905651, 57.65442408621311, 53.98023784160614, 57.168950736522675, 60.245128870010376, 60.50947308540344, 47.641421779990196, 27.41459984332323, 34.59056608378887, 31.283356547355652, 17.72007554769516, 26.971967294812202, 51.28335915505886, 64.2054283618927, 63.91767740249634, 49.953377321362495, 53.72385799884796, 64.87784788012505, 4.0916793420910835, 0.5536536255385727, 0.12797316972864792, 0.10112663061590865, 0.0648429935972672, 0.044950615701964125, 0.01991099281440256, 0.09720283647766337, 0.07485729685868137, 0.03949917736463249, 0.1814165449468419, 0.021285990223987028, 0.1379614681354724, 0.06156609990284778, 0.011217808896617498, 0.059636890728143044, 0.055682405072730035, 0.17078176169889048, 0.13291832234244794, 0.23500909184804186, 0.2265586718567647, 0.16853342531248927, 0.2408066752832383, 0.18339058355195448, 0.14762004517251626, 0.277925874106586, 0.20330509229097515, 0.2497655851766467, 0.1940447962260805, 0.3345613006968051, 0.21784162789117545, 0.45198411389719695, 0.2620358986314386, 0.6324649590533227, 0.2277359555591829, 1.2894228100776672, 0.4917309310985729, 23.625416569411755, 119.85617056488991, 89.85658273100853, 65.37069663405418, 83.7861804664135, 106.84895932674408, 98.97552341222763, 80.5713401734829, 41.71878218650818, 50.87473668158054, 44.817014336586, 59.588463306427, 98.6740779876709, 96.1263906955719, 79.70591381192207, 88.36068660020828, 84.97375354170799, 79.74033236503601, 76.81612327694893, 80.03648847341537, 70.42224436998367, 78.39327424764633, 65.1486973464489, 70.6622850894928, 71.65350750088692, 78.31005871295929, 33.23183499276638, 3.7565933726727962, 32.74882011115551, 73.92826303839684, 51.725970804691315, 44.522283151745796, 33.433159589767456, 16.602272428572178, 45.0254787504673, 40.05421690642834, 35.62920235097408, 31.991387754678726, 34.8579653352499, 30.789033472537994, 25.133705735206604, 30.689666904509068, 24.674948751926422, 14.757022093981504, 13.447562959045172, 8.227118086069822, 22.371105775237083, 24.56734422594309, 23.197928108274937, 47.98225589096546, 62.32633799314499, 46.60446122288704, 32.50051483511925, 7.389210322871804, 0.3281641361536458, 1.2684722780250013, 0.7124420581385493, 1.0003945254720747, 1.102541594300419, 0.45229531126096845, 0.7399181462824345, 2.0930568873882294, 0.26146129821427166, 1.9512223731726408, 0.19384947780054063, 0.8708393492270261, 0.18488522444386035, 0.17894302611239254, 0.8065995806828141, 0.18780346785206348, 1.0149130714125931, 5.437526749446988, 16.735006906092167, 12.867316044867039, 2.5239274045452476, 1.0474000219255686, 1.7995960218831897, 1.9617612264119089, 0.8642289508134127, 0.14676135062472895, 0.3502578131156042, 0.41400274727493525, 0.6839325441978872, 0.9077282447833568, 0.44573724910151213, 0.4215217719320208, 1.0322428727522492, 1.831492935307324, 34.27515260875225, 50.22148333489895, 61.0907468944788, 32.983708307147026, 29.325532503426075, 23.896273635327816, 20.7680743932724, 20.893355570733547, 23.923214189708233, 22.40037750452757, 24.38703630119562, 20.64209785312414, 28.028601296246052, 28.945188112556934, 31.38595674186945, 24.826832301914692, 32.10924983024597, 23.966296277940273, 38.127233907580376, 46.20372332632542, 31.727054938673973, 9.031842704862356, 29.144700206816196, 43.041149228811264, 66.04935541749, 60.91607786715031, 8.691928144544363, 14.817986022680998, 1.4557541348040104, 0.8860801532864571, 0.5915916210506111, 2.599158617667854, 30.664939731359482, 60.07800243794918, 68.69823127985, 60.29744066298008, 65.19051790237427, 65.58098495006561, 71.23196572065353, 56.30746476352215, 49.64762672781944, 44.93244834244251, 41.833171248435974, 17.759215347468853, 32.140928730368614, 76.22923716902733, 74.54037219285965, 65.51388055086136, 60.150810331106186, 58.593425899744034, 86.96470990777016, 16.510817036032677, 1.4270269637927413, 0.393514038878493, 0.3731957572745159, 0.21721252414863557, 0.13667930412339047, 0.18951383623061702, 0.21035668265540153, 0.2604634955059737, 0.17237353487871587, 0.3124349989229813, 0.23574245249619707, 0.19215420470573008, 0.18693416059250012, 0.10000838476116769, 0.19090681773377582, 0.29187673644628376], [0.03284936348791234, 0.066989522165386, 0.022542937913385686, 0.08029628937947564, 0.04663232233724557, 0.028734883780998643, 0.06019619919243269, 0.024902848781493958, 0.01539770335512003, 0.055147361126728356, 0.09291820271755569, 0.10064348505693488, 0.0573490572423907, 0.12734111223835498, 0.0994488870492205, 0.0705966938403435, 0.046012629027245566, 0.058495478733675554, 0.08334218960953876, 0.5213093454949558, 0.09055717120645568, 36.387352868914604, 83.97399678826332, 55.34247234463692, 49.23885606229305, 73.21827113628387, 77.7694009244442, 57.05146104097366, 31.700690053403378, 25.58194298297167, 32.13001191616058, 25.541157871484756, 66.6412116587162, 62.40836799144745, 63.890037685632706, 69.87670764327049, 66.99191763997078, 68.89020457863808, 67.30059787631035, 63.07911939918995, 64.31769713759422, 53.931482657790184, 67.83088222146034, 45.145312920212746, 35.460392609238625, 25.91371078044176, 3.0528051126748323, 18.167946115136147, 65.12747168540955, 46.54032826423645, 35.20545668900013, 32.78647609055042, 21.033617444336414, 34.547951370477676, 33.35055582225323, 34.16200987994671, 23.759488575160503, 23.15389607101679, 26.505986899137497, 26.729678995907307, 24.52171817421913, 19.980412758886814, 11.179786697030067, 5.409647170454264, 3.294281680136919, 6.381398001685739, 13.046218995004892, 18.035511821508408, 21.738698109984398, 44.673420041799545, 46.195344775915146, 27.07650538533926, 6.837853733450174, 7.832191027700901, 0.4452534281881526, 1.7620722041465342, 0.7998333312571049, 1.4089319785125554, 1.2561135599389672, 0.6996210117358714, 0.7782343996223062, 0.5798374861478806, 0.3642183233750984, 1.3922917214222252, 0.4247222392586991, 0.10520873227505945, 0.054957664469839074, 0.18899385788245127, 0.7738969917409122, 0.8260151732247323, 0.381136410869658, 2.1302692405879498, 3.6043006321415305, 0.7647990330588073, 0.45205942704342306, 0.12621640227735043, 0.1226166743435897, 0.48504756472539157, 0.42207182210404426, 0.1284365518949926, 0.21292801655363292, 0.2714570180978626, 0.4531121486797929, 0.2813255338696763, 0.3474635083694011, 0.7643058313988149, 0.35302914096973836, 1.628973064944148, 20.290932096540928, 41.25302217900753, 54.84271556138992, 33.740236312150955, 21.956369429826736, 22.902476862072945, 12.55972160026431, 10.780678912997246, 10.2303914912045, 9.63378170505166, 11.617318969219923, 15.296134315431118, 19.941301457583904, 23.18869650363922, 23.493392653763294, 26.595303006470203, 25.451741069555283, 28.692400977015495, 29.549498185515404, 31.5005224943161, 35.14438256621361, 34.22330439090729, 10.653994660824537, 18.573990426957607, 34.31568123400211, 60.845409259200096, 44.37092587351799, 8.317689076066017, 17.308519631624222, 3.3493393007665873, 1.8225771887227893, 0.49952600500546396, 0.10900455788942054, 0.798477279022336, 23.774256482720375, 37.15007074177265, 41.623859480023384, 38.145902305841446, 31.560278087854385, 16.02225825190544, 5.9674406144768, 6.830842634662986, 23.62312339246273, 17.806992083787918, 48.66301216185093, 53.60836699604988, 50.65796971321106, 57.54481516778469, 37.49675653874874, 55.823093354701996, 26.80202141404152, 0.6304206093773246, 0.16700694628525525, 0.012378336759866215, 0.03069652109843446, 0.04461597760382574, 0.018903781528933905, 0.10070804448332638, 0.031767961554578505, 0.08026261813938618, 0.07153568876674399, 0.10060066313599236, 0.0476388081733603, 0.0030825655721855583, 0.1501582792843692, 0.021351790892367717, 0.09000982987345196, 0.10952791300951503, 0.08000016503501683, 0.06983996296185069, 0.023802776267984882, 0.0328100222395733, 0.0297107560254517, 0.05767773589468561, 0.02182430889661191, 0.027241870047873817, 0.0082882059905387, 0.04965660751622636, 0.06922350541572087, 0.07055656591546722, 0.021996119794494007, 0.14257670642109588, 0.09949800980393775, 0.2246757096145302, 0.019808045799436513, 0.039036359230522066, 0.010923784830083605, 0.4983106639701873, 0.0753343642281834, 33.481755182147026, 91.78782150149345, 59.73368011415005, 60.76179474592209, 76.65286883711815, 86.07010871171951, 54.51405979692936, 26.568903923034668, 21.58198121935129, 28.760770708322525, 31.341900005936623, 72.14904651045799, 73.41377064585686, 68.04291844367981, 71.14037543535233, 69.41696271300316, 74.1083125770092, 74.57602187991142, 67.94556766748428, 70.48193156719208, 56.253378465771675, 78.20500954985619, 49.7125044465065, 37.92022481560707, 19.03267901390791, 17.662780322134495, 26.210877634584904, 59.3645641207695, 52.33647644519806, 60.18110990524292, 54.843471720814705, 26.45067136734724, 32.11591087281704, 32.57637396454811, 31.626272946596146, 22.814074605703354, 18.734919391572475, 24.706834740936756, 24.931237399578094, 22.391206696629524, 16.33014813065529, 8.586893230676651, 5.607997477054596, 4.60446372628212, 9.008657298982143, 13.238513376563787, 18.019928857684135, 17.1197609603405, 45.5561088770628, 53.58621798455715, 42.72233113646507, 18.109007477760315, 2.0444555953145027, 0.5045393609907478, 1.8590193707495928, 1.367850482929498, 1.923827980645001, 2.1257591200992465, 1.032812842167914, 1.1567268054932356, 0.804728715447709, 0.7336801872588694, 4.9149920884519815, 0.6621542503125966, 0.05163943686056882, 0.10141562292119488, 0.030880503218213562, 0.5096285347826779, 0.508483846206218, 0.8322198246605694, 2.1956668188795447, 8.87924574315548, 1.075464366003871, 0.6881921156309545, 0.20572784822434187, 0.8016671484801918, 0.8838083501905203, 0.3474128642119467, 0.2752910420531407, 0.26907968160230666, 0.4893237602664158, 0.5267494067084044, 0.389005818287842, 0.5165658344049007, 0.6710089626722038, 0.31221553101204336, 2.7045894227921963, 30.652645491063595, 51.17565393447876, 61.03354476392269, 31.207358725368977, 18.970580846071243, 24.185823798179626, 13.13506392762065, 13.765595443546772, 10.523874443024397, 11.066319085657597, 9.463252555578947, 9.612753633409739, 12.298043891787529, 15.882916878908873, 18.33195101469755, 18.31789556890726, 17.125040777027607, 25.8395254611969, 29.216681644320488, 36.18741139769554, 33.456285148859024, 31.003934741020203, 12.91064701974392, 40.31714379787445, 49.38061125576496, 57.246367782354355, 33.06542292237282, 11.67539980262518, 27.43614088743925, 9.895193427801132, 4.610192868858576, 1.2520197546109557, 0.13294875039719045, 0.29058118409011513, 23.129934556782246, 40.00831916928291, 38.37534539401531, 34.0181951969862, 29.25557065755129, 14.796645417809486, 5.431632315739989, 4.9213899951428175, 26.571299694478512, 24.5171470195055, 42.87787578999996, 60.64033426344395, 59.70479406416416, 58.39060418307781, 41.09636038541794, 63.84144589304924, 18.680356219410896, 0.5633190600201488, 0.2642748097423464, 0.0759383908007294, 0.04326827453041915, 0.02138268835551571, 0.05228322770562954, 0.0933726791117806, 0.033685604357742704, 0.14149561990052462, 0.07700330592342652, 0.017864351757452823, 0.06223673051863443, 0.06348003938910551, 0.05032665183534846, 0.029000012327742297, 0.09354870169772767, 0.11652017608867027, 0.13208572170697153, 0.1602201393689029, 0.16430592950200662, 0.28793382458388805, 0.09535905221127905, 0.18520813289796934, 0.14263429708080366, 0.1048462005564943, 0.05614232140942477, 0.12189590794150718, 0.12942700734129176, 0.2387822003220208, 0.26758176041767, 0.2519197133369744, 0.2734383742790669, 0.28641690441872925, 0.19867993891239166, 0.21195553592406213, 0.16087533702375367, 0.633120839484036, 0.18877940688980743, 64.57561209797859, 106.34530395269394, 69.9709577858448, 70.93593120574951, 85.22412970662117, 102.48569145798683, 94.07720625400543, 49.35950718820095, 46.91528834402561, 53.288781344890594, 50.16742363572121, 87.89904177188873, 81.72456309199333, 77.46068269014359, 84.55818504095078, 78.83395940065384, 81.55411183834076, 83.26219618320465, 76.2064915895462, 78.28241139650345, 63.49199004471302, 83.79605233669281, 59.48666296899319, 51.4278008043766, 40.230751633644104, 11.027620062232018, 25.943917259573936, 76.10182240605354, 64.57480654120445, 48.16346816718578, 39.17160786688328, 24.318033903837204, 43.5906795412302, 41.32063955068588, 43.23567979037762, 31.584045812487602, 31.426093988120556, 33.24013374745846, 33.23364369571209, 32.850947231054306, 27.237782031297684, 17.13517103344202, 12.344958074390888, 9.369750022888184, 14.123893417418003, 18.657675236463547, 25.803452096879482, 27.070249021053314, 53.397516310214996, 58.829347640275955, 48.14343184232712, 37.3464860022068, 14.07675789669156, 0.4230205836938694, 2.2379383631050587, 1.2967311241663992, 1.559586888179183, 2.0683783991262317, 0.9410704462788999, 0.9579906414728612, 0.6025147286709398, 0.6465991912409663, 3.5112186893820763, 3.400699719786644, 0.20830657391343266, 0.12844048527767882, 0.4599108744878322, 0.9407643252052367, 0.7460685318801552, 0.5327895982190967, 8.53143710643053, 16.528349295258522, 4.878275608643889, 0.9147032455075532, 0.5248192290309817, 0.8674051647540182, 1.6877582855522633, 0.9836198505945504, 0.6389839248731732, 1.6934816096909344, 2.1783269243314862, 1.2361846980638802, 1.2760389782488346, 0.40360448649153113, 0.7219933799933642, 2.149211699143052, 4.1065645683556795, 38.32353137433529, 51.390699595212936, 65.86021676659584, 44.269760102033615, 25.766312889754772, 32.66981475055218, 19.8794711753726, 17.98234887421131, 15.402598902583122, 16.942128092050552, 18.43111239373684, 23.26008327305317, 24.84055146574974, 31.128609851002693, 32.157720029354095, 34.33094501495361, 31.272760815918446, 42.43749842047691, 35.73902405798435, 40.555854588747025, 42.53679849207401, 48.4785358607769, 13.730083499103785, 26.07994806021452, 44.823587983846664, 71.02607756853104, 49.664881601929665, 11.622558888047934, 22.224654033780098, 4.669651128351688, 2.850297116674483, 0.4466391069581732, 0.16013304091757163, 5.988131929188967, 46.69497236609459, 55.4033412784338, 50.96023969352245, 43.15157890319824, 42.03938998281956, 19.96545296162367, 8.789958134293556, 9.176572188735008, 34.37470726668835, 22.856138348579407, 67.36839383840561, 78.78806546330452, 66.88464179635048, 70.69925710558891, 49.18969430029392, 81.17245271801949, 45.476769134402275, 0.41429723147302866, 0.3823528502834961, 0.23754852823913097, 0.13794125203276053, 0.11816869387985207, 0.24441545741865411, 0.19992027548141778, 0.18462492356775329, 0.2429207126260735, 0.22071664861869067, 0.25828282814472914, 0.2213302266318351, 0.14372431905940175, 0.32959752017632127, 0.15663694648537785, 0.18770286231301725, 0.24292574438732117], [0.036310120558482595, 0.023484055382141378, 0.07116888969903812, 0.03691172030812595, 0.09054093301529065, 0.12602553673787042, 0.010362292596255429, 0.017319177495664917, 0.015110158237803262, 0.03820357676886488, 0.08192304740077816, 0.11876311706146225, 0.18803997547365725, 0.10177123040193692, 0.12102554683224298, 0.0854615110438317, 0.0552294612134574, 0.07439237844664603, 0.023433073547494132, 0.02803049657813972, 0.27469833323266357, 1.9905487191863358, 55.41804648935795, 75.09952738881111, 47.21766471862793, 52.346116527915, 70.47737181186676, 65.11836737394333, 43.73451702296734, 26.645067036151886, 27.607650384306908, 24.12099927663803, 70.68639859557152, 73.09753641486168, 69.36536148190498, 70.67775785923004, 68.18994775414467, 68.86846214532852, 58.707716166973114, 67.19710662961006, 53.34733620285988, 69.37398701906204, 40.641494393348694, 10.747456345707178, 3.083127960562706, 4.43809250369668, 10.641711819916964, 59.277392998337746, 54.519527703523636, 37.63362519443035, 26.325479485094547, 22.269449830055237, 38.570502921938896, 39.41841222345829, 42.71183229982853, 31.28917023539543, 25.483619458973408, 26.368458978831768, 23.515490368008614, 27.546967640519142, 22.671369463205338, 18.065653704106808, 12.032199706882238, 8.6803188174963, 5.262653958052397, 6.563896033912897, 14.148393552750349, 17.652102895081043, 23.429698571562767, 46.224276423454285, 48.6681304872036, 25.516368001699448, 9.395920168608427, 10.278920587152243, 2.345455256290734, 2.7395843574777246, 1.8341640732251108, 0.9904975409153849, 1.4142128638923168, 1.1585834808647633, 1.378653421998024, 1.0562582965940237, 0.5297748162411153, 1.1763314972631633, 0.12035184001433663, 0.20954193809302524, 0.05259162717266008, 0.33649272518232465, 1.104983794502914, 0.21461331518366933, 0.31476347241550684, 1.742815668694675, 6.902159582823515, 1.0704429354518652, 0.0797287913155742, 0.16872145584784448, 0.11658273913781159, 0.22410462697735056, 0.08864422619808465, 0.6174717354588211, 0.38122324214782566, 0.44699299265630543, 0.6980408902745694, 0.21620317362248898, 0.8729762595612556, 0.7346761494409293, 0.6844000378623605, 2.4295984162017703, 23.993504717946053, 44.233848229050636, 56.271712481975555, 36.681730672717094, 23.714084811508656, 22.894590385258198, 19.372430182993412, 14.756529070436954, 11.347290258854628, 8.200508113950491, 12.148207481950521, 12.098587844520807, 14.987770412117243, 21.202301792800426, 18.827051147818565, 19.647736810147762, 31.820472925901413, 27.70708154886961, 21.014787554740906, 22.508852183818817, 22.294245399534702, 33.71577702462673, 44.78890724480152, 11.923531237989664, 28.498712070286274, 45.39298743009567, 66.46272003650665, 29.45206381380558, 16.94186970591545, 29.483626820147038, 2.905546627007425, 2.041429770179093, 0.5825515498872846, 0.6761744292452931, 0.41867887135595083, 10.31040284782648, 11.470990721136332, 13.330755326896906, 11.131777223199606, 4.847764195874333, 1.0156140150502324, 1.944460398517549, 10.128398314118385, 36.664392203092575, 56.91091798245907, 56.14899426698685, 48.15217897295952, 39.25204195082188, 37.79712662100792, 34.161998480558395, 2.2954988619312644, 0.44392887270078063, 0.14531667111441493, 0.04465917059860658, 0.09737432454130612, 0.024757449064054526, 0.03336537134600803, 0.07275122276041657, 0.04012899356894195, 0.11552051058970392, 0.12281873889151029, 0.14686631999211386, 0.06946195004275069, 0.09574291325407103, 0.1704618812073022, 0.0787174073047936, 0.12697509984718636, 0.06205026962561533, 0.04631714335118886, 0.045385510529740714, 0.06669394701020792, 0.06778986164135858, 0.15963281854055822, 0.062374662375077605, 0.024845992847986054, 0.09032411457155831, 0.02127178551745601, 0.06929502618731931, 0.07273106602951884, 0.11430995640694164, 0.06650009061559103, 0.17704867932479829, 0.08881408895831555, 0.1092491252347827, 0.033090542929130606, 0.043858593635377474, 0.012604612948052818, 0.05542069782677572, 0.26709120080340654, 1.5957844583317637, 58.11766482889652, 86.70068487524986, 51.22539706528187, 60.42880341410637, 77.90630757808685, 77.74327352643013, 31.89045377075672, 26.46327719092369, 26.31289456039667, 35.30571810901165, 77.90373891592026, 78.57449412345886, 69.09348607063293, 75.64827874302864, 67.97800272703171, 73.28969970345497, 64.95670884847641, 70.83237916231155, 56.100182086229324, 82.3377513885498, 42.258106246590614, 10.1191714592278, 3.698883019387722, 19.1552110388875, 23.147179931402206, 48.6803924292326, 54.132142290472984, 60.66194370388985, 48.28838646411896, 24.9833782017231, 36.00768864154816, 32.17287361621857, 37.624247297644615, 27.213051058351994, 24.02944128960371, 25.72207186371088, 22.341307774186134, 26.454609856009483, 16.56158421188593, 11.36552358046174, 9.96369805186987, 8.496973905712366, 5.945362849161029, 7.424237793311477, 15.34297725185752, 16.13268982619047, 20.040132254362106, 51.95850692689419, 57.67762944102287, 42.19736650586128, 18.959817923605442, 1.9005123130045831, 1.8110271147452295, 1.8069019610993564, 2.063581394031644, 1.4905557548627257, 1.8081644433550537, 0.5945784389041364, 0.8539603580720723, 1.0972115490585566, 1.0366610856726766, 5.372376870363951, 0.7716888946015388, 0.24745630362303928, 0.32992733060382307, 0.069867823185632, 1.3641899731010199, 0.2799942990532145, 0.9653940692078322, 1.7308934521861374, 6.213787570595741, 0.9338686452247202, 0.21702593337977305, 0.0893713379628025, 0.9756495407782495, 2.668065307661891, 0.7121925777755678, 1.121431093197316, 0.6244958366733044, 1.3942779460921884, 0.4067065450362861, 0.6091513100545853, 0.5902533209882677, 0.6038486945908517, 1.2515691225416958, 3.2239564787596464, 34.76593427360058, 54.259682446718216, 65.74142754077911, 38.76211144030094, 18.02391104400158, 22.45702676475048, 19.50763262808323, 17.511858120560646, 12.801547273993492, 8.553062696009874, 7.172676092013717, 7.284363498911262, 7.769391797482967, 13.784224893897772, 12.760510426014662, 12.574020233005285, 18.3972505107522, 16.656411923468113, 11.45095819607377, 10.064124763011932, 12.598911747336388, 23.785213194787502, 42.04816371202469, 14.802800137549639, 49.51946720480919, 57.096507623791695, 55.37556856870651, 26.32581576704979, 17.073469944298267, 42.46692404150963, 14.343511182814837, 3.1457341136410832, 1.0649293125607073, 0.5960022343788296, 0.1516982208704576, 10.069722812622786, 9.175835028290749, 7.829969096928835, 8.660497181117535, 4.4911158084869385, 1.5931009710766375, 2.991758775897324, 17.147007398307323, 43.181327506899834, 57.077626436948776, 75.14570251107216, 56.85544095933437, 51.86194270849228, 44.29284766316414, 36.16716608405113, 3.7866533221676946, 0.1880181414890103, 0.0699201223324053, 0.03539593562891241, 0.10802570221130736, 0.09361714255646802, 0.011772909383580554, 0.0893240186269395, 0.09392137857503258, 0.06643887827522121, 0.24817070981953293, 0.17191999359056354, 0.04676640615798533, 0.1494977530092001, 0.2346373797627166, 0.07645191988558508, 0.10827457401319407, 0.0770883857330773, 0.15885543369222432, 0.202023729798384, 0.2307923571788706, 0.2931523695588112, 0.40217347734142095, 0.19636087585240602, 0.12626137642655522, 0.257060065632686, 0.08583422502852045, 0.10904948008828796, 0.19197237852495164, 0.23559213790576905, 0.2665585168870166, 0.32769765181001276, 0.2763721434166655, 0.2791300235548988, 0.1443334887153469, 0.44870925368741155, 0.1479085476603359, 0.22625390149187297, 0.3926783805945888, 2.8267918154597282, 89.20674920082092, 98.64662826061249, 66.55252441763878, 70.60896635055542, 93.77431690692902, 102.2324350476265, 75.8061982691288, 42.214013412594795, 49.273707792162895, 46.7570686340332, 94.68746110796928, 88.11186835169792, 82.75583535432816, 88.0784073472023, 80.94001159071922, 84.17864620685577, 74.40082848072052, 77.55719751119614, 64.25699919462204, 86.36545926332474, 56.09534494578838, 18.32965023815632, 8.541339375078678, 9.294132180511951, 20.49631107598543, 63.92326310276985, 73.69731143116951, 47.835116386413574, 37.37697556614876, 26.622108668088913, 55.15159338712692, 46.44873417913914, 57.83600114285946, 35.83490811288357, 34.10124734044075, 35.31698830425739, 31.45372610539198, 33.9036313444376, 28.56117881834507, 24.83191642910242, 19.278977997601032, 17.20543496310711, 11.202336587011814, 11.820752453058958, 19.7658059746027, 25.85828885436058, 26.236442662775517, 57.174156457185745, 65.46256810426712, 44.58579674363136, 41.33603632450104, 18.720497265458107, 2.2294446313753724, 2.366326111368835, 2.019195738248527, 0.8923577726818621, 1.4494697470217943, 1.3029088801704347, 1.3890170096419752, 1.6443236474879086, 0.9203715319745243, 13.66191990673542, 3.900729613378644, 0.25758841540664434, 0.44946202891878784, 0.5732708447612822, 1.409926931373775, 0.24491251824656501, 0.304880915209651, 8.460122533142567, 15.96418596804142, 2.2948756953701377, 0.7092976081185043, 0.41563211765605956, 0.5522825522348285, 1.9462345470674336, 1.3752393051981926, 3.931290660984814, 1.8476757919415832, 2.91170253418386, 0.6390795728657395, 0.9890902508050203, 1.3119802996516228, 0.7389066880568862, 0.998893843498081, 4.374937992542982, 49.859503358602524, 57.86503158509731, 74.2805877327919, 46.874592527747154, 34.48841616511345, 28.42610366642475, 25.690235272049904, 21.259692013263702, 21.139557659626007, 17.064342834055424, 20.24697605520487, 17.16562259942293, 21.20522003620863, 29.083641283214092, 25.703753046691418, 24.242794141173363, 35.36654904484749, 34.208922162652016, 26.234176084399223, 24.585718140006065, 28.26572187244892, 38.34024667739868, 52.34667129814625, 12.550849076360464, 33.58675874769688, 53.571634367108345, 73.89404967427254, 35.96693582832813, 18.732738308608532, 35.47012008726597, 7.251625880599022, 6.309811742976308, 1.0271488898433745, 0.8177841024007648, 0.9395242261234671, 18.51780854165554, 15.586501434445381, 14.983049165457487, 12.71531280130148, 7.807617746293545, 1.7641527112573385, 4.2807115986943245, 20.797824896872044, 43.411006182432175, 87.97965064644814, 79.82699811458588, 66.69915094971657, 61.58755883574486, 56.92642115056515, 64.71593856811523, 6.912982827052474, 0.4484904685523361, 0.17533880076371133, 0.3906451928196475, 0.4017934383591637, 0.12740527832647786, 0.1201075546850916, 0.19318662118166685, 0.22856211435282603, 0.19849496602546424, 0.33093362348154187, 0.2741935837548226, 0.16159501246875152, 0.21882598288357258, 0.2804381924215704, 0.21183708915486932, 0.3708235267549753, 0.10383403729065321], [0.07871573747252114, 0.05872837209608406, 0.051931026682723314, 0.10472767957253382, 0.11857769888592884, 0.04695153489592485, 0.06039928048267029, 0.06721480109263211, 0.09075177717022598, 0.20139729778748006, 0.06997786884312518, 0.03001671939273365, 0.06419224140699953, 0.07453943500877358, 0.1573848383850418, 0.026485222660994623, 0.21660457161488011, 0.1451608052593656, 0.17371800960972905, 0.0634943628392648, 0.5239818489644676, 0.23690480418736115, 14.5236880145967, 74.10338044166565, 57.03411877155304, 42.49263346195221, 57.99719989299774, 65.11265248060226, 54.94803071022034, 24.09446530044079, 30.22160042077303, 23.24257381260395, 57.692106664180756, 54.24658454954624, 59.60409566760063, 75.51330998539925, 70.18143609166145, 62.58101552724838, 66.92775428295135, 50.665915086865425, 57.028677463531494, 24.835279248654842, 1.9207585765980184, 0.8077835140284151, 9.431498609483242, 10.879540108144283, 43.11566703021526, 83.38311329483986, 50.98571352660656, 30.129852443933487, 36.99607640504837, 66.09950512647629, 45.59902757406235, 45.30606709420681, 44.53215882182121, 43.14071908593178, 31.59959077835083, 22.619481347501278, 30.734584294259548, 27.505810149013996, 28.617987670004368, 16.659257970750332, 12.230230830609798, 11.718308050185442, 8.621207289397717, 16.59348350018263, 17.90005289018154, 21.11364495009184, 22.880848422646523, 47.11737670004368, 54.645316153764725, 25.584614239633083, 14.822233244776726, 12.595640122890472, 1.4840287738479674, 1.9600075017660856, 3.4139640955254436, 6.375623736530542, 3.6109576374292374, 0.9697384829632938, 1.0922260978259146, 1.8347625411115587, 0.9487177734263241, 7.187484847381711, 1.6392563818953931, 0.2678973216097802, 0.27187793457414955, 0.07865338964620605, 0.37904394033830613, 0.39888424915261567, 0.5570720764808357, 0.9660304756835103, 3.9622915349900723, 0.16040448885178193, 0.4391569521976635, 0.08265645999927074, 0.38971373811364174, 1.0224896273575723, 0.264874494750984, 0.19198821595637128, 0.07975846237968653, 0.178554734447971, 0.5336017452646047, 1.2006389116868377, 1.775755388662219, 2.845931388437748, 0.3633066691691056, 6.055148458108306, 24.942917972803116, 53.677435889840126, 53.94839555025101, 39.636216536164284, 24.11224454641342, 23.223616629838943, 21.44295047968626, 11.347388103604317, 10.03202123567462, 7.20690893009305, 8.45693165436387, 10.739671513438225, 18.906157203018665, 21.732506342232227, 30.68154104053974, 40.77710531651974, 54.312985986471176, 63.33664298057556, 67.60553911328316, 70.44017940759659, 65.00529304146767, 46.972289085388184, 34.29304584860802, 33.89516159892082, 11.438563261181116, 37.75769233703613, 59.08296503126621, 52.705197259783745, 21.606886982917786, 22.887632958590984, 15.00655185431242, 0.8087128610350192, 0.857724827947095, 0.29564102820586413, 0.20756316458573565, 0.35374198865611106, 0.34475751919671893, 0.4193366813706234, 0.9781987883616239, 0.48095717327669263, 0.16921137721510604, 0.6662582675926387, 9.148445148020983, 31.91425569355488, 59.54543061554432, 55.65421901643276, 36.22279889881611, 29.978996738791466, 30.494570173323154, 10.205255839973688, 0.8133804949466139, 0.14243403595173731, 0.060653299078694545, 0.1710611951421015, 0.12532508291769773, 0.1672841384424828, 0.04147414736507926, 0.06209530314663425, 0.1061887011746876, 0.13682568533113226, 0.1366826141020283, 0.10432211071019992, 0.033552566965227015, 0.14179145480738953, 0.19665963482111692, 0.11419424816267565, 0.055467156271333806, 0.14467106200754642, 0.039019545874907635, 0.095890051452443, 0.15652336820494384, 0.1374166426830925, 0.16609745915047824, 0.06178109266329557, 0.14914735540514812, 0.03031182142876787, 0.1529024593764916, 0.12721969687845558, 0.0469434009573888, 0.04614175530150533, 0.030725214382982813, 0.06569444478373043, 0.27882799913641065, 0.05219741688051727, 0.10004439376643859, 0.2417596968007274, 0.09841664126724936, 0.12805013044271618, 0.3677972563309595, 0.45685975695960224, 14.100451525300741, 83.70775267481804, 62.96278864145279, 52.18064300715923, 70.76805621385574, 77.85431876778603, 55.48775754868984, 27.467240318655968, 36.90842270851135, 36.3278366625309, 66.86266377568245, 51.809938699007034, 60.6294060498476, 75.51277041435242, 71.31034031510353, 68.00979942083359, 73.60907256603241, 56.701697409152985, 61.165587678551674, 25.33375170081854, 2.006700108759105, 1.2577542406506836, 21.64093315601349, 27.687902078032494, 34.4478989392519, 69.19159680604935, 71.27494901418686, 58.45338061451912, 33.68190944194794, 64.42663729190826, 44.05938819050789, 48.348795622587204, 36.34146273136139, 24.447445459663868, 14.722390752285719, 14.485335722565651, 22.518070489168167, 18.704642616212368, 16.043749898672104, 11.499179508537054, 11.02477876469493, 10.911636035889387, 11.24065563082695, 19.831297360360622, 16.447941809892654, 21.096775755286217, 24.70658015459776, 53.09561111032963, 63.9137028157711, 45.7015460729599, 19.915449544787407, 5.921082627028227, 1.287398706190288, 3.5063544753938913, 3.4398411819711328, 5.360065056011081, 4.291937621310353, 1.6809932235628366, 1.1718268389813602, 1.0806934791617095, 1.4480552729219198, 6.910376166924834, 0.929999859072268, 0.6664752715732902, 0.56711167213507, 0.1803023141110316, 0.3574192413361743, 0.21705587161704898, 0.696197870420292, 1.308991878759116, 3.151591974310577, 0.575457033701241, 0.7855936547275633, 0.3992453188402578, 1.5836118115112185, 1.828185806516558, 0.24572977126808837, 0.27627135976217687, 0.15208170341793448, 0.38999064825475216, 0.9151458030100912, 1.614013030193746, 1.376895778812468, 2.843614937737584, 0.66218375810422, 9.117686748504639, 42.693733870983124, 69.91185575723648, 63.26329931616783, 44.44559946656227, 19.602718725800514, 20.626376196742058, 19.022273272275925, 11.093959752470255, 6.996007421985269, 4.927811175584793, 7.5327875185757875, 10.91658242046833, 18.18425104022026, 17.399676740169525, 20.024089515209198, 26.77207712084055, 39.932251051068306, 43.31470414996147, 43.90114948153496, 37.87770889699459, 34.89803798496723, 25.065911673009396, 13.766949120908976, 14.926979374140501, 11.849430464208126, 57.31644742190838, 59.97337885200977, 39.42978501319885, 18.5580350831151, 16.57149028033018, 25.077060274779797, 2.511692773550749, 1.1947365221567452, 0.9711756964679807, 0.923634844366461, 0.9277319151442498, 0.2682043332606554, 0.1987406169064343, 0.24649638013215736, 0.1984272970003076, 0.3510200581513345, 0.6047767354175448, 12.718402035534382, 32.282797917723656, 61.71267852187157, 65.43121978640556, 46.51263155043125, 40.676790699362755, 44.23082739114761, 9.542185720056295, 0.5389978119637817, 0.23268652585102245, 0.05744569229136687, 0.06560201771208085, 0.22037227725377306, 0.007848839723010315, 0.04822956514544785, 0.06119489247794263, 0.08529714017640799, 0.09263603817089461, 0.09726179268909618, 0.05175084435904864, 0.28374104644171894, 0.17272789555136114, 0.16600372589891776, 0.15395792695926502, 0.04294391517760232, 0.15553991863271222, 0.20697903499240056, 0.12703867221716791, 0.30933840258512646, 0.25951238872949034, 0.40243587107397616, 0.1341627407236956, 0.18798643694026396, 0.20536207332042977, 0.25648784008808434, 0.3324039070867002, 0.2017944655381143, 0.08969200513092801, 0.2634245459921658, 0.2116662319167517, 0.4349645006004721, 0.08408000314375386, 0.3140818839892745, 0.5402796494308859, 0.2340816892683506, 0.24821317550959066, 0.9279517689719796, 0.6046843528747559, 24.120609797537327, 111.03356078267097, 75.1610004901886, 62.03217677772045, 81.91297978162766, 97.6445460319519, 98.43343690037727, 46.09434239566326, 49.964472725987434, 47.76673145592213, 80.09160831570625, 67.7279457449913, 74.70887035131454, 89.85551118850708, 81.64044320583344, 77.99247935414314, 82.32868507504463, 73.5415805876255, 82.65549793839455, 36.56086675822735, 4.113179538398981, 1.724781955126673, 13.303391095250845, 22.6153851673007, 46.921937987208366, 109.17363658547401, 65.3983211517334, 41.58763602375984, 38.296138644218445, 90.12443795800209, 49.961102306842804, 57.66173489391804, 47.4590277671814, 49.29727792739868, 39.77256081998348, 29.596549160778522, 32.959663197398186, 34.23754222691059, 36.440888196229935, 26.407251097261906, 17.829560972750187, 19.355296902358532, 14.362164381891489, 24.460598453879356, 25.470589958131313, 29.398021213710308, 29.52478241175413, 55.49504175782204, 62.9667404294014, 51.67208969593048, 49.07513044774532, 30.41617088019848, 0.6891010387334973, 4.924392309039831, 6.112542953342199, 12.050567921251059, 9.036111775785685, 1.8483330379240215, 1.166432078462094, 1.7799628316424787, 1.3853712240234017, 10.98362697288394, 3.162078461609781, 0.8505667245481163, 0.5265559733379632, 0.25232166051864624, 0.3425261186202988, 0.4265669215237722, 0.7425739069003612, 3.1393395317718387, 7.735037840902805, 0.45786266564391553, 0.8401487523224205, 0.2531836798880249, 1.1120567587204278, 2.6128191221505404, 0.3674904227955267, 0.3886856260942295, 0.2797640848439187, 0.37230728776194155, 1.005258858203888, 1.8964043771848083, 1.5380470314994454, 3.6739931674674153, 0.2779970015399158, 14.187959879636765, 66.95157900452614, 70.57165995240211, 70.08854627609253, 58.98346357047558, 33.366606160998344, 31.531798616051674, 25.308479256927967, 17.62207880616188, 15.804957412183285, 12.45261674746871, 14.25681883469224, 20.315573774278164, 25.3611596301198, 26.41398623585701, 42.030829042196274, 52.65411280095577, 69.12206053733826, 81.87742128968239, 87.17364549636841, 84.69304740428925, 79.47690010070801, 62.29441210627556, 40.15621103346348, 37.56401672959328, 10.222880244255066, 43.75724360346794, 61.41916327178478, 53.343551605939865, 24.107926078140736, 25.484884791076183, 19.944738373160362, 0.890400402713567, 1.428507340606302, 0.5847980012185872, 0.5637331190519035, 0.9995497833006084, 0.46945073758251965, 0.41903685370925814, 1.0799642745405436, 0.7239340664818883, 0.49132601532619447, 0.6108088523615152, 14.300906918942928, 38.23328621685505, 85.76921805739403, 70.30165404081345, 61.13469913601875, 54.723299369215965, 67.6121735572815, 22.883802764117718, 1.0695827566087246, 0.3310622228309512, 0.12970516429049894, 0.2854424942051992, 0.43124114570673555, 0.18485723063349724, 0.13680652307812124, 0.25701749604195356, 0.14689762378111482, 0.23367344867438078, 0.17977820942178369, 0.1555310722324066, 0.2785043336916715, 0.25240872928407043, 0.4143276298418641, 0.27655293059069663, 0.2720663807122037, 0.23025808506645262], [0.09596583957318217, 0.03916427209333051, 0.05226785782724619, 0.09458784945309162, 0.038660056961816736, 0.051089271655655466, 0.022012745757820085, 0.0902862947259564, 0.13397368602454662, 0.044446474785218015, 0.015295889043045463, 0.07245035609230399, 0.19129122054437175, 0.11520912026753649, 0.1589408697327599, 0.05220053390075918, 0.04592246550600976, 0.06860810914076865, 0.02204584739956772, 0.08483461147989146, 0.14641156158177182, 0.2457916663843207, 0.30482276051770896, 39.026744440197945, 80.68961262702942, 45.275904312729836, 47.31223024427891, 61.866232082247734, 57.502044662833214, 32.86258980631828, 25.592287927865982, 22.527811266481876, 28.760734610259533, 29.403916597366333, 30.35175483673811, 67.21088469028473, 63.15371699631214, 63.03123436868191, 49.18061278760433, 35.91107502579689, 5.009635034948587, 2.176460986956954, 0.7123067497741431, 4.734976748004556, 27.009123601019382, 31.688762493431568, 88.01661506295204, 62.84675806760788, 35.51428131759167, 33.373776376247406, 52.7166498452425, 57.41475574672222, 44.46999415755272, 52.181330770254135, 67.03320622444153, 82.08591610193253, 80.91793477535248, 56.19955815374851, 57.53485210239887, 41.44009754061699, 30.89934155344963, 25.62180284410715, 21.427090130746365, 15.861449930816889, 14.299433548003435, 17.436825446784496, 26.91657956689596, 15.967339798808098, 19.05951127409935, 41.88465088605881, 54.227893352508545, 35.06455644965172, 12.489900346845388, 12.856916952878237, 4.930595951154828, 2.100466014817357, 1.7520296992734075, 2.342632720246911, 1.4080567192286253, 0.8193445717915893, 0.8169685711618513, 1.2028278317302465, 5.618999786674976, 3.6610558116808534, 0.8417177118826658, 0.10435868374770507, 0.1392636404489167, 0.33017547510098666, 0.5842321878299117, 1.3265000330284238, 1.6085668536834419, 0.40353252785280347, 0.6059186928905547, 0.9686310798861086, 0.09920186319504865, 0.4575996188214049, 1.2873411155305803, 6.284924978390336, 0.5900296673644334, 0.06704999235807918, 0.385089386254549, 0.5781427770853043, 0.7033297908492386, 1.86420822981745, 1.6587811592034996, 1.7727127019315958, 2.277869707904756, 7.35349508933723, 33.228692561388016, 55.41475586593151, 52.5245663523674, 46.86923861503601, 25.449453592300415, 24.515391513705254, 21.219227984547615, 16.252571493387222, 11.047086417675018, 8.601501546800137, 8.670343402773142, 17.387714982032776, 21.213980466127396, 46.1465971916914, 66.02338001132011, 68.7690594792366, 65.79308196902275, 69.82493922114372, 70.04120081663132, 74.30874422192574, 87.7883993089199, 84.0410327911377, 83.18411037325859, 66.16749867796898, 47.40033611655235, 20.121151506900787, 51.71355687081814, 56.55216783285141, 32.6940992474556, 45.868516713380814, 53.636325895786285, 5.222034612670541, 1.2110005994327366, 0.1858874800382182, 0.3536294790683314, 0.2921134221833199, 0.038031747317290865, 0.04882797737082001, 0.6466802337672561, 0.12946965114679188, 0.2762288792291656, 0.3306277102092281, 11.270169597119093, 53.901616260409355, 50.66111974418163, 41.687281876802444, 29.881807453930378, 23.43270990997553, 23.08632619678974, 1.1300728982314467, 0.11811642441898584, 0.16281526652164757, 0.02792581479297951, 0.23598715342814103, 0.06619458552449942, 0.06740224533132277, 0.1306256648967974, 0.09507593771559186, 0.17265258240513504, 0.10223628240055405, 0.20758810074767098, 0.1261034919298254, 0.06969823502004147, 0.05726804069126956, 0.2259357724688016, 0.203441810735967, 0.16428972099674866, 0.15306421788409352, 0.09415370790520683, 0.07268367990036495, 0.04958129437000025, 0.09971919207600877, 0.048135906108655035, 0.06195672191097401, 0.044858340770588256, 0.16814952716231346, 0.06127128915977664, 0.0790913680975791, 0.07136850515962578, 0.033729854912962765, 0.19159610965289176, 0.15772725048009306, 0.10723077299189754, 0.03981890571594704, 0.03464518646069337, 0.03918237307516392, 0.034717790767899714, 0.032057529024314135, 0.1207249028084334, 0.258375151315704, 0.8890142489690334, 41.295446902513504, 87.2382040321827, 55.58357700705528, 64.39722687005997, 80.57422041893005, 76.71579346060753, 40.96136502921581, 37.193893790245056, 38.85619059205055, 27.298827655613422, 22.767623998224735, 25.263936147093773, 62.25057005882263, 66.80375933647156, 68.5761134326458, 51.79211765527725, 45.49905873835087, 8.891815468668938, 1.0972218797542155, 0.767448500264436, 10.701356269419193, 45.397182404994965, 25.878201685845852, 66.86370491981506, 75.12796506285667, 67.92587712407112, 37.75358095765114, 58.07386077940464, 53.02161768078804, 28.09339351952076, 25.052086114883423, 33.98367404937744, 61.78535342216492, 52.04033173620701, 40.114439874887466, 33.250887170434, 20.55042017251253, 20.88166929781437, 19.87135861068964, 19.87871501594782, 20.861745066940784, 17.707589417696, 22.200042754411697, 30.771221928298473, 19.51563499867916, 20.71041628718376, 46.21093153953552, 63.13905358314514, 63.381434977054596, 42.04255521297455, 12.3621179535985, 2.936123348772526, 4.207044951617718, 1.8911135173402727, 3.336700703948736, 1.085936010349542, 1.1832003411836922, 0.444716380443424, 1.0923185991123319, 3.3712125895544887, 3.269603904336691, 4.348852392286062, 0.05454726793686859, 0.2970762230688706, 0.39169553958345205, 1.0641830088570714, 0.830245177494362, 1.760936421342194, 0.4843970277579501, 4.390971707180142, 5.715245772153139, 1.5164291602559388, 3.217399218119681, 3.70862593408674, 6.596720572561026, 0.22284346574451774, 0.07286808133358136, 0.3063279250636697, 1.2979265162721276, 0.3751528006978333, 1.6531692165881395, 2.3016281705349684, 1.9524438888765872, 1.5042468952015042, 18.888387456536293, 41.18737310171127, 66.42722994089127, 63.690081015229225, 54.164900332689285, 25.497678704559803, 20.22015329450369, 14.505790024995804, 8.581904098391533, 7.726877778768539, 7.486762963235378, 11.09760470688343, 19.83454428613186, 22.606744430959225, 39.21071536839008, 64.1995994746685, 70.67006707191467, 74.33910459280014, 70.90346574783325, 68.13974484801292, 71.8873393535614, 80.62771394848824, 79.69090461730957, 68.12246337532997, 37.40065969526768, 19.247722774744034, 13.94016282632947, 59.72156636416912, 47.2265600413084, 24.8697566986084, 35.64191646873951, 42.39582605659962, 11.61028079688549, 1.0008374392054975, 0.7643334392923862, 1.491892570629716, 1.7388951103202999, 0.08058856197749265, 0.09470133125432767, 0.4798628913704306, 0.48103863140568137, 0.21143708640011027, 0.760022095637396, 11.641126591712236, 38.91871243715286, 53.00076439976692, 47.50508509576321, 36.89887382090092, 38.27954113483429, 24.280794002115726, 1.0899646254256368, 0.09204484333167784, 0.07134952844353393, 0.06403330306056887, 0.4170931095723063, 0.2179462558706291, 0.13584210217231885, 0.09688605816336349, 0.014676547325507272, 0.17171578423585743, 0.12375764476018958, 0.49681986740324646, 0.17046048596967012, 0.11970983774517663, 0.4169117583660409, 0.14631575031671673, 0.2230562988552265, 0.1504843492875807, 0.09738137494423427, 0.2726938220439479, 0.2088538187672384, 0.10964450440951623, 0.1948206522502005, 0.20400562032591552, 0.4665910347830504, 0.15538611594820395, 0.2869115013163537, 0.39187217073049396, 0.13815551006700844, 0.19632307084975764, 0.16662132635246962, 0.38615653524175286, 0.4026050807442516, 0.4906774079427123, 0.3041471092728898, 0.4467414936516434, 0.13258686434710398, 0.13876978569896892, 0.10611505786073394, 0.22419736575102434, 0.37739940045867115, 1.2681620009243488, 64.49040547013283, 106.6076722741127, 70.1684407889843, 73.25967371463776, 94.36754867434502, 104.08503323793411, 65.32922565937042, 44.87729050219059, 54.32012960314751, 43.926520720124245, 38.875451758503914, 38.846846893429756, 80.1179713010788, 89.05482575297356, 79.19400528073311, 63.11016373336315, 67.6550504565239, 32.07764692604542, 3.0362399015575647, 1.4933799533173442, 9.472402464598417, 46.30220644176006, 35.45713238418102, 103.89837205410004, 80.81518828868866, 48.97079564630985, 36.41713187098503, 64.6540778875351, 66.59356221556664, 55.16108527779579, 60.427952259778976, 74.80932176113129, 98.94792929291725, 98.35243284702301, 69.99640122056007, 71.57821834087372, 50.342218056321144, 42.04929605126381, 37.42587134242058, 30.128530114889145, 24.479977414011955, 16.91229399293661, 20.62970481812954, 35.41066847741604, 24.993825741112232, 25.751516483724117, 45.98166324198246, 63.07183139026165, 63.5638327896595, 60.18946945667267, 34.77867119014263, 4.6729626506567, 6.153456782922149, 2.5562857557088137, 4.327251501381397, 1.2879566824994981, 2.2980359382927418, 0.6715298315975815, 1.2759955180808902, 14.062262624502182, 5.792616745457053, 5.817131130024791, 0.21818067063577473, 0.25908203213475645, 0.7234989304561168, 0.6981395068578422, 1.6884160065092146, 1.1653408245183527, 1.0630573192611337, 1.7692964477464557, 3.5084814112633467, 0.9184822021052241, 1.5066968137398362, 4.984104679897428, 21.240132562816143, 0.5541539518162608, 0.18076447915518656, 0.7577608013525605, 1.8157998961396515, 0.6965059507638216, 2.570730918087065, 2.4560022493824363, 2.7596791042014956, 1.28854256356135, 15.882950127124786, 51.223003193736076, 67.80299931764603, 69.77174207568169, 72.92366534471512, 37.3910728096962, 34.130038395524025, 26.849756352603436, 22.404714971780777, 17.072951272130013, 15.630505923181772, 13.386899214237928, 21.20400220155716, 27.913467474281788, 53.554174304008484, 79.3258886039257, 81.8979249894619, 75.07476791739464, 72.37803742289543, 72.83420294523239, 74.5295199751854, 85.88485345244408, 91.17568954825401, 89.28633213043213, 74.20985832810402, 51.90763905644417, 17.60294683277607, 49.57836024463177, 58.953600972890854, 39.00839522480965, 57.279965579509735, 61.58813640475273, 8.778984323143959, 1.761346918065101, 1.2406479148194194, 0.8778985985554755, 0.6187734031118453, 0.107429282652447, 0.24432745354715735, 1.0492697590962052, 0.5190323176793754, 0.6673403782770038, 0.635012366110459, 15.759791135787964, 70.12851253151894, 67.90269836783409, 58.88016611337662, 48.35345417261124, 56.16880640387535, 49.41990874707699, 1.145525244064629, 1.1377039575017989, 0.3926131606567651, 0.2377170996624045, 0.568197820102796, 0.2716833434533328, 0.17369862471241504, 0.20719845837447792, 0.15615196782164276, 0.37233136303257197, 0.19154856767272577, 0.8528653637040406, 0.5918639001902193, 0.17520172608783469, 0.6178025552071631, 0.3902612649835646, 0.2775114885298535, 0.2436043048510328, 0.24517356127034873], [0.1684245077194646, 0.011629632208496332, 0.040582416113466024, 0.2258756139781326, 0.1384138219873421, 0.021191989799262956, 0.0720285638817586, 0.024506495537934825, 0.1511106625548564, 0.054673663107678294, 0.143261352495756, 0.015472116647288203, 0.11536307138158008, 0.2527500578435138, 0.05002074598451145, 0.03774092190724332, 0.026588882137730252, 0.05685554016963579, 0.009090673574974062, 0.02868531573767541, 0.07537705256254412, 0.061231940489960834, 0.08256518325651996, 4.660714482888579, 61.1060106754303, 59.53967772424221, 41.407198905944824, 60.41206531226635, 59.78117376565933, 41.929746866226196, 25.49086757004261, 22.863479554653168, 7.716001337394118, 10.067547429352999, 9.665299113839865, 27.28262722492218, 26.472326405346394, 27.445989958941936, 20.931684114038944, 7.830392299219966, 2.218793327920139, 0.540726303588599, 0.888995606219396, 35.78825041651726, 27.681377828121185, 53.0846107006073, 79.859858751297, 41.26256346702576, 32.5653887540102, 48.32594744861126, 50.47990746796131, 77.06157490611076, 122.65687867999077, 147.2194066643715, 123.3280822634697, 87.28835374116898, 80.90463548898697, 75.05095079541206, 86.89382091164589, 75.41717514395714, 46.09604850411415, 31.30328457802534, 30.488731786608696, 18.349325582385063, 18.689116649329662, 15.651503596454859, 20.2695544436574, 27.074039317667484, 24.91269439458847, 45.834003165364265, 57.483239471912384, 46.72320105135441, 19.01455018669367, 16.754152178764343, 6.084566954523325, 3.2884618174284697, 1.623243447393179, 2.0774477999657393, 1.1269445973448455, 1.2678251252509654, 1.1941872141323984, 0.993960639461875, 0.8275096211582422, 6.782192420214415, 0.6684151862282306, 2.0236068265512586, 2.2317458828911185, 0.4706077161245048, 0.8321480441372842, 0.5275022413115948, 1.5356661030091345, 0.5006385140586644, 1.873650960624218, 1.1363397119566798, 0.6891205720603466, 3.7353306636214256, 2.632838347926736, 0.8898304332979023, 0.2540122432401404, 0.3503877780167386, 0.4161392420064658, 1.1094572232104838, 1.4638007967732847, 0.7227308966685086, 1.3564015785232186, 0.6472085835412145, 2.18758940231055, 4.928410118445754, 29.252984896302223, 44.87488903105259, 47.64844000339508, 39.189767092466354, 21.008426696062088, 17.28222504258156, 16.681832559406757, 17.116447538137436, 8.115253038704395, 9.857824333012104, 10.209251325577497, 30.1816151663661, 57.6906019449234, 75.57051971554756, 73.47716644406319, 72.21431940793991, 65.8976523578167, 67.62057110667229, 66.13920539617538, 62.66288973391056, 67.69524469971657, 68.39677065610886, 64.41336840391159, 86.63090541958809, 84.29696425795555, 64.3284809589386, 27.761342637240887, 59.541053250432014, 37.19363160431385, 35.106392204761505, 64.38764378428459, 15.498979780822992, 0.7947871426586062, 2.0119020296260715, 1.518139662221074, 0.36541122186463326, 0.3182439965894446, 0.11597319098655134, 0.22755778074497357, 0.46680385305080563, 0.30440329865086824, 0.8245706569869071, 8.091727551072836, 50.22094376385212, 37.80599534511566, 27.41693291813135, 19.14261471480131, 27.583031505346298, 2.8285819943994284, 0.37207680637948215, 0.5453066609334201, 0.06856654144939966, 0.037805548126925714, 0.05749960932007525, 0.10847827870748006, 0.0809523108182475, 0.10345561619033106, 0.11922095538466237, 0.15419489471241832, 0.09582017082720995, 0.13410918734734878, 0.037208891080808826, 0.3241737268399447, 0.28048530395608395, 0.1080974233627785, 0.15269471739884466, 0.050881010174634866, 0.067887060722569, 0.13719159382162616, 0.08697705823578872, 0.0929905918019358, 0.18845398997655138, 0.22438360028900206, 0.05561879188462626, 0.058066068377229385, 0.051922317579737864, 0.18314111803192645, 0.11859479796839878, 0.13455457985401154, 0.03517354365612846, 0.22755726124159992, 0.2866737172007561, 0.14314912492409348, 0.14178664569044486, 0.08622229404863901, 0.12028929180814885, 0.01832131063565612, 0.05414905746874865, 0.1711007664562203, 0.22888604697072878, 0.25511424348223954, 5.061100898310542, 65.30949711799622, 73.6947275698185, 57.74549379944801, 76.31763562560081, 75.70988863706589, 47.56426312029362, 26.914696767926216, 27.618109323084354, 9.19230904430151, 7.877802355214953, 4.99385068193078, 21.27393364906311, 24.258152917027473, 24.68729618936777, 22.52632934600115, 7.250622734427452, 0.8817188779357821, 0.8083636953961104, 1.7338760546408594, 60.84854029119015, 27.341867946088314, 47.61332228779793, 70.06235808134079, 71.87244415283203, 46.027682572603226, 34.11790184676647, 32.88600794970989, 46.855950728058815, 80.72513312101364, 107.87378713488579, 107.63325244188309, 89.12709027528763, 86.43158331513405, 74.80194255709648, 75.88308334350586, 64.14735987782478, 40.57583011686802, 36.296366751194, 35.07537066936493, 20.582135170698166, 18.907272443175316, 18.975254595279694, 19.741198495030403, 25.083825811743736, 23.799238242208958, 50.999841168522835, 62.22169540822506, 69.23527166247368, 65.61687782406807, 25.04235863685608, 1.880445471033454, 3.2904695346951485, 1.5560235106386244, 1.5745750651694834, 1.1635065916925669, 1.1778477346524596, 0.6406106532085687, 0.7205275492742658, 0.40178079216275364, 1.7706624744459987, 1.169050969183445, 3.459730027243495, 2.236701766960323, 0.41930847975891083, 1.051674555055797, 2.989211962558329, 4.164918512105942, 1.280563110485673, 8.893268890678883, 0.6060690223239362, 0.37540002493187785, 2.4355781078338623, 2.744386112317443, 1.0082080936990678, 0.24728509015403688, 0.5436131393071264, 0.19870818505296484, 0.5799761193338782, 0.9717669209931046, 0.7301228656433523, 1.0994015377946198, 1.3016587472520769, 2.3098609037697315, 20.236581712961197, 39.380402863025665, 49.068332612514496, 49.5064453035593, 46.61230780184269, 21.21644653379917, 13.018830064684153, 9.326671734452248, 9.726235494017601, 11.912475731223822, 15.688461363315582, 15.260164495557547, 26.32675241678953, 55.41442908346653, 76.93200945854187, 77.6617830991745, 73.66670027375221, 67.53037914633751, 63.653644770383835, 61.644316390156746, 59.9533349275589, 67.14605256915092, 67.3289367556572, 60.943550392985344, 80.00116556882858, 71.65499702095985, 41.23419038951397, 21.553412452340126, 64.62272956967354, 29.932105354964733, 37.14500181376934, 54.91265460848808, 15.680734477937222, 2.672171937301755, 1.4927680674009025, 4.2798010725528, 1.8436888558790088, 0.5045197089202702, 0.26463816524483263, 0.7304862211458385, 0.7737322349566966, 0.28198206739034504, 0.6884760316461325, 12.639883048832417, 42.565277963876724, 44.82717879116535, 35.06242856383324, 27.575853690505028, 32.35987298190594, 1.3603144185617566, 0.38489776372443885, 0.05806846180348657, 0.0508865799929481, 0.012913307418784825, 0.09240115585271269, 0.07817172838258557, 0.06040170730557293, 0.08203370161936618, 0.07456830455339514, 0.18454256001859903, 0.09989020516513847, 0.32044865016359836, 0.21203580661676824, 0.10126034336281009, 0.23826398828532547, 0.3739880444481969, 0.020753120770677924, 0.07851241127355024, 0.044206115417182446, 0.32564617751631886, 0.1695219660177827, 0.21329845214495435, 0.35244955332018435, 0.2694100857479498, 0.13304730760864913, 0.16105619841255248, 0.15939334232825786, 0.45543812855612487, 0.19163997058058158, 0.38214840344153345, 0.15037152799777687, 0.4115222819382325, 0.44512414606288075, 0.20772992516867816, 0.2831463486654684, 0.14873583451844752, 0.23011911049252376, 0.11681952877552249, 0.1291484644752927, 0.5565130908507854, 0.2138648889376782, 0.477258576429449, 8.315876573324203, 94.3578439950943, 86.69447600841522, 72.10465729236603, 86.37004181742668, 96.2345252931118, 67.83222734928131, 41.6506290435791, 37.70864076912403, 16.59292683005333, 14.52477665618062, 10.790001712739468, 33.50740760564804, 33.78761976957321, 35.914012268185616, 41.5768788009882, 23.627987131476402, 1.2952727149240673, 1.4563738577999175, 1.3103186013177037, 54.02290195226669, 34.53772991895676, 74.78475227952003, 101.85875549912453, 63.03539514541626, 43.654120936989784, 52.56192974746227, 67.82249227166176, 89.7593155503273, 146.30937069654465, 157.59687781333923, 132.38627940416336, 92.87735223770142, 87.33050107955933, 77.47903570532799, 94.08517062664032, 91.82457312941551, 56.87581546604633, 41.82860389351845, 39.052864238619804, 21.79056152701378, 22.66196496784687, 21.836043186485767, 25.367921367287636, 41.04845255613327, 36.4802198857069, 51.89477674663067, 67.1597470343113, 79.45533245801926, 65.83388417959213, 39.717228189110756, 10.281966123729944, 4.17785681784153, 2.5105416728183627, 2.005878402851522, 0.9824173338711262, 1.4795277966186404, 1.0144467651844025, 2.1075419476255774, 1.340854475274682, 10.64352622255683, 1.227761262562126, 4.209341928362846, 2.726003173738718, 0.47622998943552375, 1.0131669463589787, 3.785855839960277, 10.056750308722258, 0.6469389167614281, 7.788083469495177, 0.9478730906266719, 1.456202866975218, 11.647374406456947, 15.748519990593195, 1.3625331432558596, 0.9517808840610087, 0.4267627891385928, 0.5385453393682837, 0.9671758767217398, 1.4639578945934772, 1.3119103596545756, 1.0166939883492887, 2.2569378186017275, 1.4391315705142915, 18.823673129081726, 45.24334765970707, 53.70618134737015, 60.79650588333607, 48.87451261281967, 26.816682927310467, 20.54328415542841, 19.79264583438635, 25.467840805649757, 13.715310841798782, 15.224590804427862, 14.426273591816425, 39.75097797811031, 69.60292473435402, 81.38339459896088, 80.26913478970528, 74.2396031320095, 68.35318699479103, 65.48408254981041, 60.494623482227325, 58.19360375404358, 60.64932078123093, 62.52548150718212, 56.21554009616375, 85.08080139756203, 87.78244882822037, 68.4779267013073, 27.42024064064026, 64.10491615533829, 39.15483556687832, 43.485079407691956, 76.79880380630493, 27.576723843812943, 1.856057073455304, 5.262357573956251, 3.9580884855240583, 0.738408142933622, 0.29505559243261814, 0.2323002231423743, 0.510967547306791, 0.671891940291971, 0.5295173800550401, 0.7691078237257898, 17.26966481655836, 78.04618567228317, 57.67579413950443, 52.7560955286026, 44.954403564333916, 56.556191816926, 4.723397344350815, 0.6834284181240946, 0.6688322138506919, 0.24202554894145578, 0.15113268949789926, 0.2886442083399743, 0.3112670365953818, 0.20661766844568774, 0.17723341472446918, 0.25289786397479475, 0.3216498903930187, 0.3724607639014721, 0.45498829800635576, 0.3655556438025087, 0.5083921167533845, 0.6535145826637745, 0.49427596328314394, 0.4306272411486134, 0.24705171439563856, 0.2518168219830841], [0.05491663483553566, 0.04509133803367149, 0.08154050738085061, 0.03748120361706242, 0.060725446965079755, 0.08791534812189639, 0.04036078855278902, 0.09524127337499522, 0.043369429258746095, 0.0912072257779073, 0.10444265033584088, 0.09970742161385715, 0.03235659227357246, 0.030149122248985805, 0.18847537867259234, 0.012900049878226127, 0.14195057126926258, 0.04416219511767849, 0.08163590304320678, 0.015686632577853743, 0.05508780748641584, 0.12087803756003268, 0.21420446602860466, 0.2696343627758324, 10.883492846041918, 53.35986793041229, 44.10110615193844, 46.79538577795029, 64.02954339981079, 45.88723450899124, 50.503895580768585, 42.27505333721638, 4.219588553532958, 3.3898235158994794, 1.9674815819598734, 7.0491323713213205, 6.74122491851449, 4.957675198093057, 1.457192595116794, 0.3288981202058494, 0.6209424929693341, 0.14104976726230234, 1.8441835418343544, 29.578859210014343, 26.829716227948666, 69.6947506070137, 66.27105072140694, 29.295029640197754, 48.99169072508812, 81.37031570076942, 113.53511095046997, 119.59963113069534, 108.1083333492279, 98.58602911233902, 84.77659732103348, 83.890880048275, 74.9443893134594, 76.59445077180862, 81.96535617113113, 72.83366337418556, 75.15425205230713, 50.54665468633175, 31.685697957873344, 23.71016912162304, 26.573076099157333, 24.35782726854086, 30.067851170897484, 26.935988925397396, 27.698725797235966, 46.3418535143137, 62.07347676157951, 55.710953772068024, 26.921099424362183, 19.61024422198534, 7.574862185865641, 1.8048073234967887, 2.2794138500466943, 1.7951971641741693, 0.5014031636528671, 0.2737213106593117, 0.7955136755481362, 1.3496981444768608, 0.8575590024702251, 1.4405173086561263, 4.4703199993819, 1.8205022625625134, 1.6482009831815958, 0.47477535030338913, 1.9438838982023299, 0.679803709499538, 3.0742366751655936, 0.7360354077536613, 9.012183509767056, 12.075096555054188, 0.5562305997591466, 2.8965814830735326, 0.07576534422696568, 0.29648683906998485, 0.6546053022611886, 0.5130945425480604, 0.3227334260009229, 0.6929692905396223, 0.4824506415752694, 0.3156761359423399, 0.39704116992652416, 0.4384322895202786, 2.9992529237642884, 6.39814417809248, 30.030654966831207, 39.622506871819496, 46.52346856892109, 30.93776509165764, 16.827436946332455, 21.529416739940643, 15.655136201530695, 14.13924839347601, 7.59525521658361, 15.176375191658735, 35.68480856716633, 66.6719976067543, 76.3330627977848, 75.2137340605259, 71.37356892228127, 71.02160140872002, 64.62184801697731, 73.40449154376984, 69.67394292354584, 74.14925917983055, 68.52477058768272, 75.9943413734436, 68.04424837231636, 72.1957916021347, 74.40434709191322, 84.36284512281418, 60.56771256029606, 45.05865477025509, 57.462051808834076, 23.82366333156824, 49.19589936733246, 42.24498175084591, 1.7013045586645603, 0.9037224284838885, 3.106944845058024, 3.742283578030765, 0.45997466950211674, 0.4481105779996142, 0.37423604051582515, 0.5328480794560164, 0.3285558120114729, 0.4616146971238777, 4.525392819195986, 19.21401858329773, 20.783408470451832, 15.917221438139677, 21.303862743079662, 6.278734635561705, 0.3956211742479354, 0.17108252446632832, 0.2074620098574087, 0.062384852062677965, 0.11001755978213623, 0.05047261744039133, 0.07239237209432758, 0.06404706989997067, 0.24505851353751495, 0.030257898833951913, 0.17853113415185362, 0.07498254170059226, 0.10802609554957598, 0.09686363046057522, 0.25880936707835644, 0.17541561304824427, 0.04563798174785916, 0.06106806315074209, 0.08872101621818729, 0.061720900775981136, 0.03293403140560258, 0.048303163930540904, 0.07675419663428329, 0.019984456157544628, 0.14705020934343338, 0.06557026121299714, 0.09490122873103246, 0.0930009076546412, 0.10208627951215021, 0.07527864378062077, 0.16248388274107128, 0.10971411044010893, 0.07090039551258087, 0.18051850172923878, 0.2713267266517505, 0.06287758616963401, 0.12801247386960313, 0.10972706833854318, 0.1245959525112994, 0.016637856242596172, 0.12606671109097078, 0.08992183342343196, 0.3159083687933162, 0.6273546488955617, 16.069843098521233, 64.53300878405571, 57.34771214425564, 59.27042797207832, 76.93578645586967, 50.64258433878422, 49.45938482880592, 50.206474140286446, 5.081599373370409, 1.0054791276343167, 1.555674523115158, 4.225315796211362, 2.6847912976518273, 3.012741724960506, 0.614008636912331, 0.18967645562952384, 0.32603948609903455, 0.1810545549960807, 10.843743178993464, 46.60516798496246, 24.415052197873592, 55.44580779969692, 76.63846760988235, 50.69569788873196, 28.632390797138214, 46.34887933731079, 84.5801630616188, 113.88071000576019, 110.46380415558815, 101.87884122133255, 85.59473901987076, 87.2966904938221, 76.0172313451767, 78.19573804736137, 83.17529484629631, 81.83240130543709, 75.82142025232315, 49.1045256704092, 32.3229693621397, 30.802384056150913, 28.936319388449192, 24.582697302103043, 27.779049687087536, 35.872902274131775, 27.209475450217724, 49.185639917850494, 69.05680283904076, 72.21143916249275, 65.34216776490211, 32.64259301126003, 6.545310281217098, 1.5852445363998413, 1.9993712520226836, 1.1821301048621535, 0.06655369594227523, 0.26560503523796797, 1.2428671144880354, 2.6184413954615593, 1.0140977776609361, 0.2699421759461984, 1.7882608738727868, 1.064122449606657, 1.8825453333556652, 0.10640585358487442, 2.6973149506375194, 8.142661917954683, 3.9414902636781335, 6.125180600211024, 8.442633021622896, 12.542411629110575, 0.10892635036725551, 2.062406069599092, 0.107621387578547, 1.0103540285490453, 0.19763545511523262, 0.8196012955158949, 0.34154048713389784, 0.3639323590323329, 0.7467267278116196, 0.16273455054033548, 0.4089634458068758, 0.8047771628480405, 3.675267999060452, 13.462471459060907, 38.0704877525568, 41.74765303730965, 51.359879449009895, 39.21622507274151, 17.29808919131756, 11.926993802189827, 11.461657471954823, 18.037020340561867, 14.570356160402298, 13.02900591865182, 29.166455939412117, 65.38929283618927, 84.57582369446754, 78.12538102269173, 73.08358356356621, 75.92304199934006, 66.2723882496357, 75.34522980451584, 70.0510422885418, 75.94517201185226, 68.45596387982368, 70.7937504351139, 62.70341455936432, 70.73539316654205, 69.01316598057747, 79.23296079039574, 51.68025925755501, 42.4010393768549, 56.808236092329025, 21.705501191318035, 47.934667244553566, 36.02088153362274, 3.4843914164230227, 1.0991552635096014, 1.2979968125000596, 4.611107669770718, 1.665498842485249, 1.3110761856660247, 0.8151301823090762, 0.81499760504812, 0.23100438877008855, 0.6121039891149849, 10.089978575706482, 27.008116655051708, 30.505492687225342, 28.49779821932316, 33.43501769006252, 3.5039546666666865, 0.2191040656180121, 0.10556068838923238, 0.15177433553617448, 0.0586628738528816, 0.051453280248097144, 0.09340419812360778, 0.05363653399399482, 0.04371899565740023, 0.10577340275631286, 0.03533364346367307, 0.1034128462197259, 0.07681926814257167, 0.13241302367532626, 0.11017448690836318, 0.16089533048216254, 0.36235295003280044, 0.0914176543301437, 0.06331212105578743, 0.04257034030160867, 0.08852995029883459, 0.1329144780174829, 0.22697932115988806, 0.17331781389657408, 0.17557725281221792, 0.24000597215490416, 0.18900286755524576, 0.34844097623135895, 0.29048568452708423, 0.2046855611843057, 0.16016838198993355, 0.24293340335134417, 0.22246774606173858, 0.1475311952526681, 0.28732891485560685, 0.38397583819460124, 0.13949223677627742, 0.23635099874809384, 0.24368996353587136, 0.33001849602442235, 0.2690821752185002, 0.2223527428577654, 0.12762682425091043, 0.6719203200191259, 1.4154780772514641, 25.012691728770733, 89.87818077206612, 67.80305251479149, 72.54312336444855, 90.18844932317734, 64.4349816441536, 66.092399507761, 68.4913095831871, 7.194876400753856, 5.936202015727758, 2.497180877253413, 7.020874237641692, 6.674646316096187, 9.229964073747396, 3.949979958124459, 0.3519798628985882, 1.1431189044378698, 0.13914283365011215, 6.553523540496826, 45.03806747496128, 34.648349583148956, 88.90676289796829, 85.11211171746254, 40.479440689086914, 54.42806661128998, 101.83707386255264, 129.39290642738342, 134.38675045967102, 105.55544793605804, 95.33160254359245, 82.05016002058983, 87.9471243917942, 77.00982168316841, 75.276939868927, 83.51350709795952, 73.30688238143921, 80.00191792845726, 54.243217930197716, 34.584797993302345, 32.16885343194008, 32.70408131182194, 33.30777011811733, 39.194296449422836, 47.035198509693146, 41.15994617342949, 48.080058842897415, 74.17138919234276, 75.72643294930458, 64.22777116298676, 46.52803212404251, 8.633668720722198, 1.8200181447900832, 3.0603429581969976, 1.6800851910375059, 0.4322298348415643, 0.46576178865507245, 0.6276758504100144, 2.5708005018532276, 1.030753708910197, 1.1070021986961365, 6.691613830626011, 1.3263968448154628, 1.1157824588008225, 0.7113201089669019, 2.8570244181901217, 9.288223497569561, 6.267083985731006, 5.119754076004028, 17.532002739608288, 25.24676486849785, 5.8921286556869745, 6.100253462791443, 0.1780240988591686, 1.8890854949131608, 1.1532344366423786, 0.7141470385249704, 0.3399786521913484, 1.2264388147741556, 0.8529752015601844, 0.32131102576386184, 0.3377311321673915, 1.1209852108731866, 3.932347479276359, 19.19376377016306, 37.00986586511135, 40.205285400152206, 59.19654093682766, 48.95981043577194, 19.844093173742294, 26.475782319903374, 19.676662757992744, 23.38042851537466, 9.533479437232018, 19.086567722260952, 44.36256632208824, 80.42472124099731, 84.44011017680168, 78.49472880363464, 72.8606191277504, 75.40541097521782, 68.85050430893898, 80.44583290815353, 68.41225862503052, 71.32382959127426, 61.971767619252205, 70.71563422679901, 60.629588440060616, 65.32507628202438, 66.70497223734856, 83.05358737707138, 67.03088834881783, 51.5848083794117, 60.33602759242058, 29.30117581039667, 66.4276859164238, 72.96484753489494, 9.217788577079773, 1.924780779518187, 6.211285879835486, 5.004218900576234, 1.112081694882363, 0.5998516059480608, 0.6964152306318283, 0.806240796810016, 0.29876229353249073, 0.3543264447944239, 27.087049819529057, 49.830347523093224, 45.08938372135162, 43.04359629750252, 48.911955803632736, 13.566009253263474, 0.7812005560845137, 0.18584185279905796, 0.35782261344138533, 0.15795983956195414, 0.19545073562767357, 0.2556698746047914, 0.18827919935574755, 0.10097883190610446, 0.49847126472741365, 0.15294443524908274, 0.21547583921346813, 0.1632578982389532, 0.2731345093343407, 0.09860230435151607, 0.3223935520509258, 0.3141981933731586, 0.22426408482715487, 0.11884117615409195, 0.4106290329946205, 0.12627121730474755], [0.03669907644507475, 0.06867022690130398, 0.027148719382239506, 0.08790768915787339, 0.03462104810751043, 0.06951482806471176, 0.04156979906838387, 0.10036918727564625, 0.07301074438146316, 0.04983698650903534, 0.019721058670256753, 0.17411262437235564, 0.07650496118003502, 0.029473214963218197, 0.09549097638227977, 0.08485072350595146, 0.03454553458141163, 0.04930192772008013, 0.19619240832980722, 0.03606003905588295, 0.09899069991661236, 0.06377066441928037, 0.5233673506882042, 0.1341814873740077, 1.6016100207343698, 28.270735703408718, 53.843912556767464, 44.54027518630028, 47.69936487078667, 53.379216492176056, 42.22248695790768, 23.263801373541355, 2.6392927765846252, 0.38566437258850783, 1.017704971600324, 0.7935825479216874, 0.3659708012128249, 0.14581508265109733, 0.3532846475718543, 1.542082296218723, 0.09663452947279438, 0.1351302638067864, 11.97954973205924, 46.41149237751961, 39.694554805755615, 75.41536644101143, 34.24874022603035, 38.8513458520174, 95.2966520190239, 109.89643380045891, 96.61344096064568, 78.41630101203918, 81.21052667498589, 82.3633848130703, 90.07077723741531, 97.64592155814171, 85.18475621938705, 78.56717571616173, 75.16565144062042, 69.6811093389988, 72.66087144613266, 77.05194622278214, 62.05836497247219, 37.12865509092808, 25.414962843060493, 24.172357320785522, 26.83940950781107, 23.472976349294186, 27.79297214001417, 42.09537237882614, 62.29892626404762, 53.22882056236267, 34.069720432162285, 16.446699276566505, 7.02743268571794, 0.6574743264354765, 0.30909218767192215, 0.6762495345901698, 1.202164173591882, 1.6824625572189689, 0.19621725543402135, 1.9148500123992562, 0.9604535030666739, 0.19161832955433056, 0.2863638260168955, 0.5813878029584885, 0.5727170244790614, 0.35230821871664375, 2.343278448097408, 5.699275229126215, 1.5423635998740792, 4.971233820542693, 6.731838947162032, 1.8128611100837588, 0.5460425151977688, 1.2609784863889217, 1.0113197704777122, 0.49607893684878945, 0.12288130936212838, 2.002578992396593, 0.7202111568767577, 0.25624848261941224, 0.1912733941571787, 0.2871864818735048, 0.34665397368371487, 0.22595408867346123, 5.208486914634705, 3.377799061127007, 30.154501721262932, 36.151013150811195, 48.222699388861656, 29.958833120763302, 21.16829551756382, 23.171361833810806, 13.45673281699419, 10.022718384861946, 20.22530011832714, 47.28458292782307, 70.62525987625122, 77.25251466035843, 68.91494125127792, 80.68351775407791, 66.92021548748016, 70.90495526790619, 68.75591978430748, 69.02654126286507, 64.87666994333267, 66.38686090707779, 72.0425534248352, 71.4731615781784, 72.9214234650135, 76.03078901767731, 77.51831039786339, 75.35222142934799, 76.97229489684105, 41.3795629888773, 59.797581285238266, 47.63990946114063, 26.8376350030303, 47.01379805803299, 10.407935064285994, 0.5120558326598257, 3.4371644631028175, 10.316745657473803, 1.5778293530456722, 0.9646992408670485, 1.0567164095118642, 0.7930097286589444, 0.14740560902282596, 2.4597381614148617, 4.618024248629808, 20.9680899605155, 15.659460369497538, 23.70667140930891, 14.050683695822954, 0.20735113299451768, 0.08744042555917986, 0.037691535690100864, 0.04445786675205454, 0.08544476819224656, 0.2035913831787184, 0.14049407676793635, 0.09169690965791233, 0.08319165237480775, 0.23629357136087492, 0.07296021896763705, 0.08431914538959973, 0.04523175237409305, 0.061176750677987, 0.05652555533742998, 0.09488378826063126, 0.02992520145198796, 0.12278928305022418, 0.07732604368356988, 0.026413338237034623, 0.24157797452062368, 0.013343295722734183, 0.14058132364880294, 0.09384610995766707, 0.06301661269390024, 0.004815756847165176, 0.05687549652066082, 0.06935813100426458, 0.03670128804515116, 0.05548047040065285, 0.04736635833978653, 0.04149273445364088, 0.17153627355583012, 0.03558670468919445, 0.12458152516046539, 0.08193320740247145, 0.06309159187367186, 0.05453380166727584, 0.061759778182022274, 0.1704448414966464, 0.09979075737646781, 0.24350527266506106, 0.09357873641420156, 0.4439541354076937, 0.13140876428224146, 3.225236772559583, 39.51790988445282, 70.23624435067177, 61.44657500088215, 66.06524616479874, 55.580723360180855, 42.49334782361984, 39.73331652581692, 2.2233338467776775, 0.09477204308495857, 1.1042724014259875, 0.4323614918394014, 0.1603503862861544, 0.19492004066705704, 0.21720480581279844, 0.17853325669420883, 0.13497534790076315, 0.1156551213352941, 24.56565711647272, 43.82854297757149, 31.33376844227314, 76.7207407951355, 57.22678363323212, 28.068366162478924, 62.35546723008156, 108.25203403830528, 97.73442640900612, 77.81701236963272, 74.94458690285683, 84.35095176100731, 93.00830841064453, 99.70731094479561, 88.05832162499428, 81.18759870529175, 75.38763552904129, 68.55473577976227, 77.35269248485565, 82.40392103791237, 59.67476427555084, 32.280765026807785, 24.452478289604187, 30.936786644160748, 24.059947952628136, 29.142218939960003, 31.47602330893278, 50.695044323801994, 62.28626534342766, 63.212169259786606, 66.1549061536789, 23.656527400016785, 3.459334373474121, 1.6986559820361435, 0.11575453943805769, 1.9736193213611841, 0.8488637034315616, 1.024394512642175, 4.7042435221374035, 2.5806267745792866, 0.8080186857841909, 0.5325308558531106, 0.04268601885996759, 0.28946128324605525, 0.715180286206305, 0.9617231099400669, 2.4703265307471156, 16.59952897578478, 3.068856163881719, 8.718237932771444, 1.4971273834817111, 2.0473864255473018, 0.4934328538365662, 1.4996096002869308, 0.5992110434453934, 0.5639859836082906, 0.10059756838018075, 1.0519784200005233, 0.4104492551414296, 0.22292392939561978, 0.07631842236150987, 0.37966283212881535, 0.29694946424569935, 0.36909182905219495, 2.279969332739711, 5.020644469186664, 33.60303707420826, 37.913084998726845, 57.187318950891495, 34.845422208309174, 13.615477848798037, 12.484037261456251, 20.053121857345104, 16.158703230321407, 17.640990391373634, 30.07701627910137, 73.59588727355003, 81.93284511566162, 74.88664001226425, 77.91589066386223, 71.99634030461311, 72.60322093963623, 71.52427643537521, 69.57475304603577, 67.55665093660355, 66.61389872431755, 68.5299003124237, 66.0406918823719, 73.33887666463852, 72.96161010861397, 75.69174841046333, 74.60168570280075, 77.07354426383972, 41.35325700044632, 57.38093376159668, 51.3682010024786, 28.616072572767735, 57.77640514075756, 19.342369996011257, 1.5915898396633565, 0.5115916044451296, 7.663382235914469, 1.6072900034487247, 1.272793358657509, 1.5637040860019624, 0.4468930698931217, 0.6708545959554613, 3.427699408493936, 16.07350990176201, 31.38907827436924, 27.838252410292625, 36.235942393541336, 16.26228377223015, 0.21617369551677257, 0.034290562325622886, 0.044679661295958795, 0.014783517708565341, 0.024151594952854794, 0.0763621942314785, 0.09377371345181018, 0.03185194669640623, 0.08475979557260871, 0.1468612882308662, 0.13664771831827238, 0.09601856174413115, 0.03296090828371234, 0.06892937002703547, 0.06628752467804588, 0.0856363090861123, 0.03905251949618105, 0.07386991390376352, 0.13950871245469898, 0.10059785781777464, 0.07684454569243826, 0.10790021246066317, 0.2407256921287626, 0.21694345108699054, 0.30168409924954176, 0.10567451899987645, 0.2419869275763631, 0.17685117898508906, 0.2009033688227646, 0.5301457713358104, 0.13392556516919285, 0.21012784884078428, 0.2342027038685046, 0.1344299435731955, 0.24574544542701915, 0.20140635198913515, 0.29802813136484474, 0.24869868851965293, 0.19387465144973248, 0.3751935000764206, 0.19920938706491143, 0.402712068753317, 0.1717467763228342, 0.6461835885420442, 0.32224809110630304, 3.579515512101352, 55.753838270902634, 89.85494881868362, 75.68054661154747, 81.40362471342087, 78.28986659646034, 57.09197826683521, 36.124756559729576, 2.7977276500314474, 0.27149065223056823, 2.328620022162795, 1.9213043223135173, 0.46615388011559844, 0.20289124106056988, 0.4412350250640884, 2.5005833571776748, 0.4332200379576534, 0.15352152928244323, 21.232741959393024, 54.47339817881584, 50.6943603605032, 95.3427055478096, 47.858082354068756, 48.197924718260765, 121.93031966686249, 124.3560791015625, 94.38636526465416, 74.11466583609581, 74.49589937925339, 81.6870667040348, 101.94375693798065, 102.78899118304253, 89.68828216195107, 82.2237879037857, 72.65897914767265, 69.89873126149178, 74.27231177687645, 79.10468727350235, 67.05305635929108, 41.249450370669365, 29.510774463415146, 35.05112037062645, 31.742250323295593, 37.54099756479263, 41.87927037477493, 50.05106247961521, 70.89351028203964, 70.56053414940834, 61.02764368057251, 31.921969279646873, 20.24722684174776, 2.1692822221666574, 0.3058050078107044, 1.5615004417486489, 2.447562189772725, 4.860783722251654, 4.292773576453328, 4.7064730525016785, 2.1386608527973294, 1.236456383485347, 0.33230247034225613, 0.9448897757101804, 2.560013593174517, 1.12419746350497, 5.61267027631402, 14.270313810557127, 4.414884774014354, 8.882951494306326, 13.877154607325792, 6.299590766429901, 0.9861598955467343, 4.412367884069681, 3.0092361755669117, 0.4919788084225729, 0.2183341170893982, 2.2171454038470984, 0.6799590855371207, 0.5613828264176846, 0.3612608351977542, 0.46137608180288225, 0.44370569405145943, 0.5311582982540131, 7.073939340189099, 22.04185914248228, 32.98601858317852, 43.72669704258442, 63.1935578584671, 43.459506779909134, 22.0001582801342, 29.108016975224018, 24.0511267259717, 10.870995316654444, 23.411115668714046, 58.35334338247776, 85.12861043214798, 81.28529906272888, 68.82370054721832, 78.88502106070518, 66.99824050068855, 74.52287793159485, 72.41070806980133, 68.70304942131042, 64.8587729036808, 64.79981526732445, 67.2665137052536, 64.92416739463806, 69.42847609519958, 74.14685770869255, 70.91446995735168, 73.34329202771187, 71.99415922164917, 47.859761863946915, 70.8611436188221, 56.938869282603264, 40.54744943976402, 71.27101242542267, 23.239893056452274, 1.7359087080694735, 6.827114084735513, 17.6855942979455, 2.104475274682045, 1.176819889806211, 2.6931715104728937, 1.5700825187377632, 0.43961263087112457, 3.859546948224306, 41.697503328323364, 47.740326672792435, 39.39616061747074, 50.55368810892105, 30.521444231271744, 0.32035027106758207, 0.17383341357344761, 0.29969725117553025, 0.11851017829030752, 0.1364277902757749, 0.25916541984770447, 0.28428898891434073, 0.14632419595727697, 0.1097336140810512, 0.3146926121553406, 0.13548299175454304, 0.1522360256058164, 0.18346269062021747, 0.12326442825724371, 0.21872885059565306, 0.266204453073442, 0.164641187293455, 0.1919249998172745, 0.18380441993940622, 0.17403784557245672, 0.49251837946940213], [0.020262785656086635, 0.036830006138188764, 0.024377562222070992, 0.07157710060710087, 0.07779170424328186, 0.033624314091866836, 0.0647810020018369, 0.08659578728838824, 0.016032423300202936, 0.10863815215998329, 0.08371173462364823, 0.008501394404447637, 0.07380939918220975, 0.10968365269945934, 0.1225310898735188, 0.06031385186361149, 0.018392946440144442, 0.07297105432371609, 0.04256025451468304, 0.08434702045633458, 0.1713283683056943, 0.015643259612261318, 0.35814230097457767, 0.07076993337250315, 0.5728266842197627, 13.196239694952965, 46.551625058054924, 41.170524805784225, 43.43187466263771, 54.59354393184185, 45.51913306117058, 19.479683227837086, 0.2939548983704299, 0.17519905435619876, 0.1882044502417557, 0.33053633698727936, 0.1374353002756834, 0.20215822180034593, 0.2223119989503175, 0.364610682008788, 0.27692587464116514, 0.9011342329904437, 31.007468551397324, 61.4231226593256, 46.785384714603424, 54.61760424077511, 29.87288173288107, 88.26747000217438, 103.50011542439461, 86.40175491571426, 83.99769991636276, 95.66425949335098, 91.44744336605072, 79.1527470946312, 85.26992484927177, 85.17752900719643, 81.37036889791489, 89.69312310218811, 74.38850954174995, 79.50462341308594, 73.8933353126049, 64.40553322434425, 74.37341675162315, 78.40719670057297, 50.64092002809048, 29.2993139103055, 28.94754208624363, 27.145540080964565, 30.529488399624825, 35.8541426807642, 61.58980071544647, 51.08280971646309, 42.45889127254486, 11.537375058978796, 0.1615059992764145, 1.5589270298369229, 0.9975195047445595, 0.5390106956474483, 5.037246253341436, 1.767664197832346, 0.26395488472189754, 0.8254742959979922, 0.7530127780046314, 0.85672203800641, 0.4948662972310558, 0.06872853002278134, 0.9789021662436426, 0.4207954171579331, 5.3110006637871265, 6.981192966923118, 2.680544313043356, 8.533906023949385, 2.8713593864813447, 1.4475155831314623, 0.14423610409721732, 1.0326477885246277, 0.2941912575624883, 0.13285050488775596, 0.4645456757862121, 1.20885870186612, 0.7842071447521448, 0.06032104698533658, 0.280305941705592, 0.05755773432611022, 0.18298338196473196, 0.0623388760141097, 3.0030888179317117, 2.018723851069808, 26.561078242957592, 37.481032982468605, 43.212618827819824, 30.974919497966766, 31.681816466152668, 21.477665416896343, 13.816632404923439, 22.319920621812344, 48.34455884993076, 68.06326255202293, 70.86523219943047, 74.92425039410591, 73.24073553085327, 72.29822650551796, 72.63928100466728, 75.08031561970711, 71.65189638733864, 70.35727545619011, 72.29678258299828, 73.06304946541786, 71.41858890652657, 74.58491340279579, 76.34396821260452, 69.64695677161217, 76.44810542464256, 75.7123813033104, 78.61048579216003, 66.68151989579201, 35.73041372001171, 60.91074675321579, 30.617197193205357, 29.959222599864006, 30.296906679868698, 2.8545388765633106, 0.219543669372797, 6.589745571836829, 5.285910610109568, 2.163462834432721, 2.684224178083241, 0.4229839809704572, 2.074779630638659, 5.547747910022736, 5.748012363910675, 8.822812121361494, 17.436650656163692, 23.195885717868805, 1.799050394911319, 0.1553893368691206, 0.1090372346516233, 0.04384602536447346, 0.10875732623389922, 0.08654328776174225, 0.08379124832572415, 0.06959558115340769, 0.008964544649643358, 0.09723833340103738, 0.09640405551181175, 0.09145560776232742, 0.09828802707488649, 0.03616709014750086, 0.07400415357551537, 0.051240246757515706, 0.12210716769914143, 0.045021075202384964, 0.03936274464649614, 0.09045164522831328, 0.08100377133814618, 0.11302745842840523, 0.036372698450577445, 0.08815606372081675, 0.04904911511403043, 0.039796296186978, 0.1892408891580999, 0.07432232712744735, 0.10003574032452889, 0.03316986738354899, 0.01670738434768282, 0.11003741223248653, 0.03721644614415709, 0.05510512179171201, 0.06649293631198816, 0.07925907120807096, 0.03739933730685152, 0.029844088421668857, 0.05053840512118768, 0.05208384602156002, 0.10102428845129907, 0.10709521229728125, 0.10607999138301238, 0.08252092899056152, 0.3847541136201471, 0.08136657765135169, 0.9582373313605785, 18.958191610872746, 64.72658559679985, 61.347947493195534, 61.220247745513916, 65.16195863485336, 46.66497677564621, 27.243956699967384, 0.5169509793631732, 0.15911340422462672, 0.3078355238540098, 0.21978565404424444, 0.2645604475401342, 0.16445812914753333, 0.4284015402663499, 0.8158933476079255, 0.8010531251784414, 1.169081130065024, 42.434576377272606, 54.123326763510704, 43.709396570920944, 69.02728602290154, 32.31286570429802, 68.28328594565392, 110.22766962647438, 86.91417261958122, 87.14029088616371, 91.22590005397797, 89.35700833797455, 76.73538520932198, 87.77099624276161, 91.2512218952179, 84.49259296059608, 88.23840916156769, 74.65116664767265, 83.87097671627998, 72.11836695671082, 67.9650530219078, 80.21662920713425, 76.9697642326355, 35.93480475246906, 24.923698604106903, 29.573189914226532, 24.87748358398676, 33.50229687988758, 45.887804478406906, 66.82955995202065, 54.009800255298615, 59.013440161943436, 22.645376957952976, 4.9668564554303885, 4.096299419179559, 1.0382549813948572, 0.5085181631147861, 1.2994340853765607, 2.7813101559877396, 0.348978677066043, 0.7452634500805289, 2.1396212512627244, 2.1029529813677073, 0.19041418010601774, 0.8801665424834937, 2.497835154645145, 0.44373410346452147, 8.189428858458996, 18.589062318205833, 2.015114757232368, 10.62101623043418, 2.901709545403719, 1.5443102829158306, 0.6369966315105557, 0.3183488472132012, 0.29068674717564136, 0.39700622961390764, 0.3274803509702906, 1.1037798528559506, 0.39121516223531216, 0.14767929824301973, 0.1766299596056342, 0.3102744882926345, 0.10032266203779727, 0.20749136921949685, 2.9659113753587008, 6.481694569811225, 29.861816726624966, 40.7543483376503, 48.010917752981186, 38.11659827828407, 22.431575730443, 24.683057516813278, 23.435656651854515, 18.650022447109222, 30.98389081656933, 65.19352734088898, 78.6828263103962, 74.26968231797218, 75.05897596478462, 74.71918299794197, 76.14948704838753, 75.39480194449425, 75.29116630554199, 70.52761271595955, 76.44173696637154, 72.15063482522964, 71.66417732834816, 71.25433132052422, 76.4070600271225, 68.36818858981133, 75.95407113432884, 75.74896574020386, 77.77167320251465, 70.49564883112907, 40.17580658197403, 62.91043125092983, 39.85278971493244, 35.38161903619766, 43.55279937386513, 6.191417695954442, 0.3437320195371285, 4.234378784894943, 5.805112374946475, 1.9434378971345723, 2.2742138290777802, 0.5452578573022038, 4.013728424906731, 10.35959405824542, 18.514990992844105, 19.469003900885582, 31.727144233882427, 31.422284692525864, 1.166642492171377, 0.041566199652152136, 0.07781715248711407, 0.09671479274402373, 0.09424609044799581, 0.09012199065182358, 0.0869415613124147, 0.03609850456996355, 0.1493471415597014, 0.08192838344257325, 0.05891049142519478, 0.056036431778920814, 0.13461708353133872, 0.02213537081843242, 0.049388907427783124, 0.012948452749697026, 0.1315835103741847, 0.027780392811109778, 0.026111148690688424, 0.06919931882293895, 0.06087882662541233, 0.015560207721136976, 0.13632705115014687, 0.33353306993376464, 0.1538883728790097, 0.24003196216654032, 0.5299138056579977, 0.21861093817278743, 0.25871924066450447, 0.17360561876557767, 0.12966928887180984, 0.21857255429495126, 0.11925362472538836, 0.14870555489324033, 0.1569945429218933, 0.2112417234457098, 0.17868839524453506, 0.11656080867396668, 0.13195312960306183, 0.15945697407005355, 0.21808070334373042, 0.2724490320542827, 0.24403455754509196, 0.2601597789907828, 0.5444339546374977, 0.1921917573781684, 1.2479410297237337, 25.039919167757034, 92.83208906650543, 77.95567452907562, 75.98400592803955, 78.90742465853691, 73.40134531259537, 34.99005384743214, 0.794139455538243, 0.2675802761223167, 0.5472518596798182, 0.28306854190304875, 0.17453348147682846, 0.3567776398267597, 0.23818034824216738, 1.3645928702317178, 2.92160052806139, 1.570673743262887, 43.40575486421585, 74.7754579782486, 63.35593454539776, 72.36791476607323, 43.42005729675293, 104.88242045044899, 116.53099939227104, 86.8328645825386, 84.34640720486641, 92.6003623008728, 90.40559247136116, 76.51866763830185, 88.71557995676994, 84.99126300215721, 82.7675311267376, 93.1720644235611, 75.55076077580452, 83.01711693406105, 71.6540090739727, 63.04710611701012, 78.57921347022057, 90.92393025755882, 58.851299062371254, 36.420008316636086, 37.42319628596306, 42.0310228317976, 39.072030410170555, 44.407392516732216, 74.69681739807129, 57.51578472554684, 62.1021044254303, 26.01078987121582, 7.703993506729603, 3.9729188522323966, 1.2658854480832815, 0.6697834690567106, 5.980634456500411, 7.555232439190149, 0.49502995563670993, 1.896413757931441, 2.330739120952785, 2.7049387665465474, 0.602452150778845, 1.0500946710817516, 2.3256120085716248, 1.3415998290292919, 11.056428216397762, 20.544935166835785, 3.8960202410817146, 13.34823913872242, 5.839052628725767, 4.5887833926826715, 0.5459820746909827, 2.8295051073655486, 0.4166236863238737, 0.6799156253691763, 0.4459299106383696, 2.397359046153724, 0.8973470237106085, 0.3419553179992363, 0.23566933610709384, 0.6302498560398817, 0.16249223932391033, 0.22501724597532302, 4.841103628277779, 22.29876145720482, 30.972223542630672, 44.592119604349136, 54.36414644122124, 43.31085875630379, 34.81976218521595, 30.170052386820316, 16.248963586986065, 25.879343524575233, 63.685236275196075, 76.04035690426826, 81.63980484008789, 69.54973518848419, 73.88417020440102, 69.63758647441864, 75.31005129218102, 80.19535794854164, 73.69847416877747, 70.31189829111099, 75.30462518334389, 69.90797996520996, 70.67161738872528, 72.36218467354774, 74.14228275418282, 67.31404915452003, 78.53866964578629, 75.03119945526123, 76.7270940542221, 65.2028900384903, 48.789150193333626, 75.48088252544403, 44.388853311538696, 50.125557482242584, 50.37676580250263, 7.048866860568523, 1.018769033253193, 13.165012020617723, 8.696823231875896, 4.234712217003107, 6.184625085443258, 0.7125652546528727, 3.664088286459446, 16.67389288544655, 37.28509649634361, 35.5965469032526, 45.184697806835175, 49.57070365548134, 3.749264753423631, 0.4215122130699456, 0.3080899320775643, 0.18058275687508285, 0.22227027540793642, 0.15940855635562912, 0.14440335449762642, 0.14002738462295383, 0.30010605580173433, 0.282141599454917, 0.15190872363746166, 0.2309493807842955, 0.2080537538859062, 0.16214256902458146, 0.21335825440473855, 0.1490509058930911, 0.3979013190837577, 0.13358506781514734, 0.1227663952158764, 0.18437700171489269, 0.20404400420375168, 0.20033817883813754], [0.06895515965879895, 0.05016291550418828, 0.09213276556693017, 0.028719933216052596, 0.028232898803253192, 0.08358545077499002, 0.021681983525922988, 0.021655698510585353, 0.07483273177058436, 0.08339905296452343, 0.10078684572363272, 0.06683451720164157, 0.05667258221365046, 0.07846471344237216, 0.02202430656325305, 0.09811124749830924, 0.011665578131214716, 0.037300101030268706, 0.07787350376020186, 0.11796548642450944, 0.10175037605222315, 0.13393651926890016, 0.073740334919421, 0.21998287236783653, 0.023666898305236828, 3.273785342462361, 34.80461619794369, 40.890886411070824, 53.03716264665127, 66.21944949030876, 46.28839798271656, 39.32259276509285, 0.2703212352935225, 0.15577428886899725, 0.1399248791858554, 0.38609271054156125, 0.12519289157353342, 0.6855185434687883, 0.7470468012616038, 0.31037429231218994, 0.3288111701840535, 4.672264438122511, 56.863785311579704, 53.46841290593147, 48.68615671992302, 47.34955944120884, 53.19220572710037, 93.22277650237083, 78.48585247993469, 96.5533509850502, 79.07414451241493, 83.26124623417854, 81.94210901856422, 82.60382831096649, 81.38385817408562, 75.94321131706238, 81.53660997748375, 88.56943219900131, 80.10549277067184, 74.4956485927105, 73.36185023188591, 69.78941112756729, 70.75895950198174, 77.2867964208126, 74.93131041526794, 51.58934913575649, 27.172569930553436, 36.58304616808891, 26.534234583377838, 31.96465238928795, 50.3659325838089, 52.268539890646935, 46.556598991155624, 12.320666927844286, 2.7511571114882827, 0.26048056490253657, 0.8794471342116594, 2.112544379197061, 0.21988315740600228, 0.18775243777781725, 0.8406892139464617, 0.46627571107819676, 1.0391558893024921, 0.40385984466411173, 0.26046708750072867, 0.17550939082866535, 2.2987495874986053, 0.1793912981520407, 4.406999722123146, 20.633172132074833, 2.6669757161289454, 6.513093709945679, 0.06603977351915091, 0.7436920562759042, 0.15195593907264993, 0.10618916872772388, 0.3614628181094304, 0.734190191142261, 0.4215093929087743, 0.4282067413441837, 0.20924902724800631, 0.4221051890635863, 0.32347972970455885, 0.10698744503315538, 0.08028949130675755, 0.25169386295601726, 2.041313163936138, 1.4304651855491102, 21.558677069842815, 36.917967796325684, 39.36820171773434, 28.911001347005367, 28.880033008754253, 21.499784030020237, 19.971338845789433, 43.56980726122856, 71.70736581087112, 71.99862778186798, 74.6645799279213, 70.52081108093262, 74.76341262459755, 70.53749978542328, 73.56056436896324, 73.15065756440163, 72.82764449715614, 70.27702376246452, 71.55038103461266, 69.3894749879837, 70.75732558965683, 77.23451882600784, 71.83106437325478, 79.34092819690704, 70.88125973939896, 77.33662694692612, 70.60024961829185, 83.56772258877754, 48.81702549755573, 38.301378563046455, 52.47663192451, 28.72284684330225, 39.79617655277252, 15.992076471447945, 0.5049953365232795, 3.584419386461377, 2.1005071001127362, 2.349836896173656, 2.199370670132339, 0.6508035468868911, 6.117478413507342, 5.877153184264898, 5.649513574317098, 6.602680077776313, 22.92618378996849, 5.932502439245582, 0.07420886016916484, 0.08653545068227686, 0.10226451369817369, 0.013496295032382477, 0.05282462443574332, 0.06051658434444107, 0.06978730016271584, 0.05449210038932506, 0.03732711149496026, 0.10146162123419344, 0.11423417570767924, 0.12012322884402238, 0.017745697186910547, 0.07046214246656746, 0.016222058729908895, 0.01949229907040717, 0.09001693222671747, 0.03239871657569893, 0.08587425647419877, 0.06490651401691139, 0.03882628690917045, 0.06394734751665965, 0.04783750337082893, 0.06128241766418796, 0.11977473113802262, 0.07577894779387861, 0.0468163638288388, 0.047660063282819465, 0.02888988132326631, 0.07118520210497081, 0.07852770693716593, 0.05974553743726574, 0.057112961512757465, 0.020686713396571577, 0.07476458034943789, 0.022285527702479158, 0.0059086217152071185, 0.03461684384092223, 0.00969757133134408, 0.09854472111328505, 0.034479427777114324, 0.13132021122146398, 0.05949534832325298, 0.14974334451835603, 0.16411218442954123, 0.16525059443665668, 0.11776927742175758, 5.348572097718716, 45.83134710788727, 59.874071180820465, 66.37980848550797, 79.04748514294624, 55.44580020010471, 40.972300842404366, 1.8487500655464828, 0.14575646782759577, 0.06661087842076086, 0.6597984954714775, 0.6396821967791766, 1.2107477942481637, 2.3593758093193173, 0.3467649989761412, 1.4835036895237863, 16.49108849465847, 59.611550867557526, 47.40261599421501, 54.72031272947788, 54.95293624699116, 47.99704849720001, 99.7748713195324, 81.20311707258224, 97.16965511441231, 80.03987029194832, 84.72814992070198, 81.7036110162735, 82.79320254921913, 83.0129599571228, 79.6875, 88.51331681013107, 90.31977787613869, 79.36727598309517, 74.72917646169662, 74.18365493416786, 69.15203332901001, 77.02256619930267, 82.74133533239365, 75.13792812824249, 33.21133129298687, 23.19425370544195, 35.451637879014015, 24.265830405056477, 34.13796856999397, 60.666169077157974, 62.52920910716057, 55.56080102920532, 24.984419345855713, 10.736235547810793, 0.6736251816619188, 0.9171561920084059, 1.5785263781435788, 0.3123277734266594, 0.10521910749957897, 0.6785665196366608, 0.6218857923522592, 1.536619970574975, 0.928054719697684, 0.22489899216452613, 0.20162676984909922, 1.3363099191337824, 0.6727303296793252, 8.403265234082937, 22.224154360592365, 2.5756395421922207, 13.836396094411612, 1.1281200405210257, 0.8545498608145863, 0.3544200741453096, 0.0761637587856967, 0.6295894039794803, 0.40808836463838816, 0.7771134003996849, 0.3581477631814778, 0.16589465987635776, 0.6278686900623143, 0.1834679747116752, 0.3389521432109177, 0.0337304449203657, 0.7305534300394356, 1.4337890571914613, 5.47737711109221, 26.735441386699677, 43.90597142279148, 42.301556915044785, 33.682688400149345, 27.03536119312048, 29.228658601641655, 18.362299986183643, 17.87582729011774, 62.289966344833374, 76.93197906017303, 79.74076554179192, 73.49643141031265, 74.19343560934067, 75.41595920920372, 73.10798585414886, 74.65659275650978, 74.28752616047859, 74.63515430688858, 71.16168469190598, 69.80612263083458, 70.22154673933983, 79.28399205207825, 70.39655774831772, 80.13843700289726, 70.6660544872284, 77.17040866613388, 69.11835193634033, 84.73198771476746, 59.84521172940731, 44.58889737725258, 60.11128105223179, 39.20133367180824, 52.07434371113777, 26.784806437790394, 0.8891329925972968, 0.9014645183924586, 2.8144538775086403, 3.0826076259836555, 0.4076021391665563, 1.5749821183271706, 10.978639740496874, 16.442616395652294, 17.12114218622446, 22.506543807685375, 36.4130736887455, 5.634625498205423, 0.08981223305454478, 0.048388544310000725, 0.09082026255782694, 0.0625719029631, 0.04901501342828851, 0.02242882714199368, 0.037428121504490264, 0.0924652922549285, 0.06601487446459942, 0.034644644692889415, 0.021583791822195053, 0.050116308630094863, 0.08153137896442786, 0.1032768699224107, 0.01877555696410127, 0.01688852033112198, 0.08218614617362618, 0.08587358111981302, 0.05306536229909398, 0.03145540234982036, 0.0780156695691403, 0.031711914562038146, 0.20729483367176726, 0.15578804828692228, 0.23342926724581048, 0.24431008729152381, 0.1368266501231119, 0.14961499749915674, 0.09489689458860084, 0.1848749234341085, 0.18301502714166418, 0.26244188309647143, 0.1581412204541266, 0.20035176014062017, 0.15570455667329952, 0.22663860116153955, 0.2455088635906577, 0.13656306895427406, 0.14936050021788105, 0.2542868675664067, 0.14882738585583866, 0.21230725455097854, 0.2515863406006247, 0.31832587032113224, 0.35648864752147347, 0.29225882375612855, 0.26760642940644175, 6.193650076165795, 61.84024527668953, 82.3784776031971, 82.97303169965744, 94.1806823015213, 74.28398475050926, 69.2177926003933, 2.234403365291655, 0.3549147304147482, 0.24379068781854585, 0.7702432502992451, 0.7716136111412197, 0.6268071220256388, 3.628721684217453, 0.7740259473212063, 3.487856830470264, 17.362579330801964, 79.30635765194893, 73.14631059765816, 64.65803727507591, 70.10583534836769, 67.40606501698494, 103.850487023592, 78.45825836062431, 100.8504644036293, 81.56127065420151, 76.36777013540268, 81.88379734754562, 84.80451822280884, 80.53210347890854, 73.23367550969124, 87.97667920589447, 91.51572570204735, 81.61480978131294, 76.36868968605995, 71.87239855527878, 68.43197956681252, 72.47733369469643, 84.35339882969856, 82.66904041171074, 70.78597605228424, 31.055192090570927, 46.87083452939987, 34.94829788804054, 36.17357634007931, 67.3606650531292, 68.25194522738457, 58.788503631949425, 29.22194816172123, 14.157334472984076, 0.32997275004163384, 0.8449058001860976, 3.324479847215116, 0.2858943137107417, 0.22881548356963322, 0.7632732368074358, 1.4773919549770653, 2.4385445611551404, 0.824944224441424, 0.3467394394101575, 0.28156189306173474, 3.9781846571713686, 0.3826198453316465, 6.9413915276527405, 29.092709496617317, 3.759427070617676, 16.804907955229282, 0.4362030857009813, 1.9391811755485833, 0.8335828233975917, 0.35668914613779634, 2.728588222526014, 0.6461418501567096, 0.7510213879868388, 0.961900275433436, 0.333058659452945, 0.694075565552339, 0.46069473086390644, 0.5277424596715719, 0.13791639008559287, 0.541689908131957, 1.756723872385919, 15.048046577721834, 28.503894992172718, 47.60520972311497, 45.417249128222466, 42.66194097697735, 35.73830969631672, 27.66016736626625, 24.088530018925667, 57.382130697369576, 80.92340648174286, 74.30736869573593, 76.2109449505806, 67.77265414595604, 72.97398224473, 72.32050091028214, 76.15093097090721, 77.51033842563629, 73.02858531475067, 73.75105574727058, 70.43921425938606, 70.59592545032501, 70.81575885415077, 77.72109031677246, 69.15916174650192, 81.03968024253845, 70.22198751568794, 76.44557476043701, 67.28610545396805, 85.09676054120064, 58.05453881621361, 56.36171445250511, 68.73299181461334, 46.40584588050842, 62.85776607692242, 31.82551145553589, 0.6972887681331486, 9.0903852134943, 5.0758664309978485, 8.16747933626175, 4.439326962456107, 0.8959527360275388, 15.02357779070735, 32.09974654018879, 35.4484498500824, 36.567125022411346, 53.5092531144619, 13.24803376570344, 0.19447228813078254, 0.18673600716283545, 0.2465579190175049, 0.16131407988723367, 0.17380314879119396, 0.09839089616434649, 0.16219474200624973, 0.3181247186148539, 0.14731901523191482, 0.11353787791449577, 0.2117836248362437, 0.1272994332248345, 0.2495189249748364, 0.24993912898935378, 0.08605731462012045, 0.08935029807616957, 0.2459629243821837, 0.15834220888791606, 0.15530675067566335, 0.23674319410929456, 0.1890745887067169, 0.12144093430833891], [0.07747793904854916, 0.05800126775284298, 0.047858743637334555, 0.12818195071304217, 0.03561574121704325, 0.02843814159859903, 0.10343185262172483, 0.06274996645515785, 0.05707288182748016, 0.13427832280285656, 0.054893769265618175, 0.03160862986987922, 0.04510731276241131, 0.03574399175704457, 0.1376183732645586, 0.06521574468933977, 0.053918754201731645, 0.08342978529981337, 0.07939262068248354, 0.044204690493643284, 0.0090236938194721, 0.06253408311749808, 0.22716715873684734, 0.09617223084205762, 0.26996589498594403, 0.2830237755551934, 20.34623432904482, 45.615678280591965, 42.97798901796341, 55.429088696837425, 37.77064964175224, 33.43323178589344, 0.7969163940288126, 0.18760506209218875, 0.06480782321887091, 1.4545219321735203, 1.110803538467735, 1.1167984292842448, 4.881628453731537, 1.2310629291459918, 1.1233169795013964, 16.601789854466915, 65.75794905424118, 46.01466827094555, 56.11365996301174, 40.42104162275791, 73.22153896093369, 79.21347543597221, 82.74794697761536, 85.53196638822556, 79.64751854538918, 90.2174873650074, 80.36844626069069, 80.38173794746399, 78.68262872099876, 81.38284742832184, 83.14388573169708, 87.19291046261787, 81.29381820559502, 85.01604527235031, 69.66129720211029, 74.71244975924492, 64.20278370380402, 81.61432340741158, 80.13355046510696, 79.30499732494354, 40.74372410774231, 27.682175785303116, 43.61701212823391, 40.27703694999218, 42.78548374772072, 44.85008776187897, 51.86392620205879, 15.17318431288004, 5.027343509718776, 1.5014756564050913, 0.6740742700640112, 1.1052338685840368, 0.2786327846115455, 0.6188321218360215, 0.7381648966111243, 0.5252766888588667, 0.39565949875395745, 2.6319558452814817, 0.1683962912647985, 0.6006284267641604, 0.8768776408396661, 3.759841723367572, 9.3811902590096, 18.94992135465145, 1.4422502531670034, 12.332359850406647, 2.2049399837851524, 0.7393708568997681, 0.45683277247007936, 0.9842629660852253, 0.9637019725050777, 0.4408586077624932, 0.7934155350085348, 0.6676651421003044, 0.04789867489307653, 0.20660438400227576, 0.15371665474958718, 0.3463814570568502, 0.2577838971046731, 0.5845265532843769, 0.15676076640374959, 3.1717427680268884, 22.280083559453487, 45.135406851768494, 33.904588893055916, 29.927142821252346, 25.27765341103077, 22.876852937042713, 61.80133156478405, 64.12939444184303, 80.74895784258842, 66.09666287899017, 69.15950372815132, 66.41035124659538, 76.7510175704956, 71.21920600533485, 77.53480151295662, 75.00662997364998, 71.39619290828705, 71.07134833931923, 77.01235994696617, 73.37001979351044, 75.92253282666206, 72.8761450946331, 76.27644583582878, 71.54409617185593, 76.4077515900135, 72.33996346592903, 78.57177346944809, 78.12941640615463, 75.50446406006813, 36.83113865554333, 48.62759806215763, 40.01382887363434, 41.75660155713558, 32.24384240806103, 2.9534430569037795, 1.3313802774064243, 3.7889153882861137, 0.9595883963629603, 1.0493974084965885, 3.9868310932070017, 8.771155793219805, 6.268144128844142, 1.3027033349499106, 3.7660852633416653, 6.302598780021071, 0.21751186199253425, 0.09064121200935915, 0.04925419278151821, 0.05108443285280373, 0.028979447415622417, 0.02344876811548602, 0.02995586513861781, 0.013826626818627119, 0.08214152083382942, 0.017410268701496534, 0.013762302096438361, 0.036798253349843435, 0.0590867886057822, 0.05166914874280337, 0.030876215460011736, 0.03196314268279821, 0.03602256430895068, 0.05895984795643017, 0.023582458597957157, 0.03540789533872157, 0.053036555837024935, 0.048811138040036894, 0.10232001150143333, 0.10433011848363094, 0.08457197283860296, 0.0067304616732144495, 0.14383008994627744, 0.010316463121853303, 0.015236466206260957, 0.03797366684011649, 0.008330392447533086, 0.0348794231103966, 0.13915856718085706, 0.05084707918285858, 0.03139051637845114, 0.030465982199530117, 0.058955703061656095, 0.12448887544451281, 0.12290251252125017, 0.06311640929197893, 0.03988074146036524, 0.0493165628722636, 0.04947163091856055, 0.07003585284110159, 0.20422621630132198, 0.08467593288514763, 0.11593810966587625, 0.2519367233617231, 0.6013328733388335, 28.941629603505135, 61.85172826051712, 64.30591017007828, 68.5044264793396, 54.19315941631794, 40.447662994265556, 5.9697280917316675, 0.11001643171766773, 0.031831021842663176, 2.12412734515965, 1.123117608949542, 2.8416627924889326, 7.091661589220166, 0.44487704057246447, 2.7801414811983705, 25.47764427959919, 54.16332721710205, 49.44969914853573, 63.2071877270937, 46.66078940033913, 76.77020654082298, 81.20790481567383, 88.04938450455666, 86.52832612395287, 80.78999564051628, 90.83648934960365, 81.19585186243057, 78.58748182654381, 81.8264888226986, 80.0596672296524, 83.66312026977539, 93.31006541848183, 84.19994786381721, 84.06245604157448, 71.98378577828407, 72.7745309472084, 64.77271512150764, 88.55867877602577, 86.37080177664757, 71.55522957444191, 24.177523143589497, 28.96065518260002, 36.05827532708645, 36.51929698884487, 49.87917110323906, 61.86955310404301, 59.516434371471405, 20.24245049804449, 13.052117228507996, 5.537186376750469, 0.6154895480722189, 0.31013511295896024, 0.735879794228822, 0.9034128638450056, 0.7088031596504152, 0.5779341445304453, 0.21597113372990862, 1.7046650033444166, 0.27576405729632825, 1.4545518555678427, 1.0571495862677693, 8.51156322285533, 11.087292060256004, 25.280292369425297, 0.826541444985196, 7.386620761826634, 5.775087336078286, 1.508823987096548, 1.3667049631476402, 1.3195556681603193, 0.767369179520756, 0.5522314924746752, 1.6471552080474794, 0.7835252594668418, 0.05686149961547926, 0.5717734282370657, 0.11819633888080716, 0.6120930053293705, 0.4200367641169578, 0.387966099078767, 0.9433619014453143, 8.699655029922724, 31.28016471862793, 49.943927228450775, 38.41646298766136, 35.506852716207504, 31.76522959023714, 24.355714581906796, 38.257251530885696, 50.94558008015156, 85.60679197311401, 69.99233543872833, 72.8359280526638, 65.28484404087067, 82.93922111392021, 71.19821593165398, 80.85625648498535, 74.93681252002716, 76.44190415740013, 73.34579229354858, 77.21362754702568, 74.30771827697754, 76.57105922698975, 72.06280633807182, 75.36819577217102, 72.65557453036308, 77.74467945098877, 73.97520571947098, 80.06313264369965, 81.2842883169651, 80.98520636558533, 44.93152879178524, 55.141398534178734, 49.99641761183739, 49.02522012591362, 47.26589173078537, 5.833994150161743, 0.08353678073035553, 3.431201158091426, 0.7813050504773855, 3.350078361108899, 8.38865976780653, 17.505459263920784, 14.795864559710026, 13.733292426913977, 12.75974191725254, 2.3030685307458043, 0.17725064739352092, 0.16833567264257, 0.11160806388943456, 0.08109910762868822, 0.012943337496835738, 0.065871595434146, 0.045569318244815804, 0.042207556252833456, 0.03445841386565007, 0.04182571756246034, 0.052008399288752116, 0.014584108193957945, 0.1561016947380267, 0.01811083569918992, 0.03512275477987714, 0.0653905353101436, 0.04850620069191791, 0.03931112456484698, 0.037960608751745895, 0.07297622709302232, 0.06960687664104626, 0.04398294047859963, 0.059295799655956216, 0.2913865924347192, 0.1423913476173766, 0.19904513494111598, 0.28846012603025883, 0.11873509356519207, 0.22354608663590625, 0.16272206761641428, 0.17212642938829958, 0.2039189968490973, 0.3286399121861905, 0.14154988573864102, 0.13257211045129225, 0.15363034297479317, 0.1479061134159565, 0.30248220486100763, 0.16955512517597526, 0.22953863226575777, 0.11418695285101421, 0.31739177356939763, 0.1691227054107003, 0.3015235281782225, 0.3080919507192448, 0.27263688447419554, 0.17832233832450584, 0.2868873963598162, 0.8509184431750327, 33.17440487444401, 84.719417989254, 81.8532545864582, 87.52201840281487, 70.79093098640442, 68.02364587783813, 12.120696008205414, 0.38255916733760387, 0.12833953835070133, 4.017154891043901, 1.68820844264701, 1.883991512004286, 16.39823667705059, 1.2147286743856966, 4.058332806453109, 34.938756600022316, 98.37492004036903, 63.96295577287674, 75.56022226810455, 58.116509690880775, 78.54894429445267, 82.5984326004982, 89.08501133322716, 88.53322014212608, 83.71282920241356, 95.88861465454102, 78.0384036898613, 80.6509231030941, 78.69888424873352, 77.89404943585396, 82.97528117895126, 92.0379164814949, 83.58986780047417, 89.51158404350281, 66.55820891261101, 77.38395720720291, 61.100322380661964, 86.95066586136818, 84.75931584835052, 95.72802007198334, 51.38156868517399, 33.97734358906746, 53.890289068222046, 48.71875137090683, 52.65124775469303, 69.45408672094345, 65.59115320444107, 25.6181151419878, 18.13225083053112, 7.547802412882447, 0.6125000584870577, 1.444628806784749, 1.3757294788956642, 0.9589522867463529, 0.8634761755820364, 0.9112431749235839, 0.6071020325180143, 4.760498553514481, 0.2088779237237759, 1.3655871106311679, 1.29612660035491, 6.67958177626133, 16.783847585320473, 27.957444414496422, 2.7206960460171103, 19.370066709816456, 4.512139605358243, 3.3911498822271824, 1.096963849849999, 1.0931883961893618, 2.0566018810495734, 2.268363805487752, 3.3473296836018562, 1.1178583349101245, 0.09792303884751163, 0.5868855735752732, 0.20838383148657158, 0.9894990851171315, 0.5651611299254, 0.7172192330472171, 0.5219258624128997, 14.674767907708883, 29.80480458587408, 59.29162323474884, 37.17810943722725, 49.626036286354065, 27.93205227702856, 28.947914466261864, 73.30186665058136, 77.06711500883102, 82.54588142037392, 66.50971591472626, 69.62655186653137, 63.84684160351753, 81.58032283186913, 73.59287023544312, 78.6394402384758, 74.76076036691666, 72.39443734288216, 71.82857930660248, 76.88748344779015, 73.73093962669373, 75.09813666343689, 72.04279661178589, 75.05722805857658, 72.23825812339783, 75.72383388876915, 72.83408895134926, 81.54537990689278, 82.71146893501282, 79.64389353990555, 49.43113334476948, 68.08505058288574, 57.67746224999428, 59.62448537349701, 52.17295601963997, 6.659347387030721, 2.655617888085544, 13.890420645475388, 3.9755540108308196, 2.8654901264235377, 9.067324250936508, 30.13318106532097, 30.87489176541567, 34.081450402736664, 39.76137802004814, 13.372887466102839, 0.5087811208795756, 0.2174321108032018, 0.3554280591197312, 0.16833093774039298, 0.15596922137774527, 0.16065236617578194, 0.16846152604557574, 0.1206058771640528, 0.18432037584716454, 0.09695953820482828, 0.22204273293027654, 0.13337722193682566, 0.15318254590965807, 0.20177770784357563, 0.1505528049892746, 0.09339820157038048, 0.24259151075966656, 0.11417774279834703, 0.12875986110884696, 0.29349734948482364, 0.10523697099415585, 0.10335369704989716, 0.23108917172066867], [0.1267641963204369, 0.019942335566156544, 0.011297089749859879, 0.03000078177137766, 0.04742283206724096, 0.07974502950673923, 0.02897308349929517, 0.09214226505719125, 0.07104912932845764, 0.10687858681194484, 0.17364836647175252, 0.14077103143790737, 0.08111783943604678, 0.05776869351393543, 0.05394324878579937, 0.05359358219720889, 0.033174097625305876, 0.025715962474350818, 0.05415944011474494, 0.05433665755845141, 0.19784040661761537, 0.061528614023700356, 0.035681306253536604, 0.024054624082054943, 0.0457510442356579, 0.036461622585193254, 5.0952111929655075, 46.23044729232788, 47.826266661286354, 37.69124910235405, 47.19075456261635, 28.355731442570686, 4.910006755962968, 0.6903968285769224, 0.15627650020178407, 1.6066890419460833, 2.4621099466457963, 5.340713169425726, 1.9455011864192784, 0.5174590239766985, 5.692551489919424, 43.48307691514492, 57.9117576777935, 58.37455004453659, 48.023274689912796, 49.56189192831516, 86.56766921281815, 75.15957176685333, 83.20766910910606, 83.19641411304474, 83.95385786890984, 81.0878312587738, 77.7326188981533, 83.60229313373566, 78.47649738192558, 81.48643746972084, 83.716811388731, 78.87872099876404, 79.04925584793091, 79.04762953519821, 68.68127658963203, 70.63405260443687, 74.71757188439369, 69.2194265127182, 77.02643439173698, 75.01295283436775, 65.02201974391937, 33.42974737286568, 32.95796848833561, 41.8753831833601, 42.98254497349262, 47.742161974310875, 52.307438403367996, 21.32910668849945, 7.974039316177368, 2.958123693242669, 1.2307469523511827, 0.42515090375673026, 0.12149215734098107, 0.018050111320917495, 0.16379778098780662, 0.5521928414236754, 0.7028120092581958, 2.4814642081037164, 0.8000502164941281, 0.5084131937474012, 0.8000982482917607, 2.144973026588559, 8.655705638229847, 21.977857276797295, 1.5343337995000184, 8.825962152332067, 7.76266710832715, 0.9648840653244406, 3.3064517145976424, 3.6251524882391095, 2.5872189458459616, 3.7307205609977245, 0.5695421167183667, 0.24722608941374347, 0.3191832883749157, 0.562760311877355, 0.42433074151631445, 1.0572029021568596, 0.176628059707582, 1.2705629970878363, 0.46786613354925066, 3.1437955051660538, 19.797112494707108, 49.01404872536659, 28.368477858603, 37.98000320792198, 12.355757094919682, 58.89883451163769, 76.46214947104454, 52.97247491776943, 70.56370317935944, 65.92184945940971, 73.73128920793533, 72.22859144210815, 76.57628774642944, 72.29752734303474, 74.93318751454353, 72.84651428461075, 75.13598263263702, 73.37581068277359, 75.92219844460487, 67.79118195176125, 74.9048562347889, 70.14612078666687, 76.6326767206192, 78.91364872455597, 81.16299882531166, 72.81460359692574, 76.19836002588272, 70.2518767118454, 80.2339106798172, 55.89228004217148, 40.053255558013916, 50.492173209786415, 35.774099975824356, 40.08604779839516, 11.722500175237656, 0.39352095569483936, 2.993740844540298, 1.1888349638320506, 5.882100518792868, 9.334586709737778, 10.757240820676088, 10.666742026805878, 12.124586049467325, 6.672470457851887, 1.6801637993194163, 0.09649253435782157, 0.09948713734047487, 0.12576532491948456, 0.0525766617647605, 0.051538315528887324, 0.061165347578935325, 0.12731393479043618, 0.08436501753749326, 0.05933423548412975, 0.04950004775309935, 0.0873878740821965, 0.026090286919497885, 0.07081535281031393, 0.07919173614936881, 0.05419407243607566, 0.027579740199144, 0.05878981450223364, 0.03877074457705021, 0.012252805263415212, 0.023456096823792905, 0.017198264940816443, 0.05639240662276279, 0.01785146065230947, 0.009152513030130649, 0.020762649946846068, 0.011305344287393382, 0.01476157425713609, 0.07753286539809778, 0.07541566650616005, 0.052665430048364215, 0.07684963682550006, 0.10060009910375811, 0.022949363956286106, 0.1788372700684704, 0.1427802923717536, 0.11210314318304881, 0.06023853871738538, 0.021346657085814513, 0.06903329296619631, 0.036392079637153074, 0.01635440406971611, 0.03394514824321959, 0.04476890084333718, 0.168027414183598, 0.0528841632331023, 0.15715150715550408, 0.05502338164660614, 0.19753830798435956, 0.07913786364952102, 8.244258016347885, 61.26007720828056, 67.42817223072052, 62.09513179957867, 62.84262768924236, 45.9040068089962, 16.728974729776382, 1.044708222616464, 0.22493509022751823, 0.4944516147952527, 3.6112335976213217, 4.777050940319896, 0.948397284373641, 0.14988761802669615, 11.684819497168064, 54.873227924108505, 49.7183333337307, 67.49857485294342, 52.005761191248894, 59.94456119835377, 89.7266373038292, 80.50194829702377, 84.99134659767151, 86.5869265794754, 87.93431147933006, 78.81426885724068, 77.42061764001846, 83.3958350121975, 81.82395815849304, 80.07310330867767, 84.91037294268608, 82.51341596245766, 81.29885673522949, 80.05761533975601, 69.49748799204826, 73.85827079415321, 77.10727885365486, 73.59936788678169, 82.60275676846504, 79.85952436923981, 53.31432357430458, 22.853639982640743, 38.751472011208534, 45.719378516077995, 47.43682935833931, 63.054257333278656, 55.36778278648853, 23.6988590285182, 15.160830225795507, 7.976052258163691, 1.8180069839581847, 0.4000189038924873, 0.24690718855708838, 0.04450682994502131, 0.10350187425501645, 1.2556322920136154, 0.337979692267254, 2.199752787128091, 0.9972346387803555, 0.8103169093374163, 1.8679367797449231, 16.606976576149464, 6.974147669970989, 23.76566704362631, 0.7818774541374296, 4.006687877699733, 4.985402310267091, 1.8712408212013543, 4.418840361759067, 11.846631914377213, 6.544427303597331, 7.030421225354075, 1.2958893505856395, 0.280039599747397, 0.6091877049766481, 0.5562442552763969, 1.0985109605826437, 1.0562178050167859, 0.2916194486897439, 0.6831380899529904, 2.1607048949226737, 13.428247645497322, 33.23816545307636, 59.00744408369064, 33.770266100764275, 44.24489423632622, 18.748057186603546, 62.302289083600044, 76.43102154135704, 56.071790009737015, 73.91209110617638, 64.7973757982254, 74.28010135889053, 73.45300734043121, 77.4727888405323, 72.80028596520424, 80.74208781123161, 75.05565494298935, 74.29001122713089, 74.1685089468956, 77.01865240931511, 71.82306200265884, 74.90910440683365, 73.1264528632164, 79.20194685459137, 78.55098858475685, 82.6927587389946, 76.39094889163971, 77.65014812350273, 72.31589555740356, 81.29414498806, 65.05789741873741, 47.05431908369064, 60.94876751303673, 48.86962987482548, 55.37675030529499, 21.15619696676731, 0.8067485445644706, 0.9259704721625894, 5.034258663654327, 11.723337080329657, 19.897292219102383, 21.960404813289642, 24.556700997054577, 18.35210893303156, 7.623525224626064, 2.530286363326013, 0.03416256782657001, 0.1402463627164252, 0.061519660011981614, 0.013456367487378884, 0.04586375791404862, 0.01807555770938052, 0.07982083247043192, 0.10746031926828437, 0.0337476850108942, 0.08224985213018954, 0.13231103774160147, 0.06316231854725629, 0.07729316654149443, 0.12088361851056106, 0.05822816085128579, 0.04014699436083902, 0.05350329251086805, 0.0726284715346992, 0.05347671620256733, 0.05330472718924284, 0.007230679411804886, 0.06129396548203658, 0.05652044193993788, 0.23290284705581143, 0.10530215382459573, 0.09483228321187198, 0.12475106137571856, 0.12460698082577437, 0.1481834243168123, 0.14172470604535192, 0.1668411653372459, 0.20219463156536222, 0.17695077520329505, 0.344421801273711, 0.25238646485377103, 0.13396670983638614, 0.2068223973037675, 0.07758865263895132, 0.14555148663930595, 0.2449601492844522, 0.14074046979658306, 0.29561499366536736, 0.31912002770695835, 0.5244762974325567, 0.23883247340563685, 0.18301498261280358, 0.20324206911027431, 0.3810736845480278, 0.24801190505968407, 9.664156325161457, 74.84317034482956, 87.25082695484161, 73.87983843684196, 84.84305575489998, 66.78084656596184, 29.393189772963524, 1.1963038193061948, 0.15463495859876275, 4.465261045843363, 5.369438203051686, 10.463991556316614, 3.429542309604585, 0.5077048286329955, 12.314674649387598, 72.89262861013412, 83.41500118374825, 80.40519028902054, 66.43799856305122, 65.14119654893875, 90.76554715633392, 84.59847807884216, 88.5593019425869, 88.8599494099617, 87.18614682555199, 80.09990707039833, 77.26058542728424, 85.685675740242, 84.28730517625809, 79.86104428768158, 86.26874685287476, 80.75367718935013, 78.93264770507812, 79.99972924590111, 69.33468952775002, 71.20554953813553, 75.41922703385353, 68.70152950286865, 78.44526305794716, 85.32210364937782, 80.61373069882393, 38.644564747810364, 39.45930562913418, 51.62298493087292, 51.918020099401474, 68.66970241069794, 61.04457937180996, 32.3003301769495, 24.402594566345215, 16.71330627053976, 1.2390690995380282, 1.0305227525532246, 0.35076196887530386, 0.22791058290749788, 0.18793975585140288, 1.698327655903995, 0.8343338768463582, 4.86790026538074, 5.5846125818789005, 1.0485190618783236, 1.4044581935741007, 18.236401341855526, 9.591648615896702, 31.42688624560833, 2.503011664375663, 16.863495111465454, 9.936722349375486, 2.0400910545140505, 4.885173188522458, 14.037366360425949, 4.51923287473619, 7.7923425659537315, 1.4988603279925883, 0.7538717100396752, 0.5328977736644447, 0.7996108056977391, 1.5463627665303648, 2.967171245254576, 0.2269594167592004, 2.452134769409895, 0.8897535467986017, 17.09982343018055, 31.299874261021614, 67.49604418873787, 37.96076484024525, 54.54444296658039, 18.96532002836466, 64.76877853274345, 90.70434004068375, 55.73569044470787, 69.90896791219711, 63.674209266901016, 74.28292080760002, 72.98632398247719, 73.30864548683167, 74.15826469659805, 75.91753989458084, 71.77250191569328, 77.22743600606918, 76.50494277477264, 78.14320966601372, 70.93466207385063, 74.46802407503128, 71.55960693955421, 77.79129534959793, 76.82640552520752, 79.58765655755997, 78.02450403571129, 76.80908605456352, 72.28403806686401, 81.52990713715553, 62.20437593758106, 56.06051981449127, 68.08356866240501, 55.40689788758755, 68.47579881548882, 21.56068716198206, 1.001777769997716, 5.8934794832021, 6.266261329874396, 10.346703249961138, 30.475043021142483, 38.05161416530609, 37.32963390648365, 27.212427891790867, 6.859964746981859, 3.7790052825585008, 0.1680375073920004, 0.2254428231390193, 0.13726698118261993, 0.18993396603036672, 0.11654282643576153, 0.12834048829972744, 0.22891816712217405, 0.18771835835650563, 0.134195365535561, 0.3159023722400889, 0.24594533548224717, 0.15102351957466453, 0.19389961729757488, 0.21590797696262598, 0.1449384429724887, 0.21023957175202668, 0.23519747861428186, 0.17377754469634965, 0.19567755080061033, 0.11471271252958104, 0.08671457544551231, 0.17778129782527685, 0.1953863023663871], [0.018520029952924233, 0.06921848849742673, 0.034210688681923784, 0.030192263293429278, 0.08056643855525181, 0.023167150902736466, 0.12110595111153089, 0.1317003689473495, 0.0638387564686127, 0.057506555822328664, 0.05339973322406877, 0.08648188988445327, 0.05361786897992715, 0.1284768950426951, 0.025221517717000097, 0.14416131045436487, 0.1299351706984453, 0.05356014473363757, 0.021623248103423975, 0.1428633535397239, 0.14579728594981134, 0.034347470209468156, 0.030834645913273562, 0.1690435627824627, 0.012640655349969165, 0.04499163420405239, 0.29255550471134484, 7.938650865107775, 48.118562176823616, 44.26504075527191, 45.48117309808731, 35.26095651090145, 15.131777934730053, 3.600754947401583, 0.2553233510116115, 1.275190555024892, 2.0438177045434713, 7.06688454374671, 4.028751868754625, 0.22915512003237382, 26.806066296994686, 71.19062393903732, 53.02213445305824, 58.80600929260254, 41.635239869356155, 78.88850167393684, 83.21803495287895, 79.75885257124901, 84.66508850455284, 77.6240587234497, 82.14114233851433, 80.83536520600319, 79.70290437340736, 79.99673500657082, 81.71871140599251, 78.94464746117592, 80.66495195031166, 81.99909076094627, 81.41430214047432, 85.77227309346199, 76.81724801659584, 77.79270127415657, 71.64342284202576, 75.99487334489822, 76.32260575890541, 76.50906935334206, 70.65131887793541, 49.065228179097176, 22.853930667042732, 30.564991794526577, 39.978650361299515, 49.49549049139023, 45.60570001602173, 22.66779575496912, 5.123634617775679, 4.07824088819325, 4.417354641482234, 0.3996266343165189, 0.1267515798099339, 0.6828497804235667, 0.2346443707938306, 0.2920073544373736, 0.1737335798679851, 0.6255815096665174, 3.587661562487483, 1.8599840439856052, 3.575093736872077, 14.086972698569298, 6.252111839130521, 17.055787593126297, 0.26726364623755217, 3.6776454839855433, 6.845931150019169, 1.3151502795517445, 4.952953951433301, 6.3688472751528025, 5.495133558288217, 4.524236731231213, 0.5924715113360435, 0.9884505195077509, 0.29465854342561215, 0.37866330763790756, 0.10647454677382484, 0.5644635111093521, 1.349118200596422, 1.658384317997843, 2.7579079242423177, 8.587583843618631, 13.673819918185472, 48.06849226355553, 32.132816165685654, 35.78371345996857, 18.79469208419323, 23.042254261672497, 27.797710485756397, 62.879725098609924, 69.16219398379326, 77.48804122209549, 68.71098339557648, 76.65837854146957, 72.23858490586281, 76.77473589777946, 72.36396297812462, 75.39129853248596, 75.16415432095528, 74.00955587625504, 68.9387659728527, 74.94586363434792, 76.56897693872452, 71.20965331792831, 74.98102694749832, 78.76968964934349, 73.6106912791729, 76.28513976931572, 75.19912004470825, 73.02752897143364, 73.75056937336922, 73.00686568021774, 38.06934781372547, 46.884335204958916, 49.38682772219181, 39.80485528707504, 25.089740194380283, 6.616022111847997, 1.4169500232674181, 10.668660923838615, 13.970689438283443, 10.922436956316233, 15.807209741324186, 28.407663255929947, 28.53752128779888, 10.181138534098864, 0.17665436142124236, 0.13293527299538255, 0.05990841287712101, 0.03409761135117151, 0.02167308146454161, 0.04557430918794125, 0.014145408931653947, 0.07048042898532003, 0.07164609065512195, 0.03039140563487308, 0.016478539400850423, 0.0761474018509034, 0.02206350865890272, 0.037093353530508466, 0.0904672229080461, 0.12646248360397294, 0.0344152505567763, 0.07294287497643381, 0.03676222579088062, 0.04680141697463114, 0.07820384111255407, 0.07377274450846016, 0.03815881413174793, 0.1427997663267888, 0.11614565868512727, 0.008154797524184687, 0.039427782758139074, 0.06942980762687512, 0.0775171244458761, 0.049213500824407674, 0.07593004163936712, 0.07251391361933202, 0.12982631247723475, 0.06087488953198772, 0.14374604914337397, 0.03618576258304529, 0.07076189591316506, 0.004005801456514746, 0.025402358696737792, 0.10179284916375764, 0.022208490918274038, 0.09781090033357032, 0.034293267453904264, 0.08019310116651468, 0.12504067708505318, 0.038659355632262304, 0.09864882216788828, 0.10093105243868195, 0.11122936819447204, 0.11098821472842246, 0.6649967352859676, 18.29753816127777, 69.54190000891685, 62.97987252473831, 69.15122777223587, 51.75802208483219, 36.77352614700794, 7.823483319953084, 0.22499793529277667, 0.5995206674560905, 0.9513534663710743, 3.055504630319774, 2.1028389874845743, 0.5779816419817507, 42.20204785466194, 82.00757950544357, 61.07835575938225, 69.03315290808678, 50.07438562810421, 85.94935119152069, 86.79417505860329, 83.55668038129807, 87.73827999830246, 80.87025493383408, 86.2855875492096, 82.40142077207565, 81.20304867625237, 82.4864450097084, 82.98358753323555, 81.13586828112602, 82.65242770314217, 81.12468928098679, 83.37951108813286, 88.20438578724861, 77.49823987483978, 76.77431792020798, 72.72795304656029, 77.01695010066032, 77.74506703019142, 76.84245586395264, 74.29710164666176, 35.32489188015461, 22.27630276232958, 34.07087177038193, 48.30415941774845, 63.84899228811264, 47.83390425145626, 26.908691190183163, 12.087722327560186, 4.0750400349497795, 9.923422113060951, 0.44763765181414783, 0.10839754788321443, 0.6455214146990329, 0.2380784068373032, 0.299858920625411, 0.18269704654812813, 0.9037755068857223, 1.0910633602179587, 3.1798353837803006, 2.196276211179793, 11.837725192308426, 7.07915123552084, 19.020010493695736, 0.2929250942543149, 1.8851440376602113, 5.428384440019727, 1.040657996200025, 1.8654929171316326, 6.996375527232885, 0.8390391524881124, 10.481500066816807, 6.113337110728025, 1.9680349272675812, 0.13496105413651094, 0.32040358695667237, 0.08680082784849219, 0.37512406473979354, 1.8046948732808232, 0.7734538405202329, 10.032268222421408, 18.486604616045952, 21.687370464205742, 51.6203098744154, 43.095740899443626, 38.33414040505886, 21.322508342564106, 27.687064222991467, 34.2233157902956, 60.6696230918169, 74.87042248249054, 76.08844712376595, 69.27386239171028, 77.69475772976875, 74.59614560008049, 78.14409121870995, 72.80641123652458, 77.9704861342907, 82.23316580057144, 74.64805841445923, 68.43667611479759, 76.5409268438816, 78.3754912018776, 74.56788271665573, 75.15708670020103, 79.91163477301598, 75.54991722106934, 77.35149934887886, 77.68044009804726, 75.72314992547035, 75.26516050100327, 80.97126871347427, 45.79779490828514, 57.26963393390179, 62.19006970524788, 53.803258538246155, 42.47875280678272, 11.835356019437313, 4.6983215399086475, 15.919286627322435, 22.865723334252834, 22.38034687936306, 28.545242473483086, 41.85037672519684, 33.91753099858761, 11.598132848739624, 0.6444694055244327, 0.08844829178997315, 0.111668652825756, 0.05431973659142386, 0.026641741605999414, 0.08945025794673711, 0.05634167340758722, 0.044994784620939754, 0.1286199811147526, 0.06235465407371521, 0.05839160774485208, 0.03426746668992564, 0.027858264511451125, 0.054757299440097995, 0.02332350100914482, 0.07114721898688003, 0.06162891528219916, 0.036966372063034214, 0.07886176987085491, 0.1252034745994024, 0.08618818494142033, 0.08891445701010525, 0.06960179292946123, 0.136302768078167, 0.1906499158940278, 0.22589176311157644, 0.15109734842553735, 0.16454972501378506, 0.2771652617957443, 0.1371833262965083, 0.2963993843877688, 0.31234303198289126, 0.1786222550435923, 0.08296729371068068, 0.24801623920211568, 0.3372305980883539, 0.24467195849865675, 0.17658269964158535, 0.09419278198038228, 0.304530740249902, 0.16847712598973885, 0.24910439096856862, 0.20238325581885874, 0.26528166665229946, 0.26216396363452077, 0.10981464176438749, 0.22456919657997787, 0.22129019518615678, 0.20871668471954763, 0.2145722892601043, 0.8907638175878674, 20.142314471304417, 90.28047278523445, 79.32413309812546, 91.62039488554001, 72.22284615039825, 57.162141501903534, 12.902261819690466, 0.2446221752325073, 3.252795268781483, 5.6136691477149725, 12.951055001467466, 6.3519619312137365, 0.7888304872903973, 51.93114459514618, 96.5332880616188, 76.02279424667358, 81.08215436339378, 59.155856519937515, 89.42888528108597, 89.73240539431572, 87.27668076753616, 90.65048933029175, 82.20618724822998, 87.19793379306793, 83.55810910463333, 81.90400466322899, 79.31763544678688, 83.3710603415966, 78.08812022209167, 82.2917814552784, 79.82233196496964, 81.85852110385895, 87.56146028637886, 79.05607268214226, 74.23895716667175, 69.743881970644, 77.53651902079582, 76.36609822511673, 76.6929642856121, 82.14440256357193, 59.915059581398964, 26.049251407384872, 40.02315357327461, 52.23498769104481, 68.04207488894463, 51.841701194643974, 34.30253393948078, 17.91337687522173, 19.854922592639923, 11.670342274010181, 0.9073216072283685, 0.23563726048450917, 1.226440833415836, 0.2989075763616711, 0.38857409614138305, 0.3131331520853564, 2.1033925702795386, 9.635823145508766, 5.717746037989855, 4.963670801371336, 30.22472955286503, 7.145269587635994, 34.199616461992264, 0.300317271030508, 6.362009542062879, 16.362814977765083, 1.045863360632211, 11.739107184112072, 17.53203123807907, 12.74424634873867, 20.267650745809078, 11.846789605915546, 4.817547742277384, 0.8890106866601855, 0.2859739609993994, 0.26998032233677804, 1.8530853954143822, 4.6911736484616995, 1.6653751116245985, 7.636802662163973, 21.923064216971397, 21.65274292230606, 56.18809036910534, 45.94133980572224, 46.44669368863106, 24.991004392504692, 25.071218088269234, 40.75945906341076, 60.35040222108364, 78.19728076457977, 73.47479537129402, 68.94231498241425, 78.02049905061722, 72.86777034401894, 75.79922184348106, 74.03755277395248, 76.35026067495346, 80.86605995893478, 75.0128236413002, 67.59311378002167, 74.97775912284851, 75.88409408926964, 72.59703487157822, 73.83719712495804, 78.2344351708889, 77.65112087130547, 79.09407064318657, 79.51324135065079, 77.37755835056305, 74.2858238518238, 78.77836838364601, 51.65410526096821, 70.18832132220268, 72.85387828946114, 65.44846326112747, 52.786961272358894, 10.270550586283207, 3.339265566319227, 16.280091516673565, 33.24395254254341, 37.48102158308029, 38.043034225702286, 52.52178870141506, 43.85298706591129, 12.729166857898235, 0.7764707005117089, 0.12050806210027076, 0.11828379356302321, 0.1130670816928614, 0.11934566588024609, 0.2765521587571129, 0.15230635151965544, 0.2029776864219457, 0.18396744009805843, 0.19092399103101343, 0.20552651840262115, 0.18197551573393866, 0.11034178183763288, 0.10180705387028866, 0.1450528227724135, 0.15661132754758, 0.21632939809933305, 0.17647418280830607, 0.20282275567296892, 0.24660363531438634, 0.1744956913171336, 0.17176470661070198, 0.17967462044907734, 0.1932121955906041], [0.06602861161809415, 0.015443575503013562, 0.08211665146518499, 0.06819673668360338, 0.04059582301124465, 0.006712912199873244, 0.06879418040625751, 0.037157823899178766, 0.06444840852054767, 0.02195554472564254, 0.03339908340421971, 0.022554903189302422, 0.04836357846215833, 0.1044778355571907, 0.03268114087404683, 0.0815311711630784, 0.12391893571475521, 0.05867828083864879, 0.08920799868064933, 0.09991175713366829, 0.05449632320960518, 0.011344769027346047, 0.04384303079859819, 0.07161002227803692, 0.05144132053828798, 0.1175577801768668, 0.0934485043399036, 1.2440249836072326, 33.91379199922085, 45.89144088327885, 38.35112549364567, 31.837459914386272, 25.78288570046425, 15.10209297761321, 3.016475737094879, 0.6931694329250604, 2.9664678080007434, 3.238335382193327, 0.469537420431152, 2.4397312849760056, 55.03989838063717, 59.45806950330734, 55.06906561553478, 45.15070863068104, 54.52062584459782, 88.32312181591988, 79.02080297470093, 83.68537187576294, 79.00133281946182, 80.3951208293438, 81.0611642897129, 83.35817903280258, 77.22407698631287, 80.77661275863647, 81.05842843651772, 80.96223279833794, 82.92901486158371, 79.15384143590927, 80.96243038773537, 82.69442304968834, 83.03710386157036, 78.38676899671555, 78.56757089495659, 75.76073750853539, 79.88030925393105, 77.7639976143837, 74.75803211331367, 54.42730665206909, 34.21206459403038, 38.43795083463192, 42.375193163752556, 50.53644463419914, 36.10066205263138, 20.704329013824463, 4.7964816726744175, 0.749201166909188, 11.17826297879219, 0.8934184501413256, 0.03143343477859162, 0.20686676289187744, 0.12128829679568298, 0.4662103427108377, 0.09782370980246924, 0.0629798170120921, 0.7869850331917405, 1.8874764000065625, 1.4185427315533161, 6.06220087967813, 4.9112549889832735, 19.650896340608597, 0.4296845948556438, 0.6548882089555264, 4.910235218703747, 4.398696692660451, 9.80226181447506, 4.729454219341278, 0.4601148166693747, 3.77868942450732, 0.7395189895760268, 1.6322087100706995, 0.24986981239635497, 1.1487688450142741, 0.6546671676915139, 1.6442038351669908, 1.3633844163268805, 2.4882570561021566, 7.124531250447035, 19.861714728176594, 17.570829056203365, 32.63337850570679, 36.509121134877205, 41.41203984618187, 29.777943827211857, 29.09754853695631, 47.908957824110985, 82.25543260574341, 67.09966465830803, 70.52154064178467, 68.51107612252235, 78.0976577103138, 71.29529312252998, 74.51853856444359, 78.5138949751854, 74.69405114650726, 68.54012176394463, 74.1123479604721, 73.34871053695679, 71.15151643753052, 71.5664541721344, 73.3081591129303, 77.03841134905815, 76.0777772963047, 74.83555555343628, 76.08938947319984, 73.95727068185806, 80.60746103525162, 72.83272862434387, 82.7574160695076, 51.84057265520096, 40.19812658429146, 50.28334401547909, 39.48145844042301, 29.5840098336339, 19.935710057616234, 17.98378709703684, 19.449138566851616, 11.93545214831829, 12.944733090698719, 30.44374030083418, 51.228661090135574, 16.615182235836983, 0.2507435576990247, 0.0634733600600157, 0.0024516507573935087, 0.062352375680347905, 0.08698605306562968, 0.08758631694945507, 0.054131605866132304, 0.05958689966064412, 0.0717436162813101, 0.039924053198774345, 0.04109555928152986, 0.0907247704162728, 0.08075813530012965, 0.03707986499648541, 0.1737246147240512, 0.08409878690144978, 0.06818014968303032, 0.04396804186399095, 0.022886014230607543, 0.0269332219613716, 0.01725170328427339, 0.07305133985937573, 0.05857634314452298, 0.01903052550915163, 0.04435119786649011, 0.060353553053573705, 0.04928797163302079, 0.1222693566523958, 0.1264703503693454, 0.04147480787651148, 0.009455466988583794, 0.03777787715080194, 0.05827444860187825, 0.02433527093671728, 0.08190608932636678, 0.09781634027604014, 0.07416039050440304, 0.08132241986459121, 0.08108789377729408, 0.0750532683741767, 0.05903467128518969, 0.06859950022771955, 0.0626674025261309, 0.022814636322436854, 0.1089267288625706, 0.020650112528528553, 0.08561678318073973, 0.0249062255534227, 0.052899662987329066, 0.12117831051000394, 0.13659817253937945, 0.032719632363296114, 2.941403640434146, 43.262415155768394, 64.23922374844551, 62.54010692238808, 54.6937445551157, 48.46480719745159, 28.693404123187065, 5.008373502641916, 0.48933875164948404, 1.0548655525781214, 1.6388049186207354, 0.37708143470808864, 4.8795713391155005, 73.42874944210052, 69.26011472940445, 66.34858936071396, 55.54687097668648, 64.43502724170685, 96.17702677845955, 84.73509594798088, 88.74050661921501, 81.39531835913658, 84.43773150444031, 83.1092543900013, 81.73847794532776, 77.07282990217209, 84.55516800284386, 81.81214839220047, 81.69639900326729, 85.23162290453911, 76.51311993598938, 85.23403957486153, 84.5130206644535, 84.13935631513596, 77.53242284059525, 80.69642186164856, 75.28667494654655, 83.18436115980148, 78.11087340116501, 81.76842033863068, 46.308871284127235, 25.06634294986725, 38.694319278001785, 47.8083810210228, 63.708346635103226, 36.62001058459282, 25.245448239147663, 11.997491419315338, 1.0838369792327285, 20.456120632588863, 2.960837222635746, 0.21840267669176683, 0.09642757417168468, 0.3809895250014961, 0.6049807963427156, 0.5300409800838679, 0.9486297250259668, 0.2693876135163009, 0.26171546895056963, 4.454796407371759, 16.628726609051228, 8.448529355227947, 24.15509294718504, 0.7821077574044466, 0.48602099530398846, 3.4234811598435044, 4.719618447124958, 19.744525216519833, 1.0931844776496291, 0.6717423826921731, 1.1067929724231362, 2.2151923086494207, 2.019008598290384, 2.0368966134265065, 1.7481033224612474, 0.6415524682961404, 2.178003704175353, 3.138614008203149, 4.341802820563316, 16.825265362858772, 23.99345152080059, 22.203679159283638, 41.72861605882645, 46.2218027561903, 45.76344855129719, 35.68668186664581, 21.293711587786674, 51.200698390603065, 81.80441200733185, 70.23391887545586, 71.86327144503593, 68.8239361345768, 78.96145015954971, 73.1779097020626, 75.89708939194679, 77.21744254231453, 77.88666263222694, 70.84557205438614, 75.25638297200203, 75.69666534662247, 72.6104785501957, 73.1041632592678, 74.96890559792519, 78.45837235450745, 77.93029949069023, 79.09175276756287, 80.58114364743233, 76.22073322534561, 80.24324297904968, 75.78129440546036, 86.63937896490097, 57.86681368947029, 49.55584645271301, 61.95430375635624, 53.97255465388298, 46.47923894226551, 31.69562492519617, 24.269740395247936, 30.50470232963562, 23.160152435302734, 27.337591275572777, 49.41639393568039, 59.09176155924797, 23.61513812094927, 1.4097730396315455, 0.2900093444623053, 0.027549968945095316, 0.09069400097359903, 0.07055997237330303, 0.10121027065906674, 0.08852908940752968, 0.024323723118868656, 0.034694669157033786, 0.03239718404074665, 0.048868287121877074, 0.08222864154959098, 0.03816553798969835, 0.09904965612804517, 0.029157650060369633, 0.007816412507963832, 0.019947743967350107, 0.033832275003078394, 0.04292494217224885, 0.09911862391163595, 0.051419668379821815, 0.09986271601519547, 0.08241318399086595, 0.03412243248021696, 0.030340711382450536, 0.1312782205059193, 0.23687968990998343, 0.3045196080347523, 0.23392666946165264, 0.12922423775307834, 0.07485335605451837, 0.20129152690060437, 0.11119173388578929, 0.18179506994783878, 0.2995468326844275, 0.23057397280354053, 0.14587678480893373, 0.4265553143341094, 0.13177873974200338, 0.1712720244540833, 0.18827278719982132, 0.24887816951377317, 0.1356434589251876, 0.15190029283985496, 0.20009969710372388, 0.159217408800032, 0.20549592707538977, 0.1186810429499019, 0.1175964460708201, 0.2921888540731743, 0.28580338577739894, 0.1630580675555393, 2.864056178368628, 54.37083788216114, 84.47924047708511, 83.8279478251934, 79.31730106472969, 66.99015453457832, 45.35520225763321, 5.494259130209684, 0.8343220024835318, 8.726018965244293, 8.249795269221067, 0.6747317535337061, 5.2908180467784405, 92.02688187360764, 82.7422396838665, 80.20225837826729, 68.32064554095268, 71.9123724102974, 96.80143967270851, 86.63929536938667, 90.6745420396328, 84.24929961562157, 83.3468708395958, 83.83089646697044, 82.52448856830597, 81.89528033137321, 83.71376395225525, 81.33347287774086, 82.02314347028732, 86.54401168227196, 75.36359041929245, 84.4115737080574, 83.77261519432068, 84.22243505716324, 75.36864414811134, 80.0261302292347, 78.18181559443474, 80.53682282567024, 79.19532001018524, 80.40636822581291, 66.54601916670799, 38.32541227340698, 48.9229030162096, 54.456044510006905, 70.49962341785431, 38.08630250394344, 31.355932652950287, 17.67459198832512, 10.392627585679293, 22.6410660892725, 5.0062370672822, 0.3117036569165066, 0.24884358543204144, 0.45851976319681853, 0.863268671091646, 0.7104196166619658, 1.7366563179530203, 1.4994261413812637, 5.86543271318078, 6.272154338657856, 22.005751579999924, 10.475593283772469, 28.831921890378, 0.6966135918628424, 1.1330243898555636, 18.370216861367226, 6.430596811696887, 31.997619420289993, 6.316140778362751, 2.5130528630688787, 6.8032812885940075, 4.070724891498685, 5.944790979847312, 4.561158400028944, 1.1209612246602774, 1.4274556282907724, 6.447118325158954, 5.828789854422212, 8.493746928870678, 18.954916186630726, 32.47866600751877, 24.40299354493618, 41.79757095873356, 50.900050923228264, 51.55554614961147, 42.710198387503624, 35.203856974840164, 65.11112496256828, 79.69193056225777, 70.9681686758995, 67.26158156991005, 69.63198557496071, 80.07336929440498, 71.36875078082085, 74.93297472596169, 79.03226315975189, 75.63592940568924, 71.24416306614876, 74.65558961033821, 74.72450271248817, 71.10309183597565, 71.73147171735764, 72.85150721669197, 76.65337041020393, 78.83743241429329, 78.16100031137466, 80.48270612955093, 74.20937955379486, 79.32097926735878, 76.36960163712502, 87.5774498283863, 59.55246403813362, 58.234238773584366, 70.74262797832489, 65.89848831295967, 57.94769994914532, 35.60211360454559, 24.867421723902225, 41.432786732912064, 39.52100291848183, 41.59746989607811, 65.16483888030052, 70.7503491640091, 30.987422727048397, 1.8978967471048236, 0.7547895982861519, 0.13504506525350735, 0.16962255671387538, 0.23625572182936594, 0.2779594191815704, 0.09882010985165834, 0.1605666332761757, 0.14099421008722857, 0.1626590741216205, 0.17247203271836042, 0.24802703002933413, 0.16641794820316136, 0.14218054799130186, 0.2546406345209107, 0.10033008351456374, 0.07196073900558986, 0.18689619231736287, 0.1338568126084283, 0.15769664430990815, 0.12479845492634922, 0.34176253771875054, 0.19753064902033657, 0.15429892897373065, 0.12635291292099282], [0.10712568488088436, 0.05871110603038687, 0.07145119525375776, 0.09030349770910107, 0.11858100144308992, 0.08016084742848761, 0.08916494669392705, 0.05284356033371296, 0.06541757175000384, 0.03420038025069516, 0.0855719723040238, 0.07787011956679635, 0.01893943059258163, 0.09933420296874829, 0.023791007661202457, 0.07026867941021919, 0.08143976825522259, 0.08026444382267073, 0.19695447525009513, 0.05532392176974099, 0.029933760270068888, 0.06206638536241371, 0.06706270534778014, 0.09985658587538637, 0.03856043847918045, 0.07368085178313777, 0.04298191313864663, 0.11676504029310308, 12.194223962724209, 38.61946329474449, 46.23654596507549, 41.228175312280655, 34.218208864331245, 33.64095903933048, 20.466077998280525, 7.5876484997570515, 2.9831140022724867, 0.6007323274388909, 0.2939622011035681, 20.494768358767033, 63.08027073740959, 55.28048247098923, 58.470141515135765, 44.49942357838154, 69.91411283612251, 89.05775919556618, 77.99240335822105, 85.71395382285118, 81.10679984092712, 81.79245784878731, 83.17686036229134, 84.16988387703896, 80.10184496641159, 82.19019770622253, 80.18385216593742, 85.6012062728405, 80.9513121843338, 80.09244427084923, 82.88336411118507, 87.45701149106026, 84.41307842731476, 80.26448383927345, 71.86672925949097, 80.76357185840607, 75.99028319120407, 76.48237198591232, 76.47633031010628, 70.60420140624046, 37.09675580263138, 30.31169928610325, 52.11744859814644, 48.10668021440506, 29.512854851782322, 21.496599800884724, 6.598001578822732, 1.6679957835003734, 15.476107858121395, 5.225441129878163, 0.5092556797899306, 0.05520233571587596, 0.35186370194423944, 0.20678141590906307, 0.20319417089922354, 0.2617136877961457, 0.19767615449381992, 0.04081032224348746, 0.1514068536926061, 1.4872310520149767, 7.759089125320315, 15.355166997760534, 0.5320880608633161, 0.37505593558307737, 1.9761649472638965, 5.444100871682167, 10.305559057742357, 0.5125371005851775, 2.5720881577581167, 2.3739917250350118, 0.8721532474737614, 0.20183485321467742, 0.8481079002376646, 4.870235240086913, 0.691497641382739, 2.7554682176560163, 4.334156205877662, 8.623153734952211, 15.019076932221651, 25.740155093371868, 20.260229744017124, 25.265912041068077, 45.46377383172512, 38.14090937376022, 28.08608651161194, 37.6858039945364, 52.68584109842777, 67.6173184812069, 71.5084920823574, 70.66428378224373, 69.84022960066795, 70.36599218845367, 75.80830335617065, 74.11253035068512, 73.8920433819294, 73.78387838602066, 73.61659616231918, 71.92967668175697, 75.42791336774826, 72.75050103664398, 74.68094184994698, 72.76581421494484, 77.5248384475708, 73.04856464266777, 74.36476841568947, 74.53095629811287, 74.2377108335495, 78.49759384989738, 71.38292402029037, 76.3279102742672, 59.59152594208717, 34.500332325696945, 58.70118051767349, 40.68170763552189, 34.28154766559601, 30.22813607007265, 28.96657906472683, 13.353012632578611, 10.338328499346972, 21.446729376912117, 24.398925863206387, 29.340727888047695, 1.5203636116348207, 0.18941087066195905, 0.1410147824208252, 0.10013598963269033, 0.057781376817729324, 0.05583510566793848, 0.03355747998284642, 0.022039451941964217, 0.07996043786988594, 0.031254317436832935, 0.008750471224630019, 0.016320280119543895, 0.05470356423757039, 0.034967812898685224, 0.05420109686383512, 0.054569762432947755, 0.08133462819387205, 0.07127322081942111, 0.019619924350990914, 0.04560129738820251, 0.02373658226133557, 0.02396249386947602, 0.0457219186500879, 0.040925128778326325, 0.07796610894729383, 0.025574713217793033, 0.11717210087226704, 0.10773686575703323, 0.0744667490653228, 0.08235557848820463, 0.11632608962827362, 0.17575254809344187, 0.0871241519053001, 0.06602425521123223, 0.18040173221379519, 0.024966408163891174, 0.19715918926522136, 0.056930025821202435, 0.14740492624696344, 0.059274429513607174, 0.026090205283253454, 0.12304191011935472, 0.05835777323227376, 0.07572014001198113, 0.056259131742990576, 0.013988805567350937, 0.1033944335358683, 0.04310141746827867, 0.048602486931486055, 0.11055569848394953, 0.019397671530896332, 0.07072746768244542, 0.3009508573450148, 0.020812705952266697, 18.082082122564316, 58.84824402630329, 65.35760253667831, 65.56984394788742, 54.865278750658035, 52.14137211441994, 30.59769283980131, 8.918160405009985, 3.0391913931816816, 0.3987638431135565, 1.0256881057284772, 31.79422963410616, 82.60594859719276, 66.10364690423012, 72.47005328536034, 54.287405759096146, 82.36745059490204, 95.91898262500763, 85.63443168997765, 88.73042196035385, 86.47687688469887, 85.67302241921425, 85.53540140390396, 86.01132586598396, 82.96540170907974, 81.7617554962635, 81.83511435985565, 86.03488460183144, 81.93681970238686, 81.12227261066437, 86.07931181788445, 89.69620853662491, 86.49787455797195, 77.043936252594, 74.88335698843002, 81.16199567914009, 79.2543688416481, 75.56302651762962, 80.955940335989, 71.69934824109077, 24.68049645423889, 31.042428575456142, 57.729527056217194, 58.4346704185009, 31.3953460380435, 24.292214289307594, 16.535042636096478, 0.9205567126628011, 19.669298753142357, 10.96692306920886, 0.5722149764187634, 0.32187624543439597, 0.2187872279318981, 0.17513781232992187, 1.0681160353124142, 3.6828901525586843, 0.8948844589758664, 0.7387432374525815, 6.854072213172913, 26.09540183097124, 6.239890744909644, 20.58887030929327, 1.0727276816032827, 0.50128911039792, 1.9584549288265407, 2.57210501935333, 22.445815466344357, 2.454202570952475, 16.690999567508698, 9.799961037933826, 2.4155940301716328, 0.5899575899820775, 3.923759227618575, 6.301050363108516, 5.978672336786985, 9.44039298221469, 9.389743600040674, 9.36562154442072, 17.323428131639957, 25.993286110460758, 20.07075861096382, 29.930587336421013, 55.8158927410841, 41.32836073637009, 34.9001544713974, 28.579018861055374, 59.83469009399414, 66.77816390991211, 74.64997351169586, 70.68429350852966, 72.56497219204903, 74.91586044430733, 80.33120065927505, 73.06900754570961, 75.87997511029243, 74.94340136647224, 76.25489339232445, 73.05568546056747, 77.13532134890556, 75.05342826247215, 74.96861681342125, 75.18928617238998, 79.86933544278145, 76.18163332343102, 78.45391899347305, 77.39454343914986, 78.84883180260658, 79.6253353357315, 75.32036393880844, 85.41951522231102, 68.04107934236526, 43.68937164545059, 70.63233509659767, 56.19195096194744, 52.0527570694685, 44.43045727908611, 38.996851444244385, 29.502325616776943, 22.678233794867992, 41.646027490496635, 42.64856569468975, 38.818557411432266, 2.2930615302175283, 0.31838963564950973, 0.23207076592370868, 0.07482273504137993, 0.08338881132658571, 0.1637930460856296, 0.013714133929170202, 0.0880959423375316, 0.04003397640190087, 0.006396003082045354, 0.12030516634695232, 0.04185789337498136, 0.014560889176209457, 0.04449832493264694, 0.0313863195333397, 0.08195344576961361, 0.04145533763221465, 0.04289799850084819, 0.027102565218228847, 0.018858313851524144, 0.12036363274091855, 0.0455502636032179, 0.10012892438680865, 0.031196144191198982, 0.04478156930417754, 0.05999203807732556, 0.20063252944964916, 0.2065133670112118, 0.2499104820890352, 0.27918624866288155, 0.2418471366399899, 0.2793201321037486, 0.2194312636856921, 0.20262666541384533, 0.23600983346113935, 0.1672033779323101, 0.17699384945444763, 0.2925764332758263, 0.30031180882360786, 0.19167376798577607, 0.20880370895611122, 0.21036489080870524, 0.09686902587418444, 0.140722420765087, 0.23084619257133454, 0.14672035438707098, 0.20289928594138473, 0.20242747297743335, 0.18856831040466204, 0.18218570679891855, 0.14622372400481254, 0.2465802725055255, 0.494128157151863, 0.1964917907025665, 19.02271594852209, 68.46933916211128, 83.56690183281898, 90.0777916610241, 80.68379893898964, 72.70534425973892, 40.49599640071392, 8.905539382249117, 4.977272171527147, 1.8820685776881874, 0.8064523385837674, 38.28319653868675, 100.22123336791992, 78.82968842983246, 87.93405309319496, 65.2318748831749, 86.5576833486557, 96.97366163134575, 88.81772607564926, 91.21819406747818, 87.66990646719933, 87.9726742208004, 89.59069579839706, 86.18059158325195, 83.31032440066338, 84.09844011068344, 81.14836201071739, 85.35738095641136, 80.80163061618805, 79.36497330665588, 84.27835285663605, 86.06731966137886, 83.69488656520844, 78.28960061073303, 71.11837461590767, 81.74878299236298, 76.56977489590645, 77.76981130242348, 77.08422929048538, 85.59024766087532, 43.15551929175854, 36.70687012374401, 64.52371448278427, 61.330008655786514, 33.550071716308594, 30.240152925252914, 23.689961805939674, 5.589496744796634, 25.33883772790432, 14.327684082090855, 0.6992378260474652, 1.6493613459169865, 0.42725708917714655, 0.3209129674360156, 1.6830175649374723, 10.378498993813992, 0.8572028309572488, 0.2852240949869156, 6.451840046793222, 23.515087589621544, 14.233540333807468, 35.224360674619675, 0.5911929986905307, 0.4257028241408989, 6.639926629140973, 15.558999460190535, 39.701998606324196, 1.7258438793942332, 16.74212582409382, 7.672870326787233, 6.291108671575785, 0.6909612170420587, 10.697792060673237, 19.176883175969124, 20.491605028510094, 21.613954603672028, 18.440961465239525, 17.43502054363489, 29.753906317055225, 31.9104140996933, 29.92184780538082, 29.979131631553173, 61.372345983982086, 45.93741461634636, 42.30525031685829, 47.95754961669445, 62.86771774291992, 64.17070582509041, 78.14491957426071, 71.06997281312943, 73.11682417988777, 72.85864323377609, 81.91560924053192, 73.1890507042408, 73.19015264511108, 73.18578287959099, 75.72682812809944, 71.699029058218, 77.36340790987015, 75.14957830309868, 76.03673189878464, 76.60770446062088, 79.31766584515572, 76.27082973718643, 82.4996455013752, 80.1082894206047, 76.8588025867939, 80.44256508350372, 74.16666224598885, 87.71671235561371, 69.2011646926403, 54.696586802601814, 78.8317023217678, 69.37699645757675, 57.405282855033875, 54.83711466193199, 47.88740158081055, 45.99503472447395, 34.180161505937576, 60.56450933218002, 61.543173417449, 46.02046675980091, 5.320946630090475, 0.3414083254756406, 0.55838193744421, 0.13102229830110446, 0.14069234894122928, 0.3660220984602347, 0.1100857112032827, 0.12448917230358347, 0.09802500251680613, 0.1527760864701122, 0.1820213656174019, 0.2725524577545002, 0.07355223016929813, 0.18128564493963495, 0.15298031066777185, 0.11839522703667171, 0.125885627057869, 0.15424050710862502, 0.04573356665787287, 0.2633611368946731, 0.22621517622610554, 0.11744671777705662, 0.2305058584897779, 0.15048955916427076, 0.2583127812249586, 0.11834363293019123], [0.08176316652679816, 0.06556646883836947, 0.0856102374382317, 0.016465616754430812, 0.10578759261989035, 0.028665812096733134, 0.012760617955791531, 0.1003004792437423, 0.05437081490526907, 0.09140533467871137, 0.08218161165132187, 0.020000401200377382, 0.0790977654105518, 0.11820092535344884, 0.04929229093249887, 0.07796757097821683, 0.03529690715367906, 0.12044862349284813, 0.0607430544187082, 0.07123681105440482, 0.07167955409386195, 0.047620209952583537, 0.1148826272401493, 0.0382882483972935, 0.03609224826504942, 0.06872969519463368, 0.18211536604212597, 0.04806873432244174, 1.5664019412361085, 22.18701135367155, 47.511506751179695, 48.25241379439831, 52.30330802500248, 48.2059308886528, 41.25664718449116, 27.717513889074326, 16.150263883173466, 4.6337031573057175, 10.688120629638433, 38.416276797652245, 57.78107509016991, 60.64783126115799, 56.599851474165916, 47.58918598294258, 83.4431728720665, 84.24372151494026, 82.72006407380104, 83.4051901102066, 82.84746363759041, 83.79070982336998, 85.80437377095222, 80.25858655571938, 79.0544767677784, 83.47038701176643, 83.06516155600548, 81.46266594529152, 79.96796295046806, 80.28102055191994, 84.79615867137909, 85.3629894554615, 82.7340093255043, 82.05533534288406, 79.14521589875221, 81.21244177222252, 76.02682963013649, 78.34253937005997, 78.05382326245308, 70.58552160859108, 44.52073283493519, 35.331055149436, 55.66453546285629, 43.30788731575012, 25.175285004079342, 22.82833904027939, 8.725186809897423, 1.0211475868709385, 3.8830591365695, 12.700985670089722, 1.9450073316693306, 0.31951924378518015, 0.12243316348758526, 0.23618406004970893, 3.39525009971112, 1.3120895437896252, 0.24294794944580644, 2.1622723108157516, 5.3594376146793365, 18.571645952761173, 2.6778768561780453, 15.139047894626856, 0.914383587660268, 1.5352767426520586, 0.6265343679115176, 4.533648826181889, 14.320200383663177, 2.2291909949854016, 11.770667340606451, 3.476508501917124, 1.2265144544653594, 0.513800117187202, 0.36826210794970393, 8.511559423059225, 2.7628842322155833, 2.057201536372304, 1.7806522571481764, 3.8868149975314736, 22.804812602698803, 27.432405687868595, 23.82556702941656, 17.05888442695141, 38.934063613414764, 44.71529379487038, 31.233341731131077, 31.56252756714821, 60.53277723491192, 72.12123200297356, 68.90384584665298, 70.14723032712936, 66.63411363959312, 71.28276899456978, 73.68623122572899, 71.03131368756294, 73.60825181007385, 73.62712919712067, 73.58794569969177, 75.5258797109127, 73.69468197226524, 69.94685187935829, 71.14694148302078, 75.85646957159042, 75.14975309371948, 76.43264025449753, 71.82717338204384, 76.84712201356888, 75.77693983912468, 76.0997325181961, 71.3695715367794, 74.67447459697723, 62.221718207001686, 34.607034400105476, 51.56677454710007, 48.88378791511059, 35.9512996673584, 33.093674406409264, 20.83268992602825, 18.86926308274269, 21.301256082952023, 20.921289771795273, 23.75824224203825, 10.619710050523281, 1.0197202884592116, 0.12431246694177389, 0.19101453304756433, 0.0747990160016343, 0.057955302836489864, 0.0626378353626933, 0.028554840610013343, 0.12531887856312096, 0.02000400247197831, 0.09241234743967652, 0.07773982812068425, 0.048061635679914616, 0.08690095841302536, 0.015679138741688803, 0.09570530863129534, 0.07609700260218233, 0.04479319504753221, 0.0062541318129660795, 0.08658019476570189, 0.10118747930391692, 0.041149891912937164, 0.07004829865763895, 0.004243283146934118, 0.05466999689815566, 0.03734625148354098, 0.0921716244192794, 0.0862350441457238, 0.07776917263981886, 0.054163336390047334, 0.0265747516459669, 0.02876173282857053, 0.041551579342922196, 0.04304842070268933, 0.027658252001856454, 0.04444237441930454, 0.014285857596405549, 0.14088370429817587, 0.1291747810319066, 0.16064340103184804, 0.0599608233460458, 0.05178103492653463, 0.066026741405949, 0.05071439802122768, 0.15074785624165088, 0.04387695065815933, 0.10216793059953488, 0.07918128671008162, 0.10150600908673368, 0.028352195331535768, 0.024389019126829226, 0.019290535092295613, 0.0634060546872206, 0.07155077662901022, 0.060908646119059995, 3.310353155247867, 30.669092908501625, 63.48903760313988, 71.10512852668762, 70.2715976536274, 64.5793966948986, 54.97000873088837, 32.65419378876686, 16.653841361403465, 6.199005413800478, 16.337916813790798, 57.40305237472057, 74.76389899849892, 76.85398444533348, 70.46897426247597, 59.403876811265945, 90.70308610796928, 89.65526953339577, 88.5929149389267, 90.23258775472641, 85.93111976981163, 86.29163682460785, 90.20577639341354, 84.95419219136238, 79.2314712703228, 82.37705647945404, 84.32661786675453, 84.51864436268806, 81.72302797436714, 79.26155805587769, 87.20288872718811, 89.68785658478737, 84.61481720209122, 83.28710004687309, 81.08979195356369, 82.84001603722572, 79.97372344136238, 80.3892083466053, 78.03736254572868, 78.87609153985977, 34.69401553273201, 32.07875646650791, 62.41984337568283, 54.09222923219204, 23.984958976507187, 25.44234037399292, 19.19573776423931, 1.6379053168930113, 12.979101296514273, 20.04023864865303, 2.382677346467972, 0.5512311367783695, 0.1349781235330738, 0.11247780901612714, 1.2561799376271665, 5.185212688520551, 0.9739579784218222, 1.6988780326209962, 5.912549709901214, 24.507119357585907, 5.731210615485907, 17.63831153512001, 3.5266308998689055, 1.4932666718959808, 1.6839277348481119, 7.397352810949087, 14.335482213646173, 5.6740388832986355, 14.916751272976398, 3.751964746043086, 1.5675592166371644, 0.6203474092762917, 1.5219867182895541, 15.968274548649788, 2.51407025847584, 0.2465776601457037, 3.346454780548811, 4.4990920554846525, 18.842869699001312, 24.689015597105026, 20.66414427012205, 19.696121513843536, 46.13556258380413, 49.39192704856396, 32.54496105015278, 30.38810558617115, 63.93785431981087, 71.91852048039436, 72.30427578091621, 71.8748228251934, 70.38605511188507, 71.89400419592857, 76.35083824396133, 70.8787290751934, 74.7833539545536, 74.69778254628181, 74.79007959365845, 75.4446704685688, 75.45980885624886, 72.98003152012825, 73.41414302587509, 74.5870640873909, 77.3740017414093, 78.24072763323784, 75.84114879369736, 76.15716263651848, 80.91058596968651, 78.51743638515472, 76.86255678534508, 77.02692836523056, 68.51855412125587, 41.45593509078026, 65.3706282377243, 54.68366749584675, 51.08134299516678, 39.553612768650055, 32.771455496549606, 25.58724369853735, 28.704594522714615, 41.35402835905552, 34.27781626582146, 17.425127774477005, 2.2606856049969792, 0.21823674731422216, 0.05839866556925699, 0.18321079085581005, 0.05293198722938541, 0.06381772400345653, 0.059624107234412804, 0.058711888996185735, 0.06040464992111083, 0.1295483930152841, 0.06268762605031952, 0.016585345583735034, 0.013445111890177941, 0.050359068845864385, 0.010055954444396775, 0.029313794220797718, 0.06734641356160864, 0.0833621014317032, 0.059581259338301606, 0.13313185307197273, 0.01760163333528908, 0.02683491893549217, 0.01716664573905291, 0.06582734116818756, 0.04040088679175824, 0.09850229995208792, 0.2019952461705543, 0.18504223320633173, 0.35747104324400425, 0.11862066181492992, 0.20910942927002907, 0.2212164702359587, 0.10752907925052568, 0.19808200537227094, 0.12079571853973903, 0.19850259530358016, 0.16987699462333694, 0.2859397331485525, 0.2031299751251936, 0.37209464760962874, 0.15987575316103175, 0.14921595953637734, 0.23795917339157313, 0.3763841721229255, 0.13637512747664005, 0.22930400969926268, 0.24076014262391254, 0.22524306667037308, 0.24513560783816501, 0.2021605966729112, 0.12064802373060957, 0.1635596257983707, 0.24425089359283447, 0.08775181588134728, 2.4612583173438907, 35.5931156873703, 77.05056309700012, 93.26384469866753, 97.53807574510574, 87.42925778031349, 69.04461309313774, 41.334577202796936, 17.294082306325436, 5.433019241318107, 18.29855650663376, 72.70368754863739, 91.83379143476486, 90.71571663022041, 83.65608304738998, 71.09339475631714, 95.46510457992554, 95.26109352707863, 91.98520570993423, 92.31024026870728, 86.5572501718998, 88.2136344909668, 90.94299003481865, 83.07605177164078, 78.98540407419205, 85.09983837604523, 87.46520385146141, 84.08438846468925, 81.7031778395176, 79.77730438113213, 84.6083727478981, 86.99112609028816, 81.14837720990181, 80.83823785185814, 77.95937553048134, 81.67215630412102, 75.35225182771683, 79.83337417244911, 73.1526106595993, 81.94876626133919, 53.075798973441124, 42.56942734122276, 68.19053292274475, 61.71000726521015, 25.84538284689188, 32.07927703857422, 25.118603445589542, 4.332778779789805, 21.067903004586697, 28.44340603798628, 2.3863944970071316, 0.5547824618406594, 0.15595185512211174, 0.410332708270289, 11.446861065924168, 10.838234424591064, 0.7799032225739211, 2.417518151924014, 11.740915887057781, 39.988864213228226, 10.252800788730383, 37.72800832986832, 4.022488379850984, 1.4524584054015577, 3.8968139234930277, 21.912211999297142, 19.48551021516323, 2.3367045633494854, 30.80590646713972, 7.600399190559983, 8.83620260283351, 1.8586979317478836, 0.9170787711627781, 21.46465301513672, 18.790025934576988, 12.200401481240988, 4.178613927215338, 12.159167993813753, 29.282817095518112, 35.585436299443245, 31.11361775547266, 22.67264809459448, 55.189576148986816, 56.062229722738266, 44.32575389742851, 46.304592713713646, 65.6873032450676, 71.72444209456444, 73.44809800386429, 74.06081512570381, 69.15814340114594, 70.8677476644516, 75.81896558403969, 71.2155582010746, 75.06654515862465, 74.44108352065086, 72.73474708199501, 72.97614812850952, 74.98725101351738, 72.0217153429985, 75.40695369243622, 75.59125900268555, 76.92720651626587, 81.30498200654984, 77.62969002127647, 79.79153081774712, 81.35441735386848, 80.31886652112007, 78.53257477283478, 81.13643065094948, 70.43926745653152, 46.33236162364483, 72.18605652451515, 68.28402310609818, 61.57683581113815, 52.047710940241814, 45.46502776443958, 40.20851142704487, 41.47857807576656, 61.42482876777649, 43.96992199122906, 17.40801729261875, 2.0779797714203596, 0.36601423169486225, 0.14273904380388558, 0.26381093775853515, 0.20715030783321708, 0.141228535794653, 0.2048108505550772, 0.19274354417575523, 0.17262150126043707, 0.27526619494892657, 0.16148955328390002, 0.10828079321072437, 0.1954548025969416, 0.13430216058623046, 0.16690677119186148, 0.13684438745258376, 0.1378543020109646, 0.17542552814120427, 0.1577372249448672, 0.24133780068950728, 0.0652889501361642, 0.13225445640273392, 0.10494708069018088, 0.21047202724730596, 0.20146999857388437, 0.210269910749048], [0.07121863585780375, 0.037421364249894395, 0.035488433204591274, 0.05046927777584642, 0.044290876103332266, 0.0752515257045161, 0.06318517669569701, 0.04506945209868718, 0.04596468999807257, 0.03609461200539954, 0.039399013403453864, 0.0013698360044145375, 0.01772403389622923, 0.14112580771325156, 0.0562340063333977, 0.06329046518658288, 0.06784428333048709, 0.17024095868691802, 0.21209522295976058, 0.0687249306065496, 0.05633185479382519, 0.014285991182987345, 0.10536072411923669, 0.06433157963328995, 0.05595749695203267, 0.07368980208411813, 0.020318921706348192, 0.055052362513379194, 0.02255595703900326, 7.749592484906316, 38.48430834710598, 54.25449572503567, 64.33907479047775, 72.16696634888649, 61.90863020718098, 49.792425557971, 32.24514953792095, 18.394970633089542, 31.04188520461321, 49.17082451283932, 62.70737014710903, 64.97566223144531, 50.507702976465225, 53.923028111457825, 86.59555211663246, 83.73778626322746, 88.04544791579247, 85.04709720611572, 86.68702080845833, 83.56921210885048, 86.34414240717888, 86.97301626205444, 86.38805285096169, 83.22757244110107, 83.52773353457451, 84.06825453042984, 79.5549251139164, 83.69538053870201, 89.41240176558495, 85.85016891360283, 83.64703953266144, 82.48579904437065, 78.15367430448532, 84.19306263327599, 79.37756583094597, 77.62766093015671, 78.64280685782433, 81.94845467805862, 39.539713114500046, 34.453416243195534, 61.888107508420944, 34.33702848851681, 23.684619292616844, 26.30296379327774, 7.118140943348408, 2.282619928009808, 2.1852698642760515, 6.69689079746604, 3.128968463279307, 1.223445050418377, 0.5505421862471849, 3.4576959488913417, 2.0282615767791867, 0.10966741450829431, 0.7619319087825716, 1.988262073136866, 5.552461557090282, 18.678074441850185, 3.79758486058563, 5.596190085634589, 0.8722637384198606, 1.445142135489732, 0.6088983861263841, 1.3465837365947664, 5.872599128633738, 12.947435695677996, 2.4572642566636205, 1.0185088659636676, 0.49902104772627354, 0.2731083263643086, 0.22397311840904877, 2.4336943589150906, 1.529733908828348, 2.428286299109459, 1.6122853104025126, 1.5056641004048288, 18.531696796417236, 22.17585325241089, 27.44480062276125, 19.35886301100254, 21.924373246729374, 52.659379318356514, 32.42248982191086, 31.237637400627136, 63.097339421510696, 66.40722781419754, 69.16467905044556, 72.22789227962494, 71.99927374720573, 67.06746518611908, 72.81640470027924, 75.67822113633156, 71.32653504610062, 71.78121104836464, 78.31333413720131, 75.12066185474396, 78.66853907704353, 75.90226471424103, 75.31251356005669, 75.97069144248962, 75.85194021463394, 76.96395054459572, 78.86250346899033, 74.54831376671791, 76.97879254817963, 76.3027024269104, 72.23262682557106, 76.51156201958656, 62.44236096739769, 32.825006023049355, 52.78543375432491, 40.7496327906847, 43.6759165674448, 26.894647143781185, 19.613945223391056, 19.90508560091257, 14.771230481564999, 7.587415287271142, 8.638178128749132, 3.360852445475757, 0.278715044260025, 0.08101719678961672, 0.12699167942628264, 0.09082073753233999, 0.08145120475091971, 0.09059657924808562, 0.0832516847003717, 0.046669225630466826, 0.07652371525182389, 0.11050115805119276, 0.06406309286830947, 0.015367541545856511, 0.058862990263151005, 0.08742225778405555, 0.03519735917507205, 0.06338085135212168, 0.06669759095530026, 0.06767783444956876, 0.09071701497305185, 0.07081262170686387, 0.061839432892156765, 0.02328808757738443, 0.032767259690444916, 0.04073345800861716, 0.008937367201724555, 0.039609905797988176, 0.02338155551115051, 0.054688431846443564, 0.02265479812194826, 0.053497088156291284, 0.07163354093790986, 0.06641332613071427, 0.15396387898363173, 0.1157899695681408, 0.015710318220953923, 0.06556155582075007, 0.07240538936457597, 0.04319302075600717, 0.041621523050707765, 0.13778434717096388, 0.13315589865669608, 0.08346778326085769, 0.03713602331117727, 0.05800870407256298, 0.17978824325837195, 0.05183841036341619, 0.08798781142104417, 0.035353744533495046, 0.1474696266814135, 0.058939015871146694, 0.029119355240254663, 0.07955947032314725, 0.08678015903569758, 0.21151906403247267, 0.14064501476241276, 13.495057560503483, 50.9848889708519, 73.20583060383797, 88.11181515455246, 86.87750458717346, 78.89466494321823, 63.189898654818535, 39.1571344435215, 26.748077608644962, 43.938843458890915, 64.79576468467712, 76.31430700421333, 80.92358887195587, 67.19264566898346, 63.54931376874447, 95.07125571370125, 90.14732033014297, 93.53915512561798, 89.93852153420448, 93.91772881150246, 86.95543840527534, 90.90626880526543, 90.6932370364666, 87.87150844931602, 83.37169870734215, 82.42244124412537, 86.73356831073761, 81.69689297676086, 84.81831908226013, 92.99604266881943, 91.81944340467453, 84.18773531913757, 85.1159343123436, 80.25366201996803, 89.3801186978817, 81.4059729874134, 80.17308354377747, 78.7358258664608, 88.1861163675785, 37.337708473205566, 31.152554266154766, 68.86634185910225, 41.38136029243469, 22.273487113416195, 23.733007796108723, 18.824032209813595, 1.7198919737711549, 10.35943066701293, 12.680824901908636, 6.070587979629636, 2.0985570922493935, 0.3621399833355099, 1.8662461079657078, 3.7868160009384155, 1.1758111626841128, 0.640225448878482, 0.7075698883272707, 2.627967484295368, 22.065282985568047, 3.8224381394684315, 14.813876543194056, 5.059683099389076, 1.4638630184344947, 0.4012262891046703, 14.281641002744436, 3.103273054584861, 19.240605756640434, 4.343924056738615, 1.1486014164984226, 0.9284303057938814, 0.299808454583399, 0.16934380604652688, 5.4268402978777885, 3.6820506351068616, 1.8974039610475302, 2.2351804235950112, 7.632706956937909, 20.32693136483431, 23.482941314578056, 25.022272914648056, 20.34161187708378, 28.125266209244728, 59.23856668174267, 32.27503873407841, 32.743112817406654, 65.16899585723877, 68.3908961713314, 72.88744568824768, 70.50442636013031, 74.70364943146706, 67.70263910293579, 76.02515012025833, 74.65198740363121, 74.47941586375237, 72.5554347038269, 79.34633150696754, 77.6716397702694, 78.03683057427406, 75.59365287423134, 77.44175210595131, 78.39377582073212, 78.86587768793106, 78.25363174080849, 79.71415176987648, 76.9725912809372, 81.26385301351547, 78.10122191905975, 73.68099510669708, 82.15783104300499, 66.851986348629, 43.84993202984333, 66.20813369750977, 53.65802273154259, 52.79054068028927, 37.742550149559975, 28.098219260573387, 21.52155116200447, 26.66159424930811, 25.32534845173359, 16.12348672002554, 4.274572553113103, 0.36848127900157124, 0.15496490261284634, 0.1609966336400248, 0.09740051493281499, 0.029527927945309784, 0.09392215783009306, 0.07987299803062342, 0.09353207016829401, 0.07884452235884964, 0.05983164883218706, 0.024296477022289764, 0.011976339483226184, 0.07851263391785324, 0.0592852908448549, 0.030106161175353918, 0.05747435032390058, 0.009717059201648226, 0.010088117269333452, 0.10454148956341669, 0.11715393309714273, 0.05394669235101901, 0.020729206917167176, 0.048975679601426236, 0.032080309247248806, 0.08463397927698679, 0.028702171766781248, 0.16732139425585046, 0.1436950042261742, 0.1676517687155865, 0.15676272567361593, 0.2166158374166116, 0.24192049051634967, 0.30724676325917244, 0.21344128588680178, 0.11663143144687638, 0.1453292282531038, 0.18621874507516623, 0.21969002089463174, 0.10590270714601502, 0.40786230645608157, 0.3730823867954314, 0.1339607874979265, 0.1958659227238968, 0.21770232677226886, 0.37695835693739355, 0.11572253803024068, 0.2549744228599593, 0.14045039395568892, 0.28744068229570985, 0.1982027676422149, 0.23678046476561576, 0.18171462113969028, 0.2803874295204878, 0.25888224598020315, 0.21852830745046958, 11.851181220263243, 51.91218741238117, 88.59688952565193, 110.25514215230942, 104.03690502047539, 95.07814094424248, 71.95453494787216, 50.96451826393604, 34.72562223672867, 57.66618825495243, 81.42529875040054, 89.5788936316967, 91.4402237534523, 78.98137629032135, 75.64221426844597, 99.19977977871895, 94.2403618991375, 96.42418071627617, 92.96491473913193, 93.60025584697723, 91.15039810538292, 91.75962701439857, 92.84677907824516, 87.4404139816761, 83.7623405456543, 83.30023974180222, 87.91962906718254, 79.94684368371964, 83.58407691121101, 90.14002472162247, 88.4567454457283, 81.78082287311554, 81.8563324213028, 78.71339946985245, 87.51023903489113, 80.891283005476, 78.16252022981644, 76.6924475133419, 88.7212036550045, 51.852842196822166, 44.33116100728512, 70.91144531965256, 51.41714237630367, 24.691981337964535, 30.152976103127003, 23.803611807525158, 2.9662117967382073, 11.407732665538788, 21.678017266094685, 12.04201553016901, 4.912228211760521, 0.5330188921652734, 6.6646067798137665, 5.783032234758139, 0.6658512144349515, 2.9180223075672984, 3.2025213539600372, 8.688876908272505, 41.20264448225498, 6.903821993619204, 28.63500125706196, 10.197828188538551, 1.4216371905058622, 3.244507913477719, 28.299141079187393, 6.336211776360869, 20.07710237056017, 12.805676702409983, 4.089154377579689, 3.9688167348504066, 0.5500128271523863, 1.0484893759712577, 3.7664255825802684, 8.973364792764187, 7.91023931466043, 1.9188408670015633, 10.76365202665329, 32.51524664461613, 28.74519534409046, 34.46665473282337, 28.01761608570814, 35.71972109377384, 64.82801735401154, 45.43918155133724, 45.7915860414505, 64.61244732141495, 66.11472710967064, 72.26004615426064, 73.48191618919373, 75.60889765620232, 67.89615511894226, 76.42115727066994, 75.40647491812706, 73.19123938679695, 71.04332864284515, 79.4227834045887, 76.71325519680977, 78.27934876084328, 73.85983631014824, 76.58477649092674, 78.71667489409447, 78.16078752279282, 78.87288451194763, 83.87539207935333, 78.64069417119026, 83.44339326024055, 78.56206119060516, 77.1489854156971, 83.33040252327919, 67.9508113861084, 52.36519530415535, 76.34423419833183, 65.79819649457932, 68.43508020043373, 52.240079417824745, 43.438919484615326, 37.67312787473202, 41.5126546472311, 47.34093390405178, 19.356258250772953, 3.433720897883177, 0.44587831653188914, 0.33967938856221735, 0.23710368492174894, 0.22534959454787895, 0.1560125924879685, 0.21062479092506692, 0.24160737841157243, 0.20578849653247744, 0.14805923332460225, 0.29052314814180136, 0.1059011412144173, 0.17709482606733218, 0.2030153726809658, 0.18191075592767447, 0.14198637247318402, 0.19969743822002783, 0.20059129572473466, 0.16331961523974314, 0.1685529586393386, 0.3329310397384688, 0.12707055488135666, 0.16781196871306747, 0.07543168205302209, 0.15593111951602623, 0.22783132153563201, 0.09880715937470086], [0.08636516489787027, 0.16103004512842745, 0.049372992070857435, 0.01422659246600233, 0.08392594070755877, 0.16157104109879583, 0.07013554553850554, 0.04936885459756013, 0.0014184517795001739, 0.05637247995764483, 0.0630204941262491, 0.14900882611982524, 0.23619554849574342, 0.039464459696318954, 0.11890478563145734, 0.1702308506355621, 0.1293563103536144, 0.07315532959182747, 0.08290610363474116, 0.12067297473549843, 0.033899754780577496, 0.06427255662856624, 0.13550561241572723, 0.12355529819615185, 0.07432370010064915, 0.062007507076486945, 0.014390291689778678, 0.07867915701353922, 0.11105880039394833, 1.1322180018760264, 20.22960338741541, 47.091621682047844, 64.44231525063515, 91.28817111253738, 71.5016296505928, 67.56018474698067, 57.51976691186428, 52.13598780333996, 49.88260991871357, 69.30156290531158, 63.14975380897522, 77.71302714943886, 49.208089113235474, 59.88424323499203, 88.01216170191765, 85.61354041099548, 92.66965538263321, 92.3058021068573, 88.2466547191143, 90.09698063135147, 90.57720646262169, 88.53122904896736, 83.9108593761921, 86.3714325428009, 85.38964122533798, 84.28966104984283, 78.75126823782921, 85.08782342076302, 87.30242818593979, 83.32365408539772, 82.29533806443214, 84.79415997862816, 86.76917240023613, 82.70326897501945, 81.96950554847717, 80.9436745941639, 83.11934664845467, 81.7423689365387, 41.388925686478615, 35.3357744961977, 58.47659356892109, 23.708280622959137, 25.965063124895096, 24.406031481921673, 10.062286611646414, 6.829443359747529, 3.7761865463107824, 0.2991745714098215, 1.0216269548982382, 0.9004156559240073, 2.373374020680785, 0.414642152027227, 0.6140509690158069, 0.16762200859375298, 0.2668648457620293, 0.5715158733073622, 1.1537483590655029, 17.832104936242104, 2.099142735823989, 4.731716522946954, 3.1087077129632235, 2.374504222534597, 1.537336113397032, 1.9003115175291896, 1.786778715904802, 9.438943360000849, 0.2880797308171168, 0.7336545980069786, 0.3157013392774388, 0.1322822572547011, 0.12417507314239629, 0.15340385434683412, 0.22973776533035561, 0.6888798787258565, 3.386219646781683, 1.1784768383949995, 14.668597988784313, 21.764669716358185, 25.317720361053944, 25.661052837967873, 12.240631822496653, 45.82953080534935, 48.60022433102131, 24.881528466939926, 68.50784629583359, 70.73724746704102, 72.15510338544846, 69.40952271223068, 71.56572461128235, 74.80106100440025, 69.56377923488617, 72.88929238915443, 75.34589856863022, 74.9129194021225, 76.38043105602264, 75.41609600186348, 76.76734149456024, 78.24768126010895, 76.17904946208, 76.93740516901016, 79.9360978603363, 75.9475126862526, 81.37501984834671, 77.93935060501099, 75.07358998060226, 79.79661494493484, 73.62546488642693, 79.7319196164608, 57.96439625322819, 31.836407370865345, 49.710167571902275, 41.934796795248985, 36.40775017440319, 18.36254697293043, 13.829214479774237, 11.686977781355381, 2.4174134200438857, 8.641903828829527, 3.6619026912376285, 0.5499806476291269, 0.4515449405880645, 0.28937762835994363, 0.06844488118076697, 0.0982812957954593, 0.05120367743074894, 0.09170652789180167, 0.15185712953098118, 0.14548292703693733, 0.013779935525235487, 0.06580400804523379, 0.03227543471439276, 0.18462973268469796, 0.03552298388967756, 0.059214044667896815, 0.046705498098162934, 0.04217834160954226, 0.12809411011403427, 0.047817279846640304, 0.07422381444484927, 0.07509361894335598, 0.08754132795729674, 0.10421137485536747, 0.07649147635675035, 0.02235300933534745, 0.027293768434901722, 0.04043811291921884, 0.030662562276120298, 0.10542103846091777, 0.030216394225135446, 0.04875995211477857, 0.12794728361768648, 0.049256204001721926, 0.038686358675477095, 0.04287681760615669, 0.03922953284927644, 0.044581749752978794, 0.039105200849007815, 0.1469665247714147, 0.18790503818308935, 0.06638686856604181, 0.10653221906977706, 0.1068902607948985, 0.16276894166367128, 0.19127771345665678, 0.047884288360364735, 0.05672923776728567, 0.031685438443673775, 0.0586468954134034, 0.01655326810578117, 0.042050269184983335, 0.02654417145095067, 0.05704507355403621, 0.0657586108718533, 0.06463323297793977, 0.027941438856942113, 1.6553666861727834, 27.40297246724367, 56.933184787631035, 86.14437192678452, 98.86869594454765, 87.79832437634468, 75.53008988499641, 68.44882786273956, 60.24122267961502, 60.13627611100674, 87.54724144935608, 78.3744652569294, 90.43814912438393, 64.23774942755699, 65.46835899353027, 94.33032587170601, 91.23070299625397, 95.04113093018532, 96.45049810409546, 94.282988011837, 97.74653255939484, 94.528918415308, 89.83491629362106, 87.51915335655212, 89.40341144800186, 87.57697865366936, 85.39769679307938, 80.02954244613647, 88.3010981976986, 90.79935014247894, 84.92842957377434, 83.23307454586029, 89.95880484580994, 87.6589934527874, 87.36144661903381, 81.65663793683052, 84.92486536502838, 82.56744906306267, 84.2464117705822, 44.27548639476299, 32.6407615095377, 65.44474706053734, 29.49891719967127, 23.614689745008945, 23.24704997241497, 18.263009414076805, 4.72509347833693, 8.2433270663023, 1.7287622415460646, 1.3677019346505404, 0.39458240498788655, 0.904897159198299, 3.955854205414653, 1.2290896475315094, 0.6048305262811482, 1.0974930902011693, 0.5604321649298072, 1.4724962739273906, 17.136605456471443, 2.058618147857487, 20.69886490702629, 5.912714526057243, 2.7333063818514347, 2.0085152238607407, 10.841384455561638, 6.601964766159654, 13.71094012632966, 0.6653950607869774, 0.9899062570184469, 0.20501277409493923, 0.09047520841704682, 0.248180431954097, 0.16568567109061405, 0.5621478916145861, 1.85576330171898, 1.5845736349001527, 8.472826201468706, 16.512437649071217, 23.178589046001434, 25.763033665716648, 28.229209631681442, 15.792624223977327, 51.20468057692051, 48.495543748140335, 26.78081475198269, 72.42719918489456, 71.23747542500496, 75.9747876226902, 67.37708017230034, 71.7687401175499, 76.58349975943565, 74.00118872523308, 74.7580549120903, 75.8607405424118, 76.09602391719818, 80.87907806038857, 74.80960294604301, 77.57523134350777, 77.1131457388401, 75.76149746775627, 80.64523860812187, 81.15407690405846, 81.36488199234009, 82.60171562433243, 83.06901454925537, 79.39445212483406, 80.97762197256088, 74.46496903896332, 83.26864063739777, 63.75255346298218, 45.069643780589104, 60.15417695045471, 55.480667129158974, 45.638093277812004, 26.91964790225029, 22.13099665939808, 17.773202396929264, 18.869135789573193, 15.579973384737968, 7.987608388066292, 0.5037330917548388, 0.6897997856140137, 0.011682516724249581, 0.4098447907017544, 0.05159285225090571, 0.08419418256380595, 0.06663243781076744, 0.09645195372286253, 0.07644924073247239, 0.1600206649163738, 0.08824702876154333, 0.08551168764824979, 0.12565625889692456, 0.008512003405485302, 0.08960149280028418, 0.03829939174465835, 0.05648709353408776, 0.08827911180560477, 0.02761633735644864, 0.03764030523598194, 0.0845801735704299, 0.09902920995955355, 0.06382170191500336, 0.14979332074290141, 0.0912703899666667, 0.03371586913999636, 0.04911574142170139, 0.17277328530326486, 0.22814599215053022, 0.2812679728958756, 0.17157228256110102, 0.15258153987815604, 0.520534721435979, 0.14569242048310116, 0.09392790947458707, 0.1147353628766723, 0.23243002477101982, 0.11448171164374799, 0.22665239026537165, 0.23560325527796522, 0.19793851854046807, 0.2598667494021356, 0.2572974341455847, 0.28432609629817307, 0.33215240808203816, 0.18284863763255998, 0.2565594424959272, 0.18116411083610728, 0.15359492768766358, 0.21225187549134716, 0.12912753591081128, 0.1185628336679656, 0.29674706573132426, 0.09618947835406289, 0.19602291664341465, 0.21723523386754096, 1.4783604280091822, 24.67791259288788, 63.166849091649055, 101.71611115336418, 125.01477375626564, 98.82597103714943, 84.67480838298798, 81.64893195033073, 73.87062773108482, 71.34606599807739, 97.34066873788834, 90.57015404105186, 101.86662867665291, 75.33136814832687, 79.51003432273865, 100.87741255760193, 95.63727334141731, 100.18346339464188, 100.18806874752045, 97.60506615042686, 98.36781442165375, 92.74635046720505, 89.16416108608246, 86.34983450174332, 87.57650747895241, 88.65689590573311, 85.72242736816406, 79.79549020528793, 86.26927882432938, 89.11100953817368, 85.21592974662781, 82.92282119393349, 83.75803917646408, 88.19224923849106, 84.80943515896797, 80.48323810100555, 82.01782375574112, 82.33132213354111, 81.00324019789696, 54.115009009838104, 44.85744796693325, 74.21330094337463, 38.877511247992516, 29.216470755636692, 26.84108331799507, 20.974716804921627, 9.02876676991582, 7.156991483643651, 3.7980289617553353, 2.2506593680009246, 0.5760039668530226, 7.516471669077873, 5.735860615968704, 1.5990311466157436, 1.0112081514671445, 1.941969869658351, 2.301544100046158, 3.8057385105639696, 34.70813937485218, 4.64466224424541, 26.17921583354473, 7.6447755843400955, 2.724716467782855, 7.201707009226084, 24.49710499495268, 7.7622809540480375, 22.920607589185238, 1.1975209414958954, 4.389470787718892, 0.35140229389071465, 0.2690541814081371, 0.39985759067349136, 0.3340280527481809, 0.74043711530976, 3.4900041902437806, 3.9931211806833744, 11.355255581438541, 23.936595171689987, 30.575980804860592, 32.653999999165535, 36.348344162106514, 24.393066577613354, 60.62446251511574, 62.9280699044466, 36.812793239951134, 71.22959464788437, 72.28958576917648, 73.13406005501747, 70.03255248069763, 71.94986879825592, 79.88948196172714, 73.17680776119232, 74.6764124929905, 75.7210448384285, 76.88455760478973, 79.71961587667465, 77.60926231741905, 76.38341009616852, 78.57935786247253, 75.67569807171822, 80.55480346083641, 81.26601129770279, 83.32899659872055, 83.3402743935585, 85.0896093249321, 81.33253812789917, 81.95328801870346, 77.59345516562462, 83.91905933618546, 64.28644761443138, 55.09767808020115, 68.2613155245781, 67.15380415320396, 60.5021470785141, 45.39877451956272, 37.707744017243385, 32.352778762578964, 27.987990975379944, 23.895730264484882, 6.224017096683383, 0.39173528901301324, 0.948699665023014, 0.27317262603901327, 0.4311487334780395, 0.149367684207391, 0.18068889883579686, 0.12570929276989773, 0.2251682136557065, 0.23015066661173478, 0.3906588186509907, 0.13802683650283143, 0.3296709631104022, 0.29309136501979083, 0.21077966230222955, 0.28357899107504636, 0.17947113839909434, 0.2058691531419754, 0.21472342021297663, 0.07621490760357119, 0.22702962392941117, 0.16886859404621646, 0.27096381643787026, 0.18288578954525292, 0.2683796582277864, 0.2593202912248671, 0.15186198317678645, 0.13157408509869128], [0.049758634268073365, 0.05249637251836248, 0.08790319174295291, 0.0899747633957304, 0.06520079783513211, 0.12568542530061677, 0.11737151595298201, 0.07506826717872173, 0.053249478005454876, 0.10333924743463285, 0.0159308900765609, 0.221406118653249, 0.1691439308342524, 0.06308033349341713, 0.0546450013644062, 0.14721159677719697, 0.20723225577967241, 0.13358172815060243, 0.1280068335472606, 0.08153105241945013, 0.18854865833418444, 0.05478320410475135, 0.13206252217059955, 0.08312681835377589, 0.05892693741770927, 0.055701478268019855, 0.021194342407397926, 0.06562733236933127, 0.10238615170237608, 0.3360243112547323, 5.799286337569356, 26.903589963912964, 69.93636444211006, 94.25873771309853, 81.66091650724411, 71.05446204543114, 69.62384641170502, 58.181406408548355, 48.5834976285696, 66.92432686686516, 62.63767808675766, 76.10873803496361, 52.40289308130741, 59.14231404662132, 94.67518776655197, 85.63646078109741, 91.3464903831482, 95.7495953142643, 95.23416817188263, 87.37639501690865, 93.21527570486069, 92.54224821925163, 88.59233736991882, 89.1016012430191, 85.12034967541695, 88.01913052797318, 86.6119672358036, 86.59125074744225, 87.19630748033524, 86.4067554473877, 81.51732221245766, 83.58179703354836, 89.03515800833702, 89.58105191588402, 81.22318759560585, 84.73622828722, 79.07987460494041, 87.56746396422386, 38.792923986911774, 35.95872446894646, 53.237313106656075, 16.43595725297928, 28.286673948168755, 22.020105309784412, 12.854557279497385, 5.916925650089979, 4.797782152891159, 1.3774733478203416, 0.36265066999476403, 1.3888133643195033, 0.7998111261986196, 0.3540167020400986, 0.052609312551794574, 0.13065422273939475, 0.07456092760548927, 0.260828691534698, 1.15815564757213, 9.753638673573732, 1.4915258903056383, 12.815274987369776, 2.4344455311074853, 2.484015771187842, 0.708808503113687, 2.3786652367562056, 5.259744739159942, 8.28468119725585, 1.5099036041647196, 1.0634020320139825, 0.06323534587863833, 0.3514353046193719, 0.09963154443539679, 0.17266567389015108, 0.7278119365219027, 30.82043308764696, 2.578293699771166, 5.064363498240709, 13.990499675273895, 23.956061527132988, 27.987534999847412, 29.912986680865288, 19.11602944135666, 26.928039751946926, 57.25247025489807, 28.431159295141697, 59.26279038190842, 72.29994401335716, 73.03433820605278, 74.74946737289429, 69.1800606250763, 75.38380533456802, 72.769895195961, 73.2780647277832, 76.30984604358673, 79.08733740448952, 77.26060062646866, 79.2243504524231, 78.64210769534111, 79.16318893432617, 78.80932152271271, 78.38967964053154, 78.78730550408363, 78.66821229457855, 80.99764689803123, 79.2717795073986, 80.07553517818451, 78.13450813293457, 67.72114410996437, 85.85281357169151, 48.074184358119965, 37.238662987947464, 48.22958081960678, 37.329500913619995, 32.562649101018906, 12.196747977286577, 2.566336216405034, 2.1405032789334655, 4.390609776601195, 1.0096374107524753, 0.433415460283868, 0.087567696464248, 0.5801430135034025, 0.17659734963672236, 0.21735798509325832, 0.20963815011782572, 0.12035621868562885, 0.03244458872359246, 0.05672825442161411, 0.04626034678949509, 0.22620906092924997, 0.07498750666854903, 0.05199547107622493, 0.03338534625072498, 0.018510703011997975, 0.04638072685338557, 0.02738680035690777, 0.08858843153575435, 0.013221538047218928, 0.06249728743568994, 0.03816998716501985, 0.04361085360869765, 0.0286670811692602, 0.03335613160743378, 0.10363738299929537, 0.1275223001721315, 0.05272013746434823, 0.027697615514625795, 0.07046559345326386, 0.058534129784675315, 0.05872607885976322, 0.05166704475414008, 0.13165270822355524, 0.2382630086503923, 0.03737921768333763, 0.06501667841803282, 0.06961252438486554, 0.08614112535724416, 0.09957295187632553, 0.23540115362266079, 0.013053038055659272, 0.0463403503090376, 0.13214035861892626, 0.09862890292424709, 0.131061750871595, 0.0291176204700605, 0.12614506704267114, 0.08366418522200547, 0.055895601835800335, 0.11258490092586726, 0.03782072875765152, 0.05463844077894464, 0.03282840894826222, 0.06841742913820781, 0.04562487913062796, 0.06722224483382888, 0.15137722715735435, 0.3844410757301375, 11.003639549016953, 40.30623458325863, 81.67135074734688, 105.2071738243103, 91.44675180315971, 84.5375445485115, 78.04257586598396, 68.83401319384575, 59.859734550118446, 76.50705546140671, 82.14410617947578, 86.92895382642746, 67.2378708422184, 65.79301357269287, 97.52087026834488, 91.99688628315926, 97.1452908217907, 96.30026936531067, 101.74418404698372, 95.83489313721657, 98.68023365736008, 97.17323452234268, 94.01032224297523, 90.56648343801498, 90.80305874347687, 86.77041113376617, 86.5533135831356, 92.13981181383133, 89.70307096838951, 85.01836314797401, 83.02837952971458, 86.53595611453056, 89.06087502837181, 91.69398173689842, 82.44286894798279, 87.63003900647163, 81.50345295667648, 91.87967017292976, 39.99897167086601, 36.56044878065586, 61.71547517180443, 21.227416545152664, 28.68671078234911, 21.263432912528515, 22.104939557611942, 3.5089041385799646, 9.519509486854076, 2.4760521110147238, 0.5122497410047799, 0.8044355374295264, 2.7880980167537928, 1.0563135123811662, 0.8681929099839181, 0.2865703508723527, 0.15473198698600754, 0.5135327065363526, 1.0549213620834053, 10.184765439480543, 2.0535093219950795, 26.94004710763693, 6.440985929220915, 1.9937394792214036, 3.4795008413493633, 5.339947985485196, 10.371524468064308, 12.339369524270296, 0.9885243186727166, 1.4809812186285853, 0.02766697965853382, 0.7214938255492598, 0.12323578135692514, 0.36811160040088, 0.2504844591021538, 42.05103635787964, 12.471952959895134, 17.317175567150116, 20.994935519993305, 25.50567727535963, 26.215781271457672, 31.693877018988132, 25.31330119818449, 33.840695321559906, 62.736981958150864, 31.510664150118828, 63.92346069216728, 71.98178708553314, 76.78895473480225, 73.55791971087456, 73.32202076911926, 76.23291537165642, 75.10708138346672, 74.5421352982521, 75.90872436761856, 82.01100692152977, 78.25909584760666, 80.88131994009018, 78.89436095952988, 77.91208326816559, 83.5224062204361, 81.73021718859673, 83.58347654342651, 79.22708630561829, 88.75235438346863, 81.5776401758194, 80.68965822458267, 77.55510002374649, 72.26436272263527, 91.26139014959335, 55.71484476327896, 48.34085404872894, 61.308099031448364, 47.684253081679344, 43.35191175341606, 22.21690434962511, 13.519224263727665, 8.386522382497787, 7.515904074534774, 5.8166708797216415, 0.7114579109475017, 0.5442432523705065, 0.44134613941423595, 0.06371031297021545, 0.09838993137236685, 0.15096959512447938, 0.04888099640083965, 0.03086936914769467, 0.09109531732974574, 0.11254826851654798, 0.15285614936146885, 0.06043262517778203, 0.18809519126079977, 0.008052068515098654, 0.07877851574448869, 0.014031733244337374, 0.04032320990518201, 0.154980072111357, 0.08275029715150595, 0.08734663293580525, 0.06461496130214073, 0.08509603299899027, 0.050952286037500016, 0.07275939380633645, 0.2056804546737112, 0.06114655268902425, 0.08875001192791387, 0.07644080251338892, 0.28277153440285474, 0.21504490374354646, 0.2009628593805246, 0.18162005668273196, 0.23942743835505098, 0.37818192096892744, 0.18857669667340815, 0.17968797910725698, 0.22669136786134914, 0.35474160220474005, 0.17892482865136117, 0.22871946450322866, 0.17988197650993243, 0.1709143686457537, 0.1924670347943902, 0.15693941619247198, 0.24036304908804595, 0.17337602796033025, 0.22843661718070507, 0.3483207186218351, 0.28582956874743104, 0.2675512433052063, 0.30605065869167447, 0.13913088507251814, 0.22397911496227607, 0.21569637581706047, 0.08508519022143446, 0.1399991087964736, 0.1851219398668036, 0.3191886318381876, 8.891932312399149, 35.24030081927776, 91.44045174121857, 127.82207071781158, 107.19277247786522, 87.83439204096794, 91.49748668074608, 82.7898283302784, 77.47168689966202, 92.18251392245293, 97.66270905733109, 98.79909127950668, 77.76491716504097, 75.4077136516571, 104.94355157017708, 97.61702790856361, 104.86988112330437, 98.48561570048332, 108.71907457709312, 98.15281435847282, 100.0998754799366, 96.735999584198, 96.06287330389023, 90.30382633209229, 89.62260648608208, 86.00976794958115, 88.352380245924, 89.53777983784676, 87.29700967669487, 82.64600604772568, 81.7908239364624, 83.85583072900772, 89.54043969511986, 89.60065126419067, 84.66383457183838, 83.75089555978775, 81.41612604260445, 88.0224135518074, 48.599148988723755, 44.22387756407261, 72.94029325246811, 27.240020111203194, 34.73120793700218, 25.142069086432457, 27.724904492497444, 6.804705262184143, 11.338853761553764, 3.142412854358554, 0.9709366061724722, 5.6299735978245735, 2.7620770130306482, 0.6549572583753616, 3.3394139958545566, 0.22881922399392352, 0.2650073094991967, 1.0160765214823186, 6.5316172409802675, 27.946212217211723, 2.4481599451974034, 34.066984578967094, 7.876779735088348, 4.258301351219416, 12.730513885617256, 12.882861010730267, 12.712882831692696, 15.184327214956284, 3.1728843692690134, 4.126704437658191, 0.19023328903131187, 1.1311833886429667, 0.22238035075133666, 0.45983158343005925, 1.3910579751245677, 56.97716362774372, 24.189027026295662, 16.684207431972027, 26.300507225096226, 31.554114818572998, 34.44406874477863, 37.32107296586037, 32.299897000193596, 41.533382534980774, 74.39753785729408, 41.050618439912796, 62.43488296866417, 72.19365611672401, 76.1907148361206, 74.30369809269905, 73.40174809098244, 78.64550471305847, 77.10113078355789, 75.32519727945328, 75.07422834634781, 83.31366822123528, 80.00314146280289, 80.82879155874252, 80.47757640480995, 76.87600806355476, 81.67941391468048, 82.12450683116913, 82.4117486178875, 78.54907348752022, 87.41104155778885, 87.79292106628418, 84.43289816379547, 77.54354864358902, 74.16655585169792, 89.07120287418365, 62.010647132992744, 59.776545614004135, 74.2172223329544, 64.45008963346481, 60.271883234381676, 39.03084062039852, 36.693711429834366, 13.463917281478643, 13.53327875956893, 4.756673583760858, 0.3257218765793368, 0.4473887354834005, 0.6460381869692355, 0.25646462570875883, 0.5806665541604161, 0.2501338685397059, 0.3212301910389215, 0.11753268816391937, 0.11747385811759159, 0.2530670736450702, 0.6801602966152132, 0.1855961128603667, 0.3688408643938601, 0.2636180684203282, 0.20573203393723816, 0.14614891551900655, 0.2724704652791843, 0.23837263870518655, 0.13472058344632387, 0.17467005149228498, 0.18218575132777914, 0.17034563119523227, 0.16182907100301236, 0.17299285711487755, 0.42462739278562367, 0.2507736295228824, 0.11667855782434344, 0.23206908866995946], [0.16498649376444519, 0.0324599623127142, 0.03752782162337098, 0.06685869637294672, 0.050399441679473966, 0.08688744390383363, 0.0641213143535424, 0.03467427864961792, 0.0786551040073391, 0.09499591193161905, 0.0685155633254908, 0.019364983636478428, 0.13777789048617706, 0.15139334660489112, 0.0791327354090754, 0.13883209641790017, 0.11135157765238546, 0.1301184663316235, 0.112076411023736, 0.004943967032886576, 0.13231608434580266, 0.04512427454756107, 0.08756964831263758, 0.10163985542021692, 0.22029812185792252, 0.09853706957073882, 0.09153593782684766, 0.14503530808724463, 0.029529406674555503, 0.0897493954107631, 2.025197041220963, 7.676494857296348, 34.13253106176853, 65.39474174380302, 65.27249470353127, 63.26690912246704, 63.293006122112274, 60.71450248360634, 58.50534662604332, 55.08499436080456, 71.1405198276043, 67.13911414146423, 61.359696462750435, 49.64915804564953, 89.92048770189285, 88.73627364635468, 90.62242403626442, 93.77791151404381, 102.19231680035591, 94.51615869998932, 94.02410790324211, 91.2008897960186, 90.51142439246178, 92.10715636610985, 91.23596951365471, 83.89725610613823, 96.49064674973488, 85.89543208479881, 84.91327598690987, 86.47119998931885, 85.61885252594948, 87.92587593197823, 91.01771682500839, 85.65760284662247, 87.4061930179596, 91.1552694439888, 83.13387706875801, 85.46089500188828, 41.4404509216547, 44.233023673295975, 38.87444481253624, 21.897398494184017, 31.106890216469765, 20.30131693929434, 13.856748752295971, 6.540198605507612, 3.3043912751600146, 1.060919458977878, 0.4711939534172416, 1.3932077097706497, 0.2787824015831575, 0.4127490223618224, 1.0180914821103215, 0.23114373441785574, 0.290979539277032, 0.13797271909425035, 0.45806254085619, 4.353653909638524, 0.43052239052485675, 18.209835067391396, 2.7715632040053606, 0.7203771604690701, 0.7808486593421549, 5.21583192050457, 7.760546822100878, 11.884588077664375, 0.5093014554586262, 1.1977946455590427, 0.020387742915772833, 0.5597068194765598, 0.035898083879146725, 0.543676489032805, 0.3196544630918652, 20.931049548089504, 7.2336257714778185, 13.22680240496993, 20.369521379470825, 25.939226411283016, 30.998250246047974, 32.25476302206516, 26.293105222284794, 26.51055995374918, 42.67459809780121, 35.1973707228899, 54.660750925540924, 77.68408790230751, 74.60864692926407, 74.36061903834343, 70.09344801306725, 75.93783840537071, 72.3194445669651, 72.27225109934807, 77.3676560819149, 85.93713104724884, 73.61788049340248, 76.71757936477661, 79.12200674414635, 77.18196004629135, 81.47914946079254, 82.13250160217285, 82.72625014185905, 82.78823241591454, 82.99219027161598, 85.02293810248375, 79.47195276618004, 76.59929171204567, 74.19888451695442, 91.89828157424927, 40.16990169882774, 42.67065770924091, 51.422579884529114, 33.40903088450432, 22.92935471981764, 4.385046875104308, 5.7834454625844955, 2.3005181550979614, 1.2846862454898655, 0.516215362586081, 0.26403349300380796, 0.7866509479936212, 0.5862872244324535, 0.3356751159299165, 0.07459894040948711, 0.129618436913006, 0.03655907770735212, 0.32630291883833706, 0.1372135613928549, 0.2369224969879724, 0.11255486620939337, 0.14442217536270618, 0.04432202775205951, 0.11089903084211983, 0.06272385769989341, 0.04997639152861666, 0.05919512361288071, 0.045222327098599635, 0.09068118408322334, 0.03813665360212326, 0.020235565534676425, 0.1350078688119538, 0.11028972017811611, 0.09566793407429941, 0.1111962016148027, 0.12709503091173247, 0.07632677152287215, 0.028003372935927473, 0.09585404986864887, 0.07348855389864184, 0.005427715586847626, 0.10550845603574999, 0.10536506568314508, 0.1482064012088813, 0.08946472982643172, 0.035841669523506425, 0.04478732094867155, 0.14102665678365156, 0.07140919711673632, 0.10402275060187094, 0.12091726006474346, 0.037737348466180265, 0.05091729748528451, 0.24723149224882945, 0.031505118822678924, 0.024406552365690004, 0.11866405518958345, 0.048383000466856174, 0.13395919930189848, 0.04000616812845692, 0.046174884773790836, 0.06572078360477462, 0.11441439884947613, 0.1007267391833011, 0.07312821893719956, 0.1247732070623897, 0.01370458898236393, 0.150805150042288, 2.6538830436766148, 17.82915249466896, 55.38594201207161, 97.32850179076195, 99.06885400414467, 90.55419489741325, 79.75757583975792, 71.34206861257553, 66.94942831993103, 65.43781623244286, 81.23692765831947, 89.65656146407127, 75.33424839377403, 65.14079377055168, 97.32568234205246, 92.45937466621399, 97.09853813052177, 102.45413795113564, 96.74046814441681, 100.84808573126793, 102.23613604903221, 96.35446965694427, 90.54603293538094, 98.06225001811981, 95.44512525200844, 88.45047578215599, 95.1276370882988, 86.40696823596954, 87.89474040269852, 89.14502531290054, 82.74175330996513, 89.05261427164078, 91.50843009352684, 85.85147604346275, 87.65020072460175, 94.08118844032288, 82.35460728406906, 87.38603889942169, 45.57347394526005, 45.483388379216194, 45.703206583857536, 26.948566250503063, 33.39240677654743, 21.638201102614403, 24.759950190782547, 7.800923455506563, 9.118756391108036, 2.099811974912882, 0.35717350139748305, 4.1784880589693785, 1.595899045933038, 0.17890504299430177, 1.5677018277347088, 0.27681333536747843, 0.8354318398050964, 0.26414300431497395, 0.8935367781668901, 5.168212400749326, 0.9126940439455211, 26.05531968176365, 4.544476345181465, 1.779117020778358, 8.80745429545641, 14.80539919808507, 12.527225743979216, 15.755048990249634, 0.5823968269396573, 0.5686593765858561, 0.009285825944971293, 0.5417065916117281, 0.15590214607072994, 0.31102233566343784, 0.2513267967151478, 23.583666309714317, 9.932967200875282, 22.25482441484928, 24.841309525072575, 28.36930811405182, 34.15794029831886, 34.69566844403744, 32.338354736566544, 34.59227219223976, 49.48262818157673, 38.597462475299835, 59.83046472072601, 78.37650954723358, 77.45657131075859, 76.21696382761002, 72.91220515966415, 79.34181734919548, 78.28363493084908, 74.8598438501358, 79.11363959312439, 84.69617083668709, 74.92171213030815, 79.3376375734806, 78.63271459937096, 79.56841439008713, 84.01139438152313, 86.8594479560852, 84.41408157348633, 86.65133312344551, 86.81379720568657, 85.88955000042915, 82.15902417898178, 79.05015259981155, 80.23391827940941, 96.45297557115555, 43.795097172260284, 58.06115806102753, 59.74377617239952, 46.137211695313454, 33.96167702972889, 19.622019790112972, 5.955076077952981, 4.044870603829622, 2.125089168548584, 0.5840762180741876, 0.19967793457908556, 0.49190447491128, 0.8859266771469265, 0.20230481080943719, 0.1603879834874533, 0.13812226185109466, 0.04092582268640399, 0.25921092834323645, 0.05735487196943723, 0.16035743668908253, 0.07743849389953539, 0.28314821887761354, 0.0894582731416449, 0.011115518682345282, 0.03338320515467785, 0.04677448443544563, 0.06836244341684505, 0.03577986717573367, 0.16151196614373475, 0.015061169997352408, 0.0653781191795133, 0.05020818280172534, 0.03899446499417536, 0.07727822710876353, 0.024287127816933207, 0.06036258128006011, 0.08243184900493361, 0.03746933667571284, 0.23354499775450677, 0.20782487554242834, 0.1625886294641532, 0.22743442095816135, 0.17757705878466368, 0.2928046288434416, 0.22134336264571175, 0.1715144989429973, 0.12767105625243858, 0.2773872233228758, 0.19108782755210996, 0.14413940225495026, 0.1500562933506444, 0.23689318215474486, 0.2601960551692173, 0.29787625826429576, 0.12795525428373367, 0.26385876175481826, 0.30283528903964907, 0.12957739614648744, 0.32102025230415165, 0.2818183199269697, 0.21705334831494838, 0.21977918251650408, 0.4318333201808855, 0.352754516643472, 0.17222998867509887, 0.1764603640185669, 0.09613349815481342, 0.19119618111290038, 2.110072849318385, 13.27270109206438, 54.483938813209534, 109.21570032835007, 108.3455242216587, 102.94463083148003, 89.1786003112793, 86.79491221904755, 81.5365643799305, 83.8068513572216, 102.01176568865776, 104.52257215976715, 89.39714178442955, 73.77333015203476, 99.83602523803711, 96.37038320302963, 101.8651695549488, 104.23185735940933, 103.15425038337708, 103.75879794359207, 102.9677563905716, 93.02376598119736, 89.53097820281982, 98.21196958422661, 94.86872658133507, 85.61928570270538, 95.24733826518059, 86.28030583262444, 91.64635509252548, 86.55911207199097, 83.33931684494019, 87.69491672515869, 92.56748646497726, 83.79245012998581, 86.69384524226189, 93.12003761529922, 84.03258204460144, 86.29858285188675, 51.99421361088753, 53.444284200668335, 56.89910061657429, 33.714526891708374, 39.642752185463905, 24.477883726358414, 29.216506853699684, 9.33277990669012, 10.34044973552227, 7.014115825295448, 2.902975589968264, 4.792880890890956, 2.090298947878182, 0.5189653462730348, 2.8851250978186727, 2.0688172755762935, 4.2984176985919476, 0.3023045643931255, 0.7043876778334379, 12.632295805960894, 1.5639538038522005, 40.92676408588886, 7.113378848880529, 2.399713732302189, 18.34870621562004, 23.29988233745098, 14.350864738225937, 26.233062744140625, 2.7022067131474614, 1.2340412568300962, 0.12636505445698276, 0.9184432541951537, 0.31512005953118205, 1.0891951667144895, 0.3886474500177428, 39.94436860084534, 19.315431341528893, 23.483118005096912, 28.320872113108635, 35.92744454741478, 40.92787742614746, 43.28380800783634, 39.721540957689285, 40.54654508829117, 59.92473006248474, 48.35178606212139, 62.566192522645, 79.40245449542999, 78.22951063513756, 76.23388051986694, 76.0349839925766, 81.83237850666046, 76.52168467640877, 77.28456974029541, 78.4516391158104, 88.68882939219475, 74.70833837985992, 80.69214329123497, 79.19781267642975, 77.04826802015305, 80.84346637129784, 85.64227446913719, 86.85546576976776, 86.97346463799477, 89.9031226336956, 89.91502359509468, 84.42115679383278, 81.6688884794712, 80.70352748036385, 97.79167413711548, 54.9696097522974, 66.22961014509201, 77.24470987915993, 63.58110286295414, 52.77766317129135, 41.896422654390335, 20.865225680172443, 3.5378246242180467, 2.8042526124045253, 0.20510702684987336, 0.19969613204011694, 0.7252012984827161, 0.8038887230213732, 0.607155526522547, 0.373386875144206, 0.24530021619284526, 0.16816095623653382, 0.38041159976273775, 0.3548875678097829, 0.3390759928151965, 0.19246143900090829, 0.3690983896376565, 0.4757193918339908, 0.13726555625908077, 0.2772849256871268, 0.18297331844223663, 0.18531323585193604, 0.14289933285908774, 0.2790640020975843, 0.13922449958045036, 0.15182493516476825, 0.2913867705501616, 0.10908250565989874, 0.17187938326969743, 0.39389226702041924, 0.16563222161494195, 0.18304039374925196, 0.13968099461635575], [0.13510149816283956, 0.05378363137424458, 0.10205824859440327, 0.029951421529403888, 0.017758107751433272, 0.15236103296047077, 0.13943276106147096, 0.024876407915144227, 0.09718817163957283, 0.14988337294198573, 0.011862417031807126, 0.16837303235661238, 0.11585157524677925, 0.0852285954169929, 0.17686357285128906, 0.13285564054967836, 0.10952983517199755, 0.15039575169794261, 0.09025003339047544, 0.09726890988531522, 0.1459843071643263, 0.16976824030280113, 0.16732011776184663, 0.13754479674389586, 0.32493828737642616, 0.2847194642527029, 0.17862961714854464, 0.16178089077584445, 0.14566343219485134, 0.12197656455100514, 0.13822433684254065, 1.969266061205417, 15.527549497783184, 36.105263605713844, 34.59754250943661, 38.506624549627304, 34.22949805855751, 46.05120711028576, 49.5730709284544, 51.015807911753654, 55.93103036284447, 70.45384347438812, 62.21419841051102, 49.80449751019478, 85.60939863324165, 94.03948947787285, 96.22258633375168, 92.8187745809555, 99.10135746002197, 104.90521162748337, 93.231842815876, 95.17887353897095, 98.89985427260399, 95.19884526729584, 93.38263392448425, 91.83899715542793, 94.51918333768845, 92.70513027906418, 87.4348358809948, 85.19297897815704, 86.58773213624954, 90.3387388586998, 81.6591078042984, 87.12129950523376, 86.13527521491051, 87.47311502695084, 79.89297017455101, 84.73850816488266, 41.26607067883015, 39.46388818323612, 31.514486744999886, 29.415264688432217, 27.8257966786623, 26.127453111112118, 15.889195092022419, 8.588175661861897, 6.964757423847914, 1.8823507125489414, 2.061494356021285, 0.3551926201907918, 0.5222995486110449, 0.9762151760514826, 0.2598450786899775, 1.2365851015783846, 0.15552373981336132, 0.11922501493245363, 1.0235612886026502, 1.135375751182437, 0.948495069751516, 10.768328625708818, 0.16466634609969333, 1.0266742715612054, 7.112398501485586, 6.722091045230627, 6.10373217612505, 18.303623534739017, 0.9656288253609091, 0.865402672206983, 0.13541973108658567, 0.595017671585083, 0.314866304397583, 0.4729442344978452, 0.7864730700384825, 4.594015711918473, 5.068238340318203, 34.78772610425949, 26.952561736106873, 27.6376573741436, 33.270015344023705, 32.04569824039936, 33.519228771328926, 21.880042925477028, 35.31663492321968, 34.37619298696518, 53.65313999354839, 74.99291270971298, 77.50020816922188, 74.69069972634315, 75.90373903512955, 73.92638593912125, 75.33403560519218, 78.61256808042526, 81.20275229215622, 81.938316822052, 79.88831162452698, 82.8926432132721, 81.24805346131325, 86.87677502632141, 89.45537745952606, 84.24663975834846, 83.65477591753006, 88.48331362009048, 88.88605400919914, 79.21280667185783, 80.3859481215477, 74.5240406692028, 86.95360690355301, 80.88929191231728, 27.8013563901186, 55.46163775026798, 41.63638360798359, 24.23574361950159, 14.142266381531954, 6.15509781986475, 0.30220490880310535, 2.7600270230323076, 0.7012872223276645, 0.19076692289672792, 0.7295341941062361, 0.477611452806741, 0.5475862417370081, 0.1333562340005301, 0.16919101268285885, 0.0648278983135242, 0.11450091100414284, 0.0521496262808796, 0.01250532193807885, 0.22335689835017547, 0.18450656585628167, 0.0651366614329163, 0.15690358530264348, 0.03251451387768611, 0.07678348920308053, 0.07111853497917764, 0.11431769700720906, 0.03260694837081246, 0.07507460511988029, 0.02614321874716552, 0.06860136301838793, 0.11799382162280381, 0.16540246753720567, 0.12095352140022442, 0.11270343675278127, 0.12105359259294346, 0.13381623197346926, 0.04786746758327354, 0.1073848428495694, 0.017198244531755336, 0.016146927409863565, 0.14520153432385996, 0.05063607546617277, 0.14842272241367027, 0.06130089714133646, 0.04014025937067345, 0.06428587075788528, 0.09831192423007451, 0.05653441658068914, 0.09040407356224023, 0.15591418370604515, 0.03034036071767332, 0.01179290191430482, 0.2467062001232989, 0.07749842232442461, 0.03539970573910978, 0.0784246671537403, 0.0843932933639735, 0.05009832268115133, 0.2931735949823633, 0.21159281866857782, 0.053471268838620745, 0.09364985642605461, 0.07699940222664736, 0.20628055528504774, 0.1659097254741937, 0.14567453472409397, 0.06655885386862792, 0.16566885402426124, 4.999300064519048, 27.651880010962486, 60.10626532137394, 73.9094540476799, 75.49827039241791, 59.76643815636635, 62.44562119245529, 62.2422219067812, 56.74849569797516, 66.73900321125984, 81.70082196593285, 87.17915520071983, 61.70075096189976, 102.86145329475403, 99.0118570625782, 95.02689689397812, 102.75850921869278, 104.07829239964485, 97.92329907417297, 99.43558752536774, 104.74089324474335, 106.67329475283623, 97.84056231379509, 98.12867045402527, 93.41326028108597, 96.8110303580761, 87.28833854198456, 91.70449957251549, 90.69223389029503, 88.59825745224953, 87.30956420302391, 85.63578441739082, 90.09106814861298, 86.89552322030067, 89.23907026648521, 83.39980959892273, 86.28697067499161, 46.256863474845886, 46.698399782180786, 38.044884726405144, 34.44509468972683, 32.08095274865627, 24.76021997630596, 20.322536900639534, 11.92384947091341, 14.037562999874353, 2.7377490559592843, 1.6543160425499082, 0.5660565756261349, 0.186717557371594, 1.6565287113189697, 0.6802335614338517, 1.1274745501577854, 0.6661247997544706, 0.4477442242205143, 1.335391199681908, 1.3641763175837696, 0.7895666384138167, 11.772287953644991, 0.32062293612398207, 2.35241933260113, 24.439743272960186, 15.639716628938913, 5.797839565202594, 23.81532657891512, 1.3676279573701322, 1.6869618720375001, 0.1452766841975972, 0.9677904343698174, 0.5511178553570062, 0.3589867759728804, 0.353348056669347, 7.753391331061721, 7.691459879279137, 43.79654869437218, 29.015102460980415, 28.93677346408367, 33.74975860118866, 34.9602672457695, 36.32634334266186, 32.19324432313442, 42.8668487817049, 41.5658213943243, 57.064171358942986, 79.01942744851112, 79.94454860687256, 77.79983729124069, 79.09547656774521, 77.5557915866375, 74.99630212783813, 81.53189823031425, 81.235491335392, 83.31196591258049, 79.56507816910744, 83.23023229837418, 82.02948153018951, 88.18524241447449, 88.98110970854759, 85.5109991133213, 84.64991211891174, 93.64424228668213, 88.49549576640129, 81.58105999231339, 84.42759364843369, 78.7684129178524, 90.88777899742126, 81.29780039191246, 36.63728825747967, 71.10089555382729, 51.97754390537739, 38.3451522141695, 29.101969599723816, 5.076290583238006, 0.5140893172938377, 0.3680842596804723, 0.7643386640120298, 0.007964488595462171, 0.694246853236109, 0.6674930825829506, 0.6504347291775048, 0.12302511531743221, 0.33171970630064607, 0.05540056707104668, 0.1390466364682652, 0.20039771392475814, 0.12674605823121965, 0.22446102113462985, 0.22029073006706312, 0.23728378931991756, 0.09374144487082958, 0.08298825938254595, 0.030706658835697453, 0.03365726544870995, 0.027818203379865736, 0.17137905699200928, 0.030415889086725656, 0.010312387803423917, 0.10149855792406015, 0.07945513178128749, 0.17548573116073385, 0.05854159579030238, 0.13130560575518757, 0.19546464347513393, 0.14616347645642236, 0.10862234441447072, 0.40253172686789185, 0.2711068728240207, 0.24597251293016598, 0.2551940392004326, 0.0955925096059218, 0.23754731111694127, 0.295207406161353, 0.1530946756247431, 0.15947474108543247, 0.3730545117286965, 0.18847055471269414, 0.3153055370785296, 0.28447161661460996, 0.20341190218459815, 0.16390830161981285, 0.5033205170184374, 0.15123445278732106, 0.13431967527139932, 0.11748086399165913, 0.20637933514080942, 0.24487033457262442, 0.45786934497300535, 0.4645281017292291, 0.23110944719519466, 0.4131390358088538, 0.34620913036633283, 0.35827606567181647, 0.3358030621893704, 0.20984013302950189, 0.20018397539388388, 0.18168048234656453, 3.337217951193452, 25.589023903012276, 68.76343578100204, 83.55251580476761, 78.83338943123817, 66.05997204780579, 78.9838233590126, 74.75129887461662, 76.31515815854073, 84.45158556103706, 103.2342816889286, 105.95935866236687, 74.16972488164902, 105.0601977109909, 97.44941130280495, 100.40733218193054, 105.87684988975525, 104.26515117287636, 104.31118950247765, 104.79248687624931, 104.56681698560715, 107.62361615896225, 96.51446387171745, 95.07947847247124, 93.22127938270569, 96.2429228425026, 88.42479676008224, 92.39823594689369, 88.9053949713707, 86.54510602355003, 91.70551031827927, 81.34487986564636, 89.73735272884369, 87.82888993620872, 89.90532651543617, 82.98917323350906, 88.9407254755497, 50.778480246663094, 54.96974274516106, 45.95467709004879, 39.770676121115685, 36.463637575507164, 30.393313206732273, 25.529707185924053, 10.996084604412317, 17.479930333793163, 7.671206966042519, 8.562597334384918, 0.7217171229422092, 0.8373405248858035, 2.1509669674560428, 1.1500209965743124, 3.1867362884804606, 1.038099902216345, 0.26909491047263145, 2.4841485265642405, 4.900650233030319, 1.8621880444698036, 26.07717800885439, 0.2037384471623227, 2.873310106806457, 40.19846476614475, 24.39396522939205, 8.216841537505388, 51.29898391664028, 2.2999873710796237, 1.9629901042208076, 0.2800317626679316, 1.3939090096391737, 0.7134561880957335, 0.8264138549566269, 1.2674578512087464, 13.763486556708813, 13.61562604084611, 47.111217230558395, 34.02177840471268, 34.34729553759098, 40.03970928490162, 39.70653176307678, 44.02110144495964, 36.154923141002655, 50.22586449980736, 49.69812221825123, 62.389448806643486, 78.83000761270523, 83.57689529657364, 79.10805389285088, 79.52429115772247, 77.8637270629406, 78.68009805679321, 82.29608282446861, 84.97797131538391, 80.61214238405228, 82.244793176651, 83.27824652194977, 79.71533730626106, 85.45818194746971, 87.91253104805946, 88.16894128918648, 85.54550886154175, 91.35964527726173, 93.37588548660278, 87.75233924388885, 86.48523643612862, 80.18015116453171, 88.83607149124146, 89.63345870375633, 47.02362433075905, 80.9304741024971, 72.08916172385216, 53.884988352656364, 47.913297191262245, 36.35506220161915, 0.2544607379240915, 7.176394192501903, 0.5164629430510104, 0.20569480780977756, 0.7342831674031913, 0.6197397387586534, 1.4651009207591414, 0.2485129883280024, 0.4945705662248656, 0.2742689859587699, 0.23921758867800236, 0.3667916759150103, 0.2256683469749987, 0.2699246909469366, 0.4981572472024709, 0.6004643824417144, 0.27228142542298883, 0.15521349239861593, 0.2131129300687462, 0.12116560494177975, 0.2161554535268806, 0.16705806541722268, 0.3996720537543297, 0.07456037841620855, 0.24221216939622536, 0.18027353362413123, 0.5681264551822096, 0.2379752928391099, 0.17849022697191685, 0.4384191386634484, 0.21643928048433736, 0.37270884902682155], [0.1039310211490374, 0.1786864805035293, 0.05395447376940865, 0.07114111111150123, 0.22144157846923918, 0.1633554312866181, 0.21050140145234764, 0.3033172694267705, 0.12588019453687593, 0.09502049928414635, 0.02518715256883297, 0.10475431525264867, 0.15897655219305307, 0.11602624712395482, 0.05598497125902213, 0.3812027588719502, 0.20590410829754546, 0.16531384026166052, 0.12840867682825774, 0.07182356785051525, 0.06968455723836087, 0.14604970521759242, 0.2162013776251115, 0.11639994074357674, 0.37900279567111284, 0.4335802764398977, 0.21906685433350503, 0.262153692310676, 0.2526422980008647, 0.03659625930595212, 0.041145349969156086, 0.36435657064430416, 2.572170803323388, 15.111502222716808, 25.507936254143715, 33.08857887983322, 25.288940705358982, 32.7530112862587, 30.403981134295464, 34.79665942490101, 46.54472842812538, 60.55759370326996, 68.73227745294571, 45.38410350680351, 81.73169150948524, 98.68152558803558, 94.08962398767471, 110.28586730360985, 88.24239134788513, 97.6257598400116, 100.5558206140995, 91.88585624098778, 94.28843691945076, 99.14295762777328, 101.67044520378113, 100.93979761004448, 93.20826128125191, 87.6459601521492, 93.23973879218102, 89.44919139146805, 83.1290665268898, 86.7222449183464, 88.92671942710876, 81.49175718426704, 85.10991543531418, 80.86957097053528, 83.81904870271683, 74.00491252541542, 37.00006999075413, 33.98203633725643, 25.772626250982285, 27.612457126379013, 35.45099951326847, 28.837954066693783, 19.003528878092766, 9.921734053641558, 3.7209921330213547, 0.8294595102779567, 4.621839243918657, 0.345683719497174, 1.4985021972097456, 1.2466912530362606, 0.3007526742294431, 0.3255803044885397, 0.13639032666105777, 1.4304571109823883, 1.2282402743585408, 2.0525664975866675, 1.869806160684675, 4.800892286002636, 3.487763497978449, 0.9844432189129293, 18.50222747772932, 4.420773033052683, 0.589227257296443, 23.96102786064148, 5.366323320195079, 0.7453891402110457, 0.2275826723780483, 0.4967375780688599, 0.08884899958502501, 0.22374866326572374, 0.36996593058574945, 5.8478957042098045, 6.1496037896722555, 41.02763347327709, 30.36343540996313, 30.84810320287943, 31.491100899875164, 32.5860558450222, 42.401784136891365, 24.510265588760376, 28.100157156586647, 37.16720022261143, 40.94464972615242, 80.26278153061867, 75.57666778564453, 75.53756028413773, 73.36121186614037, 78.6354124546051, 72.60343372821808, 77.04094961285591, 79.70647618174553, 80.19459038972855, 81.34133085608482, 83.93628001213074, 83.36868926882744, 86.41845121979713, 83.78725200891495, 89.09343168139458, 88.66810530424118, 90.49912065267563, 82.83821493387222, 84.12647500634193, 86.22594594955444, 78.16511929035187, 96.50957733392715, 52.835454270243645, 30.242947675287724, 61.86939351260662, 25.686161890625954, 22.67585512250662, 7.1385325491428375, 3.949445611797273, 1.3541740668006241, 0.4512404522392899, 0.18250398425152525, 0.1361328607890755, 0.696453406708315, 0.44254108623135835, 0.404112352989614, 0.09786838709260337, 0.17959326622076333, 0.10612300626235083, 0.058977266162401065, 0.14767318294616416, 0.16034906526328996, 0.24048105056863278, 0.12698974984232336, 0.11600175625062548, 0.07148871081881225, 0.049637207775958814, 0.06038373619958293, 0.06871061457786709, 0.025815523440542165, 0.09871414600638673, 0.06354370081680827, 0.01634907916013617, 0.01634758558793692, 0.13796655926853418, 0.2509757608640939, 0.10499667099793442, 0.22279117401922122, 0.231862474756781, 0.13772438163869083, 0.22314688540063798, 0.19606137473601848, 0.1650377464829944, 0.05582707191933878, 0.018640730995684862, 0.1691104451310821, 0.13048522087046877, 0.16213418275583535, 0.22108831617515534, 0.1117352902656421, 0.08692076633451506, 0.013048997989244526, 0.1380525148124434, 0.2464155008783564, 0.1878450726508163, 0.0377799217676511, 0.06286937059485354, 0.3702705376781523, 0.24489699251716956, 0.04712300069513731, 0.10074112200527452, 0.09571219576173462, 0.14566301659215242, 0.15523296635365114, 0.17148421931779012, 0.3128934680717066, 0.017063702434825245, 0.37213680159766227, 0.5391753336880356, 0.4684250894933939, 0.149181330925785, 0.20014208857901394, 0.5674598878249526, 8.107439707964659, 27.34448030591011, 46.52415633201599, 57.87686035037041, 58.26429896056652, 50.95173954963684, 45.08080378174782, 43.58860865235329, 57.6639311760664, 67.92935013771057, 78.80076438188553, 57.0774744451046, 89.26601082086563, 117.8256507217884, 97.78323099017143, 106.59171313047409, 103.05039435625076, 101.80244252085686, 94.1468033194542, 91.34281978011131, 102.41864785552025, 104.05442968010902, 105.26006698608398, 102.04717218875885, 94.78427991271019, 92.33433857560158, 90.21776854991913, 91.73434317111969, 91.06777533888817, 90.35264611244202, 88.489590883255, 82.47123062610626, 89.79054227471352, 80.84599703550339, 83.82916375994682, 75.99410578608513, 44.517856389284134, 41.60282380878925, 34.94229421019554, 35.92044532299042, 36.11518867313862, 31.387554556131363, 24.08265933394432, 21.043128333985806, 19.945699721574783, 4.206897709518671, 1.9007455254904926, 0.2523744123755023, 1.215636469423771, 1.8565523531287909, 0.6617621588520706, 1.368420571088791, 0.9867498138919473, 5.342848179861903, 5.053435759618878, 2.1700295945629478, 0.4716301284497604, 7.85581910982728, 2.1196447731927037, 3.544639083556831, 35.65601371228695, 18.14946200698614, 0.5374431016389281, 39.258197620511055, 5.315651139244437, 0.33472798706497997, 0.11727761942893267, 0.4845269036013633, 0.07094508764566854, 0.04613517987309024, 2.4259800603613257, 5.214085914194584, 8.034473173320293, 44.724819883704185, 29.93231624364853, 33.76904636621475, 30.052444897592068, 38.30477558076382, 41.859154254198074, 36.52040272951126, 40.548300594091415, 46.537930592894554, 48.15572798252106, 83.25081959366798, 79.39772754907608, 79.495420306921, 79.28158298134804, 80.80397129058838, 79.13374051451683, 80.37604585289955, 83.06171894073486, 79.83587443828583, 81.24949738383293, 81.12472727894783, 84.64810341596603, 88.88424530625343, 86.91347345709801, 89.92731213569641, 91.18883684277534, 91.53844088315964, 84.66611444950104, 87.38246709108353, 86.85206115245819, 82.2272077202797, 102.55072876811028, 54.44951266050339, 43.37962746620178, 72.94897198677063, 39.46767657995224, 35.91337390244007, 15.257356446236372, 3.0220968229696155, 1.8434827169403434, 0.5947187938727438, 0.29117852391209453, 0.14622779097408056, 0.6311127066146582, 0.44135169067885727, 0.3213651431724429, 0.186559583817143, 0.35784668871201575, 0.09521042971755378, 0.08111303031910211, 0.15413501823786646, 0.18147584254620597, 0.21148822037503123, 0.09134021122008562, 0.11932051449548453, 0.038760458410251886, 0.08359690211364068, 0.03485436078335624, 0.04596849721565377, 0.07739387598121539, 0.17658644006587565, 0.16328892001183704, 0.04188695216726046, 0.02364467283769045, 0.024456309656670783, 0.17990624473895878, 0.2148411248344928, 0.23651253461139277, 0.3329080331604928, 0.08163838181644678, 0.13024874293478206, 0.4151941911550239, 0.32147112186066806, 0.3198451059870422, 0.1715677257743664, 0.39658326481003314, 0.2458233857760206, 0.24778574297670275, 0.3202507639070973, 0.15360577788669616, 0.1338271118584089, 0.08311430574394763, 0.3191652987152338, 0.4225065722130239, 0.3012016142020002, 0.16251851135166362, 0.497715164674446, 0.6655605300329626, 0.3186217200709507, 0.3677450685063377, 0.16054475476266816, 0.2057959180092439, 0.4434931429568678, 0.40040318795945495, 0.35578339942730963, 0.4415459849406034, 0.44331900542601943, 0.556012645829469, 0.7642740674782544, 0.34642862796317786, 0.21422005112981424, 0.39471373544074595, 0.39632713480386883, 4.806455187499523, 25.812267623841763, 58.41915585100651, 73.78491193056107, 64.45309147238731, 54.54152472317219, 53.10429364442825, 55.322071239352226, 74.5225739479065, 94.29246470332146, 111.22670441865921, 79.6958215534687, 104.79259327054024, 113.91281828284264, 97.03006580471992, 111.90339490771294, 104.73445639014244, 97.36569419503212, 100.1601554453373, 100.03249749541283, 105.89290022850037, 103.23240458965302, 103.65795135498047, 100.72194010019302, 94.84546422958374, 89.07694056630135, 92.2100168466568, 94.8178169131279, 88.88775631785393, 87.36583918333054, 88.72757971286774, 83.6551558971405, 86.95163860917091, 83.47899734973907, 81.76516771316528, 80.97444534301758, 51.607960537075996, 49.16553519666195, 39.4673839956522, 41.411006301641464, 44.1966862231493, 36.94115035235882, 28.8979509472847, 18.679491765797138, 20.246364288032055, 12.207101471722126, 9.972111750394106, 1.604780238121748, 3.0782269360497594, 3.9407742395997047, 0.7307104091159999, 1.3208891591057181, 1.184175938833505, 6.170800477266312, 12.346686031669378, 4.608758445829153, 1.8649214040488005, 14.255165923386812, 4.342289669439197, 5.41027651168406, 49.14018675684929, 31.637451946735382, 1.3164781895466149, 59.87793177366257, 12.151581700891256, 0.7177146908361465, 0.47747356176842004, 0.3969670442165807, 0.17654510244028643, 0.25380847917404026, 2.316574431024492, 9.747923780232668, 15.043603666126728, 52.08910591900349, 38.47809948027134, 39.370227009058, 40.306462571024895, 40.30961260199547, 53.69891993701458, 39.95503082871437, 44.96001586318016, 53.23002129793167, 56.59636326134205, 87.39666312932968, 79.84782099723816, 81.34278237819672, 78.53839606046677, 83.11807751655579, 78.42813357710838, 83.01042169332504, 86.14086091518402, 82.85591438412666, 85.32072812318802, 82.10663259029388, 83.61998498439789, 84.23360645771027, 86.46660223603249, 93.08840811252594, 90.74656337499619, 94.30995136499405, 90.3214193880558, 86.03694409132004, 85.97503781318665, 81.33416444063187, 100.76794043183327, 69.97403562068939, 49.68983866274357, 87.03023359179497, 56.02808095514774, 50.32779783010483, 41.279651150107384, 10.527318008244038, 3.3544452767819166, 1.0259051690809429, 0.27957320446148515, 0.11565095788682811, 0.8391679893247783, 0.4712917091092095, 0.730865013319999, 0.5285918328445405, 0.3890929464250803, 0.39408056472893804, 0.25761824974324554, 0.3121627197833732, 0.4773218370974064, 0.20083758485270664, 0.40593628480564803, 0.4076323297340423, 0.22419098328100517, 0.13813698606099933, 0.1645795741933398, 0.09906762352329679, 0.16978069354081526, 0.4273055662633851, 0.384284898173064, 0.22407752374419942, 0.11794294739956968, 0.1734212989686057, 0.629035821184516, 0.24214119039243087, 0.31136413919739425, 0.625269035808742, 0.2842560672434047, 0.38120819139294326], [0.23154844238888472, 0.06299258195213042, 0.11230023534153588, 0.11509194999234751, 0.13122589909471571, 0.11287257962976582, 0.09507901762844995, 0.10083592394948937, 0.01889693521661684, 0.05690000223694369, 0.03644558477390092, 0.03616996968048625, 0.22520104626892135, 0.33509713131934404, 0.09226015521562658, 0.16576505120610818, 0.30986704921815544, 0.08581343005062081, 0.07413997402181849, 0.09734282779390924, 0.04290412492991891, 0.1239826787787024, 0.1785569460480474, 0.38540726294741035, 0.0952407241857145, 0.26650229177903384, 0.8631390624213964, 0.34695944166742265, 0.24542713828850538, 0.405980427749455, 0.15012265619589016, 0.09955020505003631, 0.5622126662638038, 6.66124158538878, 19.285513646900654, 25.156284123659134, 20.601308941841125, 21.12492084503174, 25.114792250096798, 25.993979573249817, 31.665762327611446, 43.015417009592056, 83.04017409682274, 52.802491039037704, 58.578906878829, 120.82244351506233, 94.11779567599297, 108.54131251573563, 109.32544603943825, 89.83553946018219, 95.24496719241142, 102.48400434851646, 100.9622848033905, 96.18622228503227, 103.1191934645176, 104.66663762927055, 97.22600609064102, 93.50162073969841, 91.73114374279976, 93.3745251595974, 85.4094685614109, 82.39214166998863, 81.85377135872841, 87.72655382752419, 77.46968060731888, 71.45877555012703, 83.16118240356445, 60.13065621256828, 26.24039065092802, 31.49200525134802, 22.55254413932562, 30.218836069107056, 32.12424762547016, 28.37901659309864, 24.451085664331913, 11.605377160012722, 4.448426049202681, 2.8131536347791553, 3.470862479880452, 1.4422148675657809, 1.1155980499461293, 0.21752744709374383, 1.2800103588961065, 5.142262168228626, 3.670760728418827, 7.1429208386689425, 3.0326825799420476, 2.98300095833838, 1.2253521918319166, 2.200697986409068, 0.9980837744660676, 5.9024489019066095, 29.16844703257084, 18.442899361252785, 5.453687757253647, 18.389495126903057, 4.022068502381444, 3.7645408837124705, 1.3890838623046875, 0.6869176402688026, 0.6718550703953952, 2.6527993893250823, 3.635153789073229, 1.0892647504806519, 1.6992320073768497, 25.3485120087862, 39.99676398932934, 35.95389872789383, 37.84535363316536, 35.27656227350235, 31.52220033109188, 25.707873925566673, 28.959893323481083, 38.61501753330231, 36.50109216570854, 64.11348849534988, 81.4867490530014, 79.87147852778435, 79.78644669055939, 69.83857288956642, 81.24178379774094, 81.33182376623154, 80.6769897043705, 76.6975924372673, 83.68119969964027, 85.61624586582184, 90.31051397323608, 91.19358658790588, 87.67363786697388, 89.75900396704674, 91.84426367282867, 90.9215895831585, 81.08751967549324, 84.69826832413673, 83.15795257687569, 85.89243784546852, 88.89491513371468, 28.664147593080997, 52.92257599532604, 41.97275675833225, 25.958272889256477, 19.2024178057909, 6.701312810182571, 0.5692143843043596, 0.8738031308166683, 0.18721874454058707, 0.12490140565205365, 0.2769177407026291, 0.33269174164161086, 0.18162599386414513, 0.1364978341734968, 0.18059276102576405, 0.35453757096547633, 0.2053440539748408, 0.061957334182807244, 0.0336955639795633, 0.1676034549018368, 0.2683451335178688, 0.012346500479907263, 0.06409671957953833, 0.012423397183738416, 0.0844565020815935, 0.04217652705847286, 0.04982559083146043, 0.06045513080607634, 0.19252686674008146, 0.2273978033917956, 0.10380056643043645, 0.040614903628011234, 0.06557320753927343, 0.3346872580004856, 0.15825439797481522, 0.08688741421792656, 0.10453354858327657, 0.15373290778370574, 0.08699671772774309, 0.24483288580086082, 0.16194705764064565, 0.035544951460906304, 0.06406117070582695, 0.1415628139511682, 0.03188339891494252, 0.11731694583431818, 0.07816606579581276, 0.05325645048287697, 0.11356957504176535, 0.03677339511341415, 0.1250810647616163, 0.21699428820284083, 0.39841268851887435, 0.07549342131824233, 0.12210503773530945, 0.14347531367093325, 0.06237126333871856, 0.021430625529319514, 0.03101988597336458, 0.06558195003890432, 0.07740238099358976, 0.17512212332803756, 0.33399943553376943, 0.4431624716380611, 0.09720068424940109, 0.32487072225194424, 0.5768887849990278, 0.6748681305907667, 0.45363280980382115, 0.26909491047263145, 0.1671177489333786, 0.9155978006310761, 11.707043554633856, 27.456769980490208, 48.43367166817188, 54.41096372902393, 48.772195503115654, 28.081617951393127, 33.972134068608284, 45.043919160962105, 56.49981424212456, 82.48127728700638, 64.33820083737373, 65.24766683578491, 129.44601237773895, 113.01566362380981, 106.43720582127571, 108.43036606907845, 110.97018018364906, 94.6494023501873, 97.41908133029938, 103.63060802221298, 103.2185885310173, 103.58770072460175, 106.70955240726471, 91.19054675102234, 97.95186594128609, 93.04885223507881, 88.81429105997086, 92.63990297913551, 89.32473286986351, 84.52638074755669, 88.98432433605194, 84.22928988933563, 75.73470890522003, 85.47273516654968, 61.5631527453661, 34.564621075987816, 44.149397760629654, 35.53139179944992, 36.55342295765877, 31.884465292096138, 31.188673228025436, 28.034874759614468, 18.806950226426125, 11.695173941552639, 2.7909803995862603, 4.173807185143232, 1.121590684633702, 1.6058638924732804, 0.8777912543155253, 0.41176288621500134, 2.711258064955473, 12.220764588564634, 17.904538549482822, 6.493443064391613, 2.7893823478370905, 0.4007967934012413, 4.625458549708128, 0.5521914758719504, 7.459480427205563, 37.927904203534126, 32.311885356903076, 3.9400881389155984, 23.590300753712654, 18.95286999642849, 4.737783847376704, 2.357456674799323, 0.8404597418848425, 2.834700853563845, 6.524799456819892, 2.9393740743398666, 0.8810208435170352, 6.009936584159732, 33.230337873101234, 36.40065975487232, 34.83087278902531, 35.42319640517235, 40.373863354325294, 40.1171263307333, 28.743618428707123, 43.75804156064987, 47.71856144070625, 46.8037985265255, 64.51169952750206, 86.53044641017914, 82.91741788387299, 87.05704495310783, 76.17003634572029, 83.48418027162552, 85.36893993616104, 84.93389368057251, 78.73346239328384, 83.86691093444824, 85.87283089756966, 91.80316507816315, 91.64811059832573, 91.95620566606522, 92.67331078648567, 94.35310184955597, 90.28333023190498, 82.54476428031921, 85.3194209933281, 86.06510058045387, 93.84791895747185, 88.96423861384392, 35.79296216368675, 65.88094085454941, 52.47109942138195, 39.77766014635563, 26.95163268595934, 1.4281632215715945, 0.7397712604142725, 0.43519875209312886, 0.26912857429124415, 0.1591836113948375, 0.4913107567699626, 0.31593155348673463, 0.2621944510610774, 0.18634499923791736, 0.06715579293086194, 0.19585937698138878, 0.05446883777040057, 0.10007733770180494, 0.20631269027944654, 0.0896539403765928, 0.059651017509168014, 0.11042102094506845, 0.021327841786842328, 0.10542298288783059, 0.0634098841692321, 0.06016294355504215, 0.03254983639635611, 0.06376730249030516, 0.25525355944409966, 0.09637163107981905, 0.09721701149828732, 0.005554479048441863, 0.0492832330201054, 0.13737128261709586, 0.11790972886956297, 0.3648746194085106, 0.07099222886608914, 0.18749298295006156, 0.04026977527246345, 0.3700712264981121, 0.4903323092730716, 0.24611693486804143, 0.21927245892584324, 0.2880561602069065, 0.2663105505052954, 0.19034400262171403, 0.19313875265652314, 0.17038232297636569, 0.12463360908441246, 0.13213707832619548, 0.19452489155810326, 0.3560618235496804, 0.75541882077232, 0.2004813836538233, 0.1565291717997752, 0.5258063448127359, 0.31730642658658326, 0.2599496324546635, 0.21317504782928154, 0.15664649050449952, 0.27315229119267315, 0.40478191862348467, 0.5995831859763712, 0.9282407315913588, 0.3534971392946318, 0.80032599857077, 0.6794083525892347, 0.523744955426082, 0.273308171890676, 0.32399991585407406, 0.2849465317558497, 0.4940759693272412, 9.379932526499033, 28.19976881146431, 46.67477644979954, 57.76230029761791, 53.63898955285549, 34.917679131031036, 44.33427684009075, 56.20219141244888, 72.26921126246452, 108.65759387612343, 84.72973063588142, 84.3912447988987, 136.9676023721695, 111.38753458857536, 104.9746111035347, 109.40394222736359, 104.65171962976456, 89.57388550043106, 107.39565879106522, 108.61575812101364, 105.38154646754265, 103.2302463054657, 108.18803787231445, 94.16036859154701, 97.62759894132614, 92.68972590565681, 91.41965165734291, 93.64980518817902, 89.31774884462357, 82.53440603613853, 89.86403793096542, 86.93648502230644, 76.62757739424706, 87.70206034183502, 66.73728570342064, 44.59288336336613, 48.00234541296959, 35.94860181212425, 43.32221254706383, 41.59433886408806, 38.58763240277767, 33.179743587970734, 21.322515942156315, 12.904774434864521, 10.823377221822739, 3.008044227026403, 1.3993452116847038, 1.2880820757709444, 0.8356005745008588, 1.3862005295231938, 10.446629337966442, 20.831000916659832, 34.17844779789448, 10.049487948417664, 4.652600018307567, 2.1353222569450736, 7.854634048417211, 2.138674152083695, 11.117236353456974, 46.38719268143177, 49.43724721670151, 6.6168219689279795, 28.127804473042488, 33.80351431667805, 9.423775523900986, 2.1816066233441234, 0.8861128671560436, 2.6782015012577176, 6.810668567195535, 3.489090339280665, 0.9903745225165039, 9.494944754987955, 39.99127708375454, 50.00134974718094, 42.10093528032303, 45.263752564787865, 45.66715031862259, 46.59795597195625, 32.4917297065258, 42.939500883221626, 53.87434512376785, 51.763907968997955, 74.271749407053, 84.23203334212303, 85.45933708548546, 85.21593734622002, 77.3926055431366, 87.076735496521, 85.47085046768188, 85.80288425087929, 82.8698368370533, 84.59329515695572, 85.39234668016434, 92.67444312572479, 94.66280043125153, 92.0457972586155, 94.27650555968285, 93.55740934610367, 93.62579807639122, 87.62450650334358, 87.70466700196266, 86.43681943416595, 90.22444859147072, 100.61008170247078, 47.723827958106995, 70.37011876702309, 73.12274426221848, 55.61339780688286, 52.85905480384827, 22.65364721417427, 0.5493994569405913, 1.3182847551070154, 0.3185751131968573, 0.38027688511647284, 0.3850419184891507, 0.8162760583218187, 0.5494334769900888, 0.19634163938462734, 0.16131397598655894, 0.46170693123713136, 0.36106755025684834, 0.16002180782379583, 0.23759022209560499, 0.4040936508681625, 0.4969286365667358, 0.29997748613823205, 0.1300908435950987, 0.14167933113640174, 0.2761467976961285, 0.17222483817022294, 0.08333858277183026, 0.26687001110985875, 0.36497228604275733, 0.37742950196843594, 0.1787177991354838, 0.08852322644088417, 0.22792112140450627, 0.5600285553373396, 0.28668758051935583, 0.4376125428825617, 0.24066396028501913, 0.2850090799620375, 0.1113725062168669], [0.16353577317204326, 0.05591265267867129, 0.12079734384315088, 0.12601652706507593, 0.07558344383141957, 0.06265452626394108, 0.08284740717499517, 0.14860597351798788, 0.04073877178598195, 0.05969695273961406, 0.0651091945474036, 0.07215184945380315, 0.07188119561760686, 0.2617534372257069, 0.11796990220318548, 0.11433280713390559, 0.38371629430912435, 0.205939048610162, 0.15416327922139317, 0.061180747143225744, 0.11162960843648762, 0.11021109705325216, 0.13980469579109922, 0.14518817566568032, 0.2083612108253874, 0.5201722565107048, 0.24818362318910658, 0.7502712844870985, 0.26415953936520964, 0.2374819724354893, 0.21048440627055243, 0.4375298082595691, 0.41009373671840876, 0.4206887853797525, 5.305737946182489, 15.348352063447237, 23.42049166560173, 18.060472682118416, 24.55074291676283, 23.485435880720615, 14.26831416785717, 24.056841619312763, 50.613177716732025, 73.74968022108078, 40.33598318696022, 103.63554775714874, 111.5045303106308, 98.83497655391693, 112.24925994873047, 99.86666679382324, 93.00668969750404, 102.06766828894615, 104.04807642102242, 104.89419981837273, 98.02055105566978, 103.96658599376678, 93.2252311706543, 98.242839127779, 87.27728113532066, 91.934584826231, 92.66346171498299, 85.50358191132545, 84.05292615294456, 78.91636177897453, 78.12735691666603, 73.43765616416931, 76.79674431681633, 28.394681252539158, 26.746021918952465, 26.54104571789503, 14.931734818965197, 24.99264780431986, 32.774730920791626, 32.36351698637009, 17.461349330842495, 16.809754595160484, 8.756058253347874, 3.4315291279926896, 0.6532901572063565, 1.7542619607411325, 1.2233582488261163, 0.24308653810294345, 0.8131799369584769, 0.6195340154226869, 2.4644271098077297, 1.0554903815500438, 7.309509599581361, 2.348601487465203, 0.4973384801996872, 1.1984949954785407, 1.414103026036173, 1.9435731461271644, 36.256848871707916, 23.119642809033394, 8.5243153385818, 1.9922665832564235, 12.795025873929262, 10.28468867763877, 11.243337336927652, 8.419725000858307, 2.9193517612293363, 2.4652514280751348, 1.3471305510029197, 1.8316699820570648, 3.4843439189717174, 32.9859159886837, 28.42426836490631, 32.424655705690384, 43.03184732794762, 38.51884089410305, 31.57660771161318, 25.074839293956757, 27.85471122711897, 32.79439106583595, 41.99944272637367, 42.42782413959503, 75.3393705189228, 76.05540409684181, 73.60041663050652, 80.9400799870491, 76.44429802894592, 79.3452599644661, 76.5519842505455, 74.70784440636635, 71.12070769071579, 68.70958507061005, 64.29522514343262, 63.04951138794422, 70.56913688778877, 79.41039606928825, 85.14498755335808, 83.01434308290482, 81.25748455524445, 94.29456979036331, 81.09429851174355, 99.2100240290165, 50.630937963724136, 36.1267514526844, 55.88473744690418, 25.83053894340992, 27.427635043859482, 8.583932239562273, 0.8490391471423209, 0.5127075570635498, 0.27616395615041256, 0.03673248051200062, 0.09025792984175496, 0.4620667838025838, 0.05318966832419392, 0.346060493029654, 0.1638581621227786, 0.21289657917805016, 0.022715932536812034, 0.052937085783923976, 0.40790502447634935, 0.15767141128890216, 0.21030306990724057, 0.08311243553180248, 0.19360485108336434, 0.03321401403809432, 0.14827355073066428, 0.10975790457450785, 0.10752330534160137, 0.07365976736764424, 0.004207743550068699, 0.14304316107882187, 0.04994954062567558, 0.11789630341809243, 0.18100860121194273, 0.06603255242225714, 0.06092356699809898, 0.16613165731541812, 0.07125749471015297, 0.21674584684660658, 0.2215023009921424, 0.12760677142068744, 0.05980972207908053, 0.10733723407611251, 0.16394435515394434, 0.14000973635120317, 0.048236652655759826, 0.037457707221619785, 0.16228436375968158, 0.0132405333170027, 0.06308950643870048, 0.08390400282223709, 0.0680147620732896, 0.050888847254100256, 0.14277288573794067, 0.21129763685166836, 0.4324082174571231, 0.18367007636697963, 0.1381580185261555, 0.16097417625132948, 0.09995450483984314, 0.03046332345547853, 0.08760998403886333, 0.08437310694716871, 0.25448941451031715, 0.1451282249763608, 0.4090619436465204, 0.24902783101424575, 0.11846366789541207, 0.5691331636626273, 0.8172314101830125, 0.3007647267077118, 0.10748450586106628, 0.3075980069115758, 0.2988078910857439, 1.4544777595438063, 9.86098576337099, 23.23031947016716, 38.57312098145485, 42.22629055380821, 32.54212260246277, 26.04729451239109, 23.23748018592596, 40.90375252068043, 63.067556619644165, 84.0599861741066, 52.77798235416412, 101.87535300850868, 124.93201419711113, 112.58096694946289, 105.54021075367928, 107.17226877808571, 108.96668449044228, 92.40766704082489, 101.97034031152725, 105.24182796478271, 103.51231276988983, 99.04185265302658, 98.57727438211441, 92.80831754207611, 96.03578835725784, 89.50233533978462, 92.80919909477234, 92.67232283949852, 89.6636214852333, 77.42695569992065, 78.74638929963112, 80.734533816576, 76.10378310084343, 38.21725867688656, 36.10160820186138, 38.87726046144962, 21.050125658512115, 32.31185495853424, 38.390198796987534, 35.07360376417637, 22.474025152623653, 24.62893322110176, 11.460826266556978, 4.09335695207119, 1.268860213458538, 1.7763645434752107, 2.2535942355170846, 0.4546983557520434, 0.8543830853886902, 2.1393783017992973, 4.635789720341563, 2.662624237127602, 14.055074360221624, 2.844923730008304, 0.3168018552241847, 2.2211064537987113, 2.890637652017176, 3.890901915729046, 42.10128106176853, 44.23083119094372, 14.372881706804037, 0.910277848597616, 37.90749169886112, 15.59956893324852, 16.07425846159458, 12.271013092249632, 5.7425430323928595, 3.720862939953804, 1.2513674958609045, 2.0953410398215055, 7.791295247152448, 39.43819396197796, 27.098908983170986, 37.13460937142372, 42.79176861047745, 38.680298030376434, 43.41862477362156, 29.088096544146538, 39.33998063206673, 48.290176168084145, 53.13072122633457, 51.39551393687725, 73.35910677909851, 84.0288582444191, 73.58303636312485, 86.0193282365799, 81.41225785017014, 88.16890329122543, 79.60171580314636, 79.30061995983124, 72.36157670617104, 71.9966746866703, 67.24771991372108, 65.2796459197998, 71.02568998932838, 84.21109646558762, 87.0603659749031, 83.11607122421265, 82.53735467791557, 94.4279046356678, 84.91578385233879, 103.49915027618408, 49.25814002752304, 51.043926402926445, 63.980016857385635, 41.37076646089554, 40.52600719034672, 8.462168723344803, 1.937842934858054, 1.3563264138065279, 0.43589280860032886, 0.07840062156901695, 0.004862418454649742, 0.2473586518317461, 0.19870281190378591, 0.3065733681432903, 0.13917428586864844, 0.340678408392705, 0.09062729674042203, 0.08814772198093124, 0.22601205040700734, 0.10715609809267335, 0.26335021248087287, 0.20192564756143838, 0.031026325959828682, 0.046378507831832394, 0.11648985935607925, 0.07053648339933716, 0.06643117478233762, 0.008766679729887983, 0.01966730491403723, 0.04409678964293562, 0.01638086720049614, 0.038042775631765835, 0.06948925365577452, 0.03016421938809799, 0.010098186357936356, 0.22571563662495464, 0.29970048693940043, 0.10674435456166975, 0.0727290399663616, 0.12760447076288983, 0.24549581663450226, 0.2025281824171543, 0.29218846815638244, 0.4365443845745176, 0.24068101483862847, 0.16951907164184377, 0.2777565160067752, 0.25699932826682925, 0.1593269794830121, 0.12860573187936097, 0.3230557555798441, 0.16319460788508877, 0.2712595771299675, 0.5055793770588934, 0.5969151353929192, 0.21953773219138384, 0.35696501727215946, 0.35509715031366795, 0.13175935484468937, 0.10653565521351993, 0.1951752949389629, 0.15283939166693017, 0.3668902924982831, 0.48210391018074006, 1.032259853091091, 0.5237574235070497, 0.1912499571335502, 1.0742408316582441, 0.7012323627714068, 0.24390953534748405, 0.1676199008943513, 0.5475225357804447, 0.36400042881723493, 0.5977193266153336, 8.592279441654682, 24.104555658996105, 47.40454629063606, 48.11356544494629, 38.39073836803436, 34.55026164650917, 38.37314151227474, 57.69227385520935, 76.36644020676613, 103.03774103522301, 72.41269156336784, 124.73558753728867, 123.4583468735218, 108.87822523713112, 105.17708703875542, 111.8962436914444, 98.40021908283234, 97.01424345374107, 111.52878060936928, 113.05043935775757, 106.12715005874634, 103.64293456077576, 98.44154566526413, 100.27467370033264, 96.72315627336502, 93.61306875944138, 97.18289360404015, 94.54274207353592, 89.69553217291832, 79.52253565192223, 81.83646708726883, 83.97872373461723, 78.27446222305298, 47.2070936858654, 44.054136872291565, 45.919300988316536, 24.44321058690548, 42.37698286771774, 42.64333717525005, 44.689344987273216, 25.411379635334015, 33.468908071517944, 19.52129289507866, 10.888561774045229, 0.7427230488974601, 3.1169812940061092, 3.0611406778916717, 0.5005602620076388, 1.1038944404572248, 4.178251046687365, 8.163215015083551, 4.465261045843363, 15.782154835760593, 6.0823592729866505, 0.7547659683041275, 3.522747508250177, 2.9929181886836886, 8.971481993794441, 44.13169451057911, 70.84668919444084, 23.09924740344286, 1.6150421812199056, 58.00648659467697, 20.016229636967182, 29.23072949051857, 18.780017271637917, 12.031868174672127, 4.113114941865206, 1.751817623153329, 2.651638789102435, 10.897168312221766, 51.09172783792019, 38.671577498316765, 43.1253907084465, 55.05567133426666, 49.98118042945862, 46.277108788490295, 38.19986701011658, 43.31075616180897, 48.32132309675217, 61.6656294465065, 59.94964152574539, 82.25832805037498, 83.98104161024094, 82.43928954005241, 85.0416710972786, 81.51970088481903, 88.81093963980675, 85.87114378809929, 81.5679506957531, 76.24659463763237, 75.91155901551247, 74.94641840457916, 71.71569496393204, 78.6194609105587, 86.64659097790718, 94.72033694386482, 89.29900825023651, 82.04465791583061, 90.23232936859131, 81.97660356760025, 103.99874746799469, 65.56659892201424, 53.77710074186325, 79.17451232671738, 56.87507450580597, 61.09708875417709, 38.975439593195915, 5.45772741548717, 2.1897709602490067, 1.359429897274822, 0.4695768136298284, 0.13598009711131454, 0.7946386537514627, 0.45326167659368366, 0.29169488057959825, 0.36143711011391133, 0.6006619718391448, 0.16845512873260304, 0.16267397644696757, 0.44478035357315093, 0.23927880101837218, 0.23707842221483588, 0.3464924526633695, 0.2963765856111422, 0.22850010049296543, 0.37144345755223185, 0.17659393575740978, 0.27282815077342093, 0.18536534946179017, 0.16368631040677428, 0.1885243455762975, 0.32122820208314806, 0.1601431192830205, 0.24776330043096095, 0.1537157196435146, 0.17661299410974607, 0.637082364410162, 0.42582269583363086, 0.15114882378838956, 0.25134169904049486, 0.17235906299902126], [0.2339296232094057, 0.19859425054164603, 0.06608801311813295, 0.06346772715914994, 0.06645510904490948, 0.08765771155594848, 0.053117895222385414, 0.0971172223216854, 0.04348554568423424, 0.0483441972755827, 0.1265585917280987, 0.08912282239180058, 0.1310201609157957, 0.10978464415529743, 0.15122939134016633, 0.10349862364819273, 0.054511166163138114, 0.19816555635770783, 0.13641005294630304, 0.10520882133278064, 0.021469540042744484, 0.07770762633299455, 0.09878681710688397, 0.36407538573257625, 0.44795386609621346, 0.09414044572622515, 0.1445033960044384, 0.46420773142017424, 0.23768380691763014, 0.1904123544227332, 0.013700562831218122, 0.06247090408578515, 0.20435852638911456, 0.5731738905888051, 0.7508210674859583, 3.543862975202501, 11.855520587414503, 12.042475305497646, 14.283785037696362, 31.64864044636488, 13.120936285704374, 19.40481584519148, 28.926817998290062, 74.68577519059181, 59.85882639884949, 55.73661759495735, 131.95407539606094, 106.65837675333023, 107.78603464365005, 109.9190653860569, 96.94417521357536, 91.33433103561401, 93.8335557281971, 91.20223492383957, 90.88255807757378, 91.02309733629227, 96.65741220116615, 97.21033573150635, 100.18689081072807, 92.13979661464691, 97.34842032194138, 81.47905066609383, 75.1411047577858, 82.6209881901741, 70.69068476557732, 71.11715868115425, 43.89521040022373, 23.981123082339764, 23.997089825570583, 13.019259441643953, 25.33336602151394, 21.500496491789818, 23.59546657651663, 17.41416346281767, 20.985358133912086, 20.098005048930645, 7.510309349745512, 1.554738823324442, 0.24148191092535853, 1.342184878885746, 0.26714867271948606, 0.26976251683663577, 0.3700152982492, 0.10113940297742374, 0.26364062970969826, 0.9916295239236206, 9.237281531095505, 1.8916973797604442, 0.4167032445548102, 0.8347720408346504, 0.7642776891589165, 0.24840411526383832, 14.092236366122961, 27.638740316033363, 8.078733198344707, 9.768437929451466, 7.934384644031525, 2.0320119755342603, 0.6852948304731399, 0.5356954329181463, 0.9786706755403429, 0.5242633307352662, 2.0437770942226052, 3.3327144803479314, 4.926997544243932, 20.018386021256447, 35.55222608149052, 29.212830550968647, 26.51943437755108, 35.751270800828934, 23.64202357828617, 24.757820405066013, 28.51233433932066, 25.65727014094591, 35.78390724956989, 41.45544491708279, 43.5702708363533, 80.65554365515709, 79.35116484761238, 68.14263269305229, 83.6368028819561, 82.4082300066948, 70.28357461094856, 69.31378304958344, 57.65511944890022, 53.735823556780815, 45.35501606762409, 48.932945877313614, 55.072850212454796, 65.06323993206024, 70.900509506464, 77.95312866568565, 90.73588594794273, 83.44822660088539, 104.64528277516365, 70.61436206102371, 30.30926551669836, 53.66887494921684, 30.20927768200636, 34.12986360490322, 15.330843552947044, 4.767050351947546, 0.5673483281861991, 0.619513294659555, 0.23793597385520115, 0.18349590915022418, 0.37780583021230996, 0.3966014919569716, 0.19887968053808436, 0.05409631674410775, 0.09901484940201044, 0.04251446771377232, 0.0716552190715447, 0.20312495820689946, 0.3375249932287261, 0.6340737571008503, 0.45253544056322426, 0.14486384228803217, 0.07875173905631527, 0.1012489439744968, 0.17672462796326727, 0.07446845600497909, 0.060869983935845084, 0.04047123497002758, 0.14716264471644536, 0.09691008148365654, 0.0933366478420794, 0.11874952833750285, 0.015914523864921648, 0.04873771365964785, 0.07442309593898244, 0.15331994713051245, 0.07231451338157058, 0.12313733546761796, 0.15979143034201115, 0.15496922191232443, 0.02035965819231933, 0.15811444376595318, 0.05749800257035531, 0.047548507354804315, 0.06129548688477371, 0.03069630402023904, 0.0084922400128562, 0.07439012231770903, 0.01333541504209279, 0.005180614734854316, 0.10245921614114195, 0.08520028248312883, 0.09707548393635079, 0.12659373984206468, 0.058984932547900826, 0.06156812967674341, 0.09782217355677858, 0.18225546868052334, 0.16828762600198388, 0.020381683279993013, 0.04517970184679143, 0.09462019224883988, 0.12070214113919064, 0.156728275178466, 0.2603722410276532, 0.4627282154979184, 0.1136867972672917, 0.08371551957679912, 0.6644159008283168, 0.3855954419123009, 0.04053356795338914, 0.05248407513136044, 0.07912592249340378, 0.10866981960134581, 1.7476665833964944, 6.980312839150429, 16.842890717089176, 33.254683166742325, 33.643250316381454, 26.42374601215124, 23.61689742654562, 28.979447074234486, 50.54739184677601, 79.70526024699211, 77.2361071407795, 58.827854320406914, 137.27856248617172, 115.90618371963501, 118.00771415233612, 101.53266459703445, 115.54139569401741, 94.36718389391899, 91.20818540453911, 90.04273474216461, 95.91831386089325, 89.50807303190231, 97.68600940704346, 93.26246917247772, 103.47496077418327, 98.60559046268463, 90.20091265439987, 86.95095464587212, 84.44854572415352, 84.26735624670982, 69.6793994307518, 80.6101056933403, 49.910766407847404, 34.08208876848221, 36.71767294406891, 23.8716072589159, 30.59850599616766, 33.252144902944565, 33.46845969557762, 23.74268777668476, 23.29040564596653, 23.26436374336481, 13.101425282657146, 2.119597988203168, 0.22006116894772276, 1.6458689770661294, 0.0357495838397881, 0.39082464412786067, 0.3106488869525492, 0.49804031441453844, 0.6172296172007918, 2.1035994216799736, 12.587605454027653, 6.321455743163824, 0.6928188423626125, 0.620953714242205, 1.9801675574854016, 3.339103600010276, 21.137319579720497, 48.64986106753349, 8.37900448590517, 8.440161254256964, 21.39145754277706, 0.9005014481954277, 0.9302147256676108, 0.4154401982668787, 2.291770074516535, 0.6365408340934664, 1.8716335063800216, 5.572797115892172, 13.714722823351622, 27.529783062636852, 28.482334949076176, 20.026582181453705, 31.31522923707962, 41.26227468252182, 33.076354935765266, 35.63163802027702, 31.01050838828087, 44.60126951336861, 51.01688705384731, 56.2469682097435, 52.52513252198696, 82.95239880681038, 88.81017208099365, 74.65187340974808, 90.79162135720253, 82.9928058385849, 75.68592712283134, 71.53800889849663, 64.88993883132935, 60.200743451714516, 52.021720334887505, 56.46238625049591, 60.33098146319389, 67.77783706784248, 72.64863610267639, 79.2606309056282, 85.15685051679611, 84.85134690999985, 109.64386895298958, 67.30112984776497, 39.12936553359032, 64.46871623396873, 44.24574539065361, 46.97250187397003, 21.23618457466364, 2.760384203866124, 1.5111667988821864, 0.024738962165429257, 0.15478378889383748, 0.1521911850431934, 0.46486239472869784, 0.47276463476009667, 0.2553150389576331, 0.10217904055025429, 0.1940276674577035, 0.11583723695366643, 0.08544619311578572, 0.19932345516281202, 0.3400504920864478, 0.4307040979620069, 0.5932048126123846, 0.13469852681737393, 0.024538695470255334, 0.1261866866843775, 0.03931485756766051, 0.08390392860746942, 0.08741909623495303, 0.09236139900167473, 0.19155275338562205, 0.10430930866277777, 0.09635966023779474, 0.05689128200174309, 0.07064425066346303, 0.09426216536667198, 0.06887356052175164, 0.10399023711215705, 0.17159894050564617, 0.08500856347382069, 0.059327827038941905, 0.4204923240467906, 0.20219249418005347, 0.4044569469988346, 0.15010891162091866, 0.13184465729864314, 0.16279367002425715, 0.19509842328261584, 0.14834543515462428, 0.19186522724339738, 0.13437125453492627, 0.10148585235583596, 0.19693464506417513, 0.1516172377159819, 0.25534306245390326, 0.23017114988761023, 0.4758571938145906, 0.28002885344903916, 0.14761913975235075, 0.37977753847371787, 0.3471754363272339, 0.18585576064651832, 0.1863636271446012, 0.14051458972971886, 0.2702307526487857, 0.545265635009855, 0.6180977518670261, 0.7129949878435582, 0.1766275253612548, 0.5083560186903924, 1.0913577256724238, 0.3502556757302955, 0.08820344984997064, 0.1698075741296634, 0.24470502859912813, 0.5918317206669599, 1.2947261380031705, 6.186448037624359, 19.745805747807026, 32.212729677557945, 39.089273884892464, 55.41972979903221, 35.09244315326214, 48.05507518351078, 63.598308339715004, 102.05820679664612, 93.30805152654648, 82.3139114677906, 150.45134603977203, 111.03602305054665, 107.96433627605438, 107.62376815080643, 112.75460243225098, 90.46021074056625, 101.83153375983238, 100.80762550234795, 100.56957587599754, 97.30314955115318, 102.26869270205498, 94.95633468031883, 105.70051655173302, 97.27626979351044, 94.87362071871758, 92.04514369368553, 84.30891841650009, 84.84848946332932, 79.51944261789322, 86.14646181464195, 58.2144608348608, 42.678720876574516, 38.854708671569824, 28.763377368450165, 39.51442547142506, 39.88064222037792, 33.83300453424454, 33.44173192977905, 33.341789692640305, 35.92725835740566, 25.82964789122343, 3.9765877928584814, 0.26895995833911, 2.999726473353803, 0.17891595256514847, 1.0317683732137084, 0.31025557836983353, 1.3243601541034877, 0.7291141385212541, 3.04707502014935, 17.759095653891563, 11.017638947814703, 0.8208086807280779, 1.592577074188739, 2.289537931792438, 6.896975710988045, 25.589263290166855, 62.09512419998646, 21.41156606376171, 24.183789007365704, 30.277147740125656, 1.473435654770583, 1.8379459390416741, 0.3664964495692402, 3.1792858382686973, 1.1561617045663297, 4.939293684437871, 7.023322731256485, 22.36653082072735, 44.06554765999317, 50.00676445662975, 31.600137948989868, 36.95938937366009, 48.14310126006603, 36.107725873589516, 36.63158096373081, 38.45099553465843, 39.81851555407047, 53.09549331665039, 57.75742515921593, 61.97445027530193, 93.16908538341522, 86.75249129533768, 73.11398193240166, 90.46315938234329, 89.08459335565567, 79.21348303556442, 76.05305582284927, 66.28324046730995, 65.4731847345829, 62.43059299886227, 63.4622148424387, 65.27540534734726, 77.1663048863411, 82.77715221047401, 79.75756824016571, 84.07067880034447, 83.64643156528473, 112.59859800338745, 85.24301469326019, 49.307100400328636, 72.13633239269257, 62.29228042066097, 60.38625709712505, 52.52546690404415, 16.93255640566349, 1.3504433794878423, 1.541438705753535, 0.48868958023376763, 0.44035026628989726, 0.37781939667183906, 0.31497994204983115, 0.42070457828231156, 0.25021930458024144, 0.2954927471000701, 0.19674990966450423, 0.17260558961424977, 0.2645597350783646, 0.5675830249674618, 0.47697258240077645, 0.714704777346924, 0.539817736716941, 0.13238011684734374, 0.29789739463012666, 0.34975819929968566, 0.22339724149787799, 0.17537494335556403, 0.15350566216511652, 0.37164968554861844, 0.3368037147447467, 0.2721603662939742, 0.17608679656405002, 0.20423611655132845, 0.17650631780270487, 0.11235818223212846, 0.4076200694544241, 0.5492320284247398, 0.2646533941151574, 0.1549428459838964, 0.585248633287847], [0.16066055948613212, 0.13539488398237154, 0.13604120555100963, 0.1282164012081921, 0.047628919055568986, 0.06075680641515646, 0.03392430873645935, 0.03913691652996931, 0.040600090360385366, 0.03636052722868044, 0.044529075821628794, 0.039437582818209194, 0.08579951478168368, 0.06668531583272852, 0.0212479959736811, 0.08130336893373169, 0.0351204838079866, 0.08841362607199699, 0.11948278508498333, 0.09822997628361918, 0.0559866373805562, 0.06817278015660122, 0.38735902227927, 0.1866154675371945, 0.5033632647246122, 0.658246991224587, 0.11226644535781816, 0.009408766418346204, 0.16317728615831584, 0.21113503229571506, 0.3777325653936714, 0.5257373547647148, 0.21744438592577353, 0.4539600672433153, 0.30684128345455974, 0.22897031041793525, 2.0201630238443613, 6.230608318001032, 2.668483522720635, 9.197487216442823, 18.52854296565056, 8.894405979663134, 30.992919132113457, 32.78416581451893, 69.40374702215195, 34.44951385259628, 78.70319321751595, 132.39337742328644, 99.22977536916733, 113.64401310682297, 109.98625338077545, 83.82808461785316, 70.26698470115662, 64.9609038233757, 60.10575994849205, 56.27974145114422, 61.355915665626526, 75.71848377585411, 87.62324497103691, 91.13047957420349, 84.53782573342323, 94.14412826299667, 85.1100142300129, 64.3920287489891, 70.50251886248589, 62.47921898961067, 24.137929268181324, 28.13975863158703, 18.955241069197655, 22.07639928907156, 14.421515297144651, 12.518155630677938, 21.52851238846779, 24.07421238720417, 26.747623533010483, 17.081521712243557, 6.118939910084009, 2.7945436583831906, 0.9206366864964366, 0.5508439138066024, 0.23867123440140858, 1.1416873312555254, 0.08178101517842151, 0.7894955109804869, 0.561999996425584, 0.7217194384429604, 3.1993383122608066, 5.029769679531455, 0.2590427576797083, 1.2314210599288344, 0.4819751327158883, 1.9647549907676876, 4.440920976921916, 14.178044311702251, 15.032227076590061, 5.282499343156815, 0.44036968087311834, 0.400870117591694, 0.82285754266195, 0.551245742244646, 0.5157786828931421, 1.5636284463107586, 1.816152089741081, 6.731631383299828, 7.473313109949231, 13.27985705807805, 19.443896748125553, 25.4786816239357, 25.436986461281776, 28.091115541756153, 24.97825227677822, 17.52813834697008, 27.65160832554102, 32.747015208005905, 45.766799971461296, 59.610779508948326, 48.31630356609821, 40.64912438392639, 79.40535753965378, 93.7822736799717, 76.30125090479851, 62.94424183666706, 71.3040554523468, 62.62549214065075, 50.82598149776459, 44.85166847705841, 42.51742333173752, 44.578911513090134, 50.91089554131031, 54.68086704611778, 62.991047725081444, 74.51799139380455, 79.60179939866066, 96.22142359614372, 73.37636545300484, 31.58772211521864, 50.17623156309128, 42.31274351477623, 43.761430978775024, 31.39391541481018, 10.295505747199059, 1.5189681365154684, 0.7907868479378521, 0.24607515195384622, 0.0693719794799108, 0.25312885001767427, 0.6753743346780539, 0.6233221152797341, 0.4518977872794494, 0.1435343737830408, 0.10420054692076519, 0.06323033638182096, 0.05772729651653208, 0.15757577813928947, 0.268909017322585, 0.5936797871254385, 0.16045737429521978, 0.0455110893381061, 0.051554590827436186, 0.013537719860323705, 0.035321427712915465, 0.1698348406353034, 0.07797381244017743, 0.05477937091200147, 0.16525356302736327, 0.05812670926388819, 0.018238212360301986, 0.07035300965071656, 0.024493942109984346, 0.06967680921661668, 0.05201780229981523, 0.020298104464018252, 0.21749722684035078, 0.11336664960253984, 0.09843089792411774, 0.26171858597081155, 0.12200361583381891, 0.12486876599723473, 0.03668176585051697, 0.09910771434078924, 0.10446550106280483, 0.13438403431791812, 0.07361310854321346, 0.022690174446324818, 0.03928552418074105, 0.04681977770815138, 0.027083983695774805, 0.05209543836826924, 0.043839787613251247, 0.10893795755691826, 0.12430612157913856, 0.06589132171939127, 0.03209453992894851, 0.10970481132972054, 0.1973618401098065, 0.05324836107320152, 0.06527495323098265, 0.05569310684222728, 0.2718370273942128, 0.3501502313883975, 0.330803896067664, 0.5357064167037606, 0.11706601828336716, 0.03462737120571546, 0.06448516709497198, 0.36150639702100307, 0.5216732353437692, 0.25306024588644505, 0.3169041231740266, 0.2382938819937408, 0.28528162627480924, 1.030740172136575, 3.1077774753794074, 6.474518179893494, 12.475830651819706, 9.698403887450695, 13.292119950056076, 12.34164560213685, 36.2159288674593, 52.94439822435379, 80.91107994318008, 49.68854673206806, 76.43419057130814, 141.60244166851044, 106.92071467638016, 113.13165619969368, 110.17543002963066, 95.14928832650185, 76.19722008705139, 70.38704305887222, 67.37698897719383, 61.96351446211338, 65.9078586101532, 76.36674419045448, 87.01796784996986, 95.56877061724663, 88.91922622919083, 93.27730357646942, 92.33344182372093, 71.48347422480583, 81.88828110694885, 59.0414522588253, 37.52851523458958, 42.430271208286285, 38.49040322005749, 31.353658474981785, 19.56197541207075, 26.163009703159332, 29.117290377616882, 28.083878830075264, 23.442809768021107, 13.829573560506105, 14.166808314621449, 1.7322460608556867, 0.8643973292782903, 1.7528239754028618, 0.27088458475191146, 0.6554944545496255, 0.30670348147396, 0.5448830430395901, 0.43596518284175545, 0.8336233149748296, 3.1404692586511374, 6.289401613175869, 1.9706525118090212, 0.7882669300306588, 0.2827652409905568, 1.5657604881562293, 10.351138561964035, 23.774121589958668, 25.1677880063653, 8.230042979121208, 1.3372618868015707, 0.22491616546176374, 0.9387444367166609, 0.20971316640498117, 0.7120186183601618, 1.8677928624674678, 1.9385669147595763, 8.079944383352995, 19.97739002108574, 25.600717775523663, 27.887740954756737, 24.68242485076189, 22.658111974596977, 26.588666662573814, 32.13235639035702, 37.48674027621746, 38.221723437309265, 44.343308955430984, 64.48688685894012, 76.62858814001083, 65.99132493138313, 42.72597514092922, 77.96442165970802, 99.4256092607975, 82.81086400151253, 71.0265639424324, 77.16585651040077, 67.21542164683342, 60.849653631448746, 52.83784434199333, 52.48095229268074, 53.22306387126446, 58.69623318314552, 58.23437176644802, 68.1272891163826, 75.45023337006569, 84.81689035892487, 104.56250041723251, 68.79730716347694, 41.10684782266617, 62.4248781055212, 52.61451132595539, 54.18976619839668, 36.324147060513496, 7.8720917366445065, 1.3717455114237964, 1.5020349388942122, 0.31949193275067955, 0.1406543658231385, 0.19633386167697608, 0.43082696793135256, 0.542456042021513, 0.33888425154145807, 0.1450299349380657, 0.0424953945184825, 0.10469879518495873, 0.11420805210946128, 0.22571879817405716, 0.3578432748327032, 0.5589744087774307, 0.09537404359434731, 0.09336760282167234, 0.04622342123184353, 0.010233935372525593, 0.04954273237672169, 0.11290092224953696, 0.057640261147753336, 0.04407668486237526, 0.13193426420912147, 0.07727491713012569, 0.051201974201831035, 0.04844819814024959, 0.11838494829135016, 0.06351158808683977, 0.0006902358961724531, 0.05369302256440278, 0.35342550720088184, 0.06107554771006107, 0.0857455309596844, 0.1521983987186104, 0.229401498218067, 0.2128504918073304, 0.2649044478312135, 0.20014277135487646, 0.22845365689136088, 0.16906198288779706, 0.16317498550051823, 0.1784735731780529, 0.21303519752109423, 0.16305661294609308, 0.12760214041918516, 0.13230665907030925, 0.21483000746229663, 0.20088068878976628, 0.23313985933782533, 0.23936625570058823, 0.15781133581185713, 0.3082719066878781, 0.39306913618929684, 0.08802059208392166, 0.1091943250503391, 0.16753957082983106, 0.34914034651592374, 0.38040690938942134, 0.624935959931463, 0.9424553532153368, 0.3453972504939884, 0.2238438808126375, 0.3399956622160971, 0.6674126931466162, 0.36984240752644837, 0.308893826440908, 0.183182826731354, 0.37272199988365173, 0.365489533287473, 0.8719465741887689, 4.1088292468339205, 8.689008001238108, 8.789702598005533, 13.117900248616934, 42.39748656749725, 38.23524311184883, 60.52720293402672, 69.32512924075127, 103.17891106009483, 64.68236356973648, 98.77753123641014, 142.29722678661346, 104.90553081035614, 114.15076911449432, 114.00125473737717, 94.78104248642921, 76.75655007362366, 81.23568892478943, 77.2042116522789, 69.78617370128632, 72.67972603440285, 82.83366277813911, 93.94822597503662, 101.47487729787827, 91.70967489480972, 97.53308281302452, 95.56799545884132, 73.27696278691292, 77.88178369402885, 71.32979527115822, 42.250689044594765, 48.974964022636414, 39.21554870903492, 37.47546628117561, 27.50365376472473, 28.137670643627644, 34.46454584598541, 39.967820942401886, 38.144830763339996, 27.030681744217873, 24.45464037358761, 8.179973065853119, 1.3039001519791782, 3.600603430531919, 0.17740443523507565, 1.7898452701047063, 0.9518546238541603, 1.5310086216777563, 0.6938895536586642, 0.8827254083007574, 5.760253882035613, 9.27768001332879, 5.345394993200898, 2.1364237228408456, 1.9439785368740559, 2.727083503268659, 13.86501805856824, 31.95675641298294, 32.625478729605675, 11.786235105246305, 1.5199236664921045, 0.3889521461678669, 1.0478214430622756, 0.6423533940687776, 1.3397847139276564, 3.855597535148263, 4.011159762740135, 9.336992930620909, 34.0612430870533, 45.391239523887634, 45.11694744229317, 50.79549193382263, 42.07258880138397, 41.981291100382805, 40.56599244475365, 37.550740242004395, 43.741691038012505, 44.29859675467014, 63.45882162451744, 83.42329233884811, 70.65458670258522, 56.16993114352226, 87.42196977138519, 98.09720054268837, 88.63135367631912, 76.53764382004738, 79.30712521076202, 67.79419139027596, 66.32072925567627, 62.027909606695175, 59.32542622089386, 58.18243995308876, 66.93008735775948, 68.11607971787453, 72.20022976398468, 76.49236544966698, 78.48118633031845, 103.27750816941261, 91.41044095158577, 50.10638751089573, 63.31697903573513, 67.34333798289299, 61.96019724011421, 60.14983378350735, 29.597373716533184, 2.408411465585232, 1.616676093544811, 0.8940612094011158, 0.23328459297772497, 0.16167178022442386, 0.3845151123823598, 0.5147111776750535, 0.2822959958575666, 0.4045239184051752, 0.22863215825054795, 0.12331559191807173, 0.15655853116186336, 0.21285521186655387, 0.44095309800468385, 0.6401950505096465, 0.4014210286550224, 0.22248071880312636, 0.2227129219681956, 0.0765121154836379, 0.14856531866826117, 0.20079688547411934, 0.21561024215770885, 0.1641835641930811, 0.16407108429120854, 0.23079400474671274, 0.1170297346834559, 0.154417167941574, 0.15713568456703797, 0.12896252679638565, 0.139924033137504, 0.15503335831454024, 0.309792032931, 0.26868569024372846, 0.15654520218959078, 0.26439254404976964], [0.2212966518709436, 0.02665471620275639, 0.11656835631583817, 0.0921539835690055, 0.048265915538650006, 0.04289205760869663, 0.14443134830798954, 0.04442451834620442, 0.02228823839686811, 0.02794863212329801, 0.07764799476717599, 0.0942004557873588, 0.16706750553566962, 0.23847976030083373, 0.18153613462345675, 0.07308743792236783, 0.0379821199021535, 0.12966369307832792, 0.1824066590052098, 0.12302716364501975, 0.007747438694423181, 0.03413089296373073, 0.1349176830262877, 0.5076994257979095, 0.3179876587819308, 0.45103677723091096, 0.2522135741310194, 0.06464293284807354, 0.2806279150536284, 0.379151136148721, 0.41766037757042795, 0.2681932010455057, 0.81357701565139, 0.19160549039952457, 0.45351068198215216, 0.10321884881705046, 0.580673263175413, 1.3058129930868745, 7.247267039492726, 0.46914004487916827, 6.5109938476234674, 4.3786252196878195, 10.82829985767603, 29.090368822216988, 39.4191949814558, 66.24648123979568, 38.30888316035271, 98.3081728219986, 122.61467054486275, 93.57092142105103, 97.25624486804008, 91.67616829276085, 71.64892494678497, 61.40637315809727, 51.10544130206108, 53.32159258425236, 50.43834529817104, 61.66500248014927, 63.37193548679352, 79.39938426017761, 82.46570572257042, 78.4612450003624, 71.49945616722107, 79.08615946769714, 60.985861122608185, 21.18322491645813, 30.894056037068367, 36.2225367128849, 24.34215310961008, 14.241025932133198, 14.968471247702837, 22.64285199344158, 29.67453047633171, 21.79852779954672, 14.916925113648176, 8.03153308108449, 7.431431282311678, 5.421625077724457, 0.26919527852442116, 1.1918078293092549, 0.1519142452161759, 1.3610679656267166, 0.47381088486872613, 0.4692220373544842, 0.9371570125222206, 0.7099065254442394, 0.3465266211424023, 0.713830942986533, 0.07704851013841107, 0.4061897430801764, 0.6857741985004395, 1.114981414284557, 0.8683073788415641, 8.484767060726881, 16.5640027821064, 0.805331279989332, 0.584247624501586, 0.18570912710856646, 0.4369636089541018, 0.6114645546767861, 1.2329781451262534, 0.5377095029689372, 4.898565569892526, 7.061221422627568, 7.026018211618066, 12.11333580315113, 10.325011163949966, 19.638159424066544, 25.152866207063198, 17.414467446506023, 8.105178829282522, 12.08749433979392, 18.45700040459633, 27.335453890264034, 33.669807091355324, 35.86783714592457, 51.58674247562885, 42.26419731974602, 38.99405859410763, 55.1693232357502, 83.45103085041046, 94.9097491800785, 78.98850470781326, 69.33832973241806, 51.562955752015114, 48.36750961840153, 50.89906297624111, 54.86063539981842, 60.08724734187126, 65.36649405956268, 77.57947191596031, 86.27908989787102, 96.54461905360222, 63.07322211563587, 33.96483466029167, 50.851345136761665, 44.94974121451378, 45.04059433937073, 40.290366634726524, 19.57751277834177, 4.481302360072732, 0.16382396395783871, 0.2977577521232888, 0.3133547870675102, 0.24643982847919688, 0.3356234624516219, 0.4224046308081597, 0.1767782703973353, 0.11697916474076919, 0.011739760429918533, 0.03269783919677138, 0.05006537132430822, 0.20827843167353421, 0.2330842279479839, 0.21716602117521688, 0.16196742217289284, 0.2787836780771613, 0.11102736301836558, 0.048847425350686535, 0.08632897777715698, 0.05285128609102685, 0.08351728451089002, 0.03711148048751056, 0.13145287754014134, 0.08279514513560571, 0.11818775223218836, 0.010814534198289039, 0.09842006998951547, 0.08131784823490307, 0.047200699846143834, 0.14221050107153133, 0.2879945916356519, 0.1272002822952345, 0.18919552909210324, 0.036292127188062295, 0.17991828237427399, 0.20198944257572293, 0.12347655632765964, 0.06317396284430288, 0.005185652989894152, 0.07817542427801527, 0.06494823755929247, 0.031207929496304132, 0.013192059013817925, 0.11722894938429818, 0.06800133662181906, 0.08025015747989528, 0.08787610335275531, 0.16540650482056662, 0.2533622703049332, 0.1909481850452721, 0.04224832613545004, 0.11653387613478117, 0.11432800543843769, 0.0700761069310829, 0.24444297625450417, 0.06152636531624012, 0.08103195810690522, 0.1059838016226422, 0.497147748246789, 0.5588933068793267, 0.3851476893760264, 0.2501283766468987, 0.03286782812210731, 0.1321631870814599, 0.2930579090025276, 0.6020310265012085, 0.2440726148779504, 0.6751950911711901, 0.2965070848586038, 0.3459894546540454, 0.02121110010193661, 0.3205420123413205, 0.7033833442255855, 5.592048782855272, 11.184453796595335, 4.9121099431067705, 19.177132062613964, 7.634334219619632, 34.498728811740875, 60.40035054087639, 79.6991577744484, 51.62975996732712, 94.53633561730385, 134.66612666845322, 98.54840353131294, 96.42856568098068, 93.64059448242188, 83.74556824564934, 64.23264250159264, 58.49010184407234, 58.24788764119148, 59.896178394556046, 67.31017336249352, 69.68082055449486, 77.32061460614204, 88.74808341264725, 77.74306833744049, 74.08967077732086, 88.08770924806595, 63.67827124893665, 32.55318000912666, 51.82941645383835, 51.931330785155296, 36.69534154236317, 18.633257746696472, 22.229331582784653, 18.40819012373686, 29.14508778601885, 33.46866488456726, 19.33106940239668, 16.087614744901657, 11.103022266179323, 3.079696032218635, 0.9725464135408401, 1.9937675027176738, 1.0787304094992578, 0.8126946911215782, 0.047516880731564015, 0.41567326232325286, 0.8546999527607113, 0.7304510730318725, 0.36857781757134944, 2.176356017589569, 0.37897459405940026, 0.48167714558076113, 0.3742261847946793, 0.5054646707139909, 3.2306094467639923, 10.21168889477849, 23.0580348148942, 0.9126240445766598, 0.4206941882148385, 0.04266111980541609, 0.24572384892962873, 0.5192486091982573, 0.7201674592215568, 0.10208297695498914, 4.892793204635382, 9.367563240230083, 17.624020501971245, 29.72624760121107, 8.321432825177908, 18.80547970533371, 29.224818907678127, 25.233283191919327, 11.388989221304655, 14.52685609459877, 28.630555495619774, 33.143873512744904, 44.55480940639973, 53.987856432795525, 73.71143907308578, 61.5877678245306, 50.4997082054615, 60.45552358031273, 91.41525909304619, 104.56715896725655, 89.39577385783195, 84.54353302717209, 62.70318657159805, 60.584731847047806, 58.41870367527008, 61.96588173508644, 68.85113507509232, 72.43112817406654, 81.27472802996635, 91.33113160729408, 104.29842218756676, 61.034490913152695, 42.06859141588211, 56.39370873570442, 49.20953303575516, 53.29464443027973, 45.48015095293522, 21.009481139481068, 2.7858380880206823, 0.2396648217109032, 0.5874868319369853, 0.3036233608145267, 0.22676770517136902, 0.18238117365399376, 0.2981059974990785, 0.1730089171906002, 0.11001361897797324, 0.10513589790207334, 0.1635447976877913, 0.040996141178766266, 0.2106105862185359, 0.1327490236144513, 0.21625089371809736, 0.20635898545151576, 0.2321578495320864, 0.19571304030250758, 0.12627635296666995, 0.07811637900886126, 0.08933454970247112, 0.08467758045298979, 0.0694872647000011, 0.11609321853029542, 0.09114265893003903, 0.10209649146418087, 0.057635407501948066, 0.05210841110965703, 0.10196073781116866, 0.05778140650363639, 0.1672025170410052, 0.20421361463377252, 0.1225839604740031, 0.1983895365265198, 0.07314874674193561, 0.04801020855666138, 0.29863903764635324, 0.15901849837973714, 0.247630589583423, 0.1785469418973662, 0.1539014940499328, 0.1267762339557521, 0.1658819246222265, 0.17541412875289097, 0.17065860971342772, 0.20223414350766689, 0.24678320536622778, 0.12542956246761605, 0.295631499029696, 0.44067615817766637, 0.16886277560843155, 0.11419381029554643, 0.22567287407582626, 0.22600877011427656, 0.22831334645161405, 0.3084255015710369, 0.1173954873229377, 0.14654188271379098, 0.15186143398750573, 0.5232265801168978, 0.6580975523684174, 0.4861041158437729, 0.2625155041459948, 0.19862957677105442, 0.2812012389767915, 0.5417954712174833, 0.7254634844139218, 0.21642040024744347, 0.6070378515869379, 0.18214312236523256, 0.24283235252369195, 0.21696651703678071, 0.3434090071823448, 1.6711532953195274, 6.111517483368516, 8.147843889892101, 6.198116261512041, 29.682396054267883, 34.9989377707243, 58.93855758011341, 71.11226454377174, 91.94527745246887, 65.75037226080894, 119.0027667582035, 129.3577355146408, 99.59447219967842, 103.16743567585945, 103.83656457066536, 84.93829384446144, 69.62989568710327, 66.9762396812439, 68.32148909568787, 67.63706222176552, 74.99640092253685, 69.03847262263298, 89.78986591100693, 92.00542822480202, 82.45090931653976, 78.9025229215622, 90.52894905209541, 77.74448946118355, 42.16385990381241, 59.41868081688881, 56.36888846755028, 39.84796777367592, 23.816675506532192, 33.075822964310646, 48.66846106946468, 49.860772490501404, 46.92310072481632, 22.807149477303028, 24.35458794236183, 16.621288508176804, 9.774213619530201, 2.487722709774971, 3.654771661385894, 0.6705109518952668, 1.8929206766188145, 0.5543852050323039, 0.3637824155157432, 0.8607509499415755, 1.6768792318180203, 0.5878425284754485, 3.378578731790185, 1.8077785265631974, 1.4855080819688737, 1.0783234750851989, 1.2128349510021508, 5.553635694086552, 15.047036781907082, 26.462768018245697, 1.5233130846172571, 0.3745070134755224, 0.20674371480708942, 0.46927618444897234, 0.8317773265298456, 0.9681624581571668, 2.085870048031211, 10.005395114421844, 15.759082473814487, 32.39819772541523, 51.734847128391266, 24.691817946732044, 32.657096832990646, 49.97013442218304, 48.037482127547264, 20.330360680818558, 15.68153528496623, 33.1689939647913, 39.675947204232216, 47.0701452344656, 58.97077225148678, 81.43238916993141, 65.59833481907845, 55.928199514746666, 73.38715687394142, 102.833471596241, 103.07095125317574, 87.76351824402809, 82.63617217540741, 72.79191881418228, 62.95882165431976, 64.75338935852051, 69.8975533246994, 75.42764738202095, 79.18483257293701, 81.60265803337097, 84.35327723622322, 106.70643657445908, 83.54811564087868, 53.69425758719444, 55.314901024103165, 59.976167902350426, 56.54234156012535, 58.023289293050766, 38.12806226313114, 9.147394504398108, 0.2573452878277749, 1.2023756559938192, 0.48851196945179254, 0.5515069782268256, 0.31036191328894347, 0.46723610954359174, 0.2992873184848577, 0.1659876955091022, 0.14233472174964845, 0.27481767057906836, 0.1380301613244228, 0.2737483842065558, 0.26854732423089445, 0.352271378505975, 0.27764480793848634, 0.3735311783384532, 0.35288970626425, 0.15141078707529232, 0.17089783359551802, 0.2022848025080748, 0.15977967472281307, 0.20477031444897875, 0.19424707599682733, 0.28031760826706886, 0.26923277182504535, 0.15001529711298645, 0.14800811419263482, 0.16334754967829213, 0.17092879599658772, 0.15651838097255677, 0.23049769486533478, 0.14477056916803122, 0.2435227279784158, 0.1351756980875507, 0.19538992404704913], [0.029201421930338256, 0.11430431608459912, 0.055315182980848476, 0.05296031500620302, 0.08033651378354989, 0.07182449553511105, 0.037272615591064095, 0.07083588803652674, 0.26951725187245756, 0.19044112006668001, 0.11503941335831769, 0.04324610657931771, 0.3495474887313321, 0.18379453453235328, 0.15587571077048779, 0.09203199675539508, 0.179106832947582, 0.023460380871256348, 0.17524390976177529, 0.08970647701062262, 0.10952829892630689, 0.25086544803343713, 0.13366467057494447, 0.23161961435107514, 0.3326774330344051, 0.7348828227259219, 0.7311356300488114, 0.4018639720743522, 0.2160386394825764, 0.18407858413411304, 0.509236918296665, 0.4698927904246375, 1.332719111815095, 0.8443157630972564, 1.006999877281487, 0.4557342454791069, 0.05149590921064373, 1.170983521733433, 0.2893125865375623, 3.7619430106133223, 1.1659382237121463, 9.897401109337807, 5.567219015210867, 3.923834986053407, 34.85946625471115, 45.602310597896576, 63.4598133713007, 47.85860292613506, 103.42948481440544, 121.72416552901268, 95.74089378118515, 95.16561985015869, 70.4055480659008, 50.05404531955719, 52.71045237779617, 45.62657989561558, 51.13411836326122, 53.54380086064339, 58.387305960059166, 64.21035289764404, 73.465007096529, 68.3627700805664, 78.705815076828, 48.92957925796509, 25.87525114417076, 42.35839806497097, 45.094581842422485, 28.07166438549757, 22.544944547116756, 19.684534035623074, 27.34350185841322, 33.86862002313137, 25.36457944661379, 22.052236385643482, 17.382260374724865, 3.0590417655184865, 2.2151160752400756, 9.046911746263504, 1.6610301635228097, 1.9983220333233476, 1.6364727937616408, 1.0952149936929345, 1.1893871217034757, 0.46178337244782597, 0.37794247444253415, 1.8416615459136665, 0.1126404655224178, 1.2814091588370502, 0.738051674561575, 0.5950455169659108, 2.159352167509496, 1.12284627975896, 0.4505081009119749, 2.9758984269574285, 9.813860692083836, 0.19493460160447285, 0.07300129684153944, 1.0782809648662806, 2.1527357725426555, 1.6159055661410093, 0.7029944588430226, 2.267659893259406, 4.4813512824475765, 2.526378035545349, 7.414646632969379, 4.397613750770688, 8.654788937419653, 4.151363214477897, 8.439826872199774, 15.52020924165845, 22.96286702156067, 19.87882900983095, 20.224281772971153, 26.37935109436512, 34.90073584020138, 26.416376307606697, 27.853430695831776, 31.004761196672916, 44.926714450120926, 46.11122488975525, 51.96526676416397, 71.72979220747948, 93.0567330121994, 101.6151961684227, 88.44801351428032, 90.00174254179001, 80.75768977403641, 84.35578510165215, 89.71040457487106, 94.32171553373337, 100.95749706029892, 88.7622794508934, 55.827064141631126, 38.23957867920399, 59.18273247778416, 44.6036633849144, 49.320441484451294, 53.936224803328514, 30.136437490582466, 6.669901795685291, 0.4528230376308784, 1.1010464932769537, 0.6872577220201492, 0.13404508063104004, 0.48715357203036547, 0.22050869883969426, 0.46971740608569235, 0.19914836768293753, 0.09213329991325736, 0.11128287704195827, 0.10683079992304556, 0.16566106147365645, 0.15966229664627463, 0.49169263627845794, 0.288277231156826, 0.2208331658039242, 0.3064693487249315, 0.20392837759573013, 0.05289651999191847, 0.15453328436706215, 0.16896995657589287, 0.14811248984187841, 0.18072511564241722, 0.05396662272687536, 0.06386238645063713, 0.06505890662083402, 0.04828499615541659, 0.13829550880473107, 0.04985819337889552, 0.06684227264486253, 0.22685579810058698, 0.1260086306137964, 0.2133913987199776, 0.06429866538383067, 0.051736847453867085, 0.07711670608841814, 0.11094220899394713, 0.08538264301023446, 0.04683629420469515, 0.03997616680862848, 0.07789257695549168, 0.08123111343593337, 0.022901371121406555, 0.04008738134871237, 0.20997780142351985, 0.1344719046028331, 0.059108377681695856, 0.08730703935725614, 0.2152104620472528, 0.13648365915287286, 0.21073309995699674, 0.12330327968811616, 0.0926897770841606, 0.08900985267246142, 0.01940075700986199, 0.12219333104440011, 0.18878393399063498, 0.20341304509202018, 0.18378297187155113, 0.27111595671158284, 0.4601697949692607, 0.41502052859868854, 0.4623496311251074, 0.3693201730493456, 0.38968405220657587, 0.19909189024474472, 0.25305772258434445, 0.5970152362715453, 0.4766964144073427, 1.2811920954845846, 0.8721395919565111, 0.42219282186124474, 0.17274857178563252, 0.4290042829234153, 1.2255844543688, 2.756631667725742, 5.183545527979732, 4.890794036909938, 16.99684325605631, 14.327723979949951, 45.49228750169277, 59.52510930597782, 80.06236508488655, 59.1554119437933, 100.13115540146828, 132.0264235138893, 106.60288453102112, 92.484590113163, 81.61984071135521, 62.464437782764435, 56.35521300137043, 54.57158111035824, 58.02883319556713, 58.88274237513542, 66.99757933616638, 71.38948246836662, 75.6237244606018, 82.41071507334709, 78.5746157169342, 50.250232592225075, 38.405694365501404, 58.98299619555473, 54.68888841569424, 45.674924701452255, 31.03193923830986, 25.40820110589266, 42.64771454036236, 43.28791558742523, 26.230104602873325, 17.60240726172924, 11.970183234661818, 6.464517116546631, 5.26591133326292, 4.9633055459707975, 2.9739569686353207, 2.482166695408523, 2.111388291232288, 1.098631841596216, 0.6194940581917763, 0.4416320740710944, 0.07685576696530916, 0.8280442049726844, 0.4201145115075633, 1.5969205973669887, 1.0993072553537786, 0.7153847033623606, 1.2267302116379142, 1.224385262466967, 1.4989028382115066, 5.189977157860994, 10.945957694202662, 0.5411454092245549, 0.11147472963784821, 0.27514819346833974, 0.9221469867043197, 0.8006644179113209, 0.4313072859076783, 2.4939113901928067, 9.751873668283224, 9.670703373849392, 12.59540168568492, 21.958761401474476, 31.554285809397697, 7.698502326384187, 21.886198595166206, 30.059404224157333, 23.510018661618233, 20.73347344994545, 22.590325511991978, 28.536485843360424, 51.559182554483414, 48.48798595368862, 44.57318142056465, 43.83159801363945, 65.08930653333664, 69.97478038072586, 58.69906783103943, 77.6418037712574, 101.63962885737419, 107.99188479781151, 102.61027917265892, 98.49553316831589, 89.79260176420212, 94.13954570889473, 94.56650599837303, 97.5567327439785, 103.266861140728, 92.1336181461811, 59.002025574445724, 50.418734550476074, 62.30704262852669, 49.874998927116394, 56.6118398308754, 56.56654246151447, 29.80153676122427, 6.280518639832735, 0.6204754742793739, 1.0224612476304173, 0.7230970426462591, 0.19285966060124338, 0.2989032125333324, 0.15226737392367795, 0.39008727588225156, 0.29823153920006007, 0.1111208662041463, 0.15586754714604467, 0.06928478454938158, 0.1423468632856384, 0.14514682319713756, 0.20504766987869516, 0.15649372682673857, 0.21384876949014142, 0.3815450967522338, 0.23052683158311993, 0.010281546929036267, 0.20275796618079767, 0.18677991261938587, 0.2680417138617486, 0.10462851379998028, 0.04073423355293926, 0.09965996869141236, 0.06919050953001715, 0.06138178381661419, 0.07579649958643131, 0.008708032437425572, 0.10477263887878507, 0.08359339917660691, 0.055579179752385244, 0.1534061846905388, 0.1480287458980456, 0.06594745034817606, 0.013210001361585455, 0.2831762423738837, 0.1559434094815515, 0.07625514685059898, 0.18971783778397366, 0.2906185883330181, 0.17717910435749218, 0.19586152920965105, 0.1481938737560995, 0.27121172344777733, 0.4137814388377592, 0.17400909477146342, 0.24831047106999904, 0.6702781550120562, 0.278589294757694, 0.3509753511752933, 0.22066238278057426, 0.22490372706670314, 0.15595132077578455, 0.15608045447152108, 0.2088817532057874, 0.22541745653143153, 0.2529835671884939, 0.19948240835219622, 0.38568592455703765, 0.8062542148400098, 0.631753031630069, 0.40676722303032875, 0.49796387320384383, 0.3781279519898817, 0.2158552993205376, 0.8125074324198067, 0.4232562897959724, 0.8679221745114774, 1.2867158115841448, 0.7138857431709766, 0.25214535591658205, 0.19090359681285918, 0.7142669695895165, 0.9201071492861956, 2.513213879428804, 4.14868863299489, 12.749776002019644, 25.17811395227909, 38.098188266158104, 65.5265186727047, 70.08741393685341, 88.04232448339462, 76.31797760725021, 122.43019044399261, 127.42946058511734, 100.82861557602882, 95.5768033862114, 86.32072046399117, 67.71806627511978, 61.3847941160202, 63.79736825823784, 62.93607987463474, 68.69422629475594, 74.2433725297451, 75.81121399998665, 87.65917584300041, 85.5954609811306, 91.01211592555046, 69.71598386764526, 41.47880606353283, 60.89040644466877, 64.27741169929504, 54.19717200100422, 39.91530016064644, 37.98623867332935, 51.01128615438938, 56.062127128243446, 43.373825177550316, 30.781682766973972, 25.08399110287428, 6.233501387760043, 9.670845866203308, 32.274179980158806, 10.708094257861376, 7.394449766725302, 3.494530222378671, 1.9337424798868597, 2.5148957641795278, 0.8343318582046777, 0.23239935922902077, 1.4252766827121377, 1.204713718034327, 1.7193009867332876, 3.3825697051361203, 2.224323218688369, 3.8554365187883377, 1.463623868767172, 1.1742213042452931, 6.719457786530256, 15.827126372605562, 1.131286695599556, 0.14710487594129518, 2.056565545499325, 2.5495320931077003, 1.5403247717767954, 0.9720273257698864, 3.0117870261892676, 16.142774485051632, 18.223569430410862, 36.22027203440666, 54.804668202996254, 62.142595052719116, 19.68952886760235, 53.77183422446251, 51.03779733181, 44.31643679738045, 52.475579380989075, 44.216749146580696, 48.96880455315113, 72.71748840808868, 59.13450166583061, 53.80313314497471, 51.78376950323582, 66.41770765185356, 69.77680340409279, 68.12924221158028, 86.57413646578789, 104.66089993715286, 117.09064856171608, 111.26405641436577, 109.10363674163818, 93.5298304259777, 99.76591899991035, 99.15369585156441, 93.52101489901543, 101.91286459565163, 99.20215845108032, 80.35571694374084, 59.460653364658356, 66.94963350892067, 61.015780717134476, 60.50213187932968, 66.98645353317261, 50.064091980457306, 22.811733931303024, 0.7925094023812562, 2.0377812534570694, 0.8041387377306819, 0.357085601426661, 0.3785153233911842, 0.19482598087051883, 0.3868180559948087, 0.4193426185520366, 0.1853919035056606, 0.270433685509488, 0.2616202662466094, 0.2252174774184823, 0.2792219311231747, 0.44569853867869824, 0.2797988470410928, 0.3211370069766417, 0.3299093112582341, 0.2159460194525309, 0.19323187734698877, 0.3649973409483209, 0.3162058215821162, 0.23637449514353648, 0.18186169996624812, 0.1499799857265316, 0.11293299045064487, 0.10759741620859131, 0.15518543921643868, 0.3364647610578686, 0.11896553041879088, 0.1701462161145173, 0.2254441738477908, 0.23322536959312856, 0.2570700697833672, 0.2483242898597382, 0.2151734585640952, 0.12384512912831269], [0.07550896189059131, 0.09945104669895954, 0.09833680102019571, 0.06722479782183655, 0.028422480427252594, 0.09144988580374047, 0.07921691722003743, 0.09749650431331247, 0.08627956558484584, 0.05746148890466429, 0.05051102729339618, 0.04802731877134647, 0.11499737811391242, 0.17774279520381242, 0.04075032702530734, 0.15189168392680585, 0.15391865250421688, 0.11181449226569384, 0.10657699283910915, 0.046528532984666526, 0.29497627168893814, 0.1742032851325348, 0.37976409075781703, 0.2913588361116126, 0.591275644255802, 0.7785670005250722, 0.7770252926275134, 0.7066174456849694, 0.43246767832897604, 0.21221251197857782, 0.7051786291413009, 0.12311233251239173, 0.3391648130491376, 0.6761135731358081, 0.3631360939471051, 0.2247071173042059, 0.6029343686532229, 0.13878372323233634, 1.4913420751690865, 0.4924584733089432, 2.919834335334599, 1.2885968293994665, 7.801533322781324, 5.181079460307956, 13.414838165044785, 42.82463304698467, 55.55398799479008, 69.90738719701767, 53.18804495036602, 91.40676274895668, 135.14927834272385, 115.05958914756775, 111.46204099059105, 93.81912410259247, 79.78447079658508, 79.99643862247467, 79.46670904755592, 77.44246646761894, 80.98632350564003, 88.15022349357605, 85.70353478193283, 66.935163885355, 39.53038461506367, 32.097546458244324, 38.67218926548958, 29.479412846267223, 19.120237715542316, 25.994644537568092, 28.488063141703606, 28.564148359000683, 17.761576920747757, 15.750218499451876, 38.549372255802155, 43.846652805805206, 27.885542772710323, 6.6075423918664455, 24.22212515026331, 8.924392070621252, 2.0655173901468515, 2.1557896211743355, 3.026643991470337, 3.520667594857514, 1.4231410785578191, 0.7571718329563737, 0.36695441405754536, 2.4903896916657686, 1.4905178756453097, 0.4011334909591824, 1.707434223499149, 3.1490107253193855, 0.8466200425755233, 1.4073513820767403, 0.7732189656235278, 3.6715643852949142, 2.3678018571808934, 1.452333249617368, 2.508616838604212, 1.3679394219070673, 1.5614790678955615, 1.3860137457959354, 1.4043842162936926, 3.8063559774309397, 4.237694106996059, 6.2694883067160845, 4.399346457794309, 7.782521042972803, 40.17392948269844, 30.056138299405575, 11.477652713656425, 10.455317571759224, 7.900274824351072, 24.985502287745476, 28.902235217392445, 38.56631554663181, 34.63889569044113, 27.17968314886093, 25.44668734073639, 23.053098879754543, 29.09998420625925, 46.23428888618946, 57.601895704865456, 64.28574845194817, 66.14198684692383, 71.44806012511253, 83.17234620451927, 91.44817292690277, 89.04917165637016, 92.63678714632988, 89.10316675901413, 82.06253975629807, 75.75401946902275, 54.796369448304176, 45.643033012747765, 51.8751659989357, 39.927911683917046, 61.36749744415283, 64.80677649378777, 37.95087017118931, 8.430250436067581, 0.33362248388584703, 0.6753414426930249, 0.8177792932838202, 0.5953139963094145, 0.6012865039519966, 0.4251484101405367, 0.6319016392808408, 0.6069694552570581, 0.5529473978094757, 0.1393656709115021, 0.20399830274982378, 0.26158149645198137, 0.1068639442382846, 0.3333258326165378, 0.2685334609122947, 0.3627477429108694, 0.3555918065831065, 0.5295432661660016, 0.1666194264544174, 0.4511171072954312, 0.5213553586509079, 0.325790451024659, 0.38161456177476794, 0.15303439839044586, 0.1936779823154211, 0.17186402081279084, 0.05739123349485453, 0.15041118836961687, 0.14791182795306668, 0.32370736123993993, 0.18384053284535185, 0.2497856825357303, 0.17685021419310942, 0.1845916753518395, 0.1661760822753422, 0.04280986846424639, 0.20655609987443313, 0.15063666767673567, 0.013912740068917628, 0.071229114982998, 0.07843963627237827, 0.06656128069153056, 0.1385298345121555, 0.033635617000982165, 0.06779833696782589, 0.0543295329407556, 0.007649568433407694, 0.0152691234870872, 0.08459690157906152, 0.050495468167355284, 0.042711088608484715, 0.15493503859033808, 0.09626895494875498, 0.05376206827349961, 0.051887065565097146, 0.06735700400895439, 0.07279063822352327, 0.2688109053997323, 0.06805889017414302, 0.3067467041546479, 0.3755102487048134, 0.6492300156969577, 1.0680683003738523, 0.6790023681242019, 0.4065970337251201, 0.3381514549255371, 0.26966876874212176, 0.6094881857279688, 0.2582502330187708, 0.6333962653297931, 0.5996385798789561, 0.6459215213544667, 0.16973344841971993, 0.4733384633436799, 0.15963264042511582, 1.1596598918549716, 0.5033871915657073, 3.199477717280388, 3.36810530629009, 0.6402269331738353, 8.818163070827723, 32.541203051805496, 60.78824132680893, 67.80590996146202, 85.81371366977692, 68.52837279438972, 85.74043840169907, 129.25536900758743, 126.66278332471848, 114.90204960107803, 103.50621029734612, 91.38467073440552, 86.92608118057251, 87.35240310430527, 93.21321621537209, 85.59499740600586, 91.33496940135956, 85.64376398921013, 70.6538799405098, 49.59645487368107, 48.624702617526054, 53.308281898498535, 39.57603916525841, 36.56705282628536, 46.92793406546116, 40.799337923526764, 48.33160154521465, 30.153464376926422, 31.83738961815834, 36.81573428213596, 33.67689371109009, 32.563086077570915, 19.901764579117298, 26.17966800928116, 17.0657791569829, 4.956790320575237, 2.152148229070008, 2.5165135273709893, 0.9289279009681195, 0.9800092724617571, 1.3083355827257037, 0.655118334107101, 1.5563092078082263, 0.6948828441090882, 0.7318112219218165, 0.8649067988153547, 1.7210828536190093, 1.3827437837608159, 1.6384092648513615, 0.44349450850859284, 4.760333262383938, 2.9818584071472287, 1.0439964733086526, 2.127795098349452, 1.200706239324063, 1.0139252431690693, 0.9785928984638304, 1.3023725152015686, 4.823448350653052, 5.9022897854447365, 6.822475483641028, 11.855193804949522, 15.765618123114109, 43.94844554364681, 22.460357286036015, 19.12070319056511, 16.071347817778587, 22.083753794431686, 45.21077200770378, 51.03297159075737, 56.60311929881573, 58.00808250904083, 50.50287343561649, 52.75674529373646, 45.51005534827709, 40.58623395860195, 58.18364828824997, 81.40658855438232, 76.04583621025085, 70.13475179672241, 78.11855658888817, 87.22985208034515, 92.58042857050896, 102.12278813123703, 97.8298468887806, 93.78937929868698, 84.75676238536835, 76.55551806092262, 60.26245974004269, 58.81322130560875, 53.637028858065605, 42.11613826453686, 66.3552238047123, 63.64407688379288, 39.16503041982651, 9.30614048615098, 0.44538125570397824, 0.9091645083390176, 0.7001598703209311, 0.4674278211314231, 0.3803821513429284, 0.31696165446192026, 0.43154702929314226, 0.5129613715689629, 0.4018871270818636, 0.15505265415413305, 0.18195026786997914, 0.09143198520177975, 0.10988879716023803, 0.16928997065406293, 0.1956945756683126, 0.14961958397179842, 0.3645134309772402, 0.36767474259249866, 0.20916094916174188, 0.40055034100078046, 0.33657516294624656, 0.17569354735314846, 0.2979259821586311, 0.10458265649504028, 0.1296915384591557, 0.04527894554485101, 0.08749768225243315, 0.12466528394725174, 0.10864918047445826, 0.28556687815580517, 0.190689442679286, 0.29344029317144305, 0.14487745327642187, 0.10769871194497682, 0.07533078707638197, 0.026659005816327408, 0.12820231524528936, 0.22979076951742172, 0.18030860752332956, 0.18809061963111162, 0.15898867888608947, 0.09367936421767808, 0.28725018783006817, 0.2003161667380482, 0.13460506073897704, 0.09988096542656422, 0.11596892363741063, 0.10541182840825059, 0.2660939621273428, 0.21935598022537306, 0.3677757043624297, 0.4073074471671134, 0.22073235246352851, 0.21474538778420538, 0.26003189210314304, 0.3029796516057104, 0.12110684168874286, 0.3293751727323979, 0.20382118178531528, 0.4977514111669734, 0.21054187818663195, 0.40921720094047487, 0.8979662123601884, 0.5381091346498579, 0.2924560272367671, 0.706052997848019, 0.33555224596057087, 0.6475879694335163, 0.8965622470714152, 0.5152848281431943, 0.986196706071496, 0.46957719954662025, 0.23767703853081912, 0.7716951286420226, 0.08097928046481684, 0.913552975980565, 0.48169053392484784, 1.4786779484711587, 1.604658525902778, 7.973922472447157, 37.63275124132633, 50.58958098292351, 72.3382231593132, 83.79491999745369, 95.2289168536663, 78.1826439499855, 111.51774600148201, 137.46715396642685, 129.34300750494003, 114.03268665075302, 103.8257123529911, 84.25401136279106, 84.81723994016647, 88.42080697417259, 89.15200173854828, 86.45318895578384, 89.74100813269615, 88.70882391929626, 84.87647876143456, 55.34580856561661, 51.39279328286648, 56.96211263537407, 46.61230780184269, 37.694915905594826, 50.549025759100914, 45.2711583673954, 51.347549110651016, 27.115536890923977, 31.8641534820199, 47.854024171829224, 72.72038385272026, 55.79949662089348, 23.60474567860365, 43.714336305856705, 34.1882398724556, 14.079898428171873, 6.482347659766674, 5.168874515220523, 6.240414641797543, 0.9940298076253384, 1.8697236338630319, 0.4494961677119136, 2.692558793351054, 2.16521002817899, 0.6335892237257212, 1.8730857409536839, 6.330447485670447, 2.4928787956014276, 5.768590159714222, 1.5754968719556928, 4.140118192881346, 2.3387647652998567, 0.9177944983821362, 1.4283313625492156, 0.8057458733674139, 0.8649746014270931, 1.4602790982462466, 0.8209229120984674, 12.039355672895908, 19.36352726072073, 26.853603646159172, 30.406583994627, 30.106335505843163, 72.81833499670029, 46.51339910924435, 22.13891353458166, 17.777739353477955, 40.947191789746284, 74.31809931993484, 77.36831724643707, 80.49098208546638, 70.90535804629326, 58.9845085144043, 59.03310790657997, 55.12448564171791, 56.31381802260876, 67.45126739144325, 78.87147098779678, 81.72477588057518, 85.978252440691, 96.39625981450081, 106.08455434441566, 109.24714744091034, 108.10320362448692, 99.53367546200752, 95.32759755849838, 88.54698300361633, 80.7033982872963, 68.70247185230255, 68.56656074523926, 68.05840641260147, 56.330974102020264, 67.33905181288719, 74.41599726676941, 60.8418944478035, 28.800191693007946, 0.898190044099465, 1.2963739433325827, 0.5151172808837146, 0.4605881287716329, 0.3760790900560096, 0.23354038159595802, 0.3133667801739648, 0.3841296408791095, 0.38746004342101514, 0.10962259621010162, 0.21974626084556803, 0.15507775358855724, 0.3340862668119371, 0.26358704664744437, 0.22029637038940564, 0.3565400338266045, 0.41907434700988233, 0.34023053711280227, 0.39217336394358426, 0.35531234345398843, 0.5636160972062498, 0.2915109466994181, 0.4924029012909159, 0.1673750812187791, 0.32607558416202664, 0.3487381321610883, 0.1478280543233268, 0.18326364661334082, 0.26117830246221274, 0.32069020438939333, 0.312113975523971, 0.2872447849949822, 0.2793884987477213, 0.21627692825859413, 0.13604424835648388, 0.12466230051359162, 0.3728884784504771], [0.09810362564167008, 0.13724732911214232, 0.08240014445618726, 0.05701287547708489, 0.028142803930677474, 0.07717476430116221, 0.04639075697923545, 0.05218058497121092, 0.08875813844497316, 0.05294546463119332, 0.09449528137338348, 0.02387978893239051, 0.08120475977193564, 0.0466696301009506, 0.08477828247123398, 0.09029500011820346, 0.14400738902622834, 0.020985175506211817, 0.09849536087131128, 0.20416386105353013, 0.09383997981785797, 0.11179435779922642, 0.43795419798698276, 0.46368502196855843, 0.6809139030519873, 1.7929050559177995, 0.8914917160291225, 0.6684977724216878, 0.7168253604322672, 0.13472022721543908, 0.5556218605488539, 0.777748441323638, 0.52480224869214, 0.6817474833223969, 1.6595940780825913, 0.9833568928297609, 0.21973587077809498, 0.48822006792761385, 0.6749099283479154, 2.9995350586250424, 2.229886595159769, 4.938137121498585, 1.402448220178485, 10.83515563979745, 17.064603120088577, 36.668028607964516, 49.909018501639366, 57.52850644290447, 80.47664165496826, 61.33804902434349, 75.0241394340992, 108.7410070002079, 109.8692424595356, 112.27640569210052, 112.2263091802597, 98.9814130961895, 97.92598932981491, 106.44283711910248, 97.57125556468964, 76.08087033033371, 61.24797485768795, 40.19126035273075, 31.261433623731136, 31.92539669573307, 22.6353644952178, 16.879237666726112, 28.614744544029236, 27.50564105808735, 21.059668846428394, 20.171111226081848, 28.737162575125694, 24.752341099083424, 28.539343290030956, 19.904401637613773, 21.70022327452898, 17.331639491021633, 30.497401021420956, 26.241912469267845, 3.537775226868689, 5.1475438848137856, 3.5499511985108256, 3.87342712841928, 1.205198192037642, 1.7640203121118248, 3.9130186289548874, 1.2282940652221441, 0.28969983919523656, 2.3121175076812506, 0.1903049211250618, 0.7869331422261894, 1.249849833548069, 0.9739022282883525, 1.4124984433874488, 3.571873172186315, 2.7119434531778097, 1.4097169926390052, 1.5987219382077456, 1.3051987322978675, 0.9120894013904035, 2.8288494050502777, 4.165344564244151, 9.21582218259573, 6.327974768355489, 5.890423972159624, 21.864604353904724, 44.550614431500435, 26.372338570654392, 21.267696283757687, 15.424319487065077, 28.66747621446848, 45.85509583353996, 37.16612108051777, 25.44052977114916, 25.329703018069267, 14.57407521083951, 18.50711401551962, 31.580907180905342, 38.555607721209526, 36.40553489327431, 31.28959011286497, 44.9880887567997, 53.726742044091225, 54.376157596707344, 58.31492364406586, 68.82379934191704, 80.37507310509682, 87.69032657146454, 78.3325383067131, 72.1967339515686, 68.03480207920074, 58.573302179574966, 53.135284781455994, 52.21758462488651, 45.50828464329243, 63.17679315805435, 62.097917050123215, 45.07940545678139, 15.556453596800566, 2.0727752381935716, 1.6381393605843186, 2.157646296545863, 1.0680747125297785, 0.5873544921632856, 0.6738180806860328, 0.5086243199184537, 0.8071440202184021, 0.8468988526146859, 0.6555865402333438, 0.25658541766460985, 0.5414857878349721, 0.12798011623090133, 0.31019347545225173, 0.16154775250470266, 0.3181525639956817, 0.4728770552901551, 0.5804636212997139, 0.39031648077070713, 0.5137461482081562, 0.6262066948693246, 0.6951092288363725, 0.37241819431073964, 0.318153157713823, 0.4683161719003692, 0.06546841628733091, 0.1592335430905223, 0.17991944012464955, 0.19447936821961775, 0.2370029012672603, 0.367069179774262, 0.5388879147358239, 0.3184263868024573, 0.10527495411224663, 0.4418197780614719, 0.30862712825182825, 0.09541466875816695, 0.2539975190302357, 0.04674133269872982, 0.11421311355661601, 0.11294003343209624, 0.039509021953563206, 0.038670558351441287, 0.05834834053530358, 0.13150800426956266, 0.05780448358564172, 0.07201613290817477, 0.052424577152123675, 0.07546156833996065, 0.04659655452996958, 0.16653845814289525, 0.03724607639014721, 0.10019701643614098, 0.09676028639660217, 0.137435122160241, 0.02736049864324741, 0.08034616912482306, 0.05414358412963338, 0.15842850581975654, 0.10562521070824005, 0.3020016197115183, 0.8756734617054462, 0.5510140734259039, 1.1508538643829525, 1.2276099831797183, 0.5460546864196658, 0.4312070069136098, 0.47738159482833, 0.38546684256289154, 0.45930920052342117, 0.44749005348421633, 0.6325340084731579, 1.4373573032207787, 0.8134349982719868, 0.16875660396181047, 0.37242226128000766, 0.6873409019317478, 2.657407117076218, 1.3142484216950834, 4.477811297401786, 1.180802194867283, 6.280230330303311, 12.429149206727743, 48.90861578285694, 62.951294258236885, 63.88935372233391, 90.7347460091114, 78.99614229798317, 83.13959196209908, 106.106798350811, 110.28417259454727, 114.79377061128616, 116.86969041824341, 110.28980389237404, 103.20386812090874, 97.3307740688324, 97.96931460499763, 88.8585738837719, 69.67994660139084, 51.05184517800808, 50.545518547296524, 48.40900719165802, 44.0827227383852, 44.05681952834129, 40.13588972389698, 32.17100791633129, 32.30011358857155, 27.583766765892506, 30.625558644533157, 28.474530167877674, 41.875018402934074, 58.63561123609543, 39.47543956339359, 32.07539364695549, 43.38078260421753, 26.1924372240901, 6.2557045463472605, 3.2934355130419135, 2.3070229310542345, 2.0446845330297947, 6.610776968300343, 1.8189822253771126, 1.0019501857459545, 0.4839024308603257, 0.09952186243026517, 1.9463219423778355, 1.2615708983503282, 4.227423733100295, 1.8998284684494138, 1.7314258986152709, 1.684866996947676, 5.2357803750783205, 2.76628362480551, 1.8277350557036698, 2.10775307379663, 1.218744465149939, 0.8258832490537316, 2.363829407840967, 4.035823764279485, 4.543648939579725, 2.512510917149484, 1.9072619383223355, 10.810349620878696, 24.71059463918209, 48.62150698900223, 43.56737159192562, 24.77580104023218, 29.559877328574657, 28.0074193328619, 23.340523056685925, 33.58293615281582, 40.81956423819065, 36.83595299720764, 36.710191145539284, 45.50043046474457, 56.68260343372822, 64.98727440834045, 47.83657170832157, 54.5361328125, 74.25120010972023, 74.33190017938614, 65.31933858990669, 65.91010048985481, 75.3530801832676, 81.6248032450676, 85.07713839411736, 77.5485871732235, 72.89823710918427, 64.08236056566238, 56.37948989868164, 54.169908463954926, 53.11507746577263, 67.41155952215195, 60.30499845743179, 44.54464115202427, 14.22341862693429, 1.1827497091144323, 1.3677624939009547, 2.21485388930887, 1.6369424248114228, 0.7821119134314358, 0.483767359983176, 0.37151042895857245, 0.569877567468211, 0.6938332691788673, 0.5810255755204707, 0.26754076418001205, 0.48940257634967566, 0.15061219164635986, 0.3455860528629273, 0.1109545657527633, 0.15887685207417235, 0.3674568480346352, 0.4035272734472528, 0.22279758617514744, 0.45842598541639745, 0.4852737713372335, 0.4940582765266299, 0.25047872972209007, 0.3271507186582312, 0.09676954839960672, 0.06459557640482672, 0.09670494444435462, 0.09993982515879907, 0.1677332416875288, 0.1841404495644383, 0.11503919813549146, 0.33856993715744466, 0.2211187145439908, 0.11062194258556701, 0.28984708129428327, 0.20840927230892703, 0.17179785092594102, 0.156011019134894, 0.16104347800137475, 0.22245996835408732, 0.2118179269018583, 0.14310787635622546, 0.16291869222186506, 0.20182305306661874, 0.17751467385096475, 0.17066497734049335, 0.16088051721453667, 0.1960722397780046, 0.1576419034972787, 0.1767836880753748, 0.14366825722390786, 0.11302515777060762, 0.18003908917307854, 0.18660908506717533, 0.16117179533466697, 0.10555710381595418, 0.09941732350853272, 0.2949095971416682, 0.3025386674562469, 0.10693484160583466, 0.3881111741065979, 0.7082385930698365, 0.5411376908887178, 1.7370220483280718, 1.3783673685975373, 0.407543865730986, 0.3396843757946044, 0.685133517254144, 0.2538812393322587, 0.978681540582329, 0.9226068807765841, 1.0046057682484388, 1.5925666247494519, 0.6336887902580202, 0.18540640507126227, 0.6135816941969097, 0.322813696693629, 1.7947486694902182, 1.3014684012159705, 1.9859797018580139, 0.6284262507688254, 15.880506858229637, 63.698706552386284, 65.90459078550339, 73.43291401863098, 93.65748837590218, 104.26941454410553, 79.55022856593132, 92.78589114546776, 112.7072873711586, 115.42127653956413, 114.8810139298439, 118.49375367164612, 109.42747816443443, 113.49950686097145, 107.19509035348892, 102.8704360127449, 94.27230298519135, 71.57460853457451, 52.165139839053154, 46.06618210673332, 52.37169675529003, 52.30972968041897, 47.18696616590023, 46.678177267313, 38.838202357292175, 41.91521264612675, 34.40603658556938, 43.65333057940006, 32.1804504096508, 55.64408116042614, 67.29083999991417, 56.34681925177574, 34.67455677688122, 53.63008663058281, 42.46186651289463, 22.718806117773056, 13.325175326317549, 5.7780426274985075, 10.654488634318113, 15.330674462020397, 3.401724952273071, 4.445687821134925, 0.38736638438422233, 0.2555472421227023, 1.686836953740567, 1.5455089998431504, 6.545974770560861, 3.222547466866672, 2.0708895893767476, 5.76719943434, 4.63898534886539, 1.85842054663226, 1.293303114362061, 0.972490900894627, 0.6007819622755051, 0.29687795089557767, 3.009338532574475, 11.170335654169321, 21.660488806664944, 13.609777204692364, 16.381623968482018, 40.88919170200825, 50.681771636009216, 39.490517154335976, 42.999799847602844, 20.884203761816025, 41.27792224287987, 57.90959559381008, 58.75327192246914, 68.85057270526886, 65.35055011510849, 63.54781664907932, 56.71725757420063, 57.144290059804916, 64.36182796955109, 76.02533251047134, 60.66862754523754, 69.59411680698395, 75.95173045992851, 74.0564377605915, 74.7589060664177, 76.42482027411461, 84.37404692173004, 95.50169661641121, 98.52971613407135, 92.08957850933075, 80.80572679638863, 75.53885981440544, 70.75056955218315, 61.53519004583359, 47.27666795253754, 59.91616532206535, 66.09724804759026, 58.938192799687386, 32.09988333284855, 3.0762263434007764, 1.4883516356348991, 1.6034107678569853, 0.7931624923367053, 0.4586196562740952, 0.5044253077358007, 0.2615648426581174, 0.5711802444420755, 0.4014293703949079, 0.47527499380521476, 0.21169342420762405, 0.33472807612270117, 0.18576538190245628, 0.316868707886897, 0.15964715683367103, 0.23705784988123924, 0.25389833841472864, 0.49134967499412596, 0.26933741464745253, 0.38893053482752293, 0.3757355350535363, 0.43617069837637246, 0.3125481912866235, 0.2883765602018684, 0.4735835501924157, 0.17843324487330392, 0.19770540995523334, 0.2990344539284706, 0.4210893966956064, 0.18722604727372527, 0.2816477743908763, 0.5371373367961496, 0.5745628941804171, 0.28233004559297115, 0.30478894826956093, 0.30160418478772044, 0.18053472507745028, 0.222781837801449], [0.12144154286943376, 0.10786058177473024, 0.30892407638020813, 0.2859165781410411, 0.07397069755825214, 0.14286319026723504, 0.17776079970644787, 0.12305233729421161, 0.12484666483942419, 0.04051416821312159, 0.12612038321094587, 0.07789702242007479, 0.21033259254181758, 0.0816424265212845, 0.3087957442039624, 0.1583075209055096, 0.2635496127186343, 0.12895774736534804, 0.33968989737331867, 0.1679167154361494, 0.3501861810218543, 0.2588205586653203, 0.5762965511530638, 1.03291021194309, 1.0572745045647025, 0.754548964323476, 1.6693989769555628, 1.2773292465135455, 0.9390516264829785, 1.59451900748536, 0.39824819890782237, 0.2912244776962325, 0.40495092049241066, 0.13121720112394542, 0.4450881667435169, 1.1951610306277871, 1.4155705785378814, 1.5122372726909816, 1.791967456229031, 2.700873934663832, 3.1747484067454934, 1.2975316937081516, 4.013811545446515, 1.506944156717509, 22.026283778250217, 23.546905182301998, 52.78981491923332, 52.96830654144287, 50.966509357094765, 85.04049316048622, 82.72452503442764, 72.4403540790081, 91.4901302754879, 97.63509973883629, 102.9908287525177, 104.97402593493462, 106.74322620034218, 81.34275197982788, 69.22738328576088, 64.92973029613495, 51.78383029997349, 50.44021099805832, 32.86119528114796, 20.584646835923195, 24.437942169606686, 25.588218346238136, 21.561422422528267, 33.1418976187706, 37.86773823201656, 46.06580972671509, 34.502475410699844, 26.843760274350643, 18.74889124184847, 32.28511579334736, 17.439036928117275, 7.79028782621026, 20.433365553617477, 38.59488621354103, 9.43819859996438, 0.16827260493300855, 1.513221776112914, 3.85747202206403, 13.624109085649252, 4.843994798138738, 0.374839881551452, 0.3840360709000379, 0.38683381921146065, 1.6207689489237964, 1.078730528242886, 0.48005531542003155, 3.0663126753643155, 1.5803517051972449, 1.339766902383417, 0.42941353283822536, 1.3231255766004324, 0.25118418561760336, 2.2344000404700637, 1.2043204391375184, 0.858494583517313, 9.002820812165737, 13.278957456350327, 9.725182950496674, 0.6472374382428825, 1.7405413719825447, 11.137720104306936, 47.76389300823212, 14.051489252597094, 35.26651941239834, 4.840825293213129, 4.5619136095047, 25.642361640930176, 38.98627661168575, 54.66017335653305, 50.41947931051254, 47.129414454102516, 40.36912880837917, 37.83530697226524, 28.047556579113007, 33.128776922822, 36.738207042217255, 34.57359999418259, 34.410782530903816, 38.500305488705635, 41.88650518655777, 51.3272126019001, 53.86997155845165, 53.47276367247105, 54.26424600183964, 50.05895845592022, 44.41262103617191, 43.97091753780842, 47.744590044021606, 53.94080735743046, 60.66624127328396, 50.78407734632492, 37.65597179532051, 14.153473880141973, 4.918875005096197, 1.5201351488940418, 1.4912859094329178, 1.4435370778664947, 1.4445637352764606, 0.7432717632036656, 0.5426238267682493, 0.49563851673156023, 1.137980273924768, 0.3632050543092191, 0.7500453747343272, 0.4527582332957536, 0.6125621020328254, 0.4944243037607521, 0.17040532955434173, 0.18662927148398012, 0.7049119309522212, 0.6769944133702666, 0.6848705594893545, 0.9619045502040535, 0.7068801065906882, 0.5353551136795431, 0.1881452268571593, 0.2833510033087805, 0.26215137680992484, 0.4057083267252892, 0.04541266200249083, 0.10656960104824975, 0.20976312778657302, 0.32212979276664555, 0.025115550160990097, 0.026065744095831178, 0.25187937018927187, 0.37012822343967855, 0.18032123887678608, 0.3654157044366002, 0.449997978284955, 0.4336821287870407, 0.11167963661137037, 0.07668757403735071, 0.07384682568954304, 0.2085465844720602, 0.15666514809709042, 0.0830939931620378, 0.11611136404098943, 0.1888782312744297, 0.1482460170518607, 0.15958492032950744, 0.062150240628398024, 0.09906340070301667, 0.04748561404994689, 0.04714307207905222, 0.14431462332140654, 0.23021334840450436, 0.08724141123821028, 0.07936576977954246, 0.08082850574282929, 0.31662489753216505, 0.16446691617602482, 0.3116094635333866, 0.17477144370786846, 0.48901336442213506, 0.7041782734449953, 0.7670803356450051, 0.7399994856677949, 1.353924348950386, 1.0712557355873287, 0.7604013034142554, 0.8656030520796776, 0.5661373806651682, 0.31586099008563906, 0.12757886666804552, 0.10566360200755298, 0.7064516795799136, 1.1639973591081798, 1.0311463940888643, 1.670592469163239, 2.1888934448361397, 1.9838837580755353, 2.7195694064721465, 1.0227760369889438, 4.642799394205213, 1.2639014795422554, 12.609521728008986, 28.896887004375458, 64.30900320410728, 70.08495166897774, 72.38537862896919, 99.32642698287964, 91.21377110481262, 85.64146131277084, 98.07753279805183, 100.53461015224457, 111.00557908415794, 106.0415330529213, 97.81014874577522, 92.70331397652626, 81.80566594004631, 66.97251588106155, 60.68391032516956, 64.58567395806313, 46.10215477645397, 40.91981805860996, 32.20631182193756, 20.76922383159399, 17.313392870128155, 27.374608889222145, 33.27460169792175, 36.53474695980549, 45.70302799344063, 51.579918041825294, 45.513744950294495, 40.61033986508846, 34.78614918887615, 31.119511239230633, 39.429967403411865, 53.30128647387028, 21.10393837094307, 6.5244788490235806, 4.921940015628934, 1.2914388393983245, 7.706787306815386, 3.1067890534177423, 1.0845494410023093, 2.0960665633901954, 1.5631620213389397, 0.160997390630655, 2.1502822916954756, 3.5415166011080146, 2.3908651946112514, 0.7896964251995087, 0.5851149873342365, 1.1354170739650726, 1.6603885916993022, 0.2189425891265273, 2.0388660952448845, 2.4840656435117126, 0.6338042684365064, 4.733984051272273, 4.940977469086647, 6.5152158960700035, 1.419818988069892, 5.90838560834527, 17.078297585248947, 58.17215010523796, 41.18792787194252, 46.36320076882839, 24.986121654510498, 31.498170420527458, 33.97486612200737, 31.98363997042179, 35.42000837624073, 43.77857185900211, 54.86348904669285, 61.678214371204376, 54.70798999071121, 42.13062308728695, 35.10248601436615, 47.28548347949982, 46.75047218799591, 45.99103733897209, 51.47192403674126, 59.03286091983318, 70.1403146982193, 67.08440467715263, 58.174699768424034, 49.89839047193527, 49.909732863307, 52.09591515362263, 51.89518712460995, 53.01205359399319, 59.449025988578796, 58.693706318736076, 53.57227273285389, 44.26587291061878, 18.069219812750816, 2.5787978852167726, 1.0814401390962303, 1.3282728753983974, 1.7381104524247348, 1.003697735723108, 0.8792041847482324, 0.6255708227399737, 0.4116375820012763, 0.8171930559910834, 0.5010244308505207, 0.5586967861745507, 0.46231786720454693, 0.5584381031803787, 0.5072499811649323, 0.4228836722904816, 0.2756253647385165, 0.5398516973946244, 0.41429853765293956, 0.41706416581291705, 0.8243643993046135, 0.7280304841697216, 0.7210523961111903, 0.35162416636012495, 0.28706669923849404, 0.25757214752957225, 0.23906702175736427, 0.1807570131495595, 0.07182658097008243, 0.12610505043994635, 0.1531641703331843, 0.20769940805621445, 0.18083179194945842, 0.21571181248873472, 0.16549364780075848, 0.07051858279737644, 0.39646306657232344, 0.5239526380319148, 0.12424974062014371, 0.06266816693823785, 0.15323129016906023, 0.2373903914121911, 0.36146222439128906, 0.34099435550160706, 0.2915155777009204, 0.21787704317830503, 0.42350579984486103, 0.2520014683250338, 0.31886692566331476, 0.1784502697410062, 0.28157439082860947, 0.22807609668234363, 0.17137536109657958, 0.16832280380185694, 0.4762977920472622, 0.4975768580334261, 0.2977020019898191, 0.15488291013753042, 0.3175965172704309, 0.2733326330780983, 0.4872148734284565, 0.17821346526034176, 0.35036910558119416, 0.9250337036792189, 0.7710925047285855, 0.6388122809585184, 1.9581606821157038, 0.8103157812729478, 0.5319271038752049, 1.3829521788284183, 0.7939865137450397, 0.35254992137197405, 0.5171029712073505, 0.29395074234344065, 0.5036119732540101, 0.6650842493399978, 0.5174185917712748, 0.8913540921639651, 2.551698451861739, 1.7194910952821374, 1.7481586569920182, 0.7112629932817072, 2.541123144328594, 0.6447099801152945, 32.74960666894913, 72.13532164692879, 73.80755871534348, 70.18340438604355, 84.68526542186737, 107.50567808747292, 104.85221207141876, 90.91582149267197, 98.09702575206757, 102.35258460044861, 115.88720753788948, 105.88068008422852, 91.00360438227654, 83.72355222702026, 81.16566628217697, 76.26875504851341, 57.73565232753754, 60.094197168946266, 63.491720259189606, 56.423681527376175, 44.34835888445377, 27.19163540750742, 26.624709628522396, 44.95321802794933, 55.945101007819176, 65.85248798131943, 67.50770956277847, 96.82716429233551, 71.97972759604454, 59.60924059152603, 37.12489329278469, 34.536004811525345, 36.358884796500206, 73.24284821748734, 40.16224130988121, 12.672602143138647, 7.640197305008769, 27.260189428925514, 32.705939412117004, 11.833062842488289, 0.5016915325541049, 1.5606044023297727, 0.8233528223354369, 0.9450723440386355, 1.5207239985466003, 4.995016744360328, 6.750767156481743, 1.3876464706845582, 0.9870527882594615, 0.3443503472954035, 1.5077830804511905, 0.14150639588478953, 1.5738360048271716, 1.2125517474487424, 0.5873806157615036, 23.45647193491459, 26.97454735636711, 21.067678816616535, 10.836591012775898, 12.265171855688095, 23.668025583028793, 75.06806507706642, 34.394359812140465, 55.48413634300232, 18.2804124802351, 18.551596328616142, 34.276262149214745, 58.82069170475006, 83.02100792527199, 103.48718091845512, 105.78133061528206, 105.92599645256996, 97.66679003834724, 68.89027297496796, 62.281785383820534, 73.80650997161865, 71.17827460169792, 65.49219891428947, 66.70695573091507, 55.34639373421669, 63.26473943889141, 64.82820734381676, 69.66186717152596, 76.00175097584724, 71.04946911334991, 66.67433068156242, 65.84939494729042, 56.02499172091484, 62.255623787641525, 78.71542096138, 62.654473185539246, 58.80558371543884, 32.19240076839924, 2.9971437994390726, 0.6585827388335019, 0.5341065244283527, 1.0900182975456119, 1.2874065432697535, 1.120983192231506, 0.3840934834443033, 0.23360925290035084, 0.48877869732677937, 0.6587163847871125, 0.5844464607071131, 0.2312390410224907, 0.3272800601553172, 0.517322706291452, 0.5353628913871944, 0.2506986726075411, 0.5812688812147826, 0.42279909714125097, 0.3865154378581792, 0.6960741989314556, 0.4791621258482337, 0.6426238920539618, 0.49783791590016335, 0.21221873117610812, 0.25303320202510804, 0.49159511807374656, 0.28132808685768396, 0.2574379672296345, 0.3126730502117425, 0.3617600630968809, 0.22634438413660973, 0.1602085618651472, 0.3701711492612958, 0.453930203220807, 0.24328492901986465, 0.34669781976845115, 0.9202818211633712, 0.6864570931065828, 0.13139605871401727], [0.12999194499570876, 0.24810307048028335, 0.11014556541340426, 0.08508778031682596, 0.15084148559253663, 0.2346841202233918, 0.11967347250902094, 0.1334593034698628, 0.09867212560493499, 0.1631257514236495, 0.2417013788362965, 0.22253942268434912, 0.020489960770646576, 0.046643369205412455, 0.14779333665501326, 0.04055073011841159, 0.19283978588646278, 0.06870075885672122, 0.09624076075851917, 0.25832762417849153, 0.4598511167569086, 0.8489031263161451, 1.077232458628714, 0.39993533806409687, 0.5137946549803019, 0.8228906127624214, 1.539955954067409, 1.1640006839297712, 0.4020694876089692, 0.18720544525422156, 0.3185821190709248, 0.15022722480352968, 0.12469691428123042, 0.46180225268471986, 0.4508647770853713, 1.6722601046785712, 1.2639539642259479, 2.1989526925608516, 1.5323754795826972, 3.1916351756080985, 3.7973093753680587, 3.5798677057027817, 2.318718465976417, 2.3999524069949985, 0.6905829592142254, 20.87455987930298, 34.08694490790367, 53.14888425171375, 64.6831539273262, 62.267809733748436, 65.72862982749939, 76.7869408428669, 72.49510914087296, 73.12168031930923, 84.46094065904617, 82.27947771549225, 73.35912197828293, 80.44002681970596, 69.57363590598106, 55.45804314315319, 41.901274994015694, 29.43661194294691, 28.226148895919323, 22.127117067575455, 16.19660809636116, 18.93363732844591, 33.95670309662819, 47.37140066921711, 50.77381029725075, 34.59732212126255, 8.322058841586113, 15.229051765054464, 15.782163385301828, 10.481208432465792, 8.122570496052504, 4.714600816369057, 29.468566328287125, 38.08920934796333, 18.284685350954533, 2.746706837788224, 6.408824929967523, 11.161376684904099, 9.069908112287521, 3.43930731061846, 3.9186789002269506, 2.7083626203238964, 4.134256532415748, 1.1375924572348595, 3.700811415910721, 7.7698601223528385, 3.557753604836762, 2.3491664696484804, 1.9349128170870245, 4.392534848302603, 2.8627561731263995, 1.561307127121836, 0.9195902582723647, 1.3269276288338006, 4.771963013336062, 6.541193202137947, 7.6524511724710464, 2.3181197606027126, 3.983447137288749, 6.360158566385508, 1.4466696535237134, 33.35326887667179, 43.60292628407478, 46.629437282681465, 28.37594635784626, 20.879100635647774, 9.081234354525805, 6.549147125333548, 22.892924174666405, 21.16867359727621, 16.129195913672447, 25.90858295559883, 32.1203338354826, 38.535180017352104, 48.0176167935133, 45.86228124797344, 45.73390893638134, 48.18722069263458, 53.36572341620922, 52.94819802045822, 44.43867623806, 38.59358288347721, 31.555621437728405, 29.757926501333714, 31.832915358245373, 36.1727137863636, 38.50736930966377, 41.61411300301552, 39.95028108358383, 35.27796819806099, 32.62556232511997, 17.168994918465614, 6.511644087731838, 3.0208110669627786, 2.928004846908152, 2.6333375461399555, 0.954889829736203, 1.7612995393574238, 2.2148500895127654, 1.3504525227472186, 1.0266911331564188, 1.1104346020147204, 1.910334904678166, 0.9124939609318972, 0.8921556710265577, 1.1359516577795148, 0.6293511448893696, 0.7650200149510056, 0.8216221339534968, 0.6538239098154008, 0.4766635224223137, 0.4636947886319831, 1.157887524459511, 0.8124245493672788, 0.6996541412081569, 0.5414625734556466, 0.29575356747955084, 0.16871293599251658, 0.06313025776762515, 0.07674054853850976, 0.5082010582555085, 0.1300183654529974, 0.05286651496135164, 0.38453621906228364, 0.374244975973852, 0.1412738364888355, 0.45993266394361854, 0.2907143550692126, 0.4268243577098474, 0.5187615228351206, 0.11471761070424691, 0.04098648212675471, 0.06495108740637079, 0.18233208800666034, 0.17265868285903707, 0.1401132214232348, 0.2039599634008482, 0.21397730946773663, 0.18524197483202443, 0.1099244350916706, 0.08740275414311327, 0.1721074155648239, 0.1475362418568693, 0.16822044679429382, 0.01891314186650561, 0.02068156289169565, 0.12282386713195592, 0.04006555478554219, 0.13528204784961417, 0.05734627047786489, 0.36883837077766657, 0.381318029249087, 0.2747954655205831, 0.42036633705720305, 0.6389223563019186, 0.471245072549209, 0.7930128753650934, 0.8315518917515874, 0.8283094188664109, 0.7867898780386895, 0.5868085089605302, 0.30626341758761555, 0.11825977766420692, 0.08411092101596296, 0.18313252396183088, 0.2917056862497702, 0.03517004814057145, 1.2342193722724915, 1.3896248582750559, 2.2859727730974555, 1.5491127502173185, 3.0273878015577793, 4.0416027791798115, 4.1509651858359575, 1.6696123592555523, 2.072044489905238, 0.3092049644328654, 6.781742619350553, 35.47035187482834, 59.11388397216797, 71.45125195384026, 78.95442813634872, 81.49193957448006, 85.90008303523064, 83.49895387887955, 84.92038160562515, 81.68195217847824, 87.31998324394226, 93.52645620703697, 88.01926732063293, 67.85700961947441, 59.34392362833023, 52.95914143323898, 37.046047523617744, 26.08313988894224, 22.70182102918625, 21.148285791277885, 26.68890718370676, 37.50719077885151, 36.751624122262, 47.125272676348686, 56.010408103466034, 45.46425260603428, 31.100407764315605, 27.240365892648697, 29.186235778033733, 18.869960345327854, 14.318201690912247, 35.10791972279549, 65.08525595068932, 36.36147625744343, 12.655777595937252, 7.183889765292406, 14.125441834330559, 11.832497622817755, 0.554661521455273, 3.9562565088272095, 1.1876122606918216, 3.2338891457766294, 2.893327670171857, 1.6218845453113317, 4.7480100486427546, 4.713107971474528, 4.08550419844687, 3.016382404603064, 4.313959339633584, 0.9737823565956205, 1.8150315061211586, 2.7210071543231606, 1.4945270167663693, 3.738871836103499, 12.94209698215127, 13.378045689314604, 7.556674461811781, 3.043193290941417, 6.566320303827524, 18.947867564857006, 72.21581652760506, 54.38708961009979, 13.313855733722448, 10.786649342626333, 29.2161762714386, 27.36487191170454, 13.283609356731176, 15.695623029023409, 11.399378813803196, 19.513913691043854, 40.0697922706604, 65.55793538689613, 76.83800250291824, 70.22346943616867, 50.596952587366104, 55.51024854183197, 56.135014817118645, 57.89974272251129, 64.98275265097618, 55.1436822116375, 48.590360060334206, 39.3162015080452, 32.28306770324707, 34.91892546415329, 39.9315594881773, 45.26088371872902, 43.6207777261734, 42.328140288591385, 42.02394761145115, 27.299893498420715, 13.281092941761017, 5.454579759389162, 3.614172264933586, 3.1954209599643946, 2.6427978510037065, 1.361946074757725, 1.0225722729228437, 1.2640407658182085, 1.371303666383028, 1.3964268495328724, 1.5319523960351944, 1.9776176568120718, 0.949170661624521, 1.000625838059932, 1.388597369659692, 0.6068109325133264, 0.5171618680469692, 0.6856873375363648, 0.681891756830737, 0.7232734956778586, 0.5792190693318844, 0.582722956314683, 0.6672831438481808, 0.6644503364805132, 0.36341395403724164, 0.29276170302182436, 0.2905825199559331, 0.06346998328808695, 0.017854794750746805, 0.27887036092579365, 0.19749524857616052, 0.1212156553810928, 0.3654248476959765, 0.26417717279400676, 0.2499634714331478, 0.29228402709122747, 0.2832398295868188, 0.1412608934333548, 0.20582652417942882, 0.08692918228916824, 0.2209475010749884, 0.2045110080507584, 0.28384741104673594, 0.23124644765630364, 0.20883514633169398, 0.2776185952825472, 0.2862539584748447, 0.3522564464947209, 0.3130643698386848, 0.2542592299869284, 0.18901422241469845, 0.4633097327314317, 0.18518782773753628, 0.10237094509648159, 0.2627767698140815, 0.25878962595015764, 0.1415776865906082, 0.18445667868945748, 0.08690450587891974, 0.4508014570455998, 0.4708033462520689, 0.3735932515701279, 0.5458458163775504, 0.850836985046044, 0.39757937542162836, 0.5350122414529324, 0.4684645717497915, 1.1505865724757314, 1.0022088093683124, 0.6102875678334385, 0.31441285216715187, 0.637458722339943, 0.2503020688891411, 0.4867893853224814, 0.9718939173035324, 0.9808989590965211, 1.404025610536337, 1.09324800549075, 1.1281307274475694, 0.5057966778986156, 2.0017629861831665, 2.809277130290866, 3.4159411769360304, 1.4031420391984284, 1.5340703073889017, 0.35547086619772017, 36.73634134232998, 76.99505567550659, 83.8070185482502, 88.63732695579529, 84.04056161642075, 79.86171305179596, 95.59102982282639, 93.33102509379387, 97.13934034109116, 95.38152426481247, 89.81150195002556, 91.6004991531372, 91.97056129574776, 73.05855810642242, 59.43511113524437, 70.37996783852577, 63.13862040638924, 43.89587916433811, 34.773837849497795, 29.272363856434822, 50.31750798225403, 72.24366143345833, 66.33406654000282, 78.83303225040436, 87.49611139297485, 83.33775892853737, 48.93667347729206, 41.41178905963898, 35.91007947921753, 19.05957017093897, 17.858690209686756, 45.64019836485386, 61.06305778026581, 36.87317579984665, 23.929833434522152, 20.915882661938667, 30.655064061284065, 23.444472178816795, 8.062386475503445, 7.141231829300523, 1.6529757832176983, 3.9764566998928785, 2.523313737474382, 9.20246209949255, 14.367183912545443, 6.682421173900366, 4.925251062959433, 2.308633807115257, 5.37538155913353, 2.4630515836179256, 2.125940560363233, 2.4220292223617435, 1.2671048264019191, 7.0294874254614115, 21.875201985239983, 19.61890395730734, 7.120212782174349, 6.073047872632742, 9.523112643510103, 21.684087440371513, 74.3390741944313, 66.28570273518562, 29.75594110786915, 38.11098977923393, 41.311208456754684, 20.5161365121603, 8.35979936644435, 31.598910614848137, 60.19208751618862, 84.75632160902023, 120.00553295016289, 147.38684087991714, 139.94033485651016, 105.67524030804634, 81.1774380505085, 83.10801565647125, 89.10656377673149, 79.32659536600113, 79.19253095984459, 71.1908595263958, 67.59385094046593, 52.569236755371094, 38.853036761283875, 42.083266228437424, 55.22433668375015, 63.880082219839096, 63.40964846313, 61.27385526895523, 55.27130216360092, 53.26745688915253, 21.10993254929781, 4.405846009030938, 1.6196020552888513, 1.2387420795857906, 1.8245599698275328, 2.517824932001531, 1.6349330451339483, 1.596928434446454, 1.0287110810168087, 0.6647596636321396, 0.9241089876741171, 1.168205989524722, 0.36659557081293315, 0.49614181159995496, 1.3005220144987106, 0.5325600074138492, 0.4073142452398315, 0.36293681245297194, 0.32068506872747093, 0.3645946813048795, 0.7220702664926648, 0.868500693468377, 0.9327728790231049, 0.7882685330696404, 0.38584394264034927, 0.3578221087809652, 0.3672847291454673, 0.15323161671403795, 0.14912256767274812, 0.41756036574952304, 0.2513739082496613, 0.1942193938884884, 0.3706711786799133, 0.45693664345890284, 0.14012099913088605, 0.4243402706924826, 0.4985660221427679, 0.3370686911512166, 0.3011085488833487, 0.0840561802033335, 0.28555915981996804], [0.31627219927031547, 0.1056556536059361, 0.10044439652119763, 0.18630958395078778, 0.10090156691148877, 0.048451983093400486, 0.14788377477088943, 0.04129403183469549, 0.27285091986414045, 0.07782234009937383, 0.07669239057577215, 0.1779947691829875, 0.11134053449495696, 0.07222262065624818, 0.21009520918596536, 0.20824889419600368, 0.24083613854600117, 0.23560836125398055, 0.12541887554107234, 0.3248336148681119, 0.5067124881315976, 0.2969213220058009, 0.6948780349921435, 1.0937745147384703, 1.349211058113724, 1.5322139882482588, 0.7508692773990333, 0.5877737165428698, 0.6847334699705243, 0.384398031164892, 0.1974402999621816, 0.20814405841520056, 0.17272709403187037, 0.26626590290106833, 0.13101788994390517, 0.2093415879062377, 0.6598050857428461, 1.5034428820945323, 4.125319886952639, 4.3852088414132595, 4.256150191649795, 4.408320626243949, 3.0929207475855947, 1.7485756846144795, 2.1355808805674314, 2.221051356755197, 15.350979622453451, 30.67755125463009, 34.35146391391754, 48.15555319190025, 56.500061228871346, 55.30321665108204, 55.89562006294727, 63.249874636530876, 61.9777674973011, 57.67663389444351, 68.58527854084969, 66.27095952630043, 66.20924323797226, 67.40779012441635, 55.86193487048149, 44.00867611169815, 23.065091036260128, 5.804126802831888, 15.990816839039326, 35.6862410902977, 39.68393437564373, 29.484681263566017, 17.168704234063625, 14.24296572804451, 16.739291176199913, 11.025046650320292, 1.5091346204280853, 5.375713091343641, 6.915458869189024, 4.887950364500284, 24.53010242432356, 35.548563078045845, 25.398576222360134, 3.531235777772963, 5.974977510049939, 7.30481400154531, 25.497241728007793, 15.88961686939001, 6.780346669256687, 5.090903649106622, 1.6140852263197303, 4.738302994519472, 2.9138263827189803, 3.7697976641356945, 5.203911010175943, 4.290233412757516, 5.977096371352673, 3.5147855104878545, 1.6373969754204154, 4.297541845589876, 4.52872809022665, 1.9161928840912879, 8.313847482204437, 11.25369368121028, 3.488495433703065, 2.8324544616043568, 4.2049626633524895, 3.6773450626060367, 11.136374976485968, 47.4339909106493, 40.939945578575134, 3.664576797746122, 4.154553143307567, 4.882995905354619, 7.726448401808739, 11.6499706171453, 3.093527527526021, 1.4362186705693603, 9.805516339838505, 13.558706045150757, 3.087322935461998, 16.62993874400854, 31.158975921571255, 30.745085030794144, 38.64045336842537, 45.01310281455517, 46.57541938126087, 46.130360662937164, 49.53850418329239, 40.451219603419304, 40.70295229554176, 37.209294363856316, 31.587357334792614, 25.64161878079176, 18.254663161933422, 20.48779383301735, 27.998991385102272, 19.431680403649807, 7.352597862482071, 3.6873185774311423, 5.466207135468721, 6.275329068303108, 5.635824808850884, 2.177669322118163, 1.2645094469189644, 1.1231109593063593, 1.5035674441605806, 2.1214914740994573, 2.0661063585430384, 2.1197946276515722, 1.5981725114397705, 2.4074838403612375, 2.3716574627906084, 1.356627547647804, 1.6923544951714575, 1.1191337602213025, 1.885193435009569, 1.7154773231595755, 1.4913127454929054, 1.2239303556270897, 0.26693386549595743, 0.3054971946403384, 0.5031858617439866, 0.2541438111802563, 0.5927414749749005, 0.6138260092120618, 0.347847911179997, 0.07162228255765513, 0.07463520174496807, 0.17523996153613552, 0.19692167232278734, 0.11381567863281816, 0.27443178347311914, 0.1295817451318726, 0.14750753558473662, 0.5204528477042913, 0.23521533468738198, 0.07482726956368424, 0.039640649265493266, 0.1291870413115248, 0.21611154807033017, 0.11508632451295853, 0.18465342203853652, 0.11078539318987168, 0.08343552210135385, 0.04700230150774587, 0.11402424439438619, 0.19190429389709607, 0.3442389064002782, 0.0650289683835581, 0.05059628892922774, 0.21418266172986478, 0.10872191094676964, 0.11027273983927444, 0.1453176062204875, 0.06774309891625308, 0.07956423491123132, 0.1649709086632356, 0.23633553239051253, 0.07953308697324246, 0.5492603487800807, 0.5104658554773778, 1.0158969811163843, 1.007863380946219, 1.1240195855498314, 1.4745208527892828, 1.0065241903066635, 0.7906184694729745, 0.7998206256888807, 0.32444852928165346, 0.1123129780171439, 0.06935911063919775, 0.1708999412949197, 0.10511282453080639, 0.12440975508070551, 0.6189370318315923, 0.9804241626989096, 1.7834267020225525, 4.734253361821175, 5.479430425912142, 5.196718471124768, 4.212840590626001, 2.9454492358490825, 2.098281607031822, 2.0788045646622777, 2.426813403144479, 10.205768812447786, 24.72361844033003, 53.87383595108986, 53.0092379450798, 65.36085516214371, 72.66498282551765, 68.75148922204971, 63.460599929094315, 72.91111081838608, 77.3151732981205, 73.5808476805687, 71.11714348196983, 82.07118809223175, 80.88470935821533, 57.0766194909811, 40.74864484369755, 34.432262778282166, 27.469250410795212, 26.951902471482754, 26.566827334463596, 26.711213886737823, 48.64100754261017, 53.705125004053116, 29.719261676073074, 11.807741951197386, 19.28117997944355, 19.727549627423286, 11.730460748076439, 6.587667558342218, 5.518428683280945, 24.067758433520794, 44.58349786698818, 38.06120865046978, 29.1846626624465, 18.473373726010323, 16.601833552122116, 6.203940398991108, 5.326844388619065, 4.1554071474820375, 4.155002469196916, 3.081449163146317, 0.6986127002164721, 3.753890530206263, 8.185741156339645, 4.987322632223368, 7.3037258349359035, 8.129462376236916, 5.681289844214916, 2.279108203947544, 3.500264114700258, 1.6453822469338775, 2.2503349604085088, 6.025496749207377, 12.393698059022427, 4.983683377504349, 1.9503872492350638, 4.936877964064479, 10.584631282836199, 24.80232171714306, 46.35545678436756, 32.184208407998085, 29.635755456984043, 31.43424265086651, 17.879442796111107, 8.007465172559023, 9.502183366566896, 7.128751873970032, 3.1869661761447787, 8.923655860126019, 7.893839394673705, 6.202467503026128, 33.59340459108353, 50.05539044737816, 55.09081944823265, 57.813513949513435, 53.73961955308914, 59.24404978752136, 60.27280278503895, 62.72099241614342, 53.5161117464304, 47.874501273036, 48.74031901359558, 41.91155344247818, 30.79829927533865, 19.803351759910583, 16.728176772594452, 17.158482782542706, 12.45236311107874, 7.374003538861871, 4.209625963121653, 5.664545092731714, 5.5372595228254795, 5.163834560662508, 2.939252480864525, 1.3478128518909216, 1.30140962311998, 2.4633102072402835, 2.449925900436938, 2.0971172070130706, 1.6218546219170094, 1.7553724511526525, 2.309692525304854, 2.051531528122723, 1.8527907924726605, 1.6638752608560026, 1.2116378964856267, 2.0052552362903953, 1.7118195444345474, 1.2182762590236962, 1.1626250389963388, 0.941552723525092, 0.5150216328911483, 0.2681437146384269, 0.35598499642219394, 0.38682390411850065, 0.2529028512071818, 0.29106432222761214, 0.11478244472527876, 0.06326315415208228, 0.12718163954559714, 0.05671885512128938, 0.1750057694152929, 0.4147260740865022, 0.4193381656659767, 0.22349480423144996, 0.14192550152074546, 0.15600806538714096, 0.07665411802008748, 0.05837847544171382, 0.17865146597614512, 0.36162356729619205, 0.167398251069244, 0.18510933819925413, 0.19728093117009848, 0.2629588631680235, 0.17961774225113913, 0.1879837503656745, 0.4069024423370138, 0.4017413395922631, 0.23052104283124208, 0.1182579668238759, 0.17533293779706582, 0.29411312425509095, 0.16050522797740996, 0.3932899993378669, 0.255556118208915, 0.19042860745685175, 0.17013319884426892, 0.5088596104178578, 0.7535337656736374, 0.5139369098469615, 0.27913260622881353, 0.5146056739613414, 0.5875154491513968, 0.8392994978930801, 0.9158842102624476, 0.37438895262312144, 0.39303939091041684, 0.5845858657266945, 0.3431108419317752, 0.2707278431626037, 0.3511016647098586, 0.2613528852816671, 0.3414520825026557, 0.23550367390271276, 0.8379674318712205, 1.1037248745560646, 1.6422134544700384, 2.9819659888744354, 3.3307283744215965, 3.5160437179729342, 2.545722322538495, 1.3193254242651165, 0.8355622796807438, 1.420113353524357, 1.040463731624186, 35.334250777959824, 79.26304757595062, 81.60483911633492, 88.60312879085541, 91.06777533888817, 81.26673325896263, 79.21683445572853, 71.21981397271156, 80.47660365700722, 88.1391128897667, 90.26069864630699, 81.74655631184578, 75.04989445209503, 76.46538689732552, 64.06904608011246, 57.26111479103565, 48.18658232688904, 68.57691898941994, 91.56627058982849, 81.51030018925667, 68.50018590688705, 79.83664959669113, 85.69689273834229, 63.731696382164955, 33.42662014067173, 23.510398641228676, 12.259040884673595, 5.691932123154402, 4.884089296683669, 9.584878329187632, 39.82888139784336, 55.317329093813896, 33.282638266682625, 35.91304711997509, 23.722721748054028, 14.935171734541655, 38.26770476996899, 28.266584426164627, 6.903984434902668, 8.3680534735322, 5.927480533719063, 5.743305841460824, 9.355066660791636, 16.39616008847952, 9.940146915614605, 7.991080451756716, 9.267525058239698, 3.512185737490654, 1.4587080013006926, 3.3687728829681873, 6.208358136937022, 3.487763023003936, 17.716921716928482, 18.601960726082325, 5.5850353091955185, 2.68760837148875, 5.912954388186336, 11.738691106438637, 28.545145578682423, 66.17517426609993, 66.09490737318993, 41.05666011571884, 27.478092536330223, 14.132806789129972, 23.711162768304348, 12.626086939126253, 3.3514838106930256, 1.0765028977766633, 18.50914690643549, 40.78601583838463, 58.98904547095299, 78.33753123879433, 80.80295294523239, 80.40234804153442, 74.85251784324646, 73.5151644051075, 88.19414153695107, 96.92407429218292, 95.84628492593765, 74.29582491517067, 56.33464090526104, 58.18424865603447, 60.4993162304163, 58.06899704039097, 51.673792004585266, 46.78224228322506, 39.43572409451008, 23.85171912610531, 4.2858764715492725, 1.1624415800906718, 2.7356449188664556, 3.8921917090192437, 5.650720484554768, 3.101919377222657, 1.324278220999986, 0.7431670313235372, 1.393964581657201, 1.5592393255792558, 1.714516212232411, 1.5799169847741723, 1.1587080429308116, 1.5768569614738226, 1.8365688691847026, 1.376746993046254, 1.0988239687867463, 0.4183027212275192, 1.147801203187555, 1.3494458142668009, 1.2501795846037567, 0.6152411364018917, 0.4633821069728583, 0.4195595037890598, 0.37980235589202493, 0.36558743740897626, 0.4174154985230416, 0.39208754198625684, 0.2561201504431665, 0.24487174465321004, 0.2338784298626706, 0.23733006964903325, 0.1805165721452795, 0.21275672886986285, 0.4083861439721659, 0.49558742728549987, 0.30741104506887496, 0.5898274469655007, 0.22053712309570983, 0.0966972483729478, 0.1383660128340125, 0.5211470823269337], [0.09515951096545905, 0.012144375632487936, 0.1610222228919156, 0.05570845074544195, 0.1480572295258753, 0.17957714677322656, 0.023958003876032308, 0.12191207191790454, 0.27494665584526956, 0.31895823951344937, 0.11083646779297851, 0.11991386898444034, 0.12640204309718683, 0.27919102809391916, 0.3632664744509384, 0.3713280981173739, 0.18197115190559998, 0.1646425380022265, 0.16024837066652253, 0.10453386770677753, 0.14960034750401974, 0.5594648199621588, 1.431989734992385, 1.65602951310575, 1.435251859948039, 1.7683430551551282, 2.029258073307574, 1.0241830302402377, 0.6554997980128974, 0.1734532558475621, 0.13477434462402016, 0.3156689222669229, 0.1926730846753344, 0.12082352681318298, 0.5636586667969823, 0.43858537974301726, 0.6812080310191959, 0.7505504507571459, 3.1475523160770535, 4.9017540737986565, 5.311403442174196, 6.109020542353392, 6.381971770897508, 5.973253827542067, 3.192025604657829, 4.365791408345103, 2.1405761875212193, 2.4441442731767893, 11.661072671413422, 17.562895081937313, 30.463843122124672, 40.926156118512154, 39.6314287930727, 36.47279888391495, 43.702511340379715, 50.14609158039093, 55.648295134305954, 64.43428248167038, 79.38423827290535, 74.88876029849052, 60.47442376613617, 31.372457966208458, 11.152200177311897, 15.77119242399931, 15.256093963980675, 15.078627336770296, 11.85249499976635, 7.523476118221879, 11.598477680236101, 10.528431348502636, 2.992569082416594, 1.5340622328221798, 0.9713012084830552, 0.9297143993899226, 0.6683865690138191, 2.970295390114188, 6.380122695118189, 6.401837579905987, 20.04157617688179, 15.853495057672262, 4.837317606434226, 5.591717725619674, 9.202726185321808, 21.863616406917572, 12.862877883017063, 5.835791928693652, 2.506732614710927, 0.6908486480824649, 0.7211146177724004, 3.1598667427897453, 2.918507969006896, 0.8875638549216092, 2.816109638661146, 2.6874860655516386, 3.4826971823349595, 2.89714100304991, 3.676060256548226, 7.448778301477432, 10.634365864098072, 5.236701350659132, 3.7323817843571305, 3.5238696355372667, 2.4774554232135415, 7.120210407301784, 27.18813769519329, 6.054846374318004, 19.06061891466379, 10.115070529282093, 6.522846361622214, 5.928141223266721, 5.480533791705966, 5.514871599152684, 5.896556843072176, 9.557505548000336, 5.848212037235498, 1.7411381774581969, 2.0831035589799285, 6.120034251362085, 9.117157626897097, 22.666549421846867, 32.00426526367664, 29.05754428356886, 30.399848856031895, 33.36678475141525, 32.299425825476646, 37.43358492851257, 37.698723301291466, 31.29220437258482, 23.315353207290173, 16.98900807648897, 6.924318093806505, 1.1988076474517584, 2.0527187269181013, 3.0834409687668085, 6.117800921201706, 8.028255756944418, 6.790173891931772, 5.779832806438208, 3.5145938582718372, 2.2759270621463656, 2.19773699529469, 2.9568578861653805, 3.533973768353462, 2.062156470492482, 1.1715367482975125, 0.9532410150859505, 2.199333622120321, 1.7657540878280997, 1.2736918916925788, 0.8516522194258869, 0.8904999692458659, 1.4919405430555344, 1.8645587610080838, 1.4041238115169108, 1.3431021734140813, 0.9740603354293853, 0.9881724219303578, 0.5390277947299182, 0.2137305898941122, 0.20372790866531432, 0.02020300194999436, 0.05468726667459123, 0.14733280433574691, 0.21457528753671795, 0.17675219132797793, 0.11433850682806224, 0.32726025965530425, 0.39361437724437565, 0.220478834817186, 0.4237866878975183, 0.3353327186778188, 0.06124230829300359, 0.24846180982422084, 0.12489585438743234, 0.0910920073511079, 0.1628636397072114, 0.1274928665952757, 0.0750008133763913, 0.10920236993115395, 0.10745093852165155, 0.13111175678204745, 0.06290179502684623, 0.036813894112128764, 0.06399270016117953, 0.2731976512586698, 0.3112190047977492, 0.15504805283853784, 0.1395819179015234, 0.17663654987700284, 0.4060186631977558, 0.22362104355124757, 0.3263707511359826, 0.17681619414361194, 0.2082268672529608, 0.034025860513793305, 0.238662862975616, 0.41105440235696733, 0.7156614947598428, 0.9461253031622618, 1.3907276303507388, 1.6294321278110147, 1.776318233460188, 2.0587169425562024, 1.039990538265556, 0.6069512874819338, 0.42647326248697937, 0.28105135483201593, 0.26374067121651024, 0.18157880811486393, 0.30403884476982057, 0.8009597333148122, 0.5944746569730341, 1.2242082157172263, 0.8990167966112494, 2.199025838635862, 4.624850582331419, 6.045404355973005, 6.893878877162933, 6.369884619489312, 5.188319021835923, 3.1905576959252357, 2.8384177666157484, 1.609217687509954, 5.816505113616586, 10.62366658821702, 27.620512694120407, 39.935070499777794, 44.324477165937424, 48.29978585243225, 52.778848707675934, 54.844243079423904, 59.61724676191807, 67.793028652668, 76.97342723608017, 86.89212620258331, 79.85165119171143, 67.39291772246361, 44.172869101166725, 17.52105552703142, 14.53091237694025, 13.304734323173761, 20.95259439200163, 30.823548920452595, 27.645378559827805, 7.385492697358131, 11.200919263064861, 9.297150168567896, 3.046117234043777, 1.5169859491288662, 0.8261972072068602, 1.589390707667917, 3.273023720830679, 17.268750965595245, 31.530117206275463, 20.101983435451984, 24.863887913525105, 9.476910922676325, 6.510607218369842, 13.383374903351068, 15.584397297352552, 9.858184363692999, 2.0653371373191476, 1.0192029224708676, 1.52961409650743, 1.585234443191439, 8.086699470877647, 5.066176475957036, 7.427028268575668, 4.309748690575361, 2.8275990346446633, 3.089570514857769, 2.8290182584896684, 6.57786313444376, 5.825616549700499, 5.53907772526145, 2.041619997471571, 0.9053201240021735, 3.282891078852117, 3.2125461660325527, 9.19867180287838, 25.45665230602026, 39.95751969516277, 36.32333390414715, 19.3516243994236, 11.78325416520238, 7.086077313870192, 8.06497698649764, 8.344570733606815, 5.359274698421359, 4.96200886555016, 5.543177705258131, 2.8092215582728386, 2.626739675179124, 3.483314886689186, 8.240615911781788, 24.372984655201435, 42.31987193226814, 48.96190032362938, 40.62506787478924, 33.87017793953419, 36.320518255233765, 44.345300048589706, 48.430020064115524, 36.89879022538662, 29.1942248493433, 26.763772666454315, 17.85975605249405, 9.421291407197714, 3.4254321176558733, 3.1539366859942675, 6.556490706279874, 7.968413243070245, 6.4361359644681215, 5.199265284463763, 4.302112525328994, 3.032603021711111, 2.599936625920236, 3.0616527004167438, 2.9570291144773364, 1.7967024771496654, 1.324239510577172, 0.8486689638812095, 1.4816612633876503, 1.1417622584849596, 0.737855153856799, 0.5187709629535675, 0.7449389831162989, 1.7192576453089714, 1.5562606416642666, 1.8546298937872052, 1.72740179579705, 1.5603335481137037, 0.9584711375646293, 0.6305936782155186, 0.1471098928595893, 0.07765992850181647, 0.09286637854529545, 0.06775913672754541, 0.2820998610695824, 0.18714221427217126, 0.1606948021799326, 0.25092363241128623, 0.5168447631876916, 0.39375743363052607, 0.4926411306951195, 0.43764493020717055, 0.28765305527485907, 0.16345335025107488, 0.06618861123570241, 0.0706946276477538, 0.025339810490550008, 0.161490889149718, 0.17174701381009072, 0.13548039423767477, 0.21928008820395917, 0.17623638384975493, 0.25808701990172267, 0.30778974818531424, 0.3513649193337187, 0.512725249864161, 0.42318352963775396, 0.5893061030656099, 0.34692883549723774, 0.2994619606761262, 0.29496923612896353, 0.49586139852181077, 0.31660227687098086, 0.29997113335411996, 0.14061967784073204, 0.2044498105533421, 0.27029428048990667, 0.2474389225244522, 0.401152697741054, 0.6433691864367574, 1.1998996138572693, 1.113237664103508, 0.9236590680666268, 0.9622727148234844, 1.142877023667097, 0.5542371317278594, 0.428883817512542, 0.25545456272084266, 0.16639563924400136, 0.4545301554026082, 0.23516255314461887, 0.2043507486814633, 0.35723593086004257, 0.5066937860101461, 1.6377986851148307, 2.0252112904563546, 3.782969182357192, 4.149536462500691, 4.198188101872802, 4.373294580727816, 3.764830380678177, 3.1721643079072237, 2.064036657102406, 3.3856230787932873, 0.8123500377405435, 8.690550718456507, 51.067105159163475, 69.36885729432106, 82.34676450490952, 86.03580415248871, 82.46762841939926, 83.1368713080883, 80.41062399744987, 79.92510885000229, 83.25072839856148, 91.49259254336357, 101.65727511048317, 92.44169801473618, 80.02986162900925, 68.5729444026947, 65.13264700770378, 47.10442699491978, 23.192764185369015, 29.283052682876587, 32.23787672817707, 41.436225548386574, 37.20566935837269, 16.68567795306444, 5.174879617989063, 0.771438404917717, 0.4098064068239182, 1.2313581258058548, 2.8451113449409604, 2.9606719315052032, 12.748446073383093, 30.283029824495316, 34.58293229341507, 23.223113156855106, 11.697362624108791, 18.62561635673046, 28.845842443406582, 64.0366718173027, 25.90264767408371, 18.735219575464725, 4.692190093919635, 1.1488657398149371, 5.150743313133717, 16.75297424197197, 6.63391487672925, 11.218368876725435, 8.65770623087883, 4.958866909146309, 4.0763618890196085, 3.7319293711334467, 5.423584347590804, 12.989209704101086, 23.231058530509472, 7.353168781846762, 3.696591267362237, 4.9641956482082605, 5.773171288892627, 14.555586352944374, 53.36455687880516, 58.121130242943764, 27.91985683143139, 13.483887109905481, 6.886931899935007, 2.8390311961993575, 3.0022887233644724, 4.5063278172165155, 8.949571419507265, 8.391989339143038, 5.122477579861879, 1.4394075307063758, 1.586556772235781, 7.817346649244428, 30.286907516419888, 47.193418219685555, 66.67129084467888, 73.65656241774559, 66.74606323242188, 61.749354153871536, 64.89243909716606, 64.00694221258163, 72.19725832343102, 70.55060908198357, 61.519709676504135, 47.81394012272358, 38.296328634023666, 20.657855607569218, 4.767813161015511, 1.7127039469778538, 4.116798369213939, 4.920296128839254, 4.80525397695601, 5.462918886914849, 4.2153707798570395, 2.6015729131177068, 1.8622108432464302, 2.384555395692587, 3.0818319926038384, 1.743623719085008, 1.7652452713809907, 1.078401489648968, 1.7047484801150858, 1.559760372620076, 1.19957817485556, 0.6328164995647967, 0.660128187155351, 1.3115174369886518, 1.203480209223926, 1.026594357099384, 1.0011893953196704, 1.1793336924165487, 1.0939599922858179, 0.7931184978224337, 0.31490670691709965, 0.14573197695426643, 0.2199889876646921, 0.08378021258977242, 0.27914483682252467, 0.25692828989122063, 0.41526258748490363, 0.3076901816530153, 0.532681600889191, 0.5307042226195335, 0.31334795930888504, 0.44957430101931095, 0.368376606493257, 0.34950432542245835, 0.28514655539765954, 0.19060004357015714, 0.14937186992028728, 0.2358962848666124], [0.039140430599218234, 0.0388980488787638, 0.21287391398800537, 0.11843129541375674, 0.14816997660091147, 0.20227276487275958, 0.09328248590463772, 0.1361773896496743, 0.1493737252894789, 0.07042535420623608, 0.06986388238146901, 0.1189983927179128, 0.18668755976250395, 0.13414613145869225, 0.3261766053037718, 0.3233755618566647, 0.3415159962605685, 0.08723082079086453, 0.12530768697615713, 0.08940944724599831, 0.21662419399945065, 0.23539560235803947, 0.6020108994562179, 1.1363166756927967, 1.4136001467704773, 1.5556152700446546, 1.080403032246977, 0.7935829635243863, 0.6417324836365879, 0.5643429863266647, 0.285937269218266, 0.074337941914564, 0.2789096056949347, 0.7192635233514011, 0.7942729233764112, 0.7727441098541021, 0.9894986695144325, 1.0646342346444726, 1.2881306419149041, 2.9591230396181345, 4.048719797283411, 5.476738745346665, 5.402840785682201, 5.90424383059144, 4.094836497679353, 1.2007698859088123, 1.5553910820744932, 1.1043468536809087, 0.9404491202440113, 2.3707447992637753, 5.66669387742877, 10.705119967460632, 16.042258478701115, 20.702632404863834, 27.605254612863064, 35.14559090137482, 43.08878347277641, 48.570293337106705, 54.36553716659546, 37.22641624510288, 26.269208304584026, 11.882959865033627, 1.44108597189188, 3.150565316900611, 5.253506898880005, 8.002078961580992, 8.334873653948307, 4.8805763851851225, 3.189537450671196, 2.039839318022132, 2.249932182021439, 2.0962045434862375, 4.010693337768316, 2.5362401688471437, 2.568714888766408, 1.1066041700541973, 2.166248084977269, 5.100194150581956, 4.962784498929977, 10.580177921801805, 6.758633209392428, 3.9150579320266843, 2.9368726210668683, 0.7951160031370819, 2.3789183981716633, 8.845304064452648, 5.20750941708684, 0.25011353369336575, 0.9379049192648381, 1.9072799873538315, 3.381829932332039, 3.344860766083002, 0.8204473438672721, 0.9866320202127099, 1.3100628275424242, 1.353565624449402, 3.691603085026145, 11.035803873091936, 5.771758239716291, 1.7664015968330204, 2.591266678646207, 3.209088114090264, 1.370877258013934, 7.6434271316975355, 4.992678444832563, 13.512577470391989, 3.88248679228127, 0.7042312331032008, 1.625312080141157, 2.378136827610433, 2.8358512418344617, 3.7767534283921123, 3.871940695680678, 2.7939748764038086, 2.022530296817422, 2.6674777641892433, 0.8407634880859405, 1.1180954659357667, 1.856382074765861, 1.8171010888181627, 5.554358130320907, 12.661195155233145, 13.210505079478025, 9.242519550025463, 13.803857490420341, 21.733490489423275, 20.954560786485672, 11.943992190063, 7.97650633379817, 3.8875419460237026, 3.4251946303993464, 2.0924092596396804, 1.991661584470421, 2.992081521078944, 5.449520330876112, 5.572260869666934, 3.332304102368653, 1.9023818126879632, 1.34115549037233, 1.5938865789212286, 1.464497703127563, 1.0058662318624556, 0.9103489760309458, 0.5163439619354904, 0.10216018999926746, 0.030658218856842723, 0.18496824108297005, 0.5088891182094812, 0.2867262909421697, 0.35221723141148686, 0.3448329510865733, 0.7012776040937752, 1.0031527024693787, 1.2600171379745007, 1.2063469178974628, 0.9888516354840249, 0.4759580665268004, 0.401777348597534, 0.21956982265692204, 0.11262771542533301, 0.06657374135102145, 0.09076441594515927, 0.39678260567598045, 0.2992147661279887, 0.2854254544945434, 0.2943845425033942, 0.06468553954618983, 0.12255014080437832, 0.21346503461245447, 0.1034169651393313, 0.26692018029280007, 0.12171944006695412, 0.07247083936817944, 0.02962507507618284, 0.15378249809145927, 0.11935051952605136, 0.07001700229011476, 0.04394925068481825, 0.05192745324166026, 0.16974158235825598, 0.02799503676214954, 0.06126928907178808, 0.13067426072666422, 0.08364996567252092, 0.07829161491827108, 0.05998071290377993, 0.05772767501184717, 0.10001843344070949, 0.03800775368290488, 0.12869247409980744, 0.3770542424172163, 0.22734279540600255, 0.11102673219284043, 0.08086495261522941, 0.07783764318446629, 0.11907344611245207, 0.34123754245229065, 0.12013266896246932, 0.698421107372269, 0.9995139227248728, 1.2190691102296114, 1.026629030238837, 1.020612409338355, 1.1139459698460996, 0.8019783161580563, 0.5352254456374794, 0.2884288370842114, 0.04947282206558157, 0.16840320808114484, 0.49710654420778155, 0.621653173584491, 0.6164317193906754, 0.8496727631427348, 1.5817953902296722, 1.7711357865482569, 2.4672802817076445, 3.069649371318519, 3.43661040533334, 4.347698679193854, 5.400572782382369, 3.8693976821377873, 1.3962528901174664, 1.4821552368812263, 0.8380208071321249, 0.5114174075424671, 3.3425984624773264, 7.0194231905043125, 18.394499458372593, 24.540815949440002, 27.854620032012463, 32.746673226356506, 38.30299727618694, 46.95732928812504, 56.49510249495506, 58.101519495248795, 42.926988154649734, 28.722432665526867, 12.910542525351048, 5.241577913984656, 5.959573611617088, 7.175603359937668, 6.654796656221151, 1.714524405542761, 3.36325581651181, 2.9254995938390493, 2.2619314631447196, 1.7823189427144825, 1.8882571393623948, 2.2205129731446505, 3.414896233007312, 4.1131652891635895, 2.2894123010337353, 5.10798848234117, 12.785111255943775, 19.125397838652134, 12.205561604350805, 5.309266056865454, 6.204696083441377, 3.9550978085026145, 10.427695903927088, 13.618960361927748, 5.709770265966654, 4.705067127943039, 0.09609832035494037, 0.1227452143211849, 1.3788524363189936, 3.0441665137186646, 2.9941918328404427, 2.3147733276709914, 0.26529959694016725, 1.3927605212666094, 0.9855984163004905, 3.3464027708396316, 6.3135535921901464, 1.6228241636417806, 2.071399949491024, 2.988804434426129, 0.669767854269594, 2.45928218588233, 13.986550737172365, 32.02406220138073, 25.043462477624416, 6.068747453391552, 0.6255841813981533, 1.17669687140733, 1.1959477071650326, 0.23422507219947875, 2.4890277022495866, 2.47603596188128, 2.3480374552309513, 1.5223545860499144, 1.188995148986578, 0.8914947439916432, 0.6304273777641356, 0.7647070661187172, 0.11172956830705516, 1.717604377772659, 4.559413343667984, 9.25054281949997, 12.443084958940744, 16.321906372904778, 19.42827008664608, 14.131054133176804, 9.365490451455116, 8.602411597967148, 6.067229909822345, 2.0192904956638813, 1.0529407183639705, 1.452655994798988, 2.5195137038826942, 3.794065061956644, 3.101362232118845, 1.6104880068451166, 1.2493978952988982, 0.5937520426232368, 0.8189793163910508, 0.3637054399587214, 0.31177404220215976, 0.5983477178961039, 0.3752050775801763, 0.2743125648703426, 0.01360083673716872, 0.14901194314006716, 0.14874583866912872, 0.18554953567218035, 0.10565871125436388, 0.3407913335831836, 0.49235745216719806, 0.44576200714800507, 0.6821978185325861, 0.5746869219001383, 0.4581394273554906, 0.42093105206731707, 0.38648435671348125, 0.214932483213488, 0.1041294788592495, 0.09562192833982408, 0.18148758332245052, 0.35590540850535035, 0.37822315469384193, 0.06505944838863797, 0.09438440451049246, 0.0780243007466197, 0.04271193465683609, 0.08274791485746391, 0.08796413691015914, 0.18867626320570707, 0.17934135161340237, 0.07632645982084796, 0.001760944583111268, 0.12396980993798934, 0.08070839656284079, 0.1865732393343933, 0.16811130655696616, 0.32037010125350207, 0.30727318371646106, 0.3761436272179708, 0.3323855611961335, 0.25658054917585105, 0.32893436669837683, 0.3106061986181885, 0.2258251330931671, 0.3764985519228503, 0.4171444068197161, 0.24013794085476547, 0.31222476332914084, 0.5707825720310211, 0.2813889132812619, 0.2903489215532318, 0.21016856306232512, 0.2014897990738973, 0.25754163041710854, 0.6668982957489789, 0.4725016176234931, 0.8150681981351227, 1.0599341243505478, 1.4251421461813152, 1.3602328416891396, 1.3124042144045234, 0.9364922263193876, 0.7471237471327186, 0.672568007139489, 0.6108847295399755, 0.12481654848670587, 0.32749249250628054, 0.876796479569748, 0.905500139342621, 0.7987946807406843, 0.92252476955764, 1.4982609101571143, 1.961443587206304, 3.3493889356032014, 4.980425052344799, 5.2636205311864614, 5.697792833670974, 5.596550591289997, 3.245553094893694, 0.6358904752414674, 1.0345121822319925, 0.49217167776077986, 0.8537026843987405, 16.059752739965916, 37.44737818837166, 57.12036274373531, 73.91035079956055, 77.89345666766167, 83.01545262336731, 83.46132069826126, 88.60803052783012, 98.21194678544998, 99.85231876373291, 89.0119032561779, 73.07079344987869, 50.44100895524025, 25.840935185551643, 8.545845933258533, 7.767985397949815, 14.695564191788435, 14.126851558685303, 10.325172655284405, 3.5445680748671293, 2.462566397152841, 2.117779073305428, 2.2967981547117233, 3.0025271605700254, 3.0700227012857795, 2.6884343521669507, 2.3527985997498035, 3.2091137627139688, 10.284850168973207, 27.56481908261776, 20.686492770910263, 10.949160922318697, 15.020946431905031, 15.287912506610155, 29.783981703221798, 45.76034031808376, 29.887609742581844, 12.363957054913044, 0.4689738334855065, 1.45214848453179, 7.365912823006511, 14.810623917728662, 21.862831749022007, 6.779551561921835, 1.2460475438274443, 2.3362497752532363, 1.9198045902885497, 18.444599770009518, 35.44357851147652, 18.819780237972736, 8.902362752705812, 6.185879493132234, 7.298381896689534, 9.877778962254524, 32.85798065364361, 39.517879486083984, 24.570074379444122, 4.709583185613155, 0.45501344196964055, 0.9301905613392591, 2.0312581909820437, 2.6933318143710494, 6.9672586396336555, 3.4020849829539657, 3.315473855473101, 2.2904030978679657, 2.5903827510774136, 1.152032632380724, 1.6162279550917447, 1.4981960761360824, 5.242574410513043, 14.528426360338926, 27.142751030623913, 34.86875295639038, 40.65781071782112, 44.19409096240997, 53.097530007362366, 47.864143028855324, 41.252623200416565, 31.13087072968483, 16.73941656947136, 5.67366317845881, 2.2524711582809687, 2.6603498216718435, 2.8374402690678835, 4.786230772733688, 5.590176433324814, 3.180641890503466, 2.9429475450888276, 1.4959886320866644, 1.6449262714013457, 1.396739026531577, 1.325252156239003, 1.4817784633487463, 0.7475186290685087, 0.4257554275682196, 0.4699713393347338, 0.2959141682367772, 0.5444144213106483, 0.37453782744705677, 0.40988047316204756, 0.46260861097835004, 0.7995207386557013, 1.222189455293119, 1.1419149627909064, 1.5083415317349136, 1.1813710955902934, 0.806814506649971, 0.6706093903630972, 0.2992239687591791, 0.16948080650763586, 0.2584813378052786, 0.2890935936011374, 0.3871536848600954, 0.48657858569640666, 0.3306229010922834, 0.6054242444224656, 0.14007504534674808, 0.2191067225066945, 0.2543068758677691, 0.24858787102857605, 0.3567254520021379, 0.4327868908876553, 0.28917190502397716, 0.1145493658259511, 0.3321782941929996, 0.257558521698229], [0.016621801732981112, 0.027392062183935195, 0.13938989461166784, 0.0963858506293036, 0.053259701089700684, 0.08747747357119806, 0.06198988477990497, 0.023948441303218715, 0.048209126398433, 0.024949414837465156, 0.020756772137247026, 0.05179319872695487, 0.04392681556055322, 0.07650619314517826, 0.11567786074010655, 0.017780095731723122, 0.05109836296469439, 0.07943166507175192, 0.12172243834356777, 0.03805879860010464, 0.0458658210845897, 0.07378755777608603, 0.2781389595475048, 0.3503045387333259, 0.3865260357270017, 0.22096412518294528, 0.49853283329866827, 0.607087902026251, 0.5127029854338616, 0.2780998928938061, 0.11320246427203529, 0.039702800422674045, 0.028624216574826278, 0.12767406937200576, 0.11163479604874738, 0.41989979334175587, 0.5124421056825668, 0.6262427335605025, 0.8941759157460183, 0.5409789306577295, 0.8302083075977862, 0.7373190263751894, 1.724612032994628, 1.5054821851663291, 1.7203299002721906, 1.5974492440000176, 1.0017141234129667, 0.6218060560058802, 0.12825451791286469, 0.059033394791185856, 0.12193403948913328, 0.8842960302717984, 0.8229961164761335, 1.5258723660372198, 1.201801411807537, 5.412867972627282, 12.278859671205282, 12.557307779788971, 14.12851206958294, 12.449706103652716, 7.875800812616944, 1.9385893573053181, 1.0175520298071206, 1.1805748008191586, 0.6528001616243273, 0.7842948962934315, 0.836594874272123, 0.7532969315070659, 0.3914270899258554, 0.6746477424167097, 1.2886715191416442, 1.3395827310159802, 0.2090229542227462, 0.37408063479233533, 0.6211746367625892, 1.0753399226814508, 1.3683146517723799, 5.501617435365915, 5.928569175302982, 5.952646108344197, 4.428898422047496, 1.590653546154499, 2.268400378525257, 0.577408050885424, 4.832682805135846, 7.500653117895126, 4.859229605644941, 0.551883039297536, 0.1064748658973258, 0.47608613152988255, 1.852996931411326, 2.140972316265106, 0.8497728046495467, 0.1841571627301164, 0.5490687559358776, 10.701534859836102, 14.464738927781582, 8.19552468135953, 3.6589837353676558, 3.901247810572386, 2.593845552764833, 0.6635457475204021, 4.910854110494256, 12.80678529292345, 8.991946745663881, 4.139170618727803, 0.829900880344212, 1.1332380096428096, 0.21331124677089974, 0.105155802302761, 0.5305332911666483, 0.19784570555202663, 0.21226440294412896, 0.17721600393997505, 0.06710891888360493, 0.13971091801067814, 0.16825173574034125, 0.1670590153662488, 0.09092294611036777, 0.20815199939534068, 0.10312958329450339, 0.2972557337488979, 0.316946217790246, 0.7192579424008727, 1.3389233476482332, 1.4364860812202096, 0.6867141730617732, 0.36857710510957986, 0.08153272225172259, 0.03660568458144553, 0.15059150056913495, 0.1215762723586522, 0.22746122733224183, 0.9821034944616258, 0.9110308019444346, 0.6771168380510062, 0.3050677286228165, 0.1830488393898122, 0.2301385102327913, 0.2370157404220663, 0.09958416572771966, 0.1092946263088379, 0.23760678683174774, 0.10307148797437549, 0.06911978285643272, 0.09700518028694205, 0.0777726162050385, 0.057262834525317885, 0.06892676508869044, 0.058068959042429924, 0.15261585678672418, 0.08205447433283553, 0.077819601574447, 0.05526885812287219, 0.21265613817377016, 0.12321408838033676, 0.026172301659244113, 0.06473460292909294, 0.05092822932056151, 0.026647387494449504, 0.11051002671592869, 0.04535013977147173, 0.10971399911795743, 0.15383415156975389, 0.041570318571757525, 0.05690617319487501, 0.04618282204319257, 0.10449099383549765, 0.27479801850859076, 0.06344755558529869, 0.07025893501122482, 0.10375744765042327, 0.06410506131942384, 0.18952078273287043, 0.015810435797902755, 0.02666015614522621, 0.007049583782645641, 0.06980039164773189, 0.02209916514402721, 0.06728651482262649, 0.11362553297658451, 0.08375779230846092, 0.07108600664651021, 0.05339251954865176, 0.04354548524133861, 0.058688971475930884, 0.01142919945777976, 0.0837659856188111, 0.07972648323629983, 0.019814277984551154, 0.057716527953743935, 0.06726563820848241, 0.10311563091818243, 0.10831260166014545, 0.09344866019091569, 0.04079234742675908, 0.027795896276074927, 0.10545775250648148, 0.13050969690084457, 0.2767110971035436, 0.06113962102972437, 0.27203621983062476, 0.12204430779092945, 0.21132576424861327, 0.009800883854040876, 0.10518881303141825, 0.06743828402250074, 0.03297801849839743, 0.04765931371366605, 0.05176813639991451, 0.06837548295152374, 0.2577011921675876, 0.2837340108817443, 0.4108962061582133, 0.41791365772951394, 0.27957353100646287, 0.06282207352342084, 0.2028348675230518, 0.33171320508699864, 0.35863660101313144, 0.9903037513140589, 0.2936799474991858, 0.3734904492739588, 0.5409814836457372, 0.4538952629081905, 0.17428604944143444, 0.275006799492985, 0.38897740887477994, 4.305333802476525, 8.102203588932753, 3.1670939549803734, 3.4395768586546183, 2.9555771173909307, 1.196543681435287, 2.434536013752222, 1.3195458124391735, 1.5003245556727052, 3.5307988012209535, 1.6402104869484901, 0.1343397726304829, 1.5111572993919253, 0.6525615463033319, 0.2752568735741079, 0.3792208683444187, 0.225999508111272, 0.6111218011938035, 0.45985316508449614, 1.188018482644111, 0.4214003565721214, 0.11991472987574525, 0.6905523827299476, 0.8662199252285063, 1.5189142269082367, 5.914475731551647, 9.24487542361021, 15.908083878457546, 7.345633786171675, 3.3365774480625987, 4.149842346087098, 2.237612293101847, 1.5364411426708102, 15.33843269571662, 14.989710208028555, 0.9846671693958342, 0.21724249207181856, 1.1960611073300242, 1.2238347670063376, 0.5959037959109992, 0.7885080389678478, 0.3066139487782493, 0.8126073551829904, 10.396515727043152, 24.908735007047653, 9.886893723160028, 4.065981321036816, 4.785075634717941, 2.694782861508429, 2.2570337634533644, 9.063231870532036, 19.79558877646923, 16.295245103538036, 8.185089491307735, 1.6994757880456746, 0.7631410751491785, 0.2700876665767282, 0.1647942329873331, 0.49196301552001387, 0.11998904112260789, 0.06794302607886493, 0.11801929213106632, 0.11802785651525483, 0.19656508520711213, 0.12731193099170923, 0.00684398058183433, 0.17080283869290724, 0.20812142291106284, 0.018853126239264384, 0.018522813006711658, 0.18348201614571735, 0.43930633168201894, 0.6759450165554881, 0.7574905408546329, 0.35650595440529287, 0.29860911425203085, 0.11290064023341984, 0.0638039645855315, 0.052480267913779244, 0.07118988505681045, 0.03486419424007181, 0.5228928511496633, 0.41233481490053236, 0.31022224109619856, 0.33528821950312704, 0.0654065805429127, 0.12759032542817295, 0.08642204309580848, 0.12991339608561248, 0.06383421452483162, 0.006416178366634995, 0.08702079299837351, 0.04407011314469855, 0.07153467944590375, 0.09745502567966469, 0.02146219278074568, 0.07132453290978447, 0.12135326440329663, 0.10645282411132939, 0.0672028302506078, 0.07761768545606174, 0.13716873567318544, 0.11526239904924296, 0.11998932313872501, 0.09981832074117847, 0.09657944727223366, 0.02412704285234213, 0.024306946870638058, 0.0845730266883038, 0.06556383421411738, 0.03539672601618804, 0.04893312114290893, 0.037902049589320086, 0.07813039075699635, 0.04351235205831472, 0.08988387999124825, 0.147580488701351, 0.012977545866306173, 0.012968405389983673, 0.003991802695963997, 0.16344978794222698, 0.11785068360040896, 0.08636834128992632, 0.04383838866488077, 0.1086455216864124, 0.16180017177248374, 0.2973989682504907, 0.1908819706295617, 0.16283260309137404, 0.22718382737366483, 0.2306429628515616, 0.1470993395196274, 0.14415829733479768, 0.13238265499239787, 0.12042622547596693, 0.16387423704145476, 0.25602355250157416, 0.20442873355932534, 0.13707403762964532, 0.1970734860515222, 0.18545133469160646, 0.2978458598954603, 0.20231747184880078, 0.1569076077430509, 0.1242687099147588, 0.30094236717559397, 0.7619990583043545, 0.9082712000235915, 1.0166762955486774, 0.854333391180262, 1.0641539166681468, 1.1208702670410275, 0.8374905574601144, 0.5720219586510211, 0.3092274960363284, 0.23425882507581264, 0.14621734153479338, 0.3015150083228946, 0.4203802003758028, 0.6403127254452556, 1.1459106858819723, 1.1284449230879545, 1.2150539131835103, 1.0355103411711752, 1.985100880265236, 2.0247348910197616, 3.36514787748456, 2.696415586397052, 2.711788136512041, 2.191209658049047, 1.1011803173460066, 1.4522730465978384, 0.7089744473341852, 0.24943939642980695, 1.0107639315538108, 4.903445933014154, 16.012536473572254, 32.22327031195164, 38.059703931212425, 46.162879317998886, 48.61304484307766, 47.99748167395592, 49.52198646962643, 46.49976924061775, 30.33954419195652, 14.431162979453802, 5.431944373995066, 7.1253657806664705, 4.945047050714493, 1.2974654347635806, 0.7571558619383723, 0.7054607046302408, 0.8623088069725782, 0.9370842820499092, 1.7410079156979918, 2.1402413304895163, 0.8935522742103785, 0.4241349035874009, 0.9912805957719684, 2.174508129246533, 0.9138516162056476, 8.808380495756865, 14.543968476355076, 25.494540072977543, 12.884086444973946, 8.860238213092089, 13.181474637240171, 11.921830829232931, 15.813664644956589, 36.25994950532913, 33.05781953036785, 1.1233590147458017, 0.2645183529239148, 4.818855347111821, 10.669556725770235, 12.972720488905907, 3.8885636162012815, 1.1120995064266026, 2.121194377541542, 24.12038940936327, 43.3466262370348, 20.71060437709093, 13.787427172064781, 12.400046568363905, 6.612431304529309, 10.371274631470442, 24.889194555580616, 37.721533477306366, 22.821733094751835, 6.357427937909961, 1.0979300667531788, 2.0228366553783417, 0.35093678918201476, 0.25209091196302325, 0.639048699522391, 0.20381004957016557, 0.22037405840819702, 0.4338440060382709, 0.7126135239377618, 0.5095134128350765, 0.41068552527576685, 0.1888250489719212, 0.38101466896478087, 0.41856003866996616, 0.2869802835630253, 0.30206096183974296, 0.8191929955501109, 2.2376968385651708, 4.4225674867630005, 4.31516102515161, 2.0383203495293856, 0.9212198958266526, 0.25005211355164647, 0.2587778109591454, 0.29071928292978555, 0.2964393119327724, 0.4089551040669903, 1.2100399634800851, 0.8994034258648753, 1.0650583868846297, 0.7610099238809198, 0.3839520300971344, 0.420958066242747, 0.41391793463844806, 0.2224836131790653, 0.24445905117318034, 0.4180311842355877, 0.40606776368804276, 0.0932597836072091, 0.19665102590806782, 0.24052519351243973, 0.16188139241421595, 0.18248050269903615, 0.24407552409684286, 0.4997228819411248, 0.29428117617499083, 0.3236644354183227, 0.3211827826453373, 0.3006795875262469, 0.40160187520086765, 0.2104791667079553, 0.20709981210529804, 0.1614821911789477, 0.10970505623845384, 0.41487483016680926, 0.26387954188976437, 0.17290620395215228, 0.160072362923529, 0.0994687617640011, 0.32756474800407887, 0.14464057458098978, 0.2385627175681293, 0.47666016791481525, 0.17870455922093242, 0.21999021962983534, 0.2346570318331942, 0.3318002144806087, 0.3847467218292877, 0.20390891848364845, 0.11994451226200908], [0.05434476552181877, 0.038530574456672184, 0.04426998093549628, 0.10429163070512004, 0.04847823285672348, 0.025385411754541565, 0.02876352325984044, 0.022265261504799128, 0.024315895316249225, 0.07526443165261298, 0.0274235329561634, 0.017310533330601174, 0.10642476350767538, 0.06894574922625907, 0.04755579895572737, 0.0630022150289733, 0.04730622582428623, 0.11527067399583757, 0.013495342300302582, 0.01960676978342235, 0.050126386995543726, 0.022331963882606942, 0.09442710026632994, 0.12712847208604217, 0.06728032531100325, 0.08953451397246681, 0.061694127798546106, 0.07367630983935669, 0.028453934501158074, 0.07452082936652005, 0.08913933517760597, 0.047257975093089044, 0.018009988962148782, 0.047327024512924254, 0.14841598371276632, 0.15990074869478121, 0.10583589159068651, 0.06309791497187689, 0.06837511929916218, 0.011550908893696032, 0.07547723507741466, 0.18904626835137606, 0.06079939084884245, 0.07084728742484003, 0.18652728555025533, 0.2708599157631397, 0.029793956346111372, 0.09558610487147234, 0.11846907073049806, 0.2503776195226237, 0.06254430991248228, 0.09599870187230408, 0.04734131827717647, 0.06558086650329642, 0.2854743174975738, 0.5958298780024052, 1.3912187539972365, 0.6407982087694108, 0.9236650646198541, 0.7687681575771421, 0.1412715803598985, 0.13565368572017178, 0.024999769557325635, 0.06056847902073059, 0.02956744730909122, 0.18397306557744741, 0.22293154383078218, 0.19537822779966518, 0.19180805218638852, 0.09582842350937426, 0.11558371188584715, 0.14931006386177614, 0.09142463051830418, 0.23344880057265982, 0.06432077396311797, 0.3159716888330877, 0.7149740285240114, 4.485867340117693, 12.649275194853544, 9.702108688652515, 7.842534072697163, 1.3337691617198288, 2.3042576294392347, 3.2711432967334986, 3.4585570776835084, 5.2262006141245365, 6.665037106722593, 3.058634474873543, 0.18455680925399065, 0.27790476742666215, 0.6483687087893486, 0.6213137449230999, 0.16983978333882987, 0.2975201461231336, 10.69249989464879, 10.020026229321957, 18.114777468144894, 5.068461578339338, 0.6868336291518062, 1.6491667251102626, 1.3402691879309714, 1.757710394449532, 8.654540050774813, 11.924658827483654, 13.286470603197813, 3.467118018306792, 1.1515121790580451, 0.2162861605756916, 0.016627024597255513, 0.06309683143626899, 0.08494387788232416, 0.20710490323835984, 0.13074491318548098, 0.08654970733914524, 0.04562211463053245, 0.058364059223094955, 0.052642879891209304, 0.030988066391728353, 0.16734089789679274, 0.12080838700057939, 0.049763521310524084, 0.1566871305112727, 0.062367040518438444, 0.04708092092187144, 0.027907634030270856, 0.0390858604805544, 0.06992221518885344, 0.03966813841543626, 0.05513793214049656, 0.04269932927854825, 0.06996616517426446, 0.042876624647760764, 0.07412187303998508, 0.15197753557004035, 0.0429695266939234, 0.06015694700181484, 0.03597965704102535, 0.03388869678019546, 0.05916353409702424, 0.09686412027804181, 0.040232519459095784, 0.06366798828821629, 0.018982951987709384, 0.08673306234413758, 0.014051485504751327, 0.03592357665183954, 0.0383849873469444, 0.020654546860896517, 0.03880554388160817, 0.02860274809791008, 0.039154201149358414, 0.05659056005242746, 0.016659593748045154, 0.03687854630697984, 0.10190652392338961, 0.08471009394270368, 0.12524776597274467, 0.04300130545743741, 0.009429951023776084, 0.04262449852831196, 0.04033824210637249, 0.07136879459721968, 0.06550466277985834, 0.023887058268883266, 0.0641534493479412, 0.03367269840964582, 0.0462220556801185, 0.04662580628064461, 0.02074936179269571, 0.044086766938562505, 0.06500488569145091, 0.03602888740715571, 0.0691599775745999, 0.0862040594802238, 0.026905113118118607, 0.03108964599960018, 0.030232220524339937, 0.012984058212168748, 0.018341834729653783, 0.0541702940245159, 0.1324663098785095, 0.048991825024131685, 0.03683105627715122, 0.04124220024095848, 0.021802525006933138, 0.01709745902189752, 0.0100330424902495, 0.030431284940277692, 0.04837035055970773, 0.016414896526839584, 0.10981914660078473, 0.2501561329700053, 0.04302766283217352, 0.042343116947449744, 0.010505602240300504, 0.07279756988282315, 0.025523887234157883, 0.0470960236270912, 0.05873590118426364, 0.025320711320091505, 0.061584969007526524, 0.08718095588847063, 0.07112683961167932, 0.048400147788925096, 0.06547608267283067, 0.01910174571094103, 0.04315018028137274, 0.028720784830511548, 0.13751542253885418, 0.03838887620077003, 0.09903806378133595, 0.09055297065060586, 0.09951514599379152, 0.07567104694317095, 0.02505481279513333, 0.06891489814734086, 0.1246515690581873, 0.16576242400333285, 0.08877447311533615, 0.08269922254839912, 0.12538484064862132, 0.31863323820289224, 0.11824594403151423, 0.12284056545468047, 0.12464290077332407, 0.20120571978623047, 0.12388269664370455, 0.05595345595793333, 0.020477683792705648, 0.269230812555179, 0.18055670749163255, 0.5911653314251453, 0.4779569077072665, 0.6368267093785107, 0.7424780214205384, 0.3005299111828208, 0.2947592083364725, 0.27250564307905734, 0.035830010383506306, 0.03865677666908596, 0.2219543282990344, 0.158951512130443, 0.0382182230532635, 0.03570600492821541, 0.21129696891875938, 0.09607512824004516, 0.05936488989391364, 0.21087091678055003, 0.04478755472518969, 0.04279656175640412, 0.03291083929070737, 0.28058697818778455, 0.675587123259902, 4.769132640212774, 11.23277960345149, 14.43357964977622, 11.68280465528369, 1.9017339474521577, 3.2789613772183657, 2.305800346657634, 4.5196085795760155, 1.0697418730705976, 10.44166300445795, 10.374171026051044, 0.21449572930578142, 0.3970819286769256, 0.2702636149479076, 0.7151661557145417, 0.24559069279348478, 0.8893064770381898, 20.440607964992523, 26.966233402490616, 24.80469658970833, 12.357381507754326, 0.31667619477957487, 3.0559356696903706, 1.9160435046069324, 4.431507932022214, 17.751551158726215, 26.324867717921734, 18.55233918875456, 4.670153651386499, 0.8684961218386889, 0.08271447368315421, 0.022612041138927452, 0.10811771368025802, 0.16217047377722338, 0.15927854692563415, 0.04569815137074329, 0.07206083988421597, 0.02153134239051724, 0.023721115903754253, 0.07125595104298554, 0.03221012942958623, 0.07699091947870329, 0.10134397598449141, 0.05137875377840828, 0.1524970686296001, 0.04759196010127198, 0.05626280537398998, 0.09717726206872612, 0.08058321851422079, 0.02392720660282066, 0.04858010004682001, 0.09136420485447161, 0.04202583026199136, 0.09861655358690768, 0.03096505424764473, 0.05388045567087829, 0.19067617307882756, 0.1804950350197032, 0.10178504919167608, 0.045371120286290534, 0.015426623922394356, 0.07442817965056747, 0.04015762562630698, 0.021836040396010503, 0.02419273219857132, 0.04444056728971191, 0.08817950816592202, 0.03461257278104313, 0.019923496147384867, 0.0489825481781736, 0.02904829460021574, 0.06213664077222347, 0.04958317571436055, 0.09330627915915102, 0.08597934458521195, 0.031326992248068564, 0.03839532917481847, 0.02574789152276935, 0.028686881669273134, 0.22004908678354695, 0.02527142900362378, 0.014394324334716657, 0.009196943556162296, 0.017701745346130338, 0.047460340210818686, 0.06849801895441487, 0.07165603543398902, 0.024445318449579645, 0.030516390725097153, 0.05068089005362708, 0.017872513526526745, 0.06136715608590748, 0.12586367432959378, 0.07413137995172292, 0.0295630259643076, 0.05118857472552918, 0.0748400493466761, 0.03055196186323883, 0.026799767110787798, 0.13233405916253105, 0.19589685543905944, 0.07672226944123395, 0.18823851482011378, 0.3712192695820704, 0.16466829052660614, 0.1114679389866069, 0.12923450907692313, 0.16367449541576207, 0.1456744605093263, 0.10109803566592745, 0.1735355006530881, 0.2702303964179009, 0.16512714559212327, 0.17612584837479517, 0.2822058100719005, 0.16269659710815176, 0.2560285397339612, 0.16341907787136734, 0.22084869153331965, 0.13438431633403525, 0.19166024605510756, 0.1873079061624594, 0.321093428065069, 0.18647683435119689, 0.1723761620814912, 0.16583867225563154, 0.2596953132888302, 0.1127096039999742, 0.10305381743819453, 0.26463668094947934, 0.16622515307972208, 0.15847836330067366, 0.16759910591645166, 0.20169239054666832, 0.5042286089155823, 0.20363723306218162, 0.2301350369816646, 0.15365147934062406, 0.20702776440884918, 0.1789270996232517, 0.32971415610518306, 0.2043903645244427, 0.28795442660339177, 0.22580727702006698, 0.847304540220648, 0.6461441656574607, 0.3561569668818265, 0.34216415835544467, 0.4956945340381935, 0.39939496549777687, 0.21276753454003483, 0.18035150365903974, 0.4460642987396568, 1.4615728100761771, 3.3672776632010937, 3.2698083808645606, 2.202907567843795, 1.780577686149627, 1.043061485979706, 0.44299284636508673, 0.39523819636087865, 0.19830206700135022, 0.18241419922560453, 0.7692842767573893, 0.5388639878947288, 0.31964995083399117, 0.2618465619161725, 0.5908473953604698, 0.23677584860706702, 0.21203513868385926, 0.2680589910596609, 0.44173472793772817, 0.25395123870112, 0.17379985365550965, 0.3506174578797072, 0.2952163416193798, 3.233765889890492, 17.77101371437311, 22.808868885040283, 25.184296220541, 10.352196805179119, 9.77187579497695, 7.210067510604858, 6.854463592171669, 9.33175491169095, 33.87982942163944, 22.570539973676205, 0.22022065648343414, 0.9998839278705418, 6.039398778229952, 5.594792235642672, 0.4809486534213647, 1.0792038403451443, 37.79964208602905, 51.586993262171745, 46.16235874593258, 19.935026094317436, 7.918348079547286, 8.17589208483696, 8.857579305768013, 14.199975784868002, 30.46411480754614, 34.62151542305946, 22.605218812823296, 4.066071566194296, 1.8707802146673203, 0.35643657844047993, 0.23794057517079636, 0.14351129299029708, 0.27243300166446716, 0.4752924194326624, 0.1896875284728594, 0.24908473889809102, 0.2536750410217792, 0.2290953474584967, 0.13521129149012268, 0.33278560847975314, 0.2601920475717634, 0.34710172621998936, 0.1709048097836785, 0.3628099645720795, 0.17166537756565958, 0.16197404213016853, 0.12901043985038996, 0.26050015760120004, 0.1039474671415519, 0.12972869037184864, 0.47418581787496805, 0.2868699113605544, 0.1303261044085957, 0.1252680562902242, 0.3524655243381858, 0.20719879976240918, 0.27530728024430573, 0.1443646737607196, 0.1592512655770406, 0.12441857179510407, 0.1888757970300503, 0.15624872903572395, 0.11572562536457554, 0.1772302680183202, 0.11329514367389493, 0.25134935800451785, 0.14769547706237063, 0.13378264236962423, 0.16968718293355778, 0.07465875009074807, 0.1545793717377819, 0.14266086596762761, 0.17531542311189696, 0.10906637136940844, 0.1227157139510382, 0.117772060475545, 0.10455599855049513, 0.1564575545489788, 0.35414476704318076, 0.1075270606088452, 0.06390447364537977, 0.11519953914103098, 0.09440957073820755, 0.15822499408386648, 0.17402640165528283, 0.12425046050339006, 0.20322513330029324, 0.12442328443285078, 0.1639420396531932, 0.14882153773214668, 0.12692950229393318, 0.20267563231755048, 0.1893230597488582, 0.07697779830778018, 0.1633451451198198, 0.21282628295011818, 0.1205201813718304, 0.15148283477174118], [0.03332053449412342, 0.01581592769070994, 0.05012797519157175, 0.034083562495652586, 0.030405413672269788, 0.07250312279211357, 0.03998695763584692, 0.028250209397810977, 0.09177334344713017, 0.02451821961585665, 0.09618964904802851, 0.04470496853173245, 0.04256488180544693, 0.021950789414404426, 0.016939259112405125, 0.11555316508747637, 0.05278600307065062, 0.018609462458698545, 0.08559969151974656, 0.03961435497330967, 0.031094176811166108, 0.06171405446366407, 0.0672129234590102, 0.024621023767394945, 0.05023992445785552, 0.05084963588160463, 0.05753111719968729, 0.0329339831660036, 0.023954833050083835, 0.05481369524204638, 0.029004981006437447, 0.10677954720449634, 0.04752384949824773, 0.046438733115792274, 0.0714854898978956, 0.02311979445948964, 0.056354746338911355, 0.0597606178780552, 0.0351174521347275, 0.037285744183463976, 0.04854461796639953, 0.024344364101125393, 0.05139368578966241, 0.02994951792061329, 0.07689633275731467, 0.03541141682944726, 0.04446173334144987, 0.04282488582248334, 0.052964051719754934, 0.04837314103497192, 0.042892484343610704, 0.04788298218045384, 0.014682773944514338, 0.09427712706383318, 0.06457785391830839, 0.04840904242882971, 0.09128711055382155, 0.02413354035525117, 0.04359573977126274, 0.09205034264596179, 0.12062592257279903, 0.08334734753589146, 0.04006690920505207, 0.055995613656705245, 0.037498376914300025, 0.13540643180022016, 0.10578194487607107, 0.073166721558664, 0.034683904304984026, 0.09121501832851209, 0.006990835372562287, 0.05782568303402513, 0.016870094659680035, 0.061852342550992034, 0.2460265115951188, 0.06964406566112302, 0.24409508710959926, 4.054225701838732, 13.170417230576277, 20.241629742085934, 9.908214379101992, 7.0112887769937515, 2.973141437396407, 2.5051167514175177, 0.524478197330609, 5.675737392157316, 3.7871358962729573, 3.2689854875206947, 4.202434848994017, 0.30071895103901625, 0.18126539915101603, 0.3146529517835006, 0.963751666713506, 9.780170749872923, 17.515414729714394, 10.428445413708687, 18.1683336943388, 5.312284994870424, 0.8393403457012028, 0.5083656369242817, 1.2726275925524533, 6.012652013450861, 9.733302164822817, 9.857925977557898, 7.738809613510966, 1.8012768379412591, 0.4214818443870172, 0.19506490789353848, 0.1249965192982927, 0.06370681003318168, 0.20608626102330163, 0.04888173483777791, 0.09604058126569726, 0.07304495738935657, 0.0812398485140875, 0.05487341957632452, 0.051561281288741156, 0.06553962535690516, 0.024332215143658686, 0.06665674314717762, 0.11162494774907827, 0.047599656172678806, 0.02549014549003914, 0.07853922506910749, 0.0859625126759056, 0.05407282034866512, 0.04027987590234261, 0.062275155214592814, 0.05077392197563313, 0.03292617206170689, 0.05305872007738799, 0.028299116929701995, 0.025838385299721267, 0.06489309598691761, 0.04937324811180588, 0.018816619995050132, 0.020265936072974, 0.026759151223814115, 0.061458956042770296, 0.042275251253158785, 0.011351478042342933, 0.061897327832411975, 0.028860943129984662, 0.04030689749924932, 0.029925275666755624, 0.03620859104557894, 0.020787224311789032, 0.07497917977161705, 0.058052056629094295, 0.025855267303995788, 0.061100543243810534, 0.02495940228982363, 0.05428129334177356, 0.028985720418859273, 0.02690255827474175, 0.04739602569316048, 0.031412914395332336, 0.06428756285458803, 0.038164038851391524, 0.1100533090357203, 0.03491704999760259, 0.11140524235088378, 0.07436972809955478, 0.04192762928141747, 0.022958715017011855, 0.03843302656605374, 0.03339094575494528, 0.0948561358381994, 0.045131933511584066, 0.059247908866382204, 0.06774334382498637, 0.04532637249212712, 0.04505568525928538, 0.068310136848595, 0.05050934632890858, 0.042117426128243096, 0.08024843569728546, 0.05113938888825942, 0.046614392049377784, 0.03253736831538845, 0.04935653865686618, 0.06323104884359054, 0.040025315538514405, 0.05407681310316548, 0.019510882448230404, 0.006599115913559217, 0.06489540406619199, 0.032481844536960125, 0.03878864517901093, 0.04935370365274139, 0.02236792650364805, 0.13831234071403742, 0.07712962687946856, 0.028873559640487656, 0.08065655754762702, 0.027835293185489718, 0.03486020890704822, 0.004652462557714898, 0.04494563960179221, 0.05625698693620507, 0.044178526077303104, 0.014574579017789802, 0.013977344024169724, 0.05690124904504046, 0.045957980983075686, 0.11377894232282415, 0.06150344779598527, 0.03490656345093157, 0.031707149973954074, 0.02861880075215595, 0.03743827408470679, 0.01138046261985437, 0.04150198903516866, 0.029343353962758556, 0.038526032512891106, 0.05120025984069798, 0.015900040853011888, 0.03858620213577524, 0.012436541546776425, 0.03917555273801554, 0.08925809364882298, 0.1020334089116659, 0.055970146859181114, 0.057321189597132616, 0.02609262282931013, 0.08124482090352103, 0.08935833553550765, 0.009856951255642343, 0.04704022154328413, 0.07510852126870304, 0.029356213526625652, 0.02159969233616721, 0.05085759170469828, 0.032359995020669885, 0.08897439285647124, 0.05901971700950526, 0.08820799921522848, 0.13583652122179046, 0.05472728327731602, 0.04318165847507771, 0.056889630723162554, 0.13921088859206066, 0.02076855002087541, 0.02754104647465283, 0.02962026781460736, 0.014061931233300129, 0.02580558979389025, 0.17506736767245457, 0.057434868067502975, 0.02378636181674665, 0.06378804551786743, 0.12607842218130827, 0.19263615540694445, 4.0300485491752625, 14.984743874520063, 20.30472155660391, 16.305628046393394, 7.769916644319892, 0.7188109320122749, 2.9084541834890842, 3.6802780302241445, 0.3715586388716474, 11.509567201137543, 13.617281801998615, 9.925168119370937, 0.08081893945927732, 0.5139401752967387, 0.6315332371741533, 1.3783011096529663, 22.039299979805946, 36.479193940758705, 26.109290085732937, 23.15002027899027, 14.401232935488224, 4.604303659871221, 1.7471424490213394, 4.405510677024722, 10.596300456672907, 18.55037659406662, 18.894780613482, 13.82566262036562, 2.8865459840744734, 0.347417495213449, 0.1151318330084905, 0.07267510809469968, 0.13697801856324077, 0.19642750587081537, 0.045446195945260115, 0.1988709974102676, 0.030648788015241735, 0.03978560183895752, 0.054613831161987036, 0.010178693610214395, 0.05363789954571985, 0.0664454982324969, 0.1797784023801796, 0.06010783166857436, 0.04747668601339683, 0.09964104392565787, 0.09165451818262227, 0.06631209718761966, 0.10774914087960497, 0.06168849860841874, 0.003794918106905243, 0.03193331947841216, 0.019926659551856574, 0.033266339160036296, 0.04254163402947597, 0.06351526171783917, 0.02566497878433438, 0.0350053767033387, 0.012839498049288522, 0.019558687890821602, 0.020142574430792592, 0.015956167626427487, 0.02733479064772837, 0.05810171001940034, 0.07924090343294665, 0.06013501282723155, 0.04859622320509516, 0.07086511381203309, 0.046136244855006225, 0.03726133865711745, 0.025876216277538333, 0.005065592977189226, 0.034421855671098456, 0.0596211868833052, 0.14192492264555767, 0.03847120635327883, 0.042440616598469205, 0.02747045895375777, 0.015492674137931317, 0.027081709013145883, 0.02135882830771152, 0.023614840356458444, 0.03641519011580385, 0.02026019741606433, 0.10646791939507239, 0.02356995526497485, 0.005196249467189773, 0.021774542328785174, 0.031701171974418685, 0.03655912965768948, 0.032237043415079825, 0.011970073901466094, 0.013672463264811086, 0.01892241129098693, 0.052904000840499066, 0.017930363937921356, 0.058846822576015256, 0.07711608268436976, 0.08036686762352474, 0.14214692870154977, 0.13690303196199238, 0.11997269903076813, 0.15672811190597713, 0.18428553943522274, 0.10003464936744422, 0.1458074088441208, 0.19404283695621416, 0.12931788194691762, 0.14338143198983744, 0.21533625607844442, 0.2512973186094314, 0.17956444120500237, 0.20378088316647336, 0.14720319566549733, 0.34811066114343703, 0.15877154131885618, 0.10332974052289501, 0.2905022195773199, 0.09745904069859535, 0.21303123445250094, 0.32244422589428723, 0.15624769002897665, 0.16292410989990458, 0.2606803213711828, 0.14396030717762187, 0.1327947250683792, 0.20300082658650354, 0.13884352549212053, 0.31530096544884145, 0.1836501422803849, 0.2450528583722189, 0.12297113149543293, 0.1401238192920573, 0.1802746913745068, 0.09747270363732241, 0.20170500705717131, 0.16627196775516495, 0.11362421937519684, 0.14492561866063625, 0.15901625709375367, 0.170013356837444, 0.15248056326527148, 0.1312993568717502, 0.222080344974529, 0.21466795209562406, 0.12305806667427532, 0.10246257807011716, 0.16328997386153787, 0.1700474214158021, 0.28936334943864495, 0.1344494620570913, 0.21513854793738574, 0.3163682925514877, 0.1884213206358254, 0.19547491479897872, 0.18347260571317747, 0.14052128390176222, 0.16290484374621883, 0.12344776841928251, 0.23569332232000306, 0.26324752892833203, 0.2737623068969697, 0.17121951008448377, 0.14666151691926643, 0.23082367581082508, 0.1961396267870441, 0.17711383989080787, 0.14019659429322928, 0.15197361703030765, 0.06381344181136228, 0.2972985408268869, 0.1071752529242076, 0.11131351289805025, 0.3193632740294561, 0.22507035406306386, 0.17838472325820476, 2.551241763867438, 14.864258989691734, 33.93590681254864, 26.68323028832674, 22.962167859077454, 14.421238861978054, 9.363941084593534, 10.4278345964849, 38.29228185117245, 46.93368695676327, 35.745669901371, 18.138465397059917, 0.7129300350788981, 1.1038592923432589, 1.3509668014012277, 1.8997069937177002, 31.174290999770164, 60.568704307079315, 60.295225381851196, 46.541430205106735, 32.50198535621166, 17.648675478994846, 9.97557146474719, 21.53392519801855, 31.618889942765236, 36.632922291755676, 32.87102535367012, 12.946437299251556, 2.184521541930735, 1.132209214847535, 0.36178951151669025, 0.20433125988347456, 0.23493115149904042, 0.47892662754748017, 0.3813949751202017, 0.2767997985938564, 0.1662403967930004, 0.19098935939837247, 0.179697003623005, 0.16592413798207417, 0.19486109929857776, 0.17131076456280425, 0.23974380106665194, 0.18843500583898276, 0.2547407947713509, 0.1880973731749691, 0.2235964933061041, 0.20880313008092344, 0.18960411107400432, 0.23156114795710891, 0.14130476920399815, 0.1548157012439333, 0.22841282392619178, 0.2611181588144973, 0.15512706188019365, 0.1420257063000463, 0.12067465198924765, 0.15619364683516324, 0.1452457217965275, 0.12243006131029688, 0.13741526228841394, 0.12298584086238407, 0.196882531454321, 0.13301446015248075, 0.23109041852876544, 0.15833287267014384, 0.2004725520964712, 0.1525358235812746, 0.09580421465216205, 0.19419663964072242, 0.20305855083279312, 0.0805841907276772, 0.10378843973740004, 0.17085064784623682, 0.1950367062818259, 0.11323824321152642, 0.13318729150341824, 0.10643579924362712, 0.16824131598696113, 0.11877150333020836, 0.13330723741091788, 0.22042712196707726, 0.14907300705090165, 0.1313105781446211, 0.26770949887577444, 0.15448121528606862, 0.1685846335021779, 0.11172723054187372, 0.1371172009385191, 0.22223730920813978, 0.18737980542937294, 0.20055001747095957, 0.1984393346356228, 0.21855518803931773, 0.1798413068172522, 0.12087055671145208, 0.27505183301400393, 0.2917761605931446, 0.1880206202622503], [0.03974230494350195, 0.03583339086617343, 0.012642133151530288, 0.03379864829184953, 0.02799043730192352, 0.03935759414162021, 0.0282785111994599, 0.0291579005352105, 0.07666748409974389, 0.03249453897296917, 0.05783641820016783, 0.03279896794992965, 0.06427678687032312, 0.03489946851914283, 0.05666416996973567, 0.019601597014116123, 0.06242490577278659, 0.042727716427179985, 0.03431505690969061, 0.09023694190545939, 0.11039797725970857, 0.034108509789803065, 0.055567431554663926, 0.05565932427998632, 0.0229981879965635, 0.03642694573500194, 0.04888467003183905, 0.04557053165626712, 0.027076578917331062, 0.07037168950773776, 0.17204534233314916, 0.053719064526376314, 0.017778535366232973, 0.05961781011137646, 0.002486870766915672, 0.05406608535849955, 0.04562457856081892, 0.07294396593351848, 0.043176830804441124, 0.07721460278844461, 0.044688748894259334, 0.10752070782473311, 0.014135791625449201, 0.035346193180885166, 0.08387535592191853, 0.12263161377632059, 0.07030536376987584, 0.03346310848428402, 0.06875367398606613, 0.021360312603064813, 0.03703999311255757, 0.022124928800622, 0.01394999217154691, 0.12459043093258515, 0.08734035436646082, 0.0428387046122225, 0.061554399944725446, 0.11841485684271902, 0.22329849132802337, 0.06613992634811439, 0.06141002624644898, 0.0989074532117229, 0.023312190678552724, 0.05850780951732304, 0.06991147631197236, 0.03791914496105164, 0.08090016010100953, 0.06202518503414467, 0.08042146000661887, 0.04447919978701975, 0.017820238499552943, 0.0034988269271707395, 0.22239942394662648, 0.0464717475551879, 0.05098817258840427, 0.11665650861687027, 0.12875919317593798, 1.0660940688103437, 7.134314775466919, 17.61017594486475, 17.36479841172695, 8.860217314213514, 2.094441675581038, 1.7268232768401504, 1.6252867877483368, 2.862725299783051, 4.303373582661152, 3.65633646491915, 5.18617213703692, 3.7962703686207533, 2.3874040553346276, 5.484348786994815, 14.232348147779703, 21.29121132194996, 14.959826711565256, 15.308127421885729, 2.421078085899353, 6.147742364555597, 5.90516148135066, 5.7095650769770145, 4.4856080040335655, 6.021215803921223, 9.598375204950571, 9.756297580897808, 4.349655574187636, 0.8158652647398412, 0.07649268605746329, 0.008838820194796426, 0.06774306923034601, 0.041782342741498724, 0.053779887239215896, 0.06405489213648252, 0.04971948597813025, 0.017036868230206892, 0.04600864369422197, 0.02854145783203421, 0.03220817387045827, 0.041267325650551356, 0.0633985515742097, 0.04105448882910423, 0.07308190892217681, 0.04840195120777935, 0.05520299993804656, 0.07902070079580881, 0.08578848646720871, 0.07663542332011275, 0.027761017190641724, 0.047327347347163595, 0.03966819778725039, 0.03712950354383793, 0.03348432277562097, 0.05701040041458327, 0.022093945990491193, 0.01597047994437162, 0.043631774751702324, 0.010698691439756658, 0.03636289096903056, 0.04074232667335309, 0.04644542728783563, 0.09247453199350275, 0.02115768402290996, 0.041043490200536326, 0.053232319551170804, 0.07437177642714232, 0.013720894894504454, 0.01025831677907263, 0.05418098095105961, 0.04538470158877317, 0.011999605812889058, 0.031046317562868353, 0.05561680663959123, 0.030090088112046942, 0.025693853895063512, 0.0343340039398754, 0.028165791954961605, 0.014406648624571972, 0.048021607944974676, 0.07635981935891323, 0.017971503039007075, 0.03058001875615446, 0.025148911554424558, 0.04034452067571692, 0.0213322297349805, 0.031224687190842815, 0.028625578415812925, 0.06297258849372156, 0.03771977440919727, 0.01783741550752893, 0.07801909829140641, 0.025192019202222582, 0.019324629356560763, 0.058772366610355675, 0.056686041061766446, 0.012597200748132309, 0.107605275552487, 0.04399114492116496, 0.037317085079848766, 0.05514385818969458, 0.0393238227115944, 0.04735288464871701, 0.039780744482413866, 0.0335011583956657, 0.10705273918574676, 0.09421251568710431, 0.06802510019042529, 0.015697193339292426, 0.025326733848487493, 0.10846503137145191, 0.04220048358547501, 0.03704204886162188, 0.11027571585145779, 0.22365709708537906, 0.12016894514090382, 0.039974797546165064, 0.040345155211980455, 0.018736293641268276, 0.0900879038090352, 0.05078574067738373, 0.07577483629574999, 0.07344228099100292, 0.04145025020989124, 0.027420599617471453, 0.01654296152992174, 0.01794964678992983, 0.03497232144582085, 0.028727278622682206, 0.10596515887300484, 0.04572400779579766, 0.06481770120444708, 0.056491538998670876, 0.06425203624530695, 0.048690390613046475, 0.037132976794964634, 0.028909179018228315, 0.04890893083938863, 0.04104477040527854, 0.031475032155867666, 0.038534121922566555, 0.08847264165524393, 0.025905447619152255, 0.035248764033894986, 0.10263952091918327, 0.054786985347163863, 0.014748550493095536, 0.06953734482522123, 0.03511444643663708, 0.009852383336692583, 0.029991981755301822, 0.033520320648676716, 0.05812847928609699, 0.011226747137698112, 0.021733239955210593, 0.050787584914360195, 0.12191054309369065, 0.11892173628439195, 0.046798029070487246, 0.08362543027033098, 0.06429901419323869, 0.020109517317905556, 0.06616464728722349, 0.10550881226663478, 0.07183924200944602, 0.027547968857106753, 0.04052216114359908, 0.035767640292760916, 0.0517349846631987, 0.05524428190256003, 0.08047911003814079, 0.07412046295939945, 0.06432935319026001, 0.026519342900428455, 0.0996288652822841, 0.10690005714423023, 1.8914824537932873, 9.897767789661884, 24.849885664880276, 21.47852797061205, 11.738910544663668, 4.369381740689278, 0.9146886400412768, 2.0684603322297335, 6.7038073763251305, 8.663264382630587, 15.526069477200508, 22.464149482548237, 16.694546677172184, 6.468051401898265, 11.503803860396147, 31.7995797470212, 44.8977068066597, 36.57867640256882, 27.978584580123425, 6.618110099807382, 9.52244957908988, 8.89316439628601, 8.758538570255041, 9.595596604049206, 10.145933423191309, 20.019054785370827, 16.589546911418438, 8.123838678002357, 1.460891815368086, 0.11331877365591936, 0.05324252037098631, 0.1228456714306958, 0.03865558923280332, 0.06253484752960503, 0.08922442983021028, 0.030351487366715446, 0.03518775207339786, 0.03019974599737907, 0.013912033173255622, 0.0778161951166112, 0.02720689448324265, 0.04071507872140501, 0.07756109669571742, 0.05189279865589924, 0.033441241102991626, 0.036862037231912836, 0.039944595846463926, 0.006522473859149613, 0.06666276938631199, 0.038856818864587694, 0.05448796662676614, 0.09975881534046493, 0.06864160968689248, 0.058256577685824595, 0.015238693576975493, 0.05195352488954086, 0.04690355504862964, 0.01593792378116632, 0.02038772992818849, 0.03419295135245193, 0.08304262169986032, 0.004522723547779606, 0.06212557535036467, 0.0662792423099745, 0.02865538863261463, 0.03590391715988517, 0.014162169409246417, 0.03814070201769937, 0.06357071499223821, 0.03538373843184672, 0.016734654564061202, 0.025903941059368663, 0.02604037192213582, 0.02995040478708688, 0.03186237387126312, 0.059646163863362744, 0.04527643708570395, 0.0279273213527631, 0.0423687989678001, 0.01185151395475259, 0.05950507787929382, 0.00496820279295207, 0.07948628714075312, 0.07047348248306662, 0.011277814319328172, 0.13025954860495403, 0.055562266206834465, 0.0628522937768139, 0.09557192985084839, 0.03528876208292786, 0.03819860809016973, 0.05557932447118219, 0.05458543288114015, 0.07986844124388881, 0.08857214139425196, 0.026475719459995162, 0.19819797336822376, 0.043645385740092024, 0.02248860342660919, 0.308809548150748, 0.15815043792827055, 0.16405370319262147, 0.19349113921634853, 0.11955249501625076, 0.1413454388966784, 0.24765879119513556, 0.15244229813106358, 0.1954189271782525, 0.1714969248860143, 0.18143451976357028, 0.2929985668743029, 0.15297832171199843, 0.15986934100510553, 0.17659225850366056, 0.3140248276758939, 0.198456552461721, 0.13608430948806927, 0.1650421548401937, 0.19640677026472986, 0.22504477965412661, 0.1734333366039209, 0.25219579227268696, 0.1999467849964276, 0.16060757014201954, 0.08568762859795243, 0.2015071059577167, 0.17847925802925602, 0.19149943749653175, 0.2154941257322207, 0.24904021003749222, 0.19508562865667045, 0.12361980567220598, 0.1424024798325263, 0.09430152145796455, 0.1478957975632511, 0.0953594381280709, 0.14828316896455362, 0.14434012351557612, 0.13593427691375837, 0.15564986038953066, 0.10658182422048412, 0.1549596036784351, 0.12856718472903594, 0.15747327270219103, 0.22667032055323943, 0.20272902242140844, 0.09840110069490038, 0.12607454817043617, 0.18869386694859713, 0.16747858113376424, 0.19287184666609392, 0.12768722022883594, 0.17106725106714293, 0.282057321164757, 0.10016955697210506, 0.2648586721625179, 0.22183447144925594, 0.2298387567861937, 0.12434074276825413, 0.14754157047718763, 0.22519645979627967, 0.11091724314610474, 0.14680623571621254, 0.23104056104784831, 0.122311584855197, 0.17110379441874102, 0.19469966733595356, 0.14080281020142138, 0.20769336697412655, 0.12258241680683568, 0.13349520857445896, 0.2347444271435961, 0.13266035181004554, 0.11056835952331312, 0.22099210415035486, 0.1058624530560337, 0.763415788533166, 8.818443305790424, 28.312871642410755, 37.37113907933235, 28.893224000930786, 23.634807765483856, 11.166340168565512, 10.830541737377644, 27.291241362690926, 36.135327592492104, 45.66619656980038, 44.2814064770937, 28.006798066198826, 7.389068780466914, 15.756401717662811, 42.22797006368637, 69.66702729463577, 61.07855334877968, 67.05251678824425, 40.88354900479317, 36.81809775531292, 32.86573983728886, 31.819627471268177, 26.312685571610928, 29.883236177265644, 41.07199989259243, 25.207896754145622, 7.4450877495110035, 1.3581776269711554, 0.6466457387432456, 0.12752381415339187, 0.3015221923124045, 0.15357828873675317, 0.1255095363012515, 0.4015289666131139, 0.09805018358747475, 0.1189298256940674, 0.11596786236623302, 0.07846869877539575, 0.14346137613756582, 0.1272731611970812, 0.18997543724253774, 0.15192801947705448, 0.16585390112595633, 0.1882574989576824, 0.08042768662562594, 0.1439956037211232, 0.2892776165390387, 0.3039135999279097, 0.12723752326564863, 0.13123240030836314, 0.21052210737252608, 0.19148055725963786, 0.11135675784316845, 0.119843298161868, 0.19157786766299978, 0.14301528601208702, 0.11973018001299351, 0.09665591074735858, 0.12228514955495484, 0.24938518996350467, 0.24109730031341314, 0.16514133545570076, 0.1700256616459228, 0.2281148813199252, 0.13161977170966566, 0.17663598584476858, 0.08132981165545061, 0.16267252183752134, 0.17709067004034296, 0.16597270412603393, 0.09094996770727448, 0.16722249565646052, 0.1395850200788118, 0.20714158017653972, 0.19774385320488364, 0.14078011532546952, 0.11657071634544991, 0.08497618357068859, 0.18002299941144884, 0.11646467828541063, 0.09872303693555295, 0.211139514867682, 0.198002714314498, 0.19429256964940578, 0.13744779804255813, 0.12505676684668288, 0.23639548307983205, 0.18519992474466562, 0.1315769794746302, 0.14170006674248725, 0.1534892458585091, 0.15383571007987484, 0.19863996683852747, 0.21324080211343244, 0.25286114250775427, 0.3623155754758045, 0.22973026963882148, 0.20431223121704534], [0.03177885999321006, 0.04311300610424951, 0.02352790703298524, 0.0840198817604687, 0.01372479766359902, 0.052039795846212655, 0.018178376703872345, 0.03256388154113665, 0.07661931871552952, 0.079513271630276, 0.048613997641950846, 0.01584925383212976, 0.11398205329896882, 0.03220707178115845, 0.02679651093785651, 0.0563878906541504, 0.038494105319841765, 0.08441736863460392, 0.05361268136766739, 0.08344643909367733, 0.05153409641934559, 0.04087879649887327, 0.09212840916006826, 0.051058275857940316, 0.03388848155736923, 0.07358258400927298, 0.07773662204272114, 0.0437193110701628, 0.07441585999913514, 0.0547751592239365, 0.028849977898062207, 0.011975661345786648, 0.02527119893784402, 0.04950507951434702, 0.01178245804112521, 0.041422694266657345, 0.06943102474906482, 0.006349187015075586, 0.074337719270261, 0.05746809401898645, 0.022478179962490685, 0.052473647956503555, 0.10068594332551584, 0.014084749491303228, 0.05438489344669506, 0.11379405987099744, 0.09276789554860443, 0.004380645868877764, 0.037320216943044215, 0.05261196944047697, 0.05390862388594542, 0.05996106454404071, 0.09237464633770287, 0.06585722003364936, 0.03836475640127901, 0.036160466479486786, 0.06500705276266672, 0.07756921579129994, 0.02894945351727074, 0.042366620764369145, 0.04054663717397489, 0.024528544745408, 0.08815317676635459, 0.11060338147217408, 0.1721814225311391, 0.05897473172808532, 0.12129912473028526, 0.034412916502333246, 0.01470289820645121, 0.04229658799886238, 0.10298628942109644, 0.13781980698695406, 0.06451351713621989, 0.05470478878123686, 0.06513085783808492, 0.045715725427726284, 0.05459249070554506, 0.5371439864393324, 2.8471544478088617, 6.722801607102156, 14.796285387128592, 11.99651962146163, 3.6407791497185826, 1.3968284404836595, 0.7495398831088096, 1.4127859217114747, 2.830206169746816, 3.131272802129388, 5.204113824293017, 8.432845696806908, 11.082205083221197, 14.66011019423604, 18.93459677696228, 13.89425178989768, 18.995587304234505, 20.703681148588657, 3.696069032885134, 2.108112392015755, 6.826757378876209, 3.84120034519583, 1.9137964001856744, 5.500546367838979, 5.94511111266911, 4.034097231924534, 1.0506666591390967, 0.25672814750578254, 0.10177931981161237, 0.07041897915769368, 0.030138691363390535, 0.12902143847895786, 0.08580788620747626, 0.016279784831567667, 0.03731937460543122, 0.028313163929851726, 0.02371203387156129, 0.007393451414827723, 0.056114041872206144, 0.06979451383813284, 0.018609224971442018, 0.02422539226245135, 0.014779790271859383, 0.05563219136092812, 0.011072713459725492, 0.05325030550011434, 0.045533721131505445, 0.048009329111664556, 0.014907532440702198, 0.023289065356948413, 0.0568884915264789, 0.06394526208168827, 0.03567146537534427, 0.04349660739535466, 0.05920161369431298, 0.10218378287390806, 0.0804763195628766, 0.033140793748316355, 0.03801258506427985, 0.08795670801191591, 0.027060357424488757, 0.020771242161572445, 0.06438626107410528, 0.09593399401637726, 0.03797429766564164, 0.05659269372699782, 0.051865294663002715, 0.0381519381335238, 0.020084028255951125, 0.0321660495683318, 0.05405074145528488, 0.03989273085608147, 0.03230404450732749, 0.01659242010646267, 0.0942191133799497, 0.03832682894426398, 0.0659299133985769, 0.05696000858733896, 0.031689984098193236, 0.03746898415556643, 0.061414946685545146, 0.018676929248613305, 0.054490842449013144, 0.036092960726819, 0.08034553829929791, 0.07703514405875467, 0.04022360255476087, 0.06401608523447067, 0.04881739805568941, 0.04924430737446528, 0.055988555832300335, 0.12791103712515905, 0.043177027473575436, 0.06025640221196227, 0.01177362091766554, 0.05380562120990362, 0.05145613009517547, 0.04056803329149261, 0.07713890372542664, 0.024929527135100216, 0.04411008150782436, 0.0746317656012252, 0.03135516417387407, 0.0481224583927542, 0.01421379134626477, 0.022259923607634846, 0.0779500043427106, 0.01593891269294545, 0.11945110280066729, 0.036765086770174094, 0.04330831339757424, 0.1282609745976515, 0.0941907856031321, 0.09507866139756516, 0.024731830126256682, 0.10193344161962159, 0.019112890913675074, 0.05257917022390757, 0.07014842180069536, 0.03238998520828318, 0.0591959214216331, 0.04062016545503866, 0.07914599758805707, 0.00132906403450761, 0.11561880062799901, 0.0404079557483783, 0.04730817396193743, 0.03554211274604313, 0.011813753480964806, 0.05166143411770463, 0.011826920108433114, 0.04301567343645729, 0.03902233635017183, 0.015523083638981916, 0.009910401658999035, 0.024255209900729824, 0.04557600499538239, 0.06975942509598099, 0.023944250024214853, 0.03292911838798318, 0.07675757340621203, 0.04610468873579521, 0.041910103464033455, 0.052180373459123075, 0.07267131572007202, 0.03148445743136108, 0.045130567959859036, 0.012408019883878296, 0.04294040481909178, 0.08461037155939266, 0.11322969367029145, 0.05789801274659112, 0.041897297705872916, 0.03474602948699612, 0.04372215349576436, 0.034134822635678574, 0.025218152077286504, 0.021797279878228437, 0.03395592051674612, 0.13614276103908196, 0.06802655479987152, 0.09095579356653616, 0.11391022824682295, 0.0740850402507931, 0.061924950568936765, 0.033222637794096954, 0.037018930961494334, 0.00844157359097153, 0.06328790477709845, 0.09863933752058074, 0.028640202435781248, 0.024876244642655365, 0.11144065763801336, 0.011189069227839354, 0.08085974273853935, 0.7197265641298145, 4.1465673968195915, 14.451836720108986, 25.01768086105585, 19.4392628967762, 7.266522981226444, 2.714881645515561, 0.8178804628551006, 1.8896818254143, 9.339039120823145, 16.519672460854053, 15.829262807965279, 26.594233363866806, 31.388757191598415, 35.084448382258415, 37.31031574308872, 28.373710177838802, 41.645024344325066, 36.3429294526577, 7.2289016749709845, 3.9154388615861535, 11.09524978324771, 8.898678850382566, 6.162046222016215, 10.487593039870262, 14.62208753451705, 10.716354064643383, 2.9905285919085145, 0.333107789629139, 0.19767723802942783, 0.01904107142763678, 0.01770420556567842, 0.062289397028507665, 0.04530004851403646, 0.030088553721725475, 0.01533724336695741, 0.05168399169633631, 0.0328727003216045, 0.04134532908210531, 0.032409741179435514, 0.056813248884282075, 0.02563988120527938, 0.03134136764856521, 0.047922828089213, 0.010213159876002464, 0.035318663212819956, 0.005609297322735074, 0.0038537103500857484, 0.058714185943244956, 0.03311080356070306, 0.04764464516483713, 0.054654742052662186, 0.03532267452101223, 0.07385053642792627, 0.045016325457254425, 0.023940147802932188, 0.017793580555007793, 0.06387289526173845, 0.010564397962298244, 0.05676594068063423, 0.05294526054058224, 0.022573785281565506, 0.02535810443077935, 0.09582072743796743, 0.016372805621358566, 0.035163958818884566, 0.05811273462313693, 0.03216717021132354, 0.02434401529171737, 0.02343027194001479, 0.027230003106524237, 0.027966814741375856, 0.07347516555455513, 0.028213257864990737, 0.061984348358237185, 0.03867020583129488, 0.04510552047577221, 0.05957986038993113, 0.1698397091240622, 0.052565269797923975, 0.06441622899728827, 0.04596771424985491, 0.03899571551301051, 0.06601061453693546, 0.07065406927722506, 0.012412862397468416, 0.0289651536513702, 0.06213519358425401, 0.05628000093565788, 0.054973880396573804, 0.028367557788442355, 0.05012822010030504, 0.06666855071671307, 0.0377731274056714, 0.005861993040525704, 0.030519717402057722, 0.058831018541241065, 0.09227585906046443, 0.05460217944346368, 0.19472840329399332, 0.12286124911042862, 0.09862686201813631, 0.1468717525131069, 0.21351278439396992, 0.15745195822091773, 0.17628622648771852, 0.10660105326678604, 0.1454335148446262, 0.15774976724060252, 0.2641251333989203, 0.12009778060019016, 0.21945680840872228, 0.20898369461065158, 0.23636708850972354, 0.18699651584029198, 0.14381270884769037, 0.26210699637886137, 0.19362423598067835, 0.13560685620177537, 0.11140130896819755, 0.1869589334819466, 0.1363564995699562, 0.19549409189494327, 0.11240961306612007, 0.13528495706850663, 0.2244813262950629, 0.098197217885172, 0.21727504266891629, 0.15348878572694957, 0.08820433300570585, 0.18068239762214944, 0.09268255598726682, 0.10890848687267862, 0.10135388365597464, 0.16318341629812494, 0.1386834739241749, 0.13643697806401178, 0.12510258704423904, 0.2771239686990157, 0.13151674676919356, 0.13870659924577922, 0.16386377275921404, 0.12641627748962492, 0.16391567856771871, 0.2079454151680693, 0.2542245271615684, 0.09369174324092455, 0.08975762582849711, 0.11188993157702498, 0.16814752336358652, 0.095974329742603, 0.2661105268634856, 0.12171768117696047, 0.1350698826718144, 0.09450869940337725, 0.1803780280170031, 0.1156946703849826, 0.14394267374882475, 0.10016884451033548, 0.08879231434548274, 0.18283928657183424, 0.15676493727369234, 0.21605177549645305, 0.3165291011100635, 0.13283906097058207, 0.16597956157056615, 0.09269786649383605, 0.13049552188022062, 0.12477141106501222, 0.15699605690315366, 0.18842788122128695, 0.17275931808399037, 0.2629974251613021, 0.14987878646934405, 0.11331515197525732, 0.10216065013082698, 0.4111962713068351, 3.338096416555345, 15.307726543396711, 35.660786256194115, 32.911983355879784, 25.761521346867085, 16.87653411179781, 7.891794154420495, 15.785013232380152, 35.34765265882015, 38.93370643258095, 43.88159953057766, 55.64649023115635, 55.60836307704449, 61.3288839161396, 67.10620030760765, 55.30975230038166, 62.093064710497856, 65.91407507658005, 21.045864187180996, 21.483697593212128, 37.0169372856617, 26.402831934392452, 22.361133210361004, 33.69593068957329, 25.921956337988377, 13.866137098520994, 1.8642814946360886, 0.5166034761350602, 0.2850251103518531, 0.1095255752443336, 0.16475981217809021, 0.24058112176135182, 0.2320124628022313, 0.13584799482487142, 0.07662851392524317, 0.10045601113233715, 0.16435741970781237, 0.21030510339187458, 0.20131567638600245, 0.21309194213245064, 0.1894398737931624, 0.12350731834885664, 0.14973069832194597, 0.1439224576461129, 0.0515491434634896, 0.1357629892299883, 0.1761564693879336, 0.18701682100072503, 0.11550079172593541, 0.21425010811071843, 0.17182810086524114, 0.24847222957760096, 0.15638574433978647, 0.1577566543710418, 0.10817974980454892, 0.13057237869361416, 0.26972330175340176, 0.11903802340384573, 0.22156627412186936, 0.24802754953270778, 0.13662404380738735, 0.15053963928949088, 0.24550577625632286, 0.21689988701837137, 0.1510973781114444, 0.18360663758357987, 0.12409323651809245, 0.11755161292967387, 0.09714663363411091, 0.11844978973385878, 0.16139527084305882, 0.16435817669844255, 0.1282592082861811, 0.1354928920045495, 0.15669345360947773, 0.11212079887627624, 0.16307007550494745, 0.22825299500254914, 0.10361000517150387, 0.1389310840750113, 0.22616493282839656, 0.09892265981761739, 0.18038120440905914, 0.084026546246605, 0.17699742660624906, 0.20827951520914212, 0.2340579405426979, 0.27186288381926715, 0.16755404270952567, 0.11180304834851995, 0.1333688950398937, 0.30839082843158394, 0.19952892616856843, 0.1893395057413727, 0.12252277781954035, 0.18645853298949078, 0.14507394429529086, 0.15131030027987435], [0.019243809474573936, 0.03855956645566039, 0.08087128313491121, 0.08693857787875459, 0.07258161233039573, 0.04119912970054429, 0.03523068160575349, 0.09489317642874084, 0.03237119773984887, 0.020478793303482234, 0.03690670338983182, 0.02115968040016014, 0.04700328856415581, 0.03372843741090037, 0.04749031184474006, 0.04016078346467111, 0.12805496924556792, 0.03943468473153189, 0.07651527703274041, 0.033570641971891746, 0.032016503100749105, 0.10864322845009156, 0.014807414863753365, 0.05350463579816278, 0.008558656663808506, 0.019176615423930343, 0.030034723895369098, 0.023662410167162307, 0.02073779727652436, 0.002358931233175099, 0.04676150427258108, 0.04657298391975928, 0.041893442248692736, 0.07945742501760833, 0.05196667574637104, 0.07391807186650112, 0.0442834323621355, 0.06179212468850892, 0.013059867669653613, 0.09634451300371438, 0.027119050173496362, 0.04765442667121533, 0.016023140888137277, 0.01174513265141286, 0.026659842587832827, 0.07944537253933959, 0.02764840184681816, 0.06232595522305928, 0.07917058494058438, 0.07126047814381309, 0.016737196419853717, 0.030568699148716405, 0.050442152278264984, 0.053259092528605834, 0.01557056439196458, 0.04250640427926555, 0.058604830483091064, 0.030032658869458828, 0.05941484385402873, 0.03985109637142159, 0.09310324239777401, 0.010501329325052211, 0.08013764047063887, 0.035843825462507084, 0.01997487688640831, 0.07138871384086087, 0.027400301878515165, 0.08703841900569387, 0.044385848741512746, 0.0403775907761883, 0.03936883025744464, 0.03685417046654038, 0.09300862599047832, 0.0378488413116429, 0.03200099221430719, 0.08452333247987553, 0.059429171014926396, 0.19446477759629488, 0.37412323406897485, 5.0960134249180555, 8.55695653706789, 8.588780779391527, 6.792742554098368, 1.1557204532437027, 3.599180644378066, 2.799109350889921, 6.714473878964782, 5.500019621104002, 8.12668377533555, 7.80348926782608, 12.152168769389391, 14.22884188592434, 10.574075449258089, 12.993205189704895, 38.684637397527695, 18.912569358944893, 5.340677546337247, 2.7422209409996867, 1.0174695029854774, 4.874249249696732, 4.851021571084857, 7.144015654921532, 7.4435721058398485, 2.1248046588152647, 0.25523435266222805, 0.03880076816130895, 0.033671158453216776, 0.056015466107055545, 0.03757099235372152, 0.027233814034843817, 0.03174803488946054, 0.04984280494682025, 0.024371606486965902, 0.068515429738909, 0.030192662197805475, 0.03589942345570307, 0.012537910570245003, 0.012212528909003595, 0.07341868069488555, 0.028997912049817387, 0.04048748429340776, 0.023206581208796706, 0.015750037964608055, 0.032796808300190605, 0.02961585018056212, 0.05630540836136788, 0.02423468580673216, 0.0803127427934669, 0.02394826504314551, 0.027717809352907352, 0.10500796648557298, 0.07179189298767596, 0.054759295817348175, 0.024700082904018927, 0.02761265444860328, 0.0631606116076, 0.033778009164961986, 0.041583870188333094, 0.014912677379470551, 0.02988892712892266, 0.07444423230481334, 0.023720191929896828, 0.031722608910058625, 0.00284408708466799, 0.07704796094913036, 0.062082682925392874, 0.026448939061083365, 0.03747376729734242, 0.07335400252486579, 0.04765469013364054, 0.04293246383895166, 0.025890632496157195, 0.04755073008709587, 0.0541187258932041, 0.02395437848463189, 0.014225097966118483, 0.0863344399840571, 0.031110105155676138, 0.05816681121359579, 0.02091506110446062, 0.09412698316737078, 0.009789433443074813, 0.06374642587616108, 0.04268894663255196, 0.0231860441272147, 0.04982406200724654, 0.06108151086664293, 0.021507480487343855, 0.0748636199568864, 0.03618883878516499, 0.016348602330253925, 0.06574629864189774, 0.0669315826962702, 0.0829751901619602, 0.1677697108243592, 0.03502586740069091, 0.03298960342362989, 0.01185742979942006, 0.016519179407623596, 0.029406000503513496, 0.11974114153417759, 0.047973557593650185, 0.04507772333454341, 0.07987399250851013, 0.057448501320322976, 0.054076809392427094, 0.08956244098953903, 0.05151909019332379, 0.04493657426792197, 0.08484109785058536, 0.15883995249168947, 0.07970679405843839, 0.01381548996505444, 0.05781577907328028, 0.038077214994700626, 0.04235324355249759, 0.03484076092718169, 0.033746197004802525, 0.04996759336791001, 0.039919670816743746, 0.06468035935540684, 0.02896572510508122, 0.07702100614551455, 0.02837301628460409, 0.072524274000898, 0.007759393765809364, 0.05688929675670806, 0.024299209981109016, 0.018892159496317618, 0.0646480091381818, 0.06173222223878838, 0.048880796020966955, 0.045662146076210774, 0.017511436417407822, 0.030550464580301195, 0.09026849802467041, 0.08021342116990127, 0.04216039276798256, 0.04986201543943025, 0.06382729770848528, 0.04270877681847196, 0.0675165509164799, 0.05308014959155116, 0.019582353124860674, 0.013610512487503001, 0.0393605627323268, 0.034123645891668275, 0.06887931216624565, 0.03830394853139296, 0.061145873623900115, 0.06077852907765191, 0.00933951198021532, 0.048909713805187494, 0.05246061584330164, 0.044664009401458316, 0.05772613134467974, 0.05980379974062089, 0.15686906059272587, 0.1117689318198245, 0.0633368494163733, 0.042327672854298726, 0.112930348404916, 0.061990374597371556, 0.020040271228936035, 0.09950559455319308, 0.04604576221026946, 0.07862532904255204, 0.09764707865542732, 0.0701543886680156, 0.05211453382798936, 0.06625299996812828, 0.04334268596721813, 0.04399019497213885, 0.17746487574186176, 1.3898591394536197, 6.159962033852935, 14.783708062022924, 19.813096337020397, 14.772508163005114, 5.887344237416983, 0.9181158186402172, 2.9094642167910933, 2.861943729221821, 9.240029733628035, 21.100993528962135, 24.956412948668003, 34.34217341244221, 30.523450523614883, 29.614550694823265, 35.23295201361179, 52.11829595267773, 29.29683644324541, 7.229981767013669, 5.167526537552476, 10.042057447135448, 5.8215122949332, 7.876926027238369, 10.661154426634312, 11.118051409721375, 3.753453316166997, 0.3766562434611842, 0.14302576513728127, 0.08924163281335495, 0.045286615641089156, 0.02977041542180814, 0.01740303276164923, 0.06553639701451175, 0.04503880882111844, 0.03804451596806757, 0.018058248970191926, 0.040681752579985186, 0.05049399129347876, 0.010839142887562048, 0.038124126149341464, 0.07328314226469956, 0.05429655189800542, 0.055059179139789194, 0.015590389011777006, 0.031504706930718385, 0.038862303335918114, 0.012238921535754343, 0.05460878826852422, 0.029554541360994335, 0.006055541443856782, 0.0249131089731236, 0.040755113877821714, 0.05281891360937152, 0.03849903689115308, 0.011316748314129654, 0.01274078591450234, 0.058377128443680704, 0.02358945148444036, 0.035226763066020794, 0.05194239267439116, 0.030175987994880415, 0.0050729982194752665, 0.027218329123570584, 0.08912816585507244, 0.02964556020742748, 0.03265906940214336, 0.01918002002639696, 0.03780780425586272, 0.052035940389032476, 0.029851110994059127, 0.07068966267979704, 0.0037918882890153327, 0.09552397226798348, 0.058457369450479746, 0.013793680100206984, 0.028687582998827565, 0.012521150092652533, 0.013379334413912147, 0.05047245787864085, 0.022685003532387782, 0.03852287838526536, 0.06323361667455174, 0.06100066500948742, 0.061704317486146465, 0.04947314861055929, 0.012243610053701559, 0.022322358636301942, 0.05847602333233226, 0.027298534878354985, 0.00839709946376388, 0.09436482665478252, 0.03509478694468271, 0.0036997903134761145, 0.01786127184459474, 0.033245028389501385, 0.11297055796603672, 0.1259226750698872, 0.05346203652152326, 0.14080784196266904, 0.10723273226176389, 0.15397514478536323, 0.17780489812139422, 0.22003397665685043, 0.11037226926418953, 0.0828055500460323, 0.12140743376221508, 0.08700310761923902, 0.1257685903692618, 0.23106004984583706, 0.12801422533812, 0.1662268303334713, 0.11323499260470271, 0.17530366749269888, 0.28165501775220037, 0.3304222540464252, 0.18725712841842324, 0.14905984135111794, 0.17291190364630893, 0.08712150243809447, 0.23582722060382366, 0.20115927618462592, 0.1700993420672603, 0.21783908974612132, 0.19234011269873008, 0.22774555895011872, 0.10030738121713512, 0.21179325791308656, 0.09321809717221186, 0.15766796772368252, 0.1562204977381043, 0.11958618109929375, 0.13818540377542377, 0.11222427652683109, 0.2872302389005199, 0.20181770960334688, 0.23043332097586244, 0.11153474712045863, 0.20581076096277684, 0.2452819890459068, 0.12437982426490635, 0.18181444000219926, 0.13954185676993802, 0.11691105784848332, 0.14392425364349037, 0.23645150038646534, 0.14991676958743483, 0.1395461760694161, 0.13742054637987167, 0.13627891545183957, 0.2242989360820502, 0.1272221904946491, 0.16124188376124948, 0.15217119158478454, 0.19979421427706257, 0.10290613005054183, 0.20976191066438332, 0.22754740552045405, 0.08373408811166883, 0.16743224143283442, 0.21681972022634, 0.17114453832618892, 0.198595141118858, 0.0836791394976899, 0.22733653167961165, 0.1908266806276515, 0.22245579748414457, 0.23852262675063685, 0.1610802736831829, 0.1687831580056809, 0.12051413286826573, 0.2287136163795367, 0.11432832456193864, 0.12066153081832454, 0.2209338010288775, 0.14144647488137707, 0.13661975419381633, 1.2169820722192526, 8.821382448077202, 18.793858028948307, 30.93122374266386, 26.168732196092606, 23.485648669302464, 21.059959530830383, 11.970795001834631, 14.935427270829678, 33.69641326367855, 46.135839968919754, 49.94698606431484, 66.94765761494637, 57.555032819509506, 62.37695127725601, 53.24117749929428, 72.14070215821266, 56.42920643091202, 22.15223751962185, 28.373267501592636, 36.21305242180824, 26.313774213194847, 26.15910731256008, 25.252019986510277, 18.435398563742638, 3.239704496227205, 0.4498541500652209, 0.2072042619693093, 0.17888460424728692, 0.16199897829210386, 0.1567770936526358, 0.20844470243901014, 0.15857128018978983, 0.2197760803392157, 0.24306464474648237, 0.15157201123656705, 0.1982572561246343, 0.2250874086166732, 0.12083459965651855, 0.12205314676975831, 0.24715378938708454, 0.18940929730888456, 0.12447701592464, 0.09606435225578025, 0.1885175029747188, 0.11446437507402152, 0.1829795227968134, 0.18305204546777532, 0.10365557303884998, 0.14452920790063217, 0.15897419216344133, 0.17213865998201072, 0.28260176070034504, 0.0945813037105836, 0.08296231389977038, 0.05638142283714842, 0.13730030361330137, 0.14190279180184007, 0.0992431266058702, 0.17807208612794057, 0.12956440856214613, 0.15157296118559316, 0.12336618412518874, 0.26099009381141514, 0.15873569558607414, 0.1368944824207574, 0.11294338793959469, 0.15877922996878624, 0.1010999504069332, 0.20760025712661445, 0.1266826194478199, 0.18805839557899162, 0.17019499005982652, 0.16096170817036182, 0.08489264742820524, 0.17090705106966197, 0.10877360153244808, 0.1293543362407945, 0.19033315242268145, 0.1322433538734913, 0.23135397001169622, 0.20821431011427194, 0.18631276034284383, 0.12036670523229986, 0.12554570857901126, 0.09514809673419222, 0.14195955125615, 0.1422148203710094, 0.21703534381231293, 0.12403736021951772, 0.17473227315349504, 0.1297404311480932, 0.09207960552885197, 0.09518068443867378, 0.14397221122635528, 0.1699239428853616, 0.39746039430610836, 0.10597732267342508], [0.0536272645695135, 0.03239265693991911, 0.03986124153016135, 0.03281565514043905, 0.07863911814638413, 0.02331710740691051, 0.03223470564989839, 0.0335965243721148, 0.005611431924990029, 0.06685022104647942, 0.015849697265366558, 0.03453734127106145, 0.012111291616747621, 0.04011869626992848, 0.04180489660939202, 0.051251479162601754, 0.0595412687107455, 0.04988202745153103, 0.03064533888391452, 0.06284999311901629, 0.025288477991125546, 0.04310897253162693, 0.04284500544599723, 0.0259229882794898, 0.10322690854081884, 0.06856844134745188, 0.05202301217650529, 0.04871993551205378, 0.03354793967446312, 0.017892764881253242, 0.0028351615992505685, 0.07524932152591646, 0.022210370407265145, 0.034380588549538516, 0.0054212143732002005, 0.038823492723167874, 0.018894792265200522, 0.04580510598316323, 0.05053240485722199, 0.009430249738215934, 0.07274038740433753, 0.0886362481105607, 0.02651859147590585, 0.05478826926264446, 0.09136359629337676, 0.05690174257324543, 0.04711714886070695, 0.013510608278011205, 0.039720311397104524, 0.014192499129421776, 0.08522731892298907, 0.02591579315776471, 0.09611707442672923, 0.044607146046473645, 0.05994419923808891, 0.02867789055017056, 0.06874547325423919, 0.013869818885723362, 0.10100146741024218, 0.06768449151422828, 0.08862495262292214, 0.09595141222234815, 0.05216851393925026, 0.07890408713137731, 0.10579977868474089, 0.11650607528281398, 0.04156596216489561, 0.07219821884064004, 0.05566669751715381, 0.07694406769587658, 0.02452140899549704, 0.04668988702178467, 0.04201589290460106, 0.047291119408328086, 0.06522164476336911, 0.0855127711838577, 0.029483415783033706, 0.03373027422640007, 0.11918000367586501, 0.6797327601816505, 3.149390467442572, 4.896406810730696, 9.795836359262466, 3.4923391649499536, 5.232385732233524, 1.1263461294583976, 4.208486024290323, 5.788388047367334, 2.7981518022716045, 9.270054772496223, 11.774088107049465, 11.241061259061098, 8.506221659481525, 16.801712326705456, 27.419045604765415, 6.142645413056016, 3.5587999736890197, 3.171941782347858, 1.6960237920284271, 6.645281966775656, 6.003116425126791, 3.3180294558405876, 1.9916969700716436, 0.1903947803657502, 0.07355771464062855, 0.09017847551149316, 0.07114599444321357, 0.028443852424970828, 0.06540615751873702, 0.013479448280122597, 0.048305045274901204, 0.059766488266177475, 0.11517163438838907, 0.023913361837912817, 0.024222171341534704, 0.1236243624589406, 0.02674369785381714, 0.03403796494239941, 0.03511137765599415, 0.044979214362683706, 0.027149409579578787, 0.10075579426484182, 0.09221285814419389, 0.04019194624561351, 0.06722967373207211, 0.02556692808866501, 0.05508954040124081, 0.029061842506052926, 0.031147514964686707, 0.028309820554568432, 0.0839456744142808, 0.009311414269177476, 0.04050148119858932, 0.06571464604348876, 0.06499773138784803, 0.0533705779525917, 0.052828591215074994, 0.06653424425167032, 0.042998017743229866, 0.029529905768868048, 0.027928263880312443, 0.028123573029006366, 0.04760399773658719, 0.052256321141612716, 0.04004723115940578, 0.0350976442132378, 0.07315694005228579, 0.05664894852088764, 0.04884715446678456, 0.07599514283356257, 0.018527839201851748, 0.08254874468548223, 0.005679061987393652, 0.031820394287933595, 0.05759446692536585, 0.006245174090508954, 0.04901449763565324, 0.010807412363647018, 0.03018966021045344, 0.0700020331714768, 0.047722570670885034, 0.06245948243304156, 0.04003112655482255, 0.053208440949674696, 0.030424939577642363, 0.034774594751070254, 0.0842431494675111, 0.051656862488016486, 0.0528085829137126, 0.02184027249313658, 0.04068470632773824, 0.06306160168605857, 0.06644981753197499, 0.06541329697938636, 0.08080869039986283, 0.02932573166617658, 0.01617858186364174, 0.03390542849956546, 0.07927576210931875, 0.01894832337711705, 0.04328405259002466, 0.05932292144279927, 0.02540259618399432, 0.006853223567304667, 0.03524841522448696, 0.07172977522714064, 0.06813812186010182, 0.09621592107578181, 0.050152896510553546, 0.12790149310603738, 0.0759618500887882, 0.0307083527877694, 0.06740082782926038, 0.07761265369481407, 0.02946746888483176, 0.06196378715685569, 0.04385218890092801, 0.01905806660943199, 0.0031368701411338407, 0.022944734810153022, 0.03340210394526366, 0.042022245688713156, 0.10248332109767944, 0.08443944010650739, 0.038501255912706256, 0.08626862632809207, 0.04072072646522429, 0.08327573770657182, 0.0027811687323264778, 0.00295246708446939, 0.026805500201589894, 0.08371009447728284, 0.025480317599431146, 0.066858592472272, 0.06689284258754924, 0.023848921155149583, 0.07263544030138291, 0.02415950810245704, 0.056293912493856624, 0.04279288070392795, 0.03656139691884164, 0.03360131864610594, 0.0760635020560585, 0.06903344881720841, 0.02400809884420596, 0.03550476787495427, 0.12097318831365556, 0.048683907953090966, 0.039565183978993446, 0.017256434475712012, 0.04623903972969856, 0.011478344476927305, 0.0895252000191249, 0.01438662826330983, 0.01443838378690998, 0.04026341877761297, 0.10183611637330614, 0.0745013405685313, 0.044449480483308434, 0.044558524241438136, 0.14809626649366692, 0.011659050942398608, 0.019453542263363488, 0.0720969527901616, 0.04608449118677527, 0.01853044599556597, 0.06476611451944336, 0.015795104882272426, 0.012466156022128416, 0.05100369831779972, 0.011374968871677993, 0.060508866008603945, 0.04759784533234779, 0.04242025206622202, 0.15357683412730694, 1.4695657999254763, 6.26072502695024, 15.840473156422377, 19.51440006494522, 7.340213852003217, 7.239651773124933, 2.817572085186839, 1.7352800793014467, 5.967402616515756, 11.735853608697653, 21.60315178334713, 28.595690466463566, 28.750585354864597, 24.343612231314182, 20.67527387291193, 26.6326018050313, 11.419952809810638, 1.941924390848726, 12.085968721657991, 4.649402964860201, 4.552454492077231, 13.61801516264677, 10.926687028259039, 4.832822922617197, 0.3278866322943941, 0.026367748105258215, 0.04255378669768106, 0.023921247156977188, 0.029007994126004633, 0.013545049496315187, 0.008209462266677292, 0.11268673100857995, 0.05796345903945621, 0.03942178620491177, 0.04649375223380048, 0.05024203586799558, 0.05506403649633285, 0.028024787607137114, 0.06795706009143032, 0.037029651284683496, 0.06300084947724827, 0.03548565015080385, 0.036756596600753255, 0.08831695391563699, 0.04681616715970449, 0.1151614892296493, 0.04903757100692019, 0.03675616986583918, 0.04964373125403654, 0.010909804623224773, 0.004164374759056955, 0.03972721708123572, 0.05907976046728436, 0.031462408223887905, 0.04769541548739653, 0.06233958847587928, 0.020472264259296935, 0.03215105818526354, 0.015878141930443235, 0.054188550857361406, 0.02132449470082065, 0.09295400392147712, 0.05645659868605435, 0.02260673663840862, 0.022738484549336135, 0.025710333284223452, 0.02826517666107975, 0.028478219428507145, 0.02176068828703137, 0.03224878790206276, 0.06491638458101079, 0.0162026255929959, 0.017064437161025126, 0.02054496875643963, 0.017082126250898, 0.0828610107419081, 0.032789820979814976, 0.056155757993110456, 0.043539948819670826, 0.0928659035707824, 0.03109461467829533, 0.02726693423028337, 0.11592644310439937, 0.037831048321095295, 0.08215921363444068, 0.02430975961033255, 0.011580590162338922, 0.013335244348127162, 0.017923857158166356, 0.04360085316875484, 0.044057559716748074, 0.06193889552378096, 0.029541572330344934, 0.0075896149610343855, 0.01893873111839639, 0.04555231564154383, 0.053855326550547034, 0.10869981721043587, 0.16661296976963058, 0.1815170020563528, 0.1712747704004869, 0.14599720569094643, 0.0883052428252995, 0.12393232405884191, 0.10757197538623586, 0.15402397810248658, 0.19341953680850565, 0.16208258864935488, 0.30762570386286825, 0.15105227037565783, 0.16895612294320017, 0.22136642859550193, 0.13318536191945896, 0.23886049690190703, 0.11142343239043839, 0.1258516960660927, 0.11696542758727446, 0.11206452181795612, 0.11600611265748739, 0.11965074052568525, 0.2082946995506063, 0.15507100004469976, 0.1928764776675962, 0.20358661859063432, 0.19994721544208005, 0.11553577656741254, 0.2356927137589082, 0.1045905974751804, 0.15880131628364325, 0.19851406890666112, 0.08128884510369971, 0.11742352566216141, 0.25039281870704144, 0.10533920183661394, 0.1374401242355816, 0.20246609434252605, 0.10796256028697826, 0.1605752867180854, 0.19286276277853176, 0.1942932078964077, 0.1608280770597048, 0.21126634790562093, 0.22272570175118744, 0.1274704240495339, 0.1574762858217582, 0.18676655396120623, 0.0788252339407336, 0.278522145235911, 0.11236438658670522, 0.1311396763776429, 0.08279944217065349, 0.1892650980153121, 0.0856564955029171, 0.18602822092361748, 0.10869995821849443, 0.17982606310397387, 0.16176597360754386, 0.20453619654290378, 0.15262733038980514, 0.1209850404120516, 0.1450808611116372, 0.3165868698852137, 0.14246241567889228, 0.13987775280838832, 0.24449056276353076, 0.1758331008022651, 0.20700723660411313, 0.12918972788611427, 0.09620435099350289, 0.07763352288748138, 0.09901270459522493, 0.15190192556474358, 0.1541621659998782, 0.11589752903091721, 0.08302023110445589, 0.25273809442296624, 0.6453918654005975, 7.4138980731368065, 25.175159610807896, 30.811716355383396, 16.336944065988064, 27.835147976875305, 26.909230761229992, 24.57358919084072, 20.87341234087944, 28.110027126967907, 46.36035092175007, 51.99404641985893, 54.85661141574383, 40.678660199046135, 33.42918120324612, 52.59466879069805, 27.336251847445965, 31.79438352584839, 47.0366158336401, 32.04331576824188, 18.601766936481, 25.556932725012302, 18.40851690620184, 4.505859017372131, 0.3321228706045076, 0.34705675207078457, 0.1520217230427079, 0.08126284024911001, 0.25994289375375956, 0.09494417681708, 0.10197992975008674, 0.26081289863213897, 0.09517797559965402, 0.19930601469241083, 0.12174535586382262, 0.09916516399243847, 0.21895818907069042, 0.10102633677888662, 0.14001212606672198, 0.07496813661418855, 0.2840075665153563, 0.09123910844209604, 0.1509080859250389, 0.3097177291056141, 0.13558524486143142, 0.1965120216482319, 0.14577824244042858, 0.19036040408536792, 0.21157840616069734, 0.13810016069328412, 0.13993654574733227, 0.13368273444939405, 0.10476969255250879, 0.1547358906827867, 0.09555712400469929, 0.13842299493262544, 0.09748416239744984, 0.18112079909769818, 0.16601324023213238, 0.13205058843595907, 0.08208552579162642, 0.16833898262120783, 0.10162411446799524, 0.08460641591227613, 0.16681455192156136, 0.16654133767588064, 0.16618209367152303, 0.15456630993867293, 0.3135269653284922, 0.11660489224595949, 0.12047833908582106, 0.10107560054166242, 0.15220460307318717, 0.15662761026760563, 0.11484926770208403, 0.25943784741684794, 0.14245503873098642, 0.12504612444899976, 0.16134977719048038, 0.2543424692703411, 0.18753337062662467, 0.16664693044731393, 0.2670141658745706, 0.13860350009053946, 0.1295520443818532, 0.08902766421670094, 0.12296402914216742, 0.21356286451919004, 0.32324408297427, 0.10157787866774015, 0.09659688774263486, 0.2343963153543882, 0.10560402981354855, 0.17321593186352402, 0.241997258272022, 0.1646629025344737, 0.11500443593831733], [0.00860187934449641, 0.012855784480052534, 0.024380434333579615, 0.04735756760055665, 0.013986117137392284, 0.061126755899749696, 0.02742190579738235, 0.015049756693770178, 0.04139883050811477, 0.07334488895139657, 0.06396334822056815, 0.024005048617254943, 0.04734997914056294, 0.12376187500194646, 0.020727234659716487, 0.013793274702038616, 0.039688959368504584, 0.06024135887855664, 0.05883194622583687, 0.058414128216099925, 0.049321201295242645, 0.032257975690299645, 0.035940475354436785, 0.054489053873112425, 0.05054049055615906, 0.052797550888499245, 0.03406158008147031, 0.04797244066139683, 0.0492335239687236, 0.016999864747049287, 0.03285543054516893, 0.01532566586320172, 0.06004658222082071, 0.06346535228658468, 0.02888035771320574, 0.06130201036285143, 0.012660687771131052, 0.039487514513893984, 0.04850296121730935, 0.01646762240852695, 0.009808142986003077, 0.043131236961926334, 0.02487276025931351, 0.055233038365258835, 0.015455434095201781, 0.02718121246289229, 0.0401241584768286, 0.017997370596276596, 0.042895000224234536, 0.07713433951721527, 0.04286680603399873, 0.03187822243489791, 0.03476882084214594, 0.07274084011442028, 0.032767074153525755, 0.03319746785564348, 0.06363620952470228, 0.03770522089325823, 0.10997421835782006, 0.023498015179939102, 0.025441699945076834, 0.054739510160288773, 0.04254773819411639, 0.040453798210364766, 0.02515984895580914, 0.09837042773142457, 0.09068360348464921, 0.052264306650613435, 0.03993770500528626, 0.08233478351030499, 0.03506208049657289, 0.08055345097091049, 0.046323644564836286, 0.07169435251853429, 0.07210544295958243, 0.049620880527072586, 0.0408133910241304, 0.06655894292634912, 0.04812527484318707, 0.2801349508808926, 1.2605627649463713, 3.3463647728785872, 5.241580288857222, 7.40874127484858, 2.0118673564866185, 4.484353121370077, 2.472039288841188, 3.671818021684885, 6.676913369446993, 3.99376287125051, 5.561091843992472, 2.6165882823988795, 10.526923779398203, 14.23004737123847, 9.252124484628439, 2.8681428590789437, 7.476564785465598, 1.3277158490382135, 2.7511497493833303, 7.954378221184015, 1.3652855018153787, 0.8741684455890208, 0.1865342172095552, 0.04715509858215228, 0.015584229186060838, 0.016105660288303625, 0.07339747753576376, 0.06983921339269727, 0.007856675874791108, 0.05348300590412691, 0.04267825970600825, 0.029574668405984994, 0.028575117939908523, 0.03175866244419012, 0.04196479232632555, 0.04219987502438016, 0.026477200044610072, 0.033380117820343, 0.034552792785689235, 0.04969750727468636, 0.01403937643772224, 0.0721560871170368, 0.014627713080699323, 0.010792464581754757, 0.06145356433989946, 0.04290716773539316, 0.07200989144621417, 0.050064692259184085, 0.010433697407279396, 0.04133303169510327, 0.05359344861062709, 0.055864891764940694, 0.03823455401288811, 0.01233507882716367, 0.10853545376448892, 0.02462687189108692, 0.02053567150142044, 0.010290404461557046, 0.006525677617901238, 0.03983720707765315, 0.04634371965948958, 0.016333514467987698, 0.16493340051965788, 0.014147170604701387, 0.028727261924359482, 0.02229801433713874, 0.02919666476373095, 0.008078835926426109, 0.022557682532351464, 0.05267704837024212, 0.03554235023329966, 0.01259522199688945, 0.07813059113686904, 0.07649670849787071, 0.018220317324448843, 0.02943449711892754, 0.03646135541202966, 0.050685910682659596, 0.015929301880532876, 0.029960460888105445, 0.027321851302986033, 0.0417597295017913, 0.014242234155972255, 0.037288393650669605, 0.012088316580047831, 0.06592802834347822, 0.039914319931995124, 0.05256036049104296, 0.01696964078291785, 0.015442158000951167, 0.042982696104445495, 0.030043021106394008, 0.028282279454288073, 0.09905570463160984, 0.02308580224053003, 0.06725472863763571, 0.0032805494674903457, 0.01583308428962482, 0.0063958648570405785, 0.05623810298857279, 0.051526930983527564, 0.056333435568376444, 0.015714105029474013, 0.038067908462835476, 0.015311310871766182, 0.027587503063841723, 0.039033706052578054, 0.02875857870094478, 0.061779081443091854, 0.08790279840468429, 0.05784461151051801, 0.03167308539559599, 0.01706962848402327, 0.06624775298405439, 0.07176162820542231, 0.036290843272581697, 0.05487682603416033, 0.07023775411653332, 0.044433357325033285, 0.05181211236049421, 0.07368933453108184, 0.018413765537843574, 0.0429650997830322, 0.03403842136322055, 0.08521059833583422, 0.006226208042789949, 0.023327818453253713, 0.0035822749396174913, 0.031104717163543683, 0.054337217879947275, 0.06851583792013116, 0.05755161531851627, 0.1074306556256488, 0.048084998488775454, 0.06595323167857714, 0.014652314348495565, 0.0012822064536521793, 0.12783113750629127, 0.01677480660873698, 0.020674890984082595, 0.03355839282448869, 0.015575800243823323, 0.029553151689469814, 0.06000358589517418, 0.03145789225527551, 0.04729088192107156, 0.0709093977638986, 0.041189815747202374, 0.07435533043462783, 0.05045545527536888, 0.05802251173008699, 0.04763959484989755, 0.10608165379380807, 0.027639178806566633, 0.09569243979058228, 0.07882183490437455, 0.010914537670032587, 0.0732755872013513, 0.06846330870757811, 0.053334327749325894, 0.06649869537795894, 0.051507560929167084, 0.08041626497288235, 0.005404047105912468, 0.046375847232411616, 0.012033485782012576, 0.042643816632335074, 0.03403146743949037, 0.031194990151561797, 0.0327497784019215, 0.06818507754360326, 0.052868218190269545, 0.024950836050265934, 0.03101335692917928, 0.067728419235209, 0.15881290863035247, 1.3486839551478624, 6.468080375343561, 12.882505729794502, 16.743742637336254, 6.333306832239032, 5.2120815217494965, 9.198362119495869, 8.819180466234684, 8.1868383474648, 6.637910362333059, 15.10983221232891, 15.206648167222738, 25.5184293910861, 26.580383107066154, 10.631190184503794, 6.738360347226262, 11.832616366446018, 4.832754526287317, 1.6220614733174443, 9.133394155651331, 8.1943847425282, 3.0262507125735283, 0.40672955161426216, 0.05720126966480166, 0.04559942346531898, 0.07030146007309668, 0.0957218288385775, 0.02635278826346621, 0.04897954248008318, 0.0681399401219096, 0.022189033661561552, 0.05050690095231403, 0.02871551001589978, 0.03066348253923934, 0.03783269217819907, 0.026062569559144322, 0.05202427753829397, 0.012273960182938026, 0.03439326443185564, 0.0644546870898921, 0.0186774617395713, 0.02111867488565622, 0.03804705040238332, 0.04948686349962372, 0.01807819789974019, 0.06441341625759378, 0.08334290207130834, 0.03227304870961234, 0.11255352292209864, 0.04666537388402503, 0.0833852267533075, 0.0848309304274153, 0.02558258369390387, 0.03651635597634595, 0.05134471517521888, 0.01631261002330575, 0.01791200877050869, 0.01784180902177468, 0.08599103341111913, 0.06696947675663978, 0.041657750989543274, 0.021288086791173555, 0.06706865737214684, 0.022961618669796735, 0.04745297810586635, 0.07028247593552805, 0.04468782863114029, 0.05389001082221512, 0.043623466408462264, 0.0019793630508502247, 0.0340763228450669, 0.04224533156957477, 0.027942828528466634, 0.04973583549144678, 0.018779633210215252, 0.03717562802194152, 0.08183539233868942, 0.02900216084526619, 0.043159149136045016, 0.0646307690476533, 0.023024897891446017, 0.07477334511349909, 0.039785345798009075, 0.0351948247407563, 0.037010841551818885, 0.05397505723522045, 0.0703053934557829, 0.06246058823307976, 0.011721696555468952, 0.044254325330257416, 0.026065708843816537, 0.060704536954290234, 0.09782045177416876, 0.008927031867642654, 0.049470766316517256, 0.07865366424084641, 0.12789554108167067, 0.09782948371139355, 0.10702912404667586, 0.19559728010790423, 0.09821860658121295, 0.17134683293988928, 0.11139129739603959, 0.08851257662172429, 0.1204980282636825, 0.22858118754811585, 0.17467287165345624, 0.0677050490048714, 0.1555946297594346, 0.3612663864623755, 0.232750320865307, 0.11485108596389182, 0.1650701486505568, 0.14052011130843312, 0.17838211089838296, 0.20050323248142377, 0.15625092579284683, 0.2294829415041022, 0.19773141480982304, 0.10876140062464401, 0.2670410613063723, 0.13784545561065897, 0.11260856059379876, 0.13796295243082568, 0.21138163312571123, 0.21132137073436752, 0.07959156821016222, 0.08167350766598247, 0.21149724489077926, 0.1472006575204432, 0.1346571446629241, 0.15818062849575654, 0.15671640081563964, 0.14433378557441756, 0.15403230499941856, 0.12452463211957365, 0.11212301789782941, 0.1810243644285947, 0.08385548120713793, 0.24486614885972813, 0.11133562147733755, 0.10415905344416387, 0.22923748358152807, 0.1751457087812014, 0.09866390260867774, 0.12270691207959317, 0.40326030808500946, 0.17573090706719086, 0.2785821701399982, 0.2887791901594028, 0.1790467041428201, 0.1374478722573258, 0.18034872802672908, 0.1541203385568224, 0.19058301870245486, 0.12327516713412479, 0.08378761180210859, 0.22255597257753834, 0.19661396305309609, 0.13165658223442733, 0.11638612195383757, 0.19063735875533894, 0.12724849220830947, 0.13840320927556604, 0.1960778355714865, 0.12925416114740074, 0.20662851864472032, 0.20555581839289516, 0.1356443643453531, 0.1648160076001659, 0.165099982987158, 0.18606948433443904, 0.15009749738965183, 0.09374853980261832, 0.10611643083393574, 0.31313258805312216, 0.9690681751817465, 8.443805258721113, 20.942813716828823, 22.974065020680428, 11.673553101718426, 27.384524457156658, 40.284150168299675, 39.67574581503868, 32.413028329610825, 25.904779359698296, 33.47903452813625, 26.42663385719061, 38.50525662302971, 50.55469885468483, 36.00276030600071, 27.00936108827591, 47.42213934659958, 31.816802322864532, 25.47074005007744, 22.11944717913866, 18.04361678659916, 4.030408104881644, 0.42232943640556186, 0.25749350956175476, 0.13836369733326137, 0.10709191716159694, 0.2044888326781802, 0.12676035199547186, 0.13827063201460987, 0.09855436161160469, 0.11089601772255264, 0.1152659984654747, 0.1068724863580428, 0.12227616956806742, 0.184853742539417, 0.11219251260627061, 0.21614826953737065, 0.1563942345092073, 0.11014353935024701, 0.14484463550616056, 0.12210857035825029, 0.12656700768275186, 0.07685951481107622, 0.10536345522268675, 0.11832913136458956, 0.204622152086813, 0.20724111702293158, 0.1132675283588469, 0.19105594488792121, 0.15660996199585497, 0.25849867437500507, 0.10080662395921536, 0.20255757146514952, 0.16129919240484014, 0.2575630636420101, 0.1196961896494031, 0.0899028789717704, 0.12216371193062514, 0.18758937309030443, 0.18474601238267496, 0.12613213883014396, 0.06215365821844898, 0.20698197389720008, 0.17169982806080952, 0.14022969407960773, 0.23845308751333505, 0.11324020248139277, 0.2698597084963694, 0.08201727046980523, 0.14035403350135311, 0.14690704905660823, 0.1269838571897708, 0.20503851177636534, 0.19529740791767836, 0.07203178480267525, 0.27083441556897014, 0.28451840160414577, 0.18916306755272672, 0.16248368978267536, 0.20124267874052748, 0.13153864012565464, 0.16357859509298578, 0.09149401390459388, 0.07377106725471094, 0.10777009912999347, 0.1724136553821154, 0.15171019913395867, 0.13877354096621275, 0.10077139420900494, 0.1655326847685501, 0.12850462167989463, 0.11773123493185267, 0.26227332651615143, 0.20115212188102305, 0.12625514238607138, 0.14976795413531363], [0.014358852458826732, 0.031308115721913055, 0.03917289956007153, 0.02154340600100113, 0.03229179164918605, 0.06340825144434348, 0.03542376616678666, 0.02876523205486592, 0.051993203815072775, 0.13829911564243957, 0.07282840611878783, 0.036381363024702296, 0.051302112187840976, 0.07505683810450137, 0.022343522832670715, 0.05013525194954127, 0.07018814896582626, 0.022496854253404308, 0.04010002012364566, 0.06813179876189679, 0.03370566089870408, 0.022041604170226492, 0.03932369283575099, 0.03651773637102451, 0.0322248313750606, 0.061728886284981854, 0.02261223224195419, 0.029893420833104756, 0.017137766917585395, 0.01983878741157241, 0.04964363106410019, 0.03437624698563013, 0.03515073374728672, 0.022888116363901645, 0.018628355683176778, 0.032104718484333716, 0.06044332323654089, 0.11641708435490727, 0.03579447635274846, 0.01993061334360391, 0.025214780871465337, 0.03485504355921876, 0.038226627875701524, 0.0524811622017296, 0.026157547763432376, 0.05475385958561674, 0.07820223065209575, 0.02775251959974412, 0.0394126837636577, 0.03841813166218344, 0.027445446721685585, 0.03291247572633438, 0.03634597742347978, 0.01338672156634857, 0.04436499439179897, 0.025310061500931624, 0.03688178207085002, 0.05987126838590484, 0.04666071690735407, 0.015160803322942229, 0.1360234385356307, 0.04528195124294143, 0.04830228819628246, 0.0276521997875534, 0.09622424055123702, 0.039842082987888716, 0.0374026175995823, 0.04585766488162335, 0.04576277016894892, 0.03713275415066164, 0.06594289356144145, 0.07827010005712509, 0.06698475757730193, 0.08099989732727408, 0.04132554342504591, 0.0795601679419633, 0.03505257729557343, 0.05950925617071334, 0.04692095099017024, 0.12799221323803067, 0.03449918745900504, 0.5830446328036487, 1.1365491757169366, 8.390467520803213, 4.942714450880885, 1.8246538960374892, 3.7490678764879704, 1.7708599450998008, 3.8534007780253887, 5.80639005638659, 8.755735270678997, 7.0383884478360415, 12.042108625173569, 4.03523194603622, 1.6486074426211417, 0.7082324184011668, 3.42338640242815, 4.5577609073370695, 3.9476114977151155, 3.155985726043582, 2.0148304849863052, 0.0463113583100494, 0.05730042059440166, 0.10291528073139489, 0.006429970253520878, 0.03802612183790188, 0.03398764361918438, 0.03614844368712511, 0.06633314449572936, 0.10271390638081357, 0.021582981025858317, 0.02924266864283709, 0.06809357815654948, 0.02511985832825303, 0.0732533227710519, 0.08373776916414499, 0.007367683583652251, 0.04601404281856958, 0.05926770936639514, 0.016800117555249017, 0.04201090938295238, 0.07293923103134148, 0.03154997051751707, 0.0734960644331295, 0.05388123121520039, 0.05391297287133057, 0.07733421472948976, 0.07541210419731215, 0.024739971486269496, 0.017566798778716475, 0.02983804177347338, 0.1118232867156621, 0.026645828984328546, 0.03223056817660108, 0.031020396199892275, 0.015872568401391618, 0.0624752530711703, 0.04040975916723255, 0.025295578489021864, 0.04703778358816635, 0.03453976067248732, 0.08251698818639852, 0.05971100901660975, 0.028963138720428105, 0.044829671605839394, 0.0327344864490442, 0.01891983047244139, 0.019209483289159834, 0.027997420911560766, 0.05499849001353141, 0.04075339209521189, 0.03641693416284397, 0.06137435862910934, 0.04124199243960902, 0.006791157293264405, 0.012929102176713059, 0.10050190554466099, 0.0285558684845455, 0.04280585715605412, 0.02878350373066496, 0.01947192711668322, 0.03002053217642242, 0.045569158683065325, 0.051929880064562894, 0.05267826549243182, 0.059781015806947835, 0.026671794876165222, 0.0762678227329161, 0.012951159733347595, 0.0728345214156434, 0.011436466938903322, 0.045699338807025924, 0.03466044130618684, 0.13671308668563142, 0.02562792149547022, 0.043859558427357115, 0.02412684803857701, 0.006875369717818103, 0.046119064136291854, 0.02011340988246957, 0.09916149036143906, 0.041371051920577884, 0.0014971450605116843, 0.03897740301908925, 0.08919170853914693, 0.09111784893320873, 0.08229754996136762, 0.07380147304502316, 0.05660386676026974, 0.05487177200848237, 0.05274754868878517, 0.02942932434962131, 0.02978432698000688, 0.01886347177787684, 0.04253894745488651, 0.080752880894579, 0.07810984810930677, 0.053350658708950505, 0.014663721158285625, 0.06767001963453367, 0.09524381894152611, 0.10476290932274424, 0.029236946684250142, 0.03830280191323254, 0.08724708866793662, 0.0032406608852397767, 0.04739708696433809, 0.025723426624608692, 0.012331638044997817, 0.05025605503760744, 0.01340868078841595, 0.08623196423286572, 0.07042786266538315, 0.02819405108311912, 0.03627873142249882, 0.053923218220006675, 0.05172675795620307, 0.06938449208973907, 0.10859420217457227, 0.03532759867084678, 0.002264628383272793, 0.015651367575628683, 0.09464608578127809, 0.07725841918727383, 0.02158254872483667, 0.05882574929273687, 0.0389750467002159, 0.050825326834456064, 0.02982407640956808, 0.10273115389281884, 0.052850677529932, 0.05350168947188649, 0.033084357128245756, 0.024372951629629824, 0.033272580621996894, 0.08245204284321517, 0.043179884742130525, 0.06302194131421857, 0.02724193127505714, 0.030020526610314846, 0.09289997557061724, 0.10203505647950806, 0.010657799102773424, 0.044369425013428554, 0.04100821963220369, 0.05153545454959385, 0.03211746858141851, 0.0503492390998872, 0.035359229004825465, 0.04146487422985956, 0.029444881620293017, 0.08910815013223328, 0.01965618197573349, 0.02416926363366656, 0.05944179865764454, 0.24338880000868812, 0.07995180669240654, 0.9438490471802652, 3.488217811100185, 14.202417153865099, 8.690660912543535, 3.457627077586949, 4.116568956524134, 7.02806725166738, 11.797915678471327, 11.832015048712492, 8.340337760746479, 10.514841377735138, 14.697121158242226, 10.94467906281352, 9.446252267807722, 12.387815974652767, 4.487239541485906, 0.13925117236794904, 4.842325737699866, 7.003725282847881, 3.099074517376721, 0.1251176674850285, 0.04708011940238066, 0.08870599514921196, 0.013462989300023764, 0.06430490684579127, 0.08063080502324738, 0.045728145269094966, 0.035089432349195704, 0.052916532004019246, 0.009311615576734766, 0.031937353051034734, 0.002496684742254729, 0.08107813453534618, 0.008932507989811711, 0.03898922914231662, 0.024219024635385722, 0.026890605986409355, 0.058044182442245074, 0.023796011591912247, 0.04351338364358526, 0.02060755592538044, 0.04998994314519223, 0.04078294812643435, 0.0418135982909007, 0.04698721364547964, 0.07292570910067298, 0.017476379216532223, 0.02030606770858867, 0.04112639551749453, 0.04704727936768904, 0.053237985848682, 0.04670898248150479, 0.020554559159791097, 0.03765519642911386, 0.05338318704161793, 0.05201038082304876, 0.058152665878878906, 0.06525121934828348, 0.06324923146166839, 0.013721282666665502, 0.003976198577220202, 0.09364576719235629, 0.026630049069353845, 0.04159850905125495, 0.038451736108982004, 0.01911955354444217, 0.06397569013643079, 0.026177435465797316, 0.07708132790867239, 0.08127222099574283, 0.04111541173188016, 0.08386302884900942, 0.03162525397783611, 0.0060758795370929874, 0.02690331526537193, 0.05023029509175103, 0.04650438349926844, 0.07317496681935154, 0.019432563603913877, 0.08489564570481889, 0.020941910152032506, 0.03410348545003217, 0.04754531240905635, 0.09976518296753056, 0.036237468011677265, 0.04839335713768378, 0.14449215988861397, 0.07151212557801045, 0.011535486137290718, 0.009257399833586533, 0.05563553102547303, 0.06973330149776302, 0.055240875444724225, 0.09048839638126083, 0.08454938186332583, 0.1258190267253667, 0.11535778729012236, 0.1626914762891829, 0.10891467638430186, 0.25995960691943765, 0.10854058200493455, 0.14046774536836892, 0.13524670677725226, 0.16909624042455107, 0.3362751571694389, 0.19795091240666807, 0.1332594282575883, 0.2004198744543828, 0.17704538418911397, 0.15584960201522335, 0.12512688495917246, 0.19467413745587692, 0.11992813306278549, 0.13625921885250136, 0.10157132550375536, 0.312611066037789, 0.1627386175096035, 0.13511613331502303, 0.15901342208962888, 0.33610909420531243, 0.1750738243572414, 0.23912063450552523, 0.1349967811256647, 0.16575201909290627, 0.07731982448603958, 0.16922602721024305, 0.09301716811023653, 0.06601150511414744, 0.12973490956937894, 0.14600634895032272, 0.18233106384286657, 0.1175491489993874, 0.20106536481762305, 0.16845514357555658, 0.1925020047929138, 0.12105305824661627, 0.16383601643610746, 0.15344786370405927, 0.16798422118881717, 0.0992157487780787, 0.16511709691258147, 0.2469760153326206, 0.17624567553866655, 0.06800211587687954, 0.22693817649269477, 0.10398672675364651, 0.10674300385289825, 0.1152372031356208, 0.17446423909859732, 0.14792074856813997, 0.11423284726333804, 0.18351222155615687, 0.15168092882959172, 0.1851824694313109, 0.11489234937471338, 0.16724367655115202, 0.14859132352285087, 0.19422270386712626, 0.18713019147980958, 0.1939054357353598, 0.13802992383716628, 0.09424751537153497, 0.19625859305961058, 0.1309590376331471, 0.13278988626552746, 0.09451226913370192, 0.1282746746437624, 0.12810758751584217, 0.09614300506655127, 0.1140808108903002, 0.20826649793889374, 0.11752635764423758, 0.28809202078264207, 0.14946107607102022, 0.28457946551498026, 0.13823429646436125, 0.5362569121643901, 4.239997258409858, 22.32592809945345, 14.875066559761763, 17.294585779309273, 32.17882789671421, 52.957917898893356, 47.46125064790249, 41.7121097445488, 33.3269476890564, 39.54895041882992, 50.45943796634674, 31.126358471810818, 22.155254557728767, 57.75243982672691, 38.002266213297844, 20.54308846592903, 16.49131268262863, 14.026494193822145, 4.950595702975988, 0.34293032193090767, 0.2727809501811862, 0.21062330662971362, 0.05843628503498621, 0.07967159399413504, 0.16377336432924494, 0.1551474115694873, 0.18282407254446298, 0.12617395143024623, 0.1286068302579224, 0.07515109828091227, 0.10832462445250712, 0.17887316033011302, 0.10604301016428508, 0.19739945215405896, 0.14948363736039028, 0.18590080901049078, 0.13409045553999022, 0.10906021154369228, 0.17513482889626175, 0.13810033880872652, 0.14416175574297085, 0.174912748625502, 0.18015771405771375, 0.16077747743111104, 0.15783855778863654, 0.10324492046493106, 0.10463823593454435, 0.12400665757013485, 0.11559128921362571, 0.20476982463151217, 0.1613486639689654, 0.17148234910564497, 0.1252159575233236, 0.16141354251885787, 0.23320522770518437, 0.17496406071586534, 0.10207936269580387, 0.1423015329055488, 0.15481723006814718, 0.3398849337827414, 0.1674837019527331, 0.13841895764926448, 0.12382554385112599, 0.120918069005711, 0.08834865104290657, 0.1460975588997826, 0.2220045420108363, 0.17013827513437718, 0.14236274524591863, 0.13200865709222853, 0.19478985312161967, 0.13996489578858018, 0.12451529590180144, 0.16923482908168808, 0.17837903840700164, 0.15230462973704562, 0.1666273971204646, 0.11550292911124416, 0.21098633558722213, 0.14757815835764632, 0.1405430436716415, 0.10757734853541479, 0.1685823773732409, 0.14465314656263217, 0.1358118819189258, 0.22157725790748373, 0.1635392612661235, 0.1227044926781673, 0.07020449847914279, 0.17038955149473622, 0.13994371489388868, 0.214769552112557, 0.23950583883561194, 0.11623519138083793], [0.136944770347327, 0.0506088683323469, 0.03823746694251895, 0.048479453689651564, 0.044547106299432926, 0.05093973260954954, 0.017264811467612162, 0.12863172189099714, 0.09556074568536133, 0.08866439035045914, 0.04878223509876989, 0.02533547634811839, 0.019327488480485044, 0.027757710922742262, 0.02820907215209445, 0.05167131581401918, 0.026377017529739533, 0.02730119176703738, 0.017284153691434767, 0.052851876098429784, 0.06214861532498617, 0.07087546677212231, 0.030249640585680027, 0.031803235833649524, 0.05879358832316939, 0.047945396800059825, 0.0389794290822465, 0.044234150045667775, 0.020392999176692683, 0.06905880058184266, 0.08224554025218822, 0.039346844132523984, 0.035021922885789536, 0.020492346775426995, 0.07026640101685189, 0.04225449338264298, 0.08764902100665495, 0.07201815897133201, 0.025717116513988003, 0.018978538064402528, 0.08565356401959434, 0.10676613659597933, 0.027863275863637682, 0.043873503382201307, 0.014913584655005252, 0.025828295802057255, 0.029118757811374962, 0.04451881562999915, 0.06102891486079898, 0.07127696124371141, 0.005569242221099557, 0.01913611271447735, 0.06793213877244852, 0.06301380737568252, 0.07406361444736831, 0.08252110710600391, 0.0578832774044713, 0.08158363358234055, 0.02524456511309836, 0.12741875572828576, 0.06332924982416444, 0.058925315825035796, 0.07274461022461765, 0.05713921127608046, 0.07552597191534005, 0.028870060414192267, 0.015842144057387486, 0.03264738799771294, 0.040352602663915604, 0.022223443338589277, 0.04487417078053113, 0.02212513289123308, 0.018842396639229264, 0.0816387083614245, 0.025496659691270906, 0.06011668920109514, 0.025028368218045216, 0.10231486841803417, 0.0042891687462542905, 0.0394267585943453, 0.07398813060717657, 0.08051672950387001, 0.10109828057466075, 0.6289626751095057, 3.3878203108906746, 3.695204104296863, 5.6308546755462885, 1.4701423002406955, 4.381876895204186, 0.04160259457421489, 4.912984846159816, 5.8838707488030195, 5.5043509136885405, 1.5336754848249257, 3.338250545784831, 8.02634160965681, 4.667328977957368, 4.872902221977711, 5.19663630053401, 1.3757286476902664, 0.10505870712222531, 0.09156858490314335, 0.03712213772814721, 0.03535754432959948, 0.022030416294001043, 0.045215072605060413, 0.025323084337287582, 0.10312625847291201, 0.13745493750320747, 0.01778034620656399, 0.09027696592966095, 0.025845187083177734, 0.10422365739941597, 0.003598450743993453, 0.043776278325822204, 0.03065998331294395, 0.09003740808111615, 0.01777511406544363, 0.047234211524482816, 0.06058906248654239, 0.04526977631030604, 0.017994361187447794, 0.058792964919121005, 0.009133392522926442, 0.034994986635865644, 0.05134022518177517, 0.09139244357356802, 0.06868953758385032, 0.011368965824658517, 0.07120446825865656, 0.04697893498814665, 0.03321968033560552, 0.011195125152880792, 0.04066979658091441, 0.019926822824345436, 0.04521532864600886, 0.07263308027177118, 0.026688756661314983, 0.02493178326403722, 0.050042728398693725, 0.025628678486100398, 0.02694101451197639, 0.05853040420333855, 0.04932507530611474, 0.00782887780587771, 0.03884216886945069, 0.012419961039995542, 0.06147945787233766, 0.06316429266007617, 0.024757083556323778, 0.01636541011976078, 0.009942557990143541, 0.025789908213482704, 0.01999235446419334, 0.02032781263551442, 0.03334175249619875, 0.05774407647550106, 0.022426869727496523, 0.007151149939090828, 0.007026000184851, 0.01600804003828671, 0.025804817960306536, 0.045438793022185564, 0.008948103295551846, 0.02254165770864347, 0.04427637453773059, 0.03692370970384218, 0.0299147019177326, 0.0392712601023959, 0.0147649361861113, 0.030422650052059907, 0.07085278673912399, 0.07719481713138521, 0.018098606960847974, 0.04772362080984749, 0.08634125289972872, 0.05213323594944086, 0.015958473850332666, 0.050559389346744865, 0.007587481286464026, 0.04426106774189975, 0.02005108803132316, 0.019778599234996364, 0.06748152896761894, 0.019976214607595466, 0.08591060686740093, 0.08429971596342511, 0.053684213271480985, 0.10289997764630243, 0.042369259099359624, 0.031088139439816587, 0.0166528995760018, 0.03303529374534264, 0.026459015571163036, 0.042350349176558666, 0.04630462331988383, 0.057633592950878665, 0.047481075816904195, 0.09186865747324191, 0.07055199428577907, 0.06263616553042084, 0.044156721778563224, 0.03807653221883811, 0.030764982366235927, 0.013632496757054469, 0.03250458394177258, 0.05725138689740561, 0.01562968573125545, 0.033131646778201684, 0.01790493795851944, 0.05070114697446115, 0.047560292659909464, 0.08134467687341385, 0.03394799437955953, 0.022352450869220775, 0.008726594478503102, 0.023869821889093146, 0.04598671323037706, 0.04045737907290459, 0.04158020397881046, 0.026097610061697196, 0.03766382760659326, 0.027561791357584298, 0.08098180376691744, 0.03874160043778829, 0.0948886493279133, 0.043559519253904, 0.03878514966345392, 0.06140466051874682, 0.05537420598557219, 0.008383604435948655, 0.08006370771909133, 0.08086009896942414, 0.05639691145916004, 0.01193965234051575, 0.04531040518486407, 0.052562779892468825, 0.10287714176229201, 0.07685843127546832, 0.05251682610833086, 0.11640686498139985, 0.03602086479077116, 0.05921382944507059, 0.021387102278822567, 0.04148228501435369, 0.04149970322032459, 0.10094162804307416, 0.023598381376359612, 0.04124364742892794, 0.061750942913931794, 0.018375120052951388, 0.07941678501083516, 0.04229351179674268, 0.040852131132851355, 0.0237659008053015, 0.02365159150940599, 0.031473607232328504, 0.05557826691074297, 0.07825284512364306, 1.0523346508853137, 3.8394674006849527, 3.496036841534078, 7.109259869903326, 3.783608260564506, 8.455402236431837, 8.593862056732178, 14.382942616939545, 9.557957723736763, 13.349696360528469, 9.375214129686356, 9.037674441933632, 10.129130724817514, 13.779943473637104, 13.064198680222034, 6.334744580090046, 1.5941258473321795, 0.02321289874089416, 0.05720728477172088, 0.0784594813012518, 0.03523772829794325, 0.0447748268925352, 0.04758283910632599, 0.03809287059993949, 0.05256265743810218, 0.07492050557630137, 0.08618428124464117, 0.034771143764373846, 0.005762247928942088, 0.0521100549667608, 0.03981233399827033, 0.024643332726554945, 0.034683755875448696, 0.028154830433777533, 0.034973471774719656, 0.05147103613126092, 0.06803119322285056, 0.008212757402361603, 0.05852930211403873, 0.046135165030136704, 0.07406097982311621, 0.054406497365562245, 0.01100691557439859, 0.02453294197039213, 0.013102891825838014, 0.0868081083172001, 0.0244572354858974, 0.04054574659676291, 0.018282219862157945, 0.013795250670227688, 0.07712486229138449, 0.02273956994031323, 0.03131708457658533, 0.02543782778957393, 0.025727495449245907, 0.03092528997513, 0.05757431390520651, 0.003173150726070162, 0.04171753840637393, 0.10287919751135632, 0.04281395027646795, 0.024723636815906502, 0.011681551004585344, 0.06263053262955509, 0.03294983172963839, 0.06587552139535546, 0.00714505226824258, 0.061676282857661135, 0.07079483242705464, 0.061915332335047424, 0.030103159188001882, 0.04636654441128485, 0.055514022897114046, 0.0592597943614237, 0.09977375477319583, 0.035097822328680195, 0.06136747892014682, 0.029255036533868406, 0.02069224796287017, 0.07461020621121861, 0.18627627636305988, 0.013410666961135576, 0.015638250115443952, 0.06645868619671091, 0.04757246388180647, 0.04500713024754077, 0.06404618674423546, 0.023681858147028834, 0.05088321435323451, 0.009274860713048838, 0.024047705410339404, 0.12297251189011149, 0.03558277872798499, 0.33804722770582885, 0.14739038015250117, 0.15170292608672753, 0.13816898746881634, 0.18377558008069173, 0.14792209927691147, 0.08171049630618654, 0.22645592893240973, 0.10765030165202916, 0.2737360348692164, 0.19313576922286302, 0.12883226503618062, 0.29449826921336353, 0.2709609072189778, 0.12965398578671739, 0.1415740352240391, 0.13272196491016075, 0.1424270894494839, 0.17483783623902127, 0.1216360078251455, 0.21079107653349638, 0.20557515876134858, 0.18959835200803354, 0.19255444494774565, 0.3039007756160572, 0.11379115807358176, 0.11141907598357648, 0.1528408017475158, 0.12318222055910155, 0.1323681979556568, 0.18837275449186563, 0.10849261700059287, 0.16739354585297406, 0.2365690268925391, 0.20356720400741324, 0.11539084996911697, 0.2132691373117268, 0.19002766959602013, 0.1463127668830566, 0.09083601835300215, 0.1650936747319065, 0.13271233183331788, 0.1290027512004599, 0.09005783198517747, 0.18112945253960788, 0.09800926898606122, 0.13665095408214256, 0.20973173493985087, 0.12966577109182253, 0.26664021250326186, 0.09917897536070086, 0.20710661017801613, 0.24387014214880764, 0.14943521964596584, 0.16565625235671178, 0.1744896057061851, 0.1330750045599416, 0.24783778237178922, 0.15951012668665498, 0.18762363062705845, 0.14641343179391697, 0.2715351217193529, 0.18592684355098754, 0.13413486565696076, 0.16486402455484495, 0.09908263717079535, 0.1331874547759071, 0.16445584333268926, 0.1345629958086647, 0.19976497365860268, 0.15824086120119318, 0.14783782098675147, 0.16100493085104972, 0.13135832792613655, 0.11773336489568464, 0.1444993884069845, 0.1667077123420313, 0.2525242668343708, 0.15855714969802648, 0.18321551091503352, 0.09547914654831402, 0.27142157312482595, 0.1669875910738483, 2.148963762447238, 7.941300747916102, 9.57628034055233, 24.477127566933632, 30.206197947263718, 51.104586347937584, 61.255183070898056, 65.73441311717033, 63.9320482313633, 61.702935844659805, 41.72359652817249, 44.63542588055134, 42.098093032836914, 24.18111965060234, 22.049236446619034, 10.600930508226156, 3.100966103374958, 0.30744358082301915, 0.25463169906288385, 0.21286245522787794, 0.1455904493923299, 0.1000749331433326, 0.13141005561919883, 0.07707106400630437, 0.20440044288989156, 0.28743207338266075, 0.17398018069798127, 0.11310874586342834, 0.11134523228975013, 0.15708006802015007, 0.09090489707887173, 0.15883082407526672, 0.10384823457570747, 0.15236302191624418, 0.11474820945295505, 0.16189012007089332, 0.18871991633204743, 0.09431638667592779, 0.175103168876376, 0.28176714142318815, 0.14075546117965132, 0.1493484922684729, 0.1182693884766195, 0.12572864798130468, 0.11890622539795004, 0.2474085389985703, 0.19951711117755622, 0.16231449495535344, 0.15601915307343006, 0.20425228052772582, 0.14062938513234258, 0.16280916606774554, 0.15128748666029423, 0.14614232524763793, 0.07067928745527752, 0.07911489417892881, 0.16073308215709403, 0.1119921104691457, 0.13336660922504961, 0.2875931194284931, 0.11148188394145109, 0.13243993395008147, 0.11541382686118595, 0.1445849283481948, 0.1884643652010709, 0.15482781309401616, 0.07894488298916258, 0.2222206851001829, 0.13076601986540481, 0.15230452583637089, 0.08745275263208896, 0.12424401866155677, 0.20869177824351937, 0.12524951744126156, 0.14110452291788533, 0.1417452041641809, 0.16771085851360112, 0.13520844164304435, 0.12116230238461867, 0.17221667454577982, 0.25484825775492936, 0.09925782855134457, 0.11936026392504573, 0.18405067938147113, 0.16956219042185694, 0.1285926255513914, 0.11500779044581577, 0.13119193841703236, 0.16840365336975083, 0.131710744171869, 0.10448536835610867, 0.2753165422473103, 0.2225352666573599], [0.06948506794287823, 0.047359512027469464, 0.07723666683887132, 0.08196268550818786, 0.009458799231651938, 0.00997288121652673, 0.010363078345108079, 0.030284961248980835, 0.03908878825313877, 0.030660460142826196, 0.044435457602958195, 0.030180587455106433, 0.052781635531573556, 0.016952981422946323, 0.01244858010977623, 0.019707482933881693, 0.03518850906402804, 0.02487715562892845, 0.052737347868969664, 0.0218324112938717, 0.06748659783625044, 0.031058700296853203, 0.0922473605896812, 0.04467399870918598, 0.05576105788350105, 0.0435738612577552, 0.08553899126127362, 0.018011809079325758, 0.023949821697897278, 0.02701529421756277, 0.052346518059493974, 0.03033224718819838, 0.08056830876739696, 0.05716537569242064, 0.024757927749305964, 0.046674880795762874, 0.06822090101195499, 0.023451094748452306, 0.006771509861209779, 0.029038158718321938, 0.06622702479944564, 0.07289780434803106, 0.07224157510790974, 0.0803759292466566, 0.028429055855667684, 0.05669901380315423, 0.01745507586747408, 0.03279265969467815, 0.051951190835097805, 0.03147466108202934, 0.057355536191607825, 0.04655208504118491, 0.05956130669801496, 0.04735204973258078, 0.09498283528955653, 0.02324356057215482, 0.018319386617804412, 0.007098713031155057, 0.037112745849299245, 0.02763601725746412, 0.016628933772153687, 0.024024149643082637, 0.051059021716355346, 0.03043307166080922, 0.04897259597782977, 0.04434251844941173, 0.07095213062711991, 0.03156132166623138, 0.07361391006270424, 0.03139056090731174, 0.04049260140163824, 0.06962567524169572, 0.045289472909644246, 0.03918174596037716, 0.02123740552633535, 0.019980827055405825, 0.02173953893361613, 0.025907111885317136, 0.054037412483012304, 0.07244325373903848, 0.04881625143752899, 0.03442226385232061, 0.037273728812579066, 0.11977347690844908, 0.14727490197401494, 2.1760862320661545, 2.8236669581383467, 8.72523620724678, 3.060328708961606, 4.423917839303613, 1.1678450088948011, 4.9263515789061785, 3.1783643877133727, 8.043836820870638, 4.036032278090715, 5.232538199052215, 9.948363974690437, 3.9055738784372807, 0.682629095390439, 0.04567394622426946, 0.03432797770074103, 0.022417542786570266, 0.07310214728931896, 0.028580309262906667, 0.039256257587112486, 0.03941516995837446, 0.05611023836536333, 0.10249567043501884, 0.030446209530055057, 0.04749690582684707, 0.01439813247998245, 0.012757060285366606, 0.08391362105612643, 0.03496606514090672, 0.043484280322445557, 0.04580058630381245, 0.020376955799292773, 0.07713009443250485, 0.025198292205459438, 0.019792449566011783, 0.10302715207217261, 0.08663499495014548, 0.09138391629676335, 0.09931551569025032, 0.048268026948790066, 0.027044302914873697, 0.04145016115217004, 0.03833014263364021, 0.04590484320942778, 0.03458474966464564, 0.003798113516495505, 0.03078628571529407, 0.0739969770074822, 0.006981519100008882, 0.02280026463267859, 0.054867204089532606, 0.007489648132832372, 0.07661393072339706, 0.07199817293439992, 0.031602091548847966, 0.014848489026917377, 0.014732234376424458, 0.03225100321287755, 0.02991884310176829, 0.028444919262256008, 0.020443218454602174, 0.05644370015943423, 0.028768816628144123, 0.02390331501374021, 0.009123827167059062, 0.0285081520996755, 0.01463156482714112, 0.026229142749798484, 0.022572143279830925, 0.06530432001454756, 0.05722362686356064, 0.0307789978251094, 0.06530727376230061, 0.023178038209152874, 0.0821235979674384, 0.028017774311592802, 0.050067812990164384, 0.05427401658380404, 0.05706384989025537, 0.05864085062057711, 0.042706004896899685, 0.06737137940945104, 0.06731597808538936, 0.08061622182140127, 0.010091448584717, 0.006079078193579335, 0.03328504128148779, 0.008776506692811381, 0.0654772923735436, 0.016174713418877218, 0.04404100611282047, 0.04679554287577048, 0.052387521718628705, 0.049986748199444264, 0.04621248197508976, 0.06908472380018793, 0.007376577295872266, 0.03935751250537578, 0.02496028730092803, 0.05606200247711968, 0.04154055473918561, 0.0269968073189375, 0.05278717937471811, 0.012455673186195781, 0.0673134028329514, 0.07787011956679635, 0.046197490592021495, 0.08616448074462824, 0.008427638840657892, 0.05796732562885154, 0.10513782748603262, 0.06992338778218254, 0.044528318830998614, 0.10686309818993323, 0.055943455517990515, 0.0450296099006664, 0.04392818853375502, 0.06088893838750664, 0.015153431941143936, 0.00798093737103045, 0.06907257484272122, 0.021872490979149006, 0.03488039532385301, 0.04094107382115908, 0.016158289690793026, 0.011030826644855551, 0.0699957694450859, 0.008846668406476965, 0.07327733866986819, 0.04292940990126226, 0.015300160102924565, 0.01371535847283667, 0.02612117325043073, 0.051226290670456365, 0.01920018232340226, 0.04131880843488034, 0.045689906110055745, 0.026211377589788754, 0.032124949429999106, 0.06806731355027296, 0.035231364381616004, 0.020921413888572715, 0.04791604857018683, 0.038950726520852186, 0.01961399830179289, 0.07387003264739178, 0.09168519114609808, 0.02430797103443183, 0.04208037811622489, 0.02344626893318491, 0.04790637467522174, 0.03431965451454744, 0.03577002258680295, 0.07266856977366842, 0.020679330882558133, 0.054945994197623804, 0.030870897971908562, 0.01878488576039672, 0.05587091429333668, 0.0395859752461547, 0.014662443736597197, 0.04987291387806181, 0.017110285189119168, 0.009112676398217445, 0.0570582429645583, 0.0212470664337161, 0.03071688934142003, 0.03644872776931152, 0.010043603251688182, 0.08619992571766488, 0.03685760289954487, 0.04044971639814321, 0.028114516971982084, 0.035245008766651154, 0.07395662643830292, 0.12189275381388143, 0.8050167874898762, 3.0310650542378426, 13.490666896104813, 15.444101225584745, 3.0201470525935292, 8.767808172851801, 14.07598178833723, 10.495879445225, 11.595226004719734, 12.801152095198631, 22.68856544047594, 19.71793234348297, 5.3045049123466015, 0.562164515722543, 0.056332611784455366, 0.060989781413809396, 0.012338363758317428, 0.02135094669938553, 0.04528297169599682, 0.10528892875299789, 0.051495293228072114, 0.03392165926925372, 0.08726961284992285, 0.07070947060128674, 0.036041002967976965, 0.011755195246223593, 0.03633191001426894, 0.005495159184647491, 0.01967566891835304, 0.06682415682007559, 0.018750624512904324, 0.03971113474108279, 0.05124298528244253, 0.08086653338978067, 0.035336634318809956, 0.13439721486065537, 0.0830680773651693, 0.042279715271433815, 0.01913799776957603, 0.035810833287541755, 0.04280243956600316, 0.02994443420902826, 0.0734007875144016, 0.09213646888383664, 0.06585457056644373, 0.03568005202396307, 0.026165846829826478, 0.05909931234782562, 0.049375574744772166, 0.033936097752302885, 0.01837658950535115, 0.03858860298350919, 0.01892883828986669, 0.0617036235780688, 0.017671341411187313, 0.04338068392826244, 0.08975767035735771, 0.01844475576945115, 0.08429835783317685, 0.016976821061689407, 0.026473465186427347, 0.05684183270204812, 0.029938515581307, 0.11935948466998525, 0.03850796492770314, 0.033180350219481625, 0.017247107534785755, 0.019706750063051004, 0.08373080781893805, 0.014509371139865834, 0.05875511167687364, 0.07009118737187237, 0.029477278221747838, 0.03541307924024295, 0.087308887304971, 0.041490493167657405, 0.012285091470403131, 0.042198442679364234, 0.03980943962233141, 0.04592777186189778, 0.036763172029168345, 0.0675140498788096, 0.02892198106565047, 0.07465629358193837, 0.11476567218778655, 0.05054668006778229, 0.024852135975379497, 0.08757489529671147, 0.059577815773081966, 0.05777965874585789, 0.006785307778045535, 0.13312490656971931, 0.17512915888801217, 0.15155091939959675, 0.1911551403463818, 0.16484103281982243, 0.09609939646907151, 0.15059803146868944, 0.15655134717235342, 0.11693895517964847, 0.16172491799807176, 0.11044195693102665, 0.2208881441038102, 0.26447331940289587, 0.1287009791121818, 0.1625143107958138, 0.20511945040198043, 0.190863402094692, 0.17512763006379828, 0.15035655145766214, 0.17982006655074656, 0.11296815340756439, 0.2553457044996321, 0.26072348468005657, 0.20276004419429228, 0.17416960647096857, 0.17055001866538078, 0.2533476351527497, 0.17048295820131898, 0.10755512863397598, 0.13561049272539094, 0.12031712976749986, 0.11766539158998057, 0.28465869720093906, 0.0995556969428435, 0.10889320605201647, 0.18049595528282225, 0.1948556222487241, 0.1325432854355313, 0.1173914797254838, 0.1111626713827718, 0.17462961928686127, 0.17144295590696856, 0.15979053976479918, 0.14179967780364677, 0.1902652607532218, 0.09145667645498179, 0.14154963340843096, 0.09542076921206899, 0.16064066992839798, 0.14836783317150548, 0.1501434066449292, 0.13751315156696364, 0.16685038281138986, 0.1110042748041451, 0.1570008066482842, 0.2297876079683192, 0.10213703499175608, 0.19697034236742184, 0.15018986508948728, 0.1700372391496785, 0.12106787151424214, 0.16696434700861573, 0.20990691147744656, 0.2036904450505972, 0.13709073595236987, 0.11068017891375348, 0.1438377785962075, 0.1630722128902562, 0.15728631085949019, 0.07056131566059776, 0.20405587856657803, 0.18840796197764575, 0.10214647511020303, 0.08635062622488476, 0.06624952671700157, 0.10040826877229847, 0.16489783680299297, 0.10997860445058905, 0.2562114642933011, 0.10550838182098232, 0.1432876690523699, 0.15059722994919866, 0.09252864198060706, 0.19349979265825823, 0.17356251482851803, 2.3990276316180825, 9.332088343799114, 31.8334948271513, 30.219419337809086, 33.07328090071678, 44.535274654626846, 45.419658198952675, 43.29974055290222, 42.2722452878952, 37.11416266858578, 37.770539447665215, 39.45119306445122, 15.982614979147911, 1.8926858017221093, 0.2173063316149637, 0.3026804473483935, 0.08541440693079494, 0.15021848230389878, 0.2006276312749833, 0.1449314074125141, 0.10854717227630317, 0.15612991119269282, 0.19090134068392217, 0.16196586366277188, 0.14114194200374186, 0.09682699805125594, 0.17575858917552978, 0.24337284383364022, 0.0951615370286163, 0.103659862652421, 0.10497703377041034, 0.1338343700626865, 0.22145976108731702, 0.1977450554841198, 0.15028649271698669, 0.26754999649710953, 0.2450931866769679, 0.1354933372931555, 0.1215951080666855, 0.15067750064190477, 0.11228190429392271, 0.14685925474623218, 0.16764375352067873, 0.23381246777717024, 0.1154664006025996, 0.13939004304120317, 0.11622757694567554, 0.1980732035008259, 0.15972837747540325, 0.12598345696460456, 0.15148259728448465, 0.12589714518981054, 0.12049958677380346, 0.16088376782136038, 0.11254719240241684, 0.13531070959288627, 0.11065597005654126, 0.1254447764949873, 0.1357222007936798, 0.16763962717959657, 0.15225309500237927, 0.16081213572761044, 0.14517097268253565, 0.21228778059594333, 0.12092434757505544, 0.09502262182650156, 0.04037223246996291, 0.15918430901365355, 0.14659666805528104, 0.14251944230636582, 0.1385034288978204, 0.12441791128367186, 0.1347971730865538, 0.1226972344738897, 0.19668673805426806, 0.13751974183833227, 0.1012498716590926, 0.18151756608858705, 0.1593333322671242, 0.12886689364677295, 0.12113416014472023, 0.23981857986655086, 0.14864167082123458, 0.15008185291662812, 0.28957661299500614, 0.23171495064161718, 0.18748072267044336, 0.16550405271118507, 0.1447096685296856, 0.23638166429009289, 0.12233836154337041], [0.07201119762612507, 0.048051546182250604, 0.058076499262824655, 0.03192607982782647, 0.017254649610549677, 0.008929541254474316, 0.02144439236872131, 0.04201847557851579, 0.04713939102657605, 0.03454951991443522, 0.030583913176087663, 0.05811590359371621, 0.026856719523493666, 0.019308070186525583, 0.006819068075856194, 0.03502673571347259, 0.08927419083192945, 0.051850065792677924, 0.020934483109158464, 0.006822587711212691, 0.044216742971912026, 0.03473159471468534, 0.08735852956306189, 0.08428653542068787, 0.009506269780104049, 0.007339994053836563, 0.030667527244077064, 0.05433951853774488, 0.014052338046894874, 0.05206575988268014, 0.02435630711261183, 0.010765391034510685, 0.0824994215508923, 0.06555175947141834, 0.02574491736595519, 0.1022504128923174, 0.04536337226454634, 0.00793238421465503, 0.09867834480246529, 0.03629967482993379, 0.05701577727450058, 0.05712213445804082, 0.052437854174058884, 0.014325186784844846, 0.048961931315716356, 0.043313196729286574, 0.018544036574894562, 0.043880524099222384, 0.008254442909674253, 0.023645539295102935, 0.023472095672332216, 0.050792323527275585, 0.01262676420083153, 0.031245181598933414, 0.02237648717709817, 0.02166105310607236, 0.0298887193275732, 0.0347952338779578, 0.03873878398735542, 0.03399320601602085, 0.055376198652083986, 0.04142965561186429, 0.002882199846681033, 0.01929289512190735, 0.036903898071614094, 0.0374144585657632, 0.07315096576348878, 0.017931601469172165, 0.04069579401402734, 0.024662821524543688, 0.03900117771991063, 0.0555498426547274, 0.03754764067707583, 0.03507692716084421, 0.055348082387354225, 0.0534828314994229, 0.03000860586325871, 0.031012349463708233, 0.04572887257381808, 0.09633083522203378, 0.010420729304314591, 0.05597721952653956, 0.006361076684697764, 0.07737032763543539, 0.03295381706266198, 0.1656298022135161, 0.05407641605415847, 4.774831859394908, 10.494495369493961, 10.416503604501486, 8.80101079121232, 0.7498471322469413, 2.595845670439303, 5.913083106279373, 6.16725099273026, 6.217634389176965, 2.8434862196445465, 0.22631460917182267, 0.04007042327430099, 0.03158481435093563, 0.025196039787260816, 0.06602006949833594, 0.06408650762750767, 0.0966564154077787, 0.08181025579688139, 0.042425502761034295, 0.07797520025633276, 0.0036826360337727237, 0.0897470056952443, 0.039720426429994404, 0.04399600969918538, 0.016071334102889523, 0.05739739703130908, 0.044909062853548676, 0.019454447683528997, 0.08931860837037675, 0.06147417749161832, 0.057795930333668366, 0.025201251519320067, 0.022061922318243887, 0.02661776466993615, 0.009519143259240082, 0.09277680874220096, 0.020336198904260527, 0.05614449219137896, 0.07817339079338126, 0.10285440235747956, 0.07694990839809179, 0.028770399258064572, 0.0206486412207596, 0.011233843924856046, 0.04104195395484567, 0.017511545884190127, 0.02119969514751574, 0.01042655238052248, 0.041531196256983094, 0.007109935231710551, 0.0068370804638107074, 0.016260973243333865, 0.10067092967801727, 0.03674240673717577, 0.03718943567946553, 0.02531439564336324, 0.013556923859141534, 0.010411560069769621, 0.035240867582615465, 0.04777588284923695, 0.05685282390913926, 0.027730320107366424, 0.013335653457033914, 0.0777414756885264, 0.04663720937969629, 0.04157808143645525, 0.01768077039741911, 0.04127659136429429, 0.07488913499400951, 0.055019188512233086, 0.056963444731081836, 0.04515505141171161, 0.07882876656367444, 0.020453799625101965, 0.03768176531593781, 0.0320942764665233, 0.028848439797002356, 0.04521650123933796, 0.014812621029705042, 0.02731453743763268, 0.04015165875898674, 0.0645255547715351, 0.0613192578748567, 0.05493096570717171, 0.010646267983247526, 0.02890028066758532, 0.03691477053507697, 0.014711149033246329, 0.04869376738497522, 0.010085858357342659, 0.04305938593461178, 0.071470572729595, 0.02658482815604657, 0.023736235307296738, 0.11505608941661194, 0.027984346124867443, 0.007002762613410596, 0.02414322538243141, 0.030350956731126644, 0.009138069908658508, 0.053134144545765594, 0.02902131382143125, 0.04316307509725448, 0.07399630907457322, 0.03628937010944355, 0.02753135031525744, 0.07653875116375275, 0.06402775921742432, 0.03676864165754523, 0.031137881887843832, 0.05872156660188921, 0.004333844181019231, 0.10084551991894841, 0.0406595067033777, 0.02562743167800363, 0.049306684886687435, 0.011112380325357663, 0.03334138142236043, 0.05363258947909344, 0.048040187612059526, 0.05041031414293684, 0.006504389575638925, 0.010254566150251776, 0.022526328648382332, 0.0803980155615136, 0.09887563734082505, 0.019508620753185824, 0.10736948039266281, 0.034620454389369115, 0.08156591109582223, 0.0405480509652989, 0.036407538573257625, 0.06470954802352935, 0.08983155115856789, 0.026971535335178487, 0.008582610407756874, 0.012856610119342804, 0.0343323007109575, 0.042703685685410164, 0.03805182612268254, 0.06332420321996324, 0.01565549577208003, 0.06842994174803607, 0.017730056424625218, 0.1133744273101911, 0.028807447270082776, 0.03279402524640318, 0.049945035789278336, 0.042988618442905135, 0.05348007813154254, 0.004316003414714942, 0.006241179480639403, 0.027604340539255645, 0.041688427663757466, 0.04268928802048322, 0.055334152275463566, 0.017639794568822253, 0.09875926858512685, 0.017323400315945037, 0.03148487303406, 0.023808264450053684, 0.014729532031196868, 0.04050686919072177, 0.07085954770445824, 0.14550197054632008, 0.028743494549416937, 0.025401338243682403, 0.0320731178362621, 0.019172264583176002, 0.0188165828876663, 0.09489063828368671, 0.038195839879335836, 0.027672727592289448, 0.0777988437039312, 0.16597723122686148, 0.2002344117499888, 2.6402144646272063, 7.450341917574406, 11.02406345307827, 4.314314145594835, 3.4298097202554345, 2.6358425617218018, 8.940426260232925, 9.930027108639479, 6.003001006320119, 1.4605723950080574, 0.08624717826023698, 0.01756567999109393, 0.06793870677938685, 0.021322776628949214, 0.02153079505660571, 0.03730736665602308, 0.06949599977815524, 0.031570817445754074, 0.04203353375487495, 0.0396697006362956, 0.028197867577546276, 0.04766293539432809, 0.02513531726435758, 0.03739447995030787, 0.030288315756479278, 0.03238615572627168, 0.025264046489610337, 0.06116624557762407, 0.04779844413860701, 0.02325144403585, 0.04273081860446837, 0.05325513688148931, 0.037819355784449726, 0.02494387841579737, 0.03870936525345314, 0.12257069087354466, 0.04115273062780034, 0.054369775898521766, 0.012831530166295124, 0.00981660346951685, 0.012815627796953777, 0.012803425033780513, 0.01537014462883235, 0.061973698539077304, 0.01982355854124762, 0.03876280730764847, 0.014367697931447765, 0.04462794473511167, 0.006424790526580182, 0.018636038766999263, 0.03743284527445212, 0.026989723519363906, 0.054722563218092546, 0.04833872022572905, 0.008444234190392308, 0.0929659153916873, 0.05844584389706142, 0.04182083052000962, 0.05640174655127339, 0.04517180539551191, 0.04190280815237202, 0.03731955272087362, 0.027603930502664298, 0.07512475945986807, 0.004577914287438034, 0.03024854406248778, 0.021736355120083317, 0.03694465311127715, 0.031992450094548985, 0.04288473261112813, 0.05687138131179381, 0.029116325422364753, 0.04916260062600486, 0.025916817321558483, 0.03706623916514218, 0.030223097674024757, 0.015624904444848653, 0.01872984994406579, 0.03349244187120348, 0.020653066276281606, 0.02469928323989734, 0.009818768685363466, 0.011263688465987798, 0.03964322451793123, 0.013402719487203285, 0.002962203134302399, 0.04848500495427288, 0.03157613864459563, 0.02700484292290639, 0.1835858277627267, 0.19674621376907453, 0.2499478863319382, 0.08982588115031831, 0.10866994576645084, 0.2070567081682384, 0.11255638019065373, 0.06483119344920851, 0.1262627271353267, 0.16152476076968014, 0.13353221205761656, 0.13310455688042566, 0.16366340772947297, 0.15110965323401615, 0.17208307312102988, 0.12308378209127113, 0.23715101910056546, 0.22872234403621405, 0.09159865672700107, 0.15182652336079627, 0.18572425207821652, 0.1268312122556381, 0.17370303306961432, 0.21998457930749282, 0.11017958546290174, 0.11636098541202955, 0.20213141542626545, 0.09757429623277858, 0.09725184048875235, 0.22454483929323032, 0.10547928963205777, 0.10997247431077994, 0.15726591664133593, 0.14155628305161372, 0.1837249062373303, 0.1923019959940575, 0.23663123371079564, 0.06585743525647558, 0.18174963566707447, 0.1491471624467522, 0.13760464353254065, 0.15246065886458382, 0.15033857664093375, 0.15708380844444036, 0.18693675810936838, 0.13228463212726638, 0.11356686620274559, 0.11868155503179878, 0.17309821239905432, 0.11311479436699301, 0.10576557309832424, 0.1704204545239918, 0.10508581035537645, 0.15832580742426217, 0.13984670134959742, 0.20676850253948942, 0.13174001447623596, 0.08643490451504476, 0.14765569794690236, 0.19839360349578783, 0.15816033817827702, 0.11291779126622714, 0.07808780632331036, 0.09270280919736251, 0.16557492781430483, 0.1314012537477538, 0.11831279669422656, 0.08880772133124992, 0.19501319504342973, 0.09570585039909929, 0.1475715680862777, 0.142805703508202, 0.06483613615273498, 0.07561022794106975, 0.14243577257730067, 0.27948328584898263, 0.21053646050859243, 0.12356153965811245, 0.14159388025291264, 0.12260983916348778, 0.16317676665494218, 0.22764713532524183, 0.08371953459572978, 0.1883170785731636, 0.26621724769938737, 0.2834541321499273, 0.5503387190401554, 13.750313613563776, 28.215498067438602, 36.22286729514599, 41.559228748083115, 35.38357213139534, 30.8898401632905, 24.820171259343624, 30.0040240958333, 27.617894634604454, 8.525157943367958, 0.351576876710169, 0.09292994349380024, 0.20718300685985014, 0.13317017757799476, 0.16926775075262412, 0.16695379366865382, 0.13075580791337416, 0.1952223025728017, 0.13619701203424484, 0.1322588202310726, 0.16760716564022005, 0.18560148600954562, 0.09404396652826108, 0.14195665688021109, 0.17853969853604212, 0.15725037606898695, 0.12289453443372622, 0.11278979305643588, 0.11559189777472056, 0.16137857252033427, 0.10572528932243586, 0.2518760156817734, 0.057365544053027406, 0.1550134687568061, 0.10519478732021526, 0.23592557001393288, 0.1453599234810099, 0.2360553716425784, 0.10985641725710593, 0.14291981613496318, 0.1366708436398767, 0.08827796889818273, 0.2042776916641742, 0.17005430854624137, 0.10156053467653692, 0.10066419839859009, 0.19214333966374397, 0.1555302707129158, 0.12924907001433894, 0.1305953852715902, 0.21221666800556704, 0.06684735635644756, 0.19515497493557632, 0.1712713119923137, 0.1189053941925522, 0.20552791364025325, 0.10816365262144245, 0.16023490810766816, 0.15733946347609162, 0.1617082642042078, 0.07919530587969348, 0.14307189703686163, 0.18462836713297293, 0.26946874510031193, 0.09327040374046192, 0.15199456043774262, 0.09405421558767557, 0.2399495244026184, 0.12034755782224238, 0.12853524269303307, 0.10932547738775611, 0.17941722879186273, 0.18218303506728262, 0.16904905467526987, 0.1533716154517606, 0.11052499583456665, 0.16045207536080852, 0.12049253637087531, 0.14485726685961708, 0.10567513498244807, 0.12401373765897006, 0.20231978734955192, 0.21466379606863484, 0.15930468536680564, 0.13441244373098016, 0.13225188857177272, 0.21545666211750358, 0.10598273292998783, 0.1975500487606041], [0.027990197959297802, 0.06675993136013858, 0.014817772462265566, 0.02086206804960966, 0.041489183277008124, 0.04389159694255795, 0.016429288625658955, 0.011822880969702965, 0.030977546448411886, 0.016120612708618864, 0.03569913264072966, 0.004655854172597174, 0.053151533065829426, 0.05382154769904446, 0.10192258399911225, 0.061924134206492454, 0.051310683993506245, 0.0409203975868877, 0.008941718042478897, 0.04098199584404938, 0.07135994077543728, 0.04481481380935293, 0.019472058847895823, 0.03070299448154401, 0.029535672256315593, 0.07515736200730316, 0.03871498331136536, 0.022540104764630087, 0.044303533431957476, 0.04002182373369578, 0.051477448287187144, 0.05400973037467338, 0.032271208183374256, 0.010623829148244113, 0.10024808361777104, 0.027327901661919896, 0.07783683424349874, 0.025358811326441355, 0.015737701614852995, 0.10268295140122063, 0.07529772439738736, 0.014069194076000713, 0.09562339037074707, 0.030920165445422754, 0.04653691554267425, 0.04220917042403016, 0.018307814680156298, 0.0808852948830463, 0.019310630596010014, 0.033219884426216595, 0.11599094315897673, 0.050387986630084924, 0.07179198946687393, 0.023051017778925598, 0.04170796470134519, 0.011288198820693651, 0.053428740066010505, 0.04969370747858193, 0.05620889205601998, 0.09111626815865748, 0.05925575336732436, 0.026637797091098037, 0.00542826802302443, 0.03289833039161749, 0.07402284085401334, 0.045980115537531674, 0.07191914904979058, 0.06713527996907942, 0.016500095080118626, 0.04802720373845659, 0.02163159726478625, 0.04358096732175909, 0.07586381238070317, 0.04324860390624963, 0.06300032997387461, 0.0673519574047532, 0.057004860282177106, 0.013892200204281835, 0.0031166955523076467, 0.12582300463691354, 0.07422442300594412, 0.01662897087953752, 0.04258990702510346, 0.07447823008988053, 0.06381446597515605, 0.030887067514413502, 0.027098422178823967, 0.0630801627994515, 0.2483605660381727, 1.8674970720894635, 3.2229861058294773, 5.216700648888946, 2.7336951484903693, 1.210076417773962, 0.6736611609812826, 0.4393668018747121, 0.060918631716049276, 0.07479415493435226, 0.04045154208142776, 0.04413377828313969, 0.005987195208945195, 0.025383756765222643, 0.05184131587157026, 0.011313442046230193, 0.039144367692642845, 0.07454146107193083, 0.04378097983135376, 0.03060130911762826, 0.024966395176306833, 0.014900848473189399, 0.008343284480361035, 0.057444634730927646, 0.036537893101922236, 0.10067255498142913, 0.050364898415864445, 0.012134135849919403, 0.04439921482116915, 0.011437772191129625, 0.020452834833122324, 0.0552014414279256, 0.013058495624136413, 0.09505972178885713, 0.045449075478245504, 0.03923608972399961, 0.04818213448743336, 0.03292492154287174, 0.017598609083506744, 0.059647666712407954, 0.03525514650391415, 0.07723014336079359, 0.028341729193925858, 0.04465797574084718, 0.03854176233289763, 0.05726647847041022, 0.06625681460718624, 0.10741898906417191, 0.026382461182947736, 0.10826278128661215, 0.021373053423303645, 0.03219089667254593, 0.04009271739050746, 0.06994820520048961, 0.02907880800194107, 0.029894083199906163, 0.037363502706284635, 0.07465005954145454, 0.06441919016651809, 0.03892950109730009, 0.048732826617197134, 0.021946544329694007, 0.0664468712056987, 0.022055400695535354, 0.05894685295061208, 0.04387814180518035, 0.05100481525005307, 0.02539416353101842, 0.06839431865955703, 0.040682943727006204, 0.039766684494679794, 0.08604240487329662, 0.012201503377582412, 0.030608532069891226, 0.01981708330276888, 0.027345299458829686, 0.00618483655671298, 0.003218146212020656, 0.007265517215273576, 0.07280537727638148, 0.035346939039300196, 0.04632973017578479, 0.019076893040619325, 0.05749557945819106, 0.016345173607987817, 0.06258751775021665, 0.024869403896445874, 0.029749551795248408, 0.0915938698744867, 0.12614503735676408, 0.01022647771605989, 0.0371719358372502, 0.020362328068586066, 0.005012947804061696, 0.02345930290175602, 0.11609589768340811, 0.010559202000877121, 0.05151504177774768, 0.06816742185037583, 0.02612928677990567, 0.03723240974068176, 0.020231385387887713, 0.06946081455680542, 0.018759454214887228, 0.057674377676448785, 0.05103599658468738, 0.042798443100764416, 0.05024560559832025, 0.03856211573292967, 0.09414316940819845, 0.017294078061240725, 0.022391035126929637, 0.006662148371106014, 0.06386359615135007, 0.003912147521987208, 0.04004344991699327, 0.030210137920221314, 0.02536407315346878, 0.02441693130094791, 0.08648454677313566, 0.038497548885061406, 0.021308262075763196, 0.03323744735098444, 0.01778224981535459, 0.07733311635092832, 0.028256910991331097, 0.043477864455780946, 0.06410109825083055, 0.07280131030711345, 0.09372064247145317, 0.09510814692475833, 0.057960249250754714, 0.018037027257378213, 0.015910649854049552, 0.041116176143987104, 0.06144870327261742, 0.035512682879925705, 0.03581659235351253, 0.01679323413554812, 0.028592148373718373, 0.04077314806636423, 0.030323564060381614, 0.026998100511264056, 0.03795679040194955, 0.11979441289440729, 0.05184677065699361, 0.05457593339087907, 0.030723472191311885, 0.032574672368355095, 0.04143183381529525, 0.04621869375114329, 0.04440027980308514, 0.039163255351013504, 0.019828597723972052, 0.07171951874624938, 0.031875854983809404, 0.05241524464508984, 0.023330989279202186, 0.03902973185176961, 0.041562548285583034, 0.05236608849372715, 0.020872929380857386, 0.0850193171936553, 0.017703563607938122, 0.03598561277613044, 0.01018825154460501, 0.053592201802530326, 0.050772174217854626, 0.03858590898744296, 0.05210734983847942, 0.027281088841846213, 0.014126657642918872, 0.04354958931799047, 0.01294812434935011, 0.023550878358946647, 0.05641223309794441, 0.1440815592650324, 1.0053046932443976, 1.641228951048106, 3.168733804486692, 2.3120923340320587, 1.9692053832113743, 0.7279957516584545, 0.3159000864252448, 0.0779374768899288, 0.06827967910794541, 0.07033523521386087, 0.08662517633638345, 0.013955074955447344, 0.04121811383811291, 0.05631898224237375, 0.016566908780077938, 0.059689119370887056, 0.0826691729889717, 0.03540768753737211, 0.06636807738686912, 0.02134225986083038, 0.05203122775128577, 0.013525967951864004, 0.03228527188184671, 0.005142742938915035, 0.052018325513927266, 0.07295704999705777, 0.05740078864619136, 0.03473511249467265, 0.037165545945754275, 0.01579305655468488, 0.04817023786017671, 0.029728252156928647, 0.05906198231969029, 0.012131251678511035, 0.008235533914557891, 0.030694667584612034, 0.013727304267376894, 0.011530602805578383, 0.027428460816736333, 0.03209816160961054, 0.10922045607003383, 0.02574406946223462, 0.04733540707093198, 0.03908787912223488, 0.04872010991675779, 0.07722391674178652, 0.107253067108104, 0.01437026390703977, 0.08110133407171816, 0.04073895361216273, 0.015101671779120807, 0.03876000198943075, 0.03084700267208973, 0.049506341165397316, 0.01974359398445813, 0.05371251878386829, 0.005522440533241024, 0.023582503126817755, 0.023631343865417875, 0.026082229051098693, 0.031360366629087366, 0.03593497604015283, 0.06619569874601439, 0.04570077857351862, 0.0353696895763278, 0.028176254381833132, 0.025164459548250306, 0.03632709718658589, 0.1059788886050228, 0.05915012719924562, 0.03566714978660457, 0.0038061567738623125, 0.020485656314122025, 0.0543126676348038, 0.03228037370718084, 0.031619854853488505, 0.00604155891778646, 0.01337914794930839, 0.03575512768293265, 0.013001020925003104, 0.06707204898702912, 0.058978390516131185, 0.04804456257261336, 0.013128238024364691, 0.05539661884540692, 0.16546234401175752, 0.018808593667927198, 0.260497871786356, 0.18043407500954345, 0.10860131937079132, 0.08372580574359745, 0.14630151592427865, 0.0768568430794403, 0.1268627683748491, 0.2765210479265079, 0.09165986906737089, 0.1353508746251464, 0.11822897111414932, 0.14926255156751722, 0.14981231972342357, 0.1747775441617705, 0.19543170696124434, 0.13917965901782736, 0.1262927841162309, 0.12684979563346133, 0.1171249448088929, 0.13900595193263143, 0.18653099628863856, 0.25007229996845126, 0.0833430876082275, 0.1774973372812383, 0.1611268360284157, 0.21094673458719626, 0.1969655480934307, 0.165464140009135, 0.1129265411873348, 0.09588227374479175, 0.14243194309528917, 0.16231468791374937, 0.15681013406720012, 0.0743650525691919, 0.18055451073450968, 0.09461692679906264, 0.14136005920590833, 0.14185907930368558, 0.10894952021772042, 0.13071749825030565, 0.24157804873539135, 0.2197881625033915, 0.199021712760441, 0.12641175038879737, 0.11017601573257707, 0.13772108650300652, 0.14126136840786785, 0.13337434240384027, 0.1716199581278488, 0.14363950642291456, 0.1881028650677763, 0.14603373419959098, 0.17325275723123923, 0.17020137252984568, 0.09463098307605833, 0.1799341049627401, 0.146337732730899, 0.1558613873203285, 0.1655643299454823, 0.1336212846217677, 0.11625587503658608, 0.09206734524923377, 0.09378759903484024, 0.14446006942307577, 0.12351225363090634, 0.2297540777362883, 0.2586707042064518, 0.13392440741881728, 0.1348402473377064, 0.1559234011801891, 0.17733044311171398, 0.11077575269155204, 0.21182420547120273, 0.20308694540290162, 0.19849784555844963, 0.1309572861646302, 0.13730952108744532, 0.10569197431323119, 0.12768722022883594, 0.28521135973278433, 0.09984117146814242, 0.14698559796670452, 0.1188865139556583, 0.15469881298486143, 0.1087095467664767, 0.18551511486293748, 0.20815833733649924, 0.1649157374049537, 0.8051128510851413, 5.38999842479825, 4.957527006044984, 9.32687597349286, 5.257009360939264, 4.946670513600111, 3.0869762040674686, 0.6067374302074313, 0.40613708028104156, 0.16528051783097908, 0.29471019690390676, 0.23329977731918916, 0.12223477999214083, 0.13268806360429153, 0.15563696186291054, 0.11827902155346237, 0.13101827586069703, 0.2725845779059455, 0.1452839424018748, 0.13570554699981585, 0.09557529920130037, 0.12163899868028238, 0.12013119951006956, 0.0869231040996965, 0.16130833566421643, 0.1879843440838158, 0.1221553998766467, 0.056196954610641114, 0.16213198599871248, 0.1287250395398587, 0.088743080268614, 0.14070590055780485, 0.11710310340276919, 0.2712341659935191, 0.1901500645908527, 0.12866805744124576, 0.0921268061210867, 0.19503363379044458, 0.06973156487219967, 0.1281197735806927, 0.11259194390731864, 0.22730084921931848, 0.10866439450182952, 0.09274688534787856, 0.10236802845611237, 0.1157727517420426, 0.21670229762094095, 0.23513162042945623, 0.15017668454675004, 0.2594823169056326, 0.2455665433080867, 0.10144067782675847, 0.1252115936949849, 0.1383611443452537, 0.15064720617374405, 0.17263825895497575, 0.1171224437712226, 0.1677283286699094, 0.1013925569714047, 0.1273858340573497, 0.11749116500141099, 0.149034860660322, 0.2583044988568872, 0.1421691634459421, 0.1290732849156484, 0.07707061871769838, 0.08495777830830775, 0.15188184304861352, 0.09230155221302994, 0.2449472656007856, 0.1185868050379213, 0.20804890024010092, 0.136647094914224, 0.16834309411933646, 0.15464997966773808, 0.07514325377997011, 0.1610526064177975, 0.10036121660959907, 0.051712345448322594, 0.11996928515145555, 0.07907481078291312, 0.17939431127160788, 0.14589100435841829, 0.15987511491402984, 0.08475171358441003, 0.09458171189180575, 0.3739561914699152, 0.2437686757184565], [0.1102307194378227, 0.009252904274035245, 0.053121431556064636, 0.04604133529937826, 0.05115678482980002, 0.02726523842284223, 0.01570393575093476, 0.041775526115088724, 0.03760671192139853, 0.008226693080359837, 0.030727674602530897, 0.013859848131687613, 0.016833167246659286, 0.03239391116949264, 0.03421658133447636, 0.025739739030541386, 0.012722910360025708, 0.028288452267588582, 0.04028003917483147, 0.06924248955328949, 0.01824158913223073, 0.021302636596374214, 0.060877167925355025, 0.02769913691736292, 0.036441358242882416, 0.09193566598696634, 0.06800416420446709, 0.017609982496651355, 0.050749635192914866, 0.041258315977756865, 0.06729939850629307, 0.05821403035952244, 0.0034745960374493734, 0.012899595312774181, 0.03550729488779325, 0.047826360023464076, 0.04228545949445106, 0.03112422451522434, 0.022139242973935325, 0.013110980307828868, 0.023321133558056317, 0.03737705061212182, 0.040061395047814585, 0.012169380443083355, 0.014668611911474727, 0.04470353618671652, 0.033979635845753364, 0.031078254032763653, 0.03886688609782141, 0.0436971134331543, 0.02767971862340346, 0.031883087212918326, 0.1086886998382397, 0.06625391280977055, 0.045722085633315146, 0.11963617216679268, 0.0724339100997895, 0.036898068501614034, 0.07033858972135931, 0.05403636605478823, 0.06532815779792145, 0.03277171628724318, 0.01611183866771171, 0.05983846916933544, 0.05746685463236645, 0.021412032874650322, 0.04683936669607647, 0.020733925121021457, 0.03645378179498948, 0.04712520858447533, 0.05563220249314327, 0.035984429050586186, 0.023745057587802876, 0.04184023026027717, 0.030902630351192784, 0.04814424413780216, 0.05172714387299493, 0.03377156732312869, 0.028928250358148944, 0.04718095871794503, 0.04508909674768802, 0.05701372523617465, 0.060939701288589276, 0.04080578772118315, 0.20342548348708078, 0.08303038368467242, 0.04040849380544387, 0.010983306001435267, 0.02550777335272869, 0.08521366340573877, 0.051378286225371994, 0.09804258399526589, 0.10098903643665835, 0.048843421463971026, 0.07168108291807584, 0.050728873611660674, 0.041626985257607885, 0.09941739772330038, 0.0636242312612012, 0.04948403962771408, 0.10295304120518267, 0.030246594069467392, 0.05744045272876974, 0.020537812597467564, 0.019517229666234925, 0.04455850568774622, 0.07391796796582639, 0.023662039093323983, 0.0860554666724056, 0.03428779040405061, 0.042196390641038306, 0.016434465105703566, 0.04128664746531285, 0.03927414334611967, 0.07582202946650796, 0.015681806762586348, 0.05608078252407722, 0.027666849782690406, 0.041067762140301056, 0.07419585032039322, 0.026025028018921148, 0.034003737091552466, 0.024777301514404826, 0.05519688093045261, 0.03336330075399019, 0.029628286720253527, 0.04465925223485101, 0.08096358404145576, 0.035705633854377083, 0.018256159346492495, 0.08409233021666296, 0.04136605726671405, 0.010908503081736853, 0.044180281256558374, 0.06861681453301571, 0.030773045800742693, 0.03290694672614336, 0.04739096424600575, 0.06355533027090132, 0.05374594882596284, 0.031275271976483054, 0.0509169004362775, 0.06999999968684278, 0.008571030120947398, 0.02922382551332703, 0.015379998494609026, 0.006083835824028938, 0.05209908602409996, 0.058738810403156094, 0.030877731296641286, 0.028620520679396577, 0.03298795585578773, 0.013242737495602341, 0.01756849273078842, 0.03676388078019954, 0.06788873797631823, 0.05342809439753182, 0.06557530039572157, 0.01603066255484009, 0.04536817024927586, 0.07193952100351453, 0.04633268021279946, 0.059455494993017055, 0.04012288569356315, 0.0843535439344123, 0.019755731809709687, 0.030231624950829428, 0.020581894314091187, 0.03305925398308318, 0.05088362253445666, 0.07186872011516243, 0.04929855465888977, 0.016706597671145573, 0.058442289009690285, 0.027367628827050794, 0.05296931725752074, 0.04287583054974675, 0.0410810094763292, 0.06776140769943595, 0.04259242661646567, 0.03991796758782584, 0.015492954298679251, 0.060426068303058855, 0.006800724968343275, 0.053267482508090325, 0.030124610966595355, 0.021525375523197, 0.015916412630758714, 0.050147352667408995, 0.05333628330845386, 0.007524074972025119, 0.06476593640400097, 0.010383705412095878, 0.017685870807326864, 0.0641513045411557, 0.08134460265864618, 0.019713592664629687, 0.03367444245668594, 0.02862929286493454, 0.0873718511138577, 0.03380559850484133, 0.03185080007824581, 0.004252212111168774, 0.006841834847364225, 0.019085924977844115, 0.022614720292040147, 0.02787567715131445, 0.14716773584950715, 0.044920376894879155, 0.04849756951443851, 0.026386626486782916, 0.043164255112060346, 0.0464781671325909, 0.10448760222061537, 0.04428911350260023, 0.03345285942486953, 0.018605076365929563, 0.038203688091016375, 0.058164933579973876, 0.023461683340428863, 0.01986732484510867, 0.0165581532928627, 0.06454048678278923, 0.023681379461777397, 0.029822764663549606, 0.06138192482467275, 0.021579479944193736, 0.08194821362849325, 0.06430601264582947, 0.09103687320020981, 0.015582665109832305, 0.07540751772467047, 0.05115018713695463, 0.02245353509351844, 0.02832657268299954, 0.018286294252902735, 0.05845986677741166, 0.04265566873073112, 0.07047389066428877, 0.05409122561104596, 0.037694945858675055, 0.010944191108137602, 0.03516300144838169, 0.05384006057283841, 0.012815753034374211, 0.02330562081624521, 0.083533047727542, 0.05529889283934608, 0.04312300654419232, 0.08508729792083614, 0.04021123837446794, 0.03210369060980156, 0.01457038773878594, 0.03324863522720989, 0.036884483488393016, 0.03474020733847283, 0.07169801872805692, 0.03199314029188827, 0.04459031784790568, 0.03844060760457069, 0.08345060254214332, 0.06879418782773428, 0.08877966814907268, 0.03719633023138158, 0.02843868893251056, 0.21081607206724584, 0.04771679305122234, 0.14460887003224343, 0.08084766057436354, 0.11044668441172689, 0.07274624294950627, 0.05471808435686398, 0.07537999888882041, 0.00719620804375154, 0.024289491557283327, 0.048959485939121805, 0.05804275380796753, 0.06334410019917414, 0.04770244733663276, 0.03934196451155003, 0.027577179789659567, 0.018206387212558184, 0.039104822353692725, 0.027634338148345705, 0.04778089976753108, 0.009703669002192328, 0.015357048505393323, 0.03519277641316876, 0.0530433130916208, 0.060176391270942986, 0.040480363386450335, 0.0472161105426494, 0.041661665818537585, 0.08164783677784726, 0.08250226397649385, 0.09394926848472096, 0.019736517606361303, 0.01357801198537345, 0.05862749938387424, 0.048945348025881685, 0.0507414381718263, 0.018765456334222108, 0.012038588047289522, 0.023782790231052786, 0.006088650507081184, 0.023556685664516408, 0.009212591739924392, 0.02783512249152409, 0.03963191789807752, 0.028426413809938822, 0.035682512243511155, 0.03223347739549354, 0.04240582471538801, 0.047362016775878146, 0.04868667987466324, 0.07111469065421261, 0.03051026058528805, 0.029369164003583137, 0.04715855327958707, 0.035678541753441095, 0.029885444600949995, 0.02967439821077278, 0.01862819797679549, 0.029984879402036313, 0.04128769018279854, 0.04354300646809861, 0.03704822353029158, 0.046597868131357245, 0.04371728500700556, 0.02434120626276126, 0.03306862730823923, 0.02294816167704994, 0.05371024410123937, 0.09852239731117152, 0.03694810038723517, 0.05929119462962262, 0.03826116742857266, 0.011769889770221198, 0.04857702013396192, 0.049356627714587376, 0.053933719609631225, 0.04176958522293717, 0.026867159685934894, 0.03012220826349221, 0.02833810380252544, 0.06552737992024049, 0.019206108372600283, 0.020319966279203072, 0.02242673985165311, 0.032230994911515154, 0.005556091364269378, 0.06487070539151318, 0.13806073780870065, 0.09374022032716312, 0.11195391954970546, 0.2910901192808524, 0.19887304573785514, 0.17291769239818677, 0.1412405734299682, 0.16777653858298436, 0.18058903544442728, 0.06074754070141353, 0.16292657383019105, 0.1148505813034717, 0.1863333920482546, 0.15135150431888178, 0.0942750193644315, 0.1275437482399866, 0.09257992438506335, 0.09982135612517595, 0.1957581628812477, 0.1603163217077963, 0.15824991540284827, 0.0907222916430328, 0.20828439854085445, 0.14310953876702115, 0.1832892803940922, 0.20361565140774474, 0.12338786968030035, 0.1156984553381335, 0.17861763888504356, 0.13362303609028459, 0.19155352521920577, 0.11727853969205171, 0.13226858689449728, 0.23524260119302198, 0.11015677926479839, 0.18846371211111546, 0.1379154104506597, 0.1566621646634303, 0.13768958975560963, 0.0807636568788439, 0.09925727936206385, 0.1890187049866654, 0.1746521657332778, 0.08547643563360907, 0.10172861628234386, 0.15024739637738094, 0.15646033018128946, 0.08693251453223638, 0.09415678039658815, 0.14773050643270835, 0.1037119391548913, 0.20754716388182715, 0.22198417747858912, 0.15948225161992013, 0.07290449109859765, 0.23139946366427466, 0.24447968287859112, 0.08537493951735087, 0.1476099222782068, 0.1705593994120136, 0.16326261829817668, 0.17980860779061913, 0.136198436957784, 0.1980908666155301, 0.17253190919291228, 0.112176578695653, 0.12915254628751427, 0.1175180752761662, 0.13571716903243214, 0.07177623367169872, 0.10626448929542676, 0.0924109150946606, 0.09531922114547342, 0.11392118234653026, 0.09765335722477175, 0.09417882960406132, 0.133504010445904, 0.18347943347180262, 0.120017034932971, 0.1579589192988351, 0.10257548099616542, 0.09977196619729511, 0.08870132704032585, 0.11431673963670619, 0.25630604359321296, 0.24169076612452045, 0.1096183065965306, 0.1465179113438353, 0.16779041674453765, 0.4641379101667553, 0.17806519899750128, 0.19028424489079043, 0.324407770531252, 0.3307753975968808, 0.45319218188524246, 0.18470513488864526, 0.1081567803339567, 0.24909821629989892, 0.1585138082737103, 0.1711541268741712, 0.19050577597226948, 0.090758322912734, 0.12042321235639974, 0.11402087504393421, 0.08256547269411385, 0.16083655238617212, 0.1411912206094712, 0.06476756912888959, 0.1418696326436475, 0.13957372459117323, 0.14529505977407098, 0.06520310591440648, 0.10449294568388723, 0.16046065458795056, 0.15037963225040585, 0.08034468482946977, 0.19126236584270373, 0.16217369469814003, 0.15798584441654384, 0.23083519394276664, 0.10362264394643717, 0.0906022715207655, 0.1268226478714496, 0.15984011522959918, 0.15121566160814837, 0.11741532493033446, 0.21881615684833378, 0.1682961013284512, 0.16596501547610387, 0.08919850661186501, 0.1555254912818782, 0.10325545896193944, 0.11083905046689324, 0.13432758656563237, 0.20928150363033637, 0.12620558176422492, 0.15720845956820995, 0.17004151392029598, 0.10832002313691191, 0.14587679965188727, 0.09089929386391304, 0.13916885334765539, 0.18734881334239617, 0.10451026741066016, 0.08759117059526034, 0.17669563967501745, 0.07741103443549946, 0.26846129447221756, 0.10407050780486315, 0.1423968988819979, 0.127147545281332, 0.21757509297458455, 0.14133815100649372, 0.059500639836187474, 0.10205831538769417, 0.12645075767068192, 0.17407262261258438, 0.14394357916899025, 0.20561850018566474, 0.22326503531076014, 0.15049292851472273, 0.08034277750994079, 0.14998253871453926, 0.12619490968063474, 0.1297922182129696, 0.19428479194175452, 0.2003324791439809, 0.12159445497673005, 0.14650514640379697, 0.24706333642825484, 0.12644419708522037, 0.1250239639193751, 0.10684103413950652, 0.1457762237987481, 0.14230506552848965, 0.3272250818554312], [0.059767646016553044, 0.08651209529489279, 0.09248082540580072, 0.07842550578061491, 0.014099869822530309, 0.033058823537430726, 0.00917996507268981, 0.03298905423434917, 0.04026929658721201, 0.0018731558043327823, 0.031449372399947606, 0.04308091934944969, 0.06581804205779918, 0.027092854215879925, 0.04216827066557016, 0.00820652800030075, 0.014437951485888334, 0.032835585516295396, 0.029597090542665683, 0.05588281092059333, 0.012247455306351185, 0.07729330012807623, 0.04083052721398417, 0.023081393883330747, 0.04743151519505773, 0.030743567695026286, 0.019779252324951813, 0.05153199614142068, 0.029415429489745293, 0.036954037568648346, 0.02500529670214746, 0.04368607769720256, 0.0012120205042265297, 0.07761596367345192, 0.028089224579161964, 0.04752785338496324, 0.03202511201379821, 0.0409954250062583, 0.02587113998743007, 0.01953475733898813, 0.008235220357164508, 0.04913316704914905, 0.059963688036077656, 0.023800497874617577, 0.10648546376614831, 0.025567108059476595, 0.0755886611295864, 0.01308496153797023, 0.05490191433636937, 0.05471466305607464, 0.04841640453378204, 0.010869132147490745, 0.02241918849904323, 0.04728533807792701, 0.04751724438392557, 0.020616261317627504, 0.03114071318123024, 0.0034383289039396914, 0.025174014699587133, 0.037686121722799726, 0.002227567615591397, 0.04917911712254863, 0.08129073758027516, 0.04419928023708053, 0.01340382714261068, 0.06610520125832409, 0.05171025259187445, 0.049681139207677916, 0.06545566619024612, 0.02892899250582559, 0.04480325114855077, 0.024814874595904257, 0.08229872997617349, 0.08641491847811267, 0.07921295415144414, 0.009139238791249227, 0.03818927187239751, 0.01460543566281558, 0.0341345740162069, 0.022557176016562153, 0.009429315559827955, 0.03833083283097949, 0.03138344000035431, 0.09065263366210274, 0.008520503779436694, 0.0283646040406893, 0.04234599276969675, 0.07734729879302904, 0.03953543127863668, 0.04191671599983238, 0.06440877783461474, 0.014313944175228244, 0.057922919222619385, 0.05516336554137524, 0.009910229109664215, 0.03206336230505258, 0.03223449413781054, 0.0616727502347203, 0.03913203690899536, 0.03129912460281048, 0.018765855238598306, 0.048177859716815874, 0.021198715512582567, 0.030020149970368948, 0.10693988821003586, 0.03058500042243395, 0.025803695461945608, 0.028143885610916186, 0.02750579260464292, 0.025352191369165666, 0.012375939622870646, 0.03253796574426815, 0.016798661090433598, 0.0940929631178733, 0.06982206978136674, 0.09621316770790145, 0.05160090084245894, 0.009361529646412237, 0.0880673251231201, 0.07390970044070855, 0.018739408806141, 0.03563812068023253, 0.01724929501506267, 0.0371099887706805, 0.01054630811267998, 0.023603706285939552, 0.0330882200069027, 0.071650283789495, 0.06400994025170803, 0.011663367458822904, 0.03368457648321055, 0.0656620945665054, 0.06842518458142877, 0.02850425211363472, 0.018944393705169205, 0.02957333439553622, 0.03789832400798332, 0.07311693829251453, 0.034348891422268935, 0.002896698861150071, 0.011531139934959356, 0.03506463719531894, 0.011752318496291991, 0.13293629715917632, 0.08704778490937315, 0.0373035111988429, 0.054795308533357456, 0.03191741154296324, 0.018686777548282407, 0.040865523187676445, 0.058345089928479865, 0.04299502688809298, 0.054862461765878834, 0.023372378855128773, 0.06874784812680446, 0.07062243894324638, 0.02865756869141478, 0.09073821071069688, 0.056641204209881835, 0.049581242419662885, 0.011222784069104819, 0.02164916390029248, 0.018818813041434623, 0.028233266166353133, 0.02221299389930209, 0.02750194827967789, 0.01653176066611195, 0.03676319058286026, 0.016304214477713685, 0.02417969451926183, 0.015591730443702545, 0.04554177343379706, 0.04812888539163396, 0.08531728206435218, 0.06106240056396928, 0.051693123823497444, 0.007246984396260814, 0.045756970284855925, 0.039288273837883025, 0.011723566767614102, 0.051853475961252116, 0.02369652112975018, 0.03420020584599115, 0.03577844596293289, 0.036207722732797265, 0.024357264483114704, 0.06009696291584987, 0.09039098949870095, 0.07723261471255682, 0.02615634919493459, 0.03227241417334881, 0.017713823799567763, 0.0278663706194493, 0.00574733725443366, 0.053629739632015117, 0.04301810397009831, 0.01481643474107841, 0.03874623143929057, 0.050261042269994505, 0.03927747187844943, 0.048874773492570966, 0.018954243860207498, 0.03983578957559075, 0.07202992201200686, 0.06844187548267655, 0.02714906819164753, 0.04551264784822706, 0.027581868307606783, 0.02869590804039035, 0.06284666087594815, 0.06260089125134982, 0.07879534023231827, 0.05904498713789508, 0.08245049175457098, 0.007512818910981878, 0.021511874001589604, 0.03956475353334099, 0.02566046838182956, 0.023678841316723265, 0.10404491113149561, 0.08824747405014932, 0.011054984479414998, 0.03210633265553042, 0.07440567031153478, 0.03849808323138859, 0.07702718823566101, 0.023177889779617544, 0.018579407333163545, 0.034933855931740254, 0.029896678861405235, 0.02695018374652136, 0.0932993994501885, 0.0635424985375721, 0.027645585396385286, 0.008961584408098133, 0.017197979213960934, 0.03601105730922427, 0.0343978100863751, 0.08503605262376368, 0.034745090670185164, 0.013807640825689305, 0.07664665943593718, 0.03636318040662445, 0.05613489622191992, 0.04030039257486351, 0.030328143111546524, 0.01462018213715055, 0.05813804185891058, 0.04873850404692348, 0.015280872612493113, 0.025971387440222315, 0.028125994285801426, 0.009013424350996502, 0.03822598220722284, 0.023443114805559162, 0.00856457158079138, 0.026574389848974533, 0.06332670425763354, 0.052594647713704035, 0.07441541471052915, 0.008120773763948819, 0.03108539905952057, 0.0013661481102644757, 0.08117338176816702, 0.09436522741452791, 0.01775438773620408, 0.035864883902831934, 0.07975170883582905, 0.11116316862171516, 0.035878071867045946, 0.041367530429852195, 0.07109649319318123, 0.03868501909892075, 0.05755406811658759, 0.04519279333180748, 0.017720347277645487, 0.017353141884086654, 0.03587966006307397, 0.06888818083098158, 0.03926220961147919, 0.025147575688606594, 0.021001064887968823, 0.037582068907795474, 0.013780838162347209, 0.04235041968058795, 0.01581717820954509, 0.054833384419907816, 0.005368213433030178, 0.03670673169835936, 0.0761588680325076, 0.05256278360320721, 0.020822596925427206, 0.08043467023526318, 0.003828251901722979, 0.01793293919035932, 0.02569444761320483, 0.028855458658654243, 0.020768190079252236, 0.036914469965267926, 0.02450387204589788, 0.011295422700641211, 0.05492183358001057, 0.0514461185230175, 0.07780832092976198, 0.05891072520171292, 0.052508476946968585, 0.044134757918072864, 0.014622450325987302, 0.06451103094150312, 0.05066189849458169, 0.037690021708840504, 0.023220179209602065, 0.0635102076921612, 0.028627589636016637, 0.04738695664855186, 0.0029543966684286715, 0.02782715924695367, 0.03430135315284133, 0.04309818541514687, 0.0818484764022287, 0.06283856404479593, 0.018155978686991148, 0.12653163692448288, 0.05986558353470173, 0.022191284224390984, 0.029379123625403736, 0.04409904948261101, 0.028960509662283584, 0.03680686226289254, 0.00777104038206744, 0.07587800966575742, 0.037951899648760445, 0.032874362732400186, 0.03224175234208815, 0.02388742934272159, 0.04061584244482219, 0.055496474815299734, 0.027361270476831123, 0.010974047709169099, 0.09939887371729128, 0.07134429630241357, 0.03139472064503934, 0.08955815879744478, 0.043261446771794, 0.023800611052138265, 0.011057816700486, 0.00725379963114392, 0.09092132080695592, 0.03578689160349313, 0.045964189048390836, 0.016339292087650392, 0.06577071530045941, 0.12739873258396983, 0.1644642889732495, 0.11719206464476883, 0.10164582228753716, 0.1566848298534751, 0.1017978809250053, 0.1794767045066692, 0.12140944498241879, 0.10046415991382673, 0.13996016088640317, 0.12816639529773965, 0.14786452346015722, 0.18811862828442827, 0.1440113817807287, 0.13242473476566374, 0.14178971818182617, 0.14541873126290739, 0.1624760901904665, 0.14128832321148366, 0.1877410532324575, 0.12342823509243317, 0.15942586323944852, 0.12084023997886106, 0.10864853480597958, 0.13607240543933585, 0.14553322980646044, 0.14740489656105638, 0.11476053652586415, 0.12461887003155425, 0.09510632866295055, 0.1501882026786916, 0.10763719532405958, 0.057475148132652976, 0.17886199842905626, 0.10181187040871009, 0.1452129485551268, 0.15653482696507126, 0.19728403334738687, 0.08703191779204644, 0.05462295586767141, 0.15701161231845617, 0.13621679769130424, 0.1275416256976314, 0.1150971079187002, 0.17777387634851038, 0.09520477455225773, 0.13404534780420363, 0.13031727285124362, 0.18502326391171664, 0.19747193029616028, 0.11932249602978118, 0.13708221609704196, 0.1023954211268574, 0.11383892269805074, 0.14515425951685756, 0.21435721486341208, 0.1436712109716609, 0.06454872462200001, 0.09780879263416864, 0.08884240931365639, 0.11107799233286642, 0.20068660232936963, 0.13572122115874663, 0.21114384901011363, 0.17685505299596116, 0.15374010661616921, 0.08084132263320498, 0.1752719926298596, 0.17478404537541792, 0.06900256805238314, 0.17013097240123898, 0.12511052802437916, 0.2919154765550047, 0.1546778398915194, 0.10130186652531847, 0.10518611903535202, 0.08596752959419973, 0.09858703837380745, 0.13948940177215263, 0.11059912154451013, 0.0904025298950728, 0.16264282108750194, 0.09256059885956347, 0.2162120200227946, 0.09245619352441281, 0.10166498454054818, 0.15218322922009975, 0.23342175671132281, 0.1532513726851903, 0.11781462264480069, 0.23798792419256642, 0.13785154122160748, 0.25308084790594876, 0.17637990036746487, 0.15545299829682335, 0.18893423373810947, 0.12041334179230034, 0.10282108734827489, 0.10701223276555538, 0.18216209165984765, 0.1221714005805552, 0.11712197621818632, 0.16800737619632855, 0.1344836750649847, 0.202576718875207, 0.13186242431402206, 0.0720311539771501, 0.053902345316600986, 0.15476149477763101, 0.19946787710068747, 0.12052293473971076, 0.10632944948156364, 0.1176992038381286, 0.18886120640672743, 0.1226203702390194, 0.18081895279465243, 0.15575708588585258, 0.1251087023410946, 0.1994064569589682, 0.16644059855025262, 0.09979750349884853, 0.1431511584087275, 0.10479110351298004, 0.08521251307683997, 0.17630022339290008, 0.14709179929923266, 0.11642399374977686, 0.2116249388200231, 0.19130383705487475, 0.10706283239414915, 0.08746174004045315, 0.12493014161009341, 0.13612570648547262, 0.10337746803998016, 0.21749048813944682, 0.1544542159535922, 0.1901638091658242, 0.15375101618701592, 0.14034362859092653, 0.06933724696864374, 0.08837886387482285, 0.10889411147218198, 0.13399773160926998, 0.14243341254768893, 0.20012844790471718, 0.13121549418428913, 0.278037641546689, 0.09547229652525857, 0.11707140627549961, 0.1576388903777115, 0.16231354500632733, 0.14901019167155027, 0.1401935811736621, 0.08263042545877397, 0.19918105186661705, 0.1611744670663029, 0.17678775504464284, 0.1152658426144626, 0.13732985593378544, 0.11309048160910606, 0.12597425433341414, 0.1327587160631083, 0.06620502012083307, 0.2345480103394948, 0.12961439962964505, 0.10823536635143682, 0.2043702226364985, 0.11184696122654714, 0.08403148895013146, 0.15579628612613305, 0.06802383853937499, 0.12396478559821844, 0.10018235901952721, 0.17657697026152164, 0.1624134974554181, 0.12830597843276337], [0.03602314318413846, 0.042642406551749445, 0.09501292195636779, 0.009405770924786339, 0.03192029849742539, 0.06144398692413233, 0.07768221519654617, 0.03093230141530512, 0.008662509098940063, 0.02342972089536488, 0.009850990882114274, 0.029148204375815112, 0.026178411389992107, 0.04177709575742483, 0.02690030771191232, 0.024728295647946652, 0.04837840286199935, 0.026184537819062825, 0.04915051846182905, 0.054956551248324104, 0.055677080163150094, 0.05869221095053945, 0.041188899194821715, 0.014989735500421375, 0.058988431774196215, 0.07091344246873632, 0.0160582593161962, 0.08041472872719169, 0.015648744083591737, 0.027515713263710495, 0.016976195802271832, 0.011061520017392468, 0.08612061239546165, 0.02860672044334933, 0.033177333389176056, 0.02753552489593858, 0.04472944085136987, 0.03327810591144953, 0.015401064356410643, 0.05738435378589202, 0.044622408313443884, 0.07021888872259296, 0.050682374348980375, 0.04791258274053689, 0.018018416049017105, 0.01877135640825145, 0.01892699219752103, 0.01787676603271393, 0.010510621941648424, 0.061762650293530896, 0.11205908929696307, 0.028703715433948673, 0.01447883454602561, 0.0377150320855435, 0.040707928128540516, 0.030372271212399937, 0.016011350016924553, 0.048174256589845754, 0.040685767598915845, 0.051226476207375526, 0.03933808307920117, 0.05198639089940116, 0.03331192558107432, 0.052390093260328285, 0.046280815222417004, 0.01801504669856513, 0.03258441676734947, 0.027707033368642442, 0.013978089882584754, 0.012874190670117969, 0.04621887928806245, 0.03647040590294637, 0.0312629560357891, 0.07868841159506701, 0.026010890105681028, 0.06261305505177006, 0.033016762317856774, 0.012464488972909749, 0.056829164241207764, 0.02920368548075203, 0.04655985161662102, 0.04129278502659872, 0.00528363364537654, 0.09236527301254682, 0.03158302577503491, 0.024290396977448836, 0.04026713693747297, 0.01145259937402443, 0.025519595765217673, 0.013434871179924812, 0.09639712385251187, 0.16893348743906245, 0.06501237396150827, 0.07534750024206005, 0.02192919662775239, 0.01615540088096168, 0.048040439942269586, 0.04651699629903305, 0.03453439494478516, 0.01316599757046788, 0.03345936434925534, 0.058004455277114175, 0.025350918585900217, 0.008598812419222668, 0.06627255555940792, 0.011374126534064999, 0.01470527957280865, 0.05758736086136196, 0.0301913949806476, 0.024411534031969495, 0.03501138438878115, 0.06517713816720061, 0.043768578543676995, 0.03684774346766062, 0.05037953356804792, 0.04246642849466298, 0.04904643967165612, 0.02514207266358426, 0.052575333320419304, 0.025309417687822133, 0.013482998529070755, 0.012946062106493628, 0.04369236368802376, 0.026314469323551748, 0.012854242668254301, 0.028500845655798912, 0.06831946564489044, 0.051606459528557025, 0.03384208248462528, 0.014538348295900505, 0.05967052486084867, 0.019752265980059747, 0.06480166339315474, 0.016652125887048896, 0.07091589155606925, 0.07732308251434006, 0.05152635581907816, 0.03573566486011259, 0.046616069303127006, 0.04274913480912801, 0.07941294068587013, 0.02394941166130593, 0.04819880683498923, 0.07332066525123082, 0.016742977750254795, 0.02924069824075559, 0.006048653385732905, 0.041949971637222916, 0.03911611784133129, 0.03315918416774366, 0.011451815480540972, 0.04913220967864618, 0.04658497331547551, 0.04937553021591157, 0.031309184414567426, 0.037457350990734994, 0.05294437738484703, 0.015049973771965597, 0.08777545328484848, 0.033152935284306295, 0.018520273006288335, 0.02443407862301683, 0.07694442392676137, 0.03562187877832912, 0.04145948252698872, 0.06015094302711077, 0.03888169194397051, 0.016413785160693806, 0.023493725566368084, 0.027806048856291454, 0.012329278943070676, 0.014971268083172617, 0.01641136947000632, 0.012451441089069704, 0.04574628335831221, 0.02946242042526137, 0.02607891907246085, 0.03194579498085659, 0.04650578986911569, 0.03544446837622672, 0.06558257344295271, 0.031388412389787845, 0.028438785411708523, 0.1114963335567154, 0.0152773121590144, 0.003386478292668471, 0.010836732762982138, 0.045367977290879935, 0.09603869621059857, 0.027092030431958847, 0.025037934501597192, 0.030507980336551555, 0.011547461617738008, 0.04509503392910119, 0.06385037107975222, 0.01433649526006775, 0.026489302617846988, 0.025016640429385006, 0.04285705050278921, 0.043533636853680946, 0.03552503963874187, 0.03486429814074654, 0.04063740183482878, 0.04289113734557759, 0.06232375104445964, 0.12408951093675569, 0.04488888385822065, 0.012929773820360424, 0.07943186545162462, 0.02371009501075605, 0.03374916559550911, 0.022181901622388978, 0.01746069021464791, 0.025055395381059498, 0.012872713796241442, 0.08105155822704546, 0.13473119615809992, 0.03501863146084361, 0.029669472205569036, 0.030813856501481496, 0.0393939816422062, 0.027953042335866485, 0.02057914280158002, 0.04265154981112573, 0.0841243242030032, 0.03606865167967044, 0.09346979655674659, 0.017361450227326714, 0.021170205909584183, 0.01619979986571707, 0.07571864829515107, 0.028521343774627894, 0.04095632495591417, 0.07681244038394652, 0.03720908032846637, 0.03428738593356684, 0.02567762683611363, 0.05904834906687029, 0.0033041335291272844, 0.006897018629388185, 0.03391048623598181, 0.03475188132142648, 0.08616292965598404, 0.06319954467471689, 0.0060297109939710936, 0.01500177870184416, 0.06069098162697628, 0.02349501875869464, 0.019524909039319027, 0.03925787175830919, 0.01537995118269464, 0.06454001922975294, 0.026445976036484353, 0.06640497696935199, 0.049452197781647556, 0.10779570322483778, 0.04001526685897261, 0.011334238879499026, 0.02679726792848669, 0.04500239163462538, 0.020179093662591185, 0.04823551716981456, 0.0312376821966609, 0.031824446414248087, 0.05612809443846345, 0.07562985774711706, 0.07864041690481827, 0.12685516878264025, 0.08315816667163745, 0.0681725204049144, 0.03432575496844947, 0.027576098109420855, 0.06279465116676874, 0.007837585053493967, 0.04643822103389539, 0.06812954263295978, 0.13129058468621224, 0.06405645064660348, 0.045306167521630414, 0.0180921168794157, 0.07939097311464138, 0.04364207576145418, 0.013779206365143182, 0.014097566381678917, 0.012979157254449092, 0.03408195945667103, 0.022628945407632273, 0.05198467282752972, 0.057496503432048485, 0.056838507880456746, 0.04669142697821371, 0.04797314941242803, 0.03939775546314195, 0.0799778634973336, 0.01950991394551238, 0.06756550297723152, 0.020733058663608972, 0.05757682978583034, 0.004363592706795316, 0.02687058655283181, 0.012310061956668505, 0.01609809223737102, 0.04277409694623202, 0.06071775089367293, 0.04608332230418455, 0.01564034668263048, 0.08410655718762428, 0.03276256931712851, 0.0302831095905276, 0.017505508512840606, 0.11309431109111756, 0.0646021963621024, 0.008488397543260362, 0.023824677045922726, 0.040488682861905545, 0.06131520574854221, 0.06781362520996481, 0.0366736578871496, 0.05912504631851334, 0.049995713343378156, 0.030027992615941912, 0.03690207238832954, 0.05027820072427858, 0.029046292656857986, 0.007077421741996659, 0.017774796797311865, 0.025867338335956447, 0.05919324597925879, 0.016432257216365542, 0.00602854535827646, 0.02344461579923518, 0.01318735472523258, 0.03673721170343924, 0.06909934410941787, 0.08554562606150284, 0.10386835419922136, 0.010880869212996913, 0.025005556453834288, 0.03488181653665379, 0.03314829315058887, 0.03603064629714936, 0.018406559283903334, 0.033017348614521325, 0.0279143968509743, 0.0035754418468059157, 0.04368638197774999, 0.04226129887683783, 0.022235811229620595, 0.1424733697785996, 0.05991223493765574, 0.08608579082647339, 0.011523322336870478, 0.14205493207555264, 0.17386876948876306, 0.1947073856717907, 0.1265966342180036, 0.1571511509246193, 0.12222277946420945, 0.13816471269819885, 0.18801929923938587, 0.13123217766406015, 0.12821411539334804, 0.09068440500413999, 0.12879545451141894, 0.12459924764698371, 0.15705893165431917, 0.08358695733477362, 0.06444181082770228, 0.15343106148066, 0.12460297322832048, 0.2068841439904645, 0.12146906170528382, 0.11999943861155771, 0.12377443214063533, 0.11843229731312022, 0.09481010041781701, 0.11739622204913758, 0.12211363922688179, 0.2138004853622988, 0.15362306992756203, 0.12124479952035472, 0.2300370141165331, 0.15664766309782863, 0.06481420568889007, 0.24244155240012333, 0.08808477301499806, 0.1600784040056169, 0.15644688246538863, 0.07571955371531658, 0.10530478102737106, 0.10731030895840377, 0.17033691838150844, 0.2437613729853183, 0.09732001417432912, 0.10410364469862543, 0.106197332352167, 0.15338193130446598, 0.13201002264395356, 0.11915840717847459, 0.1387992934905924, 0.1716595294419676, 0.08809092541923746, 0.20670408412115648, 0.2094297402072698, 0.17754087166395038, 0.16553911176742986, 0.13596667908132076, 0.12966685462743044, 0.10265386663377285, 0.23500493582105264, 0.15870004281168804, 0.1702107532764785, 0.11803046145359986, 0.11174672676133923, 0.09179581567877904, 0.15203640272375196, 0.08489842133712955, 0.1134162102243863, 0.2525161922676489, 0.14727165136719123, 0.08953173834015615, 0.08383743959711865, 0.17282312794122845, 0.11596093070693314, 0.08908578922273591, 0.09289530746173114, 0.10954310477245599, 0.2212102065095678, 0.12396166115649976, 0.11469021061202511, 0.15969159663654864, 0.2929539489559829, 0.10648781637428328, 0.1158792499336414, 0.10694402197259478, 0.2703673078212887, 0.23522651143139228, 0.13452545797917992, 0.10971284878905863, 0.17706494720187038, 0.18679551256354898, 0.15372735651908442, 0.213110807526391, 0.20788264431757852, 0.3303660883102566, 0.21664978325134143, 0.11859359568916261, 0.10166734457015991, 0.2827037317911163, 0.1459672229248099, 0.16928044147789478, 0.17895769095048308, 0.2428901509847492, 0.2369825664209202, 0.1626049418700859, 0.12959449522895738, 0.2071189892012626, 0.09845400840276852, 0.07579762765089981, 0.11492913763504475, 0.09666385914897546, 0.11644645855994895, 0.11147426950628869, 0.13284636370372027, 0.09491967110079713, 0.1263143212418072, 0.1214709690248128, 0.17492607759777457, 0.22395174455596134, 0.15194743406027555, 0.18375910440227017, 0.15870792442001402, 0.10610529119730927, 0.08553696519811638, 0.09497367718722671, 0.148112757015042, 0.05982030139421113, 0.12439538710168563, 0.13291774346726015, 0.21100306359585375, 0.14400591957382858, 0.10328947901143692, 0.15512283163843676, 0.08780272721196525, 0.08426220781984739, 0.06333762867143378, 0.14093425939790905, 0.1480646213167347, 0.12687140697380528, 0.12374988189549185, 0.16797795746242628, 0.20122995832934976, 0.20903491764329374, 0.13486654905136675, 0.14393443590961397, 0.18354140280280262, 0.09468433607253246, 0.1389453184674494, 0.17467742844019085, 0.11102688062237576, 0.15938829572405666, 0.08717621356481686, 0.08085129709797911, 0.20074451953405514, 0.19116731156827882, 0.16357178217731416, 0.22841865720693022, 0.13958175462903455, 0.10318704036762938, 0.13765242299996316, 0.1809047895949334, 0.24393312080064788, 0.1449096476426348, 0.12218247342389077, 0.2002464939141646, 0.10755046794656664, 0.24453564081341028, 0.21474880166351795, 0.20216583623550832, 0.12971000309335068, 0.1551422759075649, 0.2068538049934432, 0.1200047301244922, 0.1397311786422506, 0.17935095500433818, 0.20406119234394282, 0.22089534293627366, 0.08325456423335709], [0.01896482503070729, 0.09240894098184071, 0.04631755895388778, 0.04824760304472875, 0.010607006515783723, 0.06406666259863414, 0.03716847742907703, 0.04423366022820119, 0.06392272305674851, 0.038596755475737154, 0.0672275957185775, 0.0557290230790386, 0.08731676891329698, 0.031503686477662995, 0.011693194373947335, 0.08695661948877387, 0.022053495231375564, 0.02887783255573595, 0.02163269935408607, 0.07933894856250845, 0.0690500951895956, 0.062232867639977485, 0.008482797111355467, 0.060263812556513585, 0.037308350001694635, 0.046868202844052576, 0.04629248920537066, 0.0635303718445357, 0.005337782131391577, 0.03062567197048338, 0.0435063146869652, 0.0032140637040356523, 0.028272182535147294, 0.042125945983571, 0.0452150095225079, 0.03801582824962679, 0.04570165430777706, 0.06472502180258743, 0.057963358849519864, 0.06357754275086336, 0.013112051783537026, 0.020481632018345408, 0.025683068633952644, 0.02648249897902133, 0.05516827113751788, 0.02672731123311678, 0.027044104390370194, 0.03705295101099182, 0.060188050410943106, 0.04764120159961749, 0.014192355338309426, 0.03761618543649092, 0.017407927225576714, 0.04891087897703983, 0.04929884409648366, 0.07241605402668938, 0.02358978359552566, 0.018304096520296298, 0.014854709152132273, 0.030655997979920357, 0.037192099989624694, 0.02740310719673289, 0.06085523004003335, 0.017973530957533512, 0.025470012878940906, 0.04983480088412762, 0.01622099745873129, 0.022333435190375894, 0.06576413987204432, 0.007187574547060649, 0.020979941509722266, 0.030092292290646583, 0.022848457847430836, 0.004521586206465145, 0.020839306380366907, 0.027976707569905557, 0.07507586677093059, 0.05992989805235993, 0.050522311648819596, 0.02969984088849742, 0.04577966516080778, 0.029320722169359215, 0.057253884224337526, 0.04514786371146329, 0.06141077210486401, 0.08194936395739205, 0.06651596515439451, 0.06832615239545703, 0.08926289534429088, 0.06745113059878349, 0.047831339834374376, 0.04635735662304796, 0.06257469343836419, 0.04549142984615173, 0.04244173353072256, 0.07478448475012556, 0.029249411054479424, 0.036449217586778104, 0.039934105589054525, 0.06191054548253305, 0.02908672671765089, 0.03925931523554027, 0.02087201468384592, 0.02475292010785779, 0.08220605799579062, 0.012803882382286247, 0.053622440609615296, 0.019494345542625524, 0.04678379467804916, 0.02002375287702307, 0.026230350595142227, 0.08037523162784055, 0.026114566280739382, 0.015406331749545643, 0.096048915584106, 0.009452067024540156, 0.037573682639049366, 0.021048658818472177, 0.017932551418198273, 0.04636499332264066, 0.021581123801297508, 0.05376078435801901, 0.0505370729661081, 0.012833976470574271, 0.0583734770771116, 0.02892883294407511, 0.04020709719043225, 0.0327063998702215, 0.025741551726241596, 0.016887965575733688, 0.011828753213194432, 0.029900730987719726, 0.026465442570042796, 0.05943633274000604, 0.06743256948539056, 0.09998340407037176, 0.028079376279492863, 0.029653141245944425, 0.037431257078424096, 0.04105647407413926, 0.02349025602597976, 0.059041484200861305, 0.03579151518351864, 0.05965234224277083, 0.02598392231448088, 0.07209852614323609, 0.024489157112839166, 0.018653334518603515, 0.015287670685211197, 0.08856160289724357, 0.017394538881490007, 0.027026732568629086, 0.04232739454891998, 0.021310106312739663, 0.056471890638931654, 0.05328874132828787, 0.038615598605247214, 0.04211925552226603, 0.02297915933013428, 0.03777340200031176, 0.06054681201931089, 0.05555024341447279, 0.04447753737622406, 0.0073029237773880595, 0.04186826117802411, 0.032881520746741444, 0.0868349517986644, 0.0439641567209037, 0.040084576030494645, 0.05091893021017313, 0.07045573031064123, 0.013025452426518314, 0.05112085746077355, 0.09151013335213065, 0.022774931421736255, 0.042863028502324596, 0.0547559932601871, 0.047219487314578146, 0.0568637260585092, 0.08060445878072642, 0.03847882820991799, 0.028701552073471248, 0.024818978672556113, 0.01222563430928858, 0.10708354573580436, 0.06647797461482696, 0.011519348136062035, 0.04076261328009423, 0.007183343377619167, 0.052698800718644634, 0.0201472870685393, 0.037548802138189785, 0.024552458598918747, 0.057436129718553275, 0.08160063618561253, 0.03801782462687697, 0.02487968078639824, 0.012315796902839793, 0.031017468427307904, 0.024018763506319374, 0.019643942105176393, 0.030085045218584128, 0.039667867531534284, 0.07713854007306509, 0.013134522159816697, 0.033469791524112225, 0.017855945079645608, 0.017878098187793512, 0.05024216945457738, 0.056138807340175845, 0.005888355981369386, 0.017491262988187373, 0.05577429779805243, 0.01640986662096111, 0.05112614897370804, 0.09063301869900897, 0.024873949550965335, 0.044499549476313405, 0.04113575771043543, 0.06911951568326913, 0.010371095395385055, 0.019833132246276364, 0.012621847472473746, 0.03432072320720181, 0.05685028947482351, 0.05527372661163099, 0.027296447588014416, 0.004849732367802062, 0.040991643763845786, 0.09075333568034694, 0.06394585579982959, 0.0054403571448347066, 0.07776233003824018, 0.023759676041663624, 0.01480665230701561, 0.037300167823559605, 0.03488336762529798, 0.02966658525110688, 0.05169485302758403, 0.022287362662609667, 0.01586191116075497, 0.05329902007360943, 0.04290015443984885, 0.02621740011818474, 0.049615433163126, 0.026486541828489862, 0.05148371943505481, 0.059585125927696936, 0.02890642936108634, 0.02821267713443376, 0.051655597126227804, 0.00505305207298079, 0.055003718443913385, 0.0471072448999621, 0.0363805429515196, 0.02497510242392309, 0.03323376258776989, 0.05631831802020315, 0.02314749512152048, 0.03373142455529887, 0.029033325481577776, 0.048626150310155936, 0.08563404553569853, 0.11980708135524765, 0.09349597210530192, 0.01747610091115348, 0.06741584889823571, 0.028031088440911844, 0.059277219988871366, 0.03160452579322737, 0.03243042854592204, 0.05905981895921286, 0.05936511624895502, 0.0326185592712136, 0.1047727873083204, 0.021553799779212568, 0.032764561983640306, 0.06325404057861306, 0.03335307766974438, 0.05400646863563452, 0.14685892820125446, 0.021384009378380142, 0.04911109557724558, 0.04236551496433094, 0.01963148886716226, 0.07037312185275368, 0.019051557974307798, 0.03396639593120199, 0.009553460167808225, 0.0647091175778769, 0.0182253509410657, 0.05540888283576351, 0.007816556299076183, 0.02983973201480694, 0.0503851813118672, 0.022674700667266734, 0.062170185847207904, 0.08330664073582739, 0.07363501674262807, 0.0286980658347602, 0.05889379681320861, 0.013864235152141191, 0.027528925347723998, 0.037578020492219366, 0.012885778378404211, 0.03899023475241847, 0.02222119648649823, 0.02896087331464514, 0.03454765712376684, 0.02404330447461689, 0.01054278940500808, 0.0036926290522387717, 0.0262294488857151, 0.04671025897550862, 0.09331050197943114, 0.02845094735675957, 0.02445059140882222, 0.11015301657607779, 0.014273521246650489, 0.04188687424175441, 0.030444586082012393, 0.02610981468023965, 0.08063283850788139, 0.13193512510042638, 0.03214652737369761, 0.014858503382129129, 0.10588177116005681, 0.14304878655821085, 0.04038656334159896, 0.03550678651663475, 0.034058600358548574, 0.022327368133119307, 0.0037935486125206808, 0.014385129125003004, 0.022999464490567334, 0.05001604076824151, 0.005205776324146427, 0.027680596213031095, 0.08612844947492704, 0.06547037555719726, 0.05176260368898511, 0.014470750702457735, 0.020321359661465976, 0.0112463806544838, 0.03695564802910667, 0.05357263136829715, 0.040390908616245724, 0.012611205074790632, 0.03610821186157409, 0.06523988675326109, 0.05165297363419086, 0.044969584996579215, 0.13068224623566493, 0.17540871107485145, 0.11616790085099638, 0.15078282624017447, 0.11869500274769962, 0.18165566492825747, 0.1161309122107923, 0.07295506846276112, 0.22293319139862433, 0.20763246633578092, 0.13459680805681273, 0.25428475986700505, 0.12642062647501007, 0.1377096722717397, 0.16366254683816805, 0.1645008026389405, 0.10382924301666208, 0.16322548122843727, 0.12637010106118396, 0.23973078379640356, 0.12307331780903041, 0.20796095574041829, 0.16365113260690123, 0.11508931536809541, 0.20504253421677276, 0.2158135164063424, 0.19388063316000625, 0.14302868919912726, 0.11556651632417925, 0.09902358448016457, 0.16556551738176495, 0.10946310867439024, 0.08165834558894858, 0.20870956010185182, 0.13430584163870662, 0.14069521363126114, 0.2016906687640585, 0.12760778074152768, 0.14199921162799, 0.3144467534730211, 0.09854897361947224, 0.1439841598039493, 0.12479333410738036, 0.08484841542667709, 0.2219739358406514, 0.07462629597284831, 0.1683149964082986, 0.08315597733599134, 0.1707473854185082, 0.19226527452701703, 0.07940599418361671, 0.10120263395947404, 0.12365858288831078, 0.21983718877891079, 0.13271344505483285, 0.1627960300538689, 0.20417589868884534, 0.11226366230403073, 0.06890644508530386, 0.1649449483375065, 0.10286802076734602, 0.13973236607853323, 0.11717800094629638, 0.03717041443451308, 0.1527945214184001, 0.12474056740757078, 0.13769629877060652, 0.12153259696788155, 0.21990870212903246, 0.13793602731311694, 0.15020288235973567, 0.10714524789364077, 0.09898593532852829, 0.06615251317271031, 0.14203762519173324, 0.12323680552071892, 0.17906202207086608, 0.1549849406001158, 0.15691302542109042, 0.1763444850803353, 0.11355343332979828, 0.18218462326331064, 0.16881297749932855, 0.14627128082793206, 0.17135330446762964, 0.18647533521289006, 0.15598118479829282, 0.22367679368471727, 0.2600060059921816, 0.12408263122779317, 0.12428648435161449, 0.13913698552642018, 0.16857238806551322, 0.19657313008792698, 0.11037124510039575, 0.12239538074936718, 0.19732220942387357, 0.1007445581490174, 0.22548398264916614, 0.1729945937404409, 0.09154951170785353, 0.15075365983648226, 0.16737037600250915, 0.1397953150444664, 0.2677843370474875, 0.2777240693103522, 0.16946609714068472, 0.11022400300134905, 0.16702241264283657, 0.2295702329138294, 0.08504803088726476, 0.16612951993010938, 0.22590249456698075, 0.18925381737062708, 0.145564355480019, 0.1458362487028353, 0.0869577401317656, 0.1316188959754072, 0.17832054232712835, 0.13357700809137896, 0.14906755968695506, 0.12470577552448958, 0.21282010828144848, 0.11486707182484679, 0.12466384418075904, 0.1785616364213638, 0.1237792857864406, 0.11199351312825456, 0.15888275956967846, 0.07905411228421144, 0.13640619377838448, 0.09624159938539378, 0.18266700441017747, 0.14654859172878787, 0.0932409924280364, 0.32147224992513657, 0.13768780860118568, 0.0850997214729432, 0.1744622501428239, 0.12665435846429318, 0.07504370209062472, 0.19588879571529105, 0.11450525256805122, 0.0951537667424418, 0.11940140117076226, 0.11192953257705085, 0.18572980334283784, 0.2152887437841855, 0.1444785637431778, 0.18073989922413602, 0.17966138053452596, 0.22704736125888303, 0.15674538910388947, 0.09882285579806194, 0.14427479967707768, 0.11327157306368463, 0.11375022120773792, 0.10958499158732593, 0.1772749304655008, 0.13737531990045682, 0.09763567926711403, 0.11816527257906273, 0.26194099278654903, 0.1182231749407947, 0.2169840910937637, 0.162151831027586, 0.14460138918366283, 0.15580875420710072, 0.20590982283465564, 0.13511396624380723, 0.22472556709544733, 0.10117961996002123, 0.14285615470726043, 0.23261001042556018, 0.09668379323557019, 0.1378226123051718], [0.024707897719054017, 0.07904031575890258, 0.019463431381154805, 0.04001857683761045, 0.04476988789974712, 0.06050239819160197, 0.02986098341352772, 0.026464663314982317, 0.06591751211090013, 0.03548667431459762, 0.010396350680821342, 0.004278567166693392, 0.0719824839325156, 0.057923127023968846, 0.06848935066955164, 0.0036678605692941346, 0.08394329954171553, 0.04196451773168519, 0.0217212208735873, 0.0493862134317169, 0.08920845881220885, 0.07478619168978184, 0.0914995429047849, 0.008417277531407308, 0.0447253182210261, 0.04117723263334483, 0.05523235558939632, 0.021019876476202626, 0.03025125104613835, 0.013633218495670008, 0.017741402007231954, 0.0617878573393682, 0.01393043843563646, 0.026563717765384354, 0.040219220172730274, 0.03374323212483432, 0.07097782377968542, 0.018594947905512527, 0.009020578654599376, 0.027788792067440227, 0.04726719998870976, 0.030385089958144818, 0.024016089919314254, 0.03449299794738181, 0.022627585422014818, 0.06260088382987306, 0.04343227803474292, 0.033163009939016774, 0.02526438416680321, 0.03356322420586366, 0.024130115343723446, 0.0449037898943061, 0.07214200115413405, 0.04080689723195974, 0.04926364403218031, 0.008790958163444884, 0.06438246127800085, 0.02808532830385957, 0.03877378738252446, 0.014386647744686343, 0.06650687384535559, 0.031918706590658985, 0.03439880456426181, 0.051939680124633014, 0.026867232045333367, 0.03177423270244617, 0.12634130573133007, 0.025308664407930337, 0.014910093777871225, 0.022269046457950026, 0.005809147487525479, 0.035065219781245105, 0.024081402625597548, 0.030421939445659518, 0.07743027090327814, 0.029750867252005264, 0.03151744960632641, 0.04934988159220666, 0.05109617362904828, 0.015598712197970599, 0.05970476384391077, 0.06382780979038216, 0.05040720454417169, 0.06159359276352916, 0.070094853581395, 0.06263810253585689, 0.020925844510202296, 0.033447070672991686, 0.048984722670866176, 0.04863440670305863, 0.02545444447605405, 0.04326823000155855, 0.013086332655802835, 0.0382740177155938, 0.04523308452917263, 0.048580979491816834, 0.03132090292638168, 0.05897186703805346, 0.010985499975504354, 0.04666472079406958, 0.003665026029011642, 0.033592880427022465, 0.057473760316497646, 0.024167630908777937, 0.04061835461470764, 0.03272961424954701, 0.037710519827669486, 0.08405341941397637, 0.02148465016944101, 0.018749143928289413, 0.03300988260889426, 0.019275903650850523, 0.026218910388706718, 0.04850961828196887, 0.040207078636740334, 0.0871489396377001, 0.03303064419014845, 0.03936480039556045, 0.015696332447987515, 0.027128013462061062, 0.06398389086825773, 0.09612861482310109, 0.016110595570353325, 0.036295028985477984, 0.014799706732446793, 0.03621979005401954, 0.011096008547610836, 0.02060824797808891, 0.020463351065700408, 0.041713534519658424, 0.0270067446763278, 0.06569482327904552, 0.019526660507835913, 0.037431027012644336, 0.016584753720962908, 0.020529107205220498, 0.012263923563295975, 0.03762986321817152, 0.013500301702151773, 0.04874964739428833, 0.0310129320496344, 0.048698402097215876, 0.04749413019453641, 0.03389619247172959, 0.046245963967521675, 0.039785104600014165, 0.08714709911146201, 0.0629228497564327, 0.07944879384012893, 0.025678092533780728, 0.05510995688382536, 0.059357605714467354, 0.04984009610780049, 0.03049909126275452, 0.04712434769317042, 0.035033730455324985, 0.016228315034823027, 0.03192629876139108, 0.022354656903189607, 0.020752538184751756, 0.024243137013399974, 0.04719580909295473, 0.05347871257981751, 0.0466552880970994, 0.02922171595855616, 0.05685728792741429, 0.035493242321535945, 0.04006447867141105, 0.025708010361995548, 0.014477930053544696, 0.02311354186531389, 0.005976928523523384, 0.034898522280855104, 0.0246514870741521, 0.03878453739162069, 0.02698141888686223, 0.027327703137416393, 0.04005476766906213, 0.038225677926675417, 0.06313773861620575, 0.0715475260221865, 0.05099533431348391, 0.0321579712908715, 0.025398377074452583, 0.0269698061310919, 0.05160388427611906, 0.008181599259842187, 0.048766278923721984, 0.022139014763524756, 0.06021855639119167, 0.033917896580533125, 0.0217230799535173, 0.10254618842736818, 0.08108991241897456, 0.030687084690725897, 0.04271592741133645, 0.07837114346330054, 0.019104719867755193, 0.027071484073530883, 0.04101398983038962, 0.056260486162500456, 0.052061288442928344, 0.03668341341835912, 0.005028597843192983, 0.053956292031216435, 0.053649603214580566, 0.04729586544272024, 0.06146787665784359, 0.045342536468524486, 0.00866012402184424, 0.024205821828218177, 0.0352254346216796, 0.06953538555535488, 0.0615078672853997, 0.017060190220945515, 0.05046764876169618, 0.007313384348890395, 0.03627870915806852, 0.04110317000595387, 0.03940231224987656, 0.02759806939138798, 0.036077932236366905, 0.033054003288270906, 0.007200132613434107, 0.02019795163505478, 0.03609857136325445, 0.021443757832457777, 0.056887990576797165, 0.04402572158141993, 0.018953112085000612, 0.011944856651098235, 0.04301440807466861, 0.019593385150074027, 0.027776134738815017, 0.06473971632658504, 0.05575142480665818, 0.03776370584091637, 0.0662980334891472, 0.012948762596352026, 0.0175429795490345, 0.038780195827712305, 0.00915304830414243, 0.046946350994403474, 0.010029622117144754, 0.05413392878836021, 0.031242799304891378, 0.036035941520822234, 0.0420249137096107, 0.06874205195344985, 0.05342145588656422, 0.05921227093494963, 0.02397113432380138, 0.013202429599914467, 0.04171983164269477, 0.026199970779998694, 0.1138664637983311, 0.03897001864970662, 0.051708204264286906, 0.02815994568663882, 0.041280428267782554, 0.027828337406390347, 0.030975696645327844, 0.023204835306387395, 0.026541861516307108, 0.014357829222717555, 0.015977682487573475, 0.03642858217062894, 0.11400322677218355, 0.11972693682764657, 0.022367852288880385, 0.05686996009899303, 0.05290659835736733, 0.02324620076251449, 0.02296491937158862, 0.06434950992115773, 0.08552734696422704, 0.06897896775626577, 0.03167019101965707, 0.031103765359148383, 0.027938540770264808, 0.04624807166692335, 0.05233295159996487, 0.03312076318252366, 0.05714207225537393, 0.025101573664869647, 0.019032698146475013, 0.04594018799252808, 0.04003845155239105, 0.007240737832034938, 0.03665531941805966, 0.052540426404448226, 0.02532717913709348, 0.006593398129552952, 0.014985421767050866, 0.08743573518586345, 0.034085306542692706, 0.015710147526988294, 0.04182015145488549, 0.033244935621041805, 0.025961405553971417, 0.10785553517052904, 0.06025940048857592, 0.04850151774007827, 0.052505241183098406, 0.06227720354218036, 0.006361208415910369, 0.03640511175035499, 0.11528132381499745, 0.018597604794194922, 0.04995479503122624, 0.023195495377876796, 0.03216065415472258, 0.08426047119428404, 0.028019082346872892, 0.007322283163375687, 0.022548448359884787, 0.014891373102727812, 0.01404099431965733, 0.03398929118702654, 0.008800098639767384, 0.029587874923890922, 0.022897265189385507, 0.03276974588516168, 0.025397781500942074, 0.012162981274741469, 0.04898287843388971, 0.07467028306564316, 0.013598598234239034, 0.043573182192631066, 0.03644456432084553, 0.013634558072226355, 0.028305475279921666, 0.04807378463738132, 0.025267692290071864, 0.012015829161100555, 0.022983619637670927, 0.024310314365720842, 0.012784265563823283, 0.05641808493237477, 0.006464651742135175, 0.02897673301049508, 0.010660868811100954, 0.04142444202443585, 0.0006490549912996357, 0.02793510091578355, 0.058141544795944355, 0.03672966035082936, 0.021794546919409186, 0.04537536537100095, 0.05105170785100199, 0.037629763028235175, 0.09251333147403784, 0.1880979520501569, 0.12006374570773914, 0.12238956231158227, 0.1539912642329, 0.23701140627963468, 0.10388466660515405, 0.12751403264701366, 0.15077104093506932, 0.1990850773290731, 0.12361580549622886, 0.06498774208012037, 0.11192243022378534, 0.2103284513577819, 0.14442180428886786, 0.12593904684763402, 0.14287185855209827, 0.277018643100746, 0.17227257310878485, 0.07905146281700581, 0.09136682463577017, 0.1353649457450956, 0.14250790933147073, 0.14489001041511074, 0.1717774270218797, 0.12416647165082395, 0.14516953291604295, 0.13056844531092793, 0.11790117190685123, 0.12325439442065544, 0.13187094416934997, 0.12977206148207188, 0.16382807545596734, 0.06445850915042683, 0.12648167554289103, 0.0948909054568503, 0.14423984452150762, 0.20024704310344532, 0.22534005052875727, 0.11099963638116606, 0.20330393454059958, 0.1213620143244043, 0.07791323834680952, 0.09978820438846014, 0.13316639262484387, 0.07735371837043203, 0.17621830513235182, 0.22162957931868732, 0.1652264894801192, 0.1394184079254046, 0.12893623992567882, 0.10831523628439754, 0.11813862947747111, 0.10119556871359237, 0.12929820019053295, 0.13224770285887644, 0.12696429417701438, 0.11853812015033327, 0.07729623161139898, 0.16114038764499128, 0.08125509964884259, 0.21899001236306503, 0.18395753984805197, 0.12973226752365008, 0.14515034097712487, 0.1614837348461151, 0.13637687894515693, 0.26882945909164846, 0.1052362733753398, 0.15265054476913065, 0.13467158685671166, 0.10929353535175323, 0.12365360307740048, 0.15540933032752946, 0.13191991107305512, 0.12197545132949017, 0.09315420567872934, 0.13033337745582685, 0.1510493314708583, 0.1185740326764062, 0.12146685010520741, 0.191579767561052, 0.1543463225243613, 0.13414783839834854, 0.2584584499709308, 0.14009745820658281, 0.15999725757865235, 0.0846262312552426, 0.10281658251187764, 0.20255904091754928, 0.08803144228295423, 0.1378000361728482, 0.16707029601093382, 0.19030155177460983, 0.17152051033917814, 0.12665544199990109, 0.10555048385867849, 0.08406723078223877, 0.17027431080350652, 0.22622256801696494, 0.10566139040747657, 0.1346809379174374, 0.09123143463511951, 0.09276484532165341, 0.0907149889098946, 0.08448635126114823, 0.06220703347935341, 0.06732654626830481, 0.17276109923841432, 0.13123266748152673, 0.12074784259311855, 0.08616874809376895, 0.1174436675501056, 0.13465352298226207, 0.2121193427592516, 0.09624246769817546, 0.12373345816740766, 0.09452230297029018, 0.09369474893901497, 0.1484682605951093, 0.12714816868538037, 0.1538791850907728, 0.2028087290818803, 0.10474036287632771, 0.09644033169024624, 0.1587612699950114, 0.14331451995531097, 0.12378287778119557, 0.13587414810899645, 0.19358435296453536, 0.21880964079173282, 0.09519507468212396, 0.18897474015830085, 0.11340093682520092, 0.1061832983396016, 0.16351661091903225, 0.25213971559423953, 0.20168078335700557, 0.10826525263837539, 0.08236961992224678, 0.11330609035212547, 0.10684981374652125, 0.13061797624686733, 0.15519683860475197, 0.16903465701034293, 0.0997824156365823, 0.1744214617065154, 0.25565114279743284, 0.12865118100307882, 0.1701435592258349, 0.12501348479418084, 0.18673287529964, 0.19471471809083596, 0.1762494011200033, 0.1830477558542043, 0.13043341896263883, 0.15511287201661617, 0.10862490482395515, 0.11818900646176189, 0.12336713407421485, 0.14541761804139242, 0.1362874056212604, 0.16160578845301643, 0.15120996191399172, 0.15786422125529498, 0.15279702987754717, 0.1340896391775459, 0.14675265265395865, 0.08232162523199804, 0.17289590294240043, 0.16771244670962915, 0.10001408445532434, 0.05843131635629106, 0.13579711318016052, 0.07906137048848905, 0.2279451521462761, 0.11242539854720235], [0.012376149279589299, 0.030537907441612333, 0.01790167807484977, 0.01687874068011297, 0.03747756709344685, 0.12093639263184741, 0.006095944427215727, 0.012426381545083132, 0.04522101349721197, 0.050013970176223665, 0.034790124191204086, 0.03608840022934601, 0.029524534475058317, 0.03868911946483422, 0.0325676776265027, 0.031625224291929044, 0.03888339146215003, 0.09427624390809797, 0.05597347168077249, 0.04676746371842455, 0.02929122550995089, 0.023183596895250957, 0.04365028391475789, 0.048170401132665575, 0.021461151918629184, 0.07266357511980459, 0.05957971567113418, 0.06458657415350899, 0.05730571581807453, 0.040926357032731175, 0.12885861127870157, 0.052269538791733794, 0.03601228185289074, 0.021842376481799874, 0.037044902419438586, 0.054163406894076616, 0.0460244180430891, 0.024903438788896892, 0.03879745818267111, 0.010581677943264367, 0.055456550981034525, 0.04979829092917498, 0.030820836400380358, 0.018796882577589713, 0.05087761855975259, 0.05154067555849906, 0.025944909466488753, 0.03602689474064391, 0.026469709919183515, 0.019563901478250045, 0.03501385945128277, 0.022044003162591252, 0.012182242790004238, 0.04300830762076657, 0.049184215677087195, 0.135335378581658, 0.061339937819866464, 0.08896199156879447, 0.037457499420270324, 0.01909361733851256, 0.08502857177518308, 0.048485446532140486, 0.05841167912876699, 0.022550808389496524, 0.018391272897133604, 0.07990981597686186, 0.10562348892563023, 0.08080169194727205, 0.028292977513046935, 0.04520806673099287, 0.030253175063990057, 0.049754296414903365, 0.09265570508432575, 0.04761593147122767, 0.05157509265700355, 0.051760303031187505, 0.03278117495938204, 0.013987591228215024, 0.09278843819629401, 0.0221135312676779, 0.06373602838721126, 0.04633947457477916, 0.02432195866276743, 0.02707451018068241, 0.059220022667432204, 0.003401070539439388, 0.03593894281948451, 0.016229138818744104, 0.05154646059963852, 0.019511869504640345, 0.013099944571877131, 0.10188993692281656, 0.0690025532094296, 0.02876804293919122, 0.02805092419293942, 0.048931083947536536, 0.023799173141014762, 0.013315802862052806, 0.0639095573569648, 0.0492745350493351, 0.005578051050179056, 0.03897356982633937, 0.0434609657531837, 0.04101782673387788, 0.03095758267591009, 0.033315936889266595, 0.05553097355004866, 0.009608657401258824, 0.04422820173203945, 0.048648641095496714, 0.038521327296621166, 0.02361547674809117, 0.026437133346917108, 0.009789592077140696, 0.06505627199658193, 0.04473127766686957, 0.06966407396248542, 0.02479587376001291, 0.024067849153652787, 0.031107954782783054, 0.04371503629954532, 0.017529426077089738, 0.024861108540790156, 0.018139736785087734, 0.057819753274088725, 0.03159455503919162, 0.08449147950159386, 0.013361115616135066, 0.15657295851269737, 0.009802468339330517, 0.04773890905198641, 0.02729183699557325, 0.02554814247559989, 0.05804488006106112, 0.04949927963025402, 0.026546678054728545, 0.06991402187850326, 0.02212118652096251, 0.05636163718008902, 0.10801402080687694, 0.012354958180367248, 0.021099089608469512, 0.04550446567009203, 0.04556681349640712, 0.03140185268421192, 0.03971706079028081, 0.04621381413016934, 0.03301499971712474, 0.026885017614404205, 0.02128617761627538, 0.046940109532442875, 0.045397284702630714, 0.03133893711492419, 0.04557203079457395, 0.03718784006196074, 0.04544997347693425, 0.023252514583873563, 0.02832100843079388, 0.06785928955650888, 0.03761286803637631, 0.05283262478769757, 0.03221405168005731, 0.04093653929885477, 0.03663632785901427, 0.0021264409497234738, 0.07396694971248507, 0.06851652811747044, 0.0850789413379971, 0.03420362714678049, 0.05142662601429038, 0.03282874291471671, 0.033858350361697376, 0.04807506855286192, 0.02732268436375307, 0.03484942179056816, 0.04886537048150785, 0.014152285857562674, 0.04190645951894112, 0.03076201377552934, 0.040844557515811175, 0.019132301786157768, 0.03890975254762452, 0.030468013828794938, 0.020889303013973404, 0.03797754456172697, 0.061243302770890296, 0.04902389322523959, 0.029822638498444576, 0.04740933611174114, 0.058811704147956334, 0.035616984314401634, 0.028309388253546786, 0.05836024087329861, 0.04910506191663444, 0.042579049404594116, 0.010812359705596464, 0.021455634050653316, 0.03864787831844296, 0.02223121733550215, 0.07908767962362617, 0.008491317894367967, 0.06575355684617534, 0.03269337888923474, 0.018897438021667767, 0.051897704252041876, 0.055861162472865544, 0.020793295079784002, 0.1113102697127033, 0.02072129562293412, 0.04091522110684309, 0.06657932230154984, 0.03970093392126728, 0.05351494051865302, 0.05361732350138482, 0.03021539047040278, 0.06959342892514542, 0.041489506111247465, 0.03666137905383948, 0.026446391639183275, 0.052324565331218764, 0.06487704333267175, 0.06568854470970109, 0.03197368860128336, 0.0589543523528846, 0.029189350898377597, 0.015711000996816438, 0.023210559120343532, 0.03583640398574062, 0.030730808321095537, 0.04532083235972095, 0.047739153960719705, 0.08873542872606777, 0.06672748466371559, 0.04826954464078881, 0.01179920089271036, 0.07276570206158794, 0.06278526299865916, 0.06413681039703079, 0.061899428110336885, 0.11282490406301804, 0.02289123338414356, 0.021229043377388734, 0.05030013860960025, 0.042183455007034354, 0.038767950391047634, 0.01914048581966199, 0.05587581988947932, 0.0737948234018404, 0.035098764856229536, 0.0384046616818523, 0.04470185151149053, 0.0745757037657313, 0.10573785388260148, 0.032868588823475875, 0.052252361783757806, 0.028878916091343854, 0.04678120087191928, 0.044015847306582145, 0.013586110671894858, 0.02980469522299245, 0.06188774299516808, 0.09967484133085236, 0.034174471875303425, 0.043383797237765975, 0.04515009386523161, 0.025607514289731625, 0.046982189305708744, 0.022873768793942872, 0.09666086087236181, 0.060264580679358914, 0.013716167413804214, 0.0562905097467592, 0.038131080073071644, 0.02360960264923051, 0.038223841111175716, 0.05015729373553768, 0.03980254135967698, 0.05936469322477933, 0.03099749723332934, 0.09142561757471412, 0.07855481017031707, 0.03153310521156527, 0.025818933609116357, 0.01725360689306399, 0.028389200670062564, 0.08061981381615624, 0.026550628135737497, 0.0352054485847475, 0.02577898936579004, 0.027585174575506244, 0.04263432085281238, 0.04324603978602681, 0.05660408940457273, 0.032155507360585034, 0.026825473250937648, 0.025064941255550366, 0.026845344254979864, 0.006763255787518574, 0.04050452771480195, 0.0528109503648011, 0.055791816193959676, 0.037848774518352, 0.0699211390747223, 0.0414412071404513, 0.02268612417537952, 0.05027822669944726, 0.02898948125221068, 0.03781587511184625, 0.046933797566452995, 0.03649666679848451, 0.02430780961731216, 0.05297449744830374, 0.08702662627911195, 0.02109098535584053, 0.016961271212494466, 0.048072708523250185, 0.016554717149119824, 0.016260262636933476, 0.030395669273275416, 0.012515123853518162, 0.08631013464764692, 0.03767192072700709, 0.03930522820155602, 0.07296145835425705, 0.05313870504323859, 0.05632860789773986, 0.036499839479802176, 0.05593426030827686, 0.07651759995496832, 0.02284115325892344, 0.1126501802355051, 0.04092819013749249, 0.0326254426909145, 0.04671331662393641, 0.036760106959263794, 0.04885396367171779, 0.05676199245499447, 0.022100660571595654, 0.039325076941167936, 0.0665730437322054, 0.009743243099364918, 0.04832296443055384, 0.06583075504750013, 0.1047594434930943, 0.039961750590009615, 0.07118781446479261, 0.02985437458846718, 0.05193102297198493, 0.03946014781831764, 0.06771614411263727, 0.0466795897227712, 0.028860991369583644, 0.1628268588683568, 0.21115793497301638, 0.12382503919070587, 0.15759424277348444, 0.14164796797558665, 0.24645161378430203, 0.12792356457794085, 0.08116645010886714, 0.10389220682554878, 0.21950446913251653, 0.12771070178132504, 0.135657396458555, 0.2439763880101964, 0.14461071055848151, 0.18898556067142636, 0.15033249102998525, 0.1882474502781406, 0.2793352719163522, 0.17586623027455062, 0.19785680808126926, 0.12670875788899139, 0.10010568774305284, 0.09845586377196014, 0.14375689934240654, 0.13797135354252532, 0.24189322401070967, 0.10056547049316578, 0.18569912295788527, 0.13898539444198832, 0.14991083240602165, 0.13937254319898784, 0.14126470807241276, 0.06507797981612384, 0.11578395817195997, 0.13604116102214903, 0.15345636871643364, 0.21784495271276683, 0.12609572906512767, 0.12224390098708682, 0.198629843944218, 0.11026885840692557, 0.15478850895306095, 0.15860672516282648, 0.1572348948684521, 0.10969120776280761, 0.09662382770329714, 0.14330794452689588, 0.1535759138641879, 0.06902337787323631, 0.1296102732885629, 0.09642709177569486, 0.09905576400342397, 0.14277423644671217, 0.10459481287398376, 0.13728829566389322, 0.287425869028084, 0.3363365476252511, 0.21787272387882695, 0.10158109216718003, 0.20716801547678187, 0.1662464378750883, 0.13565603090682998, 0.16689782089088112, 0.214017815887928, 0.08834161548293196, 0.17713852372253314, 0.22129518241854385, 0.137395239144098, 0.14597924571717158, 0.09052237190189771, 0.11994274595053867, 0.23163421981735155, 0.22011182794813067, 0.14910509751643986, 0.07896359995356761, 0.2001962802023627, 0.1406772091286257, 0.11707142111845315, 0.13043843588093296, 0.18036854336969554, 0.15710294101154432, 0.11916125702555291, 0.12650480086449534, 0.1499249183689244, 0.16050191799877211, 0.17775109241483733, 0.14548058185027912, 0.10939146173768677, 0.11646758008282632, 0.10675416575395502, 0.20669532677857205, 0.18391090328805149, 0.1418937969719991, 0.12250790518010035, 0.0930133460497018, 0.1344030481413938, 0.11752428705221973, 0.06611122007598169, 0.17678834876278415, 0.15039144724141806, 0.10821299059898593, 0.13688723905943334, 0.13594432559330016, 0.1660659772460349, 0.1885312475496903, 0.1696806075051427, 0.14518111041979864, 0.07828728077583946, 0.12919542758027092, 0.16165436943992972, 0.0735222696675919, 0.11493840705952607, 0.08747184067033231, 0.0668064714409411, 0.1977046678075567, 0.12206913263071328, 0.10646958180586807, 0.18058594811009243, 0.12602883187355474, 0.10478478041477501, 0.15020835940958932, 0.09825671586440876, 0.1455692684976384, 0.14616867149015889, 0.17108420172007754, 0.13542128959670663, 0.19294405763503164, 0.1509122716379352, 0.37082673283293843, 0.13613370683742687, 0.08834676598780788, 0.061919647923787124, 0.16024020704207942, 0.15830293443286791, 0.1592327415710315, 0.11995221575489268, 0.2199904719600454, 0.10852910098037682, 0.19448640377959237, 0.21316909580491483, 0.11707345460308716, 0.09394134976901114, 0.10067550872918218, 0.1137995146564208, 0.18765104556223378, 0.14618489483837038, 0.09391219078679569, 0.1234073807427194, 0.14788208267418668, 0.08974886848591268, 0.13040310965152457, 0.14544635399943218, 0.1970514887943864, 0.10615765713737346, 0.25900024746079, 0.1617356642964296, 0.09168577744276263, 0.11239589075557888, 0.13858380349120125, 0.14184680418111384, 0.3594902192708105, 0.18492252478608862, 0.2666720357956365, 0.1508603064576164, 0.15074067225214094, 0.1439699699403718, 0.19426668353844434, 0.252025454537943, 0.162197116878815, 0.15216587780741975, 0.12383817520458251, 0.12092702672816813, 0.12539416202344, 0.21733484492870048, 0.1454121558344923, 0.18928463134216145], [0.01332000712864101, 0.011662415654427605, 0.008220357922255062, 0.04869835014687851, 0.02517655841074884, 0.03270319750299677, 0.010578071105555864, 0.04701109595771413, 0.05055405701568816, 0.027382848420529626, 0.04006684241176117, 0.08600313783972524, 0.019608756883826572, 0.052506985230138525, 0.04893046796496492, 0.0658432231284678, 0.0530669727595523, 0.06999245946644805, 0.11307661086902954, 0.030416416011576075, 0.04464641308004502, 0.03877371687849518, 0.01482880448747892, 0.04084289881575387, 0.0658642927010078, 0.03836625925032422, 0.030825042522337753, 0.0780702025804203, 0.027046731593145523, 0.01779954556695884, 0.011086149115726585, 0.05807207977341022, 0.020106324227526784, 0.05377320419938769, 0.04632419746485539, 0.08675042117829435, 0.008106973527901573, 0.08458562835585326, 0.00893417689439957, 0.024012972899072338, 0.022439261738327332, 0.00973410447841161, 0.06401181788532995, 0.01459583041651058, 0.09381918483995833, 0.012297797038627323, 0.07145118041080423, 0.022521469436469488, 0.03907681370037608, 0.007622046814503847, 0.01835837905673543, 0.024819876671244856, 0.028197719148010947, 0.05804086504213046, 0.028467680931498762, 0.0846201901731547, 0.011817497615993489, 0.03375062391569372, 0.014438116613746388, 0.030649203617940657, 0.00792977927631, 0.005156143342901487, 0.034560377534944564, 0.007461543000317761, 0.028480006149038672, 0.04752145607199054, 0.0421942458342528, 0.017934000461536925, 0.026955773973895703, 0.05334381239663344, 0.04544210671156179, 0.01014814402878983, 0.011200759909115732, 0.025488139835943002, 0.01905095312395133, 0.03938764741178602, 0.03312925706268288, 0.020935870925313793, 0.019954924246121664, 0.0695804636052344, 0.03452704768278636, 0.031313923027482815, 0.01665269363002153, 0.012447335157048656, 0.019986187217000406, 0.06402827872079797, 0.012068722026015166, 0.006915076473887893, 0.03337982467201073, 0.018603807293402497, 0.020414113278093282, 0.03290947373898234, 0.029929880693089217, 0.02058984086033888, 0.05507459725777153, 0.14956727740354836, 0.08077585036517121, 0.011446292046457529, 0.022090231541369576, 0.026323029997001868, 0.035939889057772234, 0.01755102442984935, 0.05542654966120608, 0.032889324429561384, 0.026699467707658187, 0.039800021768314764, 0.015026150831545237, 0.062094609238556586, 0.011283663370704744, 0.019540790999599267, 0.06426227046176791, 0.04073775504366495, 0.06210236097103916, 0.08837229586788453, 0.08461181132588536, 0.03795168442593422, 0.012501670571509749, 0.025138636519841384, 0.06198544673679862, 0.0800213310867548, 0.05024841091653798, 0.024567637374275364, 0.03177795457304455, 0.016164735243364703, 0.033495083916932344, 0.0211013494481449, 0.10546009027166292, 0.08654668679810129, 0.010832639818545431, 0.028157071719761007, 0.00934982319449773, 0.05327195023710374, 0.047615894363843836, 0.03157136663503479, 0.05088327743578702, 0.03807312205026392, 0.029079453670419753, 0.09733364742714912, 0.03777332036406733, 0.049531403492437676, 0.057534134029992856, 0.030057370531721972, 0.022092109174991492, 0.024932280502980575, 0.020629527207347564, 0.008157857027981663, 0.04528478624706622, 0.03326022757391911, 0.052630178033723496, 0.05102836359583307, 0.02061126295302529, 0.03344464385008905, 0.045590476875077, 0.03282297642726917, 0.05088282843644265, 0.06554038976901211, 0.024953880711109377, 0.04929892944346648, 0.009698865451355232, 0.03754062738153152, 0.0460052520793397, 0.014569563954864861, 0.05468733717862051, 0.016633197410556022, 0.03640787996118888, 0.04204585711704567, 0.1010208523075562, 0.05293415058986284, 0.0321504681778606, 0.06882127621793188, 0.03621609786932822, 0.027279437563265674, 0.049297022123937495, 0.030639461074315477, 0.025620722663006745, 0.07671359373489395, 0.03075741060456494, 0.024680571841599885, 0.0751596775080543, 0.041304217811557464, 0.019137494964525104, 0.06395974138285965, 0.045186878414824605, 0.051704853467526846, 0.04137114839977585, 0.052757935045519844, 0.03960939371609129, 0.04834066094190348, 0.04567361967929173, 0.03531948328600265, 0.07673980639083311, 0.03374368854565546, 0.019974826791440137, 0.018417040264466777, 0.010999548831023276, 0.023017344683466945, 0.07704587551415898, 0.03830984118394554, 0.018405789305688813, 0.030476053143502213, 0.04615049409039784, 0.04057508740515914, 0.04488799699174706, 0.03427288065722678, 0.016554629946767818, 0.05560840181715321, 0.0226458700853982, 0.0534364658233244, 0.0425474264920922, 0.02032922271610005, 0.023020268745312933, 0.09057425544597208, 0.008038561427383684, 0.06883299472974613, 0.050130368617828935, 0.08452615264104679, 0.025192516441165935, 0.02810985442920355, 0.008076419308054028, 0.01236692438396858, 0.061445400715456344, 0.054780194695922546, 0.0746389792766422, 0.0236276646683109, 0.013722793864872074, 0.025489323561487254, 0.06287659169174731, 0.05692735037882812, 0.029430717731884215, 0.049623600498307496, 0.03704634960740805, 0.07685054966714233, 0.03806429049291182, 0.0445170122111449, 0.0076528487261384726, 0.03305842277768534, 0.02955873449536739, 0.05186443006095942, 0.035244908576714806, 0.03634206259448547, 0.01739827373967273, 0.014122645407042, 0.04600805739755742, 0.023034699806885328, 0.01052877301845001, 0.061229335551615804, 0.03900993506249506, 0.029529198873206042, 0.04899829284113366, 0.035323895353940316, 0.04358859659987502, 0.04175339527137112, 0.06112442184530664, 0.004165397995166131, 0.02881985968997469, 0.01550531291286461, 0.011122275009256555, 0.031769293709658086, 0.0413990234665107, 0.03408914344618097, 0.01840455734054558, 0.09722771326778457, 0.029526117104978766, 0.011592740047490224, 0.0017320060419478978, 0.023383193802146707, 0.006996957627052325, 0.0768043880816549, 0.028623596881516278, 0.04988713342754636, 0.01373728244288941, 0.012829136740037939, 0.12353075537248515, 0.025102182225964498, 0.06863162780064158, 0.02311521540832473, 0.038957977303653024, 0.02483928568835836, 0.07238843129016459, 0.02705689716094639, 0.016480886442877818, 0.10061365072033368, 0.0022955787244427484, 0.08639318839414045, 0.07259287813212723, 0.05023266625357792, 0.06473384593846276, 0.08414327123318799, 0.08153259608661756, 0.06008599768392742, 0.04166642298514489, 0.007086426776368171, 0.014188444220053498, 0.04689682747994084, 0.01686713905655779, 0.04336800804594532, 0.05787634574517142, 0.03208537440514192, 0.04338095481216442, 0.0028199536018291838, 0.014864957283862168, 0.020085874348296784, 0.05432674988696817, 0.08444424922345206, 0.022735994643880986, 0.015615963420714252, 0.053164580021984875, 0.03434884318266995, 0.018701130684348755, 0.044123625702923164, 0.03505247710563708, 0.0801537673396524, 0.030531955417245626, 0.03223635321774054, 0.004371348150016274, 0.025842194372671656, 0.03897967399097979, 0.019964241910201963, 0.06058859122276772, 0.04044208712002728, 0.07154288759920746, 0.009794184115889948, 0.03493237163638696, 0.007074009718053276, 0.030513958336086944, 0.01404054068188998, 0.01648749712330755, 0.042227364174323156, 0.03886661150318105, 0.06541594644659199, 0.056000044278334826, 0.06080557293898892, 0.06288308548391797, 0.02733647903369274, 0.02366292039369, 0.03897648646670859, 0.038833960716146976, 0.00498229200275091, 0.06148107204353437, 0.018509563815314323, 0.012628542572201695, 0.0694802959333174, 0.06608733034227043, 0.03100753849139437, 0.005943885325905285, 0.004346847072156379, 0.0477002691332018, 0.027016693165933248, 0.17095175804570317, 0.05663268435455393, 0.09704749012598768, 0.02458652132190764, 0.1219051105726976, 0.159237016341649, 0.18739972467301413, 0.15447081037564203, 0.1125373737886548, 0.16974977566860616, 0.11842024483485147, 0.09207846262142994, 0.12715612450847402, 0.2380383011768572, 0.1301264518406242, 0.09495326070464216, 0.12255566238309257, 0.13303207873832434, 0.21493338863365352, 0.2446106422576122, 0.16552395711187273, 0.13051576766883954, 0.17238557251403108, 0.1621707557933405, 0.13224607013398781, 0.16361064102966338, 0.12203585472889245, 0.09498839397565462, 0.07750921315164305, 0.1245488558197394, 0.10754867194918916, 0.1659913023468107, 0.14932042424334213, 0.13704553915886208, 0.0887776049785316, 0.13180922716856003, 0.18831262568710372, 0.20308261126047, 0.11696193949319422, 0.2521882520522922, 0.08529429775080644, 0.1884872085065581, 0.1066125491342973, 0.11624514358118176, 0.08528382604708895, 0.14479056262644008, 0.1814560272032395, 0.07362913151155226, 0.1303388099768199, 0.22999542416073382, 0.31686538306530565, 0.1552380426437594, 0.13042176724411547, 0.187226373818703, 0.20946462114807218, 0.11209635995328426, 0.07131807622499764, 0.10274316926370375, 0.1440956155420281, 0.174865429289639, 0.1673387159826234, 0.1139778750075493, 0.16184970270842314, 0.11928461681236513, 0.09295882045989856, 0.3021331282798201, 0.17287251044763252, 0.2017479477217421, 0.12249692881596275, 0.13708257232792675, 0.11593529692618176, 0.08306868592626415, 0.11406256147893146, 0.19643875682959333, 0.1473652065033093, 0.11824373243143782, 0.21984032064210624, 0.13459385430905968, 0.17209134064614773, 0.15757594141177833, 0.1982928643701598, 0.15031779650598764, 0.12716782075585797, 0.1471177744679153, 0.14027401513885707, 0.10599685600027442, 0.16535468806978315, 0.13391366112045944, 0.14300890354206786, 0.20043765631271526, 0.10353363075410016, 0.09676479865447618, 0.13569649279816076, 0.1469959583482705, 0.08997780620120466, 0.15079119766596705, 0.11861412349389866, 0.13194907747674733, 0.14586618694011122, 0.18882742384448647, 0.22756591468350962, 0.06576991378096864, 0.18775942880893126, 0.21354566153604537, 0.16274571244139224, 0.19223594485083595, 0.17263456305954605, 0.11050165529013611, 0.14353898994158953, 0.1835319329984486, 0.14889999758452177, 0.14219365431927145, 0.11207899369765073, 0.07549722853582352, 0.11299352001515217, 0.18856853304896504, 0.124418542109197, 0.22768922994146124, 0.1583542613661848, 0.12328354598139413, 0.07979565882124007, 0.14102759188972414, 0.11197066982276738, 0.16274593508569524, 0.09928023398970254, 0.06302444235188887, 0.07009821551037021, 0.11549346672836691, 0.062163198526832275, 0.09567525165039115, 0.20228993816999719, 0.1835308494628407, 0.09989431666326709, 0.17183003044920042, 0.10645165893947706, 0.1417172103538178, 0.11958945397054777, 0.18510028399759904, 0.1732088517746888, 0.1443592709256336, 0.08705689848284237, 0.11682890210067853, 0.1313404570100829, 0.16981763765215874, 0.11708892096066847, 0.1314665182144381, 0.18424025358399376, 0.0707694361335598, 0.2020970094599761, 0.08181105731637217, 0.07650518382433802, 0.08910186414141208, 0.10637405997840688, 0.15405250625917688, 0.0942962893168442, 0.15281923493603244, 0.14992913376772776, 0.22251956281252205, 0.0861336593516171, 0.06951746268896386, 0.13875696138711646, 0.13812894118018448, 0.07875665207393467, 0.14631989150075242, 0.20038159447722137, 0.20921068789903075, 0.16678073967341334, 0.11640291675576009, 0.06848161006928422, 0.18315351189812645, 0.24532550858566537, 0.11782853049226105, 0.14425857632886618, 0.11008930319803767, 0.13099377014441416, 0.1287757430691272, 0.21563082933425903, 0.09809330978896469, 0.12640101893339306, 0.1398632809286937], [0.013122658001520904, 0.012221513534313999, 0.029428791858663317, 0.09467016105190851, 0.03142360503261443, 0.05661093942762818, 0.07814066208084114, 0.0026587097272567917, 0.02945737011032179, 0.05865916682523675, 0.07873892216593958, 0.025948134098143782, 0.014035702806722838, 0.02146502592950128, 0.05211313487961888, 0.03458012608462013, 0.020635273285734, 0.03322747288621031, 0.05241925595328212, 0.03728450108610559, 0.041479924984741956, 0.025484336329100188, 0.04381978673336562, 0.036155612833681516, 0.047974878616514616, 0.021939403013675474, 0.03503449115669355, 0.034552310389699414, 0.030370872264029458, 0.06126502172264736, 0.04064887543790974, 0.014079235334065743, 0.047285783366532996, 0.03265066086896695, 0.04981147518265061, 0.05501526626176201, 0.014387668197741732, 0.05027826009609271, 0.04092151822987944, 0.022098573281255085, 0.007002841002758942, 0.05385098127590027, 0.04659431695472449, 0.06707207125145942, 0.03249562993005384, 0.05021114026021678, 0.04478779221244622, 0.03357406698341947, 0.05681895971065387, 0.03712332887516823, 0.05921054915233981, 0.04379548139695544, 0.03552040121576283, 0.07971149927470833, 0.0780939958349336, 0.022258140597841702, 0.016758321653469466, 0.032102399272844195, 0.048613927137921564, 0.05191927106352523, 0.03308124010800384, 0.026755178878374863, 0.03611299871408846, 0.041888551495503634, 0.036881232881569304, 0.021180720286793076, 0.05966439101030119, 0.03052709434996359, 0.06733514033840038, 0.0035315936747792875, 0.06549083656864241, 0.007697628989262739, 0.0582038146967534, 0.05381281633162871, 0.010220385611319216, 0.07120962618500926, 0.04038136830786243, 0.05292117042699829, 0.03576485723897349, 0.04435425922565628, 0.06985444968449883, 0.033226196392206475, 0.021331175885279663, 0.02729025622102199, 0.03642765819677152, 0.040178517083404586, 0.009918864925566595, 0.0053903308253211435, 0.03840111421595793, 0.026623395715432707, 0.045863431369070895, 0.00483267132040055, 0.021136070827196818, 0.05736827144573908, 0.0365137547487393, 0.03221908715204336, 0.02691499666980235, 0.062002894628676586, 0.03962863018386997, 0.04629994778952096, 0.033175129210576415, 0.02117125604854664, 0.018389174474577885, 0.07196104328613728, 0.006119450563346618, 0.01415439355696435, 0.03964799652749207, 0.026486489878152497, 0.04460126452613622, 0.05241580496658571, 0.08247030709753744, 0.053064074672874995, 0.024637102396809496, 0.04895745987596456, 0.01503831184891169, 0.041914775283657946, 0.035327876976225525, 0.025457400079176296, 0.0195098657059134, 0.058076603163499385, 0.04080159829754848, 0.011058064392273081, 0.027881512287422083, 0.02711761226237286, 0.04270960060239304, 0.015273032749973936, 0.019169709739799146, 0.015294900131266331, 0.10128806257853284, 0.054453501288662665, 0.01725603186059743, 0.01852434183092555, 0.05975961968943011, 0.048537292968831025, 0.019942265062127262, 0.03238417790271342, 0.030004104737599846, 0.029048125761619303, 0.014490066951111658, 0.021454589477798436, 0.05107785000291187, 0.10496987946680747, 0.05706535273930058, 0.03534802628564648, 0.012231513974256814, 0.03583794765290804, 0.03243608371121809, 0.06339035826385953, 0.022002168298058677, 0.071547414700035, 0.015080159701028606, 0.0007279106171154126, 0.019482675270410255, 0.010860011152544757, 0.03808450659562368, 0.014906883989169728, 0.02845913881174056, 0.06386525856214575, 0.03958811634220183, 0.0319765347376233, 0.04607141454471275, 0.04591764525684994, 0.05209435854339972, 0.06933507247595116, 0.03845366940367967, 0.02991080193169182, 0.06951638657483272, 0.02558181371568935, 0.052236847186577506, 0.021950676236883737, 0.012965534206159646, 0.05842745347763412, 0.041290265435236506, 0.047079436626518145, 0.040792102518025786, 0.034768616751534864, 0.05474391480674967, 0.010715887001424562, 0.0337972382112639, 0.061784833087585866, 0.0424258107523201, 0.04763798067870084, 0.055584070505574346, 0.028271826304262504, 0.054572241206187755, 0.00863658680827939, 0.03903989556420129, 0.048053119535325095, 0.024272078917420004, 0.009130673479376128, 0.02623749191116076, 0.008559518482798012, 0.02533401988330297, 0.05223873224167619, 0.050276122710783966, 0.017354427654936444, 0.04675504387705587, 0.022642330040980596, 0.04157409610343166, 0.012596106080309255, 0.04590558906784281, 0.06318757383269258, 0.06338450271869078, 0.018303966644452885, 0.050367837320663966, 0.06957829653401859, 0.02919191501860041, 0.06327877636067569, 0.022307823674054816, 0.0077301280998653965, 0.022412629768950865, 0.046758676689933054, 0.019457156522548757, 0.019446380538283847, 0.030212655656214338, 0.03443515124672558, 0.02343385094718542, 0.035252779052825645, 0.0457963709050091, 0.02554229064116953, 0.03376018277776893, 0.07682914612814784, 0.03035940979316365, 0.032886548797250725, 0.024704760289750993, 0.02058035806840053, 0.05087329926027451, 0.012331182551861275, 0.10676523859729059, 0.05293699672620278, 0.004639162807507091, 0.02625218272441998, 0.06765749960322864, 0.06457663679611869, 0.036197978333802894, 0.04185772639175411, 0.03416964420466684, 0.08999325029435568, 0.03370259211806115, 0.0498651473026257, 0.010090508840221446, 0.021116259194968734, 0.01319707314905827, 0.03638990885519888, 0.05930616374826059, 0.06517314541270025, 0.051000781677430496, 0.03211477829609066, 0.09340298100141808, 0.0802009753533639, 0.046980987026472576, 0.05428399847005494, 0.006507956522909808, 0.015594771393807605, 0.05259914141788613, 0.029128409441909753, 0.04462540659005754, 0.03647714089311194, 0.04720411372545641, 0.07292446971405298, 0.009042491492436966, 0.04107632652448956, 0.028067075181752443, 0.0547272647236241, 0.006818567590016755, 0.03975758205342572, 0.03554856943082996, 0.01317526421189541, 0.06726440624333918, 0.023641017760382965, 0.07663645490538329, 0.04694026167271659, 0.041765922724152915, 0.09269353235140443, 0.039537676275358535, 0.03399323199118953, 0.025072821008507162, 0.024078929418465123, 0.05157054329174571, 0.079596087889513, 0.007594917606184026, 0.06596856444957666, 0.021773271400888916, 0.020269060514692683, 0.010538687183725415, 0.009798277060326654, 0.0482785097847227, 0.029412319890980143, 0.03836174699245021, 0.0117222615153878, 0.05862652717041783, 0.028321095633145887, 0.08205365054891445, 0.029663147251994815, 0.03386699267139193, 0.06184817539178766, 0.03055596574995434, 0.016918772125791293, 0.018118255320587195, 0.027139665180584416, 0.05390260506828781, 0.059699802586692385, 0.03498378020594828, 0.04432296285813209, 0.08737390686292201, 0.014916568088665372, 0.02821517631673487, 0.05251389833574649, 0.019582913446356542, 0.059096982004120946, 0.01868151386588579, 0.03545661362295505, 0.028556996549014002, 0.01674557712249225, 0.0663810055993963, 0.021700854485970922, 0.02787698889733292, 0.03235245851101354, 0.0798056110215839, 0.10392109863460064, 0.024820108592393808, 0.04802871400897857, 0.0135058511114039, 0.047967446007533, 0.05582089725066908, 0.04322012398915831, 0.0667194917332381, 0.03823605686193332, 0.027635347469185945, 0.04394675335788634, 0.02793272418784909, 0.01897763264423702, 0.033182302067871206, 0.05612485496385489, 0.10251101062749512, 0.03288651911134366, 0.034051876500598155, 0.013912048943893751, 0.03709454838826787, 0.02969886681967182, 0.014979125571699115, 0.06463910336606205, 0.07571396534331143, 0.049416222173022106, 0.05312193250574637, 0.03059439972275868, 0.10066281058243476, 0.11038533848477527, 0.07599932854645886, 0.03962920163758099, 0.06739368094713427, 0.05127604053996038, 0.06811066239606589, 0.14533990033669397, 0.08887311938451603, 0.11116532084997743, 0.10367898037657142, 0.11439715875894763, 0.17689352593151852, 0.07729832446784712, 0.12235759058967233, 0.19349821930518374, 0.2236632420681417, 0.1565750958980061, 0.07325391648919322, 0.10874489526031539, 0.14406687958398834, 0.09217333878041245, 0.09147232834948227, 0.16081048815976828, 0.16968587675364688, 0.1659561987617053, 0.16537672985577956, 0.16516311006853357, 0.08351208205567673, 0.09646629943745211, 0.11788548290496692, 0.16844038967974484, 0.13737906032474712, 0.10268812417052686, 0.1254406204679981, 0.20146937516983598, 0.1441384819918312, 0.09148761659162119, 0.07301370555069298, 0.1499511458678171, 0.12079375184839591, 0.13434600667096674, 0.09081364260055125, 0.17361918522510678, 0.1135576116212178, 0.1029683517117519, 0.09905814629746601, 0.16458675818284974, 0.19109076645690948, 0.1610916730714962, 0.13173473038477823, 0.13805689348373562, 0.2077612141147256, 0.1160800528305117, 0.13163225463358685, 0.12478347838623449, 0.141652406018693, 0.11192651945748366, 0.17941244936082512, 0.2317923418013379, 0.1568886829772964, 0.09353557310532779, 0.11868961475556716, 0.15817117353435606, 0.19361157494131476, 0.13131951360264793, 0.17950311012100428, 0.1861913746688515, 0.17738798924256116, 0.13630333211040124, 0.22079227346694097, 0.21517139539355412, 0.16062055772636086, 0.2230281863012351, 0.1338315795874223, 0.08367281639948487, 0.27338948159012944, 0.12589898571604863, 0.1719967316603288, 0.20534093695459887, 0.19746989681152627, 0.22340403957059607, 0.09725515788886696, 0.07437548716552556, 0.27153657632879913, 0.1380091585451737, 0.13766639021923766, 0.13619241071864963, 0.10687549205613323, 0.14228795160306618, 0.20740574022056535, 0.11569123424123973, 0.10530602041399106, 0.14294726075604558, 0.12567003315780312, 0.15692718559876084, 0.23328658193349838, 0.08911905970307998, 0.16231387155130506, 0.19224234216380864, 0.13490598677890375, 0.14815718197496608, 0.11062459205277264, 0.18880388292018324, 0.1691042704624124, 0.16565099795116112, 0.11534486649907194, 0.09886423053103499, 0.20880934927845374, 0.1689624905702658, 0.116930516960565, 0.16316584224114195, 0.08111532355542295, 0.22299673408269882, 0.10416126504424028, 0.07958145273732953, 0.26646660931874067, 0.12326986077823676, 0.1254203449934721, 0.15905464097158983, 0.06581698078662157, 0.06939238854101859, 0.19140340358717367, 0.13666624232428148, 0.09326906787464395, 0.2272792675648816, 0.08984862797660753, 0.08572119593736716, 0.09789757576072589, 0.16087484720628709, 0.1404881989583373, 0.15052068483782932, 0.07980898037203588, 0.1603082026122138, 0.21911187301157042, 0.17488396813860163, 0.10947353584924713, 0.20845065446337685, 0.14173401257721707, 0.1304086163872853, 0.16561329684918746, 0.10205140599282458, 0.08911936398362741, 0.1203728279506322, 0.1609313246444799, 0.12180618970887735, 0.16899434354854748, 0.25214891822542995, 0.30003670952282846, 0.2482664171839133, 0.07847004206269048, 0.15039821562822908, 0.13446737750200555, 0.22551978385308757, 0.06960234211874194, 0.20264700026018545, 0.2278851272421889, 0.09545793596771546, 0.07634129535290413, 0.16580527561018243, 0.10322744288714603, 0.1418770244345069, 0.12303963172598742, 0.21875256963539869, 0.15075368952238932, 0.15840389620279893, 0.18436067446600646, 0.14609292789828032, 0.19252740108640864, 0.11749932120437734, 0.12567889440106228, 0.1564581779530272, 0.19300160376587883, 0.13432933803414926, 0.1386688239290379, 0.1276465505361557, 0.1789412894868292, 0.18218349519884214, 0.08829714599414729, 0.2337006854941137, 0.20633774518501014, 0.07406267934129573], [0.051487626842572354, 0.014143692715151701, 0.047414828004548326, 0.042043118592118844, 0.057576948529458605, 0.051596588964457624, 0.02822921218466945, 0.030677145477966405, 0.050265220561414026, 0.014926012845535297, 0.09859555080765858, 0.07557294244179502, 0.07624221863807179, 0.004228055668136221, 0.06211862884811126, 0.04695374649600126, 0.011498209914861945, 0.011759243661799701, 0.13945818704087287, 0.020034322915307712, 0.028278245881665498, 0.042863050766754895, 0.04669726768042892, 0.05942175324889831, 0.014276489837357076, 0.04420478697284125, 0.02787890363833867, 0.03056522960832808, 0.038136716684675775, 0.06495359586551785, 0.07398454603389837, 0.08861994312610477, 0.09347664657980204, 0.07523657142883167, 0.060865831619594246, 0.018478753554518335, 0.02209296821092721, 0.06757147726602852, 0.056035927118500695, 0.02696938310691621, 0.06913366843946278, 0.051899388927267864, 0.04944302112562582, 0.033786087442422286, 0.020866582162852865, 0.0661778129870072, 0.034393728274153545, 0.022858784832351375, 0.012534605230030138, 0.021662186736648437, 0.012755394163832534, 0.006331431595754111, 0.023468963809136767, 0.029061645836918615, 0.04293669779144693, 0.04483964978135191, 0.03501939958368894, 0.025907178678608034, 0.10073253535665572, 0.09107139791012742, 0.03908543003490195, 0.0179401806963142, 0.02997542072989745, 0.09264361549867317, 0.018232338261441328, 0.05924009034060873, 0.01362876932034851, 0.023543807546957396, 0.0349849045596784, 0.010372508259024471, 0.003774772508222668, 0.011855355496663833, 0.016845709542394616, 0.13042911450611427, 0.007004213975960738, 0.033714318051352166, 0.045480739208869636, 0.02049808914307505, 0.008910850265237968, 0.0701380317332223, 0.008551199007342802, 0.04900421146885492, 0.016458699938084465, 0.013355874198168749, 0.028618646756513044, 0.005929844355705427, 0.05763871748058591, 0.01667634402110707, 0.02624332333653001, 0.02958360200864263, 0.036767383717233315, 0.024216766651079524, 0.10397753154393286, 0.041814429496298544, 0.07226611051009968, 0.08933947014156729, 0.0630022150289733, 0.06778929760912433, 0.029500238415494096, 0.03740413158084266, 0.01571215132571524, 0.041995094215963036, 0.03315289817692246, 0.06038887928298209, 0.02210818223829847, 0.052536478178808466, 0.03811249298451003, 0.020163996523479, 0.02651074140885612, 0.028846289424109273, 0.08482007280690596, 0.04767387465108186, 0.015594609976687934, 0.08002529415534809, 0.07934228822705336, 0.08910648029996082, 0.06468501262133941, 0.01725894479022827, 0.026223407803627197, 0.02391451216681162, 0.07026914696325548, 0.0530378917028429, 0.03074743985052919, 0.02871808897907613, 0.039807101857149974, 0.04130700086534489, 0.030186556177795865, 0.03733170167834032, 0.07636953407200053, 0.065809848747449, 0.020385735406307504, 0.018242767291667406, 0.017110259213950485, 0.04402793689223472, 0.024792291042103898, 0.017852330820460338, 0.033635134604992345, 0.03898215276421979, 0.02058040630799951, 0.027237689901085105, 0.04901918800896965, 0.02889146766392514, 0.03829423752904404, 0.014198344470059965, 0.09176932100672275, 0.0960700519499369, 0.013211543173383689, 0.06687883826089092, 0.025537004694342613, 0.03394861036213115, 0.04357454032287933, 0.027903054979105946, 0.02962006372399628, 0.020753187563968822, 0.03841323348751757, 0.018766706853057258, 0.09407269506482407, 0.011266562432865612, 0.027775234884757083, 0.07792277494445443, 0.043301240730215795, 0.04479885392356664, 0.09192316822009161, 0.05715550512832124, 0.0484725405840436, 0.050891429928014986, 0.014263469784054905, 0.07440377783495933, 0.0029291766350070247, 0.014441357943724142, 0.04868339958193246, 0.04031768461572938, 0.03843485967081506, 0.03965826785133686, 0.04012816978502087, 0.05442842040793039, 0.05420189096184913, 0.012342621830612188, 0.02839580392901553, 0.03735880491149146, 0.08419240883085877, 0.028857744473498315, 0.026823838670679834, 0.046182217192836106, 0.0284467801975552, 0.029489384505723137, 0.10432117560412735, 0.007336505495914025, 0.03584589605452493, 0.009426281103515066, 0.040681544778635725, 0.007766323105897754, 0.010892658228840446, 0.0675525821861811, 0.08021423011086881, 0.033556296257302165, 0.07951980995130725, 0.029311469443200622, 0.02681332429347094, 0.023648025489819702, 0.05582952100667171, 0.05137284999364056, 0.02514689291274408, 0.09053308851434849, 0.025713858485687524, 0.030593462761316914, 0.040682658000150695, 0.06506664722110145, 0.043387021869421005, 0.04769626153574791, 0.03950910730054602, 0.011393829627195373, 0.04243642346409615, 0.02588049290352501, 0.004075800361533766, 0.04758953698910773, 0.050656966923270375, 0.025741828176251147, 0.05559053832257632, 0.03949024190660566, 0.008353829471161589, 0.042975719916285016, 0.009797277944016969, 0.03262904581788462, 0.054299268158501945, 0.10640757536748424, 0.006185511447256431, 0.029431947841658257, 0.01728915947751375, 0.018078915927617345, 0.07007783613516949, 0.007950827512104297, 0.026614593843987677, 0.01330978868281818, 0.0654318580927793, 0.032730386083130725, 0.025502854769001715, 0.02580330583441537, 0.04347095877164975, 0.02239207042293856, 0.07087641672114842, 0.04302004468627274, 0.03717783220054116, 0.011684261698974296, 0.05905982638068963, 0.07313843088923022, 0.034949418768519536, 0.04995546296413522, 0.03853575835819356, 0.0646433410292957, 0.04622370324796066, 0.018649859412107617, 0.023684362895437516, 0.038661548678646795, 0.03909002392902039, 0.08869344543199986, 0.04854334889387246, 0.1092243820312433, 0.017440344236092642, 0.045717161483480595, 0.0036982958135922672, 0.019705718477780465, 0.05126887510414235, 0.018178120662923902, 0.053789353332831524, 0.06951063493033871, 0.05320874151948374, 0.011964736004301812, 0.03883971236064099, 0.06788196958950721, 0.1242004991217982, 0.08565662166802213, 0.04471013387956191, 0.024810614668240305, 0.011308570774417603, 0.03645436438091565, 0.0532441159884911, 0.045809265720890835, 0.05929964027018286, 0.038161471020430326, 0.009890208748402074, 0.0502817370579578, 0.023702289472566918, 0.0511876841483172, 0.04136947856750339, 0.00875354278832674, 0.06792234242311679, 0.019337045487191062, 0.041264019382651895, 0.010799095671245595, 0.022460574364231434, 0.15748013014672324, 0.08624700014479458, 0.059823099290952086, 0.041349503662786447, 0.057905052017304115, 0.056228915200335905, 0.025518165275570937, 0.044135834032204, 0.03478894417639822, 0.049949692765949294, 0.05038552641053684, 0.0350516978505766, 0.015281648156815208, 0.058196500831400044, 0.012390885549393715, 0.023345617009908892, 0.08129286012263037, 0.016075744315457996, 0.039268005784833804, 0.017944685532711446, 0.03163448258419521, 0.02015688303799834, 0.016201629259740002, 0.01493839929025853, 0.007865636380302021, 0.04359801816463005, 0.020856140145042446, 0.019053745454584714, 0.06706473883241415, 0.028125042481406126, 0.04902388209302444, 0.06211425759829581, 0.023226133089337964, 0.024818268066155724, 0.01449007066185004, 0.001617359764622961, 0.03668332807137631, 0.039523237792309374, 0.05070354040071834, 0.014173772888170788, 0.01308688462813734, 0.04928011599986348, 0.028576359181897715, 0.05446317889436614, 0.07346132450038567, 0.0026619635809765896, 0.048613455874146894, 0.008849275200191187, 0.049994255023193546, 0.06000150788167957, 0.040325703521375544, 0.041276940173702314, 0.030124379045446403, 0.009414286141691264, 0.026953182023135014, 0.036048450419912115, 0.0174654733564239, 0.020887861392111517, 0.10318001222913153, 0.037052832267363556, 0.04224632604746148, 0.1936555397696793, 0.11009635360096581, 0.12251415406353772, 0.15553191828075796, 0.16602900344878435, 0.24022751807933673, 0.18787336332025006, 0.1819491694914177, 0.13254200894152746, 0.104201251961058, 0.20459310442674905, 0.12479717843234539, 0.18721956090303138, 0.08103464468149468, 0.1409744838019833, 0.1882163542904891, 0.12629541131900623, 0.2639817801536992, 0.19575642625568435, 0.142490454018116, 0.13464007526636124, 0.1420040355878882, 0.11213895180844702, 0.1986076240427792, 0.13984782941406593, 0.16002709191525355, 0.08316797786392272, 0.11249606584897265, 0.07662799442186952, 0.09788964220206253, 0.15995422785636038, 0.2787041198462248, 0.1693315160810016, 0.15204098919639364, 0.11147130833705887, 0.10865024174563587, 0.1155085620121099, 0.09223499640938826, 0.1704362325835973, 0.114391807874199, 0.13665865757502615, 0.15939745382638648, 0.1265552669065073, 0.1150376841542311, 0.11725317308446392, 0.17243179347133264, 0.10434226744109765, 0.15158805646933615, 0.08837881934596226, 0.17652880487730727, 0.10536971894907765, 0.07486100017558783, 0.11116949914139695, 0.051646498395712115, 0.14607418124796823, 0.13009857677388936, 0.08728530185180716, 0.12597026157891378, 0.2083293578471057, 0.2042837772751227, 0.19730497675482184, 0.07687509249080904, 0.14063959708437324, 0.19019407394807786, 0.21613894816255197, 0.15774129191413522, 0.1352518127532676, 0.1029977630241774, 0.1469644467579201, 0.1628677363623865, 0.07143448208807968, 0.21832237631315365, 0.12204368438688107, 0.16808421816676855, 0.12925965304020792, 0.13931106368545443, 0.09492119250353426, 0.17798249406041577, 0.07854827927076258, 0.15653585112886503, 0.09893948430544697, 0.28849352267570794, 0.09062485507456586, 0.08276654276414774, 0.14761471655219793, 0.10346082606702112, 0.17468505771830678, 0.06241487935767509, 0.21578789746854454, 0.15815733990166336, 0.10008329714764841, 0.07556331678642891, 0.211489021894522, 0.23143753584008664, 0.17738267546519637, 0.23021619825158268, 0.14256380789447576, 0.1343698296113871, 0.11400997289456427, 0.10596561900456436, 0.12444119987776503, 0.12794998503522947, 0.1302945037605241, 0.16627625736873597, 0.11315721552819014, 0.12806049082428217, 0.09709987833048217, 0.23516831221058965, 0.19846391456667334, 0.19645106163807213, 0.15328601613873616, 0.13192384445574135, 0.14760318357730284, 0.11890035500982776, 0.2189892702153884, 0.27882957248948514, 0.1835680310614407, 0.1508718097466044, 0.12357081650407054, 0.24042311852099374, 0.0917686901811976, 0.0987398020515684, 0.13698625640245155, 0.11168125449330546, 0.22161484026582912, 0.1977905788226053, 0.11542026870301925, 0.07110339516657405, 0.18454109056619927, 0.1632738544140011, 0.10996451106620952, 0.1470224084914662, 0.12434479489456862, 0.13548168557463214, 0.09207626586430706, 0.11170523328473791, 0.1085918495664373, 0.05769533592683729, 0.10565422126092017, 0.0956769214826636, 0.14791383175179362, 0.11286477965768427, 0.1725660776719451, 0.11443218812928535, 0.13618806173326448, 0.13029169844230637, 0.15594290482113138, 0.20128560456214473, 0.09336617789813317, 0.10713940719142556, 0.09325408391305245, 0.19604494358645752, 0.18172226526075974, 0.11919208584004082, 0.10195080045377836, 0.15106510953046381, 0.1464024480083026, 0.16592617146670818, 0.14092566532781348, 0.12781022378476337, 0.21514421794563532, 0.1463788328692317, 0.20851406356086954, 0.1482316045439802, 0.11193469050340354, 0.1284567976836115, 0.08537617890397087, 0.1574399502715096, 0.09285230000386946, 0.09640602962463163, 0.14443927444517612, 0.09164148606942035, 0.15655376657377928, 0.15853843273362145, 0.21901359781622887, 0.10963484164676629], [0.1300262173754163, 0.022813951691205148, 0.06092360781622119, 0.06124460152932443, 0.021791893741465174, 0.07768680909066461, 0.049640914803603664, 0.05835160969581921, 0.04242769951815717, 0.0346396240638569, 0.02139244017598685, 0.029257374299049843, 0.030823715933365747, 0.034584545574034564, 0.05309069179929793, 0.004520881630014628, 0.031072871606738772, 0.07656805857550353, 0.041245369211537763, 0.06605969276279211, 0.030043364349694457, 0.060140623463667, 0.03417083164094947, 0.05163660185644403, 0.03516015531204175, 0.1215117797255516, 0.020040727649757173, 0.04170544882072136, 0.03914419328793883, 0.041292009482276626, 0.09492978657362983, 0.019761245966947172, 0.02320073494047392, 0.03003952373546781, 0.03329715684230905, 0.011051791389036225, 0.08870845907949843, 0.030568478359782603, 0.03459721774561331, 0.059891284108744, 0.042837138680624776, 0.08196747236070223, 0.03397379885427654, 0.03110465779172955, 0.02238339657196775, 0.05114758590934798, 0.030858563477522694, 0.05167388735571876, 0.022922219905012753, 0.04025259826448746, 0.031454879135708325, 0.02733830471697729, 0.01883811073639663, 0.01936342698172666, 0.07888744075899012, 0.0258944823872298, 0.03463017652393319, 0.07410579069983214, 0.05938711350609083, 0.008195495047402801, 0.06311219389317557, 0.03359020498464815, 0.02782473613478942, 0.009101740852202056, 0.05032608038163744, 0.047005555825307965, 0.015860770108702127, 0.07525888038799167, 0.011532416428963188, 0.022840249694127124, 0.06420611956855282, 0.02651887905813055, 0.04152728884946555, 0.005562445076066069, 0.01903360171127133, 0.00866923110152129, 0.04403260500112083, 0.011011378664989024, 0.0261547981062904, 0.06487745893537067, 0.02390013491094578, 0.042504511802690104, 0.07671166415093467, 0.02152869292331161, 0.015398147716041422, 0.07418696681270376, 0.029174387345847208, 0.0149627955397591, 0.028011017056996934, 0.023142611789808143, 0.06958858270081691, 0.02281722456245916, 0.11595509000471793, 0.06379361162544228, 0.03843346443318296, 0.04261909198248759, 0.017841287663031835, 0.01174660859760479, 0.01636928598600207, 0.04257258529833052, 0.017200335532834288, 0.04451035514648538, 0.0073703553152881796, 0.01117367522965651, 0.05765812464233022, 0.0730947258125525, 0.004411358258948894, 0.015421891803271137, 0.023298947053262964, 0.04322365661209915, 0.04215368375298567, 0.017679104275885038, 0.039247982640517876, 0.036517350454232655, 0.08236772744567133, 0.03467291309789289, 0.0612338069913676, 0.005880595899725449, 0.01765489356330363, 0.053613776035490446, 0.010881845137191704, 0.020193014497635886, 0.030963705394242425, 0.05240221995336469, 0.03472522337688133, 0.04622235624992754, 0.057891144169843756, 0.0211965614289511, 0.02583297133242013, 0.04123766200791579, 0.026879566539719235, 0.07125336836907081, 0.028758458101947326, 0.0504260142770363, 0.022852682523080148, 0.029162574210204184, 0.050328830038779415, 0.021507860838028137, 0.02977286265377188, 0.0035166039151590667, 0.045228924791445024, 0.0433747393253725, 0.03812235241639428, 0.03479576080280822, 0.018916175395133905, 0.07243855594424531, 0.08410901369643398, 0.06912116325111128, 0.04760227595397737, 0.030123661017569248, 0.053587563379551284, 0.07390025290078484, 0.039404427370755, 0.06327312861685641, 0.03352746382006444, 0.05223621636105236, 0.0010098587813445192, 0.017531556040921714, 0.04683129212935455, 0.042733820591820404, 0.04448636151209939, 0.03635631925135385, 0.01851091637945501, 0.02358632889809087, 0.06305093702394515, 0.02213981071690796, 0.05273414921248332, 0.055684230756014585, 0.03144228488963563, 0.03997237443400081, 0.03766729714698158, 0.005065433415438747, 0.09807601032662205, 0.009022949816426262, 0.04663032967073377, 0.03635101660620421, 0.10883712937356904, 0.013857273806934245, 0.04342690859630238, 0.07773016535793431, 0.02009965046454454, 0.11394115354050882, 0.0412681345915189, 0.00786226146374247, 0.07094959248206578, 0.01589735984453, 0.0785647178418003, 0.006325322792690713, 0.01930234080646187, 0.06316580664133653, 0.07656661138753407, 0.02431733322737273, 0.006833927263869555, 0.02301083233760437, 0.07744581889710389, 0.07066405858495273, 0.056851751505746506, 0.04741073877085, 0.007249302216223441, 0.07753340716590174, 0.04492166823183652, 0.042464083308004774, 0.03502334038785193, 0.0561564778763568, 0.06584176851902157, 0.02416542116407072, 0.08333984442288056, 0.09433118510060012, 0.025048291172424797, 0.10636890947353095, 0.026442823764227796, 0.008432953545707278, 0.05325331490894314, 0.007161186558732879, 0.013520801676349947, 0.0453036034014076, 0.01404124664986739, 0.09054843612830155, 0.09392128951731138, 0.040449987282045186, 0.06605402275454253, 0.04481032010517083, 0.0523318383784499, 0.015680309479648713, 0.025118288685916923, 0.05381224487791769, 0.056985879855346866, 0.011352905748935882, 0.020180822866677772, 0.08566670745494775, 0.04704407328972593, 0.07247137371450663, 0.013766492447757628, 0.008977351335488493, 0.043051010798080824, 0.04675119955209084, 0.061964956039446406, 0.010365449506934965, 0.09225009169313125, 0.024508078167855274, 0.03390666046470869, 0.022838518634671345, 0.01282614402953186, 0.046019193323445506, 0.06040374450094532, 0.04140766577620525, 0.10288138684700243, 0.06518907190184109, 0.029982417327119038, 0.01609623130207183, 0.03535370000463445, 0.017929593959706835, 0.03298398165497929, 0.02164758312574122, 0.06590891804080456, 0.042746251565404236, 0.03799874772084877, 0.020400598768901546, 0.10941573738818988, 0.019005912181455642, 0.06585954295587726, 0.03417330670345109, 0.03879225201671943, 0.025103534790105186, 0.044062290908186696, 0.02118374268320622, 0.02918886108091101, 0.030677446047775447, 0.04477895323361736, 0.05303850026393775, 0.012561285439005587, 0.028638308103836607, 0.03519896221405361, 0.008230340736190556, 0.02493945707101375, 0.04704911247245036, 0.043185161412111484, 0.04324763169279322, 0.035290673113195226, 0.030543050525011495, 0.013899937093810877, 0.022973246268520597, 0.011516757112985943, 0.00415492536376405, 0.03758248822123278, 0.0549765818141168, 0.07760497988783754, 0.01801441772840917, 0.037285365688148886, 0.05691420694347471, 0.03574168738850858, 0.029996234261489008, 0.03598448100092355, 0.02479690534528345, 0.009527773509034887, 0.05397781431383919, 0.04235738473653328, 0.024258035628008656, 0.01741993703035405, 0.02827790263836505, 0.03226354550861288, 0.05804189291666262, 0.019380923113203607, 0.06908548079081811, 0.030607185071858112, 0.011578474113775883, 0.04560318986477796, 0.03144244445138611, 0.01393519931298215, 0.034992040309589356, 0.06827524106483907, 0.019557027335395105, 0.024279897443193477, 0.0027583080327531206, 0.08793211323791184, 0.03557474497938529, 0.04055262259498704, 0.0462009638431482, 0.00871701613505138, 0.005267994738460402, 0.024207048227253836, 0.018868937695515342, 0.013293162719492102, 0.03330802188429516, 0.06710958681651391, 0.0418861692014616, 0.09175678613246419, 0.03235177573515102, 0.038383228456950746, 0.04318669394706376, 0.008814339525997639, 0.04957545366778504, 0.03617707945522852, 0.012093453169654822, 0.02447118971758755, 0.043551285125431605, 0.06485302743385546, 0.03220828148187138, 0.020483099615375977, 0.03426240153203253, 0.0625461430172436, 0.03751421805645805, 0.03813234172412194, 0.020674143270298373, 0.011244872239331016, 0.019584889414545614, 0.055037066849763505, 0.008410997106693685, 0.07686480632401071, 0.04054038457979914, 0.011393903841963038, 0.02569419528299477, 0.2399501032778062, 0.10844864475075155, 0.14061660534935072, 0.16191483358852565, 0.19985729682957754, 0.22704911272739992, 0.1280516741098836, 0.12628006370505318, 0.12218396514072083, 0.12120522820623592, 0.12414703480317257, 0.20720411353977397, 0.1123865471163299, 0.18172744545154274, 0.2295930465334095, 0.06690219364827499, 0.16227715008426458, 0.1435556437354535, 0.1324488248792477, 0.1707690116018057, 0.1720772695261985, 0.19532859296305105, 0.08858955960022286, 0.1426113795605488, 0.07070801599184051, 0.150724018458277, 0.08459165459498763, 0.20140497159445658, 0.1228395190264564, 0.09770664342795499, 0.26752894918899983, 0.1880418011569418, 0.14061770372791216, 0.12907521449960768, 0.14618960005464032, 0.16692240082193166, 0.21706145256757736, 0.08357046681339853, 0.1386065874248743, 0.19772584870224819, 0.09396290915901773, 0.2363672517822124, 0.13795140461297706, 0.12253806606167927, 0.14128948096185923, 0.13248802511952817, 0.2031257003545761, 0.18228148837806657, 0.07918282295577228, 0.15284406719729304, 0.10956711324979551, 0.07340418655076064, 0.11910412649740465, 0.2189493426703848, 0.15502939524594694, 0.13156240369426087, 0.1612834885600023, 0.148579211672768, 0.11236143283895217, 0.12061260844347998, 0.1859110506484285, 0.1293957480811514, 0.18699399253819138, 0.18371052341535687, 0.12764828716171905, 0.10428167850477621, 0.10530297018704005, 0.20827871368965134, 0.12369823583867401, 0.1434523961506784, 0.13680846750503406, 0.11879770114319399, 0.14302218798547983, 0.1913750238600187, 0.08519487222656608, 0.11540161111042835, 0.08109298491035588, 0.14129644230706617, 0.15204674826236442, 0.12844073760788888, 0.14126150199444965, 0.17610257462365553, 0.16272389329969883, 0.10034074075520039, 0.19311145646497607, 0.15179133071796969, 0.14387087838258594, 0.05300222779624164, 0.1319457674981095, 0.10044588081655093, 0.18423412344418466, 0.11599600460613146, 0.15894692565780133, 0.13261249812785536, 0.18151342490455136, 0.13323523424332961, 0.18609385646414012, 0.14329088997328654, 0.12475123949116096, 0.13931027700891718, 0.15715116576757282, 0.15111020242329687, 0.1801233080914244, 0.1728003440075554, 0.19517648237524554, 0.16694475430995226, 0.08697046054294333, 0.061866068572271615, 0.08873895392753184, 0.1172403858799953, 0.18755985045572743, 0.09164420232991688, 0.21050622541224584, 0.10485261271242052, 0.1696819136850536, 0.06415061434381641, 0.1076909268158488, 0.11501858127303421, 0.09354444919154048, 0.2430566740804352, 0.21002017805585638, 0.11169446472194977, 0.10274598200339824, 0.17553297628182918, 0.1051644112158101, 0.1551351067610085, 0.15268857241608202, 0.1359216752462089, 0.12790518900146708, 0.11200147637282498, 0.13239507854450494, 0.18638083012774587, 0.08383137625060044, 0.16016032226616517, 0.180257206375245, 0.1389481534715742, 0.11964599820203148, 0.1149919381714426, 0.18041612987872213, 0.10651984746800736, 0.12310193502344191, 0.14473079005256295, 0.12950779753737152, 0.12302431379794143, 0.155084180587437, 0.13489348901202902, 0.17660929821431637, 0.1618856078130193, 0.12279130169190466, 0.11866575470776297, 0.12701183615718037, 0.2344001893652603, 0.11598095385124907, 0.17617211386095732, 0.09129003461566754, 0.2448520332109183, 0.0805406340805348, 0.11145787546411157, 0.1108911566552706, 0.11281998362392187, 0.09809418552322313, 0.11345575927407481, 0.13397089554928243, 0.06408297500456683, 0.17124671721830964, 0.13828369381371886, 0.1765484717907384, 0.12309727433603257, 0.1019763748627156, 0.13938596122898161, 0.07586321124108508, 0.14711330673890188, 0.13814385834848508, 0.25457238662056625, 0.12146768131060526, 0.0746703424374573], [0.04796326029463671, 0.020156821810815018, 0.10504814636078663, 0.034027122164843604, 0.1155981986084953, 0.05868930915312376, 0.06903690722538158, 0.01674233022640692, 0.050365057977614924, 0.04322556393162813, 0.022722465291735716, 0.03319777584692929, 0.06409829293261282, 0.046669960356666707, 0.038114923518151045, 0.012009249094262486, 0.05867992098501418, 0.023993732720555272, 0.09920613796566613, 0.0432705863204319, 0.02069276561087463, 0.08209653926314786, 0.029181146455812268, 0.04784057957294863, 0.017035921991919167, 0.100227333168732, 0.04074741038493812, 0.03240012294554617, 0.015910169313428923, 0.01678607426583767, 0.04834494313399773, 0.06595820406801067, 0.023858760177972727, 0.02405652583547635, 0.06030203316186089, 0.037213158429949544, 0.0631520472234115, 0.059419103781692684, 0.021170916515984572, 0.012566588084155228, 0.03642034062067978, 0.017553772231622133, 0.05031755310483277, 0.04400333469675388, 0.03661949966044631, 0.02311279415152967, 0.10677073049009778, 0.015887127483438235, 0.03787568479310721, 0.024058262461039703, 0.05390227852331009, 0.06236977904336527, 0.033925013776752166, 0.06386075372574851, 0.008188829633581918, 0.06313551959465258, 0.04370459799247328, 0.03646914796263445, 0.029191987377998885, 0.047826256122789346, 0.018377674896328244, 0.0838229306100402, 0.05719265704101417, 0.041448777046753094, 0.07482924367650412, 0.03089816262217937, 0.028369876999931876, 0.03494937423965894, 0.033944406095542945, 0.02994052123540314, 0.03843133818008937, 0.01083856030163588, 0.03206974106433336, 0.017966352534131147, 0.055795018561184406, 0.08340116808540188, 0.07443611320923083, 0.0378327515500132, 0.06762643330148421, 0.06544241885421798, 0.0335482550872257, 0.05421609937911853, 0.023703515871602576, 0.06736852956237271, 0.021048404632892925, 0.030107305938145146, 0.02922950850916095, 0.011768105832743458, 0.014799723430769518, 0.035344104035175405, 0.028716305969282985, 0.026842568622669205, 0.04580139895551838, 0.023816298198653385, 0.06124287974671461, 0.020444867877813522, 0.019583826287998818, 0.07794570730766281, 0.06569620367372409, 0.040343021537410095, 0.03199904036591761, 0.03689900731842499, 0.04267763259122148, 0.03369575693795923, 0.04956901553669013, 0.03141944529488683, 0.0260881810754654, 0.041458224586676806, 0.006879209404360154, 0.02525576597690815, 0.0353758642449975, 0.046861857481417246, 0.03260635465267114, 0.011080501371907303, 0.030438723115366884, 0.05888365536520723, 0.06296288120211102, 0.04416487798152957, 0.036599999730242416, 0.027843197058246005, 0.028207014547660947, 0.02352436142246006, 0.0368806799815502, 0.053618985912180506, 0.039839055025368, 0.04792013409314677, 0.028314208502706606, 0.037546416133409366, 0.04067672081873752, 0.027602689260675106, 0.02718306041060714, 0.05874826907529496, 0.030443749310506973, 0.03777795878704637, 0.06529591148137115, 0.03938615940569434, 0.04570431119645946, 0.0314354088914115, 0.04656390374293551, 0.05269347951980308, 0.014922883765393635, 0.0074944855441572145, 0.017154070046672132, 0.03015382004377898, 0.11303891718853265, 0.03760223677090835, 0.059654553842847236, 0.017139106494141743, 0.027410181719460525, 0.05548061883018818, 0.017518854183435906, 0.010102101186930668, 0.027644644724205136, 0.024221024723374285, 0.06696664175251499, 0.036695005765068345, 0.059954715470667, 0.0319417651189724, 0.02675158131751232, 0.04542439535725862, 0.05494421304319985, 0.058490049923420884, 0.10175800533033907, 0.003220746280021558, 0.0592624067212455, 0.014152925959933782, 0.04821753493160941, 0.014847679158265237, 0.006149781211206573, 0.01249283530341927, 0.04594442936650012, 0.024646596320963, 0.050792460824595764, 0.1328696374548599, 0.020696259271062445, 0.01501806327723898, 0.0137617844484339, 0.04787690028024372, 0.08663129163323902, 0.01601405514520593, 0.03434535137785133, 0.020502881561696995, 0.022803415049565956, 0.01675689301919192, 0.04881861517787911, 0.0073662405702634715, 0.04619018785888329, 0.02046394849458011, 0.0391088559263153, 0.029621614812640473, 0.02584361001936486, 0.02180236544518266, 0.02890941279474646, 0.01425035325155477, 0.08565097392420284, 0.043237319550826214, 0.027372543700039387, 0.044657385733444244, 0.016461939412693027, 0.06497850234154612, 0.01604688775842078, 0.1339390128850937, 0.02437947696307674, 0.01925744643813232, 0.030922349214961287, 0.057559036795282736, 0.03784154599998146, 0.012149719095759792, 0.033022224524756894, 0.0005153450274519855, 0.07234727178001776, 0.010551486448093783, 0.04715125796792563, 0.08959850936662406, 0.04478684226342011, 0.014131350799289066, 0.0659149517014157, 0.019038286518480163, 0.05073782020190265, 0.03286867788119707, 0.04983435559552163, 0.022591166380152572, 0.036002444685436785, 0.01754108707245905, 0.020117009298701305, 0.044571181570063345, 0.016582282369199675, 0.029791158449370414, 0.036129422442172654, 0.0402181737445062, 0.07602358935400844, 0.028224557063367683, 0.0380224667605944, 0.047497462437604554, 0.009827183712332044, 0.04604414803907275, 0.05343347496818751, 0.021845443407073617, 0.005832764945807867, 0.04236184133333154, 0.021046525143901818, 0.02861358159861993, 0.048100501953740604, 0.07395706430543214, 0.011920032738998998, 0.029931762037449516, 0.005278805510897655, 0.04237203473167028, 0.03985937873949297, 0.018128457995771896, 0.0541162025911035, 0.043159056367585436, 0.016714277044229675, 0.039149210206232965, 0.08214396992116235, 0.04608856557752006, 0.025432115107832942, 0.12612673599505797, 0.024869441003829706, 0.055280606320593506, 0.010794658555823844, 0.08328846553922631, 0.07887626401497982, 0.03908584563760087, 0.032927953216130845, 0.03602646058425307, 0.014689002418890595, 0.028625945778912865, 0.03140323678962886, 0.036606296853278764, 0.06164486774650868, 0.06641772706643678, 0.056005929509410635, 0.02912529798777541, 0.04318375875300262, 0.08084372719167732, 0.03561266872566193, 0.028420309645298403, 0.045128204219508916, 0.034513559148763306, 0.029498433141270652, 0.04302252345951274, 0.017776564964151476, 0.03628684309660457, 0.031646215938962996, 0.07695626118220389, 0.016124781723192427, 0.021401041667559184, 0.040350090494030155, 0.019370583140698727, 0.02007379589485936, 0.03384357420145534, 0.09137561166426167, 0.014035168460395653, 0.04827678800211288, 0.03484707289317157, 0.0223780957821873, 0.012839808823628118, 0.09583891005604528, 0.030077067131060176, 0.005526872546397499, 0.007679973296035314, 0.011052022382500581, 0.015545307251159102, 0.04010575692518614, 0.00949121531448327, 0.029230146756162867, 0.06162614707136527, 0.026744360220618546, 0.06427171800169162, 0.06227371544810012, 0.02431060009257635, 0.032492943355464377, 0.03801178354478907, 0.015687252271163743, 0.00923129571674508, 0.027522162527020555, 0.0395018082781462, 0.06580285029485822, 0.011702682731993264, 0.08622250184998848, 0.04575221311824862, 0.07302683414309286, 0.034231082900078036, 0.03939668677048758, 0.13946079940069467, 0.0453415160154691, 0.0752850336721167, 0.07430219266097993, 0.05244958752882667, 0.06578402200830169, 0.03399344721401576, 0.05165308124560397, 0.009033215574163478, 0.016684027104929555, 0.044682095540338196, 0.03447163893724792, 0.0082226734230062, 0.04954931151587516, 0.0290624677654705, 0.09226643378497101, 0.03739414598385338, 0.028753472724929452, 0.0362169661821099, 0.010723658215283649, 0.03977551605203189, 0.06865050061605871, 0.007660610663151601, 0.03696596759255044, 0.04764011064253282, 0.061428268236340955, 0.025068379254662432, 0.09464173679589294, 0.10807620536070317, 0.17205660813488066, 0.10551374754868448, 0.22403449402190745, 0.11113022468634881, 0.18800361023750156, 0.20898644055705518, 0.1768311855266802, 0.12757653632434085, 0.11784447924583219, 0.16169533599168062, 0.13791826029773802, 0.1073897781316191, 0.0814728086697869, 0.10917963794781826, 0.18745744891930372, 0.08805424105958082, 0.1652478039613925, 0.11129584978334606, 0.15807423420483246, 0.12845022225519642, 0.12316981927142479, 0.1325166126480326, 0.0823625769407954, 0.22740779269952327, 0.09358177921967581, 0.03639294794993475, 0.07177184757892974, 0.1551311436924152, 0.14165841741487384, 0.13396495836786926, 0.1494235233985819, 0.1559956418350339, 0.15291235962649807, 0.06694209892884828, 0.15711405838374048, 0.2578834042651579, 0.19200063950847834, 0.11854948243126273, 0.15693319699494168, 0.06466962047852576, 0.18185430817538872, 0.14432921394472942, 0.13996786437928677, 0.21461989061208442, 0.2556570206070319, 0.1528635114664212, 0.06982754683122039, 0.15755177708342671, 0.09393518994329497, 0.11179075096151792, 0.19116119627142325, 0.13043604616541415, 0.19422064069658518, 0.1319602393778041, 0.12640826229471713, 0.1100893403054215, 0.08362566775758751, 0.14303363190265372, 0.20715421152999625, 0.1379780625575222, 0.22012868954334408, 0.10289503494277596, 0.14460787555435672, 0.16538524971110746, 0.11334714596159756, 0.15334083116613328, 0.09154216444585472, 0.08142833175952546, 0.12040565314237028, 0.11414606051403098, 0.1315508410334587, 0.11682720258249901, 0.2665042213629931, 0.1923014468047768, 0.1494491274934262, 0.06418254153686576, 0.2224844295415096, 0.2335881016915664, 0.10413706360850483, 0.22885118087287992, 0.09006971376948059, 0.20235530653735623, 0.06308291616733186, 0.13985931786010042, 0.1270408689742908, 0.075801657512784, 0.11384243305656128, 0.1420481043169275, 0.11326451523927972, 0.1513497528503649, 0.11433505584136583, 0.14497333875624463, 0.11712444014847279, 0.12903746886877343, 0.1080959835962858, 0.13160535920178518, 0.27328284981194884, 0.1301663793856278, 0.13932825182564557, 0.20188736758427694, 0.19344347849255428, 0.0806336326058954, 0.15956387302139774, 0.12688380084000528, 0.09326874132966623, 0.18089687830070034, 0.1159697251569014, 0.18315162684302777, 0.12877900851890445, 0.10730878755566664, 0.10381409578258172, 0.08303831724333577, 0.05278995871776715, 0.146293782745488, 0.16797351941931993, 0.14624451898271218, 0.24188037001295015, 0.10718593242927454, 0.10409180002170615, 0.10110322327818722, 0.1572211948223412, 0.1347888758755289, 0.11638570635113865, 0.09102024167077616, 0.05240039055934176, 0.14775974705116823, 0.12661748856771737, 0.06348461101879366, 0.1619646613835357, 0.08922709414036945, 0.0922273300238885, 0.1789257489144802, 0.17815041239373386, 0.11882595470524393, 0.09604297098121606, 0.23160223325248808, 0.12473819253500551, 0.1636581978527829, 0.12634319078642875, 0.1374394414597191, 0.15181597002083436, 0.09131162369158119, 0.16034370695706457, 0.16935406252741814, 0.1426996654481627, 0.15161542687565088, 0.09075648238649592, 0.2189127993187867, 0.08291415593703277, 0.1442209049127996, 0.18200955062638968, 0.15886184584815055, 0.15194476232863963, 0.11639495351118967, 0.1832582289353013, 0.17146079713711515, 0.051987775004818104, 0.13895279931603, 0.2010775508824736, 0.10221035918220878, 0.2339500916423276, 0.09049702755874023, 0.1313773714355193, 0.1395261677680537, 0.12454331939807162, 0.1445558510022238, 0.0875502782582771, 0.08689441267051734, 0.18158349848818034, 0.12500434153480455, 0.0883347877243068, 0.2534913446288556, 0.1100201127701439, 0.09343552417703904], [0.012896497773908777, 0.02115123104886152, 0.055608468610444106, 0.015158732730924385, 0.052666921765194274, 0.05002997459087055, 0.04076489538419992, 0.04171833621512633, 0.059477948670974, 0.056614386703586206, 0.014863544420222752, 0.04255184227076825, 0.021051102339697536, 0.023973587121872697, 0.043641841984936036, 0.027149737979925703, 0.02598978713649558, 0.054552926812903024, 0.06114025185524952, 0.09792743978323415, 0.016169015580089763, 0.046472255926346406, 0.010101676307385787, 0.022248134591791313, 0.06646761423326097, 0.02278215622936841, 0.01752712356392294, 0.06223762480658479, 0.012883977742603747, 0.010772667792480206, 0.020887193459202535, 0.056845417275326326, 0.02527722517697839, 0.05664940494170878, 0.024917055343394168, 0.0319696290534921, 0.032531590695725754, 0.004613579585566185, 0.04804074051207863, 0.06951018222025596, 0.06712940958095714, 0.03841106270556338, 0.041149101525661536, 0.015898684578132816, 0.09333079971838742, 0.04058946651639417, 0.025260632610297762, 0.04828796845686156, 0.01318928245382267, 0.023528459933004342, 0.018916219923994504, 0.019678281278174836, 0.08121205508359708, 0.01800792022550013, 0.00963863181823399, 0.04164124562521465, 0.03240680969611276, 0.0335879154590657, 0.050610308098839596, 0.054366469630622305, 0.05207489572057966, 0.03648348254500888, 0.018067690944008064, 0.03707336378283799, 0.054628703801427037, 0.027680759485519957, 0.06558859226061031, 0.06545709853526205, 0.05599613687081728, 0.04176888760412112, 0.012672274551732698, 0.045542396837845445, 0.09636679227696732, 0.05671104401699267, 0.04414019043906592, 0.07864067665650509, 0.04241619993990753, 0.01786135348083917, 0.03296800692623947, 0.0106518730535754, 0.08020058201509528, 0.04606501723174006, 0.014658675481769023, 0.03311877793748863, 0.03984338174632285, 0.04296033890568651, 0.02605063396913465, 0.06093711119319778, 0.047776736319065094, 0.04399193530844059, 0.023096722943591885, 0.07396918357699178, 0.008438868462690152, 0.038917630445212126, 0.014238224703149172, 0.09409389822394587, 0.030435329645115416, 0.017984631631406955, 0.013635668510687537, 0.06621485357754864, 0.023010550321487244, 0.01278721189009957, 0.02617936690512579, 0.06151032750494778, 0.018135731043003034, 0.034254560741828755, 0.05430347613582853, 0.09488669747952372, 0.07348111757892184, 0.04721224024251569, 0.0663367216475308, 0.012176903037470765, 0.03911239968147129, 0.01650380581850186, 0.022621112038905267, 0.0848047029285226, 0.023708265616733115, 0.09363322489662096, 0.0135553820473433, 0.041993246268248186, 0.06345043511828408, 0.0574407273234101, 0.007647233915122342, 0.07469176081940532, 0.03875373084156308, 0.04508420228376053, 0.055980488687055185, 0.032439074566354975, 0.05349899176508188, 0.034486967997509055, 0.04763027718581725, 0.01950908645085292, 0.02176279969717143, 0.045642074692295864, 0.06029779549862724, 0.07259292266098782, 0.042835082931560464, 0.02892713342589559, 0.03626586258178577, 0.025598541724320967, 0.09066074533620849, 0.01830339704611106, 0.05451164113765117, 0.07882417266955599, 0.021116912284924183, 0.028556760917126667, 0.0708338174445089, 0.03349994498421438, 0.02271504381496925, 0.03784474465646781, 0.04839079672819935, 0.018241791367472615, 0.03743582128663547, 0.03847681698971428, 0.03413783946598414, 0.0824904118780978, 0.02078543202514993, 0.03103930055658566, 0.03953371320676524, 0.04593232493789401, 0.0543890902918065, 0.03794425923842937, 0.02482518302713288, 0.012417838497640332, 0.0100649566957145, 0.030736326189071406, 0.10993534466251731, 0.059747333434643224, 0.005523558857021271, 0.03648908204922918, 0.061162408674135804, 0.029835648347216193, 0.036454624132602476, 0.06657201214693487, 0.02786605149594834, 0.013605154181277612, 0.03923115444194991, 0.02772037718386855, 0.05967245815554634, 0.045658071685465984, 0.03326997197291348, 0.022033169661881402, 0.024452706529700663, 0.0123461822840909, 0.03286225088231731, 0.05582826677709818, 0.01985380662517855, 0.029403588523564395, 0.026244278851663694, 0.04953775256581139, 0.02457098446029704, 0.028067596540495288, 0.009531831201456953, 0.05759168016084004, 0.08761867458815686, 0.023150725319283083, 0.015048584100441076, 0.012438460926205153, 0.02946799766505137, 0.06793195323552936, 0.04406631334859412, 0.029994152537256014, 0.024692149345355574, 0.02736125563387759, 0.015073131562530762, 0.04174925037659705, 0.02580109423433896, 0.08161904144799337, 0.019402634643483907, 0.07290464694960974, 0.00883193399204174, 0.03343149299325887, 0.02480381659552222, 0.11226769958739169, 0.00654612471407745, 0.0807141927361954, 0.07195056416094303, 0.054944710282143205, 0.028609733562916517, 0.01269432190383668, 0.05789741160697304, 0.04446284285222646, 0.025473291316302493, 0.016312580337398686, 0.05084272277599666, 0.01912492669362109, 0.05306641243805643, 0.032125843717949465, 0.016073859260359313, 0.030500575558107812, 0.006255079442780698, 0.07731605437584221, 0.033001054762280546, 0.025658733611635398, 0.014468416648014681, 0.0332091269956436, 0.05997248248604592, 0.020074801504961215, 0.011104429140686989, 0.021946373635728378, 0.01983798218134325, 0.039509775233455, 0.07602381199831143, 0.06437172240111977, 0.020244354418537114, 0.04405899948324077, 0.04875235252256971, 0.036595235142158344, 0.0349407950125169, 0.06346840993501246, 0.030121913259790745, 0.041358969756402075, 0.04334524266596418, 0.03364862684975378, 0.033416338337701745, 0.050572952095535584, 0.006759475936632953, 0.07359368653851561, 0.008905760987545364, 0.05809935741126537, 0.0555585183610674, 0.06794828790589236, 0.03376788255991414, 0.01921269122249214, 0.02441196262225276, 0.029781690500385594, 0.030655940463475417, 0.0589611467148643, 0.02008585950534325, 0.03909124105121009, 0.039209134920383804, 0.06223172844329383, 0.0410716918122489, 0.05133937913342379, 0.013447628698486369, 0.044944808396394365, 0.09099233691813424, 0.027006097152479924, 0.008918858038668986, 0.04001606837846339, 0.07611183071276173, 0.10737989272456616, 0.05873880298167933, 0.007143590701161884, 0.017102156816690695, 0.05388940597185865, 0.035303605036460795, 0.04140401812037453, 0.014244244448491372, 0.024142624242813326, 0.07500196370529011, 0.006508033984573558, 0.056381749382126145, 0.04914850724162534, 0.015377755353256362, 0.010477132527739741, 0.006574004883077578, 0.13252393022412434, 0.027399620958021842, 0.03878080809954554, 0.04106888278329279, 0.048483231221325696, 0.014993727327237139, 0.07409345620544627, 0.06748255313141271, 0.04807023717148695, 0.005894759324291954, 0.08899716936866753, 0.09519251427263953, 0.02270953522383934, 0.06284816001425497, 0.02566380990174366, 0.019399278280616272, 0.08058810926740989, 0.04165756545262411, 0.023584852024214342, 0.08813446722342633, 0.008944753426476382, 0.0394806719123153, 0.05752377364842687, 0.0417046213260619, 0.027579647430684417, 0.04365469598269556, 0.0562377690221183, 0.019245508992753457, 0.03556966868927702, 0.055202628864208236, 0.07587596875964664, 0.012777167848980753, 0.01334774489805568, 0.01675811014138162, 0.10425035245134495, 0.01628343805350596, 0.04078796504472848, 0.04977919175871648, 0.05344479272025637, 0.04391085196402855, 0.013747260618401924, 0.06596360690309666, 0.07675216314964928, 0.045388794533209875, 0.012122473926865496, 0.08983881678432226, 0.04327987800934352, 0.014102221502980683, 0.055971297188079916, 0.023047694812703412, 0.05557091593800578, 0.037139930718694814, 0.022934502449061256, 0.023975763469934464, 0.018298816139576957, 0.09278756246203557, 0.16357993095880374, 0.16327648161677644, 0.15455081389518455, 0.17590473289601505, 0.08875957078998908, 0.11768911805120297, 0.16774242947576568, 0.1517287825117819, 0.1481307318317704, 0.13891158043406904, 0.11864664440508932, 0.13887769397115335, 0.1266688748728484, 0.1265887526096776, 0.16699639294529334, 0.13417820708127692, 0.12003333249595016, 0.1381144841434434, 0.09626712926547043, 0.19245177623815835, 0.11712644394719973, 0.2004239265806973, 0.20693386788479984, 0.1358343689935282, 0.16451050993055105, 0.1124026368779596, 0.0818708966835402, 0.09797183505725116, 0.06310927725280635, 0.20170190487988293, 0.13199936540331692, 0.21626762172672898, 0.10293396800989285, 0.09110592262004502, 0.1164162828354165, 0.09927296836394817, 0.2342902624513954, 0.09869680943666026, 0.14382072404259816, 0.2795754902763292, 0.10807422382640652, 0.18577028007712215, 0.07065010620863177, 0.32140008348505944, 0.1050840959942434, 0.09084024859475903, 0.11769383068894967, 0.11553166506928392, 0.15056004835059866, 0.10448045533848926, 0.16972288023680449, 0.1701375626726076, 0.12931409699376673, 0.08694283038494177, 0.17510423756903037, 0.15638902463251725, 0.09292966889915988, 0.11391447333153337, 0.16098039544885978, 0.14520499273203313, 0.09371491309138946, 0.0959943157795351, 0.12245962105225772, 0.16532197420019656, 0.1549739419715479, 0.15645725768990815, 0.20461297914152965, 0.0759866600856185, 0.13571734714787453, 0.0882670222199522, 0.12558997026644647, 0.14486453990684822, 0.16230633133091033, 0.14032422885065898, 0.2559812500840053, 0.15239284140989184, 0.07920415227999911, 0.11743668394046836, 0.1552184351021424, 0.16629791323794052, 0.14136610028799623, 0.12281253453693353, 0.13634133007144555, 0.09614144655643031, 0.174124498735182, 0.07764009831589647, 0.09855938595137559, 0.1186188732390292, 0.18102375586749986, 0.12643793335882947, 0.15506292547797784, 0.09165594310616143, 0.14311414008261636, 0.13381243217736483, 0.1474506573867984, 0.21059077087556943, 0.11846825436805375, 0.07176226645242423, 0.19687702471856028, 0.20866179547738284, 0.1198275646311231, 0.07498529506847262, 0.1143310334009584, 0.13775843137409538, 0.1631022253422998, 0.23571466648718342, 0.18759630474960431, 0.1489591467543505, 0.12939806358190253, 0.12822389689972624, 0.11908795509953052, 0.08280128269689158, 0.075047093705507, 0.2488429768709466, 0.14023975760210305, 0.11959552473854274, 0.14767411805223674, 0.10557580593740568, 0.10958385610138066, 0.08786996579146944, 0.30192850332241505, 0.062181169632822275, 0.1911627547815442, 0.13565196393756196, 0.16886761441128328, 0.11742678369046189, 0.13954328169347718, 0.11537683079950511, 0.15644269675249234, 0.12715118180494756, 0.15737438894575462, 0.16966079216217622, 0.08746249703108333, 0.15574540448142216, 0.16249459935352206, 0.15043667372083291, 0.10879110879614018, 0.19462025753455237, 0.1177845656638965, 0.38250092358794063, 0.09379821916809306, 0.13905273692216724, 0.1352821517502889, 0.13292077142978087, 0.1163229726080317, 0.13080467091640458, 0.19297542079584673, 0.11894186332938261, 0.20499151898548007, 0.13199604058172554, 0.11999270733213052, 0.12855798209784552, 0.10663066495908424, 0.09577242846717127, 0.2788922394393012, 0.11957286696997471, 0.14269314939156175, 0.1764122283202596, 0.13146734941983595, 0.1694915082771331, 0.2020563546102494, 0.1035408370080404, 0.1501685951370746, 0.13481434638379142, 0.1126306840160396, 0.2402891163364984, 0.12493368907598779, 0.12697366008069366, 0.09437931337743066, 0.14292360108811408, 0.12837113899877295, 0.09445539835724048, 0.12417794525390491, 0.11434733838541433, 0.10315311679732986], [0.03890532192599494, 0.03598269242502283, 0.014609745685447706, 0.01206569777423283, 0.03855894676235039, 0.02450658088491764, 0.08080019280896522, 0.022560955403605476, 0.06290868957876228, 0.030201076297089458, 0.05981880967738107, 0.04157091228989884, 0.027195732582185883, 0.07087932594004087, 0.018351399157836568, 0.05463988425617572, 0.055888647912070155, 0.019109606910205912, 0.026269480331393424, 0.03794687901972793, 0.024238051446445752, 0.026542867126408964, 0.07000761412200518, 0.030027441571292002, 0.030464191768260207, 0.07371630417765118, 0.06320376007352024, 0.04478135408135131, 0.01874238110758597, 0.058086644421564415, 0.040038856022874825, 0.018962630128953606, 0.08148342880303971, 0.011083110020990716, 0.074351352523081, 0.023237302411871497, 0.04248568351613358, 0.024902435034164228, 0.03304028097772971, 0.027445311279734597, 0.02156826238206122, 0.046673537508468144, 0.05062012671260163, 0.04117000411497429, 0.04439124415512197, 0.07771964912535623, 0.03355723136337474, 0.01996402112126816, 0.014954056750866584, 0.008503510453010676, 0.03686761818244122, 0.018257376468682196, 0.024757664286880754, 0.039201505642267875, 0.06042606459232047, 0.058821723141591065, 0.013602957424154738, 0.05414063038188033, 0.01502423794590868, 0.03901711534126662, 0.029778068819723558, 0.03273541784437839, 0.012152761901234044, 0.046735050418647006, 0.028693069325527176, 0.034217805878142826, 0.022421997527999338, 0.03691575759148691, 0.02357140059757512, 0.03524335377733223, 0.04158342118898872, 0.02713424193643732, 0.06499177194200456, 0.0521168493287405, 0.04322481436247472, 0.014081529498071177, 0.014895849180902587, 0.051499987312126905, 0.03887432612827979, 0.03887479368131608, 0.04096966877114028, 0.028534613375086337, 0.04570102348225191, 0.033107204144471325, 0.04978831275366247, 0.044036044855602086, 0.03553310678398702, 0.09239731152774766, 0.04560776520520449, 0.04698923228716012, 0.02804985735565424, 0.006885231005071546, 0.06552058926899917, 0.0706574237847235, 0.014067370248085354, 0.06384137624991126, 0.04035077698063105, 0.052574977089534514, 0.029436016666295473, 0.022160717016959097, 0.06422358230338432, 0.016267548671748955, 0.035667721240315586, 0.039717799227219075, 0.04274375052773394, 0.02642282473971136, 0.028851823990407865, 0.0555212699691765, 0.03454510784649756, 0.11089163905126043, 0.031691542608314194, 0.015572607153444551, 0.013609595007437747, 0.03603611221478786, 0.06175167021865491, 0.020270819404686335, 0.057349372655153275, 0.025657720580056775, 0.04844840594159905, 0.01235854553669924, 0.060004747356288135, 0.03385479918506462, 0.0675328410579823, 0.023873380487202667, 0.05617433023871854, 0.0375778794841608, 0.03253015092923306, 0.0311021901507047, 0.019080162201134954, 0.020385371753945947, 0.0030285471939350828, 0.06131767338956706, 0.05173970843316056, 0.04343043750850484, 0.014991845055192243, 0.050675223756115884, 0.019090850983047858, 0.04747626298922114, 0.07236877179821022, 0.0807131092005875, 0.048989747010637075, 0.038197480025701225, 0.020087332668481395, 0.018365650248597376, 0.019105000028503127, 0.04464527388336137, 0.02381556903856108, 0.015580887666146737, 0.03198131045792252, 0.04622504653525539, 0.06209142542502377, 0.0391837720235344, 0.05919230345170945, 0.01016706879454432, 0.041690950965858065, 0.030317025739350356, 0.023417369702656288, 0.021212267129158136, 0.008707633533049375, 0.024724143331695814, 0.10324506889446639, 0.04778407987032551, 0.03797639423282817, 0.06681018217932433, 0.09074132773093879, 0.01801486487238435, 0.022109616438683588, 0.04348279602709226, 0.03354770589794498, 0.11890328649315052, 0.01859148764197016, 0.04948256646457594, 0.07509780465625226, 0.01884277142380597, 0.029625256902363617, 0.015032456303742947, 0.05227212517638691, 0.05457155100884847, 0.05420746820163913, 0.09167511278064921, 0.041909999563358724, 0.02305544840055518, 0.04359080448921304, 0.0254587489325786, 0.03141935623716563, 0.0429669811273925, 0.03124330767604988, 0.010257248086418258, 0.029250878651509993, 0.023748762760078534, 0.04631785210222006, 0.03169923867972102, 0.037386602052720264, 0.01191555944387801, 0.04955754935508594, 0.08217383394367062, 0.04583916314004455, 0.049749750760383904, 0.02739343144639861, 0.019208015692129266, 0.024738019637879916, 0.0131021867855452, 0.026901660276053008, 0.01035905683238525, 0.03595145171857439, 0.03396312677068636, 0.016707907561794855, 0.060448366130003706, 0.04852173755352851, 0.03193028780515306, 0.04802972704055719, 0.021826188385603018, 0.009357346716569737, 0.03765654342714697, 0.01913693835376762, 0.0477802095701918, 0.03542640079103876, 0.05192256248847116, 0.07711131809628569, 0.013739377154706744, 0.0028250419518371928, 0.0759143749019131, 0.0403087380254874, 0.03515695294481702, 0.021134000235178974, 0.029887782366131432, 0.04947570902004372, 0.005171385200810619, 0.027551711136766244, 0.05225475149927661, 0.024909056846809108, 0.050255257228855044, 0.015083483594935387, 0.05950565304374322, 0.046036693165660836, 0.014076712031965144, 0.018709585601754952, 0.07302972109755501, 0.018660067653399892, 0.09927247112500481, 0.03466230409685522, 0.08509169143508188, 0.03526738080836367, 0.03588856212445535, 0.0022333953302222653, 0.022708865435561165, 0.050461065911804326, 0.047049242348293774, 0.0761028061970137, 0.007977697896421887, 0.029272087376739364, 0.034672842593863606, 0.022757611550332513, 0.023767667116771918, 0.08642307468107902, 0.034869533992605284, 0.03469112911261618, 0.02342806961678434, 0.021609893155982718, 0.08590210185502656, 0.04645973218430299, 0.09397618618095294, 0.03611823827668559, 0.06192612316226587, 0.008153593389579328, 0.05287843385303859, 0.07687726698350161, 0.02201856048486661, 0.0762120725994464, 0.09622328318073414, 0.04730002889118623, 0.06624264700803906, 0.0333987531485036, 0.04220454684400465, 0.025177105744660366, 0.048166545675485395, 0.02434784848446725, 0.035574800640461035, 0.028970541643502656, 0.029737059594481252, 0.03274778944614809, 0.08367421905859374, 0.039996843042899854, 0.003725050237335381, 0.04942180683428887, 0.06810678096371703, 0.029256702655402478, 0.06878706321003847, 0.02837089374224888, 0.027510156432981603, 0.06373956843162887, 0.015762524599267635, 0.048475104704266414, 0.016205612737394404, 0.01788059737009462, 0.01884037243144121, 0.036131374290562235, 0.03296618124295492, 0.022813688228779938, 0.042843769770115614, 0.029018976056249812, 0.039537594639114104, 0.043426359407021664, 0.022428066440625116, 0.02616529949591495, 0.12412811745889485, 0.034516186351538636, 0.02925445765868062, 0.0386193204758456, 0.09297902914113365, 0.024047582955972757, 0.048585777476546355, 0.025857796172203962, 0.02516529075364815, 0.08210432439227588, 0.030007373898115475, 0.017902325598697644, 0.05076694578747265, 0.019677934324136004, 0.02378218723606551, 0.08039363689022139, 0.01737582562782336, 0.022610814739891794, 0.06772315740818158, 0.09040916469530202, 0.033250601918553, 0.027120052072859835, 0.05710222263587639, 0.033826894432422705, 0.030018919860594906, 0.0305068634042982, 0.08059126339503564, 0.09716847504023463, 0.032591712079010904, 0.06023650894348975, 0.10111667841556482, 0.083822841552319, 0.003696635722008068, 0.04200151750410441, 0.03924536285921931, 0.06814002175815403, 0.038372085109585896, 0.04052083269925788, 0.03039845232706284, 0.023368102229142096, 0.031992346193874255, 0.03342083946336061, 0.047727747150929645, 0.02813583330862457, 0.010771757733891718, 0.024650952727824915, 0.016775238909758627, 0.1009351342509035, 0.35800541925709695, 0.16913615312660113, 0.14703107677632943, 0.09418382425792515, 0.19677980337291956, 0.1468303258297965, 0.12605097756022587, 0.1962741484749131, 0.17016994999721646, 0.13223063346231356, 0.09886639018077403, 0.09155763080343604, 0.21525163640035316, 0.12035264153382741, 0.11944633079110645, 0.08727308610104956, 0.1283213557326235, 0.1337490082369186, 0.14668045652797446, 0.10968228714773431, 0.11053501482820138, 0.1253239400102757, 0.12734074116451666, 0.13090687949443236, 0.12484586331993341, 0.14215439470717683, 0.25992950540967286, 0.12802890501916409, 0.2520205860491842, 0.153892335947603, 0.13150016719009727, 0.14183576102368534, 0.15830352815100923, 0.2958002337254584, 0.135392613010481, 0.08964964334154502, 0.14245855651097372, 0.11481521054520272, 0.1421101181767881, 0.13935237162513658, 0.097891089390032, 0.16863075055880472, 0.14645214221673086, 0.1219866874453146, 0.1411046861903742, 0.16986897942842916, 0.09570887836162001, 0.14037905872100964, 0.1341603955370374, 0.13400012132478878, 0.09177163650747389, 0.11950934655033052, 0.1644373341696337, 0.08396427263505757, 0.12429884853190742, 0.0760074179561343, 0.1610019919462502, 0.09251048162695952, 0.11218039333471097, 0.1261504995636642, 0.19906879460904747, 0.10104303510161117, 0.1547683373792097, 0.10363375389715657, 0.11584908905206248, 0.12608649674803019, 0.11157984743476845, 0.09152323225862347, 0.12376730010146275, 0.08305157200084068, 0.09879060948151164, 0.18264834681758657, 0.18058130226563662, 0.1950709638185799, 0.10181617486523464, 0.2157187441480346, 0.1477719479589723, 0.19430120824836195, 0.1522449016920291, 0.1302722838590853, 0.13560259627411142, 0.186516776739154, 0.1151059617404826, 0.14800910867052153, 0.20687437732703984, 0.21925014996668324, 0.19478232774417847, 0.14708078582771122, 0.19115614966722205, 0.11456915890448727, 0.22374806954758242, 0.19926280685467646, 0.23364264954579994, 0.15975637128576636, 0.14969635172747076, 0.09446250813198276, 0.129479625611566, 0.11796131555456668, 0.1281315737287514, 0.15411183354444802, 0.23139493656344712, 0.10197605573921464, 0.15948164305882528, 0.1330122782383114, 0.1972947351168841, 0.08729074179427698, 0.0800003951007966, 0.14163449057377875, 0.3272284066770226, 0.07607873092638329, 0.14645542250946164, 0.09775200349395163, 0.11846044697449543, 0.178906274959445, 0.21561528876191005, 0.15714788547484204, 0.09828746304265223, 0.10558801426668651, 0.153006745968014, 0.16219092736719176, 0.12102918335585855, 0.1465476120938547, 0.12497652583988383, 0.13790380326099694, 0.2212952566333115, 0.1651559557649307, 0.11085008620284498, 0.11209987773327157, 0.21569122531218454, 0.12374413025099784, 0.16444374632555991, 0.09785300979274325, 0.2240796759724617, 0.06867093936307356, 0.13977621216326952, 0.09233949080226012, 0.14972636417951435, 0.18086287309415638, 0.2350897336145863, 0.0984534592134878, 0.12654420890612528, 0.09389431987074204, 0.03765783847484272, 0.11509698175359517, 0.14069133962038904, 0.19671182264573872, 0.1622082045651041, 0.09778502906556241, 0.21388632216257975, 0.11041650868719444, 0.23939953360240906, 0.14815400558291003, 0.18254379305290058, 0.15602871193550527, 0.15383805526653305, 0.1578496751608327, 0.13521249376935884, 0.10933712910627946, 0.2422118280082941, 0.24242587824119255, 0.11397177455364726, 0.11605156178120524, 0.16629237681627274, 0.1406741960090585, 0.13758153305388987, 0.12103009619750082, 0.14843437413219362, 0.17265727277845144, 0.2836746984394267, 0.1549711069674231, 0.12591832608450204, 0.09539966253214516, 0.16809107561130077, 0.0858856484410353, 0.1619844915694557], [0.0742930790875107, 0.0194697841652669, 0.09274062904296443, 0.014780855253775371, 0.07358384566032328, 0.017130033738794737, 0.029974014360050205, 0.04396211952553131, 0.035340408139745705, 0.044737385542248376, 0.05239612692093942, 0.026873172937484924, 0.09882788013783284, 0.07640482319402508, 0.03286399121861905, 0.041341169344377704, 0.02754530454694759, 0.040912297044997104, 0.035886309706256725, 0.052074832638027146, 0.0871081289369613, 0.023684524312557187, 0.04516233930189628, 0.07388438578345813, 0.1254224230069667, 0.015003881762822857, 0.014635367406299338, 0.00977020810751128, 0.01564048397995066, 0.06322005021502264, 0.04478130955249071, 0.035456220284686424, 0.01466255598643329, 0.02039541672274936, 0.05970916849037167, 0.014176132917782525, 0.07516750716604292, 0.01255378881978686, 0.03396206178877037, 0.010704871674533933, 0.008782333479757654, 0.07166047347709537, 0.04816623026272282, 0.03538869226758834, 0.02791302202240331, 0.0517785635747714, 0.01139536401751684, 0.038838606560602784, 0.01947880125953816, 0.043127336975885555, 0.10391969597549178, 0.06523840987938456, 0.03475492412690073, 0.014596400942537002, 0.023432502093783114, 0.10778829659102485, 0.12051854122546501, 0.03206206354661845, 0.021543905095313676, 0.035401345885475166, 0.02835103943652939, 0.054850012238603085, 0.031501137200393714, 0.0712313043186441, 0.09770715550985187, 0.027561698589124717, 0.0340649902500445, 0.043199633291806094, 0.054907024023123085, 0.01449983546990552, 0.07633256027475, 0.09327144274720922, 0.06335257552564144, 0.029532657281379215, 0.04019183492346201, 0.03501057544781361, 0.00598814794102509, 0.03821002974291332, 0.07074025488691404, 0.030047629843465984, 0.051778712004306726, 0.017463599433540367, 0.0363942652620608, 0.05127567688759882, 0.02776911402179394, 0.013267996491777012, 0.10503400844754651, 0.0424923183163628, 0.04981207261153031, 0.05379239984904416, 0.019001155014848337, 0.049911386813619174, 0.08428509565419517, 0.021696119583793916, 0.03151640688884072, 0.023355788143817335, 0.038446975231636316, 0.036909497575834394, 0.03395471823750995, 0.01577732302393997, 0.026020307959697675, 0.021146874641999602, 0.014910623485775432, 0.017171334257000126, 0.02000962424062891, 0.006314361271506641, 0.0560854357900098, 0.014351524678204441, 0.011120607032353291, 0.03361862552992534, 0.049430070648668334, 0.012069882559444522, 0.006336099240797921, 0.02774001070065424, 0.015221355151879834, 0.04426601044542622, 0.0313269848265918, 0.04095194999536034, 0.04351460447651334, 0.06017758983944077, 0.035419509949861094, 0.014017766025062883, 0.06317052670056, 0.04903830573312007, 0.0038802660174042103, 0.01793616196664516, 0.027570361307880376, 0.03446545313636307, 0.046367275426746346, 0.0048960001731757075, 0.020425152724783402, 0.04473719258385245, 0.020077668050362263, 0.10034533464931883, 0.034224982446176, 0.04499200527789071, 0.013025483967794571, 0.05484174100274686, 0.02986489638715284, 0.02821591289830394, 0.07326985039981082, 0.13133745873346925, 0.060003311300533824, 0.06609202071558684, 0.04634462879039347, 0.03324422687001061, 0.054837020943523385, 0.012756211453961441, 0.019611044554039836, 0.02532844264351297, 0.020006959930469748, 0.01622797364689177, 0.019095667521469295, 0.03826134925475344, 0.017465946475567762, 0.020568359395838343, 0.03597888149670325, 0.07467449104296975, 0.04520792201219592, 0.0637220760108903, 0.055830489509389736, 0.07091594350640662, 0.03984305891208351, 0.06331471857265569, 0.0498607203917345, 0.036821011308347806, 0.08662040432682261, 0.006774106450393447, 0.06078714912291616, 0.03241128484660294, 0.07998261324246414, 0.06959961843676865, 0.03510233458655421, 0.030362901597982273, 0.05479834020661656, 0.02200857303250814, 0.041748133444343694, 0.021233390507404692, 0.08958466089097783, 0.01034391423672787, 0.07216342695755884, 0.0524978939210996, 0.021018394036218524, 0.0034601965171532356, 0.03050634575629374, 0.020485209170146845, 0.05024524565669708, 0.027519364630279597, 0.0796417670790106, 0.1400923077017069, 0.027841944684041664, 0.11740601097699255, 0.008415755200985586, 0.071618059737375, 0.04041148094984237, 0.02602923043014016, 0.018854744121199474, 0.048415306155220605, 0.04152846886427142, 0.0740067585138604, 0.05983511837257538, 0.01043913456669543, 0.04640918821678497, 0.02821114831021987, 0.04271941550541669, 0.09234962111804634, 0.09951467844075523, 0.08051605414948426, 0.043819070560857654, 0.018048148340312764, 0.039886504237074405, 0.012438300436770078, 0.0457974321761867, 0.049840719511848874, 0.05721412737329956, 0.037844462640350685, 0.024195698933908716, 0.03640176095359493, 0.026198742525593843, 0.03307148457679432, 0.05000084529456217, 0.05941072493442334, 0.01284179592403234, 0.061772105254931375, 0.007725111181571265, 0.028222672008269, 0.04599574145686347, 0.03984985327406321, 0.029913397593190894, 0.06697001852444373, 0.009660840587457642, 0.04959657147992402, 0.028859508929599542, 0.06944220149307512, 0.0319814477552427, 0.05642143572913483, 0.02257048643514281, 0.036626000874093734, 0.04186068013950717, 0.05557723532547243, 0.03588073988794349, 0.006410429969037068, 0.023066922003636137, 0.029841926916560624, 0.05690009129466489, 0.04921668834867887, 0.02491671395546291, 0.037177090052864514, 0.055326151923509315, 0.019823784896289, 0.04941732797306031, 0.002639317408466013, 0.03972533202613704, 0.011742854258045554, 0.01078727418644121, 0.017141542593890335, 0.06097639306972269, 0.0291322500561364, 0.005763031358583248, 0.03629482860560529, 0.048501937053515576, 0.03547969441569876, 0.08999462326755747, 0.10651099364622496, 0.03684749855892733, 0.07172330369940028, 0.04395241594465915, 0.013312825922184857, 0.029308664124982897, 0.041591492044972256, 0.017236949388461653, 0.023383128864225, 0.016517953008587938, 0.06004524264426436, 0.03705642797285691, 0.009273535979446024, 0.017130204432760365, 0.03857263196550775, 0.008265171582024777, 0.03413678932702169, 0.0643049884820357, 0.03326271005789749, 0.010537804955674801, 0.04511040009674616, 0.10660742089385167, 0.04642875865101814, 0.007308261210710043, 0.043574614537646994, 0.041234032905776985, 0.04634520024410449, 0.005687762741217739, 0.03160022875817958, 0.010797732902574353, 0.02758570892183343, 0.048446932778460905, 0.029995955956110265, 0.016564120160182938, 0.037363766168709844, 0.024886412065825425, 0.03664587187813595, 0.04368045221781358, 0.03099368816037895, 0.00214646015137987, 0.005888322120881639, 0.014073544916755054, 0.05150157550815493, 0.07111457933206111, 0.08044275222346187, 0.03553577480488457, 0.05958066562016029, 0.015944601254886948, 0.03434281694353558, 0.013023097035329556, 0.06951733652385883, 0.0351782043435378, 0.035914403706556186, 0.03378232846444007, 0.06308123891358264, 0.07841723825549707, 0.024164439673768356, 0.01494442831244669, 0.02271645760629326, 0.0523853101185523, 0.0239273086481262, 0.02166268397559179, 0.03252280366723426, 0.06651586867519654, 0.03425723247346468, 0.011414710879762424, 0.016524558122910094, 0.040859315122361295, 0.041426401294302195, 0.04899767314782366, 0.05021357450459618, 0.057270500910817645, 0.05375422006181907, 0.04743108103866689, 0.09675965557107702, 0.028735618507198524, 0.014323340692499187, 0.02861235334421508, 0.07496383957914077, 0.04123750244616531, 0.007035142052700394, 0.024852110000210814, 0.01682173075096216, 0.05768470837210771, 0.025196381175192073, 0.03818523829977494, 0.07101076771505177, 0.012861650229751831, 0.031209495427901857, 0.16914859152166173, 0.1201919888262637, 0.1992473256541416, 0.13815424841595814, 0.14385596121428534, 0.19959712954005226, 0.0751843761827331, 0.1327154043246992, 0.13235906953923404, 0.13727248791838065, 0.18866600672481582, 0.11607970402110368, 0.21981275727739558, 0.20776602323167026, 0.08180206248653121, 0.18759649770800024, 0.14064765680814162, 0.23786404490238056, 0.10598699285765179, 0.10282240094966255, 0.15885139640886337, 0.0989197134913411, 0.15838430350413546, 0.16425130743300542, 0.150492824614048, 0.08949765891884454, 0.11317939090076834, 0.09112615356571041, 0.14182681072270498, 0.26161631802096963, 0.1633582217618823, 0.21922242332948372, 0.12128203306929208, 0.10324636765290052, 0.13650708133354783, 0.07495936442865059, 0.14227297506295145, 0.17345205356832594, 0.14629635057644919, 0.09567773042363115, 0.12153762872912921, 0.13547757407650352, 0.07413082334096543, 0.12943407258717343, 0.15294111042749137, 0.17411430162610486, 0.11233565805014223, 0.10247181038721465, 0.1352201378904283, 0.10951963806292042, 0.1989697030512616, 0.12779869080986828, 0.15584378357743844, 0.1168262748979032, 0.10153435912798159, 0.1641187450150028, 0.1813382632099092, 0.1749238363117911, 0.05844316845468711, 0.07933253640658222, 0.08768715255428106, 0.1262136414879933, 0.10204293066635728, 0.19691003544721752, 0.12100670370273292, 0.20796732336748391, 0.08694677118910477, 0.21492623433005065, 0.18070038728183135, 0.11074275680584833, 0.13388283230597153, 0.18777572637191042, 0.14409289928153157, 0.08900280969101004, 0.15904908970696852, 0.07240784587338567, 0.15522342233452946, 0.28388935723342, 0.11281228013103828, 0.13075687660602853, 0.11109920291346498, 0.1408340546186082, 0.07630616950336844, 0.14133639953797683, 0.09594674411346205, 0.10992068724590354, 0.22987780859693885, 0.2478921669535339, 0.11819949300843291, 0.14447317575104535, 0.10084623980219476, 0.13626192027004436, 0.17075792391551659, 0.20326449681306258, 0.15412186738103628, 0.06438589000026695, 0.07909864114481024, 0.18640358437551185, 0.15809081378392875, 0.0686782124103047, 0.18576630216557533, 0.10883539274800569, 0.15663339901948348, 0.11073425179347396, 0.15454370412044227, 0.0682492955820635, 0.1049017057812307, 0.07153438258683309, 0.14327634387882426, 0.1262211223365739, 0.1299822228611447, 0.09985964352381416, 0.13314875919604674, 0.10242466174531728, 0.08580434616305865, 0.10427030880236998, 0.134002021222841, 0.11409686354454607, 0.13063655962469056, 0.1338081425637938, 0.13492713798768818, 0.0978724095330108, 0.11143400799483061, 0.13682424556463957, 0.10930546166491695, 0.16817103460198268, 0.07405927288345993, 0.1223749494238291, 0.08248825222835876, 0.1896150058018975, 0.12046285788528621, 0.12295058884774335, 0.11267574722296558, 0.25150642613880336, 0.1168720876739826, 0.13762444403255358, 0.06448165673646145, 0.12052713529556058, 0.09905701081152074, 0.1325784929213114, 0.23477590904803947, 0.40074021206237376, 0.1387138871359639, 0.11813125252956524, 0.10569921767455526, 0.1877002202672884, 0.1716286560986191, 0.14411602460313588, 0.11659745592623949, 0.14860122377285734, 0.11727262477506883, 0.1089850690914318, 0.1700033972156234, 0.13713599211769179, 0.10563024989096448, 0.09166475982056, 0.18200465245172381, 0.0866505726298783, 0.06163917918456718, 0.1668600455741398, 0.16458567464724183, 0.21174910012632608, 0.09978729154681787, 0.08621335859061219, 0.07124456649762578, 0.135184618702624, 0.15504499519011006, 0.12155918069765903, 0.2506126428488642, 0.0662832499074284, 0.3003988182172179, 0.14369895245181397, 0.14561878459062427, 0.20966945390682667, 0.1609915870358236, 0.11027103289961815], [0.04250092351867352, 0.006649241495324532, 0.038535602507181466, 0.02001145920075942, 0.06004963244777173, 0.06430303663364612, 0.05111410020617768, 0.027763338257500436, 0.06426826701499522, 0.006479482171926065, 0.017834398677223362, 0.03606125246733427, 0.024066615333140362, 0.022158384817885235, 0.00666380243274034, 0.034629163492354564, 0.022667037992505357, 0.05780067265732214, 0.041347091682837345, 0.021358986014092807, 0.025925131230906118, 0.052498847580864094, 0.006099235388319357, 0.10154616669751704, 0.04245184158207849, 0.056722120571066625, 0.11176375162904151, 0.084131448820699, 0.05113095809065271, 0.09011514062876813, 0.0964568073686678, 0.03859590942738578, 0.009728962322697043, 0.07130770842195489, 0.073628790123621, 0.08485202968586236, 0.046156086173141375, 0.05902290082303807, 0.038587723538512364, 0.023797315916453954, 0.04617334852810018, 0.024785882596916053, 0.08200044598197564, 0.028122172225266695, 0.03449535426625516, 0.042849473175010644, 0.030654276197310537, 0.043662737152772024, 0.040941778861451894, 0.04248865581757855, 0.02414812355709728, 0.024448437325190753, 0.00866642949404195, 0.015588288733852096, 0.06910851705470122, 0.008837142013362609, 0.03819922778347973, 0.031158287238213234, 0.02975478764710715, 0.002009547124544042, 0.046209264764911495, 0.013624285820696969, 0.021107846951053943, 0.06801871029892936, 0.012204676986584673, 0.05120051959238481, 0.027619886677712202, 0.011026227184629533, 0.027413673524279147, 0.007192995008153957, 0.009238710699719377, 0.025876800718833692, 0.042825973068829626, 0.0009449956542084692, 0.055915547054610215, 0.08358532460988499, 0.0237627800743212, 0.022859254240756854, 0.013492161269823555, 0.009254167780454736, 0.06760278105502948, 0.06097561010392383, 0.02047541282081511, 0.03281010016507935, 0.04114392875635531, 0.028771918805432506, 0.03794911288423464, 0.019890038274752442, 0.023300179018406197, 0.023391084687318653, 0.008502775726810796, 0.05704466166207567, 0.03730966731382068, 0.06170757922518533, 0.045809610819560476, 0.04922336396703031, 0.07165399452787824, 0.05650225932186004, 0.05302375750034116, 0.016446779191028327, 0.031265976576833054, 0.017776381282601506, 0.012348931013548281, 0.08155635965522379, 0.03556265539373271, 0.05769887226051651, 0.028417983012332115, 0.07641389966011047, 0.03996013641881291, 0.10552631953032687, 0.035047018609475344, 0.03748168972379062, 0.027837842462759, 0.008448215812677518, 0.017504437964817043, 0.024993346269184258, 0.007307343266802491, 0.0339974659436848, 0.025778193412406836, 0.06774390785722062, 0.036042116189491935, 0.02877856844861526, 0.021417038660729304, 0.09486839611781761, 0.030757030253880657, 0.07363051932770759, 0.07552479190053418, 0.020869827203569002, 0.029965472240292, 0.042387289577163756, 0.06126386026153341, 0.035840315103996545, 0.0797597537166439, 0.014706125621160027, 0.040545475712860934, 0.018762445070024114, 0.04761084775964264, 0.022313133740681224, 0.04572282407025341, 0.015845229536353145, 0.01507846111053368, 0.04719833239505533, 0.05177508661290631, 0.001377315809349966, 0.019358554782229476, 0.07030779059277847, 0.01642963743506698, 0.043720209068851545, 0.02401897687377641, 0.05445992086606566, 0.027141765458509326, 0.06533831779961474, 0.03393468025024049, 0.06268177792662755, 0.00801389614935033, 0.08968378955614753, 0.05472622942761518, 0.01150584012066247, 0.027075254183728248, 0.11131451479741372, 0.0133798539172858, 0.027521596639417112, 0.08793672197498381, 0.022046706435503438, 0.01621120853087632, 0.03224997904908378, 0.020076970431546215, 0.06525175369461067, 0.05681887436367106, 0.06869544507935643, 0.09009289846289903, 0.018979180022142828, 0.018206821368949022, 0.05008871557947714, 0.06084917040425353, 0.015027947756607318, 0.025523421536490787, 0.018160810068366118, 0.019682168276631273, 0.03650840386399068, 0.02934109783382155, 0.03408592252526432, 0.03609837469412014, 0.07181340784882195, 0.07538583959103562, 0.04604296060279012, 0.07050870481180027, 0.027348537078069057, 0.013006632489123149, 0.03672093640489038, 0.04719222823041491, 0.00752502631257812, 0.10324762188247405, 0.054897394657018594, 0.02885611917008646, 0.03371314916876145, 0.07812254625605419, 0.06377844212693162, 0.023873044665378984, 0.08012483100173995, 0.017623465464566834, 0.051881774052162655, 0.006802477364544757, 0.019975739633082412, 0.06961743740248494, 0.03306867183709983, 0.06523636155179702, 0.05735216684115585, 0.01703906869806815, 0.05031921922636684, 0.049204079259652644, 0.09866526816040277, 0.05991466918203514, 0.11868764064274728, 0.019246386582381092, 0.08426533968304284, 0.023827866425563116, 0.0477764468814712, 0.025260267102567013, 0.012482987931434764, 0.024030448621488176, 0.052479614823823795, 0.025088946022151504, 0.026886485211434774, 0.018203895451733842, 0.0714160174538847, 0.007318601183214923, 0.038323173866956495, 0.03356502391397953, 0.015633465118298773, 0.03596894042857457, 0.03460362248006277, 0.010799281208164757, 0.026028252650576178, 0.05112787817779463, 0.0457554711465491, 0.01063557085217326, 0.0765763632080052, 0.06415560899768025, 0.08992009679786861, 0.10306163967470638, 0.057405007755733095, 0.019729405976249836, 0.005130151939738425, 0.03930640821636189, 0.06556977881700732, 0.049917676515178755, 0.030577636462112423, 0.05792697877041064, 0.019115660979878157, 0.07864464714657515, 0.09230614610714838, 0.03439314568822738, 0.03415667888475582, 0.03530566820700187, 0.03779973711061757, 0.03672816492326092, 0.049886187189258635, 0.026633778361428995, 0.01934406620421214, 0.03627746606071014, 0.04209678329061717, 0.042424422936164774, 0.05111129488795996, 0.06916662721778266, 0.03799344878643751, 0.038761950127081946, 0.07578118907986209, 0.024683805750100873, 0.05105158168589696, 0.06886223534820601, 0.018594420980662107, 0.07272745919181034, 0.04686163112637587, 0.019755125103984028, 0.043695180138456635, 0.022779888968216255, 0.04262802001903765, 0.018724159526755102, 0.05064224642410409, 0.012131569874327397, 0.017455411689297762, 0.017001423257170245, 0.03265261271735653, 0.01693737034656806, 0.03918323025573045, 0.03611100975831505, 0.00616235272900667, 0.06820687442086637, 0.04748925428430084, 0.018417554201732855, 0.07810239694663323, 0.06460191434598528, 0.02429017247777665, 0.04256653308402747, 0.0671771370980423, 0.03886034777679015, 0.030800759450357873, 0.045609049120685086, 0.010914485719695222, 0.10367508410126902, 0.08175696959369816, 0.02842239693563897, 0.02183041491662152, 0.020355077285785228, 0.06960609738598578, 0.07803516578860581, 0.045630979584529996, 0.0072869035921030445, 0.035849324776791036, 0.05028206360293552, 0.03108303531917045, 0.010012844013544964, 0.011010062280547572, 0.050205165971419774, 0.03564426566299517, 0.028960387207916938, 0.04043685126816854, 0.02392612677795114, 0.02915309141826583, 0.05759732790465932, 0.0564225934795104, 0.02500438942661276, 0.03843404330837075, 0.01960613710252801, 0.009958739592548227, 0.02479881266481243, 0.05506728710315656, 0.0747940584551543, 0.062035623341216706, 0.04390502981550526, 0.047095478148548864, 0.11375975780538283, 0.04130456662096549, 0.026046518760267645, 0.0387288280762732, 0.08044698988669552, 0.022073638974688947, 0.021142204677744303, 0.08859380468493327, 0.009595757019269513, 0.009946059071808122, 0.00651582839054754, 0.011282077957730507, 0.021125278144609183, 0.01891670974146109, 0.031135770477703772, 0.04950557675329037, 0.03374758111021947, 0.08703855259227566, 0.11068973035435192, 0.024165552895283327, 0.11372398628736846, 0.08378384911338799, 0.1762276710360311, 0.10190423068706878, 0.20552953152218834, 0.09744152601342648, 0.10727642991696484, 0.13970410509500653, 0.19522154558217153, 0.06481525211711414, 0.1410050899721682, 0.09432613849639893, 0.09729138953844085, 0.1085683234850876, 0.102519626962021, 0.11862168597872369, 0.19537690677680075, 0.11563436346477829, 0.16805332998046651, 0.13727536745136604, 0.16402465553255752, 0.18080443638609722, 0.06420947407605127, 0.22449346783105284, 0.10768255539005622, 0.15192531805951148, 0.18971075769513845, 0.19074445066507906, 0.15584871143801138, 0.12111105708754621, 0.1649663073476404, 0.13509839598555118, 0.19933185627451167, 0.18629022873938084, 0.1125808859069366, 0.13910465757362545, 0.131517845147755, 0.28910962399095297, 0.10546462479396723, 0.19909361202735454, 0.1435637183021754, 0.22677916393149644, 0.13366348313866183, 0.1437511996482499, 0.15595546195982024, 0.12113167395000346, 0.0896724643826019, 0.12361305954982527, 0.12529296276625246, 0.2225050760898739, 0.07964098040247336, 0.16664672264596447, 0.11203505855519325, 0.1587718678638339, 0.2799451688770205, 0.051774774910882115, 0.08142950435285456, 0.1444298491696827, 0.17086301202652976, 0.15115958492970094, 0.26373909786343575, 0.1738932603620924, 0.12638443935429677, 0.16654126346111298, 0.1555615002871491, 0.11128624639241025, 0.064372954366263, 0.05300749333400745, 0.10239371418720111, 0.22138591739349067, 0.08869393524946645, 0.14126052235951647, 0.061723194012301974, 0.05371057064621709, 0.2064838889054954, 0.13855025841621682, 0.14874940097797662, 0.12809995823772624, 0.14451599767198786, 0.11961106531089172, 0.13185397867346182, 0.10916018625721335, 0.13719082198804244, 0.0761204470472876, 0.12200327444588766, 0.07421213304041885, 0.12128838585340418, 0.11407764934119768, 0.18161235318984836, 0.19741279596928507, 0.07958128946484067, 0.14118105318630114, 0.13463585986755788, 0.23842026974307373, 0.15748010046081617, 0.12632209894945845, 0.1586851998581551, 0.14043783681700006, 0.1624109296244569, 0.218663704872597, 0.16211412992561236, 0.11947635066462681, 0.10885204654186964, 0.15072381065692753, 0.2167598734376952, 0.11767859439714812, 0.08988854810013436, 0.1773947279434651, 0.1446946623036638, 0.19566999573726207, 0.15748719539260492, 0.130471134907566, 0.08818292204523459, 0.15186184959020466, 0.10640330059686676, 0.19223410432459787, 0.07619768235599622, 0.15345595311373472, 0.1992980291834101, 0.11726630909834057, 0.07213653152575716, 0.1677997232764028, 0.1424018564284779, 0.17876023513963446, 0.21386266249464825, 0.22520437109051272, 0.08529604921932332, 0.07931430925964378, 0.10181981881032698, 0.17713000386720523, 0.1492983230855316, 0.10768960579298437, 0.1590871618827805, 0.11971889936830848, 0.11993215550319292, 0.13665675767697394, 0.18417161976685748, 0.05524193671590183, 0.13407835853286088, 0.09105754201300442, 0.16764237312600017, 0.1342779368860647, 0.10482953191967681, 0.08808293991023675, 0.13699571136385202, 0.1465329175698571, 0.11103438373538665, 0.12984681059606373, 0.10647794581018388, 0.1451669353991747, 0.08391545416088775, 0.1743578299647197, 0.14509237924357876, 0.09213610523147509, 0.1792126483633183, 0.16299949726089835, 0.25173465139232576, 0.17203180555952713, 0.11408877413487062, 0.13382271834416315, 0.21587863244349137, 0.09444983224966563, 0.17459675698773935, 0.12247659396962263, 0.08378460610401817, 0.12473767303163186, 0.12657429557293653, 0.11469266712083481, 0.16919607413001359, 0.16330563317751512, 0.15715493587777019, 0.09543432082864456, 0.09147310760454275, 0.29385604429990053, 0.253900297684595, 0.1071777316974476], [0.020333714564912952, 0.013883636747777928, 0.05024069258070085, 0.00805216221124283, 0.07303550984943286, 0.05480380241351668, 0.033566508209332824, 0.05062088370323181, 0.05184247733268421, 0.027110919945698697, 0.04394791481900029, 0.05211431118368637, 0.05744819332903717, 0.05868477463081945, 0.023188072045741137, 0.04804359035915695, 0.07694418643950485, 0.015850827185204253, 0.031177100681816228, 0.008447700947726844, 0.044340945096337236, 0.048732919385656714, 0.04837716718611773, 0.026622885488905013, 0.04402821148687508, 0.03530154928739648, 0.043452776153571904, 0.018452785807312466, 0.014283365835581208, 0.04146727136685513, 0.07155586776207201, 0.07123641029465944, 0.018041240800812375, 0.02315268458914943, 0.043642034943331964, 0.06515673652756959, 0.028350473548925947, 0.0012898199611299788, 0.03483165848592762, 0.03407505006180145, 0.025883331618388183, 0.03423320173169486, 0.02071684088150505, 0.08322156092617661, 0.01808129636629019, 0.01978045460418798, 0.016876829649845604, 0.06824930300354026, 0.020707977782876696, 0.01631288276257692, 0.0979354401351884, 0.03295660382718779, 0.01556181354317232, 0.05180027139431331, 0.0669317385472823, 0.08217263908591121, 0.10781378936371766, 0.033007756355800666, 0.029723350271524396, 0.038226386677706614, 0.04244843512424268, 0.05044056037149858, 0.02181409694458125, 0.050335750565864146, 0.07739553839201108, 0.11437156208558008, 0.010089942024933407, 0.04201112089504022, 0.056521158112445846, 0.05965444623143412, 0.0477579451398924, 0.03237516080844216, 0.03700508990732487, 0.05103396310005337, 0.036286446047597565, 0.03244731982704252, 0.049955307113123126, 0.060162342415424064, 0.05606292274023872, 0.10840059811016545, 0.06408636661944911, 0.023941179388202727, 0.06530088387080468, 0.06595430037123151, 0.029561742048827, 0.04061960142280441, 0.020190474497212563, 0.031095416197786108, 0.01725435275147902, 0.019464268152660225, 0.06505108438432217, 0.036061085484107025, 0.010033731759904185, 0.014975011290516704, 0.031232683832058683, 0.028845510169048794, 0.058334154382464476, 0.011511757820699131, 0.0702546008687932, 0.0755475609912537, 0.08573874772991985, 0.03598769078962505, 0.056868193787522614, 0.03771032686927356, 0.05090783139166888, 0.03676126099890098, 0.08837903456878848, 0.01689184515271336, 0.09454935425310396, 0.025083324253500905, 0.02930135582573712, 0.12245766178239137, 0.02053694799542427, 0.06996809475822374, 0.09027023465023376, 0.015670748762204312, 0.03519206766213756, 0.036697302712127566, 0.03151996177621186, 0.032664665195625275, 0.01409545868227724, 0.02165547586628236, 0.030229036710807122, 0.012030471734760795, 0.03542343220033217, 0.02851260498573538, 0.05022045050282031, 0.0037643550740540377, 0.01921705319546163, 0.08858826826326549, 0.014430786977754906, 0.016691884593456052, 0.03676195119624026, 0.01543722179121687, 0.010949503957817797, 0.014773961629543919, 0.03142291483527515, 0.04072530922712758, 0.0377979819313623, 0.02148968749679625, 0.008033084377530031, 0.03546521511452738, 0.027934878271480557, 0.04474803907214664, 0.007617094370289124, 0.0245359365362674, 0.05815995376906358, 0.023508347730967216, 0.065144298132509, 0.08147496089804918, 0.019532811056706123, 0.042125170439248905, 0.05355945082555991, 0.06482996890554205, 0.021859110056539066, 0.023884590627858415, 0.034635534830158576, 0.06396846903953701, 0.02949883019027766, 0.06433664850192145, 0.0676220101013314, 0.007481097663912806, 0.024945019467850216, 0.00965675320912851, 0.03672037608339451, 0.04357140845968388, 0.03137939529551659, 0.026054140616906807, 0.018706615155679174, 0.01744173019687878, 0.020443277826416306, 0.029548001184593886, 0.051518785912776366, 0.10947508693789132, 0.03943513744161464, 0.021800066642754246, 0.028493388927017804, 0.015230377812258666, 0.06755063775926828, 0.03444418318395037, 0.03442037137574516, 0.03928019184968434, 0.015251844433805672, 0.030952116758271586, 0.06819365677074529, 0.0751374798710458, 0.022223977684916463, 0.016033182146202307, 0.033859578616102226, 0.016518051343155093, 0.028973365515412297, 0.03475388883089181, 0.05336838490620721, 0.02505938999092905, 0.03849282511509955, 0.02155630267225206, 0.019009394709428307, 0.05736973347666208, 0.032938521399046294, 0.032463034804095514, 0.062044046717346646, 0.016974065838439856, 0.022437257939600386, 0.027565503951336723, 0.03912312371539883, 0.026343810131947976, 0.016504685263498686, 0.04023288311145734, 0.009152790407824796, 0.04974929805030115, 0.05611496584606357, 0.07580248129670508, 0.009200806434819242, 0.00625630955255474, 0.03783707827096805, 0.05026398488553241, 0.03790088441746775, 0.04690283887612168, 0.030098311108304188, 0.12213538415380754, 0.026586151034280192, 0.017253823971259408, 0.0273460044991225, 0.08440361663815565, 0.020025613812322263, 0.04515500688285101, 0.03845834122330416, 0.05288679414661601, 0.03696049425343517, 0.07972683204570785, 0.01600014544237638, 0.020366493372421246, 0.10450622270582244, 0.012002125404251274, 0.02593214638181962, 0.044524441109388135, 0.029488857580872718, 0.025668184862297494, 0.009145526637439616, 0.05032939407101367, 0.016299839517159853, 0.05955238237220328, 0.05581380602961872, 0.05836267882841639, 0.04151914006797597, 0.08229807688621804, 0.024071893858490512, 0.05369700047594961, 0.03142622852465138, 0.030031280330149457, 0.016173702242667787, 0.04451458909898065, 0.04618261053110473, 0.03533024813805241, 0.0795367531827651, 0.061370762923615985, 0.03066147502977401, 0.05598240713879932, 0.030460080270131584, 0.08801711883279495, 0.05796660203486681, 0.07642747354111634, 0.05638080314383842, 0.014081479403103003, 0.027334406586305704, 0.03489672628347762, 0.09517793849227019, 0.05017645227781031, 0.011956151211052202, 0.040682197868591174, 0.00885204990481725, 0.1004826245480217, 0.06457806914113462, 0.0803435270790942, 0.01572243192640599, 0.05592807079665363, 0.030968740866228472, 0.06818270267103799, 0.08191227141651325, 0.08519499097019434, 0.04408355714986101, 0.012451111761038192, 0.046695193377672695, 0.015216803931252798, 0.03021933684067335, 0.021397058189904783, 0.02810908445098903, 0.03574792142899241, 0.03901979078364093, 0.03951432088797446, 0.10644056383171119, 0.02382128543104045, 0.021105071318743285, 0.06254912645090371, 0.01349891481368104, 0.019936415083066095, 0.052043272808077745, 0.034310897171963006, 0.03501454964862205, 0.04120201294426806, 0.01216561033288599, 0.02141794222552562, 0.0638241510023363, 0.025224773889931384, 0.04686422493250575, 0.06114731710113119, 0.011034011386072962, 0.03847955180390272, 0.028273557363718282, 0.04238159359374549, 0.01592306412931066, 0.03476656100247055, 0.06067137037462089, 0.02500680882803863, 0.023433856513292994, 0.024589616077719256, 0.049602701619733125, 0.02819967470713891, 0.01979065542400349, 0.015057663349580253, 0.03928439240553416, 0.027456886928121094, 0.03719363252457697, 0.024808057969494257, 0.024070786203083117, 0.07006505635217763, 0.0740926546859555, 0.10713371491874568, 0.08029013697523624, 0.01563983088999521, 0.025479779542365577, 0.04681980368332006, 0.021678640150639694, 0.07712163394899108, 0.06189680832903832, 0.04542898554063868, 0.05257890676148236, 0.013936334798927419, 0.05161285684152972, 0.029897274434915744, 0.023550496152893174, 0.015828933828743175, 0.03178107530402485, 0.01762015548592899, 0.0565384538640501, 0.022683539646095596, 0.05007254418160301, 0.0586042256327346, 0.032240405344055034, 0.02583726465672953, 0.018591919942991808, 0.006966063410800416, 0.12064629452652298, 0.08755234885029495, 0.11203624599147588, 0.1501684615504928, 0.21724655904108658, 0.17408598127076402, 0.1545750821242109, 0.16955413069808856, 0.13321740785613656, 0.1994170102989301, 0.105470829148544, 0.11319993354845792, 0.17385566316079348, 0.12535500631202012, 0.051445981225697324, 0.12654036458116025, 0.26678077527321875, 0.14413533528568223, 0.1130942146119196, 0.18129037984181195, 0.05968339370156173, 0.10054066049633548, 0.20167937327641994, 0.19225234631448984, 0.2045046552666463, 0.1303013612050563, 0.18498896184610203, 0.1619383745128289, 0.0888704031240195, 0.12127229609177448, 0.22846864827442914, 0.1583355147158727, 0.11051926645450294, 0.09577484786859713, 0.17751503008184955, 0.12243292600032873, 0.0765751460858155, 0.07746075832983479, 0.16562482982408255, 0.12361288885585964, 0.16706179099855945, 0.07880431279772893, 0.1232810746296309, 0.2131938241655007, 0.10124877328053117, 0.09957629896234721, 0.1117600779980421, 0.140351272711996, 0.18626643548486754, 0.12429263675585389, 0.23325219081016257, 0.13045538653386757, 0.1360320474486798, 0.1725858188001439, 0.1508740065037273, 0.12697140395175666, 0.2085233700927347, 0.12122939253458753, 0.09637054754421115, 0.15385611914098263, 0.08620831940788776, 0.15583269589114934, 0.05825007647217717, 0.20315393165219575, 0.1687804120592773, 0.12511078035458922, 0.09729763842187822, 0.16984577989205718, 0.12921553978230804, 0.14199554541846737, 0.12103765868232585, 0.14214958559023216, 0.11035701070795767, 0.11657568131340668, 0.10516250389628112, 0.08811710838926956, 0.1000574036152102, 0.0798601885617245, 0.20100897643715143, 0.14459892525337636, 0.09794541459996253, 0.09268835216062143, 0.13777287356788293, 0.185770665993914, 0.12306796692428179, 0.13405952282482758, 0.1952793588861823, 0.11484241767902859, 0.11571502749575302, 0.11286744396784343, 0.17416372866136953, 0.13289677037391812, 0.17183350370032713, 0.18870059080654755, 0.21676094213034958, 0.2028984547359869, 0.13431779021630064, 0.12902270013000816, 0.1542849765974097, 0.14006150857312605, 0.248740634706337, 0.1928411514381878, 0.17550380987813696, 0.26235689234454185, 0.19133303314447403, 0.11569616210181266, 0.1434816516120918, 0.09562411025399342, 0.11674193723592907, 0.059704162704292685, 0.09784670153749175, 0.2054859377676621, 0.10098768572788686, 0.11111589381471276, 0.23665242944844067, 0.1194701759959571, 0.10287640703609213, 0.12139063896029256, 0.09965217614080757, 0.1242004768573679, 0.21290383738232777, 0.140584277396556, 0.14734141324879602, 0.09891862253425643, 0.08821647454169579, 0.07958651418448426, 0.16689513431629166, 0.12358309904811904, 0.20955630607204512, 0.1158089165983256, 0.12852157233282924, 0.1566673448542133, 0.043607343250187114, 0.18262982281157747, 0.12241374148288742, 0.10793232519063167, 0.10784257727209479, 0.06864192881039344, 0.09995926200645044, 0.09486891562119126, 0.14590563951060176, 0.1372032010112889, 0.11854416123242117, 0.17987007246119902, 0.1419763089506887, 0.11882957638590597, 0.10998060082783923, 0.12350117336609401, 0.1778251735959202, 0.1178118544339668, 0.11162549693835899, 0.18363412673352286, 0.2697238064138219, 0.15424072975292802, 0.12628519936697558, 0.1454568182816729, 0.07447392563335598, 0.15631215297617018, 0.18496549513656646, 0.12889631238067523, 0.14805124781560153, 0.12305827447562478, 0.09850244096014649, 0.11966481164563447, 0.08783641329500824, 0.12229608881170861, 0.09719547437271103, 0.11721202099579386, 0.22221814695512876, 0.09437388085643761, 0.1504866499453783, 0.1420749700628221, 0.1965054907486774, 0.2887976251076907, 0.11633754096692428, 0.12339033361058682], [0.03685499425046146, 0.048543545563006774, 0.008245100198109867, 0.05320114563801326, 0.03794660071434919, 0.04304965266783256, 0.016130136318679433, 0.07647335311048664, 0.053341812308644876, 0.03256852738559246, 0.03744752495549619, 0.004831965816265438, 0.08981615159427747, 0.07126841912395321, 0.05740708205848932, 0.020381731519591995, 0.03736422258953098, 0.048173889226745814, 0.01738801354804309, 0.04915948731650133, 0.06953233532840386, 0.036972661764593795, 0.08007908501895145, 0.05806348199257627, 0.026291345857316628, 0.011604064293351257, 0.046287438890431076, 0.06710664049023762, 0.06818853595177643, 0.04439311436726712, 0.05332827553502284, 0.018187174864578992, 0.04194872853986453, 0.04946294779074378, 0.027699602615030017, 0.004617467975549516, 0.06404007144737989, 0.00472868900942558, 0.04030948017316405, 0.0147560610275832, 0.03740402025869116, 0.09009170360513963, 0.04775935522047803, 0.03627046760811936, 0.04785567485669162, 0.04635264027456287, 0.041208098555216566, 0.014537263832608005, 0.036697347240988165, 0.014467022338067181, 0.03745857182366308, 0.03773849879507907, 0.013667633738805307, 0.04423111837240867, 0.04761855125252623, 0.03336450674396474, 0.03452463570283726, 0.06781317249988206, 0.002115348625011393, 0.03409529585042037, 0.04718372321804054, 0.043684931079042144, 0.004076167260791408, 0.03886890845024027, 0.03445945658313576, 0.06038725026883185, 0.03125298157101497, 0.036468235120992176, 0.02528660963434959, 0.06222828116733581, 0.04630183284461964, 0.03777772872126661, 0.032493147446075454, 0.020517501870926935, 0.010830899482243694, 0.06936663601663895, 0.027820969735330436, 0.07986603668541647, 0.08914100500987843, 0.05098073626868427, 0.04686354957812, 0.005759380455856444, 0.026952469561365433, 0.012227735514898086, 0.08556111468351446, 0.0281702856591437, 0.039565551342093386, 0.01646449982217746, 0.05602665027254261, 0.03071705261390889, 0.05434027923911344, 0.03485882480163127, 0.02167631722841179, 0.014232804242055863, 0.011717352208506782, 0.033517277843202464, 0.03912715728802141, 0.009765339618752478, 0.06729245942551643, 0.020275101596780587, 0.039040845513227396, 0.08238315669586882, 0.021644291700795293, 0.037698767919209786, 0.02103309041558532, 0.06978853954933584, 0.0232350666919956, 0.048420193197671324, 0.024341208118130453, 0.021823039824084844, 0.020498983431025408, 0.04849574383115396, 0.03395703744899947, 0.02014276553381933, 0.040928501839516684, 0.040381064027315006, 0.05088735924800858, 0.08082994550932199, 0.061924330875626765, 0.08152152324328199, 0.06988840294070542, 0.11796845501521602, 0.017521576010040008, 0.020614038585335948, 0.046527360391337425, 0.08057656144956127, 0.009061409764399286, 0.03683186150738038, 0.022154837351990864, 0.1078556093852967, 0.03865294718707446, 0.057570900025893934, 0.0756668315443676, 0.01890800063847564, 0.027432251335994806, 0.032800493063405156, 0.03311533437226899, 0.022155976548674516, 0.039139087311923504, 0.10571566366706975, 0.02167695918615209, 0.06534081141580828, 0.10014650586526841, 0.08251339619164355, 0.03793950949329883, 0.051668900123331696, 0.036262085050111637, 0.041795334036578424, 0.011062212997785537, 0.04086671433469746, 0.014680042841064278, 0.06686182823614217, 0.05183582026802469, 0.025586249903426506, 0.017745418881531805, 0.03014686797541799, 0.007264304731506854, 0.030373599656741135, 0.06086420260544401, 0.04017483603092842, 0.018342055518587586, 0.008971142342488747, 0.05319690055330284, 0.04752242086397018, 0.02028146365773864, 0.04073848976986483, 0.030117978021735325, 0.04651821713196114, 0.08642478904221207, 0.07965884389705025, 0.0117250278708525, 0.03440169894020073, 0.03137672727461904, 0.08351665368536487, 0.027226386991969775, 0.044123777843196876, 0.047575796124874614, 0.04585952396155335, 0.0673691307019908, 0.01284169851714978, 0.03714371196110733, 0.023226582088682335, 0.017639026445976924, 0.02955098832899239, 0.021240452042547986, 0.08487392304232344, 0.03836940224573482, 0.1165576397033874, 0.046808597253402695, 0.06212797248736024, 0.02976623898575781, 0.050446467867004685, 0.0256843618262792, 0.04152075052843429, 0.0801427687110845, 0.07470185402780771, 0.023385852546198294, 0.01491091385105392, 0.011021097088814713, 0.012636594874493312, 0.05168596951989457, 0.03450967400567606, 0.05065253259090241, 0.06379563026712276, 0.01597556365595665, 0.029082294240652118, 0.030134190237731673, 0.06650065464782529, 0.020078814668522682, 0.04105521242308896, 0.0895162571396213, 0.018717552557063755, 0.04218110982037615, 0.02020592972257873, 0.0472464977792697, 0.04219411966914777, 0.0025100385300902417, 0.0323415786260739, 0.12377095888950862, 0.047424546428374015, 0.0340211478760466, 0.050841739430325106, 0.04173484157945495, 0.020297182345530018, 0.07072242107824422, 0.01817390526412055, 0.059836042346432805, 0.030717676017957274, 0.023881961569713894, 0.07474125464796089, 0.03824127787083853, 0.03389828161743935, 0.012294555708649568, 0.04158244526479393, 0.042159231306868605, 0.0238745679234853, 0.11130929007777013, 0.005353318993002176, 0.049240422231378034, 0.009270096124964766, 0.048393019460490905, 0.046300211251946166, 0.02073228868539445, 0.03322311647934839, 0.023711842768534552, 0.037179168066359125, 0.02501432678400306, 0.02196625020587817, 0.08488095860229805, 0.057503973148413934, 0.005545976819121279, 0.025722740138007794, 0.07209736097138375, 0.051704749566852115, 0.016901340932236053, 0.02153926110622706, 0.002205201371907606, 0.052426068868953735, 0.06296917461440898, 0.025828056459431536, 0.08255463733803481, 0.05359711853088811, 0.011063225101679564, 0.039895294976304285, 0.005380101247283164, 0.05256682459730655, 0.03468543312919792, 0.08288618439109996, 0.008689312689966755, 0.022748607443645597, 0.024153580197889823, 0.03263412210799288, 0.07987225588294677, 0.023642708001716528, 0.0026395347185825813, 0.02007921542826807, 0.03235955715354066, 0.06919073217432015, 0.05656898581946734, 0.021200296287133824, 0.02121994835761143, 0.03736274942639284, 0.02589837124105543, 0.04020245134597644, 0.03771413037611637, 0.032895306139835157, 0.034151728759752586, 0.08537332163541578, 0.020488172194745857, 0.005605008173006354, 0.048804332545842044, 0.034730908228084445, 0.03299739597423468, 0.034490916223148815, 0.062121760711306706, 0.06371953786583617, 0.05599576579697896, 0.04567087373288814, 0.07169015938416123, 0.017769197293091565, 0.07549725822173059, 0.09857380588073283, 0.0305819353525294, 0.023211442276078742, 0.002556756958256301, 0.032378437390434556, 0.019555799080990255, 0.08082452783128247, 0.017123172583524138, 0.03765343382838182, 0.0527329580654623, 0.00801836016762536, 0.020317441121733282, 0.0209058362088399, 0.038567310766666196, 0.04753815439471509, 0.04825535848794971, 0.03345360528328456, 0.04879382002400234, 0.0092993914768158, 0.03196637102519162, 0.07437182095600292, 0.04210757040709723, 0.028849198643001728, 0.016228853091888595, 0.018691662735363934, 0.016146971938724164, 0.04567325973766856, 0.0518447371723596, 0.009733835449878825, 0.015450241844519041, 0.09083668628591113, 0.06019076667143963, 0.041505940971546806, 0.03291228276793845, 0.05116316729981918, 0.01763281466992339, 0.03637460577010643, 0.027440446501714177, 0.030179513196344487, 0.054261281329672784, 0.04225032993417699, 0.019573916761146393, 0.03005396036314778, 0.05490037066920195, 0.050069453136529773, 0.03649332342320122, 0.014905994339642348, 0.04627898582839407, 0.08874084640410729, 0.02039460036030505, 0.08738950680708513, 0.12090228352462873, 0.1617458465625532, 0.22799313941504806, 0.09631867884309031, 0.1091347899637185, 0.17431083717383444, 0.17069221416022629, 0.1575233379844576, 0.17639083962421864, 0.2227546603535302, 0.09014939816552214, 0.17682677716948092, 0.23786791891325265, 0.2196016607922502, 0.18852992652682588, 0.12764764891471714, 0.14013852865900844, 0.23619329236680642, 0.24986322212498635, 0.16417353035649285, 0.14597703411709517, 0.06018493339070119, 0.18741946580121294, 0.15003861539298669, 0.14955198916140944, 0.12244868179550394, 0.1462497140164487, 0.1675335000618361, 0.16236012219451368, 0.09180780136375688, 0.09717110966448672, 0.1448058063397184, 0.08039749605813995, 0.13293162162881345, 0.17272655968554318, 0.09865420273854397, 0.15291739138774574, 0.10324964052415453, 0.20762617292348295, 0.12113519915146753, 0.13407166436081752, 0.14695071702590212, 0.19918707810575143, 0.1598106964956969, 0.13854593911673874, 0.16508230502950028, 0.12417887293850072, 0.10957666469039395, 0.16577409056480974, 0.15449417318450287, 0.11620377626968548, 0.10550573977525346, 0.08192604567739181, 0.1770932527142577, 0.06694602489005774, 0.09343082638224587, 0.18833771027857438, 0.17337156023131683, 0.16779700701590627, 0.12424021886545233, 0.11716680935933255, 0.10166370062506758, 0.13823520188452676, 0.06861309637315571, 0.09745424642460421, 0.1184277405263856, 0.08240328374085948, 0.1369308031280525, 0.09027508829603903, 0.18863563804188743, 0.08106741050141864, 0.12112111318856478, 0.16515997820533812, 0.10176445459364913, 0.20325572462752461, 0.1385121713974513, 0.13767210475634784, 0.2115448610857129, 0.12827869708416983, 0.11216239625355229, 0.18089536431943998, 0.16097827290650457, 0.18233306764159352, 0.09047436236869544, 0.2203654940240085, 0.18265766819240525, 0.15924362145597115, 0.14178480516420677, 0.24440619541564956, 0.07959566486533731, 0.16823491867398843, 0.23229317273944616, 0.08369882867555134, 0.13101309566991404, 0.1389938549255021, 0.06560666355653666, 0.24957066751085222, 0.16696390172000974, 0.13328728848136961, 0.10380044768680818, 0.1284519737237133, 0.13383888232056051, 0.06049802323104814, 0.09908219930366613, 0.10329353855922818, 0.157114963803906, 0.16012374922866002, 0.22347613179590553, 0.1280456775566563, 0.0969127903226763, 0.1582518153009005, 0.1681632420513779, 0.11891290472703986, 0.10149291760171764, 0.12786022969521582, 0.13246779417386279, 0.18550573411630467, 0.14417740021599457, 0.2310810674680397, 0.1467447858885862, 0.12412957948981784, 0.3099372563883662, 0.11084971512900665, 0.12342050933511928, 0.13849514652974904, 0.21705162653233856, 0.096733056998346, 0.0829134434752632, 0.09718003027956001, 0.2101559762377292, 0.14128995593637228, 0.1862391096074134, 0.13809299154672772, 0.07987193675944582, 0.08665483997901902, 0.08286168609629385, 0.14906684722518548, 0.09678686270490289, 0.15191705053439364, 0.19865501759340987, 0.19107025349512696, 0.1338804722763598, 0.1691816170932725, 0.12179559184005484, 0.1160964988230262, 0.14485946361673996, 0.1044653081044089, 0.16073854436399415, 0.10793063309392892, 0.17102119338233024, 0.09206865885062143, 0.320341216865927, 0.17400140612153336, 0.15488604200072587, 0.12956472026417032, 0.157575792982243, 0.15719980612630025, 0.14728293201187626, 0.1525069391936995, 0.16239196032984182, 0.20894023444270715, 0.0936269760131836, 0.12012002276605926, 0.20372134807985276, 0.13039558427408338, 0.13307414366863668, 0.16299146722303703, 0.10578466113656759, 0.15645458595827222, 0.16332141123712063, 0.09529496033792384, 0.19579068379243836, 0.09964519253117032, 0.22729443706339225, 0.166220611135941, 0.150633892044425], [0.01919246027682675, 0.10556538618402556, 0.03234495910874102, 0.041967482611653395, 0.01105591587474919, 0.00569116641599976, 0.024814128737489227, 0.03259779768995941, 0.05128082739247475, 0.038640145139652304, 0.008742133195482893, 0.06075957091525197, 0.012030080251861364, 0.039435623548342846, 0.01599479826836614, 0.04428198517416604, 0.04568908974761143, 0.05978445195069071, 0.010792841221700655, 0.05937332069152035, 0.05404562805779278, 0.0410878928960301, 0.031393002573167905, 0.049733193445717916, 0.024049312160059344, 0.0548079584405059, 0.06916670885402709, 0.02684890841919696, 0.06786039535654709, 0.038207992547540925, 0.053533638929366134, 0.03974144405219704, 0.04822634793526959, 0.03351473969814833, 0.044626048547797836, 0.02507312714442378, 0.034991190550499596, 0.06668633257504553, 0.07386118624708615, 0.045107743208063766, 0.02120415731042158, 0.03901448813849129, 0.08231909450842068, 0.06758481365977786, 0.05321280477801338, 0.04105640728084836, 0.028834448457928374, 0.07488733899663202, 0.03492815623758361, 0.05779299513960723, 0.0046128768644848606, 0.020747363560076337, 0.10110323812114075, 0.03761041894904338, 0.019168529724993277, 0.1147252251394093, 0.039622032491024584, 0.014104582460277015, 0.04582532950735185, 0.07493718905607238, 0.02987073708936805, 0.0257448041884345, 0.03260741963458713, 0.004143682290305151, 0.04079082973476034, 0.02903240150772035, 0.020039790688315406, 0.06160746721434407, 0.04428408916282933, 0.06296406121691689, 0.04781794035807252, 0.021528904435399454, 0.08121040751575492, 0.015546939048363129, 0.013342441325221444, 0.04355698481958825, 0.05296683848428074, 0.03782598316320218, 0.03491322051559109, 0.006243913830985548, 0.06911314063472673, 0.024034463640418835, 0.047578998492099345, 0.03945042197301518, 0.046744045248487964, 0.02922782012319658, 0.02054957192740403, 0.050925913819810376, 0.026989586222043727, 0.045085100282449275, 0.07127754754037596, 0.07080970506649464, 0.03012630306329811, 0.033938038468477316, 0.02684739258256741, 0.028243387205293402, 0.03296159105957486, 0.027286263466521632, 0.020243578874215018, 0.03708446631208062, 0.011966274105361663, 0.02331911677174503, 0.14110093092313036, 0.045340733049670234, 0.053936840340611525, 0.028020293902955018, 0.03571951943740714, 0.03211834802641533, 0.014860647261230042, 0.06133217866590712, 0.02417474996036617, 0.06917443461134098, 0.026705017116910312, 0.044486650949693285, 0.03503924090182409, 0.058327300648670644, 0.031142015650402755, 0.010495218666619621, 0.005572006721195066, 0.11644130063359626, 0.011228651674173307, 0.11435563559643924, 0.04626336733053904, 0.034027834626613185, 0.04006539522379171, 0.04290642558771651, 0.05158036561624613, 0.025088625043281354, 0.07073456261423416, 0.009482767818553839, 0.02639056729094591, 0.04956784294336103, 0.025535088097967673, 0.022728233634552453, 0.04458844392502215, 0.004465482625164441, 0.03637944828369655, 0.03260872581449803, 0.0035941796841143514, 0.005930148636252852, 0.032622860016999766, 0.011979728315054672, 0.030019621190149337, 0.02551503712311387, 0.02235579609987326, 0.056392673795926385, 0.053938458222546615, 0.05131155230628792, 0.02182694908697158, 0.05184169436688535, 0.08755358823691495, 0.03757759746804368, 0.021833162718394306, 0.06312242068815976, 0.03275366354500875, 0.0243754359689774, 0.04176691720203962, 0.07146730727981776, 0.06210883992025629, 0.008901284909370588, 0.03942851377360057, 0.02486558925738791, 0.03417151812755037, 0.047573328483849764, 0.0544144531886559, 0.119516322738491, 0.055954769559320994, 0.030790844357397873, 0.02291084278112976, 0.05466377770062536, 0.06001964597089682, 0.03196339130226988, 0.07373988220933825, 0.039622778349439614, 0.06266019627219066, 0.09439168497920036, 0.009991283695853781, 0.059554909385042265, 0.0367240088962717, 0.02512650240532821, 0.028192418358230498, 0.030614029528805986, 0.010627264364302391, 0.0013967692393634934, 0.03262093414377887, 0.15555290621705353, 0.03027850456419401, 0.06413285474991426, 0.009426030628674198, 0.04421126221131999, 0.025739451448316686, 0.040457905997755006, 0.009920837183017284, 0.020683971160906367, 0.06106232634920161, 0.05599371004791465, 0.06559342364198528, 0.02566241837484995, 0.02856331779184984, 0.030162100556481164, 0.04169311803707387, 0.07554956478998065, 0.028716651067952625, 0.04293099067581352, 0.07527778288931586, 0.024919897768995725, 0.07577900716569275, 0.027668983457260765, 0.021021468382969033, 0.03819055207713973, 0.024521700288460124, 0.09144480209215544, 0.028840246486652177, 0.044182978963362984, 0.022442892695835326, 0.036813333790632896, 0.049600738639128394, 0.028891142974316608, 0.1476630600518547, 0.010163658625970129, 0.03650327562354505, 0.04402003301947843, 0.07671949380892329, 0.035266056074760854, 0.03338797345350031, 0.05465510199428536, 0.04012135315861087, 0.014867257941659773, 0.042373047763248906, 0.0358871557546081, 0.006422083542929613, 0.07316748597077094, 0.06616570855840109, 0.038894160024938174, 0.05347817452275194, 0.023918258157209493, 0.04298531588574406, 0.05521387611224782, 0.03363004347193055, 0.03916470624972135, 0.04525092204858083, 0.0032608806986900163, 0.02227636217867257, 0.040753232533461414, 0.010219850337307435, 0.02074734315101523, 0.02447639959427761, 0.02336496294446988, 0.11858451922307722, 0.048988117996486835, 0.02844111018930562, 0.05457859027956147, 0.03183665103279054, 0.03537419812346343, 0.02344678287045099, 0.028825626177422237, 0.028750535675499123, 0.02944372386991745, 0.02152672994270688, 0.03283229780208785, 0.024107368517434224, 0.07198969760793261, 0.03998424137535039, 0.033325402982882224, 0.05658029986079782, 0.009302356356784003, 0.026693582476582378, 0.0484500980383018, 0.013263337659736862, 0.054526350504602306, 0.009566647204337642, 0.05833257360791322, 0.024834183423081413, 0.05322575896570925, 0.013017729452258209, 0.09989357451559044, 0.03933016436349135, 0.014147090823826147, 0.06514362277812324, 0.06203324475791305, 0.022856845971546136, 0.07410678517771885, 0.052297907386673614, 0.03679579313029535, 0.021235837739368435, 0.016088214251794852, 0.0676081319397781, 0.03182797161571216, 0.06912888158694841, 0.011333540332998382, 0.016950951649050694, 0.03690436562465038, 0.040756538801360875, 0.0371744591393508, 0.025151481240754947, 0.11131433668197133, 0.03996446313976776, 0.05006115221476648, 0.03259854354837444, 0.028347438164928462, 0.056182723928941414, 0.07392822444671765, 0.033294878448941745, 0.05489253730047494, 0.02533051880163839, 0.022005114624334965, 0.10108166388818063, 0.05446185045002494, 0.01828190630476456, 0.0242046659332118, 0.02526593154470902, 0.03962801049055997, 0.049289504167973064, 0.017548805408296175, 0.040120952398865484, 0.046688250586157665, 0.02227726759883808, 0.03446552735113073, 0.05417237203801051, 0.04113147922907956, 0.02918781650805613, 0.02879738931369502, 0.014278412927524187, 0.06310113589279354, 0.024039957388595212, 0.05326866252289619, 0.014199277720763348, 0.05128319484356325, 0.06086756082368083, 0.05385158241551835, 0.06670548740657978, 0.04337924416176975, 0.07672475563595071, 0.03673563463962637, 0.04328520662966184, 0.06752236935426481, 0.01230244102771394, 0.03978669650678057, 0.06396345954271965, 0.022506053173856344, 0.01329084814642556, 0.12618374777957797, 0.039740327119943686, 0.06828226178186014, 0.06772471591830254, 0.06436437513912097, 0.06147520165541209, 0.033273545413976535, 0.056985557021107525, 0.020028213184559718, 0.06196391332196072, 0.0033482131584605668, 0.06580509158084169, 0.12105868372600526, 0.10298217792296782, 0.10738994140410796, 0.13703051808988675, 0.178197123168502, 0.07295771792996675, 0.09759426000528038, 0.10067515991977416, 0.2239382523111999, 0.11593589806579985, 0.17787409597076476, 0.12588472163770348, 0.14942071808036417, 0.09272761177271605, 0.11177481705090031, 0.19027450791327283, 0.11122205061838031, 0.22260952595388517, 0.13147748715709895, 0.1654974921257235, 0.18917403649538755, 0.13945769722340629, 0.1639562740456313, 0.1590297938673757, 0.10629357406287454, 0.1752400357509032, 0.11887040935107507, 0.12919098953716457, 0.13308205496286973, 0.16175982862478122, 0.12956215243320912, 0.13331433234270662, 0.11059978947741911, 0.20286588929593563, 0.20353069034172222, 0.12585941440192983, 0.252836681320332, 0.13549805735237896, 0.2793563192244619, 0.11759724759031087, 0.08517139809555374, 0.23680520796915516, 0.23388503497699276, 0.128639766771812, 0.12711155111901462, 0.14002527692355216, 0.12453129660570994, 0.10319323730072938, 0.14177695324178785, 0.14681586879305542, 0.13666294718859717, 0.1622588190366514, 0.1625852452707477, 0.06561911679455079, 0.14261192874982953, 0.22047738020773977, 0.16591904684901237, 0.09790630341740325, 0.11657053823000751, 0.0767105064005591, 0.15840595937334, 0.19481539784464985, 0.15536266408162192, 0.1503356674220413, 0.06652553143794648, 0.0710776426421944, 0.32132937165442854, 0.2024794530007057, 0.10660673069651239, 0.1386890548747033, 0.07882610967499204, 0.22877641691593453, 0.11493097073980607, 0.08474738686345518, 0.10773854301078245, 0.19097131036687642, 0.1381701006903313, 0.091080563433934, 0.1397562335478142, 0.17414507106877863, 0.0907237536739558, 0.19417836796492338, 0.10155949566978961, 0.1245354229467921, 0.14399091334780678, 0.1614977020653896, 0.14658788102678955, 0.12256712856469676, 0.138045790954493, 0.13059548917226493, 0.19133873283863068, 0.158711516414769, 0.16408028692239895, 0.10049532269476913, 0.1371759790345095, 0.1580118789570406, 0.09421941023902036, 0.1142519575660117, 0.1370870994287543, 0.10555783112067729, 0.16876577690709382, 0.24124607123667374, 0.1735688972985372, 0.12851054401835427, 0.15954977221554145, 0.09253232303308323, 0.1075892080552876, 0.1300933668971993, 0.12030316996970214, 0.17182387062348425, 0.10541189520154148, 0.14207507396349683, 0.14253964356612414, 0.13423089956631884, 0.27947535971179605, 0.17034745687851682, 0.14433190051931888, 0.1184477933566086, 0.2801237296080217, 0.16310097853420302, 0.19343953026691452, 0.10785686361487024, 0.12203101592604071, 0.18324694829061627, 0.12690140458289534, 0.16372545127524063, 0.10776297451229766, 0.11350287823006511, 0.06917545877513476, 0.1761491221259348, 0.20689995173597708, 0.1296935571008362, 0.05457293511426542, 0.11066611521528102, 0.08122953266138211, 0.14840522257145494, 0.10521473624976352, 0.06732702866429463, 0.09267911242204718, 0.12732089613564312, 0.09281436141463928, 0.09269710950320587, 0.1608050853246823, 0.12503543752245605, 0.17994928930420429, 0.19690774963237345, 0.13646688661538064, 0.1286200701724738, 0.10768578373244964, 0.12889988953247666, 0.13439138157991692, 0.1855047099525109, 0.16647156095132232, 0.08818562346277758, 0.07866092986660078, 0.20314848428824916, 0.19068671157583594, 0.1702029161970131, 0.23547109361970797, 0.15776551561430097, 0.16311405517626554, 0.13524860667530447, 0.13069970154901966, 0.1287823630264029, 0.2685030031716451, 0.1406516198767349, 0.17659485602052882, 0.10547201658482663, 0.19326414592796937, 0.22431550081819296, 0.14533997455146164, 0.15348191343946382, 0.16941972775384784, 0.1451185770565644, 0.22727319679688662], [0.03778518730541691, 0.07837177428882569, 0.02056941139016999, 0.021364192180044483, 0.08781540309428237, 0.0432440285658231, 0.030322784805321135, 0.03668312398076523, 0.005567771377172903, 0.06538750734762289, 0.027771692984970286, 0.04059468010382261, 0.00714987483661389, 0.06460998149123043, 0.0659508716489654, 0.016995372898236383, 0.053230727644404396, 0.025812209751165938, 0.00914180754989502, 0.04006312425190117, 0.020815114221477415, 0.07672548294067383, 0.041614157235017046, 0.018734709155978635, 0.02499989943316905, 0.06483704899437726, 0.02675190415175166, 0.014388146882993169, 0.08479105483274907, 0.018551669563748874, 0.021861453387828078, 0.09747678544954397, 0.03448782517807558, 0.05594984540948644, 0.002122189371220884, 0.01836803068727022, 0.0296462856567814, 0.03796546610828955, 0.06591976823983714, 0.022443404777732212, 0.0503709506301675, 0.009094994729821337, 0.03016801918420242, 0.016647385418764316, 0.025510634332022164, 0.025311050412710756, 0.018890148276113905, 0.027389780079829507, 0.08058735969825648, 0.00967808624409372, 0.010646764294506283, 0.030625697945652064, 0.04143043115618639, 0.023388503868773114, 0.03771378156670835, 0.017354579795210157, 0.04154169393586926, 0.03338612921652384, 0.03883697383571416, 0.02278771120472811, 0.03348253791045863, 0.02481113602698315, 0.050002529969788156, 0.06252044244320132, 0.07874828806961887, 0.009718076871649828, 0.08149298766511492, 0.013218727162893629, 0.00344609084095282, 0.041765703790588304, 0.03577609335479792, 0.015100171713129384, 0.04446157006896101, 0.03905157696863171, 0.07186424496467225, 0.04270868405001238, 0.05146928466274403, 0.05175326376047451, 0.01480090715631377, 0.04037212856928818, 0.03743542794836685, 0.04561325709801167, 0.015305991528293816, 0.005747311279264977, 0.06105949134507682, 0.06446667277486995, 0.021183256576478016, 0.00621630825662578, 0.048816577982506715, 0.027179243916179985, 0.02770192368188873, 0.01015563786495477, 0.03008340878295712, 0.08168034284608439, 0.03393132945348043, 0.00960418317845324, 0.07805357105098665, 0.026576007730909623, 0.02743483772064792, 0.050158874510088935, 0.022116028594609816, 0.038330012757796794, 0.07263141043949872, 0.0705781475699041, 0.04983491962775588, 0.06584354225196876, 0.0299587224071729, 0.017817245789046865, 0.013983076187287224, 0.042527236364549026, 0.012177910502941813, 0.01543105361633934, 0.029190380628278945, 0.05445481489005033, 0.05038891431468073, 0.05557753218454309, 0.03442300599999726, 0.06769683343009092, 0.07283527098479681, 0.03425742172112223, 0.007138680930438568, 0.017008844733936712, 0.026965624128933996, 0.04436121314938646, 0.026046388884424232, 0.004695315556091373, 0.049830600328277797, 0.07448975564329885, 0.033394637939636596, 0.029611801764986012, 0.011052138343075057, 0.024397603920078836, 0.00587457151596027, 0.05959730828180909, 0.08504637589794584, 0.014443099207710475, 0.02663224768184591, 0.056068485137075186, 0.03681479211081751, 0.022167023416841403, 0.033149321025121026, 0.06284838265855797, 0.03677631917526014, 0.03747339251276571, 0.07184468195191585, 0.0213003823228064, 0.04554724306217395, 0.018465485809429083, 0.0727907198597677, 0.04767129568790551, 0.025544203526806086, 0.06592455509235151, 0.031590213475283235, 0.034322393039474264, 0.04890668213192839, 0.05078449386928696, 0.06056748825358227, 0.026293709597666748, 0.05625137629976962, 0.007388211852230597, 0.002470244339747296, 0.10137229633983225, 0.019845737624564208, 0.01594119665242033, 0.03409082812140696, 0.018444707529852167, 0.016470620685140602, 0.03884371995809488, 0.00983170153631363, 0.09203192254062742, 0.029106412184773944, 0.03856576709949877, 0.03921946190530434, 0.03098107350524515, 0.011125450473628007, 0.02025239373324439, 0.03731448385224212, 0.014772099766560132, 0.04332287804572843, 0.07217139020212926, 0.023575217092002276, 0.06090078306442592, 0.03066426364966901, 0.02756632587988861, 0.028067297826055437, 0.0763349054614082, 0.024428634969808627, 0.05940843911957927, 0.08162965415976942, 0.02315451954927994, 0.057448200750513934, 0.057302736095152795, 0.03588539686461445, 0.01622493269678671, 0.03744390698557254, 0.030236697530199308, 0.041673632949823514, 0.0895673836930655, 0.06976452365051955, 0.03432989244174678, 0.013513492449419573, 0.03170613323163707, 0.05821132152050268, 0.04570170996885281, 0.07815719713107683, 0.04044883695314638, 0.01820624434913043, 0.04900887215626426, 0.051113187364535406, 0.007793392942403443, 0.03356277149578091, 0.013138469457771862, 0.06968892106669955, 0.04406095504236873, 0.022997093328740448, 0.020098613313166425, 0.026948786653520074, 0.03721386718098074, 0.008992644216050394, 0.05140205721545499, 0.030534669822372962, 0.006709215376758948, 0.06635186888161115, 0.0567312007478904, 0.06696217402350157, 0.006535121910928865, 0.006459225714934291, 0.040855793631635606, 0.013298978374223225, 0.04158833791734651, 0.010806956870510476, 0.010753591814136598, 0.08465291888569482, 0.05835956922965124, 0.03080460191995371, 0.0252263862057589, 0.03190460949554108, 0.05104627533000894, 0.01564483296533581, 0.018295647168997675, 0.08375127625185996, 0.07340834999922663, 0.04325375070038717, 0.045452474514604546, 0.04487031532335095, 0.0802234178991057, 0.018211906935903244, 0.027875857122126035, 0.029000179310969543, 0.015997941263776738, 0.03713568192324601, 0.04038966551888734, 0.08440095974947326, 0.021762562209914904, 0.02948692985228263, 0.04389447276480496, 0.0468288022238994, 0.042753146117320284, 0.0709947595896665, 0.013407472943072207, 0.02651135924679693, 0.013073515765427146, 0.04709481021563988, 0.026713846818893217, 0.042132458329433575, 0.04125398554606363, 0.07325238766497932, 0.06483094111899845, 0.04128214633965399, 0.061845974923926406, 0.07228346192277968, 0.016239629076153506, 0.08320901120896451, 0.05594747424765956, 0.13815601472742856, 0.02877000591979595, 0.013959053794678766, 0.046024447728996165, 0.029650961187144276, 0.09766780684003606, 0.09661244315793738, 0.04978847973688971, 0.02522241757105803, 0.00939076748181833, 0.04145357132074423, 0.055566166192875244, 0.02774310916720424, 0.009954743127309484, 0.02046110421360936, 0.02018427385337418, 0.046016128253540955, 0.04891142074484378, 0.03170717594912276, 0.02768467802525265, 0.011800135071098339, 0.012563420968945138, 0.02875634112569969, 0.028711923587252386, 0.066148201294709, 0.05924964920268394, 0.04520504247921053, 0.00827160043627373, 0.05461923028633464, 0.04131896799663082, 0.02570802520494908, 0.0224903270645882, 0.03801519000262488, 0.05785433735582046, 0.05547281514736824, 0.03651657490991056, 0.04839976187213324, 0.03472101168881636, 0.020060663591721095, 0.03684101589897182, 0.010215981892542914, 0.016040503433032427, 0.05042757649789564, 0.02956748998258263, 0.055641861545154825, 0.06692834693240002, 0.03116937863524072, 0.036393274494912475, 0.02035126821283484, 0.05644248674798291, 0.013271526331664063, 0.03624631812272128, 0.057701896512298845, 0.052374133374542, 0.008797218179097399, 0.03438408406509552, 0.018227870532427914, 0.05638558628561441, 0.06333866025670432, 0.03128758420643862, 0.052043617906747386, 0.027840094880957622, 0.03694913197250571, 0.05077496469311882, 0.043097740126540884, 0.019627915426099207, 0.034971256463904865, 0.0034830010918085463, 0.04115193281904794, 0.03210159033187665, 0.02088490207825089, 0.03742753149708733, 0.03008202838827856, 0.012977620081073837, 0.030651693523395807, 0.03671158163342625, 0.013116007430653553, 0.04485041834414005, 0.08990437068860047, 0.17177272180560976, 0.11757516869693063, 0.30847308808006346, 0.2741288091056049, 0.20236743323039263, 0.11082608514698222, 0.11118095790152438, 0.12018611101666465, 0.1539379928726703, 0.11235696510993876, 0.13607978238724172, 0.1637698762351647, 0.15418284223414958, 0.13781768444459885, 0.17423084849724546, 0.16144759225426242, 0.07988429351826198, 0.07639911607839167, 0.16493657691171393, 0.1592999356216751, 0.17538315150886774, 0.11717251647496596, 0.14276892266934738, 0.17797427106415853, 0.1107265408791136, 0.22031152504496276, 0.10322937989258207, 0.23762259457726032, 0.17036528326570988, 0.13704314944334328, 0.14918789151124656, 0.13154742715414613, 0.15867105452343822, 0.15106012229807675, 0.12912373611470684, 0.14172948547638953, 0.10893362341448665, 0.17585595895070583, 0.1196722182794474, 0.15902571205515414, 0.14861915406072512, 0.18072254781145602, 0.08771468623308465, 0.08860620597261004, 0.14617998182075098, 0.11436090484494343, 0.10393129574367777, 0.17262775014387444, 0.07832024697563611, 0.10043724963907152, 0.19147141400026157, 0.10178092285059392, 0.10702056708396412, 0.17851964570581913, 0.11070029853726737, 0.2548941521672532, 0.10681334460969083, 0.10508052626391873, 0.09443182774703018, 0.12140935592469759, 0.1171115564648062, 0.15234565566061065, 0.17967172607313842, 0.19462476979242638, 0.21169327577808872, 0.10051371311419643, 0.20196956786094233, 0.08855022577336058, 0.12659195868764073, 0.10738729193690233, 0.145830029505305, 0.10293456172803417, 0.07084812605171464, 0.10713708426919766, 0.09965038014343008, 0.14285041048424318, 0.110492474923376, 0.11831370953586884, 0.1126986721646972, 0.13123685319442302, 0.18808098655426875, 0.11376362439477816, 0.2208893612259999, 0.26798649807460606, 0.17896500852657482, 0.17795571737224236, 0.11336651601595804, 0.09279092439101078, 0.13539642764953896, 0.20704753522295505, 0.13816449005389586, 0.1459512222209014, 0.15223281952785328, 0.12213837500894442, 0.0442977521015564, 0.1934261864516884, 0.18782052240567282, 0.19717265182407573, 0.15848260838538408, 0.13996019057231024, 0.1324156508781016, 0.2044345816830173, 0.27050249744206667, 0.17134836176410317, 0.17283301334828138, 0.08179107870091684, 0.08661684943945147, 0.16106226918054745, 0.18461644824128598, 0.11067537721828558, 0.12863420066423714, 0.09761534442077391, 0.15028796216938645, 0.08802831784123555, 0.11636689290753566, 0.11387453836505301, 0.16877940273843706, 0.17208933684742078, 0.08654122459120117, 0.18261570716276765, 0.0783142949512694, 0.22157020750455558, 0.12015264015644789, 0.13623049773741513, 0.18880533752962947, 0.27865110081620514, 0.2348314513801597, 0.12871090904809535, 0.11412902080337517, 0.10606006471789442, 0.13664189988048747, 0.1406511597451754, 0.1393485421431251, 0.23208268481539562, 0.06831919847172685, 0.1426346236257814, 0.21195132052525878, 0.1488758480991237, 0.10892912599956617, 0.19834377570077777, 0.17732561915181577, 0.09728672142955475, 0.1367363752797246, 0.1325547887245193, 0.19684726459672675, 0.12205429709865712, 0.14129927731119096, 0.23158963158493862, 0.14601997478166595, 0.26714223087765276, 0.14625804091338068, 0.11678720824420452, 0.14307888806797564, 0.11560892264242284, 0.14916727464878932, 0.2457410519127734, 0.06216538415174, 0.14568183745723218, 0.06514589375001378, 0.15794983541127294, 0.34562874119728804, 0.12215169655974023, 0.18064247007714584, 0.10595481333439238, 0.08147860484314151, 0.13460745045449585, 0.08849258316331543, 0.11556842364370823, 0.2610961318714544, 0.20608125894796103, 0.16337091248715296, 0.11907913096365519, 0.11295518808765337, 0.13383769488427788, 0.08777802853728645], [0.05439890519483015, 0.04594236619595904, 0.04869520344072953, 0.04223954652843531, 0.047999391754274257, 0.06534159809234552, 0.05866759762284346, 0.026819018421520013, 0.012465476029319689, 0.07837863915483467, 0.03567145424312912, 0.01789542362530483, 0.048405172128695995, 0.030424277210840955, 0.026679420443542767, 0.04071332354214974, 0.010637685045367107, 0.03277249554230366, 0.042375526536488906, 0.03259188277297653, 0.038122304176795296, 0.06938586506294087, 0.0184195802648901, 0.08833135158056393, 0.026876304800680373, 0.018723669709288515, 0.03811625196249224, 0.038736153073841706, 0.057096333694062196, 0.017293836863245815, 0.050611788683454506, 0.0600494840182364, 0.05754948535468429, 0.03748514071048703, 0.04758352930366527, 0.03369173078681342, 0.013123937278578524, 0.03457920211076271, 0.051861060710507445, 0.04174639310804196, 0.06411343274521641, 0.037431060409289785, 0.03225412765459623, 0.06969492504140362, 0.009100879960897146, 0.006853770901216194, 0.028859683334303554, 0.05285599872877356, 0.05557074895477854, 0.038672024093102664, 0.03527604538248852, 0.00604614260737435, 0.03043373773834901, 0.03548751294147223, 0.05417899570602458, 0.03609023704484571, 0.023895782214822248, 0.06015729210048448, 0.039768142814864404, 0.021166934893699363, 0.030028458313609008, 0.01230463407409843, 0.005390101687225979, 0.01717431212455267, 0.10258027527015656, 0.13669114880030975, 0.020639980357373133, 0.014224344686226686, 0.06928822811460122, 0.05579187927651219, 0.02505054359062342, 0.0147583848774957, 0.05896787057281472, 0.06136786854767706, 0.05742012901464477, 0.03332811553264037, 0.035648165649035946, 0.056798135046847165, 0.018995629725395702, 0.0371925860963529, 0.010873938481381629, 0.037129844931769185, 0.03291047192760743, 0.014917578337190207, 0.025671847361081745, 0.009475787919654977, 0.03145438931824174, 0.03056924277188955, 0.06082879473979119, 0.024472768636769615, 0.04647230787668377, 0.040884058325900696, 0.021837029307789635, 0.06885286202304997, 0.021664763844455592, 0.042501610005274415, 0.0579948667291319, 0.03611374457250349, 0.03321960241009947, 0.060284937790129334, 0.0486813994939439, 0.02576519469585037, 0.024105943593895063, 0.02125800383510068, 0.029929444681329187, 0.03367841665749438, 0.020868164792773314, 0.047044136372278444, 0.06269859499298036, 0.0829553154471796, 0.03715618746355176, 0.05915515896049328, 0.022843559672764968, 0.039597374634468, 0.02539887987950351, 0.07671818020753562, 0.04636596182535868, 0.023405087158607785, 0.07317553085158579, 0.08298848944832571, 0.04690459405537695, 0.01838555279391585, 0.03156993057928048, 0.06170728607685305, 0.05146835326740984, 0.031786871477379464, 0.029486189559975173, 0.03831069465377368, 0.03370479629666079, 0.056648169265827164, 0.04275675295502879, 0.058387448007124476, 0.025038799103640486, 0.023045470225042664, 0.03434754442423582, 0.04902155546005815, 0.048876024011406116, 0.05510063550900668, 0.032493377511855215, 0.1141353661660105, 0.020328090940893162, 0.07338937328313477, 0.008838515914249001, 0.021537329666898586, 0.06540629852679558, 0.06341147236526012, 0.046538893366232514, 0.00860013993587927, 0.01413520532878465, 0.05246611144684721, 0.06473245812230743, 0.02993985701323254, 0.0193434112588875, 0.030662899953313172, 0.011136302528029773, 0.043701217509806156, 0.05414369916252326, 0.02230021851573838, 0.00283615723674302, 0.026612155888869893, 0.04098416291526519, 0.019744336132134777, 0.05700049274310004, 0.06988676279434003, 0.03792409137531649, 0.01978740667254897, 0.03535920302965678, 0.07739610242424533, 0.03470992771326564, 0.03246548760216683, 0.04096952405234333, 0.08721225225599483, 0.06795933106332086, 0.03062788728129817, 0.06351952906697989, 0.04212704436213244, 0.024665036835358478, 0.024088304598990362, 0.03183600907505024, 0.09291734924772754, 0.03165941874613054, 0.0284238292806549, 0.02146157123206649, 0.05113906605402008, 0.03499623344396241, 0.016164026492333505, 0.0672499937354587, 0.06410787405911833, 0.031171356458798982, 0.0702310302585829, 0.020642999043047894, 0.04351823728939053, 0.03482389191049151, 0.036803474358748645, 0.07645204605069011, 0.0215516234311508, 0.01417891597156995, 0.054834612674312666, 0.02360868424148066, 0.058161041015409864, 0.02378888697421644, 0.09586026906617917, 0.029455872827384155, 0.010311304267816013, 0.07199527113698423, 0.06801069510402158, 0.07819415608537383, 0.10065446884254925, 0.009579644065524917, 0.04983559869288001, 0.07205085799796507, 0.04249334248015657, 0.02298397772392491, 0.04485279321670532, 0.04975527976057492, 0.02374865514866542, 0.0030565129418391734, 0.04660763108404353, 0.03931303559511434, 0.04739517222333234, 0.023289169257623143, 0.036806183197768405, 0.022789928370912094, 0.04861291039560456, 0.0283577874142793, 0.04501259245444089, 0.041339699891977943, 0.04614755518559832, 0.04098840057849884, 0.01836058323533507, 0.028273917305341456, 0.03085784916038392, 0.05794871256512124, 0.022662878254777752, 0.06952311785425991, 0.061707059721811675, 0.09149673016509041, 0.024902340410335455, 0.031205732739181258, 0.0285458865982946, 0.10334378937841393, 0.018731323107203934, 0.023096645018085837, 0.02947118890006095, 0.045742283182335086, 0.049173773659276776, 0.02412580532109132, 0.051450619648676366, 0.030114708861219697, 0.02448575251037255, 0.0476929441356333, 0.02248442699055886, 0.033253232832066715, 0.0937727783457376, 0.00791027470768313, 0.06568756507476792, 0.026876672163780313, 0.0663650048954878, 0.022815909105702303, 0.011633085978246527, 0.02624704149639001, 0.026854687894228846, 0.017618023666727822, 0.060568104236153886, 0.06995899602770805, 0.02446424878144171, 0.06839765090262517, 0.06802923395298421, 0.043920655734837055, 0.08106373687041923, 0.04307793962652795, 0.0469312519999221, 0.02896001242334023, 0.02136360217264155, 0.07000175115535967, 0.04332612494181376, 0.03125982046185527, 0.006762461689504562, 0.020478494589042384, 0.044309912191238254, 0.041082026218646206, 0.013763319766439963, 0.02204958782385802, 0.004779245036843349, 0.024819000936986413, 0.016663265523675364, 0.019516118300089147, 0.028251884796191007, 0.07592702851979993, 0.03175717814883683, 0.021809200625284575, 0.033799524026107974, 0.08553936233511195, 0.04014630045276135, 0.02337996174901491, 0.0382833576441044, 0.02489318787411321, 0.03371704544406384, 0.09232568685547449, 0.05008392872696277, 0.022151787125039846, 0.02876330432627583, 0.06163678575831, 0.024178015410143416, 0.028028748820361216, 0.06129091896582395, 0.06997657750616781, 0.10960994259221479, 0.012711343988485169, 0.10012397426180542, 0.012289912647247547, 0.056406076982966624, 0.038005720198270865, 0.03595039786887355, 0.05464714617119171, 0.07156385327107273, 0.032611820570309646, 0.019590420270105824, 0.01125668537497404, 0.015777374974277336, 0.06206901998666581, 0.05814937445393298, 0.028854740630777087, 0.02938902016467182, 0.04812607265193947, 0.06504892473458312, 0.1280957428389229, 0.028707318560918793, 0.05192495220398996, 0.058877324845525436, 0.023400714053423144, 0.0306286554041435, 0.06354315904900432, 0.012311772607063176, 0.009558884339639917, 0.0615139528963482, 0.026210462892777286, 0.05177689003176056, 0.06874904298456386, 0.020009123290947173, 0.028994121530558914, 0.011793593039328698, 0.03417408966924995, 0.02504668813344324, 0.024733965656196233, 0.0335765828640433, 0.09430058635189198, 0.04850266806897707, 0.01068397094059037, 0.020930110003973823, 0.05760503881901968, 0.01298726892855484, 0.15788091957801953, 0.08815488370601088, 0.09482710302108899, 0.15965460799634457, 0.12100579086109065, 0.13355119619518518, 0.17001350526697934, 0.09599517667084001, 0.12571785715408623, 0.21462210221216083, 0.1442347385454923, 0.1519882373395376, 0.12593929917784408, 0.17419157404219732, 0.08058226856519468, 0.10171223708312027, 0.12004272066405974, 0.13345468731131405, 0.22926952951820567, 0.1011942328477744, 0.09259134603780694, 0.12105658344808035, 0.13015670177992433, 0.17536155501147732, 0.1347510115010664, 0.16801018151454628, 0.14705938228871673, 0.10196006245678291, 0.17819823639001697, 0.1789358421228826, 0.2287102915579453, 0.25620531931053847, 0.11863178660860285, 0.2274364692857489, 0.164889732550364, 0.19006473245099187, 0.14455972501309589, 0.18639834481291473, 0.15568644826998934, 0.1307245486532338, 0.13192164769861847, 0.1226858573500067, 0.15347731212386861, 0.16324887372320518, 0.09718420114950277, 0.10580345973721705, 0.17314901982899755, 0.15508239943301305, 0.17036672303220257, 0.21892160119023174, 0.13414369721431285, 0.10153177645406686, 0.11452049628132954, 0.11358420277247205, 0.12623980961507186, 0.13936725910753012, 0.09656361726229079, 0.14972308388678357, 0.22612297179875895, 0.1803492772160098, 0.18829849519534037, 0.1849327961099334, 0.07260123471496627, 0.10012012251536362, 0.28916688810568303, 0.23319520871154964, 0.1407973628374748, 0.07662966425414197, 0.11739956913515925, 0.18386576586635783, 0.09087388272746466, 0.10261058458127081, 0.16856576810823753, 0.12197154763271101, 0.14145278313662857, 0.09469188371440396, 0.13033892872044817, 0.1575298243551515, 0.08174355156370439, 0.16159281571162865, 0.08429420180618763, 0.1538618782069534, 0.11534876277437434, 0.16773607669165358, 0.1919884089147672, 0.16878538444871083, 0.09233318996848539, 0.11540094317751937, 0.1916092456667684, 0.11187486597918905, 0.1098935840127524, 0.22553103481186554, 0.15829965414013714, 0.1938091791816987, 0.14228645246475935, 0.20916161709465086, 0.24585684179328382, 0.11642565616057254, 0.1744794679689221, 0.1998074393486604, 0.10301158923539333, 0.09914373818901367, 0.13439630944048986, 0.10604765600874089, 0.10688559268601239, 0.10098971921252087, 0.19020988169359043, 0.17259260202990845, 0.1160082129354123, 0.13504831586033106, 0.17127217288361862, 0.2417116946890019, 0.18267270410433412, 0.23847098811529577, 0.09996520660934038, 0.12133338226703927, 0.1278124947566539, 0.07781832508044317, 0.1199215576343704, 0.14029360783752054, 0.13478598149958998, 0.20922900410369039, 0.15573943761410192, 0.31491130823269486, 0.13112418033415452, 0.11274011369096115, 0.09600991572369821, 0.15120145690161735, 0.17587126203579828, 0.13945222017355263, 0.10856368506210856, 0.22318650124361739, 0.1454806560650468, 0.14116270729573444, 0.1972726488020271, 0.32192611775826663, 0.18608653888804838, 0.20861704397248104, 0.12186964333523065, 0.20599076146027073, 0.14202221820596606, 0.14838145900284871, 0.13276414858410135, 0.1423746789805591, 0.22694647370371968, 0.11605366205913015, 0.19240570371039212, 0.05794321325083729, 0.11312766320770606, 0.1613457695930265, 0.3308077255496755, 0.12656141188926995, 0.17026310437358916, 0.1614756157505326, 0.07742264904663898, 0.09760560002177954, 0.15108406398212537, 0.10294919688021764, 0.14199607976479456, 0.24758766376180574, 0.1375913294032216, 0.1650693768169731, 0.16138131846673787, 0.22930115985218436, 0.15460476803127676, 0.14801237412029877, 0.18481650156900287, 0.18287485028849915, 0.07754115518764593, 0.11794360791100189, 0.21863186673726887, 0.12208727071993053, 0.12441031911293976, 0.15938097814796492, 0.30970962485298514, 0.14259007992222905], [0.007468568355761818, 0.035540509707061574, 0.025516486166452523, 0.038342681218637154, 0.03622881085902918, 0.052403967711143196, 0.03430752411077265, 0.041495658515486866, 0.07313523965422064, 0.026662705422495492, 0.056903850272647105, 0.022498229081975296, 0.04972308539436199, 0.09051327317138202, 0.03223887651984114, 0.10926042072242126, 0.04133906535571441, 0.03673937877465505, 0.158485948049929, 0.06720772842527367, 0.03195373967173509, 0.008551111804990796, 0.012848012338508852, 0.022875618597026914, 0.015212325997708831, 0.06544963995111175, 0.02139591713785194, 0.038888115232111886, 0.04585799513733946, 0.031946225426509045, 0.032922134778345935, 0.043608274645521306, 0.011563000334717799, 0.07307692911126651, 0.018888439481088426, 0.05061864612798672, 0.03908726685040165, 0.05377964975195937, 0.01504487614511163, 0.04028867777378764, 0.008087436490313848, 0.06708291402901523, 0.09950316773029044, 0.03871919871016871, 0.03768065209442284, 0.010072024724649964, 0.03602474622312002, 0.03460028652625624, 0.040511886109015904, 0.04263554539647885, 0.04095975738891866, 0.021558727639785502, 0.025518909278616775, 0.043537859673961066, 0.020365014643175527, 0.04565996045130305, 0.03609335777582601, 0.06290509016253054, 0.05304394391714595, 0.04974024755938444, 0.007434018134517828, 0.04509504135057796, 0.008058309049374657, 0.037506124936044216, 0.0643604937067721, 0.047960061638150364, 0.016637041735521052, 0.06613379620830528, 0.043473630503285676, 0.03369089215993881, 0.04837129308725707, 0.037269012464093976, 0.026074930028698873, 0.03765299225051422, 0.016893835963855963, 0.06186510006955359, 0.04097720157005824, 0.09439866858883761, 0.05394647712819278, 0.011938463048863923, 0.030672497778141405, 0.04121262565604411, 0.0390647686435841, 0.02605336507258471, 0.024225490597018506, 0.023358864345937036, 0.056167751099565066, 0.06306997311185114, 0.012953440909768688, 0.03427024603297468, 0.06624720379477367, 0.01477204688853817, 0.06173739871883299, 0.038049258291721344, 0.02772616036963882, 0.04023958841571584, 0.07016491974354722, 0.011235915444558486, 0.06724295075400732, 0.010582498944131657, 0.013085840982967056, 0.014613900784752332, 0.04480906958633568, 0.03701180263306014, 0.038020477804820985, 0.01417741312252474, 0.018387404452369083, 0.07004837287240662, 0.02470710918714758, 0.031017127039376646, 0.06250087200896814, 0.04633340009604581, 0.049819052510429174, 0.025406852400919888, 0.03446511174843181, 0.060756661696359515, 0.014756455293536419, 0.04322724860685412, 0.027407302186475135, 0.06586260802578181, 0.023005514849501196, 0.04746588776470162, 0.017717990958772134, 0.08960979743278585, 0.013489598077285336, 0.02142618192010559, 0.022330991669150535, 0.02276593844726449, 0.0110414170922013, 0.05676861241227016, 0.036284312373027205, 0.04370079448563047, 0.05027751794841606, 0.04197900074359495, 0.05120282025018241, 0.024800996434350964, 0.07284740509930998, 0.04716080569778569, 0.09440364097827114, 0.042804903496289626, 0.03133180878649, 0.01927310946484795, 0.035768222878687084, 0.018710602344071958, 0.03176051039190497, 0.03622987584094517, 0.036042806386831217, 0.07085171804646961, 0.08293509934446774, 0.019503674338920973, 0.025108069312409498, 0.04378145109512843, 0.03418442778638564, 0.018763613952614833, 0.0240642163407756, 0.0429086408985313, 0.04660822851292323, 0.07167604373535141, 0.04196371621219441, 0.03833422073512338, 0.03657097804534715, 0.06722500562318601, 0.021148577870917507, 0.03569469459762331, 0.020909854938508943, 0.1078692203736864, 0.06238694491912611, 0.04843727743718773, 0.053195850414340384, 0.0358580746978987, 0.06513968939543702, 0.01291771299293032, 0.030787187424721196, 0.03570710701751523, 0.02883051878598053, 0.04067219371790998, 0.05052389242337085, 0.032944603299256414, 0.04347137066361029, 0.03709506418090314, 0.05829109126352705, 0.06438585289288312, 0.020352468636701815, 0.04706099796749186, 0.11484819900942966, 0.0836705973779317, 0.0843971896392759, 0.02508537258108845, 0.05090559752716217, 0.0665421703888569, 0.030346045568876434, 0.0453235003806185, 0.025398020843567792, 0.04497788591834251, 0.10315820050891489, 0.056507740082452074, 0.04790215185494162, 0.021962079335935414, 0.02394042610831093, 0.07165138216805644, 0.06694941650494002, 0.04345726243627723, 0.010417397061246447, 0.08576430729590356, 0.013777656204183586, 0.014374937582033454, 0.06673231604509056, 0.03346354635141324, 0.06984853476751596, 0.06961063190829009, 0.04474537476198748, 0.06746417013346218, 0.06847746888524853, 0.016597817375441082, 0.021888981500524096, 0.037375770407379605, 0.09266826222301461, 0.035182686915504746, 0.05813011943246238, 0.07233483338495716, 0.033063217051676475, 0.028952661450603046, 0.016449035319965333, 0.02387970729614608, 0.047505577822448686, 0.013478650471370202, 0.0908337919099722, 0.034740730552584864, 0.08518077142070979, 0.05082750132714864, 0.02996715691551799, 0.03485344423097558, 0.016926392127061263, 0.00713943745722645, 0.027423334431659896, 0.06089431895816233, 0.013310273861861788, 0.019168058461218607, 0.018785010070132557, 0.01772270174114965, 0.0041162562229146715, 0.041684100942802615, 0.01243848597368924, 0.04198375048872549, 0.06757672425010242, 0.054856494898558594, 0.05057077018136624, 0.0419387095462298, 0.024835582371451892, 0.024822685700200964, 0.0666748292860575, 0.04948321955453139, 0.028534704288176727, 0.0363923393888399, 0.03260872952523641, 0.05002388155844528, 0.021662227554770652, 0.03636303939856589, 0.021935651457170025, 0.10161684884224087, 0.06695888630929403, 0.06120830308645964, 0.06761526397895068, 0.04499278082221281, 0.05583039303019177, 0.038341720137395896, 0.03174300312821288, 0.04815472326299641, 0.055217764966073446, 0.030829911011096556, 0.034325973902014084, 0.03852484136587009, 0.011485616596473847, 0.008922484357754001, 0.02496010176400887, 0.03976295891334303, 0.03430239587032702, 0.010651277480064891, 0.06809998289099894, 0.04892182936600875, 0.024757584506005514, 0.01233401662830147, 0.09196726663503796, 0.010779985368571943, 0.025288886172347702, 0.015016245015431195, 0.03332902095280588, 0.025364928478666116, 0.09099595859879628, 0.017219969049619976, 0.08297570966533385, 0.06222368356247898, 0.012782662524841726, 0.022080479720898438, 0.05607239254459273, 0.12284576790989377, 0.023332996788667515, 0.026194616184511688, 0.026663705466489773, 0.06212497792148497, 0.032491473903064616, 0.042197455622954294, 0.06381329338182695, 0.041050421859836206, 0.007121836033547879, 0.018387072341283783, 0.058584703438100405, 0.044846726159448735, 0.01259637047041906, 0.0292251595237758, 0.026936841786664445, 0.02960091074783122, 0.05098457317217253, 0.01688503038167255, 0.0672722581657581, 0.008165655144694028, 0.023298108426388353, 0.07838535559130833, 0.021090476984682027, 0.07115128595614806, 0.03053642500162823, 0.021223263902356848, 0.06776621681638062, 0.010136304917978123, 0.05630623585602734, 0.004278966998754186, 0.06393562158336863, 0.0565903745155083, 0.09394335356773809, 0.0736994574253913, 0.047667544131400064, 0.014380392367456807, 0.04773607033712324, 0.027033825645048637, 0.04077622426848393, 0.05450341443065554, 0.008216959813580615, 0.02158386789233191, 0.008249549373431364, 0.044689494752674364, 0.01193718655486009, 0.06249693862628192, 0.07836633434635587, 0.038686726038577035, 0.061533616099040955, 0.03961779482779093, 0.017343881736451294, 0.02139423246262595, 0.01586713216966018, 0.08109852133202367, 0.015570631185255479, 0.118864405376371, 0.06951301722438075, 0.10108963455422781, 0.1215728881652467, 0.09950958730769344, 0.1495464675826952, 0.12548819213407114, 0.11095597583334893, 0.09329087217338383, 0.15932565846014768, 0.18087445059791207, 0.18751299125142395, 0.11678712660796009, 0.17768594669178128, 0.16034532483899966, 0.0875988147163298, 0.24647344776894897, 0.11267143534496427, 0.11254216806264594, 0.1893141242908314, 0.16784490522695705, 0.11055060735088773, 0.05271573652862571, 0.10391737305326387, 0.132407724740915, 0.1491880844696425, 0.23619293613592163, 0.11380695839761756, 0.196046516939532, 0.10011247839429416, 0.07557096090749837, 0.16642620088532567, 0.08184999780496582, 0.18271950393682346, 0.1743393059587106, 0.10766975334263407, 0.14035553263965994, 0.14604183845221996, 0.11005655964254402, 0.12775019888067618, 0.1519917996483855, 0.14762411214178428, 0.30404199147596955, 0.19065128144575283, 0.13763723865849897, 0.1695931379799731, 0.1196513045579195, 0.16036292858188972, 0.13987606071168557, 0.1146040101593826, 0.10584418880171143, 0.30284155276603997, 0.11937672476051375, 0.19689885870320722, 0.2514574147062376, 0.09322415309725329, 0.10713957046391442, 0.10408211499452591, 0.13455967098707333, 0.14115470694378018, 0.20083231560420245, 0.13522331428248435, 0.1251859896001406, 0.13270577124785632, 0.10458224089234136, 0.12642384739592671, 0.07719540342804976, 0.1416606141719967, 0.1962022195220925, 0.12672564917011186, 0.15444066433701664, 0.16122776811243966, 0.14879093156196177, 0.15760498907184228, 0.181727786839474, 0.14946806710213423, 0.1365149035700597, 0.12889288365840912, 0.2720170724205673, 0.14620638743508607, 0.09953490196494386, 0.15912005386780947, 0.10168977969442494, 0.11997008667094633, 0.16277464135782793, 0.12324999348493293, 0.2040782172116451, 0.14076534658670425, 0.10055566672235727, 0.15141678362851962, 0.09859568439424038, 0.12701686791842803, 0.10115305849467404, 0.1668727066135034, 0.13894160772906616, 0.1516642453498207, 0.16540399636141956, 0.19587485818192363, 0.10562853552983142, 0.17695092363283038, 0.09730568330269307, 0.07142780275898986, 0.1946676807710901, 0.16211933980230242, 0.14301858114777133, 0.13270974915940315, 0.07280856851139106, 0.1409039946156554, 0.142559859668836, 0.09129312937147915, 0.14945432252716273, 0.11398450980777852, 0.13502802554285154, 0.13111108884913847, 0.15306070010410622, 0.09828710681176744, 0.1160366742988117, 0.07398528076009825, 0.1506932935444638, 0.22592539724428207, 0.19368765992112458, 0.10361328546423465, 0.08127971668727696, 0.13251077936729416, 0.18223577208118513, 0.08090873932815157, 0.1481630894704722, 0.1605285017285496, 0.13370581524213776, 0.08511942549375817, 0.10828259662957862, 0.14609457546612248, 0.1501275840564631, 0.1470978552242741, 0.14604461408453062, 0.1263907624525018, 0.178534681617748, 0.14219145756214857, 0.20625346689485013, 0.15171215840382501, 0.10167366766836494, 0.1094906275102403, 0.1639846240868792, 0.1526924761128612, 0.1409042172599584, 0.1372663874644786, 0.14329345780424774, 0.13623621227452531, 0.1097685618151445, 0.13315080752363428, 0.14071627578232437, 0.16508318076375872, 0.15082747384440154, 0.1538533583516255, 0.3066376084461808, 0.07920932504930533, 0.1290939759928733, 0.16197147429920733, 0.168875377275981, 0.12160255922935903, 0.1266564364777878, 0.09627025370718911, 0.14478781668003649, 0.12998259393498302, 0.14199220575392246, 0.13841992244124413, 0.16357198997866362, 0.24901953380322084, 0.13409024773864076, 0.1537215826101601, 0.0931195993325673, 0.2798214083304629, 0.1282316746073775, 0.1308599757612683, 0.133473374589812, 0.09338220828794874, 0.19398892734898254], [0.04256077401805669, 0.0700539760873653, 0.07090812869137153, 0.03977155669417698, 0.05516823031939566, 0.06083706597564742, 0.008737105144973611, 0.06687296787276864, 0.031080196604307275, 0.03942222407204099, 0.01708992807834875, 0.0831361100426875, 0.030686815662193112, 0.022010493339621462, 0.02287251641973853, 0.024606379338365514, 0.02723154677369166, 0.062439028843073174, 0.06207058220752515, 0.021555137500399724, 0.06331926051643677, 0.05248176705208607, 0.06080136867240071, 0.02646416236530058, 0.06297723433817737, 0.06183094643347431, 0.04229568628943525, 0.025891599143506028, 0.07874448085203767, 0.023041670428938232, 0.02906677964347182, 0.048636822393746115, 0.041487910493742675, 0.055848219417384826, 0.014374226047948468, 0.022468251881946344, 0.041317346403957345, 0.05569990120420698, 0.04155050693952944, 0.04784384502272587, 0.05760025938798208, 0.0264590675215004, 0.06911399410455488, 0.027584072486206423, 0.011570624974410748, 0.019698892574524507, 0.04567849187878892, 0.055036814519553445, 0.06967288325540721, 0.015082048466865672, 0.058635206587496214, 0.07663226177101023, 0.013902204354963033, 0.05250639151199721, 0.03952658487833105, 0.03552458692865912, 0.028672766020463314, 0.032521953908144496, 0.07165391289163381, 0.038548775628441945, 0.043384005039115436, 0.05171911012439523, 0.044875495514133945, 0.023251256643561646, 0.038172532731550746, 0.0410444030421786, 0.041190287010977045, 0.0755067725549452, 0.02965106879855739, 0.04714245238574222, 0.040683875122340396, 0.05252599163213745, 0.03858244315779302, 0.030547870774171315, 0.02972561753267655, 0.06974226664169692, 0.06411924376152456, 0.03864983387757093, 0.09263350002584048, 0.026384285010863096, 0.020971816848032176, 0.05056580150267109, 0.06995364514295943, 0.04243162176862825, 0.03941001203202177, 0.09997360772104003, 0.02901019644923508, 0.008014616032596678, 0.04576059938699473, 0.06664233806077391, 0.01172695559944259, 0.03717297855473589, 0.019592338721849956, 0.08101305560558103, 0.06047093113011215, 0.038430622007581405, 0.018323416479688603, 0.08480611300910823, 0.11527687092893757, 0.04392606599139981, 0.06254548992728814, 0.018276772498211358, 0.04731132437882479, 0.019174722947354894, 0.05174844722205307, 0.07074642955558375, 0.05579649543506093, 0.09093841988942586, 0.03825191284704488, 0.07012852482148446, 0.010117206675204216, 0.010333225454814965, 0.01934163195983274, 0.04301786648284178, 0.03649814367236104, 0.05707743490347639, 0.06273248887737282, 0.051831430464517325, 0.04334702010964975, 0.02155010759452125, 0.03572749381419271, 0.05721908120904118, 0.027769167827500496, 0.048029088793555275, 0.052716567734023556, 0.08015034603886306, 0.03550323534000199, 0.03334067267132923, 0.08134947856888175, 0.015135050798562588, 0.037026278223493136, 0.06924894623807631, 0.027304477625875734, 0.050248225379618816, 0.06293744037975557, 0.03500978506053798, 0.018831852576113306, 0.04517264031164814, 0.05385201657190919, 0.07383002346614376, 0.015720060764579102, 0.022010849570506252, 0.08883601942216046, 0.05243955740297679, 0.014720905492140446, 0.026177125619142316, 0.03095318730629515, 0.07122256181901321, 0.037270871544023976, 0.0366619505075505, 0.04649272435926832, 0.00959918388616643, 0.03611145875765942, 0.028932348868693225, 0.0486038265080424, 0.0347940167557681, 0.08407608460402116, 0.05135764709848445, 0.022601268865400925, 0.09528570575639606, 0.049283147673122585, 0.05424173687060829, 0.023287876065296587, 0.12395022466080263, 0.0464364250365179, 0.06189974723383784, 0.03654234598798212, 0.017948932472791057, 0.0733240568661131, 0.08895248465705663, 0.09049624830367975, 0.03257794895034749, 0.04560868917906191, 0.08095300843706354, 0.00552988009985711, 0.03982456088124309, 0.0516407467512181, 0.07006792846368626, 0.0512051023542881, 0.031692210541223176, 0.01998565101530403, 0.04877026425674558, 0.044030560384271666, 0.08784816149272956, 0.015897259654593654, 0.012004443688056199, 0.002887436394303222, 0.0033525804656164837, 0.055302982073044404, 0.026354105575592257, 0.031505649458267726, 0.0872828156570904, 0.012112256408727262, 0.06595815211767331, 0.010648816332832212, 0.02241225869511254, 0.055867129340185784, 0.05874118156498298, 0.009361359880131204, 0.04472132175578736, 0.06045553527656011, 0.0338736608682666, 0.01650838301429758, 0.06427784814150073, 0.0930640495789703, 0.012004971540591214, 0.02093346822221065, 0.02639605361764552, 0.013080954868200934, 0.03917828755220398, 0.03555297778802924, 0.03128996650048066, 0.0343035721743945, 0.07449482451193035, 0.036668140019173734, 0.014388557847269112, 0.0713295943569392, 0.04487316145969089, 0.04186769714578986, 0.004072800693393219, 0.013694296321773436, 0.010640605396474712, 0.041799593964242376, 0.04133172180445399, 0.042760664073284715, 0.053584765482810326, 0.19369070272659883, 0.03277279240137432, 0.026094272252521478, 0.03239356978156138, 0.03727537266968284, 0.03444979382038582, 0.0040715260547585785, 0.04128294785914477, 0.027019648769055493, 0.01674170867772773, 0.04439705146069173, 0.01017217477055965, 0.039138493593782187, 0.0473966639401624, 0.008225781166402157, 0.021561527391895652, 0.07491500626201741, 0.04446259423275478, 0.027025251984014176, 0.02247525961138308, 0.09420377318747342, 0.04521545481111389, 0.04074122087331489, 0.04372215349576436, 0.027657023747451603, 0.01935208882059669, 0.06895539714605547, 0.044596874722628854, 0.08186654027667828, 0.018337177752982825, 0.07320563236135058, 0.0057199895763915265, 0.010659091367415385, 0.08434884613961913, 0.04774441578774713, 0.008096108485915465, 0.017275750724365935, 0.04837192020204384, 0.04427955464052502, 0.03309895888378378, 0.014083876540098572, 0.044838384419563226, 0.028789212701667566, 0.07781584630720317, 0.03233902192732785, 0.04447476545465179, 0.040832794475136325, 0.044697829071083106, 0.054316044406732544, 0.007744082331555546, 0.03432202196563594, 0.011921158020413714, 0.031204671468003653, 0.03178949868015479, 0.0664219944155775, 0.05988448603602592, 0.08880070803570561, 0.07151668978622183, 0.05027220046031289, 0.044881692447233945, 0.05308191590302158, 0.03040493498701835, 0.06503702810732648, 0.0455428050190676, 0.017081480582419317, 0.034336645985604264, 0.08152335634804331, 0.03377340042789001, 0.04022890148917213, 0.032746668803156354, 0.03452062439464498, 0.012585547174239764, 0.025609128460928332, 0.05161219261935912, 0.024153854792530183, 0.06556230538990349, 0.05413395105279051, 0.0032703727674743277, 0.0800226817955263, 0.062394997221417725, 0.059740390643128194, 0.024402758135693148, 0.03998841224529315, 0.07532882038503885, 0.017450665654905606, 0.03911655199772213, 0.06443927268264815, 0.042980677462765016, 0.04344450120697729, 0.04755989561090246, 0.03405582101549953, 0.04395358482724987, 0.018537336836743634, 0.04313831705076154, 0.03723695168446284, 0.05676460852555465, 0.02148441824829206, 0.027683926600730047, 0.04034738907648716, 0.02574780060967896, 0.024083233874989673, 0.14510032022371888, 0.05803109466796741, 0.058977347798645496, 0.008386696408706484, 0.011214519327040762, 0.08893911115592346, 0.04818229775992222, 0.028745811905537266, 0.03325255376694258, 0.051425831916276366, 0.020568938271026127, 0.08661818530526944, 0.050101105734938756, 0.048660289103281684, 0.04716291710792575, 0.015084114420460537, 0.03015847145434236, 0.0727163121337071, 0.09284291183575988, 0.02916172074037604, 0.03366758501215372, 0.02022666718403343, 0.01268391792109469, 0.05664091106154956, 0.007267896726261824, 0.16169214475667104, 0.16581467119976878, 0.15610224392730743, 0.20685334486188367, 0.12750019901432097, 0.23177871596999466, 0.16719361126888543, 0.17467628553276882, 0.10506896360311657, 0.1535339083056897, 0.12670877273194492, 0.16716147627448663, 0.18854739668313414, 0.13148943573469296, 0.12288855272345245, 0.10053157660877332, 0.12931549223139882, 0.11519870793563314, 0.1409840426640585, 0.1731334940996021, 0.13858717284165323, 0.16389071271987632, 0.20047939469804987, 0.15489545243326575, 0.1515367443789728, 0.15999419993022457, 0.08118692596326582, 0.12569606769829988, 0.17982766614295542, 0.1736442995024845, 0.12873217900050804, 0.10871604798012413, 0.1603143772808835, 0.1798500493168831, 0.10306586991646327, 0.1520125797833316, 0.13236785656772554, 0.10812112013809383, 0.09232910815626383, 0.13681959972018376, 0.2623276220401749, 0.1831403313553892, 0.12158695186371915, 0.12154315772932023, 0.10365879395976663, 0.11229417941649444, 0.11657644572551362, 0.17681327008176595, 0.153960851021111, 0.19242044276325032, 0.20689509809017181, 0.22032746637705714, 0.06688435983960517, 0.08617786166723818, 0.11842019288451411, 0.1162611813924741, 0.12321442976826802, 0.06978607561904937, 0.13981179072288796, 0.1340087450807914, 0.18430626019835472, 0.09329726206487976, 0.12266034973436035, 0.11338297685142606, 0.11006044849636964, 0.11424875890952535, 0.1773255004081875, 0.1250245131086558, 0.09114218395552598, 0.1114712786511518, 0.1275701983831823, 0.12180435660411604, 0.07612561239511706, 0.1925559144001454, 0.2084884446230717, 0.19113930291496217, 0.1704310078639537, 0.18688048847252503, 0.14350465819006786, 0.12919928674818948, 0.15021824481664225, 0.14972961478633806, 0.10540534203755669, 0.2787798782810569, 0.09622044817660935, 0.18479373247828335, 0.10203777274000458, 0.09554900490911677, 0.1826462391181849, 0.1567914616316557, 0.14976673701312393, 0.10670478324755095, 0.09942444070475176, 0.25021556415595114, 0.16113600897369906, 0.12493204150814563, 0.08592292651883326, 0.24968730343971401, 0.20623221178539097, 0.1038791672908701, 0.1589360457728617, 0.14853529137326404, 0.15112516412045807, 0.14366632763994858, 0.1578019402222708, 0.1208138937363401, 0.2108061421313323, 0.1655696882517077, 0.13972127839224413, 0.11977838250459172, 0.14609470905270427, 0.08876990890712477, 0.08781771117355675, 0.11054789851186797, 0.08858852059347555, 0.15161078103119507, 0.1806667383061722, 0.15477684239158407, 0.1425747768371366, 0.11898492273758166, 0.12518852774519473, 0.04758502102049533, 0.11315895215375349, 0.12300531481741928, 0.13109683961374685, 0.17234914790606126, 0.1077009977598209, 0.16971798206213862, 0.17381848156219348, 0.1250512749538757, 0.08566692267777398, 0.10634276361088268, 0.11983462987700477, 0.1654772463371046, 0.15315818862291053, 0.12931564066093415, 0.12740003876388073, 0.1612868727534078, 0.1661930329282768, 0.1803698792355135, 0.10225315141724423, 0.07063463242957368, 0.18797575001372024, 0.13459654088364914, 0.1855441031511873, 0.11320090576191433, 0.1325179633568041, 0.21431464527267963, 0.1502267349860631, 0.1310595392715186, 0.1406939816661179, 0.2610610728152096, 0.1433894768706523, 0.15422938973642886, 0.09303765138611197, 0.202688041026704, 0.18708753283135593, 0.1334477259661071, 0.11834018194349483, 0.1684129747445695, 0.11350926070008427, 0.11780789136537351, 0.12692136835539714, 0.18711723358137533, 0.16955868748482317, 0.1349220468546264, 0.16260670818155631, 0.08454650233034045, 0.1793955432367511, 0.18054101848974824, 0.16200797312194481, 0.14939570770366117, 0.1344012373010628, 0.12327901145908982, 0.18029671831754968, 0.1257161353714764], [0.06935641664313152, 0.0832900611567311, 0.038060872902860865, 0.04527917561063077, 0.005508163003469235, 0.04381149323307909, 0.07043178120511584, 0.020044284392497502, 0.06285349605605006, 0.02740575666393852, 0.04427376217790879, 0.03974149229179602, 0.055631786890444346, 0.005567728239839198, 0.03517103148624301, 0.03115452083875425, 0.03285469952970743, 0.025527045072522014, 0.051640542660607025, 0.042215129869873635, 0.03375770400452893, 0.01633374824450584, 0.053418791576405056, 0.03259825040004216, 0.08851146340020932, 0.029681558080483228, 0.0442753095558146, 0.05579692588071339, 0.018287926977791358, 0.011582427905523218, 0.011680522202368593, 0.06598141844733618, 0.046220096410252154, 0.023411907495756168, 0.02910855142545188, 0.018957835854962468, 0.02105134910380002, 0.035784312640316784, 0.030952031411288772, 0.05124233590322547, 0.03959208683227189, 0.06565383446286432, 0.011519397303345613, 0.032701167729101144, 0.031155864126048982, 0.012085553935321514, 0.05353277061658446, 0.022355092914949637, 0.02307829727214994, 0.04528264144028071, 0.03977275155193638, 0.03441823399043642, 0.020402365080371965, 0.03443633126153145, 0.023201104158943053, 0.026169607663177885, 0.037651199963875115, 0.013972499655210413, 0.030869239271851256, 0.03684964707645122, 0.031037665976327844, 0.029751624242635444, 0.009355776146549033, 0.04340243627666496, 0.012067082807334373, 0.02884135228669038, 0.046076776561676525, 0.024941460869740695, 0.04436607050593011, 0.055519036104669794, 0.08997652228572406, 0.022620253002969548, 0.05412708247604314, 0.047653877481934614, 0.05835411444422789, 0.06530231621582061, 0.041326148275402375, 0.020934922831656877, 0.026374655644758604, 0.020021964301122352, 0.014908765333530027, 0.03553730362909846, 0.04716477618785575, 0.021299725522112567, 0.0418215207173489, 0.056438612737110816, 0.0650188306462951, 0.03539526769600343, 0.05833132308907807, 0.03023142271558754, 0.007968822737893788, 0.0626377017761115, 0.0463225127896294, 0.030524689791491255, 0.0652172883565072, 0.04683638326241635, 0.051330432543181814, 0.029170839879952837, 0.010170871373702539, 0.02214116699178703, 0.0580562163668219, 0.0557729545107577, 0.056352390020038, 0.060308864631224424, 0.022172606222738978, 0.015360205416072858, 0.013562394415203016, 0.10006000113207847, 0.015918958197289612, 0.08900653527234681, 0.021141597972018644, 0.03297806302725803, 0.026921842982119415, 0.039678402317804284, 0.061776213042321615, 0.024676367575011682, 0.1047693140571937, 0.06585952069144696, 0.0480238158343127, 0.024249243033409584, 0.05806323708384298, 0.013261822750791907, 0.025405013730050996, 0.0421508450381225, 0.03124719652987551, 0.05653293970681261, 0.019957390031777322, 0.024865270133886952, 0.06348880415316671, 0.06233221152797341, 0.01466135649025091, 0.01946169104485307, 0.03286564620793797, 0.10893371247220784, 0.0711821518780198, 0.03458182931353804, 0.024915558060456533, 0.021734277106588706, 0.04550887031655293, 0.044129822636023164, 0.02442658478685189, 0.017689069463813212, 0.0602309205714846, 0.005094782572996337, 0.022356341578415595, 0.061457668416551314, 0.10493759604287334, 0.026406148681417108, 0.027501139338710345, 0.013049164044787176, 0.07972663908731192, 0.032105223144753836, 0.01072772796760546, 0.02637023244460579, 0.01755210611008806, 0.053113089816179127, 0.012845893506892025, 0.016747708941693418, 0.008812015676085139, 0.003134553712698107, 0.0280612196365837, 0.07542322156950831, 0.045528477858169936, 0.04450156069651712, 0.01866925915237516, 0.05529114852834027, 0.05401511465606745, 0.03881752214510925, 0.056394247149000876, 0.04505451266595628, 0.058501987368799746, 0.028353199086268432, 0.07004312588833272, 0.018980899949383456, 0.040243069088319317, 0.020553787326207384, 0.06679068595985882, 0.03435125887335744, 0.04607473194482736, 0.038908735805307515, 0.04233029263559729, 0.0939476654457394, 0.055661001533735543, 0.012792062752851052, 0.06974485673708841, 0.026297826661902945, 0.019452358537819237, 0.11111578991403803, 0.024945492586994078, 0.01884605171653675, 0.06733263187925331, 0.05748209834564477, 0.019405063321755733, 0.0019143659892506548, 0.03594727713789325, 0.03774000164412428, 0.053051268914714456, 0.013185140342102386, 0.014376887575053843, 0.05665398399287369, 0.08871475249179639, 0.020682982249127235, 0.03753845659957733, 0.039425478389603086, 0.027830151957459748, 0.018078847278957255, 0.030180541070876643, 0.015974389207258355, 0.01635676781006623, 0.03999422326160129, 0.012542706699605333, 0.021080309561511967, 0.05468826486321632, 0.05714989449188579, 0.05454580961668398, 0.02829260458383942, 0.020297419832786545, 0.01064347194187576, 0.031872311228653416, 0.03516061173286289, 0.03826460728305392, 0.08278652137960307, 0.011235359761485597, 0.03926124110876117, 0.05360713381378446, 0.03702129099110607, 0.048877100125537254, 0.0706264613836538, 0.08589825010858476, 0.0316416777059203, 0.051768117846222594, 0.046452299575321376, 0.014207113872544141, 0.03843408412649296, 0.0291059353548917, 0.040643008760525845, 0.03590880420233589, 0.009995547334256116, 0.013498969547072193, 0.044594006321858615, 0.006253159135667374, 0.04083116917172447, 0.008732728329050587, 0.016534992719243746, 0.04596253034833353, 0.039116889674915, 0.037678043445339426, 0.04851039011555258, 0.04780833696713671, 0.03907856145815458, 0.015625362721038982, 0.06014812286593951, 0.01981850822630804, 0.03133085512672551, 0.04221999835863244, 0.04219317343086004, 0.025040654472832102, 0.034160827490268275, 0.028904657483508345, 0.062041037308517843, 0.025229768543795217, 0.05177438899409026, 0.016699621482985094, 0.03821149919531308, 0.020445517257030588, 0.03978658147389069, 0.029249607723613735, 0.03615870387875475, 0.04663573250581976, 0.05711807119951118, 0.04202517346129753, 0.012534406705526635, 0.05536217206099536, 0.04038763203425333, 0.02257264051877428, 0.028375175934343133, 0.06457250303355977, 0.031499738252023235, 0.027496307957335375, 0.04733174457214773, 0.04209294267639052, 0.0074050688090210315, 0.014894107916916255, 0.07158765394706279, 0.02740571213507792, 0.05111884624056984, 0.03062340842006961, 0.020403513553901576, 0.04188489641819615, 0.023404480452882126, 0.04416702649905346, 0.05910777283133939, 0.059632393313222565, 0.022145729344629217, 0.016944892013270874, 0.08935780861065723, 0.03432194404012989, 0.05396098982600961, 0.04975707575795241, 0.019083525985479355, 0.05463311215862632, 0.09410852595465258, 0.029490859524230473, 0.06054121251509059, 0.0846893286507111, 0.0214434646841255, 0.014967568477004534, 0.012492751811805647, 0.06058840939658694, 0.020311557746026665, 0.0532802140514832, 0.07539680111221969, 0.02014221448916942, 0.01576720012963051, 0.05685042677214369, 0.01801385369617492, 0.07484695132006891, 0.05128204451466445, 0.014530267235386418, 0.05312519795552362, 0.04694830655353144, 0.06215382891241461, 0.06351958843879402, 0.023346207017311826, 0.013129469061823329, 0.03995494880655315, 0.025617243845772464, 0.043463370311656035, 0.013701743773708586, 0.02636296867422061, 0.04660734164644964, 0.04573831640300341, 0.02223159397544805, 0.02860045300622005, 0.07959468523040414, 0.020069456186320167, 0.11051058332668617, 0.020386449723446276, 0.029204746751929633, 0.051005008208449, 0.006378762527674553, 0.05275591269310098, 0.06420105812139809, 0.035835713788401335, 0.042969500718754716, 0.09036487332195975, 0.08391268595005386, 0.046870555452187546, 0.037957740350975655, 0.051340692734811455, 0.026687545105232857, 0.02447822527756216, 0.18644676252733916, 0.23605069611221552, 0.1079708055476658, 0.12565003969939426, 0.10882107671932317, 0.11984640776063316, 0.11255960111157037, 0.06343585933791474, 0.1342667601420544, 0.14144800370559096, 0.12607957993168384, 0.20068721089046448, 0.08430754562141374, 0.11442381670349278, 0.13652557565364987, 0.14714708930114284, 0.10585868294583634, 0.0823208830843214, 0.13651240995386615, 0.13158025976736099, 0.2230595049331896, 0.1465973656740971, 0.16028672485845163, 0.11681105344905518, 0.29084331064950675, 0.14070431236177683, 0.22396284708520398, 0.17454712215112522, 0.11789869313361123, 0.12938936561113223, 0.11495310900500044, 0.12501967430580407, 0.16916799126192927, 0.16362630034564063, 0.1392788693192415, 0.10079176616272889, 0.06615002697799355, 0.11216149083338678, 0.14182580140186474, 0.1298761848011054, 0.1556419936241582, 0.1677608347381465, 0.1860238125664182, 0.1570713403634727, 0.0793631054693833, 0.10049311109469272, 0.10374606310506351, 0.14815562346484512, 0.12570464692544192, 0.15374932409031317, 0.09223684435710311, 0.15403364086523652, 0.1595805713441223, 0.0893041884410195, 0.14858762762742117, 0.08481072916765697, 0.15804736845893785, 0.1269586241687648, 0.13236390834208578, 0.14199101831763983, 0.14109183219261467, 0.14134741300949827, 0.06704947285470553, 0.14426050591282547, 0.08664200082421303, 0.10022277638199739, 0.0837027991656214, 0.08089464594377205, 0.08721634148969315, 0.15531144104897976, 0.18132309371139854, 0.10128145746421069, 0.17879913852084428, 0.14639759436249733, 0.21011756267398596, 0.1149436688865535, 0.12200377168483101, 0.09640805568778887, 0.1394269277807325, 0.1412552679539658, 0.1340492515009828, 0.08544901327695698, 0.11826575195300393, 0.08614640202722512, 0.12483692786190659, 0.21955132833682, 0.15882981475442648, 0.18516428681323305, 0.13257197686471045, 0.0998742415686138, 0.10350752199883573, 0.18632736580912024, 0.11019522993592545, 0.12870059319538996, 0.15357353899162263, 0.12009740210487507, 0.19626038905698806, 0.11295958902337588, 0.09023425533086993, 0.16608604491921142, 0.17696141760097817, 0.0902488904830534, 0.16585730016231537, 0.16693451267201453, 0.13707354781217873, 0.15732359635876492, 0.09485184622462839, 0.14253361732698977, 0.08754494963795878, 0.12890444631921127, 0.0905316932767164, 0.08496600872604176, 0.12877698987722397, 0.12502510682679713, 0.14836750662652776, 0.3171594219747931, 0.13751027203397825, 0.1445433680783026, 0.1795872993534431, 0.17021706153173, 0.2545549313072115, 0.08128808811306953, 0.12280310926144011, 0.09141611808445305, 0.11479773296741769, 0.18781626247800887, 0.13543018052587286, 0.11344311307766475, 0.18968769174534827, 0.14398712839465588, 0.14188625675160438, 0.08369561517611146, 0.16540494631044567, 0.14288158068666235, 0.14637006068369374, 0.12552334024803713, 0.08882263849955052, 0.10679335115128197, 0.14071513287490234, 0.15206050768028945, 0.19292116980068386, 0.11122282245196402, 0.12909011682495475, 0.10897217056481168, 0.07136287225876004, 0.2195824688533321, 0.25020912231411785, 0.07641274933121167, 0.133295570849441, 0.1304992029326968, 0.16839134856127203, 0.1366406085435301, 0.1658173429314047, 0.07278944336576387, 0.10277707799104974, 0.09999769783462398, 0.1108676973672118, 0.13347294414415956, 0.14829642372205853, 0.11962949283770286, 0.17530702200019732, 0.16031359060434625, 0.1671007092227228, 0.1538013931713067, 0.08967224915977567, 0.1674507060670294, 0.145638941321522, 0.18046263285214081, 0.15410939930006862, 0.1845415506977588, 0.22284613747615367, 0.09805526729905978, 0.12439776939572766, 0.08477348077576607, 0.1063271562452428, 0.12571269180625677], [0.06395583026460372, 0.12555408000480384, 0.02168851442547748, 0.07518551909015514, 0.03238017401599791, 0.01923561987496214, 0.03649497841252014, 0.04182183613011148, 0.09164338596747257, 0.06354445038596168, 0.045758911001030356, 0.01644744712393731, 0.04708718464826234, 0.019200685128453188, 0.042852571641560644, 0.020980826520826668, 0.012950731143064331, 0.021778664959128946, 0.031525858139502816, 0.049782457208493724, 0.026434663850523066, 0.062369118531933054, 0.06994940747972578, 0.05482052300067153, 0.05286403247737326, 0.042239331305609085, 0.026268886613252107, 0.05725631846871693, 0.01140454438427696, 0.02396974465227686, 0.02091379945341032, 0.008555485837860033, 0.049639838689472526, 0.017098843127314467, 0.004789709319084068, 0.039434796053683385, 0.011569677808438428, 0.0751276983646676, 0.014392133143701358, 0.029247689271869604, 0.032028047207859345, 0.03885945348883979, 0.020115782899665646, 0.0419946823240025, 0.04004840746347327, 0.02997967694682302, 0.012878719626314705, 0.032769163299235515, 0.05846982268849388, 0.04561874899081886, 0.014865453595120925, 0.03850501489068847, 0.020472091709962115, 0.016434062490588985, 0.02886902140744496, 0.0207475268325652, 0.04410919464135077, 0.02613132954138564, 0.05915229055972304, 0.10014161511207931, 0.05089469166705385, 0.022685749390802812, 0.039729298805468716, 0.021686319523723796, 0.0433760677697137, 0.05785491994174663, 0.010993146879627602, 0.0975114363245666, 0.011756986605178099, 0.033604242707951926, 0.01774751359334914, 0.017888467846205458, 0.03558266369509511, 0.0497175489726942, 0.07721501096966676, 0.018078522589348722, 0.018265866638103034, 0.06645476765697822, 0.11169924415298738, 0.04439884745806921, 0.022670561338600237, 0.03689466575451661, 0.03804126536124386, 0.020295618269301485, 0.016077937361842487, 0.03283420512161683, 0.04792008956428617, 0.09836859462666325, 0.026214375866402406, 0.03507313478621654, 0.04339565675763879, 0.13991671556141227, 0.026203217676084023, 0.04214033993775956, 0.01967689717275789, 0.03329246646899264, 0.022691905505780596, 0.030454885236395057, 0.04210575956676621, 0.06579030799912289, 0.019980665638286155, 0.017919096280820668, 0.014348938293551328, 0.11905358624062501, 0.09105076620471664, 0.011532554653967964, 0.029469229630194604, 0.025442575679335278, 0.050644747461774386, 0.03120335786661599, 0.05896462738746777, 0.020764163928106427, 0.02113343249220634, 0.0773440333432518, 0.025152362541120965, 0.03383903967915103, 0.006896051054354757, 0.052073615515837446, 0.05232771945884451, 0.04341508247307502, 0.038177798269316554, 0.01844018970587058, 0.024049573767115362, 0.031439052836503834, 0.020843057936872356, 0.046503340781782754, 0.07019427910563536, 0.04492446983931586, 0.03652646402770188, 0.04375227726995945, 0.03485578199615702, 0.04620203995727934, 0.031520303164143115, 0.02106791755068116, 0.026087030746566597, 0.03774263626837637, 0.06166889477754012, 0.03933191954274662, 0.0582545627548825, 0.04158529882261064, 0.0105691217322601, 0.00656876346511126, 0.007348861327045597, 0.039733373196213506, 0.08914527978049591, 0.028191303281346336, 0.03539268873282708, 0.022654794411209878, 0.007523837484768592, 0.010235572735837195, 0.04636047735402826, 0.01639000118302647, 0.01932600418513175, 0.044402947823982686, 0.04923580236209091, 0.01631984781852225, 0.07036994546069764, 0.028512770113593433, 0.05690546073310543, 0.020037942740600556, 0.024948177306214347, 0.010591336067591328, 0.039326832120423205, 0.02205769022111781, 0.0686249855789356, 0.03425450137001462, 0.026432723134348635, 0.02813846236676909, 0.005626666361422394, 0.02591055916127516, 0.06563772243680432, 0.07411382073769346, 0.05396685279265512, 0.0663193034415599, 0.019090754503849894, 0.03537015712936409, 0.06585170587641187, 0.039350588267552666, 0.011973458094871603, 0.017350215966871474, 0.03267535212216899, 0.02325898240087554, 0.040503336567780934, 0.01790417911252007, 0.1145283853111323, 0.03357518762641121, 0.06551166123244911, 0.04643826927349437, 0.01820657831558492, 0.05644457218295429, 0.037340689086704515, 0.018260298675158992, 0.03968370125221554, 0.027026303978345823, 0.04344141387264244, 0.03527308792399708, 0.03571581983123906, 0.04280927103536669, 0.008296948490169598, 0.029684420915145893, 0.03246083433623426, 0.032639439596096054, 0.047634874790674075, 0.08571280224714428, 0.04386777029139921, 0.033441229970776476, 0.05083467789518181, 0.040836583139025606, 0.05925128934904933, 0.04660950129618868, 0.027142403705511242, 0.01289199108214234, 0.039459183026337996, 0.030346967687364668, 0.005890619067940861, 0.058013591115013696, 0.0659002349129878, 0.012344806527835317, 0.02727660998061765, 0.028324949234956875, 0.009200420518027386, 0.09865982821793295, 0.01859674019215163, 0.029111735238984693, 0.03346274854266085, 0.061544700074591674, 0.015285869121726137, 0.009687328765721759, 0.10806187448906712, 0.040898240768001415, 0.005698665354429977, 0.01789633090083953, 0.05863827907887753, 0.06966599612496793, 0.02923338808614062, 0.1029047644988168, 0.013165794407541398, 0.011126167573820567, 0.08637638617074117, 0.012359085449134, 0.03165072819683701, 0.049482239919598214, 0.025567599732312374, 0.01669728557317285, 0.025772477019927464, 0.08044023634283803, 0.03970571335230488, 0.01430884562068968, 0.09657210001023486, 0.0594228404952446, 0.05735712438763585, 0.03435135164181702, 0.020956346779712476, 0.02967646694742143, 0.054190339433262125, 0.014528282918035984, 0.02043398799287388, 0.04127856547711417, 0.033875620138132945, 0.01929485810251208, 0.05135620362125337, 0.04382523780805059, 0.05865598672244232, 0.028417582252586726, 0.04054156830534339, 0.04898602142930031, 0.034191741651738994, 0.04039858242322225, 0.0382895100483438, 0.05921079035033472, 0.026239837097818963, 0.045055688970023766, 0.027929746320296545, 0.08420955986366607, 0.011992788258794462, 0.007381405894193449, 0.03283531463239342, 0.015968145889928564, 0.018656338361324742, 0.10878276705625467, 0.09741516492795199, 0.04017690291220788, 0.024717465857975185, 0.07279529891093262, 0.01173041493530036, 0.05486332636792213, 0.08005785959539935, 0.025430350651731715, 0.024347557191504166, 0.029320746289158706, 0.021944787295069546, 0.048208042862825096, 0.03193157914211042, 0.02637407491420163, 0.016462740932183806, 0.043922915574512444, 0.02142738419934176, 0.042637092774384655, 0.013023343799432041, 0.018554725356807467, 0.019755950743274298, 0.040971282942336984, 0.09564138003042899, 0.05959392408840358, 0.03175167512381449, 0.02861914585082559, 0.04636738674889784, 0.049681814562063664, 0.041239461716031656, 0.05249059489869978, 0.009622454854252283, 0.03129784810880665, 0.012611069632839644, 0.06284090180997737, 0.013324945193744497, 0.00800367584815831, 0.036748024795087986, 0.03361820250574965, 0.08025720046134666, 0.06803172756917775, 0.05637452457449399, 0.02741331914876355, 0.04902715125354007, 0.04219925533107016, 0.025526692552375607, 0.01284935377043439, 0.022875523973198142, 0.004431242714417749, 0.024239706435764674, 0.06477421877207235, 0.04920426108583342, 0.05122465794556774, 0.029808674989908468, 0.032700217780075036, 0.04648807480407413, 0.028592450798896607, 0.02379675930569647, 0.027011880338250194, 0.04958474906743504, 0.05356155110348482, 0.04951857546984684, 0.07098320435034111, 0.04007047893537674, 0.036862222768832, 0.029969650531711522, 0.02690104429348139, 0.01138512794568669, 0.03371967264683917, 0.015240500706568127, 0.02027807760896394, 0.021850074408575892, 0.015459132773685269, 0.20617144473362714, 0.2639206568710506, 0.08896742408978753, 0.14904450858011842, 0.15511294623138383, 0.15262029482983053, 0.10208717751083896, 0.09843802254181355, 0.2281152969226241, 0.10970076662488282, 0.17894547519972548, 0.1261352706933394, 0.07448934004059993, 0.13848306436557323, 0.11334073380567133, 0.05670780454238411, 0.14985968358814716, 0.14457358833169565, 0.1481884263921529, 0.19785018812399358, 0.1582438001059927, 0.2976633212529123, 0.15326609689509496, 0.1427461684215814, 0.11111149287899025, 0.12097968210582621, 0.10848225661902688, 0.13551202457165346, 0.12561870622448623, 0.14628903300035745, 0.11918229691218585, 0.09048746869666502, 0.15129294886719435, 0.10917045015958138, 0.13048553257249296, 0.10620172586641274, 0.11884473846293986, 0.19696679490152746, 0.16796722600702196, 0.09907029525493272, 0.11173338294611312, 0.13991632964462042, 0.10536948146182112, 0.18144428642699495, 0.089145658275811, 0.1732076791813597, 0.12704895838396624, 0.11881919373990968, 0.16827008163090795, 0.2416762794018723, 0.08910197546356358, 0.09257200566935353, 0.15962529316311702, 0.13236512546427548, 0.12572195380926132, 0.06849441953818314, 0.14533060864778236, 0.1508869940880686, 0.12056706284056418, 0.2763665624661371, 0.1632800290826708, 0.07848432098398916, 0.15742230199975893, 0.0978114124154672, 0.19127162784570828, 0.12964312074473128, 0.14395488949958235, 0.1674757312866859, 0.10818324532010593, 0.28830780764110386, 0.08784761972492561, 0.16482277598697692, 0.2849229908315465, 0.1567418416379951, 0.20079638081369922, 0.1805175220943056, 0.081928836152656, 0.1169975774246268, 0.21598116756649688, 0.12125282213673927, 0.11729905265383422, 0.13086626917356625, 0.1501528764492832, 0.08749039436224848, 0.17163030366646126, 0.1240025089646224, 0.1863035131827928, 0.14015362394275144, 0.08059166415478103, 0.14207982370862737, 0.12539901566924527, 0.18107250012690201, 0.16522240766789764, 0.16905076161492616, 0.22848358028568327, 0.07401987968478352, 0.11612683039857075, 0.15571565920254216, 0.12334590122918598, 0.12816571252187714, 0.07352313798037358, 0.06498094400740229, 0.09903041966026649, 0.24297914933413267, 0.2335597071214579, 0.1977191842161119, 0.09806813613977283, 0.08858857996528968, 0.18349625053815544, 0.12800134165445343, 0.1809507136931643, 0.08980980623164214, 0.15601713443174958, 0.158709260285832, 0.11560555329197086, 0.13956882641650736, 0.11526317830430344, 0.15528828604146838, 0.10035626648459584, 0.22715164785040542, 0.09958401729818434, 0.1970158953918144, 0.10471184214111418, 0.07681364266318269, 0.05624769153655507, 0.1869236072525382, 0.2374219030025415, 0.16553819150431082, 0.16206902218982577, 0.13932440750068054, 0.14675953978439793, 0.2250039021600969, 0.1404205447761342, 0.16883783944649622, 0.15490416524698958, 0.1320844897418283, 0.18014576548011974, 0.17028869362547994, 0.12740581267280504, 0.10825677731190808, 0.14718192571308464, 0.13093874731566757, 0.208174902072642, 0.1426468839053996, 0.17653584043728188, 0.11103642464149743, 0.20923301170114428, 0.10008985773310997, 0.09795953024877235, 0.1610043371329084, 0.08523664771928452, 0.0944906058430206, 0.17155594046926126, 0.1544395659584552, 0.17438264738302678, 0.12453796109184623, 0.22765060857636854, 0.08271175000118092, 0.14627160737290978, 0.1366050002980046, 0.12528530380222946, 0.09445352072361857, 0.12652041565161198, 0.07149211727664806, 0.12634363607503474, 0.14644929236965254, 0.11049110937165096, 0.06519269358250313, 0.08314178005093709, 0.13529556978028268, 0.22551804722752422, 0.10182187455939129, 0.13837548263836652, 0.11908917964319699, 0.13101193791953847, 0.17918959725648165]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0194381575420266, 0.004910799525532639, 0.1132839966157917, 0.0574551361205522, 0.043047652579844, 0.03366493183420971, 0.10525890887947753, 0.015903139319561888, 0.02610124101920519, 0.06208700593560934, 0.048705827284720726, 0.03807643945037853, 0.01737384038278833, 0.03885285208525602, 0.019575616279325914, 0.007983217619766947, 0.04615192643541377, 0.05088717371108942, 0.05811798160721082, 0.04632939992006868, 0.04005455986771267, 0.06707693974021822, 0.019140385629725643, 0.0372700922889635, 0.0757321628043428, 0.054872057735337876, 0.039501596766058356, 0.02862091216229601, 0.03696152212796733, 0.07088194572133943, 0.07486867398256436, 0.0721611782500986, 0.009462787347729318, 0.005755544480052777, 0.013479824920068495, 0.034830218719434924, 0.0473338745359797, 0.04393003648146987, 0.020512852315732744, 0.015626947206328623, 0.02796438791847322, 0.08243318487075157, 0.02729363855905831, 0.027548282414500136, 0.05508001122507267, 0.028405646662577055, 0.02547698164562462, 0.030059578421059996, 0.0319169773865724, 0.004308434436097741, 0.002125393593814806, 0.06996742682531476, 0.09022226222441532, 0.03434110629314091, 0.027876731001015287, 0.04114014751394279, 0.04536631859082263, 0.009850986243691295, 0.027188687745365314, 0.03234751209674869, 0.037004529585829005, 0.044128642621217296, 0.049038439319701865, 0.07314154048799537, 0.0467588882020209, 0.09222803506418131, 0.03573844049242325, 0.020848267813562416, 0.03989633398305159, 0.010666254020179622, 0.052004243261762895, 0.027948442875640467, 0.04616711077687796, 0.03110300465777982, 0.023263338807737455, 0.056005217047641054, 0.03695988569234032, 0.02450158994179219, 0.018192972893302795, 0.019156848320562858, 0.04960363301506732, 0.03134125632641371, 0.029481499186658766, 0.03343843207403552, 0.08312882215250283, 0.05167005416296888, 0.06103147898102179, 0.039644456483074464, 0.020355466913315468, 0.0222535374268773, 0.055935956115718, 0.0664269742264878, 0.01015125362755498, 0.026419655769132078, 0.027228327708144207, 0.05050687126640696, 0.03278066658822354, 0.029299203597474843, 0.028960593153897207, 0.02904146684159059, 0.017398268173565157, 0.02696622526855208, 0.03302670709672384, 0.02647758967214031, 0.010293080831615953, 0.04688494940637611, 0.02815860239934409, 0.0720433474634774, 0.04540150010143407, 0.07569062479888089, 0.016166432906175032, 0.008563582669012249, 0.034852356984629296, 0.03861253724608105, 0.021831097692484036, 0.005551883386942791, 0.00998013385469676, 0.0347816674184287, 0.029292409235495143, 0.022267435997491702, 0.02740479372732807, 0.018768552945402917, 0.04139622556976974, 0.017997348331846297, 0.01959189714398235, 0.028399941402312834, 0.05890719257877208, 0.047198406609822996, 0.033540091462782584, 0.010393663178547285, 0.0424383827339625, 0.025836318418441806, 0.03723399051523302, 0.09552028379403055, 0.05643168478854932, 0.12178810356999747, 0.05296584029565565, 0.050177383673144504, 0.09381899930303916, 0.031580183349433355, 0.05080228685983457, 0.01324637401921791, 0.04385656015074346, 0.018655766907613724, 0.05138431617524475, 0.030758093380427454, 0.02653869440109702, 0.08699989411979914, 0.020351882340037264, 0.03478207559965085, 0.01003886092803441, 0.040327993046958, 0.013325520358193899, 0.03166757494909689, 0.02929103069618577, 0.010703384596126853, 0.021725998449255712, 0.02183227214118233, 0.01789355341315968, 0.039755151519784704, 0.05132290345500223, 0.008653576423967024, 0.03402749323868193, 0.030883855870342813, 0.009155103125522146, 0.01677007912803674, 0.005110237334520207, 0.04556496554869227, 0.051856975187547505, 0.03174571567797102, 0.017204845935339108, 0.045301944701350294, 0.04231383922160603, 0.011319912646285957, 0.034872072137659416, 0.046507381775882095, 0.030666595848742872, 0.06457538256654516, 0.048909027318586595, 0.014546113015967421, 0.06890575488796458, 0.02854324455256574, 0.04959674959536642, 0.031711131596239284, 0.11663468205370009, 0.0010579115678410744, 0.04054990262375213, 0.02535546424041968, 0.069144021399552, 0.037337408793973736, 0.0628398553817533, 0.02745269379374804, 0.008440914934908506, 0.044998617813689634, 0.02115758012223523, 0.027442993923614267, 0.008590607048972743, 0.05985137882817071, 0.05689034689567052, 0.03814334406342823, 0.07348928862484172, 0.07733620368526317, 0.022056844172766432, 0.004317130087656551, 0.07802113177604042, 0.027002314054698218, 0.07064510413329117, 0.0792294298298657, 0.01629611950193066, 0.03957932931371033, 0.04378544384962879, 0.02595681722596055, 0.02845714243449038, 0.04598283921950497, 0.019364386207598727, 0.015005703735369025, 0.03827032553090248, 0.06440500772441737, 0.03424655667913612, 0.02411157463939162, 0.05571928239078261, 0.02215951659309212, 0.017546517738082912, 0.028921906850882806, 0.013301763283379842, 0.06218689159140922, 0.052382371213752776, 0.0347864468494663, 0.01333699117822107, 0.06237345267436467, 0.012088702496839687, 0.009829451901168795, 0.03769357288547326, 0.05987544667732436, 0.019612458345363848, 0.06788366168620996, 0.05236206605331972, 0.12556596921058372, 0.0924179283902049, 0.033850580075522885, 0.03645715114544146, 0.022519536141771823, 0.02059339574771002, 0.07296915442566387, 0.059694603842217475, 0.025088250258704647, 0.0727153844491113, 0.05408077246102039, 0.029322284390218556, 0.027833037056552712, 0.009936718215612927, 0.04515846900176257, 0.05216871060838457, 0.02925314591266215, 0.019018294915440492, 0.005065938539701165, 0.044684481545118615, 0.0193456247143331, 0.029559213180618826, 0.045416647335514426, 0.0639341669739224, 0.07782893779221922, 0.046608621851191856, 0.062181744797271676, 0.03401839450816624, 0.07702076123678125, 0.023589364282088354, 0.03240067955630366, 0.12131548166507855, 0.06410563277313486, 0.0435544726497028, 0.06316445593256503, 0.01242885196916177, 0.02775641216430813, 0.04169973799434956, 0.03368895886524115, 0.03573412119294517, 0.026856118383875582, 0.04767335885844659, 0.03832532609521877, 0.027404407810536213, 0.02845832430466544, 0.05451667289889883, 0.05331679079972673, 0.11971224972512573, 0.09278293888201006, 0.05212899828620721, 0.03493614916806109, 0.06014517282892484, 0.04143750382354483, 0.02416109258774668, 0.07862338461563922, 0.04747524253616575, 0.011085354090027977, 0.05668454192345962, 0.06398731216904707, 0.05164068737940397, 0.024189561372622848, 0.0326072489406215, 0.02399711505859159, 0.03301677345007192, 0.04983325721696019, 0.041210955823771656, 0.01782312730938429, 0.030828224480501376, 0.03435290273046121, 0.05210825525864493, 0.04287423493224196, 0.040963308565551415, 0.04812281462363899, 0.045012733462499455, 0.10401518069556914, 0.06633312965277582, 0.01132455756305717, 0.03235376098018605, 0.030958929673943203, 0.0425939257547725, 0.016159100487129763, 0.037582425138680264, 0.031266091609722935, 0.06273124206927605, 0.059897128521697596, 0.024951411214715336, 0.05874902977666352, 0.02620195045892615, 0.029455221592797898, 0.04377941389975604, 0.03396203581360169, 0.02932515835709637, 0.01147730547018, 0.04819596440938767, 0.04428404092323035, 0.10923500216449611, 0.020561719029501546, 0.021491711704584304, 0.009294258597947191, 0.01432586956070736, 0.028957568902114872, 0.021590389515040442, 0.06964784319279715, 0.018455765530234203, 0.035397902320255525, 0.02525961030187318, 0.00980942597379908, 0.033024773802026175, 0.007537718429375673, 0.06229226171853952, 0.052533632042468525, 0.07907438775873743, 0.03278017677075695, 0.03548508982930798, 0.04751093983941246, 0.14013045409228653, 0.13569221802754328, 0.17577968101250008, 0.20328615268226713, 0.14804980804910883, 0.12427494395524263, 0.25364235683809966, 0.10020856425398961, 0.15788998862262815, 0.11174829269293696, 0.19433546578511596, 0.14321535418275744, 0.1629550426150672, 0.14411446609301493, 0.15517447027377784, 0.08922552078729495, 0.10491283057490364, 0.1558108173776418, 0.12087062350474298, 0.1128052148851566, 0.1350373320747167, 0.14549613726558164, 0.08665452827699482, 0.12154527285019867, 0.18117390718543902, 0.18158913881052285, 0.1002858292486053, 0.1343682562583126, 0.19281805580249056, 0.13097845221636817, 0.1391435312689282, 0.3187418886227533, 0.09662840675446205, 0.08934554090956226, 0.15059630968607962, 0.0958741843351163, 0.20202139945467934, 0.1465399976586923, 0.1149507489753887, 0.14635094295954332, 0.0986744930560235, 0.13179517089156434, 0.18647209944901988, 0.09543762338580564, 0.2675539150368422, 0.09249638824258, 0.12381576976622455, 0.13844877714291215, 0.08938097846112214, 0.181611284497194, 0.14579621725715697, 0.12740738602587953, 0.17961593141080812, 0.1998042777995579, 0.10975897326716222, 0.1033699352410622, 0.20607440150342882, 0.11906078507308848, 0.05737041254178621, 0.12082698522135615, 0.1531691278796643, 0.17233405262231827, 0.1715829101158306, 0.21944493404589593, 0.16322399693308398, 0.17826857714680955, 0.12572891515446827, 0.2569769450929016, 0.24905051104724407, 0.07481299806386232, 0.1461971551179886, 0.14605791337089613, 0.11458233944722451, 0.10876206113607623, 0.09370547297294252, 0.09886529922368936, 0.0945516474894248, 0.12882015318609774, 0.08365868590772152, 0.08212542365072295, 0.09668336278991774, 0.21657607314409688, 0.08217850947403349, 0.15348066663136706, 0.18117007770342752, 0.15167988982284442, 0.11786481409217231, 0.1131671380426269, 0.20883918361505494, 0.13488033815519884, 0.15519449341809377, 0.17723452794598415, 0.13658076175488532, 0.15851910720812157, 0.16830447275424376, 0.14085088652791455, 0.12719850114081055, 0.14370822929777205, 0.08005315437912941, 0.14070837933104485, 0.09100888681132346, 0.1449952766415663, 0.14460383827099577, 0.10165613814024255, 0.14445380569668487, 0.0887427685665898, 0.13807032635668293, 0.18384982453426346, 0.2981935709249228, 0.20693201251560822, 0.14976885955547914, 0.28136599576100707, 0.21133054367965087, 0.14561948220944032, 0.17752864107023925, 0.13238234329037368, 0.05462416556838434, 0.12215275040944107, 0.113038397685159, 0.11468728655017912, 0.1691524506895803, 0.07439047854859382, 0.11453380298917182, 0.14598469308111817, 0.14023520081536844, 0.17111152759753168, 0.1945356378564611, 0.15279677754733711, 0.13989011698868126, 0.14235339418519288, 0.08308631935506128, 0.15437001187819988, 0.23047614289680496, 0.2551798493368551, 0.1221044514386449, 0.4944910079939291, 0.14922933303751051, 0.113478157290956, 0.20536688243737444, 0.16937012260314077, 0.25897504412569106, 0.10741042467998341, 0.12616117164725438, 0.18859688309021294, 0.18164151959354058, 0.15295458782929927, 0.14409833180252463, 0.12242752316524275, 0.059402947226772085, 0.14571395760867745, 0.18597630027215928, 0.13136999448761344, 0.10240857198368758, 0.09411670442204922, 0.07232220203150064, 0.1558462029788643, 0.2001411683158949, 0.10961710431729443, 0.12310264748521149, 0.20661379443481565, 0.1423365919617936, 0.08180778444511816, 0.08848039709846489, 0.11317145734210499, 0.15144684060942382, 0.15196659631328657, 0.06586271934793331, 0.14198950433637947, 0.12048029093421064, 0.12721931096166372, 0.1972666967776604, 0.13904994644690305, 0.15518901636824012, 0.09522666048724204, 0.10031074314611033, 0.11017313619959168], [0.048789229840622284, 0.001258177219369827, 0.08859152629156597, 0.02298947518283967, 0.06182153971167281, 0.040105371008394286, 0.05016072987928055, 0.03321664495160803, 0.024050447646004613, 0.040088442619889975, 0.024280088546220213, 0.0455720641912194, 0.05174408339371439, 0.01975479484826792, 0.07371105719357729, 0.06588955540792085, 0.06189676380017772, 0.057941717823268846, 0.036149872321402654, 0.01959167821041774, 0.06448478117818013, 0.04148714979237411, 0.03578278010536451, 0.06006613781210035, 0.045079166811774485, 0.05326642123691272, 0.06846774675068446, 0.017675636590865906, 0.055372640053974465, 0.06895496670040302, 0.032143469725269824, 0.01996861130464822, 0.06472450972069055, 0.01053282978318748, 0.03391706908587366, 0.07590683468151838, 0.05768690512923058, 0.04701171565102413, 0.05224138170888182, 0.03129368466034066, 0.03906452744558919, 0.0059837901426362805, 0.03776691562961787, 0.027690835995599627, 0.02630421284266049, 0.027655750964186154, 0.0031554486486129463, 0.03259918921685312, 0.014015252927492838, 0.05813477640913334, 0.050226788443978876, 0.022403792645491194, 0.010237095066258917, 0.07686240918701515, 0.024001046585908625, 0.0482629951875424, 0.02720866265008226, 0.03710711665917188, 0.04770436207763851, 0.0828762173478026, 0.03196775141987018, 0.08072753655142151, 0.047218362960848026, 0.03215973389160354, 0.04292722798709292, 0.00852767107062391, 0.05546236199734267, 0.030653689900645986, 0.044984721098444425, 0.009552915616950486, 0.020653997671615798, 0.03859581294818781, 0.038267368072411045, 0.06489145584055223, 0.03947438963223249, 0.034817479754565284, 0.02741831380262738, 0.05986182084598113, 0.04550030222162604, 0.020436320191947743, 0.06856471576611511, 0.016006587284209672, 0.02060383962088963, 0.04381191625725478, 0.0649071745283436, 0.06412607152014971, 0.06606853174162097, 0.04615797493897844, 0.03861290460918099, 0.036062439903616905, 0.029709455411648378, 0.03898434581060428, 0.00631725193670718, 0.04771384301420767, 0.051484621144481935, 0.04934118733217474, 0.009748750762810232, 0.03925432058167644, 0.03477589722024277, 0.04780841860338114, 0.05001212964998558, 0.046649384312331676, 0.040641413143021055, 0.05529956819373183, 0.04081140206835698, 0.07399144800729118, 0.07194349891506135, 0.027024576629628427, 0.00838360350826406, 0.02567300140071893, 0.0735407491447404, 0.01463310292820097, 0.10358880201238208, 0.008292921411339194, 0.025654631390352733, 0.006049902976883459, 0.0248761704278877, 0.039584142141393386, 0.027343841138645075, 0.02555615395976929, 0.041779106977628544, 0.03403559006983414, 0.026949072380375583, 0.014102635250310414, 0.028249138849787414, 0.029571351005870383, 0.03243047678552102, 0.059799825539812446, 0.039572527530253865, 0.021401446138042957, 0.0383750499895541, 0.03203572101483587, 0.018540401906648185, 0.03719889806234278, 0.01463177262849058, 0.04076167075254489, 0.012246934875292936, 0.04030778807646129, 0.03400042711291462, 0.014190178062563064, 0.03224697335099336, 0.044354255514917895, 0.06178083291160874, 0.03975554114731494, 0.056797400320647284, 0.05228505338891409, 0.03810662259638775, 0.009573852530593285, 0.029719860322074965, 0.05306213766743895, 0.09324629878392443, 0.041633709115558304, 0.012201356803416274, 0.0495799993223045, 0.09047456274856813, 0.04836301442992408, 0.06569289369508624, 0.09308215798228048, 0.10093295975821093, 0.025407216053281445, 0.018571464497654233, 0.08028722033486702, 0.07106722288881429, 0.0185206348032807, 0.11168374810949899, 0.029622397778439336, 0.03650613289210014, 0.016214876595768146, 0.02651520542713115, 0.04251266429491807, 0.0735299063671846, 0.04056481608131435, 0.05809039968880825, 0.023281115099962335, 0.024931169136834797, 0.03084415653574979, 0.05861106081283651, 0.06993485396378674, 0.05989452729409095, 0.034553126752143726, 0.030362745746970177, 0.057822517774184234, 0.04749265332065988, 0.0472422935126815, 0.06288278120337054, 0.1136184974166099, 0.03596138165448792, 0.11076610477175564, 0.0640197069151327, 0.01493236841270118, 0.030043950646359008, 0.05088189704110846, 0.04464877682039514, 0.07053385619656183, 0.04111487738555297, 0.05822164108394645, 0.05069879436632618, 0.031192771130008623, 0.04746188016724773, 0.03846404833893757, 0.03551235633494798, 0.02690355831873603, 0.03211050352547318, 0.04065723202074878, 0.04228852085361723, 0.03385480660654139, 0.012640732347790617, 0.019697935204021633, 0.010273182924720459, 0.056560369484941475, 0.07929844956379384, 0.029263714095577598, 0.048997814155882224, 0.03689610923174769, 0.018831958332157228, 0.03610112064052373, 0.02994498525367817, 0.04133596317842603, 0.03988574353570584, 0.06551233658683486, 0.04304477304685861, 0.030353444781212602, 0.029289522281032987, 0.05866583873284981, 0.01026074452965986, 0.025482518067292403, 0.018112301440851297, 0.0493760979588842, 0.04557817577733658, 0.046656464401166886, 0.05447111245302949, 0.03474842662399169, 0.06500308227259666, 0.0440968601469649, 0.09582780752680264, 0.10770770677481778, 0.015743683325126767, 0.03880231553921476, 0.06850806763395667, 0.03085163923969958, 0.028284936342970468, 0.009315531333413674, 0.012971593841939466, 0.038185969315236434, 0.03835301562503446, 0.03360946000611875, 0.033298667112831026, 0.028260822109587025, 0.0247137662518071, 0.06336568185361102, 0.026502132495807018, 0.03909557519364171, 0.10240118019282818, 0.028513308170659002, 0.011459636789368233, 0.0403540869592689, 0.05222263134783134, 0.10844209158676676, 0.014211991638148902, 0.035997245940961875, 0.09148392811766826, 0.03830512854619883, 0.02501766459317878, 0.02174075420043664, 0.02430917702440638, 0.050672069628490135, 0.01970882436580723, 0.022050847619539127, 0.031817800481803715, 0.020741383705171756, 0.03842263649858069, 0.050732569507090375, 0.06524551965412684, 0.03118222150078509, 0.07762364490190521, 0.08686549117555842, 0.0444395728118252, 0.03524566927808337, 0.04125690218643285, 0.02135022125003161, 0.022424160888476763, 0.06542220275150612, 0.03676116080896463, 0.017130284213635605, 0.059177965158596635, 0.03943371993955225, 0.025442045043746475, 0.024453773366985843, 0.04197255148028489, 0.034770739293890074, 0.03577457937353756, 0.024880890487111174, 0.05707354976038914, 0.15055661962833256, 0.02835298015270382, 0.03447685252467636, 0.05011405250115786, 0.028579557838384062, 0.03653255334938876, 0.0571855027374113, 0.012913012415083358, 0.018213192706753034, 0.04472980821446981, 0.02202081846917281, 0.017344685111311264, 0.07061972268274985, 0.018904115495388396, 0.026284247214789502, 0.021852371355635114, 0.08086458154139109, 0.026903688194579445, 0.030009151341801044, 0.06011367979226634, 0.08024902199395001, 0.0317768376407912, 0.022043813914933708, 0.0246189531753771, 0.07512778000091203, 0.06559738671057858, 0.024177015366149135, 0.026457338317413814, 0.00781370181357488, 0.013076247796561802, 0.031027409495436586, 0.029974244425829966, 0.030291855800896883, 0.06097040393797215, 0.06243560754228383, 0.033583265903871506, 0.023365426786767785, 0.07679012400330976, 0.03392012673430145, 0.027406415320001543, 0.013401775104284752, 0.03683538670884445, 0.026764496542455163, 0.06554784835316241, 0.1205265564203728, 0.08137969140079804, 0.04284028909751214, 0.08323497895617038, 0.030137385183479637, 0.06507255471660756, 0.06650734139839187, 0.051102110810461454, 0.03574442591343541, 0.046415448232437484, 0.06329562311293557, 0.11218546962481923, 0.028042298581567593, 0.010645783731888514, 0.03803633378993254, 0.1640310083166696, 0.1805396974668838, 0.16008325765142217, 0.1943678382667713, 0.11022666731150821, 0.1920867880107835, 0.1505786762572825, 0.11375189104001038, 0.139044068637304, 0.3128939133603126, 0.10365186972194351, 0.17937373893801123, 0.18028337450232357, 0.12872591527411714, 0.1503669415251352, 0.1689707877812907, 0.13528397743357345, 0.19955424824729562, 0.17744427372235805, 0.1494009027373977, 0.20112173835514113, 0.11097245151177049, 0.13312775641679764, 0.10222359909676015, 0.1454240153543651, 0.10922838220722042, 0.13073188107227907, 0.15493141690967605, 0.1582695823162794, 0.13312741502886638, 0.15038383280625567, 0.1231058980920352, 0.15954022819641978, 0.15516505984123796, 0.19784855539910495, 0.12412290016072802, 0.16684806731063873, 0.12425210807123221, 0.1484921874362044, 0.1370043499628082, 0.09551974944770336, 0.13640708435559645, 0.07698247383814305, 0.15436354035045952, 0.21273157006362453, 0.10002605529734865, 0.06969162990571931, 0.12135693803429604, 0.06638303908403032, 0.10624503760482185, 0.09904522550641559, 0.18431748147122562, 0.09267297486076131, 0.16972197481663898, 0.11116646375739947, 0.12614312261575833, 0.10276005312334746, 0.1467762974789366, 0.26325456448830664, 0.2836900163674727, 0.17226629453944042, 0.14097199018578976, 0.1583580017904751, 0.11143472045660019, 0.11349835855071433, 0.06763356534065679, 0.19547120406059548, 0.16097209823783487, 0.18969204073073342, 0.08537697300198488, 0.14546211721608415, 0.099628486786969, 0.14551201922586188, 0.1172838089405559, 0.13031458627665415, 0.08311334837344475, 0.1826423651073128, 0.15007005276856944, 0.08690094357007183, 0.12042670787195675, 0.13226175913587213, 0.27593166392762214, 0.07068926934152842, 0.10984034975990653, 0.2315885035204701, 0.2697083103703335, 0.2189265438937582, 0.09357178249047138, 0.09068470928468741, 0.10706686225603335, 0.07732966536423191, 0.17464826203649864, 0.18072351260343567, 0.14583804470021278, 0.19227266631787643, 0.10393806413048878, 0.19430244021350518, 0.1129415251489263, 0.1617888020700775, 0.14172115857945755, 0.09604025472071953, 0.09630149070289917, 0.17919415404321626, 0.12353290760074742, 0.19622265826910734, 0.1679451990639791, 0.15546485781669617, 0.1121273817261681, 0.08003597366041504, 0.18404419301077724, 0.2391932313912548, 0.17820237757405266, 0.18027326645096764, 0.11995186694548465, 0.1554371608654037, 0.05818847079353873, 0.12094162477296777, 0.23245694988872856, 0.11713995845639147, 0.10279876354616135, 0.1477840746520087, 0.09847052118857391, 0.09429853060282767, 0.23492827196605504, 0.07958219488500617, 0.11797889703302644, 0.1516471165814437, 0.09489448260865174, 0.1169576721440535, 0.11957234004512429, 0.1102057758544106, 0.23243953910423443, 0.10712992996559478, 0.10081417902256362, 0.10682339328923263, 0.175475652795285, 0.16519662545761093, 0.12375379301374778, 0.12666359078139067, 0.07297604155610316, 0.14798785356106237, 0.20170543750282377, 0.1494298316538334, 0.15517838881351054, 0.10792108907480724, 0.0891913597297389, 0.11169875433552079, 0.08287528966320679, 0.1385624593240209, 0.12825567566324025, 0.309426985331811, 0.1543986884644255, 0.08908628646167926, 0.10194409143878147, 0.2511098521063104, 0.1145333651220426, 0.12065438393619843, 0.14682254812214524, 0.1551348395878449, 0.1276278929435648, 0.14336614374769852, 0.303364351275377, 0.19627560308435932, 0.08881121684680693, 0.20859938085777685, 0.12016096705337986, 0.14437754260143265, 0.15849569987040013, 0.1134908628591802, 0.0960474090243224, 0.155468390439637, 0.1429233784438111, 0.2728047879645601, 0.17275516205700114, 0.121504744165577, 0.13201435678638518], [0.03348244143126067, 0.03960020963859279, 0.019340043763804715, 0.02895342586270999, 0.038847890828037634, 0.07702089482336305, 0.06645067100180313, 0.0330368522554636, 0.016787408276286442, 0.07216564597911201, 0.05129647928697523, 0.035357310553081334, 0.0705558608751744, 0.03816335607552901, 0.021587639857898466, 0.030331963316712063, 0.05607895684079267, 0.10349162519560196, 0.05391902508563362, 0.03356127235747408, 0.02665328200237127, 0.044122835315647535, 0.015705651967437007, 0.012313629831623985, 0.06515114815556444, 0.03723758250998799, 0.028325257226242684, 0.03185643668984994, 0.07673125684959814, 0.045998008718015626, 0.048873304040171206, 0.10345057700760663, 0.05266704421956092, 0.020790200323972385, 0.030745037147426046, 0.029940825515950564, 0.02102828129864065, 0.034718492097454146, 0.04514492851740215, 0.024437592692265753, 0.03422970992687624, 0.045403459371300414, 0.050334281113464385, 0.03645831631729379, 0.032492620521225035, 0.032653451344231144, 0.015345883821282769, 0.03154795558657497, 0.08187348677893169, 0.042655524011934176, 0.03636516565165948, 0.036033566648256965, 0.02087729320919607, 0.025109618545684498, 0.04155547561822459, 0.029679661893169396, 0.056903520016931, 0.025113221672654618, 0.025727948159328662, 0.08016447653062642, 0.03526467196934391, 0.02658585046447115, 0.03163412635331042, 0.053367056461866014, 0.08604673901572824, 0.01779739704943495, 0.023181457654573023, 0.035225019018980674, 0.019590373885876033, 0.049360527700628154, 0.028001721657346934, 0.021907384907535743, 0.011676790127239656, 0.013592078466899693, 0.0909419302479364, 0.08629175907117315, 0.023112536255212035, 0.024792291042103898, 0.06819630623795092, 0.02915313780249562, 0.0312060778378509, 0.033742801679181866, 0.04459304895135574, 0.02648536923516076, 0.04224881966365501, 0.038740075324312784, 0.06824093157774769, 0.025763535995793063, 0.03106664869847009, 0.0256339013503748, 0.03750945717911236, 0.013680548963748151, 0.02057907600828912, 0.045859768870286644, 0.035919175716117024, 0.04389619454741478, 0.06087361674872227, 0.03960753834689967, 0.05242427287157625, 0.0405524333473295, 0.05580874458246399, 0.0033219170109077822, 0.05418313689006027, 0.015949590342643205, 0.046934521160437725, 0.035981683104182594, 0.07075978821376339, 0.040698654993320815, 0.06953574178623967, 0.05189380797673948, 0.036150161758996546, 0.03482343920040876, 0.04029712712508626, 0.04829743083973881, 0.013019867765251547, 0.059058687184005976, 0.05124384246300906, 0.030029048321011942, 0.03765491441299673, 0.012724449388770154, 0.042271061829524115, 0.03169879339111503, 0.050836781883845106, 0.052743845371878706, 0.06378381527611054, 0.03442026376433205, 0.009407019588252297, 0.04801765600859653, 0.019255867518950254, 0.059104911852045916, 0.058722331013996154, 0.06530664293677546, 0.03505521563056391, 0.045655411086045206, 0.021023999106546398, 0.04592212040734012, 0.052490275775198825, 0.043052617547800764, 0.030428232857957482, 0.0312982562900288, 0.019676568772410974, 0.02148058505554218, 0.03126336421701126, 0.01084994948541862, 0.05254146541119553, 0.07395483044092543, 0.051193265098845586, 0.025489486833976116, 0.0027375237232263316, 0.008865186846378492, 0.03566179148037918, 0.016996901722450275, 0.021416051604319364, 0.0252697424730286, 0.05054539615230169, 0.027190893779334147, 0.07369582090177573, 0.0285453114338452, 0.039706852548988536, 0.02907914011302637, 0.03733207646291703, 0.012030648922518594, 0.016488517576362938, 0.0050478375578677515, 0.051136216206941754, 0.02849055948900059, 0.020666133641498163, 0.01781701201252872, 0.023716841133136768, 0.04139608827244956, 0.016550186337553896, 0.02672352627996588, 0.04561309011478443, 0.0375711741799023, 0.04149958447669633, 0.0346651428117184, 0.03311033971840516, 0.049193429440492764, 0.05438583226350602, 0.02179747840273194, 0.05814188618387561, 0.1126986499002669, 0.03849039458145853, 0.021735824484494515, 0.007469555876014056, 0.08184291029465385, 0.04895630954706576, 0.03640586503024679, 0.08772828979999758, 0.02531626585550839, 0.020236422715242952, 0.021528661382035352, 0.06736681520123966, 0.018930645419459324, 0.08914262289181352, 0.042242967829224654, 0.026497768667468335, 0.04250966230756603, 0.027169145141670015, 0.038711973902536556, 0.018513974027882796, 0.07343372402829118, 0.012156999564467696, 0.03634920947661158, 0.08112015493679792, 0.03305425190774258, 0.06281007299548946, 0.015338469765993068, 0.03878001029079314, 0.04316607708460651, 0.06547101380419917, 0.04138796546612866, 0.031466653308598325, 0.045202519177109934, 0.06355063247610815, 0.01709438281977782, 0.01911561645101756, 0.044917311824974604, 0.05622334167128429, 0.028991229009989183, 0.048950398340821266, 0.020840703473368194, 0.02383454018854536, 0.04081240025698207, 0.03220494181732647, 0.058526797365630046, 0.08435023395577446, 0.01818340846512001, 0.04650298455089796, 0.001289129415908974, 0.010920207678282168, 0.04474538589420263, 0.014772546910535311, 0.0744321130332537, 0.064674347959226, 0.074594272300601, 0.025167817766487133, 0.01862801243987633, 0.03595807538658846, 0.009946139780367957, 0.015487874297832604, 0.04540336289210245, 0.005115340527481749, 0.016587392055953387, 0.04441371638677083, 0.05951638820988592, 0.04785620920301881, 0.007663106134714326, 0.028604809413081966, 0.05156814986548852, 0.054732808566768654, 0.04109054978471249, 0.014824224508629413, 0.02411201250652084, 0.07788372313370928, 0.02598209848656552, 0.036806572825298645, 0.02587793249404058, 0.029337225678318646, 0.04950690890836995, 0.04718438744021114, 0.024910945612646174, 0.028968665865249932, 0.022182207758305594, 0.020598865376086906, 0.01816232776036486, 0.0467302041943185, 0.014604141542804427, 0.04282756126485765, 0.03589726380596403, 0.05349152204871643, 0.03193398741132114, 0.040880796586861834, 0.04608735587680712, 0.022805797343607992, 0.059284964299877174, 0.01978407071874244, 0.046529093306162395, 0.027871797574334778, 0.020901947355014272, 0.019957367767347023, 0.023175743117462844, 0.04123174338019453, 0.04595065598550718, 0.04729382453660946, 0.03067648682190338, 0.0588812285423046, 0.01607919344678521, 0.028718563953589182, 0.039777668280294165, 0.0023463546131097246, 0.022655985558230896, 0.03274474664067384, 0.013905058840464335, 0.023853413003962487, 0.03307161445263773, 0.04915886762319133, 0.014387900118890684, 0.043558457982726395, 0.10289220736012794, 0.06532448416692205, 0.010414041626063408, 0.02785170763672795, 0.03734894547960721, 0.022963260671531316, 0.022569525353901554, 0.06923961744178087, 0.027197523013455793, 0.06743075864505954, 0.02836187293723924, 0.03425299481023103, 0.020504911335592624, 0.006352661657729186, 0.014531894394167466, 0.01090372550606844, 0.02363174091442488, 0.029552556115959305, 0.02026790833042469, 0.029441102233249694, 0.04954398660629522, 0.01323398015301791, 0.03840443161607254, 0.02816727810568409, 0.03419835047679953, 0.04573263897327706, 0.02551723016949836, 0.058108493249164894, 0.043999757544952445, 0.06614839425310493, 0.051712701679207385, 0.057308851392008364, 0.02475188666721806, 0.02667822929652175, 0.043286434884066693, 0.00813330028904602, 0.03558189557224978, 0.011190920886292588, 0.016076647880254313, 0.009856561628112104, 0.020814192102989182, 0.035820933917420916, 0.06465978702181019, 0.03275937066064216, 0.027971416056971066, 0.030271801115304697, 0.054446903595817275, 0.05194755802222062, 0.06856093823444098, 0.02256083480460802, 0.030125642551865894, 0.030195851577445865, 0.05956893968686927, 0.11870791611727327, 0.1783601284842007, 0.11371761866030283, 0.0864992784045171, 0.09749343182193115, 0.2311894655576907, 0.1692163644474931, 0.12262887525139377, 0.1419961836654693, 0.1779305882519111, 0.12325774892815389, 0.13010975351789966, 0.2187578091979958, 0.10433593692141585, 0.13087122672004625, 0.10461129597388208, 0.11331601286656223, 0.1572824813774787, 0.22433258505770937, 0.08724456536583602, 0.07106610966729932, 0.1411009902949445, 0.14168883062666282, 0.1569109919364564, 0.09567078392137773, 0.12803551013348624, 0.1272652647458017, 0.21172793407458812, 0.1663706882391125, 0.1941874815383926, 0.16577147820498794, 0.20641437935410067, 0.13675586407771334, 0.07135231891879812, 0.23705854750005528, 0.26740916655398905, 0.11931220986298285, 0.2011875668540597, 0.18559709249529988, 0.08490792082739063, 0.17211842903634533, 0.15074662427650765, 0.222427595872432, 0.10534215558436699, 0.12536219030153006, 0.10291654980392195, 0.11040250436053611, 0.10166215695790015, 0.20820665115024894, 0.17148387792985886, 0.1565454842057079, 0.12878743931651115, 0.19775094813667238, 0.15285413071978837, 0.09913668778608553, 0.08999275305541232, 0.15350025933003053, 0.06975569209316745, 0.2013785659801215, 0.1662588762701489, 0.08298061526147649, 0.07786205984302796, 0.10970890798489563, 0.16061145899584517, 0.14035824890015647, 0.20605734694981948, 0.06560176538187079, 0.15080221113748848, 0.18321163690416142, 0.24159776017768309, 0.057715815491974354, 0.14467018627328798, 0.11846998357214034, 0.1122029175166972, 0.11176190368132666, 0.19965961837442592, 0.10011656762799248, 0.1402295011212118, 0.31633997219614685, 0.09810347721213475, 0.2155361758195795, 0.270049698301591, 0.11214445112273097, 0.19141475844662637, 0.1581833595992066, 0.17512988619273528, 0.23157328949309886, 0.11483423921163194, 0.07561453981907107, 0.1684719606419094, 0.0962432543747127, 0.11055854833102785, 0.14734976983163506, 0.153140377078671, 0.15058378223329782, 0.15908880945062265, 0.10084916386404075, 0.14803132857196033, 0.0908587800222449, 0.1952723678550683, 0.11163112983922474, 0.17875202698633075, 0.18990269192727283, 0.11143040857859887, 0.2081090142019093, 0.10432898299768567, 0.126514790172223, 0.12681816529948264, 0.12476005620555952, 0.11108508726465516, 0.15390781714813784, 0.1324329132330604, 0.17654296505497769, 0.13051796442596242, 0.08623569723567925, 0.14211690140655264, 0.16408205323386937, 0.06529096135636792, 0.11621830009971745, 0.12175141178886406, 0.1269265337032266, 0.1030203614209313, 0.11882366889039986, 0.1585769056691788, 0.1330146234249696, 0.08546421988285147, 0.21167642902582884, 0.13369909138418734, 0.1161419553682208, 0.09729356403113343, 0.22208592592505738, 0.15010416187578812, 0.14062269096029922, 0.06906210313900374, 0.13103685923852026, 0.1401043898658827, 0.11268100904999301, 0.22452318342402577, 0.2137293282430619, 0.15145072946324944, 0.1626693009166047, 0.10474989947397262, 0.1397843609447591, 0.13586945773568004, 0.08870775403920561, 0.13350003253435716, 0.13563752174377441, 0.10653890582034364, 0.1871907210443169, 0.14390639757039025, 0.25551850616466254, 0.13883035979233682, 0.10065162641694769, 0.1465551820001565, 0.16265917802229524, 0.10068221774417907, 0.186965657339897, 0.12364837835775688, 0.11194570397492498, 0.08503689125063829, 0.09942077449522913, 0.14062436821404845, 0.08110873328405432, 0.10608085969579406, 0.13407644379185513, 0.13315953518031165, 0.12315712854615413, 0.09534896642435342, 0.10504623904125765, 0.1262980978935957, 0.2099794044625014, 0.17202656599693, 0.13321590871782973, 0.15462775976629928, 0.11051338122342713, 0.13678684132173657], [0.02821548801875906, 0.0463572824082803, 0.06151974535896443, 0.03718419611686841, 0.02146806687960634, 0.06590255041373894, 0.022058807153371163, 0.03859159754938446, 0.03331030398840085, 0.040388385314145125, 0.0599061790126143, 0.06589229393284768, 0.054206176864681765, 0.029856682667741552, 0.09820334060350433, 0.04835712919884827, 0.05447109018859919, 0.02106958181684604, 0.056823394043021835, 0.0490885157341836, 0.12232570792548358, 0.05060352857981343, 0.019086943575530313, 0.006846231608506059, 0.03365888333064504, 0.03507514229568187, 0.022338702583510894, 0.06018834355927538, 0.05554945302719716, 0.030852080817567185, 0.010792401499202242, 0.016575727349845693, 0.151147666038014, 0.012133008713135496, 0.020706035211333074, 0.1058602414559573, 0.024797289406706113, 0.07444662202033214, 0.0580264933523722, 0.021499101640074514, 0.035069624427706, 0.03348345446283929, 0.061053275858284906, 0.03207872847269755, 0.02944667576230131, 0.006961470444366569, 0.031896961663733236, 0.04203820557449944, 0.06100741484260652, 0.052539702810463496, 0.009466147421335336, 0.024445711787848268, 0.03337417321745306, 0.06897894549183547, 0.019899899562005885, 0.02102326623571571, 0.024538361503800843, 0.05042522388976067, 0.025216870017175097, 0.04918234175420366, 0.03511287679430097, 0.040456124843331054, 0.12035742096486501, 0.02772922543954337, 0.057156707407557406, 0.08448543841950595, 0.06959113568882458, 0.07555759482784197, 0.033712496078806, 0.039039583862177096, 0.0036231162539479556, 0.03281574048742186, 0.044575968422577716, 0.07009647146333009, 0.022974081184656825, 0.09901146520860493, 0.06917322491062805, 0.04131018838961609, 0.030324608633236494, 0.0799009992624633, 0.01957540662260726, 0.052908038123860024, 0.03362727897183504, 0.08588745928136632, 0.038531836107722484, 0.051596566700027324, 0.06307875271886587, 0.0421086836286122, 0.05887552884814795, 0.020664922085416038, 0.054665584830217995, 0.06918076513102278, 0.023942335283209104, 0.020232340903021395, 0.02866558759706095, 0.0487676704506157, 0.018624208933033515, 0.05235041433479637, 0.08233151806052774, 0.026842993502214085, 0.011899219207407441, 0.028969641789444722, 0.059313113961252384, 0.04266102703695651, 0.05013151152525097, 0.040038295701378956, 0.015564007517241407, 0.02109567758452613, 0.08069171308306977, 0.057116635143756866, 0.016072681100922637, 0.05627944803563878, 0.009034862214321038, 0.046205338803702034, 0.03311867774755228, 0.05886833001568448, 0.03004928854352329, 0.09190061435219832, 0.030938368472561706, 0.014609975751227466, 0.06162028781545814, 0.018638946130522527, 0.06438516269554384, 0.08254288171883672, 0.03336506706546061, 0.03907564852852374, 0.04645556131436024, 0.043637366834445857, 0.04501965770032257, 0.010758295175037347, 0.011972082338616019, 0.00942373739235336, 0.09145082090981305, 0.05301953468006104, 0.009097600595850963, 0.03496619130601175, 0.060100410191807896, 0.06926975605892949, 0.020724202986457385, 0.014681283155368874, 0.04521392227616161, 0.02343436673982069, 0.060772499127779156, 0.007536436833106563, 0.020788608417205978, 0.05326140802935697, 0.07784315734170377, 0.012031391997879837, 0.021581305627478287, 0.042131526934099384, 0.0419679019250907, 0.04610957206750754, 0.015408445015054895, 0.11148790275910869, 0.022058497306716163, 0.020319225986895617, 0.02291658329340862, 0.051812104939017445, 0.03462242108071223, 0.028291407870710827, 0.029325126815820113, 0.04034422381664626, 0.043751134362537414, 0.04029229203297291, 0.05097770830616355, 0.04701770107203629, 0.027705556494765915, 0.01840436252678046, 0.0535014000342926, 0.05613275512587279, 0.02539772955060471, 0.08270786856883205, 0.01822953108785441, 0.09672099709860049, 0.05177427767193876, 0.031692325574113056, 0.04909769239020534, 0.006754979913239367, 0.07363588505540974, 0.0797748490003869, 0.04166756589256693, 0.02504064148524776, 0.009319268974650186, 0.025084181434067432, 0.052157867830828764, 0.013788633496005787, 0.03049483504582895, 0.029523428675020114, 0.05046288046287373, 0.05145398528838996, 0.045191490862634964, 0.07503118205931969, 0.013734744297835277, 0.027210484622628428, 0.030546191665052902, 0.08682007173774764, 0.03889449028065428, 0.04821581314899959, 0.029743245395366102, 0.025802498748817015, 0.027146741558681242, 0.007503760998588405, 0.05953113468422089, 0.0738953473046422, 0.05156379716936499, 0.04628247763321269, 0.011843172214867081, 0.032155117733054794, 0.05056614289060235, 0.0644435103458818, 0.01919333044497762, 0.011463513583294116, 0.015042418708617333, 0.014503441379929427, 0.028204318696225528, 0.08090198578429408, 0.05334091802069452, 0.012634265458473237, 0.037071170736453496, 0.04102763421542477, 0.04454597823496442, 0.017856535087048542, 0.0489082072454039, 0.02672344464372145, 0.05195947320316918, 0.047065217077033594, 0.010320933633920504, 0.056230774280265905, 0.08969564907602035, 0.07761226035654545, 0.09702719238703139, 0.04916120909911115, 0.024230008421000093, 0.030489053715427872, 0.027264689233561512, 0.06914026613230817, 0.0398545028292574, 0.024339324918400962, 0.019853801059070975, 0.04840591056563426, 0.09578314507962205, 0.0289329073348199, 0.115200110594742, 0.027945765577896964, 0.07344864119659178, 0.08964686770923436, 0.0428604384069331, 0.040768862163531594, 0.06459882701165043, 0.052887324782204814, 0.016969807766145095, 0.05198999773710966, 0.05280974437482655, 0.043803819426102564, 0.015346227064583218, 0.06319124746369198, 0.035933198596467264, 0.013309482546901563, 0.03902971700881608, 0.02537015319830971, 0.01856309492723085, 0.07173470308771357, 0.048667105729691684, 0.04363716645457316, 0.04243533992848825, 0.042201184915029444, 0.001335061979261809, 0.055482533571193926, 0.007162728370531113, 0.026515381687204354, 0.1277151398244314, 0.025853094666672405, 0.0005363400373425975, 0.07367772734141909, 0.020934854182996787, 0.0635823147604242, 0.03030222545930883, 0.006853233307992923, 0.028319221710262354, 0.08067039118031971, 0.03256687239627354, 0.044122560721007176, 0.006958945286896778, 0.03322015159938019, 0.05293046582664829, 0.014270381961978273, 0.05348009668523446, 0.02656677726918133, 0.032977172450046055, 0.020579174342856277, 0.05363468604627997, 0.06260725887841545, 0.04298152351111639, 0.06975633034016937, 0.0036733281103806803, 0.059770458756247535, 0.015860089188208804, 0.012493821432144614, 0.04861779001657851, 0.14879792259307578, 0.05381869414122775, 0.07331299886573106, 0.10340999637264758, 0.04271834681276232, 0.03675886386190541, 0.019553158890630584, 0.058217273544869386, 0.060875746712554246, 0.08029493867070414, 0.01951876034581801, 0.02388803790381644, 0.03249665038310923, 0.00523963542036654, 0.02580128904810408, 0.025035711769305635, 0.07270010362844914, 0.04613598881405778, 0.031222453326336108, 0.06228949350770563, 0.012364075464574853, 0.01201472799948533, 0.051743630683631636, 0.055553475467604585, 0.04296110331779346, 0.008633319503132952, 0.029341897497943137, 0.06874590369989164, 0.1005160657223314, 0.06887732321047224, 0.04824929143069312, 0.023699792145635, 0.00742635128517577, 0.062409365200437605, 0.028435414205887355, 0.03071306913625449, 0.03081809416471515, 0.012639860324270558, 0.0398042186134262, 0.029957462611491792, 0.05488079281349201, 0.0563201214390574, 0.09722205068101175, 0.03840216435492039, 0.005945220727880951, 0.02353270316234557, 0.0181701759720454, 0.02684935741854133, 0.10347655959776603, 0.08421948237810284, 0.08415956137469038, 0.04511021084908862, 0.06356571291689761, 0.07498468650737777, 0.11322446895064786, 0.22517784673254937, 0.19515905674779788, 0.05726892013626639, 0.2472094801487401, 0.10705023814807646, 0.09936537317116745, 0.12353298923699185, 0.1298695500008762, 0.19567562121665105, 0.15506964933592826, 0.13214910111855716, 0.09805754569242708, 0.19756867666728795, 0.15756480919662863, 0.16262119490420446, 0.12928075972013175, 0.09555029624607414, 0.17652041860856116, 0.22181418113177642, 0.16083998110843822, 0.1409666912513785, 0.1468496216693893, 0.1230936823412776, 0.2085034508490935, 0.21777110901894048, 0.13930079236160964, 0.14188812696374953, 0.12393018667353317, 0.12193635498988442, 0.09868641194771044, 0.22264462953899056, 0.19327512971358374, 0.053977695570210926, 0.17474885273259133, 0.09857724944595248, 0.17542214394779876, 0.12820851959986612, 0.20538806333206594, 0.14968780218623579, 0.14834547968348488, 0.1435167551971972, 0.096785111236386, 0.097061717096949, 0.14711260912008584, 0.1722761947894469, 0.15613216732162982, 0.11695874825818464, 0.15485755837289616, 0.06511553248856217, 0.12189651650260203, 0.22167732910020277, 0.1571613480336964, 0.275814879569225, 0.16116850019898266, 0.10313738326658495, 0.10055919934529811, 0.08388492962694727, 0.1041755588084925, 0.250288502429612, 0.14290970808360726, 0.163322925218381, 0.08808878803392872, 0.22280767938354984, 0.1749822433339432, 0.20694703358458355, 0.1515812732395716, 0.17870809184387326, 0.1519603474298492, 0.09081575029995292, 0.09568347464664839, 0.11941673394176178, 0.24676720466231927, 0.10226906306343153, 0.1700420631095767, 0.15978722978616133, 0.15251678007189184, 0.12912373611470684, 0.13409823324764147, 0.18151235621189699, 0.13506283226888627, 0.07905726641183719, 0.16614270047284663, 0.13392091932473704, 0.2555552573176101, 0.14051990350708365, 0.14256411959649995, 0.2062721541733481, 0.13201015623053536, 0.11414334425353445, 0.14909868536051363, 0.1206741547503043, 0.1019663039187435, 0.1759078202303499, 0.08764541416894644, 0.09565360320266336, 0.12696638703346252, 0.15263377223163843, 0.15258299448760226, 0.08529089129297063, 0.05962378068943508, 0.11141972907353193, 0.2446575608337298, 0.13612401438876987, 0.12980345432879403, 0.0964221268077381, 0.13520346925361082, 0.14271658641519025, 0.10197716896072961, 0.09563562096445821, 0.11188625794602558, 0.13378765928791836, 0.15057149226777256, 0.1457765355007723, 0.25008631171658635, 0.12781234632711858, 0.17417834897059947, 0.14733997348230332, 0.10863861971301958, 0.10258268725010566, 0.1537788170389831, 0.237703355087433, 0.24840886500896886, 0.1354983838973567, 0.13605658285086975, 0.14313260471681133, 0.14269887877162546, 0.10712093513575383, 0.14958832471165806, 0.10781724035041407, 0.14095716207521036, 0.21097227931022644, 0.12374045661999844, 0.1163072168128565, 0.12317738175624982, 0.26805949572008103, 0.10189750682911836, 0.0987744158192072, 0.12164615298388526, 0.168305036786478, 0.10537354100961238, 0.16479304555105045, 0.1286716791219078, 0.07358397182542831, 0.10737816352047957, 0.18229262059321627, 0.06912111872225069, 0.147540160396602, 0.12213799651362933, 0.09922423152602278, 0.37534436385612935, 0.12732950504869223, 0.19380162411835045, 0.08694864140124992, 0.09908526437357068, 0.10844740536413155, 0.1259608511463739, 0.07843525017960928, 0.1593790337210521, 0.09242239611921832, 0.12127594745834358, 0.1117266590881627, 0.10542069707298651, 0.16293442575260997, 0.18182417697971687, 0.12251163818291388, 0.08973499774583615, 0.12008546094875783, 0.1322177646216005, 0.13804711197735742, 0.22458258492406458, 0.24796388810500503, 0.21912607771810144, 0.12360524473479018, 0.18883205484598875], [0.02204436681495281, 0.03190104347595479, 0.008673684915265767, 0.05149158991116565, 0.023328107890847605, 0.012548099330160767, 0.04888694471446797, 0.07020845412625931, 0.046215116599341854, 0.003343040621075488, 0.09523531392915174, 0.05021204939112067, 0.0552832186804153, 0.05186604794289451, 0.05371978440962266, 0.04106844120542519, 0.028111119790992234, 0.01172823023807723, 0.008442460457445122, 0.01709094110992737, 0.020232682290952653, 0.04226118755468633, 0.020194719581922982, 0.02993653961311793, 0.06360028215567581, 0.06942703941604123, 0.04352080140961334, 0.043993378785671666, 0.01392320806189673, 0.05831321839650627, 0.06675832089968026, 0.061499555231421255, 0.04765603342093527, 0.022237909652176313, 0.02712103170779301, 0.03204395514330827, 0.016440853141830303, 0.05913887624046765, 0.11525031688506715, 0.05950511127593927, 0.021385708896559663, 0.05765004265413154, 0.04461149132112041, 0.04188888917269651, 0.03593573303078301, 0.051812576202792116, 0.06240735398023389, 0.02086604967189487, 0.07945922843646258, 0.02216807541117305, 0.044118909354438074, 0.01514282294010627, 0.030244965055317152, 0.025098217302002013, 0.06089055626944173, 0.016229333632509224, 0.032698358700145036, 0.10606829513562843, 0.031159114732872695, 0.04896500009635929, 0.05758132349001244, 0.026653163258743007, 0.06559928660863079, 0.04954847659973893, 0.0535734403092647, 0.06212954584043473, 0.05500126935658045, 0.024753383950155694, 0.07194483478087932, 0.017365155399602372, 0.01583427543664584, 0.11270251648966223, 0.061326319409999996, 0.06366863395669498, 0.026428281380503904, 0.01220916605234379, 0.04097262251889333, 0.015351188321801601, 0.018285355436091777, 0.05548514593101572, 0.046636760380351916, 0.017196463377331384, 0.03647361198090948, 0.03997064894065261, 0.0563977389538195, 0.006900924645378836, 0.03117727508652024, 0.05741288936405908, 0.054938799075898714, 0.019190447201253846, 0.013116327481839107, 0.035822388526867144, 0.023679865480517037, 0.043301964324200526, 0.033156861245515756, 0.021987937616358977, 0.01718793424515752, 0.0785066225216724, 0.07323884346988052, 0.06798720613005571, 0.01634213636862114, 0.038510699741891585, 0.02183320353651652, 0.039087218610802665, 0.020319277937232982, 0.03344998731336091, 0.0033484963341834373, 0.07091153514920734, 0.035046836783294566, 0.02063948126306059, 0.056767792339087464, 0.013757754586549709, 0.07539344660472125, 0.01812375649024034, 0.02792745679471409, 0.017046454922819976, 0.01656253753026249, 0.044676150937448256, 0.03991451289039105, 0.024218119215220213, 0.032810166958370246, 0.048882610572036356, 0.052355631632963195, 0.0029644469714185107, 0.018000077579927165, 0.08135780546581373, 0.04125657935219351, 0.04649314367270563, 0.0545154409337556, 0.024673961161170155, 0.06885507362312637, 0.04937480662192684, 0.022453002602560446, 0.06165425591461826, 0.016044980438891798, 0.06506539299152792, 0.040206277117249556, 0.01640984250116162, 0.08599028384196572, 0.014408518836717121, 0.027802352960861754, 0.06967039706069045, 0.01274068850761978, 0.026443165152159054, 0.026706395656219684, 0.10638344814651646, 0.026615358256094623, 0.01984844831895316, 0.025758582160051446, 0.07448832329828292, 0.01781408609531354, 0.024135887397278566, 0.04779841074196156, 0.012961528464074945, 0.015654228554922156, 0.03250407557061408, 0.03241330348828342, 0.03980319816037081, 0.03572375338990241, 0.04616114019881934, 0.01440136175006046, 0.037270641478244215, 0.041118243025266565, 0.0719096050306689, 0.024737733911024407, 0.025476250630163122, 0.02925483615399571, 0.04332353113568388, 0.0395130518154474, 0.024903910052671563, 0.036396154027897865, 0.04203387885354459, 0.059839886671397835, 0.06772022592485882, 0.008545866676286096, 0.033315202163066715, 0.016444382054032758, 0.04400603982503526, 0.06420769292162731, 0.0059742915800597984, 0.03111551170150051, 0.03526669432176277, 0.03198600454197731, 0.04520117217907682, 0.041377642191946507, 0.007978088451636722, 0.062221690895967185, 0.05536480668524746, 0.02927501886006212, 0.022295058734016493, 0.03649909733212553, 0.06732244961312972, 0.026665408695407677, 0.0342888776503969, 0.028284385298320558, 0.051934655784862116, 0.07633580346009694, 0.01842893318098504, 0.009493249726801878, 0.014194647646945668, 0.09593076567398384, 0.004589919917634688, 0.015114526704564923, 0.036027863243361935, 0.06088762478611898, 0.043290086250635795, 0.0602986007288564, 0.030406387741095386, 0.04151374465436675, 0.053284867317415774, 0.031135900353547186, 0.015329114994528936, 0.05278484532027505, 0.038079556470620446, 0.051354533788980916, 0.020923809170199092, 0.04131014757149387, 0.07116828855942003, 0.040443489779136144, 0.07533051990321837, 0.009977526133297943, 0.0374452873802511, 0.02163673849281622, 0.04367582863778807, 0.04448879204574041, 0.034790959107340313, 0.04658430167182814, 0.021831337035109755, 0.052744761924259365, 0.031558356786263175, 0.0839296737103723, 0.038705558035871945, 0.013959040807094425, 0.013604695905087283, 0.1149611093569547, 0.057968041801359504, 0.02778041693090927, 0.032159548354684375, 0.05383537391026039, 0.057906395304598846, 0.040625679612276144, 0.007809008657204686, 0.03914250490197446, 0.027357368635421153, 0.04758781891723629, 0.02524605497455923, 0.043201640801271424, 0.1141739207378123, 0.06216316141944844, 0.02589971638371935, 0.014082749403314665, 0.04380975660751574, 0.030526053487847093, 0.03345225086377468, 0.039358837238978595, 0.039262795908143744, 0.025357332597195636, 0.004692505135608371, 0.051405782796791755, 0.0009446918954836292, 0.03731051707291044, 0.0337861505249748, 0.06592474805074744, 0.017704001475067344, 0.0441935545677552, 0.03814170020632446, 0.03883042067172937, 0.031364485548692755, 0.07199290368589573, 0.06503293887362815, 0.017391881992807612, 0.03807595705438871, 0.018085413430526387, 0.0382832685863832, 0.060800671053584665, 0.06374594348017126, 0.048875908978516236, 0.06681959261186421, 0.03862534671497997, 0.015232794430630747, 0.05530917158466764, 0.05586761544691399, 0.00740378767659422, 0.07437313455739059, 0.004395496707729762, 0.03995665203547105, 0.03697566004120745, 0.021296818158589303, 0.04893161458312534, 0.022931220300961286, 0.03005891790962778, 0.04820234687940683, 0.02761077124887379, 0.05472390279464889, 0.06451553577790037, 0.00800830777734518, 0.027557895082281902, 0.005928150403633481, 0.006958679969102377, 0.03142878893413581, 0.058915697591146454, 0.07808877111529, 0.058893871027976274, 0.019990705040981993, 0.046041591340326704, 0.05157292558578774, 0.03159640669764485, 0.010321583940822165, 0.02253956856293371, 0.030173642808222212, 0.0679963271250017, 0.028660834141192026, 0.02276488274219446, 0.04700029770901892, 0.12618454929906875, 0.04773803702846635, 0.04562984038784634, 0.037467243819264695, 0.026637680202838965, 0.015880624414421618, 0.07485881083994173, 0.10479042073711753, 0.011999202270089881, 0.024738620777498, 0.04451567634532694, 0.04281881876522675, 0.011737250115402276, 0.029719082922383677, 0.05276093703287188, 0.011898779484909028, 0.05836146170622669, 0.018376995831204113, 0.03177084479830228, 0.03535180010658223, 0.040321124470210634, 0.031237344519468024, 0.05102156923385337, 0.02855569593521068, 0.014618467776017496, 0.0383322466223035, 0.055431752116419375, 0.0347283292649081, 0.06097995908930898, 0.04035832462250255, 0.06291516110650264, 0.01416857136064209, 0.06336841295706108, 0.034333662551944144, 0.04339056562457699, 0.036642858758568764, 0.0157619345918647, 0.07494596124161035, 0.20989741198718548, 0.1510276904446073, 0.33183364081196487, 0.1093568182841409, 0.07428841840010136, 0.12374503567116335, 0.12403149725287221, 0.16371929144952446, 0.20577525661792606, 0.12055011218762957, 0.2729661902412772, 0.12698495556833223, 0.2134688344085589, 0.18966416566399857, 0.22202875086804852, 0.21958735218504444, 0.14944480819394812, 0.11148266319651157, 0.10969062146614306, 0.12696518475422636, 0.07766073002130724, 0.18044200114673004, 0.08900353699573316, 0.1067661885463167, 0.1606665857252665, 0.14511658810079098, 0.09265510394470766, 0.18771412811474875, 0.13525221351301298, 0.2816914423601702, 0.2574165933765471, 0.16448591515654698, 0.12873323285020888, 0.21246996300760657, 0.06678484525764361, 0.11939780917600729, 0.17893753421958536, 0.12806828337488696, 0.16688683710526675, 0.27593130769673735, 0.1648957736324519, 0.11685563425999135, 0.09368999919388443, 0.09225816625985317, 0.0893417485349346, 0.10500018135644495, 0.17632238392252475, 0.09176140229101293, 0.18960173620143905, 0.12617608881555498, 0.13689029670786113, 0.2167654543882236, 0.15990561718354002, 0.16315209766617045, 0.22701037261867896, 0.13763657072559, 0.06895334881846793, 0.19760545750614256, 0.21402663260232657, 0.08944424655055627, 0.15096610703039914, 0.11932650362723507, 0.1568700253847055, 0.08962633248302154, 0.24606440565548837, 0.20717384875752032, 0.2045290867681615, 0.19467247504508123, 0.16529387648915872, 0.08911169017665088, 0.13710198691114783, 0.15294918499421328, 0.2696170855779201, 0.08927062110160477, 0.11943406309001148, 0.15467959136003628, 0.08103446656605229, 0.08844680749461986, 0.10384772991528735, 0.15052525646751747, 0.15121506789000705, 0.10714830554206856, 0.1340970754972659, 0.07036356299067847, 0.10947489397949539, 0.10991489849402569, 0.17774402716895565, 0.09803398992517032, 0.17380071454681456, 0.13416045490885153, 0.14151113078696653, 0.1694722124375403, 0.17218436143593863, 0.1403281622333452, 0.09251071911421604, 0.10953843666356988, 0.07552645431132987, 0.18713327881414443, 0.1624806915060617, 0.18314658023882657, 0.11812504075351171, 0.14126530179055408, 0.1030757330590859, 0.14098607614869252, 0.12548059254186228, 0.14274039451265708, 0.10155584430322051, 0.17704541387502104, 0.18726400070590898, 0.15605609718477353, 0.1440976490266621, 0.2397455376922153, 0.1455435753450729, 0.08776203525485471, 0.15037755423691124, 0.14957757841330022, 0.10928781339316629, 0.13695875240955502, 0.1964431651867926, 0.09424042043974623, 0.22148858610307798, 0.1477582479128614, 0.09114860353292897, 0.1637407098314725, 0.17095977324061096, 0.1855650168727152, 0.13333021430298686, 0.16458459111163393, 0.10982356237946078, 0.1705079834209755, 0.1439865495194681, 0.129361312428955, 0.07869745837524533, 0.10456775416969322, 0.23004875489277765, 0.19804094976279885, 0.1314495230326429, 0.1160852775501553, 0.21909894479904324, 0.10465548344654962, 0.14104549249168485, 0.1855601483839564, 0.0906669200048782, 0.07705593903665431, 0.14955632330384105, 0.19999765179818496, 0.14295751723693684, 0.07537822515587322, 0.0767338098376058, 0.194584708660841, 0.10088969997013919, 0.14641420362750068, 0.15716306981630623, 0.07333222049055621, 0.12324803421506658, 0.12461409060051665, 0.08464990576612763, 0.1161622085783165, 0.2031169578549452, 0.08976887678727508, 0.2138875244418159, 0.08548664758563973, 0.080150316352956, 0.10897759566432796, 0.1748421703814529, 0.1053107478946913, 0.2160709971212782, 0.12364648588118143, 0.19468213780783117, 0.10517995178815909, 0.1308152242563665, 0.10195134222158231, 0.1479709622799419, 0.13985447905724868, 0.12189514352940023, 0.12069466771208681], [0.08547423145500943, 0.022785421679145657, 0.04449323008884676, 0.06058415317966137, 0.052020448056282476, 0.021288613716023974, 0.022601827331527602, 0.06276111351326108, 0.031745251835673116, 0.04548050172161311, 0.0414076991728507, 0.002338021454306727, 0.03585007805668283, 0.004741715092677623, 0.012047567106492352, 0.03507655979774427, 0.029869547797716223, 0.007480915837732027, 0.016176203280338086, 0.02942085273389239, 0.003970619018218713, 0.03935903019737452, 0.06784953773603775, 0.038251025980571285, 0.025535006461723242, 0.01835169972764561, 0.05728499876568094, 0.04196940477413591, 0.06704430750687607, 0.02094676750857616, 0.04345633846241981, 0.09292936461861245, 0.01365616199109354, 0.035055018961429596, 0.04840860827243887, 0.06291499783401377, 0.07696369008044712, 0.01191137651403551, 0.06925526933628134, 0.10129700545803644, 0.0684412446571514, 0.038875513564562425, 0.028901418008899782, 0.059488717233762145, 0.014337949869513977, 0.054899357637623325, 0.025021306682901923, 0.036496752145467326, 0.013918854438088601, 0.06615907375817187, 0.014037578584975563, 0.0474437383672921, 0.10588471006485634, 0.00881291181940469, 0.03674137144116685, 0.03021753527718829, 0.02311764965270413, 0.008695903889019974, 0.010692696741898544, 0.008862164449965348, 0.006681623717668117, 0.04544142393569928, 0.012819026833312819, 0.017454322587582283, 0.04614418954588473, 0.045626686260220595, 0.016001243820937816, 0.007087641115504084, 0.04294133992516436, 0.05663079929945525, 0.03811123504419811, 0.0035622450695882435, 0.04047207359690219, 0.009572433173161699, 0.030221502056519967, 0.11129616148537025, 0.05635559238726273, 0.0182296220009448, 0.024554269439249765, 0.07628313323948532, 0.04548938151856419, 0.059162038669455796, 0.05510080991371069, 0.011982206160610076, 0.028879157289338764, 0.05964358861092478, 0.09858254095888697, 0.04156840012001339, 0.06662728730589151, 0.08540552342310548, 0.01615338409465039, 0.008274428018921753, 0.071321846335195, 0.06250701699173078, 0.01867123140982585, 0.06263577219215222, 0.06399774676538073, 0.06673403040622361, 0.07742187721305527, 0.03636347726569511, 0.020223366482241545, 0.050217147945659235, 0.02947964381746715, 0.00474479871627409, 0.055084760970203206, 0.04604107183695305, 0.09831310424488038, 0.009892858215607703, 0.029653862984559964, 0.043464472400955856, 0.028749517077812925, 0.020929353013343643, 0.025964685846702196, 0.010997543176927138, 0.020223180945322383, 0.04114574330742471, 0.005255153264442924, 0.054428082730737515, 0.03563056561688427, 0.04723022990219761, 0.06284106508246623, 0.016359491492039524, 0.03326781603391282, 0.0636704002681654, 0.05109342026116792, 0.03423285663302522, 0.06581418288988061, 0.03215590069885366, 0.06813902728026733, 0.049874171818373725, 0.12486973078921437, 0.018652677717909683, 0.03373404804733582, 0.036670744957518764, 0.04347283269453328, 0.022359241520462092, 0.08044333109864965, 0.05503263993887231, 0.01875385656603612, 0.028162741728010587, 0.013567049536504783, 0.035807541862595826, 0.07897747069364414, 0.04439913318492472, 0.024356435133086052, 0.02810006364597939, 0.010298283286829246, 0.02899765044276137, 0.031062474117788952, 0.04644430293410551, 0.08190318010747433, 0.039053228247212246, 0.028615143819479272, 0.055639327110839076, 0.014813212892477168, 0.029417167970677838, 0.032531969191040844, 0.015180980462901061, 0.04925944347633049, 0.017344636871712282, 0.058791829433175735, 0.024425614428764675, 0.08330487442435697, 0.044497749768197536, 0.0569529396307189, 0.01887366332084639, 0.03290096872660797, 0.036251605924917385, 0.021244685995043255, 0.011898828652192606, 0.02983553145895712, 0.013568690610554768, 0.06123742125055287, 0.05910680803935975, 0.005925348332311842, 0.018488852329028305, 0.051483841889421456, 0.04737231407489162, 0.0527725516440114, 0.019858842097164597, 0.0043659879884216934, 0.022070158302085474, 0.004248349232511828, 0.07291027985047549, 0.05262581420538481, 0.05211969546508044, 0.030762670576223172, 0.026795700141519774, 0.0684165905113332, 0.02852409343176987, 0.04643533407943323, 0.08860259171342477, 0.011627778694673907, 0.05510277289431542, 0.039355360277113505, 0.02191563202359248, 0.006553209441335639, 0.03777258563786745, 0.020146539354755078, 0.053650475238100626, 0.03819276738795452, 0.05891377542866394, 0.021686968902940862, 0.024733357095101383, 0.0306788950911141, 0.029395604869932868, 0.01821646001189947, 0.0747916464752052, 0.08129905705573037, 0.019062964784097858, 0.025551060971338302, 0.026965178840328008, 0.06565151896211319, 0.0703773892018944, 0.035357384767849, 0.12159211721154861, 0.07378581372904591, 0.015805756556801498, 0.0222907858187682, 0.0033139129482151475, 0.040234745902125724, 0.08861525275278836, 0.07301182049559429, 0.04457520401047077, 0.02741516895184759, 0.04958349854859989, 0.1078508299542591, 0.05378622518037446, 0.06910220879944973, 0.0336882835108554, 0.017875678786367644, 0.02095123338222038, 0.07102478688466363, 0.03357086832693312, 0.03832709611742757, 0.022831427413620986, 0.02106405281665502, 0.030977064052422065, 0.025791399930312764, 0.025428307890251745, 0.03970050718635321, 0.04041991174744908, 0.04214303022308741, 0.038392809583456255, 0.0344945713004563, 0.06655684264842421, 0.04841888330702204, 0.030845128749206197, 0.05893774679861963, 0.08570121732191183, 0.007269584648383898, 0.12204808532260358, 0.017015297707985155, 0.05622043245239183, 0.06362768966937438, 0.0336052000784548, 0.014749889141967287, 0.03069195503485389, 0.06238744215806946, 0.04114930561627261, 0.042053894576383755, 0.03401217902137432, 0.010206020415353123, 0.033596735884202644, 0.05903897574171424, 0.021736980379500892, 0.03568533982615918, 0.02459215793351177, 0.04021596585516818, 0.03148190073261503, 0.02213375293649733, 0.02008296512940433, 0.003765908481909719, 0.054434164630947635, 0.08372355703613721, 0.08724925573915243, 0.04062660729687195, 0.023914200464787427, 0.043776979655376635, 0.0484867935301736, 0.07248954148963094, 0.04886388618615456, 0.04400047371746041, 0.04122336824366357, 0.026960009781760164, 0.02432254495943198, 0.03330186205857899, 0.033631416445132345, 0.08785272570094094, 0.012233043726155302, 0.04048848248203285, 0.048305598174920306, 0.011173308794241166, 0.027480151402414776, 0.041494727120152675, 0.030729017889825627, 0.06894799051224254, 0.062498749466612935, 0.03711087934789248, 0.1093345093249809, 0.013641327386721969, 0.07893061148934066, 0.05923540738876909, 0.05957194538495969, 0.03095183474215446, 0.046045676863286644, 0.11434819927671924, 0.007130232042982243, 0.03883471399603877, 0.04430968583619688, 0.034548351031844504, 0.050533558896859176, 0.03213934338418767, 0.02342606952879578, 0.03264768856752198, 0.01920606940984726, 0.1331742890761234, 0.01273242654860951, 0.07670653591048904, 0.009477202638663584, 0.0811243183852639, 0.029100890606059693, 0.01258736729141674, 0.12547867780085653, 0.02973579608806176, 0.058666799814091064, 0.05446346833196003, 0.02252942525956314, 0.08693724201293662, 0.05363196978578344, 0.05864451683009975, 0.03386902615602594, 0.051943891812697984, 0.02760737406788394, 0.013761037662334275, 0.02333126016310416, 0.04981539743312169, 0.059925092646153644, 0.010881771850108635, 0.09393467786139809, 0.025608890973671805, 0.03312720873509534, 0.03464164270553738, 0.024788812224869616, 0.052175761011312716, 0.07647508231457323, 0.012680968811764615, 0.05283233163936529, 0.03923266471247189, 0.036812610196648166, 0.04683491381001659, 0.044940333245904185, 0.1812170704943128, 0.15026862180093303, 0.12233501445734873, 0.1898079938837327, 0.12724546424578875, 0.0847516096837353, 0.18571208085631952, 0.21256844600429758, 0.09691472732811235, 0.13397617964074016, 0.17802724556531757, 0.15141053474508226, 0.16021723015001044, 0.16936933592660353, 0.09791609234525822, 0.17244635440874845, 0.21505685232114047, 0.07708697565249167, 0.2244456735206768, 0.22256832191487774, 0.06755183261702769, 0.07552446535555646, 0.14043460105312988, 0.11860177415655926, 0.18060187459923327, 0.14194831514032558, 0.20269044558517635, 0.12248293933225796, 0.19216383778257295, 0.14698893763124943, 0.10311404272215441, 0.28553983429446816, 0.14153299445752054, 0.09672367625171319, 0.10828056314494461, 0.18732825585175306, 0.1870635020895861, 0.08797604095889255, 0.21917106671025977, 0.1471968725672923, 0.2691467123804614, 0.17309107293840498, 0.10780126191093586, 0.13368770683882758, 0.08850536294630729, 0.2385387461981736, 0.11871806127601303, 0.1356551848584786, 0.10790804954012856, 0.1564393867738545, 0.17781844973796979, 0.18057647830573842, 0.29073014797177166, 0.090432141587371, 0.14492371876258403, 0.12223834230098873, 0.17659558332525194, 0.08884911090717651, 0.1146285975119099, 0.06576716041308828, 0.07878686490585096, 0.1616341681801714, 0.11682290554745123, 0.1252773479791358, 0.15167107310844585, 0.1466597951366566, 0.11347553750965744, 0.21107742679305375, 0.16913116589421406, 0.27878946682903916, 0.09328919491963461, 0.06668900430668145, 0.14176721626427025, 0.2305661208811216, 0.09461688227020204, 0.18210184411145747, 0.153318848751951, 0.12269405066035688, 0.11572670890018344, 0.2221982425544411, 0.14139280276140198, 0.12144275999162346, 0.21134627721039578, 0.10903212867560796, 0.13669791718712077, 0.19964686827734113, 0.14105800510151312, 0.1129403748200275, 0.07562409868114628, 0.22213800984900445, 0.12526406353572384, 0.14218226977391168, 0.18579334602691233, 0.1732103360700421, 0.06941827465198003, 0.11561575782252476, 0.1246877561789006, 0.18789259978802875, 0.18834887217963114, 0.1259500306332484, 0.12973891716683283, 0.12039714070851915, 0.13673061621375382, 0.15476110886083916, 0.1177697375533171, 0.11450500765931793, 0.17135245841927826, 0.08231019615777768, 0.20100235647987574, 0.12875570508185774, 0.11369510932127014, 0.1346589406603016, 0.13735143758822232, 0.08717017990420572, 0.20284999249270186, 0.132640952069778, 0.07662997595616616, 0.12768637418048456, 0.205631012795493, 0.11004093001247384, 0.14032682636752725, 0.09008710228954442, 0.17658986878814176, 0.2065717740333639, 0.13358344993321225, 0.1274899870622903, 0.19142195727908984, 0.22299728327197954, 0.2069104605470784, 0.1485020134714432, 0.2004506142111495, 0.1409296877682209, 0.13653589150635526, 0.24663375166710466, 0.0968498265137896, 0.20980108121875674, 0.16335716791218147, 0.11115761735709384, 0.17412443936336786, 0.17299834900768474, 0.13327232678420842, 0.12187797765363939, 0.19149304018355906, 0.10413721945951693, 0.23011550365481526, 0.09837408651947044, 0.11043961174436845, 0.16683076042681932, 0.14978463761508465, 0.0827646502875723, 0.1303479532361962, 0.18734303943347186, 0.21228819619864225, 0.15890935814240947, 0.11977795205893926, 0.08179400276276283, 0.2058902004500851, 0.11232697492232546, 0.1375237197498791, 0.10827119724126533, 0.1122811769891996, 0.2156039932742715, 0.08897269333829172, 0.21953491203021258, 0.1623590980307199, 0.1269520932692103, 0.09096833586227149, 0.10027971395174973, 0.1371024173568003, 0.14488331624306738, 0.1290496697765775, 0.13719322654651478, 0.16666036332026124, 0.14550507272360846, 0.17426938080461696, 0.09766402188688517], [0.059049117189715616, 0.017620504295337014, 0.02310430398210883, 0.028155969630461186, 0.039010502805467695, 0.09946013800799847, 0.04798031484824605, 0.058596087983460166, 0.04890097501629498, 0.01971488214621786, 0.015131854925130028, 0.08816250556265004, 0.05677242705132812, 0.023167364270193502, 0.07422920243698172, 0.0352654920425266, 0.024681343675183598, 0.037082061753608286, 0.03270440720370971, 0.03855147704598494, 0.04841026326175779, 0.016271333624899853, 0.09140983951510862, 0.043340132979210466, 0.016672095225658268, 0.031254547502612695, 0.06876062048831955, 0.057846296185743995, 0.019261116358393338, 0.017194316715176683, 0.018145902176911477, 0.018794429779518396, 0.04985095001757145, 0.0489540200214833, 0.01462321195504046, 0.01453539269277826, 0.04213829161017202, 0.03513192401442211, 0.00832359251944581, 0.033877204623422585, 0.007117710156308021, 0.07420754656777717, 0.023212355117721017, 0.021396212141553406, 0.07610587868839502, 0.020422226807568222, 0.03597747141611762, 0.04160027536272537, 0.05975746375042945, 0.05455412909213919, 0.08741592726437375, 0.020287460210965946, 0.09638375777285546, 0.03612799751863349, 0.048726930253906175, 0.02452734061080264, 0.02941569109680131, 0.01421456596290227, 0.04637481564714108, 0.07272274655406363, 0.04937226105539594, 0.08001539390534163, 0.03129477932816371, 0.024460244894726202, 0.05898820541915484, 0.05035569207393564, 0.0687511581054423, 0.011320545327180298, 0.017940104626177344, 0.02960568461276125, 0.08440270379651338, 0.06297978732618503, 0.04211024956020992, 0.03715477367222775, 0.001571148084167362, 0.039670598634984344, 0.04435127579199616, 0.03697767126141116, 0.013699033079319634, 0.051029907263000496, 0.039389729136019014, 0.07464291265932843, 0.06623806053539738, 0.022722179564880207, 0.07168975120293908, 0.04596361759467982, 0.0456494590616785, 0.020658942230511457, 0.039553376409457996, 0.049562202621018514, 0.030776051498833112, 0.01785000418749405, 0.015056733809615253, 0.049967378145083785, 0.06650743787758984, 0.030518849089276046, 0.06717419077176601, 0.08366301262867637, 0.020069066558789928, 0.013028127868892625, 0.07512417316320352, 0.03500938801153097, 0.024898395895434078, 0.03329826635308564, 0.031843278411543, 0.028449657875171397, 0.06994695839239284, 0.022184873923833948, 0.06811472936533391, 0.006488568378699711, 0.043047615472460166, 0.023667675704928115, 0.038656876859022304, 0.03338241847814061, 0.04854284423345234, 0.04265792485966813, 0.014899624857207527, 0.07939301402075216, 0.014559903047484113, 0.09456696541747078, 0.07120564827346243, 0.024631959313410334, 0.02467001850163797, 0.10169726796448231, 0.042857414155150764, 0.004058082049596123, 0.025244455646316055, 0.05349898063286673, 0.07074134584399872, 0.054082319838926196, 0.01473643214922049, 0.024196248123189434, 0.10805644938955083, 0.0063628416046412895, 0.049454149630037136, 0.03547302621882409, 0.009167368043563329, 0.04397062824864406, 0.06763277124264278, 0.032002903244574554, 0.047187756790663116, 0.048551727741141804, 0.08402155159274116, 0.04651308147003874, 0.07231317009427585, 0.06682215302134864, 0.02592232220195001, 0.03973712846345734, 0.08484139470965602, 0.03212334639101755, 0.01299231274970225, 0.04148343163251411, 0.0509951153799193, 0.004863373969783424, 0.04354925906227436, 0.03602556629630271, 0.04655363241909072, 0.01580643747729482, 0.0719478701648768, 0.061894058671896346, 0.035626442986540496, 0.030622207996202633, 0.015284889486792963, 0.042538079142104834, 0.03361388691700995, 0.035131812692270614, 0.03520193451549858, 0.03947953271563165, 0.003761675920941343, 0.01608348306035623, 0.04191450439975597, 0.00838476311400882, 0.0520944513118593, 0.019401039025979117, 0.02367223620240111, 0.03293382360425312, 0.06852823178633116, 0.019633295996754896, 0.06239539055968635, 0.04984699437045492, 0.010283598967362195, 0.017504860988992732, 0.026927789440378547, 0.0246040805359371, 0.03075536784308497, 0.04312867284170352, 0.031500988770858385, 0.015330236565205269, 0.022073831933084875, 0.08604852759162895, 0.04986734034901019, 0.01505976641055895, 0.01713625850243261, 0.023454365764337126, 0.01930745977006154, 0.007318006073546712, 0.01696567029284779, 0.01015976327835233, 0.040829580975696445, 0.01694258207862731, 0.007153914903028635, 0.08253683321527205, 0.0072731928776192944, 0.054089214390842244, 0.04362712519650813, 0.040777723406790756, 0.01191524959722301, 0.03750164236407727, 0.03882789736962877, 0.013715346412936924, 0.027446582207630854, 0.019265977425675374, 0.006878641661387519, 0.05241966042376589, 0.04951405579049606, 0.0216908113725367, 0.08271691534901038, 0.06500481147668324, 0.041236522811232135, 0.0392916654527653, 0.053828497912036255, 0.018318458933208603, 0.05291351146297529, 0.04338590122642927, 0.022351072329911403, 0.07072734151734039, 0.02098398621455999, 0.08527376994607039, 0.019129793327010702, 0.009152189268206712, 0.0394622369640274, 0.07559295074315742, 0.1004878937965259, 0.02528555764001794, 0.06904386114911176, 0.06401102378731593, 0.05598215480858926, 0.05741572807892226, 0.02959191220725188, 0.07096209767041728, 0.08046258240938187, 0.04282202113245148, 0.08461304329102859, 0.05605898564681411, 0.04618451785063371, 0.027956567537330557, 0.09369510516989976, 0.01827565185521962, 0.053184926000540145, 0.05416919935669284, 0.022236545955820475, 0.03342530719237402, 0.058231789953424595, 0.004322198028603452, 0.020239250297890976, 0.053973446774762124, 0.06294319944572635, 0.06203757890034467, 0.07153089449275285, 0.012577379839058267, 0.020346869132481515, 0.024893412373785395, 0.04837543427129276, 0.029523037192120682, 0.0445239178952761, 0.012618028194992803, 0.053482642251765355, 0.11047051477362402, 0.03331440435431432, 0.042057898463099264, 0.023471782114938833, 0.06855966174043715, 0.05955830099992454, 0.06703043676679954, 0.03824162296950817, 0.013174956220609602, 0.06795380206312984, 0.026530887007538695, 0.01162577304057777, 0.035806885061901994, 0.042274052684661, 0.016155302546394523, 0.018651063546712976, 0.025490505431662314, 0.03343767879414372, 0.02284543174027931, 0.01668283966864692, 0.06996209820499644, 0.0656834090477787, 0.07514873082982376, 0.025503244396531954, 0.08163427773979492, 0.03915376328222919, 0.07861482765292749, 0.05733094512834214, 0.04596638209477533, 0.06571488353074528, 0.03836078962194733, 0.06160075819934718, 0.07200658146757632, 0.05620555239147507, 0.06011364639562089, 0.012312628859945107, 0.05701307956769597, 0.0033502825908726663, 0.04608092887792736, 0.05116335283673834, 0.039665295989834704, 0.07294501978321932, 0.03354902692080941, 0.01991491506487364, 0.07611454697325826, 0.0288876697231899, 0.02367949069594033, 0.04377275312435813, 0.025390976006747223, 0.03254694944189396, 0.07087724792654626, 0.06741782301105559, 0.051247107912786305, 0.027765343911596574, 0.07225851091789082, 0.0624255662842188, 0.03275084338383749, 0.07172460245783441, 0.030185457799234428, 0.014097732437221566, 0.02932467596110655, 0.07122247276129201, 0.006712374606649973, 0.07514769924455322, 0.08432815506239422, 0.05170852709852625, 0.026984641663148068, 0.018982380533998366, 0.006793036782255513, 0.030024200241314247, 0.017173319502035156, 0.02742551820119843, 0.029130296352377627, 0.06795979861635715, 0.060358269402058795, 0.054505967418663204, 0.031046916847117245, 0.014259708950703498, 0.03994370155851357, 0.010197532101301476, 0.06917389284353703, 0.07032872657873668, 0.0237896922044456, 0.0575466280861292, 0.04143980077060405, 0.19801967981038615, 0.12819560623029247, 0.19302186439745128, 0.12145340238930658, 0.10319870692910627, 0.18326171702938154, 0.10520016789087094, 0.1173832270433195, 0.19599189487053081, 0.12404734210576862, 0.1987345758243464, 0.13282908650580794, 0.1663609067327343, 0.22070851468015462, 0.16815113020129502, 0.11736149695934728, 0.11877887285663746, 0.24835517804604024, 0.1482465217122808, 0.10473829228430986, 0.13377210387261584, 0.09471753975958563, 0.15420136624015868, 0.09837758203502744, 0.1525496126851067, 0.15033330739242956, 0.118546899757348, 0.16006801393814385, 0.09508428687695414, 0.12900922272820026, 0.16339489870006219, 0.1027732336660847, 0.18563345773145556, 0.14651586301624775, 0.098431461956352, 0.11791319469921291, 0.13646458595758304, 0.11043295467970893, 0.11412968131480739, 0.1550642168149352, 0.1595625074696727, 0.13585468899691477, 0.10550619990681298, 0.1226512658467982, 0.15935463190544397, 0.12122875428758562, 0.22577103052753955, 0.14383334055310115, 0.15037053351989016, 0.28012411552481353, 0.18405358860036358, 0.2275140830897726, 0.1359566007158719, 0.11668635037494823, 0.13977630122099072, 0.22405283991247416, 0.14918855944415554, 0.09977541718399152, 0.2334314343170263, 0.133597535896115, 0.1421176880830899, 0.13712108979234472, 0.2189153226208873, 0.14606083743274212, 0.1959375399746932, 0.07354687186307274, 0.1782144300523214, 0.09574832351063378, 0.1459932723082602, 0.10758097763755359, 0.21206524019362405, 0.23608425603015348, 0.14872602332616225, 0.11493439204059541, 0.08156092386343516, 0.18557460542069748, 0.18072824750561267, 0.08316664199810475, 0.08634978759801015, 0.08962268853792921, 0.15586736903060228, 0.18142908724257722, 0.17456502275308594, 0.06816964829340577, 0.13768188626272604, 0.1159683967125602, 0.12977949780179188, 0.15333731338614598, 0.12060382883646525, 0.19513631734298542, 0.1460976924863644, 0.19044585496885702, 0.09113361957133748, 0.26666039892006665, 0.2271587576251477, 0.12414570635883138, 0.1767383428523317, 0.11850303140818141, 0.08483496771077625, 0.0979381415527314, 0.10727025524829514, 0.1526928917155601, 0.09630782122258097, 0.20957008033292368, 0.16069193748990074, 0.07690523852943443, 0.12804980389773846, 0.1452197614707984, 0.09126497228862718, 0.11348544518114068, 0.10203033642028458, 0.15578055259538814, 0.10731672111433, 0.285798457916826, 0.17817615007515997, 0.2880262368125841, 0.10008800236391835, 0.1709073330857791, 0.2109277356066741, 0.2931095624808222, 0.14488267799606547, 0.12432407413143665, 0.11383464050595649, 0.26183355948887765, 0.14324613846838474, 0.13151382270734757, 0.08493637476931326, 0.14743599254870787, 0.188892332080286, 0.14320558751933277, 0.2843388612382114, 0.11500882945256308, 0.1920355946640484, 0.07679914851905778, 0.17528883938211948, 0.1369160640751943, 0.07023557220236398, 0.106451406609267, 0.13064651924651116, 0.19342425686772913, 0.1837193252868019, 0.08986249871668406, 0.15110344887943938, 0.22166606329847127, 0.14851158717647195, 0.21547647746047005, 0.19886624766513705, 0.08712168797501363, 0.11489643118693493, 0.08282738403067924, 0.1775572434416972, 0.16557479422772303, 0.1229215189232491, 0.09418746078154072, 0.22314771660603583, 0.12142448089434765, 0.11603965773247182, 0.11739905705326237, 0.10368768576881848, 0.13450911588734016, 0.16137685073772445, 0.1116772172099445, 0.1566508543328382, 0.13271825417177752, 0.19310936360852793, 0.15842157416045666, 0.17586962931090966, 0.14362637040903792, 0.12022654322208837, 0.13256053294753656, 0.09849297857726924, 0.11698432266712189, 0.16970947704976425, 0.15937887044856325, 0.12648713774979115, 0.11673727654851973], [0.036653749775723554, 0.03369398691575043, 0.05557683827646542, 0.028923365171067417, 0.05216508150624577, 0.015592086674587335, 0.01990931370528415, 0.0212269486655714, 0.028737544380419422, 0.026394921842438634, 0.0684327025373932, 0.05751875301939435, 0.025616520251787733, 0.014536894614138873, 0.020624480603146367, 0.016758985875640064, 0.016977791419776622, 0.06223821110324934, 0.023805318123777397, 0.03608767292462289, 0.02239287379779853, 0.027790113090304658, 0.025260777329094708, 0.009436976379220141, 0.06650422437814996, 0.03231153648812324, 0.01987864259717753, 0.051163438183721155, 0.051777895641862415, 0.041349136299686506, 0.03429745316680055, 0.04193327702523675, 0.08740610865061171, 0.02613079148432007, 0.0340116743609542, 0.03311825843411498, 0.05666460783686489, 0.05351466221327428, 0.03334131833980791, 0.08214148372644559, 0.021389749890659004, 0.05117138658533804, 0.023337624079431407, 0.07554906012956053, 0.04482042073504999, 0.04469421481189784, 0.035882799347746186, 0.02390438185102539, 0.0077253880954231136, 0.06321524109807797, 0.03342575619171839, 0.04555726576654706, 0.07952388434205204, 0.02682930829905672, 0.0136827512869786, 0.034959552795044146, 0.05619768562610261, 0.043596396571956575, 0.024169530806830153, 0.053245232920744456, 0.01903159234643681, 0.024155600694939494, 0.06107083878305275, 0.020162530781817622, 0.011840769511763938, 0.07213694712845609, 0.0701223204669077, 0.023047379399940837, 0.04317114595323801, 0.05893093388294801, 0.021763690274383407, 0.08287658100016415, 0.047225131347659044, 0.01019995706883492, 0.013467290973494528, 0.0636009055597242, 0.0500387282227166, 0.10381923886598088, 0.01653881663514767, 0.030522029192070477, 0.05119484216265846, 0.01528161476016976, 0.04321138891100418, 0.12131956347730011, 0.03819854500761721, 0.11494686012156308, 0.04261187830707058, 0.00928411807763041, 0.026246945017192047, 0.06552946535521187, 0.01389884520904161, 0.008003490311239148, 0.02982893191074254, 0.021714936738135293, 0.013487699106917717, 0.02869074269256089, 0.018837036477634683, 0.03700830340676475, 0.038561284527531825, 0.029666063892364036, 0.033455241718911566, 0.034147847327403724, 0.03779301325266715, 0.06964280401007272, 0.03580258802685421, 0.04240478199790232, 0.013395618989306968, 0.07192420307546854, 0.10186325671384111, 0.00952084556047339, 0.045412112813210115, 0.10159931189264171, 0.0413345753622707, 0.02842882207914954, 0.06101311453676317, 0.0507217861013487, 0.028094701629015617, 0.035203099687350914, 0.014463633506238693, 0.02575572860223474, 0.0327089231723221, 0.028395894842105918, 0.048957660255837254, 0.00734500540602312, 0.06760356773156673, 0.044651671196334064, 0.017477410801802762, 0.028408674625097774, 0.09870647962088697, 0.018288266510353424, 0.034745873635984026, 0.026073557055497076, 0.027851401500811335, 0.042525859680608846, 0.043580559140536934, 0.048417625366710126, 0.06965156877413392, 0.035870850770152174, 0.06574133367394097, 0.04112462549528573, 0.020472275391512085, 0.015486588526982814, 0.04429395972692873, 0.037156662438064814, 0.07579391691251658, 0.07873711132560857, 0.025517454669170547, 0.02769654311123304, 0.04403692430059891, 0.054308403996401466, 0.061120455065974966, 0.03845453400572296, 0.021884894122194964, 0.04651057672163006, 0.03786107561609242, 0.07170094278990291, 0.007881498859205749, 0.04860292850935366, 0.049576904566492885, 0.03559920245606918, 0.032698759459890425, 0.08337308521731757, 0.11239776838920079, 0.019968615015386604, 0.014225456052372465, 0.04545839685306419, 0.023770340703777038, 0.0089442181524646, 0.08408704612520523, 0.00663199212795007, 0.024699463210708927, 0.0615641035255976, 0.038715139162377454, 0.03559637116268277, 0.04137985008128453, 0.0534803304617526, 0.10126175344339572, 0.053376789728645235, 0.08088097558356822, 0.036147968712612055, 0.09267529036151245, 0.02709462609345792, 0.0496494940307457, 0.0278892324786284, 0.004213573120068759, 0.027839148642669898, 0.02651853395946091, 0.04899784384178929, 0.025442139667575248, 0.050701365908025764, 0.033095533872256055, 0.014127605736575788, 0.030980904666648712, 0.06552349848789163, 0.04093305491551291, 0.015385567385237664, 0.0322366055479506, 0.031597809356753714, 0.04295740742236376, 0.04486925034143496, 0.02171790347347269, 0.08769193940679543, 0.055760163595550694, 0.01464129160012817, 0.04100794132682495, 0.061984600688447244, 0.04855942381254863, 0.034181277369498275, 0.12512269924627617, 0.03641100811364595, 0.054454351047752425, 0.06241174749447964, 0.06432876689359546, 0.02887215327064041, 0.020034449080412742, 0.022272330461419187, 0.04791499472048599, 0.017277639490203, 0.033509989953017794, 0.07944486787891947, 0.013662499932252103, 0.0632128662255127, 0.05560680619964842, 0.04668997607950587, 0.01628695026738569, 0.06687324988888577, 0.0057665741860546404, 0.01815946863644058, 0.06864170616609044, 0.017372745714965276, 0.009043996196851367, 0.05634860135614872, 0.03713404177688062, 0.061387390742311254, 0.04192783708276693, 0.05306594117428176, 0.051764574091066606, 0.007028589352557901, 0.03831452413578518, 0.055669072389719076, 0.03227847751986701, 0.05227937224844936, 0.03975784551585093, 0.03306876831629779, 0.04413230512000155, 0.09432796417968348, 0.010130324135388946, 0.09897981261019595, 0.05718040789361112, 0.023949432070367038, 0.011708223792084027, 0.0734380359062925, 0.03310675885586534, 0.053205398144200444, 0.028942978278791998, 0.029434977659548167, 0.055907825008034706, 0.018837312927644234, 0.03368442063219845, 0.03613047258113511, 0.04275935047189705, 0.029532874359574635, 0.06542788018123247, 0.05347781829186715, 0.02254588238429278, 0.019953833289036993, 0.01845065584348049, 0.05872067231393885, 0.03920274873962626, 0.036853576748399064, 0.01435076583220507, 0.028559510574268643, 0.024486045658704825, 0.020194836470182054, 0.013649510492541594, 0.024959949623735156, 0.03373711311724037, 0.02318451715837, 0.030470125238934997, 0.02525343563320348, 0.03034085424587829, 0.08043352732784115, 0.03728952542587649, 0.06435385890654288, 0.062406255601672456, 0.03850390909065027, 0.05707465184968896, 0.036117407071287744, 0.05695145533536561, 0.05628301405522507, 0.039713038349873386, 0.012615014147741022, 0.0461558598181, 0.029883539136790205, 0.010775546397781, 0.046449290166492574, 0.03705224968143739, 0.024790428251435515, 0.027151116519235075, 0.030041219542908948, 0.02183872140449239, 0.03344703356560785, 0.036645716027123854, 0.0073309124854858965, 0.05094753629236948, 0.03246186221076641, 0.03876715258229524, 0.023942671105032787, 0.04908053022518288, 0.0323705706250621, 0.07228556962218136, 0.02564444912422914, 0.10560670154518448, 0.02372822567849653, 0.03994875187345315, 0.020959768080501817, 0.02834969800460385, 0.05942003888776526, 0.020124260081502143, 0.028128677149652503, 0.01050924154696986, 0.03341481693496462, 0.015099601187102962, 0.02099773450026987, 0.019590466654335614, 0.05595588649157435, 0.026571543712634593, 0.033359738445142284, 0.07837958168238401, 0.030502401241392363, 0.0613552668801276, 0.031512900241068564, 0.053495481406571344, 0.0040906015692598885, 0.05213448646827601, 0.028390363986545708, 0.028492791498138104, 0.13723946234676987, 0.03505514883727301, 0.026720362875494175, 0.03442692082899157, 0.04686563501309138, 0.034910318718175404, 0.03753036718990188, 0.08745859333430417, 0.020688626282208133, 0.026323948404751718, 0.021461313335748855, 0.015302166684705298, 0.03075237513257889, 0.07203561428468674, 0.012750577625411097, 0.15430764178745449, 0.22249004017794505, 0.17691365297650918, 0.07240607214043848, 0.14561382704414427, 0.11937996052438393, 0.16368855169275776, 0.16155008284840733, 0.14813315123319626, 0.11813709323178045, 0.20434185775229707, 0.14160437422106043, 0.08846931683365256, 0.19679111370351166, 0.18658449029317126, 0.0760214519686997, 0.1552686488139443, 0.17145203979453072, 0.07234135686303489, 0.11426721612224355, 0.1629701378988102, 0.12426011584466323, 0.16942005429882556, 0.22650514816632494, 0.14397374005056918, 0.16527613915968686, 0.1421309428405948, 0.09494734578765929, 0.1154419023077935, 0.15206205134745687, 0.18497595941880718, 0.1639952664845623, 0.20541920384857804, 0.20297884417232126, 0.14483255334198475, 0.17246113799046725, 0.1805772352963686, 0.16365775256417692, 0.09863161918474361, 0.12987725349375978, 0.1213237491901964, 0.18812214606441557, 0.11780734959756956, 0.15496604552026838, 0.11753494429285638, 0.177391076576896, 0.11278433084953576, 0.12654023099457845, 0.09070616477401927, 0.14602294337237254, 0.1951644744258374, 0.12980710569536313, 0.09942497505107895, 0.10711614828323945, 0.125765755365137, 0.18037066591205075, 0.1268326965509914, 0.11314116287394427, 0.08049976400798187, 0.19260581640992314, 0.19276116276159883, 0.12416312456480227, 0.17083117389120162, 0.13437512854579836, 0.11938854717300273, 0.21021202323026955, 0.19154708337737247, 0.13730327220400795, 0.16032611805712804, 0.17567095637787133, 0.16531382541870698, 0.19650155736599118, 0.1826530965627171, 0.07850373556721024, 0.08287087388453074, 0.1949973576120101, 0.1442197768483311, 0.1467509160283953, 0.18511598784243688, 0.11763231406803243, 0.14535796421114355, 0.26570178160909563, 0.13779159053228796, 0.23575411905767396, 0.13255849946290255, 0.3058813599636778, 0.1843044493580237, 0.10707878856919706, 0.12574947264511138, 0.1603241587872617, 0.09348974548629485, 0.08376424899324775, 0.17222651542397216, 0.09897438751067966, 0.06509412152809091, 0.09389902508701198, 0.06688145804218948, 0.12883066199719906, 0.11376823313185014, 0.10435479489387944, 0.09555923912557773, 0.15363389044068754, 0.0982972964993678, 0.20217707235133275, 0.14279820781666785, 0.1560082583455369, 0.0672552407195326, 0.11612561327638105, 0.1970911046373658, 0.10564403899479657, 0.12627473508473486, 0.2783597930101678, 0.1366678305203095, 0.11556616751477122, 0.1805524920928292, 0.1725969955441542, 0.09017673146445304, 0.11969450497417711, 0.09286388492910191, 0.14145290188025683, 0.1041492645163089, 0.13812303368467838, 0.12321252244873904, 0.14496076677460223, 0.14046431664610282, 0.16326149023370817, 0.0850216623803135, 0.08909609023248777, 0.23334329685894772, 0.11688123835483566, 0.07987072705873288, 0.14161080121994019, 0.12706801673630252, 0.11982182040810585, 0.12331509467912838, 0.10951919277431443, 0.2998438401846215, 0.08764432321186177, 0.12210641070851125, 0.18845667655114084, 0.1207622625224758, 0.0992880784906447, 0.13184250507038087, 0.15565355628496036, 0.1002433338726405, 0.23629753442946821, 0.14417233876883984, 0.10977661411743611, 0.17633736046263948, 0.14845574798528105, 0.1796937084873207, 0.1369766381685622, 0.1952743122819811, 0.15957610361510888, 0.07695648382650688, 0.15411098749609664, 0.15394961490528658, 0.1644243168993853, 0.16086332907434553, 0.10959389735944569, 0.16613446263363585, 0.23646098503377289, 0.18523093167459592, 0.10495357448235154, 0.07823098145308904, 0.09478263353230432, 0.13619258883409202, 0.07960180984809995, 0.1651330234017223, 0.14263359946198761, 0.12619501358130947, 0.13506522198440507, 0.0648478175571654, 0.11634845053777099, 0.2606228494551033, 0.10175397546845488], [0.033024198637576774, 0.10805626385263167, 0.044837534660473466, 0.017492398474132642, 0.024714961109566502, 0.04213898551824968, 0.004497870413615601, 0.0424049192952225, 0.030341201199917123, 0.020789383961528074, 0.050040064088534564, 0.02155205758754164, 0.046465149862342514, 0.012744078267132863, 0.05661639792378992, 0.03585784463211894, 0.02562980469519971, 0.06615525169763714, 0.06955963151995093, 0.024814249336486682, 0.013661886732734274, 0.02518233046430396, 0.05719434913771693, 0.0387325907649938, 0.03452026816376019, 0.024957170280686114, 0.06947040310478769, 0.053219699329929426, 0.09164734903606586, 0.050780823949025944, 0.03493416021228768, 0.03114180413831491, 0.02726820886891801, 0.019617432590166572, 0.05339282753993757, 0.06502323900349438, 0.03027963077329332, 0.03966457981732674, 0.04103431354451459, 0.02689930952328723, 0.0555864268244477, 0.02483866785041755, 0.0342832781461766, 0.02496241169865243, 0.06701892605633475, 0.021333068361855112, 0.025648102346167434, 0.046375342571991496, 0.003157493265462108, 0.027987403773295227, 0.06149487599032, 0.006927097874722676, 0.02499563393939752, 0.07205241650808603, 0.015228674583340762, 0.06125260188127868, 0.06267106131417677, 0.011160653320985148, 0.07985615127836354, 0.026893735994235612, 0.11214923797524534, 0.028038309537805617, 0.03509819340251852, 0.07681163144297898, 0.021457916154759005, 0.04403729166369885, 0.014089994620007928, 0.023178581832326017, 0.028248207454453222, 0.026531783150858246, 0.055759109745849855, 0.050030219499603845, 0.020188685921311844, 0.05245493841357529, 0.031675248756073415, 0.007049195546642295, 0.05711512487323489, 0.05796220852062106, 0.054879104427527636, 0.06876086539705284, 0.08614507358288392, 0.01714960417302791, 0.0638571914169006, 0.030258294027589727, 0.10395362696726806, 0.026018543503596447, 0.03177560196490958, 0.05384776777646039, 0.004240979242240428, 0.03943064744817093, 0.04771349791553803, 0.025009387791214976, 0.048408051661681384, 0.02160100222681649, 0.012735078798868926, 0.07315789742278866, 0.0204927215600037, 0.0050513084897829685, 0.029601443238789216, 0.04541069531114772, 0.05193103781493846, 0.03597718197852373, 0.03178747632773593, 0.03796489465457853, 0.04094372699910309, 0.054723297944292426, 0.06062890839530155, 0.01411670080415206, 0.10053715013782494, 0.026985879194398876, 0.02288177656737389, 0.024284762221213896, 0.021098128527228255, 0.07942415453726426, 0.04729955020593479, 0.040494304630556144, 0.004183011014902149, 0.03593989276851062, 0.015117464681679849, 0.010781676537590101, 0.009955664318113122, 0.06563694318174385, 0.0744544665212743, 0.006671603796348791, 0.02903131055063568, 0.0925014125823509, 0.03802605875534937, 0.03373412968358025, 0.01419001293470501, 0.04127299565880094, 0.0465821865509497, 0.023231871746247634, 0.06988064749748446, 0.011563251737243263, 0.09916683382471092, 0.029594888219435234, 0.02696176125027705, 0.011246472495258786, 0.022494919103337452, 0.021246489413897507, 0.03174671757733449, 0.06052322656614706, 0.052665096081909724, 0.03826237341854721, 0.021499047834367957, 0.06110019443440251, 0.033412367847631685, 0.030723600211786106, 0.05221438979788218, 0.031705016299383715, 0.06599401269340888, 0.009159248947980814, 0.04393866765894927, 0.0296531690764823, 0.046998464604257606, 0.015028589714347618, 0.03690616904350463, 0.031151704388321377, 0.04289349737518933, 0.022778291495342273, 0.01606273446668638, 0.0399864307109965, 0.03193614706106018, 0.040168349660234526, 0.03508798145048786, 0.029845669196220115, 0.03880404845403973, 0.13322518556378782, 0.04163573888945393, 0.0240398052483215, 0.03376288790605031, 0.0771876479848288, 0.03762337684747763, 0.013604484392999439, 0.03648656616860535, 0.03731593104021158, 0.025116234792221803, 0.02517284210625803, 0.015743566436867695, 0.030882228711561766, 0.05363627424230799, 0.08323356145410798, 0.023172748551587574, 0.04679870071413461, 0.07732886384474114, 0.010829195325641194, 0.032860198843991384, 0.04269517696229741, 0.0892893603304401, 0.02666205047717085, 0.03570716638932936, 0.024995880703500006, 0.11451945727458224, 0.04328138456912711, 0.06599140775506385, 0.030055090282985475, 0.04605543610523455, 0.06526022902107798, 0.043765869704657234, 0.02815583604387939, 0.08086703062872402, 0.052555343572748825, 0.03425332877668552, 0.04484105986193754, 0.0324382062535733, 0.03316827547678258, 0.06307067815214396, 0.08471381952404045, 0.06651210598647594, 0.01711648397758836, 0.030806123322690837, 0.05638238391838968, 0.025663652195362374, 0.0324182647455018, 0.05866339706699364, 0.043981923736282624, 0.06390977257979102, 0.0015461386351489637, 0.0072672863097977825, 0.026645120233297348, 0.03441634893533774, 0.04016519553260878, 0.03617833739554044, 0.01654667968978174, 0.05552665053983219, 0.02922748615674209, 0.0015652612296435109, 0.013708745937037747, 0.041196138845407404, 0.06673786730971187, 0.03624084849434439, 0.019998556963400915, 0.04965417698258534, 0.04705088249465916, 0.020468475595407654, 0.024754914629738778, 0.051315745440660976, 0.04073923933901824, 0.010903750553552527, 0.037214041585684754, 0.04671455972129479, 0.04210220096865669, 0.02766685349342879, 0.029627919357153587, 0.04450944601558149, 0.06143054291896988, 0.025838633919192944, 0.06397697405191138, 0.01715317390335258, 0.016403814406658057, 0.005424734472398995, 0.058278816140955314, 0.03384497314982582, 0.03946548386011273, 0.020070805039722472, 0.06279666238697246, 0.06154181312012952, 0.08653329103253782, 0.04391628077428322, 0.04117803786357399, 0.03737497630936559, 0.05235344600805547, 0.011835400073323399, 0.042549326390144415, 0.04213222455291543, 0.01688953892880818, 0.061648671253351495, 0.008007407923287246, 0.03980773268267512, 0.007849801731936168, 0.04053647346154321, 0.0680150960397441, 0.06564622002770193, 0.019933604198740795, 0.040710187968215905, 0.02587583221611567, 0.017610373979550786, 0.03016052534803748, 0.006926697114977287, 0.013798687741655158, 0.044422893042792566, 0.039935126042109914, 0.048265295845340006, 0.0490247763809748, 0.10932302830042318, 0.031572368534398265, 0.05841346770466771, 0.03681301466713194, 0.032551227923249826, 0.033104654867202044, 0.04192449741822202, 0.042292372600059025, 0.04632894720998593, 0.008543018684576964, 0.02356439843424596, 0.0234072746388847, 0.033357523134327494, 0.028660487187153194, 0.015069423607201315, 0.004932734627800528, 0.030192372760211583, 0.018365175274084322, 0.01846068596933037, 0.052953390768379904, 0.08052141987718642, 0.08644162837299518, 0.02316976140718907, 0.045363168173935264, 0.035525570274330676, 0.026262609899276868, 0.054332468134816736, 0.03810356494795997, 0.06639582628849894, 0.030505124923365656, 0.03041332125576446, 0.03217159341147635, 0.07074729044688866, 0.03193284079316072, 0.03435332946537528, 0.061400174236041494, 0.04816712455067318, 0.04629830764315557, 0.014744232121302048, 0.06321565670077689, 0.016539178432140034, 0.043367180551285855, 0.047468511256738566, 0.04965044397977181, 0.023098053243302274, 0.06445087245083414, 0.011839993967441842, 0.03409374476177618, 0.04468366147193592, 0.003136068621643062, 0.08166430503479205, 0.023361287458101287, 0.029656252700078767, 0.024848137654771563, 0.03948108380427584, 0.03680793466628529, 0.03064219403313473, 0.033423911954741925, 0.025872204969346058, 0.027619771644822322, 0.039500298007624224, 0.04107725791982375, 0.020688331278506666, 0.030288462330645416, 0.012706275119853672, 0.04262426104105543, 0.029832907966920175, 0.01657710032304749, 0.15812858910067007, 0.17923800012795255, 0.1227215323888231, 0.11786095492425375, 0.15040866506751627, 0.16164476604899392, 0.14091879304032773, 0.09771916345926002, 0.1604965003207326, 0.14494516683043912, 0.07420599547913298, 0.1294975558994338, 0.18606939527671784, 0.09433114799321629, 0.11026881387806498, 0.12945225520525128, 0.24702208786038682, 0.17381275218212977, 0.19300930725876242, 0.11954422749113292, 0.12101309359422885, 0.11237443526624702, 0.12261812153155915, 0.1381681117345579, 0.33616003522183746, 0.17726216552546248, 0.22173677512910217, 0.1369581586914137, 0.13894393807277083, 0.1829755151993595, 0.1424942389712669, 0.09019562654430047, 0.16739633632823825, 0.09968972881324589, 0.07991371967364103, 0.17729879793478176, 0.11578345351153985, 0.13270390103571117, 0.324991840752773, 0.10466453764820471, 0.20359957648906857, 0.1374470113660209, 0.1792392024071887, 0.07596859621116892, 0.11159836401930079, 0.15824212285224348, 0.14606202486902475, 0.07445379858836532, 0.1377787662204355, 0.09924131576553918, 0.14687366725411266, 0.10882341448450461, 0.09181654386338778, 0.07910303465905599, 0.1268322067335248, 0.1327134302118793, 0.1761061666184105, 0.15995523717720062, 0.1231953788374085, 0.18255805713124573, 0.2370366541435942, 0.1377903882530518, 0.12623093352885917, 0.15118238370632753, 0.18455499841365963, 0.14666090835817158, 0.09180377892334945, 0.14250908192479983, 0.18119961518095806, 0.11196019069757313, 0.08644304587505758, 0.17902256950037554, 0.11702642470481806, 0.1069432872463949, 0.12128702030167915, 0.15994354092981666, 0.1502756870468147, 0.10131372604519129, 0.09749398101121187, 0.16635562264127657, 0.14435412042075768, 0.15426185127580538, 0.10279785812599584, 0.10772364068543538, 0.18133477511582896, 0.1904452167218551, 0.14832220593234524, 0.11939386837184429, 0.0982069771271199, 0.16878165886737406, 0.15576878213323653, 0.1370221615070477, 0.116075340192765, 0.10952731186989695, 0.08409636750002392, 0.2428444050019607, 0.16744211199693382, 0.11071010230807588, 0.15659936412703246, 0.16469199472339824, 0.10522696684347466, 0.15112972090719268, 0.1021871373814065, 0.11179965673363768, 0.16962478315690532, 0.13821351632941514, 0.10773075046017766, 0.1546148315537721, 0.21726692357333377, 0.26235045050270855, 0.12797164090443403, 0.1942540521849878, 0.13858686113962904, 0.1658752007642761, 0.09002348539070226, 0.09341910787043162, 0.20007682411232963, 0.1738130341982469, 0.12662919965805486, 0.13306167558766901, 0.13131007348420098, 0.16531128727365285, 0.20536196941975504, 0.11938793861190788, 0.080985440290533, 0.10322243339032866, 0.13875997450668365, 0.16704083274817094, 0.17948817810975015, 0.1994394973735325, 0.22893640911206603, 0.18806218053214252, 0.11531106909387745, 0.13852024596417323, 0.1608260435750708, 0.07884857448516414, 0.23490422638133168, 0.16546618833672255, 0.1340824700309895, 0.09128370409598574, 0.19247065647505224, 0.1382210268639028, 0.08653403318021446, 0.17737945454427972, 0.18341041373787448, 0.19895336095942184, 0.09858177654678002, 0.2015695651061833, 0.12238812254508957, 0.0853191374335438, 0.09140431793639436, 0.14355273451656103, 0.19055745913647115, 0.12446941633243114, 0.11519416599185206, 0.12428672183887102, 0.1441029182751663, 0.1335804516565986, 0.13682681339560077, 0.21273482067044824, 0.08835235435981303, 0.2021691165282391, 0.13157423352822661, 0.11579084530239925, 0.10652879034751095, 0.18284948368091136, 0.08242796757258475, 0.23306123621296138, 0.12121774823754095, 0.13587543944595382, 0.12116650294046849, 0.11153053172165528, 0.08290451543871313, 0.15211382356937975, 0.08138438919559121, 0.11355273571098223], [0.04153443944233004, 0.037502440172829665, 0.06706811560434289, 0.06221609881322365, 0.007278701004906907, 0.031044746065163054, 0.03118680055195, 0.035910258811782114, 0.039830791210988536, 0.038296686616376974, 0.05518289144674782, 0.017064696912711952, 0.008028564698179252, 0.0892128300620243, 0.024790498755464796, 0.026073258341057226, 0.09166395830106921, 0.014388057825271972, 0.04404716593853664, 0.02765173037914792, 0.023660345141252037, 0.02768622725852765, 0.0302097427265835, 0.016990129624900874, 0.035558321251301095, 0.07326973165618256, 0.03484482418571133, 0.04145637292822357, 0.02837640975485556, 0.015138926664803876, 0.05774657380243298, 0.08561892056604847, 0.01751182604493806, 0.03516469354508445, 0.1661751768551767, 0.05462798391818069, 0.034955960800289176, 0.07729320364887826, 0.04205276651191525, 0.05749982454290148, 0.044000740890624, 0.013318682395038195, 0.04850393714150414, 0.01892607378977118, 0.030865459884807933, 0.020758916944032535, 0.020171243595541455, 0.02301754691870883, 0.05023177196562756, 0.09508999399258755, 0.060901406468474306, 0.036265617673052475, 0.021309798321453854, 0.0433146290743025, 0.017345833584840875, 0.030178871238604188, 0.04163762023381423, 0.0383149620029144, 0.008418069774052128, 0.017294833196501713, 0.045720374982920475, 0.013648169988300651, 0.024610015861981083, 0.054396949635702185, 0.04151749250013381, 0.08127839566441253, 0.028649367959587835, 0.027379048624425195, 0.04241160975652747, 0.030415256405831315, 0.015525151447945973, 0.06359928025631234, 0.062322459707502276, 0.023432654234056827, 0.03457912789599504, 0.027136826465721242, 0.054587251142947935, 0.05172760400455445, 0.08476859002257697, 0.08116489159874618, 0.0015204844453364785, 0.004871408182225423, 0.08480548218358308, 0.08190478314645588, 0.0245117684971774, 0.017915626740432344, 0.02781691204290837, 0.024137824402714614, 0.022037911985535175, 0.01567211060319096, 0.020214839205436874, 0.017624797619646415, 0.01064860853148275, 0.033898159163072705, 0.04295945203921292, 0.043743011556216516, 0.05988543969579041, 0.015568133858323563, 0.021565826282312628, 0.0530205180257326, 0.05030482898291666, 0.008499682826368371, 0.01584423876920482, 0.0372314486594405, 0.049700141898938455, 0.037913215201115236, 0.04378641977382358, 0.025119631973211654, 0.020779398364538793, 0.053813910999451764, 0.004684552559410804, 0.0341389341338072, 0.013889393958379515, 0.07192061850219034, 0.02280249107570853, 0.02519082434446318, 0.07279986311914399, 0.010832434800249757, 0.051048646491835825, 0.023948131456563715, 0.03417522515519522, 0.02457232589222258, 0.033631898841122165, 0.03421563138545025, 0.03619912124122493, 0.027215080372116063, 0.014255789483286208, 0.024250747737823986, 0.02551626352214953, 0.013191882753744721, 0.05190361916902475, 0.02586851092928555, 0.007069558223520289, 0.037236536081763916, 0.0216139694020967, 0.014491914898826508, 0.05278744283714332, 0.06248714969842695, 0.02284712940308964, 0.02889780189434532, 0.040995966774062254, 0.03238865676394198, 0.06739806703990325, 0.02582134558906546, 0.044243538213777356, 0.046623193920822814, 0.04894035337201785, 0.04690053821832407, 0.03736069367732853, 0.03802139435720164, 0.049098249000962824, 0.032872318115551025, 0.018931137092295103, 0.021944581349089276, 0.015814237449376378, 0.052739437014679424, 0.005015661745346733, 0.03334550776344258, 0.04241394010023214, 0.07957572335726582, 0.013827039638272254, 0.022461264561570715, 0.09066263039130718, 0.008816248700895812, 0.05207210524531547, 0.007724325432718615, 0.028045181825291365, 0.08572153732529841, 0.015703104545536917, 0.04595725367835257, 0.011959688472416019, 0.03425768889428582, 0.09438104258151725, 0.03519923680869397, 0.057881422035279684, 0.04415317060193047, 0.039131491430453025, 0.04544284143776167, 0.06615344085730612, 0.05696968990378082, 0.07668965947232209, 0.04660908940422814, 0.026644565477909055, 0.06529396705445834, 0.040385962201980874, 0.012890663565485738, 0.029488054206012748, 0.04174574372882489, 0.02322521097084973, 0.08947795489802957, 0.05053715831309091, 0.05675318316207267, 0.09602711128536612, 0.09772958321264014, 0.051786571348202415, 0.0239737856463762, 0.022407614706025925, 0.06378327350830659, 0.04087005399924237, 0.04163466648606118, 0.06034381236531772, 0.03380725349416025, 0.015927593085507397, 0.023213501735881437, 0.05848778266226873, 0.031010844759293832, 0.041766932044993155, 0.11424126321799122, 0.04115157658816315, 0.053287175396690145, 0.0609195556899067, 0.013412449043244123, 0.06605616013985127, 0.010937132356048096, 0.04521417460637167, 0.018847196479327977, 0.04582878049404826, 0.05154996724741068, 0.018183313841291238, 0.03487089583359193, 0.07556778451544233, 0.007065677255013725, 0.10490892687812448, 0.05536406082683243, 0.00794071482232539, 0.0733609712915495, 0.059412149857962504, 0.0680865574395284, 0.07282675855094567, 0.06171943503431976, 0.024807516201690305, 0.05565120889514219, 0.06167330684547778, 0.027377829646866303, 0.023767895327182487, 0.009089330287679331, 0.029920939668954816, 0.04571574769215658, 0.010587703254714143, 0.06715358133078553, 0.029934500562376343, 0.04904432826151606, 0.01677522963291267, 0.05257068376522511, 0.04929923001327552, 0.022624377488682512, 0.030533855315297842, 0.010490000440768199, 0.012739044650516007, 0.018649226731213275, 0.03267438733018935, 0.008117455436149612, 0.057703054262674414, 0.04603182096616365, 0.02457956739817746, 0.008338481857208535, 0.04784111391927581, 0.03131427554762922, 0.020892807806376368, 0.04468953557079658, 0.06488308441475965, 0.020231402086210437, 0.04299036991142202, 0.029846183133486193, 0.06648444614256732, 0.042610089731169865, 0.025080914128920995, 0.03952336024667602, 0.014539933708874742, 0.026836648139578756, 0.03815073585428763, 0.045580561782117, 0.05096502500236966, 0.03450812662777025, 0.017883289510791656, 0.06707016393193044, 0.017706289145280607, 0.026552424133114982, 0.07193042227299884, 0.06756447139196098, 0.005190457932258141, 0.0076296102270134725, 0.00796693211668753, 0.025836962231551297, 0.05279760283883661, 0.05328755018126685, 0.024056588918028865, 0.08049537049373612, 0.0302769571862882, 0.04746936472656671, 0.005206892328715185, 0.010829053389898036, 0.0736398110166192, 0.02648443969519576, 0.03981211506470572, 0.011643335037661018, 0.0681414466816932, 0.05069463833933696, 0.04370843118522316, 0.011958968589169672, 0.056295671383850276, 0.012487327639973955, 0.05352064021280967, 0.05684158037183806, 0.049951024921028875, 0.061972733747097664, 0.043219578510615975, 0.026356526832387317, 0.06410956615582108, 0.04708667256636545, 0.023145745508372784, 0.011515186542965239, 0.030970312363933772, 0.03520368969475385, 0.04022093453386333, 0.06234723259694874, 0.02887603099225089, 0.044380835533957, 0.03273860907938797, 0.042970532304025255, 0.049697191861923784, 0.04161411270615645, 0.06733464309945703, 0.06247078534215689, 0.05739392749092076, 0.07918265226180665, 0.021671281756425742, 0.047753807666595094, 0.02481181509210728, 0.025046259543159977, 0.022855317147332244, 0.02670084995770594, 0.071835397684481, 0.017699928939691745, 0.042346608752268367, 0.038282240711851045, 0.024260950413008686, 0.09063534162123688, 0.040520483889849856, 0.015427944945258787, 0.014190510173648363, 0.016937821201281622, 0.013070717868686188, 0.010612503047013888, 0.050036279135383666, 0.040111909329425544, 0.048908878889051266, 0.04618513383320533, 0.04651686642318964, 0.029810337400704157, 0.019948053814005107, 0.038710697408532724, 0.1262721820967272, 0.129041550680995, 0.19949937384808436, 0.193649765860755, 0.17491745384177193, 0.18854172667488456, 0.18658616754692048, 0.1370230075553991, 0.07603757141623646, 0.08257557332399301, 0.12045684648910537, 0.1904700935119763, 0.1690954834339209, 0.1752794289495796, 0.12418912941939197, 0.09398932219482958, 0.17059782781871036, 0.1556541203171946, 0.1149225102562923, 0.163139495998621, 0.07931657281005755, 0.08411491377046332, 0.13303065381478518, 0.26216921804007143, 0.1474075682926923, 0.14569777878932655, 0.09576433905749582, 0.1580255344742909, 0.11906145300599746, 0.13349093380384147, 0.1469693152466789, 0.21145238948520273, 0.19907692854758352, 0.16906195320189, 0.22995991981588304, 0.1296539412578568, 0.14838490256806836, 0.16557926195673645, 0.12550377723528072, 0.14305650489404798, 0.16048265184508637, 0.1709101680899039, 0.0885048731288407, 0.1033501050551422, 0.12045290568494238, 0.15308063419070095, 0.20701924455352128, 0.1708241828600876, 0.10220771713647991, 0.1332815145724453, 0.13825583358993754, 0.12627388903638348, 0.15693015418946743, 0.11960673858993687, 0.08745893472223543, 0.14402105938643217, 0.13480214547598734, 0.0994106219150126, 0.1008880375593435, 0.09492762692389078, 0.17157483554910868, 0.10753422975540161, 0.15379423886770383, 0.24294642062159255, 0.14981926622567698, 0.21542152884649113, 0.1527864913805388, 0.12072706987964921, 0.18439405626850203, 0.11057632276788354, 0.1581836713012308, 0.14063125534448773, 0.1555319776525721, 0.08488924097036943, 0.12832779757445678, 0.10110804723808542, 0.13471958896843717, 0.13588897621957585, 0.16252259316388518, 0.11770877012168057, 0.07893667483585887, 0.11027672517229803, 0.26202586479485035, 0.13825187052134424, 0.19725001329788938, 0.09765371345565654, 0.08235417582909577, 0.2343534043757245, 0.14368011674378067, 0.12187127606011927, 0.09370982195832767, 0.13023355859331787, 0.15971117449225858, 0.14203009981429204, 0.16790663707070053, 0.15952344081597403, 0.19932108029024675, 0.08819326016237028, 0.17642346443608403, 0.1868642948102206, 0.1819005885045044, 0.07219126491690986, 0.11301436694338918, 0.1716664611012675, 0.08544215583242476, 0.08849397097947076, 0.08431808411842212, 0.1475084261619486, 0.14279397757491097, 0.12902930524433032, 0.058351873158244416, 0.20683792303316295, 0.07771174525259994, 0.15249022602802143, 0.12776842602761462, 0.08334518046467565, 0.16668529948219657, 0.10256091263727285, 0.10029906916315667, 0.10004969270084985, 0.13099963311105967, 0.12546669953735545, 0.1399370058788918, 0.08720333164092153, 0.12440262304153293, 0.10425661617773585, 0.14954943617340177, 0.21265429764753208, 0.16114605765324086, 0.10008994679083116, 0.1589447882724926, 0.1457096976810135, 0.07611580862430856, 0.13601186103187501, 0.07321455297642387, 0.10142056562472135, 0.11797740531619638, 0.24143870308762416, 0.09774492340511642, 0.12445184227544814, 0.14219666743883863, 0.1413993930327706, 0.19710986613063142, 0.13460973626933992, 0.12717294157482684, 0.12556399509776384, 0.22359564725775272, 0.14799024327658117, 0.08686750239576213, 0.13925856415880844, 0.1457718896563165, 0.06280205037910491, 0.1540433629998006, 0.30880117672495544, 0.27582892100326717, 0.14716754289111122, 0.12018764726235531, 0.0784160582406912, 0.16181189770577475, 0.20581766293616965, 0.12609068246092647, 0.2592912584077567, 0.17160226532723755, 0.12719903548713773, 0.06385420798324049, 0.09247478432371281, 0.10748115135356784, 0.22610942018218338, 0.08036665240069851, 0.16553222463699058, 0.12293307416257448, 0.22467014350695536, 0.16671125980792567, 0.17048971174517646, 0.151186881121248, 0.11446122836787254], [0.02304602683580015, 0.06514143344247714, 0.11099205905338749, 0.0390308858914068, 0.041906144106178544, 0.03040531348233344, 0.03189461276633665, 0.035525110142771155, 0.02049294977041427, 0.0343699684162857, 0.038748383667552844, 0.014000776409375248, 0.06800727380323224, 0.014957410330680432, 0.017299360297329258, 0.06503768119728193, 0.045017702141194604, 0.04683778592152521, 0.017509480858279858, 0.026781623455462977, 0.01367344939353643, 0.06500179093563929, 0.02359487843932584, 0.011496513179736212, 0.018135092796001118, 0.02415333343378734, 0.00692080492626701, 0.03536378208082169, 0.06646125402767211, 0.03785229229833931, 0.06500766874523833, 0.03336621368362103, 0.07351760155870579, 0.024080172515823506, 0.06999527220614254, 0.026352049826527946, 0.02424635607894743, 0.02258764303405769, 0.04858801134105306, 0.06719701923429966, 0.014244830745155923, 0.032848127812030725, 0.024769473711785395, 0.11938002731767483, 0.019824569717457052, 0.05232365248957649, 0.03262631471443456, 0.12854781467467546, 0.03229145397199318, 0.02361683302297024, 0.039009241154417396, 0.0578503668657504, 0.0347983323445078, 0.04900318730506115, 0.045244417124195024, 0.025258331952500157, 0.020235860538377892, 0.024584265192970634, 0.037939320245641284, 0.05078978167148307, 0.036975014372728765, 0.013317748216650216, 0.03309781968710013, 0.02413331956631737, 0.03143521593301557, 0.0653820599836763, 0.06756683884304948, 0.007814456948835868, 0.019543414491636213, 0.0576671157614328, 0.06889654483529739, 0.02197863293986302, 0.04160274300375022, 0.03309226842247881, 0.03327520040329546, 0.04865905342740007, 0.0520319958741311, 0.0028067422135791276, 0.026575135707389563, 0.033029330588760786, 0.018380691726633813, 0.060346621394273825, 0.06196291884407401, 0.030775101549807005, 0.07526059474912472, 0.028877600634586997, 0.07608716914546676, 0.020893423788947985, 0.02879736704926472, 0.03240380028728396, 0.04482284013647586, 0.003835197708212945, 0.013516057497326983, 0.06570893892785534, 0.04743837263958994, 0.026551739501883276, 0.049864278989844024, 0.02374089785007527, 0.01809030603908468, 0.03714378617587499, 0.033144014669233, 0.05724833667045459, 0.007050212752801599, 0.08563567826058716, 0.012029185963911004, 0.06538808622281067, 0.01929855214257259, 0.05264082414214499, 0.033651153862592764, 0.07501781597966328, 0.05816666278406046, 0.04875344719039276, 0.04282891197362915, 0.05848803870321717, 0.04085113665496465, 0.053257200052030385, 0.05428076270618476, 0.0436251844803337, 0.05727254552766681, 0.04993511698557995, 0.07148882956244051, 0.027874730913026724, 0.0767725647892803, 0.045729944977210835, 0.02182200267270673, 0.01751775580487447, 0.006782764530726126, 0.03947324672481045, 0.05016278933908325, 0.03594803412852343, 0.09756657047546469, 0.07019474665867165, 0.0299435176566476, 0.009441842084925156, 0.05828142479003873, 0.06003239977871999, 0.027815483408630826, 0.039694332517683506, 0.015450890296051512, 0.02660237623786088, 0.040154404705390334, 0.06433238115278073, 0.0618516412214376, 0.09532620475511067, 0.009729458633955801, 0.0016423328020209738, 0.07497310158214532, 0.010514217647141777, 0.0391108040639665, 0.00917772100365255, 0.05884374266315717, 0.0323271920933621, 0.024588102096458897, 0.027845801996591035, 0.06540892572957091, 0.04040177365823183, 0.03235678894270677, 0.09650610081735067, 0.03073499032325344, 0.02307708014996024, 0.038334536147885956, 0.03873561501677614, 0.014894087507855147, 0.014361389676196268, 0.029835390450898558, 0.03390663448954001, 0.026805041925399564, 0.009534440778224962, 0.015322886520152679, 0.07375712229986675, 0.036414217902347445, 0.04361562561825849, 0.0650981068611145, 0.13611593982204795, 0.09837224599323235, 0.01137234259658726, 0.01631786442885641, 0.061355396755971014, 0.05533025228942279, 0.05044145837018732, 0.044858867695438676, 0.0355246129038278, 0.03764282853808254, 0.05328698985977098, 0.03752271935809404, 0.03976208688982297, 0.022972361257416196, 0.03363394345797133, 0.043199944993830286, 0.027285371033940464, 0.13283711654366925, 0.09772253280971199, 0.03571347835531924, 0.056101466179825366, 0.02976243176817661, 0.02426881532301195, 0.022306801365630236, 0.048847573780221865, 0.00702185482623463, 0.011877581891894806, 0.007768013347231317, 0.034366324471193366, 0.009452244212297956, 0.028610123190446757, 0.06776615002308972, 0.030091667031229008, 0.028612843161681667, 0.02864513957320014, 0.028896096810058225, 0.04727250634459779, 0.025224682976840995, 0.04548531083855778, 0.0841639845748432, 0.040984125807881355, 0.05917343805776909, 0.014805166156293126, 0.06593010635697283, 0.07502838416257873, 0.05376184191845823, 0.05630163082969375, 0.03956325068429578, 0.033903346775332466, 0.05860872675839346, 0.04370964459667448, 0.016515342504135333, 0.036835961873293854, 0.02962436632515164, 0.04494733169849496, 0.017485524331277702, 0.03061992218135856, 0.04734927410027012, 0.03976517422415782, 0.022558545279025566, 0.02175768073357176, 0.0893132203782443, 0.012844375814893283, 0.03823327009740751, 0.013586700679297792, 0.027949424365942832, 0.041243372834287584, 0.03803942854574416, 0.05915734087466262, 0.0337972382112639, 0.05358854301448446, 0.00915367912966758, 0.02715218892262783, 0.02631248593388591, 0.023679414625803474, 0.024641017225803807, 0.00946797681535827, 0.025009957389556803, 0.03389548743143678, 0.009910102944559185, 0.05412275204434991, 0.020899646697216667, 0.0112383469058841, 0.039714997619739734, 0.04696872303611599, 0.03552169626345858, 0.03200475490302779, 0.05695013802323956, 0.04538238608802203, 0.023712223119218834, 0.03240274643758312, 0.01646526052354602, 0.04296681043342687, 0.04042054257297423, 0.01039923485222971, 0.03691300793434493, 0.014716561145178275, 0.005045723364673904, 0.04549656921881251, 0.0743129092734307, 0.03466706126346253, 0.053498294146265835, 0.04596560283971485, 0.025300413581135217, 0.024388115562032908, 0.043437343192636035, 0.03844083024887368, 0.033777882999856956, 0.017873556244012434, 0.04447417915798724, 0.09116884190007113, 0.06190998887177557, 0.004747568782477174, 0.05475733654748183, 0.04433090012753382, 0.06179642914503347, 0.04065728768182453, 0.05935508612310514, 0.042037266757688485, 0.06129374654847197, 0.011643529851426138, 0.0342746247042669, 0.025737753785506357, 0.022827742650406435, 0.030073087364144158, 0.042681413833634, 0.060176780898473226, 0.0290653454430867, 0.04995118077204097, 0.003969719164160779, 0.0011254714740971394, 0.02090945046802517, 0.020542957536235917, 0.01899962247989606, 0.03778620404773392, 0.054152757074916735, 0.018028379381576087, 0.012611489873961546, 0.04241862305207178, 0.055579973850399256, 0.021310191659722477, 0.009445281939406414, 0.005622565531666623, 0.04546480158751365, 0.06418772914912552, 0.04344092034443747, 0.07075463770888746, 0.045287131433724426, 0.07387590303551406, 0.07053964494843967, 0.028875832467747387, 0.026665776058507618, 0.030729012323718052, 0.03188870527083054, 0.032145536606549285, 0.12120933970436454, 0.02988257063407218, 0.04118824239412788, 0.04208176593238022, 0.029017636479693465, 0.04387200795463286, 0.056903931908891536, 0.03775837722059805, 0.10104142464115284, 0.016504698251083028, 0.012623967231775168, 0.05101965449284762, 0.07964489894220605, 0.010233727571176132, 0.027917263396375347, 0.055239602661458775, 0.03013134224602254, 0.03730717369762715, 0.05681101501977537, 0.011628327883954626, 0.09835857563302852, 0.03765155248402152, 0.03660977381514385, 0.02858126663340954, 0.08351061260327697, 0.2212732593761757, 0.29900622263085097, 0.08231455998611636, 0.10796953647513874, 0.11573347728699446, 0.10714137388276868, 0.17107161489548162, 0.07911452310509048, 0.15779457811731845, 0.133012990700081, 0.11417803965741768, 0.07828002257156186, 0.20576366427121684, 0.16990979755064473, 0.17461997136706486, 0.2521973953116685, 0.12289546211832203, 0.09521555053652264, 0.18496368429623544, 0.13858205202268437, 0.10463983155204915, 0.15628310531610623, 0.07300077733816579, 0.15910196030745283, 0.08139895013300702, 0.07850476715248078, 0.13324813276994973, 0.1910636038519442, 0.16833503439556807, 0.09627506282413378, 0.11782021843828261, 0.2346987256896682, 0.1532372273504734, 0.08476470116875134, 0.12778822652762756, 0.1419916417216882, 0.12884195748483762, 0.19095906493021175, 0.21707834384869784, 0.1236688245262485, 0.1458751075551845, 0.09593339287675917, 0.18374101084191352, 0.10872312064748257, 0.10851580169401132, 0.11530073097674176, 0.1612500919145532, 0.13158883899450302, 0.17616976867429912, 0.10495076174265705, 0.2001510834088549, 0.1670947571983561, 0.15208683907985687, 0.16513839655090123, 0.17076412827009335, 0.07384767915937118, 0.10688084294088185, 0.16645829135086387, 0.15059417230077088, 0.11529686438734643, 0.20921163784805685, 0.10486761151696555, 0.10722150356741622, 0.13545812980737537, 0.1630234092590399, 0.15380946773802862, 0.15683478821301833, 0.12771083536790684, 0.1379303721478209, 0.18401256267679855, 0.11007542503648438, 0.1917105636675842, 0.13529231917345896, 0.15495899511734024, 0.15638804499758407, 0.140833965560887, 0.13766702846623957, 0.05095396329124924, 0.13190837809816003, 0.2105862883036025, 0.14696754893520847, 0.08623104396974668, 0.19328614318510517, 0.11369963642209768, 0.18992599536431953, 0.16266789083601907, 0.14420046616578475, 0.13747588091064245, 0.1162205265427474, 0.1323556259740144, 0.1218713131675031, 0.1031154379597865, 0.15862518979702145, 0.1212851946183946, 0.15520534361712635, 0.14712461706949398, 0.16671820631017908, 0.08953985743573867, 0.15174565894994885, 0.09129318874329329, 0.2188686266890727, 0.18425154907163233, 0.13909993751440197, 0.1009674028318841, 0.11754019127693027, 0.10450836751260795, 0.1574901639833115, 0.1077145864837803, 0.07208044742583297, 0.08435911746346392, 0.1094983310031239, 0.16888778598513454, 0.08686840781592764, 0.10773369678645395, 0.1617135779815726, 0.12968735274625942, 0.14108942763414234, 0.14146814559353516, 0.16836071270518005, 0.12518465373432264, 0.10040383072919212, 0.21251615427900106, 0.16515277937287465, 0.08497732647811063, 0.0973915052600205, 0.10575412175967358, 0.1108502568968106, 0.09438988156034611, 0.13995637593325227, 0.21180067938985303, 0.127952478651423, 0.16231911111390218, 0.08389889684622176, 0.12185663348645903, 0.17461103590903804, 0.11013503433787264, 0.1866030291421339, 0.1214410678949207, 0.16583424905547872, 0.0798913736070972, 0.13143594173016027, 0.1792101250612177, 0.19320536783197895, 0.1294253597734496, 0.13791860168566927, 0.1798944891197607, 0.0755054218461737, 0.08766692160861567, 0.16696557897375897, 0.15251035307301208, 0.20123522757785395, 0.18560466240160167, 0.13001906307181343, 0.13518734980607405, 0.06043145629519131, 0.09484629496000707, 0.19077625911450014, 0.12133713011280634, 0.09689537953818217, 0.27612263336777687, 0.1143313673674129, 0.13619315286632627, 0.14471333473920822, 0.12116270314436406, 0.17980601027375087, 0.08085088149528019, 0.13066102081211284, 0.13266124238725752, 0.16775660449638963, 0.269369178568013, 0.16861608572071418, 0.13579968101112172, 0.16048968740506098, 0.22462898399680853, 0.1559805020224303], [0.030545735244231764, 0.016298817208735272, 0.023040492269501556, 0.098696468048729, 0.06867211937787943, 0.054674913626513444, 0.05765234702266753, 0.01905034456285648, 0.014257694019761402, 0.061126937725930475, 0.022288312611635774, 0.027173755734111182, 0.017374582530464977, 0.03844735001621302, 0.030443190844380297, 0.06362213098327629, 0.018171832816733513, 0.03621699957875535, 0.02847390012902906, 0.01855034668551525, 0.05920272691582795, 0.02524556330172345, 0.03293376794317737, 0.024508759088348597, 0.029969721035740804, 0.03957189299399033, 0.0092076100736449, 0.0248990990803577, 0.03419655447942205, 0.05269944267638493, 0.04846654032007791, 0.042055787052959204, 0.05459255007735919, 0.035827761676046066, 0.020827702901442535, 0.007928935083327815, 0.02761157462373376, 0.07976992113981396, 0.016400597196479794, 0.016577484384470154, 0.02768647773336852, 0.11189117096364498, 0.03527524015225936, 0.04715243056125473, 0.026369241677457467, 0.029967303489684127, 0.05869097156391945, 0.03271245208452456, 0.04319377774663735, 0.053399696116684936, 0.016313242704200093, 0.07186837130575441, 0.08458709780825302, 0.057405809275223874, 0.016789938999863807, 0.036408822488738224, 0.03727277144207619, 0.014097633174969815, 0.10091741918586195, 0.02370892612816533, 0.009372952226840425, 0.02866940038074972, 0.014434967124543618, 0.026669353210309055, 0.05731206860218663, 0.0206015890580602, 0.013243860921647865, 0.09072215805645101, 0.022726712231815327, 0.05072980871773325, 0.07165273287682794, 0.07014480754151009, 0.04834820116229821, 0.06969000460230745, 0.006369673074004822, 0.06698875775327906, 0.018307215395907406, 0.0571984049747698, 0.034583673550514504, 0.01835580751503585, 0.02882517161197029, 0.10616471496177837, 0.023747705199639313, 0.029686279995075893, 0.011768683780246647, 0.046576019303756766, 0.035739947052206844, 0.06177142247906886, 0.05500389655935578, 0.03141226501611527, 0.014224981077859411, 0.004277710449969163, 0.024232075302279554, 0.07442648755386472, 0.0643233121081721, 0.02868596882763086, 0.030549985895049758, 0.06350255614961497, 0.05015225455281325, 0.06578621876542456, 0.028296031450736336, 0.0693265451991465, 0.019763440868700854, 0.08397675555897877, 0.07314953341847286, 0.03377959365025163, 0.05281179641315248, 0.004411225136209396, 0.013095005579089047, 0.019999133983219508, 0.04748359169752803, 0.06663276435574517, 0.04286529205273837, 0.03523321975080762, 0.018560102216724772, 0.09467236523050815, 0.020597353250195738, 0.021654511074302718, 0.012388443883537548, 0.0450078983703861, 0.037442433822434396, 0.06609721574932337, 0.07113200495950878, 0.04722732068330515, 0.0073746254474826856, 0.04318371051340364, 0.03140497341519222, 0.0707617103762459, 0.04242482369591016, 0.005690652014891384, 0.01248956614290364, 0.05161420383956283, 0.04100804893823806, 0.039348773716483265, 0.06510368039016612, 0.03260446959757246, 0.03393712191609666, 0.055433117668144405, 0.021550525052589364, 0.010318795320927165, 0.03700432549521793, 0.046362213979591615, 0.03547362735844217, 0.06833519175415859, 0.05463434041303117, 0.032376188682974316, 0.022010805041645654, 0.018633266845426988, 0.05347048587282188, 0.03561003781214822, 0.028304167244641576, 0.04307591727410909, 0.022089853046054486, 0.05494105149409734, 0.025797517082537524, 0.08298158005345613, 0.023274526683962904, 0.022293318397714756, 0.032616581447655335, 0.018270948494318873, 0.046503893681801856, 0.04661275561375078, 0.053696781542385, 0.068673054483952, 0.03793821444560308, 0.04659855090721976, 0.03196617435605731, 0.053729840510641225, 0.008912495977710932, 0.0846807420020923, 0.020513117633527145, 0.021734295660280623, 0.036458479589782655, 0.02193041374994209, 0.01936466451297747, 0.036751227162312716, 0.04626308160368353, 0.046979747639852576, 0.07145823081373237, 0.05543193394260015, 0.054189215079532005, 0.04344802269770298, 0.05173768979148008, 0.0363241731247399, 0.03789417169173248, 0.07075846719089895, 0.021055327015346847, 0.036705666716443375, 0.10135317119420506, 0.05006127466913313, 0.011281569586572004, 0.04751722954097204, 0.018019952294707764, 0.034572715740068816, 0.06118899611465167, 0.04043197535793297, 0.03968315206293482, 0.028298126162553672, 0.038473737076856196, 0.02959631685371278, 0.019508472323650494, 0.04066316920216195, 0.016926844837144017, 0.022814396979811136, 0.03588360457797535, 0.08880390669219196, 0.043613803645712323, 0.020435206970432773, 0.001248219220997271, 0.07993760198587552, 0.06274484563618898, 0.013394946417975007, 0.043015725386794657, 0.05504177577677183, 0.05059697912656702, 0.0651045709673781, 0.01653308168897638, 0.0796013348735869, 0.0485048091650242, 0.07581501617096364, 0.058678611094364896, 0.03226884815376252, 0.036531351070152596, 0.05535100644920021, 0.11704939417541027, 0.044925345573574305, 0.08149404151481576, 0.04561755784379784, 0.010506823073228588, 0.033673473953967914, 0.02385233874520054, 0.03755671343242284, 0.003377245279807539, 0.05607731669442728, 0.03734310106665362, 0.055497061111964285, 0.05037460941821337, 0.00936039787120535, 0.013218745716585545, 0.07111614526365884, 0.0298806187856826, 0.012759569672198268, 0.03626915029599331, 0.04044059540319722, 0.03972345068177674, 0.04693729308201, 0.047571228205924854, 0.02335839864826994, 0.02068524951027939, 0.039751181029714644, 0.06587415584363043, 0.03054298744245898, 0.02772398031083867, 0.0461818646726897, 0.0433915155736031, 0.05102843409986235, 0.05146184834302403, 0.006906325161253335, 0.02091005902912002, 0.07220268656965345, 0.06636448539211415, 0.054940806585364044, 0.010380593957961537, 0.019531198740878608, 0.04573446094582323, 0.05045941834396217, 0.018254038659506477, 0.04308343523007352, 0.039396545762429014, 0.010183379345107824, 0.05793279720819555, 0.04638013313524425, 0.026946771722577978, 0.16830802022013813, 0.046825202807667665, 0.016000711329979822, 0.08437778989900835, 0.010448639623064082, 0.013279719642014243, 0.08346912654815242, 0.040340483392355964, 0.030299546306196135, 0.053305157634895295, 0.03542797785485163, 0.0916210695868358, 0.023487760554417036, 0.02505350661522243, 0.04762202821439132, 0.041522854517097585, 0.020875363625236787, 0.028100737144995946, 0.04924324981402606, 0.033833711058832705, 0.025808239261095878, 0.024733999052841682, 0.05604045793006662, 0.017753050015016925, 0.06787091158912517, 0.03686714691866655, 0.09243827807949856, 0.030756451378692873, 0.023348225658992305, 0.04277656087651849, 0.011206018025404774, 0.040965546140796505, 0.022229948262975086, 0.05884464808332268, 0.042483913493924774, 0.03899188603099901, 0.06268394499784335, 0.03556471856427379, 0.04028612107504159, 0.05878489406313747, 0.0538044968561735, 0.03731699973286595, 0.03947825251088943, 0.07006929401541129, 0.031394850520882756, 0.010335164315620204, 0.018741184394457377, 0.017081282057915814, 0.025780295545700938, 0.051395029076957144, 0.02734906771365786, 0.025000305759022012, 0.03538179771567229, 0.04265181327355094, 0.03864754064125009, 0.07507256421376951, 0.051904988431488164, 0.018213654693681747, 0.06398908590199426, 0.0067972011584060965, 0.014569020331691718, 0.05176376515009906, 0.06358854880090803, 0.035108242082060315, 0.033505366372992285, 0.044327872165013105, 0.0485865864175139, 0.025251660044887103, 0.026730014506028965, 0.005321305061443127, 0.057345391032868065, 0.02387692980846623, 0.05614410256384872, 0.057038230952457525, 0.07218526836368255, 0.037627180354320444, 0.05755299200245645, 0.018296068337804172, 0.06909667979925871, 0.13632059446536005, 0.10106557412655093, 0.15070276334881783, 0.24169778684154153, 0.1444926645490341, 0.1514822558965534, 0.1292864594142884, 0.192120362771675, 0.12743974366458133, 0.18892259686253965, 0.07211126139736734, 0.14592631574487314, 0.12155460164649412, 0.13782994472421706, 0.12496638810262084, 0.15889144269749522, 0.12150516718975268, 0.3155737789347768, 0.09806402464164421, 0.08576845590141602, 0.14808173524215817, 0.09015074887429364, 0.13053736416622996, 0.14255901362048462, 0.18755955359665677, 0.09148544209892862, 0.12372611090540886, 0.08823956275591627, 0.11611029534833506, 0.2004686780855991, 0.1201051427051425, 0.15072004054673016, 0.09357639122754335, 0.15781599649926648, 0.28609309054445475, 0.08900677275960334, 0.08787441867752932, 0.21046935551567003, 0.12492623791331425, 0.10653908393578604, 0.14169564354233444, 0.1785365369869396, 0.17303885542787611, 0.10596555221127346, 0.15298755402909592, 0.0812780691194348, 0.09333990587037988, 0.1129753448185511, 0.20233094925060868, 0.16512336063897237, 0.12872471299488097, 0.12889416015241295, 0.14949880685890093, 0.3160283889155835, 0.1669965562177822, 0.1481167200836353, 0.09624749945942312, 0.09856774253421463, 0.20717313629575074, 0.10727519053034484, 0.10744378421804868, 0.09366015743580647, 0.10024960502050817, 0.1980726543115452, 0.14259454765124246, 0.21324620494851843, 0.07847799788578413, 0.14277232170570642, 0.0953793351072818, 0.17969531152630225, 0.122926097974414, 0.16570686682825908, 0.2809923095628619, 0.15106887964066118, 0.13086046557873487, 0.19557186897145584, 0.11288145571597852, 0.1293513082782738, 0.16300202056299895, 0.11427708668634295, 0.12050780234858394, 0.18045671051368117, 0.1395414856960997, 0.1140644316910766, 0.13731259357882664, 0.1465557757182978, 0.11780629574786872, 0.2799394988687709, 0.12427529276465066, 0.13811003125738353, 0.0728803787205834, 0.13668953091837466, 0.19681184930959716, 0.11994820815743878, 0.15158566675381735, 0.08562182978494093, 0.07753597499686293, 0.20419371023308486, 0.16855292895343155, 0.10861753529752605, 0.16975185368210077, 0.14920693502062932, 0.13136715948348865, 0.162003104633186, 0.10520842057303526, 0.07224821732961573, 0.10685689383535646, 0.2090218261582777, 0.21336714533390477, 0.12951719312695786, 0.10495320340851322, 0.1230190742353443, 0.15263813605997711, 0.09543553795083426, 0.13604270468931645, 0.2273320491076447, 0.10658085200702772, 0.1131485027144663, 0.0868202572746668, 0.12311623620917089, 0.13024728832533583, 0.18194130272604525, 0.15856054873438552, 0.19199526635929942, 0.1721731698489748, 0.09364099518279545, 0.10361002743593417, 0.13941778452135623, 0.14990505849709734, 0.19014314777450636, 0.12756337062455714, 0.09149722740403377, 0.15467083401745185, 0.22119733766885474, 0.13366517523536459, 0.10955436315271072, 0.15332711627706885, 0.15584057749947533, 0.1271013985387981, 0.17686655628494918, 0.2001316539826803, 0.10212462628260255, 0.08168567146640271, 0.10597801287076436, 0.19886399153620005, 0.08431705995462835, 0.10063357738545164, 0.08071995180216618, 0.0701842230046168, 0.22679939487716183, 0.149865917628631, 0.13610347174108028, 0.13991855608765036, 0.1280896126991138, 0.2027834960608743, 0.16582912823650986, 0.12257538866833784, 0.07316880699363537, 0.23090265516657382, 0.12581521208630875, 0.10058084037154913, 0.13367871200898662, 0.12536769703729078, 0.11994803746347316, 0.16379402572056279, 0.10818311173352413, 0.08508434417308308, 0.1395944898831658, 0.15193143335636705, 0.1245586818549782, 0.13683288416359574, 0.13830610667355359, 0.07830253933207132, 0.11040789977414533, 0.09527340836939402, 0.11005057051079348], [0.026246401394018903, 0.038598421597271226, 0.020590879867086187, 0.007034632290014997, 0.0270055052897078, 0.05670000085956417, 0.06081799649109598, 0.018192548013757914, 0.055060270096873865, 0.036094341121497564, 0.04526062562945299, 0.05602470955636818, 0.004908799901386374, 0.007426462143484969, 0.027477852599986363, 0.012286184282856993, 0.05493685835972428, 0.045331574947340414, 0.025055332298506983, 0.06337952290778048, 0.01630846698390087, 0.019521764188539237, 0.04533065468422137, 0.04957281533279456, 0.004268723969289567, 0.05618397073703818, 0.022207581787370145, 0.05978562083328143, 0.04251825266692322, 0.01222330396558391, 0.02853818681614939, 0.03229915375413839, 0.012384689543978311, 0.058594091606209986, 0.06016604202159215, 0.0444700045773061, 0.05011572233343031, 0.06907142451382242, 0.038985073115327395, 0.048446209184476174, 0.03237225530028809, 0.010392311542091193, 0.06732080204528756, 0.08016562685952522, 0.08431329726590775, 0.05258874763967469, 0.048641434841556475, 0.04858807071286719, 0.03770792231080122, 0.03230670881748665, 0.05144165450474247, 0.0362292487261584, 0.04300031840102747, 0.044367131777107716, 0.03694601124152541, 0.06798894275561906, 0.02379587800533045, 0.061566322547150776, 0.02073445575661026, 0.01077448605428799, 0.010997818699252093, 0.05150723438418936, 0.07082119351252913, 0.06559660003404133, 0.016722353466320783, 0.07459644679329358, 0.018173164971813094, 0.033771478265407495, 0.030194786595529877, 0.02013455181440804, 0.03384950767213013, 0.03242520753701683, 0.023997591888473835, 0.039335392793873325, 0.03389270066691097, 0.026868701497733127, 0.030711924373463262, 0.05608152467175387, 0.026667703787097707, 0.029923644797236193, 0.013889510846638586, 0.013145044886186952, 0.016348925164493266, 0.015296902074624086, 0.002698147222872649, 0.020363884723337833, 0.06960277998587117, 0.04150680928432848, 0.024353431290364824, 0.04067035319167189, 0.04762274809763767, 0.05061114301497582, 0.03884710415150039, 0.009220947395078838, 0.04412143265653867, 0.010283742758474546, 0.026877957934630103, 0.01873185745353112, 0.04429035288922023, 0.07244145032018423, 0.018568148952908814, 0.019525833013176452, 0.01947977903910214, 0.016992151977319736, 0.06866030438686721, 0.00619185031609959, 0.05273144779494032, 0.016513138325535692, 0.013702211326744873, 0.04889007286692504, 0.007022587233223021, 0.03945433309127111, 0.07501186395529658, 0.02173083725210745, 0.024060214309429284, 0.05610310261545237, 0.04675771931943018, 0.025548461599100847, 0.03306747697934043, 0.029565178192569874, 0.013194429247960215, 0.0447217113833176, 0.027903654263354838, 0.01612002084584674, 0.005278656617520028, 0.03542387377819978, 0.0726953538833186, 0.06044158661097754, 0.080939805629896, 0.029815949892508797, 0.05264214887574781, 0.01462595419070567, 0.08807030113530345, 0.039513749434263445, 0.037084985815454274, 0.019251724479545373, 0.041937210407922976, 0.06481662509031594, 0.05235477816313505, 0.015188139404926915, 0.02426310078590177, 0.04787760160979815, 0.06430763052776456, 0.008721401300135767, 0.015021641356725013, 0.03344327458762564, 0.026588735563564114, 0.037439034786075354, 0.02628607104270486, 0.007599451200803742, 0.017516753905510996, 0.036887774913338944, 0.07020212360657752, 0.07842729435651563, 0.0048522964880248765, 0.06400418860721402, 0.03321682677778881, 0.015560754127363907, 0.019133780515403487, 0.08537690620869398, 0.023766737576806918, 0.05712258345738519, 0.05616402180748992, 0.024830929105519317, 0.045665611905860715, 0.04610112271620892, 0.013337699929252267, 0.005432803473013337, 0.05629501087241806, 0.04500013550568838, 0.02937063531135209, 0.02337457746762084, 0.07361804382526316, 0.014740841434104368, 0.025402637002116535, 0.00856429049235885, 0.017022238644130994, 0.047999670059653, 0.02140247215720592, 0.02639806112711085, 0.011394045777706197, 0.051709454783122055, 0.055203842275659554, 0.03766056215681601, 0.024613251625851262, 0.012936709190398687, 0.05855501382029615, 0.07112101375241764, 0.01774225733242929, 0.006635123063460924, 0.011721348673745524, 0.015765610078233294, 0.05058319744421169, 0.014730727816640865, 0.010727043336373754, 0.037254369890433736, 0.03037576487258775, 0.04841342852159869, 0.023624753594049253, 0.04420361066877376, 0.03219014710339252, 0.012958070983586367, 0.033603979245526716, 0.04936338125844486, 0.0589170371677028, 0.01600863746716641, 0.04336531404987909, 0.024817347803036682, 0.026645309480954893, 0.013940399912826251, 0.011952602817473235, 0.05406513169873506, 0.06566473661223426, 0.04524061732809059, 0.05888918436539825, 0.015157479429035448, 0.006976759150347789, 0.022647001860605087, 0.014120565538178198, 0.07540749546024017, 0.10742960177594796, 0.04001196430181153, 0.05101485279737972, 0.014847974161966704, 0.036330525908851996, 0.020369051926536486, 0.019894801007467322, 0.010619888344081119, 0.04916019977827091, 0.076278821361484, 0.04978576718713157, 0.027248250662523787, 0.03298183684819378, 0.06763676399714313, 0.04835647610889282, 0.05490992210980039, 0.035017447735299356, 0.025218896080332343, 0.04724749225715641, 0.07064604666084051, 0.07093612992321141, 0.0561176153132692, 0.060265293141128495, 0.03221618535462767, 0.039309480707743205, 0.03763047920074314, 0.004108632974748616, 0.024049093226494733, 0.017118899668275844, 0.02530314653995447, 0.02590093165053986, 0.01997871007915819, 0.06970421673031524, 0.07100879360223189, 0.08279400222818367, 0.03837178082903847, 0.02052159295999445, 0.013453589072014438, 0.03487915593723301, 0.0077044984936947, 0.032226716430159286, 0.04047557282319758, 0.06669361304375343, 0.016359673318220302, 0.05485359681188129, 0.045238888124004006, 0.042405809872434475, 0.05293049922329374, 0.058096652282983996, 0.057632457464933395, 0.0722477571980562, 0.04470626729016658, 0.07214094730443321, 0.0069190019712550566, 0.040691986796446145, 0.0802553302492015, 0.03005425907758763, 0.06265595860895701, 0.015350537087215343, 0.018425263260724023, 0.035027485282626, 0.049318882083753124, 0.021189783765294123, 0.051927367894677445, 0.044153051858302206, 0.04049434915941674, 0.02301272481417982, 0.04190031824691687, 0.11739804773242213, 0.02511006754502887, 0.04753354565764312, 0.049547044254723005, 0.05592889086983632, 0.04465243931917939, 0.025859508677967824, 0.022292062312772032, 0.009377361511724303, 0.05473705365147907, 0.009423484134458704, 0.0265369280896266, 0.05077284586150199, 0.057266344883828424, 0.03126055147731677, 0.12205368853756227, 0.05621831733151339, 0.059999136719852686, 0.043681602546712384, 0.016847225379024167, 0.044144008788862266, 0.04462923236133065, 0.06967856810661033, 0.038654798845527694, 0.020765330955327954, 0.06700763799017295, 0.030282719962997362, 0.01768741632986348, 0.09155587933491915, 0.04286045324988663, 0.019649224341264926, 0.0014945823318157636, 0.04508486279519275, 0.043035084308939986, 0.007605411574331811, 0.04006619674328249, 0.05851496011018753, 0.0058397332486492814, 0.030577823854400776, 0.0522829939291114, 0.02643473620992154, 0.07209226241684519, 0.03433854959439486, 0.015400900156237185, 0.021409658002085052, 0.041126113501377404, 0.023538998430012725, 0.028581719343492296, 0.07301636243937537, 0.06827812801930122, 0.06338627645163797, 0.02215729015006218, 0.0431349402788328, 0.05562016485782806, 0.0350363168399781, 0.026847674598684534, 0.05882363417185843, 0.035374398503336124, 0.07431970734614879, 0.019850338940159418, 0.06802586460253224, 0.030297273478936404, 0.026006722946476657, 0.05588960528257303, 0.09249414695659652, 0.10678927676053718, 0.11525666966917925, 0.08927912611397915, 0.07353387685725465, 0.11751615311368369, 0.13367877138080075, 0.17612222669413313, 0.06883820460643619, 0.13415220222668722, 0.17009999515721574, 0.16572316439123824, 0.11250354669755325, 0.04570753953885287, 0.16436923469882458, 0.08758660638704896, 0.1281902627670206, 0.10347718300181441, 0.10907458694418892, 0.1485395958297886, 0.09398099529789761, 0.09982261777622625, 0.10026112315244973, 0.14393746387213469, 0.15281113068340346, 0.14240930759115145, 0.2173713140655309, 0.10044957671198063, 0.18449620547471568, 0.10914359183516353, 0.10364261514041573, 0.059620136744342744, 0.09379241557326168, 0.15739954775199294, 0.11323327082209289, 0.0954377198650036, 0.1478214343660511, 0.11311106878565624, 0.12979638908291236, 0.11399330425774679, 0.08511025996995158, 0.17832297657150775, 0.12136946548707783, 0.23099206911865622, 0.21674804360372946, 0.18972937075886875, 0.13103867007885128, 0.15259938110830262, 0.13796848885249346, 0.14221398916561157, 0.15336823125835508, 0.1110862079076469, 0.11124271200969815, 0.17614386772038415, 0.16347010794561356, 0.14934233244275674, 0.11651823166175745, 0.2026948390994221, 0.12936276703840122, 0.09397013767738827, 0.18176133191445842, 0.1242524420376867, 0.15331470756791532, 0.17463836178649217, 0.18856547540053725, 0.12833888526074588, 0.0781716319033876, 0.0956036195566412, 0.13343516882741824, 0.12992714066058397, 0.1555313987773843, 0.10365780690335669, 0.11639166579698212, 0.07471161326975562, 0.1565916309482418, 0.12864349235314876, 0.1352053988375701, 0.11516293641761877, 0.1390615091077052, 0.15519582928391173, 0.14949931151932105, 0.08978098863735795, 0.12606853677425534, 0.2586399792926386, 0.11916122733964585, 0.10737909120507538, 0.16164227243280038, 0.08821156152407639, 0.13873343530576676, 0.11997021283605136, 0.16021521150832996, 0.14431466785026714, 0.2063306502532214, 0.14540442265570164, 0.12308628312894143, 0.11746402466087602, 0.2274580064113252, 0.20279306976590306, 0.12710169539786875, 0.15179703041212633, 0.1093929608759936, 0.19189801532775164, 0.05901062198972795, 0.10044879003544338, 0.17542891233460978, 0.18209323519840837, 0.1154542293807026, 0.13337521813809872, 0.10926948234555312, 0.13719065871555358, 0.14844325021840632, 0.12903602910228074, 0.16331062040990219, 0.0887364603113383, 0.1790608643204905, 0.1400472890236415, 0.1028005001717247, 0.19003746594535187, 0.18161526240874082, 0.1468476327136159, 0.06540842849062756, 0.1710065285442397, 0.0878081597329583, 0.11093236069427803, 0.09446086798561737, 0.2225141748203896, 0.20320631243521348, 0.33352045342326164, 0.10043084490462206, 0.1909538995823823, 0.15811205405043438, 0.07746595336357132, 0.13162707444280386, 0.19855203718179837, 0.20223295607138425, 0.12886607728432864, 0.12335684048593976, 0.1888861574116163, 0.1106274567428045, 0.10878763554501347, 0.13558910402934998, 0.09345000347821042, 0.10216183756710961, 0.12591359118232504, 0.07818248952389695, 0.11746530115487985, 0.07970222242875025, 0.12119188439100981, 0.17511415266199037, 0.12980318715563044, 0.16088777541881427, 0.3310865949606523, 0.142520199296996, 0.23313925077673048, 0.10386917056166567, 0.13370366301387548, 0.10701762075768784, 0.10624894872307777, 0.07421743939630687, 0.13081322045763955, 0.15397930081235245, 0.17423377255909145, 0.11121018367703073, 0.1509909689775668, 0.14041307877050713, 0.1168563541432377, 0.13679349096491933, 0.10156444579479285, 0.12271647836314514, 0.13869905902538449, 0.1369988135411404, 0.11977309099165723, 0.18434078490827233, 0.09995945496484637, 0.08313314887345769, 0.14053577062441036], [0.00854525718750665, 0.04069838410941884, 0.011473793256300269, 0.043956011650152504, 0.06266956959734671, 0.007960681377880974, 0.03528958586684894, 0.058246387998224236, 0.04196791676804423, 0.035097466097795404, 0.050175179494544864, 0.0394126169703668, 0.032987762897391804, 0.06468703868449666, 0.03564923434169032, 0.014839389368717093, 0.026743289672594983, 0.029430478389258496, 0.032001734361983836, 0.045893005953985266, 0.012227012848597951, 0.06050666554074269, 0.11857034420245327, 0.01573811907292111, 0.04860523287788965, 0.07511983159929514, 0.01752248699631309, 0.026038036012323573, 0.058372438070364296, 0.03755508812901098, 0.05224416105193086, 0.03176668134983629, 0.02510539943614276, 0.040348506008740515, 0.04419283468450885, 0.03070043407205958, 0.06433026603190228, 0.05341039788618218, 0.008797438040346606, 0.02820659523422364, 0.0014010264999342326, 0.028716946071654093, 0.01014319761452498, 0.11100451971287839, 0.03896864196576644, 0.0438291303726146, 0.05551813810598105, 0.09007268978166394, 0.050046376054524444, 0.08347363880602643, 0.06798565504141152, 0.046225458427215926, 0.03285701503045857, 0.011621973244473338, 0.010111100655194605, 0.035789177418337204, 0.019952146758441813, 0.05230553666478954, 0.07021134108072147, 0.030731893712072633, 0.022886075457790866, 0.04681510959926527, 0.0389248292776756, 0.07893081186921336, 0.07622154240380041, 0.013200112243794138, 0.10117759389686398, 0.03125003524473868, 0.03473219585430343, 0.08243141855928116, 0.009166958006971981, 0.0624357040214818, 0.025564903880876955, 0.01832280606322456, 0.028442631592042744, 0.04533772364084143, 0.03599798808863852, 0.03707561991177499, 0.062122573363012634, 0.011048640044464264, 0.02593112592876423, 0.08021109824767336, 0.030680691088491585, 0.0014937582000129623, 0.08381202846067026, 0.02149195846868679, 0.06116379277955275, 0.024887319341360126, 0.04823282688448671, 0.10678419304895215, 0.045406858407659456, 0.016408757110184524, 0.03558856747986283, 0.0116736155905528, 0.0035953084443463013, 0.0458370925480267, 0.012177134958619718, 0.00805875526566524, 0.03540831465215888, 0.04521541399299167, 0.04125695413677022, 0.07490707270335406, 0.0755516799108591, 0.04287899580958765, 0.03148414944007527, 0.048944190275506116, 0.03973832703195512, 0.08990513510070741, 0.09184306079987437, 0.03692939084430691, 0.02602795579150552, 0.009615163253329229, 0.033880841147038154, 0.031321474380092695, 0.04296616476494819, 0.054345696917152964, 0.04277208943676669, 0.039717765830573626, 0.0028445506950447452, 0.009872225582512328, 0.009652147255110322, 0.04721827761386521, 0.10953750155749731, 0.041425540402997285, 0.047909499116940424, 0.021197947389737237, 0.04635486671759281, 0.01871221094916109, 0.010935496848105686, 0.05877807743672747, 0.006027466924933833, 0.02868944578949595, 0.09130593884037808, 0.030824782770650927, 0.012975876034033718, 0.03612772292399313, 0.040487673541065305, 0.05177272658329457, 0.010688062029657885, 0.005933524016654701, 0.018273920795763843, 0.03700238106830511, 0.038338402737281285, 0.025210392923327163, 0.04850385550525971, 0.0656635565974284, 0.07076670503010973, 0.014358426651597256, 0.0097201854987361, 0.03556520467100199, 0.012161878257757053, 0.042040135158458725, 0.051532370925997384, 0.09256728561013006, 0.07455958431819454, 0.06312273981166072, 0.07430473080603406, 0.04550129298877437, 0.021814126630488317, 0.038410320557886735, 0.053379175733425654, 0.009883779894153122, 0.02216409564425703, 0.031078910833457485, 0.061841143542551436, 0.02508959540136857, 0.05706705596821848, 0.009234890494553838, 0.04768490667629521, 0.027006421842088457, 0.017379239507135935, 0.09265998727642, 0.036190772079862654, 0.05833582050399855, 0.04008362979220692, 0.058571081317495555, 0.017305173169006594, 0.05496500802109949, 0.010612846290314337, 0.02137621311703697, 0.008176361552614253, 0.005413509488789714, 0.08838331676088274, 0.024269472123705782, 0.02086616284941556, 0.05082597992441151, 0.06867243107990362, 0.03581954981200397, 0.02778684578515822, 0.03154854188323952, 0.024599492207926232, 0.022613801884290297, 0.02183089545724215, 0.043148005788680166, 0.027594596140261274, 0.06838375047664158, 0.030718985908606555, 0.08316512059536763, 0.04960690588632133, 0.023658632635488175, 0.020610051396943163, 0.095776027883403, 0.013902030877943616, 0.013886161905247718, 0.03710398850671481, 0.020311685766500887, 0.014771795486012707, 0.04907357259071432, 0.046105820511002094, 0.015800337023392785, 0.02353176434553461, 0.018892497173510492, 0.060292778580333106, 0.022434999955294188, 0.042431907495483756, 0.022180174273671582, 0.029201934012235142, 0.03878360228554811, 0.05386296696087811, 0.011949806776101468, 0.04244161107635591, 0.034633308387128636, 0.10227917853626423, 0.044708605055348016, 0.027367723450879566, 0.10726347944000736, 0.022288368272711523, 0.020487559922912624, 0.053835051076021045, 0.010868563476833515, 0.015021504987089429, 0.05212848620431032, 0.005063263561169151, 0.04268228214641567, 0.05035597409005277, 0.029700204540858977, 0.029160880258132238, 0.07291232817806304, 0.020273459595046006, 0.011978875772911124, 0.04236977118125651, 0.028151010228611995, 0.07429479344864376, 0.004930065215376089, 0.014261377855291357, 0.03100627684034407, 0.037945149815641344, 0.01395406006849953, 0.0743290212994907, 0.06386217864928767, 0.0097001781250583, 0.028043113088642713, 0.07180646134656854, 0.04466492966457736, 0.054955233936198056, 0.026533007694524713, 0.05823600535222795, 0.11232249977183528, 0.046866399425198324, 0.00928652170841815, 0.10649281844962388, 0.027840835173265077, 0.027434169787738938, 0.02942433155112667, 0.02305160407559015, 0.061029530843370594, 0.06932246338692494, 0.0465587049984606, 0.02041034873400349, 0.057050992181757465, 0.05896289076190442, 0.06650987212196924, 0.044785398786189035, 0.07563521605334245, 0.051970193526358344, 0.011167921729793306, 0.029749078676104546, 0.10658439947292209, 0.03082972176343901, 0.015313079966290388, 0.059647058151313104, 0.012683067234320333, 0.010693613294279203, 0.03140777502267156, 0.03960498906963039, 0.02041569405264454, 0.022866291656100657, 0.05079351096355822, 0.03460621999693103, 0.009139170142589137, 0.04022123510367237, 0.030364886843017302, 0.02972007183416281, 0.055980121323955245, 0.029732669790973887, 0.03546107021975331, 0.10317483203834854, 0.02079275331198005, 0.03303284836874809, 0.02910418203100562, 0.04395784475491382, 0.04368248199170921, 0.02257601729070302, 0.01616359419131186, 0.01523800801805919, 0.0723111440311186, 0.06126814987510443, 0.058327760780230165, 0.05257593446003739, 0.03378371999133378, 0.03778067133680452, 0.04541701098787598, 0.065824498742586, 0.0885529642982874, 0.073851879715221, 0.03519802339724265, 0.030738919995201286, 0.050500622382969595, 0.00826267239972367, 0.038340629180311225, 0.06465636572102085, 0.09682485324447043, 0.011544578374014236, 0.043233523465460166, 0.03705094721226487, 0.047327462380053475, 0.015788147247803863, 0.057880045351339504, 0.04851565194258001, 0.0669684971217066, 0.022440204265876673, 0.027532342937774956, 0.03605707788665313, 0.03118342749075964, 0.013075716233288404, 0.05098363435536157, 0.019047919595323037, 0.0761921310913749, 0.054629802179988474, 0.02153460227418691, 0.03260415789554827, 0.050372219702694565, 0.038978267621132545, 0.013399543095147237, 0.026616438080964144, 0.02115123290423071, 0.036582889515557326, 0.10071942902868614, 0.015492312340938952, 0.06434093811549246, 0.05120164765685331, 0.038928829453652725, 0.12929644872201607, 0.15161271061515436, 0.16549474617931992, 0.09406980811036192, 0.13242663466371596, 0.1222681172657758, 0.15548836905509233, 0.11266752422670834, 0.09340730772237293, 0.17319133708951995, 0.11640826764050871, 0.1478143988060765, 0.08101131155854091, 0.08453609741991386, 0.2061448313179426, 0.11076865033828653, 0.1441700677969493, 0.11225198832107708, 0.0875986366008874, 0.2459689654642716, 0.1317755485069938, 0.23006713046925142, 0.29055699007585645, 0.1729703848832287, 0.13327474618563429, 0.23466620477847755, 0.15198938024695963, 0.06965395848965272, 0.19834570528473705, 0.12483385537052527, 0.2158708992647007, 0.11871397204231471, 0.13074540300294757, 0.1038268681440968, 0.1682720409007743, 0.10671742202248424, 0.13864026608644053, 0.14131165633443743, 0.1652423565974459, 0.139892477018293, 0.12353825848549604, 0.200608127634041, 0.09098314912989736, 0.16680189088219777, 0.10138123921933584, 0.19276528910268098, 0.15004766959464177, 0.17333862371742725, 0.23195858288090676, 0.20149183255853131, 0.1583651709370315, 0.11758311709854752, 0.14099272579187527, 0.13172977283829823, 0.05018466414185241, 0.18302417040104046, 0.14249934494728222, 0.16884628508705646, 0.14840045798337087, 0.14876391738653183, 0.13115650828694925, 0.17771297571016476, 0.1038198771129828, 0.11022357997717336, 0.23534215288236737, 0.13116195565089583, 0.20948942372342572, 0.1295049922191538, 0.1598631960223429, 0.15102674049558118, 0.1374709975789301, 0.08483786950819194, 0.24799672071821988, 0.14799693744862452, 0.14680921914987266, 0.05769056762801483, 0.14031925646122545, 0.14424266468267888, 0.18542161909863353, 0.06742534096702002, 0.16226613661274314, 0.19858519633999094, 0.25821852847002447, 0.07139948240364902, 0.24388658814132214, 0.15192522900179029, 0.17772023391444236, 0.12034933897666633, 0.0947224379342515, 0.12627127667656168, 0.10053523539681919, 0.18792728777043521, 0.13705328718060628, 0.18671531608561054, 0.09947063939762302, 0.10727827044320293, 0.12728404108202085, 0.13169011246645823, 0.101992442359915, 0.12414543176419102, 0.10869300429476425, 0.25817272311542183, 0.179984541318845, 0.1543016600771807, 0.1537216271390207, 0.09295933254179545, 0.08001249210792594, 0.1619959354866296, 0.20573144021909684, 0.11678642156766728, 0.09135607833741233, 0.11857151679578237, 0.13791854231385514, 0.1429373605060391, 0.1313392844167538, 0.12262027375982143, 0.09622124969610013, 0.11622788122622296, 0.09154045008472167, 0.11444600691902451, 0.20743484725244343, 0.14958102197851986, 0.2165424093254842, 0.1341149612562731, 0.17314539814833552, 0.12564667034894228, 0.07610087661305442, 0.1454306798405014, 0.10933221608866006, 0.15665750397602096, 0.13131880114087835, 0.19808107026619837, 0.1829504602937959, 0.13549747847719118, 0.10895559840719216, 0.1088487588276621, 0.15177071385551244, 0.1633683594991453, 0.17619678284972906, 0.1147912911255844, 0.08310216420795768, 0.12376893282635137, 0.17157848691567779, 0.12092832548660226, 0.14833997294772416, 0.13479950343025848, 0.13896403543185443, 0.17062392173102126, 0.11004473723005503, 0.20328532147686929, 0.0874623931304086, 0.2957557048648596, 0.1750039288890548, 0.20845945633482188, 0.1613775483565405, 0.2100526841240935, 0.12892409838968888, 0.07456587030901574, 0.1457481409306638, 0.1572322825086303, 0.1398788660299033, 0.19505114847561345, 0.1476733759045601, 0.14791396533837542, 0.1517201290698722, 0.1477633390459232, 0.16217983968090266, 0.13470575533574447, 0.09581946578691714, 0.16046389035182074, 0.09195741833536886, 0.25123812491074204, 0.0812263933767099, 0.12387134920572862, 0.1817351786303334, 0.18574580404674634], [0.03233133698813617, 0.05064143748313654, 0.014593947216781089, 0.014669684314867482, 0.007277876757143531, 0.06129131230409257, 0.004133894753977074, 0.03405165385629516, 0.10682930078473873, 0.005998738388370839, 0.01801448637706926, 0.08548265483113937, 0.010017880413215607, 0.009943393833964365, 0.014993976874393411, 0.03708687458129134, 0.015414873869303847, 0.04986011925211642, 0.024814811513351742, 0.02484030985215213, 0.07350088097155094, 0.010528802704357076, 0.005181716824154137, 0.0137578891008161, 0.029310797799553256, 0.005340445050023845, 0.0781198893673718, 0.06860994966700673, 0.020765561021107715, 0.006041418373570195, 0.06244860254810192, 0.05747225375671405, 0.07568269124021754, 0.06941220388398506, 0.01542180923934211, 0.011906378149433294, 0.06891575903864577, 0.07694341460592113, 0.024878001677279826, 0.057579690765123814, 0.034964016813319176, 0.030638197567895986, 0.025966474422602914, 0.028144397692813072, 0.08747159576159902, 0.0804726904607378, 0.010872000548260985, 0.022786926383560058, 0.0969723699381575, 0.004994239652660326, 0.0203809114464093, 0.01586392980243545, 0.0676117610419169, 0.0606027810863452, 0.04971588285116013, 0.016940168243309017, 0.022684881078021135, 0.046566471573896706, 0.04404501371027436, 0.025930135161615908, 0.10533457825658843, 0.04155421396717429, 0.04003564994491171, 0.022355144865287002, 0.024517052588635124, 0.034810848665074445, 0.11724303534720093, 0.046060987369855866, 0.032376852905144915, 0.023441647208528593, 0.09555502372677438, 0.023023257745080628, 0.037568264961009845, 0.031223573969327845, 0.023129566689021885, 0.05633440407109447, 0.055579699255758896, 0.04073619653354399, 0.022405696254281793, 0.037418436477310024, 0.021102193641127087, 0.048858383161132224, 0.02530368645238923, 0.034053286581183784, 0.042459756587049924, 0.018261886871187016, 0.03692465223139152, 0.047621549529139884, 0.0597315368213458, 0.018827310632332228, 0.04172114895482082, 0.04610156800481491, 0.036791885722777806, 0.047193185600917786, 0.01045095048539224, 0.024598351155873388, 0.04903227207250893, 0.04358224010502454, 0.05203478263865691, 0.03496068085951265, 0.04883464927843306, 0.05014551956264768, 0.02344570675631985, 0.04172970220679417, 0.03902605822077021, 0.024647611207910813, 0.013319575755303958, 0.01449066623536055, 0.12556326779304072, 0.03159102241625078, 0.031225963684846647, 0.041439722845098004, 0.03680557092593517, 0.018039366877928842, 0.03875566784699913, 0.06568524215254001, 0.025867052609100938, 0.010557649984548334, 0.031011124920041766, 0.02593638033431489, 0.06314599129837006, 0.014667122977698455, 0.059305677641532384, 0.0064202606426988496, 0.0513006909750402, 0.021843606591573916, 0.058650676655815914, 0.045418012887239456, 0.0339571858785348, 0.03764239067095332, 0.07475518475985155, 0.04338644299423322, 0.046236701964517124, 0.03294885951618198, 0.05730454693548381, 0.010838973121281015, 0.008934829056670424, 0.04621069339918904, 0.021540678608289454, 0.07507179980166256, 0.009615355284040561, 0.1280989934457466, 0.03197993748472072, 0.02823683218593942, 0.052307685182313435, 0.028947347673238255, 0.03180354011419695, 0.06065716195735149, 0.04683078375819605, 0.04343602588050999, 0.02336269011721015, 0.023116942757042125, 0.039804649059078656, 0.05373331005102955, 0.09724803327117115, 0.041369894170202315, 0.02279607335367473, 0.04290187622245867, 0.024363465126953088, 0.05716714571462944, 0.07182719695265405, 0.016659397078910843, 0.025889714088407345, 0.035745698696700856, 0.09190503755235113, 0.05668294630595483, 0.0441141892952146, 0.022265497136686463, 0.04742589342640713, 0.0496966797800269, 0.06275834530242719, 0.04393634473672137, 0.021292127785272896, 0.02117518386512529, 0.039566352861584164, 0.05881691031390801, 0.019772975610976573, 0.04592434685037006, 0.007704072686465224, 0.03167769042192958, 0.02656419645063579, 0.049900555168278515, 0.029964696695969906, 0.034594219468999654, 0.021829027100466192, 0.04336087229603436, 0.030081653603701852, 0.03849410160910338, 0.0216300814281567, 0.03691893769428134, 0.025737497744557913, 0.03542835263942834, 0.01197204894197057, 0.08598201631684788, 0.0328671453462448, 0.025721780912135728, 0.0052815825347352074, 0.01053041965860757, 0.049420775249018334, 0.044504748220788315, 0.10005209725932218, 0.08105542481644079, 0.06490698899142444, 0.09654150868300349, 0.027480657918204088, 0.010847096855286509, 0.05274114395433571, 0.04354135147877969, 0.05404709751019254, 0.04437866104126442, 0.0539130990364356, 0.0491171106841648, 0.036828744487138465, 0.03273941430961713, 0.012343405724095646, 0.04880125263298396, 0.014146665016596671, 0.05209534559980966, 0.05229264927038457, 0.04506950775976293, 0.04730532782559749, 0.04190762098005507, 0.046776406597928144, 0.014270855081122136, 0.0016335686177626485, 0.035094241466140375, 0.006749744989065221, 0.02776358502160292, 0.048062173736980185, 0.06592301884666085, 0.029364627625909634, 0.01516597516456386, 0.05657920890371315, 0.06468325373134576, 0.04669375361118, 0.039291016073548235, 0.022256684133026283, 0.035101024695904925, 0.056688256372581236, 0.05138402302691247, 0.04393608498503454, 0.07002576705417596, 0.05252982482488733, 0.014537162714987062, 0.028847356261394452, 0.041184654110111296, 0.03092612674663542, 0.05293344183883164, 0.06032184108335059, 0.03836468589724973, 0.019534933599061333, 0.037686604118789546, 0.028610054541786667, 0.012108668124710675, 0.04758409704663791, 0.011160043832205702, 0.10021573340054601, 0.06633272889303043, 0.03040516505279811, 0.007451272604157566, 0.026538256533967797, 0.051817979037878104, 0.03819917583314236, 0.023875710830907337, 0.020165508649370167, 0.030354450391314458, 0.057961214042734355, 0.05231159258983098, 0.029255700756039005, 0.05530406560865231, 0.03618138762249146, 0.03001524066348793, 0.022953022744331975, 0.02473203421686776, 0.03404110422707163, 0.0705435560666956, 0.0006253092226415902, 0.015508509713981766, 0.013989053259138018, 0.008096265264612157, 0.04443204372364562, 0.014279050246841507, 0.04682921411585994, 0.032063770486274734, 0.03056224431929877, 0.04200501301966142, 0.06177584196848329, 0.039837181102484465, 0.03723391258972697, 0.04074499840498902, 0.035188253023079596, 0.02789541827951325, 0.1019156226539053, 0.021923224194324575, 0.046762394849793054, 0.011409987109800568, 0.05855226416315418, 0.0306708836069447, 0.016784953622845933, 0.09607242682250217, 0.010820348925335566, 0.026688515463320073, 0.0432167175313225, 0.017616715631447732, 0.018653113729669712, 0.036772708626813255, 0.015460622635146137, 0.027248053993389476, 0.019716607639566064, 0.0388868943991838, 0.09939912604750134, 0.03990703204181045, 0.01902912470541196, 0.03176293721480761, 0.06553029656060971, 0.05517581135791261, 0.06729481945512816, 0.02421200020762626, 0.04561077832477167, 0.040047049333225004, 0.04493780252232682, 0.032003270607674494, 0.007343545694311615, 0.01280668584513478, 0.022800696933700237, 0.017579511768417433, 0.07073510438203812, 0.038909240465727635, 0.03210979477444198, 0.013342742822715081, 0.04568522686895449, 0.05452074357890524, 0.024037886796577368, 0.041455916507402435, 0.07046131126116961, 0.03705329610966146, 0.01056461132975528, 0.029632739606313407, 0.023470038067898713, 0.028848014917457476, 0.0793369447637815, 0.04229332254908513, 0.020537287527986336, 0.013337498621694976, 0.03521951970469672, 0.007245362803587341, 0.07315581940929405, 0.06406906715710647, 0.04093446499609854, 0.01610883482499048, 0.036976906849304214, 0.057494254724588245, 0.16352367616491392, 0.12364255991997197, 0.14307737408671528, 0.13698809692868963, 0.1105541993456427, 0.1497975064557977, 0.10666654779925011, 0.12210508226417005, 0.15596757380990312, 0.1359123390284367, 0.16991137090371922, 0.18683760717976838, 0.12749785382766277, 0.11381639851606451, 0.13282070023706183, 0.12733257754007354, 0.13071280787698925, 0.11574128468055278, 0.11916090079466812, 0.09586679996573366, 0.15919950819807127, 0.09703421310405247, 0.2106126197031699, 0.1410347016644664, 0.1734592524007894, 0.25423536251764745, 0.16661197529174387, 0.27954372635576874, 0.10159769401070662, 0.18837171548511833, 0.12836491980124265, 0.16865577577846125, 0.21745180740254, 0.16640834481222555, 0.12799337098840624, 0.12550248589832336, 0.11904363404028118, 0.2272863031248562, 0.092367269389797, 0.10389072995167226, 0.1045049239473883, 0.15520173677941784, 0.1362032163888216, 0.17260487715248019, 0.13013917225180194, 0.21148388623259962, 0.11835444602183998, 0.10250001199892722, 0.1710523190558888, 0.11176173298736103, 0.11700289862346835, 0.10734297829912975, 0.18053451727610081, 0.16643837210722268, 0.08029941382119432, 0.08871465601259843, 0.11052550049498677, 0.15750929655041546, 0.20555123192025349, 0.1040080412349198, 0.2081188847660087, 0.11795357495429926, 0.09992300067096949, 0.12571217230288312, 0.12185871149995364, 0.17105329869082198, 0.18500370089896023, 0.12037720662192442, 0.13691547035705298, 0.14401380118215457, 0.21588580159004778, 0.13202722562709823, 0.09738744571222924, 0.16493770497618243, 0.06898599589476362, 0.13621132064145058, 0.15025290311314166, 0.1307102697319351, 0.20381091046147048, 0.14253612578613684, 0.145914307795465, 0.16680083703249693, 0.13654849317390472, 0.09910108696203679, 0.09482115099672228, 0.15198966226307675, 0.09325563500169665, 0.17452564439736307, 0.1364027353702113, 0.1107264740858227, 0.21762431220849976, 0.10268235768307932, 0.11237928891205229, 0.12008948338916525, 0.09170694349450059, 0.13464890682371333, 0.15279311133781448, 0.11940335301915184, 0.11262463551247492, 0.12772851332556456, 0.17075471783755347, 0.10641538276104257, 0.11753441736800596, 0.06568286727997474, 0.12099998726625927, 0.13928048720117658, 0.1522602344630286, 0.11950311250984669, 0.13581758161308244, 0.1345691704773344, 0.17101592413382605, 0.2110821320093237, 0.09617995659937151, 0.1520168545539491, 0.12767104140948504, 0.144537698070053, 0.13396059453953058, 0.09488264535320923, 0.07941282194224186, 0.13206694537075236, 0.20112291094847023, 0.1488257828168571, 0.21016618818975985, 0.19786001415923238, 0.12402598309563473, 0.17965762526728213, 0.14087941468460485, 0.09049048923770897, 0.215088645927608, 0.09622159850550815, 0.15868131100432947, 0.14148102927720174, 0.07539331301813945, 0.1060200778010767, 0.22304212383460253, 0.117860279569868, 0.09707713892566971, 0.15709302591858432, 0.1501942882896401, 0.13852964155375957, 0.18615520239109173, 0.20775278331711888, 0.16872571577550843, 0.15250938828103244, 0.1264034234918654, 0.10550827049883083, 0.15142947435379028, 0.15464303316548467, 0.1153374821296893, 0.15447947866050526, 0.13600794249214232, 0.1786872374941595, 0.11696259258314967, 0.1588165303110145, 0.1579654947272502, 0.13777603511698544, 0.1103521347977221, 0.16129190451465547, 0.19239860877860337, 0.13772141304798424, 0.13120361982146278, 0.09806744594243355, 0.13041737372986972, 0.12928608834045008, 0.16924977593589574, 0.2060661488212645, 0.16093752899905667, 0.11397181908250786, 0.1538855824037455, 0.16966012422926724, 0.2890993229812011, 0.12170015164883807, 0.10471801680978388, 0.12838645692681894, 0.08404766034800559, 0.1578955102013424], [0.05283284743200056, 0.018436718310113065, 0.07579033976071514, 0.055261922752833925, 0.023169768828665838, 0.04929596827423666, 0.012801783032045932, 0.029535282628785353, 0.061271096201380715, 0.06509602142614312, 0.041731769088073634, 0.023234710461110808, 0.02927512276073685, 0.024286543375637848, 0.012808641404262744, 0.09460574263357557, 0.036646361695602536, 0.024165604845620692, 0.054708996758563444, 0.0341066432883963, 0.015912328963167965, 0.04616980477294419, 0.023470795058528893, 0.015358889959316002, 0.012182672307972098, 0.055097715157899074, 0.012260994863027008, 0.03800651800702326, 0.042722840516944416, 0.06450941305956803, 0.0598784709291067, 0.08250515835243277, 0.12092653691070154, 0.02263819256768329, 0.049608174958848394, 0.057984406157629564, 0.038519798472407274, 0.047833644202910364, 0.07247533678309992, 0.0671470801171381, 0.04629525741620455, 0.029269252372614574, 0.050310398801229894, 0.05345022895198781, 0.01690589215286309, 0.021234481464489363, 0.05211961382883601, 0.03406680851185229, 0.0013983416647533886, 0.02836268744431436, 0.004919041539324098, 0.018717083148658276, 0.027446825260994956, 0.033887141980812885, 0.03195910911017563, 0.0015494799231419165, 0.0262188918350148, 0.056668058823561296, 0.04511923165409826, 0.0644339292193763, 0.028536283207358792, 0.03183930792147294, 0.03801052189373877, 0.03507729452394415, 0.05579724871495273, 0.056936282126116566, 0.08698471719981171, 0.021630944174830802, 0.04324051820731256, 0.026424520547152497, 0.05847041269589681, 0.06521486153360456, 0.07532695759437047, 0.05516046745469794, 0.03724093701748643, 0.03442935507337097, 0.023470913802157156, 0.07104592325049452, 0.03660852700704709, 0.053295528268790804, 0.01907376488816226, 0.07658562521100976, 0.03747803835722152, 0.02176651600166224, 0.016380249362555332, 0.06895907819853164, 0.03878180628817063, 0.00908994812562014, 0.039672940110904165, 0.05678534784237854, 0.040228400539490394, 0.027969488328380976, 0.021782303338113707, 0.021919107130088378, 0.03197747726517264, 0.05116756452480331, 0.04565845760225784, 0.04905476285784971, 0.04194079498120118, 0.04979304394510109, 0.07226093774079345, 0.06015071296133101, 0.03568902087863535, 0.06502744698082097, 0.03358089103130624, 0.03983355200034566, 0.006890354607094196, 0.05990474295685999, 0.047117271315073594, 0.038802285853307694, 0.0984908634563908, 0.06529312100610696, 0.03856458337395452, 0.030321267113322392, 0.03179127612384036, 0.01815032537706429, 0.04060929670231417, 0.038131195105961524, 0.03580771626729984, 0.04048464557854459, 0.07563963925349526, 0.037695773353334516, 0.03742318622244056, 0.013713783264392987, 0.047883976658340544, 0.0497603746043751, 0.05646071018418297, 0.0883868864912074, 0.046784922742517665, 0.05035863840021193, 0.02688230135390768, 0.034692179251578636, 0.010464761853654636, 0.0626552090398036, 0.03548971340933349, 0.010087456757901236, 0.016913551116886083, 0.04254452098393813, 0.053507040356635116, 0.03718491971085314, 0.033918816843652166, 0.029822163523931522, 0.05396763946919236, 0.03194158329279162, 0.07142867107177153, 0.024770338313828688, 0.023486738245992456, 0.06528719124617055, 0.05660378883476369, 0.04868923657340929, 0.0535509977635229, 0.0018287521811544138, 0.06367097914335318, 0.09393884873134084, 0.08904331611120142, 0.05304124621034134, 0.029865315700590145, 0.010387807633378543, 0.0012686636500802706, 0.013972671276860638, 0.00986545719570131, 0.02143806927051628, 0.019320579085615464, 0.024325396661879495, 0.044369083625497296, 0.06306137904175557, 0.01991453842492774, 0.03960451780585572, 0.050763702602125704, 0.02200301063567167, 0.024496179685229436, 0.03579095115128439, 0.04590312142681796, 0.037827111227670684, 0.06604800393688492, 0.03344737495353911, 0.013002144351048628, 0.03809447734965943, 0.04029615120089147, 0.03267069885623641, 0.024550439957238268, 0.03955309439334087, 0.04152138877543621, 0.038704444814356975, 0.00545218373190437, 0.030917772019165568, 0.03777561360038817, 0.031448303707293235, 0.06620208121603355, 0.03090005695412401, 0.01784715805115411, 0.034928761087940075, 0.06121698250353802, 0.08688744390383363, 0.06374149059411138, 0.07122340044588782, 0.036558650972438045, 0.012790549699275289, 0.03078648980590515, 0.05930432693276089, 0.035815230512525886, 0.02127903815562604, 0.046104191496851854, 0.058532100010779686, 0.026440973961143754, 0.01301818494539475, 0.09428765071788803, 0.036065653403056785, 0.03312966895464342, 0.05026696089771576, 0.034871842071879655, 0.05092465587949846, 0.017791472855606116, 0.02996961342432769, 0.04502151678025257, 0.055322225962299854, 0.010997493081958964, 0.04887869945378043, 0.04192667933239136, 0.037000570227974094, 0.01739069641189417, 0.043724075658246875, 0.005196745314606233, 0.04924065600789618, 0.027753386057156604, 0.005728818814532133, 0.036322503292467445, 0.024417543572781142, 0.028518651633930858, 0.04404203027661424, 0.01569479805766605, 0.023504184282501228, 0.014841690026514698, 0.00922369797990541, 0.012754885792674031, 0.03566948013030924, 0.04221362331009004, 0.016621426948404405, 0.03662171868199948, 0.07469560514437035, 0.039770907314959913, 0.026219574610877316, 0.02692991569347214, 0.0722429777670186, 0.09274076262954623, 0.05682550916390028, 0.056139015141525306, 0.04709057626314461, 0.058617502654669806, 0.05522426617972087, 0.0032721131037760642, 0.05074253283964936, 0.01871381584351184, 0.012820195715903537, 0.02590515447081998, 0.045911470588180237, 0.040277723674080335, 0.02939445825177245, 0.015435041732416721, 0.06018941225192975, 0.013279381964821368, 0.046080817555775866, 0.05265460582450032, 0.051283977809362113, 0.03916726665920578, 0.10679033061023802, 0.02590049563877983, 0.059450066182762384, 0.04385079366329592, 0.04480743686144706, 0.021175580914132297, 0.035287196151330136, 0.05738048719649669, 0.0051825457103404915, 0.01358117910058354, 0.019430313041084446, 0.08530960825737566, 0.03264335071435198, 0.04304927417251747, 0.03673059916764032, 0.06221117095265072, 0.03877592105709482, 0.02245023068098817, 0.01214901127241319, 0.04589090938679874, 0.03061581253859913, 0.06522314390167594, 0.02053126499959035, 0.047605979270883836, 0.04549173783743754, 0.05001300909498241, 0.004792895451828372, 0.06110095513577107, 0.052499548910418525, 0.04254347826645244, 0.03965720286942087, 0.025410867419850547, 0.06276312473346479, 0.0051840610831277445, 0.04241708309564274, 0.010465755403856747, 0.03754259778361302, 0.021723315585404634, 0.019959323326474987, 0.05232794581388589, 0.021126901592651848, 0.040169577914639376, 0.014773778875678545, 0.0109269064887485, 0.016306012330460362, 0.023304643036681227, 0.07899984644609503, 0.027602937880146783, 0.0353745580650866, 0.011009378577000462, 0.03178370250680018, 0.07491462776670232, 0.039163314722827636, 0.04697922071500216, 0.036123307145317085, 0.05216067314904649, 0.0332723357132636, 0.01380871508445125, 0.033304403914371505, 0.0740241767198313, 0.008831244722387055, 0.034286291265743785, 0.04408291890285909, 0.023051117968861945, 0.09103900316404179, 0.10771377754281275, 0.05880571872694418, 0.02464532353769755, 0.032066056301118806, 0.03413674479816109, 0.05765541580331046, 0.019684962462633848, 0.0160920548660215, 0.011634150960162515, 0.006312008663371671, 0.052294615961727686, 0.025854261693893932, 0.08417526521952823, 0.028034988426952623, 0.06217767411726527, 0.030992682550277095, 0.04221032817440573, 0.008725870884518372, 0.05880148477444891, 0.020961026020813733, 0.05785410357930232, 0.08144990599248558, 0.1430910444469191, 0.0814118560811039, 0.19911372422939166, 0.1257306369370781, 0.07580435150885023, 0.11180932691786438, 0.13884962594602257, 0.12257627924554981, 0.10496740811504424, 0.18293546891072765, 0.13772421836620197, 0.10423049257951789, 0.113499672152102, 0.18658582615898922, 0.05331005209882278, 0.21407463471405208, 0.11984761003986932, 0.15077294083312154, 0.17900854290928692, 0.16299008682835847, 0.07446297895512544, 0.12733937561279163, 0.15822373243281618, 0.1474708438036032, 0.11603151637245901, 0.1253052378888242, 0.14682272623758763, 0.11353386289556511, 0.22890221094712615, 0.16102306894026697, 0.22943612682865933, 0.1807801830000244, 0.24160285131074488, 0.13077961601084098, 0.13040527672274038, 0.11855953111080453, 0.11821751977549866, 0.13178337074350566, 0.1061019441112876, 0.15480400499654934, 0.11815191392088309, 0.128767995047383, 0.14759390673134476, 0.15311325900256634, 0.13240355387097225, 0.11637596195214428, 0.1118867180775851, 0.10343177840695716, 0.1469230794464238, 0.1240792618773412, 0.11816439684480429, 0.058558824748615734, 0.13893555180402473, 0.12799025396816432, 0.13444208510918543, 0.16157185746124014, 0.11051831650547683, 0.09483847272349522, 0.14106694055953994, 0.17876550438813865, 0.19259180466178805, 0.0891491983202286, 0.09575232368661091, 0.32022095925640315, 0.17560457868967205, 0.2213538862997666, 0.2370193917886354, 0.27570127160288393, 0.2290350553812459, 0.1023494970286265, 0.24002865218790248, 0.1999763521598652, 0.15322878170991316, 0.13291958399349824, 0.08536058638128452, 0.1602368673775345, 0.14926099305739626, 0.10481809542397968, 0.14098033192567527, 0.1516070554498583, 0.09789798394194804, 0.12738752615405247, 0.16393444006098434, 0.07300864410353824, 0.1638203125912696, 0.152188528154511, 0.26043093006592244, 0.13209335098508745, 0.05917445108934771, 0.13151362974895164, 0.16611512226518244, 0.11209813368623145, 0.16108530544443056, 0.17322966159554198, 0.18939044675789773, 0.1660875737434253, 0.15446398261701688, 0.09585394596797414, 0.12280176597414538, 0.09303266415372491, 0.16943872673437, 0.1475717016728595, 0.18869251623982564, 0.17436437570722774, 0.1465848827501759, 0.12002286821370944, 0.09633334368118085, 0.12788489868398756, 0.09873049551970325, 0.12219114913023077, 0.15521511028055102, 0.13735731539782137, 0.19006945251021534, 0.07275206880876794, 0.13679766183486208, 0.09788427647436038, 0.13740392227191478, 0.15897089702775702, 0.16899407637538388, 0.1304732426069677, 0.11520645595737733, 0.16286732075968757, 0.15813213656656444, 0.1011594409646932, 0.06144773848063778, 0.10642605484463274, 0.08756823081057519, 0.20130886347033083, 0.1301368122221902, 0.10840084301889874, 0.15985506208380684, 0.10483277510502376, 0.13854797260137275, 0.10876902990275994, 0.10153074486879632, 0.16627895878627896, 0.07992541592102498, 0.1669991240487434, 0.0821369863115251, 0.14455145748797804, 0.14671214623376727, 0.10937683400698006, 0.14522961719194427, 0.18638513458427042, 0.125912893563509, 0.11109066079370677, 0.1525383468833752, 0.13765925075858831, 0.14766712702112272, 0.10796840098919347, 0.1772801106562838, 0.12531395070254803, 0.15276618622010574, 0.23261694208486006, 0.19303446606500074, 0.13498772692400962, 0.11671834436128847, 0.16804693266749382, 0.0822998357762117, 0.12431298644514754, 0.11693522217683494, 0.08663518790854141, 0.12556617701193318, 0.1567515786155127, 0.1444938816712238, 0.12470314832171425, 0.20123991795117036, 0.10583825162029825, 0.0973974795488175, 0.1102296136377845, 0.08366955094970763, 0.10316971864085644, 0.17849910305812955, 0.10961900421534665, 0.1789045234909281, 0.22680671245325357], [0.0531388126546517, 0.046713854681001976, 0.03387835866305977, 0.03789675436564721, 0.022596485723624937, 0.036772764287889004, 0.07308063984964974, 0.019763763702940196, 0.025697288183437195, 0.037483285341295414, 0.008476684597553685, 0.06067488073313143, 0.0787182904605288, 0.007849603207432665, 0.015883871310506947, 0.07667884638067335, 0.027359801024431363, 0.03030421070434386, 0.08528374441084452, 0.05999524044455029, 0.04687966902565677, 0.0313863195333397, 0.05908655482926406, 0.07066674515954219, 0.03996749110228848, 0.01871126842161175, 0.008004086812434252, 0.05286129395244643, 0.02653451982041588, 0.036346359629533254, 0.020917411857226398, 0.050006704550469294, 0.04516695917118341, 0.06973244802793488, 0.032006198380258866, 0.09296818636357784, 0.06115518386650365, 0.07362371383351274, 0.0257057857743348, 0.04302781126170885, 0.04820662165002432, 0.04133051581447944, 0.02376026604906656, 0.04385149499285035, 0.04945778244291432, 0.0930392841110006, 0.04282111200154759, 0.019800106674665585, 0.025926676753442734, 0.04804645504918881, 0.02003964596951846, 0.013178738390706712, 0.024678209956618957, 0.010256087552988902, 0.03208270267350599, 0.0066619266544876155, 0.025969860471377615, 0.014861253039271105, 0.030574599222745746, 0.06831603692262433, 0.03617452646722086, 0.039081355644157156, 0.0456933237001067, 0.019638643170765135, 0.06605593007407151, 0.03810205467743799, 0.035409194097155705, 0.006222687015906558, 0.04048613729537465, 0.0283216021489352, 0.008181861794582801, 0.026104962889803573, 0.04030796990264207, 0.06394876501872204, 0.02921075443737209, 0.06062664855562616, 0.06602199166081846, 0.0367773025209317, 0.054079622132121585, 0.04155508227995597, 0.013831246687914245, 0.056010990956565365, 0.05846778549312148, 0.016990120348054916, 0.0441692752065137, 0.014400069485418499, 0.04683924424170982, 0.01859179748862516, 0.026155870509683155, 0.009435335305170156, 0.021205153643677477, 0.04964089624991175, 0.010290527843608288, 0.03869858926918823, 0.008950155333877774, 0.03897599293850362, 0.019078202931268606, 0.03320696734590456, 0.05172892502741888, 0.023838343695388176, 0.02625636843731627, 0.07795076875481755, 0.029121596526238136, 0.03602287972171325, 0.02557821058871923, 0.03418372645683121, 0.04658500671212096, 0.04057951802678872, 0.030561218300135806, 0.11114697495941073, 0.030125588746159337, 0.0191559095037519, 0.024858527722244617, 0.007716221643931931, 0.029714489028265234, 0.027586423238972202, 0.010934539477602812, 0.02591136253613513, 0.015230361113935942, 0.03827040345640853, 0.031206467465381138, 0.058075660635950044, 0.05616041125904303, 0.011973012806265615, 0.010538499791437062, 0.017348874534945935, 0.04544157607597299, 0.03422426998440642, 0.030008186549821403, 0.03545059480529744, 0.06427446394809522, 0.03982459798862692, 0.03778901678742841, 0.07343724922975525, 0.05099495581816882, 0.1081481046276167, 0.06100465034251101, 0.04101188213098794, 0.048260074836434796, 0.0797447697550524, 0.056730028154561296, 0.022561079713341314, 0.03648817662906367, 0.0251500748709077, 0.07193329438450746, 0.04630613730114419, 0.05870735818461981, 0.08881455651135184, 0.041647090038168244, 0.03214806361938827, 0.01920587645145133, 0.02409844790236093, 0.06627804003073834, 0.08391539478907362, 0.0682429427979514, 0.05013457288441714, 0.10263478601700626, 0.024556338175898418, 0.017499951682111714, 0.030011025264684577, 0.016280356285278685, 0.008824614560580812, 0.039468051691073924, 0.020241864513081964, 0.056885007143137045, 0.033240542106796056, 0.035518145086825825, 0.07779313658829778, 0.0966909401176963, 0.06428900262108073, 0.048218440351774916, 0.04127568594412878, 0.05478104074427392, 0.034295861260034144, 0.020427047056728043, 0.07121951901353896, 0.05010987049899995, 0.04244693598593585, 0.030833282216917723, 0.02977912823553197, 0.028291142552916426, 0.044258054622332565, 0.05525505417608656, 0.016640129069855902, 0.04689801120548509, 0.04426638151926454, 0.04390505579067394, 0.08058367864578031, 0.049945596110774204, 0.048546013204031624, 0.03845496445137542, 0.05654752290865872, 0.011411844334361376, 0.03811993672570679, 0.025532316176395398, 0.10390798488515429, 0.03974293947976548, 0.010204076916124905, 0.04179397219559178, 0.022578811476705596, 0.02950997353764251, 0.02486822759237839, 0.015852389406063594, 0.05693267899914645, 0.025256278058805037, 0.04502047406276688, 0.06007364092511125, 0.04643247681087814, 0.032132292981259525, 0.01073083107257844, 0.04048450085974764, 0.008554192645533476, 0.03564773149264511, 0.04704699735157192, 0.06397717443178408, 0.06223448923265096, 0.025475955626461655, 0.03317095462989528, 0.03451158874668181, 0.11834041200927459, 0.07400537811918184, 0.0719742980436422, 0.06457705239881761, 0.0426832506491337, 0.03952295577619225, 0.017963183563551866, 0.08818246191367507, 0.030698018381372094, 0.006390925400410197, 0.05464517576911021, 0.05646127050567884, 0.08236541936639696, 0.01644013882469153, 0.044336870705592446, 0.007015183846306172, 0.05374234198825434, 0.01914017597300699, 0.01144973097325419, 0.024911127438826952, 0.03762616361200344, 0.05600864576990716, 0.05849192013556603, 0.024645865305501502, 0.02761519259365741, 0.04290471122658346, 0.05175874081032816, 0.08272694918559864, 0.022324518286040984, 0.009227477366948733, 0.07276156087755226, 0.0387185159343062, 0.053927121916785836, 0.02232067952718353, 0.0314476469065994, 0.060191653537913226, 0.03974440893216524, 0.07361348703852855, 0.023726038198219612, 0.010960115741909249, 0.019234291430620942, 0.06106664935941808, 0.01909589016577229, 0.05290836837957613, 0.03896277157764416, 0.06388168971170671, 0.05351591644284781, 0.01779304991941899, 0.06069372015190311, 0.025686532608233392, 0.041106435455731116, 0.0422288373374613, 0.04756502385134809, 0.02790310692944331, 0.07302595840883441, 0.0525941467640223, 0.05785453773569316, 0.016141693413374014, 0.07878029689891264, 0.024435004452243447, 0.054736626916565, 0.057069308386417106, 0.028736677923006937, 0.10843921947525814, 0.03201248437108006, 0.05088941499707289, 0.034464718410163186, 0.04161613505857531, 0.03297929128166288, 0.022104564268374816, 0.025128283559752163, 0.09366750469780527, 0.027279300265945494, 0.038225377356866375, 0.012959033920196816, 0.03454628043982666, 0.07629939369508065, 0.03214167372789234, 0.04351577335910406, 0.04436748429725412, 0.01236709043951123, 0.051979548297822475, 0.023175080750661436, 0.02065597363980487, 0.016135982587002218, 0.055643423766014166, 0.07874683346017264, 0.07973144078277983, 0.02944584826764185, 0.038233834129641764, 0.022747137991245836, 0.03128766955342144, 0.059040074120275676, 0.0463119780033594, 0.025796568988880608, 0.044961885214434005, 0.05229769958532415, 0.02049040049314499, 0.003840044628304895, 0.05176789149118122, 0.08732062808121555, 0.0755053550528828, 0.016665688635839615, 0.07211515767266974, 0.04289114105631597, 0.030110736515780445, 0.03410442055610474, 0.026551442642812617, 0.03332678337756079, 0.02641931252583163, 0.02612351658171974, 0.01849802898505004, 0.08475254478980787, 0.03091608734393958, 0.02743439057667274, 0.05664469972543884, 0.0457616458152188, 0.030276638062787242, 0.021939371472399216, 0.03023721517820377, 0.03825388695986476, 0.06014882048475556, 0.01538648022687994, 0.04469988482014742, 0.07233570911921561, 0.0753198478196282, 0.006282527310759178, 0.06753834779374301, 0.039482063439209014, 0.03971657468355261, 0.03892255088430829, 0.037751063355244696, 0.017688800435280427, 0.14362936868565157, 0.14989315444836393, 0.1463644055183977, 0.13325975480256602, 0.06584576127352193, 0.20866373990429565, 0.14059805165743455, 0.14451663591898978, 0.08752601002925076, 0.05931169645918999, 0.11824690882349387, 0.24004297563806176, 0.1748434320325032, 0.10070027419715188, 0.15437112509971485, 0.24158538115443662, 0.09764481510501355, 0.1250277934013866, 0.2174864211701788, 0.17548991687363014, 0.20027726335683838, 0.10649280360667035, 0.17075467330869287, 0.14523157646181062, 0.16667762567522004, 0.11086291051469743, 0.0737675568962004, 0.1274321143864654, 0.0848280954232905, 0.1869494785205461, 0.13765911717200652, 0.15380203141830862, 0.10298639332177117, 0.16164722997928038, 0.18738802842563018, 0.23845246410928667, 0.17435288726119325, 0.12974473560461774, 0.09874074457911775, 0.18948524870211259, 0.057777202237048186, 0.214194476720877, 0.10313225502613932, 0.27494264824781567, 0.15219237247947603, 0.2132771525066346, 0.12171308728284203, 0.11838986130896956, 0.15841721033211797, 0.19642750587081537, 0.1573203457519412, 0.17588847986189649, 0.09009462024550885, 0.14256205642595887, 0.17528800817672163, 0.20755712350364774, 0.06612071956624277, 0.11304541840218008, 0.16093053796794266, 0.21761372918263078, 0.11485018796520308, 0.07247057219501585, 0.11783992988057435, 0.22258564364165068, 0.12695541809080169, 0.19850007200147957, 0.09083859360544011, 0.08300315428641625, 0.15153810993069783, 0.20005105674499646, 0.23406386288115755, 0.10878889719606377, 0.09274555690353736, 0.17036194360116497, 0.18699289415962994, 0.09748846685397439, 0.15185793105047196, 0.1659786413074471, 0.17413174209650606, 0.10974772230838425, 0.19750243256567046, 0.1011088710220065, 0.11180098517797887, 0.09473286510910839, 0.12307782264542766, 0.11023496452253312, 0.1838073885301128, 0.09700964801595546, 0.17237717140233144, 0.11923911573830992, 0.11565340697416104, 0.2145830207155086, 0.11733089078916237, 0.1435410976409912, 0.10317928492440842, 0.10517616683500819, 0.13391087064519525, 0.1806225805194117, 0.13296316290507093, 0.09347836836241186, 0.1345384752494283, 0.2694208320463076, 0.13145084405550733, 0.1616811312851496, 0.19095729861874133, 0.14845703932223842, 0.22159713262226433, 0.08410389287746511, 0.15921920479740947, 0.16829234606120735, 0.15661848185118288, 0.06534114538226277, 0.10722502876888029, 0.21100928279338405, 0.14844880148302764, 0.12416017081704922, 0.16838339273817837, 0.20906889316393062, 0.10931379598332569, 0.1841791599872522, 0.139208335604053, 0.12075037331669591, 0.10326043877284974, 0.0852509266405832, 0.09035567069076933, 0.06459166528657079, 0.10484505764907226, 0.12610794481588528, 0.14419565704884008, 0.2401826181448996, 0.13300830032676458, 0.13515019789338112, 0.15265287511283532, 0.09650161824538372, 0.11299444769974798, 0.21495547494851053, 0.14501434983685613, 0.18553856672951952, 0.10561700255493633, 0.18097314139595255, 0.10290561054716818, 0.08122784798615612, 0.1748045434942469, 0.3066078631673008, 0.19975229777628556, 0.12276065841433592, 0.1713761774590239, 0.306595335714519, 0.1600806156056933, 0.13257638522190973, 0.12143382453359663, 0.09974720072932541, 0.1725899599841796, 0.1901282009202987, 0.13670214742887765, 0.1461528637446463, 0.1947491685859859, 0.13734891428612173, 0.11555414472240955, 0.17196440370753407, 0.14092945028096437, 0.07009860884863883, 0.05581238852755632, 0.14363754715304822, 0.23443698504706845, 0.131757840863429, 0.18429635994834825, 0.15227184165269136, 0.28592898685019463, 0.25710135872941464, 0.25364577071741223, 0.0913012187811546, 0.10431183196487837, 0.11196733015822247, 0.14984264387749135, 0.2226054886705242], [0.03746681337361224, 0.029726814245805144, 0.019097376316494774, 0.01839210781326983, 0.03185336048773024, 0.009881346577458316, 0.01620044367882656, 0.015077563111844938, 0.05114491417771205, 0.007892815683590015, 0.022766784495615866, 0.04161191594903357, 0.034472496117814444, 0.06753992856829427, 0.07870097615523264, 0.051522708163247444, 0.03174624631355982, 0.02191555038734805, 0.015263639943441376, 0.037839746291865595, 0.020357886314741336, 0.016509867309650872, 0.015889340938883834, 0.010748240929387975, 0.05345011020835955, 0.051582636588136666, 0.022680849360767752, 0.051709729377762415, 0.03566716091881972, 0.04238139692461118, 0.06690919952234253, 0.08158542957971804, 0.0318152808904415, 0.07137364082154818, 0.024559330886404496, 0.03729508040123619, 0.06614690995775163, 0.05815193486341741, 0.02870531847293023, 0.10765999410068616, 0.04337813094025478, 0.01966424912097864, 0.07317461800994352, 0.05523518688278273, 0.06776433176128194, 0.04227115088724531, 0.03227147906727623, 0.021216925961198285, 0.02614076409372501, 0.03072423474804964, 0.029152508832339663, 0.04975494579412043, 0.047367178412969224, 0.03339284936373588, 0.047897932745399885, 0.021154735841264483, 0.03794217009271961, 0.05269692308502272, 0.022442911249527242, 0.056335387416766025, 0.12961815489688888, 0.007643612698302604, 0.05539651865547057, 0.053428406099556014, 0.033531426888657734, 0.02088001318043098, 0.0393418160820147, 0.06749715117621236, 0.036420173637452535, 0.020513379240583163, 0.025335986574646086, 0.06195249537995551, 0.022048550672479905, 0.03744015542906709, 0.038782255287515, 0.014476043143076822, 0.07088820944773033, 0.028492021519923583, 0.05290829787554685, 0.05218015823629685, 0.023637576050532516, 0.03312284861749504, 0.005742106968682492, 0.054039019232732244, 0.01343218924375833, 0.05090854756417684, 0.049796929088188335, 0.043344812220311724, 0.07699364316067658, 0.014831616299488815, 0.021921159168414306, 0.020884848272544332, 0.091789492580574, 0.051612485767691396, 0.036918792975484394, 0.02298039871675428, 0.03709174307005014, 0.03102802362263901, 0.038259427092270926, 0.019209564925404266, 0.06183412653626874, 0.052050133963348344, 0.03332068292365875, 0.04929608330712654, 0.016015621076803654, 0.09100941373617388, 0.07114697407814674, 0.0339719917246839, 0.01170280982478289, 0.02765703116892837, 0.06371895156917162, 0.033159763042931445, 0.0631681147206109, 0.017917624973051716, 0.029831644460500684, 0.008091555409919238, 0.07854476149077527, 0.07790217292495072, 0.004848595490329899, 0.008399002144869883, 0.027839295216836035, 0.003558407702257682, 0.042348408460384235, 0.03456051854300313, 0.011018645218427991, 0.04188824721495621, 0.03252016533224378, 0.05026482351240702, 0.023317441373365, 0.03523678948113229, 0.04833701328607276, 0.08789211147814058, 0.023210848557937425, 0.049617711556493305, 0.09389722166815773, 0.0923561594390776, 0.01579847052198602, 0.04306772767449729, 0.04523674702795688, 0.031171152368187904, 0.02511759477783926, 0.028194654078106396, 0.028111752471886575, 0.018549597116361838, 0.042682478815549985, 0.00852930008477415, 0.026030903973151, 0.02478779362718342, 0.021323513210518286, 0.027909352102142293, 0.04235005231748801, 0.03117888183624018, 0.02631048955663573, 0.014380047268787166, 0.01853139779996127, 0.045268529502209276, 0.026745356553874444, 0.05298480587953236, 0.01482586743804859, 0.06543763942318037, 0.008189735981432023, 0.06609400967136025, 0.11064275982789695, 0.04824740637559444, 0.03991498044342734, 0.065329760836903, 0.07351351974648423, 0.015634441042493563, 0.08164860861143097, 0.03270319379225839, 0.034782550574163906, 0.0540059862396447, 0.03991471698100213, 0.07511475530918688, 0.040255151252495125, 0.007098238984326599, 0.05971621518256143, 0.02158057646738598, 0.07414996332954615, 0.04745150123198982, 0.013951058081147494, 0.031293885040213354, 0.03516620010486804, 0.04873823687375989, 0.024800745959510095, 0.024106463097268716, 0.027880630987056065, 0.034366944164503366, 0.025528661099087913, 0.055787051605875604, 0.01683313570538303, 0.08486066086334176, 0.009094767447095364, 0.06634583522100002, 0.014957962303014938, 0.033593626285437495, 0.03247105370974168, 0.04565856150293257, 0.059429697939776815, 0.03416731386096217, 0.026424988100188784, 0.045172707104939036, 0.013979555624246132, 0.036471307612373494, 0.05576576309977099, 0.05006381652492564, 0.09839076257776469, 0.03085969525272958, 0.02345205397432437, 0.025169046020891983, 0.008947307342168642, 0.029617095133289695, 0.026958143280353397, 0.052668791977339424, 0.046013211613171734, 0.05527187495317776, 0.009684762790129753, 0.001308792502641154, 0.03321952448459342, 0.06395931835868396, 0.07722157897660509, 0.009132553896051832, 0.016876145018613897, 0.05527259854716249, 0.052838903357042, 0.03593988163629547, 0.04691406385973096, 0.02224958734586835, 0.06551141632371582, 0.0637298908259254, 0.02032650645560352, 0.02043239237536909, 0.03752062279090751, 0.05416647567471955, 0.01747332527884282, 0.042543392919469625, 0.07196011560154147, 0.0701334081531968, 0.04922237691062037, 0.06943167783902027, 0.010002762865042314, 0.023745011203573085, 0.036901489802403376, 0.07851875663618557, 0.011421038616390433, 0.028066939739801455, 0.027395149518270046, 0.053239299450069666, 0.012545012923510512, 0.03328562386741396, 0.029067659088468645, 0.020083501331100706, 0.051235367136541754, 0.09045128899742849, 0.059942421794403344, 0.07259198755491525, 0.03760431478440296, 0.03761681255127769, 0.06935096927918494, 0.038025253525120206, 0.005609146110145957, 0.013539513074647402, 0.01723345758364303, 0.025860499445116147, 0.039464574729208834, 0.021506860794033855, 0.01321015721259755, 0.06457343813963234, 0.04494057815463748, 0.01645003165322123, 0.03150904107315, 0.022005793689459097, 0.03982911024650093, 0.03339070826768875, 0.03719151369296014, 0.04832411104871426, 0.004617260638042353, 0.0908241439901758, 0.03305448197352234, 0.06747474573785439, 0.047138674854068086, 0.01903780226712115, 0.02134646969352616, 0.044236157555133104, 0.018780531208903994, 0.04135875824431423, 0.05115413536259439, 0.040416097108391114, 0.04264805800630711, 0.021570743010670412, 0.03442798581090756, 0.03194020289811306, 0.07935525354696438, 0.04115124262170866, 0.016946411560638808, 0.024028865991567727, 0.016885759541764855, 0.02491476210707333, 0.07914648740552366, 0.03174741148541216, 0.022710945304424968, 0.030507694609696046, 0.020255490344425198, 0.03541111254889984, 0.03866382336127572, 0.022944573393033352, 0.03485292101686355, 0.07593847243697383, 0.024491465192113537, 0.03071498758799862, 0.11473853184725158, 0.03529313704348169, 0.03454980193055235, 0.05698431392374914, 0.0474640991888009, 0.023884111942606978, 0.029418505691864993, 0.034317149766138755, 0.04472439795790706, 0.015433411790581886, 0.0251083123657736, 0.022732239376637153, 0.019298075312690344, 0.029663687164429575, 0.05557962504099123, 0.02701280431210762, 0.03839954828436021, 0.055259328946704045, 0.08312492587720044, 0.059106195767526515, 0.0495669412339339, 0.01355451002382324, 0.0676255056168884, 0.05680797963577788, 0.028897736956423614, 0.0420404505712213, 0.01540420549645205, 0.00964389457294601, 0.09284872285206802, 0.021256152176647447, 0.008026159212022321, 0.047451927966903895, 0.06357085600029677, 0.051481500413501635, 0.08882241585524753, 0.0017912395151142846, 0.06808553327573463, 0.07367175305262208, 0.02394397171883611, 0.044828491591033526, 0.03952262923121452, 0.01642260373046156, 0.08804279714240693, 0.1197626935027074, 0.17388040636433288, 0.10800515956361778, 0.12479557539336383, 0.11801525484770536, 0.1096903023426421, 0.13156909786630422, 0.12153352465247735, 0.10705999739002436, 0.08848845682223327, 0.13711669627809897, 0.10121963656274602, 0.15301948122214526, 0.14623703813413158, 0.19118700816761702, 0.220278054184746, 0.2782924356870353, 0.07200910476967692, 0.20506344793830067, 0.1176258573832456, 0.10212038119789213, 0.1633893177495338, 0.06491895241197199, 0.12224015314131975, 0.22292697220109403, 0.07878828982939012, 0.10942359673208557, 0.1699264661874622, 0.143189690716099, 0.18479631515219808, 0.14648409909568727, 0.08883279107976705, 0.12370980592095293, 0.10223690580460243, 0.0755067725549452, 0.21154312446014956, 0.18698891624808311, 0.13479107263265178, 0.18551337823737413, 0.15155448170844465, 0.040393524686805904, 0.2528183354297653, 0.10890943682170473, 0.17973492736928165, 0.07074506400385872, 0.09481153276283294, 0.1478060125373304, 0.19295067759230733, 0.097972443618346, 0.1585567044094205, 0.1402190962107852, 0.14593078347388655, 0.11560606537386775, 0.11616879884968512, 0.13722421863349155, 0.14092005469137803, 0.12293535997741856, 0.09686526318546385, 0.16948162287008017, 0.22461381449829787, 0.1556747074937448, 0.17297923128353432, 0.21294744597980753, 0.12440051534213126, 0.10580987931462005, 0.1961798660340719, 0.1938310725381598, 0.23317732295254245, 0.19434901740169153, 0.16945520241279155, 0.13100237905746326, 0.10128257810720243, 0.1618061534827575, 0.13726947479881346, 0.07288016349775717, 0.1925303993630223, 0.22650007187621668, 0.10977878861012869, 0.1276442498783581, 0.10928454794338904, 0.1729812499252148, 0.09273913732613437, 0.18304150697076693, 0.07769003001158126, 0.14405007736058906, 0.08827894853311591, 0.1682316532242112, 0.16925929026911035, 0.09682624848210253, 0.11599653153098188, 0.09980738890590146, 0.2773553703445941, 0.18044471740722656, 0.10579370049526915, 0.16043923620600253, 0.13599106605397537, 0.16672317869961262, 0.10350837546866387, 0.13211742625571787, 0.12826205813325942, 0.1829978241585195, 0.09736210136907175, 0.10647148170392029, 0.14427854010136798, 0.2407379078795202, 0.12507717590779066, 0.1171561075898353, 0.11851873525301926, 0.09549379654345103, 0.2947726857382804, 0.15388964937301353, 0.13253259850898758, 0.09267517161788419, 0.09730785037390888, 0.16422933986177668, 0.2668636286398396, 0.1545398004236631, 0.07215782374260016, 0.08517461159499362, 0.13964940881123766, 0.07741378038190305, 0.1715663305367343, 0.10042465539299883, 0.07907576815341599, 0.2759522362612188, 0.12208715939777903, 0.15740190778160468, 0.1598934904905036, 0.1384529925417155, 0.11486460047308356, 0.14279923198046163, 0.10907452015089802, 0.12681069929385558, 0.19112775509711355, 0.14521661476464942, 0.0676618485886138, 0.2001320695853792, 0.11128283993457444, 0.18285309051861987, 0.12562686984892935, 0.1337537876679562, 0.16210638190386817, 0.07671665138332173, 0.18495339812943712, 0.11651599037577398, 0.16787353728432208, 0.08208047176594846, 0.1069778342207428, 0.13619193574413657, 0.10024185699876398, 0.2273823370342143, 0.15261373424436897, 0.18675442726816982, 0.1422698877286166, 0.14590212173061445, 0.2652861789101735, 0.16129620897118002, 0.0883499052724801, 0.10147985580260865, 0.14628492150222883, 0.14780877332668751, 0.2135275976615958, 0.10564629512373358, 0.12508826359407976, 0.097014620405389, 0.1442367720301263, 0.15219586057355627, 0.19832081365166232, 0.11197274041478522, 0.1086008147103712, 0.1461039562127553, 0.11022139806300402, 0.22643822128884494, 0.1181068507139571, 0.1485481602139771], [0.017788420773285907, 0.04908874208922498, 0.07528081085183658, 0.06279677370912395, 0.014440979448409053, 0.036025258305016905, 0.04419280499860179, 0.043297303636791185, 0.009293950606661383, 0.05103273484564852, 0.03618915790866595, 0.07822364903404377, 0.032103557023219764, 0.02645115808263654, 0.03576799281290732, 0.03290832712082192, 0.08145518266246654, 0.00310959714170167, 0.05817158322315663, 0.060116841341368854, 0.04703069236711599, 0.0016760641096880136, 0.026399148373457137, 0.03685196628794074, 0.02193769050791161, 0.01500189373473404, 0.04391111171571538, 0.03543676117260475, 0.047679240378784016, 0.026805097586475313, 0.01771638049831381, 0.010864123578357976, 0.03448804040090181, 0.01097744025173597, 0.02121462344803149, 0.009546787332510576, 0.03940794515074231, 0.026689354090194684, 0.0135219631374639, 0.005081314911876689, 0.023552941529487725, 0.053631698901881464, 0.008664378383400617, 0.04803035415534396, 0.030951894113968592, 0.08314314560266212, 0.012447707158571575, 0.10131483184522949, 0.02467948645062279, 0.03930453058273997, 0.015004163778939983, 0.03810924979916308, 0.016858674862305634, 0.06649408664088696, 0.012803136523871217, 0.027706426662916783, 0.011945272253797157, 0.09797460326808505, 0.03967006428865716, 0.04077839133969974, 0.044739140721503645, 0.038963855113252066, 0.03561410849215463, 0.09311514644650742, 0.03176327489200048, 0.10227337494143285, 0.008840455702738836, 0.0444606423843652, 0.0047804301539144944, 0.03849088439892512, 0.024685241805855185, 0.004136829484195914, 0.05281709905830212, 0.052071582031203434, 0.015329679954447784, 0.010189046570303617, 0.03853883084957488, 0.030062951482250355, 0.04712391353677958, 0.030593197443522513, 0.04442983212356921, 0.04442603974894155, 0.024863939834176563, 0.01122369134463952, 0.03383535862667486, 0.03757800193852745, 0.054971494391793385, 0.06183911747939419, 0.05575582945311908, 0.041066901248996146, 0.036870494004688226, 0.018355206375417765, 0.05556181349675171, 0.04098637822607998, 0.018011102183663752, 0.026638034578354564, 0.022160958214954007, 0.019670616748044267, 0.12074372367351316, 0.06081786661525257, 0.02125119648553664, 0.026293772680219263, 0.01705263515759725, 0.01987456820643274, 0.05504548280441668, 0.015985799727786798, 0.03746327703993302, 0.029837243964720983, 0.04131824440264609, 0.052428618146223016, 0.02943279945611721, 0.021034975470684003, 0.05742192872276064, 0.005092690180390491, 0.05295452996506356, 0.05995735751639586, 0.03720764427271206, 0.0468951984657906, 0.01748357062751893, 0.06420656485715881, 0.04098044846614357, 0.032078023432404734, 0.06836470696725883, 0.022732584475306794, 0.030617834891017992, 0.024474664824083447, 0.03682171263790224, 0.04940384314977564, 0.0364073233504314, 0.012126922174502397, 0.042956943580065854, 0.07322071280214004, 0.07887419342296198, 0.011773923342843773, 0.017717541959427763, 0.029168910295993555, 0.03784043277846649, 0.10445650623296387, 0.06223078220500611, 0.06709056557156146, 0.02084171836031601, 0.027200829281355254, 0.017334526964987163, 0.03099958452366991, 0.018443156441207975, 0.05497733880474698, 0.036675991941592656, 0.04916983285511378, 0.05777677179139573, 0.06583495560334995, 0.027121773855469655, 0.023156898132583592, 0.03382993352715857, 0.032382374483859167, 0.02091504997224547, 0.022709427612426225, 0.04869675452937372, 0.018443774279148784, 0.013413212527666474, 0.047854005024419166, 0.07021661775070243, 0.02012854783970397, 0.039605200581718236, 0.04980894816981163, 0.02866988092137035, 0.015151765819609864, 0.025428524968447164, 0.08488722975016572, 0.04259486457158346, 0.01140473919804208, 0.016834992929943837, 0.0170204890309833, 0.018508684370317496, 0.04018173800432123, 0.043802858344861306, 0.06871399134979583, 0.01286490825805231, 0.03980477893492207, 0.06301063840510324, 0.03338570248160977, 0.010126350862265099, 0.07881305529735982, 0.05540457095776219, 0.033770687878131866, 0.03798518126131967, 0.06081561790779233, 0.11870498463395052, 0.04227014156640507, 0.025588704556867015, 0.012514260179159464, 0.02873570756491972, 0.04039108673168812, 0.03987978408986237, 0.02186876539781224, 0.05269737208436709, 0.04383314539154526, 0.022078902657085564, 0.049785314477048814, 0.032092254114104435, 0.016666057854308747, 0.05845690560818184, 0.05430033685115632, 0.002452999610795814, 0.10001649643527344, 0.03171360294800252, 0.024110780541377608, 0.03382986302312929, 0.028885267020086758, 0.09253477212041616, 0.05500226754520554, 0.06450391374528408, 0.04211344450595789, 0.024121923888742458, 0.05767982132965699, 0.05962895716947969, 0.039205405628308654, 0.010087928949360503, 0.0038775393204559805, 0.0442920412751846, 0.05905739213631023, 0.03208928923413623, 0.03908746351953596, 0.008189169166143984, 0.07233714146423154, 0.06304834692855366, 0.04710553796030581, 0.04756139845994767, 0.046914126942283474, 0.020634321481338702, 0.06003121234243736, 0.02479423361364752, 0.01554870721520274, 0.04898968763882294, 0.09686540419352241, 0.07233680007630028, 0.029993030038895085, 0.005134849270689301, 0.0589473576110322, 0.049017803903552704, 0.06151233501441311, 0.0448585077538155, 0.025526291792630218, 0.03774407603486907, 0.046348510222742334, 0.035710146112251095, 0.027431139969849028, 0.013340025634533959, 0.018070674377668183, 0.055765892975614406, 0.013567320420406759, 0.048232967892545275, 0.07170609329477884, 0.11148978039273061, 0.033741365623427555, 0.06049642390280496, 0.03893778346537147, 0.03627600774052553, 0.008993095070763957, 0.021384794199548196, 0.011236852406000253, 0.017708430241327733, 0.009885890376608586, 0.008229423256125301, 0.06903521512867883, 0.021369533787947148, 0.04791379615198821, 0.03474778095551301, 0.036574833502527326, 0.029561985102191102, 0.024600432880106382, 0.018885795579990372, 0.03396618441911414, 0.01831247536756564, 0.00841007962662843, 0.030779289118072484, 0.025960796992876567, 0.015767539662192576, 0.02704294107388705, 0.030619471326644998, 0.03335983492434025, 0.10217305883998051, 0.01887994189019082, 0.00606117898314551, 0.09878126584226266, 0.03580350828997325, 0.046068445954006165, 0.021047625377832446, 0.048496437739231624, 0.09920998971210793, 0.02820404595695436, 0.05870857901754789, 0.06048433431715239, 0.02592195669421926, 0.024299551369040273, 0.02633552961924579, 0.031222601755871437, 0.04252956299751531, 0.07916020229458809, 0.005621670779873966, 0.041348813465447165, 0.029128663627489004, 0.04554869396088179, 0.039110455254558474, 0.027642427558021154, 0.03962475617299788, 0.02877789123886032, 0.01556103243274265, 0.047279471400543116, 0.07870610439567827, 0.013603953757410636, 0.04370360722532496, 0.040794763117446564, 0.0329440095811151, 0.04639688711904455, 0.022191235984792, 0.030327241402119398, 0.09889716704492457, 0.021507192905119155, 0.04904782006633468, 0.010168694097956177, 0.03043346499907784, 0.005679230825990089, 0.03332269043312408, 0.0402275804663077, 0.011767375744966557, 0.033283827870036475, 0.015977094335539732, 0.014149569597066147, 0.027332592035236303, 0.0164319343821262, 0.004450286223800504, 0.0758949454757385, 0.07415025276714005, 0.025543719275447074, 0.03543143626302481, 0.039118225540732965, 0.060473510093288496, 0.06020701599481981, 0.05513002826774027, 0.027815375797217712, 0.016695259510015603, 0.051247189549030736, 0.07499285013182089, 0.07390818645944819, 0.034110023771063425, 0.09677655427367426, 0.027037206127715763, 0.023183363118732814, 0.03726014379935805, 0.06405764550436288, 0.023229322468978353, 0.017869934563350398, 0.0678324163891375, 0.19117719697533175, 0.3040902904467657, 0.09042801524628885, 0.07953202570206486, 0.1493514163303189, 0.13744849566137418, 0.14490408153505996, 0.1958212157478556, 0.16605925338808447, 0.16839005722431466, 0.14685904694488272, 0.13756717991782352, 0.1614031969802454, 0.17958548851311207, 0.12468465400161222, 0.135754959192127, 0.09824797336477786, 0.16090174263808876, 0.13798947678878903, 0.1163902557163965, 0.12670764466747642, 0.06519795540953055, 0.2598685899283737, 0.1794623810565099, 0.16904187068575993, 0.19633506395621225, 0.3336196340387687, 0.16737137048039585, 0.1303020736668259, 0.15035477030323818, 0.0986541730526369, 0.0993596512125805, 0.1309864377253689, 0.10018687869887799, 0.10531649211770855, 0.11018341494491324, 0.15961172670358792, 0.1500004096305929, 0.09381793803186156, 0.15405862155603245, 0.13555815647123381, 0.12043906463077292, 0.14301547897048295, 0.14505678584100679, 0.1378734939498827, 0.10697415316826664, 0.2920334186637774, 0.12834796914830804, 0.11052376386942342, 0.13418038899544626, 0.21636414545355365, 0.1284605381079018, 0.0980881073337514, 0.11400350878830068, 0.055709189182380214, 0.16648524615447968, 0.31824280915316194, 0.1520719367545098, 0.16921495436690748, 0.17541840352350846, 0.11562247425899841, 0.1888657483505085, 0.2261889784131199, 0.12622916721738875, 0.15080561017384753, 0.08543105330318213, 0.08992772607598454, 0.14688876253785565, 0.3121387038845569, 0.09277291988837533, 0.13243803405202925, 0.12541397736640647, 0.14572595071513206, 0.09526074733003043, 0.12921268993522972, 0.13774283142993227, 0.1946844087797217, 0.1767747080884874, 0.10224440149613656, 0.24209894734667614, 0.21726325736381114, 0.18689218471990898, 0.09024656013934873, 0.11809114686911926, 0.0876865885220468, 0.19422663724981248, 0.1708381055505015, 0.07275627678609453, 0.18495418480597436, 0.2067864328273572, 0.10030281700892374, 0.20859608572209254, 0.08444608974969015, 0.1386804014327936, 0.1043379852490034, 0.08026935684029013, 0.11522840868565254, 0.20371606398839504, 0.11477205465780571, 0.10235657711746171, 0.10750061788712628, 0.1099368289578706, 0.12922069028718397, 0.1517704763682559, 0.09966870376956649, 0.1133058380219154, 0.17092748981667683, 0.09823355343542062, 0.21667210705345497, 0.15696303133154288, 0.11975994013482705, 0.23569786426378414, 0.16612073290161788, 0.1382500003091991, 0.23589432559674606, 0.15474334184546024, 0.08144355320837349, 0.1296861653099768, 0.09201235210639425, 0.1533952305908315, 0.11946150771109387, 0.2516806230414659, 0.15083256497746333, 0.10014028666773811, 0.20326023688539863, 0.12920277484226972, 0.15065539948409423, 0.10265687233186327, 0.15533523430349305, 0.0989034233498387, 0.12453325587557629, 0.24227534100646153, 0.09225021043675952, 0.10219713411061093, 0.14551098021911457, 0.17199426773004234, 0.1847048825584352, 0.14912654558429495, 0.19125402410281822, 0.17482511582784355, 0.08943295106291771, 0.15114254521904513, 0.11585760148591362, 0.10362199827795848, 0.1426635673851706, 0.1182035451347474, 0.18621455936226994, 0.08258891713921912, 0.11647732448182069, 0.11324552368023433, 0.1066408991755452, 0.11555254168342799, 0.11245189321925864, 0.16759036341682076, 0.1631783548509702, 0.1489448529900983, 0.08270116697531193, 0.10465198793099262, 0.12922189256642014, 0.25785045290831476, 0.19631554547231644, 0.13567097776103765, 0.10944684821879491, 0.09770497359568253, 0.349628560943529, 0.15275460871635005, 0.29066762945149094, 0.10193974987487309, 0.1823558664182201, 0.08218949325964786, 0.129063859640155, 0.13712330139242113, 0.1697430814965628, 0.17015038698446006, 0.1032778866647277], [0.06882213710923679, 0.002208628470725671, 0.04126840918615926, 0.06032238656189293, 0.04763285985973198, 0.047408148675458506, 0.012971932446816936, 0.04370536240458023, 0.01710122171061812, 0.06788300117477775, 0.11162730035721324, 0.06995576768531464, 0.07729444303549826, 0.03729133997694589, 0.020851115805271547, 0.026391571045678575, 0.043477563885971904, 0.03956849395763129, 0.024075548935797997, 0.011319965524307918, 0.06601328626857139, 0.0452404392126482, 0.017659647019172553, 0.02758348433417268, 0.035017688933294266, 0.016013040258258116, 0.027219097246415913, 0.02785570039122831, 0.04882454493781552, 0.0009070839678315679, 0.009387179197801743, 0.03682288523123134, 0.047153959385468625, 0.03480137143924367, 0.022784124776080716, 0.011812445445684716, 0.029665431211469695, 0.05418229826318566, 0.05282007135974709, 0.040761173513601534, 0.03366446428117342, 0.07387718695099466, 0.02361062495765509, 0.08131754395435564, 0.034290146722923964, 0.019698499236255884, 0.05918814742472023, 0.0658046462922357, 0.04761635820614174, 0.01574193185660988, 0.030265351851994637, 0.022400640373234637, 0.04244564464897849, 0.010301017173333094, 0.025155574185191654, 0.08775217953370884, 0.03074331907555461, 0.16102905065054074, 0.025602189380151685, 0.050360675595584325, 0.02602381275210064, 0.0371156550681917, 0.054702354536857456, 0.10583652983768843, 0.03950919635826722, 0.02712930850975681, 0.0032435631464977632, 0.023136874988267664, 0.07244137610541657, 0.011871371043525869, 0.04678075187257491, 0.016714967241568957, 0.0802627888333518, 0.007470034561265493, 0.04538003347988706, 0.05724068141716998, 0.05002004465495702, 0.00912790434085764, 0.03809465175436344, 0.032443319651065394, 0.04296192710171454, 0.026791968994075432, 0.05398928049544338, 0.019964015555160586, 0.023118146891647484, 0.008029780892684357, 0.047263300002668984, 0.017814666825870518, 0.029076303253532387, 0.020521251572063193, 0.04520349881204311, 0.037033677435829304, 0.022548171909875236, 0.048382896566181444, 0.007474256453861017, 0.0426254410558613, 0.04360807055491023, 0.05085438933747355, 0.054133557714521885, 0.040385401880485006, 0.04495618923101574, 0.042726799874799326, 0.03300757824035827, 0.06871434758068062, 0.07683111281949095, 0.027933180608670227, 0.08263248862931505, 0.05200868130486924, 0.06639384475420229, 0.04426660045282915, 0.06908737326739356, 0.07373804910457693, 0.04858688698732294, 0.045978876150911674, 0.043401824004831724, 0.03269224711402785, 0.0041968710866058245, 0.028033403941662982, 0.049122751006507315, 0.038676087351632304, 0.0743800587952137, 0.02918405196396634, 0.06227039804798551, 0.03123911825241521, 0.10024210932897404, 0.06545700205606408, 0.02613111246319022, 0.05224780870776158, 0.046335452134371735, 0.02893607073929161, 0.01713195404590806, 0.035299782975926064, 0.0444581858755555, 0.033073269441956654, 0.08514135595760308, 0.013471383917931234, 0.04983536491636187, 0.02408283868135186, 0.02179532246373128, 0.056957006599986926, 0.023927444090077188, 0.038122556507005356, 0.0981748198682908, 0.07950415063533, 0.014170353442750638, 0.07220036364742555, 0.021585409704130143, 0.021251539728837088, 0.05341704010788817, 0.04937894038448576, 0.020073766208952293, 0.11315573123283684, 0.06621394815738313, 0.01309091077928315, 0.03079873524256982, 0.03693579557875637, 0.043147200558451004, 0.02907696190959541, 0.05539261124795303, 0.029354070575209334, 0.05127443379024044, 0.03390702411707025, 0.034981368225999177, 0.0728790502762422, 0.016798379074316472, 0.033190551039297134, 0.03175427264068276, 0.03129336182610132, 0.02149483800167218, 0.04152563386014663, 0.03935124877898488, 0.021323119872249663, 0.012006966990156798, 0.05258645069261547, 0.00526110992723261, 0.032746360811870545, 0.00711455881173606, 0.10429914866108447, 0.05594478396233171, 0.018891361687565222, 0.024374298627662938, 0.05162838628166355, 0.03759316401556134, 0.06130191759439185, 0.040111556809279136, 0.10575855980277993, 0.06592066623852588, 0.029166635613364633, 0.07284639577846974, 0.013358376163523644, 0.046803179575363174, 0.045223670385894366, 0.02599723644379992, 0.015511007040913682, 0.03135869308607653, 0.008370662308152532, 0.012160253882029792, 0.040355229866690934, 0.03989982578787021, 0.01758720969519345, 0.01767782036040444, 0.10345798364141956, 0.028677417431026697, 0.00951865436945809, 0.03615737543441355, 0.0267832561803516, 0.027855351581820287, 0.03275744107668288, 0.011427343160903547, 0.04875180333328899, 0.03559838980436325, 0.012502782865340123, 0.0333827524445951, 0.016845572245074436, 0.09536061814287677, 0.02589561972854426, 0.0263550258387113, 0.12173537397757173, 0.06759013485861942, 0.03125972769339569, 0.04984607410733588, 0.009781985063455068, 0.019162236312695313, 0.05290466877340805, 0.014389484604180325, 0.0027820695140690077, 0.015185393458523322, 0.05596550843620207, 0.11830387607915327, 0.026643786222848576, 0.04075269076565746, 0.053529861397692, 0.024305796541739255, 0.07065386889735237, 0.05306401159032248, 0.03846448249532841, 0.07186775532318279, 0.03624652592407074, 0.0072003965397016145, 0.03820174366410356, 0.0312810607283609, 0.016840256612340454, 0.011583145005715778, 0.02513810402888339, 0.06725164872477762, 0.017840543659985997, 0.040184955214499496, 0.09790514566702768, 0.046188803753466345, 0.06540187532664277, 0.015764175877848174, 0.01708998745016288, 0.0374095455481438, 0.012643949557968881, 0.09439708039280958, 0.054488285750267096, 0.018174946126237046, 0.10809227285790257, 0.0018426515634928364, 0.028651056345552206, 0.03320893032650929, 0.07995306092198007, 0.07133521241485141, 0.023634807839698624, 0.058963183910236694, 0.033228664033231325, 0.009181780551443808, 0.0176483274117345, 0.05251820279227104, 0.03068751513637835, 0.022289921216724906, 0.04584730078931898, 0.030259461054811254, 0.04735135211376473, 0.01449067272915272, 0.07862852027756162, 0.05797070982225705, 0.015300450468203053, 0.04887920411420055, 0.04263810580596328, 0.015160117764025927, 0.008142067836161004, 0.057844585535349324, 0.03871530985634308, 0.036086069885641336, 0.03862391065922566, 0.032242264423985034, 0.01640266036702087, 0.023924434681248385, 0.10590244739432819, 0.05882242076040711, 0.015630010420863982, 0.03630335217167158, 0.056516189433750696, 0.02607807302410947, 0.01562624216603581, 0.048165042826440185, 0.037223912149784155, 0.055746315119904466, 0.06465094062150456, 0.028115118111600168, 0.057798064008238725, 0.09201607026625425, 0.021733091525675263, 0.0037825100935151568, 0.034423967081238516, 0.040740367403486744, 0.0033785644473027787, 0.0270100861962419, 0.03335557128593791, 0.03384770425327588, 0.01875183606898645, 0.028866386783192866, 0.05901571683352813, 0.08539295886293985, 0.03785688619245775, 0.007227728910947917, 0.010351791206630878, 0.03786569548537955, 0.033561713935341686, 0.006064405470169731, 0.0210645222250605, 0.01796312048099935, 0.017956801093532704, 0.03241354839701671, 0.08978485522675328, 0.037970226985635236, 0.025750062304723542, 0.02089041252474999, 0.012225176960782846, 0.05247086490271613, 0.024701621005078778, 0.031753890434629284, 0.028205335438542534, 0.057223586045438424, 0.08184724443708546, 0.02460005067405291, 0.0773399144236464, 0.09896028670482337, 0.015248784930008696, 0.03809194291534368, 0.043322091369191185, 0.051837961364071816, 0.06275879059103318, 0.037165252797422, 0.02013148674450349, 0.03502466883219313, 0.04168467610725202, 0.04375198783236556, 0.023465566628146917, 0.03343672513437923, 0.014969299536460312, 0.1480112163699232, 0.18007828941335902, 0.12869522004621103, 0.3659092029556632, 0.1861785800429061, 0.1529444204061292, 0.09484127062023617, 0.18393009522696957, 0.1023098366567865, 0.1549685391364619, 0.21625693480018526, 0.20794026466319337, 0.14634980005212128, 0.0984240479010623, 0.22052415035432205, 0.13495596300344914, 0.12479110766435042, 0.09884019978926517, 0.059056356840301305, 0.07429931312799454, 0.1618382884771563, 0.13703841454116628, 0.11654919406282715, 0.14530852233292535, 0.0959630639408715, 0.16732491203583777, 0.09998836903832853, 0.13226140290498734, 0.20371425314806402, 0.11174204380949959, 0.13259018916869536, 0.11676651716697961, 0.17093393165851012, 0.11529746552696452, 0.13196256972150877, 0.08918428706238046, 0.12195728355436586, 0.14503089973004535, 0.17440810304833576, 0.15488807548535988, 0.09819777449592948, 0.23893398436484858, 0.09496466009295546, 0.16639510489767417, 0.14192762406310067, 0.09455833423999138, 0.1884444014285691, 0.13239056628663093, 0.07269478242960759, 0.14993233984569088, 0.06104896769102197, 0.1685039175208658, 0.2452741371234879, 0.07419826972181909, 0.09791887539904565, 0.26370368257630616, 0.06633082899497822, 0.2742588333785534, 0.09196856539347209, 0.17237970954738557, 0.2176191023318097, 0.11134811182273552, 0.1144628314068541, 0.23779840936185792, 0.13029398425715044, 0.05947020064922981, 0.06993037881329656, 0.12504468468250707, 0.1411210431251675, 0.09291378693887964, 0.16199188336031511, 0.15882542124018073, 0.19292185257654637, 0.1010494027286768, 0.16485090338392183, 0.16925590607570484, 0.09017377029522322, 0.13837983162375167, 0.18274311907589436, 0.1833083832752891, 0.18091984034981579, 0.13245122943772003, 0.11119085815153085, 0.10916247207205743, 0.13446751108858734, 0.1672744905226864, 0.11538171413121745, 0.13057910255156457, 0.1534423718112521, 0.15175944805378094, 0.12842454394558445, 0.10827633290318772, 0.10532737200264819, 0.16404390684328973, 0.12956437887623906, 0.12531307496828958, 0.12804048252291977, 0.20289680716814473, 0.11502853347337805, 0.11874023664859124, 0.19407914282055572, 0.17669731692876667, 0.12962989567313343, 0.1283831024193205, 0.12541979580419138, 0.14178971818182617, 0.1496584279811941, 0.10641976143233478, 0.17738469410687685, 0.16076413361588493, 0.2496513834921643, 0.12271955827600323, 0.10968620568746701, 0.13569095637649298, 0.21083882631501183, 0.07716383988736197, 0.14808884501690045, 0.10736162847024389, 0.19125291088130325, 0.1782930680201389, 0.12455054791644216, 0.1550205933745019, 0.13642781996168196, 0.18173562391893938, 0.20993068988900632, 0.11616730713285506, 0.17069016583263874, 0.12671959324507043, 0.13273369084345177, 0.1445307515677996, 0.12635821185540408, 0.09340862874523737, 0.0813438679324463, 0.16017641202779487, 0.1668370538391173, 0.0780949235195294, 0.18853774876333773, 0.14678401581477374, 0.14372908364748582, 0.1755790042807348, 0.10857629415113479, 0.1348476391285658, 0.19864240108290687, 0.19328844384290278, 0.1405466950382106, 0.13650236127432436, 0.09978928792406805, 0.08421428734436631, 0.10824861368746497, 0.1273470642627217, 0.15107404498849064, 0.15975527290720493, 0.20798532787011936, 0.13560068153310567, 0.11243325046962127, 0.08712680137250572, 0.10818450697115622, 0.2756374469026923, 0.23983708902960643, 0.16137440165039152, 0.10826488898601383, 0.1980871261912398, 0.22646427067229524, 0.21026605158112943, 0.1869982376229018, 0.1655875294818543, 0.14313275314634666, 0.09580204015946947, 0.14169881993439049, 0.14671940443804488, 0.17510707257315516, 0.15002755739260465, 0.11245417903410271, 0.10126423221663572, 0.13563743268605322, 0.11924535720027052], [0.03237635195546318, 0.043689016602002084, 0.0244187922362471, 0.04504193326283712, 0.017827563497121446, 0.05689430625352543, 0.062356346170417964, 0.006959008833291591, 0.02685956937057199, 0.01111126988689648, 0.030106947851891164, 0.03967396427469794, 0.02348261004954111, 0.055405669336323626, 0.052917070061084814, 0.08202472905395553, 0.025983818413806148, 0.06498327435110696, 0.036015239311382174, 0.045545703105744906, 0.06680634527583607, 0.015249499247147469, 0.03255417053878773, 0.04293454185244627, 0.05047178623499349, 0.05420546811365057, 0.025903863133862615, 0.02467592970788246, 0.05931369654717855, 0.014102415389061207, 0.08540436567272991, 0.06492126791272312, 0.026367139544163365, 0.047626473678974435, 0.026864820065384265, 0.017549892654642463, 0.057597695267759264, 0.04029068528325297, 0.02558639091148507, 0.02311848827957874, 0.10280880480422638, 0.021294801372278016, 0.04000459848612081, 0.03428818745305762, 0.05776501988293603, 0.014590819992008619, 0.005298370842865552, 0.022004036654834636, 0.06816515087848529, 0.024257942859549075, 0.05402114831667859, 0.056499042111681774, 0.059110073489136994, 0.0683470512740314, 0.03478366008494049, 0.06970544869545847, 0.014288776092143962, 0.02106975622155005, 0.03315528418170288, 0.032331785987480544, 0.032671904846210964, 0.042683662541094236, 0.012546684611152159, 0.06987105152802542, 0.061352517222985625, 0.023881872511992697, 0.029053083308099303, 0.03568440100934822, 0.016371807432733476, 0.023181324067991227, 0.07620456206495874, 0.029370876509347, 0.04994299859390594, 0.007272089860634878, 0.034356064279563725, 0.024895050664781593, 0.06953112562769093, 0.06317241175565869, 0.08707921486347914, 0.08245424702181481, 0.04238689252815675, 0.015208005770546151, 0.04308687137381639, 0.03627624151704367, 0.00485901709907921, 0.02920792128861649, 0.026272142786183394, 0.03098688081081491, 0.0633518556423951, 0.08026423602132127, 0.08166222702129744, 0.04672532086260617, 0.09626313651097007, 0.011343024980305927, 0.03861271536152344, 0.021954886069579516, 0.022278171163634397, 0.05772214972239453, 0.07257727818796411, 0.03296481569122989, 0.02366800224990584, 0.09062095879926346, 0.038069478105171584, 0.056447355236741714, 0.030516980732500087, 0.02052462277788436, 0.044102062602178194, 0.026563177852949593, 0.08393306532525457, 0.044421905986382626, 0.0345614091202151, 0.05491424512001686, 0.07766187292872928, 0.03519815698382445, 0.006915698486409383, 0.044737934731529094, 0.054175077166291885, 0.050450163762434386, 0.033507444386486895, 0.04443794008693658, 0.0338773790281266, 0.039375921478495, 0.01570175569213461, 0.03674729377962649, 0.04209885017189663, 0.049043856997741386, 0.05649592880217824, 0.039548990316689014, 0.04184468314633705, 0.05574266746407375, 0.07947073914692737, 0.052318060406832956, 0.030394854766200297, 0.03632195410318673, 0.07379089001915418, 0.04146098166529555, 0.022719435473845806, 0.05768201808677986, 0.015521380410064012, 0.00244905440013099, 0.04959553247317672, 0.0750408077146858, 0.020953771527274512, 0.04416867406689562, 0.019475788139970973, 0.0237621381165809, 0.01806182241125498, 0.05307974883180577, 0.05163023051864002, 0.003699657654578914, 0.03906462021404877, 0.025610876218706835, 0.03301911863673013, 0.07951638865051791, 0.11748888660804369, 0.029064228510833345, 0.017352026807202492, 0.031494320573983714, 0.005351034569684998, 0.012235570738994284, 0.05843083024956286, 0.031522370045422576, 0.022499260667245835, 0.0862722925376147, 0.03680053174321074, 0.032569577524554916, 0.03723546367837116, 0.04306063274270855, 0.04379765217890963, 0.03106617929006461, 0.054763841471867636, 0.06036694139766041, 0.07464955488103442, 0.04145502964092884, 0.020059444614162203, 0.01642398041440174, 0.0255719542838051, 0.04333966542617418, 0.019989935062767472, 0.070144206401892, 0.024198966239055153, 0.025683669773570728, 0.07097656955011189, 0.039239433099282905, 0.037121959612704813, 0.013556221601902507, 0.023551967460662127, 0.06336024933261797, 0.03649211743322667, 0.006804146269132616, 0.015840535452298354, 0.039483339933212847, 0.04472324391826987, 0.034377593983663246, 0.04651369003113359, 0.019021727348444983, 0.029927045688964427, 0.048535548921790905, 0.04948985806549899, 0.05735017046390567, 0.0811540859285742, 0.055066993954824284, 0.05797214587801136, 0.047282362065743655, 0.08332149111083709, 0.022472214950539637, 0.017670847882982343, 0.05464877889608033, 0.053681849531130865, 0.022482848071376793, 0.08205009566154331, 0.007894780519563938, 0.027527587626536842, 0.06498456568806432, 0.011641475957731018, 0.02179022576456191, 0.09330344415502623, 0.011248102437093621, 0.04981340105587151, 0.02735136280534789, 0.027208705323573668, 0.05929612249019556, 0.08051225435337983, 0.03383123599633109, 0.09413309104274958, 0.011113899872725597, 0.01028224547553691, 0.03472245516604744, 0.05744414862419944, 0.013051974929112475, 0.039965387113625184, 0.009436017153348075, 0.06669911235803738, 0.02272895537316799, 0.02599099127110094, 0.04402648228278849, 0.043575590461841784, 0.0432515094144037, 0.03552724010660313, 0.037685947318095714, 0.01252873762496165, 0.058623514050850645, 0.047049554050317965, 0.03023332632437814, 0.0473358449380612, 0.03919468159438111, 0.03082869759964524, 0.04562388094200287, 0.0415756137954304, 0.01725319685647264, 0.02505574419046752, 0.027631362136162352, 0.025789555693336297, 0.0398569148092065, 0.004123626213186071, 0.02871289208997041, 0.018318848560738843, 0.01369915553368628, 0.04989159002434462, 0.10797230468597263, 0.019313350567244925, 0.020850518376391847, 0.049180337955476716, 0.023198545604827814, 0.12285762000828981, 0.09067319115274586, 0.0650558341294527, 0.037306030790205114, 0.05011846456909552, 0.02787650464597391, 0.022669741265417542, 0.14464536885498092, 0.012725975429930259, 0.028251480325707234, 0.03381508315214887, 0.0069295084631448844, 0.022193328841240145, 0.0975289213238284, 0.05636026049614884, 0.017173777778225485, 0.057938734389608726, 0.030781359710090328, 0.03303173514723312, 0.03529518908180762, 0.056202212726930156, 0.06286914795055054, 0.09319585500634275, 0.03205158813216258, 0.05490178446052596, 0.050277933551114984, 0.0698554738482926, 0.04377255274448544, 0.05829182598972693, 0.01932047147420235, 0.06742891069734469, 0.04228185636748094, 0.05369363112549763, 0.0134464486836805, 0.07431142497807741, 0.07529940165113658, 0.023788816470187157, 0.016750898321333807, 0.03965987831179518, 0.020807427426916547, 0.05302408404531889, 0.019479437651170883, 0.06102600564190652, 0.024892198962334078, 0.015228731172101106, 0.049464888506918214, 0.060061677504563704, 0.03685861964186188, 0.021171330263314303, 0.03806670989433769, 0.13050839072093368, 0.003494718444017053, 0.03040790728846332, 0.015453299492946826, 0.06802101837820373, 0.0237370628019562, 0.013510687131201848, 0.06425197687349282, 0.015751050996186677, 0.03128762502456084, 0.03765573819691781, 0.009522285326966085, 0.056738458952168, 0.0391987559851259, 0.013124873312335694, 0.004992401445633732, 0.03146620430925395, 0.007806198700563982, 0.03708628086315002, 0.031278003079933114, 0.01826696316129528, 0.03147908428218216, 0.007978124631335959, 0.02493798019713722, 0.030047639120311942, 0.04419864199007861, 0.029342583984544035, 0.012516778842837084, 0.02470500705385348, 0.021468907361850142, 0.04153647292696405, 0.016021485898818355, 0.03622510012064595, 0.0052307913392724, 0.026053498659166507, 0.047612358030164614, 0.01361857313895598, 0.015749408994452097, 0.1359314567525871, 0.14542407472617924, 0.17917096934979782, 0.14760441554244608, 0.07256124037667178, 0.17108469153754413, 0.20308081526309252, 0.10298495355527848, 0.19518221175530925, 0.08954279634053819, 0.1539113646140322, 0.16467041306896135, 0.10223764795227908, 0.10088313938467763, 0.15227337047690526, 0.25976531265769154, 0.10632922683726065, 0.16265297366771847, 0.147966954682488, 0.13734550040680915, 0.15394004120025784, 0.17749714432284236, 0.08693025840329938, 0.1512797683244571, 0.2540558815235272, 0.22623234952334315, 0.29006678669247776, 0.1479027737514116, 0.23990337766008452, 0.12348947711871006, 0.20860190415987745, 0.225467239797581, 0.1552301165065728, 0.17916764452820644, 0.33374378050211817, 0.10906428593443707, 0.20335598877863958, 0.13590212707640603, 0.136121817631647, 0.13024544779909775, 0.17042907827999443, 0.11267277121078223, 0.19427679158980027, 0.10248293518088758, 0.10569551435764879, 0.09659908449975774, 0.2096563921077177, 0.20167117996606976, 0.1463345266529359, 0.12709813308902085, 0.13546059373766184, 0.14011458697495982, 0.1918515271972865, 0.08092654345091432, 0.12663576024351642, 0.19590917509049177, 0.13659674761584029, 0.10695525808841921, 0.10613291393383406, 0.13281105231726542, 0.10851174214622006, 0.12006490345811471, 0.14400566724361852, 0.21626448986353353, 0.10498422518139705, 0.19729929190361872, 0.07299622797290795, 0.11793037541792728, 0.1063384665758349, 0.13266553200082853, 0.14802926540141925, 0.1942591878469102, 0.19229935394832864, 0.10370116317062639, 0.10918526342720725, 0.11602633618167602, 0.11767912132199854, 0.143335493048653, 0.1483536878367886, 0.29820146737620234, 0.16118405561428517, 0.07886571809649467, 0.12392722550430335, 0.23225272569106892, 0.1575439251610078, 0.10210645850747824, 0.14349386736284941, 0.14255527319619432, 0.2004229321028106, 0.17862259643152356, 0.180808161967434, 0.132213935139589, 0.19151984655763954, 0.07166713054175489, 0.14410089963348582, 0.2422154793748632, 0.09826799650909379, 0.25473657937254757, 0.1531844903365709, 0.14970041869673878, 0.09118634174228646, 0.23888250900199637, 0.2101485844468698, 0.12510322529124096, 0.13123168784659356, 0.09867033702903427, 0.1851317659020424, 0.128710983262863, 0.15404493635287508, 0.11359419950167648, 0.16012745996704325, 0.1311284105759114, 0.29166860855184495, 0.23532448976766318, 0.11673321700072847, 0.1438555307686329, 0.12981515057617798, 0.08512546657584608, 0.1730136520927772, 0.16063293674960732, 0.12347148003755137, 0.09855105163296685, 0.1022948972240556, 0.19946713495301083, 0.1266621658578515, 0.1044790526793804, 0.11886619395227171, 0.11678527866024524, 0.166463308269158, 0.12412245487212203, 0.1415864290902391, 0.1589599429280497, 0.15934542927425355, 0.19884858455043286, 0.1672212191624567, 0.0954202793946024, 0.08394163713091984, 0.09125346899963915, 0.21486423531314358, 0.1228496790281497, 0.13605943269794807, 0.1543271602713503, 0.238645956851542, 0.08260255039203912, 0.08812415137072094, 0.1431203741231002, 0.2400355541612953, 0.11269209673628211, 0.13286096916999668, 0.07294056689715944, 0.1817805683822371, 0.16789985384093598, 0.10816350419190712, 0.13916024443460628, 0.23972190771019086, 0.19079730642260984, 0.23992785369046032, 0.1641554813249968, 0.09355675400001928, 0.10776416937005706, 0.1493095888872631, 0.15410720254294574, 0.11947897786740214, 0.1407817777362652, 0.17101258446928114, 0.09602861784514971, 0.11262379688560031, 0.12161725375335664, 0.12829506886191666, 0.14862290932796896, 0.14844786637695506, 0.1869855320546776, 0.10276844681357034, 0.14335281477542594, 0.11169171877554618, 0.13329312176210806], [0.015535199199803174, 0.007175290147642954, 0.0226056568135391, 0.030518042003677692, 0.04794722990482114, 0.016115870384965092, 0.039325295874732547, 0.017334862786810845, 0.019371544221939985, 0.06388508132658899, 0.030550099072570447, 0.08487885090289637, 0.058559158715070225, 0.11772724217735231, 0.03910110790457111, 0.06850029734778218, 0.04784973025380168, 0.04380677317385562, 0.10760566146927886, 0.028763907321263105, 0.02762795196758816, 0.10422940162243322, 0.002355082037865941, 0.04436138384335209, 0.018974480371980462, 0.03551260495441966, 0.06066840920539107, 0.0938820447481703, 0.022877935953147244, 0.015255153484758921, 0.02391916172200581, 0.020249875997251365, 0.12574098247569054, 0.048007273362600245, 0.050338711735093966, 0.02023389384703478, 0.00915405762498267, 0.03169989548041485, 0.020622194788302295, 0.01262551182662719, 0.009366957528982311, 0.018922739691333845, 0.055825416930019855, 0.045869973400840536, 0.04590878030285239, 0.03218369041860569, 0.030964417856012005, 0.047397866219398566, 0.03728314295585733, 0.02472017840773333, 0.029435476753860712, 0.03961287438869476, 0.034057294178637676, 0.0191336228090222, 0.10134398340596817, 0.048943166111712344, 0.021264091301418375, 0.02379844769166084, 0.053290455689420924, 0.043445948394946754, 0.047159514360828325, 0.061466837651096284, 0.03727062663529068, 0.031146605833782814, 0.08248063779319637, 0.05058362788986415, 0.011367916613380658, 0.07564385465229861, 0.028289337278692983, 0.012900176043331157, 0.12384011963149533, 0.07704888863372616, 0.0968052085954696, 0.045969948114361614, 0.0735334909404628, 0.07046065817121416, 0.10229829626041465, 0.08207342136302032, 0.0359368202771293, 0.06658037615125068, 0.03759647770493757, 0.05033417350205127, 0.02083514293190092, 0.0423844694159925, 0.03332606720505282, 0.028511660602816846, 0.0635658687679097, 0.05548925000766758, 0.016404421112383716, 0.033557294445927255, 0.044163297206978314, 0.05103391857119277, 0.05903038538235705, 0.033448859248892404, 0.04913557531835977, 0.10369781608460471, 0.003321607396173931, 0.036775450862478465, 0.024957379937404767, 0.03375438289367594, 0.08657914091600105, 0.043487527218530886, 0.02441459353576647, 0.02750144361925777, 0.01149715328210732, 0.05955900232947897, 0.052734100972884335, 0.04416594667418394, 0.05488723094458692, 0.06649180824751966, 0.027277077533653937, 0.021307252754922956, 0.04238269568304531, 0.04712492285761982, 0.002691916197363753, 0.033720329447533004, 0.019187862671969924, 0.009955046480172314, 0.06971488881390542, 0.02488423757313285, 0.0435422346345149, 0.03874228692438919, 0.061651034993701614, 0.03999908803962171, 0.014131951011222554, 0.040590542630525306, 0.026751943114504684, 0.014247688941395609, 0.02145045200450113, 0.06150691362563521, 0.006187905801198212, 0.016555487127334345, 0.058553867202135734, 0.0811703538056463, 0.041614992151153274, 0.03519948171742726, 0.026023543723567855, 0.06698157376376912, 0.0326233387022512, 0.057111985588562675, 0.043780259948107414, 0.04738888252177276, 0.10219060321105644, 0.02548740325437393, 0.05447605515655596, 0.0343595449521672, 0.06438242417061701, 0.03880031916196458, 0.050613554994924925, 0.022646231882390566, 0.023184159072116017, 0.02931605962658068, 0.009718655746837612, 0.023936702382343356, 0.017482908260717522, 0.0575863107223995, 0.01846319813921582, 0.023725776591163594, 0.04699965204054024, 0.018348287703702226, 0.07147729658754542, 0.032689052168279886, 0.04777713707881048, 0.02846526709618047, 0.023826165052014403, 0.03167070681229234, 0.02486553359631216, 0.01967321426491253, 0.03365516517078504, 0.01832965608628001, 0.014760187368665356, 0.01676373191003222, 0.042491991771385074, 0.030618736600445118, 0.01563938374602003, 0.045153058745199814, 0.008884169128577923, 0.042017885571112856, 0.03250074332754593, 0.0733586706337519, 0.09349045794806443, 0.05569238324824255, 0.04483491116843652, 0.02796125419990858, 0.017237971696886234, 0.029795195732731372, 0.020527450360532384, 0.06922242188011296, 0.05932282125286292, 0.014656402654509293, 0.0022233642766877892, 0.05097162640595343, 0.047099404109758325, 0.0594880418793764, 0.02604471163067501, 0.043447325078886934, 0.034871107345679775, 0.025782945012906566, 0.02495424065273255, 0.08529762999387458, 0.01684143477177713, 0.025135551040875725, 0.07061375581542961, 0.040874562546378, 0.0541137015534332, 0.04679266334278509, 0.02596499940409558, 0.040565914459875785, 0.04264814706402831, 0.08662657157401554, 0.015606187480443623, 0.03793091913394164, 0.0378557692602044, 0.01586195568961557, 0.0366984233551193, 0.026271831084159203, 0.016321933253493626, 0.02862629644369008, 0.04368887188320514, 0.020397351872816216, 0.022042745222279336, 0.027112745628983248, 0.06316182130831294, 0.04584653637721203, 0.04860877292230725, 0.016573341345065273, 0.05576448660576716, 0.018135721766157076, 0.07818403319106437, 0.024847265631251503, 0.03495438002573792, 0.043706724245566875, 0.020789519403479062, 0.033668197283986956, 0.07559430145192891, 0.018320950694032945, 0.06554738080012612, 0.08253116320702247, 0.03352230218297336, 0.031035992433317006, 0.08166059429640882, 0.04366293753264472, 0.04921108884445857, 0.016985413276415784, 0.060656753776129335, 0.07892043664469384, 0.05926827339862939, 0.09035458715516143, 0.06082522500946652, 0.03731917422555853, 0.07378323105513118, 0.019419993477640674, 0.042827568686334416, 0.027732086418836843, 0.06008210140862502, 0.01602061758603668, 0.02192460829974152, 0.018912076884589624, 0.06597256462555379, 0.01214470681588864, 0.016890728220460005, 0.04131781024625525, 0.09147989825578406, 0.019215580032323487, 0.001288255421059148, 0.0266980483502266, 0.0499674857564969, 0.039725625174469315, 0.02991874105646275, 0.03086012013227446, 0.08924431196646765, 0.07297082425793633, 0.036565144764608704, 0.07342853641603142, 0.027143715451529715, 0.023358016442216467, 0.03985393879702315, 0.05645222372550052, 0.021213356230873615, 0.05969450736301951, 0.03547904874722008, 0.07085024117259309, 0.04936603072565049, 0.020385024799907114, 0.08250903978478163, 0.025635745587351266, 0.04557265048788395, 0.04974283765477594, 0.023358921862381976, 0.04742916629766114, 0.04553119411866646, 0.05851519017596729, 0.016124156463774852, 0.005548425442611915, 0.08584045164752752, 0.02653371459018672, 0.09019273958983831, 0.010711816321418155, 0.06346550071612, 0.03519781930663157, 0.020853717032878194, 0.031033775267133024, 0.0200019021940534, 0.016481454185850453, 0.05885623300855514, 0.0689084711484611, 0.0021362310371841886, 0.04410218505654484, 0.06705769585096277, 0.023409050227201078, 0.06602432200452313, 0.034551059870864265, 0.07868147251429036, 0.031321003116318025, 0.08227935250033624, 0.014593339583370835, 0.03543496517522726, 0.02087071963615017, 0.055733472254360095, 0.024295820221595932, 0.00607992470577301, 0.04015914702904411, 0.027689765447576065, 0.019027571761398576, 0.05613711153273471, 0.02906035635533044, 0.00974060012595146, 0.03266450934461318, 0.03804525069426745, 0.01328940281382529, 0.05016788418288343, 0.026260164522682317, 0.023281667999981437, 0.10359267602325417, 0.01843368292611558, 0.022076731875131372, 0.04151856861426495, 0.056987449497682974, 0.03558159871317912, 0.016359263281628955, 0.03876323775330093, 0.018830887784133665, 0.03487299611151684, 0.0977546010108199, 0.03561678764526732, 0.025853632723737974, 0.02473755579558201, 0.01786821649147896, 0.017833324418461416, 0.03215163706045132, 0.021296185477694962, 0.02160692456527613, 0.12618711713002995, 0.13223658548668027, 0.0838379591004923, 0.13493945763912052, 0.19557903811801225, 0.11939582764171064, 0.12497070740209892, 0.12488527136156335, 0.07688961632084101, 0.15030805952847004, 0.13356734532862902, 0.10783050252939574, 0.12151157192420214, 0.18715073412749916, 0.20221717801177874, 0.22476316429674625, 0.09583096907590516, 0.16093052312498912, 0.21765151934232563, 0.1893494653631933, 0.16196859476622194, 0.16561001655645669, 0.18579444440547377, 0.30449250480160117, 0.058602273784345016, 0.23875157930888236, 0.12664010922890157, 0.15565973095363006, 0.23016941326204687, 0.0817789816937875, 0.13542160129873082, 0.0972749806533102, 0.2531854313565418, 0.18040864903014153, 0.11284082313068211, 0.13967180682811886, 0.09512503078440204, 0.09077626804355532, 0.08542893076082692, 0.08271805083495565, 0.13171264406992123, 0.1954466092865914, 0.13377664581639692, 0.10770515378681011, 0.15081919147633016, 0.19085755397100002, 0.17785808042390272, 0.16484386782394722, 0.11121620249468833, 0.11319340264890343, 0.09528445894829929, 0.15607652108883485, 0.1792894012760371, 0.10143149745999835, 0.18299199087778106, 0.12912318692542613, 0.18996227154275402, 0.19988073385320604, 0.14406788890482858, 0.20443765417439863, 0.12036706146318465, 0.17164455290185288, 0.2021516760578379, 0.1416111277649179, 0.17251581943128258, 0.1990083689452149, 0.20316700829425827, 0.12959920044522732, 0.16651086509227753, 0.25540664966683835, 0.20868123974651098, 0.22241974395001307, 0.33764756633900106, 0.113619447365636, 0.2195171153289266, 0.16676646075211465, 0.2671212429413572, 0.23655458469875157, 0.16054871783126146, 0.2651530673028901, 0.09469179465668276, 0.14308090670965612, 0.09723177281557582, 0.1525432599009946, 0.09614126101951115, 0.08169728607754223, 0.12190047957119532, 0.13997470698086545, 0.14923788257874548, 0.136505804839544, 0.12196028183097951, 0.12132823918364011, 0.13298881152877584, 0.09652884022216313, 0.15022784820757806, 0.21747809427324682, 0.09781012107850984, 0.08302394184283912, 0.11888813183759339, 0.1340936913038604, 0.13578124606283382, 0.22294427908491343, 0.09377303067594767, 0.12833107786718756, 0.0860978729906492, 0.08564720381400548, 0.09024520943057723, 0.1441934157628566, 0.12075561287929304, 0.09479378059040755, 0.15028346475446597, 0.18233631824841723, 0.12400127699947916, 0.1636135799344629, 0.09907498562824912, 0.10917529638390988, 0.16227006999542937, 0.16476288466947153, 0.24272390990518034, 0.16441392683191225, 0.13109819032251835, 0.09518354912870564, 0.2282830816693604, 0.1688060606829822, 0.27437113516498357, 0.0973913048801478, 0.13607754110125825, 0.10931438970146701, 0.13656026363605633, 0.18903635325841606, 0.09196337035973556, 0.21862906141905114, 0.2363657674868591, 0.09783689776668325, 0.23881773435277864, 0.08699324447661638, 0.18492311850422993, 0.27007374388631433, 0.26527751062531024, 0.18084957380779088, 0.11148144607432187, 0.15683768258895725, 0.1712782436516136, 0.12062759240507148, 0.256545816664584, 0.11515709571540356, 0.11865155742270872, 0.1471123271039687, 0.1378034648951143, 0.11604324230575003, 0.06224553239007946, 0.09204257978126407, 0.2061741758370772, 0.1597260174457915, 0.07983594259712845, 0.16447224479634315, 0.08949852723162621, 0.16602371935732663, 0.08830611855955794, 0.06695757270790637, 0.18451817304594442, 0.2239643016946502, 0.14164056134177372, 0.10953665550914593, 0.08630722542875446, 0.22051279549486935, 0.13279039092594758, 0.12097030878067017, 0.2031944232294336, 0.1460615053656511, 0.043749817050411366, 0.1386071663000621, 0.20448593830224127, 0.09573365125106648, 0.2395522379083559, 0.1721194086712785], [0.03771154770220164, 0.032988349194056354, 0.04536084896244574, 0.02813744005834451, 0.06451572131481953, 0.009585136886016699, 0.09877474236418493, 0.053693979934905656, 0.03735629274160601, 0.02249616776680341, 0.03865183767629787, 0.02755448305833852, 0.008620288317615632, 0.04257080414390657, 0.0068953228219470475, 0.05449339543702081, 0.0659756593813654, 0.06357298596412875, 0.011074795183958486, 0.00969294775131857, 0.05688927078153938, 0.0381667662441032, 0.06850578924058937, 0.02053916330623906, 0.006779180885132519, 0.08638743674964644, 0.049405984245822765, 0.07400442074867897, 0.03322605167340953, 0.04696386939031072, 0.021751994026999455, 0.05234403557551559, 0.035259447249700315, 0.03960818030463997, 0.1122884797223378, 0.11698010726831853, 0.10427539251395501, 0.03200157480023336, 0.041486385380267166, 0.059556998530752026, 0.03178509774443228, 0.04391141970700119, 0.036541622393997386, 0.012541874566522893, 0.02795318705466343, 0.0122233503498137, 0.03126707495539449, 0.03229510533856228, 0.03408303928154055, 0.06774508787202649, 0.011844809578178683, 0.07069243089063093, 0.039364473850582726, 0.07567142543848604, 0.054930950864218175, 0.009083472887141397, 0.03303588746348396, 0.02663728500920115, 0.01317054136961815, 0.032795409351820126, 0.019588537070376333, 0.02613609227410052, 0.0113304158912797, 0.033093893725890666, 0.05007707870390732, 0.03361721173860133, 0.021664834348484874, 0.05427574949862901, 0.03184132285241503, 0.01756368361384375, 0.059855104409507476, 0.047818370803724974, 0.03365520969964564, 0.013086652706988389, 0.023245768461492844, 0.05719976681575645, 0.015475476720894221, 0.12782211299054325, 0.0827893489622511, 0.014610716043534921, 0.033893717409227975, 0.04212267682305537, 0.00868362134497147, 0.0177728857670445, 0.01158964900241699, 0.030748638419026975, 0.01699711508990731, 0.09770430566277355, 0.06587570693227462, 0.016161362182174344, 0.021482798510987777, 0.03289607797341887, 0.048758924240246415, 0.05523040374100674, 0.05327847371518146, 0.07204296896816231, 0.03445219466811977, 0.0257956858331454, 0.0520300032076193, 0.025782852244446985, 0.024353802364203148, 0.016827419312903658, 0.030190712204785086, 0.03550259709300008, 0.039057287795003504, 0.05467734416015446, 0.04339081053331029, 0.026700352718762588, 0.02862264507712098, 0.05508449008630123, 0.019527718068275135, 0.059955539254588075, 0.02107276191964047, 0.04191479383734986, 0.059292126024956815, 0.04714124268502928, 0.00733859371393919, 0.05248897330602631, 0.013711422307096655, 0.04711820642114617, 0.024841137346811593, 0.06094760145060718, 0.0504565573646687, 0.04497880247072317, 0.05291967128869146, 0.03179703147907276, 0.026427053126099054, 0.0041095462802331895, 0.038798178065917455, 0.02588220355391968, 0.035262979872641154, 0.060496000878629275, 0.041800647813943215, 0.0854193718987517, 0.03936947963666171, 0.059681360216927715, 0.014037947803444695, 0.03290707289124839, 0.04745100399304647, 0.060066809455747716, 0.04172391345491633, 0.02547838430473348, 0.02723230376432184, 0.00666486927002552, 0.01849043124821037, 0.002930961036327062, 0.07971951446961612, 0.028744774754159153, 0.03649821417639032, 0.09132179853622802, 0.027615658291324507, 0.032346454536309466, 0.08341449705767445, 0.03843480772047769, 0.07443419846822508, 0.05808861111290753, 0.06400644473615102, 0.017784181254683062, 0.024617107083031442, 0.017846775845100638, 0.07281319209141657, 0.03658457048004493, 0.055993617279455066, 0.0414244086277904, 0.02718390831432771, 0.022025633152225055, 0.0536334392381832, 0.0063271308499679435, 0.07866835134336725, 0.042202787954011, 0.019906558482034598, 0.06628489005379379, 0.04539079462119844, 0.01234263017977355, 0.03472920128842816, 0.0051669898311956786, 0.07638409500941634, 0.058099131056223996, 0.10140532191144302, 0.0515230940800393, 0.02231448444945272, 0.05674320498656016, 0.025974302225222345, 0.060850613881484605, 0.04705165803898126, 0.06739517266396433, 0.029199082309787627, 0.02359045152843464, 0.01471648043661844, 0.013553584194596624, 0.044481463337433524, 0.01323319440416526, 0.040882529501686804, 0.060860139346914366, 0.012943813399033388, 0.004389675486891065, 0.03796349570620805, 0.01535179038910428, 0.07352878572419286, 0.06585775437997654, 0.027661947897286154, 0.0727759585424792, 0.022156086015456822, 0.02784708220133325, 0.010124627224286087, 0.043069601597380824, 0.05339286093658302, 0.048073031357489526, 0.012980608153156936, 0.05043882745667361, 0.07093975160387345, 0.05446880437375512, 0.04253201579558663, 0.04354371521912981, 0.04310663847718388, 0.017055108364729676, 0.02892357668315526, 0.014641964171460131, 0.010809198156493949, 0.09702835755888373, 0.06318667583400384, 0.016911204074858688, 0.046583938019466586, 0.07953239677590318, 0.033477791876066476, 0.08537200061255135, 0.05183538611163385, 0.04420888733875472, 0.054714470097678714, 0.11938635041587986, 0.03374410414835438, 0.005681073207597365, 0.012012190782115795, 0.030192871854524128, 0.03189899514836725, 0.0701679105986841, 0.07310821063583717, 0.013146808414603584, 0.05183286652027164, 0.03620312883867882, 0.09898108168272302, 0.07755749727948569, 0.01336865954726818, 0.03347489378938917, 0.0753095764957834, 0.06190370659169275, 0.058468809656915255, 0.13618645869428292, 0.05678870606061537, 0.0425356300547719, 0.02750702085904777, 0.03854137641610578, 0.02289667147124419, 0.04053038785059471, 0.047930075161275454, 0.0357639481080696, 0.01256140418263385, 0.022058198592276312, 0.03264159553509671, 0.04183564007689711, 0.009894770173559664, 0.10003223738749512, 0.06822349110734649, 0.01975470207980834, 0.11045731196645647, 0.03889763327606488, 0.024020392520469613, 0.029360690532485023, 0.007645465284440434, 0.024875786366465036, 0.06360664236126468, 0.04131739464355633, 0.03479314844298642, 0.03345205419464037, 0.039028989704092965, 0.009728324075695127, 0.071613102190895, 0.03979284148954321, 0.036383199840201996, 0.030365233797056135, 0.02766448047623271, 0.07055452500935644, 0.03190977113263216, 0.027551119273994118, 0.04565932591503952, 0.06203453609487042, 0.019051370582019445, 0.055251788726309314, 0.031246673315763474, 0.07013696304056793, 0.06332690463750623, 0.022120123394415714, 0.07333219822612591, 0.09043045691214502, 0.07252460054587573, 0.006979892405070132, 0.01803774714062456, 0.05988424483803101, 0.002313169711669616, 0.06517515663290396, 0.02360357826546533, 0.026198814884992316, 0.019295921229058877, 0.020682846807176247, 0.0017218554330611369, 0.044352856566547416, 0.00907340008780011, 0.061855084786657244, 0.03325174482597504, 0.03904634853824973, 0.041139542663586326, 0.011416672004997963, 0.01425786285835784, 0.011316354975861032, 0.04463088363991119, 0.0517550152289914, 0.024941633419075515, 0.025641814499977045, 0.03243920815293677, 0.01969621156604262, 0.0633714186551515, 0.012567076046252623, 0.019912072639272083, 0.027941843327425886, 0.07161970730521716, 0.07397966270218603, 0.021586213078990113, 0.007403585905194632, 0.052584205695893615, 0.03501303195662331, 0.019225632422603667, 0.036733129891217686, 0.05231435708992649, 0.030244543886510655, 0.08261261391453445, 0.07841452199500054, 0.09934284898918122, 0.06400493075489067, 0.03254299008403905, 0.0351867687277263, 0.022074982261983678, 0.022562495360034518, 0.07935745030408725, 0.057823734896373935, 0.015311796978494385, 0.02690386631002184, 0.008505813893862069, 0.06955386503250338, 0.011791752513090614, 0.03980241890531033, 0.03667689365101978, 0.08531288112862967, 0.1831849047448486, 0.12837007030611858, 0.14796085422858596, 0.17045769549440593, 0.13929849170381203, 0.12242199416505173, 0.12451841292204335, 0.12506806233432144, 0.18096693704137579, 0.1682395051466301, 0.0970492119085975, 0.13230092969024554, 0.10739520323113538, 0.08243713309639134, 0.18834982212865725, 0.10548101141466759, 0.1921212236629799, 0.13568779482739046, 0.09819725499255583, 0.06919603853020817, 0.15030397771624848, 0.10178208802244626, 0.1227352992282249, 0.10596436477499083, 0.12894167244667187, 0.20872039545793086, 0.1916636896203272, 0.17711449298076332, 0.09975600260077044, 0.19951464724726975, 0.2592257416108623, 0.12632016936549917, 0.08301561494590715, 0.14162607461912557, 0.13610029534902424, 0.203975414915476, 0.22292067878879607, 0.0890094593341928, 0.17656853946391493, 0.15541327855316922, 0.10622871035593562, 0.09487032570177689, 0.14597299683373421, 0.17686008475720882, 0.2075648566824384, 0.10484297963557765, 0.13473891449393705, 0.16036591201554984, 0.2045297101722099, 0.12743322760798037, 0.13453074207063764, 0.15410859778057784, 0.10643347632139921, 0.16736151475924999, 0.27621569868642837, 0.0776401354232803, 0.08502513563144021, 0.16757620323915035, 0.09979663518606685, 0.1325324352364987, 0.13015864620683715, 0.20514343661488965, 0.11083962192060426, 0.16169876471394673, 0.22421168920118362, 0.1596943277399987, 0.12039228706271388, 0.3028718917630613, 0.0998553390672896, 0.16106871102238074, 0.18363454233622178, 0.31760162324644625, 0.12308947436395101, 0.1584734651260078, 0.16936654545133933, 0.14055376028409228, 0.16573304979829118, 0.18058315763482824, 0.17355634015984833, 0.10592677499516867, 0.1265230428543873, 0.15867286536376923, 0.12923286150908098, 0.08463032791041769, 0.06779145725886337, 0.1738422896596603, 0.07952942076371983, 0.22201473911991343, 0.15022587409475818, 0.09611267349100672, 0.09742148802615702, 0.1395575309288688, 0.09963656877516769, 0.16442621679743752, 0.150879290595185, 0.1441017456818372, 0.13057683157967404, 0.08235736706410535, 0.1461954481783323, 0.1412729755975306, 0.22589136235183105, 0.11609633555053733, 0.11754039165680297, 0.17166963749332353, 0.15557255828753114, 0.13561972504248843, 0.12240225303685293, 0.13549183815484866, 0.16872406820766628, 0.13870130031136796, 0.09254413802409545, 0.10775927861686796, 0.23958002391736954, 0.1358690718188882, 0.19043737964238971, 0.13041584490565583, 0.1502979514771141, 0.17642451828578487, 0.2847058087354526, 0.07322878736886196, 0.14649328688392416, 0.1406785598373972, 0.10863715768209659, 0.20434620673768222, 0.1363828161265701, 0.15982625191099942, 0.09842151717748493, 0.14296744717285037, 0.09251516457879916, 0.12627820833586156, 0.09826510955463164, 0.16838416457176208, 0.12649194686673582, 0.1476303907111287, 0.08516957241226919, 0.11842621912364848, 0.09398945578141138, 0.1420607208274305, 0.1706297550117597, 0.1635352981975302, 0.1933209053822793, 0.1299839001148939, 0.11384923855075613, 0.08157621210557409, 0.07113786792615429, 0.12804921017959714, 0.16424499917775393, 0.13773227808997035, 0.2244719010195695, 0.2575699210865423, 0.11955590889556333, 0.16456761077279225, 0.14298466499894857, 0.1524601987330243, 0.20478264894336462, 0.11822914922959171, 0.13295694370754063, 0.14505947241559625, 0.14337988832267, 0.14047374192159623, 0.17522912618005648, 0.12746485794195905, 0.09302913895226084, 0.12278681169846095, 0.0966375351708848, 0.10380372797953896, 0.1471176408813335, 0.07413528364850208, 0.15284620458260179, 0.20588445622706786, 0.074567005794961, 0.13047981803538278, 0.12457969947718084, 0.0801041028171312, 0.09272857656469569, 0.14995347621152177], [0.012899063749500783, 0.04621268235496245, 0.057272026024293154, 0.008962400770542445, 0.07016388073679991, 0.02485032699041767, 0.0641051800630521, 0.029816736569046043, 0.029171689639042597, 0.011467767944850493, 0.02651314040122088, 0.05920071569562424, 0.028231670548848342, 0.05621753436571453, 0.04053881493746303, 0.028813610806537326, 0.03703727685206104, 0.006035251126377261, 0.021405470433819573, 0.023269431840162724, 0.053374722847365774, 0.018133632620447315, 0.0584627129137516, 0.026482903449505102, 0.08769848514930345, 0.022218710291781463, 0.046027627831790596, 0.025227508704119828, 0.024571216381445993, 0.06198356539243832, 0.03403827293368522, 0.021312082280928735, 0.06377913974574767, 0.03714935599418823, 0.023068640075507574, 0.009771571803867118, 0.03766048052057158, 0.007742358693576534, 0.011483975522423862, 0.017026786154019646, 0.05124932693433948, 0.026990651203959715, 0.017427104321541265, 0.05807508176076226, 0.02825402403686894, 0.041952209212468006, 0.013934460876043886, 0.003217952325940132, 0.028962632204638794, 0.055172445718199015, 0.03953699349949602, 0.04224402910040226, 0.014513522528432077, 0.043373158550821245, 0.1133976639539469, 0.09061759687028825, 0.01895347759273136, 0.04719182747066952, 0.00949584074987797, 0.055610969648114406, 0.06463433877797797, 0.07103364070644602, 0.015509621080127545, 0.024235171913460363, 0.08234612352680415, 0.07941285162814893, 0.018795357464114204, 0.017023320324369706, 0.006724538870912511, 0.03602903583669104, 0.09980298054870218, 0.06265782882110216, 0.033899869813467376, 0.0610967879765667, 0.01478220317949308, 0.05212945099628996, 0.03153804049361497, 0.03909704464604147, 0.05361620285839308, 0.01837943749706028, 0.037416840859805234, 0.05687942248187028, 0.0544169764907565, 0.0564235879573971, 0.03969332690758165, 0.010908288786595222, 0.03345806559082121, 0.10312391328625381, 0.07488160961656831, 0.028563447667693254, 0.009708270317787537, 0.02281254346598871, 0.05723011323425453, 0.025181521523336414, 0.05866583502211142, 0.10021468697232194, 0.018065755793941207, 0.03634042615885846, 0.11046980231185444, 0.04789563208760228, 0.036811919999308884, 0.058037080088979565, 0.11274059608695097, 0.06506869554868899, 0.04736461800348479, 0.024740982662478928, 0.0132822522209608, 0.019137450435664505, 0.03341782263305504, 0.036450045081437565, 0.10637309518642724, 0.01628339166927617, 0.06058004539227113, 0.023535024229204282, 0.035316355133545585, 0.014403758887056028, 0.07987775519723073, 0.03279879725596402, 0.034874858902185224, 0.0267179230650072, 0.029729784691880923, 0.007529402200816548, 0.05388596611737739, 0.03392427162907552, 0.054125282767927274, 0.027846904085890856, 0.06972140487050638, 0.03455323436355684, 0.0547353652655147, 0.04293530626455322, 0.06871256642625667, 0.022322199074551463, 0.027181401710549835, 0.052740895334864035, 0.055504245101474226, 0.05504301887413021, 0.03927693753212225, 0.04163275545579381, 0.1543562376173213, 0.053575548008666374, 0.014712204738316359, 0.06492806598544121, 0.03129445278318599, 0.036734747773152776, 0.022262192724156193, 0.05344351622625254, 0.030015476295375265, 0.026129043726541568, 0.056640562252141535, 0.046722860643058084, 0.027852982275362592, 0.02939396843430586, 0.03959101071814075, 0.0718238424451556, 0.052722798063769005, 0.010880686459131539, 0.027568741570576094, 0.062017032541916706, 0.04396776726935059, 0.007024731112323934, 0.027605296054389328, 0.05446904557175003, 0.026303470694983844, 0.01759236020006938, 0.04127641695959028, 0.09389179656864144, 0.09662134150858037, 0.022682313247059938, 0.02702389199839672, 0.021586522925645113, 0.004856524874412571, 0.033530658765812404, 0.021729054242314305, 0.014622433627664577, 0.0470333232806297, 0.04573434962367173, 0.06764346559066325, 0.004976514846930513, 0.013229793512437027, 0.03940294307540171, 0.02214936030213721, 0.016962968875304796, 0.02917040943430038, 0.012310414476814913, 0.02016773880313849, 0.0177474783413345, 0.1072321756510064, 0.01902902266010642, 0.020811050962947775, 0.023878152496763505, 0.05917610978940502, 0.018029718958132435, 0.07093032632838003, 0.02928153862740146, 0.004997574214939959, 0.04719043223303743, 0.05748148978454992, 0.03438349776843097, 0.05998222688504029, 0.013925492949056206, 0.014381155851879157, 0.037684411072405055, 0.03110824978648452, 0.027804251003544778, 0.032159834081539884, 0.009827436042542104, 0.0831228775496129, 0.059139187942491844, 0.0380792781652417, 0.025616715065552853, 0.04405459112604149, 0.010291233811585698, 0.01113460579290404, 0.04010702970845159, 0.031505270962952636, 0.029021974332863465, 0.0740613583184313, 0.051302961946930736, 0.016531695728190243, 0.09748629978275858, 0.03549405497324187, 0.06581876194104552, 0.031702652559033595, 0.023541798182122875, 0.03204167674994096, 0.03673023180454038, 0.035777577650151215, 0.06285283554461785, 0.03278743497503456, 0.0441706259152852, 0.06460460092057474, 0.02795419452013448, 0.026864391475101, 0.024310900662385393, 0.022804665568401106, 0.04783744028827641, 0.08346692979102954, 0.02717466115427669, 0.0684587741852738, 0.0510340447362978, 0.053747236452181824, 0.007423398001265014, 0.011508202005643398, 0.09279831618187018, 0.06607565635931678, 0.01274081003430183, 0.051865157365682535, 0.025734148803167045, 0.011016442895197542, 0.05131532612722367, 0.06076577898056712, 0.0398161486373283, 0.04555555140541401, 0.06552012171596289, 0.04434658170794137, 0.02175486984924646, 0.013558689242927358, 0.03024562927748775, 0.01993157999095274, 0.0895621367089916, 0.061764795100316405, 0.02482565429090755, 0.036080180943827145, 0.03800166065047961, 0.018365388641541358, 0.070656518364558, 0.012356196639302652, 0.019989089014416095, 0.1233765073993709, 0.0771618657745421, 0.07014661838184111, 0.026767927120090462, 0.037271558030624874, 0.08006673568161204, 0.04370218972326256, 0.03461987551418133, 0.0383751613117056, 0.041392422062926926, 0.03893358662026003, 0.03732502977072727, 0.02830255492881406, 0.033608992453082465, 0.010120393271790817, 0.04178017195954453, 0.03226508175430354, 0.014018015572219156, 0.07748901189188473, 0.07333098852541298, 0.03337798785651103, 0.019152107852278277, 0.0163827132928418, 0.020059340713487472, 0.05769426352344453, 0.017041786813933868, 0.0381574708444532, 0.03674369065265637, 0.012907814598293044, 0.026782805325638037, 0.09112910731346346, 0.05274640578136314, 0.07059941010084003, 0.009292934792028973, 0.026444358154549263, 0.03307492072053719, 0.06055644138541538, 0.04154459202254657, 0.08836255146889016, 0.013830381158186356, 0.05573721638938878, 0.02553928494307911, 0.06752325251000002, 0.014198184908309486, 0.03451706208579708, 0.04228544465149753, 0.010145592896151356, 0.024886104074539617, 0.04185113240964711, 0.07063452110742219, 0.031892334372969344, 0.05433230115158949, 0.02984273771289736, 0.034342627695878036, 0.07139944529626518, 0.029281072929734364, 0.04641262436052784, 0.03781987528782338, 0.03361599090567324, 0.03765757501241751, 0.06771609958377667, 0.07980496535310522, 0.022587223720620386, 0.029250800726003945, 0.03408153643249534, 0.04101379687199369, 0.029389740047918167, 0.010438861827424262, 0.03715477738296613, 0.08816715882858261, 0.06351808930048719, 0.043536308585316874, 0.02459891704347683, 0.015952549656503834, 0.05949365993728861, 0.04094148571311962, 0.05397937653469853, 0.019154916881234385, 0.030559218212147243, 0.04608377130352892, 0.09317774660303257, 0.02759226023044903, 0.019903009160771035, 0.038408587643061765, 0.23765002435538918, 0.11117271264083683, 0.23076007375493646, 0.11325003593810834, 0.21938535443041474, 0.12260046583833173, 0.20002928213216364, 0.10746706539066508, 0.09626542974729091, 0.13977149210404605, 0.17086228472180665, 0.05253189170616679, 0.11193008176633157, 0.18176418176153675, 0.19566702714655548, 0.12487402040278539, 0.20274209906347096, 0.09302728358306922, 0.30148413497954607, 0.12252596163307317, 0.13941917975898832, 0.15961187513312325, 0.08558097455534153, 0.08528980033588596, 0.23111971851903945, 0.10457185824634507, 0.17237678548553959, 0.14109300478594378, 0.06762051096302457, 0.14086856448557228, 0.1477883048937656, 0.1646510578575544, 0.1741237417445518, 0.14644090610090643, 0.1312932712608017, 0.09290649904869497, 0.11873996947542764, 0.13986893609398976, 0.08978755664429627, 0.10007979421061464, 0.14456738397711888, 0.10592753940727562, 0.09378202550578862, 0.176395277667325, 0.15788670832989737, 0.18309247767319903, 0.1839429492247291, 0.10383834174717776, 0.11281577564659528, 0.15731550694908947, 0.16837896953802556, 0.20576465874910355, 0.13306286302395165, 0.10168395383516327, 0.28290066809859127, 0.2225900668418035, 0.1087197290326003, 0.12125385372200981, 0.1338993525132537, 0.1973346626618877, 0.16167632216820493, 0.088983521272894, 0.2509019320132211, 0.15814637095900252, 0.1853401164407842, 0.1806675991974771, 0.10490110464161262, 0.17842511093476787, 0.14379653002833948, 0.1349249412305653, 0.2128593678935431, 0.1424757594941184, 0.07392746745608747, 0.14295932807726786, 0.11833828204544261, 0.20863868499873206, 0.14582887175492942, 0.17177931207697839, 0.16322769282851368, 0.10992007868480869, 0.13584792061010376, 0.12892688886495307, 0.30400773393921554, 0.22732455341611058, 0.1841034460812807, 0.08550852609914728, 0.15916553267743438, 0.29759038297925144, 0.1371078350348398, 0.16551126638660207, 0.14112472417764366, 0.19872103905072436, 0.23154752212576568, 0.1536948059219867, 0.18849405110813677, 0.14316457643872127, 0.1268459958373569, 0.19632753857877105, 0.224747504980769, 0.19679345889016986, 0.1375251595163718, 0.10196743940468878, 0.1743414136581123, 0.14733280433574691, 0.1577474072109908, 0.19257699139416218, 0.11079795032856055, 0.13119242823449895, 0.13649586006067693, 0.1211597716610413, 0.23689052526606247, 0.10320233603124507, 0.18366577191045508, 0.1283166802022606, 0.12394298872095533, 0.276282224804163, 0.24203525623306632, 0.19408099818974733, 0.20547188149066642, 0.12710024078842252, 0.11826341418782249, 0.07486334536224604, 0.1828469306929037, 0.14753287250641733, 0.2257358527276665, 0.1396232406841591, 0.16111969656776637, 0.1145256171002984, 0.2422245781053789, 0.17143366421805695, 0.21517798566492274, 0.13444003678159788, 0.09823916407185607, 0.25674109056126326, 0.0785612891195342, 0.08790553692961112, 0.08407734625507146, 0.18707309063756838, 0.22407857759390026, 0.13702584255952388, 0.14096804196015, 0.17630188580369577, 0.10727665256126784, 0.14008401049068198, 0.10509102765354328, 0.1454673270927742, 0.13476058520609513, 0.12829748826334253, 0.17520721798064187, 0.15886313718510792, 0.07505119778215885, 0.08034586484427564, 0.06801162278861739, 0.18303028569789603, 0.1080603085574694, 0.1483398096752353, 0.10955091958749108, 0.17223623755853623, 0.1297166378935799, 0.095993143186206, 0.14369384647579864, 0.1292209723033011, 0.18400570523226634, 0.11255128905759193, 0.14219973993021995, 0.11374607260222547, 0.20494918688200414, 0.08795656700385734, 0.11976477893767878, 0.17406156461220235, 0.11756537976907566, 0.11167891672812402, 0.17648886248935014, 0.11182181726326235, 0.16991500742733479, 0.13260599691420794], [0.027605672694335226, 0.04052285505167674, 0.022407763135561254, 0.08844910815241747, 0.024876443167158868, 0.04032572949654423, 0.029874356914660893, 0.01431290702385013, 0.04048240058182273, 0.053327982386690564, 0.017411224216630217, 0.06395816060830839, 0.022530165551870596, 0.03751403623027727, 0.046866974589647725, 0.039219706814037636, 0.030766585405217484, 0.03963281218602788, 0.005311494796842453, 0.03013889174326323, 0.0377527443197323, 0.003298834362794878, 0.05515278622624464, 0.08638123981654644, 0.022068497746658977, 0.07858759083319455, 0.028235652171133552, 0.08379023158340715, 0.0021059574419268756, 0.04459869669517502, 0.027427214008639567, 0.0759728932462167, 0.045011174952378497, 0.06804755757912062, 0.008375139314011903, 0.10270915663568303, 0.016697168684913777, 0.03579113668820355, 0.027135305062984116, 0.036023822249262594, 0.041007158361026086, 0.026605641687638126, 0.07343454781221226, 0.049774905855883844, 0.05309398322424386, 0.05127375843585469, 0.029766777042823378, 0.06391765418811701, 0.023580874112667516, 0.04933074531436432, 0.022156757659104187, 0.04336455705924891, 0.049396573813282885, 0.019205924691050313, 0.03177607693942264, 0.028725944612233434, 0.083346917090239, 0.03553038681275211, 0.051188960642321035, 0.018713071840466, 0.023613311532244552, 0.04631891337339766, 0.015564723689749371, 0.04514321044553071, 0.007328403098654235, 0.026585373634588905, 0.002125383389284252, 0.0554921443836065, 0.03597258066292852, 0.026281211830792017, 0.0394268031232059, 0.05846607113198843, 0.027409654794610105, 0.0980840774718672, 0.02420821154373698, 0.021773605367343407, 0.025854738523776177, 0.10189456792431884, 0.05199322236876469, 0.013630109824589454, 0.03531680042215157, 0.07013970156549476, 0.07409561585518532, 0.023680153062741738, 0.025660726278147195, 0.06795657027396373, 0.051496922242222354, 0.022107044896984007, 0.011635613918770105, 0.029265233642945532, 0.0613341973075876, 0.021716239207307808, 0.10291166647220962, 0.0544242124306038, 0.015687920204072725, 0.034810436773113906, 0.08137272263411433, 0.029742288024863228, 0.03041526382730808, 0.068114091118332, 0.07320302000152878, 0.05015803217247594, 0.0034604254233272513, 0.036382108883117326, 0.024835736367094796, 0.02612462794786552, 0.024136514512065332, 0.029692586394958198, 0.05513536059879698, 0.04172454428044148, 0.01218817811604822, 0.055136492374003865, 0.020106910524191335, 0.030746506599825807, 0.05591771041508764, 0.009172404443233972, 0.03379095593118109, 0.057050131290452555, 0.08129715715767816, 0.02970435314637143, 0.046921288667363115, 0.020295814938435797, 0.0385728434775956, 0.03463631779595744, 0.006659446025878424, 0.026139413384953514, 0.02539200388127938, 0.09325678533059545, 0.012209771830384852, 0.010661648993846029, 0.06975480151595548, 0.04343725413491484, 0.02274312482768437, 0.0364097575948108, 0.022206045541679487, 0.03466097194177564, 0.04557051681331359, 0.0579583716171328, 0.034268950985278934, 0.028752019970852416, 0.044816899244324304, 0.07097095891367644, 0.02433789813949261, 0.05557650431001093, 0.029873714956920594, 0.056420110995532013, 0.06407444772776216, 0.0703094010532368, 0.020841137629759032, 0.05685494274075609, 0.03214519521861803, 0.06124676117906347, 0.008136059223033953, 0.02847075342288008, 0.017253716359846294, 0.06884466129122302, 0.09288972651120275, 0.07187273513409309, 0.06603659712709486, 0.04854519313084893, 0.0350314038223587, 0.05429439595900476, 0.022596945855184458, 0.0688171127694659, 0.013119300710968673, 0.05863015256181825, 0.04935435303195845, 0.04995504365069792, 0.06487768157967366, 0.04271268051525112, 0.03342131443787366, 0.010925077094725566, 0.06241343216970563, 0.022937890353205148, 0.020276346549508162, 0.06736916038789786, 0.03835130868537817, 0.011201843444723636, 0.06399711593985558, 0.03929990700271446, 0.030031172718736343, 0.03561063524102792, 0.05279474557028152, 0.025163938189507462, 0.04376531309389975, 0.06337365994113497, 0.03356110908498522, 0.029974103417771403, 0.02613939854199998, 0.028762898000422865, 0.04666067237849347, 0.021337638136174064, 0.05664733806042932, 0.0396579487278359, 0.014343993734655669, 0.04286620860511903, 0.05183151952223852, 0.043540486876736395, 0.027690316492225975, 0.04697529104305431, 0.03779681304877158, 0.015871299328864552, 0.02749629125901265, 0.049393200752092525, 0.02221152444690233, 0.02760002123977756, 0.039884804718894884, 0.025021581277542282, 0.02187102523748763, 0.02304460376763018, 0.05408147379057482, 0.054301116106216796, 0.014254743982746731, 0.041902117955032736, 0.049665839833323844, 0.037965922529110685, 0.06943826811038889, 0.04172946100879926, 0.10712463103118353, 0.032329526147805154, 0.023427546402672306, 0.015494242852582829, 0.03233145202102605, 0.053843025452806614, 0.02919924558227649, 0.025119923266174737, 0.04368086039903574, 0.02663730912900064, 0.0824383131111972, 0.032074238479253836, 0.03411124831472989, 0.020954096216883045, 0.05886362479941454, 0.09737250627949834, 0.05091114137030672, 0.0162974386694259, 0.06280936795519665, 0.027189940119569656, 0.07750343182124197, 0.024657906651555095, 0.08337665494764224, 0.038308256698655896, 0.06795935332775116, 0.04764900899317581, 0.043821630970342085, 0.02693692898901645, 0.06917558494023979, 0.06523915944853798, 0.02534791474317899, 0.022754834062652662, 0.07113110696082003, 0.10567252262262627, 0.0037386519488791237, 0.006105837255745428, 0.04449668478628155, 0.039280228957068175, 0.05227842972090002, 0.017347896755381953, 0.03358526599186007, 0.0642875925404951, 0.012600212940014899, 0.03586000428185798, 0.06867366304504685, 0.012029917907057097, 0.014417479342228035, 0.050121945241698995, 0.1376633028849028, 0.05977750915917568, 0.021061945117253345, 0.048554173117736354, 0.025591424528101925, 0.008962422107288148, 0.024512692471034825, 0.021218747933744453, 0.03499896825815085, 0.032239626088994555, 0.0739584001712501, 0.006284468954618205, 0.011214337500859983, 0.037315452354960144, 0.019402716279728338, 0.02885570727812592, 0.0069598061782016885, 0.020424000540515408, 0.015932752867229283, 0.05334504065103829, 0.043792138021672145, 0.032314033815055154, 0.05619737392407842, 0.044938129067304544, 0.026335511065553874, 0.040433908652630635, 0.009523513581370935, 0.04012037723441608, 0.0921142786683049, 0.04620931300451048, 0.07963886528159492, 0.07936545807751827, 0.04830592100915965, 0.012813481134799076, 0.054786963082733564, 0.03794023308728356, 0.058817303652176633, 0.05263868675683625, 0.023447031489922665, 0.0382765410176944, 0.045148446297389455, 0.034754204243654385, 0.05992925609461963, 0.04592428376781754, 0.04463475022930652, 0.04143148129514884, 0.049299063030048274, 0.0207270992177655, 0.06538853893289343, 0.03998474232503213, 0.02108699074597098, 0.01939402944117319, 0.03945031436160207, 0.03188604838214815, 0.014937662708689459, 0.034640169542399235, 0.0450935273693176, 0.05098268811707385, 0.06796508270781487, 0.06715756666380912, 0.016000837495084852, 0.018684087262954563, 0.013666715331055457, 0.030585603417421225, 0.00960524352194625, 0.04341435145761352, 0.009605230534361908, 0.050793035989045165, 0.0257777147271554, 0.04981441037671175, 0.022622781871177722, 0.0009157182182661927, 0.04374077769170981, 0.0345001040113857, 0.05118823333759792, 0.048484964136150666, 0.043004797262256034, 0.05091137885756325, 0.05948751495452598, 0.061286347336135805, 0.014778448839933844, 0.03127937234239653, 0.0551755256310571, 0.007140551142583718, 0.03696850944834296, 0.011028034314222168, 0.14018376998137683, 0.07506163979996927, 0.0925534445559606, 0.1914206362562254, 0.09414210813702084, 0.12110998097341508, 0.10354223966714926, 0.07698213987168856, 0.15368952183052897, 0.13075620867311954, 0.07536851044278592, 0.11864229541970417, 0.12385376772726886, 0.11881854064995423, 0.11418305657571182, 0.2027204431942664, 0.21705824648961425, 0.11557878402527422, 0.09285694584832527, 0.1308074762346223, 0.08836638837237842, 0.07881847297539935, 0.10297324988641776, 0.13075417518848553, 0.1300131852622144, 0.14213262009434402, 0.12577546265674755, 0.1454729971010238, 0.12023048402625136, 0.16692078293999657, 0.06317983323242515, 0.14620457659475505, 0.08282794806291349, 0.09708483499707654, 0.2188376197591424, 0.19003566994797438, 0.06869261007523164, 0.09407935955096036, 0.15605949622113258, 0.08911112614441663, 0.16237882431596518, 0.23826033691875637, 0.14613481471315026, 0.12699559796601534, 0.11622834877925925, 0.06973218827624805, 0.14748773508472368, 0.11576481076190248, 0.12209654014441185, 0.13466950884321705, 0.18898682232247666, 0.09771778306458145, 0.15339048084570095, 0.15163329779170454, 0.15444459771970287, 0.12693443015450612, 0.2912649989593774, 0.21805033466080204, 0.13086751598166302, 0.14216806506738067, 0.16086965217255056, 0.18062621704302728, 0.17869970557512715, 0.20453432633075863, 0.1563228399027139, 0.10625485621858388, 0.16287797800032422, 0.13174091989640146, 0.18382508133072406, 0.15699227195000276, 0.15842708089621738, 0.13739615940721706, 0.1329851453192532, 0.13963744539069012, 0.13698828988708556, 0.17218260996742174, 0.16414120240369812, 0.2350201943772845, 0.16212471295148134, 0.084737954166485, 0.13892002607462928, 0.15705905039794743, 0.12168921981356107, 0.2712633472401649, 0.09566063876263797, 0.16636479558655992, 0.21680477337213233, 0.17041528917616233, 0.13373930094530806, 0.1453869228134863, 0.24418291286565363, 0.14099015796091408, 0.21802055969601497, 0.2979668299667537, 0.08444939230685122, 0.09386885678395629, 0.17328667338006198, 0.08598248386988416, 0.16025482735130936, 0.22510162816615775, 0.16978991101495922, 0.11791508717578836, 0.15092396788531914, 0.07102922492776997, 0.18881894851801917, 0.16032625164370984, 0.1219778781523928, 0.13895320007577538, 0.17165059398394078, 0.17558437742991373, 0.09316966461483389, 0.09760003391420469, 0.13507095136446878, 0.17446777172153816, 0.15377046045614406, 0.19064479507505894, 0.10410810500616208, 0.11528103437740356, 0.2856683742720634, 0.20940535323461518, 0.11632384092081338, 0.08953550102887675, 0.1327410529484041, 0.14087558520259336, 0.13990166480652988, 0.1488143834285438, 0.12349729935522191, 0.1679153647273779, 0.06314752754406072, 0.12090664735296741, 0.13059004180831835, 0.08651314914459363, 0.18653159000677988, 0.2080523586482741, 0.14861560659483075, 0.17136845912318677, 0.10935693702776916, 0.21883010922465473, 0.1739443201222457, 0.10242056509014219, 0.09057320159627125, 0.1091273091151379, 0.10136988435988314, 0.12394313715049066, 0.10622519999742508, 0.0674485182389617, 0.11861194900120609, 0.14863055344903842, 0.20640108006773517, 0.13036502263275906, 0.11185266092070378, 0.14393782010301948, 0.09421511320397258, 0.09220366293448023, 0.10468836058862507, 0.20397152606165037, 0.1957044907612726, 0.16593976761214435, 0.1392475061584264, 0.12516685703303665, 0.14961541310185567, 0.12659102358156815, 0.1628802638151683, 0.17077732365578413, 0.17403187870513648, 0.17205656360602006, 0.1655495908926241, 0.10724111110903323, 0.11295128439087421, 0.18021626950940117, 0.11832648189738393, 0.20141220011282712, 0.1179172468255274, 0.1223187540017534, 0.1250289659947157, 0.1365915228961967], [0.015816541817912366, 0.0297929321823176, 0.021977386131766252, 0.11818600818514824, 0.04029573188745417, 0.02046066634648014, 0.05340426032489631, 0.06472292894613929, 0.0797128351405263, 0.03234079937101342, 0.008046593320614193, 0.018206012427981477, 0.05575723582296632, 0.015354874940385344, 0.08792020176770166, 0.045307570180739276, 0.013632244426844409, 0.03769494214793667, 0.04519422938756179, 0.019881457192241214, 0.009123944055318134, 0.010184931361436611, 0.027883556904271245, 0.05247370732831769, 0.022736089267709758, 0.029800891716149636, 0.05496946832863614, 0.03469082854280714, 0.04547717318928335, 0.02434769819956273, 0.0688245045603253, 0.013745829201070592, 0.044698033161694184, 0.007434283452312229, 0.019745031895581633, 0.037121399291208945, 0.03666362405056134, 0.04842393362196162, 0.020478860096773133, 0.019699903750733938, 0.04533305182121694, 0.034889033922809176, 0.07064854769851081, 0.10497524519450963, 0.026930322019325104, 0.009922096978698391, 0.05106311095005367, 0.007325535161726293, 0.026504822781134862, 0.025335470782010816, 0.017400492761225905, 0.027745914485421963, 0.02543665519624483, 0.09263437576009892, 0.05375331093091518, 0.06602051478694193, 0.048428434747620486, 0.045748684206046164, 0.015930966146697756, 0.07978320558322594, 0.01995204100239789, 0.03764152977964841, 0.01653510033065686, 0.10580510730505921, 0.016857710070325993, 0.028564043241203763, 0.03452040546108037, 0.06800033472245559, 0.020648082754632924, 0.019708356812770944, 0.06456827279180288, 0.039731443612254225, 0.04319340667279903, 0.03886853366566356, 0.043881878518732265, 0.06692445065709762, 0.05456515369587578, 0.04472030501347035, 0.10628464602632448, 0.028702221861749422, 0.015290513110812753, 0.08078527564066462, 0.09524007109575905, 0.04538181092357263, 0.006521382902064943, 0.06854950173874386, 0.11695438442984596, 0.07270492758834735, 0.036621102699427865, 0.03282764082541689, 0.10626163202687167, 0.06465413927799091, 0.01893381810077699, 0.022595314985665027, 0.05170192940568086, 0.08472461035125889, 0.0025484989419055637, 0.09010075780679472, 0.05004418300813995, 0.062267822795547545, 0.03908122576831374, 0.05478525243233889, 0.010549696944508469, 0.016645088471705094, 0.020518331220955588, 0.046156535172485746, 0.048614168335916474, 0.048297772227670066, 0.012379655927361455, 0.0619235701742582, 0.07715696017839946, 0.04195285859168507, 0.03759408798941877, 0.02490082086296752, 0.008215785364882322, 0.04358342011983041, 0.023518960442743264, 0.03181083171512, 0.030119493858364876, 0.05436023559013847, 0.01613861350051593, 0.02502276129234815, 0.07198337450972758, 0.05397908709710464, 0.015399628300656332, 0.04293672005587723, 0.051287146779941395, 0.030853848984406795, 0.013567188689194154, 0.04955000913469121, 0.04997213160095271, 0.052049343576072715, 0.049457222121418454, 0.025616933999117464, 0.033770661902963184, 0.05179659405257553, 0.06285146999289282, 0.06337780112517066, 0.04682343278545886, 0.03263618527853396, 0.04603514578775503, 0.036040750637766905, 0.03232382645364851, 0.007258289160745335, 0.03315506153739989, 0.029116967380105052, 0.04849522061704192, 0.043278608936816454, 0.05851826266734861, 0.008556454340578057, 0.04182562850473914, 0.0476507381972624, 0.035702249660971574, 0.04128000153286848, 0.0562184917362174, 0.04897661099676043, 0.00334804640715447, 0.017789450503187254, 0.04104409134015441, 0.15313633979531005, 0.00765110978136363, 0.04234493520925753, 0.010542323707340984, 0.03309857667773031, 0.02581217820988968, 0.025488013670837972, 0.06898978084791452, 0.11120834315079264, 0.08607860683696344, 0.0555398607684765, 0.08361435742699541, 0.026790603442350402, 0.056532023154431954, 0.04354153701569885, 0.03926603909349069, 0.018425044327159412, 0.03350417522597127, 0.03443777844950091, 0.007250419612319092, 0.053125917838769965, 0.054437033031717874, 0.04781459327205084, 0.02937193406978622, 0.04496417102927808, 0.029831713109160773, 0.03980786626925692, 0.030063109188631643, 0.05138033455295954, 0.04049711365951225, 0.07031081855529919, 0.04123989958316088, 0.06617476276005618, 0.039626648649573326, 0.023373781514237635, 0.04853905556956306, 0.0208575669239508, 0.06394087598891929, 0.02339261907764012, 0.06266550262807868, 0.03411866237001959, 0.028225785317772534, 0.025560554895491805, 0.019351656519575045, 0.021118576551089063, 0.019366148808330763, 0.022743612789781764, 0.03629844657552894, 0.06004148366628215, 0.03473882323305588, 0.05113390812766738, 0.01868721541541163, 0.057841843299684115, 0.0462684881495079, 0.06995242802076973, 0.03177331243932713, 0.0258545789620257, 0.007639509085493046, 0.05564574297750369, 0.02193913584051188, 0.04385372143588029, 0.028647161925619002, 0.08199937728932127, 0.07380890194326639, 0.027139963895024266, 0.04923707514535636, 0.054112822108436376, 0.02208274327131221, 0.11910235276445746, 0.05701841560949106, 0.05108884863147978, 0.02035189903835999, 0.039669129182584584, 0.03524332780216355, 0.01693137008260237, 0.06118425750173628, 0.051440782481222413, 0.02724659010709729, 0.06711803245707415, 0.016960786961135454, 0.029566254306701012, 0.037646401979145594, 0.06097996280004736, 0.0571866975951707, 0.07124257754185237, 0.022848135013191495, 0.040436513590975665, 0.05451498451293446, 0.0624096323736012, 0.005053941722508171, 0.03547897082171403, 0.04377495730295777, 0.018304842378711328, 0.037166373440413736, 0.03296953203971498, 0.07177840074291453, 0.07844854204449803, 0.05443449488666374, 0.06106068249209784, 0.04943414875015151, 0.08356411402928643, 0.06366169487591833, 0.06335250131087378, 0.0682729329855647, 0.06846920136013068, 0.07364179997239262, 0.01977246909518726, 0.05784843357105274, 0.04598377432557754, 0.01198123580252286, 0.051546776012401097, 0.03857734460325446, 0.10698797937948257, 0.03165256872307509, 0.04585001333907712, 0.049947076695389114, 0.06077658836147748, 0.06882877933094278, 0.026456481136847287, 0.044674495948129334, 0.03226758650271222, 0.03645457218226511, 0.038295128106256016, 0.039126786214183085, 0.06852632446680218, 0.04456531118194107, 0.06394311727490276, 0.07214442797703668, 0.04690381480031647, 0.037574417365249246, 0.03793852243688889, 0.031223084151861258, 0.02917783276643604, 0.051074350776616484, 0.006337201793940039, 0.018053233907266986, 0.03585362923331559, 0.0509831853560172, 0.05758505649282597, 0.05314504298439715, 0.028526726200652774, 0.03296356888313312, 0.014463999013969442, 0.08269282523542643, 0.05683423310983926, 0.04675240925280377, 0.027653619144984987, 0.08676865574670956, 0.04739362484542653, 0.09351604719995521, 0.03767958340176847, 0.035122127665090375, 0.02253663151350338, 0.027015637460863218, 0.1181401137728244, 0.04420372570166364, 0.012827890859625768, 0.03407982207136229, 0.039945363969309255, 0.024825260952638928, 0.019789653524640016, 0.021015275160607416, 0.06066280599043239, 0.02144128091458697, 0.01691307614237303, 0.020016099479107652, 0.06473982764873654, 0.05759247796959244, 0.013302505431056488, 0.08184952283045277, 0.010878379307541763, 0.022886455808475148, 0.0031390835965794395, 0.016563092285650782, 0.05910888976359274, 0.06569467484951019, 0.040909198578447104, 0.04477692717046011, 0.021645202687068377, 0.01971885263628792, 0.04413648712215945, 0.049045337582356296, 0.007348198032559594, 0.07010760367847979, 0.03689812416268978, 0.02804997053317493, 0.04502416995819658, 0.014129131777735893, 0.02656425396708073, 0.035389193217270076, 0.03092988201387925, 0.08836221750243567, 0.026066133723361418, 0.11737505599739961, 0.08615533006377518, 0.15134544839384034, 0.269938376150094, 0.1673027515062131, 0.11339960838085972, 0.20267423707991838, 0.1376201247330755, 0.13069038017420098, 0.104030216607498, 0.09193281613988802, 0.1473423928837292, 0.18510813592001796, 0.11151781131047755, 0.17291138414293528, 0.14875190943712369, 0.14219846343621612, 0.16113238729303703, 0.1566185857518576, 0.1119227716117166, 0.12855051609221846, 0.06544454881804995, 0.17063974431948736, 0.15197277098195627, 0.1482005976140499, 0.09174709368380718, 0.13498993852408603, 0.129943824140355, 0.1749698494677432, 0.09580753205227666, 0.15989687468390912, 0.1257634101784788, 0.12909413926536217, 0.07323367812205106, 0.07100758390151896, 0.18202080158516765, 0.1541389516205527, 0.14407262380700558, 0.1036520923662465, 0.1672186958603561, 0.11586324180825613, 0.10080959997139871, 0.09288666886277497, 0.1850299135548994, 0.08804664146737196, 0.18451894487952814, 0.13110184168908745, 0.1854335083044134, 0.12655694416025653, 0.12773577152984217, 0.11269288341281936, 0.19126054015941918, 0.08535813729395159, 0.13756381056737155, 0.1442401116946712, 0.19774254702497274, 0.15588172216666862, 0.14325563795864582, 0.09791739110369235, 0.19119857082841918, 0.1352562359534204, 0.31054136459715664, 0.12017206216114573, 0.1672863055136986, 0.16217406577197835, 0.12209972395794466, 0.16857059206813574, 0.16460776096209884, 0.1262857930851169, 0.07880685836425982, 0.25875649647787213, 0.21372529095970094, 0.12472548696678132, 0.1349774852860719, 0.09773388766916469, 0.15842760039959103, 0.11397702895919792, 0.13665825681528077, 0.19036289770156145, 0.14685153641039506, 0.1484168297611177, 0.22102854360127822, 0.2859351021470502, 0.192648564116098, 0.13821158674545586, 0.10714623495005071, 0.16623128321953118, 0.21046862821094692, 0.16572973981965333, 0.11110732943052426, 0.18891087092924863, 0.3039893286768347, 0.1838938338914886, 0.1216184115037322, 0.17427472426788881, 0.2508372167358175, 0.10183391961618327, 0.21946504624793306, 0.1396817367640324, 0.4479787132004276, 0.20004008780233562, 0.15151145198615268, 0.09397536981850863, 0.1892211480299011, 0.10595013038255274, 0.24771071184659377, 0.12363948742859066, 0.1446710026357323, 0.11667995306197554, 0.2812266204273328, 0.16570003906963393, 0.12756386044202372, 0.14352960919495672, 0.14796935924096033, 0.11529988492839038, 0.12068436670233496, 0.17883998632896692, 0.17570392257766798, 0.0981957335898187, 0.10218190524028614, 0.10785907521494664, 0.16039304493460804, 0.11084220459451899, 0.2730200404766947, 0.15337933378759772, 0.1318779500434175, 0.16350558260455728, 0.12044550647260621, 0.1722074273857288, 0.21105508814798668, 0.15976646449416876, 0.19573778350604698, 0.09709201898658648, 0.1287782218423672, 0.0977113560657017, 0.0861260894453153, 0.10080840511363931, 0.16780261765234172, 0.14703671709867194, 0.10384884313680232, 0.1384589890949428, 0.08306395102408715, 0.10419365236884914, 0.1388012824463658, 0.11078331517637707, 0.21629433904308826, 0.23619957093615085, 0.1296621494111605, 0.11717181143467315, 0.127781888586469, 0.2094233428942971, 0.14844850462395698, 0.1777070979005657, 0.07229586321045645, 0.11663031080388464, 0.13284192566061392, 0.16793455666629598, 0.12180160323623568, 0.14661238674307242, 0.18878049042541534, 0.07782387634506449, 0.112667598441476, 0.11031389934942126, 0.11337998599628918, 0.08730656438274309, 0.1186335009697359, 0.12653246812988073, 0.20104412455111742, 0.3098024526843801, 0.13026499596890062, 0.1744140253867954, 0.15174150292295963, 0.18203879124484956, 0.11775389270042069, 0.15207604825263843, 0.15426625963300467], [0.05160704211448319, 0.016082765032479074, 0.030222027126001194, 0.04377425226266496, 0.05595880313194357, 0.06915760270203464, 0.04018773455754854, 0.04256203195836861, 0.018369835961493663, 0.04736292961752042, 0.04890332762442995, 0.02826115050993394, 0.01382049389576423, 0.022654104213870596, 0.12818591378163546, 0.010903198581218021, 0.04039433362777345, 0.057219752852688543, 0.08220419520512223, 0.011033368500648066, 0.10276470638928004, 0.03333204149384983, 0.017611695002415217, 0.02661109647306148, 0.038332320837071165, 0.01509844436441199, 0.036575924459612, 0.0347760456497781, 0.013091788368910784, 0.03799459169385955, 0.048236719449050725, 0.02965256237075664, 0.041440194108872674, 0.007668344305784558, 0.04156547976890579, 0.03540893434546888, 0.038898167622392066, 0.0648726720828563, 0.021127918334968854, 0.010684631452022586, 0.013702428404940292, 0.12785550963599235, 0.014945591628929833, 0.05526839799131267, 0.04532696621026844, 0.0573682454705704, 0.09542209765641019, 0.03217749348550569, 0.0279670930467546, 0.07666764737223275, 0.03767680776945781, 0.008227825783251319, 0.039812771865399554, 0.1604147898615338, 0.010859269932552706, 0.021595100297417957, 0.0622669470612891, 0.03148088027955964, 0.05500680206750985, 0.0826109663466923, 0.0036559136151481653, 0.03262145364715252, 0.009461735353397671, 0.06344864654238336, 0.048974807577906176, 0.02800233578454936, 0.012174721123301424, 0.049303734849672765, 0.034838482533814386, 0.06851343336165883, 0.048831521125975996, 0.01448666049327585, 0.06933461234439164, 0.04614337318344042, 0.05635049383272417, 0.009019621284096502, 0.0590244444902055, 0.028622719291888643, 0.13067887688521296, 0.03165816451655701, 0.03793463729380164, 0.018585214638733305, 0.07588951295474544, 0.03281534714915324, 0.06593529396923259, 0.024168272866518237, 0.049293315096292645, 0.08353876968612894, 0.0641240380355157, 0.014491823058051523, 0.05635590037854854, 0.02278415260661859, 0.07877211101003923, 0.019529781238816213, 0.018053371204587165, 0.027272235020063818, 0.025753103254828602, 0.04198487484245561, 0.016850976935529616, 0.052514755516313016, 0.0894099147990346, 0.022686430311296135, 0.06621354739763774, 0.0402894607395865, 0.02285961789311841, 0.027528749087650795, 0.03484355140244588, 0.0903581568854861, 0.0216886201815214, 0.032282314423355274, 0.07745082097244449, 0.00799574136181036, 0.019525046336639207, 0.0139434213815548, 0.10753225564258173, 0.05788593800389208, 0.017481846989539918, 0.011594310617510928, 0.015491867052332964, 0.005403943205237738, 0.025225718272849917, 0.09070129628526047, 0.0391248788946541, 0.03345256998727564, 0.031427063440787606, 0.06901190427015536, 0.08760757205891423, 0.03276989060395863, 0.040051090327324346, 0.020988416836189572, 0.03903519034793135, 0.010975019922625506, 0.08505727062583901, 0.03771995994611643, 0.041406482050661, 0.007028439531495678, 0.0431641103932634, 0.06043947520083748, 0.01720786647638306, 0.07267022476298735, 0.03735571386641823, 0.03917308509699069, 0.06625335619901307, 0.1276825595414266, 0.02307715250935871, 0.07883496349677444, 0.09000409307191148, 0.09410351645783521, 0.009064634396054316, 0.04226269411446992, 0.023738836534903385, 0.012963887566002086, 0.03172231576172635, 0.059985410698573105, 0.04284474198357202, 0.013971361386211356, 0.011184383492945926, 0.02666510070412187, 0.03795818563958164, 0.009763841408130247, 0.03453543395153247, 0.06520034512504935, 0.03710851560754236, 0.05390145473938901, 0.09352444831165485, 0.022449436582974158, 0.12470135232433677, 0.011876260869030375, 0.03321439253340941, 0.05379835929488763, 0.06990225141635165, 0.041085031916736625, 0.019951629110437352, 0.035434705423540436, 0.09794795274501666, 0.010416784789413214, 0.050928874989040196, 0.09851743976469152, 0.022489321454486344, 0.023352229545707814, 0.024803124542813748, 0.03798994956014212, 0.04739145406347234, 0.04724560720205773, 0.007670352279092185, 0.07698980625718832, 0.06516576846479438, 0.024159298445738386, 0.026171103090746328, 0.041326745704282075, 0.020143452020420227, 0.10584663788904436, 0.034792235601344146, 0.016363781105610542, 0.036112853995291516, 0.11839254788355902, 0.016518511474714614, 0.014076072857278632, 0.06421249461709522, 0.032742724288254976, 0.015742417963338085, 0.04349241797171999, 0.036553407699102536, 0.02595650737930555, 0.019385685845918488, 0.05187566617678385, 0.07735420076642185, 0.0530303663254017, 0.03042830892809434, 0.03930302402295638, 0.034540135457064025, 0.04756687179906294, 0.010840828490472632, 0.018152922893932555, 0.07769483912852593, 0.051028931338805705, 0.026282723956683185, 0.13192016340326518, 0.056471456482540816, 0.04710312598035671, 0.026050004998978693, 0.030334892944665626, 0.05465220761834644, 0.03840139623207506, 0.06792720349039882, 0.08371381263714284, 0.11567257664864883, 0.025494882247585338, 0.07963571857544594, 0.07056803209707141, 0.042163179532508366, 0.01994141344766831, 0.016052737737481948, 0.03125634349999018, 0.059701995633076876, 0.042971875591319986, 0.03003601337695727, 0.04101191181689501, 0.07007083026110195, 0.03255483476095833, 0.05525826767552644, 0.02993574737047311, 0.022754791389161255, 0.014793860464124009, 0.08060889682383277, 0.022175814156071283, 0.12003162555629387, 0.11468169817817397, 0.02690740078833187, 0.010384230481577106, 0.047143357805907726, 0.027809633429569658, 0.0937780253298115, 0.08428374494542368, 0.14883575728163123, 0.06016892526531592, 0.023431754379998893, 0.12962665990926325, 0.04797871923074126, 0.026477281680854503, 0.07342342301853932, 0.03132973077299539, 0.018353590348851867, 0.06083705113269389, 0.021829004836035892, 0.01103890492231585, 0.06997051415964961, 0.04300258937291801, 0.11652118540951051, 0.018617357054608874, 0.052179891063133255, 0.08754209236940369, 0.037150777206989005, 0.02299403011420509, 0.04370404880319256, 0.05356191104510799, 0.04611060365277808, 0.12573719752253965, 0.0741667729744222, 0.020106415140617173, 0.03433903941186145, 0.031222516408888623, 0.08815132139716297, 0.06742672136169858, 0.022527432593051344, 0.06739247124642134, 0.014518763018713798, 0.021284164540702477, 0.0033182851257151924, 0.020778576435986906, 0.008566279448132263, 0.04190889376332052, 0.019447458507784177, 0.04339382365287747, 0.005225413087828201, 0.05148716671101283, 0.12210529006551951, 0.02633284304465633, 0.005321810185705544, 0.031212879621307366, 0.039258895922102965, 0.037352808358264156, 0.06953744872589596, 0.03607595441280864, 0.04911632029688917, 0.07817044446710497, 0.06107326931669377, 0.04308198062062729, 0.015506950276176212, 0.052152349962852895, 0.06420343299396336, 0.0324108506902121, 0.026487348914088216, 0.02532311402319465, 0.07738555650576018, 0.0782127765705809, 0.0439727878983831, 0.06926243106136099, 0.046298500601551495, 0.12081007167580537, 0.04673793366237078, 0.05137789288710337, 0.09484131514909677, 0.05036975948314648, 0.01800319460016908, 0.05481203283125069, 0.03715989078045823, 0.03169500472722575, 0.03933462838176638, 0.04677437311329413, 0.0054855135840625735, 0.04410150970215909, 0.0984707660973072, 0.06033118843333796, 0.042562454982544295, 0.030380086027435027, 0.02956177730084164, 0.03253431437769905, 0.026113781459571328, 0.031344447561423294, 0.05659267888404429, 0.017092197194870096, 0.08875252038706094, 0.057385144173167646, 0.06704973260639235, 0.04611905671481509, 0.042750403881655075, 0.04933274911309127, 0.012443000086932443, 0.029225461948954035, 0.07743313559331, 0.011590173144213622, 0.145021949429065, 0.22172264463733882, 0.11204313312191516, 0.17080153251299635, 0.08437791606411338, 0.19015322613995522, 0.17344399384455755, 0.1069471167284064, 0.17679599288385361, 0.19186098215868697, 0.1929224462946877, 0.10238578062853776, 0.1825172538519837, 0.16156673664227128, 0.16503691527759656, 0.21490866027306765, 0.1659173844382167, 0.10513093293411657, 0.15003171341959387, 0.18152084638131782, 0.1832595796440728, 0.09577552322298288, 0.13416839588899165, 0.12203392514493316, 0.08384936591028236, 0.10961789841530845, 0.17807360010920092, 0.16719752980861813, 0.062022895508562215, 0.157712125510443, 0.13987794576678425, 0.12016305248835124, 0.14290926279500127, 0.09765079681528732, 0.13446277618641034, 0.13661579112522304, 0.10518053808482364, 0.15994235349353403, 0.13892939197830856, 0.13323192426469177, 0.1452938129659742, 0.27427207329310477, 0.10797497641760856, 0.12503521487815306, 0.18869275372708216, 0.15039964055176824, 0.17194964981172234, 0.09314845403423533, 0.16150212526554242, 0.20649162208428606, 0.18605153920361772, 0.19260866625700146, 0.17789483157685027, 0.20631040446460247, 0.08050908538280055, 0.11360128701198846, 0.17865476111182943, 0.17049509973730892, 0.174746448174119, 0.18860108364606276, 0.12197981515782885, 0.14618528075516224, 0.17426535836420953, 0.142168213496916, 0.10530622079386376, 0.07122155991964974, 0.12902057758765295, 0.12334011247730814, 0.161814940511249, 0.14778687997022644, 0.29500399832613766, 0.18875426292652264, 0.12643809663131833, 0.14478811353910714, 0.2621931448811665, 0.14507600746583194, 0.29830234008841217, 0.1816304022213444, 0.37945132004097104, 0.1906875873100944, 0.09138658802839927, 0.17725038022035733, 0.32740604714490473, 0.13742824987275526, 0.2784915390657261, 0.09761377106769942, 0.12297340246732347, 0.1857129269046709, 0.16522371384780854, 0.0478106413356727, 0.13187907810788602, 0.1842517568729818, 0.20171986485365778, 0.15336906246375293, 0.12963319080881774, 0.17551514989463612, 0.25772226916160434, 0.12380210682749748, 0.1131550781428814, 0.22124768496723846, 0.18194498377852142, 0.29271292907651514, 0.16622378752799705, 0.10282272749464028, 0.10756965246400796, 0.13057742529781535, 0.21220234455540776, 0.18901588482549414, 0.11232002099859528, 0.14587679965188727, 0.12931148463394493, 0.12332043814240023, 0.14416999358218163, 0.1379569261916913, 0.19801598391495645, 0.12175692594610155, 0.10300609734258614, 0.15494936204049736, 0.11346986750140786, 0.11974714550888166, 0.17285278416238725, 0.09876148760668002, 0.10714602714870125, 0.13836274738423526, 0.10000580950872973, 0.19654391915537417, 0.19691129709826782, 0.14075811806833372, 0.11585816551814787, 0.16326431039487943, 0.1663007927709259, 0.08600586152169853, 0.1438400792540051, 0.17097008909331635, 0.13619324192404747, 0.09614512018742971, 0.14189323293976486, 0.1411253327387385, 0.15257509803632274, 0.17008990194881335, 0.13355763803701848, 0.19689247623318806, 0.17676924588158727, 0.2006690134294331, 0.12204309809021652, 0.13034050207352266, 0.16599321708781645, 0.23469753825338557, 0.16742300911573693, 0.16760465718107298, 0.1408070998149924, 0.13312655413756147, 0.2479764897725545, 0.15938068128889427, 0.16727333277231082, 0.12538605777081102, 0.2279233923763968, 0.2136500074993819, 0.047656059396103956, 0.1178341633931268, 0.08154790659318678, 0.14533479436067864, 0.12106661728466861, 0.08715672476682812, 0.1564590833731927, 0.08404057283769362, 0.18343193602049723, 0.19059470010688528, 0.16391259123338386, 0.20454268291359767, 0.12422371350112371, 0.11755581348552369, 0.20785295841051266, 0.10136160199181177, 0.1563262240961194, 0.07738707048702054], [0.04108272012672387, 0.018897697773354594, 0.09144669456873089, 0.07141157941077836, 0.039924706288729794, 0.026171223689743783, 0.02870496224204544, 0.08671138421050273, 0.026620809330779593, 0.02230386802693829, 0.05837890588736627, 0.09513734301435761, 0.02606066223961534, 0.04807605189853348, 0.0005923325863932405, 0.01572214619955048, 0.026690261365729384, 0.0361922229785705, 0.04073855285241734, 0.027055728278355673, 0.0447129466192564, 0.029743790873908438, 0.027519639224919956, 0.003279754209870589, 0.060796207035309635, 0.007543380552306189, 0.01821269361244049, 0.025300964625785127, 0.0324064460437512, 0.027472733636386693, 0.0293828937356011, 0.04238679975969717, 0.05427317424619105, 0.029597094253404066, 0.028981117247894872, 0.05262228900392074, 0.028078027426090557, 0.01613310490938602, 0.04114269308047369, 0.039624284909223206, 0.036452178756007925, 0.05597447729087435, 0.03836506439256482, 0.08049187497817911, 0.0945425932877697, 0.02966676893265685, 0.044596277293749154, 0.038566757866647094, 0.03221574006602168, 0.07543905900092795, 0.014662494759249967, 0.029262070238473825, 0.026041078817797825, 0.03351817955262959, 0.005886129074497148, 0.008644889585411875, 0.03849734850518871, 0.02750550502241822, 0.05211815921938978, 0.10794352419907227, 0.03779628612392116, 0.0483968266780721, 0.049344174476573244, 0.010795461002999218, 0.022185341476870235, 0.007341974660448614, 0.027103090287710074, 0.0430675050301943, 0.039770198563928716, 0.030964484649302904, 0.023356567398877814, 0.07007546868408099, 0.06704263025312684, 0.144984545186162, 0.04015739556052722, 0.032404854136984795, 0.025113423907896504, 0.01584077108418569, 0.07948437982122414, 0.03641040326328948, 0.10340819295379333, 0.04206048484775238, 0.041717022613738663, 0.04769803155795671, 0.022504782245960087, 0.02302993892953964, 0.04597889099386521, 0.04077698496985249, 0.05320935379131697, 0.04642738938855473, 0.023012665442365687, 0.11760232388041914, 0.05035704278270714, 0.07243850399390794, 0.10151468479307368, 0.11089081526733935, 0.15131150255911052, 0.1659381645731628, 0.0021739314433943946, 0.08121640406898223, 0.03785982509725727, 0.022540906284120865, 0.02879299394408008, 0.03947288678318728, 0.09471945450059138, 0.031049944809637964, 0.025630235140852164, 0.045319652344915085, 0.014157278656057315, 0.03197660524165258, 0.027746849591494538, 0.01169593753729714, 0.04930177557980642, 0.02885700603656005, 0.01428423971447046, 0.039540830402984284, 0.02556264960730914, 0.010008311346609844, 0.09649712083046325, 0.03658960966276936, 0.03736801867489703, 0.060466288996394724, 0.026097942172782496, 0.054261811965261586, 0.07284105973667465, 0.0249608030935633, 0.042908355171675794, 0.040836041371221654, 0.04488928090722766, 0.010431313257868169, 0.02621120132971555, 0.049739961832528934, 0.06313747886451893, 0.07091096369549632, 0.10303335642674938, 0.04567071417113766, 0.009202855690091383, 0.021927298585069366, 0.010017339573096251, 0.06147592524939682, 0.024916721376939677, 0.04987038686522283, 0.08046108327107504, 0.011881428999913624, 0.0217977529973723, 0.04064332046255004, 0.013373509482335066, 0.09435897853109054, 0.03953963554522488, 0.053131873573875055, 0.01033937693136977, 0.015461960356333293, 0.01585851212439593, 0.05246313172392547, 0.04980090328899678, 0.03348030033521354, 0.026376262394478545, 0.08305573544930667, 0.05869687163794879, 0.020126067211094778, 0.04246013137162663, 0.0438823126751231, 0.02426889695925638, 0.08507503021974117, 0.03397273016162217, 0.011079827872890746, 0.03305559519503731, 0.025487698258075397, 0.05022658806410618, 0.037000251104473136, 0.03844122729788069, 0.04550261772237718, 0.021476245347002987, 0.013837554943165742, 0.04272907826816663, 0.08106025619781576, 0.03637792317022104, 0.026190261633018963, 0.08490749780321494, 0.06546356264152564, 0.012584190899360692, 0.01860595581092639, 0.04933368050842546, 0.0358767768193502, 0.014119771440164186, 0.04146674444200471, 0.09637444381951354, 0.07143302747863345, 0.034223624315927736, 0.06124736231868155, 0.04197744965495076, 0.029052387544652447, 0.04394013711134903, 0.014903154697094578, 0.023376353055937216, 0.02110187637299532, 0.054435815909528174, 0.044815259097958915, 0.07276726799318567, 0.06157592964882497, 0.04300542066630442, 0.03892742679454386, 0.04786433943081647, 0.03885876700223889, 0.0257755458005704, 0.0657265204063151, 0.044278675195528194, 0.022846570936962962, 0.03553480259142816, 0.037937108645564876, 0.02347511992411455, 0.07579431767226197, 0.07096818328136578, 0.020572146204358432, 0.07148178658098914, 0.025118752528214827, 0.05872467991139274, 0.014630161240347661, 0.08224160686950199, 0.008843315754347714, 0.0836121680913493, 0.0769333956122864, 0.037625013283104636, 0.040961939303088, 0.05026083817938343, 0.024166662406059913, 0.0325812218216015, 0.05238271631242242, 0.015463927047676407, 0.012591617014550138, 0.07838706253096461, 0.02533650978875812, 0.06410428206436336, 0.02652509640029166, 0.06191412263433449, 0.06517757603432983, 0.04113168331969064, 0.10153433686355129, 0.08534307911759242, 0.028930098305863794, 0.061192406283225864, 0.045367955026449636, 0.028228243681951426, 0.017358446384605486, 0.1110238155524712, 0.04865843373409007, 0.09027053893078119, 0.05301694829540793, 0.035772675764746964, 0.016730149727663957, 0.05324403435224667, 0.062186116047087125, 0.06588272022781894, 0.02274757956911344, 0.1555528913741, 0.06429122906411067, 0.12324295792495832, 0.4001818795222789, 0.13344066072022542, 0.044317786378087476, 0.12880280177341774, 0.06038761021045502, 0.030261650390457362, 0.02469173003191827, 0.1867531953030266, 0.1556356408400461, 0.17032819072483107, 0.16970319848041981, 0.03957434950280003, 0.0491122644598363, 0.15338107041316107, 0.17082140722777694, 0.22692036494845524, 0.22344644588883966, 0.020778680336661637, 0.05288124659273308, 0.059069819399155676, 0.06636239995714277, 0.033751017253962345, 0.03928339421690907, 0.04127164495002944, 0.07637785354745574, 0.01723644101730315, 0.015057912896736525, 0.03827872664260212, 0.05150109682290349, 0.06299880114966072, 0.026072731416206807, 0.03003096306201769, 0.10989530579536222, 0.06620186599320732, 0.03150854754494503, 0.048081235800054856, 0.06543339433846995, 0.032164253570954315, 0.004776575624418911, 0.034445151686668396, 0.016445745750388596, 0.0568959055817686, 0.04687903820013162, 0.058525557979010046, 0.06113331648521125, 0.046552307685487904, 0.03688073193188757, 0.016589776205364615, 0.031377395207528025, 0.0422057973628398, 0.03889899882778991, 0.05482454173034057, 0.05860648918314837, 0.040794822489260696, 0.0780380675860215, 0.07138623506762087, 0.08886328592780046, 0.03324418605188839, 0.03918217640602961, 0.029949098607175983, 0.040025200505624525, 0.00772568541833607, 0.03555845112714451, 0.05101061142340768, 0.04041937369038351, 0.026897157295024954, 0.039941530776559375, 0.009056018989213044, 0.03551269772287924, 0.026577833414194174, 0.02319915973203024, 0.015172498642641585, 0.03789129215874709, 0.031028116391098592, 0.03977731576014776, 0.05547991378989536, 0.015509189706790494, 0.004923957339997287, 0.026714386731327977, 0.008600522141932743, 0.01186571402286063, 0.03729397831193637, 0.03754274992388673, 0.03571825036488008, 0.02509657158952905, 0.04392170216306113, 0.03187914269801695, 0.07911809283541515, 0.02736361937422771, 0.027291306359984446, 0.03541681595379487, 0.012454160132620018, 0.017874804907478392, 0.04091491311555728, 0.02232421400549356, 0.13098168798023835, 0.11990108177997172, 0.2007155164028518, 0.13795901904813945, 0.10112804069649428, 0.0704296215553768, 0.13147350924555212, 0.2569139515981078, 0.14158314879750833, 0.1411185198230669, 0.2015142305754125, 0.26851538219489157, 0.12712698779068887, 0.18626584176672623, 0.10261390940286219, 0.14920540619641542, 0.12852854852098972, 0.20998799853259698, 0.14187331369612366, 0.1490689697675407, 0.16321762930601835, 0.08160539335221983, 0.12083114866982214, 0.16516732546733692, 0.16759638965595514, 0.11492270321468823, 0.12250710366060957, 0.105459674668964, 0.1699156456743367, 0.12696378951659426, 0.11321951140416786, 0.126837253337726, 0.10077451865072362, 0.22593719739234075, 0.09201489767292514, 0.09570904905558564, 0.13490007928339764, 0.07169053045799956, 0.09480115753831342, 0.12466060841688886, 0.1575807059998624, 0.11856540892040357, 0.19082368235103786, 0.12873027910245582, 0.12133298150729388, 0.22276825649896637, 0.1882665086304769, 0.185937411733903, 0.1157205193885602, 0.12868270743638277, 0.12612266902578995, 0.12362926063360646, 0.08129346126224846, 0.1247249823063612, 0.23301281849853694, 0.20490868046181276, 0.2055886064772494, 0.07670281032915227, 0.15757785615278408, 0.1936016746913083, 0.16087089898064733, 0.18692863901378587, 0.19091511494480073, 0.09987361074308865, 0.2050178058561869, 0.13395290588960052, 0.09439923262107186, 0.13887891109334305, 0.23270041885552928, 0.1258143808809109, 0.1662393577862531, 0.24312214634846896, 0.15596732147969306, 0.22073109081247821, 0.14624158007791266, 0.16428489703685045, 0.2563069044845179, 0.12447031433111988, 0.2888478833483532, 0.1573328286758624, 0.1876972962054424, 0.33063931739889085, 0.20108442316995934, 0.20793066127225757, 0.2950105885975063, 0.2583474840503186, 0.10160558304050937, 0.1023641915526241, 0.28281882405281067, 0.25713683338835835, 0.28213115001562983, 0.22729952819645405, 0.2439014904666692, 0.31830004358198494, 0.37898053124081343, 0.4614687612047419, 0.533821361605078, 0.3183678461937234, 0.1163318486942444, 0.13924563594628125, 0.11439369292929769, 0.13702952361200005, 0.1566179475048557, 0.1525406920700334, 0.2926393080269918, 0.10676825171685778, 0.15506834315601736, 0.0971658033085987, 0.14343958668177947, 0.19059541256865487, 0.13168931094696745, 0.12911870435345918, 0.21890974167035893, 0.14221985213225707, 0.10310597557690926, 0.1476349326549098, 0.08925608985009603, 0.10275611974066123, 0.2008537933579646, 0.18767528410535306, 0.15891100571025163, 0.10941213055048138, 0.13566625770181417, 0.18594324501464143, 0.15025032043922693, 0.14668612653622404, 0.15024920721771196, 0.12796111725037917, 0.13588143599918112, 0.12184872961370274, 0.08605541472206824, 0.21567044517723843, 0.16653448023134843, 0.09489241943811066, 0.12275635395781137, 0.18402139423415065, 0.12174015340860933, 0.2074164865189232, 0.11643289952189662, 0.12368794225039892, 0.1094188544084318, 0.1417415973264724, 0.2558861661236733, 0.10435667252750136, 0.09753198639373295, 0.1308854907983914, 0.13958916126284748, 0.18902951065683737, 0.12478114804252982, 0.16985127178486437, 0.06752131550456397, 0.12968203896889463, 0.1174620802339632, 0.15404668782139197, 0.09341881101136096, 0.3136735246516764, 0.0940195276052691, 0.16017185524106026, 0.10154120172956027, 0.10326348157832399, 0.10670867952285334, 0.07006896747043356, 0.17328854359220713, 0.20015556598082185, 0.1276021997909993, 0.12626495357835665, 0.14798334130318835, 0.11703267358825542, 0.12948344025062397, 0.23122309969039634, 0.1449796321685426, 0.1451662674662657, 0.08165974082658067, 0.10551201092312112, 0.10031144818640314, 0.20358599518658593], [0.05671279919624794, 0.023114271025406197, 0.045039380274829455, 0.050333776453044266, 0.08021973684662953, 0.043664529439411126, 0.04076521079696249, 0.020223973187967204, 0.03572832501959056, 0.0408647142467089, 0.020080840731679928, 0.027242098258284386, 0.04587045208609197, 0.0068346109674166655, 0.020357177563710138, 0.05809601403598208, 0.02010232590691885, 0.0445016089361161, 0.04173644461843651, 0.020378313929541036, 0.03009430907695787, 0.06258004432311282, 0.047488040872849524, 0.026906810780928936, 0.018172658456023782, 0.029650087308255024, 0.07656379122636281, 0.057526512173353694, 0.047250471980078146, 0.0478743361600209, 0.02161402877391083, 0.051609339061542414, 0.023978142053238116, 0.05574530950980261, 0.032780213878140785, 0.012320439036557218, 0.020987982679798733, 0.07387165795080364, 0.021902982116444036, 0.0912952444923576, 0.07087151112500578, 0.09280187849071808, 0.08018645894480869, 0.029925043745606672, 0.010377161524957046, 0.03555633229552768, 0.03675972475321032, 0.027408194619056303, 0.05410682184447069, 0.045562271552626044, 0.024798690210445784, 0.028608971006178763, 0.039672758284723386, 0.07207330054370686, 0.05647716730891261, 0.006653186010225909, 0.026705480959208217, 0.09093477594433352, 0.018663550181372557, 0.01899311570014106, 0.04068098445713986, 0.047067306222743355, 0.03648222460469697, 0.042250842016073875, 0.05541318729228806, 0.04550171972368844, 0.043148740514880046, 0.00561493068744312, 0.050826109800254926, 0.10294563457136974, 0.09849919035332277, 0.06559965768246911, 0.04837481457798276, 0.0603221713390667, 0.023954395182954613, 0.2025611634599045, 0.2738570049405098, 0.11219837557291612, 0.2606970048509538, 0.08661790328915231, 0.11091371794464067, 0.8009314129594713, 0.3693625645246357, 0.572119269054383, 1.483638344798237, 0.6885661580599844, 0.23992760136025026, 0.25709369976539165, 0.43621044780593365, 1.2495705485343933, 0.6243269832339138, 1.3597430242225528, 0.6502732972148806, 0.7426402252167463, 3.4577788319438696, 3.7094274535775185, 4.877471001818776, 1.3465919299051166, 0.36349701520521194, 0.34214824670925736, 0.19677480129757896, 0.08276188949821517, 0.050162002662546, 0.03670587822853122, 0.028679974129772745, 0.07190860313130543, 0.01438310491721495, 0.09908471518428996, 0.04735405353130773, 0.09036631308845244, 0.03720389271620661, 0.04754645902721677, 0.05175279620743822, 0.014273807901190594, 0.05644080578349531, 0.021567902440438047, 0.021124753075127956, 0.04993493887013756, 0.047217832325259224, 0.03565015831554774, 0.026666709309211, 0.0982131295313593, 0.06386919194483198, 0.05221054547291715, 0.02690807799808681, 0.02004198559006909, 0.02056448909570463, 0.029104068853484932, 0.04704460021457635, 0.010304791921953438, 0.0599156525277067, 0.06552803301019594, 0.05779173348855693, 0.05581195808190387, 0.09470513847190887, 0.00906682465938502, 0.058714482802315615, 0.017125647646025755, 0.04781350973644294, 0.047680583666078746, 0.02451228614518186, 0.014291764164227061, 0.0018695060612117231, 0.03816745644144248, 0.027863004979735706, 0.015560983265459072, 0.03166554517520126, 0.022848103471915238, 0.02523930699680932, 0.027564815609366633, 0.11032517999410629, 0.03022724256879883, 0.0055601054555154406, 0.07528740854468197, 0.03219108963094186, 0.029092893964843825, 0.06840697227744386, 0.039217524899868295, 0.029169767476560082, 0.086356593092205, 0.016071040954557247, 0.03446894494118169, 0.03599942414439283, 0.05600174750725273, 0.019645816028059926, 0.03730217162228655, 0.0822564127156511, 0.027721325277525466, 0.013412735697784228, 0.017132122884504497, 0.06864533526822925, 0.008551239825465018, 0.04473643930396065, 0.01959296212589834, 0.023049904557410628, 0.02538470485887956, 0.010039858188974904, 0.03318328170280438, 0.023536829503427725, 0.03217409444914665, 0.010097437716467539, 0.002986421036439424, 0.06375953962560743, 0.05638056936732028, 0.03136815175821539, 0.02534015929995803, 0.008871934824128402, 0.07190052114310674, 0.03433814883464947, 0.01574943682498997, 0.060565313760889694, 0.016461777995573357, 0.024511052324669436, 0.025618024956202134, 0.007793927288730629, 0.016023588032112457, 0.03583942452678457, 0.01991277025808813, 0.03326450605527498, 0.04662131999793928, 0.03028013543371344, 0.04513724357821047, 0.017385542196279857, 0.07658222617465071, 0.023112664275686257, 0.02940728812973248, 0.03172603763232473, 0.04612382501363754, 0.028071676497347653, 0.006788385835534427, 0.010017269996751565, 0.08432448143139482, 0.028533878648886457, 0.04763968019688036, 0.017506261792732403, 0.14215034258086234, 0.06675498123513535, 0.03092313403612934, 0.017582311520527583, 0.08908938863896765, 0.0888530962402001, 0.028310538582445588, 0.016237458294199314, 0.04563028196571395, 0.01778795507561881, 0.025496279340586625, 0.04949077090714127, 0.020023882752866484, 0.03737138431461062, 0.04871931581874378, 0.08258204485173337, 0.023662408311793115, 0.014507352498185355, 0.07284995066584088, 0.008236802987084957, 0.1148008499876596, 0.04823790688533336, 0.009609287299099378, 0.055876758706290275, 0.021331834541342687, 0.04886021255515516, 0.10212323846644722, 0.01783903338946402, 0.05622944583592471, 0.06422905935323797, 0.1508899181499146, 0.09967706035240553, 0.09229856877936982, 0.0799508864292875, 0.06420779682230204, 0.048912229685811326, 0.10784799495013431, 0.09299208351876587, 0.1572345386375673, 0.19373906106920913, 0.0899079255759716, 1.060941545292735, 3.8573338044807315, 2.645117864012718, 3.387096212245524, 4.990008138120174, 2.651491309516132, 1.2571625411510468, 0.9123331226874143, 2.861517914570868, 4.117036331444979, 3.6831893865019083, 4.16569747030735, 2.1331112505868077, 4.828333938494325, 10.281318258494139, 13.193248305469751, 15.76431194320321, 6.719482010230422, 1.0854929778724909, 0.1744918618351221, 0.26054076792206615, 0.31286826473660767, 0.017167775658890605, 0.06318417479633354, 0.06027683353750035, 0.028227759430592414, 0.05168874886294361, 0.07151525001972914, 0.0628507426881697, 0.057153965171892196, 0.050216665549669415, 0.06726562336552888, 0.04259368455677759, 0.046351656928891316, 0.04755037385621108, 0.007529108588641975, 0.06198282695550006, 0.07152565493015572, 0.06212075510120485, 0.04184180732409004, 0.037787795954500325, 0.08023199712624773, 0.0348300034966087, 0.08296028041513637, 0.07664502671104856, 0.07792607008013874, 0.00202689459456451, 0.009055443824763643, 0.04496155866945628, 0.03274101734859869, 0.09494103753240779, 0.05550113179197069, 0.057493657295708545, 0.008745164868741995, 0.03549537228536792, 0.04550362333247904, 0.0077437177515093936, 0.15359176613856107, 0.08984420477645472, 0.12576547334901989, 0.04065100540174171, 0.11219732914469205, 0.01733941215206869, 0.035157472448190674, 0.02689996261324268, 0.032590472692390904, 0.062010434849071316, 0.030376729664567392, 0.06094213924370706, 0.030633824462711345, 0.03944360534660518, 0.027042616384278517, 0.039429871903848834, 0.031194860275718383, 0.01299881952945725, 0.058680789297795855, 0.061201048592920415, 0.048452981282025576, 0.060726170559064485, 0.037707477022195235, 0.017883975997392554, 0.03594006717321463, 0.02756347974354867, 0.1272544145467691, 0.02276037419505883, 0.008583089093008311, 0.05386887445638422, 0.012916219420731068, 0.009680590064817807, 0.035661030779010616, 0.033972362798522227, 0.037619744034600444, 0.06432430658605881, 0.016262669050775003, 0.06693554576486349, 0.03994502629211638, 0.11244365538004786, 0.16106519324239343, 0.10321570953237824, 0.16192200273508206, 0.178058757155668, 0.10385402332758531, 0.1644145353930071, 0.1920208110823296, 0.08981218852568418, 0.11609102919464931, 0.11653947934973985, 0.20530613022856414, 0.1302934647537768, 0.1623935336829163, 0.07389329155557789, 0.16284213226754218, 0.06806240795413032, 0.14897102111717686, 0.20215865224599838, 0.10875758598558605, 0.09495206584688276, 0.18617774883750826, 0.11977225978625938, 0.13660223950864747, 0.08594182902015746, 0.12333591192145832, 0.20412442332599312, 0.16120937769301236, 0.132735368097201, 0.16147862887009978, 0.14663399808341637, 0.13934496499132365, 0.14731043600477278, 0.13377195544308051, 0.11738199507817626, 0.20844185259193182, 0.12255107591045089, 0.12832462118240073, 0.09233788776327856, 0.19741454743780196, 0.21914952958468348, 0.21305688307620585, 0.21071466500870883, 0.20006411854410544, 0.12602194474311545, 0.1305467597558163, 0.09246820147382095, 0.1550282523385249, 0.21000926848500967, 0.24713891674764454, 0.1488046019221656, 0.16414388897828758, 0.1746199416811578, 0.15149270533584058, 0.14352208381751552, 0.08360410836758092, 0.11807158385636285, 0.3267250524368137, 0.11934122783713974, 0.15960255375830457, 0.10133348201634362, 0.19594482786487788, 0.19515752792358398, 0.08826937482808717, 0.1223290030611679, 0.24446742259897292, 0.1207135479489807, 0.13330799440154806, 0.1503625331679359, 0.2522678696550429, 0.25364784873090684, 0.212992271699477, 0.2710504992865026, 0.14079951506573707, 0.12866259523434564, 0.3434958087746054, 0.5460441776085645, 0.20622927288059145, 0.5394793767482042, 0.08255819964688271, 0.573510944377631, 2.329367157071829, 1.5998464403674006, 2.4263873510062695, 4.505020212382078, 2.0321680046617985, 0.9947432193439454, 0.775262484094128, 1.9495791988447309, 3.2957384269684553, 3.3943438483402133, 3.6920592980459332, 2.1506256982684135, 4.595268219709396, 9.212183877825737, 11.447177398949862, 12.848000731319189, 4.6241233963519335, 0.4698660137364641, 0.47868667636066675, 0.5138887593057007, 0.532557632541284, 0.17327889567241073, 0.16845377802383155, 0.132043567718938, 0.16030783153837547, 0.12775334558682516, 0.22334802226396278, 0.149614893598482, 0.22924901655642316, 0.16396801482187584, 0.22710128570906818, 0.17157467227661982, 0.11596263764658943, 0.2098455061786808, 0.20015675341710448, 0.10069815907627344, 0.23384253960102797, 0.18123348680092022, 0.15588240494253114, 0.09927177350618877, 0.2369062291109003, 0.1797765024821274, 0.16577481786953285, 0.15798354375874624, 0.1503230509115383, 0.20319756993558258, 0.14446673390921205, 0.19581830652896315, 0.17772312829038128, 0.24569037806941196, 0.11637960589723662, 0.13032761838985607, 0.0774816275225021, 0.17979026190005243, 0.1614963513566181, 0.1570259060827084, 0.23839318135287613, 0.20643711875891313, 0.20851740322541445, 0.17943815735634416, 0.18239785713376477, 0.12466356216464192, 0.14666117553133518, 0.07531575858592987, 0.15156291250605136, 0.157932736328803, 0.20069218327989802, 0.18794037925545126, 0.11209214455448091, 0.1545868971152231, 0.08517550959368236, 0.10943446919554844, 0.11808842318714596, 0.11772393962019123, 0.17338963894871995, 0.12256813046406023, 0.2115525645785965, 0.1368247502250597, 0.18413001496810466, 0.0894086086191237, 0.1179619538015686, 0.08365021058125421, 0.21059685648651794, 0.17896717559779063, 0.14471437374595553, 0.13860048697097227, 0.13106096419505775, 0.1103669183794409, 0.20353477215394378, 0.1531679107574746, 0.1037813893344719, 0.10400102051789872, 0.11167634147568606, 0.17199926980538294, 0.08791821281192824], [0.06861990186735056, 0.011735758398572216, 0.003461069932200189, 0.06780097159207799, 0.09728057644679211, 0.040877067294786684, 0.00837398712974391, 0.03452461343840696, 0.00588733274526021, 0.007185198282968486, 0.043654109686031006, 0.0244246793226921, 0.02902911750425119, 0.07262985192937776, 0.030602644983446226, 0.01120011609600624, 0.04820818758162204, 0.019245881921960972, 0.059653852513292804, 0.059532589293667115, 0.0184270388490404, 0.049396952308597974, 0.026936739741358906, 0.01801023758162046, 0.060089118414907716, 0.004197908237983938, 0.044288119024713524, 0.04041400054120459, 0.055470529332524166, 0.039117297856137156, 0.043657434507622384, 0.03396272601094097, 0.06031804499798454, 0.05447942821774632, 0.014115655303612584, 0.027744411636376753, 0.02847149000444915, 0.07626413425896317, 0.035383144713705406, 0.0694688297517132, 0.024785023560980335, 0.05796451659989543, 0.02291681335918838, 0.0610553575825179, 0.022080967682995833, 0.022804576510679908, 0.05482608910824638, 0.05773364558990579, 0.055608758048038, 0.06243873940547928, 0.039722125948173925, 0.024956012530310545, 0.032875015822355635, 0.04820674039365258, 0.017680269447737373, 0.07767482340568677, 0.04661800259782467, 0.08798629743978381, 0.04308495292207226, 0.06385664222761989, 0.13468723132973537, 0.09773491925443523, 0.04409080422192346, 0.06148350999865215, 0.04209452345094178, 0.02947723554825643, 0.015719717521278653, 0.04411808928125538, 0.06415924552129582, 0.21321681590052322, 0.36641606013290584, 0.16639238863717765, 0.09446170661249198, 0.200977910135407, 0.7085670379456133, 4.165980080142617, 14.944719672203064, 19.189515598118305, 33.94535690546036, 35.85548400878906, 56.51517301797867, 66.08318880200386, 66.15599289536476, 72.22036868333817, 73.39705914258957, 71.4293347299099, 59.446126744151115, 54.550089463591576, 63.16070482134819, 63.139536157250404, 64.01187434792519, 73.8175217807293, 68.36789980530739, 68.25606420636177, 91.86334624886513, 92.9420855641365, 104.75173026323318, 82.186648696661, 63.33399072289467, 22.79481913894415, 6.68902569450438, 1.8006586586125195, 0.24944853968918324, 0.15019286336610094, 0.3061160270590335, 0.016188135159609374, 0.12043329072184861, 0.07607433741213754, 0.024593983616796322, 0.02957383720058715, 0.026046125421999022, 0.06672437506495044, 0.08644499030197039, 0.048662827248335816, 0.041062240561586805, 0.049713166590663604, 0.01615409470105078, 0.06378835721989162, 0.08847504621371627, 0.03863630823616404, 0.07063244309392758, 0.05541342849028297, 0.10677194019081071, 0.05751921686169226, 0.07897170420619659, 0.027287669836368877, 0.028359412717691157, 0.04578604763082694, 0.06579293520189822, 0.02612818469060585, 0.01450946947443299, 0.10869149773498066, 0.02884228182665538, 0.031534003210254014, 0.04947518580593169, 0.04975301992089953, 0.0479799289314542, 0.029848444828530774, 0.06887404291774146, 0.06101511091401335, 0.07491985248634592, 0.041565175488358364, 0.03890807900461368, 0.09446673095226288, 0.07211010364699177, 0.02986636769492179, 0.04276725434465334, 0.010851360493688844, 0.07235423312522471, 0.06308866781182587, 0.03829078654234763, 0.0418452694430016, 0.03748433548025787, 0.03426458715694025, 0.019358029712748248, 0.028579277677636128, 0.04585249953379389, 0.035780479447566904, 0.016943424416240305, 0.021306525450199842, 0.0380737454543123, 0.03815898482571356, 0.06243597119464539, 0.07544061751104891, 0.05140621695318259, 0.014190691072144546, 0.006634371175096021, 0.039862165504018776, 0.02625344437547028, 0.033785167179303244, 0.032851489741005935, 0.07761081316857599, 0.10180841200053692, 0.0547341704077553, 0.01782232207915513, 0.05484836838149931, 0.042872012199950404, 0.03262217353039887, 0.04526048833213281, 0.08289579520351253, 0.06758261690265499, 0.013984268261992838, 0.07875887851696461, 0.020535990624921396, 0.056759773433441296, 0.03345830678881612, 0.04009842079540249, 0.013645456510857912, 0.07043468300253153, 0.0019180043682354153, 0.036339717407827266, 0.044966519926674664, 0.04784519573149737, 0.040804678210406564, 0.02394815001025563, 0.0492694661807036, 0.0415414416056592, 0.04254532621416729, 0.023766783961036708, 0.02320100953511428, 0.003636805631686002, 0.004830895732084173, 0.01426609791451483, 0.02811313657730352, 0.07395794003969058, 0.03448948758887127, 0.012682457745540887, 0.08329922668053769, 0.01984159829589771, 0.03755237928999122, 0.08929829578846693, 0.02032151365710888, 0.03590962427551858, 0.07344662997638807, 0.05594563372142147, 0.016210277135542128, 0.029188215412432328, 0.08174977818271145, 0.044049492571502924, 0.006158273699838901, 0.014319227339001372, 0.011421136950957589, 0.04664213724026922, 0.00845873668367858, 0.030406051919271704, 0.02896436140872538, 0.03988457094237674, 0.021275728176988196, 0.038445654208771884, 0.08415300078922883, 0.031749541449244134, 0.03807342262007296, 0.033196955773746595, 0.1204324966238346, 0.03824199775408488, 0.061244438256835565, 0.06747457504388876, 0.07557769960840233, 0.06429427186958492, 0.08476103495922871, 0.09531444171443582, 0.026726942014647648, 0.0970727379899472, 0.05534785974305123, 0.1839371901587583, 0.2970260538859293, 0.14013765292475, 0.1402285066433251, 0.08808846891042776, 0.42206653801258653, 2.8936266666278243, 13.274686485528946, 30.457009188830853, 39.07574661076069, 57.58471302688122, 58.762220442295074, 82.56257012486458, 89.22024607658386, 92.83268943428993, 99.45885747671127, 98.62997755408287, 92.12454423308372, 81.87482982873917, 76.67188301682472, 85.41009172797203, 83.9094990491867, 83.09315085411072, 94.9610236287117, 91.37473046779633, 97.4577708542347, 120.60181215405464, 120.94270706176758, 132.90096938610077, 113.64620938897133, 94.41020518541336, 44.36520338058472, 16.51616144925356, 6.335265627130866, 0.611908893333748, 0.08380521554499865, 0.2567960391752422, 0.03524811094393954, 0.18624504678882658, 0.017005252739181742, 0.03433672391111031, 0.004598849345711642, 0.03408954791666474, 0.03699391687405296, 0.06561344678630121, 0.05538345685636159, 0.06911771968589164, 0.03343020536703989, 0.04998070711735636, 0.08478862800984643, 0.04137618016102351, 0.06280895235249773, 0.048823899269336835, 0.016706211754353717, 0.10278036570525728, 0.034501543777878396, 0.027145058738824446, 0.02532591748604318, 0.012354886748653371, 0.00804406630777521, 0.02228846660727868, 0.007403345634884317, 0.021188843093113974, 0.01897292742796708, 0.032449976715724915, 0.09230206429492682, 0.018891434046963695, 0.04933786622132175, 0.06332668941468, 0.03812815230048727, 0.030311275950225536, 0.06406158630852588, 0.04041342908749357, 0.04219200825900771, 0.07045774895232171, 0.117613418988185, 0.09213124416419305, 0.02080300051602535, 0.04340033599874005, 0.006172831854200922, 0.03777091209485661, 0.04677789460401982, 0.011501957760629011, 0.02609176008263603, 0.06092420524510089, 0.06272684113355353, 0.03252458853239659, 0.009476501309109153, 0.017327240930171683, 0.060738627507817, 0.05781830979685765, 0.02209309437603224, 0.05085937285912223, 0.046939708772697486, 0.01592058535607066, 0.02748530747339828, 0.043038353469455615, 0.0297606413369067, 0.014648828109784517, 0.04903066532278899, 0.05407790406025015, 0.0419840584800113, 0.03632397645560559, 0.01935738961037714, 0.1185433151840698, 0.025772317458176985, 0.05257114389678463, 0.04908385504677426, 0.1866134934243746, 0.11215941281989217, 0.11815158737590536, 0.20131169847445562, 0.18746314861346036, 0.12097860599169508, 0.15156159148318693, 0.16215781273785979, 0.1257768875802867, 0.09681271912995726, 0.09994021107559092, 0.1353802636731416, 0.14192271104548126, 0.17324744345387444, 0.13615785632282495, 0.11217072315048426, 0.07576019372208975, 0.15032748895464465, 0.1343142575933598, 0.104043055762304, 0.1349225069861859, 0.21634499804349616, 0.12593303545145318, 0.14299083966761827, 0.1131288061151281, 0.12602161819813773, 0.22078948299167678, 0.23583538422826678, 0.14403692650375888, 0.14720472448971123, 0.11631396293523721, 0.1805203125695698, 0.12247322461917065, 0.14039749366929755, 0.12823917029891163, 0.14807915256824344, 0.08248480866313912, 0.2319708580034785, 0.1264159064157866, 0.12813933659344912, 0.12555486668134108, 0.2324208221398294, 0.10326183401048183, 0.11202862413483672, 0.1193367897940334, 0.0935708251199685, 0.15587265312206, 0.1736989661003463, 0.11060476928832941, 0.07817529069143347, 0.07689418795052916, 0.12846561439801008, 0.16150334238773212, 0.17950080946320668, 0.14854974841000512, 0.11252492797211744, 0.20557777112117037, 0.24839992955094203, 0.14496373536530882, 0.14465195912634954, 0.4402650677366182, 0.19258319574873894, 0.18743497668765485, 0.26535030046943575, 0.22104739415226504, 0.16608947364147753, 0.1351703843101859, 0.17530207929667085, 0.3232109535019845, 0.49592979485169053, 0.34383532649371773, 0.2953170659020543, 0.10455871481099166, 0.2585361973615363, 1.5771417086943984, 9.065260961651802, 25.683365240693092, 37.350073009729385, 54.976156800985336, 59.34324726462364, 84.76265206933022, 93.56632366776466, 98.08202415704727, 107.91377618908882, 107.95379564166069, 100.13450682163239, 88.99927273392677, 84.58263292908669, 98.64523753523827, 95.64264625310898, 95.2013835310936, 107.71143704652786, 103.62275764346123, 107.89417684078217, 133.11737537384033, 134.0115585923195, 151.80232554674149, 121.6511182487011, 96.12329766154289, 42.721939757466316, 14.58148481324315, 4.452916933223605, 0.3865919087547809, 0.2658266108483076, 0.5159505049232394, 0.1243355477345176, 0.2810781018342823, 0.32130378240253776, 0.12839448696468025, 0.1448822920792736, 0.12139849088271149, 0.16419864463387057, 0.27711209433618933, 0.14987148373620585, 0.20308182458393276, 0.15027346060378477, 0.1107895492168609, 0.2161463547963649, 0.1736815701588057, 0.2755629055900499, 0.15615222015185282, 0.08264334624982439, 0.2585052646463737, 0.1873097021598369, 0.11464952607639134, 0.14330697973491624, 0.07057984708808362, 0.07599365111673251, 0.12373103134450503, 0.1745679319719784, 0.1158420683350414, 0.22455833153799176, 0.07284568331670016, 0.2165665736538358, 0.15727044374216348, 0.1476268284022808, 0.14940636494429782, 0.12516779213910922, 0.14181642065523192, 0.13688170263776556, 0.14317796478280798, 0.20206579472869635, 0.19604938162956387, 0.18499310303013772, 0.13123340962920338, 0.1413823533221148, 0.1602831477066502, 0.08689664653502405, 0.17306866007857025, 0.13894738163799047, 0.1195395816466771, 0.12354806225630455, 0.11568343426915817, 0.11347190840751864, 0.08893539299606346, 0.0943940895376727, 0.08687349894898944, 0.13040955149335787, 0.16734405944589525, 0.12512687011621892, 0.10006678436184302, 0.0990597864438314, 0.09557696161209606, 0.10341305402107537, 0.12961264816112816, 0.19487254321575165, 0.12612044258276, 0.11152041624882258, 0.11916314950212836, 0.15867801586864516, 0.1232236620853655, 0.1116164427367039, 0.1884786886512302, 0.1765810966026038, 0.19891601608833298, 0.13999529415741563], [0.05230347720498685, 0.05862935846380424, 0.05526865403226111, 0.029663982168131042, 0.037573051813524216, 0.010222009987046476, 0.04882791428826749, 0.032157711539184675, 0.058202972359140404, 0.047718451751279645, 0.021026338727097027, 0.024900375574361533, 0.030240380438044667, 0.02957341417641146, 0.05954396641755011, 0.02115053157467628, 0.06608088107896037, 0.08068977607763372, 0.035478610880090855, 0.024927322956500575, 0.04496220062719658, 0.0194162252228125, 0.0346272301976569, 0.07573376584332436, 0.025834815569396596, 0.024173215570044704, 0.06047566232155077, 0.09577535252901725, 0.012889719182567205, 0.06158023410534952, 0.03069880505790934, 0.06404081359505653, 0.03395015031856019, 0.011591729798965389, 0.01563314042869024, 0.04001979024906177, 0.04251549187756609, 0.08281870090286247, 0.0288443134559202, 0.019663464299810585, 0.04106757289264351, 0.016678728170518298, 0.021673549017577898, 0.053569525480270386, 0.016870460167410783, 0.04266052979801316, 0.037900279567111284, 0.017467373254476115, 0.04188390936178621, 0.029799678304698318, 0.043344355799490586, 0.07046338185318746, 0.008963395248429151, 0.037503620187635534, 0.0897505680040922, 0.015600999868183862, 0.02387300755799515, 0.06295217201113701, 0.013680344873137074, 0.05905329548113514, 0.025957481448131148, 0.035229794739279896, 0.05208718568610493, 0.059829593083122745, 0.02696308041777229, 0.07967478522914462, 0.06042823908501305, 0.15784822055138648, 1.4284255262464285, 6.302733197808266, 18.753534592688084, 19.379328712821007, 26.073906384408474, 38.03253538906574, 58.87770004570484, 90.12797936797142, 101.19689181447029, 108.12160983681679, 102.6661665737629, 101.76524251699448, 102.5624929368496, 111.4716012775898, 98.85739535093307, 99.12544056773186, 103.11644241213799, 104.70477238297462, 105.5921919643879, 103.7991289794445, 101.28958404064178, 100.26727169752121, 103.02363619208336, 99.28744867444038, 104.17577996850014, 111.12316757440567, 100.31573429703712, 104.87134024500847, 106.93814054131508, 107.0363500714302, 106.02588549256325, 98.9958143234253, 88.70839834213257, 65.0592577457428, 50.92647470533848, 25.113599114120007, 4.417941235005856, 1.5129157737828791, 1.2861460796557367, 0.2889106690417975, 0.47111674037296325, 0.23625204077688977, 0.06206646328791976, 0.06253961953916587, 0.03113816761469934, 0.039700243723928, 0.05223749656579457, 0.015840361047594342, 0.04247564225806855, 0.05089079168101307, 0.04012803248770069, 0.02951048005343182, 0.01864240268332651, 0.018045864380837884, 0.011718601799657336, 0.020390323734318372, 0.04464028294023592, 0.0786675869312603, 0.004615952602762263, 0.058249783323844895, 0.01771902068867348, 0.03886235528625548, 0.048887809316511266, 0.09506861271802336, 0.07049644453218207, 0.030809652234893292, 0.05177489365451038, 0.05733248879550956, 0.012476972824515542, 0.0345244279014878, 0.03131306955765467, 0.01597615180799039, 0.02027767684921855, 0.03113709892204497, 0.026679336951929145, 0.017491457801952492, 0.017361700702167582, 0.03709297874593176, 0.05570037988945842, 0.02743958746577846, 0.0394139231502777, 0.10162265243707225, 0.03041792628209805, 0.04633797914721072, 0.10443283914355561, 0.046594413433922455, 0.04688497167080641, 0.04543629940599203, 0.039850343091529794, 0.00720198659109883, 0.022512261239171494, 0.026407558762002736, 0.006991449035922415, 0.040853095924830996, 0.02846013885573484, 0.026931780339509714, 0.037817930860910565, 0.024060585383267608, 0.08690972317708656, 0.03264294995460659, 0.014893091174599249, 0.028310824309301097, 0.034462009571143426, 0.028137057852291036, 0.01682853624515701, 0.11582772262045182, 0.04630230039765593, 0.06345196394249797, 0.06373522686772048, 0.03211966533854138, 0.0695655909657944, 0.10040809065685607, 0.02189296683354769, 0.03943569405237213, 0.018225003987026867, 0.04753873326990288, 0.04028119321446866, 0.05333501052518841, 0.07594999799039215, 0.01823689690354513, 0.007919029267213773, 0.06610911979805678, 0.006880115288367961, 0.015011828309070552, 0.026129101242986508, 0.07512126394431107, 0.011945571895921603, 0.05427746014902368, 0.10524265584535897, 0.05623029930575285, 0.03461799045908265, 0.07025765851722099, 0.06919914070749655, 0.035618338733911514, 0.07702928109210916, 0.03472729025816079, 0.01832909205404576, 0.07858250712160952, 0.018957128959300462, 0.09721829541376792, 0.058785803194041364, 0.025660314386186656, 0.04164881924225483, 0.05684743220626842, 0.061539950329461135, 0.07019390061032027, 0.006904469792061718, 0.01010117350233486, 0.029939059204480145, 0.026742966838355642, 0.008839027996145887, 0.057211399980587885, 0.0882929157523904, 0.0397385088581359, 0.0427805202343734, 0.02625440916744992, 0.032587626556050964, 0.03289008884166833, 0.05104955562273972, 0.050064736788044684, 0.0359275916707702, 0.04255634339642711, 0.06683127401629463, 0.03719349893799517, 0.027779897427535616, 0.10075175698148087, 0.0570868379145395, 0.09982522271457128, 0.05620340758468956, 0.07753696947474964, 0.05236017357674427, 0.036106334227952175, 0.0951937833451666, 0.12069143194821663, 0.10683959437301382, 0.47710495186038315, 5.437175268307328, 17.75917734950781, 35.61894670128822, 38.72884042561054, 50.02350255846977, 62.30797737836838, 83.53414759039879, 115.06381452083588, 119.9031588435173, 128.12640398740768, 113.24593886733055, 114.64385345578194, 111.3519760966301, 121.86283528804779, 109.47507441043854, 107.70158797502518, 112.67039895057678, 114.28776696324348, 118.29428717494011, 118.00228044390678, 112.5513057410717, 113.83163183927536, 115.99120035767555, 109.81672927737236, 113.23599860072136, 117.90730834007263, 109.12490040063858, 113.66572514176369, 114.39232975244522, 117.47382000088692, 115.0845918059349, 120.40237605571747, 116.51108846068382, 93.44666808843613, 79.47274312376976, 44.69388194382191, 12.183594983071089, 4.959437353536487, 4.07318620942533, 0.36474334832746536, 0.14861740259220824, 0.29427984030917287, 0.049134443543152884, 0.0189219307503663, 0.04724266087578144, 0.12817721581086516, 0.07112828679964878, 0.054805817344458774, 0.06428823078749701, 0.0704481232969556, 0.012956469799974002, 0.10266254234011285, 0.09445723888347857, 0.04357417667051777, 0.06306419178145006, 0.03965063486248255, 0.01259965725694201, 0.046471038804156706, 0.004900677558907773, 0.05321825956343673, 0.041458072446403094, 0.07407681725453585, 0.03861528690322302, 0.02094650404615095, 0.032683601093594916, 0.03231779279303737, 0.027637640705506783, 0.0433692511433037, 0.09763786118128337, 0.03660560665593948, 0.047197156090987846, 0.01159510471552494, 0.020764232576766517, 0.021340634557418525, 0.04288975695089903, 0.10307564400136471, 0.036519139030133374, 0.025824922740866896, 0.060124830561107956, 0.036268786643631756, 0.04430476910783909, 0.061752011606586166, 0.045814475597580895, 0.07036714756395668, 0.03487522255454678, 0.10169083354412578, 0.04227435325447004, 0.02199039783590706, 0.001518289079740498, 0.014927513839211315, 0.08318927750224248, 0.03009756896062754, 0.017369565612170845, 0.09623992213164456, 0.023330252697633114, 0.03483253422018606, 0.06092166710004676, 0.01933090421516681, 0.07505637055146508, 0.05213692071265541, 0.024517935744370334, 0.02044012740952894, 0.027203343306609895, 0.011735446696548024, 0.061513600376201794, 0.06617878520046361, 0.043970001133857295, 0.026769008800329175, 0.17456190573284402, 0.2313688278081827, 0.19316999707370996, 0.15880308259511366, 0.16878611175343394, 0.10788182946271263, 0.11612977672484703, 0.1256350928451866, 0.1384576829150319, 0.14381827495526522, 0.17643600673181936, 0.12913820799440145, 0.129202670941595, 0.1728818318224512, 0.0871920509962365, 0.0778075194102712, 0.12213315028930083, 0.1947082465630956, 0.10647557835909538, 0.0938510155538097, 0.2525864588096738, 0.1394995246664621, 0.09120372284087352, 0.11398131115129218, 0.18531967769376934, 0.14557113870978355, 0.09459622830036096, 0.23657018464291468, 0.17121660086559132, 0.1532760268310085, 0.18712395743932575, 0.14171958522638306, 0.16940825415076688, 0.14593167405109853, 0.19755371497012675, 0.14125929039437324, 0.16229001892497763, 0.2842464193236083, 0.12644985225051641, 0.10769673041068017, 0.15205330884782597, 0.11551990202860907, 0.048536843969486654, 0.14713551179738715, 0.12798611278412864, 0.14495873328996822, 0.11711090337485075, 0.10868256227695383, 0.2462553750956431, 0.134494851808995, 0.13822344626532868, 0.14422476408071816, 0.1361278587137349, 0.17743090022122487, 0.15274325385689735, 0.16587919351877645, 0.11118213049485348, 0.22171599499415606, 0.12082091445336118, 0.29264064389280975, 0.18819342192728072, 0.1753784908214584, 0.3844325855607167, 0.07841469268896617, 0.22450678196037188, 0.29094121477101, 0.15699295472586527, 0.2786222758004442, 4.1676306165754795, 15.879292823374271, 30.443214029073715, 34.05604876577854, 47.029700204730034, 60.23480862379074, 87.44093835353851, 127.56923228502274, 135.5431044101715, 144.4080439209938, 130.91946691274643, 131.34788632392883, 131.0990908741951, 141.31628662347794, 126.45760953426361, 120.75044497847557, 127.37035855650902, 129.700385928154, 131.32206290960312, 133.30117911100388, 131.51080638170242, 129.73079949617386, 133.50361704826355, 125.92854112386703, 130.25629609823227, 137.10749566555023, 123.15485715866089, 127.50512212514877, 126.94573134183884, 129.29043352603912, 136.25837802886963, 135.42987048625946, 131.22373938560486, 100.1189960539341, 81.51368200778961, 42.38891422748566, 11.188044603914022, 4.220626847818494, 2.6881367806345224, 0.37501238635741174, 0.6579077406786382, 0.3226046485360712, 0.20269567030481994, 0.1604136617970653, 0.1543084136210382, 0.20993493497371674, 0.1708693796535954, 0.2531308983452618, 0.1855932333273813, 0.12532111984910443, 0.17594186996575445, 0.18096012412570417, 0.2367478993255645, 0.1191010168986395, 0.22644038836006075, 0.11837014986667782, 0.09985791431972757, 0.1991282554809004, 0.09348694758955389, 0.14896643464453518, 0.10495387876289897, 0.10857481727725826, 0.2042153661022894, 0.13529632677091286, 0.18535948649514467, 0.10582125643850304, 0.17585753230378032, 0.1398430351400748, 0.12223266487126239, 0.15121156495297328, 0.13227298040874302, 0.2055409160675481, 0.12570708116982132, 0.14780622033867985, 0.1495475065894425, 0.1699216867564246, 0.14307257981272414, 0.10725850705057383, 0.09272052426240407, 0.08550451108021662, 0.132417417189572, 0.19879909814335406, 0.15637286065611988, 0.1932567689800635, 0.2184488085913472, 0.4183199687395245, 0.10167412779992446, 0.16993090423056856, 0.19511644262820482, 0.08619114611065015, 0.16445723857032135, 0.0768753225565888, 0.1225508977950085, 0.2006331825396046, 0.10995754972100258, 0.09364238299895078, 0.17638466495554894, 0.093058847123757, 0.16739295213483274, 0.1444982158136554, 0.1727186780772172, 0.12391909898724407, 0.12780538498191163, 0.14604353054892272, 0.17321251798421144, 0.22342516109347343, 0.1601948172901757, 0.14763794577447698], [0.013958302370156161, 0.019642146107798908, 0.023776203670422547, 0.03184171990142204, 0.05709619268600363, 0.0345950284099672, 0.024989167977764737, 0.024431711171928328, 0.030745103940716945, 0.04222989118716214, 0.09991936414735392, 0.045335730974329636, 0.0243766753555974, 0.06738312760717236, 0.07775081932777539, 0.011819873416243354, 0.0060384933840396116, 0.034667781146708876, 0.04708590444352012, 0.034644013867364265, 0.042890179975074716, 0.01683470905845752, 0.05696701075066812, 0.053469569320441224, 0.0412805729865795, 0.03739854320883751, 0.061621464119525626, 0.0016401810376009962, 0.03920196948456578, 0.05108239936816972, 0.07913893976365216, 0.01965977582585765, 0.08822360658086836, 0.05812424162286334, 0.06355453617288731, 0.018340612041356508, 0.11465211617178284, 0.010911630306509323, 0.036403497579158284, 0.006418407128876424, 0.008560386795579689, 0.02584521491371561, 0.041005974635481834, 0.0788832402031403, 0.06282306057983078, 0.01914778484206181, 0.0077782378230040194, 0.020217700184730347, 0.05044210032792762, 0.06362953761708923, 0.056959173671202734, 0.08683515960001387, 0.05137302439834457, 0.13182044844143093, 0.03541978083376307, 0.052816624083789065, 0.03865564489387907, 0.1105479133548215, 0.022973079285293352, 0.08498385737766512, 0.12419367878464982, 0.058508492293185554, 0.11552914918866009, 0.06273037375649437, 1.1354557843878865, 7.083002328872681, 22.61207554489374, 37.451850548386574, 61.213275119662285, 86.43340721726418, 98.79278361797333, 97.88368999958038, 97.1685303747654, 102.78619453310966, 98.2268799841404, 90.81065073609352, 92.98292577266693, 71.54980346560478, 92.58576348423958, 88.42151373624802, 88.87824162840843, 98.04177671670914, 90.78785195946693, 107.78259962797165, 94.02099967002869, 106.182771474123, 96.43121793866158, 94.38412338495255, 87.79314905405045, 90.62522828578949, 94.34742495417595, 101.0214552283287, 103.73753428459167, 95.0369967520237, 98.89035478234291, 73.82082760334015, 102.64843672513962, 93.83730232715607, 97.77738690376282, 84.54930111765862, 90.73562756180763, 101.01371884346008, 101.00203827023506, 98.84490922093391, 75.05000844597816, 66.94277107715607, 61.82579845190048, 34.76863592863083, 14.822335839271545, 3.708604797720909, 0.42847795179113746, 0.33561043033842, 0.3220300778048113, 0.040222329771495424, 0.017679469783615787, 0.08059176063397899, 0.027591855759965256, 0.08596254978328943, 0.09662120050052181, 0.07542432736954652, 0.03910337145498488, 0.024074901411950123, 0.0844267568027135, 0.011713313069776632, 0.04114036273676902, 0.03541206620866433, 0.0494535373582039, 0.03727246345079038, 0.05428826952993404, 0.01414111004123697, 0.051656699215527624, 0.0640868341724854, 0.0329836031596642, 0.12719121325062588, 0.018583003038656898, 0.07724301220150664, 0.03270875247835647, 0.007907996314315824, 0.0355687892442802, 0.054263693309621885, 0.0336374018661445, 0.028549380258482415, 0.05644864657369908, 0.07240609440486878, 0.05341217161912937, 0.024055065659922548, 0.05921321346249897, 0.013438148689601803, 0.013525362173822941, 0.03992182304500602, 0.026881253070314415, 0.06156840798212215, 0.010922429482889129, 0.05110102727485355, 0.011355903097864939, 0.0800422225438524, 0.010553031042945804, 0.009079543215193553, 0.07738667714875191, 0.028275227195990738, 0.03749301118659787, 0.07874222472310066, 0.042112123483093455, 0.05477898128447123, 0.015546250706393039, 0.04928007518174127, 0.03479813567537349, 0.09555460070259869, 0.038851493955007754, 0.011277174216957064, 0.0617073194734985, 0.04270407160220202, 0.04919627186609432, 0.05378377980377991, 0.08604316928540356, 0.033500523859402165, 0.017401721015630756, 0.05141350855410565, 0.016149626972037368, 0.055440346186514944, 0.03571953056962229, 0.01562946865306003, 0.042404466585139744, 0.04082816347363405, 0.027625527000054717, 0.11588958805077709, 0.06353079486871138, 0.027451745700091124, 0.01309569763179752, 0.054647179567837156, 0.06911748219863512, 0.03626681995228864, 0.05681481852661818, 0.058865929167950526, 0.021085816297272686, 0.0652694316522684, 0.06109217552875634, 0.021909991701249965, 0.046547053279937245, 0.06304823560640216, 0.027299200955894776, 0.013437428806355456, 0.12033113409415819, 0.05444972004625015, 0.06033498822944239, 0.0641487812390551, 0.05180524007300846, 0.04946820219629444, 0.06733614223776385, 0.04789827413333114, 0.035170463743270375, 0.01950284313352313, 0.06308801472187042, 0.03714165621204302, 0.10580858055618592, 0.015578609272779431, 0.10443358871270902, 0.005754381163569633, 0.01899809365568217, 0.023942034713400062, 0.009051312845258508, 0.02641433271492133, 0.015817964886082336, 0.023273508086276706, 0.053246264506014995, 0.034419914954924025, 0.022478361788671464, 0.017103650388889946, 0.04987280997738708, 0.04640882456442341, 0.10809057333972305, 0.08876699968823232, 0.04586727198329754, 0.07442060232278891, 0.05474099816638045, 0.09036211995407939, 0.13618979835882783, 0.12186767664388753, 0.1495398921542801, 0.1692906831158325, 3.9231265615671873, 16.284835562109947, 39.84525091946125, 56.94328084588051, 86.33187666535378, 108.05529579520226, 115.10008737444878, 117.2689501941204, 110.90603962540627, 115.87722927331924, 111.74388706684113, 100.32281711697578, 110.8306136727333, 92.29172006249428, 126.17887169122696, 104.87010911107063, 113.06677088141441, 116.49805516004562, 110.4371827840805, 133.19639593362808, 112.2008353471756, 127.10294410586357, 121.86234131455421, 117.71972760558128, 106.57567039132118, 111.21663495898247, 111.31206303834915, 124.2455506324768, 125.89140191674232, 116.84885993599892, 127.84503668546677, 102.00780630111694, 135.5945536494255, 122.0755022764206, 117.09055736660957, 107.57296487689018, 104.10008043050766, 110.35865619778633, 110.75490653514862, 116.23749554157257, 98.43064025044441, 90.87489008903503, 86.58986002206802, 60.23649573326111, 32.443958669900894, 11.78670248016715, 3.006781032308936, 0.5589530349243432, 0.10102900108904578, 0.27188559353817254, 0.08109861038974486, 0.045347171180765145, 0.04993807815480977, 0.14431909105041996, 0.07815465156454593, 0.0684264610754326, 0.031624214971088804, 0.03209518559742719, 0.1478461330407299, 0.05492953336215578, 0.059583300244412385, 0.08010029559955001, 0.04135942246648483, 0.026559281577647198, 0.0351149065681966, 0.017374209601257462, 0.06823259725933895, 0.027886039388249628, 0.050324629482929595, 0.0538236850843532, 0.0312525325716706, 0.012613068793143611, 0.048601143644191325, 0.019874616446031723, 0.04077877354575321, 0.058908732535201125, 0.01848912321293028, 0.05228705718764104, 0.06698578916257247, 0.07233274794998579, 0.030381950673472602, 0.03878140923916362, 0.024530247974325903, 0.03327363076095935, 0.05576859810389578, 0.04944576707202941, 0.0670234754215926, 0.04879197207628749, 0.06196962043759413, 0.10187450025114231, 0.0109323510696413, 0.0291753410056117, 0.01849292115366552, 0.027759698023146484, 0.02954066134407185, 0.03562549303751439, 0.025392367533640936, 0.03288022940978408, 0.050377681909594685, 0.028559068996401038, 0.022427637850341853, 0.02351577848457964, 0.03357046014571097, 0.05685310963599477, 0.10451493551954627, 0.04354731092462316, 0.0368677109509008, 0.01857470953837037, 0.042186564605799504, 0.03668175471830182, 0.00550725897483062, 0.022915291956451256, 0.11392491534934379, 0.14951949793612584, 0.07759850093862042, 0.15766590455314144, 0.11680140552925877, 0.10425185158965178, 0.11295224176137708, 0.10864156603929587, 0.10736208860180341, 0.18846513703465462, 0.14886897581163794, 0.18880664370954037, 0.12340092405793257, 0.1204845508618746, 0.2002382412320003, 0.10370579417212866, 0.22694032872095704, 0.11314436153043061, 0.08695276774233207, 0.22699970053508878, 0.17420821299310774, 0.12004512522253208, 0.19855778140481561, 0.17697345523629338, 0.13090720603941008, 0.08426450105616823, 0.21352265495806932, 0.12460871745133772, 0.22159282816573977, 0.2477992352214642, 0.2036744888755493, 0.17043617321178317, 0.20281131175579503, 0.12166789791081101, 0.1674746032222174, 0.1275090454146266, 0.21286756120389327, 0.12204503509565257, 0.1868171090609394, 0.1822881231782958, 0.24286466563353315, 0.1900030006072484, 0.18306912970729172, 0.1989933181903325, 0.15470066835405305, 0.1685653970343992, 0.16041015886003152, 0.150235254841391, 0.1973315011127852, 0.18769140355288982, 0.15337149670813233, 0.20795452874153852, 0.19945957988966256, 0.22354688815539703, 0.13109872466884553, 0.1775311940582469, 0.16125273396028206, 0.20207413646858186, 0.12829928426072001, 0.17687756975647062, 0.19031456904485822, 0.13632522546686232, 0.3012268175370991, 0.15031752933282405, 2.309085507877171, 14.144305922091007, 37.629434019327164, 57.95825198292732, 92.79764011502266, 117.56377637386322, 129.60697174072266, 131.31076991558075, 126.55335679650307, 134.90729212760925, 127.46701776981354, 110.41306167840958, 114.07377004623413, 92.83207386732101, 118.54918509721756, 112.60898664593697, 111.09175845980644, 118.0142194032669, 114.32753562927246, 133.0835723876953, 117.79852017760277, 130.98090201616287, 124.17761027812958, 119.16670516133308, 115.41923984885216, 113.9715251326561, 118.93028184771538, 127.57015943527222, 129.35642838478088, 119.33360740542412, 126.22592836618423, 102.3600398004055, 130.24548947811127, 124.89001885056496, 122.29038834571838, 111.29481956362724, 114.60818856954575, 128.1783851981163, 128.6639991402626, 135.7328662276268, 110.95007926225662, 99.39553007483482, 93.33601802587509, 62.24581651389599, 29.98323731124401, 9.424043409526348, 2.060963334515691, 0.47422375646419823, 0.6232496222946793, 0.41328161722049117, 0.2839084155857563, 0.2710400795331225, 0.13194229424698278, 0.37112296849954873, 0.15296864410629496, 0.13446719938656315, 0.10369319992605597, 0.11490258359117433, 0.23114449140848592, 0.19784957956289873, 0.13734557462157682, 0.17899427883094177, 0.12157955265138298, 0.16442090302007273, 0.16993776167510077, 0.1002784151933156, 0.24365061486605555, 0.13818941137287766, 0.12321782880462706, 0.14713343378389254, 0.14784715720452368, 0.131718180491589, 0.13532763055991381, 0.08931661199312657, 0.15654720598831773, 0.11592993119847961, 0.06645662302616984, 0.1960826150025241, 0.2532201341819018, 0.16994898294797167, 0.14407427137484774, 0.1243578566936776, 0.12551591877127066, 0.05820968137413729, 0.10884418719797395, 0.13731634884607047, 0.1842257074895315, 0.12634526879992336, 0.1144908474816475, 0.2125168964266777, 0.14606079290388152, 0.17723293974995613, 0.11922357516596094, 0.08942875792854466, 0.14249462488805875, 0.08854026615153998, 0.14626175165176392, 0.16867299360455945, 0.1356927226879634, 0.19974774098955095, 0.15119370887987316, 0.13080814416753128, 0.11829432463855483, 0.26432426646351814, 0.1839212339837104, 0.21233171573840082, 0.12866832461440936, 0.1237789963488467, 0.16949167154962197, 0.15280903782695532, 0.12496947543695569, 0.09994323903811164], [0.03090314243308967, 0.02254606606584275, 0.036822970578214154, 0.01729161784169264, 0.08007051321328618, 0.02022837412368972, 0.060537601966643706, 0.050558034927234985, 0.027354722878953908, 0.055191025385283865, 0.044531246603582986, 0.021652063842338976, 0.05088236088340636, 0.05498537255334668, 0.035980937245767564, 0.02488434147380758, 0.03778859005251434, 0.017240207416762132, 0.05642729869578034, 0.038681482765241526, 0.04495406297792215, 0.1101400660991203, 0.053560998203465715, 0.03871411499858368, 0.06410039321053773, 0.0489299187756842, 0.0340471972594969, 0.02580368432973046, 0.02156260536139598, 0.05143424044945277, 0.019934982738050167, 0.04051957846968435, 0.018155171601392794, 0.05710654193535447, 0.01912949090183247, 0.03181573731126264, 0.025298482141806744, 0.016483808649354614, 0.056073246014420874, 0.07365369659964927, 0.0500028750684578, 0.02452063901728252, 0.01870329404482618, 0.07869653069064952, 0.009286090335081099, 0.06911558972205967, 0.011428666966821766, 0.020291647779231425, 0.03649195787147619, 0.04164600650256034, 0.0527701396640623, 0.03256152893300168, 0.022515636155731045, 0.07515836390666664, 0.03323883887787815, 0.021199081020313315, 0.006876610959807294, 0.1944922815891914, 0.008760884484217968, 0.14514489361317828, 0.10070992953842506, 2.6691297255456448, 17.059403099119663, 26.858349591493607, 50.52110105752945, 78.42535212635994, 87.28465273976326, 93.42162743210793, 93.43805015087128, 88.48019018769264, 87.0336078107357, 75.58862194418907, 74.59962621331215, 81.98069974780083, 90.61780348420143, 89.60328072309494, 74.689711779356, 87.14459225535393, 51.56446427106857, 88.01678225398064, 73.17192882299423, 108.62578958272934, 79.08005699515343, 65.89194506406784, 66.31141975522041, 75.46614691615105, 61.78957499563694, 76.68493911623955, 70.09372159838676, 72.39154189825058, 85.63567042350769, 63.885318338871, 72.3474794626236, 80.12408137321472, 58.95189866423607, 45.26170067489147, 57.38752640783787, 71.83394461870193, 75.27131617069244, 64.89121556282043, 82.94129580259323, 83.07251036167145, 89.91050943732262, 81.73621326684952, 95.61770439147949, 85.27138397097588, 91.00653782486916, 97.47851774096489, 102.41386771202087, 82.17037037014961, 63.04042607545853, 42.044105529785156, 14.808677472174168, 2.9211348155513406, 0.2561525674536824, 0.4166529269423336, 0.03609627812693361, 0.02158776045689592, 0.03311129337816965, 0.14784786966629326, 0.12415695731760934, 0.04212426130834501, 0.056443752109771594, 0.09160777030047029, 0.06760963107808493, 0.08780712814768776, 0.046891109232092276, 0.06509597689728253, 0.0301298245540238, 0.027246495483268518, 0.026270489652233664, 0.011530066603882005, 0.017697153307381086, 0.02878846127714496, 0.023114269170037005, 0.06615487320232205, 0.016362541718990542, 0.09369542429340072, 0.05529284433578141, 0.01631624469155213, 0.015422368633153383, 0.0400423366954783, 0.05873603106010705, 0.20991546101868153, 0.03574707909137942, 0.05575438968662638, 0.014218612523109186, 0.08843094037729315, 0.04894803831120953, 0.024108439065457787, 0.06303112168097869, 0.023763540775689762, 0.02106530333549017, 0.03985334507888183, 0.02664468607690651, 0.04233594409015495, 0.02830238237947924, 0.03174101046170108, 0.011208749128854834, 0.02519813264370896, 0.036872638811473735, 0.039605809142813087, 0.05763783061411232, 0.08062667868216522, 0.011574788422876736, 0.02848311203706544, 0.03695773717481643, 0.025985558750107884, 0.02528866723878309, 0.032471747617819346, 0.009695069365989184, 0.139770349196624, 0.06470023407018743, 0.04729075575596653, 0.05367021636629943, 0.023991851376194973, 0.027189975371584296, 0.03131795660010539, 0.04243170711561106, 0.021737386705353856, 0.04060616483911872, 0.018947881799249444, 0.008031917350308504, 0.059591526951408014, 0.028493760000856128, 0.03589554573409259, 0.023150062952481676, 0.038090469752205536, 0.042096367687918246, 0.02345371638512006, 0.017142021279141773, 0.018992492296092678, 0.04507744131842628, 0.044532014726428315, 0.019260748995293397, 0.036754692991962656, 0.06898547639138997, 0.04046619578730315, 0.038912580130272545, 0.07289878398296423, 0.034284365392522886, 0.09011202360852621, 0.04017516257590614, 0.03856272429402452, 0.04900291271042079, 0.0502185506047681, 0.017502912851341534, 0.04206665951642208, 0.053063224913785234, 0.03379563888302073, 0.027697934638126753, 0.05409799770859536, 0.0074358554138598265, 0.032748642915976234, 0.05723192778532393, 0.03621494382969104, 0.007280268791873823, 0.039208826929097995, 0.023999187505978625, 0.06554866471560672, 0.04213062893541064, 0.09045410173712298, 0.021777590700367, 0.04828684410313144, 0.04863024325459264, 0.021972192953398917, 0.08224289078498259, 0.02821074755047448, 0.0865438517939765, 0.1283962235902436, 0.025460220240347553, 0.01479154310800368, 0.09567701796186157, 0.13466325995977968, 0.03876223214319907, 0.1431098801549524, 0.21217503352090716, 8.919934909790754, 32.965142503380775, 47.48099438846111, 70.82895934581757, 98.23736742138863, 101.77883058786392, 106.32075726985931, 103.27156528830528, 101.43215239048004, 105.20832896232605, 94.72277641296387, 97.74370551109314, 105.18337950110435, 118.89382660388947, 119.38106685876846, 107.61118322610855, 109.79467526078224, 53.08943264186382, 106.6608314216137, 102.99351900815964, 140.17411351203918, 101.96539297699928, 96.69667169451714, 103.5761721432209, 108.41563045978546, 90.29112741351128, 109.05588090419769, 97.85692423582077, 98.97245317697525, 114.46952641010284, 88.6696708202362, 103.10009568929672, 109.6519473195076, 82.73945823311806, 65.60702875256538, 89.56917375326157, 96.65859013795853, 108.42317685484886, 92.27162674069405, 103.73868942260742, 103.62027257680893, 115.93442380428314, 100.61959639191628, 109.47291612625122, 95.03908663988113, 100.7859818637371, 108.98217245936394, 117.83255875110626, 105.96389561891556, 88.46718728542328, 63.31822916865349, 28.098680935800076, 7.483554035425186, 0.5934360064566135, 0.48750799207482487, 0.20137332641752437, 0.08109285874525085, 0.053208737808745354, 0.10175320363487117, 0.10799899973790161, 0.06814200329245068, 0.1467606530059129, 0.08276995664346032, 0.03585044170904439, 0.07311626293812878, 0.031741281345603056, 0.07123207615222782, 0.03211570598068647, 0.05743142079154495, 0.019403664373385254, 0.04573029378661886, 0.047993755142670125, 0.06368528775055893, 0.006922588399902452, 0.0027663301852953737, 0.0310249938047491, 0.04326762515120208, 0.012281296312721679, 0.03729341427970212, 0.06144196828245185, 0.04347804257122334, 0.028697195666609332, 0.010993731320922961, 0.08989184323581867, 0.08416325727012008, 0.023380813363473862, 0.01767045268934453, 0.04383379848150071, 0.03229104208003264, 0.04095287396921776, 0.03149960837617982, 0.004183272621958167, 0.01730130286887288, 0.048120792271220125, 0.03354619191668462, 0.03020641419425374, 0.020117675376241095, 0.011075613401771989, 0.040412252783426084, 0.010456080581207061, 0.010314145765732974, 0.028498253705038223, 0.04404791921842843, 0.11329137356369756, 0.062431236292468384, 0.028623522666748613, 0.016960451139311772, 0.016800919074739795, 0.014720848903380102, 0.07388218902633525, 0.07984367577591911, 0.04118780081626028, 0.04045400601171423, 0.026512262811593246, 0.01393910764818429, 0.1310577432741411, 0.1853710343129933, 0.14732714917045087, 0.11192470119567588, 0.14549646381055936, 0.15771653386764228, 0.14179032674292102, 0.21167332684854046, 0.0743888458237052, 0.1761572709074244, 0.08633925652247854, 0.1680375964497216, 0.26690029073506594, 0.15716195659479126, 0.08122444152832031, 0.13250742485979572, 0.16336883447365835, 0.12084947971743532, 0.17572540033143014, 0.1474970713024959, 0.12549626670079306, 0.21265094314003363, 0.12788385967724025, 0.19500653055729344, 0.12213959955261089, 0.22817339224275202, 0.21768935403088108, 0.12303792478633113, 0.17142536700703204, 0.13992688298458233, 0.1301401518867351, 0.2089582834742032, 0.10343283967813477, 0.16514154325705022, 0.1397124319919385, 0.16200740908971056, 0.19749933038838208, 0.0933167508628685, 0.18866795115172863, 0.2763688482809812, 0.135762395511847, 0.11794317746534944, 0.2071265591075644, 0.1765406792401336, 0.07638153459993191, 0.21678791177691892, 0.07224093686090782, 0.12835607340093702, 0.1372391209588386, 0.22866781102493405, 0.1373498493921943, 0.1385746305459179, 0.2333073175395839, 0.20816189964534715, 0.17817056912463158, 0.14141055493382737, 0.10229724983219057, 0.20954526291461661, 0.17326063883956522, 0.3899114462547004, 0.16768994479207322, 5.037526963278651, 27.45102658867836, 44.10150893032551, 73.90832170844078, 110.27626901865005, 114.41625326871872, 119.30296584963799, 116.20882228016853, 110.60506537556648, 106.84788778424263, 95.32125949859619, 95.46719446778297, 102.58398458361626, 114.97929185628891, 114.49631497263908, 96.96900308132172, 107.02825650572777, 65.94137281179428, 111.55592635273933, 91.69225662946701, 130.5786707997322, 99.0141673386097, 84.67373684048653, 86.45843267440796, 97.80860602855682, 78.36302787065506, 97.87857547402382, 90.90151906013489, 94.0463975071907, 103.67389529943466, 84.59992200136185, 92.16742873191833, 100.10096982121468, 75.44536963105202, 61.435251608490944, 73.09259667992592, 90.84253862500191, 99.75250571966171, 89.47707429528236, 106.234220713377, 106.61569744348526, 115.08650690317154, 104.2906554043293, 117.3829896748066, 109.90852475166321, 115.1028536260128, 126.52453914284706, 136.19470864534378, 120.29234915971756, 94.499591588974, 63.72489474713802, 25.906073190271854, 5.740436045452952, 0.490118422312662, 0.6380383693613112, 0.2401023919810541, 0.1978408222203143, 0.17327398265479133, 0.3650518739596009, 0.23123145627323538, 0.09356422000564635, 0.18088114476995543, 0.1782403013203293, 0.09815441080718301, 0.1330576531472616, 0.1153808606613893, 0.1157171797240153, 0.1697917960700579, 0.1538158205221407, 0.15988764236681163, 0.07842618855647743, 0.08125396416289732, 0.11450777587015182, 0.13308103079907596, 0.23934741999255493, 0.13201313966419548, 0.11907334221177734, 0.17864437104435638, 0.1181009209540207, 0.19514223968144506, 0.1070635300129652, 0.2078029970289208, 0.32782262947876006, 0.1278742414433509, 0.1392325444612652, 0.17564174544531852, 0.10060154629172757, 0.1719930357648991, 0.10281280498020351, 0.19333660922711715, 0.09373504755785689, 0.09792121316422708, 0.0923477509059012, 0.12761042278725654, 0.2589050744427368, 0.07482797460397705, 0.09341215394670144, 0.09008163266116753, 0.2066336988355033, 0.12309817233472131, 0.10151887792744674, 0.12427454319549724, 0.3590132558019832, 0.11181020265212283, 0.1886745117371902, 0.12248346625710838, 0.11999805079540238, 0.1020283623074647, 0.10434082025312819, 0.15820606931811199, 0.17692439927486703, 0.21156098053324968, 0.1037240213190671, 0.13126161124091595, 0.14492143294773996], [0.023065189088811167, 0.03528161149006337, 0.024950064216682222, 0.052503942424664274, 0.018352937258896418, 0.022301357712422032, 0.02770181050436804, 0.027205951955693308, 0.038906290428712964, 0.014730148013768485, 0.033207019296241924, 0.03896874957717955, 0.03716477040143218, 0.014912431543052662, 0.05620307732897345, 0.07278455261257477, 0.017835194630606566, 0.050530319422250614, 0.030644541075162124, 0.016933360893744975, 0.06501071897218935, 0.008699951376911486, 0.020940874856023584, 0.01830890563724097, 0.044917233899468556, 0.06295949700870551, 0.011343812584527768, 0.01309938703343505, 0.06766089121811092, 0.06377110228640959, 0.05249162648397032, 0.021437579453049693, 0.03525642299791798, 0.021784570599265862, 0.04832320933928713, 0.032278310536639765, 0.06101220540585928, 0.02192595900851302, 0.06594557271455415, 0.026144337534788065, 0.06228638390894048, 0.01535568573672208, 0.008036203253141139, 0.007750247723379289, 0.06092897725466173, 0.019641557955765165, 0.06613907287828624, 0.06982782142586075, 0.022811261405877303, 0.029128277710697148, 0.026973906497005373, 0.03434977828874253, 0.03132812773401383, 0.0849459262099117, 0.015093392194103217, 0.12323836403083988, 0.028966166682948824, 0.18616274261148646, 0.11624607126577757, 7.134873820468783, 27.956519164144993, 65.17278045415878, 86.73434346914291, 91.1808268725872, 94.69080492854118, 76.95170760154724, 84.18791770935059, 73.19705307483673, 85.04277303814888, 77.65213921666145, 78.87562036514282, 65.15293791890144, 57.927211448550224, 60.33489525318146, 53.22009243071079, 55.04100412130356, 29.921680614352226, 56.784449368715286, 101.22629463672638, 63.41502517461777, 35.7577570527792, 41.84473782777786, 40.885665491223335, 38.284708857536316, 25.193113647401333, 36.500598192214966, 38.133286982774734, 36.53298385441303, 33.514684215188026, 40.1726071536541, 34.44392055273056, 38.191727846860886, 31.232285387814045, 37.61221334338188, 41.16520129144192, 40.86573176085949, 29.710522145032883, 48.12819465994835, 22.53528356552124, 46.44732065498829, 47.56101429462433, 57.28015176951885, 63.873067796230316, 75.1398204267025, 63.43869410455227, 79.531769156456, 80.59461772441864, 86.52337118983269, 76.8541668355465, 84.68920961022377, 87.43322476744652, 84.11227136850357, 86.37845456600189, 75.42531430721283, 27.975233159959316, 6.1017577070742846, 0.9123764047399163, 0.4270493768854067, 0.1657324263942428, 0.03545217929058708, 0.024253337833215483, 0.04529274949163664, 0.06491172389360145, 0.0333702249918133, 0.044853279323433526, 0.03188117618265096, 0.07020063931122422, 0.03923545889847446, 0.020668523357016966, 0.027658975595841184, 0.04991571724531241, 0.06917986713233404, 0.0030557320633306517, 0.018169244576711208, 0.0539446366019547, 0.046426201952272095, 0.06712259666528553, 0.016099257409223355, 0.014225700033421163, 0.040776057285256684, 0.045329649074119516, 0.02305521091329865, 0.0533756245567929, 0.02066637112875469, 0.018116318315151148, 0.028692933883576188, 0.09063163830433041, 0.048587016863166355, 0.0658094479877036, 0.04014917998574674, 0.028540420680656098, 0.026656684749468695, 0.06933378856047057, 0.03964776646171231, 0.052227904307073914, 0.065535499015823, 0.012919512701046187, 0.0914886778627988, 0.06809974540374242, 0.049443774405517615, 0.03514913812978193, 0.00880714625964174, 0.017808180455176625, 0.045399444352369756, 0.010137012741324725, 0.010831313229573425, 0.06439439501264133, 0.0536044027103344, 0.014521529374178499, 0.038737529757781886, 0.012398782000673236, 0.03012944605870871, 0.06721075638779439, 0.039208355665323325, 0.020026007150590885, 0.008504876932420302, 0.06627734241192229, 0.044187064486322924, 0.08933912875363603, 0.05152730947884265, 0.00117574954401789, 0.05397253393311985, 0.059472056018421426, 0.06409136127331294, 0.05100081878481433, 0.03659354675619397, 0.054216975113376975, 0.06074712138797622, 0.01580366926646093, 0.006490331443274044, 0.07012639485765249, 0.07859900506446138, 0.024532353818358388, 0.03411480320210103, 0.038003827721695416, 0.07460688138962723, 0.0629859694163315, 0.12678576313192025, 0.06774928842787631, 0.02744464891293319, 0.1542685751337558, 0.019604259468906093, 0.019500863454595674, 0.01774103093339363, 0.019333377422299236, 0.05302265541104134, 0.004047288439323893, 0.07447609270457178, 0.010348284558858722, 0.030535428668372333, 0.044519045695778914, 0.003910024515789701, 0.032376429880969226, 0.0014202805937202356, 0.034330233829678036, 0.04089183232281357, 0.07830625007045455, 0.06441601377446204, 0.019328473681525793, 0.04437997835339047, 0.04445529149961658, 0.07533924013841897, 0.038584305948461406, 0.027043082081945613, 0.05369892263843212, 0.053885795423411764, 0.08263775045634247, 0.05208606133237481, 0.04031535798276309, 0.052730820680153556, 0.08455269184196368, 0.0969762662134599, 0.08189410364138894, 0.13379861338762566, 1.5110415243543684, 18.68917364627123, 49.071247056126595, 85.97555458545685, 99.66804385185242, 104.9870440363884, 105.61382040381432, 87.27676436305046, 100.83553120493889, 98.51442575454712, 107.2777359187603, 103.35265293717384, 110.91510593891144, 98.14873337745667, 89.50615793466568, 97.99993336200714, 75.09765028953552, 85.67397236824036, 52.39416114985943, 84.72166746854782, 101.62028029561043, 64.61940094828606, 48.611334934830666, 55.615149512887, 67.71286055445671, 53.34648124873638, 44.46313552558422, 49.633514285087585, 54.07223470509052, 44.807647839188576, 43.781934678554535, 49.38704051077366, 51.256806179881096, 54.48550432920456, 43.85225370526314, 54.36086341738701, 52.635395005345345, 55.92048592865467, 48.19418951869011, 69.23641920089722, 43.371260315179825, 71.73387318849564, 78.64960089325905, 94.3583607673645, 94.33942258358002, 104.82005059719086, 99.00471344590187, 104.89324226975441, 108.76712679862976, 107.30974540114403, 96.50041222572327, 94.0256430208683, 96.63164958357811, 93.8068051636219, 102.71275967359543, 94.38109114766121, 46.805322244763374, 16.26666683703661, 3.7151304725557566, 0.15252641314873472, 0.2935864665778354, 0.05684773648681585, 0.06599010899662971, 0.041321602620882913, 0.19887377304257825, 0.04057416343130171, 0.043269131710985675, 0.06167673927848227, 0.05736233797506429, 0.079177175211953, 0.056504274252802134, 0.049132666099467315, 0.040319944455404766, 0.06057575206796173, 0.08320025386638008, 0.025293951330240816, 0.02512108472728869, 0.05031815053371247, 0.013168162786314497, 0.007955976161611034, 0.01970635672478238, 0.03998712832981255, 0.021340660532587208, 0.06065879097150173, 0.039544478058815, 0.03260895216953941, 0.031054948740347754, 0.047228597177308984, 0.07866378713515587, 0.019919764999940526, 0.08521580079104751, 0.007757777275401168, 0.03627805977885146, 0.03120179935649503, 0.04003666668722872, 0.10802251839777455, 0.042725950115709566, 0.032588524554739706, 0.01729308543872321, 0.027051941469835583, 0.0552076828898862, 0.022284731749095954, 0.023317942323046736, 0.07397724330076016, 0.03744830421055667, 0.024065182988124434, 0.05401629467087332, 0.04582384892273694, 0.06384673455613665, 0.01907929759909166, 0.02629443504702067, 0.018310599589312915, 0.011968604449066333, 0.08335089500178583, 0.04567467352899257, 0.055820919515099376, 0.02541308644140372, 0.01385955683872453, 0.17121045588282868, 0.16043874638853595, 0.13136877736542374, 0.22278186748735607, 0.10827156831510365, 0.1170262169034686, 0.11882622929988429, 0.09189305186737329, 0.13272183132357895, 0.13813711964758113, 0.09628129686461762, 0.16060880210716277, 0.10559446352999657, 0.03799776066443883, 0.11214772399398498, 0.17373536102240905, 0.06666455054073595, 0.14009806676767766, 0.16669246862875298, 0.151951011212077, 0.13732512103160843, 0.16155702935066074, 0.11955666588619351, 0.08469699503621086, 0.21853096433915198, 0.1889140621642582, 0.10756403440609574, 0.08234840934164822, 0.14477408694801852, 0.15174448635661975, 0.14795795985264704, 0.1305685640545562, 0.09425619849935174, 0.11004660002072342, 0.16894732107175514, 0.08600707122241147, 0.12583481962792575, 0.05370078171836212, 0.24323024757904932, 0.10673458047676831, 0.17891924770083278, 0.1465056065353565, 0.09019802368129604, 0.08811193561996333, 0.11082386612542905, 0.12349844968412071, 0.2694025752134621, 0.1488183019682765, 0.167425740219187, 0.19708706735400483, 0.1909263213747181, 0.17150354484329, 0.10758049524156377, 0.10460576697369106, 0.24751353805186227, 0.309355323552154, 0.2043114890693687, 0.2956902771256864, 0.718104763654992, 14.554737098515034, 45.86943246424198, 93.23114365339279, 112.70959004759789, 119.05223250389099, 121.11631974577904, 100.06756201386452, 103.48043248057365, 94.87573340535164, 105.42281225323677, 98.39391142129898, 99.34856459498405, 85.49173414707184, 78.50751131772995, 82.98742532730103, 69.52738478779793, 71.136834025383, 40.91118112206459, 68.19561704993248, 116.5563516318798, 78.5693795979023, 48.47315154969692, 53.698615953326225, 56.34339563548565, 53.18945847451687, 35.20816974341869, 50.33659815788269, 51.186445355415344, 51.26493014395237, 46.34246148169041, 57.153892144560814, 48.37528400123119, 55.74428178369999, 45.018509924411774, 50.648721009492874, 58.79277840256691, 60.95095619559288, 45.96273645758629, 69.73483845591545, 33.700919821858406, 61.18759609758854, 67.10779622197151, 76.6168087720871, 85.80427497625351, 102.01316401362419, 90.45476943254471, 106.09979912638664, 107.25813657045364, 107.83459603786469, 100.59737518429756, 105.15007048845291, 108.52588534355164, 109.85266014933586, 113.79782125353813, 104.17815864086151, 49.22388106584549, 14.359858855605125, 2.172330846078694, 0.4758503957418725, 0.43265633226837963, 0.12283991978620179, 0.11932675595744513, 0.1949160182266496, 0.2644186082761735, 0.1548548717983067, 0.1605784334242344, 0.15646157698938623, 0.15283707616617903, 0.20152586745098233, 0.15390827727969736, 0.08906922448659316, 0.2569206606131047, 0.12296114960918203, 0.16496428870595992, 0.14314948115497828, 0.0871275360987056, 0.13054079288849607, 0.14557370654074475, 0.061639216291951016, 0.0986195815494284, 0.14668553281808272, 0.13780000648694113, 0.15371289948234335, 0.15432334563229233, 0.08755979259149171, 0.1363619914627634, 0.10710554299294017, 0.19742719363421202, 0.13686271850019693, 0.1525706599932164, 0.07524364409619011, 0.1172688917722553, 0.10801141586853191, 0.12019256770145148, 0.21092261478770524, 0.08807530321064405, 0.20823989936616272, 0.10917924460954964, 0.15102987235877663, 0.2621521783294156, 0.09001411206554621, 0.11914223578060046, 0.12076673025148921, 0.10524680445087142, 0.09447735108551569, 0.13178130757296458, 0.11332131922245026, 0.1569661038229242, 0.09908271880703978, 0.11410030710976571, 0.12099086627131328, 0.1642221855581738, 0.21414856746559963, 0.1489285405841656, 0.1377535331994295, 0.12449309826479293, 0.08570641235564835], [0.021484457211045083, 0.05584223028563429, 0.010378016850154381, 0.04393743569380604, 0.023781595373293385, 0.008180072290997487, 0.029151822345738765, 0.013952246445114724, 0.0945850441348739, 0.04022583641926758, 0.07436327883624472, 0.055137238232418895, 0.009780768868949963, 0.036135367045062594, 0.030142715659167152, 0.019091871436103247, 0.02326868041564012, 0.023945138746057637, 0.026483608489797916, 0.0342943658324657, 0.07141516398405656, 0.08737666023080237, 0.04170813539531082, 0.04102639853954315, 0.07312482732231729, 0.02991038818436209, 0.031650023156544194, 0.03424576258112211, 0.05296691640978679, 0.03278206553659402, 0.08780604461207986, 0.0400923537381459, 0.0517548593779793, 0.016204338098759763, 0.12318434310145676, 0.01638168170757126, 0.08942659085732885, 0.02128490112227155, 0.03975740393798333, 0.04564606002531946, 0.11070037275203504, 0.04485521261813119, 0.014021386778040323, 0.07810788141796365, 0.033969160431297496, 0.026921271528408397, 0.0359040433249902, 0.042111180955544114, 0.003533178855832375, 0.11536532008904032, 0.040744375000940636, 0.06289517506957054, 0.07027382249361835, 0.07842956532840617, 0.11202625668374822, 0.04555494655505754, 2.534424578770995, 21.25781301409006, 47.54074618220329, 73.90043333172798, 81.76323741674423, 79.68746200203896, 76.47123858332634, 68.04236367344856, 70.13076201081276, 87.48639911413193, 68.82509887218475, 60.87957702577114, 63.91016900539398, 59.70266617834568, 40.80465003848076, 30.067742876708508, 38.555983901023865, 31.424232088029385, 33.89391526579857, 24.422551095485687, 40.76865456998348, 30.695068314671516, 49.52798634767532, 140.53375661373138, 61.01953111588955, 54.71296772360802, 37.44699440896511, 51.87871500849724, 58.519713655114174, 44.776158928871155, 48.02143178880215, 62.75726146996021, 40.225143134593964, 42.72379405796528, 35.06109483540058, 37.97877587378025, 50.61797305941582, 36.235676407814026, 50.684727877378464, 35.683535635471344, 57.53628842532635, 43.93987700343132, 42.917640656232834, 40.33362731337547, 27.22855992615223, 15.142350867390633, 36.457713693380356, 21.952765323221684, 27.58803963661194, 47.78790771961212, 47.96448804438114, 53.12675043940544, 58.7473214417696, 73.73566657304764, 71.83741003274918, 79.81246769428253, 73.44353064894676, 76.26202180981636, 84.53991562128067, 71.17601752281189, 60.30871465802193, 23.33878844976425, 0.8890832390170544, 0.41690727579407394, 0.41039104107767344, 0.046498201409121975, 0.042742407240439206, 0.041930082079488784, 0.05849662164109759, 0.021236754291749094, 0.04933822616294492, 0.10358352534240112, 0.04416747920913622, 0.07744490605546162, 0.03713295081979595, 0.0477294169832021, 0.044113287585787475, 0.05236504577624146, 0.05213076830841601, 0.041921922165784054, 0.02605518704513088, 0.05513458505447488, 0.07343399862293154, 0.029503190307877958, 0.049000363433151506, 0.018938059474749025, 0.04068829461175483, 0.06309453819994815, 0.03847637170110829, 0.07421527974656783, 0.027873434009961784, 0.018589118335512467, 0.051037651574006304, 0.054292150962282903, 0.036543218011502177, 0.07871929978136905, 0.018427365394018125, 0.07019760392722674, 0.08865558105753735, 0.12418772676028311, 0.022865369537612423, 0.05899551928450819, 0.09302284553996287, 0.004844335562665947, 0.04017299179395195, 0.04582891036989167, 0.025352935372211505, 0.10011302016209811, 0.05184014327824116, 0.02651622773555573, 0.08046030401601456, 0.066079812386306, 0.04511851548159029, 0.11266085974057205, 0.03821188511210494, 0.04476896021515131, 0.10185785387875512, 0.017316444536845665, 0.05207168964261655, 0.01612779113202123, 0.014538399318553274, 0.05753552926762495, 0.04766606354678515, 0.04258594024577178, 0.022385823394870386, 0.04938330421282444, 0.0683967825898435, 0.029989554932399187, 0.029923661495558918, 0.04467749793548137, 0.01882172411569627, 0.09896977877360769, 0.032914249459281564, 0.01982129499083385, 0.03760112726013176, 0.008069752038863953, 0.035550402535591274, 0.010762409456219757, 0.04045118585054297, 0.05986375042994041, 0.08476812246954069, 0.034999806885025464, 0.01830400560720591, 0.05506490109837614, 0.0331422891758848, 0.05700106790754944, 0.00520484400112764, 0.00897080744834966, 0.0825982607784681, 0.02789833306451328, 0.005158447247595177, 0.02924604541476583, 0.06369192255078815, 0.050666113893385045, 0.08039146981900558, 0.044249505081097595, 0.06165758073620964, 0.05317438379279338, 0.03923599324480165, 0.023995896081032697, 0.057664418054628186, 0.07711462807492353, 0.04444795165909454, 0.056243249782710336, 0.03813891344179865, 0.03624822915298864, 0.0120030271136784, 0.015047114648041315, 0.011698244688886916, 0.10440174315590411, 0.047937318522599526, 0.017422606906620786, 0.05679559319105465, 0.06763623707229272, 0.1549493768834509, 0.1328320847824216, 8.197811208665371, 39.0947949886322, 72.02459558844566, 91.28247901797295, 94.2114682495594, 86.84607267379761, 95.35661280155182, 84.21399191021919, 92.84894496202469, 116.7864140868187, 97.40457370877266, 102.94387087225914, 93.37777018547058, 89.23786953091621, 61.18318073451519, 47.53443092107773, 58.38259041309357, 37.65532582998276, 34.26651567220688, 27.982416674494743, 34.40187580883503, 35.203446596860886, 64.28769394755363, 145.15471905469894, 55.269839242100716, 55.28382629156113, 39.42220441997051, 42.33843773603439, 50.27411811053753, 42.78887316584587, 41.83051139116287, 61.79487191140652, 35.1691572368145, 45.41245758533478, 32.40844577550888, 34.98817674815655, 41.074644550681114, 19.61116187274456, 37.04186774790287, 23.942319564521313, 33.49831849336624, 28.53751178830862, 19.99766193330288, 28.144394382834435, 25.424466133117676, 23.31843864172697, 48.88677075505257, 33.509923070669174, 50.16363523900509, 69.0510955452919, 77.68560782074928, 85.93360483646393, 93.92871022224426, 109.40820559859276, 104.2631296813488, 109.04999122023582, 95.6362321972847, 89.48060810565948, 98.92360299825668, 91.90299332141876, 84.50966164469719, 45.44928900897503, 5.2697016298770905, 0.28807132970541716, 0.5220973282121122, 0.035700850712601095, 0.050445803644834086, 0.05089929298264906, 0.019053083087783307, 0.033157937359646894, 0.014644835355284158, 0.09878068696707487, 0.06594831866095774, 0.03390523554116953, 0.07791977666784078, 0.048069565527839586, 0.06652345342445187, 0.02562286190368468, 0.03949182268115692, 0.020559321892505977, 0.05200515239266679, 0.030966241683927365, 0.0664681411581114, 0.04649275775591377, 0.029634826896653976, 0.04688988468842581, 0.06484234050731175, 0.024062140182650182, 0.018765589920803905, 0.09560437654727139, 0.041566771105863154, 0.02606404828839004, 0.020884883524558973, 0.043168477932340465, 0.08218882532673888, 0.02696145140362205, 0.062327795749297366, 0.02835077597410418, 0.050208769098389894, 0.052542823541443795, 0.10073948185890913, 0.017722662778396625, 0.04852797159401234, 0.0275681868151878, 0.019980446704721544, 0.06609210977330804, 0.01831682435295079, 0.07864715560572222, 0.02101603771734517, 0.030654628717456944, 0.017630710681260098, 0.04303776346205268, 0.027516145564732142, 0.07407398225041106, 0.03678551809571218, 0.05100313799630385, 0.033438981263316236, 0.03936359069484752, 0.05637870286591351, 0.009718862620502478, 0.15561667154543102, 0.14581941679352894, 0.12176238815300167, 0.10604424212942831, 0.0947768373589497, 0.13066816027276218, 0.11762015026761219, 0.12022312934277579, 0.18270990054588765, 0.09187580435536802, 0.11815128309535794, 0.1835786140873097, 0.07471046294085681, 0.2305119441007264, 0.15640462457668036, 0.11586954264203086, 0.09119624199229293, 0.11525169727974571, 0.16370875295251608, 0.20002116303658113, 0.14669632364530116, 0.1490108299185522, 0.122818493982777, 0.21088660578243434, 0.15433633321663365, 0.11090765459812246, 0.11208571013412438, 0.06462728837504983, 0.18135554040782154, 0.1595836883643642, 0.12782552686985582, 0.07526702174800448, 0.15303974185371771, 0.20934369560563937, 0.3642040444537997, 0.13463008595863357, 0.2186185822938569, 0.16449577087769285, 0.12119885315769352, 0.13083220459520817, 0.1549648877698928, 0.11737348264432512, 0.1542782675824128, 0.11791925062425435, 0.16096411272883415, 0.194118254003115, 0.12951674783835188, 0.1426251241355203, 0.09292552029364742, 0.24658389418618754, 0.11221730033867061, 0.0897742054075934, 0.15521102846832946, 0.15903877385426313, 0.2389727986883372, 0.1862594296108, 4.770921394228935, 33.79130557179451, 69.88345608115196, 102.61315181851387, 107.42499321699142, 101.84919521212578, 97.35062420368195, 86.66600033640862, 89.0608674287796, 110.66529974341393, 87.15276181697845, 82.57817968726158, 81.47212743759155, 75.08650168776512, 50.9063433855772, 38.96233789622784, 47.38463155925274, 39.111168310046196, 49.8487613350153, 34.97302696108818, 51.471407264471054, 41.911644637584686, 54.376784563064575, 144.04326349496841, 73.5437236726284, 74.57830175757408, 50.98882935941219, 65.58621346950531, 77.87932902574539, 63.573552668094635, 63.69686745107174, 86.20234921574593, 55.9899690002203, 60.11065788567066, 48.53373169898987, 51.27529598772526, 69.32322934269905, 52.102352008223534, 68.69250878691673, 48.869071304798126, 74.40054729580879, 54.085442796349525, 59.493916779756546, 55.76037012040615, 39.3252070248127, 24.971652030944824, 51.05564497411251, 32.33271583914757, 41.68540097773075, 64.9149338901043, 64.90491762757301, 74.96348708868027, 83.57536017894745, 100.13101860880852, 95.47820627689362, 102.05597251653671, 95.89926928281784, 100.5012783408165, 113.1347644329071, 102.4938914179802, 88.83965849876404, 42.37845338881016, 4.422839172184467, 0.5800769326742738, 0.7133318635169417, 0.09269149886677042, 0.09313141432357952, 0.1421859211404808, 0.1503774058073759, 0.15203496295725927, 0.15766609751153737, 0.16545159771339968, 0.13258523162221536, 0.16415549616795033, 0.21078948833746836, 0.1887054741382599, 0.1581946254009381, 0.1122736293473281, 0.1258812632295303, 0.12732812465401366, 0.147993775899522, 0.14099826221354306, 0.19825136347208172, 0.09165480762021616, 0.3202620445517823, 0.18818171083694324, 0.20509111520368606, 0.09148026932962239, 0.11148143123136833, 0.19343279156601056, 0.14576485409634188, 0.10546780860750005, 0.12297214081627317, 0.18121655099093914, 0.22556774143595248, 0.1497962448047474, 0.1520953292492777, 0.1642517527216114, 0.1767985607148148, 0.21624379878630862, 0.23752069770125672, 0.21418845048174262, 0.13920138910179958, 0.13494474173057824, 0.23899170861113816, 0.22263418009970337, 0.05722202382457908, 0.24075518507743254, 0.1979482703609392, 0.1960094243986532, 0.12516397750005126, 0.1223994031897746, 0.17384944396326318, 0.23847863223636523, 0.13827431306708604, 0.13272619515191764, 0.15697014110628515, 0.12041213951306418, 0.172063524951227, 0.1768365438329056], [0.03253270762797911, 0.023878506872279104, 0.06527142060804181, 0.0823691523692105, 0.05271054520562757, 0.027886633106390946, 0.04724204118247144, 0.03711525059770793, 0.03848806423775386, 0.029762157173536252, 0.05267209082376212, 0.008731694888410857, 0.11712766106938943, 0.04370809350803029, 0.014948897896829294, 0.03255456016631797, 0.031716675439383835, 0.030118104186840355, 0.02715484024520265, 0.02486986959411297, 0.05554555304115638, 0.030840011640975717, 0.03497461468214169, 0.06666665824013762, 0.0522110204474302, 0.053764268741360866, 0.02616921246954007, 0.04056909085193183, 0.02591448326711543, 0.06480392694356851, 0.06375165801728144, 0.05154873157152906, 0.04113432907615788, 0.017946837760973722, 0.02729485568124801, 0.01979936452698894, 0.0469064420030918, 0.09806605070480146, 0.03211559094779659, 0.06322802088106982, 0.1022826146800071, 0.09681700132205151, 0.08603135429439135, 0.09548356232699007, 0.019617812940850854, 0.04295980455935933, 0.020402194386406336, 0.14161673840135336, 0.033800785677158274, 0.05269000255793799, 0.03608312355936505, 0.028294547155383043, 0.1750241153058596, 0.2341880538733676, 4.950610427185893, 29.428051002323627, 58.228808864951134, 85.64437955617905, 86.89436808228493, 82.40950673818588, 74.02369111776352, 79.3047921359539, 65.45973345637321, 82.87445738911629, 77.04363226890564, 58.06445628404617, 49.382047578692436, 32.19088464975357, 29.14732776582241, 21.623085513710976, 36.29558019340038, 48.580180406570435, 41.550508216023445, 56.58969461917877, 57.59624920785427, 64.4879812002182, 82.68635988235474, 83.08751955628395, 47.61005826294422, 37.971525862812996, 64.29790779948235, 58.95341478288174, 68.61105635762215, 57.948212921619415, 65.90737223625183, 45.648280531167984, 62.45376415550709, 45.01419335603714, 49.60689291357994, 55.17146252095699, 70.99539041519165, 73.81876811385155, 54.483965411782265, 62.904541566967964, 62.08875194191933, 72.82389789819717, 93.97783398628235, 81.27915859222412, 106.89274057745934, 115.42256847023964, 118.46223816275597, 85.73676779866219, 60.50872452557087, 44.32792738080025, 40.22779539227486, 24.19039875268936, 22.138254269957542, 19.01246029883623, 19.394070021808147, 24.799941144883633, 37.29030221700668, 38.71451899409294, 50.172120183706284, 72.5045858323574, 69.77306440472603, 70.10868519544601, 83.9453387260437, 78.870969414711, 52.41243436932564, 24.357979260385036, 5.185821130871773, 0.2602471743011847, 0.060067933809477836, 0.12614858482265845, 0.05793310519948136, 0.036115470065851696, 0.06379996440955438, 0.01463936387153808, 0.04708893611677922, 0.023156788665801287, 0.014284492044680519, 0.014646787203673739, 0.02507799563318258, 0.12519510317360982, 0.015935014562273864, 0.0642265954229515, 0.03181373351253569, 0.04396639429614879, 0.026306353938707616, 0.06804230317356996, 0.059066190297016874, 0.07517791949794628, 0.051193253966630436, 0.03756536687433254, 0.045100028582965024, 0.0631411599169951, 0.07373148109763861, 0.0246031509959721, 0.020206729386700317, 0.10574680418358184, 0.022158778156153858, 0.019654883217299357, 0.012949834072060185, 0.0007360522670296632, 0.07152990001486614, 0.02309710700501455, 0.01381137104544905, 0.020436210725165438, 0.028013006012770347, 0.05586153354670387, 0.03045425812160829, 0.07731210615020245, 0.023130596418923233, 0.02663129402208142, 0.03133755672024563, 0.022428227857744787, 0.020340904120530467, 0.05854463859577663, 0.0359777423000196, 0.11580045611481182, 0.02960551206342643, 0.04507340403506532, 0.017968120700970758, 0.0831748427299317, 0.03092200968239922, 0.021443598270707298, 0.05208049151406158, 0.08205699763493612, 0.011686508551065344, 0.0068062108312005876, 0.02437439139612252, 0.004517916286204127, 0.06859073546365835, 0.053720578507636674, 0.09352934648632072, 0.03229907211789396, 0.03854872738884296, 0.02464172041072743, 0.016824458143673837, 0.03146235256281216, 0.05252587659924757, 0.008119174435705645, 0.01874333291198127, 0.06105050393671263, 0.050483326631365344, 0.08445861720247194, 0.016041015514929313, 0.05200818777666427, 0.04099866819160525, 0.01864587036834564, 0.018984903836098965, 0.02874268189771101, 0.007514859817092656, 0.028727393655572087, 0.04512906140007544, 0.01277776620554505, 0.03284713333414402, 0.0754818512359634, 0.0658132329408545, 0.025263977840950247, 0.11496654187794775, 0.04564395232591778, 0.007941488511278294, 0.057914380813599564, 0.052238888092688285, 0.042184902195003815, 0.10736093085142784, 0.04962705519574229, 0.023486241007049102, 0.03511142589559313, 0.016361280067940243, 0.07660027520614676, 0.06381005019648, 0.12202474477817304, 0.09603230631910264, 0.0706984571297653, 0.07241905230330303, 0.03632257750723511, 0.1287587924161926, 1.686400689650327, 15.389894284307957, 51.40846364200115, 78.76424834132195, 99.3211680650711, 95.38136467337608, 93.9076441526413, 93.30536127090454, 103.65564867854118, 95.46633571386337, 116.90309822559357, 105.16828671097755, 88.40076684951782, 68.13428834080696, 36.42734952270985, 29.922683760523796, 14.729995094239712, 19.44284040480852, 29.728516079485416, 19.91122607141733, 27.31907296925783, 36.87282621860504, 28.116748966276646, 29.860923774540424, 26.705736480653286, 28.522447496652603, 35.32226622104645, 37.615937143564224, 36.30014754831791, 23.515741154551506, 24.990297630429268, 18.171726912260056, 21.93975292146206, 22.51120425760746, 20.751569978892803, 24.660416431725025, 25.814539901912212, 27.475145794451237, 37.17342048883438, 29.54552359879017, 36.25974431633949, 37.64864198863506, 49.057708382606506, 50.60940831899643, 55.9076464176178, 70.18642902374268, 67.00075596570969, 90.53029417991638, 50.68677216768265, 45.99420636892319, 32.90671683847904, 24.915331453084946, 24.01714514940977, 20.95389012247324, 18.560098372399807, 26.552598997950554, 42.0632679015398, 62.09521919488907, 62.230480536818504, 74.16872933506966, 102.66049727797508, 90.00059500336647, 86.05880811810493, 95.1453897356987, 89.29596841335297, 78.84806424379349, 49.60578717291355, 14.33881938457489, 0.3120910283178091, 0.23235707165440544, 0.04483025048102718, 0.09684105432825163, 0.034597822595969774, 0.08135707816109061, 0.045029843677184545, 0.09907804327667691, 0.06915716483490542, 0.044706000117002986, 0.019833512596960645, 0.05031868859077804, 0.09768804520717822, 0.06114548028563149, 0.026593112379487138, 0.04927841648168396, 0.06298178370343521, 0.017297382473770995, 0.04857996646023821, 0.027225798839936033, 0.0378017000912223, 0.04508516336500179, 0.06181475277116988, 0.06373398005962372, 0.018999453641299624, 0.04907457820081618, 0.1262678627972491, 0.05784065957413986, 0.10940545122139156, 0.044847505414509214, 0.058446741895750165, 0.04302487235690933, 0.028319030607235618, 0.056826377476681955, 0.02686336916667642, 0.04327011505665723, 0.005274326185826794, 0.037580083662760444, 0.01679686138231773, 0.0348019391822163, 0.006006197436363436, 0.011233116620132932, 0.01555811300931964, 0.03835779876681045, 0.04775168883497827, 0.03814181894995272, 0.05369548649468925, 0.038588551033171825, 0.06689265705063008, 0.016821721474116202, 0.06306645533186384, 0.04088969864824321, 0.028431766550056636, 0.01297037579206517, 0.06813478961703368, 0.1180834359547589, 0.16886106866877526, 0.1475677831331268, 0.16991603159112856, 0.09509354887995869, 0.08778488598181866, 0.19279537576949224, 0.17890863498905674, 0.17273509438382462, 0.18937377812108025, 0.21067947236588225, 0.08277599030407146, 0.1531192852417007, 0.16126371774589643, 0.10080452368129045, 0.1035162273910828, 0.10265849763527513, 0.3046454762807116, 0.16328672325471416, 0.1522709510754794, 0.18155327823478729, 0.12273838656255975, 0.12581985793076456, 0.1624871778767556, 0.09862058344879188, 0.09001371872727759, 0.09489134332397953, 0.09171426107059233, 0.08111380215268582, 0.14768535416806117, 0.11647638937574811, 0.16820296179503202, 0.20812903734622523, 0.13830465206410736, 0.14101433713221923, 0.1363547332584858, 0.1739190871012397, 0.24719698238186538, 0.2138882369035855, 0.13690414518350735, 0.22235167416511104, 0.13606450898805633, 0.22009058768162504, 0.13106494210660458, 0.10268516300129704, 0.14934509323211387, 0.10403120366390795, 0.22175109857926145, 0.20483930449699983, 0.13869479909772053, 0.17043022118741646, 0.06741430523106828, 0.3282954666065052, 0.9680783282965422, 11.415647640824318, 48.50815907120705, 84.18667897582054, 113.58999520540237, 108.80510956048965, 104.73878055810928, 92.79823288321495, 101.50048032402992, 86.44377306103706, 107.11140364408493, 93.79439502954483, 69.93995904922485, 58.25460188090801, 41.12317934632301, 38.51964645087719, 30.259655378758907, 49.52257163822651, 65.24421662092209, 55.42069494724274, 74.40104126930237, 74.06892389059067, 84.98830676078796, 104.92446899414062, 109.29729714989662, 65.18519818782806, 50.64868301153183, 90.0879219174385, 78.3615231513977, 94.81574222445488, 76.98215156793594, 89.20616403222084, 63.11263360083103, 87.66372039914131, 61.80475518107414, 69.19830724596977, 70.98269909620285, 99.09612134099007, 98.69822949171066, 80.02298399806023, 93.198913782835, 90.86523100733757, 100.43808773159981, 126.3091666996479, 105.31859144568443, 131.8534567952156, 133.62736880779266, 136.07624620199203, 105.54542407393456, 81.29967749118805, 62.92278818786144, 54.763421416282654, 38.61869193613529, 34.28924225270748, 27.040074840188026, 27.896554581820965, 35.30041739344597, 50.90661697089672, 53.04611496627331, 68.3731359243393, 93.09722363948822, 90.85108056664467, 92.56704568862915, 105.69406449794769, 101.90986275672913, 89.107855707407, 50.01150280237198, 10.621129274368286, 0.3059006854891777, 0.29223412508144975, 0.1899912895169109, 0.16782796941697598, 0.19841938570607454, 0.18546516832429916, 0.1889761205529794, 0.1376882242038846, 0.2012802314129658, 0.1275396070559509, 0.1276550703914836, 0.07456739913322963, 0.227113145228941, 0.13612383627332747, 0.12168153116363101, 0.15328371548093855, 0.1568893509102054, 0.07626251637702808, 0.188175298681017, 0.10219392061117105, 0.18550307722762227, 0.19352127041202039, 0.1338844353449531, 0.17219117435161024, 0.11531318421475589, 0.17505325202364475, 0.18625395256094635, 0.17169448459753767, 0.19115420524030924, 0.13470896141370758, 0.15162495605181903, 0.08970399823738262, 0.11844464665045962, 0.10411980125354603, 0.1786382557475008, 0.11604850413277745, 0.0744801819382701, 0.1517397366114892, 0.14709310547914356, 0.156034218671266, 0.1636733376653865, 0.07739809138001874, 0.15102302975719795, 0.09622260040487163, 0.1364898041356355, 0.15031159215141088, 0.15174831583863124, 0.22029803280020133, 0.25515746616292745, 0.08266826014732942, 0.14520965341944247, 0.12390032265102491, 0.11828389004222117, 0.07778303595841862, 0.19449940620688722], [0.03980679015512578, 0.035794194336631335, 0.06264018797082826, 0.04610318959748838, 0.05936961737461388, 0.04031086427858099, 0.018247402003908064, 0.04456179711269215, 0.019471127452561632, 0.035889879436581396, 0.046008127901586704, 0.017325324333796743, 0.08676786907017231, 0.09416763801709749, 0.021136161740287207, 0.04750832747959066, 0.04802838746400084, 0.0926724702003412, 0.03323259370517917, 0.03984050221333746, 0.05354805143724661, 0.05885602891794406, 0.058484060791670345, 0.03448323128395714, 0.021266102521622088, 0.0930865143891424, 0.06726677369442768, 0.055069083100534044, 0.02533944498281926, 0.07008582906564698, 0.03337576512421947, 0.05180726984690409, 0.022211698851606343, 0.060465958740678616, 0.09330871340353042, 0.056491995419492014, 0.00544036966857675, 0.06506545236334205, 0.030283436135505326, 0.03559747325198259, 0.032763218696345575, 0.11255678837187588, 0.03126737923594192, 0.11450092584709637, 0.15147948026424274, 0.015041976203065133, 0.11494579885038547, 0.03160049222060479, 0.0526255730073899, 0.17432818858651444, 0.045160242734709755, 0.05434021986729931, 9.280719850212336, 46.49465471506119, 70.78138589859009, 85.77179431915283, 83.84115591645241, 76.27197727560997, 71.80969431996346, 67.23755925893784, 64.52379047870636, 66.04919582605362, 50.49020491540432, 38.29569026827812, 25.149028412997723, 21.909574940800667, 37.392528131604195, 76.71094492077827, 60.32957933843136, 78.6648228764534, 76.39911845326424, 84.07152235507965, 101.98593467473984, 70.54133757948875, 56.622471660375595, 66.38460382819176, 76.0415880382061, 85.1704689860344, 98.83353263139725, 62.46674045920372, 71.98182508349419, 70.58837905526161, 80.40724217891693, 73.12656685709953, 85.77503174543381, 74.47475731372833, 84.33758407831192, 78.8910399377346, 70.24611622095108, 83.00928175449371, 72.73323476314545, 62.235781252384186, 66.1887775361538, 52.56618931889534, 60.67823342978954, 48.69691014289856, 52.03521341085434, 43.03882755339146, 46.712994799017906, 64.02803108096123, 61.844314858317375, 82.52799957990646, 77.77817845344543, 81.02408587932587, 75.89165568351746, 56.30262762308121, 82.38571241497993, 72.94735327363014, 49.47993792593479, 38.92252743244171, 39.23175863921642, 36.34022019803524, 36.97687603533268, 38.64187829196453, 46.234026700258255, 58.30360785126686, 66.05203047394753, 70.32554715871811, 76.46863952279091, 78.42288225889206, 61.91428430378437, 18.949030302464962, 1.1784028611145914, 0.1662085735006258, 0.07799257393344305, 0.033821042597992346, 0.004443099451236776, 0.10177066636970267, 0.0840797953424044, 0.03422702706302516, 0.10510829000850208, 0.06757275376003236, 0.06866267183795571, 0.011324710631015478, 0.10534479020861909, 0.03618959948653355, 0.018266731240146328, 0.06980804319027811, 0.03962463371863123, 0.035674411701620556, 0.0419219555624295, 0.049006270928657614, 0.06597639410756528, 0.01376322514261119, 0.03706598683493212, 0.10343663205276243, 0.06722107966197655, 0.02907045327447122, 0.043851394802914, 0.010953800065180985, 0.06522588242660277, 0.018220816418761387, 0.06830736121628433, 0.052325277792988345, 0.009822186275414424, 0.03027209240826778, 0.03527703614963684, 0.08994731135317124, 0.05014836569898762, 0.059196429792791605, 0.028534036355267745, 0.0014289742739492794, 0.02700003195059253, 0.044511887681437656, 0.05885018079425208, 0.032750665268395096, 0.031397741186083294, 0.08173581838491373, 0.04004652611911297, 0.024072415217233356, 0.015558540671918308, 0.09263548156013712, 0.009436265772819752, 0.0066214322941959836, 0.008495139027218102, 0.007819716920494102, 0.027550898485060316, 0.05276780189888086, 0.042540042122709565, 0.029655744328920264, 0.054472366682603024, 0.036832073019468226, 0.05434570062789135, 0.02871465840144083, 0.04915534984320402, 0.012619895624084165, 0.031149425994954072, 0.02406652256468078, 0.03643515388830565, 0.04598238279868383, 0.07124700074200518, 0.06203056560480036, 0.032260317166219465, 0.06428806009353139, 0.021252569458738435, 0.018940562367788516, 0.009567035904183285, 0.02311736021511024, 0.03153958787152078, 0.008970220224000514, 0.0650200032396242, 0.0874313194071874, 0.06288148986641318, 0.03406308293051552, 0.026280887141183484, 0.11698156929924153, 0.06019103755534161, 0.07649932085769251, 0.0190747074157116, 0.015081047495186795, 0.03464491186605301, 0.06310172961093485, 0.06815528773586266, 0.09676053872681223, 0.018800706493493635, 0.03715376806212589, 0.06862474809167907, 0.032474304316565394, 0.012595579155458836, 0.06772185122827068, 0.08145395069732331, 0.019249234574090224, 0.052005093020852655, 0.1037897310743574, 0.0725616114505101, 0.07095174471032806, 0.0265842678345507, 0.21444079553475603, 22.861513160169125, 70.6484842300415, 88.68258252739906, 97.35072299838066, 94.84035730361938, 96.98132202029228, 98.59389469027519, 97.16251149773598, 88.25405672192574, 99.03204917907715, 81.81202679872513, 48.93880896270275, 21.989640444517136, 18.029745630919933, 21.642359979450703, 39.63606454432011, 34.09579083323479, 46.54239535331726, 44.60205987095833, 48.71963292360306, 66.74181506037712, 53.55705074965954, 53.43460991978645, 53.94396498799324, 62.62453459203243, 64.03317600488663, 91.20919615030289, 53.5239165276289, 52.188740372657776, 49.8611106723547, 67.07312688231468, 62.60800927877426, 66.251550167799, 53.393477126955986, 58.74211572110653, 54.145623967051506, 51.519866064190865, 58.79668079316616, 60.250881761312485, 56.32178619503975, 58.27213793992996, 47.08666294813156, 58.277404457330704, 50.04562497138977, 56.20637118816376, 54.173594266176224, 60.72586007416248, 75.0753378868103, 66.71609804034233, 72.73735374212265, 61.56678915023804, 64.55379366874695, 51.59260556101799, 43.00769962370396, 55.6429298222065, 48.83914791047573, 32.963873371481895, 25.823342129588127, 29.94361873716116, 26.10649723559618, 41.86621427536011, 63.458722829818726, 79.60128262639046, 85.08289888501167, 88.29409897327423, 90.70952296257019, 89.29552003741264, 89.99060913920403, 84.01489019393921, 39.58271160721779, 6.978041511029005, 0.20889583916869015, 0.1601995967212133, 0.0749304577766452, 0.04592638404574245, 0.10065009017125703, 0.06250735095818527, 0.04446858336450532, 0.08056435312028043, 0.08654023753479123, 0.12673793913563713, 0.05031902255723253, 0.01814950715925079, 0.03613473250879906, 0.043477118597365916, 0.07639219926204532, 0.007390902137558442, 0.05900652533455286, 0.03229969552194234, 0.03872153647535015, 0.047637364696129225, 0.06421312544262037, 0.07333930057939142, 0.07386248500552028, 0.0157665822916897, 0.06540363421663642, 0.04779683738888707, 0.01016679234453477, 0.031104808076634072, 0.04433674082974903, 0.03948527322791051, 0.021795764041598886, 0.04163724173849914, 0.026215876860078424, 0.08154648166964762, 0.07563957246020436, 0.09533779710181989, 0.05555831427045632, 0.035686712799360976, 0.019638537414721213, 0.06367442270857282, 0.01760760205797851, 0.07150172808906063, 0.03534379975462798, 0.005501646019183681, 0.017517510896141175, 0.03775440673052799, 0.10800265852594748, 0.009144387440755963, 0.01556616902234964, 0.028097547765355557, 0.05949878446699586, 0.033125071349786595, 0.035922515380661935, 0.07565809646621346, 0.22467999922810122, 0.22989927150774747, 0.10158915189094841, 0.23655016149859875, 0.10112337258760817, 0.09741685702465475, 0.17532949423184618, 0.13808196323225275, 0.09382327407365665, 0.13555883924709633, 0.1309747266350314, 0.14185048523359, 0.16961581801297143, 0.21642143925419077, 0.14854936249321327, 0.13844775297911838, 0.18817023723386228, 0.1450009021209553, 0.10748601242084987, 0.145681080466602, 0.21806639473652467, 0.13577093021012843, 0.11670443651382811, 0.22915544657735154, 0.1283025200245902, 0.24700872920220718, 0.2142335136886686, 0.08640972344437614, 0.2296621850109659, 0.07688482946832664, 0.1709498284617439, 0.10968905553454533, 0.13106494210660458, 0.13261929620057344, 0.16079928172985092, 0.15291023708414286, 0.13240018452052027, 0.19839879852952436, 0.15400793286971748, 0.1780174343730323, 0.26697492110542953, 0.23667469387874007, 0.22840513527626172, 0.20625928533263505, 0.2185218656086363, 0.25490124709904194, 0.17009652190608904, 0.17617110454011708, 0.2718229265883565, 0.10368745570303872, 0.13847797323251143, 17.891396954655647, 70.39447546005249, 101.32472455501556, 110.12977167963982, 105.08305728435516, 96.20788112282753, 94.35162752866745, 85.46816021203995, 83.3446517586708, 80.98348125815392, 63.21547128260136, 48.58138494193554, 35.41254937648773, 31.39488436281681, 47.227289602160454, 101.31432071328163, 78.65302830934525, 102.98985600471497, 102.86030575633049, 106.36426493525505, 132.5681984424591, 96.13585218787193, 78.8961012661457, 92.8726252913475, 107.99929440021515, 118.8381975889206, 131.5940523147583, 85.0632843375206, 99.1492348909378, 98.29649984836578, 113.97918552160263, 105.16033753752708, 125.3635722398758, 105.56007608771324, 124.51013043522835, 116.61796912550926, 103.54557618498802, 121.74225255846977, 106.0466779768467, 89.72770124673843, 93.50449338555336, 71.49498000741005, 88.73812794685364, 66.81944489479065, 75.08486017584801, 60.314467549324036, 69.59597110748291, 90.00861257314682, 81.95315882563591, 106.27224147319794, 99.16990578174591, 100.54133579134941, 97.53671541810036, 78.05038824677467, 108.98338079452515, 99.66285333037376, 69.80421513319016, 54.23592232167721, 53.033009469509125, 47.942529022693634, 49.6134589612484, 52.63262875378132, 68.28591540455818, 76.87786236405373, 87.97238543629646, 93.14503267407417, 94.08276155591011, 102.34475702047348, 91.57479733228683, 38.38583663105965, 4.251509690657258, 0.39432381105143577, 0.2606409875443205, 0.171984649496153, 0.13347561587579548, 0.3093359980266541, 0.10498147923499346, 0.19742440315894783, 0.21900357882259414, 0.21587262104731053, 0.23683241510298103, 0.14355322433402762, 0.15612808550940827, 0.18695955688599497, 0.1614727362175472, 0.2475621338817291, 0.08179610304068774, 0.14761254948098212, 0.15401507233036682, 0.12904036324471235, 0.12256556263309903, 0.1389865076635033, 0.17694345762720332, 0.204379232309293, 0.15733349660877138, 0.20445910224225372, 0.07938477618154138, 0.20097586180781946, 0.12987199908820912, 0.155352556030266, 0.18634298059623688, 0.10659666717401706, 0.13518239225959405, 0.1137361500877887, 0.12059687491273507, 0.18726100242929533, 0.21234384243143722, 0.1276077510556206, 0.07655700799659826, 0.0996249022136908, 0.16031908249715343, 0.12721607519779354, 0.21785831137094647, 0.15002525673480704, 0.11680632596835494, 0.16451318166218698, 0.16130379372043535, 0.13501036242814735, 0.214429292245768, 0.1487388921668753, 0.08734859962714836, 0.12701256346190348, 0.14241138560464606, 0.18878898059483618], [0.01959243520104792, 0.032046741907834075, 0.029763081147393677, 0.033492363945697434, 0.02845868053555023, 0.04990002453268971, 0.014432424341066508, 0.04878779378486797, 0.037603368546115234, 0.037256822688505054, 0.04924608481815085, 0.06837652937974781, 0.0488109376601642, 0.010546704234002391, 0.05002812293241732, 0.008130592377710855, 0.05956303219136316, 0.021921786283201072, 0.04598194493155461, 0.015750485108583234, 0.06038601088221185, 0.013348423035495216, 0.044549239974003285, 0.054256186485872604, 0.09132378749200143, 0.05491192961926572, 0.054134670936036855, 0.02536433847126318, 0.04004537207947578, 0.10079401487018913, 0.02275820341310464, 0.03313776207505725, 0.01999751795665361, 0.03825734536803793, 0.018006174323090818, 0.07397436376777478, 0.01867023322120076, 0.061027040937915444, 0.03267139276431408, 0.03703251597471535, 0.04429073138453532, 0.013926659048593137, 0.03566451516235247, 0.018155696670874022, 0.034082452984876, 0.031164506435743533, 0.056154436970246024, 0.18538684205850586, 0.044468093547038734, 0.035692267774720676, 2.3597733629867435, 31.959864646196365, 71.70660585165024, 82.38993018865585, 76.13174200057983, 68.07992845773697, 63.56110833585262, 56.744581907987595, 60.703144893050194, 42.1849449723959, 27.07562953233719, 31.470669396221638, 25.643885359168053, 48.85372772812843, 77.48540416359901, 82.6889057457447, 77.38024100661278, 60.38355924189091, 67.36568838357925, 52.17459373176098, 48.54212924838066, 58.09867724776268, 59.49491612613201, 65.26310920715332, 43.56250785291195, 26.93426761776209, 10.363090820610523, 7.437593601644039, 7.944124471396208, 21.213224306702614, 21.81717149913311, 16.054746508598328, 18.340261168777943, 17.52421695739031, 15.953867621719837, 17.208417803049088, 18.69035728275776, 18.963446728885174, 20.890861004590988, 18.62201415002346, 17.19770047813654, 12.245507910847664, 7.20882355235517, 5.903729433193803, 5.3296049404889345, 21.205047145485878, 27.760301493108273, 23.819677345454693, 25.22432517260313, 27.217050343751907, 29.30024866014719, 32.81082518398762, 41.70045576989651, 46.717109978199005, 46.170760095119476, 47.85644084215164, 56.40913210809231, 45.9932716190815, 64.3723002076149, 70.37704959511757, 151.4722752571106, 102.66490504145622, 32.86362335085869, 32.33398877084255, 13.919582180678844, 39.46135371923447, 50.00192351639271, 62.191259041428566, 59.09350946545601, 62.532241344451904, 67.84343674778938, 80.37520229816437, 53.89481462538242, 16.987864337861538, 0.18182073341449723, 0.33193507755640894, 0.11268526897765696, 0.035316778157721274, 0.030363120531546883, 0.040125705854734406, 0.025450744869885966, 0.0603730529837776, 0.02777402703941334, 0.016770288784755394, 0.03072413084737491, 0.008004391092981678, 0.045345508769969456, 0.01759190192387905, 0.03726931303390302, 0.05389405552705284, 0.03350489139847923, 0.014865546363580506, 0.034855833946494386, 0.03438700812694151, 0.027450114830571692, 0.004981551246601157, 0.011501658118504565, 0.07231132956803776, 0.06233723586774431, 0.03805547006777488, 0.047551227326039225, 0.03378261790203396, 0.029385958805505652, 0.01748016231431393, 0.041721879970282316, 0.03893065884767566, 0.14427753078052774, 0.03641570219770074, 0.034583847955218516, 0.02973020771605661, 0.06805909055401571, 0.0030447614972217707, 0.048157365308725275, 0.05277315649436787, 0.06032577446603682, 0.038271063967840746, 0.03866233535518404, 0.052492283284664154, 0.011645526228676317, 0.05377744557335973, 0.09202885747072287, 0.006015376411596662, 0.051409248626441695, 0.023799598020559642, 0.020492016519710887, 0.029719197955273557, 0.0565576643566601, 0.030944968020776287, 0.023278842272702605, 0.017065936299331952, 0.03210834016499575, 0.046418112542596646, 0.030744829346076585, 0.0643732438038569, 0.027467790932860225, 0.06484901983640157, 0.055461085503338836, 0.027711881448340137, 0.04305865862988867, 0.026586854219203815, 0.05640460381982848, 0.03917811314749997, 0.014153797983453842, 0.05664473683282267, 0.0636937927629333, 0.05508360693056602, 0.055793285646359436, 0.10124962675035931, 0.06197338312631473, 0.02411191973806126, 0.07321046374272555, 0.02128523508872604, 0.06544883843162097, 0.026090921455761418, 0.0889510523120407, 0.016439673127024435, 0.01899059054267127, 0.06378936654073186, 0.03314197005238384, 0.032803224166855216, 0.027429394067439716, 0.009307270302088, 0.05873827976756729, 0.055828148033469915, 0.020553525719151367, 0.053447297468665056, 0.09344943944597617, 0.02359241079830099, 0.10954112323815934, 0.05935273351497017, 0.0531085590046132, 0.04809859092347324, 0.04676901109633036, 0.08917261307942681, 0.06713289025356062, 0.2574049268150702, 9.616561979055405, 53.3229149132967, 90.1299324631691, 85.94843164086342, 90.2074483036995, 89.83322158455849, 88.80577191710472, 82.17159390449524, 87.15894028544426, 74.39443722367287, 43.04312512278557, 31.055146493017673, 22.275877185165882, 32.02208250761032, 56.96611762046814, 55.583785995841026, 52.886724919080734, 56.48361951112747, 67.64306589961052, 56.352378353476524, 52.27106675505638, 53.287170231342316, 62.396109849214554, 69.15843218564987, 44.316212609410286, 22.931315414607525, 7.996873240917921, 6.343416664749384, 7.715266551822424, 20.404952578246593, 19.731246829032898, 14.405749943107367, 16.4710920676589, 18.48207525908947, 16.59599706530571, 19.78339523077011, 19.749449752271175, 21.680470034480095, 24.32911790907383, 20.257265903055668, 14.237037096172571, 8.570875190198421, 4.993954701349139, 2.64531331602484, 2.8913482138887048, 11.393219344317913, 18.333011157810688, 12.562063224613667, 17.501249089837074, 21.715874634683132, 18.686540387570858, 26.151384226977825, 32.80545227229595, 33.42595137655735, 40.63084356486797, 44.9561058729887, 55.490709990262985, 47.451891750097275, 52.35414169728756, 50.82631208002567, 114.23868879675865, 86.52208685874939, 22.05878533422947, 19.31962251663208, 15.891123488545418, 53.35208974778652, 64.73724782466888, 87.22251087427139, 88.00646960735321, 87.79539093375206, 84.99548077583313, 94.55935478210449, 74.95809137821198, 35.143865793943405, 3.104695128276944, 0.16194511321373284, 0.3305137756979093, 0.10316883548512124, 0.0640232469595503, 0.06120528625615407, 0.044477333285612985, 0.06045586182153784, 0.03498274119920097, 0.029797025126754306, 0.02660703321453184, 0.027081378757429775, 0.017664148144831415, 0.07479695283109322, 0.038052735253586434, 0.00625252274403465, 0.019557390987756662, 0.04218295405735262, 0.04664682761358563, 0.055497762441518717, 0.044489337524282746, 0.0254249533827533, 0.008862773938744795, 0.026606407955114264, 0.022774710632802453, 0.00809341634521843, 0.011793140329245944, 0.04896387574262917, 0.030024482257431373, 0.05370611404941883, 0.07989440156961791, 0.033901843926287256, 0.08346519316546619, 0.04988115171727259, 0.006953072115720715, 0.12111792937503196, 0.04724187048850581, 0.04214246248011477, 0.02908096394094173, 0.031086046583368443, 0.06071007337595802, 0.021349616399675142, 0.029761452133243438, 0.024257165459857788, 0.03314943234727252, 0.02342110270546982, 0.017589404596947134, 0.02117980930051999, 0.022490644332719967, 0.023490189232688863, 0.04451975073607173, 0.06812652209191583, 0.14124806912150234, 0.0948601657000836, 0.09148047713097185, 0.171823083946947, 0.12688351882388815, 0.09752380050485954, 0.10322798465494998, 0.17165081662824377, 0.20340176444733515, 0.181519569887314, 0.17658369411947206, 0.16144913592142984, 0.22995519975665957, 0.12644870934309438, 0.2191800912260078, 0.11651369713945314, 0.12831025320338085, 0.19070511683821678, 0.17851713724667206, 0.19930620765080675, 0.1829042096505873, 0.14027603378053755, 0.11448904406279325, 0.0594594914582558, 0.18016826739767566, 0.22922517877304927, 0.16510891844518483, 0.07459117754478939, 0.25890094810165465, 0.15187618788331747, 0.08758416472119279, 0.12244860015925951, 0.1971685403259471, 0.10921017732471228, 0.09380866118590347, 0.1980361554888077, 0.1774829693022184, 0.19251465098932385, 0.09768452742719091, 0.08050688862567768, 0.1539970826706849, 0.17082839825889096, 0.1658227902953513, 0.12601035239640623, 0.13117761496687308, 0.11737657740013674, 0.178385509934742, 0.2506561920745298, 0.1479060243582353, 0.3910265676677227, 6.13493942655623, 52.31118880212307, 104.12908047437668, 103.53488355875015, 94.34597343206406, 87.9925699532032, 84.54832077026367, 76.3868223130703, 76.8570926785469, 54.59708534181118, 40.03519132733345, 38.44851426780224, 34.60256963968277, 63.60673248767853, 97.782341837883, 107.58133962750435, 100.91281145811081, 84.4174861907959, 92.67938286066055, 74.96259793639183, 72.08552911877632, 81.99570894241333, 83.14263939857483, 88.50499525666237, 63.55710335075855, 44.067865535616875, 18.523610830307007, 14.026008769869804, 15.101497359573841, 37.484411001205444, 39.21101555228233, 27.32853066176176, 29.843078032135963, 32.95908562839031, 32.52461314201355, 35.65203532576561, 39.433801397681236, 39.92891103029251, 43.27823370695114, 38.22228580713272, 33.663127049803734, 26.22218392789364, 15.38349162787199, 12.287873737514019, 10.706695932894945, 36.75787478685379, 42.492595463991165, 34.345988407731056, 34.88066151738167, 39.06723886728287, 45.63932441174984, 50.21476149559021, 60.82016721367836, 65.57117387652397, 68.16310599446297, 71.3283209502697, 78.84307891130447, 68.30964893102646, 86.68282583355904, 96.14393055438995, 175.46894520521164, 116.74510270357132, 45.39900630712509, 43.93334895372391, 19.566436372697353, 50.932200998067856, 68.68386045098305, 80.00404581427574, 79.69601914286613, 82.44113624095917, 87.24204942584038, 105.52028462290764, 81.53464168310165, 30.258682630956173, 1.429032781161368, 0.39691055193543434, 0.5458581657148898, 0.2084709596238099, 0.12513957568444312, 0.15891813032794744, 0.23609086114447564, 0.3679874539375305, 0.1574726789840497, 0.15581377112539485, 0.1299558617756702, 0.15145493001909927, 0.11857214019983076, 0.1617687937687151, 0.1667115418240428, 0.148951472947374, 0.05918305629165843, 0.21348243055399507, 0.1078844047151506, 0.10505186452064663, 0.23642144340556115, 0.09109015940339305, 0.10647999413777143, 0.16827953659230843, 0.1274381554685533, 0.16116826271172613, 0.0926423018972855, 0.1398685501771979, 0.09783952496945858, 0.1699109107721597, 0.1326620884356089, 0.11659585288725793, 0.389744492713362, 0.17818624328356236, 0.130201393913012, 0.29824843048118055, 0.21125202445546165, 0.08866521413438022, 0.10733232105849311, 0.12428516332875006, 0.15521554072620347, 0.07813750053173862, 0.10497510418645106, 0.07283032085979357, 0.22754099336452782, 0.1783048384822905, 0.13978775998111814, 0.10879595502046868, 0.19307758484501392, 0.1213902530435007, 0.1950066493009217, 0.19288593262899667], [0.03378449553565588, 0.035070533558609895, 0.025951752068067435, 0.03741871478268877, 0.034769284684443846, 0.035972480472992174, 0.02538531341997441, 0.012054996932420181, 0.08746670500840992, 0.04327168098825496, 0.04838438086153474, 0.06317434876109473, 0.0419717314071022, 0.04089524249138776, 0.033885720768012106, 0.09507440889137797, 0.03778572536248248, 0.005817944256705232, 0.08657666214276105, 0.02692030117032118, 0.05791130832221825, 0.06690654263366014, 0.029540746691054665, 0.07108242207323201, 0.05731764584197663, 0.06277453154325485, 0.01981932273338316, 0.00985365890301182, 0.01891702886496205, 0.08072984463069588, 0.03549529064912349, 0.00791706906966283, 0.03984684015449602, 0.020667144817707594, 0.004964786594428006, 0.01671978934609797, 0.014352710259117885, 0.01383499453368131, 0.007470904729416361, 0.06613762569031678, 0.04727996863948647, 0.07050503860227764, 0.012590353508130647, 0.06962902974919416, 0.019485552948026452, 0.039111008154577576, 0.056608430968481116, 0.3640193387400359, 0.9700872329995036, 23.569787554442883, 66.91922754049301, 83.03278729319572, 78.45638126134872, 72.33457535505295, 60.435548052191734, 67.66785576939583, 49.13639836013317, 42.558597922325134, 39.07280936837196, 24.874325953423977, 34.353303015232086, 59.20167066156864, 68.35725277662277, 68.38010475039482, 87.45467081665993, 77.5110375881195, 59.0289281308651, 35.51183044910431, 27.480518706142902, 23.756408840417862, 19.01168704032898, 14.066636189818382, 16.101223714649677, 15.21024752408266, 4.9864135310053825, 0.4825803096173331, 0.17774665437173098, 0.15500776906264946, 0.2805084886495024, 0.20189470000332221, 0.30910165747627616, 0.06539411246194504, 0.713533905800432, 2.3956268141046166, 1.0032759583555162, 0.5661096540279686, 0.5982210778165609, 0.5946234427392483, 0.14033972489414737, 0.5503676331136376, 3.0284208711236715, 1.5336285810917616, 0.5538721731863916, 0.11569878188311122, 0.15431878884555772, 0.36206419521477073, 1.551461024209857, 3.8604066520929337, 2.3756375117227435, 1.6540855611674488, 2.4813611386343837, 2.1072431886568666, 1.9719946710392833, 3.8451742194592953, 6.617899686098099, 9.509799107909203, 18.94371248781681, 35.89688278734684, 52.85473443567753, 50.054239109158516, 39.09511797130108, 28.50435096770525, 63.226334899663925, 90.33869326114655, 77.34660521149635, 28.63720513880253, 22.521199621260166, 29.290659874677658, 39.21651765704155, 43.48276913166046, 37.649534940719604, 53.50185491144657, 65.1737380027771, 77.33186960220337, 49.15115296840668, 13.244009781628847, 1.5557886357419193, 0.14870922110276297, 0.07864759347285144, 0.03747802722500637, 0.048689804316381924, 0.06808778198319487, 0.026381013994978275, 0.02692353693419136, 0.0545787387090968, 0.06518265974591486, 0.04585649228829425, 0.058521286919130944, 0.03409353696042672, 0.016303574375342578, 0.0540151480527129, 0.0433506380795734, 0.08354016492376104, 0.0510447353735799, 0.016785495390649885, 0.022322601689666044, 0.001556788222387695, 0.05001546931453049, 0.009247414236597251, 0.0446615788678173, 0.0864683827967383, 0.023922911423142068, 0.029909282384323888, 0.10418053119792603, 0.06827482546214014, 0.0068690967145812465, 0.027638941319310106, 0.05284936763928272, 0.04833659026189707, 0.03215836833987851, 0.08479071344481781, 0.021153177331143524, 0.01998054689465789, 0.00903737809494487, 0.03744897214346565, 0.04377929144538939, 0.03227800625609234, 0.049415565372328274, 0.049445266122347675, 0.07367071404587477, 0.03766788344364613, 0.057540787383913994, 0.01217388991790358, 0.05154885402589571, 0.03778964761295356, 0.05369717488065362, 0.04192991509626154, 0.03818524943199009, 0.06205210644111503, 0.016346284974133596, 0.01749654893501429, 0.036968887943658046, 0.0701765195117332, 0.017857364437077194, 0.04066821209562477, 0.03208380105206743, 0.06007310657878406, 0.03457768812950235, 0.04364035768958274, 0.04796172404894605, 0.04203884382150136, 0.05158992076758295, 0.02118445700034499, 0.06404822765034623, 0.018961880559800193, 0.0957562867552042, 0.10566280790953897, 0.042011503101093695, 0.007449402392012416, 0.05759586958447471, 0.022848504231660627, 0.02166663220123155, 0.023978863791853655, 0.0653161943773739, 0.04151270193688106, 0.03656979803054128, 0.05577435345912818, 0.0692781200632453, 0.06198241135280114, 0.007856699994590599, 0.00659136464491894, 0.07578788325190544, 0.048222139957943, 0.03163664594467264, 0.03767813992453739, 0.018712489254539832, 0.04428638982062694, 0.0404790868924465, 0.10925385271548294, 0.08426527288975194, 0.07834770643967204, 0.02905211480538128, 0.025141111582343, 0.2540456398855895, 5.14455059543252, 43.889981880784035, 87.0501521229744, 95.84611773490906, 92.75958135724068, 94.72529947757721, 83.41137617826462, 95.67213267087936, 76.19561657309532, 62.8935107588768, 40.322284922003746, 17.58568435907364, 20.85102964192629, 33.51647771894932, 35.32390393316746, 65.94133481383324, 87.92800381779671, 69.25744727253914, 59.586073234677315, 35.8904155343771, 25.967477895319462, 18.955071978271008, 14.975463822484016, 10.352488439530134, 10.453382525593042, 9.40768813714385, 2.83239200245589, 0.7927151850890368, 0.503878730814904, 0.32823256216943264, 0.40536622633226216, 0.5135451746173203, 0.5306254955939949, 0.777116606477648, 0.9262393671087921, 0.6309527589473873, 0.7880236837081611, 0.5713171558454633, 0.7347155129536986, 0.425898929242976, 0.32950674067251384, 1.041388032026589, 1.6895057167857885, 1.0722986608743668, 0.42530179722234607, 0.3333408833714202, 0.3422163164941594, 0.5240884213708341, 0.49055124283768237, 0.12161154663772322, 0.9366816224064678, 0.7324581372085959, 0.45888641383498907, 0.5087074998300523, 0.5999735556542873, 1.0652262903749943, 2.483488074503839, 4.986178893595934, 11.95875819772482, 26.919300220906734, 44.61900316178799, 47.16543272137642, 43.96086327731609, 35.56848160922527, 64.2916989326477, 74.42740425467491, 42.7401901781559, 13.880248591303825, 25.681581236422062, 36.97625666856766, 55.33435598015785, 71.02135822176933, 63.13016965985298, 73.20211440324783, 76.69817760586739, 90.28151392936707, 72.50086963176727, 31.55417561531067, 6.696869423612952, 0.13640135497553274, 0.13011000584810972, 0.13640316581586376, 0.026380347917438485, 0.11519444800796919, 0.07326657010708004, 0.022915705703780986, 0.04470536558073945, 0.02105221927195089, 0.05732516379794106, 0.0994440853537526, 0.02605253943329444, 0.061085440538590774, 0.02695681669138139, 0.05125163501361385, 0.05882262485101819, 0.02575140373664908, 0.014510087312373798, 0.04720846642157994, 0.02322078220458934, 0.07041454111458734, 0.06346506284899078, 0.04857296800764743, 0.018469421047484502, 0.04897095954220276, 0.0342490391631145, 0.06545317999552935, 0.07657822599867359, 0.07679753063712269, 0.012156353895989014, 0.008853228064253926, 0.08954925302532502, 0.03546923755493481, 0.050969852673006244, 0.028949961888429243, 0.0624740136845503, 0.05340630123100709, 0.017473395782872103, 0.05877121257071849, 0.028779138046957087, 0.04955852527928073, 0.03234091811464168, 0.06434504961362109, 0.024860375669959467, 0.05643510608933866, 0.016433407545264345, 0.07705325246206485, 0.12056283259880729, 0.019670512847369537, 0.1652857573935762, 0.20220139995217323, 0.12188821929157712, 0.10688122143619694, 0.09052220862940885, 0.08563567826058716, 0.18286741396877915, 0.17561715067131445, 0.11644535275991075, 0.19230398494983092, 0.11646169485175051, 0.16610425722319633, 0.07054544854327105, 0.1052574765344616, 0.11297905555693433, 0.1128546790278051, 0.17962212092243135, 0.13373407622566447, 0.13263556407764554, 0.17531284043798223, 0.15721187344752252, 0.17208672448759899, 0.09291630281950347, 0.15704793302575126, 0.1189511401753407, 0.1740072394022718, 0.10549844446359202, 0.12901904876343906, 0.1094163088419009, 0.18032983294688165, 0.1640855858568102, 0.13066259416518733, 0.12512869579950348, 0.059863412752747536, 0.10153759489185177, 0.14942669979063794, 0.12180099467514083, 0.11113504864624701, 0.22710006858687848, 0.16453636635560542, 0.181437102437485, 0.13541705935494974, 0.13147290068445727, 0.21965767809888348, 0.11807925766333938, 0.1728435666882433, 0.0968124000064563, 0.581442128168419, 2.636560248211026, 36.87606364488602, 95.85981220006943, 105.31960979104042, 94.61315229535103, 95.25594100356102, 82.16540023684502, 85.90807780623436, 61.79038815200329, 52.083941996097565, 49.66687649488449, 32.7199986577034, 44.704658165574074, 81.87964797019958, 93.38745206594467, 87.70386144518852, 104.90368410944939, 99.1824223101139, 81.64274588227272, 56.404515355825424, 42.90542051196098, 38.253227546811104, 31.46340798586607, 22.443250603973866, 22.693655267357826, 20.430652499198914, 8.943175412714481, 2.5839658454060555, 0.9763004339765757, 0.7645449216943234, 1.1547312000766397, 1.5035630506463349, 1.8396988324820995, 1.2745252344757318, 2.342139696702361, 4.850078271701932, 3.4773931419476867, 1.72714400338009, 2.9220455791801214, 3.025309550575912, 1.5498177311383188, 2.733673774637282, 9.856999777257442, 5.83233411423862, 1.8199529545381665, 1.3745426363311708, 1.1236799787729979, 2.4035859620198607, 3.6979173962026834, 7.378394678235054, 6.535381888970733, 4.8199862614274025, 4.89395166747272, 4.555200794711709, 3.221642402932048, 6.898162672296166, 9.355838019400835, 13.654021080583334, 26.86732091009617, 49.4829435646534, 74.84351232647896, 71.05300292372704, 63.1320695579052, 45.33849835395813, 83.94084736704826, 122.71485596895218, 101.27001509070396, 41.78566999733448, 36.665824726223946, 43.14340554177761, 50.6435988843441, 56.75472356379032, 54.48675826191902, 70.74756771326065, 83.5388745367527, 102.43528336286545, 75.39541751146317, 26.740257628262043, 4.11309689283371, 0.3218354273121804, 0.1962742375326343, 0.15606494358507916, 0.10918314088485204, 0.21677814511349425, 0.13757620443357155, 0.15076443582074717, 0.1763405665406026, 0.15666755265556276, 0.12581105605931953, 0.1974924432579428, 0.140775142936036, 0.1206936954986304, 0.18975442566443235, 0.12817629554774612, 0.14083237736485898, 0.13127373793395236, 0.11668960098177195, 0.1375625786022283, 0.08104501248453744, 0.21060021099401638, 0.10403073611087166, 0.16944409988354892, 0.23455537244444713, 0.12196332463645376, 0.1405310505651869, 0.1839727390324697, 0.1718134805560112, 0.17368680972140282, 0.10643597735906951, 0.12343616122961976, 0.1534773566527292, 0.14743294974323362, 0.15834557823836803, 0.10775723028928041, 0.10067664421512745, 0.10067861832794733, 0.13949237036285922, 0.09801277192309499, 0.10126128589035943, 0.14488799177343026, 0.1703184240614064, 0.10734041046816856, 0.1480921104666777, 0.16754090669564903, 0.09134658626862802, 0.08933129167417064, 0.26174370024818927, 0.1352638058597222], [0.01314730287049315, 0.02920653161709197, 0.05305633778334595, 0.01875898666185094, 0.03566067083738744, 0.04240747228323016, 0.0588438465638319, 0.03336231740831863, 0.03567490151908714, 0.05557942466111854, 0.04619645158527419, 0.10128319408977404, 0.0032215774854194024, 0.046570635022362694, 0.04517933448369149, 0.040041520333033986, 0.06482239899924025, 0.07262806335347705, 0.024814056378090754, 0.017831604491220787, 0.024392774394073058, 0.03099647492490476, 0.03091418373514898, 0.01463110005715862, 0.030047182699490804, 0.03430532735364977, 0.10240588540909812, 0.03809606183494907, 0.03347600701090414, 0.025996768890763633, 0.016725077148294076, 0.011418049616622739, 0.02144120113371173, 0.03332171079819091, 0.044316476487438194, 0.07499177401768975, 0.036055452583241276, 0.021732258464908227, 0.08731572990654968, 0.053043442967464216, 0.17295255849603564, 0.06495137684396468, 0.07593413829454221, 0.07252702736877836, 0.07748588745016605, 0.2150519986753352, 1.519347403664142, 21.54318530112505, 62.02505216002464, 89.54832047224045, 79.9307781457901, 78.65865960717201, 62.60582819581032, 47.818309888243675, 45.26555746793747, 35.161873027682304, 26.346921734511852, 37.3266776651144, 61.876172348856926, 106.42159625887871, 74.29817318916321, 54.98994626104832, 66.75006061792374, 38.431035205721855, 35.228407457470894, 33.19778122007847, 11.433855313807726, 4.283940000459552, 1.991430390626192, 0.7540497067384422, 0.2526761993067339, 0.15968079096637666, 0.5901365366298705, 0.824452507076785, 0.25828594516497105, 0.034740719420369714, 0.09824314198340289, 0.0682815418986138, 0.03780382263357751, 0.07844424500945024, 0.03782493673497811, 0.08411670234636404, 0.098723734554369, 0.09607799293007702, 0.005424073497124482, 0.043561831043916754, 0.08455230592517182, 0.06850354053312913, 0.0065552401429158635, 0.05249049099802505, 0.14879663125611842, 0.03907440172042698, 0.09793704317416996, 0.15313589450670406, 0.08335769307450391, 0.03635656044934876, 0.07676277586142533, 0.06974679374252446, 0.06687506072921678, 0.039863230485934764, 0.043262819744995795, 0.10909994613029994, 0.08401064944337122, 0.04680786994867958, 0.028945559097337537, 0.12625858595129102, 0.214877950202208, 0.33933678350877017, 3.503129160962999, 14.73610706627369, 34.13927949965, 41.461342200636864, 23.98139476776123, 29.65285073965788, 52.7026741951704, 82.36412957310677, 55.48812232911587, 34.75930742919445, 30.19560221582651, 29.521630480885506, 47.14521020650864, 47.26213373243809, 46.21128872036934, 61.47679477930069, 68.5117980837822, 83.07972237467766, 55.32570004463196, 18.573751039803028, 1.516143106855452, 0.22209916583960876, 0.04609304072801024, 0.06174485730298329, 0.0415197746042395, 0.06278121087234467, 0.06071794014133047, 0.09732898673973978, 0.0015335688567574834, 0.05273212314932607, 0.05488874863658566, 0.01834280694311019, 0.0678438603063114, 0.04409827022755053, 0.02889323397539556, 0.05339316892786883, 0.008458486208837712, 0.06404318104614504, 0.01371033877148875, 0.061015315004624426, 0.05997875734465197, 0.05949324804532807, 0.038437416369561106, 0.0478160849888809, 0.019630681781563908, 0.03132223879219964, 0.08291737685794942, 0.0382857696240535, 0.039238512836163864, 0.037147070179344155, 0.04958864163199905, 0.08926518115913495, 0.06322200206341222, 0.017135709313151892, 0.017194843640027102, 0.014589561124012107, 0.0392534003185574, 0.07392155996058136, 0.04301345441490412, 0.04674004507251084, 0.016401252141804434, 0.04894784164207522, 0.07873788315919228, 0.030579690355807543, 0.028848176334577147, 0.0845108347130008, 0.07109218131517991, 0.02614716697280528, 0.010350619540986372, 0.028143217678007204, 0.024155730570782907, 0.009045963815879077, 0.006379969909175998, 0.03212227027688641, 0.03128473064862192, 0.05193163153307978, 0.051398301948211156, 0.03164901012496557, 0.012642068213608582, 0.08499112300341949, 0.019312087060825434, 0.06371979019604623, 0.07550067952251993, 0.04309458970965352, 0.013935232709627599, 0.049793864018283784, 0.04569938333588652, 0.007980194295669207, 0.04795006490894593, 0.03132018304313533, 0.04673616735090036, 0.012171862927061738, 0.04017977131297812, 0.02276208299008431, 0.06837720473413356, 0.07748265910777263, 0.0429466648347443, 0.011128124988317722, 0.0676940503763035, 0.06680037098703906, 0.012649780983338133, 0.06522238691104576, 0.01312197708102758, 0.03154773294227198, 0.034082942802342586, 0.08600955741712824, 0.06010037679516245, 0.05676197761204094, 0.16621896356809884, 0.01837133695516968, 0.08249666818301193, 0.05983041315630544, 0.02858924101019511, 0.3364512836560607, 5.377087667584419, 40.75629383325577, 85.21767765283585, 100.34209728240967, 92.34314650297165, 102.50096663832664, 90.5663238465786, 78.39227870106697, 68.17445978522301, 41.40806145966053, 21.095162741839886, 22.117307893931866, 45.585656091570854, 69.60004448890686, 68.43584775924683, 63.87526407837868, 60.17288334667683, 36.32801905274391, 31.59819435328245, 24.740096256136894, 5.531079629436135, 0.8362853690050542, 0.20618076610844582, 0.36411626322660595, 0.34651890280656517, 0.5760362651199102, 0.6679457926657051, 0.827283711405471, 0.3757128253346309, 0.05829931797052268, 0.06306340510491282, 0.19206232682336122, 0.03243666258640587, 0.30178143933881074, 0.13586298620793968, 0.2385537524241954, 0.06375198456225917, 0.2157088735839352, 0.03663219038571697, 0.230759865953587, 0.15195184241747484, 0.23313117621000856, 0.2815082506276667, 0.08569827099563554, 0.061865723473601975, 0.04861551904468797, 0.03744726149307098, 0.09630623302655295, 0.06660673723672517, 0.07883913436671719, 0.06010801349475514, 0.022805917942605447, 0.1277554829721339, 0.10159171972190961, 0.02304263151017949, 0.11908574349945411, 0.04346288049418945, 0.07736303232377395, 0.10521413511014543, 0.1597174975904636, 0.4744901874801144, 0.29898128646891564, 1.1069993488490582, 9.183160085231066, 25.44735800474882, 30.37879228591919, 20.948644503951073, 35.37909597158432, 65.0079832971096, 87.65576362609863, 47.63976126909256, 24.436304457485676, 23.866021558642387, 36.257251650094986, 57.96315751969814, 68.40466663241386, 72.03576698899269, 77.93431207537651, 77.69607245922089, 96.13704532384872, 78.67230847477913, 35.838156938552856, 4.502367004752159, 0.2338020331808366, 0.06750101034413092, 0.04718091418908443, 0.07017932482995093, 0.0777527860191185, 0.08689919952303171, 0.04771438478201162, 0.027758777760027442, 0.06149894295958802, 0.08085259585641325, 0.05006825827877037, 0.08073630873695947, 0.03739810905244667, 0.05098964204080403, 0.046896307976567186, 0.0616267593431985, 0.02486622008291306, 0.013114657649566652, 0.05928038153797388, 0.10800535252201371, 0.039705301460344344, 0.05132948630489409, 0.05343478114809841, 0.031485507570323534, 0.032781097033875994, 0.0680520549940411, 0.008921374846977415, 0.012892950308014406, 0.0532175582338823, 0.03236036980524659, 0.10500182892428711, 0.01845502894866513, 0.026347387283749413, 0.00788863182606292, 0.01752635358570842, 0.06697936958516948, 0.05891865504963789, 0.01115279583245865, 0.0805158240837045, 0.012694978704530513, 0.007830876038497081, 0.09005538289784454, 0.05468655792356003, 0.018209593290521298, 0.06078796548536047, 0.028708079262287356, 0.01664057435846189, 0.14143988461000845, 0.09631399589125067, 0.15419738832861185, 0.16599018912529573, 0.12482031859690323, 0.14436366443987936, 0.0987038821040187, 0.12122593412641436, 0.16247871739324182, 0.10556739740422927, 0.09284492305596359, 0.23361104889772832, 0.0968854124948848, 0.11500095526571386, 0.1916869930573739, 0.12661454966291785, 0.1833323249593377, 0.1694339027744718, 0.13621679769130424, 0.0444507718202658, 0.16952018486335874, 0.1004614881821908, 0.13266723894048482, 0.1070586837886367, 0.10976166726322845, 0.10551300540100783, 0.2129703338141553, 0.24650629522511736, 0.10661306121619418, 0.11797639599535614, 0.17831600038334727, 0.11583255400182679, 0.1070711667125579, 0.14207865111529827, 0.1433588410145603, 0.15972635883372277, 0.1330147570115514, 0.149972282233648, 0.16541259043151513, 0.14371204393683001, 0.2871970203705132, 0.19246317562647164, 0.15980985044734553, 0.20611159794498235, 0.160577810020186, 0.5686130071990192, 3.1235984014347196, 34.479254856705666, 92.53661692142487, 116.18635028600693, 98.90524998307228, 96.77538067102432, 86.71343699097633, 64.60006758570671, 59.73193220794201, 44.27929759025574, 35.54433390498161, 50.81448711454868, 84.6984127163887, 138.6157563328743, 99.14367198944092, 75.08046001195908, 95.28263077139854, 57.58338309824467, 52.72396445274353, 47.14681752026081, 16.879993826150894, 8.278754465281963, 4.048989107832313, 1.8760417448356748, 0.9557698981370777, 1.212073804344982, 1.4334844797849655, 1.3047767174430192, 0.617965649580583, 0.07283258441020735, 0.3119578870246187, 0.37160287087317556, 0.13943933648988605, 0.4633120779180899, 0.287030185572803, 0.338623728021048, 0.19049042835831642, 0.20248295593773946, 0.1650627123308368, 0.29987530724611133, 0.25069816794712096, 0.40933184791356325, 0.3425864700693637, 0.13760329282376915, 0.3870146657573059, 0.1527029403951019, 0.2175611851271242, 0.26216233090963215, 0.29261873569339514, 0.20257425494492054, 0.33642489288467914, 0.37321523122955114, 0.573916572611779, 0.22197107115061954, 0.19162931333994493, 0.3210714308079332, 0.2271583568654023, 0.2047176961787045, 0.2571607899153605, 0.45218737330287695, 1.1141852382570505, 1.2377613759599626, 4.171741995960474, 17.831565365195274, 42.713671401143074, 58.133042603731155, 40.40189445018768, 44.14787024259567, 77.98749402165413, 112.34306171536446, 77.90033429861069, 48.76482009887695, 43.890206068754196, 38.82445849478245, 57.251109927892685, 61.22894547879696, 64.71666052937508, 78.34967538714409, 87.05725774168968, 107.10029304027557, 83.7069471180439, 34.128142297267914, 3.0200988426804543, 0.3643202647799626, 0.13830350915668532, 0.2096349440398626, 0.1397767019807361, 0.15589537768391892, 0.23197393049485981, 0.28206762217450887, 0.19036665296880528, 0.20613488653907552, 0.19668204768095165, 0.12585316551849246, 0.19751153129618615, 0.18264739686856046, 0.18183737236540765, 0.14086080162087455, 0.12196680530905724, 0.12479806900955737, 0.0712699256837368, 0.16528761276276782, 0.21475736604770645, 0.15496656502364203, 0.16731395793613046, 0.10292345177731477, 0.1273208812926896, 0.12410423514666036, 0.19062128383666277, 0.14107231370871887, 0.22034581226762384, 0.25718338089063764, 0.25733733200468123, 0.17410668719094247, 0.16912132501602173, 0.08587390024331398, 0.07426280688378029, 0.12171396301710047, 0.15052213944727555, 0.13456550426781178, 0.15418377734022215, 0.17545729206176475, 0.12413246644428, 0.10080357373226434, 0.33984839043114334, 0.19099133351119235, 0.13214102655183524, 0.1884708961006254, 0.11424643598729745, 0.15870802832068875], [0.005421427740657236, 0.014329699042718858, 0.027799269337265287, 0.008136309697874822, 0.06045398418791592, 0.03739248728379607, 0.018670251774892677, 0.027578202098084148, 0.0035017989966945606, 0.055336111545329913, 0.029857925765099935, 0.038266644478426315, 0.06701645470457152, 0.04910699150059372, 0.06920408341102302, 0.03734222904313356, 0.045705732409260236, 0.010199358712270623, 0.028601052290468942, 0.031237496659741737, 0.027930054311582353, 0.0145624068682082, 0.02086712578602601, 0.02621039795485558, 0.06907077142386697, 0.023007232921372633, 0.06794459943193942, 0.019825673662126064, 0.03741153079317883, 0.08343966328538954, 0.03513410592859145, 0.1150961134408135, 0.026913371366390493, 0.007357361700996989, 0.015386673185275868, 0.044036779581801966, 0.04399038793053478, 0.07548159148427658, 0.0097605100927467, 0.0369637634139508, 0.11740017027477734, 0.0066430881634005345, 0.03467141024884768, 0.11105099300039001, 0.29508453619200736, 14.158484861254692, 60.30824348330498, 84.14958536624908, 84.22735959291458, 76.68861731886864, 70.52510485053062, 60.93490585684776, 42.53659710288048, 37.62202821671963, 40.38366682827473, 43.62697519361973, 63.11382293701172, 68.66406351327896, 48.5055486112833, 51.4033567160368, 31.43732998520136, 24.822574630379677, 21.71952623873949, 24.198676608502865, 7.640205854550004, 0.18828362255590037, 0.12998090183828026, 0.17346783162793145, 0.031375580656458624, 0.01809908564609941, 0.09742991140228696, 0.05250131893262733, 0.28883707767818123, 0.4283045860938728, 0.06740554788848385, 0.08845258882502094, 0.08596277242759243, 0.07001352161751129, 0.25555721658747643, 0.10476328039658256, 0.19987547944765538, 0.26559209218248725, 0.09017885400680825, 0.132568845001515, 0.33248432620894164, 0.09022338286740705, 0.16811034176498652, 0.11255195699050091, 0.05639178692945279, 0.06385891319951043, 0.22702365706209093, 0.3615827194880694, 0.16613183543086052, 0.26974390377290547, 0.06515805012895726, 0.14258150069508702, 0.155892705952283, 0.16499157005455345, 0.22005736915161833, 0.2782755147200078, 0.14764069172088057, 0.3472892817808315, 0.27243849355727434, 0.12476660194806755, 0.007428329108734033, 0.08930221432819963, 0.08936959391576238, 0.05043102748459205, 0.2551858755759895, 0.5848910962231457, 0.13088169100228697, 3.11202778480947, 15.576663762331009, 23.073954060673714, 17.730593383312225, 14.245012868195772, 35.98153464496136, 61.526587307453156, 60.11332154273987, 50.01893900334835, 35.71958810091019, 26.71334747225046, 40.520174503326416, 55.57512246072292, 51.34887523949146, 51.39221951365471, 66.71394735574722, 74.80258092284203, 44.57984246313572, 10.210410263389349, 0.14892895618686453, 0.46987622568849474, 0.08354523379239254, 0.03754728444619104, 0.10169729765038937, 0.07578035045298748, 0.02197318372054724, 0.03597022434405517, 0.052390390119398944, 0.023543623865407426, 0.02439017316646641, 0.02756938909442397, 0.08748832377023064, 0.04020244021376129, 0.03323171797092073, 0.04529411504336167, 0.011368701434548711, 0.09740216992213391, 0.032487811404280365, 0.05549296816752758, 0.04286020091967657, 0.08577489032177255, 0.031114062658161856, 0.01288247211050475, 0.0615238457248779, 0.043865432526217774, 0.04481360039790161, 0.1319854723988101, 0.022589357395190746, 0.050720806466415524, 0.04319340667279903, 0.016807034371595364, 0.036560087028192356, 0.02645386877702549, 0.025624834161135368, 0.08000503352377564, 0.03519383768434636, 0.02051844810921466, 0.053069158384460025, 0.003070907823712332, 0.03224117717763875, 0.02230269914434757, 0.022087788020144217, 0.06891736207762733, 0.0286497520210105, 0.03885137150064111, 0.010110314906341955, 0.010597143373161089, 0.050562947944854386, 0.056387052027275786, 0.06262734139454551, 0.0024547705606892123, 0.032006313413148746, 0.03988821859820746, 0.015088199015735881, 0.02210842714703176, 0.04443327197805047, 0.052179419799358584, 0.049518044834258035, 0.040270413519465365, 0.05749432522861753, 0.013344240105652716, 0.033405391659471206, 0.042500392883084714, 0.026482346838747617, 0.049004849715856835, 0.03768091926758643, 0.0084578470341512, 0.04663847103074659, 0.031231195825967006, 0.02978249016450718, 0.06024428665114101, 0.02872035067412071, 0.10659029212547466, 0.057937001474783756, 0.06763244469766505, 0.054301023337757215, 0.07730564204393886, 0.035890591898350976, 0.05670546306646429, 0.029222114862932358, 0.05716183935874142, 0.08263396550319158, 0.008485287016810616, 0.012792298384738388, 0.043683691692422144, 0.07500076884753071, 0.06434771392378025, 0.03396515654458199, 0.04882409964920953, 2.401891965419054, 31.3376347348094, 84.77882400155067, 93.8395594060421, 94.39882099628448, 95.00559523701668, 96.00393086671829, 84.05857264995575, 60.440780371427536, 48.8160565495491, 39.84346121549606, 26.367402635514736, 39.97590310871601, 64.4938176870346, 58.410423919558525, 58.70135150849819, 31.442324817180634, 16.830396987497807, 10.715592205524445, 13.68252145126462, 3.84845819324255, 0.4721644154051319, 0.3105763642815873, 0.02367213415709557, 0.09203814915963449, 0.050464806336094625, 0.1011658605420962, 0.1860945689259097, 0.1899419812252745, 0.23039885563775897, 0.02144309732102556, 0.14170122449286282, 0.13657141069415957, 0.051493159553501755, 0.2791006048209965, 0.13778749387711287, 0.3949165198719129, 0.37637256493326277, 0.4341714712791145, 0.16770389716839418, 1.0333964671008289, 0.7719735824503005, 0.4290890065021813, 0.4693408403545618, 0.27706352819222957, 0.2583751216297969, 0.29762864811345935, 0.40212859224993736, 0.353260186384432, 0.3003609093138948, 0.13669840700458735, 0.13981940515805036, 0.16896069457288831, 0.08318261301610619, 0.0731578009435907, 0.3008529532235116, 0.16403655958129093, 0.0999832185334526, 0.09824711989494972, 0.1550962182227522, 0.07699715351918712, 0.09657334681833163, 0.10840664661373012, 0.011008961118932348, 0.166905197838787, 0.4854973655892536, 0.29550732288043946, 1.4843167271465063, 5.39469069801271, 7.865555612370372, 11.632993128150702, 17.998471409082413, 47.90434867143631, 65.08016422390938, 42.737572118639946, 19.75741032510996, 26.303651556372643, 28.98999720811844, 59.966562017798424, 89.41439285874367, 82.46821358799934, 71.83544933795929, 77.99431845545769, 89.14937227964401, 66.0274837911129, 21.968040503561497, 0.741389439208433, 0.3575418144464493, 0.1000799129542429, 0.046569762998842634, 0.11113973159808666, 0.04239362751832232, 0.04907889378955588, 0.03165207519487012, 0.05011752946302295, 0.06448391286539845, 0.05639428796712309, 0.06680095728370361, 0.053282596345525235, 0.03136229621304665, 0.015245483300532214, 0.06957400692044757, 0.04232731291267555, 0.03023831912287278, 0.03052676223887829, 0.03554343005816918, 0.008723818846192444, 0.017266663126065396, 0.045120663999114186, 0.07493923738365993, 0.014173335021041567, 0.03971164311224129, 0.02736619091592729, 0.13800049026031047, 0.011095672725787153, 0.04376880489871837, 0.038797547240392305, 0.003645984374998079, 0.038402965874411166, 0.05915474706853274, 0.048951133067021146, 0.08360578562133014, 0.05406673102697823, 0.0336280396732036, 0.04158852345426567, 0.008150811263476498, 0.04712078538432252, 0.08240830065915361, 0.020020890042360406, 0.04150535096414387, 0.03677988890558481, 0.02915978002420161, 0.11259862323640846, 0.18976500869030133, 0.12025319374515675, 0.19312350894324481, 0.17101007601013407, 0.08928552342695184, 0.23978438170161098, 0.10488770887604915, 0.10480913770152256, 0.2972222480457276, 0.1441633142530918, 0.1054199697682634, 0.17807275406084955, 0.08076117068412714, 0.29023848997894675, 0.11828679183963686, 0.10279280410031788, 0.14995162084233016, 0.1600685334415175, 0.15493616665480658, 0.13216621504398063, 0.09458059867029078, 0.11147137513034977, 0.17544841597555205, 0.2693474484840408, 0.1384211247204803, 0.22163003945024684, 0.19976749696070328, 0.12864154792623594, 0.20089452242245898, 0.18943939881864935, 0.23066739435307682, 0.11388175204047002, 0.11985863093286753, 0.12303500814596191, 0.11746839591069147, 0.13074227113975212, 0.17770316451787949, 0.2238265739288181, 0.1860013254918158, 0.27607201889622957, 0.1847359785460867, 0.11868061250424944, 0.33396375307347625, 1.1926332162693143, 25.272082909941673, 88.33173975348473, 111.53783172369003, 104.18433710932732, 94.77421805262566, 92.03860804438591, 76.70532882213593, 50.43871007859707, 45.49935892224312, 55.45852191746235, 63.611763417720795, 86.14602863788605, 94.78495627641678, 65.6473445892334, 71.34858906269073, 46.99423670768738, 37.62717694044113, 30.955863520503044, 33.570571616292, 10.970454029738903, 1.1660550674423575, 1.5344646549783647, 0.4025888128671795, 0.4400895943399519, 0.22380378999514505, 0.29152961913496256, 0.34702326636761427, 0.4140709951752797, 0.6217602209653705, 0.269324115361087, 0.6442658789455891, 0.4410867439582944, 0.3113935876172036, 0.6189149455167353, 0.5940404115244746, 0.7784126931801438, 0.8944172621704638, 0.8478877495508641, 0.9442886954639107, 1.3885005936026573, 0.8740175818093121, 0.7342954573687166, 0.5225436261389405, 0.8465145982336253, 0.5287611018866301, 1.1162747698836029, 1.4291370380669832, 1.056072344072163, 0.9039692964870483, 0.40119995770510286, 0.5627059866674244, 0.6446339841932058, 0.4447117791278288, 0.5595037085004151, 0.8980615634936839, 0.7744734326843172, 0.7664519443642348, 0.6485981214791536, 0.6842433556448668, 0.31200455327052623, 0.21442632365506142, 0.2585063630249351, 0.17954474460566416, 0.3023451747139916, 0.5550371075514704, 0.512825291370973, 4.777080863714218, 22.01391164213419, 32.23523586988449, 27.39114560186863, 20.143047831952572, 53.83055627346039, 84.94302839040756, 78.50971519947052, 62.66434885561466, 50.61635434627533, 35.77747039496899, 49.23595301806927, 75.2109906077385, 69.5036132633686, 67.37068891525269, 84.25179988145828, 97.54977911710739, 71.05577677488327, 18.418759256601334, 0.41943188407458365, 0.588989770039916, 0.34606298664584756, 0.1981577489641495, 0.2772005583392456, 0.19028115755645558, 0.11735537424101494, 0.1117394982429687, 0.16202345432247967, 0.1161867291375529, 0.13331802823813632, 0.15161878138314933, 0.1635973565862514, 0.09007369910250418, 0.10297114960849285, 0.11061533004976809, 0.13804487069137394, 0.304541545920074, 0.16696160106221214, 0.15688566985772923, 0.10188753236434422, 0.15999081573681906, 0.11027693297364749, 0.1382322926656343, 0.1816237228922546, 0.24548904824769124, 0.13683631288586184, 0.26409298356156796, 0.1179703845991753, 0.20476660371059552, 0.05586970459262375, 0.08225221958127804, 0.08468453437671997, 0.10360191576182842, 0.10030888777691871, 0.19412760506384075, 0.10042262932984158, 0.1462476805318147, 0.1739767668186687, 0.09098784692469053, 0.17932086833752692, 0.22189982497366145, 0.11005183216184378, 0.20894955581752583, 0.14715749421156943, 0.1518134615616873], [0.020063394695171155, 0.06805236669606529, 0.022098588124208618, 0.003321022722957423, 0.03493605639960151, 0.0348632888199063, 0.054082230781205, 0.005716546475014184, 0.07525702501880005, 0.01704952370346291, 0.05206051289860625, 0.014529504678648664, 0.057737000097404234, 0.06076653968193568, 0.02242682148789754, 0.0362746867176611, 0.03806132561294362, 0.015612569950462785, 0.001451958355573879, 0.030160738715494517, 0.00976629513388616, 0.03185909357853234, 0.0583351228851825, 0.03779599668632727, 0.0739075630553998, 0.027022739814128727, 0.02653348637977615, 0.05066930141765624, 0.03092652008490404, 0.04859126936935354, 0.03601259355491493, 0.0163594525292865, 0.007035049284240813, 0.05892552733712364, 0.03519227546348702, 0.016011275802156888, 0.013344443268579198, 0.0828336997074075, 0.05878841555386316, 0.07927271188236773, 0.25653931545093656, 0.08219973489758559, 0.19786238903179765, 8.947167098522186, 44.776371717453, 88.07719141244888, 80.40832132101059, 78.09081807732582, 63.3048614859581, 58.711420968174934, 48.396490663290024, 42.742390260100365, 40.700938403606415, 39.148881286382675, 50.602663680911064, 60.28209708631039, 39.13464345037937, 31.78152121603489, 30.05020871758461, 27.371785640716553, 21.14931933581829, 11.012540571391582, 2.3657891526818275, 0.38761408359277993, 0.9338028018828481, 0.05349066115741152, 0.023647891903237905, 0.09592453163350001, 0.014037278015166521, 0.05319984687957913, 0.03726284521690104, 0.05939821232459508, 0.1398917200276628, 0.2293072603060864, 0.004206627545499941, 0.11061087716370821, 0.1124172646086663, 0.07126579192117788, 0.11930155262234621, 0.19270268152467906, 0.1441124771372415, 0.07786582253174856, 0.1585100233205594, 0.491133353789337, 0.08520935894921422, 0.21916892932495102, 0.4687047901097685, 0.1706622462370433, 0.28844400658272207, 0.03726069669937715, 0.029489885455404874, 0.04382940496725496, 0.03726532027940266, 0.021162832672416698, 0.057922358901123516, 0.2008267494966276, 0.05655614295392297, 0.015609016918460838, 0.04230026534060016, 0.01209275647852337, 0.09565497617586516, 0.009832118066697149, 0.0678859103936702, 0.04299848158552777, 0.0799319393991027, 0.0458329105458688, 0.051963825899292715, 0.11135162960272282, 0.2463745343266055, 0.35196326847653836, 0.17144699319032952, 0.013272818596306024, 0.2083649512496777, 1.8073561554774642, 18.615121319890022, 30.515887029469013, 15.779975652694702, 17.714077569544315, 40.2798829972744, 72.9276779294014, 98.13215866684914, 56.130162477493286, 23.499875105917454, 23.423746190965176, 36.535533517599106, 41.58536374568939, 52.30835795402527, 55.74045538902283, 68.64475294947624, 65.57444930076599, 34.28830750286579, 6.441037226468325, 0.15699568582931533, 0.0890773806895595, 0.0433022129436722, 0.11090949512436055, 0.04549727054836694, 0.044105999695602804, 0.0411089402041398, 0.016155215344042517, 0.021014931917306967, 0.0037758057169412496, 0.08436176693066955, 0.03884489997290075, 0.06491160514997318, 0.030024940533621702, 0.051822880923282355, 0.04576332306896802, 0.04413318827573676, 0.06908164388732985, 0.06458884512539953, 0.02938394944067113, 0.05328726445441134, 0.05021621283958666, 0.029869484715163708, 0.08962498919572681, 0.021605633228318766, 0.04514901775110047, 0.07307765641598962, 0.03148439805954695, 0.02834554197761463, 0.023930652023409493, 0.03143890069623012, 0.005548484814426047, 0.03878153540426865, 0.08123875755700283, 0.08537270565284416, 0.029642964545928407, 0.04784340344485827, 0.08443715429166332, 0.061521990355686285, 0.08799613831797615, 0.0642836517363321, 0.03393067636352498, 0.020239537880115677, 0.03908863240212668, 0.08922996625187807, 0.0302397978521185, 0.022320479147310834, 0.05355390327167697, 0.0864768803876359, 0.00806128506155801, 0.033115709156845696, 0.03833701121038757, 0.06813955420511775, 0.05162339162779972, 0.029753036178590264, 0.06870432116556913, 0.06950269395019859, 0.06581013076356612, 0.03778908358071931, 0.09085462399525568, 0.05104699892399367, 0.060240472012083046, 0.05005679209716618, 0.049663064201013185, 0.05287206993671134, 0.0126889617422421, 0.027191175795451272, 0.04510651124292053, 0.09355648682685569, 0.03357655317813624, 0.005224797569098882, 0.056759647268336266, 0.04254997576936148, 0.10805381476529874, 0.049766482479753904, 0.05296781069773715, 0.004220408764012973, 0.04279268774553202, 0.04415858456923161, 0.0468188871309394, 0.09336862698546611, 0.029134370743122417, 0.04196819878416136, 0.0481210186262615, 0.2432914450764656, 0.15084375656442717, 0.45591711066663265, 23.981322571635246, 70.94504311680794, 101.911131888628, 92.84854978322983, 102.63645976781845, 90.36204680800438, 83.0050639808178, 72.69076824188232, 44.682543352246284, 30.35007532685995, 18.108536303043365, 28.98725375533104, 69.98713731765747, 54.53319177031517, 35.3624414652586, 23.847362659871578, 11.70371113345027, 6.054265955463052, 3.900927915237844, 0.4133005568291992, 0.4967444948852062, 0.7903133577201515, 0.1100611015863251, 0.046880032678018324, 0.007907516701379791, 0.03497081117529888, 0.07096164496033452, 0.04055478966620285, 0.08035713064600714, 0.1255774576566182, 0.20315220986958593, 0.09437190674361773, 0.08323352434672415, 0.15451842657057568, 0.10134759766515344, 0.09856539734755643, 0.32784403301775455, 0.06237000910914503, 0.11336379233398475, 0.17040911450749263, 0.39818099001422524, 0.153676682675723, 0.6705563713330775, 0.7152775966096669, 0.38941756181884557, 0.5800599523354322, 0.27402716455981135, 0.3900326241273433, 0.09080842530238442, 0.1121211402642075, 0.2307496836874634, 0.015105597740330268, 0.04549862125713844, 0.03478023507341277, 0.029283642616064753, 0.027822279625979718, 0.06389676273101941, 0.027822951269627083, 0.08473357549519278, 0.060662869072984904, 0.07309998763957992, 0.03881905468006153, 0.0356598618964199, 0.09596683405106887, 0.04283793648937717, 0.1029408625618089, 0.21390765148680657, 0.08948120550485328, 0.033666957897366956, 0.09097992820898071, 0.5334713053889573, 6.061328826472163, 8.531833235174417, 8.137289006263018, 19.800950288772583, 50.97577325999737, 64.72049072384834, 73.79568055272102, 35.755378380417824, 19.83892735093832, 29.973304644227028, 51.0513512045145, 67.32724204659462, 82.95049890875816, 74.85045835375786, 81.31075009703636, 81.94913864135742, 55.50306312739849, 16.183740086853504, 0.38758442737162113, 0.12485957820899785, 0.02845979561243439, 0.08895033985027112, 0.031137989499256946, 0.00872953431098722, 0.014423452703340445, 0.07769941817969084, 0.035061386588495225, 0.04428103151440155, 0.05210271512623876, 0.023172987894213293, 0.01210133477798081, 0.037193168682279065, 0.10046342518762685, 0.04448252460861113, 0.04851893965678755, 0.03484003362245858, 0.03898155162460171, 0.055926104105310515, 0.021880658314330503, 0.019788078316196334, 0.010632062349031912, 0.03636753681348637, 0.016011687694117427, 0.07380602983175777, 0.01341987515843357, 0.035381341294851154, 0.05879264579562005, 0.06595032988116145, 0.07041494187433273, 0.04072489362442866, 0.030981370364315808, 0.04789750601048581, 0.04759354458656162, 0.04895930782367941, 0.030579484409827273, 0.04172915672825184, 0.028680009381787386, 0.013166043027013075, 0.03513229879899882, 0.030069690183154307, 0.008514985911460826, 0.017324875334452372, 0.1478269707877189, 0.2011047283303924, 0.15818085114005953, 0.15289175760699436, 0.13824145076796412, 0.08889830045518465, 0.11964379402343184, 0.10568335797870532, 0.1687181755551137, 0.1151321224460844, 0.12250958985532634, 0.1533158207894303, 0.18268217390868813, 0.1603255985537544, 0.15019878570456058, 0.18548801162978634, 0.11342585814418271, 0.20460658182855695, 0.1355549058644101, 0.16200064070289955, 0.13148556172382087, 0.15175787470070645, 0.12879934336524457, 0.13658595678862184, 0.11232272983761504, 0.09665881254477426, 0.1653960405383259, 0.1563997264020145, 0.09044768215971999, 0.2921562292613089, 0.09912203036947176, 0.1440017783897929, 0.12570942635647953, 0.15562430082354695, 0.17942288395715877, 0.14727534726262093, 0.13361377408728004, 0.14733237389009446, 0.11603880426264368, 0.20833585906075314, 0.45262936677318066, 0.11886856882483698, 0.22929571248823777, 17.297538220882416, 71.09075009822845, 116.83676138520241, 99.01675119996071, 98.51504132151604, 85.93397721648216, 80.03885954618454, 63.05314399302006, 54.91939924657345, 54.64235991239548, 57.773775681853294, 70.35672828555107, 85.12831404805183, 56.15638867020607, 42.12404944002628, 43.95971193909645, 37.64354266226292, 29.487912990152836, 16.507169231772423, 4.368315897881985, 1.110173009801656, 1.1229430558159947, 0.18962241243571043, 0.28885420644655824, 0.3181237983517349, 0.230653278704267, 0.35186753142625093, 0.15868680289713666, 0.32490575162228197, 0.3094671800499782, 0.41388070851098746, 0.1932327530812472, 0.20560318225761876, 0.31818426854442805, 0.43973520398139954, 0.4662466485751793, 0.5401144770439714, 0.2541650366038084, 0.29621224442962557, 0.4584300226997584, 1.2105201627127826, 0.23352681513642892, 1.4219023450277746, 1.9147081137634814, 0.8774914860259742, 1.0214463458396494, 0.7417365268338472, 0.4242752882419154, 0.3489797160727903, 0.21836261556018144, 0.4614244995173067, 0.32188075769227, 0.33492768416181207, 0.31035829160828143, 0.11972831722232513, 0.117515730089508, 0.1523461751639843, 0.2205392753239721, 0.23716511990642175, 0.22978937427978963, 0.22422325186198577, 0.2128894248744473, 0.2894176746485755, 0.29083155503030866, 0.40521975606679916, 0.5899618053808808, 0.47557054669596255, 0.3734988800715655, 0.16842118289787322, 0.34801097586750984, 3.526511681266129, 28.04451484233141, 40.6718547642231, 23.11293426901102, 28.731400184333324, 61.431995183229446, 101.86639308929443, 120.68011835217476, 65.1342049241066, 32.211289554834366, 30.465414337813854, 46.26126363873482, 56.05800814926624, 72.68812358379364, 74.88983944058418, 91.60044595599174, 91.59111365675926, 56.893062740564346, 13.117883149534464, 0.28885385021567345, 0.3475027531385422, 0.18136806786060333, 0.2481667764368467, 0.14605709700845182, 0.14297938090749085, 0.09473508413066156, 0.32630164234433323, 0.08015952640562318, 0.10641317116096616, 0.1620720501523465, 0.17168992781080306, 0.118030075536808, 0.1859163644257933, 0.2004853615653701, 0.15512381127336994, 0.07612198329297826, 0.12180617486592382, 0.23329311283305287, 0.13112743094097823, 0.1809742843033746, 0.18996001541381702, 0.08251840568846092, 0.2155736691202037, 0.0803557650942821, 0.17248729127459228, 0.16759414836997166, 0.06516729728900827, 0.1842599650262855, 0.22106090123998, 0.1776677492307499, 0.06835680309450254, 0.13643455866258591, 0.13021472288528457, 0.2612322417553514, 0.1667365522007458, 0.13682924763998017, 0.12797799368854612, 0.13731569575611502, 0.1045297784730792, 0.19759947579586878, 0.16470958362333477, 0.1798393327044323, 0.1341563434107229], [0.08178687072359025, 0.043746187948272564, 0.020934978492732625, 0.06624367117183283, 0.03457206265011337, 0.01645895968977129, 0.01627227244171081, 0.03521432096022181, 0.05833867777255364, 0.025000431924127042, 0.03340976662002504, 0.014728803798789158, 0.02487123700120719, 0.04613357683410868, 0.01923397787322756, 0.06024815695127472, 0.024220395753218327, 0.02865027894586092, 0.016664208051224705, 0.07004804632742889, 0.03890405656420626, 0.030517921404680237, 0.09409916747245006, 0.04803536365216132, 0.09031955036334693, 0.05666380631737411, 0.0712908171408344, 0.013352477017178899, 0.052015594410477206, 0.09824734996072948, 0.05905009682464879, 0.07808661146555096, 0.05376096989493817, 0.04979705154255498, 0.08377892125281505, 0.02510773905669339, 0.050464921368984506, 0.04871504475886468, 0.1050491705245804, 0.052513538394123316, 0.16504119004821405, 0.9346976538654417, 24.527567960321903, 78.24927717447281, 83.52248221635818, 71.76047936081886, 77.94375836849213, 53.069042935967445, 42.86092109978199, 37.92900234460831, 34.617392644286156, 44.68182519078255, 44.370192512869835, 67.68084347248077, 59.93699200451374, 22.50870019197464, 24.961320385336876, 39.309031292796135, 35.06639935076237, 9.852580614387989, 0.6328109779860824, 0.48274577886331826, 0.23619268380571157, 0.14373473881278187, 0.58973518316634, 0.14252374676289037, 0.014535860245814547, 0.07351525637204759, 0.06445956300012767, 0.07522999600041658, 0.08375788136618212, 0.1421311654848978, 0.28280781058128923, 0.15675962349632755, 0.048436880388180725, 0.1077390402497258, 0.010368008061050205, 0.07492911448935047, 0.16615488653769717, 0.028933931498613674, 0.05121546644659247, 0.1714457166963257, 0.2530576928984374, 0.19232981168897822, 1.2742499867454171, 0.29629097145516425, 0.3687946731224656, 0.41046653233934194, 0.3860396321397275, 0.20944906573276967, 0.4098747140960768, 0.10725863321567886, 0.18741643783869222, 0.176595613011159, 0.08802074051345699, 0.020841197001573164, 0.06683563042315654, 0.13186249852878973, 0.08027949457755312, 0.0388938668766059, 0.08551585109671578, 0.061536862995126285, 0.05382020812248811, 0.10717404322349466, 0.06158256444905419, 0.09200580636388622, 0.06416581352823414, 0.046016380583751015, 0.062472640711348504, 0.13698364404262975, 0.11398099944926798, 0.120549971179571, 0.09785099115106277, 0.20514434203505516, 0.8121291152201593, 2.2512352745980024, 18.109528049826622, 27.080468572676182, 18.071756176650524, 18.090099692344666, 41.17372423410416, 74.73526373505592, 67.87983119487762, 41.9252061098814, 34.415608271956444, 22.668981291353703, 36.09537273645401, 44.09972682595253, 56.21308542788029, 53.695416525006294, 68.40316951274872, 60.73332667350769, 28.42149831354618, 1.481812542770058, 0.33751487033441663, 0.04559980196063407, 0.03961123053159099, 0.036355554839246906, 0.00993677758742706, 0.04543772061879281, 0.026946894176944625, 0.1086987930466421, 0.044113128024036996, 0.018891391373472288, 0.047246957910829224, 0.018686386065382976, 0.022252737762755714, 0.053878210674156435, 0.05615722002403345, 0.06154129732749425, 0.0349284902040381, 0.06383247789926827, 0.03997808526037261, 0.05034658592194319, 0.04730369138997048, 0.03393294362467714, 0.05509378919668961, 0.027836437948280945, 0.09983507843571715, 0.062302124861162156, 0.07619460244313814, 0.02056159843050409, 0.05514614029380027, 0.0428665908111725, 0.0449824241513852, 0.06542613613419235, 0.02454512803524267, 0.02978442716994323, 0.07753714759019203, 0.01997591032704804, 0.0716975140676368, 0.04172898974502459, 0.028852801769971848, 0.017108364882005844, 0.04225217046041507, 0.045694140062551014, 0.01939100333402166, 0.014295725377451163, 0.0066857950514531694, 0.08092862146440893, 0.034042948464048095, 0.0445201329421252, 0.02396670555754099, 0.036318280472187325, 0.050042246002703905, 0.049635040704743005, 0.014409195118787466, 0.05726840434363112, 0.03956972221203614, 0.06600536755286157, 0.03343873635458294, 0.011411669929657364, 0.05062221214757301, 0.012795791117241606, 0.0019785158428931027, 0.020247547508915886, 0.0342466271831654, 0.03803529849392362, 0.07792460804921575, 0.029017204178671818, 0.09077376700588502, 0.03384632014785893, 0.0792466476559639, 0.0037650009744538693, 0.12268547885469161, 0.1383812862331979, 0.0390090853034053, 0.04448123698239215, 0.012476406009227503, 0.05101653376186732, 0.03439906802668702, 0.04219289883621968, 0.02818479093548376, 0.08963390238932334, 0.13190643367124721, 0.0675634249637369, 0.2084016875596717, 4.9294365383684635, 45.74724242091179, 95.97702071070671, 91.36610493063927, 91.45226150751114, 110.42533501982689, 80.65973103046417, 62.28629574179649, 61.04241728782654, 47.73040160536766, 24.141307286918163, 29.0839471668005, 68.67255985736847, 79.87328723073006, 26.795320473611355, 15.622654594480991, 14.451393093913794, 14.068305250257254, 3.390507479198277, 0.28436142252758145, 0.4787399328779429, 0.07589468572405167, 0.09823367217904888, 0.5714628542773426, 0.0799756073683966, 0.02414736842183629, 0.06867178541142493, 0.0957251462386921, 0.06471457236330025, 0.1564246477209963, 0.25921066117007285, 0.27790144260507077, 0.18172655487433076, 0.06732643494615331, 0.03950066908146255, 0.03942161551094614, 0.07133594714105129, 0.08575014711823314, 0.031225997081492096, 0.17183292482513934, 0.14136292389594018, 0.20339251728728414, 0.3632710757665336, 0.40822343551553786, 0.7195159129332751, 0.38497604546137154, 0.3872727253474295, 0.40487735881470144, 0.35264479753095657, 0.5116493138484657, 0.2988608804298565, 0.7525969378184527, 0.34299426537472755, 0.12213681649882346, 0.16650008910801262, 0.05815208329295274, 0.09361611839267425, 0.0843463747878559, 0.025045192705874797, 0.0653881455946248, 0.16739313025027514, 0.03145621871226467, 0.05907798302359879, 0.06923026638105512, 0.04107497210497968, 0.047165136129478924, 0.15736615110654384, 0.05542669438000303, 0.11743588242097758, 0.16790525667602196, 0.09104250610107556, 0.07627318103914149, 0.12775855546351522, 0.37166533002164215, 1.3557828054763377, 6.034751627594233, 8.266091644763947, 10.168359819799662, 19.383835271000862, 44.32832255959511, 66.28440320491791, 32.395697459578514, 21.21277403086424, 23.804183676838875, 20.069339387118816, 48.43733087182045, 68.00056591629982, 86.17889687418938, 72.03155681490898, 80.84833770990372, 75.69451466202736, 49.43087495863438, 6.629853844642639, 0.17369619046803564, 0.07404578063869849, 0.010941407126665581, 0.02409946835541632, 0.0863031436165329, 0.03972391823481303, 0.03948628997022752, 0.06559829213074408, 0.03956217457016464, 0.03629590843047481, 0.05059638169768732, 0.02452807719237171, 0.01863885892817052, 0.03401773399673402, 0.028177734966448043, 0.090055813343497, 0.05577055737376213, 0.06543582858284935, 0.08815181121462956, 0.03467704686045181, 0.019220673020754475, 0.023450603075616527, 0.027409747563069686, 0.0176536170692998, 0.016116916813189164, 0.08080060841166414, 0.021693585149478167, 0.09750267898198217, 0.1708754207356833, 0.0574966555723222, 0.025188510699081235, 0.027216434791625943, 0.013324498977453914, 0.06096809585869778, 0.03690658093546517, 0.0384327259962447, 0.06811009836383164, 0.06075363002310041, 0.015139007373363711, 0.023035762933432125, 0.09924927158863284, 0.036454980363487266, 0.15785317809786648, 0.0968881361768581, 0.12007849218207411, 0.2954756480176002, 0.11765421484597027, 0.2714501606533304, 0.08243177479016595, 0.08617458879598416, 0.1376538330805488, 0.15800902910996228, 0.11107288635685109, 0.08338621380971745, 0.10203899728367105, 0.11940832540858537, 0.13970201223855838, 0.13270888826809824, 0.1399534518714063, 0.07268097106134519, 0.06492966902442276, 0.24966708733700216, 0.14918707514880225, 0.20564288715831935, 0.14872624597046524, 0.12716519355308264, 0.17793079605326056, 0.13625362305901945, 0.16991966811474413, 0.16415310645243153, 0.29301804082933813, 0.172512850840576, 0.21690410241717473, 0.22756854188628495, 0.1524241006700322, 0.11685519639286213, 0.1521504411357455, 0.1996995459194295, 0.09098354988964275, 0.13851399708073586, 0.2500336489174515, 0.1293952582636848, 0.3350102703552693, 2.940840795636177, 43.099016323685646, 108.75286996364594, 106.02554351091385, 91.21095925569534, 101.62543281912804, 72.16530963778496, 57.85572208464146, 48.59913758933544, 48.872449323534966, 65.8130156993866, 61.50457888841629, 95.4918247461319, 85.78690230846405, 32.20071852207184, 37.89914354681969, 55.45147329568863, 46.47350884974003, 17.24095545709133, 1.922425024677068, 0.9570861118845642, 0.34976395836565644, 0.2536460378905758, 1.2001386447809637, 0.469251693575643, 0.1912840810837224, 0.3274712077109143, 0.2356598959886469, 0.2672012761468068, 0.2306222272454761, 0.43646580597851425, 0.6534010637551546, 0.3335005638655275, 0.37342056864872575, 0.406531635671854, 0.21717749477829784, 0.30896997079253197, 0.4760015266947448, 0.4556236951611936, 0.587342024082318, 1.1299147317185998, 1.1179006076417863, 0.845543690957129, 3.257796037942171, 2.1478696586564183, 1.7445766367018223, 1.8962894333526492, 1.4875746960751712, 0.7775093510281295, 0.7950357918161899, 0.6231765949632972, 0.6977783481124789, 0.4791791655588895, 0.4450105084106326, 0.43932746804784983, 0.4725728934863582, 0.339305168017745, 0.4407241602893919, 0.2928670879919082, 0.41056203190237284, 0.5782782635651529, 0.22003137913998216, 0.30290003400295973, 0.2526506991125643, 0.24448898941045627, 0.1738546389969997, 0.36774693871848285, 0.1523537450702861, 0.2837268268922344, 0.3509100718656555, 0.5399804748594761, 0.30782670713961124, 0.34056046628393233, 1.3153543998487294, 5.447267051786184, 26.071043238043785, 36.14111468195915, 26.002751402556896, 27.902153581380844, 60.76492577791214, 101.5889547765255, 87.38592490553856, 56.8824765086174, 49.868398681283, 30.771833695471287, 45.87970711290836, 58.687976226210594, 75.56445524096489, 72.68382221460342, 90.03559872508049, 83.87501209974289, 50.22440157830715, 5.292883710935712, 0.48417845042422414, 0.20143636444117874, 0.18721007625572383, 0.1352514119935222, 0.16468130779685453, 0.1652743134764023, 0.1957198977470398, 0.26865238265600055, 0.2251886375597678, 0.1313216658309102, 0.18008813029155135, 0.08574367559049278, 0.10253878179355524, 0.16525797138456255, 0.11890572815900669, 0.16426190530182794, 0.13423049880657345, 0.20081252994714305, 0.1398194200010039, 0.15015925891930237, 0.11304534418741241, 0.11014729461749084, 0.15578735066810623, 0.1411160855786875, 0.220189040992409, 0.12658499734243378, 0.12518236791947857, 0.21496755711268634, 0.36448991973884404, 0.12810064101358876, 0.10110570947290398, 0.18469373550033197, 0.07132715269108303, 0.1650478396913968, 0.1752302097156644, 0.14890137797920033, 0.2799756563035771, 0.14034091233043, 0.08046637478400953, 0.1420796604361385, 0.1856883618165739, 0.16473496507387608], [0.032965168211376294, 0.04947814697516151, 0.04968929541064426, 0.01321119529166026, 0.02888022969273152, 0.06356658122967929, 0.059986282722093165, 0.0664182985201478, 0.04367549467133358, 0.022272558671829756, 0.044890011922689155, 0.08097501311567612, 0.023915081765153445, 0.014007816607772838, 0.038514774132636376, 0.025125283427769318, 0.06317250081337988, 0.040479294693795964, 0.0339182565221563, 0.011310078261885792, 0.026480608357815072, 0.022190256349858828, 0.028179102373542264, 0.09259204365662299, 0.02995113580254838, 0.034198766079498455, 0.015941443416522816, 0.052175004020682536, 0.0864013668615371, 0.02591812350146938, 0.03549833345459774, 0.037961310081300326, 0.0658094702521339, 0.04894278390565887, 0.0342584904137766, 0.021466064936248586, 0.059821822796948254, 0.07517460209783167, 0.07184136455180123, 1.102101649157703, 21.334017924964428, 55.3839623183012, 81.89781099557877, 65.85830926895142, 76.50092259049416, 62.33258865773678, 47.848039492964745, 34.04943712055683, 42.556815817952156, 37.08869643509388, 41.79968364536762, 81.30928337574005, 66.08320400118828, 30.254994928836823, 13.161078281700611, 39.37567971646786, 29.771235287189484, 8.45454253256321, 0.26653993350919336, 0.8351018512621522, 0.033718644772307016, 0.3417034924495965, 0.1391215340117924, 0.180257206375245, 0.16042762901633978, 0.0743218521529343, 0.06755208494723774, 0.05909743100346532, 0.03996243707661051, 0.0950126325187739, 0.03692708276503254, 0.06152343012217898, 0.12162079379777424, 0.2254279504995793, 0.054622276802547276, 0.1111828800640069, 0.06855489715235308, 0.11233755052671768, 0.022735087368346285, 0.09698038513306528, 0.013193305821914691, 0.053740857692901045, 0.061992645569262095, 0.04100681697309483, 0.08852656610542908, 0.03497287805657834, 0.09990061749704182, 0.12738856516079977, 0.03150777571136132, 0.08748554813791998, 0.0443335384625243, 0.05907713326450903, 0.031407463320647366, 0.0749612420622725, 0.02680506975593744, 0.06782872791518457, 0.010356952843721956, 0.047973787659429945, 0.0641857847222127, 0.08515933819580823, 0.013984318356961012, 0.011387168851797469, 0.07096869536326267, 0.05063884367700666, 0.05530618815100752, 0.052650327343144454, 0.02428722429613117, 0.09887309919577092, 0.0769187678815797, 0.06796939458581619, 0.08428884349996224, 0.0658396162907593, 0.05373468673496973, 0.2482370429788716, 0.525333626428619, 0.15335515461629257, 0.7552875496912748, 2.55995184648782, 16.788228750228882, 23.081851936876774, 17.059420198202133, 20.702837593853474, 55.561583787202835, 65.67098692059517, 59.231943637132645, 54.4680442661047, 27.9251841455698, 31.08154557645321, 38.307861015200615, 43.05235102772713, 54.29916612803936, 61.74535296857357, 82.34265312552452, 51.70410297811031, 20.5400600284338, 0.2866223902674392, 0.03276532268500887, 0.026729302044259384, 0.06803905256674625, 0.038932213647058234, 0.011571825398277724, 0.013142694133421173, 0.07682418858166784, 0.04797848545422312, 0.059657707970472984, 0.04783148084243294, 0.03795755110331811, 0.0218367268826114, 0.013288883310451638, 0.05461983884742949, 0.032297658326569945, 0.04412880589370616, 0.02343727039260557, 0.05636692498228513, 0.02199466518504778, 0.018216187272628304, 0.10616872255923226, 0.018926006996480282, 0.07113898114766926, 0.04245652824465651, 0.02677929682249669, 0.09041671233717352, 0.022437703228206374, 0.04050606024975423, 0.052149021430523135, 0.03748642462596763, 0.0986182976339478, 0.05119439316331409, 0.05457614119222853, 0.06059466199076269, 0.02451341977575794, 0.09201822991599329, 0.030117911228444427, 0.06886743038194254, 0.054627382778562605, 0.02004249025048921, 0.04955618380336091, 0.018411264500173274, 0.05264758139674086, 0.033281601427006535, 0.026943259508698247, 0.028612447968043853, 0.011642970457614865, 0.03413604346860666, 0.054305832454701886, 0.07112050167052075, 0.04787052523170132, 0.08559183217585087, 0.044292631282587536, 0.03256975192925893, 0.06020151296979748, 0.031601987648173235, 0.040670445960131474, 0.072195836546598, 0.02448302140692249, 0.02338370217330521, 0.04038913859403692, 0.008841338858474046, 0.035725682973861694, 0.02264507784275338, 0.018924177602457348, 0.025196913666150067, 0.053299224164220504, 0.007208359320429736, 0.04614608573319856, 0.039901020645629615, 0.1093519497953821, 0.03541967693308834, 0.035332537663634866, 0.038941097154747695, 0.041814177166088484, 0.043550824993872084, 0.02376404358074069, 0.02772914565866813, 0.06628233706578612, 4.096119403839111, 41.88922964036465, 80.99574699997902, 95.59003427624702, 81.74112260341644, 101.64239510893822, 86.16028547286987, 69.90696921944618, 52.58429914712906, 49.134069085121155, 19.756101295351982, 15.495982691645622, 83.7133763730526, 86.38664692640305, 36.698385179042816, 12.655905839055777, 14.924077279865742, 11.072906032204628, 2.8687691129744053, 0.41730943077709526, 0.5017964425496757, 0.07896863913629204, 0.26210580894257873, 0.2488367131445557, 0.19005820155143738, 0.18480339524103329, 0.06312316283583641, 0.13854595395969227, 0.10548292615567334, 0.05757510429248214, 0.02786311259114882, 0.07637653994606808, 0.20827578962780535, 0.09732012549648061, 0.1205501715594437, 0.09935818918165751, 0.038914301912882365, 0.03255640440329444, 0.0848728914570529, 0.06652352763921954, 0.04687594344432, 0.039062842770363204, 0.11478323882329278, 0.3903030924266204, 0.061719902587356046, 0.269653094583191, 0.349717351491563, 0.3448260045843199, 0.6916302780155092, 0.3368545963894576, 0.16818161762785167, 0.04377522818685975, 0.16448941809358075, 0.07431486112182029, 0.10577674242085777, 0.03903619966877159, 0.08543171381461434, 0.06744445126969367, 0.15946277766488492, 0.10799544485053048, 0.1218067982699722, 0.07076860492816195, 0.15576468547806144, 0.08508475235430524, 0.12566690129460767, 0.07458300649886951, 0.05623311204544734, 0.10545630531851202, 0.1459639723179862, 0.04434004338691011, 0.14411740499781445, 0.11814919766038656, 0.030794024460192304, 0.07182037661550567, 0.28055889531970024, 0.2977987186750397, 0.1085683457495179, 0.6174151541199535, 0.9541139588691294, 4.769958620890975, 8.780197408050299, 14.196365028619766, 24.541518911719322, 56.58979341387749, 48.90139997005463, 39.0960793197155, 35.23187667131424, 16.23419187963009, 32.366473227739334, 54.97604660689831, 66.86637997627258, 77.0076633989811, 81.52052164077759, 94.6903945505619, 76.0159470140934, 35.83772376179695, 0.8833749359473586, 0.05997895401378628, 0.046661948872497305, 0.04154114103585016, 0.06531571198138408, 0.030976262532931287, 0.08686198081704788, 0.0337167003453942, 0.04328305811213795, 0.004046973954245914, 0.07629618019564077, 0.0807291544333566, 0.058345594588899985, 0.052261356613598764, 0.07414519874146208, 0.024108850957418326, 0.06796607718570158, 0.040683403858565725, 0.04099849007616285, 0.0400467190775089, 0.03733704514161218, 0.022955167551117484, 0.03372675273567438, 0.04572764060867485, 0.02939969410363119, 0.015410379237437155, 0.05947614525211975, 0.0025890863025779254, 0.019694118709594477, 0.024567420296079945, 0.020798861187358852, 0.042320785723859444, 0.050513554306235164, 0.07284251434612088, 0.01098414184525609, 0.05555032505071722, 0.032283590917359106, 0.04589309872244485, 0.05991075806377921, 0.021841369016328827, 0.09140535694314167, 0.15610307513270527, 0.16142740583745763, 0.23328080802457407, 0.12947057140991092, 0.12899809051305056, 0.19013669108971953, 0.1271147423540242, 0.07442521848133765, 0.12114432014641352, 0.13654453010531142, 0.18043784511974081, 0.19974129914771765, 0.19662647566292435, 0.11230126692680642, 0.1269967111875303, 0.1830191831686534, 0.11112925989436917, 0.1395591488108039, 0.09864483683486469, 0.10375162921263836, 0.09309027707786299, 0.14032262581167743, 0.09059441959834658, 0.17294840246904641, 0.1075483305612579, 0.12791724147973582, 0.11746181306079961, 0.139181069098413, 0.18413252342725173, 0.10494903996004723, 0.16326088167261332, 0.12849806109443307, 0.1446460367878899, 0.1649496387108229, 0.17246049974346533, 0.08769408421358094, 0.12542469397885725, 0.1338457694509998, 0.21906295063672587, 2.110665854997933, 37.22901530563831, 87.89298489689827, 110.37349060177803, 86.62014439702034, 101.34894445538521, 82.64095231890678, 63.91785979270935, 42.827156111598015, 57.1219776570797, 50.70735566318035, 55.957233756780624, 95.127462297678, 93.19858700037003, 41.50775671005249, 19.111633077263832, 57.5538244843483, 43.201257437467575, 14.985900912433863, 1.1023183562792838, 1.2482554628513753, 0.2547023812076077, 0.741493102395907, 0.5521792452782393, 0.5823097284883261, 0.28396490786690265, 0.22627260361332446, 0.3302519756834954, 0.2190425861044787, 0.2652956190286204, 0.33082170761190355, 0.22069067345000803, 0.3447157808113843, 0.17320851038675755, 0.40176695853006095, 0.3530335641698912, 0.17385561863193288, 0.23104525142116472, 0.32496387662831694, 0.16690286749508232, 0.2118295934633352, 0.1434178714407608, 0.172413031978067, 0.46439887897577137, 0.1596661112853326, 0.5421802599448711, 0.22990569850662723, 0.2559678320540115, 0.6145778938662261, 0.7670923287514597, 0.19926285138353705, 0.2095226274104789, 0.12894996965769678, 0.15494489431148395, 0.1493291073711589, 0.07111168495612219, 0.20071266655577347, 0.07395035529043525, 0.2890699339332059, 0.14824438432697207, 0.25752387824468315, 0.10843794298125431, 0.1758682043873705, 0.3060858661774546, 0.23410181631334126, 0.28148907353170216, 0.2553784183692187, 0.3392720385454595, 0.408654801431112, 0.3783067502081394, 0.3578907425981015, 0.32600410049781203, 0.2373099426040426, 0.18968690506881103, 0.7396162406075746, 0.9855881449766457, 0.5054839665535837, 1.2357541336677969, 4.5374557469040155, 24.101388528943062, 30.319184884428978, 26.53646696358919, 36.10176779329777, 84.89227831363678, 93.10224696993828, 81.30641832947731, 72.87161573767662, 41.70864053070545, 40.880725756287575, 46.78995206952095, 58.25243979692459, 72.70219802856445, 79.62223470211029, 103.44909936189651, 80.83304733037949, 33.88127714395523, 0.5566079076379538, 0.1791376172332093, 0.1498196372995153, 0.14696315542096272, 0.28250053175725043, 0.18117769213858992, 0.1291518338257447, 0.16058840788900852, 0.16112630168208852, 0.14674076344817877, 0.16352432925486937, 0.16889581602299586, 0.14295972883701324, 0.16415856865933165, 0.22468265611678362, 0.08362448032130487, 0.16179977101273835, 0.17463236523326486, 0.0716345279943198, 0.11219601554330438, 0.16219535056734458, 0.19224789342842996, 0.07372527674306184, 0.13831795135047287, 0.09179955610306934, 0.11451792845036834, 0.2016830988577567, 0.12644188158446923, 0.14183225808665156, 0.22996501094894484, 0.14841478143353015, 0.1879490920691751, 0.11074539143010043, 0.1937378291040659, 0.19539308559615165, 0.17095738352509215, 0.1528211051481776, 0.11329469096381217, 0.1480506095685996, 0.2031826676102355, 0.14419083308894187], [0.03619485389208421, 0.004814955791516695, 0.0689521613821853, 0.011618057487794431, 0.02506577060557902, 0.04282860769308172, 0.07414747713482939, 0.011006908152921824, 0.07749538694042712, 0.03063375952478964, 0.03081603099417407, 0.029842952935723588, 0.034907120061689056, 0.06396940414560959, 0.007044054318612325, 0.015993223059922457, 0.04334094192017801, 0.053280885695130564, 0.03850131899525877, 0.05622965734801255, 0.019767583908105735, 0.029863295203540474, 0.022266966589086223, 0.03233537056075875, 0.026898033029283397, 0.056913546432042494, 0.0468554045073688, 0.012815201062039705, 0.02585528029158013, 0.049571991548873484, 0.026239184007863514, 0.051456174624036066, 0.06517536443425342, 0.04908009977953043, 0.041832942370092496, 0.033548756036907434, 0.10950204174150713, 0.09188989031827077, 8.134380262345076, 45.02169035375118, 83.55998620390892, 83.8077861070633, 72.02954292297363, 66.09680727124214, 58.171496540308, 52.835154086351395, 35.977810844779015, 38.118186593055725, 32.49997906386852, 73.38684529066086, 88.78074645996094, 24.561859220266342, 11.672488208860159, 28.025069385766983, 45.71331404149532, 8.79816284403205, 0.36092131747864187, 0.5355903448071331, 0.035139319516019896, 0.585348199820146, 0.05010802997276187, 0.16930552606936544, 0.040311027551069856, 0.08079509425442666, 0.186848932353314, 0.08561397044104524, 0.05694762214261573, 0.06017322601110209, 0.1578710786998272, 0.04956610260705929, 0.10399482358479872, 0.12711926945485175, 0.0744394380308222, 0.2650562021881342, 0.004046272624691483, 0.09468576099607162, 0.10088195936987177, 0.012179406858194852, 0.1163357894984074, 0.070583394553978, 0.05808192065160256, 0.11229795694816858, 0.01882053111330606, 0.13317075645318255, 0.0642489043821115, 0.06878430984215811, 0.12524058198323473, 0.1371018384816125, 0.19136702350806445, 0.19160232885042205, 0.389898176654242, 0.44504770485218614, 1.0309822903946042, 0.7009446469601244, 0.14595010899938643, 0.1162476371973753, 0.17133010493125767, 0.07760988548398018, 0.039773341559339315, 0.03022100110683823, 0.2037977596046403, 0.8389376860577613, 0.07022639183560386, 0.011952368113270495, 0.02954214007331757, 0.11840894934721291, 0.04869862103078049, 0.04130382447328884, 0.04625900350220036, 0.006533373689308064, 0.06147818137833383, 0.06932301999768242, 0.04170178632193711, 0.0231667668413138, 0.18681794026633725, 0.30445391312241554, 0.37655810185242444, 0.3197270748205483, 0.8979360514786094, 0.588077997090295, 8.97510889917612, 17.857008799910545, 18.31462014466524, 29.734504558146, 37.69096031785011, 56.628156155347824, 58.82228761911392, 33.08199383318424, 27.881915867328644, 29.508365392684937, 42.359192222356796, 39.57089424133301, 46.44599452614784, 68.46444502472878, 68.1899705529213, 32.12143957614899, 1.5538885002024472, 0.25787013466469944, 0.04239005778799765, 0.03572228393750265, 0.06424094855901785, 0.04533105173322838, 0.04454447167518083, 0.024696876826055814, 0.004678340319514973, 0.031472746341023594, 0.03333277622004971, 0.00702840149642725, 0.06018471816787496, 0.05446917544759344, 0.04521883529378101, 0.02876315404137131, 0.021222746254352387, 0.043423468741821125, 0.0759569148067385, 0.03483948443317786, 0.022637489382759668, 0.0383118412719341, 0.021939310245215893, 0.061184602600405924, 0.05194047793338541, 0.05288323183776811, 0.033324645992252044, 0.02245229570689844, 0.04126807893044315, 0.016320233735314105, 0.010615208175295265, 0.04097671917406842, 0.028574038115039002, 0.045910342523711734, 0.07093382184393704, 0.03146211878629401, 0.07186114278738387, 0.047529296862194315, 0.049527169539942406, 0.040579146952950396, 0.03174643927195575, 0.01405353847076185, 0.094893807254266, 0.04355033888714388, 0.011353099635016406, 0.0207710974427755, 0.010337240473745624, 0.03152945755573455, 0.07933334534754977, 0.034768639015965164, 0.03472554250038229, 0.039287401814362966, 0.013200093690102221, 0.08903991707484238, 0.04288697018637322, 0.03123186375887599, 0.07722278867731802, 0.0810214492958039, 0.0886027624073904, 0.037925356737105176, 0.05186378810321912, 0.03872330278682057, 0.03856063885905314, 0.025956765275623184, 0.0058550855010253144, 0.04298877429391723, 0.0034052330602207803, 0.05136741376190912, 0.07520664803450927, 0.06200752191944048, 0.04407712272950448, 0.025559078021615278, 0.07289174100151286, 0.08634742014692165, 0.01731734624627279, 0.03549182481947355, 0.07537317855167203, 0.32444897457025945, 19.688803106546402, 66.75933972001076, 99.60983857512474, 96.11401095986366, 96.69479459524155, 88.36932733654976, 73.68849590420723, 74.76964429020882, 43.50513473153114, 20.887127704918385, 13.844188526272774, 48.71122397482395, 98.47844168543816, 35.28632394969463, 10.574632119387388, 10.424685515463352, 17.34423391520977, 3.619687194004655, 0.3545319306431338, 0.6747404811903834, 0.05590559485426638, 0.5578083463478833, 0.15202669543214142, 0.13409248902462423, 0.023527307748736348, 0.06854847015347332, 0.28196666040457785, 0.14281636074883863, 0.0978241179836914, 0.02000279833737295, 0.11374720066669397, 0.0208439114067005, 0.07127559569198638, 0.196765806467738, 0.1266346321790479, 0.19685042614582926, 0.07960074115544558, 0.3148435353068635, 0.2080547038349323, 0.15848692768486217, 0.19018684542970732, 0.2256365236826241, 0.37679362983908504, 0.610853381222114, 0.6467764161061496, 0.6855726905632764, 0.33773647563066334, 0.6456967396661639, 0.8811485522892326, 1.0829010419547558, 1.2837640824727714, 0.9327443211805075, 0.704908724874258, 0.6996641156729311, 1.0772762750275433, 2.2437470639124513, 0.9789791714865714, 0.7438737340271473, 0.5035832966677845, 0.17846428148914129, 0.6079398281872272, 0.10524358352995478, 0.3417543740943074, 1.211375710554421, 0.12165504391305149, 0.04008164454717189, 0.07305753679247573, 0.1565004061558284, 0.03543536222423427, 0.055732934197294526, 0.08073297649389133, 0.11792889112257399, 0.031665333663113415, 0.03751671909412835, 0.029676355625269935, 0.02720464577578241, 0.10653804492903873, 0.3556211956311017, 0.33547191589605063, 0.20632349594961852, 0.4190266417572275, 0.1956648303894326, 2.4438379146158695, 11.308934167027473, 19.919847808778286, 35.48061892390251, 35.1298863440752, 49.191172420978546, 42.95668736100197, 19.071436934173107, 21.139434166252613, 39.72905695438385, 62.14128792285919, 62.3680255562067, 66.04091227054596, 80.45028626918793, 81.16744458675385, 49.40071977674961, 4.107009619474411, 0.056875745140132494, 0.03259146717027761, 0.04084570784470998, 0.0973319924378302, 0.032450503640575334, 0.03256225252698641, 0.036310432260506786, 0.018941159796668217, 0.014978109757066704, 0.025058434475795366, 0.03403208342206199, 0.04166078637354076, 0.0635486286773812, 0.009227161954186158, 0.03858112955640536, 0.0760871394595597, 0.023434938193531707, 0.09547917623422109, 0.03834010596619919, 0.04323667017160915, 0.04497523645113688, 0.06292719132034108, 0.033804782142397016, 0.03262504564190749, 0.032872904412215576, 0.0467910231964197, 0.021638415746565443, 0.08133301773341373, 0.0455767990933964, 0.021440381060529035, 0.004745393825942301, 0.017260820568480995, 0.06939541650353931, 0.023061411557137035, 0.015959620468493085, 0.018560033568064682, 0.027106255547550973, 0.03633056301623583, 0.06155008064524736, 0.16575984132941812, 0.07230275034089573, 0.18660951551282778, 0.13872602867195383, 0.0809731577464845, 0.08727880063815974, 0.17612912866752595, 0.1097470469539985, 0.15360619348939508, 0.091569104406517, 0.18123078538337722, 0.13490503682987764, 0.06733191941748373, 0.2236248878762126, 0.13418123504379764, 0.11432655082899146, 0.14866846235236153, 0.1842033540015109, 0.21554086619289592, 0.15686408820329234, 0.17528262018458918, 0.1471303464495577, 0.14168158726533875, 0.14977804734371603, 0.1461009430931881, 0.1641268641105853, 0.12569087266456336, 0.13605932879727334, 0.1160158718994353, 0.22828358632978052, 0.18600766343297437, 0.11052063200622797, 0.1739046597504057, 0.16832155699376017, 0.15848053037188947, 0.12415477540344, 0.1602108625229448, 0.25428283028304577, 15.174006018787622, 72.47719690203667, 112.58849054574966, 105.4519870877266, 93.29330831766129, 91.70388400554657, 74.19864133000374, 65.93216970562935, 50.078531205654144, 52.73464187979698, 46.69111177325249, 98.22906106710434, 128.98254364728928, 34.31889206171036, 20.150337740778923, 41.1380023509264, 66.24579727649689, 15.122505482286215, 0.9882224723696709, 1.3051866204477847, 0.16212950722547248, 1.5058964816853404, 0.5875589686911553, 0.2210492198355496, 0.11027708140318282, 0.21613967546727508, 0.717772637726739, 0.4132061853306368, 0.1780933709233068, 0.2809629502007738, 0.31862385745625943, 0.19676047784741968, 0.17581671418156475, 0.4298394365468994, 0.14888077595969662, 0.48157701501622796, 0.22157139494083822, 0.23056540841935202, 0.31795663700904697, 0.17398665222572163, 0.20141614833846688, 0.24382585077546537, 0.27738309698179364, 0.335763668990694, 0.5082970624789596, 0.6193372572306544, 0.26451951067429036, 0.36155980196781456, 0.8465160231571645, 0.7698266976512969, 0.8145896613132209, 0.793988888617605, 0.6639832584187388, 1.6020673024468124, 3.031502505764365, 1.480521799530834, 0.44826749770436436, 0.27800436364486814, 0.2620651986217126, 0.2417710071313195, 0.3741392644587904, 0.1168822476756759, 1.1626040213741362, 2.04674924723804, 0.19852233643177897, 0.22339917108183727, 0.1821426919195801, 0.33284509903751314, 0.1312764987233095, 0.2268919110065326, 0.20603221782948822, 0.19597348960814998, 0.1997088227653876, 0.20941783615853637, 0.1738499486236833, 0.14422522421227768, 0.37792202085256577, 0.9254503750707954, 0.6980975309852511, 0.5359501973725855, 1.1371211637742817, 1.5052815084345639, 13.60049620270729, 24.964056238532066, 30.903479531407356, 50.212424620985985, 58.22069250047207, 77.51155436038971, 79.67613860964775, 49.13726471364498, 37.436947748064995, 38.6104691773653, 53.10745507478714, 53.85347664356232, 63.65016795694828, 86.53683766722679, 94.23020124435425, 49.75255809724331, 2.634510020725429, 0.31534944253508, 0.12920779176056385, 0.12643656780710444, 0.14308354875538498, 0.2224709521397017, 0.2213973761536181, 0.17320156388450414, 0.1294398316531442, 0.07066257428959943, 0.17539238382596523, 0.1079757185652852, 0.14791783934924752, 0.15641134843463078, 0.2559009497053921, 0.23710850888164714, 0.1859779775259085, 0.1125337892153766, 0.20186410867609084, 0.10090738534927368, 0.16724550223443657, 0.13156509026885033, 0.12532067456049845, 0.21208245801972225, 0.15190740261459723, 0.1694049738580361, 0.10021352180046961, 0.16661592351738364, 0.14924214250640944, 0.10487314051715657, 0.09198192405165173, 0.09347681727376767, 0.08916245307773352, 0.19868215051246807, 0.19135093374643475, 0.1638788532000035, 0.0935649398888927, 0.13634566421387717, 0.10526104626478627, 0.25325097783934325], [0.06570455283508636, 0.04708486172603443, 0.030884108200552873, 0.05129264609422535, 0.023729448366793804, 0.07866038809879683, 0.11651830587652512, 0.03629669881775044, 0.011381746535334969, 0.11508531519211829, 0.017205523145094048, 0.005766581607531407, 0.056520089419791475, 0.07867708642152138, 0.045609910011989996, 0.010902455505856778, 0.03089304551394889, 0.014313920983113348, 0.07308627275051549, 0.03314753244922031, 0.0019682041647683945, 0.08082077256403863, 0.03393216436961666, 0.02810680049151415, 0.02724152680457337, 0.03331529864226468, 0.01897595724585699, 0.07587660700664856, 0.03265176295826677, 0.08149745539412834, 0.03403828406590037, 0.03217270663299132, 0.033931047437363304, 0.033204425490112044, 0.054230664027272724, 0.07726260490017012, 0.7172846607863903, 25.49808908253908, 82.05816239118576, 85.91829925775528, 73.94679084420204, 70.99510923027992, 61.007934138178825, 45.22857405245304, 38.32411274313927, 21.768881790339947, 51.83587610721588, 84.93535280227661, 57.482939288020134, 46.95737108588219, 13.402693066745996, 20.681657530367374, 45.57939022779465, 30.51938284188509, 1.4812856772914529, 0.6519497791305184, 0.16256942268228158, 0.2897168492199853, 0.16695005324436352, 0.17698109935736284, 0.022579165852221195, 0.1047111074149143, 0.17949812288861722, 0.121737526205834, 0.21803078649099916, 0.03638545225840062, 0.010318324057152495, 0.09165248469798826, 0.06605005968594924, 0.11854330776259303, 0.1543864727136679, 0.17164382559712976, 0.28729994141031057, 0.15276997117325664, 0.03777149468078278, 0.0924282442429103, 0.12906651652883738, 0.09389265745994635, 0.059175783244427294, 0.1343369227834046, 0.37570947082713246, 0.33770236652344465, 1.9444532738998532, 1.2145518651232123, 0.1870265876641497, 4.412558823823929, 1.5444165584631264, 2.7622947888448834, 3.169338684529066, 0.807689290959388, 0.4395789373666048, 0.36137848044745624, 0.9594165743328631, 3.5123733524233103, 3.1502456590533257, 2.9874557442963123, 1.4322142791934311, 0.9207966341637075, 1.983211669139564, 0.046676728743477724, 0.8828074601478875, 0.25369377282913774, 0.16552331886487082, 0.04682667597080581, 0.12840855808462948, 0.02804208892484894, 0.031737514946144074, 0.08264293064712547, 0.1164645298558753, 0.2629155811155215, 0.08387064328417182, 0.1020729579613544, 0.09543193111312576, 0.04014397010905668, 0.042077832549693994, 0.047231190983438864, 0.10900542620220222, 0.23041016596835107, 0.4147464386187494, 0.11238257662625983, 0.5679381871595979, 0.12700956518528983, 6.182613093405962, 15.336615443229675, 29.817653596401215, 27.29260928928852, 42.20916107296944, 69.94286969304085, 58.50487545132637, 31.588463075459003, 26.97604827582836, 41.620454862713814, 52.79552221298218, 52.64896787703037, 58.80702383816242, 69.29246619343758, 43.79284389317036, 10.248860400170088, 0.3814089868683368, 0.029518061091948766, 0.10034563150838949, 0.05229695372690912, 0.01644826163101243, 0.05871643836144358, 0.04512545085162856, 0.03745562178664841, 0.025388875728822313, 0.016771450245869346, 0.04114465235034004, 0.03304376907180995, 0.033957946579903364, 0.0013957356827631884, 0.12790558976121247, 0.08811526786303148, 0.022285527702479158, 0.07701880938839167, 0.03644789656391367, 0.0296769827400567, 0.023753217501507606, 0.03210469621990342, 0.020841787008976098, 0.044978787627769634, 0.02547971274907468, 0.01872942506452091, 0.053990030064596795, 0.07201890111900866, 0.051873016709578224, 0.05338020360795781, 0.062438962049782276, 0.04452374720131047, 0.027233858563704416, 0.04847579119086731, 0.025853107654256746, 0.044913226302014664, 0.05017232593672816, 0.022698994871461764, 0.054762705985922366, 0.01836107490817085, 0.023767889761074912, 0.08622874331194907, 0.08104239270323887, 0.06846904550911859, 0.10286290736985393, 0.05249476947938092, 0.059608132505672984, 0.04700705125287641, 0.006597989240617608, 0.044938370265299454, 0.04356522265879903, 0.018158641141781118, 0.1420504049747251, 0.029779362012050115, 0.08592034384491853, 0.0026529300203037565, 0.06336368547636084, 0.06421757832868025, 0.012926552899443777, 0.06955163116799667, 0.06094043972552754, 0.047354086927953176, 0.012844353550462984, 0.036466179371927865, 0.024369793791265693, 0.08265571043011732, 0.033206629668711685, 0.010297987355443183, 0.04833901708479971, 0.046080286920187064, 0.038392316055251285, 0.06130408095486928, 0.06473253975855187, 0.09993452622438781, 3.4527571639046073, 45.721316412091255, 103.63181635737419, 105.58017700910568, 98.57436373829842, 104.81723874807358, 94.68752190470695, 78.74632850289345, 51.99163354933262, 15.857033617794514, 30.344533324241638, 60.02716116607189, 60.48474781215191, 67.84719854593277, 14.37705958262086, 8.756150398403406, 17.30944488197565, 11.634988021105528, 0.21551564801484346, 0.3965117217740044, 0.23289591539651155, 0.3617302584461868, 0.09834498690906912, 0.06832786675659008, 0.028560163664224092, 0.09450407582335174, 0.1794786934624426, 0.18544579826993868, 0.21227525314316154, 0.07921088355942629, 0.03505047701764852, 0.15910022368188947, 0.29056479746941477, 0.31543657067231834, 0.6011810002382845, 0.7899983308743685, 0.6956827011890709, 1.0833739978261292, 0.3577215626137331, 0.46253493055701256, 0.9080430341418833, 0.5640884593594819, 0.8394276222679764, 0.6297194876242429, 1.624651865568012, 2.083526523783803, 5.887102000415325, 3.9776968583464622, 2.8945735283195972, 10.283564887940884, 6.1409046314656734, 9.396654479205608, 11.11410342156887, 4.14088100194931, 2.00149058829993, 1.716353294905275, 3.2881093863397837, 7.253914782777429, 3.122131205163896, 8.000244610011578, 4.8433502577245235, 3.0967808654531837, 3.246127814054489, 0.21755364490672946, 0.6809483387041837, 0.39889903273433447, 0.13250077521661296, 0.02317633498023497, 0.13797366904327646, 0.05769402974692639, 0.06880985456518829, 0.10065814989502542, 0.19819829991320148, 0.38459829229395837, 0.1190836877503898, 0.09297810887801461, 0.11003860709024593, 0.08649750467156991, 0.19809851073659956, 0.04339262508437969, 0.11292997733107768, 0.28627705411054194, 0.3036932711256668, 0.08233584478148259, 0.4084452782990411, 0.20275605143979192, 3.0858652386814356, 11.7586181871593, 32.852284759283066, 30.86586344987154, 42.785711735486984, 66.02553829550743, 53.49640600383282, 24.304846711456776, 27.738213278353214, 55.79339414834976, 74.7869485616684, 79.6746414899826, 83.25450539588928, 81.59938260912895, 62.99447514116764, 22.226544432342052, 0.28531205432955176, 0.1375933035160415, 0.029343652677198406, 0.08111635514069349, 0.042888183597824536, 0.02760265957476804, 0.018926626689790282, 0.04717293610156048, 0.060122581853647716, 0.09290574947954156, 0.024710600991966203, 0.017851282536867075, 0.05594354086497333, 0.0556030249572359, 0.02207264449680224, 0.044231303909327835, 0.04300711276300717, 0.09508522940450348, 0.09724791452754289, 0.03650478960480541, 0.017252681063837372, 0.02107728345436044, 0.022279698132479098, 0.019018962848349474, 0.019169902698195074, 0.05501947052835021, 0.055350331094814464, 0.05905369995161891, 0.04701391611888539, 0.02495553755579749, 0.03961217305914033, 0.08042546760407276, 0.04829933444852941, 0.016918347246246412, 0.04900418920442462, 0.027939778301515616, 0.03490413662802894, 0.033928546399693005, 0.12721675797365606, 0.1939967495854944, 0.10094301585922949, 0.17535679042339325, 0.1525468222098425, 0.22081413713749498, 0.24381835508393124, 0.15456743800314143, 0.15140597795834765, 0.3700195433339104, 0.13214938313467428, 0.1406869461061433, 0.2038176788482815, 0.12647570867557079, 0.24382684525335208, 0.17653444519964978, 0.18980351131176576, 0.0778545493085403, 0.18992362049175426, 0.21000358363380656, 0.1221478522347752, 0.18618908885400742, 0.12368355615762994, 0.09301808837335557, 0.0973431246529799, 0.14657621446531266, 0.11477945387014188, 0.12977393169421703, 0.1395713645615615, 0.20645620679715648, 0.19320793566294014, 0.14653820166131482, 0.17809933779062703, 0.1232001582684461, 0.2296208919142373, 0.20118605287279934, 2.1316219680011272, 44.975686222314835, 118.77183794975281, 114.57544952630997, 96.49424135684967, 94.53103110194206, 83.81483852863312, 59.99978743493557, 55.56747727096081, 33.34290683269501, 70.82677066326141, 118.3563606441021, 84.68964278697968, 68.61998587846756, 20.38767110556364, 29.422974474728107, 65.14170572161674, 48.08945953845978, 4.589681094512343, 0.9503153502009809, 0.4502465086989105, 0.7711733097676188, 0.4837360413512215, 0.2088320441544056, 0.1718182154581882, 0.35343975643627346, 0.759862088598311, 0.33210544497705996, 0.3305095306131989, 0.2181444241432473, 0.17196922766743228, 0.1602259578066878, 0.16871768573764712, 0.2276719972724095, 0.2745136572048068, 0.26635424816049635, 0.3763060981873423, 0.282404349418357, 0.1660269551211968, 0.17824279493652284, 0.5619041109457612, 0.29778642870951444, 0.3030619112541899, 0.41693197446875274, 1.4839203609153628, 1.2707964470610023, 5.458651715889573, 2.8751283092424273, 1.619603717699647, 10.492058750241995, 4.071559896692634, 8.658703677356243, 8.521820772439241, 1.6801584558561444, 0.8204629586543888, 1.3751609344035387, 2.377503211610019, 7.093893019482493, 6.977921342477202, 7.7712351735681295, 4.221639968454838, 4.906413573771715, 6.011314960196614, 0.40748084255028516, 1.9581438205204904, 1.624617192428559, 0.44955812219996005, 0.1544520488823764, 0.29986815294250846, 0.27896523708477616, 0.30293470714241266, 0.297741157701239, 0.4000348155386746, 0.5387232766952366, 0.2875403081998229, 0.27412509836722165, 0.28626574377994984, 0.3482283657649532, 0.37421698216348886, 0.14481965481536463, 0.39404235896654427, 0.81064487923868, 1.0025392728857696, 0.24654610402649269, 0.7997642224654555, 1.068830278236419, 9.783510770648718, 23.93688965588808, 46.726267486810684, 43.62513229250908, 60.111904218792915, 92.8432148694992, 77.14368090033531, 43.491664454340935, 39.28008824586868, 50.96725411713123, 63.61044108867645, 72.37562075257301, 77.16015681624413, 93.4663662314415, 66.14836290478706, 18.801172636449337, 0.39764373446814716, 0.24583809514297172, 0.24025475489906967, 0.17576417012605816, 0.14075814775424078, 0.1894697971874848, 0.08035035483771935, 0.14469481073319912, 0.14518369309371337, 0.20336747722467408, 0.13834655372193083, 0.1452258025528863, 0.08442453035968356, 0.1721514546079561, 0.15931614412693307, 0.2162352344021201, 0.09466381568927318, 0.23384077328955755, 0.14515399234369397, 0.13741601927904412, 0.10778087511425838, 0.09312282767496072, 0.13040800782619044, 0.13442270021187142, 0.08712661583558656, 0.11422190800658427, 0.11177614549524151, 0.19109612476313487, 0.17035300814313814, 0.07799923099810258, 0.14284623961430043, 0.1191074142116122, 0.08456282957922667, 0.12667078961385414, 0.15895716729573905, 0.17075611307518557, 0.13867412286344916, 0.12140222388552502], [0.008677290825289674, 0.01635838569200132, 0.062061706121312454, 0.01217224977153819, 0.014980606156314025, 0.0046535405272152275, 0.037657534194295295, 0.08724826126126572, 0.057659493904793635, 0.07196102844318375, 0.05685749572876375, 0.01239632456417894, 0.02042973919742508, 0.06448123371228576, 0.02580126492830459, 0.039547591368318535, 0.032356885421904735, 0.05167328621610068, 0.04198137190542184, 0.040919507009675726, 0.020099361026950646, 0.049184456875082105, 0.013482402955560246, 0.019736367321456783, 0.017557319697516505, 0.01994253780139843, 0.037724835856352, 0.0823417522769887, 0.04316004713473376, 0.0940033265214879, 0.02600607356725959, 0.06375896817189641, 0.0638350828376133, 0.0542228343692841, 0.030857815763738472, 7.667951015755534, 46.52167126536369, 83.37824195623398, 69.90139111876488, 64.26863417029381, 47.852207869291306, 39.54223617911339, 36.35684430599213, 24.95134972035885, 31.66504606604576, 64.81789469718933, 70.22199511528015, 40.57621769607067, 19.862617179751396, 9.522266238927841, 40.94244584441185, 36.194403022527695, 6.297374535351992, 1.046303662005812, 0.007275602538356907, 0.2115542269893922, 0.112070436734939, 0.11208928728592582, 0.05051330568676349, 0.12928878975799307, 0.14025819255039096, 0.14689015777548775, 0.05866997620614711, 0.06666302913799882, 0.03337795817060396, 0.050549693187349476, 0.0799569275113754, 0.019224287279939745, 0.08164052662323229, 0.06956717916182242, 0.11620960955042392, 0.1097854902036488, 0.19749282917473465, 0.2972104924265295, 0.0794833927648142, 0.7448296202346683, 1.3282265653833747, 2.4979083007201552, 1.4167272602207959, 1.7142970114946365, 4.7524249367415905, 7.796059241518378, 3.5860734852030873, 2.145639890804887, 7.724737543612719, 5.7362595945596695, 5.123327309265733, 9.62490538135171, 24.113000705838203, 18.23094293475151, 6.044301940128207, 1.7450336809270084, 2.2828336665406823, 11.105262245982885, 5.866511380299926, 9.489689636975527, 5.740819349884987, 2.5044325506314635, 2.655383488163352, 0.5638921167701483, 0.08829814789351076, 0.11441523005487397, 0.13548970076953992, 0.01587189490237506, 0.1761259968043305, 0.08521269861375913, 0.14945294213248417, 0.07243362808367237, 0.08534852648153901, 0.19104475330095738, 0.28056165610905737, 0.19917622790671885, 0.05849481822224334, 0.03391009660845157, 0.07076745459926315, 0.054869760788278654, 0.084113080665702, 0.08762518322328106, 0.16395134618505836, 0.18531868321588263, 0.515883652260527, 0.06976188902626745, 0.31170760514214635, 0.34715931687969714, 5.511608524248004, 22.855433486402035, 31.176510080695152, 32.73280777037144, 37.99221195280552, 63.88045459985733, 44.82948146760464, 22.75774832814932, 26.971722207963467, 42.734965458512306, 37.50462591648102, 55.32445751130581, 64.82857212424278, 73.5198001563549, 22.22507581114769, 0.5892632366158068, 0.025834286789176986, 0.08783597542787902, 0.18023522396106273, 0.04266688629286364, 0.04572673518850934, 0.0693273838260211, 0.05003041245799977, 0.029617002364830114, 0.037653585968655534, 0.034109474581782706, 0.05431321311334614, 0.03320249219541438, 0.07077466827468015, 0.03338420334330294, 0.06970995353185572, 0.08364653695025481, 0.017457999929320067, 0.04376949509605765, 0.014175272026477614, 0.11401912357541732, 0.03404132316063624, 0.0378569863823941, 0.0478603058581939, 0.02302552315086359, 0.06237967929337174, 0.03322077129269019, 0.06058283215679694, 0.05473360637552105, 0.05280259378196206, 0.05551404887228273, 0.009834936372499214, 0.04696185817010701, 0.0462140887248097, 0.011427923891460523, 0.0343496075947769, 0.01109631097278907, 0.04476264082768466, 0.029539013776229694, 0.0844106447766535, 0.044249345519347116, 0.02018503084400436, 0.020357633984531276, 0.09079621697310358, 0.026337804301874712, 0.04566248375340365, 0.05036110604123678, 0.04057672013004776, 0.018725009285844862, 0.01991746434214292, 0.04994667964638211, 0.05638964954414405, 0.0255740118882386, 0.05334971618140116, 0.005510830096682184, 0.04859877248236444, 0.025676164805190638, 0.01817279204260558, 0.03998499094450381, 0.01597525566467084, 0.08447866261121817, 0.03883877354383003, 0.08237806556280702, 0.08240975526859984, 0.004078432202732074, 0.09565016705892049, 0.10438008728669956, 0.027367213224351872, 0.08119149759295397, 0.034543946385383606, 0.03973858678364195, 0.2426532277604565, 15.426442623138428, 69.0924297273159, 102.42106452584267, 90.3557163476944, 93.71899947524071, 73.25829818844795, 63.50249648094177, 50.689359828829765, 29.398463889956474, 27.676987163722515, 49.799838960170746, 76.78969949483871, 43.29608894884586, 21.531905606389046, 4.971375362947583, 14.082603882998228, 17.692620120942593, 2.4890136905014515, 0.7148102216888219, 0.10721564802224748, 0.3154976642690599, 0.07516417492297478, 0.1561551887425594, 0.07084790340741165, 0.11378625247743912, 0.20627271820558235, 0.19881169981090352, 0.141603275842499, 0.08229849248891696, 0.23700166930211708, 0.7582581590395421, 0.6395348953083158, 0.3872812748886645, 0.958831999450922, 1.189222780521959, 1.8486193288117647, 0.6061674014199525, 0.8975601091515273, 2.203520997427404, 1.758818628732115, 5.127700874581933, 7.671490525826812, 6.759034087881446, 6.050736419856548, 7.871537916362286, 10.863934345543385, 20.07026843726635, 14.179229848086834, 7.668893840163946, 14.662932492792606, 11.117557436227798, 12.334400340914726, 15.55557394400239, 29.333513975143433, 26.660311818122864, 12.218589205294847, 8.726722877472639, 4.960688911378384, 8.046815861016512, 7.205004282295704, 8.41817943379283, 5.893213022500277, 0.68794762250036, 0.6259926001075655, 0.3693145327270031, 0.4542138520628214, 0.17110575368860736, 0.42708393128123134, 0.1827547262655571, 0.043385003227740526, 0.060272291593719274, 0.02257579835713841, 0.07246430846862495, 0.28179991466458887, 0.09180116656352766, 0.13809340714942664, 0.2525224559940398, 0.08007994591025636, 0.07155896251788363, 0.16076472733402625, 0.033995347112067975, 0.13495980732841417, 0.0367283467494417, 0.11237228303798474, 0.017388289998052642, 0.4522813588846475, 0.037951554550090805, 0.1797577558318153, 0.2096576982876286, 3.30374744720757, 19.18378170579672, 30.031021647155285, 34.46115642786026, 41.02553978562355, 60.365498811006546, 27.76323303580284, 10.278067532926798, 32.00795866549015, 55.361114144325256, 61.55986972153187, 80.54514437913895, 76.61984860897064, 87.1577775478363, 39.61098209023476, 1.4835123578086495, 0.21427814644994214, 0.09218459716066718, 0.06404327010386623, 0.05696403102774639, 0.046639892243547365, 0.05228073408943601, 0.03820569188974332, 0.030624410319433082, 0.033573669934412464, 0.04846669988182839, 0.07209949835669249, 0.02757022957666777, 0.03372122002474498, 0.040246304852189496, 0.06851841317256913, 0.03223041603632737, 0.022843897349957842, 0.09796063604881056, 0.10282441216986626, 0.03474896839179564, 0.03175859194016084, 0.021326120004232507, 0.019873423443641514, 0.005766579752162215, 0.031494391078012995, 0.06009747499774676, 0.04418179523781873, 0.04488526959903538, 0.048042428898043, 0.06192913257109467, 0.0021799880641992786, 0.021292352284945082, 0.05602926263236441, 0.025286149502790067, 0.02165942409192212, 0.07112165942089632, 0.14592402993002906, 0.0934010514174588, 0.12972189229913056, 0.11291665578028187, 0.08700132646481507, 0.12078203333658166, 0.19253225473221391, 0.11074666792410426, 0.1480941439513117, 0.11973924905760214, 0.16943274502409622, 0.14269436651375145, 0.1397807541070506, 0.19298250088468194, 0.1206654122506734, 0.09536260709865019, 0.14484260202152655, 0.11881675949553028, 0.13415626919595525, 0.11286189270322211, 0.08557370150811039, 0.10262811410939321, 0.07133929422707297, 0.12071088363882154, 0.13026873639319092, 0.1921613293234259, 0.10473980626557022, 0.1622652163496241, 0.16225307481363416, 0.17155579203972593, 0.16637333028484136, 0.24436460545985028, 0.11978440874372609, 0.11953478737268597, 0.2831364929443225, 13.26641907915473, 75.72170600295067, 117.4271585047245, 87.53407895565033, 86.63123220205307, 68.65324929356575, 52.06484042108059, 45.848203003406525, 35.2561991661787, 47.27448306977749, 95.40069043636322, 101.05440706014633, 61.77562594413757, 31.47915244102478, 15.485169421881437, 57.882818430662155, 57.02531464397907, 12.365181539207697, 1.2344926013611257, 0.2759957854868844, 0.825358402216807, 0.18671902682399377, 0.2907701942604035, 0.2221412307699211, 0.5410387774463743, 0.3622619330417365, 0.32480244466569275, 0.28068535728380084, 0.24447113333735615, 0.3183440677821636, 0.3665522887604311, 0.37234329676721245, 0.3492604853818193, 0.34744361881166697, 0.5438849434722215, 0.45526906731538475, 0.16744758904678747, 0.24341196985915303, 0.6779006647411734, 0.445580359082669, 1.5516905556432903, 7.944714864715934, 6.09867749735713, 5.360834989696741, 8.573734536767006, 14.2187325283885, 18.852063305675983, 11.160895060747862, 6.739300796762109, 16.370935142040253, 11.809437610208988, 12.66961645334959, 18.37533138692379, 38.914984837174416, 34.61944453418255, 14.05127551406622, 9.273441340774298, 8.80243856459856, 22.415696382522583, 16.592560149729252, 19.086778610944748, 12.880110908299685, 6.735874805599451, 5.271471384912729, 1.1877000122331083, 0.49724309938028455, 0.7409969321452081, 0.4732151183998212, 0.3058093716390431, 0.4597408336121589, 0.4523269267519936, 0.40176574140787125, 0.3744017769349739, 0.6060580385383219, 0.484759759856388, 0.4503885854501277, 0.8087697392329574, 0.23385111882817, 0.1509402654482983, 0.2928200952010229, 0.3433274006238207, 0.28865807165857404, 0.20129427284700796, 0.37455644051078707, 0.7557648397050798, 0.9046477975789458, 0.16668572992784902, 0.5999723088461906, 1.313601031433791, 8.758296333253384, 34.431996792554855, 47.8516910970211, 47.4571468681097, 56.66907615959644, 91.60440534353256, 59.89155024290085, 33.47780339419842, 37.99987234175205, 52.3544342815876, 53.112193420529366, 73.22664588689804, 83.18490073084831, 100.59512570500374, 41.089273765683174, 0.9654019656591117, 0.23021452099783346, 0.10096791491378099, 0.21162450837437063, 0.19028997427085415, 0.19082031300058588, 0.13416618428891525, 0.09425083277164958, 0.16425065434304997, 0.12668592942645773, 0.15883972984738648, 0.12668417795794085, 0.13683537777978927, 0.15279472921974957, 0.15210707002552226, 0.1930723007535562, 0.1704459250322543, 0.1326429410255514, 0.20657498011132702, 0.15565845445962623, 0.27107784000691026, 0.11686298894346692, 0.12611760757863522, 0.11912673973711208, 0.1088524324586615, 0.17776989843696356, 0.14845556986983865, 0.15298667829483747, 0.06827941935625859, 0.15985120291588828, 0.21013354853494093, 0.0724216498201713, 0.11435328298830427, 0.10907595249591395, 0.11897131917066872, 0.14892931241774932, 0.1471015956485644], [0.031236958602676168, 0.05042901626438834, 0.04439566735527478, 0.048209133819909766, 0.04437767398485448, 0.044406573215383105, 0.05814475087390747, 0.03213230782421306, 0.02730555374000687, 0.03432070094277151, 0.10166988271521404, 0.013769948072877014, 0.02709390621021157, 0.007945950674184132, 0.06492782107670791, 0.035329747188370675, 0.04909943643724546, 0.08726872227271087, 0.02451565735100303, 0.030196400766726583, 0.0370872604980832, 0.022986460207903292, 0.05205901376029942, 0.04189428087556735, 0.0041281324411102105, 0.03364617034094408, 0.02463472195813665, 0.0593179787392728, 0.018781878206937108, 0.01937213608471211, 0.03631674051575828, 0.03329168350319378, 0.08890736207831651, 0.16020427225157619, 17.143946662545204, 69.59655627608299, 87.16905534267426, 77.00943410396576, 67.6634632050991, 58.52450519800186, 51.67077876627445, 38.15250635147095, 40.39372868835926, 58.10503430664539, 53.16661410033703, 53.70371527969837, 26.86544571071863, 30.651762038469315, 33.577308654785156, 63.97202968597412, 14.392153322696686, 0.3543411986902356, 0.2170707590994425, 0.5903084180317819, 0.11401584328268655, 0.05508720634679776, 0.13410422980086878, 0.1830248680198565, 0.06639316197833978, 0.0685501102998387, 0.04055345380038489, 0.11673204440739937, 0.07364873905316927, 0.025130569374596234, 0.14810159511398524, 0.052991926786489785, 0.3104254708159715, 0.3270078403875232, 0.7124891399871558, 0.6599501904565841, 2.0154695631936193, 3.468313291668892, 2.711374908685684, 8.564273044466972, 5.522185256704688, 6.476356806233525, 3.261941378004849, 8.644667230546474, 9.120967872440815, 10.1219149120152, 10.038985311985016, 7.307070130482316, 9.330446831882, 8.469298090785742, 7.156219650059938, 6.834583058953285, 10.13003222644329, 11.363000515848398, 13.104361575096846, 14.51790852472186, 10.983285941183567, 4.791987938806415, 13.826119545847178, 7.3001739755272865, 2.7941109566017985, 3.236610274761915, 2.0631368178874254, 0.9029308240860701, 0.15410490188514814, 0.5398111464455724, 0.6463593291118741, 0.7554017216898501, 0.6081977393478155, 0.49139482725877315, 0.38999186537694186, 0.1823952596168965, 0.121559277176857, 0.03896496091329027, 0.05226319713983685, 0.02723192341363756, 0.0933950548642315, 0.06716075047734194, 0.09909961750963703, 0.10023173410445452, 0.11013896772055887, 0.020246488093107473, 0.12797637580661103, 0.12746349239023402, 0.12129535462008789, 0.05492178905114997, 0.11545099361683242, 0.02606054720672546, 0.3255327179795131, 0.1137052767444402, 0.2142553625162691, 0.33956067461986095, 5.681431386619806, 18.707454465329647, 33.27902466058731, 22.588934786617756, 45.15743046998978, 75.92125609517097, 38.89997184276581, 19.901855774223804, 35.7189117372036, 36.04272276163101, 50.69301523268223, 54.7113262116909, 73.04973497986794, 29.817001931369305, 0.6735420611221343, 0.10058811341878027, 0.10107627589604817, 0.043561786515056156, 0.025195490597980097, 0.03934607972041704, 0.023471574313589372, 0.033430750845582224, 0.018674079401534982, 0.028018271550536156, 0.06126219413999934, 0.04394152121676598, 0.10505305937840603, 0.019170021441823337, 0.06136656978924293, 0.02229842808446847, 0.04227767436532304, 0.03685573268739972, 0.008513227021467173, 0.02631163617479615, 0.04071665578521788, 0.028055236070940737, 0.05366774872527458, 0.019089346278633457, 0.03922689451428596, 0.07447074181982316, 0.0740080646937713, 0.03069761205551913, 0.008374579920200631, 0.019159022813255433, 0.038380953774321824, 0.02573515255789971, 0.01824950784794055, 0.0321275395253906, 0.024488476192345843, 0.08056971884798259, 0.051509304976207204, 0.105001101619564, 0.06991001428104937, 0.010872206494241254, 0.06819634334533475, 0.04979399760486558, 0.0008440751082616771, 0.010164380364585668, 0.07102101677446626, 0.01229640551173361, 0.028490913864516187, 0.013318056207936024, 0.05130937039211858, 0.012946677161380649, 0.04145304439589381, 0.017190290564030875, 0.0823813903843984, 0.08016309613594785, 0.0021725190435972763, 0.02149497900973074, 0.10576540982583538, 0.06907529110321775, 0.08247823323472403, 0.04419768833031412, 0.03392295431694947, 0.01005506572255399, 0.0282952206543996, 0.04001646171673201, 0.012184434908704134, 0.05062361480668187, 0.043743033820646815, 0.046178855263860896, 0.07764186462736689, 0.6398958165664226, 31.690953075885773, 91.7438730597496, 101.74789264798164, 101.9647242128849, 108.6171792447567, 88.34725052118301, 71.45483136177063, 31.289071440696716, 22.682215981185436, 25.00924911350012, 47.88256824016571, 70.28003320097923, 26.9287047162652, 27.649212554097176, 21.27254292368889, 36.19371525943279, 7.059888644143939, 0.19107605708995834, 0.08861238806275651, 0.527249020524323, 0.09645373487728648, 0.08936501486459747, 0.054874788838787936, 0.14091022865613922, 0.1948366974829696, 0.08116550015984103, 0.16519310767762363, 0.04894190074992366, 0.6105999229475856, 0.3837127913720906, 1.4725451963022351, 0.21046801964985207, 1.0193863813765347, 0.7701073482166976, 1.0424742987379432, 1.8951223022304475, 1.8853330775164068, 2.8519730642437935, 3.1094094878062606, 6.017176620662212, 6.830786587670445, 10.131356455385685, 11.097165830433369, 16.051315292716026, 14.156400673091412, 21.886360086500645, 19.74508188664913, 15.374299921095371, 13.625113181769848, 12.959326207637787, 9.351007528603077, 9.674249533563852, 13.813175540417433, 11.854730229824781, 17.71319791674614, 17.27852214127779, 9.916325993835926, 8.090741503983736, 11.02382406592369, 6.491801552474499, 4.153518648818135, 1.714786235243082, 3.1048319209367037, 2.4705319572240114, 0.7705646893009543, 1.2236662697978318, 1.5238064643926919, 1.4967612968757749, 1.5905063040554523, 1.021640372928232, 0.5283458554185927, 0.3022259857971221, 0.17723837227094918, 0.07023202473646961, 0.05848680673807394, 0.09569258822011761, 0.10834332657395862, 0.15401403332361951, 0.09029584616655484, 0.0548762137623271, 0.08258165893494152, 0.08279429908725433, 0.1283381282701157, 0.04747988095914479, 0.08785228041233495, 0.04063512715219986, 0.08395000855671242, 0.05431958445115015, 0.13995029032230377, 0.061596353552886285, 0.20325415127445012, 0.23388184374198318, 3.6003471817821264, 11.224642340093851, 17.57693912833929, 28.474746756255627, 63.30422692000866, 58.73043894767761, 15.812440160661936, 16.290499158203602, 41.665896624326706, 62.059098333120346, 77.69904389977455, 68.66939082741737, 86.15466937422752, 46.669517531991005, 1.5957684279419482, 0.2881620795233175, 0.06578489774256013, 0.04754511945066042, 0.02150599248125218, 0.036611128234653734, 0.015507181269640569, 0.03717057028552517, 0.025661115905677434, 0.044901997607667, 0.0251795770964236, 0.03973401144321542, 0.09489824529737234, 0.051549688942031935, 0.02884145433199592, 0.046565221055061556, 0.019929448171751574, 0.021314650111889932, 0.04437061244971119, 0.013235074820840964, 0.06263377581490204, 0.028955210727872327, 0.0068057896623940906, 0.01864746413048124, 0.059390059832367115, 0.008489138763252413, 0.07878662741859443, 0.02540275760111399, 0.01921320701512741, 0.008796722795523237, 0.03408667580515612, 0.05445573515316937, 0.03322719087009318, 0.04540062065643724, 0.016970529504760634, 0.0567119011975592, 0.15458545734873042, 0.16782467428129166, 0.11686856247251853, 0.13585434760898352, 0.1861988555174321, 0.1872226779232733, 0.08712792201549746, 0.09930360422004014, 0.12422863394021988, 0.1315921192872338, 0.16761087637860328, 0.1361755936522968, 0.1220774075773079, 0.074068995018024, 0.17224926967173815, 0.19014596793567762, 0.26797215978149325, 0.15668079257011414, 0.0650214652705472, 0.10876170490519144, 0.1889415513142012, 0.12214347356348298, 0.20949127909261733, 0.1356735307490453, 0.11380871728761122, 0.09027659485582262, 0.12071788951288909, 0.19381430000066757, 0.06813461150159128, 0.17049701447831467, 0.07327008788706735, 0.09846736706094816, 0.24270169000374153, 0.6475858320482075, 32.74953827261925, 100.07010027766228, 112.6736743748188, 100.65679639577866, 92.52259567379951, 77.46037110686302, 64.34679597616196, 54.434298276901245, 55.841142386198044, 80.91927990317345, 78.23327243328094, 75.60246840119362, 42.50187076628208, 42.01100550591946, 46.86565920710564, 87.29945674538612, 24.71299421042204, 0.47881150559987873, 0.40175380767323077, 1.0447634384036064, 0.37388467811979353, 0.1640108070569113, 0.3813287161756307, 0.45730706420727074, 0.28570580820087343, 0.3483484749449417, 0.22634534892858937, 0.3136576130054891, 0.5612745916005224, 0.23686852800892666, 0.4683933552587405, 0.1316632764064707, 1.1099741142243147, 0.7540372386574745, 1.1814969638362527, 2.100040912628174, 2.7175842504948378, 6.571572571992874, 5.1495877001434565, 14.847236853092909, 13.597319573163986, 14.538532868027687, 11.337837316095829, 19.07733991742134, 19.954011775553226, 19.22712218016386, 23.1095714494586, 17.69641801714897, 19.52102690935135, 16.51681311428547, 15.24281557649374, 14.179573729634285, 18.27916994690895, 19.427563324570656, 25.52460975944996, 29.24427956342697, 24.237831607460976, 16.665316745638847, 31.097806803882122, 13.488140981644392, 6.603238172829151, 5.744538875296712, 3.060849756002426, 3.0705577600747347, 0.43094526627101004, 1.2674175971187651, 2.232252205722034, 1.5406326740048826, 1.5610946947708726, 1.1025765049271286, 0.730462116189301, 0.6359623151365668, 0.3186321695102379, 0.1881834474625066, 0.2191553480224684, 0.18964662129292265, 0.33933488361071795, 0.37137366598472, 0.18329299113247544, 0.2871472667902708, 0.27941889711655676, 0.11919374082935974, 0.21462418022565544, 0.4100260528502986, 0.38603764318395406, 0.16268690465949476, 0.2758187090512365, 0.2828431368106976, 0.7979199558030814, 0.2026861411286518, 0.43577697419095784, 1.1261688452214003, 11.184687484055758, 28.70524238795042, 46.42973139882088, 38.16055051982403, 71.24056085944176, 103.08760955929756, 52.28601895272732, 30.385768711566925, 46.41754925251007, 50.40523387491703, 68.53406488895416, 71.6225315630436, 97.99974337220192, 48.46002705395222, 0.9059867507312447, 0.423512538545765, 0.21235914551652968, 0.18473725504009053, 0.09077323265955783, 0.08589792356360704, 0.07218949860543944, 0.1736666975193657, 0.1509167393669486, 0.16130797943333164, 0.11157960252603516, 0.17693149420665577, 0.18511833302909508, 0.15763454139232635, 0.14282407908467576, 0.14321829308755696, 0.16017409652704373, 0.10125680331839249, 0.06489333347417414, 0.16733363969251513, 0.22080438531702384, 0.08300417845021002, 0.1209319026384037, 0.10306604803190567, 0.1938891233294271, 0.2312384027754888, 0.22768994240323082, 0.06927012713276781, 0.09552720803185366, 0.07681053306441754, 0.12303705647354946, 0.12622413545614108, 0.16420286003267393, 0.150723573169671, 0.19578541454393417, 0.20003049925435334], [0.028585376276168972, 0.06846043659606948, 0.009438790930289542, 0.03688929260533769, 0.034188093995908275, 0.033021434137481265, 0.06858174805529416, 0.01506334727309877, 0.029624611233884934, 0.03855151044263039, 0.0217090700607514, 0.03375381886144169, 0.03343511838465929, 0.032717866051825695, 0.033818701122072525, 0.057673093760968186, 0.02729176834691316, 0.00432207232734072, 0.07820510276360437, 0.04647868292522617, 0.08048929972574115, 0.026596990101097617, 0.029953642406326253, 0.022749440504412632, 0.053688447223976254, 0.016614999949524645, 0.034346653847023845, 0.04529168079898227, 0.07377126021310687, 0.05143439630046487, 0.05433512131276075, 0.03140808672469575, 1.299608638510108, 29.550064355134964, 84.74407106637955, 80.49431830644608, 66.20767012238503, 55.68104937672615, 48.455436900258064, 46.78791917860508, 34.11627173423767, 56.371046751737595, 64.04499337077141, 83.88756662607193, 59.58467110991478, 14.101816602051258, 39.19497661292553, 40.1548583060503, 23.74118495732546, 1.105268660467118, 0.5548227753024548, 0.26971000246703625, 0.12575454893521965, 0.07180462824180722, 0.07982737079146318, 0.04905905618215911, 0.029724396699748468, 0.22997439169557765, 0.06438900702050887, 0.05190649499127176, 0.17599151964532211, 0.0717323950084392, 0.040436320632579736, 0.15034294046927243, 0.3273870481643826, 3.4565362986177206, 1.648780214600265, 0.35798339231405407, 4.466661270707846, 4.553104257211089, 11.380984000861645, 15.014718566089869, 7.27717000991106, 11.193227525800467, 9.658076651394367, 18.160490915179253, 9.767944905906916, 8.73629741370678, 10.773322507739067, 17.517677508294582, 18.54472439736128, 19.279063493013382, 20.43129276484251, 15.160184260457754, 23.45923438668251, 14.249883256852627, 11.463811006397009, 14.222643468528986, 10.59479858726263, 11.126980930566788, 7.371766408905387, 9.045384228229523, 3.2985094282776117, 1.695293162483722, 2.751976205036044, 2.6296821422874928, 1.8745247949846089, 1.4313049404881895, 2.1003396715968847, 0.828156714560464, 2.318077487871051, 2.5912880524992943, 2.7914743730798364, 2.2342687100172043, 1.7996783112175763, 0.936588408658281, 1.1212222231552005, 0.5438848841004074, 0.4554434126475826, 0.21179260482313111, 0.22272001689998433, 0.06108907706220634, 0.07285150917596184, 0.02612464093544986, 0.17333507625153288, 0.10665894820704125, 0.06507917467388324, 0.06456085131503642, 0.1614806178258732, 0.18360706802923232, 0.4002285754540935, 0.027833857129735406, 0.10990149530698545, 0.04641285071556922, 0.10090487689012662, 0.10773106216220185, 0.14348246797453612, 1.4731042413040996, 26.746760979294777, 33.1379534304142, 7.942174701020122, 23.969083428382874, 64.85192567110062, 51.07400558888912, 36.82169996201992, 24.871793389320374, 35.91636814177036, 54.574202969670296, 54.67259109020233, 66.33262261748314, 37.744077667593956, 2.9234553035348654, 0.4001519561279565, 0.029901270900154486, 0.10301621281541884, 0.016418590566900093, 0.04814287487533875, 0.024596673902124166, 0.06713525770464912, 0.018816508672898635, 0.0632274494273588, 0.0388013544579735, 0.1031863946991507, 0.02365304797422141, 0.04385286054457538, 0.011230083091504639, 0.029440668076858856, 0.031347364201792516, 0.04106452266569249, 0.014233560305001447, 0.06480694748461246, 0.007658331805941998, 0.034263421985087916, 0.02173986918933224, 0.04894495097687468, 0.09032984395162202, 0.020788524925592355, 0.01872347860626178, 0.06660647006356157, 0.04226768134685699, 0.049791581914178096, 0.09405589284142479, 0.022355731161951553, 0.049089710591943, 0.013107623944961233, 0.005964335668977583, 0.02233663384686224, 0.011131800474686315, 0.04704492304881569, 0.018366776457696687, 0.028493023419287056, 0.029078895204293076, 0.0707247291575186, 0.007754438074698555, 0.028993685518798884, 0.06511525789392181, 0.037582621807814576, 0.008986973280116217, 0.04926943649479654, 0.017038877595041413, 0.038737459253752604, 0.029153015348128974, 0.0552528537082253, 0.05711592639272567, 0.0647993256279733, 0.10997634832165204, 0.0387444094667444, 0.029378850886132568, 0.06278213855694048, 0.026555802760412917, 0.05339471259503625, 0.010269122449244605, 0.019643443010863848, 0.06510121645987965, 0.02784471660561394, 0.055767637022654526, 0.010172890943067614, 0.1320172066334635, 2.725203554145992, 45.86173787713051, 101.84755370020866, 96.61598682403564, 88.38065832853317, 83.62045615911484, 58.206393867731094, 42.81475357711315, 17.817882299423218, 36.87876150012016, 63.3100064098835, 86.64818689227104, 68.32901269197464, 6.42850074917078, 21.58514454960823, 27.485152557492256, 12.331128716468811, 0.2959735400509089, 0.4998748144134879, 0.2878061158116907, 0.10613197882776149, 0.06622347733355127, 0.08384734726860188, 0.026343325880588964, 0.0439580265810946, 0.28673697786871344, 0.18055728636682034, 0.5937673605512828, 0.4241633723722771, 0.45930323365610093, 0.77280443161726, 0.22957176173804328, 1.1612339573912323, 0.48203426704276353, 1.4829860860481858, 0.6253740645479411, 1.9708789559081197, 0.7637721381615847, 0.9302146662957966, 1.612854686100036, 0.45093605294823647, 1.4935008343309164, 2.673987289890647, 2.226489814929664, 5.970805333927274, 4.980901451781392, 13.44184996560216, 23.117524422705173, 26.462348140776157, 24.54438205808401, 24.446687400341034, 20.956774167716503, 28.615027628839016, 18.408098928630352, 12.508096620440483, 17.64499917626381, 23.483307994902134, 19.707070626318455, 14.419430159032345, 7.479951353743672, 3.823520843870938, 4.4420618657022715, 4.697569655254483, 3.2715805107727647, 0.7729172974359244, 1.0139073128812015, 1.0207883873954415, 1.1778213735669851, 1.4192540058866143, 2.153612575493753, 2.525949371047318, 1.701204814016819, 2.380506000481546, 2.177501656115055, 1.5888729854486883, 0.8979833708144724, 0.8558393572457135, 0.6056321051437408, 0.37748246162664145, 0.10991624920279719, 0.03303059595054947, 0.02937881748948712, 0.26471303310245275, 0.212744394375477, 0.2760468452470377, 0.07201846325187944, 0.3257539967307821, 0.15444057527929544, 0.3417002863716334, 0.037781380087835714, 0.10083046174258925, 0.058927898498950526, 0.03785679342399817, 0.1148333634773735, 0.20553989190375432, 0.3069982031593099, 13.989635221660137, 14.319372978061438, 9.172031432390213, 34.25505928695202, 46.87374137341976, 31.885472238063812, 16.461818665266037, 18.890351951122284, 48.80754120647907, 81.15897864103317, 77.47165650129318, 82.8600637614727, 57.79866434633732, 7.831162232905626, 0.37934059160761535, 0.0908821057237219, 0.03802890489168931, 0.03932054984034039, 0.06785996491089463, 0.04423563805175945, 0.03681971997139044, 0.04273900449334178, 0.04693806120485533, 0.038894275057828054, 0.09023501232150011, 0.023091813636710867, 0.0588309443264734, 0.04425892293511424, 0.02394483075477183, 0.08080921732471325, 0.007688204177611624, 0.011567893870960688, 0.11104127086582594, 0.05786397414340172, 0.019633767260529567, 0.035241899167886004, 0.031168655041255988, 0.03038866154383868, 0.05297405587043613, 0.06592825840925798, 0.0367158860899508, 0.03730115116923116, 0.15018483332823962, 0.07000758443609811, 0.030333455033542123, 0.06241001086891629, 0.08470868386211805, 0.12284451368032023, 0.14206012710928917, 0.10407726134872064, 0.11846695560961962, 0.08140584468492307, 0.17097577394451946, 0.15404667297843844, 0.19951495894929394, 0.06347191287204623, 0.07836717297323048, 0.16578318929532543, 0.09983522686525248, 0.20532140362774953, 0.19447908620350063, 0.09210223361151293, 0.12806954502593726, 0.1932541120913811, 0.1661111888824962, 0.20429620082722977, 0.20234579220414162, 0.2278232914977707, 0.10796057875268161, 0.11051485067582689, 0.19806348136626184, 0.1132712910475675, 0.1581303108832799, 0.13457135239150375, 0.11380271331290714, 0.10625234775943682, 0.16099508997285739, 0.13714526896364987, 0.11420453432947397, 0.12224130347021855, 3.190508298575878, 50.4798998683691, 117.36731931567192, 103.99290338158607, 91.94669097661972, 78.95285502076149, 60.567340180277824, 61.81694492697716, 48.37295472621918, 78.73801454901695, 94.28837612271309, 121.18778631091118, 85.25357812643051, 22.52918679267168, 57.262155935168266, 60.479872673749924, 38.304122015833855, 1.7430424690246582, 0.8614921476691961, 0.544462037505582, 0.7728450419381261, 0.14639980596257374, 0.2796611934900284, 0.3643083607312292, 0.28100507450290024, 0.48405474924948066, 0.23219054855871946, 0.3591099724872038, 0.5661987711209804, 0.20362935145385563, 0.4073310474632308, 0.39421432942617685, 2.149087255820632, 10.152216386049986, 5.374158499762416, 2.9486852372065187, 11.472621783614159, 16.09005991369486, 31.130272261798382, 35.35665437579155, 20.01617643982172, 33.03613409399986, 23.47884703427553, 34.7439144551754, 18.120701350271702, 16.405342295765877, 22.024070397019386, 29.79999214410782, 32.46868394315243, 31.030474416911602, 36.08110450208187, 30.27470827102661, 38.03687855601311, 27.37239930778742, 20.34890368580818, 25.736849270761013, 21.689773835241795, 22.003234215080738, 18.607647120952606, 19.48847785592079, 9.104706645011902, 7.909134523943067, 6.650924663990736, 5.0915268156677485, 2.4261427391320467, 2.355648446828127, 4.24313304014504, 3.17817036062479, 3.2327872049063444, 3.7503524450585246, 5.143320886418223, 3.507713139988482, 2.958690575323999, 2.146497219800949, 1.6955023887567222, 0.9551067149732262, 1.0448724450543523, 0.6766793271526694, 0.5701237823814154, 0.1277522768941708, 0.20353998203063384, 0.17148206708952785, 0.29424009087961167, 0.49928804277442396, 0.3148168179905042, 0.3634731180500239, 0.38268791511654854, 0.5710241559427232, 0.789327488746494, 0.17431264801416546, 0.32179843867197633, 0.6317441852297634, 0.214002943248488, 0.22105920914327726, 0.3845073643606156, 4.2526591289788485, 43.74123126268387, 45.53487181663513, 14.690831545740366, 41.34607158601284, 95.48133730888367, 67.03491613268852, 51.55075080692768, 31.472654789686203, 46.56425178050995, 78.90369325876236, 72.41331472992897, 90.76040983200073, 62.28828303515911, 6.290303589776158, 0.7676777942106128, 0.24772006290731952, 0.19278149760793895, 0.10637295417836867, 0.14117569488007575, 0.18233052949653938, 0.12690676288912073, 0.1479015566292219, 0.2134754543658346, 0.1183026737999171, 0.16448319889605045, 0.13197935710195452, 0.17421925615053624, 0.1547265544650145, 0.11312560003716499, 0.1421472107176669, 0.0958693158463575, 0.12887240038253367, 0.18328421894693747, 0.11144011587020941, 0.14940348541131243, 0.10961539737763815, 0.15445936645846814, 0.14014945307280868, 0.09767105002538301, 0.1991540822200477, 0.14078302454436198, 0.20734069839818403, 0.2363051933934912, 0.20659720001276582, 0.06188353872857988, 0.15827700379304588, 0.23098001664038748, 0.17020071943989024], [0.06177759343700018, 0.03827146843832452, 0.0352197460597381, 0.015097236519068247, 0.08544007039745338, 0.03581645134545397, 0.036232543861842714, 0.030399446804949548, 0.03495999437291175, 0.04688480468757916, 0.09130535996519029, 0.06645042609306984, 0.08775033158599399, 0.06883752925205044, 0.006688908824799, 0.054758412661612965, 0.014217598563845968, 0.04622468288289383, 0.01127097171774949, 0.06216129862878006, 0.040537467939429916, 0.023930321767693385, 0.059371906900196336, 0.04751753753225785, 0.032791895282571204, 0.047666304744780064, 0.04834273895539809, 0.0478900066082133, 0.06498012764495797, 0.05358928887289949, 0.07265139647643082, 1.4537599543109536, 35.54334595799446, 78.34087505936623, 75.65206333994865, 75.13311758637428, 66.69433280825615, 51.587738022208214, 53.427458703517914, 53.83660934865475, 72.40069940686226, 52.08151392638683, 44.13444556295872, 36.680917516350746, 30.255184918642044, 53.423746302723885, 17.388942316174507, 1.9311189581640065, 0.6561303860507905, 0.07555886390036903, 0.5197134311310947, 0.019517203691066243, 0.05483768516569398, 0.41383846546523273, 0.03382501679880079, 0.0911623406864237, 0.1582931529264897, 0.13762163871433586, 0.12267718906514347, 0.03854233007587027, 0.20616014924598858, 0.17070083791622892, 0.7384612213354558, 1.1120883445255458, 6.909651355817914, 3.892419934272766, 2.291622357442975, 2.802265319041908, 2.0611777855083346, 5.5088018998503685, 1.880550084169954, 3.366473293863237, 2.0930497627705336, 5.472014173865318, 3.9752203412353992, 6.792063340544701, 13.510106652975082, 10.893605053424835, 13.315715733915567, 27.537673339247704, 10.995318945497274, 12.032302301377058, 13.018589727580547, 19.433996379375458, 22.349925711750984, 13.908445928245783, 18.627284467220306, 18.370026871562004, 18.464193418622017, 12.291975617408752, 13.884797897189856, 8.219897523522377, 3.300775531679392, 0.6880602508317679, 2.159763020463288, 1.4254137128591537, 2.691407217644155, 1.5387615119107068, 0.9941935550887138, 1.5978239988908172, 3.236763454042375, 3.897193190641701, 3.5115618584677577, 2.7505422569811344, 2.942462833598256, 2.4753372743725777, 2.0443568006157875, 2.05307234544307, 1.6552672977559268, 1.222413049545139, 0.4596255929209292, 0.32020923332311213, 0.12361214670818299, 0.09376251444336958, 0.06473250265116803, 0.05676504639268387, 0.11812131517217495, 0.06665539243840612, 0.09622300858609378, 0.06045190617442131, 0.043457184510771185, 0.030942793528083712, 0.16430244140792638, 0.02960207963042194, 0.02089309538860107, 0.02858147072402062, 0.08675871096784249, 0.35691223572939634, 0.4310292180161923, 28.329174667596817, 51.9171005487442, 26.187529787421227, 42.198141664266586, 76.79626554250717, 58.93498957157135, 57.76223190128803, 26.84251394122839, 28.298987187445164, 40.58645434677601, 49.065665155649185, 62.859513983130455, 47.10081338882446, 12.278729528188705, 0.16498508368385956, 0.03695952575071715, 0.1294898524065502, 0.04379085039545316, 0.01773976742697414, 0.0053346205822890624, 0.04939694859785959, 0.0522078774520196, 0.01231110560183879, 0.08543778458260931, 0.03208226851711515, 0.04017404564365279, 0.008895775390556082, 0.015860480671108235, 0.03372071165358648, 0.04032423777971417, 0.058073356267414056, 0.051856700592907146, 0.048375738551840186, 0.07519492210121825, 0.003146808426208736, 0.05792859665234573, 0.061001117719570175, 0.013296498673298629, 0.023088806083251256, 0.004519626936598797, 0.045951323918416165, 0.08810492974589579, 0.03398176209884696, 0.08484654521453194, 0.014528805204463424, 0.019047468740609474, 0.025819267575570848, 0.020386956239235587, 0.038835107334307395, 0.02873354791518068, 0.03441562905209139, 0.03499455990095157, 0.07549166242824867, 0.02157468938094098, 0.06979936006246135, 0.03972202575823758, 0.00727137461581151, 0.09741185494931415, 0.05861675308551639, 0.0631022268498782, 0.026926143727905583, 0.07097044683177955, 0.06261124421143904, 0.02507916637114249, 0.09863809071248397, 0.04124574399611447, 0.057650807066238485, 0.019097856857115403, 0.05260935708065517, 0.08598060623626225, 0.052044248732272536, 0.0450358068337664, 0.09374380490044132, 0.07279062338056974, 0.028506851485872176, 0.02976791623950703, 0.046895881241653115, 0.13986555190058425, 4.117026831954718, 56.27557687461376, 94.32793959975243, 95.59071063995361, 98.85557144880295, 98.16644042730331, 67.0588244497776, 33.339414820075035, 33.7428467720747, 62.87792019546032, 63.32967795431614, 43.32985393702984, 38.872932493686676, 22.26828519254923, 28.126480244100094, 10.769838094711304, 0.652096486883238, 0.4017850966192782, 0.23450598993804306, 0.5673238669987768, 0.07378874521236867, 0.0628744023561012, 0.19341358478413895, 0.08154004724929109, 0.19211886363336816, 0.18626964156283066, 0.34356334421318024, 0.6252680858597159, 0.27893507620319724, 0.20259363984223455, 0.2850224089343101, 0.9299153729807585, 0.43307742686010897, 2.2769807931035757, 0.9893917408771813, 2.0743421791121364, 1.8619703873991966, 2.198387235403061, 1.8316001608036458, 1.5099837561137974, 1.351064764894545, 2.449473012238741, 2.6167086884379387, 2.474318454042077, 3.291661483235657, 4.298293255269527, 0.8059148455504328, 3.455814574845135, 17.576515451073647, 12.708485517650843, 19.154162295162678, 15.806271191686392, 28.31364680081606, 27.570902556180954, 18.211402483284473, 24.584707394242287, 28.23013298213482, 21.516565829515457, 13.640136625617743, 18.85544702410698, 12.412811983376741, 5.600613998249173, 1.3952099648304284, 1.3713702815584838, 0.7952866377308965, 3.135772948153317, 2.3755907267332077, 3.6541843554005027, 4.256514022126794, 4.8841458186507225, 5.589742306619883, 4.986794935539365, 4.87011032178998, 4.436640506610274, 3.1982620200142264, 3.092590165324509, 2.443160838447511, 2.0568020828068256, 1.8276725965552032, 1.4116475265473127, 1.3611358869820833, 0.5115992040373385, 0.2539598773000762, 0.3310038009658456, 0.10013217499363236, 0.11660391261102632, 0.1799355002003722, 0.1563949469709769, 0.0751375021354761, 0.08317321000504307, 0.07037392337224446, 0.2439759427215904, 0.07900798038463108, 0.039155325503088534, 0.09005783940665424, 0.11947086619329639, 0.28650961350649595, 0.17539769760333002, 16.306393705308437, 18.752763234078884, 13.93922047689557, 50.73368065059185, 73.26250836253166, 46.584983468055725, 28.278597481548786, 14.640230610966682, 44.94156785309315, 69.62409719824791, 70.91248646378517, 78.1960116326809, 68.32209706306458, 24.027719981968403, 0.4324981360696256, 0.0684190470201429, 0.10239076043944806, 0.06096601784520317, 0.07858137163566425, 0.03286757208115887, 0.06304959373665042, 0.03367945937498007, 0.07010162196820602, 0.07587988729937933, 0.05832523376739118, 0.02823873579473002, 0.02930315924459137, 0.050421772903064266, 0.03748543756955769, 0.060745139853679575, 0.05585173348663375, 0.06509959857794456, 0.009267172063118778, 0.03968675147916656, 0.06398351237294264, 0.020788005422218703, 0.11899662640644237, 0.049849795977934264, 0.041219275299226865, 0.011700771701725898, 0.11028311506379396, 0.006931031721251202, 0.047804874848225154, 0.01819406756112585, 0.034977063769474626, 0.039235978401848115, 0.05948048310528975, 0.11128951926366426, 0.16205486201215535, 0.15220381639664993, 0.13950556574855, 0.23577524058055133, 0.18232033238746226, 0.09011144473333843, 0.13288633577758446, 0.15451480488991365, 0.13594765041489154, 0.2518848917679861, 0.15220685920212418, 0.20736527832923457, 0.2122222341131419, 0.12031416117679328, 0.13662537967320532, 0.0644658860983327, 0.25336292339488864, 0.19524832227034494, 0.11844069100334309, 0.09529009184916504, 0.12304620715440251, 0.305264011840336, 0.174218692118302, 0.15078821423230693, 0.1974961836822331, 0.14061109861359, 0.11798416628153063, 0.13385310187004507, 0.10936559046967886, 0.17220723442733288, 5.734175406396389, 63.3394206315279, 112.13248461484909, 99.68315184116364, 103.54383587837219, 90.14335334300995, 69.01080250740051, 78.76788094639778, 74.1970606148243, 97.33013570308685, 70.9529846906662, 65.02110779285431, 50.8429741859436, 41.880927085876465, 81.20687127113342, 29.300725534558296, 3.526833476498723, 0.8276337676215917, 0.3293703042436391, 1.22326432261616, 0.1853145271888934, 0.2042512415209785, 0.82825135323219, 0.24140567751601338, 0.2752754866378382, 0.37157924089115113, 0.4006975534139201, 0.2965694252634421, 0.16031883016694337, 0.3989580483175814, 0.6908645003568381, 2.8516170708462596, 5.062815556302667, 19.217540994286537, 13.111944068223238, 7.3886047303676605, 8.73671444132924, 9.26893288269639, 13.036297727376223, 9.270970523357391, 10.479417778551579, 11.519042942672968, 16.996909752488136, 15.449099857360125, 23.10916867107153, 27.091852761805058, 24.88246511667967, 23.21075811982155, 40.119326412677765, 19.82723157852888, 24.290662072598934, 24.57216616719961, 35.68600170314312, 35.37990912795067, 27.836709693074226, 32.940394431352615, 35.06632335484028, 29.292080998420715, 24.636164233088493, 27.105915807187557, 18.656736686825752, 8.575142361223698, 2.777828830294311, 3.537052315659821, 3.1656229589134455, 8.751876577734947, 5.037384470924735, 5.328494925051928, 6.333032771945, 6.6451736725866795, 7.063208715990186, 7.211281545460224, 6.742020025849342, 7.065070141106844, 4.919470623135567, 3.62771260086447, 3.1220357352867723, 2.3008207138627768, 2.2669011214748025, 1.4821070269681513, 1.4111610339023173, 0.419324332033284, 0.4281648248434067, 0.48485154868103564, 0.14295229251729324, 0.35774694406427443, 0.30860937607940286, 0.27159698714967817, 0.2151328482432291, 0.18423750763759017, 0.4101211961824447, 0.39922860567457974, 0.15217295789625496, 0.20655418513342738, 0.30147701036185026, 0.2867868501925841, 0.6297075538896024, 1.4960666466504335, 51.827843338251114, 78.94457906484604, 35.377332866191864, 55.52998848259449, 105.53708732128143, 80.76723486185074, 83.7650839984417, 41.120299100875854, 39.0334814786911, 59.02464956045151, 65.42830914258957, 85.6098698079586, 74.43384870886803, 21.219560466706753, 0.3115427593002096, 0.14262248208979145, 0.2428577488171868, 0.11202885420061648, 0.17605342960450798, 0.23249043559189886, 0.14883274416206405, 0.12903251132229343, 0.22669714177027345, 0.15465686679817736, 0.15416197304148227, 0.11583709594560787, 0.13008195266593248, 0.15323412517318502, 0.140973222150933, 0.09873333052382804, 0.20703134156065062, 0.18163570115575567, 0.15208447905024514, 0.18617577472468838, 0.10613421269226819, 0.1872295798966661, 0.25954100594390184, 0.11960480158450082, 0.1221861173689831, 0.09840173152042553, 0.2669710322516039, 0.14476016425760463, 0.07582424848806113, 0.14145588531391695, 0.19250668032327667, 0.14183350489474833, 0.08781365162576549], [0.002716853286983678, 0.02867213148419978, 0.003414829725443269, 0.02491128514520824, 0.07536285527748987, 0.05051453765190672, 0.11053577181883156, 0.08487986022373661, 0.054475042124977335, 0.032372537316405214, 0.02621478219225537, 0.09446985539398156, 0.015905350919638295, 0.04960040838341229, 0.012222107252455316, 0.0035521400332072517, 0.027818941816804, 0.08466755403787829, 0.07385735676507466, 0.06949496077140793, 0.043359996561775915, 0.034384054379188456, 0.06592952006030828, 0.08294016821309924, 0.036633299896493554, 0.02020787971559912, 0.07022693360340782, 0.03227775763662066, 0.02888710754632484, 0.2590717014390975, 9.877722915261984, 45.35415731370449, 77.68689975142479, 75.98741814494133, 75.2125409245491, 64.85369637608528, 40.00124014914036, 32.64983922243118, 53.23358550667763, 39.72553834319115, 37.37705536186695, 32.44146600365639, 105.59646293520927, 88.98321479558945, 37.72481270134449, 7.718737190589309, 0.9780080860946327, 0.12994790595257655, 0.2156998639111407, 0.08071609263424762, 0.07368036938714795, 0.0921666446083691, 0.32336858566850424, 0.10263395481160842, 0.05353909371478949, 0.1633127429522574, 0.3238270845031366, 0.11835068333311938, 1.2684449669905007, 1.0186827066354454, 0.762595507549122, 2.617130703292787, 3.3801392605528235, 1.1461752466857433, 0.9692547214217484, 0.4028362449025735, 2.664727186784148, 6.724462117999792, 18.798351287841797, 24.12612710148096, 25.90691864490509, 18.388018906116486, 14.011986572295427, 11.224116068333387, 5.60120296664536, 3.4106551855802536, 2.0761012472212315, 3.424571701325476, 1.8028619466349483, 5.140261575579643, 8.152538537979126, 20.09568527340889, 22.386183366179466, 27.260238826274872, 14.628158658742905, 17.310866005718708, 28.41848697513342, 21.686217226088047, 18.68349865078926, 14.076413065195084, 14.389711003750563, 5.171492099761963, 1.5042563946917653, 2.0440551917999983, 2.3246461478993297, 1.4946550223976374, 1.3663863739930093, 1.931030850391835, 4.132091598585248, 4.361786898225546, 5.5616100411862135, 5.882267709821463, 6.07492639683187, 6.608974914997816, 5.927818715572357, 6.9336974155157804, 4.782694587484002, 4.714451199397445, 3.439809358678758, 2.441144334152341, 2.537099397741258, 1.7795962700620294, 1.2200779560953379, 0.3970824630232528, 0.5740649427752942, 0.26752684148959816, 0.18080351612297818, 0.19410948181757703, 0.1291192980716005, 0.05270309775369242, 0.171530366060324, 0.019768146084970795, 0.07975919710588641, 0.12993658077903092, 0.020214585019857623, 0.04825623793294653, 0.09369283419800922, 0.01811551679566037, 0.12775104492902756, 0.389020245638676, 4.390348065644503, 38.12001049518585, 70.11871665716171, 87.27466687560081, 80.58126524090767, 91.09580263495445, 67.78995081782341, 21.430570743978024, 28.079866245388985, 51.03787712752819, 52.05820977687836, 67.96971157193184, 57.90604658424854, 27.61605553328991, 0.7724164368119091, 0.04765787765791174, 0.06678243327769451, 0.0673356449988205, 0.021655217969964724, 0.008630640350020258, 0.03473703094641678, 0.025645248788350727, 0.07845757398172282, 0.03923753320123069, 0.029154909680073615, 0.04050534036650788, 0.031107040085771587, 0.07414921376039274, 0.07196358143119141, 0.007030632114037871, 0.051034449206781574, 0.03027833387022838, 0.025236191831936594, 0.04468376537261065, 0.03203046289854683, 0.024307256717293058, 0.06456582370446995, 0.01976315885258373, 0.013042299178778194, 0.0713034559157677, 0.052718768201884814, 0.07724079317995347, 0.11159113550093025, 0.05489973242220003, 0.05841636208060663, 0.06528179583256133, 0.04557370804832317, 0.016304630080412608, 0.023192868175101466, 0.0037275716840667883, 0.04377620782179292, 0.02565328624768881, 0.08529334780178033, 0.04522794515651185, 0.020753571625391487, 0.02883482324250508, 0.04127531858102884, 0.05204439345106948, 0.013895572337787598, 0.07723758710199036, 0.036918336554663256, 0.030938817471906077, 0.07704530406044796, 0.07717719854554161, 0.00943861652558553, 0.016171280985872727, 0.013715844579564873, 0.06759777897968888, 0.012635864786716411, 0.10538516304222867, 0.020526541229628492, 0.1188729029672686, 0.07151640034862794, 0.005658171457980643, 0.049664841644698754, 0.6011491769459099, 15.782095938920975, 67.03457415103912, 94.44346100091934, 98.61972570419312, 102.20944628119469, 96.75454258918762, 58.24316829442978, 22.32185661792755, 47.71310493350029, 39.52054314315319, 47.305307015776634, 32.73344613611698, 94.5378403365612, 70.6576569378376, 21.48124672472477, 4.024219661951065, 0.4892338119680062, 0.17721837881254032, 0.24089739541523159, 0.020026548918394838, 0.03902237716829404, 0.3769573476165533, 0.2768743102205917, 0.6056363205425441, 0.6152163783553988, 0.9867983206640929, 1.1111006350256503, 0.13286709930980578, 0.27255067660007626, 1.7882089829072356, 0.20588549523381516, 1.8117937236092985, 2.9330103658139706, 0.6282796617597342, 1.7241507139988244, 1.0285518458113074, 4.323176695033908, 10.874058902263641, 26.159770376980305, 32.89036251604557, 35.75446642935276, 26.996766664087772, 22.97886986285448, 19.5861554145813, 11.795646250247955, 7.912525841966271, 4.894242826849222, 1.9866194925270975, 0.4094635642832145, 1.1719901114702225, 2.376555874943733, 6.346651716157794, 24.30230464786291, 25.834452733397484, 18.069117218255997, 21.13198846578598, 29.06035803258419, 27.31707237660885, 19.224319830536842, 17.42002084851265, 18.366804644465446, 4.940577540546656, 2.5414724880829453, 2.446151990443468, 2.8962159901857376, 2.6609775004908442, 1.004719405900687, 0.9949424117803574, 1.5454429783858359, 1.233774796128273, 1.3173367059789598, 1.2622191198170185, 2.7577469078823924, 4.720690939575434, 6.203780332580209, 9.316549077630043, 8.214308973401785, 7.006781743839383, 5.457700816914439, 4.144884562119842, 3.2725458964705467, 1.2721058330498636, 1.1154850060120225, 0.7935956097207963, 0.4413094773190096, 0.39853253052569926, 0.6928410474210978, 0.3636056062532589, 0.4103917832253501, 0.2800579753238708, 0.18579800671432167, 0.042015072831418365, 0.10172104637604207, 0.13478709472110495, 0.0606314650940476, 0.0350659507967066, 0.24419083900284022, 0.10645913978805766, 0.04539080946415197, 0.3356991021428257, 1.6716190078295767, 19.62271135300398, 59.9536807090044, 86.82399585843086, 82.53067463636398, 92.10834950208664, 65.77530652284622, 7.204759670421481, 32.808043733239174, 71.69300258159637, 76.26117825508118, 85.22738233208656, 76.82343408465385, 44.07461017370224, 1.5669814101420343, 0.09791814067284577, 0.09249090377124958, 0.018437727630953304, 0.0560518610291183, 0.08196572089218535, 0.06016199731675442, 0.03343837641295977, 0.10015926338382997, 0.025200008421961684, 0.009829052996792598, 0.05048500759585295, 0.05504839573404752, 0.017973341709875967, 0.05443634283437859, 0.0738740996166598, 0.025436684882151894, 0.05053559609223157, 0.06083668748033233, 0.003011316148331389, 0.04956386132107582, 0.08090128074400127, 0.037207273198873736, 0.004556452768156305, 0.053206637530820444, 0.019882629785570316, 0.03990138429799117, 0.05455608836200554, 0.12946456001373008, 0.12930716533446684, 0.03832546339253895, 0.029081856373522896, 0.25814897438976914, 0.11432698869612068, 0.09193469377350993, 0.15202083246549591, 0.20883706107269973, 0.08470702145132236, 0.21069805574370548, 0.1616603066213429, 0.13142075738869607, 0.09754977567354217, 0.13447169680148363, 0.21269024728098884, 0.09757943931617774, 0.2239678194746375, 0.11735542619135231, 0.07753507699817419, 0.21144560625543818, 0.20180565712507814, 0.14212922105798498, 0.13563888729549944, 0.10015380859840661, 0.13597586686955765, 0.12009651894913986, 0.1919469822314568, 0.09112570827710442, 0.2028283366234973, 0.20349546801298857, 0.19298993720440194, 0.12408721770043485, 0.4830906994175166, 20.256279855966568, 77.77569338679314, 107.52861365675926, 100.45707911252975, 103.0698873102665, 88.72404590249062, 55.7866495102644, 50.68540804088116, 78.35087612271309, 59.813445433974266, 53.123144432902336, 54.486838057637215, 133.37191611528397, 111.64204493165016, 52.58675001561642, 12.171669322997332, 1.134990428108722, 0.26861880789510906, 0.548131987452507, 0.23938231577631086, 0.23773286287905648, 0.44242160045541823, 0.7839314814191312, 0.3480728709837422, 0.38138900825288147, 0.7775256189052016, 1.1356775974854827, 0.6269832781981677, 3.3911142591387033, 4.48200817219913, 1.7274668673053384, 10.291748698800802, 13.939223326742649, 6.2067123502492905, 4.529422977939248, 0.700356806628406, 2.8089911956340075, 6.75517444498837, 20.774912126362324, 26.629478372633457, 28.9024556055665, 22.849131524562836, 18.594216741621494, 14.370262697339058, 8.182126600295305, 5.265704244375229, 5.412784377112985, 7.818611031398177, 8.941757138818502, 13.225548472255468, 20.530784726142883, 33.476994037628174, 39.10421848297119, 43.69990848004818, 25.47976266592741, 32.95887663960457, 44.484858959913254, 36.86924301087856, 34.90380607545376, 31.23766589909792, 27.724108435213566, 11.880070120096207, 5.911685731261969, 4.017326356843114, 4.384047528728843, 4.899686509743333, 3.553770943544805, 3.9509845292195678, 6.922238655388355, 5.434708250686526, 7.069689268246293, 8.294541668146849, 5.803022012114525, 7.09392674267292, 7.658163690939546, 9.382306449115276, 8.903451394289732, 7.870478248223662, 5.744700841605663, 5.099038062617183, 4.3034044560045, 2.1014064643532038, 1.6906249942258, 0.7576463918667287, 0.5956233234610409, 1.2587052583694458, 1.033763384912163, 1.0105064953677356, 1.0684024449437857, 0.4897162673296407, 0.37532836315222085, 0.16072252881713212, 0.260580368922092, 0.32059330958873034, 0.1823165622772649, 0.06458317511714995, 0.3973046620376408, 0.4797969589708373, 0.19355943164555356, 0.5726052273530513, 9.589841812849045, 59.43259187042713, 79.77630883455276, 98.88024732470512, 98.58482077717781, 100.8225966989994, 90.89895039796829, 31.975109428167343, 35.32979741692543, 67.73284748196602, 71.58528596162796, 88.54005977511406, 89.42568585276604, 45.66291734576225, 1.1795318755321205, 0.3482793364673853, 0.2088565201847814, 0.26199246814940125, 0.13353604153962806, 0.1445322358631529, 0.2681689476594329, 0.19340751401614398, 0.1716372650116682, 0.19562870264053345, 0.14712236094055697, 0.1375267031835392, 0.13742964511038736, 0.11800624517491087, 0.11292864888673648, 0.19142075499985367, 0.1723953094915487, 0.135050319659058, 0.13739805930526927, 0.1347477312083356, 0.11144053147290833, 0.24044388381298631, 0.09667931808508001, 0.12295632564928383, 0.1702723663765937, 0.1768512828857638, 0.2064141715527512, 0.15280909719876945, 0.24624836922157556, 0.2073793049203232, 0.2413893651100807, 0.2154485578648746], [0.04886036469542887, 0.0719468979514204, 0.05312424058502074, 0.0696310335479211, 0.015633882576366886, 0.04272458085324615, 0.03435921098571271, 0.04901045293081552, 0.06288276636041701, 0.023661157792957965, 0.04314707810408436, 0.058976616783184, 0.026762322049762588, 0.04053212818689644, 0.016504072991665453, 0.03609089755627792, 0.04914173885481432, 0.023242922325152904, 0.09328840824309736, 0.1105271109554451, 0.06347390924929641, 0.07193008088506758, 0.022083105068304576, 0.07506025940529071, 0.02444177840516204, 0.007325079204747453, 0.03779513579502236, 0.10549208425800316, 0.18010141473496333, 14.77639440447092, 61.69474348425865, 79.8356768488884, 78.13188627362251, 63.453216925263405, 52.24399320781231, 35.92533566057682, 40.89545376598835, 71.29604548215866, 35.530255660414696, 56.17705196142197, 60.21740175783634, 119.24648568034172, 89.41588997840881, 25.19776839762926, 2.0055414084345102, 0.13411819702014327, 0.3929158381652087, 0.08721820428036153, 0.017210571604664437, 0.16508088010596111, 0.5687327601481229, 0.3833272308111191, 0.6562628445681185, 0.15538259816821665, 0.17542318295454606, 0.1440961053594947, 0.3389963158406317, 0.35009670769795775, 3.2683380972594023, 3.8229693984612823, 0.4812759405467659, 0.9199771250132471, 4.831332452595234, 19.451262652873993, 40.47177270054817, 55.15570096671581, 61.93079821765423, 84.3626095354557, 97.41354122757912, 100.69262087345123, 99.19076666235924, 91.23311966657639, 92.20028176903725, 97.66257226467133, 82.08350703120232, 80.15378057956696, 61.49734787642956, 37.570685371756554, 11.16311889141798, 9.809153694659472, 5.870887320488691, 9.511889945715666, 16.080864407122135, 23.648088052868843, 22.516214288771152, 17.726504802703857, 18.706981390714645, 18.75584676861763, 22.861231975257397, 13.89326574280858, 7.2700064443051815, 1.4683164982125163, 1.433540170546621, 0.9725050907582045, 8.668668642640114, 22.11156640201807, 26.78742829710245, 40.23389786481857, 48.48126031458378, 49.50958393514156, 46.600976809859276, 39.800371527671814, 31.113881841301918, 20.06622165441513, 13.70911717414856, 11.877235472202301, 9.986254591494799, 7.782354326918721, 7.796241156756878, 6.360334781929851, 6.063385466113687, 3.573518958874047, 2.201709682121873, 1.076999008655548, 0.6791004503611475, 0.4830175533425063, 0.37217690725810826, 0.03853792542940937, 0.08718055512872525, 0.04797127920028288, 0.36893710610456765, 0.0928843385190703, 0.07701000009546988, 0.04847933123528492, 0.09861949991318397, 0.08575411018682644, 0.10820973257068545, 0.07259393198182806, 0.04690018198743928, 0.5062135274056345, 0.7043928431812674, 0.5354249349329621, 2.89763402659446, 28.691703714430332, 39.609652161598206, 97.91705220937729, 59.61609922349453, 70.98738804459572, 46.59573309123516, 23.7373186647892, 42.57279776036739, 33.67370568215847, 61.081380397081375, 59.54141803085804, 33.34817335009575, 1.098123025149107, 0.047558871447108686, 0.10636144346790388, 0.03966269847296644, 0.04617695536580868, 0.05065491859568283, 0.04242204435286112, 0.09330385233624838, 0.02411147259408608, 0.01909661561512621, 0.06386887282133102, 0.057078637182712555, 0.013421278745227028, 0.048586293269181624, 0.03898163697158452, 0.052544222489814274, 0.0670978386187926, 0.08836267021251842, 0.029474589791789185, 0.046894389524823055, 0.019180997805960942, 0.026359890616731718, 0.07207877017208375, 0.028366418591758702, 0.016527016487088986, 0.03425689850701019, 0.023446719787898473, 0.016522517216799315, 0.04286142546334304, 0.08708973851753399, 0.027685659515555017, 0.006407270275303745, 0.04473193075682502, 0.05875167182239238, 0.07140817295294255, 0.0625025641056709, 0.04077882178535219, 0.03126220646663569, 0.05135189916472882, 0.07097658439306542, 0.039460845437133685, 0.07320669363252819, 0.06299232962192036, 0.02365377342357533, 0.010194596907240339, 0.06646128371357918, 0.03777595869905781, 0.04830595069506671, 0.03020487609319389, 0.019203334595658816, 0.027878452783625107, 0.008183108602679567, 0.12652915815124288, 0.03191583447915036, 0.09989345577196218, 0.0908848516701255, 0.07899396121501923, 0.002416402917333471, 0.10372351665864699, 0.43540782993659377, 26.082919500768185, 81.06769233942032, 95.8750569820404, 99.16280016303062, 92.04559206962585, 79.53035563230515, 59.10121165215969, 27.871814109385014, 61.03013254702091, 47.29149095714092, 62.94046103954315, 56.57731868326664, 105.8500537276268, 72.18987911939621, 12.611393127590418, 0.713784514227882, 0.1379624626133591, 0.37994775746483356, 0.11996955232461914, 0.05983999799354933, 0.16791520145488903, 0.8491645404137671, 0.8817954082041979, 1.6591687384061515, 1.1562215513549745, 0.07833255920559168, 0.2526021032826975, 0.5159236688632518, 0.533747028093785, 1.5819020220078528, 2.4572260212153196, 0.5728856998030096, 2.2576099075376987, 9.092955775558949, 27.594020515680313, 53.18247824907303, 70.25439977645874, 74.85166668891907, 95.90338066220284, 103.39588701725006, 106.36407494544983, 102.79662117362022, 96.34354144334793, 103.63421782851219, 106.89850106835365, 95.4360893368721, 93.73695731163025, 81.31771132349968, 50.506768226623535, 20.005358420312405, 18.226823955774307, 11.349916867911816, 1.074986185412854, 4.0942879021167755, 22.194766737520695, 23.496706075966358, 22.36475821584463, 20.73114227503538, 19.927152916789055, 21.63839679211378, 15.126483868807554, 7.408895641565323, 2.0223146583884954, 1.1119591514579952, 2.7704282524064183, 14.493170902132988, 31.630201935768127, 40.51083840429783, 57.351166158914566, 67.6812082529068, 71.81081146001816, 72.22505003213882, 65.13721436262131, 54.40290056169033, 45.98927043378353, 28.836105465888977, 10.634915884584188, 4.5816440507769585, 8.69680043309927, 7.051595114171505, 8.092810492962599, 6.4226865861564875, 6.340885050594807, 3.3454846451058984, 1.9877506443299353, 0.6280252535361797, 0.09482306573772803, 0.14742701256182045, 0.13751338905422017, 0.2000034850789234, 0.0677893272950314, 0.2687151386635378, 0.4062386357691139, 0.37733824749011546, 0.0866564801253844, 0.15039698366308585, 0.1416364053147845, 0.0816627019958105, 0.07804325519828126, 0.04934604097798001, 0.2577485708752647, 0.41947709571104497, 0.4350326000712812, 0.7684929098468274, 22.63271603733301, 39.231777638196945, 101.02052047848701, 65.87169215083122, 59.30759757757187, 20.086617060005665, 35.4121807962656, 66.39357134699821, 58.1683275103569, 75.19271358847618, 70.82569912075996, 52.62104697525501, 3.6771688470616937, 0.13308196590514854, 0.16689954267349094, 0.03727902774699032, 0.04442062207090203, 0.01508189632659196, 0.06513821994303726, 0.03661259397631511, 0.01602284588443581, 0.03752498290850781, 0.05998290223942604, 0.07303735037567094, 0.0271039697327069, 0.015968849074852187, 0.030128614853310864, 0.036816499050473794, 0.026547025008767378, 0.02871657499781577, 0.02561554247222375, 0.040232671599369496, 0.05130180419655517, 0.06580411194590852, 0.02069075624604011, 0.041234240707126446, 0.014481456182693364, 0.030831332223897334, 0.009317279091192177, 0.007813472675479716, 0.03487774956738576, 0.013225284037616802, 0.0487259060901124, 0.09430168473045342, 0.11875006268383004, 0.16709221905330196, 0.19759566115681082, 0.14647831034380943, 0.1786977463052608, 0.13396432012086734, 0.14490529865724966, 0.14758939447347075, 0.17090069828554988, 0.1378807966830209, 0.1581377026741393, 0.11136778615764342, 0.1112159872718621, 0.15814521320862696, 0.1386205101152882, 0.1344929519109428, 0.12915318453451619, 0.22497782309073955, 0.1539744174806401, 0.08089469789410941, 0.2895947510842234, 0.09998740424634889, 0.16244606289546937, 0.15174003347055987, 0.18428999232128263, 0.07965905911987647, 0.20264998369384557, 0.6862989265937358, 32.85084083676338, 95.49840599298477, 108.34673255681992, 104.11274135112762, 91.26589670777321, 72.44280114769936, 52.819787710905075, 62.10371933877468, 98.20251569151878, 54.12092909216881, 75.51873609423637, 83.36913764476776, 149.53764706850052, 101.22791334986687, 33.716430589556694, 3.3847142150625587, 0.383299711975269, 0.6036362622398883, 0.3809099073987454, 0.1713937069871463, 0.47202717745676637, 1.2177523621357977, 0.5429262074176222, 1.200050062034279, 0.8092792087700218, 0.820865499554202, 0.27776013768743724, 3.539011823013425, 3.1012199772521853, 10.006238669157028, 9.732247721403837, 2.814243701286614, 1.344604161567986, 6.134421704337001, 24.524978399276733, 53.742974773049355, 73.90335157513618, 77.25892871618271, 99.72893178462982, 112.12680771946907, 114.50991064310074, 113.73938798904419, 105.77448338270187, 110.71267560124397, 114.06253784894943, 99.67790052294731, 95.8802779018879, 75.82541763782501, 43.622951209545135, 15.30818346887827, 13.982633147388697, 12.552520986646414, 18.950535021722317, 22.30866562575102, 36.72202751040459, 36.61444768309593, 31.594193167984486, 31.133251301944256, 31.228117011487484, 43.18519949913025, 26.820693612098694, 12.334893364459276, 4.3374596536159515, 2.9292998649179935, 3.6071547539904714, 16.489448882639408, 35.82977458834648, 47.22519211471081, 63.42281095683575, 73.42964619398117, 77.01714769005775, 79.66620594263077, 73.41128557920456, 64.75038751959801, 58.14559333026409, 41.82025954127312, 21.146370694041252, 12.40757206454873, 14.704981986433268, 10.819744616746902, 10.211669895797968, 8.931689579039812, 8.185924496501684, 5.14711070805788, 4.099649414420128, 2.583815990947187, 0.8488222619052976, 1.220675592776388, 0.4571325407596305, 0.6911817833315581, 0.12335566047113389, 0.5031367018818855, 0.3084337245672941, 0.5208844214212149, 0.14666182862129062, 0.4500240128254518, 0.4969884833553806, 0.16954921768046916, 0.2708220959175378, 0.1495980320032686, 0.6922369392123073, 0.784053074894473, 0.5527009454090148, 5.5090218130499125, 41.51542849838734, 56.75457917153835, 118.97104606032372, 75.65401643514633, 105.79142287373543, 62.8335727751255, 34.22303080558777, 56.80740773677826, 52.238817885518074, 79.30907070636749, 84.04556974768639, 57.601002752780914, 3.279992309398949, 0.2393324879813008, 0.3202220576349646, 0.15996674046618864, 0.21116991323651746, 0.0912231819529552, 0.12139100261265412, 0.2209829757339321, 0.1383026482653804, 0.1956610009074211, 0.16830589767778292, 0.19541615154594183, 0.19339118676725775, 0.07007629246800207, 0.2031845081364736, 0.26320855133235455, 0.13142175186658278, 0.11861430160934106, 0.08797661983408034, 0.14820398180745542, 0.13984766614157706, 0.1482658027089201, 0.18174700846429914, 0.12907987518701702, 0.08335872465977445, 0.09382216827361844, 0.08328308496857062, 0.07150316043407656, 0.10806771519128233, 0.22831867507193238, 0.10083674031193368], [0.07085733610438183, 0.01851447312219534, 0.01914217235025717, 0.071199369704118, 0.03552680595021229, 0.020410973993421067, 0.04117669457627926, 0.023912025972094852, 0.027288632772979327, 0.02192292919062311, 0.032039980942499824, 0.0819266913458705, 0.03033948869415326, 0.07799376136972569, 0.02740116648055846, 0.0171741061785724, 0.104880881117424, 0.07662637653993443, 0.10049715579953045, 0.06080946550355293, 0.06110758622526191, 0.02884448414988583, 0.061488115024985746, 0.018797702650772408, 0.0986854026268702, 0.03303525663795881, 0.07005550491157919, 0.40667641384061426, 21.750724464654922, 76.24546229839325, 86.48584440350533, 72.7400515973568, 73.33630800247192, 57.44489572942257, 40.51849879324436, 30.625074170529842, 73.19807901978493, 36.523450165987015, 43.90320137143135, 98.15526142716408, 130.4974463582039, 67.88791716098785, 4.565248405560851, 0.22035862173652276, 0.16216965741477907, 0.2567573881242424, 0.15223402180708945, 0.22434699756558985, 0.26500822976231575, 0.15464972733752802, 0.09941952768713236, 7.491456186398864, 7.132431976497173, 4.890824435278773, 0.5731218215078115, 2.1982578048482537, 3.000518730841577, 0.5197963141836226, 0.2921274636173621, 13.883225731551647, 35.63926041126251, 62.66205757856369, 80.02825811505318, 92.24624410271645, 92.19576001167297, 89.85719069838524, 85.69867104291916, 81.28191724419594, 69.02331903576851, 71.90794184803963, 60.792508497834206, 71.60730198025703, 74.78419750928879, 77.30001971125603, 76.78185671567917, 81.35781437158585, 89.9103270471096, 90.60347065329552, 94.48283448815346, 117.86193117499352, 71.70062497258186, 15.081948358565569, 1.65091332513839, 9.065215364098549, 17.860772497951984, 16.173837818205357, 14.138460885733366, 11.818195190280676, 18.371117413043976, 7.791385017335415, 3.4399703750386834, 0.39112316560931504, 12.284784503281116, 43.213724568486214, 66.6780012845993, 76.16546899080276, 86.37590110301971, 88.3703000843525, 92.92469769716263, 91.79276123642921, 87.5076399743557, 87.63402879238129, 80.9980496764183, 65.42061075568199, 61.15742191672325, 50.82266427576542, 35.48289120197296, 30.74495203793049, 22.338150143623352, 8.6561150662601, 1.7826786171644926, 3.618907523341477, 3.175852010026574, 2.2846392821520567, 3.0511096911504865, 1.5013988292776048, 1.3143461477011442, 1.6178317065350711, 0.5401044432073832, 0.2979260712163523, 0.19230373261962086, 0.1513073020032607, 0.3565577859990299, 0.1131001221074257, 0.09431199316168204, 0.008582660502725048, 0.05988768098177388, 0.04134142538532615, 0.1178120102849789, 0.17354210576741025, 0.06154898597742431, 0.22101585287600756, 0.06634202800341882, 1.8523483537137508, 21.728159375488758, 46.872981414198875, 44.01431500911713, 26.77048310637474, 58.731563687324524, 31.30862709134817, 21.328468322753906, 39.324621856212616, 44.26229730248451, 55.379033982753754, 66.49741217494011, 42.84215770661831, 3.4588684234768152, 0.013779138644167688, 0.0654499590746127, 0.02965368486911757, 0.024593595844635274, 0.059915051388088614, 0.009834010543272598, 0.06137985423265491, 0.03134615450107958, 0.05901851844100747, 0.06198539107572287, 0.021272882040648255, 0.01739106377499411, 0.014580070910596987, 0.07328513864194974, 0.056470376657671295, 0.061582709167851135, 0.017373441478412133, 0.025296667590737343, 0.0246585912827868, 0.02805616746627493, 0.04160606040386483, 0.04143410849792417, 0.021097531098348554, 0.06215076384251006, 0.03388543875189498, 0.07984101146575995, 0.057101703132502735, 0.0301982561359182, 0.02108045984641649, 0.08270062520750798, 0.02712059569603298, 0.08192221619538032, 0.09268798850825988, 0.022285169616225176, 0.0906949583441019, 0.06988496679696254, 0.05214485798205715, 0.026972155028488487, 0.02692797868803609, 0.020103407587157562, 0.03565284117939882, 0.02941703252872685, 0.014725593082403066, 0.04493087086302694, 0.03864798964059446, 0.045580817823065445, 0.02802999377308879, 0.09146544121904299, 0.02211307299148757, 0.13695570960408077, 0.016546501574339345, 0.038138175004860386, 0.035533258924260736, 0.10720419668359682, 0.0704841100377962, 0.06549516328959726, 0.705927248345688, 35.057196244597435, 91.23025462031364, 100.81275522708893, 99.63378489017487, 96.90865471959114, 79.02887374162674, 63.50335903465748, 22.471051812171936, 55.11208690702915, 43.96568521857262, 50.963731706142426, 105.20085856318474, 116.6276054084301, 49.99069131910801, 2.869912851601839, 0.21607056667562574, 0.14960747212171555, 0.09853033829131164, 0.16315071727149189, 0.2660233690403402, 0.2456158961285837, 0.14645122195361182, 0.32955866132397205, 5.795999988913536, 8.115206491202116, 3.3780308486893773, 0.8755605365149677, 0.23096354096196592, 1.7091290513053536, 0.2836176718119532, 0.9216078312601894, 19.980771839618683, 47.475739270448685, 75.67168548703194, 91.40635997056961, 102.51716136932373, 100.62106311321259, 96.49798035621643, 91.75417810678482, 87.86465361714363, 75.16828089952469, 81.10782578587532, 68.71353685855865, 80.85358902812004, 81.99089840054512, 83.76976534724236, 82.58245825767517, 88.13060134649277, 92.53763526678085, 95.97287893295288, 103.34947630763054, 131.0761097073555, 86.54976457357407, 25.50736628472805, 4.14139112457633, 2.554796473123133, 14.187600798904896, 17.55705289542675, 17.76014819741249, 15.113897044211626, 14.028766471892595, 3.813932058401406, 2.1479397173970938, 0.8043331804219633, 17.78208252042532, 57.04970933496952, 83.29738229513168, 93.0197685956955, 99.7466692328453, 99.377161860466, 102.3297630250454, 97.960704267025, 97.10692048072815, 98.2005625963211, 94.32857036590576, 81.74075022339821, 76.36758014559746, 72.95351654291153, 64.60810795426369, 60.22026680409908, 49.791965782642365, 32.429698035120964, 16.81128591299057, 9.797518718987703, 4.711525831371546, 1.5111988596618176, 5.493777031078935, 2.49910737387836, 2.238362515345216, 1.751811804715544, 0.440933327190578, 0.4941960488213226, 0.15067862870637327, 0.14523130928864703, 0.647958746412769, 0.4041502915788442, 0.2850356191629544, 0.2954257756937295, 0.15660473727621138, 0.1025897821818944, 0.015119890576897888, 0.09995395565056242, 0.17043090396327898, 0.2313873963430524, 0.0674221126246266, 1.7730163293890655, 22.16359131038189, 53.41030262410641, 43.60206373035908, 28.787990547716618, 54.98002499341965, 20.688721351325512, 27.809831835329533, 55.224560871720314, 69.0603518486023, 75.83136811852455, 79.45616081357002, 64.21787649393082, 7.704394860193133, 0.167472168977838, 0.14745730702998117, 0.06016737417667173, 0.04412125454109628, 0.04835336651012767, 0.03154095342324581, 0.04324316396377981, 0.0403813979937695, 0.03443287656409666, 0.048891675905906595, 0.015933765898807906, 0.02903157401306089, 0.021492939958989155, 0.02780905084364349, 0.011185872426722199, 0.03068280992010841, 0.014413655426324112, 0.052843408193439245, 0.017004924338834826, 0.0213154980156105, 0.02278732899867464, 0.02294645288202446, 0.07602069497806951, 0.06328846138785593, 0.025110279057116713, 0.031685586873209104, 0.04688844121119473, 0.02911767798650544, 0.059915363090112805, 0.17028091591782868, 0.12153011077316478, 0.2262166456785053, 0.23564505303511396, 0.0866417633369565, 0.22374701569788158, 0.20929606456775218, 0.13136751571437344, 0.23616972175659612, 0.13844490313204005, 0.1351257218630053, 0.15548752300674096, 0.07960917937452905, 0.15450143138878047, 0.2820178685942665, 0.1255401424714364, 0.15965759143000469, 0.14743633393663913, 0.22793697367887944, 0.10504390869755298, 0.15112516412045807, 0.18008669052505866, 0.23778543662047014, 0.16475743730552495, 0.19452548527624458, 0.22018501855200157, 0.24901395285269246, 0.8105583745054901, 43.89156259596348, 106.91689968109131, 111.36146798729897, 98.6343777179718, 101.10486835241318, 75.56448563933372, 54.20332007110119, 50.3624177724123, 109.08931910991669, 56.445051580667496, 65.80965667963028, 117.6393011212349, 157.1703279018402, 74.49029088020325, 7.455806024372578, 0.5277822981588542, 0.3740145836491138, 0.7117959146853536, 0.3489974682452157, 0.4891650000354275, 0.40673667623195797, 0.3878154431004077, 0.6506755412556231, 14.305909350514412, 12.762708608061075, 10.288318432867527, 4.863388007506728, 5.8088618237525225, 7.776312176138163, 2.1783713344484568, 0.36429333966225386, 17.362303845584393, 45.17192289233208, 78.38229283690453, 97.3732177913189, 109.34752285480499, 105.27332067489624, 102.07939445972443, 95.22752612829208, 88.1463173031807, 75.02202674746513, 80.12127712368965, 67.63985127210617, 81.3586351275444, 79.88034725189209, 87.00903072953224, 84.98299464583397, 90.6869749724865, 101.16272404789925, 104.78829190135002, 107.17436626553535, 148.21063667535782, 88.0240398645401, 16.347558796405792, 7.2894742246717215, 13.907454181462526, 31.15309003740549, 26.904011741280556, 25.127798952162266, 24.753583632409573, 32.982617765665054, 14.62249506264925, 7.090117447078228, 1.4625855744816363, 17.677348740398884, 56.515051424503326, 85.1949092745781, 90.5495211482048, 97.4944768846035, 96.3260167837143, 100.05654260516167, 97.41658866405487, 96.01365834474564, 98.1843526661396, 93.49715977907181, 84.50423553586006, 83.84994104504585, 81.85137748718262, 77.40994021296501, 75.03809988498688, 61.5660709887743, 42.51642398536205, 25.29614131897688, 15.957247540354729, 7.83444763161242, 3.898712871596217, 6.115737631917, 3.050277060829103, 4.370342614129186, 2.049771510064602, 1.06510624056682, 1.3380320579744875, 0.8047515142243356, 0.23094362171832472, 0.664936057291925, 0.9386202902533114, 0.9013910160865635, 0.39094442676287144, 0.31343107984866947, 0.2610176126472652, 0.30264927714597434, 0.36396186682395637, 0.7272015349008143, 0.5633934529032558, 0.2030852236202918, 5.475306697189808, 39.39401373267174, 67.91011556982994, 67.78704017400742, 38.23006018996239, 84.83718127012253, 42.189592123031616, 32.03894980251789, 53.18084433674812, 68.4020371735096, 75.90452939271927, 89.07086089253426, 73.57786864042282, 7.2693101316690445, 0.2663143799873069, 0.35778651537839323, 0.19361982762347907, 0.18693534802878276, 0.12051703466568142, 0.08706951499334536, 0.1871653544367291, 0.13261137006338686, 0.24649876984767616, 0.17640075471717864, 0.16953933227341622, 0.16064642899436876, 0.08729301276616752, 0.13942523568402976, 0.21467344398843125, 0.14487271837424487, 0.19597676990088075, 0.0892870819370728, 0.050243761361343786, 0.07297877265955321, 0.18760255363304168, 0.1207458833232522, 0.18744403088930994, 0.16895319888135418, 0.26594980736263096, 0.20882860058918595, 0.21913225238677114, 0.160575999179855, 0.17044694919604808], [0.017793860715755727, 0.07104233125573955, 0.03142185727483593, 0.012494960628828267, 0.010386125741206342, 0.05928608123213053, 0.10789350344566628, 0.018831108573067468, 0.038045725668780506, 0.08887931631761603, 0.009185825256281532, 0.05298554431647062, 0.03760793275432661, 0.06454767819377594, 0.02373277318838518, 0.01994880338315852, 0.047848758040345274, 0.02575899776275037, 0.05119944718899205, 0.07920553267467767, 0.10928049581707455, 0.007860284567868803, 0.027412294984969776, 0.0722195630078204, 0.005937250525676063, 0.29932021046988666, 1.6819821204990149, 28.45319241285324, 76.20978221297264, 87.32210353016853, 69.81675446033478, 55.576452389359474, 53.600395023822784, 44.46726210415363, 34.94684636592865, 80.24011954665184, 42.715069726109505, 40.75371757149696, 72.15683609247208, 66.70632496476173, 52.001319229602814, 2.7386073349043727, 0.8147106610704213, 0.32837030477821827, 0.3182591067161411, 0.15536762162810192, 0.17086290812585503, 0.11703116702847183, 0.07395524604362436, 0.09994064894272014, 0.37303379096556455, 0.8373107202351093, 1.0025539970956743, 2.3208879120647907, 0.7087702676653862, 0.29683719214517623, 5.036037918180227, 27.57546231150627, 58.64533491432667, 81.90611734986305, 91.84790387749672, 87.49660536646843, 88.83029580116272, 86.19604915380478, 87.54698306322098, 90.13693168759346, 85.76896727085114, 86.18143513798714, 88.04032579064369, 91.18189081549644, 86.27510771155357, 93.14055651426315, 97.20179378986359, 90.79205453395844, 92.84197613596916, 87.62681677937508, 79.54940021038055, 77.25220307707787, 77.35560312867165, 71.6361652314663, 88.60505908727646, 101.76315262913704, 42.07318156957626, 2.4271192867308855, 3.419144405052066, 17.141229808330536, 10.551288072019815, 4.523867201060057, 6.795954806730151, 2.484928434714675, 1.7220154660753906, 25.746867433190346, 65.71061119437218, 87.8301590681076, 93.17856207489967, 90.86222916841507, 87.51328647136688, 86.23350754380226, 85.1937085390091, 86.50938034057617, 83.88939812779427, 84.01107519865036, 85.78254014253616, 81.5435940027237, 76.946532279253, 81.66102290153503, 86.56158953905106, 83.41609552502632, 76.60268872976303, 61.70844554901123, 53.12219448387623, 44.37782630324364, 36.29888981580734, 22.53822460770607, 7.0676568523049355, 2.3023845674470067, 2.0598670933395624, 2.4239580938592553, 2.955627702176571, 0.6345936167053878, 0.7616468647029251, 1.247676587663591, 0.5485862412024289, 0.9494025679305196, 0.26492697943467647, 0.1671722819446586, 0.036053292933502235, 0.197346062050201, 0.051500365807441995, 0.031409055227413774, 0.044502922537503764, 0.17105892417021096, 0.034626543711056, 0.06265553558478132, 2.905029379762709, 38.71518775820732, 70.58899462223053, 38.77593129873276, 28.924541920423508, 58.777476623654366, 44.46424126625061, 26.105668880045414, 28.744279593229294, 41.46044544875622, 53.70293252170086, 69.95137363672256, 50.36909781396389, 6.539360750466585, 0.23065243265591562, 0.07385196135146543, 0.05540239275433123, 0.059349987568566576, 0.03698394612001721, 0.04452172484889161, 0.07703954499447718, 0.06870936776977032, 0.052322776755318046, 0.08674990167492069, 0.0359634670894593, 0.04638720580260269, 0.015657792719139252, 0.06328175237285905, 0.03412416910578031, 0.01062243112755823, 0.03150663280393928, 0.02322744669072563, 0.009878901200863766, 0.05740785018133465, 0.01125475115259178, 0.04461159522179514, 0.033670008124317974, 0.046701149112777784, 0.018823546088242438, 0.05750114185502753, 0.04942386629409157, 0.08796279362286441, 0.05862574420461897, 0.05270958412438631, 0.03223172221623827, 0.04619993967935443, 0.034988574479939416, 0.04968094624928199, 0.05176092643523589, 0.05012707719288301, 0.029692567841266282, 0.10625924231135286, 0.03015811522345757, 0.02907452580984682, 0.017126300735981204, 0.04095601696462836, 0.05143025511642918, 0.025840700800472405, 0.016480181402585004, 0.04514327352808323, 0.038259631182882003, 0.01069854486559052, 0.08388045447645709, 0.03678739201859571, 0.030281174440460745, 0.10312991726095788, 0.01748033486364875, 0.3680482803611085, 3.4770231368020177, 42.81751222908497, 89.66026246547699, 105.22452369332314, 93.40594187378883, 84.17980894446373, 82.3790855705738, 65.58110654354095, 22.873404622077942, 48.14415380358696, 48.461774960160255, 49.59316045045853, 69.47491720318794, 63.35157997906208, 36.98557756841183, 2.184088840149343, 0.6216670072171837, 0.1965195915545337, 0.24492894939612597, 0.11610203524469398, 0.09358334515127353, 0.18293077853741124, 0.08625045855296776, 0.20300943549955264, 0.3251965547678992, 0.5537110974546522, 0.08760648852330633, 1.1258103582076728, 0.8899576670955867, 0.5115573469083756, 8.28610897064209, 38.86296182870865, 75.41003152728081, 94.12569925189018, 98.9826138317585, 92.96978607773781, 94.4682888686657, 93.00565615296364, 93.50172713398933, 96.02627366781235, 92.50232756137848, 93.03918555378914, 95.25192841887474, 95.7478778064251, 95.67891910672188, 100.34407317638397, 101.94423571228981, 97.75562927126884, 100.77816188335419, 93.66892576217651, 89.47477921843529, 84.62155044078827, 83.82822141051292, 83.4764514863491, 95.98468109965324, 103.27461272478104, 58.04592467844486, 5.913986032828689, 1.4423813461326063, 11.513256803154945, 11.803310438990593, 4.8103096056729555, 3.4367362735792994, 1.4976978278718889, 3.5418234346434474, 37.65972599387169, 78.36236670613289, 97.80243515968323, 99.94240432977676, 95.15133261680603, 92.29146927595139, 91.56832247972488, 89.2437744140625, 92.35488787293434, 90.44172093272209, 89.39800053834915, 93.12262907624245, 90.78138470649719, 85.28568640351295, 91.19417935609818, 99.60376650094986, 98.02780106663704, 88.64966869354248, 76.5283191204071, 71.00911527872086, 67.25780457258224, 60.170120894908905, 36.265535205602646, 10.954621229320765, 6.671123430132866, 7.0060450583696365, 6.703942269086838, 5.766751058399677, 0.8683717378880829, 0.43278659402858466, 0.9624844940844923, 0.6080572062637657, 0.3326807578559965, 1.4853465906344354, 0.47142229741439223, 0.08094117118162103, 0.41938230860978365, 0.060218081416678615, 0.07606141662108712, 0.032616247481200844, 0.28556984674651176, 0.12321825182880275, 0.02912920910603134, 1.4712031558156013, 36.7655997723341, 77.17882141470909, 39.46073815226555, 26.224249117076397, 48.51062133908272, 30.486962981522083, 31.58564742654562, 46.22024863958359, 60.59344857931137, 73.62678721547127, 83.99561762809753, 70.69398298859596, 13.782578632235527, 0.11555686840438284, 0.024232366595242638, 0.07349582694587298, 0.02151611723093083, 0.05760126128734555, 0.03902658514562063, 0.038743834302295, 0.045024518767604604, 0.03280953242210671, 0.010931590368272737, 0.04870026859862264, 0.015223946174955927, 0.030730602375115268, 0.0651168312469963, 0.01903093925648136, 0.020349763508420438, 0.028996199544053525, 0.04571528384985868, 0.06703219565679319, 0.02324117271200521, 0.06032588207744993, 0.015342044134740718, 0.036928537374478765, 0.024458146472170483, 0.011225653397559654, 0.09256997218471952, 0.02524446306779282, 0.045771408767905086, 0.12604474351974204, 0.1979530497919768, 0.08761680437601171, 0.13905862957471982, 0.16208385030040517, 0.2078012900892645, 0.23593080957653, 0.1536708790808916, 0.08226803474826738, 0.273213978507556, 0.1628059896756895, 0.15412519220262766, 0.17150139261502773, 0.16144771099789068, 0.06348876704578288, 0.1825175655540079, 0.13981812866404653, 0.11143833471578546, 0.14899043570039794, 0.16410047333920375, 0.21744453435530886, 0.1390417679795064, 0.08773922905675136, 0.21153217036044225, 0.11098873423179612, 0.5194322462193668, 4.377233544364572, 51.70352540910244, 105.70756137371063, 110.68331077694893, 96.87765598297119, 83.33963602781296, 73.40405836701393, 64.1851070523262, 53.07232975959778, 114.66599866747856, 62.034015879034996, 62.0470529794693, 99.94590774178505, 83.37544530630112, 59.61588643491268, 6.07660305686295, 1.2896222993731499, 0.4325337294721976, 0.43414591171313077, 0.41874147893395275, 0.2702190860873088, 0.44749610940925777, 0.35497181641403586, 0.4014196037314832, 1.1138950288295746, 3.293298245407641, 2.5181284407153726, 6.667588194832206, 3.8477134332060814, 0.5196351790800691, 6.211237907409668, 38.35327237844467, 76.19181677699089, 98.57313260436058, 104.54915553331375, 96.58609002828598, 95.45556709170341, 92.22143903374672, 92.85199239850044, 96.33439913392067, 93.02151650190353, 98.26012820005417, 97.733294069767, 99.70417991280556, 100.18484652042389, 100.87302759289742, 105.83703562617302, 101.38773277401924, 102.01892450451851, 96.32109224796295, 86.84364840388298, 86.95580318570137, 82.0010894536972, 86.40801697969437, 108.79294261336327, 107.22561031579971, 49.00163099169731, 4.544599363580346, 8.36468305438757, 24.97388631105423, 18.38776431977749, 13.038917686790228, 13.347276840358973, 5.700957113876939, 2.4945682799443603, 34.2951775342226, 76.03220254182816, 95.9265062212944, 97.06973567605019, 92.89084911346436, 90.89702770113945, 90.09198769927025, 89.12960574030876, 93.09717044234276, 90.00399202108383, 91.25063672661781, 93.5089011490345, 90.09402438998222, 81.30947336554527, 89.22519341111183, 99.08168971538544, 100.18293142318726, 93.48455965518951, 82.08240509033203, 80.0388215482235, 76.15713983774185, 64.68464344739914, 39.023374021053314, 12.360097412019968, 8.284451309591532, 8.477812483906746, 7.895307540893555, 5.965399174019694, 1.384807073045522, 1.0652107349596918, 2.781892712228, 2.8475776500999928, 2.291757012717426, 2.1528583159670234, 0.6499765568878502, 0.25115349038969725, 0.33804259670432657, 0.2547428134130314, 0.24469463853165507, 0.1556275217444636, 0.3711610258324072, 0.22401809255825356, 0.1267258421285078, 4.954646285623312, 51.69437550008297, 83.37550610303879, 54.33560237288475, 40.755252689123154, 86.65333181619644, 63.01868364214897, 38.87820661067963, 40.807150304317474, 62.01700799167156, 71.56337633728981, 89.51000332832336, 79.47759926319122, 14.008227623999119, 0.31534374284092337, 0.21542148431763053, 0.13155352760804817, 0.13966401427751407, 0.08784689984167926, 0.1472119678510353, 0.1277832838241011, 0.15229058830300346, 0.12763743696268648, 0.21269452205160633, 0.10323541355319321, 0.19445564917987213, 0.12203160964418203, 0.12393616838380694, 0.1273750135442242, 0.13731533952523023, 0.208836734527722, 0.10226846192381345, 0.196612345171161, 0.22338569368002936, 0.3081933280918747, 0.12048320757457986, 0.1383737163268961, 0.12712394498521462, 0.1772689339122735, 0.14707495254697278, 0.1006489027349744, 0.22360617091180757], [0.011674136949295644, 0.05566237821767572, 0.06944836874026805, 0.04298677420592867, 0.03596336689952295, 0.037515487128985114, 0.03572567555238493, 0.05353315282263793, 0.06286548916250467, 0.03528928158630151, 0.03261028803535737, 0.02000910844799364, 0.11004648869857192, 0.047261956715374254, 0.056070240316330455, 0.058492335738264956, 0.05138717715453822, 0.06215663051989395, 0.05060774397861678, 0.03833778675470967, 0.10951929667498916, 0.05335539361112751, 0.02292024208145449, 0.08636014055809937, 0.132613685564138, 6.887680934742093, 48.22712995111942, 81.83686226606369, 81.15547522902489, 76.5789096057415, 69.9144472181797, 52.46849276125431, 37.27223798632622, 33.277801126241684, 92.37983733415604, 71.8808189034462, 25.53294651210308, 73.02375197410583, 70.22434338927269, 50.3432098031044, 4.287254847586155, 0.5879976076539606, 0.05369008365960326, 0.08731458699912764, 0.18370856414549053, 0.24321435077581555, 0.16877368820132688, 0.26288004708476365, 0.26194933452643454, 0.2551599300932139, 0.18952265294501558, 0.4359375749481842, 0.4215294012101367, 2.3301123920828104, 15.470573455095291, 45.7372185587883, 65.63884064555168, 81.46621495485306, 85.14660626649857, 90.42960718274117, 87.60226249694824, 88.7891136109829, 91.37575641274452, 94.04160216450691, 91.28837630152702, 91.09785452485085, 89.30443435907364, 88.23881953954697, 88.30946534872055, 82.89001375436783, 80.30035391449928, 85.24348586797714, 87.03853234648705, 88.01862135529518, 84.9505215883255, 85.34946978092194, 89.82964217662811, 93.33924025297165, 93.20457547903061, 93.3848226070404, 84.47436913847923, 84.5828153192997, 104.71040368080139, 76.80736094713211, 3.121046363376081, 3.0956414015963674, 5.126142483204603, 4.159405957907438, 2.7723875222727656, 6.4231544360518456, 43.73189136385918, 91.07529133558273, 90.22996589541435, 85.16467049717903, 84.21722933650017, 87.61120721697807, 86.87317281961441, 91.78095147013664, 89.1401843726635, 91.72917544841766, 90.04928559064865, 92.9666018486023, 85.41739493608475, 85.13328418135643, 79.07683476805687, 78.81385087966919, 76.73078745603561, 76.94688946008682, 70.0062046945095, 71.88220202922821, 70.99995017051697, 74.03414815664291, 77.47468873858452, 74.56199303269386, 67.55593657493591, 58.235713094472885, 43.688345700502396, 46.78914271295071, 46.98444463312626, 34.80806641280651, 13.998361453413963, 2.396982153877616, 1.112279046792537, 0.3467100503621623, 0.3953234839718789, 0.3178552002646029, 0.01306819642195478, 0.2599078050116077, 0.13452223705826327, 0.21574219601461664, 0.10432933922857046, 0.2503693668404594, 0.04758574090374168, 0.045187234645709395, 0.12426367815351114, 2.8076413180679083, 51.7798937112093, 85.10138869285583, 52.275356724858284, 31.866701245307922, 49.410508051514626, 38.816121742129326, 26.565753892064095, 34.514015391469, 44.16460454463959, 51.815683990716934, 65.25961339473724, 59.079416021704674, 9.095020964741707, 0.26955691224429756, 0.06300176231889054, 0.04449628402653616, 0.022675088439427782, 0.10901198678766377, 0.029752624286629725, 0.028391781488608103, 0.028011915055685677, 0.0547497963270871, 0.0043747750169131905, 0.009274713211198105, 0.0863728832337074, 0.021842484093212988, 0.05841339720063843, 0.014513888963847421, 0.057359321144758724, 0.004112955521122785, 0.03957423446991015, 0.060591615474550053, 0.04934927303111181, 0.02750798565102741, 0.026207889495708514, 0.01697548334050225, 0.009770123688213062, 0.03636380009993445, 0.0482934714818839, 0.04941758401400875, 0.04745341597299557, 0.024506389781890903, 0.007170877152020694, 0.016159148726728745, 0.006693445666314801, 0.08177082549082115, 0.03872941066219937, 0.01811394715332426, 0.07851382877561264, 0.020673699837061577, 0.03533189570589457, 0.060863994804094546, 0.020607943697541486, 0.10494354806724004, 0.04087115237780381, 0.05403964634751901, 0.0463510409463197, 0.013436955687211594, 0.019585429326980375, 0.021004219015594572, 0.04144597543927375, 0.01817656771891052, 0.046406453402596526, 0.11813497811090201, 0.22206499736057594, 12.127332352101803, 66.006128937006, 97.23766386508942, 96.5455462038517, 102.37811923027039, 97.21225842833519, 75.76319977641106, 53.552187010645866, 15.262467171996832, 54.784662276506424, 79.87034618854523, 38.434447422623634, 76.37460216879845, 67.93927520513535, 43.27160686254501, 2.222751290537417, 0.3649593429872766, 0.10495571186766028, 0.14277310838224366, 0.16143751388881356, 0.19044919463340193, 0.1277655761805363, 0.11563109059352428, 0.14363806665642187, 0.46768053725827485, 0.5357869248837233, 1.2068452849052846, 0.9307744831312448, 4.277306981384754, 24.69906035810709, 63.92266273498535, 83.80720853805542, 94.0304383635521, 91.70443117618561, 97.08068668842316, 94.98994007706642, 95.77241688966751, 99.36766237020493, 100.79615011811256, 96.79751068353653, 96.30331680178642, 94.38698843121529, 93.2723106443882, 90.72274625301361, 88.61913353204727, 83.90088111162186, 91.69177025556564, 89.75778803229332, 91.59120485186577, 87.32804641127586, 89.00908380746841, 90.56422635912895, 96.54191359877586, 96.13807126879692, 95.56526720523834, 89.05895993113518, 87.23071843385696, 103.63727286458015, 90.8465588092804, 7.771118329837918, 1.5066659403964877, 2.071512518450618, 0.3450521221384406, 1.9522390561178327, 10.19076531752944, 55.8604833483696, 98.39133515954018, 95.06439328193665, 92.37941175699234, 89.01539906859398, 94.26980271935463, 93.33281099796295, 96.6895280778408, 95.06081387400627, 96.2374359369278, 96.4657960832119, 97.93311774730682, 92.86153748631477, 91.82423874735832, 83.40102553367615, 84.22038316726685, 85.22102907299995, 84.5974749326706, 79.97489377856255, 85.7426118850708, 84.84734952449799, 85.88428348302841, 87.17776447534561, 87.3700949549675, 84.87549841403961, 76.55177906155586, 59.1801942139864, 59.9531639367342, 56.791471391916275, 46.24485991895199, 22.315222173929214, 3.853187276981771, 0.46506868209689856, 0.2548105566529557, 0.533990393159911, 0.20228078006766737, 0.3910585690755397, 0.5183247243985534, 0.3347250778460875, 0.3537837864132598, 0.04419050434080418, 0.2034722684766166, 0.07828818619600497, 0.010910456785495626, 0.08423364255577326, 0.5345812614541501, 46.180217787623405, 96.09753504395485, 52.470803037285805, 21.187860667705536, 33.41805540025234, 27.859061993658543, 32.188642770051956, 54.50502768158913, 66.59206509590149, 74.76080596446991, 76.06677308678627, 74.84905242919922, 19.268425963819027, 0.2596842701314017, 0.012119368966523325, 0.043404154348536395, 0.05752739161835052, 0.05232484363659751, 0.053840594919165596, 0.10518253446207382, 0.023605598762515, 0.03607943137467373, 0.027324903385306243, 0.04886269503913354, 0.042150106601184234, 0.008642479460831964, 0.02596434631414013, 0.0432675546471728, 0.03605471414630301, 0.02281161392602371, 0.011273349373368546, 0.041553805785952136, 0.0513755625433987, 0.04816659391508438, 0.020794204210687894, 0.011279829250270268, 0.06984088322496973, 0.040444651240250096, 0.005830910504300846, 0.10082335938932374, 0.1041605303180404, 0.13675348920514807, 0.20960908761480823, 0.1267470230231993, 0.13412716216407716, 0.14637298474553972, 0.12410078415996395, 0.12217111856443807, 0.185369772661943, 0.09838751197094098, 0.14105969719821587, 0.15904729370959103, 0.2591152803506702, 0.15330828056903556, 0.10152603223104961, 0.22302613797364756, 0.17053352814400569, 0.07428898243233562, 0.1816418461385183, 0.11299715653876774, 0.16132151620695367, 0.13633834663778543, 0.3333956835558638, 0.18735256860964, 0.2553990203887224, 13.836900517344475, 81.26161873340607, 114.43087488412857, 106.23200923204422, 100.0320415198803, 92.47864723205566, 73.30849349498749, 56.067074462771416, 50.66493093967438, 132.62986153364182, 103.60809043049812, 43.33619199693203, 94.93267714977264, 89.93949428200722, 67.65277817845345, 7.349817361682653, 1.03856454603374, 0.22168010473251343, 0.2197177178459242, 0.2853484492516145, 0.3740502067375928, 0.4252779297530651, 0.4723099060356617, 0.43613789544906467, 0.969267605105415, 0.9596678358502686, 1.9766975124366581, 1.0224740719422698, 2.6360669871792197, 21.635605841875076, 65.36946550011635, 88.64903792738914, 98.8436096906662, 95.08708566427231, 96.97230890393257, 94.58583936095238, 95.14345943927765, 99.34648990631104, 102.25646495819092, 99.84772861003876, 98.23138654232025, 96.73996657133102, 96.31975471973419, 91.68734729290009, 88.54955926537514, 87.3080138862133, 91.78403690457344, 92.10157066583633, 91.73389479517937, 88.93251031637192, 94.84436228871346, 97.67220094799995, 102.92092770338058, 100.80854505300522, 97.984718978405, 90.39980918169022, 90.08981421589851, 110.49322217702866, 89.6407999098301, 4.703978011384606, 6.040046643465757, 12.829725611954927, 10.5896489135921, 4.997739773243666, 8.446807097643614, 53.397007137537, 99.76797848939896, 95.35731196403503, 93.009562343359, 92.45961785316467, 95.48544108867645, 94.65608239173889, 98.77332866191864, 94.15767833590508, 95.60186684131622, 97.96548441052437, 97.90493085980415, 92.03606978058815, 93.3977647125721, 84.30030047893524, 84.15793731808662, 84.1492509841919, 84.763845205307, 79.76166442036629, 83.54712009429932, 86.12373903393745, 86.84463635087013, 87.6897794008255, 89.43833917379379, 87.11686134338379, 76.97639107704163, 60.524687469005585, 56.93614102900028, 52.03196458518505, 40.286449044942856, 18.480329252779484, 2.8662959206849337, 1.5430857986211777, 1.761762520764023, 1.0913954861462116, 0.4884541709907353, 0.7626725127920508, 0.49104527570307255, 0.28807331866119057, 0.3919664234854281, 0.5075572896748781, 0.6377425789833069, 0.20215574302710593, 0.2164598973467946, 0.21573668927885592, 4.7197509650141, 67.11471945047379, 101.94213062524796, 66.94698125123978, 46.96738354861736, 73.1550121307373, 57.88905769586563, 42.75432921946049, 47.22773797810078, 60.907414332032204, 69.49732080101967, 82.21142336726189, 87.65219181776047, 20.62466438859701, 0.4214002378284931, 0.1733611850067973, 0.1550431695068255, 0.19353007228346542, 0.22930156061192974, 0.13351146160857752, 0.16400250984588638, 0.1101824501529336, 0.1529239074443467, 0.15538026782451198, 0.16138685488840565, 0.12481953192036599, 0.11489450160297565, 0.2329997715423815, 0.13977076479932293, 0.11070971639128402, 0.1318854308919981, 0.12877762812422588, 0.229046365711838, 0.14126408466836438, 0.12407331727445126, 0.14440093509620056, 0.1427701991633512, 0.1728395590907894, 0.13669263309566304, 0.2508752146968618, 0.24586687562987208], [0.02916967285273131, 0.0167018998763524, 0.020657598943216726, 0.03857734460325446, 0.08251664679846726, 0.06593319369130768, 0.03101459446043009, 0.022808476496720687, 0.036424719291971996, 0.04728602085378952, 0.05573938717134297, 0.05045794147008564, 0.0392986379301874, 0.052136122903903015, 0.08658812090288848, 0.03056773992284434, 0.03751979900698643, 0.007429786501234048, 0.03633957268903032, 0.10095187710248865, 0.03035271005501272, 0.060675745335174724, 0.07642575917998329, 0.056113459286279976, 7.644263561815023, 66.2585797905922, 84.32853296399117, 87.09040716290474, 69.02547731995583, 50.113990902900696, 45.393846184015274, 47.50856190919876, 32.175864055752754, 81.94952622056007, 76.49724438786507, 36.1264892667532, 62.44279034435749, 70.48672690987587, 43.949099108576775, 2.8354904986917973, 0.24617667775601149, 0.2230454041273333, 0.40373771684244275, 0.31089664553292096, 0.1491621241439134, 0.08381046252907254, 0.09866678214166313, 0.25863000482786447, 0.3384906460996717, 3.4383663861081004, 9.995035920292139, 15.632211081683636, 37.54896193742752, 62.302513271570206, 85.17715662717819, 86.50943353772163, 89.11375299096107, 86.51267856359482, 91.916064620018, 91.47527307271957, 93.39627519249916, 90.45190438628197, 89.27168771624565, 87.34842091798782, 89.24504354596138, 93.2310600578785, 92.3041681945324, 92.05218091607094, 94.38298344612122, 92.50557258725166, 87.08949521183968, 88.81156280636787, 90.84298700094223, 92.61723339557648, 91.23864457011223, 84.66904789209366, 75.62069982290268, 74.04930174350739, 81.37846246361732, 80.23676812648773, 81.93998113274574, 86.70502424240112, 83.30634221434593, 91.64762422442436, 68.6269699037075, 4.945383332669735, 0.4974935296922922, 0.4421531211119145, 11.722297836095095, 51.439029201865196, 86.34037300944328, 84.36488941311836, 81.94084748625755, 85.64484313130379, 85.09225398302078, 89.55518290400505, 85.1488709449768, 83.87571886181831, 82.57292836904526, 82.68834337592125, 85.88907122612, 85.91132283210754, 88.59109863638878, 84.35513153672218, 81.49359628558159, 83.79459321498871, 89.16084006428719, 79.7239400446415, 80.75178489089012, 81.98842853307724, 78.00301238894463, 76.43320262432098, 76.03922456502914, 75.53056105971336, 79.70993399620056, 80.32468020915985, 72.67110049724579, 82.19227999448776, 78.75805467367172, 75.52624449133873, 71.35560348629951, 51.72917403280735, 16.99515424668789, 0.4882179602282122, 1.4367121690884233, 0.27017903979867697, 0.22796532372012734, 0.04024155510705896, 0.12482019985327497, 0.0788003571506124, 0.06787212871131487, 0.2952918328810483, 0.028973825646971818, 0.013528446725104004, 0.05834648516611196, 0.5793980159796774, 1.8462273571640253, 59.56506036221981, 90.3968757390976, 82.52182111144066, 48.13929386436939, 47.199600487947464, 35.4045470058918, 18.02147727459669, 34.18720252811909, 42.75645710527897, 51.327558383345604, 58.06721493601799, 57.047782838344574, 17.09153227508068, 0.5172215960919857, 0.04629776958609, 0.005469671514219954, 0.10102962449309416, 0.06389223563019186, 0.07371748419245705, 0.03650873783044517, 0.05407371463661548, 0.06008872507663909, 0.04844266914005857, 0.07037827235762961, 0.023259449953911826, 0.0542111937829759, 0.011217853425478097, 0.10883482129429467, 0.05072537809610367, 0.04839427740080282, 0.02345766461075982, 0.05853733586263843, 0.038636634781141765, 0.05736295766837429, 0.03274100621638354, 0.005574439574047574, 0.0184881009045057, 0.03607044396630954, 0.044501556985778734, 0.042692820643424056, 0.0612840912071988, 0.05290333661832847, 0.018230234272778034, 0.008786909747868776, 0.060371832150849514, 0.023708369517407846, 0.061966113789821975, 0.041450480275671, 0.028674198365479242, 0.04102909624634776, 0.06261953400098719, 0.04207882331684232, 0.08581935981055722, 0.05190631687582936, 0.026441350601089653, 0.07452472564182244, 0.0560102302551968, 0.04524092160863802, 0.08628295719972812, 0.03777943937166128, 0.02259554690681398, 0.05622544565994758, 0.06253891449887305, 13.603692781180143, 84.55540359020233, 96.08425095677376, 100.63061580061913, 90.83607137203217, 73.80318135023117, 67.57738262414932, 63.78974586725235, 19.66390874236822, 47.48318687081337, 66.17933124303818, 42.8168510645628, 64.93831783533096, 65.74430778622627, 36.3445595651865, 1.2797628971748054, 0.3715169004863128, 0.14595794607885182, 0.24189018120523542, 0.3100313903996721, 0.03460348889348097, 0.1321835516137071, 0.2125168964266777, 0.3015227266587317, 1.6133123240433633, 9.101727604866028, 17.006086260080338, 25.19075397402048, 51.14269830286503, 79.97421741485596, 99.70931723713875, 94.75224763154984, 95.43116480112076, 94.51340764760971, 99.42790433764458, 97.02641040086746, 99.00368750095367, 95.37475302815437, 91.30772486329079, 90.59432074427605, 93.83394330739975, 97.31104552745819, 96.202622205019, 95.80659985542297, 98.93799662590027, 95.50148382782936, 92.70709097385406, 92.56673410534859, 93.15888673067093, 93.64433348178864, 92.2893413901329, 90.97806215286255, 82.98181682825089, 79.30742159485817, 84.61829021573067, 85.24621412158012, 85.96919372677803, 89.50532957911491, 89.5020617544651, 92.82423108816147, 81.65651634335518, 10.750759318470955, 0.15291883115423843, 1.217050349805504, 18.45861341804266, 62.48547725379467, 91.82843372225761, 90.78643843531609, 87.94637963175774, 89.84470456838608, 89.25135120749474, 92.98895224928856, 87.84879326820374, 85.89048475027084, 86.0086128115654, 85.40635272860527, 86.570283472538, 88.06174144148827, 90.18050014972687, 87.63203009963036, 86.01843908429146, 88.42076897621155, 92.22355172038078, 86.6334056854248, 86.47992432117462, 88.15647035837173, 82.71037459373474, 83.75433817505836, 81.36156857013702, 83.05962145328522, 84.69766035676003, 86.62072956562042, 80.04035666584969, 89.82056826353073, 84.35755580663681, 80.17621457576752, 81.18330493569374, 66.39071390032768, 27.114377953112125, 0.9172109328210354, 0.7322617946192622, 0.37756466190330684, 0.24135157495038584, 1.3031324744224548, 0.5632924614474177, 0.17438983137253672, 0.22235716605791822, 0.52829236141406, 0.057457280927337706, 0.023832584629417397, 0.04867847172135953, 0.3288485744269565, 0.5776291515212506, 54.47389975190163, 95.44028431177139, 78.9117868244648, 37.60060116648674, 35.32667778432369, 22.15992070734501, 22.3922573402524, 55.86195006966591, 60.10618932545185, 71.25220343470573, 67.41234228014946, 70.90759232640266, 28.574252016842365, 0.5944545299280435, 0.06202539283549413, 0.03730431642907206, 0.013438535534078255, 0.0580326457566116, 0.058294056143495254, 0.022086578319431283, 0.03867020954203326, 0.08013721744646318, 0.022044329707568977, 0.0625359384866897, 0.08081948864855804, 0.10867779768886976, 0.04406130756251514, 0.042429807217558846, 0.02184575510909781, 0.025605662631278392, 0.0392260892840568, 0.024595067152404226, 0.04181884156423621, 0.07664455915801227, 0.034795411993400194, 0.0411820417502895, 0.01757293448463315, 0.04779407288879156, 0.04143405283684842, 0.16024883079808205, 0.11805403206381015, 0.15535421844106168, 0.11045708932215348, 0.18950911617139354, 0.206872878188733, 0.07622776160133071, 0.08053303448832594, 0.1068280465551652, 0.11110404171631671, 0.11682130992994644, 0.1086678529100027, 0.13249936513602734, 0.1551092800218612, 0.13125037512509152, 0.09786593058379367, 0.12565167242428288, 0.2005021637887694, 0.09278066791011952, 0.16247540741460398, 0.11255946010351181, 0.2335373536334373, 0.186725661624223, 0.17735914938384667, 16.401181519031525, 98.41856449842453, 109.48354035615921, 109.74897131323814, 94.145777374506, 73.63124817609787, 63.50539952516556, 67.55545780062675, 53.708244636654854, 122.87108838558197, 112.48969584703445, 52.38006770610809, 80.6933668255806, 88.89686822891235, 57.72933326661587, 3.3768785605207086, 0.6584234442561865, 0.39265406783670187, 0.5932092061266303, 0.45468051452189684, 0.2880004100734368, 0.3225466125877574, 0.3429362294264138, 0.607825240585953, 1.0066317720338702, 6.300709331408143, 12.82053580507636, 21.009781323373318, 46.71815872192383, 78.89159470796585, 105.35539627075195, 99.44168999791145, 98.08389365673065, 93.6069130897522, 99.73794490098953, 97.74268716573715, 100.18023356795311, 97.67603114247322, 93.95142540335655, 93.02418395876884, 95.10917767882347, 99.845881909132, 98.37949499487877, 100.65041273832321, 100.11812970042229, 99.18279469013214, 98.20934772491455, 91.57379418611526, 95.9293332695961, 94.69269722700119, 95.63744813203812, 89.5468233525753, 83.170735090971, 80.59785515069962, 88.96780282258987, 89.72317948937416, 89.49766159057617, 93.7629023194313, 91.93365767598152, 96.62645146250725, 85.56574657559395, 7.2734262607991695, 2.8545706998556852, 2.2596943331882358, 15.711045451462269, 61.30339488387108, 88.51671382784843, 93.91594290733337, 88.70238706469536, 91.04469537734985, 88.73973906040192, 94.29792881011963, 88.67692843079567, 88.38498249650002, 87.11492344737053, 87.06142991781235, 88.34390670061111, 89.65184211730957, 89.4717089831829, 87.02862247824669, 83.93267020583153, 90.20010709762573, 92.88244396448135, 89.4740192592144, 87.82877594232559, 90.95457941293716, 84.56518426537514, 86.30533888936043, 86.14755615592003, 82.92539745569229, 86.71791315078735, 84.9575512111187, 78.32239285111427, 89.09729987382889, 83.68691459298134, 78.28798189759254, 78.3711214363575, 60.46285718679428, 22.918743789196014, 0.6436978094279766, 3.864003634080291, 1.7285993252880871, 1.0545321204699576, 2.12749847676605, 0.4490932705812156, 0.2880078018642962, 0.1318487391108647, 0.4715545184444636, 0.2105996321188286, 0.151070824067574, 0.1183784322347492, 0.6611528259236366, 3.3676616800948977, 73.6826366186142, 102.14450776576996, 99.89620640873909, 65.51763474941254, 69.86699536442757, 50.73786422610283, 28.967321924865246, 44.954601153731346, 57.17195637524128, 71.23706504702568, 75.42652264237404, 84.71531420946121, 34.95093494653702, 0.9491532656829804, 0.1421866484452039, 0.09172105172183365, 0.27042483910918236, 0.13939927535830066, 0.19572280696593225, 0.13361395220272243, 0.12980286061065271, 0.13577904930571094, 0.12872380757471547, 0.16366391238989308, 0.19308828661451116, 0.2372512684087269, 0.13381069555180147, 0.130711798556149, 0.14613655133871362, 0.1825519566773437, 0.11866265253047459, 0.12724479631287977, 0.19026451860554516, 0.17521262081572786, 0.19989148015156388, 0.13517716753995046, 0.13319487625267357, 0.1435232415678911, 0.13959500938653946], [0.06873720572912134, 0.03693691993248649, 0.014950743061490357, 0.02006115155381849, 0.0023771792530169478, 0.0711149800918065, 0.05194663033762481, 0.07990065787453204, 0.02630123868584633, 0.015089777007233351, 0.0026185305478065857, 0.01657118169532623, 0.026259567093802616, 0.0017945401009455964, 0.04847638490900863, 0.028479022803367116, 0.04458042873011436, 0.05918595808907412, 0.03763810847885907, 0.026840741084015463, 0.07820324739441276, 0.08423398394370452, 0.13014592579565942, 6.492750076577067, 55.70339597761631, 85.23892611265182, 85.26863291859627, 72.83784314990044, 62.158877179026604, 73.61394390463829, 37.2524144500494, 34.4027953594923, 70.60419380664825, 67.62905225157738, 71.97629258036613, 156.25591456890106, 114.28922608494759, 39.004663825035095, 2.582251662388444, 0.2516200637910515, 0.44528842787258327, 0.30840484017971903, 0.04507701829425059, 0.12228439998580143, 0.19825669209240004, 0.13536865648347884, 0.08904268528567627, 2.663963190279901, 26.697342731058598, 51.35912328958511, 59.48852486908436, 73.94162312150002, 84.18470308184624, 92.97043964266777, 90.66226869821548, 93.82176116108894, 87.70234152674675, 91.25003635883331, 89.46119114756584, 91.41173288226128, 87.77256935834885, 87.88762718439102, 86.97154194116592, 89.25111562013626, 87.73441940546036, 86.3193753361702, 90.23165300488472, 90.338054895401, 85.86559608578682, 82.66074165701866, 79.09951955080032, 85.27867957949638, 85.5678516626358, 93.58358234167099, 85.5351810157299, 87.99006208777428, 87.2268958389759, 90.15828654170036, 81.53439089655876, 84.79026898741722, 80.33391371369362, 82.89939165115356, 85.71326985955238, 88.92042696475983, 78.76980364322662, 63.75433936715126, 8.36366280913353, 8.51147772744298, 53.08939844369888, 78.27042683959007, 86.69462040066719, 84.89822119474411, 87.27763071656227, 82.96574369072914, 83.46269622445107, 82.55124673247337, 85.36177352070808, 83.32862421870232, 87.71265417337418, 87.56491050124168, 81.53138905763626, 80.32799363136292, 82.32958942651749, 78.42074677348137, 77.61021986603737, 80.82221031188965, 80.62521368265152, 77.35835418105125, 82.77992606163025, 81.47703677415848, 80.72654664516449, 77.44832575321198, 80.29242753982544, 77.7570515871048, 77.92989671230316, 76.32461205124855, 80.24865388870239, 77.53629863262177, 77.45925396680832, 75.53930059075356, 76.41047224402428, 85.1389230787754, 72.75299370288849, 39.59981828927994, 7.3200383596122265, 0.15743753087008372, 0.34478281158953905, 0.9644464356824756, 0.5070252588484436, 0.2662867127219215, 0.1583340304205194, 0.12726902001304552, 0.07144050090573728, 0.10406811066786759, 0.07425689938827418, 0.05357086134608835, 0.06589560391148552, 3.9475848991423845, 57.722128853201866, 70.02501368522644, 61.15908242762089, 33.16181614995003, 49.1999651491642, 49.61445450782776, 25.84343735128641, 40.59998162090778, 38.87203574180603, 51.25726215541363, 63.82085859775543, 60.28930529952049, 27.16500263661146, 1.147901185322553, 0.23014913778752089, 0.037105172232259065, 0.055968336018850096, 0.10584076007944532, 0.030671122949570417, 0.07396073793643154, 0.034648396249394864, 0.07744826056296006, 0.040736226219451055, 0.013772815545962658, 0.05749428441049531, 0.06969064284930937, 0.03058779089769814, 0.035866605685441755, 0.01399013957779971, 0.020433511162991636, 0.035330997707205825, 0.05734550977649633, 0.02348527250433108, 0.04610763135133311, 0.02129227064870065, 0.030596379401686136, 0.06519407397718169, 0.020786884779226966, 0.0005564827949910978, 0.03556221752660349, 0.043724866045522504, 0.06032803801645059, 0.034347421969869174, 0.028911336812598165, 0.06570363257196732, 0.041352130865561776, 0.031956519014784135, 0.020395149549585767, 0.010690386807254981, 0.047620562472729944, 0.02331740612135036, 0.01260793220353662, 0.06273535356740467, 0.08276844266219996, 0.0343339594110148, 0.02863109257305041, 0.05257548174995463, 0.030866382003296167, 0.0372432005679002, 0.09454641534830444, 0.4075409861980006, 14.41826457157731, 79.20321598649025, 92.22749590873718, 103.50532874464989, 95.52731484174728, 83.55421051383018, 82.35513165593147, 45.50087884068489, 22.060411646962166, 42.07918144762516, 70.67445203661919, 88.70784357190132, 159.0729770064354, 97.9364387691021, 30.974953696131706, 1.2808936927467585, 0.2626131410943344, 0.2319928107317537, 0.14579164562746882, 0.11137527442770079, 0.08552700557629578, 0.1254185935249552, 0.11222510031075217, 0.2723230153787881, 6.900572692975402, 37.900427877902985, 64.75702196359634, 72.26324558258057, 84.2759057879448, 94.7400426864624, 99.1133876144886, 97.01211556792259, 102.81338587403297, 97.41242408752441, 99.04585003852844, 93.5552054643631, 96.03016465902328, 91.67182892560959, 91.74261912703514, 90.79678148031235, 94.11075085401535, 92.66574159264565, 90.47069057822227, 94.79247987270355, 94.22803536057472, 86.68835073709488, 86.43672823905945, 83.06481197476387, 85.1567593216896, 86.05986446142197, 95.05455181002617, 88.63911285996437, 90.35054102540016, 90.38343966007233, 93.98540318012238, 86.73526301980019, 88.45472395420074, 83.03423881530762, 86.73897162079811, 87.27194622159004, 95.42137652635574, 83.42510104179382, 77.6166795194149, 15.470236223191023, 15.364078469574451, 64.65050607919693, 82.40653529763222, 90.45448064804077, 88.94865185022354, 91.11518159508705, 86.17604702711105, 87.84626260399818, 86.3752019405365, 90.07686451077461, 88.82241502404213, 93.49798053503036, 91.04170113801956, 86.91335946321487, 87.19597309827805, 87.11757570505142, 82.5898602604866, 81.94649398326874, 83.32442164421082, 80.94552129507065, 82.18318328261375, 85.96106976270676, 86.94748163223267, 85.60517325997353, 85.03736972808838, 87.73776322603226, 84.43830907344818, 84.71931919455528, 83.04787248373032, 86.89078107476234, 82.32772752642632, 81.86295166611671, 79.96432274580002, 79.05095055699348, 87.03562930226326, 82.79074028134346, 56.13930478692055, 12.5550602003932, 0.34446612233296037, 0.14876801404170692, 0.4564967576880008, 1.751988020259887, 1.9312442326918244, 0.7986492791678756, 0.5405611312016845, 0.1143706715083681, 0.06650086987065151, 0.07118528374121524, 0.075208213966107, 0.06261498463572934, 1.749264516402036, 58.165139481425285, 77.39431545138359, 64.8387099802494, 25.6944777444005, 30.46897664666176, 21.83998167514801, 28.00464168190956, 57.77526520192623, 55.087015852332115, 75.65400883555412, 74.85781475901604, 72.8450095653534, 39.38342750072479, 1.725204682443291, 0.2024875720962882, 0.0147576102608582, 0.08601124951383099, 0.031826739650568925, 0.11292354291072115, 0.022298598778434098, 0.016552193847019225, 0.0079119630936475, 0.03402370086405426, 0.0027624348376775743, 0.029442139384627808, 0.026077965412696358, 0.02782587533147307, 0.07817768040695228, 0.04015497244836297, 0.0422578738653101, 0.061412133945850655, 0.04569147575239185, 0.04727873296360485, 0.0783492426853627, 0.038092900285846554, 0.06344955938402563, 0.06824863507063128, 0.016346984448318835, 0.14749019901501015, 0.09023699385579675, 0.24640911840833724, 0.1770124031463638, 0.14872116968035698, 0.19722388969967142, 0.0943901042046491, 0.18793076102156192, 0.10148135494091548, 0.13216673454735428, 0.08697195968125015, 0.13216533930972219, 0.18002350407186896, 0.08919663639971986, 0.19362051039934158, 0.19552569254301488, 0.1783125419751741, 0.09380063856951892, 0.11357341194525361, 0.16859763592947274, 0.16084755101474002, 0.18830551591236144, 0.39236644108314067, 17.06530798226595, 94.26841199398041, 105.27440741658211, 111.45405381917953, 97.12626904249191, 88.72552022337914, 97.28785917162895, 55.29429852962494, 56.425516828894615, 101.172975897789, 95.32279461622238, 90.40344178676605, 182.66565263271332, 133.7363165616989, 54.23148795962334, 3.7535725347697735, 0.38624161505140364, 0.6418121606111526, 0.37324236414860934, 0.16361016605515033, 0.17300569626968354, 0.40628930961247534, 0.5814339348580688, 0.33260939293541014, 4.457999160513282, 31.915247440338135, 63.46638321876526, 76.24384358525276, 92.60827347636223, 97.91271284222603, 98.48770558834076, 94.38359901309013, 103.50567072629929, 97.87861347198486, 100.93363434076309, 96.22282192111015, 100.20799487829208, 94.06044155359268, 95.31635776162148, 93.77062350511551, 97.1775358915329, 94.51298967003822, 92.52888053655624, 97.56271362304688, 95.8267767727375, 88.60188245773315, 88.10168489813805, 83.64967659115791, 86.23916164040565, 87.522132396698, 96.51384070515633, 91.61008983850479, 94.41256105899811, 93.11471790075302, 98.72426569461823, 88.87786164879799, 91.23751223087311, 84.61753025650978, 87.76781961321831, 91.59366711974144, 99.37632590532303, 85.42775318026543, 79.84205290675163, 11.216047201305628, 12.199615873396397, 67.45749905705452, 80.09847074747086, 93.56801837682724, 90.34633845090866, 92.19056189060211, 87.66163811087608, 91.5780271589756, 89.31010365486145, 92.59992152452469, 88.98828372359276, 94.59524765610695, 92.49358803033829, 87.22305044531822, 85.60336455702782, 89.7901014983654, 84.56773772835732, 87.47729480266571, 87.14927360415459, 86.2020756304264, 84.92463737726212, 89.02953431010246, 87.32611611485481, 87.11399629712105, 85.66120505332947, 90.66767200827599, 85.84153577685356, 87.04838901758194, 85.97094163298607, 89.2157319188118, 83.86427387595177, 83.43654602766037, 81.83110937476158, 80.4826757311821, 86.89274176955223, 82.44215458631516, 53.69949750602245, 9.674414824694395, 0.5851114843972027, 1.6022927965968847, 2.0124131022021174, 1.937610909808427, 1.2519677449017763, 0.7820633472874761, 0.320866271504201, 0.40462954086251557, 0.17513401253381744, 0.1577924407320097, 0.3863683738745749, 0.26846123510040343, 6.278906101360917, 74.54656586050987, 81.23219311237335, 77.03328922390938, 46.988643407821655, 71.40694633126259, 68.05821642279625, 39.99543406069279, 54.86080639064312, 54.94318976998329, 72.63985097408295, 80.3429040312767, 84.56769973039627, 44.76622626185417, 2.2391376737505198, 0.5456066073384136, 0.08150469875545241, 0.17166620877105743, 0.18986421899171546, 0.18539322452852502, 0.1381621597101912, 0.1845552062150091, 0.22231284499866888, 0.20828583830734715, 0.12937183608300984, 0.13923845195677131, 0.20366197626572102, 0.18574734771391377, 0.16645229479763657, 0.1495160098420456, 0.1413874889840372, 0.17680565564660355, 0.16707255213987082, 0.20811863243579865, 0.21935887460131198, 0.10570523649221286, 0.14117524959146976, 0.21202299714786932, 0.10675719371647574], [0.07903571444330737, 0.09986229299101979, 0.05338108676369302, 0.060625950936810113, 0.028341000033833552, 0.05651213359669782, 0.058412614234839566, 0.008319926309923176, 0.04042121050588321, 0.012783430647687055, 0.0333900106488727, 0.04931890063744504, 0.07735546241747215, 0.0759590818779543, 0.04231736071233172, 0.0473985452845227, 0.011521548603923293, 0.011066560127801495, 0.02839415265043499, 0.073457977414364, 0.08865475727361627, 0.4143103526439518, 19.36991471797228, 71.12384632229805, 80.99712252616882, 85.07169708609581, 59.32736411690712, 59.92903143167496, 51.4693895727396, 58.201343938708305, 51.530209109187126, 73.40033456683159, 56.40178710222244, 70.22320345044136, 126.032275557518, 71.46797105669975, 21.653913259506226, 2.1659170277416706, 0.13872257026378065, 0.12521209835540503, 0.011270414179307409, 0.03662510287540499, 0.17217671731486917, 0.44448453350923955, 0.4766521230340004, 0.18610351922689006, 5.080040032044053, 41.57184027135372, 72.19437047839165, 70.17918661236763, 64.57917630672455, 74.09216344356537, 89.06360328197479, 99.65812638401985, 97.25803077220917, 91.52833342552185, 93.90334278345108, 91.02710232138634, 88.15640956163406, 88.30697268247604, 85.50011649727821, 87.27755472064018, 87.40506067872047, 88.21856662631035, 86.76549419760704, 91.76527351140976, 87.35348224639893, 85.82412511110306, 84.2864540219307, 84.76472675800323, 81.38087913393974, 81.20809480547905, 82.83975765109062, 88.75187560915947, 85.26888370513916, 83.46271142363548, 81.20011523365974, 83.42003971338272, 82.61863231658936, 75.14498054981232, 77.80759647488594, 86.00890919566154, 76.71401515603065, 82.40456700325012, 86.19510680437088, 75.509844571352, 53.61631236970425, 47.61846341192722, 61.25080190598965, 76.00365087389946, 82.71639347076416, 81.15028470754623, 84.35451596975327, 81.38887390494347, 78.8046857714653, 81.49912118911743, 86.1893767118454, 85.78344449400902, 84.84139904379845, 85.36311104893684, 87.91082873940468, 83.09240609407425, 81.10733181238174, 80.22369682788849, 77.66569688916206, 79.9847960472107, 74.05799567699432, 78.34190860390663, 79.2454545199871, 76.98941677808762, 79.95078027248383, 78.42906832695007, 77.57951751351357, 78.95853951573372, 76.6531728208065, 73.94554451107979, 77.05821588635445, 79.90766778588295, 78.29783856868744, 75.5064095556736, 74.70382422208786, 72.60921701788902, 77.5422415137291, 82.06921979784966, 72.88886681199074, 28.453598991036415, 0.7233518071006984, 1.12999951466918, 0.9203490894287825, 0.6612108321860433, 0.4077934945235029, 0.6425861909519881, 0.02499231468391372, 0.14603722229367122, 0.037441016320372, 0.42080286832060665, 0.10992162977345288, 0.15734620217699558, 10.375239718705416, 71.26420319080353, 70.44814378023148, 59.03686970472336, 39.61726315319538, 58.85810449719429, 56.223477870225906, 30.518888868391514, 33.608402386307716, 41.20413780212402, 49.20966602861881, 65.02312928438187, 59.792470559477806, 35.3357744961977, 3.3040625927969813, 0.1049513925681822, 0.1538152268039994, 0.06625553069170564, 0.14388929848792031, 0.09291326001402922, 0.09357377886772156, 0.024197112725232728, 0.058052078893524595, 0.04170148946286645, 0.02033031552855391, 0.062285344902193174, 0.030591831891797483, 0.059986293854308315, 0.04858693893766031, 0.04575438018946443, 0.060911562759429216, 0.010493090558156837, 0.043890839951927774, 0.049173795923707075, 0.055813412691350095, 0.03487555652100127, 0.037947814125800505, 0.02201410574343754, 0.04058771504787728, 0.06540022775880061, 0.05874280686839484, 0.0031151576831689454, 0.03732494813448284, 0.05497192483744584, 0.07664958349778317, 0.021830865771335084, 0.05895031506952364, 0.02365902782912599, 0.034288068709429353, 0.05538297446037177, 0.058216698380419984, 0.08948246715590358, 0.04744923397083767, 0.09858332021394745, 0.016834072666824795, 0.014970033334975597, 0.00783373330705217, 0.0026376545338280266, 0.06476923153968528, 1.1117802048102021, 34.904163256287575, 92.12202116847038, 93.37218448519707, 103.07851284742355, 83.74435231089592, 79.78605151176453, 74.55598175525665, 74.36846181750298, 32.6046634465456, 37.63095013797283, 56.15702323615551, 87.22798258066177, 126.97962552309036, 64.54682484269142, 18.496548682451248, 1.22820203891024, 0.18885439349105582, 0.1361871266271919, 0.039197754085762426, 0.02111647256242577, 0.35738275735639036, 0.46159629186149687, 0.2000375051284209, 0.23136093135690317, 11.083645205944777, 52.9605283588171, 82.34927996993065, 79.92462247610092, 78.37252736091614, 86.36149227619171, 95.93991190195084, 103.77260640263557, 104.33778047561646, 95.57709977030754, 97.04648092389107, 94.88467052578926, 93.13804104924202, 92.94709369540215, 94.86496478319168, 92.23304361104965, 91.0562315583229, 90.34545689821243, 88.34367871284485, 94.35500174760818, 91.33768245577812, 87.35557213425636, 87.17253595590591, 87.70737245678902, 87.22150012850761, 83.49962264299393, 85.32077372074127, 90.56437835097313, 90.63435539603233, 87.59710997343063, 85.29287561774254, 86.58832490444183, 85.93241930007935, 79.8829311132431, 82.80160769820213, 87.39940658211708, 82.3524110019207, 84.5801554620266, 92.61644303798676, 80.47664925456047, 61.50683976709843, 54.30071264505386, 66.23274117708206, 83.80638778209686, 88.0450527369976, 87.32630610466003, 86.03350147604942, 84.07406821846962, 83.92786726355553, 86.85080721974373, 89.98365551233292, 87.60464116930962, 86.07560321688652, 87.7604328095913, 87.73100718855858, 83.44391763210297, 82.52286225557327, 82.58851513266563, 82.92938724160194, 82.05848157405853, 79.44274753332138, 83.02810594439507, 83.90703678131104, 82.56063222885132, 82.63903722167015, 81.5388822555542, 81.78611978888512, 81.33934736251831, 81.66852369904518, 79.64827090501785, 80.37981525063515, 82.64881789684296, 83.04936200380325, 82.19911202788353, 83.30896407365799, 78.84839102625847, 79.74328860640526, 87.72093012928963, 86.39914825558662, 43.17389130592346, 1.750370019581169, 0.47036503383424133, 1.2771193077787757, 0.820420685922727, 0.8650919201318175, 2.1789674274623394, 0.11484983173431829, 0.3571024927077815, 0.13229767908342183, 0.33684773894492537, 0.23399368539685383, 0.22645769524388015, 7.499964879825711, 75.35090669989586, 79.44059684872627, 60.163114070892334, 36.65660262107849, 48.67238245904446, 22.751332372426987, 27.758192606270313, 51.117843836545944, 57.3976718634367, 68.83266046643257, 79.8638865351677, 71.66958063840866, 53.86848583817482, 5.148259671404958, 0.06802335614338517, 0.18590814142953604, 0.05587591636867728, 0.1178502976836171, 0.05795240846055094, 0.03314683483040426, 0.06017886262270622, 0.03473106407909654, 0.08178727890481241, 0.049250545125687495, 0.040657848003320396, 0.027278830857540015, 0.05535703639907297, 0.013359099757508375, 0.0652158931188751, 0.027864162730111275, 0.008011832051124657, 0.03345680393977091, 0.08093927128356881, 0.009730978181323735, 0.034573869779706, 0.02705906608753139, 0.056275381066370755, 0.16629115969408303, 0.21747720369603485, 0.19942460989113897, 0.14534824207657948, 0.16356599342543632, 0.15824461646843702, 0.11957068505580537, 0.12031212769215927, 0.2771030698204413, 0.16181833954760805, 0.07113921121344902, 0.17966801533475518, 0.1607620407594368, 0.17879596212878823, 0.2179906956735067, 0.23435653623891994, 0.10043407324701548, 0.10463334518135525, 0.13941474171588197, 0.12366905459202826, 0.20138904510531574, 1.151712618302554, 37.2435837239027, 107.64124721288681, 105.71510776877403, 109.72890079021454, 83.09738382697105, 79.6234430372715, 70.74500665068626, 88.06481927633286, 84.1422213613987, 105.68210273981094, 85.30998229980469, 88.60867649316788, 140.98377406597137, 83.90998542308807, 34.01721104979515, 2.8484969632700086, 0.3450244548730552, 0.3189289988949895, 0.10072688761283644, 0.17398850759491324, 0.2321594674140215, 0.9936499467585236, 0.8548049221280962, 0.5539743520785123, 7.516643134877086, 50.479174107313156, 89.41851183772087, 90.57218313217163, 84.39616173505783, 86.06047242879868, 93.86137023568153, 103.36184084415436, 106.1237682402134, 100.07587596774101, 101.29439458251, 97.18168526887894, 95.17283946275711, 97.66702562570572, 96.73219218850136, 95.12341931462288, 92.97875359654427, 91.81682914495468, 90.07690250873566, 96.13924160599709, 90.61250656843185, 88.5388134419918, 88.33753064274788, 90.0942675769329, 89.25917118787766, 84.84335973858833, 88.65321770310402, 94.96097803115845, 93.17452669143677, 90.19465059041977, 86.21197029948235, 89.93732079863548, 88.4678940474987, 81.55961394309998, 87.57319405674934, 93.53904113173485, 80.39796307682991, 88.84180918335915, 93.95526319742203, 81.55915796756744, 68.21531519293785, 60.16863897442818, 69.02497574687004, 80.91646805405617, 89.19345751404762, 86.79399266839027, 90.42342111468315, 85.9853808581829, 86.26877725124359, 87.29281470179558, 90.92372506856918, 87.24555283784866, 88.33699867129326, 90.05623161792755, 90.40059953927994, 86.847615391016, 83.9325562119484, 83.91864895820618, 82.45055213570595, 83.59659343957901, 80.87891846895218, 83.79444122314453, 84.40427049994469, 83.1392651796341, 86.90133690834045, 86.01382613182068, 84.8209485411644, 84.67862337827682, 82.77557149529457, 80.98225772380829, 82.7695906162262, 86.41414985060692, 86.37826457619667, 83.78674283623695, 85.05833700299263, 80.32084241509438, 81.51518672704697, 87.61691451072693, 84.49232697486877, 39.495540484786034, 0.8144479407928884, 3.1198722263798118, 4.488977948203683, 2.117689778096974, 2.5825722701847553, 1.358539795037359, 0.1640576365753077, 0.24825086176861078, 0.27249059232417494, 0.7256425498053432, 0.2924862178042531, 0.424330088426359, 15.831495188176632, 90.71589902043343, 84.22296702861786, 75.94141021370888, 55.175015330314636, 86.47929355502129, 74.26439300179482, 44.58192095160484, 48.32638442516327, 58.82272459566593, 69.20516967773438, 84.75718036293983, 81.81449666619301, 61.528190821409225, 6.772114410996437, 0.3402891370933503, 0.23944535379996523, 0.20485543878749013, 0.2084573931642808, 0.17349633009871468, 0.1846607544575818, 0.11412774430937134, 0.15437842783285305, 0.16025662334868684, 0.11927375177037902, 0.1586865505669266, 0.0828684247971978, 0.11242763241170906, 0.139135783247184, 0.12018979949061759, 0.21998189273290336, 0.1344464044086635, 0.1698324954486452, 0.1659990058396943, 0.13742784911300987, 0.10079598898300901, 0.16731985058868304, 0.11576216129469685], [0.005868405196451931, 0.04943828251271043, 0.028215840538905468, 0.048289931437466294, 0.0722692497947719, 0.02671372436452657, 0.05191808733798098, 0.046494987909682095, 0.053376055002445355, 0.08894046186469495, 0.049542305641807616, 0.05662201227096375, 0.05824684070830699, 0.14445545326452702, 0.03402872520382516, 0.016464015570818447, 0.06191100932483096, 0.06235160384676419, 0.032697215792723, 0.06220723756996449, 0.45443904935382307, 31.08815722167492, 83.41945454478264, 76.64906144142151, 71.74108520150185, 67.04495519399643, 51.4226558804512, 44.49965916574001, 40.89055962860584, 30.30950490385294, 51.20472997426987, 71.68649733066559, 83.88897255063057, 95.27885377407074, 46.166523322463036, 18.19595631211996, 4.076237920671701, 0.24894478468922898, 0.06381526007317007, 0.12108309296309017, 0.07939839459140785, 0.14222402300219983, 0.4692866635741666, 0.5999249301385134, 0.0964803779788781, 4.859726428985596, 47.27365851402283, 79.18349504470825, 72.83274382352829, 68.31222519278526, 84.78020712733269, 96.23699516057968, 105.01612767577171, 96.2393282353878, 91.5363509953022, 90.26759907603264, 88.65624234080315, 87.50762477517128, 85.71562573313713, 89.0539138019085, 88.65975335240364, 91.15227520465851, 91.9400717318058, 92.62088879942894, 90.08412212133408, 87.60967969894409, 88.33813861012459, 86.6726803779602, 89.27081376314163, 86.74263462424278, 86.45429089665413, 83.90629202127457, 81.64773881435394, 78.47550943493843, 84.07480537891388, 84.81974020600319, 86.58072531223297, 79.72894057631493, 82.23660841584206, 79.75460439920425, 77.08065748214722, 74.86265569925308, 83.76974254846573, 78.42255547642708, 83.52321177721024, 77.17093303799629, 47.74264074862003, 41.597371101379395, 68.72816607356071, 85.2973821759224, 78.40998575091362, 84.29293647408485, 79.76945400238037, 80.09685963392258, 82.7276560664177, 81.5653820335865, 83.249801248312, 79.74483132362366, 81.49028286337852, 84.75699037313461, 81.84896841645241, 80.89021906256676, 76.35071665048599, 77.76573032140732, 80.6909729540348, 75.85056468844414, 78.9619517326355, 80.73507338762283, 79.74055275321007, 83.24932247400284, 78.4672486782074, 79.75196734070778, 76.80999040603638, 77.35909134149551, 76.70623317360878, 77.92016163468361, 75.46914875507355, 73.54733347892761, 73.5684983432293, 76.84423416852951, 74.86300528049469, 77.56990402936935, 71.94961801171303, 72.36135631799698, 78.41123968362808, 83.56145292520523, 51.2513192743063, 2.759549436159432, 3.352997791953385, 3.4012872632592916, 1.7234332649968565, 2.2049395088106394, 1.2312238267622888, 0.1550950456294231, 0.07411081503960304, 0.044606389055843465, 0.026422936061862856, 0.19318967883009464, 0.10558626279816963, 15.21891200914979, 66.6545033454895, 62.41974838078022, 64.37749072909355, 42.784108221530914, 59.24275405704975, 44.35101494193077, 26.16574175655842, 32.06716328859329, 44.004066959023476, 51.00911647081375, 60.27513965964317, 66.41959995031357, 37.41338901221752, 6.157485041767359, 0.05100581343867816, 0.07656625515664928, 0.005704407722078031, 0.014165925604174845, 0.06206812940945383, 0.03729292075149715, 0.008872666767274495, 0.10489615451660939, 0.03323606324556749, 0.07855857285903767, 0.039762094311299734, 0.038825362935313024, 0.027481652396090794, 0.04269826058589388, 0.008379436349059688, 0.04863664427830372, 0.022143076166685205, 0.02921013659943128, 0.023722503719909582, 0.04196402420348022, 0.12425152919604443, 0.055174753797473386, 0.06186048762174323, 0.05905924379476346, 0.06228861035197042, 0.028243492961337324, 0.02789598973322427, 0.05747068040363956, 0.01623979420401156, 0.01965103147085756, 0.026291104659321718, 0.03558385113137774, 0.024787836300674826, 0.004197198559268145, 0.042816184140974656, 0.01600820331077557, 0.02492687024641782, 0.05272805989079643, 0.03152186909574084, 0.035776820659521036, 0.03167315218888689, 0.031520050833933055, 1.2955302698537707, 50.47896891832352, 99.83625322580338, 87.0179982483387, 87.68082708120346, 89.27381560206413, 66.78075537085533, 65.75185418128967, 47.75012254714966, 19.789896681904793, 31.581986322999, 64.6580296754837, 89.3549032509327, 94.48854938149452, 48.199133053421974, 24.106782339513302, 3.8481451850384474, 0.08881201094482094, 0.06492187647381797, 0.12916416832013056, 0.12317440574406646, 0.7489887345582247, 0.4155704006552696, 0.43345571437384933, 0.15866213390836492, 8.753608334809542, 58.75808246433735, 89.26120787858963, 83.88801500201225, 81.71194016933441, 99.16465446352959, 105.21294951438904, 107.87014693021774, 98.46470922231674, 95.86405277252197, 94.10803779959679, 94.81105327606201, 91.78491845726967, 91.62709772586823, 93.8421280682087, 93.94821837544441, 94.38740640878677, 93.84125411510468, 95.906443297863, 93.24878230690956, 89.34789642691612, 92.14092895388603, 90.69754600524902, 92.20357239246368, 91.07312545180321, 90.19192233681679, 87.9177975654602, 83.12515273690224, 81.70083716511726, 86.67480066418648, 88.04000660777092, 91.90272733569145, 85.34342810511589, 88.38961064815521, 84.22971546649933, 78.59941318631172, 79.61673259735107, 89.50048103928566, 83.59714061021805, 88.45620587468147, 83.6204181611538, 53.3355226367712, 45.630676075816154, 75.75487062335014, 90.73517918586731, 82.48744055628777, 87.36580118536949, 84.80064243078232, 84.87378850579262, 85.18846482038498, 84.64132457971573, 83.56320843100548, 83.38217854499817, 87.08821848034859, 89.82081905007362, 86.08119651675224, 83.78843754529953, 81.23688966035843, 79.1198180615902, 82.11166352033615, 80.824224203825, 84.85961526632309, 85.27934074401855, 84.25390496850014, 84.11580517888069, 84.29161414504051, 85.17168492078781, 81.41813233494759, 81.77845939993858, 80.84162726998329, 79.87955689430237, 79.62741002440453, 77.85523071885109, 74.87880483269691, 79.51257258653641, 79.3102790415287, 83.59233766794205, 77.07149997353554, 75.93406140804291, 82.11509093642235, 90.68683058023453, 64.93614435195923, 6.7079676780849695, 1.3825465505942702, 0.9991033072583377, 0.46675677120219916, 2.238000347279012, 4.071030775085092, 0.6300063722301275, 0.008414859985350631, 0.028247530244698282, 0.14730014983797446, 0.12358185224002227, 0.07473834542906843, 10.53317254409194, 71.30339428782463, 69.57364350557327, 67.34618782997131, 44.2661464959383, 40.035221725702286, 26.97250496596098, 35.56912377476692, 44.887618348002434, 62.2225009649992, 68.86251926422119, 74.95541632175446, 76.789091527462, 53.88864755630493, 8.901099320501089, 0.05830550748214591, 0.1342349813785404, 0.02513407602236839, 0.059235563239781186, 0.0894880406849552, 0.055494066546089016, 0.025085927336476743, 0.11013367620762438, 0.053292593074729666, 0.015732330321043264, 0.07744607864879072, 0.08689801950822584, 0.019656074364320375, 0.054533753427676857, 0.042067965696332976, 0.07016638919594698, 0.028886925720144063, 0.012587610344780842, 0.037207981949904934, 0.030423264179262333, 0.0544303870992735, 0.04070900795341004, 0.08591707839514129, 0.14602185983676463, 0.13728011719649658, 0.13197261840105057, 0.16175260010641068, 0.20364368974696845, 0.1574125947081484, 0.06039550295099616, 0.1170592573180329, 0.2712564601097256, 0.12972428201464936, 0.10677432990632951, 0.16436426230939105, 0.13362352590775117, 0.15879266284173355, 0.19211574661312625, 0.19514413957949728, 0.11645845908788033, 0.13897445518523455, 0.1502808672375977, 1.38956987997517, 54.052821546792984, 116.24520912766457, 99.37729105353355, 94.40334275364876, 92.25779548287392, 73.56360420584679, 66.52353197336197, 61.256330609321594, 52.57891483604908, 84.64385524392128, 94.2660029232502, 99.33885231614113, 116.54034689068794, 66.08394876122475, 40.04287451505661, 7.8202530182898045, 0.46203674166463315, 0.15423019125591964, 0.19495403103064746, 0.2637107775080949, 0.5777666566427797, 1.7095214989967644, 1.7520363489165902, 0.1757018148782663, 6.037226244807243, 58.33104617893696, 97.19653487205505, 90.7323445379734, 86.77278220653534, 98.98595005273819, 107.20953717827797, 112.48708918690681, 102.23382577300072, 97.4995306134224, 98.2038152217865, 98.4455506503582, 94.94540646672249, 92.0746149122715, 96.9149623811245, 94.34252321720123, 98.4454670548439, 96.86460748314857, 98.8594776391983, 96.10671535134315, 92.00980558991432, 94.04500678181648, 90.83897441625595, 94.15552005171776, 91.68293952941895, 91.14994212985039, 90.74867606163025, 85.03578901290894, 81.44056633114815, 87.15276941657066, 89.78678807616234, 93.85950073599815, 87.27806389331818, 92.822285592556, 87.98655107617378, 81.69818490743637, 82.78358146548271, 92.09172919392586, 87.14376389980316, 91.15592300891876, 83.50184172391891, 61.840009689331055, 55.51695518195629, 74.82034116983414, 93.66125777363777, 85.05014464259148, 89.24489915370941, 87.59277820587158, 88.13254684209824, 86.74280941486359, 89.90746960043907, 89.79658395051956, 88.14676567912102, 88.55866357684135, 94.1231381893158, 87.81993761658669, 87.05739453434944, 82.20058634877205, 82.70611122250557, 88.19158807396889, 85.76669499278069, 85.51754996180534, 86.98272854089737, 86.0767811536789, 85.84967494010925, 86.76199078559875, 88.01266327500343, 83.09106096625328, 83.73368248343468, 82.89885208010674, 85.0929607450962, 84.34972062706947, 80.8358059823513, 78.97769048810005, 84.00308802723885, 79.70097407698631, 85.12424826622009, 79.74771156907082, 78.715930134058, 83.2119856774807, 90.4746575653553, 61.12586461007595, 4.627435393631458, 6.493932763114572, 5.43072416447103, 5.516761997714639, 6.882296623662114, 3.4269095258787274, 0.47831940231844783, 0.22458724561147392, 0.18983080750331283, 0.20395341765834019, 0.38574636506382376, 0.18187848734669387, 21.418213807046413, 83.41100379824638, 77.31176868081093, 83.2054652273655, 59.32635337114334, 84.5263959467411, 66.73274114727974, 42.963621988892555, 48.57325337827206, 60.33104985952377, 69.67598721385002, 77.96110063791275, 90.26864022016525, 64.63297381997108, 10.818906761705875, 0.12142203180701472, 0.1980622494011186, 0.07786792280967347, 0.1128660784161184, 0.18299487041076645, 0.21246190328383818, 0.1094497945450712, 0.13037683762377128, 0.1252200096496381, 0.19118230295134708, 0.14068773278268054, 0.2842736413003877, 0.13462169968988746, 0.09819519924349152, 0.1092837612668518, 0.3408860613126308, 0.12467925116652623, 0.0758774382120464, 0.10552004096098244, 0.15456274762982503, 0.1693594505195506, 0.24570407811552286], [0.03554642462404445, 0.04347558235167526, 0.038593816570937634, 0.02486998462700285, 0.07424693234497681, 0.02329715291125467, 0.023080956016201526, 0.04132254885917064, 0.020049006307090167, 0.04857821128098294, 0.06098637866671197, 0.035942460599471815, 0.05007736443076283, 0.020903225704387296, 0.03447504910582211, 0.04488476122787688, 0.030314027462736703, 0.13201195222791284, 0.11740331698092632, 0.25561914138961583, 19.704847745597363, 81.10619947314262, 74.45643469691277, 74.65781629085541, 67.07469999790192, 60.463271364569664, 45.78260712325573, 41.470108330249786, 51.735618487000465, 64.50818091630936, 66.53061479330063, 82.51650139689445, 41.9212581217289, 28.343904577195644, 27.546764351427555, 8.540069293230772, 0.36616349243558943, 0.10023393086157739, 0.16793094982858747, 0.1019666156207677, 0.029746429208898917, 0.3590635734144598, 1.943810514640063, 0.09986458622734062, 2.601382923312485, 36.51425085961819, 82.11549371480942, 77.52451926469803, 75.28870403766632, 93.82027924060822, 100.87539866566658, 97.55026549100876, 97.59484469890594, 96.35007709264755, 89.8643571138382, 86.28277570009232, 91.41731098294258, 90.3504878282547, 93.87622743844986, 86.55397474765778, 90.4935197532177, 91.57843753695488, 88.3559900522232, 86.60906419157982, 90.37781596183777, 88.37963998317719, 90.12183889746666, 88.2550598680973, 90.85532113909721, 87.54269689321518, 86.62253066897392, 82.65240490436554, 80.25199010968208, 86.11058413982391, 88.55807080864906, 89.68836575746536, 85.40146619081497, 85.18469542264938, 83.46531048417091, 80.18622323870659, 71.13918229937553, 72.98855066299438, 81.55386865139008, 80.80046027898788, 79.64304238557816, 88.3243453502655, 45.125892162323, 28.674621731042862, 79.30815115571022, 79.02272567152977, 79.80242103338242, 79.48737993836403, 79.9631068110466, 78.61370041966438, 79.50497299432755, 73.14747333526611, 80.84313958883286, 78.62794205546379, 81.71241134405136, 81.65692672133446, 82.71431118249893, 79.66158539056778, 79.04969662427902, 77.34516888856888, 78.55253890156746, 76.68056175112724, 83.72463896870613, 77.51083239912987, 79.49405997991562, 74.4967657327652, 76.3748149573803, 75.31593337655067, 75.54967403411865, 71.14272370934486, 74.90998595952988, 72.36537650227547, 73.69680985808372, 73.04579839110374, 73.70366469025612, 72.36815795302391, 74.21712353825569, 71.78818747401237, 76.97740942239761, 75.48370957374573, 74.36455562710762, 73.55807170271873, 86.31708025932312, 70.97112491726875, 7.711387434974313, 2.035597083158791, 0.7223667693324387, 3.762985817156732, 1.96571693290025, 0.5790476629044861, 0.047831948395469226, 0.32984551624394953, 0.11782470101024956, 0.20406940049724653, 0.09999302972573787, 0.3217095590662211, 17.297673113644123, 53.15738819539547, 53.53558570146561, 57.35789179801941, 39.73876163363457, 34.4490996748209, 30.70057611912489, 29.723534546792507, 50.07354587316513, 50.34814573824406, 60.690616965293884, 56.539609506726265, 64.77754846215248, 46.22091360390186, 6.702730134129524, 0.18873967230319977, 0.03703069771290757, 0.010568521520326613, 0.07418952722218819, 0.0637844015727751, 0.0706153069040738, 0.056273110094480217, 0.08522458039806224, 0.03306515034637414, 0.05069322825875133, 0.013498257085302612, 0.011511978609632934, 0.006980714797464316, 0.02250716268463293, 0.05412153492216021, 0.0633006845600903, 0.014261092128435848, 0.03200469924195204, 0.02147971303202212, 0.029392821816145442, 0.038083252366050147, 0.002747268586063001, 0.031107579998206347, 0.04796285582415294, 0.03840319222945254, 0.018158353559556417, 0.04855789498833474, 0.011720125985448249, 0.009369465060444782, 0.02805467574944487, 0.08441065961960703, 0.051063118371530436, 0.012328916218393715, 0.047856309392955154, 0.032956080613075756, 0.016433817581855692, 0.03325345918710809, 0.0322589145071106, 0.1048607169650495, 0.04169810526946094, 0.5714356619864702, 36.31007261574268, 99.30859073996544, 84.95357662439346, 95.88994458317757, 88.48317682743073, 71.80071920156479, 61.690081134438515, 50.22060938179493, 45.65000183880329, 35.89869908988476, 61.556890681385994, 91.53253600001335, 49.03424084186554, 32.80553586781025, 33.135840743780136, 7.269214186817408, 0.1882064391975291, 0.07061111376970075, 0.10860954978852533, 0.13108128419844434, 0.5859290342777967, 0.6918384949676692, 1.1993693048134446, 0.0207797286202549, 4.288864536210895, 52.05623008310795, 93.80996659398079, 85.49715265631676, 84.85719859600067, 103.9268933236599, 104.44333121180534, 101.27610236406326, 98.68652611970901, 98.7414787709713, 94.16578710079193, 92.86911427974701, 95.45638024806976, 95.41600361466408, 96.84213548898697, 89.1052034497261, 93.08879569172859, 93.42728912830353, 90.30781611800194, 91.43393129110336, 93.01192581653595, 92.68506735563278, 92.78041943907738, 91.3723973929882, 91.44925966858864, 92.09678292274475, 93.03754404187202, 86.1754922568798, 84.35681864619255, 87.39510521292686, 89.81948152184486, 92.00989678502083, 87.6349863409996, 89.60340231657028, 87.11435347795486, 84.81656357645988, 76.169952750206, 77.5997020304203, 83.43119591474533, 83.49984303116798, 81.46338030695915, 91.37142464518547, 50.59085011482239, 32.23177805542946, 80.69060057401657, 81.95017978549004, 84.36248034238815, 81.54458954930305, 81.64369583129883, 81.43381029367447, 81.93716168403625, 78.71332347393036, 85.73102250695229, 82.50326290726662, 84.33406546711922, 84.18752253055573, 83.17663237452507, 83.23268696665764, 80.66768780350685, 80.07137060165405, 82.92423471808434, 81.93659171462059, 86.90019696950912, 82.39028736948967, 83.16741406917572, 78.49529877305031, 80.6311945617199, 80.17261996865273, 79.11067575216293, 75.92045053839684, 77.97391355037689, 77.88113012909889, 76.60983234643936, 77.1052573621273, 78.25705155730247, 76.20487287640572, 78.17650347948074, 76.24849453568459, 81.43282234668732, 79.45796191692352, 78.637555539608, 77.35611990094185, 89.86858248710632, 83.5571363568306, 13.352349568158388, 0.15818711486645043, 0.9645772317890078, 1.3374555576592684, 4.523638263344765, 1.9285907875746489, 0.18183168751420453, 0.2725375257432461, 0.17721736949170008, 0.7068615825846791, 0.14452356757828966, 0.32891147886402905, 13.89594554901123, 57.27897383272648, 60.882795453071594, 62.919265776872635, 38.53870242834091, 15.862415079027414, 18.093073032796383, 35.672501027584076, 62.30080336332321, 67.75249242782593, 80.51292210817337, 72.61834412813187, 74.36447963118553, 61.66424632072449, 9.929042961448431, 0.20629388425732031, 0.05193748707824852, 0.023205011566460598, 0.052686581257148646, 0.02789215654047439, 0.029408939408313017, 0.0427395982114831, 0.05883855505089741, 0.04277205232938286, 0.02144557423889637, 0.03618118353188038, 0.04172992485109717, 0.030602262777392752, 0.02196519635617733, 0.016079096967587247, 0.055812047139625065, 0.05328211023879703, 0.05734946171287447, 0.03107844513579039, 0.13561694941017777, 0.06389378671883605, 0.08989461886812933, 0.19118680036626756, 0.1880649264785461, 0.1381820789538324, 0.12522475939476863, 0.12330261175520718, 0.1053329900605604, 0.08343297653482296, 0.1465005599311553, 0.13888658490031958, 0.1731712100445293, 0.1211601724207867, 0.13406323356321082, 0.1070239141699858, 0.12234665133291855, 0.10279674490448087, 0.14613620995078236, 0.2979533525649458, 0.14265598263591528, 0.47064648591913283, 39.32120583951473, 112.28780508041382, 95.87714686989784, 100.7480750977993, 92.36412137746811, 85.14931932091713, 66.93615183234215, 64.31008994579315, 78.88410151004791, 90.7013837993145, 83.47817659378052, 99.03923839330673, 61.6533637046814, 48.03759232163429, 48.8783960044384, 13.168447986245155, 0.5574198765680194, 0.13124718389008194, 0.28759071487002075, 0.1325390551937744, 0.28320554236415774, 1.0878651193343103, 5.93129220418632, 0.22448566043749452, 3.0556730087846518, 52.09326669573784, 100.26072844862938, 92.34899818897247, 89.65295165777206, 106.33348658680916, 111.54925391077995, 103.34188431501389, 101.98438435792923, 102.39473193883896, 98.95477652549744, 95.2960592508316, 98.72923582792282, 95.82588002085686, 100.79988911747932, 91.17082580924034, 98.0314488708973, 96.25556856393814, 95.15652313828468, 92.92548805475235, 95.92659741640091, 95.63412711024284, 96.49943947792053, 93.65756437182426, 96.84925630688667, 96.96170747280121, 96.65250286459923, 88.79814952611923, 89.29277658462524, 92.15988993644714, 95.22781491279602, 94.3809087574482, 88.42394560575485, 90.33996239304543, 87.9805625975132, 86.61183044314384, 77.8617587685585, 82.70134627819061, 85.41604980826378, 87.7772507071495, 87.36686512827873, 90.68676978349686, 57.653508335351944, 44.46806766092777, 83.01802888512611, 85.29463112354279, 85.47122284770012, 85.51687359809875, 83.54413345456123, 84.19585168361664, 85.37606835365295, 82.12308570742607, 84.5359106361866, 83.67433726787567, 85.39766639471054, 84.53160166740417, 85.4595422744751, 82.80047535896301, 81.80372044444084, 82.13304877281189, 86.2196458876133, 83.98811683058739, 91.23457118868828, 84.31054472923279, 86.2905652821064, 80.88429898023605, 84.32764381170273, 82.78908357024193, 82.36748099327087, 79.74790155887604, 79.65742081403732, 79.11849573254585, 79.28562596440315, 80.28361961245537, 80.73707967996597, 80.28368800878525, 81.10708102583885, 77.49408289790154, 82.54194483160973, 83.35770785808563, 82.41806387901306, 79.2951862514019, 91.39553815126419, 82.31923118233681, 9.985845163464546, 4.018456321209669, 4.071353282779455, 7.623089672997594, 4.31768361479044, 2.088572890497744, 0.1481268578208983, 0.49652974703349173, 0.32386736827902496, 0.35000450327061117, 0.14496229559881613, 0.34649758832529187, 26.072095781564713, 72.35008612275124, 66.64482906460762, 79.91957634687424, 54.26117196679115, 48.252170607447624, 50.20970396697521, 43.30184563994408, 65.47082126140594, 68.80752101540565, 80.5894424021244, 75.28964638710022, 83.43235865235329, 73.41126278042793, 12.237425744533539, 0.5553919728845358, 0.13104459241731092, 0.20078827656107023, 0.22648494690656662, 0.18590790394227952, 0.13658281008247286, 0.13047781423665583, 0.15444360324181616, 0.09081197276827879, 0.14760747319087386, 0.10665938607417047, 0.12263967350008897, 0.10328270320314914, 0.09660176365287043, 0.1217212360643316, 0.16005254758056253, 0.06975117241381668, 0.14546720834914595, 0.09839494086918421, 0.2549306064611301, 0.30780975648667663], [0.054458870727103204, 0.023245015181601048, 0.03501090199279133, 0.08649306662846357, 0.024525314547645394, 0.0415540135873016, 0.019652975897770375, 0.11988904414465651, 0.026224426401313394, 0.11814696379587986, 0.06811396495322697, 0.03488032481982373, 0.029958065606479067, 0.0174713159140083, 0.03582743142032996, 0.029869375248381402, 0.07314971153391525, 0.021980540259392, 0.258052465505898, 8.729436881840229, 77.30593219399452, 72.91975915431976, 79.61268201470375, 54.32138353586197, 57.26826600730419, 71.39163315296173, 49.797498285770416, 52.42053173482418, 39.80746194720268, 33.41409981250763, 65.62722086906433, 27.295348942279816, 30.679981224238873, 40.923112481832504, 11.826520543545485, 1.3568634912371635, 0.23432106157997623, 0.14417235361179337, 0.1369186319061555, 0.06096096010878682, 0.23507563280873, 1.3940496020950377, 0.31819774594623595, 0.7018722721841186, 24.316561482846737, 87.84905925393105, 83.08054313063622, 80.439373254776, 91.24970197677612, 105.03777891397476, 98.93332287669182, 103.96425291895866, 94.2999655008316, 90.3464524447918, 85.5884237587452, 91.4039508998394, 88.41213583946228, 89.05998587608337, 82.91324570775032, 86.87764137983322, 86.64564862847328, 88.0964943766594, 87.00824797153473, 89.51153844594955, 88.65341529250145, 90.06020620465279, 88.65921378135681, 89.47514399886131, 81.58989831805229, 81.56646877527237, 81.10187530517578, 81.97796389460564, 83.10799285769463, 81.66225403547287, 82.77083694934845, 83.9703793823719, 82.58535370230675, 86.01938903331757, 84.3698063492775, 84.99634712934494, 79.93294402956963, 70.12780576944351, 82.15884178876877, 79.21488896012306, 80.87632700800896, 85.41509225964546, 35.84263689815998, 22.225773073732853, 57.46853806078434, 87.04005226492882, 75.37024766206741, 82.06058666110039, 78.05308610200882, 77.567890137434, 71.20018422603607, 79.3265725672245, 81.18048548698425, 80.3924685716629, 82.1606656908989, 81.97770550847054, 78.38465631008148, 79.6907602250576, 77.55744829773903, 79.35691013932228, 76.47533476352692, 76.25695288181305, 76.31214112043381, 77.25005239248276, 78.95351618528366, 79.99616503715515, 78.86682763695717, 76.45261198282242, 73.88641968369484, 74.13703143596649, 72.30420738458633, 74.8137903213501, 70.23664712905884, 70.7012178003788, 71.90398246049881, 71.3833723962307, 71.91728174686432, 74.26886156201363, 72.52785578370094, 75.44676795601845, 73.23552221059799, 74.76205229759216, 71.51948109269142, 82.18340367078781, 74.94226142764091, 10.548518020659685, 0.8231253095436841, 1.603673784993589, 6.6245597787201405, 1.7732706782408059, 0.1312157465144992, 0.02919855909567559, 0.1900693486095406, 0.12969318602699786, 0.0537350466765929, 0.040496646106475964, 0.2881744288606569, 15.307733193039894, 52.45241962373257, 65.530204474926, 51.16507530212402, 53.02167467772961, 46.79378226399422, 33.81520628929138, 27.830103747546673, 44.534807279706, 50.99129542708397, 50.98476357758045, 57.7743798494339, 56.01591780781746, 47.594395503401756, 8.256456311792135, 0.16642002621665597, 0.11973625078098848, 0.06856588835944422, 0.03154254533001222, 0.06011315286741592, 0.014399735518964007, 0.038876018224982545, 0.02210937709605787, 0.05041429576522205, 0.03693556551297661, 0.05974544466880616, 0.06579297973075882, 0.029390931194939185, 0.08562208211515099, 0.07381759249255992, 0.028378617644193582, 0.04100816397112794, 0.06692594237392768, 0.014812425288255326, 0.016313040468958206, 0.047675336682004854, 0.057103276485577226, 0.09230745970853604, 0.08598996471846476, 0.048313160659745336, 0.028059538672096096, 0.08578962937463075, 0.04728827698272653, 0.04523883246292826, 0.027857704189955257, 0.02592450226075016, 0.031072815945663024, 0.03943642877857201, 0.015843012370169163, 0.07935111236292869, 0.06118889221397694, 0.1335315589676611, 0.05327852566551883, 0.3103218966862187, 14.546791724860668, 99.56936314702034, 80.79286068677902, 102.0808307826519, 74.75907325744629, 80.96088767051697, 94.35708403587341, 69.0468929708004, 56.04237958788872, 31.601137295365334, 42.38400489091873, 80.81128969788551, 36.149314641952515, 36.441530361771584, 43.85103017091751, 8.89435088261962, 1.127890746574849, 0.2428149714251049, 0.05755511825555004, 0.07544797961600125, 0.5666036868933588, 1.011084420606494, 0.18755665922071785, 0.23882205365225673, 1.1906846333295107, 38.5331167280674, 99.1236774623394, 89.70347374677658, 88.1055910885334, 99.80587005615234, 104.87858265638351, 99.9656742811203, 106.84015139937401, 99.07340615987778, 92.0962281525135, 89.77212846279144, 94.61359307169914, 90.69857954978943, 90.38527116179466, 88.33065301179886, 91.03961884975433, 92.15846881270409, 92.07640841603279, 90.16656249761581, 93.19380685687065, 91.7733746767044, 91.06701537966728, 93.93934965133667, 91.38144090771675, 83.98544177412987, 87.58039087057114, 85.70999443531036, 86.64484307169914, 84.6019434928894, 85.30541494488716, 85.81321969628334, 86.00860521197319, 89.59332525730133, 88.1380945444107, 88.18328931927681, 87.40801692008972, 83.04764449596405, 74.25939247012138, 85.92856630682945, 83.34634646773338, 89.05073717236519, 85.4906702041626, 38.68053741753101, 30.48827201128006, 53.472600281238556, 91.80797562003136, 79.29268598556519, 85.63548043370247, 83.06196212768555, 80.40040254592896, 76.4082683622837, 83.6097863316536, 82.24853977560997, 84.26220372319221, 85.29115051031113, 88.3233954012394, 81.42965331673622, 83.82113099098206, 81.81013450026512, 84.00295123457909, 80.12507691979408, 78.37197259068489, 79.92780670523643, 80.97831353545189, 81.60901129245758, 83.4526115655899, 83.32336530089378, 82.30217009782791, 79.5369140803814, 77.6583556830883, 75.9846518933773, 77.27845206856728, 75.0858861207962, 73.24764356017113, 73.48538160324097, 76.13627895712852, 76.69402822852135, 78.67951288819313, 74.75365474820137, 76.61503046751022, 77.36649334430695, 81.31049931049347, 75.17784118652344, 84.61418643593788, 88.48000019788742, 20.594697296619415, 0.40980498190037906, 1.4081727317534387, 0.9168793412391096, 3.0086293956264853, 3.0152094550430775, 0.03383967421541456, 0.2398424324928783, 0.0752091416507028, 0.3362177743110806, 0.06373758689733222, 0.1170358870876953, 12.743612732738256, 57.90277116000652, 72.49546632170677, 56.624907329678535, 51.77822180092335, 22.417098507285118, 27.25623194128275, 39.50436361134052, 54.23772342503071, 71.17496877908707, 69.59644988179207, 69.60309952497482, 63.14128406345844, 61.33790843188763, 14.010432455688715, 0.17180372873554006, 0.07724644834524952, 0.018245498395117465, 0.04499716320424341, 0.060359141425578855, 0.04546648255200125, 0.03287501953309402, 0.019814966326521244, 0.09430008169147186, 0.05871229346666951, 0.07691386970691383, 0.029679018080059905, 0.022831217756902333, 0.03117456624750048, 0.041216358658857644, 0.018095636514772195, 0.040349552436964586, 0.05435945262433961, 0.049938883385038935, 0.051520025299396366, 0.14474086841801181, 0.16622148687019944, 0.2687383530428633, 0.30275302939116955, 0.14878149144351482, 0.11960246381931938, 0.13615365576697513, 0.21794374741148204, 0.16153955919435248, 0.1622998301172629, 0.2420308330329135, 0.07959951661177911, 0.13282470783451572, 0.13947173865744844, 0.16141749074449763, 0.16976801765849814, 0.38246610201895237, 0.3803459939081222, 0.3800960088847205, 16.731984168291092, 109.5890910923481, 95.20804837346077, 104.7136715054512, 80.00142395496368, 80.46387434005737, 92.69172459840775, 73.33992540836334, 82.9623618721962, 60.69647245109081, 45.001977011561394, 84.94900166988373, 44.984809532761574, 49.515477418899536, 64.74650412797928, 17.246199175715446, 2.3239609971642494, 0.5448318645358086, 0.13153694802895188, 0.2747716277372092, 0.25918308296240866, 0.6449586292728782, 5.220809178426862, 0.6817604263778776, 1.2185475882142782, 37.981815710663795, 105.20732581615448, 93.09481456875801, 93.81723180413246, 104.45110559463501, 108.4147185087204, 102.79697075486183, 111.5746745467186, 102.41145864129066, 96.81802958250046, 89.89073529839516, 98.37444126605988, 94.78319317102432, 95.77329084277153, 89.3016529083252, 94.66986805200577, 95.2579852938652, 95.45484513044357, 94.00795117020607, 95.38320377469063, 95.08017003536224, 93.76870080828667, 96.68850973248482, 96.42990320920944, 87.4246296286583, 89.72248792648315, 87.2502113878727, 90.0756561756134, 88.25801610946655, 87.66034618020058, 89.12426322698593, 89.74858492612839, 92.86326259374619, 93.24763476848602, 91.4775301516056, 91.10195830464363, 85.43549716472626, 76.31914034485817, 92.15657651424408, 86.5541723370552, 91.16094633936882, 91.86965391039848, 43.595364689826965, 33.802902549505234, 63.22584092617035, 95.07295802235603, 82.43202432990074, 89.55775916576385, 86.65871232748032, 84.20415803790092, 80.18214225769043, 85.29476031661034, 88.7649317085743, 85.12650534510612, 87.80609875917435, 90.39765849709511, 84.7062174975872, 87.83722668886185, 84.31083351373672, 88.25629860162735, 83.99004712700844, 81.60427674651146, 80.80609157681465, 83.65136370062828, 84.00766298174858, 84.29599910974503, 85.9473828971386, 84.47846531867981, 81.96225553750992, 79.82816085219383, 78.86032238602638, 80.68564563989639, 75.68496957421303, 76.02740719914436, 77.64002546668053, 78.45352381467819, 80.87354555726051, 82.05483376979828, 76.52355417609215, 80.30905544757843, 79.07054230570793, 84.12497028708458, 76.72545254230499, 90.51048964262009, 91.41967445611954, 18.299778141081333, 2.8472674917429686, 4.368240376934409, 12.844868749380112, 4.39307726919651, 1.1659246869385242, 0.15585619228659198, 0.6628961011301726, 0.9112294600345194, 0.3578419686527923, 0.09695613916846924, 0.9532226098235697, 25.34152988344431, 69.38379809260368, 78.15808966755867, 71.00159168243408, 74.63151410222054, 64.84036669135094, 53.52774292230606, 45.380581095814705, 60.021871849894524, 69.02572050690651, 70.5923080444336, 77.9180109500885, 75.63448548316956, 73.52568984031677, 17.14984394609928, 0.4523770068772137, 0.15306130866520107, 0.13888953864807263, 0.16983144159894437, 0.2235929755261168, 0.08879952059942298, 0.09145957825239748, 0.16783849307103083, 0.14795010793022811, 0.14281515846960247, 0.14915982348611578, 0.11547477944986895, 0.10669157301890664, 0.20566812017932534, 0.1444983048713766, 0.1266949242562987, 0.13957268558442593, 0.15978819457814097, 0.1652694449876435, 0.1627213106257841], [0.031407622882397845, 0.04515966014878359, 0.05668320976838004, 0.02343714608286973, 0.03891054293490015, 0.026069261875818484, 0.037230383677524514, 0.017671849782345816, 0.03166233538649976, 0.017688475745671894, 0.029860940740036312, 0.04848578792007174, 0.05064224642410409, 0.04978547403879929, 0.044857683969894424, 0.0379698150936747, 0.08638541810796596, 0.027583313640207052, 0.14424074994167313, 37.80799403786659, 88.52178275585175, 69.50358286499977, 61.51138052344322, 52.17759557068348, 37.6887184381485, 38.113771229982376, 36.205696016550064, 37.181605249643326, 34.00830812752247, 24.699537232518196, 18.230747245252132, 30.63542291522026, 37.258060947060585, 11.231101043522358, 1.1741328402422369, 0.22263655497226864, 0.2366996300406754, 0.11620095610851422, 0.04573308426188305, 0.44820533541496843, 1.9772928929887712, 1.2474250886589289, 0.1870330740348436, 15.358225833624601, 80.10258972644806, 88.8326820731163, 86.4165361225605, 95.58737441897392, 98.65220636129379, 99.2136262357235, 102.13129207491875, 92.06443905830383, 92.78817862272263, 86.69357925653458, 87.74145662784576, 80.6682425737381, 85.36643967032433, 85.44037610292435, 87.07550436258316, 84.33711290359497, 86.65225267410278, 87.09438174962997, 86.72683507204056, 85.95738396048546, 90.49937903881073, 86.92163541913033, 84.48236390948296, 81.23663887381554, 83.36593821644783, 87.35763922333717, 86.93366557359695, 81.96819081902504, 87.22059577703476, 82.86173567175865, 86.14382475614548, 82.07189485430717, 83.9897583425045, 79.28038224577904, 85.17188251018524, 77.1526712179184, 78.21764767169952, 73.60845699906349, 78.80239829421043, 75.02711087465286, 91.498793810606, 61.890277191996574, 38.45181629061699, 57.34619602560997, 22.10908703505993, 85.27883157134056, 75.52495256066322, 81.26755401492119, 75.75367748737335, 70.43437331914902, 75.7280744612217, 79.79392468929291, 76.87487572431564, 81.18440687656403, 78.96347165107727, 81.14515498280525, 78.11702907085419, 78.83734121918678, 75.89199006557465, 78.63125547766685, 76.9527031481266, 76.6838751733303, 78.29187288880348, 75.74906453490257, 74.5590291917324, 75.86573347449303, 74.46431547403336, 75.95578864216805, 73.27167347073555, 71.85284480452538, 70.07096081972122, 70.56790575385094, 69.38517361879349, 68.97022068500519, 66.46209686994553, 71.25424772500992, 71.27333790063858, 71.16394177079201, 71.36089280247688, 75.84791243076324, 72.53023445606232, 73.8126428425312, 74.05959159135818, 73.52464109659195, 72.09486901760101, 76.15241289138794, 11.093351785093546, 0.5629451957065612, 5.921782264485955, 3.5818984592333436, 1.3158964645117521, 0.22093678446253762, 0.12498802912887186, 1.5069407131522894, 0.41062422387767583, 0.05283061727823224, 0.04472225315112155, 0.5979945743456483, 16.710616014897823, 42.62321725487709, 49.77991662919521, 29.25559725612402, 39.34494696557522, 39.97941792011261, 36.16136759519577, 30.163611732423306, 35.09051665663719, 49.031801372766495, 54.16609726846218, 58.832383677363396, 57.89037622511387, 53.31077076494694, 17.428754679858685, 0.29353885038290173, 0.08517772119375877, 0.047652660359744914, 0.02360476941248635, 0.025453310845477972, 0.0712007872061804, 0.021017648177803494, 0.04753081455419306, 0.020896097375953104, 0.02195301029132679, 0.021209921942499932, 0.02239286266558338, 0.0307965922911535, 0.012988389571546577, 0.028415422602847684, 0.0421768721571425, 0.011620492659858428, 0.028322266371105798, 0.033642147900536656, 0.0361320904630702, 0.02018474697251804, 0.0828638012171723, 0.08188022547983564, 0.04802050214493647, 0.013366630701057147, 0.07336657450650819, 0.058342243792139925, 0.028533500153571367, 0.042541166476439685, 0.08911261043976992, 0.030291499570012093, 0.0092152235811227, 0.055172378924908116, 0.026708406876423396, 0.010930173793894937, 0.03519594538374804, 0.028224902162037324, 0.19768008787650615, 56.4685533195734, 99.52457875013351, 81.72167524695396, 80.68518966436386, 69.39173206686974, 55.87601311504841, 54.96564656496048, 43.92446883022785, 37.60098874568939, 31.610887572169304, 41.44973382353783, 26.266601644456387, 35.750560238957405, 40.47933429479599, 9.781502578407526, 0.8940538472961634, 0.10001032176660374, 0.06604403344681486, 0.1769150630570948, 0.16374114027712494, 1.193414074368775, 1.0573794739320874, 0.841239650035277, 0.5609336192719638, 24.335106387734413, 95.57184845209122, 91.54622286558151, 92.37459361553192, 99.67565104365349, 100.4632879793644, 101.12028792500496, 105.41298598051071, 95.36964610219002, 97.49420329928398, 89.7107769548893, 90.68875327706337, 84.21283677220345, 88.01035299897194, 90.70923417806625, 92.91544899344444, 88.1535217165947, 91.68765127658844, 90.56742578744888, 89.9826143682003, 91.01998150348663, 93.35683330893517, 90.09669184684753, 87.89828941226006, 85.53624495863914, 89.34313148260117, 89.84371662139893, 90.91235607862473, 85.98873227834702, 89.03257414698601, 84.43623438477516, 89.13728132843971, 83.28065559267998, 84.84364092350006, 83.42535942792892, 87.07656070590019, 83.5762645304203, 82.29074031114578, 76.3599805533886, 80.31285524368286, 77.93403849005699, 93.15164431929588, 59.04590182006359, 43.15940648317337, 65.10331258177757, 21.459618285298347, 83.43748077750206, 82.35023751854897, 82.58881151676178, 79.4989313185215, 73.84330719709396, 79.50901597738266, 80.6367726624012, 79.69266012310982, 84.41038057208061, 80.80634236335754, 82.5985997915268, 80.50381779670715, 79.96357798576355, 77.34125509858131, 79.8342253267765, 82.11046278476715, 79.00769367814064, 81.49760887026787, 79.95651796460152, 76.81396499276161, 78.05254653096199, 76.28453180193901, 78.74102398753166, 75.03094866871834, 74.21097546815872, 71.97380751371384, 72.51314297318459, 70.76756224036217, 74.09933745861053, 69.61610242724419, 73.04621636867523, 74.26102638244629, 74.31132048368454, 75.14426618814468, 78.07023838162422, 77.4052132666111, 76.60946756601334, 79.43022340536118, 77.17667832970619, 78.24625253677368, 87.25860133767128, 23.418156690895557, 0.30004828702658415, 1.4478924754075706, 0.3206016810145229, 1.8787309317849576, 2.0039770798757672, 0.4634328401880339, 1.601546611636877, 0.26506086287554353, 0.02501188140740851, 0.029373049146670382, 0.22443938010837883, 14.771489817649126, 49.14567366242409, 55.86405895650387, 33.68223622441292, 31.562556065618992, 25.077858231961727, 30.22252567112446, 42.429515048861504, 52.511305063962936, 61.167191192507744, 71.8005520105362, 74.59413170814514, 66.97596609592438, 69.4916895031929, 27.95423548668623, 0.32690533495042473, 0.038986323634162545, 0.01117626903578639, 0.026491718308534473, 0.0189455236250069, 0.01056258619428263, 0.02724002581089735, 0.04209637510939501, 0.021069977010483854, 0.07636306254426017, 0.04142129160754848, 0.06189950603584293, 0.012745992080454016, 0.042128669665544294, 0.008131470895023085, 0.03421165718464181, 0.0357092369813472, 0.03634935048467014, 0.017971436245716177, 0.26138268993236125, 0.09965044693672098, 0.22954551939619705, 0.1418458839179948, 0.21545537078054622, 0.15314615098759532, 0.18939262867206708, 0.14756889635464177, 0.14973383018514141, 0.1349793406552635, 0.17147381440736353, 0.10684682289138436, 0.12485598621424288, 0.1724626519717276, 0.12171152877272107, 0.0800260659889318, 0.25374370452482253, 0.2075219902326353, 0.33976411214098334, 62.52427317202091, 113.7288473546505, 91.67571991682053, 83.91936331987381, 75.80714821815491, 58.21205176413059, 55.45502990484238, 63.51725488901138, 61.66565224528313, 49.217436611652374, 36.27712458372116, 33.69241587817669, 52.008094266057014, 60.67435383796692, 15.782997440546751, 2.4519150936976075, 0.30398823029827327, 0.36507778975646943, 0.34096496645361185, 0.1828469752217643, 0.7227035262621939, 5.373310670256615, 5.36880886182189, 0.7030355441384017, 22.604764737188816, 99.79478225111961, 98.29418197274208, 99.10816669464111, 103.0210143327713, 105.15741169452667, 107.12752237915993, 108.36471319198608, 98.14472079277039, 98.82043853402138, 94.78329956531525, 97.97873809933662, 87.84343555569649, 90.07188677787781, 91.92972868680954, 93.26208159327507, 89.48622420430183, 92.90497675538063, 95.3685137629509, 94.50423493981361, 91.44814252853394, 96.93599045276642, 94.55990955233574, 90.9162774682045, 90.85244849324226, 92.47867003083229, 94.73696485161781, 93.6238069832325, 87.73262590169907, 93.20845887064934, 89.81224671006203, 93.30664560198784, 86.39077350497246, 88.66913884878159, 86.68196707963943, 91.62317633628845, 85.93928173184395, 85.18395826220512, 80.3470154106617, 83.46784114837646, 82.95667737722397, 97.69059956073761, 68.90390664339066, 45.42500451207161, 59.53451380133629, 29.00541678071022, 92.66984537243843, 86.46626025438309, 87.57241129875183, 82.34006926417351, 77.93411448597908, 83.79220694303513, 84.76673305034637, 80.30487567186356, 87.6135402917862, 85.36634847521782, 87.89002105593681, 84.2534413933754, 82.51663818955421, 81.22210845351219, 84.11278814077377, 84.56278279423714, 81.43449425697327, 85.09812846779823, 82.06478163599968, 80.47077476978302, 82.13010013103485, 80.52601620554924, 83.44661548733711, 77.78156787157059, 78.91421869397163, 76.55750155448914, 76.02450415492058, 74.1776892542839, 76.2725168466568, 73.09701204299927, 79.83059272170067, 77.05313935875893, 76.9265529513359, 76.18071377277374, 83.59059736132622, 81.28410592675209, 79.09644931554794, 82.48299479484558, 79.69507679343224, 77.85124853253365, 93.70953798294067, 20.53222294896841, 1.6608985955826938, 14.180412534624338, 10.828795731067657, 1.8581790220923722, 1.6746903117746115, 0.20296300674090162, 4.762314856052399, 2.3928266018629074, 0.21867526753339916, 0.18721724540228024, 1.9807932176627219, 30.597214065492153, 60.32820001244545, 66.32326751947403, 44.9971778690815, 56.98879100382328, 59.36220444738865, 53.96450288593769, 46.689686849713326, 49.58563685417175, 65.22246658802032, 75.56503280997276, 78.8424177467823, 76.04876965284348, 80.65134108066559, 32.91338928043842, 0.5549594492185861, 0.2792564855189994, 0.21511447266675532, 0.11766809300752357, 0.11025417130440474, 0.19457577320281416, 0.12436338569386862, 0.11986125813564286, 0.08534896434866823, 0.14168529800372198, 0.2079917845549062, 0.1847595046274364, 0.10434804135002196, 0.09284786196076311, 0.11354829766787589, 0.1411849123542197, 0.16588729777140543, 0.14590072649298236, 0.12455839983886108], [0.04863165333517827, 0.0246133982000174, 0.029625555616803467, 0.007711137468504603, 0.020925280477968045, 0.050360846289549954, 0.027363589688320644, 0.04296435392461717, 0.05905639394768514, 0.06416420306777582, 0.12060183245921507, 0.056458865947206505, 0.01924586707900744, 0.010589395351416897, 0.03243967941671144, 0.10267226447467692, 0.032881465085665695, 0.1628984761191532, 0.4727198980981484, 64.25143629312515, 78.93196374177933, 76.7781937122345, 57.491739615798, 47.61879399418831, 51.63804732263088, 40.15517748892307, 46.750441789627075, 37.29100897908211, 36.63379244506359, 18.8946970179677, 29.384986013174057, 34.55827921628952, 19.08389076590538, 2.4312529899179935, 0.060266027867328376, 0.05115374573506415, 0.27317523839883506, 0.017358064178552013, 0.09707696081022732, 4.538631308823824, 2.533904481679201, 0.4283674608450383, 2.2331164218485355, 64.12906005978584, 91.21173441410065, 80.06845235824585, 84.89127516746521, 105.94602137804031, 95.5318745970726, 98.79059493541718, 97.75165468454361, 96.71187847852707, 84.924196600914, 82.58673682808876, 81.6297809779644, 82.8611733019352, 89.45492908358574, 87.8171181678772, 88.33332046866417, 86.66673749685287, 84.29128736257553, 83.6405798792839, 84.99810263514519, 90.10334149003029, 83.49053353071213, 83.60502898693085, 82.09125101566315, 84.23033863306046, 84.68148082494736, 86.31468638777733, 82.8158189356327, 83.18751499056816, 82.55122393369675, 78.97348031401634, 81.55634611845016, 84.7057843208313, 80.55049449205399, 80.89373007416725, 77.6147036254406, 81.38080313801765, 79.02049139142036, 72.60037869215012, 77.70692467689514, 78.42492654919624, 84.28687199950218, 40.530076771974564, 45.912199169397354, 76.60588815808296, 26.403230912983418, 51.65591016411781, 82.50972256064415, 73.11658099293709, 77.49042749404907, 67.69884690642357, 75.79849228262901, 74.9030551314354, 80.52637338638306, 73.86330932378769, 77.54459738731384, 73.66259649395943, 79.19902101159096, 76.07179641723633, 78.15147042274475, 76.00078582763672, 76.2521043419838, 73.95934537053108, 74.36611354351044, 73.61332833766937, 74.92322444915771, 75.03859385848045, 75.29496610164642, 72.24920153617859, 69.82591956853867, 69.50372725725174, 69.57245036959648, 69.01814371347427, 67.44370579719543, 66.05214446783066, 68.48507031798363, 66.74740076065063, 70.13933435082436, 73.56735080480576, 72.74517372250557, 71.06029093265533, 73.4584030508995, 73.75062257051468, 73.89900460839272, 74.27010029554367, 73.52239921689034, 71.14043623209, 72.7935603260994, 18.11914913356304, 0.2387759811244905, 4.162537939846516, 5.527035696431994, 0.058571541449055076, 0.09845048320130445, 0.14528147847158834, 0.9756011527497321, 0.10073343335534446, 0.08166586354491301, 0.03786634115385823, 1.5826275455765426, 29.31932743638754, 56.95457763969898, 57.183914333581924, 36.5341579914093, 43.99865984916687, 45.967030227184296, 27.084766142070293, 38.241695165634155, 49.92907762527466, 43.008949756622314, 46.179849207401276, 59.953870698809624, 58.95935766398907, 62.29439690709114, 20.494247786700726, 0.18513117218390107, 0.17490206169895828, 0.03073305888392497, 0.04290157936338801, 0.0367201348853996, 0.038341786930686794, 0.09880076948320493, 0.07383786054560915, 0.03095085696259048, 0.030336152740346733, 0.04582002686220221, 0.02663245362782618, 0.06010831777530257, 0.00860640551763936, 0.09736350402818061, 0.10488195723155513, 0.029931424360256642, 0.01597100872459123, 0.055502753384644166, 0.026189872005488724, 0.03898569651937578, 0.0639973979559727, 0.030768216274736915, 0.054694502614438534, 0.03617333532019984, 0.006712694657835527, 0.0338573261979036, 0.06350830037263222, 0.04994686147256289, 0.0396777789137559, 0.045796215053997, 0.01491903387432103, 0.030361825483851135, 0.09599869445082732, 0.06855577288661152, 0.024869943808880635, 1.648141611367464, 81.1818078160286, 86.1024297773838, 92.6335497200489, 69.70536723732948, 61.01591370999813, 71.824049949646, 47.501395493745804, 39.92946960031986, 34.25694398581982, 36.26735910773277, 18.240455724298954, 29.112762920558453, 37.53452271223068, 19.1265681758523, 1.8456637999042869, 0.023286393625312485, 0.10216742593911476, 0.27837816858664155, 0.20403502421686426, 0.16704028355889022, 1.1865597171708941, 1.6900227265432477, 0.5315068701747805, 6.769129671156406, 81.51833295822144, 91.69878467917442, 90.65725296735764, 91.25762835144997, 105.57180985808372, 101.86594471335411, 101.97862386703491, 99.45137187838554, 101.20345026254654, 87.51875057816505, 88.63289639353752, 85.31233057379723, 86.70626297593117, 91.21733531355858, 91.95890352129936, 90.26402726769447, 90.58678954839706, 86.896663159132, 87.53788635134697, 87.53472492098808, 91.12693816423416, 88.46705809235573, 89.30463954806328, 84.93939578533173, 87.61188358068466, 86.36228263378143, 88.6264519393444, 86.92388489842415, 87.03273385763168, 88.741015791893, 83.14194023609161, 83.4556894004345, 90.23694232106209, 86.41991794109344, 86.05221927165985, 81.3088957965374, 82.74694383144379, 80.76278910040855, 75.96991628408432, 81.97814628481865, 83.80979999899864, 86.12949952483177, 43.63040640950203, 50.64099982380867, 75.67609325051308, 33.87492008507252, 48.867646381258965, 90.04686132073402, 77.28537529706955, 82.2329606115818, 69.65963289141655, 79.05737221240997, 77.94129610061646, 81.88944384455681, 78.37846264243126, 82.32375293970108, 79.26960602402687, 82.41478085517883, 80.74311375617981, 81.27274453639984, 79.78569433093071, 79.04827550053596, 76.21838495135307, 77.69434735178947, 78.61893653869629, 80.1380418241024, 79.7238640487194, 81.1477692425251, 77.67222493886948, 75.86174368858337, 73.42783749103546, 73.72661545872688, 73.73856961727142, 72.31861621141434, 68.96607130765915, 71.85688778758049, 72.78282970190048, 72.18494698405266, 75.47243937849998, 78.03452029824257, 75.0983114540577, 75.92363476753235, 77.41836056113243, 77.76364803314209, 77.64279171824455, 81.61570653319359, 74.43327873945236, 84.34431731700897, 30.047664754092693, 0.5197630659677088, 2.6407350366935134, 0.7487004844006151, 1.6760132345370948, 1.103897171560675, 0.5570602614898235, 2.0750886015594006, 0.07895314309280366, 0.162774448399432, 0.014283092168625444, 0.7545530016068369, 28.740333504974842, 64.02969539165497, 62.02591851353645, 37.97939904034138, 28.695058934390545, 23.88745430856943, 20.629237443208694, 43.70015546679497, 69.9646045267582, 62.85767488181591, 61.836776062846184, 78.32431554794312, 67.82795637845993, 78.54360178112984, 28.64731639623642, 0.2054788576788269, 0.10315240433556028, 0.07082716780132614, 0.03566862294974271, 0.09338629752164707, 0.03335330402478576, 0.02565843860793393, 0.015037980665510986, 0.02370059366512578, 0.030337850403157063, 0.02432798304653261, 0.012789738902938552, 0.03806956716289278, 0.012864665204688208, 0.023088722591637634, 0.08744961334741674, 0.017558961699251086, 0.013123602384439437, 0.1528657675953582, 0.16754645796027035, 0.08414744952460751, 0.13545569556299597, 0.10237927199341357, 0.1957280613714829, 0.07900780226918869, 0.10329038443160243, 0.14009386621182784, 0.16080144880106673, 0.24378722941037267, 0.12294307089177892, 0.15853351971600205, 0.11346633487846702, 0.16147837653988972, 0.3025294648250565, 0.18552176450612023, 0.40980587247759104, 2.7085461979731917, 93.97390499711037, 100.61813727021217, 102.21234932541847, 82.1956542134285, 68.6560383439064, 75.75936198234558, 67.25446075201035, 77.2084142267704, 62.55021817982197, 54.93494801223278, 33.79406042397022, 52.375173568725586, 58.07381518185139, 28.37972715497017, 4.073993666097522, 0.18469003960490227, 0.12698161590378731, 0.4805185046279803, 0.16560789401410148, 0.20079415437066928, 7.469744626432657, 9.182411525398493, 0.8767401950899512, 4.618326332420111, 86.39743074774742, 97.92088240385056, 92.06883922219276, 95.52589371800423, 110.33035531640053, 104.5485171675682, 105.98361656069756, 102.87607491016388, 104.8565362393856, 93.7050998210907, 94.1130231320858, 87.26536497473717, 88.45961049199104, 93.28512355685234, 95.13475030660629, 94.71589878201485, 94.33844983577728, 91.12386032938957, 91.46105423569679, 90.72964668273926, 97.02853068709373, 92.48572245240211, 91.04244589805603, 89.71288204193115, 89.35222819447517, 87.92655989527702, 92.34185457229614, 88.79180386662483, 89.98910441994667, 88.28028291463852, 83.78076955676079, 86.60905659198761, 92.26160287857056, 88.48704501986504, 88.77766102552414, 85.55145174264908, 88.09424489736557, 84.14732828736305, 79.34605032205582, 85.55579110980034, 84.97417911887169, 92.68400341272354, 48.2358542829752, 50.078728795051575, 78.10925468802452, 32.7024208009243, 57.72941306233406, 91.77298709750175, 82.03082665801048, 84.84343573451042, 74.76699963212013, 83.13414305448532, 80.52681416273117, 88.41131508350372, 81.53398811817169, 84.68476384878159, 80.8657331764698, 86.07990458607674, 84.7197599709034, 85.4728415608406, 82.61136710643768, 82.41418808698654, 81.2297460436821, 80.90879246592522, 80.12656643986702, 81.60086452960968, 79.97710525989532, 83.04018929600716, 79.34244811534882, 80.02945125102997, 74.90080565214157, 75.70761635899544, 75.42239606380463, 74.62618678808212, 73.71904626488686, 75.93378782272339, 75.0515815615654, 76.61354094743729, 79.93139371275902, 79.27069276571274, 77.52489924430847, 79.47693049907684, 82.44362130761147, 81.99972912669182, 81.44490569829941, 84.32880654931068, 77.40165665745735, 89.3412771821022, 28.30855317413807, 1.083088181912899, 9.031002949923277, 9.52347457408905, 0.49868096597492695, 0.5394924979191273, 0.2794841764261946, 2.567273103632033, 0.15247519011609256, 0.37179752136580646, 0.11944271653192118, 4.963065208867192, 48.057412058115005, 70.51723927259445, 73.6178120970726, 52.397193387150764, 61.48756340146065, 63.945172727108, 40.68018011748791, 55.21191135048866, 71.56874924898148, 59.85661871731281, 64.40851226449013, 81.60549268126488, 76.5416032075882, 91.15164443850517, 33.61872263252735, 0.35302819102071226, 0.2070110512431711, 0.24609648127807304, 0.15283036715118214, 0.1477154259919189, 0.1356034423224628, 0.12006799079244956, 0.11421119881561026, 0.06228426136658527, 0.09135128406342119, 0.15109801635844633, 0.07284472594619729, 0.14767159475013614, 0.16125760244904086, 0.14752696501091123, 0.16087720723589882, 0.12076577288098633, 0.1375065464526415], [0.03674885971122421, 0.056127712232409976, 0.041240526697947644, 0.0697491983009968, 0.007276307578649721, 0.04362197840237059, 0.030960230287746526, 0.014550310788763454, 0.005994581433697022, 0.06962387182284147, 0.05371690487663727, 0.03687738113512751, 0.041222785657737404, 0.021937696074019186, 0.04942316125379875, 0.060049524836358614, 0.06696903888951056, 0.04477451147977263, 1.8221698980778456, 65.55569350719452, 70.81790953874588, 60.668296962976456, 57.81410671770573, 39.35994476079941, 43.94198589026928, 40.16395501792431, 47.18035452067852, 38.99970129132271, 36.15095615386963, 45.81571474671364, 37.612627521157265, 22.047015465795994, 5.22068758495152, 0.08213896042434499, 0.0713618629379198, 0.025943042965081986, 0.14817929797573015, 0.1163503727002535, 0.20129160111537203, 3.313145530410111, 0.41421259695198387, 0.29135862831026316, 59.34341445565224, 89.75359305739403, 78.29022377729416, 104.20101821422577, 97.22251787781715, 97.89721727371216, 94.69445273280144, 98.96890416741371, 95.37992835044861, 86.98402807116508, 76.45527184009552, 89.27534312009811, 83.81016477942467, 86.26596540212631, 85.35686418414116, 85.759756565094, 85.49717545509338, 84.83006805181503, 82.58430495858192, 83.78580048680305, 80.81184446811676, 82.41719752550125, 84.70191612839699, 84.14443284273148, 84.60786357522011, 83.2455150783062, 84.4354896247387, 88.2226400077343, 85.54150387644768, 84.06792014837265, 83.14696356654167, 77.53123730421066, 78.56415867805481, 79.47301670908928, 85.19129186868668, 85.0518849492073, 80.22657707333565, 73.83186981081963, 71.38727098703384, 77.05982699990273, 72.05851256847382, 82.65197172760963, 77.35858976840973, 52.47736908495426, 66.1787536740303, 64.51597809791565, 53.518235832452774, 30.193922705948353, 82.97830581665039, 74.16706502437592, 74.60534110665321, 67.42631793022156, 73.12143713235855, 76.31962671875954, 76.41805663704872, 74.28954765200615, 77.09353119134903, 77.95803040266037, 80.36220699548721, 78.44355314970016, 76.73341691493988, 77.19746321439743, 77.3971500992775, 75.39651185274124, 77.54119277000427, 76.97620868682861, 75.4427021741867, 76.27394556999207, 77.38107696175575, 75.12381568551064, 74.32958230376244, 73.35023805499077, 72.59923115372658, 69.4838847219944, 71.29272446036339, 67.70064041018486, 69.65668424963951, 70.91462954878807, 65.11686265468597, 66.37487635016441, 72.73397952318192, 73.55819329619408, 70.50066456198692, 71.97385311126709, 74.33848902583122, 71.47960603237152, 69.37894955277443, 77.11444526910782, 66.06165155768394, 60.12608505785465, 13.670200612396002, 0.42333860881626606, 4.103274894878268, 3.75044506508857, 1.4534450462087989, 0.3874225204344839, 0.15420345909660682, 0.13723057141760364, 0.06168719242850784, 0.08994964911835268, 0.1088025007629767, 4.791004741564393, 32.41561599075794, 43.347173407673836, 49.5168187469244, 37.60763458907604, 46.161310002207756, 45.579944998025894, 36.40869252383709, 28.682907186448574, 41.46071143448353, 46.17513746023178, 43.06983768939972, 56.5885204821825, 57.556301951408386, 54.67425920069218, 7.351634614169598, 0.11049651220673695, 0.049803400615928695, 0.034494771680328995, 0.1048722944688052, 0.028724968688038643, 0.05812156246975064, 0.032405314268544316, 0.04200345079880208, 0.047612061171093956, 0.03818133089225739, 0.05767557995568495, 0.03825256593700033, 0.06256785825826228, 0.04566503674141131, 0.02316972615517443, 0.02679342545889085, 0.02897431175370002, 0.05381348426453769, 0.051730605991906486, 0.044975036071264185, 0.04721952442196198, 0.005807868674310157, 0.040971858106786385, 0.06288713761023246, 0.018548227853898425, 0.024031515458773356, 0.02768324011412915, 0.017370239111187402, 0.03804126536124386, 0.0050629040833882755, 0.06092696603445802, 0.08002596950973384, 0.06356202444294468, 0.002391736479694373, 0.070468131598318, 3.8008431857451797, 81.78920522332191, 79.46461156010628, 73.82576733827591, 63.40257704257965, 52.73836947977543, 47.94611223042011, 39.100285694003105, 31.079140305519104, 25.09426575154066, 31.462083756923676, 36.41995891928673, 37.9705835133791, 25.15815932303667, 3.293438362888992, 0.06972464063437656, 0.031189620713121258, 0.09478539432166144, 0.43805162713397294, 0.6645475281402469, 2.01487940736115, 1.0288922837935388, 0.4038429830688983, 1.4341090712696314, 79.0288357436657, 97.13084399700165, 88.18648874759674, 107.52710893750191, 102.35460609197617, 101.18923902511597, 99.66047465801239, 101.55220314860344, 98.95330220460892, 86.3436408340931, 81.64287507534027, 93.04490804672241, 87.23018646240234, 90.02695798873901, 91.74011126160622, 90.55536523461342, 90.01799046993256, 85.44992879033089, 85.28415888547897, 86.2133002281189, 84.71018448472023, 84.91353437304497, 88.76361697912216, 88.05513739585876, 88.10116052627563, 87.02704176306725, 89.02315825223923, 90.49963742494583, 89.46855515241623, 86.88489139080048, 84.15176644921303, 83.50498795509338, 81.71420484781265, 83.17928463220596, 88.01592350006104, 89.25512060523033, 84.91142928600311, 77.2385922074318, 74.28500309586525, 78.02626714110374, 75.75041726231575, 82.66403988003731, 81.88666239380836, 59.12881337106228, 69.84298825263977, 64.54201430082321, 59.22057464718819, 31.348032876849174, 80.9832912683487, 78.82356315851212, 76.24453514814377, 73.527262955904, 76.5722143650055, 79.9127747118473, 78.49039703607559, 79.05669584870338, 78.75644356012344, 80.32861679792404, 81.24214097857475, 82.40743964910507, 79.40006822347641, 81.6981241106987, 83.15460875630379, 79.27353501319885, 79.97261390089989, 79.59739923477173, 78.37090864777565, 77.98777520656586, 79.02014181017876, 77.61990934610367, 79.10765871405602, 77.31128990650177, 75.88863104581833, 72.60252937674522, 75.28849884867668, 71.43845424056053, 72.00003370642662, 74.5433360338211, 71.12499386072159, 69.16613817214966, 74.02362272143364, 76.87957227230072, 75.16736134886742, 73.52304518222809, 77.61681631207466, 76.72053560614586, 75.61933189630508, 80.61368510127068, 73.53764399886131, 69.69150558114052, 26.592844538390636, 0.38145998725667596, 1.7075812281109393, 2.0322432881221175, 4.1751309391111135, 1.599654194433242, 0.24445946677587926, 0.10212445558863692, 0.09141009184531868, 0.13613740273285657, 0.17185894452268258, 3.6607724893838167, 33.58876124024391, 49.02131773531437, 55.29078371822834, 39.960445538163185, 38.59007187187672, 23.097372204065323, 30.101030990481377, 42.31418363749981, 54.7575469315052, 61.3064157217741, 63.66120256483555, 73.50729122757912, 67.518972158432, 68.38768914341927, 12.613468766212463, 0.12943738256581128, 0.12406128706061281, 0.07082569834892638, 0.09794510289793834, 0.007111811937647872, 0.07116589142242447, 0.028299656842136756, 0.04150370339630172, 0.052515891002258286, 0.025198726361850277, 0.02225534826720832, 0.03635217435657978, 0.029986994522914756, 0.01985717968636891, 0.027874781007994898, 0.021814158171764575, 0.06130548732471652, 0.15843456174479797, 0.14463352417806163, 0.13050295819994062, 0.21022067667217925, 0.14018820802448317, 0.10138083845959045, 0.14645696617662907, 0.14968593197409064, 0.185019597702194, 0.16832416935358196, 0.2061120283906348, 0.12133212803746574, 0.15007124020485207, 0.1465298153925687, 0.10313825900084339, 0.265212498488836, 0.1291709960787557, 0.35889080143533647, 6.203094944357872, 99.1411717236042, 91.05873182415962, 85.61743140220642, 79.48535084724426, 63.55245240032673, 67.85601407289505, 66.73403307795525, 75.02814441919327, 64.95283305644989, 53.48904959857464, 77.88986206054688, 55.43306328356266, 39.832700192928314, 8.07187456637621, 0.2534196828491986, 0.1712167344521731, 0.28941221244167536, 0.3821257530944422, 0.49379671399947256, 2.3572887713089585, 8.029305450618267, 1.508384991902858, 1.0324124386534095, 72.1352456510067, 100.22082298994064, 91.10370621085167, 112.93210610747337, 103.6843067407608, 104.88156169652939, 101.9927667081356, 104.90565240383148, 103.72612729668617, 93.14947843551636, 83.38664710521698, 96.4024230837822, 90.91934010386467, 93.82539376616478, 94.80739027261734, 92.87944972515106, 92.31230735778809, 93.05419474840164, 90.78052595257759, 92.28771507740021, 87.5331138074398, 88.87969315052032, 90.669746696949, 90.57605892419815, 91.25443652272224, 91.31858468055725, 91.05085104703903, 95.80922171473503, 91.4968179166317, 88.00041273236275, 87.85779878497124, 85.66952660679817, 86.60524159669876, 84.55256134271622, 90.00270009040833, 91.31041511893272, 85.94271674752235, 80.40895208716393, 78.6937165260315, 83.64016190171242, 77.70850539207458, 85.69548681378365, 85.12120082974434, 57.793283835053444, 66.82545617222786, 64.66365337371826, 56.18245147168636, 38.03741812705994, 89.40424740314484, 80.5343833565712, 79.31635111570358, 77.06733539700508, 77.96848744153976, 82.9519048333168, 82.20186308026314, 81.57960087060928, 83.6015559732914, 84.00485873222351, 85.7310301065445, 86.81292325258255, 81.36452481150627, 84.46227818727493, 86.23394072055817, 80.61596497893333, 84.28377136588097, 82.63053327798843, 80.40203645825386, 81.46933078765869, 83.97323682904243, 78.1950768828392, 79.8158723115921, 79.74844872951508, 77.84587562084198, 75.41106507182121, 79.23400193452835, 74.0610659122467, 74.77264612913132, 79.46484714746475, 72.37667709589005, 73.80154743790627, 77.6444636285305, 79.73416909575462, 77.20925018191338, 77.56991922855377, 81.3793820142746, 78.35264682769775, 77.9170610010624, 83.51976156234741, 73.636674284935, 75.31832724809647, 24.18757550418377, 1.9533440843224525, 12.658101171255112, 6.531753558665514, 2.9893022077158093, 0.6460180599242449, 0.10274939588271081, 0.4640736401779577, 0.23766844446072355, 0.26369403465650976, 0.2764159895014018, 10.000398382544518, 50.81730276346207, 56.35489761829376, 66.53168633580208, 57.89148956537247, 67.19078376889229, 67.15279340744019, 58.9603266119957, 42.774521335959435, 57.55899600684643, 63.48552659153938, 64.354547560215, 78.19247782230377, 76.06668189167976, 81.8058331310749, 14.84033927321434, 0.26608490792568773, 0.3028507553972304, 0.15582989057293162, 0.15958595933625475, 0.114874151913682, 0.1442570029757917, 0.12866603879956529, 0.12040478482958861, 0.19181171839591116, 0.11346655010129325, 0.1585019932826981, 0.12072513287421316, 0.2369031120906584, 0.06986132197198458, 0.1064885436790064, 0.0860370094596874, 0.14519561198540032], [0.02618430218717549, 0.05738859515986405, 0.022251416739891283, 0.02306212958501419, 0.03907676917151548, 0.10694422235246748, 0.04412248650623951, 0.01092659014830133, 0.07097744528437033, 0.00413620839935902, 0.007172386494858074, 0.025238403432013, 0.08979521560831927, 0.04919925529975444, 0.06385463100741617, 0.06495015230029821, 0.03387387238035444, 0.038900965519133024, 1.9346107332967222, 63.542253747582436, 63.482330963015556, 61.57865211367607, 57.93393328785896, 60.13283349573612, 47.38340422511101, 39.66081641614437, 40.575096756219864, 54.93061624467373, 31.82859878987074, 36.893702298402786, 30.198049284517765, 11.479524113237858, 0.3439312713453546, 0.07939812741824426, 0.07048283354379237, 0.06907381422934122, 0.008883703430910828, 0.38534331950359046, 0.9368084999732673, 0.38604277884587646, 0.5012442846782506, 28.54194425046444, 116.30881771445274, 83.61702114343643, 99.34776663780212, 99.53387305140495, 98.11329647898674, 96.79252535104752, 98.8320355117321, 90.41210532188416, 87.6297502219677, 78.26615586876869, 88.29997345805168, 84.57700923085213, 85.69483324885368, 87.23356068134308, 86.95352330803871, 83.52066591382027, 82.97610193490982, 79.77624043822289, 76.45229279994965, 76.13177239894867, 84.25196707248688, 82.4795749783516, 84.42792043089867, 79.35218319296837, 85.13990342617035, 87.63681024312973, 86.66814342141151, 86.21637806296349, 88.05451422929764, 86.59723922610283, 85.75038626790047, 83.18006739020348, 80.95839500427246, 80.70497140288353, 85.11712744832039, 79.6719816327095, 86.102764159441, 81.7517240345478, 72.50294432044029, 68.47478047013283, 80.1521846652031, 79.04515966773033, 77.62918844819069, 72.11179330945015, 72.93305844068527, 56.29798427224159, 70.40881589055061, 37.66859471797943, 52.559402883052826, 75.53254455327988, 67.34700098633766, 69.52337220311165, 67.5030206143856, 73.53400379419327, 71.18203639984131, 73.18727239966393, 74.2723497748375, 76.81605488061905, 72.13280618190765, 75.26226505637169, 73.3073915541172, 75.43690368533134, 75.07346838712692, 74.14686530828476, 73.77352014183998, 76.89445987343788, 76.79987534880638, 76.58973142504692, 75.81043884158134, 76.23096987605095, 72.98251658678055, 71.19529768824577, 69.73518043756485, 70.6387035548687, 68.60369995236397, 67.66018018126488, 68.3129395544529, 67.77863502502441, 69.82865542173386, 69.17110070586205, 66.45781829953194, 67.4965001642704, 74.69719737768173, 71.38753697276115, 71.54764518141747, 70.23967936635017, 75.99102035164833, 69.98991876840591, 80.03982469439507, 67.7438896894455, 74.00030717253685, 8.83238760754466, 0.12135691576986574, 7.441794751212001, 5.891307899728417, 1.1448620609007776, 1.2881821766495705, 0.05178311294002924, 0.0816201620909851, 0.09509607960353605, 0.044793855558964424, 0.04437646428414155, 7.60713005438447, 29.900971725583076, 31.08478680253029, 33.02388735115528, 35.5093339830637, 42.840155214071274, 38.3463529497385, 37.6311819255352, 26.482361666858196, 34.67408940196037, 39.99127708375454, 52.14702621102333, 54.32308204472065, 59.14514109492302, 40.7696995139122, 4.739558827131987, 0.056970958976307884, 0.08477355499053374, 0.060502290580188856, 0.036079067722312175, 0.06135587173048407, 0.060423956892918795, 0.035395111844991334, 0.04766168487549294, 0.04156636663537938, 0.03845144296064973, 0.04619740524503868, 0.03921301264199428, 0.03855428236420266, 0.03325847239466384, 0.03857016061374452, 0.08059895946644247, 0.016784213330538478, 0.030728511374036316, 0.01800056554202456, 0.0834052573191002, 0.032540529864490964, 0.039551309528178535, 0.06564034221810289, 0.054375089675886557, 0.03423304216994438, 0.019264237089373637, 0.052840309726889245, 0.03429187592701055, 0.0473202412831597, 0.027216084126848727, 0.06953142990823835, 0.05759999592555687, 0.10629198586684652, 0.13174791092751548, 3.9494619984179735, 79.85767766833305, 71.62651374936104, 75.76139107346535, 70.43062672019005, 67.28127211332321, 50.30651897192001, 23.168042711913586, 31.488488540053368, 57.67689988017082, 31.671359427273273, 39.793322905898094, 30.66483523696661, 9.51873717829585, 0.344306412152946, 0.12121313950046897, 0.11238805367611349, 0.06142397862276994, 0.3199425054481253, 2.6684203511103988, 1.0867124749347568, 0.2941052574897185, 0.7234687695745379, 44.53513786196709, 113.75831857323647, 89.4552330672741, 105.03496706485748, 100.27819991111755, 100.86803466081619, 101.09098389744759, 102.30460077524185, 93.54228615760803, 89.85006988048553, 85.15202477574348, 95.44147744774818, 87.27524444460869, 90.64336851239204, 91.1937765777111, 89.52115952968597, 88.35048794746399, 85.69994017481804, 84.82118412852287, 80.47623127698898, 80.29682770371437, 88.35231944918633, 84.61078941822052, 88.38821232318878, 83.57601374387741, 89.39652621746063, 89.42698538303375, 88.48291844129562, 88.77735704183578, 91.37954860925674, 88.65327849984169, 89.3261843919754, 86.34221211075783, 86.04473367333412, 84.38368320465088, 88.95098492503166, 82.55088195204735, 88.76058474183083, 84.66755837202072, 75.97448363900185, 70.95840319991112, 83.94869014620781, 81.20270669460297, 83.33856448531151, 77.11439967155457, 72.72179737687111, 59.31188754737377, 72.28697150945663, 46.83334194123745, 56.764211654663086, 77.60062918066978, 72.00144723057747, 73.64771649241447, 70.73220893740654, 77.96075865626335, 73.34187850356102, 78.03357034921646, 78.06668937206268, 80.29014766216278, 77.54439979791641, 77.83908918499947, 76.98092043399811, 78.46706628799438, 77.82819896936417, 76.79039865732193, 76.33411914110184, 81.61704406142235, 77.50590026378632, 80.19796460866928, 77.74721011519432, 80.14752611517906, 77.4011854827404, 75.20177990198135, 72.52489194273949, 73.60054582357407, 70.13262391090393, 70.81856310367584, 71.88268080353737, 70.71327835321426, 73.779706209898, 73.50120395421982, 70.27903005480766, 70.42571738362312, 76.84964507818222, 75.84515377879143, 72.67029494047165, 74.86752703785896, 77.97153487801552, 74.01461720466614, 82.37323388457298, 76.6709178686142, 81.11519739031792, 18.34137260913849, 0.4653723689261824, 3.590965485200286, 6.482868231832981, 5.102921454235911, 2.361952308565378, 0.1900931418640539, 0.0695110579545144, 0.15819700027350336, 0.05673893763741944, 0.16513799579115584, 6.198620209470391, 32.04458869993687, 34.361183792352676, 35.936822444200516, 37.939463183283806, 38.50177600979805, 18.290191255509853, 36.06715925037861, 33.161272779107094, 48.076544031500816, 56.480423882603645, 65.57970061898232, 71.30891919136047, 69.47818502783775, 59.287785440683365, 7.502524517476559, 0.11279722937615588, 0.18401847017230466, 0.018982662550115492, 0.06008329255564604, 0.009299629891756922, 0.07576107687782496, 0.031793001617188565, 0.028944110053998884, 0.05727983712858986, 0.04980321507900953, 0.0403106638987083, 0.05061520998424385, 0.017570782256370876, 0.15848014445509762, 0.027645698573905975, 0.08602360627264716, 0.06921772408531979, 0.18036373425275087, 0.09846345594269224, 0.15565495152259246, 0.06675122596789151, 0.18494695628760383, 0.22710351215209812, 0.09792224474949762, 0.17439903400372714, 0.04912185300781857, 0.09628448067815043, 0.17353818722767755, 0.1698004940408282, 0.09835243807174265, 0.21308748924639076, 0.16396684222854674, 0.20023717253934592, 0.4401676979614422, 7.181203309446573, 99.56121638417244, 83.11301618814468, 93.93443271517754, 81.79443374276161, 88.03216382861137, 74.735157340765, 63.22963312268257, 58.95290181040764, 82.58638724684715, 50.52867405116558, 58.886922150850296, 46.40364199876785, 17.39641271531582, 0.8739298896398395, 0.2881599421380088, 0.2615731843980029, 0.2747363015078008, 0.13473153754603118, 2.2781786788254976, 2.533560125157237, 0.7027561997529119, 1.1586958123371005, 39.12285268306732, 125.21708250045776, 94.50553447008133, 106.20933204889297, 104.11078065633774, 105.50952360033989, 104.14120182394981, 107.6957818865776, 99.40671667456627, 96.75110757350922, 88.03350895643234, 96.48395910859108, 91.9344936311245, 93.3379939198494, 94.0265017747879, 94.24245178699493, 91.25732436776161, 91.72181144356728, 86.9109807908535, 84.96470242738724, 82.64986664056778, 91.68632134795189, 88.33976492285728, 94.17983874678612, 86.42858147621155, 93.10780227184296, 92.2936275601387, 91.84864103794098, 93.30968543887138, 94.1474036872387, 92.22735911607742, 91.21614217758179, 89.79779228568077, 87.92106539011002, 88.41350376605988, 94.41674083471298, 85.5530172586441, 93.30947265028954, 88.9991283416748, 79.65684324502945, 73.71223703026772, 87.60825097560883, 84.70806419849396, 88.6135022342205, 78.76829892396927, 70.7103981077671, 58.76788593828678, 70.33290356397629, 49.281132593750954, 60.589378997683525, 78.48464414477348, 77.27861925959587, 76.34997949004173, 75.44763430953026, 82.98722013831139, 78.64292085170746, 81.59801468253136, 80.38134276866913, 83.66868317127228, 80.44874355196953, 82.56750985980034, 80.00415980815887, 83.11521247029305, 82.70031273365021, 78.62080603837967, 79.00651574134827, 83.95816683769226, 82.27193892002106, 83.7079730629921, 82.94258013367653, 83.10053005814552, 82.34098121523857, 77.56811812520027, 74.74566757678986, 77.35560312867165, 74.59264978766441, 74.11107122898102, 74.80430603027344, 75.90353384613991, 77.15436592698097, 75.55321544408798, 74.18237060308456, 73.65600764751434, 80.97544848918915, 77.96006709337234, 77.14825585484505, 77.93887943029404, 84.01356026530266, 74.18721154332161, 89.30777817964554, 75.2813096344471, 86.36651560664177, 14.43022632971406, 1.4517264696769416, 16.92215446382761, 11.929373424500227, 4.358239788562059, 1.964350906200707, 0.24323906429344788, 0.31598083209246397, 0.3448795579606667, 0.1215217616118025, 0.2347695265780203, 15.438442379236221, 47.06998564302921, 41.56095005571842, 50.04258893430233, 53.85039880871773, 61.45517013967037, 53.392120599746704, 58.41844528913498, 39.24961768090725, 50.952404513955116, 55.93966729938984, 72.29420632123947, 75.8056890964508, 80.41086718440056, 66.58356115221977, 7.387664280831814, 0.27332720055710524, 0.3067000082228333, 0.18211061629699543, 0.15999479364836589, 0.1279402183718048, 0.20836777141084895, 0.11572119474294595, 0.13993883156217635, 0.16254119138466194, 0.15254515979904681, 0.24947878962848336, 0.12569894723128527, 0.14419015031307936, 0.24571483925683424, 0.19133199413772672, 0.24236901488620788], [0.018100030029017944, 0.06503340642666444, 0.028949056468263734, 0.03522616934787948, 0.054601915981038474, 0.03853170623187907, 0.019052756542805582, 0.02496571425581351, 0.02377154669375159, 0.020599449817382265, 0.04059649094415363, 0.07840383506845683, 0.02170211613702122, 0.005511509161806316, 0.10562319206655957, 0.06148811873572413, 0.15781436377437785, 0.1368486919091083, 2.125316681340337, 64.02463406324387, 60.04945456981659, 56.06465399265289, 47.1202227473259, 41.67834855616093, 37.315601259469986, 47.939116805791855, 37.70830638706684, 39.54940639436245, 37.56419152021408, 41.76897369325161, 16.533078141510487, 1.0448815883137286, 0.03966681739257183, 0.07505936140660197, 0.06165869395772461, 0.1285727063077502, 0.3799814806552604, 1.575524895451963, 1.1514581507071853, 0.3970880142878741, 6.284260964021087, 90.44761061668396, 80.08220002055168, 93.37097615003586, 99.26085010170937, 96.45963281393051, 95.93607410788536, 94.76887553930283, 90.57158276438713, 89.79978337883949, 81.72086969017982, 87.6882366836071, 89.63842123746872, 86.74700438976288, 90.48320710659027, 85.1550418138504, 83.13692450523376, 77.71740451455116, 78.49900737404823, 74.4736097753048, 75.35997301340103, 80.99166601896286, 81.93397745490074, 81.10264286398888, 82.90264427661896, 85.3520992398262, 84.70421120524406, 83.11392813920975, 82.04708978533745, 87.02090129256248, 86.88195034861565, 84.15815770626068, 85.12539580464363, 82.80077934265137, 81.03309899568558, 80.8297947049141, 81.17685288190842, 78.67112293839455, 80.03744602203369, 78.03916364908218, 72.52382040023804, 66.46569147706032, 79.80441212654114, 72.78900817036629, 74.13597509264946, 79.64634820818901, 69.24637466669083, 59.42542925477028, 71.72798350453377, 68.2101246714592, 69.98899161815643, 72.36748918890953, 69.41324651241302, 69.15157735347748, 66.1411964893341, 68.05550336837769, 69.84003201127052, 75.91898381710052, 75.78884080052376, 76.04759931564331, 73.88974070549011, 75.52126675844193, 74.57706302404404, 73.8434287905693, 72.43299007415771, 75.606739372015, 77.35570952296257, 76.115592867136, 75.48618704080582, 74.76233348250389, 73.7725093960762, 73.25588151812553, 69.89007532596588, 72.19629317522049, 69.23539325594902, 66.75177812576294, 66.8697389960289, 66.83794990181923, 68.15167620778084, 66.79344668984413, 65.56698650121689, 71.01299867033958, 70.76223492622375, 68.86725381016731, 66.08441233634949, 74.00992065668106, 71.10257506370544, 69.86381113529205, 67.86649391055107, 75.39135932922363, 69.66377466917038, 71.56372591853142, 72.67789453268051, 64.6121433377266, 4.993793684989214, 2.5872887670993805, 6.355457743629813, 6.447984678670764, 3.5591049073264003, 0.16735275741666555, 0.38484741642605513, 0.16366812778869644, 0.08212926055421121, 0.021735778100264724, 0.15555382648017257, 17.468130066990852, 28.702422939240932, 25.700515620410442, 31.748071610927582, 35.001286044716835, 45.89624762535095, 41.118429601192474, 38.82977440953255, 35.00733532011509, 34.29377160966396, 40.50830774009228, 42.35163062810898, 52.20062993466854, 59.099475145339966, 34.958298951387405, 0.731520775007084, 0.06164864156744443, 0.03429577591305133, 0.027667721806210466, 0.07576190066174604, 0.05882892568479292, 0.03426905859669205, 0.03805842381552793, 0.016365519586543087, 0.039189961535157636, 0.04394925068481825, 0.009446566782571608, 0.06342048203805462, 0.04035045043565333, 0.03608436294598505, 0.01714614947559312, 0.008625183709227713, 0.07221148101962171, 0.02416337469185237, 0.025428044427826535, 0.048595840999041684, 0.01959422748768702, 0.02278624175232835, 0.03486737063212786, 0.009910692951962119, 0.020183232991257682, 0.08216265719966032, 0.030948387466196436, 0.0670168777287472, 0.016414727688243147, 0.07020222008577548, 0.045225299400044605, 0.17994976427871734, 0.21384036837844178, 6.041194656863809, 81.37837126851082, 70.52922382950783, 66.74946784973145, 51.01366862654686, 50.01724049448967, 34.237880408763885, 36.539356112480164, 40.8250093460083, 52.85867482423782, 43.37741978466511, 44.09453630447388, 16.143899224698544, 0.24828795430948958, 0.09513352837529965, 0.027045562710554805, 0.039605464044143446, 0.4469059535767883, 2.343567470088601, 2.439915337599814, 1.3204365083947778, 0.7908263301942497, 13.42156095430255, 99.97567534446716, 82.88729310035706, 101.9257003068924, 101.63042575120926, 101.30913779139519, 100.54324328899384, 99.09411504864693, 93.8429944217205, 93.22747305035591, 87.76184633374214, 93.84712859988213, 92.72285252809525, 89.49795797467232, 92.19102546572685, 88.46895039081573, 85.76554745435715, 82.63737291097641, 82.48917326331139, 78.88836488127708, 78.71371105313301, 85.05395963788033, 83.9237330853939, 84.25698280334473, 86.61655738949776, 87.90306955575943, 85.70130810141563, 86.11737817525864, 83.82474839687347, 88.77469718456268, 89.12597313523293, 87.22060337662697, 87.90297076106071, 87.57038980722427, 84.97645899653435, 85.54690718650818, 81.96813762187958, 82.94565796852112, 84.52641874551773, 81.97712033987045, 76.39491587877274, 69.54873964190483, 78.73804494738579, 76.68298602104187, 79.06127840280533, 83.53667065501213, 71.13819435238838, 58.790509924292564, 74.00033757090569, 79.49231967329979, 76.67729392647743, 77.85200089216232, 73.20576220750809, 74.39639791846275, 68.33145216107368, 71.64672866463661, 74.83690828084946, 79.7752220928669, 78.0992004275322, 79.47493940591812, 77.13570892810822, 78.268131762743, 75.46926274895668, 75.84396824240685, 76.49767756462097, 78.76722738146782, 79.905304312706, 80.71681156754494, 79.53388184309006, 76.77594423294067, 76.46366938948631, 75.417061150074, 71.07050478458405, 74.04872417449951, 71.76705300807953, 70.79954892396927, 69.84660565853119, 71.17189094424248, 69.14369657635689, 71.4919401705265, 69.27988886833191, 72.20625624060631, 76.02990746498108, 74.94748994708061, 69.66200396418571, 74.94050592184067, 73.52229282259941, 73.94068837165833, 71.17460399866104, 77.29516357183456, 72.53547817468643, 77.55247056484222, 76.37359902262688, 77.9985286295414, 11.463047247380018, 1.225740839727223, 3.19530435372144, 9.162901472300291, 6.905897632241249, 1.422417217399925, 0.8444900193717331, 0.13897617696784437, 0.13256982463644817, 0.013465345618897118, 0.1520582367083989, 14.065029826015234, 32.00773827731609, 31.021307408809662, 39.63879659771919, 39.08782236278057, 39.79996494948864, 14.090337418019772, 30.51471669226885, 46.29129342734814, 46.90553046762943, 55.590070858597755, 59.541155844926834, 68.12213659286499, 69.16363030672073, 51.488396152853966, 1.2344307359308004, 0.0588911881641252, 0.12331351390457712, 0.007100405127857812, 0.03776041812670883, 0.06387004541466013, 0.04423973470693454, 0.010448989360156702, 0.028946540587639902, 0.04538508379482664, 0.012553350952657638, 0.01803882511012489, 0.04124997052713297, 0.014964519177738111, 0.012665397625823971, 0.03720437511219643, 0.09786664304556325, 0.21707068488467485, 0.17041751561919227, 0.12525699828984216, 0.1307265376090072, 0.10882642018259503, 0.10756502146250568, 0.15686045167967677, 0.12921438203193247, 0.1578502540360205, 0.2116869972087443, 0.11343314603436738, 0.06345174129819497, 0.16179432364879176, 0.2254356539924629, 0.12610016710823402, 0.37690468481741846, 0.48975162324495614, 9.78383470326662, 101.13794937729836, 82.40829080343246, 86.37470796704292, 67.29894116520882, 69.66076523065567, 61.24992415308952, 69.8990124464035, 55.85455946624279, 62.435050159692764, 56.90928407013416, 62.561218589544296, 25.836495123803616, 1.8225260102190077, 0.2120672885212116, 0.22215111617697403, 0.12053067533997819, 0.3766299120616168, 2.23591900896281, 7.742194281890988, 7.443524608388543, 1.2306284462101758, 12.071702387183905, 109.60698053240776, 89.25968796014786, 102.76678517460823, 104.5027144253254, 105.2934367954731, 104.9555741250515, 100.32433703541756, 97.38581031560898, 97.41873174905777, 91.10573530197144, 95.88691234588623, 97.56056293845177, 93.61915603280067, 95.74664667248726, 91.86577811837196, 89.8301437497139, 84.661965072155, 85.9857988357544, 81.56480446457863, 79.1001883149147, 87.88497492671013, 88.31054449081421, 88.82699757814407, 89.5281283557415, 92.61122211813927, 89.31818962097168, 91.59498944878578, 86.23872846364975, 93.49067732691765, 94.92490276694298, 91.60984665155411, 92.80960947275162, 90.78408256173134, 88.27892258763313, 87.74308294057846, 84.6962696313858, 84.93821024894714, 87.56991103291512, 83.65968525409698, 79.12969753146172, 75.136309415102, 84.52572718262672, 79.90266725420952, 84.5344515144825, 85.67790135741234, 72.97908157110214, 58.993134051561356, 77.05790430307388, 84.70057100057602, 74.23624411225319, 79.17284801602364, 73.99528384208679, 78.69833707809448, 73.34044978022575, 75.54267480969429, 74.15541484951973, 81.36672109365463, 81.57238125801086, 82.65746623277664, 82.34669610857964, 82.58271664381027, 79.6131531894207, 81.45071938633919, 79.94257271289825, 80.99816367030144, 83.46492290496826, 84.79226008057594, 82.07367315888405, 80.54551675915718, 81.13136172294617, 81.38782516121864, 73.94348502159119, 78.72149303555489, 74.8810163140297, 72.80514970421791, 73.38624492287636, 76.05654403567314, 74.65869024395943, 73.03694486618042, 70.79667627811432, 77.68104806542397, 79.49631705880165, 77.5767208635807, 74.45616111159325, 81.39717265963554, 77.9535086452961, 75.34361109137535, 72.71709322929382, 83.46168547868729, 73.63403722643852, 80.78738898038864, 81.63678020238876, 81.75534904003143, 9.214410558342934, 6.062999311834574, 16.342894546687603, 13.607672117650509, 7.072684457525611, 0.3293976152781397, 0.7822425314225256, 0.45714008098002523, 0.22036205045878887, 0.19814324739854783, 0.41779981227591634, 27.681839503347874, 46.56502313911915, 39.50503997504711, 50.85837855935097, 52.203077003359795, 68.47744032740593, 57.64631152153015, 59.22417685389519, 53.4678353369236, 48.80892813205719, 56.78033798933029, 62.47584097087383, 71.87655553221703, 82.69373148679733, 55.87983950972557, 1.2284084153361619, 0.1102493992948439, 0.21038486942416057, 0.17155622248537838, 0.12728776666335762, 0.22093863983172923, 0.2653713774634525, 0.1053901354316622, 0.10264496086165309, 0.06623370412853546, 0.12200564189697616, 0.09751786332344636, 0.1425944734364748, 0.1270739539177157, 0.10335889208363369, 0.1214150853047613], [0.013617381991934963, 0.04548261313175317, 0.12346347968559712, 0.012760583631461486, 0.06404596409993246, 0.03823628692771308, 0.03727572890056763, 0.02386382533586584, 0.021856961539015174, 0.05169306445168331, 0.04465690704819281, 0.007946837540657725, 0.040618577259010635, 0.0018981829953190754, 0.08299954002723098, 0.06572816055268049, 0.16855908877914771, 0.18897120753536, 7.2922243271023035, 69.07001093029976, 57.883057817816734, 54.7309635579586, 55.527180433273315, 54.00577627122402, 46.148633882403374, 31.712231934070587, 32.70852707326412, 31.543103009462357, 36.38352647423744, 28.608142398297787, 2.030347427353263, 0.1862149898079224, 0.0792674723197706, 0.17231628560693935, 0.04340281848271843, 0.43832690455019474, 2.598804999142885, 3.698972789570689, 0.21448611107189208, 0.39219963597133756, 53.571592569351196, 84.58332449197769, 90.81649482250214, 101.13269045948982, 96.6370452940464, 98.04886713624, 97.35863417387009, 94.1117312014103, 90.08428171277046, 83.96738514304161, 87.22664505243301, 90.92833802103996, 87.8954091668129, 89.48573023080826, 84.86814960837364, 83.85720625519753, 82.19750851392746, 80.20266115665436, 76.88780263066292, 74.7063472867012, 81.3341036438942, 77.5011733174324, 74.54026579856873, 78.25444489717484, 83.00181895494461, 81.51820376515388, 80.1055383682251, 85.9651431441307, 81.63806453347206, 84.1926446557045, 82.86979123950005, 83.52426052093506, 84.80262592434883, 83.36611300706863, 82.02511176466942, 83.89219477772713, 76.8053774535656, 78.08525517582893, 82.30346202850342, 76.63255512714386, 71.293765604496, 65.05820140242577, 69.84385460615158, 72.97487139701843, 78.43408405780792, 75.92817172408104, 68.69988799095154, 61.886564791202545, 69.71034497022629, 62.487855926156044, 79.1981090605259, 74.3348640203476, 70.60952872037888, 71.6009259223938, 64.07017841935158, 64.93238255381584, 75.52606970071793, 73.81134331226349, 74.54985648393631, 71.07892513275146, 71.86475336551666, 69.48578462004662, 71.23036220669746, 72.06442505121231, 73.05817812681198, 73.31581950187683, 75.65508797764778, 72.49251767992973, 70.89307710528374, 71.75333574414253, 73.43347638845444, 69.02274906635284, 67.28123411536217, 67.28064894676208, 66.26213639974594, 63.27066712081432, 66.5822160243988, 64.83186274766922, 64.85487431287766, 68.28906163573265, 71.96788743138313, 67.7253694832325, 69.10802409052849, 71.36326387524605, 69.89388272166252, 68.67106273770332, 69.77825492620468, 71.32968127727509, 72.81602472066879, 67.34110370278358, 70.52385091781616, 73.36619719862938, 72.20133930444717, 72.66110703349113, 50.44643126428127, 1.0147923091426492, 6.436554891988635, 8.38001998141408, 5.0801497511565685, 0.2478772052563727, 0.21504764968995005, 0.06916071972227655, 0.1157110718486365, 0.03873674308124464, 0.043082604024675675, 0.6372592924162745, 19.256779588758945, 34.340224117040634, 25.753965452313423, 26.02762296795845, 31.133317798376083, 54.921264946460724, 39.957504495978355, 34.18032109737396, 51.40779107809067, 53.15633185207844, 50.628441497683525, 45.238936096429825, 55.96023179590702, 53.988422602415085, 14.481190145015717, 0.2447754138847813, 0.08419525125646032, 0.039107690754462965, 0.061730930901831016, 0.06439510005293414, 0.09372751475893892, 0.036123856334597804, 0.011193792070116615, 0.06213126762304455, 0.06981095983064733, 0.08530347811756656, 0.01429536729119718, 0.03491712792310864, 0.055104464991018176, 0.02262883965158835, 0.04775950736075174, 0.01893004427984124, 0.05333646884537302, 0.034383260281174444, 0.03626588855695445, 0.026007051346823573, 0.016957720035861712, 0.0585837089602137, 0.025166543127852492, 0.023090114118531346, 0.06712769521982409, 0.03608885293942876, 0.05214828299358487, 0.08492035922245122, 0.07558396333479322, 0.010083648612635443, 0.1781288010533899, 0.273616430349648, 9.833596833050251, 84.88648742437363, 68.97638395428658, 74.48323085904121, 58.33967551589012, 62.79579520225525, 33.303886726498604, 32.197541892528534, 48.241770565509796, 36.56513012945652, 42.21472777426243, 27.89880596101284, 1.1557570262812078, 0.2804074081359431, 0.019450345462246332, 0.11165927950059995, 0.18747923837509006, 3.36315939668566, 3.312272527255118, 1.7721293144859374, 0.7350371300708503, 1.684181964956224, 69.9540562927723, 88.10408636927605, 99.98211219906807, 102.41120785474777, 99.43884015083313, 100.64991116523743, 98.858702480793, 97.1285717189312, 93.19014385342598, 88.71355846524239, 90.62010616064072, 94.80305090546608, 90.18822893500328, 91.94242760539055, 87.41966709494591, 87.67954275012016, 85.12744769454002, 83.18075895309448, 79.31080341339111, 80.06136193871498, 82.89439871907234, 78.41155886650085, 80.0324758887291, 82.90908873081207, 85.88190481066704, 83.63871037960052, 84.6677939593792, 86.60743027925491, 83.32388207316399, 86.6683942079544, 86.32274195551872, 87.81142607331276, 86.57810345292091, 84.56907525658607, 86.3328418135643, 84.52216297388077, 78.27421143651009, 84.1441060602665, 84.31024074554443, 80.6564100086689, 76.23995259404182, 69.40272107720375, 74.38866913318634, 76.32846504449844, 82.59550675749779, 75.78311830759048, 69.44313570857048, 64.86952632665634, 73.20662096142769, 71.41720578074455, 78.92133191227913, 77.66732320189476, 75.5034077167511, 75.11690005660057, 69.5693801343441, 68.44324216246605, 76.29329413175583, 76.15093097090721, 78.02119821310043, 76.39765933156013, 76.78446337580681, 73.08007255196571, 74.48143735527992, 77.6107670366764, 76.60476341843605, 75.55000081658363, 77.44155451655388, 75.56287452578545, 73.95444363355637, 75.19268319010735, 74.47859510779381, 72.4980653822422, 69.70586121082306, 69.91654470562935, 67.87049129605293, 68.09876784682274, 69.07883405685425, 69.26850467920303, 68.63585382699966, 69.64005634188652, 73.9641635119915, 73.06649208068848, 72.87741422653198, 73.50803598761559, 73.94150152802467, 72.14182689785957, 73.86904701590538, 74.26284268498421, 77.00220689177513, 70.03428518772125, 74.80910897254944, 74.92939531803131, 79.01859909296036, 77.21230521798134, 65.13332337141037, 3.1088065076619387, 1.9616326270624995, 2.087232987396419, 6.817480176687241, 1.8914450495503843, 1.1380443954840302, 0.07019185970420949, 0.10036207007942721, 0.03539466284564696, 0.01962468151759822, 0.4944341297959909, 16.206438168883324, 35.98158024251461, 29.882827699184418, 32.4178084731102, 36.524548307061195, 36.92841723561287, 32.9678213596344, 32.36889369785786, 50.45300871133804, 70.10990113019943, 56.181132942438126, 61.13460414111614, 65.57811990380287, 67.32495456933975, 22.29432139545679, 0.29397814243566245, 0.049622290607658215, 0.06312373428954743, 0.012044833219988504, 0.07202421489637345, 0.0948600543779321, 0.08434561779722571, 0.01791149112250423, 0.016811971509014256, 0.024496120313415304, 0.04585105605656281, 0.045953988228575327, 0.03634913526184391, 0.022765658286516555, 0.020370139172882773, 0.13067892141407356, 0.17506754578789696, 0.2710105123696849, 0.14395960955880582, 0.11217393664992414, 0.11133278647321276, 0.14465467538684607, 0.13856375066097826, 0.11453723913291469, 0.06544737640069798, 0.19998776639113203, 0.10554770080489106, 0.15404272475279868, 0.1886557650868781, 0.29584782023448497, 0.18366311502177268, 0.33393270161468536, 0.6076035462319851, 14.893910698592663, 103.42038050293922, 80.17802327871323, 84.19800996780396, 82.97708988189697, 85.8235551416874, 70.12712180614471, 48.269535675644875, 54.58210654556751, 51.39026641845703, 57.55388528108597, 44.230021834373474, 3.278130409307778, 0.48436567944008857, 0.21074513759231195, 0.3081895876675844, 0.18157111946493387, 2.3799172695726156, 5.729144476354122, 13.040354009717703, 3.971900981850922, 0.8777653682045639, 78.88757452368736, 92.7497398853302, 103.58950182795525, 107.46401712298393, 103.61893504858017, 106.31589353084564, 103.71829971671104, 99.69561517238617, 97.67397925257683, 92.84248530864716, 95.21874099969864, 99.37346085906029, 92.94454783201218, 94.85833033919334, 90.95329508185387, 88.8725571334362, 87.66394838690758, 85.97493141889572, 84.75676998496056, 83.67672353982925, 89.40570652484894, 83.26073706150055, 84.04530376195908, 86.30010277032852, 91.37246578931808, 88.37700292468071, 88.0135752260685, 89.91958335042, 87.03271865844727, 91.84483364224434, 88.39239209890366, 89.48918044567108, 92.35473588109016, 88.01741302013397, 88.8340499997139, 90.16986072063446, 83.33732575178146, 86.53803840279579, 89.09594714641571, 85.39678484201431, 78.45521852374077, 72.82305434346199, 76.82785704731941, 80.83012908697128, 88.04416358470917, 79.86758753657341, 72.94568136334419, 66.71874269843102, 72.69256934523582, 75.02109199762344, 86.69879257678986, 81.06811791658401, 77.5033164024353, 79.118792116642, 74.17058363556862, 72.39246904850006, 82.60798528790474, 81.00071713328362, 81.68653473258018, 79.75158736109734, 82.1727642416954, 75.83940088748932, 78.58476117253304, 78.91177922487259, 78.3143600821495, 79.3643045425415, 80.72256445884705, 78.70463714003563, 77.24552303552628, 78.94923761487007, 79.6555133163929, 77.04567655920982, 74.96375307440758, 73.07370409369469, 72.4517534673214, 70.26249334216118, 74.40699934959412, 71.6323958337307, 71.11993253231049, 74.53259781002998, 77.05285057425499, 75.9326022863388, 75.37771806120872, 78.21846082806587, 76.12269848585129, 74.82265144586563, 77.7184608578682, 78.65207836031914, 79.30816635489464, 73.73065084218979, 78.4601354598999, 78.22666078805923, 79.3902799487114, 83.3743965625763, 66.89138263463974, 2.0368906762450933, 14.47694482281804, 14.058841858059168, 10.011246800422668, 0.5612044141162187, 0.9202573006041348, 0.2776156860636547, 0.29680361738428473, 0.16168647474842146, 0.20861858763964847, 1.3548632548190653, 29.15983099490404, 47.41485133767128, 40.236857905983925, 45.66729851067066, 47.559938952326775, 77.83733367919922, 57.70017363131046, 49.74009856581688, 68.0005431175232, 70.18343478441238, 67.07436561584473, 68.23306024074554, 73.26215878129005, 81.67009681463242, 23.876621089875698, 0.45553808100521564, 0.24776609090622514, 0.22992233745753765, 0.20796324155526236, 0.15013041906058788, 0.16066400305135176, 0.12669075338635594, 0.11251211850321852, 0.13105824793456122, 0.15903489984339103, 0.1785881310934201, 0.22035940841306, 0.13547439768444747, 0.08548534140572883, 0.12310523758060299], [0.0028363325691316277, 0.02593339504528558, 0.022264285580604337, 0.010672055759641808, 0.07278248202055693, 0.04361997089290526, 0.04024836431199219, 0.03328117469209246, 0.05902143879211508, 0.022364802061929367, 0.020723959933093283, 0.0333517677790951, 0.02161138858355116, 0.02944199095509248, 0.043343068173271604, 0.0466714223875897, 0.015438997379533248, 0.18975420302012935, 5.35658111795783, 54.38515171408653, 53.68216283619404, 57.4293127655983, 58.36750142276287, 45.89998282492161, 33.89791265130043, 40.579101741313934, 32.63788506388664, 46.639700531959534, 32.215241342782974, 8.600152619183064, 0.1399083886644803, 0.06300242283032276, 0.024443596666969825, 0.10066700371680781, 0.04019254738523159, 0.2209419646533206, 2.972224736586213, 1.1836614226922393, 0.21687492117052898, 24.21378079801798, 74.15802150964737, 85.46781823039055, 100.65834671258926, 95.14497935771942, 99.00757849216461, 94.62985619902611, 89.96211066842079, 91.44274681806564, 83.84880110621452, 88.43764767050743, 94.40643578767776, 88.8771016895771, 88.86008620262146, 86.95258855819702, 83.09383481740952, 83.10782566666603, 79.37237530946732, 76.61677077412605, 75.05494818091393, 75.58338582515717, 72.68940791487694, 75.87378904223442, 77.02856987714767, 79.10154864192009, 75.41802629828453, 78.14434960484505, 78.45857754349709, 78.60437572002411, 76.69037282466888, 81.77826941013336, 80.4574602842331, 82.28441745042801, 84.07033681869507, 81.21558800339699, 81.79894790053368, 79.54332813620567, 75.00691875815392, 82.02540054917336, 77.69791156053543, 73.5645541548729, 65.67588865756989, 68.17999988794327, 75.38945183157921, 76.95901840925217, 74.94506567716599, 75.11397421360016, 67.67166316509247, 68.32759916782379, 78.87703388929367, 70.22653207182884, 74.20168116688728, 76.31443619728088, 72.94938996434212, 69.64894786477089, 62.66495302319527, 64.93087783455849, 66.94587931036949, 74.22230646014214, 74.6403144299984, 72.28246495127678, 72.28245735168457, 72.87995249032974, 74.07180413603783, 74.48517635464668, 74.17873039841652, 75.37473142147064, 72.43552833795547, 70.5045859515667, 69.03965815901756, 67.47139871120453, 66.4944939315319, 68.39683905243874, 61.93996712565422, 64.41454634070396, 67.49279156327248, 66.6392433643341, 65.59265792369843, 65.3636822104454, 68.00673678517342, 67.14432746171951, 66.73329591751099, 69.43390980362892, 68.41074630618095, 71.08805984258652, 71.04072958230972, 72.1066027879715, 64.94093969464302, 67.95809179544449, 69.21743541955948, 70.01907840371132, 69.58165347576141, 66.67145803570747, 72.19993337988853, 70.28118073940277, 72.58648663759232, 30.595593452453613, 0.5861186084803194, 5.736588751897216, 8.599187470972538, 7.202802775427699, 0.7952288689557463, 0.13350737979635596, 0.21046616428066045, 0.05134864113642834, 0.09120588249061257, 0.11110321051091887, 1.4995926199480891, 25.28437715023756, 30.967477597296238, 24.15491245687008, 25.66131502389908, 34.03910167515278, 39.882496520876884, 104.12965804338455, 63.14921423792839, 35.63164941966534, 56.48979797959328, 37.54407539963722, 50.14408528804779, 50.32115958631039, 36.71273320913315, 2.308193505741656, 0.017234498445759527, 0.052031921659363434, 0.08578623033827171, 0.06527378805913031, 0.022089884587330744, 0.029989686663611792, 0.04022509056085255, 0.03318164155643899, 0.031090384436538443, 0.04821210983209312, 0.10167870685108937, 0.05521177583432291, 0.022723791880707722, 0.029031937665422447, 0.037876330461585894, 0.032625153253320605, 0.04731399611046072, 0.00741135248063074, 0.05433007470855955, 0.04189798048173543, 0.05282373385853134, 0.050254823072464205, 0.021207092504482716, 0.08004513918422163, 0.05215370067162439, 0.06698289478663355, 0.0686631839198526, 0.023652548879908863, 0.015308063047996257, 0.01598393322638003, 0.03767518988752272, 0.11973410597420298, 10.711220540106297, 70.7975198328495, 67.40459829568863, 71.22153908014297, 66.93030774593353, 61.53438448905945, 40.333973094820976, 44.95208948850632, 41.686073541641235, 48.56528140604496, 33.44591550529003, 8.138514440506697, 0.24806453817291185, 0.008439258090220392, 0.22202363004907966, 0.11175252293469384, 0.9617846191395074, 0.9274107136297971, 2.352905231527984, 0.9450609446503222, 0.5701265728566796, 41.07168450951576, 85.40847301483154, 94.40881446003914, 105.4896430671215, 100.26034846901894, 100.54994612932205, 97.91150450706482, 95.36849856376648, 93.97411778569221, 87.33192980289459, 94.6094436943531, 96.25763565301895, 92.24622890353203, 89.88600075244904, 90.69940030574799, 86.35421946644783, 83.8847167789936, 82.2659732401371, 83.4502024948597, 77.91943207383156, 78.11267450451851, 76.70672714710236, 79.17002856731415, 81.74201175570488, 81.89265087246895, 78.42264667153358, 80.28297364711761, 79.27367940545082, 79.48765352368355, 81.29585489630699, 82.58820354938507, 82.97413364052773, 84.59845528006554, 86.10353171825409, 86.0115310549736, 83.86631816625595, 83.10752168297768, 80.49719855189323, 85.10441333055496, 80.18190667033195, 78.18891361355782, 68.35292100906372, 71.65147840976715, 79.20379355549812, 77.07684248685837, 75.36821857094765, 78.1590548157692, 72.59300708770752, 74.02370631694794, 79.56963032484055, 76.86980679631233, 76.918223798275, 78.87037664651871, 77.45885118842125, 73.4065206348896, 67.36578717827797, 68.86133372783661, 71.30901038646698, 79.11850333213806, 79.38955038785934, 74.63012337684631, 75.63753291964531, 76.78197830915451, 77.75335058569908, 78.8900899887085, 78.29066455364227, 78.74827399849892, 76.30135729908943, 71.81328132748604, 71.33538857102394, 70.37248983979225, 66.62510812282562, 70.05209103226662, 65.79288437962532, 66.44000485539436, 69.95922401547432, 71.67523473501205, 69.9222519993782, 69.19753968715668, 71.0643719136715, 70.52195861935616, 69.46255266666412, 71.90098822116852, 73.0432753264904, 73.40476512908936, 72.6059339940548, 75.51999762654305, 71.87642633914948, 73.16978573799133, 70.42811885476112, 75.58520972728729, 71.46048545837402, 70.26591315865517, 73.50119635462761, 77.9143251478672, 76.43688842654228, 47.28153169155121, 0.8664734428748488, 1.402123812586069, 4.79881189763546, 6.433968655765057, 2.0560010382905602, 0.5369264481123537, 0.10324413378839381, 0.04438122887222562, 0.060463847330538556, 0.06193424967932515, 1.1079986952245235, 23.623015098273754, 31.188449040055275, 26.144992969930172, 34.163377806544304, 41.947427317500114, 25.69629594683647, 66.4840292930603, 52.427747547626495, 37.89333365857601, 65.39342701435089, 53.309680223464966, 68.19103449583054, 59.52145390212536, 54.34724114835262, 3.0612285481765866, 0.013180139194446383, 0.031771920912433416, 0.04777087706315797, 0.06208336941199377, 0.009639465806685621, 0.03640999879280571, 0.02508861020032782, 0.013236861541372491, 0.045236283185658976, 0.02844626626028912, 0.04519526468357071, 0.040774944063741714, 0.026660254479793366, 0.10394519616966136, 0.07610863205627538, 0.09989810903789476, 0.10123397485585883, 0.09679111521109007, 0.15043449180666357, 0.13488814554875717, 0.07283820246811956, 0.24933730659540743, 0.14308534475276247, 0.14353952428791672, 0.2193731238367036, 0.1580941682914272, 0.15605620108544827, 0.0799071516667027, 0.16996673512039706, 0.1840341740171425, 0.26158906635828316, 0.5238740891218185, 15.50530169159174, 93.11759054660797, 78.36144715547562, 83.26405808329582, 84.073536247015, 73.60565274953842, 54.607800766825676, 58.6092596501112, 54.518361166119576, 68.21846142411232, 48.57207544147968, 14.807238299399614, 0.5350527924019843, 0.34491999016609043, 0.40993972623255104, 0.3501965117175132, 0.5180993489921093, 0.8501930977217853, 12.161070741713047, 4.911604570224881, 0.6903852510731667, 44.068895280361176, 87.95170694589615, 92.26484030485153, 108.65548118948936, 100.36475166678429, 104.78525966405869, 100.79804241657257, 97.90084227919579, 96.90778836607933, 91.14482000470161, 98.39429140090942, 100.16314208507538, 95.47170862555504, 96.01186484098434, 95.00820189714432, 89.52884271740913, 90.72165191173553, 86.01574122905731, 85.84082901477814, 81.42098218202591, 83.87391775846481, 79.57804307341576, 84.04499217867851, 86.83628439903259, 86.59454137086868, 81.61956712603569, 85.82025691866875, 84.29868176579475, 85.54221823811531, 83.91054019331932, 87.49640017747879, 88.08755725622177, 88.08554336428642, 93.13158139586449, 90.865937769413, 88.24571996927261, 85.86387857794762, 83.44358325004578, 87.77620196342468, 83.4519200026989, 79.83853429555893, 72.8979255259037, 77.58273974061012, 80.05390673875809, 80.15818074345589, 78.08739826083183, 79.89143505692482, 79.21790599822998, 78.60586524009705, 82.59293049573898, 78.7807622551918, 80.82090318202972, 81.49649173021317, 80.50998106598854, 77.3868678510189, 69.97770622372627, 73.7496954202652, 71.85539066791534, 80.53222507238388, 80.84092810750008, 77.7150410413742, 78.17819058895111, 79.35652256011963, 80.37729978561401, 81.11713528633118, 81.90826803445816, 82.10808411240578, 81.29032239317894, 76.32663354277611, 76.12870216369629, 75.0842598080635, 72.73780971765518, 75.1669205725193, 67.62596681714058, 70.98424181342125, 74.60881412029266, 73.69539633393288, 72.50816524028778, 71.58742904663086, 75.59108421206474, 73.21514010429382, 73.8381926715374, 74.97110947966576, 74.63823974132538, 75.71528434753418, 77.76617869734764, 77.77992635965347, 73.33821550011635, 74.32832837104797, 75.23525610566139, 76.99254781007767, 73.76226514577866, 72.93510273098946, 79.9588206410408, 79.98366370797157, 85.17663985490799, 48.283332735300064, 1.4901172346435487, 16.09512884169817, 22.86464799195528, 17.348235100507736, 1.6714220121502876, 0.5066762713249773, 0.32142320880666375, 0.07637289600097574, 0.19628044188721105, 0.2439957729075104, 3.027309668250382, 37.82204948365688, 48.5739753395319, 39.22315210103989, 49.60717789828777, 53.566557839512825, 49.58874128758907, 122.49579772353172, 78.0018724501133, 53.657840341329575, 74.60417836904526, 56.001508980989456, 71.37381970882416, 73.56580808758736, 63.72025139629841, 2.9531136620789766, 0.17611381073947996, 0.15380698896478862, 0.17042973136994988, 0.14575713576050475, 0.12145191067247652, 0.0951255280233454, 0.15031540679046884, 0.14673822530312464, 0.18786030152114108, 0.13118448725435883, 0.14251665183110163, 0.15185616473900154, 0.11937788993236609, 0.13910859095631167], [0.025282390524807852, 0.024132154394465033, 0.055909223956405185, 0.03953756866394542, 0.06747942126821727, 0.053978107462171465, 0.009964645232685143, 0.04880708962446079, 0.04204180499073118, 0.05887217434064951, 0.04520674570812844, 0.03398670109163504, 0.03599772091547493, 0.03520714810292702, 0.009000385744002415, 0.062053557339822873, 0.0827085439232178, 0.08669367656693794, 18.980809897184372, 57.46400490403175, 52.53167197108269, 45.954802483320236, 35.360868349671364, 42.34093800187111, 16.68266661465168, 23.648184947669506, 42.081259936094284, 42.67381154000759, 19.720797389745712, 0.7377174706198275, 0.1491314437589608, 0.06384184380294755, 0.08785994679783471, 0.06846683390904218, 0.7252516457810998, 7.6223767362535, 2.432188452221453, 0.12410154115059413, 10.116310212761164, 72.36194908618927, 93.18103194236755, 101.42066940665245, 96.88588634133339, 100.29587656259537, 94.85883951187134, 92.46294647455215, 88.70995625853539, 87.39526480436325, 83.00874218344688, 91.58738225698471, 90.3558075428009, 87.75627583265305, 86.9441606104374, 85.26555508375168, 81.09530925750732, 80.14954000711441, 76.40235587954521, 74.76953789591789, 69.82273533940315, 71.79003417491913, 71.2154670059681, 72.26042613387108, 72.90696904063225, 73.35272312164307, 72.80084073543549, 70.41456118226051, 72.03537940979004, 76.15454837679863, 77.16568171977997, 75.15305891633034, 76.59299165010452, 78.64806577563286, 79.70701575279236, 78.36954072117805, 78.25451329350471, 76.01951882243156, 78.24453502893448, 81.98145970702171, 77.21773132681847, 74.48567032814026, 63.8602776825428, 67.82622367143631, 77.17691391706467, 70.61407327651978, 71.22162267565727, 78.09425309300423, 68.42719182372093, 72.46725663542747, 72.32268199324608, 75.60100167989731, 73.93562704324722, 71.53461948037148, 68.39216530323029, 67.73211032152176, 65.09691372513771, 63.192505314946175, 71.53930082917213, 74.44567367434502, 74.36503440141678, 71.25539526343346, 72.5572358071804, 72.79100686311722, 72.75438442826271, 72.89632961153984, 72.49584630131721, 70.06703943014145, 66.33805632591248, 64.18839007616043, 66.87492191791534, 64.56177324056625, 65.46784222126007, 63.89359429478645, 61.329845264554024, 63.537253215909004, 62.989968582987785, 64.682127982378, 63.70048865675926, 65.54254621267319, 63.371787294745445, 68.3283819258213, 68.95332679152489, 67.5765922665596, 69.35845345258713, 70.16328066587448, 70.53770497441292, 69.62636947631836, 70.416179895401, 68.58044520020485, 69.76062387228012, 68.76747876405716, 70.14977619051933, 71.56958520412445, 67.28208526968956, 71.33259192109108, 68.94366011023521, 68.21387127041817, 10.846995804458857, 2.299103680998087, 5.074718417599797, 11.811901777982712, 2.1845460031181574, 0.07663584634428844, 0.36670036206487566, 0.024293172609759495, 0.14780902565689757, 0.019454469947959296, 0.19288122741272673, 3.9389681490138173, 23.816481716930866, 24.427487030625343, 26.52753934264183, 24.922596663236618, 42.53921136260033, 35.37545956671238, 36.21479272842407, 80.92991173267365, 48.52094538509846, 44.033899158239365, 47.53197245299816, 47.90444366633892, 54.25729237496853, 8.881486672908068, 0.12373248595395125, 0.11134748841868713, 0.025884893839247525, 0.08276001928607002, 0.052807833344559185, 0.05239667239948176, 0.06814205524278805, 0.030525576657964848, 0.012758267203025753, 0.028564941239892505, 0.054647027427563444, 0.05447347619337961, 0.05821292827022262, 0.02289875876158476, 0.024506070658389945, 0.01612591906450689, 0.05625143938232213, 0.09139151588897221, 0.05333095097739715, 0.03347237048728857, 0.020000540353066754, 0.04960046033374965, 0.005840845542479656, 0.03715214646945242, 0.07832587245502509, 0.031124562192417216, 0.11506707320222631, 0.013907800148444949, 0.03120238565315958, 0.06060111496481113, 0.0630540020938497, 0.0944289704784751, 33.07624854147434, 74.62823867797852, 69.5106428861618, 51.47809870541096, 42.21794240176678, 52.00315073132515, 18.28780308365822, 28.502711355686188, 43.073375299572945, 45.635581612586975, 20.055103451013565, 0.5179783492349088, 0.012247561990079703, 0.023815413187548984, 0.07384252865449525, 0.232105617178604, 3.463606294244528, 7.1657120157033205, 2.7254450786858797, 1.1142419977113605, 19.3385910987854, 86.93572506308556, 98.47249120473862, 104.70495477318764, 100.23264795541763, 101.71583756804466, 97.07212194800377, 95.03234580159187, 92.09855362772942, 90.13435542583466, 88.80011782050133, 93.85277509689331, 94.52997475862503, 92.34792664647102, 90.02752035856247, 89.1109411418438, 82.87494376301765, 83.94954890012741, 77.62862607836723, 75.33120855689049, 74.46705132722855, 75.88812947273254, 75.30302166938782, 74.41038876771927, 74.80942815542221, 76.33281201124191, 76.76687031984329, 76.96521207690239, 76.58270180225372, 79.66967895627022, 79.28342208266258, 77.36033007502556, 78.66663157939911, 80.42415127158165, 82.26058512926102, 81.45616069436073, 80.9589421749115, 80.30686676502228, 83.85845258831978, 83.90276581048965, 81.40089645981789, 75.31292393803596, 67.6615709066391, 71.39173194766045, 77.52002030611038, 70.31439855694771, 76.45202681422234, 80.19871696829796, 75.74413239955902, 77.9658579826355, 76.41193136572838, 77.60893553495407, 76.9552718102932, 73.69594350457191, 70.5549256503582, 69.49542850255966, 66.347426623106, 64.434122890234, 73.72508034110069, 76.187963783741, 76.15733742713928, 76.385537981987, 75.79666078090668, 76.1672092974186, 76.81491494178772, 74.14679691195488, 73.74900385737419, 71.38763576745987, 69.80701178312302, 67.96484783291817, 69.70096707344055, 67.77804225683212, 70.04468142986298, 65.6837846338749, 66.00238233804703, 66.19702309370041, 65.27720645070076, 66.28257170319557, 69.31401863694191, 67.91500210762024, 67.31032535433769, 70.10188356041908, 71.20567113161087, 71.10512852668762, 72.66890421509743, 71.81788668036461, 76.25679329037666, 73.1309974193573, 74.10778060555458, 73.11208203434944, 72.77271464467049, 68.72685894370079, 73.4678265452385, 75.10933846235275, 70.10572895407677, 74.24825146794319, 74.00324821472168, 79.6634016931057, 20.92490527778864, 1.3861196651123464, 1.2140012509189546, 7.609421331435442, 3.4476594999432564, 0.27276871958747506, 0.22879737516632304, 0.023470110427297186, 0.10988070775056258, 0.042329862189944834, 0.1567541464464739, 2.8999606892466545, 22.43197660893202, 23.292596228420734, 30.87644398212433, 30.64217895269394, 50.6088687479496, 33.1308364123106, 22.99150988459587, 56.99925944209099, 58.713180273771286, 49.59199771285057, 59.660017266869545, 57.74301253259182, 66.61253079771996, 11.43638787791133, 0.2479079004842788, 0.10846201825188473, 0.10850700724404305, 0.046542622658307664, 0.014590621467505116, 0.09805843626963906, 0.04701799050963018, 0.016877957714314107, 0.05645309203828219, 0.023316268780035898, 0.09933434397680685, 0.004745559881484951, 0.08852812461555004, 0.012023072522424627, 0.1434884051559493, 0.06583882219274528, 0.20420516899321228, 0.3062647831393406, 0.14363923924975097, 0.14245600352296606, 0.17141224583610892, 0.1578720731777139, 0.12851559062255546, 0.1472628940246068, 0.21624330896884203, 0.11255269171670079, 0.1788459235103801, 0.0900333930621855, 0.1659417268820107, 0.12957644619746134, 0.2116803772514686, 0.3531127067981288, 39.005761966109276, 93.2003653049469, 76.39360874891281, 73.73549178242683, 50.56146629154682, 65.42630285024643, 27.51921772956848, 38.188384026288986, 64.4589051604271, 63.30975942313671, 30.752925910055637, 1.2779170274734497, 0.2002220624126494, 0.32831719669047743, 0.3005380748072639, 0.23638970917090774, 3.0890010204166174, 17.97325026243925, 6.993813989683986, 1.4937936561182141, 19.61032021790743, 91.36494979262352, 97.27084368467331, 110.00789701938629, 101.9908744096756, 104.1209565103054, 100.44175073504448, 97.70516037940979, 94.85009998083115, 93.78741100430489, 90.02327978610992, 98.4358611702919, 99.12772804498672, 94.68797028064728, 92.93343722820282, 90.97664102911949, 85.39341062307358, 87.83164858818054, 83.08673679828644, 81.74426883459091, 79.98451486229897, 80.34828454256058, 79.54860225319862, 80.01245096325874, 79.04142826795578, 83.11004474759102, 82.06070825457573, 79.86018553376198, 80.08869007229805, 84.58490520715714, 83.57221394777298, 81.893889605999, 83.08699518442154, 83.86211559176445, 86.72951772809029, 85.19052430987358, 83.33449110388756, 85.4536221921444, 86.45175263285637, 88.33101019263268, 84.31562885642052, 78.45453456044197, 71.0521137714386, 73.48602756857872, 82.66869843006134, 74.41773757338524, 77.51777082681656, 84.77636933326721, 76.23637318611145, 81.53874546289444, 80.16371324658394, 81.17473259568214, 78.78388568758965, 77.94942006468773, 74.00758758187294, 72.1856689453125, 70.23560598492622, 69.48126286268234, 78.04425537586212, 80.49620300531387, 80.82078918814659, 79.43570271134377, 79.95974019169807, 79.75760623812675, 79.01753515005112, 77.5292918086052, 78.40458244085312, 76.38612315058708, 71.8181374669075, 71.17786422371864, 73.15870553255081, 70.85615828633308, 73.53439137339592, 70.84092870354652, 68.95526468753815, 70.9317134320736, 69.98911321163177, 71.52131259441376, 72.4611845612526, 70.93236699700356, 68.91028270125389, 75.06870344281197, 75.12494802474976, 75.57872727513313, 77.00591549277306, 74.39337328076363, 76.31869196891785, 78.58561992645264, 77.18531906604767, 75.84891557693481, 74.22386437654495, 73.33511486649513, 76.84547290205956, 77.26073741912842, 71.61562353372574, 79.66755107045174, 76.69320747256279, 84.86877277493477, 19.757545217871666, 5.8798163663595915, 14.253002889454365, 23.308536373078823, 5.863373698666692, 0.2649955538799986, 0.7788131560664624, 0.17435569257941097, 0.6611237931065261, 0.23950404283823445, 0.5252941441722214, 6.140868058428168, 36.358694806694984, 41.606650203466415, 46.3732398301363, 43.391387835145, 70.84414333105087, 55.11494815349579, 48.850178718566895, 99.39540848135948, 64.48714524507523, 60.532807633280754, 70.17175421118736, 67.28339239954948, 80.0736352801323, 13.849759977310896, 0.472469586529769, 0.20803693681955338, 0.19962699356256053, 0.1922233431832865, 0.11763376867747866, 0.22778925660531968, 0.21655873657437041, 0.15898198471404612, 0.11904121463885531, 0.12547946447739378, 0.22098404442658648, 0.10264313517836854, 0.165471576328855, 0.12082716333679855], [0.0361246764077805, 0.013545961410272866, 0.09333015404990874, 0.06957333156606182, 0.04088974688784219, 0.07871425317716785, 0.037401374502223916, 0.04637469690351281, 0.04135280250920914, 0.0529280278715305, 0.03929719445295632, 0.05079237176687457, 0.002355169935981394, 0.03840478784695733, 0.02341400035220431, 0.06575763123692013, 0.008103632935672067, 1.7887407168745995, 47.607994973659515, 60.00460557639599, 42.79486924409866, 57.99025386571884, 50.26934176683426, 41.19902327656746, 33.370215967297554, 33.31908971071243, 36.52243182063103, 29.121023677289486, 4.248901605606079, 0.09891264082398266, 0.029978224192745984, 0.0887154797965195, 0.13350441120564938, 0.2029188341111876, 2.396317427046597, 3.2732146605849266, 0.4340502043487504, 0.8682093559764326, 52.74599187076092, 82.70576164126396, 95.82303777337074, 96.7919097840786, 95.63861086964607, 95.20311623811722, 92.58333921432495, 91.9268636405468, 86.31781741976738, 85.15858322381973, 93.11952084302902, 90.93096747994423, 90.86381748318672, 86.72634109854698, 88.22936564683914, 83.6827652156353, 82.18799382448196, 78.45203429460526, 72.47935518622398, 68.1072261929512, 70.23167699575424, 70.06217569112778, 65.56135520339012, 68.09592559933662, 67.14346870779991, 70.2086654305458, 71.3928946852684, 71.55814781785011, 70.7131415605545, 70.92026844620705, 69.67233180999756, 71.90005347132683, 72.68530413508415, 75.85286736488342, 77.25245386362076, 79.49117213487625, 77.78378695249557, 78.37238296866417, 80.14428868889809, 82.16806009411812, 75.9391151368618, 68.41469049453735, 61.8380755931139, 70.68744733929634, 70.7103069126606, 73.80133464932442, 74.97272059321404, 73.47205191850662, 77.69854232668877, 72.53674730658531, 74.17455062270164, 71.9724091887474, 73.8996733725071, 69.74706619977951, 67.18345016241074, 61.64452537894249, 66.95177659392357, 62.30293124914169, 65.26614904403687, 69.93761837482452, 70.69455295801163, 71.2838177382946, 72.71043598651886, 72.48687878251076, 70.54682448506355, 68.1589338183403, 69.31344106793404, 67.99159839749336, 69.00964736938477, 65.93165293335915, 63.04745189845562, 62.02083818614483, 62.1360670030117, 61.194511726498604, 61.11102640628815, 62.03463524580002, 59.464673548936844, 59.829111993312836, 58.39714363217354, 62.15637691318989, 64.13148432970047, 65.42445614933968, 66.4368586242199, 68.34065526723862, 67.69645303487778, 70.98322346806526, 69.94438201189041, 70.22574931383133, 68.38087990880013, 70.2618245780468, 70.51289230585098, 65.50610616803169, 64.09024134278297, 67.43942722678185, 68.62124741077423, 69.2323686182499, 68.01534712314606, 68.55706885457039, 50.60463957488537, 1.0156033281236887, 2.827600697055459, 2.9208115953952074, 2.615257641300559, 0.6441506976261735, 0.15516209125053138, 0.12409198970999569, 0.01902010575577151, 0.031453031187993474, 0.08195708229322918, 0.34845279122237116, 4.44639315828681, 13.369187414646149, 21.514342948794365, 17.397104278206825, 14.233783520758152, 22.11497861891985, 43.957280069589615, 32.235976830124855, 42.70612120628357, 51.19149908423424, 54.5137520134449, 52.57729612290859, 48.76637801527977, 9.885109718888998, 0.1197641332692001, 0.0728690238611307, 0.0350865119980881, 0.10885931216762401, 0.06945916698896326, 0.031712370982859284, 0.04049107628816273, 0.017370745626976714, 0.04087524532224052, 0.04836565276491456, 0.06354352270136587, 0.03076617907936452, 0.02804751587973442, 0.03372593266249169, 0.027529699036676902, 0.02030140887654852, 0.034448580408934504, 0.051220680034020916, 0.05004689926863648, 0.05839296958583873, 0.025295376253779978, 0.00593096128795878, 0.007781017629895359, 0.013366534221859183, 0.06259375179070048, 0.06406867381883785, 0.07228553993627429, 0.022609970546909608, 0.061911981538287364, 0.008864620958775049, 0.04160315860644914, 3.3345141587778926, 65.15935197472572, 73.89300853013992, 61.76382377743721, 84.04553174972534, 71.9296082854271, 26.170592196285725, 22.469710484147072, 36.44317947328091, 41.81383788585663, 30.39947647601366, 3.697393024340272, 0.1624642900424078, 0.1472693803953007, 0.08903460329747759, 0.6506523862481117, 2.207570867612958, 1.4724055537953973, 4.420198313891888, 1.0859233047813177, 4.196019843220711, 74.39545556902885, 88.87723848223686, 100.74640318751335, 100.27381494641304, 99.4701960682869, 99.51430410146713, 95.7991674542427, 95.54680779576302, 91.75129026174545, 90.11941462755203, 94.45344686508179, 95.6880234181881, 91.76742419600487, 90.19135236740112, 88.23175951838493, 86.84713661670685, 83.83491665124893, 81.31556823849678, 76.69665768742561, 71.18781968951225, 75.19121646881104, 73.1598986685276, 70.79191133379936, 71.80111438035965, 70.98815560340881, 72.09075003862381, 75.01628905534744, 75.40031164884567, 73.14345315098763, 72.71825596690178, 73.37430596351624, 77.09747537970543, 77.07109719514847, 78.72250378131866, 80.53603246808052, 82.31800004839897, 81.08966276049614, 81.52012646198273, 83.68867009878159, 82.92844489216805, 78.45760479569435, 70.02923145890236, 65.38630619645119, 73.20624858140945, 72.3003163933754, 77.29858338832855, 76.96956664323807, 75.94267174601555, 80.14321714639664, 77.65695735812187, 78.43159899115562, 74.43778529763222, 76.58444210886955, 74.27019149065018, 68.01815897226334, 62.0202112197876, 67.96537980437279, 67.48156696557999, 66.96610942482948, 73.99887084960938, 74.98973608016968, 74.81569781899452, 75.77548831701279, 75.21146178245544, 73.68836671113968, 71.60189867019653, 72.38569021224976, 71.59563660621643, 71.22562006115913, 68.15699592232704, 65.81117659807205, 64.06459271907806, 64.00609865784645, 64.79209408164024, 63.305921629071236, 64.88248363137245, 62.87491075694561, 62.704208716750145, 61.13096013665199, 66.07400089502335, 68.78265514969826, 68.49375665187836, 69.480449706316, 68.88402611017227, 70.53909569978714, 72.43965491652489, 71.50915324687958, 73.68540287017822, 73.111702054739, 71.3114346563816, 75.2284924685955, 70.47867134213448, 71.37976258993149, 69.77966085076332, 72.80635043978691, 72.7409939467907, 76.09919294714928, 71.24844923615456, 69.38984736800194, 3.840587865561247, 0.18197364552179351, 1.5386153385043144, 5.234510293230414, 0.6924047239590436, 0.2117179150809534, 0.02270302844408434, 0.002475339415468625, 0.1353598991408944, 0.1156514922331553, 0.5468094802927226, 2.8328698268160224, 13.418486919254065, 24.182909354567528, 23.23527440428734, 19.27603505551815, 32.63795346021652, 46.55734375119209, 41.455992087721825, 56.37268826365471, 61.83531694114208, 61.31342634558678, 62.19029389321804, 59.40334104001522, 11.965882815420628, 0.2353229609434493, 0.08293969323858619, 0.1333472688565962, 0.02696894709515618, 0.014126255027804291, 0.040097014425555244, 0.05839832789206412, 0.029216938382887747, 0.03510026028379798, 0.034171696242992766, 0.11190944263944402, 0.030502506997436285, 0.015607048371748533, 0.05346583260688931, 0.1790534280007705, 0.06840551766799763, 0.14332731458125636, 0.20230126334354281, 0.17678226315183565, 0.22384840791346505, 0.10764958919025958, 0.1780365817830898, 0.08468974425341003, 0.20551277382764965, 0.14990627561928704, 0.15233266807626933, 0.218284452566877, 0.18216718279290944, 0.15556711092358455, 0.15019921615021303, 0.09588075976353139, 4.377789264544845, 81.56248658895493, 82.43390142917633, 75.6446461379528, 84.39968034625053, 67.60835856199265, 64.22243624925613, 48.021112605929375, 52.82413087785244, 57.81025372445583, 42.91308470070362, 6.409144587814808, 0.39473392185755074, 0.30460697365924716, 0.23148547857999802, 0.4510309884790331, 1.6225916636176407, 6.263228617608547, 9.698393438011408, 1.4302273420616984, 2.9577439511194825, 77.91414275765419, 87.09075674414635, 104.39094722270966, 103.9806604385376, 104.623464345932, 102.17785477638245, 98.11087980866432, 100.48116222023964, 96.97765901684761, 91.49907499551773, 100.11378273367882, 97.59885728359222, 94.5368903875351, 92.75627553462982, 94.76871594786644, 90.85269168019295, 89.35995697975159, 84.75233942270279, 82.40698367357254, 73.72137933969498, 78.61151173710823, 77.37739115953445, 75.55319264531136, 75.7626374065876, 75.02925395965576, 76.50779262185097, 77.337386906147, 78.71517017483711, 77.18726456165314, 78.5529112815857, 77.27006211876869, 79.17115330696106, 78.8839191198349, 82.16287717223167, 83.50933492183685, 86.73229157924652, 84.78683397173882, 83.38986933231354, 86.05315402150154, 89.18528035283089, 81.65873542428017, 75.31597897410393, 68.79543766379356, 76.61594241857529, 76.3991716504097, 77.53474071621895, 83.23331773281097, 79.90357920527458, 85.64355880022049, 81.01772502064705, 78.35669741034508, 79.96249124407768, 78.34683313965797, 78.23884293437004, 70.20833104848862, 65.53411826491356, 72.51899465918541, 71.26162692904472, 72.41135403513908, 76.92407548427582, 78.01683604717255, 77.65052810311317, 80.12164190411568, 78.67052257061005, 77.03352481126785, 74.82820674777031, 76.48448467254639, 74.4369113445282, 76.20358854532242, 71.40245497226715, 70.61033427715302, 68.09533283114433, 69.338109344244, 68.48694741725922, 68.43457862734795, 69.11311581730843, 66.67030289769173, 65.31061425805092, 65.74792519211769, 70.09518072009087, 71.6965439915657, 72.79496625065804, 74.6785555779934, 72.48019114136696, 74.53777313232422, 76.28741204738617, 75.7111805677414, 76.1992871761322, 77.46276497840881, 75.87258070707321, 79.61613982915878, 70.61652794480324, 73.05221244692802, 74.57894012331963, 75.9032754600048, 74.47277382016182, 79.4505675137043, 76.8708023428917, 73.13495680689812, 3.054751083254814, 5.708355316892266, 11.713943984359503, 10.686390772461891, 1.5326094045303762, 0.31914342020172626, 0.4192804265767336, 0.1062392265885137, 0.4466811422025785, 0.6138079008087516, 1.1588045815005898, 6.932414984330535, 23.02846100181341, 38.54080371558666, 34.96991492807865, 27.384444661438465, 35.80797515809536, 61.47847428917885, 45.83937607705593, 59.71573367714882, 76.49040475487709, 81.71403765678406, 71.73002779483795, 76.97759181261063, 15.889860056340694, 0.48452755669131875, 0.13178233173675835, 0.19051450362894684, 0.22626642894465476, 0.1549527610768564, 0.09225697140209377, 0.11385518315364607, 0.09292020651628263, 0.2547779318410903, 0.17730617488268763, 0.2818563475739211, 0.1948554441332817, 0.10145550593733788, 0.23407649423461407], [0.001039387677792547, 0.07138283603126183, 0.0378699331486132, 0.025444739039812703, 0.03837753247353248, 0.018921353730547708, 0.09263964500860311, 0.028081235359422863, 0.030200662549759727, 0.05304659338435158, 0.04955457705364097, 0.027978969264950138, 0.054047052981331944, 0.06336226797429845, 0.0635500461794436, 0.13170927471946925, 0.03404670744203031, 2.5841560726985335, 51.52548976242542, 53.067637011408806, 55.816679298877716, 72.23954245448112, 20.99688671529293, 42.81998209655285, 46.87675081193447, 38.417333140969276, 26.122159995138645, 9.253225475549698, 0.40959563688375056, 0.05589668537140824, 0.08764897647779435, 0.03527104330714792, 0.12908735603559762, 0.4112156562041491, 6.950708152726293, 1.1792150675319135, 0.7092903053853661, 39.32979717850685, 91.33819162845612, 93.7689059972763, 101.9293025135994, 93.72026100754738, 96.52121990919113, 93.21567848324776, 92.27276667952538, 87.10420042276382, 89.27509233355522, 90.58411449193954, 90.01558899879456, 92.1639633178711, 86.27580687403679, 83.82642030715942, 82.59387284517288, 82.2934153676033, 80.54593473672867, 74.30693551898003, 67.79330223798752, 70.60932353138924, 73.95870700478554, 67.82701402902603, 67.43795290589333, 68.55649888515472, 69.58790794014931, 66.71131029725075, 70.91410517692566, 67.59306818246841, 67.62742593884468, 70.2735735476017, 71.0679817199707, 70.7602970302105, 72.9767332971096, 72.59023323655128, 74.06306460499763, 74.74379807710648, 76.30629703402519, 76.17699757218361, 79.73530143499374, 74.13819417357445, 71.03871569037437, 67.69965246319771, 62.54668816924095, 70.88569030165672, 72.39032596349716, 72.6952899992466, 67.23620653152466, 69.02308344841003, 70.37677600979805, 71.29318043589592, 70.92585414648056, 68.39443758130074, 69.8250000178814, 70.7409256696701, 69.39253002405167, 64.92794439196587, 61.53821088373661, 61.709786877036095, 61.81660674512386, 67.96150401234627, 68.62334489822388, 70.31085714697838, 68.20962309837341, 67.89804741740227, 67.61835962533951, 66.82560056447983, 63.22877436876297, 62.104357704520226, 60.99211558699608, 60.48488460481167, 60.258994325995445, 61.41562186181545, 61.817936673760414, 62.14362479746342, 59.029501900076866, 58.519242480397224, 57.20459662377834, 57.761487141251564, 55.63892483711243, 57.54772961139679, 60.03247328102589, 64.52172338962555, 64.89002242684364, 67.17607855796814, 67.3423120379448, 65.23635864257812, 68.69193881750107, 70.03632947802544, 69.92529943585396, 69.06016945838928, 67.06217586994171, 67.73347064852715, 69.18062299489975, 66.27112671732903, 67.6385897397995, 66.91281348466873, 70.69320023059845, 66.50839358568192, 68.49874198436737, 23.38353294879198, 0.7671933795791119, 1.2018299102783203, 4.423465188592672, 1.006850735284388, 0.059407136650406756, 0.11176769985468127, 0.050964932233910076, 0.3090214164694771, 0.11299449222860858, 0.13245078414911404, 0.20406917785294354, 4.536499148234725, 15.590030495077372, 26.223297268152237, 21.167423464357853, 22.170833721756935, 17.82529380172491, 14.559923820197582, 34.199403673410416, 36.20000012218952, 46.42729952931404, 49.58840310573578, 40.431601256132126, 2.264008764177561, 0.03440804430283606, 0.029949063355161343, 0.0036054359770787414, 0.05240742983005475, 0.10865599339012988, 0.02405010996881174, 0.03663602357846685, 0.02149986605218146, 0.032806964591145515, 0.024419701367150992, 0.01866163915110519, 0.047863931249594316, 0.09925852617016062, 0.05263823033601511, 0.03296972128737252, 0.044809577957494184, 0.04654844480683096, 0.03183220927894581, 0.05851995105331298, 0.05275560099107679, 0.05812941810290795, 0.0412830962886801, 0.018333749030716717, 0.07008930973825045, 0.04563688336929772, 0.011199149448657408, 0.12258203089004382, 0.043959789181826636, 0.05233469564700499, 0.1749672371079214, 0.10170872672460973, 3.625852125696838, 61.56742751598358, 64.81329694390297, 72.83589005470276, 94.99871760606766, 35.298099517822266, 32.63704150915146, 43.131154999136925, 42.32594020664692, 31.289525516331196, 8.393191024661064, 0.42294524086173624, 0.03588991654396523, 0.07535588651080616, 0.030304633728519548, 0.6398676743265241, 0.8488875115290284, 4.108821172267199, 0.6403477548155934, 2.3196962010115385, 65.40924936532974, 99.1837066411972, 98.749108761549, 103.29694792628288, 98.67611467838287, 98.12202841043472, 96.1340206861496, 94.08093765377998, 90.5225881934166, 90.82468718290329, 94.7291524708271, 92.86108151078224, 92.13547244668007, 88.13003897666931, 86.96130529046059, 84.61927816271782, 85.86436495184898, 82.95006573200226, 77.36530020833015, 70.59468671679497, 75.87045282125473, 75.13808012008667, 71.60719558596611, 74.61439222097397, 72.66002789139748, 71.56318634748459, 72.35380992293358, 76.22316509485245, 70.48003926873207, 71.57556608319283, 72.79935121536255, 72.03423947095871, 72.40747064352036, 74.12506207823753, 74.41355779767036, 75.81672370433807, 76.9394950568676, 78.4778881072998, 79.09200355410576, 82.28554219007492, 76.60400345921516, 74.95423838496208, 71.03536427021027, 67.17214196920395, 74.37094688415527, 76.17598682641983, 75.10574385523796, 70.47490954399109, 72.41194680333138, 73.14183443784714, 73.71028393507004, 73.62624764442444, 71.30964875221252, 70.44174492359161, 71.86447978019714, 71.59170761704445, 65.27887836098671, 64.20710787177086, 66.56041279435158, 63.77938762307167, 70.13478219509125, 72.74261265993118, 73.66324245929718, 72.42433413863182, 70.60656487941742, 71.20714545249939, 69.52800035476685, 65.83303302526474, 63.61706033349037, 63.27541686594486, 63.197513446211815, 62.636598944664, 63.918156176805496, 64.71442624926567, 64.78601440787315, 63.59189808368683, 62.37684868276119, 59.336080849170685, 60.82183912396431, 59.83163885772228, 59.401167556643486, 61.847829669713974, 66.90637663006783, 68.77790540456772, 70.91056376695633, 71.44922286272049, 67.81409472227097, 73.0531319975853, 72.59885877370834, 72.35504105687141, 72.33163431286812, 69.59308326244354, 69.85829383134842, 71.29504233598709, 69.33754697442055, 71.62563979625702, 70.67977175116539, 74.16347041726112, 73.09426859021187, 74.97916504740715, 38.582137897610664, 0.5501817399635911, 0.9453137498348951, 1.0131055559031665, 0.4805465874960646, 0.029522270924644545, 0.04606740323652048, 0.09852279064944014, 0.4389601940056309, 0.16645630239509046, 0.02002544868446421, 0.14133482618490234, 3.106275130994618, 12.351512722671032, 29.218769632279873, 18.563683480024338, 25.461628139019012, 22.188574969768524, 17.10589360445738, 44.78579521179199, 45.38748152554035, 56.21648624539375, 56.03403903543949, 52.59406842291355, 2.5092851277440786, 0.08842757102684118, 0.0129270788966096, 0.010311148416803917, 0.042441247423994355, 0.06017093277478125, 0.016136047524923924, 0.0452119110559579, 0.043120223490404896, 0.04389524459838867, 0.0114951216528425, 0.0217503464591573, 0.04730301232484635, 0.042127259584958665, 0.02256786850921344, 0.11518258848809637, 0.1622369553660974, 0.14878296089591458, 0.11281481085461564, 0.21154757734620944, 0.13576616562204435, 0.26009268884081393, 0.08340361717273481, 0.07616616334416904, 0.11809839023044333, 0.13906806969316676, 0.084206257306505, 0.22405773808714002, 0.14454397663939744, 0.160275844973512, 0.2952724776696414, 0.1801218237960711, 5.409709867089987, 79.42030593752861, 72.86270141601562, 80.26630774140358, 85.44094607234001, 36.38024345040321, 72.53883719444275, 71.56626418232918, 58.116448894143105, 42.26980201900005, 14.740843512117863, 1.0064603062346578, 0.14513871894450858, 0.34342913422733545, 0.2013909153174609, 0.5093015742022544, 1.0010083112865686, 15.860850512981415, 6.459841467440128, 1.7093481332994998, 64.64150816202164, 102.19452068209648, 99.06438544392586, 108.65792825818062, 100.98853379487991, 101.6098004579544, 98.70463594794273, 97.69570648670197, 93.57751026749611, 95.74717104434967, 96.34901314973831, 97.44021579623222, 95.99576130509377, 92.09589377045631, 89.51795250177383, 90.069310516119, 87.81584903597832, 87.40162566304207, 81.69127687811852, 72.70101249217987, 77.34670400619507, 82.22630336880684, 75.11879995465279, 76.89021930098534, 74.76891472935677, 76.40236347913742, 75.53585037589073, 79.6039804816246, 74.28841531276703, 74.57485914230347, 76.8157508969307, 76.75157234072685, 77.0609213411808, 80.33872425556183, 78.65507259964943, 79.71650764346123, 81.08938157558441, 81.41498610377312, 85.54331257939339, 88.40397387742996, 79.26576063036919, 79.18348744511604, 74.29397061467171, 71.88264280557632, 77.62399792671204, 79.19847384095192, 80.57022303342819, 74.43086206912994, 76.32815346121788, 76.22864440083504, 78.82485508918762, 78.51911589503288, 74.71973776817322, 75.13342157006264, 76.97069138288498, 76.27244845032692, 67.89346486330032, 66.14531546831131, 68.63676577806473, 68.04623946547508, 74.8007570207119, 76.94650948047638, 76.97020500898361, 75.33586710691452, 74.1147418320179, 74.50682759284973, 75.21881058812141, 70.26192337274551, 67.34358116984367, 67.20320910215378, 68.23002800345421, 67.84190163016319, 67.93550580739975, 68.87372866272926, 69.8634235560894, 66.76912799477577, 65.69765388965607, 64.28173586726189, 64.32935491204262, 63.407854959368706, 63.03753063082695, 65.58344721794128, 70.99331572651863, 69.71895530819893, 75.30647188425064, 73.76919597387314, 69.41050305962563, 75.7823583483696, 74.89029541611671, 75.08596211671829, 72.81424641609192, 73.95459562540054, 72.96088814735413, 76.22104480862617, 72.90659666061401, 74.18033391237259, 73.39965060353279, 78.36789920926094, 76.98310911655426, 81.97541043162346, 41.98869310319424, 1.5811439626850188, 9.269020278006792, 9.814473409205675, 2.5985387759283185, 0.09382375646964647, 0.22663261945126578, 0.22752750111976638, 1.4298613741993904, 0.6337557022925466, 0.27457353367935866, 0.9597350447438657, 7.53941816277802, 25.15660710632801, 39.888378605246544, 38.131881058216095, 38.33103597164154, 29.178757779300213, 21.734674125909805, 50.85196070373058, 52.17506870627403, 68.9264090359211, 67.17369228601456, 70.2481909096241, 5.072839418426156, 0.22957084147492424, 0.09907995801768266, 0.12028457917040214, 0.12315557745750993, 0.12640636239666492, 0.06381998013239354, 0.19820765097392723, 0.10692886731703766, 0.10312350510503165, 0.06296630992437713, 0.1273792437859811, 0.22878060262883082, 0.17908436071593314, 0.2558876504190266], [0.07168150594225153, 0.05996067862724885, 0.029854482199880295, 0.04208959187963046, 0.10351638324209489, 0.022442135705205146, 0.023539575449831318, 0.040583243608125485, 0.0344833500275854, 0.062273745134007186, 0.054533853617613204, 0.029873167623009067, 0.0304381665046094, 0.0908019018243067, 0.052310980317997746, 0.135891291720327, 0.11731983278878033, 4.428844749927521, 49.748385921120644, 52.61116750538349, 44.47390414774418, 25.130008533596992, 26.53018780052662, 20.8140804246068, 24.846610240638256, 21.254752278327942, 17.160023599863052, 1.0041476553305984, 0.058028255953104235, 0.1052614396030549, 0.136165990261361, 0.05656491142872255, 1.578338525723666, 3.8272168580442667, 0.7502299023326486, 1.208784249611199, 15.920196678489447, 99.35060128569603, 89.25642013549805, 96.86254039406776, 93.66159215569496, 92.57320135831833, 89.4778722524643, 92.44512543082237, 87.98362523317337, 89.43351343274117, 84.82599467039108, 89.73303616046906, 86.49245604872704, 88.18965777754784, 82.12247014045715, 85.74879795312881, 82.27752462029457, 82.51240521669388, 75.19781291484833, 71.06026813387871, 70.93637198209763, 76.33748576045036, 67.67209634184837, 73.65479931235313, 70.46430811285973, 68.15407767891884, 73.2147753238678, 70.74105486273766, 66.73638135194778, 65.98414331674576, 67.09162428975105, 67.89599552750587, 64.71995875239372, 65.6272740662098, 64.97576862573624, 66.66168496012688, 69.05874833464622, 70.55496364831924, 69.5434883236885, 71.50520905852318, 72.24008202552795, 71.09024852514267, 67.11410388350487, 60.38392782211304, 64.17081981897354, 72.67663300037384, 68.6808206140995, 65.98268419504166, 65.64299762248993, 70.62874048948288, 69.0326589345932, 69.69699248671532, 67.36968576908112, 68.5445599257946, 63.380207642912865, 63.29781286418438, 63.86609137058258, 66.87652543187141, 65.95089510083199, 62.70600222051144, 58.533795699477196, 63.42373050749302, 63.84933426976204, 66.76101922988892, 68.52015763521194, 67.09600165486336, 64.76325362920761, 62.32018232345581, 60.66787138581276, 60.61190418899059, 57.56082370877266, 58.55011582374573, 58.278563395142555, 60.266738310456276, 60.544598400592804, 61.62341371178627, 56.52445591986179, 61.1310513317585, 59.81984429061413, 57.40031652152538, 57.893511056900024, 58.678921312093735, 58.6225551366806, 60.043644681572914, 63.023273795843124, 65.42330861091614, 65.94244435429573, 69.02664005756378, 66.63633272051811, 69.28957834839821, 69.57291394472122, 68.14991310238838, 64.3071261048317, 68.63131687045097, 66.05841413140297, 66.97485655546188, 66.66478559374809, 65.80682203173637, 68.61126154661179, 68.23068156838417, 65.80492213368416, 53.28786179423332, 3.6776675703004003, 1.422182461246848, 2.1147216623649, 0.4347468138439581, 0.07335898975725286, 0.028511681011877954, 0.09741330955876037, 0.38782969233579934, 0.04971112939529121, 0.06918645740370266, 0.009186129536828957, 0.2663642819970846, 2.20040041487664, 19.753013961017132, 27.041864544153214, 17.78842817991972, 27.52428475767374, 38.84693808853626, 36.998413279652596, 38.61358880996704, 41.77122317254543, 48.685586750507355, 29.919035956263542, 0.25492107728496194, 0.042168871805188246, 0.05276271818729583, 0.11427374702179804, 0.035679907305166125, 0.0076031322532799095, 0.014250181629904546, 0.07116906781448051, 0.016655179824738298, 0.030702898002346046, 0.09757434818311594, 0.02795660650008358, 0.05195188474317547, 0.12912723905174062, 0.024920652904256713, 0.0377000035950914, 0.11008837551344186, 0.008715955791558372, 0.009829052069108002, 0.014967305014579324, 0.04646053370379377, 0.06352582990075462, 0.01165801471870509, 0.08057753366301768, 0.030691814026795328, 0.03989230783190578, 0.044420562699087895, 0.04679461148043629, 0.02451368694892153, 0.046154008159646764, 0.11827096925117075, 0.14999068749602884, 6.042246725410223, 65.94435945153236, 69.33285802602768, 67.29638010263443, 34.8830895870924, 21.809321120381355, 22.19032097607851, 30.831315703690052, 24.433502107858658, 16.948468051850796, 0.7421290338970721, 0.13003498956095427, 0.086037053988548, 0.22894740774063393, 0.09175372106255963, 0.5013759713619947, 2.49363353010267, 1.4255171385593712, 1.3602133677341044, 23.23530290275812, 103.48345711827278, 90.12222647666931, 96.66324868798256, 95.49444660544395, 93.97043958306313, 93.21779116988182, 95.72990477085114, 91.17225453257561, 93.02248924970627, 88.30853819847107, 94.90289434790611, 89.75216433405876, 89.6248559653759, 86.06078401207924, 88.51503431797028, 86.72629550099373, 84.89634409546852, 77.7670070528984, 73.84493350982666, 76.93360537290573, 79.33321461081505, 71.89277306199074, 79.00305032730103, 74.1968098282814, 76.53189852833748, 75.12164980173111, 72.74917110800743, 68.82287219166756, 68.86324122548103, 72.7480311691761, 71.08213976025581, 67.4456512928009, 69.9105866253376, 70.39261355996132, 70.39333552122116, 70.83237156271935, 71.67849496006966, 72.4414636194706, 75.44383451342583, 74.93551298975945, 73.27099710702896, 68.77397641539574, 63.019219413399696, 68.86156171560287, 74.76496294140816, 69.73748311400414, 70.92068642377853, 71.49143099784851, 74.37438189983368, 73.48625555634499, 74.93248835206032, 70.32405763864517, 70.84985822439194, 68.7714609503746, 68.31792488694191, 66.16247534751892, 68.3193688094616, 69.40555572509766, 65.63707754015923, 60.75441174209118, 65.44038489460945, 66.88531816005707, 70.06130933761597, 68.43226075172424, 69.33944687247276, 67.66622185707092, 64.3932218849659, 64.33715209364891, 62.32066869735718, 61.91154085099697, 60.10182335972786, 59.96818833053112, 63.69811378419399, 63.38062562048435, 64.71686571836472, 61.30649171769619, 64.04005363583565, 63.62871810793877, 63.89722689986229, 61.64249248802662, 62.51266859471798, 62.47046805918217, 61.88662178814411, 64.46325972676277, 68.01631987094879, 68.33675667643547, 71.51145592331886, 68.79428252577782, 73.36185783147812, 71.70645385980606, 72.05908253788948, 66.91105797886848, 71.08938977122307, 69.99737396836281, 69.44766506552696, 69.57419827580452, 69.99844551086426, 69.26029711961746, 74.62212860584259, 71.55681028962135, 67.2521048784256, 8.285167571157217, 1.0439049219712615, 0.6398424413055182, 0.2087168479920365, 0.09861529193585739, 0.06047659371688496, 0.14026408520294353, 0.4894445225363597, 0.04993616712454241, 0.03996041472419165, 0.046585670934291556, 0.10439760197186843, 1.5457070642150939, 18.863092213869095, 32.18623749911785, 14.396805223077536, 27.521706596016884, 33.78870651125908, 40.7805061340332, 46.50184392929077, 51.59673973917961, 58.27243812382221, 38.243830651044846, 0.3240767726674676, 0.035153435164829716, 0.026700347152655013, 0.04639409664378036, 0.06730302760843188, 0.02397510666924063, 0.03801385042606853, 0.04052258045703638, 0.06766100996173918, 0.053213843784760684, 0.01991395212826319, 0.040491592080798, 0.04746153506857809, 0.09310773239121772, 0.06292328762356192, 0.19376137002836913, 0.10702248182496987, 0.06933680910151452, 0.17474606225732714, 0.17779459711164236, 0.10606974974507466, 0.16902122413739562, 0.12584261217853054, 0.15231579163810238, 0.1817734437645413, 0.12306933247600682, 0.14436519326409325, 0.13191253412514925, 0.17224423791049048, 0.2495302353054285, 0.26901499601081014, 0.4569994588382542, 7.05252748914063, 82.45020255446434, 75.39024978876114, 70.76728865504265, 46.00472040474415, 47.38724201917648, 33.70555557310581, 49.443950057029724, 37.081556618213654, 26.641721315681934, 1.9679223583079875, 0.18949528253870085, 0.22322601318592206, 0.5157228733878583, 0.17299088300205767, 3.202976379543543, 7.993089593946934, 4.8757910169661045, 3.111754674464464, 21.917556412518024, 108.61717164516449, 92.0254835486412, 103.2657516002655, 99.27250027656555, 96.95014089345932, 95.12792587280273, 99.86871108412743, 95.86608186364174, 96.5882483124733, 90.86215317249298, 99.20020535588264, 90.49896106123924, 95.90208113193512, 89.31523337960243, 91.96977853775024, 90.47202050685883, 89.74297642707825, 83.29530000686646, 77.1465003490448, 77.92155995965004, 84.99181017279625, 75.28301954269409, 83.04344952106476, 77.69649043679237, 78.57682719826698, 79.51384171843529, 77.04633012413979, 73.00709366798401, 73.0313591659069, 76.17054551839828, 75.69980397820473, 72.06854403018951, 73.51536959409714, 73.51118221879005, 74.03220266103745, 75.44902503490448, 77.7909229695797, 74.87163081765175, 79.57222178578377, 78.39266628026962, 78.93866658210754, 74.14455503225327, 67.30628237128258, 72.39688441157341, 81.2703050673008, 75.41687875986099, 74.74563717842102, 73.78895491361618, 78.77387702465057, 75.43140158057213, 79.13504004478455, 73.91034319996834, 75.10377556085587, 70.00805139541626, 70.94087854027748, 71.20263129472733, 73.16888138651848, 72.90181651711464, 69.18578311800957, 66.59106954932213, 69.38626796007156, 71.27699330449104, 73.96115407347679, 73.64280715584755, 73.38977873325348, 72.74122953414917, 68.95313680171967, 68.96409541368484, 67.52537101507187, 65.43847739696503, 63.519975543022156, 64.29693505167961, 67.78871968388557, 66.8124532699585, 67.40459069609642, 62.25512981414795, 68.34558740258217, 65.97513779997826, 67.30502843856812, 63.73580776154995, 65.81055343151093, 64.79160770773888, 66.76655173301697, 69.79729190468788, 72.23097771406174, 72.06655293703079, 75.68971931934357, 71.85982123017311, 74.99688729643822, 76.73019468784332, 74.80157017707825, 68.47692355513573, 74.38101634383202, 74.10830497741699, 75.14480575919151, 72.81922414898872, 74.11069124937057, 73.5459503531456, 77.28626444935799, 73.71900826692581, 73.55425670742989, 9.029222745448351, 4.6029366832226515, 6.478243404999375, 0.5261008883826435, 0.29927455354481936, 0.17117572337156162, 0.5288983695209026, 1.9687754125334322, 0.6699135527014732, 0.19292010110802948, 0.28462826914619654, 0.4959488828899339, 5.376201365143061, 33.28386940062046, 43.73219154775143, 31.865521408617496, 44.103435426950455, 57.54401721060276, 54.33349348604679, 55.63832826912403, 60.49979120492935, 67.91766956448555, 50.8989679813385, 0.7140076335053891, 0.16821691417135298, 0.14152266376186162, 0.10473550923052244, 0.19125233200611547, 0.16227306827204302, 0.12718772515654564, 0.12411540446919389, 0.17936514486791566, 0.09770071366801858, 0.17450314247980714, 0.1416155806509778, 0.13963849924039096, 0.23703752987785265, 0.14718539896421134], [0.05540854515857063, 0.07707939090323634, 0.04706902429461479, 0.02636003162479028, 0.05882131867110729, 0.02869157018722035, 0.03239047873648815, 0.039623628108529374, 0.05494107004778925, 0.044270311191212386, 0.05542630475247279, 0.04994092058041133, 0.016918410328798927, 0.06475701578892767, 0.04240697133354843, 0.15217196341836825, 0.046359093248611316, 19.721165969967842, 58.32797214388847, 44.147486463189125, 34.512799456715584, 41.90737746655941, 38.03201861679554, 23.899454064667225, 23.67077473551035, 20.42774375528097, 3.921364168636501, 0.04180080366495531, 0.11924684891710058, 0.05524100903130602, 0.28294329706113786, 0.03527942215441726, 1.706035661045462, 1.4574000402353704, 1.616113604977727, 0.14649331656983122, 48.75378929078579, 99.00457665324211, 83.5426439344883, 94.84750851988792, 89.26568403840065, 91.80365145206451, 88.65495041012764, 89.2976251244545, 85.14736622571945, 86.0534656047821, 89.25805404782295, 90.4672859609127, 87.79342263936996, 88.89287084341049, 84.9222207069397, 85.3801341354847, 80.00560373067856, 78.32800894975662, 72.52715662121773, 74.89478677511215, 76.67656436562538, 74.80767264962196, 71.5380696952343, 76.04800209403038, 72.35303476452827, 73.8817611336708, 71.30117520689964, 69.92168202996254, 65.58372840285301, 67.25419476628304, 69.66132760047913, 65.09971037507057, 67.83649072051048, 67.1370242536068, 67.01153218746185, 69.68667224049568, 68.44584882259369, 67.9286889731884, 70.79867497086525, 69.51152443885803, 67.6027424633503, 61.5773069858551, 60.17108604311943, 57.77462303638458, 66.32652774453163, 66.10462725162506, 62.98196621239185, 70.77013850212097, 71.76575347781181, 72.0789098739624, 72.71523132920265, 71.32810056209564, 70.18021255731583, 72.37970173358917, 71.9007982313633, 70.31025677919388, 68.64862874150276, 62.32637219130993, 60.88654965162277, 62.210869789123535, 56.46997444331646, 56.074430868029594, 59.20470289885998, 58.550636395812035, 62.28019326925278, 59.90647204220295, 60.027867928147316, 56.305378675460815, 56.692984476685524, 58.04963707923889, 59.125431552529335, 58.11519876122475, 57.535239681601524, 58.08870278298855, 61.0197439044714, 62.354984655976295, 59.90535490214825, 58.23577769100666, 60.52622638642788, 61.876008957624435, 58.173920810222626, 59.534810185432434, 58.291262313723564, 57.44538590312004, 58.91904182732105, 63.44454199075699, 65.0518025457859, 66.9993044435978, 67.84961521625519, 68.83832976222038, 66.67806208133698, 67.11775928735733, 66.77459970116615, 66.07308894395828, 67.97212824225426, 68.05955395102501, 66.71636402606964, 67.2878685593605, 63.95929276943207, 69.92365032434464, 64.70203891396523, 71.16778716444969, 21.41418792307377, 0.2778650773689151, 0.30774076643865556, 0.30318970908410847, 0.1488081197021529, 0.1842768266214989, 0.10359085776144639, 0.10533618129556999, 0.06825584132457152, 0.03596757858758792, 0.044692745359498076, 0.051919838806497864, 0.23078207101207227, 3.9045125478878617, 23.98834839463234, 25.82554791122675, 23.315174616873264, 26.881142668426037, 41.46341688930988, 47.75134228169918, 48.27792562544346, 46.126211285591125, 32.62455157935619, 0.10291405618772842, 0.05446123075671494, 0.09167187701677904, 0.023353687865892425, 0.03638758593297098, 0.011181726604263531, 0.08064236768404953, 0.04938757898344193, 0.006104198037064634, 0.03803135397902224, 0.06260309542994946, 0.03729336975084152, 0.055164723671623506, 0.05646084748150315, 0.031215106064337306, 0.044540289673022926, 0.06449685592087917, 0.009615298695280217, 0.0515100137272384, 0.03289306485385168, 0.01583408247824991, 0.03893514513038099, 0.06390301903593354, 0.02813703744322993, 0.04535649255558383, 0.07224785367725417, 0.022230657014006283, 0.021560395616688766, 0.006894400703458814, 0.08994592353701591, 0.023466024904337246, 0.04948967252857983, 27.48888585716486, 69.46782678365707, 57.224165573716164, 53.64934399724007, 43.88987548649311, 31.602613516151905, 26.980621330440044, 24.453796818852425, 21.01807627826929, 3.3154037967324257, 0.05530648872081656, 0.10472925292560831, 0.013896586297050817, 0.24833101371768862, 0.10933429410215467, 1.1000110488384962, 1.2979589332826436, 0.12897172942757607, 0.34876001067459583, 60.15100412070751, 100.45796826481819, 86.49612665176392, 98.95524770021439, 92.38215520977974, 93.52708697319031, 91.11426204442978, 94.15425091981888, 87.82255187630653, 89.13076847791672, 93.60204935073853, 92.41231799125671, 91.54224827885628, 91.38384237885475, 87.79833197593689, 88.533835709095, 84.65144723653793, 81.01666867733002, 76.15221530199051, 80.02808332443237, 80.37552908062935, 78.22479888796806, 77.13739603757858, 79.30103793740273, 76.41513839364052, 77.13849797844887, 75.09119063615799, 74.1266655921936, 70.89430823922157, 73.08523267507553, 72.79146283864975, 69.95278716087341, 70.5695852637291, 68.7865537405014, 68.49394664168358, 70.75504571199417, 70.51591694355011, 68.77631708979607, 70.87635040283203, 70.96512123942375, 68.23492214083672, 65.89280381798744, 62.30921231210232, 60.55813327431679, 68.95078852772713, 66.12553372979164, 68.67444455623627, 74.98659744858742, 75.62661990523338, 75.84065482020378, 77.0535497367382, 73.52291598916054, 75.06837666034698, 74.58006486296654, 75.30770301818848, 75.76990261673927, 72.4048487842083, 67.43022412061691, 64.1172730922699, 63.87632042169571, 60.467842519283295, 59.436547458171844, 61.28155745565891, 61.84616535902023, 63.277795538306236, 60.05816750228405, 61.985899060964584, 60.237650871276855, 58.41310657560825, 60.810952708125114, 63.48251715302467, 61.22115969657898, 60.38718804717064, 61.95208467543125, 63.369290828704834, 65.4096445441246, 65.04232585430145, 63.18972006440163, 61.04329124093056, 65.4957327246666, 61.350538954138756, 63.041968792676926, 61.90325349569321, 59.96993623673916, 62.02100917696953, 65.37125900387764, 68.42972248792648, 68.9798341691494, 70.47392919659615, 71.4791576564312, 70.19379302859306, 70.65831050276756, 70.29562756419182, 70.44874414801598, 70.59363797307014, 71.33036524057388, 70.1428833603859, 71.73841014504433, 68.89812335371971, 72.38663256168365, 69.6235728263855, 77.31768876314163, 34.33726787567139, 0.1911621165345423, 0.4108392389025539, 0.2257619466399774, 0.15120325289899483, 0.0989543940522708, 0.37347415171097964, 0.11317593249259517, 0.08923413712182082, 0.07516192621551454, 0.03923394120647572, 0.1667348007322289, 0.21802020346513018, 2.797698201611638, 30.629888512194157, 30.156889893114567, 23.419414423406124, 18.95850509405136, 35.47761708498001, 58.7690182775259, 56.11707217991352, 55.0247447937727, 38.45283843576908, 0.0680459471186623, 0.10193745663855225, 0.0947930384427309, 0.033391632241546176, 0.011402492345951032, 0.0005005194100249355, 0.010366451406298438, 0.015047989454615163, 0.07400022019282915, 0.027081278567493428, 0.053065829852130264, 0.037181476145633496, 0.06423180529964156, 0.060637461647274904, 0.05764945635746699, 0.11569711205083877, 0.13165267853764817, 0.21462098899064586, 0.25301868561655283, 0.11687381687806919, 0.12170865666121244, 0.16806064755655825, 0.11657221548375674, 0.16046994627686217, 0.11278626043349504, 0.1564536805381067, 0.17261293687624857, 0.10030838311649859, 0.10022465401561931, 0.22753302269848064, 0.36312561482191086, 0.1542487449478358, 31.850871294736862, 83.98154318332672, 65.80544650554657, 55.78181616961956, 65.85818007588387, 60.965494215488434, 42.13968180119991, 43.24995182454586, 32.80021235346794, 6.595287574455142, 0.15280491148587316, 0.3330181381898001, 0.17071541369659826, 0.6809618754778057, 0.22241465281695127, 3.687545615248382, 6.599231762811542, 2.6977336406707764, 0.5371664883568883, 62.292360216379166, 106.76233917474747, 91.81570440530777, 104.65614259243011, 96.93465292453766, 97.30465427041054, 94.40558463335037, 97.28046476840973, 93.51416006684303, 94.05061528086662, 96.20399013161659, 95.87640210986137, 94.82360780239105, 95.21015346050262, 91.56880885362625, 92.53059044480324, 90.65800532698631, 85.80703362822533, 79.38409388065338, 82.52071157097816, 82.29056552052498, 82.65147015452385, 78.59421506524086, 83.94646346569061, 78.72258737683296, 80.80598518252373, 78.40365529060364, 78.52036222815514, 71.12428709864616, 75.40203675627708, 75.82484006881714, 72.21123397350311, 73.63855138421059, 71.78329333662987, 72.40312367677689, 76.72843158245087, 76.18806257843971, 71.32777377963066, 75.38680717349052, 77.00863614678383, 75.37854641675949, 69.15645629167557, 66.31803140044212, 64.2820018529892, 74.33587476611137, 72.50488221645355, 71.48098155856133, 76.94810539484024, 79.37198013067245, 79.48045670986176, 79.39418613910675, 76.5604729950428, 79.7693020105362, 78.76034215092659, 77.72740557789803, 76.11847311258316, 75.17844155430794, 69.91974413394928, 68.95258963108063, 68.6558635532856, 64.84060987830162, 63.84498730301857, 66.30315139889717, 65.23502111434937, 68.52202713489532, 66.14869728684425, 68.63114207983017, 65.44040769338608, 61.82900547981262, 64.63963106274605, 65.08985370397568, 64.86525535583496, 63.494421914219856, 65.10021194815636, 66.61392152309418, 69.78766322135925, 67.08714812994003, 65.68903595209122, 65.19227340817451, 67.96319112181664, 63.21650482714176, 65.75622394680977, 64.13985148072243, 63.11950363218784, 65.85311874747276, 71.21045887470245, 71.63894668221474, 74.81537863612175, 75.19246280193329, 75.61595007777214, 71.62415027618408, 74.0139788389206, 73.54394406080246, 73.12845915555954, 74.74537119269371, 75.33126935362816, 73.56792837381363, 75.52882075309753, 71.27380147576332, 75.93480616807938, 72.89919465780258, 83.83679375052452, 38.076879009604454, 0.6761941406875849, 2.42776857689023, 0.6025418022181839, 0.3382987267104909, 0.526352624874562, 1.312678037211299, 0.33836284826975316, 0.23944378044689074, 0.3408587502781302, 0.14893720886902884, 0.412593349465169, 0.4194296873174608, 6.600123289972544, 42.93949328362942, 44.58629451692104, 42.8489213436842, 39.801709055900574, 60.74778489768505, 68.03841948509216, 66.74227863550186, 65.89509889483452, 49.02660325169563, 0.1874761510407552, 0.21127362095285207, 0.25986464170273393, 0.08125901818857528, 0.1921450614463538, 0.1055563245608937, 0.2986555133247748, 0.13406048761680722, 0.16978311294224113, 0.07442875852575526, 0.1101114488847088, 0.14693243050714955, 0.14210357243428007, 0.14241779776057228, 0.13041980797424912], [0.02130723234586185, 0.05057696711446624, 0.09175734274322167, 0.041146322182612494, 0.01812161168345483, 0.02363922176300548, 0.05364788885344751, 0.005814792912133271, 0.016057416978583205, 0.025190048800141085, 0.06697571821860038, 0.04154724891122896, 0.030995903471193742, 0.09853168157860637, 0.04460528325580526, 0.05712066500564106, 1.5184744005091488, 46.024422347545624, 53.45575198531151, 45.797498524188995, 42.15451620519161, 24.994051828980446, 22.038579918444157, 25.139287635684013, 25.239887237548828, 7.5016059167683125, 0.43018708820454776, 0.06406088868970983, 0.17229399149073288, 0.0927170881186612, 0.3403147857170552, 0.25192042579874396, 0.08764977057580836, 0.7937746157404035, 0.8106198243331164, 1.9475580635480583, 75.52705004811287, 82.94465482234955, 87.61261314153671, 89.92466747760773, 82.7561317384243, 88.468486815691, 86.50602132081985, 89.01776254177094, 83.69490936398506, 87.05223441123962, 88.59708711504936, 86.94485977292061, 88.29005599021912, 85.90310007333755, 82.46882155537605, 82.73398652672768, 77.18632981181145, 74.47250783443451, 72.55677223205566, 79.70994159579277, 75.21045103669167, 75.25445267558098, 76.14986702799797, 77.89826720952988, 74.6648459136486, 73.3754763007164, 71.13891631364822, 69.84141513705254, 69.28563416004181, 72.49472916126251, 69.94638070464134, 65.34587636590004, 68.65314289927483, 67.69125491380692, 65.62073081731796, 65.72952657938004, 65.55963769555092, 63.02081152796745, 61.7822489887476, 62.594086825847626, 60.21771714091301, 60.46212002635002, 59.40112195909023, 61.68862201273441, 58.972406163811684, 60.26560217142105, 75.49751803278923, 72.8605355322361, 72.2432054579258, 70.58179020881653, 72.45908707380295, 70.717853307724, 71.81868463754654, 69.7823891043663, 68.3230622112751, 70.96724912524223, 72.87981569766998, 67.96370789408684, 63.616703152656555, 55.93797639012337, 53.79965253174305, 53.60485978424549, 52.654792964458466, 55.756980702281, 55.264865309000015, 53.61209839582443, 55.68540394306183, 58.250239714980125, 57.73882135748863, 57.21273958683014, 59.68368999660015, 61.28739394247532, 61.80748723447323, 59.495733082294464, 59.08523350954056, 61.395395547151566, 65.66049188375473, 62.81982511281967, 60.880944952368736, 60.278726667165756, 63.74061070382595, 61.28757633268833, 59.682569056749344, 58.35319899022579, 58.05227413773537, 59.56124536693096, 63.6775416880846, 64.13976028561592, 66.02711901068687, 66.34271487593651, 66.97820797562599, 64.80720967054367, 64.59453508257866, 63.5002887994051, 66.9458869099617, 67.10310727357864, 64.96198296546936, 64.68490943312645, 67.47536569833755, 64.74528819322586, 67.34864249825478, 67.46746212244034, 53.59816454350948, 3.8829368306323886, 0.057082893399638124, 0.14540943957399577, 0.1831915692309849, 0.30411567189730704, 0.12374297992209904, 0.0515064291539602, 0.03455995822150726, 0.035750793540501036, 0.05443573427328374, 0.027264212403679267, 0.08617904910352081, 0.37753865704871714, 8.274697232991457, 36.86861604452133, 23.191204369068146, 34.852721616625786, 37.38281965255737, 43.88572610914707, 40.20076364278793, 50.87454669177532, 32.54534862935543, 0.17853656667284667, 0.1151577265409287, 0.01555799797642976, 0.07386507510091178, 0.06019069245667197, 0.015698946663178504, 0.07876506802858785, 0.04296366743801627, 0.019347168381500524, 0.05042726479587145, 0.01864913952886127, 0.02756392688752385, 0.08642947199405171, 0.033517875272082165, 0.03446362374234013, 0.05674015104887076, 0.03969356439483818, 0.05332116204954218, 0.10097600432345644, 0.07250068854773417, 0.0025537329383951146, 0.038099316152511165, 0.02369609439483611, 0.03761684594792314, 0.054227465370786376, 0.02721914919675328, 0.040424958351650275, 0.0436579391680425, 0.025091946154134348, 0.04593811368977185, 0.0401384336873889, 1.9643064960837364, 59.91083800792694, 66.30502849817276, 69.51498225331306, 52.765918001532555, 22.99174927175045, 20.21464169025421, 28.402208648622036, 25.599175058305264, 5.704177916049957, 0.32663872581906617, 0.35759219143074006, 0.12856087647378445, 0.16795374860521406, 0.27761286590248346, 0.1831432108883746, 0.01856728435086552, 0.32027860928792506, 1.5037509030662477, 3.734210911206901, 84.77735728025436, 85.21950915455818, 94.00587648153305, 88.3618113398552, 86.88470900058746, 92.39276424050331, 89.86238121986389, 91.28648400306702, 86.02992206811905, 92.19206660985947, 91.93944096565247, 87.66930609941483, 90.03741502761841, 89.38796907663345, 86.68778076767921, 84.49421927332878, 79.34222012758255, 79.39387455582619, 77.20074623823166, 83.79645511507988, 78.53143483400345, 80.01185819506645, 79.64285999536514, 80.91481894254684, 79.11946848034859, 76.9963476061821, 77.10866957902908, 73.26767608523369, 74.28526148200035, 74.64036762714386, 73.21258664131165, 70.66060557961464, 73.70817884802818, 71.1886328458786, 70.6608335673809, 69.4366304576397, 69.40549492835999, 64.56139326095581, 64.58204135298729, 65.22235259413719, 63.79074901342392, 63.92726808786392, 63.0696427077055, 64.48587611317635, 60.77092565596104, 64.5908796787262, 76.13122522830963, 75.69883123040199, 74.30084064602852, 73.60284850001335, 76.95490702986717, 75.45515790581703, 73.60258251428604, 71.29900172352791, 70.79701825976372, 72.32385993003845, 73.07523161172867, 70.63232749700546, 69.33937847614288, 61.564402878284454, 57.2878273576498, 57.684594467282295, 55.244019627571106, 59.76123243570328, 59.903303012251854, 57.713526114821434, 59.757174253463745, 60.761224776506424, 60.33211000263691, 59.390946105122566, 63.50196070969105, 65.93796819448471, 65.28232857584953, 62.66084164381027, 61.383680775761604, 64.72726196050644, 68.23201909661293, 65.58043777942657, 65.2856495976448, 63.94666224718094, 67.02895045280457, 64.7461849451065, 62.7987552434206, 61.697524935007095, 61.62860043346882, 62.45340697467327, 65.78536078333855, 65.69136142730713, 68.16451951861382, 69.44911658763885, 69.92063328623772, 68.17664086818695, 67.56685718894005, 66.91144555807114, 69.29938182234764, 68.43967035412788, 68.91498684883118, 66.89069107174873, 72.33529731631279, 68.90405863523483, 72.68507614731789, 72.16505125164986, 65.50206318497658, 7.394863469526172, 0.045645232530659996, 0.22256551659666002, 0.15515131526626647, 0.12509253836469725, 0.03806630542385392, 0.02083985000354005, 0.02495918521162821, 0.071356994449161, 0.029749041568720713, 0.13532872893847525, 0.22670307895168662, 0.25654741970356554, 8.568775802850723, 44.81208220124245, 27.785988114774227, 29.98323731124401, 21.552796885371208, 50.82168772816658, 50.20091883838177, 60.27992740273476, 41.94110065698624, 0.20432394230738282, 0.07482620829250664, 0.04501955379964784, 0.039093025916372426, 0.08950074625317939, 0.054137999468366615, 0.04670936097681988, 0.05013807582145091, 0.054877519942237996, 0.03607302664022427, 0.05916158224863466, 0.038609598341281526, 0.06369736991473474, 0.0423280327959219, 0.018619030597619712, 0.15032631636131555, 0.2024589994107373, 0.1387225851067342, 0.15111334912944585, 0.14575312816305086, 0.16739011713070795, 0.3225499077234417, 0.11682033029501326, 0.15764454554300755, 0.2845699363388121, 0.10899803441134281, 0.18227178108645603, 0.13484774302924052, 0.12459537363611162, 0.19397767639020458, 0.18979150336235762, 2.2886228933930397, 69.1522005200386, 78.78405287861824, 71.44661620259285, 63.193706050515175, 43.30781891942024, 34.75561022758484, 44.298942536115646, 39.72770802676678, 11.67973442003131, 1.6049376921728253, 0.5755494756158441, 0.3040723007870838, 0.3259561874438077, 0.49612251576036215, 0.725528437178582, 0.1621361865545623, 4.47262505069375, 4.680692860856652, 3.2239241804927588, 87.18853309750557, 87.75472551584244, 98.5261519253254, 95.01517832279205, 89.67345535755157, 96.32287055253983, 94.32261988520622, 95.61243027448654, 91.33452862501144, 94.02758091688156, 94.30843144655228, 90.64323171973228, 93.3872240781784, 94.15668278932571, 91.23802900314331, 88.23797598481178, 83.97426277399063, 82.39816054701805, 83.33424791693687, 85.70503950119019, 83.25800120830536, 82.53490760922432, 82.19139084219933, 83.53354722261429, 82.44953379034996, 80.14947161078453, 80.46488508582115, 75.42895451188087, 73.49663659930229, 79.57860544323921, 76.83636099100113, 73.56286704540253, 75.75155720114708, 75.62598913908005, 76.0793124139309, 73.41030523180962, 73.55391472578049, 67.8423348069191, 68.50789949297905, 68.76220464706421, 66.75829097628593, 66.15034639835358, 66.74894347786903, 69.19950798153877, 66.5994442999363, 67.09788635373116, 81.06674998998642, 79.56035882234573, 78.05948495864868, 75.59268772602081, 80.98051741719246, 78.73078733682632, 77.66970187425613, 74.25037175416946, 74.273641705513, 76.4282400906086, 78.90969693660736, 73.61417949199677, 70.6711994111538, 63.45718011260033, 60.920903608202934, 61.06119588017464, 60.30610799789429, 63.07866722345352, 62.013675570487976, 61.08376286923885, 63.13279151916504, 65.89212745428085, 63.998787850141525, 62.72041104733944, 65.92451691627502, 70.00218451023102, 67.50989064574242, 64.38486993312836, 64.52087983489037, 66.7616955935955, 72.33319222927094, 69.00561198592186, 67.82582849264145, 66.52953565120697, 70.55263817310333, 68.07697221636772, 66.54546439647675, 64.9765057861805, 64.78346854448318, 65.83130031824112, 71.09358474612236, 68.80990728735924, 71.82133689522743, 73.96565303206444, 73.99264678359032, 70.26918098330498, 69.62492555379868, 69.68629986047745, 72.08072617650032, 70.95971792936325, 71.16444334387779, 70.70886299014091, 75.26171788573265, 70.80347791314125, 76.75395101308823, 74.94141787290573, 69.19107243418694, 7.696777693927288, 0.10468980035511777, 0.44267345569096506, 0.5268757499288768, 0.6214187736622989, 0.4457391193136573, 0.1654586332733743, 0.09668327373219654, 0.2526779210893437, 0.1551281157298945, 0.8877592475619167, 0.5104255420155823, 0.9076353278942406, 14.534073807299137, 54.27786447107792, 40.5148433893919, 53.61452266573906, 53.313324227929115, 61.18091605603695, 56.80970661342144, 69.23043832182884, 48.537535294890404, 0.32579810998868197, 0.335841653868556, 0.11666958525893278, 0.09272978626540862, 0.18848453677492216, 0.192876165965572, 0.14459018275374547, 0.2027069212635979, 0.14126110123470426, 0.08891282428521663, 0.14815427275607362, 0.08013954779016785, 0.11421591145335697, 0.19898647558875382, 0.13057751435553655], [0.0740628871426452, 0.01673810555075761, 0.05078757007140666, 0.03243078477680683, 0.041613845532992855, 0.0031261764888768084, 0.021228045188763645, 0.012343959551799344, 0.00863162926179939, 0.031317986286012456, 0.06740967422956601, 0.02218351022747811, 0.05351008687284775, 0.019584028523240704, 0.04044679233629722, 0.1670458645094186, 7.184080230072141, 52.879163324832916, 44.716578125953674, 41.12280696630478, 36.32390387356281, 34.286749586462975, 40.88720440864563, 28.54137048125267, 7.940203556790948, 0.32028338871896267, 0.10268755271681584, 0.7665315025951713, 0.09833287505898625, 0.22585398779483512, 0.09215430269250646, 0.09028311091242358, 0.3606664342805743, 0.7853011297993362, 0.7042371109127998, 15.683590024709702, 88.09145584702492, 80.27063190937042, 92.79317155480385, 81.56045749783516, 89.41275134682655, 86.20623260736465, 88.81214797496796, 83.09516474604607, 89.34300988912582, 87.79200151562691, 85.44036090373993, 86.30420655012131, 86.40206649899483, 82.42235764861107, 84.85720619559288, 78.88242200016975, 71.83557853102684, 74.86064180731773, 78.40359449386597, 79.33348819613457, 76.27759337425232, 81.02283954620361, 77.6824463903904, 75.94566598534584, 72.36343100667, 76.01069569587708, 70.62497109174728, 74.02687534689903, 75.65573394298553, 74.47484850883484, 71.38804614543915, 73.38958114385605, 72.83484891057014, 73.23112204670906, 69.25185397267342, 64.8843303322792, 64.0124899148941, 63.743897527456284, 64.06134009361267, 60.18952265381813, 59.53088119626045, 61.50068789720535, 59.04081009328365, 57.124918699264526, 58.39493215084076, 68.98997202515602, 68.49530696868896, 72.37458720803261, 70.25004521012306, 70.30936762690544, 69.7172150015831, 70.66792398691177, 69.81405660510063, 69.0009306371212, 72.04642161726952, 68.2824119925499, 68.39404240250587, 69.70501005649567, 67.04972013831139, 66.17705896496773, 56.29753589630127, 54.207526445388794, 55.47859624028206, 54.13684643805027, 57.666184455156326, 56.62674643099308, 56.92745849490166, 55.67422114312649, 60.23149900138378, 59.0809815376997, 60.7335052639246, 63.22500117123127, 63.58858086168766, 62.494554966688156, 61.45038239657879, 61.15290015935898, 61.41447052359581, 63.510027676820755, 62.26068511605263, 64.04237151145935, 60.455949157476425, 61.321280524134636, 62.82132223248482, 58.12140382826328, 58.54046054184437, 56.71664960682392, 58.71142856776714, 61.156471967697144, 67.3779009282589, 64.34956222772598, 66.17942243814468, 65.7384940981865, 66.6894918680191, 65.98722875118256, 62.51976661384106, 66.30993783473969, 67.09862351417542, 63.537519201636314, 66.74053072929382, 66.22802942991257, 66.61588221788406, 70.56253284215927, 60.53287982940674, 17.487022653222084, 0.22777941572712734, 0.11595163159654476, 0.09185739167151041, 0.08068956827628426, 0.11093952241935767, 0.11281033570412546, 0.028750240671797656, 0.032875015822355635, 0.06254128937143832, 0.17329902271740139, 0.11106913108960725, 0.0913744539138861, 0.518450295785442, 25.58720950037241, 41.29798136651516, 21.111290976405144, 37.173561081290245, 35.531293004751205, 35.234152749180794, 44.598317071795464, 44.08587656915188, 0.9094690263736993, 0.04748926541651599, 0.02343815354834078, 0.011552442356332904, 0.06259632704313844, 0.03523614381265361, 0.0112014974183694, 0.06718518940033391, 0.026726236974354833, 0.1310962755815126, 0.05432333971839398, 0.027778094008681364, 0.04332690790761262, 0.0655667285900563, 0.014886261560604908, 0.08521420517354272, 0.047466592804994434, 0.06824382595368661, 0.038099271623650566, 0.05912456392252352, 0.027031194731534924, 0.06643389104283415, 0.06865310555440374, 0.011666607861116063, 0.061427544642356224, 0.042487071332288906, 0.03744988498510793, 0.016255603804893326, 0.01394550588884158, 0.11321947429678403, 0.22061668132664636, 9.777176510542631, 66.38773486018181, 60.57219631969929, 59.60652753710747, 30.969801172614098, 25.659624114632607, 40.20367428660393, 33.94461214542389, 6.587920719757676, 0.4642200213856995, 0.08186674065655097, 1.0151464026421309, 0.6194854492787272, 0.5504844174720347, 0.11992733896477148, 0.06299461543676443, 0.31319207861088216, 0.7081048283725977, 1.329847772140056, 22.06486690789461, 96.11947506666183, 84.21918243169785, 97.776520550251, 84.83712047338486, 95.13915047049522, 89.80880409479141, 93.53867635130882, 87.32778802514076, 92.24505856633186, 90.20243257284164, 88.09952661395073, 85.82589581608772, 90.09359121322632, 86.17794692516327, 85.18212676048279, 82.97949895262718, 76.49605885148048, 78.2627360522747, 81.84734210371971, 80.6161929666996, 80.6416667997837, 82.86849930882454, 81.46027967333794, 79.54361692070961, 78.55965211987495, 79.8590835928917, 75.16109928488731, 80.19647508859634, 79.18394342064857, 76.90345019102097, 74.39080461859703, 78.92745718359947, 76.29882663488388, 74.62406650185585, 72.76943162083626, 69.62696984410286, 66.97147473692894, 66.55780613422394, 67.1753565967083, 64.4458718597889, 64.56820249557495, 65.73402553796768, 60.81968083977699, 60.91024897992611, 64.65206399559975, 72.98387691378593, 72.77885511517525, 74.39668670296669, 74.1331784427166, 74.84778329730034, 75.41084468364716, 74.99261632561684, 74.56130906939507, 72.59584933519363, 75.68131417036057, 72.68063798546791, 69.26671877503395, 71.27820163965225, 71.05328410863876, 67.49412909150124, 59.318039417266846, 56.86986118555069, 57.74064525961876, 57.64242433011532, 58.929172083735466, 58.24509859085083, 59.827816262841225, 59.051514118909836, 63.90245541930199, 62.43033841252327, 63.18748578429222, 64.55182537436485, 67.54060059785843, 66.12407460808754, 64.58446562290192, 64.03895169496536, 66.73966437578201, 66.16843342781067, 66.43064975738525, 66.01411610841751, 65.70393115282059, 63.206002190709114, 65.61980366706848, 64.27177280187607, 61.27882540225983, 61.099448427557945, 61.23579651117325, 63.68364796042442, 69.56916734576225, 67.458935379982, 67.59252101182938, 67.40411192178726, 69.51652497053146, 68.34408268332481, 66.5016907453537, 68.1059342622757, 70.41845217347145, 67.71374210715294, 69.52752158045769, 69.12280529737473, 71.55192375183105, 73.5160231590271, 67.73750603199005, 26.157908476889133, 0.21229782927548513, 0.1024498428159859, 0.07221165171358734, 0.16017044516047463, 0.07566945132566616, 0.09038874079124071, 0.09957458460121416, 0.10191782683250494, 0.09387094221892767, 0.17287120426772162, 0.05909939398407005, 0.10507376529858448, 0.4531537980074063, 28.443119153380394, 46.70063406229019, 22.720231041312218, 22.40963190793991, 33.04282933473587, 52.971395775675774, 49.44669350981712, 55.14134533703327, 1.1543826875276864, 0.0569324897514889, 0.10564784621237777, 0.02096182382956613, 0.016322710653184913, 0.008758140393183567, 0.01597858234163141, 0.0396313687087968, 0.025268499375670217, 0.1032444009615574, 0.10834734901436605, 0.034991075517609715, 0.07619854324730113, 0.043051734392065555, 0.04399898571136873, 0.12752672337228432, 0.1781141510582529, 0.20318124268669635, 0.1261762817739509, 0.1607663749018684, 0.10259283983032219, 0.07464051552233286, 0.12816802802262828, 0.08535675689927302, 0.1405236142454669, 0.17542800691444427, 0.12127716458053328, 0.11881280384841375, 0.06789555089198984, 0.18685193062992766, 0.48597916786093265, 11.553874723613262, 81.3745790719986, 60.92914916574955, 57.862383127212524, 53.73425044119358, 51.94712273776531, 61.664337515830994, 47.55380228161812, 11.66432909667492, 1.420017289929092, 0.27039901237003505, 2.917568231932819, 1.6811464028432965, 1.2332753604277968, 0.36559301835950464, 0.31797786243259907, 0.8983169810380787, 3.2538031646981835, 1.5029075858183205, 21.798826083540916, 105.19037872552872, 89.39712658524513, 102.14135393500328, 89.45353075861931, 100.18834993243217, 93.63423362374306, 98.673827201128, 91.05672553181648, 95.23636445403099, 94.59663078188896, 92.21028283238411, 90.76428562402725, 94.69319880008698, 90.66691964864731, 90.91554790735245, 89.06519159674644, 81.4855407178402, 79.82256755232811, 83.6513788998127, 85.8274233341217, 82.7169482409954, 85.34153580665588, 82.83506870269775, 81.09558284282684, 82.28763207793236, 82.63699293136597, 78.57537567615509, 84.97050851583481, 81.37503504753113, 81.57522350549698, 75.99311783909798, 79.65060397982597, 79.8217011988163, 79.09287750720978, 74.82392817735672, 71.24392747879028, 70.59770375490189, 69.11382257938385, 68.5230378806591, 66.10613197088242, 66.8266949057579, 71.05956137180328, 64.38660264015198, 64.79393318295479, 67.56640881299973, 76.4280652999878, 75.74904933571815, 78.63170385360718, 76.88172295689583, 79.2389264702797, 77.71118804812431, 78.90736386179924, 78.23753580451012, 74.74432244896889, 80.2074185013771, 74.32778880000114, 72.3906983435154, 74.09316658973694, 73.54332089424133, 70.62947764992714, 63.200291097164154, 60.84717616438866, 62.81079679727554, 61.64412260055542, 65.74385181069374, 62.33149811625481, 64.26217451691628, 64.15050610899925, 67.634387165308, 66.97654366493225, 66.9899645447731, 67.89055421948433, 70.80908641219139, 68.24517399072647, 67.46868565678596, 68.19416552782059, 69.16967958211899, 70.54109439253807, 70.13933435082436, 69.3507170677185, 66.93507269024849, 65.60715034604073, 67.39523559808731, 66.24019637703896, 67.0183490216732, 62.78045542538166, 65.94332590699196, 65.79828768968582, 72.48706117272377, 70.25881513953209, 71.69291138648987, 73.56214508414268, 73.4702356159687, 71.97685495018959, 71.15400910377502, 72.26766854524612, 73.60522717237473, 70.45613095164299, 74.2176403105259, 73.10701310634613, 74.54485595226288, 76.60602495074272, 72.1522231400013, 30.068476237356663, 0.6709293450694531, 0.15396327042253688, 0.4637735750293359, 0.43924811761826277, 0.4029893351253122, 0.21964274608762935, 0.17108966392697766, 0.18807634070981294, 0.19538748980266973, 0.2199592869146727, 0.4316825157729909, 0.20607116573955864, 1.1646422557532787, 41.6110123693943, 57.07043722271919, 35.40327787399292, 51.390410810709, 53.96471947431564, 52.71774038672447, 59.957507103681564, 65.01821234822273, 1.6161482781171799, 0.1344617223367095, 0.2275668943184428, 0.19872871285770088, 0.13533043587813154, 0.1051276526413858, 0.10407712034066208, 0.14426528534386307, 0.13695127156097442, 0.19243774964706972, 0.29202086152508855, 0.07718351422226988, 0.21585050504654646, 0.15385243808850646, 0.11242502747336403], [0.033940068242372945, 0.03879516865708865, 0.03443792687903624, 0.03395204650587402, 0.04399507088237442, 0.010504041874810355, 0.042893575300695375, 0.07557568838819861, 0.032048278153524734, 0.06574315193574876, 0.030777969950577244, 0.00959176519245375, 0.062386492209043354, 0.06904267371282913, 0.04628603252058383, 0.014388717409019591, 23.835492096841335, 60.165781527757645, 46.443030685186386, 38.88140223920345, 40.71273677051067, 35.79535983502865, 31.342903152108192, 18.555054143071175, 1.3065822143107653, 0.03646163000667002, 0.12419827267876826, 0.04124140985368285, 0.19641380582470447, 0.6519813055638224, 0.440222141915001, 0.06884822360007092, 0.1362717166193761, 0.42331575066782534, 1.0208635521121323, 35.867491364479065, 90.30192643404007, 83.24195846915245, 86.12426340579987, 83.06212931871414, 82.72315710783005, 84.53843370079994, 88.00890147686005, 86.2764224410057, 86.18708163499832, 81.51642546057701, 84.03981685638428, 81.15779310464859, 84.42016884684563, 82.42493391036987, 78.30239072442055, 76.17443650960922, 72.04464331269264, 78.74076560139656, 81.36448681354523, 77.37310498952866, 81.57320961356163, 80.00262469053268, 81.92032858729362, 78.65657731890678, 75.14892473816872, 74.16351601481438, 75.43527737259865, 77.4677275121212, 78.94963279366493, 76.7353244125843, 74.85417455434799, 75.57995080947876, 71.55000865459442, 71.68022766709328, 69.33833733201027, 67.10891336202621, 62.57423669099808, 66.4525517821312, 61.44040033221245, 61.645661517977715, 60.65511927008629, 57.62330375611782, 57.50095412135124, 57.80819043517113, 61.67071357369423, 67.15133428573608, 73.83753910660744, 73.43553587794304, 73.97956028580666, 72.28816464543343, 72.31437563896179, 68.85555803775787, 69.8591297864914, 68.76088991761208, 66.1130627989769, 68.83908212184906, 72.17321321368217, 66.21174350380898, 62.725707963109016, 60.556921139359474, 55.046730414032936, 52.22402907907963, 51.73277623951435, 54.934522435069084, 53.68476189672947, 54.565953612327576, 53.44089098274708, 59.07037250697613, 56.47209472954273, 59.13610897958279, 60.900282114744186, 59.68423716723919, 61.823670566082, 62.22380429506302, 64.32158812880516, 61.95004418492317, 63.77459987998009, 63.33131946623325, 61.13884851336479, 66.89693033695221, 64.02541682124138, 64.01618331670761, 64.27665933966637, 64.09167006611824, 61.464700028300285, 59.05046537518501, 56.78135633468628, 58.721532225608826, 63.903739750385284, 66.91735804080963, 64.44266483187675, 66.89353331923485, 63.902326226234436, 66.05238765478134, 63.044077679514885, 64.72961023449898, 65.94169199466705, 67.00717762112617, 65.87191253900528, 64.34936463832855, 67.61387586593628, 69.08330261707306, 61.210531666874886, 37.161093950271606, 0.6070329830981791, 0.04892683515208773, 0.2034529429511167, 0.10465434796060435, 0.07979217072715983, 0.13718623551540077, 0.04467156817554496, 0.07619353375048377, 0.053051187278470024, 0.07368209859123453, 0.044343524059513584, 0.03999660926638171, 0.217429721087683, 8.3298303745687, 65.17284125089645, 25.52115384489298, 28.543319776654243, 40.70098020136356, 19.269898384809494, 39.064886793494225, 45.47940619289875, 2.005044585093856, 0.05260039564745966, 0.054669785386067815, 0.007775159301672829, 0.0934557625441812, 0.008503875033056829, 0.04974336457962636, 0.008752667981752893, 0.010994816711900057, 0.03417922533117235, 0.07910247804829851, 0.05518230143934488, 0.05552330345381051, 0.07665468205232173, 0.03173364093527198, 0.02820479181536939, 0.047049427885212936, 0.04870209057116881, 0.02431365217489656, 0.037108693722984754, 0.04711810623120982, 0.10485436418093741, 0.005299565700624953, 0.03078825797274476, 0.054511822963831946, 0.06069691138691269, 0.02418052201392129, 0.08901132212486118, 0.05127088261360768, 0.01687441395915812, 0.09196950049954467, 34.35504712164402, 70.6354433298111, 71.16518050432205, 50.14778628945351, 24.61021162569523, 37.918222323060036, 37.160672172904015, 20.093008317053318, 1.1544444342143834, 0.04891394775768276, 0.12067601754097268, 0.11503629633807577, 0.248488245124463, 0.7641183352097869, 0.6701243226416409, 0.07404958043480292, 0.3483566682552919, 1.852330898400396, 1.1315523250959814, 40.95081679522991, 94.06753957271576, 86.3605423271656, 92.35897645354271, 86.7527648806572, 88.42195451259613, 88.49269151687622, 91.54946029186249, 89.59431320428848, 88.61311465501785, 85.83398938179016, 85.41431710124016, 84.64571714401245, 88.38226944208145, 84.86977592110634, 79.8475930094719, 78.0548720061779, 77.54628449678421, 85.24154037237167, 83.40880751609802, 79.37780141830444, 85.57537525892258, 83.69987949728966, 87.273108959198, 80.91741040349007, 78.92471373081207, 77.7235297858715, 80.45957297086716, 81.11667171120644, 82.02318146824837, 80.62959864735603, 78.77450779080391, 76.83576062321663, 75.60781091451645, 74.1113144159317, 74.39515918493271, 71.04707524180412, 66.30925387144089, 67.33000069856644, 65.18927916884422, 65.20406037569046, 63.04238677024841, 60.77699013054371, 60.23553058505058, 59.17982563376427, 65.26282042264938, 71.42602890729904, 76.12616389989853, 75.83920329809189, 75.82762151956558, 73.75585108995438, 76.54852643609047, 71.11609473824501, 72.9200479388237, 72.53015846014023, 67.1038444340229, 68.31660255789757, 72.36109033226967, 69.67978700995445, 67.10904255509377, 63.89375388622284, 59.059239104390144, 55.08921593427658, 55.00127725303173, 56.17758393287659, 57.32938192784786, 57.11555600166321, 56.49103291332722, 58.751064240932465, 61.06117308139801, 61.58018723130226, 65.62045723199844, 63.61515283584595, 65.17332002520561, 64.634098559618, 67.64166757464409, 65.5543027818203, 66.70778408646584, 65.51474690437317, 66.03072121739388, 68.68187695741653, 68.41323897242546, 66.7501138150692, 67.21922144293785, 66.92864343523979, 65.32941564917564, 60.67530378699303, 60.1981557905674, 63.64498883485794, 64.0803162753582, 69.29796069860458, 67.61669531464577, 69.81983989477158, 67.75680899620056, 68.75802487134933, 66.11542627215385, 66.625085324049, 68.65836381912231, 69.73749831318855, 69.76158142089844, 68.99832397699356, 71.95212587714195, 74.41250905394554, 69.65270966291428, 49.60768327116966, 1.6740194102749228, 0.029470376248355024, 0.16746081411838531, 0.10559243004536256, 0.3019487194251269, 0.29327520984224975, 0.35461068735457957, 0.008069060913840076, 0.10440071157063358, 0.12608455232111737, 0.17837632214650512, 0.0178341686114436, 0.24375426321057603, 10.972599014639854, 69.620061814785, 33.13496299088001, 26.402096673846245, 32.0600500702858, 37.37643979489803, 49.255932345986366, 57.034681141376495, 3.020366015844047, 0.08660310486447997, 0.04712927926448174, 0.03601815966248978, 0.09542585292365402, 0.023417931879521348, 0.0421297754655825, 0.05683903851604555, 0.05005642102332786, 0.007322637538891286, 0.06662681233137846, 0.040655473130755126, 0.03645893229986541, 0.07572020680527203, 0.05214750002778601, 0.14155288401525468, 0.1844975264975801, 0.13611962087452412, 0.19340610393555835, 0.17214376595802605, 0.14010737329954281, 0.149010518216528, 0.1654653571313247, 0.26449813682120293, 0.16666420764522627, 0.21447376173455268, 0.12266669509699568, 0.2255667172721587, 0.15139438561163843, 0.18159936560550705, 0.1868309426936321, 37.87885643541813, 85.16499727964401, 70.34924268722534, 64.09305319190025, 61.38295501470566, 58.560557663440704, 51.736861020326614, 30.022223219275475, 2.6214479841291904, 0.17085337894968688, 0.17373289709212258, 0.3472770511871204, 0.9389519412070513, 1.9126078952103853, 1.2549581844359636, 0.3188883588882163, 0.3544342936947942, 2.5645940098911524, 1.8659326247870922, 45.01170068979263, 101.31331756711006, 91.73244327306747, 97.56082892417908, 93.49546507000923, 91.65044367313385, 91.84356451034546, 97.06054016947746, 92.65849158167839, 92.29708537459373, 87.41506934165955, 90.27290359139442, 88.77338245511055, 92.80740559101105, 89.11713480949402, 85.94427466392517, 80.78643143177032, 78.26078295707703, 87.42750987410545, 89.5303550362587, 82.5349760055542, 88.90777364373207, 86.8802860379219, 92.13139906525612, 83.88053700327873, 82.76824548840523, 84.5662634074688, 82.00720712542534, 83.04958239197731, 83.72266307473183, 83.68690699338913, 80.49318596720695, 82.11346462368965, 79.12279710173607, 77.97129929065704, 75.72150841355324, 73.98621752858162, 70.72517931461334, 73.80845546722412, 68.6876754462719, 68.96961271762848, 67.7888260781765, 63.70201997458935, 64.17431563138962, 63.79707187414169, 68.79343137145042, 73.2770311832428, 80.14484345912933, 80.18138989806175, 80.23644134402275, 76.84488013386726, 81.48010700941086, 76.81432217359543, 77.23832622170448, 75.36505714058876, 70.65926045179367, 73.6512503027916, 78.74556854367256, 74.26857277750969, 69.70728233456612, 66.55936405062675, 60.42223356664181, 59.46614407002926, 56.93329498171806, 62.053721621632576, 61.1393690854311, 61.23691365122795, 59.78675566613674, 63.740040734410286, 64.01438221335411, 65.036960542202, 68.97891461849213, 65.52481636404991, 68.42085376381874, 68.23651045560837, 71.86112836003304, 66.5853850543499, 70.36295995116234, 70.11518284678459, 68.50042909383774, 74.02316674590111, 70.62025174498558, 72.33221188187599, 71.63751035928726, 71.24164000153542, 67.60362401604652, 62.685840502381325, 63.02309140563011, 65.23502111434937, 68.38794752955437, 73.51448804140091, 71.65789246559143, 74.99882519245148, 70.27920484542847, 73.09953510761261, 67.65001952648163, 69.88677710294724, 70.85279166698456, 71.83319225907326, 72.55127012729645, 73.12068477272987, 74.44223865866661, 76.81823596358299, 71.42608970403671, 54.544986337423325, 2.737068892456591, 0.3460902679944411, 0.6254697125405073, 0.8455395349301398, 0.5308315751608461, 0.462039828998968, 0.28104734723456204, 0.18443159409798682, 0.26900656521320343, 0.35361327056307346, 0.22838465200038627, 0.12085182490409352, 0.6377627654001117, 15.475994814187288, 80.36821067333221, 39.922344982624054, 45.396616235375404, 56.227729842066765, 31.330145336687565, 53.36778290569782, 68.01267966628075, 3.930233367718756, 0.22349395818309858, 0.12871807819465175, 0.09168018164928071, 0.1566437297151424, 0.1909199240617454, 0.1919212593929842, 0.17455015011364594, 0.12448153560399078, 0.09804543384234421, 0.17112038884079084, 0.13211236480856314, 0.23771056876285002, 0.17941584839718416, 0.13197917898651212], [0.021377172342909034, 0.03708114891196601, 0.11108484235592186, 0.03732737124664709, 0.11297774195554666, 0.010039409189630533, 0.009160638619505335, 0.07777313570841216, 0.053957668715156615, 0.05983522227325011, 0.06489211635198444, 0.06567650707438588, 0.07267135282745585, 0.1873060062644072, 0.23477892216760665, 4.794281590729952, 53.63388642668724, 45.962922647595406, 30.592000745236874, 34.53138425946236, 26.41312938183546, 34.53173764050007, 34.98321421444416, 2.9315108712762594, 0.05397236323915422, 0.17297424405114725, 0.06154827351565473, 0.07074565772200003, 0.09314163369708695, 0.21628711052471772, 0.33036240725778043, 0.1299145835218951, 1.1093427543528378, 0.8403038315009326, 0.5747385753784329, 42.09709748625755, 86.47549375891685, 84.89899635314941, 84.65765610337257, 78.38075011968613, 85.97116962075233, 84.93775427341461, 85.20493313670158, 84.98716682195663, 80.64002528786659, 83.20395290851593, 79.98462125658989, 84.13256227970123, 84.77700769901276, 80.09286984801292, 76.81068956851959, 74.9356497824192, 73.77107307314873, 82.61265903711319, 75.7317678630352, 80.62326058745384, 77.2765901684761, 82.25558459758759, 76.69405862689018, 77.73811340332031, 72.61018976569176, 78.3788350224495, 79.40798699855804, 77.21504867076874, 77.85719141364098, 77.22396299242973, 76.25838160514832, 74.34135407209396, 71.86996668577194, 71.19851991534233, 69.04338955879211, 63.05945545434952, 59.862348809838295, 61.29588268697262, 61.2866073846817, 59.18025881052017, 58.785220608115196, 57.73868076503277, 55.341115817427635, 56.33393034338951, 64.05858904123306, 71.67208090424538, 71.45870715379715, 69.43794518709183, 67.26423382759094, 63.26736129820347, 64.88268122076988, 61.335651353001595, 65.55699303746223, 64.27656814455986, 56.378000378608704, 56.69985070824623, 64.21978399157524, 67.3042456805706, 67.60911852121353, 65.12926518917084, 59.3059066683054, 52.4281807243824, 54.11255434155464, 54.67618189752102, 51.70444115996361, 52.55571708083153, 51.671021953225136, 53.51393066346645, 56.04686714708805, 58.437410071492195, 56.60221114754677, 59.92966219782829, 61.90641492605209, 62.224530056118965, 63.0036136507988, 65.80603167414665, 65.53094163537025, 63.07145521044731, 62.48394213616848, 63.629797250032425, 64.82554748654366, 64.79417636990547, 61.91925063729286, 62.84690245985985, 63.71960923075676, 59.46546770632267, 56.58370614051819, 57.33314372599125, 59.08270664513111, 64.4375579059124, 66.56225949525833, 66.97552531957626, 64.03309240937233, 65.25981858372688, 64.11664232611656, 64.31131348013878, 64.30561378598213, 64.06042814254761, 65.8021254837513, 64.66192066669464, 68.59022587537766, 68.36021661758423, 70.00101417303085, 62.50803664326668, 11.694109048694372, 0.06494616696727462, 0.28637282084673643, 0.0328863781032851, 0.12477835756726563, 0.09429499797988683, 0.14334561594296247, 0.061371475385385565, 0.024407882665400393, 0.08266089804237708, 0.4998323635663837, 0.01610241710295668, 0.26771635632030666, 10.464964304119349, 25.459355860948563, 38.450714349746704, 26.325564980506897, 34.15938042104244, 34.43740390241146, 33.17484185099602, 53.358575999736786, 3.994298167526722, 0.18051998602459207, 0.15391365042887628, 0.046714058771613054, 0.05725774710299447, 0.02714093425311148, 0.097497981187189, 0.03493676886137109, 0.07195573693024926, 0.02724115201999666, 0.013105934631312266, 0.14812160341534764, 0.019994261783722322, 0.03582374665711541, 0.06682936669676565, 0.08220733448979445, 0.04279230553947855, 0.025480017029622104, 0.02352928557229461, 0.04969589310348965, 0.08323002140969038, 0.06546384465764277, 0.10239984432701021, 0.021272677950037178, 0.09219097963068634, 0.04529020392510574, 0.05029316613217816, 0.043565148444031365, 0.22166457900311798, 0.3917510522296652, 7.108512260019779, 63.868804425001144, 60.86691990494728, 54.50282000005245, 34.41764876246452, 23.3137895911932, 41.171269565820694, 37.16346502304077, 2.7268327167257667, 0.04153481793764513, 0.21018524654209614, 0.13648235297296196, 0.15821677108760923, 0.02629249618621543, 0.19115012342808768, 0.19179525756044313, 0.08989254827611148, 1.802019460592419, 0.49072894267737865, 0.9856444888282567, 52.43167273700237, 92.72621154785156, 87.48230293393135, 89.30298283696175, 85.88051408529282, 91.04308426380157, 86.95911660790443, 88.80641028285027, 87.39239975810051, 83.65878850221634, 86.2737549841404, 85.74628248810768, 85.3103394806385, 87.5339725613594, 83.49155187606812, 79.07474488019943, 80.26724249124527, 79.48480367660522, 84.32388961315155, 78.47817689180374, 85.79727575182915, 81.18359372019768, 86.86800509691238, 80.3412701189518, 81.75588861107826, 77.13371023535728, 83.58753472566605, 83.80492106080055, 81.1791479587555, 80.87622821331024, 81.54433876276016, 81.49257034063339, 78.82756054401398, 74.98662784695625, 74.22886490821838, 70.24641260504723, 65.79924523830414, 65.19557163119316, 66.50099918246269, 63.444899171590805, 62.73422710597515, 61.54416136443615, 59.71018597483635, 58.17717343568802, 59.7260957211256, 67.62826949357986, 77.63205349445343, 74.3565608561039, 72.45821312069893, 67.58012607693672, 65.81625312566757, 66.64805129170418, 64.96237814426422, 67.2820396721363, 66.67932361364365, 58.9072472602129, 59.578116461634636, 67.56172746419907, 70.82078218460083, 70.26788905262947, 69.52271103858948, 61.93465881049633, 54.30484302341938, 55.517327561974525, 56.49113930761814, 55.01592546701431, 54.721395671367645, 54.49724569916725, 55.512380227446556, 58.14729943871498, 62.0154082775116, 58.86939749121666, 63.71695697307587, 65.29620543122292, 65.84564834833145, 65.14178171753883, 67.86070302128792, 68.28786849975586, 66.70083805918694, 67.46826007962227, 66.57890260219574, 67.99638614058495, 68.01468595862389, 67.09524929523468, 65.31616196036339, 66.4474068582058, 65.45984745025635, 59.96597684919834, 60.55271476507187, 61.59687593579292, 67.39091902971268, 69.20274540781975, 67.99619615077972, 66.00812003016472, 67.48231172561646, 67.2650545835495, 65.52687585353851, 68.13664421439171, 67.04548716545105, 68.43527019023895, 68.68393644690514, 69.89753812551498, 71.18243157863617, 75.4677352309227, 69.67814549803734, 21.97752859443426, 0.2682698203716427, 0.1768030581297353, 0.10426726599689573, 0.03667544646305032, 0.04675730371673126, 0.2868613915052265, 0.31297308567445725, 0.04383383187814616, 0.05015121554606594, 0.7867429149337113, 0.043240121158305556, 1.1404887330718338, 14.840111285448074, 24.30128440260887, 32.93947108089924, 32.602592557668686, 21.070294976234436, 35.995871275663376, 42.33826294541359, 63.23483124375343, 6.987066026777029, 0.33828726795036346, 0.12854071974288672, 0.03655502187029924, 0.004695795169027406, 0.02121042289218167, 0.08120642218273133, 0.009313061837019632, 0.07242930878419429, 0.017323923530057073, 0.05288506123179104, 0.02802223647449864, 0.03185209883667994, 0.03117397995083593, 0.07293346454389393, 0.13907480839407071, 0.11890575784491375, 0.17384225997375324, 0.11295658332528546, 0.2967178844846785, 0.1514599024085328, 0.16786139574833214, 0.20060459501110017, 0.29205354570876807, 0.2787225547945127, 0.1945984087069519, 0.12290190396015532, 0.12101684143999591, 0.3444739297265187, 0.46957188576925546, 7.343847407028079, 78.70181009173393, 63.719597831368446, 48.27643230557442, 53.78072574734688, 41.83152973651886, 54.72782112658024, 52.98228979110718, 6.20602791197598, 0.17896012519486248, 0.39315255358815193, 0.2823821740457788, 0.2939113194588572, 0.2426238387124613, 0.7151885388884693, 1.1880286945961416, 0.2456469921162352, 2.2729933820664883, 2.2083714371547103, 1.3093325542286038, 60.5988784879446, 97.768115401268, 93.58662977814674, 94.88297581672668, 88.40286433696747, 95.73151588439941, 94.89626750349998, 92.90627628564835, 90.49782872200012, 87.63934850692749, 89.7244942188263, 87.80780866742134, 90.5017577111721, 90.91629266738892, 87.25316002964973, 82.92032852768898, 84.3540295958519, 82.47234776616096, 88.37173640727997, 82.8886230289936, 89.37571853399277, 82.53138899803162, 91.14947095513344, 83.70560958981514, 82.94279292225838, 81.4538124203682, 85.24074241518974, 84.41166490316391, 84.33367028832436, 83.80517944693565, 83.79118859767914, 83.55734914541245, 82.2507132589817, 78.09149444103241, 75.77835336327553, 75.13016894459724, 68.76838311553001, 67.28367358446121, 70.13941034674644, 67.42707788944244, 65.40984973311424, 66.00840881466866, 62.69888520240784, 59.55936446785927, 62.379911318421364, 70.72146311402321, 79.09361466765404, 79.6631433069706, 77.29463160037994, 73.01357612013817, 68.97170260548592, 70.19103437662125, 68.3470769226551, 71.55450001358986, 70.27630940079689, 59.74179267883301, 60.49268938601017, 70.75633004307747, 71.81549280881882, 73.01320374011993, 69.96329739689827, 66.64223000407219, 58.42251107096672, 59.30793195962906, 60.87562143802643, 59.001786187291145, 59.4276787340641, 58.27229753136635, 58.662483394145966, 62.32994019985199, 64.6525351703167, 61.36808641254902, 67.26689368486404, 68.76559406518936, 68.19930285215378, 68.03642839193344, 71.28001794219017, 71.15943521261215, 69.20689478516579, 69.41702350974083, 71.74479380249977, 72.15337827801704, 68.21251094341278, 70.44536232948303, 68.40509980916977, 69.57118883728981, 67.16345563530922, 63.29221576452255, 63.636811673641205, 64.72960263490677, 72.18079760670662, 71.89140513539314, 70.55453807115555, 71.18655055761337, 70.85413679480553, 70.7843953371048, 69.85996574163437, 70.3190267086029, 70.35403043031693, 72.00127243995667, 71.91535145044327, 74.99149158596992, 75.61598047614098, 76.88137337565422, 72.8397810459137, 21.647730991244316, 0.3205709857866168, 0.3765111684333533, 0.26536080928053707, 0.225430058198981, 0.16468417248688638, 0.2751193387666717, 0.45466092182323337, 0.10007537843193859, 0.24373835156438872, 0.8975634339731187, 0.08518967719282955, 1.062810451257974, 19.37411919236183, 39.190238267183304, 48.13071772456169, 41.26524992287159, 48.41520845890045, 46.86644196510315, 44.993043690919876, 77.0424011349678, 7.660364247858524, 0.44013023434672505, 0.29483259189873934, 0.1324518528417684, 0.2394464224926196, 0.06477493865531869, 0.17429823550628498, 0.1401029055705294, 0.17997054441366345, 0.15083505859365687, 0.13534450699808076, 0.16959054046310484, 0.2354008419206366, 0.19989349879324436, 0.1207324727147352], [0.009303605020249961, 0.033184550775331445, 0.03888062325131614, 0.004254221939845593, 0.009929421048582299, 0.03363316791364923, 0.044569125820999034, 0.07234337550471537, 0.04127677319047507, 0.09906420964398421, 0.022591984597966075, 0.024300942895933986, 0.07741763954982162, 0.03382660499482881, 0.07067930229823105, 17.565290853381157, 58.62467922270298, 37.30107083916664, 43.77351813018322, 41.20251528918743, 27.09748785942793, 43.69929291307926, 9.843038376420736, 0.5149362562224269, 0.04588424118992407, 0.14278050017310306, 0.06369641254423186, 0.08458006966975518, 0.18918283836683258, 0.09812739663175307, 0.0524720003886614, 0.1571806735591963, 0.7737880444619805, 0.047130114180617966, 3.374177855439484, 53.89178238809109, 86.28342166543007, 83.216363042593, 83.52524086833, 81.90620854496956, 80.24701237678528, 82.00232818722725, 84.31411653757095, 81.78741931915283, 84.97278079390526, 84.83901277184486, 80.35629451274872, 78.33653569221497, 80.34142971038818, 74.9538280069828, 77.79973849654198, 73.1302298605442, 81.98671862483025, 80.32179236412048, 81.20331466197968, 80.16441240906715, 80.73866799473763, 80.984066426754, 75.85165902972221, 75.2141672372818, 76.055046916008, 79.50935795903206, 78.54050114750862, 80.39664074778557, 76.14953264594078, 77.64441803097725, 75.96928551793098, 72.25297093391418, 69.07171323895454, 70.04851162433624, 63.01727771759033, 62.708753272891045, 61.653508096933365, 59.595359936356544, 59.070729687809944, 58.369184732437134, 58.19371394813061, 55.88339611887932, 56.32196478545666, 56.60284951329231, 66.39217302203178, 71.8226820230484, 70.80097764730453, 68.1855171918869, 62.153861448168755, 61.66286699473858, 63.89790326356888, 65.7565051317215, 65.8288000524044, 63.39083567261696, 61.95517010986805, 62.13410630822182, 66.82063803076744, 70.27785211801529, 66.85846120119095, 65.64929768443108, 58.861908093094826, 50.52710473537445, 50.5064794421196, 51.77096039056778, 49.93915468454361, 51.39908194541931, 51.249062195420265, 51.300564631819725, 52.211797535419464, 53.84825572371483, 56.365035474300385, 58.74514415860176, 62.49096415936947, 64.04028162360191, 62.093345895409584, 62.55757078528404, 65.33313944935799, 64.96665671467781, 64.37549203634262, 64.17727187275887, 63.10534559190273, 64.10377621650696, 62.360403165221214, 65.98558723926544, 63.01714472472668, 63.48810665309429, 59.208859875798225, 58.31906922161579, 54.44788634777069, 61.7134764790535, 64.43218499422073, 66.44169956445694, 65.42720720171928, 64.29964810609818, 62.718461751937866, 62.94326908886433, 64.73981648683548, 64.3735009431839, 66.02344840765, 66.96285679936409, 64.62101206183434, 67.42827102541924, 70.15872091054916, 68.3732271194458, 59.40407820045948, 8.4657671302557, 0.41048956860322505, 0.37286054401192814, 0.08435649026068859, 0.16462885279906914, 0.664534050738439, 0.09481702465564013, 0.24431804311461747, 0.044589108147192746, 1.2051609065383673, 0.26770733180455863, 2.3311043763533235, 16.75919260829687, 5.382013628259301, 8.895350228995085, 34.17988792061806, 29.154336489737034, 59.65662404894829, 26.497076377272606, 56.24530769884586, 15.444745291024446, 0.22933311673114076, 0.12596668442711234, 0.015136250294744968, 0.027874161314684898, 0.05834305644384585, 0.06708890316076577, 0.04197310066956561, 0.08421701844781637, 0.045103197553544305, 0.06883099093101919, 0.022061721938371193, 0.03835206196526997, 0.11171637292136438, 0.05211268588027451, 0.01980154644115828, 0.02710021817620145, 0.047624039434595034, 0.02907712147134589, 0.010563518517301418, 0.03653824933280703, 0.0322027227957733, 0.08823834563372657, 0.048866531942621805, 0.09377765425597318, 0.07139605368138291, 0.04606931055604946, 0.04658226447645575, 0.057361091166967526, 0.16248904808890074, 22.60853413492441, 68.78254115581512, 55.93810178339481, 46.863060146570206, 23.4242819622159, 31.654117852449417, 51.892432272434235, 9.520932510495186, 0.48674717196263373, 0.1568523474270478, 0.05298093557939865, 0.06034271398675628, 0.05188649782212451, 0.2824283653171733, 0.5850136396475136, 0.1125066340318881, 0.6056090095080435, 0.6983908277470618, 0.24211957905208692, 5.116016026586294, 63.69018740952015, 86.04293256998062, 90.16641050577164, 84.24431428313255, 85.33866316080093, 84.01881918311119, 85.27868717908859, 86.41889199614525, 85.60176864266396, 86.3822391629219, 87.91367098689079, 83.45300674438477, 84.30773288011551, 82.30999007821083, 78.74190554022789, 81.40169441699982, 76.48853525519371, 85.7072813808918, 84.24688294529915, 84.10066679120064, 83.6243699491024, 83.96939143538475, 82.09510400891304, 79.24027919769287, 79.57393169403076, 80.16677588224411, 82.29928225278854, 79.61369276046753, 79.94070321321487, 78.13587605953217, 78.90709787607193, 76.91904455423355, 76.12586751580238, 73.61177802085876, 72.27293506264687, 67.48961493372917, 66.31545513868332, 66.60858660936356, 62.52250626683235, 59.80625621974468, 60.088691264390945, 60.71900524199009, 58.43859940767288, 58.96443799138069, 59.70336154103279, 66.67665615677834, 71.8087899684906, 72.96199008822441, 71.65924519300461, 63.91354322433472, 65.59708088636398, 66.21479853987694, 68.62947776913643, 68.18307772278786, 67.59324297308922, 66.75042539834976, 67.298074811697, 71.00494310259819, 70.2250349521637, 69.39295560121536, 67.12153628468513, 60.9491740912199, 53.66022281348705, 53.437664955854416, 54.3987587839365, 53.70376467704773, 54.25815872848034, 53.25574591755867, 54.367334470152855, 54.071026369929314, 55.56510239839554, 57.205816358327866, 61.058775410056114, 66.18357181549072, 66.58840209245682, 66.18858754634857, 65.70933446288109, 67.83497080206871, 67.84690216183662, 67.64195635914803, 67.04900577664375, 66.36394053697586, 67.1994549036026, 65.84247931838036, 68.43963235616684, 63.21072153747082, 67.98145294189453, 63.238433450460434, 62.75953754782677, 56.71726897358894, 62.32580602169037, 66.59487694501877, 67.5884248316288, 66.82527378201485, 69.00182738900185, 64.95363101363182, 65.38859367370605, 68.0979622900486, 65.399871468544, 66.56559571623802, 69.00557398796082, 68.17192912101746, 71.58312767744064, 71.92834675312042, 72.18290269374847, 67.62379333376884, 15.060938335955143, 0.5195357906632125, 0.4409109737025574, 0.0792390777496621, 0.6151260144542903, 1.6518532996997237, 0.3561370476381853, 0.1311324181733653, 0.2327558127581142, 1.5018941089510918, 0.48700668616220355, 4.255433930084109, 29.097945615649223, 5.386046161875129, 5.263470439240336, 40.41710123419762, 25.742182284593582, 45.533408895134926, 36.4483167976141, 63.27461890876293, 21.708710119128227, 0.23046312562655658, 0.16996493912301958, 0.021147650186321698, 0.01624368491320638, 0.04773389213369228, 0.052029030994162895, 0.015180754107859684, 0.026891492852882948, 0.030532743949152064, 0.07216720448923297, 0.03921904259186704, 0.079878890683176, 0.043308172389515676, 0.023864291033532936, 0.14592998195439577, 0.18540636054240167, 0.16492709226440638, 0.12722063198452815, 0.08124459083774127, 0.14346815936733037, 0.14343146758619696, 0.18116278981324285, 0.18284555029822513, 0.24352269829250872, 0.10169840345042758, 0.1027598230575677, 0.135674747871235, 0.20742350723594427, 0.322730308980681, 26.313057951629162, 82.86765575408936, 54.21737551689148, 63.90475809574127, 63.2891721278429, 43.365309834480286, 72.4583651125431, 14.724304899573326, 0.9673516172915697, 0.2859730110503733, 0.27129330032039434, 0.2758953283773735, 0.21385847678175196, 0.34177043417003006, 0.3334457636810839, 0.1384467733441852, 1.0206145467236638, 2.4170541018247604, 0.6731057376600802, 5.898144207894802, 73.40963646769524, 89.45470869541168, 92.6856829226017, 90.73802143335342, 90.58786109089851, 87.06275224685669, 89.26879227161407, 90.09422197937965, 89.28779125213623, 91.64089098572731, 91.49326130747795, 87.73492857813835, 85.17187491059303, 87.04651951789856, 82.69281953573227, 85.6744359433651, 78.13561007380486, 90.37459373474121, 87.02902525663376, 87.64983594417572, 86.46670863032341, 88.01944971084595, 87.88643404841423, 80.9977000951767, 82.31378227472305, 82.7927465736866, 83.95513460040092, 84.8234412074089, 85.37655472755432, 81.45778700709343, 81.4706227183342, 81.45888894796371, 79.27577689290047, 76.01717814803123, 75.8416959643364, 70.01660853624344, 71.80305987596512, 69.13510143756866, 66.99009373784065, 64.0594781935215, 65.64334720373154, 65.12891560792923, 61.67462736368179, 61.507713720202446, 66.39106348156929, 71.16764277219772, 74.1781984269619, 75.11498495936394, 72.41281315684319, 66.10901221632957, 66.58672258257866, 66.24970346689224, 70.85048899054527, 71.99108138680458, 68.5548497736454, 67.21953302621841, 67.20999553799629, 74.82062235474586, 74.88811433315277, 73.21517050266266, 72.54701435565948, 64.9548089504242, 58.11165735125542, 55.49493536353111, 56.362102031707764, 56.784198582172394, 58.56129102408886, 55.666697546839714, 57.468378469347954, 58.3273109793663, 60.92660330235958, 62.8209612518549, 64.82164889574051, 69.62190851569176, 69.1872650384903, 67.87660896778107, 68.06263938546181, 70.9920085966587, 71.06319397687912, 72.21304267644882, 70.30399471521378, 70.23008868098259, 70.02084150910378, 69.91625592112541, 70.80609977245331, 69.59942132234573, 69.94306728243828, 64.9254061281681, 65.65090879797935, 61.45103596150875, 65.15584096312523, 70.5315189063549, 71.97391390800476, 71.51549130678177, 70.44356122612953, 68.69541183114052, 67.74335771799088, 72.64266282320023, 68.25747773051262, 71.47437751293182, 72.26445391774178, 72.244231402874, 73.2771223783493, 77.41637706756592, 74.92053419351578, 69.3606573343277, 14.580930043011904, 0.5548254470340908, 1.1196065973490477, 0.5134155065752566, 0.5742508359253407, 2.356514325365424, 0.4340177576523274, 0.3325903048971668, 0.46098695893306285, 2.1518216840922832, 0.32720798277296126, 4.576297262683511, 31.019912883639336, 6.888580061495304, 13.866040203720331, 55.10239742696285, 44.81685094535351, 85.3207965195179, 37.80475661158562, 77.44473114609718, 22.52618495374918, 0.277491866145283, 0.1981615339173004, 0.1369901600992307, 0.13183906150516123, 0.21493790089152753, 0.18476262164767832, 0.08880330555257387, 0.1602177051245235, 0.1715307668200694, 0.21965586725855246, 0.10819762072060257, 0.16897421650355682, 0.1269349199719727, 0.16070026438683271], [0.0644265374285169, 0.02939512618468143, 0.02361743045184994, 0.03237720542529132, 0.04180484094831627, 0.020817698750761338, 0.02473703629220836, 0.0984486352535896, 0.05610123982478399, 0.04327441209170502, 0.0694256961287465, 0.007727457759756362, 0.048350331126130186, 0.13422807940514758, 0.16819953307276592, 38.13547946512699, 54.16494593024254, 34.678276777267456, 63.71500387787819, 32.02158473432064, 47.58584216237068, 17.469667084515095, 0.869991994695738, 0.041370858962181956, 0.1778577093500644, 0.08994775664177723, 0.15427089063450694, 0.1013678137678653, 0.12118560582166538, 0.011528990489750868, 0.20183617423754185, 0.47191698336973786, 0.1584967240341939, 0.6759272050112486, 18.40217124670744, 76.05495572090149, 78.29343840479851, 94.10923853516579, 80.42398408055305, 82.81321227550507, 81.18753790855408, 85.2703808248043, 78.80309745669365, 83.1150908768177, 83.085156083107, 81.10648065805435, 79.80406254529953, 81.54744699597359, 75.80917730927467, 76.03705108165741, 74.76907432079315, 76.30454152822495, 81.83240130543709, 79.02467876672745, 79.71196308732033, 78.79191845655441, 78.79476830363274, 76.15219250321388, 74.97974261641502, 74.78942602872849, 79.4400192797184, 79.8036977648735, 77.18009814620018, 75.37840962409973, 73.33592802286148, 74.20282870531082, 76.2072591483593, 72.25313812494278, 72.93312683701515, 66.8578152358532, 66.80382013320923, 63.03856037557125, 59.10786509513855, 58.170292004942894, 55.883924290537834, 54.51765440404415, 56.8478299677372, 56.612953171133995, 55.80003619194031, 54.988091960549355, 58.58223170042038, 68.43357548117638, 68.09381291270256, 72.42587685585022, 65.59934556484222, 62.04303279519081, 67.23661690950394, 67.1318793296814, 63.51200357079506, 66.23395711183548, 65.80202668905258, 66.91219791769981, 67.05925762653351, 65.60076668858528, 68.9861798286438, 66.83375492691994, 55.690005496144295, 49.22604314982891, 50.06103314459324, 53.398390263319016, 53.51152539253235, 48.07596266269684, 51.21913120150566, 48.3945831656456, 50.384802371263504, 50.432258024811745, 51.41529567539692, 52.93286584317684, 57.472417652606964, 61.70878753066063, 63.69788959622383, 62.19766549766064, 64.28231343626976, 65.61623945832253, 62.69100062549114, 64.0563927590847, 61.88167825341225, 63.18487912416458, 62.389551401138306, 61.95352479815483, 62.107728123664856, 60.94999484717846, 63.95973354578018, 60.0631832331419, 54.10930171608925, 58.82533885538578, 64.49607476592064, 66.09833478927612, 65.64120411872864, 65.00090807676315, 62.771225720644, 67.11437746882439, 62.63671673834324, 63.48081484436989, 63.5962450504303, 66.20017692446709, 67.76630088686943, 67.52800047397614, 70.41622549295425, 67.76745602488518, 63.42838145792484, 37.24245898425579, 1.364697958342731, 0.11887165615917183, 0.30716637382283807, 1.4716432197019458, 0.4479012923547998, 0.10361692198785022, 0.02862560810171999, 0.04591595316014718, 1.2130475020967424, 1.1754532693885267, 4.93216241709888, 26.01796768605709, 1.5832163952291012, 0.5617175647057593, 16.554533690214157, 46.2844879925251, 37.694452330470085, 25.686332881450653, 51.02464623749256, 30.22190060466528, 0.11953299137530848, 0.231372122943867, 0.0066665595113590825, 0.06313290723483078, 0.07365916622802615, 0.09299586105044, 0.03465567671810277, 0.08051594282733276, 0.037590173160424456, 0.03499717226077337, 0.015154602679103846, 0.018055827713396866, 0.011194221588084474, 0.012439409019862069, 0.05967534511000849, 0.033327503260807134, 0.022967425975366496, 0.04968803747033235, 0.010093172222696012, 0.05666530174494255, 0.014669816973764682, 0.007780850182825816, 0.05491652722412255, 0.017832608245953452, 0.03471926764177624, 0.015157535090111196, 0.03271330184361432, 0.08531926359864883, 0.2829599508550018, 45.89861109852791, 68.26453015208244, 47.3765379935503, 50.90079568326473, 27.371916733682156, 59.07220020890236, 23.39287854731083, 0.6268185807857662, 0.0527538717869902, 0.2260082060820423, 0.14078220818191767, 0.11317287484416738, 0.1283825680729933, 0.9344786906149238, 0.5756351491436362, 0.764895809115842, 0.9309286717325449, 0.3221355815185234, 0.7039436360355467, 26.026891507208347, 85.02347007393837, 80.68553164601326, 95.02681329846382, 84.32137414813042, 87.49192401766777, 86.05038776993752, 88.28111127018929, 82.78304949402809, 86.32759049534798, 85.3683851659298, 85.6045500934124, 83.53084176778793, 82.89233922958374, 77.4107837677002, 80.23131161928177, 77.76713624596596, 81.00058794021606, 84.74152520298958, 81.43008649349213, 80.59090912342072, 83.63324627280235, 81.58104479312897, 78.57020035386086, 77.7761721611023, 79.4449970126152, 83.93596842885017, 81.84262275695801, 79.42228183150291, 80.8653075993061, 77.4473150074482, 76.35184898972511, 80.21386295557022, 76.78893953561783, 75.55613368749619, 70.68121567368507, 70.6492517888546, 65.65335586667061, 63.569490686059, 60.81901207566261, 57.60052017867565, 57.94655621051788, 60.22476576268673, 59.41343329846859, 58.87718707323074, 57.79126614332199, 62.347472459077835, 70.84686398506165, 73.37793096899986, 74.39036384224892, 69.17055353522301, 63.83605018258095, 69.66358467936516, 70.57442620396614, 67.12289661169052, 67.7916607260704, 68.8348339498043, 66.96541786193848, 69.83817011117935, 68.6947050690651, 69.166768938303, 71.4452862739563, 59.45934623479843, 52.47461423277855, 54.9341044574976, 56.646573767066, 56.40279784798622, 49.68856953084469, 52.57723152637482, 51.9935068488121, 51.63428172469139, 53.536262065172195, 54.133909195661545, 54.2234817892313, 59.16307233273983, 62.95598700642586, 66.01468607783318, 67.04796463251114, 67.75123849511147, 67.22485274076462, 65.90690106153488, 65.23520350456238, 65.1751059293747, 66.15410059690475, 65.59236153960228, 65.28107464313507, 64.70908373594284, 63.982281535863876, 65.0041151046753, 63.81477132439613, 57.11064666509628, 59.858214631676674, 67.51377403736115, 68.41937944293022, 68.13115730881691, 69.11546409130096, 67.74041667580605, 69.91095900535583, 66.81547030806541, 63.60694907605648, 66.10913380980492, 66.61578342318535, 70.85172012448311, 70.77034369111061, 72.13200822472572, 70.7073050737381, 65.07397815585136, 47.59339235723019, 3.617364331148565, 0.1787926076212898, 0.09913742251228541, 1.949454874265939, 2.532044481486082, 1.7938097636215389, 0.08666102949064225, 0.16392296645790339, 1.5531368530355394, 0.914658538531512, 3.528614630922675, 24.183524921536446, 0.9618280199356377, 0.7770004752092063, 17.606638334691525, 52.81184233725071, 26.15688443183899, 31.57836701720953, 58.014473766088486, 35.434443801641464, 0.10610708719468676, 0.15568711620289832, 0.05231876544712577, 0.05270978079352062, 0.04245016803906765, 0.1326039040577598, 0.04421252386237029, 0.07435863299178891, 0.07155485844123177, 0.030096622722339816, 0.004310425711082644, 0.06238431771635078, 0.04001255801995285, 0.020388511038618162, 0.13580486120190471, 0.12175540454336442, 0.09709926976938732, 0.14978512743255123, 0.14597905275877565, 0.21269642194965854, 0.12213459747727029, 0.1685561944032088, 0.09989462836529128, 0.1915338879916817, 0.17663539212662727, 0.1100160829082597, 0.17833600868470967, 0.26037414092570543, 0.31823069730307907, 54.383491203188896, 74.83307048678398, 50.65213322639465, 85.50751090049744, 51.019546911120415, 72.31809183955193, 32.55662262439728, 0.8614572370424867, 0.12001724273432046, 0.30213550315238535, 0.35072171478532255, 0.2597148169297725, 0.35475935437716544, 0.5802793311886489, 0.32113498833496124, 0.8076902409084141, 0.9861312189605087, 0.5148701753932983, 1.1966881924308836, 25.918840505182743, 94.72178846597672, 91.73093095421791, 103.75689044594765, 90.74781730771065, 93.57611954212189, 89.70001593232155, 94.53387334942818, 86.96027174592018, 91.26744702458382, 88.21384727954865, 87.9223421216011, 87.01541438698769, 86.74977824091911, 81.25918686389923, 81.34396031498909, 80.8127412199974, 84.1767767071724, 88.94279256463051, 85.63503205776215, 82.64830872416496, 86.87637984752655, 85.50957038998604, 84.32716503739357, 81.57874211668968, 82.20781356096268, 87.3483145236969, 84.22058835625648, 84.79260206222534, 84.7295406460762, 80.58527022600174, 80.21222904324532, 85.3365732729435, 79.6809795498848, 80.08629620075226, 73.7374296784401, 75.77117934823036, 69.74870771169662, 67.5469234585762, 65.26874050498009, 60.440111607313156, 61.74920596182346, 62.295601442456245, 62.02838458120823, 61.86742901802063, 61.918000504374504, 66.49526908993721, 76.6615703701973, 77.74953559041023, 76.84621766209602, 70.58419927954674, 65.14788419008255, 72.47530460357666, 72.7869562804699, 72.51520246267319, 72.40552514791489, 72.61239364743233, 72.86908507347107, 73.41420382261276, 73.38374465703964, 72.18067601323128, 74.25994724035263, 64.15310516953468, 55.803919583559036, 57.376598194241524, 59.19473223388195, 60.41358523070812, 54.405879601836205, 54.87967237830162, 53.916872441768646, 55.78191116452217, 55.98318636417389, 55.87796241044998, 58.501277044415474, 62.82414548099041, 67.40116328001022, 71.7671138048172, 69.52037796378136, 69.92865845561028, 70.72337061166763, 67.3362247645855, 67.4043171107769, 67.53392815589905, 69.93539169430733, 68.18758428096771, 69.16279435157776, 67.63889372348785, 66.5371960401535, 68.55805680155754, 65.89924067258835, 61.55410923063755, 63.536147475242615, 70.7456374168396, 72.3710685968399, 73.84438633918762, 70.55371731519699, 70.74667096138, 73.61444547772408, 70.30877485871315, 69.16555300354958, 68.31882923841476, 68.98104250431061, 73.66271808743477, 73.09101596474648, 74.8721931874752, 70.97414195537567, 70.29185816645622, 50.0856102257967, 3.431217069737613, 0.3076908941147849, 0.3644509124569595, 4.864251986145973, 4.368168655782938, 2.322824145667255, 0.2773378853453323, 0.12488414329709485, 1.9581007165834308, 2.1651223953813314, 8.10648500919342, 31.38046033680439, 1.0680263838730752, 1.0323291993699968, 27.22797855734825, 65.74402660131454, 55.909341126680374, 36.434363946318626, 68.25082048773766, 41.825609654188156, 0.3473055793438107, 0.4626443824963644, 0.11797876344644465, 0.11920137752895243, 0.15634982439223677, 0.15908025990938768, 0.14432933268835768, 0.1831839547958225, 0.11400650706491433, 0.22104663716163486, 0.09532046053209342, 0.10976051693432964, 0.16467030916828662, 0.08472248038742691], [0.024943054631876294, 0.05586808671068866, 0.03713360019901302, 0.04092226408829447, 0.046147009707055986, 0.0316814271354815, 0.02773639644146897, 0.02838356220308924, 0.0038103788983789855, 0.05337921655154787, 0.10809986502863467, 0.05958030196779873, 0.08031801204197109, 0.10658149025402963, 3.9574178215116262, 54.8786236345768, 35.138257294893265, 51.32079094648361, 33.817885145545006, 27.144364044070244, 47.715947180986404, 2.3968850215896964, 0.06947035115445033, 0.10380484120105393, 0.021530132689804304, 0.030080471733526792, 0.2222028438700363, 0.13958007737528533, 0.5213082768023014, 0.8729187282733619, 0.4544778191484511, 0.4914528632070869, 0.35814283532090485, 2.6058588456362486, 58.28128784894943, 77.31518089771271, 79.48382332921028, 87.36619636416435, 80.98767623305321, 79.16284695267677, 77.4732980132103, 78.95578846335411, 80.97749277949333, 77.84081429243088, 83.31122875213623, 80.48826143145561, 79.61338117718697, 77.44096174836159, 75.79956382513046, 77.08040669560432, 73.50602209568024, 80.86999654769897, 82.85255536437035, 78.87562036514282, 78.56813326478004, 79.85370308160782, 73.9866355061531, 73.58806729316711, 73.74702036380768, 79.7979524731636, 80.3513091802597, 77.81878307461739, 75.99945589900017, 76.09533995389938, 73.34130093455315, 73.15897151827812, 76.09096258878708, 72.93666824698448, 67.93026208877563, 62.1930905431509, 62.54451088607311, 58.54025535285473, 56.87596745789051, 55.72332590818405, 57.36308231949806, 51.81082405149937, 58.78621615469456, 56.89508803188801, 58.65918517112732, 57.275421023368835, 54.824290350079536, 63.68175566196442, 68.2173290848732, 72.13504046201706, 66.02597147226334, 65.39230227470398, 67.69328400492668, 67.44415417313576, 64.94391113519669, 64.78162184357643, 66.094109416008, 61.02322831749916, 65.9750010073185, 64.43056628108025, 64.21840086579323, 62.62083359062672, 53.368102088570595, 51.097127348184586, 54.32356841862202, 51.95944167673588, 51.96641430258751, 49.21784698963165, 53.69068957865238, 49.114097356796265, 46.61496765911579, 49.928363263607025, 50.99306233227253, 51.65175698697567, 53.71597722172737, 55.66843405365944, 58.01069676876068, 62.450245544314384, 66.2428106367588, 65.75315371155739, 63.479139134287834, 63.1537701934576, 61.326303854584694, 63.734766617417336, 60.316937416791916, 63.542310744524, 64.72115948796272, 61.67789898812771, 62.122562527656555, 60.99305413663387, 58.52512836456299, 57.91907988488674, 61.48035518825054, 63.41460719704628, 64.38013538718224, 65.09380549192429, 62.49965809285641, 65.0728078186512, 64.11270573735237, 59.60462383925915, 64.9357795715332, 63.7699793279171, 65.72377368807793, 70.18775135278702, 68.93182754516602, 68.8519786298275, 62.87703104317188, 62.60226018726826, 14.554729498922825, 2.485486054793, 0.15961891069309786, 0.5249088804703206, 1.3876467081718147, 0.7059284357819706, 0.18704413203522563, 0.4684513615211472, 0.9780627675354481, 0.3328254766529426, 1.5434002317488194, 11.972442213445902, 0.3010886296397075, 0.26916214905213565, 5.431605717167258, 35.71923092007637, 31.993614435195923, 30.289561673998833, 34.6889504045248, 30.734035223722458, 0.05952346829872113, 0.025260580659960397, 0.029610000201500952, 0.01499959214925184, 0.08769727544859052, 0.02965024501463631, 0.017782418653951026, 0.03184112618328072, 0.06393398885848, 0.03804041931289248, 0.06761909346096218, 0.13537594437366351, 0.03295486720162444, 0.0609709234413458, 0.06394070529495366, 0.041225449967896566, 0.025659188177087344, 0.010986544548359234, 0.10544433447648771, 0.011626389023149386, 0.018107993273588363, 0.0054155694124347065, 0.013987963229737943, 0.019734100060304627, 0.03302070312201977, 0.03664672163722571, 0.08276969689177349, 0.37175325967837125, 5.922411605715752, 62.34438322484493, 54.227061197161674, 56.43098473548889, 22.57562220096588, 34.35629345476627, 54.64796081185341, 3.436172241345048, 0.05685297604941297, 0.08205969905247912, 0.07441928129992448, 0.04341138657764532, 0.24214953213231638, 0.2756051189498976, 1.1864976142533123, 1.877244261559099, 0.8056219643913209, 0.39735969970934093, 0.29580572561826557, 4.35380257666111, 68.18848103284836, 81.90724968910217, 89.05996307730675, 92.1497368812561, 89.86327797174454, 83.30663099884987, 82.60158643126488, 83.08997422456741, 85.33556252717972, 80.92118740081787, 86.54249176383018, 83.9373667538166, 84.05883863568306, 80.85836917161942, 78.329186886549, 78.82705897092819, 77.39173918962479, 84.42422702908516, 86.1570556461811, 81.43093004822731, 81.52606174349785, 81.43825605511665, 78.96041661500931, 76.25758364796638, 78.59730809926987, 80.92105820775032, 84.05882343649864, 78.92215266823769, 79.81048420071602, 80.59814393520355, 79.2343819141388, 78.51922988891602, 77.55427166819572, 75.50943419337273, 69.80744495987892, 65.26922687888145, 66.00153878331184, 60.31194068491459, 60.18824592232704, 58.62686030566692, 61.25197224318981, 55.268269926309586, 59.73744951188564, 61.704402565956116, 61.21318772435188, 61.35564208030701, 58.383969739079475, 65.61342760920525, 70.53147330880165, 73.52782532572746, 66.9804422557354, 68.30950453877449, 71.98082193732262, 70.34300342202187, 70.04696890711784, 67.58606895804405, 69.5974226295948, 64.28323298692703, 69.06253293156624, 66.23318195343018, 68.62879380583763, 63.80055248737335, 58.04188169538975, 54.959133714437485, 59.25690829753876, 54.514724761247635, 54.605467692017555, 51.2175352871418, 57.65419989824295, 51.387199983000755, 49.9159075319767, 52.98255197703838, 53.23829725384712, 55.2824317663908, 56.879607662558556, 56.35563477873802, 60.504320561885834, 63.36381912231445, 67.16708824038506, 67.60603308677673, 68.2371412217617, 67.97466650605202, 64.82739418745041, 65.53495422005653, 64.62811008095741, 64.47858810424805, 66.61053210496902, 64.64818820357323, 64.47476550936699, 65.46422481536865, 63.38876098394394, 60.530732944607735, 64.2563684284687, 66.07460126280785, 67.83962935209274, 66.64511024951935, 66.64878845214844, 68.96391302347183, 67.1522006392479, 63.68912346661091, 67.39311531186104, 65.78331649303436, 66.67607858777046, 74.81561422348022, 70.58892622590065, 72.64834731817245, 65.1885724067688, 69.3425703048706, 17.729960717260838, 4.150787070393562, 0.8855141617823392, 1.0825014696456492, 2.776645668782294, 3.004558151587844, 0.7213703321758658, 1.0034790099598467, 0.35043337556999177, 0.30043081962503493, 3.0783699033781886, 11.893670540302992, 0.15567878930596635, 0.3822150483028963, 4.562183870002627, 43.275064677000046, 28.282746858894825, 33.997702896595, 51.95765197277069, 34.95322622358799, 0.29434170573949814, 0.07366551901213825, 0.11949424384511076, 0.04517558292718604, 0.10037295738584362, 0.10579243142274208, 0.06110139671363868, 0.042285374147468247, 0.11057724303100258, 0.0233159366689506, 0.020506690634647384, 0.12182924823719077, 0.03224674699595198, 0.03589378684409894, 0.18962015630677342, 0.1652806217316538, 0.0914279256539885, 0.17860997992102057, 0.1632308098487556, 0.08213185807107948, 0.1285655371611938, 0.11321436089929193, 0.14360236935317516, 0.20445801870664582, 0.16109225194668397, 0.18491125898435712, 0.3056463069515303, 0.4266518825897947, 6.667259037494659, 80.52653297781944, 51.68653652071953, 71.5681640803814, 52.20800153911114, 43.02243523299694, 70.38189813494682, 5.423474628478289, 0.2799511654302478, 0.21745534002548084, 0.25476614653598517, 0.14645030169049278, 0.48845307261217386, 0.2554874843917787, 1.0612395917996764, 4.727251762524247, 0.8599749009590596, 1.674067738931626, 1.0974178067408502, 4.566301899030805, 72.88134321570396, 82.49646127223969, 93.43757137656212, 98.13253864645958, 95.29925107955933, 88.12500804662704, 87.09394097328186, 87.06501692533493, 91.23663827776909, 85.00103607773781, 91.45978510379791, 87.76833638548851, 88.2336974143982, 84.13616448640823, 82.59006544947624, 83.26148942112923, 82.12472721934319, 85.90078219771385, 91.72514006495476, 85.08582472801208, 83.47839698195457, 86.72199413180351, 81.96510538458824, 80.35035163164139, 82.48073011636734, 85.94188839197159, 86.06328427791595, 84.89825919270515, 81.94850787520409, 83.06744143366814, 79.84535872936249, 82.16448828577995, 81.15425169467926, 78.46228614449501, 75.22979959845543, 67.41709202528, 72.78238892555237, 65.00672936439514, 63.38304229080677, 61.50324895977974, 64.68299433588982, 58.81574437022209, 66.61448389291763, 65.48039674758911, 66.63627952337265, 63.88438358902931, 61.6561945527792, 71.84001669287682, 75.31618416309357, 78.77529814839363, 69.94131937623024, 71.14405363798141, 73.82536455988884, 73.63722145557404, 74.36588555574417, 73.20073887705803, 74.40220400691032, 64.13120314478874, 72.74937629699707, 70.62851250171661, 73.18402737379074, 68.97497043013573, 61.088900193572044, 56.512725949287415, 62.19358451664448, 59.39240142703056, 60.926040932536125, 55.196871757507324, 60.53489372134209, 55.55894672870636, 51.079359501600266, 57.60278105735779, 57.07020163536072, 58.03476847708225, 60.19051060080528, 60.95258250832558, 64.21660736203194, 67.51187413930893, 72.38154083490372, 71.38012737035751, 69.46920990943909, 70.0456465780735, 68.34369510412216, 70.94220086932182, 67.35498055815697, 68.5566508769989, 67.96990156173706, 65.95344096422195, 68.97732630372047, 68.79261821508408, 66.24101713299751, 64.43182021379471, 68.74206572771072, 67.96042487025261, 70.71017012000084, 70.32291010022163, 67.35270828008652, 72.21244990825653, 69.92141604423523, 65.6332017481327, 69.91008505225182, 70.15689700841904, 70.41741102933884, 76.8822929263115, 71.80440500378609, 73.8552537560463, 68.7087795138359, 72.37138777971268, 20.684005804359913, 5.100425463169813, 0.7832599862013012, 2.605489077977836, 4.041970409452915, 3.1814749957993627, 0.24524535663658753, 1.2704570777714252, 1.8475527735427022, 0.8306300255935639, 2.7775626070797443, 16.013473123311996, 0.3668401826871559, 0.41385565360542387, 8.500456418842077, 53.90370614826679, 46.24169088900089, 43.37378717958927, 50.97428373992443, 46.245775669813156, 0.2628020028350875, 0.1676313448115252, 0.22171733085997403, 0.1541509447270073, 0.16687330033164471, 0.2123233739985153, 0.09331174136605114, 0.14897111017489806, 0.2918744506314397, 0.1575311305350624, 0.12731626513414085, 0.2849621168570593, 0.1210149192775134, 0.15780612593516707], [0.015095923845365178, 0.05928781785769388, 0.0810610874032136, 0.07685621225391515, 0.05396388420194853, 0.011401568372093607, 0.019389747249078937, 0.056694579470786266, 0.046399993007071316, 0.04799479786015581, 0.043495880090631545, 0.023936997386044823, 0.004347329468146199, 0.0832117794197984, 16.420613676309586, 65.0940790772438, 32.87311524152756, 37.11284413933754, 25.54398111999035, 52.11575388908386, 20.017724856734276, 0.05943157186266035, 0.10274351807311177, 0.09378781425766647, 0.037694600760005414, 0.09264219057513401, 0.09292236616602167, 0.07173110367148183, 2.767875026911497, 1.4369028713554144, 0.4740319261327386, 0.3233122418168932, 0.04044114830321632, 26.476111002266407, 81.15427449345589, 70.28895512223244, 84.71635535359383, 80.96852526068687, 81.41275942325592, 77.98124715685844, 83.93494248390198, 78.64130973815918, 79.5989191532135, 81.09484568238258, 81.62599638104439, 82.25031808018684, 79.77553367614746, 77.57495775818825, 75.9116730093956, 76.16655573248863, 73.95225495100021, 82.31261193752289, 78.38651061058044, 77.84243300557137, 79.15203273296356, 78.0686728656292, 72.61475712060928, 75.12744069099426, 75.43017044663429, 77.94684380292892, 73.8971883058548, 72.54902824759483, 75.797800719738, 76.02618366479874, 73.71723756194115, 74.50578644871712, 70.69449216127396, 66.76498621702194, 65.99716901779175, 64.13620367646217, 61.186547353863716, 56.24177768826485, 54.67617429792881, 55.527024641633034, 56.93042993545532, 56.50442719459534, 54.3303282558918, 52.47859261929989, 57.165416926145554, 58.47132325172424, 59.10714313387871, 61.33576914668083, 68.80375921726227, 70.15912368893623, 67.85624206066132, 66.91855877637863, 67.87239119410515, 67.56940305233002, 67.5601315498352, 66.8760846555233, 66.7929907143116, 68.33965212106705, 64.8298792541027, 64.6178886294365, 65.17996206879616, 60.705599561333656, 54.20756824314594, 53.273749351501465, 52.996995002031326, 50.358484983444214, 50.4018634557724, 52.45438791811466, 49.78459417819977, 49.07174102962017, 49.515743404626846, 48.62127900123596, 48.284689262509346, 50.3940586745739, 53.67748908698559, 52.99958646297455, 58.115719333291054, 61.65001228451729, 62.615035101771355, 62.72880479693413, 64.5133638381958, 65.67958205938339, 63.151129335165024, 62.480944097042084, 62.826919332146645, 60.300214514136314, 66.87464833259583, 63.44364903867245, 65.08418440818787, 59.857735857367516, 59.73658315837383, 58.58549192547798, 61.05847142636776, 62.695461586117744, 66.10400408506393, 64.59642738103867, 65.87818220257759, 63.91506314277649, 63.90621721744537, 61.35013237595558, 64.05149102210999, 65.58090135455132, 64.42964673042297, 67.44975507259369, 68.22106808423996, 71.44898727536201, 57.250365167856216, 56.96065351366997, 28.09967838227749, 4.5065391808748245, 0.581717019667849, 1.110095945186913, 2.4093103548511863, 2.141405255533755, 0.24521341460058466, 0.0142210662488651, 0.02565391707321396, 0.19067359040491283, 4.573231302201748, 8.133546207100153, 0.19165482837706804, 0.30876169446855783, 0.5835281568579376, 34.11798544228077, 28.472480177879333, 25.37446841597557, 28.018011264503002, 35.20406976342201, 0.28417763707693666, 0.030512720804836135, 0.04311484291974921, 0.007876289910200285, 0.01587892675161129, 0.0822326194611378, 0.024669979538884945, 0.04857289379287977, 0.06366495290421881, 0.0624654493003618, 0.02569343829236459, 0.040689222296350636, 0.016286200698232278, 0.03218060308427084, 0.039083177616703324, 0.001477916478052066, 0.08449167245998979, 0.014043572355149081, 0.11273391675786115, 0.07175393213401549, 0.025948883667297196, 0.05947998957708478, 0.053285891481209546, 0.01598530991032021, 0.02987762421980733, 0.06369954440742731, 0.14820224518189207, 0.0718363476335071, 20.693070217967033, 74.8276899755001, 46.922055780887604, 42.69501060247421, 25.667719580233097, 61.68737567961216, 22.440138570964336, 0.379529720521532, 0.11201538422028534, 0.044432151335058734, 0.09425521886441857, 0.09668783051893115, 0.11744315546820872, 0.08738215954508632, 2.1586119197309017, 3.313927575945854, 1.5362716955132782, 0.9206122253090143, 0.11150883132359013, 33.06562051177025, 84.83307749032974, 75.56584596633911, 87.14892402291298, 86.00567176938057, 86.56516134738922, 82.5146546959877, 87.08816528320312, 82.14839234948158, 83.48166480660439, 83.0391101539135, 84.86184194684029, 85.4995845258236, 79.8337009549141, 81.14266231656075, 80.02139568328857, 77.69769877195358, 78.65766406059265, 83.76668751239777, 82.38252818584442, 80.18156468868256, 80.35931155085564, 81.01714745163918, 75.5384874343872, 79.4320397078991, 79.9405512213707, 80.54835140705109, 76.71287521719933, 76.22485980391502, 79.28323209285736, 77.46119946241379, 76.26303255558014, 76.20639279484749, 72.04697638750076, 70.30071929097176, 68.42694863677025, 66.69795781373978, 64.91907566785812, 58.763052597641945, 57.213343754410744, 59.078481271862984, 60.43012574315071, 59.719905853271484, 59.10586640238762, 56.84237726032734, 59.80458810925484, 60.529824793338776, 62.5274346023798, 63.95466461777687, 71.5986916422844, 71.61390602588654, 71.53055369853973, 69.5057563483715, 68.43218475580215, 71.26934811472893, 69.97036501765251, 69.55733478069305, 70.67582756280899, 68.61694604158401, 66.50877356529236, 68.88986259698868, 70.00856056809425, 62.63967677950859, 56.21493972837925, 55.72076864540577, 56.82084761559963, 53.3338925242424, 54.88522008061409, 54.70715403556824, 53.14560502767563, 52.12672010064125, 52.89155825972557, 52.45126448571682, 52.28408105671406, 53.496048822999, 56.79584115743637, 58.25728453695774, 61.20354384183884, 63.606755286455154, 66.47122398018837, 64.80165436863899, 68.89566868543625, 66.42140105366707, 66.29669174551964, 64.5968909561634, 65.29313519597054, 63.31617347896099, 68.2392767071724, 67.70840719342232, 67.33946219086647, 63.22290748357773, 63.465581461787224, 60.43007634580135, 65.21359026432037, 65.7954378426075, 70.13961553573608, 65.39430856704712, 70.02331137657166, 67.19137653708458, 66.51596277952194, 65.97726568579674, 65.87537035346031, 66.85731366276741, 63.96296337246895, 70.46602562069893, 71.42184153199196, 74.21555802226067, 57.82470054924488, 60.342088267207146, 28.892977014183998, 4.688409296795726, 0.7776494091376662, 1.3834898499771953, 3.001934392377734, 4.868490183725953, 1.2862049764953554, 0.3665121830999851, 0.2204095182241872, 0.11536538688233122, 4.401294803246856, 6.9108634907752275, 0.15017478464869782, 0.9803133155219257, 0.3015937650343403, 36.9661720097065, 34.65552359819412, 27.131604328751564, 40.3199328482151, 42.4239407479763, 0.5347827693913132, 0.15964264457579702, 0.08914706093491986, 0.03449558433203492, 0.10383263463154435, 0.04292338366212789, 0.12267674377653748, 0.031161259539658204, 0.02644801508722594, 0.005962653776805382, 0.10901134854066186, 0.11207031056983396, 0.03625248536991421, 0.03219729398551863, 0.15280293737305328, 0.10873382983845659, 0.16390095435781404, 0.15959704702254385, 0.2522074885200709, 0.1550581312039867, 0.10743819584604353, 0.12314898718614131, 0.23690179106779397, 0.09965769029804505, 0.13630472734803334, 0.14937022235244513, 0.20187985704978928, 0.2622251462889835, 23.453810177743435, 89.56023663282394, 48.77203971147537, 58.12488064169884, 46.04939840734005, 74.82915669679642, 28.820583298802376, 0.8968331606592983, 0.33664189686533064, 0.2821710775606334, 0.1338455468066968, 0.28902196150738746, 0.32693410059437156, 0.5422633211128414, 8.565060552209616, 12.174187637865543, 7.221054146066308, 1.3177848444320261, 0.3007937001530081, 35.01783795654774, 97.28964507579803, 81.79928228259087, 94.12754595279694, 91.16942748427391, 93.01415249705315, 88.69996279478073, 93.78535151481628, 85.90917974710464, 87.79125675559044, 88.2911579310894, 89.44268614053726, 89.77042615413666, 87.14391589164734, 85.27235671877861, 85.8970507979393, 82.69649013876915, 80.38046881556511, 85.38015693426132, 85.32270401716232, 81.5508060157299, 85.54524287581444, 84.60182949900627, 78.22682797908783, 82.09526360034943, 83.89547780156136, 82.51938164234161, 80.85332304239273, 79.38963398337364, 83.83230239152908, 82.93908432126045, 81.1609697341919, 79.52112212777138, 76.20757073163986, 73.52045372128487, 72.59449660778046, 73.126620054245, 69.12345886230469, 61.59638196229935, 59.58758555352688, 62.439518719911575, 64.04307067394257, 64.85229805111885, 62.74748079478741, 62.19468645751476, 65.93594670295715, 66.43050536513329, 66.29964038729668, 67.2636866569519, 75.4792258143425, 74.45769622921944, 71.71479821205139, 72.46071338653564, 73.44366744160652, 74.01961013674736, 72.38956600427628, 71.32357120513916, 74.97427850961685, 70.8557403087616, 68.07213127613068, 70.90896785259247, 71.7220938205719, 65.27837678790092, 59.35837425291538, 60.590921714901924, 61.52012765407562, 58.58337923884392, 60.09919390082359, 58.79853509366512, 57.65399470925331, 55.80914430320263, 57.37573184072971, 56.51487283408642, 53.92500400543213, 56.65355399250984, 60.17883002758026, 59.8558359593153, 64.81319814920425, 69.42889407277107, 70.73630511760712, 69.05736520886421, 71.40779748558998, 70.88873773813248, 69.32951420545578, 68.98918926715851, 66.78722262382507, 67.55256235599518, 72.04673320055008, 70.33383071422577, 71.91234201192856, 65.92306539416313, 66.2873062491417, 63.31518933176994, 68.06615799665451, 67.29104518890381, 72.07533046603203, 69.40346583724022, 72.61515989899635, 69.07128006219864, 70.40161907672882, 68.62152099609375, 68.45447435975075, 70.003202855587, 67.5068736076355, 73.0692583322525, 74.58041444420815, 76.28655329346657, 64.67081218957901, 68.84407505393028, 33.63812059164047, 8.322161436080933, 1.8947252235375345, 2.655532630160451, 9.735880326479673, 5.771792912855744, 0.3862053982447833, 0.1285689658834599, 0.21746323647676036, 0.3013646195176989, 5.701401215046644, 12.029382158070803, 0.34786622738465667, 2.5394849572330713, 0.6327552278526127, 45.63875824213028, 42.75950454175472, 36.65631763637066, 44.142417535185814, 53.63855257630348, 0.5167061893735081, 0.24571676884079352, 0.129982816579286, 0.1782730151899159, 0.09890904882922769, 0.16136699501657858, 0.20538113167276606, 0.1769314199918881, 0.17814005201216787, 0.13470805599354208, 0.1901502427062951, 0.2689008240122348, 0.20593024673871696, 0.12098543375032023], [0.08050244316109456, 0.03433480545936618, 0.026321786899643485, 0.03889485393301584, 0.031294883228838444, 0.030556537203665357, 0.0014895125354996708, 0.011765744875447126, 0.05718428932595998, 0.021567095354839694, 0.03642461910203565, 0.01856875380326528, 0.06989775400143117, 0.046941118853283115, 37.45962493121624, 51.96865998208523, 43.74111346900463, 30.757227279245853, 14.964800644665956, 48.0965081602335, 2.539065317250788, 2.333798431791365, 1.6699147992767394, 0.22382032504538074, 0.34359003184363246, 0.07489750641980208, 0.05058197661128361, 1.134572213049978, 1.5858982200734317, 1.5455158869735897, 0.7064778031781316, 0.37338568770792335, 3.943504630587995, 52.44219817221165, 70.73895737528801, 80.39343371987343, 77.9057452082634, 79.87688943743706, 80.58541461825371, 76.37272506952286, 74.68754589557648, 78.16036194562912, 78.16673800349236, 75.52093237638474, 80.14077007770538, 82.52129673957825, 73.31357002258301, 75.01416876912117, 73.20776090025902, 77.77209877967834, 78.98300260305405, 81.51901692152023, 79.4083745777607, 77.99488082528114, 77.23414644598961, 76.63969874382019, 70.01282393932343, 77.72767156362534, 75.79541444778442, 76.70529082417488, 73.35289791226387, 75.4516088962555, 75.74778780341148, 72.2263115644455, 71.78728312253952, 73.3628685772419, 68.74271929264069, 67.62337535619736, 63.09964969754219, 59.746591821312904, 54.64853458106518, 54.71180118620396, 54.635558277368546, 53.05423893034458, 55.592875108122826, 53.93429830670357, 54.95653845369816, 54.46882702410221, 54.134433567523956, 55.833820179104805, 55.68213231861591, 60.853666216135025, 66.91265389323235, 70.46353295445442, 71.01795360445976, 67.69700020551682, 65.43942734599113, 63.56932729482651, 65.32806292176247, 64.22802194952965, 67.56451651453972, 69.03211176395416, 64.64607551693916, 65.98098948597908, 66.8333825469017, 58.3863940089941, 52.60427467525005, 51.12523823976517, 50.619093999266624, 48.354609310626984, 48.743339851498604, 49.56712044775486, 49.842062294483185, 48.15204218029976, 49.514189288020134, 50.78969344496727, 47.32258088886738, 48.56330931186676, 49.839182049036026, 49.458263888955116, 54.37659077346325, 57.38710083067417, 59.314042031764984, 61.72032371163368, 62.98446647822857, 63.54870580136776, 65.97184717655182, 60.32013304531574, 62.508864998817444, 61.06032952666283, 62.36273244023323, 63.91486555337906, 62.494364976882935, 62.967029213905334, 59.58552226424217, 60.26549197733402, 62.319749146699905, 60.244897082448006, 62.669641971588135, 62.76214800775051, 65.14281526207924, 64.11371648311615, 62.35365092754364, 65.705656260252, 64.12102729082108, 65.3280857205391, 60.40847830474377, 68.70893150568008, 67.22110614180565, 79.44589376449585, 51.434363052248955, 28.783060312271118, 10.359848644584417, 2.816701219417155, 1.4454426756128669, 0.2714179514441639, 2.350791357457638, 3.7521649478003383, 1.2126275058835745, 0.2982705761678517, 0.0408945708477404, 0.04501646646531299, 4.047759398818016, 3.39291631244123, 0.32058538345154375, 0.9434251917991787, 0.649628103710711, 25.737107656896114, 33.48775126039982, 28.48828922957182, 34.32897292077541, 31.052868515253067, 1.2899750866927207, 0.18757537618512288, 0.05572487076278776, 0.08402934414334595, 0.1329992461251095, 0.02254445746075362, 0.04783725475135725, 0.06151609028165694, 0.07412277103867382, 0.019875338184647262, 0.026896194358414505, 0.0876149935356807, 0.04643859210773371, 0.0464284358167788, 0.03630974577390589, 0.10347498624469154, 0.05440554741653614, 0.035737308717216365, 0.11124032229417935, 0.03239441954065114, 0.023137862044677604, 0.0558739645202877, 0.017717015034577344, 0.03526099091686774, 0.102222968271235, 0.02137552477506688, 0.1070624910062179, 0.11109926970675588, 44.34088468551636, 62.413611710071564, 53.99862885475159, 29.11757156252861, 20.713420026004314, 55.26936046779156, 2.34429988078773, 3.1241783453151584, 2.1923343976959586, 0.2219390103709884, 0.2784054499352351, 0.12326807220233604, 0.10557148663792759, 0.8240421290975064, 0.16059061948908493, 2.493019625544548, 0.7204889575950801, 0.25246341072488576, 5.66441684961319, 58.4844933450222, 75.44722393155098, 83.02603885531425, 83.7577959895134, 84.28022995591164, 82.18479439616203, 81.886867582798, 79.37705665826797, 81.11341148614883, 82.11966589093208, 80.81996083259583, 82.75280311703682, 86.15939632058144, 77.09434434771538, 79.66200336813927, 75.14320984482765, 80.51598474383354, 81.07332363724709, 85.99927291274071, 82.35673516988754, 79.52432915568352, 79.05836015939713, 78.89184549450874, 74.89125296473503, 79.26013693213463, 78.90902057290077, 79.96630623936653, 76.59372881054878, 78.42105075716972, 79.92178782820702, 75.45432195067406, 73.61038729548454, 75.6516681611538, 71.35580867528915, 70.12098893523216, 65.11257648468018, 62.692949920892715, 57.97026313841343, 59.88341107964516, 56.23098246753216, 56.59669764339924, 59.5486756414175, 56.32619395852089, 58.76162767410278, 56.673339530825615, 58.155765384435654, 60.06399258971214, 59.75615970790386, 63.263371512293816, 71.03979483246803, 73.62444654107094, 71.91253200173378, 69.73043069243431, 67.76040360331535, 67.31337279081345, 65.82265958189964, 64.77277591824532, 69.60965037345886, 71.10778838396072, 66.21026158332825, 68.77717584371567, 70.49079269170761, 62.15562455356121, 57.849615812301636, 53.181539699435234, 55.37592954933643, 53.34579348564148, 51.92347660660744, 53.971247524023056, 53.28000761568546, 51.11401364207268, 52.61886589229107, 54.274121671915054, 49.93143729865551, 51.18414647877216, 54.62007790803909, 54.66821372509003, 56.550499722361565, 60.37777215242386, 61.503552943468094, 61.897652596235275, 66.97659686207771, 67.36609876155853, 68.71818020939827, 64.49777707457542, 63.95192876458168, 63.97011458873749, 62.81043581664562, 67.1314537525177, 64.99792903661728, 67.12912827730179, 63.58814388513565, 60.34280262887478, 64.14730668067932, 64.5702163875103, 64.83991831541061, 65.05611911416054, 68.10535669326782, 65.77507093548775, 63.255600929260254, 70.52145704627037, 66.66325807571411, 68.63761693239212, 63.99824067950249, 71.49242654442787, 68.80444318056107, 79.49291244149208, 56.61039590835571, 32.0963267236948, 11.499418895691633, 3.114811135455966, 1.60713100573048, 0.3296162816695869, 0.8618011185899377, 4.36330396682024, 3.6722606979310513, 1.735302284359932, 0.8847868570592254, 0.13407834368990734, 4.552629282698035, 2.4220251850783825, 0.41732074110768735, 0.6221828295383602, 0.6044199701864272, 26.280391104519367, 38.00244100391865, 26.078247651457787, 40.89312069118023, 42.76776149868965, 3.0041100131347775, 0.4342745110625401, 0.06087525689508766, 0.10157000448089093, 0.11892083828570321, 0.01903161461086711, 0.10881672773393802, 0.04932775816996582, 0.07882185716880485, 0.027690134666045196, 0.04385187719890382, 0.032726990757510066, 0.0072390990771964425, 0.016758852289058268, 0.1444756842101924, 0.2107150954543613, 0.13955980190075934, 0.1657964737387374, 0.3519843454705551, 0.28941752621904016, 0.1931727578630671, 0.11017678014468402, 0.17155806301161647, 0.1724590896628797, 0.15360758872702718, 0.12958601990249008, 0.14689259201986715, 0.22456989419879392, 53.65925386548042, 71.98215186595917, 62.33673043549061, 47.88078233599663, 28.27236581593752, 67.22682103514671, 3.4719361597672105, 4.918033825233579, 1.988166009541601, 0.3516610956285149, 0.6055342010222375, 0.2421524265082553, 0.28391951811499894, 2.3247677413746715, 3.0121772177517414, 3.94052701536566, 1.7748009273782372, 0.41751138400286436, 6.292978171259165, 68.25817689299583, 84.88591745495796, 90.34041836857796, 91.37767910957336, 90.27610301971436, 89.55862551927567, 85.86570248007774, 83.7544597685337, 87.81042292714119, 85.42260065674782, 84.86615091562271, 88.13104212284088, 90.45558258891106, 81.38181388378143, 83.97229447960854, 79.3176506459713, 83.23844745755196, 85.25822147727013, 87.42788225412369, 85.35133168101311, 82.99731239676476, 82.53397285938263, 82.28515461087227, 76.1402079463005, 83.10816004872322, 81.28136247396469, 81.68692991137505, 80.06910592317581, 84.50564906001091, 83.96519646048546, 77.34513089060783, 77.70163536071777, 79.72190335392952, 76.20649918913841, 75.85270017385483, 70.43159186840057, 67.90598139166832, 61.07495494186878, 61.639118269085884, 60.66804617643356, 60.8340060710907, 63.37597846984863, 60.573944225907326, 62.74711221456528, 63.12139593064785, 60.67276172339916, 62.538484409451485, 63.55035111308098, 65.37137299776077, 72.56482779979706, 76.64273098111153, 75.98371714353561, 74.88484650850296, 72.80912429094315, 71.49585396051407, 69.74689900875092, 70.56010097265244, 72.08535432815552, 74.44461733102798, 68.947763890028, 70.60103997588158, 74.48060140013695, 66.30917027592659, 59.69410143792629, 58.08234952390194, 59.050191789865494, 58.52893956005573, 56.983307898044586, 59.468841925263405, 57.12391555309296, 54.1680845618248, 57.9193040728569, 58.41269239783287, 52.84944511950016, 52.700462713837624, 56.882411912083626, 56.53425559401512, 59.50565814971924, 64.21721532940865, 64.2446194589138, 66.4212566614151, 68.43869760632515, 69.68194529414177, 70.92298150062561, 67.14847683906555, 69.63648453354836, 67.06010118126869, 64.74290952086449, 69.56230491399765, 67.07325607538223, 71.51629686355591, 65.69085225462914, 65.60891345143318, 68.07542189955711, 67.23040044307709, 67.32788801193237, 67.95474037528038, 71.23360723257065, 68.46781924366951, 66.66258931159973, 74.0240179002285, 70.05197703838348, 70.48664331436157, 67.56150707602501, 72.95639678835869, 74.10218730568886, 81.48824617266655, 62.229169607162476, 43.376610428094864, 19.012044221162796, 5.686367796733975, 5.3056685999035835, 1.0382249392569065, 6.216103546321392, 9.221582673490047, 2.815730608999729, 0.7592101860791445, 0.373299004859291, 0.10705918102758005, 6.886729560792446, 4.524866547435522, 0.652512920787558, 2.047066055238247, 0.8660912665072829, 37.851087525486946, 48.01060996949673, 46.494738310575485, 50.34997344017029, 53.052073046565056, 3.5368236154317856, 0.5846823449246585, 0.2549965388607234, 0.23852942482335493, 0.31679309788160026, 0.23358357459073886, 0.16579341609030962, 0.18427590635837987, 0.1943793415557593, 0.1390916996751912, 0.17482147930422798, 0.1698416832368821, 0.08590639146859758, 0.11792827514000237], [0.03377079920028336, 0.05110941725433804, 0.08311901838169433, 0.04529304263996892, 0.04534949781373143, 0.07287460481165908, 0.07011111403699033, 0.013178334847907536, 0.09697539790067822, 0.12014073610771447, 0.07172915924456902, 0.07378452239208855, 0.0916372261417564, 2.1546340081840754, 54.40952740609646, 46.72237269580364, 38.40175777673721, 26.26322742551565, 32.03931078314781, 39.453051164746284, 1.1627985234372318, 4.046394797042012, 3.0034709349274635, 0.13588505767984316, 0.10574685613391921, 0.05326012411387637, 0.2054325328208506, 0.2577866875799373, 0.8942473400384188, 1.5387428691610694, 0.4669099801685661, 0.628649132559076, 20.92653539031744, 66.71925947070122, 60.97224645316601, 76.45629018545151, 79.29757252335548, 78.94242078065872, 81.19790375232697, 76.6741780936718, 75.11599570512772, 75.46103239059448, 75.3587418794632, 72.44156241416931, 76.15318804979324, 79.48484167456627, 70.68403512239456, 73.07814225554466, 73.0755963921547, 76.09025582671165, 76.43882632255554, 77.86442622542381, 78.21235835552216, 78.47984120249748, 74.129918217659, 74.65713992714882, 74.16665464639664, 77.57382541894913, 73.33273619413376, 75.01983806490898, 72.23135769367218, 69.91893097758293, 72.2169640660286, 73.94677564501762, 74.58272472023964, 67.63834655284882, 66.37327283620834, 64.0061366558075, 60.35219952464104, 56.63976073265076, 56.31609030067921, 56.31601430475712, 56.273221001029015, 53.797068670392036, 57.25465513765812, 53.31892512738705, 53.28490175306797, 54.014071226119995, 51.76915928721428, 57.43187762796879, 53.60868237912655, 59.53311167657375, 66.20148405432701, 72.81375244259834, 66.65789276361465, 62.89890646934509, 59.418266639113426, 61.860049813985825, 62.473663687705994, 60.001060366630554, 63.0868785828352, 67.27580040693283, 67.08486825227737, 66.85609772801399, 64.20279130339622, 58.851052075624466, 52.75082141160965, 49.22553397715092, 52.454938888549805, 44.85573425889015, 46.84940367937088, 47.576996237039566, 47.99781605601311, 48.187000304460526, 51.46151639521122, 46.3862769305706, 48.98546665906906, 49.4013087451458, 48.90226252377033, 52.844364792108536, 53.3923713862896, 55.48168167471886, 59.12441700696945, 58.695610016584396, 61.19218625128269, 59.363693967461586, 62.31157958507538, 63.961040675640106, 59.61260341107845, 59.611619263887405, 62.15894937515259, 61.41268461942673, 64.681436419487, 61.567302122712135, 65.7958710193634, 56.91833138465881, 61.415743455290794, 58.069927990436554, 60.66718742251396, 65.60834348201752, 66.19277492165565, 62.75746665894985, 61.66535206139088, 66.39227941632271, 63.53721521794796, 65.14193370938301, 61.61681346595287, 67.8576023876667, 65.15799924731255, 75.7644385099411, 51.644617170095444, 13.66548316553235, 2.779640145599842, 1.1788135953247547, 0.9907407278660685, 0.9122092730831355, 1.0475072474218905, 5.027362033724785, 7.674667630344629, 2.8021204518154263, 0.5748384981416166, 0.18189163820352405, 4.603531826287508, 0.482757831341587, 0.21419980534119532, 0.24051471438724548, 0.7331269606947899, 18.099583983421326, 35.94829402863979, 26.76065683364868, 27.72803172469139, 37.42329128086567, 6.158895716071129, 0.36115666734986007, 0.2695326885441318, 0.08433414419414476, 0.22410848614526913, 0.021245359494059812, 0.12162627826910466, 0.07265577514772303, 0.11898205062607303, 0.061863704831921495, 0.03915811226761434, 0.030122130337986164, 0.06399382080417126, 0.05432407444459386, 0.0476643937145127, 0.06909000047016889, 0.06144863276858814, 0.058199291306664236, 0.022617918948526494, 0.032032455565058626, 0.019712982248165645, 0.049241847154917195, 0.03346723853610456, 0.09706958386232145, 0.03459924380877055, 0.11724749565473758, 0.14561350049916655, 2.850952106527984, 63.27187925577164, 56.961671859025955, 53.20142403244972, 26.42085436731577, 39.19231295585632, 43.734642416238785, 0.9704647783655673, 4.851410100236535, 3.337655640207231, 0.2816953608999029, 0.1294637584942393, 0.19895998091669753, 0.584112434880808, 0.5645548843313009, 0.4470593703445047, 0.6460318935569376, 0.323905247496441, 0.7901407638564706, 25.212255120277405, 74.30900260806084, 69.91441681981087, 78.09410870075226, 82.32271939516068, 83.68903487920761, 86.67743012309074, 81.24386608600616, 80.87083250284195, 77.92579293251038, 77.69155070185661, 78.40189978480339, 81.14191755652428, 82.41507723927498, 75.15264853835106, 77.30552181601524, 77.17588037252426, 79.7326947748661, 82.04750776290894, 81.57407596707344, 80.68264380097389, 80.86868181824684, 77.84845188260078, 77.65496626496315, 76.53148055076599, 78.48955348134041, 76.84296503663063, 77.5987596809864, 74.23592492938042, 74.06111150979996, 75.19408151507378, 75.68509876728058, 74.46405708789825, 71.21277675032616, 69.52143430709839, 68.64381060004234, 63.29793445765972, 59.90812115371227, 58.79051372408867, 58.661522045731544, 59.296205788850784, 55.108925476670265, 58.605045676231384, 56.995433047413826, 55.234938114881516, 56.028605327010155, 54.59162883460522, 62.23674640059471, 58.246876895427704, 59.449728950858116, 66.17860168218613, 73.67585778236389, 67.58606135845184, 64.51933711767197, 62.793389931321144, 65.00367432832718, 66.19312450289726, 64.95285585522652, 65.3761987388134, 67.60627627372742, 70.30746012926102, 68.50295975804329, 68.96977230906487, 62.89824150502682, 55.938926339149475, 52.512976974248886, 54.15524125099182, 48.555990904569626, 50.274509489536285, 52.706568986177444, 52.87698604166508, 51.800644397735596, 55.16357034444809, 50.34760616719723, 53.65119069814682, 52.450033351778984, 52.06275813281536, 56.411658972501755, 55.43015643954277, 58.19295018911362, 58.36971290409565, 63.53383719921112, 63.32490921020508, 63.73174957931042, 67.5096170604229, 67.23267272114754, 64.37155544757843, 62.40301787853241, 64.40529763698578, 66.52405634522438, 68.3470769226551, 65.03735572099686, 68.92590746283531, 60.27753733098507, 63.251854330301285, 62.159838527441025, 62.39962466061115, 68.33639189600945, 67.8098313510418, 65.69111064076424, 63.57277370989323, 69.12225812673569, 66.22469320893288, 68.56415167450905, 63.21992464363575, 69.55015316605568, 65.66170021891594, 78.5532608628273, 59.58851270377636, 18.113867416977882, 2.629384333267808, 0.9540436626411974, 1.327185658738017, 0.6825319037307054, 0.750384209677577, 2.1859590522944927, 5.895501924678683, 3.7385521782562137, 1.4340164512395859, 0.3066583292093128, 5.023138085380197, 0.36507906625047326, 0.14293268497567624, 0.19280457840068266, 0.7299877947662026, 19.922771751880646, 38.27666088938713, 24.303389489650726, 35.14322742819786, 50.000342801213264, 8.258703891187906, 0.4824709764216095, 0.37419516302179545, 0.12281791510758922, 0.2222318173153326, 0.02733203727984801, 0.08638666491606273, 0.09211249751388095, 0.038072071911301464, 0.11217778097488917, 0.025834288644546177, 0.07371967352810316, 0.04492257736274041, 0.02562458554166369, 0.1203443888516631, 0.22139234439237043, 0.18528344604419544, 0.1366791853797622, 0.09716638960526325, 0.11609109598794021, 0.22952577826799825, 0.14187344728270546, 0.21048041351605207, 0.2784353436436504, 0.16048098943429068, 0.25484635785687715, 0.31366948736831546, 2.940072286874056, 75.02987712621689, 67.2216609120369, 53.149340227246284, 44.37785670161247, 49.2391562461853, 54.294317588210106, 1.5463233436457813, 7.260920656844974, 6.391300270333886, 0.6333581486251205, 0.35151892981957644, 0.36599526240024716, 1.010073081124574, 0.7930484984535724, 1.9345572986640036, 1.952936912421137, 2.1655128244310617, 2.813050802797079, 26.452605463564396, 83.55905145406723, 74.52294632792473, 88.0882716178894, 88.07048097252846, 90.82219451665878, 88.76886829733849, 86.20865687727928, 83.94433557987213, 82.42402195930481, 83.90467330813408, 80.66118255257607, 83.3721698820591, 84.5049498975277, 79.55272123217583, 81.05639934539795, 80.48674151301384, 83.61506044864655, 83.5333040356636, 85.24394944310188, 84.3879009783268, 84.0077693760395, 80.43367356061935, 81.09464809298515, 80.17899602651596, 82.80501991510391, 78.61546352505684, 83.20206061005592, 77.56787493824959, 78.9111864566803, 79.31274890899658, 81.07561871409416, 80.69565430283546, 73.6629156768322, 73.33504647016525, 72.07898586988449, 66.2328551709652, 62.48942904174328, 63.640945851802826, 63.57311949133873, 62.61845491826534, 59.366642609238625, 64.3662965297699, 61.04466296732426, 61.22833751142025, 62.47771047055721, 58.41712296009064, 66.36060431599617, 60.525048449635506, 65.05953893065453, 71.3862906396389, 79.35879483819008, 73.76507699489594, 70.34111112356186, 66.05013057589531, 68.49369585514069, 69.56735864281654, 68.24739307165146, 69.22326430678368, 71.09795451164246, 72.57942661643028, 71.71187996864319, 72.90343523025513, 65.73385074734688, 58.97098124027252, 56.86593599617481, 62.071394473314285, 54.688595831394196, 54.59400750696659, 56.094205006957054, 56.87721759080887, 55.19858166575432, 59.48485046625137, 53.295487985014915, 55.83777196705341, 55.434970781207085, 54.51787479221821, 59.67633739113808, 58.299838453531265, 63.413512855768204, 64.7073358297348, 66.65584087371826, 67.54506915807724, 67.23519578576088, 70.86206316947937, 70.01750528812408, 65.55695503950119, 64.86065000295639, 67.86263331770897, 69.69665050506592, 70.31501412391663, 69.11444574594498, 72.2216834127903, 63.19324627518654, 67.74409487843513, 63.97558629512787, 67.0023138821125, 72.12789684534073, 72.86807432770729, 69.23903346061707, 65.97554057836533, 73.01311254501343, 68.06402251124382, 70.65092369914055, 66.64855286478996, 71.14162936806679, 68.18530440330505, 79.54039469361305, 65.3050209581852, 31.402829736471176, 4.811149835586548, 1.5757807879708707, 2.193799219094217, 1.7646168801002204, 4.279117109254003, 7.944986550137401, 17.02914722263813, 6.5585763193666935, 1.057838061824441, 0.24799764098133892, 9.025365952402353, 0.4525369545444846, 0.229013919015415, 0.2845268027158454, 0.8342189330141991, 24.54482663422823, 50.08668556809425, 44.25966024398804, 43.73358987271786, 58.57345037162304, 10.455505661666393, 0.8223247400019318, 0.6161651993170381, 0.3121848060982302, 0.35157806414645165, 0.16805488849058747, 0.2342851713183336, 0.2670041617238894, 0.16127833805512637, 0.25038308172952384, 0.1682196304318495, 0.22483932349132374, 0.1426225563045591, 0.26848076842725277], [0.07204328809166327, 0.025347795999550726, 0.059842320915777236, 0.03390315752767492, 0.05082769799628295, 0.025264400865125936, 0.09923020581481978, 0.027721429178200196, 0.07649042250704952, 0.04673466079111677, 0.020069176025572233, 0.02350113405555021, 0.133709748624824, 7.576592518016696, 60.10958254337311, 33.67893040180206, 40.017966851592064, 23.482827320694923, 48.51776495575905, 15.594103876501322, 0.5359862360637635, 0.7163372647482902, 0.7062543870415539, 0.020564244186971337, 0.04363567102700472, 0.014155077260511462, 0.06871429563034326, 0.6019011803437024, 0.4038912523537874, 2.89486943744123, 0.7276294869370759, 7.123891459777951, 38.67766857147217, 70.86585536599159, 55.63458167016506, 78.74848678708076, 73.53590369224548, 78.90781983733177, 83.918496966362, 74.53945264220238, 74.95067417621613, 76.01548343896866, 77.58007228374481, 75.47557801008224, 79.8055824637413, 75.48583745956421, 70.26516079902649, 73.6403600871563, 75.05674168467522, 74.62262257933617, 79.48886945843697, 73.81772696971893, 77.57553532719612, 75.25949120521545, 72.16236859560013, 74.5659752190113, 71.8413770198822, 75.91856583952904, 72.58566588163376, 73.08422952890396, 73.92529159784317, 72.70982041954994, 74.22594666481018, 72.35302716493607, 66.85726806521416, 66.02186009287834, 64.81930822134018, 61.794218346476555, 57.39035725593567, 55.86372457444668, 56.236853152513504, 54.29170712828636, 56.220088452100754, 51.62539780139923, 53.59899289906025, 56.280501410365105, 52.175456285476685, 51.025884971022606, 50.9376423060894, 54.155055060982704, 53.59746538102627, 53.886797055602074, 58.10339279472828, 58.69961880147457, 55.50611436367035, 54.06754955649376, 58.00200663506985, 64.68630015850067, 64.35267046093941, 61.14415302872658, 61.82536527514458, 61.15579940378666, 64.7009901702404, 68.49751085042953, 67.25477993488312, 58.420877158641815, 49.1093286126852, 48.412305414676666, 48.567694276571274, 44.38070274889469, 49.33660201728344, 47.882135063409805, 47.34689198434353, 50.95429301261902, 48.48297782242298, 47.98002541065216, 48.71331386268139, 46.98123760521412, 50.029962211847305, 49.55350577831268, 52.118713930249214, 51.528347209095955, 56.50796100497246, 57.481020390987396, 59.48199301958084, 61.158102080225945, 62.6956781744957, 63.45142342150211, 63.176804557442665, 59.210573583841324, 61.37660935521126, 60.404412522912025, 62.56444461643696, 60.49569122493267, 60.825429931283, 62.76492565870285, 56.74746595323086, 61.83015301823616, 60.782021060585976, 63.02320919930935, 63.49312238395214, 62.87316285073757, 60.05381293594837, 66.7239636182785, 63.91607388854027, 65.60578241944313, 59.96584005653858, 68.65452602505684, 64.82308521866798, 73.27995702624321, 54.24721151590347, 8.162761889398098, 0.6202205910813063, 0.46511894033756107, 0.824087489163503, 0.40873379562981427, 0.0976616915431805, 4.139679316431284, 7.3395683616399765, 7.07631753757596, 3.2383090211078525, 1.3322466309182346, 0.7992315979208797, 0.12365858288831078, 0.19364096398930997, 0.29340045468416065, 0.3763771365629509, 10.695779118686914, 41.31273977458477, 16.727357916533947, 25.050174817442894, 38.14942091703415, 8.962783310562372, 0.6949312321376055, 0.5042723659425974, 0.09543587191728875, 0.18624944030307233, 0.06515641740406863, 0.17199530673678964, 0.06402346218237653, 0.015021809267636854, 0.10286572753102519, 0.08726701533305459, 0.056763788452371955, 0.05310228043526877, 0.024499773535353597, 0.0424103629484307, 0.018777620134642348, 0.03571631707018241, 0.11053103691665456, 0.025395059674337972, 0.07486054746550508, 0.030248959665186703, 0.057587817282183096, 0.10817918577231467, 0.025557098342687823, 0.020627315607271157, 0.20896561589324847, 0.27524446486495435, 9.419012479484081, 68.34997996687889, 45.640616342425346, 40.44645085930824, 23.313571102917194, 59.68592427670956, 16.7009474337101, 0.7796964899171144, 0.749119590036571, 1.6167083918116987, 0.040533438077545725, 0.1795976745779626, 0.1242675818502903, 0.433616908849217, 0.8997796650510281, 0.5408777017146349, 1.4579314179718494, 0.9014495566952974, 9.533318895846605, 44.33488480746746, 76.88978612422943, 62.390615344047546, 81.97928622364998, 79.16087865829468, 83.70588317513466, 85.31902581453323, 77.36656934022903, 78.08520957827568, 80.42864263057709, 81.7048953473568, 79.93042096495628, 83.75914111733437, 80.68889826536179, 72.59201914072037, 76.53358563780785, 77.59792372584343, 81.20885476469994, 79.91638451814651, 76.78152993321419, 80.35855919122696, 77.75432333350182, 75.55999428033829, 78.10049995779991, 76.50740504264832, 79.49287444353104, 76.5237745642662, 77.01882719993591, 77.46684595942497, 77.101389169693, 77.3122550547123, 73.29925999045372, 69.40868675708771, 70.79998970031738, 66.99692577123642, 63.0492340028286, 60.77579699456692, 57.87577360868454, 58.66708494722843, 58.59391987323761, 58.70488911867142, 56.64677135646343, 56.73508241772652, 57.643176689743996, 55.143765807151794, 55.684533789753914, 55.355513244867325, 57.62109227478504, 56.15619108080864, 55.90546913444996, 58.53127263486385, 59.76464465260506, 56.308395713567734, 57.52406448125839, 60.738080218434334, 66.66442841291428, 66.89665675163269, 64.19013038277626, 62.15490639209747, 64.05469045042992, 64.10094156861305, 71.49820983409882, 68.73953506350517, 59.06953655183315, 53.28118935227394, 52.50221975147724, 51.11701928079128, 48.27135197818279, 52.25098863244057, 50.851740315556526, 51.96842439472675, 55.19892364740372, 51.24211236834526, 50.22917032241821, 52.24395141005516, 49.96940106153488, 51.919684410095215, 52.00854264199734, 53.00535075366497, 56.57252714037895, 58.07501211762428, 59.56014342606068, 61.30296930670738, 64.42835479974747, 64.60677802562714, 66.3446831703186, 65.42371898889542, 61.882867589592934, 62.53970794379711, 63.549876138567924, 66.13044306635857, 66.52644261717796, 64.9194860458374, 65.59653371572495, 59.99536067247391, 63.82719665765762, 61.29081755876541, 66.10965058207512, 66.3111537694931, 66.9185283780098, 62.515940219163895, 68.65293011069298, 66.05111092329025, 69.07632619142532, 64.06669780611992, 69.96841952204704, 66.58947363495827, 74.54422518610954, 62.93574169278145, 17.951534427702427, 0.9036656096577644, 0.35640908929053694, 1.4321836433373392, 1.1980713182128966, 1.2375766108743846, 3.144732629880309, 3.5808114800602198, 5.935399308800697, 2.0582217816263437, 0.6336244905833155, 0.7809346297290176, 0.14998307306086645, 0.2460710404557176, 0.3087756171589717, 0.4866708494955674, 12.17825721949339, 42.77884170413017, 21.376108266413212, 31.00055292248726, 47.049569338560104, 11.811489500105381, 0.7482217694632709, 0.36435137561056763, 0.11526124872034416, 0.15655912488000467, 0.006830691499999375, 0.07799183920724317, 0.04224287135002669, 0.044004117662552744, 0.1040588783507701, 0.06808285412262194, 0.08194856985937804, 0.02480970368196722, 0.042377660211059265, 0.24262750492198393, 0.1230711730022449, 0.12720139551674947, 0.17368673550663516, 0.12008612146019004, 0.0808070576749742, 0.14667805196950212, 0.1147932800813578, 0.2779256069334224, 0.08506931568263099, 0.1071046969445888, 0.26608211745042354, 0.3421985049499199, 10.179141741245985, 80.88713362812996, 50.2580563724041, 53.909660428762436, 37.843556329607964, 67.91823953390121, 22.684813141822815, 0.9191022219602019, 2.0357550121843815, 1.9293545465916395, 0.14067600684938952, 0.34907076274976134, 0.1134523750806693, 0.11534521530847996, 1.0613013384863734, 0.5569543421734124, 6.500483136624098, 2.9686788143590093, 10.813542399555445, 46.65448173880577, 86.93478271365166, 70.20596757531166, 86.38056725263596, 83.19273591041565, 87.39536359906197, 89.2876772582531, 84.2925488948822, 81.89164012670517, 84.83221873641014, 84.67370644211769, 84.18880686163902, 90.76223373413086, 84.28355097770691, 75.70293501019478, 82.01346158981323, 81.83005303144455, 83.5751473903656, 85.1363468170166, 78.63821670413017, 82.58768677711487, 81.23701885342598, 78.72525483369827, 82.0558749139309, 77.1782286465168, 80.05727335810661, 78.87556716799736, 80.0070096552372, 78.09622138738632, 81.40807047486305, 82.14047357439995, 79.35531422495842, 72.99331560730934, 74.82996225357056, 70.87122067809105, 68.88374492526054, 63.47460597753525, 61.712876111269, 62.30220548808575, 61.63258641958237, 63.70311051607132, 59.97519135475159, 60.254122987389565, 63.7245337665081, 60.17100244760513, 58.0985214561224, 59.1001933068037, 62.54847027361393, 59.152527898550034, 60.288245156407356, 64.64768663048744, 65.88361591100693, 61.02331191301346, 62.07639120519161, 64.01774123311043, 71.20227411389351, 69.72695767879486, 68.97200658917427, 67.40098088979721, 69.74535629153252, 68.25088888406754, 77.2472633421421, 73.42840746045113, 66.57508760690689, 55.929715633392334, 56.4930772036314, 55.51232323050499, 52.0119396597147, 57.500460147857666, 54.240987449884415, 54.996299520134926, 60.236484333872795, 54.81742411851883, 53.589444011449814, 55.33924251794815, 53.21548707783222, 55.465901121497154, 55.824962854385376, 57.13111236691475, 58.405639976263046, 61.962807700037956, 64.29885014891624, 65.42995825409889, 67.08182841539383, 67.31156408786774, 69.68468114733696, 67.715854793787, 64.17913377285004, 65.95679998397827, 68.48742619156837, 70.51697328686714, 67.94818952679634, 68.22177484631538, 69.35610517859459, 62.00588978827, 67.88755998015404, 68.59192058444023, 70.2099497616291, 69.1485983133316, 71.13336101174355, 65.21754965186119, 72.22379609942436, 69.64701756834984, 69.7422556579113, 66.85415983200073, 73.13817143440247, 68.274956792593, 77.36969277262688, 68.70056435465813, 33.90376053750515, 1.7553155729547143, 0.25730669614858925, 1.9562987820245326, 1.62598678143695, 0.884767264360562, 7.751037832349539, 10.859495233744383, 18.366795144975185, 5.309779504314065, 1.309312842786312, 3.1494370149448514, 0.2815871557686478, 0.6175453565083444, 0.35351987869944423, 0.5423686467111111, 16.311398036777973, 57.845413237810135, 28.321345187723637, 39.238499477505684, 57.25636504590511, 14.539599660784006, 0.9995355340652168, 0.7655399932991713, 0.3001618949929252, 0.3512386651709676, 0.2348201410495676, 0.2673377125756815, 0.2040646062232554, 0.1368330919649452, 0.21793735009850934, 0.15098696138011292, 0.18668160773813725, 0.1464937618584372, 0.13121126394253224], [0.036220313268131576, 0.04649840178899467, 0.04780225506692659, 0.060606020560953766, 0.0434875457722228, 0.044777205475838855, 0.09825933564570732, 0.029877282831876073, 0.0397428467113059, 0.07434586805175059, 0.046389020353672095, 0.012560008945001755, 0.01303115212067496, 13.77530012279749, 55.58394558727741, 34.69892106950283, 58.019447699189186, 24.13170900195837, 58.20341482758522, 4.952528849244118, 0.36861284694168717, 0.18540365912485868, 0.5031858617439866, 0.5144441232550889, 0.031879242887953296, 0.9703405131585896, 0.43805091467220336, 0.30198380816727877, 0.6113854120485485, 0.3238225425593555, 0.3328464349033311, 14.478921666741371, 45.36899171769619, 63.35470721125603, 56.6023251414299, 74.68620076775551, 77.0746386051178, 76.46244585514069, 81.21476724743843, 73.11181604862213, 78.35384756326675, 76.68479472398758, 77.35906854271889, 76.86900123953819, 78.63953903317451, 71.8809024989605, 70.0228402018547, 73.2913564145565, 75.23454174399376, 75.8999316394329, 76.74047693610191, 76.29827946424484, 75.87816640734673, 72.03376829624176, 72.10278019309044, 72.74809956550598, 77.47847333550453, 74.3164350092411, 70.87698876857758, 73.20283636450768, 75.19954562187195, 72.60595679283142, 70.30917003750801, 66.52987003326416, 65.9607669711113, 65.39298623800278, 63.66036280989647, 55.54600842297077, 57.20902718603611, 56.363363564014435, 54.758044704794884, 57.2689613699913, 53.78613665699959, 53.028901889920235, 53.883301243186, 52.68220469355583, 51.53356432914734, 51.32636144757271, 50.32970912754536, 50.52472986280918, 54.793648794293404, 52.680578380823135, 52.353666722774506, 51.04905232787132, 50.653299763798714, 58.16722556948662, 64.31303098797798, 64.46943059563637, 64.80923116207123, 63.245535269379616, 57.22049497067928, 52.22524121403694, 55.181676372885704, 59.53769043087959, 57.246318385005, 49.483688324689865, 49.906590431928635, 50.04864200949669, 44.0542508661747, 44.074743166565895, 47.644473016262054, 45.36343261599541, 48.95092651247978, 48.160983100533485, 47.64572694897652, 49.32590939104557, 46.89550660550594, 49.06542956829071, 52.010598331689835, 49.71462093293667, 49.235892221331596, 50.9355828166008, 54.106178283691406, 53.631549552083015, 56.10439985990524, 61.35934688150883, 60.61275914311409, 62.52326622605324, 62.59982831776142, 59.92768630385399, 56.969260051846504, 59.203327372670174, 61.43653213977814, 64.41615745425224, 60.36860704421997, 62.37796202301979, 60.842502415180206, 56.74118869006634, 57.17896319925785, 60.51721327006817, 61.024543046951294, 63.913490027189255, 62.63116143643856, 64.77539017796516, 61.73582687973976, 67.54372403025627, 64.81968820095062, 67.13636308908463, 62.21398562192917, 71.00024655461311, 56.58391512930393, 10.13418635353446, 0.2337930235080421, 0.9170223085675389, 0.8292153140064329, 0.25775557674933225, 0.21107503707753494, 0.4869734973181039, 2.990777953527868, 2.954537160694599, 2.9759547114372253, 0.306319048977457, 0.16671927500283346, 0.08468672371236607, 0.06353093587676995, 0.10287925688317046, 0.17475712025770918, 4.343270966783166, 37.327965795993805, 25.03983747214079, 23.900069631636143, 42.68441677093506, 10.397532172501087, 0.23883119691163301, 0.14901379850925878, 0.06548526303959079, 0.05806025736092124, 0.044950341107323766, 0.0650459190364927, 0.03545256520737894, 0.013198166889196727, 0.03530010209942702, 0.04039574741909746, 0.038489470607601106, 0.02103913891914999, 0.04699972254456952, 0.014838329025224084, 0.023810800739738625, 0.0783852516906336, 0.048055780134745874, 0.07288834938663058, 0.047456403117394075, 0.07368429534835741, 0.0820292932621669, 0.010571479906502645, 0.10523301534703933, 0.05626649013720453, 0.16327847057254985, 0.02574286532762926, 17.676714174449444, 65.20596787333488, 50.03123514354229, 61.773406863212585, 25.752244144678116, 68.50460886955261, 5.495085585862398, 0.35960759734734893, 0.1863488435628824, 0.06574135593837127, 1.0662259929813445, 0.07802857551723719, 1.5519139124080539, 2.104239212349057, 1.2345953145995736, 0.239448634092696, 0.39771278388798237, 2.5051305256783962, 18.967787995934486, 48.79559084773064, 73.92589956521988, 60.82164913415909, 79.58517149090767, 80.43762534856796, 83.11568364501, 82.58929789066315, 79.71054196357727, 82.74408638477325, 81.87650173902512, 79.68099474906921, 81.43387109041214, 81.76348820328712, 75.89440673589706, 73.47952231764793, 76.24150291085243, 77.68040969967842, 78.52674588561058, 81.0384339094162, 78.68602573871613, 78.56396868824959, 74.83658149838448, 74.87866804003716, 75.25667935609818, 78.25564563274384, 74.87293794751167, 75.45330360531807, 76.89238518476486, 78.33987951278687, 74.78216081857681, 73.74534085392952, 69.58846271038055, 69.54247757792473, 68.13844531774521, 66.68076753616333, 57.48776122927666, 59.31146577000618, 59.101850017905235, 58.34828585386276, 60.52216060459614, 59.389589577913284, 57.27420888841152, 57.142093777656555, 56.75583690404892, 56.70437626540661, 54.47765775024891, 53.91312584280968, 53.343449011445045, 59.373778626322746, 56.270948722958565, 55.27532994747162, 54.013668447732925, 56.23788669705391, 61.07810117304325, 68.01138773560524, 66.61401271820068, 69.13145363330841, 65.5232584476471, 60.65437451004982, 54.23504076898098, 56.73844523727894, 61.732087880373, 54.31373454630375, 51.965099573135376, 53.40315520763397, 53.31239327788353, 48.37807685136795, 47.851873487234116, 50.01402206718922, 49.3461737036705, 53.03524374961853, 51.969883516430855, 50.25491774082184, 52.57606118917465, 49.69241872429848, 51.54586806893349, 52.64079451560974, 52.158281207084656, 53.76858539879322, 52.372015938162804, 55.329822823405266, 57.93584458529949, 59.112816229462624, 64.48804959654808, 63.854509592056274, 64.3285721540451, 65.1330041885376, 61.44959203898907, 61.63393534719944, 61.46506480872631, 65.90810939669609, 67.09479331970215, 66.78542912006378, 65.0783783197403, 63.525264859199524, 59.35236677527428, 61.295210123062134, 63.52202743291855, 64.02180701494217, 65.95376014709473, 65.99836215376854, 67.41929590702057, 64.42227512598038, 69.9198505282402, 67.07180455327034, 68.19981202483177, 66.97597369551659, 72.02993050217628, 63.21526989340782, 25.09070724248886, 0.5641738954000175, 0.568603448336944, 0.5962955311406404, 1.5446256659924984, 1.5309478249400854, 2.0456335321068764, 1.8541413825005293, 5.112989488989115, 2.2740540001541376, 0.19244983181124553, 0.5711078108288348, 0.116390144394245, 0.12529542669653893, 0.06818244291935116, 0.17434925073757768, 5.008445223793387, 40.282204672694206, 28.813139498233795, 26.863046139478683, 50.43894946575165, 13.613122925162315, 0.26617040333803743, 0.229294910968747, 0.06594050384592265, 0.11106459656730294, 0.06162860729091335, 0.04416851079440676, 0.1091834377439227, 0.021703439015254844, 0.0355352590122493, 0.0405169104487868, 0.014895312051521614, 0.025611933779146057, 0.06932068223250099, 0.11291179471299984, 0.11899955046828836, 0.1612553166341968, 0.12745516549330205, 0.13344138802494854, 0.17014732933603227, 0.2022174748708494, 0.20738887862535194, 0.13040536578046158, 0.2043094258988276, 0.11094349290942773, 0.33237030263990164, 0.1677893628948368, 20.369073003530502, 81.6137458384037, 49.28986832499504, 82.09483802318573, 39.71788935363293, 75.80793857574463, 8.41193636879325, 0.5317785555962473, 0.31841857940889895, 0.9777321259025484, 1.0915969940833747, 0.17184347816510126, 3.473867168650031, 1.8477331451140344, 0.49968785257078707, 3.2225035317242146, 5.653272047638893, 6.764700533822179, 23.54899886995554, 53.84482070803642, 79.0732629597187, 69.43565770983696, 86.31640389561653, 86.23919203877449, 88.0782401561737, 85.81519559025764, 82.49298065900803, 85.26927888393402, 86.04820668697357, 83.83693814277649, 83.74901846051216, 88.0083467066288, 80.16098499298096, 77.94465512037277, 81.54460474848747, 81.17223992943764, 80.7100859284401, 82.29501888155937, 81.69542625546455, 80.61584338545799, 77.52704232931137, 79.76108685135841, 78.85186403989792, 83.30685138702393, 78.77708405256271, 77.9409009218216, 81.26402020454407, 81.54810056090355, 79.9400420486927, 75.91026708483696, 73.42222139239311, 72.71170511841774, 71.4300262928009, 71.27595975995064, 60.84364615380764, 64.52149540185928, 62.616536021232605, 60.91356620192528, 64.9562756717205, 62.52862013876438, 61.70568309724331, 62.276059091091156, 58.838634341955185, 60.12847512960434, 58.9230278134346, 58.615403920412064, 58.409789353609085, 61.31243459880352, 59.46861393749714, 58.63246500492096, 57.28455573320389, 56.86736471951008, 62.75987572968006, 72.39002197980881, 69.3564623594284, 71.76193848252296, 66.98304891586304, 62.87079557776451, 57.596587389707565, 61.32272444665432, 67.41227388381958, 62.89536125957966, 55.24194873869419, 56.45566441118717, 57.26102739572525, 52.297722324728966, 51.74709387123585, 55.533704683184624, 51.30208075046539, 57.67855279147625, 55.14342002570629, 55.162434205412865, 57.05551162362099, 53.05704317986965, 55.6714890897274, 59.465676695108414, 55.87388902902603, 55.95974162220955, 56.50593191385269, 59.617261961102486, 59.86136086285114, 62.027772814035416, 66.58313557505608, 66.01452648639679, 66.47190034389496, 67.64466181397438, 64.37529444694519, 63.50247748196125, 64.80842560529709, 69.48456108570099, 69.13585379719734, 67.1253664791584, 68.93292188644409, 66.28243491053581, 61.99222952127457, 63.87557566165924, 66.4870311319828, 68.26608046889305, 70.87470889091492, 69.09648790955544, 70.62265321612358, 66.26387670636177, 70.31243786215782, 69.78253349661827, 70.85990488529205, 67.18689277768135, 74.41354259848595, 68.43235954642296, 37.298270389437675, 1.7416991223581135, 0.9078282862901688, 1.7664654809050262, 1.8561388878151774, 1.0581086785532534, 3.4868489345535636, 6.3393850810825825, 13.180167507380247, 6.793603207916021, 0.8977474272251129, 0.500754585955292, 0.22459880827227607, 0.41554255527444184, 0.1463065922143869, 0.3383447992382571, 6.744454745203257, 52.55403757095337, 38.9424117654562, 38.92682500183582, 60.48754446208477, 16.00712936371565, 0.47756573650985956, 0.43897390889469534, 0.1761925229220651, 0.24413284758338705, 0.08831434155581519, 0.22472711076261476, 0.20212387520587072, 0.20733421202749014, 0.13109255000017583, 0.1620646138326265, 0.13819191983202472, 0.16497041884576902, 0.15213780978228897], [0.07561669946881011, 0.09540751445456408, 0.10945028436253779, 0.039520599457318895, 0.0690077556646429, 0.09127502838964574, 0.066531171760289, 0.022220728933461942, 0.06637034835875966, 0.0760276266373694, 0.17008126334985718, 0.12718386598862708, 0.20847728272201493, 21.444276608526707, 52.78786562383175, 29.64462038129568, 30.563466176390648, 23.6833805590868, 56.52772754430771, 0.8286487287841737, 0.06014014477841556, 0.4560972744366154, 0.0632824722561054, 1.3024947023950517, 0.18564968107966706, 3.0242631817236543, 5.5875735729932785, 0.8160615479573607, 0.0560487180337077, 0.2421443519415334, 2.242249231785536, 11.983555667102337, 37.42734186351299, 54.58016864955425, 60.07522478699684, 67.34554186463356, 72.49092176556587, 77.23005026578903, 76.36325597763062, 76.47851139307022, 72.56739646196365, 76.55006915330887, 76.24309122562408, 78.7280210852623, 72.94595494866371, 69.68310043215752, 71.12848207354546, 72.45316699147224, 77.97498509287834, 77.84706115722656, 75.68444520235062, 71.48684844374657, 74.86451759934425, 69.36337038874626, 71.7301569879055, 72.68335863947868, 75.0800496339798, 74.19247806072235, 73.99590700864792, 71.47351875901222, 71.93062663078308, 71.80427581071854, 69.97582912445068, 68.19495588541031, 66.00863680243492, 61.16937607526779, 56.566253677010536, 55.462412908673286, 55.368531346321106, 54.09527286887169, 51.64082117378712, 53.0468787252903, 54.21052448451519, 51.125827208161354, 54.911765456199646, 54.425319358706474, 56.9280930608511, 48.81497360765934, 49.50151316821575, 49.99511808156967, 54.76306043565273, 58.44940982758999, 56.044340282678604, 58.65677610039711, 60.85922911763191, 65.62455341219902, 65.87129697203636, 69.07668337225914, 67.21096068620682, 65.17586588859558, 59.72191974520683, 49.92801368236542, 48.513611778616905, 49.052814245224, 49.886147528886795, 52.761236652731895, 54.43546861410141, 47.87462666630745, 43.87122988700867, 45.58222867548466, 46.70434266328812, 49.15771521627903, 49.51371431350708, 47.547984793782234, 46.165485978126526, 46.596709638834, 50.34031815826893, 47.596314400434494, 50.45378006994724, 49.74566526710987, 49.86682936549187, 46.35101482272148, 50.07234513759613, 53.41968432068825, 56.542808935046196, 60.7438825070858, 61.93550996482372, 61.197703555226326, 63.28660726547241, 60.91561809182167, 59.93809014558792, 57.89821520447731, 59.5220010727644, 63.87415453791618, 62.28053905069828, 60.882050693035126, 61.525454968214035, 59.020864963531494, 57.01171517372131, 58.02600994706154, 61.14668749272823, 63.65505829453468, 63.40199187397957, 61.39304727315903, 61.452035307884216, 65.19624799489975, 66.18537291884422, 66.68492451310158, 66.12034320831299, 66.33435532450676, 60.0760493427515, 13.514042291790247, 1.6823267145082355, 1.457205656915903, 0.8790210820734501, 1.100870396476239, 1.5475965128280222, 0.7275645341724157, 1.5270142047666013, 2.441658256575465, 1.247170027345419, 0.19199434609618038, 0.035840864293277264, 0.02809601337503409, 0.10526239697355777, 0.17075430223485455, 0.03094540588790551, 0.9978580428287387, 25.747568495571613, 37.724413722753525, 19.02258675545454, 35.48361696302891, 19.04686365276575, 0.28841167862992734, 0.2963595755863935, 0.020006740996905137, 0.13440012407954782, 0.08197714254492894, 0.016512106740265153, 0.04284887574613094, 0.05968787627352867, 0.025629478150221985, 0.028879973651783075, 0.1271304313559085, 0.03182549284247216, 0.030264721026469488, 0.02974378159706248, 0.13320756697794423, 0.0658926204778254, 0.02339298458537087, 0.017726484838931356, 0.07194961421191692, 0.08572010498028249, 0.011274235312157543, 0.07846720705856569, 0.07340737778577022, 0.09264909997000359, 0.08642659246106632, 0.15708082501078025, 27.21052799373865, 63.10558117926121, 44.595471024513245, 28.322272337973118, 25.933593213558197, 60.69540850818157, 0.8815228915773332, 0.06948019203264266, 0.716117232805118, 0.09304692823207006, 0.6602569052483886, 0.5103731760755181, 2.648476646281779, 6.6982112266123295, 0.9804286155849695, 0.15027993213152513, 0.2782432164531201, 5.385421570390463, 21.478710360825062, 44.06744755804539, 59.47553716599941, 65.54333657026291, 70.13640850782394, 76.83680936694145, 80.88993027806282, 82.529656291008, 80.40924847126007, 79.52201128005981, 80.68126827478409, 79.80761155486107, 82.19338193535805, 77.05626279115677, 75.33244729042053, 75.88819786906242, 74.17132839560509, 80.86014747619629, 80.0518548488617, 79.15750443935394, 74.54136773943901, 78.51071834564209, 73.83773669600487, 75.88306054472923, 77.77791246771812, 76.1195370554924, 77.17629835009575, 77.22850754857063, 75.56155979633331, 75.72849243879318, 75.53401127457619, 72.84535154700279, 71.78826346993446, 67.72041454911232, 64.66653361916542, 58.90634670853615, 59.637670665979385, 59.99064892530441, 56.33835710585117, 53.854753375053406, 56.561560928821564, 57.797589004039764, 54.32887673377991, 56.393864527344704, 57.59710416197777, 58.4427297860384, 54.034453332424164, 54.906970113515854, 53.25052119791508, 58.227121755480766, 62.47897580265999, 60.25982268154621, 62.342969700694084, 63.08552585542202, 68.86900931596756, 72.09967195987701, 72.11856454610825, 70.81439852714539, 67.99258634448051, 63.4791125357151, 55.71036480367184, 51.43330290913582, 50.39863742887974, 53.66010881960392, 56.73777647316456, 57.138081192970276, 51.170273423194885, 47.47290462255478, 49.81037579476833, 50.104179829359055, 53.316136077046394, 54.58114519715309, 50.64850062131882, 51.053118109703064, 51.34806588292122, 53.655104488134384, 50.38137495517731, 51.92414917051792, 51.41670159995556, 53.397231325507164, 51.48261286318302, 53.10732588171959, 54.93062004446983, 57.785224467515945, 64.81694474816322, 65.0487095117569, 65.96484795212746, 66.69744864106178, 64.60747718811035, 64.36221554875374, 62.44994916021824, 62.37841799855232, 66.67232438921928, 65.37306770682335, 65.0235928595066, 64.02713432908058, 61.503108367323875, 61.40274815261364, 60.37644602358341, 63.71440730988979, 64.87328052520752, 67.17982515692711, 63.97138372063637, 64.97171804308891, 65.47114044427872, 70.72611406445503, 67.16876775026321, 70.01629695296288, 68.2186134159565, 64.62402909994125, 29.869249127805233, 2.053811405785382, 1.3786485535092652, 0.8785009849816561, 1.0014608432538807, 1.5681538847275078, 1.8989097489975393, 1.3133985735476017, 1.0821339581161737, 0.8133489091414958, 0.9829707979224622, 0.0633652439864818, 0.02745933972619241, 0.07712164879194461, 0.06351034870021977, 0.08063152490649372, 1.0662080626934767, 29.18407179415226, 39.62604448199272, 22.401517443358898, 47.451515570282936, 26.53122704476118, 0.1965986896539107, 0.15819952357560396, 0.04627274065569509, 0.07995824853423983, 0.04750296917336527, 0.07688252881052904, 0.026714165942394175, 0.03311360145744402, 0.0725254688586574, 0.03496650300803594, 0.10289504236425273, 0.035265885380795226, 0.040850283185136504, 0.20155196136329323, 0.24212374992202967, 0.18805217638146132, 0.10514930851059034, 0.12753228947985917, 0.2102657695650123, 0.11918406322365627, 0.1340162704582326, 0.15886960871284828, 0.2614479692419991, 0.33022338815499097, 0.14890225371345878, 0.606656625168398, 32.06128500401974, 72.29558184742928, 41.889674216508865, 46.30398474633694, 37.95233689248562, 72.69712910056114, 1.6481534857302904, 0.17447310034185648, 0.9012758347671479, 0.1916349388193339, 2.001120583154261, 0.5037459160666913, 7.442418867722154, 12.603946477174759, 1.4917857013642788, 0.5578990664798766, 0.3115439467364922, 7.585721053183079, 32.68363460898399, 62.60506443679333, 69.99662160873413, 73.30108389258385, 72.88576617836952, 81.28400713205338, 85.88125124573708, 85.45701920986176, 84.7092117369175, 83.37967067956924, 83.76357167959213, 85.98476529121399, 88.43028366565704, 82.07770854234695, 78.54971945285797, 79.9250328540802, 77.57349863648415, 86.00589215755463, 84.1253350675106, 82.03072026371956, 75.22035330533981, 83.06487277150154, 75.94306692481041, 78.86815756559372, 80.05810171365738, 78.34543481469154, 80.82749962806702, 82.57479786872864, 77.19810158014297, 80.26497021317482, 78.43261733651161, 76.32762148976326, 74.01308968663216, 71.95270344614983, 67.87812128663063, 63.954033851623535, 62.13270038366318, 62.12288551032543, 61.13627605140209, 57.3153530806303, 60.584868639707565, 62.85897061228752, 57.34286740422249, 62.64106750488281, 60.455477982759476, 63.844219744205475, 57.316006645560265, 59.55689460039139, 56.8767312169075, 62.13604040443897, 65.21768644452095, 62.17683121562004, 65.13372614979744, 67.02559143304825, 73.08730736374855, 75.13953924179077, 74.65074867010117, 77.10993871092796, 69.7910526394844, 66.61052450537682, 56.93661980330944, 53.668886348605156, 54.384509548544884, 56.274094954133034, 59.31603692471981, 62.17569887638092, 54.50591303408146, 51.47605821490288, 53.76039303839207, 56.10591217875481, 56.33296139538288, 59.34006303548813, 54.793777987360954, 54.57613326609135, 54.412593841552734, 58.10479871928692, 52.19783328473568, 55.41458487510681, 54.35269005596638, 57.26289689540863, 52.96061955392361, 57.44473613798618, 57.66475573182106, 61.44060172140598, 68.6803874373436, 71.25677838921547, 67.97470450401306, 69.80504348874092, 66.51813626289368, 68.38021874427795, 65.52584990859032, 66.47294908761978, 71.30134999752045, 67.98763900995255, 66.04623958468437, 66.60623833537102, 63.5729219019413, 63.86998236179352, 63.89002248644829, 67.86177456378937, 68.79694238305092, 68.8114196062088, 66.11348077654839, 66.70334592461586, 68.72565060853958, 72.88439825177193, 71.81081905961037, 70.2595143020153, 70.74954360723495, 69.19323831796646, 40.09885311126709, 4.4410487450659275, 2.0733777433633804, 1.77668598247692, 3.1422102777287364, 3.3650502702221274, 3.2976409373804927, 3.5689038690179586, 8.119250424206257, 1.8386830994859338, 0.42736259289085865, 0.0966549088479951, 0.1470862331916578, 0.34986833401490003, 0.3983008617069572, 0.1620693487348035, 2.341063404455781, 38.432372733950615, 55.29123589396477, 36.52971222996712, 50.43686717748642, 32.07760892808437, 0.5249666492454708, 0.45993788866326213, 0.19126385013805702, 0.2987516362918541, 0.1612949324771762, 0.21088276145746931, 0.20167910610325634, 0.1497507214662619, 0.16004211298422888, 0.18356639833655208, 0.24328325176611543, 0.1409896236145869, 0.1537345553515479], [0.07243849657243118, 0.01837139447161462, 0.10044324619229883, 0.04410225556057412, 0.015229867585730972, 0.0647744711022824, 0.08373403616133146, 0.14401488471776247, 0.1665643442538567, 0.14071257988689467, 0.02155374411813682, 0.07644452067324892, 0.48217177216429263, 54.77037504315376, 39.75126676261425, 42.26819850504398, 31.141669750213623, 35.59704467654228, 44.03942406177521, 0.3190383914625272, 0.18437035207170993, 0.0300005071767373, 0.3852645627921447, 0.05629766405036207, 1.5400900156237185, 0.6336126755923033, 4.901025937870145, 0.8529494935646653, 0.3128264076076448, 0.2355878779781051, 0.6869838992133737, 10.333698447793722, 24.65231716632843, 48.870587423443794, 55.44678434729576, 65.5371581017971, 69.32445287704468, 71.96873858571053, 77.6553462445736, 74.36528518795967, 73.49202364683151, 76.2742267549038, 74.84155923128128, 76.54991716146469, 70.97963646054268, 69.03401166200638, 71.97541862726212, 74.5951272547245, 77.51932874321938, 72.29216203093529, 71.94077968597412, 72.55716741085052, 72.8992934525013, 72.3439608514309, 72.90861055254936, 75.33076778054237, 72.45113030076027, 74.02308315038681, 73.96145045757294, 71.46737828850746, 73.5218596458435, 70.24631381034851, 68.24996933341026, 66.59934550523758, 63.78887951374054, 58.224686086177826, 54.794499948620796, 57.644274830818176, 54.501691460609436, 54.780083522200584, 51.13311901688576, 51.89087055623531, 53.91931191086769, 52.20221444964409, 51.89476154744625, 53.14061589539051, 52.492575868964195, 51.030463725328445, 47.57202610373497, 49.3777310103178, 53.85267108678818, 60.38430780172348, 54.582220539450645, 54.077854603528976, 62.29248560965061, 66.06720685958862, 68.90504658222198, 67.38183751702309, 65.06127923727036, 67.26645290851593, 66.55541226267815, 58.989395052194595, 56.448524594306946, 52.81759522855282, 52.07370534539223, 57.99983315169811, 49.65329222381115, 45.42355298995972, 45.300694182515144, 46.023514196276665, 48.88202860951424, 48.573055788874626, 50.211113691329956, 47.074017226696014, 49.62365761399269, 45.964662954211235, 47.77905039489269, 49.25475440919399, 50.688322484493256, 50.63754580914974, 49.15714144706726, 48.10305520892143, 49.84450936317444, 49.194858223199844, 53.300933092832565, 56.49661481380463, 58.470513895154, 62.171785086393356, 63.23469065129757, 62.239451855421066, 59.792744144797325, 56.86584860086441, 58.453247621655464, 60.35964712500572, 63.10379147529602, 60.03084696829319, 57.797718197107315, 60.187759548425674, 57.902850955724716, 59.545434415340424, 59.529836252331734, 62.22902901470661, 62.23855510354042, 62.4296810477972, 62.03754968941212, 62.92321756482124, 65.8780226111412, 65.22547602653503, 68.23900312185287, 65.42932748794556, 59.939241483807564, 27.685303017497063, 4.470460116863251, 1.3989786501042545, 0.6778191472403705, 1.8044718727469444, 1.6274600336328149, 0.7007363112643361, 1.0184095962904394, 3.05215154774487, 0.6280843878630549, 0.022025230537110474, 0.2255112343118526, 0.14511960122035816, 0.06252086546737701, 0.018863429104385432, 0.06658903701463714, 0.15092877700226381, 13.707653302699327, 42.85222336649895, 19.763484299182892, 27.902942039072514, 28.67245774716139, 0.1269336137920618, 0.02051284860499436, 0.052637844419223256, 0.03628365557233337, 0.05363586977182422, 0.07246397450217046, 0.0735223364608828, 0.03806384891504422, 0.05727477197069675, 0.05083349045889918, 0.024327817918674555, 0.06773735469323583, 0.11328903579851612, 0.07155511077144183, 0.06435620409320109, 0.05518241276149638, 0.014727416910318425, 0.05374700267566368, 0.04431365632626694, 0.08890783705282956, 0.045645046993740834, 0.14066699717659503, 0.14138793427264318, 0.10108520393259823, 0.055862609660835005, 1.8727143108844757, 64.39316108822823, 51.83344043791294, 51.27042844891548, 22.808272317051888, 41.591420620679855, 47.87202000617981, 0.25459384953137487, 0.1341091576614417, 0.17862056294688955, 0.49146536097396165, 0.12066332681570202, 1.6676118853501976, 0.888205545488745, 3.592346948571503, 1.4140828396193683, 0.5597859027329832, 0.16249148233328015, 2.6123671839013696, 23.801960796117783, 43.30747693777084, 49.98883701860905, 63.680323138833046, 68.43315750360489, 75.48613384366035, 76.2143723666668, 83.36335435509682, 79.65178191661835, 77.18156486749649, 80.16305208206177, 77.61686950922012, 80.776886343956, 74.21067908406258, 73.51768746972084, 76.46835073828697, 78.18914160132408, 81.03238463401794, 75.7147827744484, 72.7315704524517, 76.11346498131752, 74.35084596276283, 77.29993611574173, 76.15637227892876, 78.12099605798721, 73.9243796467781, 76.39473348855972, 77.07881078124046, 75.64458534121513, 74.15931344032288, 73.79380345344543, 71.77295789122581, 70.43641000986099, 67.67828240990639, 62.41588018834591, 59.79091264307499, 59.196700528264046, 57.226320058107376, 58.35074432194233, 54.126621186733246, 54.309288784861565, 56.2676353007555, 57.416294664144516, 56.38389766216278, 58.06385971605778, 55.461983531713486, 55.01484252512455, 51.3205249607563, 53.457036316394806, 56.96970462799072, 61.95246085524559, 56.45390510559082, 56.392656192183495, 65.52954331040382, 69.36192646622658, 71.89321383833885, 71.10616967082024, 69.95064407587051, 70.68598821759224, 67.69168049097061, 61.53488986194134, 61.52141958475113, 57.19063997268677, 54.83933374285698, 59.78053919970989, 50.64391806721687, 50.36072686314583, 48.194151520729065, 49.78362523019314, 50.64930617809296, 52.79144123196602, 52.45007514953613, 49.4076582044363, 51.18004269897938, 51.233969405293465, 51.96843199431896, 53.15399117767811, 52.32687436044216, 54.163570404052734, 51.62825144827366, 50.810508728027344, 52.16795928776264, 53.78992885351181, 55.835663080215454, 57.76855856180191, 62.91216395795345, 64.71032246947289, 65.24841159582138, 64.89340424537659, 62.21530795097351, 61.16222105920315, 61.04724682867527, 62.26399473845959, 66.60407245159149, 64.65559020638466, 61.05841062963009, 62.7258675545454, 61.226566806435585, 60.73915936052799, 63.22149395942688, 64.86036121845245, 66.53152674436569, 65.30033200979233, 64.68538820743561, 65.39358660578728, 67.08359152078629, 65.83451494574547, 69.12203773856163, 68.14853757619858, 61.59431867301464, 38.49130377173424, 13.04255599156022, 2.8900125855579972, 2.232883684337139, 2.617625151760876, 1.0726179624907672, 0.2533575502457097, 2.1965880319476128, 1.5340514271520078, 0.6208616285584867, 1.4924461534246802, 0.559803833020851, 0.05998165543132927, 0.06816201159381308, 0.022240093421714846, 0.03120576984656509, 0.10723908504587598, 14.375752452760935, 50.59608243405819, 20.990482158958912, 33.009140342473984, 37.68449306488037, 0.07331210828851908, 0.06442476369556971, 0.06161149336548988, 0.062020865734666586, 0.03263995167799294, 0.06458959469455294, 0.1378167196526192, 0.04606987087754533, 0.030863151805533562, 0.05791724550363142, 0.08091789743048139, 0.0238334028472309, 0.015080971425049938, 0.11166060052346438, 0.2294644174980931, 0.23759656003676355, 0.1429740819730796, 0.20997107756556943, 0.2534301026025787, 0.27728670684155077, 0.273499705363065, 0.28389297891408205, 0.22183838998898864, 0.28403377917129546, 0.14617411885410547, 2.4774278746917844, 79.24286305904388, 52.36212506890297, 59.85799424350262, 53.531664311885834, 53.4637201577425, 60.8142015337944, 0.39520625432487577, 0.22589415282709524, 0.270342193543911, 0.6744147080462426, 0.5703581229317933, 2.7459886763244867, 1.234573822002858, 14.971588030457497, 3.091082121245563, 0.7259820378385484, 0.20739389554364607, 4.833828918635845, 38.86376738548279, 68.30864578485489, 59.03403885662556, 75.4697947204113, 72.46056899428368, 80.8805675804615, 80.49833089113235, 89.04434591531754, 81.79031476378441, 80.82084238529205, 86.39896586537361, 85.90936973690987, 83.55432450771332, 79.57045868039131, 74.98237207531929, 80.24673119187355, 83.0789016187191, 83.99049550294876, 79.51286897063255, 74.33895260095596, 78.06399151682854, 78.69451448321342, 81.18648156523705, 80.86659952998161, 81.77884697914124, 76.8041843175888, 81.83809340000153, 81.30869820713997, 77.50796735286713, 76.47318407893181, 76.16757407784462, 75.79905465245247, 73.95993813872337, 71.98199227452278, 65.08774101734161, 62.06699050962925, 62.84653387963772, 61.70206569135189, 63.30933004617691, 57.73551553487778, 56.51504002511501, 59.07006472349167, 60.52443288266659, 59.91216793656349, 62.12437883019447, 58.533761501312256, 57.58353888988495, 56.51461444795132, 56.42101027071476, 60.635504722595215, 66.55038893222809, 62.08860754966736, 62.32499286532402, 68.54443073272705, 74.01757344603539, 75.29684320092201, 74.25687700510025, 72.49963849782944, 72.90269806981087, 72.02948212623596, 62.96814255416393, 63.023137003183365, 57.88777336478233, 59.31473359465599, 66.18618607521057, 53.89071844518185, 52.880113273859024, 53.764979392290115, 54.58908677101135, 55.06338112056255, 56.45987078547478, 57.899761721491814, 53.61396409571171, 55.53671412169933, 54.78785790503025, 55.548387095332146, 57.64819622039795, 57.23792843520641, 57.01652951538563, 55.391409918665886, 52.81595751643181, 55.66744990646839, 55.70275381207466, 58.96082058548927, 61.27641633152962, 65.56756407022476, 68.06032910943031, 70.77598258852959, 67.0532539486885, 63.89635294675827, 63.70335750281811, 64.87993016839027, 65.08757382631302, 72.62078359723091, 66.55538946390152, 64.1496929526329, 64.60353299975395, 64.77675810456276, 65.51891908049583, 69.38344851136208, 68.23601648211479, 70.69734960794449, 68.98656740784645, 66.91251710057259, 67.32566133141518, 69.66511979699135, 69.97228011488914, 72.32877686619759, 69.64172065258026, 66.00962474942207, 51.78379990160465, 19.93223324418068, 3.359954981133342, 3.433025060221553, 3.335435134358704, 2.137210755608976, 0.9123808576259762, 4.005436794832349, 6.334914145991206, 2.265848102979362, 0.6656755332369357, 0.7015816471539438, 0.3459316265070811, 0.2334299054928124, 0.21440825978061184, 0.15907271968899295, 0.3552874963497743, 22.284327931702137, 64.47646021842957, 33.89902979135513, 41.26043178141117, 45.47287054359913, 0.20130990247707814, 0.18241569836391136, 0.16693032695911825, 0.2047979668714106, 0.19404743827180937, 0.16561653261305764, 0.19631278468295932, 0.15413674002047628, 0.2007313835201785, 0.19558006228180602, 0.1850157236913219, 0.27277682384010404, 0.13212529302109033], [0.03505038424918894, 0.05013437992602121, 0.014437094305321807, 0.07320929114939645, 0.1680361121543683, 0.1504673541057855, 0.12108442882890813, 0.08628824871266261, 0.3335633792448789, 0.26334118796512485, 0.235965735046193, 0.05797011239337735, 23.09164211153984, 73.87747496366501, 27.24563241004944, 35.521345138549805, 17.508212216198444, 42.187696024775505, 27.509378157556057, 0.2501666417811066, 0.11848443318740465, 0.06444781480240636, 0.044804609278799035, 0.0894506587064825, 0.9167406486812979, 1.611606334336102, 3.9283536560833454, 1.503723948262632, 0.05102537645143457, 0.3500989935128018, 1.1366965365596116, 0.8471993927378207, 13.163374308496714, 52.74491272866726, 55.80264665186405, 62.07420252263546, 67.01149418950081, 71.91969841718674, 71.34060189127922, 76.09702706336975, 70.12782096862793, 73.63929614424706, 73.25565353035927, 77.8290045261383, 68.60351756215096, 70.46905025839806, 71.92510932683945, 75.24097859859467, 74.67030242085457, 71.49823263287544, 70.30743733048439, 75.51536187529564, 70.17382130026817, 69.64757233858109, 70.76541155576706, 77.10511296987534, 70.38046181201935, 73.76818522810936, 70.39013609290123, 74.32617768645287, 69.99192506074905, 70.30670017004013, 67.03097954392433, 67.23868399858475, 61.75945021212101, 56.980176866054535, 55.419380217790604, 55.07377356290817, 52.882104367017746, 54.625842198729515, 53.9891217648983, 51.251893043518066, 51.881515458226204, 52.77377977967262, 51.80700525641441, 52.877738401293755, 52.45153807103634, 51.0924232006073, 48.82160805165768, 49.47332248091698, 53.62619183957577, 56.167541071772575, 56.40394538640976, 52.69242614507675, 59.46996286511421, 69.09163177013397, 67.18252301216125, 64.33125481009483, 65.54722756147385, 67.397371083498, 66.1842405796051, 59.367877542972565, 54.991188794374466, 60.10714687407017, 50.34248024225235, 54.26501736044884, 46.25057481229305, 46.43988445401192, 45.1260669529438, 45.22983558475971, 45.159170776605606, 45.8444108068943, 47.18516506254673, 46.49988703429699, 46.71452231705189, 46.62928909063339, 48.10767576098442, 48.71800661087036, 48.11588332056999, 49.7514371573925, 46.33627541363239, 47.62668237090111, 49.60345409810543, 51.3020009547472, 51.904644817113876, 53.34927789866924, 56.28510296344757, 61.09172724187374, 63.9140447974205, 61.2517024576664, 58.56552019715309, 58.785201609134674, 58.97188559174538, 58.343030735850334, 61.67756460607052, 62.370282635092735, 58.64333242177963, 59.2472568154335, 59.108537659049034, 54.06819932162762, 58.07046376168728, 59.79339390993118, 61.454383581876755, 62.87350483238697, 63.73338349163532, 62.683473229408264, 61.382814422249794, 65.04003837704659, 67.4874946475029, 65.03234758973122, 54.94978241622448, 40.01410625874996, 21.411431171000004, 0.8007081155665219, 1.6478314530104399, 0.06801687719416805, 0.35891481733415276, 0.12893797655124217, 0.24296890769619495, 0.7371738029178232, 0.5115335388109088, 1.8910175724886358, 0.6067772686947137, 0.09412929124664515, 0.05698814711649902, 0.047865122396615334, 0.04876912877080031, 0.03616540547227487, 4.824544116854668, 40.63362881541252, 38.85201081633568, 25.599536038935184, 30.57952981442213, 0.10574775413260795, 0.08580701789469458, 0.030450141057372093, 0.0608457899215864, 0.0457355964317685, 0.03201033214281779, 0.01697599913313752, 0.038917938436497934, 0.07444245857186615, 0.01564245809277054, 0.20682302070781589, 0.21439436677610502, 0.09095751534914598, 0.027442758291726932, 0.09529136834316887, 0.13392307155299932, 0.013966333335702075, 0.1898603152949363, 0.14162844949169084, 0.10379981686128303, 0.11244141409406438, 0.1345876499544829, 0.3182958281831816, 0.2970671094954014, 0.07335845541092567, 35.226864740252495, 79.29431989789009, 41.4687480032444, 44.38229486346245, 21.439070887863636, 50.7886902987957, 32.38796107470989, 0.16440721781691536, 0.03731892931682523, 0.14895874599460512, 0.2446770793176256, 0.046853686435497366, 0.6011329684406519, 4.093350302428007, 1.8287490075454116, 1.4981794520281255, 0.13221452885773033, 0.4933343263110146, 2.6623931620270014, 13.872673697769642, 28.83544810116291, 61.343334540724754, 54.39357586205006, 70.83364829421043, 68.26370939612389, 80.53620725870132, 73.76791924238205, 82.75855600833893, 74.06201586127281, 79.37400162220001, 74.72057372331619, 80.44266387820244, 71.89002200961113, 75.77883213758469, 74.00599166750908, 80.19804060459137, 77.95288547873497, 74.93516340851784, 74.20378625392914, 75.71779981255531, 72.33183190226555, 73.57352167367935, 73.1544041633606, 79.50928956270218, 73.99360433220863, 75.63496425747871, 72.49483555555344, 76.37402459979057, 73.67508262395859, 73.1698389351368, 70.79251170158386, 68.41572403907776, 64.1658116877079, 59.25380386412144, 58.384304121136665, 57.78557404875755, 56.750893369317055, 58.478056490421295, 57.63909950852394, 54.140015468001366, 54.25362557172775, 57.37561784684658, 57.649393156170845, 55.879011154174805, 55.47566279768944, 54.769417494535446, 51.98179967701435, 53.37898850440979, 56.45146943628788, 59.94705006480217, 59.43268306553364, 55.54785892367363, 60.78658081591129, 70.74838846921921, 69.94492158293724, 67.77844503521919, 68.33010703325272, 67.44283184409142, 69.52524170279503, 60.77626816928387, 58.77428479492664, 63.719879016280174, 52.54942461848259, 55.843536257743835, 50.44944450259209, 49.97868776321411, 50.28955668210983, 49.14728097617626, 49.336898401379585, 50.42082443833351, 49.90138091146946, 51.73452414572239, 50.07777884602547, 50.49158804118633, 52.82224237918854, 54.994601011276245, 51.35400116443634, 52.28598855435848, 51.131804287433624, 50.70553936064243, 50.86551457643509, 51.73386298120022, 56.78804777562618, 57.58104622364044, 60.628988072276115, 62.3690515011549, 65.36465495824814, 63.20552721619606, 62.303892597556114, 61.21557779610157, 60.82288786768913, 59.99788373708725, 63.963791728019714, 65.58619067072868, 63.00124637782574, 62.59364224970341, 62.152482122182846, 59.18250449001789, 60.001413747668266, 61.77908755838871, 63.70749548077583, 64.27177280187607, 65.55587589740753, 63.86501982808113, 64.15012612938881, 67.53614723682404, 68.05890798568726, 69.05081436038017, 56.91890895366669, 44.95689623057842, 36.64635457098484, 7.031913120299578, 2.8975354693830013, 1.4048248738981783, 0.3540635167155415, 0.11172262180480175, 0.3382221073843539, 0.7022007170598954, 0.917066065594554, 2.3275705659762025, 1.0829703882336617, 0.20758014492457733, 0.12900925241410732, 0.0811073009390384, 0.052441527805058286, 0.05151143865077756, 4.971594801172614, 47.0833533257246, 38.428960517048836, 29.318842962384224, 48.39015260338783, 0.41552682174369693, 0.06720098972436972, 0.04361790772236418, 0.039519222773378715, 0.03517833421938121, 0.09481729925028048, 0.09445904972380958, 0.04985560699424241, 0.06571663499926217, 0.10981114624883048, 0.26944645098410547, 0.27833162108436227, 0.12108632130548358, 0.13809475785819814, 0.23174717469373718, 0.2620625268900767, 0.18917583249276504, 0.2237460360629484, 0.24909878033213317, 0.3224173601483926, 0.22349627368384972, 0.3816607530461624, 0.40476680849678814, 0.27131286333315074, 0.20309061161242425, 39.725990518927574, 92.86071673035622, 41.64226949214935, 51.56412988901138, 32.46492974460125, 60.22870235145092, 43.474823758006096, 0.2696307114092633, 0.17457661509979516, 0.17836633283877745, 0.7390085107181221, 0.17325142136542127, 2.130284202285111, 7.1579124592244625, 10.846062004566193, 3.3895261818543077, 0.1503070502076298, 0.8773213857784867, 3.6251494009047747, 21.864990033209324, 50.64821183681488, 70.23480042815208, 65.52596390247345, 74.47341978549957, 73.73351588845253, 83.67277935147285, 77.66670763492584, 87.97868549823761, 77.34325379133224, 84.75830510258675, 80.61557739973068, 88.91665756702423, 75.34100443124771, 77.73968651890755, 77.66515731811523, 83.71202364563942, 82.6911324262619, 76.39537185430527, 73.86643275618553, 81.3407152891159, 73.3307147026062, 76.46161749958992, 75.87072640657425, 85.1891639828682, 76.78270027041435, 78.80400940775871, 76.73801466822624, 81.82281821966171, 74.88651841878891, 76.41921177506447, 73.73058244585991, 73.4324124455452, 67.94024035334587, 64.84070867300034, 60.06733641028404, 60.69596707820892, 58.70996564626694, 62.192733362317085, 61.62254735827446, 57.70791381597519, 58.78405787050724, 62.052984461188316, 60.805275812745094, 60.41444778442383, 58.701123520731926, 58.85935463011265, 55.427177399396896, 58.56594577431679, 60.72560168802738, 62.50713609158993, 61.530892476439476, 57.95972250401974, 64.75239381194115, 77.35700145363808, 73.29055845737457, 72.09138080477715, 72.06824764609337, 73.4729714691639, 73.93811970949173, 66.32834404706955, 60.52791729569435, 61.66243001818657, 54.96022805571556, 60.420421063899994, 52.45245382189751, 52.89253480732441, 53.01942139863968, 52.65878275036812, 52.22511202096939, 53.18769916892052, 54.11115221679211, 54.266309291124344, 53.745239451527596, 55.95714636147022, 56.41167797148228, 58.30233111977577, 54.850923120975494, 55.458586513996124, 53.27829010784626, 54.83863078057766, 54.79986526072025, 56.18536591529846, 58.514397740364075, 59.65461015701294, 64.87416967749596, 67.27361172437668, 69.27665144205093, 67.89091140031815, 64.53558504581451, 63.192873895168304, 66.74031794071198, 65.62483459711075, 67.13002502918243, 68.55120956897736, 65.04518330097198, 66.40227288007736, 64.96580556035042, 62.15290769934654, 64.67898935079575, 67.60990887880325, 65.68501576781273, 68.95345598459244, 68.10039415955544, 67.96705931425095, 66.59821316599846, 70.41939452290535, 70.00428199768066, 72.11712062358856, 59.49600666761398, 56.13956317305565, 43.67785066366196, 11.33181368932128, 3.7441875133663416, 1.4280980313196778, 0.8697401988320053, 0.3463136841310188, 0.3727804811205715, 1.4022683235816658, 1.4055973012000322, 5.374068254604936, 1.7732654535211623, 0.27302434493321925, 0.2561796410009265, 0.17039339581970125, 0.2179170449380763, 0.2751046442426741, 8.606506828218699, 59.920865669846535, 59.087065011262894, 44.12189103662968, 54.070068821311, 0.5082246288657188, 0.13465634314343333, 0.2131949967588298, 0.24060495954472572, 0.13066799700027332, 0.24302097677718848, 0.24651908985106274, 0.1473982766037807, 0.20240648504113778, 0.2015025046421215, 0.41190021322108805, 0.40328631293959916, 0.35685405135154724], [0.13832736178301275, 0.0466235946805682, 0.08659287806949578, 0.01922240964631783, 0.06695174684864469, 0.27330840937793255, 0.2711192221613601, 1.485742125660181, 6.061954367905855, 14.22789003700018, 21.03947103023529, 13.138459045439959, 52.523335218429565, 52.00489483773708, 34.84853804111481, 29.018317088484764, 22.015228271484375, 47.768205776810646, 13.632710874080658, 0.1602412757347338, 0.07224624321679585, 0.06659970909822732, 0.18600473937112838, 0.016818272342788987, 0.16718961851438507, 0.5457781325094402, 1.1561783286742866, 0.29438605648465455, 0.13962282508146018, 0.010475647304701852, 1.263642618432641, 0.3862767037935555, 9.4222223572433, 36.689345464110374, 59.4530575722456, 61.358727514743805, 70.80824285745621, 73.23852404952049, 74.36491280794144, 74.10716503858566, 72.58485272526741, 74.70719084143639, 70.87834909558296, 69.86705616116524, 66.51856184005737, 67.90139123797417, 71.0045251250267, 75.8846564590931, 72.67242282629013, 73.53563010692596, 70.89359387755394, 72.21323266625404, 69.17082712054253, 73.06812599301338, 70.67895859479904, 74.31124448776245, 71.18394389748573, 74.67714965343475, 70.04257634282112, 73.17144244909286, 70.74876084923744, 70.10616213083267, 64.96196016669273, 64.51089397072792, 56.41983613371849, 54.00160789489746, 53.46735656261444, 55.046574622392654, 55.28377689421177, 57.59054571390152, 56.86571180820465, 52.967117205262184, 52.078865468502045, 51.80858597159386, 53.011365830898285, 54.17654670774937, 51.77655749022961, 50.28719320893288, 47.10123896598816, 50.57011462748051, 52.12787143886089, 57.41735860705376, 57.67545595765114, 56.10446445643902, 52.47064344584942, 58.923229202628136, 61.19755536317825, 60.417909398674965, 60.973059609532356, 61.84664413332939, 57.83464461565018, 54.420645609498024, 50.375584065914154, 53.720069602131844, 55.784316435456276, 51.31270498037338, 49.375751316547394, 46.99093848466873, 45.9786120057106, 44.099791422486305, 44.99394804239273, 46.59607507288456, 44.33156758546829, 45.01730918884277, 46.85366705060005, 48.2354287058115, 47.743533700704575, 45.174100175499916, 50.49174763262272, 48.49655069410801, 48.7181244045496, 46.99200242757797, 46.579048186540604, 50.11386550962925, 52.94490359723568, 55.131906643509865, 55.00733032822609, 58.949527591466904, 60.0653301179409, 58.290981128811836, 60.20835444331169, 61.18071086704731, 61.86664626002312, 57.66704700887203, 55.96771739423275, 61.935521364212036, 59.99647781252861, 57.35426299273968, 60.75021296739578, 56.77559204399586, 56.52415573596954, 57.085017040371895, 57.19502113759518, 57.1016563475132, 64.80820521712303, 62.7719970792532, 60.08483827114105, 64.27332311868668, 66.72608390450478, 65.55573150515556, 48.584778159856796, 41.93665489554405, 38.90203133225441, 14.15060693398118, 0.8192612731363624, 0.1010266930097714, 0.42518771428149194, 0.09692568884929642, 0.4411078803241253, 0.13346342981094494, 0.3306608396815136, 4.847091156989336, 0.5663081933744252, 0.04403886130603496, 0.04374192430987023, 0.03283769321569707, 0.09610735971364193, 0.02745056011917768, 0.8884835243225098, 26.656880602240562, 34.6603075414896, 16.672089882194996, 34.024556055665016, 9.806268699467182, 0.2909229282522574, 0.12323808201472275, 0.05050952073361259, 0.1546615720144473, 0.09547712790663354, 0.04818349261768162, 0.05369227670598775, 0.14987292350269854, 1.4676555711776018, 3.6271813418716192, 4.304564343765378, 1.5139165450818837, 0.2202123889583163, 0.11204907030332834, 0.04151158871536609, 0.039897016758914106, 0.08481210956233554, 0.3901344467885792, 0.2821633592247963, 1.8487130175344646, 6.414505150169134, 18.20002019405365, 25.693030022084713, 21.630838997662067, 62.96598047018051, 59.968895092606544, 45.19359692931175, 27.2603927180171, 22.114999517798424, 54.32613708078861, 16.445483341813087, 0.2915698732249439, 0.21118901611771435, 0.04946355635183863, 0.5072376318275928, 0.01684901952103246, 0.03141784225590527, 0.4528987070079893, 1.3069779868237674, 0.8331384847406298, 0.10783301841001958, 0.2873779262881726, 1.7582018743269145, 8.492296356707811, 17.28062152862549, 48.49488638341427, 61.12100847065449, 71.34206101298332, 69.8569943010807, 79.73194241523743, 76.33927166461945, 79.43477556109428, 77.46957421302795, 79.41492542624474, 75.47668755054474, 72.7377337217331, 72.6121960580349, 72.03433066606522, 75.09201139211655, 77.09597826004028, 76.29860624670982, 73.69490996003151, 75.80784738063812, 71.60190626978874, 73.15827995538712, 75.57120367884636, 74.76970508694649, 74.88960385322571, 75.14830157160759, 78.32324400544167, 75.21544396877289, 74.22909289598465, 73.37772578001022, 72.52489194273949, 67.2671140730381, 66.78419038653374, 60.33206820487976, 58.94989237189293, 56.507102251052856, 59.42148506641388, 57.73277588188648, 60.21151587367058, 59.0525970607996, 55.36328382790089, 55.83456493914127, 54.11642253398895, 55.077565759420395, 57.60582469403744, 55.465422347187996, 52.39990644156933, 50.947593972086906, 54.99706707894802, 55.279597118496895, 59.06441442668438, 61.592848151922226, 60.101811960339546, 58.05838420987129, 63.30307558178902, 64.0245732665062, 63.28868955373764, 63.504643365740776, 64.57043677568436, 59.95044708251953, 58.18443104624748, 53.921416997909546, 58.26788976788521, 58.098646849393845, 55.71503475308418, 53.6077856272459, 52.221103236079216, 50.63319504261017, 48.021876364946365, 48.111384361982346, 49.7191958874464, 48.11872176826, 50.807362496852875, 51.256574392318726, 50.817918330430984, 50.09382538497448, 48.64505812525749, 52.99742817878723, 50.87197802960873, 52.96540729701519, 49.134008288383484, 49.68656703829765, 50.94429574906826, 55.692277774214745, 56.795905753970146, 57.911818474531174, 61.437284499406815, 64.72812831401825, 61.45091816782951, 62.5908038020134, 63.54855380952358, 62.354452684521675, 60.665671303868294, 59.85123820602894, 63.99510204792023, 62.01788194477558, 59.36101891100407, 63.72566230595112, 61.104517355561256, 59.30913649499416, 59.81219530105591, 61.010267212986946, 60.276967361569405, 66.46535709500313, 63.624488934874535, 60.712990164756775, 65.10546326637268, 68.44112947583199, 67.40737974643707, 49.81957130134106, 48.49545635282993, 50.876632779836655, 23.492697291076183, 2.995718875899911, 0.8744211914017797, 0.3689449728699401, 0.08454143346170895, 0.2171445731073618, 0.8193689142353833, 0.5498272308614105, 0.2065210705040954, 0.9431324887555093, 0.07890886656241491, 0.055442183002014644, 0.13863501168088987, 0.04698933618783485, 0.022621546195296105, 0.5582646781112999, 29.01426650583744, 44.82883170247078, 22.722596414387226, 46.8099769949913, 25.95051560550928, 0.29849143931642175, 0.12126198023906909, 0.05255717667751014, 0.1279304813942872, 0.09243469350622036, 0.04051043149956968, 0.004280733774066903, 0.28015878866426647, 2.682352541014552, 5.329205961897969, 5.991334207355976, 2.316605541855097, 0.24513157055480406, 0.18290933046955615, 0.2331677047186531, 0.12539135670522228, 0.2315009746234864, 0.39904927310999483, 0.5007535766344517, 1.9979831390082836, 7.410213220864534, 22.83496778458357, 32.61386275291443, 28.764587603509426, 77.41614148020744, 68.20846796035767, 54.39040683209896, 43.13208594918251, 37.96988055109978, 67.70524576306343, 23.377303183078766, 0.4030718025751412, 0.41471794014796615, 0.14875676308292896, 0.687854349380359, 0.15382917918032035, 0.1664681322290562, 0.5040984065271914, 7.311067515984178, 1.0425092093646526, 0.2184684161329642, 0.20314643596066162, 2.1185133839026093, 16.4049756154418, 30.450114458799362, 56.90406695008278, 68.56389328837395, 77.78117269277573, 73.19247052073479, 86.22631832957268, 78.64925131201744, 87.89359286427498, 80.61164081096649, 86.71380177140236, 78.66958782076836, 79.30717080831528, 74.20802682638168, 73.22753503918648, 76.7300882935524, 81.89687624573708, 78.76165688037872, 77.32277289032936, 77.86181196570396, 78.64028379321098, 76.14986702799797, 79.59380462765694, 76.08147829771042, 77.45321229100227, 78.06406751275063, 83.06210651993752, 77.13456138968468, 80.60589551925659, 75.54707497358322, 76.22897118330002, 70.35637110471725, 72.06969156861305, 62.89238981902599, 61.547159403562546, 60.443155243992805, 61.57008357346058, 63.871737867593765, 63.558015301823616, 61.59794747829437, 58.92465032637119, 58.8983329385519, 59.083816185593605, 59.594117403030396, 63.380336835980415, 60.3753212839365, 57.875367030501366, 54.05247576534748, 57.98755221068859, 59.841750115156174, 63.075179010629654, 64.46357131004333, 61.35810434818268, 57.74176239967346, 67.51137256622314, 68.35468411445618, 67.49751091003418, 68.58894154429436, 67.6329280436039, 64.60776597261429, 60.75455233454704, 56.01472087204456, 56.26692093908787, 61.65154740214348, 58.31525802612305, 55.682424902915955, 54.96081322431564, 53.201606422662735, 52.867345958948135, 51.94469466805458, 53.94775718450546, 49.96528588235378, 53.603826239705086, 54.00865651667118, 53.670128881931305, 53.513113707304, 50.36360710859299, 57.12176486849785, 54.43939760327339, 56.615320444107056, 53.59143890440464, 53.44746842980385, 55.280801653862, 58.69807988405228, 60.37578105926514, 60.566576421260834, 62.965197712183, 65.92447891831398, 66.00700289011002, 65.0088420510292, 66.99023053050041, 66.51198819279671, 65.03692254424095, 62.524953335523605, 68.83411198854446, 63.47055919468403, 61.70474074780941, 67.96488583087921, 62.680703178048134, 64.07739043235779, 63.440859988331795, 63.00637610256672, 63.39595019817352, 69.41494882106781, 66.48315533995628, 62.89701037108898, 69.13471385836601, 70.85197851061821, 68.65092381834984, 57.004214376211166, 53.48828963935375, 58.7412303686142, 31.37884732335806, 8.473633658140898, 2.071724832057953, 0.7006518251728266, 0.17376780771883205, 0.9341019170824438, 1.0091160074807703, 0.8900523651391268, 8.574981819838285, 2.00015377253294, 0.13900515041314065, 0.1173173614370171, 0.21727395913330838, 0.22964796546148136, 0.16331992694176733, 1.472056566271931, 40.26586934924126, 56.463856771588326, 30.575454533100128, 53.6961954832077, 24.240242578089237, 0.5432260350789875, 0.32250273681711406, 0.22045988036552444, 0.23902210697997361, 0.19879748026141897, 0.20597888709744439, 0.12146800043410622, 0.2615645161131397, 2.012531370855868, 4.575115526095033, 5.142238419502974, 1.9738251040689647], [33.43125209212303, 20.257486291229725, 14.046756606549025, 3.292851294390857, 0.1889060766552575, 7.960273129865527, 22.81031660735607, 28.767604641616344, 37.10227310657501, 30.340678431093693, 36.213732585310936, 33.10131199657917, 52.38548621535301, 38.85158143937588, 32.69720368087292, 32.59533874690533, 25.49770150333643, 38.52675586938858, 5.00344374217093, 0.09910774402669631, 0.007632665556229767, 0.05479643659782596, 0.1718155140406452, 0.09744511058670469, 0.09472320234635845, 0.4713349021039903, 0.3098263201536611, 0.17225827934453264, 0.16586420213570818, 0.07494831384974532, 2.2624912206083536, 6.365204220637679, 14.707247614860535, 35.01452833414078, 57.53986023366451, 56.06940373778343, 65.68612530827522, 72.16746032238007, 73.25845018029213, 70.08343935012817, 72.32648178935051, 73.77665877342224, 71.01682126522064, 70.09367600083351, 68.73335659503937, 71.41533628106117, 72.70469829440117, 74.4799554347992, 68.69095847010612, 69.77296561002731, 71.66754394769669, 71.98875591158867, 66.21091514825821, 71.40221938490868, 73.82836639881134, 73.03887516260147, 70.58654755353928, 70.59539347887039, 70.95080360770226, 72.1386730670929, 69.83970522880554, 68.06474447250366, 63.61308954656124, 64.42780762910843, 54.59583520889282, 53.50201450288296, 52.59343005716801, 55.93704164028168, 52.59656108915806, 55.234938114881516, 53.836582750082016, 52.06145480275154, 51.6803352534771, 50.9992939978838, 49.370933175086975, 53.46160367131233, 50.430122539401054, 48.05485859513283, 47.81562723219395, 51.48958548903465, 50.826992243528366, 49.41397346556187, 51.24604895710945, 61.07432037591934, 62.15480379760265, 62.84280627965927, 62.22848184406757, 65.06426587700844, 62.31894738972187, 64.6900087594986, 62.590811401605606, 61.26903712749481, 50.05849488079548, 45.04899948835373, 55.88746950030327, 51.15904122591019, 56.30137749016285, 48.041787296533585, 45.60933642089367, 43.782998621463776, 45.9781788289547, 45.75829602777958, 44.58333067595959, 48.47122125327587, 46.32562458515167, 46.06879636645317, 45.78076422214508, 48.6425806581974, 49.5712698251009, 48.118835762143135, 48.31717371940613, 46.650282964110374, 49.109852984547615, 47.55335010588169, 49.904625937342644, 54.030406549572945, 54.9994495511055, 57.24816508591175, 61.320448368787766, 58.70288662612438, 62.199474200606346, 60.97080633044243, 61.002933606505394, 58.53428967297077, 58.4408450871706, 59.26833428442478, 60.754795521497726, 58.87888178229332, 59.71642903983593, 57.946514412760735, 58.58555652201176, 58.845941349864006, 58.19214083254337, 59.79628175497055, 61.94154404103756, 60.23353949189186, 58.924008160829544, 64.01633530855179, 64.69737276434898, 65.07156908512115, 39.658437743783, 47.889012694358826, 45.73703236877918, 23.74922152608633, 7.978991400450468, 1.7966597294434905, 0.16970817086985335, 0.05647323763696477, 0.11969921761192381, 0.27029143064282835, 2.3826763965189457, 1.8778895144350827, 1.4277524873614311, 0.17760227696271613, 0.08272316423244774, 0.237374123535119, 0.08864916890161112, 0.12442159233614802, 0.03713712911121547, 13.89197951182723, 27.71787866950035, 13.80916865542531, 22.435428723692894, 43.20948779582977, 10.901727117598057, 0.5235252797137946, 0.17079981073038653, 0.14013239851919934, 0.14360104833031073, 0.006779140994694899, 5.009543364867568, 26.80686615407467, 33.2848459482193, 37.9472603648901, 40.16078598797321, 39.722639098763466, 43.59385997056961, 27.274442464113235, 20.5774899199605, 5.18179714679718, 0.2429194509750232, 10.127809345722198, 31.36299267411232, 44.771184995770454, 57.17978775501251, 55.30509755015373, 52.112421467900276, 48.191202878952026, 62.128744795918465, 51.249464973807335, 40.52336633205414, 24.962642714381218, 27.631091326475143, 46.86221659183502, 7.275961199775338, 0.14102313900366426, 0.10928638104815036, 0.10725579821155407, 0.5186614219564945, 0.08142428705468774, 0.10862116439966485, 0.4726585967000574, 0.5214725586120039, 0.30392876942642033, 0.04406104038935155, 0.16352406208170578, 2.6779117668047547, 7.8807552717626095, 17.469982467591763, 49.382104575634, 58.06660316884518, 65.32307758927345, 66.08254283666611, 77.41090536117554, 75.35148426890373, 75.14868915081024, 75.9296764433384, 77.7212955057621, 75.87269470095634, 72.28730589151382, 72.03679293394089, 74.6682657301426, 75.232003480196, 78.31145703792572, 73.95857021212578, 71.02435246109962, 75.33217370510101, 70.90849667787552, 71.85789853334427, 72.12462902069092, 75.12651354074478, 74.90947678685188, 75.2771982550621, 74.95383560657501, 75.62583714723587, 74.14884880185127, 72.03733250498772, 68.90817001461983, 67.93884962797165, 65.69985017180443, 58.684127032756805, 55.738464295864105, 57.59957402944565, 58.865962475538254, 55.79605020582676, 54.857527166604996, 55.25294154882431, 54.44438673555851, 56.865423023700714, 53.99657316505909, 53.506616055965424, 57.22951948642731, 52.58023716509342, 53.146106600761414, 51.25048331916332, 53.097305819392204, 51.220711916685104, 50.19490756094456, 52.39009536802769, 61.44377075135708, 64.6126601099968, 67.38506734371185, 66.79550617933273, 68.99798199534416, 66.36520206928253, 67.2090531885624, 67.70552694797516, 65.17567589879036, 51.898872926831245, 50.26287451386452, 56.96436211466789, 52.377255856990814, 58.35316479206085, 51.46397866308689, 48.856250792741776, 47.90590658783913, 49.14417274296284, 47.2344484180212, 49.530387818813324, 51.356379836797714, 49.78018641471863, 48.338710963726044, 47.21132665872574, 52.87978269159794, 53.07426005601883, 51.01102776825428, 51.00021354854107, 51.2609251588583, 49.932778626680374, 50.72070054709911, 53.217573165893555, 56.839706003665924, 59.35561180114746, 61.31980620324612, 62.102564200758934, 64.3242783844471, 63.15764978528023, 64.93086263537407, 61.83455318212509, 60.48184856772423, 59.790205880999565, 64.22818914055824, 61.00104130804539, 62.33048357069492, 61.384820714592934, 60.53079754114151, 61.47958002984524, 62.97710247337818, 59.63080443441868, 62.97906316816807, 62.0726066082716, 60.53975746035576, 63.62009257078171, 65.47167241573334, 65.70732817053795, 62.715862691402435, 47.21885025501251, 49.59949091076851, 53.289176523685455, 33.655094280838966, 12.323442678898573, 1.2880216352641582, 0.5868607561569661, 0.02514655152481282, 0.0796531887317542, 1.0205139708705246, 5.288812704384327, 3.137589250691235, 0.8690881181973964, 0.20729627343825996, 0.3603380487766117, 0.24665457633091137, 0.13774493912933394, 0.13642741920193657, 0.10991213770466857, 14.853794351220131, 32.81087838113308, 18.857742100954056, 25.98515074700117, 57.09714978933334, 21.889935694634914, 0.44747619016561657, 0.05105150004965253, 0.045154561594245024, 0.21067479683551937, 0.08863975846907124, 8.436856381595135, 36.324781626462936, 45.41593819856644, 51.931045800447464, 54.07674886286259, 53.35054323077202, 48.144184201955795, 29.490759037435055, 21.97669453918934, 6.315427841618657, 0.5231630522757769, 13.559629395604134, 36.18623726069927, 51.61356143653393, 62.16909483075142, 62.538408413529396, 62.297383546829224, 64.2716284096241, 75.14586210250854, 57.57206730544567, 50.47581888735294, 56.43426015973091, 44.06751975417137, 58.780793845653534, 10.232830960303545, 0.22834083560155705, 0.29649945558048785, 0.18408079573418945, 0.9640093997586519, 0.1276892240275629, 0.27850644139107317, 0.947077211458236, 0.9174791746772826, 0.7722052512690425, 0.3548070299439132, 0.22859384858747944, 2.959825526922941, 18.48978314548731, 31.542115062475204, 59.47570815682411, 66.97859555482864, 74.54587429761887, 69.80940565466881, 81.29203230142593, 77.41677224636078, 81.5096466243267, 81.56977459788322, 83.78349021077156, 77.97060772776604, 80.00449419021606, 74.7689451277256, 78.14776942133904, 77.81335696578026, 83.28657567501068, 74.98029738664627, 73.72426718473434, 75.94518721103668, 76.5882571041584, 73.10186818242073, 78.9166809618473, 79.1557489335537, 79.17429953813553, 78.66243660449982, 79.174535125494, 76.41671910881996, 78.3658093214035, 75.92061772942543, 72.22146302461624, 70.64227536320686, 69.81379821896553, 62.17094153165817, 59.494490548968315, 58.40202637016773, 61.8266686052084, 59.64474208652973, 59.513820111751556, 59.257516264915466, 58.11315827071667, 61.44648380577564, 57.601268738508224, 55.33833056688309, 62.41607777774334, 57.16115355491638, 53.873265981674194, 56.1818815022707, 57.93643355369568, 55.1562063395977, 53.279692232608795, 55.19271858036518, 66.45808428525925, 68.80165413022041, 70.9391838312149, 67.65618279576302, 73.43330159783363, 66.6158290207386, 68.49313348531723, 69.16103884577751, 66.2907412648201, 53.93793851137161, 47.66659922897816, 58.48425395786762, 57.97308638691902, 61.7378293722868, 55.13770513236523, 51.653417497873306, 51.2363138794899, 53.98038603365421, 50.77640175819397, 52.28158839046955, 55.615924671292305, 52.62966111302376, 52.171246111392975, 50.58959998190403, 55.14125794172287, 56.85721166431904, 55.34581616520882, 53.3327791839838, 54.47643421590328, 54.19217526912689, 55.49680486321449, 55.47667734324932, 61.085487976670265, 60.540585815906525, 64.18737933039665, 66.48760870099068, 66.02650344371796, 67.34661340713501, 68.6305645108223, 64.66851711273193, 65.27653008699417, 64.33769926428795, 67.24781110882759, 64.97739493846893, 64.31388214230537, 67.18578323721886, 62.02045440673828, 64.70760181546211, 65.74143514037132, 63.16252872347832, 64.04659688472748, 66.19045704603195, 62.71038718521595, 66.56258627772331, 65.07238984107971, 70.13744205236435, 63.690673783421516, 53.28101456165314, 57.01506659388542, 59.86557483673096, 43.817170187830925, 19.417235478758812, 5.034208316355944, 1.1630018125288188, 0.09464028218644671, 0.2848361595533788, 2.464820626191795, 7.699702586978674, 4.633265230804682, 3.349008481018245, 0.2930876542814076, 0.3578588302480057, 0.7968476414680481, 0.19334642041940242, 0.7200022274628282, 0.1527580522815697, 22.64162465929985, 40.63951089978218, 30.32836139202118, 34.49656292796135, 66.93712458014488, 17.375331446528435, 0.7223321555647999, 0.33210301073268056, 0.2177108614705503, 0.2121199810062535, 0.19075797259574756, 8.04059274494648, 37.73505315184593, 50.02607882022858, 56.25703386962414, 59.680923745036125, 54.862767085433006], [27.998926788568497, 34.13239806890488, 38.5596165060997, 31.70374508947134, 19.760085381567478, 33.272040635347366, 23.28967798501253, 20.313430689275265, 13.30598445609212, 17.72123258560896, 29.461149126291275, 45.0587497651577, 56.483528316020966, 42.45074450969696, 38.74242849647999, 25.862898007035255, 30.401743054389954, 36.46271802484989, 2.1577676525339484, 0.035316195571795106, 0.017991077183978632, 0.10673973098164424, 0.11289900008705445, 0.20890107873128727, 0.1310996597749181, 0.2395915865781717, 0.10474287875695154, 0.13200513931224123, 0.06644340537604876, 0.06428711756598204, 4.530760031193495, 10.252766590565443, 18.403271287679672, 50.845162868499756, 57.07785062491894, 49.228661209344864, 59.4359090924263, 75.90020522475243, 72.03653454780579, 70.3930239379406, 72.49220609664917, 71.50685057044029, 70.75568407773972, 65.82645937800407, 71.51042237877846, 69.3934115767479, 72.54159584641457, 74.42707747220993, 69.05634686350822, 71.28262460231781, 68.53914141654968, 71.69368654489517, 70.85316404700279, 66.34136214852333, 66.91907554864883, 71.06696337461472, 70.4275868833065, 70.66530212759972, 71.71822562813759, 70.33889964222908, 72.0446965098381, 66.95689111948013, 61.68853081762791, 57.77360089123249, 53.717200756073, 54.652296379208565, 52.282773926854134, 54.1114068031311, 53.16088020801544, 53.44058699905872, 54.20359745621681, 52.57256157696247, 52.237009182572365, 51.30944475531578, 51.4223100990057, 53.627141788601875, 50.50273284316063, 48.5895811021328, 48.2299418002367, 46.870082169771194, 45.76441369950771, 47.225739285349846, 47.09908828139305, 50.1867114007473, 59.41226676106453, 65.15520259737968, 66.17282599210739, 66.20222121477127, 66.77895426750183, 64.21714693307877, 62.98952020704746, 59.98938739299774, 52.40297667682171, 44.63042914867401, 53.04772228002548, 51.308411210775375, 51.92032277584076, 48.87984372675419, 46.641931012272835, 45.2625822275877, 45.66180020570755, 43.885840103030205, 47.69735857844353, 46.099559515714645, 46.57443903386593, 44.189478009939194, 45.445299223065376, 45.608869045972824, 46.01646937429905, 47.99701429903507, 48.587787598371506, 47.406324595212936, 48.79467889666557, 47.142371758818626, 49.07859206199646, 52.42546007037163, 55.15943616628647, 59.307449385523796, 60.68404331803322, 58.37380908429623, 60.59849090874195, 60.88753379881382, 62.29028172791004, 59.25298310816288, 59.42805491387844, 58.20660285651684, 58.23649205267429, 58.91713812947273, 58.732464239001274, 57.9885895550251, 58.381233885884285, 57.24824868142605, 55.899343863129616, 58.4343284368515, 59.03216935694218, 59.34575133025646, 60.80164320766926, 59.23777252435684, 61.12912863492966, 61.98524169623852, 34.68792825937271, 53.227384239435196, 47.46749751269817, 36.546887308359146, 17.603843584656715, 8.104641158133745, 0.8248622319661081, 0.915205649798736, 0.19950945221353322, 1.1027274280786514, 6.163284480571747, 18.652957789599895, 4.362262347713113, 0.28052757668774575, 0.45089823310263455, 0.29519048519432545, 0.11384571334929205, 0.08202236902434379, 0.1167213055305183, 4.105429379269481, 43.300850093364716, 21.258939653635025, 28.424312062561512, 29.151241555809975, 48.53686273097992, 0.6942568870726973, 0.07616868664626963, 0.13226158102042973, 0.026644407771527767, 4.284490495920181, 37.8487316519022, 31.702667847275734, 25.012893117964268, 27.02939361333847, 23.78251723945141, 17.479556053876877, 43.43893088400364, 48.481685891747475, 54.20335806906223, 48.56629215180874, 27.671893537044525, 61.70030638575554, 42.014649510383606, 38.75532880425453, 26.765566170215607, 32.30576388537884, 38.75122882425785, 57.87813328206539, 65.70320919156075, 49.96979244053364, 41.780202090740204, 25.23030985146761, 36.781562715768814, 44.05289813876152, 2.5315101351588964, 0.013675688824150711, 0.11513171426486224, 0.1013602438615635, 0.1873418371542357, 0.10217470640782267, 0.09845524036791176, 0.20063526055309922, 0.05520656966837123, 0.12029097648337483, 0.08918814623029903, 0.21238244895357639, 4.516535019502044, 15.749994311481714, 26.471674740314484, 60.72708360850811, 61.41224004328251, 56.28439620137215, 60.902398601174355, 78.35960045456886, 75.98285838961601, 76.32206618785858, 76.06578513979912, 77.25539490580559, 74.7023195028305, 70.14943420886993, 78.42488095164299, 74.23744484782219, 73.92804265022278, 75.11558532714844, 70.46104788780212, 73.97999346256256, 72.19965979456902, 73.52504387497902, 73.98100420832634, 69.99032154679298, 70.6930710375309, 73.1821046769619, 73.34860414266586, 72.37327247858047, 76.10397309064865, 71.32719621062279, 72.8800816833973, 70.63681125640869, 68.52855518460274, 60.772749558091164, 55.8014003187418, 56.13757207989693, 54.89492475986481, 56.33361496031284, 56.540947034955025, 55.400225445628166, 54.83156315982342, 54.042299911379814, 56.47112958133221, 53.92923317849636, 55.99832855165005, 55.1834736764431, 53.6757829785347, 52.500327453017235, 53.29205296933651, 47.900005504488945, 48.681710958480835, 49.060630425810814, 48.68203394114971, 49.773358181118965, 61.0796856880188, 66.02789416909218, 70.13615012168884, 65.93768700957298, 69.82827544212341, 68.13010096549988, 65.88319033384323, 61.379633992910385, 52.009956166148186, 48.013797998428345, 56.51418887078762, 52.42272041738033, 54.269850701093674, 51.34770110249519, 49.74287621676922, 47.484820783138275, 49.74709399044514, 47.73066759109497, 51.09648518264294, 48.539036214351654, 49.63028825819492, 45.97876399755478, 47.73927792906761, 48.429507091641426, 47.127457559108734, 51.17819979786873, 52.1512857824564, 50.37173867225647, 49.773966148495674, 49.88253012299538, 52.36227706074715, 54.142432138323784, 57.13593430817127, 60.67933917045593, 62.024812772870064, 62.67197884619236, 61.79490990936756, 63.386948481202126, 63.76108780503273, 61.79158128798008, 61.47804491221905, 60.013512298464775, 61.631332486867905, 61.51706121861935, 61.622570157051086, 60.10137498378754, 60.012440755963326, 59.36949625611305, 60.26691310107708, 60.35376504063606, 60.35026542842388, 61.37499064207077, 62.722842916846275, 58.0858339369297, 63.397067338228226, 62.45422013103962, 41.90706208348274, 60.52923582494259, 58.88560362160206, 45.61808355152607, 22.575215622782707, 7.51800156198442, 0.6862633628770709, 0.5750577582512051, 0.13138762791641057, 1.285005547106266, 13.956216964870691, 29.35319121927023, 6.4866081811487675, 0.7640374707989395, 0.32443600182887167, 0.0999074823630508, 0.04123906466702465, 0.1250834099482745, 0.05082580180896912, 4.007776519283652, 47.02712394297123, 25.609379410743713, 41.2584862858057, 35.86338758468628, 64.9038764834404, 3.1657459773123264, 0.12618720618775114, 0.16518896649358794, 0.04632077987480443, 8.657539039850235, 49.225815162062645, 45.73613941669464, 40.719470009207726, 39.87546689808369, 33.94620805978775, 28.97082343697548, 48.87450501322746, 61.11162677407265, 70.02268821001053, 61.8502501398325, 36.79633252322674, 68.29351499676704, 47.175581976771355, 52.863675355911255, 34.73981827497482, 42.36095152795315, 49.49756138026714, 70.90828388929367, 75.31682252883911, 62.87007361650467, 57.0438576489687, 49.73027229309082, 44.14055183529854, 60.460049137473106, 4.3605495896190405, 0.11162473994772881, 0.26099591224920005, 0.16314559645252302, 0.3227146348217502, 0.729829806368798, 0.30858087760861963, 0.5301195883657783, 0.2753384207608178, 0.19371694506844506, 0.3064827073831111, 0.3148023906396702, 5.847585070878267, 21.892141476273537, 46.89383089542389, 67.01220855116844, 68.78907680511475, 64.92073997855186, 67.20051884651184, 87.49236479401588, 79.46892812848091, 81.44518688321114, 80.6274251639843, 83.9610242843628, 79.0524172782898, 72.50279232859612, 79.35311794281006, 76.33145928382874, 76.56588390469551, 80.78344479203224, 72.9199643433094, 76.1899396777153, 74.15720835328102, 77.14311093091965, 76.8668581545353, 73.295558989048, 73.31480875611305, 77.90719673037529, 75.80463275313377, 77.55035027861595, 76.64123386144638, 75.24617671966553, 77.10794001817703, 72.4695973098278, 68.95090252161026, 66.73612296581268, 59.28376145660877, 61.67484015226364, 56.840959936380386, 59.62814457714558, 60.5376485735178, 59.3654228746891, 57.59382873773575, 57.21264839172363, 60.60898594558239, 57.820862755179405, 57.919091284275055, 59.77319039404392, 56.380033269524574, 57.572473883628845, 55.7441183924675, 50.883286222815514, 52.2729704529047, 52.726540714502335, 51.2762725353241, 51.32833734154701, 65.97679451107979, 72.67915606498718, 73.51957216858864, 70.73241412639618, 72.05979689955711, 70.44957250356674, 68.22182044386864, 65.98586842417717, 53.491268679499626, 45.856307968497276, 55.912909135222435, 53.29827703535557, 58.318370059132576, 55.17314203083515, 51.99629969894886, 52.17722699046135, 53.968709260225296, 49.417051300406456, 56.376818642020226, 52.976035326719284, 53.836727142333984, 49.09934654831886, 49.99484449625015, 52.014869302511215, 51.461520195007324, 55.75258053839207, 53.75235266983509, 55.12043885886669, 54.950705766677856, 53.98968793451786, 55.8785779774189, 57.33294613659382, 61.23807638883591, 64.62651416659355, 69.42164406180382, 64.74663332104683, 64.90506201982498, 68.47766071557999, 68.74904215335846, 64.54296424984932, 64.41052615642548, 62.956336587667465, 64.85116571187973, 62.75789983570576, 64.26525235176086, 61.16478592157364, 64.55325409770012, 62.92822569608688, 64.15132686495781, 63.84893909096718, 63.58677975833416, 63.23709972202778, 66.82057723402977, 59.37073118984699, 68.54766815900803, 61.962249130010605, 50.201929584145546, 64.36641052365303, 59.27878752350807, 55.92667579650879, 34.3423406034708, 13.17215658724308, 3.72790704946965, 0.6651414243970066, 0.6545318593271077, 3.184295631945133, 22.781633846461773, 34.69902366399765, 5.063655311241746, 1.949071807321161, 0.4780546040274203, 0.7486575585789979, 0.13242510583950207, 0.3031541750533506, 0.21660572936525568, 7.7671014703810215, 61.16817153990269, 33.577616438269615, 47.630383372306824, 41.455118134617805, 75.083477050066, 2.392566790804267, 0.277465742547065, 0.24830465263221413, 0.1862617747974582, 8.898257073014975, 58.02437983453274, 52.978463396430016, 50.82202970981598, 52.052703872323036, 45.532101765275, 37.25828893482685], [35.19888684153557, 18.510600328445435, 19.96862769126892, 29.234111309051514, 32.72600993514061, 13.182588927447796, 35.45928306877613, 40.12152649462223, 58.665800616145134, 44.898827746510506, 43.88813517987728, 38.49192313849926, 39.77894827723503, 47.47732758522034, 38.43840681016445, 18.571408465504646, 37.33472183346748, 16.4771793410182, 0.14012993458891287, 0.08828375022858381, 0.06284573319135234, 0.07627981583937071, 0.12790248758392408, 0.03871272718242835, 0.13021828519413248, 0.7336233090609312, 0.048594638719805516, 0.11607964464928955, 0.044230502389837056, 0.18131872988305986, 6.729652639478445, 13.682694341987371, 37.40127146244049, 56.39692336320877, 57.77345269918442, 51.05299651622772, 51.44087590277195, 71.0895873606205, 70.14039069414139, 67.36073344945908, 69.86850768327713, 68.57396274805069, 69.09905657172203, 63.65415394306183, 70.16399502754211, 69.0468093752861, 72.09544658660889, 68.87179836630821, 72.30002000927925, 70.64235135912895, 69.84686404466629, 70.66978588700294, 73.70941758155823, 69.63751047849655, 69.14666041731834, 68.16926166415215, 67.95479357242584, 71.24234676361084, 69.7281888127327, 71.57445654273033, 69.89800170063972, 66.88978672027588, 60.392416566610336, 54.0155341476202, 52.162559777498245, 54.976867362856865, 54.10978429019451, 50.60530833899975, 50.25259606540203, 50.460574105381966, 51.653022319078445, 51.41707018017769, 53.55622999370098, 51.86338663101196, 49.68016818165779, 51.48075096309185, 51.41625702381134, 49.26721014082432, 47.075578942894936, 49.30342599749565, 45.22852845489979, 45.42443834245205, 47.92490936815739, 48.58400300145149, 56.668365597724915, 61.05982415378094, 60.51284350454807, 69.04316157102585, 67.53050833940506, 64.04260709881783, 60.480970814824104, 54.347894713282585, 53.196776881814, 49.129197746515274, 51.299227103590965, 51.945606619119644, 49.55236963927746, 48.19554604589939, 45.14359541237354, 42.89254680275917, 43.398383259773254, 47.22957707941532, 47.07418441772461, 44.92958329617977, 40.26931956410408, 46.5733826905489, 44.89746741950512, 45.41927821934223, 45.19273817539215, 47.392664328217506, 46.30951724946499, 47.096854001283646, 46.9145891815424, 47.979428842663765, 46.118596494197845, 51.93977393209934, 54.22277122735977, 56.73517741262913, 57.1477934718132, 58.58469396829605, 57.937185913324356, 63.52466069161892, 58.62841822206974, 60.377255380153656, 56.663547456264496, 58.49232852458954, 59.17639821767807, 61.228899881243706, 57.96035327017307, 57.561591267585754, 56.97344742715359, 58.24050843715668, 55.979375168681145, 60.000239610672, 61.64457097649574, 59.81137074530125, 60.66618047654629, 58.65062043070793, 63.53499233722687, 59.71265584230423, 40.61482362449169, 80.80502763390541, 56.117049381136894, 44.4064349681139, 30.406981073319912, 17.542034201323986, 5.681910160928965, 2.788236471824348, 1.1747028096579015, 5.173326451331377, 3.9811256993561983, 7.941590007394552, 8.839385882019997, 2.795084654353559, 0.6106974114663899, 0.4116623103618622, 0.22684772353386506, 0.26034038804937154, 0.16601092473138124, 0.44561426038853824, 34.30059604346752, 21.902604214847088, 14.614346399903297, 30.6973272934556, 49.52384456992149, 12.886961940675974, 0.4020571679575369, 0.16005369048798457, 1.03228110820055, 29.55037023872137, 28.506754338741302, 45.08211471140385, 67.25774377584457, 71.36161476373672, 71.47953763604164, 60.49715034663677, 43.58605898916721, 28.063521422445774, 31.53674215078354, 52.104840874671936, 65.21201714873314, 24.224118143320084, 44.16359379887581, 52.35214300453663, 69.46123033761978, 60.72197288274765, 55.07948085665703, 46.97811037302017, 48.499385342001915, 56.76937937736511, 44.444634318351746, 19.735635593533516, 44.91795971989632, 21.283345744013786, 0.17504059098428115, 0.09163436887320131, 0.06700167112285271, 0.09085164798307233, 0.08559398440411314, 0.14351556776091456, 0.3713379835244268, 0.42386072454974055, 0.029761209079879336, 0.03684740950120613, 0.1019898300000932, 0.10509122803341597, 7.983332667499781, 19.287039265036583, 49.42321836948395, 58.47032010555267, 64.80040043592453, 57.82738700509071, 55.33595949411392, 76.67728632688522, 73.00928235054016, 73.41497898101807, 75.2973523736, 74.48779821395874, 73.8132356107235, 70.06741940975189, 73.84340599179268, 72.63576239347458, 72.87138015031815, 73.85893195867538, 73.43175888061523, 74.97996300458908, 72.83984944224358, 74.02220159769058, 76.30375877022743, 72.62019082903862, 71.1742316186428, 70.38474038243294, 71.10070556402206, 72.6937472820282, 71.79486751556396, 74.44663122296333, 73.07910740375519, 68.82990181446075, 62.6844497770071, 57.81719595193863, 55.53438484668732, 55.173958986997604, 58.56450565159321, 54.471068903803825, 54.01037022471428, 52.81576372683048, 53.10455583035946, 51.98013536632061, 55.03296755254269, 55.616300851106644, 52.885174602270126, 54.50994461774826, 54.97537784278393, 51.91004052758217, 49.385186210274696, 52.25214757025242, 47.981469333171844, 45.0512033700943, 48.528351187705994, 52.67601862549782, 57.42517478764057, 64.46538001298904, 62.509765550494194, 69.80007335543633, 68.60375314950943, 66.88021123409271, 63.244779109954834, 57.727410569787025, 51.47188983857632, 50.62691777944565, 55.85514463484287, 53.12750659883022, 47.26941794157028, 51.52172416448593, 50.312127470970154, 46.139708161354065, 46.34867414832115, 50.75949266552925, 48.94763208925724, 48.787219896912575, 46.460334956645966, 45.817599445581436, 48.10767576098442, 48.5466244071722, 48.25784370303154, 49.89905923604965, 50.65639279782772, 51.04905232787132, 49.27583567798138, 52.0911768078804, 51.940583288669586, 53.88637527823448, 56.552000641822815, 59.867083355784416, 60.71978040039539, 63.1691175699234, 60.48320509493351, 65.34933418035507, 60.84844149649143, 63.57696108520031, 61.772069334983826, 60.137792229652405, 62.758439406752586, 63.05915147066116, 61.74768224358559, 61.32112853229046, 59.682888239622116, 61.431068032979965, 60.88450536131859, 60.09462274610996, 63.844827711582184, 63.29250454902649, 63.868409246206284, 59.977684020996094, 62.79475785791874, 62.83126249909401, 43.04931879043579, 84.66112151741982, 67.71134823560715, 56.40779837965965, 38.97221736609936, 23.30486387014389, 6.587817650288343, 2.3441545385867357, 1.243021006230265, 3.7555776396766305, 9.663993883877993, 20.63412208110094, 18.526567071676254, 5.01583487726748, 0.4681717202765867, 0.09340922246337868, 0.1411611190997064, 0.35879889386706054, 0.10613324047881179, 0.7967729517258704, 40.571186766028404, 24.04091477394104, 23.069246113300323, 39.40434917807579, 60.9645214676857, 18.400280848145485, 0.7037013990338892, 0.1374376454623416, 2.036877376958728, 44.64481517672539, 41.90866179764271, 56.328694224357605, 77.64843821525574, 81.16666182875633, 81.23702645301819, 76.29447966814041, 64.9091126024723, 34.028800427913666, 38.734228536486626, 73.38853999972343, 77.16124355792999, 37.29384362697601, 87.47701361775398, 91.69058471918106, 125.00963643193245, 96.35901421308517, 72.28792905807495, 60.461257472634315, 64.50793012976646, 66.83396011590958, 59.49134811758995, 34.94118086993694, 53.90423431992531, 31.134691424667835, 0.29803439509123564, 0.26230280462186784, 0.36848032905254513, 0.49280452192761004, 0.564882616745308, 0.20267051149858162, 0.5252996657509357, 1.2699482613243163, 0.11088580577052198, 0.1838819743716158, 0.21015943464590237, 0.19191959698218852, 8.320691864937544, 28.641183525323868, 63.39612878859043, 66.09856277704239, 70.16872197389603, 63.34204249083996, 62.57403530180454, 81.58395543694496, 81.27763107419014, 78.12114804983139, 78.98950785398483, 78.9616097509861, 77.37196505069733, 73.30812111496925, 78.56110364198685, 72.91437104344368, 74.71074745059013, 74.89692226052284, 79.04349535703659, 79.15477618575096, 74.0603819489479, 77.84499406814575, 79.39666360616684, 75.73096230626106, 74.9033135175705, 75.93931272625923, 72.99505591392517, 77.40870907902718, 77.52863064408302, 78.06263878941536, 77.02873706817627, 72.29944244027138, 67.16754421591759, 60.69807596504688, 58.74599531292915, 60.040525048971176, 60.74764810502529, 56.902588829398155, 55.93072257936001, 55.80529510974884, 58.21268253028393, 56.62896931171417, 60.09164750576019, 62.0741531252861, 56.41241513192654, 57.24298596382141, 57.31721878051758, 55.94211056828499, 52.071524262428284, 52.88530759513378, 51.4879097789526, 47.77327090501785, 48.73029515147209, 54.067553356289864, 61.76549568772316, 67.69205287098885, 64.30722489953041, 73.48871022462845, 72.60832026600838, 68.07255685329437, 64.84550401568413, 59.19495642185211, 53.501995503902435, 47.89848558604717, 57.313734367489815, 55.055922120809555, 53.006821274757385, 56.10052406787872, 52.432094514369965, 50.167438834905624, 51.190948113799095, 53.14645618200302, 53.188546523451805, 50.23768946528435, 48.01905691623688, 51.98867350816727, 52.76270717382431, 49.334686920046806, 49.629372507333755, 52.7632999420166, 54.279293194413185, 54.38260965049267, 53.00808660686016, 54.162422865629196, 55.090618059039116, 57.147573083639145, 60.10153457522392, 61.57333619892597, 63.716124817728996, 63.9957632124424, 61.11099600791931, 68.62855061888695, 65.62395304441452, 66.41393825411797, 63.30523006618023, 63.781355917453766, 68.23315903544426, 65.24712726473808, 62.97691248357296, 62.497864589095116, 62.964346557855606, 62.85691112279892, 63.4594751894474, 64.1778114438057, 65.28067946434021, 65.51121309399605, 66.83272138237953, 61.420914977788925, 65.54767593741417, 63.88567551970482, 51.8196015805006, 76.89680054783821, 71.57873511314392, 64.06097531318665, 47.775828167796135, 38.5151968896389, 16.43754556775093, 8.194995559751987, 10.08288150653243, 18.79338875412941, 15.572196152061224, 22.438111379742622, 28.642156273126602, 8.020048197358847, 1.8518677982501686, 0.8057380956597626, 0.6914250296540558, 0.7750431646127254, 0.4846591246314347, 1.488438080996275, 52.74470753967762, 32.19101384282112, 25.18919985741377, 46.220332235097885, 72.40112498402596, 20.13258509337902, 0.8361932239495218, 0.34071518923155963, 1.6474477923475206, 52.80398055911064, 46.91814959049225, 73.57171297073364, 102.01124131679535, 112.51616522669792, 110.82970172166824, 107.16089218854904], [53.12918230891228, 39.81953389942646, 25.899015069007874, 7.1550925355404615, 26.183864884078503, 43.24068792164326, 37.63248145580292, 28.618103563785553, 35.454981699585915, 40.45629993081093, 45.922774001955986, 31.39574121683836, 19.336366318166256, 44.583706855773926, 24.549479484558105, 23.531647101044655, 32.99325339496136, 5.923519246280193, 0.017294707031396683, 0.09085441619390622, 0.028533798868011218, 0.23382940358715132, 0.07592886162456125, 0.27262008225079626, 0.04205993565847166, 0.2439587694243528, 0.11896658426849172, 0.022798958452767693, 0.06692099224892445, 0.25413665687665343, 5.238625472411513, 32.32729732990265, 52.76131644845009, 59.18150134384632, 58.11899855732918, 56.211531311273575, 45.21637290716171, 66.58282399177551, 68.2925346493721, 69.91106539964676, 70.32527357339859, 68.03614720702171, 66.89365491271019, 65.99831655621529, 71.20755583047867, 64.9231718480587, 69.25901278853416, 69.37059760093689, 71.01571932435036, 69.5861828327179, 67.28631064295769, 72.2564971446991, 72.76932522654533, 69.77169647812843, 70.51055923104286, 66.75924852490425, 68.22365194559097, 71.60544767975807, 69.13560301065445, 71.57121911644936, 67.74202018976212, 65.06132483482361, 57.08473205566406, 51.88352555036545, 52.562978491187096, 53.2677760720253, 49.92506504058838, 51.71233333647251, 53.41709665954113, 51.22109189629555, 51.657430082559586, 49.372475892305374, 47.80195936560631, 48.79138067364693, 51.78299054503441, 52.45599143207073, 50.8632081001997, 49.017730727791786, 47.32783980667591, 46.09020061790943, 43.24713617563248, 44.482552483677864, 46.408737525343895, 47.40424990653992, 50.17968937754631, 59.07320335507393, 65.39985626935959, 64.91548866033554, 66.5186682343483, 64.8656277358532, 62.70850248634815, 55.105452463030815, 47.730576395988464, 53.073519095778465, 50.1220578700304, 51.68510019779205, 45.797042548656464, 46.067162454128265, 44.491573199629784, 40.136254504323006, 45.32901406288147, 48.030289113521576, 47.12707377970219, 44.88991342484951, 44.82105351984501, 43.68154786527157, 43.99641416966915, 46.06236331164837, 45.48485890030861, 47.32454538345337, 45.10752774775028, 47.78803691267967, 45.807024613022804, 47.284624725580215, 48.00582602620125, 52.0293503254652, 54.47831891477108, 58.28652396798134, 54.84125643968582, 57.1420443803072, 56.870955526828766, 62.64247342944145, 58.28917242586613, 58.52022662758827, 60.561629086732864, 57.243897914886475, 59.71481792628765, 60.592627823352814, 57.93740250170231, 61.18046388030052, 57.83507779240608, 55.90535894036293, 53.9545664191246, 58.196841180324554, 59.626058489084244, 59.75063860416412, 58.679692670702934, 64.62348192930222, 59.379607513546944, 64.40822347998619, 39.444133043289185, 83.67068946361542, 60.53859852254391, 59.07123506069183, 42.4573789536953, 27.35421158373356, 12.783354800194502, 11.999517660588026, 15.260521676391363, 4.514820836484432, 1.0713916970416903, 0.9581374085973948, 0.567181552760303, 0.7915891986340284, 1.012256657704711, 0.2883085794746876, 0.04129313012526836, 0.38671178044751287, 0.15221787267364562, 0.1978469078312628, 19.16634064167738, 29.896896444261074, 32.43037819862366, 29.481109455227852, 47.08033628761768, 20.364948324859142, 0.4905180539935827, 0.03555698167474475, 13.74861415475607, 29.259974621236324, 36.070894449949265, 65.35070970654488, 34.33963134884834, 18.53220596909523, 15.100396368652582, 31.574660316109657, 76.83227241039276, 56.5133111178875, 35.38524404168129, 53.333406150341034, 41.98276162147522, 56.16251394152641, 72.27238789200783, 51.15971378982067, 60.305427834391594, 59.64114747941494, 57.2664725035429, 41.500316709280014, 28.350248336791992, 58.459980860352516, 30.326588787138462, 27.32298105955124, 41.480261385440826, 7.957652695477009, 0.030941912227717694, 0.23618745908606797, 0.05948550744506065, 0.488845223444514, 0.18570388754596934, 0.3335823188535869, 0.1544323968118988, 0.41995643405243754, 0.07837021577870473, 0.14895548054482788, 0.059755504480563104, 0.22806928376667202, 7.074766745790839, 33.75468693673611, 59.51722472906113, 63.61414209008217, 66.74181506037712, 62.00878523290157, 51.43931798636913, 71.14420562982559, 72.07349136471748, 72.90151253342628, 75.86644023656845, 73.9807990193367, 69.8010765016079, 71.88884407281876, 73.19271370768547, 69.92748811841011, 69.57039088010788, 72.60709673166275, 73.97258386015892, 72.29668378829956, 70.18280401825905, 73.59681442379951, 71.91184803843498, 72.38372951745987, 75.25041729211807, 69.99189466238022, 69.91224333643913, 73.7668476998806, 72.0233416557312, 75.32319098711014, 70.10835081338882, 67.63915210962296, 59.96779315173626, 54.59816448390484, 56.30008935928345, 58.15533220767975, 54.62416648864746, 54.16180729866028, 53.84021155536175, 51.29343621432781, 54.4436951726675, 52.048269510269165, 50.427850261330605, 52.16690294444561, 54.75383833050728, 54.96967054903507, 54.72224682569504, 54.42325606942177, 49.57762688398361, 50.60987949371338, 45.728623420000076, 46.46649822592735, 48.076559230685234, 48.10443073511124, 49.50590193271637, 61.26292705535889, 66.9765056669712, 70.07261753082275, 68.73850151896477, 68.81537899374962, 65.51504328846931, 57.97591343522072, 48.419703617691994, 54.08312112092972, 51.50809809565544, 53.99196021258831, 47.90758229792118, 50.60582511126995, 48.31069886684418, 45.134396106004715, 47.86150977015495, 50.56446813046932, 47.372039034962654, 48.55595290660858, 47.5039641559124, 47.45425522327423, 45.6269408762455, 48.99027340114117, 48.0270516872406, 50.526671558618546, 48.12960058450699, 51.92905470728874, 50.15259303152561, 51.7746651917696, 50.32669968903065, 53.94594848155975, 54.61770303547382, 61.343893110752106, 59.250767827034, 62.954125106334686, 59.2898715287447, 65.55286645889282, 60.23894280195236, 61.51285484433174, 64.85802814364433, 58.7186785787344, 58.81485141813755, 63.78241986036301, 59.7921209782362, 63.08604642748833, 61.50143265724182, 60.18103390932083, 55.84536775946617, 59.47310909628868, 62.13964641094208, 62.14091174304485, 61.869116127491, 64.81654956936836, 62.759423553943634, 60.66828176379204, 50.682824179530144, 83.44732224941254, 71.65239796042442, 71.04562371969223, 52.539294362068176, 40.827019438147545, 21.592907533049583, 15.33013679087162, 18.428826816380024, 9.861047510057688, 2.4813848873600364, 2.8653450217097998, 4.757385570555925, 2.574791950173676, 0.16725332447094843, 0.22679547633742914, 0.11905700011993758, 0.03981738060247153, 0.11319211873342283, 0.19660750636830926, 24.662046544253826, 31.72192331403494, 33.60704205930233, 36.37403078377247, 54.661180302500725, 27.529710866510868, 0.5231696425471455, 0.22415325249312446, 20.23784514516592, 46.5321359038353, 45.11135794222355, 73.79327908158302, 45.92780873179436, 35.48549026250839, 24.223646968603134, 37.21296116709709, 116.29836827516556, 95.84028124809265, 55.757733061909676, 104.34843510389328, 72.14037537574768, 113.63394364714622, 103.12347963452339, 72.60230138897896, 84.24765050411224, 90.28367981314659, 74.91082191467285, 52.56741285324097, 39.50775682926178, 70.2362671494484, 48.29287402331829, 38.57414312660694, 51.14791162312031, 14.27921673282981, 0.10083749730256386, 0.4992815712466836, 0.14293155691120774, 0.6234605703502893, 0.18193275318481028, 1.151085295714438, 0.17340504593448713, 1.0880900197662413, 0.30665019527077675, 0.2550072851590812, 0.2571956708561629, 0.5220868194010109, 7.125775683671236, 40.70931315422058, 70.79210132360458, 66.83245539665222, 70.87670758366585, 69.07734453678131, 60.817229971289635, 75.04047855734825, 79.52666223049164, 79.781993329525, 78.45827355980873, 76.61987900733948, 74.26404342055321, 74.65825706720352, 77.10844159126282, 72.7235908806324, 71.7273223400116, 75.31317472457886, 77.36029967665672, 76.86777010560036, 73.96314516663551, 75.93724563717842, 77.61162579059601, 77.11135983467102, 76.62931010127068, 72.52341002225876, 72.49954730272293, 77.51453340053558, 75.07172048091888, 78.94185081124306, 74.70234230160713, 71.80730804800987, 63.62374037504196, 57.82492093741894, 58.70282582938671, 62.45028354227543, 57.14694231748581, 57.23429962992668, 57.77179218828678, 53.44553053379059, 58.23213368654251, 54.04927633702755, 53.03199112415314, 57.019983530044556, 58.55711504817009, 58.40867981314659, 58.59362728893757, 57.6975479722023, 53.19392703473568, 52.68510773777962, 47.50833012163639, 47.88741298019886, 49.46869432926178, 50.05027212202549, 53.5238329321146, 65.45721039175987, 68.79284620285034, 74.27036628127098, 74.24109265208244, 71.88454270362854, 69.18091177940369, 60.35479098558426, 51.331658363342285, 53.991158455610275, 54.49435405433178, 56.2424236536026, 50.97407095134258, 53.686832785606384, 52.20695659518242, 48.17235969007015, 51.06971561908722, 54.32576470077038, 51.10471934080124, 51.43718630075455, 49.94374103844166, 50.1638176292181, 48.396825045347214, 51.95014737546444, 51.54872551560402, 53.67706350982189, 49.70927082002163, 54.14023585617542, 52.277313619852066, 55.779574289917946, 53.7685701996088, 58.23599807918072, 58.502306789159775, 64.01327267289162, 60.4451235383749, 63.74488927423954, 61.4226058870554, 69.48544263839722, 64.47950005531311, 63.709110394120216, 68.07144731283188, 62.295635640621185, 64.98806476593018, 66.9091048836708, 61.178271397948265, 64.91174206137657, 65.26151329278946, 60.97950026392937, 59.822568744421005, 60.691388323903084, 64.26961451768875, 60.440145805478096, 65.07045194506645, 67.63246446847916, 67.53867030143738, 60.46859867870808, 57.23334588110447, 74.68677073717117, 74.56548124551773, 74.33773666620255, 61.59194000065327, 50.139673724770546, 31.49968843907118, 41.563465520739555, 38.66093806922436, 13.856788650155067, 3.0093067092821, 5.549716204404831, 17.84506604075432, 6.298406654968858, 5.0627609342336655, 0.6312579894438386, 0.2691511355806142, 0.9123957599513233, 0.3212681889999658, 1.2288526352494955, 32.19882242381573, 44.72279079258442, 53.605874329805374, 45.41274257004261, 69.97716665267944, 30.46214271336794, 0.5491190438624471, 0.21393459144746885, 22.47029945254326, 57.10852637887001, 61.090230122208595, 103.37481334805489, 66.60376846790314, 56.44124038517475, 47.85349600017071, 71.53424710035324], [20.11189140379429, 51.398082599043846, 38.906055316329, 13.992097489535809, 51.529540345072746, 29.17370595037937, 5.334636345505714, 10.290084388107061, 25.709433741867542, 38.319146409630775, 37.52466984093189, 23.127686977386475, 19.36998311430216, 37.529164999723434, 21.603157483041286, 40.873582139611244, 26.162610724568367, 0.8390658104326576, 0.03806790475209709, 0.10247149868519045, 0.11842375519336201, 0.049641341538517736, 0.09100027789827436, 0.13673521752934903, 0.36414600850548595, 0.550589564954862, 0.14063285838346928, 0.0947213543986436, 0.046457142088911496, 0.19256980740465224, 1.1962341167964041, 33.962976559996605, 61.74075521528721, 60.798800960183144, 53.279084265232086, 55.1760146766901, 41.70219607651234, 63.72970528900623, 61.69719435274601, 65.1089970767498, 66.59252107143402, 69.97466638684273, 64.38597947359085, 66.43396317958832, 70.5698436498642, 66.5180678665638, 70.10666370391846, 72.01732277870178, 71.47218123078346, 68.68491679430008, 70.73141857981682, 68.89333561062813, 68.3428743481636, 68.81263554096222, 67.88835793733597, 64.53872367739677, 67.11674094200134, 69.08283904194832, 72.11734861135483, 70.8361941576004, 66.12975150346756, 65.21913796663284, 54.17207434773445, 53.04141841828823, 53.01434867084026, 51.050313860177994, 50.60264468193054, 50.85141733288765, 52.837460562586784, 52.997105196118355, 50.54850898683071, 51.540704146027565, 49.47905637323856, 49.29441288113594, 48.24443802237511, 49.581609070301056, 54.564160108566284, 49.97102737426758, 48.59134420752525, 45.1835160702467, 42.3335549980402, 43.955402970314026, 48.01222488284111, 47.44073174893856, 46.69714204967022, 52.618227526545525, 66.0199373960495, 63.63616570830345, 63.12223568558693, 63.01396809518337, 65.371053814888, 56.12824738025665, 47.66870431602001, 54.875602796673775, 48.09246897697449, 47.90179900825024, 43.30888286232948, 46.229816526174545, 45.11651046574116, 45.48686899244785, 49.33583825826645, 46.720146015286446, 45.27259089052677, 43.9474917948246, 44.19750317931175, 44.464640244841576, 44.0389908850193, 45.372966304421425, 46.11819751560688, 46.984193846583366, 46.62271924316883, 45.940610244870186, 45.08572071790695, 47.55086503922939, 45.88589698076248, 49.512775763869286, 54.09872308373451, 58.081916347146034, 58.18793065845966, 57.34582744538784, 58.90560194849968, 61.77055321633816, 57.413361221551895, 61.34447827935219, 61.90291911363602, 59.03443403542042, 55.52591510117054, 60.10962054133415, 57.44134671986103, 53.65158587694168, 56.6137321293354, 55.56411825120449, 53.82466658949852, 58.40605415403843, 61.40500143170357, 60.213313177227974, 54.68879722058773, 63.93872827291489, 60.172153785824776, 66.27096712589264, 36.351414397358894, 66.66689828038216, 57.17766746878624, 68.37301433086395, 47.64206774532795, 36.55057691037655, 20.558886118233204, 18.798142299056053, 10.564455315470695, 0.7847545528784394, 0.8067020564340055, 0.39418520755134523, 1.5255901124328375, 0.5552616517525166, 0.7371017849072814, 0.18181435094447806, 0.035450895375106484, 0.13697969581699, 0.2867115964181721, 0.1624131263815798, 10.68910002708435, 36.39996059238911, 27.689370699226856, 28.432075046002865, 48.96623209118843, 24.8796608671546, 0.7581424433737993, 1.0571695351973176, 20.474986620247364, 23.536647632718086, 44.99394044280052, 30.622230023145676, 21.39257848262787, 13.302117213606834, 11.099338363856077, 4.112517423927784, 22.608638629317284, 72.39230185747147, 50.12089133262634, 30.515254363417625, 74.7616571187973, 57.639042511582375, 22.468581944704056, 22.871746011078358, 47.857728973031044, 63.21471132338047, 54.066276624798775, 29.981901682913303, 34.809065759181976, 50.979603454470634, 28.36541522294283, 45.91873101890087, 33.936993554234505, 1.1573494970798492, 0.028871214453829452, 0.22513021569466218, 0.22628033679211512, 1.02099773241207, 0.5259291850961745, 0.27825927652884275, 0.3542591765290126, 0.6078177003655583, 0.06474987632827833, 0.0933143611473497, 0.13652786146849394, 0.10557665198575705, 2.095165536738932, 42.20324099063873, 70.59003576636314, 69.62355762720108, 62.18104138970375, 62.185984924435616, 47.60452575981617, 68.98106530308723, 67.1016101539135, 70.71388632059097, 74.93198677897453, 75.24252131581306, 68.38293179869652, 71.41356557607651, 73.37578788399696, 68.87102320790291, 71.07202470302582, 74.11006808280945, 73.34102734923363, 71.825250685215, 72.59570494294167, 71.15838646888733, 69.59084898233414, 71.99754863977432, 69.81416299939156, 68.37384268641472, 68.18899780511856, 70.939951390028, 71.34493365883827, 73.45816746354103, 67.9123042523861, 68.11917275190353, 55.49810439348221, 54.76652964949608, 54.04615290462971, 56.69771522283554, 53.716949969530106, 54.82886530458927, 52.68659345805645, 55.2314916998148, 51.069480031728745, 53.59085753560066, 50.27258679270744, 51.93616032600403, 48.81144739687443, 54.14713628590107, 57.25667662918568, 55.26169627904892, 51.50234140455723, 47.99027346074581, 45.942016169428825, 44.36042323708534, 50.14737211167812, 48.87713447213173, 47.47673101723194, 56.77379094064236, 68.70941787958145, 67.47760757803917, 66.47534295916557, 68.7904903292656, 67.98045739531517, 59.80413593351841, 46.33877947926521, 54.11681391298771, 48.38500387966633, 48.854107707738876, 45.0542052090168, 48.40656392276287, 45.40060982108116, 50.458301827311516, 51.632355228066444, 49.70754191279411, 48.4244229644537, 49.09438021481037, 47.9509037733078, 47.75153607130051, 46.031497567892075, 48.245912343263626, 48.70588906109333, 52.33081474900246, 48.854141905903816, 50.580556467175484, 47.93285094201565, 50.59609763324261, 47.93999835848808, 52.30575889348984, 55.48513188958168, 61.08935996890068, 61.60723797976971, 63.05898807942867, 62.135717421770096, 63.470882177352905, 59.59838077425957, 62.20070153474808, 63.912015706300735, 59.98166620731354, 56.417472660541534, 63.302714601159096, 59.47176396846771, 58.57159607112408, 60.42621575295925, 59.46288384497166, 54.075350537896156, 60.28355620801449, 61.60939246416092, 60.08876346051693, 61.364643797278404, 66.57194897532463, 61.791509091854095, 61.51810236275196, 46.164764016866684, 71.24122202396393, 66.17851048707962, 73.37934449315071, 59.34196673333645, 50.54522596299648, 28.723048232495785, 35.883131325244904, 25.358051396906376, 2.5281696394085884, 1.0830316599458456, 0.8746876521036029, 1.7226170212961733, 0.2697636152151972, 0.526714080478996, 0.11283290441497229, 0.03132338169962168, 0.13600751204648986, 0.09554608084727079, 0.14502435398753732, 12.743969913572073, 39.503687247633934, 28.148308172822, 35.423192605376244, 58.39407339692116, 29.907505474984646, 0.6127166468650103, 1.9354580878280103, 33.871067091822624, 39.23417150974274, 60.64789205789566, 41.362213119864464, 24.35179129242897, 16.66569672524929, 15.446949172765017, 7.82667419873178, 47.09487050771713, 107.03147873282433, 96.71926528215408, 100.39546921849251, 118.29500153660774, 76.2363351881504, 30.340644232928753, 40.536517426371574, 72.1529982984066, 85.69635316729546, 77.79834017157555, 40.99200278520584, 45.673381984233856, 65.7233253121376, 47.188204899430275, 56.405906081199646, 45.38995899260044, 2.7163438545539975, 0.21776483044959605, 0.313632765901275, 0.34183218085672706, 0.515381129225716, 0.31097074155695736, 0.9647662716452032, 2.117237839847803, 3.829325269907713, 0.2806416596285999, 0.6168182892724872, 0.22536332427989691, 0.33171739079989493, 4.190458841621876, 39.46304462850094, 70.90336695313454, 74.10893574357033, 68.77456918358803, 66.55362635850906, 56.490379348397255, 70.02931505441666, 71.8075892329216, 74.01574194431305, 79.21559572219849, 75.218286216259, 72.37694308161736, 74.07133296132088, 76.60165518522263, 70.71481347084045, 73.38819801807404, 79.41843643784523, 78.63899186253548, 76.09112977981567, 77.55574598908424, 73.71722236275673, 75.28237357735634, 74.86959412693977, 73.91342103481293, 71.32108613848686, 70.31836554408073, 74.35106635093689, 79.71565648913383, 74.01867538690567, 70.47236368060112, 72.65606850385666, 58.10494311153889, 58.72348912060261, 59.487039148807526, 60.86307071149349, 56.06580153107643, 56.70364670455456, 56.103826090693474, 60.96774369478226, 55.0902608782053, 59.30722139775753, 54.76365700364113, 53.70877280831337, 52.30657584965229, 57.61782065033913, 62.0010070502758, 57.00323402881622, 54.96267892420292, 50.10239392518997, 48.110225424170494, 48.303665444254875, 51.041027158498764, 51.14519476890564, 50.65808370709419, 57.82138332724571, 73.70599016547203, 74.38774958252907, 71.64527714252472, 75.38474768400192, 72.95811429619789, 61.4816053211689, 48.38623881340027, 62.05977849662304, 50.786216631531715, 51.39269068837166, 47.14114062488079, 52.48433791100979, 51.9246431440115, 53.34230527281761, 55.86275942623615, 52.2043689340353, 52.99550548195839, 53.36027450859547, 51.061736047267914, 51.11525997519493, 47.29316666722298, 51.61924213171005, 52.02267028391361, 55.39304383099079, 52.38354831933975, 53.88509474694729, 52.402741089463234, 53.976058065891266, 49.59361642599106, 52.69420064985752, 59.03103321790695, 63.83779048919678, 63.2709027081728, 62.87955790758133, 64.77956235408783, 68.01999807357788, 65.33326864242554, 66.83099627494812, 71.98920428752899, 61.80209532380104, 59.54806387424469, 65.34707710146904, 61.08040764927864, 59.14653941988945, 60.643358901143074, 58.28800588846207, 57.408455684781075, 64.3161316215992, 64.40301775932312, 59.56534534692764, 62.734933868050575, 65.85103645920753, 64.90081384778023, 67.20152959227562, 50.10907396674156, 69.65245127677917, 68.14153835177422, 73.42968419194221, 63.46458971500397, 56.43730379641056, 43.20688873529434, 51.44485428929329, 23.55097856372595, 3.5103250248357654, 2.1169870533049107, 1.8038007337599993, 5.110758533701301, 3.676798604428768, 3.2572892401367426, 0.345031104516238, 0.16055318556027487, 0.5154866923112422, 0.3091510251397267, 0.776363059412688, 20.250232480466366, 53.091929107904434, 50.802209973335266, 48.856756165623665, 66.22647911310196, 34.83916774392128, 1.1028371471911669, 2.1969475876539946, 41.845862567424774, 54.72858868539333, 90.6525868177414, 65.24494618177414, 48.962736278772354, 40.09663783013821, 43.07418465614319, 41.1018168926239], [10.418539345264435, 28.32732606679201, 33.98402363061905, 29.77824591100216, 16.04548830538988, 4.361072536557913, 1.089665035251528, 4.190991288051009, 10.306258220225573, 24.526942893862724, 25.134925469756126, 35.05139775574207, 35.512092635035515, 24.62618976831436, 28.51943425834179, 41.52666449546814, 12.35738530755043, 0.05206579699006397, 0.04970105845131911, 0.28659763222094625, 0.06755157286534086, 0.6281199515797198, 1.422552466392517, 0.15464059892110527, 0.09387768834130839, 0.34163171192631125, 0.16275726025924087, 0.029257916066853795, 0.0740280729951337, 0.0610149884596467, 0.266737166675739, 13.632252998650074, 40.18232703208923, 58.35580185055733, 48.036144599318504, 52.71774038672447, 37.78863787651062, 57.447198405861855, 62.45211124420166, 64.41936448216438, 66.28591552376747, 71.14700227975845, 63.888981342315674, 65.6728184223175, 68.70896190404892, 61.94725513458252, 70.0748062133789, 69.95922401547432, 70.4989318549633, 68.18213537335396, 67.94822752475739, 69.08199548721313, 64.60362419486046, 66.5847010910511, 66.87992244958878, 64.4962951540947, 66.5966248512268, 68.71612071990967, 66.63827821612358, 70.54168716073036, 68.29888790845871, 60.936254784464836, 50.88895171880722, 52.96217367053032, 50.14664255082607, 51.1426755040884, 50.73060281574726, 51.361714750528336, 50.85864454507828, 53.726947233080864, 50.94668962061405, 51.36419981718063, 50.7801977545023, 48.11003163456917, 49.08896550536156, 48.99471916258335, 48.91559220850468, 50.72464473545551, 47.0918420702219, 44.595710411667824, 42.6998021453619, 45.0297649204731, 48.468059822916985, 47.06468112766743, 43.371655493974686, 50.668548345565796, 59.77452792227268, 61.7202515155077, 61.025280207395554, 60.34057974815369, 60.577493235468864, 55.89345797896385, 44.93618734180927, 40.947450175881386, 45.715134143829346, 42.12091840803623, 41.54912509024143, 42.89097748696804, 43.264140263199806, 47.054216489195824, 48.28560881316662, 45.497143641114235, 45.69227457046509, 44.22572426497936, 44.508269503712654, 42.76811107993126, 44.65570919215679, 44.76594887673855, 45.64205266535282, 45.68150594830513, 46.458043679594994, 49.017274752259254, 46.74141347408295, 47.933379113674164, 45.2311085164547, 47.71041467785835, 52.677337154746056, 58.69014210999012, 57.03213527798653, 59.3549582362175, 57.085993587970734, 63.53420577943325, 57.201169207692146, 57.87203460931778, 61.43994815647602, 59.897557720541954, 54.80264291167259, 57.01040044426918, 60.10179676115513, 56.09874576330185, 55.48356257379055, 57.06210806965828, 54.15904484689236, 60.33515363931656, 56.349642500281334, 61.88591882586479, 54.65249016880989, 65.22384211421013, 57.35363982617855, 67.42974534630775, 31.441536359488964, 59.546825140714645, 52.925570234656334, 62.807281985878944, 53.527488335967064, 42.31366686522961, 30.83415985107422, 19.86737832427025, 4.0540205128490925, 0.5734262801706791, 0.513587387977168, 2.0932043669745326, 0.7376949687022716, 0.318893613293767, 0.3494643681915477, 0.09704999858513474, 0.055171228596009314, 0.096878065232886, 0.34593741525895894, 0.08447363827144727, 5.777297867462039, 27.66313310712576, 32.13326074182987, 37.05660715699196, 52.92806290090084, 21.415840834379196, 0.6636991049163043, 4.806410064920783, 24.01076339185238, 27.99256592988968, 37.10782840847969, 12.464394215494394, 1.2761370604857802, 0.10645102069247514, 0.6828587455675006, 3.2296082004904747, 13.995161075145006, 39.74339738488197, 50.27777351438999, 13.844822142273188, 35.121526792645454, 10.55777432397008, 2.073381068184972, 5.707061011344194, 33.31684783101082, 43.02143208682537, 38.889841586351395, 48.02335828542709, 50.93959540128708, 33.095296919345856, 37.201523780822754, 51.05279132723808, 16.964676082134247, 0.1926291495328769, 0.07002313985140063, 0.3540350776165724, 0.2281156976823695, 0.5268221965525299, 1.5811558370478451, 0.3075303230434656, 0.3103164641652256, 0.16644687711959705, 0.21825386123964563, 0.09362406679429114, 0.03733462574018631, 0.04386397049529478, 0.4138549411436543, 18.335511423647404, 51.812347769737244, 69.17158707976341, 61.151577830314636, 62.16083787381649, 46.020846739411354, 60.678757801651955, 67.4188095331192, 70.4456815123558, 72.34277531504631, 74.9887253344059, 68.2848134636879, 69.84255507588387, 72.15516418218613, 65.2775028347969, 72.98503205180168, 71.81321293115616, 70.06170451641083, 71.00189566612244, 72.31511279940605, 72.58006498217583, 66.8997573852539, 70.54064601659775, 70.31197428703308, 67.79707923531532, 68.28588500618935, 70.2384178340435, 69.79466244578362, 72.67506748437881, 71.40450686216354, 62.42058053612709, 54.66034434735775, 54.32923771440983, 54.53582502901554, 55.81914156675339, 54.71722349524498, 55.86202226579189, 52.49141313135624, 55.99245026707649, 54.24698352813721, 54.177223071455956, 52.041084095835686, 50.695842280983925, 51.79861530661583, 52.96711340546608, 52.95630298554897, 55.9188824146986, 50.797733813524246, 48.39928351342678, 45.12513980269432, 48.14771041274071, 50.67951835691929, 46.78386099636555, 44.83869977295399, 50.38703665137291, 62.04290360212326, 65.85273116827011, 62.16687574982643, 64.00070294737816, 62.38197460770607, 53.334443494677544, 44.348172694444656, 43.93595561385155, 47.474025562405586, 43.066832050681114, 42.512240409851074, 46.25074200332165, 47.561542466282845, 50.3220259398222, 51.23423919081688, 47.53473490476608, 48.58406759798527, 48.939363732934, 47.052571177482605, 46.2091114372015, 46.91934272646904, 48.199133053421974, 46.9223939627409, 48.92881169915199, 49.100676476955414, 50.5431854724884, 49.5858496427536, 53.84232044219971, 49.39149007201195, 50.17236337065697, 54.43926461040974, 61.2906389683485, 61.223686560988426, 60.3377602994442, 60.809049010276794, 67.56539046764374, 58.14547173678875, 58.70946787297726, 63.32705229520798, 61.717223078012466, 56.67800948023796, 59.63062584400177, 63.040262684226036, 58.31713892519474, 59.59868475794792, 61.086798906326294, 58.18889960646629, 61.002454832196236, 58.83656345307827, 65.52698224782944, 59.28208954632282, 66.48378610610962, 63.69659386575222, 64.75724995136261, 41.42677545547485, 65.49212291836739, 61.562164798378944, 67.46835127472878, 61.02075845003128, 53.00386123359203, 40.842473208904266, 28.67827333509922, 13.498063199222088, 1.8953941063955426, 0.304081414360553, 2.736463062465191, 0.25283837341703475, 0.22164501599036157, 0.16555641865124926, 0.035406451861490496, 0.11943496851017699, 0.045797639977536164, 0.1353594390093349, 0.03679877656395547, 7.697115400806069, 36.95238634943962, 34.13160391151905, 42.443775683641434, 58.2259514182806, 25.601610727608204, 1.3466483331285417, 8.659696374088526, 36.6656157374382, 48.86940188705921, 53.37032496929169, 16.423007547855377, 1.8606956745497882, 0.06408293047570623, 0.7135665009263903, 4.314169753342867, 55.93781299889088, 59.94700066745281, 80.5839554965496, 74.78328555822372, 43.142516389489174, 14.461374208331108, 1.2287936196662486, 13.415177296847105, 65.48975944519043, 60.71938902139664, 60.292291939258575, 58.56702111661434, 68.20760160684586, 48.6100772023201, 50.13150416314602, 58.805636912584305, 24.002981409430504, 0.6851118465419859, 0.21409323293482885, 0.759053563233465, 0.5251828220207244, 1.8563186656683683, 3.510584360919893, 0.5643201875500381, 1.4193197898566723, 1.1377290124073625, 0.3576823475304991, 0.16774734249338508, 0.2149944970733486, 0.16385973547585309, 0.5691804829984903, 29.809115454554558, 55.804261565208435, 65.29244363307953, 68.8101352751255, 68.8061910867691, 55.65565153956413, 67.29774042963982, 73.11762973666191, 75.46041682362556, 74.6259132027626, 79.01448011398315, 72.8306083381176, 74.33305531740189, 76.36836290359497, 66.16450443863869, 76.78774639964104, 78.5946786403656, 75.86599186062813, 74.50614362955093, 75.18506079912186, 74.84022170305252, 70.80992236733437, 74.60217967629433, 72.39999264478683, 71.61552473902702, 71.05795785784721, 73.86825665831566, 73.81897330284119, 77.13301867246628, 75.89479431509972, 65.39996266365051, 57.38690324127674, 58.72843265533447, 58.29467833042145, 57.497055530548096, 58.86504292488098, 60.021522268652916, 55.43826520442963, 61.61225751042366, 56.765427589416504, 56.757307425141335, 55.16936123371124, 52.98319034278393, 55.12896940112114, 56.08296141028404, 57.14308172464371, 59.92902383208275, 54.65693213045597, 51.01809158921242, 47.192346677184105, 50.47305643558502, 52.13615499436855, 47.268304601311684, 45.976807102561, 52.628353983163834, 65.20760178565979, 69.51983079314232, 67.16356962919235, 67.25713580846786, 67.87607699632645, 58.76885108649731, 46.35576456785202, 49.628908932209015, 48.81782725453377, 43.89036945998669, 44.287520349025726, 48.26036296784878, 50.66995806992054, 54.69876408576965, 53.62357757985592, 51.79875589907169, 51.955280900001526, 54.416325241327286, 51.937418058514595, 49.847815185785294, 51.165728867053986, 51.23575530946255, 50.16230531036854, 53.102769926190376, 53.32767225801945, 56.12721763551235, 52.69138120114803, 56.3818571716547, 52.43320785462856, 54.266069903969765, 58.62557217478752, 64.78320255875587, 63.61060447990894, 64.47223484516144, 61.50588221848011, 71.18791848421097, 64.45938393473625, 63.075171411037445, 66.99968442320824, 64.5835080742836, 58.046365454792976, 62.69579216837883, 64.26886975765228, 59.49811555445194, 60.386488884687424, 62.97897197306156, 59.891109466552734, 65.17271965742111, 61.46688111126423, 64.57118913531303, 56.672533974051476, 69.17141988873482, 65.16299977898598, 69.39284920692444, 44.3765951693058, 68.4978224337101, 64.99928936362267, 67.84512385725975, 65.41194722056389, 59.031739979982376, 54.663650169968605, 38.874885588884354, 16.320207864046097, 4.705003956332803, 0.45155298546887934, 4.629037482663989, 1.9982626615092158, 0.5991843855008483, 0.6766742211766541, 0.2865823736647144, 0.35252017609309405, 0.17774457635823637, 0.5203196173533797, 0.350291506620124, 13.062539119273424, 48.0376873165369, 47.794359773397446, 55.9322576969862, 67.95374482870102, 32.89542764425278, 1.7997693875804543, 10.58733768761158, 51.35271303355694, 69.82186138629913, 79.80989903211594, 39.983958676457405, 4.193065976724029, 0.1664667369914241, 0.975925144739449, 15.075587499886751], [8.13596572726965, 22.924500480294228, 38.17840576171875, 27.981954999268055, 0.9000356763135642, 0.15655680937925354, 0.32375577895436436, 0.2338247577426955, 12.297853901982307, 14.261727221310139, 21.373813189566135, 27.47032955288887, 27.059771083295345, 40.43451189994812, 70.25529652833939, 36.71344377100468, 5.592390764504671, 0.231951710593421, 0.10020864589023404, 0.2210440396447666, 0.2530329051660374, 3.492234433069825, 4.997518435120583, 0.37208259513136, 0.0747259144554846, 0.03677884989883751, 0.0691303213534411, 0.06600849199458025, 0.019096639734925702, 0.09226872702129185, 0.1417532193590887, 2.607365702278912, 14.140967801213264, 32.35905982553959, 40.329196751117706, 42.291601449251175, 35.29240362346172, 43.43960344791412, 54.58233453333378, 61.24714270234108, 67.38162472844124, 66.77105829119682, 62.81437620520592, 63.60123798251152, 68.94983857870102, 61.47257700562477, 73.7183167040348, 69.19942438602448, 71.16124391555786, 67.42605954408646, 66.11376196146011, 66.29539981484413, 65.61070695519447, 63.23618397116661, 66.1869004368782, 66.45201221108437, 66.6960959136486, 67.93978437781334, 69.00250375270844, 66.6906090080738, 66.25921055674553, 54.63984824717045, 49.93949666619301, 51.77510976791382, 50.35656228661537, 50.7386963814497, 50.40958844125271, 51.78431287407875, 51.88239701092243, 51.01020321249962, 50.19419699907303, 51.7178126424551, 50.07566995918751, 47.09737457334995, 48.17485995590687, 49.64696556329727, 51.000167950987816, 51.36051021516323, 46.87160208821297, 43.197742626070976, 41.97978638112545, 43.36768090724945, 46.92185439169407, 47.850433364510536, 46.26136623322964, 44.267958998680115, 53.289560303092, 62.42708958685398, 59.14182007312775, 59.10444527864456, 53.96910823881626, 46.94945231080055, 44.328945726156235, 45.600543692708015, 43.83864663541317, 42.02521674335003, 39.5412178337574, 43.203126937150955, 42.19650015234947, 48.684507608413696, 45.84928214550018, 46.06634549796581, 41.92945048213005, 43.8529072701931, 44.49513740837574, 44.943897128105164, 44.68148320913315, 43.85255388915539, 45.84471479058266, 46.60899817943573, 46.97124794125557, 46.82355746626854, 45.98071709275246, 47.782481610774994, 46.16567976772785, 47.70617790520191, 49.56162594258785, 57.6042477786541, 56.44203074276447, 58.66507865488529, 58.12369890511036, 64.17959734797478, 55.52172012627125, 54.84042428433895, 58.80067437887192, 58.13388995826244, 57.913611978292465, 56.29836805164814, 58.66233520209789, 54.93824623525143, 54.901927784085274, 59.41619575023651, 55.9079048037529, 57.29807920753956, 56.553140580654144, 58.70426595211029, 55.514333322644234, 64.91576984524727, 64.89481016993523, 64.72236022353172, 33.339422419667244, 53.9448731392622, 47.90543541312218, 55.88798627257347, 53.907600939273834, 56.38778105378151, 43.27962443232536, 18.439407348632812, 2.274918216280639, 1.7994616040959954, 0.8809910388663411, 2.2588434163480997, 0.044315994091448374, 0.140110163774807, 0.09803086548345163, 0.038034994213376194, 0.0671832449734211, 0.027972575662715826, 0.09336257848190144, 0.036991482629673555, 3.65558291785419, 28.33222210407257, 24.060453325510025, 36.466441825032234, 52.02989749610424, 16.709920652210712, 0.9339102648664266, 7.829843228682876, 26.376962922513485, 31.696766763925552, 39.39730055630207, 3.626359160989523, 0.06926588204805739, 0.027761132223531604, 0.1627109947730787, 0.3369064279831946, 0.5801541754044592, 36.05404615402222, 54.93866801261902, 25.96012718975544, 1.5448730089701712, 0.10099377876031213, 0.8223966986406595, 13.834146615117788, 32.55468472838402, 37.213067561388016, 31.649259813129902, 44.25995662808418, 40.94980984926224, 52.55266584455967, 77.19480335712433, 46.103066727519035, 7.62531777843833, 0.11986128040007316, 0.028049373104295228, 0.09338156261947006, 0.14183967956341803, 0.6403158721514046, 0.7923875120468438, 0.3217643889365718, 0.05529089619813021, 0.07699922411120497, 0.09194352533086203, 0.067862495634472, 0.0667319746571593, 0.08025593138881959, 0.07779204563121311, 3.685198766179383, 17.668345123529434, 36.659384071826935, 48.85622039437294, 50.61222396790981, 46.1799556016922, 47.768186777830124, 60.52292816340923, 67.65473127365112, 71.06933444738388, 74.55392226576805, 68.9909827709198, 68.39992448687553, 70.33836767077446, 65.3430113196373, 76.33249282836914, 74.98801857233047, 72.9158453643322, 72.99837693572044, 69.43042919039726, 70.4949040710926, 68.83864894509315, 65.06246477365494, 70.43673679232597, 68.04140612483025, 70.43318018317223, 68.46294030547142, 70.93330174684525, 67.84153684973717, 66.8620254099369, 58.2053679227829, 51.0883954167366, 54.648796766996384, 52.748887315392494, 51.86065457761288, 53.04692052304745, 54.18170303106308, 54.58828881382942, 54.23906855285168, 52.65463337302208, 53.29231135547161, 52.708772867918015, 49.65016879141331, 50.62838830053806, 51.73276484012604, 52.63120003044605, 56.254457607865334, 50.45194856822491, 45.89668460190296, 43.708625212311745, 44.12993140518665, 47.27407269179821, 48.85773651301861, 47.048987969756126, 44.10489074885845, 52.8163792937994, 66.81302323937416, 62.3670794069767, 64.0310101211071, 55.430167838931084, 47.29056000709534, 46.67039528489113, 47.134962156414986, 45.62832020223141, 42.90295824408531, 40.830063074827194, 46.12512454390526, 46.419593542814255, 51.96678288280964, 50.049804747104645, 48.871419578790665, 46.17392152547836, 47.26588033139706, 48.31219978630543, 47.07192733883858, 48.951640874147415, 47.597549334168434, 47.45536096394062, 49.45423610508442, 49.2233756929636, 48.97611156105995, 49.63312290608883, 51.707234010100365, 48.92776295542717, 50.54880537092686, 51.29877112805843, 59.20987442135811, 58.95533747971058, 59.360023364424706, 61.15136504173279, 65.565025806427, 57.11085945367813, 57.47038476169109, 62.18302108347416, 60.62025614082813, 59.03420604765415, 57.883289605379105, 59.77667100727558, 58.54356497526169, 58.50634977221489, 61.77260510623455, 60.62862329185009, 60.45735888183117, 59.78583611547947, 59.9090027064085, 61.29738360643387, 66.88390463590622, 66.23522624373436, 62.03400447964668, 41.068986654281616, 60.14672175049782, 53.23734350502491, 63.746393993496895, 62.187064066529274, 67.96588897705078, 55.18844000995159, 31.6619074344635, 9.261038806289434, 3.239964544773102, 2.02917352784425, 0.9736114845145494, 0.04586348331940826, 0.12720026745228097, 0.08065201560384594, 0.02783970339805819, 0.09083384386030957, 0.03847623069304973, 0.10225934092886746, 0.14169709815178066, 4.6612706780433655, 32.909661680459976, 32.82304912805557, 45.42037636041641, 57.47249744832516, 20.30592229217291, 1.4464724203571677, 11.226257253438234, 39.69387844204903, 52.250308468937874, 63.20287875831127, 15.080494936555624, 0.34202484239358455, 0.06060013904061634, 0.05691275975550525, 0.02585583133623004, 25.271486341953278, 68.38838830590248, 79.91560935974121, 62.19210259616375, 2.486615781672299, 0.3446996316779405, 0.9532230254262686, 38.065578415989876, 57.77225576341152, 58.50006490945816, 56.768319234251976, 61.83157414197922, 54.602465853095055, 70.78627243638039, 90.0353479385376, 55.754936411976814, 13.2900177128613, 0.5140619468875229, 0.31301203358452767, 0.6902433524373919, 0.626073464518413, 6.6656825970858335, 14.908110536634922, 2.5257137836888433, 0.18402342771878466, 0.15456662164069712, 0.2679163799621165, 0.24309942178661004, 0.22007663530530408, 0.1948895532405004, 0.3611438727239147, 7.394586559385061, 41.76991604268551, 54.20759104192257, 57.6851986348629, 60.889562889933586, 56.65853172540665, 55.697886273264885, 66.04243978857994, 72.81945213675499, 73.84817853569984, 77.08783149719238, 71.87039986252785, 72.11306244134903, 73.8212987780571, 66.3138896226883, 82.90126875042915, 79.62963670492172, 78.81481602787971, 75.97951456904411, 70.93487486243248, 72.28450164198875, 72.1286492049694, 67.99862042069435, 73.90259921550751, 71.5079753100872, 72.42582365870476, 72.8931225836277, 75.06730511784554, 73.30289259552956, 70.98071560263634, 60.77757529914379, 56.79692029953003, 57.10192993283272, 55.61598926782608, 55.41010111570358, 58.05962294340134, 57.282503843307495, 56.9123201072216, 57.165048345923424, 57.46189221739769, 55.849281549453735, 57.288986295461655, 52.8852353990078, 53.80041629076004, 55.19885525107384, 58.07235985994339, 58.772932067513466, 52.60552480816841, 48.92271302640438, 45.979284569621086, 44.62861284613609, 48.40579256415367, 49.87805016338825, 49.93869110941887, 45.19514724612236, 56.20089188218117, 70.47537311911583, 63.18395957350731, 66.21447175741196, 57.200739830732346, 48.6193373054266, 45.63756890594959, 46.403558403253555, 44.96618673205376, 43.23673613369465, 42.168427258729935, 46.59395478665829, 47.2885537147522, 57.33993776142597, 53.235341012477875, 52.15803802013397, 48.49294848740101, 50.87035171687603, 50.734892785549164, 50.145597606897354, 50.63594229519367, 50.508535131812096, 51.864914149045944, 52.44355469942093, 52.70659178495407, 52.131158262491226, 53.35534617304802, 54.758603274822235, 53.05850990116596, 54.87512022256851, 55.6931821256876, 62.487213760614395, 63.59377898275852, 60.50302483141422, 63.93023952841759, 69.88724827766418, 63.1923571228981, 60.90007312595844, 65.91177999973297, 62.727182283997536, 60.572116523981094, 59.64889146387577, 63.76807942986488, 59.89854946732521, 59.46966268122196, 62.48654879629612, 60.94789735972881, 63.17971520125866, 61.59644655883312, 61.454546973109245, 61.87526419758797, 69.34354305267334, 69.6587361395359, 71.60506770014763, 42.05645106732845, 63.57579454779625, 60.3772097826004, 64.01119038462639, 65.03588140010834, 65.06198599934578, 60.99216118454933, 48.40809144079685, 13.654315564781427, 8.92252067103982, 2.975372630171478, 4.919549943879247, 0.19331058952957392, 0.19303535664221272, 0.26129936159122735, 0.08849465375533327, 0.23769899125909433, 0.19054508011322469, 0.45424502226524055, 0.16615320928394794, 7.425632318481803, 41.85492888092995, 41.752505376935005, 51.580955386161804, 65.48341378569603, 26.291782893240452, 1.8669268651865423, 15.453781206160784, 59.67494286596775, 70.74882164597511, 78.96116137504578, 16.466403119266033, 0.5738154624123126, 0.16221844620304182, 0.22633167856838554, 0.8502407732885331], [0.12527512153610587, 13.957426249980927, 27.621350549161434, 6.06056316755712, 0.2665682538645342, 0.0323792018025415, 3.144391835667193, 16.52033742517233, 11.487374491989613, 8.950573615729809, 11.321838274598122, 17.511582635343075, 32.012499421834946, 18.24001494795084, 35.9639947861433, 32.659718692302704, 1.260548634454608, 0.07477114835637622, 0.1404788627405651, 0.021787637524539605, 0.2859515184536576, 0.4959222546312958, 1.49187998380512, 0.18899715301813558, 0.030122271346044727, 0.04484010620217305, 0.004231165266901371, 0.029519497147703078, 0.02514953310310375, 0.029636648869200144, 0.1581633512978442, 0.11506175200338475, 5.094784190878272, 10.126455668359995, 19.393929429352283, 24.733813293278217, 29.92709342390299, 37.583334892988205, 48.34213078022003, 61.24165199697018, 65.07735997438431, 67.44697362184525, 60.909679010510445, 67.70927354693413, 64.84585359692574, 66.82286471128464, 70.30505865812302, 70.99393889307976, 69.94110658764839, 65.57161465287209, 66.8456406891346, 66.04827627539635, 66.37678384780884, 62.685696110129356, 66.70324712991714, 66.359943151474, 66.42659157514572, 61.994775384664536, 65.28088465332985, 61.96183495223522, 60.9826996922493, 51.82113669812679, 50.09594187140465, 51.185305416584015, 51.71526297926903, 48.567017912864685, 49.604202657938, 51.43511541187763, 50.42463943362236, 52.31462761759758, 50.09955167770386, 49.145928248763084, 49.77957084774971, 50.149241611361504, 47.63198308646679, 48.88120025396347, 46.047224923968315, 50.59296280145645, 50.18226183950901, 42.90568269789219, 42.55790255963802, 43.118900656700134, 44.41465772688389, 43.89383107423782, 47.146486937999725, 45.44244557619095, 55.60427829623222, 60.50546050071716, 60.244425907731056, 55.55702783167362, 49.92584019899368, 44.560277312994, 54.26231950521469, 48.43146398663521, 42.73121885955334, 41.39545373618603, 41.762555837631226, 41.02629214525223, 45.05657248198986, 46.654356345534325, 44.83918234705925, 43.67895260453224, 43.63796420395374, 44.60463613271713, 43.275106474757195, 46.734953820705414, 44.85067293047905, 44.58371065557003, 44.89964850246906, 46.39648698270321, 46.69572092592716, 46.34169392287731, 46.263011544942856, 46.39018312096596, 42.90641985833645, 46.67521342635155, 45.788519605994225, 54.4900830835104, 56.36903665959835, 57.99648553133011, 59.610616117715836, 58.36614869534969, 53.34727920591831, 50.27256019413471, 55.440742671489716, 56.473778039216995, 59.26867626607418, 56.2976498901844, 59.21472676098347, 59.06395465135574, 54.67727243900299, 56.924300864338875, 56.838566064834595, 60.03363221883774, 54.542250484228134, 57.95114256441593, 57.515302151441574, 65.57653158903122, 61.34597919881344, 57.76386201381683, 31.995495334267616, 53.0286131054163, 51.31557382643223, 58.18296432495117, 67.51850098371506, 65.0257283449173, 48.73342618346214, 23.426523841917515, 3.972464301623404, 4.099873127415776, 0.3009578038472682, 0.4704247025074437, 0.09727604934596457, 0.07451819474226795, 0.004727854093289352, 0.04723174759419635, 0.026351313244958874, 0.09154234998277389, 0.09625544043956324, 0.12742780992994085, 2.7037890907377005, 20.9596012160182, 17.09230363368988, 33.83153781294823, 54.54379700124264, 8.201939687132835, 0.330578550347127, 5.261782854795456, 36.91637188196182, 31.11283879727125, 57.80757486820221, 25.122583732008934, 0.0793620219337754, 0.07364128046901897, 0.10671141804778017, 0.041886762919602916, 0.045272867355379276, 6.898450506851077, 20.5326846241951, 2.7498974790796638, 0.2640996628906578, 0.28545558569021523, 10.750543680042028, 40.67173317074776, 29.493177607655525, 22.419340386986732, 22.58847501128912, 34.112939313054085, 47.71231457591057, 33.095201924443245, 42.98450946807861, 38.59416425228119, 1.9175249501131475, 0.14809105661697686, 0.2302982352557592, 0.593512358609587, 0.2520378038752824, 0.2656542247859761, 0.1751933101331815, 0.16448449023300782, 0.04889311567239929, 0.04373535259219352, 0.11172197613632306, 0.025424086925340816, 0.054646396602038294, 0.10081550004542805, 0.028273006319068372, 0.2543953398708254, 3.3491141628473997, 9.97711893171072, 18.38019322603941, 29.661974050104618, 42.30835475027561, 42.04769253730774, 56.304151341319084, 65.67369237542152, 69.4962340593338, 72.45941385626793, 65.88997676968575, 73.07659193873405, 67.41566330194473, 68.0501988530159, 72.90832176804543, 72.99993485212326, 72.18533456325531, 67.67951354384422, 68.52083399891853, 66.97707563638687, 69.4329522550106, 64.63662162423134, 67.2737105190754, 69.69089761376381, 71.49366527795792, 65.04533529281616, 68.0951276421547, 63.165427967906, 62.288020849227905, 54.616734087467194, 52.40784041583538, 53.020044565200806, 54.16398078203201, 53.938926458358765, 51.933242082595825, 54.19885531067848, 52.965240105986595, 55.84563374519348, 51.67852655053139, 52.312385737895966, 52.3863335698843, 52.9927696287632, 52.19740770757198, 50.067469999194145, 49.97978210449219, 53.376275449991226, 52.17121571302414, 44.89614509046078, 44.89923432469368, 43.711988031864166, 45.52650086581707, 43.625493273139, 45.720647647976875, 45.51405273377895, 56.025937870144844, 63.52936863899231, 60.70345647633076, 55.757926851511, 50.0545658916235, 46.075624600052834, 52.82780148088932, 47.86727026104927, 43.78428675234318, 42.962824031710625, 44.881325885653496, 43.7780474871397, 47.33209177851677, 49.72651049494743, 46.16029545664787, 46.476104110479355, 47.83581554889679, 48.86952348053455, 46.74573764204979, 47.263459861278534, 48.487218394875526, 49.174415320158005, 47.51910634338856, 47.24828727543354, 48.0522595345974, 48.980462327599525, 50.02982161939144, 51.878540217876434, 49.68439735472202, 50.66472575068474, 49.13956359028816, 57.03320302069187, 58.75025488436222, 59.89451788365841, 63.201716020703316, 59.89462047815323, 56.908136531710625, 52.84539073705673, 60.14186941087246, 57.674604803323746, 62.29880467057228, 60.31704381108284, 62.63812266290188, 59.91614252328873, 58.14376562833786, 57.46213920414448, 58.074962720274925, 64.28098350763321, 60.151376500725746, 60.198117792606354, 58.81207376718521, 66.47769123315811, 61.99344165623188, 56.90470531582832, 38.6427940428257, 57.71507263183594, 57.73083038628101, 67.15704917907715, 74.63649183511734, 72.44651734828949, 60.83490662276745, 36.358960792422295, 11.863884888589382, 4.3802819307893515, 1.3440610282123089, 0.756095718825236, 0.07792723525199108, 0.041425299205002375, 0.03529905938194133, 0.09888342989142984, 0.019022232008865103, 0.116495269612642, 0.07995228166691959, 0.15306211018469185, 3.7968450877815485, 25.591820552945137, 23.788587413728237, 44.84163701534271, 59.92411829531193, 10.634254720062017, 0.7321802771184593, 7.690301891416311, 52.724207639694214, 48.90640810132027, 74.80060502886772, 44.65679593384266, 0.5034917453303933, 0.1606807459029369, 0.04895170080999378, 0.03384243500477169, 0.3295321814948693, 37.34009474515915, 68.84231954813004, 15.58981105685234, 0.6017975765280426, 0.29555324697867036, 12.662723623216152, 69.9852754175663, 49.77176606655121, 47.47044615447521, 55.66311813890934, 52.53934755921364, 62.28953316807747, 40.31713239848614, 53.80377531051636, 51.57678321003914, 3.3534473553299904, 0.43081497482489794, 0.4932220542104915, 0.8494206704199314, 0.7181247125845402, 3.112705573439598, 4.338553519919515, 1.4755117683671415, 0.13271253963466734, 0.2997975004836917, 0.17047991539584473, 0.15652986941859126, 0.23329715011641383, 0.10630452816258185, 0.20517016877420247, 0.4067929310258478, 12.646561190485954, 29.519947171211243, 38.59431244432926, 49.31849978864193, 53.3390336483717, 54.78389851748943, 59.695518761873245, 69.46602568030357, 70.47914251685143, 76.16714850068092, 68.43948036432266, 76.87603086233139, 69.26009193062782, 70.69784358143806, 77.08400130271912, 75.85581600666046, 73.2819177210331, 71.47381514310837, 71.70317083597183, 70.64039066433907, 71.57197907567024, 67.94092431664467, 72.24288627505302, 72.61341199278831, 73.00568774342537, 66.844272762537, 71.97559341788292, 67.28818014264107, 67.43877366185188, 57.350915372371674, 55.27653448283672, 59.11599285900593, 57.431866228580475, 54.93586376309395, 55.85557401180267, 57.67978012561798, 55.05080759525299, 59.301635697484016, 56.079062819480896, 55.3290780633688, 56.03433161973953, 55.53421385586262, 55.44915162026882, 53.975689485669136, 52.50935196876526, 55.94175338745117, 55.12978255748749, 47.26357385516167, 49.010423719882965, 45.55048517882824, 46.30238123238087, 44.31655839085579, 50.14842465519905, 46.86324253678322, 59.2263313382864, 67.65509605407715, 64.07872036099434, 59.24469195306301, 52.98165522515774, 48.43795023858547, 57.17596895992756, 53.27005974948406, 44.71987634897232, 44.82369817793369, 45.36167711019516, 46.53494395315647, 50.884315967559814, 53.14464747905731, 49.28447641432285, 47.7318911254406, 48.70255284011364, 53.45546320080757, 49.43910911679268, 52.349163964390755, 51.28207862377167, 52.965205907821655, 50.24294838309288, 52.62372203171253, 51.00850850343704, 52.80862770974636, 52.780376225709915, 53.70235875248909, 49.453658536076546, 54.10226829349995, 52.95120365917683, 61.150582283735275, 62.391926273703575, 61.90214395523071, 65.54712876677513, 62.71537631750107, 59.81370002031326, 56.22282810509205, 62.88834683597088, 58.73914048075676, 62.541296258568764, 61.7911671102047, 65.22951140999794, 61.0409277677536, 58.74028041958809, 59.960603937506676, 60.00437378883362, 66.4523009955883, 62.57878504693508, 61.78701393306255, 59.19806845486164, 70.56759417057037, 65.32185405492783, 63.75957548618317, 44.66688059270382, 65.75399726629257, 62.43167594075203, 68.58180552721024, 74.36317250132561, 73.03757563233376, 63.91465276479721, 48.00378933548927, 29.405322521924973, 11.49967823177576, 1.1523733078502119, 0.962839478161186, 0.368758337572217, 0.15650209825253114, 0.10477752221049741, 0.3109837736701593, 0.10855883883778006, 0.20827912929235026, 0.31634406885132194, 0.21593580750050023, 5.396807184442878, 35.42993724346161, 25.79863965511322, 49.671261459589005, 72.87859976291656, 18.098157159984112, 1.4301546709612012, 13.827401027083397, 71.49843782186508, 63.484911024570465, 87.2532132267952, 46.55592642724514, 0.15594069322105497, 0.2692559565184638, 0.2754134964197874, 0.16746911132941023], [0.03510370013827924, 0.34677583433222026, 0.2606980735436082, 0.038079578735050745, 0.059109995563630946, 1.5405064495280385, 21.117055267095566, 23.258645050227642, 7.380538713186979, 11.414350010454655, 9.03320588171482, 23.667510710656643, 37.387417405843735, 14.593598563224077, 35.71594789624214, 25.61650972813368, 0.6819866923615336, 0.15494873863644898, 0.207587210170459, 0.14973638317314908, 0.17210799444001168, 0.5575176025740802, 0.35334262414835393, 0.09760637927684002, 0.035108127049170434, 0.11742069807951339, 0.09052436085767113, 0.054517730459338054, 0.026610376589815132, 0.006314043539532577, 0.03531670765369199, 0.3610158077208325, 0.9856135561130941, 3.2342344522476196, 6.533866245299578, 8.319906257092953, 21.493451669812202, 33.141354247927666, 40.96892662346363, 54.87550400197506, 59.80786353349686, 65.57719275355339, 58.79044912755489, 67.04558596014977, 61.09152965247631, 66.68873190879822, 70.26494041085243, 66.50087758898735, 66.64390191435814, 68.14217671751976, 61.53223380446434, 62.29815110564232, 65.56710809469223, 63.05727817118168, 64.93764907121658, 68.22056651115417, 66.80784031748772, 60.954603999853134, 64.81911823153496, 61.399966701865196, 56.13224096596241, 50.757592767477036, 50.00600829720497, 47.13582091033459, 48.37172359228134, 47.684253081679344, 48.106539621949196, 49.05237726867199, 49.99481789767742, 49.72551494836807, 49.49375778436661, 49.91791382431984, 48.78850802779198, 48.66150364279747, 47.90973678231239, 45.46279348433018, 46.933204382658005, 45.65983571112156, 49.179989621043205, 44.79458414018154, 43.033462241292, 43.91699843108654, 41.920311972498894, 43.27475309371948, 42.85543419420719, 43.1758102029562, 49.51513543725014, 53.90669658780098, 51.74794502556324, 47.39086702466011, 44.09121908247471, 44.732529670000076, 45.40607392787933, 42.605590000748634, 40.975876450538635, 40.83511680364609, 43.3802430331707, 41.50099687278271, 43.66538353264332, 45.188197419047356, 43.77408429980278, 43.93955402076244, 45.17937809228897, 43.45536880195141, 43.710297122597694, 45.36177970468998, 44.64198812842369, 44.68806445598602, 45.37998452782631, 46.26060247421265, 47.70835138857365, 46.14006154239178, 44.69531826674938, 45.54105028510094, 44.564533084630966, 46.63196414709091, 44.1798797249794, 49.86609600484371, 58.16037833690643, 60.289058312773705, 59.31458160281181, 55.982111021876335, 52.37255550920963, 49.42553624510765, 52.92453669011593, 55.829420015215874, 58.31239677965641, 58.186175152659416, 59.5518484711647, 56.04842506349087, 53.49503427743912, 56.27903088927269, 56.065915524959564, 59.329195618629456, 56.95106282830238, 55.52567571401596, 57.313023805618286, 63.0309683829546, 58.1915632635355, 54.277929067611694, 32.44063384830952, 48.549823835492134, 51.71465501189232, 55.89091591536999, 63.21526609361172, 62.960280776023865, 55.84088779985905, 38.72525341808796, 17.39764764904976, 7.562441602349281, 0.34498129156418145, 0.1844072071253322, 0.05228547641308978, 0.04535589141596574, 0.07333948611631058, 0.07756408755085431, 0.05083493764686864, 0.0909842252440285, 0.06236194938537665, 0.07323787867790088, 2.984576686285436, 19.639772437512875, 22.46385119855404, 34.630615934729576, 44.7227717936039, 4.045126615092158, 0.0855387092451565, 1.9050875050015748, 32.92868725955486, 35.90816058218479, 67.20684930682182, 58.14437739551067, 11.264673192054033, 0.3308175515849143, 0.04561008812743239, 0.030693029293615837, 0.06924764747964218, 0.22474432858871296, 0.7753879961092025, 0.13158020039554685, 0.19493866857374087, 5.948491981253028, 43.44947911798954, 49.493241012096405, 23.660380393266678, 11.769239567220211, 13.885233923792839, 36.5097177028656, 53.32312770187855, 20.85324302315712, 43.05090330541134, 32.37623110413551, 0.8911464095581323, 0.11205405011423863, 0.46084390254691243, 0.36348831723444164, 0.13460360612953082, 0.027447237152955495, 0.18488382920622826, 0.06160444667330012, 0.06171328634081874, 0.1183013898844365, 0.02638489728269633, 0.08672855750774033, 0.07422287191729993, 0.06673506199149415, 0.03899456518411171, 0.20382140442961827, 1.1954239290207624, 3.5325695062056184, 5.83651483990252, 9.860625732690096, 32.03040026128292, 45.17843574285507, 45.575256049633026, 60.31698301434517, 65.11055499315262, 71.5126034617424, 63.60029563307762, 73.9706763625145, 62.65983089804649, 67.60024979710579, 74.2636938393116, 71.00197926163673, 68.7525987625122, 69.15762662887573, 64.52781826257706, 64.67545554041862, 69.62290406227112, 67.37882807850838, 67.38990068435669, 69.0210847556591, 67.92868137359619, 63.874739706516266, 66.46226406097412, 63.26063945889473, 57.54127375781536, 53.03514875471592, 54.42171335220337, 52.84668266773224, 51.03148207068443, 51.570460349321365, 51.853723749518394, 53.46975803375244, 53.76212954521179, 52.85623915493488, 53.59890550374985, 52.45160646736622, 50.6878437101841, 50.32936334609985, 51.18601977825165, 50.05006693303585, 50.86786665022373, 50.468333289027214, 51.54638484120369, 48.51250223815441, 46.546480134129524, 44.67504635453224, 43.96187782287598, 42.59658828377724, 42.53787383437157, 44.20925974845886, 49.357531294226646, 53.41354764997959, 53.06879594922066, 48.72762009501457, 46.39636918902397, 44.15247559547424, 45.49580231308937, 40.33816806972027, 39.54196639358997, 41.00120209157467, 43.890206068754196, 43.79583813250065, 44.88438472151756, 48.59476022422314, 45.90222470462322, 47.38513693213463, 50.45678190886974, 48.04293863475323, 46.43583007156849, 46.94270007312298, 47.8762149810791, 48.64013358950615, 47.33344450592995, 47.14914299547672, 47.06614784896374, 48.96870195865631, 47.226639837026596, 47.41742379963398, 47.49305494129658, 52.02238529920578, 47.93761968612671, 52.16721072793007, 58.323856964707375, 61.8409064412117, 59.686049669981, 58.412285819649696, 57.19633586704731, 55.215498358011246, 55.77167451381683, 58.424255177378654, 58.64349581301212, 61.45162872970104, 60.15967145562172, 59.83891926705837, 56.790529042482376, 58.568962812423706, 56.17736354470253, 63.19742605090141, 59.73648436367512, 58.02969574928284, 59.487244337797165, 67.24420890212059, 59.29569661617279, 54.869865104556084, 40.03571189939976, 55.503830686211586, 58.19410912692547, 63.015529811382294, 68.24526518583298, 72.64096811413765, 67.54196852445602, 52.35577940940857, 24.289645627141, 8.001392148435116, 0.2805378183256835, 0.26434504659846425, 0.15322725288569927, 0.028201055101817474, 0.08895842925994657, 0.11715999644366093, 0.03358372603543103, 0.05603512188827153, 0.02544157006923342, 0.13339172350242734, 4.718588227406144, 26.525757238268852, 24.527837745845318, 40.35278968513012, 50.24524345993996, 6.312310583889484, 0.45566210872493684, 1.9047019444406033, 39.99004974961281, 53.7467897683382, 75.58293744921684, 79.68987107276917, 23.363333232700825, 0.22303686942905188, 0.009142006074398523, 0.06342800741549581, 0.18761561543215066, 0.8000168495345861, 2.2224256955087185, 0.32663997262716293, 0.29990339011419564, 4.444692274555564, 61.83514975011349, 72.55334481596947, 42.277401611208916, 56.15256607532501, 18.474593460559845, 55.142101496458054, 68.37062805891037, 32.55428954958916, 53.446092903614044, 42.45055451989174, 2.3629165068268776, 0.38911414216272533, 1.0251851077191532, 0.5864634399767965, 0.4183244809973985, 1.7577651352621615, 0.7854501530528069, 0.33549910818692297, 0.2304983331123367, 0.21507610363187268, 0.17933673545485362, 0.20904705917928368, 0.24835271411575377, 0.15921310434350744, 0.16007525729946792, 0.9443363710306585, 1.1236227443441749, 7.618058267980814, 19.28968582302332, 23.623548969626427, 47.54295766353607, 53.86190079152584, 56.75166852772236, 64.30469423532486, 68.2102158665657, 74.07725304365158, 68.0313366651535, 79.36643242835999, 65.56902319192886, 71.5731418132782, 74.6269391477108, 77.10586532950401, 73.76997113227844, 71.85651540756226, 66.68078273534775, 69.1955029964447, 69.84956189990044, 71.10522732138634, 73.41571614146233, 72.92080789804459, 72.16089427471161, 69.91655990481377, 72.85313352942467, 69.29383412003517, 63.58900263905525, 56.07919201254845, 55.4803441464901, 54.12835769355297, 55.428127348423004, 52.95947201550007, 54.40445467829704, 55.456340834498405, 57.65736512839794, 56.14935524761677, 57.77396947145462, 55.72365269064903, 56.72500155866146, 52.787493243813515, 53.40928427875042, 52.095569372177124, 51.660363525152206, 52.95303136110306, 56.511156633496284, 51.34103626012802, 51.22657120227814, 46.03310488164425, 44.47230823338032, 43.95141698420048, 43.02425533533096, 43.785673677921295, 52.71025858819485, 58.12157481908798, 54.89201031625271, 51.29439756274223, 48.169703632593155, 46.92500822246075, 50.51832340657711, 43.03621329367161, 42.75507017970085, 41.118532195687294, 45.20081654191017, 48.004872277379036, 48.00892286002636, 50.821828320622444, 47.442897632718086, 46.90476290881634, 51.382526233792305, 50.40197364985943, 47.79739201068878, 51.643237844109535, 49.059429690241814, 51.93899877369404, 52.79130443930626, 49.38464663922787, 51.88291758298874, 51.48323982954025, 48.528978154063225, 49.14090871810913, 50.33208779990673, 53.26539359986782, 52.95282617211342, 56.40077255666256, 62.727714255452156, 64.31951344013214, 63.09775359928608, 59.7566194832325, 59.84095215797424, 56.91853657364845, 57.34737016260624, 60.48312909901142, 62.1923153847456, 63.74128706753254, 62.46564231812954, 60.27123726904392, 55.91072425246239, 58.42777758836746, 58.640615567564964, 65.36524012684822, 61.0795982927084, 61.089131981134415, 60.96216179430485, 67.86670669913292, 57.555074617266655, 60.540209636092186, 45.524935349822044, 61.81153781712055, 64.04675647616386, 64.56240400671959, 69.41424205899239, 69.15378883481026, 68.61577570438385, 61.40687853097916, 40.398277044296265, 18.73938225209713, 0.49204566108528525, 0.3543365380028263, 0.16445858927909285, 0.10397344231023453, 0.19155346584739164, 0.242548436508514, 0.1346287500928156, 0.23925723420688882, 0.11320264238747768, 0.5257318925578147, 5.66498301923275, 33.17593239247799, 34.905740171670914, 54.007622972130775, 65.75155779719353, 10.29671123251319, 0.6660992105025798, 4.255654793232679, 61.15644916892052, 68.37951958179474, 88.15376490354538, 91.50714576244354, 15.35837972536683, 0.8608242147602141, 0.1650742898345925, 0.2127352956449613], [0.05463705296278931, 0.07969077109009959, 0.060761827044188976, 0.13560500083258376, 1.5391867328435183, 20.363375209271908, 36.77272439002991, 14.716870598495007, 4.5794054958969355, 6.619899328798056, 2.9463854106143117, 22.011238485574722, 26.6236836835742, 25.937714092433453, 48.73535268008709, 20.803342200815678, 0.07116520122508518, 0.09074415531358682, 0.26850600144825876, 0.26023948565125465, 0.05849220586242154, 0.033723416781867854, 0.04344637884059921, 0.038752884793211706, 0.07144102040911093, 0.08555193431675434, 0.06718458826071583, 0.04136419447604567, 0.0597234362794552, 0.037687246076529846, 0.11432666215114295, 0.09647119019064121, 0.40728562802542, 0.7729978649877012, 1.2774644955061376, 2.4261738499626517, 8.35643369704485, 34.60003897547722, 33.311398923397064, 50.16785301268101, 54.74695309996605, 66.05567067861557, 59.71871271729469, 66.9158761203289, 60.858545154333115, 64.11955296993256, 67.84957721829414, 67.82686203718185, 60.66761299967766, 60.89063063263893, 64.33339029550552, 64.53344956040382, 61.722481995821, 67.02201962471008, 64.63629484176636, 60.271814838051796, 61.236324682831764, 62.4167313426733, 57.08837226033211, 59.20504868030548, 54.600725546479225, 55.45990124344826, 53.90040032565594, 50.65828129649162, 48.50000850856304, 48.620663434267044, 46.65205366909504, 49.98863942921162, 51.326110661029816, 52.361110523343086, 47.34190285205841, 46.3945908844471, 46.67573019862175, 47.789154052734375, 49.34633709490299, 49.54610377550125, 49.26674276590347, 45.50051786005497, 44.62757930159569, 43.95369306206703, 43.59070993959904, 43.23824465274811, 44.2248123139143, 43.99311974644661, 46.43844053149223, 48.56344610452652, 46.33202724158764, 45.73438011109829, 46.64358392357826, 47.4190729111433, 45.020508617162704, 43.196541890501976, 41.55359745025635, 41.52789182960987, 40.21530546247959, 39.91034522652626, 41.34146623313427, 39.32119823992252, 39.621655717492104, 41.41341157257557, 44.520250260829926, 45.83279862999916, 45.91645114123821, 46.137101501226425, 44.24677513539791, 43.77944961190224, 44.46915440261364, 45.311113223433495, 45.315828770399094, 46.71651341021061, 46.464210748672485, 47.159049063920975, 45.09799025952816, 42.474364042282104, 41.37203559279442, 44.45970430970192, 45.038173869252205, 47.35881954431534, 53.67165260016918, 57.958400174975395, 57.537177577614784, 58.61951529979706, 57.1342433989048, 56.16597555577755, 49.869177639484406, 52.14667662978172, 52.01187506318092, 53.95602934062481, 57.44771517813206, 59.63174298405647, 56.58524125814438, 54.03130330145359, 49.267403930425644, 59.86392952501774, 56.29090145230293, 54.62235398590565, 54.44053374230862, 63.27850230038166, 59.588379710912704, 49.41896639764309, 31.470599099993706, 47.35224209725857, 61.26930311322212, 60.30666656792164, 70.46966582536697, 64.58135738968849, 49.20606002211571, 35.84078639745712, 29.498210437595844, 6.082559237256646, 0.19779687223490328, 0.015790525831107516, 0.06256211403524503, 0.06014375903760083, 0.0661863328423351, 0.012904217965115095, 0.05275950468785595, 0.018538472322688904, 0.028123124029661994, 0.12699365353910252, 5.885697025805712, 20.3702300414443, 22.213972806930542, 26.38359546661377, 30.963176228106022, 3.594896849244833, 0.20299039199016988, 0.34947650972753763, 20.27822557836771, 45.58296963572502, 45.8654198795557, 87.97123029828072, 51.749673932790756, 2.185584297403693, 0.36217533925082535, 0.17092821712139994, 0.15655281662475318, 0.14875941997161135, 0.0977695404435508, 0.1497568070772104, 3.690916746854782, 38.73693399131298, 64.67005223035812, 32.40602910518646, 9.508409332484007, 3.947596773505211, 8.95294088870287, 37.33477883040905, 41.995148956775665, 36.49463631212711, 58.60933944582939, 25.494042299687862, 0.10312436599633656, 0.13182914641220123, 0.14562297030352056, 0.05025329053751193, 0.09689758371678181, 0.005187046835999354, 0.07458776366547681, 0.03619508024712559, 0.10147459397558123, 0.04644846267183311, 0.050504296013969, 0.04754703048092779, 0.014856648940622108, 0.05262368795229122, 0.0533490668021841, 0.03234729316318408, 0.4605803807498887, 0.3369614656548947, 0.49457445507869124, 0.8180980011820793, 10.686828698962927, 38.425795286893845, 42.508657202124596, 55.76419271528721, 59.19698551297188, 71.5912364423275, 64.34023752808571, 72.58111372590065, 63.94906371831894, 68.01877453923225, 70.46061471104622, 67.8741542994976, 65.27717605233192, 65.2115535736084, 67.41276785731316, 67.03237786889076, 62.20009356737137, 68.46623852849007, 66.63532957434654, 64.38973367214203, 63.2693637907505, 64.48665887117386, 59.76904481649399, 60.78044034540653, 55.43201453983784, 56.67593099176884, 57.22766898572445, 52.94892758131027, 49.96925286948681, 51.24103702604771, 49.95997376739979, 51.71753525733948, 54.49631094932556, 55.079203471541405, 52.69214116036892, 52.12434142827988, 50.59536427259445, 51.390441209077835, 50.02536065876484, 53.748678267002106, 52.098005041480064, 50.23315630853176, 48.24536897242069, 46.835705414414406, 45.70578284561634, 45.49275487661362, 44.955748692154884, 46.17792651057243, 49.400723576545715, 47.76266187429428, 48.551624938845634, 45.85647515952587, 46.320703849196434, 46.315703317523, 47.40731254220009, 44.015333354473114, 42.649736031889915, 41.14069640636444, 39.717475175857544, 41.74360245466232, 42.99964405596256, 40.92080220580101, 42.8323770314455, 43.89476582407951, 47.065536081790924, 48.7190705537796, 49.01993080973625, 50.55770069360733, 47.0541100949049, 46.39129266142845, 48.037200942635536, 49.55618463456631, 48.7887854129076, 47.739186733961105, 47.281125113368034, 48.56764867901802, 48.008421286940575, 45.55042438209057, 45.46019062399864, 47.42224954068661, 48.487989753484726, 48.19245681166649, 54.767057821154594, 57.98808418214321, 59.35608297586441, 60.181379690766335, 61.80578112602234, 58.161442279815674, 51.92054696381092, 56.47801101207733, 54.037979543209076, 57.174832820892334, 59.35373090207577, 60.86286172270775, 58.44644598662853, 55.151851773262024, 52.13426649570465, 62.21370443701744, 59.46449115872383, 59.82877001166344, 56.26355051994324, 61.170998588204384, 59.18131895363331, 53.2777239382267, 40.279769003391266, 55.70027254521847, 69.02524173259735, 65.66529482603073, 76.78484335541725, 69.77589145302773, 55.0816885381937, 46.16011306643486, 41.87760606408119, 6.699736844748259, 0.24761301552644, 0.12965946283657104, 0.041168827810906805, 0.04973589857399929, 0.10273936204612255, 0.0324665340303909, 0.03955472340749111, 0.07844769599614665, 0.09702219773316756, 0.2601536043221131, 8.170710112899542, 27.73326974362135, 30.621768347918987, 31.700690053403378, 37.7286808937788, 4.846310298889875, 0.28085008438210934, 0.4923714342294261, 25.77229756861925, 58.33075359463692, 56.25379264354706, 91.24017208814621, 69.98082965612411, 5.6841126177459955, 0.32745603821240366, 0.15152283653151244, 0.29398847313132137, 0.18065725365886465, 0.2213923740782775, 0.2562336396658793, 2.006260519847274, 40.99593937397003, 90.47502994537354, 46.94349803030491, 48.02219554781914, 20.670459531247616, 11.37163270264864, 67.06655323505402, 52.0562718808651, 53.196659088134766, 71.27098202705383, 35.27498535811901, 0.6879902514629066, 0.2884049993008375, 1.0656359558925033, 0.9447944245766848, 0.42993897339329123, 0.18890880775870755, 0.18238377117086202, 0.27101238258183, 0.2185946999816224, 0.21571003133431077, 0.13303749641636387, 0.12356814477243461, 0.12500876473495737, 0.1523822732269764, 0.2003072461229749, 0.2145513755385764, 0.7783679862041026, 0.8940299798268825, 1.1621187161654234, 7.177969682961702, 24.157747104763985, 55.51445871591568, 52.064836621284485, 61.52032524347305, 62.651676535606384, 73.45734670758247, 67.8901894390583, 72.13791310787201, 64.32589709758759, 69.16388869285583, 73.52687537670135, 70.075573772192, 65.29462471604347, 66.8510439991951, 69.8192623257637, 70.5147922039032, 64.93745908141136, 73.59101593494415, 70.43758034706116, 67.11528182029724, 67.90456786751747, 67.59675398468971, 62.51742973923683, 66.98136940598488, 61.34093686938286, 61.20290167629719, 61.51521071791649, 55.435476154088974, 53.67957517504692, 55.063263326883316, 54.05241496860981, 55.67827172577381, 57.02234320342541, 57.959027141332626, 52.463161647319794, 54.30231235921383, 53.73460002243519, 55.00890724360943, 52.88941517472267, 56.35051645338535, 54.89872455596924, 51.130303367972374, 50.29963754117489, 49.65378239750862, 49.632355347275734, 48.563974276185036, 45.84313027560711, 46.03985331952572, 49.32913161814213, 49.01323176920414, 48.45896691083908, 49.8112915456295, 47.75129288434982, 48.14279347658157, 49.41553518176079, 45.801484510302544, 44.687878265976906, 42.087503001093864, 40.910850539803505, 42.09004506468773, 47.42733746767044, 42.19188719987869, 46.220142245292664, 46.557431146502495, 48.820620104670525, 51.65149860084057, 50.30728653073311, 51.44024893641472, 48.49695727229118, 46.51024907827377, 49.696541503071785, 51.565847396850586, 50.96529342234135, 51.652266159653664, 50.4543462395668, 52.095253989100456, 49.04224321246147, 45.630444288253784, 48.16958583891392, 51.30857840180397, 51.123855113983154, 50.957864820957184, 58.805131539702415, 62.68356442451477, 61.40600837767124, 63.06774660944939, 63.58794629573822, 62.03699491918087, 53.46593163907528, 57.00049817562103, 55.52734762430191, 58.964046612381935, 58.23726341128349, 63.23625236749649, 60.023399367928505, 56.238878443837166, 52.839862033724785, 64.50299799442291, 61.27410225570202, 59.902102276682854, 53.60256090760231, 66.41517698764801, 62.87395320832729, 54.35829095542431, 48.04020278155804, 60.3706931322813, 68.89919489622116, 67.59037792682648, 77.5711427628994, 69.48076888918877, 64.2436695098877, 50.314099565148354, 61.563167944550514, 8.891064058989286, 0.6029967090580612, 0.27680288592819124, 0.13703367963898927, 0.2869906439445913, 0.11676249472657219, 0.13268303184304386, 0.20782472711289302, 0.15370491397334263, 0.26815324381459504, 0.34749904240015894, 11.959898136556149, 35.08461557328701, 42.51822508871555, 47.47467152774334, 60.64322590827942, 8.390725906938314, 0.340580593328923, 0.6123697967268527, 44.69154126942158, 74.65880423784256, 65.73757454752922, 109.38963979482651, 71.43860623240471, 2.761091203428805, 0.5198901216499507, 0.44319696666207165], [0.143496835953556, 0.15889591042650864, 0.06334269011858851, 0.3854478138964623, 17.273800894618034, 42.794261276721954, 31.463062204420567, 12.183541785925627, 14.64673301205039, 0.6622776249423623, 8.45655357465148, 16.463591270148754, 19.93011485785246, 19.754630774259567, 40.17462104558945, 16.68010365217924, 0.08145213985699229, 0.03959558605856728, 0.1611594163114205, 0.1263811145327054, 0.04592324847180862, 0.05655371984175872, 0.09096469191717915, 0.08638061641249806, 0.02603065349831013, 0.0773389644746203, 0.06135709256341215, 0.03474817058304325, 0.04155238828388974, 0.05020258329750504, 0.07889755623182282, 0.13502136105671525, 0.03825640284048859, 0.10716574601246975, 0.19226902979426086, 0.17160815797979012, 0.9645194630138576, 6.536013130098581, 18.402270041406155, 42.555622681975365, 49.24212388694286, 60.59513568878174, 57.93666534125805, 63.92754927277565, 59.74383316934109, 64.0227797627449, 67.66874492168427, 62.83079132437706, 63.350622430443764, 63.836604952812195, 60.79854257404804, 64.66388136148453, 59.81427758932114, 64.16513532400131, 61.70860894024372, 60.550165101885796, 56.35682411491871, 60.20102843642235, 57.2591844946146, 54.08926159143448, 55.14821916818619, 57.2905670106411, 53.077318891882896, 50.608864948153496, 47.560334131121635, 50.66480554640293, 47.184397503733635, 49.313126876950264, 49.620298594236374, 51.98720298707485, 49.878840520977974, 49.56396281719208, 47.90756709873676, 47.29453079402447, 46.404827535152435, 48.960030823946, 49.04062829911709, 46.22573934495449, 44.456854462623596, 46.309042274951935, 41.80985949933529, 43.52814629673958, 41.337791830301285, 45.417283326387405, 49.667188078165054, 53.52198243141174, 47.87909522652626, 45.39894551038742, 39.728821367025375, 39.878852516412735, 39.05446395277977, 39.547008723020554, 37.50209905207157, 41.006772592663765, 39.81927931308746, 42.58583106100559, 41.52540676295757, 38.84984873235226, 38.68478938937187, 40.41675165295601, 42.31869779527187, 43.98809261620045, 43.311937898397446, 45.8983489125967, 44.54597108066082, 47.02377252280712, 45.22102005779743, 45.90575471520424, 47.20473401248455, 47.73699425160885, 44.82396796345711, 45.21060101687908, 43.08903805911541, 44.634772315621376, 44.14623633027077, 41.721404045820236, 44.25899527966976, 45.69795906543732, 47.53324918448925, 51.65591016411781, 53.901726454496384, 57.66988925635815, 60.64170598983765, 57.22937889397144, 53.03910814225674, 56.92309632897377, 49.34152655303478, 51.494817808270454, 56.28158815205097, 47.04988472163677, 55.26252843439579, 54.61168795824051, 46.994894072413445, 55.78652411699295, 55.28767928481102, 56.84626445174217, 56.37523412704468, 47.191404327750206, 50.59472970664501, 45.03445766866207, 45.49622029066086, 44.2179536819458, 56.390349715948105, 55.17134852707386, 57.641075402498245, 49.34330105781555, 57.23922036588192, 81.5610958635807, 35.01837372779846, 0.8822458621580154, 0.21454334550071508, 0.1301676855655387, 0.12445480344467796, 0.10140777842025273, 0.15486207063077018, 0.035687261988641694, 0.11974636625382118, 0.08814162894850597, 0.11833781449240632, 0.21114928153110668, 4.366849651560187, 24.30637612938881, 25.454642213881016, 22.86777712404728, 21.530058905482292, 3.3151442231610417, 0.10933041266980581, 0.06035449558112305, 6.0211079847067595, 56.40884332358837, 41.90597914159298, 60.65964102745056, 85.30387222766876, 24.777689538896084, 0.09000818972708657, 0.05810346519865561, 0.15916271251626313, 0.07506486814236268, 0.0932896402082406, 1.196125466376543, 28.4920035302639, 67.23568215966225, 51.99709005653858, 25.719246715307236, 23.77836786210537, 2.449921863153577, 7.977798264473677, 38.09074446558952, 28.00149355083704, 34.58991251885891, 51.26253627240658, 21.32186807692051, 0.1166679005837068, 0.1544244706747122, 0.2009820067905821, 0.11915699709788896, 0.09199013220495544, 0.057932615382014774, 0.08025868475669995, 0.09241598396329209, 0.057610089133959264, 0.011979995488218265, 0.010880797781283036, 0.10971609939588234, 0.06364861823385581, 0.06875544771901332, 0.05714843988243956, 0.11459550514700823, 0.07210861935163848, 0.14311210659798235, 0.1723638572730124, 0.19783012045081705, 0.03312399894639384, 6.595420567318797, 22.32591100037098, 47.526265159249306, 55.31408026814461, 64.80179876089096, 64.55636233091354, 69.03553918004036, 61.10788397490978, 66.77106589078903, 72.74938389658928, 65.00270158052444, 64.37595561146736, 65.50436586141586, 62.855672389268875, 69.02637407183647, 61.72627419233322, 62.92968861758709, 64.74810764193535, 62.33185529708862, 61.0275486856699, 60.73383964598179, 57.87612698972225, 58.049982860684395, 56.40208728611469, 60.79341284930706, 55.2152019739151, 53.509610295295715, 50.3058236092329, 52.830248549580574, 50.476575046777725, 54.12648819386959, 52.65117555856705, 54.59596440196037, 53.96766051650047, 52.99151569604874, 50.24773612618446, 49.339771047234535, 48.02512139081955, 49.94313307106495, 51.20602950453758, 49.85772505402565, 49.51709233224392, 48.82487207651138, 44.73001420497894, 44.67840917408466, 42.89902925491333, 44.53615240752697, 48.69290515780449, 53.16398084163666, 49.71733778715134, 46.925916373729706, 39.252212941646576, 39.6975414454937, 38.391391932964325, 38.752725943923, 37.9653549939394, 39.89710293710232, 38.88795308768749, 45.26512809097767, 42.96514570713043, 40.98154194653034, 42.10568502545357, 41.64251647889614, 43.170832470059395, 47.906883135437965, 45.62628351151943, 49.3646065145731, 48.728668838739395, 51.00665420293808, 49.78473477065563, 47.97963783144951, 50.0605733692646, 49.557107985019684, 45.51587663590908, 47.84269317984581, 45.31307391822338, 48.08618411421776, 48.51336859166622, 44.9201750010252, 46.863272935152054, 50.56426674127579, 50.1055059581995, 53.16635571420193, 55.834754928946495, 60.08817829191685, 60.98682627081871, 60.89684709906578, 57.33107663691044, 60.201985985040665, 51.34258657693863, 51.81199058890343, 56.57549098134041, 47.677162662148476, 60.25463975965977, 60.94092093408108, 50.78143268823624, 58.23764719069004, 57.38147333264351, 60.90204142034054, 58.230138793587685, 49.31044042110443, 51.92233286798, 44.71646413207054, 52.90299944579601, 48.8475226610899, 61.71541057527065, 60.71050889790058, 61.56378351151943, 58.19134287536144, 71.44590944051743, 94.35465216636658, 33.80619317293167, 1.1659467732533813, 0.13347456202609465, 0.04884935122390743, 0.06858680950244889, 0.008431049009232083, 0.1827322837198153, 0.11414329230319709, 0.06947835150640458, 0.09729623576276936, 0.07400304777547717, 0.5135410185903311, 7.533442033454776, 33.30204002559185, 31.078251153230667, 30.32676737755537, 33.65762114524841, 3.6558707524091005, 0.08776292583206668, 0.10285893687978387, 3.583053359761834, 70.64751148223877, 52.37734705209732, 70.54079800844193, 91.31549164652824, 39.72032502293587, 0.142465666285716, 0.12823246128391474, 0.256449367152527, 0.27323499612975866, 0.2019593707518652, 1.1349334311671555, 25.32728634774685, 85.00824809074402, 74.47394415736198, 40.82412399351597, 65.32224923372269, 3.988471180200577, 22.04692617058754, 63.95032525062561, 44.82957266271114, 48.43922697007656, 55.196658968925476, 32.94859059154987, 0.6184910307638347, 0.4165623849257827, 1.082362539600581, 0.7200835668481886, 0.4073347878875211, 0.1718719766358845, 0.2241196925751865, 0.2216952297021635, 0.22201548126759008, 0.1508560316869989, 0.13757549197180197, 0.2916751097654924, 0.22479550709249452, 0.1951273818849586, 0.14159551297780126, 0.3754707070766017, 0.31451966206077486, 0.26657341921236366, 0.3445160243427381, 0.34864720422774553, 2.7461805660277605, 17.86203023046255, 38.82632419466972, 52.68695443868637, 62.187219858169556, 71.04786559939384, 67.20095962285995, 74.34433311223984, 62.62117937207222, 68.65531638264656, 74.47750836610794, 66.6862316429615, 66.99100568890572, 69.01312038302422, 64.92356702685356, 70.07083922624588, 63.37651804089546, 67.76253908872604, 68.08434382081032, 63.34024518728256, 61.27541698515415, 64.25644442439079, 60.92364326119423, 60.820839777588844, 59.051194936037064, 64.2590206861496, 57.75060832500458, 55.96596568822861, 53.91626447439194, 55.673970356583595, 52.783754244446754, 56.43564708530903, 55.24428181350231, 59.81658786535263, 56.67607918381691, 54.79536630213261, 54.90912839770317, 54.080579057335854, 51.80397301912308, 53.63634489476681, 54.08300332725048, 51.90110340714455, 51.72417350113392, 52.97108419239521, 46.88011363148689, 46.328121051192284, 44.12154145538807, 46.542706936597824, 50.84481708705425, 56.3263763487339, 50.287379398941994, 47.04441301524639, 41.00638881325722, 42.047928124666214, 41.20929792523384, 41.67030058801174, 39.68483492732048, 41.3742470741272, 40.44752240180969, 46.220735013484955, 45.9211552888155, 44.174233227968216, 42.727160677313805, 44.23881456255913, 47.06602245569229, 48.87725226581097, 46.63653910160065, 51.13679721951485, 48.325301483273506, 52.05767400562763, 51.97576940059662, 50.75804114341736, 50.97198486328125, 53.09986308217049, 47.65059448778629, 50.55266596376896, 48.001235872507095, 48.59886020421982, 49.677933901548386, 45.67645601928234, 50.26057183742523, 52.53770984709263, 52.481419667601585, 56.84306122362614, 58.44382032752037, 64.03910368680954, 62.362436056137085, 60.90442769229412, 56.47119037806988, 62.36085534095764, 52.144286558032036, 51.76614984869957, 58.14952231943607, 47.829302698373795, 59.654169380664825, 58.17762941122055, 48.68516117334366, 58.953851759433746, 59.68667283654213, 57.25767597556114, 60.59003636240959, 47.09593445062637, 50.29807962477207, 51.523631662130356, 62.500908225774765, 57.201974764466286, 68.27716067433357, 58.486408442258835, 60.23375608026981, 58.0649920552969, 70.23496761918068, 93.12453657388687, 36.5351003408432, 0.976440254598856, 0.43194600788410753, 0.24266554741188884, 0.2698155655525625, 0.14677564438898116, 0.24902990902774036, 0.18391186808003113, 0.33876892179250717, 0.23049871902912855, 0.5313692463096231, 0.8177640347275883, 12.186129447072744, 46.96057431399822, 43.70359428226948, 46.94878354668617, 49.2351208627224, 4.910687869414687, 0.13397531874943525, 0.31711432908196, 7.510712128132582, 94.70934793353081, 60.54921135306358, 83.21545869112015, 100.9367273747921, 40.117662101984024, 0.34439552924595773, 0.22715529921697453], [0.06601860746741295, 0.1477854698896408, 0.20362261275295168, 4.571963120251894, 53.28057758510113, 57.3294997215271, 24.40535131841898, 30.020819194614887, 19.371533431112766, 1.3277456536889076, 2.0422353269532323, 20.58968536555767, 45.7752089202404, 30.379468649625778, 27.377251647412777, 16.523324064910412, 0.3867244266439229, 0.039540362849947996, 0.1730663000489585, 0.1205973573087249, 0.09464977425523102, 0.0427897043118719, 0.07841228813049383, 0.03249316228902899, 0.09726521398988552, 0.04214691165543627, 0.05073009444458876, 0.10219329720712267, 0.06523282892885618, 0.09870828303974122, 0.033985799382207915, 0.03458497601968702, 0.18779664009343833, 0.06133149960078299, 0.032236078623100184, 0.05016575050831307, 0.0931134914571885, 0.8376293093897402, 4.272931516170502, 21.727196127176285, 41.718470603227615, 52.710566371679306, 57.10057720541954, 59.90855053067207, 57.46623918414116, 58.606744185090065, 67.19393759965897, 61.165443286299706, 59.35866303741932, 62.75495879352093, 63.57830621302128, 62.071238681674004, 63.239721581339836, 61.27749927341938, 61.099524423480034, 59.346404895186424, 58.89655463397503, 50.43662019073963, 53.143180757761, 53.89921098947525, 56.75466276705265, 54.973318353295326, 51.22600883245468, 49.14454512298107, 48.26470613479614, 49.5674092322588, 50.80194018781185, 49.00640353560448, 49.81966249644756, 50.24688497185707, 48.954916298389435, 48.52284908294678, 47.883814573287964, 47.09380656480789, 46.0081972181797, 43.53933669626713, 46.51201218366623, 45.472653955221176, 43.46787393093109, 42.30444855988026, 42.82091684639454, 46.09503395855427, 41.26145772635937, 43.37471053004265, 47.70006023347378, 50.433834940195084, 49.028567746281624, 46.66800521314144, 44.016199707984924, 40.09876191616058, 36.85200333595276, 35.421881675720215, 35.59717386960983, 38.382515609264374, 39.365952238440514, 46.544576436281204, 41.245479583740234, 39.1574764251709, 38.36174972355366, 38.40756766498089, 40.948419123888016, 43.92018266022205, 44.55688789486885, 45.854085087776184, 45.55991627275944, 46.65842592716217, 47.32017181813717, 45.80138951539993, 45.485516265034676, 47.40493766963482, 45.650115832686424, 44.74183917045593, 44.22158248722553, 43.175669610500336, 43.564742133021355, 43.722543865442276, 42.120424434542656, 47.00419597327709, 47.87712313234806, 48.46813581883907, 55.138218104839325, 56.890608072280884, 57.84073568880558, 56.844535544514656, 55.057833418250084, 55.13267420232296, 45.54303377866745, 44.68088284134865, 48.821288868784904, 47.070065438747406, 52.724842205643654, 57.77184918522835, 42.66875021159649, 54.81597259640694, 55.615016520023346, 59.31810401380062, 51.29994906485081, 50.63696064054966, 41.448943465948105, 17.95846715569496, 43.34681622684002, 48.13138268887997, 51.853218376636505, 61.373261734843254, 61.24897800385952, 67.66763538122177, 71.15463986992836, 29.192978516221046, 0.27882966154720634, 0.04812674429558683, 0.107186362874927, 0.006653683249169262, 0.10125929693458602, 0.025033394413185306, 0.19597964943386614, 0.03793534233409446, 0.055045890985638835, 0.007397819417747087, 0.12869814410805702, 0.17727191734593362, 3.152609132230282, 23.60538974404335, 16.40183698385954, 23.501640111207962, 33.56395237147808, 3.795656939037144, 0.20034984539961442, 0.07184097863500938, 0.11097359441919252, 42.61134669184685, 66.2928919494152, 45.692392364144325, 87.07203134894371, 57.18566603958607, 2.1749472431838512, 0.1584792835637927, 0.09401079994859174, 0.1288548411685042, 0.1041392603656277, 8.462981879711151, 74.70906794071198, 78.87419164180756, 39.64945122599602, 42.735649421811104, 21.16410244256258, 0.13417762820608914, 15.428320672363043, 44.140874817967415, 59.9391882866621, 42.15281009674072, 34.73291024565697, 21.627105697989464, 0.4353756207274273, 0.16412922414019704, 0.1251264099846594, 0.11411228537326679, 0.07757373547065072, 0.06766685066395439, 0.006201030219017412, 0.03454266618064139, 0.09679900424089283, 0.0870870148355607, 0.11354355534422211, 0.03910750150680542, 0.07502912631025538, 0.028117971669416875, 0.07760486114420928, 0.07254059382830746, 0.016189792004297487, 0.06981759463087656, 0.00978929707343923, 0.0997391038981732, 0.10510431951843202, 0.816309544024989, 4.386487472802401, 22.15217862278223, 46.63022764027119, 56.21454834938049, 62.96878471970558, 66.04047149419785, 60.76063580811024, 59.82588216662407, 70.1902288198471, 61.80097818374634, 64.00372758507729, 66.37963369488716, 67.69661262631416, 64.63627964258194, 66.07619717717171, 63.45380209386349, 63.34048457443714, 60.2806493639946, 59.3426088988781, 54.08304512500763, 54.90828864276409, 59.0519092977047, 60.28049357235432, 59.04295317828655, 52.428758293390274, 54.07975070178509, 52.021522745490074, 52.71314263343811, 53.967816308140755, 52.01029434800148, 53.2398247718811, 53.07294152677059, 52.14046776294708, 52.48583883047104, 49.54722471535206, 48.39408919215202, 46.76830843091011, 47.50090152025223, 49.13495063781738, 48.892953023314476, 46.58202722668648, 43.27257961034775, 46.9530925154686, 47.68272176384926, 41.83532573282719, 42.56025843322277, 46.686453223228455, 50.7039700448513, 49.55588445067406, 48.011020347476006, 45.39981186389923, 40.42207896709442, 38.380330726504326, 37.75333397090435, 36.77742473781109, 38.815118595957756, 39.803373366594315, 48.689625933766365, 42.594392001628876, 42.378897964954376, 39.73371170461178, 40.49043729901314, 45.09923279285431, 46.94440618157387, 46.56700663268566, 47.43638478219509, 47.37840749323368, 49.68027077615261, 49.497006610035896, 50.73039382696152, 47.988920733332634, 48.25570821762085, 47.54061698913574, 47.88188047707081, 45.22597499191761, 46.83679215610027, 47.07853138446808, 47.969146594405174, 45.646034851670265, 48.5635980963707, 50.19257448613644, 52.63040207326412, 59.10808548331261, 57.93350011110306, 57.589409574866295, 57.9434859752655, 58.42164471745491, 59.302509650588036, 45.74629247188568, 45.39511911571026, 50.33670835196972, 48.47705014050007, 52.540088519454, 59.119291082024574, 44.78673376142979, 61.405582800507545, 61.46172098815441, 61.91762052476406, 58.64356800913811, 54.114093258976936, 32.57498323917389, 10.834499225020409, 45.587878972291946, 53.68348516523838, 58.9208847284317, 67.5505256652832, 68.80516514182091, 74.73282426595688, 66.81444436311722, 25.698659420013428, 0.18056733504636213, 0.08282935814349912, 0.06477116112364456, 0.03778102756768931, 0.06138544631539844, 0.02331198102183407, 0.1682532942504622, 0.07039703385089524, 0.044981451937928796, 0.0534741112642223, 0.18182836269261315, 0.25723188766278327, 6.1152232345193624, 35.57729713618755, 18.437585346400738, 36.85387663543224, 43.748492673039436, 5.005142726004124, 0.4029279149835929, 0.15226339601213112, 0.15102636942174286, 38.83079655468464, 70.89696809649467, 55.586742237210274, 88.95236805081367, 74.94498208165169, 3.814625758677721, 0.16231874004006386, 0.18304693949175999, 0.32303729094564915, 0.2085258933948353, 4.777370123192668, 81.6675965487957, 93.61404150724411, 50.390676856040955, 71.81921660900116, 49.72439780831337, 1.8501600273884833, 40.910447761416435, 62.45339557528496, 78.93014743924141, 50.735021978616714, 44.9742840975523, 32.406013906002045, 0.7810751628130674, 0.2801182377152145, 0.5783022497780621, 0.24581597914220765, 0.1282047643326223, 0.23026941023999825, 0.17517981788842008, 0.1815376040758565, 0.2722458023345098, 0.227377706032712, 0.2254419622477144, 0.15522311063250527, 0.14417481754207984, 0.20589313935488462, 0.17003094573738053, 0.13390854030149058, 0.24516726785805076, 0.27450472174678, 0.09190183147438802, 0.07397611523629166, 0.17768498189980164, 1.1786117311567068, 15.995249301195145, 44.68980096280575, 53.113796934485435, 64.51745241880417, 65.18836721777916, 68.99999588727951, 59.301943480968475, 61.76942467689514, 73.7668476998806, 62.99472592771053, 65.4449674487114, 71.54262945055962, 69.25481021404266, 69.70823228359222, 68.84624853730202, 67.64675170183182, 64.4759814441204, 64.13805037736893, 61.82359836995602, 55.80137372016907, 60.24754174053669, 59.01861548423767, 62.90832996368408, 62.161012664437294, 55.82579120993614, 55.09457364678383, 54.628422260284424, 55.981613248586655, 57.469032034277916, 53.547460064291954, 54.13191810250282, 55.90420380234718, 55.034878849983215, 56.27767436206341, 52.96800635755062, 50.824488177895546, 50.287371799349785, 48.469484746456146, 52.93059356510639, 51.026519536972046, 47.79129333794117, 46.266123577952385, 48.130463138222694, 50.58333031833172, 41.41219183802605, 46.67854584753513, 47.09309220314026, 54.12420451641083, 50.83858922123909, 48.87377165257931, 45.94494581222534, 43.30863207578659, 37.979551032185555, 40.700269639492035, 36.270216554403305, 39.12388622760773, 39.83561463654041, 52.19908341765404, 44.513612017035484, 45.96981167793274, 41.079420894384384, 42.951265051960945, 46.028583124279976, 49.23219881951809, 47.33487702906132, 50.649743154644966, 48.75978156924248, 53.09108555316925, 51.2502933293581, 52.57056288421154, 51.44793212413788, 52.729652747511864, 51.42050139605999, 52.11659364402294, 48.45267444849014, 48.597621470689774, 47.2531396150589, 48.430947214365005, 48.49789202213287, 50.44949769973755, 52.124117240309715, 55.24291768670082, 62.9380139708519, 60.203384310007095, 62.291262075304985, 62.78221093118191, 59.09049242734909, 59.63061444461346, 45.04323899745941, 43.957606852054596, 49.95686173439026, 46.691332161426544, 52.90236487984657, 61.41401834785938, 43.908642679452896, 58.647151216864586, 60.25438517332077, 60.40407054126263, 54.37379792332649, 47.69311040639877, 44.39149037003517, 29.03776064515114, 54.30505581200123, 58.31097565591335, 62.95903444290161, 69.29655477404594, 70.99858984351158, 76.30503550171852, 74.5982962846756, 26.034804582595825, 0.3755376784829423, 0.20254455419490114, 0.2415372454561293, 0.12326162293902598, 0.1985655294265598, 0.10934375648503192, 0.29103481443598866, 0.19330533512402326, 0.25539795169606805, 0.08807665391941555, 0.26038411539047956, 0.48508853127714247, 10.872096307575703, 48.66714634001255, 28.25808808207512, 52.51413211226463, 56.97459116578102, 7.781623341143131, 0.5645548843313009, 0.3206548484740779, 0.23769824911141768, 60.7445702701807, 84.1213908791542, 66.78514793515205, 104.40297737717628, 79.71097514033318, 3.0557706160470843, 0.23486000922275707], [0.1337474794127047, 0.1513025225722231, 0.19301459135022014, 24.229428358376026, 80.48691630363464, 44.523696675896645, 34.30775485932827, 38.13178986310959, 2.66118838917464, 0.590234559495002, 14.834607280790806, 25.875509530305862, 82.31834962964058, 71.30369827151299, 32.734065502882004, 13.601566795259714, 0.5948845006059855, 0.22754856327082962, 0.030956565933593083, 0.11007135064573959, 0.02606636749987956, 0.03313958033686504, 0.031113557997741736, 0.04957573568390217, 0.12564575008582324, 0.04276081992429681, 0.08803600649116561, 0.03878266717947554, 0.1153090430307202, 0.047707159974379465, 0.05067649653938133, 0.06794132656068541, 0.05422720190836117, 0.07980762966326438, 0.042750047650770284, 0.02760075596597744, 0.05962468982033897, 0.16451475501526147, 0.25128683948423713, 1.7862481693737209, 23.98294698446989, 39.50746804475784, 46.83736972510815, 52.74906970560551, 54.87781807780266, 57.61671870946884, 65.40601193904877, 57.1868933737278, 59.05500993132591, 63.44222791492939, 63.692026510834694, 60.774550661444664, 62.204592525959015, 61.643013060092926, 61.94032430648804, 58.44721734523773, 56.653572991490364, 52.29222781956196, 56.17968901991844, 58.66748012602329, 62.01905608177185, 53.084048330783844, 48.882362991571426, 49.96597744524479, 48.140711188316345, 46.338661685585976, 47.210046127438545, 47.142474353313446, 50.28775177896023, 50.40987342596054, 48.71232971549034, 49.60707150399685, 48.43793883919716, 44.07863795757294, 47.140278071165085, 45.83624504506588, 47.51961171627045, 47.171045020222664, 43.05846109986305, 42.222726345062256, 44.66398134827614, 44.955269917845726, 40.586518943309784, 44.09121908247471, 46.16092622280121, 45.34182317554951, 47.744529247283936, 44.11176078021526, 40.7919055223465, 38.86757858097553, 37.96986535191536, 37.186518386006355, 38.838741928339005, 38.77644047141075, 42.7339281141758, 46.231693625450134, 39.7195840626955, 37.4408957362175, 35.505583584308624, 38.550265207886696, 42.56801001727581, 42.13165283203125, 44.095151871442795, 44.032466635107994, 44.61430661380291, 45.38777410984039, 44.61269550025463, 42.84621208906174, 43.62451672554016, 43.43542367219925, 45.614382550120354, 45.127279087901115, 45.06608337163925, 45.03203719854355, 43.296981900930405, 47.78606861829758, 44.25881288945675, 46.10181279480457, 50.30795529484749, 48.464054837822914, 55.60329794883728, 55.27414061129093, 54.84075486660004, 51.14904396235943, 57.77835823595524, 56.09147675335407, 51.05073183774948, 46.953502893447876, 49.94853638112545, 39.26125645637512, 44.6599193662405, 45.14821216464043, 41.86480455100536, 48.071836084127426, 50.35604551434517, 53.59435714781284, 58.75215858221054, 34.69260200858116, 5.306352563202381, 0.8430806512478739, 15.59453135356307, 43.397209122776985, 28.716634176671505, 20.038585737347603, 25.08201900869608, 25.44873733073473, 5.993333850055933, 0.6891282310243696, 0.19058527483139187, 0.04428158812515903, 0.03329122337163426, 0.049907542488654144, 0.0767126734717749, 0.16174121556105092, 0.0836779223755002, 0.05169181393284816, 0.1602573654963635, 0.01982968682568753, 0.3087648411747068, 0.127487137215212, 4.375829994678497, 26.602038145065308, 31.641065552830696, 38.32044593989849, 38.42677943408489, 3.107210830785334, 0.12141466970206238, 0.28944326390046626, 0.39056147856172174, 8.717121742665768, 65.23814454674721, 63.67158740758896, 64.70897734165192, 91.47001415491104, 8.096471596509218, 0.3091295622289181, 0.11488229327369481, 0.19725627702428028, 0.413347787107341, 33.375653475522995, 97.06026658415794, 56.115282475948334, 44.71896439790726, 47.939812168478966, 0.08392913194256835, 0.7046412548515946, 32.23411872982979, 45.390426367521286, 102.1746401488781, 81.10874533653259, 39.45256859064102, 20.033125430345535, 0.6432672450318933, 0.2477952276240103, 0.017276810140174348, 0.20811588648939505, 0.018535179042373784, 0.03294087771791965, 0.06335705067613162, 0.07129664300009608, 0.1376565344980918, 0.05630693347484339, 0.05658961381413974, 0.11482427216833457, 0.07834364689188078, 0.16542688419576734, 0.07926878592115827, 0.12330177312833257, 0.1356687067891471, 0.08841821996611543, 0.02539736218750477, 0.06617805047426373, 0.07344041820033453, 0.10563885138253681, 0.2903946675360203, 1.6223582136444747, 20.581576600670815, 41.96417301893234, 49.587130174040794, 56.51805326342583, 55.960733368992805, 59.63343769311905, 68.82116988301277, 62.08571970462799, 62.61239804327488, 66.578948199749, 67.23410904407501, 64.96894419193268, 64.90260735154152, 64.87573519349098, 64.93160739541054, 60.81751495599747, 58.43772545456886, 55.81826761364937, 60.59592604637146, 61.829385459423065, 64.60269704461098, 54.906935915350914, 51.83736942708492, 52.725271582603455, 51.103267818689346, 49.03426744043827, 51.26660965383053, 48.791783452034, 51.86072677373886, 51.38120770454407, 51.455733105540276, 52.286471128463745, 52.199474796652794, 47.82257705926895, 51.31451368331909, 48.65237653255463, 50.33396489918232, 48.48688021302223, 45.89094690978527, 44.39171835780144, 47.47332260012627, 49.347024857997894, 40.950262024998665, 41.83642007410526, 45.99702961742878, 46.909657046198845, 47.81969301402569, 43.36108826100826, 41.89363740384579, 38.885388225317, 39.58920545876026, 36.66273929178715, 39.47508618235588, 38.730155155062675, 45.506000965833664, 49.3202780932188, 41.61612689495087, 39.755849316716194, 40.0536697357893, 40.88588587939739, 44.93816703557968, 45.50066985189915, 46.38534598052502, 46.32558658719063, 46.64701133966446, 48.36503215134144, 47.58620694279671, 45.970947816967964, 46.1303074657917, 46.47000923752785, 49.2173720151186, 46.54888540506363, 47.7368688583374, 47.42148958146572, 47.67937034368515, 51.205835714936256, 51.05843782424927, 48.52034501731396, 52.79462166130543, 49.49189968407154, 58.03245820105076, 57.648089826107025, 58.26934888958931, 56.78402379155159, 60.557753294706345, 59.63368847966194, 53.94160911440849, 49.67207461595535, 48.97634334862232, 39.22502540051937, 47.56089650094509, 50.35537675023079, 43.59234005212784, 49.77790653705597, 54.740159064531326, 56.277955546975136, 50.63616268336773, 18.409926630556583, 1.6834206995554268, 0.8313395781442523, 9.901228453963995, 37.635798677802086, 31.693044863641262, 21.696015000343323, 23.082307912409306, 16.576234325766563, 3.276340705342591, 0.7441689900588244, 0.10526726546231657, 0.02625672466820106, 0.05504590953933075, 0.0047133692260104, 0.09641824537538923, 0.0907484300842043, 0.08335104343132116, 0.08696115401107818, 0.08081195584964007, 0.04718040210718755, 0.28481683402787894, 0.2395756749319844, 6.935137063264847, 38.193338960409164, 31.537654101848602, 55.62949754297733, 53.88837397098541, 4.496012320742011, 0.28122955933213234, 0.09549820490065031, 0.3614323306828737, 6.64205071516335, 68.2837039232254, 72.63297334313393, 69.20789033174515, 102.48286440968513, 12.68780892714858, 0.301917667966336, 0.1916443492518738, 0.3159266256261617, 0.6277309474535286, 29.69890806823969, 115.83910971879959, 69.12635430693626, 60.34911409020424, 82.14113473892212, 8.892735969275236, 2.0136444736272097, 58.51802654564381, 59.074974060058594, 104.52977657318115, 86.29935801029205, 53.440545201301575, 29.297818690538406, 1.0315323108807206, 0.37158357503358275, 0.0694232618843671, 0.47888628439977765, 0.13456909626256675, 0.11571886439924128, 0.13393228902714327, 0.15186797973001376, 0.23537458473583683, 0.23648351663723588, 0.14969571348046884, 0.24058640585280955, 0.2658680226886645, 0.26476355851627886, 0.26534273056313396, 0.23217965383082628, 0.3151820437051356, 0.1474741389392875, 0.11127892139484175, 0.15964050719048828, 0.1431597673217766, 0.327782939421013, 0.3992482280591503, 14.011527746915817, 44.71885800361633, 51.66113868355751, 58.34078885614872, 65.38524985313416, 59.48291257023811, 60.86113281548023, 71.1215740442276, 63.62192787230015, 66.15727722644806, 66.97671085596085, 70.99950939416885, 65.70616543292999, 68.80878254771233, 67.054363489151, 65.82015931606293, 62.73547723889351, 62.52282164990902, 58.683724254369736, 64.03601065278053, 65.56300431489944, 67.43026211857796, 57.62520745396614, 53.38476039469242, 54.72928784787655, 53.926998898386955, 53.427116721868515, 54.753861129283905, 52.25870981812477, 54.94944803416729, 55.2308115363121, 55.07762275636196, 56.561948508024216, 54.37609679996967, 49.83917824923992, 53.99130664765835, 52.480211332440376, 53.81748877465725, 51.571368500590324, 47.65393450856209, 45.14206409454346, 49.59892474114895, 48.97934518754482, 42.411165833473206, 45.704981088638306, 48.181957975029945, 47.55019627511501, 49.20782312750816, 46.017795503139496, 41.23701363801956, 40.29581554234028, 39.18243728578091, 37.69899308681488, 40.55563040077686, 39.57507021725178, 45.65662108361721, 53.110187128186226, 43.210202157497406, 42.48007133603096, 40.177516490221024, 42.9593700170517, 47.80887879431248, 47.7173987030983, 48.9401388913393, 48.58375981450081, 49.133305326104164, 51.65258914232254, 48.25222760438919, 47.54892334342003, 48.287664502859116, 48.88435788452625, 50.77669054269791, 51.73315241932869, 49.61062051355839, 51.00760795176029, 48.604723289608955, 52.69368387758732, 51.00265681743622, 51.44136607646942, 54.666427820920944, 52.17867471277714, 60.50185069441795, 60.15573866665363, 60.899430960416794, 57.46943101286888, 61.960174441337585, 61.18662714958191, 51.936072930693626, 49.20765593647957, 50.81092290580273, 39.386843517422676, 48.508242666721344, 50.511742159724236, 41.98731757700443, 50.59049293398857, 52.97865338623524, 55.768931061029434, 58.78622755408287, 38.74062739312649, 9.022547453641891, 1.1377424304373562, 24.94144555181265, 58.92261743545532, 51.23243048787117, 43.99025849997997, 33.89679171144962, 25.00608578324318, 5.9640749450773, 0.8183413068763912, 0.24070219573331997, 0.11212732235435396, 0.1295331641449593, 0.09235316858394071, 0.2028363072895445, 0.20761463994858786, 0.227298385289032, 0.21098750818055123, 0.28518630482722074, 0.16337149136234075, 0.6698982347734272, 0.8042101620230824, 10.437004454433918, 48.42706002295017, 50.21061211824417, 59.69717547297478, 63.31075116991997, 11.689945422112942, 0.6133045465685427, 0.27312028978485614, 1.1956033506430686, 14.641177710145712, 91.56452268362045, 77.50522390007973, 80.84330677986145, 111.06888368725777, 12.203048039227724, 0.6152065226342529], [0.17344393447274342, 0.1687484551803209, 0.7398638210725039, 48.662142008543015, 88.66598501801491, 44.447651356458664, 45.88606797158718, 25.949805043637753, 0.5209282971918583, 3.2003162847831845, 35.05517855286598, 32.11653023958206, 53.39691214263439, 31.02633073925972, 29.990261234343052, 14.787767194211483, 0.3242469026008621, 0.11586260356125422, 0.014200929927028483, 0.040447256178595126, 0.07496648162486963, 0.05229441187111661, 0.050089951255358756, 0.04161757853580639, 0.021971614078211132, 0.025745483253558632, 0.006730785435138387, 0.07847668428439647, 0.04591887351125479, 0.04155307477049064, 0.03995462968305219, 0.05589628461166285, 0.08283816001494415, 0.04157693481829483, 0.03945980643038638, 0.07261952123371884, 0.03152938334096689, 0.005984906611047336, 0.12279938368010335, 0.21179745846893638, 0.23738406831398606, 17.796922624111176, 32.92590580880642, 38.35794232785702, 45.380075722932816, 51.49357907474041, 61.393301859498024, 59.42511007189751, 57.61106461286545, 63.63824039697647, 65.11485636234283, 64.61047902703285, 60.97049854695797, 61.370408087968826, 63.409131690859795, 57.59613521397114, 57.4409781396389, 53.97894591093063, 60.099281296133995, 61.696985363960266, 64.0521065890789, 52.39419534802437, 54.38641704618931, 50.536292642354965, 49.82976235449314, 47.8917371481657, 49.47421543300152, 48.589588701725006, 47.61449262499809, 48.06414529681206, 47.89511516690254, 47.510237619280815, 49.063392877578735, 47.621089071035385, 48.28862585127354, 47.22719080746174, 47.70482137799263, 45.35918064415455, 43.358105421066284, 41.60522148013115, 47.97612302005291, 52.8545368462801, 49.929529801011086, 40.996292755007744, 43.12551990151405, 40.761925131082535, 41.8818162381649, 37.9781299084425, 40.177911669015884, 37.972297221422195, 37.89091318845749, 37.96103082597256, 39.846660643815994, 40.97635142505169, 46.08389675617218, 48.707462176680565, 42.39411994814873, 40.10883517563343, 39.24489073455334, 40.688383877277374, 42.50010386109352, 41.108679324388504, 44.21870604157448, 44.41953286528587, 43.633446246385574, 43.41096058487892, 42.298342287540436, 44.479945823550224, 44.63503070175648, 45.43586812913418, 44.993009492754936, 47.082224786281586, 44.97072748839855, 45.08314065635204, 46.19757905602455, 45.5096335709095, 53.25253888964653, 50.25589428842068, 50.8073814958334, 47.635976672172546, 53.49670238792896, 53.812469244003296, 57.11455665528774, 55.94013087451458, 55.31104423105717, 54.27506022155285, 56.64980359375477, 51.94846786558628, 41.57335638999939, 41.37821026146412, 42.62119576334953, 36.59226447343826, 35.71820877492428, 39.006765112280846, 44.077650010585785, 33.64702731370926, 13.141195848584175, 0.9479413682129234, 0.3417437762254849, 0.0628645317920018, 0.2600729773985222, 1.5030884323641658, 2.473329557105899, 1.8561042146757245, 1.3679003552533686, 0.8170552540104836, 0.19684082275489345, 0.26911482971627265, 0.04381305545393843, 0.06877301435451955, 0.06374587668688037, 0.054478485690196976, 0.10314985876902938, 0.07428044773405418, 0.09202950313920155, 0.012093535733583849, 0.04251190730428789, 0.0300810673070373, 0.20108017808524892, 0.1978805271210149, 9.164908714592457, 30.77048286795616, 28.223724626004696, 34.24066185951233, 35.82215219736099, 4.0615474339574575, 1.4572936459444463, 0.14709096809383482, 0.059533138482947834, 0.6297193688806146, 40.302947759628296, 73.95385846495628, 58.372057378292084, 94.86830100417137, 15.851093586534262, 0.35241538484115154, 0.12653378915274516, 0.07981019749422558, 1.2016681814566255, 59.50753524899483, 107.60130375623703, 60.09295843541622, 58.43042604625225, 31.18293173611164, 0.7164212164934725, 5.349489273503423, 55.49589291214943, 46.2681944668293, 62.75348827242851, 41.89222387969494, 38.7649916857481, 22.073779329657555, 0.2878957969369367, 0.1103868376230821, 0.03251358990382869, 0.06850727353594266, 0.05096974135085475, 0.05415406696556602, 0.07792718330165371, 0.06087842586566694, 0.01908373935293639, 0.06775342219043523, 0.09321276855189353, 0.012419577906257473, 0.01988476902624825, 0.08931201067753136, 0.036632888004533015, 0.04918170721794013, 0.04142666104598902, 0.09425511496374384, 0.07869448236306198, 0.03977239532105159, 0.07478089275537059, 0.04963374565704726, 0.013224889771663584, 0.23794110951712355, 1.2676005810499191, 18.390256986021996, 39.24883872270584, 43.91123794019222, 50.305029451847076, 54.19980525970459, 62.936623245477676, 63.77311795949936, 63.51510800421238, 65.79253479838371, 67.82837435603142, 66.51790827512741, 63.77026051282883, 63.59917849302292, 64.98786717653275, 61.77770063281059, 60.30749872326851, 57.538165524601936, 64.86604571342468, 64.30530220270157, 65.8547754585743, 56.452400386333466, 58.55829678475857, 53.33458408713341, 51.50445409119129, 51.71122759580612, 51.182235181331635, 51.08223594725132, 50.290803015232086, 51.26601308584213, 51.65500961244106, 49.68408577144146, 50.7278935611248, 49.93987664580345, 48.05856339633465, 48.124588653445244, 48.196621388196945, 48.11834938824177, 45.91314531862736, 44.282288029789925, 51.36867977678776, 55.21857999265194, 53.71850788593292, 43.6707678437233, 44.94053430855274, 41.14702686667442, 41.87079302966595, 37.38308943808079, 40.05754552781582, 39.886440709233284, 39.59207430481911, 39.67410050332546, 39.247478395700455, 43.192441910505295, 50.6582622975111, 51.76462233066559, 45.00111825764179, 41.392972469329834, 42.34751544892788, 43.31390619277954, 44.4576296210289, 42.18789741396904, 45.86006596684456, 46.353632882237434, 45.78063502907753, 45.74915371835232, 45.73708936572075, 46.730701848864555, 47.38778539001942, 46.619576811790466, 48.576365411281586, 46.84876151382923, 47.19072416424751, 49.04174163937569, 49.65781018137932, 48.251794427633286, 55.712542086839676, 53.87915566563606, 53.26019547879696, 50.74923701584339, 56.13462723791599, 57.398792803287506, 59.642207622528076, 56.576543524861336, 55.90880535542965, 56.173996925354004, 59.36220824718475, 54.23870377242565, 46.53853476047516, 47.93856583535671, 45.72439044713974, 38.34045946598053, 35.79619958996773, 36.34535752236843, 31.82874508202076, 15.524171479046345, 2.6633172249421477, 0.9814993268810213, 0.10816364519996569, 0.018825412589649204, 0.6289389857556671, 0.46811870124656707, 1.2493217806331813, 0.9599461709149182, 1.0843384335748851, 0.7083575741853565, 0.27409630303736776, 0.34763203526381403, 0.045889469620306045, 0.020537363598123193, 0.033487076143501326, 0.06286400486715138, 0.10725913045462221, 0.034537575047579594, 0.04299650747270789, 0.03858633943309542, 0.029986855370225385, 0.11492090721731074, 0.03217645818949677, 0.36009213072247803, 14.054137710481882, 40.6696280837059, 29.67847466468811, 40.51089160144329, 47.63139791786671, 3.5157003113999963, 0.5790585873182863, 0.11469062621472403, 0.07809722417732701, 0.05724042908695992, 45.885649994015694, 77.43845388293266, 64.37979340553284, 103.68292361497879, 18.379176780581474, 0.4429180081933737, 0.3541483887238428, 0.2195690359803848, 1.2061341293156147, 62.944409027695656, 120.61830326914787, 66.6683878004551, 84.30485263466835, 58.144525587558746, 0.6807616143487394, 6.234779069200158, 75.10395795106888, 58.76568965613842, 72.82814607024193, 51.33472479879856, 49.53698426485062, 30.14939859509468, 0.6338340137153864, 0.28106717742048204, 0.0752317400474567, 0.16486110049299896, 0.16463395877508447, 0.19485008582705632, 0.18950786936329678, 0.12304314208449796, 0.11167936943820678, 0.17467472702264786, 0.13761384616373107, 0.14769382949452847, 0.07815851815394126, 0.19419377495069057, 0.14088499563513324, 0.1345028670039028, 0.20923845906509086, 0.17719834082527086, 0.20838748285314068, 0.16919064160902053, 0.21330254880012944, 0.26220884872600436, 0.3619850822724402, 0.32356279087252915, 10.100529659539461, 42.11060956120491, 45.37795163691044, 50.49811989068985, 54.95466135442257, 57.75201424956322, 67.05845966935158, 63.67433086037636, 63.60967732965946, 68.47843587398529, 70.27252480387688, 70.65711736679077, 65.36412298679352, 66.22646391391754, 68.35988983511925, 62.8652972728014, 62.90849715471268, 59.53001484274864, 65.51379695534706, 67.13945612311363, 71.69888466596603, 57.86205254495144, 59.1162246465683, 56.82855360209942, 55.91031387448311, 53.8612662255764, 56.38349488377571, 53.51376727223396, 52.83497169613838, 54.16076995432377, 51.938884779810905, 52.65803799033165, 54.82001557946205, 52.800321355462074, 52.375678941607475, 52.94806882739067, 52.082802057266235, 51.17614030838013, 49.090808406472206, 46.14870227873325, 54.192923828959465, 58.881914019584656, 52.79208339750767, 42.09335468709469, 44.81751590967178, 40.67618653178215, 41.96286968886852, 37.093632370233536, 41.12935021519661, 38.7321500480175, 39.95918020606041, 39.37642067670822, 40.37727937102318, 42.69711188971996, 50.79013042151928, 54.02119964361191, 47.104510590434074, 43.53655144572258, 45.40404103696346, 45.44162102043629, 45.7894429564476, 45.6877414137125, 47.61196196079254, 49.289598539471626, 48.165520057082176, 46.17919944226742, 46.349730491638184, 48.40894639492035, 49.28771384060383, 49.324670657515526, 50.65788231790066, 50.38361683487892, 48.955687656998634, 53.607341051101685, 52.431193962693214, 50.61670392751694, 56.81343801319599, 56.48599058389664, 56.13628014922142, 51.49235554039478, 58.378121852874756, 56.71151228249073, 61.15798428654671, 56.915546134114265, 59.17988643050194, 57.363804280757904, 61.57847732305527, 54.80323567986488, 48.80001001060009, 45.55267006158829, 45.529232919216156, 39.12515915930271, 40.58409087359905, 51.800256818532944, 56.47728905081749, 38.8646375387907, 16.760678328573704, 1.2580134579911828, 0.35074718529358506, 0.23991689959075302, 1.2698464980348945, 7.229744279757142, 6.476312158629298, 2.3507813829928637, 1.6631937911733985, 0.747839652467519, 0.437777180923149, 0.6463344523217529, 0.16336314962245524, 0.2186240890296176, 0.11109250874142163, 0.1477439986774698, 0.16073116741608828, 0.2679054258624092, 0.163775872788392, 0.23266975331353024, 0.21210919017903507, 0.23843186208978295, 0.6396402209065855, 0.601780180586502, 19.629636481404305, 50.96238657832146, 45.45086212456226, 47.791065350174904, 71.40101864933968, 6.396249504759908, 3.2616248074918985, 0.1108217732689809, 0.23342803528066725, 1.0472036199644208, 56.38338848948479, 90.03936052322388, 72.39265143871307, 115.42927131056786, 21.27293810248375, 0.5388300865888596], [0.2531191724119708, 0.10813306871568784, 2.1058550756424665, 63.08981582522392, 89.95543822646141, 55.83478532731533, 48.610244393348694, 6.262529455125332, 0.3814016841351986, 8.823031559586525, 47.84507565200329, 49.26909863948822, 78.08718547224998, 28.364356979727745, 27.179040983319283, 20.40846548974514, 0.1151727772958111, 0.13378564064623788, 0.07133562059607357, 0.0410084608301986, 0.015761379836476408, 0.011607451269810554, 0.02623482945637079, 0.03920381743228063, 0.049783845024649054, 0.04006171417131554, 0.029414674354484305, 0.021870329474040773, 0.06193712921231054, 0.040859474684111774, 0.031452378098038025, 0.05508309855940752, 0.07088902581017464, 0.05450010074127931, 0.030451393431576435, 0.03890784522809554, 0.03013653913512826, 0.045094247252563946, 0.003141200572827074, 0.11277593715931289, 0.18680468550883234, 2.915719631128013, 16.882380098104477, 28.048098050057888, 33.14551882445812, 46.64359912276268, 52.79769949615002, 58.354384526610374, 59.2442511767149, 61.20270408689976, 59.86304797232151, 60.72899490594864, 63.270898908376694, 61.717557460069656, 60.9712091088295, 61.16426154971123, 57.11920380592346, 62.6303368806839, 61.49957835674286, 64.26059380173683, 57.90226198732853, 57.6895722001791, 55.25273256003857, 51.363181471824646, 50.617722272872925, 47.71338231861591, 47.31266342103481, 51.187646090984344, 47.22405597567558, 45.808327943086624, 47.15527206659317, 45.13431631028652, 48.19643519818783, 45.20250365138054, 43.7833596020937, 43.68319697678089, 47.53188505768776, 45.320453122258186, 44.39215153455734, 46.0730255395174, 49.83689837157726, 53.69666665792465, 58.50784309208393, 48.738358318805695, 46.314726769924164, 47.433762922883034, 42.96704560518265, 39.59551692008972, 38.13349977135658, 40.48003725707531, 42.07495607435703, 43.226906061172485, 40.906013399362564, 46.02108232676983, 52.16991238296032, 50.62993101775646, 47.35351882874966, 41.66571423411369, 42.00111463665962, 44.48808118700981, 42.53522537648678, 40.351611748337746, 42.42354936897755, 41.270254254341125, 42.0767267793417, 43.64103443920612, 43.941005542874336, 43.35249312222004, 44.95191849768162, 43.2140551507473, 44.273894280195236, 44.42022442817688, 43.987043872475624, 45.00111825764179, 47.41631045937538, 49.144849106669426, 57.87817507982254, 55.41101686656475, 53.36089387536049, 54.04274828732014, 56.03904336690903, 56.8608632683754, 55.149047523736954, 52.57566221058369, 52.035844177007675, 53.94424997270107, 52.30382859706879, 51.04060918092728, 45.794067308306694, 40.86795464158058, 32.64700837433338, 25.362499058246613, 20.13498656451702, 12.175679057836533, 4.513142751529813, 0.9598028473556042, 0.7042320049367845, 0.30781842477153987, 0.022322590557450894, 0.07302033292944543, 0.12915705854538828, 0.2461232728092, 0.28724071802571416, 0.2742194995516911, 0.048702324347686954, 0.08651918280520476, 0.06428142529330216, 0.17132069449871778, 0.03563573096471373, 0.060386983095668256, 0.03928841855667997, 0.07274795731063932, 0.05002426747523714, 0.010651434258761583, 0.04907655231363606, 0.011122082050860627, 0.05870045621122699, 0.026454802027728874, 0.07601952980621718, 0.08724947838345543, 12.923460882157087, 32.91665330529213, 24.199257977306843, 21.784316562116146, 19.463053420186043, 4.761868380010128, 6.0036588460206985, 2.7021473413333297, 1.027138796634972, 0.5268802028149366, 50.44792838394642, 70.50143972039223, 70.58503523468971, 90.26345729827881, 12.57758729159832, 0.39316383423283696, 0.3050164313754067, 0.1999295226414688, 2.5506278593093157, 75.07057294249535, 106.27500012516975, 68.39952170848846, 64.23217132687569, 6.830737190321088, 0.39880347379948944, 12.42492763325572, 65.92920586466789, 56.58182144165039, 82.04896688461304, 35.87174333631992, 32.49559409916401, 31.53789158910513, 0.06202263946761377, 0.0954799925966654, 0.05686635326128453, 0.001971156057152257, 0.029657538470928557, 0.0478274398483336, 0.060033472182112746, 0.07295111281564459, 0.05333348912245128, 0.054692023841198534, 0.022978543347562663, 0.059223833595751785, 0.029511981047107838, 0.06544370276969858, 0.0679630195372738, 0.026897400348389056, 0.048595017215120606, 0.017560902415425517, 0.06582700720173307, 0.0902015934116207, 0.05066766498202924, 0.0393246205203468, 0.061557702501886524, 0.031673434205004014, 0.21303913090378046, 0.4849858477246016, 12.391965351998806, 24.15744312107563, 30.480273440480232, 48.382530212402344, 59.008097648620605, 64.7309173643589, 62.99696020781994, 67.53036394715309, 62.76139944791794, 64.80210274457932, 66.66163936257362, 63.33839848637581, 66.07286095619202, 65.98200023174286, 60.704904198646545, 64.08591717481613, 64.30943638086319, 64.6009111404419, 60.88960088789463, 58.97167280316353, 59.76464085280895, 56.45750731229782, 53.99281516671181, 50.42465083301067, 49.708890840411186, 52.01578885316849, 48.63009832799435, 49.02457416057587, 49.311523362994194, 49.251000210642815, 49.40738461911678, 47.53052473068237, 46.63250371813774, 47.69846811890602, 49.813069850206375, 51.54594786465168, 46.09683886170387, 49.181995913386345, 54.04708385467529, 56.04198060929775, 58.54734197258949, 51.97709172964096, 46.487055122852325, 48.080366626381874, 45.639981776475906, 41.06815069913864, 38.99552911520004, 41.431373208761215, 44.1045905649662, 45.35958342254162, 41.493431478738785, 46.7211377620697, 54.22493331134319, 51.212599352002144, 51.46328330039978, 45.37187196314335, 42.90985867381096, 45.96605747938156, 45.00557541847229, 44.00886990129948, 43.24574925005436, 43.604419603943825, 44.615974724292755, 45.59250332415104, 44.32414658367634, 45.15184096992016, 44.26051139831543, 46.082794815301895, 46.542125567793846, 45.86859650909901, 47.76092156767845, 47.394651621580124, 50.77712371945381, 54.50129248201847, 61.72695815563202, 61.163642182946205, 55.212872698903084, 58.46300929784775, 59.064076244831085, 58.99215370416641, 56.76435224711895, 55.772198885679245, 55.97544997930527, 57.568149715662, 55.53748928010464, 55.37068963050842, 52.45634861290455, 40.58442145586014, 28.970166072249413, 20.632505267858505, 10.673781149089336, 5.978113766759634, 0.20215574302710593, 0.48340044217184186, 0.13287137408042327, 0.057680173849803396, 0.009592255009920336, 0.04642470652470365, 0.06073066426324658, 0.2087224437855184, 0.16158091166289523, 0.18304769648239017, 0.05236492332187481, 0.12488261447288096, 0.166367304045707, 0.09894415983580984, 0.06335705067613162, 0.03504558255372103, 0.10218384224572219, 0.029041906564089004, 0.015746971039334312, 0.044690656213788316, 0.007343474726440036, 0.06858011533040553, 0.08924128400394693, 0.02513543044187827, 0.14759313489776105, 0.16963834961643443, 22.390102855861187, 40.12618884444237, 35.27386821806431, 27.878942526876926, 34.84414167702198, 1.6422981186769903, 6.175305135548115, 4.46465402841568, 0.5883630411699414, 3.2830860558897257, 66.13653793931007, 72.31698989868164, 77.3633623123169, 97.99623996019363, 12.510661482810974, 0.5837148218415678, 0.45768600481096655, 0.37537194206379354, 2.5215107342228293, 82.49262347817421, 116.5370486676693, 75.80056697130203, 93.4949178993702, 21.127544604241848, 0.6394378817640245, 17.203417271375656, 80.07111981511116, 64.82877731323242, 97.18384355306625, 47.991561591625214, 41.10950767993927, 41.283055767416954, 0.28716671105939895, 0.24689161829883233, 0.18371917685726658, 0.09552975359838456, 0.13956838112790138, 0.14225419872673228, 0.1993763109203428, 0.13865858229110017, 0.10838879796210676, 0.15230188379064202, 0.14147777867037803, 0.13577202858868986, 0.1666034257505089, 0.12386775721097365, 0.1804346390417777, 0.25521271163597703, 0.20957665576133877, 0.12293009072891437, 0.1897625596029684, 0.19211694889236242, 0.11777175619499758, 0.15167098405072466, 0.12900479952804744, 0.4002828412922099, 0.21956067939754575, 9.104359913617373, 35.70480689406395, 44.37941461801529, 45.96837915480137, 53.31508733332157, 62.28131040930748, 67.62028232216835, 64.41504031419754, 69.73671555519104, 65.6208524107933, 64.63292062282562, 66.86793029308319, 65.30443578958511, 69.82017427682877, 68.01156252622604, 61.68897159397602, 65.84209933876991, 65.61507672071457, 67.04676389694214, 63.42807747423649, 62.826250568032265, 61.49364307522774, 56.232608780264854, 57.56602942943573, 53.829670920968056, 53.44174973666668, 54.99946475028992, 51.49618573486805, 51.60643681883812, 52.47949697077274, 51.84993155300617, 55.68774841725826, 50.54165795445442, 49.36574645340443, 50.17937779426575, 52.01538227498531, 52.731488049030304, 49.153045266866684, 49.6722836047411, 55.561678782105446, 58.78117002546787, 62.99275763332844, 52.36006557941437, 47.108473777770996, 51.1113765835762, 44.128191098570824, 40.26107020676136, 39.66876178979874, 41.790887117385864, 43.11640799045563, 43.8672249019146, 42.92852707207203, 48.22538584470749, 57.25964806973934, 54.364701211452484, 53.77020791172981, 47.56509147584438, 46.030125841498375, 49.567663818597794, 48.88116605579853, 45.71844756603241, 46.85650549829006, 45.412917360663414, 48.259656205773354, 48.77373822033405, 46.02259084582329, 49.20566864311695, 48.64221587777138, 48.95800933241844, 48.20488594472408, 48.00873667001724, 49.77539487183094, 50.61222396790981, 53.17227579653263, 53.40307921171188, 63.50949950516224, 63.37959587574005, 57.04565115272999, 57.36156240105629, 59.834161922335625, 61.149286553263664, 57.907900884747505, 57.67761804163456, 57.587703466415405, 59.34123337268829, 57.65187822282314, 59.7654540091753, 51.70260585844517, 47.76916712522507, 45.48944905400276, 40.484775602817535, 39.01223681867123, 25.62963042408228, 8.007274232804775, 1.2435444281436503, 0.9382877487223595, 0.37103361391928047, 0.13048533961409703, 0.16651185957016423, 0.18266357568791136, 0.46891410544048995, 0.4952441988280043, 0.29371678770985454, 0.15438289556186646, 0.19775008724536747, 0.2763749932637438, 0.19566854112781584, 0.15163654839852825, 0.09698050387669355, 0.15859732957324013, 0.16707320522982627, 0.1814576450851746, 0.0925954278500285, 0.1596396166132763, 0.15715011191787198, 0.084378309402382, 0.10410100265289657, 0.17965311300940812, 0.6713929201941937, 32.24708743393421, 51.92896731197834, 41.60600423812866, 30.672700814902782, 50.898097828030586, 7.689968459308147, 14.183070491999388, 3.8712289463728666, 1.7400156939402223, 1.7673076107166708, 75.87279349565506, 82.63423427939415, 84.99256253242493, 113.26975598931313, 18.089187741279602, 0.6825588585343212], [0.09078562652575783, 0.07272224189364351, 2.2637529904022813, 69.90285024046898, 82.58124232292175, 35.74884653091431, 35.97413644194603, 2.9517989326268435, 0.28342981939204037, 4.14253581315279, 58.455649092793465, 53.0998744815588, 71.21413707733154, 52.09827862679958, 29.4749765843153, 24.928045570850372, 0.2727520657936111, 0.20242386613972485, 0.04605223373800982, 0.06866100200568326, 0.02896498110203538, 0.010496421873540385, 0.014408883416763274, 0.05674524589267094, 0.02886080397729529, 0.1005768847244326, 0.020936102846462745, 0.028114576343796216, 0.02094721650792053, 0.016035280568758026, 0.06998534227022901, 0.08935834295698442, 0.17761336464900523, 0.11704094111337326, 0.2524733555037528, 0.04697051161201671, 0.033965141701628454, 0.03403692593565211, 0.018837242423614953, 0.08747411906369962, 0.08924152891268022, 0.1712010899791494, 0.09227102025761269, 2.2137319995090365, 6.6875651478767395, 22.030381858348846, 45.137166157364845, 50.80644674599171, 53.258124589920044, 59.30706560611725, 59.3110515922308, 62.39791475236416, 65.40024384856224, 62.710827961564064, 61.073944196105, 63.75598847866058, 60.5363604426384, 61.35275423526764, 62.31946796178818, 62.170534953475, 57.75064252316952, 58.85715074837208, 57.553034126758575, 51.79377056658268, 48.821144476532936, 47.985413521528244, 48.258653059601784, 49.42649759352207, 46.708465442061424, 47.388100773096085, 46.33360035717487, 45.30644327402115, 44.82262663543224, 45.98448649048805, 46.06778182089329, 44.94142726063728, 46.123783215880394, 45.75075723230839, 48.03290717303753, 48.22784051299095, 50.57022102177143, 52.21157714724541, 46.78771398961544, 47.645194977521896, 48.98348316550255, 44.89392600953579, 45.30575551092625, 43.01475204527378, 42.01984763145447, 43.20485584437847, 44.72226642072201, 44.34396632015705, 43.04426126182079, 44.944387301802635, 47.249552607536316, 48.76723296940327, 49.01026792824268, 47.32839457690716, 44.77543696761131, 41.6077521443367, 41.084353029727936, 40.2746544778347, 41.873012110590935, 41.44714616239071, 43.93328435719013, 43.392295986413956, 42.80108951032162, 42.438151985406876, 44.777420461177826, 44.065087884664536, 43.52976121008396, 45.301758125424385, 45.20628824830055, 43.01196679472923, 47.78890706598759, 55.49525834619999, 58.84849861264229, 59.50055502355099, 55.43012224137783, 54.45144675672054, 53.812237456440926, 54.6779678016901, 54.6133978664875, 54.6976887434721, 50.68806789815426, 50.078797191381454, 46.482639759778976, 44.470127150416374, 31.92475453019142, 17.379705011844635, 11.31526367738843, 6.66881600394845, 0.6170145131181926, 0.05352842163119931, 0.19450207793852314, 0.039026499798637815, 0.04982188380381558, 0.06662037048954517, 0.067199201148469, 0.06339114494039677, 0.05966863609501161, 0.02091571604978526, 0.04520290138316341, 0.10471142653841525, 0.0937196851009503, 0.051102044017170556, 0.03558699041604996, 0.07123885938199237, 0.019177383546775673, 0.077380858710967, 0.031265427387552336, 0.03792653304117266, 0.041351429536007345, 0.016804967490315903, 0.033495521784061566, 0.06417771015549079, 0.01797013006580528, 0.012322355632932158, 0.0691714660206344, 0.13250157673610374, 18.45249004662037, 33.603797033429146, 18.999402299523354, 18.15223205834627, 10.216036811470985, 2.6401064079254866, 6.4842029102146626, 7.095642350614071, 8.008346725255251, 26.509970985352993, 49.86759692430496, 58.75371649861336, 79.98872503638268, 71.5728910267353, 3.4698187233880162, 0.39337065594736487, 0.0998616918514017, 0.032711131061660126, 2.160750017501414, 74.8383218050003, 95.91189220547676, 42.71233007311821, 60.750634744763374, 2.257780423387885, 1.3117070705629885, 7.4923125654459, 74.49655294418335, 62.38424688577652, 78.60588043928146, 52.384201884269714, 30.739666521549225, 32.70082488656044, 0.40957527235150337, 0.31254691479261965, 0.04400591737066861, 0.035332982952240855, 0.016288948500005063, 0.0447241010988364, 0.026862781014642678, 0.05805276538012549, 0.021191885898588225, 0.07245333210448734, 0.02418306758045219, 0.027974969088973012, 0.11478465632535517, 0.06691029790090397, 0.07788881426677108, 0.072773390711518, 0.09357863251352683, 0.059585367125691846, 0.16693813435267657, 0.012019140995107591, 0.03837302021565847, 0.02082295686705038, 0.019721208955161273, 0.021896623766224366, 0.08896458908566274, 0.14975817262893543, 0.2238742494955659, 1.2006658664904535, 4.189211558550596, 18.15408445894718, 42.14915469288826, 54.45525795221329, 59.13262836635113, 62.111740708351135, 64.43855345249176, 64.93007987737656, 65.16553044319153, 65.55742621421814, 63.74163664877415, 65.58077216148376, 62.89540305733681, 65.0118362903595, 64.25032675266266, 62.86946564912796, 63.3983288705349, 62.241724133491516, 61.69169224798679, 53.06172072887421, 50.86127020418644, 48.60395573079586, 49.97673086822033, 50.59459291398525, 50.25924190878868, 50.33423848450184, 48.85667636990547, 48.483650386333466, 46.64753571152687, 48.860932141542435, 46.77487067878246, 47.29526795446873, 48.5675460845232, 49.80370335280895, 52.039624974131584, 51.25258840620518, 52.36037336289883, 55.433967635035515, 50.5596461892128, 51.06001473963261, 51.68160438537598, 47.88387157022953, 47.181885838508606, 43.55601780116558, 44.558821991086006, 45.58510132133961, 46.247987151145935, 46.402916237711906, 46.98683090507984, 44.98939588665962, 48.94554980099201, 48.73548947274685, 50.50255045294762, 50.26190936565399, 46.578774601221085, 43.32152858376503, 44.63140569627285, 42.57274456322193, 44.29640807211399, 43.94673943519592, 46.58923923969269, 45.3319551050663, 44.85856890678406, 45.98854847252369, 46.61173403263092, 45.68639248609543, 46.60354547202587, 46.8763480335474, 47.349783629179, 45.871955528855324, 48.43420743942261, 58.76733876764774, 58.96647088229656, 61.7984589189291, 58.41002494096756, 57.60961689054966, 55.91850623488426, 56.20586201548576, 57.36961416900158, 55.20306162536144, 54.182512387633324, 54.59709674119949, 51.27596095204353, 49.39063511788845, 27.269603423774242, 6.8715569749474525, 2.6024687150493264, 3.475358351133764, 0.5561234930064529, 0.13125163677614182, 0.1782820248627104, 0.07489778843591921, 0.08256826316937804, 0.07671718572964892, 0.07207779053715058, 0.08159223507391289, 0.11815712379757315, 0.04780640738317743, 0.023822344846848864, 0.10107050198712386, 0.11037229895009659, 0.09870608628261834, 0.026615623573889025, 0.0869282842904795, 0.027051568540628068, 0.03111677335255081, 0.018262163321196567, 0.04699369259469677, 0.02364471922192024, 0.04554876817564946, 0.03939520989661105, 0.0075056353853142355, 0.06939945378690027, 0.0851940707070753, 0.13752919679973274, 0.44948185910470784, 31.80025991052389, 40.25046497583389, 26.80383201688528, 22.834792993962765, 17.9118512570858, 18.964788056910038, 19.07632727175951, 10.069847255945206, 20.871527642011642, 46.51015028357506, 58.72953839600086, 69.36782374978065, 87.78884008526802, 73.11576023697853, 1.5834297775290906, 0.32389061234425753, 0.2197511590202339, 0.17726085934555158, 3.417815901339054, 86.10418528318405, 111.13946869969368, 56.62071995437145, 86.82166278362274, 7.9484225157648325, 1.4357841876335442, 17.50797662883997, 88.18929299712181, 76.89444467425346, 88.97044748067856, 65.97873240709305, 46.7028683423996, 45.54166205227375, 0.8326890401076525, 0.5257551663089544, 0.2288994798436761, 0.12726245942758396, 0.14732679293956608, 0.2257105306489393, 0.1465625737910159, 0.19167510385159403, 0.12869256315752864, 0.1930299389641732, 0.08051767945289612, 0.10407759531517513, 0.193453720130492, 0.14170109090628102, 0.1577007261221297, 0.249164504930377, 0.29297523375134915, 0.4240154178114608, 0.5066202243324369, 0.13097150571411476, 0.1471623923862353, 0.1332705159438774, 0.13812928256811574, 0.13419408904155716, 0.2655922109261155, 0.31714015582110733, 0.3698617033660412, 6.873829253017902, 17.066392824053764, 36.52639880776405, 54.60103712975979, 56.3912046700716, 58.90674948692322, 66.03583574295044, 64.43372771143913, 67.03245386481285, 68.78785327076912, 69.70118746161461, 65.87908655405045, 67.68839746713638, 66.99981361627579, 65.23934528231621, 65.3262922167778, 65.76434791088104, 64.31607842445374, 64.31183785200119, 62.884159460663795, 55.981905832886696, 54.896133095026016, 52.96010658144951, 52.2090844810009, 52.88714289665222, 51.44661359488964, 54.24150802195072, 52.10449889302254, 49.151855930686, 49.325236827135086, 51.875033006072044, 50.50854653120041, 50.57658948004246, 51.75616778433323, 52.190112099051476, 52.0719650387764, 54.434837847948074, 55.61144471168518, 58.61497834324837, 52.93573848903179, 53.149427622556686, 54.973823726177216, 50.82094296813011, 49.22720208764076, 45.195082649588585, 44.03695419430733, 50.29842160642147, 48.714142218232155, 48.10943886637688, 49.70685034990311, 48.81405785679817, 52.42349557578564, 52.49135613441467, 54.86032381653786, 53.9233510941267, 50.391269624233246, 46.125789508223534, 46.6959223151207, 45.91779626905918, 48.486918210983276, 46.058757305145264, 49.273365810513496, 48.01955468952656, 47.48797081410885, 47.36820884048939, 48.91536042094231, 48.06982979178429, 48.96405480802059, 51.022446155548096, 50.95941513776779, 48.968283981084824, 52.95526944100857, 59.62561771273613, 62.56232053041458, 63.01754370331764, 61.222964599728584, 60.09278744459152, 58.247933238744736, 60.44342502951622, 58.87896917760372, 56.628319546580315, 55.51270321011543, 55.43585233390331, 54.950420781970024, 54.957530200481415, 48.91894742846489, 46.037862226367, 29.59127314388752, 16.43768236041069, 3.0760662769898772, 0.21398934710305184, 0.37794648203998804, 0.22586589184356853, 0.20275977702112868, 0.11068854291806929, 0.21192868502112105, 0.1438781662727706, 0.15581215324345976, 0.24301536614075303, 0.1669454964576289, 0.22817150718765333, 0.14705121866427362, 0.1976860547438264, 0.18817851960193366, 0.1893075043335557, 0.06931717187399045, 0.26885190163739026, 0.12179384779301472, 0.10032490332378075, 0.17781224538339302, 0.1642575563164428, 0.09252737290808, 0.11588247827603482, 0.10387352696852759, 0.2025992059498094, 0.20623976684873924, 0.6551362643949687, 42.19081565737724, 52.621556147933006, 31.780164688825607, 26.81704580783844, 24.306435026228428, 24.04771450906992, 29.06165186315775, 15.285021811723709, 18.80499143153429, 52.104514092206955, 67.9832236468792, 77.71050408482552, 93.11779573559761, 95.06507724523544, 5.241289604455233, 0.6559688353445381], [0.06894400517921895, 0.0199464619072387, 1.0412153787910938, 46.35853461921215, 93.20703014731407, 42.45653159916401, 49.303498193621635, 7.485789740458131, 6.472295299172401, 6.920979022979736, 55.89242823421955, 55.214563608169556, 43.89567397534847, 38.581940308213234, 21.90265741199255, 15.896537248045206, 1.2163522560149431, 0.21086573658976704, 0.09928284634952433, 0.08888902360922657, 0.07160756576922722, 0.019305353926029056, 0.04215155007841531, 0.03489322705718223, 0.04142023404710926, 0.06641674001002684, 0.04487390360736754, 0.05211534276895691, 0.023232743769767694, 0.08959018246969208, 0.012112120966776274, 0.1065540307899937, 0.11015983691322617, 0.17625425476580858, 0.056367277502431534, 0.050054272505803965, 0.0202033247842337, 0.028824594592151698, 0.06474572030128911, 0.10398561353213154, 0.08050102565903217, 0.08131052323733456, 0.059038281833636574, 0.09865268133580685, 0.16479668207466602, 1.8520317832008004, 12.115849368274212, 32.891198471188545, 43.05125668644905, 50.92454060912132, 55.6909516453743, 59.04466308653355, 61.352655440568924, 60.6487812101841, 63.53145092725754, 61.23855136334896, 59.56012822687626, 63.67580898106098, 64.03148129582405, 59.296635165810585, 60.527491718530655, 64.2071382701397, 61.63654960691929, 49.292588979005814, 47.151202484965324, 48.582958057522774, 48.50270636379719, 48.680479824543, 48.50608438253403, 43.38760703802109, 46.60013325512409, 48.215985149145126, 43.744168505072594, 45.62079280614853, 43.576198518276215, 45.76867327094078, 44.95455555617809, 47.38079376518726, 49.48483966290951, 50.66425457596779, 48.941932395100594, 52.092825919389725, 52.036239355802536, 45.9161813557148, 49.277568385005, 46.008919179439545, 46.59457415342331, 42.77535729110241, 44.14170317351818, 44.503151178359985, 43.06806318461895, 46.200299710035324, 46.37862414121628, 47.13139034807682, 48.88064168393612, 47.81187683343887, 46.42736792564392, 50.712006613612175, 43.33179943263531, 42.16624237596989, 40.74959859251976, 41.955805867910385, 41.324766129255295, 42.66063764691353, 43.00670027732849, 43.67315411567688, 44.65536721050739, 43.260743245482445, 41.88057750463486, 44.315619841217995, 44.26142334938049, 44.04703505337238, 43.570460826158524, 43.811690881848335, 46.20081648230553, 56.70364290475845, 52.980435490608215, 54.61286969482899, 54.35430496931076, 51.09173163771629, 52.915033400058746, 52.076764181256294, 53.67742829024792, 49.536862671375275, 52.09063723683357, 48.701211512088776, 41.534172892570496, 28.299633152782917, 15.347353667020798, 4.4389868807047606, 1.0852065682411194, 0.19209619844332337, 0.17834123340435326, 0.0048231263735942775, 0.08095034412690438, 0.0646245943789836, 0.09120648363023065, 0.048727928442531265, 0.09627104780520312, 0.031004837073851377, 0.06392841532942839, 0.06935795288882218, 0.06623945577302948, 0.07757467057672329, 0.06740047159837559, 0.06931444077054039, 0.07747033203486353, 0.06547517725266516, 0.06778873357689008, 0.05520736005564686, 0.049423680757172406, 0.0789070111932233, 0.0035202657181798713, 0.024786335306998808, 0.010035990671894979, 0.03492641219054349, 0.08533806962077506, 0.12839407136198133, 0.06753082983777858, 0.48869355814531446, 25.3269861638546, 26.686368919909, 14.42686541005969, 13.485739510506392, 6.373784635215998, 10.072310473769903, 21.667351238429546, 25.695028714835644, 36.04189820587635, 44.879619777202606, 59.84699383378029, 78.70011538267136, 77.7074034512043, 31.911459043622017, 0.20016242342535406, 0.11234079371206462, 0.0656174543837551, 0.1065068227762822, 0.8432360866572708, 48.610871359705925, 113.25774103403091, 50.36995656788349, 72.99049615859985, 26.414833590388298, 7.514159018173814, 21.02799754589796, 64.6093162894249, 66.76836043596268, 49.66813802719116, 41.58812239766121, 28.804004788398743, 29.038545303046703, 0.9702082921285182, 0.29789834457915276, 0.057919453392969444, 0.17140258307335898, 0.03665288146294188, 0.04040067899040878, 0.11105473342468031, 0.028703819334623404, 0.05190873627725523, 0.039578323703608476, 0.007869847140682396, 0.006320477959889104, 0.0195788501878269, 0.05979989975458011, 0.019550637443899177, 0.018058180321531836, 0.20447088754735887, 0.29846507823094726, 0.027619385728030466, 0.02362243067182135, 0.08474350543110631, 0.038339849925250746, 0.003273832103332097, 0.0160972777302959, 0.040142092475434765, 0.06497280264738947, 0.03375380030774977, 0.015594713877362665, 0.39151828503236175, 0.9863344486802816, 6.324549727141857, 26.204208992421627, 41.93095900118351, 56.833428740501404, 59.959547594189644, 64.31344136595726, 62.963453605771065, 63.679069206118584, 64.91994962096214, 63.1765765696764, 60.094744339585304, 63.73651832342148, 66.05470553040504, 59.411054626107216, 62.37954653799534, 66.44446581602097, 63.031310364603996, 54.442589432001114, 49.607462882995605, 50.11915862560272, 52.30938009917736, 49.45017032325268, 48.50921541452408, 48.12814526259899, 49.61101949214935, 48.74301306903362, 45.947624668478966, 47.32767641544342, 46.01478986442089, 47.42872819304466, 46.492466032505035, 48.96913893520832, 52.20268562436104, 53.27226363122463, 50.901886224746704, 56.32379248738289, 55.2543930709362, 49.574233666062355, 51.680806428194046, 48.86343240737915, 49.01992700994015, 47.12115749716759, 47.64595873653889, 47.83962294459343, 45.37216454744339, 49.2220875620842, 49.02837015688419, 49.020318388938904, 50.88780038058758, 51.5667175501585, 48.374444246292114, 52.229892164468765, 47.07660868763924, 43.438524305820465, 43.09656925499439, 43.92407365143299, 43.47887434065342, 45.52006021142006, 43.833026736974716, 45.440735667943954, 43.43691699206829, 46.623228415846825, 44.80154536664486, 47.25558288395405, 48.48624564707279, 46.3249596208334, 45.35462848842144, 46.74558565020561, 49.446172937750816, 60.66522292792797, 58.57210524380207, 56.21303603053093, 57.4919980019331, 58.776815459132195, 54.48830857872963, 56.92496582865715, 53.36059369146824, 52.44045026600361, 56.78222268819809, 53.952423334121704, 45.40267691016197, 26.037709526717663, 8.678208030760288, 2.7252610260620713, 0.5370208492968231, 0.19312609161715955, 0.2953692834125832, 0.09219213738106191, 0.03827180240477901, 0.05548332766920794, 0.07934891560580581, 0.053111779925529845, 0.032546830698265694, 0.04466194994165562, 0.034171176739619114, 0.09366928585222922, 0.11657204478979111, 0.030908990556781646, 0.0683063741598744, 0.057342763830092736, 0.16831987974001095, 0.07315635375562124, 0.06008922973705921, 0.04204400916933082, 0.019850060634780675, 0.07481315391487442, 0.0749871801235713, 0.10622580113704316, 0.033307502380921505, 0.023468570470868144, 0.04569792501570191, 0.03328495964524336, 0.06272706377785653, 2.0792755018919706, 41.16972304880619, 31.70969747006893, 20.832665227353573, 13.9976204931736, 7.471268819645047, 17.94731665402651, 35.09876601397991, 43.12411017715931, 46.87970705330372, 57.24577881395817, 77.15122729539871, 80.21393895149231, 81.64772361516953, 17.772887013852596, 0.21516370674362406, 0.05818955432914663, 0.1805204461561516, 0.20273547910619527, 1.9120436254888773, 63.80526423454285, 129.02762442827225, 74.28071692585945, 85.25677755475044, 35.134354904294014, 6.605612570419908, 28.15708190202713, 81.30113661289215, 76.32358610630035, 58.60099509358406, 55.29051773250103, 35.72170078754425, 49.152376502752304, 2.651539519429207, 0.485789148369804, 0.1700825843727216, 0.3225587838096544, 0.10535109846387058, 0.10944039153400809, 0.1845876974402927, 0.126926266530063, 0.13450544967781752, 0.2634190837852657, 0.21003761852625757, 0.09102180018089712, 0.13063235906884074, 0.2069896922330372, 0.08324076028657146, 0.24072919506579638, 0.35099586413707584, 0.5529405700508505, 0.13590631278930232, 0.07173229110776447, 0.10821304997080006, 0.09906661420245655, 0.10761317942524329, 0.14760563266463578, 0.192214110866189, 0.3082144941436127, 0.18831240304280072, 0.1833506114780903, 0.45035578252281994, 5.267521971836686, 23.536009266972542, 45.633617118000984, 51.05005167424679, 61.678187772631645, 63.68492089211941, 65.27280628681183, 63.16776104271412, 65.15334829688072, 67.84071609377861, 63.16588394343853, 63.30959603190422, 65.75289532542229, 69.3655514717102, 61.97859205305576, 64.42616611719131, 69.0960319340229, 68.76172587275505, 53.814638927578926, 53.588543459773064, 53.491105288267136, 56.661009192466736, 52.69922398030758, 50.306081995368004, 48.595976158976555, 52.40252070128918, 52.85403527319431, 48.29255864024162, 49.690085649490356, 47.75978922843933, 50.86396425962448, 50.27310736477375, 52.06771306693554, 56.10423266887665, 55.566994696855545, 53.48672412335873, 57.187843322753906, 59.364043548703194, 50.86934857070446, 53.57008405029774, 51.27611294388771, 53.38561154901981, 48.18480022251606, 50.26884399354458, 48.218291625380516, 46.791886165738106, 51.67926371097565, 50.97998343408108, 49.781949520111084, 53.00595872104168, 53.104757219552994, 49.01934564113617, 56.68765336275101, 48.78600396215916, 46.52929745614529, 46.361969634890556, 47.510879784822464, 46.37759819626808, 48.61425697803497, 48.530684262514114, 51.4821682870388, 46.55106648802757, 50.339542999863625, 45.96538491547108, 50.5090519040823, 50.92310428619385, 50.681437253952026, 47.79679924249649, 48.38494688272476, 52.35135644674301, 62.86217384040356, 59.13290195167065, 59.67122666537762, 59.93448793888092, 56.011464446783066, 56.82061202824116, 58.367642015218735, 54.8944877833128, 55.21827220916748, 58.005255460739136, 58.72677594423294, 51.7041789740324, 50.54062820971012, 34.72853668034077, 11.184382550418377, 2.545486972667277, 0.8238415711093694, 0.6341540277935565, 0.1423634577076882, 0.1733909302856773, 0.18638390261912718, 0.3141894657164812, 0.15982285287464038, 0.2118703373707831, 0.10361396824009717, 0.1164036885893438, 0.16110804484924302, 0.15688595187384635, 0.2695772470906377, 0.139719185535796, 0.10659239982487634, 0.3318449214566499, 0.1267638846184127, 0.35665904462803155, 0.19456006935797632, 0.18267176899826154, 0.1967891544336453, 0.12443738523870707, 0.19839112472254783, 0.13859539583791047, 0.12039528533932753, 0.13120701885782182, 0.30551744042895734, 0.24703513481654227, 2.4023697897791862, 56.3262889534235, 41.9591648876667, 29.075139239430428, 17.012988589704037, 9.257143065333366, 22.881623581051826, 41.49989493191242, 46.438588723540306, 60.17559640109539, 66.95777267217636, 83.52731555700302, 89.89469468593597, 100.3376667201519, 45.78476160764694, 0.2790008601732552, 0.20858158415649086], [0.044440908677643165, 0.18404980364721268, 0.2044372831005603, 21.5998687595129, 73.93536865711212, 47.19792477786541, 49.68772977590561, 53.118770867586136, 27.236237414181232, 52.69467942416668, 55.1924791932106, 65.15381947159767, 40.608686953783035, 39.59646686911583, 32.50315569341183, 7.210725825279951, 3.706901064142585, 0.1636663021054119, 0.20123496040469036, 0.040550696721766144, 0.045828773072571494, 0.08591139354393817, 0.044466579565778375, 0.04756913163873833, 0.03504737855109852, 0.05431258599855937, 0.11200456370715983, 0.06514457272714935, 0.12090727817849256, 0.0543554710020544, 0.0383911842800444, 0.034691845285124145, 0.08325920265633613, 0.20107400341657922, 0.04825566276849713, 0.10947587361442856, 0.058334302811999805, 0.040823647505021654, 0.02713163699809229, 0.03782157109526452, 0.03154496844217647, 0.014792847432545386, 0.05014834343455732, 0.025618138133722823, 0.08322012858116068, 0.23462945362553, 0.26432233687955886, 2.804411966353655, 20.569445751607418, 38.603937327861786, 53.026021644473076, 55.77865853905678, 58.390015214681625, 58.78433905541897, 62.85953678190708, 58.482129871845245, 59.48343314230442, 60.49992799758911, 60.67034125328064, 59.20200504362583, 59.882578924298286, 62.291022688150406, 60.63999608159065, 51.657232493162155, 47.3845099657774, 47.236739695072174, 45.86269922554493, 46.644305884838104, 47.23377205431461, 46.03410802781582, 43.8099467754364, 43.492762595415115, 46.385266184806824, 45.12638233602047, 44.77821841835976, 46.74513727426529, 44.89645667374134, 41.70535750687122, 46.066030114889145, 47.53735676407814, 51.73321321606636, 54.22787435352802, 50.043048709630966, 47.220240980386734, 49.85424064099789, 47.72474370896816, 46.26630216836929, 47.99088902771473, 45.47311373054981, 47.95665666460991, 45.76270379126072, 46.86037369072437, 45.33076956868172, 48.79592142999172, 49.67083588242531, 51.919357627630234, 46.08610063791275, 45.230352357029915, 43.29633593559265, 41.595106422901154, 40.07172256708145, 41.01241149008274, 43.95575255155563, 40.76102077960968, 39.711688086390495, 42.68700063228607, 41.68193556368351, 41.68245993554592, 43.60679067671299, 41.80521234869957, 43.02937366068363, 44.02777388691902, 42.885270193219185, 43.89395646750927, 45.710426196455956, 55.08550353348255, 54.24470745027065, 52.03272454440594, 50.51892377436161, 55.650689005851746, 50.95881097018719, 53.00046041607857, 50.69970287382603, 49.86742593348026, 49.99800592660904, 39.7760908305645, 26.470057927072048, 13.132271077483892, 3.7901028245687485, 0.7031941856257617, 0.1487858107429929, 0.06415485200705007, 0.013018285135331098, 0.001711271015665261, 0.018398731481283903, 0.01526402400486404, 0.0584032223559916, 0.04497210458794143, 0.04284720962459687, 0.05393450257543009, 0.012940664837515214, 0.06591052107978612, 0.05881016048078891, 0.09652100314269774, 0.090235079114791, 0.011449426692706766, 0.057871807512128726, 0.07256806813529693, 0.027127037537866272, 0.10346377981477417, 0.04647443041903898, 0.025357848389830906, 0.04111061374715064, 0.03721208602655679, 0.04079217302205507, 0.052411381766432896, 0.013485975468938705, 0.03935746797651518, 0.21675968047929928, 1.9712985958904028, 37.348264306783676, 19.831470251083374, 16.30591493099928, 8.118118084967136, 8.13138697296381, 7.9907517693936825, 11.174866911023855, 16.06654867529869, 41.335492953658104, 65.60564562678337, 82.08270147442818, 66.96437671780586, 39.016386196017265, 0.34990918182302266, 0.10391987409093417, 0.04670452588470653, 0.08140280187944882, 0.14926360541721806, 0.12370668890071101, 17.73670345544815, 85.07989704608917, 63.14650118350983, 56.1630155146122, 72.19067707657814, 33.96222420036793, 68.39973449707031, 61.168779507279396, 70.58110624551773, 46.682585030794144, 40.02428591251373, 36.681989058852196, 19.077294319868088, 2.187739019282162, 0.13417090434813872, 0.09146310345386155, 0.12764601618982852, 0.0819612383202184, 0.12503885140176862, 0.0023036692937239422, 0.020929753773089033, 0.02660190497408621, 0.05263375518552493, 0.07636979382368736, 0.023341030537267216, 0.07178563668276183, 0.043969978869426996, 0.13451928331051022, 0.04889677817118354, 0.1097124331863597, 0.19894046243280172, 0.11184118731762283, 0.05045407116995193, 0.0187660778829013, 0.02278400417708326, 0.06041152591933496, 0.06774516208679415, 0.03564486680261325, 0.07970822640345432, 0.046670290612382814, 0.04909945128019899, 0.040568645563325845, 0.12802256707800552, 0.5446221039164811, 2.601208845153451, 14.350442960858345, 39.334489926695824, 57.128072530031204, 54.498416036367416, 60.33663935959339, 60.85495054721832, 66.76914319396019, 63.61577980220318, 62.8514090180397, 62.37807981669903, 62.476418539881706, 60.282173082232475, 63.49979482591152, 63.60321767628193, 65.7026544213295, 53.6013525724411, 50.31400837004185, 48.18545378744602, 48.99357922375202, 49.08999145030975, 49.09996211528778, 48.86866852641106, 46.79492600262165, 47.42575295269489, 48.376701325178146, 47.010047659277916, 47.956687062978745, 48.562233969569206, 48.05939935147762, 44.87316392362118, 49.6632856875658, 48.76407153904438, 52.98766270279884, 55.236439034342766, 52.20001436769962, 49.78807859122753, 50.571364760398865, 51.00239083170891, 47.64028184115887, 49.734091088175774, 49.83713395893574, 47.838213220238686, 49.488240480422974, 50.385368540883064, 48.77423219382763, 51.10182009637356, 52.19847925007343, 51.76247164607048, 49.12461519241333, 48.46974313259125, 45.55708922445774, 43.466445207595825, 43.56698781251907, 42.63665333390236, 47.11357310414314, 42.50213295221329, 43.9279380440712, 44.31402012705803, 44.05504882335663, 43.62148068845272, 45.74946150183678, 44.64240990579128, 46.2455552816391, 45.78981153666973, 46.364344507455826, 46.26617677509785, 49.454703480005264, 56.48222878575325, 56.70394688844681, 55.88504523038864, 52.73152604699135, 58.43834102153778, 55.714289993047714, 55.21535016596317, 54.86245930194855, 53.595611080527306, 54.53635320067406, 45.233130007982254, 22.547608204185963, 6.819208133965731, 1.5125778294168413, 0.49407320853788406, 0.1224814030865673, 0.11857883437187411, 0.042423988779773936, 0.027026389325328637, 0.054446996364276856, 0.05142833666468505, 0.07354598870733753, 0.05229123176832218, 0.0760301276750397, 0.051907318775192834, 0.008226961181208026, 0.03960494454076979, 0.10147186287213117, 0.06631446463870816, 0.07984106341609731, 0.049986588637693785, 0.10703420033678412, 0.09534880315186456, 0.01818191674828995, 0.05531703092856333, 0.07090495229931548, 0.014947202089388156, 0.05962195500615053, 0.06010823984979652, 0.04148258187342435, 0.03942418334190734, 0.033518231502966955, 0.1496634300565347, 0.46686931047588587, 6.962132239714265, 52.100767493247986, 29.534464292228222, 17.525404393672943, 7.219071602448821, 8.569931890815496, 7.878819275647402, 9.92496008053422, 18.327140472829342, 56.34469896554947, 73.92118781805038, 73.44429820775986, 62.900502383708954, 21.511721089482307, 0.44555120752193034, 0.0790198399045039, 0.011457880682428367, 0.15668033243855461, 0.4916972969658673, 0.8218061272054911, 34.99590553343296, 114.16568711400032, 94.61461901664734, 70.87883546948433, 81.39050781726837, 38.99370141327381, 81.19050934910774, 70.15565067529678, 83.90976503491402, 57.655875608325005, 54.21675994992256, 47.45471499860287, 37.55275793373585, 4.857159191742539, 0.2399608792620711, 0.1964903954649344, 0.22911881416803226, 0.2723386004799977, 0.4297605314059183, 0.1739636159618385, 0.13211249839514494, 0.0814221719338093, 0.19901356397895142, 0.2713434101315215, 0.17306564695900306, 0.15726020210422575, 0.1669311136356555, 0.13802368979668245, 0.16875451110536233, 0.22759568964829668, 0.46620093227829784, 0.22508507827296853, 0.17889015551190823, 0.18209246336482465, 0.1752710426808335, 0.17855495709227398, 0.20448731869691983, 0.13952618261100724, 0.23016197694232687, 0.19443534401943907, 0.19037398538785055, 0.2152390792616643, 0.46501319913659245, 0.9797659667674452, 12.752391211688519, 33.530916944146156, 51.092787981033325, 60.68264119327068, 62.13227480649948, 62.00920321047306, 60.15188567340374, 66.40766859054565, 63.310602977871895, 63.88700544834137, 64.02038589119911, 64.3960565328598, 63.066648468375206, 66.16784825921059, 66.00366666913033, 65.42058795690536, 58.39103735983372, 54.30156759917736, 50.024646297097206, 51.08643092215061, 52.437307834625244, 52.631192430853844, 52.05028340220451, 47.90573179721832, 49.845242723822594, 50.88332422077656, 49.87588427960873, 49.61502447724342, 51.10739819705486, 52.11455315351486, 47.291046380996704, 51.45713523030281, 50.844459906220436, 56.47619090974331, 60.41669726371765, 53.73646192252636, 52.74943068623543, 52.83540487289429, 53.5591596364975, 49.76499482989311, 53.55093687772751, 51.95196747779846, 52.142580449581146, 52.780581414699554, 51.161362901329994, 50.87114207446575, 55.11981949210167, 57.32321485877037, 55.835100710392, 50.92083960771561, 50.917769372463226, 48.16117309033871, 48.29324260354042, 45.35954162478447, 44.37770090997219, 51.99200592935085, 44.08294312655926, 45.17636485397816, 47.353739216923714, 46.45224519073963, 45.98764792084694, 51.20759502053261, 49.53117057681084, 49.45340394973755, 48.04474733769894, 48.003466352820396, 47.961634397506714, 51.20896674692631, 58.87735426425934, 59.94872957468033, 55.28439626097679, 55.288671031594276, 59.821444004774094, 58.92987124621868, 55.62325827777386, 55.59669770300388, 54.296133890748024, 57.013808861374855, 50.529004633426666, 45.824313685297966, 29.635200686752796, 12.027602903544903, 2.130245016887784, 0.3404569218400866, 0.3241421707207337, 0.15102049161214381, 0.19485085766064003, 0.2626231749309227, 0.1275086446548812, 0.18269584426889196, 0.15500549809075892, 0.15664272039430216, 0.13874487922294065, 0.06260361493332312, 0.23273334052646533, 0.19792192411841825, 0.2019085781648755, 0.2303384299739264, 0.10058354921056889, 0.30060276039876044, 0.14107451046584174, 0.17755132110323757, 0.3294950147392228, 0.1157106042956002, 0.11245833506109193, 0.16288381128106266, 0.19696482078870758, 0.23041988810291514, 0.16501491802046075, 0.16692847158992663, 0.33665154478512704, 0.6449522764887661, 7.980217784643173, 66.85903877019882, 38.63706395030022, 30.68792089819908, 11.221212074160576, 9.77948298677802, 5.931635610759258, 24.054048769176006, 35.03700412809849, 69.94107618927956, 86.66388764977455, 99.85155880451202, 94.29063320159912, 58.447373136878014, 0.8498204208444804, 0.1572010974632576, 0.24039972602622584], [0.005089379274068051, 0.06670786227914505, 0.08960933730122633, 2.1980504784733057, 27.560544312000275, 40.89518778026104, 39.70687374472618, 45.84908455610275, 50.03455616533756, 64.28574845194817, 66.417396068573, 60.92364326119423, 38.7589880079031, 56.96289919316769, 33.100837022066116, 8.728697821497917, 7.693297080695629, 0.1281534373993054, 0.08400700549827889, 0.21350068738684058, 0.058629837149055675, 0.05227193592872936, 0.08404837280977517, 0.08199405609047972, 0.034757736866595224, 0.020572060857375618, 0.034255347418366, 0.02901066400227137, 0.05871605244465172, 0.00644405018647376, 0.02660795347765088, 0.06657049074419774, 0.05694689112715423, 0.059892237768508494, 0.12679625710006803, 0.03427843934332486, 0.07646193145774305, 0.008410888567595975, 0.04029351657663938, 0.01634022904909216, 0.038083077961346135, 0.026173656078753993, 0.05145466064277571, 0.07238085396238603, 0.07196841281256638, 0.029209032654762268, 0.1594511853181757, 0.32167179859243333, 0.33151306270156056, 13.07871675118804, 42.012126445770264, 47.68758550286293, 57.39641033113003, 59.697764441370964, 63.766802698373795, 63.17001432180405, 61.13195948302746, 62.114252373576164, 60.23480482399464, 58.33418861031532, 59.62792418897152, 60.66583849489689, 59.49165590107441, 51.72308295965195, 50.68310156464577, 49.55238863825798, 44.747132286429405, 45.01938387751579, 44.99399743974209, 45.42484492063522, 43.663426637649536, 43.20348031818867, 45.45387916266918, 42.63302832841873, 42.17265263199806, 43.750464767217636, 42.880991622805595, 41.71513058245182, 46.03245131671429, 47.09171287715435, 49.11785915493965, 49.01013493537903, 49.48622278869152, 46.116160824894905, 46.5446600317955, 46.93121708929539, 47.11066246032715, 47.55117282271385, 48.64205628633499, 46.798539608716965, 47.51921273767948, 48.53880822658539, 44.85276281833649, 44.36032064259052, 46.59582048654556, 46.88554733991623, 49.387842267751694, 43.3967911452055, 42.42083251476288, 38.17217029631138, 39.17141407728195, 39.587905928492546, 42.569180354475975, 40.86893878877163, 40.87145045399666, 43.07255074381828, 39.785742312669754, 40.68466007709503, 41.65227435529232, 40.132488906383514, 42.484938874840736, 42.70811229944229, 44.93931457400322, 47.01263152062893, 48.64799916744232, 52.377856224775314, 52.881416603922844, 55.59696368873119, 50.502086877822876, 52.52425856888294, 52.55801975727081, 52.72272191941738, 54.83852818608284, 48.85059289634228, 45.85409268736839, 28.06445237249136, 11.255891863256693, 2.046687975525856, 0.7476532249711454, 0.0867606108658947, 0.032731098544900306, 0.07403802519547753, 0.07178502070019022, 0.05816907105327118, 0.05873089539818466, 0.0440329204138834, 0.043983931245747954, 0.050205429433844984, 0.07379402188234963, 0.028059069263690617, 0.05188965194975026, 0.03220412545488216, 0.02840662815287942, 0.05677584464137908, 0.07806404275470413, 0.04538700224657077, 0.07188321425928734, 0.03197875004843809, 0.05186608505027834, 0.04086780158104375, 0.021137261974217836, 0.09513150973361917, 0.029811320746375713, 0.09098240698222071, 0.013158660512999631, 0.10710747257689945, 0.036907341636833735, 0.11060029413783923, 0.1178328126843553, 8.152149058878422, 43.60283128917217, 17.331914976239204, 11.156677287071943, 4.1177920158952475, 4.625231986865401, 5.194510314613581, 18.56733128428459, 37.37869307398796, 40.270558297634125, 36.56330242753029, 36.213534995913506, 23.71340274810791, 0.6419689615722746, 0.18568807980045676, 0.08244089578511193, 0.06908844196004793, 0.05971010359644424, 0.12699325277935714, 0.14412479678867385, 2.4624493159353733, 37.77322970330715, 56.21706761419773, 57.19134673476219, 57.592574805021286, 60.4117651283741, 70.36603778600693, 75.15799105167389, 67.82746240496635, 47.586514726281166, 57.76372142136097, 41.669419035315514, 22.96790935099125, 4.76882865652442, 0.0770884302619379, 0.038929783113417216, 0.136994345812127, 0.04161593096796423, 0.037744153960375115, 0.02188332819059724, 0.04568708594888449, 0.034715816655079834, 0.054208254878176376, 0.06554093153681606, 0.06053714554582257, 0.022547030857822392, 0.054524491424672306, 0.014394034897122765, 0.03223121755581815, 0.010320161800336791, 0.1395529296132736, 0.04659323712985497, 0.03393690298253205, 0.05972259023110382, 0.04484985060116742, 0.05402419112215284, 0.025127771477855276, 0.018843164762074593, 0.0646025303285569, 0.034858609578805044, 0.09448762983083725, 0.058750276584760286, 0.032370485278079286, 0.08351265350938775, 0.2701518771937117, 2.6817611977458, 9.99087419360876, 41.24666512012482, 53.64199139177799, 60.73734685778618, 62.40852378308773, 64.01579573750496, 66.0967768728733, 61.94776810705662, 64.93420645594597, 62.538852989673615, 61.932219341397285, 61.506676375865936, 65.02442121505737, 61.377661898732185, 56.72285467386246, 53.56577888131142, 52.48247221112251, 48.44520024955273, 48.75713311135769, 47.574560567736626, 47.377647534012794, 46.083524376153946, 45.66899321973324, 47.70139396190643, 46.27476051449776, 45.95340795814991, 47.006943225860596, 45.39243645966053, 44.824480935931206, 46.4769172668457, 50.326517298817635, 52.301058545708656, 51.134908720850945, 53.40136930346489, 47.54588730633259, 48.964461386203766, 50.6429111212492, 50.99700652062893, 50.73551595211029, 52.47264973819256, 49.909960851073265, 51.19045794010162, 50.92439241707325, 48.2757331430912, 47.63176269829273, 49.5315657556057, 46.4900341629982, 51.44264280796051, 45.59931255877018, 43.090747967362404, 41.359591260552406, 42.245517522096634, 41.85270980000496, 45.059019550681114, 43.47010441124439, 44.73498813807964, 44.46290373802185, 42.36595205962658, 43.30534145236015, 43.88491675257683, 43.224812373518944, 45.615583285689354, 45.202028676867485, 49.725062772631645, 50.60832537710667, 51.19213744997978, 56.28818079829216, 56.584937274456024, 57.3818077147007, 53.240922912955284, 53.53136792778969, 54.19610045850277, 55.39336681365967, 57.90184400975704, 51.38451352715492, 50.24280399084091, 26.952204555273056, 7.273353589698672, 1.6115236887708306, 0.3706555935787037, 0.12832948967115954, 0.057898521117749624, 0.06461276454501785, 0.03671232749184128, 0.03248551445722114, 0.029696794372284785, 0.06856994790723547, 0.019925596425309777, 0.08938753162510693, 0.015532783509115689, 0.10747473177616484, 0.06546732533024624, 0.05339362163795158, 0.05513199866982177, 0.07781724154483527, 0.051258228995720856, 0.006127571050456027, 0.06886771981953643, 0.09641064578318037, 0.07796439458616078, 0.04830881538509857, 0.05967648801743053, 0.021715098155254964, 0.010351085238653468, 0.03925563047232572, 0.04400380596052855, 0.12667988834436983, 0.01240109842910897, 0.10532737200264819, 0.3351774316979572, 14.554593656212091, 54.69076931476593, 29.963738657534122, 15.237264074385166, 4.339841175824404, 8.534642234444618, 2.7887758053839207, 13.848246708512306, 45.42037256062031, 41.61725543439388, 32.21951611340046, 31.679684780538082, 5.550181679427624, 0.6062308105174452, 0.06134607167041395, 0.06246872217161581, 0.08557914145058021, 0.12006839155219495, 0.3713101678295061, 0.23820755537599325, 8.313371557742357, 75.9664736688137, 91.93299651145935, 85.9090581536293, 68.48688662052155, 72.71822556853294, 81.4909516274929, 88.40818405151367, 78.340685069561, 54.5737773925066, 71.64099857211113, 54.21107165515423, 42.26757153868675, 8.9594841375947, 0.40439908916596323, 0.09764086687937379, 0.3405964159173891, 0.0718441401841119, 0.1321243282291107, 0.09493644363828935, 0.1746746973367408, 0.08414269977947697, 0.16552802408114076, 0.14892039180267602, 0.21922111714957282, 0.13287797919474542, 0.18285114609170705, 0.10889060111367144, 0.14160232589347288, 0.08579538844060153, 0.3915806848090142, 0.3279401856707409, 0.1921991046401672, 0.24630839412566274, 0.16550697677303106, 0.14044735115021467, 0.15566519316053018, 0.10134719690540805, 0.12237699775141664, 0.12307043085456826, 0.26870421424973756, 0.09781740154721774, 0.12874558218754828, 0.3246061911340803, 0.7040532364044338, 5.833178143948317, 28.83567988872528, 50.77115423977375, 54.11878980696201, 62.42499589920044, 64.11566957831383, 68.05660530924797, 67.01341688632965, 62.537542060017586, 65.25472685694695, 66.95135861635208, 61.191965863108635, 64.185281842947, 65.80793157219887, 62.86951504647732, 57.10094578564167, 55.869956240057945, 55.31632974743843, 51.424407586455345, 50.197966396808624, 50.22376701235771, 51.320646554231644, 50.34156069159508, 48.78429405391216, 50.81693038344383, 48.823561146855354, 47.49397449195385, 49.20903526246548, 50.292851105332375, 46.866935938596725, 50.67241653800011, 50.88109754025936, 55.98609320819378, 52.8029166162014, 56.354950815439224, 50.67442283034325, 51.170110031962395, 52.28912338614464, 52.90149472653866, 55.056385695934296, 55.29586784541607, 52.018178924918175, 52.84104377031326, 53.076220750808716, 50.80140441656113, 49.56506475806236, 51.144214421510696, 48.89938607811928, 54.7708386182785, 49.22798104584217, 48.055420964956284, 44.65231217443943, 45.698213651776314, 44.777120277285576, 48.15352410078049, 47.480078637599945, 48.32809813320637, 49.287128672003746, 43.61919321119785, 45.679674446582794, 48.15594457089901, 46.54994174838066, 50.847039967775345, 47.9622233659029, 50.23621514439583, 53.061754927039146, 52.38294795155525, 58.27677369117737, 60.39835944771767, 61.60369277000427, 53.58735032379627, 55.77813416719437, 55.72438985109329, 60.14237478375435, 57.338843420147896, 55.79912044107914, 51.625162214040756, 44.40551161766052, 24.010208621621132, 5.565173299983144, 0.9439515229314566, 0.19214427476981655, 0.1974600410903804, 0.15267375914845616, 0.16679859574651346, 0.2091022304375656, 0.12837416696129367, 0.22041521791834384, 0.13218791544204578, 0.23553200910100713, 0.2501559548545629, 0.164765571244061, 0.13130560575518757, 0.14414750650757924, 0.15489206823986024, 0.19218150089727715, 0.2160461648600176, 0.11960778501816094, 0.1665167577448301, 0.12194053328130394, 0.09760552580701187, 0.193503740883898, 0.10777468560263515, 0.30653851688839495, 0.1225481295841746, 0.12997475685551763, 0.22205531975487247, 0.34651830908842385, 0.14468494016909972, 0.17138910567155108, 0.7579251425340772, 20.440113991498947, 66.44780203700066, 39.14455331861973, 27.364490032196045, 4.212226448580623, 9.035408813506365, 7.295983275398612, 44.288101717829704, 84.4516995549202, 84.76937770843506, 69.74123731255531, 67.3609234392643, 39.16533440351486, 0.9133113920688629, 0.4968526109587401, 0.2569206606131047, 0.23020154825644568], [0.06677477431367151, 0.07079944858560339, 0.054034417917137034, 0.02111862850142643, 6.965930135920644, 10.11014599353075, 19.369798824191093, 38.854879662394524, 51.00604623556137, 56.781455129384995, 55.32640300691128, 54.751984030008316, 27.63573467731476, 61.13623045384884, 49.16815705597401, 11.708740163594484, 9.398866910487413, 0.05025354286772199, 0.04789837432326749, 0.0637930104858242, 0.04559452529065311, 0.13251337688416243, 0.05881181175936945, 0.06441979130613618, 0.0874326478515286, 0.05834867450175807, 0.09124016971327364, 0.01692403580818791, 0.027132054456160404, 0.03932972649636213, 0.01767247504176339, 0.12604073592228815, 0.07409246172755957, 0.043242577667115256, 0.05694288352970034, 0.13047851185547188, 0.07582067875773646, 0.138142463110853, 0.04760242809425108, 0.023839981986384373, 0.10282391493092291, 0.02346475583181018, 0.03170956566464156, 0.005968596060483833, 0.016416367834608536, 0.06234692089492455, 0.016524816019227728, 0.048619207518640906, 0.5559942999389023, 1.118552628904581, 17.628316171467304, 47.598818466067314, 55.651296973228455, 61.19182147085667, 59.27653044462204, 62.88436844944954, 58.33822779357433, 62.57677875459194, 57.97367535531521, 62.39166408777237, 60.31056135892868, 60.42512521147728, 56.68648302555084, 58.47132705152035, 53.29682171344757, 48.93680267035961, 43.120906949043274, 43.4624782204628, 44.517609402537346, 43.996554762125015, 44.41490851342678, 43.847431764006615, 43.40757116675377, 43.29928457736969, 42.05817237496376, 40.64804144203663, 41.10855773091316, 42.01323218643665, 43.572090938687325, 47.26015403866768, 42.90889732539654, 48.50931040942669, 47.813309356570244, 45.533956065773964, 45.05021922290325, 48.80469135940075, 48.53645235300064, 48.245380371809006, 46.88295587897301, 48.19650359451771, 49.66679289937019, 46.853849440813065, 43.226871863007545, 43.131747767329216, 47.732404097914696, 44.62331973016262, 42.57505103945732, 47.07807160913944, 38.894310146570206, 38.33025701344013, 36.14250160753727, 40.13283848762512, 42.05161392688751, 39.43239167332649, 40.83093702793121, 39.79711890220642, 38.56137581169605, 41.85501627624035, 40.25676503777504, 39.30139370262623, 42.110715955495834, 43.757710978388786, 45.320494920015335, 49.33371417224407, 47.6339627802372, 54.59346033632755, 51.00801073014736, 52.572094202041626, 48.323097601532936, 51.433394104242325, 48.356361016631126, 52.64052852988243, 51.48038998246193, 45.38562722504139, 37.18394212424755, 11.910707876086235, 1.6168226231820881, 0.26667099678888917, 0.06352162192342803, 0.08611082346760668, 0.0361209359834902, 0.05427910029538907, 0.05704006034648046, 0.04686166452302132, 0.09664480821811594, 0.056649445759830996, 0.02769291400909424, 0.037365899843280204, 0.06320839849649929, 0.03403882212296594, 0.027354698759154417, 0.038555158098461106, 0.07982691808138043, 0.04462882046937011, 0.009594973125786055, 0.04702790560259018, 0.021135898277861997, 0.07718240100075491, 0.008708985169505468, 0.05805599743325729, 0.06120318968896754, 0.011551099069038173, 0.12247997816302814, 0.06588573334738612, 0.04639290178602096, 0.01623689240659587, 0.02117357526003616, 0.09039189491886646, 0.3283320099581033, 15.703239720314741, 40.85629306733608, 21.51328280568123, 6.805865149945021, 4.6131339110434055, 1.4839469594880939, 4.530905848369002, 15.520647168159485, 11.20045568794012, 13.166764676570892, 15.72048794478178, 7.441348750144243, 0.15187842916930094, 0.11857483419589698, 0.05882049117644783, 0.010059460164484335, 0.026654137327568606, 0.04268756994861178, 0.04436354349309113, 0.06941331710550003, 0.08917102488339879, 10.624270755797625, 29.55663040280342, 32.73384131491184, 57.09407955408096, 62.03510262072086, 61.72443889081478, 63.16788263618946, 67.71762549877167, 36.32133521139622, 70.2523098886013, 62.87348583340645, 24.830419309437275, 0.9638754569459707, 0.06691032758681104, 0.10147230073926039, 0.12081954148015939, 0.033946725307032466, 0.10756143688922748, 0.07750770659185946, 0.02447100789140677, 0.07747477749944665, 0.06794641027227044, 0.05162198896869086, 0.03266252781031653, 0.01884985151264118, 0.030191986843419727, 0.04146271458012052, 0.059632853444782086, 0.1749112198012881, 0.019219895621063188, 0.27816333167720586, 0.15984229714376852, 0.07706580960075371, 0.04019885935122147, 0.04898661885818001, 0.03054179258469958, 0.04236027169099543, 0.016062650975072756, 0.03571615008695517, 0.015772415572428145, 0.023709803717792965, 0.05288501670293044, 0.07916066984762438, 0.07806868859915994, 0.6328167370520532, 2.092304052785039, 13.044531885534525, 45.47545440495014, 56.04285456240177, 64.28143188357353, 62.87804178893566, 62.950864881277084, 59.84034799039364, 63.83028969168663, 60.63702464103699, 64.20561835169792, 61.44413933157921, 65.1106233894825, 59.31473359465599, 59.37494516372681, 57.25722000002861, 49.682957231998444, 46.42034970223904, 48.102242052555084, 44.86799240112305, 45.36347061395645, 46.30021534860134, 47.95188412070274, 45.07729656994343, 45.11072337627411, 44.578071758151054, 44.22017276287079, 42.74375818669796, 43.31195309758186, 47.716102972626686, 48.86448875069618, 45.16973040997982, 49.51283656060696, 48.278856575489044, 46.71202965080738, 47.01282911002636, 49.77437272667885, 51.88370034098625, 50.88856413960457, 48.405374586582184, 49.586282819509506, 51.79317019879818, 47.57843255996704, 45.921580865979195, 43.9004123210907, 47.54391521215439, 46.55406452715397, 44.514983743429184, 49.10031169652939, 41.0263529419899, 42.2886186093092, 39.29066687822342, 41.58293567597866, 43.2998925447464, 42.96103052794933, 44.13995526731014, 43.578497394919395, 41.299239099025726, 42.978490591049194, 42.61598624289036, 42.9014877229929, 45.737077966332436, 44.95068356394768, 49.581540673971176, 51.85620881617069, 51.84912979602814, 55.486328825354576, 52.69389286637306, 55.04290781915188, 50.91655723750591, 54.38935808837414, 52.84971110522747, 57.13600270450115, 52.97714106738567, 52.50632353127003, 33.64467144012451, 8.013192415237427, 0.6794668338261545, 0.22169661009684205, 0.037892628024565056, 0.13361879100557417, 0.10347684903535992, 0.0669597991509363, 0.08283079048851505, 0.06360989296808839, 0.05674546853697393, 0.024188902716559824, 0.05997816362651065, 0.044472409135778435, 0.06981452213949524, 0.024882293146220036, 0.06340411026030779, 0.044107365247327834, 0.09301112702814862, 0.01692778736469336, 0.07216019861516543, 0.07050831889500841, 0.08040723303565755, 0.07394706015475094, 0.02429657721222611, 0.08651006923173554, 0.07354882371146232, 0.03552381880581379, 0.025978584417316597, 0.01647001026867656, 0.004899716013824218, 0.050082169836969115, 0.02893105938710505, 0.22953563398914412, 0.9618382318876684, 30.147436000406742, 50.695097520947456, 31.766352429986, 8.735486157238483, 4.933814853429794, 4.547558929771185, 2.96474008820951, 15.646750051528215, 8.049666658043861, 2.3104408476501703, 6.290990402922034, 2.311954591423273, 0.1303114544134587, 0.07892958732554689, 0.11765130562707782, 0.07801848230883479, 0.04244900286721531, 0.30799306696280837, 0.17435459420084953, 0.27608701027929783, 0.25170211563818157, 24.791708886623383, 66.41295790672302, 69.92146164178848, 83.4453159570694, 75.12560918927193, 75.45196607708931, 70.42383268475533, 77.87904784083366, 46.02833613753319, 80.48622474074364, 73.66545394062996, 41.009911224246025, 17.69939135760069, 0.15197343891486526, 0.17115000053308904, 0.15258465689839795, 0.18176532466895878, 0.35596421628724784, 0.24540482932934538, 0.17613543692277744, 0.2866260119481012, 0.17947459680726752, 0.2398448222083971, 0.1309602992841974, 0.1427206682274118, 0.21101720893057063, 0.20655032596550882, 0.214744541735854, 0.280789079843089, 0.11636293726041913, 0.41077912494074553, 0.3453854948747903, 0.2982173493364826, 0.2598061307799071, 0.17569899471709505, 0.15377558127511293, 0.24769160896539688, 0.1606627117143944, 0.18724135035881773, 0.15653055219445378, 0.17928505229065195, 0.19676687516039237, 0.1611857328680344, 0.3185890062013641, 1.1223411443643272, 4.0667384304106236, 28.12813125550747, 53.08807231485844, 59.747328981757164, 66.52486190199852, 62.53362067043781, 66.64579421281815, 58.86387638747692, 65.8009323477745, 62.64177806675434, 65.98553404211998, 63.28687705099583, 64.71825644373894, 60.64383387565613, 63.050852715969086, 61.59738130867481, 52.29507006704807, 47.97665499150753, 50.487989634275436, 47.74622015655041, 48.40893879532814, 48.64529371261597, 51.279650554060936, 49.09162536263466, 50.31781576573849, 48.03275518119335, 47.113968282938, 46.44602872431278, 47.080894857645035, 48.18304471671581, 51.248830407857895, 48.76686438918114, 53.83882462978363, 52.40371383726597, 50.235595777630806, 51.205482333898544, 55.08066639304161, 56.52479030191898, 54.72476989030838, 51.58868417143822, 53.000973388552666, 57.17581696808338, 52.231187894940376, 49.23129826784134, 46.37824036180973, 52.23295480012894, 49.09021943807602, 45.1257211714983, 51.07864134013653, 43.55626478791237, 44.576726630330086, 42.60923020541668, 46.15117594599724, 48.521021381020546, 44.42131116986275, 45.298824682831764, 44.62976798415184, 42.564035430550575, 46.50985769927502, 46.563047245144844, 45.75397565960884, 50.3634437173605, 47.64567755162716, 52.46467396616936, 52.38200940191746, 52.18654029071331, 58.167343363165855, 55.27627229690552, 54.97096247971058, 52.73053430020809, 56.030740812420845, 53.68814751505852, 55.55697463452816, 56.85564614832401, 50.97301460802555, 42.36459173262119, 23.224184699356556, 4.07690335996449, 0.5591594113502651, 0.20891707943519577, 0.1401340015581809, 0.24663820455316454, 0.11141281967866234, 0.2117911502136849, 0.12885098200058565, 0.13155567983631045, 0.12088403411325999, 0.15101450990187004, 0.17908534035086632, 0.27388208953198045, 0.07099524940713309, 0.232534444949124, 0.20703646237961948, 0.26057374896481633, 0.07987713921465911, 0.11599238292546943, 0.16349155601346865, 0.15438118862221017, 0.12024965370073915, 0.11002566403476521, 0.19587243878049776, 0.26697542576584965, 0.26224313594866544, 0.14723638450959697, 0.22468477865913883, 0.1912135473685339, 0.16433438344392926, 0.14441571867791936, 0.3407118940958753, 0.6627600803039968, 35.22031769156456, 60.31724900007248, 44.520755633711815, 17.92326394468546, 5.117788156494498, 4.284620163962245, 6.663169031962752, 34.31282378733158, 45.692829340696335, 36.76041305065155, 40.02617061138153, 14.277041349560022, 0.24106477940222248, 0.23869884229497984, 0.39161152846645564, 0.165635843295604, 0.2368937907158397], [0.02062512627162505, 0.042475193258724175, 0.0728122124564834, 0.1129873156605754, 0.528017885517329, 6.880168737843633, 5.804946608841419, 12.471098955720663, 43.217729553580284, 49.9854552000761, 40.39147540926933, 27.84501224756241, 30.063194520771503, 25.28929978609085, 13.53065500035882, 17.704864963889122, 0.44069845229387283, 1.3213743455708027, 0.08685055174282752, 0.03184788343787659, 0.080953216238413, 0.0325973783765221, 0.004393387616801192, 0.06568785451236181, 0.06666539658908732, 0.01889382561785169, 0.01067528410203522, 0.023863968199293595, 0.059758669740404, 0.07464775888365693, 0.028106859863328282, 0.006892512865306344, 0.053039286940474994, 0.22513440140755847, 0.27515603054780513, 0.05230103553913068, 0.7957230799365789, 0.15383182122604921, 0.037630957885994576, 0.0066629331922740676, 0.010376851678302046, 0.016010182989703026, 0.07053458350128494, 0.03516519449476618, 0.09824311229749583, 0.04172105989709962, 0.06157292766147293, 0.036435873771551996, 0.3746600146405399, 0.9970114007592201, 2.4800233729183674, 22.3159384354949, 46.89904801547527, 58.243198692798615, 63.92855241894722, 56.771036088466644, 55.935126543045044, 59.44293111562729, 62.17760257422924, 59.6201878041029, 60.61134181916714, 58.87076161801815, 56.521780863404274, 58.21084342896938, 55.7075871527195, 51.84639014303684, 43.58353592455387, 43.689812421798706, 42.65206530690193, 43.516549319028854, 44.779194965958595, 42.81989850103855, 42.245673313736916, 41.429777294397354, 38.423162028193474, 42.18800000846386, 40.72212986648083, 41.70943848788738, 48.20853374898434, 50.61666592955589, 50.107926428318024, 44.37089167535305, 40.47456935048103, 43.45036827027798, 40.65208062529564, 42.825442403554916, 44.771082401275635, 46.67624697089195, 46.29333771765232, 46.56756140291691, 43.083433359861374, 43.39141823351383, 42.706991359591484, 41.454327777028084, 40.67229554057121, 43.77623878419399, 44.201929941773415, 48.6662457883358, 42.34668329358101, 36.950881630182266, 37.61555716395378, 38.05605232715607, 37.840683683753014, 39.4720159471035, 38.81563916802406, 39.091641157865524, 39.91366624832153, 39.354514852166176, 40.928515791893005, 39.94629129767418, 39.66481380164623, 42.088996320962906, 51.146133318543434, 51.46083623170853, 48.95959384739399, 52.84886375069618, 51.12407170236111, 51.33043862879276, 45.516317412257195, 48.284130692481995, 51.608275920152664, 52.66832783818245, 46.36098548769951, 40.32241031527519, 16.896049864590168, 2.4288372695446014, 0.47660649579484016, 0.06046004382369574, 0.06056483507563826, 0.09868618188193068, 0.013841781474184245, 0.049497205327497795, 0.04985468302038498, 0.038460586220026016, 0.05160448170499876, 0.057481998155708425, 0.047279768259613775, 0.06655797071289271, 0.058106715805479325, 0.10388333816081285, 0.02762182368314825, 0.06190022962982766, 0.2270625752862543, 0.12397714235703461, 0.07013009075308219, 0.04850570716371294, 0.052074981067562476, 0.06691411253996193, 0.10153310489840806, 0.0331577147153439, 0.023186602593341377, 0.037271661931299604, 0.041302841127617285, 0.03524202162225265, 0.0323520020901924, 0.029803390898450743, 0.08024456168641336, 0.34413188870530576, 2.1695973677560687, 35.81890717148781, 39.17693518102169, 23.15670222043991, 8.955418355762959, 3.493260140530765, 3.113774028606713, 5.276700854301453, 4.0364027582108974, 7.59676706045866, 0.8086210722103715, 0.36996070586610585, 0.28778459352906793, 0.0724649170297198, 0.01885499274067115, 0.036215548680047505, 0.03130368881102186, 0.0684922376240138, 0.051405289268586785, 0.07305536229978316, 0.020012153108837083, 0.11056268209358677, 0.22306903410935774, 12.869385033845901, 13.016961514949799, 22.36243274062872, 56.12015001475811, 62.946620509028435, 47.04859659075737, 40.186548605561256, 39.65926989912987, 39.42804090678692, 22.647356651723385, 28.142207600176334, 25.294321216642857, 2.7163072815164924, 0.01955774350790307, 0.06859685076051392, 0.056744956455077045, 0.026107066878466867, 0.02786279346764786, 0.030524658250214998, 0.027689971393556334, 0.026084193887072615, 0.04326559166656807, 0.011293497755104909, 0.11560590210137889, 0.07115687432815321, 0.019254422186349984, 0.03019884057721356, 0.08984381885966286, 0.045881205805926584, 0.1470818545203656, 0.07282263963134028, 0.2870849857572466, 0.03338553920912091, 0.036449184190132655, 0.02039313461864367, 0.01897578655189136, 0.030277523073891643, 0.07534379692515358, 0.0279672915712581, 0.06973123090574518, 0.045387703576125205, 0.04620647800038569, 0.04307993971451651, 0.23704486229689792, 0.7414095068816096, 2.6730249915271997, 17.625891901552677, 46.19841881096363, 57.63996206223965, 64.16442856192589, 60.62765434384346, 61.162734031677246, 62.35287196934223, 65.16956582665443, 58.800286799669266, 62.82883442938328, 61.452719271183014, 58.90779823064804, 61.28448709845543, 58.88780750334263, 56.095732524991035, 47.82068856060505, 46.7628139257431, 44.55378346145153, 46.05542868375778, 46.25103458762169, 46.52455151081085, 45.767673924565315, 43.8330153375864, 42.33370319008827, 43.98188374936581, 42.59048581123352, 45.94506360590458, 50.87288238108158, 52.411617413163185, 51.625375002622604, 45.495574325323105, 43.19469898939133, 42.95432768762112, 43.126336857676506, 44.69723716378212, 48.3768343180418, 49.1441385447979, 50.28529331088066, 51.11824281513691, 46.451150849461555, 44.224876910448074, 43.64351190626621, 43.9989448338747, 41.760899126529694, 44.45719264447689, 46.76942557096481, 50.613170117139816, 47.7806007117033, 40.48229433596134, 41.41274280846119, 41.42962530255318, 41.68983153998852, 42.276972234249115, 41.85462109744549, 41.943722516298294, 42.69891299307346, 42.86079950630665, 44.28734935820103, 42.49253086745739, 42.459427043795586, 47.155439257621765, 57.67322547733784, 55.892527028918266, 54.25510749220848, 58.627958446741104, 54.103776812553406, 54.65922720730305, 49.82025906443596, 51.87476322054863, 54.13362421095371, 55.60549423098564, 52.761141657829285, 34.209803715348244, 10.183742344379425, 0.3226624469971284, 1.1073441803455353, 0.07738219457678497, 0.12349214142886922, 0.08332278986927122, 0.11310292742564343, 0.0325188331771642, 0.02578707877546549, 0.06465016136644408, 0.07946046040160581, 0.0340044606855372, 0.07627223851159215, 0.04494781780522317, 0.021729499530920293, 0.057369614733033814, 0.0337829630007036, 0.009518965143797686, 0.07046453218208626, 0.09918723546434194, 0.0957822025520727, 0.015360960551333847, 0.05663976444338914, 0.10060953180072829, 0.07432502112351358, 0.04743382698507048, 0.03334455410367809, 0.050014003572869115, 0.04750871339638252, 0.03886401769705117, 0.032530948737985454, 0.06630992269492708, 0.09872336348053068, 0.4660164046799764, 4.285600511357188, 48.668917044997215, 44.891152158379555, 28.938756957650185, 10.644803903996944, 6.2796674855053425, 3.227534224279225, 4.335561180487275, 7.928095981478691, 11.685246024280787, 4.709472516551614, 0.24688134697498754, 0.144466481579002, 0.12777587719028816, 0.050636873274925165, 0.015267460148606915, 0.03572396490199026, 0.050613154235179536, 0.16933258477365598, 0.12941952649271116, 0.09973292180802673, 0.17775728192646056, 0.9863874677103013, 21.866223067045212, 41.132648438215256, 56.28299407660961, 71.04850396513939, 72.10708916187286, 57.69562527537346, 41.83796279132366, 51.78990997374058, 40.921740755438805, 29.31793101131916, 40.40616162121296, 46.78468555212021, 4.970851466059685, 0.139617555832956, 0.281908149481751, 0.24758766376180574, 0.14573163556633517, 0.1509059188538231, 0.21918049198575318, 0.19162005133694038, 0.1430325335240923, 0.10310273981303908, 0.10842082163435407, 0.18895323271863163, 0.12889335863292217, 0.11797880055382848, 0.10117022437043488, 0.19846563634928316, 0.31587702047545463, 0.5459856963716447, 0.23214113636640832, 1.44907753681764, 0.35442473483271897, 0.2227767466683872, 0.053359861340140924, 0.10866801618249156, 0.1634855891461484, 0.19771489460254088, 0.15251133270794526, 0.15479355555726215, 0.19921476021409035, 0.1829965179786086, 0.09617458345019259, 0.4813194600865245, 1.3511367235332727, 4.904152695089579, 30.909899286925793, 50.88466554880142, 66.14798292517662, 67.97783553600311, 62.2135828435421, 59.08159330487251, 65.82686215639114, 66.66529476642609, 64.31180745363235, 63.126468658447266, 64.14878860116005, 61.73695921897888, 63.02270382642746, 59.937729164958, 56.33363015949726, 49.33924287557602, 49.40702363848686, 47.01455041766167, 50.12526109814644, 50.26775725185871, 51.376051381230354, 48.73492330312729, 47.577577605843544, 43.37043195962906, 47.16447897255421, 44.63364377617836, 47.89794601500034, 52.01666280627251, 54.87395368516445, 54.609016701579094, 48.33784841001034, 44.27720010280609, 46.45549401640892, 44.04849797487259, 49.038473814725876, 50.8762414008379, 52.96657383441925, 52.421230897307396, 53.47591370344162, 50.37473291158676, 48.1551618129015, 46.749678030610085, 47.290069833397865, 43.7962257117033, 47.107219845056534, 48.77059958875179, 54.095664247870445, 47.95572951436043, 41.41540266573429, 43.09430457651615, 44.68389607965946, 43.137534856796265, 45.418491661548615, 43.69264326989651, 43.25494855642319, 45.53916558623314, 45.7868704944849, 46.9698192179203, 45.71285426616669, 44.529031589627266, 50.13821080327034, 57.65400230884552, 56.96699917316437, 54.46574918925762, 59.51292335987091, 57.26636230945587, 58.303087279200554, 48.874884992837906, 49.71539989113808, 53.53654704988003, 59.32253837585449, 50.86616814136505, 44.15171563625336, 28.899506963789463, 4.324050648137927, 2.5950246769934893, 0.13749269797699526, 0.1778884491068311, 0.3850270458497107, 0.2788157982286066, 0.2210707718040794, 0.1250437941052951, 0.17083592363633215, 0.21148917032405734, 0.11025301355402917, 0.1687600920558907, 0.21030431671533734, 0.10563944510067813, 0.23489839310059324, 0.13723671640036628, 0.2594184031477198, 0.3781477821758017, 0.22853207221487537, 0.20364836527733132, 0.16077703214250505, 0.2249691993347369, 0.31187043234240264, 0.20476473349845037, 0.17485888354713097, 0.2032325102481991, 0.19858124811435118, 0.09711229446111247, 0.10283847586833872, 0.14828551415121183, 0.0834637088701129, 0.25521627394482493, 0.8918031211942434, 4.693626891821623, 61.16205386817455, 56.68540768325329, 44.66226004064083, 13.901358358561993, 4.265741351991892, 3.2721452554687858, 6.4414941519498825, 40.199908688664436, 31.125883497297764, 5.364770153537393, 0.5807749670930207, 0.6001510773785412, 0.2029805807978846, 0.1509383655502461, 0.11706252276781015, 0.12297934707021341, 0.10618409243761562], [0.06887243245728314, 0.06401820035534911, 0.05400174486567266, 0.046284796844702214, 0.20115837076446041, 0.2984280599048361, 0.9017605462577194, 5.126601783558726, 29.74631242454052, 55.718602761626244, 49.09664869308472, 23.434816896915436, 23.054197020828724, 9.443074688315392, 20.526500456035137, 21.742478907108307, 33.60638469457626, 13.369810581207275, 0.09947712576831691, 0.031028795456222724, 0.06688009249046445, 0.04645968394470401, 0.05670632024703082, 0.028706721132039092, 0.0353516739414772, 0.06491045482107438, 0.045096562753315084, 0.05358282105589751, 0.04393497918499634, 0.018174038850702345, 0.11214254380320199, 0.0373374162154505, 0.02388458320638165, 0.28319631004706025, 0.6683703605085611, 1.2205839226953685, 3.0964680947363377, 1.5234114043414593, 0.6042771216016263, 0.15840958105400205, 0.024137789150699973, 0.01901398860354675, 0.04395376665343065, 0.05665091892296914, 0.033054574741981924, 0.11816801110398956, 0.05149245080247056, 0.046944562418502755, 0.15245325223077089, 0.4273408034350723, 1.0996043519116938, 2.28002751711756, 23.380443714559078, 44.03751656413078, 53.154219165444374, 59.79785867035389, 63.16147617995739, 57.43777871131897, 58.719123154878616, 54.48586530983448, 58.537781685590744, 57.69820153713226, 60.35003364086151, 59.79994095861912, 62.710683569312096, 56.99414871633053, 49.70730632543564, 46.628494933247566, 44.60120111703873, 42.5728889554739, 41.789086014032364, 43.14416170120239, 39.51407589018345, 41.0942704975605, 39.48126085102558, 40.60943931341171, 41.81234836578369, 44.9495892226696, 46.97398379445076, 48.56393627822399, 49.42441910505295, 45.66787227988243, 43.226837664842606, 42.98093006014824, 42.315407171845436, 41.67514532804489, 45.808996707201004, 45.42134150862694, 45.884939432144165, 46.04054108262062, 42.84501135349274, 40.90086467564106, 39.71336379647255, 39.43028658628464, 39.31988351047039, 42.12555795907974, 45.74101835489273, 44.802913293242455, 43.925319984555244, 40.0938905775547, 38.03703434765339, 37.38522112369537, 37.684941440820694, 37.937225103378296, 38.43406364321709, 37.74646393954754, 40.88330961763859, 39.76496122777462, 41.56508803367615, 38.653045892715454, 44.13750059902668, 47.964404448866844, 55.73206543922424, 51.6661886125803, 48.08555714786053, 52.11190469563007, 49.66933116316795, 50.24252660572529, 47.59249560534954, 49.84037518501282, 50.67556656897068, 46.30176566541195, 38.8563197851181, 17.978663071990013, 2.7185598481446505, 0.054513129143742844, 0.10663942230166867, 0.6260911573190242, 0.039541257137898356, 0.05560117700952105, 0.07530830742325634, 0.020421360350155737, 0.04643130050681066, 0.0515881618775893, 0.02391967937001027, 0.03468659459031187, 0.06394555894075893, 0.030216026862035505, 0.030579818376281764, 0.04697965858213138, 0.07169293501647189, 0.1169836769986432, 0.10415051132440567, 0.09878131037112325, 0.06079827762732748, 0.08858467626851052, 0.04047440022986848, 0.053505018004216254, 0.03752874559722841, 0.02452308253850788, 0.009898742518998915, 0.047782061228645034, 0.010516809597902466, 0.09473716214415617, 0.025011384168465156, 0.11004625863279216, 0.1020419065025635, 0.43635115900542587, 6.343841291964054, 36.80707074701786, 39.189425110816956, 25.787103474140167, 4.799851141870022, 5.2406982611864805, 3.2228483632206917, 3.2811111118644476, 4.470731802284718, 7.200008500367403, 5.094472132623196, 0.09572424824000336, 0.038082276441855356, 0.040444591868435964, 0.05370890081394464, 0.04966653374140151, 0.06772404798539355, 0.02705116778088268, 0.15910987160168588, 0.05059998111391906, 0.022275334304140415, 0.10677430764189921, 0.2158691329532303, 0.7957287202589214, 3.367300699464977, 3.524140133522451, 40.53643383085728, 64.51486095786095, 54.84325133264065, 28.907030560076237, 30.677437260746956, 16.18141271173954, 25.405641943216324, 32.037228494882584, 53.13292130827904, 28.248592391610146, 0.20838592434301972, 0.17228983546374366, 0.10014791594585404, 0.02879763051168993, 0.06841620459454134, 0.04789038510352839, 0.09255521086743101, 0.017578294646227732, 0.01955777690454852, 0.007337421120610088, 0.06727898202370852, 0.07326730483327992, 0.06776751557481475, 0.03334706256282516, 0.10005329211708158, 0.36518177948892117, 0.6725218158680946, 0.37833593145478517, 1.7634104448370636, 1.340310035739094, 0.2911069808760658, 0.042101276994799264, 0.00465560926386388, 0.03326227961224504, 0.042133215320063755, 0.013727359000768047, 0.025914811667462345, 0.09043720303452574, 0.0565699246362783, 0.041332553009851836, 0.28467063093557954, 0.046487495928886347, 1.8171984585933387, 4.545798674225807, 17.349209748208523, 41.589680314064026, 55.07704518735409, 59.8277972638607, 63.72411198914051, 60.45503340661526, 60.434510707855225, 57.681866213679314, 61.335487961769104, 60.28713181614876, 62.307331413030624, 63.83737251162529, 64.34319376945496, 58.03433530032635, 50.89593194425106, 48.624163046479225, 45.00362612307072, 46.76191337406635, 44.909581169486046, 47.20480240881443, 44.06781233847141, 41.60012975335121, 42.157339453697205, 44.320859760046005, 44.862323105335236, 47.66176588833332, 50.296153128147125, 51.22545026242733, 50.95878817141056, 50.17877362668514, 47.20861740410328, 45.00426448881626, 46.29730090498924, 45.49127295613289, 48.79388093948364, 50.415082946419716, 47.001973092556, 49.979193136096, 46.33839949965477, 44.38798315823078, 42.026850655674934, 43.092849254608154, 43.33305336534977, 47.4749793112278, 49.28082101047039, 48.44976760447025, 48.034533485770226, 43.498952463269234, 41.32370978593826, 40.09789556264877, 40.79492636024952, 41.23967729508877, 42.27263666689396, 42.15397283434868, 44.79982405900955, 41.62005588412285, 43.684279918670654, 44.15469467639923, 46.5203907340765, 52.882119566202164, 57.74869702756405, 55.366164073348045, 51.57718598842621, 55.35363994538784, 54.639912843704224, 52.68674165010452, 50.772529765963554, 50.520823672413826, 55.930285602808, 50.523042753338814, 32.551021724939346, 8.638076484203339, 0.8826249511912465, 0.20622777374228463, 0.4823186283465475, 0.997713056858629, 0.17057222372386605, 0.046884463299647905, 0.06566549360286444, 0.025867004369501956, 0.02992268928210251, 0.027600969333434477, 0.09838364538154565, 0.020453847864700947, 0.05624769895803183, 0.06246582779567689, 0.07896383744082414, 0.022594324218516704, 0.033469424161012284, 0.06950573675567284, 0.1504280648077838, 0.01057127952662995, 0.1768091882695444, 0.13668590923771262, 0.012727581251965603, 0.07414192587020807, 0.08429682900896296, 0.07030620981822722, 0.009372816784889437, 0.03354222884809133, 0.010250516806991072, 0.05353385415219236, 0.030766414711251855, 0.11989061007625423, 0.1286132275708951, 0.6425598892383277, 14.827599506825209, 52.17122711241245, 50.0134938955307, 30.277058444917202, 8.998756930232048, 3.974399585276842, 4.18950604274869, 8.76689337193966, 4.596386309713125, 12.491002287715673, 11.334199961274862, 0.1968440436758101, 0.20045211334945634, 0.10032611302449368, 0.03878614414134063, 0.06575764607987367, 0.062002675695111975, 0.02021527150645852, 0.3025452874135226, 0.1421396408113651, 0.20708925876533613, 0.22223187668714672, 0.43118854227941483, 1.3509859191253781, 5.540133593603969, 29.64811809360981, 63.081121891736984, 74.4159896671772, 69.37724724411964, 39.044804871082306, 44.49962116777897, 16.642512269318104, 35.40803521871567, 42.31653191149235, 71.21508702635765, 30.47685742378235, 0.21802355797262862, 0.3396993671776727, 0.3410333924693987, 0.12322951020905748, 0.20180760155199096, 0.19543034140951931, 0.2541104145348072, 0.23381616367259994, 0.1462298838305287, 0.10573418767307885, 0.19883982720784843, 0.20694707811344415, 0.16661558212945238, 0.1065328498953022, 0.8316372090484947, 0.41460513370111585, 1.4904685970395803, 3.071248373016715, 3.623050251044333, 2.1458569541573524, 0.8715524640865624, 0.294502543983981, 0.16348551493138075, 0.2111449622316286, 0.15664426406146958, 0.18651358550414443, 0.08450328707112931, 0.22558970900718123, 0.15439776820130646, 0.17624439904466271, 0.3539019066374749, 0.9114268119446933, 3.1348353484645486, 5.862245159223676, 33.41534614562988, 46.57380826771259, 57.9583165794611, 65.16571283340454, 62.82047487795353, 59.92171302437782, 63.61392170190811, 58.276823088526726, 63.023969158530235, 62.54198782145977, 64.36204835772514, 67.50321820378304, 66.58603101968765, 59.40361462533474, 55.33066637814045, 50.81663019955158, 48.96391041576862, 48.32870610058308, 46.48848004639149, 49.338106736540794, 46.88471898436546, 45.08435279130936, 43.815935254096985, 48.43931056559086, 48.36763121187687, 52.467056438326836, 51.72112986445427, 55.202753841876984, 53.518733605742455, 53.905115872621536, 49.38609056174755, 46.7058701813221, 49.313788041472435, 46.81111313402653, 51.26757860183716, 52.15844079852104, 48.75132702291012, 52.27003701031208, 47.91714258491993, 45.63187301158905, 43.637759014964104, 44.75794270634651, 45.29789753258228, 48.615476712584496, 52.229033410549164, 51.65695510804653, 49.97813679277897, 44.75229240953922, 43.907012566924095, 44.83770802617073, 42.14389577507973, 44.8056947439909, 44.5708217471838, 46.64905562996864, 48.595436587929726, 45.237093195319176, 48.06157663464546, 45.49297146499157, 50.02103269100189, 52.451587468385696, 62.338151559233665, 59.92076687514782, 52.85597696900368, 56.903496980667114, 53.94428037106991, 54.673571437597275, 50.846963971853256, 53.16471800208092, 57.58999094367027, 49.21006500720978, 48.25449228286743, 30.41264656931162, 4.9639747850596905, 0.4870177590055391, 0.9736884897574782, 1.1644933512434363, 0.11911337365745567, 0.14992393873399124, 0.1883381704101339, 0.11895936317159794, 0.17860444349935278, 0.2269826311385259, 0.19230080855777487, 0.20380909962113947, 0.21611472446238622, 0.16227934684138745, 0.1242177837411873, 0.11008226021658629, 0.240584802813828, 0.1876239274861291, 0.19068806228460744, 0.22077832109062, 0.22488462418550625, 0.16276784328510985, 0.07814840268110856, 0.13725108437938616, 0.30332950002048165, 0.24973388062790036, 0.17113971436629072, 0.12368783092824742, 0.10410963383037597, 0.1607062015682459, 0.22269068722380325, 0.3017975884722546, 0.35498799523338675, 0.8783538022544235, 18.565154001116753, 66.04353412985802, 58.66119906306267, 48.11878256499767, 8.172737304121256, 4.010287709534168, 3.075484433211386, 10.639481339603662, 28.715954013168812, 19.548204950988293, 20.861496180295944, 0.2102434606058523, 0.28442316921427846, 0.12937185092596337, 0.19585476082284003, 0.24726064380956814, 0.23561777168652043, 0.2398559989524074], [0.1377522715483792, 0.08604980408563279, 0.09909483065712266, 0.07564023297163658, 0.15918788616545498, 0.11812978307716548, 0.20812226895941421, 1.5760140004567802, 10.244724322110415, 47.28314660489559, 51.50297597050667, 37.19527691602707, 20.282775834202766, 12.04933013767004, 22.640178836882114, 25.282718539237976, 47.08796627819538, 44.4319923967123, 1.0067100240848958, 0.10385162619058974, 0.11951310923905112, 0.07250367198139429, 0.07286544670932926, 0.029700111772399396, 0.04035295147332363, 0.04763603625178803, 0.0598970171995461, 0.07760361433611251, 0.0661990384105593, 0.05687530727300327, 0.05580249198828824, 0.09348195293569006, 0.43816268211230636, 0.09021061792736873, 3.273261683061719, 7.038654908537865, 9.973292537033558, 7.561379559338093, 2.7386828558519483, 0.5339810124132782, 0.03208830959920306, 0.05221221159445122, 0.025183208053931594, 0.01176536545244744, 0.027258470036031213, 0.050613484490895644, 0.021176875961828046, 0.024392609266215004, 0.2514823211822659, 0.33823386300355196, 1.1810673493891954, 3.031063391827047, 3.811109997332096, 19.94915373623371, 39.73237417638302, 48.045929074287415, 53.934241309762, 60.98771542310715, 60.0904505699873, 58.69510844349861, 61.8221240490675, 57.222151681780815, 58.74211572110653, 62.469069734215736, 59.64246220886707, 56.70753389596939, 49.58954684436321, 47.03520990908146, 42.396802604198456, 43.54705028235912, 40.41642867028713, 42.06417225301266, 41.31843566894531, 39.112676829099655, 41.68188236653805, 41.10476553440094, 45.20395137369633, 48.706383034586906, 46.61735013127327, 46.15101255476475, 45.85663475096226, 45.70211224257946, 48.20993207395077, 46.50552213191986, 45.825563818216324, 47.259447276592255, 46.78689703345299, 45.93229629099369, 41.65307991206646, 46.713412776589394, 44.600908532738686, 46.20509885251522, 44.96323049068451, 43.46321538090706, 43.79146836698055, 44.04959611594677, 44.9386952072382, 43.03304046392441, 43.33133965730667, 43.46498228609562, 39.34207431972027, 38.134392723441124, 35.337321013212204, 36.774111315608025, 37.62968860566616, 38.366370275616646, 39.762992933392525, 39.888078421354294, 38.300838991999626, 40.627226158976555, 44.334957003593445, 52.38217659294605, 54.132313281297684, 50.655298456549644, 49.89621698856354, 48.28851945698261, 52.29017972946167, 50.426307544112206, 50.470734760165215, 46.16410665214062, 49.359252601861954, 36.99534684419632, 16.770971976220608, 2.5035289116203785, 0.0662308839673642, 0.03213120573491324, 0.030475420462607872, 0.7296158303506672, 0.12884219497209415, 0.10103930209879763, 0.07046479193377309, 0.019680800869537052, 0.0457034614373697, 0.023649634094908834, 0.12744930252665654, 0.033201913320226595, 0.012468745189835317, 0.05233220203081146, 0.04804916759894695, 0.02005805308726849, 0.23882571986177936, 0.21088923298520967, 1.6769459657371044, 1.8908559624105692, 0.39921156596392393, 0.2547697682166472, 0.14448006288148463, 0.08691528928466141, 0.09461264460696839, 0.054790670110378414, 0.06616468439460732, 0.08011454483494163, 0.06978839854127727, 0.062343091412913054, 0.04219958187604789, 0.1143870952364523, 0.07705388328759, 0.43983043637126684, 18.48620753735304, 40.6049707531929, 43.51809963583946, 26.809531711041927, 7.363660018891096, 13.548502642661333, 3.0406509898602962, 1.9093679753132164, 3.4312690794467926, 15.374694149941206, 9.105907380580902, 0.3237442608224228, 0.08794087058049627, 0.11700674294843338, 0.021448151346703526, 0.12101814761990681, 0.03418447231524624, 0.0795293168630451, 0.09498033425188623, 0.050010159247904085, 0.06959376289159991, 0.06539245005114935, 0.16356085776351392, 0.09126095726969652, 0.13020979502471164, 2.6530546881258488, 13.87347450479865, 62.34463781118393, 58.70004057884216, 40.08166663348675, 28.788946196436882, 10.68302795290947, 28.377196490764618, 33.749051839113235, 54.88305039703846, 57.727991938591, 1.5593193587847054, 0.12473887531086802, 0.14072218327783048, 0.05678838322637603, 0.09855447293375619, 0.099808643135475, 0.03626756581070367, 0.09964419805328362, 0.05729953743866645, 0.08132250150083564, 0.020853440582868643, 0.03860433280351572, 0.06388908150256611, 0.11132917963550426, 0.12673651421209797, 0.2641031361417845, 3.2513541961088777, 5.821074368432164, 8.162174820899963, 6.522723343223333, 2.3500857828184962, 0.3541808354202658, 0.024286517400469165, 0.11869924041093327, 0.023347379610640928, 0.03976914471422788, 0.08977260979008861, 0.0582111842231825, 0.044077289712731726, 0.09675062363385223, 0.32073158654384315, 0.293676889850758, 2.467422061599791, 3.4674528753384948, 5.768308974802494, 17.916411012411118, 35.89362636208534, 49.7851337492466, 56.361262276768684, 63.78210827708244, 63.72871734201908, 63.39741311967373, 62.84293167293072, 61.40093185007572, 62.48173825442791, 63.07176299393177, 63.16994972527027, 57.49666415154934, 52.52160631120205, 50.23526519536972, 46.436153054237366, 46.867407113313675, 43.723357021808624, 44.54467535018921, 43.525991812348366, 41.67260326445103, 44.34293657541275, 43.0724785476923, 48.55743482708931, 50.01739628612995, 49.150431007146835, 48.69281016290188, 48.79491828382015, 47.442665845155716, 50.65352015197277, 47.822109684348106, 47.01494559645653, 51.074917539954185, 49.94157895445824, 49.777336567640305, 45.646498426795006, 48.464674204587936, 49.261727035045624, 49.62063677608967, 48.33725184202194, 47.2299038618803, 47.783184573054314, 45.61520330607891, 49.324906244874, 45.2217648178339, 46.3054096698761, 47.00945869088173, 41.78886942565441, 42.6182547211647, 39.1519059240818, 40.505716279149055, 41.328900307416916, 40.58596797287464, 42.306633442640305, 41.95301301777363, 40.92539615929127, 44.760302379727364, 46.916268691420555, 53.55605900287628, 56.12104296684265, 52.99231365323067, 51.46987974643707, 53.67688491940498, 53.896649926900864, 53.26483502984047, 53.631025180220604, 50.40931485593319, 50.22977828979492, 30.884769335389137, 8.312167022377253, 0.6795760779641569, 0.062366699130507186, 0.025049502728506923, 0.05608859362837393, 0.7404780818615109, 0.5319596990011632, 0.16444269247585908, 0.04262196409399621, 0.07270567715750076, 0.05441552188131027, 0.06931360214366578, 0.11615693190833554, 0.020169714771327563, 0.05426525924121961, 0.0865118503861595, 0.05299576740071643, 0.010807732414832572, 0.19986258092103526, 0.4521154146641493, 1.5486824233084917, 1.1644710274413228, 0.7538730755914003, 0.6154862826224416, 0.12521913391537964, 0.05400027170253452, 0.018929489524452947, 0.04209900973364711, 0.0683147604286205, 0.05968826219032053, 0.052598952170228586, 0.12630063603864983, 0.025653918928583153, 0.05897107665077783, 0.048624324626871385, 0.4415249376324937, 37.042806297540665, 54.42107878625393, 50.42036846280098, 33.89708049595356, 12.645972222089767, 9.864541422575712, 1.6597402514889836, 4.199124751612544, 6.62806841544807, 24.336770698428154, 11.518544219434261, 0.4152904625516385, 0.46255579974967986, 0.14575841225450858, 0.06103971310949419, 0.022420396344386972, 0.11136557455756702, 0.04678116747527383, 0.18144001165637746, 0.16028092126362026, 0.21411303343484178, 0.4797998978756368, 0.5035245779436082, 0.26016731921117753, 0.4727760935202241, 4.250836176797748, 38.618171364068985, 80.51409244537354, 68.22540745139122, 56.94046899676323, 33.80903922021389, 16.60562004894018, 39.10701893270016, 43.01364250481129, 67.35593810677528, 66.12561732530594, 1.6079178010113537, 0.27385166147723794, 0.19693943933816627, 0.1820001401938498, 0.15844707435462624, 0.15969691041391343, 0.15707062790170312, 0.11878706616698764, 0.16923034650972113, 0.1865023048594594, 0.1638971545617096, 0.18389300268609077, 0.16532998939510435, 0.2837449056096375, 0.6351216696202755, 1.1487205163575709, 6.642658207565546, 9.23241589218378, 11.091543082147837, 10.261486172676086, 4.280375316739082, 0.9259878087323159, 0.18015968817053363, 0.17433748027542606, 0.2724993199808523, 0.0890078859811183, 0.2921269292710349, 0.2028395578963682, 0.23788201971910894, 0.25244271964766085, 0.9042812359984964, 0.3719702933449298, 3.450431451201439, 6.03970181196928, 9.162423647940159, 31.44725315272808, 45.53022846579552, 51.90327689051628, 59.90271784365177, 67.3084482550621, 65.8884796500206, 63.61392170190811, 64.99833941459656, 64.17859420180321, 64.42691087722778, 64.08521041274071, 65.80497533082962, 59.13249917328358, 52.11200349032879, 53.59012417495251, 47.867296859622, 51.49240493774414, 46.530376598238945, 47.191077545285225, 46.93376675248146, 44.40167002379894, 48.60815450549126, 45.17920330166817, 51.11381605267525, 52.386534959077835, 49.125143364071846, 52.96248145401478, 53.417400643229485, 52.309281304478645, 54.95088055729866, 52.0385230332613, 48.57304058969021, 54.6944323182106, 51.64498955011368, 53.90194684267044, 48.7452207505703, 52.75533176958561, 51.62100903689861, 50.89532017707825, 49.59386721253395, 49.61155526340008, 49.47943635284901, 47.66772776842117, 50.767780020833015, 49.948920160532, 48.17679025232792, 48.57392594218254, 43.56853432953358, 45.38789190351963, 41.699030846357346, 43.85726943612099, 44.93743747472763, 43.705049604177475, 46.38640232384205, 46.30316399037838, 43.99129204452038, 47.2563998401165, 48.42684343457222, 61.17353305220604, 58.075004518032074, 57.310588136315346, 54.74309630692005, 53.61853525042534, 54.118474423885345, 57.868876978755, 54.65593658387661, 51.48527272045612, 50.462477803230286, 42.62658387422562, 32.023895010352135, 4.868006659671664, 0.631522728363052, 0.21447166887810454, 0.19175221299519762, 2.9661469627171755, 0.28065786813385785, 0.20187497371807694, 0.2503279550001025, 0.06416908639948815, 0.3729550342541188, 0.11556391880731098, 0.3721621830482036, 0.1303454744629562, 0.17162032920168713, 0.19144583959132433, 0.17498864064691588, 0.1557934659649618, 0.6408613210078329, 1.3070284528657794, 2.796047665178776, 2.36172242090106, 0.9341951902024448, 0.8536918787285686, 0.14490189962089062, 0.18770813156152144, 0.22300905373413116, 0.11513597419252619, 0.2513776783598587, 0.13962692173663527, 0.16229963715886697, 0.19249612698331475, 0.11799073428846896, 0.1599512592656538, 0.1993470554589294, 0.3065063967369497, 42.07323096692562, 63.23744170367718, 63.14589701592922, 48.381519466638565, 13.509071208536625, 15.944476425647736, 1.1895970604382455, 3.1887525552883744, 23.67710519582033, 47.847344130277634, 18.069894276559353, 0.46363152796402574, 0.5542908632196486, 0.2294011865160428, 0.10601299029076472, 0.15575091121718287, 0.18067966651869938, 0.22451239259680733], [0.019817779066215735, 0.0609064753371058, 1.622753986157477, 2.9737945273518562, 0.47835668781772256, 0.09810308387386613, 0.07490924719604664, 0.6473000161349773, 4.277250459417701, 25.231704376637936, 58.193858340382576, 36.58481687307358, 14.92294019088149, 15.651224311441183, 20.853376016020775, 31.762172654271126, 47.00260005891323, 47.8556314855814, 1.8553133821114898, 0.26150452089495957, 0.15123725810553879, 0.05846693573403172, 0.09967922000214458, 0.03394281418877654, 0.07395234424620867, 0.018312046777282376, 0.026027766543847974, 0.017573095901752822, 0.09289528519730084, 0.04200861614663154, 0.1305443700402975, 0.3420262673171237, 0.7468572864308953, 2.1032215794548392, 7.453993521630764, 13.511102199554443, 18.24134487658739, 9.32279309257865, 5.864047212526202, 2.4770944425836205, 0.17652353562880307, 0.09302879014285281, 0.01029359476888203, 0.054365690375561826, 0.015518163199885748, 0.022144495524116792, 0.09724194023874588, 0.21629705530358478, 0.29596300155390054, 0.5036056798417121, 2.499708691611886, 1.169603958260268, 2.7094498369842768, 7.086031241342425, 17.440406754612923, 33.17184001207352, 45.551621317863464, 53.89108322560787, 57.32534274458885, 57.607143223285675, 57.11378909647465, 56.209300830960274, 56.78911551833153, 57.97937124967575, 61.134554743766785, 55.28262555599213, 51.01697064936161, 47.086134776473045, 44.277135506272316, 42.35300235450268, 40.809680968523026, 40.3054404258728, 40.857186019420624, 40.813427567481995, 40.60927972197533, 40.80589637160301, 44.338703602552414, 47.59258300065994, 47.02316835522652, 46.088798493146896, 45.01976765692234, 45.77698342502117, 45.53918078541756, 42.9383609443903, 44.27237816154957, 43.59516330063343, 45.67145548760891, 42.76629097759724, 39.926239773631096, 44.805546551942825, 43.77386771142483, 45.084960758686066, 44.6871031075716, 44.89644527435303, 43.46728876233101, 43.5639213770628, 42.87145413458347, 43.30744653940201, 41.69060289859772, 46.21692381799221, 42.03861482441425, 37.891878336668015, 37.91987143456936, 38.25378991663456, 37.67475038766861, 38.01099814474583, 38.88491325080395, 39.425867423415184, 38.587343618273735, 42.28764586150646, 45.48229023814201, 48.73389355838299, 52.199725583195686, 48.95422473549843, 42.809988632798195, 51.50113306939602, 47.13721923530102, 48.03156964480877, 43.55292096734047, 46.346318274736404, 36.93305678665638, 18.183852061629295, 2.9557889560237527, 0.17465044395066798, 0.06723558122757822, 0.0225993930871482, 0.1373638166114688, 0.277947515132837, 0.8872703206725419, 0.06604836758924648, 0.034789137134794146, 0.07010757399257272, 0.009911329343594844, 0.045744186791125685, 0.06363242457155138, 0.06499484443338588, 0.06232782543520443, 0.01915014672704274, 0.04794096988916863, 0.16387359879445285, 0.6338443444110453, 1.6404212568886578, 4.234031578525901, 0.6962447741534561, 0.8930967736523598, 0.5546415725257248, 0.18338614550884813, 0.14887347322655842, 0.025731742389325518, 0.013482016111083794, 0.14153370691929013, 0.04590253513015341, 0.08973647461971268, 0.03405922376259696, 0.09568855093675666, 0.043141404385096394, 0.1325204421300441, 2.321630297228694, 45.64570426940918, 48.59337329864502, 48.85148964822292, 29.01001263409853, 6.439461736008525, 9.64003236964345, 9.781369585543871, 1.3843598845414817, 6.035099783912301, 20.406702384352684, 9.613720681518316, 0.14458834222750738, 0.3771809715544805, 0.2298228006111458, 0.05950974598817993, 0.0796197030285839, 0.17412844696082175, 0.01026332070978242, 0.051645132843987085, 0.04816559943719767, 0.6976817501708865, 3.0480729416012764, 0.1678033746429719, 0.13068649132037535, 0.07045253907563165, 0.5360052944160998, 6.6123277600854635, 36.67849704623222, 66.4306877553463, 45.704114735126495, 23.72472044080496, 17.39372055977583, 28.758344538509846, 43.170600682497025, 53.01224358379841, 62.780193239450455, 4.005366023629904, 0.20972281432477757, 0.07307765641598962, 0.0852099155599717, 0.07020458753686398, 0.04481539268454071, 0.08917063154513016, 0.007811529176251497, 0.06881514607812278, 0.03600750242185313, 0.03380594360351097, 0.06495019682915881, 0.051126783509971574, 0.6098163337446749, 0.8012983901426196, 1.622589526232332, 7.168388972058892, 13.330911118537188, 15.523054338991642, 12.758453786373138, 6.436141664162278, 2.09318608045578, 0.09524876164505258, 0.04080469676409848, 0.04289913398679346, 0.032491759629920125, 0.004907733064101194, 0.07675860499148257, 0.12292848026845604, 0.17550533870235085, 0.27512218861375004, 2.9005947802215815, 4.410920161753893, 1.04827587492764, 4.317843206226826, 8.809486236423254, 17.398922480642796, 30.01640383154154, 43.910595774650574, 54.780383706092834, 56.01127825677395, 56.3670189678669, 54.825464487075806, 56.538135185837746, 56.976061686873436, 56.82155057787895, 61.46517500281334, 55.72638474404812, 51.83271087706089, 48.88738252222538, 45.37567175924778, 45.03001570701599, 43.41730624437332, 42.582506239414215, 43.140046522021294, 44.30620774626732, 41.9716852158308, 44.222733825445175, 48.52161414921284, 49.22756686806679, 50.915614888072014, 48.98749954998493, 48.170174807310104, 47.540335804224014, 47.018331214785576, 45.14937110245228, 46.32685571908951, 45.47196239233017, 49.30225946009159, 44.227175787091255, 44.47356976568699, 47.30972237884998, 45.678534507751465, 45.98316416144371, 46.41727186739445, 46.217467188835144, 46.62576287984848, 45.71940891444683, 46.73923999071121, 46.80619619786739, 43.29656392335892, 49.25489120185375, 44.31763373315334, 41.963926032185555, 39.27044816315174, 42.493401020765305, 40.936799347400665, 41.40697091817856, 42.18834578990936, 43.05915646255016, 43.185951858758926, 46.084930300712585, 47.95453257858753, 51.16849131882191, 53.161035999655724, 51.70918710529804, 43.75730820000172, 50.128498524427414, 50.612284764647484, 50.81593483686447, 43.36957320570946, 43.16900856792927, 28.923603370785713, 7.600845191627741, 0.8733646105974913, 0.1600191806210205, 0.09588430722942576, 0.0338827336236136, 0.09527519694529474, 0.1344318880001083, 1.0909397481009364, 0.5374555103480816, 0.14379421452758834, 0.06846608433988877, 0.107001471624244, 0.06776727808755822, 0.05048268838436343, 0.06355638412060216, 0.048239313255180605, 0.09911204848322086, 0.1024535387114156, 0.13560272986069322, 1.117933380883187, 2.634076368995011, 4.27555812522769, 2.151589896529913, 0.7213165413122624, 0.3022983600385487, 0.12937671941472217, 0.07396726141450927, 0.07985166128491983, 0.03116421699814964, 0.06715890995110385, 0.047343273836304434, 0.017805686838983092, 0.053343177860369906, 0.017527837881061714, 0.18063779454678297, 0.2148298590327613, 4.036739515140653, 63.31837736070156, 60.98508596420288, 54.19146850705147, 35.24663507938385, 15.089355111122131, 8.250548578798771, 4.97189593501389, 6.333783706650138, 11.565559096634388, 37.2231712192297, 16.573927849531174, 0.12878743931651115, 2.1358896140009165, 2.467006458900869, 0.2712085470557213, 0.04551300036837347, 0.04389495887153316, 0.06580706569366157, 0.26531126350164413, 0.2817621541908011, 2.8720416873693466, 6.1089663952589035, 0.49379297357518226, 0.20208433357765898, 0.1507968083024025, 1.178338739555329, 20.812678299844265, 60.17429307103157, 78.74773442745209, 56.78614407777786, 22.508020028471947, 24.254134632647038, 39.54830825328827, 53.52989740669727, 61.149845123291016, 77.68026530742645, 5.708017610013485, 0.5284499935805798, 0.44099284743424505, 0.24957440793514252, 0.21909655508352444, 0.13190394005505368, 0.20613879023585469, 0.14790373854339123, 0.1196461911604274, 0.12263472337508574, 0.27955530385952443, 0.14490719855530187, 0.25285838171839714, 1.4197006006725132, 2.4667570972815156, 5.090811504051089, 11.364007461816072, 15.81352025270462, 19.41667690873146, 15.271752923727036, 10.69300526753068, 4.220934631302953, 0.2755049290135503, 0.20905957178911194, 0.1434903050540015, 0.17022629384882748, 0.0722157557902392, 0.14044994866708294, 0.29713880096096545, 0.29806883074343204, 0.5560571746900678, 2.2910884860903025, 6.770243486389518, 3.0708132963627577, 6.418161503970623, 13.198445476591587, 29.98523600399494, 39.73213478922844, 46.431410908699036, 59.79783967137337, 60.609890297055244, 60.663999393582344, 60.253146439790726, 60.182922407984734, 60.607181042432785, 60.42751148343086, 63.98071601986885, 59.75374683737755, 54.83888916671276, 52.305318117141724, 48.13256062567234, 47.44265824556351, 47.032272666692734, 46.08999542891979, 48.52294407784939, 47.53561645746231, 45.751646384596825, 45.786608308553696, 50.635455921292305, 51.53859905898571, 53.70078183710575, 49.374611377716064, 52.01786354184151, 51.679176315665245, 52.318902388215065, 48.09103265404701, 48.2271109521389, 48.85122366249561, 53.335275650024414, 46.01880244910717, 46.44293189048767, 52.5069884955883, 48.78504641354084, 49.93996024131775, 50.76828919351101, 50.709057971835136, 48.845960944890976, 48.25906723737717, 49.47931095957756, 50.55798187851906, 46.88352584838867, 52.7634709328413, 45.8628436177969, 45.421254113316536, 42.733232751488686, 45.46109117567539, 43.00865337252617, 44.6177264302969, 46.40450455248356, 46.786114275455475, 45.42142130434513, 49.38854143023491, 49.88309629261494, 54.58495259284973, 57.53613643348217, 53.63555073738098, 48.71629290282726, 54.5633165538311, 52.4932674318552, 52.23662160336971, 44.62868124246597, 48.71873617172241, 44.09851089119911, 33.15676622092724, 5.6287956610322, 0.39941957511473447, 0.15798425622051582, 0.08949974435381591, 0.21890600124606863, 0.5044178862590343, 2.1181452786549926, 0.28491224453318864, 0.2126345713622868, 0.15357750206021592, 0.10798493603942916, 0.09763105568708852, 0.27171302936039865, 0.11124125740025192, 0.1746789424214512, 0.11643394595012069, 0.178725547157228, 0.23336042562732473, 1.3771602208726108, 4.107036693021655, 5.52969460375607, 2.5965507701039314, 2.0104756811633706, 1.418290757574141, 0.4009359609335661, 0.26474939833860844, 0.11286941808066331, 0.1388142551877536, 0.24610292311990634, 0.11354544782079756, 0.13226533628767356, 0.1775690881186165, 0.29800019692629576, 0.2973309578374028, 0.4054294276284054, 2.9372640000656247, 74.17463421821594, 65.61893731355667, 65.56017726659775, 46.86642296612263, 16.64865653961897, 12.703112605959177, 7.477288646623492, 5.42486060410738, 20.23488510400057, 58.59024927020073, 21.08350306749344, 0.2858816081425175, 0.7916436425875872, 0.815670940792188, 0.43272692535538226, 0.18482699553715065, 0.24744911963352934, 0.21163221186725423], [0.05789712588011753, 0.06937926737009548, 7.018395820632577, 14.168764259666204, 6.975975371897221, 0.3020921617280692, 0.05145341012394056, 0.36644960520789027, 0.9922026994172484, 12.727914825081825, 44.57592487335205, 24.77482069283724, 6.261408515274525, 8.609744254499674, 28.12262535095215, 33.65943744778633, 48.61977808177471, 48.48764397203922, 4.301206273958087, 0.22092801227699965, 0.19360170437721536, 0.10055508042569272, 0.09881956808385439, 0.040789141348795965, 0.025254025640606415, 0.030214616781449877, 0.023533912863058504, 0.06437809744966216, 0.07835705750039779, 0.042134476971114054, 0.27180226519703865, 0.32667589257471263, 3.2330396538600326, 10.39954986423254, 15.89368550106883, 22.339937947690487, 25.383753217756748, 22.356573455035686, 15.586083456873894, 6.4970523957163095, 1.6320918663404882, 0.06902191584231332, 0.03596119240683038, 0.08799501025350764, 0.09528674476314336, 0.070947774220258, 0.051211970931035466, 0.22063106414861977, 0.40664649044629186, 5.533066922798753, 1.849297711160034, 0.8682051405776292, 3.3120668632909656, 6.2790775671601295, 9.61634824052453, 13.394263219088316, 23.533875681459904, 41.030380725860596, 42.159509137272835, 44.41577106714249, 43.89996014535427, 44.05497282743454, 47.43323855102062, 47.103328853845596, 49.11840632557869, 52.841826528310776, 50.16874596476555, 45.72062864899635, 44.23687666654587, 40.74391029775143, 40.83377547562122, 40.926422104239464, 40.41502274572849, 38.851022869348526, 42.38103345036507, 44.1380325704813, 46.526611000299454, 44.95411857962608, 48.127119317650795, 46.49288401007652, 43.09333562850952, 43.85181672871113, 43.54623332619667, 43.45136761665344, 43.308962658047676, 43.72645005583763, 44.60911229252815, 40.69050416350365, 39.09810461103916, 41.56773269176483, 43.44320185482502, 45.11592149734497, 42.935906276106834, 41.97404108941555, 42.46427558362484, 42.63899400830269, 44.51522693037987, 46.180012598633766, 44.57937888801098, 43.614599257707596, 42.23154567182064, 39.55772414803505, 36.33117288351059, 38.13816212117672, 36.90244942903519, 36.506457477808, 37.797711789608, 39.423116371035576, 37.797920778393745, 45.604590475559235, 43.01349811255932, 42.86990761756897, 45.31978435814381, 45.42561627924442, 41.94874204695225, 41.28397151827812, 42.23858669400215, 41.85178264975548, 34.82569366693497, 27.168751135468483, 16.38373665511608, 1.5478065703064203, 0.4658867960097268, 0.04413012691657059, 0.017905548374983482, 0.16605346463620663, 0.004586245822792989, 0.06808480597101152, 1.6702865855768323, 0.6487910205032676, 0.21603374130791053, 0.14997060497989878, 0.06969974157982506, 0.023944828899402637, 0.07247894362080842, 0.07467391958925873, 0.04700390083598904, 0.027214440269744955, 0.20882860058918595, 1.2188027682714164, 4.65151185169816, 7.035782262682915, 4.190990813076496, 4.911270663142204, 6.174244517460465, 6.676842598244548, 2.0572309847921133, 2.048230217769742, 0.20470310555538163, 0.016456579251098447, 0.09398795664310455, 0.06805262644775212, 0.0387010531994747, 0.0624840178352315, 0.04000230153906159, 0.07124025461962447, 0.3947135276393965, 11.169434152543545, 58.15960317850113, 62.03353330492973, 54.9964515119791, 28.965767808258533, 7.142400266602635, 7.614341592416167, 1.0754681657999754, 3.7802043557167053, 6.308408193290234, 17.643367163836956, 7.359589962288737, 4.251044215634465, 33.68948243558407, 39.1816621273756, 2.828207239508629, 0.07628771229065023, 0.038930102236918174, 0.05280347693769727, 0.08582907452364452, 0.12134681513998657, 5.553690316155553, 16.91559411585331, 9.006474316120148, 0.3480556234717369, 0.15197536849882454, 0.42223402590025216, 2.4819130590185523, 21.603609658777714, 61.064076125621796, 30.180993899703026, 16.188845112919807, 12.180287260562181, 31.97427347302437, 41.564529463648796, 54.34674337506294, 62.19790868461132, 4.844401376321912, 0.31557692564092577, 0.027225559497310314, 0.008038499272515764, 0.1374307880178094, 0.13302060513524339, 0.08060790234594606, 0.07966308898176067, 0.01833672318753088, 0.034883386178989895, 0.030900635829311796, 0.029758648670394905, 0.05565249652136117, 0.39183503366075456, 3.7946528429165483, 10.949747040867805, 16.026954799890518, 23.606159202754498, 26.806809157133102, 19.61794450879097, 18.81666250526905, 6.490714335814118, 1.121184581425041, 0.1012325647752732, 0.04253106584656052, 0.06012047415424604, 0.2498516149353236, 0.16405661241151392, 0.12010371036012657, 0.5922338459640741, 2.5525773921981454, 4.456596560776234, 1.5888290503062308, 2.3937266785651445, 4.5057103503495455, 7.334687523543835, 13.434349168092012, 18.727880269289017, 21.385009288787842, 38.52240510284901, 46.6354713588953, 44.84356351196766, 45.16543664038181, 44.29136574268341, 45.426064655184746, 44.389168694615364, 47.20514819025993, 50.91368839144707, 50.98263569176197, 47.31269761919975, 45.7938165217638, 43.41113157570362, 44.138507544994354, 42.36005857586861, 45.02498857676983, 43.28455276787281, 44.99223433434963, 45.91444864869118, 50.310877338051796, 46.91878415644169, 50.86548797786236, 51.78433187305927, 47.320460602641106, 48.36209870874882, 45.702306032180786, 43.97212967276573, 45.906016901135445, 46.02786876261234, 46.253234669566154, 45.37365406751633, 44.135368913412094, 45.12899659574032, 45.39071135222912, 46.22515417635441, 44.97279457747936, 44.55199755728245, 46.04657515883446, 45.561842769384384, 47.317819744348526, 48.04767698049545, 47.39887319505215, 45.22854745388031, 44.55677010118961, 41.906583309173584, 40.11857785284519, 40.24577222764492, 40.96419207751751, 39.56729583442211, 42.780601009726524, 41.803031265735626, 41.83495715260506, 46.10392928123474, 44.94136646389961, 45.20001098513603, 44.89600069820881, 47.06489011645317, 47.130854576826096, 41.18120223283768, 41.314312890172005, 33.58877643942833, 23.98200273513794, 14.518132712692022, 2.5930630322545767, 0.5437365733087063, 0.30341662815771997, 0.012840329254686367, 0.06764336911146529, 0.15128059952985495, 0.03053594260563841, 0.07015972470981069, 0.4487137362593785, 1.383867810945958, 0.6902137259021401, 0.05932936699537095, 0.031297970563173294, 0.05611574510112405, 0.057453020999673754, 0.0353566092235269, 0.05839820914843585, 0.03417051993892528, 0.2964052028255537, 1.0199709562584758, 4.931143121793866, 8.426476288586855, 7.092909822240472, 5.690589370205998, 5.218762988224626, 8.325935583561659, 2.3134780721738935, 2.154902368783951, 0.2210258718696423, 0.02813864604831906, 0.09132088569458574, 0.037747964888694696, 0.09531783332931809, 0.061026892508380115, 0.15699396404670551, 0.13288658810779452, 0.3833658224903047, 20.393234007060528, 69.59743022918701, 67.79962509870529, 62.15739145874977, 41.00012294948101, 13.769563380628824, 6.020106263458729, 4.702559262514114, 8.82616639137268, 7.383265541866422, 36.583638936281204, 9.078682791441679, 2.39332081284374, 63.457161113619804, 63.23079206049442, 3.6966432770714164, 0.025988002271333244, 0.02869597668905044, 0.033036317909136415, 0.19227425451390445, 0.5952603835612535, 12.24633626639843, 34.36151437461376, 20.599378645420074, 1.0245893709361553, 0.3060625627404079, 0.6497256516013294, 4.0329221449792385, 48.35842430591583, 77.14025348424911, 33.23826424777508, 13.216274119913578, 18.154513835906982, 45.75132340192795, 55.980279520154, 61.33929915726185, 76.74610063433647, 13.589059766381979, 0.42635368765331805, 0.25462377292569727, 0.18626692530233413, 0.24908245308324695, 0.33601252594962716, 0.17427919199690223, 0.16100355045637116, 0.06308345793513581, 0.17305360932368785, 0.27884304989129305, 0.33042145252693444, 0.6516644975636154, 1.3118702243082225, 8.12712550163269, 18.58762789517641, 19.329657778143883, 28.934026211500168, 30.737829320132732, 25.858676433563232, 25.982943065464497, 10.435528233647346, 4.1099221631884575, 0.4764523368794471, 0.19691294466610998, 0.15787974698469043, 0.3728833724744618, 0.37871306121814996, 0.32800596964079887, 1.976101656910032, 1.467172997072339, 7.209972515702248, 3.847783016972244, 3.3668093383312225, 5.817978484556079, 9.069419838488102, 18.30755442380905, 26.076332554221153, 32.36348278820515, 44.43253956735134, 45.006848350167274, 45.701386481523514, 44.492002576589584, 44.44195546209812, 47.83174976706505, 48.54064352810383, 50.21591663360596, 55.24655029177666, 53.53284224867821, 48.33847537636757, 46.256734281778336, 44.40395750105381, 46.98448643088341, 45.8306023478508, 46.60403564572334, 43.41349124908447, 48.99857595562935, 49.87004019320011, 53.273696154356, 50.2084044367075, 53.610000908374786, 52.14969366788864, 49.27130252122879, 51.45616628229618, 51.67571850121021, 47.10654728114605, 47.832912504673004, 50.188482105731964, 48.81264813244343, 47.345182076096535, 44.64347384870052, 48.20329003036022, 48.31690393388271, 50.561914667487144, 48.8174282759428, 46.82210594415665, 48.200839161872864, 48.718249797821045, 52.019208669662476, 53.25284667313099, 51.21458284556866, 48.91232058405876, 47.540757581591606, 45.09242355823517, 43.03715564310551, 42.936027869582176, 45.309004336595535, 42.90506713092327, 44.09109368920326, 46.557970717549324, 43.44932332634926, 49.6634528785944, 48.408068642020226, 49.34399642050266, 49.58523407578468, 48.75177159905434, 49.30794395506382, 45.248747169971466, 43.906119614839554, 43.9065869897604, 41.01673565804958, 36.23931281268597, 27.035630978643894, 2.589225238189101, 0.7495142344851047, 0.12671680276980624, 0.14930616016499698, 0.36463968513999134, 0.13185233110561967, 0.17073626804631203, 1.8443907494656742, 3.396103153936565, 0.45055850758217275, 0.29515397152863443, 0.1152409658243414, 0.14475557778496295, 0.25939409038983285, 0.1772263049497269, 0.11671291184029542, 0.1612052068230696, 0.457171518355608, 1.1895772302523255, 6.331355161964893, 9.341611582785845, 10.284986961632967, 11.256705969572067, 7.849129093810916, 10.591997187584639, 3.7027970468625426, 2.927261986769736, 0.46485203434713185, 0.13455581181915477, 0.13144030555849895, 0.19803962873993441, 0.18751405994407833, 0.17369481007335708, 0.2165864483686164, 0.2213950754958205, 0.5137681751511991, 17.757647931575775, 79.78831619024277, 69.91214454174042, 68.0018350481987, 53.822029531002045, 16.54361877590418, 12.651622518897057, 13.748612254858017, 9.847679827362299, 21.398954540491104, 64.42292869091034, 12.231246326118708, 10.68805793300271, 77.57419779896736, 61.628323048353195, 3.119729496538639, 0.16489170666318387, 0.16992493736324832, 0.15466085955267772], [0.054459505263366736, 0.1359841343946755, 9.267203975468874, 5.438352255150676, 1.397357324603945, 2.6215710025280714, 0.27520890114828944, 0.2423571702092886, 0.5728675320278853, 11.224162615835667, 40.67637652158737, 16.087726838886738, 8.55389580130577, 19.792070165276527, 28.547155670821667, 36.054927706718445, 50.87831608951092, 52.93336741626263, 3.685976774431765, 0.8519611903466284, 0.0758798056631349, 0.08782342571066692, 0.06771673040930182, 0.04026778260595165, 0.044745968480128795, 0.025614616642997134, 0.04679882687923964, 0.021280685723468196, 0.01944801140780328, 0.16864942299434915, 1.3412895519286394, 0.31737636658363044, 7.470119381323457, 18.905906416475773, 34.083281904459, 25.312018766999245, 29.06474109739065, 39.26281817257404, 25.114444568753242, 6.89440087415278, 4.167368905618787, 1.1988366208970547, 0.4634540359256789, 0.2990761329419911, 0.16678431682521477, 0.449403072707355, 0.1600228319875896, 0.5302561435382813, 5.115091251209378, 1.0494151012971997, 1.4194058789871633, 1.903901849873364, 2.916649393737316, 6.701333709061146, 8.95865198224783, 14.37764760106802, 11.94878563284874, 19.172070734202862, 44.61264230310917, 40.67196115851402, 44.487560614943504, 42.81103737652302, 43.938379883766174, 41.6589467972517, 44.29002441465855, 42.1127450466156, 45.96718981862068, 43.05244982242584, 47.80936896800995, 43.86359229683876, 41.964252814650536, 40.50036996603012, 41.818207651376724, 40.372791811823845, 43.569210693240166, 44.71996754407883, 48.00500527024269, 45.80625705420971, 47.16076277196407, 46.11428752541542, 44.849700182676315, 45.84476798772812, 41.31821148097515, 38.85223500430584, 43.25139194726944, 43.84634882211685, 46.10421046614647, 43.45834024250507, 41.71017184853554, 44.7791113704443, 45.311816185712814, 43.28865274786949, 42.667142897844315, 42.186537086963654, 44.4985344260931, 40.290906205773354, 43.39649856090546, 44.60467413067818, 45.86081452667713, 43.45525860786438, 40.03929130733013, 38.81313130259514, 39.97205391526222, 35.81069961190224, 34.29177671670914, 36.808514669537544, 38.413259759545326, 36.73848442733288, 37.380573973059654, 40.463029369711876, 39.239194840192795, 36.575389578938484, 38.93970251083374, 36.55916064977646, 44.73041318356991, 38.399299308657646, 29.145030789077282, 15.185475703328848, 10.111622214317322, 3.9269363321363926, 0.2696191635914147, 0.3303175518522039, 0.062240693587227724, 0.07536580160376616, 0.00047177211683901987, 0.042083535954589024, 0.10087700182339177, 0.05711566664103884, 0.07270756221259944, 0.3812599933007732, 1.1974255903623998, 0.1381464855512604, 0.08581429836340249, 0.054640084636048414, 0.11452310864115134, 0.10775619128253311, 0.12771040492225438, 0.06581636480404995, 0.31864671560470015, 2.3574008652940392, 5.534757357090712, 4.180125296115875, 3.404703992418945, 15.947375670075417, 14.491137061268091, 8.439700528979301, 3.459621020592749, 2.3322063172236085, 0.7188509486149997, 0.23476464324630797, 0.6191295152530074, 0.14373904326930642, 0.13870260649127886, 0.10301805334165692, 0.05873818699910771, 0.052445806286414154, 0.2794492954853922, 33.9212092012167, 63.08300279080868, 69.53051581978798, 56.6969058662653, 28.85136354714632, 14.135941620916128, 15.225349813699722, 6.333604641258717, 0.4051692603388801, 13.004406988620758, 8.526761457324028, 5.740127312019467, 2.9635695135220885, 46.59814976155758, 69.24610868096352, 6.626307209953666, 0.2316104859346524, 0.046949208262958564, 0.08700531179783866, 0.040412048692815006, 0.4233590030344203, 14.073825404047966, 19.38737478107214, 17.504334524273872, 10.387834142893553, 0.07969451151438989, 0.18281613156432286, 0.9428023220971227, 22.03907009214163, 51.40366069972515, 24.939862936735153, 11.392199099063873, 21.96816399693489, 41.29546210169792, 45.3606853634119, 58.45082335174084, 65.89097991585732, 25.06704021245241, 0.8106384670827538, 0.15491143829422072, 0.08882647540303878, 0.043504533532541245, 0.06434222945244983, 0.04822898998099845, 0.09007270462461747, 0.011466039668448502, 0.07541319515439682, 0.0493990711402148, 0.05807246569020208, 1.61053906660527, 0.8017920074053109, 13.169883359223604, 24.10980887711048, 34.58084240555763, 34.93057943880558, 33.05743955075741, 44.25081431865692, 31.032438911497593, 8.619921058416367, 3.660330050624907, 0.6008736323565245, 0.3264497750205919, 0.32335317868273705, 0.3053781541530043, 0.27410811802838, 0.21074650314403698, 0.5547552101779729, 1.2185734743252397, 3.6027237167581916, 2.7292610239237547, 3.423271933570504, 3.5384064679965377, 7.862094948068261, 11.306863278150558, 16.786150261759758, 18.964124992489815, 21.062607988715172, 40.968759432435036, 43.044124469161034, 45.14403618872166, 44.0605965256691, 43.869102001190186, 41.12722992897034, 45.37918657064438, 40.98294787108898, 46.65231965482235, 43.804915845394135, 47.21318855881691, 46.37648865580559, 45.234528332948685, 43.49068030714989, 43.735603764653206, 42.61100471019745, 46.48886002600193, 47.47187867760658, 49.20050472021103, 48.31170581281185, 49.052073284983635, 48.77880334854126, 48.815174996852875, 50.67100681364536, 45.97911737859249, 41.14573873579502, 44.9678510427475, 45.60277797281742, 49.411374405026436, 48.94777648150921, 44.85775575041771, 47.948403507471085, 47.62328915297985, 44.336894899606705, 44.78603459894657, 44.049565717577934, 48.72367970645428, 43.39175261557102, 45.177785977721214, 47.6748675853014, 47.13009461760521, 46.69586531817913, 42.331852689385414, 41.64944350719452, 42.794314473867416, 40.75959965586662, 40.32821640372276, 39.730664268136024, 40.79184092581272, 39.31612931191921, 41.66351035237312, 41.50005832314491, 40.80400787293911, 37.427558451890945, 39.67372812330723, 36.76683470606804, 46.889917105436325, 43.34830194711685, 24.53883435577154, 6.205906793475151, 3.659192961640656, 1.6741507407277822, 0.20747150934766978, 0.09779781627003103, 0.060932561827939935, 0.05580277771514375, 0.12556343106552958, 0.1396565037430264, 0.042095989192603156, 0.05104547381051816, 0.1098801288753748, 0.2213263971498236, 1.9844739139080048, 0.1878848220803775, 0.06371305891661905, 0.08115046424791217, 0.032092632609419525, 0.05111527651024517, 0.08729017776204273, 0.051311934512341395, 0.4714626999339089, 3.607011786662042, 7.938341181725264, 6.596902962774038, 6.420686943456531, 17.121362574398518, 17.68650434911251, 8.359539080411196, 4.009137796238065, 3.560528880916536, 0.3973302216036245, 0.17104155791457742, 0.9803742310032248, 0.05586296960245818, 0.1155098459275905, 0.09343228841316886, 0.0545564074855065, 0.026724457675300073, 0.40714346221648157, 47.182896584272385, 70.3780147433281, 72.81137377023697, 66.2114243209362, 41.29349760711193, 13.005047254264355, 12.22991544753313, 10.541913975030184, 1.8529039551503956, 14.503228962421417, 28.40683490037918, 4.691857611760497, 44.65306453406811, 74.60415557026863, 77.77216717600822, 9.366705436259508, 0.31639040855225176, 0.04075627904967405, 0.06567007265402935, 0.19070459733484313, 0.8095522003713995, 18.922511525452137, 35.81046022474766, 41.804881766438484, 25.75463991612196, 0.44218527094926685, 0.38778287766035646, 2.056770734488964, 42.44792126119137, 64.22118991613388, 28.779712691903114, 21.73107761889696, 28.55389080941677, 45.18811762332916, 56.32505401968956, 63.313502222299576, 77.70219773054123, 39.181988909840584, 1.5676330751739442, 0.24034802801907063, 0.26017940137535334, 0.24646610050695017, 0.1345879616565071, 0.17674350820016116, 0.12332143262028694, 0.08609793978394009, 0.1209457140066661, 0.1352648003376089, 0.5917230702470988, 2.7232307475060225, 3.3363651344552636, 18.24940424412489, 27.558993995189667, 33.076506927609444, 37.60673023760319, 33.71709555387497, 46.914057210087776, 34.2096783220768, 14.164530336856842, 9.355428591370583, 1.822047948371619, 0.8922368916682899, 0.5336281657218933, 0.41524299478624016, 0.5742704879958183, 0.6428448739461601, 1.5202403557486832, 11.348672434687614, 6.002661399543285, 5.34782781265676, 5.439414298161864, 5.590730253607035, 8.941417057067156, 13.823997359722853, 24.58075750619173, 24.339200668036938, 29.654640443623066, 48.57039213180542, 43.988176211714745, 46.6132615506649, 41.92072615027428, 42.54741132259369, 39.893113151192665, 45.06968937814236, 40.83918258547783, 48.425775691866875, 43.846470415592194, 49.17585164308548, 49.15842577815056, 47.15515047311783, 46.100262477993965, 46.37171231210232, 45.86877129971981, 47.69092172384262, 49.04408611357212, 52.787329852581024, 50.319271087646484, 51.18736870586872, 52.990288361907005, 51.77439920604229, 51.51371419429779, 48.71927574276924, 43.00873316824436, 48.087305054068565, 50.81218063831329, 54.05591458082199, 50.639605298638344, 47.57811717689037, 51.42175532877445, 53.07956837117672, 48.80481295287609, 48.07702660560608, 48.0797016620636, 53.1992581486702, 45.49228370189667, 49.67572622001171, 52.01867289841175, 50.68669617176056, 48.93222391605377, 47.012559324502945, 45.35173684358597, 43.90470989048481, 44.0450743585825, 41.585272550582886, 45.417256727814674, 44.27627295255661, 43.080887496471405, 43.544797003269196, 44.50921945273876, 44.37447868287563, 39.92747850716114, 42.46061258018017, 40.92014864087105, 48.57314698398113, 44.01210352778435, 40.39965257048607, 29.439761973917484, 19.526804499328136, 7.606979962438345, 0.4043393017491326, 0.7270167104434222, 0.10371357930125669, 0.29476265190169215, 0.19279258529422805, 0.18937238288344815, 0.21778751048259437, 0.13590227550594136, 0.11373115543392487, 1.2753972876816988, 5.389916729182005, 0.22164314577821642, 0.2158258657436818, 0.14490624860627577, 0.24173210375010967, 0.30093648936599493, 0.15863388776779175, 0.15385542152216658, 0.3883845516247675, 3.81515440531075, 10.25321401655674, 9.993016328662634, 15.011562835425138, 23.007275238633156, 21.469853036105633, 14.806410893797874, 7.293052207678556, 4.544141488149762, 1.7540159239433706, 0.6415950378868729, 1.2400525342673063, 0.2955461817327887, 0.2726890129270032, 0.2547918545315042, 0.1481953135225922, 0.15111518965568393, 0.2821798052173108, 47.82368279993534, 79.79062646627426, 79.48396772146225, 75.92374116182327, 51.807290241122246, 28.99767279624939, 25.161164961755276, 13.755506034940481, 2.9062210908159614, 41.43334150314331, 45.71236029267311, 7.897349456325173, 68.26383858919144, 85.72512522339821, 88.99284347891808, 13.88036448508501, 0.45585379062686116, 0.19076671509537846, 0.26890260516665876], [0.031472378977923654, 0.24394305073656142, 3.8203978864476085, 3.328102002851665, 4.362923512235284, 7.439784659072757, 0.7349832204636186, 0.18190262198913842, 2.2249658592045307, 19.974361583590508, 31.43191147595644, 7.144149597734213, 27.55584016442299, 15.42906828224659, 21.341953799128532, 32.111001536250114, 52.872122302651405, 60.40158927440643, 27.8089464828372, 2.337091905064881, 0.1881447370396927, 0.18233582843095064, 0.07976931257871911, 0.15893484349362552, 0.04581259796395898, 0.04295483588066418, 0.047627290041418746, 0.02836273197317496, 0.0739525372046046, 1.5077604004181921, 2.1083287429064512, 3.7073223665356636, 20.772041380405426, 35.13201802968979, 24.72611490637064, 18.047555275261402, 43.66612449288368, 49.51470986008644, 31.70564118772745, 16.897786371409893, 16.716543696820736, 8.783807214349508, 1.5744615462608635, 2.874833825044334, 0.2859069005353376, 0.22123374743387103, 0.6846272537950426, 0.7501717773266137, 2.140746465884149, 0.658177585573867, 0.8528660761658102, 1.3343904283829033, 5.561845628544688, 12.04248670488596, 11.160639524459839, 8.205186612904072, 14.326880425214767, 14.426265992224216, 23.026844188570976, 35.51125667989254, 39.373730421066284, 42.247242629528046, 46.56987927854061, 43.08515086770058, 44.174130633473396, 42.15114198625088, 42.897250950336456, 43.851094767451286, 44.23692226409912, 42.80780754983425, 44.285768643021584, 43.43311719596386, 43.091504126787186, 42.501821368932724, 44.76222887635231, 45.17933249473572, 44.85324539244175, 46.048999428749084, 45.48226743936539, 46.74526646733284, 46.59987486898899, 46.79383546113968, 42.62443698942661, 44.094087928533554, 43.912320882081985, 43.84860210120678, 42.08435297012329, 42.66846522688866, 42.576202377676964, 46.55733995139599, 41.44718416035175, 40.57260788977146, 40.42723909020424, 42.64314718544483, 43.71045671403408, 43.04156340658665, 44.00836832821369, 42.95616298913956, 45.42522490024567, 47.50634662806988, 42.61966064572334, 41.31515644490719, 42.083163633942604, 40.532375648617744, 37.01238892972469, 35.922903791069984, 36.24381937086582, 36.92004628479481, 37.720332741737366, 34.844179674983025, 36.37981407344341, 34.414555728435516, 33.89067783951759, 33.3841498196125, 36.5419627726078, 30.30765250325203, 9.61993619799614, 1.4045091345906258, 0.1757271369569935, 0.1700955125852488, 0.05779932937002741, 0.06941204803297296, 0.016727119909774046, 0.027030356104660314, 0.12434636824764311, 0.04746712715132162, 0.04090747679583728, 0.027233467080804985, 0.04314391284424346, 0.06482393524493091, 0.18055252177873626, 0.06789001447032206, 0.04576645493216347, 0.08507477046805434, 0.0073514838913979474, 0.11227539565879852, 0.1114836725173518, 0.18360607355134562, 1.1057040933519602, 7.527716690674424, 10.188260301947594, 8.218448851257563, 15.752024352550507, 26.81815914809704, 31.06376063078642, 21.178914047777653, 4.620185857638717, 2.3112464044243097, 1.3932717125862837, 2.2458839742466807, 0.1619002132792957, 0.2227326185675338, 0.12918094085762277, 0.03576952905859798, 0.16901205119211227, 0.12508271232945845, 1.5644665388390422, 57.47863031923771, 61.72952301800251, 64.24872323870659, 53.078690618276596, 32.95593559741974, 26.895940974354744, 29.049667306244373, 6.116112861782312, 6.685539856553078, 18.621751964092255, 2.844327874481678, 14.76022057235241, 62.96456694602966, 51.17023162543774, 56.43498212099075, 2.107398505322635, 0.08819554597721435, 0.01813370869058417, 0.13401537988102064, 0.03242206454160623, 0.282809947966598, 8.762202523648739, 12.143067307770252, 10.061289165169, 16.062581688165665, 3.0999643821269274, 0.12236424765433185, 2.700506541877985, 30.914238654077053, 50.09038656949997, 12.05889992415905, 22.917987629771233, 19.743755757808685, 27.220314368605614, 41.64813257753849, 61.24448664486408, 68.76163467764854, 50.87344475090504, 13.283032737672329, 0.6031483446713537, 0.2767183998366818, 0.06304628375801258, 0.03660390342702158, 0.06414682939066552, 0.07992383514647372, 0.07803630869602785, 0.03499387712508906, 0.07105214986950159, 2.2240581829100847, 4.697005385532975, 9.915791172534227, 30.44631276279688, 40.27110166847706, 32.38062746822834, 26.0401413962245, 45.36228507757187, 52.99454793334007, 36.318770349025726, 17.99509909003973, 16.842478439211845, 6.990378024056554, 1.6722324374131858, 1.5195099636912346, 0.35007097001653165, 0.2089506690390408, 1.2401282927021384, 1.0967743350192904, 1.5918932296335697, 2.292574681341648, 1.6283678286708891, 1.7780384724028409, 6.5351244527846575, 14.359785709530115, 13.526544570922852, 8.478033822029829, 16.19640100747347, 19.174293614923954, 25.176065862178802, 36.80875405669212, 42.24131874740124, 43.81693460047245, 45.75811363756657, 46.14076070487499, 44.59598779678345, 42.004401460289955, 44.902274161577225, 43.57390344142914, 45.1202342659235, 47.31457471847534, 45.247322246432304, 46.24900549650192, 46.234927251935005, 45.07552966475487, 45.713393837213516, 48.44665937125683, 48.16827490925789, 48.1374129652977, 47.316653206944466, 50.06394378840923, 49.96661961078644, 48.33407521247864, 44.62183400988579, 46.5689255297184, 45.098267644643784, 46.71255402266979, 46.65594466030598, 48.53804066777229, 45.3347859531641, 48.18368688225746, 45.13245441019535, 43.91825616359711, 42.982434779405594, 45.41553921997547, 46.36666618287563, 45.60753531754017, 46.96776732802391, 45.5387894064188, 48.21163058280945, 47.76219069957733, 44.006434231996536, 44.44228984415531, 43.44728283584118, 44.07481536269188, 41.21522940695286, 39.80762533843517, 38.605240657925606, 39.84585128724575, 40.140704065561295, 37.275862991809845, 39.51406069099903, 37.1605733782053, 35.55729880928993, 38.7939765304327, 32.795542404055595, 19.10539761185646, 4.304325906559825, 0.7833223266061395, 0.16300828428938985, 0.07688770900131203, 0.012756999985867878, 0.008139697602018714, 0.03284622049250174, 0.0424632149952231, 0.09899200609652326, 0.10781307690194808, 0.019064204170717858, 0.05661362600221764, 0.05755214595410507, 0.15416186914080754, 0.18156835867557675, 0.045164947950979695, 0.051875989011023194, 0.045250936891534366, 0.10906355120823719, 0.01293786601308966, 0.05192355325561948, 0.12169729438028298, 0.5713235680013895, 9.635004289448261, 12.449914142489433, 9.002572875469923, 18.211689367890358, 32.23262161016464, 36.21402136981487, 33.965807408094406, 23.886487260460854, 5.667583979666233, 2.0586145855486393, 2.8801499772816896, 0.2685636514797807, 0.15578079008264467, 0.03763112486922182, 0.04342937252658885, 0.24577220727223903, 0.22408469289075583, 3.1831017835065722, 66.60429283976555, 64.92503374814987, 69.98816326260567, 63.92803564667702, 42.13899023830891, 22.61145617812872, 24.117005690932274, 11.524466201663017, 10.637020971626043, 25.58288913220167, 2.003655284643173, 43.13726507127285, 87.60460317134857, 70.20770028233528, 60.90152084827423, 3.0586515739560127, 0.05153032259840984, 0.03507147608615924, 0.08773021938395686, 0.21994453301886097, 0.7738463475834578, 11.660961527377367, 44.70233269035816, 33.5150907933712, 39.832426607608795, 5.521750655025244, 0.5380558187607676, 5.33302903175354, 48.262977227568626, 59.81420919299126, 13.073362838476896, 38.04838053882122, 19.835748821496964, 28.710940182209015, 49.33079592883587, 67.88473293185234, 77.52333372831345, 65.87023302912712, 16.976086869835854, 0.6355746765621006, 0.31192164053209126, 0.14773366798181087, 0.16929788194829598, 0.18300463707419112, 0.15489108860492706, 0.1226091044372879, 0.18670161603949964, 0.11509736024891026, 3.8742742454633117, 7.286675199866295, 14.623377565294504, 36.023089215159416, 45.93591369688511, 37.149679362773895, 34.70775179564953, 50.7612481713295, 54.591446444392204, 44.17716667056084, 28.21668930351734, 28.607600927352905, 13.569796700030565, 2.9145882418379188, 3.079956555739045, 0.3983222949318588, 0.5432379094418138, 1.4003749564290047, 1.1271959776058793, 3.5644825687631965, 5.074408259242773, 1.1706433212384582, 3.597028059884906, 8.042063266038895, 17.649266347289085, 15.19208449870348, 15.023580640554428, 25.36845523864031, 27.404091507196426, 32.77603805065155, 39.33273822069168, 40.2548423409462, 42.45716616511345, 45.19061788916588, 44.92827616631985, 44.30406466126442, 43.72995346784592, 43.31003800034523, 45.146323665976524, 43.90173465013504, 50.04284732043743, 47.582251355051994, 50.2361923456192, 47.629775404930115, 48.59179638326168, 49.19407546520233, 52.20512129366398, 50.931144654750824, 51.85157686471939, 50.924149230122566, 53.63434620201588, 50.73475979268551, 52.854886427521706, 47.1777668595314, 51.97710692882538, 49.1654933989048, 49.002732932567596, 48.30829359591007, 51.24670632183552, 46.663145273923874, 54.237617030739784, 46.75233408808708, 46.129357516765594, 46.05345278978348, 47.98810377717018, 46.45636796951294, 48.63413751125336, 49.83697056770325, 46.65591046214104, 52.354430481791496, 52.32615999877453, 48.212185353040695, 47.18281298875809, 49.025558307766914, 47.14621715247631, 43.82609210908413, 43.86676512658596, 43.000126630067825, 42.71902911365032, 42.84303545951843, 37.85132311284542, 42.994388937950134, 37.785161063075066, 37.652278393507004, 38.61657164990902, 36.9723504781723, 41.507084146142006, 24.195068702101707, 6.17135857231915, 0.9749476471915841, 0.18735323654254898, 0.26167554140556604, 0.20972158235963434, 0.12907212716527283, 0.08881402958650142, 0.21089871763251722, 0.21878749510506168, 0.09954171488061547, 0.23247162956977263, 0.15954904491081834, 0.26756059436593205, 0.6042861461173743, 0.19385465799132362, 0.21246923570288345, 0.18869073508540168, 0.16211331356316805, 0.17761887138476595, 0.3119431034428999, 0.2632890595123172, 1.6676527331583202, 11.15998500958085, 18.775170631706715, 21.797133274376392, 28.261036723852158, 34.215431213378906, 36.45623937249184, 38.26472952961922, 32.07953542470932, 9.092627093195915, 3.4033063799142838, 5.466517293825746, 0.8768452832009643, 0.3756845643511042, 0.16026269411668181, 0.09435517873498611, 0.44471771630924195, 0.39917781308759004, 1.807984784245491, 75.13027533888817, 74.0482909977436, 75.91731950640678, 71.5872922539711, 45.29837250709534, 41.40847183763981, 50.8259055018425, 26.797727644443512, 24.93113100528717, 45.692228972911835, 9.025441948324442, 43.34300123155117, 98.31656277179718, 77.26275891065598, 75.21444842219353, 5.141293695196509, 0.2063881221693009, 0.11672366556013003, 0.2566887839930132], [0.1427753793541342, 0.1566985744284466, 0.6618852366227657, 8.776527754962444, 0.0738629674015101, 6.7578761000186205, 7.4363453686237335, 2.00915121473372, 5.443950304761529, 28.493318259716034, 23.303167261183262, 15.370684415102005, 24.011774137616158, 25.701269879937172, 26.9552443921566, 31.24884869903326, 42.2695018351078, 66.92028388381004, 45.279084742069244, 13.573243115097284, 0.8729680662509054, 0.2853343781316653, 0.09780648455489427, 0.03792982446611859, 0.09953759596101008, 0.06524321157485247, 0.06589662065380253, 0.10645861286320724, 0.412741630570963, 4.5828433614224195, 10.04457101225853, 25.19515983760357, 42.465309128165245, 46.7587785422802, 41.49222694337368, 45.967072024941444, 51.79888889193535, 58.33281688392162, 48.69407929480076, 35.60963720083237, 26.04960858821869, 13.980755098164082, 5.828508669510484, 5.957905501127243, 2.7240762021392584, 2.131930226460099, 1.8059263634495437, 2.273438908159733, 1.4837114908732474, 1.6492730006575584, 0.5672025703825057, 4.81041457504034, 8.338461611419916, 13.278421685099602, 10.002785604447126, 5.08073017001152, 8.149358108639717, 12.215537019073963, 18.514804802834988, 26.883137561380863, 36.27594284713268, 40.55671714246273, 37.86303028464317, 43.11724774539471, 44.23245370388031, 42.61316679418087, 44.94458109140396, 42.91944935917854, 43.56688901782036, 44.49392527341843, 45.17198748886585, 44.36085641384125, 45.03237538039684, 45.38978040218353, 42.1192616969347, 43.91411438584328, 46.72744542360306, 47.55336530506611, 45.84276929497719, 45.75570836663246, 43.286821246147156, 43.80721092224121, 43.2426942139864, 44.42897155880928, 43.53833355009556, 41.3862544298172, 44.920881763100624, 43.79067800939083, 43.78605365753174, 43.774646669626236, 42.042509615421295, 40.63513733446598, 40.50975166261196, 41.18527941405773, 42.31736406683922, 43.737480863928795, 43.171303644776344, 43.05418252944946, 45.32380074262619, 43.742523193359375, 43.802814558148384, 42.32049509882927, 39.77952964603901, 39.82151359319687, 37.65773110091686, 39.94130976498127, 34.30783845484257, 37.8951271623373, 37.45965152978897, 33.016671538352966, 34.7553176432848, 34.3630038946867, 32.71128952503204, 34.62730251252651, 19.9512892216444, 2.1195174800232053, 0.7842308341059834, 0.03869152773404494, 0.1072037810808979, 0.04442251825821586, 0.07381046045338735, 0.06340827370877378, 0.08618606982054189, 0.02639644324517576, 0.07458098043571226, 0.372112785698846, 0.11538576625753194, 0.1002670603338629, 0.15227417199639603, 0.054257047377177514, 0.04014835991256405, 0.1718728375271894, 0.07664567237952724, 0.057460138195892796, 0.12044931369018741, 0.06056386657292023, 0.15685567224863917, 0.012153879761171993, 6.901913546025753, 15.463428888469934, 18.933304846286774, 23.564857318997383, 32.202945202589035, 34.80798661708832, 43.96180182695389, 46.16240054368973, 34.09375034272671, 11.957399770617485, 5.393790146335959, 3.641925025731325, 2.047136826440692, 0.16677118081133813, 0.13974355766549706, 0.24931884196121246, 0.39824327104724944, 0.6022134167142212, 12.2810835018754, 68.0807264149189, 57.94625222682953, 67.72782415151596, 49.63254153728485, 41.985862255096436, 71.17904976010323, 48.6791916936636, 38.19157585501671, 33.85481156408787, 16.067384630441666, 3.123039356432855, 75.68542554974556, 46.43785536289215, 58.07769097387791, 40.226663053035736, 0.42257122811861336, 0.07123464398318902, 0.029246063968457747, 0.02199395457864739, 0.08145467800204642, 0.1228915732644964, 1.3002015254460275, 12.026746049523354, 14.835243746638298, 14.011614192277193, 8.88275295495987, 0.5076315638143569, 6.9159043952822685, 41.56177461147308, 36.25249810516834, 16.470729187130928, 14.991394467651844, 14.058336485177279, 25.8086559176445, 39.854568019509315, 52.36530549824238, 73.86694192886353, 55.24811580777168, 34.99880097806454, 2.997396723367274, 0.5445700348354876, 0.18156457372242585, 0.11995673543424346, 0.15454343694727868, 0.029865846336178947, 0.06526739074615762, 0.04268436758138705, 0.2805396291660145, 5.830414742231369, 17.158773466944695, 31.68514508754015, 47.04679548740387, 52.15792402625084, 45.415782406926155, 49.7290563583374, 54.4985718280077, 60.88994286954403, 51.11255832016468, 41.313507333397865, 29.791474901139736, 16.490697115659714, 7.595682218670845, 5.669133821502328, 2.069041463546455, 1.2231471226550639, 2.538947998546064, 3.1233856128528714, 0.6549547053873539, 3.197441501542926, 3.1425266107544303, 6.306446073576808, 11.784786432981491, 15.05631398409605, 10.15373820438981, 8.399944212287664, 10.676342211663723, 14.147679191082716, 23.954860791563988, 25.982540287077427, 33.633724227547646, 41.76046974956989, 42.78299108147621, 42.259040996432304, 44.87968437373638, 42.89555624127388, 45.938337966799736, 42.85779006779194, 43.70396286249161, 46.88078619539738, 48.89171048998833, 47.67918415367603, 47.58977875113487, 45.130630508065224, 46.140574514865875, 47.39339388906956, 49.198631420731544, 48.73423933982849, 48.99986028671265, 48.083041682839394, 44.675357937812805, 48.20575229823589, 45.800112783908844, 45.81771723926067, 44.9133125692606, 43.99106405675411, 47.51737363636494, 47.00923450291157, 46.203499138355255, 44.934139251708984, 45.952340215444565, 43.602808490395546, 44.3823366612196, 43.785783872008324, 44.620485082268715, 45.90045019984245, 45.01942567527294, 44.52354848384857, 47.1120797842741, 44.76040497422218, 44.822052866220474, 44.406594559550285, 42.74078294634819, 43.33209581673145, 40.90839207172394, 42.39755876362324, 36.43676921725273, 39.83961962163448, 38.27825300395489, 34.640837386250496, 36.37977607548237, 35.69865122437477, 32.60871022939682, 31.29972606897354, 13.26079348102212, 2.3711007926613092, 0.9071817866060883, 0.102675789676141, 0.10093575765495189, 0.10363706387579441, 0.02712347893975675, 0.07500892505049706, 0.023904756635602098, 0.004995177541786688, 0.20958642242476344, 0.30275243567302823, 0.24402197072049603, 0.3333601198391989, 0.0946210976690054, 0.09579297111486085, 0.085737916524522, 0.11499285843456164, 0.06875736246001907, 0.06174320231366437, 0.12411568648531102, 0.1467512277304195, 0.08084653250989504, 0.21833928243722767, 7.3829463589936495, 18.423898480832577, 24.13909960538149, 32.452227026224136, 39.517647698521614, 44.16483253240585, 48.835678696632385, 50.983935222029686, 47.745593190193176, 22.569151148200035, 9.83691880479455, 8.332718219608068, 2.6695348788052797, 0.25160349905490875, 0.3046605864074081, 0.9174314397387207, 0.8189398341346532, 0.45601572724990547, 18.756418637931347, 75.02578854560852, 64.64654669165611, 73.67866203188896, 58.73141549527645, 54.554470628499985, 67.58667692542076, 47.71271735429764, 40.86216375231743, 44.614128023386, 22.748189941048622, 6.890779668465257, 78.86381819844246, 57.49412588775158, 69.54067647457123, 45.00465206801891, 0.44220094510819763, 0.07479594351025298, 0.1281519976328127, 0.028452077276597265, 0.17904989537782967, 0.36719890718813986, 1.116626844741404, 40.960456877946854, 44.8761011660099, 34.022625759243965, 23.910935148596764, 4.690772769972682, 7.800058051943779, 61.94427229464054, 35.5618167668581, 29.94047250598669, 37.33479782938957, 35.656815469264984, 40.281851291656494, 46.2669063359499, 58.39801378548145, 83.7474225461483, 66.48542001843452, 49.93549548089504, 3.53737102355808, 0.6001086859032512, 0.25792327243834734, 0.1821777509758249, 0.2763057657284662, 0.09857186887529679, 0.2258247768622823, 0.1996776377200149, 0.48189527762588114, 7.37947192043066, 22.183861322700977, 37.73882634937763, 53.14037270843983, 55.92863269150257, 54.97313596308231, 57.780748307704926, 58.88490825891495, 61.62186339497566, 55.75289972126484, 49.63289111852646, 33.11430349946022, 25.894584506750107, 11.148388981819153, 7.223540162667632, 3.9951554965227842, 3.723144717514515, 4.018182260915637, 4.368617506697774, 2.471867110580206, 5.711191389709711, 7.189398994669318, 9.85133333131671, 16.451207734644413, 21.163196191191673, 17.86163505166769, 15.811676401644945, 19.036680199205875, 26.26204378902912, 32.98558160662651, 36.39842167496681, 38.589745089411736, 44.32872153818607, 40.39829604327679, 43.58098246157169, 42.231481075286865, 42.34625391662121, 46.504933163523674, 42.51996919512749, 44.436685144901276, 49.98456224799156, 50.179693177342415, 49.78787340223789, 49.952450171113014, 47.7250324934721, 48.24824541807175, 49.26911003887653, 54.467303305864334, 54.442779421806335, 50.21108329296112, 50.85302084684372, 47.02920623123646, 51.521556973457336, 45.724987015128136, 50.260241255164146, 46.628494933247566, 46.67258016765118, 51.258941665291786, 51.43278993666172, 50.64035765826702, 49.37407560646534, 49.2666781693697, 46.994783878326416, 46.97554551064968, 48.626830503344536, 47.74313472211361, 48.50604258477688, 47.39855781197548, 47.956618666648865, 52.04836830496788, 51.32657043635845, 49.97298426926136, 48.314924240112305, 45.955486446619034, 46.08909107744694, 43.085036873817444, 47.23062962293625, 38.94714631140232, 44.64780181646347, 40.12778475880623, 35.629331544041634, 38.9376962184906, 38.96526373922825, 35.85030488669872, 35.291613265872, 28.113790825009346, 13.005986753851175, 2.3548108292743564, 0.2516506105894223, 0.4123443737626076, 0.29508385341614485, 0.11132215149700642, 0.14632415142841637, 0.18493577954359353, 0.09691556595498696, 0.23816180939320475, 0.8846557047218084, 0.3787061444018036, 0.32323351479135454, 0.2198920928640291, 0.1790594690828584, 0.17920936807058752, 0.24371861043618992, 0.2343133432441391, 0.2071022760355845, 0.2387999524944462, 0.2617149049183354, 0.1632302755024284, 0.3557455795817077, 8.403627164661884, 24.15534943342209, 30.107160061597824, 39.992208033800125, 42.07675337791443, 43.8652528077364, 50.17233297228813, 53.75622846186161, 54.67286467552185, 29.73113413900137, 15.130397658795118, 10.086308922618628, 3.9138769078999758, 0.6543672806583345, 0.938592622987926, 1.1537215230055153, 1.1822116817347705, 0.6414993898943067, 15.93365840613842, 85.38105368614197, 70.26026666164398, 82.85835385322571, 65.4708744585514, 59.37443219125271, 82.99565568566322, 55.59514358639717, 55.2266925573349, 56.595493108034134, 37.28066213428974, 15.350179765373468, 96.77791133522987, 67.68611758947372, 71.58141016960144, 62.39298261702061, 0.740330305416137, 0.1962229105993174, 0.34309994720388204, 0.2019831194775179], [0.07005037667113356, 0.15136808389797807, 0.10981252664350905, 8.176349960267544, 2.0859671803191304, 6.0834792628884315, 2.6513212686404586, 8.793340902775526, 4.628886915743351, 48.57331417500973, 15.235950294882059, 22.221547700464725, 40.85511893033981, 54.36318889260292, 26.2752727791667, 35.107934921979904, 33.678983598947525, 61.390197426080704, 51.64175972342491, 24.4718686491251, 2.7954990696161985, 0.45542370120529085, 0.1538250528392382, 0.05978069668344688, 0.09185036353301257, 0.011309661731502274, 0.11931094821193255, 0.26617402501869947, 1.5996120404452085, 12.38972157239914, 23.16525176167488, 40.631941705942154, 46.429944187402725, 38.98330897092819, 32.766755148768425, 36.22174255549908, 48.56199838221073, 56.33526027202606, 60.09009338915348, 59.59927372634411, 47.54344403743744, 27.682037092745304, 8.974228296428919, 13.626922834664583, 7.80331970192492, 9.868301320821047, 9.285164661705494, 10.52122788503766, 4.938564598560333, 9.085724763572216, 10.803026463836432, 12.763370722532272, 11.853917073458433, 16.90784253180027, 13.800237234681845, 6.546485843136907, 4.695115461945534, 10.686060190200806, 15.59000389650464, 15.186101719737053, 19.98875331133604, 28.14417589455843, 36.39521844685078, 36.68237663805485, 40.062774047255516, 43.614907041192055, 42.886239141225815, 39.822144359350204, 44.86219011247158, 40.4583366215229, 45.75563997030258, 43.659121468663216, 44.279449582099915, 42.40887835621834, 41.46899498999119, 47.1529845893383, 45.42098432779312, 45.919498577713966, 49.37799319624901, 45.2519503980875, 44.83908735215664, 40.410367995500565, 44.24236737191677, 41.9611369818449, 42.696367129683495, 44.15828928351402, 48.06702174246311, 43.38756524026394, 45.75403645634651, 46.14527106285095, 41.14788942039013, 41.164923906326294, 41.92957207560539, 39.51905742287636, 43.14610339701176, 41.247470676898956, 43.93685236573219, 42.84679725766182, 43.1856706738472, 40.988765358924866, 41.194113940000534, 38.649899661540985, 39.966088235378265, 39.48925942182541, 37.93707691133022, 38.79372574388981, 35.96610747277737, 36.28074198961258, 33.99595879018307, 32.00778387486935, 34.70699183642864, 28.06468416005373, 27.879590392112732, 19.90712609142065, 1.2557977018877864, 0.29371589713264257, 0.0901024202175904, 0.040772558058961295, 0.08104195483610965, 0.1008582922804635, 0.06095308963267598, 0.05063909600721672, 0.3027514857240021, 1.4439340378157794, 2.7974550146609545, 2.2393053397536278, 2.746063247323036, 1.6459361859597266, 0.058139741377090104, 0.025753162626642734, 0.03390985541045666, 0.02779242116957903, 0.08751608009333722, 0.10240824543870986, 2.2662805672734976, 6.057139551267028, 3.17577435169369, 10.134368743747473, 18.31197738647461, 29.831213168799877, 34.959362894296646, 42.6280277967453, 47.28807874023914, 44.6058938652277, 42.13022790849209, 43.67483742535114, 32.836059629917145, 12.047632578760386, 13.955312613397837, 22.632657140493393, 9.271927122026682, 1.3137491047382355, 0.640510730445385, 1.5868849796243012, 0.4505287029314786, 0.04678721968957689, 31.886186599731445, 68.4501425921917, 60.136849880218506, 57.88898549973965, 35.999146699905396, 27.650379091501236, 29.732253178954124, 35.63468925654888, 70.90775951743126, 55.09464204311371, 35.83685740828514, 27.34221752732992, 48.485732674598694, 36.48659594357014, 66.03807002305984, 13.917574938386679, 0.39513904543127865, 0.19458234863122925, 0.08332970668561757, 0.0790359074017033, 0.08626777285826392, 0.20317088230513036, 0.2345544521813281, 8.099996857345104, 20.370473228394985, 13.90427565202117, 15.020963530987501, 4.397288868203759, 9.431266821920872, 66.80189743638039, 26.510905735194683, 23.497878313064575, 38.88652816414833, 34.21235337853432, 27.137759998440742, 41.215107813477516, 44.13675583899021, 68.49448621273041, 63.00827220082283, 41.00397974252701, 8.170418478548527, 0.5797595903277397, 0.17949453089386225, 0.1515982238925062, 0.13971691456390545, 0.06571008925675415, 0.1620577267021872, 0.04310004449507687, 3.060289998538792, 17.723799347877502, 25.735849924385548, 42.83572845160961, 47.084865644574165, 48.09705913066864, 43.50393399596214, 46.88698746263981, 56.07320733368397, 63.067583218216896, 62.33684062957764, 63.403720781207085, 52.538796588778496, 36.12314164638519, 16.038734167814255, 15.241227261722088, 8.240822050720453, 11.737155988812447, 11.46197760477662, 12.3823775164783, 6.784839928150177, 10.261698961257935, 13.702159747481346, 16.155433505773544, 17.97027502208948, 23.264939412474632, 20.552804544568062, 12.092778906226158, 11.99730047956109, 13.642205614596605, 18.544735796749592, 17.240009307861328, 22.218169681727886, 27.790593467652798, 36.928816214203835, 40.87856747210026, 39.4574361294508, 43.53402078151703, 43.35180535912514, 39.99606102705002, 46.70504182577133, 45.13702556490898, 45.90061359107494, 47.268391996622086, 46.0750812292099, 48.55034440755844, 46.385687962174416, 50.85573390126228, 48.20311903953552, 49.2461022734642, 49.19881381094456, 48.201405331492424, 48.18793885409832, 45.1778581738472, 46.03911615908146, 44.93961475789547, 46.720951572060585, 46.97053737938404, 51.74960553646088, 47.23629131913185, 46.575635969638824, 48.49307008087635, 43.42690072953701, 41.845049411058426, 43.50816696882248, 43.77654656767845, 46.07024788856506, 45.521583929657936, 45.928287506103516, 45.13658478856087, 45.445401817560196, 45.252786353230476, 45.29913626611233, 43.67681711912155, 43.72801937162876, 41.65175378322601, 39.12528835237026, 42.32842527329922, 39.94633309543133, 39.19808104634285, 36.645321026444435, 34.39530976116657, 34.221613481640816, 28.30800600349903, 25.96174020320177, 13.430811557918787, 2.0055226469412446, 0.2012106031179428, 0.3309302096022293, 0.054038525704527274, 0.08526623714715242, 0.07164855458540842, 0.03212799594621174, 0.13407117454335093, 0.525769890518859, 1.9104496110230684, 3.7611410161480308, 3.5259756725281477, 5.466431798413396, 4.149622907862067, 0.22458865569205955, 0.10489597640116699, 0.038381874037440866, 0.057964498046203516, 0.05605665530310944, 0.18389280972769484, 3.407859248109162, 5.96191143617034, 3.805805006995797, 11.886845156550407, 22.45593812316656, 37.99445383250713, 43.084729090332985, 52.87766620516777, 59.026602655649185, 50.72177588939667, 50.91306522488594, 51.240915432572365, 44.796096459031105, 25.616251341998577, 21.932176128029823, 30.775124318897724, 15.707906819880009, 3.4587062196806073, 2.0537634333595634, 5.075120721012354, 0.4400150530273095, 0.25345005153212696, 41.60366736352444, 73.59985426068306, 67.2461847960949, 65.9098269045353, 50.60099557042122, 34.85364496707916, 34.08385947346687, 49.36322718858719, 79.59752842783928, 69.15995210409164, 47.30955518782139, 49.64058190584183, 65.92901587486267, 51.26456156373024, 72.16908663511276, 16.84302370995283, 0.35347644821740687, 0.203013428254053, 0.07678909241803922, 0.08337252860656008, 0.32796233135741204, 0.45942506461869925, 0.2807419386226684, 28.134856894612312, 51.80556893348694, 28.882797360420227, 53.61882783472538, 23.654334917664528, 30.145165622234344, 86.61898165941238, 26.81017767637968, 36.32754407823086, 52.985888198018074, 68.94033148884773, 37.36048445105553, 51.49178937077522, 46.32224276661873, 78.18662613630295, 75.3512790799141, 60.822743475437164, 15.397289637476206, 0.812054187990725, 0.6542745418846607, 0.3020927554462105, 0.28251469193492085, 0.1787422751658596, 0.32710927713196725, 0.3488561336416751, 4.066252056509256, 20.681252852082253, 30.44256616383791, 47.70022742450237, 54.9233890324831, 56.96192644536495, 50.797312036156654, 55.62735065817833, 62.96654284000397, 61.22411213815212, 62.72798404097557, 62.30277545750141, 59.17862109839916, 45.998260751366615, 22.699744440615177, 17.92094226926565, 10.208869446069002, 13.296542912721634, 14.8492013476789, 15.928079355508089, 9.548080153763294, 14.203844927251339, 18.294042348861694, 21.042921245098114, 23.235297203063965, 24.244777634739876, 23.73717427253723, 19.31940022855997, 21.088874079287052, 19.833022467792034, 28.41402031481266, 28.485969454050064, 32.515991404652596, 31.937977820634842, 37.535271272063255, 41.128711849451065, 43.61630156636238, 43.98435741662979, 42.88101442158222, 39.689212292432785, 47.54482336342335, 45.85497044026852, 47.437520921230316, 48.19516606628895, 47.6741798222065, 50.9868610650301, 47.787850722670555, 54.41995024681091, 50.86668111383915, 54.483596831560135, 52.326122000813484, 50.05586542189121, 50.79878255724907, 47.24489405751228, 50.122316256165504, 49.94992710649967, 51.1739706248045, 51.92200228571892, 53.806055188179016, 49.17494349181652, 50.55867724120617, 50.24515986442566, 46.26584619283676, 46.30001775920391, 46.90003216266632, 46.30715757608414, 51.80537514388561, 48.05120699107647, 50.94328500330448, 47.90548861026764, 49.06339667737484, 48.95613223314285, 48.44072408974171, 45.84002584218979, 46.322770938277245, 44.35227647423744, 41.44568704068661, 46.61363773047924, 42.8947164863348, 41.70023538172245, 39.006635919213295, 36.79921656847, 37.902099788188934, 30.5372266843915, 31.204774864017963, 29.283181875944138, 6.199946813285351, 0.6932039873208851, 0.39322507625911385, 0.1444502137019299, 0.21055238699773327, 0.375457318732515, 0.08565657713916153, 0.17912933486513793, 0.6157064926810563, 1.5004063700325787, 3.744650613516569, 3.039912641979754, 4.458475084975362, 2.7021706150844693, 0.2519356843549758, 0.18018236820353195, 0.11726582670235075, 0.11149162091896869, 0.31212804664392024, 0.4152206709841266, 4.193724766373634, 7.3020425252616405, 4.3269802909344435, 13.766315504908562, 28.122323267161846, 42.23754175007343, 47.34434612095356, 52.81402722001076, 56.68664261698723, 53.13702508807182, 53.21239784359932, 55.550492182374, 53.478550761938095, 42.73466907441616, 32.14738078415394, 32.757031470537186, 14.836535677313805, 3.958359220996499, 2.179111819714308, 5.85082202218473, 0.9905756742227823, 0.18585427635116503, 45.823952704668045, 83.32088023424149, 77.81275659799576, 71.26785099506378, 54.638826102018356, 42.501486986875534, 40.33546261489391, 46.52930125594139, 83.56358841061592, 78.4268644452095, 59.639745354652405, 63.83216679096222, 78.8693355023861, 53.16372625529766, 96.08996585011482, 27.92279977351427, 0.7699927012436092, 0.42272517923265696, 0.2521598129533231, 0.2815952303353697], [0.062106346304062754, 0.03371863735083025, 0.4089304350782186, 6.438918365165591, 9.13503946736455, 7.499962979927659, 15.955699123442173, 40.192206501960754, 38.16001854836941, 73.33727315068245, 20.632737055420876, 32.42499768733978, 45.42007997632027, 61.812981739640236, 30.44209498912096, 38.959172666072845, 31.50028880685568, 59.38444085419178, 51.98850251734257, 29.006913900375366, 2.1505359280854464, 0.6443849194329232, 0.06283356196945533, 0.09584717015968636, 0.006782100308555528, 0.06646693887887523, 0.09134731357335113, 1.1272465623915195, 12.402531635016203, 24.40288335084915, 32.22645454108715, 58.218040242791176, 61.32530830800533, 43.97522650659084, 18.116132095456123, 24.17888917028904, 49.77982923388481, 60.793089866638184, 54.97828088700771, 60.27913324534893, 42.05296665430069, 22.57600788027048, 13.108158521354198, 21.75833735615015, 16.70398347079754, 17.888978384435177, 19.368734881281853, 21.855524741113186, 23.978073745965958, 27.2489857301116, 20.797680504620075, 13.261063266545534, 17.08878692239523, 20.207733660936356, 28.154986314475536, 15.868227817118168, 7.000302616506815, 9.347459468990564, 11.366515327244997, 10.491225644946098, 6.8610068410634995, 13.439211007207632, 18.166694082319736, 31.333525255322456, 34.0561855584383, 40.043683871626854, 41.38525888323784, 42.9435932636261, 45.864340737462044, 43.46308998763561, 45.11240668594837, 46.50909774005413, 44.3580711632967, 46.02883391082287, 42.00263075530529, 46.42020910978317, 44.02579799294472, 46.239513605833054, 45.176885426044464, 44.228718504309654, 43.59987124800682, 41.66667178273201, 40.011940374970436, 40.64938277006149, 41.70175530016422, 41.12167462706566, 43.95923316478729, 45.696370750665665, 41.192400231957436, 47.39119000732899, 40.71830727159977, 41.84243135154247, 37.91305460035801, 38.91622357070446, 40.99446505308151, 41.746570095419884, 40.554456263780594, 45.304098799824715, 41.82645320892334, 43.4402684122324, 41.402756944298744, 40.16767501831055, 40.22348642349243, 38.67161549627781, 37.00854353606701, 41.97879083454609, 37.987500205636024, 39.80968862771988, 37.578497752547264, 33.98059241473675, 29.03723817318678, 26.787551790475845, 15.90427553281188, 2.907242998480797, 0.2758691454073414, 0.17865566653199494, 0.268202344304882, 0.09702859504614025, 0.0025055501600945718, 0.014625842868554173, 0.3060257522156462, 0.3800446819514036, 1.4525178959593177, 1.098949599545449, 3.298644321039319, 5.13937764801085, 9.403714500367641, 9.755642116069794, 3.1271573854610324, 0.5445425456855446, 0.029662943161383737, 0.4267342609819025, 3.4298493806272745, 10.01516629010439, 17.864467799663544, 18.176573552191257, 15.307141374796629, 22.75396753102541, 34.33078542351723, 47.73012802004814, 46.498184725642204, 50.231590792536736, 52.23784513771534, 43.80765549838543, 43.91469955444336, 37.55761407315731, 31.245810762047768, 14.878083597868681, 16.900548823177814, 26.91626038402319, 39.10706453025341, 19.975131042301655, 9.587047062814236, 6.026015421375632, 0.25534021260682493, 2.006005458533764, 48.05930815637112, 62.90745981037617, 55.191897824406624, 52.562309727072716, 28.078785203397274, 26.01726282387972, 15.910852029919624, 28.60401961952448, 36.68331138789654, 51.649986281991005, 48.8495859503746, 48.45513291656971, 30.671194195747375, 35.44051967561245, 58.98237682878971, 1.2828744552098215, 0.12207749663502909, 0.0445803990442073, 0.013656105402333196, 0.10693149451981299, 0.02860611188225448, 0.057168871207977645, 0.5724370270036161, 7.338314903900027, 28.26187837868929, 30.267790742218494, 34.95140232145786, 56.695644333958626, 51.76765836775303, 84.44468513131142, 35.554908737540245, 29.644073210656643, 45.61395317316055, 61.38752996921539, 31.39752522110939, 39.8049920797348, 41.038842871785164, 68.50242018699646, 64.8402450978756, 46.745897233486176, 11.855657380074263, 0.6733753450680524, 0.11885014871950261, 0.05259127836325206, 0.04016831997432746, 0.0199355504810228, 0.20084807882085443, 1.1993860476650298, 13.759600315243006, 26.262602359056473, 37.32661306858063, 62.41294674575329, 65.70795133709908, 56.230260506272316, 25.437740720808506, 31.079571582376957, 56.166906505823135, 65.96886053681374, 59.85165238380432, 64.44512709975243, 56.2653174251318, 38.34389828145504, 20.351128466427326, 24.89747431129217, 20.211959034204483, 18.506954424083233, 21.173778623342514, 27.17042114585638, 30.85867613554001, 32.859333381056786, 26.235302723944187, 19.595723301172256, 20.462038815021515, 27.506665103137493, 35.533075109124184, 27.14471362531185, 18.43611292541027, 22.108439169824123, 20.664712339639664, 18.538553528487682, 12.46031703427434, 10.459448900073767, 18.31164490431547, 30.885267108678818, 37.60231487452984, 40.77392488718033, 41.62913739681244, 43.30854848027229, 48.41982901096344, 47.6884176582098, 47.88194887340069, 49.062492325901985, 48.904390409588814, 47.91956685483456, 45.822417587041855, 49.5063579082489, 48.427618592977524, 48.18120941519737, 47.77858301997185, 47.015424370765686, 44.874680042266846, 43.359408751130104, 43.959217965602875, 43.413852229714394, 46.364659890532494, 44.60911989212036, 44.832293316721916, 46.060995385050774, 45.34505680203438, 48.871009200811386, 43.37015837430954, 43.074146658182144, 42.20652401447296, 42.65792079269886, 43.60583692789078, 41.21112942695618, 43.23905400931835, 48.74447599053383, 46.92523621022701, 45.84761023521423, 46.61585681140423, 42.88351468741894, 41.28979280591011, 41.66369654238224, 39.51185680925846, 44.321186542510986, 40.851930901408195, 39.82953116297722, 43.066961243748665, 38.450870141386986, 33.8723324239254, 27.729688435792923, 14.169430173933506, 2.2100195987150073, 0.1112783350981772, 0.18925245181890205, 0.03577057919756044, 0.13709346705581993, 0.03412035446672235, 0.08822917268844321, 0.11256271813181229, 0.5093417689204216, 2.6396254962310195, 2.9654651368036866, 5.5433847941458225, 12.067986186593771, 10.525452308356762, 10.641447734087706, 5.613917084410787, 1.2091706413775682, 0.0060264770854701055, 2.001860593445599, 5.809961864724755, 13.731904551386833, 20.684290789067745, 23.582463674247265, 19.0105888992548, 30.888506434857845, 42.23734796047211, 57.08797708153725, 55.05297347903252, 59.163402915000916, 59.78651627898216, 53.87871488928795, 53.320038467645645, 50.43326877057552, 44.513999596238136, 31.878093034029007, 22.087283805012703, 34.473714753985405, 45.52953690290451, 36.929606571793556, 29.231413453817368, 12.777567710727453, 0.2334333342150785, 3.2479153806343675, 60.21048992872238, 68.55014562606812, 66.24382898211479, 62.171184718608856, 43.02089251577854, 31.900967806577682, 19.647132642567158, 37.87916041910648, 45.90980149805546, 80.36308854818344, 73.79289910197258, 58.01217868924141, 51.87403365969658, 47.15145707130432, 66.05992645025253, 3.2611187221482396, 0.10029399287304841, 0.03738114726729691, 0.06951323244720697, 0.10815610497957096, 0.24031239008763805, 0.11543425076524727, 0.8575352537445724, 15.115900486707687, 70.14067187905312, 53.283226042985916, 47.93442025780678, 82.31946676969528, 70.01745209097862, 95.94900101423264, 35.35428710281849, 45.76510526239872, 52.94453501701355, 70.18614023923874, 43.13504599034786, 51.386926397681236, 45.81419862806797, 75.99072396755219, 79.20792773365974, 64.51805278658867, 23.395105227828026, 1.0516746737994254, 0.3173240600153804, 0.27931695571169257, 0.22301239339867607, 0.16374164493754506, 0.3007066313875839, 1.7662967462092638, 16.878777891397476, 30.208314433693886, 42.37782642245293, 64.40175622701645, 71.43324092030525, 69.034034460783, 37.14310571551323, 42.86979362368584, 61.308604404330254, 66.62231907248497, 57.521879598498344, 62.70350955426693, 53.987058475613594, 49.53106418251991, 37.393968254327774, 35.40516637265682, 24.397195056080818, 18.084776178002357, 22.93430395424366, 30.07783703505993, 31.53275426477194, 35.68628288805485, 32.72485859692097, 26.65941696614027, 29.704982042312622, 37.187669724226, 40.79399921000004, 32.382569164037704, 27.02483955770731, 27.71648034453392, 25.045356675982475, 23.44683565199375, 21.362030021846294, 22.267004661262035, 25.392426252365112, 36.12459696829319, 41.149952709674835, 43.63280788064003, 42.130482494831085, 41.73488952219486, 48.56702171266079, 49.09846119582653, 50.874497294425964, 48.577839732170105, 50.474903136491776, 50.14771029353142, 48.117593228816986, 53.257740810513496, 48.68988052010536, 50.80040507018566, 48.97822044789791, 50.56042894721031, 50.96198000013828, 45.60348853468895, 46.48735150694847, 46.07641875743866, 48.331681340932846, 47.54324644804001, 48.14814738929272, 51.40175700187683, 47.76906453073025, 54.68895301222801, 48.56846563518047, 47.60582149028778, 45.521215349435806, 45.99781237542629, 48.23300823569298, 45.68997569382191, 46.36650279164314, 55.140380188822746, 47.5810582190752, 50.45060344040394, 50.061234533786774, 45.95493547618389, 48.446142598986626, 46.479303538799286, 41.07896111905575, 47.5446979701519, 43.18977065384388, 44.61945913732052, 44.35982286930084, 41.85689337551594, 35.037361308932304, 34.25440572202206, 27.37194523215294, 6.286951694637537, 0.4378459631698206, 0.4137945006368682, 0.24149930686689913, 0.4388473281869665, 0.12609176599653438, 0.1442372173187323, 0.5228252266533673, 1.1500002164393663, 3.540176935493946, 5.373286921530962, 6.980229718610644, 12.532759197056293, 12.863648291677237, 15.170683097094297, 6.308537861332297, 1.0191187332384288, 0.11139920126879588, 1.647861732635647, 4.1114482562989, 12.395413666963577, 26.22100029140711, 29.915648438036442, 23.90673827379942, 37.088719233870506, 46.051024720072746, 58.183473497629166, 54.342115223407745, 57.925368547439575, 57.91233144700527, 53.144050911068916, 57.67669089138508, 55.62232732772827, 56.3513258099556, 42.26654939353466, 30.91936457902193, 38.01519311964512, 43.095680102705956, 35.74663124978542, 26.087353862822056, 16.437049694359303, 0.5192033678758889, 2.781752832233906, 63.84113430976868, 75.94642594456673, 73.178251683712, 66.34130135178566, 46.076783537864685, 38.72984737157822, 25.281722992658615, 41.26012779772282, 53.3527585119009, 72.845359146595, 70.94074174761772, 72.33537331223488, 53.1129115819931, 57.68171802163124, 91.60415455698967, 4.939931575208902, 0.3228106984170154, 0.29325938725378364, 0.15304993896279484, 0.20979747438104823], [0.046436094780801795, 0.05111843805934768, 0.12700416235020384, 1.495681086089462, 21.506958045065403, 15.629768762737513, 14.26061388105154, 39.59589309990406, 56.126628667116165, 69.9000383913517, 39.21726621687412, 31.492738611996174, 64.44350838661194, 64.33133840560913, 53.53734880685806, 42.74468153715134, 33.20129983127117, 54.15269538760185, 60.32587073743343, 28.902003429830074, 1.0587333887815475, 1.0716528142802417, 0.0913395507086534, 0.12563003139803186, 0.04094758987776004, 0.1365669578080997, 1.4290599734522402, 10.684226788580418, 25.473213717341423, 40.072300136089325, 43.77989038825035, 76.17993861436844, 62.99645483493805, 28.302623592317104, 16.45168460905552, 33.20608377456665, 53.87972563505173, 56.35954096913338, 57.18549504876137, 58.41457709670067, 33.58244977891445, 20.81701386719942, 28.695391416549683, 36.00274510681629, 30.156975388526917, 21.122620068490505, 24.524077847599983, 31.454157382249832, 33.770900666713715, 34.21539321541786, 43.82187433540821, 40.88000759482384, 38.70352618396282, 37.61654891073704, 39.66020464897156, 33.72625686228275, 15.149275995790958, 18.199338130652905, 23.060671873390675, 19.212608858942986, 9.397238697856665, 3.809259496629238, 5.844389442354441, 13.404705058783293, 20.97746405750513, 31.87488030642271, 37.44144290685654, 41.63231022655964, 43.61755929887295, 44.83026422560215, 42.123570665717125, 47.630265578627586, 46.087004989385605, 44.45886455476284, 40.89898377656937, 45.17103374004364, 45.754640623927116, 44.99908536672592, 45.88618576526642, 43.46715196967125, 42.538060024380684, 40.187388360500336, 41.48249566555023, 42.06135280430317, 42.33700901269913, 41.32844813168049, 41.62059165537357, 43.11510466039181, 43.752117678523064, 43.69230508804321, 40.978612303733826, 39.3290676176548, 38.641760498285294, 41.97042368352413, 40.14329172670841, 39.115454480051994, 39.32783268392086, 43.801811411976814, 42.73423209786415, 41.267013028264046, 39.02965508401394, 40.32689407467842, 37.80349127948284, 37.401009276509285, 38.14812898635864, 41.24781645834446, 39.35709871351719, 35.355689227581024, 38.15243415534496, 42.12779983878136, 32.764775454998016, 21.4677669480443, 5.40560751222074, 0.366740616154857, 0.23052527307299897, 0.12904348026495427, 0.233246520801913, 0.040304095891769975, 0.35829358035698533, 0.18071567552397028, 0.5037920479662716, 1.2147073005326092, 3.7088961945846677, 6.4514885656535625, 12.033274099230766, 29.248936213552952, 29.38281062990427, 23.41892994940281, 14.615328647196293, 4.319251980632544, 6.521920636296272, 21.951359398663044, 36.22124098241329, 43.58710013329983, 36.349742487072945, 23.043042719364166, 24.125142954289913, 40.22431097924709, 48.73482830822468, 47.39470101892948, 48.86766918003559, 44.80165176093578, 42.46983848512173, 39.09689627587795, 39.53220471739769, 39.14677619934082, 33.54743465781212, 24.335461668670177, 18.14790029078722, 27.032142765820026, 38.77212390303612, 39.96811352670193, 41.10812455415726, 11.944889891892672, 0.095266639982583, 8.047781009227037, 61.12196981906891, 63.05872209370136, 60.923073291778564, 33.07434104382992, 28.136053830385208, 30.146535448729992, 23.072523437440395, 33.110697492957115, 23.85400280356407, 36.27367056906223, 14.310458656400442, 27.93984565883875, 21.33406162261963, 57.74784207344055, 28.976730220019817, 0.14013759355293587, 0.17831711360486224, 0.03811272676102817, 0.030531918309861794, 0.046470270681311376, 0.04450454413017724, 0.028988442245463375, 0.44792429893277586, 5.382595947012305, 34.40449386835098, 36.92375488579273, 38.77900913357735, 72.29978442192078, 61.854460313916206, 80.86618155241013, 54.46756549179554, 45.38697995245457, 75.14498054981232, 68.65016385912895, 54.989817067980766, 47.14114062488079, 34.52415704727173, 63.98417383432388, 68.13645422458649, 52.02891334891319, 22.596636973321438, 1.3092730636708438, 0.4053954075789079, 0.08493063796777278, 0.0785323156742379, 0.303480630973354, 1.6727316356264055, 10.663901679217815, 30.168840251863003, 43.470184206962585, 50.5057080835104, 72.4426643550396, 68.3488704264164, 42.06017106771469, 22.456551790237427, 45.0932253152132, 61.69331856071949, 62.06969976425171, 59.236712381243706, 64.31221023201942, 44.07742582261562, 28.524679876863956, 34.92071136832237, 43.64706091582775, 35.618357732892036, 25.99262684583664, 28.570959493517876, 36.66631489992142, 37.367248088121414, 40.83755627274513, 50.27742013335228, 51.0350538790226, 51.484733149409294, 47.35485255718231, 48.86472813785076, 45.25974377989769, 34.692339822649956, 35.7520117610693, 38.23523551225662, 33.771862015128136, 19.810934253036976, 9.985101353377104, 4.576284913346171, 11.373894531279802, 22.431581430137157, 32.53325767815113, 39.468641728162766, 39.412594735622406, 47.15782552957535, 47.26824760437012, 46.513672694563866, 51.33224353194237, 49.36745636165142, 46.00438602268696, 46.90751016139984, 47.59713515639305, 49.008881002664566, 46.85295268893242, 48.45337741076946, 45.781942158937454, 46.316425278782845, 42.75071561336517, 45.10956063866615, 43.52604500949383, 47.64040723443031, 43.09427797794342, 45.02322927117348, 46.61092087626457, 48.43875579535961, 46.32489502429962, 44.26768161356449, 41.09574481844902, 41.74604952335358, 44.07068498432636, 43.435214683413506, 41.599814370274544, 42.29948602616787, 47.003417015075684, 45.93905232846737, 46.22842200100422, 41.537775099277496, 44.33333069086075, 40.78323058784008, 39.84895572066307, 40.42625494301319, 43.55319835245609, 40.62344916164875, 36.73251874744892, 39.92994077503681, 48.437661454081535, 35.270015224814415, 23.28882683068514, 5.40849725715816, 0.3497972065815702, 0.30403590586502105, 0.09206124479533173, 0.115631639782805, 0.02737102044193307, 0.25027938885614276, 0.1348010470974259, 0.39152463781647384, 1.2333851982839406, 7.098447550088167, 8.073595874011517, 12.084877230226994, 29.90050435066223, 36.83837726712227, 32.696223333477974, 21.66871726512909, 7.416651975363493, 12.736739851534367, 34.538945853710175, 42.717380002141, 47.17049024999142, 45.48242703080177, 33.21036994457245, 33.621272295713425, 48.86077634990215, 59.268338084220886, 56.44995331764221, 56.942745074629784, 50.70550516247749, 52.126062735915184, 46.077459901571274, 51.07631206512451, 52.44152560830116, 48.98106649518013, 43.60777102410793, 34.582620710134506, 32.4052919447422, 43.36312495172024, 45.12135900557041, 50.82218550145626, 16.120059303939342, 0.13071059627691284, 10.795329976826906, 70.368842035532, 67.46403470635414, 70.6459079682827, 35.934325978159904, 35.970796421170235, 34.98300142586231, 26.849190182983875, 32.787053659558296, 32.67067730426788, 56.78533852100372, 23.0927649512887, 48.22860807180405, 25.81777162849903, 62.78792582452297, 36.72653026878834, 0.2736720914253965, 0.27070804266259074, 0.09534426120808348, 0.07402456263662316, 0.06250351405469701, 0.14050317549845204, 0.13360981101868674, 0.6526527414098382, 4.7327272687107325, 65.78889459371567, 69.78678166866302, 42.74050176143646, 72.46863216161728, 75.08156955242157, 85.90050861239433, 59.138818234205246, 44.59104426205158, 70.45938357710838, 73.68142068386078, 68.88409450650215, 57.255491092801094, 48.20802077651024, 67.41741120815277, 84.00418996810913, 61.33202634751797, 39.05401177704334, 2.2566485591232777, 0.6907787674572319, 0.209275700035505, 0.1185418531531468, 0.31588004843797535, 2.4270079052075744, 13.458303082734346, 36.78924970328808, 51.904044449329376, 57.76478536427021, 74.67308387160301, 75.17452016472816, 50.075916945934296, 32.530894204974174, 57.860411033034325, 62.849258333444595, 63.5730054974556, 56.24860592186451, 64.77411344647408, 50.69406017661095, 40.122100263834, 51.23263567686081, 50.557704493403435, 41.3179112970829, 28.297172784805298, 29.51227158308029, 40.888906717300415, 39.597382619977, 41.67226888239384, 50.71369372308254, 53.803429529070854, 52.71014079451561, 50.413145050406456, 55.0094810128212, 51.84558838605881, 38.998857736587524, 41.91445268690586, 39.99520607292652, 33.62306199967861, 20.663821287453175, 12.167503796517849, 16.08343306928873, 19.704230278730392, 27.994946502149105, 40.33798187971115, 39.312196522951126, 39.24398258328438, 47.39151678979397, 46.67969338595867, 45.70954084396362, 52.17894829809666, 52.535167783498764, 47.07085959613323, 46.89009949564934, 48.26036676764488, 52.371898144483566, 48.775326535105705, 49.627837389707565, 48.349251598119736, 48.95887568593025, 45.62764763832092, 48.60027752816677, 48.208385556936264, 51.89809396862984, 46.28273628652096, 49.0448422729969, 48.88376131653786, 53.39480705559254, 51.02877661585808, 47.398846596479416, 44.73254106938839, 43.85649807751179, 47.06036455929279, 49.26295056939125, 44.747630059719086, 45.31175538897514, 48.77019681036472, 48.06576021015644, 46.524562910199165, 45.01945607364178, 47.78142526745796, 44.244016483426094, 42.60861463844776, 42.07823909819126, 45.975081995129585, 45.015637278556824, 41.51422016322613, 44.81882303953171, 51.970354691147804, 40.23446023464203, 30.0237450376153, 8.774537611752748, 0.5964640877209604, 0.33004126511514187, 0.22941139846807346, 0.19226113334298134, 0.07982179726241156, 0.4820952715817839, 0.2842649433296174, 0.7384372351225466, 2.793453116901219, 9.442819152027369, 10.284730475395918, 18.122572749853134, 34.34120066463947, 38.82516145706177, 33.65407593548298, 23.6561132222414, 8.072158601135015, 12.126347254961729, 36.00071981549263, 42.89864167571068, 45.30411779880524, 48.98955523967743, 43.82035441696644, 39.397577941417694, 50.9065143764019, 58.26228126883507, 54.756475389003754, 57.564019337296486, 54.60865572094917, 56.58668518066406, 54.532697796821594, 56.10069505870342, 58.54402095079422, 55.965243726968765, 54.76258926093578, 43.69457356631756, 39.382348358631134, 48.39479595422745, 50.821915715932846, 62.21840478479862, 21.10275473445654, 0.25409583875443786, 9.943913463503122, 77.78883308172226, 73.29561218619347, 79.75297808647156, 43.134259432554245, 44.72159005701542, 47.73079678416252, 31.555820927023888, 47.65172302722931, 36.937905326485634, 57.63387478888035, 24.18145403265953, 46.56242407858372, 37.2707636654377, 89.50766265392303, 55.02648890018463, 0.39528934517875314, 0.423696888028644, 0.20579851552611217, 0.21622615051455796, 0.13699357397854328], [0.0743108535243664, 0.10497030249098316, 0.05530352755158674, 0.42853248480241746, 17.979951202869415, 44.68208357691765, 22.960486449301243, 24.817651994526386, 58.74313026666641, 62.751200795173645, 49.42402392625809, 20.30143853276968, 26.078990511596203, 62.07026593387127, 69.87391859292984, 44.06341977417469, 35.351881831884384, 43.86635094881058, 62.47698470950127, 42.484080120921135, 12.193056475371122, 0.7196094235405326, 0.18047823279630393, 0.10200798293226399, 0.04590413816913497, 0.3913806314812973, 7.72098476998508, 34.15495365858078, 43.720374181866646, 50.32530136406422, 58.054732605814934, 63.918156176805496, 53.281132355332375, 33.84052813053131, 27.948381900787354, 43.55687275528908, 52.38649696111679, 54.450633600354195, 56.626510843634605, 58.72066207230091, 41.234916150569916, 31.27389695495367, 42.86030173301697, 47.97014594078064, 48.80629487335682, 39.74064253270626, 41.70697622001171, 48.58112275600433, 47.86263071000576, 49.84396979212761, 52.312727719545364, 53.192920088768005, 56.41891658306122, 59.22627434134483, 47.12576664984226, 42.67752394080162, 36.86418168246746, 35.729885548353195, 38.29142689704895, 39.38964396715164, 26.72030109912157, 12.127050217241049, 3.0765099031850696, 2.2265548864379525, 12.666608914732933, 14.034772999584675, 33.696861639618874, 37.89745643734932, 40.61684511601925, 42.557321190834045, 44.38674062490463, 46.00886598229408, 46.19173116981983, 42.83217944204807, 43.160474225878716, 44.35594327747822, 42.20040634274483, 45.30384801328182, 43.6609073728323, 43.44954751431942, 40.06994426250458, 40.568340718746185, 40.65262399613857, 41.85284659266472, 43.15018057823181, 40.52965119481087, 41.580408811569214, 44.93729308247566, 42.441727593541145, 43.48326690495014, 42.201732471585274, 39.33676980435848, 40.725576281547546, 42.068295031785965, 38.83934609591961, 40.123973563313484, 43.65781053900719, 43.644826635718346, 41.59777007997036, 41.56363271176815, 39.77656580507755, 38.88464726507664, 37.86723665893078, 37.658042684197426, 39.45552483201027, 46.02429695427418, 39.45886865258217, 35.033348724246025, 34.093157574534416, 40.74958719313145, 32.00440965592861, 14.338352959603071, 0.40023733279667795, 0.12322065638727508, 0.054236860960372724, 0.11325892686727457, 0.27809463848825544, 0.07083692704327404, 0.05973348866973538, 0.07717097934801131, 2.01790452003479, 1.2661996437236667, 5.033267391845584, 9.86859580501914, 11.270262692123652, 23.090410977602005, 41.96717485785484, 40.961323231458664, 32.22473703324795, 26.206325478851795, 37.783960327506065, 61.330506429076195, 55.304447785019875, 61.22175246477127, 47.918434515595436, 40.05770891904831, 51.661176681518555, 50.120173171162605, 46.94276846945286, 42.504625618457794, 42.96396777033806, 39.68916669487953, 38.25788989663124, 39.50887016952038, 40.255568102002144, 41.57298021018505, 41.49939335882664, 36.21617965400219, 28.05272050201893, 26.68460201472044, 34.115014001727104, 39.12104018032551, 39.66408424079418, 12.425805386155844, 0.013021275062783388, 18.958592489361763, 64.8912687599659, 56.62671983242035, 40.21592102944851, 30.023517049849033, 33.661987110972404, 28.021586872637272, 18.073800466954708, 40.11473245918751, 30.309689193964005, 26.267492696642876, 32.9914028942585, 36.84001497924328, 47.90252096951008, 62.55352780222893, 5.1857042871415615, 0.12503184552770108, 0.05835854877659585, 0.12885513802757487, 0.06273662263993174, 0.013485076542565366, 0.05644373355607968, 0.06311830176855437, 0.0754115401650779, 0.7606366532854736, 33.77481825649738, 43.802248388528824, 27.82986056059599, 51.065064668655396, 93.32296952605247, 71.8707874417305, 27.80351087450981, 20.260841511189938, 33.511047810316086, 68.43887999653816, 67.56437972187996, 57.33023688197136, 33.481933772563934, 50.919148698449135, 74.83654350042343, 56.789662688970566, 40.58826304972172, 6.153395511209965, 0.41287129861302674, 0.010561017479631118, 0.04646313493140042, 0.36909304617438465, 10.568738635629416, 40.78443132340908, 49.43791218101978, 56.797421872615814, 59.93357978761196, 67.69394516944885, 66.65439695119858, 43.68456490337849, 36.07395328581333, 53.16232793033123, 60.07989853620529, 60.896140336990356, 61.13852933049202, 64.3735921382904, 48.495304360985756, 38.30644749104977, 50.985470339655876, 56.3932603597641, 55.195534229278564, 44.822071865200996, 43.312340676784515, 50.79989209771156, 52.5766159594059, 56.01879045367241, 55.035008043050766, 56.224291026592255, 61.112208142876625, 63.81558448076248, 54.77457381784916, 50.472304075956345, 47.119664177298546, 47.50581085681915, 48.11462178826332, 51.00069232285023, 39.66579034924507, 18.274294808506966, 8.327193316072226, 2.0771820517256856, 9.53806484118104, 18.947044909000397, 35.32500967383385, 41.10114812850952, 44.72648799419403, 42.61651821434498, 45.182220339775085, 45.905887708067894, 46.92960977554321, 43.70857201516628, 45.77814996242523, 45.676220431923866, 47.0845540612936, 48.329743444919586, 47.975423857569695, 44.76765118539333, 43.82196173071861, 43.628867492079735, 42.95612879097462, 42.260310128331184, 44.51578550040722, 41.41085430979729, 44.8895600438118, 48.31874683499336, 47.00331822037697, 46.23004071414471, 44.44765515625477, 44.094859287142754, 42.19663314521313, 43.160535022616386, 42.2712991386652, 42.25337170064449, 46.85989111661911, 47.53310099244118, 45.70665679872036, 44.87794026732445, 43.796453699469566, 41.85449190437794, 38.78816284239292, 41.98441073298454, 44.48556952178478, 47.003333419561386, 40.52835926413536, 37.98973448574543, 37.024343088269234, 40.00528693199158, 32.20031954348087, 9.207545276731253, 0.4996189218945801, 0.22869654698297381, 0.10159191268030554, 0.14068871241761371, 0.2622106595663354, 0.1152213582827244, 0.020130505254201125, 0.26575880823656917, 1.322700830642134, 2.895824611186981, 5.555187435820699, 16.46338988095522, 18.203291818499565, 34.34907004237175, 48.14337484538555, 45.77753059566021, 37.467406913638115, 34.67617928981781, 47.07796521484852, 62.8370001912117, 62.05694764852524, 63.15989166498184, 58.21966275572777, 50.93825787305832, 61.35971166193485, 59.09466080367565, 52.32641078531742, 49.88303929567337, 51.30935736000538, 49.66946795582771, 49.72166955471039, 47.63134852051735, 48.14961031079292, 51.752915158867836, 53.377989158034325, 50.57655148208141, 47.77924798429012, 45.28346970677376, 45.05018122494221, 53.25627788901329, 49.679476618766785, 14.67024140059948, 0.02433280329569243, 24.61684986948967, 73.69598150253296, 62.73448169231415, 44.33599054813385, 36.34276986122131, 38.76776933670044, 34.793148413300514, 21.25968061387539, 36.25785581767559, 34.40412528812885, 21.740404218435287, 37.312873005867004, 51.32663123309612, 51.52389004826546, 72.89122268557549, 6.648172661662102, 0.10803142416989431, 0.08344449466676451, 0.05551021567953285, 0.0793596099538263, 0.037666588395950384, 0.22767324408050627, 0.22547203407157212, 0.14622007263824344, 1.2596525950357318, 40.38242429494858, 89.75231632590294, 52.39881969988346, 46.64119005203247, 84.06394556164742, 70.091183334589, 73.28761741518974, 35.69571018218994, 32.828779220581055, 79.29822608828545, 74.02524903416634, 64.53243881464005, 46.03627771139145, 56.73442505300045, 85.98596602678299, 63.9796444773674, 55.31118482351303, 8.938424717634916, 0.47694832901470363, 0.24342639720998704, 0.29959985171444714, 0.5962949967943132, 15.817311499267817, 46.76509000360966, 55.003082156181335, 62.6134429872036, 65.86658522486687, 69.61952224373817, 68.92883330583572, 55.016305446624756, 49.18983869254589, 60.48220194876194, 60.93235619366169, 59.73279096186161, 57.18212082982063, 63.0025877058506, 55.86093172430992, 49.35459025204182, 55.4936396330595, 53.69752921164036, 54.92706723511219, 44.25892688333988, 44.45447959005833, 53.15364919602871, 55.5524642765522, 56.738338842988014, 55.67148149013519, 57.547228038311005, 59.30871471762657, 64.48590651154518, 57.318244725465775, 55.37601314485073, 52.87954330444336, 50.332399383187294, 52.27439537644386, 53.33981640636921, 42.74183169007301, 18.324919492006302, 8.252869304269552, 8.71131470426917, 15.550524014979601, 21.95563606917858, 39.069397151470184, 40.939371809363365, 45.07275961339474, 44.71245154738426, 47.98296645283699, 46.146259009838104, 51.314996257424355, 44.81989838182926, 48.10435093939304, 46.90733157098293, 49.775193482637405, 52.32682876288891, 50.05220241844654, 47.61159338057041, 44.68963757157326, 44.49281573295593, 44.428872764110565, 46.581236869096756, 47.97050692141056, 44.53950382769108, 48.17053958773613, 51.10514871776104, 50.25486074388027, 50.93388430774212, 48.85420650243759, 48.40789005160332, 46.302225440740585, 48.26025277376175, 44.51312944293022, 45.74931710958481, 49.800036549568176, 51.42732962965965, 49.01331916451454, 48.4637014567852, 47.92142875492573, 44.59425888955593, 42.26797431707382, 42.59952552616596, 46.12428478896618, 50.97850911319256, 44.30048905313015, 39.92741011083126, 38.33285607397556, 44.64523695409298, 39.1922065615654, 16.70154020190239, 1.5235869074240327, 0.5014505423605442, 0.21760998875834048, 0.3750727971782908, 0.36107684194575995, 0.2228857681620866, 0.23728655010927469, 0.4234887007623911, 3.5631562024354935, 5.230591278523207, 10.257518235594034, 18.627045080065727, 23.59669581055641, 36.172417402267456, 52.53556676208973, 46.62897750735283, 35.44527322053909, 34.88273620605469, 49.28341627120972, 64.53969642519951, 62.52587288618088, 65.34200817346573, 59.76929560303688, 55.40117919445038, 60.88149592280388, 57.26044602692127, 54.72698137164116, 54.13606368005276, 55.80350540578365, 54.732791259884834, 52.19935320317745, 51.44754834473133, 54.14676010608673, 58.481221720576286, 60.0133641064167, 57.77766667306423, 56.53919152915478, 52.41580478847027, 54.88610163331032, 61.27347148954868, 56.51500582695007, 16.332633197307587, 0.18950827012304217, 24.46208417415619, 80.04858702421188, 72.26682499051094, 55.13474129140377, 48.716475293040276, 52.193258330225945, 48.8796803355217, 24.497481174767017, 58.534711450338364, 42.053931802511215, 43.92848141491413, 55.91406807303429, 63.18075634539127, 76.96474090218544, 108.82619082927704, 9.018630813807249, 0.14464443374890834, 0.23687955632340163, 0.2375699911499396, 0.18246882129460573, 0.18642053502844647], [0.06123505379946437, 0.025706652231747285, 0.03346834062540438, 0.5828961438965052, 3.647010577842593, 50.81427812576294, 63.16061742603779, 31.931559965014458, 28.003309853374958, 45.88039107620716, 74.15166825056076, 59.60696071386337, 44.08720649778843, 45.19803889095783, 57.784050330519676, 47.55461543798447, 38.229338228702545, 32.60583758354187, 57.88253344595432, 51.76682621240616, 36.497501358389854, 7.0047312788665295, 0.45760947454255074, 0.1692739996360615, 0.08449824046692811, 3.6154371220618486, 14.87925773486495, 43.09430077672005, 46.58116087317467, 62.821345031261444, 63.41611951589584, 35.30505694448948, 31.82777613401413, 43.74149724841118, 50.847606137394905, 54.1867795586586, 56.5149412304163, 54.54747900366783, 54.06866669654846, 55.93120515346527, 51.45939610898495, 45.13551704585552, 52.236332818865776, 53.15727420151234, 51.97551101446152, 53.4939019382, 59.453646540641785, 57.89919175207615, 55.65178334712982, 55.22052928805351, 56.376655250787735, 56.90677620470524, 58.95574025809765, 55.53235575556755, 53.852112516760826, 45.47905661165714, 52.214430794119835, 52.660108879208565, 52.79989577829838, 51.8804857134819, 48.18784385919571, 32.52280443906784, 11.307925321161747, 3.154134750366211, 5.416400833055377, 13.694950584322214, 22.053619511425495, 37.83941075205803, 37.88171388208866, 39.608417227864265, 42.044386714696884, 48.506502360105515, 43.49716275930405, 42.52502292394638, 41.013076454401016, 44.66084271669388, 42.45890647172928, 46.25477738678455, 45.191868022084236, 42.922048419713974, 43.10028165578842, 42.68394559621811, 41.92024737596512, 40.86627133190632, 40.51982492208481, 43.45689631998539, 44.02219958603382, 43.91618527472019, 42.385087832808495, 43.766746893525124, 38.79616141319275, 41.70050136744976, 40.21980822086334, 39.585177674889565, 39.773282781243324, 40.420084074139595, 41.740216836333275, 46.1656379699707, 43.37784916162491, 41.873346492648125, 39.449209570884705, 39.14218224585056, 36.878822296857834, 39.478870779275894, 42.00720950961113, 41.88030391931534, 37.77765266597271, 37.18123286962509, 36.814655140042305, 33.869019001722336, 18.15566137433052, 2.8474235208705068, 0.27605592913459986, 0.34381113247945905, 0.5169896897859871, 0.44549441838171333, 0.9414245397783816, 1.5940002165734768, 1.8987619131803513, 1.7326406459324062, 3.99617669172585, 4.652491249144077, 5.262338574975729, 19.572688937187195, 17.38572958856821, 38.359500244259834, 48.42601887881756, 52.80982844531536, 54.585796147584915, 49.717242792248726, 55.61012618243694, 55.84580473601818, 55.05976751446724, 55.506600737571716, 52.433656230568886, 50.93263417482376, 55.516119226813316, 47.90529862046242, 42.53736466169357, 39.44889798760414, 39.37917172908783, 39.49725419282913, 36.15731321275234, 38.09379570186138, 35.467528626322746, 40.0956004858017, 40.94241924583912, 43.34739379584789, 39.571319818496704, 41.26779958605766, 41.18888922035694, 46.90603584051132, 43.780931532382965, 11.725097335875034, 0.1871637810836546, 34.46430645883083, 65.27002483606339, 49.606664925813675, 36.710441932082176, 34.07046519219875, 25.078601092100143, 37.83043943345547, 22.946039624512196, 40.15190586447716, 43.1913323700428, 82.74010419845581, 45.71126975119114, 39.49120491743088, 64.05323132872581, 29.14104100316763, 0.08529109909432009, 0.0757584793609567, 0.029524948222388048, 0.012575985529110767, 0.03880406329699326, 0.05885684899112675, 0.09104404976824299, 0.040675978671060875, 0.07561954189441167, 0.6334517186041921, 8.078300021588802, 69.63162079453468, 44.589664936065674, 22.60464884340763, 45.56428223848343, 77.7620293200016, 64.34994980692863, 38.530259281396866, 33.07086043059826, 55.904925763607025, 54.80357006192207, 54.97091308236122, 41.00038893520832, 36.875778660178185, 68.83047938346863, 61.0206064581871, 58.55756722390652, 23.28151222318411, 0.4999114468228072, 0.14770852401852608, 0.12908805365441367, 4.787364061921835, 20.313728973269463, 53.5481022298336, 56.47446200251579, 68.05265352129936, 67.4734278023243, 42.0052982121706, 42.545872405171394, 55.967120826244354, 61.64338544011116, 63.747233748435974, 63.65766115486622, 60.773881897330284, 58.067716509103775, 61.97709873318672, 57.61226914823055, 53.76529477536678, 60.54781302809715, 60.52403770387173, 57.51277148723602, 58.34950938820839, 61.66739635169506, 60.32314248383045, 58.64828735589981, 57.561196088790894, 63.52291278541088, 61.9725351780653, 61.54506951570511, 57.88610905408859, 56.300218552351, 52.46938571333885, 51.82502768933773, 52.88155719637871, 54.64103378355503, 51.491869166493416, 50.963807702064514, 43.32979314029217, 16.665835417807102, 6.258952897042036, 1.7932792170904577, 11.080289036035538, 28.364339880645275, 40.83198957145214, 40.91043256223202, 40.96157781779766, 45.03526322543621, 50.550321489572525, 46.068139001727104, 45.95446050167084, 44.1840822994709, 44.97195102274418, 46.27872750163078, 49.21002700924873, 50.04700429737568, 47.132663279771805, 44.66173566877842, 45.92245101928711, 45.30951350927353, 43.37578967213631, 43.205767795443535, 47.127123177051544, 47.76934951543808, 48.77634108066559, 44.9083386361599, 46.413753256201744, 40.421113818883896, 45.15184096992016, 41.757118329405785, 42.12100960314274, 41.98304280638695, 43.076787516474724, 44.00101192295551, 47.928766161203384, 45.027952417731285, 45.25488004088402, 42.37988591194153, 42.37826719880104, 40.34979544579983, 42.56810121238232, 44.45297107100487, 43.84151928126812, 38.026911690831184, 40.76559193432331, 37.529704570770264, 36.00106179714203, 16.073815785348415, 4.593886993825436, 0.823233425617218, 0.09654035093262792, 0.5703410238493234, 0.8361998735927045, 0.8636756055057049, 1.9872810132801533, 1.1136996955610812, 1.472765940707177, 5.186166912317276, 5.705900173634291, 14.118371363729239, 27.018491998314857, 33.23395527899265, 45.52229069173336, 51.3287553191185, 57.026739567518234, 59.60017427802086, 55.025170370936394, 59.765370413661, 61.48789398372173, 60.373250395059586, 60.788537710905075, 59.77455072104931, 59.803634360432625, 59.99941125512123, 54.72752094268799, 50.78247383236885, 47.98191390931606, 47.62625679373741, 45.17582528293133, 44.54868793487549, 46.720077618956566, 44.57377798855305, 47.847062945365906, 51.38942286372185, 51.955862268805504, 52.026530876755714, 52.910340651869774, 55.76927304267883, 59.20034073293209, 51.76770396530628, 13.512813057750463, 0.7553751824889332, 40.57130075991154, 73.22450280189514, 53.03587071597576, 48.324115946888924, 48.97293873131275, 32.35020250082016, 43.55734393000603, 26.498123221099377, 42.511864230036736, 44.60002318024635, 96.08812674880028, 60.78042134642601, 44.21590939164162, 77.13418141007423, 35.51821790635586, 0.2731906750705093, 0.04867910625762306, 0.041144945498672314, 0.023970776237547398, 0.025725899831741117, 0.07790349394781515, 0.2143482942483388, 0.15253666962962598, 0.2442955708829686, 0.9381607524119318, 6.333142966032028, 83.9756990969181, 89.74332600831985, 47.70859457552433, 45.726332142949104, 62.33848974108696, 85.04865512251854, 78.37682873010635, 56.48455046117306, 56.300446540117264, 66.2315708398819, 63.300947695970535, 51.8683947622776, 44.25387315452099, 74.35358181595802, 69.13295835256577, 68.52992311120033, 29.963370077311993, 0.7385826366953552, 0.2234711148776114, 0.2658473019255325, 6.785401348024607, 33.665399327874184, 57.34369195997715, 57.80522279441357, 70.88134333491325, 72.26734936237335, 51.78346171975136, 51.38194866478443, 58.82274739444256, 62.197844088077545, 60.633627623319626, 62.107994109392166, 59.59443658590317, 56.49243123829365, 59.467177614569664, 58.67249585688114, 55.10256841778755, 58.610209599137306, 57.15764254331589, 55.41497245430946, 54.981411918997765, 62.45423153042793, 61.15617178380489, 62.83602364361286, 57.58271053433418, 63.321219608187675, 65.08934453129768, 63.72056297957897, 59.702369794249535, 59.178906083106995, 57.135523930191994, 57.715695798397064, 58.434982001781464, 59.27790217101574, 55.7837350666523, 53.73944476246834, 48.61015699803829, 16.99532713741064, 6.046476373448968, 7.217849493026733, 15.385770555585623, 27.847307324409485, 39.289686530828476, 44.48529593646526, 43.57237972319126, 49.16190639138222, 53.303368762135506, 47.29135416448116, 48.59285272657871, 46.008645594120026, 46.31069138646126, 46.813442409038544, 53.04690532386303, 52.84950211644173, 48.98692958056927, 45.6399779766798, 49.0051344037056, 46.62777677178383, 45.37566415965557, 45.98148085176945, 49.84919831156731, 49.69519257545471, 51.98035955429077, 47.91510209441185, 49.56643648445606, 43.72044637799263, 49.741956666111946, 45.324773490428925, 44.499017000198364, 46.23297795653343, 47.73049660027027, 48.30371864140034, 53.30349035561085, 48.43232274055481, 47.23417483270168, 46.10764168202877, 45.903246849775314, 42.7314430475235, 45.89801073074341, 47.24076747894287, 45.27401961386204, 41.15631736814976, 42.502843514084816, 40.92526316642761, 42.3237781226635, 22.60897871106863, 6.32226082496345, 1.1028627958148718, 0.7508395914919674, 1.2021530116908252, 0.759827415458858, 1.4279733505100012, 3.0929126730188727, 2.8551689302548766, 2.1004622150212526, 8.138719629496336, 9.105915930122137, 20.464442186057568, 36.796560510993004, 40.42203716933727, 51.395852118730545, 53.94631326198578, 58.332835882902145, 59.38102103769779, 52.96417996287346, 57.736123502254486, 59.72879737615585, 58.44666637480259, 60.28380699455738, 58.27479399740696, 55.764576494693756, 58.210022673010826, 56.0825814306736, 55.65089799463749, 52.95755311846733, 50.47676503658295, 49.313658848404884, 49.97348204255104, 53.04635055363178, 48.67709420621395, 54.71515640616417, 59.39802132546902, 61.560690477490425, 59.44373667240143, 61.51330702006817, 60.96315734088421, 64.22717839479446, 59.273748993873596, 16.83474015444517, 0.9251368325203657, 40.484904795885086, 80.96876084804535, 62.24398121237755, 61.35650843381882, 49.67338174581528, 43.98250311613083, 57.88290202617645, 31.09134905040264, 53.542847111821175, 68.73207226395607, 118.42802479863167, 73.70571658015251, 64.7812570631504, 94.65225979685783, 50.05124107003212, 0.44998361030593514, 0.14797275827731937, 0.17131820088252425, 0.17390408087521791, 0.13380554504692554, 0.21139528864296153], [0.05118890498124529, 0.05944900491158478, 0.10606480704154819, 0.016835174756124616, 0.9856903238687664, 21.997089944779873, 66.30654841661453, 68.42060297727585, 32.68659085035324, 22.66176737844944, 31.506564170122147, 66.69152095913887, 63.553949519991875, 24.264183193445206, 31.571202501654625, 48.56691151857376, 42.71845534443855, 25.154289230704308, 43.3145597577095, 56.7524740844965, 49.7274262458086, 34.85398314893246, 1.4499221602454782, 0.10013878752943128, 1.4034714340232313, 12.189939692616463, 15.79594999551773, 44.33491140604019, 61.69329576194286, 65.07265582680702, 55.63176602125168, 35.74937470257282, 40.09625405073166, 54.84573259949684, 58.554041013121605, 54.10276226699352, 49.890992268919945, 51.99712045490742, 46.74695357680321, 47.9068261384964, 51.820855513215065, 53.19647289812565, 53.711151480674744, 55.230625346302986, 56.27764396369457, 58.15566658973694, 57.37391173839569, 58.591772988438606, 58.43569256365299, 56.68153189122677, 57.64126539230347, 59.31813061237335, 62.55373679101467, 63.90911266207695, 58.5727322101593, 56.92692652344704, 55.946799516677856, 61.004324331879616, 59.84921291470528, 54.2157644033432, 50.4571732878685, 44.13741320371628, 30.80510850995779, 14.119382109493017, 3.0419726064428687, 4.283316358923912, 21.816396340727806, 35.87531894445419, 39.300584346055984, 37.24647156894207, 41.44588842988014, 42.561694756150246, 43.9425178617239, 44.060189947485924, 41.090774685144424, 42.476799711585045, 44.9688807874918, 43.91806997358799, 43.62101711332798, 44.02990937232971, 44.49214696884155, 44.743366688489914, 39.89984259009361, 40.229550898075104, 38.770991563797, 40.12594945728779, 46.14614501595497, 45.42682461440563, 40.85935190320015, 43.77824127674103, 39.55724157392979, 41.61491475999355, 38.60016793012619, 38.81469301879406, 39.11824733018875, 36.551044285297394, 40.77939659357071, 42.93026737868786, 39.856935292482376, 40.923902839422226, 38.18056404590607, 37.62790270149708, 35.037688091397285, 39.862182810902596, 41.72417789697647, 37.854241356253624, 35.48552826046944, 38.850525096058846, 31.594785936176777, 24.699396640062332, 8.902084417641163, 3.026715237647295, 0.7522341760341078, 4.595849113538861, 3.792323567904532, 2.557800211943686, 3.167547080665827, 3.8926847325637937, 4.374020341783762, 9.960301034152508, 19.373737312853336, 17.36284341663122, 15.088766142725945, 16.483015827834606, 35.696922317147255, 46.042224392294884, 49.031466990709305, 50.69755218923092, 52.4689145386219, 50.11955000460148, 54.311116486787796, 56.437983959913254, 54.85210105776787, 50.94551548361778, 53.07598136365414, 52.45876528322697, 45.00362612307072, 41.14533595740795, 39.47710007429123, 36.09697625041008, 35.27684345841408, 34.66040253639221, 34.90971475839615, 36.60706847906113, 40.73425121605396, 41.20654687285423, 42.272632867097855, 42.50009246170521, 45.095824375748634, 45.97496040165424, 51.65356948971748, 50.172712951898575, 47.59105548262596, 10.390915777534246, 1.1798289720900357, 43.721753507852554, 68.58329504728317, 42.83190205693245, 38.22002112865448, 24.014346599578857, 19.158856943249702, 50.533017218112946, 38.31895262002945, 18.53452194482088, 45.15323169529438, 47.632279470562935, 25.969702675938606, 30.516419000923634, 60.739383548498154, 5.665320251137018, 0.17605296947294846, 0.05688451732567046, 0.04845167510211468, 0.06342253778711893, 0.05722244313801639, 0.07863848732085899, 0.03513751238642726, 0.05963650481135119, 0.1034628892375622, 0.14589035126846284, 0.5346244247630239, 34.18545462191105, 78.15576419234276, 47.53776714205742, 25.590963698923588, 26.685960441827774, 51.908835992217064, 71.64066419005394, 50.192084312438965, 25.93994077295065, 33.704332038760185, 61.211629807949066, 54.533366560935974, 28.445818908512592, 52.53755025565624, 64.08688992261887, 59.74146209657192, 50.1370594650507, 2.432570569217205, 0.3535162570187822, 3.474703123793006, 19.75607469677925, 28.244070634245872, 54.36756245791912, 66.6374346613884, 70.24072051048279, 63.81951346993446, 43.140133917331696, 46.4714265614748, 62.42286801338196, 64.57082435488701, 60.28108634054661, 57.25934408605099, 57.38989368081093, 54.61921535432339, 54.90599736571312, 61.01333364844322, 63.62814053893089, 59.488376677036285, 62.13438369333744, 61.380732133984566, 61.49367347359657, 61.64914213120937, 59.653242230415344, 63.513903468847275, 59.50527437031269, 61.88545525074005, 59.709144830703735, 59.59880635142326, 63.57400484383106, 57.32987970113754, 58.86999025940895, 57.19786338508129, 59.729914516210556, 59.83554504811764, 57.447703778743744, 51.93104200065136, 45.65795101225376, 36.98031485080719, 27.38911461085081, 8.68025517091155, 4.499814016744494, 18.909195140004158, 35.9615059196949, 40.37587344646454, 39.75926533341408, 45.01571327447891, 46.72664746642113, 45.54767332971096, 45.11419638991356, 42.0156754553318, 43.64952318370342, 45.33835016191006, 45.81563875079155, 45.6988026201725, 46.14568144083023, 46.29267655313015, 48.08247931301594, 43.70864041149616, 43.05647760629654, 40.780654326081276, 45.481518879532814, 47.25272923707962, 45.17315782606602, 44.47091370820999, 45.526025891304016, 44.83121417462826, 45.940515249967575, 41.12982138991356, 42.624060809612274, 40.987374633550644, 40.49573041498661, 42.15869218111038, 44.10732261836529, 44.31863307952881, 46.20867446064949, 41.06234461069107, 40.3649528324604, 39.237127751111984, 42.88932077586651, 42.25356929004192, 39.629099518060684, 38.294234946370125, 42.10061989724636, 34.08883340656757, 27.957624904811382, 10.801998618990183, 6.3191326428204775, 4.781119571998715, 7.0434554759413, 4.943396989256144, 3.0668282601982355, 4.854414314031601, 4.770044116303325, 6.08565797097981, 12.059176359325647, 24.968247413635254, 32.08722621202469, 28.981236778199673, 30.788672491908073, 43.74399371445179, 49.418901801109314, 51.48730181157589, 54.66919407248497, 55.409211963415146, 52.021591141819954, 58.823997527360916, 60.033776611089706, 57.89164915680885, 54.32202950119972, 58.26860412955284, 55.24356745183468, 51.840827241539955, 48.757121711969376, 47.82610706984997, 44.2884436994791, 43.32936376333237, 42.21280127763748, 43.9980860799551, 45.535791367292404, 47.86817841231823, 47.535456866025925, 51.532378792762756, 50.006525069475174, 55.420375764369965, 56.98870360851288, 64.30587977170944, 57.17301271855831, 59.53278109431267, 10.885531436651945, 2.4102218309417367, 48.582623675465584, 74.05598938465118, 47.07779422402382, 54.8729657381773, 32.41352990269661, 22.88274262100458, 61.65742568671703, 34.20082859694958, 24.233260452747345, 55.739193856716156, 54.680046290159225, 35.303673818707466, 36.55787251889706, 74.71631035208702, 4.428598713129759, 0.06884334768983535, 0.16588333470281214, 0.0645886966958642, 0.02096726377203595, 0.013479513218044303, 0.07712323698797263, 0.3792204230558127, 0.1644430190208368, 0.3154631395591423, 0.3156952833523974, 1.8521752255037427, 32.168378457427025, 92.90506035089493, 86.10743030905724, 49.870925545692444, 37.29651868343353, 44.408566653728485, 81.7355065047741, 71.77443981170654, 34.6528447419405, 37.08808846771717, 65.195602029562, 56.25201053917408, 37.28280521929264, 55.46375423669815, 73.48488003015518, 67.29559734463692, 54.750585705041885, 2.0387597009539604, 0.18838461401173845, 2.966608637943864, 23.73357016593218, 38.455122113227844, 58.603795543313026, 68.38036313652992, 73.65852311253548, 66.54478043317795, 52.771302312612534, 51.04087516665459, 60.83844043314457, 61.0685370862484, 57.848088294267654, 53.608097210526466, 57.01276771724224, 53.99569921195507, 54.80471380054951, 57.03744359314442, 61.49233974516392, 55.393089428544044, 59.0299578756094, 61.10334701836109, 61.10736720263958, 61.654701232910156, 60.90253159403801, 65.88768169283867, 61.898492351174355, 60.427462086081505, 60.41706584393978, 62.150947004556656, 64.58630472421646, 61.67144313454628, 61.55516937375069, 60.82701824605465, 64.35805857181549, 64.25306260585785, 63.650034964084625, 57.37630560994148, 51.73786036670208, 42.96878971159458, 29.358450137078762, 8.953335117548704, 11.245801504701376, 25.443839393556118, 35.336302667856216, 43.37300442159176, 40.429378375411034, 48.2926270365715, 49.76703532040119, 48.910796865820885, 46.87755636870861, 45.66075526177883, 47.61659771203995, 47.97821670770645, 51.007395163178444, 48.637291342020035, 49.280251041054726, 51.05338789522648, 51.465217396616936, 47.15173065662384, 45.959879010915756, 43.859344124794006, 47.186267003417015, 52.747002616524696, 50.00554472208023, 47.60041058063507, 49.8463598638773, 44.931996166706085, 49.853879660367966, 47.127685546875, 45.442836955189705, 44.14940156042576, 40.75365677475929, 44.53951522707939, 48.14665026962757, 46.47612690925598, 48.03468927741051, 44.96652491390705, 43.47174972295761, 41.86048038303852, 46.70717351138592, 47.248025089502335, 40.21289639174938, 40.173975080251694, 44.226351231336594, 38.960836976766586, 30.813832841813564, 16.58125765621662, 8.093547653406858, 5.983893256634474, 9.64297816157341, 7.061295518651605, 4.5072706416249275, 7.8605907037854195, 9.27735323086381, 9.022291917353868, 11.255660075694323, 24.305507875978947, 35.33767819404602, 37.064708322286606, 38.80474515259266, 48.27493138611317, 54.14822302758694, 53.087608739733696, 56.71847730875015, 55.98571702837944, 51.80672027170658, 59.06149618327618, 60.29183976352215, 59.676223397254944, 55.303471237421036, 60.211728662252426, 56.43379658460617, 56.66585013270378, 52.66141980886459, 51.715490967035294, 46.522024646401405, 48.03501985967159, 45.35849288105965, 48.43018725514412, 47.64872118830681, 53.01362290978432, 53.341381922364235, 55.17362840473652, 55.386367589235306, 60.620533525943756, 61.619944497942924, 71.61313086748123, 64.90016028285027, 64.59046170115471, 14.420477952808142, 1.7556484113447368, 49.97106157243252, 79.2818033695221, 55.656932070851326, 61.176265105605125, 35.781254991889, 33.77030409872532, 72.42361977696419, 49.315418154001236, 25.887231901288033, 66.4955122768879, 58.34473304450512, 42.063613682985306, 51.92959427833557, 92.07097470760345, 9.366421401500702, 0.3773584635928273, 0.30255306512117386, 0.46997006284072995, 0.22688125376589596, 0.16923919291002676, 0.3819864965043962], [0.13949002517620102, 0.07731508958386257, 0.12491158791817725, 0.022369917314790655, 0.25353807024657726, 1.4431052072905004, 47.71966338157654, 64.14536878466606, 42.02671006321907, 32.89331495761871, 33.49166125059128, 43.83866183459759, 54.880310744047165, 40.10798782110214, 17.685163021087646, 22.931100726127625, 40.79911753535271, 25.817097164690495, 31.834041997790337, 46.39620199799538, 51.818317249417305, 56.55875287950039, 9.28023062646389, 1.2264091288670897, 8.287188112735748, 18.28241117298603, 25.9995823726058, 51.63944944739342, 65.06525382399559, 55.17248846590519, 55.42479872703552, 49.92582120001316, 52.441305220127106, 54.25299480557442, 52.59740464389324, 46.76648452877998, 46.1804723739624, 46.20135225355625, 45.42294502258301, 43.123403415083885, 48.54262702167034, 51.15134283900261, 52.255035415291786, 52.01530247926712, 56.12804599106312, 51.870746836066246, 54.49838563799858, 53.602549508214, 56.715160086750984, 55.38803189992905, 57.22508892416954, 56.18024379014969, 56.14070311188698, 60.81341877579689, 61.57491311430931, 58.99404600262642, 58.30514296889305, 55.781504586339, 56.65638864040375, 58.07765677571297, 54.57165330648422, 46.70634135603905, 36.79285950958729, 39.03812102973461, 18.078650906682014, 1.778163390699774, 9.898090772330761, 32.46950849890709, 38.46989952027798, 37.964648231863976, 40.446694046258926, 39.68171909451485, 40.553787499666214, 42.815228551626205, 40.554209277033806, 42.46993727982044, 42.16267056763172, 42.16482125222683, 43.50079916417599, 42.080385982990265, 40.89082941412926, 41.43245615065098, 40.32881677150726, 37.90013149380684, 38.21114860475063, 44.7215710580349, 43.14474307000637, 42.91798263788223, 42.383723706007004, 42.34372705221176, 43.120925948023796, 44.036129638552666, 40.85772559046745, 38.0562499165535, 39.645290449261665, 39.744529724121094, 39.027219414711, 42.21776761114597, 41.03140287101269, 38.51107031106949, 38.09515602886677, 37.07050681114197, 39.08406816422939, 42.069096788764, 37.72933065891266, 35.87317205965519, 36.4009827375412, 35.55250346660614, 26.341674216091633, 17.674624286592007, 8.047336433082819, 2.6510757068172097, 14.316203948110342, 9.790275357663631, 7.530203657224774, 7.584980092942715, 7.228185413405299, 8.705517165362835, 15.834757313132286, 27.285572066903114, 25.078827179968357, 29.685065411031246, 27.452350817620754, 33.742440193891525, 40.83591856062412, 46.92371629178524, 53.13292130827904, 55.42218066751957, 54.8847147077322, 50.40206864476204, 56.105011627078056, 55.03843925893307, 51.39493636786938, 47.32482276856899, 46.313818618655205, 44.030752927064896, 41.501886025071144, 40.08718013763428, 36.98194496333599, 35.464002415537834, 34.76533770561218, 36.27041034400463, 37.21185922622681, 38.89079913496971, 40.131117179989815, 42.55923628807068, 45.215825736522675, 44.86511215567589, 49.64478448033333, 54.543872997164726, 56.85680128633976, 53.7553621083498, 55.97691670060158, 9.2247355543077, 3.4880931302905083, 48.00494447350502, 61.097989305853844, 43.30210022628307, 33.4626118093729, 14.308280423283577, 22.96844322234392, 55.67895568907261, 55.49993969500065, 24.24515951424837, 46.21274024248123, 28.572388216853142, 34.84610237181187, 58.16979043185711, 36.32945917546749, 0.08929552015615627, 0.2063192063360475, 0.1069719712540973, 0.01175608582343557, 0.00957805865255068, 0.019727467115444597, 0.020973662940377835, 0.09946255740942433, 0.038621361381956376, 0.023550555524707306, 0.10436381940962747, 0.49511135439388454, 3.4411687357351184, 65.87195813655853, 73.80357652902603, 34.391186982393265, 20.62950722873211, 30.521905906498432, 63.45691032707691, 68.90652850270271, 25.528386756777763, 25.096748918294907, 30.64677480608225, 53.47459517419338, 31.572676822543144, 36.48923300206661, 50.351755544543266, 58.34714211523533, 65.0878094136715, 13.26731963083148, 1.3257220247760415, 10.776879116892815, 30.3492583706975, 43.32392245531082, 63.32067623734474, 71.1229495704174, 59.1540440171957, 61.350067779421806, 57.81444109976292, 59.503948241472244, 60.76860398054123, 56.307643353939056, 51.74239732325077, 50.13892136514187, 52.12491139769554, 48.65443602204323, 49.728262200951576, 55.45842692255974, 58.435540571808815, 57.397436276078224, 58.19874867796898, 61.75648257136345, 59.72426041960716, 60.96390210092068, 59.39177826046944, 61.28165245056152, 59.70039390027523, 63.55913244187832, 60.41463777422905, 57.17284932732582, 59.8483769595623, 61.27677731215954, 58.039031848311424, 58.91612358391285, 54.69032093882561, 59.46949169039726, 60.542181730270386, 58.612128496170044, 51.84543639421463, 43.66104796528816, 42.27298244833946, 28.270593211054802, 11.784527096897364, 13.478384055197239, 32.93045796453953, 37.21187062561512, 42.113341614603996, 38.71864557266235, 39.24437776207924, 44.70412239432335, 44.27131801843643, 43.36839906871319, 44.54418897628784, 46.87910668551922, 44.914536103606224, 46.79407864809036, 46.50037340819836, 43.58829326927662, 43.85610289871693, 42.14504711329937, 42.077950313687325, 43.18098172545433, 45.85014849901199, 47.05661416053772, 45.171808898448944, 44.64652508497238, 45.681543946266174, 45.299656838178635, 45.57735733687878, 42.117149010300636, 40.50337180495262, 42.21055179834366, 43.12629885971546, 41.576654613018036, 43.58899623155594, 44.35782037675381, 42.511864230036736, 39.35331791639328, 39.78171832859516, 39.81255367398262, 44.26644288003445, 39.6188210695982, 36.76259033381939, 39.15589191019535, 38.42119753360748, 28.927009887993336, 18.970005176961422, 9.983418993651867, 5.227955644950271, 22.78007782995701, 11.813226006925106, 11.086102724075317, 11.460356991738081, 10.41094260290265, 13.635691814124584, 24.046055898070335, 35.748922526836395, 30.566492713987827, 36.29287853837013, 40.10163076221943, 45.74163392186165, 48.17683964967728, 51.10652044415474, 53.14735673367977, 57.2721341997385, 58.117984011769295, 54.13765199482441, 61.46695710718632, 59.496892020106316, 56.8629265576601, 51.14998631179333, 50.35570353269577, 50.95304287970066, 50.161427557468414, 46.73372648656368, 43.30531485378742, 42.003132328391075, 43.908657878637314, 45.292938798666, 45.58970287442207, 46.55180364847183, 47.271770015358925, 47.947400361299515, 51.85820370912552, 52.58581146597862, 59.252842515707016, 60.784559324383736, 63.65286201238632, 61.947258934378624, 58.9779082685709, 10.39734598249197, 4.988852050155401, 52.3811012506485, 66.1578319966793, 48.625466376543045, 44.21823486685753, 17.66795564442873, 28.789109587669373, 67.62777552008629, 48.25922302901745, 25.652841478586197, 53.75100754201412, 41.70406177639961, 35.83310700953007, 65.56152999401093, 37.96513460576534, 0.14710253075463697, 0.23768236715113744, 0.09541633859043941, 0.02428967894957168, 0.08940834886743687, 0.14737866906216368, 0.02236270363937365, 0.25823343079537153, 0.11035353745683096, 0.19986400584457442, 0.15604158077621832, 0.5471806135028601, 2.289019259624183, 71.87123581767082, 86.08749657869339, 60.773144736886024, 48.29451933503151, 46.21413096785545, 56.21135652065277, 70.8736601471901, 53.65043833851814, 27.94118508696556, 34.429929703474045, 56.91847197711468, 36.654942110180855, 45.43180614709854, 59.03344228863716, 66.34818658232689, 72.8977507352829, 12.807986978441477, 0.8552923053503036, 12.327752597630024, 34.52891819179058, 55.90397961437702, 66.60972654819489, 70.42334631085396, 61.10479474067688, 62.464832961559296, 59.06519338488579, 59.62409779429436, 57.421720772981644, 56.87211826443672, 55.54729275405407, 53.57308588922024, 53.76775324344635, 51.12158663570881, 49.30948667228222, 56.26460686326027, 57.183245569467545, 57.0940263569355, 56.55080370604992, 60.15627443790436, 58.36123175919056, 61.98654122650623, 60.72803735733032, 64.54367101192474, 60.133908838033676, 64.56962361931801, 61.616129502654076, 60.609521716833115, 63.57182376086712, 65.29817372560501, 61.63157947361469, 63.05748336017132, 57.30647295713425, 64.45974871516228, 66.09073519706726, 64.01268750429153, 52.76832327246666, 43.74872446060181, 49.07083287835121, 31.45367670804262, 13.321119993925095, 19.052116870880127, 35.23002237081528, 40.60749001801014, 43.843951150774956, 42.00817085802555, 38.81951875984669, 45.05453959107399, 45.37478640675545, 44.769737273454666, 46.91507175564766, 48.63540284335613, 47.76045419275761, 51.27142019569874, 48.70667941868305, 46.828972175717354, 48.6576734483242, 46.507456228137016, 44.840337485075, 46.430039182305336, 49.69114199280739, 50.86589455604553, 48.39390680193901, 48.28927181661129, 47.27846145629883, 49.52389396727085, 47.58329249918461, 45.333881601691246, 41.94996938109398, 44.59576740860939, 45.41286416351795, 42.92847387492657, 46.34947210550308, 47.42935135960579, 45.31170979142189, 43.28847795724869, 43.40000197291374, 44.18587580323219, 49.27235506474972, 40.22684924304485, 38.25131244957447, 42.07913585007191, 41.147524639964104, 32.33706280589104, 21.558924056589603, 13.803871739655733, 9.405278116464615, 22.108672857284546, 15.711739864200354, 12.394445668905973, 14.520044960081577, 17.566375695168972, 22.08254735916853, 23.873900435864925, 32.70717814564705, 32.75454260408878, 46.652274057269096, 48.938915356993675, 48.79160866141319, 52.533058896660805, 54.972767382860184, 57.47632384300232, 60.333401933312416, 58.12833085656166, 54.63787615299225, 60.47109514474869, 59.25313889980316, 57.815930619835854, 51.882347613573074, 53.137146681547165, 54.339953139424324, 54.42953713238239, 51.05688750743866, 49.82059344649315, 46.84911109507084, 46.42381511628628, 47.474777922034264, 47.83692508935928, 49.86873686313629, 50.756870806217194, 53.128692135214806, 56.942729875445366, 56.46893709897995, 62.7236370742321, 66.94143354892731, 68.5414668917656, 68.15137982368469, 71.13065555691719, 13.232618942856789, 4.720553671941161, 58.97342070937157, 74.08958718180656, 59.399898424744606, 44.11166958510876, 21.468587704002857, 36.790534034371376, 74.38629046082497, 73.70813325047493, 34.14593294262886, 67.89363965392113, 45.943129509687424, 60.335989594459534, 87.28786736726761, 54.367342069745064, 0.21499676804523915, 0.31500689685344696, 0.1495380070991814, 0.173665480397176, 0.12522554607130587, 0.20589978899806738, 0.15672621200792491], [0.1369630271801725, 0.042408299777889624, 0.042461790071683936, 0.040231821840279736, 0.058844102604780346, 1.1721912631765008, 6.457328852266073, 70.59236884117126, 63.04458685219288, 26.747009865939617, 28.580590076744556, 37.226332649588585, 35.516466200351715, 50.16047760844231, 47.21793830394745, 36.1577919870615, 44.22897309064865, 17.048906162381172, 23.739853128790855, 38.60679477453232, 48.79549205303192, 56.673434525728226, 23.254888951778412, 1.351123780477792, 6.791306706145406, 21.495554856956005, 34.25866149365902, 58.301517963409424, 62.59042762219906, 48.99632267653942, 53.85235570371151, 55.125534385442734, 54.52870801091194, 47.4820127338171, 47.27644756436348, 43.07440884411335, 43.19566793739796, 43.2077930867672, 43.0938334017992, 45.158980786800385, 44.224979504942894, 47.254370748996735, 50.436597391963005, 50.29336407780647, 53.029760643839836, 52.094832211732864, 51.03020153939724, 52.86541186273098, 55.84010124206543, 57.47468613088131, 58.279524743556976, 57.16035179793835, 56.92238196730614, 58.63925904035568, 62.42585085332394, 56.84068635106087, 54.851987063884735, 57.167476415634155, 55.76395332813263, 55.471775606274605, 60.803698897361755, 56.17754973471165, 52.04393774271011, 40.26605933904648, 34.801561161875725, 22.89912924170494, 11.497689988464117, 28.12383558601141, 34.61505576968193, 37.575868293643, 40.06376959383488, 37.66195647418499, 43.87671299278736, 42.42358356714249, 42.51271918416023, 39.83087249100208, 41.24149739742279, 45.20861752331257, 43.00485737621784, 41.852174028754234, 40.95011383295059, 40.13750083744526, 39.2707559466362, 38.50763529539108, 40.11366471648216, 42.63796806335449, 42.849966287612915, 42.057089433074, 41.37624956667423, 44.14459101855755, 41.38905107975006, 42.124429419636726, 42.566600292921066, 41.66991300880909, 39.77007955312729, 41.523753851652145, 41.550310626626015, 41.22065171599388, 40.92443101108074, 39.84787657856941, 38.40392366051674, 38.097907081246376, 38.9128303527832, 42.45810091495514, 37.20149338245392, 35.60883544385433, 32.32036650180817, 29.63869269937277, 25.609122924506664, 15.573429185897112, 6.2912041414529085, 12.040070984512568, 21.0256739705801, 8.911588657647371, 10.679277554154396, 13.347986452281475, 14.06552854925394, 17.31859479099512, 32.912568524479866, 34.61839199066162, 24.037426561117172, 26.327947452664375, 36.651142314076424, 43.6208613216877, 48.41947562992573, 46.610168516635895, 52.99307361245155, 51.323048025369644, 54.222311452031136, 47.971076890826225, 54.90538939833641, 53.03676746785641, 48.92431654036045, 43.519524559378624, 41.132621839642525, 39.70979578793049, 37.99559377133846, 36.382595524191856, 36.249317675828934, 38.18947456777096, 42.90578529238701, 44.59545962512493, 46.32681392133236, 47.26420842111111, 49.31828700006008, 49.684948325157166, 48.96404340863228, 52.31941916048527, 54.564494490623474, 58.45851793885231, 61.6292691975832, 58.428868129849434, 46.02007158100605, 4.7416021674871445, 6.816961979493499, 47.874725461006165, 54.72657859325409, 38.95719297230244, 23.797866515815258, 21.084975488483906, 26.663572043180466, 60.011669397354126, 67.75616303086281, 38.771238550543785, 46.10082484781742, 27.038959600031376, 45.2721881121397, 69.46927070617676, 5.434813220053911, 0.1562708747223951, 0.1582010227139108, 0.04089201785973273, 0.07287746950169094, 0.06504825680167414, 0.12984721135580912, 0.0457634826307185, 0.03891821303113829, 0.09901326120598242, 0.027554683438211214, 0.04408277789480053, 0.07087152596795931, 1.4342836244031787, 13.396229613572359, 80.72669863700867, 59.836521595716476, 24.829921536147594, 27.64928475022316, 32.022154703736305, 51.16921707987785, 37.07779482007027, 39.318181201815605, 45.44659115374088, 51.55954733490944, 26.17857936769724, 27.1881452947855, 45.82462526857853, 53.67265574634075, 67.48996451497078, 30.17275594174862, 0.5821911036036909, 7.338048443198204, 33.33045870065689, 50.025014877319336, 65.6869612634182, 65.96594229340553, 54.984010979533195, 60.125564485788345, 63.74174304306507, 58.30510497093201, 53.33676517009735, 53.30984741449356, 51.74544095993042, 49.463142827153206, 46.98462702333927, 48.053236082196236, 49.00176778435707, 49.248967319726944, 52.30963468551636, 56.635238975286484, 55.35921424627304, 58.01931090652943, 58.03653538227081, 55.87316706776619, 57.236856892704964, 59.52201247215271, 61.14518657326698, 62.00655855238438, 59.0331345051527, 60.28849594295025, 60.304922461509705, 63.39642897248268, 58.38805831968784, 57.359225526452065, 58.92738237977028, 58.64365540444851, 59.08254325389862, 63.415914326906204, 53.58811028301716, 54.444512128829956, 48.004735484719276, 40.46354614198208, 31.946675553917885, 18.32725826650858, 29.53960921615362, 37.822832241654396, 39.13714371621609, 43.007802218198776, 40.54287068545818, 44.42601531744003, 43.802035599946976, 45.76209582388401, 42.03046806156635, 44.59561161696911, 48.07383477687836, 45.117889791727066, 45.72447404265404, 44.97424989938736, 42.98240818083286, 41.82608462870121, 40.86247533559799, 41.730253770947456, 45.76170064508915, 46.270770728588104, 43.62547427415848, 45.53812064230442, 45.82543082535267, 43.29693630337715, 45.251258835196495, 44.2445332556963, 42.799269407987595, 40.9818497300148, 43.90671618282795, 43.28275166451931, 43.21488730609417, 41.92319601774216, 43.199182748794556, 40.90242259204388, 40.553411319851875, 42.717300206422806, 44.952173084020615, 37.516705468297005, 36.25565193593502, 34.99256931245327, 30.106071420013905, 26.77052680402994, 17.34047021716833, 7.512336065992713, 23.151517398655415, 21.212164163589478, 11.04427931830287, 14.578306283801794, 15.734368599951267, 16.70645333826542, 27.895277850329876, 42.55630664527416, 41.44260160624981, 31.157853081822395, 37.74908199906349, 46.3202478736639, 51.23134754598141, 55.0713986903429, 51.95314161479473, 58.29053275287151, 57.03302823007107, 56.52827471494675, 51.915303245186806, 56.9882058352232, 56.21323361992836, 54.22500930726528, 47.66782656311989, 45.75623653829098, 46.21038816869259, 41.614033207297325, 42.814088612794876, 45.208005756139755, 46.244787722826004, 51.884277909994125, 56.146326810121536, 55.29866449534893, 57.24487066268921, 60.29250852763653, 59.997442960739136, 58.06244999170303, 60.74630677700043, 63.560758754611015, 68.5368463397026, 68.46458181738853, 67.14593097567558, 49.754150211811066, 3.075714558362961, 7.278891792520881, 55.23855172097683, 57.49900862574577, 49.04554143548012, 24.491399601101875, 14.979730993509293, 37.08283714950085, 65.62391504645348, 66.99361234903336, 33.2228484749794, 53.280334398150444, 31.307663843035698, 48.32879349589348, 75.13309478759766, 3.585152984596789, 0.07732534606475383, 0.1373403795878403, 0.06758277275366709, 0.061172334899310954, 0.07282493286766112, 0.056046061145025305, 0.03649626603873912, 0.2556261175777763, 0.3109394229250029, 0.1363964716438204, 0.175386416958645, 0.1581152155995369, 1.8048571958206594, 11.090365145355463, 97.75170788168907, 78.65982234477997, 39.80282239615917, 41.5100783854723, 47.71742910146713, 48.628844395279884, 60.38375683128834, 64.1541539132595, 43.55848386883736, 62.663725689053535, 25.5725384876132, 36.87759116292, 53.911168947815895, 62.13788330554962, 74.62421089410782, 28.77205040305853, 1.5584383998066187, 16.278250515460968, 44.941651448607445, 59.155153557658195, 67.66061335802078, 69.2216531932354, 59.89753492176533, 59.825939163565636, 58.621312603354454, 57.340728119015694, 52.48795911669731, 56.50669947266579, 53.6243337392807, 50.57050220668316, 48.35772514343262, 49.93879370391369, 51.92739799618721, 51.311728432774544, 54.54095095396042, 55.99830575287342, 57.08413548767567, 59.31221053004265, 58.90291929244995, 54.57908570766449, 57.83527538180351, 59.69601273536682, 62.6910500228405, 62.135964408516884, 60.28231367468834, 59.885390773415565, 61.94507785141468, 65.5463308095932, 59.187695011496544, 60.05866527557373, 60.586540549993515, 62.91804604232311, 62.43348844349384, 67.51068100333214, 59.064118042588234, 56.90427213907242, 45.89033514261246, 44.849631786346436, 34.357623383402824, 23.377867452800274, 35.91349549591541, 40.5578076839447, 43.53728860616684, 44.90261614322662, 41.449809819459915, 46.421831622719765, 46.105236411094666, 47.6613213121891, 44.64870236814022, 46.15501753985882, 49.82487961649895, 47.320931777358055, 47.751604467630386, 46.65212206542492, 45.36937929689884, 46.015831008553505, 44.04420040547848, 45.551982298493385, 49.8007433116436, 49.95050847530365, 47.81501166522503, 48.07894170284271, 48.84588114917278, 47.16102875769138, 48.59673611819744, 47.97480069100857, 47.48554654419422, 45.05382142961025, 46.982905715703964, 49.152479097247124, 47.44933448731899, 47.316600009799004, 47.87477485835552, 46.98174297809601, 43.323694467544556, 46.52011714875698, 48.6322870105505, 40.40039353072643, 36.742272824048996, 36.72145374119282, 34.22688379883766, 30.37344217300415, 21.46508429199457, 11.872181743383408, 22.894542887806892, 28.177836388349533, 13.2024447619915, 15.658589266240597, 20.13755712658167, 23.531440012156963, 32.26210042834282, 39.8414359241724, 40.49283877015114, 35.39727799594402, 42.024073004722595, 50.90276017785072, 55.46485997736454, 56.055420488119125, 52.634665444493294, 60.51028624176979, 56.55523046851158, 57.357185035943985, 54.094873890280724, 60.31789496541023, 56.5141698718071, 56.9654830545187, 49.55657601356506, 51.29242546856403, 49.91375684738159, 48.46891097724438, 46.727225035429, 50.192513689398766, 48.40497940778732, 56.06503777205944, 58.88153403997421, 58.92034135758877, 60.058342292904854, 64.24575179815292, 58.87763164937496, 60.009541511535645, 61.97157762944698, 65.99972248077393, 70.27015373110771, 76.5481236577034, 72.32148885726929, 61.851405277848244, 5.628936728462577, 7.20894799567759, 60.55416628718376, 67.58365988731384, 56.581456661224365, 31.55787281692028, 30.154883600771427, 40.02997040748596, 78.06231960654259, 80.453782081604, 53.44234250485897, 64.66954305768013, 42.32187442481518, 69.24212649464607, 95.67347019910812, 8.236327841877937, 0.4950204264605418, 0.380901150056161, 0.3136243054177612, 0.16822522622533143, 0.2836106065660715, 0.35732273245230317, 0.13743654708378017], [0.025920511361618992, 0.06273402512306347, 0.09974177562980913, 0.035340660469955765, 0.03701680099766236, 0.10116524455952458, 0.6445108470506966, 25.168584063649178, 69.72637251019478, 50.95156475901604, 34.50131647288799, 42.82291553914547, 49.82463642954826, 58.19134287536144, 135.0488269329071, 46.905541867017746, 45.3945567458868, 27.00911410152912, 11.473281998187304, 36.92619435489178, 46.47055260837078, 64.73660945892334, 45.91294772922993, 1.0618102736771107, 2.45968425180763, 18.974380642175674, 33.70467022061348, 57.017958238720894, 57.24431969225407, 55.71941591799259, 54.810440093278885, 56.75548732280731, 51.63384094834328, 47.970442324876785, 45.467782616615295, 47.54285126924515, 46.392907574772835, 47.582817524671555, 42.73027651011944, 41.53953440487385, 41.988579109311104, 44.29836116731167, 43.110814690589905, 46.26861624419689, 47.93337531387806, 46.99467368423939, 45.358200296759605, 47.886953204870224, 50.05745753645897, 54.490235075354576, 57.40684077143669, 56.0969028621912, 54.78128805756569, 57.574480175971985, 61.547140404582024, 59.15430620312691, 56.70198619365692, 57.00668424367905, 58.45466114580631, 57.26182535290718, 57.38246887922287, 50.95446780323982, 51.49609833955765, 56.98687210679054, 44.779521748423576, 35.45242443680763, 15.690831486135721, 17.78980940580368, 32.346904277801514, 33.18129010498524, 38.257661908864975, 36.11507087945938, 38.82991500198841, 40.586587339639664, 40.19282206892967, 40.9664985537529, 41.707956567406654, 41.842408552765846, 43.049425184726715, 45.64717099070549, 41.60008415579796, 38.84810462594032, 40.30179262161255, 38.697321116924286, 41.25176064670086, 42.69909918308258, 44.195173904299736, 43.752505257725716, 41.67690083384514, 43.07165019214153, 41.55159115791321, 44.528378024697304, 42.76143863797188, 41.23092636466026, 40.85925690829754, 42.13173262774944, 41.071361526846886, 39.38269034028053, 42.32751712203026, 39.14772994816303, 41.04121394455433, 39.410535246133804, 39.27721939980984, 40.67009545862675, 32.551439702510834, 31.976644545793533, 28.467979319393635, 23.23234286159277, 26.61631777882576, 13.289074413478374, 7.593047535046935, 19.83991339802742, 10.895999874919653, 10.605613756924868, 14.070111103355885, 12.947625685483217, 15.767444875091314, 25.954670682549477, 36.191788762807846, 32.14086413383484, 27.451560460031033, 37.00132392346859, 44.424457401037216, 49.15341004729271, 49.471692368388176, 47.74975396692753, 50.43348155915737, 53.2027767598629, 55.39483353495598, 50.981465354561806, 52.67302818596363, 53.09822916984558, 47.64733426272869, 41.286323592066765, 37.96916998922825, 37.769502103328705, 35.89228503406048, 38.474630266427994, 38.514026552438736, 47.27835886180401, 48.04073855280876, 53.02070572972298, 53.00873637199402, 52.36589066684246, 54.06148888170719, 54.5839836448431, 58.05909477174282, 60.27922824025154, 60.87254360318184, 65.46338126063347, 62.66856662929058, 68.95023375749588, 30.184909589588642, 0.20267318323021755, 8.765922524034977, 46.836374178528786, 51.42362482845783, 30.95786601305008, 29.30518079549074, 25.579742901027203, 30.620092637836933, 65.39704442024231, 63.9339405298233, 35.401480570435524, 49.09588113427162, 43.43500569462776, 58.05473640561104, 41.1341417580843, 0.08181245997548103, 0.15838219580473378, 0.19385841325856745, 0.03396559812244959, 0.05105794560222421, 0.10177084448514506, 0.060266636428423226, 0.06633857701672241, 0.1095552092010621, 0.031407474452862516, 0.11444466363172978, 0.04909289440547582, 0.09207230279571377, 0.12510984524851665, 0.9543267474509776, 38.39378580451012, 78.95742237567902, 46.09373442828655, 30.623183771967888, 42.371283173561096, 39.8384340852499, 58.99612829089165, 119.70379874110222, 54.534335508942604, 40.43051831424236, 28.32523237913847, 16.809336617588997, 43.64751689136028, 53.87598283588886, 71.08516439795494, 57.16539412736893, 3.136787018738687, 1.280654186848551, 33.16915735602379, 44.60554048418999, 63.2520367205143, 62.93400518596172, 63.03273528814316, 62.32511065900326, 63.847426772117615, 56.00721247494221, 53.975328505039215, 52.30472154915333, 52.30377919971943, 53.01168881356716, 55.949311181902885, 48.925296887755394, 47.42371246218681, 47.574001997709274, 48.62846061587334, 48.21160778403282, 51.84023827314377, 52.66918659210205, 49.452833980321884, 49.82781305909157, 52.74402737617493, 54.0161307156086, 58.554899767041206, 59.73765470087528, 59.91625651717186, 58.47009211778641, 59.52790975570679, 61.264933347702026, 61.775508150458336, 57.25109852850437, 58.11600051820278, 60.02552345395088, 60.344333946704865, 60.534745529294014, 54.55360047519207, 53.38023483753204, 56.10665313899517, 50.97787454724312, 42.017358765006065, 23.093410916626453, 23.637853302061558, 36.91376902163029, 36.357760056853294, 40.03325343132019, 37.420654222369194, 39.66797523200512, 42.60441966354847, 42.98833206295967, 43.72731260955334, 45.21256171166897, 46.735170409083366, 46.0050205886364, 48.31343851983547, 45.714944154024124, 40.75656361877918, 42.51684196293354, 41.7621074616909, 42.315680757164955, 46.26173861324787, 46.96471229195595, 46.35229915380478, 47.79530972242355, 44.99818481504917, 44.03209425508976, 46.132420152425766, 44.53195743262768, 42.26349055767059, 42.174978107213974, 43.44113476574421, 42.186829671263695, 41.35747477412224, 45.32652139663696, 42.10007652640343, 43.09693023562431, 43.47399540245533, 42.19796687364578, 42.202686220407486, 36.60539276897907, 33.57853978872299, 29.34392921626568, 29.30950876325369, 28.92462931573391, 14.321814347058535, 13.702593874186277, 24.320197887718678, 15.098240934312344, 25.811739452183247, 26.96497566998005, 25.36916770040989, 28.343725986778736, 35.65740063786507, 41.13346539437771, 38.74838277697563, 38.54882128536701, 44.13797937333584, 50.494187101721764, 54.89211291074753, 54.71857622265816, 51.5374743193388, 53.17361332476139, 56.08166567981243, 58.7756223231554, 55.71998588740826, 56.284354403615, 57.29766882956028, 52.0055978000164, 46.585549637675285, 43.24983023107052, 43.185100704431534, 41.58808059990406, 45.168123096227646, 47.03441575169563, 53.73857080936432, 55.19615359604359, 57.87251718342304, 59.091123193502426, 59.36425253748894, 61.12674616277218, 60.55588759481907, 63.237183317542076, 66.07454046607018, 67.0529879629612, 66.1764357984066, 67.85698682069778, 73.26044127345085, 25.65446399152279, 0.15956278948578984, 11.844277940690517, 54.20297048985958, 57.98053398728371, 39.27117392420769, 30.859420895576477, 25.886059664189816, 31.046120077371597, 69.445119202137, 69.88459601998329, 32.70705655217171, 51.511890292167664, 43.615834191441536, 67.00270906090736, 39.12007883191109, 0.0640880958235357, 0.1276483020046726, 0.21578411251539364, 0.0991427140252199, 0.08015986779355444, 0.03720386674103793, 0.04847406940825749, 0.04243424526066519, 0.140953391965013, 0.1243532108492218, 0.2796871092868969, 0.15374127920949832, 0.4002126638079062, 0.2655201929155737, 1.7212716559879482, 37.44821034371853, 93.10742229223251, 72.11181610822678, 46.720111817121506, 55.88784568011761, 65.59011965990067, 66.8196576833725, 138.31946343183517, 51.16208106279373, 57.210395112633705, 38.03396411240101, 19.487415812909603, 54.15418490767479, 58.172522485256195, 79.54625397920609, 57.725567668676376, 2.0964881032705307, 8.329590987414122, 49.84058417379856, 52.452324628829956, 70.31762838363647, 61.19910567998886, 65.06816446781158, 60.91447815299034, 66.38434544205666, 57.627380937337875, 58.622710928320885, 56.93767614662647, 56.23098246753216, 53.2250701636076, 59.076277390122414, 49.3247352540493, 49.670490100979805, 48.8237739354372, 51.286528185009956, 48.242781311273575, 52.71182410418987, 52.05091416835785, 50.614739432930946, 51.38613983988762, 53.47339443862438, 54.766981825232506, 59.36840571463108, 61.738805919885635, 61.418703496456146, 60.149875581264496, 63.07927519083023, 63.75734120607376, 64.83237951993942, 62.06939198076725, 63.03101398050785, 63.4085351228714, 64.54703763127327, 61.99309967458248, 55.83671182394028, 54.123311564326286, 62.98359252512455, 52.16164402663708, 43.199912309646606, 28.272534906864166, 30.151477083563805, 41.92305542528629, 42.00053706765175, 43.581902012228966, 38.66606779396534, 40.3326203674078, 46.41420163214207, 44.94826689362526, 46.70403487980366, 49.70257177948952, 48.46251592040062, 49.211178347468376, 51.984843313694, 48.69762070477009, 44.817747697234154, 44.86681826412678, 45.75979694724083, 47.207215279340744, 50.59596844017506, 50.12118771672249, 48.98264721035957, 49.767620489001274, 48.044317960739136, 47.10180513560772, 49.424844682216644, 47.26937234401703, 47.170995622873306, 45.56549057364464, 49.087677374482155, 45.212747901678085, 45.01521170139313, 49.56370063126087, 46.76020726561546, 47.92476497590542, 47.07748644053936, 44.1604969650507, 44.586457908153534, 36.31067298352718, 35.5727943778038, 34.438084065914154, 30.852102488279343, 30.47817785292864, 21.170883178710938, 16.955463476479053, 27.558974996209145, 19.24544859677553, 24.283269569277763, 29.953070729970932, 28.80236327648163, 31.916698962450027, 39.49054375290871, 44.62018869817257, 44.592434987425804, 41.3415764272213, 49.176250621676445, 54.89732623100281, 55.71442298591137, 57.89534255862236, 54.17323708534241, 55.19907183945179, 57.06206627190113, 62.26094730198383, 57.991268411278725, 60.18994443118572, 60.36113664507866, 54.70810018479824, 50.71046009659767, 46.35334029793739, 48.04873712360859, 45.13140186667442, 50.07152818143368, 48.5660869628191, 56.47593632340431, 58.64580608904362, 61.00307419896126, 63.58191221952438, 62.69815184175968, 63.920496851205826, 65.5394683778286, 67.76385381817818, 70.22800639271736, 69.77986603975296, 72.70895406603813, 70.00403881072998, 77.10727125406265, 39.662731513381004, 0.3647239040583372, 12.774041499942541, 59.15573492646217, 67.9104271531105, 43.4178002178669, 41.32815174758434, 34.65371489524841, 42.09189556539059, 86.86161383986473, 78.65261793136597, 49.793337509036064, 70.03407999873161, 67.63741940259933, 85.16334056854248, 58.12115304172039, 0.17956735042389482, 0.32093033369164914, 0.28753000719007105, 0.2307198938797228, 0.09827590038185008, 0.38473434280604124, 0.1957130996743217, 0.14384992013219744], [0.037113146609044634, 0.020736344522447325, 0.02874698635423556, 0.01452761312975781, 0.09073685258044861, 0.08153681148542091, 0.08443303537205793, 1.2929528206586838, 43.77982199192047, 68.41030552983284, 54.89048279821873, 32.11035177111626, 58.324362337589264, 43.774414882063866, 30.29305748641491, 25.60589499771595, 44.56346534192562, 51.10332101583481, 13.54632155969739, 30.282581448554993, 47.181281670928, 57.62842208147049, 60.636705458164215, 11.506752502173185, 0.40192248299717903, 16.30633480846882, 32.023389637470245, 47.255476489663124, 56.09986290335655, 56.87246024608612, 52.8347285091877, 52.12792083621025, 47.595064267516136, 47.574389576911926, 45.348757803440094, 47.0902119576931, 49.036836102604866, 51.13695681095123, 50.48928536474705, 46.31499655544758, 44.12061430513859, 41.233928203582764, 40.909171029925346, 42.29715675115585, 42.64837570488453, 43.74525524675846, 46.13367788493633, 50.11025570333004, 53.296483531594276, 54.09184165298939, 57.23934955894947, 57.78694957494736, 58.58078397810459, 59.02942590415478, 59.85344208776951, 54.937695264816284, 54.563012570142746, 58.57794553041458, 56.4428249001503, 58.87198895215988, 56.03798322379589, 49.516761749982834, 58.74933533370495, 54.91243042051792, 54.665656462311745, 50.17777428030968, 32.26483628153801, 20.407867021858692, 27.16108124703169, 29.99329537153244, 31.186904422938824, 31.822610311210155, 35.0537346303463, 37.6777446269989, 38.58239248394966, 38.43051463365555, 41.23633727431297, 43.84857550263405, 40.88310442864895, 41.731469705700874, 39.302849024534225, 38.37848402559757, 39.07633177936077, 38.87619651854038, 37.97550044953823, 43.5493453592062, 44.96368266642094, 44.012118726968765, 44.35885772109032, 42.86925785243511, 41.33284829556942, 43.660732582211494, 41.617369428277016, 40.06195709109306, 41.67042218148708, 41.911188662052155, 40.71821607649326, 38.747520223259926, 39.42658558487892, 38.88691954314709, 39.23416011035442, 40.63402779400349, 41.66776232421398, 35.570069923996925, 35.00053368508816, 28.75590316951275, 21.216571927070618, 29.690586514770985, 26.126018688082695, 12.684434708207846, 11.064794417470694, 16.829291246831417, 23.794452399015427, 42.66848802566528, 35.30530773103237, 25.659494921565056, 28.2481250166893, 34.02530461549759, 37.39504739642143, 34.638135731220245, 42.02839337289333, 42.94783003628254, 45.872077122330666, 47.757684141397476, 49.79445084929466, 46.50532454252243, 53.47884714603424, 51.72612279653549, 52.87183351814747, 46.901080906391144, 49.99796412885189, 49.68927629292011, 47.38610588014126, 38.62366206943989, 39.767237305641174, 39.216377064585686, 37.53508888185024, 40.411595329642296, 48.02176617085934, 50.1031880825758, 55.09087644517422, 52.1113271266222, 53.03285367786884, 55.00761531293392, 59.51976679265499, 57.4263983219862, 60.37173807621002, 60.15848591923714, 64.84440207481384, 63.599106296896935, 76.07516303658485, 55.45263223350048, 2.5860659452155232, 0.22027388331480324, 15.814720038324594, 54.40013810992241, 47.33430325984955, 24.99764073640108, 37.62403450906277, 62.16411329805851, 57.903424724936485, 66.87027096748352, 64.36610653996468, 44.22893509268761, 37.68123283982277, 37.9364575445652, 76.39610901474953, 7.591924220323563, 0.319505202351138, 0.11344851591275074, 0.14094037469476461, 0.01740048533974914, 0.13981579832034186, 0.01700613403954776, 0.035234165989095345, 0.05469003117468674, 0.06267155113164335, 0.028019497949571814, 0.08626701586763375, 0.0208792116609402, 0.07535360811743885, 0.05317048009601422, 0.11886859108926728, 1.7576506664045155, 55.22800728678703, 76.52936786413193, 55.051153376698494, 28.755143210291862, 63.62604685127735, 52.205740660429, 39.69166316092014, 18.94257254898548, 45.57537004351616, 50.62488488852978, 19.623490311205387, 36.389283165335655, 53.17916862666607, 63.8183431327343, 68.6985732614994, 15.176900513470173, 0.4292825289303437, 32.00485423207283, 45.90462997555733, 55.66953219473362, 61.29613347351551, 63.2982574403286, 58.542721420526505, 58.83801497519016, 56.4123847335577, 55.87095558643341, 54.677234441041946, 55.023464262485504, 52.76606239378452, 56.66156776249409, 55.56803584098816, 53.49186524748802, 48.222475200891495, 45.91381788253784, 46.08596384525299, 48.078899905085564, 47.166458666324615, 48.57082910835743, 50.00918112695217, 53.67813505232334, 56.12996108829975, 58.130204156041145, 59.65241767466068, 59.344364404678345, 61.821709871292114, 61.93316929042339, 61.89311183989048, 60.68066529929638, 59.54535461962223, 59.06094901263714, 58.7546094506979, 62.357617914676666, 58.11945453286171, 51.60370096564293, 59.422157630324364, 57.46674835681915, 56.67498864233494, 55.24724945425987, 41.00461430847645, 27.27688193321228, 31.311801820993423, 34.63945426046848, 33.70970495045185, 33.97855192422867, 35.28236076235771, 37.71758168935776, 41.007243767380714, 42.422151044011116, 43.55646997690201, 44.64149035513401, 44.849536791443825, 43.89819324016571, 42.620416805148125, 42.074640691280365, 41.81392528116703, 41.58532194793224, 40.41808918118477, 45.15244513750076, 46.29843324422836, 46.16588495671749, 44.79811795055866, 44.39218573272228, 42.40537114441395, 45.09685792028904, 44.67061959207058, 42.26877607405186, 43.31435836851597, 44.93052564561367, 43.20463925600052, 42.091010212898254, 42.03441224992275, 42.8617874532938, 42.649804428219795, 41.734505742788315, 44.145548567175865, 37.69804693758488, 36.388975381851196, 26.914086900651455, 27.533702552318573, 34.094400107860565, 26.71328667551279, 22.959528900682926, 18.628167919814587, 27.590283416211605, 35.99410817027092, 52.29969061911106, 47.697065994143486, 42.19186820089817, 41.726092994213104, 46.473170667886734, 47.667138800024986, 45.49001522362232, 49.72189374268055, 48.60074110329151, 50.169840306043625, 51.98745757341385, 53.29641133546829, 51.565547212958336, 57.73558013141155, 53.49477969110012, 56.70257896184921, 51.334496811032295, 56.85408063232899, 53.040495067834854, 51.33711487054825, 45.538158640265465, 44.04972530901432, 43.544728606939316, 43.48971135914326, 47.091245502233505, 56.0451952368021, 56.39826849102974, 62.15293049812317, 58.08967553079128, 58.633730337023735, 60.27705855667591, 65.20724460482597, 63.727793991565704, 67.24504485726357, 65.68039521574974, 73.04454445838928, 70.9433788061142, 81.4387196302414, 43.75179849565029, 0.8811758633237332, 0.16505008097738028, 21.201880015432835, 61.49847261607647, 55.320311933755875, 31.54580656439066, 36.97671264410019, 60.323598459362984, 45.27136355638504, 71.51318863034248, 75.86218446493149, 44.94179964065552, 34.76827874779701, 46.008182018995285, 77.823426425457, 4.517518216744065, 0.20752305892528966, 0.12111722433473915, 0.05616720562102273, 0.036699113552458584, 0.087536934443051, 0.01131344946770696, 0.023313398523896467, 0.040450629239785485, 0.1398182919365354, 0.0922174149309285, 0.12290267579373904, 0.1262113408301957, 0.11934925787500106, 0.13057714328169823, 0.2954220649553463, 1.971300970762968, 63.42769369482994, 86.17152526974678, 79.6495172381401, 38.82174924015999, 73.31350162625313, 52.98790588974953, 41.824743300676346, 30.837309882044792, 60.78159548342228, 70.20043507218361, 20.353562235832214, 43.267723470926285, 60.93972399830818, 69.36751216650009, 76.17320537567139, 12.862683143466711, 1.1814725026488304, 48.53888802230358, 54.98410977423191, 59.962302446365356, 64.65749770402908, 65.52053779363632, 61.44443951547146, 61.873212307691574, 58.34577418863773, 59.53557774424553, 55.417776703834534, 57.64182776212692, 56.0519702732563, 60.649157389998436, 59.40131954848766, 53.087308555841446, 51.54051035642624, 48.436871096491814, 48.164995685219765, 51.624938026070595, 50.475237518548965, 49.911435171961784, 50.624394714832306, 55.316933915019035, 59.83215942978859, 60.494486689567566, 60.04856541752815, 60.853624418377876, 62.511730045080185, 62.99460433423519, 65.24709686636925, 59.37741883099079, 59.281200394034386, 62.98326574265957, 61.387583166360855, 65.6722940504551, 59.83324237167835, 54.24824886023998, 60.09947508573532, 59.54046048223972, 58.68625491857529, 58.396094888448715, 41.51335380971432, 34.854435324668884, 38.28962579369545, 38.11527594923973, 37.9379128664732, 38.06938961148262, 36.97998046875, 39.54098604619503, 43.78522150218487, 46.00483059883118, 48.05485099554062, 50.75858451426029, 47.47653342783451, 48.44409070909023, 45.92210903763771, 43.720176592469215, 44.72532905638218, 44.23865117132664, 42.99191527068615, 50.63626907765865, 49.98031407594681, 50.44547751545906, 50.90307176113129, 48.81422504782677, 46.45557381212711, 49.98221397399902, 50.38200192153454, 45.94066344201565, 48.43256212770939, 48.80545511841774, 46.56796798110008, 44.06367436051369, 45.61102353036404, 44.437053725123405, 45.86356557905674, 45.896335020661354, 47.909516394138336, 37.97909885644913, 37.90549300611019, 34.7147586196661, 30.208791308104992, 36.22241131961346, 32.20517188310623, 24.602973014116287, 20.351584441959858, 28.07346548885107, 33.19267049431801, 56.01947821676731, 51.40618376433849, 48.88431988656521, 45.67438133060932, 50.46133026480675, 49.82019066810608, 46.60164177417755, 51.68890759348869, 54.317272156476974, 52.79112204909325, 55.43090879917145, 55.815691351890564, 52.72724747657776, 59.024938344955444, 55.59650011360645, 57.17443764209747, 51.73990845680237, 59.20431911945343, 58.322226852178574, 54.412080869078636, 48.07557128369808, 48.75738389790058, 47.215293645858765, 45.612136870622635, 50.769725516438484, 58.0054834485054, 59.99155707657337, 67.19510793685913, 61.17276929318905, 62.13690295815468, 66.23970240354538, 68.88819828629494, 66.28555834293365, 68.10560747981071, 67.98206090927124, 73.49112689495087, 71.14729106426239, 81.20575413107872, 64.01685208082199, 4.261928256601095, 0.37152070028241724, 21.32352288812399, 67.1083053946495, 62.56441801786423, 38.445998802781105, 49.253044500947, 75.0803916156292, 79.82681572437286, 86.17460310459137, 75.91946259140968, 60.33719412982464, 53.305006474256516, 59.60335470736027, 101.76519691944122, 11.292297709733248, 0.6682580290362239, 0.31822069315239787, 0.1271763109252788, 0.17320148966973647, 0.16966879251413047, 0.13783439761027694, 0.16367213538615033, 0.13827446149662137], [0.018899694150604773, 0.027014899023924954, 0.015424251832882874, 0.04320651671150699, 0.0835639433353208, 0.0819402355409693, 0.051048416426056065, 0.263166842632927, 2.6699989289045334, 46.868205070495605, 63.34358900785446, 44.212041199207306, 28.80136203020811, 43.304159715771675, 42.70740553736687, 133.7433385848999, 71.36603772640228, 60.56458532810211, 19.95267614722252, 23.420240879058838, 45.613801181316376, 58.702939823269844, 61.2053981423378, 18.65953903645277, 0.09309199886047281, 15.502296052873135, 40.545530542731285, 42.363311201334, 52.21451058983803, 53.01676154136658, 50.442566871643066, 49.32449206709862, 47.5824261456728, 45.65948233008385, 46.80487386882305, 47.477479577064514, 50.855160132050514, 50.82386501133442, 53.37670862674713, 53.28241288661957, 47.52266675233841, 40.583748891949654, 41.75982378423214, 41.931555569171906, 42.22455404698849, 43.23982536792755, 43.83131682872772, 49.13987897336483, 52.70283378660679, 55.34733988344669, 54.85471911728382, 54.876906126737595, 56.078333258628845, 58.14909674227238, 57.260867804288864, 56.491880267858505, 56.48833505809307, 56.55124448239803, 56.96021653711796, 55.86611084640026, 51.61727383732796, 53.90308678150177, 57.64336667954922, 58.822394013404846, 57.90321193635464, 56.79218575358391, 49.6860046684742, 29.338028132915497, 23.221450746059418, 27.80690599232912, 27.914453521370888, 24.31231901049614, 30.358877554535866, 34.77952614426613, 38.442825973033905, 37.46487244963646, 39.74304400384426, 38.411534652113914, 39.87309582531452, 38.02563115954399, 41.37838505208492, 39.19753387570381, 38.91730271279812, 38.033481538295746, 40.281919687986374, 40.7170495390892, 41.6339897364378, 38.36606249213219, 40.65388172864914, 40.276064202189445, 42.244738563895226, 41.27582095563412, 42.27188430726528, 42.8278286755085, 41.995046362280846, 43.404318541288376, 43.6640802025795, 42.449847757816315, 40.77487863600254, 41.43147960305214, 38.16457450389862, 39.908452928066254, 41.06022052466869, 38.49776342511177, 29.432479664683342, 15.077937673777342, 27.722307331860065, 33.33217240869999, 26.26996636390686, 32.2025728225708, 23.11642438173294, 41.95086233317852, 47.76477076113224, 46.38503059744835, 43.92818123102188, 39.066722095012665, 42.23361276090145, 42.70884566009045, 44.069442451000214, 42.521124333143234, 43.7891960889101, 45.615070313215256, 48.233528807759285, 47.84470707178116, 47.97451190650463, 46.43747918307781, 53.38659569621086, 52.1330201625824, 53.76503258943558, 48.057978227734566, 48.63114707171917, 50.08265778422356, 47.83259332180023, 41.03940524160862, 38.40778045356274, 39.55768994987011, 38.519315868616104, 47.96658933162689, 52.78652809560299, 51.871088817715645, 53.55672016739845, 55.15527918934822, 53.062226101756096, 54.66850630939007, 54.00443874299526, 58.39150853455067, 62.24704384803772, 63.74276898801327, 68.209098726511, 67.6080621778965, 51.233505830168724, 7.072946168482304, 0.418301711906679, 0.5515411170199513, 25.922047533094883, 60.480568036437035, 40.82318164408207, 28.011948689818382, 38.079348877072334, 26.563903391361237, 43.27919125556946, 70.90193063020706, 52.07562044262886, 39.07528683543205, 44.28177885711193, 52.69599035382271, 43.18633183836937, 0.03832528898783494, 0.07718870183452964, 0.20743937435327098, 0.07730307421297766, 0.06140402598248329, 0.05225939363299403, 0.04972433591319714, 0.04354797143605538, 0.02823265574988909, 0.013922111538704485, 0.033009325998136774, 0.04535867446975317, 0.07964366697706282, 0.011839166472782381, 0.08089648647001013, 0.04070626571774483, 0.3147047833772376, 4.167580269277096, 61.88709296286106, 69.57992836833, 42.26042792201042, 38.460498824715614, 56.82909317314625, 34.35899131000042, 101.44406095147133, 73.18713560700417, 61.764120161533356, 22.463712505996227, 28.241378478705883, 52.10847727954388, 65.88524222373962, 65.24500697851181, 23.294524624943733, 0.23439555836375803, 17.29051999747753, 54.18919622898102, 50.68961441516876, 58.215501978993416, 58.9340016245842, 59.504077434539795, 56.14322617650032, 53.81308101117611, 54.80314068496227, 52.319004982709885, 53.41995030641556, 55.7580978423357, 56.48220978677273, 58.11191573739052, 57.68041089177132, 55.03235958516598, 46.97717182338238, 47.375607043504715, 44.86237250268459, 47.721719071269035, 46.32522560656071, 46.28438159823418, 52.85961717367172, 55.61288483440876, 56.78637966513634, 58.068180084228516, 59.51922342181206, 59.0536268055439, 60.8418982475996, 60.53558148443699, 59.574746042490005, 60.61240196228027, 61.53580941259861, 60.75749337673187, 57.94268041849136, 55.07736437022686, 55.794382095336914, 60.08674576878548, 59.289423152804375, 61.300305649638176, 57.43070729076862, 55.28414927423, 37.62831307947636, 28.563783578574657, 30.73690976947546, 33.50014239549637, 28.789136186242104, 31.49607103317976, 34.52483721077442, 40.20037606358528, 39.78283166885376, 42.76264697313309, 43.57828080654144, 44.66769374907017, 43.10487940907478, 42.938376143574715, 42.61728957295418, 40.568580105900764, 42.08364620804787, 42.537725642323494, 43.438148126006126, 42.00920060276985, 39.64284338057041, 42.42818892002106, 42.261674255132675, 43.271424472332, 43.23393568396568, 44.91287939250469, 43.2757980376482, 44.3193094432354, 44.13068376481533, 43.947168812155724, 42.71606147289276, 42.51185283064842, 41.96884676814079, 41.68521098792553, 43.77035669982433, 41.82231903076172, 38.268107548356056, 25.820306092500687, 19.839807003736496, 35.5344582349062, 30.914894118905067, 33.90444830060005, 38.12046267092228, 36.63581393659115, 51.752117201685905, 51.18763089179993, 50.21504648029804, 45.493001863360405, 44.62961979210377, 48.50161962211132, 47.14019447565079, 48.58213350176811, 47.557032108306885, 49.61090549826622, 49.75706085562706, 52.54764251410961, 49.67726893723011, 51.14383064210415, 50.06542570888996, 56.555944830179214, 55.993293821811676, 57.14829884469509, 52.677473947405815, 52.16398850083351, 54.89460177719593, 53.42229478061199, 47.193923592567444, 43.07545758783817, 44.37008611857891, 46.44888237118721, 55.416834354400635, 56.41331948339939, 58.583291843533516, 58.914843052625656, 60.45206196606159, 57.153652757406235, 59.5308355987072, 55.99955968558788, 60.6741676479578, 63.68068411946297, 66.19622513651848, 67.91181027889252, 61.207453832030296, 39.49605345726013, 7.22532844170928, 0.6719871726818383, 1.1174960481002927, 32.13698834180832, 68.20181831717491, 46.006825491786, 32.716331854462624, 39.21137273311615, 34.44142788648605, 48.104677721858025, 75.04648223519325, 60.75478792190552, 36.08456611633301, 43.02013635635376, 60.34120291471481, 34.793106615543365, 0.1544551065308042, 0.09907703395583667, 0.2022462702007033, 0.08441450394457206, 0.09721436203108169, 0.05461851782456506, 0.0364612144039711, 0.031174770338111557, 0.026782528875628486, 0.11746943491743878, 0.1488083423464559, 0.10686323177651502, 0.11999378344626166, 0.11623896891251206, 0.17646544030867517, 0.15149923623539507, 0.4387094668345526, 5.533328158780932, 77.07693368196487, 79.5036506652832, 64.10152673721313, 39.10555601119995, 56.09396941959858, 51.94772690534592, 134.64378386735916, 86.85449302196503, 74.91753235459328, 27.715463899075985, 33.02777834236622, 59.582763612270355, 70.46957463026047, 73.2182103395462, 25.244302600622177, 0.2179253421491012, 26.782961636781693, 65.62662810087204, 57.25449934601784, 64.32263687252998, 62.1984938532114, 61.14519037306309, 60.33666215837002, 58.74049320816994, 59.28248472511768, 55.61456814408302, 56.43869452178478, 58.33961471915245, 59.31161776185036, 60.79913154244423, 60.724336355924606, 54.49219197034836, 48.17119315266609, 50.76041981577873, 47.251395508646965, 49.04437869787216, 47.965673580765724, 48.76139648258686, 53.62111911177635, 56.235052049160004, 57.63107433915138, 59.61889587342739, 62.143545001745224, 62.87364162504673, 63.17892104387283, 62.731555849313736, 63.04088585078716, 61.10207028687, 62.52566009759903, 63.794328421354294, 59.22725848853588, 57.40055590867996, 55.2900655567646, 60.76644949615002, 62.779429480433464, 65.19898384809494, 60.78215405344963, 56.69286668300629, 40.42805224657059, 34.108352959156036, 34.57640424370766, 35.4660315066576, 33.57606992125511, 36.37424357235432, 36.093997210264206, 43.150621354579926, 42.77921788394451, 45.114587768912315, 45.70832870900631, 48.41912604868412, 46.22914016246796, 47.64870598912239, 47.61583395302296, 46.025417894124985, 45.74239768087864, 45.346641317009926, 46.95082403719425, 48.18592116236687, 42.682767659425735, 45.02203993499279, 45.175547897815704, 48.007186353206635, 45.673997551202774, 48.38445670902729, 48.59176978468895, 45.90576991438866, 48.70385617017746, 47.623429745435715, 47.53206364810467, 46.92753128707409, 45.91394327580929, 43.063685819506645, 46.01349413394928, 42.75422662496567, 40.57630509138107, 35.14791637659073, 25.23653581738472, 35.3254808485508, 36.30120009183884, 35.11362321674824, 40.444737151265144, 36.49898707866669, 53.04906740784645, 55.031808614730835, 54.278297647833824, 51.743377670645714, 47.920038029551506, 51.417666748166084, 48.56432005763054, 50.35888396203518, 50.34927427768707, 52.59572893381119, 52.989353612065315, 56.363397762179375, 52.67578303813934, 54.3333300948143, 51.61051020026207, 57.84202381968498, 58.46234433352947, 59.56053860485554, 54.65165041387081, 54.72518786787987, 56.63707047700882, 57.161362543702126, 50.62702037394047, 47.12411753833294, 49.5169023424387, 50.045396983623505, 58.35276961326599, 60.96899762749672, 61.92838914692402, 62.23384715616703, 63.67200918495655, 60.687900111079216, 62.06522740423679, 58.95500689744949, 64.62640777230263, 70.21575585007668, 69.59744542837143, 71.8806517124176, 72.31589555740356, 55.78918777406216, 11.024798713624477, 0.7613728637807071, 0.837076201569289, 33.35453800857067, 73.18234026432037, 54.57607626914978, 40.85671864449978, 47.73254469037056, 39.19549338519573, 62.64828711748123, 85.79169005155563, 65.50858363509178, 55.42712800204754, 63.067351430654526, 72.3773230612278, 63.42567220330238, 0.1438900109496899, 0.14377453277120367, 0.3145920659881085, 0.15013613359769806, 0.3340487735113129, 0.0760434492258355, 0.09283078514272347, 0.1978062529815361, 0.09901352095766924], [0.010903616039286135, 0.05108487071993295, 0.026955844477924984, 0.07038196083158255, 0.09253738448023796, 0.06393894640496, 0.09978656424209476, 0.056755135010462254, 0.5881471058819443, 4.54127311706543, 62.99039036035538, 56.33893847465515, 36.748831272125244, 43.5051841288805, 129.07411873340607, 110.76425403356552, 64.2570447921753, 63.70847962796688, 28.464967980980873, 21.492843702435493, 39.47000965476036, 58.7177362293005, 59.10683535039425, 30.781357884407043, 0.9506030066404492, 6.273465743288398, 45.107117369771004, 43.89184758067131, 51.986287236213684, 49.80082310736179, 55.20266264677048, 50.94799295067787, 49.02265906333923, 46.7144463211298, 47.8853914886713, 48.21351148188114, 52.13593080639839, 52.87174612283707, 52.210049629211426, 50.37028335034847, 53.42097245156765, 48.45985226333141, 41.51217207312584, 40.97735837101936, 44.02000330388546, 41.216057762503624, 44.54386219382286, 49.29101586341858, 54.72990341484547, 60.48720248043537, 57.71242417395115, 55.76734274625778, 58.34307253360748, 57.999525368213654, 57.93544940650463, 54.640763998031616, 56.50355324149132, 55.383038967847824, 54.62822467088699, 53.747055754065514, 51.838254779577255, 57.8149426728487, 56.12706944346428, 53.92328269779682, 52.26538985967636, 56.75807498395443, 54.929445907473564, 42.3209472745657, 31.736465133726597, 27.0323346555233, 31.165834553539753, 24.35777597129345, 22.735622115433216, 33.45739088952541, 33.629050478339195, 34.15122605860233, 37.33917899429798, 39.28249731659889, 39.18543912470341, 36.4677869528532, 37.8742890805006, 37.14334890246391, 36.4445436000824, 35.68234249949455, 36.13289572298527, 35.12132540345192, 34.24461744725704, 33.997919484972954, 35.59624671936035, 40.6942355632782, 43.77440348267555, 41.81135281920433, 45.037607699632645, 44.19781096279621, 45.90149134397507, 44.677835404872894, 45.115796104073524, 41.41385614871979, 41.923006027936935, 41.05521619319916, 39.57578457891941, 39.12619650363922, 37.12682358920574, 28.34697101265192, 13.402221892029047, 19.1549089550972, 35.28357669711113, 28.714018017053604, 37.368201836943626, 38.53520281612873, 45.897125378251076, 49.36145268380642, 47.61559076607227, 47.258102148771286, 45.571661442518234, 43.096622452139854, 46.29244476556778, 44.98000659048557, 44.793094620108604, 45.51336497068405, 47.69615784287453, 46.9228233397007, 46.89955718815327, 46.42865985631943, 48.389529436826706, 51.48789457976818, 52.179324477910995, 50.06402738392353, 50.77354811131954, 42.95027710497379, 47.68169581890106, 50.463777333498, 50.816983580589294, 43.32156278192997, 38.642927035689354, 40.16846537590027, 46.981826573610306, 54.178036227822304, 52.35079027712345, 55.823366940021515, 54.21568840742111, 59.54450726509094, 58.344619050621986, 60.32590493559837, 55.700416937470436, 57.12544307112694, 55.97252793610096, 58.130230754613876, 51.47178344428539, 31.908457204699516, 19.041034765541553, 6.357473060488701, 0.7219958142377436, 2.8843755880370736, 36.273792162537575, 57.815991416573524, 36.64574280381203, 39.260443300008774, 56.666427701711655, 18.389835208654404, 19.159708097577095, 66.36336296796799, 49.692099541425705, 48.436152935028076, 48.49510297179222, 62.73939482867718, 5.22453535348177, 0.3212086687562987, 0.03516132419463247, 0.11507067261845805, 0.1104539871448651, 0.11753984988899902, 0.024398210625804495, 0.10128755791811273, 0.0661805366689805, 0.06852062477264553, 0.06395584510755725, 0.07373545900918543, 0.08814943634206429, 0.06446148516261019, 0.11195273953489959, 0.023284026174223982, 0.09865281492238864, 0.05186261179915164, 0.4234170983545482, 5.063711833208799, 75.34568578004837, 64.43660035729408, 27.40785140544176, 46.88913434743881, 109.80123370885849, 99.11498352885246, 69.93394017219543, 67.98936411738396, 31.08025174587965, 26.22820470482111, 43.029419258236885, 61.64688505232334, 64.77142319083214, 37.94710837304592, 1.3023904454894364, 9.211771599948406, 53.811610490083694, 52.2787993401289, 59.96573366224766, 54.61479239165783, 59.653834998607635, 57.67142057418823, 58.36454518139362, 53.2327913492918, 53.83517682552338, 52.34032183885574, 58.80938731133938, 56.897177919745445, 57.8082512319088, 56.85748524963856, 57.17974215745926, 53.758409544825554, 45.58518871665001, 45.865207090973854, 46.78147852420807, 45.4820242524147, 47.90745310485363, 52.28751987218857, 57.895502150058746, 62.76298776268959, 58.192262426018715, 56.24818794429302, 60.91604366898537, 60.2655565738678, 60.32197594642639, 60.24741634726524, 59.15657468140125, 57.41294324398041, 58.640881553292274, 55.200869143009186, 55.44546201825142, 58.30683767795563, 59.76112604141235, 57.45785303413868, 55.906871259212494, 57.70404942333698, 56.597396805882454, 49.597480818629265, 38.34366649389267, 33.07477042078972, 34.565821811556816, 32.264490500092506, 28.61965198069811, 35.0136885792017, 34.06851589679718, 35.023222267627716, 41.937506049871445, 42.83306859433651, 43.42081345617771, 41.854567900300026, 41.71256572008133, 40.94412915408611, 41.024643033742905, 39.847998172044754, 38.51126790046692, 37.447640374302864, 37.676049917936325, 36.58932343125343, 37.10016421973705, 41.209446117281914, 46.013627126812935, 44.272666946053505, 46.511012837290764, 45.44217199087143, 44.866875261068344, 46.06902435421944, 46.15976348519325, 43.076840713620186, 43.700600042939186, 43.640255481004715, 41.27271272242069, 41.50076888501644, 36.12291745841503, 26.505764611065388, 15.540863033384085, 25.479580275714397, 35.102858394384384, 34.20005343854427, 38.608318492770195, 41.573728770017624, 50.808931812644005, 50.03197990357876, 50.64646013081074, 50.58715671300888, 50.03233328461647, 49.315820932388306, 51.63046292960644, 50.27128726243973, 52.26784072816372, 50.98947912454605, 52.6826036721468, 51.763117611408234, 51.70768238604069, 50.30936881899834, 54.545681700110435, 54.349190443754196, 56.17352955043316, 53.62850971519947, 53.237176313996315, 47.39251233637333, 51.69284798204899, 55.66338412463665, 56.74297459423542, 48.33251729607582, 43.392124995589256, 45.20141310989857, 51.956626027822495, 58.007869720458984, 58.62264633178711, 59.07732613384724, 59.40455697476864, 63.701005429029465, 62.832904011011124, 65.76438590884209, 63.96845027804375, 61.8742610514164, 59.88213434815407, 60.2341702580452, 55.92708617448807, 38.13566945493221, 26.797189973294735, 11.165114734321833, 1.3502451963722706, 3.7589095858857036, 42.24525913596153, 60.758070945739746, 42.58099012076855, 42.99918808043003, 66.1588579416275, 30.046900995075703, 30.601196251809597, 72.92338415980339, 57.35976129770279, 47.17259533703327, 54.011525362730026, 59.24842715263367, 0.9974126354791224, 0.13727315585128963, 0.02653858122357633, 0.052144052751827985, 0.07280634948983788, 0.033768424327718094, 0.022604593686992303, 0.055910671144374646, 0.09344003643491305, 0.0284213505074149, 0.10382625216152519, 0.1617271889699623, 0.1799526289687492, 0.10319573833839968, 0.2610687317792326, 0.19359882484422997, 0.17695010727038607, 0.16121323686093092, 0.4061793233267963, 8.225407227873802, 93.05970445275307, 71.34533643722534, 55.96830636262894, 53.29777926206589, 132.38001734018326, 112.91841924190521, 75.08276268839836, 80.13597473502159, 39.98030327260494, 29.276119954884052, 53.07006508111954, 68.73264983296394, 68.86400878429413, 39.349514320492744, 0.7753151468932629, 11.148959901183844, 63.540745228528976, 56.54226936399937, 64.88095611333847, 58.32829512655735, 65.22260338068008, 60.6916581094265, 61.534502282738686, 56.36249341070652, 58.72139163315296, 55.88593818247318, 61.39061540365219, 59.05005119740963, 60.67550137639046, 58.47683675587177, 61.301513984799385, 56.74309618771076, 48.207348212599754, 48.923290595412254, 49.423693343997, 47.56498508155346, 50.152372643351555, 54.20245751738548, 60.3574850410223, 67.36159220337868, 58.753397315740585, 56.1515287309885, 64.21017810702324, 62.572648376226425, 63.66171933710575, 60.515339970588684, 62.813927829265594, 58.77668246626854, 61.39047861099243, 54.58538956940174, 56.54845543205738, 60.997344106435776, 60.380709394812584, 58.65581475198269, 56.05551168322563, 60.80870322883129, 58.24268952012062, 51.484493762254715, 43.29467922449112, 36.78411237895489, 38.14880535006523, 35.60582220554352, 30.056147798895836, 38.29145349562168, 36.108162850141525, 36.16664931178093, 43.290507048368454, 46.11284360289574, 47.66995444893837, 45.37128299474716, 46.11037753522396, 44.861893728375435, 44.04817119240761, 43.42736430466175, 42.622594088315964, 41.94209240376949, 41.27264812588692, 39.53589431941509, 41.72349773347378, 45.584447756409645, 48.93161594867706, 48.176391273736954, 50.873528346419334, 50.28869792819023, 49.57134962081909, 49.434484764933586, 48.48609745502472, 47.27532662451267, 48.91795188188553, 47.162753865122795, 45.09009808301926, 43.76686088740826, 39.99549865722656, 34.81117844581604, 22.262199819087982, 27.682878747582436, 39.44902338087559, 34.858345314860344, 41.030722707509995, 46.718823686242104, 51.6594173759222, 54.72122088074684, 52.432326301932335, 53.47945511341095, 53.54069642722607, 52.15985432267189, 55.68928733468056, 54.1367020457983, 54.84191380441189, 53.09748820960522, 54.22770716249943, 55.02642050385475, 54.58651430904865, 54.363082498312, 55.49272008240223, 57.48751424252987, 60.139559134840965, 56.10695332288742, 55.11095076799393, 50.37370316684246, 55.61237186193466, 58.99602189660072, 61.99346825480461, 50.33287815749645, 47.285798862576485, 49.23067510128021, 55.727205500006676, 62.70219102501869, 63.562757447361946, 62.72353067994118, 62.95761711895466, 68.02509739995003, 66.85102880001068, 67.68227219581604, 62.31054984033108, 60.61231076717377, 60.238361433148384, 60.57690806686878, 56.59500293433666, 40.750092566013336, 25.165375135838985, 10.041750613600016, 1.279110163450241, 3.6768159409984946, 42.873513624072075, 67.06571727991104, 49.52141270041466, 49.05345641076565, 73.50181192159653, 29.933530278503895, 27.59008202701807, 82.74500593543053, 58.31505283713341, 73.93356755375862, 62.53876939415932, 87.89756745100021, 8.898840341717005, 0.5048345576506108, 0.14114767138380557, 0.2295304834842682, 0.24205090070609003, 0.24191145115764812, 0.11151208935189061, 0.16029451740905643, 0.18298458424396813, 0.14530671149259433], [0.04051620911923237, 0.03958122921176255, 0.005218097367105656, 0.06327427152427845, 0.04628783593943808, 0.10936790597043, 0.158331818820443, 0.08580579335102811, 0.061193601140985265, 0.3463681280845776, 9.122004266828299, 59.149503260850906, 55.99397398531437, 35.555113926529884, 91.98674842715263, 91.09064251184464, 76.91123977303505, 59.04696196317673, 40.32551854848862, 20.96188109368086, 35.829683393239975, 58.10423254966736, 61.046916246414185, 34.704008996486664, 2.6037779822945595, 11.03287898004055, 32.64315918087959, 40.99044866859913, 49.65902231633663, 49.08697821199894, 54.584793001413345, 52.656396478414536, 55.02647750079632, 50.72975546121597, 47.47138850390911, 47.107254043221474, 51.20899334549904, 50.302225202322006, 54.024326875805855, 53.06699484586716, 51.8011611700058, 52.00366750359535, 48.3487044274807, 41.45530052483082, 41.96874037384987, 41.590083092451096, 44.00157809257507, 47.824321165680885, 51.44003614783287, 51.29413537681103, 56.9794587045908, 55.2313207089901, 53.39968219399452, 57.22454555332661, 56.36643759906292, 57.16941811144352, 56.27951726317406, 54.76001299917698, 54.666496217250824, 52.17680141329765, 55.702921003103256, 56.474386006593704, 56.40319302678108, 54.81001831591129, 53.82103778421879, 52.09468021988869, 59.48232740163803, 54.490379467606544, 40.8101749420166, 28.21611363440752, 31.828026920557022, 33.175620809197426, 27.10639078170061, 31.598118357360363, 32.0068035274744, 33.23115102946758, 37.52413026988506, 34.72036711871624, 39.26700934767723, 35.35529024899006, 37.022671177983284, 39.41792584955692, 38.16446430981159, 33.786635622382164, 35.24606131017208, 34.57143031060696, 34.68882501125336, 35.034557059407234, 38.8791261613369, 38.6379949003458, 44.2574867606163, 42.561660557985306, 45.76029472053051, 45.01036696135998, 42.85121262073517, 43.557898700237274, 46.39923043549061, 43.128145560622215, 42.91112020611763, 42.594794780015945, 37.35019840300083, 34.418173134326935, 26.46734107285738, 16.81229665875435, 12.055178973823786, 29.973390139639378, 34.88938964903355, 34.969394356012344, 37.324124202132225, 44.10763420164585, 50.78583665192127, 51.76997624337673, 49.03759986162186, 44.14466701447964, 43.70401605963707, 46.172268614172935, 47.53500089049339, 48.97352769970894, 49.76297713816166, 47.8419142216444, 48.67755778133869, 48.873950242996216, 49.58984322845936, 48.85840527713299, 48.30794021487236, 50.67317649722099, 50.73671668767929, 49.433489218354225, 50.45407645404339, 48.61678384244442, 48.12684193253517, 52.69578896462917, 49.738130271434784, 43.86886641383171, 39.83908765017986, 40.52587039768696, 50.1332900673151, 55.19688315689564, 55.2561067789793, 54.984584748744965, 54.552361741662025, 56.00835241377354, 57.66908749938011, 59.823666885495186, 62.64547906816006, 64.4748567044735, 63.21437694132328, 61.126031801104546, 55.34574396908283, 42.212212309241295, 34.906701520085335, 19.544521048665047, 4.604297960177064, 5.7182105630636215, 39.28097739815712, 56.670740470290184, 40.03616787493229, 59.14232164621353, 22.74297472089529, 9.859471544623375, 30.84339715540409, 57.857538387179375, 59.47274811565876, 41.08970694243908, 65.92299699783325, 24.703977294266224, 0.2983502531424165, 0.05017032213800121, 0.0744765973649919, 0.12580692971823737, 0.04693684408266563, 0.04301851586205885, 0.06012925376126077, 0.08830025559291244, 0.05203986635024194, 0.09376263318699785, 0.03869260384817608, 0.050643771537579596, 0.051285551162436604, 0.00923265477467794, 0.021497439229278825, 0.06950945491553284, 0.04675430915085599, 0.05504431392182596, 0.16926300100749359, 0.3115328145213425, 8.918001763522625, 68.85301977396011, 54.870552867650986, 28.319502286612988, 95.31332552433014, 94.53495249152184, 85.77959910035133, 62.11887672543526, 48.96454118192196, 26.229384541511536, 43.25962230563164, 62.3733376711607, 68.15651714801788, 36.97188690304756, 4.693353306502104, 16.954220943152905, 38.572824597358704, 49.93017956614494, 58.39097276329994, 58.491526767611504, 60.59781074523926, 59.95689533650875, 60.001121163368225, 57.8231730312109, 54.06851090490818, 49.827193692326546, 54.86397922039032, 55.62335327267647, 57.897276654839516, 55.767764523625374, 58.700067177414894, 57.404940873384476, 52.05906093120575, 45.84118478000164, 47.172975316643715, 43.03540013730526, 46.80061049759388, 51.768425926566124, 55.68347364664078, 55.958924666047096, 57.37239561975002, 56.667791828513145, 54.36688989400864, 57.84586541354656, 58.644312769174576, 61.17220692336559, 58.89207847416401, 58.82275499403477, 55.55806137621403, 57.89656609296799, 56.92865163087845, 60.33239118754864, 59.65492554008961, 57.98006661236286, 56.0626856982708, 54.01938334107399, 56.449862122535706, 55.700663924217224, 43.78219686448574, 32.73208200931549, 34.6720527112484, 34.42148655653, 32.20527447760105, 32.80758395791054, 33.87463890016079, 36.84676721692085, 38.69401529431343, 36.95284232497215, 39.96276721358299, 40.93336433172226, 40.53261123597622, 42.76657596230507, 41.47889345884323, 38.95848490297794, 40.40393874049187, 37.997448071837425, 39.195975959300995, 40.69310322403908, 40.824678763747215, 40.74666514992714, 44.32204529643059, 43.993655517697334, 45.41402690112591, 45.8003331720829, 44.13660004734993, 44.868539571762085, 44.740813225507736, 43.84623862802982, 43.78390297293663, 43.682668805122375, 38.6024934053421, 36.25965692102909, 30.622813291847706, 18.887726292014122, 19.72337555140257, 34.29211489856243, 36.597052216529846, 37.776755914092064, 39.81504254043102, 50.68342074751854, 54.17249232530594, 52.255745977163315, 49.17924106121063, 46.51786006987095, 47.27047808468342, 48.334793373942375, 51.748815178871155, 51.937250867486, 52.190651670098305, 50.79420380294323, 51.448950469493866, 51.3591992855072, 53.249335661530495, 50.85294485092163, 52.94224753975868, 51.32870212197304, 54.40035469830036, 52.56991691887379, 53.25907073915005, 52.36797295510769, 52.593281865119934, 58.38994301855564, 53.08733515441418, 47.2054597735405, 44.172508120536804, 47.07403242588043, 56.356417536735535, 59.81412559747696, 59.92719992995262, 57.18626640737057, 59.31224472820759, 60.974670723080635, 62.46330924332142, 62.19141103327274, 66.67318314313889, 65.42257145047188, 67.19451516866684, 64.35412958264351, 61.46289512515068, 56.65350079536438, 47.295309752225876, 27.403196655213833, 7.654268899932504, 7.162859318777919, 43.610472679138184, 62.014009952545166, 46.323002725839615, 63.412965685129166, 33.8326283544302, 18.155097104609013, 40.26314489543438, 66.23024091124535, 65.51917746663094, 43.58520783483982, 72.84180253744125, 18.184321336448193, 0.3457817423623055, 0.06746482322341762, 0.05418514811026398, 0.06199168448802084, 0.08991884998977184, 0.07465530652552843, 0.03265245686634444, 0.05038910727307666, 0.09118769987253472, 0.05814501433633268, 0.1074046952999197, 0.17382913880283013, 0.13148824829841033, 0.21771062398329377, 0.17054718366125599, 0.189732413564343, 0.26773968944326043, 0.1649380908929743, 0.26611524692270905, 0.4088696383405477, 14.900812078267336, 89.40873876214027, 69.30923089385033, 53.69124814867973, 97.3179991543293, 95.08419781923294, 83.59793096780777, 73.77685636281967, 55.33175311982632, 31.859888210892677, 47.78623200953007, 71.75284177064896, 70.22516414523125, 44.74170997738838, 5.110803656280041, 18.122855834662914, 50.90963400900364, 59.1836292296648, 65.80884352326393, 62.09733188152313, 63.25415700674057, 63.22307087481022, 64.20270770788193, 60.14364771544933, 55.236119851469994, 52.899116054177284, 60.60528114438057, 59.27796296775341, 61.20629869401455, 59.64220382273197, 59.36219684779644, 60.54818540811539, 54.2639534175396, 46.29182539880276, 49.31291788816452, 47.125907242298126, 50.76478198170662, 53.44226270914078, 58.756896927952766, 58.60194884240627, 62.189321145415306, 61.182910948991776, 56.97353482246399, 62.328074499964714, 58.04421477019787, 63.7677526473999, 60.82299806177616, 63.33328776061535, 55.88997736573219, 57.180543914437294, 59.44446623325348, 62.23459951579571, 61.360973194241524, 59.98745709657669, 57.10686966776848, 56.41862399876118, 61.44761614501476, 57.000448778271675, 46.902901008725166, 37.72436052560806, 38.34478743374348, 40.45112460851669, 33.7790360301733, 37.705581933259964, 34.97106246650219, 38.07950846850872, 40.588544234633446, 38.81197616457939, 44.252053052186966, 44.29462596774101, 47.4415373057127, 49.28294889628887, 47.76268847286701, 42.60715551674366, 42.77591586112976, 40.53793855011463, 41.559897512197495, 43.35926055908203, 43.99072587490082, 44.52696830034256, 49.05241906642914, 46.27091892063618, 50.89117459952831, 50.92476859688759, 45.45342318713665, 46.595497503876686, 51.91400371491909, 49.530517011880875, 47.759002670645714, 47.3152244836092, 40.824310183525085, 39.90388937294483, 34.28716756403446, 22.40444328635931, 20.96208058297634, 36.638280004262924, 40.07590614259243, 39.33903828263283, 43.158707320690155, 52.104487493634224, 55.36384999752045, 55.12199677526951, 52.61138029396534, 51.13244265317917, 48.72407488524914, 50.89525558054447, 54.51228529214859, 54.26044620573521, 54.722904190421104, 53.34904991090298, 54.138788133859634, 55.86574986577034, 55.6034841388464, 53.57357606291771, 54.87546220421791, 55.81864379346371, 56.85794122517109, 54.04291547834873, 56.393180564045906, 54.66910667717457, 55.367201417684555, 60.29255412518978, 56.739729568362236, 51.30002126097679, 48.65543156862259, 49.59620028734207, 59.141827672719955, 64.3910863995552, 63.25696125626564, 63.66803079843521, 62.36027017235756, 62.390725538134575, 66.05367958545685, 66.62883952260017, 69.79498162865639, 71.10068276524544, 70.55302575230598, 66.73554539680481, 63.59874911606312, 55.97026705741882, 46.35636493563652, 25.239849239587784, 6.053671762347221, 7.8062312956899405, 45.95209702849388, 66.62160471081734, 54.49159920215607, 71.38132810592651, 29.69280369579792, 13.987333495169878, 46.72393821179867, 70.37897989153862, 73.64235118031502, 59.526526629924774, 86.29795208573341, 32.5169413536787, 0.44311990204732865, 0.17865471658296883, 0.13647896877955645, 0.2841656736563891, 0.35052513470873237, 0.20083326555322856, 0.23614018427906558, 0.3000651783077046, 0.1902047757175751, 0.13750721438555047], [0.036247234675101936, 0.0441023928578943, 0.05053420456533786, 0.09828151101828553, 0.018978649386554025, 0.04212890715280082, 0.06505562632810324, 0.0785549363354221, 0.08812582862447016, 0.06785221688915044, 0.1062977894616779, 9.508490078151226, 62.25309692323208, 43.70242774486542, 52.41404168307781, 101.45957931876183, 84.93321731686592, 54.45641689002514, 39.942943677306175, 23.44037789851427, 31.924986317753792, 51.052080765366554, 64.2853532731533, 29.86033670604229, 10.685770455747843, 19.715158492326736, 24.75487746298313, 45.418852642178535, 48.854449689388275, 53.23499523103237, 55.085883513092995, 57.79850475490093, 55.28084345161915, 57.67745465040207, 51.92346140742302, 45.86126670241356, 47.57904812693596, 49.95710872113705, 53.60228352248669, 51.70033738017082, 51.35692700743675, 52.10664577782154, 47.84684635698795, 46.96948483586311, 44.06786933541298, 43.14044550061226, 41.805672124028206, 44.21728491783142, 50.832247361540794, 52.30909891426563, 50.662803053855896, 50.1906593888998, 49.20730635523796, 50.98927393555641, 51.30355127155781, 54.629341810941696, 54.74211595952511, 57.55987375974655, 53.35745505988598, 56.04263037443161, 56.490318551659584, 55.07957965135574, 57.27748051285744, 53.37118372321129, 52.191077247262, 51.88486687839031, 52.20713898539543, 57.44475893676281, 49.07379291951656, 34.82175327837467, 30.5997846275568, 30.93617107719183, 30.630635172128677, 27.950293198227882, 32.59056240320206, 32.43200071156025, 32.40853317081928, 36.066315695643425, 34.80304688215256, 35.10535106062889, 34.13256525993347, 33.186940401792526, 32.91381485760212, 32.90970727801323, 31.935732141137123, 30.876369886100292, 36.43361158668995, 38.990498185157776, 39.42490227520466, 42.472760528326035, 47.21440829336643, 45.00099666416645, 43.493507355451584, 44.86127816140652, 46.89771808683872, 44.64737243950367, 41.7226617783308, 42.71487973630428, 39.58240382373333, 37.49193839728832, 34.001316502690315, 27.005642987787724, 22.43491195142269, 18.889485597610474, 26.552494503557682, 35.69713890552521, 33.76657649874687, 36.667872816324234, 41.60130389034748, 49.34925153851509, 51.58842958509922, 46.432687640190125, 44.457633420825005, 45.477369502186775, 43.59398536384106, 45.63761070370674, 49.11097012460232, 49.46763038635254, 46.964624896645546, 48.99276606738567, 50.16742743551731, 48.812370747327805, 49.81245428323746, 49.86083708703518, 49.95216138660908, 50.59569105505943, 51.11891157925129, 50.234961211681366, 48.699007630348206, 45.200725346803665, 50.03142133355141, 51.97056367993355, 50.972323045134544, 42.250320464372635, 40.985121354460716, 43.069868087768555, 54.33229275047779, 54.293519631028175, 57.28174768388271, 55.80964207649231, 56.200416907668114, 56.993434354662895, 61.00430153310299, 60.00445358455181, 60.32783143222332, 59.54675294458866, 60.82789219915867, 57.62510485947132, 59.18122015893459, 59.437611401081085, 53.048881217837334, 35.0059711933136, 14.193182699382305, 8.483570124953985, 43.57000105082989, 54.41609725356102, 41.68423444032669, 47.82711781561375, 18.292558528482914, 19.447270967066288, 36.13473102450371, 61.51930309832096, 52.118166759610176, 34.07546952366829, 64.76563230156898, 5.91895236633718, 0.22084584168624133, 0.028155793370387983, 0.07878897260525264, 0.06266081225476228, 0.052655206964118406, 0.06854596169432625, 0.07035301707219332, 0.044053407400497235, 0.014740919359610416, 0.13663194025866687, 0.0985663992469199, 0.020007279053970706, 0.046876603955752216, 0.027881295209226664, 0.048835755078471266, 0.03094902385782916, 0.018899710848927498, 0.08090146628092043, 0.04260799687472172, 0.04491566425713245, 0.1060099400638137, 8.508021812886, 69.51177522540092, 41.179572120308876, 56.819597482681274, 106.65225148200989, 89.61366936564445, 65.29424473643303, 47.33374089002609, 32.100267112255096, 35.734654292464256, 56.72802619636059, 67.57411479949951, 34.08068284392357, 16.850133128464222, 27.666687816381454, 37.685936987400055, 55.85313834249973, 56.69405221939087, 58.62352408468723, 62.43766061961651, 63.02890129387379, 61.59869223833084, 62.53072142601013, 57.97304078936577, 52.897478342056274, 48.85753892362118, 53.316960632801056, 54.20906536281109, 55.98800450563431, 55.235409289598465, 56.00457541644573, 51.58857397735119, 50.32103419303894, 46.25032402575016, 47.84261718392372, 45.261609479784966, 49.23540584743023, 52.96185828745365, 57.07816980779171, 55.19586481153965, 53.78424435853958, 52.894503101706505, 53.70737448334694, 52.26437151432037, 57.347674146294594, 54.4039911031723, 61.3615545630455, 55.47654815018177, 59.55006256699562, 55.901160165667534, 59.03219595551491, 57.6819384098053, 57.152676209807396, 53.47036600112915, 53.84998083114624, 53.555006459355354, 58.89937788248062, 52.51493386924267, 40.65909504890442, 33.72195169329643, 33.9644280821085, 35.99459834396839, 31.668969355523586, 33.84859509766102, 34.97800089418888, 36.517602279782295, 41.331248581409454, 36.949061527848244, 39.60730008780956, 37.93023727834225, 40.883693397045135, 37.80244253575802, 38.198920860886574, 31.80780630558729, 29.396474696695805, 38.46458740532398, 40.10081000626087, 41.417686343193054, 46.20587021112442, 49.46494773030281, 47.18089409172535, 46.92786566913128, 47.13645547628403, 46.260385885834694, 43.86347450315952, 43.039743304252625, 42.80870050191879, 40.21258480846882, 38.206752240657806, 35.25564819574356, 27.538704983890057, 22.433785311877728, 23.263425193727016, 32.926570773124695, 38.552450090646744, 36.09115116298199, 39.691389575600624, 43.60719345510006, 51.741774156689644, 52.81462378799915, 47.33922779560089, 47.08896182477474, 46.25785902142525, 47.14877441525459, 52.19502903521061, 50.11704973876476, 53.661586940288544, 50.9836046397686, 51.73173889517784, 51.10512971878052, 53.502139896154404, 52.17420995235443, 52.20439173281193, 52.32917323708534, 53.71816210448742, 55.44458046555519, 52.394123151898384, 50.4233855009079, 48.71378883719444, 55.50328731536865, 55.80631345510483, 55.17984867095947, 45.29028654098511, 44.35353800654411, 47.484512999653816, 59.33042295277119, 57.56078191101551, 61.09664037823677, 59.15396422147751, 58.241021409630775, 60.103499069809914, 63.96329015493393, 63.5700948536396, 65.20789057016373, 65.72620555758476, 65.35377234220505, 62.245444133877754, 65.7221169769764, 64.49668273329735, 59.0158112347126, 40.49217000603676, 17.819647304713726, 10.895400457084179, 45.73295518755913, 59.68020938336849, 48.46726946532726, 55.26445493102074, 24.695701338350773, 24.353296011686325, 40.60910873115063, 68.6288546025753, 57.12663620710373, 35.1234532892704, 71.25287219882011, 5.565921384841204, 0.21767835540231317, 0.11389437597244978, 0.11751990095945075, 0.010922631718131015, 0.07001217833021656, 0.02477945188729791, 0.019652484224934597, 0.0388479205139447, 0.011325476898491615, 0.09276950600906275, 0.18322827585507184, 0.1361745546455495, 0.2906818193150684, 0.16755460674175993, 0.2011689092614688, 0.2215598916518502, 0.2025469290674664, 0.1604252541437745, 0.1775380811886862, 0.15356543473899364, 0.4405671515269205, 19.62117813527584, 88.19450631737709, 60.609685108065605, 66.79199516773224, 103.70834425091743, 89.76259857416153, 69.09400284290314, 52.87724822759628, 33.72900411486626, 43.36115285754204, 63.6825118213892, 75.04698380827904, 37.178679406642914, 16.815870366990566, 28.819485157728195, 42.70908884704113, 66.94863796234131, 61.499703750014305, 63.260069489479065, 66.50038361549377, 68.50833266973495, 65.39079755544662, 64.77839201688766, 59.97291527688503, 54.34897765517235, 53.46059672534466, 58.12748730182648, 58.90712566673756, 57.71067626774311, 58.808718547225, 59.28090400993824, 56.52837350964546, 55.20850673317909, 49.873456209897995, 50.203540697693825, 49.38585877418518, 51.92311942577362, 57.09515869617462, 56.505042761564255, 55.472372174263, 54.72872547805309, 55.45990124344826, 58.031436055898666, 55.22056728601456, 57.57415719330311, 56.86201460659504, 62.95610100030899, 57.47779056429863, 61.121897622942924, 58.21350708603859, 59.42586623132229, 60.69741100072861, 60.32707907259464, 57.851466313004494, 57.86719746887684, 56.12087197601795, 63.917487412691116, 54.76259306073189, 44.094422310590744, 38.41628819704056, 38.25669676065445, 39.12040561437607, 35.33876493573189, 38.65750305354595, 36.421687826514244, 37.315316274762154, 41.91876545548439, 40.09762577712536, 41.77286848425865, 42.451075091958046, 44.03879329562187, 42.71359920501709, 41.645571514964104, 40.19643187522888, 41.2287262827158, 41.70634165406227, 41.454285979270935, 44.871085435152054, 46.688581109046936, 52.49125733971596, 50.79638488590717, 51.592069789767265, 50.083299949765205, 52.245163545012474, 47.730344608426094, 46.83699734508991, 44.4025781750679, 44.532436206936836, 40.15895828604698, 41.50676876306534, 29.936127439141273, 26.28378052264452, 24.50168564915657, 33.84052433073521, 40.045838356018066, 36.23497724533081, 42.1028807759285, 46.27104051411152, 54.87206518650055, 54.99646671116352, 50.20194858312607, 49.336066246032715, 49.964138343930244, 49.420927092432976, 53.03771361708641, 53.603567853569984, 57.52579718828201, 52.50258833169937, 55.77192150056362, 54.446362629532814, 55.84612771868706, 54.95246887207031, 56.48908741772175, 54.8812834918499, 54.892409294843674, 58.85274298489094, 55.20269304513931, 52.42259502410889, 49.598989337682724, 56.462982818484306, 59.34189833700657, 59.55318599939346, 47.49474585056305, 46.83732032775879, 49.819525703787804, 61.806605681777, 61.39911934733391, 65.3483310341835, 63.070790246129036, 63.218161538243294, 64.34999540448189, 68.36759582161903, 67.37691298127174, 67.28764057159424, 67.9053658246994, 67.44218587875366, 66.39360174536705, 71.19279742240906, 70.89840441942215, 62.22755469381809, 42.32248239219189, 18.287664391100407, 11.258678063750267, 50.394613444805145, 63.426633551716805, 54.263858422636986, 58.052760511636734, 24.8010278865695, 26.278698295354843, 54.253036603331566, 75.6183135509491, 68.46151918172836, 49.131557419896126, 84.31310579180717, 8.864254597574472, 0.3558390901889652, 0.25085431581828743, 0.3051579440943897, 0.1817753436625935, 0.1719086684170179, 0.3129153762711212, 0.14054207887966186, 0.12347279363893904, 0.15659142314689234, 0.18029152328381315], [0.021996448194840923, 0.04394613737531472, 0.08082070577074774, 0.10693772113882005, 0.053461435381905176, 0.08913698999094777, 0.04509050311753526, 0.06423010578146204, 0.09396939552971162, 0.04602354601956904, 0.14184414729243144, 0.09908104155329056, 23.19616310298443, 55.401509776711464, 36.24632343649864, 74.16196569800377, 102.83531829714775, 57.931243032217026, 40.11228159070015, 32.47195176780224, 30.203167609870434, 52.87762060761452, 62.1854567527771, 41.40668973326683, 21.90991122275591, 33.23633015155792, 46.5156713873148, 53.28306645154953, 52.42256082594395, 56.72693185508251, 56.23550042510033, 59.40279766917229, 59.481499046087265, 56.13110102713108, 56.580932289361954, 51.78894862532616, 46.56842015683651, 46.65950886905193, 49.76930379867554, 53.49019713699818, 47.11209878325462, 46.956785917282104, 46.785909086465836, 43.048266246914864, 42.019767835736275, 40.566007643938065, 37.366913706064224, 43.00798840820789, 47.596075013279915, 53.00471618771553, 55.55488854646683, 49.5374820381403, 47.56974622607231, 48.32256942987442, 50.02974942326546, 55.96996687352657, 53.04389588534832, 55.65430261194706, 55.809543281793594, 56.31735563278198, 56.835967004299164, 58.00069950520992, 58.46156157553196, 55.905165150761604, 51.58085659146309, 46.07380449771881, 48.26161690056324, 56.61880485713482, 54.641432762145996, 45.132800191640854, 32.01802812516689, 29.78400830179453, 34.03274841606617, 30.976471714675426, 27.813840620219707, 33.342048078775406, 38.461992144584656, 41.12271197140217, 34.172930493950844, 32.66017846763134, 33.1292898952961, 32.551793083548546, 33.72790217399597, 33.18618804216385, 15.013377238065004, 18.471234440803528, 38.958899080753326, 39.63551737368107, 41.66336216032505, 47.201591581106186, 47.24869005382061, 47.13709384202957, 44.074982553720474, 41.92368619143963, 45.87232030928135, 39.89822007715702, 37.40342974662781, 36.46807573735714, 37.50561386346817, 34.234509989619255, 24.75845117121935, 21.37106593698263, 18.30323975533247, 28.247492350637913, 37.18151405453682, 35.84696106612682, 34.78805288672447, 36.13984934985638, 42.8855399787426, 48.36395300924778, 47.71867163479328, 43.87420512735844, 43.32158178091049, 44.842659160494804, 49.4526781886816, 48.55681166052818, 46.86131604015827, 48.86584147810936, 48.82546864449978, 48.93675707280636, 49.12871137261391, 49.75037321448326, 52.050515189766884, 52.24487856030464, 49.790198877453804, 49.833805337548256, 51.677272617816925, 51.92837834358215, 49.10447247326374, 48.43739926815033, 51.16999223828316, 53.466786593198776, 49.003572687506676, 40.26518538594246, 43.09573709964752, 46.83826267719269, 56.2829864770174, 54.48120296001434, 58.092806562781334, 56.931254491209984, 55.34158319234848, 54.77187976241112, 55.837969556450844, 59.5013377815485, 63.34024138748646, 60.64510300755501, 62.25516781210899, 57.72986903786659, 59.014306515455246, 57.648621797561646, 58.557384833693504, 42.069100588560104, 21.631122082471848, 11.411792747676373, 46.290579065680504, 50.66586568951607, 46.96978881955147, 29.86901544034481, 21.64782978594303, 34.23278868198395, 33.26727569103241, 60.704782605171204, 47.84878045320511, 39.48235139250755, 59.340895190835, 3.3850390976294875, 0.3190703928703442, 0.0975771906087175, 0.05245992935670074, 0.11784023416112177, 0.04293433034035843, 0.177051707287319, 0.028108242113376036, 0.07598464886541478, 0.10441375110531226, 0.057981252030003816, 0.16052529565058649, 0.03549619978002738, 0.08675286284415051, 0.058442519075470045, 0.04505365919612814, 0.03322420743643306, 0.06023487992933951, 0.03042554628336802, 0.05817887853481807, 0.06282406247919425, 0.2312717103632167, 0.1884045629412867, 18.836748227477074, 62.75258392095566, 38.72154101729393, 86.99340596795082, 113.39919224381447, 65.77321663498878, 45.036460161209106, 38.542479425668716, 37.38615967333317, 58.5202494263649, 67.33256936073303, 48.1838920712471, 25.617383681237698, 40.54955072700977, 58.83626326918602, 63.717762529850006, 56.83219760656357, 62.614666521549225, 63.27500268816948, 66.47719725966454, 64.59524184465408, 63.497119769454, 63.3305861055851, 56.71163767576218, 50.060489773750305, 50.48330828547478, 53.26247535645962, 53.968982845544815, 49.372665882110596, 50.78899808228016, 50.73404163122177, 48.2482074201107, 46.54919698834419, 43.81552867591381, 42.30959728360176, 44.98982906341553, 52.634399458765984, 54.74887199699879, 58.00367474555969, 52.780239433050156, 50.14841325581074, 48.195625841617584, 53.12615007162094, 58.24969254434109, 55.77566049993038, 59.368451312184334, 57.32184313237667, 56.19498319923878, 57.70528055727482, 61.7974291741848, 62.1609328687191, 60.007801204919815, 52.03275874257088, 46.502919271588326, 48.99075597524643, 54.50563184916973, 54.831475764513016, 48.908482789993286, 36.64450027048588, 31.739398576319218, 37.1084363758564, 36.25189773738384, 31.670614667236805, 34.67859596014023, 39.90946747362614, 42.12336167693138, 33.653866946697235, 34.92723561823368, 36.2329975515604, 37.93224737048149, 36.2191890925169, 37.99609914422035, 15.57468881830573, 21.538507752120495, 45.17481453716755, 42.91939236223698, 43.70877720415592, 50.850076004862785, 48.58019560575485, 46.912734881043434, 43.09229828417301, 40.846793577075005, 46.45124964416027, 43.29444743692875, 43.06599609553814, 41.12756051123142, 40.49026630818844, 35.84890656173229, 24.349988289177418, 22.06466741859913, 23.4968276694417, 30.708738081157207, 38.428599536418915, 35.219139754772186, 33.79449360072613, 40.98317585885525, 46.11316658556461, 52.734850868582726, 49.90910589694977, 46.79314769804478, 48.02518978714943, 48.993856608867645, 53.20613197982311, 51.59330852329731, 50.539609864354134, 50.98997689783573, 49.45802070200443, 50.17864063382149, 49.08560648560524, 52.74175509810448, 55.82313135266304, 54.45615470409393, 52.92413391172886, 53.10512199997902, 53.9806292206049, 54.976635575294495, 52.68057458102703, 53.385630548000336, 53.89559358358383, 55.828306674957275, 51.06357514858246, 43.091067150235176, 44.33656431734562, 50.220803171396255, 62.04177126288414, 58.68269830942154, 61.156437769532204, 60.38459278643131, 59.48008552193642, 57.41247966885567, 58.021959364414215, 60.13419762253761, 65.26922687888145, 61.376590356230736, 65.11848136782646, 62.135622426867485, 62.83418834209442, 63.40171828866005, 65.9849488735199, 47.453092485666275, 23.82818128913641, 13.460138384252787, 50.61182878911495, 54.3344434350729, 53.98913696408272, 36.83266997337341, 25.44412437826395, 34.632261246442795, 38.58956269919872, 67.25941568613052, 46.72906793653965, 42.10715554654598, 66.42483606934547, 2.898272629827261, 0.1954979362199083, 0.16805812425445765, 0.029981840307300445, 0.1453954426688142, 0.13584079599240795, 0.11678749768179841, 0.0335953963076463, 0.06164809237816371, 0.17543047084473073, 0.0729014705575537, 0.2870390616590157, 0.10957726583001204, 0.17476347304182127, 0.22154406906338409, 0.1388993943692185, 0.14150023605907336, 0.11330159293720499, 0.2235900959931314, 0.2977513993391767, 0.19769699400058016, 0.4795003077015281, 0.16182475170353428, 39.587168768048286, 77.46170103549957, 50.0024326890707, 85.05205973982811, 105.36923512816429, 73.46489310264587, 51.71090841293335, 40.106737688183784, 43.10422584414482, 62.92640559375286, 72.30928391218185, 50.842795595526695, 28.020030856132507, 41.11744925379753, 65.08363723754883, 70.07959395647049, 62.140774950385094, 68.53190660476685, 65.7601909339428, 67.42482081055641, 67.39048585295677, 66.77539005875587, 65.96543312072754, 59.85846161842346, 53.845147490501404, 53.37466813623905, 56.09252169728279, 57.7104102820158, 51.826061233878136, 54.01519976556301, 52.449835762381554, 51.08722887933254, 49.47839520871639, 47.2802359610796, 43.81130710244179, 50.05092568695545, 54.18600060045719, 57.70283728837967, 62.92562663555145, 54.605741277337074, 51.03686258196831, 48.90192054212093, 53.40579606592655, 59.41410966217518, 58.23520012199879, 61.54802195727825, 60.441886112093925, 59.96609844267368, 60.392887741327286, 61.8271853774786, 63.67192558944225, 63.40335600078106, 55.81153817474842, 49.8397596180439, 52.89237521588802, 59.98239956796169, 56.24128371477127, 52.3532335460186, 38.47817547619343, 36.16281531751156, 40.389856696128845, 37.65782989561558, 33.13065782189369, 40.56671820580959, 42.26646579802036, 44.722650200128555, 34.944433495402336, 38.44682715833187, 38.267890959978104, 39.54959638416767, 39.16663013398647, 40.58243416249752, 18.597735352814198, 29.091472662985325, 50.773361921310425, 42.4980253726244, 43.23692612349987, 48.80043938755989, 49.80995401740074, 50.364720448851585, 47.86041542887688, 47.48257890343666, 55.09544759988785, 52.039282992482185, 49.80510547757149, 49.052776247262955, 41.80697165429592, 39.27102193236351, 29.599706791341305, 28.273125775158405, 26.455839090049267, 31.02223075926304, 39.41892519593239, 36.976545453071594, 36.455312222242355, 44.72530245780945, 50.6693235039711, 56.20654217898846, 52.80417814850807, 49.0782804787159, 51.02985955774784, 53.49466949701309, 56.47523336112499, 55.698152258992195, 53.45923259854317, 53.68686318397522, 53.422898948192596, 53.32165718078613, 53.77711594104767, 55.00052109360695, 58.101451098918915, 57.60946489870548, 54.00540769100189, 54.94355455040932, 57.10701406002045, 58.11811700463295, 56.086943596601486, 55.39249666035175, 57.87946321070194, 60.030421391129494, 57.512748688459396, 46.508508771657944, 48.17966289818287, 54.88716557621956, 65.9956718981266, 59.74719978868961, 65.56029886007309, 65.40886178612709, 63.094903752207756, 59.984922632575035, 61.63382515311241, 64.48620289564133, 70.02868428826332, 65.83382338285446, 69.3472820520401, 67.34935685992241, 68.42520833015442, 67.9328003525734, 70.36813527345657, 48.65167357027531, 27.253473289310932, 14.646589569747448, 51.88217282295227, 60.96201740205288, 61.15551441907883, 37.78524845838547, 32.66219615936279, 45.0099565833807, 54.46012169122696, 75.31736969947815, 66.62412017583847, 57.49134063720703, 78.15368950366974, 5.339224124327302, 0.5827814375516027, 0.31923684175126255, 0.22101687703980133, 0.28144116047769785, 0.3225782874505967, 0.32140869239810854, 0.28478227963205427, 0.0935227562149521, 0.16164954548003152, 0.25881527457386255], [0.2916449785698205, 0.14219254109775648, 0.18102008965797722, 0.23922327352920547, 0.332343882182613, 0.05285838102281559, 0.0898174280882813, 0.16196400829358026, 0.09461054432904348, 0.06909166288096458, 0.051964341691927984, 0.036092459777137265, 0.668768686009571, 54.549625888466835, 48.383833542466164, 40.34014396369457, 17.453715540468693, 45.80603286623955, 36.318238377571106, 27.8818778693676, 30.44678393751383, 39.1621957719326, 63.75146672129631, 47.533587366342545, 31.07603207230568, 46.92834824323654, 63.94343242049217, 64.45995390415192, 53.67617055773735, 54.568396881222725, 60.4169936478138, 62.19158202409744, 64.84143823385239, 58.18233735859394, 58.83334882557392, 53.8672699034214, 46.35143280029297, 44.09127987921238, 47.36106902360916, 46.84932008385658, 45.567607060074806, 41.35841332376003, 43.88330563902855, 39.75513495504856, 38.20111334323883, 33.806941732764244, 39.48113925755024, 39.69571374356747, 46.61328434944153, 53.31150032579899, 51.33946694433689, 53.09334643185139, 49.069806933403015, 52.66126401722431, 55.651365369558334, 55.15807583928108, 55.37190556526184, 53.277093172073364, 52.913266494870186, 53.064901158213615, 57.75811292231083, 63.21359418332577, 60.25731101632118, 57.00164191424847, 48.18196177482605, 39.163681492209435, 42.5254675000906, 49.504492208361626, 58.54850471019745, 50.334337279200554, 36.40208087861538, 29.798764809966087, 30.71331113576889, 34.578125551342964, 24.533081464469433, 25.432998575270176, 28.82093098014593, 36.62935808300972, 34.12379153072834, 28.15172988921404, 26.318221874535084, 32.54251778125763, 33.0748426169157, 34.509026259183884, 24.816597551107407, 40.155899450182915, 57.30624116957188, 50.47455735504627, 49.24163371324539, 54.267502427101135, 50.259116515517235, 47.877693101763725, 35.99946588277817, 32.921099066734314, 31.65473721921444, 22.462981045246124, 18.59139919281006, 21.89369559288025, 28.727860674262047, 33.137090876698494, 21.859049052000046, 19.62936669588089, 23.62842980772257, 30.747617594897747, 30.761593244969845, 29.75541863590479, 34.95951868593693, 39.25655610859394, 43.75594787299633, 47.48605191707611, 44.044584184885025, 40.21193504333496, 43.376766219735146, 47.37601742148399, 50.6956522911787, 49.50306348502636, 44.620648473501205, 44.8671792447567, 45.38673296570778, 46.53194971382618, 48.639134243130684, 51.17110177874565, 53.30192483961582, 49.62869994342327, 52.69571676850319, 54.902512952685356, 53.494380712509155, 50.904185101389885, 49.28386464715004, 49.89845126867294, 46.84963546693325, 47.48730964958668, 41.998082399368286, 41.20273947715759, 38.849392756819725, 45.2428574860096, 54.16511312127113, 53.91064837574959, 56.576790511608124, 56.945036351680756, 55.97598575055599, 51.6733056306839, 52.900160998106, 53.49968142807484, 55.26323899626732, 55.02407222986221, 56.92484423518181, 56.971790716052055, 58.349505588412285, 59.07965540885925, 62.57102966308594, 46.85285769402981, 20.258620530366898, 13.568611163645983, 46.1556901037693, 49.33925047516823, 41.502376198768616, 22.480456307530403, 23.511513881385326, 30.314638428390026, 38.74974690377712, 53.638305589556694, 77.37986862659454, 53.86305212974548, 53.16082701086998, 1.1504411115311086, 0.17397071089362726, 0.3197805391391739, 0.11641935532679781, 0.04455786001926754, 0.07732762445812114, 0.2193097147392109, 0.056455574522260576, 0.05439990709419362, 0.2974940522108227, 0.5214071902446449, 0.40759819094091654, 0.18878626433433965, 0.16967878182185814, 0.21100717509398237, 0.16934267798205838, 0.04314820245781448, 0.1145012301276438, 0.2465207819477655, 0.11585942716919817, 0.17244589427718893, 0.059070966017316096, 0.07883286321884952, 0.7055146736092865, 57.972626611590385, 52.93812096118927, 48.733281791210175, 31.439547166228294, 54.982012286782265, 41.44103229045868, 33.008695766329765, 37.249887585639954, 43.00298787653446, 65.89384496212006, 52.17840112745762, 34.836488887667656, 49.09305028617382, 70.75010597705841, 69.61164146661758, 58.58427979052067, 59.56091098487377, 62.647321969270706, 66.93178966641426, 69.22729209065437, 63.25348824262619, 63.673445507884026, 56.04130804538727, 47.98332363367081, 48.00426051020622, 54.329963475465775, 49.747401773929596, 48.559361323714256, 44.910660311579704, 47.9407013207674, 44.096728786826134, 41.72237679362297, 36.60612232983112, 41.73709340393543, 43.73093381524086, 49.57528240978718, 56.2818693369627, 54.45140115916729, 56.41788303852081, 49.24816936254501, 55.329256653785706, 58.364100605249405, 58.07508431375027, 59.089622274041176, 56.97111815214157, 55.76552264392376, 54.556039944291115, 60.38620010018349, 63.35077442228794, 62.95170083642006, 59.334640726447105, 52.24272407591343, 42.675753235816956, 43.29072743654251, 50.657072961330414, 58.29288862645626, 53.059034273028374, 40.5346517264843, 35.399611070752144, 34.700904563069344, 37.66002617776394, 30.008870735764503, 28.42540070414543, 30.263878852128983, 37.896225303411484, 36.562219485640526, 32.563093677163124, 27.899073846638203, 33.55815388262272, 34.92558650672436, 35.56981913745403, 41.75970979034901, 73.92526119947433, 74.27927300333977, 51.1710561811924, 54.48503315448761, 56.127468422055244, 50.79032801091671, 48.708792105317116, 33.954119235277176, 35.95453329384327, 37.52981096506119, 31.24342828989029, 26.401969380676746, 33.54660250246525, 35.42237184941769, 40.524707660079, 28.5263878852129, 25.86863949894905, 25.541965328156948, 29.911052584648132, 30.373499169945717, 32.18224011361599, 38.964385986328125, 42.75279030203819, 47.639860063791275, 52.14218907058239, 45.40369525551796, 40.90242639183998, 45.60308575630188, 54.15312856435776, 60.581464022397995, 55.59398464858532, 48.94015409052372, 48.36373262107372, 45.95516346395016, 50.619025602936745, 52.259648367762566, 57.33381249010563, 56.0079800337553, 51.875830963253975, 53.28631527721882, 57.98501394689083, 56.4574009180069, 54.35256086289883, 54.115704372525215, 52.63064906001091, 49.409710094332695, 47.034803330898285, 43.64818565547466, 42.84527733922005, 41.99708305299282, 50.632248893380165, 60.59907987713814, 57.13504135608673, 62.742909640073776, 62.52881392836571, 61.0650260746479, 55.11969789862633, 56.46915748715401, 58.55752542614937, 59.23637039959431, 57.99889460206032, 60.52752211689949, 58.73558007180691, 61.00020535290241, 61.64295606315136, 64.48795080184937, 50.54806061089039, 21.001283079385757, 15.362094026058912, 49.48988199234009, 55.09699411690235, 47.23194055259228, 25.036968626081944, 26.574100144207478, 28.85336223989725, 43.024042546749115, 58.28536123037338, 94.75859329104424, 57.59193643927574, 61.74465760588646, 2.051935256458819, 0.06927651702426374, 0.19994297035736963, 0.09358396855532192, 0.08964427761384286, 0.09098000984522514, 0.2001773109077476, 0.07405479773296975, 0.1352237001992762, 0.24903097772039473, 0.6912845559418201, 0.5682342150248587, 0.3190411819377914, 0.3074179618852213, 0.543739126296714, 0.3015170863363892, 0.12845586257753894, 0.21978310105623677, 0.3220216173212975, 0.29325285635422915, 0.3603767591994256, 0.21481127565493807, 0.15841507294680923, 2.7144757797941566, 85.71100518107414, 64.14329409599304, 58.80281746387482, 25.635966584086418, 57.879987582564354, 47.09732137620449, 33.55014011263847, 40.879490822553635, 49.76629436016083, 70.3392644226551, 54.84756790101528, 36.456615552306175, 53.525911420583725, 76.08153149485588, 75.77602028846741, 60.12445494532585, 63.76578435301781, 68.07134851813316, 75.13545826077461, 78.68537217378616, 70.91085255146027, 70.32127618789673, 63.10396246612072, 50.695910677313805, 49.252637922763824, 57.81387113034725, 54.46429006755352, 54.63919848203659, 47.980834767222404, 50.6050081551075, 45.93812137842178, 43.31479154527187, 37.48954452574253, 44.75915864109993, 47.56025813519955, 53.438238725066185, 61.50092728435993, 57.00037658214569, 58.834663555026054, 49.79154780507088, 53.62171187996864, 59.68199148774147, 60.246637389063835, 62.72937096655369, 58.817032501101494, 56.59406818449497, 56.46560087800026, 60.95330446958542, 65.55290445685387, 63.437584564089775, 64.51803758740425, 53.389909118413925, 45.000939667224884, 48.991360142827034, 51.61517255008221, 59.56714265048504, 54.785030856728554, 41.816227957606316, 38.14308285713196, 37.520615458488464, 41.16173207759857, 30.69333180785179, 37.269885912537575, 38.11759762465954, 42.56809741258621, 37.543889209628105, 34.747752249240875, 32.23844289779663, 37.21713714301586, 37.49471604824066, 41.15682274103165, 31.809430718421936, 73.24091032147408, 68.83298724889755, 54.45973411202431, 52.01661340892315, 55.09178079664707, 49.786881655454636, 49.79601636528969, 38.10180187225342, 41.80732503533363, 47.24695734679699, 41.81045986711979, 36.30686558783054, 44.776930287480354, 41.0898095369339, 44.79834593832493, 33.02247382700443, 30.92961262911558, 29.149005375802517, 33.04900020360947, 30.646351128816605, 30.679646842181683, 39.47243012487888, 46.217356994748116, 50.72450414299965, 56.1576160043478, 51.232666075229645, 41.87407985329628, 46.91143535077572, 56.481898203492165, 61.136561036109924, 57.716786339879036, 52.02384062111378, 51.59474104642868, 49.96951125562191, 54.067948535084724, 53.073716685175896, 57.85031117498875, 58.68462860584259, 53.10660012066364, 56.91226311028004, 62.83745236694813, 62.76786670088768, 59.05458055436611, 55.34103222191334, 54.98980946838856, 51.68794244527817, 50.86836822330952, 49.31627310812473, 48.09086926281452, 42.979246750473976, 52.6874940097332, 61.21021248400211, 59.44181777536869, 62.260726913809776, 65.70744976401329, 62.11105674505234, 59.15122836828232, 61.72241359949112, 60.83380468189716, 63.58007691800594, 63.613659515976906, 63.956572115421295, 66.18922591209412, 68.23017999529839, 69.14774715900421, 68.70060235261917, 55.296430215239525, 24.350269474089146, 17.963140904903412, 51.54189348220825, 57.989338114857674, 53.50413478910923, 29.866581670939922, 32.0523364841938, 37.44482472538948, 59.59277227520943, 65.61723500490189, 99.17777895927429, 73.73992994427681, 72.26822331547737, 3.0080233281478286, 0.4324970970628783, 0.6449376710224897, 0.3307422384386882, 0.22022651945007965, 0.2500679064542055, 0.37431170989293605, 0.2898494264809415, 0.2757207158720121, 0.3549249720526859, 1.2032487778924406], [0.3480128163937479, 0.1987739244941622, 0.38320661697071046, 0.45892981463111937, 0.17762409610440955, 0.03310457323095761, 0.027814618806587532, 0.16531900560948998, 0.08345778653165326, 0.290353522868827, 0.053480104106711224, 0.3358392196241766, 0.138054815470241, 23.88568550348282, 60.442330688238144, 33.05960163474083, 20.765118151903152, 44.237997606396675, 35.37096440792084, 24.929941669106483, 36.67652115225792, 37.806949093937874, 60.54786242544651, 52.02989749610424, 35.5275122076273, 39.78308245539665, 76.27705380320549, 68.61656606197357, 60.31999625265598, 58.982175439596176, 55.35271659493446, 56.48149162530899, 55.303144454956055, 48.34828644990921, 52.601626217365265, 46.802681386470795, 42.980447486042976, 41.87347948551178, 49.214085191488266, 42.89336375892162, 39.04336474835873, 39.14709538221359, 43.46946604549885, 37.71200358867645, 38.23944188654423, 38.88577960431576, 38.28551821410656, 42.888082042336464, 44.87760588526726, 52.53189995884895, 51.888917461037636, 52.77785696089268, 51.134163960814476, 55.14170631766319, 53.78911189734936, 53.22739563882351, 56.77750714123249, 52.794173285365105, 50.34602165222168, 51.91022291779518, 59.34250250458717, 59.527598172426224, 57.920333817601204, 53.07229556143284, 48.19173485040665, 40.31473472714424, 39.44420523941517, 50.46623580157757, 54.61964473128319, 57.54908613860607, 43.50374020636082, 38.01556929945946, 34.79026056826115, 32.60992996394634, 27.910332642495632, 20.833368189632893, 20.804864019155502, 33.21622923016548, 34.86746862530708, 33.70166078209877, 25.909033231437206, 30.146548748016357, 33.56940507888794, 29.20750703662634, 47.8401131182909, 104.72940266132355, 69.6239984035492, 43.32275591790676, 57.069111093878746, 54.2439740896225, 48.732768818736076, 42.90968008339405, 26.764388233423233, 18.258371762931347, 11.632519103586674, 8.11857596039772, 7.184746144339442, 9.304706063121557, 23.537572883069515, 35.42200326919556, 30.58316621929407, 25.520215295255184, 21.402102671563625, 29.02707751840353, 27.556567825376987, 32.10136145353317, 38.71480777859688, 42.601619213819504, 43.3713249117136, 46.88302427530289, 44.02937740087509, 38.72312553226948, 42.62945272028446, 49.710802137851715, 53.95032964646816, 52.85533860325813, 44.413453191518784, 44.643568843603134, 46.001099199056625, 49.30542089045048, 51.90035864710808, 55.7153045386076, 54.28522847592831, 53.56326341629028, 49.525303691625595, 49.7796506434679, 51.16849511861801, 52.1136450022459, 49.11484971642494, 46.730504259467125, 44.3536140024662, 38.52259509265423, 40.09398177266121, 39.36255522072315, 39.09139797091484, 48.41572903096676, 58.36205631494522, 56.45569860935211, 57.91643142700195, 55.562415942549706, 54.82577607035637, 50.72652943432331, 47.07519516348839, 53.37097853422165, 53.85504595935345, 50.59022314846516, 52.295457646250725, 54.02661435306072, 56.11555986106396, 59.71649743616581, 61.76300302147865, 46.08174227178097, 19.245642386376858, 14.051427505910397, 44.71880100667477, 50.00202611088753, 30.22889792919159, 20.456285923719406, 26.435797065496445, 36.26334272325039, 37.25314401090145, 48.24272811412811, 76.16989955306053, 42.41850703954697, 54.098407700657845, 1.2351703899912536, 0.06773710236302577, 0.16488596244016662, 0.1346806262154132, 0.07328781779506244, 0.09643751895055175, 0.1846826626569964, 0.12669446412473917, 0.6445033068303019, 0.4409731359919533, 0.367875449010171, 0.4899623931851238, 0.25593790865968913, 0.35629417514428496, 0.2900913666235283, 0.07004181970842183, 0.06975959578994662, 0.20632722153095528, 0.29513004468753934, 0.25349858799017966, 0.3016252617817372, 0.02608283204608597, 0.3171756601659581, 0.30294307856820524, 28.53967197239399, 64.67931613326073, 35.44548600912094, 28.798553980886936, 54.968359619379044, 44.980660155415535, 30.770513266324997, 43.55143144726753, 44.216483160853386, 64.71283793449402, 57.22125492990017, 37.523290514945984, 39.40078876912594, 75.88340252637863, 70.31904190778732, 66.84509351849556, 65.12181758880615, 60.99220298230648, 61.177310049533844, 58.88446748256683, 51.596355959773064, 52.690541446208954, 49.02579769492149, 47.31982223689556, 48.65922376513481, 52.6849215477705, 45.413551926612854, 42.24348083138466, 44.39766123890877, 46.94583870470524, 41.993518844246864, 44.60835613310337, 43.39911662042141, 42.13090047240257, 46.0065671056509, 47.454319819808006, 52.02069438993931, 53.58447387814522, 53.47233809530735, 53.83123643696308, 57.13422819972038, 59.88050803542137, 56.735131815075874, 56.97668485343456, 55.47677233815193, 51.01117596030235, 56.88808120787144, 60.73239952325821, 58.960847184062004, 62.58138030767441, 58.230663165450096, 52.83010795712471, 42.519057244062424, 40.67667670547962, 48.84524658322334, 55.792056620121, 58.90356905758381, 49.020310789346695, 42.27475315332413, 41.44346795976162, 37.42175616323948, 34.586599096655846, 29.725660532712936, 25.710699073970318, 38.12289074063301, 38.598758205771446, 33.52848507463932, 30.58904830366373, 31.39829657971859, 35.69520480930805, 30.269320160150528, 53.20201680064201, 119.094258248806, 67.01532438397408, 46.25298008322716, 59.52048875391483, 53.17827567458153, 48.68007704615593, 44.812321588397026, 31.80728193372488, 24.253230281174183, 16.14336535334587, 12.724104579538107, 11.52673278003931, 18.969799987971783, 31.742218025028706, 41.115792542696, 41.174305602908134, 26.574700511991978, 26.33784782141447, 31.492278836667538, 29.68584816902876, 36.44113138318062, 42.70186923444271, 46.104746237397194, 45.53636513650417, 47.9075974971056, 45.11891193687916, 40.642687529325485, 47.85787716507912, 53.1821096688509, 59.21289525926113, 56.62425376474857, 50.31781956553459, 46.4100256562233, 50.184024944901466, 50.35453699529171, 55.70300839841366, 57.971691861748695, 56.22380845248699, 56.513884887099266, 52.49707482755184, 51.55819460749626, 53.816291838884354, 53.2945304363966, 50.881006345152855, 48.80630247294903, 43.544025644659996, 38.881694823503494, 42.05123394727707, 41.22962303459644, 41.955205500125885, 51.07747860252857, 65.20849853754044, 58.85293297469616, 62.320246919989586, 59.608575627207756, 56.88635230064392, 52.8692002594471, 52.19618797302246, 57.1178662776947, 58.301251977682114, 55.24223372340202, 58.720194697380066, 57.908330261707306, 60.79391062259674, 64.7701920568943, 65.19030511379242, 48.27681228518486, 19.66829940676689, 16.51122361421585, 50.64518339931965, 53.72287005186081, 36.5068032592535, 20.595407858490944, 29.34026051312685, 32.05989047884941, 45.136941969394684, 51.134008169174194, 74.105394333601, 49.56322565674782, 67.20668211579323, 2.323416913859546, 0.10397797683253884, 0.07268515677424148, 0.14260014344472438, 0.07524972970713861, 0.36785184871405363, 0.19423864519922063, 0.36724788893479854, 0.6161105178762227, 0.336482067941688, 0.41670808335766196, 0.5345732462592423, 0.33738710219040513, 0.8533512626308948, 0.6970619084313512, 0.18639411457115784, 0.13240503816632554, 0.18954111757921055, 0.4748054518131539, 0.46478628006298095, 0.7014377298764884, 0.17209839104907587, 0.37750629941001534, 0.42558568355161697, 42.96046435832977, 83.8705663383007, 46.67292594909668, 27.96547718346119, 53.27035613358021, 47.83252492547035, 32.06846281886101, 47.04692468047142, 49.600687846541405, 71.3895508646965, 60.71473807096481, 42.73897424340248, 44.713466092944145, 87.00468376278877, 77.61156499385834, 68.28591540455818, 66.39402732253075, 64.17103260755539, 65.96309244632721, 65.8381399512291, 57.87656016647816, 60.646163150668144, 53.705466985702515, 48.628810197114944, 50.88278844952583, 55.31931258738041, 50.658934861421585, 44.41572546958923, 46.24543748795986, 48.21115180850029, 41.50199241936207, 45.3206355124712, 43.54353927075863, 43.260648250579834, 48.030767887830734, 48.23014318943024, 60.52241139113903, 55.388734862208366, 56.4181300252676, 54.03630383312702, 56.84091813862324, 59.2056642472744, 60.159325674176216, 62.83801853656769, 59.66912537813187, 51.57248184084892, 56.678887233138084, 64.18012171983719, 62.31436863541603, 64.0371809899807, 60.17840065062046, 57.96032287180424, 46.885817125439644, 43.19375663995743, 53.731449991464615, 56.72999829053879, 61.43260695040226, 46.14180564880371, 43.59558127820492, 41.49613693356514, 41.33466459810734, 36.343852803111076, 31.59411907196045, 34.57345940172672, 48.10350738465786, 43.80563400685787, 39.50773403048515, 31.65221605449915, 38.34104083478451, 39.91632230579853, 40.81669919192791, 39.701972007751465, 97.31118991971016, 68.46484020352364, 51.2792781740427, 61.54678322374821, 54.44275662302971, 50.66956289112568, 49.15399141609669, 35.45087791979313, 36.33036732673645, 26.68013535439968, 23.980927392840385, 21.672496162354946, 29.86489836126566, 43.691560328006744, 49.449885338544846, 46.01255178451538, 35.07516548037529, 31.28049150109291, 31.709211096167564, 28.750735446810722, 33.9703443646431, 44.15524944663048, 51.66888266801834, 48.93538534641266, 53.88194091618061, 50.84284499287605, 42.16177761554718, 47.170995622873306, 57.55979776382446, 64.92156833410263, 61.41895808279514, 54.80194754898548, 48.01075056195259, 51.85807451605797, 55.4667104780674, 58.62183317542076, 61.37830026447773, 59.69477400183678, 56.749932020902634, 53.034107610583305, 52.77028016746044, 62.142063081264496, 60.314638540148735, 55.93296825885773, 56.59680403769016, 48.52347604930401, 41.63720056414604, 43.415387347340584, 43.69179971516132, 42.543497532606125, 54.24250736832619, 68.09561401605606, 62.78628811240196, 63.1140623241663, 64.20896217226982, 61.76796555519104, 57.51083739101887, 57.69286282360554, 60.03447577357292, 62.6397679746151, 58.89973506331444, 58.950344547629356, 63.209775388240814, 63.46984103322029, 66.14448711276054, 67.79469296336174, 52.52263605594635, 23.21913857012987, 18.985255658626556, 50.81871248781681, 59.36541147530079, 41.84058465063572, 28.113893419504166, 35.25495283305645, 46.53458297252655, 57.868360206484795, 60.075236186385155, 76.42941042780876, 54.71306651830673, 73.81578147411346, 2.878146772272885, 0.5256202141754329, 0.2082830181461759, 0.23516331013524905, 0.2886542124906555, 0.7501986727584153, 0.2533131104428321, 0.5321331834420562, 0.898677664808929, 0.678138923831284, 0.5764022329822183], [0.22640696202870458, 0.042357967322459444, 0.14334448787849396, 0.3051117231370881, 0.34990232437849045, 0.08349905736395158, 0.041163547430187464, 0.11534735269378871, 0.1739789784187451, 0.03997799620265141, 0.11432529659941792, 0.5130358238238841, 0.3704757266677916, 15.901201497763395, 51.60661920905113, 46.377507001161575, 65.49902334809303, 39.47829321026802, 43.73192176222801, 20.197690799832344, 37.95167572796345, 41.68443962931633, 49.77341137826443, 56.08169987797737, 35.841713547706604, 33.82746063172817, 64.56580862402916, 65.46765983104706, 70.03832057118416, 67.19956889748573, 65.0139869749546, 60.667901784181595, 52.302240282297134, 48.486253246665, 49.159778505563736, 47.99651272594929, 53.584660068154335, 53.753686398267746, 52.79169961810112, 47.93873682618141, 44.368262216448784, 42.16661475598812, 42.92840547859669, 44.05860163271427, 43.859385922551155, 41.741717755794525, 41.24354928731918, 42.703168764710426, 43.51786024868488, 42.99292981624603, 48.16691838204861, 54.289617240428925, 56.75629287958145, 58.530964851379395, 55.16245700418949, 52.681015357375145, 45.86374416947365, 49.31471139192581, 53.93161565065384, 56.22173376381397, 56.72653287649155, 58.20569850504398, 61.08103081583977, 55.65835699439049, 47.588726207613945, 43.518479615449905, 39.03804883360863, 42.62105517089367, 54.70234729349613, 55.03800608217716, 53.400962725281715, 39.52650502324104, 43.5496873408556, 35.97486600279808, 30.624432004988194, 24.554821997880936, 20.160564891994, 26.08934685587883, 26.85308687388897, 16.93488758057356, 20.04352357238531, 23.482109159231186, 24.923358522355556, 19.195106998085976, 35.08980229496956, 63.12791258096695, 27.35797718167305, 28.310624063014984, 42.79354311525822, 45.168172493577, 42.891213074326515, 33.28419618308544, 14.645130448043346, 5.869274782016873, 4.661855846643448, 3.098891652189195, 4.906403124332428, 6.875100284814835, 19.821816869080067, 33.924275636672974, 38.280232697725296, 23.212521225214005, 30.069008208811283, 28.10472261160612, 27.58685790002346, 38.11272248625755, 40.92218153178692, 42.43524134159088, 43.314810544252396, 43.841849863529205, 41.39719404280186, 39.96287740767002, 46.71894147992134, 47.814578488469124, 52.14075654745102, 49.88586254417896, 45.26791714131832, 44.15411710739136, 50.59702858328819, 48.39670345187187, 49.77118469774723, 48.46934795379639, 50.09957067668438, 53.005061969161034, 55.08909434080124, 51.62100903689861, 49.13281515240669, 48.11246730387211, 45.81565394997597, 41.8605487793684, 37.9253925383091, 38.288197070360184, 42.95475706458092, 42.60990656912327, 42.71573469042778, 48.2966548204422, 54.901920184493065, 55.39944268763065, 57.50288441777229, 56.157517209649086, 54.47200745344162, 50.31226046383381, 49.39654380083084, 52.5428281724453, 49.99096490442753, 51.648846343159676, 56.64727292954922, 57.01042324304581, 60.3787487000227, 63.26917380094528, 65.27007043361664, 43.822246715426445, 13.7329694442451, 11.805267333984375, 51.82068832218647, 45.07234163582325, 27.5261352583766, 19.053452499210835, 27.77958545833826, 38.8658382743597, 39.175962433218956, 47.47535549104214, 26.241832673549652, 49.23200123012066, 61.7164821177721, 1.628068475984037, 0.0647327549813781, 0.09157403226708993, 0.09448373355553485, 0.07002678379649296, 0.12161265243776143, 0.05108203571580816, 0.06859264278318733, 0.12672538199694827, 0.09641190743423067, 0.12708309717709199, 0.12875791668193415, 0.06491386127891019, 0.030433821229962632, 0.21453081804793328, 0.09542812389554456, 0.10734563518781215, 0.08625673712231219, 0.11364019781467505, 0.08214645611587912, 0.041064225806621835, 0.13807421521050856, 0.5621702154166996, 0.4845708387438208, 19.483800306916237, 62.041011303663254, 42.55787216126919, 51.848347038030624, 50.351892337203026, 48.40414345264435, 24.137456193566322, 43.741029873490334, 44.895225539803505, 54.76848654448986, 60.26266112923622, 41.45867854356766, 36.097014248371124, 65.53328230977058, 68.0010598897934, 71.34582281112671, 70.9448379278183, 68.0977115035057, 65.65304428339005, 59.14184667170048, 55.53238995373249, 56.95549339056015, 53.00105318427086, 57.58697010576725, 60.475920885801315, 57.40717515349388, 54.50430952012539, 52.59447880089283, 47.68590219318867, 45.92376574873924, 45.20301662385464, 47.112486362457275, 42.42330618202686, 44.89774480462074, 42.797502502799034, 45.65428040921688, 43.75098533928394, 47.398219630122185, 54.98396158218384, 57.622372806072235, 61.04191951453686, 57.2253093123436, 53.41307267546654, 48.04310202598572, 52.77977965772152, 56.70091085135937, 59.42046292126179, 58.77091817557812, 59.71699520945549, 66.38376787304878, 62.347301468253136, 52.996805012226105, 48.090975657105446, 43.65845650434494, 47.23184175789356, 56.951689794659615, 58.268778920173645, 58.10262903571129, 45.926558598876, 44.05517801642418, 46.15702763199806, 29.249445386230946, 34.78321574628353, 36.80609419941902, 35.528762340545654, 32.26427771151066, 21.972826346755028, 21.478909850120544, 26.09480906277895, 24.453794918954372, 19.897605702281, 25.428493916988373, 44.001429900527, 27.506604306399822, 30.92038482427597, 43.9489471167326, 48.98217223584652, 46.37969948351383, 35.577992498874664, 21.121394634246826, 10.842430349439383, 5.389362433925271, 4.621442165225744, 7.287102676928043, 11.53973188251257, 30.560606829822063, 41.12441048026085, 44.5516973733902, 30.051344856619835, 36.19298189878464, 30.09280253201723, 28.686467595398426, 40.284184366464615, 44.277116507291794, 47.58590295910835, 46.519296392798424, 44.68634694814682, 43.054672703146935, 42.40032501518726, 49.2780851572752, 51.604631915688515, 57.320011630654335, 54.99105580151081, 50.43955363333225, 49.49800595641136, 52.70491227507591, 52.07487188279629, 51.73059515655041, 51.6076223552227, 51.923750191926956, 52.27482095360756, 57.98454277217388, 53.66865076124668, 54.77157197892666, 49.7893363237381, 47.68911302089691, 43.38406182825565, 40.32988451421261, 40.70687748491764, 43.788553923368454, 45.96764199435711, 46.49864450097084, 51.82138368487358, 58.617258220911026, 59.50205594301224, 60.24123787879944, 60.50101473927498, 57.62696675956249, 58.32622803747654, 58.01409758627415, 59.732262790203094, 56.4221616089344, 55.13515546917915, 59.13493104279041, 60.90650238096714, 63.21697600185871, 66.04516804218292, 63.39649356901646, 43.66863615810871, 11.353885754942894, 14.050854686647654, 54.63752657175064, 50.216737389564514, 28.711293563246727, 18.421257622539997, 28.157670870423317, 34.87389028072357, 46.71097330749035, 58.46035324037075, 35.49193471670151, 56.533640027046204, 71.42160594463348, 1.5534307435154915, 0.020190513459965587, 0.027031743920815643, 0.06542325660120696, 0.01325899609582848, 0.16836567025166005, 0.007330281659960747, 0.026496230566408485, 0.04690993380791042, 0.04955134500050917, 0.06798100177547894, 0.25073539407458156, 0.12923624570248649, 0.23814634303562343, 0.3682342328829691, 0.2943290595430881, 0.14350691431900486, 0.18478412908734754, 0.23150046996306628, 0.21492654603207484, 0.34169096499681473, 0.25538717571180314, 0.7879250671248883, 0.699756023241207, 27.394818104803562, 72.92886346578598, 59.39469650387764, 84.24160122871399, 52.3420013487339, 57.39657372236252, 26.93345446139574, 46.182429268956184, 51.466399133205414, 60.59744216501713, 64.44029375910759, 45.25852024555206, 41.14638090133667, 72.20238044857979, 73.13771545886993, 73.48126262426376, 75.52022561430931, 71.58303648233414, 67.8130991756916, 61.3536623865366, 56.82359866797924, 57.650001123547554, 54.58948954939842, 58.54094311594963, 61.82559326291084, 60.93040309846401, 55.777583196759224, 52.33809895813465, 48.63720014691353, 51.23424679040909, 47.46069587767124, 48.78173679113388, 46.179009452462196, 47.583322897553444, 46.659740656614304, 48.87528017163277, 47.83700868487358, 53.06955970823765, 58.80178011953831, 60.91788277029991, 61.935221180319786, 61.513474211096764, 56.357979252934456, 54.52208496630192, 54.02678154408932, 58.0668805539608, 57.87307195365429, 60.109768733382225, 64.61390644311905, 69.25986394286156, 63.94277885556221, 56.52667500078678, 51.76736958324909, 44.915695041418076, 47.4116101115942, 58.80752541124821, 60.812780410051346, 57.95734383165836, 47.70627669990063, 48.347826674580574, 46.67573779821396, 37.72131308913231, 39.72619570791721, 38.768099918961525, 41.26420497894287, 40.63940070569515, 31.094360388815403, 33.92091661691666, 33.118604868650436, 33.90252560377121, 27.481128573417664, 36.48906961083412, 57.0473762601614, 40.31004577875137, 40.92198394238949, 54.33960735797882, 48.44186022877693, 44.55506779253483, 41.422325894236565, 32.441112622618675, 20.84442749619484, 10.707086361944675, 10.808766055852175, 15.233226791024208, 23.971646390855312, 45.0759020447731, 45.69678492844105, 51.315889209508896, 35.05386762320995, 40.748454853892326, 32.83185325562954, 29.569164030253887, 41.051253005862236, 46.95675551891327, 54.15662817656994, 51.535688415169716, 49.2819419503212, 47.36068904399872, 45.91420166194439, 51.3794331997633, 55.57873986661434, 60.38529954850674, 60.017714872956276, 54.8186020553112, 52.075479850173, 57.51827359199524, 53.526074811816216, 55.81335447728634, 55.883650705218315, 54.714860022068024, 54.36948515474796, 59.06364306807518, 57.18703776597977, 58.79853129386902, 54.20413702726364, 50.49492046236992, 48.02793323993683, 44.48908433318138, 41.656746715307236, 48.17509174346924, 48.76279100775719, 46.07072286307812, 54.472414031624794, 62.06476762890816, 61.91853627562523, 63.06854456663132, 62.53607153892517, 61.33233033120632, 61.965858936309814, 59.64807070791721, 61.21074825525284, 60.5463957041502, 57.904325276613235, 62.40940913558006, 63.63434940576553, 66.82810083031654, 67.70956233143806, 68.83564710617065, 48.95513668656349, 16.91136684268713, 14.285017121583223, 59.734991043806076, 57.441308721899986, 38.25747191905975, 25.351506248116493, 35.4742618650198, 53.74205522239208, 58.59158679842949, 62.860775515437126, 34.67236049473286, 65.3186622262001, 85.71520015597343, 2.932590488344431, 0.1594973320607096, 0.3103803482372314, 0.16203866834985092, 0.12811328720999882, 0.15017358236946166, 0.10702602929086424, 0.12927033996675164, 0.23364444554317743, 0.2401603091857396, 0.21816346765263006], [0.09032177680637687, 0.025714789881021716, 0.01719250216410728, 0.057245965508627705, 0.01936390752234729, 0.026985105505445972, 0.20662627735873684, 0.03171948446833994, 0.008338110783370212, 0.07123342686099932, 0.12176517862826586, 0.32518209773115814, 0.16398454987211153, 8.465558141469955, 63.24218764901161, 44.14700008928776, 52.659364119172096, 49.93533208966255, 48.58076557517052, 23.531654700636864, 24.853142090141773, 37.49592438340187, 43.053034991025925, 50.38878835737705, 42.1867460757494, 29.027484096586704, 48.15839543938637, 65.85604459047318, 70.98006203770638, 62.81738564372063, 65.482357442379, 60.9062933921814, 61.600143760442734, 57.98223249614239, 60.692874044179916, 58.71400102972984, 60.337524712085724, 57.50502750277519, 57.523809894919395, 56.341522336006165, 54.648025408387184, 52.048835679888725, 48.98047752678394, 42.81568832695484, 40.70706367492676, 40.02212382853031, 40.68029411137104, 41.14710286259651, 40.54054521024227, 42.4055041372776, 44.26015421748161, 46.34860575199127, 50.09416736662388, 50.87037831544876, 47.58717589080334, 41.48569129407406, 45.22143043577671, 50.10088540613651, 57.66754858195782, 55.70702098309994, 55.91858223080635, 54.41330820322037, 56.555105075240135, 53.94167751073837, 48.33201952278614, 41.94753751158714, 42.99039535224438, 45.62731325626373, 52.02531114220619, 55.35973481833935, 54.5976173132658, 46.18765398859978, 34.23186533153057, 46.029381081461906, 36.186351254582405, 26.37171160429716, 39.74355697631836, 35.669104009866714, 27.62490715831518, 15.857391748577356, 10.479389280080795, 16.60817541182041, 17.782509997487068, 12.338186837732792, 6.649627508595586, 4.2766747903078794, 7.94892598874867, 12.064934950321913, 15.928699672222137, 24.73243586719036, 24.37474586069584, 23.033993504941463, 17.139008827507496, 10.213016923516989, 5.018283845856786, 3.42413994949311, 5.073940409347415, 22.524689733982086, 27.484103813767433, 36.937263160943985, 27.890845388174057, 31.842177361249924, 35.915315598249435, 28.35405383259058, 32.39323899149895, 38.086226508021355, 41.926418244838715, 42.49192290008068, 43.59716959297657, 43.72727081179619, 39.673579931259155, 38.877784833312035, 42.45201364159584, 47.489870712161064, 53.3036195486784, 51.25923804938793, 47.3278284072876, 47.84130625426769, 49.1459396481514, 50.37506349384785, 48.048193752765656, 48.204338774085045, 49.091150388121605, 50.99425546824932, 52.14617505669594, 50.730614215135574, 51.36540435254574, 46.80975280702114, 41.47194743156433, 38.985585048794746, 41.51108153164387, 40.93702353537083, 40.53695820271969, 41.00949324667454, 42.89466708898544, 44.626401364803314, 52.76208780705929, 54.483159855008125, 56.18842475116253, 56.289788112044334, 55.64904369413853, 56.54563218355179, 60.612584352493286, 59.15359564125538, 53.98116119205952, 51.32626265287399, 55.7580978423357, 59.862553998827934, 60.43837510049343, 61.75295256078243, 60.77032908797264, 27.557044699788094, 4.499658700078726, 15.95858696848154, 55.25943540036678, 39.47495698928833, 22.499214000999928, 17.57649265229702, 33.50441336631775, 38.04797016084194, 35.42145989835262, 57.70747683942318, 56.52067892253399, 46.42969720065594, 54.78020131587982, 0.4794250539271161, 0.017172334300994407, 0.022827594220871106, 0.032551951517234556, 0.01107417456296389, 0.059591196695691906, 0.004701957777797361, 0.11744147079298273, 0.03434735146583989, 0.023318901548918802, 0.026405252538097557, 0.07505585104809143, 0.08780133939580992, 0.030558060461771674, 0.08124071682686917, 0.05003809739719145, 0.0318296006298624, 0.08977205317933112, 0.042028142052004114, 0.07926344987936318, 0.07640267838723958, 0.07830640592146665, 0.20237104006810114, 0.3249229397624731, 9.209357779473066, 74.29875835776329, 44.427200853824615, 48.84113900363445, 54.15552243590355, 53.37097093462944, 27.145796567201614, 34.6248060464859, 44.93697389960289, 44.58897717297077, 54.885953441262245, 45.51789812743664, 30.662561058998108, 47.115461602807045, 71.0823829472065, 75.09135782718658, 68.80863815546036, 68.99018481373787, 66.08675301074982, 66.86942741274834, 64.18423309922218, 62.279642298817635, 63.730788230895996, 64.23367604613304, 62.778513729572296, 63.29515300691128, 60.106090530753136, 59.217116832733154, 58.53779308497906, 54.24853764474392, 46.38228714466095, 45.79883985221386, 42.92570382356644, 42.90201209485531, 44.943083971738815, 44.613402262330055, 43.03437039256096, 47.45017424225807, 45.76262779533863, 52.23956264555454, 52.73178443312645, 49.67776671051979, 45.44476345181465, 50.272279009222984, 54.82456013560295, 59.619310051202774, 59.81980249285698, 60.78414514660835, 57.985960096120834, 58.90861138701439, 54.66561086475849, 53.71148206293583, 46.13366648554802, 43.9952552318573, 48.082760497927666, 55.55184870958328, 56.6055815666914, 58.60177785158157, 49.54833805561066, 37.45790742337704, 50.379418060183525, 46.36650659143925, 39.12885636091232, 50.94523809850216, 42.9663198441267, 36.552940383553505, 23.791889436542988, 19.047350026667118, 21.53190180659294, 20.974329225718975, 18.099217303097248, 12.299360521137714, 9.578704610466957, 11.10724763944745, 12.075573429465294, 16.86073835939169, 21.624096259474754, 25.862128548324108, 30.147432200610638, 20.915658473968506, 11.801386792212725, 8.039052877575159, 8.17961398512125, 10.10623125359416, 24.6634828671813, 35.596866086125374, 43.53144071996212, 31.578754596412182, 37.26415202021599, 37.77510680258274, 30.47798216342926, 36.478129997849464, 42.0546043664217, 47.03770637512207, 46.471164375543594, 47.462740167975426, 48.20782318711281, 42.54748731851578, 40.91919869184494, 46.976294070482254, 50.728805512189865, 55.50966717302799, 53.075183406472206, 52.055120542645454, 52.85610616207123, 51.21001549065113, 52.771868482232094, 51.77010543644428, 52.12026044726372, 49.54330712556839, 52.78632290661335, 52.100140526890755, 54.237951412796974, 53.172252997756004, 52.17719279229641, 44.43964518606663, 42.666800916194916, 44.18891564011574, 43.404565528035164, 44.63606804609299, 45.10361775755882, 42.895662635564804, 49.801982045173645, 55.673328191041946, 58.194466307759285, 58.04513432085514, 59.79691632091999, 59.391022101044655, 60.172051191329956, 63.18080574274063, 64.9040512740612, 58.35746996104717, 56.4386223256588, 58.60458590090275, 63.810485154390335, 63.29161159694195, 67.79803678393364, 58.21535758674145, 22.15432930737734, 3.8237091712653637, 18.99830035865307, 60.5738378316164, 42.047251760959625, 24.166093356907368, 22.569099850952625, 32.5941152125597, 40.718208476901054, 36.78533211350441, 69.40326064825058, 70.36682054400444, 46.266826540231705, 63.35047043859959, 0.6379248504526913, 0.039807079592719674, 0.024127564211084973, 0.00755809362999571, 0.03534491297614295, 0.050410503390594386, 0.03196508710971102, 0.07233289637952112, 0.008657053385832114, 0.05388183235481847, 0.02454011297231773, 0.2975161682115868, 0.11319454555632547, 0.1007036583905574, 0.1409499187138863, 0.11734580795746297, 0.11885773346875794, 0.3241203515790403, 0.22232390299905092, 0.3055002522887662, 0.18701486173085868, 0.2794697490753606, 0.45032731373794377, 0.4238666023593396, 14.933407679200172, 88.64646166563034, 52.735485434532166, 68.49237352609634, 61.957738772034645, 64.0683089196682, 33.349738866090775, 29.07397460192442, 46.76856681704521, 52.65890434384346, 61.93468160927296, 49.389396384358406, 35.262993201613426, 52.77400016784668, 74.70894634723663, 77.8370600938797, 70.02554565668106, 72.05923452973366, 68.01571190357208, 69.2237962782383, 65.54772913455963, 66.06237351894379, 65.88277235627174, 68.12954619526863, 66.52709618210793, 66.64512544870377, 62.05808758735657, 61.63575544953346, 60.33149063587189, 55.817895233631134, 47.49554380774498, 48.93935613334179, 44.84820306301117, 45.78087821602821, 45.11591389775276, 46.5422547608614, 46.82988412678242, 50.75947746634483, 50.286942422389984, 58.61658185720444, 55.980173125863075, 53.53063456714153, 45.30520834028721, 50.04474341869354, 55.98870366811752, 62.371354177594185, 61.041265949606895, 63.52468729019165, 59.187626615166664, 63.56825195252895, 58.84089522063732, 59.08557929098606, 49.02647785842419, 45.76146125793457, 49.429013058543205, 58.67920249700546, 59.54070746898651, 64.26263809204102, 51.85531586408615, 46.71152427792549, 50.36681413650513, 44.62459646165371, 43.809616193175316, 56.649731397628784, 49.128152802586555, 44.00114871561527, 30.45621693134308, 23.69709972292185, 29.193645380437374, 27.819097638130188, 28.569422475993633, 25.3192250803113, 24.392595402896404, 25.790335200726986, 28.995411917567253, 34.08325910568237, 35.89896507561207, 34.48621988296509, 37.063309997320175, 29.851107001304626, 21.524627096951008, 15.304313376545906, 15.265515558421612, 19.739653877913952, 35.639401003718376, 44.51726742088795, 48.447582721710205, 39.785065948963165, 41.05340749025345, 40.269118174910545, 34.13734920322895, 38.352022245526314, 44.884806498885155, 52.195583805441856, 51.5872098505497, 49.88531157374382, 53.35624672472477, 45.97146078944206, 43.47435638308525, 49.19540539383888, 55.15103481709957, 60.47363720834255, 59.21700283885002, 54.57234866917133, 57.34067112207413, 55.61640724539757, 58.05566355586052, 54.577539190649986, 53.845174089074135, 51.25358775258064, 52.65457257628441, 56.619906798005104, 57.909409403800964, 56.65258124470711, 55.575878620147705, 47.512027323246, 44.53476168215275, 47.355696111917496, 45.577091351151466, 47.676569893956184, 45.55268906056881, 46.1431659758091, 52.29120187461376, 59.12575073540211, 59.51543502509594, 60.146075785160065, 62.57583260536194, 63.766589909791946, 61.94662816822529, 66.99173524975777, 68.5420748591423, 61.089090183377266, 59.95880663394928, 64.82585906982422, 67.61645972728729, 68.75580579042435, 69.53912615776062, 63.23500603437424, 30.02897545695305, 6.2610655836761, 17.97955222427845, 66.4138014614582, 48.862775042653084, 32.567604035139084, 24.497450776398182, 44.11564417183399, 54.43392589688301, 48.32188166677952, 72.77133151888847, 80.4495719075203, 60.66681504249573, 76.39415591955185, 1.2163133081048727, 0.25639171712100506, 0.14572905289242044, 0.13480278372298926, 0.09794882105779834, 0.19929905334720388, 0.1983030021074228, 0.275077095720917, 0.09921156306518242, 0.20585052523529157, 0.1686770308879204], [0.028375923648127355, 0.04053458098496776, 0.07867451859056018, 0.04428729153005406, 0.09952263426384889, 0.10436983822728507, 0.027273244340904057, 0.12483903556130826, 0.03087805784161901, 0.024296237679664046, 0.067161002807552, 0.1928305535693653, 0.23271242680493742, 4.222769932821393, 58.492993488907814, 54.59357813000679, 50.75316980481148, 55.0965191423893, 45.288398042321205, 28.465104773640633, 21.446486189961433, 36.73571817576885, 37.82990746200085, 42.621556743979454, 38.76344136893749, 26.602611914277077, 23.65423422306776, 39.503808841109276, 61.45228609442711, 66.60411044955254, 63.69407080113888, 62.22503922879696, 62.75142498314381, 60.3840684145689, 58.852355405688286, 62.19633936882019, 60.04345469176769, 59.86358754336834, 59.46421757340431, 57.11396008729935, 58.771662935614586, 57.46976159512997, 56.519364193081856, 52.68978528678417, 45.85349231958389, 43.74637618660927, 42.31439642608166, 41.79230444133282, 42.06149339675903, 41.35085552930832, 42.06067644059658, 41.629236191511154, 45.71455277502537, 42.238487899303436, 44.18688654899597, 46.00276730954647, 50.64948096871376, 52.403094470500946, 54.432994946837425, 55.83331100642681, 55.62208034098148, 52.609506994485855, 54.168871119618416, 49.65434096753597, 46.87673561275005, 44.36989612877369, 43.87156426906586, 42.24119335412979, 48.90854358673096, 49.783777222037315, 52.60039508342743, 46.69304206967354, 35.12162558734417, 32.95716293156147, 42.43073098361492, 48.37224416434765, 42.7094080299139, 37.361100018024445, 29.99594382941723, 16.935966722667217, 17.13379930704832, 13.853353634476662, 10.468748901039362, 6.788010383024812, 2.390725314617157, 1.3070305902510881, 1.8182090856134892, 2.238394101150334, 1.1711410945281386, 2.8385994443669915, 7.283020745962858, 15.65343389287591, 19.289543330669403, 13.999330401420593, 4.2655090894550085, 4.596944879740477, 14.066710285842419, 26.3359859213233, 29.036436416208744, 22.908607833087444, 32.25723668932915, 37.16549031436443, 34.66263681650162, 30.62586832791567, 34.88751634955406, 35.99465914070606, 39.45740193128586, 42.697062492370605, 40.953100472688675, 41.425130143761635, 37.797799184918404, 38.1361748278141, 40.1058105379343, 44.78961020708084, 47.53029674291611, 48.11825819313526, 51.040350794792175, 49.986872524023056, 48.38514067232609, 47.676132917404175, 49.249225705862045, 53.43768395483494, 50.714313089847565, 49.2130858451128, 49.763463512063026, 51.22863829135895, 46.3681823015213, 43.82059000432491, 40.896384716033936, 41.31086267530918, 39.77322958409786, 43.14379312098026, 46.08089491724968, 47.13307365775108, 46.03701867163181, 45.406856685876846, 49.91128318011761, 52.92460508644581, 53.80857825279236, 55.56778125464916, 55.30279107391834, 57.07798361778259, 56.82139478623867, 59.32000391185284, 56.88279949128628, 54.782150611281395, 53.62809933722019, 58.32211285829544, 57.712883949279785, 66.90708339214325, 47.11735010147095, 10.040357988327742, 1.993685094639659, 26.02315440773964, 55.87913274765015, 38.86921249330044, 24.28767543286085, 13.919649627059698, 31.706684231758118, 33.22356663644314, 42.52805136144161, 38.72433006763458, 63.85922133922577, 44.1547554731369, 52.37208433449268, 0.5053471145220101, 0.02565441987826489, 0.05655379776726477, 0.05002900608815253, 0.042111077054869384, 0.06752945686457679, 0.016968763193290215, 0.13313317409483716, 0.03792243267525919, 0.05174238387553487, 0.028618249707506038, 0.022053281863918528, 0.06707484688377008, 0.06186953069118317, 0.08737720199860632, 0.012860100996476831, 0.04709872504463419, 0.09805488880374469, 0.08874111357727088, 0.11102118834969588, 0.1709461770951748, 0.08878435852238908, 0.21630875155096874, 0.3188446315471083, 4.7426418866962194, 64.46294814348221, 61.87445864081383, 54.393146485090256, 59.466562047600746, 51.21133781969547, 30.726787112653255, 29.117499366402626, 43.431038707494736, 40.94135910272598, 47.694474533200264, 41.763722375035286, 29.222768917679787, 24.693592451512814, 38.49655129015446, 60.76068140566349, 68.23968708515167, 69.13249477744102, 63.104300647974014, 66.13447844982147, 62.01246723532677, 63.075840175151825, 62.64768674969673, 64.07274708151817, 63.697205632925034, 62.19057887792587, 61.54015637934208, 62.80662462115288, 61.63529187440872, 59.77896988391876, 58.421409130096436, 50.43237201869488, 46.330351531505585, 46.00663170218468, 45.86763136088848, 46.438227742910385, 44.23812299966812, 46.32629334926605, 46.86826966702938, 46.89970538020134, 45.20254924893379, 48.003371357917786, 49.74933207035065, 53.7802317738533, 56.41524598002434, 57.561617866158485, 59.57293353974819, 56.44614592194557, 57.6289464533329, 56.78715102374554, 53.72605808079243, 50.98804660141468, 47.833178490400314, 49.07263398170471, 46.18682183325291, 53.177234530448914, 54.11407046020031, 55.08292727172375, 52.84634828567505, 38.523415848612785, 38.496292904019356, 46.45375370979309, 51.953255608677864, 51.04204550385475, 43.40256683528423, 32.51512885093689, 21.315037943422794, 17.588397413492203, 16.50452457368374, 11.68693883344531, 9.634198732674122, 6.746820593252778, 5.2528685331344604, 3.2732110982760787, 2.781467135064304, 2.770227575674653, 3.67894287686795, 8.721804991364479, 18.765224665403366, 23.06503403931856, 14.716724306344986, 6.5611060336232185, 5.299323415383697, 17.799544483423233, 29.214886240661144, 34.55188035964966, 28.15839473158121, 37.190352380275726, 41.567478105425835, 38.784830421209335, 32.46426858007908, 39.47198174893856, 41.38229884207249, 46.95656172931194, 45.92480309307575, 45.790731087327, 42.46957249939442, 41.58230870962143, 41.4778371155262, 42.63240896165371, 47.40855887532234, 50.5054496973753, 50.021788850426674, 52.96839013695717, 52.907836586236954, 53.48693311214447, 50.39687432348728, 53.593475595116615, 54.40935641527176, 53.727942779660225, 54.86706465482712, 55.08128196001053, 55.10043293237686, 51.13892510533333, 46.50738023221493, 45.06280034780502, 43.191799744963646, 43.7117600440979, 47.68727771937847, 51.66388973593712, 51.36272929608822, 50.476943626999855, 50.07372826337814, 52.39529728889465, 55.76146826148033, 57.74649694561958, 57.87535183131695, 58.400141671299934, 60.22854655981064, 59.83348175883293, 62.718264162540436, 61.498400419950485, 58.4711142629385, 59.30440194904804, 62.351811826229095, 63.692482486367226, 65.4573167860508, 38.647669181227684, 5.954327518120408, 3.1858818093314767, 31.832721568644047, 58.012338280677795, 42.58005537092686, 28.812128752470016, 20.21595261991024, 33.54884818196297, 33.23714330792427, 44.03956465423107, 44.65038187801838, 61.372277587652206, 54.677842408418655, 62.30524152517319, 1.2462697131559253, 0.07652918488020077, 0.008445632211078191, 0.028291096168686636, 0.06854634018964134, 0.06382243664120324, 0.06378883961588144, 0.06303564878180623, 0.007246553486766061, 0.01978336938918801, 0.03868319712637458, 0.11290854410617612, 0.11987879508524202, 0.07734585902653635, 0.14187079039402306, 0.16641600377624854, 0.19608850765507668, 0.18284831108758226, 0.4108409903710708, 0.15471169666852802, 0.32554895617067814, 0.19217744877096266, 0.29796261456795037, 0.6143357162363827, 6.081229783594608, 81.3041764497757, 63.27446311712265, 61.49566076695919, 68.8629524409771, 58.189484775066376, 39.220518842339516, 25.901393741369247, 43.89353469014168, 46.59058436751366, 51.982411444187164, 45.522750467062, 32.75356985628605, 31.153437718749046, 47.6692970842123, 69.84470576047897, 70.89923277497292, 69.37381222844124, 66.25946894288063, 68.36700305342674, 62.57620878517628, 65.14859095215797, 66.4073646068573, 64.85998123884201, 66.12741842865944, 65.71884915232658, 64.875917583704, 64.55355048179626, 64.02781829237938, 62.20464572310448, 59.21286106109619, 52.25078724324703, 49.673301950097084, 48.77458557486534, 48.34673993289471, 50.421838983893394, 47.31026954948902, 48.223117366433144, 48.46050962805748, 52.141679897904396, 47.25178688764572, 49.15547713637352, 51.895795091986656, 56.62206508219242, 58.34593378007412, 60.52383251488209, 63.51759687066078, 60.264876410365105, 59.505312368273735, 60.88831275701523, 57.09666721522808, 51.09773151576519, 49.952313378453255, 50.88829815387726, 47.92576812207699, 56.58910185098648, 54.868333786726, 59.28219214081764, 53.374972119927406, 44.08941797912121, 40.10830320417881, 46.144526302814484, 56.09007082879543, 52.95748092234135, 53.792041540145874, 43.54629032313824, 34.494818821549416, 37.56836749613285, 31.410398930311203, 26.71161286532879, 23.769917115569115, 20.847976505756378, 21.847773157060146, 17.2993241250515, 15.667337346822023, 16.44156575202942, 19.80796091258526, 21.267284005880356, 29.98754058033228, 33.81056293845177, 17.814280092716217, 7.419497547671199, 6.922210156917572, 20.29611311852932, 32.9234017431736, 37.230713814496994, 36.07612296938896, 39.62133273482323, 46.69080778956413, 38.32129329442978, 33.98627690970898, 43.23484003543854, 45.33259727060795, 49.22334149479866, 49.25555236637592, 47.37804651260376, 49.202704802155495, 42.79779128730297, 44.34528484940529, 44.42008003592491, 51.328759118914604, 54.077022448182106, 54.09572124481201, 56.39878906309605, 56.68969385325909, 57.04100780189037, 53.853982016444206, 55.29523327946663, 58.719738721847534, 56.58437490463257, 56.78366281092167, 56.696791872382164, 55.39072975516319, 51.87301531434059, 50.786661207675934, 47.568256705999374, 46.675084233284, 44.60162289440632, 48.7625440210104, 52.40174554288387, 50.98649628460407, 50.09319841861725, 50.858169570565224, 56.45310714840889, 59.286706298589706, 59.45547044277191, 60.668897330760956, 61.7971707880497, 63.70252154767513, 61.896786242723465, 67.16625228524208, 66.29799887537956, 62.8378551453352, 61.28766752779484, 67.88328900933266, 66.40570029616356, 70.64870461821556, 50.74895963072777, 12.02840181067586, 3.4740184480324388, 31.32329050451517, 65.54591283202171, 52.29967541992664, 33.58004830777645, 19.201256968080997, 45.20660363137722, 42.808658704161644, 59.43001940846443, 49.10787709057331, 81.341992020607, 61.036858186125755, 75.96330463886261, 1.9011794147081673, 0.1882794516859576, 0.13878272875444964, 0.1332963872118853, 0.24275040457723662, 0.14883872587233782, 0.17834040219895542, 0.1633607895928435, 0.1805810202495195, 0.18094942235620692, 0.19021038635401055], [0.08199011528631672, 0.06850678371847607, 0.08136841817758977, 0.04094091054867022, 0.09973278079996817, 0.008634733294456964, 0.029637867846759036, 0.0851841110852547, 0.04221058050461579, 0.17361850244924426, 0.029356768282013945, 0.08210203115595505, 0.06351312433253042, 1.8831351329572499, 55.05368024110794, 50.036410465836525, 33.50589908659458, 56.52639381587505, 48.07068474590778, 34.704875349998474, 20.726635716855526, 23.04870631545782, 42.37050801515579, 48.162928596138954, 46.649553403258324, 20.972058847546577, 20.076302513480186, 25.275770612061024, 34.75176863372326, 52.01361536979675, 62.89804391562939, 60.7907035946846, 61.641014367341995, 61.109799072146416, 58.82410392165184, 56.63054242730141, 60.524516478180885, 60.325023382902145, 60.55652216076851, 57.63162910938263, 60.69801136851311, 60.61959117650986, 58.5343998670578, 58.143530040979385, 55.387670919299126, 44.618410393595695, 43.11203822493553, 42.658851742744446, 43.830469474196434, 43.359974920749664, 44.86547693610191, 43.154968321323395, 42.07388453185558, 42.589459866285324, 45.094410851597786, 47.608139365911484, 53.85002262890339, 54.74782705307007, 56.62936069071293, 55.17149291932583, 54.300344064831734, 54.94576223194599, 52.55553089082241, 51.02264754474163, 49.92383390665054, 44.18221279978752, 47.29814060032368, 43.87730956077576, 47.69158288836479, 50.85783138871193, 49.761301428079605, 47.78502747416496, 38.321753069758415, 30.007329918444157, 36.19531497359276, 38.18448543548584, 47.49275855720043, 29.21728391200304, 20.699187889695168, 7.991847060620785, 5.962752141058445, 9.045588467270136, 2.943319450132549, 1.6374221490696073, 2.2640391625463963, 1.881079562008381, 1.1671678139828146, 2.333542895503342, 2.4811785109341145, 3.5473281517624855, 1.5396737004630268, 0.49990254105068743, 1.5610837703570724, 3.7053600093349814, 1.9595320522785187, 1.6054633702151477, 9.753043055534363, 20.399140790104866, 27.002679146826267, 32.922892570495605, 27.65359751880169, 39.13817346096039, 37.01998472213745, 33.77806328237057, 37.11257055401802, 36.60077601671219, 39.21419598162174, 41.637177765369415, 40.31072594225407, 38.742975667119026, 36.91546753048897, 37.71287374198437, 42.20761835575104, 46.39636538922787, 48.73786434531212, 46.58862367272377, 50.5920622497797, 50.669654086232185, 49.18608069419861, 48.18880520761013, 48.93128536641598, 50.79082578420639, 52.318172827363014, 53.420584872365, 51.38200186192989, 48.513045608997345, 43.45614016056061, 41.26959688961506, 42.1873464435339, 42.050397992134094, 44.98825594782829, 52.44173839688301, 53.648082464933395, 55.50903260707855, 54.62662495672703, 51.17538794875145, 49.23116907477379, 53.6910467594862, 57.354270592331886, 57.94686399400234, 57.26357325911522, 57.15495988726616, 59.938401728868484, 59.41564477980137, 56.35326750576496, 54.53848488628864, 54.808502197265625, 56.993468552827835, 56.38077802956104, 57.467968091368675, 16.270926408469677, 0.5121969000902027, 5.285408087074757, 38.15901540219784, 51.76138490438461, 37.02632278203964, 17.51885164529085, 18.190832287073135, 34.85283561050892, 39.779620841145515, 37.564571499824524, 33.54252532124519, 58.59111562371254, 40.725420489907265, 51.84760607779026, 0.7161906163673848, 0.0770374372950755, 0.008216711194108939, 0.014366272080224007, 0.07698847039137036, 0.04485694553295616, 0.03437198705796618, 0.06115526921348646, 0.04783516931638587, 0.029734946328972, 0.06295094746747054, 0.03696016770845745, 0.07931045009172522, 0.026068504885188304, 0.07104358548531309, 0.09507404523901641, 0.02877512488339562, 0.05753697645559441, 0.07098235830198973, 0.11348336716764607, 0.04139328666497022, 0.02226777924079215, 0.08576093052397482, 0.19369119254406542, 2.6071386644616723, 62.35780410468578, 55.95233201980591, 41.994746178388596, 59.60606776177883, 50.04781365394592, 33.971784487366676, 25.44771708548069, 29.56696394830942, 52.185164764523506, 50.8383384346962, 52.88640193641186, 23.834979124367237, 27.002130076289177, 30.85715811699629, 40.796765461564064, 55.37704288959503, 65.43470799922943, 65.18070682883263, 67.30517283082008, 61.22308239340782, 61.39137156307697, 59.5658241212368, 61.71693429350853, 63.09331163764, 62.42467671632767, 60.91395378112793, 62.76465207338333, 62.04986862838268, 62.618637308478355, 59.77336138486862, 59.18300226330757, 48.68420362472534, 45.02439200878143, 46.70846164226532, 45.751509591937065, 47.11633935570717, 46.25340946018696, 45.937452614307404, 45.86231544613838, 48.249161168932915, 48.26608546078205, 50.818777084350586, 58.11190813779831, 57.957910001277924, 58.32383416593075, 57.31694899499416, 56.82585194706917, 56.67498104274273, 58.222250416874886, 53.96254979074001, 52.071577459573746, 48.05746905505657, 49.777568355202675, 46.267400309443474, 50.95724545419216, 52.885258197784424, 53.112288415431976, 51.87214136123657, 43.525330647826195, 35.68793959915638, 46.05976045131683, 42.311675772070885, 50.12515850365162, 37.30614736676216, 29.446812495589256, 17.521359510719776, 5.189121253788471, 6.361840451136231, 4.752480033785105, 7.71923353895545, 5.902494974434376, 3.2324654096737504, 2.7723879972472787, 2.925986680202186, 2.9474381916224957, 5.355319585651159, 3.014305103570223, 1.0173321166075766, 3.484745272435248, 2.98419076949358, 2.5500526651740074, 2.338958317413926, 11.591457556933165, 23.459247685968876, 32.44112402200699, 39.181817919015884, 29.516743943095207, 45.266359224915504, 40.0432924926281, 37.39060163497925, 40.24851568043232, 41.15888223052025, 44.457025453448296, 46.47936053574085, 46.24374657869339, 42.09205895662308, 42.31913097202778, 42.16274656355381, 45.95701776444912, 48.961022570729256, 51.59819506108761, 50.735048577189445, 52.456447407603264, 54.240782260894775, 51.27403825521469, 50.730640813708305, 51.37724831700325, 52.289909943938255, 52.70928584039211, 55.38846127688885, 51.7062346637249, 49.0635334700346, 45.318196043372154, 44.81156162917614, 45.922447219491005, 45.57642638683319, 47.93261915445328, 54.99812722206116, 60.13219892978668, 59.97868336737156, 57.07100339233875, 56.247975155711174, 54.84782248735428, 58.62472862005234, 59.27421636879444, 60.96807047724724, 61.840670853853226, 60.770169496536255, 61.215042024850845, 61.04208670556545, 60.808707028627396, 60.15744857490063, 59.60503041744232, 60.75107932090759, 60.16918994486332, 58.4900638461113, 11.39263417571783, 0.570870857918635, 7.914520259946585, 45.75929917395115, 56.47359184920788, 40.15316739678383, 23.205155320465565, 24.752616584300995, 34.286639392375946, 42.00382389128208, 39.552849009633064, 44.60977345705032, 66.21199429035187, 46.1640078574419, 61.374599263072014, 1.1765605537220836, 0.04460542797460221, 0.0383805381716229, 0.011277744742983487, 0.053845411457587034, 0.06278384549659677, 0.03128685690171551, 0.0410481212020386, 0.04675969714298844, 0.006845757097835303, 0.02828541873896029, 0.2343548441422172, 0.21382476843427867, 0.13583592750364915, 0.13829387607984245, 0.24097584042465314, 0.09516518097370863, 0.11660638396278955, 0.27493780944496393, 0.25050761410966516, 0.28831000439822674, 0.14659393695183098, 0.1691344313439913, 0.5640041513834149, 3.8949560606852174, 72.19310894608498, 60.7635198533535, 42.11380518972874, 68.98323878645897, 60.8852881193161, 44.8871623724699, 28.87906026095152, 27.57830075919628, 54.799660071730614, 57.598156705498695, 55.43502017855644, 25.700185038149357, 30.206403136253357, 35.12391686439514, 47.41773158311844, 61.01816698908806, 70.33596619963646, 66.9798418879509, 67.71078586578369, 64.87679153680801, 62.69651412963867, 59.80057932436466, 64.40584480762482, 66.29840925335884, 65.31933858990669, 63.589527010917664, 66.84681862592697, 65.77081516385078, 65.93390241265297, 62.88260154426098, 61.61733403801918, 50.07215514779091, 47.99934737384319, 47.749297991395, 49.13133703172207, 49.532242119312286, 50.77820286154747, 48.56800206005573, 47.767947390675545, 49.098799377679825, 49.90015737712383, 53.615917190909386, 60.89502699673176, 62.15377025306225, 62.002526968717575, 58.8300696015358, 59.26265738904476, 58.37430685758591, 60.01158580183983, 57.120279148221016, 54.342457205057144, 50.67810483276844, 53.88453997671604, 48.772317096590996, 53.303908333182335, 56.522210240364075, 58.30622971057892, 53.05062532424927, 48.5876128077507, 37.00658284127712, 46.58913664519787, 49.83021833002567, 58.90551075339317, 47.04172655940056, 40.31319960951805, 26.983305886387825, 13.780709132552147, 17.275102324783802, 13.881875853985548, 15.464127101004124, 15.395386889576912, 10.06676372140646, 10.859218798577785, 8.502697348594666, 5.980310998857021, 7.051011370494962, 4.873250378295779, 4.534665271639824, 6.144203804433346, 6.316976258531213, 3.567262119613588, 3.3161970041692257, 11.71379579231143, 28.341290317475796, 40.373692363500595, 43.866373747587204, 33.507616594433784, 46.732331961393356, 40.13336665928364, 40.70316508412361, 45.529582500457764, 44.71217796206474, 45.44110804796219, 51.24123461544514, 49.00620214641094, 45.62384404242039, 44.22842592000961, 42.682140693068504, 50.639932081103325, 52.578249871730804, 55.88830545544624, 52.26894646883011, 54.75330635905266, 58.105019107460976, 54.11890760064125, 54.10170592367649, 54.834185019135475, 55.533389300107956, 57.38221809267998, 59.152752086520195, 57.11341291666031, 56.09284088015556, 48.01141932606697, 47.697263583540916, 48.25960300862789, 48.8893736153841, 48.92948426306248, 56.7233220487833, 61.22934065759182, 62.05223590135574, 61.488676741719246, 58.31202819943428, 56.294093281030655, 60.562100261449814, 63.472725078463554, 65.49045860767365, 65.42720720171928, 63.197847828269005, 65.29003456234932, 67.639699280262, 63.60339246690273, 63.28207790851593, 63.60583953559399, 68.67079675197601, 65.15039965510368, 67.35956311225891, 19.189916476607323, 1.0889756097458303, 6.988197416067123, 46.24994024634361, 64.05839145183563, 48.7527671456337, 24.487746097147465, 25.215579941868782, 46.8895523250103, 54.00758117437363, 54.486701264977455, 44.4614864140749, 74.52173039317131, 51.28559723496437, 80.03154873847961, 2.4165501538664103, 0.20444430381758139, 0.10668383984011598, 0.1554748322814703, 0.16510645451489836, 0.20250330562703311, 0.15922347956802696, 0.25017866457346827, 0.12870749516878277, 0.14022930816281587, 0.11915448121726513], [0.08513592343661003, 0.016575205991102848, 0.09034554779645987, 0.13014770695008337, 0.04723820056824479, 0.08679921738803387, 0.05251390204648487, 0.11400983930798247, 0.10022589340223931, 0.02369873644056497, 0.059272744838381186, 0.3424214757978916, 0.15186483302386478, 4.6538150031119585, 60.150491148233414, 56.96156546473503, 41.269319504499435, 50.57415001094341, 52.66638994216919, 33.42022128403187, 35.1728468388319, 17.210456393659115, 32.35159322619438, 49.65892352163792, 51.98318660259247, 25.455831550061703, 24.267293326556683, 32.68357761204243, 33.366366773843765, 44.80556555092335, 49.78443078696728, 57.02623799443245, 61.770465821027756, 59.332246854901314, 59.136948734521866, 61.241245418787, 58.1841004639864, 58.11914674937725, 60.06311483681202, 53.38245391845703, 55.01196227967739, 56.8221889436245, 58.07676762342453, 58.023486882448196, 57.76432938873768, 49.21559751033783, 44.7089671343565, 44.09976862370968, 42.24269047379494, 44.011681750416756, 42.963090017437935, 40.21203003823757, 44.59746591746807, 44.08387787640095, 46.85142897069454, 51.09056510031223, 53.82594332098961, 52.658832147717476, 54.019884914159775, 56.573173105716705, 53.31103675067425, 53.632191717624664, 54.89338584244251, 48.85064609348774, 46.551609858870506, 44.20104078948498, 46.12141594290733, 44.06554386019707, 45.48199765384197, 48.34429286420345, 49.441180005669594, 46.35970115661621, 42.87189111113548, 28.420816250145435, 37.85261504352093, 33.9447907358408, 38.14063958823681, 28.975012712180614, 17.61556975543499, 7.3402998223900795, 5.3393343184143305, 2.3976238444447517, 0.7874592358712107, 1.0291188466362655, 0.8196448744274676, 0.42859912966378033, 0.6534667883533984, 0.7870729034766555, 1.1181842861697078, 0.5781857029069215, 0.32610826834570616, 0.04359507183835376, 0.044367829395923764, 1.475425441749394, 3.2651852164417505, 1.362346715759486, 5.596212884411216, 30.45695599168539, 29.697815626859665, 25.613576285541058, 21.915500722825527, 26.251379661262035, 41.14532455801964, 38.038368076086044, 35.80064155161381, 38.86090613901615, 40.47967627644539, 40.17893001437187, 38.5931421071291, 38.49139876663685, 37.514030411839485, 38.72429586946964, 40.43021433055401, 47.584652826189995, 47.28982284665108, 47.796639651060104, 47.869477942585945, 48.59607495367527, 47.3972012847662, 47.257304191589355, 44.48800139129162, 46.02838933467865, 46.74007594585419, 47.16424338519573, 44.02879223227501, 42.94456601142883, 41.76500290632248, 43.880558386445045, 39.74780134856701, 44.93444323539734, 51.63982182741165, 54.804318621754646, 56.80060990154743, 57.59609341621399, 55.589497089385986, 57.12137348949909, 54.73594889044762, 55.53357928991318, 56.9065748155117, 58.13335798680782, 60.196001306176186, 58.091769218444824, 56.37263506650925, 57.7886176854372, 60.73680728673935, 57.24642477929592, 57.14142881333828, 51.32299102842808, 50.91439135372639, 39.737431704998016, 2.507491623982787, 0.48853352142032236, 12.674362398684025, 55.935951098799706, 43.56208607554436, 37.92289987206459, 13.84449440985918, 31.497611850500107, 34.722567200660706, 40.96971318125725, 31.355375982820988, 44.73014339804649, 69.69326108694077, 35.154189839959145, 50.70830941200256, 0.1719881672761403, 0.055743305711075664, 0.05348869817680679, 0.07058016621158458, 0.017879211409308482, 0.01048429889124236, 0.04113098941161297, 0.03157713312248234, 0.06944793087313883, 0.04955698532285169, 0.07450120698194951, 0.10831301726284437, 0.06074939978134353, 0.07665474142413586, 0.07197332583018579, 0.06452516885474324, 0.1084753026952967, 0.08952744872658513, 0.10748822402092628, 0.1298520204727538, 0.08411158152739517, 0.03986104486102704, 0.3317875385982916, 0.3492873511277139, 6.618202719837427, 70.67164778709412, 60.17661854624748, 47.205072194337845, 50.36549560725689, 55.26179127395153, 31.804097704589367, 33.67180198431015, 20.90900883078575, 37.17982694506645, 53.03110957145691, 58.35004895925522, 28.895676769316196, 26.799447052180767, 40.688581466674805, 47.01387785375118, 53.37718740105629, 54.94241461157799, 59.26841787993908, 62.89097249507904, 63.812347054481506, 64.08565878868103, 62.80459173023701, 61.85234762728214, 60.44849395751953, 61.36979632079601, 57.29979291558266, 57.08194300532341, 57.133475840091705, 60.82189232110977, 61.250216737389565, 61.80285528302193, 54.42487858235836, 47.47936047613621, 46.84971906244755, 44.43162761628628, 45.81075221300125, 43.23534160852432, 43.76230873167515, 45.56680530309677, 49.411218613386154, 48.67609106004238, 55.08493736386299, 55.523878410458565, 57.209794744849205, 58.23065556585789, 56.757881194353104, 54.92819957435131, 56.18815876543522, 57.10838958621025, 53.8929945230484, 49.32217799127102, 48.36287386715412, 49.457329139113426, 47.45455160737038, 47.97853209078312, 51.53471186757088, 52.68936350941658, 49.65372920036316, 47.15442091226578, 35.026737079024315, 45.563944056630135, 43.20364750921726, 40.65870746970177, 35.842640697956085, 24.26149293780327, 15.044665709137917, 9.455527570098639, 0.73019755538553, 2.356924465857446, 1.9035912165418267, 1.3727797684259713, 0.7653229299467057, 0.8913892402779311, 1.8581365118734539, 1.8545211246237159, 2.6118862722069025, 0.35800776444375515, 0.03922263829736039, 0.021032496697444003, 1.3533067633397877, 2.5675910990685225, 2.5043774535879493, 7.341495808213949, 36.828288808465004, 34.53597441315651, 30.13419561088085, 25.778276547789574, 34.380072578787804, 46.081483885645866, 39.64228481054306, 42.2797042876482, 42.368691712617874, 45.543827936053276, 44.221069514751434, 45.46500116586685, 41.962957084178925, 42.22067445516586, 41.40710391104221, 44.57206808030605, 49.31856818497181, 50.83517700433731, 51.25484548509121, 51.93573094904423, 50.660538375377655, 52.25751668214798, 50.879361033439636, 49.124440401792526, 47.842833772301674, 48.120876252651215, 48.50551061332226, 47.28577986359596, 45.365446507930756, 45.47201178967953, 46.28169134259224, 41.90632112324238, 46.75505094230175, 56.38799004256725, 58.589010536670685, 58.07815834879875, 61.745485961437225, 58.75612556934357, 59.76695492863655, 58.08566674590111, 60.54194234311581, 60.62316678464413, 59.810804575681686, 62.39289902150631, 62.00316533446312, 61.546129658818245, 61.87348209321499, 64.31483209133148, 62.38098286092281, 61.545571088790894, 57.35014021396637, 56.85298629105091, 37.635198310017586, 1.5555503172799945, 1.1311532277613878, 16.333301961421967, 62.32783891260624, 48.37814524769783, 43.139301761984825, 20.147423297166824, 34.38059315085411, 34.82820153236389, 41.68256253004074, 34.80303928256035, 43.27104829251766, 62.46952570974827, 39.261765629053116, 62.6716672629118, 0.7679813029244542, 0.03366888005984947, 0.04455701768165454, 0.06532653991598636, 0.03216514043742791, 0.06727728992700577, 0.015100636483111884, 0.02511298418539809, 0.05131751546286978, 0.01832760219258489, 0.019855428217852022, 0.277193968067877, 0.21606082969810814, 0.2463450562208891, 0.23783190990798175, 0.1860400359146297, 0.19689963053679094, 0.17092266585677862, 0.3478482080390677, 0.35792164562735707, 0.228669369535055, 0.2940235025016591, 0.4917531955288723, 0.5905329622328281, 6.866716984659433, 80.24087950587273, 67.10046261548996, 53.67606796324253, 64.55826982855797, 64.632388651371, 44.87620756030083, 45.10904386639595, 23.105064891278744, 41.357197389006615, 57.134007811546326, 61.1531737446785, 30.440571270883083, 30.97530707716942, 44.004606530070305, 54.34263959527016, 61.553307473659515, 60.80225497484207, 67.17478662729263, 68.42122614383698, 66.82867079973221, 65.74240788817406, 63.69937911629677, 61.74632951617241, 62.80054114758968, 66.002526730299, 59.88912217319012, 61.406517550349236, 61.31232060492039, 63.86387228965759, 63.75790357589722, 64.26874056458473, 55.46094238758087, 51.05127900838852, 50.20646274089813, 47.233798652887344, 47.64448061585426, 46.617851704359055, 44.922135695815086, 49.40392680466175, 52.1375647187233, 52.31946475803852, 57.74115063250065, 59.37685266137123, 57.6992616802454, 59.85912658274174, 60.25875113904476, 56.510624662041664, 59.461466521024704, 59.54184740781784, 56.614488288760185, 50.51948994398117, 50.90156324207783, 53.353780657052994, 50.661233738064766, 51.407601088285446, 55.022898092865944, 56.76200017333031, 52.6108293235302, 51.62337251007557, 37.59814649820328, 44.89120155572891, 47.44343340396881, 50.06077855825424, 43.50596308708191, 39.39814791083336, 26.301552169024944, 12.5346077978611, 1.9139919709414244, 3.722295225597918, 2.8849108843132854, 2.07827924285084, 1.500318618491292, 2.4368823878467083, 3.1861895928159356, 3.106415248475969, 3.9385050488635898, 1.3113136729225516, 0.09475694780121557, 0.13364791288040578, 3.9864762872457504, 11.693569477647543, 5.664470521733165, 11.686841938644648, 43.81234064698219, 37.18326956033707, 34.85009975731373, 28.864083364605904, 36.02087773382664, 47.049003168940544, 44.73786078393459, 43.2541885972023, 45.3010855615139, 50.77585078775883, 50.53043335676193, 47.81214281916618, 49.28711347281933, 43.402430042624474, 45.72811804711819, 46.953278705477715, 51.84182658791542, 55.87612330913544, 54.74272392690182, 54.143032506108284, 55.12103922665119, 54.88465391099453, 54.768627136945724, 53.10789205133915, 54.147740453481674, 52.6445335149765, 55.43464779853821, 50.098373740911484, 49.89979639649391, 48.57985362410545, 49.119071289896965, 45.02233251929283, 49.59194451570511, 56.81527331471443, 60.936391577124596, 61.90305970609188, 64.6568213403225, 63.09180311858654, 64.70391601324081, 62.60689213871956, 62.95198202133179, 63.50597329437733, 63.3855539560318, 67.04839020967484, 65.61666503548622, 62.46332064270973, 63.804884254932404, 69.29631918668747, 65.78384086489677, 62.699637562036514, 63.70165139436722, 63.59969146549702, 48.458077758550644, 2.8786590322852135, 1.2409756472334266, 15.568083822727203, 65.14593869447708, 56.34524993598461, 50.13490118086338, 19.159168526530266, 44.18092466890812, 48.390076607465744, 53.26000548899174, 44.84190300107002, 52.87721022963524, 84.59442749619484, 47.24154643714428, 79.22189578413963, 1.7911817296408117, 0.24820401740726084, 0.16224526742007583, 0.10721075726905838, 0.08943404944147915, 0.1867146629956551, 0.10727067827247083, 0.22056557703763247, 0.38973051065113395, 0.15119595016585663, 0.18774163210764527], [0.08787440383457579, 0.04966602165950462, 0.08463696271064691, 0.050964368201675825, 0.02332005929929437, 0.03406703857763205, 0.050423127322574146, 0.09556445642374456, 0.08166950749000534, 0.08976558165159076, 0.02425922306429129, 0.37846120598260313, 0.3296314214821905, 8.213254529982805, 69.74919408559799, 50.331088453531265, 38.029073774814606, 50.005050748586655, 54.888354912400246, 31.949692592024803, 33.16465079784393, 21.429991275072098, 25.437389239668846, 42.385490611195564, 57.360289469361305, 29.469949454069138, 22.26929783821106, 36.65295861661434, 45.160147324204445, 44.98524650931358, 47.270158901810646, 51.46326810121536, 52.46612548828125, 57.28078253567219, 57.42396645247936, 59.90997925400734, 62.01044574379921, 58.536675944924355, 56.87428794801235, 57.488916367292404, 52.53076381981373, 51.46603435277939, 60.34001737833023, 58.101090118288994, 60.57986430823803, 50.937174931168556, 44.65133182704449, 44.6104422211647, 44.06190365552902, 41.64749041199684, 42.83318258821964, 42.49818116426468, 42.935864478349686, 43.60058940947056, 46.628570929169655, 53.875633254647255, 53.03122356534004, 54.41877231001854, 54.90617595613003, 54.805002585053444, 55.38903884589672, 55.45036755502224, 53.17033030092716, 50.10136038064957, 48.15038546919823, 48.0073307454586, 46.4019662886858, 45.38428969681263, 46.33157126605511, 47.137705609202385, 45.71024380624294, 47.17134140431881, 44.89772580564022, 30.670534931123257, 36.291320621967316, 35.83492711186409, 32.69819922745228, 25.75729977339506, 12.704796865582466, 5.0900116469711065, 6.223036274313927, 2.5800071703270078, 0.17815940722357482, 0.34499901405069977, 0.10024611692642793, 0.046566460441681556, 0.1254351285751909, 0.0858015260018874, 0.6658269907347858, 1.02185043040663, 0.1174980892392341, 0.05895622256502975, 0.10865955569897778, 0.91218878980726, 2.0432486850768328, 2.5072187511250377, 10.268281158059835, 39.265041053295135, 25.008738040924072, 19.564437679946423, 32.768392860889435, 21.84670351445675, 31.31238128989935, 38.586572259664536, 38.834934532642365, 37.56694257259369, 37.71331451833248, 40.75830392539501, 39.60663512349129, 38.065456822514534, 39.30928207933903, 40.396665930747986, 40.01125641167164, 43.998561054468155, 48.989980816841125, 48.54714497923851, 52.286402732133865, 49.07198801636696, 48.84330488741398, 48.388894870877266, 44.86781761050224, 45.481416285037994, 41.11842580139637, 42.564935982227325, 41.91190682351589, 40.494628474116325, 43.35243992507458, 40.61472862958908, 41.526136323809624, 48.07933308184147, 55.45075133442879, 56.005555763840675, 50.827497616410255, 58.3223332464695, 58.91363091766834, 56.0090933740139, 57.123030200600624, 56.7715984582901, 59.193056523799896, 57.114549055695534, 58.70228245854378, 58.3090415596962, 59.51993018388748, 57.65991859138012, 58.20851415395737, 56.52533747255802, 58.883380740880966, 53.473945409059525, 51.433986872434616, 19.186555556952953, 0.7618072279728949, 1.2539401953108609, 22.129005566239357, 58.59535239636898, 43.90979401767254, 33.5048009455204, 15.491972956806421, 43.97328861057758, 33.748793452978134, 43.341059535741806, 30.546167604625225, 33.11569042503834, 46.45911522209644, 39.03670370578766, 49.37650367617607, 0.36384662613272667, 0.12349819735391065, 0.036205462893121876, 0.020277322473702952, 0.036044068037881516, 0.05281775585899595, 0.02476896162988851, 0.10744941711891443, 0.03534148425387684, 0.06486234138719738, 0.029338350032048766, 0.1162858578027226, 0.09419292298844084, 0.053104733233340085, 0.06252309933188371, 0.03347306439536624, 0.055122135527199134, 0.0953854429826606, 0.015253012388711795, 0.1142903562868014, 0.16466848348500207, 0.11560562008526176, 0.3205432591494173, 0.2977670438122004, 9.68530124053359, 75.47217339277267, 54.29170332849026, 37.82182529568672, 50.725967064499855, 56.069012358784676, 32.31578774750233, 34.42832238972187, 22.906593941152096, 28.84933825582266, 49.58743795752525, 63.3627437800169, 33.59971225261688, 23.02635781466961, 35.41177801787853, 52.53410004079342, 57.56046272814274, 56.66013903915882, 55.63469186425209, 56.63378745317459, 61.709889471530914, 61.27101682126522, 60.603544637560844, 62.18191534280777, 59.39211644232273, 59.91891637444496, 59.59938772022724, 54.91607442498207, 52.68945470452309, 61.99606351554394, 61.35549008846283, 63.797588646411896, 53.173392936587334, 49.025413915514946, 47.08400309085846, 44.99183535575867, 42.80569106340408, 45.79151004552841, 45.59727966785431, 46.02021597325802, 46.557157561182976, 49.71760377287865, 56.44941374659538, 55.967018231749535, 57.22520671784878, 54.9998789280653, 56.07622057199478, 57.000140994787216, 58.603031784296036, 56.618793457746506, 53.0034014582634, 52.85424426198006, 49.91815321147442, 49.186377078294754, 49.66564156115055, 49.28080961108208, 50.80694451928139, 49.92394030094147, 51.01937212049961, 47.516720071434975, 36.36114567518234, 42.75735005736351, 44.91028793156147, 39.511028453707695, 32.985087633132935, 23.758958503603935, 17.666331231594086, 8.006963599473238, 1.3567085308022797, 0.7665017573162913, 0.4145501257153228, 0.3663763403892517, 0.13330691086594015, 0.020391301513882354, 0.26824767468497157, 0.9294998890254647, 1.3321908214129508, 0.06861288857180625, 0.1738057314651087, 0.5914037686306983, 0.4748784494586289, 1.0429020132869482, 1.4445384428836405, 16.003346666693687, 46.10615596175194, 28.70821762830019, 24.36906136572361, 34.226629212498665, 27.66014836728573, 35.886228159070015, 42.38215819001198, 43.43991883099079, 42.61299580335617, 43.25689785182476, 46.879927441477776, 44.059771969914436, 42.76338793337345, 43.194877579808235, 42.54117205739021, 42.96441234648228, 46.573724672198296, 50.664987936615944, 49.847739189863205, 52.51062490046024, 53.60424041748047, 51.644180193543434, 51.492306143045425, 49.27702881395817, 47.43627458810806, 44.198388531804085, 45.19615039229393, 43.83809566497803, 44.026523754000664, 45.36650665104389, 47.42071442306042, 46.67093105614185, 52.31340408325195, 56.60407304763794, 55.95374934375286, 54.58490699529648, 59.90525230765343, 61.17749243974686, 59.925797805190086, 61.70427717268467, 61.30707688629627, 61.18266396224499, 58.26345920562744, 61.786063984036446, 61.870727241039276, 62.3272043466568, 59.168289452791214, 60.31254105269909, 59.170561730861664, 61.7553236335516, 59.80176866054535, 57.4947414547205, 19.201648347079754, 0.486119938432239, 1.7038874700665474, 27.072327509522438, 64.14253413677216, 47.780365124344826, 39.73054647445679, 23.208894319832325, 39.981017634272575, 32.67294578254223, 43.81828732788563, 33.80524322390556, 36.22684948146343, 51.49229854345322, 41.64588689804077, 63.60887177288532, 1.3203562377020717, 0.12696567457169294, 0.0687252645730041, 0.040714202987146564, 0.05824159743497148, 0.039391413811245, 0.07766838156385347, 0.05596125964075327, 0.11069106622016989, 0.07515284974942915, 0.028431658938643523, 0.19869283743901178, 0.2261300667305477, 0.2176768859499134, 0.3236880654003471, 0.14079188578762114, 0.1292250244296156, 0.22768145223380998, 0.2149762402405031, 0.3218013478908688, 0.37838405231013894, 0.24376319866860285, 0.5481894593685865, 0.43537315679714084, 12.719217091798782, 84.02087867259979, 63.56154911220074, 45.577535927295685, 64.57533091306686, 68.76646041870117, 42.80397355556488, 43.75098533928394, 28.305748924613, 32.705460637807846, 55.31522020697594, 66.64365872740746, 35.13041451573372, 27.864391207695007, 41.739084497094154, 61.0657974332571, 61.82204805314541, 64.09436792135239, 62.199345007538795, 60.82035720348358, 66.54672592878342, 65.6247130036354, 64.2315861582756, 67.1609553694725, 60.15247464179993, 62.918323427438736, 62.42696799337864, 58.71475338935852, 53.65495629608631, 64.85110491514206, 63.88566792011261, 70.79818099737167, 57.217177748680115, 53.806321173906326, 49.81605648994446, 47.66610145568848, 46.59544810652733, 48.460513427853584, 49.64052110910416, 46.479276940226555, 47.862748503685, 52.95275017619133, 59.93023596704006, 58.108001947402954, 59.18102256953716, 59.4654107093811, 57.14180879294872, 61.02932699024677, 60.60729883611202, 61.149457544088364, 55.937493816018105, 55.86095452308655, 51.80755242705345, 50.8004354685545, 51.86092436313629, 52.93730780482292, 54.02439147233963, 53.03166814148426, 55.30195891857147, 49.86272178590298, 39.80469569563866, 43.235987573862076, 47.10829518735409, 44.113485887646675, 40.63144773244858, 32.1879968047142, 27.28809703141451, 22.669515162706375, 6.56466169282794, 0.816211283672601, 0.7599082204978913, 1.10763652715832, 0.24385697644902393, 0.2511516201775521, 0.600745448609814, 1.4023248455487192, 2.2795292688533664, 0.2790578571148217, 0.4209985281340778, 1.7334393155761063, 2.471272679977119, 7.887981059029698, 8.683211412280798, 19.734003581106663, 45.8708231896162, 30.158398412168026, 27.786972261965275, 41.630942299962044, 31.045757196843624, 40.72959266602993, 45.73609761893749, 48.486728221178055, 47.16637507081032, 47.95074038207531, 52.317564859986305, 46.27077832818031, 48.2041259855032, 47.5919446349144, 45.36107674241066, 46.09662227332592, 49.10168722271919, 55.710216611623764, 54.26401421427727, 58.28989818692207, 56.307821944355965, 52.83629022538662, 54.13280725479126, 53.88555832207203, 50.45962415635586, 46.6838313639164, 46.00806422531605, 48.29065874218941, 47.07414261996746, 51.14761523902416, 47.929552718997, 49.942958280444145, 53.549751341342926, 59.36505809426308, 57.69640803337097, 56.476050317287445, 61.82956404983997, 66.22243613004684, 63.51785905659199, 64.09013494849205, 65.96629187464714, 63.86029288172722, 60.18847770988941, 65.60795590281487, 63.12500573694706, 61.774436607956886, 61.02483943104744, 61.10731020569801, 61.9254595041275, 66.33856549859047, 65.64901649951935, 64.66931506991386, 25.091480500996113, 1.336925367359072, 1.9268180639483035, 27.151971235871315, 69.39292520284653, 59.40244048833847, 44.217828288674355, 23.829771503806114, 61.22359536588192, 44.32373620569706, 55.99007539451122, 47.51453138887882, 43.772784769535065, 64.57344621419907, 52.66299672424793, 75.45116811990738, 1.812547508161515, 0.26549032889306545, 0.13466161239193752, 0.14448764763073996, 0.2222397582954727, 0.14708362083183601, 0.2611446980154142, 0.13532454322557896, 0.28223142900969833, 0.21509108017198741, 0.12878433713922277], [0.12212168410769664, 0.0813586960430257, 0.06132824899395928, 0.08548393874661997, 0.030047627988096792, 0.04097333498066291, 0.08726070707780309, 0.020816503893001936, 0.19780686154263094, 0.03288526859250851, 0.06918272440088913, 0.3360478818649426, 0.05685811542207375, 6.007772600278258, 60.84462650120258, 56.35623514652252, 52.405530139803886, 47.1908837556839, 48.61103095114231, 31.10520500689745, 30.38652677088976, 18.396129570901394, 20.02138216048479, 31.072066985070705, 57.81037151813507, 35.88832564651966, 16.271817460656166, 28.41077148914337, 47.846565172076225, 55.97727008163929, 55.761669650673866, 51.830073818564415, 48.47335293889046, 52.11146391928196, 54.84682314097881, 55.05621090531349, 55.24260610342026, 55.699489787220955, 56.49815373122692, 52.585952058434486, 51.72057509422302, 55.36909371614456, 58.819126188755035, 58.19683738052845, 59.390782713890076, 51.595474407076836, 47.56652019917965, 44.44766275584698, 44.97939482331276, 41.98000676929951, 43.32554116845131, 42.20050133764744, 44.946933165192604, 43.36028270423412, 47.555265203118324, 54.10403519868851, 58.66352453827858, 54.75861847400665, 48.438201025128365, 52.34857119619846, 55.799390226602554, 54.0667250007391, 52.565813139081, 48.436753302812576, 47.31018215417862, 46.30571745336056, 46.391999423503876, 48.95283780992031, 47.14454144239426, 46.998196095228195, 46.94667465984821, 46.09240449965, 44.98059555888176, 37.251749485731125, 38.60287718474865, 31.996730268001556, 25.921297073364258, 18.097946271300316, 11.77201246842742, 4.771578758955002, 3.8569789985194802, 1.9617769005708396, 0.48351143777836114, 0.3383444430073723, 0.35712532117031515, 0.08776193877565674, 0.05097517016110942, 0.036377470460138284, 0.12148986410466023, 0.1617362431716174, 0.14744653104571626, 0.04929677350446582, 0.24320660275407135, 0.1714760111644864, 0.17804156901547685, 0.4534802836133167, 11.36012502014637, 24.806296303868294, 21.203071251511574, 29.455274641513824, 29.29698083549738, 47.40936063230038, 34.51799377799034, 36.46537408232689, 39.19086143374443, 40.08074328303337, 41.02621614933014, 40.282109677791595, 40.129677057266235, 38.244294226169586, 37.497934475541115, 35.28095483779907, 40.29481619596481, 42.23706677556038, 45.54035112261772, 47.838642597198486, 47.694493532180786, 48.24867859482765, 49.631215408444405, 49.24900531768799, 48.62545117735863, 47.83562555909157, 44.290066212415695, 43.10196116566658, 42.60476924479008, 41.716361716389656, 43.55623818933964, 42.62164793908596, 44.286251217126846, 53.83206479251385, 52.24637947976589, 55.040282160043716, 52.44810305535793, 54.529714956879616, 58.26157070696354, 59.55122530460358, 57.567302361130714, 57.3007732629776, 54.9673792719841, 55.470096096396446, 58.553277254104614, 58.60906966030598, 62.48216763138771, 56.04911282658577, 59.83559064567089, 57.71313853561878, 60.60619309544563, 54.07327584922314, 51.637131571769714, 15.832880213856697, 0.4537030169740319, 2.124508274719119, 29.549363292753696, 57.308597043156624, 39.87914890050888, 28.70259203016758, 24.980359263718128, 61.836673468351364, 37.45103359222412, 44.68853563070297, 29.385403990745544, 29.5388625562191, 56.780273392796516, 42.510671094059944, 52.78229512274265, 2.0399172138422728, 0.11502201741677709, 0.07669896600418724, 0.14910244062775746, 0.09797588718356565, 0.12303816227358766, 0.007242670662890305, 0.07790448100422509, 0.0676048145396635, 0.04797965433681384, 0.11284575841273181, 0.04738145733426791, 0.06888114527100697, 0.04475498557440005, 0.03695895429700613, 0.07290559689863585, 0.04809268342796713, 0.15224132454022765, 0.08627746530692093, 0.19852499332046136, 0.06169322979985736, 0.09726377422339283, 0.29641672095749527, 0.11589716537855566, 8.115573171526194, 69.46234747767448, 61.600839123129845, 60.373824164271355, 51.41514368355274, 52.52652704715729, 29.221722073853016, 32.563583850860596, 22.209929823875427, 24.62008159607649, 34.90394666790962, 60.045909360051155, 43.83162081241608, 16.223170571029186, 25.943455584347248, 52.03645594418049, 63.158238753676414, 62.27726362645626, 56.82448402047157, 54.04294587671757, 56.802756786346436, 57.699531465768814, 57.90708772838116, 57.95640908181667, 57.055063247680664, 59.09812241792679, 56.702822148799896, 53.083132579922676, 57.475985661149025, 62.055940702557564, 61.56295135617256, 62.6562324911356, 53.70430804789066, 49.51354332268238, 47.1182544529438, 45.385562628507614, 43.65249082446098, 45.37961594760418, 45.7002579420805, 47.137747406959534, 45.53126581013203, 50.11653296649456, 55.23405656218529, 60.168088003993034, 60.14204040169716, 50.85423678159714, 53.92107121646404, 62.46070638298988, 57.93163821101189, 56.82431302964687, 52.236522808671, 48.95139768719673, 50.57514935731888, 50.9004233032465, 51.275318786501884, 51.64541892707348, 50.389700308442116, 51.52699448168278, 49.3718109279871, 49.13785748183727, 40.16511395573616, 42.22917839884758, 40.27324475347996, 31.045559607446194, 24.093940928578377, 19.706270769238472, 18.55848915874958, 6.610949384048581, 2.48530485201627, 1.1238755495287478, 0.446912128245458, 0.33176738186739385, 0.07051609660265967, 0.049215096441912465, 0.04213123749650549, 0.05145031165739056, 0.02232597289548721, 0.23662198655074462, 0.06108334397140425, 0.09241763895261101, 0.2837775007355958, 0.18262151075759903, 0.5554918956477195, 15.872428491711617, 29.712917916476727, 29.850478135049343, 45.70173226296902, 40.15647701919079, 45.529130324721336, 40.67450322210789, 40.77204018831253, 42.451759055256844, 44.05976437032223, 45.88813506066799, 45.53759627044201, 44.695056080818176, 42.96170309185982, 41.78503543138504, 41.197081580758095, 41.97355471551418, 43.37350979447365, 48.418495282530785, 52.44429565966129, 50.099342688918114, 48.04486893117428, 52.939815670251846, 54.19087953865528, 54.03332859277725, 48.825233057141304, 47.63553209602833, 44.59561921656132, 47.22929589450359, 44.282683208584785, 46.593825593590736, 45.41893623769283, 50.83887800574303, 54.769835472106934, 55.64352259039879, 56.19032844901085, 55.61910130083561, 58.962819278240204, 60.43286919593811, 62.93988727033138, 59.728816375136375, 57.96651653945446, 58.63114647567272, 56.62375599145889, 59.69147577881813, 60.45965775847435, 63.35771284997463, 58.359084874391556, 62.0309304445982, 61.131340116262436, 64.03123050928116, 57.423316687345505, 58.6121778935194, 20.249770805239677, 0.2330716559663415, 2.803284851834178, 35.05916453897953, 59.29123945534229, 43.401692882180214, 34.551963955163956, 27.808477208018303, 51.683523282408714, 31.604986488819122, 43.92753146588802, 33.53829614818096, 33.02384555339813, 65.04359498620033, 53.721433728933334, 61.095907017588615, 4.422350423410535, 0.36955706658773124, 0.1430631396942772, 0.03403529692150187, 0.15980398748070002, 0.08196698996471241, 0.041320882737636566, 0.026614519629220013, 0.053963865648256615, 0.04459310461243149, 0.053199420144665055, 0.27593409817200154, 0.3148765757214278, 0.21610194467939436, 0.2733583707595244, 0.17737491260049865, 0.23638580547412857, 0.2138099551666528, 0.11915143099031411, 0.3735494945431128, 0.26919121155515313, 0.36800603731535375, 0.4351359367137775, 0.3440098202554509, 11.795941684395075, 80.2460016310215, 65.4173581302166, 64.70616549253464, 65.84343686699867, 61.83381222188473, 41.072528064250946, 41.003975942730904, 23.592470437288284, 26.632749997079372, 40.377127379179, 66.47724285721779, 44.52574856579304, 20.946659110486507, 33.07336829602718, 57.87728972733021, 68.10264363884926, 67.84395352005959, 62.883498296141624, 58.53853404521942, 60.62040813267231, 63.530436381697655, 62.963111624121666, 59.81105536222458, 58.105429485440254, 61.68855361640453, 58.46349187195301, 54.997234269976616, 60.924464017152786, 64.50246602296829, 65.64759537577629, 68.26587527990341, 58.11239451169968, 52.25714050233364, 48.45864772796631, 48.787083104252815, 44.745502173900604, 46.60066522657871, 47.717679888010025, 51.5362773835659, 45.74893333017826, 50.811606869101524, 56.34759820997715, 64.7003062069416, 61.3089007884264, 52.43294566869736, 53.26755568385124, 61.67680844664574, 62.885557785630226, 59.60353709757328, 55.593175292015076, 52.778609320521355, 51.09051950275898, 51.223877146840096, 55.370708629488945, 56.75126954913139, 55.48571325838566, 58.6008545011282, 53.674228861927986, 56.1208301782608, 44.41768616437912, 44.8421423882246, 43.47919352352619, 38.28556761145592, 29.94430650025606, 24.47450190782547, 25.787204168736935, 22.761618420481682, 13.811425734311342, 1.8644571164622903, 2.974959877319634, 1.4333106391131878, 0.180866761947982, 0.24486902839271352, 0.16636142623610795, 0.15130672312807292, 0.43202871282119304, 0.5023456912022084, 0.21022275468567386, 0.500842040637508, 0.6160234194248915, 0.42280049237888306, 1.9622550811618567, 23.59791174530983, 33.67062024772167, 32.15504117310047, 47.8265630453825, 47.23428122699261, 61.85756854712963, 45.607797503471375, 44.00629743933678, 47.0183540135622, 50.59425853192806, 51.3846655189991, 53.99701774120331, 49.17789213359356, 48.76111909747124, 44.23661068081856, 43.20389449596405, 45.00259257853031, 45.99998205900192, 51.260852962732315, 56.966440603137016, 54.173176288604736, 54.01157855987549, 54.606136456131935, 55.57205602526665, 55.985276252031326, 54.942027032375336, 51.440039947628975, 49.20724555850029, 49.018631279468536, 47.26848319172859, 48.84277291595936, 50.0383635610342, 53.41658368706703, 58.58073078095913, 56.84219107031822, 56.58570483326912, 54.920664578676224, 60.66141553223133, 64.53708976507187, 66.53896674513817, 61.207537427544594, 62.088622748851776, 58.44396851956844, 57.914083153009415, 62.582159265875816, 63.871813863515854, 67.35606729984283, 59.147736355662346, 61.8672314286232, 61.69231541454792, 64.82671022415161, 61.76159709692001, 62.8177048265934, 20.91894719749689, 0.5150104116182774, 2.6988833164796233, 35.38304775953293, 66.86042189598083, 55.45222565531731, 38.263707384467125, 32.33021177351475, 78.37357610464096, 50.06345361471176, 59.10594239830971, 44.65371049940586, 41.092446595430374, 76.04667216539383, 55.36120153963566, 74.64258670806885, 6.459766896441579, 0.5024887179024518, 0.2067926074960269, 0.24206975125707686, 0.2906133042415604, 0.3978051961166784, 0.17371420981362462, 0.22133165155537426, 0.16984949063044041, 0.09565565895172767, 0.19651534646982327], [0.27631677919998765, 0.10011232254328206, 0.032895833064685576, 0.038238368651946075, 0.030590677852160297, 0.057066632944042794, 0.03988573240349069, 0.08665854329592548, 0.08098351812805049, 0.18107242591213435, 0.18965981667861342, 0.32563854823820293, 0.23817429231712595, 5.933951586484909, 69.09676909446716, 42.64870248734951, 31.300767213106155, 36.59356400370598, 42.346679493784904, 40.71691274642944, 33.44984449446201, 22.155030369758606, 19.879965148866177, 29.3342587351799, 53.696282878518105, 45.35204462707043, 12.73976068943739, 12.560551855713129, 44.436548352241516, 56.89080946147442, 57.43641838431358, 54.10682424902916, 51.266837641596794, 49.33589905500412, 51.971924006938934, 50.20620055496693, 52.86970943212509, 53.15533630549908, 55.597564056515694, 53.35675969719887, 51.035369262099266, 56.35108642280102, 57.93423727154732, 61.14758424460888, 57.2342274338007, 48.71574953198433, 46.37045077979565, 40.51943354308605, 42.51068629324436, 40.88882692158222, 40.38310065865517, 42.751437574625015, 44.30442564189434, 43.42625856399536, 44.590421095490456, 52.742534056305885, 60.297771245241165, 58.991427943110466, 55.2890358120203, 56.64367072284222, 60.39287634193897, 55.56791424751282, 50.285031124949455, 47.259036898612976, 45.06553240120411, 46.396114602684975, 47.11540460586548, 48.96491356194019, 49.041217267513275, 47.34330117702484, 44.58407923579216, 43.61965298652649, 43.45692291855812, 34.68524560332298, 40.26853300631046, 24.989336282014847, 19.476954974234104, 11.589377168565989, 8.542025238275528, 8.979246877133846, 2.0866734674200416, 4.892352428287268, 0.8716886036563665, 0.22795373137341812, 0.09450109238969162, 0.08754509064601734, 0.13431532628601417, 0.04663080093450844, 0.07800536855938844, 0.06697204458760098, 0.07723508606432006, 0.08227579019148834, 0.17208620498422533, 0.019654962998174597, 0.1891785635962151, 0.21538461442105472, 2.362116174772382, 16.054545119404793, 30.563977248966694, 50.67759566009045, 45.972482934594154, 44.22485031187534, 36.29381328821182, 32.791700810194016, 40.74775569140911, 41.89765378832817, 39.931814074516296, 38.592446744441986, 37.111168429255486, 38.59844662249088, 36.6392033547163, 38.86658303439617, 38.208063170313835, 43.27457070350647, 46.88690386712551, 48.595280796289444, 47.3851103335619, 43.520622700452805, 49.288739785552025, 51.97807967662811, 51.39107957482338, 46.34852595627308, 43.818336725234985, 45.84661468863487, 42.85793825984001, 41.167488768696785, 43.15893530845642, 44.188125282526016, 45.813704654574394, 52.85979576408863, 53.087916523218155, 54.14027765393257, 55.47624796628952, 55.38154564797878, 56.089823842048645, 59.64340455830097, 58.8010011613369, 56.9803174585104, 55.12432985007763, 55.715688318014145, 57.063373401761055, 55.58437496423721, 58.12187500298023, 58.380694314837456, 56.9013386964798, 60.505772083997726, 60.406916588544846, 58.24949875473976, 55.77204309403896, 29.865076951682568, 0.6982361047994345, 4.2554885521531105, 40.4721374809742, 54.08642694354057, 31.028188839554787, 33.530255779623985, 59.475453570485115, 47.755753844976425, 35.353074967861176, 37.68952779471874, 21.944578662514687, 32.87585869431496, 38.690641075372696, 31.139167584478855, 53.1930872797966, 3.534196768887341, 0.06129999543190934, 0.0629461754579097, 0.20120120752835646, 0.0930616821278818, 0.09035650189616717, 0.03271641515311785, 0.03279192867921665, 0.040582564543001354, 0.026272077848261688, 0.08062203283770941, 0.14843858953099698, 0.0598028460808564, 0.035635025924420916, 0.05800278173410334, 0.027540593764570076, 0.1638376640039496, 0.11510816591908224, 0.0671063807385508, 0.1656147959874943, 0.05545830244955141, 0.07410521182464436, 0.22460545791545883, 0.2108682895777747, 8.16340310499072, 78.50229039788246, 50.76138496398926, 33.07350508868694, 42.85931758582592, 45.93323864042759, 36.42809048295021, 33.57258930802345, 24.92367770522833, 25.528154969215393, 35.74425257742405, 55.38566082715988, 49.48854826390743, 16.153075732290745, 10.57183736935258, 44.99028503894806, 61.3177353143692, 64.46101784706116, 59.83693577349186, 57.42352567613125, 54.85697619616985, 53.55325475335121, 53.71841289103031, 55.54287739098072, 55.92303179204464, 60.44607348740101, 57.477118000388145, 57.994578033685684, 57.92435020208359, 59.645916223526, 63.768208622932434, 60.561697483062744, 50.02889446914196, 47.53648281097412, 44.27258715033531, 43.696595057845116, 43.49491707980633, 44.70527373254299, 45.413475930690765, 46.20002992451191, 43.80682714283466, 47.33894281089306, 54.38842713832855, 61.87474362552166, 60.24689197540283, 57.8146006911993, 58.14162254333496, 58.97084444761276, 58.02947536110878, 52.51256659626961, 50.20832844078541, 48.37805785238743, 50.707488656044006, 50.48974134027958, 50.46439290046692, 52.66278773546219, 49.426379799842834, 49.56951051950455, 47.00606927275658, 48.316330164670944, 38.21680270135403, 42.16550521552563, 32.07255519926548, 25.541268065571785, 15.639345198869705, 12.389749120920897, 13.262738976627588, 7.235513320192695, 2.9441387811675668, 0.8805484813638031, 0.4788611107505858, 0.015214368759188801, 0.07593852438731119, 0.1741688049514778, 0.033803631813498214, 0.03625190649472643, 0.07000837111263536, 0.14361175009980798, 0.11738889705156907, 0.16862231976119801, 0.043503958368091844, 0.1415136837749742, 0.6156034232117236, 1.2387975328601897, 22.533442564308643, 39.277998358011246, 59.76357311010361, 64.93906259536743, 46.28811299800873, 38.814628422260284, 38.38840529322624, 42.8475496172905, 46.52563825249672, 43.76700147986412, 46.916637271642685, 43.42401288449764, 43.60615611076355, 41.00780613720417, 42.03099623322487, 39.665596559643745, 46.322026178240776, 48.99737522006035, 49.88647811114788, 51.99750043451786, 46.286053508520126, 50.9023991972208, 54.45084258913994, 54.68915820121765, 48.3535073697567, 45.22687554359436, 47.273897901177406, 45.55330842733383, 46.11884728074074, 46.96340136229992, 46.70346111059189, 50.45035645365715, 54.5255883783102, 53.967652916908264, 55.47833785414696, 56.810842752456665, 58.8043487817049, 57.873831912875175, 61.17749243974686, 59.70367692410946, 59.4679831713438, 57.119420394301414, 57.274683862924576, 59.93531249463558, 58.15827704966068, 59.876016676425934, 59.07467767596245, 58.7378903478384, 61.575114503502846, 64.23994570970535, 62.750292643904686, 63.83510023355484, 38.66685435175896, 0.6379294220823795, 5.346115054562688, 46.97222828865051, 56.238019689917564, 37.59420990943909, 39.00197736918926, 52.136003002524376, 43.015451207756996, 30.221072249114513, 36.61160163581371, 28.03326554596424, 37.949392050504684, 48.274346217513084, 35.896183624863625, 64.55145299434662, 5.047465329989791, 0.11691717314533889, 0.008594389219069853, 0.08171100838808343, 0.07706683376454748, 0.12030914425849915, 0.01349911612123833, 0.026670440456655342, 0.05754929610702675, 0.05944947246462107, 0.12261985815712251, 0.594704425893724, 0.1686724741011858, 0.15967757004546002, 0.17955473391339183, 0.2971982618328184, 0.35118537896778435, 0.3517096914583817, 0.3802641498623416, 0.3747938683954999, 0.4399135569110513, 0.4177123575937003, 0.5264572380110621, 0.3480779175879434, 12.042504753917456, 89.0251113474369, 55.73119528591633, 39.7640036791563, 50.2670618891716, 60.531660094857216, 51.59295134246349, 45.17012178897858, 28.48451793193817, 27.679576724767685, 38.83336141705513, 64.36427503824234, 52.20883749425411, 17.24167361855507, 15.235567465424538, 51.176421493291855, 65.07773235440254, 68.64013239741325, 62.45834290981293, 60.326300114393234, 59.01542365550995, 59.86803710460663, 57.68875524401665, 56.318111792206764, 56.17213122546673, 59.79098863899708, 57.502029463648796, 57.98293925821781, 61.044651567935944, 62.83032014966011, 68.52464139461517, 64.58086341619492, 52.44323171675205, 53.35505738854408, 45.75692430138588, 46.50873675942421, 46.08138509094715, 47.97076530754566, 48.20548251271248, 49.89942021667957, 44.7114522010088, 47.461881414055824, 56.831920221447945, 65.46818420290947, 63.676325753331184, 58.794951885938644, 59.43689323961735, 63.260840848088264, 62.91313290596008, 57.84067489206791, 54.57004599273205, 51.781265437603, 52.37609311938286, 51.158387660980225, 54.52153779566288, 59.07461307942867, 56.48555360734463, 56.754795759916306, 53.038180992007256, 53.4687776863575, 43.138367012143135, 48.73773515224457, 35.29848329722881, 30.533202700316906, 19.250724613666534, 15.11661009863019, 25.22849164903164, 20.279162228107452, 12.652202937752008, 3.1253726687282324, 1.6781852929852903, 0.31446358538232744, 0.29507818340789527, 0.30190727789886296, 0.08719235527678393, 0.1596939715091139, 0.23274373059393838, 0.3370167704997584, 0.38969171117059886, 0.3039585443912074, 0.1098230280331336, 0.33213780261576176, 0.9329070593230426, 15.662682596594095, 29.285837933421135, 41.6736976057291, 64.86993670463562, 62.91260473430157, 60.90387672185898, 47.75242142379284, 43.87193664908409, 48.79811771214008, 52.817842215299606, 51.46588236093521, 55.75946196913719, 49.539864510297775, 49.19186398386955, 43.800036907196045, 44.30246874690056, 41.39701925218105, 48.541498482227325, 52.480055540800095, 54.830016642808914, 56.38813063502312, 47.88601465523243, 52.55656823515892, 58.349532186985016, 59.980514869093895, 52.487791925668716, 49.5181904733181, 50.31770937144756, 47.77911119163036, 50.44136993587017, 50.716380178928375, 51.353241205215454, 54.10112075507641, 58.32723118364811, 56.18541531264782, 57.28688880801201, 59.03321050107479, 60.74593059718609, 61.6137508302927, 66.17128327488899, 62.341195195913315, 61.98190927505493, 57.19024859368801, 57.73485817015171, 61.899795681238174, 61.14081300795078, 60.88745400309563, 60.635094344615936, 58.43016006052494, 62.90225028991699, 68.04026618599892, 64.53236281871796, 66.65746718645096, 37.49039568006992, 0.6173803028650582, 5.67510187625885, 49.569689109921455, 66.42814949154854, 46.72238029539585, 44.578664526343346, 67.3092158138752, 58.41350555419922, 47.56239742040634, 47.72771514952183, 34.35022138059139, 45.47041207551956, 56.19982033967972, 39.91714306175709, 77.48279750347137, 8.483607172966003, 0.4726166801992804, 0.16213593422435224, 0.3275069495430216, 0.2732898556860164, 0.31050318852066994, 0.13109084306051955, 0.1602060830919072, 0.11230901494855061, 0.188260022259783, 0.337098614545539], [0.18895139219239354, 0.032146364101208746, 0.05753758501668926, 0.021114286937518045, 0.1029632160498295, 0.036395374772837386, 0.09888358574244194, 0.05829980407725088, 0.1513337521464564, 0.029465032785083167, 0.3402670210925862, 0.6644259346649051, 0.13382568693486974, 7.95935595408082, 62.05285146832466, 51.65239915251732, 57.42235153913498, 36.15126773715019, 40.43404072523117, 49.82579156756401, 38.489381074905396, 33.88048678636551, 27.724809497594833, 19.702039696276188, 50.99056586623192, 51.14194594323635, 20.6493953615427, 7.507154569029808, 29.03681829571724, 58.081908747553825, 56.94777600467205, 57.80094042420387, 54.766278862953186, 50.13900876045227, 47.561481669545174, 47.5712813436985, 50.9559079259634, 53.47299546003342, 56.83076128363609, 54.79147911071777, 52.46463216841221, 53.506464064121246, 57.750030755996704, 60.58118663728237, 54.98330421745777, 48.746710270643234, 46.89583718776703, 40.55075526237488, 40.220632776618004, 37.82364919781685, 41.6673519462347, 43.49576063454151, 46.16602934896946, 43.19897376000881, 45.5645140260458, 49.26734693348408, 61.675159335136414, 59.42795991897583, 58.90665829181671, 59.03059244155884, 58.70456613600254, 55.92503808438778, 48.69572080671787, 43.893960267305374, 42.96620965003967, 46.750251799821854, 50.049797147512436, 47.27146603167057, 49.069533348083496, 49.52448673546314, 43.00554133951664, 41.974937841296196, 39.96674560010433, 34.4966047257185, 32.38398268818855, 24.701965302228928, 20.110876858234406, 7.597242034971714, 5.835315529257059, 7.192443581297994, 3.1498310063034296, 4.083309341222048, 1.4452960272319615, 0.11055606955778785, 0.0827559968456626, 0.14627640164690092, 0.3459376230603084, 0.07277126074768603, 0.16031216568080708, 0.1486198665224947, 0.2158290718216449, 0.07806897803675383, 0.18621930910740048, 0.0798651238437742, 0.059159949523746036, 0.6076148268766701, 2.229230892844498, 8.51812357082963, 33.109701946377754, 50.49778550863266, 71.46528840065002, 50.63396640121937, 35.75361147522926, 31.64526242762804, 37.955000549554825, 43.38711306452751, 40.50883591175079, 35.478434041142464, 37.47490391135216, 38.36654506623745, 37.33738549053669, 36.31236009299755, 41.19453951716423, 41.072037890553474, 47.07055561244488, 48.36959570646286, 47.57621727883816, 45.28555579483509, 46.223410069942474, 51.69058330357075, 48.326988592743874, 44.80115778744221, 42.16909982264042, 43.42299073934555, 41.29602827131748, 40.65047711133957, 40.339289009571075, 45.435111969709396, 49.87705461680889, 50.953913033008575, 51.81789547204971, 53.699524104595184, 53.76274511218071, 55.508512035012245, 56.86787009239197, 57.967550083994865, 58.163904547691345, 55.08308686316013, 54.31268200278282, 54.75086309015751, 53.95477920770645, 54.64068420231342, 55.283963084220886, 57.11626656353474, 56.388943791389465, 57.69564427435398, 59.62108835577965, 59.14506509900093, 58.129474595189095, 45.96571169793606, 1.706878978293389, 9.53229010105133, 54.06873129308224, 47.56449870765209, 26.916951946914196, 31.410214640200138, 86.53282508254051, 38.05061861872673, 30.95008783042431, 35.12997753918171, 19.956580437719822, 44.977548122406006, 51.362752094864845, 31.92269504070282, 50.07821962237358, 3.4364866744726896, 0.040105129810399376, 0.15612415212672204, 0.09244475702871569, 0.03229168403777294, 0.08246008772403002, 0.05766926798969507, 0.02920937775343191, 0.038046334229875356, 0.11575417578569613, 0.12396696009091102, 0.03497681515000295, 0.035597521491581574, 0.06618259983952157, 0.02762797423201846, 0.1330248056910932, 0.019302127439004835, 0.019873185956384987, 0.06540493297507055, 0.12126183923101053, 0.08576658568927087, 0.13009148184210062, 0.6094744708389044, 0.18459295184584334, 11.84013331308961, 73.79928275942802, 55.99284164607525, 60.294324830174446, 44.30647753179073, 42.594392001628876, 43.43771114945412, 37.50278301537037, 28.289926573634148, 29.535668827593327, 23.980619609355927, 55.52854835987091, 54.49195258319378, 25.7127832621336, 8.561916220933199, 29.5046890899539, 56.9872634857893, 62.93416477739811, 61.859654635190964, 58.194124326109886, 52.41215318441391, 52.89619401097298, 52.02117696404457, 51.93045683205128, 54.15381632745266, 57.53527007997036, 59.19428005814552, 58.56438025832176, 57.423453480005264, 62.00037628412247, 61.366178914904594, 58.66764731705189, 50.70471100509167, 47.098370119929314, 45.434382408857346, 44.92833696305752, 43.41553553938866, 44.446306228637695, 47.617042288184166, 46.94394640624523, 46.90306819975376, 47.86333367228508, 51.38613224029541, 61.863344237208366, 60.40693558752537, 61.919699013233185, 57.473454996943474, 59.18324165046215, 56.984113454818726, 53.61347772181034, 47.11151361465454, 46.49195306003094, 49.1395103931427, 52.33456514775753, 51.382602229714394, 51.73244185745716, 52.469723895192146, 49.658064767718315, 46.37467235326767, 44.592503383755684, 38.72551180422306, 34.8858368396759, 33.821570947766304, 25.484903790056705, 18.738324008882046, 11.581677831709385, 9.813835993409157, 6.562214149162173, 1.6589536936953664, 1.6562934801913798, 0.2591888123424724, 0.03749671821424272, 0.1431125370436348, 0.08132484668749385, 0.0700798028265126, 0.13466109288856387, 0.014798840275034308, 0.11765146889956668, 0.22596743248868734, 0.1375335457851179, 0.055429696367355064, 0.07563789520645514, 0.1076116283365991, 3.094370844773948, 17.618577294051647, 42.69734367728233, 52.467485815286636, 75.42754098773003, 56.7007702589035, 38.36595229804516, 35.52697643637657, 41.15712672472, 45.76862007379532, 46.46964445710182, 41.56345792114735, 43.24191525578499, 42.22832344472408, 42.03506201505661, 40.047381073236465, 42.611696273088455, 42.12331987917423, 50.84661439061165, 49.169175401329994, 51.59289054572582, 48.55823278427124, 51.121943816542625, 55.53164899349213, 51.83822438120842, 47.32783980667591, 44.843593910336494, 47.33811445534229, 46.35638773441315, 42.739285826683044, 44.93273712694645, 49.21257667243481, 52.77052715420723, 53.10966655611992, 54.27379868924618, 55.93280866742134, 55.684020817279816, 57.188561484217644, 59.41825903952122, 60.57834818959236, 58.48479352891445, 56.712108850479126, 55.623068287968636, 56.45407609641552, 55.213868245482445, 55.399340093135834, 54.76847134530544, 57.282614037394524, 58.28916482627392, 60.6256328523159, 60.76504357159138, 62.72780545055866, 61.83483436703682, 51.92751199007034, 1.5948216849938035, 11.787702776491642, 57.991105020046234, 50.62852129340172, 32.61427693068981, 35.344035252928734, 75.51946565508842, 36.48681253194809, 26.980765722692013, 33.384305611252785, 30.254892334342003, 45.312553346157074, 50.932637974619865, 41.0080037266016, 59.84619587659836, 7.75759058073163, 0.14217483345419168, 0.14450645365286618, 0.051269394607516006, 0.053722667653346434, 0.04740117248729803, 0.04045189460157417, 0.02126495775883086, 0.048352464800700545, 0.13452697196044028, 0.11175236708368175, 0.5085781880188733, 0.16603391646640375, 0.13240117899840698, 0.09619010917958803, 0.35794515686575323, 0.20486483437707648, 0.20042823103722185, 0.15480685484362766, 0.49076305178459734, 0.6593316548969597, 0.44084349763579667, 0.9749919979367405, 0.39435349695850164, 14.451077710837126, 82.12080582976341, 67.29813560843468, 74.17158678174019, 51.308308616280556, 59.34461899101734, 65.59888198971748, 50.37642762064934, 40.70712827146053, 33.66521313786507, 25.71978058665991, 64.13292065262794, 61.07764519751072, 29.989259988069534, 9.775179717689753, 34.13495913147926, 63.577926233410835, 67.10702106356621, 66.25689268112183, 63.63853298127651, 54.74649712443352, 56.39732614159584, 53.83801147341728, 52.890900894999504, 52.03733369708061, 57.26782143115997, 59.35430847108364, 60.59374496340752, 58.94474744796753, 62.10018552839756, 65.25403529405594, 64.59020331501961, 54.522271156311035, 52.43736483156681, 45.885308012366295, 47.149686366319656, 42.72385485470295, 46.17816969752312, 48.89851972460747, 50.336799547076225, 48.99822257459164, 51.44720636308193, 53.36651377379894, 68.48996445536613, 63.945210725069046, 67.67185315489769, 63.83182480931282, 63.22945073246956, 61.22013375163078, 58.188660219311714, 51.93243272602558, 49.32440847158432, 49.79959957301617, 54.5017446577549, 53.19400303065777, 59.18430179357529, 57.95945651829243, 53.64991396665573, 51.91604420542717, 48.91665235161781, 45.39001978933811, 45.21379664540291, 40.22642746567726, 32.235874235630035, 20.892941392958164, 15.682696122676134, 17.649534232914448, 16.67434886097908, 12.610243689268827, 4.719006204977632, 0.531469703419134, 0.2416966884629801, 0.5772053555119783, 0.388863414991647, 0.2189784200163558, 0.2582073665689677, 0.3468252019956708, 0.32352170557715, 0.42944111104588956, 0.5366430664435029, 0.360758668393828, 0.14603674731915817, 1.4799532550387084, 5.554740484803915, 25.86825381964445, 43.78765717148781, 55.33582650125027, 72.05691665410995, 64.49479803442955, 46.08608163893223, 42.64565125107765, 44.68773387372494, 54.89925652742386, 54.795449897646904, 48.668187484145164, 48.40475521981716, 47.779996544122696, 44.953768998384476, 43.52081649005413, 45.07852390408516, 43.33514325320721, 51.8868313729763, 55.46713225543499, 54.507315158843994, 51.35652802884579, 54.603598192334175, 60.509697273373604, 56.19938336312771, 54.22593645751476, 48.698217272758484, 51.861733719706535, 48.5449942946434, 46.67530082166195, 46.935932636260986, 53.36498625576496, 55.939568504691124, 56.11980803310871, 57.91258603334427, 57.82629266381264, 58.474051505327225, 61.69968321919441, 64.75006833672523, 67.74538680911064, 63.588345274329185, 56.95687651634216, 57.09384396672249, 56.410587430000305, 57.381374537944794, 60.449671894311905, 58.516267240047455, 59.60773967206478, 59.35021609067917, 61.81885622441769, 63.20142723619938, 65.06301194429398, 63.9880496263504, 53.673362508416176, 1.8726053042337298, 11.561763100326061, 64.45184513926506, 59.13861304521561, 40.09883791208267, 41.42017520964146, 92.82762050628662, 46.25230371952057, 40.41275806725025, 44.71804104745388, 29.944196306169033, 54.57977347075939, 66.33614882826805, 43.16006004810333, 71.36994391679764, 12.628855090588331, 0.26229722367133945, 0.1917224528733641, 0.23650198127143085, 0.0940372129844036, 0.13719306327402592, 0.2738478913670406, 0.2883973403368145, 0.17043642554199323, 0.3340791125083342, 0.4742605669889599], [0.215513184084557, 0.11561383566004224, 0.035348601450095885, 0.14933648431906477, 0.07615613692905754, 0.10357711318647489, 0.03369457321241498, 0.0758366497757379, 0.06864850423880853, 0.09354565147077665, 0.17643654107814655, 0.857335408218205, 0.3570228157332167, 11.95318864658475, 69.87514212727547, 48.757026717066765, 39.685541689395905, 32.0098851621151, 50.328876972198486, 40.84904305636883, 38.18770006299019, 60.942315459251404, 63.53730261325836, 19.10316903144121, 38.920068964362144, 57.886318042874336, 29.676293581724167, 9.128899946808815, 16.78250625729561, 49.12220612168312, 59.59687985479832, 57.391683384776115, 55.46521335840225, 51.654052063822746, 48.113219663500786, 48.98789092898369, 49.362246841192245, 51.95921748876572, 55.14915771782398, 59.21676345169544, 58.26211787760258, 55.202617049217224, 56.25679448246956, 60.653933733701706, 55.275120958685875, 47.89367884397507, 42.7996189892292, 42.80153028666973, 38.7516126036644, 39.2871368676424, 42.87102095782757, 46.6665954887867, 45.987138748168945, 41.87816843390465, 46.70859843492508, 48.73245343565941, 53.79931055009365, 58.465091586112976, 57.99254134297371, 57.5462780892849, 55.33279046416283, 55.954197719693184, 48.32978144288063, 44.278370440006256, 42.23302759230137, 45.57623639702797, 47.34597623348236, 49.372768476605415, 44.84998136758804, 49.77605223655701, 42.69407585263252, 39.94417101144791, 36.71666979789734, 32.42181345820427, 22.358680441975594, 24.221513383090496, 6.58551212400198, 6.858897004276514, 0.7404448930174112, 2.151212291792035, 4.697555406019092, 4.416816495358944, 2.107258625328541, 0.09093396700336598, 0.14125767251243815, 0.025693085772218183, 0.13689057872397825, 0.11285942135145888, 0.01644507410674123, 0.06528992977109738, 0.017258098741876893, 0.10731371541623957, 0.14345791772939265, 0.12065900751622394, 0.11189139360794798, 0.16150303068570793, 0.25976050354074687, 4.265046939253807, 35.74603468179703, 40.299440547823906, 66.79501220583916, 60.26311330497265, 38.39371360838413, 30.727995447814465, 40.07952734827995, 36.540644243359566, 40.05024611949921, 35.909672901034355, 38.18885900080204, 34.92214769124985, 36.046412363648415, 38.71573492884636, 39.88018624484539, 40.83762846887112, 44.70006801187992, 47.09704399108887, 47.77310371398926, 46.19347907602787, 50.03174811601639, 50.86710289120674, 45.77153451740742, 41.899698078632355, 40.345410481095314, 41.265546306967735, 42.420186549425125, 40.03064677119255, 42.91439563035965, 47.26493798196316, 51.21123522520065, 50.78746296465397, 50.3965475410223, 49.065562561154366, 50.86151719093323, 51.20283007621765, 51.79843291640282, 53.65037754178047, 51.819510385394096, 53.85058119893074, 51.967850625514984, 52.054622769355774, 49.04923103749752, 48.760526329278946, 48.25741432607174, 50.37331558763981, 52.625010162591934, 55.47582998871803, 55.101037099957466, 56.896672546863556, 56.152053102850914, 46.00539296865463, 1.9722224213182926, 16.23090885579586, 57.229808270931244, 38.23294423520565, 21.453029438853264, 40.09439595043659, 80.96148803830147, 45.28507322072983, 30.587138906121254, 34.01102498173714, 19.21443846076727, 47.56863288581371, 56.80544324219227, 31.596792228519917, 49.88367386162281, 8.986121658235788, 0.42415773204993457, 0.10221353557426482, 0.12380259664496407, 0.14146047178655863, 0.06582383080967702, 0.014026366588950623, 0.08677916455781087, 0.029906490053690504, 0.1008298086526338, 0.07215594610897824, 0.15778812143253163, 0.13458221743348986, 0.021250020181469154, 0.08049841329921037, 0.03348677928443067, 0.0721772902761586, 0.11659606811008416, 0.05385512617067434, 0.08447661428363062, 0.17392680543707684, 0.06689443078357726, 0.554230185225606, 0.3982524439925328, 15.853490307927132, 78.06605100631714, 53.06218810379505, 46.87159828841686, 39.0279945731163, 51.214066073298454, 35.62583573162556, 30.18944274634123, 50.92321068048477, 60.241902843117714, 23.338583260774612, 44.74808223545551, 62.07714356482029, 41.10252745449543, 12.466335911303759, 16.554212607443333, 49.97169613838196, 64.43045988678932, 59.83218602836132, 57.26884737610817, 52.734980061650276, 52.091393396258354, 50.04857361316681, 50.60236729681492, 52.108348086476326, 58.93062360584736, 59.561461955308914, 60.331479236483574, 57.65989579260349, 62.55331501364708, 62.49265506863594, 57.29720525443554, 49.85729567706585, 44.17072981595993, 45.92058151960373, 44.071106761693954, 43.47322404384613, 46.17048271000385, 48.467383459210396, 48.25337894260883, 44.02913801372051, 48.33208031952381, 47.19046577811241, 53.254909962415695, 60.29880478978157, 60.840803906321526, 60.2946288138628, 58.420071601867676, 59.15223531424999, 51.69959641993046, 46.37282185256481, 46.20546743273735, 48.90980511903763, 47.978330701589584, 51.29123613238335, 49.50425282120705, 52.84052699804306, 47.55512461066246, 44.7594740241766, 42.89029732346535, 34.60733078420162, 30.645199790596962, 30.165334939956665, 22.01337207108736, 28.626060336828232, 13.251481130719185, 6.9131813663989305, 5.634577050805092, 3.78442854154855, 1.8879015021957457, 0.3479334362782538, 0.020685366398538463, 0.03890267988026608, 0.2768456336343661, 0.08596378174843267, 0.047580857572029345, 0.053191237966530025, 0.14977473736507818, 0.10919097796431743, 0.05894980669836514, 0.024833346651575994, 0.03505573513393756, 0.1903429933008738, 1.8630910897627473, 9.401237983256578, 49.20755334198475, 49.05663304030895, 67.64808923006058, 61.08003906905651, 40.485204979777336, 36.37460455298424, 44.062010049819946, 44.3873143941164, 44.922314286231995, 43.548406809568405, 42.45025433599949, 39.66093800961971, 39.14306379854679, 43.65377135574818, 42.29800030589104, 43.745490834116936, 45.341477394104004, 48.577205166220665, 50.175980776548386, 47.74805165827274, 52.21973530948162, 50.451834574341774, 49.23180744051933, 44.921938106417656, 41.38800233602524, 44.27278473973274, 45.921881049871445, 41.35594725608826, 44.99897517263889, 49.75236810743809, 53.427990674972534, 54.79223147034645, 53.053908348083496, 51.25185884535313, 50.9111425280571, 52.75546856224537, 51.39627009630203, 55.15048764646053, 54.928013384342194, 54.18033130466938, 52.69059084355831, 51.814304664731026, 48.26644264161587, 49.823591485619545, 49.41682331264019, 49.857421070337296, 52.537774443626404, 56.09858237206936, 57.9510323703289, 61.252283826470375, 58.329362869262695, 50.79674206674099, 2.0456235576421022, 20.460581593215466, 60.70121459662914, 41.91141664981842, 27.576801739633083, 42.77874290943146, 69.76698473095894, 34.126496985554695, 27.093606367707253, 33.94109733402729, 28.61894141882658, 51.87137380242348, 48.53500083088875, 32.88760006427765, 64.00918409228325, 23.5939409583807, 0.26485499111004174, 0.06104650747147389, 0.032575039731455036, 0.040684116320335306, 0.09684892851510085, 0.07100743547198363, 0.10246890116832219, 0.10826647718204185, 0.11434859261498787, 0.11239715982810594, 0.4856774106156081, 0.21814673964399844, 0.14070658333366737, 0.27396889112424105, 0.31701722647994757, 0.3312344307778403, 0.36613825941458344, 0.12121049003326334, 0.3599485399900004, 0.558746539754793, 0.4012114758370444, 0.8593813609331846, 0.5836529564112425, 21.52104578912258, 90.00873416662216, 62.47053265571594, 57.626753970980644, 47.70804360508919, 73.01831066608429, 55.03648616373539, 47.133700624108315, 68.84690210223198, 68.60931605100632, 25.607568807899952, 54.26676146686077, 68.58028560876846, 41.93158216774464, 13.865924309939146, 20.299411341547966, 55.958632081747055, 68.26384618878365, 62.11165711283684, 60.837182700634, 52.98990838229656, 53.14691975712776, 52.09077022969723, 51.81764468550682, 49.744726717472076, 56.94535553455353, 59.332934617996216, 61.529589146375656, 60.21382994949818, 62.80624844133854, 64.83171075582504, 62.10661098361015, 50.26369147002697, 48.019999265670776, 47.32502795755863, 43.515899553895, 44.496178552508354, 46.81767538189888, 51.12520024180412, 52.237943932414055, 46.006783694028854, 52.66463443636894, 51.24513700604439, 61.39948792755604, 65.64549788832664, 65.03845006227493, 65.22863745689392, 62.90452256798744, 63.61482985317707, 53.39517943561077, 51.25567004084587, 46.971107348799706, 50.50999045372009, 53.81332039833069, 55.86587145924568, 57.016320526599884, 62.12087921798229, 52.007296308875084, 50.06545230746269, 47.45940774679184, 41.940078511834145, 42.00997196137905, 40.54193593561649, 24.95502222329378, 31.564756147563457, 13.958888221532106, 6.831346107646823, 17.13869534432888, 14.61758952587843, 4.650120651349425, 1.1692270659841597, 0.46496041759382933, 0.46316097665112466, 0.5349347612354904, 0.19129138381686062, 0.20267373241949826, 0.21404411760158837, 0.18381016416242346, 0.5398976511787623, 0.2689609973458573, 0.2562019944889471, 0.20154118537902832, 0.2637739491183311, 2.3901332588866353, 23.020204044878483, 47.56680138409138, 41.683554276824, 64.36682090163231, 62.12187856435776, 50.0630584359169, 41.48047037422657, 49.921991005539894, 47.73035600781441, 54.40957300364971, 52.18282409012318, 49.08235765993595, 44.49077904224396, 43.441472947597504, 47.839695140719414, 43.98047782480717, 47.905074432492256, 49.710167571902275, 51.272848919034004, 55.35244680941105, 51.049329712986946, 54.742731526494026, 57.93724291026592, 54.12627540528774, 49.608800411224365, 45.1757986843586, 46.90959244966507, 50.18722057342529, 46.52397394180298, 47.62399211525917, 52.75570034980774, 59.979785308241844, 57.88196347653866, 53.33838768303394, 51.22844450175762, 53.52189123630524, 58.94941359758377, 57.922974675893784, 63.557061553001404, 61.13933488726616, 57.93433226644993, 54.734858348965645, 56.5831133723259, 52.04596683382988, 52.27846875786781, 50.977597162127495, 51.19824752211571, 53.91328923404217, 58.11812840402126, 59.49585847556591, 64.65251237154007, 60.350379422307014, 55.57323016226292, 2.767102480866015, 19.679056629538536, 68.45301523804665, 50.74103705585003, 33.07910978794098, 46.71809792518616, 83.08023154735565, 54.75535064935684, 43.09000700712204, 45.4671024531126, 27.402185909450054, 54.61248591542244, 68.7693102657795, 40.638313964009285, 66.9097888469696, 26.794102638959885, 0.5844069190789014, 0.1691259114886634, 0.3017802519025281, 0.37578775256406516, 0.2730317070381716, 0.23387566907331347, 0.30478265485726297, 0.2082739194156602, 0.4239787260303274, 0.38432818022556603], [0.05923987882852089, 0.06475257774582133, 0.07137789332773536, 0.11310833026072942, 0.021885356109123677, 0.12572124134749174, 0.18696265906328335, 0.10646264272509143, 0.027108598878839985, 0.047171782061923295, 0.24753321980824694, 0.36548890988342464, 0.07251784700201824, 13.59067277982831, 71.67923972010612, 39.82703849673271, 28.699842877686024, 34.08800505101681, 47.82929129898548, 28.317484594881535, 43.70248094201088, 71.77776843309402, 64.74256753921509, 30.177091509103775, 24.91851758211851, 59.029775485396385, 47.13993988931179, 19.861433543264866, 7.750873016193509, 36.238625049591064, 58.37871082127094, 58.938622176647186, 55.177990570664406, 53.545909747481346, 51.4399753510952, 49.19565238058567, 49.84471075236797, 52.90488414466381, 55.75008787214756, 56.958062052726746, 57.93129622936249, 58.61709862947464, 57.292930483818054, 60.202810540795326, 56.22241012752056, 51.98344498872757, 41.08095221221447, 42.650465592741966, 40.77431246638298, 40.596098229289055, 42.51424290239811, 46.97610028088093, 44.519057124853134, 48.07203747332096, 49.53351505100727, 49.72787082195282, 47.12463431060314, 52.695541977882385, 57.81192183494568, 55.024664998054504, 53.61586019396782, 51.414357125759125, 49.098696783185005, 44.50424171984196, 40.77405408024788, 43.332183212041855, 45.8578734844923, 45.41201300919056, 47.222110480070114, 45.123874470591545, 43.8786356896162, 36.98900878429413, 37.69851811230183, 27.31573484838009, 18.282209783792496, 21.378543935716152, 12.473097648471594, 24.74163517355919, 7.401388669386506, 0.8372576418332756, 5.00978940166533, 1.5924300695769489, 2.951104282401502, 1.059063021093607, 0.3053158731199801, 0.08637189617729746, 0.2723204920766875, 0.11153636500239372, 0.10715703319874592, 0.14722802792675793, 0.25263048300985247, 0.10048309210105799, 0.020419794418558013, 0.07896475770394318, 0.013280902439873898, 0.06867211195640266, 0.9173302701674402, 1.4235199894756079, 39.74069952964783, 38.0220365524292, 58.10634903609753, 51.46256513893604, 35.34731447696686, 33.48851501941681, 40.29278330504894, 41.124965250492096, 36.674450263381004, 37.47835032641888, 36.363068372011185, 35.83619624376297, 37.251149117946625, 38.457721173763275, 39.349806904792786, 41.555618941783905, 43.34358260035515, 45.079291462898254, 43.243609964847565, 47.15193584561348, 47.648538798093796, 44.63963985443115, 40.89336767792702, 40.3714694827795, 39.641118273139, 40.8272360265255, 41.08710788190365, 40.2922323346138, 40.97989283502102, 45.91368868947029, 46.64555601775646, 51.70217648148537, 49.03761886060238, 47.42503099143505, 47.47147969901562, 45.201667696237564, 46.14228442311287, 44.97427649796009, 43.768335208296776, 43.58359292149544, 45.11891573667526, 45.307461619377136, 45.92196464538574, 47.19190590083599, 49.9750779569149, 51.41650401055813, 53.80412869155407, 57.73213371634483, 56.50895655155182, 56.076000183820724, 57.89231792092323, 39.90353599190712, 0.9111094102263451, 31.640586778521538, 53.47707264125347, 34.92513433098793, 16.686891987919807, 32.21058279275894, 55.73935344815254, 40.57608090341091, 25.30498344451189, 32.19875022768974, 20.134304501116276, 42.298976853489876, 81.71464562416077, 31.114778593182564, 54.797019213438034, 36.724341586232185, 0.8482376276515424, 0.14639873726991937, 0.09398167065228336, 0.10033315600594506, 0.19733585009817034, 0.08022778914892115, 0.015557023907604162, 0.04415046176291071, 0.07584671329823323, 0.11815370249678381, 0.06725789018673822, 0.09851415947196074, 0.09900008066324517, 0.06681554048554972, 0.06345976391457953, 0.19868682604283094, 0.14496633288217708, 0.033056307656806894, 0.12644010043004528, 0.04558835062198341, 0.03863451966026332, 0.30770544020924717, 0.09726596355903894, 19.325544498860836, 78.0657622218132, 49.64163064956665, 33.865116611123085, 40.63565790653229, 52.108887657523155, 29.57117412239313, 34.21472065150738, 60.355421751737595, 62.374500408768654, 29.992877393960953, 31.117881126701832, 61.02719530463219, 56.48536741733551, 26.34957779198885, 8.042641784995794, 34.93408665060997, 59.64877746999264, 62.004533261060715, 59.01628240942955, 56.72038100659847, 54.1062580794096, 51.54720939695835, 50.746349170804024, 54.55239973962307, 58.99744302034378, 62.19962999224663, 62.168429866433144, 63.58302555978298, 59.49499972164631, 60.480997413396835, 58.87302249670029, 54.15883585810661, 46.37787938117981, 47.188771069049835, 47.49619357287884, 44.799227491021156, 46.7290223389864, 46.96699596941471, 46.51824004948139, 49.6021431684494, 49.32503543794155, 49.39215883612633, 47.463838309049606, 54.95577089488506, 58.80603589117527, 57.025797218084335, 59.79505442082882, 55.16283318400383, 52.34209634363651, 45.97146078944206, 44.928557351231575, 45.36910571157932, 49.96405094861984, 49.14397895336151, 51.7892412096262, 51.19257062673569, 48.84501099586487, 43.1071212887764, 43.77374991774559, 29.121895730495453, 24.81113724410534, 32.18488097190857, 36.1347272247076, 44.03082512319088, 18.26857041567564, 6.37450659647584, 7.881526155397296, 6.561116483062506, 4.5702755358070135, 0.8365794376004487, 0.08484671590849757, 0.10322228496079333, 0.09012854381580837, 0.13643959042383358, 0.04196295922156423, 0.10942147418973036, 0.12898073910037056, 0.15152541920542717, 0.12089203446521424, 0.015829531257622875, 0.07741599198197946, 0.11504621143103577, 0.5952536745462567, 2.6899625826627016, 40.508786514401436, 52.02767841517925, 61.599125415086746, 49.720123037695885, 38.70956405997276, 37.25163549184799, 41.663255766034126, 47.205277383327484, 40.21953843533993, 44.34558883309364, 40.51546275615692, 39.58104729652405, 40.84300898015499, 40.678952783346176, 43.79230432212353, 45.86682580411434, 47.94749155640602, 48.2981101423502, 44.63269762694836, 49.51194740831852, 47.379790619015694, 46.07224278151989, 43.8291547447443, 43.695694506168365, 42.06307031214237, 45.519011467695236, 42.13043689727783, 42.807005792856216, 42.9584314674139, 48.52779641747475, 49.60072584450245, 55.12338750064373, 51.07709102332592, 47.7043654024601, 47.18735374510288, 45.00720173120499, 45.30333884060383, 49.19140800833702, 49.503017887473106, 46.607793644070625, 46.591929495334625, 46.77340395748615, 46.10522881150246, 48.15733529627323, 50.59445612132549, 53.333805128932, 56.09144255518913, 60.28456315398216, 60.901463851332664, 60.75530469417572, 63.07533100247383, 40.99683232605457, 1.084168036468327, 39.2532616853714, 58.02181117236614, 37.69356697797775, 17.617674842476845, 31.486522145569324, 48.74355264008045, 37.39434063434601, 25.630150996148586, 32.3364282399416, 25.780320838093758, 45.91569498181343, 91.98250785470009, 41.03331036865711, 65.51771834492683, 60.163399055600166, 3.8247925881296396, 0.22143062436953187, 0.17729544342728332, 0.09428069679415785, 0.3541044832672924, 0.04013904595922213, 0.060621145530603826, 0.08995388678158633, 0.04762133059557527, 0.17294580495217815, 0.2168966957833618, 0.19538958265911788, 0.23872425343142822, 0.16279960720567033, 0.16354179941117764, 0.315223693032749, 0.6212020665407181, 0.21146200771909207, 0.32239524414762855, 0.15179428446572274, 0.32875969482120126, 0.3039886459009722, 0.27873362763784826, 24.400603473186493, 93.39863106608391, 54.97255079448223, 40.198457166552544, 50.045305788517, 72.03003689646721, 40.718311071395874, 55.19049569964409, 77.60139673948288, 70.04665732383728, 36.415171176195145, 38.037269935011864, 71.91887006163597, 60.94906769692898, 27.766231074929237, 9.575706571340561, 40.43293498456478, 64.14561197161674, 64.26592871546745, 59.5676252245903, 56.999821811914444, 55.99105954170227, 53.55434909462929, 51.42370082437992, 52.67581343650818, 56.607283875346184, 61.83244429528713, 63.66008922457695, 64.11893740296364, 60.15867970883846, 62.66512021422386, 61.34319394826889, 56.92637175321579, 45.30595310032368, 48.48107412457466, 48.915710002183914, 44.92647886276245, 47.94958524405956, 49.815710708498955, 50.56299760937691, 53.94051857292652, 54.033906161785126, 52.26135827600956, 52.998701110482216, 61.63897767663002, 64.86446499824524, 63.6549860984087, 62.260829508304596, 59.75558593869209, 54.240592271089554, 48.23281444609165, 45.788424611091614, 46.209647208452225, 54.52037885785103, 53.782515451312065, 59.454246908426285, 55.956857576966286, 55.15527918934822, 46.31905093789101, 49.5025809109211, 35.86857050657272, 36.2831624597311, 42.80866630375385, 42.43753641843796, 52.00566999614239, 22.552213557064533, 6.625689268112183, 15.749184004962444, 11.927623618394136, 5.962036354467273, 2.0921280747279525, 0.40033698838669807, 0.27482212346512824, 0.3275192395085469, 0.29956660349853337, 0.18715837824856862, 0.28235171630512923, 0.5689879402052611, 0.4984874732326716, 0.25582768488675356, 0.18577995768282562, 0.13596379954833537, 0.22652794694295153, 1.6655158228240907, 5.868601743131876, 48.315687999129295, 38.28232638537884, 59.14550207555294, 54.32610668241978, 48.98529186844826, 41.143477857112885, 49.01998780667782, 52.7536104619503, 46.48035608232021, 52.30299264192581, 45.51706597208977, 45.482514426112175, 43.715632036328316, 44.170194044709206, 44.434146881103516, 47.98062577843666, 50.71422569453716, 51.810170486569405, 49.04540844261646, 53.3181157708168, 52.93202228844166, 53.63104797899723, 49.9701040238142, 49.531109780073166, 44.53216642141342, 48.16806212067604, 47.23891697824001, 45.11239528656006, 44.57138791680336, 53.08439411222935, 54.23800081014633, 59.38083104789257, 53.91989327967167, 50.1488084346056, 49.84412558376789, 48.393952399492264, 50.211763456463814, 54.9566600471735, 53.9412747323513, 49.26501005887985, 47.189037054777145, 47.10094258189201, 48.17395560443401, 49.36704598367214, 49.89296816289425, 53.194633796811104, 54.73467595875263, 59.89392511546612, 60.5829231441021, 61.96701407432556, 65.62551096081734, 48.35525147616863, 2.0203888742253184, 38.428059965372086, 64.35482114553452, 44.35812056064606, 26.45097155123949, 36.70379228889942, 61.15105725824833, 49.37719143927097, 34.643478244543076, 43.318754732608795, 28.495831824839115, 45.78341647982597, 84.30873602628708, 45.26653401553631, 67.35121876001358, 63.611968606710434, 3.1423275964334607, 0.26913605513982475, 0.33132808981463313, 0.30494462116621435, 0.5723782489076257, 0.18440167070366442, 0.1863799395505339, 0.20581390766892582, 0.10038857959443703, 0.5293630727101117], [0.11436618151492439, 0.03572156776499469, 0.06695570249576122, 0.06290418474236503, 0.018519150507927407, 0.2502814371837303, 0.15360490215243772, 0.008791983254923252, 0.07895289818407036, 0.11161097310832702, 0.13010443974053487, 0.30046665051486343, 0.21285619150148705, 24.265364930033684, 63.853438049554825, 39.24679063260555, 34.635734260082245, 30.37263471633196, 36.30650460720062, 21.664539389312267, 34.11703549325466, 62.73607760667801, 46.00996792316437, 36.9076057523489, 25.506604425609112, 52.84252569079399, 54.30252134799957, 33.57005104422569, 6.903633903712034, 19.48289405554533, 53.44797760248184, 55.34406825900078, 53.49059231579304, 51.5507660061121, 51.66463449597359, 46.58283278346062, 49.529840648174286, 51.37451246380806, 58.08703847229481, 65.36045998334885, 61.07982628047466, 61.545229107141495, 62.383479326963425, 59.934518337249756, 56.40987306833267, 53.04998315870762, 45.374098643660545, 44.03900608420372, 45.27253769338131, 42.241204753518105, 45.15216015279293, 46.53147853910923, 45.483053997159004, 46.12477496266365, 49.284898191690445, 47.14523300528526, 43.330484703183174, 44.61589872837067, 50.66656865179539, 51.26448556780815, 55.20202428102493, 53.40124011039734, 47.72250942885876, 43.82571592926979, 40.23871600627899, 40.75839512050152, 40.78635022044182, 45.86613044142723, 45.15635132789612, 46.68397195637226, 45.04657901823521, 38.96949291229248, 35.71887753903866, 26.195382066071033, 19.480661675333977, 26.171053871512413, 29.282363019883633, 35.253611505031586, 9.713374134153128, 1.9321567774750292, 7.642302867025137, 3.790930942632258, 2.1942924801260233, 0.34237308776937425, 0.18247621308546513, 0.14809907181188464, 0.11451999162090942, 0.10605507748550735, 0.021541962523770053, 0.15923568047583103, 0.10018323475378565, 0.10402436848380603, 0.0370027595636202, 0.06720999197568744, 0.060293068017927, 0.11189105222001672, 1.134254930075258, 1.4038213714957237, 16.297334991395473, 47.29916654527187, 49.20894406735897, 40.211372673511505, 35.19484765827656, 36.42443887889385, 36.5166637301445, 44.78924922645092, 36.381341591477394, 37.11269974708557, 35.29515087604523, 33.4217070043087, 33.828475177288055, 36.28798820078373, 39.38486762344837, 41.324937120079994, 42.86531366407871, 41.675852090120316, 39.800398126244545, 43.40259723365307, 42.01439872384071, 38.56487162411213, 36.03809081017971, 36.232811361551285, 38.0761456489563, 39.71525229513645, 39.539713114500046, 38.88158082962036, 40.81009514629841, 46.995467841625214, 44.64051000773907, 48.44462268054485, 49.52844612300396, 47.52161420881748, 48.223375752568245, 44.95589688420296, 43.97557608783245, 42.42749735713005, 40.723987966775894, 41.51781477034092, 44.378517866134644, 43.84557746350765, 43.90266939997673, 48.37767407298088, 49.47057522833347, 53.52705895900726, 57.19749480485916, 59.54323053359985, 59.86237160861492, 52.74853773415089, 61.28350295126438, 25.35337384790182, 1.334334856364876, 46.0485814511776, 51.311481446027756, 32.102710381150246, 10.831858366727829, 24.636441618204117, 31.492953300476074, 17.059798277914524, 18.76529686152935, 34.367100074887276, 20.23080412298441, 28.654625304043293, 52.83450432121754, 41.20150454342365, 40.927425250411034, 57.466862350702286, 11.389640886336565, 0.5698555405251682, 0.15663739177398384, 0.03235283700632863, 0.1435700710862875, 0.013876832181267673, 0.0748425058554858, 0.06158832722576335, 0.07642181095434353, 0.05336012851330452, 0.10323879032512195, 0.023840822468628176, 0.025184723890561145, 0.0504373246076284, 0.056098471613950096, 0.1256987394299358, 0.15076523734023795, 0.14431592950131744, 0.12069310920196585, 0.06007048308674712, 0.031192793394438922, 0.04716887655376922, 0.0852508153184317, 32.30026178061962, 73.21107432246208, 44.32761959731579, 31.62666242569685, 33.82418520748615, 45.17941989004612, 29.780035614967346, 31.38957604765892, 50.8891075104475, 49.9304835498333, 43.198194801807404, 27.014468014240265, 58.109331876039505, 57.625853419303894, 38.9795433729887, 9.046831950545311, 16.57234713435173, 50.95349885523319, 58.08698147535324, 60.31402677297592, 56.35737508535385, 56.53347663581371, 53.65634702146053, 53.07107202708721, 55.889490991830826, 61.50285378098488, 64.71199437975883, 63.38473320007324, 61.35770536959171, 60.24451330304146, 58.86998265981674, 58.533871695399284, 55.26454232633114, 50.04804164171219, 48.03532004356384, 48.4835097938776, 44.29421938955784, 48.511742278933525, 48.406772911548615, 47.666314244270325, 46.08175367116928, 47.608800530433655, 45.938653349876404, 46.48517802357674, 46.30161367356777, 55.31435765326023, 52.88078583776951, 57.82783158123493, 54.5671771466732, 50.64168378710747, 46.39881245791912, 46.88606411218643, 44.18538182973862, 45.78797243535519, 50.64157359302044, 49.89452987909317, 52.526549845933914, 47.9163484275341, 43.27507987618446, 39.85062763094902, 29.82978254556656, 27.653432227671146, 41.696766167879105, 52.20169387757778, 48.7265295535326, 23.17214459180832, 12.569528874009848, 16.882380098104477, 10.234376527369022, 3.6394397215917706, 0.8649289445020258, 0.18039319751551375, 0.22266561747528613, 0.19350200425833464, 0.08871416619513184, 0.02592777327663498, 0.11737942724721506, 0.034295378864044324, 0.10343983813072555, 0.07378041089395992, 0.035356920925551094, 0.034731550185824744, 0.10302447291905992, 0.7040101918391883, 1.9923440041020513, 13.964106291532516, 48.64821195602417, 51.96078680455685, 42.571657821536064, 38.2920690625906, 40.334744453430176, 37.83079281449318, 49.82019066810608, 41.724447682499886, 42.13337793946266, 38.777994588017464, 40.52605278789997, 38.3278289437294, 42.26132847368717, 42.600847855210304, 45.180179849267006, 44.80027623474598, 46.1718962341547, 42.238993272185326, 44.12823669612408, 40.711828619241714, 40.37765175104141, 40.63349962234497, 41.51929669082165, 40.901461243629456, 43.782903626561165, 40.64971335232258, 40.72110392153263, 45.50550699234009, 49.5458871871233, 48.728668838739395, 50.834949016571045, 50.57411961257458, 46.62899270653725, 47.735447734594345, 46.18584528565407, 47.04608492553234, 46.22323527932167, 46.80278018116951, 44.73339602351189, 46.543865874409676, 47.112547159194946, 47.700314819812775, 47.7381531894207, 51.26164712011814, 54.623999297618866, 58.457286804914474, 61.53901644051075, 63.83717492222786, 56.90787814557552, 63.72930631041527, 21.41695987433195, 2.0844584237784147, 53.046206161379814, 54.97257739305496, 34.46661673486233, 13.010708950459957, 27.305072620511055, 34.156484976410866, 18.87468159198761, 20.23105300962925, 31.664259508252144, 27.060483545064926, 32.788193598389626, 63.56558449566364, 47.65584200620651, 54.028563648462296, 67.37497508525848, 25.322318114340305, 0.8177664096001536, 0.1020679558860138, 0.13927570777013898, 0.10446633968967944, 0.02872542325349059, 0.056672589635127224, 0.039542715458082967, 0.07134748011594638, 0.03960572379583027, 0.3484023845521733, 0.20514702860964462, 0.10953751640045084, 0.30022744147572666, 0.09646105245337822, 0.5045246961526573, 0.4721075372071937, 0.22359438560670242, 0.36835463892202824, 0.13564169261371717, 0.13781591813312843, 0.1924735211650841, 0.23780225368682295, 38.30440320074558, 85.35814091563225, 50.62711536884308, 46.92868262529373, 47.22395338118076, 56.525907441973686, 29.577677473425865, 43.633898422122, 69.25095722079277, 48.84782664477825, 47.75604262948036, 39.94679667055607, 66.09477818012238, 66.58305197954178, 40.319495871663094, 9.225624706596136, 22.14569617062807, 55.47188960015774, 58.889904990792274, 60.80500602722168, 58.05894657969475, 56.549352183938026, 54.263170659542084, 55.40075361728668, 54.42740544676781, 60.92691868543625, 67.5963132083416, 63.695491924881935, 65.09931519627571, 61.68087802827358, 60.57971611618996, 61.197847947478294, 57.69182167947292, 49.75628949701786, 49.99717377126217, 50.29875598847866, 43.811561688780785, 51.30201995372772, 53.73938396573067, 50.81265941262245, 50.21885767579079, 52.45520867407322, 50.21856889128685, 51.142994686961174, 52.49006040394306, 61.224492117762566, 59.66014266014099, 63.08244802057743, 58.35952565073967, 54.09875728189945, 47.676269710063934, 48.739095479249954, 45.38363993167877, 49.22594055533409, 56.468796506524086, 54.78735253214836, 58.76760855317116, 56.83506265282631, 47.1390051394701, 46.720617190003395, 34.825245290994644, 39.782622680068016, 54.83074240386486, 59.67549003660679, 60.826638266444206, 26.833897903561592, 13.021194487810135, 24.65227346867323, 13.79992850124836, 5.217071129009128, 0.9418755280785263, 0.26056478382088244, 0.5310711998026818, 0.18647428136318922, 0.3277445852290839, 0.13091188156977296, 0.6026338285300881, 0.20710852491902187, 0.35304558696225286, 0.23871917714131996, 0.11708495789207518, 0.10742609883891419, 0.3871279174927622, 1.9471880584023893, 1.6108480375260115, 23.67795255035162, 44.59755331277847, 49.29293096065521, 43.88607569038868, 47.15020313858986, 47.03641824424267, 46.05439133942127, 55.87867297232151, 47.98024959862232, 47.26003244519234, 43.01958918571472, 44.898561760783195, 41.06889545917511, 45.77768638730049, 46.64288096129894, 50.64709089696407, 50.34238524734974, 49.14059333503246, 44.664870500564575, 47.823823392391205, 45.86093612015247, 45.52450977265835, 43.22058320045471, 42.67671078443527, 41.95913068950176, 46.913122460246086, 44.85029295086861, 43.53419557213783, 47.90377490222454, 54.68637675046921, 52.53861799836159, 56.201036274433136, 54.484257996082306, 50.89940495789051, 50.788659900426865, 47.9803141951561, 49.698418602347374, 49.778237119317055, 49.218473955988884, 45.34822203218937, 47.97923885285854, 47.002809047698975, 46.741291880607605, 49.97636988759041, 51.112296134233475, 56.779578030109406, 59.63738188147545, 62.96481393277645, 65.71307346224785, 59.9280396848917, 66.52542427182198, 30.706549398601055, 2.499019503593445, 55.87719485163689, 62.335354909300804, 46.09711244702339, 19.975799806416035, 30.215433351695538, 42.87610128521919, 22.76273936033249, 27.752021737396717, 47.5191405415535, 30.725554078817368, 33.91237087547779, 55.25055147707462, 58.64753499627113, 52.53405064344406, 76.06444761157036, 26.884889267385006, 0.6858867674600333, 0.3855683980509639, 0.23097608325770125, 0.22249731322517619, 0.08345387541339733, 0.26370098115876317, 0.12616035528481007, 0.36636176460888237, 0.2940334769664332], [0.11459762026788667, 0.15541130444034934, 0.09165465919068083, 0.07337331320741214, 0.0305397071497282, 0.1371886846027337, 0.11074040419771336, 0.16034612635849044, 0.05846690233738627, 0.08672259806189686, 0.22372478095348924, 0.17813801852753386, 0.21546723030041903, 34.16091173887253, 57.21846207976341, 40.790085420012474, 37.34411872923374, 52.410116493701935, 41.34498104453087, 22.010632418096066, 19.965091980993748, 38.24896417558193, 19.697918817400932, 25.871061868965626, 20.35638928413391, 46.8331291526556, 67.99536779522896, 33.83678153157234, 5.748393293470144, 3.28592830337584, 32.33305782079697, 53.74671757221222, 53.03750842809677, 52.83444732427597, 52.03726150095463, 50.57760402560234, 48.978421837091446, 53.645449206233025, 60.072253346443176, 66.3645789027214, 67.24384412169456, 61.25944644212723, 59.05780278146267, 55.67564606666565, 56.95088803768158, 53.79418462514877, 48.61355021595955, 43.78141410648823, 46.986310333013535, 46.05005957186222, 42.87072837352753, 44.21633496880531, 46.2119422852993, 45.308445766568184, 45.789815336465836, 43.41438800096512, 44.07197691500187, 41.585614532232285, 46.97812557220459, 50.1684457808733, 54.13339622318745, 53.842027857899666, 46.13076724112034, 42.098693400621414, 38.93053360283375, 38.92232984304428, 40.68885125219822, 43.98214973509312, 45.57074189186096, 44.53010693192482, 40.8543361723423, 35.094403848052025, 29.5729923248291, 22.157112658023834, 22.750809900462627, 33.38592812418938, 49.174707904458046, 38.67556348443031, 23.796382695436478, 6.598268989473581, 14.967790134251118, 6.737499218434095, 0.2290883712703362, 0.8857895282562822, 0.3205330471973866, 0.2108066319487989, 0.5114268476609141, 0.07776875703711994, 0.16276177251711488, 0.07354578090598807, 0.27021608781069517, 0.07656782850972377, 0.04941638915624935, 0.009648400337027851, 0.01699630985967815, 0.14841371274087578, 0.7080030057113618, 0.18593037617392838, 4.4211924355477095, 36.30869708955288, 42.688744738698006, 40.27541823685169, 39.162180572748184, 35.51588863134384, 32.136220782995224, 41.20905473828316, 41.42637647688389, 35.799114033579826, 36.916896253824234, 32.54099026322365, 33.40642422437668, 32.895579636096954, 37.52863682806492, 40.34252643585205, 42.24528193473816, 38.212531730532646, 36.394899263978004, 36.73308491706848, 35.81506937742233, 36.16523198783398, 36.8507494032383, 33.53229247033596, 36.74831449985504, 38.374653831124306, 37.745783776044846, 37.99598515033722, 41.06444209814072, 41.199422255158424, 44.832608699798584, 46.00873298943043, 47.09910348057747, 44.727099761366844, 45.923476964235306, 44.825947657227516, 43.51815663278103, 42.488985657691956, 42.661902979016304, 41.43239915370941, 46.219317689538, 44.1237111389637, 46.87978684902191, 46.41677789390087, 51.25862628221512, 53.62808033823967, 60.79743303358555, 60.08486866950989, 61.38615824282169, 56.81090734899044, 56.616855561733246, 7.459933552891016, 3.6239044927060604, 55.41481286287308, 47.239935323596, 22.58364737033844, 8.613700792193413, 21.248879693448544, 27.622910365462303, 13.689992800354958, 22.204724103212357, 28.978719413280487, 23.192944675683975, 19.997895620763302, 26.602363027632236, 29.754996858537197, 46.95973455905914, 65.55811777710915, 45.56147038936615, 6.9753137324005365, 0.27673276781570166, 0.24382531642913818, 0.07265721491421573, 0.1559694588650018, 0.06898322768392973, 0.11220606422284618, 0.40760104078799486, 0.010288974899594905, 0.06906245936988853, 0.02596966936835088, 0.03681321504700463, 0.08976826822618023, 0.07930453517474234, 0.11113439555629157, 0.11804041365394369, 0.024892777837521862, 0.041551037575118244, 0.058379518159199506, 0.08867533702868968, 0.17576655984157696, 0.2522663556737825, 44.75176423788071, 63.73221315443516, 47.24787309765816, 28.95279910415411, 52.1664659678936, 45.2139600366354, 26.833867505192757, 23.494878374040127, 34.709336310625076, 23.276498392224312, 31.201429143548012, 22.68088985234499, 46.75658605992794, 64.14474561810493, 36.42472006380558, 8.273103218525648, 2.111377129331231, 27.674251310527325, 57.58516140282154, 60.557479709386826, 59.17656160891056, 61.48081876337528, 57.23881758749485, 55.517764538526535, 58.35508368909359, 61.52772344648838, 65.83232626318932, 67.20655292272568, 61.07024699449539, 59.11268323659897, 58.905708342790604, 60.042060166597366, 56.92196398973465, 52.40375563502312, 48.31283815205097, 49.91509057581425, 46.12433418631554, 48.78836363554001, 47.64429822564125, 48.32072272896767, 49.04277138411999, 46.248484924435616, 46.18202269077301, 48.116426691412926, 45.33203490078449, 48.94437566399574, 53.07611055672169, 53.99132564663887, 52.592434510588646, 47.840880677103996, 47.25667342543602, 43.7071280926466, 44.50701557099819, 46.82023264467716, 48.13454791903496, 49.73856724798679, 48.581012561917305, 48.02009426057339, 42.804551124572754, 37.54189431667328, 25.62886856496334, 31.226572394371033, 49.10175941884518, 63.40894170105457, 47.05487385392189, 41.63071051239967, 28.522134013473988, 28.37085273116827, 9.698024857789278, 3.075008508749306, 1.378250049892813, 0.09496645609033294, 0.6089230254292488, 0.07793255645083264, 0.017083992752304766, 0.14128761074971408, 0.1414414431201294, 0.07315050563192926, 0.05031576823967043, 0.14739795005880296, 0.013814078956784215, 0.0534320611768635, 0.1850430792546831, 0.8892896154429764, 2.2959059150889516, 5.732940947636962, 28.1168382614851, 47.65173442661762, 46.848936304450035, 44.47901487350464, 40.28350040316582, 33.550656884908676, 44.39372085034847, 43.79507437348366, 41.88702575862408, 38.789838552474976, 39.78711023926735, 37.766165882349014, 40.486645102500916, 42.521295323967934, 44.85578365623951, 45.814092233777046, 43.15352059900761, 40.01011647284031, 40.36689452826977, 40.00293105840683, 38.89100432395935, 41.00892707705498, 40.36816745996475, 41.00505128502846, 41.994206607341766, 43.04532140493393, 42.577498108148575, 46.90632842481136, 46.045750603079796, 47.83418543636799, 48.072744235396385, 47.83645771443844, 46.183269023895264, 45.55246487259865, 45.07316239178181, 46.361737847328186, 45.54248280823231, 46.66688807308674, 45.9655787050724, 49.23265479505062, 47.11899161338806, 51.91950961947441, 49.1462816298008, 53.6773294955492, 55.97027085721493, 65.1763978600502, 62.170360162854195, 64.53595742583275, 58.13753396272659, 60.26742607355118, 5.658859172835946, 6.165473638102412, 63.12548071146011, 52.61038474738598, 26.009307950735092, 11.71712726354599, 21.936447098851204, 29.95817195624113, 11.284447330981493, 25.372853502631187, 26.8133657053113, 32.946569100022316, 28.473169840872288, 42.57321193814278, 34.7578065097332, 55.35158805549145, 74.90206718444824, 64.34876427054405, 14.390572607517242, 0.6134004320483655, 0.1878802356077358, 0.061388273898046464, 0.1859890652121976, 0.010738713608589023, 0.0865016681200359, 0.17952038731891662, 0.04333606229920406, 0.23595426144311205, 0.2360489298007451, 0.09474986771238036, 0.1827553941984661, 0.184144590748474, 0.3723668970633298, 0.21743739489465952, 0.21120065299328417, 0.1667199726216495, 0.16599814494838938, 0.2292539889458567, 0.2190665277885273, 0.3840697347186506, 52.83070832490921, 73.50070238113403, 52.19599038362503, 48.78944277763367, 73.39783430099487, 53.30846048891544, 29.56730592995882, 28.550130911171436, 44.46032367646694, 24.05878521502018, 32.922660782933235, 33.412116318941116, 57.28206306695938, 75.98522946238518, 41.94243058562279, 7.770983912050724, 4.083980480208993, 35.15716888010502, 58.79214383661747, 60.937763303518295, 60.62072731554508, 61.02901540696621, 57.737495228648186, 55.69359630346298, 57.8290057182312, 62.476160153746605, 67.54662707448006, 69.90854993462563, 64.77377906441689, 63.359103575348854, 60.17021968960762, 63.15407417714596, 60.14994777739048, 53.302578404545784, 50.37773855030537, 53.31186890602112, 47.97864228487015, 49.967550560832024, 51.58982031047344, 52.08339482545853, 51.817040517926216, 52.567754834890366, 49.06147018074989, 52.37675428390503, 48.369033336639404, 56.89891442656517, 57.74360530078411, 60.3119482845068, 55.20550489425659, 50.18047213554382, 48.60588602721691, 44.018825367093086, 45.17821915447712, 50.978334322571754, 55.168840661644936, 57.84696355462074, 56.00418783724308, 55.32489828765392, 46.23615078628063, 41.174142211675644, 31.871559284627438, 41.6021778434515, 62.35149264335632, 72.12481901049614, 57.218739464879036, 43.38451400399208, 31.48441705852747, 34.99826140701771, 13.547201212495565, 4.36377989128232, 2.086694841273129, 0.27781823300756514, 0.7800802693236619, 0.5351822823286057, 0.2673127467278391, 0.5543075466994196, 0.3151346353115514, 0.26768025825731456, 0.4483363393228501, 0.5635920516215265, 0.15702761302236468, 0.17206690914463252, 0.3469284198945388, 1.5016187424771488, 3.9113638177514076, 9.144199825823307, 36.535772904753685, 49.31310407817364, 50.48170477151871, 51.40720210969448, 48.32761935889721, 40.54359644651413, 53.698220774531364, 52.53831021487713, 47.034529745578766, 44.83264669775963, 43.41941513121128, 42.35648676753044, 43.37939187884331, 47.44633264839649, 49.24005679786205, 50.15746057033539, 45.600878074765205, 41.751813814044, 43.99243198335171, 42.8227711468935, 42.355118840932846, 44.30519700050354, 41.94988578557968, 42.32267618179321, 44.54674243927002, 44.91484008729458, 45.81314608454704, 48.78659673035145, 48.071836084127426, 50.06801716983318, 53.656031638383865, 52.44082264602184, 49.33668561279774, 50.157878547906876, 48.815714567899704, 49.60353009402752, 49.492545649409294, 48.60738314688206, 48.273609057068825, 50.522700771689415, 47.00662404298782, 52.55677342414856, 49.10048268735409, 54.704296588897705, 56.694648787379265, 65.54323017597198, 65.31167060136795, 66.38746127486229, 63.23907561600208, 65.50965517759323, 10.801324155181646, 4.819893641397357, 67.06197828054428, 55.701864659786224, 34.85328398644924, 15.333179477602243, 27.483522444963455, 36.80875025689602, 21.3135427236557, 35.42837172746658, 44.23979490995407, 34.67858076095581, 30.612684935331345, 37.058070078492165, 39.92977358400822, 60.985184758901596, 77.78255581855774, 70.93985259532928, 13.663328681141138, 0.5793315195478499, 0.7678486662916839, 0.33637234882917255, 0.19381983642233536, 0.1842351327650249, 0.26276418298948556, 0.48103257548063993, 0.16491432732436806], [0.15668531967094168, 0.08495934423990548, 0.03808998364547733, 0.2016942310729064, 0.05248833134828601, 0.08952165997470729, 0.11638969910563901, 0.10950601223157719, 0.11992459301836789, 0.1040069354348816, 0.05494918914337177, 0.17714901769068092, 0.22036804701201618, 51.647748202085495, 53.58877904713154, 48.080890998244286, 49.74238224327564, 44.48139734566212, 36.12465776503086, 34.340224117040634, 17.335365191102028, 9.685967154800892, 32.50852860510349, 26.21533289551735, 24.558407105505466, 35.47301173210144, 58.14107917249203, 52.66710810363293, 18.650153540074825, 0.27158814074937254, 3.94654446747154, 35.63975438475609, 53.54318529367447, 51.49747386574745, 56.860646679997444, 52.663771882653236, 51.130622550845146, 55.97666971385479, 62.626765072345734, 66.01994499564171, 70.76720505952835, 64.23074260354042, 56.459825187921524, 50.68675696849823, 54.361383989453316, 52.64819651842117, 51.82326838374138, 47.36176818609238, 48.94995756447315, 45.707165971398354, 44.31298278272152, 41.398744359612465, 45.63734091818333, 43.329234570264816, 41.069370433688164, 42.790697067976, 43.503911197185516, 43.52685436606407, 43.99566940963268, 46.58500626683235, 50.31670242547989, 45.25196559727192, 44.21215519309044, 43.446465879678726, 43.26049245893955, 41.07760839164257, 43.92873600125313, 42.50577695667744, 43.78549888730049, 41.71916216611862, 39.30522009730339, 35.73157645761967, 25.53192626684904, 18.99505153298378, 28.434007242321968, 49.02344562113285, 53.339717611670494, 50.46273618936539, 43.67844723165035, 14.576775915920734, 20.993200913071632, 6.642339499667287, 1.80983659112826, 2.048679543659091, 0.5369672959204763, 0.9024845855310559, 0.021537800930673257, 0.17894149728817865, 0.5640679760836065, 0.08181536177289672, 0.11439888796303421, 0.043331501801731065, 0.3422160493209958, 0.08646041955216788, 0.05441713976324536, 0.1241013259277679, 1.0524257272481918, 0.6491464795544744, 3.272961499169469, 16.07202038168907, 40.037923380732536, 36.58186063170433, 43.72446656227112, 36.928679421544075, 30.719582699239254, 41.09746992588043, 39.75042700767517, 35.37740886211395, 34.79691781103611, 31.541026420891285, 31.72501064836979, 34.86015021800995, 39.74948465824127, 42.43058659136295, 41.39306366443634, 36.883127465844154, 33.77316154539585, 36.70241296291351, 34.70546051859856, 34.92161191999912, 35.987158343195915, 36.76767446100712, 35.82225859165192, 36.70384168624878, 36.33882187306881, 38.389822617173195, 42.77107872068882, 46.17119327187538, 47.52606377005577, 43.53615626692772, 45.36106534302235, 43.57713706791401, 43.834706246852875, 43.469276055693626, 45.40945194661617, 40.761985927820206, 43.1716114282608, 46.28564313054085, 47.07843638956547, 47.22173050045967, 47.98850275576115, 50.068370550870895, 48.69250237941742, 54.2945721745491, 60.419144332408905, 59.51407469809055, 59.08256985247135, 59.628262370824814, 40.672641322016716, 0.7735339330974966, 14.999650474637747, 53.85745882987976, 43.239794969558716, 20.02011302858591, 8.218310158699751, 23.35540685802698, 21.16118799895048, 23.77948310226202, 21.70041136443615, 28.926994688808918, 26.157002225518227, 19.970219805836678, 37.80034504830837, 43.45800966024399, 29.77415733039379, 58.283837512135506, 72.08378881216049, 40.16680486500263, 1.5013215271756053, 0.032916980562731624, 0.08681437946506776, 0.1660412785713561, 0.083819346036762, 0.31761815829668194, 0.151663473516237, 0.20796974276890978, 0.04436404815351125, 0.04003605441539548, 0.0668955068977084, 0.13579770689830184, 0.05868852989806328, 0.06369820112013258, 0.14002373325638473, 0.00849427164212102, 0.061709538495051675, 0.0487978795717936, 0.12042709378874861, 0.13783637172309682, 3.0516148265451193, 60.68892225623131, 61.63095250725746, 52.309323102235794, 51.3694017380476, 41.49232193827629, 41.15260876715183, 33.73985253274441, 18.81450992077589, 18.29593274742365, 38.26954387128353, 40.115777403116226, 34.96726647019386, 37.812644988298416, 58.48111152648926, 54.717649072408676, 24.803872033953667, 0.7976385927759111, 2.8255575941875577, 32.58975304663181, 59.6383698284626, 57.64764524996281, 62.30280205607414, 57.802726328372955, 60.38876116275787, 61.947293132543564, 64.85610544681549, 65.09511262178421, 67.26941674947739, 60.969233214855194, 57.58060164749622, 55.40666230022907, 60.511961951851845, 58.610217198729515, 55.97726248204708, 52.348802983760834, 49.4760849326849, 46.91941112279892, 46.1592049151659, 43.597507774829865, 48.71539615094662, 43.92666891217232, 44.270805045962334, 46.050226762890816, 46.48544400930405, 48.19888226687908, 48.23076635599136, 49.42208983004093, 51.003956347703934, 49.43654805421829, 46.93664699792862, 48.39248947799206, 46.64906702935696, 47.6446820050478, 46.47178374230862, 47.01495319604874, 47.54816338419914, 47.53695398569107, 45.849730521440506, 43.24033074080944, 31.385025791823864, 23.960946165025234, 37.957136034965515, 57.556738927960396, 59.91008564829826, 58.26483093202114, 60.86104542016983, 39.86926183104515, 26.288845650851727, 8.04451983422041, 3.422585357911885, 1.0146352113224566, 0.10621068358886987, 1.32854622323066, 0.04251342128554825, 0.14307538513094187, 0.2099834120599553, 0.12000962829915807, 0.07777997830999084, 0.015406311340484535, 0.11676245019771159, 0.11282434745226055, 0.10564917465671897, 0.10943067682092078, 0.5390675144735724, 2.4131220253184438, 4.607405718415976, 12.451265919953585, 40.573683232069016, 45.08888974785805, 48.65177236497402, 41.565403416752815, 32.55565747618675, 45.946062952280045, 41.32711060345173, 40.1012621819973, 40.80887161195278, 38.79175364971161, 40.064575150609016, 41.56852304935455, 43.54569375514984, 44.27178919315338, 44.973113760352135, 40.540564209222794, 40.11481985449791, 39.588342905044556, 37.71481543779373, 39.810475185513496, 42.91956715285778, 42.57158562541008, 40.69253705441952, 42.612775415182114, 42.870948761701584, 42.235098481178284, 44.363873451948166, 45.79334154725075, 48.70370037853718, 47.91099451482296, 46.4751997590065, 46.75717122852802, 45.723280906677246, 47.20115080475807, 46.79469421505928, 43.48885640501976, 49.39036913216114, 48.945887982845306, 51.244114860892296, 51.53140604496002, 51.2580981105566, 52.784012630581856, 52.08825096487999, 59.3781977891922, 63.89620095491409, 62.79444247484207, 60.93154303729534, 63.2965437322855, 38.775843903422356, 0.9704809868708253, 21.397658810019493, 57.986047491431236, 49.85670290887356, 21.8397156894207, 14.827741049230099, 24.183329232037067, 24.496459029614925, 21.412261426448822, 24.31393962353468, 28.480043672025204, 31.955627873539925, 27.30987176299095, 42.0888215303421, 56.7027385532856, 31.111410073935986, 71.72882705926895, 68.49652290344238, 63.31335783004761, 1.9508210197091103, 0.06568743890966289, 0.06412384507711977, 0.13452677900204435, 0.11212060591788031, 0.16627336299279705, 0.15920026518870145, 0.00943766935961321, 0.1618041645269841, 0.12576603738125414, 0.08264502350357361, 0.28837566962465644, 0.2097944464185275, 0.15808129945071414, 0.3118429728783667, 0.26484281988814473, 0.16276868933346123, 0.2390370241482742, 0.23123868479160592, 0.5224627023562789, 4.639443224295974, 74.59908664226532, 68.72782409191132, 58.59606675803661, 65.86914628744125, 61.12685635685921, 47.07166515290737, 46.58970661461353, 24.392238222062588, 15.593585204333067, 38.03469367325306, 36.51963137090206, 38.3389775454998, 46.48554280400276, 68.00722315907478, 61.83763101696968, 23.024055138230324, 0.46687429770827293, 6.031589722260833, 41.9836051762104, 61.25550985336304, 57.28326000273228, 64.379763007164, 60.04967115819454, 61.46750047802925, 64.08937498927116, 66.88328146934509, 68.025933355093, 72.40239411592484, 65.03598779439926, 61.96367785334587, 54.773566871881485, 59.62877534329891, 59.0359653532505, 57.240998670458794, 54.26060579717159, 52.7883405983448, 50.94523809850216, 49.92183141410351, 47.28248544037342, 52.20695659518242, 46.58937603235245, 46.825217977166176, 50.79962991178036, 51.38418294489384, 51.78981877863407, 52.380257695913315, 52.28217355906963, 58.271754160523415, 52.643575966358185, 49.24589328467846, 47.91482850909233, 47.726487815380096, 47.62981720268726, 52.62402981519699, 49.58345577120781, 52.184306010603905, 52.87994988262653, 52.600649669766426, 45.95547504723072, 35.22030249238014, 28.472736664116383, 50.14800287783146, 73.29445704817772, 69.06895458698273, 66.40373960137367, 56.74020454287529, 51.36652149260044, 32.33158349990845, 11.096325125545263, 4.978214045986533, 3.109721071086824, 1.5512984641827643, 2.63990240637213, 0.1106035966950003, 0.6415677862241864, 1.3726433319970965, 0.26732750062365085, 0.18168109090765938, 0.2601539308670908, 0.5255139386281371, 0.2255303371930495, 0.15388055064249784, 0.1993388621485792, 1.222577034495771, 3.3952961722388864, 5.381536278873682, 25.40674388408661, 50.53047515451908, 47.10368983447552, 56.33253201842308, 49.463040232658386, 38.862650245428085, 54.588060826063156, 47.84784570336342, 46.66723385453224, 44.6996196359396, 42.171334102749825, 42.75636211037636, 43.59825633466244, 49.058221355080605, 50.18427953124046, 50.32784342765808, 41.57386556267738, 40.80187238752842, 42.34524317085743, 38.31673353910446, 41.99457138776779, 44.23811919987202, 43.31600368022919, 40.87122246623039, 42.7443927526474, 43.84289100766182, 43.66084277629852, 48.59057664871216, 50.91646984219551, 55.309045538306236, 49.820042476058006, 48.85876625776291, 50.1849140971899, 48.90415862202644, 49.89550642669201, 52.27695643901825, 46.039473339915276, 48.29870291054249, 51.24263674020767, 52.821383625268936, 53.36116746068001, 52.388799637556076, 54.1553970426321, 52.60170221328735, 61.00030034780502, 66.76164999604225, 65.46826779842377, 66.15286186337471, 64.91260841488838, 50.004545375704765, 1.7540780268609524, 18.38046681135893, 65.29462471604347, 51.55379444360733, 30.899218060076237, 15.918379426002502, 30.963624604046345, 29.131184332072735, 36.91384121775627, 32.772002667188644, 44.08599816262722, 37.08764769136906, 29.83962021768093, 47.52623476088047, 59.68498572707176, 37.61635512113571, 73.29411506652832, 82.76097267866135, 68.77391561865807, 2.501615476794541, 0.10089223069371656, 0.1735704261227511, 0.40035266254562885, 0.15383556165033951, 0.43787965667434037, 0.22540679929079488, 0.3063738194759935], [0.11414829437853768, 0.1388228195719421, 0.14422571402974427, 0.06357033649692312, 0.023408178203681018, 0.1091695818467997, 0.2339052510797046, 0.18804137071128935, 0.12691857788013294, 0.0709464235114865, 0.17201988666784018, 0.12371290809824131, 14.383482187986374, 60.94553008675575, 52.20716178417206, 35.80324821174145, 23.060782067477703, 41.58483177423477, 24.333090595901012, 28.003452345728874, 16.580980271100998, 10.190302692353725, 24.550613723695278, 20.436384491622448, 20.034147575497627, 30.214031226933002, 41.765040904283524, 56.29802606999874, 49.862831979990005, 9.159129224717617, 0.168463900918141, 7.475946843624115, 46.92337431013584, 56.44786722958088, 64.82170209288597, 54.52866621315479, 60.396197363734245, 65.27683407068253, 66.46880730986595, 69.70945581793785, 67.74332731962204, 61.975567415356636, 51.66947543621063, 51.26968368887901, 52.93631225824356, 59.32336673140526, 57.53460131585598, 49.14587885141373, 46.92026607692242, 44.03343938291073, 41.87597595155239, 42.810923382639885, 46.88765622675419, 40.791776329278946, 40.256400257349014, 42.43945151567459, 43.50690923631191, 44.380672350525856, 44.88456331193447, 46.954874619841576, 43.37695620954037, 43.3403679728508, 40.3022637963295, 45.37213034927845, 46.379049718379974, 42.917230278253555, 40.94759076833725, 44.50225442647934, 45.18541596829891, 40.7689243555069, 35.832385048270226, 35.90445578098297, 23.579933010041714, 25.897132270038128, 33.02010655403137, 50.306074395775795, 51.74544855952263, 73.59973266720772, 47.296510487794876, 23.10086991637945, 17.89214551448822, 6.9630194921046495, 3.4995447658002377, 2.4075842974707484, 2.1693142829462886, 2.031135172583163, 0.1575402737944387, 0.2964461990632117, 0.264650959870778, 0.39823240600526333, 0.2020610449835658, 0.09799175430089235, 0.1469474664190784, 0.06560681198607199, 0.011894458330061752, 0.05611834261799231, 0.5398638092447072, 0.7665728847496212, 3.087977687828243, 9.145829938352108, 24.567866697907448, 40.500141978263855, 43.478140980005264, 42.31141738593578, 26.430268362164497, 40.23948356509209, 36.13006867468357, 35.07210664451122, 33.87013994157314, 33.92434783279896, 38.02979193627834, 39.75155934691429, 41.93918935954571, 39.49554808437824, 40.312029272317886, 34.30365867912769, 38.278078213334084, 34.87730249762535, 36.327969655394554, 35.37150017917156, 35.98493926227093, 38.12483623623848, 38.15521560609341, 38.53309012949467, 37.2031044960022, 36.37553930282593, 42.0141289383173, 45.62296248972416, 44.95252266526222, 46.242268458008766, 44.97913643717766, 43.32127399742603, 42.07122467458248, 43.88824537396431, 43.244468718767166, 45.94426944851875, 53.35200235247612, 52.1161262691021, 51.00760415196419, 49.2086248844862, 50.27209281921387, 49.0086530148983, 49.35450665652752, 56.501440554857254, 58.50394070148468, 63.6564452201128, 59.01456490159035, 62.826714143157005, 13.617183957248926, 1.007818733341992, 34.13279704749584, 54.506046026945114, 42.142307460308075, 12.843656614422798, 9.991809893399477, 27.433990202844143, 17.665466777980328, 21.888746358454227, 19.92385659366846, 29.25359856337309, 27.91486769914627, 29.10792388021946, 23.85654866695404, 38.00302617251873, 54.003522992134094, 48.49166415631771, 62.82174400985241, 66.34605869650841, 16.44948072731495, 1.5544593008235097, 0.10113263459061272, 0.261208611773327, 0.12104586683562957, 0.4432832635939121, 0.08231633371906355, 0.3124077175743878, 0.06800095812650397, 0.10355103411711752, 0.10065559690701775, 0.0753258666372858, 0.12162493498180993, 0.1094173923775088, 0.20631910243537277, 0.12470173824112862, 0.09804178247577511, 0.08085009481874295, 0.1656263438053429, 0.0785237735544797, 19.622800648212433, 72.68575251102448, 56.71468511223793, 41.368558779358864, 27.34799511730671, 45.09558118879795, 34.43346731364727, 26.77355334162712, 20.854464657604694, 20.71338202804327, 30.948628708720207, 24.904483035206795, 28.70195746421814, 32.664118856191635, 42.18208372592926, 59.487552121281624, 56.02105513215065, 17.390842214226723, 0.23141582059906796, 6.832571066915989, 49.12865437567234, 61.28071390092373, 64.90025907754898, 60.44105015695095, 62.839105278253555, 67.0706570148468, 65.5311544239521, 69.29018631577492, 66.06977552175522, 60.10669469833374, 53.057464957237244, 55.77079676091671, 59.09073941409588, 62.33987666666508, 59.11834493279457, 50.45289471745491, 47.02398531138897, 47.69295461475849, 44.66182306408882, 47.24601499736309, 47.018399611115456, 44.93298031389713, 46.51551939547062, 47.48306527733803, 47.64020584523678, 45.804657340049744, 48.37830103933811, 48.1952990591526, 46.589383631944656, 48.66846486926079, 46.731199622154236, 48.875587955117226, 47.64348886907101, 47.11081825196743, 45.295686051249504, 48.149070739746094, 48.356737196445465, 47.768179178237915, 46.1267052590847, 45.48569105565548, 30.317598469555378, 29.53299567103386, 41.91838167607784, 53.491834849119186, 56.666530296206474, 74.16552230715752, 57.26069301366806, 34.6581606566906, 16.27558495849371, 8.345490284264088, 4.10952745936811, 0.6916998024098575, 0.6364476203452796, 1.3088965276256204, 0.19404210965149105, 0.5596535035874695, 0.3251889848615974, 0.23834979539969936, 0.11867021501529962, 0.05301202785631176, 0.080025138304336, 0.07949607606860809, 0.11035955627448857, 0.071926889650058, 0.2946819952921942, 2.3462838493287563, 3.951068362221122, 8.365474361926317, 23.394236974418163, 49.61446590721607, 48.98663319647312, 44.85039934515953, 30.63882563263178, 40.491334050893784, 39.84794117510319, 38.90505976974964, 40.53048335015774, 40.01694470643997, 43.742918372154236, 45.426931008696556, 45.542798191308975, 44.00513470172882, 41.84711650013924, 39.23516325652599, 43.1969902664423, 38.82472448050976, 42.084501162171364, 41.79527208209038, 42.145917266607285, 41.42565831542015, 43.15769277513027, 43.64133082330227, 42.55427375435829, 41.27818062901497, 45.03888063132763, 45.713374838232994, 46.39755852520466, 48.14888834953308, 46.201371252536774, 46.706922724843025, 46.34285286068916, 46.79389625787735, 45.61157450079918, 51.1212370544672, 54.55632872879505, 53.53245086967945, 52.959133833646774, 54.39629651606083, 54.011225178837776, 54.35395158827305, 53.632355108857155, 61.62560619413853, 63.002462312579155, 66.04245498776436, 62.78919875621796, 60.38796700537205, 9.167034700512886, 1.933553796261549, 40.77179320156574, 58.995885103940964, 47.67106018960476, 15.864752903580666, 12.777785249054432, 28.863186612725258, 25.55672563612461, 21.091036163270473, 17.917826436460018, 30.35047620534897, 31.449966207146645, 36.250879392027855, 28.337712809443474, 56.87022216618061, 54.06334698200226, 60.42951017618179, 68.8785620033741, 73.30923065543175, 36.80549003183842, 1.1788774793967605, 0.08052510092966259, 0.1115447809570469, 0.046439801808446646, 0.11543959422851913, 0.06707850567181595, 0.11333859642036259, 0.163193806365598, 0.21631802839692682, 0.22069393889978528, 0.18264460639329627, 0.17859844694612548, 0.305976087693125, 0.35685090464539826, 0.1927313581109047, 0.21563734539086, 0.18957941239932552, 0.31633168982807547, 0.3792812494793907, 22.470210157334805, 84.76471155881882, 64.84550401568413, 45.94972215592861, 32.38555200397968, 60.223922207951546, 36.782497465610504, 36.25316686928272, 26.66512805968523, 14.83292207121849, 29.263432435691357, 27.92268007993698, 26.193180084228516, 43.42375449836254, 51.19716838002205, 64.85726058483124, 58.255187049508095, 13.180159907788038, 0.3125789458863437, 10.696972254663706, 53.17987538874149, 65.25776669383049, 68.35330098867416, 62.99400396645069, 64.05114904046059, 70.59299200773239, 68.07708621025085, 74.03993144631386, 71.51452615857124, 63.20591479539871, 54.369245767593384, 55.02830520272255, 60.87111867964268, 64.84524562954903, 64.94506627321243, 53.675171211361885, 51.88443750143051, 50.75303301215172, 46.165064200758934, 48.28007631003857, 52.89058171212673, 46.046651154756546, 47.40401431918144, 50.27181923389435, 51.22747175395489, 48.62130180001259, 51.129300221800804, 52.03508801758289, 50.83382807672024, 51.90358467400074, 47.46410429477692, 50.6983957439661, 50.035365521907806, 47.69401475787163, 48.653318881988525, 50.699273496866226, 54.35064196586609, 54.21417988836765, 48.738392516970634, 48.1238666921854, 33.78651782870293, 38.23952928185463, 55.09184159338474, 64.8935866355896, 65.14239728450775, 80.7909607887268, 56.939237862825394, 43.919137716293335, 18.674924410879612, 12.837837226688862, 7.31231527402997, 3.399007385596633, 3.668993110768497, 2.3846183298155665, 0.4757847008295357, 0.9954764018766582, 0.4372667911229655, 0.7557594368699938, 0.21928615897195414, 0.2221388855832629, 0.2329894111608155, 0.2260502561694011, 0.19216582673834637, 0.23639310820726678, 0.46154229319654405, 2.843458908610046, 5.896833753213286, 13.569283727556467, 40.830963626503944, 51.42838977277279, 55.62034763395786, 51.73238106071949, 38.311265632510185, 50.0453095883131, 48.127221912145615, 45.460528805851936, 45.20416796207428, 42.3373281955719, 46.54236115515232, 49.19433765113354, 50.03175191581249, 49.84252966940403, 47.637758776545525, 40.69203928112984, 43.908813670277596, 39.78876315057278, 43.76071661710739, 42.09252253174782, 42.67012193799019, 43.227909207344055, 43.62681560218334, 46.19439862668514, 44.008345529437065, 43.12039017677307, 47.16200910508633, 50.4170398414135, 52.337278202176094, 51.33722886443138, 51.00182086229324, 49.490402564406395, 49.31740164756775, 50.91873072087765, 47.154306918382645, 52.36005797982216, 57.29126617312431, 56.65964886546135, 56.71917647123337, 55.448733642697334, 56.64667636156082, 54.62098605930805, 54.72963362932205, 61.95284463465214, 65.93302845954895, 69.71020817756653, 64.66261222958565, 67.59898066520691, 16.05137798935175, 1.4129382697865367, 39.602801129221916, 64.54242467880249, 51.13935828208923, 24.650519862771034, 16.187315694987774, 36.900982707738876, 24.534669779241085, 33.6458607763052, 29.851861260831356, 41.5772245824337, 41.81395187973976, 44.37946781516075, 33.59074853360653, 51.962971687316895, 67.18047872185707, 57.96169459819794, 79.60445165634155, 84.3030895292759, 38.39758940041065, 1.75499722128734, 0.33945710049010813, 0.3288326330948621, 0.18820442055584863, 0.5242994881700724, 0.21319392806617543, 0.36840115673840046], [0.1277266431134194, 0.08194168272893876, 0.180378888908308, 0.043800216299132444, 0.17090234585339203, 0.24114580708555877, 0.3732694673817605, 0.18762637657346204, 0.054745387969887815, 0.034274828794877976, 0.26251404953654855, 0.08594801853178069, 26.663450449705124, 67.40367114543915, 50.3996367752552, 33.71760092675686, 35.76210401952267, 32.380255088210106, 23.16609151661396, 24.934210740029812, 18.004182502627373, 18.917765580117702, 12.372957821935415, 27.591417655348778, 8.748429212719202, 10.672512967139482, 26.13015476614237, 43.657764941453934, 49.535749331116676, 44.6668653935194, 4.359045345336199, 0.8262972487136722, 34.14595574140549, 60.31110852956772, 60.161510556936264, 57.611224204301834, 63.73946316540241, 65.46462759375572, 65.06985917687416, 65.83031237125397, 65.40850460529327, 57.32042960822582, 52.96385318040848, 51.03293739259243, 54.900214076042175, 63.678788021206856, 56.26910962164402, 50.00361442565918, 44.37306895852089, 46.539294719696045, 42.58933827280998, 47.03989505767822, 43.623061403632164, 41.53619058430195, 41.5663343667984, 44.95959788560867, 44.413814172148705, 41.17831438779831, 45.59198275208473, 43.83794367313385, 39.90606665611267, 40.71875564754009, 42.64122448861599, 46.42031170427799, 45.70708617568016, 41.86938710510731, 41.69644698500633, 45.51149547100067, 41.82649500668049, 39.72113057971001, 37.865028977394104, 39.60203357040882, 22.7701660618186, 30.900414995849133, 34.909197986125946, 49.8949858546257, 61.2644811719656, 75.011106133461, 34.93683770298958, 24.86059159040451, 8.407851587980986, 3.4883821522817016, 2.249591387808323, 2.7860789000988007, 1.7048547556623816, 0.4595617682207376, 0.399649670580402, 0.18955685110995546, 0.08032105484744534, 0.22429408243624493, 0.22088980651460588, 0.08321935674757697, 0.08533354994142428, 0.0544615276157856, 0.07423796720104292, 0.15406687423819676, 0.1158320419199299, 0.23274469538591802, 4.087715204805136, 5.5003677774220705, 15.449773371219635, 37.32602410018444, 47.32909373939037, 46.31423659622669, 24.23223450779915, 36.81632325053215, 33.23637194931507, 33.121355921030045, 34.11422364413738, 37.46337912976742, 39.72667448222637, 41.98380656540394, 43.8126902282238, 40.45026205480099, 39.69372645020485, 37.26132497191429, 35.138017907738686, 38.62484760582447, 37.93667793273926, 36.84017077088356, 39.4030686467886, 41.22518107295036, 41.55214212834835, 40.403285175561905, 37.91748136281967, 37.58675090968609, 43.35583694279194, 44.265017956495285, 43.501053750514984, 43.6366380751133, 44.24299813807011, 44.64277468621731, 42.92265258729458, 46.077752485871315, 49.31277349591255, 57.06275403499603, 56.00351147353649, 52.916036546230316, 51.250897496938705, 48.392523676157, 51.35721959173679, 53.24383735656738, 51.194037348032, 56.572736129164696, 58.85808549821377, 60.456625521183014, 62.231973856687546, 42.4403178691864, 2.1423533046618104, 7.616341710090637, 54.58657890558243, 52.25102663040161, 42.34031483530998, 6.820287751033902, 22.517023645341396, 18.427952863276005, 6.234125979244709, 12.105390429496765, 24.255836941301823, 24.893188141286373, 33.28796558082104, 26.609985418617725, 42.19449765980244, 33.615029230713844, 45.444467067718506, 26.8364342674613, 60.30747592449188, 61.20580092072487, 53.39546822011471, 2.8240467002615333, 0.18660917412489653, 0.13819003477692604, 0.13755555788520724, 0.23383278778055683, 0.08991734342998825, 0.1093109164503403, 0.06321303691947833, 0.05202713109611068, 0.03865208629576955, 0.04224241121846717, 0.26964825578033924, 0.09739462970173918, 0.026100120376213454, 0.0823974801460281, 0.018351545732002705, 0.09113205363973975, 0.13654984388267621, 0.16325129312463105, 33.54353606700897, 76.48144483566284, 56.70444466173649, 41.650625243783, 36.34504593908787, 41.32150210440159, 28.914744146168232, 26.832229793071747, 21.56172450631857, 24.35218457132578, 18.54917585849762, 23.8459662348032, 12.06247078254819, 14.957979060709476, 28.571740351617336, 52.879805490374565, 56.41501039266586, 55.99729120731354, 7.925722058862448, 0.9516449819784611, 31.80852636694908, 57.21545644104481, 61.4068291336298, 62.082258090376854, 63.91076937317848, 64.39938515424728, 64.29552152752876, 65.3451620042324, 62.82872423529625, 56.58627860248089, 56.52328558266163, 58.26364539563656, 59.22980435192585, 64.18516784906387, 56.65621004998684, 47.92146295309067, 47.003014236688614, 48.12552720308304, 45.88905841112137, 49.13574479520321, 45.99968947470188, 47.01525337994099, 44.71709869801998, 47.82586008310318, 46.63142077624798, 45.83157129585743, 47.96069584786892, 45.74979588389397, 45.371328592300415, 47.36681431531906, 48.51890489459038, 45.51173485815525, 47.032170072197914, 45.02701386809349, 47.28671461343765, 47.61781744658947, 46.81646704673767, 45.783633068203926, 44.032519832253456, 45.889020413160324, 28.231896087527275, 32.35863424837589, 43.03426019847393, 51.33390784263611, 58.64778198301792, 71.3976064324379, 45.28695032000542, 29.119224473834038, 9.47544515132904, 6.455362932756543, 2.7201697742566466, 3.0573660554364324, 2.314765015617013, 1.5121713699772954, 0.10038784486823715, 0.5174866318702698, 0.058060238807229325, 0.05134709004778415, 0.0849373395612929, 0.09054806505446322, 0.04140719451243058, 0.05412961691035889, 0.03375677260919474, 0.019271992532594595, 0.08367651229491457, 0.6853419716935605, 4.413042347878218, 8.586389757692814, 14.161936976015568, 40.34700259566307, 50.85438497364521, 43.89881260693073, 31.303594261407852, 37.60909751057625, 40.541080981492996, 38.01136672496796, 41.12619638442993, 43.13731446862221, 45.329686626791954, 45.516883581876755, 46.661009788513184, 45.8396078646183, 41.06003813445568, 40.97409434616566, 39.48437288403511, 41.62574417889118, 43.31305503845215, 41.41120009124279, 46.44148036837578, 45.37310689687729, 45.151666179299355, 43.75762738287449, 42.18617990612984, 41.11697807908058, 44.74647872149944, 45.79909063875675, 44.79908309876919, 45.21419182419777, 46.968139708042145, 46.390335112810135, 46.67951859533787, 48.10302101075649, 53.71967822313309, 57.936300560832024, 55.561876371502876, 55.15349328517914, 54.211094453930855, 53.8932491093874, 56.85878857970238, 56.434298157691956, 55.04267603158951, 60.15367157757282, 61.55549615621567, 62.35554702579975, 62.17410296201706, 37.1929894387722, 1.7605414800345898, 11.045323312282562, 56.7101139575243, 55.49460858106613, 45.18953114748001, 10.044013392180204, 17.550711035728455, 22.172790616750717, 11.717587988823652, 14.300803374499083, 18.509758673608303, 26.37408457696438, 32.837267965078354, 34.352641850709915, 40.30920222401619, 47.432015016674995, 45.10280080139637, 26.657363176345825, 83.17093268036842, 62.13384032249451, 74.79965507984161, 6.1814722046256065, 0.23163085046689957, 0.07854076873627491, 0.04248471501341555, 0.05644580414809752, 0.12879713176516816, 0.04836662126763258, 0.19768526806728914, 0.1608342071995139, 0.3585921018384397, 0.19496534136123955, 0.47804590605665, 0.3667623462388292, 0.3705388982780278, 0.17358889075694606, 0.10561383358435705, 0.19171604071743786, 0.2884679927956313, 0.19344131142133847, 41.71823501586914, 90.47999247908592, 62.230138555169106, 44.38219606876373, 46.98950216174126, 50.58788247406483, 33.075572177767754, 34.00641202926636, 27.541129253804684, 23.376469127833843, 15.960353873670101, 35.93383960425854, 10.212981775403023, 20.387625508010387, 38.687114864587784, 56.07918061316013, 60.82430899143219, 54.53410752117634, 4.977721972391009, 1.4165822742506862, 38.85455287992954, 65.58134213089943, 66.37645706534386, 67.39375367760658, 67.15248942375183, 68.18004548549652, 65.45026436448097, 69.52189028263092, 66.67381390929222, 59.51926901936531, 54.78089667856693, 58.79462130367756, 60.61720110476017, 69.4645893573761, 61.91056050360203, 53.141033872962, 49.052331671118736, 52.23491549491882, 48.12623776495457, 51.58063620328903, 47.218766659498215, 49.440632835030556, 47.01424263417721, 53.3630483597517, 52.938630133867264, 50.832479149103165, 50.70650830864906, 50.04978954792023, 47.05939181149006, 50.293649062514305, 48.937585428357124, 46.968869268894196, 51.00474290549755, 47.079230546951294, 48.60504627227783, 53.14183942973614, 50.657441541552544, 51.74044422805309, 48.37659873068333, 52.61727757751942, 31.61336313933134, 42.20068372786045, 57.334933429956436, 66.14130288362503, 69.80913206934929, 77.08126544952393, 50.876032412052155, 33.8039018958807, 10.757957082241774, 8.818258065730333, 3.7602777499705553, 3.7552622565999627, 2.0981704629957676, 1.2175818462856114, 1.3310951739549637, 0.6551572820171714, 0.16388627467676997, 0.5373075557872653, 0.3841162525350228, 0.18193779978901148, 0.1600942711229436, 0.17041312210494652, 0.16218827047850937, 0.20080132351722568, 0.1914241540362127, 0.6853365688584745, 4.848075779154897, 12.378533072769642, 32.57784068584442, 52.420303747057915, 53.57597753405571, 53.787599578499794, 38.25530223548412, 45.46361044049263, 47.36908659338951, 43.33175003528595, 44.09256801009178, 43.39904822409153, 48.4674708545208, 49.51183341443539, 52.87754461169243, 51.15529842674732, 47.45439201593399, 41.822668612003326, 42.544998452067375, 42.62211911380291, 45.39058215916157, 41.64818957448006, 47.014531418681145, 45.36689803004265, 44.964119642972946, 45.279077142477036, 45.51224023103714, 43.399610593914986, 49.43790838122368, 50.37274181842804, 49.72257390618324, 49.00506600737572, 49.68031257390976, 51.72811768949032, 48.78889560699463, 50.96813566982746, 55.85243918001652, 60.00167213380337, 59.591088965535164, 56.23656436800957, 56.82911217212677, 55.14931730926037, 58.63612420856953, 57.47222386300564, 55.367262214422226, 63.28420199453831, 67.17274233698845, 66.26856565475464, 69.62405920028687, 44.23952892422676, 3.612241018563509, 7.962405290454626, 64.213407933712, 58.546084240078926, 55.25780908763409, 16.411224380135536, 32.41614416241646, 24.373457729816437, 10.792526677250862, 21.388193517923355, 36.04458466172218, 35.15463441610336, 46.34302765130997, 38.3263698220253, 59.568176195025444, 40.840687304735184, 61.1004363745451, 30.320826396346092, 80.66375121474266, 72.51183584332466, 84.31423053145409, 6.691244300454855, 0.3233652905328199, 0.1922232986544259, 0.17018148297211155, 0.335709135979414, 0.26105730270501226, 0.34087112930137664], [0.18744374887319282, 0.09402173920534551, 0.07762192311929539, 0.06079338687413838, 0.2728738373843953, 0.16816091170767322, 0.07980906942975707, 0.038239170171436854, 0.16441171523183584, 0.006043226894689724, 0.12016707492875867, 1.4293152722530067, 44.729356840252876, 62.60837025940418, 41.41173966228962, 27.22174309194088, 34.57326181232929, 24.71254013478756, 21.992214806377888, 23.27523496001959, 26.18456594645977, 36.14094369113445, 33.43774974346161, 24.600259959697723, 19.557330161333084, 7.204847065731883, 14.449540693312883, 44.25146788358688, 55.105479061603546, 54.54034298658371, 27.904418259859085, 1.374160994309932, 12.576505299657583, 48.369865491986275, 53.76979373395443, 59.900627955794334, 62.045438066124916, 75.05626291036606, 70.94411596655846, 67.3424032330513, 59.971467554569244, 57.929278537631035, 49.58763174712658, 54.92580570280552, 60.47784358263016, 63.5279855132103, 56.17634139955044, 47.984832152724266, 40.98902374505997, 46.24416455626488, 42.550736144185066, 49.162050783634186, 41.9430385529995, 42.812029123306274, 39.9393642693758, 42.72936075925827, 41.11370265483856, 45.044546127319336, 46.757661402225494, 44.92596209049225, 40.07841020822525, 39.61287438869476, 46.7640146613121, 45.78887678682804, 43.88514094054699, 42.28395625948906, 42.93872952461243, 44.002197459340096, 42.03718990087509, 41.3385745882988, 38.65961953997612, 37.920589596033096, 20.616658218204975, 35.14961488544941, 37.03530929982662, 48.351865857839584, 62.89624661207199, 70.08134186267853, 26.764688417315483, 16.09014730900526, 2.8515669610351324, 0.8288439433090389, 0.8084335760213435, 0.7568698085378855, 0.3832911030622199, 0.2882774983299896, 0.23635580786503851, 0.13751766382483765, 0.35040101793128997, 0.1432578792446293, 0.08101220213575289, 0.1291858241893351, 0.03945955410017632, 0.11462099049822427, 0.02324370900169015, 0.1387638336746022, 0.08255088949226774, 0.41306707717012614, 2.8889070823788643, 6.209793984889984, 18.04552238434553, 31.829246655106544, 49.621776714921, 45.48002175986767, 25.50987984985113, 28.173947297036648, 34.19965825974941, 30.632251985371113, 37.08038628101349, 39.1045680642128, 41.7392098903656, 43.33066329360008, 45.87560333311558, 40.04866920411587, 39.037205278873444, 36.352014765143394, 38.142927065491676, 38.98197904229164, 38.3942835777998, 38.7432948499918, 42.59477958083153, 39.96081031858921, 42.808008939027786, 39.568336978554726, 39.25768844783306, 40.57494476437569, 44.35984566807747, 43.31512972712517, 43.004002422094345, 44.50049132108688, 46.593901589512825, 39.38011407852173, 45.8779364079237, 51.52876518666744, 57.78232142329216, 60.423381105065346, 59.46855694055557, 52.926858365535736, 55.13446390628815, 52.70526945590973, 54.59596440196037, 50.20782686769962, 55.70688799023628, 57.07565054297447, 62.57594279944897, 57.78878107666969, 55.49708604812622, 19.369540438055992, 0.6389843404758722, 26.62997044622898, 60.329826325178146, 45.64084053039551, 36.74370534718037, 4.357695942744613, 30.78267641365528, 25.914487838745117, 9.429691806435585, 8.435517903417349, 19.94162254035473, 23.93621139228344, 36.16148918867111, 24.92271825671196, 36.399873197078705, 37.3670656979084, 66.80114507675171, 41.83571331202984, 30.05390401929617, 54.8372932523489, 60.79810559749603, 12.106844801455736, 1.0599196376278996, 0.23366258363239467, 0.2550727722700685, 0.10141738181118853, 0.10196706833085045, 0.23967332672327757, 0.13185498799430206, 0.09225387664628215, 0.15078352385899052, 0.1134487014496699, 0.11819086925243028, 0.07756263294140808, 0.088493518269388, 0.0690066053357441, 0.06383694562828168, 0.03751498617930338, 0.18583656870760024, 1.7259425553493202, 60.02182625234127, 65.04791155457497, 53.67271654307842, 32.30994366109371, 35.780856013298035, 34.137987568974495, 31.14081099629402, 33.79505597054958, 29.033172391355038, 36.030745804309845, 34.15485866367817, 27.927897199988365, 18.053431659936905, 7.875082176178694, 20.673624761402607, 51.31395511329174, 63.2583861798048, 55.193862318992615, 38.24761904776096, 2.8624407900497317, 7.605353649705648, 41.985733062028885, 51.66643939912319, 60.10011725127697, 60.70094481110573, 71.62079125642776, 65.5990719795227, 65.34571677446365, 57.873394936323166, 56.224849596619606, 53.978277146816254, 60.22980809211731, 62.36352279782295, 62.03922539949417, 55.4742606729269, 48.23721081018448, 46.57368667423725, 47.75617942214012, 47.30717271566391, 49.64043751358986, 45.75549937784672, 48.11127036809921, 46.67573019862175, 47.877822294831276, 45.6868826597929, 49.17418733239174, 46.72161653637886, 47.13028080761433, 44.72479708492756, 44.48432698845863, 48.01706962287426, 47.53113649785519, 45.94500660896301, 47.034693136811256, 47.33229696750641, 48.459878861904144, 47.70358644425869, 48.101360499858856, 47.72825092077255, 44.199330881237984, 26.06185533106327, 38.20975787937641, 39.5845203101635, 45.94800844788551, 56.83124765753746, 64.89381462335587, 37.26573273539543, 19.762072674930096, 3.9954566303640604, 1.8826720328070223, 0.7092756405472755, 1.686217705719173, 1.1159133142791688, 0.49310215283185244, 0.2807680028490722, 0.22411017824197188, 0.3457991383038461, 0.2159354809555225, 0.024287665873998776, 0.11632633453700691, 0.024856540621840395, 0.0785476558667142, 0.024224000735557638, 0.048449745518155396, 0.0832315428124275, 0.24705023010028526, 4.207625845447183, 9.671906009316444, 17.060888819396496, 25.405790135264397, 49.60704490542412, 44.21433247625828, 29.90526359528303, 28.572458513081074, 44.219363406300545, 36.61070868372917, 42.329109236598015, 41.784131079912186, 45.355506241321564, 46.69848717749119, 47.03265644609928, 44.75199602544308, 44.35822695493698, 40.849597826600075, 42.23059572279453, 41.31299816071987, 43.39308254420757, 44.76772338151932, 46.97927691042423, 43.60443480312824, 47.410534769296646, 42.87108935415745, 41.86707682907581, 43.96681375801563, 47.457526847720146, 44.10199910402298, 46.550709307193756, 44.90485422313213, 47.786410599946976, 42.00415447354317, 50.134004428982735, 53.25804479420185, 58.981841057538986, 57.53381855785847, 60.64271293580532, 54.54142592847347, 58.976506143808365, 55.99843494594097, 58.603776544332504, 53.40434834361076, 59.763991087675095, 59.69413943588734, 65.96405759453773, 58.74867036938667, 52.104487493634224, 12.98664579167962, 1.4138624514453113, 33.5522186011076, 62.09185257554054, 48.45507211983204, 38.13197985291481, 5.908692916855216, 28.771539330482483, 24.717502668499947, 9.847902115434408, 16.43482681363821, 15.900861416012049, 26.81165959686041, 35.44136703014374, 30.329068154096603, 34.90702070295811, 36.806413382291794, 79.87419158220291, 32.02363282442093, 39.21958789229393, 60.60012862086296, 76.57957077026367, 19.93833191692829, 1.264069858007133, 0.03282322133600246, 0.12269254410057329, 0.14503700018394738, 0.09568173059960827, 0.08657856946229003, 0.28573884861543775, 0.30971128726378083, 0.21636315097566694, 0.19747510668821633, 0.33926895121112466, 0.18496861215680838, 0.1932894383207895, 0.23135181778343394, 0.2896616928046569, 0.2608054771553725, 0.2573055087123066, 1.9779332773759961, 71.51253506541252, 77.8498350083828, 55.65561354160309, 34.088765010237694, 49.48885604739189, 38.30911494791508, 34.49946977198124, 37.52804785966873, 34.15206201374531, 45.90854376554489, 42.433026060462, 30.46256449073553, 26.67109753936529, 11.804839856922626, 28.31105723977089, 56.84597186744213, 64.73401039838791, 61.1769300699234, 35.22449366748333, 1.8595163128338754, 12.353306226432323, 51.88043251633644, 60.44063977897167, 70.13820201158524, 67.23334908485413, 73.99221360683441, 70.64838543534279, 69.44962576031685, 59.98364970088005, 58.49464260041714, 55.11248968541622, 61.98216386139393, 65.69788187742233, 68.11206713318825, 61.9606988132, 53.13829801976681, 47.116156965494156, 52.287276685237885, 47.59384073317051, 50.50087474286556, 48.93553353846073, 50.12446694076061, 49.30170848965645, 50.76214872300625, 49.156647473573685, 55.04324220120907, 51.11855059862137, 53.29100042581558, 48.01328882575035, 47.22048796713352, 51.34441427886486, 51.53803288936615, 47.99204036593437, 48.561599403619766, 47.43883565068245, 55.749088525772095, 51.855388060212135, 54.007261991500854, 49.380478262901306, 53.1449780613184, 31.989605650305748, 48.564377054572105, 56.39811649918556, 62.58305981755257, 73.69587510824203, 76.03072062134743, 48.35511088371277, 23.516822196543217, 4.379974622279406, 2.1544668171554804, 0.712468478595838, 1.4529927517287433, 0.8700605691410601, 0.5336016265209764, 0.5863916000816971, 0.5632536322809756, 1.067323184106499, 0.6489654548931867, 0.21247803757432848, 0.2557888557203114, 0.06653076357906684, 0.2294085337780416, 0.150644252425991, 0.16428474860731512, 0.12344840666628443, 0.29521735094022006, 4.824761180207133, 14.40677398815751, 26.615987196564674, 46.94033659994602, 58.96689645946026, 50.57880476117134, 37.68695533275604, 39.197503477334976, 50.10142117738724, 42.186092510819435, 47.3636718839407, 45.64575746655464, 51.10430896282196, 50.241683050990105, 54.22633923590183, 49.31085839867592, 48.08651089668274, 41.83065578341484, 43.64568538963795, 42.92161524295807, 45.001095458865166, 44.16935808956623, 48.37595276534557, 44.38867852091789, 49.58335317671299, 45.69999195635319, 44.31057371199131, 45.98730593919754, 49.789727702736855, 47.275619208812714, 48.40131260454655, 51.878327429294586, 52.77114652097225, 43.41618150472641, 53.386341109871864, 56.120849177241325, 62.45177686214447, 62.541281059384346, 66.97424098849297, 55.913570299744606, 62.39320680499077, 57.363127917051315, 60.76434060931206, 53.96447628736496, 59.847180023789406, 60.37381276488304, 70.75054675340652, 61.895954087376595, 62.20947906374931, 24.740111455321312, 1.5126306703314185, 29.054025672376156, 69.86666858196259, 53.11649098992348, 49.95266675949097, 9.854196477681398, 43.45941178500652, 30.924068726599216, 15.191967654973269, 15.844357497990131, 27.427980825304985, 35.41023910045624, 52.19678074121475, 33.088145703077316, 50.65631300210953, 42.40053780376911, 84.03746858239174, 49.471057802438736, 44.33825522661209, 70.21851450204849, 85.80398619174957, 28.90865307301283, 1.447306356858462, 0.34420087875332683, 0.2767633442999795, 0.3597340593114495, 0.23419424338499084, 0.3232430439675227], [0.045790986623615026, 0.07568693632492796, 0.06488660961622372, 0.06437302858103067, 0.2697436069138348, 0.08557670720620081, 0.16158304904820397, 0.06512752559501678, 0.024139123161148746, 0.31305240641813725, 0.14433599717449397, 5.163408983498812, 59.06006745994091, 53.275516256690025, 35.25985077023506, 33.07328090071678, 33.374323546886444, 25.81357665359974, 23.44570331275463, 24.065546952188015, 24.55412283539772, 35.194775462150574, 38.15983235836029, 19.703367725014687, 19.997625835239887, 9.030559323728085, 14.489178266376257, 37.21590220928192, 61.74877658486366, 55.53251534700394, 52.470632046461105, 20.561872757971287, 2.4004675168544054, 15.692221261560917, 30.340501740574837, 42.22451984882355, 47.03556329011917, 59.277066215872765, 64.69791993498802, 62.09858201444149, 55.08745662868023, 55.04537008702755, 57.674639001488686, 61.43953397870064, 62.46714323759079, 62.23487310111523, 51.306104734539986, 45.19654557108879, 44.82832632958889, 45.9984165430069, 49.04306396842003, 45.15311770141125, 42.28377386927605, 42.98420548439026, 41.361768543720245, 43.76150317490101, 39.59316864609718, 45.948498621582985, 45.820240303874016, 44.477354362607, 39.280783608555794, 45.029506534338, 45.519851222634315, 48.124588653445244, 43.51682670414448, 42.52127632498741, 44.483943209052086, 43.760720416903496, 40.557750687003136, 42.44273453950882, 37.48674787580967, 38.6125248670578, 13.91429191455245, 34.94017772376537, 38.89793135225773, 43.66652347147465, 57.267711237072945, 60.98411321640015, 23.31734050065279, 9.086258634924889, 1.0009342152625322, 0.5698209861293435, 0.1884871639776975, 0.10657086269930005, 0.01627457866561599, 0.13999369111843407, 0.06115050462540239, 0.04216723908029962, 0.10050243989098817, 0.07726689451374114, 0.04128028725972399, 0.1702204011962749, 0.22750035335775465, 0.0822461413918063, 0.036987452767789364, 0.05981005233479664, 0.12120769955799915, 0.4218392330221832, 2.808572268113494, 11.529310941696167, 20.047743245959282, 26.615616716444492, 43.60889956355095, 46.05931207537651, 24.707484506070614, 18.830721750855446, 31.049220710992813, 30.169586911797523, 37.89767682552338, 39.09672528505325, 41.84667952358723, 41.51348300278187, 43.327467665076256, 39.89401750266552, 38.633024767041206, 38.970294669270515, 39.83146905899048, 39.331104308366776, 43.32185536623001, 42.753668054938316, 44.45139415562153, 45.355088263750076, 42.09417924284935, 38.92679460346699, 41.87634453177452, 41.573694571852684, 45.89056313037872, 42.538918778300285, 41.45175151526928, 42.5948403775692, 45.50734609365463, 40.473524406552315, 49.29373271763325, 55.6752622872591, 62.73411311209202, 63.21747377514839, 59.11535069346428, 55.196666568517685, 57.51170754432678, 52.77767837047577, 56.14741735160351, 55.01569747924805, 59.63100962340832, 58.91258977353573, 61.22468210756779, 51.88420191407204, 39.656036272645, 2.3310939269140363, 4.386620940640569, 54.56171303987503, 58.47658596932888, 50.38456678390503, 29.72981370985508, 5.387352341786027, 21.056349724531174, 34.20359864830971, 61.8303582072258, 30.819885917007923, 16.761107705533504, 26.70031037181616, 32.962114065885544, 34.573383405804634, 35.80608285963535, 49.17455591261387, 41.79456152021885, 64.99853700399399, 36.08205825090408, 43.28089736402035, 66.19595915079117, 28.29667691141367, 2.500786646269262, 0.18915128224762157, 0.075923340045847, 0.12110961732105352, 0.13561181374825537, 0.03584469377528876, 0.008217795657401439, 0.09267681176424958, 0.04608840601576958, 0.04667108099965844, 0.11796147882705554, 0.0736026071535889, 0.05728107651520986, 0.09492757497355342, 0.09976307526812889, 0.26786143134813756, 0.31908888719044626, 7.47838631272316, 71.89194470643997, 59.4382231682539, 46.22255891561508, 34.229809641838074, 38.15231256186962, 34.105719700455666, 32.0677674561739, 31.649476401507854, 25.79357072710991, 35.33596068620682, 34.45174813270569, 24.587770029902458, 22.396611906588078, 9.659036099910736, 20.514903478324413, 42.41591937839985, 65.0505106151104, 62.32400491833687, 60.288723930716515, 28.210208751261234, 2.1324201626703143, 8.947426434606314, 22.502223439514637, 34.064377918839455, 39.3180026113987, 49.88052763044834, 63.183689787983894, 60.11174462735653, 57.958666160702705, 59.14968565106392, 59.398241713643074, 64.53469589352608, 61.12413190305233, 61.399107947945595, 50.289199501276016, 48.26817534863949, 47.93142981827259, 47.73836597800255, 49.45511005818844, 49.69234652817249, 45.86427994072437, 47.78156965970993, 46.2836292386055, 47.49451406300068, 43.60162295401096, 47.92641408741474, 48.877001479268074, 46.250362023711205, 43.71101148426533, 47.5139956176281, 48.28357592225075, 49.28861439228058, 47.84252978861332, 45.444482266902924, 49.62175011634827, 49.791787192225456, 46.378046572208405, 46.975283324718475, 43.261241018772125, 42.616480216383934, 22.951019257307053, 35.09423665702343, 37.112350165843964, 41.265580505132675, 47.1184254437685, 54.090758711099625, 28.3452383056283, 10.972169637680054, 1.1542657250538468, 0.3800292155938223, 0.05562301470490638, 0.1767898182151839, 0.1004802793613635, 0.2136527089169249, 0.23725900158751756, 0.06495763314887881, 0.4825119726592675, 0.06504148099338636, 0.03397128668439109, 0.06805955068557523, 0.14760999649297446, 0.07878783711930737, 0.10997521283570677, 0.06334594814688899, 0.06687812579912134, 0.5077886022627354, 2.603512234054506, 11.945045683532953, 20.567608550190926, 19.55900587141514, 41.83508634567261, 43.97161290049553, 30.059742406010628, 22.51605849713087, 38.29705059528351, 38.485376089811325, 42.005841583013535, 44.32666204869747, 45.18105760216713, 44.8130739480257, 49.333132803440094, 44.69471029937267, 41.645734906196594, 41.158734038472176, 40.87961621582508, 44.12974901497364, 47.34115049242973, 46.963355764746666, 46.981860771775246, 46.64498224854469, 45.420695543289185, 42.991808876395226, 44.547502398490906, 45.63579820096493, 45.675988644361496, 44.89314705133438, 46.575662568211555, 45.96635386347771, 48.932311311364174, 45.71391820907593, 53.763717859983444, 57.446993216872215, 63.14178943634033, 60.14183521270752, 60.79818919301033, 58.47427189350128, 60.42871601879597, 57.45338827371597, 60.59766635298729, 56.87491111457348, 60.97722798585892, 60.28789937496185, 64.4108909368515, 55.772301480174065, 34.994203224778175, 1.889370835851878, 7.179526649415493, 60.130314230918884, 60.95527656376362, 55.09290173649788, 35.986086800694466, 6.986489407718182, 21.532473675906658, 28.185753263533115, 62.65041120350361, 40.95040261745453, 15.986325480043888, 29.509908109903336, 31.564649753272533, 32.9060784727335, 38.07201527059078, 41.76667861640453, 51.243677884340286, 60.203057527542114, 46.0048495978117, 55.12119121849537, 69.88433003425598, 51.90730847418308, 2.32952366117388, 0.12374413767247461, 0.09840963539318182, 0.09643419412896037, 0.1291329535888508, 0.07825055930879898, 0.16588774306001142, 0.3168823930900544, 0.2113089174963534, 0.16806290368549526, 0.3588655684143305, 0.2874544862424955, 0.285023269825615, 0.35336643224582076, 0.3329193138051778, 0.5429142736829817, 0.8614868042059243, 10.183096379041672, 82.65245050191879, 73.39952901005745, 46.15711882710457, 39.32062067091465, 48.79197344183922, 38.39193910360336, 34.52570356428623, 36.16759166121483, 28.659779727458954, 45.547574535012245, 49.46746699512005, 26.434862315654755, 25.01177027821541, 16.873091496527195, 26.805638819932938, 50.227148830890656, 69.9628110229969, 61.10990546643734, 62.857044115662575, 23.59160978347063, 2.719528558664024, 17.58520368486643, 34.348500072956085, 48.631280064582825, 49.306002259254456, 62.92889066040516, 68.12555640935898, 63.538324758410454, 60.440145805478096, 60.81575945019722, 58.89634944498539, 65.93020901083946, 65.90512275695801, 66.08533188700676, 56.331772059202194, 51.528218016028404, 50.299470350146294, 51.40495643019676, 52.67517887055874, 51.811637207865715, 47.09688059985638, 51.079298704862595, 48.92361357808113, 52.49836675822735, 45.35576082766056, 54.547224417328835, 54.216661155223846, 50.69585368037224, 47.28378877043724, 49.866768568754196, 52.151513770222664, 53.486397340893745, 50.53016357123852, 46.8110067397356, 51.23813018202782, 52.92554743587971, 50.735983327031136, 52.62538634240627, 47.39204116165638, 52.21024341881275, 29.56897784024477, 48.35648261010647, 59.69258151948452, 59.93544548749924, 71.82794094085693, 70.84352776408195, 39.48643237352371, 13.399196304380894, 1.3625383679755032, 0.7660294545348734, 0.15997638838598505, 0.1612293563084677, 0.16115524544147775, 0.2578359958715737, 0.43191869684960693, 0.2435981747112237, 1.2009620130993426, 0.14757271099369973, 0.09098297843593173, 0.3709666128270328, 0.3681631648214534, 0.4856331192422658, 0.30736696149688214, 0.19149361905874684, 0.10715266194893047, 0.5748316110111773, 2.7636964386329055, 16.676638238132, 26.56989187002182, 40.29331527650356, 58.36609169840813, 51.93174496293068, 38.69593799114227, 30.084188394248486, 44.620048105716705, 43.50375920534134, 45.34705549478531, 46.022571846842766, 49.576711133122444, 47.440906539559364, 52.4796299636364, 47.8586333245039, 45.37013165652752, 43.53269845247269, 43.13831381499767, 42.973379865288734, 46.96239061653614, 48.43706488609314, 48.428621739149094, 48.659406155347824, 46.76712669432163, 43.23654614388943, 47.62675456702709, 44.98214207589626, 49.5108150690794, 46.91117696464062, 51.13755337893963, 48.99511054158211, 53.74132566154003, 48.069271221756935, 56.72603130340576, 61.09146125614643, 67.40409672260284, 67.12786674499512, 64.73817497491837, 58.26341360807419, 63.53949509561062, 58.568841218948364, 61.45529553294182, 57.312096655368805, 60.47683663666248, 63.136655911803246, 69.44494441151619, 61.72481507062912, 50.49088507890701, 4.664887133985758, 4.767087874934077, 63.24691079556942, 68.92213806509972, 57.8924585133791, 40.327171459794044, 12.63127651065588, 30.00982068479061, 39.94115397334099, 70.22797599434853, 35.1987424492836, 22.184864468872547, 38.33095237612724, 49.09201294183731, 45.19643537700176, 47.94904567301273, 59.08637724816799, 53.74505326151848, 82.78124839067459, 44.15581941604614, 66.6906014084816, 79.35012370347977, 59.19172279536724, 3.1676867231726646, 0.3680418978910893, 0.23861460853368044, 0.30257639824412763, 0.2380744437687099, 0.265922793187201], [0.027509701867529657, 0.05682337548932992, 0.2055506085162051, 0.18630303820827976, 0.2683881780831143, 0.16996149555779994, 0.05122449467307888, 0.04443690850166604, 0.1971679020789452, 0.09786319948034361, 0.2258747085579671, 10.233484525233507, 63.38482439517975, 51.75578020513058, 31.183028630912304, 38.76557685434818, 32.32910603284836, 26.124645061790943, 22.514340989291668, 35.82161642611027, 30.310734137892723, 31.075032725930214, 39.82560217380524, 31.94476805627346, 16.84966005384922, 9.04590480029583, 12.648784071207047, 38.884191289544106, 59.860642701387405, 46.5736448764801, 47.453556060791016, 47.41633705794811, 4.799105431884527, 0.594701279187575, 3.6869504721835256, 7.5021526124328375, 10.257239900529385, 11.137973740696907, 46.16857901215553, 63.51842522621155, 58.400073274970055, 58.78103703260422, 61.83428339660168, 61.72131545841694, 62.09677331149578, 56.58712975680828, 49.09841179847717, 46.52975343167782, 45.03221198916435, 45.93662805855274, 47.29883216321468, 44.554345831274986, 42.58042775094509, 43.960460498929024, 42.43077278137207, 44.67455618083477, 41.00169226527214, 46.868881434202194, 43.26322451233864, 43.61343652009964, 44.398440197110176, 47.67711326479912, 46.86105765402317, 46.184393763542175, 46.46974325180054, 46.96281999349594, 43.59938487410545, 44.38609465956688, 44.93481561541557, 45.130691304802895, 36.56478054821491, 33.85090537369251, 8.353202920407057, 20.11614717543125, 35.81456020474434, 38.4013208001852, 48.377385288476944, 48.043151423335075, 16.538274362683296, 2.871624897234142, 0.4191416746471077, 0.1808772113872692, 0.1784326511551626, 0.07976662600412965, 0.10916572267888114, 0.12262816278962418, 0.019417423791310284, 0.029277607100084424, 0.09034192611579783, 0.35362327471375465, 0.17625668901018798, 0.18667421594727784, 0.20257060357835144, 0.06744517857441679, 0.08422763858106919, 0.0851396712823771, 0.15285611967556179, 0.16096406819997355, 1.3561587478034198, 13.271642848849297, 22.79776018112898, 24.615394547581673, 34.092838391661644, 43.757486790418625, 21.92900899797678, 15.484650749713182, 26.424209587275982, 29.762672446668148, 39.22057583928108, 36.76570236682892, 41.876777708530426, 39.261746630072594, 41.829664036631584, 37.80458942055702, 40.40614642202854, 38.910755664110184, 41.82524487376213, 43.30754913389683, 44.27623875439167, 46.57528258860111, 46.28333665430546, 43.01891282200813, 40.73816500604153, 40.16666807234287, 41.303954645991325, 42.91508339345455, 42.22874902188778, 43.409573659300804, 42.34285309910774, 42.96942427754402, 42.83170446753502, 41.745027378201485, 51.56696453690529, 56.21762618422508, 62.604745253920555, 62.96447195112705, 62.05833077430725, 57.249514013528824, 60.688234493136406, 59.688701927661896, 59.284551814198494, 58.91344852745533, 59.15048360824585, 60.351948738098145, 57.9397127777338, 49.95462745428085, 15.467299930751324, 0.5451490881387144, 24.254698902368546, 59.01834949851036, 54.16393518447876, 54.69124048948288, 36.94729462265968, 4.272163482382894, 15.094557981938124, 54.012501910328865, 44.821015521883965, 14.890529830008745, 15.939834974706173, 27.043143175542355, 30.063021630048752, 41.98555827140808, 25.630413182079792, 41.15518122911453, 20.71398239582777, 29.490056075155735, 21.970918849110603, 40.983388647437096, 53.14224600791931, 66.1969242990017, 6.039185989648104, 0.9234840399585664, 0.07346296464675106, 0.16410082957008854, 0.0834847784426529, 0.2756787103135139, 0.028658822920988314, 0.03853595502732787, 0.08582278853282332, 0.200256364478264, 0.17553063109517097, 0.23324705514824018, 0.037591894943034276, 0.06644493420026265, 0.23693328781519085, 0.2278242859756574, 0.28359220130369067, 16.752928644418716, 76.90509930253029, 60.01191258430481, 37.44550108909607, 33.083350360393524, 39.92087826132774, 34.39654469490051, 29.505388252437115, 35.82883983850479, 31.602518521249294, 37.40071289241314, 42.42234483361244, 34.49221596121788, 21.19772493839264, 13.19907434284687, 13.81727647036314, 43.11798870563507, 61.73145331442356, 53.910644575953484, 52.16842666268349, 53.59579347074032, 5.341039001941681, 0.26380936440546066, 2.2337414883077145, 3.608953719958663, 7.359951892867684, 10.795636810362339, 47.0020604878664, 63.48709590733051, 64.12507027387619, 62.77486212551594, 62.5590793043375, 62.62347064912319, 62.692110165953636, 56.724693775177, 50.652657598257065, 48.9341352134943, 48.48974525928497, 50.3789658844471, 49.784966558218, 49.2072531580925, 47.300884053111076, 46.43584527075291, 48.59896659851074, 47.19673544168472, 46.49587444961071, 49.45153824985027, 45.8613047003746, 48.15562538802624, 47.39138759672642, 47.847309932112694, 49.23522345721722, 49.0185970813036, 48.886006996035576, 48.22860807180405, 49.899731799960136, 50.422712936997414, 48.16712737083435, 49.238206297159195, 42.75784023106098, 41.491501182317734, 17.874854542315006, 24.35510091483593, 31.64294835180044, 32.39707298576832, 38.23018938302994, 44.38809335231781, 21.886350587010384, 5.452303681522608, 0.5287062423303723, 0.21219084126641974, 0.017049393827619497, 0.02107847460138146, 0.08115015996736474, 0.0691380916396156, 0.04781547271704767, 0.03170451534970198, 0.08568890509195626, 0.30249948205891997, 0.10447701177326962, 0.14014724147273228, 0.11274729768047109, 0.05706841780920513, 0.013609973502752837, 0.031069674805621617, 0.10265085351420566, 0.06342814100207761, 1.9214303093031049, 15.751771666109562, 23.13472419977188, 18.04847862571478, 30.866631008684635, 43.860723450779915, 28.92177376896143, 20.932333879172802, 33.4107331931591, 35.50360009074211, 40.29699727892876, 41.73739358782768, 45.64334839582443, 45.572466999292374, 47.083296328783035, 42.866730988025665, 43.08789052069187, 41.50082588195801, 42.71264925599098, 45.339797884225845, 45.458324924111366, 49.0408942848444, 47.55444064736366, 45.980409309268, 45.11596329510212, 44.43183280527592, 43.449946492910385, 43.967045545578, 45.533982664346695, 44.83950912952423, 44.43101204931736, 47.105015963315964, 45.92349976301193, 46.97775699198246, 54.00953806936741, 56.518041864037514, 60.85785359144211, 64.48130875825882, 62.10775472223759, 59.679981395602226, 62.18921095132828, 60.57386443018913, 62.37541235983372, 61.93511098623276, 61.912179216742516, 62.88556158542633, 62.69527159631252, 51.10321082174778, 11.550288666039705, 0.46970140538178384, 33.252213299274445, 61.88768953084946, 59.35251496732235, 60.500144585967064, 40.598978474736214, 3.7722741812467575, 17.014031633734703, 57.52673953771591, 51.67485974729061, 24.085811264812946, 16.20544072240591, 29.00138709694147, 30.72602715343237, 40.25591008365154, 29.267030842602253, 35.587245002388954, 32.64632061123848, 38.403817266225815, 28.13392024487257, 52.24405400454998, 55.78635312616825, 78.50707054138184, 9.593112487345934, 0.8187458070460707, 0.03184051762218587, 0.12902859278256074, 0.02858867883333005, 0.05649117534630932, 0.29336296138353646, 0.12881972274044529, 0.2823447994887829, 0.43374393484555185, 0.36703085526824, 0.4714130354113877, 0.15687361737946048, 0.16671418386977166, 0.7268240489065647, 0.36084279825445265, 0.8796215686015785, 22.262511402368546, 86.01666077971458, 73.0915555357933, 39.287729635834694, 50.16574412584305, 44.96317729353905, 37.050284296274185, 33.19191813468933, 48.400453850626945, 39.02778558433056, 41.96929894387722, 52.03197218477726, 44.70928251743317, 17.89003472775221, 16.12191930413246, 23.79792921245098, 47.797737792134285, 69.63414385914803, 57.69839532673359, 53.818959295749664, 53.08817870914936, 5.235909093171358, 0.6845663383137435, 5.138456197455525, 8.325381763279438, 11.816666722297668, 16.697782203555107, 58.63549344241619, 65.18508419394493, 64.84690234065056, 63.44211772084236, 62.71493934094906, 65.56302711367607, 66.99697136878967, 63.24642062187195, 57.17114321887493, 53.33214841783047, 49.31465059518814, 53.22716765105724, 50.754967108368874, 50.79174913465977, 47.62357033789158, 50.23141600191593, 51.14975072443485, 51.72108806669712, 49.64159645140171, 56.116783395409584, 50.703730657696724, 53.05675819516182, 50.2463947981596, 52.20031835138798, 53.21104131639004, 52.66709290444851, 51.14445760846138, 49.768486842513084, 51.820650324225426, 53.176960945129395, 52.89111748337746, 52.83028654754162, 48.908182606101036, 49.123574048280716, 24.5809455960989, 41.214104667305946, 57.62975960969925, 53.33632439374924, 65.82157284021378, 64.17554676532745, 33.456182554364204, 9.078240115195513, 0.6911551847588271, 0.28455467778258026, 0.17169681494124234, 0.15575399855151772, 0.15926220483379439, 0.3017498238477856, 0.136657010007184, 0.1098166752490215, 0.2035849858657457, 0.8686772652436048, 0.6509430112782866, 0.24438857682980597, 0.40643073327373713, 0.3296534187393263, 0.11233139070100151, 0.1056456939841155, 0.3514887689379975, 0.2817612636135891, 2.1136581944301724, 17.104246392846107, 27.193666398525238, 34.816156178712845, 50.2687755972147, 50.62435291707516, 38.516143038868904, 28.90878226608038, 38.18549618124962, 39.06697288155556, 45.78939735889435, 46.1392255872488, 48.797939121723175, 50.62543585896492, 50.871290266513824, 45.42918048799038, 47.457458451390266, 43.098157569766045, 42.121830359101295, 47.35242448747158, 47.213560938835144, 50.218530893325806, 49.94510896503925, 47.040282636880875, 47.815581634640694, 47.79439017176628, 45.472919940948486, 44.98734399676323, 48.52655008435249, 47.27143183350563, 48.117061257362366, 48.66968460381031, 50.01434504985809, 49.393135383725166, 56.482456773519516, 59.78794500231743, 65.93931332230568, 70.00892534852028, 66.01432889699936, 60.7459381967783, 64.16369140148163, 64.09049212932587, 64.96791824698448, 62.84175753593445, 60.548971965909004, 66.16513520479202, 67.29002684354782, 61.59191720187664, 20.369506180286407, 0.5045246961526573, 27.904522754251957, 68.21748107671738, 64.46246176958084, 64.1772110760212, 47.91469171643257, 9.816858731210232, 22.474705316126347, 62.14439995586872, 48.94888982176781, 19.47618741542101, 22.3751924559474, 37.894211411476135, 43.96603859961033, 55.388818457722664, 33.89216735959053, 53.15769977867603, 27.766856141388416, 46.504986360669136, 27.203764356672764, 61.30066283047199, 64.02306854724884, 94.36713069677353, 12.107253279536963, 0.7961407012771815, 0.21154223388293758, 0.29474003124050796, 0.18704634363530204, 0.2904431149363518], [0.12888785189716145, 0.020769553775608074, 0.04430408633197658, 0.20196223544189706, 0.026861469268624205, 0.13794030208373442, 0.04469942097784951, 0.09961184783605859, 0.06688168810796924, 0.2661163156153634, 0.17166364094009623, 22.033828273415565, 72.22218498587608, 44.457325637340546, 31.733926869928837, 43.11664737761021, 25.00652465969324, 27.895277850329876, 25.97504708915949, 43.03871735930443, 30.472016483545303, 30.8501797914505, 27.355528213083744, 34.35553349554539, 23.556780852377415, 6.720985304564238, 7.017640611156821, 30.09400136768818, 68.2612319290638, 44.70894433557987, 39.01210382580757, 60.68243980407715, 14.961526170372963, 0.35113084595650434, 0.08484353209496476, 0.3506620164262131, 0.8581618638709188, 5.827796682715416, 22.56685797125101, 66.52849450707436, 59.09542076289654, 59.63049665093422, 64.89083558320999, 63.14719274640083, 59.541817009449005, 48.77013981342316, 46.94042019546032, 46.81387558579445, 53.58210660517216, 55.43675288558006, 54.02403049170971, 45.150568038225174, 46.300766319036484, 44.69165526330471, 43.29852841794491, 44.94825929403305, 45.11331103742123, 44.083790481090546, 43.538021966814995, 43.17885763943195, 47.133339643478394, 45.756217539310455, 44.019262343645096, 46.04804947972298, 48.84916037321091, 48.36600869894028, 45.688877552747726, 44.415942057967186, 46.63467340171337, 43.32916237413883, 35.880790650844574, 28.84460560977459, 7.064724359661341, 6.379452031105757, 27.679498828947544, 34.833631440997124, 38.96054819226265, 40.30427008867264, 21.86324592679739, 5.505970576778054, 0.6363918702118099, 0.17596851306734607, 0.1683500109356828, 0.05842362399562262, 0.05484550740220584, 0.06411781141650863, 0.07321179218706675, 0.06513045707833953, 0.03001537796080811, 0.18795768613927066, 0.03279860058682971, 0.0262837165792007, 0.21795789274619892, 0.020813976880162954, 0.03179130580974743, 0.0633093157375697, 0.020869534055236727, 0.088405521819368, 1.596334003843367, 14.53801229596138, 21.17596920579672, 21.438793502748013, 26.52034442871809, 32.41181239485741, 21.743702441453934, 15.283776428550482, 26.973394118249416, 30.586846321821213, 37.08276495337486, 36.69563792645931, 41.24802924692631, 42.13180862367153, 41.84239335358143, 41.47686056792736, 40.87390512228012, 42.6630125194788, 45.77436536550522, 46.19323588907719, 46.54917798936367, 46.95322550833225, 46.37187570333481, 44.54863853752613, 41.952990218997, 40.84762953221798, 44.081225618720055, 42.204187139868736, 41.901499181985855, 43.45174379646778, 42.59086199104786, 41.81023567914963, 42.96567767858505, 44.95442256331444, 49.50832240283489, 56.26546561717987, 60.672051161527634, 62.59699746966362, 62.218552976846695, 64.67420160770416, 61.832121312618256, 62.11152791976929, 58.55578511953354, 64.41344439983368, 62.498130574822426, 60.52453547716141, 53.30118767917156, 30.32458819448948, 1.5706203086301684, 3.7479944340884686, 47.269094958901405, 56.376054883003235, 56.66770063340664, 55.40860779583454, 24.32858593761921, 0.43274233234114945, 15.498985480517149, 39.65880632400513, 18.55385910719633, 14.144322071224451, 17.68462724983692, 28.154974915087223, 30.051261261105537, 30.29019434005022, 32.39603564143181, 44.59698714315891, 26.56563799828291, 40.068834722042084, 33.8911110162735, 32.75552675127983, 50.520968064665794, 68.3890950679779, 14.848623778671026, 1.3554123253561556, 0.20219721423927695, 0.28734622173942626, 0.07455562124960124, 0.1331874993047677, 0.13192264217650518, 0.059929007475147955, 0.051306071545695886, 0.1542207956663333, 0.0337179842608748, 0.1239464248646982, 0.05255845688225236, 0.01577254730364075, 0.08650957199279219, 0.3091032902011648, 0.38077385688666254, 32.99078732728958, 78.08138698339462, 57.7237019687891, 32.0113480836153, 39.91439960896969, 33.50596748292446, 33.690603375434875, 30.073529966175556, 38.49455639719963, 29.94148325175047, 35.47109663486481, 34.32036638259888, 36.479870304465294, 23.292543031275272, 11.46214859560132, 10.309740733355284, 29.00895059108734, 71.1419789493084, 54.38857913017273, 41.546769216656685, 63.557449132204056, 18.71091987937689, 0.7459110184572637, 0.1583653490524739, 1.4672158635221422, 1.114057945087552, 5.580955753102899, 34.64440919458866, 67.90148243308067, 64.80296909809113, 62.29097329080105, 63.398575857281685, 64.20538276433945, 59.87134292721748, 51.057115495204926, 48.841328993439674, 51.86535872519016, 57.13135935366154, 59.496428444981575, 56.21310442686081, 51.083562076091766, 48.2560919970274, 47.16835096478462, 45.96747860312462, 48.4000738710165, 48.664801865816116, 48.065859004855156, 47.82173730432987, 45.746725648641586, 45.881439819931984, 48.32435913383961, 48.935210555791855, 51.04875214397907, 52.90012679994106, 50.08212961256504, 49.508478194475174, 48.99774380028248, 46.99962101876736, 47.6424515247345, 40.58406427502632, 38.679082095623016, 16.453833393752575, 14.628911968320608, 23.202128782868385, 30.82125574350357, 30.551065541803837, 36.033181473612785, 24.860576391220093, 5.807714760303497, 0.5192022991832346, 0.07678740032133646, 0.07837633849703707, 0.08422159007750452, 0.03385085095942486, 0.07487927927286364, 0.006182809565871139, 0.040705263818381354, 0.12216248738695867, 0.09339571537566371, 0.05277887474221643, 0.024715219005884137, 0.11615490584517829, 0.22493865253636613, 0.08256909437477589, 0.05966231299680658, 0.06625975351198576, 0.02538521137466887, 1.5250671654939651, 14.854841195046902, 22.091554775834084, 15.547932554036379, 23.773844204843044, 39.25218254327774, 28.841276988387108, 22.364410534501076, 33.58862444758415, 38.697062730789185, 41.685834154486656, 42.213789224624634, 45.25841765105724, 47.09305040538311, 44.39841739833355, 43.65661360323429, 41.44846849143505, 44.92993667721748, 46.84361658990383, 47.34162926673889, 47.322877272963524, 48.49383004009724, 47.85310462117195, 47.70302027463913, 43.972604647278786, 43.16567614674568, 44.09013234078884, 46.26751810312271, 45.11070817708969, 47.102093920111656, 46.798634603619576, 47.10880436003208, 46.65153309702873, 46.964503303170204, 51.96295648813248, 58.583136051893234, 60.84769293665886, 64.32322204113007, 62.83688619732857, 65.06112724542618, 62.18466259539127, 63.84811833500862, 60.351948738098145, 63.913961201906204, 62.798132076859474, 63.06070938706398, 51.782576367259026, 23.74734252691269, 0.6603992788586766, 7.2553235571831465, 54.209380745887756, 59.3832591176033, 62.62243330478668, 57.06520490348339, 23.61958008259535, 0.6318847776856273, 25.385390929877758, 41.13847732543945, 21.94229118525982, 21.05433013290167, 14.854823146015406, 28.70486620813608, 28.78289882093668, 31.154989935457706, 38.777721002697945, 36.565555706620216, 26.73690240830183, 49.38198298215866, 31.33304838091135, 43.39634656906128, 52.262220829725266, 80.20757049322128, 21.82258240878582, 1.1427826224826276, 0.1330559907364659, 0.221091314451769, 0.017174981912830845, 0.17314225144218653, 0.2297245551017113, 0.20879487739875913, 0.17565402056789026, 0.24238632177002728, 0.3266356384847313, 0.2769130503293127, 0.15755243017338216, 0.1672857563244179, 0.11198019157745875, 0.4409395018592477, 0.6628905795514584, 43.36997598409653, 90.95371305942535, 66.8977814912796, 40.914399549365044, 60.75617104768753, 33.13233733177185, 36.93637780845165, 34.96454581618309, 55.01996845006943, 39.552651420235634, 42.04012334346771, 37.49864123761654, 50.64469322562218, 29.19142819941044, 12.933557890355587, 15.530533287674189, 39.76756028831005, 75.54098770022392, 55.28178580105305, 45.489270463585854, 67.39373847842216, 17.749810852110386, 0.9054495545569807, 0.3967821307014674, 1.3209932972677052, 2.89136768784374, 7.595164496451616, 43.26038606464863, 71.13733559846878, 67.14778527617455, 62.88928158581257, 64.09722536802292, 65.83607286214828, 65.56278392672539, 57.12736576795578, 55.0126538425684, 53.653261587023735, 59.57257255911827, 62.67947964370251, 56.70696772634983, 51.63186505436897, 51.24290272593498, 49.14642982184887, 48.89397896826267, 52.01599404215813, 51.992986276745796, 53.09588469564915, 52.100949883461, 50.29367186129093, 51.35929048061371, 51.41860529780388, 53.219811245799065, 55.05046181380749, 56.2112957239151, 52.04768054187298, 51.221578270196915, 51.952716037631035, 51.42345003783703, 50.658866465091705, 45.87411381304264, 48.79415072500706, 22.904610447585583, 27.91624702513218, 47.739152535796165, 55.83714880049229, 60.94914369285107, 53.88151153922081, 32.47047744691372, 8.559488151222467, 0.7355308067053556, 0.29512657143641263, 0.28343296609818935, 0.2043582295300439, 0.2574639127124101, 0.15723370743216947, 0.2327761030755937, 0.2753334038425237, 0.2325144366477616, 0.6773832987528294, 0.10307975549949333, 0.1114158402197063, 0.25381667248439044, 0.3981894801836461, 0.16380129876779392, 0.1562991357059218, 0.1928825187496841, 0.2460349869215861, 1.770155557896942, 13.036839198321104, 24.32957388460636, 27.319451048970222, 44.561462849378586, 45.44361971318722, 37.27706752717495, 29.016618579626083, 39.43499833345413, 42.53531277179718, 46.38143219053745, 45.13938143849373, 50.211926847696304, 52.278848737478256, 49.667644053697586, 49.033944457769394, 44.42723885178566, 46.06330566108227, 49.28883858025074, 49.38723050057888, 47.33294293284416, 50.21339736878872, 51.204900965094566, 50.0200941413641, 46.592898443341255, 47.64384984970093, 47.52688452601433, 47.39896439015865, 48.13213884830475, 52.32129625976086, 48.68883177638054, 50.37815272808075, 49.80113469064236, 51.022780537605286, 55.0344380736351, 62.96286083757877, 62.909808084368706, 71.89607128500938, 66.61916524171829, 66.32869362831116, 64.06481310725212, 67.64612093567848, 63.54329489171505, 66.37072697281837, 64.84741911292076, 68.05969834327698, 59.5014213770628, 36.45559340715408, 2.250073249451816, 5.570771349593997, 54.853598177433014, 66.33367136120796, 64.60359379649162, 64.1843318939209, 33.15129831433296, 4.974949546158314, 23.436186723411083, 45.50696611404419, 23.40459331870079, 18.26007217168808, 23.755741976201534, 40.83608575165272, 42.14872531592846, 39.61191684007645, 45.15763185918331, 60.82164153456688, 33.60168814659119, 62.97789663076401, 40.23783065378666, 49.421546459198, 61.45499914884567, 91.42355024814606, 29.532245211303234, 1.3380648312158883, 0.30381447868421674, 0.4307384742423892, 0.14435726712690666, 0.3431584284408018], [0.0923758115095552, 0.10431003596750088, 0.09053371191839688, 0.0836968248768244, 0.051834951955243014, 0.19289881631266326, 0.05547775042941794, 0.025985842621594202, 0.08233380387537181, 0.11109604878583923, 0.04512645646173041, 36.244130954146385, 67.06972226500511, 43.30277658998966, 44.86411660909653, 30.824527367949486, 27.295573130249977, 25.232329443097115, 28.817364871501923, 46.45957499742508, 33.174632862210274, 41.69788330793381, 33.21820132434368, 33.924507424235344, 32.14439794421196, 14.126490578055382, 4.157203501090407, 12.37009847536683, 49.57782067358494, 64.33589816093445, 42.16026909649372, 60.161966532468796, 38.55187252163887, 2.819149475544691, 0.3655268484726548, 0.7905964425299317, 0.1401851058471948, 6.896653678268194, 28.500849455595016, 59.62199650704861, 64.26439359784126, 63.490280136466026, 64.00308161973953, 63.27811852097511, 51.707192212343216, 44.61154796183109, 47.629441022872925, 50.47017239034176, 57.667924761772156, 58.5341452807188, 59.25784684717655, 53.75970907509327, 46.75847455859184, 47.25807934999466, 46.2543024122715, 45.101368278265, 47.044663801789284, 43.21747876703739, 44.04326185584068, 42.8597317636013, 47.74468883872032, 46.691256165504456, 42.53693528473377, 46.946830451488495, 48.003515750169754, 46.77255280315876, 46.54711090028286, 43.08052271604538, 44.752319008111954, 41.72242619097233, 35.716343075037, 20.243166759610176, 5.162535030394793, 6.858011651784182, 10.670428778976202, 33.921798169612885, 30.99910520017147, 35.5892588943243, 23.47302384674549, 4.989440543577075, 0.7816188898868859, 0.0951276950945612, 0.03691426958539523, 0.0672924445825629, 0.04611908268998377, 0.022564686551049817, 0.007113576857591397, 0.08007911470485851, 0.29953391931485385, 0.11274765391135588, 0.14412959106266499, 0.036631867551477626, 0.07410149366478436, 0.01503594810856157, 0.05461558263050392, 0.0556360690825386, 0.1746107984217815, 0.05427077710919548, 2.2248836886137724, 9.204800873994827, 16.41184374690056, 14.933682214468718, 11.456580944359303, 21.172914169728756, 23.038866743445396, 17.580868117511272, 27.29965031147003, 31.026967205107212, 33.92634652554989, 37.8227486461401, 39.702914357185364, 43.286752849817276, 38.47233898937702, 38.6481099575758, 43.90295818448067, 45.11618368327618, 47.26002864539623, 46.47616110742092, 46.456972137093544, 47.34728716313839, 46.57487601041794, 43.380452021956444, 39.532577097415924, 41.020372062921524, 42.690948620438576, 42.66554698348045, 41.70039877295494, 46.97019159793854, 47.063734978437424, 44.49284993112087, 41.3808511197567, 44.8377688229084, 50.091712698340416, 53.6931062489748, 51.40703871846199, 54.71471942961216, 57.76092857122421, 62.219316735863686, 62.07521326839924, 63.30285519361496, 61.019869297742844, 59.291756227612495, 58.57383035123348, 55.37687949836254, 30.599636435508728, 4.204234527423978, 0.02567251900472911, 19.219140708446503, 49.01298478245735, 49.86907124519348, 44.93453063070774, 50.554387271404266, 12.400823626667261, 0.48898032400757074, 22.57811676710844, 29.112251847982407, 21.26177430152893, 26.98775354772806, 20.000447183847427, 28.785021007061005, 27.484704181551933, 39.03904438018799, 23.9178279787302, 42.82014548778534, 39.28359165787697, 30.37891197949648, 62.96054296195507, 41.90253272652626, 46.4515346288681, 69.90279704332352, 16.075649186968803, 1.0475049912929535, 0.08072129508946091, 0.0663588302268181, 0.04706115010776557, 0.07836464967112988, 0.02869782463676529, 0.046026881973375566, 0.0784618042234797, 0.1049454182793852, 0.0823468879389111, 0.09103628690354526, 0.03081180631852476, 0.07443535621860065, 0.03386410571692977, 0.08842370443744585, 0.06724440536345355, 48.28383430838585, 72.82354071736336, 51.447989121079445, 47.00423777103424, 33.59122730791569, 32.93949007987976, 30.71078047156334, 33.056766986846924, 41.181715205311775, 33.79964992403984, 37.79700122773647, 36.278028935194016, 32.69863620400429, 22.235806435346603, 11.865316461771727, 5.867413356900215, 12.86207327619195, 54.57481473684311, 68.02763566374779, 44.18594799935818, 63.25430899858475, 47.08088345825672, 4.94978872127831, 0.7019713043700904, 1.5585086960345507, 0.38426676008384675, 7.895533628761768, 39.47819821536541, 66.5774130821228, 66.6543285548687, 65.28740510344505, 64.69760075211525, 63.21735978126526, 53.134616017341614, 50.71542263031006, 52.36997924745083, 55.41643537580967, 59.38388228416443, 60.542284324765205, 61.141603365540504, 57.500501945614815, 48.192187026143074, 49.81346882879734, 47.57460996508598, 50.467588528990746, 52.633126527071, 50.87628699839115, 47.776591926813126, 47.008786126971245, 47.81615920364857, 49.62531052529812, 48.80650386214256, 52.53701068460941, 52.28266753256321, 51.90870299935341, 51.16461172699928, 47.93779827654362, 50.537390783429146, 44.02974598109722, 43.95362086594105, 29.672210700809956, 14.450649283826351, 16.079551577568054, 16.39312595129013, 23.521741032600403, 20.490060411393642, 32.62577511370182, 30.560289546847343, 8.158704657107592, 0.4187874624039978, 0.053550222219200805, 0.08736273754038848, 0.18061849870719016, 0.15571917698252946, 0.1315053622238338, 0.03826814361673314, 0.11557684701983817, 0.3493286739103496, 0.2946675382554531, 0.11734694344340824, 0.041665807002573274, 0.028620884331758134, 0.06859719214844517, 0.04979706267477013, 0.01172649082946009, 0.10217193819698878, 0.025022397639986593, 1.8582490808330476, 10.126060489565134, 16.84843461960554, 13.6774230748415, 11.864868085831404, 30.341869667172432, 31.448852866888046, 23.167520239949226, 33.005120158195496, 36.36992320418358, 40.263749063014984, 42.26368434727192, 44.34877306222916, 45.44118024408817, 42.12533377110958, 41.05406105518341, 45.672884210944176, 47.21038430929184, 47.65965700149536, 49.27749998867512, 48.525128960609436, 51.902475133538246, 46.824720203876495, 46.38331688940525, 43.646635338664055, 44.12128306925297, 43.901628255844116, 44.698236510157585, 45.82109905779362, 50.38610950112343, 50.81863649189472, 47.621328458189964, 43.620583936572075, 46.62849873304367, 52.55532190203667, 56.32051706314087, 55.97520299255848, 57.954250797629356, 57.037014216184616, 59.467606991529465, 62.4508611112833, 65.03106325864792, 65.60924023389816, 63.14826048910618, 62.09714189171791, 53.981408178806305, 24.90507200360298, 1.8641525390557945, 0.24380805407417938, 25.700774006545544, 56.10313072800636, 53.608404994010925, 50.02420552074909, 51.39356464147568, 13.35541695356369, 1.0231401049531996, 25.72669241577387, 26.232473775744438, 19.189008325338364, 31.676240265369415, 19.173168875277042, 26.20825957506895, 28.30844108015299, 39.018768668174744, 28.935002759099007, 41.38790354132652, 37.672345116734505, 40.531030520796776, 61.694291308522224, 47.491732612252235, 51.45698323845863, 80.22641748189926, 23.233211115002632, 0.8198948297649622, 0.09908598425681703, 0.20138949039392173, 0.08205787336919457, 0.08927016839152202, 0.21994996553985402, 0.14842650736682117, 0.1930213300511241, 0.22994814935373142, 0.1954387573641725, 0.36931049544364214, 0.10023401249782182, 0.15468652301933616, 0.20965903415344656, 0.25667397072538733, 0.1531045461888425, 58.10524709522724, 84.22863632440567, 58.93367484211922, 57.44371019303799, 45.88830605149269, 36.201675832271576, 36.18773438036442, 37.624752670526505, 60.885162726044655, 43.16962033510208, 58.87021064758301, 42.83667840063572, 48.104438334703445, 39.2848189920187, 21.2907325476408, 10.251845140010118, 21.011124551296234, 61.03634141385555, 74.94964063167572, 49.95868943631649, 70.64859062433243, 45.78257292509079, 4.963393891230226, 2.192850220017135, 2.0570737682282925, 1.7870961176231503, 8.19040635600686, 45.445683002471924, 69.77611944079399, 68.17965030670166, 65.46996250748634, 66.23034730553627, 66.27323940396309, 59.046410992741585, 55.108127519488335, 55.228771045804024, 58.18312011659145, 62.32695356011391, 63.04755449295044, 65.14239728450775, 57.1761741489172, 49.56344224512577, 53.24813112616539, 51.48700922727585, 52.09638252854347, 53.32669951021671, 54.150639697909355, 52.09598354995251, 51.33635491132736, 52.28087782859802, 54.50065791606903, 54.45846877992153, 56.57264493405819, 56.85952574014664, 53.679388985037804, 56.28116637468338, 49.19260874390602, 54.24947239458561, 47.79424197971821, 48.88935461640358, 39.29595999419689, 21.851365864276886, 24.484626464545727, 34.73383739590645, 54.06161427497864, 43.45881521701813, 42.122309133410454, 31.098823249340057, 10.151828806847334, 0.7693939364980906, 0.1777607254916802, 0.12715806893538684, 0.20550799439661205, 0.2516716282116249, 0.1875870130606927, 0.10433003684738651, 0.3606669686269015, 0.539155206643045, 0.552635695785284, 0.31975251564290375, 0.1564603895531036, 0.08760573153267615, 0.21929834503680468, 0.11392408414394595, 0.18242255580844358, 0.35256408154964447, 0.2190110002993606, 2.4566387152299285, 9.004075694829226, 17.195109017193317, 18.284628354012966, 27.27682113647461, 37.94673599302769, 37.97112688422203, 32.85404406487942, 39.98493142426014, 41.96321167051792, 46.61516144871712, 48.594399243593216, 49.19352829456329, 51.79090932011604, 44.47739616036415, 44.02582839131355, 48.027921840548515, 50.42023926973343, 50.84654979407787, 50.921884551644325, 49.59850676357746, 55.185517966747284, 49.9017570912838, 50.84889806807041, 45.86619883775711, 46.83834247291088, 48.44474047422409, 49.43859614431858, 49.43720921874046, 52.68798418343067, 53.170049116015434, 50.05146525800228, 47.231826558709145, 50.37614643573761, 55.29321938753128, 60.33747151494026, 60.22722043097019, 62.6503200083971, 60.11744052171707, 65.90179413557053, 65.17045497894287, 67.33865663409233, 67.81145006418228, 62.19556421041489, 64.97335195541382, 62.41103544831276, 37.01238892972469, 7.3002266976982355, 0.22045934601919726, 24.325093924999237, 60.44173792004585, 59.51394930481911, 55.21935515105724, 59.89161863923073, 19.778174310922623, 2.359003904275596, 29.386538229882717, 35.60337893664837, 28.359073363244534, 35.14304503798485, 27.983178533613682, 39.20882686972618, 38.16759154200554, 54.52519319951534, 33.918530344963074, 63.1908144056797, 47.52339631319046, 49.31268610060215, 72.27057158946991, 53.76656770706177, 61.30177617073059, 94.20382305979729, 34.04511295258999, 1.1564249591901898, 0.3701504581840709, 0.4239406093256548, 0.25787717022467405, 0.24782964843325317], [0.16007795871701092, 0.17971046618185937, 0.05137545493198559, 0.09911896529956721, 0.07935786590678617, 0.22415221348637715, 0.03442318782617804, 0.03504617256112397, 0.08588170021539554, 0.10462177509907633, 0.5457004148047417, 50.511441975831985, 63.426128178834915, 32.29266598820686, 23.605156056582928, 33.87332037091255, 29.376290179789066, 23.82595270872116, 27.873793803155422, 40.880820751190186, 29.40659735351801, 37.16081656515598, 36.967859119176865, 34.429519325494766, 22.991167902946472, 10.29787302017212, 4.559106985107064, 10.09801134467125, 39.19293612241745, 51.06580562889576, 48.29707279801369, 53.651160299777985, 55.96077136695385, 14.916102457791567, 0.3194729337701574, 1.7613674607127905, 0.1852798243635334, 9.512129332870245, 35.60879744589329, 60.936896950006485, 66.17018893361092, 64.76605027914047, 59.72888857126236, 56.86159282922745, 49.17556665837765, 47.38901272416115, 51.67293705046177, 57.12675400078297, 56.603229492902756, 60.262098759412766, 57.20354028046131, 59.54828806221485, 47.94614262878895, 45.71130394935608, 47.16504894196987, 47.40050330758095, 49.347986206412315, 48.326270431280136, 44.77643631398678, 44.37001772224903, 45.851049050688744, 43.797859624028206, 46.88988670706749, 45.986967757344246, 50.76609291136265, 45.22662475705147, 48.65049183368683, 48.79717156291008, 45.440066903829575, 38.29322040081024, 36.98831342160702, 11.248972434550524, 5.711442651227117, 13.425388298928738, 1.6343229403719306, 17.22310211509466, 18.30034051090479, 17.60709621012211, 11.535832341760397, 3.6051907343789935, 0.425529369385913, 0.07475505117326975, 0.06281834052060731, 0.14680660679005086, 0.03495687364193145, 0.00735430729946529, 0.05509123991942033, 0.11832069314550608, 0.2977709623519331, 0.31590813130605966, 0.06241792958462611, 0.06976292803301476, 0.03258103628468234, 0.045769616481265984, 0.044792742337449454, 0.03031863619980868, 0.10730692476499826, 0.08158010838087648, 0.5415119114331901, 1.9955880800262094, 5.155251771211624, 6.946571599692106, 3.1047682743519545, 22.88786094635725, 25.94117760658264, 15.311811324208975, 25.545677728950977, 33.25830817222595, 33.075898960232735, 36.745761036872864, 38.97120662033558, 38.53125862777233, 40.990608260035515, 41.54792435467243, 42.99102991819382, 45.931399539113045, 48.60082849860191, 46.3970797508955, 46.86351612210274, 48.90957333147526, 44.18661676347256, 41.41571804881096, 40.2966894954443, 40.87860926985741, 40.059513822197914, 41.04992687702179, 43.98358605802059, 49.46915790438652, 49.81238588690758, 48.04886631667614, 43.260101079940796, 42.48350255191326, 48.48038636147976, 49.67941202223301, 52.68208310008049, 58.20517033338547, 54.987533390522, 55.137309953570366, 54.629641994833946, 57.22594767808914, 61.75778970122337, 63.34863133728504, 47.883780375123024, 29.199478067457676, 4.4334577023983, 0.12782217236235738, 1.1899696779437363, 27.522048577666283, 54.88580144941807, 59.007960855960846, 44.61194694042206, 41.71745605766773, 6.256609847769141, 1.2351086433045566, 25.986374281346798, 33.19080859422684, 21.176565773785114, 29.331013709306717, 16.497135870158672, 31.443073377013206, 24.26394570618868, 40.13144016265869, 35.53535498678684, 34.773837849497795, 38.67207147181034, 37.17854641377926, 19.730469770729542, 24.840171486139297, 43.48954416811466, 69.83455270528793, 11.19210658594966, 0.849217203212902, 0.052283413242548704, 0.05612719643977471, 0.10986319306539372, 0.0706739365705289, 0.06050571559171658, 0.14277536451118067, 0.07040034382953309, 0.10424929860164411, 0.0573144434747519, 0.08934580808272585, 0.05000649674911983, 0.09503197288722731, 0.05530291156901512, 0.15719991002697498, 0.9347611223347485, 59.66502159833908, 68.85552763938904, 41.23064137995243, 29.839443527162075, 38.31090085208416, 35.08973769843578, 29.380253367125988, 29.824377335608006, 39.106604754924774, 32.488765865564346, 32.00673893094063, 34.66348797082901, 32.63087064027786, 20.787542648613453, 8.907905705273151, 5.590817648917437, 12.30966366827488, 46.64109505712986, 53.51514659821987, 51.37488104403019, 59.29307475686073, 59.904496148228645, 20.16267567873001, 0.4259883431950584, 1.3349830778315663, 0.503712430363521, 9.568257071077824, 41.27832122147083, 66.36316537857056, 67.48928815126419, 64.54812437295914, 62.40900635719299, 59.43687804043293, 52.35723853111267, 51.10713981091976, 53.67747388780117, 59.870803356170654, 59.968997687101364, 62.13935002684593, 60.09436435997486, 60.408561900258064, 52.11355000734329, 49.65600907802582, 49.06106360256672, 50.22999867796898, 52.84890554845333, 49.26140405237675, 49.170334339141846, 46.72447398304939, 46.44658349454403, 48.76662120223045, 50.066637843847275, 49.36301440000534, 54.36854660511017, 50.63185751438141, 55.2408391982317, 50.02296298742294, 50.53620144724846, 44.56131845712662, 44.032903611660004, 20.87315585464239, 15.522150937467813, 21.24898038804531, 13.66407249122858, 15.799035429954529, 16.548879593610764, 20.456244125962257, 17.74449873715639, 4.529785383492708, 0.010408028374513378, 0.05447766561701428, 0.07003697348409332, 0.02266953160869889, 0.02569754793512402, 0.036443629214772955, 0.036284037778386846, 0.1281313065555878, 0.26014722185209394, 0.25289542973041534, 0.04033647208416369, 0.03356986642756965, 0.09433888117200695, 0.08587854608776979, 0.063361614884343, 0.03195846715243533, 0.0969808007357642, 0.03743941328139044, 0.7784103183075786, 2.5551246805116534, 5.44795386493206, 7.325390847399831, 5.725127141922712, 27.82926019281149, 33.843180388212204, 22.72690538316965, 31.008264608681202, 41.58361203968525, 39.66517858207226, 41.75792768597603, 42.38058887422085, 40.670935213565826, 43.223167061805725, 45.260914117097855, 48.08631330728531, 48.69304195046425, 50.755457282066345, 49.19624134898186, 46.525600254535675, 51.553900837898254, 46.87452033162117, 44.43148322403431, 42.479672357439995, 44.40382830798626, 44.61077280342579, 44.46935199201107, 46.639461144804955, 51.145491153001785, 52.44015768170357, 50.10859899222851, 45.86926147341728, 45.3350443392992, 50.44372960925102, 52.92647458612919, 56.68099232017994, 60.098046362400055, 56.33435972034931, 56.880474016070366, 54.862508699297905, 60.60101397335529, 62.39298641681671, 59.359464794397354, 41.26349821686745, 19.737873673439026, 2.54017295781523, 0.30297169578261673, 2.1698163310065866, 35.371424183249474, 62.69141860306263, 69.933051019907, 51.963264271616936, 42.480314522981644, 8.30239774659276, 2.3930510273203254, 21.201760321855545, 27.615160681307316, 23.330748081207275, 31.620183773338795, 20.901285745203495, 30.015835762023926, 24.478107914328575, 38.02342347800732, 31.243306696414948, 39.283990636467934, 37.201782166957855, 44.231781139969826, 18.707222677767277, 26.865550205111504, 50.59392414987087, 78.72925221920013, 16.522151827812195, 1.0008478886447847, 0.05621675882139243, 0.12729135865811259, 0.11359218828147277, 0.07274645075085573, 0.15365407685749233, 0.31324278214015067, 0.19894077413482592, 0.24035001697484404, 0.19074586074566469, 0.24980322690680623, 0.16082350543001667, 0.15559234394459054, 0.20375265186885372, 0.313936096499674, 1.2879831623286009, 75.60325875878334, 82.63082206249237, 47.48982511460781, 32.46682584285736, 46.26343332231045, 38.985197469592094, 34.95628125965595, 34.53325375914574, 53.92979174852371, 40.18048793077469, 50.5490979552269, 46.90692879259586, 43.57330307364464, 30.033791698515415, 14.932399783283472, 10.96077024936676, 16.63431040942669, 52.99224905669689, 61.20665207505226, 58.6210922151804, 66.61296397447586, 63.694686368107796, 19.03769474476576, 2.2066874150186777, 3.979725711978972, 1.5872311173006892, 10.960483364760876, 46.99879266321659, 71.19817793369293, 67.4485619366169, 69.40078318119049, 65.1260581612587, 64.93305131793022, 57.060751542449, 55.48127509653568, 56.45935021340847, 63.16090241074562, 62.00539581477642, 66.96554705500603, 63.110106736421585, 63.68814691901207, 54.076129496097565, 53.49482908844948, 50.06011739373207, 51.98700159788132, 55.06455525755882, 53.696978241205215, 50.56887209415436, 50.7753986120224, 49.75814379751682, 53.149306029081345, 55.57826869189739, 52.04649120569229, 57.96879641711712, 53.86145621538162, 57.4601025134325, 55.10326378047466, 51.93032383918762, 50.2749502658844, 52.11540810763836, 27.325329333543777, 22.875167727470398, 30.30286096036434, 25.901167653501034, 37.75225102901459, 24.936289228498936, 24.174175523221493, 21.603140383958817, 5.385484267026186, 0.5165600159671158, 0.1806454238248989, 0.11619357173913158, 0.2277033604332246, 0.18396907282294706, 0.16550706583075225, 0.16895624168682843, 0.27318360982462764, 0.8842894993722439, 0.6061418121680617, 0.11337191142956726, 0.16288332146359608, 0.14640016219345853, 0.16161603009095415, 0.11033321003196761, 0.0900541731971316, 0.23754483234370127, 0.18415601982269436, 1.0101198661141098, 2.8683843836188316, 6.703923270106316, 8.530181273818016, 14.110466837882996, 39.67452608048916, 38.660292103886604, 29.048122689127922, 39.211444929242134, 47.16131754219532, 45.117057636380196, 47.02644757926464, 47.9932677000761, 45.06350331008434, 45.82515724003315, 47.83630192279816, 51.4765901863575, 51.06811210513115, 52.52865873277187, 50.28648264706135, 48.95450212061405, 57.575080543756485, 50.729413479566574, 48.31116624176502, 46.83702394366264, 46.922374963760376, 49.05788317322731, 47.68635056912899, 47.846899554133415, 53.32005746662617, 55.95385953783989, 53.39163042604923, 48.76513548195362, 48.719955906271935, 54.17189575731754, 55.851880609989166, 62.11236007511616, 64.05928060412407, 58.97585637867451, 58.53458225727081, 59.45414051413536, 64.91574704647064, 66.73443585634232, 68.86753499507904, 52.97082960605621, 34.459488317370415, 6.461055027320981, 0.2659823728026822, 2.266971655189991, 36.79931156337261, 63.751770704984665, 68.91950860619545, 53.77279557287693, 50.46454109251499, 12.101151756942272, 5.267500123009086, 33.73760685324669, 36.72127515077591, 25.94091162085533, 40.5064382404089, 22.442864924669266, 40.51165156066418, 33.187453374266624, 53.02765555679798, 47.481355369091034, 49.305941462516785, 48.0544064193964, 50.449999272823334, 25.53707119077444, 37.38449536263943, 62.60424368083477, 89.53719466924667, 25.70972442626953, 1.1178659345023334, 0.2746226638555527, 0.4744579188991338, 0.20285400009015575, 0.20091700949706137], [0.09742433787323534, 0.07067343191010877, 0.021726176564698108, 0.12455014715669677, 0.018092790378432255, 0.0869257609883789, 0.05962129449471831, 0.10871436330489814, 0.03063033080252353, 0.26463362330105156, 0.20574062800733373, 39.70862165093422, 61.17946453392506, 32.9721113294363, 35.85722051560879, 36.198081225156784, 32.73870885372162, 25.034295469522476, 34.321521520614624, 40.937931686639786, 33.53036977350712, 34.16254565119743, 41.11393444240093, 30.364879332482815, 21.173565834760666, 6.793834520503879, 3.722232528962195, 10.880605950951576, 47.368018850684166, 59.6020095795393, 46.18729680776596, 55.9038770198822, 59.31818760931492, 32.54962719976902, 1.9570418796502054, 2.6001883624121547, 0.1674117729999125, 9.410001263022423, 37.66527369618416, 63.42478685081005, 65.30676126480103, 63.848095536231995, 59.81706663966179, 53.886318281292915, 46.69956251978874, 51.1066610366106, 54.745140597224236, 59.40801098942757, 57.06355199217796, 57.454539611935616, 59.64592382311821, 58.4162338078022, 49.56714704632759, 45.124243050813675, 47.72693619132042, 50.360688865184784, 54.42056581377983, 49.92103725671768, 48.1008817255497, 45.28610296547413, 44.66373436152935, 43.821441158652306, 47.8136133402586, 47.764405980706215, 47.546749860048294, 46.42784669995308, 49.1851307451725, 45.946131348609924, 46.66763283312321, 36.62155710160732, 32.20907427370548, 6.596204275265336, 11.612653769552708, 10.979319903999567, 8.52503539994359, 3.2834767224267125, 5.893894135951996, 4.63377820327878, 3.5120886052027345, 0.3910984966205433, 0.08685565029736608, 0.08006123636732809, 0.0518868763174396, 0.048378584688180126, 0.0318486998003209, 0.07612447690917179, 0.03509972964820918, 0.1494075226946734, 0.3125081449979916, 0.23455348738934845, 0.05533450479560997, 0.01796737669792492, 0.0498943619459169, 0.04145721526583657, 0.03428561220061965, 0.05272832335322164, 0.04649053131288383, 0.014759006426174892, 0.07465207076165825, 0.09634958187234588, 0.1709134632255882, 0.4317752842325717, 0.8324706112034619, 18.586242869496346, 30.849813111126423, 19.04381051659584, 23.671295307576656, 31.604921892285347, 34.24394488334656, 36.458363458514214, 36.47179193794727, 36.37648165225983, 40.827414616942406, 42.45184265077114, 45.84579773247242, 47.780733704566956, 47.585553377866745, 46.59030698239803, 46.10094264149666, 45.75880900025368, 42.201097905635834, 39.147604554891586, 40.479516685009, 39.12661448121071, 40.17676033079624, 39.920304492115974, 50.228049382567406, 51.465190798044205, 50.85623927414417, 50.966182574629784, 45.49506135284901, 42.64913186430931, 45.26571325957775, 49.7151605039835, 55.7219123840332, 58.23443256318569, 58.654697611927986, 59.519272819161415, 50.819046869874, 51.73143111169338, 45.23764796555042, 20.34090131521225, 8.576912116259336, 1.089639742858708, 0.18153801967855543, 0.8883906668052077, 5.829478092491627, 41.920209378004074, 52.52518191933632, 28.26604675501585, 29.86551582813263, 49.4972687959671, 8.1436413154006, 1.8347427109256387, 7.628933759406209, 40.35326465964317, 22.63290222734213, 42.896297201514244, 14.223369229584932, 27.28110160678625, 29.802895188331604, 33.55718493461609, 36.48403488099575, 25.81675138324499, 29.683648087084293, 27.034055963158607, 48.73752236366272, 46.23248778283596, 45.25576539337635, 70.05408972501755, 10.165154691785574, 0.572781739756465, 0.016249419859377667, 0.05446376890176907, 0.0749675948463846, 0.06273415870964527, 0.016770184884080663, 0.05776542064268142, 0.03265497274696827, 0.04684669169364497, 0.03520183061482385, 0.0905875769967679, 0.06882722082082182, 0.08303625407279469, 0.037073360072099604, 0.09993797721108422, 0.6036765163298696, 50.12167789041996, 71.37267976999283, 37.041107788681984, 32.787566632032394, 39.41210076212883, 37.77218095958233, 29.680860936641693, 36.38456001877785, 38.17069597542286, 35.167508125305176, 33.23615916073322, 40.85111014544964, 33.36481265723705, 24.24217287451029, 10.493497923016548, 3.9110605465248227, 12.730763722211123, 49.87248346209526, 61.46782346069813, 49.7425152361393, 61.54218927025795, 63.63679647445679, 40.32757043838501, 3.091707187704742, 1.8444782635197043, 0.256204666220583, 10.079531986266375, 43.04988116025925, 68.61605688929558, 65.74993148446083, 66.25772103667259, 60.67943416535854, 55.542888790369034, 49.19578917324543, 53.885125145316124, 57.34504088759422, 63.848369121551514, 59.49384078383446, 58.147516027092934, 58.908546790480614, 59.593722224235535, 54.17371205985546, 49.032204151153564, 49.69980552792549, 53.41609351336956, 55.625435560941696, 52.69391946494579, 49.174381121993065, 49.65971387922764, 46.48958578705788, 48.06070268154144, 51.65869541466236, 51.578101739287376, 51.5027441829443, 52.30566769838333, 52.87298485636711, 50.76605871319771, 52.23855949938297, 42.66548618674278, 39.53201852738857, 15.659448020160198, 20.76895784586668, 20.036676339805126, 15.603048596531153, 4.920004494488239, 6.912062326446176, 7.807524651288986, 4.513722220435739, 0.7983468985185027, 0.25998109951615334, 0.11789839627454057, 0.06594382124603726, 0.13514056481653824, 0.07944676035549492, 0.03832548565696925, 0.01583170389494626, 0.13577728299424052, 0.6066807894967496, 0.26197281607892364, 0.015076517611305462, 0.05477910744957626, 0.013827859711454948, 0.04301397391827777, 0.07450289907865226, 0.04848684176977258, 0.01975390056031756, 0.04144392711168621, 0.06065686138754245, 0.20285552891436964, 0.46262642252258956, 0.6492425431497395, 0.5366026342380792, 24.12825308740139, 37.286418825387955, 25.450618229806423, 30.8735029399395, 37.93861962854862, 40.086731761693954, 40.74145942926407, 40.22496834397316, 40.88924489915371, 44.465685188770294, 48.26700881123543, 49.77138228714466, 51.586822271347046, 48.884977251291275, 48.187437281012535, 48.709939643740654, 46.99246220290661, 45.31430885195732, 42.339904457330704, 45.5913519859314, 42.76529923081398, 42.505526170134544, 43.296047151088715, 49.90469813346863, 55.34396566450596, 55.38651578128338, 51.6156817227602, 50.02708576619625, 45.51960043609142, 48.142512291669846, 52.60318033397198, 56.78273946046829, 58.80075417459011, 61.98106952011585, 58.84589955210686, 53.83006609976292, 52.45665639638901, 40.151465088129044, 10.09454783052206, 4.409491438418627, 0.44536011933814734, 0.962688495637849, 1.4633284346200526, 8.34584841504693, 47.39470861852169, 52.33485773205757, 30.47079674899578, 33.664688766002655, 52.86503568291664, 13.632718473672867, 3.149452214129269, 6.106933979317546, 41.583368852734566, 24.891022257506847, 36.44982911646366, 21.241386495530605, 27.628777250647545, 26.243825666606426, 31.32661532610655, 33.88243608176708, 29.07352052628994, 27.61028554290533, 36.253478452563286, 43.18086013197899, 48.31330172717571, 54.294568374753, 80.63402161002159, 12.963663674890995, 0.920270481146872, 0.08888234428013675, 0.25774860056117177, 0.03173082819557749, 0.17777674103854224, 0.1914034184301272, 0.21772220148704946, 0.12586371885845438, 0.2001962356735021, 0.2014308428624645, 0.14837002992862836, 0.2172774769132957, 0.24635802896227688, 0.19780601549427956, 0.31090106873307377, 1.4192728861235082, 63.724355176091194, 81.55161917209625, 45.36390379071236, 47.71759629249573, 47.087833285331726, 47.00925350189209, 33.46051812171936, 46.83303415775299, 54.341317266225815, 44.441427290439606, 45.842613503336906, 55.54883927106857, 39.50172275304794, 26.205191239714622, 11.202267240732908, 9.962769951671362, 18.959702029824257, 57.58258894085884, 69.40923392772675, 57.03467734158039, 66.70531421899796, 66.88604012131691, 38.28755110502243, 4.293621405959129, 6.097656777128577, 0.7521225570235401, 11.574815399944782, 46.48653835058212, 72.60972619056702, 67.45063662528992, 69.23165425658226, 63.910944163799286, 59.6282509714365, 52.08026759326458, 57.1447916328907, 59.97529774904251, 68.29513370990753, 62.40443900227547, 62.714266777038574, 64.7655639052391, 62.33532831072807, 55.08476257324219, 51.526314318180084, 54.62690994143486, 53.44048820436001, 58.96438479423523, 56.483357325196266, 52.06903539597988, 51.85834810137749, 50.71052469313145, 51.24256834387779, 54.017217457294464, 53.85328285396099, 52.773635387420654, 54.60064955055714, 56.81118853390217, 52.99765236675739, 56.08493350446224, 48.51115711033344, 45.80997325479984, 20.74974797666073, 28.31827875226736, 30.438156500458717, 28.818575106561184, 18.46257470548153, 9.015410486608744, 10.023923870176077, 5.705020045861602, 0.8774955233093351, 0.4404184251325205, 0.23987395892618224, 0.21503058029338717, 0.1640838640742004, 0.19163094606483355, 0.2050029777456075, 0.11991789142484777, 0.30075540533289313, 1.496283591259271, 0.7383155229035765, 0.12423143183696084, 0.20600585674401373, 0.198600321309641, 0.09801436011912301, 0.17022994521539658, 0.17816063918871805, 0.12199811651953496, 0.1807343479595147, 0.16617151064565405, 0.32379362848587334, 0.4072165786055848, 0.9400720498524606, 1.6613898379728198, 32.70968601107597, 42.143876776099205, 32.01531507074833, 37.8215479105711, 43.93832668662071, 45.56568816304207, 46.51132442057133, 44.3941730260849, 41.51746518909931, 47.31712818145752, 50.831749588251114, 52.99675561487675, 54.94733914732933, 53.39277036488056, 50.918806716799736, 51.514310762286186, 50.934173092246056, 47.97270320355892, 47.27758750319481, 48.45380678772926, 46.56218849122524, 44.91713136434555, 45.957253351807594, 54.22749437391758, 57.22537390887737, 57.07546815276146, 53.59116151928902, 50.802088379859924, 48.24129939079285, 50.66767819225788, 56.33259281516075, 61.53552062809467, 61.618941351771355, 62.16867685317993, 60.134079828858376, 53.32853481173515, 51.68633513152599, 50.17458625137806, 24.298869632184505, 9.828547853976488, 1.6605731192976236, 0.5271002347581089, 1.5703048068098724, 7.464047307148576, 52.78931714594364, 63.53940770030022, 37.81340874731541, 39.61723655462265, 60.3440185636282, 12.56747318431735, 5.447358721867204, 12.458319291472435, 46.0644493997097, 28.771127052605152, 56.939530447125435, 22.6185142993927, 36.79923556745052, 39.40900392830372, 46.35855361819267, 48.68824280798435, 36.244465336203575, 35.6153254956007, 40.489696338772774, 65.99856734275818, 59.451982229948044, 65.44540822505951, 91.8890480697155, 20.6048883497715, 0.9913669223897159, 0.2426708018174395, 0.3297324723098427, 0.14283915952546522, 0.32021528924815357], [0.04575454717269167, 0.05862694277311675, 0.04639904305804521, 0.10681712956284173, 0.009927575883921236, 0.0646579464955721, 0.05858648830326274, 0.06066168534744065, 0.10815838337293826, 0.12222680190461688, 0.37345761666074395, 46.63780063390732, 53.31067956984043, 37.78541944921017, 35.28675712645054, 29.765885174274445, 38.057731837034225, 24.768666923046112, 37.67599292099476, 38.87445241212845, 38.019889667630196, 32.09634572267532, 39.34618949890137, 27.698028534650803, 22.199052907526493, 6.437887670472264, 2.432489823549986, 5.4926470667123795, 35.46978950500488, 59.75492477416992, 50.99609076976776, 52.30651505291462, 55.56013606488705, 31.912086009979248, 2.9929956095293164, 0.9326698095537722, 0.032582372150500305, 6.44161812029779, 40.97511649131775, 65.5648586153984, 65.19364133477211, 61.76791235804558, 56.812522262334824, 52.28785425424576, 48.82049851119518, 52.50157378613949, 56.93679079413414, 58.32721218466759, 59.74202826619148, 55.93841716647148, 56.05115331709385, 57.46965140104294, 49.31157276034355, 46.22651070356369, 46.64715193212032, 53.51720228791237, 54.431087449193, 53.92238214612007, 49.106585159897804, 47.84427389502525, 44.55634072422981, 44.13347281515598, 47.270896062254906, 47.54756301641464, 49.6919247508049, 47.76124835014343, 49.45578262209892, 46.907658353447914, 41.5304908901453, 36.87074393033981, 23.316943421959877, 7.8462963458150625, 15.160884372889996, 14.008900187909603, 9.59762379527092, 0.530445302138105, 0.3024524892680347, 0.038377294986275956, 0.08456798750557937, 0.16936203319346532, 0.07581139449030161, 0.053948510612826794, 0.06812485968112014, 0.0197363858751487, 0.05058061105955858, 0.02195321623730706, 0.04880817316006869, 0.04362321778899059, 0.20344115764601156, 0.45990054379217327, 0.14415843092137948, 0.019111640394839924, 0.031967695758794434, 0.09800901665585116, 0.07131570877390914, 0.07746481045614928, 0.05435546729131602, 0.17898222635267302, 0.04938208337989636, 0.051638639051816426, 0.16380159562686458, 0.23202228883747011, 0.22618408023845404, 12.566691376268864, 35.63227638602257, 22.216231785714626, 20.556725934147835, 32.22851023077965, 32.840038016438484, 37.402981370687485, 37.01394684612751, 39.95140202343464, 39.00866501033306, 44.29705023765564, 43.64672273397446, 45.67816212773323, 44.74863700568676, 46.83233119547367, 44.51906472444534, 43.46449591219425, 41.16583585739136, 40.92745564877987, 40.98991669714451, 41.921315118670464, 39.68943268060684, 40.994784235954285, 47.729675844311714, 50.96582159399986, 54.11674551665783, 52.68518753349781, 48.506433963775635, 44.35516431927681, 43.766009733080864, 50.721585899591446, 52.95228660106659, 54.44076932966709, 58.12803827226162, 62.203254997730255, 55.37646912038326, 53.86312432587147, 15.64095726236701, 0.252809637458995, 0.05785121291410178, 0.03399512446776498, 0.3458443202544004, 1.3999125687405467, 20.998374335467815, 57.58094362914562, 56.27453193068504, 36.09545633196831, 49.9043295532465, 48.31124983727932, 31.7155434563756, 2.538719535805285, 4.089865889400244, 37.599362432956696, 22.702031917870045, 40.55668294429779, 17.581666074693203, 35.55185370147228, 28.24529606848955, 30.60606189072132, 29.29679274559021, 38.11597131192684, 43.22982430458069, 33.941572308540344, 31.500330604612827, 39.13167200982571, 49.540696665644646, 58.759005814790726, 4.190953290089965, 0.3209026367403567, 0.021111581809236668, 0.06534588028443977, 0.0670565826294478, 0.09920651646098122, 0.04822319751838222, 0.01726268706988776, 0.06454122893046588, 0.1314764333073981, 0.06783810124034062, 0.0985045189736411, 0.018249448476126418, 0.08811418432742357, 0.0759740213106852, 0.2016834996175021, 0.9397857589647174, 57.66613885760307, 64.55952376127243, 41.20992489159107, 36.610146313905716, 35.35090148448944, 39.04578521847725, 30.606390573084354, 36.419939920306206, 39.09341186285019, 35.6587989628315, 33.11140425503254, 37.12417133152485, 32.33013957738876, 24.665310569107533, 14.361227732151747, 5.643057245761156, 4.671404734253883, 36.17312416434288, 62.125864550471306, 55.407452657818794, 57.0719875395298, 60.73502518236637, 33.54735106229782, 4.189632385969162, 1.9174060877412558, 0.4315795947331935, 6.913750385865569, 41.81768327951431, 68.41750234365463, 67.26837560534477, 66.24073594808578, 59.92026910185814, 54.658231660723686, 50.808658227324486, 56.69246390461922, 59.26001273095608, 60.500763952732086, 60.41201211512089, 57.95254468917847, 60.113868713378906, 58.18176358938217, 54.44448173046112, 47.26192854344845, 50.07848180830479, 56.26718692481518, 56.905754059553146, 55.89329078793526, 52.784157022833824, 51.993225663900375, 48.905625343322754, 47.62760192155838, 50.50508871674538, 50.83428405225277, 52.701382264494896, 52.90731601417065, 53.41897755861282, 48.65347467362881, 48.24414163827896, 40.341937467455864, 31.21069684624672, 16.811863481998444, 23.709181174635887, 22.03602645546198, 19.275685474276543, 0.7429995434358716, 0.30840151535812765, 0.25235915381927043, 0.28461636509746313, 0.1330507660168223, 0.0034777953896991676, 0.008791187301540049, 0.05398906898335554, 0.05835708674567286, 0.05475066835060716, 0.017729091632645577, 0.05500568884599488, 0.08347967246663757, 0.26600903074722737, 1.7400222248397768, 0.1896668373956345, 0.05664647716912441, 0.08223101642215624, 0.04958395868015941, 0.10635622616973706, 0.04073185125889722, 0.07116680426406674, 0.16834695328725502, 0.021134298949618824, 0.07300396857317537, 0.1808169044670649, 0.056790468661347404, 0.3564668877515942, 15.509038791060448, 41.28528244793415, 28.45306321978569, 28.58255837112665, 38.09282295405865, 37.80410684645176, 42.3732590675354, 40.60589410364628, 44.640696197748184, 43.99421028792858, 48.277716636657715, 46.240072175860405, 51.17249630391598, 48.62187556922436, 47.74899020791054, 47.02052749693394, 45.89142948389053, 45.16888305544853, 43.12047757208347, 43.90728235244751, 45.01410216093063, 43.51740047335625, 44.00655962526798, 50.87319776415825, 53.27390134334564, 57.09107771515846, 56.267768293619156, 51.28548324108124, 47.171835377812386, 47.72350117564201, 51.45081616938114, 55.73457330465317, 57.368736416101456, 58.97549919784069, 63.81004437804222, 57.37244501709938, 56.26209519803524, 11.64776673540473, 0.3705150308087468, 0.1997494776151143, 0.2890956122428179, 1.4275342365726829, 1.6709814732894301, 26.07800256460905, 60.3849271684885, 61.22210584580898, 39.835333451628685, 53.51558357477188, 55.61090514063835, 39.120101630687714, 3.0208709137514234, 6.151275699958205, 44.35141772031784, 25.364275462925434, 36.221347376704216, 21.842345148324966, 34.32416997849941, 25.01327119767666, 33.64065885543823, 31.003824546933174, 38.24460580945015, 39.98531140387058, 35.577787309885025, 39.461334720253944, 42.25660912692547, 58.810352459549904, 64.33929517865181, 5.553507450968027, 0.32968354993499815, 0.037872359971515834, 0.07354603323619813, 0.020650320329878014, 0.06624684756388888, 0.21772607549792156, 0.12374923622701317, 0.25767554354388267, 0.22657640918623656, 0.11910598928807303, 0.2945793711114675, 0.14984556793933734, 0.38409986591432244, 0.2627395436866209, 0.32608321344014257, 1.6976609104312956, 69.94245171546936, 75.17762839794159, 52.872464284300804, 50.435955226421356, 39.47320148348808, 51.74164496362209, 35.0661713629961, 52.30883672833443, 50.50694301724434, 49.16414067149162, 41.952230259776115, 55.682356506586075, 35.56478440761566, 28.135090582072735, 10.331352073699236, 8.122540097683668, 12.62872114777565, 45.18139198422432, 70.09151011705399, 59.86377753317356, 62.22299113869667, 67.06811115145683, 39.36948984861374, 4.986978275701404, 2.7029130002483726, 0.8833834854885936, 9.160470552742481, 45.750772431492805, 71.52147218585014, 68.89007538557053, 66.18263706564903, 64.03721138834953, 59.04683656990528, 54.199535474181175, 59.29867945611477, 61.5251661837101, 63.3027184009552, 62.92776972055435, 61.91978260874748, 63.439761847257614, 63.20061407983303, 58.46933975815773, 50.87537884712219, 53.59098292887211, 58.70176948606968, 59.912152737379074, 58.9226820319891, 55.243126675486565, 54.905890971422195, 51.14951893687248, 51.077695190906525, 54.144430831074715, 53.37135091423988, 55.53039886057377, 55.79294577240944, 55.5726183950901, 53.23110044002533, 52.19627916812897, 47.21132665872574, 36.55325956642628, 24.674924053251743, 34.38001178205013, 34.142771512269974, 33.97839993238449, 3.2091752719134092, 0.3579924762016162, 0.6004244845826179, 0.40866709139663726, 0.2596685662865639, 0.13602787657873705, 0.1312844842323102, 0.16798429540358484, 0.15452133578946814, 0.11062742705689743, 0.16010852035833523, 0.14770558511372656, 0.28431244078092277, 1.102682661730796, 1.5626879967749119, 0.45680789567995816, 0.11493952770251781, 0.1937143030227162, 0.18401649605948478, 0.2558619127376005, 0.22752802062314004, 0.13627382431877777, 0.26376100606285036, 0.14821300632320344, 0.2221616101451218, 0.31205959094222635, 0.28474445978645235, 0.43827296525705606, 22.619418650865555, 47.07603871822357, 32.88088962435722, 36.690553799271584, 45.50766907632351, 43.662241101264954, 44.743651673197746, 43.90977121889591, 47.33559899032116, 45.26162847876549, 51.4103939384222, 47.63085834681988, 52.42285721004009, 51.3342422246933, 50.96028909087181, 49.276538640260696, 49.22151379287243, 48.99264067411423, 47.86488398909569, 48.325008898973465, 47.49079026281834, 44.803650453686714, 46.835105046629906, 53.56757998466492, 54.95774298906326, 61.26676104962826, 58.237214013934135, 54.37179543077946, 49.44030985236168, 51.43007308244705, 56.37949749827385, 57.757645547389984, 58.8691771030426, 62.26344756782055, 64.8707802593708, 58.51331099867821, 55.56917577981949, 19.009806141257286, 1.2018557963892817, 0.5967525159940124, 0.42435971496161073, 1.6002786671742797, 2.612545774318278, 25.870187915861607, 63.900927901268005, 60.83399847149849, 42.164258882403374, 60.52553862333298, 58.61512653529644, 39.529894441366196, 6.527204252779484, 7.342648096382618, 45.83839952945709, 29.090477116405964, 54.30325090885162, 23.11898924410343, 48.474363684654236, 39.77416813373566, 43.874908089637756, 38.659376353025436, 52.21803680062294, 54.93883900344372, 44.233194664120674, 41.64252407848835, 51.517324000597, 67.95502915978432, 78.88070449233055, 9.478412792086601, 0.6902638950850815, 0.13067941123154014, 0.3460471343714744, 0.13727254729019478, 0.31664392619859427], [0.10054153623059392, 0.032926828862400725, 0.012432998719305033, 0.010119926646439126, 0.09144054958596826, 0.11218909130548127, 0.02909743219788652, 0.06437097283196636, 0.04339952334703412, 0.16244635975454003, 0.7100192131474614, 55.58280184864998, 59.9675689637661, 32.60673813521862, 34.81944680213928, 31.730632446706295, 37.52129182219505, 25.714092291891575, 41.79529868066311, 38.21071542799473, 38.199616223573685, 28.548451401293278, 42.63978436589241, 34.34351094067097, 29.12257019430399, 15.630927700549364, 2.6054973900318146, 0.9573423606343567, 18.596190735697746, 56.4754993468523, 40.07154397666454, 56.305789053440094, 52.28808984160423, 40.73388263583183, 7.440022146329284, 1.590139742475003, 0.10683105967473239, 6.215432407334447, 41.779635921120644, 66.90608024597168, 64.66882109642029, 63.185224905610085, 55.43148256838322, 50.96649795770645, 48.467862233519554, 56.071011051535606, 56.26522623002529, 59.37270328402519, 58.60786512494087, 57.27600619196892, 58.44668537378311, 55.82356072962284, 48.282321989536285, 45.35110607743263, 49.674202501773834, 57.56942644715309, 55.52996188402176, 57.56349876523018, 51.334154829382896, 50.12390077114105, 46.890817657113075, 45.78960254788399, 47.549253925681114, 48.5394199937582, 49.26940642297268, 52.24056959152222, 47.71185100078583, 49.840082600712776, 42.4372286349535, 31.93363845348358, 18.24324667453766, 9.195929300040007, 19.31562703102827, 17.689150907099247, 12.916506305336952, 0.4912003251956776, 0.06877625011838973, 0.019979068165412173, 0.06455496608396061, 0.00503598174873332, 0.02635333003127016, 0.06197439244715497, 0.050351023965049535, 0.13029426627326757, 0.045818813450750895, 0.03671820159070194, 0.10709819573094137, 0.10156023781746626, 0.3802728181472048, 1.0384351154789329, 0.20581649034284055, 0.09569595757056959, 0.09253276832168922, 0.031048456803546287, 0.010073098055727314, 0.0525526273122523, 0.1423154555959627, 0.040156286049750634, 0.034437058566254564, 0.022657477275060955, 0.03629265040217433, 0.07947617908939719, 0.037689917808165774, 6.846344377845526, 30.778975412249565, 25.1601580157876, 19.226647205650806, 30.00254787504673, 32.90750339627266, 37.61528737843037, 37.32898414134979, 38.420057594776154, 40.04195876419544, 43.4907791018486, 46.223163083195686, 45.17552889883518, 47.10876636207104, 45.65544314682484, 43.37963126599789, 42.88691930472851, 40.887295603752136, 42.9850148409605, 40.1743246614933, 42.07609601318836, 42.511837631464005, 41.87302350997925, 50.67665711045265, 54.46279674768448, 54.79292683303356, 52.62048460543156, 51.10059276223183, 46.254101023077965, 41.63299418985844, 44.7149708122015, 49.48694095015526, 55.58211028575897, 54.420998990535736, 59.953999891877174, 57.60550171136856, 59.32529702782631, 7.175947716459632, 0.3189280192600563, 0.4694348556222394, 0.42705635307356715, 3.308905432932079, 4.231660030782223, 36.48876562714577, 51.905792355537415, 45.28829164803028, 64.29054379463196, 67.35536813735962, 60.320991799235344, 33.51244233548641, 0.2389631952974014, 8.456701766699553, 32.40259408950806, 27.601464316248894, 37.66039475798607, 22.659295611083508, 36.7998131364584, 25.795102044939995, 27.09182806313038, 38.67357239127159, 27.808659598231316, 32.87047818303108, 37.44661062955856, 22.822888232767582, 29.232182912528515, 56.185118928551674, 54.100079610943794, 1.644895754288882, 0.18378645996563137, 0.041520835875417106, 0.022010265129210893, 0.1169801369542256, 0.07501802378101274, 0.025744522172317374, 0.056225352891488, 0.05719261993363034, 0.05245191787253134, 0.05379234047723003, 0.12076727201929316, 0.04961760023434181, 0.11242754335398786, 0.09163023511064239, 0.1526618847856298, 1.0592202376574278, 64.69728156924248, 67.41459935903549, 38.913046941161156, 41.33281409740448, 33.41978810727596, 36.574473828077316, 29.21495083719492, 39.96275581419468, 40.70753864943981, 37.77178198099136, 31.580916680395603, 42.11133152246475, 30.881098732352257, 32.33508691191673, 16.777021251618862, 6.249441057443619, 2.2718311194330454, 20.293426662683487, 61.42993189394474, 45.57722434401512, 60.58769568800926, 59.435415118932724, 46.64761170744896, 12.650070302188396, 1.5814876067452133, 0.11948869258048944, 7.442182805389166, 43.86437505483627, 68.27747985720634, 66.23321235179901, 65.16021072864532, 54.580753818154335, 54.029061421751976, 49.401297345757484, 59.15403261780739, 60.57549074292183, 60.99048927426338, 60.46582102775574, 58.99554692208767, 61.42674006521702, 59.43159632384777, 52.389844581484795, 49.394788295030594, 53.03004942834377, 60.47129273414612, 57.9982790350914, 59.35386769473553, 54.65399868786335, 53.162905499339104, 50.55375650525093, 48.59606355428696, 49.35183919966221, 52.06627294421196, 54.59262818098068, 53.81107471883297, 49.71791535615921, 53.58821667730808, 46.1532012373209, 38.6551433801651, 24.587980918586254, 18.55868674814701, 26.553026475012302, 27.711629904806614, 17.914661206305027, 0.28017018805257976, 0.06269645018619485, 0.03816276235738769, 0.03288856001745444, 0.02939861427876167, 0.03182597894920036, 0.017761957642505877, 0.00823850436063367, 0.054317094545695, 0.05464339832542464, 0.05828366236528382, 0.06369846829329617, 0.05807910791190807, 0.12761530611896887, 1.9969975668936968, 0.6893648870754987, 0.09527981310384348, 0.042195885980618186, 0.053200166003080085, 0.1030285918386653, 0.12512991292169318, 0.09453508275328204, 0.03210761286027264, 0.028506068520073313, 0.04493138665566221, 0.052065236668568105, 0.07547205488663167, 0.050034260493703187, 8.574241809546947, 37.602208480238914, 28.939693607389927, 28.57747234404087, 35.880612060427666, 39.482396990060806, 41.232780665159225, 42.372328117489815, 43.05565685033798, 44.81567680835724, 48.08574713766575, 49.12119917571545, 48.28052468597889, 48.46203334629536, 46.395411640405655, 47.14235655963421, 46.37304224073887, 43.51147659122944, 45.99894851446152, 43.415018767118454, 45.221597626805305, 45.02471499145031, 46.321699395775795, 53.2854413241148, 56.268007680773735, 56.4675235748291, 54.69884768128395, 56.176956966519356, 51.437904462218285, 44.48735922574997, 47.94263541698456, 52.36167669296265, 57.40202642977238, 58.832657262682915, 61.36410042643547, 60.00517934560776, 62.02456958591938, 9.213615451008081, 0.32590589951723814, 0.19786106800893322, 0.19542076770449057, 1.2953458609990776, 6.359256589785218, 45.0901360809803, 56.06811560690403, 46.886907666921616, 63.79374325275421, 66.55850529670715, 67.61044085025787, 33.341694697737694, 0.3960051020840183, 15.158995874226093, 41.06394052505493, 27.794400863349438, 34.643485844135284, 26.203572526574135, 32.18423120677471, 28.140250705182552, 31.786369755864143, 33.95899057388306, 27.690229453146458, 31.925100311636925, 36.664494797587395, 26.42552811652422, 34.896480068564415, 66.28074780106544, 62.03327491879463, 1.534777544438839, 0.24473722296534106, 0.0353833228291478, 0.09081000607693568, 0.10846630044397898, 0.016854489149409346, 0.15265798108885065, 0.18408881092909724, 0.2011415982269682, 0.1418553537223488, 0.14703739987453446, 0.2303974307142198, 0.15683643578086048, 0.15331374277593568, 0.17308899492491037, 0.3447333845542744, 1.723479931242764, 76.97240889072418, 78.27531337738037, 44.8435103148222, 47.474394142627716, 40.97966484725475, 50.287595987319946, 32.59818099439144, 56.65799595415592, 48.763630762696266, 51.38050094246864, 37.76593789458275, 59.797528088092804, 44.66213084757328, 35.67921906709671, 21.61969419568777, 6.145097706466913, 5.249088685959578, 27.024828158318996, 68.18169459700584, 52.9344579577446, 67.37527146935463, 63.05986203253269, 51.112235337495804, 12.187944799661636, 2.8832204500213265, 0.6549710326362401, 8.95975487306714, 47.63787657022476, 69.59284767508507, 69.90478053689003, 65.30252069234848, 57.49645136296749, 56.032405123114586, 52.70029932260513, 61.03663019835949, 62.5095147639513, 64.62057888507843, 63.03260609507561, 61.885158866643906, 66.04993298649788, 61.561993807554245, 55.64761497080326, 53.329366967082024, 57.36982695758343, 65.15654012560844, 61.03168286383152, 64.11123901605606, 58.22083689272404, 56.86756990849972, 53.754457756876945, 51.96548715233803, 53.097864389419556, 55.20972266793251, 56.20427370071411, 57.81516306102276, 53.61482284963131, 57.61191576719284, 52.52572149038315, 42.60673373937607, 32.99205645918846, 25.27739692479372, 36.6009546071291, 39.05461594462395, 31.23806107789278, 1.3122015190310776, 0.22484159446321428, 0.13846004294464365, 0.12862118339398876, 0.1185407696175389, 0.19903747597709298, 0.19620444596512243, 0.10834687403985299, 0.23456429305952042, 0.19632802839623764, 0.2798313234234229, 0.20503818523138762, 0.16450736322440207, 0.6737044430337846, 3.2837607571855187, 0.39496282988693565, 0.5882742803078145, 0.17002572101773694, 0.16545167192816734, 0.16061261674622074, 0.23679398669628426, 0.3277556283865124, 0.13684956764336675, 0.1481467770645395, 0.1491903851274401, 0.11255437639192678, 0.1962307922076434, 0.14823638397501782, 12.886624708771706, 43.08453530073166, 35.05390182137489, 34.119748547673225, 40.84343835711479, 43.57092060148716, 45.88649354875088, 44.75276738405228, 43.556363582611084, 47.15095929801464, 50.91249145567417, 52.73896984755993, 50.18004655838013, 52.02627629041672, 49.369595646858215, 51.24989815056324, 48.23087275028229, 45.74411898851395, 50.232438147068024, 46.42514884471893, 49.532549902796745, 49.68001239001751, 47.98427738249302, 56.328986808657646, 60.77440246939659, 60.2219121158123, 57.56478689610958, 59.904606342315674, 51.96644850075245, 46.067968010902405, 49.62652266025543, 54.658900424838066, 61.711416989564896, 61.390953585505486, 65.89403495192528, 62.331942692399025, 64.03605625033379, 9.988546818494797, 0.5544601916335523, 1.4120587357319891, 1.3909141765907407, 7.187315756455064, 7.236504117026925, 46.664414405822754, 59.07468527555466, 52.00546480715275, 69.0858256816864, 74.9836640059948, 67.77601316571236, 42.67816610634327, 2.0304535841569304, 12.798246201127768, 37.14509300887585, 34.28815171122551, 48.125808387994766, 31.766228936612606, 47.14039586484432, 34.73899371922016, 35.84988310933113, 49.32886943221092, 38.957242369651794, 42.94044703245163, 49.939990639686584, 32.431020364165306, 41.97853244841099, 76.74645021557808, 74.58572655916214, 3.0854888213798404, 0.29923376510851085, 0.20485708635533229, 0.1746617691242136, 0.20406658033607528, 0.15010151983005926], [0.11514896919834428, 0.06213362023117952, 0.05245693108008709, 0.08946650355937891, 0.07337200702750124, 0.07902049299445935, 0.10395317425718531, 0.03171237840433605, 0.04999618460715283, 0.20458320417674258, 0.23613038792973384, 35.669009014964104, 60.7433657348156, 27.106936052441597, 28.418416678905487, 30.335381515324116, 35.065419003367424, 28.447534516453743, 40.38522854447365, 39.21704962849617, 38.270011246204376, 27.488674968481064, 31.688606701791286, 48.10839392244816, 25.278601460158825, 29.377937391400337, 4.297123868018389, 3.4609352750703692, 14.985125754028559, 50.544568598270416, 45.84213472902775, 52.554960921406746, 57.42998532950878, 58.10036435723305, 16.369496919214725, 2.6677758106961846, 0.06018763851898257, 4.980874378234148, 38.594399839639664, 67.9733669757843, 62.911058217287064, 60.71989059448242, 56.920151486992836, 52.96544149518013, 52.84942992031574, 60.64375787973404, 58.95771995186806, 61.21452145278454, 55.30469857156277, 58.45101714134216, 55.9440902620554, 55.42367398738861, 48.55512075126171, 44.946066811680794, 50.81110529601574, 58.043944984674454, 56.079799979925156, 55.48389695584774, 54.162103682756424, 48.85021671652794, 44.54165071249008, 45.02526976168156, 46.12486615777016, 48.89036916196346, 51.12636677920818, 49.02066417038441, 49.7922507673502, 47.190081998705864, 35.331465527415276, 31.99970930814743, 13.382002227008343, 16.22134856879711, 18.218770287930965, 20.908421762287617, 1.4385845186188817, 0.02706862309423741, 0.03761549152841326, 0.04929828006424941, 0.041780520768952556, 0.039394126361003146, 0.08536768131307326, 0.052815440358244814, 0.020870116641162895, 0.007592450429001474, 0.025944610752048902, 0.03419062100874726, 0.0734415759507101, 0.029061829518468585, 0.1302891454542987, 1.724668436218053, 0.5061637738253921, 0.027756981762649957, 0.02961632144433679, 0.02380572259426117, 0.04965046995494049, 0.07719903995166533, 0.004506817931542173, 0.08639152598334476, 0.021061828228994273, 0.07255015269038267, 0.041729579752427526, 0.040104532381519675, 0.15040566679090261, 2.6053838711231947, 27.41043146699667, 22.75677938014269, 20.975737050175667, 26.517258994281292, 34.776968881487846, 34.377028942108154, 39.31702606379986, 39.89582620561123, 40.638819336891174, 44.10551771521568, 45.751904770731926, 44.61205333471298, 45.25022529065609, 44.75568562746048, 43.965236842632294, 40.2069079130888, 43.654421120882034, 42.82378949224949, 46.21523290872574, 41.62863962352276, 41.26137413084507, 42.320818081498146, 52.61616803705692, 56.37745700776577, 52.798546850681305, 52.56604492664337, 52.68812857568264, 52.39699959754944, 46.621351316571236, 45.45293681323528, 48.17729562520981, 53.180194571614265, 57.04731546342373, 59.2903883010149, 57.3259849101305, 59.818092584609985, 16.619455106556416, 0.15370029781479388, 0.11699284252244979, 0.5655613553244621, 3.2790072122588754, 14.060950744897127, 49.65400278568268, 53.66428479552269, 52.074252516031265, 47.14794985949993, 48.848841190338135, 55.899659246206284, 12.104621920734644, 0.18046310782665387, 21.67543340474367, 39.508053213357925, 29.4383180513978, 30.184869691729546, 28.426859825849533, 36.20574161410332, 23.549021668732166, 34.81983818113804, 41.31690055131912, 33.3254923671484, 34.857478961348534, 36.35957255959511, 45.12936517596245, 41.335192769765854, 59.160359278321266, 38.50998356938362, 1.1595451855100691, 0.23664959444431588, 0.06568858923856169, 0.07775020334520377, 0.03534601506544277, 0.0402876016596565, 0.11416713008657098, 0.04162520410318393, 0.09959623304894194, 0.042973664167220704, 0.030297047123895027, 0.02988260217534844, 0.05572642927290872, 0.036068792687729, 0.01577551960508572, 0.21269349788781255, 0.2962059807032347, 47.514679580926895, 69.1606056690216, 32.97465339303017, 35.746213272213936, 30.586428344249725, 36.8769907951355, 30.82272056490183, 35.252007991075516, 38.967110440135, 36.822406724095345, 29.752114713191986, 34.12165604531765, 34.856194630265236, 32.52600386738777, 34.812417179346085, 5.802925592288375, 4.790230533108115, 19.86890584230423, 57.273851707577705, 51.99932813644409, 56.839037239551544, 60.92251472175121, 61.735462099313736, 18.56627494096756, 2.791108167730272, 0.4597536876099184, 6.100454377010465, 39.01570603251457, 68.54774415493011, 65.07381856441498, 63.08175265789032, 60.146299973130226, 55.40800362825394, 55.58619126677513, 63.08634661138058, 61.7763365060091, 62.37089820206165, 58.50967459380627, 60.72013758122921, 58.68908956646919, 58.56879182159901, 51.96912355720997, 48.39402459561825, 52.53479540348053, 58.11612211167812, 58.13486270606518, 57.182405814528465, 56.62248685956001, 52.16319054365158, 48.95717337727547, 48.97429145872593, 49.38200578093529, 51.37057967483997, 54.9432847648859, 52.80226305127144, 55.06240837275982, 50.279380828142166, 40.596200823783875, 35.77431656420231, 21.868738532066345, 23.631737530231476, 22.24170371890068, 26.258884258568287, 1.7062820540741086, 0.024873470865713898, 0.06931542782695033, 0.03965971503930632, 0.016880892908375245, 0.03784892294788733, 0.039012395282043144, 0.07841187994927168, 0.04915336088743061, 0.013395325840974692, 0.05292416870361194, 0.050251746870344505, 0.034932983908220194, 0.036338351856102236, 0.04744860314531252, 1.4121481496840715, 1.1737132002599537, 0.1962344881030731, 0.07120177426259033, 0.043159549895790406, 0.03006017956067808, 0.014660268316220026, 0.08849650170304812, 0.07213841658085585, 0.052885261611663736, 0.07032933513983153, 0.02542877173254965, 0.02407256921287626, 0.15282306441804394, 1.9246715353801847, 32.42162726819515, 27.890311516821384, 24.30328119546175, 31.37782897800207, 41.13253064453602, 39.34319145977497, 43.31895612180233, 42.995692268013954, 44.02400828897953, 46.17570362985134, 47.69598305225372, 46.143207773566246, 47.8352265805006, 46.73727549612522, 43.72094415128231, 42.911861166357994, 46.0316913574934, 46.57750926911831, 49.81304705142975, 43.77856805920601, 43.32715228199959, 45.93123234808445, 55.10610222816467, 57.1860346198082, 56.1867718398571, 55.052783489227295, 55.405146181583405, 55.309592708945274, 50.71806348860264, 49.55450512468815, 49.40391160547733, 56.79042644798756, 59.51802268624306, 63.63455839455128, 60.47022879123688, 62.36461713910103, 19.69445150345564, 0.4408941714791581, 0.16930423473240808, 0.12318746012169868, 2.740366403013468, 19.888830073177814, 54.3570826202631, 58.820471316576004, 54.48366902768612, 52.25875921547413, 55.60300536453724, 61.44391894340515, 11.540716029703617, 1.111886955332011, 27.468026876449585, 45.27932412922382, 25.985661819577217, 30.686763860285282, 24.619545824825764, 34.3151530623436, 27.020635083317757, 33.421308025717735, 29.53801330178976, 36.86822086572647, 32.04227842390537, 37.36471362411976, 40.38379602134228, 45.40531016886234, 68.32555487751961, 47.058487460017204, 1.2437487859278917, 0.14532636356307194, 0.13221283676102757, 0.05115994637890253, 0.06560112713486888, 0.02064238491584547, 0.20834912866121158, 0.1749326233402826, 0.18658345128642395, 0.1404946408001706, 0.17795987339923158, 0.15264373185345903, 0.19508071563905105, 0.18796862539602444, 0.17496339278295636, 0.20872008375590667, 0.7014221150893718, 61.18666894733906, 81.00043594837189, 38.64534370601177, 37.56007634103298, 38.9633334428072, 47.05247238278389, 36.823744252324104, 52.444090470671654, 50.695576295256615, 50.90370252728462, 34.06045652925968, 45.706747993826866, 63.44405181705952, 31.8531758710742, 37.67432101070881, 8.767238203436136, 8.354833982884884, 21.754647754132748, 62.166955545544624, 57.745144218206406, 63.69004301726818, 65.85669055581093, 67.43234440684319, 21.42792798578739, 4.877389306202531, 1.641679226886481, 8.408479504287243, 43.180092573165894, 72.1840350329876, 69.09762024879456, 64.32572990655899, 62.48792052268982, 58.07111732661724, 57.90324993431568, 67.36875101923943, 65.18652811646461, 65.87661668658257, 60.04000827670097, 64.01082560420036, 61.64545252919197, 62.49412178993225, 55.17546370625496, 52.436004504561424, 55.73677338659763, 61.439017206430435, 60.94263844192028, 59.53936234116554, 58.14246989786625, 54.298622757196426, 51.868679746985435, 53.10470402240753, 52.121320590376854, 54.654260873794556, 58.889965787529945, 55.283499509096146, 55.97722448408604, 56.046741753816605, 41.24273993074894, 40.67093901336193, 27.68188700079918, 29.323653504252434, 31.143170669674873, 38.95079791545868, 9.321920089423656, 0.1915658448706381, 0.1339773225481622, 0.18391130404779688, 0.1311095303390175, 0.1320089094224386, 0.15434848959557712, 0.11816550264484249, 0.0817230534448754, 0.07276936084963381, 0.10439798788866028, 0.10605524075799622, 0.17699641728540882, 0.13683871744433418, 0.24799324746709317, 4.579857671633363, 0.8083575207274407, 0.32221911766100675, 0.14836385525995865, 0.1209121392457746, 0.24112588784191757, 0.2417003398295492, 0.1188714632007759, 0.17309908813331276, 0.11989957522018813, 0.1513531370437704, 0.0874636325170286, 0.16575273155467585, 0.3549995430512354, 4.70407348126173, 36.50929592549801, 30.40981762111187, 32.65314504504204, 36.991535648703575, 46.421736627817154, 42.79958859086037, 47.678910568356514, 46.340231001377106, 47.56066091358662, 49.94714945554733, 52.39646002650261, 49.45564202964306, 52.79020629823208, 49.8978129029274, 46.250130236148834, 46.05532228946686, 51.420634388923645, 48.624273240566254, 54.20793302357197, 46.41432702541351, 47.6952800899744, 47.588528618216515, 58.79966363310814, 61.42688065767288, 58.28952960669994, 59.28182736039162, 58.989839628338814, 57.31755696237087, 52.50447303056717, 52.71035358309746, 55.20836994051933, 58.910579681396484, 62.07438871264458, 65.85239678621292, 62.62363784015179, 65.04091992974281, 20.27650997042656, 0.6448294362053275, 0.9030889312271029, 1.653371318243444, 5.371935619041324, 17.860985286533833, 59.82442304491997, 62.91941776871681, 60.65853528678417, 57.151920050382614, 56.76827743649483, 63.33974741399288, 17.41373598575592, 1.686662994325161, 28.08782111853361, 47.14335210621357, 37.734798565506935, 40.67820802330971, 37.17460982501507, 49.383787885308266, 31.327846460044384, 44.504359513521194, 53.74137505888939, 45.91751128435135, 45.561379194259644, 53.229664117097855, 57.39230275154114, 56.96858748793602, 79.27006959915161, 61.82374656200409, 1.6977702733129263, 0.3682431683409959, 0.20720559783512726, 0.16689373907865956, 0.09907544575980864, 0.09535880730254576], [0.018390851728327107, 0.017867494752863422, 0.08331844088388607, 0.07716828535194509, 0.04491408348258119, 0.007799392278684536, 0.025713897448440548, 0.025407768953300547, 0.03180606341629755, 0.2362932448158972, 0.03418855783820618, 29.565121047198772, 60.14577940106392, 32.57763549685478, 34.19837772846222, 59.99170906841755, 45.40070861577988, 30.783518068492413, 41.24875120818615, 48.08138497173786, 41.04705423116684, 34.046944454312325, 27.050841562449932, 57.914185747504234, 26.763996854424477, 24.99184414744377, 7.089534653350711, 2.694268226623535, 28.79248570650816, 53.19811820983887, 51.94341033697128, 55.115100145339966, 55.64800634980202, 51.81086964905262, 19.41652111709118, 1.027648919261992, 0.26885252504143864, 3.689727885648608, 33.29319790005684, 64.14669871330261, 65.17628386616707, 62.572074607014656, 57.37260080873966, 56.296924129128456, 55.343893468379974, 61.30346328020096, 60.92545576393604, 62.5252915173769, 55.635303631424904, 55.57383053004742, 57.65706114470959, 56.36114068329334, 47.504689916968346, 45.27091138064861, 52.5464341789484, 57.70977571606636, 57.97372855246067, 57.66577787697315, 55.20658403635025, 50.08054509758949, 48.44856686890125, 44.79261204600334, 45.85965558886528, 48.43039244413376, 50.929799526929855, 50.737347453832626, 50.81749655306339, 46.20793730020523, 40.76666347682476, 23.25722962617874, 17.189810201525688, 17.86519356071949, 19.33905277401209, 9.215008076280355, 0.5060985242016613, 0.041751751414267346, 0.07243221058160998, 0.12648771662497893, 0.043261131359031424, 0.008594257487857249, 0.02695578139537247, 0.015400626489281422, 0.06667548237601295, 0.02418958734779153, 0.04044054716359824, 0.09595593190169893, 0.04328751099819783, 0.029241824449854903, 0.07935056317364797, 0.416905939928256, 2.197926272638142, 0.09148276294581592, 0.093048932030797, 0.02973972019390203, 0.13850023766281083, 0.08555556341889314, 0.04737723822472617, 0.02170440937334206, 0.03593254179577343, 0.0755962978291791, 0.012977739752386697, 0.09025439721881412, 0.026071651591337286, 0.3981263976311311, 17.169561088085175, 30.25721400976181, 17.110641449689865, 19.423180259764194, 32.35475845634937, 33.632059916853905, 38.81831802427769, 38.525980710983276, 40.53340919315815, 41.524517610669136, 43.24858009815216, 43.95238593220711, 41.652878522872925, 42.53967493772507, 41.69088788330555, 42.02654667198658, 44.8064699023962, 45.434048026800156, 44.40747991204262, 44.95970048010349, 40.66331282258034, 44.4095204025507, 52.64159247279167, 54.516936242580414, 51.54820494353771, 55.0909486413002, 53.85931693017483, 54.00883510708809, 49.969112277030945, 47.217353135347366, 47.53691978752613, 51.88790671527386, 55.57104527950287, 59.562225714325905, 58.622710928320885, 59.51364532113075, 22.638565823435783, 0.9053467225749046, 0.08795838526566513, 0.3701524471398443, 3.114893543533981, 31.985471472144127, 59.755646735429764, 56.93369396030903, 59.38357450067997, 56.421135663986206, 53.99542562663555, 38.70761476457119, 7.1780238300561905, 0.7891899242531508, 33.39296534657478, 38.580397590994835, 26.22529026120901, 25.769447721540928, 34.46146801114082, 25.960018895566463, 30.12319330126047, 36.97499893605709, 39.01267759501934, 30.42271412909031, 35.868787094950676, 36.3192605227232, 31.90472960472107, 43.665938302874565, 65.25659635663033, 37.321243956685066, 0.879156687296927, 0.06453750334912911, 0.025201464886777103, 0.028328342705208343, 0.05151291181391571, 0.05030835047364235, 0.0715488989953883, 0.027907992116524838, 0.02827258886100026, 0.06428929948015139, 0.11793039768235758, 0.013675588634214364, 0.07202132052043453, 0.05534270552743692, 0.008561665144952713, 0.19662793027237058, 0.03596693662984762, 38.521219566464424, 70.76308608055115, 37.10902154445648, 33.39660555124283, 54.964715614914894, 40.51393523812294, 27.700646594166756, 39.15435679256916, 44.515447318553925, 42.16743551194668, 33.207930475473404, 28.999701887369156, 50.19350543618202, 27.265045568346977, 28.833084627985954, 11.072031129151583, 3.17150195594877, 29.561022967100143, 59.09474819898605, 53.405712470412254, 63.65306720137596, 60.44365681707859, 59.065105989575386, 24.728202894330025, 2.747048819437623, 0.40492117521353066, 3.961678105406463, 34.0968319773674, 65.987099558115, 67.45214134454727, 64.35295924544334, 60.47962948679924, 58.5025841742754, 57.94933766126633, 62.69764266908169, 63.773421943187714, 62.84442879259586, 56.26184821128845, 57.81539864838123, 61.023102924227715, 58.68653230369091, 50.98067119717598, 48.60223442316055, 56.757128834724426, 60.40279000997543, 59.467633590102196, 61.757808700203896, 56.371202543377876, 51.86892293393612, 51.0558045655489, 48.005780428647995, 51.207275837659836, 52.23581984639168, 53.76366466283798, 54.07567352056503, 53.6553742736578, 49.290282502770424, 44.20487858355045, 28.206091672182083, 28.226038701832294, 21.766360625624657, 26.359546557068825, 13.897235579788685, 0.7840221421793103, 0.05847162981808651, 0.09025295745232143, 0.06239797323360108, 0.06528232275741175, 0.03072487670578994, 0.05502870655618608, 0.0592189836606849, 0.1211362901085522, 0.005702552352886414, 0.05611370419501327, 0.04140888660913333, 0.016037301065807696, 0.0144999727672257, 0.09825776229263283, 0.2071736112702638, 1.150197449605912, 0.21854441205505282, 0.07205304733361118, 0.08103068161290139, 0.06661458173766732, 0.032526180439163, 0.012024295210721903, 0.0023265543450179393, 0.04223987307341304, 0.02111294921633089, 0.022622455326199997, 0.1935339462943375, 0.05792026604467537, 0.2530464419396594, 17.11409166455269, 37.04933814704418, 22.150823995471, 24.424633383750916, 38.66602219641209, 38.8828157633543, 42.688984125852585, 44.33540157973766, 44.409132823348045, 44.795119911432266, 45.391908288002014, 47.98343762755394, 45.19205041229725, 44.6053770929575, 44.10543791949749, 44.20658469200134, 46.75613008439541, 49.01564463973045, 48.988008722662926, 46.671584621071815, 44.48862835764885, 47.970313131809235, 54.2459499835968, 56.48762829601765, 52.55905330181122, 57.008827328681946, 54.53007213771343, 57.00756199657917, 53.10200996696949, 48.93468618392944, 50.97578465938568, 55.866954401135445, 57.670265436172485, 62.38497644662857, 63.10744687914848, 61.10060356557369, 25.127669759094715, 1.386367364320904, 0.25012196449097246, 0.6673867476638407, 6.325704865157604, 40.21890766918659, 66.53708204627037, 61.486678048968315, 63.64359810948372, 62.0578557997942, 59.19964537024498, 41.175464540719986, 5.533714788034558, 1.2608994031324983, 35.12338109314442, 39.66486319899559, 28.245470859110355, 28.88980608433485, 29.74005986005068, 27.901213131844997, 28.2716628536582, 31.83402869850397, 30.15873659402132, 34.45783160626888, 33.7592276930809, 42.09566496312618, 31.464859507977962, 47.1655011177063, 74.21166703104973, 45.062055587768555, 1.031899822410196, 0.08779679003055207, 0.05920222225540783, 0.07261798498802818, 0.0544522099517053, 0.0350598874501884, 0.25907559029292315, 0.15691957116359845, 0.16605490440269932, 0.1759754298836924, 0.24669083766639233, 0.15158872440224513, 0.17247599578695372, 0.13292246352648363, 0.08802693002508022, 0.29277562571223825, 0.08845928299706429, 48.647402599453926, 79.60227817296982, 44.504161924123764, 45.02425901591778, 75.77390760183334, 56.746956780552864, 38.15139681100845, 55.44677294790745, 61.35970026254654, 55.57783171534538, 43.72056417167187, 36.84753477573395, 74.84790489077568, 34.09713976085186, 30.00566180795431, 12.558461967855692, 7.400302877649665, 36.08734756708145, 64.88130569458008, 63.44905614852905, 66.03591173887253, 66.37702703475952, 61.874105259776115, 25.66553469747305, 3.44258819706738, 0.8293351263273507, 6.427722740918398, 37.65050768852234, 68.38043913245201, 69.78844597935677, 67.05494865775108, 64.30948197841644, 60.75499691069126, 59.161928594112396, 66.72919973731041, 66.64461627602577, 66.94349303841591, 60.48279471695423, 58.75108703970909, 64.41998764872551, 62.087919786572456, 53.64564299583435, 51.57299101352692, 59.20089930295944, 63.628186136484146, 65.61439275741577, 64.04930233955383, 61.32040277123451, 52.783051282167435, 54.95505653321743, 53.07589776813984, 53.216528221964836, 56.61119386553764, 55.602838173508644, 57.415470108389854, 56.59082695841789, 53.01178380846977, 49.93895709514618, 35.30260227620602, 33.2442831248045, 31.44219182431698, 34.73637565970421, 30.46894434839487, 1.824014342855662, 0.222741954785306, 0.11643007936072536, 0.21133976115379483, 0.130523634434212, 0.10774308495456353, 0.21187535428907722, 0.09651352229411714, 0.14852200692985207, 0.12012408231385052, 0.18888326303567737, 0.2245660944026895, 0.16456367739010602, 0.10589993893518113, 0.25491419015452266, 1.6707454109564424, 3.9242890616878867, 0.19331673451233655, 0.14279437833465636, 0.22396246116841212, 0.2531916357111186, 0.11094448738731444, 0.13828568276949227, 0.11702600168064237, 0.2283236919902265, 0.15456688881386071, 0.1516499070567079, 0.24083790485747159, 0.23236096050823107, 0.7447896630037576, 26.877464465796947, 41.667568534612656, 25.999612770974636, 31.48639675229788, 42.21136875450611, 44.07101556658745, 48.13855290412903, 46.58659838140011, 46.855084374547005, 48.35837110877037, 46.092708483338356, 52.6674272865057, 47.42612913250923, 46.46249704062939, 48.35672199726105, 45.90089097619057, 50.33610038459301, 52.08890073001385, 51.50966741144657, 50.62050372362137, 47.100361213088036, 50.523377135396004, 56.785889491438866, 58.5245393961668, 55.104415118694305, 61.03514447808266, 58.30200053751469, 60.167753621935844, 56.40085995197296, 52.99727998673916, 52.386774346232414, 58.07045616209507, 60.3734327852726, 65.25827586650848, 64.4598551094532, 62.56114639341831, 26.80735442787409, 2.7194698993116617, 0.8736530388705432, 0.5879930360242724, 4.715731730684638, 37.33886741101742, 69.41177979111671, 66.4366914331913, 70.00392481684685, 65.36708682775497, 66.27029836177826, 46.096352487802505, 11.152999084442854, 2.2693888004869223, 39.80356715619564, 47.196781039237976, 34.618942961096764, 33.854404985904694, 45.90499095618725, 34.468072056770325, 39.720598608255386, 48.139803037047386, 49.81924831867218, 40.33676594495773, 46.016104593873024, 48.50862644612789, 39.64227341115475, 59.78357903659344, 84.43557322025299, 55.72326511144638, 1.3272488303482533, 0.18549288011854514, 0.25274165673181415, 0.15343414881499484, 0.3133976535173133, 0.18670274410396814], [0.12437616547686048, 0.04127065418288112, 0.05324836849467829, 0.054642715549562126, 0.04673513576562982, 0.10275755208567716, 0.010205041708104545, 0.11536083751707338, 0.03156949271215126, 0.2550484298262745, 0.09958317867130972, 27.46307574212551, 67.25971966981888, 35.00029429793358, 53.59709680080414, 87.02505826950073, 72.82279595732689, 39.182410687208176, 34.49784345924854, 43.43727797269821, 38.497664630413055, 36.37982927262783, 25.19821297377348, 28.70547417551279, 39.4473172724247, 27.797613590955734, 14.238323327153921, 0.5676447716541588, 18.782363645732403, 58.116904869675636, 47.439295426011086, 57.39015966653824, 56.96294479072094, 59.83166545629501, 34.86115716397762, 5.526917902752757, 0.4965661419555545, 1.3060928718186915, 19.573067016899586, 58.747256845235825, 62.97744445502758, 63.46990562975407, 60.8985798060894, 59.94282849133015, 59.41595256328583, 59.642857387661934, 60.01093603670597, 58.60495448112488, 54.22273322939873, 57.91108511388302, 57.55608916282654, 54.56447549164295, 48.043117225170135, 47.03598886728287, 52.14471973478794, 56.8305940926075, 54.05923180282116, 53.939758613705635, 54.39708687365055, 53.45081605017185, 48.798847272992134, 46.17462448775768, 47.37318277359009, 51.13141670823097, 50.69492653012276, 50.586465150117874, 53.098506554961205, 40.98978370428085, 28.3607604727149, 20.3895216062665, 22.506640702486038, 14.521296042948961, 19.892039000988007, 7.165575698018074, 0.5398859549313784, 0.06826665441622026, 0.04489093589654658, 0.035822436766466126, 0.09429433004697785, 0.07493747107218951, 0.028333762238617055, 0.0970417310600169, 0.15807996358489618, 0.08367786300368607, 0.03999132888566237, 0.046116585363051854, 0.060866083949804306, 0.0507577283133287, 0.0973071379121393, 0.049717597212293185, 1.8422576389275491, 0.2188474457943812, 0.0298586642020382, 0.05544876214116812, 0.08837893808959052, 0.07172118115704507, 0.03495121476589702, 0.019995087423012592, 0.011993365278613055, 0.03927907491743099, 0.025095636483456474, 0.0399492268479662, 0.11523773006047122, 0.5289788777008653, 5.478915078565478, 25.433604642748833, 25.986326783895493, 18.879845514893532, 24.050744846463203, 35.69360509514809, 35.459294468164444, 40.171961188316345, 39.54849824309349, 42.80729457736015, 42.536414712667465, 43.93344774842262, 42.610487937927246, 41.602139845490456, 41.00602403283119, 44.14050243794918, 45.11229649186134, 46.76138900220394, 46.63644030690193, 45.321456268429756, 42.287357077002525, 42.88769066333771, 51.67516753077507, 57.8017345815897, 51.500289514660835, 51.297350004315376, 53.33398371934891, 54.31939244270325, 50.528446063399315, 49.890657886862755, 51.501995623111725, 52.86681018769741, 54.868185594677925, 59.66125600039959, 57.372380420565605, 52.356505170464516, 20.58999314904213, 1.147100378293544, 0.4058441100642085, 4.133490398526192, 23.292049057781696, 41.30906157195568, 54.54692043364048, 48.50891903042793, 52.46835216879845, 47.01428063213825, 53.8066441565752, 46.49311199784279, 1.4240733347833157, 1.8250567931681871, 42.19613157212734, 33.41240130364895, 18.068241365253925, 31.44486878067255, 26.06156464666128, 28.19352574646473, 35.0133465975523, 31.768738701939583, 28.215070590376854, 31.97592258453369, 36.81426376104355, 27.266457192599773, 20.838558711111546, 37.42677569389343, 60.37058673799038, 23.11764221638441, 0.4215364367701113, 0.11033559232600965, 0.11683414166327566, 0.09919808566337451, 0.05057842543465085, 0.04723343226942234, 0.10155294992728159, 0.01590031730302144, 0.07434350060066208, 0.012290888571442338, 0.028357549927022774, 0.056879967960412614, 0.028898968921566848, 0.03886369115207344, 0.05166492592252325, 0.19890215276973322, 0.08083370077656582, 34.22791734337807, 77.27149844169617, 36.506248489022255, 52.18372084200382, 83.16485300660133, 56.632582917809486, 31.841434501111507, 25.783746354281902, 36.908304914832115, 37.8505327552557, 37.169126719236374, 28.319048210978508, 25.817765928804874, 16.202442683279514, 27.12699707597494, 17.793031632900238, 1.775216767564416, 17.05461535602808, 62.37915515899658, 54.25279721617699, 63.8065105676651, 58.14434699714184, 62.86835990846157, 39.02229107916355, 7.2720265109092, 0.4935728228883818, 1.0496191028505564, 18.22929572314024, 59.091294184327126, 65.98077669739723, 65.3769662976265, 64.43419128656387, 63.88539433479309, 62.7583672106266, 62.97887697815895, 61.9163703918457, 60.251789912581444, 55.478611439466476, 59.68328721821308, 58.63287918269634, 59.241754710674286, 50.20809285342693, 51.67752340435982, 54.84572499990463, 59.40646827220917, 55.56032985448837, 57.129197269678116, 57.91606664657593, 56.557745933532715, 49.59909573197365, 49.88214634358883, 49.11761596798897, 53.907285556197166, 54.30339530110359, 53.935882821679115, 56.2793804705143, 45.693961679935455, 34.352383464574814, 28.40313009917736, 28.681989535689354, 21.366061605513096, 26.700468063354492, 9.266080185770988, 0.555961289210245, 0.0414113728038501, 0.05034019974118564, 0.04962839848303702, 0.03155473510560114, 0.06404667656170204, 0.037674885606975295, 0.08394591190153733, 0.018121838038496207, 0.03052946922252886, 0.07131559745175764, 0.0399040337651968, 0.04608611277944874, 0.03284700716903899, 0.060396152330213226, 0.14033101208042353, 0.2388995635556057, 0.8483464561868459, 0.13846397632732987, 0.08339230684214272, 0.019696385970746633, 0.004610655523720197, 0.03291929606348276, 0.020736515216412954, 0.06200579271535389, 0.029241015508887358, 0.04165353188000154, 0.04861563036683947, 0.03612143322243355, 0.5184193036984652, 6.576869962736964, 28.8302081823349, 28.137233667075634, 26.1659412458539, 29.818749837577343, 43.036304488778114, 39.97145734727383, 43.62277641892433, 43.34365099668503, 46.730333268642426, 45.37719547748566, 46.517658680677414, 44.12589982151985, 43.83472144603729, 44.80873458087444, 47.124087139964104, 49.83673498034477, 49.84705522656441, 50.396893322467804, 46.83226279914379, 44.37816068530083, 45.88989816606045, 53.547794446349144, 59.139889776706696, 54.30413246154785, 55.14582149684429, 55.3595220297575, 58.79188545048237, 53.78981105983257, 52.723641470074654, 54.30613115429878, 57.437706515192986, 59.95003670454025, 62.778084352612495, 60.8108539134264, 55.894609317183495, 20.540451407432556, 1.7618537158705294, 0.5196554842405021, 6.648517018184066, 31.6910195723176, 48.57100009918213, 57.860540226101875, 53.69963049888611, 58.5711894929409, 51.08098201453686, 58.49687688052654, 44.33085322380066, 0.6529579719062895, 2.9622801952064037, 46.01288616657257, 45.29359236359596, 23.149682097136974, 29.84407927840948, 25.805418491363525, 32.79772348701954, 33.53929929435253, 31.98529288172722, 29.172585010528564, 33.92890378832817, 30.679282061755657, 30.80247525125742, 19.700869359076023, 44.174480214715004, 71.0574258863926, 29.27940107882023, 0.4823771392693743, 0.09303552142228, 0.09844670566963032, 0.1379425433697179, 0.07690681188250892, 0.04819296613277402, 0.2692164445761591, 0.133681591541972, 0.14325921511044726, 0.1035719775245525, 0.18515278352424502, 0.3191264992346987, 0.12503628357080743, 0.18021252908511087, 0.15305927518056706, 0.3551175445318222, 0.1488790541770868, 44.36426863074303, 90.29016986489296, 46.92587837576866, 66.60385966300964, 106.21717482805252, 84.83136758208275, 49.23441790044308, 47.83921256661415, 54.780288711190224, 51.98879890143871, 46.683417186141014, 34.91133727133274, 41.69746533036232, 50.24801731109619, 36.857710629701614, 20.21783921867609, 3.52592081297189, 23.12071055173874, 69.94843259453773, 59.14987564086914, 68.40223476290703, 64.61579874157906, 70.10357826948166, 42.2333125770092, 7.542981896549463, 1.1898141237907112, 2.4396771378815174, 23.634963557124138, 63.82937774062157, 68.47513765096664, 67.47538089752197, 66.35504901409149, 67.01530158519745, 64.09370675683022, 65.71094557642937, 64.98725160956383, 63.04240956902504, 56.831441447138786, 62.17618525028229, 63.019234612584114, 61.042930260300636, 54.21777069568634, 52.85514861345291, 59.17275421321392, 62.48115688562393, 57.608207166194916, 59.37557972967625, 60.07565416395664, 58.87442082166672, 54.23153355717659, 52.036292552948, 53.41231271624565, 55.395449101924896, 58.83662424981594, 56.9612804800272, 58.965015560388565, 52.957986295223236, 41.007783338427544, 33.35146017372608, 35.96917770802975, 26.969125047326088, 32.47644692659378, 17.22561188042164, 1.1453933198936284, 0.14996892772614956, 0.15070567256771028, 0.18697987688938156, 0.17917662451509386, 0.11130492624943145, 0.13052468828391284, 0.15666779014281929, 0.22959717287449166, 0.1845676446100697, 0.13793191581498832, 0.15450922393938527, 0.1456883386708796, 0.11929491782211699, 0.22533869981998578, 0.34224591334350407, 4.4026503805071115, 1.0044014104641974, 0.24893927795346826, 0.11969719897024333, 0.13061177189229056, 0.09827900998061523, 0.13460298272548243, 0.12602958886418492, 0.11863074760185555, 0.26069783605635166, 0.17179295275127515, 0.11377425194950774, 0.24348706036107615, 0.7342754490673542, 10.256509389728308, 37.79122933745384, 30.752536430954933, 30.42273122817278, 35.32537825405598, 46.29885882139206, 44.409569799900055, 47.86302208900452, 46.50862656533718, 49.71228025853634, 48.674962520599365, 50.85742861032486, 48.177550211548805, 46.85466259717941, 46.37990467250347, 50.86529418826103, 54.69831570982933, 50.98115757107735, 51.59352891147137, 50.341705083847046, 46.94104716181755, 48.193524554371834, 55.94078443944454, 62.873200848698616, 56.75533153116703, 57.91900008916855, 57.61655531823635, 60.78199066221714, 56.527491956949234, 55.33372521400452, 56.247530579566956, 59.104749262332916, 61.31588861346245, 66.32039487361908, 62.4325954914093, 58.7924250215292, 25.873343646526337, 2.2317088348791003, 1.4991079084575176, 7.108838092535734, 29.32874333113432, 54.5163244754076, 64.32961329817772, 57.366627529263496, 62.388487458229065, 58.050283044576645, 62.89232522249222, 55.216398909687996, 3.0780445458367467, 3.012874242849648, 50.869584158062935, 43.94022658467293, 25.129871740937233, 42.43194691836834, 36.2630957365036, 37.28035435080528, 47.17426724731922, 42.98675894737244, 39.33596424758434, 41.52282290160656, 45.381645038723946, 39.57819364964962, 29.529184475541115, 55.61619445681572, 81.26363262534142, 39.689546674489975, 0.6609451433178037, 0.28700355731416494, 0.353841109899804, 0.1816057480755262, 0.16890436556423083, 0.199411325447727], [0.04881097105680965, 0.028876370524812955, 0.08140836798702367, 0.06323392095509917, 0.05220449325861409, 0.05412107479060069, 0.039297777038882487, 0.07643495438969694, 0.014891667178744683, 0.3202206327114254, 0.10616170926368795, 13.991442024707794, 73.36222261190414, 35.04803113639355, 27.156878672540188, 74.6655298769474, 86.02949649095535, 45.535627976059914, 47.486766278743744, 38.72938759624958, 44.557286873459816, 35.154189839959145, 31.707497388124466, 27.40725863724947, 97.5066514313221, 82.16866806149483, 13.406444415450096, 1.2700073956511915, 6.981386281549931, 55.473542511463165, 48.005480244755745, 60.33483445644379, 52.87154473364353, 57.53284960985184, 46.083668768405914, 7.780486727133393, 0.8164433680940419, 0.3551918483572081, 5.542136561125517, 41.77957892417908, 62.499038726091385, 64.74730208516121, 63.44816319644451, 59.905875474214554, 61.53802089393139, 58.15767668187618, 63.38570974767208, 60.12568987905979, 54.78958301246166, 59.01741474866867, 57.64030784368515, 53.72016079723835, 46.97133533656597, 47.55510941147804, 55.244859382510185, 58.23014259338379, 56.31914533674717, 56.52597963809967, 54.74492400884628, 54.2289724946022, 49.85238254070282, 47.30503723025322, 49.620427787303925, 53.16682688891888, 53.21371637284756, 55.47388829290867, 40.929313749074936, 31.895815283060074, 25.905252434313297, 18.38197723031044, 19.507070258259773, 18.733171485364437, 23.57685897499323, 6.440239744260907, 0.11107888291007839, 0.05070188170066103, 0.033606617580517195, 0.036293826706241816, 0.05375072083552368, 0.06423101862310432, 0.03095889071119018, 0.032713780528865755, 0.030106569356576074, 0.03591432578105014, 0.03878490475472063, 0.10207895451458171, 0.03375067586603109, 0.02904537981521571, 0.03299834963399917, 0.10070545438793488, 0.15385338803753257, 0.6117875373456627, 0.04569944641843904, 0.06433945382013917, 0.018089139011863153, 0.04648894682759419, 0.008940788502513897, 0.035975671708001755, 0.05104532167024445, 0.024431165693385992, 0.00701791541359853, 0.07885612212703563, 0.02534418730647303, 0.24459965847199783, 2.543399934656918, 19.184720255434513, 26.722060404717922, 23.870683908462524, 22.006522938609123, 32.13983438909054, 36.57302990555763, 37.9492324590683, 40.758007541298866, 41.84791445732117, 40.4457250982523, 42.776349037885666, 42.244198992848396, 42.62810759246349, 42.400256618857384, 45.55878393352032, 47.82012619078159, 50.65139226615429, 49.72837619483471, 45.844395607709885, 43.05745415389538, 46.28027781844139, 53.22268769145012, 56.5453016012907, 52.55668982863426, 58.98112289607525, 54.69412073493004, 55.580122992396355, 50.2636344730854, 50.83436384797096, 54.132742658257484, 57.3347320407629, 54.14217375218868, 56.33062832057476, 58.64156931638718, 46.61685235798359, 13.660780917853117, 0.6687518837861717, 0.808885870501399, 10.900378189980984, 51.111163794994354, 43.14432129263878, 44.03121270239353, 46.365951821208, 45.80118052661419, 47.50191606581211, 64.83547255396843, 22.487309239804745, 0.38137179042678326, 9.043921306729317, 43.494126722216606, 18.92687939107418, 27.490132190287113, 32.36232005059719, 29.696753583848476, 32.04431131482124, 30.767756514251232, 29.973857514560223, 26.335142366588116, 35.34675590693951, 39.02759179472923, 36.09525874257088, 33.59180487692356, 43.4664262086153, 67.99947917461395, 16.74199853092432, 0.532939393306151, 0.21712867630412802, 0.08612806355813518, 0.08730536210350692, 0.026754460850497708, 0.13568377238698304, 0.08383131687878631, 0.0374502449267311, 0.05435845443571452, 0.06167014529637527, 0.04328536248067394, 0.0833234132733196, 0.05186604423215613, 0.04810872494999785, 0.09604021019185893, 0.39791179820895195, 0.2381137033808045, 19.113570973277092, 85.44361352920532, 40.92943534255028, 31.469554156064987, 81.121277064085, 81.22500389814377, 43.494442105293274, 33.47721442580223, 33.10547277331352, 42.21363723278046, 33.5677407681942, 36.16831362247467, 24.236157797276974, 72.18863278627396, 80.6562352180481, 17.480388209223747, 2.084018597379327, 6.657832218334079, 54.102378487586975, 55.007824301719666, 68.43079403042793, 61.63963124155998, 62.582311257719994, 52.26254001259804, 12.747407779097557, 1.6173483012244105, 0.30306211905553937, 4.172146199271083, 39.73369650542736, 64.68931719660759, 67.5846554338932, 65.69456845521927, 63.825790733098984, 63.8059101998806, 60.81233203411102, 65.25285735726357, 60.05860447883606, 55.6537364423275, 62.21017062664032, 60.28171710669994, 58.4820918738842, 48.14573831856251, 51.27442203462124, 58.52139316499233, 61.66275680065155, 58.37260074913502, 56.41828201711178, 57.59221002459526, 57.62868046760559, 51.631557270884514, 48.35101470351219, 52.10997819900513, 56.50862596929073, 57.11326092481613, 56.9762896746397, 43.02710898220539, 39.27748538553715, 33.07119861245155, 28.912165984511375, 28.07052254676819, 24.850444234907627, 29.823699072003365, 8.76957032829523, 0.07335886359214783, 0.016963154412223957, 0.02682989274035208, 0.07856177151552401, 0.024352201180590782, 0.02311176071088994, 0.021457411494338885, 0.05242862556769978, 0.06974292715312913, 0.02804740084684454, 0.022584579819522332, 0.03605606114433613, 0.07053986759274267, 0.05189942974539008, 0.0699373624229338, 0.06044009860488586, 0.20350979146314785, 0.9078873018734157, 0.16036709945183247, 0.059637877784552984, 0.014264131223171717, 0.06255058848182671, 0.01292069178816746, 0.012073939324181993, 0.018736668425844982, 0.035515770214260556, 0.007413389212160837, 0.021776126814074814, 0.05381715047406033, 0.1892774028237909, 3.1123172817751765, 24.555420465767384, 27.692370638251305, 25.420548543334007, 29.544313363730907, 36.54425784945488, 41.16512529551983, 43.1734923273325, 44.696462005376816, 44.2775534838438, 43.89997914433479, 45.16150765120983, 44.87031787633896, 45.51480129361153, 45.71788899600506, 49.720586612820625, 49.901814088225365, 52.467026039958, 49.15855497121811, 48.494533002376556, 44.209073558449745, 47.02002592384815, 55.226996541023254, 57.218549475073814, 53.609605729579926, 58.960934579372406, 56.733083724975586, 57.59688377380371, 52.806401029229164, 51.77675887942314, 55.453604981303215, 58.38525027036667, 56.95941857993603, 60.98956972360611, 60.51148697733879, 45.124079659581184, 12.454054020345211, 0.9239469619933516, 2.711765575222671, 17.7472934871912, 53.375990465283394, 46.65877930819988, 49.358971416950226, 50.53356058895588, 48.28965559601784, 52.67285339534283, 68.29122751951218, 19.16667692363262, 0.19596557831391692, 13.075466975569725, 48.50527122616768, 31.016783751547337, 27.694413028657436, 30.44837985187769, 30.21198693662882, 33.0848740786314, 32.11121432483196, 27.71164510399103, 29.946489483118057, 34.77133758366108, 30.079334154725075, 40.67464001476765, 35.24544194340706, 50.11139564216137, 77.41642266511917, 21.62706959992647, 0.5683439341373742, 0.16240049502812326, 0.07386638128082268, 0.11204456546693109, 0.07955929220770486, 0.07414219304337166, 0.2711647900287062, 0.1134177167841699, 0.21991419402183965, 0.12462054728530347, 0.20393231097841635, 0.1903812139062211, 0.17785138625185937, 0.15647688007447869, 0.1869915731367655, 0.34742441202979535, 0.40915310906711966, 25.802401453256607, 100.858603566885, 49.09244991838932, 36.173933520913124, 78.03293198347092, 100.94439536333084, 52.54504345357418, 62.886629328131676, 53.624466732144356, 61.01947411894798, 48.53106804192066, 37.7829609811306, 37.66322560608387, 113.72069299221039, 95.44293656945229, 17.75404952466488, 2.851879019290209, 9.872674886137247, 65.88391989469528, 63.150787353515625, 73.55150565505028, 65.42082354426384, 70.2752910554409, 55.256684347987175, 13.159239180386066, 1.3373105716891587, 0.7348022551741451, 7.553792791441083, 44.332357943058014, 67.59290859103203, 70.51382705569267, 67.19097375869751, 68.028334826231, 66.39477208256721, 63.53428557515144, 65.63503324985504, 61.523893252015114, 58.12123283743858, 64.44447353482246, 63.45530681312084, 59.62428018450737, 54.45729464292526, 54.67351444065571, 63.46186526119709, 66.77100509405136, 61.17093779146671, 58.992738872766495, 56.33130468428135, 60.264097452163696, 53.37284803390503, 52.61101171374321, 54.46045607328415, 60.071592181921005, 59.67042110860348, 59.79150541126728, 47.56942704319954, 43.28275926411152, 39.4601833820343, 32.30346120893955, 34.74736846983433, 26.72619268298149, 38.55193331837654, 12.841851711273193, 0.27705198037438095, 0.12864503602031618, 0.22483576118247584, 0.18799238896463066, 0.15262008702848107, 0.11313430542941205, 0.08737183627090417, 0.12431527968146838, 0.11869226422277279, 0.16688643634552136, 0.0887501380930189, 0.12726645218208432, 0.19054807838983834, 0.1303068085690029, 0.14554829540429637, 0.4508814902510494, 0.6412090023513883, 2.174634709954262, 0.1365998201072216, 0.15337452467065305, 0.22145836584968492, 0.14895840460667387, 0.14452797593548894, 0.0902056232735049, 0.12195994044304825, 0.17057171906344593, 0.14437386154895648, 0.12527985643828288, 0.12748887384077534, 0.4486090043792501, 3.6143453931435943, 34.56220060586929, 36.0813894867897, 34.51827876269817, 32.14097812771797, 44.04844477772713, 44.1886230558157, 48.259280025959015, 48.64218547940254, 46.89557120203972, 46.96429431438446, 48.75583738088608, 47.67814680933952, 49.18134994804859, 48.72161261737347, 50.475347712635994, 54.38970007002354, 54.27963897585869, 53.17666836082935, 51.2410332262516, 46.617448925971985, 50.23694850504398, 58.970126286149025, 62.14004158973694, 55.060371682047844, 58.821774646639824, 58.11763823032379, 62.38376811146736, 54.921052157878876, 54.85832132399082, 59.19697031378746, 61.23268447816372, 58.10728758573532, 63.95754486322403, 64.14761066436768, 51.42595410346985, 16.97638515383005, 1.5103015140630305, 2.04199546482414, 17.3164327070117, 60.0919970870018, 51.211622804403305, 53.789290487766266, 57.22893811762333, 55.7845102250576, 56.06237791478634, 75.06865784525871, 29.59971249103546, 0.49003052234183997, 12.983238324522972, 52.72509679198265, 26.42359022051096, 35.4782098531723, 44.28806371986866, 38.669100031256676, 43.251866921782494, 41.55963532626629, 38.05929355323315, 36.54640853404999, 42.94684588909149, 50.79107277095318, 50.530915930867195, 43.35270211100578, 62.09900379180908, 85.61946049332619, 30.31930647790432, 0.7636734622064978, 0.3874731349060312, 0.3077049652347341, 0.2915844490053132, 0.2450547434273176, 0.24954596883617342], [0.03510257578454912, 0.032607055982225575, 0.07841069993446581, 0.15080691635375842, 0.030031964961381163, 0.0635807859362103, 0.043047110812040046, 0.05155210463271942, 0.03300226446299348, 0.24690432386705652, 0.14301289629656821, 7.049896130338311, 72.95853227376938, 49.3898219615221, 34.82629783451557, 39.27849233150482, 35.072262436151505, 21.70860942453146, 31.11700527369976, 34.282410219311714, 36.18105813860893, 38.39484594762325, 33.29159438610077, 14.029780067503452, 28.00063669681549, 19.91161935031414, 23.02989922463894, 3.9204044826328754, 3.97631230764091, 41.98427774012089, 55.712815672159195, 52.29579582810402, 62.12059423327446, 51.90647251904011, 57.462625578045845, 29.587781131267548, 6.12794210202992, 0.22541485901456326, 0.18908800673671067, 16.712229028344154, 50.79946652054787, 63.51391486823559, 67.13143095374107, 62.439210936427116, 63.272133842110634, 62.85567618906498, 66.46856412291527, 51.13792195916176, 56.631116196513176, 62.25958697497845, 58.4690547734499, 53.400423154234886, 43.88706363737583, 48.33011582493782, 53.905020877718925, 55.94689451158047, 58.54550287127495, 55.90019881725311, 58.844413831830025, 51.727874502539635, 48.61457996070385, 47.52184219658375, 52.83240303397179, 53.051214292645454, 57.86811321973801, 50.032644867897034, 37.57566310465336, 30.695740878582, 24.229635447263718, 30.07007785141468, 24.984521940350533, 25.385630317032337, 23.603235259652138, 6.323352791368961, 0.05437336418253835, 0.033354933038936, 0.09581795180565678, 0.05656190201989375, 0.060185950133018196, 0.015678394738642965, 0.04660432110540569, 0.03355484164785594, 0.057228948062402196, 0.024463888839818537, 0.03591437030991074, 0.0856293180549983, 0.06385666449205019, 0.03186195455782581, 0.06176698443596251, 0.08179812168236822, 0.05952775420155376, 0.6781791185494512, 0.06627860406297259, 0.06379952654242516, 0.0625695132475812, 0.04266444462700747, 0.010188438936893363, 0.05239946658548433, 0.06709970140946098, 0.043981934868497774, 0.02689692166313762, 0.03154050813463982, 0.03491795912850648, 0.13558021310018376, 1.9146904209628701, 15.109433233737946, 16.91049098968506, 16.85928873717785, 25.942743122577667, 26.0672415420413, 32.29641638696194, 37.223425805568695, 39.52848091721535, 41.519851461052895, 41.564461067318916, 42.07796931266785, 41.46983094513416, 43.508755937218666, 42.57415808737278, 45.28617896139622, 48.68824280798435, 51.15634337067604, 47.76772700250149, 46.58910244703293, 41.41719616949558, 45.636611357331276, 52.64388754963875, 55.158463418483734, 54.971285462379456, 55.27133636176586, 51.27414084970951, 53.38207393884659, 51.527917832136154, 54.010932594537735, 54.9804961681366, 54.832254722714424, 54.91102449595928, 57.17544838786125, 54.72399853169918, 31.14330366253853, 3.665468324907124, 3.9917304553091526, 21.991175562143326, 43.15468333661556, 43.69309924542904, 43.16898196935654, 57.12057553231716, 54.58422303199768, 56.22559055685997, 56.00936695933342, 48.362155705690384, 5.557412216439843, 0.34490241610910743, 20.701078288257122, 32.07510106265545, 18.20222407579422, 32.74118632078171, 30.39481222629547, 31.869929172098637, 34.64600130915642, 34.21073466539383, 36.0049793869257, 28.854542076587677, 30.85959568619728, 31.98634922504425, 31.237114928662777, 26.61397710442543, 48.73084992170334, 68.0932505428791, 8.539757709950209, 0.23532306484412402, 0.15137881535338238, 0.04613106095348485, 0.05452133729704656, 0.03986775016528554, 0.03522280741890427, 0.031091347373148892, 0.04402096070407424, 0.13522886554710567, 0.13442348688840866, 0.049164693482453004, 0.0329648787737824, 0.02831869849615032, 0.0726151277194731, 0.08103946121991612, 0.38366829219739884, 0.36419409967493266, 10.072647705674171, 83.64715352654457, 55.520295202732086, 31.07849434018135, 46.30659140646458, 44.633237197995186, 32.019126266241074, 34.83163274824619, 31.204332187771797, 39.71923068165779, 37.17069983482361, 32.84704104065895, 18.870716504752636, 25.032002292573452, 13.807104416191578, 22.265572138130665, 7.946582464501262, 4.435462094843388, 47.76599429547787, 71.59366071224213, 64.53526586294174, 66.77869588136673, 57.23755605518818, 59.74665641784668, 38.10375116765499, 11.339263189584017, 0.5729461996816099, 0.23638258455321193, 14.731144532561302, 50.74577160179615, 64.88829731941223, 68.71438041329384, 63.224868178367615, 63.555150255560875, 66.44342467188835, 65.62994912266731, 51.99324086308479, 58.53587418794632, 62.37158976495266, 62.03822985291481, 55.511126294732094, 49.02926690876484, 50.55823266506195, 56.756828650832176, 60.586840733885765, 59.73747231066227, 57.85898230969906, 60.25370121002197, 53.61795388162136, 52.18307867646217, 50.15425354242325, 56.283442452549934, 54.96750086545944, 58.95979084074497, 52.55220226943493, 45.501148626208305, 35.52636466920376, 30.661958791315556, 41.31058529019356, 26.4910252019763, 27.799785174429417, 34.12491247057915, 8.7929761223495, 0.09914830981870182, 0.05615183574263938, 0.05198741506319493, 0.1419311121571809, 0.06502077507320791, 0.03215207492758054, 0.029106299007253256, 0.013922490034019575, 0.0574768031219719, 0.07072798718581907, 0.04175829344603699, 0.03786433735513128, 0.02199090249632718, 0.041124473355012015, 0.0363564639701508, 0.06228029087651521, 0.025778558920137584, 0.29903486953116953, 0.20739394007250667, 0.03386464748473372, 0.06189267827721778, 0.039845741775934584, 0.05343441749573685, 0.031590109574608505, 0.03150778684357647, 0.07041954318992794, 0.04938210564432666, 0.05120878340676427, 0.015215547846310074, 0.24074868386378512, 1.2605539779178798, 27.465412616729736, 20.861708968877792, 12.238988410681486, 28.324937894940376, 31.432380750775337, 34.18899603188038, 42.83550426363945, 42.49035358428955, 47.4185561388731, 45.61008498072624, 46.14703416824341, 43.50839115679264, 45.98045490682125, 45.28035007417202, 46.71034634113312, 51.16678141057491, 53.48118782043457, 48.95102150738239, 48.4020421653986, 44.52949896454811, 48.07777896523476, 54.13853734731674, 57.86049842834473, 57.88781896233559, 57.44787476956844, 52.87504054605961, 56.70007489621639, 54.04027462005615, 57.017943039536476, 58.19208383560181, 58.97909760475159, 59.2692918330431, 61.80711105465889, 55.96515633165836, 31.94091886281967, 4.213022030889988, 7.827766165137291, 32.484202310442924, 52.12922416627407, 47.88740158081055, 47.979421243071556, 63.28042879700661, 60.5438232421875, 62.2716361284256, 59.73232738673687, 51.635015085339546, 5.003032889217138, 0.5467178695835173, 30.511847846210003, 39.86624099314213, 24.419691748917103, 29.64884575456381, 29.518560245633125, 32.0342418551445, 30.320784598588943, 32.864854484796524, 32.60786287486553, 30.83290971815586, 27.969649359583855, 33.858436569571495, 41.02131821215153, 28.19723054766655, 57.34938025474548, 77.91456073522568, 10.724045801907778, 0.38283195113763213, 0.07305164413992316, 0.1024052248976659, 0.07242719366331585, 0.11211118806386366, 0.0356057259341469, 0.17907563305925578, 0.0829155437531881, 0.14403205801500008, 0.30757188331335783, 0.13090120948618278, 0.16369021410355344, 0.18529796245275065, 0.17695231887046248, 0.311846268014051, 0.4646719299489632, 0.47276116150896996, 15.26019774377346, 100.4152737557888, 62.84056819975376, 49.78576451539993, 44.17311608791351, 37.88671441376209, 29.561769627034664, 40.166926458477974, 44.49310451745987, 46.843627989292145, 55.038378462195396, 40.978825092315674, 19.6889303997159, 38.36698204278946, 24.756277687847614, 30.611493699252605, 10.131698437035084, 6.118359491229057, 50.18230363726616, 70.56373357772827, 69.48557943105698, 69.05120193958282, 63.95286351442337, 67.80213296413422, 39.432266280055046, 12.598084341734648, 0.8270182006526738, 0.7872070244047791, 20.756089836359024, 55.69861963391304, 68.05589094758034, 71.17113098502159, 66.44992992281914, 65.83853513002396, 68.69253158569336, 66.66786342859268, 53.58201541006565, 56.81699462234974, 68.74438360333443, 62.78461240231991, 61.7851672321558, 50.806427747011185, 56.51771888136864, 59.37216751277447, 63.156791031360626, 64.31683838367462, 60.47834515571594, 63.03283788263798, 57.39618994295597, 54.12068210542202, 54.58980493247509, 58.09086486697197, 58.418734073638916, 60.748655050992966, 55.611756294965744, 47.381086349487305, 41.55530735850334, 35.56774064898491, 44.31476108729839, 35.80668702721596, 36.08025714755058, 38.47485825419426, 9.014382641762495, 0.11003168285242282, 0.15925133979180828, 0.18188973830547184, 0.1882359618321061, 0.1607897673966363, 0.10009134202846326, 0.16731232521124184, 0.09327916108304635, 0.12341695444774814, 0.19809819903457537, 0.09767220035428181, 0.14009129838086665, 0.16580402880208567, 0.1378293361631222, 0.28227064409293234, 0.23110110545530915, 0.23792650405084714, 2.1973988134413958, 0.4602674616035074, 0.1995310783968307, 0.36325347202364355, 0.11840831852168776, 0.11403233380406164, 0.08164313156157732, 0.11243595188716426, 0.17569788149558008, 0.15346944535849616, 0.1092376590531785, 0.13084419770166278, 0.296778503106907, 2.1555898943915963, 32.26523146033287, 27.46769819408655, 27.345587946474552, 36.990471705794334, 34.5212160050869, 43.76648850739002, 45.89541167020798, 47.916109040379524, 49.19236555695534, 47.856486439704895, 48.722649961709976, 49.076779559254646, 50.067709386348724, 47.17306271195412, 51.4371483027935, 55.4930354654789, 56.287679225206375, 51.13063395023346, 50.61563238501549, 47.36811764538288, 51.20608650147915, 57.519941702485085, 61.53080128133297, 59.746994599699974, 58.747420236468315, 55.53124621510506, 57.66136631369591, 55.93213230371475, 60.67880719900131, 60.40683299303055, 60.17352931201458, 59.368067532777786, 63.548941388726234, 58.83818216621876, 38.111901730298996, 6.35077259503305, 5.2470078226178885, 27.739415913820267, 52.51051090657711, 53.431551083922386, 51.4683598279953, 66.01627439260483, 66.32501542568207, 64.8390519618988, 65.95182985067368, 57.997572273015976, 8.253670111298561, 0.7221928099170327, 27.572559267282486, 39.1419542580843, 26.762699224054813, 41.281820833683014, 40.25764659047127, 41.64624787867069, 46.099190935492516, 42.37013943493366, 48.82444269955158, 40.22057577967644, 39.599529504776, 48.531698808074, 42.54846766591072, 37.35847055912018, 66.99188724160194, 90.15244245529175, 16.393120251595974, 0.7319418399129063, 0.25971015624236315, 0.3545664850389585, 0.14146404893836007, 0.2671781211392954, 0.14709726150613278], [0.02515570962714264, 0.0362846018106211, 0.04037867060105782, 0.04088143112312537, 0.060330268170218915, 0.02925420347310137, 0.05424533999757841, 0.019756288420467172, 0.04143393409322016, 0.14595206826925278, 0.11526626563863829, 2.39212553948164, 67.21108987927437, 56.38212315738201, 37.22764737904072, 33.2481437176466, 26.714901588857174, 29.86425619572401, 22.730807773768902, 35.331594720482826, 34.43002849817276, 33.0575155466795, 41.48529231548309, 17.759876511991024, 8.356697782874107, 12.825874518603086, 22.46084935963154, 11.033460348844528, 2.1761539159342647, 32.6490792632103, 43.90382453799248, 37.25166209042072, 45.74851155281067, 55.329032465815544, 52.313696667551994, 42.87568710744381, 34.79894310235977, 8.836351744830608, 1.6222953982651234, 1.4652906730771065, 26.738657914102077, 60.07832922041416, 64.0130826830864, 64.44242164492607, 61.5095604211092, 60.449242517352104, 51.82734176516533, 53.281234949827194, 63.29061225056648, 58.824502900242805, 59.119986444711685, 49.757535830140114, 47.82000459730625, 49.73851025104523, 56.538306176662445, 58.42048957943916, 56.05097092688084, 57.60208189487457, 53.23027968406677, 56.14218883216381, 49.38277333974838, 48.79188224673271, 52.91174657642841, 58.928100541234016, 52.13909603655338, 57.6650483161211, 44.98145431280136, 26.037753224372864, 32.56721265614033, 30.52716102451086, 16.324590928852558, 18.632419891655445, 26.122553274035454, 9.622602704912424, 0.1004777560592629, 0.0940158094454091, 0.15266946953488514, 0.008918136300053447, 0.03192279582435731, 0.05348197431885637, 0.10403857319033705, 0.10567772507783957, 0.02860097065422451, 0.04860122156969737, 0.02753288470557891, 0.12233361179823987, 0.05170158430701122, 0.03679792680486571, 0.04894989739113953, 0.012710663067991845, 0.1280024103471078, 0.06845208001323044, 0.07932896667625755, 0.05726312396291178, 0.04200772556941956, 0.09774406993528828, 0.10244389821309596, 0.16287239704979584, 0.00746781090128934, 0.040436123963445425, 0.0497165322303772, 0.027630230360955466, 0.15591811708873138, 0.04139339427638333, 0.5988445412367582, 21.96001723408699, 15.907632652670145, 4.515415029600263, 10.36573737859726, 22.58229274302721, 25.254197269678116, 34.12076309323311, 37.62291356921196, 40.53472012281418, 41.75312474370003, 43.49311597645283, 45.294853895902634, 41.187133714556694, 44.745220988988876, 44.52394746243954, 48.64501252770424, 48.15908320248127, 51.35881170630455, 46.457298919558525, 42.39245563745499, 46.08217924833298, 53.357128277421, 52.87458837032318, 53.761950954794884, 51.48819096386433, 55.22871404886246, 56.39684736728668, 52.199793979525566, 52.760567888617516, 54.616418704390526, 54.115696772933006, 57.42107480764389, 52.333824187517166, 51.028833612799644, 15.39294932037592, 8.066355362534523, 29.640347510576248, 50.41175812482834, 53.37346740067005, 41.58311426639557, 32.308993712067604, 50.82327224314213, 49.97834958136082, 48.21163818240166, 55.86739517748356, 36.13877020776272, 2.285815794020891, 0.5632288148626685, 28.985627442598343, 24.300988018512726, 26.172095015645027, 35.047267377376556, 29.843364916741848, 32.780449613928795, 30.318761207163334, 36.32563658058643, 31.757702194154263, 30.71409959346056, 35.10557524859905, 25.87625239044428, 21.892939433455467, 34.246198162436485, 54.926729053258896, 61.451613530516624, 2.822157726623118, 0.03123905888060108, 0.12736119475448504, 0.037874048357480206, 0.07236498684505932, 0.05136611500347499, 0.08935234640375711, 0.036647679007728584, 0.050479597339290194, 0.05256526608718559, 0.008613061654614285, 0.0657638578559272, 0.019022701417270582, 0.07935272282338701, 0.07371612606220879, 0.19068208057433367, 0.0687117426423356, 0.24114071595249698, 3.199818986468017, 78.80203351378441, 62.199310809373856, 39.43972907960415, 39.30648162961006, 27.109856195747852, 40.8683118224144, 27.74374008178711, 30.64177807420492, 32.57656395435333, 36.84358298778534, 31.259117648005486, 19.80508826673031, 14.849791266024113, 10.874406583607197, 21.146589182317257, 14.03601648285985, 2.4013162963092327, 34.75265398621559, 54.29694704711437, 44.23821799457073, 48.82087469100952, 61.93110980093479, 64.21613618731499, 50.48242673277855, 43.02201725542545, 14.612900577485561, 3.0611121794208884, 0.8476706861983985, 23.161301873624325, 56.180198192596436, 64.38411757349968, 65.20851373672485, 63.18363279104233, 61.055063009262085, 53.906468600034714, 52.40281328558922, 65.07050514221191, 59.028247967362404, 61.309558153152466, 53.701515197753906, 51.696051210165024, 53.770150914788246, 59.8624400049448, 61.974313482642174, 57.78237842023373, 59.177199974656105, 55.05875676870346, 58.85732173919678, 52.86833770573139, 51.593707501888275, 54.23108898103237, 60.55764690041542, 54.31482508778572, 60.47377400100231, 46.81832134723663, 30.2355095744133, 41.73204727470875, 29.677878096699715, 14.458978436887264, 17.458330392837524, 28.652125038206577, 15.530184656381607, 0.3019833628786728, 0.06585485258256085, 0.05269928682537284, 0.03755063153221272, 0.03704575960000511, 0.03179446364811156, 0.023068092741596047, 0.05447907940833829, 0.027639984036795795, 0.03732344528543763, 0.01760660386935342, 0.09089443279663101, 0.028477323285187595, 0.0890602741856128, 0.0371496714069508, 0.08249742517364211, 0.21614746801787987, 0.7287378399632871, 0.2481485641328618, 0.039567892818013206, 0.023792519787093624, 0.046994160147733055, 0.1653412848827429, 0.0707058489206247, 0.02945841282780748, 0.035515469644451514, 0.05082577954453882, 0.08884278780897148, 0.09862623119261116, 0.06462616031058133, 1.4860198670066893, 28.840629123151302, 20.886871218681335, 4.4038929138332605, 9.109755624085665, 23.706724606454372, 30.91842222958803, 37.136456072330475, 40.41010960936546, 44.283180981874466, 47.042957693338394, 46.273164600133896, 46.82691648602486, 44.091405272483826, 48.6069917678833, 45.8907987177372, 49.11628983914852, 50.49449108541012, 52.90577329695225, 48.09319093823433, 45.502862334251404, 48.15621055662632, 53.71580243110657, 55.740333795547485, 54.27233196794987, 53.369971588253975, 56.235815808176994, 57.01809123158455, 54.17572595179081, 54.25843231379986, 57.59743474423885, 56.684066355228424, 60.614632442593575, 53.88309985399246, 50.45668691396713, 14.80624370276928, 14.1598641872406, 37.55085043609142, 56.76229655742645, 56.126936450600624, 44.71544198691845, 36.79857440292835, 56.458043083548546, 53.258280381560326, 51.21223837137222, 63.31973768770695, 36.226663291454315, 0.7567758823279291, 2.3835315881296992, 38.29027935862541, 26.405980065464973, 28.015220314264297, 31.49823311716318, 28.152499347925186, 31.40886001288891, 31.299302391707897, 37.44500711560249, 25.225968584418297, 35.44029928743839, 28.055247366428375, 31.75709992647171, 21.335334554314613, 31.915179044008255, 62.50649392604828, 70.94219326972961, 3.986473912373185, 0.067883565207012, 0.14692972908960655, 0.03705656898091547, 0.05652763706166297, 0.02626785688335076, 0.09902919511660002, 0.2496226178482175, 0.130084891570732, 0.16049684170866385, 0.09085914367460646, 0.19413553120102733, 0.19207316217944026, 0.4460516228573397, 0.254593463614583, 0.27227922866586596, 0.3093914216151461, 0.489985013846308, 5.486673312261701, 90.29556557536125, 74.36554357409477, 54.87424246966839, 44.59238559007645, 27.371935732662678, 38.615735694766045, 29.819186814129353, 48.13286080956459, 42.19599477946758, 45.35636119544506, 54.97571602463722, 23.75383447855711, 16.907578445971012, 22.528468631207943, 31.987382769584656, 17.495017424225807, 4.268887108191848, 40.35544954240322, 57.07960233092308, 49.97798480093479, 60.724754333496094, 65.63287496566772, 62.93331362307072, 58.075289502739906, 43.96617539227009, 12.876847833395004, 2.17893797904253, 1.9776851031929255, 32.83803552389145, 66.31221011281013, 68.2563453912735, 68.31828206777573, 65.5432453751564, 61.53096467256546, 56.18927590548992, 52.38574460148811, 70.03556191921234, 61.28001853823662, 66.38777285814285, 55.1469424366951, 56.92594237625599, 55.093156322836876, 64.69010755419731, 65.42497292160988, 61.629231199622154, 60.3207828104496, 58.90855818986893, 63.14446069300175, 54.55746866762638, 55.44944800436497, 56.681965067982674, 65.25965139269829, 53.86313192546368, 64.64537635445595, 53.43526728451252, 35.347037091851234, 43.24560485780239, 45.07383115589619, 28.450072780251503, 26.21388517320156, 40.70232152938843, 13.991556018590927, 0.13943817873951048, 0.1419398546568118, 0.2080200010095723, 0.11174573228345253, 0.15137281880015507, 0.12185850369860418, 0.16735156998038292, 0.16288609709590673, 0.06854642182588577, 0.10247495709336363, 0.15359446755610406, 0.24749670614255592, 0.16057184315286577, 0.2087632322218269, 0.0986135849962011, 0.24831643793731928, 0.5779268417973071, 1.1737256683409214, 1.0632788948714733, 0.1886044826824218, 0.15076473267981783, 0.15001471823779866, 0.28897778887767345, 0.28950744483154267, 0.07245426721055992, 0.14958611311158165, 0.12807275110390037, 0.18494187999749556, 0.2292526827659458, 0.17079461569665, 1.8085217429324985, 35.584406554698944, 26.418055817484856, 9.717871192842722, 22.84773699939251, 33.58056128025055, 36.68415494263172, 44.5328313857317, 46.75977788865566, 48.57865668833256, 48.47915522754192, 48.39666165411472, 49.80346776545048, 46.77353695034981, 50.222338289022446, 48.84127199649811, 49.88239333033562, 53.57028543949127, 56.69532895088196, 49.95953679084778, 47.91221044957638, 50.96730351448059, 56.84572488069534, 58.30072000622749, 55.42895570397377, 54.13843855261803, 58.84069003164768, 61.477060765028, 55.858363062143326, 57.65647977590561, 59.96160328388214, 60.83395667374134, 65.95182225108147, 58.78446824848652, 58.041741102933884, 18.951735757291317, 11.72504223883152, 36.18548110127449, 61.619815304875374, 61.88691437244415, 48.23613926768303, 40.64194656908512, 59.016381204128265, 60.417145639657974, 59.24549750983715, 67.01132699847221, 44.02266316115856, 3.8772095879539847, 1.575525370426476, 38.55452097952366, 30.918091647326946, 36.25099718570709, 43.485371991992, 38.737013787031174, 41.312306597828865, 41.44723355770111, 46.246383637189865, 41.54735818505287, 42.76244178414345, 44.67671066522598, 38.16940784454346, 30.853107534348965, 46.25743344426155, 73.09176072478294, 80.8150514960289, 6.527406591922045, 0.305863399989903, 0.35550975473597646, 0.266157133737579, 0.20638562855310738, 0.2516851352993399, 0.2261699942755513], [0.017047486508090515, 0.036834859783994034, 0.07704198666033335, 0.07257877732627094, 0.11420894268667325, 0.06516569425002672, 0.060556775351869874, 0.027279361493128818, 0.038831125712022185, 0.12422939835232683, 0.13802762317936867, 0.04776055007823743, 49.619895815849304, 66.70725211501122, 45.621191784739494, 40.35061240196228, 51.10358700156212, 37.87167862057686, 36.926707327365875, 39.83338035643101, 51.0242510586977, 35.327760726213455, 37.56681717932224, 34.55533057451248, 13.671783227473497, 14.445625003427267, 23.697532899677753, 26.13880880177021, 1.450054559390992, 5.59952013194561, 33.81703019142151, 66.67981758713722, 74.73820477724075, 62.997761964797974, 38.303126469254494, 26.189099103212357, 40.575765520334244, 49.26574721932411, 29.293733909726143, 2.8491643024608493, 1.0599329369142652, 21.472678184509277, 51.62894681096077, 57.144863829016685, 59.278206154704094, 52.96190768480301, 52.47779846191406, 59.97956492006779, 60.548895969986916, 62.21636429429054, 58.216634318232536, 53.76972533762455, 50.604096204042435, 50.53851932287216, 56.26741871237755, 59.10324454307556, 58.500076308846474, 57.54869855940342, 57.800883427262306, 52.736971154809, 50.17473824322224, 54.724678695201874, 54.16306883096695, 56.56258687376976, 53.73886339366436, 50.053148567676544, 33.41993249952793, 23.363300934433937, 30.920789502561092, 10.071260780096054, 8.390094190835953, 12.270499169826508, 17.588581703603268, 18.53862762451172, 1.0515919094905257, 0.11729612117051147, 0.01716993716399884, 0.10600151668768376, 0.03666408418212086, 0.06724396749632433, 0.040561313144280575, 0.05277575401123613, 0.06882828951347619, 0.07374969340162352, 0.13545772904762998, 0.10664644301868975, 0.03294813592219725, 0.024799679122224916, 0.018307011305296328, 0.10534525034017861, 0.35942057613283396, 0.5063423048704863, 0.14752987422980368, 0.039241418344317935, 0.08422653278103098, 0.019548858144844417, 0.08070143521763384, 0.08597265783464536, 0.016283926015603356, 0.04134208218601998, 0.15900690603302792, 0.0346143279602984, 0.09952731721568853, 0.054698335807188414, 1.4003173657692969, 22.232455015182495, 12.425404507666826, 4.055258771404624, 5.0719977635890245, 8.318695072084665, 16.819721460342407, 28.9644093811512, 34.319602623581886, 39.37715403735638, 41.37046627700329, 44.20454420149326, 44.10627007484436, 40.937844291329384, 45.21745964884758, 45.82979679107666, 50.06101034581661, 49.47639651596546, 49.59672465920448, 45.647699162364006, 45.61280183494091, 46.23034089803696, 50.07035784423351, 53.3447827398777, 50.05938023328781, 49.728509187698364, 54.97935242950916, 56.7162050306797, 54.306989908218384, 52.3722705245018, 54.79311302304268, 52.85177059471607, 50.2298428863287, 43.455760180950165, 33.36484685540199, 10.881914030760527, 24.976557567715645, 47.793888598680496, 53.257216438651085, 46.82540416717529, 46.71905167400837, 39.015983417630196, 53.85891795158386, 57.82689683139324, 52.0354375988245, 60.42125701904297, 9.624329712241888, 0.24045862286584452, 7.8499446250498295, 32.193221524357796, 22.153896130621433, 27.321273051202297, 31.42138034105301, 30.56994292885065, 33.729422092437744, 33.02596963942051, 32.44721509516239, 35.74272505939007, 32.76754170656204, 34.764121770858765, 31.629280485212803, 36.733689084649086, 39.22872640192509, 56.46151229739189, 44.958252757787704, 0.9194836858659983, 0.0020784546086360933, 0.13444465294014663, 0.033864547294797376, 0.037204631153144874, 0.027669278460962232, 0.08234593798988499, 0.05402384231274482, 0.03414232203795109, 0.042337391278124414, 0.07269375826581381, 0.0665407751512248, 0.03732883698830847, 0.03625541314249858, 0.04000872482720297, 0.08683492211275734, 0.04180698575510178, 0.14037594170076773, 0.14941547851776704, 56.62366099655628, 76.51218518614769, 44.05608996748924, 42.979349344968796, 37.53885067999363, 34.178136214613914, 42.5700619071722, 33.406173437833786, 47.62050770223141, 30.853041037917137, 35.571612641215324, 38.156594932079315, 21.58630918711424, 16.391492038965225, 22.54839476197958, 35.457322373986244, 3.0779255647212267, 2.628131350502372, 28.444578275084496, 62.95561082661152, 75.23207947611809, 66.73893481492996, 45.22774949669838, 33.47782999277115, 43.34876552224159, 57.41702422499657, 37.59801350533962, 6.479744324460626, 1.5641035395674407, 19.59345292299986, 50.10758824646473, 55.58384299278259, 57.26579234004021, 53.480085879564285, 53.28398980200291, 58.30491878092289, 62.26404033601284, 65.3313459455967, 61.85311898589134, 57.230427637696266, 53.59874591231346, 53.715217262506485, 58.29705700278282, 60.292968302965164, 60.426724925637245, 59.42871227860451, 58.89801375567913, 54.251733273267746, 52.29462169110775, 57.039396688342094, 55.79856187105179, 60.03915712237358, 52.514082714915276, 54.19480852782726, 29.453053660690784, 25.20475622266531, 25.417218022048473, 13.707850892096758, 12.962972111999989, 16.88068348914385, 19.855213277041912, 23.653139881789684, 1.2435245979577303, 0.07547506058472209, 0.03932454259484075, 0.08063442670390941, 0.03545872874383349, 0.045195565253379755, 0.02467138590873219, 0.06377813042490743, 0.09282442493713461, 0.04823446332011372, 0.16083232214441523, 0.051372055895626545, 0.12155530668678693, 0.03401378206035588, 0.0258600894085248, 0.05894916845136322, 1.3973002089187503, 1.131771169602871, 0.2791722962865606, 0.02299558120284928, 0.11775075341574848, 0.02758083301159786, 0.12147289118729532, 0.07846904016332701, 0.09266176843084395, 0.045759783024550416, 0.08723859107703902, 0.18843460507923737, 0.04421922916662879, 0.06141313955595251, 3.442808585241437, 24.907589368522167, 17.037307284772396, 8.996006827801466, 7.65135683119297, 10.144280511885881, 17.925815507769585, 30.357657819986343, 38.28042648732662, 42.014356926083565, 45.91822184622288, 46.647402718663216, 49.137439504265785, 43.47934551537037, 45.99947668612003, 49.44318629801273, 52.85709410905838, 50.68935222923756, 52.20975324511528, 48.13555486500263, 47.239338755607605, 47.63206668198109, 53.41350205242634, 53.898853808641434, 52.490113601088524, 53.34043577313423, 55.181607976555824, 58.20809617638588, 57.976194620132446, 54.96492080390453, 57.326220497488976, 56.11245542764664, 52.810801193118095, 41.54858931899071, 34.3532308191061, 17.631508000195026, 32.80086971819401, 52.95809268951416, 57.55152180790901, 55.951515063643456, 51.76358498632908, 44.31695356965065, 57.942965403199196, 66.31084978580475, 62.02005162835121, 59.258629605174065, 4.177355719730258, 0.5564816831611097, 13.981055282056332, 33.84196825325489, 24.938458912074566, 26.55236341059208, 27.440843135118484, 29.8145966604352, 32.27292984724045, 35.70026233792305, 24.901574291288853, 30.05598820745945, 38.41187283396721, 24.248037859797478, 44.73086915910244, 30.787842236459255, 42.778096944093704, 64.27247956395149, 52.84719944000244, 0.9654756460804492, 0.03708722710143775, 0.06575766834430397, 0.0730336841661483, 0.040314979487448, 0.0349036802072078, 0.02837731888575945, 0.2112058925558813, 0.09725590745802037, 0.13458276662277058, 0.24200663901865482, 0.31560548348352313, 0.23682619590545073, 0.19927243993151933, 0.18556696129962802, 0.1878352020867169, 0.184667389257811, 0.22403314331313595, 0.5201446486171335, 69.70830827951431, 87.653848528862, 60.67908838391304, 52.92037591338158, 61.444891691207886, 46.446374505758286, 46.34664125740528, 56.20387852191925, 68.00188824534416, 48.16066391766071, 50.97187466919422, 44.1280011087656, 19.621542915701866, 25.662863440811634, 30.63592828810215, 33.99772569537163, 3.159738499671221, 10.425140541046858, 41.30380645394325, 69.16355431079865, 77.7254980802536, 67.11095005273819, 45.18413923680782, 38.44024211168289, 55.13900466263294, 64.74525779485703, 34.34520564973354, 4.111282490193844, 2.4267222080379725, 26.605292670428753, 55.69086045026779, 57.74603337049484, 57.601207941770554, 54.35899771749973, 51.94261617958546, 61.38137049973011, 62.87146054208279, 68.92203167080879, 65.64770177006721, 62.346511110663414, 56.20508685708046, 59.16659094393253, 61.80288188159466, 64.36421424150467, 63.313810005784035, 61.410332545638084, 61.565064042806625, 58.78223776817322, 54.432265385985374, 60.17563819885254, 59.13634456694126, 62.18055121600628, 58.400039076805115, 59.11834493279457, 43.31598848104477, 35.10354995727539, 43.29648032784462, 20.09360108524561, 15.437478180974722, 18.530330769717693, 32.47464582324028, 36.82979352772236, 1.9090962898917496, 0.24732605670578778, 0.10688868002034724, 0.1806699443841353, 0.1282295965938829, 0.211655099701602, 0.09246217523468658, 0.18414588208543137, 0.18211791903013363, 0.2136583492392674, 0.19858475105138496, 0.20016288355691358, 0.2054785014479421, 0.20574055379256606, 0.14867244026390836, 0.2375621095416136, 1.5363949513994157, 1.8375676218420267, 0.6341274292208254, 0.22694530111039057, 0.1866886581410654, 0.11882645194418728, 0.24812632938846946, 0.19260543049313128, 0.17438891110941768, 0.10577473862213083, 0.23420773562975228, 0.2105198660865426, 0.2025187126128003, 0.3531510609900579, 7.674444392323494, 36.963280364871025, 23.63878235220909, 9.009390659630299, 8.968081176280975, 17.280273847281933, 30.803337804973125, 39.53814759850502, 44.34359773993492, 45.766910165548325, 49.53457899391651, 49.4843190908432, 52.174152955412865, 44.30069424211979, 48.21386106312275, 51.459042727947235, 55.824267491698265, 52.884110659360886, 55.16991600394249, 50.68820849061012, 52.97640010714531, 49.69200074672699, 56.76423445343971, 57.169399112463, 54.97547663748264, 52.70062990486622, 58.18526700139046, 60.317518785595894, 59.57618236541748, 57.07751624286175, 61.80887036025524, 59.5780860632658, 59.0249003469944, 49.54480804502964, 40.10424502193928, 17.410779744386673, 32.36159808933735, 58.38726036250591, 61.999080553650856, 56.85287989675999, 53.14727693796158, 46.61082588136196, 65.51732316613197, 68.7159763276577, 60.28786897659302, 72.78942614793777, 13.643869925290346, 0.596239009173587, 10.990145523101091, 42.470925226807594, 31.410993598401546, 35.40084220468998, 38.99055138230324, 40.465704426169395, 42.84939631819725, 43.26531819999218, 40.92148996889591, 49.50021743774414, 44.787170737981796, 46.62057615816593, 47.28337459266186, 48.669578209519386, 56.82432442903519, 74.15003433823586, 69.048952460289, 1.8281082669273019, 0.10902849957346916, 0.36772396182641387, 0.23364500957541168, 0.17611317249247804, 0.13951086468296126, 0.1629775742185302], [0.07649320556083694, 0.04666073546104599, 0.11238149309065193, 0.08727681168238632, 0.03329155733808875, 0.04463021570700221, 0.0986012356588617, 0.060266131768003106, 0.07374610140686855, 0.19944191677495837, 0.38935599324759096, 0.4438451584428549, 14.717761650681496, 63.63988570868969, 51.244430243968964, 36.181616708636284, 46.78132273256779, 54.792208671569824, 40.24298697710037, 37.2052513808012, 29.483691416680813, 41.09107106924057, 20.845939815044403, 30.071713663637638, 12.649389188736677, 10.040156599134207, 16.878031231462955, 38.68360385298729, 8.43750899657607, 1.0041848220862448, 28.55284396559, 58.08535136282444, 55.69619536399841, 68.58483016490936, 42.47184857726097, 26.06896284967661, 44.94336515665054, 45.79668916761875, 55.485606864094734, 34.24511522054672, 10.008524246513844, 5.773390727117658, 30.331703312695026, 45.19045829772949, 51.13525070250034, 53.25226530432701, 56.0054911673069, 57.40579202771187, 64.10202071070671, 58.39869014918804, 60.28255686163902, 55.51472470164299, 54.991264790296555, 54.18634258210659, 62.21361704170704, 56.23515084385872, 58.52373763918877, 54.68589037656784, 55.470301285386086, 57.44457274675369, 56.070779263973236, 54.55767385661602, 59.87391918897629, 58.25506545603275, 49.94374483823776, 41.27961315214634, 5.53325311280787, 6.306229010224342, 11.003053430467844, 13.467343747615814, 10.396405532956123, 18.728043660521507, 9.541784841567278, 10.98513264209032, 1.3675786787644029, 0.08359821571502835, 0.0551673582958756, 0.107700708322227, 0.028917066192661878, 0.019587414572015405, 0.11023228536942042, 0.1333279284881428, 0.05190561554627493, 0.01721557739074342, 0.08031593402847648, 0.03511066148348618, 0.03947940655052662, 0.0777118862606585, 0.1630509429378435, 0.21892391669098288, 1.4612371218390763, 0.43285401072353125, 0.020384555391501635, 0.04503497933910694, 0.09527847723802552, 0.17238784348592162, 0.04777442823979072, 0.08480349322780967, 0.02617416816065088, 0.1040775136789307, 0.030456017011601944, 0.02557896757934941, 0.03434132522670552, 0.12944943504408002, 1.8148533906787634, 13.384078815579414, 11.255237348377705, 14.754191245883703, 6.604036130011082, 8.087659869343042, 3.1941342540085316, 16.860715560615063, 41.32530950009823, 36.93524166941643, 47.04156696796417, 43.363713920116425, 45.89016795158386, 45.412138402462006, 50.52085027098656, 48.17352622747421, 47.86724366247654, 50.79534374177456, 49.458647668361664, 45.26794373989105, 44.538626074790955, 46.53336703777313, 52.386576756834984, 53.48288252949715, 53.573598861694336, 50.464457497000694, 56.47780582308769, 53.16456601023674, 53.63152675330639, 49.25537757575512, 50.08584961295128, 47.626131400465965, 38.85912403464317, 20.651268661022186, 19.300615936517715, 29.412726424634457, 39.1156330704689, 58.968180790543556, 44.78334814310074, 46.620245575904846, 44.848130866885185, 61.143704652786255, 53.630580604076385, 48.201792910695076, 55.34610874950886, 14.719701446592808, 0.16080235422123224, 12.38976052030921, 44.11466762423515, 39.2152751237154, 19.58790712058544, 25.025172159075737, 36.4777310192585, 29.414827711880207, 34.07280966639519, 31.03473398834467, 48.919346407055855, 41.60016015172005, 28.532843738794327, 37.08380609750748, 23.361421935260296, 22.06884529441595, 40.05464248359203, 62.45206564664841, 25.789725333452225, 0.46927547198720276, 0.11762639915104955, 0.2646695135626942, 0.03510172231472097, 0.0600060609576758, 0.059431338086142205, 0.08976782293757424, 0.0732853687077295, 0.02462356747855665, 0.1475898249191232, 0.16248377884039655, 0.023894095684227068, 0.11039523131330498, 0.03628600446972996, 0.06776960100978613, 0.025573099046596326, 0.31510195112787187, 0.3398160031065345, 0.5426452599931508, 20.353657230734825, 77.95382782816887, 51.25953063368797, 45.018528923392296, 43.07910159230232, 36.99595481157303, 49.678807854652405, 27.889971435070038, 32.574508264660835, 43.46405513584614, 25.998170748353004, 34.001077115535736, 22.37980540841818, 19.7628915309906, 17.79431976377964, 40.592762008309364, 16.045944280922413, 0.6267900229431689, 20.3385853394866, 61.47389933466911, 55.73867708444595, 67.68908143043518, 39.626998230814934, 32.04690657556057, 54.816914945840836, 53.42585138976574, 62.52781458199024, 41.373635306954384, 15.978159718215466, 7.430234821513295, 28.42374589294195, 45.56936256587505, 50.45278072357178, 54.23382103443146, 56.14193044602871, 58.37268814444542, 66.67069047689438, 62.34875679016113, 63.303881138563156, 59.517737701535225, 56.2119796872139, 58.74121896922588, 61.753864511847496, 60.17708972096443, 60.86570776998997, 56.13680072128773, 57.18649059534073, 59.339724853634834, 55.242020934820175, 58.33198092877865, 59.71865192055702, 59.60596516728401, 49.62628327310085, 43.38280409574509, 3.5911564249545336, 10.299013908952475, 19.03286900371313, 23.145722709596157, 20.27436688542366, 19.993282668292522, 16.57362576574087, 13.592014107853174, 1.5843336540274322, 0.10971206953399815, 0.06180139782372862, 0.00698681339599716, 0.07646016514627263, 0.02991409521200694, 0.08018663706025109, 0.05785707588074729, 0.034313672804273665, 0.04291533878131304, 0.016244232247117907, 0.07131101840059273, 0.05315743685059715, 0.03192903728631791, 0.14061847556149587, 0.3478288825135678, 1.5235620900057256, 0.425441469415091, 0.03227422872441821, 0.05050470048445277, 0.05912948807235807, 0.09042644931469113, 0.004273615186320967, 0.02988379888847703, 0.0491679700644454, 0.030151884893712122, 0.028657505608862266, 0.08791975647909567, 0.0383509264793247, 0.07736816056421958, 0.9604115271940827, 9.781563375145197, 18.31939648836851, 21.960782893002033, 13.65337511524558, 12.833126429468393, 5.817576181143522, 13.437335807830095, 47.94403374195099, 39.663666263222694, 49.218739941716194, 46.80523104965687, 48.676702827215195, 48.27872358262539, 52.02131375670433, 48.741470351815224, 49.88131798803806, 52.00640335679054, 51.696036010980606, 48.97144541144371, 46.53905913233757, 50.18407814204693, 54.01352785527706, 55.02336926758289, 53.78343120217323, 51.5556525439024, 58.287086337804794, 55.00004991889, 54.987681582570076, 52.74828314781189, 53.87689858675003, 49.38770167529583, 37.5715821236372, 19.489302411675453, 24.52995803207159, 39.13889542222023, 46.56620107591152, 65.32050892710686, 46.256073117256165, 50.06129913032055, 49.4873209297657, 59.82343889772892, 52.68848195672035, 59.95126783847809, 51.46554417908192, 8.505081720650196, 0.11774180311476812, 24.847765378654003, 46.36489927768707, 42.28903278708458, 25.42000327259302, 24.96427282691002, 33.90386313199997, 25.83932977169752, 35.37769764661789, 27.532408721745014, 27.960216365754604, 48.43226574361324, 24.72481917589903, 34.70718942582607, 29.158624559640884, 19.387568570673466, 48.406343534588814, 73.77512365579605, 32.173325791954994, 0.6435023574158549, 0.11702250616508536, 0.19451291329460219, 0.04897104859992396, 0.09770412012585439, 0.025050962904060725, 0.061480530275730416, 0.202549229725264, 0.14871077961288393, 0.2758251508930698, 0.20920326642226428, 0.18521996273193508, 0.22058027156163007, 0.21022919652750716, 0.09506436021183617, 0.2927771693794057, 0.37047795311082155, 0.7485375681426376, 0.8506464608944952, 31.514355652034283, 88.02634254097939, 66.60709708929062, 50.54015703499317, 57.86008805036545, 70.12411996722221, 52.81520515680313, 47.53312759101391, 39.92981918156147, 60.74399650096893, 28.712391704320908, 42.701333463191986, 16.120199896395206, 19.55928895622492, 23.134017437696457, 50.12482792139053, 12.958361059427261, 1.0996506619267166, 32.86726735532284, 69.52286303043365, 58.17529633641243, 74.4917044043541, 48.183766677975655, 42.64625541865826, 63.35239693522453, 61.54775217175484, 63.559694811701775, 40.156765803694725, 12.251699678599834, 8.260313104838133, 33.81105311214924, 51.04742981493473, 51.548679918050766, 54.45759102702141, 55.07318839430809, 58.959399461746216, 68.2043869793415, 65.59780284762383, 66.19628593325615, 61.37258157134056, 61.95972986519337, 59.668942987918854, 66.11721977591515, 63.499574437737465, 61.49614714086056, 58.557377234101295, 59.180175215005875, 62.83033914864063, 59.08482313156128, 61.34133204817772, 60.09678103029728, 62.01914727687836, 54.49852243065834, 53.75197269022465, 9.707320109009743, 16.993993408977985, 23.35498508065939, 20.28345599770546, 21.830066107213497, 25.713963098824024, 23.86789295822382, 22.27641485631466, 2.437029629945755, 0.1964282925473526, 0.15796539082657546, 0.17570579278981313, 0.28631428023800254, 0.14216567535186186, 0.2743482473306358, 0.2485995227470994, 0.15990917949238792, 0.14412294141948223, 0.21421402489067987, 0.2241919926018454, 0.16566085367230698, 0.21450203756103292, 0.3979331720620394, 0.5800733703654259, 3.09666829649359, 1.0451087448745966, 0.11919826050871052, 0.13924260798376054, 0.31144040229264647, 0.31779559096321464, 0.2566265326458961, 0.11697771013132297, 0.22100166301243007, 0.1638098928378895, 0.10647296599927358, 0.15868591231992468, 0.2890162618132308, 0.17483224044553936, 4.782407702878118, 25.013945661485195, 24.350725449621677, 22.67687726765871, 13.10413833707571, 12.844007145613432, 9.653159715235233, 23.625262677669525, 53.302578404545784, 42.24779359996319, 55.600926876068115, 49.27855633199215, 51.89768739044666, 50.66976808011532, 55.175931081175804, 51.36170715093613, 52.49513313174248, 55.79766131937504, 54.65345151722431, 52.25536599755287, 50.877799317240715, 51.97327293455601, 57.381496131420135, 58.618827536702156, 57.787926122546196, 53.335895016789436, 59.910317435860634, 56.45104765892029, 58.39055098593235, 55.574069917201996, 58.487384989857674, 55.30622988939285, 46.517882868647575, 26.861828304827213, 27.171779572963715, 39.21846695244312, 49.735652804374695, 70.68424791097641, 54.29533213376999, 58.95771995186806, 54.96237874031067, 67.77694031596184, 59.39928285777569, 58.03387172520161, 65.44636577367783, 20.50009947270155, 0.17287072929320857, 16.200658679008484, 50.20168259739876, 51.12710393965244, 27.13538322597742, 30.523152239620686, 46.82005785405636, 38.09462405741215, 44.72201183438301, 39.33132469654083, 60.9181297570467, 57.28177808225155, 36.353945061564445, 50.39070725440979, 31.11106999218464, 31.11319787800312, 58.987286165356636, 83.00453200936317, 47.47619904577732, 0.6227988714817911, 0.3100884467130527, 0.42472891858778894, 0.24106112803565338, 0.23947379289893433, 0.21320140891475603, 0.31210967106744647], [0.05267409091175068, 0.19490205100737512, 0.013634507049573585, 0.023235293047036976, 0.04614369972841814, 0.050267469268874265, 0.08050918928347528, 0.06816037886892445, 0.11211291726795025, 0.0358749622682808, 0.05628544829960447, 0.051449161328491755, 4.521523676812649, 66.52746856212616, 54.42933574318886, 31.935602948069572, 33.65374535322189, 45.817546248435974, 43.152627646923065, 45.101098492741585, 34.4830584526062, 31.308469399809837, 32.04407952725887, 33.05869348347187, 20.923759639263153, 10.988259874284267, 30.226467959582806, 44.66911867260933, 34.362167939543724, 1.7900018929503858, 3.456496400758624, 40.90065948665142, 63.598137348890305, 56.629562079906464, 71.74314469099045, 43.89524459838867, 39.56117056310177, 56.52042433619499, 57.453243881464005, 62.67096810042858, 50.53182028234005, 14.213829841464758, 12.404756415635347, 35.53771086037159, 43.8809459656477, 45.179089307785034, 51.47263839840889, 58.74860197305679, 61.72916203737259, 66.20029851794243, 58.066644966602325, 60.88332362473011, 59.29438568651676, 57.7476254850626, 54.08646114170551, 57.151448875665665, 56.61758132278919, 57.31097191572189, 61.51372119784355, 55.909762904047966, 54.71250794827938, 60.30750252306461, 57.67152696847916, 51.807400435209274, 45.44365771114826, 9.804085716605186, 4.01173590682447, 11.494025085121393, 22.77404945343733, 18.18731177598238, 19.22341737896204, 13.494460992515087, 9.137767720967531, 8.472007345408201, 1.904614430386573, 0.20247879991075024, 0.09543622072669677, 0.10094442593981512, 0.09392895590281114, 0.0918714702129364, 0.04183744720648974, 0.06948738344362937, 0.03128641903458629, 0.012933558773511322, 0.02001249449676834, 0.07590377703309059, 0.027309077086101752, 0.0334019406727748, 0.13646681240061298, 0.41881061741150916, 0.7828763849101961, 0.25990845810156316, 0.11937783056055196, 0.04320934058341663, 0.015218801236187574, 0.05807587585877627, 0.05339957737305667, 0.06518321635667235, 0.030469088087556884, 0.015299593287636526, 0.025766556536837015, 0.010857952620426659, 0.11259802951826714, 0.03233888834074605, 0.687384718330577, 2.8758170222863555, 9.280897490680218, 17.11249005049467, 18.904097713530064, 9.903166349977255, 11.321160960942507, 4.5569672249257565, 26.35608684271574, 50.466756373643875, 41.269832476973534, 44.995452761650085, 49.65266905725002, 45.095980167388916, 50.090109184384346, 48.4552127122879, 53.522677794098854, 48.10245484113693, 49.96050573885441, 44.114755019545555, 45.56798703968525, 48.269364684820175, 53.003640845417976, 54.13990527391434, 56.84520810842514, 48.36567051708698, 54.32944670319557, 53.93435910344124, 52.89677917957306, 43.65597903728485, 45.39288863539696, 29.61285598576069, 23.356947675347328, 11.705594882369041, 28.118437975645065, 40.69681562483311, 44.60979625582695, 41.91516324877739, 50.489258766174316, 45.55230528116226, 52.93256565928459, 38.621009811758995, 46.29077285528183, 33.00304926931858, 10.391036421060562, 0.15606932225637138, 12.332355100661516, 55.50085164606571, 41.92395597696304, 25.227213017642498, 10.850275978446007, 29.394561499357224, 30.342730320990086, 35.34251533448696, 31.671178936958313, 43.925946950912476, 39.75102357566357, 23.24404053390026, 30.568436309695244, 34.46748308837414, 33.04228976368904, 32.786837071180344, 48.16484369337559, 55.47899901866913, 11.117135658860207, 0.12015798361971974, 0.07762862471281551, 0.05720561122871004, 0.12624899740330875, 0.02970102461404167, 0.03369837300851941, 0.0364010150951799, 0.0926437416637782, 0.12271348750800826, 0.018315453235118184, 0.02809681489452487, 0.04924873799609486, 0.06949185859411955, 0.09349846572149545, 0.04241965463734232, 0.13914878567447886, 0.10793983572511934, 0.19232081685913727, 0.24465582420816645, 6.579358829185367, 77.48851239681244, 62.09371067583561, 31.35621763765812, 44.051024839282036, 27.414656840264797, 49.652585461735725, 42.14042656123638, 29.06611282378435, 35.42902149260044, 31.85191433876753, 39.62330102920532, 29.96156707406044, 22.746058255434036, 36.93796992301941, 41.848435029387474, 44.03917707502842, 3.508937624283135, 2.4058995628729463, 39.49745178222656, 73.87134209275246, 64.52125981450081, 70.82754582166672, 46.85432821512222, 52.13322535157204, 65.19644558429718, 60.128410533070564, 62.46257588267326, 57.35378421843052, 20.441500917077065, 15.51176704466343, 36.70235596597195, 40.9669279307127, 43.2443243265152, 51.375922188162804, 56.83894604444504, 61.27436064183712, 66.45055308938026, 58.30546975135803, 63.25443439185619, 61.073036044836044, 59.356345161795616, 57.58780986070633, 59.27559569478035, 56.24973826110363, 60.49605220556259, 61.24799005687237, 55.03808207809925, 56.838771253824234, 60.36766089498997, 57.047843635082245, 54.21798348426819, 43.291407600045204, 8.0593684874475, 7.939737131819129, 24.288817271590233, 23.384161815047264, 24.879778660833836, 26.19888547807932, 13.121707644313574, 14.053815677762032, 9.861933812499046, 1.1808844842016697, 0.16597828507656232, 0.046726523141842335, 0.08681776365847327, 0.0939180314890109, 0.1480824180180207, 0.039288986299652606, 0.0668805006716866, 0.006437681631723535, 0.02621728508529486, 0.04968322464264929, 0.023648307505936828, 0.08771555454586633, 0.0215207055589417, 0.40033491037320346, 0.3335712756961584, 1.062160567380488, 0.04004624410299584, 0.07846725158742629, 0.07043490564683452, 0.07947373000206426, 0.08464298894978128, 0.06516047695185989, 0.06266759548452683, 0.04814989188162144, 0.014518579337163828, 0.039393172701238655, 0.04784409364219755, 0.07158082618843764, 0.0489181668672245, 1.245090113952756, 5.548953395336866, 13.677871450781822, 24.600216262042522, 29.77868478745222, 14.86938776448369, 22.016434706747532, 9.412244092673063, 22.32664816081524, 52.57523663341999, 46.31546393036842, 47.14794985949993, 51.684879809617996, 48.34104783833027, 50.41216470301151, 51.5965573489666, 54.26828898489475, 50.17096124589443, 51.204513385891914, 45.36897271871567, 49.65450815856457, 50.14550641179085, 56.027894765138626, 55.731655061244965, 57.71319933235645, 50.25809817016125, 54.18721653521061, 57.19585329294205, 53.44327725470066, 45.903041660785675, 43.90647679567337, 27.6307113468647, 21.867986172437668, 17.271416522562504, 35.29562585055828, 43.303798735141754, 44.60515670478344, 47.71160401403904, 59.11831833422184, 55.39627365767956, 60.862523540854454, 44.63572606444359, 53.84983263909817, 33.36800068616867, 5.267079770565033, 0.9347376704681665, 22.781001180410385, 64.97406631708145, 40.304353684186935, 29.369026869535446, 15.654087457805872, 28.305847719311714, 31.236227676272392, 31.949650794267654, 24.275888465344906, 32.07403711974621, 34.07986208796501, 28.347354792058468, 19.293709807097912, 36.416611298918724, 27.431301847100258, 30.504447743296623, 55.457051396369934, 66.19245573878288, 12.748988494277, 0.08884494745871052, 0.1048289159371052, 0.1892439171206206, 0.09961955875041895, 0.019282679459138308, 0.0759255293814931, 0.08794279274297878, 0.14807707455474883, 0.3390189365018159, 0.11718145935446955, 0.3324171470012516, 0.14080496242968366, 0.2927932591410354, 0.2557412098394707, 0.30638797965366393, 0.29074353631585836, 0.36495174339506775, 0.2906894189072773, 0.555685922736302, 11.409182287752628, 92.53020286560059, 71.7435322701931, 44.07853156328201, 44.49701830744743, 56.43112912774086, 51.798113733530045, 61.66466809809208, 47.456994876265526, 39.43654105067253, 44.76787157356739, 50.812568217515945, 30.80791275948286, 15.254273861646652, 37.63330601155758, 55.26889689266682, 46.17759592831135, 2.900968110188842, 6.018163617700338, 50.63379921019077, 74.66952726244926, 67.82239347696304, 78.67068216204643, 54.78867866098881, 51.45170532166958, 65.20946368575096, 63.482482954859734, 72.41289675235748, 59.26302216947079, 17.090662121772766, 16.81583046913147, 42.04644240438938, 46.94728642702103, 47.65570141375065, 55.35267859697342, 57.54219710826874, 65.84159776568413, 71.23093217611313, 62.726426124572754, 67.3604142665863, 63.57660390436649, 63.98065522313118, 59.75506916642189, 60.400031358003616, 59.62870694696903, 59.66408684849739, 65.51714077591896, 58.95620383322239, 58.98674659430981, 62.50453323125839, 61.46552458405495, 57.804022058844566, 58.505779802799225, 14.321014489978552, 7.650924129411578, 27.553841471672058, 31.066519282758236, 26.28283817321062, 30.198716148734093, 25.10111678391695, 15.760188214480877, 18.230441361665726, 4.0651163924485445, 0.3598623914876953, 0.15768683311762288, 0.11297881064820103, 0.2243742937571369, 0.24445401941193268, 0.16556465649046004, 0.11508120369398966, 0.10545905126491562, 0.08984801199403591, 0.08057215309236199, 0.2762029634322971, 0.14674757636385038, 0.11673711327603087, 0.3787698206724599, 0.7415760448202491, 2.072528013959527, 0.7927862531505525, 0.42825747455935925, 0.1993654458783567, 0.1432451291475445, 0.15203304821625352, 0.1318087225081399, 0.14262640062952414, 0.18610193103086203, 0.17112735018599778, 0.14741634047823027, 0.12230465319589712, 0.23357803816907108, 0.34541363711468875, 4.589730016887188, 14.945876710116863, 17.875470109283924, 25.601451136171818, 29.748229421675205, 15.988918840885162, 19.539493918418884, 9.71394220367074, 33.11549283564091, 55.95628000795841, 49.114260748028755, 50.01268073916435, 54.73746880888939, 48.87945994734764, 55.59068262577057, 54.896782860159874, 56.65252044796944, 52.199767380952835, 55.044423937797546, 47.452457919716835, 51.827501356601715, 52.80644662678242, 59.0306456387043, 58.43543417751789, 61.92716561257839, 51.07762299478054, 56.79377406835556, 56.821303591132164, 58.88360872864723, 50.548151805996895, 54.68296453356743, 35.21716766059399, 30.475953072309494, 16.50082927197218, 33.64913620054722, 48.02210055291653, 52.779270485043526, 50.96677154302597, 60.941380709409714, 53.48401486873627, 62.84667447209358, 49.43342462182045, 55.271674543619156, 43.27292539179325, 16.19529716670513, 0.44367036782205105, 16.521243676543236, 65.11140614748001, 53.11568163335323, 36.07534781098366, 14.984575733542442, 34.886919781565666, 39.55876909196377, 45.03193460404873, 40.94781115651131, 57.51331865787506, 51.33377864956856, 33.46735395491123, 41.01607069373131, 51.07163071632385, 43.04965317249298, 49.02941510081291, 62.69478142261505, 78.19266021251678, 19.385345689952374, 0.15076330775627866, 0.4254116944503039, 0.32201386929955333, 0.25085977802518755, 0.20871822838671505, 0.18308875209186226, 0.1949238107772544], [0.02902490767155541, 0.04605117246683221, 0.01886211735836696, 0.04159653864917345, 0.00700802026585734, 0.03911575047823135, 0.05819196630909573, 0.06563207469298504, 0.036424248028197326, 0.0785571479354985, 0.026061448916152585, 0.1428830946679227, 0.33605304721277207, 51.30154497921467, 62.841780334711075, 53.08188624680042, 30.237356275320053, 50.37592604756355, 39.14949305355549, 30.181045196950436, 46.85425601899624, 42.50316649675369, 35.51778092980385, 25.73377523571253, 40.537957549095154, 10.454378072172403, 19.886584393680096, 58.542611226439476, 59.56938073039055, 21.777129247784615, 0.3330241941148415, 4.828414684161544, 31.834368780255318, 64.5450085401535, 54.782792776823044, 60.765993520617485, 46.352329552173615, 47.7642197906971, 49.2026212066412, 51.838657557964325, 55.07882349193096, 33.301641047000885, 22.90425706654787, 21.55063670128584, 17.825107611715794, 22.270530872046947, 41.609230265021324, 61.67537212371826, 62.53097601234913, 59.82610635459423, 59.0610858052969, 62.45719917118549, 58.78015547990799, 60.67693769931793, 59.15193893015385, 59.43645626306534, 56.97707623243332, 56.71264462172985, 51.64793059229851, 61.708947122097015, 61.30997613072395, 53.27079311013222, 60.85718862712383, 44.32297624647617, 13.611657153815031, 10.267100371420383, 25.84539044648409, 27.467270717024803, 12.532038185745478, 27.898038402199745, 21.93615071475506, 7.296818280592561, 11.194579303264618, 6.326283859089017, 0.4055584722664207, 0.019422761688474566, 0.13978446484543383, 0.038665162937832065, 0.09156666274066083, 0.03676654137962032, 0.06374114920618013, 0.0898536152089946, 0.10190648681600578, 0.08048741467064247, 0.034660010860534385, 0.04039918727357872, 0.12626142095541582, 0.031072199963091407, 0.3525478730443865, 0.10004442345234565, 0.27095119992736727, 0.1165527044213377, 0.08010254430701025, 0.07265121093951166, 0.048248033490381204, 0.06079397317080293, 0.04514842032222077, 0.03200730789103545, 0.10261798379360698, 0.06524332289700396, 0.06600505585083738, 0.03056029432627838, 0.040512839768780395, 0.1470882518333383, 0.10075229132780805, 2.595212529413402, 12.870777659118176, 14.206528533250093, 30.126084946095943, 20.07767044007778, 6.032436601817608, 27.183391749858856, 9.838703759014606, 28.915678896009922, 52.94866159558296, 46.73001408576965, 45.039872378110886, 49.810934364795685, 50.91514751315117, 49.63433884084225, 47.08699733018875, 50.87083049118519, 51.43693171441555, 46.5389983355999, 44.7750835865736, 51.667146161198616, 55.439351946115494, 52.296931967139244, 57.54129275679588, 47.99011006951332, 52.87449337542057, 47.66635984182358, 39.031589180231094, 27.66682270914316, 20.66040527075529, 14.768742565065622, 12.338506020605564, 21.709661968052387, 46.076722741127014, 47.131933718919754, 41.129080429673195, 50.981944128870964, 50.87163604795933, 51.57676421105862, 50.33281356096268, 53.721604719758034, 45.161811634898186, 16.81044425815344, 1.1729522910900414, 6.330062756314874, 66.23051449656487, 46.29816725850105, 44.78519104421139, 13.185638263821602, 19.109277203679085, 32.23666459321976, 28.904287107288837, 28.014053776860237, 34.479726031422615, 28.152763433754444, 24.321423321962357, 28.083305060863495, 37.92367123067379, 36.60047963261604, 27.040756903588772, 33.307325541973114, 61.25898666679859, 46.34480595588684, 1.9861940341070294, 0.07104074305971153, 0.21169262268813327, 0.038376868251361884, 0.01484585254729609, 0.030787705072725657, 0.1034206165059004, 0.05273779315757565, 0.03889454223099165, 0.04090711685421411, 0.020006902414024808, 0.01662717117142165, 0.05651720246532932, 0.05358584530767985, 0.030720533286512364, 0.13012633309699595, 0.05149756048922427, 0.10783859936054796, 0.023223337047966197, 0.011646748916973593, 0.6330732232891023, 59.43302884697914, 75.75965076684952, 44.954601153731346, 40.64237594604492, 42.95996658504009, 32.0622843503952, 44.919973611831665, 31.6928206756711, 43.780768141150475, 35.22504463791847, 32.691834568977356, 39.7068053483963, 20.351763032376766, 33.39848645031452, 62.000725865364075, 65.17694503068924, 31.24799944460392, 1.4253997011110187, 2.0544877694919705, 23.44390220940113, 64.15034651756287, 61.007497161626816, 62.8315094858408, 50.14334812760353, 54.60969686508179, 57.48169295489788, 58.600227534770966, 59.22518000006676, 37.46850125491619, 27.82668773084879, 23.66410419344902, 15.496470015496016, 19.62193999439478, 41.28965221345425, 59.60367389023304, 61.09742313623428, 62.2734410315752, 61.18934780359268, 62.21066839993, 59.300313368439674, 63.09066317975521, 59.82335910201073, 59.65014159679413, 58.4871532022953, 56.825608760118484, 55.58451555669308, 64.48795080184937, 60.333143547177315, 53.555770218372345, 59.25466261804104, 44.919707626104355, 13.573516700416803, 16.95795614272356, 34.236945658922195, 25.63990317285061, 17.41868332028389, 32.706129401922226, 21.318788342177868, 9.402332324534655, 20.308095775544643, 6.926392307505012, 0.7873423921409994, 0.13985844212584198, 0.07103427153197117, 0.05514517179108225, 0.07041717573883943, 0.14015371300047264, 0.030747614255233202, 0.1171003574563656, 0.045315006500459276, 0.19661308731883764, 0.12890545564005151, 0.06538357396493666, 0.02937241646577604, 0.16271372587652877, 0.7459824427496642, 0.10924343296210282, 0.17738366994308308, 0.11289260277408175, 0.02319422816071892, 0.05574095681367908, 0.06245534124900587, 0.06748460888047703, 0.07074246648699045, 0.05346381396520883, 0.04230753467709292, 0.02886855942051625, 0.07522468222305179, 0.029400729399640113, 0.12356182167422958, 0.1328846882097423, 0.5238677957095206, 3.2433040905743837, 18.08674067258835, 18.538325540721416, 37.11220197379589, 26.77127916365862, 11.154406908899546, 39.66454781591892, 16.79509498178959, 23.773982897400856, 51.24625414609909, 52.147527784109116, 46.90770015120506, 51.10646724700928, 53.14820408821106, 50.799580514431, 50.29768064618111, 51.255210265517235, 53.86493682861328, 49.955007433891296, 47.096553817391396, 52.363922372460365, 58.32460932433605, 56.42348013818264, 57.837205678224564, 51.26834616065025, 54.352139085531235, 46.766716316342354, 38.745023757219315, 25.12872990220785, 17.823255211114883, 13.901486601680517, 16.84001997113228, 28.882402181625366, 51.32906690239906, 50.892067551612854, 45.37127159535885, 54.202776700258255, 55.91957777738571, 54.36388425529003, 54.41804654896259, 57.08780989050865, 42.37612031400204, 6.26198323443532, 1.4032498584128916, 12.825220953673124, 74.43531543016434, 56.49618923664093, 51.60391375422478, 16.121286638081074, 24.08668141812086, 28.49485907703638, 31.53230208903551, 23.400816321372986, 28.783204704523087, 25.36295123398304, 26.204549074172974, 30.050223916769028, 30.655759423971176, 44.56408090889454, 20.206591822206974, 34.65256355702877, 69.67876866459846, 56.38142019510269, 2.5409597530961037, 0.04438545540324412, 0.1806772471172735, 0.030396012516575865, 0.056471990828868, 0.03427412375458516, 0.03468129194516223, 0.0455242810130585, 0.11700427159667015, 0.20789665606571361, 0.09643811266869307, 0.130365438235458, 0.06017288462317083, 0.1644723190111108, 0.18950411409605294, 0.21605553076369688, 0.12731920403894037, 0.22826261323643848, 0.11914066242752597, 0.303923218161799, 1.53158892178908, 77.04401984810829, 85.19128426909447, 68.35626482963562, 43.74950721859932, 65.94052165746689, 48.918001279234886, 42.853781282901764, 62.953669130802155, 55.87963052093983, 50.25552190840244, 36.68652601540089, 55.819825530052185, 12.123601902276278, 27.13786069303751, 63.179984986782074, 75.78880280256271, 28.61783567816019, 1.7167918151244521, 7.1178037114441395, 41.665030270814896, 73.16283971071243, 68.59518080949783, 70.15145570039749, 56.670425087213516, 57.19661325216293, 61.822534427046776, 62.11106434464455, 63.80217880010605, 40.236018151044846, 27.109272927045822, 25.772025883197784, 21.824467107653618, 27.443225607275963, 46.028985902667046, 63.61867904663086, 64.3975080549717, 64.33098882436752, 62.822116389870644, 66.13051146268845, 63.604543805122375, 66.26719012856483, 63.345564901828766, 64.35427397489548, 60.83738029003143, 61.29932530224323, 56.2373623251915, 66.01191982626915, 64.4717712700367, 59.61140647530556, 63.434582725167274, 58.275166377425194, 20.8763362839818, 16.680774316191673, 42.65050359070301, 37.65546642243862, 19.30105671286583, 32.889636754989624, 34.106867238879204, 13.14140198752284, 24.130460768938065, 13.582777753472328, 1.1740744183771312, 0.21476250170962885, 0.21033275581430644, 0.12316267238929868, 0.2326883070054464, 0.1859817624790594, 0.1348591424175538, 0.17825591610744596, 0.2694138261722401, 0.252398161101155, 0.1708463582326658, 0.13404275028733537, 0.1667304220609367, 0.2185380444279872, 0.9932874224614352, 0.18582877615699545, 1.2055588164366782, 0.24755324295256287, 0.12328316006460227, 0.15498532651690766, 0.14201420301105827, 0.13146346056601033, 0.17626477841986343, 0.16893537249416113, 0.3481852024560794, 0.2634975139517337, 0.2618317783344537, 0.14924376038834453, 0.1428977891919203, 0.19274994148872793, 1.1656399397179484, 9.814365115016699, 23.996609151363373, 20.652212910354137, 38.10438573360443, 29.640453904867172, 10.810932889580727, 36.62794075906277, 16.707116402685642, 35.55609807372093, 56.469465270638466, 53.81991304457188, 49.03920717537403, 54.84464205801487, 53.39053988456726, 53.359947726130486, 51.80807679891586, 55.649917647242546, 55.5601816624403, 52.759572342038155, 48.067777901887894, 53.926938101649284, 61.04763820767403, 59.94771122932434, 59.33212526142597, 52.514561489224434, 56.43108353018761, 53.472744673490524, 44.91622321307659, 33.37163709104061, 25.653407648205757, 19.930249750614166, 17.990235351026058, 27.495432905852795, 57.58001647889614, 55.31245015561581, 51.402497962117195, 61.552577912807465, 61.461037024855614, 61.726612374186516, 59.01218622922897, 61.670778170228004, 54.52339209616184, 22.520580254495144, 2.2788077825680375, 8.583543710410595, 76.0060903429985, 53.17424789071083, 57.87518844008446, 19.32219497859478, 25.622139126062393, 38.45421776175499, 40.20177438855171, 36.20751611888409, 49.2549329996109, 37.7726711332798, 36.10090523958206, 38.99456776678562, 47.623026967048645, 53.71924124658108, 34.0641575306654, 50.93499384820461, 74.91846710443497, 74.79208588600159, 3.7732165306806564, 0.27445648214779794, 0.32128867227584124, 0.10864353273063898, 0.1303757244022563, 0.18433122604619712, 0.299872457399033, 0.18542586418334395], [0.01936749951710226, 0.15357548341853544, 0.06025007911375724, 0.11449687372078188, 0.057663935658638366, 0.04341930529335514, 0.06844553427072242, 0.02751075015112292, 0.06145834006019868, 0.07457228246494196, 0.10195151291554794, 0.36275822203606367, 0.4309292952530086, 24.91134736686945, 75.17132073640823, 45.29656380414963, 38.16382214426994, 37.75298438966274, 57.960167080163956, 20.8607305213809, 42.72870719432831, 40.86183696985245, 32.16514863073826, 32.54700914025307, 46.88032642006874, 32.58359357714653, 8.397326152771711, 34.118050038814545, 62.942486330866814, 53.86252395808697, 6.809968454763293, 0.3178038139594719, 0.6569555948954076, 17.513720020651817, 56.860399693250656, 56.734223663806915, 58.3456601947546, 35.94453603029251, 53.394993245601654, 62.27334223687649, 49.524395540356636, 55.91241516172886, 41.21824264526367, 16.98378335684538, 6.645697094500065, 4.908139631152153, 21.596371047198772, 51.860928162932396, 59.09114599227905, 64.6038293838501, 64.82312321662903, 63.645224422216415, 61.454683765769005, 58.27684208750725, 55.188090428709984, 56.113595366477966, 54.18252758681774, 56.60776644945145, 65.88002890348434, 53.23234297335148, 51.730781346559525, 55.82261838018894, 38.57828490436077, 12.763309925794601, 23.47698513418436, 28.676468431949615, 25.12462992221117, 7.825378943234682, 8.08460483327508, 32.05810837447643, 9.642381593585014, 7.731032380834222, 11.476055849343538, 3.9677238184958696, 0.3544191538821906, 0.2801498828921467, 0.07527057663537562, 0.18622834846610203, 0.03929094185878057, 0.043197132254135795, 0.041879475029418245, 0.0642468263686169, 0.03837432639556937, 0.01836358893342549, 0.07102257528458722, 0.04375900112790987, 0.03183217588230036, 0.060140334026073106, 0.18577005743281916, 0.132930745894555, 0.021107722641318105, 0.10259060596581548, 0.0841364954249002, 0.12258704780833796, 0.07642600408871658, 0.12592669751029462, 0.08726494474103674, 0.03062678333662916, 0.017640176774875727, 0.023783458163961768, 0.11342698620865121, 0.056197607700596564, 0.13914424373069778, 0.04121843296161387, 0.17204145347932354, 0.2761531207943335, 14.865963198244572, 20.938337557017803, 18.34611665457487, 37.45531216263771, 10.247598867863417, 8.083011768758297, 38.61725181341171, 13.784059602767229, 21.41509797424078, 47.57118634879589, 52.633061930537224, 46.367661729454994, 45.96881613135338, 49.66284491121769, 53.879269659519196, 49.51122164726257, 48.92115890979767, 51.07918091118336, 51.561671420931816, 53.29070404171944, 51.7934437841177, 56.286668479442596, 53.28331723809242, 45.893025398254395, 43.62179987132549, 32.34250411391258, 17.751095183193684, 9.562662821263075, 5.450494978576899, 11.784419752657413, 22.17291411012411, 38.11121016740799, 48.47365692257881, 44.8098137229681, 52.00502783060074, 38.44894364476204, 43.642725348472595, 40.38275107741356, 45.32745234668255, 45.21800681948662, 10.92523455619812, 0.4152480710763484, 1.320562376640737, 38.89714099466801, 25.613771975040436, 34.10030119121075, 60.741640627384186, 14.117804244160652, 23.715317845344543, 33.69529612362385, 32.460784167051315, 35.71843296289444, 19.187214821577072, 30.043044202029705, 28.680832497775555, 27.209899127483368, 38.17097336053848, 18.428319543600082, 30.445685796439648, 39.92245517671108, 60.073932856321335, 21.515921764075756, 0.1749175725854002, 0.11894202660187148, 0.13143218646291643, 0.07225569817819633, 0.04336841251642909, 0.06146152016299311, 0.15639757417375222, 0.0474945977475727, 0.037148101764614694, 0.04447991224878933, 0.016756956101744436, 0.04553118298645131, 0.026040481388918124, 0.13307366869412363, 0.09565588159603067, 0.04606077214702964, 0.04804022471944336, 0.13475387619109824, 0.06693189439829439, 0.2832436887547374, 0.35820787714328617, 30.009864382445812, 87.57028341293335, 46.855582147836685, 35.987234339118004, 47.91526548564434, 35.46538174152374, 33.309297636151314, 34.89598989486694, 34.20030042529106, 34.51675124466419, 31.95691980421543, 48.56329791247845, 35.62601052224636, 22.12090440094471, 47.54592910408974, 71.2249892950058, 59.93647903203964, 15.438391081988811, 0.3404275031061843, 0.4933307640021667, 11.570014357566833, 58.9634158462286, 61.91289357841015, 63.93518686294556, 40.483282282948494, 57.341662868857384, 68.65888819098473, 52.9945707321167, 59.42714676260948, 46.01537123322487, 20.219324938952923, 6.983040142804384, 3.82656566798687, 18.78592975437641, 48.54728937149048, 60.28024658560753, 61.31192922592163, 66.56021520495415, 64.66151028871536, 64.9350044131279, 59.11098852753639, 59.42619301378727, 57.87584200501442, 53.062765672802925, 58.435232788324356, 64.80135798454285, 50.11525243520737, 53.897748067975044, 56.12908713519573, 40.88439255952835, 16.259770207107067, 30.282632745802402, 33.63495536148548, 24.53108087182045, 13.015867173671722, 9.673585519194603, 35.2481359988451, 9.552024342119694, 13.233091067522764, 22.989722080528736, 5.505640944465995, 0.22182563989190385, 0.1213348368764855, 0.005827201621286804, 0.11186550007550977, 0.11204510723473504, 0.08321010958752595, 0.1952704827999696, 0.11391197971533984, 0.14812718436587602, 0.019260455846961122, 0.1793319411808625, 0.036607617876143195, 0.08494568130117841, 0.22808480949606746, 2.052999436855316, 0.4074601217871532, 0.038136464354465716, 0.038219525522436015, 0.07421916860039346, 0.032006576875573955, 0.02750397990894271, 0.019863163252011873, 0.027572379949560855, 0.04220165246806573, 0.09288118439144455, 0.06814034830313176, 0.1269792261882685, 0.03264596307417378, 0.07984485579072498, 0.11485104885650799, 0.14713880693307146, 1.2675470276735723, 21.100134775042534, 23.183680772781372, 21.817971356213093, 42.50174157321453, 11.15953378379345, 14.271738734096289, 49.517115131020546, 21.452740654349327, 20.938759334385395, 45.2803348749876, 55.83387337625027, 52.007649689912796, 46.70379549264908, 49.88245792686939, 54.66273061931133, 52.471498399972916, 50.679909735918045, 51.02925918996334, 53.36573861539364, 54.4012476503849, 53.62730897963047, 58.13879929482937, 55.58111093938351, 48.26735459268093, 44.28023613989353, 32.00082644820213, 15.979753732681274, 7.768277507275343, 6.550849433988333, 16.21892049908638, 28.85768260806799, 41.44460029900074, 52.25869081914425, 49.56507995724678, 56.38141259551048, 42.874550968408585, 49.87282544374466, 43.3687524497509, 50.067428201437, 42.763570323586464, 7.805548757314682, 0.37508689798414707, 4.4765307661145926, 47.10630789399147, 33.75564448535442, 31.9099011272192, 54.61298368871212, 19.918352589011192, 24.9283704534173, 30.728141739964485, 32.41584397852421, 31.641097851097584, 28.580426685512066, 19.371808916330338, 35.36926589906216, 22.70749982446432, 42.2188201546669, 23.602889478206635, 22.446330338716507, 47.4516561627388, 69.76942420005798, 24.16961006820202, 0.25093111325986683, 0.16097046551294625, 0.12763975246343762, 0.0910486956126988, 0.03674465544463601, 0.028412930842023343, 0.08362209060578607, 0.044147726948722266, 0.31267735466826707, 0.22317666036542505, 0.30790394986979663, 0.40402926213573664, 0.1626592522370629, 0.2026213813223876, 0.18916795088443905, 0.12715986493276432, 0.18068254605168477, 0.24713922844966874, 0.19132659130264074, 0.5573173414450139, 0.549215879291296, 40.5507742613554, 97.33867764472961, 62.65061639249325, 47.71487183868885, 53.992435187101364, 74.49921280145645, 26.982739716768265, 59.02130573987961, 51.64578750729561, 44.68990355730057, 43.42932119965553, 67.54998609423637, 39.28419962525368, 13.513905499130487, 40.535411685705185, 70.50851494073868, 65.85662215948105, 14.201366510242224, 0.42392309464048594, 1.0068135685287416, 22.95055378228426, 69.64116588234901, 65.36527812480927, 68.71470719575882, 46.97644226253033, 64.12621781229973, 69.09198135137558, 63.66670846939087, 65.42469933629036, 51.324104368686676, 20.031975992023945, 8.45515239983797, 6.906825257465243, 24.412449337542057, 55.92189945280552, 58.19084890186787, 66.19743347167969, 68.84401425719261, 69.68400478363037, 65.69251656532288, 61.5321160107851, 60.70782244205475, 60.53560808300972, 55.35818450152874, 60.23647293448448, 72.23768055438995, 56.553011387586594, 57.18218542635441, 61.65913939476013, 51.660139337182045, 22.148179337382317, 29.29120894521475, 40.95101438462734, 30.58638844639063, 11.168604847043753, 10.340351890772581, 46.14369794726372, 17.408619560301304, 13.033874407410622, 29.0913662686944, 10.259168297052383, 0.4120524425525218, 0.31021060422062874, 0.10503521814825945, 0.24565487372456118, 0.278644718346186, 0.16120217886054888, 0.21052844531368464, 0.10610388111672364, 0.1469746883958578, 0.061930423908052035, 0.2475591207621619, 0.15128252911381423, 0.0960552683682181, 0.20896420581266284, 1.1927776085212827, 0.31326210766565055, 0.13356025039684027, 0.08669520539115183, 0.22935406013857573, 0.2055171228130348, 0.20566105493344367, 0.15416345733683556, 0.2936861221678555, 0.07633807443198748, 0.113660569768399, 0.16780888137873262, 0.24683560099219903, 0.14219458942534402, 0.20334402535809204, 0.2752732008229941, 0.16716886806534603, 2.3252401035279036, 29.14543926715851, 26.69913813471794, 22.453988827764988, 48.11583012342453, 13.515634406358004, 13.900577500462532, 45.72156339883804, 21.362237110733986, 27.46298834681511, 52.84187972545624, 58.914843052625656, 53.21416474878788, 50.572968274354935, 54.55976374447346, 56.67845405638218, 54.17336627840996, 53.61236058175564, 56.021119728684425, 56.35249614715576, 57.71442286670208, 56.495079696178436, 60.77591858804226, 58.05189035832882, 49.24428217113018, 49.18100416660309, 39.15649227797985, 21.62920318543911, 13.676323983818293, 8.225858453661203, 14.794335141777992, 25.5843273550272, 45.09111262857914, 56.7475039511919, 53.96796829998493, 61.642693877220154, 48.52841958403587, 55.10115869343281, 46.91692225635052, 55.03903202712536, 54.540475979447365, 16.83659065514803, 1.121814635116607, 2.5970687298104167, 45.9306737780571, 34.33534137904644, 40.59474550187588, 67.35357463359833, 20.44400878250599, 27.68964808434248, 43.35521377623081, 43.459559977054596, 51.68714828789234, 27.360486947000027, 40.363531708717346, 44.27895560860634, 32.90682703256607, 54.624402076005936, 27.527966760098934, 40.401613265275955, 57.848757058382034, 80.48869460821152, 36.8744221329689, 0.29155669268220663, 0.27200620737858117, 0.37292787164915353, 0.19274015998234972, 0.12415139121003449, 0.10358415616792627, 0.2159814050537534, 0.237448041443713], [0.06893220503116027, 0.08045364695135504, 0.11294749943772331, 0.042899545878754, 0.05602612334769219, 0.04809593032405246, 0.02199933514930308, 0.016502766811754555, 0.01895878951472696, 0.035405798771535046, 0.15022563660750166, 0.14411050302442163, 0.22994847589870915, 5.218877932056785, 70.51870599389076, 53.217565566301346, 42.148223742842674, 33.120652958750725, 58.740010634064674, 31.383346281945705, 31.533215939998627, 51.90128579735756, 31.658396422863007, 38.29847551882267, 37.52800986170769, 49.19729009270668, 18.48385166376829, 23.19495476782322, 41.91891364753246, 43.39266076683998, 53.74688856303692, 5.107852639630437, 0.06859402317786589, 0.5993310932535678, 14.461059775203466, 50.08489586412907, 58.84512819349766, 54.140015468001366, 47.938740625977516, 33.798452988266945, 44.691754058003426, 47.83446662127972, 55.19729733467102, 48.65200415253639, 18.09922870248556, 2.2606288455426693, 2.2241952130571008, 21.86517622321844, 63.17230939865112, 58.43331389129162, 55.715996101498604, 57.01198495924473, 57.998317033052444, 60.96892163157463, 61.936756297945976, 54.684849232435226, 56.224017441272736, 51.09687276184559, 41.72917082905769, 52.22914360463619, 47.06159949302673, 23.86431735008955, 17.67190933227539, 36.98935076594353, 26.63666758686304, 18.66801258176565, 7.755869748070836, 2.0286778919398785, 20.436167903244495, 17.478879690170288, 4.621321521699429, 7.879308499395847, 14.692428410053253, 3.0848366813734174, 0.3130533860530704, 0.0940521078882739, 0.05635586327116471, 0.018639298650668934, 0.07571101901703514, 0.052870949293719605, 0.08603157693869434, 0.1130419599940069, 0.046605764582636766, 0.03809114881732967, 0.1120766114036087, 0.041016279355972074, 0.16718077211407945, 0.05535295458685141, 0.12610893929377198, 0.027794124398496933, 0.0956871260132175, 0.029874967331124935, 0.03182787884725258, 0.04328500996052753, 0.10733042858191766, 0.0362404254701687, 0.07362914635450579, 0.03366793011082336, 0.01872522636404028, 0.1214154192712158, 0.08974312426289544, 0.014789569922868395, 0.061797282614861615, 0.03194728298694827, 0.17220631416421384, 1.3867543498054147, 13.09472244232893, 24.919051453471184, 10.274673365056515, 22.4991038069129, 33.35752084851265, 7.680527865886688, 10.163699369877577, 41.51095233857632, 18.699600286781788, 21.731913574039936, 38.43910217285156, 51.2549214810133, 51.61386922001839, 49.07325714826584, 44.2000300437212, 52.65951231122017, 56.11584484577179, 54.538443088531494, 49.260150119662285, 56.185403913259506, 54.78894084692001, 55.7506388425827, 53.76471720635891, 46.67503863573074, 32.81514175236225, 17.004342153668404, 5.619660476222634, 1.1946439021266997, 5.614587273448706, 34.500674307346344, 47.50778295099735, 53.169270157814026, 49.741363897919655, 48.70930127799511, 48.12724091112614, 50.98390482366085, 52.246132493019104, 55.69589138031006, 41.57407835125923, 11.263304315507412, 0.8262451796326786, 0.7013416069094092, 42.09102921187878, 54.12190563976765, 20.806904509663582, 47.70537614822388, 24.861076064407825, 11.476757861673832, 27.91767194867134, 34.60687480866909, 28.591850772500038, 25.278430469334126, 23.432854302227497, 41.231006160378456, 17.587095983326435, 36.64769969880581, 24.1707519069314, 25.596477203071117, 42.740581557154655, 46.26016929745674, 67.90941640734673, 6.55887745320797, 0.04733269081043545, 0.0841318495804444, 0.06476051872596145, 0.012473694387153955, 0.08573337458074093, 0.04335736193752382, 0.009407420347997686, 0.047409859325853176, 0.020601282922143582, 0.0488288419728633, 0.016100107168313116, 0.07347215243498795, 0.070921747101238, 0.14276418776717037, 0.05059538350906223, 0.07125986958271824, 0.06560784357134253, 0.1236131857149303, 0.12315012267208658, 0.12206496176077053, 0.15978178242221475, 6.8864422012120485, 79.34487238526344, 61.37858524918556, 33.17001610994339, 42.33516991138458, 41.86648026108742, 33.61654534935951, 41.95185787975788, 31.21467713266611, 33.0908739566803, 35.28987675905228, 41.48643225431442, 42.65723302960396, 27.94522427022457, 35.105586647987366, 50.440097004175186, 55.47769948840141, 61.956374645233154, 12.505214475095272, 0.49431719700805843, 0.1744937914190814, 9.618345033377409, 51.5252997726202, 61.132875233888626, 59.388354644179344, 52.32916183769703, 39.82355408370495, 51.471167877316475, 54.50813591480255, 58.90190474689007, 50.65552644431591, 23.598286025226116, 3.8702215254306793, 1.6229155962355435, 18.781147710978985, 63.86763408780098, 58.322253450751305, 56.88279189169407, 57.67359025776386, 57.876335978507996, 60.38314126431942, 60.434442311525345, 53.87756735086441, 56.00188136100769, 46.98870800435543, 45.66608637571335, 56.86452627182007, 48.76240722835064, 26.609419248998165, 22.76083566248417, 41.29671223461628, 35.014972910284996, 19.277900755405426, 22.000477463006973, 4.750293726101518, 18.42753678560257, 21.197217665612698, 6.6652764938771725, 14.827024787664413, 28.328684493899345, 9.12751967087388, 0.21477327769389376, 0.0840352442173753, 0.07219779581646435, 0.07642702083103359, 0.35983041976578534, 0.1720606305752881, 0.4223161964910105, 0.24261445796582848, 0.0641868682578206, 0.02632085179357091, 0.36813926766626537, 0.2121613928466104, 0.24037694209255278, 0.416686026728712, 3.83856566157192, 0.6452027068007737, 0.04728523417725228, 0.056209508038591594, 0.10745552499429323, 0.027061099572165404, 0.14375443541212007, 0.033254713416681625, 0.04131406240048818, 0.0538571707875235, 0.35795097530353814, 0.30075190239585936, 0.21223342570010573, 0.20333375403424725, 0.2541199140250683, 0.632729222998023, 0.24748003750573844, 5.400438364595175, 21.628213338553905, 27.62518834322691, 14.009340964257717, 26.947048231959343, 26.247450672090054, 12.451192773878574, 12.634247001260519, 46.9497486948967, 29.635500870645046, 24.772571213543415, 36.0155276209116, 49.59661826491356, 55.600033923983574, 50.522708371281624, 47.10966691374779, 52.74669103324413, 57.60144732892513, 56.473272666335106, 52.77695640921593, 55.277564227581024, 54.97015692293644, 57.166583463549614, 52.49679744243622, 46.661233976483345, 31.984365731477737, 17.157428339123726, 4.976165005937219, 1.969856454525143, 9.170214179903269, 40.17405107617378, 48.5929249227047, 53.05226683616638, 55.7743875682354, 54.33249033987522, 53.11603121459484, 55.094604045152664, 53.23601737618446, 57.883753180503845, 39.981093630194664, 6.7819003108888865, 0.5041312985122204, 2.2998805018141866, 49.394453912973404, 57.2775337100029, 24.880044646561146, 46.48367330431938, 32.363919764757156, 19.79333359748125, 26.854483298957348, 33.2656379789114, 24.76088684052229, 27.852969020605087, 19.62537121027708, 35.25300733745098, 25.267291367053986, 24.36972063034773, 34.11752566695213, 18.084242306649685, 39.81443837285042, 53.34734760224819, 78.56488823890686, 8.583330921828747, 0.2105593038140796, 0.10260218346957117, 0.10694909084122628, 0.09019840217661113, 0.11172649581567384, 0.07764954585582018, 0.09856725271674804, 0.09229080591467209, 0.12784378370270133, 0.15036513068480417, 0.11470980331068859, 0.11167269753059372, 0.1770560265867971, 0.2538509597070515, 0.08740672463318333, 0.10218475508736446, 0.16509944864083081, 0.22875955532072112, 0.4159429291030392, 0.28926099243108183, 0.46219268173445016, 9.493800066411495, 94.84461307525635, 70.32284930348396, 53.09377580881119, 44.0461914986372, 78.26424837112427, 41.283424347639084, 44.91967722773552, 69.1058886051178, 41.988537311553955, 50.90289317071438, 48.88058848679066, 63.07720050215721, 22.52125471830368, 31.34619377553463, 46.23794429004192, 53.66226710379124, 63.1598536670208, 10.880545154213905, 0.5656587844714522, 1.204461744055152, 20.302000902593136, 62.10473768413067, 70.42744249105453, 64.3352521955967, 59.30331900715828, 47.24454067647457, 58.07256504893303, 58.76894608139992, 64.47265282273293, 50.65167725086212, 22.71986436098814, 3.6190077429637313, 3.5235288413241506, 26.64737731218338, 70.29824942350388, 58.38295139372349, 56.40351600944996, 60.050985887646675, 60.66540911793709, 62.782465517520905, 64.63954746723175, 55.446522161364555, 59.21178951859474, 54.969157576560974, 48.637283742427826, 59.84475955367088, 55.73710396885872, 33.18852111697197, 24.10683173686266, 45.32556004822254, 38.07868391275406, 23.301105871796608, 18.24840109795332, 5.639692051336169, 28.566886112093925, 27.544596567749977, 9.781517777591944, 12.250042967498302, 34.135757088661194, 8.108421005308628, 0.3872980474261567, 0.22822329425252974, 0.24665876204380766, 0.12096742182620801, 0.25872977916151285, 0.1843221124727279, 0.2611936500761658, 0.260131488321349, 0.16184861917281523, 0.10981997038470581, 0.15550144569715485, 0.19700373901287094, 0.41624156932812184, 0.3271885385038331, 4.211034262552857, 0.17438894079532474, 0.24697956279851496, 0.1667847769567743, 0.16834160982398316, 0.1496253430377692, 0.22106897580670193, 0.12470801681047305, 0.14064991293707862, 0.14909559802617878, 0.1598081286647357, 0.1967350221821107, 0.2609848987776786, 0.14800204342463985, 0.29742434970103204, 0.3836491744732484, 0.5847528192680329, 4.956772271543741, 23.644128665328026, 31.95252723991871, 15.070290584117174, 31.536576859652996, 40.22320903837681, 13.119555059820414, 16.493296176195145, 46.448320001363754, 27.466305568814278, 30.63592828810215, 43.670543655753136, 55.16876846551895, 55.218712985515594, 51.6948276758194, 50.58309853076935, 58.18246275186539, 58.46799083054066, 59.0205267816782, 53.78371238708496, 58.92929367721081, 57.894343212246895, 61.35113552212715, 56.72150954604149, 50.731214582920074, 36.95495121181011, 20.950753390789032, 7.450112979859114, 2.650116733275354, 7.660748027265072, 38.7177450209856, 52.46905133128166, 61.80002823472023, 59.2900425195694, 59.28131818771362, 58.246474117040634, 60.05163185298443, 59.95330832898617, 64.08930659294128, 47.9840911924839, 13.394513055682182, 2.815728709101677, 1.803749199025333, 49.51700873672962, 61.143602058291435, 26.628646217286587, 49.64799910783768, 35.3526645898819, 16.816461235284805, 35.58996565639973, 45.841161981225014, 38.944919630885124, 36.27165287733078, 29.830533005297184, 61.49571016430855, 26.45084235817194, 45.136368200182915, 37.738579362630844, 33.77182401716709, 59.461990892887115, 60.092206075787544, 97.01333910226822, 12.952458076179028, 0.28435100277420133, 0.2237736142706126, 0.19336111494340003, 0.3100404149154201, 0.1843096295488067, 0.14541424869094044, 0.21363811829360202, 0.18612677813507617], [0.03510927737806924, 0.11542323729372583, 0.08638878745841794, 0.0031249273615685524, 0.09552074392559007, 0.025384276268596295, 0.08011082667508163, 0.04536677872238215, 0.03587763028917834, 0.004775206825797795, 0.08234755587182008, 0.13210565579356626, 0.4322326253168285, 0.3341300832107663, 43.69788318872452, 67.48187854886055, 36.58023811876774, 28.890984021127224, 52.722520530223846, 51.186464354395866, 23.361952006816864, 48.26702781021595, 34.20185834169388, 33.33062209188938, 38.063777312636375, 46.40037037432194, 37.59043291211128, 16.379125602543354, 36.6231644153595, 24.39000204205513, 33.76683488488197, 40.412032306194305, 5.400110632181168, 0.10522108161239885, 0.28839826059993356, 11.816304791718721, 46.912290304899216, 46.98575556278229, 65.43625071644783, 50.05909904837608, 56.099471524357796, 57.904025092720985, 45.49555152654648, 40.82655966281891, 33.878605887293816, 15.370117295533419, 0.7417771371547133, 0.6964458071161062, 16.248159930109978, 52.2652530670166, 61.15028589963913, 57.319806441664696, 60.29525578022003, 52.27857135236263, 48.63959401845932, 49.4308103621006, 46.27297081053257, 48.32348898053169, 53.330560103058815, 27.657125629484653, 18.48229754716158, 25.224129483103752, 44.28348496556282, 24.29900262504816, 12.867958210408688, 12.621517684310675, 4.105438878759742, 11.666477881371975, 13.348431028425694, 11.370230577886105, 2.3178029526025057, 8.294273782521486, 18.003565035760403, 7.587937759235501, 0.040971973139676265, 0.16606124234385788, 0.06613001867663115, 0.02741979438724229, 0.03423372865654528, 0.13095324888126925, 0.4736692534061149, 0.88998889666982, 1.1448922217823565, 0.40178859955631196, 0.5684190394822508, 0.26081162213813514, 0.1586550983483903, 0.5776062933728099, 2.936000805348158, 0.2300075360108167, 0.12852891959482804, 0.024235748933278956, 0.009199594878737116, 0.007341049295064295, 0.02751030300714774, 0.051187903081881814, 0.09380811941809952, 0.07645356745342724, 0.040371434661210515, 0.19210528233088553, 0.1827488632989116, 0.08536198904039338, 0.14956013794289902, 0.3566964785568416, 0.22418835607822984, 3.8629439659416676, 13.053139373660088, 23.37309490889311, 11.69194696471095, 8.844728395342827, 22.955727204680443, 20.533528178930283, 8.33447277545929, 12.028228919953108, 34.13814716041088, 24.044444784522057, 24.335305877029896, 23.56265913695097, 32.988062873482704, 47.918476313352585, 56.40743359923363, 48.56533460319042, 47.303171530365944, 55.2774578332901, 58.61422598361969, 54.60685081779957, 53.485306799411774, 53.46934765577316, 50.02128727734089, 27.212840169668198, 13.43866003677249, 4.368218053132296, 0.9538407891523093, 7.451214445754886, 37.46671535074711, 45.900761783123016, 46.094748973846436, 45.17540730535984, 43.00098158419132, 47.01641231775284, 47.47385837137699, 48.157639279961586, 39.371579736471176, 21.868900023400784, 7.0563676580786705, 0.07548287539975718, 0.09882718251901679, 25.393765680491924, 56.17197923362255, 31.035058870911598, 43.88982228934765, 58.04349660873413, 16.546915099024773, 15.877243783324957, 33.51827882230282, 29.976760558784008, 27.98761859536171, 19.882372319698334, 47.34671339392662, 20.369219295680523, 24.18191760778427, 41.05441063642502, 27.49371539801359, 34.68798145651817, 37.6545924693346, 59.90006558597088, 30.1768122240901, 0.39146948140114546, 0.10687995236366987, 0.03181915861205198, 0.029027525597484782, 0.051714204528252594, 0.06475981368566863, 0.05253253737464547, 0.05158796520845499, 0.052289554514572956, 0.05771929987531621, 0.02849557640729472, 0.0509046624210896, 0.08489362706313841, 0.10998034849762917, 0.1354689651634544, 0.020003328972961754, 0.016202391816477757, 0.015349107525253203, 0.04445158818271011, 0.14882015733746812, 0.008639394909550902, 0.26723416813183576, 0.32574482378549874, 51.65908679366112, 76.57921358942986, 34.88277420401573, 30.042210146784782, 56.864780858159065, 31.91452167928219, 36.071099638938904, 41.34405389428139, 28.207381702959538, 28.788028545677662, 37.828189954161644, 44.02573339641094, 35.66888742148876, 28.78422684967518, 35.32132767140865, 30.265261977910995, 45.47427646815777, 48.31776648759842, 13.2031724229455, 1.6122887539677322, 0.3538980771554634, 8.361513074487448, 48.054068237543106, 52.36923448741436, 68.71118098497391, 55.99896311759949, 60.06245747208595, 63.344208374619484, 48.65795463323593, 46.29532881081104, 38.52891035377979, 19.502303414046764, 1.2267053942196071, 0.7538481394294649, 12.368139680474997, 49.263015165925026, 57.73477077484131, 59.61347736418247, 61.3107854872942, 56.36614501476288, 50.250198394060135, 51.22561365365982, 47.15505927801132, 53.34417477250099, 53.71039152145386, 27.900475971400738, 19.00266632437706, 30.91020707041025, 43.83106604218483, 35.969785675406456, 14.907916747033596, 27.02006321400404, 7.789130313321948, 8.165187109261751, 14.645186495035887, 16.256751269102097, 7.440486196428537, 20.72787445038557, 27.78305847197771, 12.759786564856768, 0.4887120524654165, 0.3404595935717225, 0.04796196524694096, 0.18813209084328264, 0.2961702091852203, 0.15524639922659844, 0.30934674432501197, 0.17023151856847107, 0.37332325824536383, 0.5520156165584922, 0.9522715327329934, 3.302399469539523, 0.924556948011741, 1.42821345012635, 4.416912440210581, 0.8458446466829628, 0.051951328132417984, 0.08528243080945686, 0.055084508639993146, 0.049288632144453004, 0.06634870733250864, 0.07651705818716437, 0.2521351142786443, 0.07948973070597276, 0.32928237458691, 0.5116543604526669, 0.2080943196779117, 0.13380168587900698, 0.22008278028806672, 0.344282069709152, 2.2551029920578003, 12.9845274053514, 21.473960615694523, 27.523595094680786, 14.688062444329262, 14.764722380787134, 23.19331705570221, 21.01421568542719, 12.12315447628498, 14.065826833248138, 47.63301283121109, 30.689837895333767, 31.101830787956715, 25.880688652396202, 30.845348350703716, 46.22713766992092, 57.708715572953224, 51.05933457612991, 47.767202630639076, 53.55349414050579, 59.14815433323383, 55.92587783932686, 56.24750778079033, 54.517863392829895, 47.84171283245087, 26.61450907588005, 12.516923546791077, 3.3334623277187347, 1.7750685755163431, 11.510644443333149, 42.54899583756924, 48.50370571017265, 49.671029672026634, 50.277192145586014, 49.896969348192215, 50.98031401634216, 51.98166288435459, 51.532325595617294, 44.134160578250885, 24.49083913117647, 7.035899106413126, 0.15115698741283268, 1.1412395490333438, 37.2368922829628, 58.237916976213455, 36.28717504441738, 46.13623894751072, 67.9570734500885, 29.147029481828213, 22.657040432095528, 30.113988295197487, 29.46407876908779, 26.387879736721516, 25.172159671783447, 23.930625692009926, 32.06378147006035, 20.191603526473045, 39.57985416054726, 29.47875928133726, 23.020618222653866, 42.85608395934105, 67.07242012023926, 38.91164481639862, 0.7608862523920834, 0.08701609520358033, 0.11898369819391519, 0.060702403279719874, 0.08660870807943866, 0.06564014925970696, 0.07798031365382485, 0.04924703105643857, 0.07910829648608342, 0.24556241696700454, 0.1763376870076172, 0.16363807080779225, 0.25795833149459213, 0.25684279447887093, 0.1740210285061039, 0.15679419273510575, 0.15437528112670407, 0.05774999510322232, 0.23155558184953406, 0.34824187285266817, 0.21513477782718837, 0.5902537365909666, 0.4890770703786984, 64.8266114294529, 88.9848943054676, 51.61557912826538, 40.58212257921696, 71.0950818657875, 68.3956991136074, 33.183748573064804, 62.62265369296074, 42.143515795469284, 46.1209599673748, 51.43653653562069, 63.73355068266392, 45.27094557881355, 24.566920548677444, 44.1183116286993, 28.380107134580612, 46.27721518278122, 52.45980262756348, 10.917796455323696, 1.1996748321689665, 0.657762992195785, 14.956000316888094, 56.81985966861248, 54.14264872670174, 76.89779609441757, 60.97447693347931, 63.983968645334244, 66.46872371435165, 51.22747175395489, 50.93674175441265, 38.67609925568104, 19.083284698426723, 1.007508218754083, 1.7072614515200257, 20.307839289307594, 59.875940680503845, 61.24227896332741, 62.25199498236179, 61.47827669978142, 56.449432745575905, 51.980963721871376, 53.637192249298096, 52.803364992141724, 54.37111146748066, 63.891846388578415, 35.46578831970692, 24.411417692899704, 31.445797830820084, 52.92317256331444, 36.48053526878357, 16.070652455091476, 23.06746780872345, 6.189758609980345, 21.44153505563736, 22.572170086205006, 19.901145212352276, 7.7271869871765375, 16.62842072546482, 31.856738179922104, 14.756086394190788, 0.30536601261701435, 0.1317496327101253, 0.12351796816801652, 0.15340398793341592, 0.2782482927432284, 0.2926557540195063, 0.7344212068710476, 1.80587874725461, 2.751659397035837, 1.8310871883295476, 2.6428128127008677, 1.7711975332349539, 0.4220520512899384, 2.4167057080194354, 8.350230529904366, 0.6460854469332844, 0.21914522512815893, 0.1659195515094325, 0.11386656027752906, 0.1018152323376853, 0.10430009861011058, 0.18771052127704024, 0.21217156026978046, 0.15679499425459653, 0.19455502275377512, 0.4575303616002202, 0.5290574859827757, 0.14908522280165926, 0.24835738964611664, 1.0154719976708293, 1.2725543277338147, 12.304602339863777, 21.783680096268654, 31.296760328114033, 16.572960801422596, 14.547698926180601, 32.77021676301956, 27.45968822389841, 14.327493142336607, 18.922910504043102, 44.34312656521797, 34.23767901957035, 33.16716246306896, 31.05408065021038, 36.73526979982853, 54.158254489302635, 60.47880493104458, 54.0960556268692, 52.471110820770264, 58.147713616490364, 62.40261510014534, 58.38685758411884, 56.85875438153744, 56.900453343987465, 52.609472796320915, 30.487445555627346, 17.512595281004906, 5.661425460129976, 2.0015665842220187, 9.405126124620438, 41.38343498110771, 52.7470938116312, 51.47345535457134, 55.01250185072422, 54.671523347496986, 56.381389796733856, 56.217842772603035, 58.41425411403179, 48.762703612446785, 29.27317701280117, 10.511417761445045, 0.4051537049235776, 0.5317620502319187, 28.666976541280746, 65.36996707320213, 39.75967951118946, 47.590903490781784, 61.247781068086624, 24.335649758577347, 21.25661987811327, 41.86064377427101, 41.12203560769558, 39.628696739673615, 29.974110201001167, 61.379538998007774, 35.26481710374355, 31.593701094388962, 58.276393711566925, 37.94068671762943, 47.12862029671669, 51.90308690071106, 80.57263970375061, 58.48849073052406, 1.9425432826392353, 0.18603322299895808, 0.3901331702945754, 0.09631082692067139, 0.26794467063155025, 0.11840593622764573, 0.1128389232326299, 0.17758115543983877, 0.15814844897249714], [0.030313741735881194, 0.04907143891614396, 0.049113307177321985, 0.11865791020682082, 0.048496716044610366, 0.09064818819751963, 0.03222738807380665, 0.03117087035207078, 0.07209867457277142, 0.03971142788941506, 0.04634740071196575, 0.11896564916241914, 0.2905293821822852, 0.13029751688009128, 17.571856901049614, 74.76790398359299, 56.161795780062675, 38.713048473000526, 28.652554415166378, 60.764150619506836, 30.067961364984512, 31.340231895446777, 41.07192389667034, 28.102186247706413, 40.935598611831665, 34.55645151436329, 50.12894690036774, 24.439785070717335, 26.147001162171364, 34.86507475376129, 20.237335972487926, 57.87283256649971, 65.89034914970398, 3.6356548871845007, 0.4445160896284506, 0.6345281295944005, 18.039551004767418, 52.99181208014488, 52.53420263528824, 64.89954471588135, 44.80191394686699, 43.05976822972298, 51.02811545133591, 50.765370950102806, 49.11213666200638, 39.784799963235855, 21.27051193267107, 2.5036649918183684, 0.09225228845025413, 2.030849000439048, 18.27557533979416, 33.19491237401962, 41.643626019358635, 48.5334163159132, 52.97662429511547, 41.72511264681816, 42.00614936649799, 26.84781275689602, 7.727642012760043, 10.859778318554163, 31.46594624966383, 37.91628062725067, 19.444119036197662, 8.366048131138086, 14.335275124758482, 5.471483152359724, 17.87635926157236, 8.445442020893097, 7.481058994308114, 10.590892396867275, 2.4658981058746576, 14.977887142449617, 20.982293598353863, 6.276307515799999, 2.0187300257384777, 0.4583447944605723, 0.9028667618986219, 0.22031358821550384, 0.9502420853823423, 1.3435254944488406, 0.7243674213532358, 0.8590411010663956, 1.3601378467865288, 0.40517751302104443, 2.420928468927741, 0.7212229713331908, 0.5226432520430535, 0.506696873344481, 4.854222424328327, 1.9098966219462454, 0.09562257400830276, 0.12585227494128048, 0.14168194349622354, 0.05765415415226016, 0.03271487890742719, 0.04066181107191369, 0.1759144401876256, 0.038625892193522304, 0.06571454214281403, 0.27088805800303817, 0.3226092498516664, 0.6968954892363399, 0.35539406875614077, 0.1525821484392509, 2.52400791272521, 13.325743395835161, 14.558190163224936, 19.11242913454771, 14.590799063444138, 4.681595787405968, 16.092506982386112, 17.10841666907072, 6.971617005765438, 9.017000701278448, 11.346251014620066, 28.929318264126778, 26.179979592561722, 27.533677853643894, 21.060474403202534, 19.566132389009, 34.823539182543755, 55.511848255991936, 58.48056435585022, 53.057852536439896, 53.3637323230505, 57.29072280228138, 59.25354927778244, 43.851239159703255, 25.24930503219366, 8.917356748133898, 11.44968906417489, 2.1473564486950636, 7.293742345646024, 24.120530001819134, 51.97030529379845, 48.15886281430721, 44.1647033393383, 49.664478823542595, 48.953476175665855, 47.7439820766449, 46.5890758484602, 48.6954016238451, 42.78095439076424, 30.937970280647278, 8.382891677320004, 0.15941749181365594, 11.213526986539364, 60.87648779153824, 47.29634329676628, 28.939330726861954, 42.25398726761341, 35.02180874347687, 13.179070316255093, 25.342531129717827, 33.92998293042183, 31.125089339911938, 26.888787858188152, 21.953614577651024, 35.756898298859596, 16.346572749316692, 43.81925627589226, 30.467316135764122, 33.01150381565094, 27.189163640141487, 51.88335455954075, 40.4802006483078, 8.395751137286425, 0.12705724075203761, 0.21366139204474166, 0.07590677530970424, 0.1200134726241231, 0.054721138294553384, 0.07145871320972219, 0.06292085337918252, 0.09041648969287053, 0.0038276676923487685, 0.03241232756408863, 0.07367857338977046, 0.054481754850712605, 0.13735695916693658, 0.11944659054279327, 0.05996432257234119, 0.04915199533570558, 0.04690691326686647, 0.07951641833642498, 0.04542708564258646, 0.10423300103866495, 0.0680868468771223, 0.2781699813203886, 0.24398870766162872, 23.661037757992744, 83.34522932767868, 60.92634491622448, 25.005483515560627, 42.434557378292084, 44.26310285925865, 31.894257366657257, 37.96699270606041, 34.73495073616505, 28.9771443977952, 32.72131718695164, 36.798749193549156, 42.890852093696594, 30.70347536355257, 33.68328496813774, 34.76083114743233, 30.508608520030975, 63.74580502510071, 74.10070538520813, 8.325255420058966, 0.9505648305639625, 0.6262383400462568, 16.294825226068497, 53.40966045856476, 59.800332337617874, 63.868272453546524, 51.91946022212505, 49.09982532262802, 57.07891456782818, 56.119682639837265, 50.620062947273254, 43.920878022909164, 27.94875618070364, 5.590628609061241, 0.19920871913200244, 1.4858026849105954, 18.982913084328175, 32.18399181962013, 39.95698392391205, 45.50670772790909, 51.33571274578571, 41.22373715043068, 42.907495200634, 22.222455851733685, 5.793116418644786, 14.014174304902554, 38.924469128251076, 40.727016404271126, 29.667364060878754, 15.750677324831486, 25.591966845095158, 12.567690722644329, 9.823272787034512, 7.624462824314833, 11.464305929839611, 14.00249183177948, 10.174463242292404, 27.281677275896072, 28.86562418192625, 9.3729162029922, 2.6044398592785, 1.078635414596647, 1.334064833354205, 0.3499624680262059, 0.22087239573011175, 0.1996216204133816, 0.5924652179237455, 0.305254096747376, 0.6952166918199509, 0.362396469572559, 0.8162979071494192, 1.7234738753177226, 2.294480041600764, 2.0034308591857553, 1.035911813378334, 1.242997613735497, 0.05444727838039398, 0.22084882511990145, 0.2463022046140395, 0.13840904255630448, 0.0519556845392799, 0.23055032797856256, 0.25693600822705775, 0.08181506491382606, 0.15492938342504203, 0.45391357911285013, 0.709196972893551, 0.568875668104738, 0.2851791208377108, 0.15208637894829735, 1.534801886882633, 16.0301124304533, 22.057814486324787, 25.919611863791943, 18.515857346355915, 7.914270423352718, 19.541954286396503, 11.943278778344393, 15.702114030718803, 13.39873842895031, 18.969830386340618, 42.20599204301834, 28.726623840630054, 36.65658742189407, 29.13503162562847, 20.12700129300356, 30.06245356053114, 52.568089216947556, 59.26983140408993, 56.42661117017269, 55.94534419476986, 58.4133193641901, 56.004997193813324, 44.66228283941746, 21.82062741369009, 7.546405987814069, 13.81191210821271, 3.2708597369492054, 10.551311820745468, 30.55310793220997, 54.11531299352646, 53.38670589029789, 48.22339475154877, 53.38778883218765, 53.79000864923, 52.95299336314201, 52.02406480908394, 52.65347063541412, 47.77985215187073, 32.37281508743763, 7.076695617288351, 0.4423316818429157, 16.829283647239208, 64.29125055670738, 64.39853399991989, 29.561942517757416, 52.37144976854324, 42.8070779889822, 21.761747673153877, 26.048647239804268, 32.17457972466946, 27.487177848815918, 28.739322759211063, 19.801639951765537, 28.805207423865795, 23.92711468040943, 27.92230200022459, 37.59895585477352, 25.842779986560345, 25.77045276761055, 56.86725452542305, 54.43492144346237, 13.690367080271244, 0.1851310534402728, 0.3474253916647285, 0.0054127274506754475, 0.0859808808309026, 0.017929844434547704, 0.011936229184357217, 0.047428231191588566, 0.04566794967104215, 0.05091354963951744, 0.08968915528384969, 0.18175012548454106, 0.12800319702364504, 0.26191923301666975, 0.2537751419004053, 0.29388092109002173, 0.22928553022211418, 0.1313151794602163, 0.1386687794001773, 0.2461824071360752, 0.13833981502102688, 0.2272674228879623, 0.594330383464694, 0.4554729798110202, 32.753360867500305, 101.02480664849281, 75.0025337934494, 49.813138246536255, 43.27663019299507, 78.68161037564278, 41.074268370866776, 44.97062869369984, 52.52193309366703, 41.74620911478996, 55.14104515314102, 45.92623561620712, 65.60656517744064, 30.482845902442932, 34.93304930627346, 40.0545284897089, 26.781240329146385, 65.0742669403553, 81.14213034510612, 8.82703559473157, 1.3338199839927256, 1.7125068325549364, 23.110321909189224, 62.31534518301487, 66.38547018170357, 75.71466878056526, 56.63444101810455, 55.07931746542454, 58.6129454523325, 59.92022730410099, 53.36841747164726, 46.407210007309914, 24.40428927540779, 3.2225175434723496, 0.40264895651489496, 3.7887215986847878, 24.3228767439723, 38.15168559551239, 45.809426084160805, 53.44765841960907, 60.64030386507511, 45.697503089904785, 48.68146017193794, 33.883948400616646, 10.38622872903943, 15.592285674065351, 39.487686306238174, 50.945500284433365, 27.87079766392708, 12.87699792534113, 26.40211757272482, 9.132701642811298, 25.906346775591373, 19.710938818752766, 14.295378215610981, 18.42490542680025, 7.35949544236064, 23.262515142560005, 31.73366468399763, 11.0466199927032, 3.2868718402460217, 0.8039786119479686, 1.8762727011926472, 2.4678481137380004, 3.259329255670309, 3.7173041934147477, 3.525622054003179, 2.7083585830405354, 2.0438326662406325, 2.8349898755550385, 5.992810428142548, 5.22371269762516, 1.7046019504778087, 1.9694389519281685, 9.459398612380028, 3.508070558309555, 0.2637404634151608, 0.26298338372725993, 0.36712724540848285, 0.1404502455261536, 0.11780317130615003, 0.3551316453376785, 0.21640160906827077, 0.1381211041007191, 0.3670151811093092, 1.0072614694945514, 3.0687329079955816, 2.4492984591051936, 1.0231430735439062, 0.4077195469290018, 3.604602715931833, 17.382138781249523, 21.320528648793697, 27.869465835392475, 20.57354763150215, 8.836038261651993, 27.29890175163746, 22.70674366503954, 15.115283019840717, 13.756630774587393, 16.54551487416029, 36.984783411026, 36.20784290134907, 37.6382989436388, 31.46662451326847, 24.144259728491306, 40.804338455200195, 59.16102424263954, 61.737639382481575, 56.72295346856117, 57.303771302103996, 60.80367609858513, 63.25907774269581, 48.58255907893181, 27.217654511332512, 12.765823490917683, 17.002964727580547, 2.9971183883026242, 9.20253049582243, 30.098365433514118, 58.71960952877998, 55.4290658980608, 54.23134356737137, 56.58649519085884, 58.359160870313644, 57.64399744570255, 54.355551302433014, 57.09501050412655, 53.366395980119705, 36.20988339185715, 10.09641258046031, 0.6311131222173572, 13.918766174465418, 69.46951389312744, 55.494483187794685, 35.34951075911522, 46.7100765556097, 40.3231018781662, 18.988323993980885, 32.43475176393986, 44.849441796541214, 41.08890138566494, 37.80282251536846, 31.828562691807747, 50.43815150856972, 25.526853539049625, 54.658615440130234, 46.08506329357624, 41.38009116053581, 43.884099796414375, 67.2660805284977, 71.6286188364029, 21.99589680880308, 0.2672836248530075, 0.45027070271316916, 0.2302023200900294, 0.24692310020327568, 0.2361159902648069, 0.23706893756752834, 0.1080031409219373, 0.17166797508252785, 0.19224703253712505], [0.0620532419270603, 0.047571057511959225, 0.06997973163379356, 0.10527858321438543, 0.06540916321682744, 0.017692884102871176, 0.019683723076013848, 0.03745873138541356, 0.06565062838490121, 0.060678420777549036, 0.026615890747052617, 0.07424553710734472, 0.06091385970648844, 0.2644370432244614, 1.9771975418552756, 45.737389549613, 56.747017577290535, 48.50737251341343, 28.029484748840332, 45.195914804935455, 45.364177376031876, 27.11579717695713, 40.809817761182785, 22.944643199443817, 34.096338003873825, 35.20532749593258, 42.086062878370285, 37.685405015945435, 16.664524488151073, 24.477311857044697, 31.294277161359787, 14.53246459364891, 56.63058042526245, 45.51986262202263, 1.2246757093816996, 0.23108503053663298, 8.905503284186125, 53.63726444542408, 57.324126809835434, 54.050233885645866, 52.24020481109619, 48.84273871779442, 59.12276789546013, 46.02398917078972, 49.85671050846577, 45.057777017354965, 45.842526108026505, 27.864904180169106, 2.634193212725222, 0.6550648994743824, 3.772585764527321, 12.497145608067513, 15.823316127061844, 7.440493321046233, 1.4504328765906394, 2.911382638849318, 1.303671570494771, 0.08114682030281983, 15.768914446234703, 40.819875821471214, 28.45180168747902, 15.539633799344301, 8.666889388114214, 13.354519251734018, 9.820817168802023, 13.977608866989613, 17.490009292960167, 1.687881185207516, 7.585125910118222, 9.110955409705639, 5.526854256168008, 26.62528719753027, 23.875049874186516, 12.536566592752934, 3.111904291436076, 3.1029469845816493, 2.3905569361522794, 1.0125152813270688, 0.7048130175098777, 0.0654975678480696, 0.061948038783157244, 0.010002322214859305, 0.14747942303074524, 0.16287679056404158, 1.7562993639148772, 7.319457940757275, 2.0765821589156985, 0.3395493049174547, 2.5415330473333597, 4.262647368013859, 0.275629639509134, 0.32615923904813826, 0.3667185892118141, 0.14146847213851288, 0.10746569241746329, 0.10936121179838665, 0.4571807209867984, 2.2309094527736306, 2.4115006998181343, 0.5424563982523978, 0.1581078683375381, 0.0339120150601957, 0.044192263230797835, 0.03776655939873308, 0.8198973827529699, 13.003260400146246, 17.077480629086494, 22.36496150493622, 19.70324993133545, 4.281826838850975, 4.747534599155188, 18.556494265794754, 5.809566210955381, 6.931198099628091, 8.40434342622757, 3.184592965990305, 21.381418481469154, 18.39639935642481, 24.462509751319885, 26.1120031401515, 21.692448891699314, 19.59785308688879, 38.21289271116257, 42.5582255423069, 56.612189412117004, 47.25010357797146, 35.30761040747166, 18.10945775359869, 6.7072271928191185, 0.3683535405434668, 2.133969529531896, 9.629185851663351, 22.013822346925735, 48.909751921892166, 43.091906905174255, 44.85589765012264, 49.548919424414635, 47.235831543803215, 48.92424814403057, 50.59074752032757, 51.06705576181412, 46.80498406291008, 50.7085108011961, 26.763274893164635, 2.8917619166895747, 1.388115151785314, 48.100535944104195, 15.528450049459934, 26.09504844993353, 43.52449469268322, 17.276114970445633, 28.3048502728343, 16.035620234906673, 33.515770956873894, 29.053723588585854, 34.209058955311775, 17.579144909977913, 30.44970978051424, 23.900012634694576, 31.350037269294262, 42.82809466123581, 36.80404230952263, 27.657408714294434, 30.176570937037468, 59.54156242311001, 36.92869082093239, 2.4207033310085535, 0.0779635262733791, 0.22093843203037977, 0.05066570571216289, 0.21540868969168514, 0.038568720847251825, 0.017277667320740875, 0.030024979496374726, 0.029885670955991372, 0.023586343741044402, 0.0931654121086467, 0.05170317250303924, 0.036614720229408704, 0.024971573511720635, 0.008129396592266858, 0.018309690458409023, 0.0428535327228019, 0.10668234812328592, 0.053722185257356614, 0.019408013358770404, 0.04729016945930198, 0.013807632476527942, 0.059146316270926036, 0.22990525321802124, 2.8338337875902653, 55.11505834758282, 70.24781852960587, 38.74463617801666, 28.580762967467308, 51.401202231645584, 33.74582201242447, 33.8903396576643, 40.00475496053696, 28.33343993872404, 28.143436834216118, 33.409346267580986, 42.50637352466583, 33.61092545092106, 27.506254725158215, 25.649220272898674, 32.134970650076866, 24.39627170562744, 58.14113236963749, 49.623334631323814, 2.6605355367064476, 0.29977179248817265, 9.366433750838041, 57.07178995013237, 61.18384949862957, 61.73184469342232, 57.73449718952179, 52.9731360822916, 61.825604662299156, 52.185780331492424, 55.31575597822666, 50.13797901570797, 48.94504062831402, 32.75827020406723, 4.464819319546223, 0.18011493666563183, 12.675238251686096, 28.4716784209013, 26.421954408288002, 16.514090560376644, 5.277908714488149, 6.788038406521082, 0.6709189550019801, 0.542744054691866, 22.221289314329624, 47.53323778510094, 33.46130087971687, 22.723846547305584, 19.178030714392662, 21.935626342892647, 15.72390016168356, 13.467565085738897, 10.803765524178743, 5.135525604709983, 11.580724082887173, 11.48733364418149, 13.868720959872007, 31.816040463745594, 32.62904293835163, 15.076615344733, 1.6388253425247967, 0.21580643631750718, 0.6625649251509458, 0.39369500416796654, 0.4563908383715898, 0.04603084875270724, 0.03076467437495012, 0.07101144306943752, 0.06818543377448805, 0.0800991452706512, 0.3425357962260023, 2.116324226371944, 2.9789610626176, 0.4293365275952965, 2.619877243414521, 2.1617738250643015, 0.26778959145303816, 0.1580831696628593, 1.080456585623324, 0.18719824642175809, 0.4646971926558763, 0.13188989862101153, 0.14344213966978714, 1.1592867993749678, 0.8848095370922238, 0.09775837854249403, 0.07506188470870256, 0.06905560934683308, 0.06828717479947954, 0.07535012744483538, 1.0500307870097458, 17.86985971033573, 22.4163119494915, 28.662093803286552, 26.957290582358837, 8.647532276809216, 8.925619404762983, 10.50738237798214, 9.834133554250002, 11.520615108311176, 12.310406528413296, 12.936854213476181, 31.723405234515667, 21.9947549700737, 32.19621956348419, 36.7740923166275, 26.109966449439526, 22.186338789761066, 34.67290386557579, 39.503755643963814, 53.16368445754051, 46.9755645096302, 34.45071078836918, 16.10225535929203, 7.8932699002325535, 1.0260180942714214, 1.007603332400322, 10.815281756222248, 28.99627637118101, 51.91973000764847, 46.74175925552845, 47.31777794659138, 52.310318648815155, 53.043728694319725, 52.250376865267754, 54.93295691907406, 54.82203707098961, 53.050271943211555, 56.44648790359497, 28.105094991624355, 1.736335710156709, 2.6479140389710665, 50.51427662372589, 15.228122714906931, 33.424180671572685, 51.189720779657364, 24.62009109556675, 27.491274029016495, 24.871905483305454, 28.892445042729378, 31.531549729406834, 26.317346021533012, 21.475539430975914, 21.691147461533546, 34.759508818387985, 26.149858608841896, 34.52307790517807, 42.70362474024296, 23.035940900444984, 35.222920551896095, 67.68539562821388, 47.880041375756264, 2.341089528053999, 0.027313140344631393, 0.2810014825081453, 0.023316836523008533, 0.1219902052253019, 0.03023279939952772, 0.046837388872518204, 0.03798135177930817, 0.04822792499908246, 0.08635842619696632, 0.23955474636750296, 0.22283978469204158, 0.16656076710205525, 0.26349956227932125, 0.18927746219560504, 0.0763682130491361, 0.11235188139835373, 0.31093309982679784, 0.15899853460723534, 0.17274864600040019, 0.12077955456334166, 0.2321726331138052, 0.19794919062405825, 0.47023560327943414, 4.802136244252324, 74.25723418593407, 81.83539554476738, 62.09832362830639, 40.698871314525604, 62.61338219046593, 61.095382645726204, 40.0497255474329, 56.39684736728668, 30.71968149393797, 50.90000532567501, 44.60463233292103, 58.25366333127022, 44.56879265606403, 25.300157703459263, 30.309018529951572, 35.57887405157089, 23.510113656520844, 63.633494451642036, 55.265131294727325, 4.11413281224668, 0.49011438502930105, 10.806028302758932, 63.94972488284111, 64.10894393920898, 67.14874282479286, 63.57113979756832, 60.65465569496155, 68.22644099593163, 55.012995824217796, 57.68637657165527, 53.92308130860329, 50.9951826184988, 34.415205493569374, 4.552715253084898, 0.8634186442941427, 7.808696888387203, 22.822306863963604, 21.999449618160725, 13.103724159300327, 2.535172188654542, 4.684960031881928, 2.658086330629885, 0.5884059076197445, 19.724017716944218, 50.8538644015789, 39.448909386992455, 21.16889588534832, 13.969226516783237, 24.00364827364683, 13.341023325920105, 24.322586059570312, 26.477644219994545, 7.385724009945989, 16.311776116490364, 12.974638435989618, 10.067616775631905, 31.5706230327487, 37.81758092343807, 17.499130703508854, 3.8145606871694326, 4.1261225938797, 4.421528717502952, 2.0147675508633256, 1.3937177136540413, 0.1425038423622027, 0.19908163376385346, 0.11975760979112238, 0.5029507493600249, 0.2705872507067397, 2.0354310795664787, 17.787421233952045, 5.596655085682869, 0.3966723819030449, 3.691480066627264, 6.624565003439784, 0.6938924035057425, 0.30790602788329124, 0.44349260861054063, 0.2815401926636696, 0.3089083725353703, 0.3602326341206208, 2.3862318182364106, 4.257405549287796, 5.794272981584072, 2.5433816481381655, 0.4440244910074398, 0.38364151550922543, 0.2574577974155545, 0.17904372070915997, 0.7761400588788092, 18.30880645662546, 20.984381586313248, 33.265995159745216, 25.776716731488705, 9.990885592997074, 10.314999651163816, 26.85093428939581, 11.77961966022849, 11.669204235076904, 12.224330697208643, 8.520595338195562, 25.41113644838333, 26.307958625257015, 37.71177180111408, 37.338753417134285, 28.726186864078045, 26.660441011190414, 42.02554352581501, 48.28294895589352, 62.609814181923866, 52.761802822351456, 41.10521011054516, 21.307157166302204, 9.740905556827784, 1.8921115575358272, 3.9371010242030025, 13.036157134920359, 27.633390203118324, 54.207192063331604, 48.949832171201706, 50.42574517428875, 56.69408641755581, 56.627350598573685, 55.66855184733868, 58.15480403602123, 59.87621806561947, 55.95630660653114, 59.902497455477715, 33.9418762922287, 4.277730183675885, 2.5581664172932506, 47.92372763156891, 19.678036384284496, 35.21870277822018, 56.95593796670437, 21.02797854691744, 36.21420755982399, 24.11665800958872, 43.10545317828655, 39.75101977586746, 45.691320821642876, 27.210651487112045, 43.7310516089201, 38.72514322400093, 40.63040278851986, 58.495653346180916, 52.48648099601269, 41.01386301219463, 47.87846826016903, 75.01080214977264, 66.20974481105804, 3.571268292143941, 0.11837541169370525, 0.3847676207078621, 0.19782768620643765, 0.4832306387834251, 0.1282926939893514, 0.17277899984037504, 0.10247073427308351, 0.14284656615927815, 0.23670402355492115], [0.042880090477410704, 0.011222931570955552, 0.014669880056317197, 0.0512596798944287, 0.08544092386728153, 0.052835259411949664, 0.041383779753232375, 0.026030187800643034, 0.08489804284181446, 0.03451695818512235, 0.006621618294957443, 0.044664985325653106, 0.01815190800698474, 0.2472745071281679, 0.31308651552535594, 10.386089086532593, 50.6480560451746, 59.04850848019123, 43.94410237669945, 31.381877660751343, 53.94218288362026, 29.21331312507391, 42.08743080496788, 27.78857957571745, 29.848542138934135, 39.51071687042713, 37.76687264442444, 42.31080561876297, 31.80998168885708, 21.000055745244026, 37.91512928903103, 43.19684587419033, 25.87510485202074, 55.19640438258648, 29.893535524606705, 0.7940941548440605, 2.9614152666181326, 26.540990620851517, 48.74023921787739, 55.74650086462498, 61.100390776991844, 59.25828002393246, 54.38889071345329, 44.32786278426647, 51.20516695082188, 48.43598574399948, 55.615119114518166, 44.221506491303444, 14.80563098564744, 0.48850431048776954, 2.4971234053373337, 2.480853865854442, 15.136387087404728, 1.0184185020625591, 0.870685635600239, 3.334431038238108, 3.4464022424072027, 34.76791776716709, 40.90987019240856, 21.73617124557495, 12.703596130013466, 7.731953356415033, 11.455028727650642, 10.64265701919794, 22.383181527256966, 22.935132309794426, 6.183390626683831, 3.75550449360162, 8.427464235574007, 6.667226739227772, 15.372580513358116, 37.29248329997063, 25.418255366384983, 16.031113676726818, 0.37249255750793964, 0.0715836463496089, 0.2075683744624257, 0.10480130062205717, 0.11881998041644692, 0.057636394558358006, 0.2282927741180174, 0.04124073078855872, 0.12238156938110478, 0.042470005646464415, 0.07646567188203335, 0.6173443235456944, 3.233299939893186, 2.173272483050823, 3.9049333753064275, 1.9817707152105868, 0.3101135016186163, 0.12864537740824744, 0.5430530849844217, 0.7673495274502784, 0.21185963560128585, 0.04986905842088163, 0.6453705509193242, 0.20749660878209397, 0.03584155820135493, 0.15667175321141258, 0.05754771533247549, 0.09146764539764263, 0.14177667122567073, 0.07778235318255611, 2.063436764292419, 10.584314949810505, 12.334499135613441, 21.697515919804573, 28.828627467155457, 12.175911795347929, 1.3806928438134491, 8.481031861156225, 12.242697961628437, 11.70398946851492, 14.378180522471666, 14.049877189099789, 3.009510235860944, 10.293886084109545, 13.59544437378645, 11.886591520160437, 27.851939275860786, 30.894352421164513, 19.397444240748882, 15.511530507355928, 11.822848990559578, 8.382075671106577, 11.805579867213964, 2.9264447931200266, 0.620599027024582, 2.715211515314877, 0.9574229281861335, 10.302703510969877, 34.30506080389023, 51.82382695376873, 47.78321877121925, 49.148930087685585, 57.95461177825928, 45.10084770619869, 54.86762322485447, 48.39131534099579, 56.33104629814625, 49.259583950042725, 55.27132496237755, 21.947422809898853, 0.7646024529822171, 5.2332653850317, 58.88274997472763, 72.3416505753994, 60.492263808846474, 17.947647236287594, 31.07374269515276, 29.384227953851223, 23.06676484644413, 37.54327744245529, 33.430628925561905, 32.52116672694683, 27.126159220933914, 34.791966676712036, 18.6288233846426, 49.92402769625187, 75.15007987618446, 30.446972027420998, 29.15418829768896, 47.63543330132961, 65.77249467372894, 15.901142600923777, 0.3857394779333845, 0.16809824475785717, 0.3325851395493373, 0.05587142637523357, 0.0547354543232359, 0.03238656390749384, 0.045718044639215805, 0.12314254534430802, 0.04543790615571197, 0.02125350270944182, 0.06903043569764122, 0.07907963474281132, 0.08659305618493818, 0.0503530017886078, 0.0552536292525474, 0.05556907912250608, 0.029293986299308017, 0.028013165574520826, 0.06307596966507845, 0.017868084760266356, 0.043869106157217175, 0.059613939811242744, 0.023702905455138534, 0.2526965638389811, 0.27084311353974044, 17.794640846550465, 64.0112055838108, 61.020066887140274, 28.190075531601906, 38.62086541950703, 45.950827896595, 33.99051368236542, 41.33346766233444, 30.850054398179054, 30.452217645943165, 27.694916501641273, 40.702131539583206, 36.97575129568577, 36.76233194768429, 28.468245305120945, 35.92805631458759, 42.131424844264984, 29.242030084133148, 57.5069236010313, 39.95432786643505, 3.4997471049427986, 3.0337199242785573, 26.790939308702946, 47.63716980814934, 61.285915821790695, 62.30506673455238, 62.45493449270725, 59.60791826248169, 49.69184875488281, 56.456181183457375, 53.50505813956261, 59.72140297293663, 48.091317638754845, 18.02360326051712, 2.105302680283785, 6.305344132706523, 5.721745798364282, 25.091064423322678, 5.256281225010753, 3.563179951161146, 3.013487197458744, 4.773905659094453, 43.69210749864578, 45.39502412080765, 32.07790531218052, 19.127875305712223, 19.202205017209053, 18.74065138399601, 11.980307791382074, 25.458981581032276, 16.838112473487854, 8.02491383627057, 6.71562141738832, 11.412676200270653, 12.025899644941092, 23.738489001989365, 36.75386980175972, 32.075260654091835, 13.255332224071026, 0.8640601567458361, 0.1164399202389177, 0.10408440080936998, 0.13595291966339573, 0.0840152359160129, 0.10557841829722747, 0.22511816321639344, 0.08140743288095109, 0.08334775571711361, 0.02050107443210436, 0.013350064109545201, 0.06519506103359163, 1.5732700726948678, 0.12204099781229161, 2.8305685753002763, 1.8444235227070749, 0.05998478358378634, 0.3532784729031846, 2.433648048900068, 3.556621978059411, 0.4795681103132665, 0.5994759604800493, 0.2494806598406285, 0.07555850024800748, 0.020007128769066185, 0.1650917303049937, 0.04638856764358934, 0.12379085586871952, 0.03835124189208727, 0.03551910616806708, 1.5683442307636142, 4.470294350758195, 15.086101535707712, 24.206388294696808, 33.39774169027805, 15.658155139535666, 5.619003586471081, 6.1851912550628185, 7.2053272649645805, 13.511010054498911, 15.351996067911386, 15.353166405111551, 12.698220368474722, 23.733499869704247, 19.44144207984209, 18.440205305814743, 36.028275936841965, 37.528291046619415, 25.968948416411877, 18.66164982318878, 10.236087385565042, 6.454050578176975, 13.522130157798529, 4.384154872968793, 0.989644427318126, 6.037312215194106, 1.9884033780544996, 13.274850826710463, 40.23487061262131, 52.781071588397026, 48.960824981331825, 53.80387410521507, 61.21752329170704, 49.68054436147213, 58.117512837052345, 54.70234349370003, 60.02281419932842, 55.967926383018494, 58.69906783103943, 29.168093651533127, 1.780924298800528, 7.207952449098229, 66.3717757165432, 64.89691525697708, 54.36327248811722, 18.68466328829527, 26.70308232307434, 30.30650496482849, 24.783942103385925, 34.338449612259865, 29.938471913337708, 27.71972917020321, 21.241405494511127, 30.364563949406147, 27.367231585085392, 33.31338621675968, 83.46123710274696, 29.843439012765884, 26.21545258909464, 54.09370735287666, 71.53263598680496, 17.338028848171234, 0.25054561207070947, 0.2520741691114381, 0.2302061050431803, 0.09728067292599007, 0.02398509968770668, 0.0355822443816578, 0.04935216740705073, 0.09998967521823943, 0.04768129983858671, 0.041080545634031296, 0.2604914002586156, 0.20651482162065804, 0.30327879649121314, 0.2248519696877338, 0.22135960083687678, 0.2114209224237129, 0.12025378746329807, 0.08066515903919935, 0.18472460884368047, 0.12318180495640263, 0.1601118451799266, 0.1979062202735804, 0.06056479054677766, 0.5411458248272538, 0.45798476377967745, 27.924160100519657, 78.66772592067719, 73.62371698021889, 58.425379917025566, 41.384407728910446, 71.65293753147125, 42.38626956939697, 58.69010031223297, 34.64276768267155, 45.79384692013264, 52.00918100774288, 52.9252814501524, 55.38194842636585, 38.82580742239952, 30.846248902380466, 45.94671651721001, 49.876553043723106, 36.13949216902256, 63.09643127024174, 38.3992575109005, 3.2167487405240536, 5.249841520562768, 34.814826250076294, 59.32187721133232, 68.22889566421509, 72.93663784861565, 63.986696898937225, 67.39194497466087, 50.091583505272865, 61.82809732854366, 54.682147577404976, 64.879010617733, 50.38872376084328, 21.211761385202408, 1.3855824689380825, 4.618425602093339, 4.095875741913915, 23.317163810133934, 2.972486447542906, 3.408478139899671, 8.22356527671218, 4.9885281175374985, 40.91189548373222, 57.40914724767208, 31.505798511207104, 21.02079503238201, 12.629365213215351, 20.444194972515106, 12.592236455529928, 34.662120044231415, 32.40284867584705, 13.915773835033178, 7.298941891640425, 13.262090161442757, 10.073553957045078, 21.08802292495966, 46.13775506615639, 32.78615690767765, 23.815054893493652, 1.1608049366623163, 0.3014188556699082, 0.387576263747178, 0.29723997053224593, 0.1906673118355684, 0.2217371462029405, 0.39537751232273877, 0.23921150306705385, 0.19535844214260578, 0.09441084723221138, 0.28143697476480156, 1.2641339795663953, 6.372728766873479, 8.031808566302061, 7.908080080524087, 2.58400313090533, 0.7833479752298445, 0.20588629675330594, 0.5727803148329258, 1.704344276804477, 0.6104729266371578, 2.1430059196427464, 2.1907456079497933, 0.17785435484256595, 0.23465412261430174, 0.31934816390275955, 0.14640155743109062, 0.33332553575746715, 0.2749828726518899, 0.16761604172643274, 4.438424035906792, 20.712217390537262, 20.445000529289246, 30.621451064944267, 33.7913853675127, 16.222330816090107, 6.476884977892041, 14.742167741060257, 20.856839530169964, 20.8356898650527, 18.09707421809435, 17.139134220778942, 6.260383520275354, 17.817794904112816, 19.76498331874609, 20.80534089356661, 43.642485961318016, 40.86507439613342, 29.746035039424896, 21.60420812666416, 15.05744632333517, 10.960898492485285, 18.909791707992554, 7.872716328129172, 0.8999745827168226, 4.940694384276867, 2.888334500603378, 13.042503744363785, 42.97365345060825, 58.06827127933502, 52.69901119172573, 57.54751682281494, 65.56349068880081, 54.9829014390707, 64.88684579730034, 58.95000636577606, 65.97205996513367, 60.72821594774723, 66.00736007094383, 27.82797396183014, 1.5266081015579402, 7.981433719396591, 69.50904697179794, 77.12414234876633, 71.56084567308426, 24.82375256717205, 39.105689004063606, 40.6002514064312, 31.363509446382523, 47.9757734388113, 44.86798480153084, 42.62113116681576, 36.79070882499218, 50.71535803377628, 30.103764943778515, 60.50623565912247, 96.88079461455345, 40.703339874744415, 43.743860721588135, 60.77015809714794, 90.95669969916344, 29.968900680541992, 0.5038315895944834, 0.44572246551979333, 0.3898201324045658, 0.16391889948863536, 0.10070040778373368, 0.20679193956311792, 0.15401036711409688, 0.3985430096508935, 0.2990800514817238, 0.19906909146811813], [0.026741124456748366, 0.07808805123204365, 0.09917107148794457, 0.009502216726104962, 0.07625220794579946, 0.04303996764065232, 0.04062030275235884, 0.08121096412651241, 0.08666284775245003, 0.005570493667619303, 0.04117140306334477, 0.07664611766813323, 0.049000556391547434, 0.13443700881907716, 0.20936857239576057, 3.07339858263731, 54.45353664457798, 54.14811283349991, 52.62960411608219, 32.18578912317753, 42.81471937894821, 38.8812692463398, 40.93978598713875, 40.99362149834633, 22.632315158843994, 36.98533818125725, 38.025779351592064, 39.13764148950577, 35.088631957769394, 26.23867504298687, 30.233396887779236, 53.186015859246254, 52.23278760910034, 50.1016491651535, 55.37664011120796, 23.26061524450779, 1.1775685683824122, 5.946061061695218, 43.31229507923126, 53.96968960762024, 57.94241063296795, 57.312062457203865, 60.50392158329487, 56.022020280361176, 56.05510510504246, 42.75386564433575, 42.83431492745876, 53.853628635406494, 25.840089730918407, 2.83895923756063, 8.485585916787386, 10.647970084100962, 5.817592330276966, 21.939846016466618, 12.055541854351759, 17.835382260382175, 40.93339093029499, 36.4138488471508, 18.851003162562847, 11.715492401272058, 11.05600168928504, 9.507580976933241, 15.406281854957342, 20.659654811024666, 30.35370033234358, 9.264131840318441, 7.85073640756309, 3.0587717425078154, 12.340720351785421, 4.979427130892873, 28.74217640608549, 35.23050494492054, 23.860901333391666, 2.0799497282132506, 0.6447258917614818, 0.10404098517028615, 0.2200474837445654, 0.03916830937669147, 0.030830749637971167, 0.13532335578929633, 0.06364256973029114, 0.11334025140968151, 0.052339092871989124, 0.09882541620754637, 0.06997256248723716, 0.18499691766919568, 1.3665314787067473, 0.660875856410712, 1.0648495168425143, 1.7331742797978222, 0.5038058222271502, 1.5095008257776499, 8.603675980120897, 3.730200701393187, 0.7553240633569658, 0.0450004620506661, 0.0387648593459744, 0.20105426228838041, 0.10011637466959655, 0.09291203547036275, 0.015541292232228443, 0.1090619110618718, 0.24337443202966824, 0.22694930870784447, 0.07529704162152484, 0.8725785277783871, 6.885088523849845, 16.609397046267986, 38.44635598361492, 21.1368940025568, 0.4479381919372827, 4.5025992672890425, 6.962365452200174, 11.79440276697278, 15.238881837576628, 22.49736350029707, 14.110009912401438, 5.4218867886811495, 8.963978346437216, 15.010452345013618, 10.668749269098043, 17.873507514595985, 27.81290017068386, 28.58943410217762, 12.520197071135044, 0.9264672955032438, 0.5633081949781626, 1.041190205141902, 2.082313201390207, 1.5526186558417976, 0.4467267991276458, 16.338515281677246, 42.21028581261635, 47.61776424944401, 40.99189639091492, 48.833740800619125, 48.98981362581253, 49.13098745048046, 44.85375076532364, 50.091214925050735, 48.83422337472439, 49.8433618247509, 31.472424902021885, 10.965809728950262, 1.5103563736192882, 18.61367929726839, 56.623140424489975, 62.72849701344967, 82.13741093873978, 54.894107803702354, 36.41456700861454, 26.74779262393713, 27.05339502543211, 35.202287659049034, 31.915361434221268, 25.124975703656673, 34.4977218657732, 28.80399528890848, 23.619352094829082, 73.96097928285599, 49.474838599562645, 36.627013608813286, 45.65247170627117, 52.45492748916149, 36.20665356516838, 2.3591378470882773, 0.04804674819752108, 0.33461075741797686, 0.06653900883975439, 0.06984760708292015, 0.05124643626913894, 0.046511949694831856, 0.04917270867736079, 0.09310826673754491, 0.10136689350474626, 0.03737758124771062, 0.0385300178459147, 0.007526829731432372, 0.10931508732028306, 0.0662322792049963, 0.07234750926727429, 0.01264117207028903, 0.050138480291934684, 0.0249715809331974, 0.03241697711928282, 0.046413303425651975, 0.0790174724534154, 0.06272871134569868, 0.07899663294665515, 0.11195852086530067, 0.10345977963879704, 4.825113611295819, 66.51837185025215, 65.01343220472336, 47.310736924409866, 25.201055221259594, 45.18135778605938, 32.20699958503246, 40.85495173931122, 37.42307469248772, 30.72542678564787, 29.786141887307167, 30.44244647026062, 39.52617064118385, 37.40158684551716, 32.513855919241905, 33.78292702138424, 56.06293648481369, 49.146623611450195, 55.60500405728817, 62.36229546368122, 34.19524669647217, 3.1575448298826814, 5.959512339904904, 46.723121255636215, 61.789468601346016, 64.95939910411835, 63.82440760731697, 64.77288991212845, 56.805602833628654, 61.64975009858608, 49.341245368123055, 46.60183176398277, 57.73820199072361, 29.94831908494234, 5.449375938624144, 13.030655980110168, 13.949104696512222, 9.042794667184353, 14.632402081042528, 4.923538779839873, 17.087983265519142, 45.29436752200127, 37.9012144356966, 30.26513658463955, 20.5039581656456, 23.09703592211008, 21.63206823170185, 12.954777851700783, 18.61396048218012, 25.39917279034853, 11.657103784382343, 9.806883316487074, 5.670335032045841, 15.035618394613266, 15.021191518753767, 30.064239464700222, 36.02269023656845, 32.47019246220589, 6.405397513881326, 0.7988602865952998, 0.05588536761933938, 0.12612780468771234, 0.07826316097634844, 0.04107030399609357, 0.08890388140571304, 0.0033505829287605593, 0.1393909633043222, 0.04035087345982902, 0.09763306690729223, 0.2348400157643482, 0.18423519213683903, 1.8372282525524497, 1.2840021634474397, 0.6286146969068795, 1.45455066813156, 1.103340145200491, 2.0633294200524688, 12.365988995879889, 4.312902046367526, 0.4230193665716797, 0.10679141414584592, 0.06430137422285043, 0.05092376530228648, 0.08529895843821578, 0.14095462393015623, 0.06541931579704396, 0.0643433872028254, 0.3204067039769143, 0.08449078188277781, 0.08658838807605207, 2.201609225012362, 5.757757890969515, 22.242771461606026, 36.98047824203968, 21.767817847430706, 4.1497259773314, 6.475519901141524, 5.272006681188941, 8.805475551635027, 13.41175653040409, 19.641358852386475, 14.465938713401556, 12.746149096637964, 22.290029525756836, 23.289218209683895, 15.13444634154439, 22.979474030435085, 32.05242767930031, 36.03279769420624, 19.941867627203465, 3.079809551127255, 0.48425088403746486, 0.5845691822469234, 3.3020669873803854, 6.291208891198039, 1.79513351758942, 20.01484841108322, 46.662176325917244, 52.618151530623436, 47.540696784853935, 51.887682527303696, 52.672123834490776, 53.24012115597725, 50.629418045282364, 57.87024490535259, 56.54343970119953, 54.81064908206463, 36.753702610731125, 14.887655284255743, 3.594109104014933, 26.685316376388073, 62.45476730167866, 65.2077841758728, 82.49551892280579, 53.57078701257706, 13.956047873944044, 29.251483976840973, 27.272738255560398, 33.78871411085129, 27.77461912482977, 24.612470604479313, 22.46793407946825, 40.09296342730522, 19.86647207289934, 66.48770749568939, 62.62269169092178, 25.93074146658182, 46.01497605443001, 63.50268267095089, 40.20135261118412, 2.3960737651214004, 0.049796595121733844, 0.2640979114221409, 0.06101199389377143, 0.08045601440244354, 0.0661358519573696, 0.024397017623414285, 0.08069500079727732, 0.08584188399254344, 0.06576454805326648, 0.05581287092354614, 0.18111784534994513, 0.12834134919103235, 0.24374354659812525, 0.15138948743697256, 0.22380965296179056, 0.1831789972493425, 0.1701027262606658, 0.2016444329638034, 0.12164933679741807, 0.14730267314007506, 0.1894241847912781, 0.2326686994638294, 0.2459279989125207, 0.28952041757293046, 0.5090840358752757, 7.558363471180201, 88.8548044860363, 71.42697885632515, 70.86341589689255, 48.077288791537285, 59.84559930860996, 52.678613886237144, 60.638867542147636, 55.01366838812828, 32.99300640821457, 55.32854609191418, 51.92175529897213, 57.53335878252983, 45.79443208873272, 37.93561019003391, 35.95758453011513, 66.74961224198341, 57.76938311755657, 60.776344165205956, 67.70734325051308, 34.23876196146011, 2.4921846203505993, 8.543514758348465, 51.27229794859886, 65.89856430888176, 72.55296483635902, 71.21947959065437, 72.65485256910324, 62.82178960740566, 66.15027040243149, 52.73702435195446, 49.90329600870609, 60.81955924630165, 31.824111230671406, 4.72654452547431, 22.55805194377899, 23.108676597476006, 11.050350442528725, 35.787467658519745, 32.232196033000946, 29.35675922781229, 47.147987857460976, 52.5630696862936, 26.45777128636837, 20.972877703607082, 18.777024932205677, 16.285331435501575, 21.929590366780758, 26.029403172433376, 38.09311933815479, 15.81100383773446, 14.046863950788975, 6.215730691328645, 16.9060680270195, 10.065320748835802, 38.762920796871185, 42.72744566202164, 37.667773962020874, 11.730790380388498, 0.8053440449293703, 0.2173468380351551, 0.2724904735805467, 0.15799531422089785, 0.17737477901391685, 0.1805283426074311, 0.1716780979768373, 0.20967945805750787, 0.14589766884455457, 0.3193303820444271, 0.2588903799187392, 0.956665106350556, 3.146026935428381, 14.10699287429452, 1.1458206782117486, 2.823688806965947, 1.1061363201588392, 2.272586328908801, 12.464806493371725, 7.966243559494615, 2.531312070786953, 0.175403323082719, 0.20295929600251839, 0.23701170313870534, 0.3224971261806786, 0.30277303769253194, 0.21874948230106384, 0.19430129730608314, 0.45063723460771143, 0.6467753474134952, 0.21124476625118405, 1.674777113366872, 15.544106159359217, 26.22028972953558, 46.746471002697945, 22.266959063708782, 4.684201972559094, 10.994866769760847, 12.366618812084198, 20.397328287363052, 23.13024614006281, 25.63317373394966, 16.650567837059498, 7.86888993345201, 15.072006192058325, 21.282969564199448, 15.386405121535063, 28.52512825280428, 41.95746637880802, 43.13669130206108, 20.339497290551662, 3.1330344825983047, 0.9613434865605086, 3.224956775084138, 8.43529561534524, 5.895480075851083, 1.2272604019381106, 20.25092974305153, 52.873167246580124, 58.85788410902023, 51.0237380862236, 55.38026511669159, 56.692547500133514, 57.30056807398796, 56.09564132988453, 64.19243305921555, 60.83427205681801, 58.882077410817146, 43.29630173742771, 16.251670941710472, 3.53210236877203, 22.89820969104767, 70.38591831922531, 76.313167065382, 95.7019154727459, 59.86154705286026, 43.454415053129196, 35.2736896276474, 35.02768702805042, 42.598678171634674, 45.10749354958534, 35.04902668297291, 47.33761288225651, 44.218455255031586, 32.76821427047253, 91.23720824718475, 68.37370589375496, 45.39620205760002, 61.26699663698673, 72.31854021549225, 63.910282999277115, 3.9594986848533154, 0.23002819740213454, 0.33789639361202717, 0.1870827385573648, 0.3059953835327178, 0.17810628429288045, 0.20413703983649611, 0.11122311931103468, 0.1879015946178697, 0.23176623304607347, 0.23576453881105408], [0.019167824684700463, 0.10330085613531992, 0.04550917830783874, 0.04472123269806616, 0.013114789380779257, 0.038071511589805596, 0.026067451035487466, 0.0714226151467301, 0.12000524962786585, 0.051445086937746964, 0.07940120733110234, 0.03195617020537611, 0.10503748912014998, 0.08416182492510416, 0.41900197276845574, 0.1719894289271906, 25.931235440075397, 72.46003702282906, 45.19599840044975, 52.787132263183594, 39.75112237036228, 45.91702491044998, 36.13623194396496, 45.304870158433914, 28.030535392463207, 24.33061122894287, 38.985121473670006, 37.90859363973141, 40.94493851065636, 31.27171967178583, 24.703986793756485, 30.647434070706367, 53.24760675430298, 64.15099248290062, 64.7230213880539, 61.71053163707256, 8.01265949383378, 2.9709760285913944, 31.94297455251217, 62.41074286401272, 51.25584103167057, 55.759568363428116, 54.39128078520298, 58.0030819773674, 48.171371743083, 59.14020135998726, 52.07907825708389, 56.35422505438328, 41.36328466236591, 12.6871401630342, 14.616375491023064, 10.774530842900276, 20.550775453448296, 6.613167989999056, 11.685917638242245, 47.42370866239071, 32.92527124285698, 15.518414787948132, 17.40643087774515, 32.454377710819244, 9.021442662924528, 14.729723408818245, 18.858718648552895, 23.85407119989395, 19.152600578963757, 9.046795852482319, 9.15788859128952, 4.9242189433425665, 9.407337605953217, 8.750203717499971, 38.161610662937164, 34.00459572672844, 23.22730243206024, 3.571893833577633, 1.3233429961837828, 0.03388338671356905, 0.3214791667414829, 0.07441899928380735, 0.14484340354101732, 0.15185374533757567, 0.16814777569379658, 0.007547135355707724, 0.1749720610678196, 0.036518129709293135, 0.12482965481467545, 0.23229703190736473, 0.09385339784785174, 0.05872713270946406, 0.8385192335117608, 1.8128897272981703, 0.9047078224830329, 1.8833842570893466, 17.804873697459698, 8.031016308814287, 0.28634488640818745, 0.13004110485780984, 0.11622287915088236, 0.09042981124366634, 0.16848579427460209, 0.05179475723707583, 0.07527073248638771, 0.11404148448491469, 0.38001116656232625, 0.06725541141349822, 0.16427677794126794, 1.5850741392932832, 4.793058056384325, 7.001615446060896, 33.78046855330467, 32.79119163751602, 0.7141838490497321, 0.7588556176051497, 5.5378584656864405, 10.451218541711569, 12.112163566052914, 18.576405197381973, 25.886559337377548, 19.078134074807167, 5.4784410540014505, 7.511182827875018, 24.60924457758665, 21.49224143475294, 20.523361824452877, 31.928778514266014, 38.286183178424835, 38.81711728870869, 8.491811882704496, 0.26026860752608627, 1.3487427332438529, 4.355090707540512, 0.6741889764089137, 8.932631928473711, 38.96553352475166, 47.573120445013046, 48.06778930127621, 46.0051079839468, 44.90770407021046, 50.32219313085079, 48.96032340824604, 48.93522955477238, 48.20531912147999, 49.36070792376995, 38.153714686632156, 9.900161661207676, 10.490847565233707, 48.04010398685932, 57.35014021396637, 47.778168842196465, 41.47458828985691, 59.075669422745705, 56.93622462451458, 21.03025272488594, 29.07347682863474, 33.44393961131573, 29.595677107572556, 18.384587690234184, 36.41808561980724, 23.80131673067808, 41.49632692337036, 66.09438300132751, 23.60760122537613, 42.36304521560669, 44.911800250411034, 58.388875275850296, 11.284402683377266, 0.15562447893898934, 0.09029992055729963, 0.028419656555342954, 0.0811444157443475, 0.06897244427818805, 0.027676959689415526, 0.018869850537157618, 0.10084698937134817, 0.03621407180617098, 0.06540741916978732, 0.04002731562650297, 0.09403104573721066, 0.09140472611761652, 0.08285419040475972, 0.03254642251704354, 0.07490139527362771, 0.019370225054444745, 0.04159096883086022, 0.061490111402235925, 0.08881097193807364, 0.06525230288389139, 0.012557983809529105, 0.010422674658912001, 0.14938448643079028, 0.06735178671078756, 0.42837740562390536, 0.36397249437868595, 37.318584099411964, 82.7495276927948, 50.366958528757095, 44.33386646211147, 42.382739558815956, 45.22443987429142, 30.435185059905052, 35.424093157052994, 33.65091450512409, 29.322027191519737, 29.75031740963459, 32.843503430485725, 36.81243985891342, 39.51767809689045, 27.093606367707253, 32.6166708022356, 54.29416559636593, 70.25964349508286, 68.1404972076416, 66.84608146548271, 10.064660534262657, 2.605466516688466, 36.94743901491165, 66.37698903679848, 58.81749227643013, 63.801943212747574, 57.14281193912029, 63.41105058789253, 52.52371899783611, 60.928252413868904, 56.712443232536316, 58.87298069894314, 43.49843189120293, 11.221231073141098, 15.54696835577488, 16.03012192994356, 12.02368626371026, 1.985104561317712, 14.30035024881363, 53.411811143159866, 34.476424008607864, 27.76339642703533, 29.120278917253017, 42.153034284710884, 21.73631753772497, 17.240132801234722, 17.230162136256695, 27.01700057834387, 19.551582969725132, 11.11310787498951, 12.390776015818119, 8.80023943260312, 17.800110653042793, 19.22926716506481, 35.359052047133446, 38.76922465860844, 34.851596876978874, 8.939470611512661, 1.7799357580952346, 0.6117383181117475, 0.15322052902774885, 0.19656161195598543, 0.05554277369810734, 0.32753981184214354, 0.09908330510370433, 0.07130655809305608, 0.013400067236943869, 0.02630623148434097, 0.135110255505424, 0.07503067739889957, 0.09872968657873571, 3.938466813415289, 0.37792656279634684, 2.5268769962713122, 4.3126864079386, 4.293493637815118, 15.154003892093897, 4.283824106678367, 0.5816622194834054, 0.16278969211271033, 0.2684393269009888, 0.012459602858143626, 0.135154205490835, 0.10149475070647895, 0.2949449233710766, 0.29475110408384353, 0.6479433691129088, 0.10943838031380437, 0.10323037437046878, 3.863208764232695, 7.080072686076164, 15.507994797080755, 38.78982335329056, 32.4353863298893, 5.832090452313423, 3.5496044671162963, 3.8526709796860814, 10.176319442689419, 12.170869465917349, 18.46715535968542, 19.246275052428246, 19.71900388598442, 9.910252019762993, 20.56962624192238, 36.80310755968094, 33.50785218179226, 30.67572545260191, 36.61522664129734, 45.1138886064291, 41.668750271201134, 12.056617196649313, 0.5893275362905115, 0.44120795151684433, 4.2511786334216595, 1.7796977958641946, 9.044610019773245, 44.39561314880848, 52.13535323739052, 51.69736593961716, 50.04361867904663, 50.819753631949425, 53.65788973867893, 55.25754690170288, 53.545841351151466, 56.362736597657204, 56.13030306994915, 44.27482523024082, 8.090731054544449, 14.300087112933397, 54.20619271695614, 60.48744946718216, 56.90881669521332, 50.95850318670273, 66.77242621779442, 39.313800036907196, 26.021510995924473, 30.48777613788843, 31.554722785949707, 26.506317481398582, 14.390807244926691, 33.14332254230976, 36.28312826156616, 28.98012913763523, 79.10912543535233, 27.52390667796135, 32.86038592457771, 51.85197204351425, 66.88651889562607, 12.489509917795658, 0.10264413707773201, 0.12971626681974158, 0.09077783397515304, 0.027147912296641152, 0.024273971393995453, 0.05230395960097667, 0.02711559547606157, 0.09229559276718646, 0.028723658797389362, 0.07737069870927371, 0.06764100166037679, 0.13979172304971144, 0.21203573240200058, 0.17586223752005026, 0.17518842680146918, 0.1308885484468192, 0.13457755674608052, 0.13456404965836555, 0.10774919282994233, 0.19857890292769298, 0.3001779847545549, 0.20383514900458977, 0.1259982108604163, 0.20146438793744892, 0.2788233384490013, 0.44039150001481175, 0.5632421735208482, 51.67181611061096, 93.64418908953667, 62.41306833922863, 68.91722112894058, 58.03341954946518, 64.77760165929794, 54.33188617229462, 65.40717467665672, 36.9534806907177, 38.40777285397053, 54.07168373465538, 55.603472739458084, 53.80760170519352, 43.27318377792835, 35.57635858654976, 39.78182852268219, 62.745428904891014, 75.52083358168602, 75.5828994512558, 70.8199842274189, 13.17235417664051, 4.318721434101462, 42.279578894376755, 72.60287135839462, 64.3514621257782, 67.32838198542595, 61.57064974308014, 68.29095393419266, 59.644814282655716, 64.42308828234673, 60.12441694736481, 64.11503121256828, 47.921253964304924, 18.577849119901657, 27.657518908381462, 24.384912215173244, 34.85612243413925, 13.658173307776451, 15.015371181070805, 57.50813573598862, 45.49417980015278, 24.74164467304945, 28.952793404459953, 41.9185184687376, 17.187080048024654, 22.716807425022125, 20.49873724579811, 29.72186453640461, 26.08684279024601, 14.944256097078323, 15.24338649585843, 8.987990207970142, 14.885814283043146, 15.42545847594738, 45.687752813100815, 42.476355135440826, 39.422094225883484, 17.971048280596733, 1.6581967030651867, 0.412076399079524, 0.39219286758452654, 0.28610867564566433, 0.3052309714257717, 0.5384879861958325, 0.2056922548217699, 0.10757146330433898, 0.25988019711803645, 0.16285252233501524, 0.27072187629528344, 0.43943582160864025, 0.207421355007682, 7.879913616925478, 1.1748722568154335, 5.699706505984068, 3.6303259106352925, 8.99654259905219, 23.016362451016903, 10.607726443558931, 0.6839760043658316, 0.25455665308982134, 0.26799451326951385, 0.15619130164850503, 0.32021816878113896, 0.1843214890686795, 0.6240532791707665, 0.24230572453234345, 1.4118218421936035, 0.29892927675973624, 0.4188602522481233, 10.618650857359171, 8.904675878584385, 24.472482316195965, 42.70924463868141, 39.81907032430172, 5.8186448737978935, 4.888956835493445, 7.339936466887593, 17.568030506372452, 17.122458815574646, 24.236779063940048, 31.900017857551575, 25.436606481671333, 7.09324087947607, 14.291535671800375, 33.575944527983665, 28.12507051974535, 27.98958119004965, 42.4521504342556, 51.399686112999916, 48.77161033451557, 11.6862871684134, 0.46762443089392036, 6.249955454841256, 13.331134356558323, 1.6373225231654942, 11.354469023644924, 49.124011024832726, 56.159333512187004, 57.16694064438343, 56.44826240837574, 52.647744342684746, 61.46563857793808, 60.010297670960426, 59.24911491572857, 61.4413882791996, 61.636682599782944, 43.872404024004936, 11.857060454785824, 15.223811846226454, 56.431528106331825, 68.64500373601913, 55.235040709376335, 56.07755430042744, 71.147640645504, 72.76284277439117, 28.074181750416756, 36.78019478917122, 44.37852166593075, 41.15602858364582, 26.729678995907307, 53.57080981135368, 38.47064048051834, 54.07600410282612, 86.92431807518005, 35.353219360113144, 58.93411181867123, 55.31764067709446, 84.23430562019348, 22.950504384934902, 0.3591894713463262, 0.2333818588522263, 0.27195986767765135, 0.30102248943876475, 0.1706388537422754, 0.15840052685234696, 0.16350204998161644, 0.19159244344336912, 0.07985891948919743, 0.24351913598366082, 0.1801803198759444], [0.06567174990777858, 0.13793261343380436, 0.08977253557532094, 0.09075435242266394, 0.021694375536753796, 0.018689196949708275, 0.05483934757648967, 0.05234936048509553, 0.1638580285361968, 0.07173605379648507, 0.09230538169504143, 0.05631256637570914, 0.09309107859735377, 0.21163518045796081, 0.09007001062855124, 0.37795805954374373, 2.0118110720068216, 62.288218438625336, 60.551631823182106, 45.892383232712746, 38.8722675293684, 37.81411170959473, 41.146282106637955, 51.32076054811478, 35.53522199392319, 25.11988777667284, 26.41496278345585, 35.119357109069824, 40.78859210014343, 34.99106839299202, 25.97840040922165, 57.277127131819725, 59.759549126029015, 45.120701640844345, 51.80868856608868, 62.36847013235092, 15.647140480577946, 2.869494636543095, 24.667765237390995, 54.114940613508224, 57.66421616077423, 53.792170733213425, 58.736993595957756, 49.349494725465775, 55.94730108976364, 44.87636715173721, 33.70482221245766, 56.69401042163372, 37.93306052684784, 8.520403448492289, 10.772920679301023, 13.779603391885757, 6.5588845778256655, 16.95818033069372, 50.46370513737202, 33.88620547950268, 20.020105428993702, 21.959593556821346, 44.2972706258297, 13.73925905674696, 16.348438449203968, 25.54810769855976, 16.907958425581455, 13.69307728484273, 19.703529216349125, 16.328935995697975, 12.23662968724966, 7.01112206093967, 8.06119903922081, 20.158416107296944, 36.299699172377586, 32.36103191971779, 17.074773274362087, 3.481311919167638, 2.0266865612939, 0.24603040044894442, 0.2939249452902004, 0.13447739649564028, 0.08504935191012919, 0.031192485403153114, 0.1227850750728976, 0.10403630221844651, 0.21679190453141928, 0.07377162386546843, 0.07765542366541922, 0.26687461242545396, 0.3042632999131456, 0.6158566439989954, 0.794697847450152, 0.6928050087299198, 3.162407618947327, 2.567465230822563, 12.513700369745493, 2.0460230112075806, 0.284270168049261, 0.07988507277332246, 0.04307261471694801, 0.09636582748498768, 0.07583745871670544, 0.09743794886162505, 0.12999095051782206, 0.2006805909331888, 0.46228859690018, 0.5719555215910077, 0.31815001100767404, 2.9608505219221115, 6.148094795644283, 0.7490116520784795, 21.987052783370018, 41.76868490874767, 3.4989413106814027, 0.7854024774860591, 3.329600072465837, 4.97701901011169, 9.033277127891779, 16.298923306167126, 21.0420510917902, 27.23347306251526, 23.700073063373566, 9.361442718654871, 5.956081124022603, 23.374223448336124, 19.01843547821045, 30.444646552205086, 29.920436181128025, 40.09985625743866, 49.516419768333435, 26.709416583180428, 5.946494238451123, 8.980438113212585, 5.127735072746873, 7.177430586889386, 40.46598181128502, 50.56329399347305, 49.614553302526474, 51.12572081387043, 49.03312750160694, 48.731712475419044, 50.40761634707451, 53.45235876739025, 54.444227144122124, 47.836541309952736, 46.111950650811195, 31.2854977324605, 16.312900856137276, 65.53753048181534, 41.890814155340195, 52.299394235014915, 38.56265254318714, 41.371765807271004, 88.45026299357414, 21.51603765785694, 33.21608863770962, 36.121952310204506, 26.929464675486088, 26.041019149124622, 30.059919096529484, 20.54252989590168, 59.060029461979866, 48.72068166732788, 28.04486822336912, 44.807526245713234, 55.10918766260147, 36.51072084903717, 1.0209104558452964, 0.061679611389990896, 0.17963675607461482, 0.04888646973995492, 0.0177388248994248, 0.0683904965990223, 0.04054576515045483, 0.12053778511472046, 0.07523129475885071, 0.055012601951602846, 0.053987495630281046, 0.09090241088415496, 0.15018017264083028, 0.10753031863714568, 0.10957764432532713, 0.042203322300338186, 0.10215275367954746, 0.02771370898699388, 0.060895588030689396, 0.06536691274959594, 0.039075537206372246, 0.05927660400629975, 0.1283831914770417, 0.053424769575940445, 0.15734504442662, 0.17994290683418512, 0.10249046055832878, 0.38200270500965416, 5.253962874412537, 73.94790798425674, 67.30996817350388, 45.18710307776928, 36.646685153245926, 43.796058520674706, 44.03013736009598, 38.10421474277973, 28.436302319169044, 32.267568334937096, 28.238813616335392, 32.703667134046555, 33.754033371806145, 43.068420365452766, 26.54786255210638, 59.97113697230816, 83.4040729701519, 53.18799175322056, 60.1870945841074, 62.044400721788406, 14.944341592490673, 4.879966517910361, 29.49845552444458, 58.71079780161381, 68.23606967926025, 59.874139577150345, 64.2476212978363, 54.207534044981, 58.458445742726326, 56.37162432074547, 43.14465567469597, 56.731050834059715, 42.426239624619484, 8.633901458233595, 13.413161505013704, 11.277385409921408, 3.191946758888662, 19.55093890428543, 56.46741718053818, 35.47206938266754, 33.644109070301056, 35.47547399997711, 48.971707597374916, 25.512154027819633, 20.877120941877365, 21.552380807697773, 14.4939318113029, 15.054584126919508, 17.548267766833305, 19.16416145861149, 14.669559337198734, 11.693110652267933, 18.094857037067413, 27.12945744395256, 36.52580223977566, 40.25700442492962, 26.357701756060123, 2.8138945950195193, 1.539730103686452, 0.3331382473697886, 0.26708621357101947, 0.20255169365555048, 0.0679738623148296, 0.14660956658190116, 0.13521604123525321, 0.20004537189379334, 0.04675092866818886, 0.1562059368006885, 0.11896381605765782, 0.20687019161414355, 0.21445011690957472, 0.8201242424547672, 0.6929064157884568, 4.07541811466217, 5.42707066051662, 5.332083832472563, 6.300548790022731, 1.1784938187338412, 0.28012669819872826, 0.05608595900412183, 0.07056311165797524, 0.021639990955009125, 0.2943819004576653, 0.05427039119240362, 0.10153051480301656, 0.1406726671848446, 0.20806211046874523, 0.15898538375040516, 0.8155454287771136, 2.870200448669493, 6.002401588484645, 9.15005911141634, 28.662158399820328, 41.26041658222675, 10.50420194864273, 3.5792780248448253, 2.781803891994059, 3.806590852327645, 9.374687857925892, 15.593899637460709, 17.491762898862362, 21.031388863921165, 20.97510628402233, 11.326223239302635, 15.276858899742365, 38.28799568116665, 37.75792792439461, 50.305002853274345, 40.08620359003544, 46.63694187998772, 56.47614151239395, 34.35798816382885, 11.329036988317966, 0.6293365987949073, 1.3118165521882474, 9.193115551024675, 49.2515017837286, 66.49965405464172, 55.59485860168934, 54.073617830872536, 53.274178728461266, 54.281694665551186, 53.69292385876179, 55.88259436190128, 62.0047802478075, 50.697103813290596, 50.147596299648285, 23.14963649958372, 17.57479604333639, 68.8154473900795, 45.82448847591877, 57.9302778840065, 43.51638212800026, 48.97158220410347, 86.60847902297974, 26.581929624080658, 32.079239040613174, 29.89414919167757, 23.122175373136997, 19.47410512715578, 38.56814704835415, 24.657739475369453, 52.30318263173103, 66.35227516293526, 22.771851271390915, 49.09601032733917, 64.1571481525898, 35.78383505344391, 0.8191997045651078, 0.16932410944718868, 0.2201197243994102, 0.0967629135993775, 0.03683173534227535, 0.17370030196616426, 0.04336625657742843, 0.06721360623487271, 0.02772858162643388, 0.09367635851958767, 0.05546848842641339, 0.034396815608488396, 0.21921915787970647, 0.2873003570130095, 0.14299226459115744, 0.11905400184332393, 0.24348850012756884, 0.062450116529362276, 0.17198536195792258, 0.13798857136862352, 0.2985690382774919, 0.3204428910976276, 0.22200771840289235, 0.14064802788197994, 0.2927342732436955, 0.4869215766666457, 0.3188453440088779, 0.624057138338685, 9.544699285179377, 91.84484124183655, 71.63580805063248, 63.10169018805027, 50.58988116681576, 55.70865869522095, 57.063270807266235, 76.31439059972763, 47.400716096162796, 35.00277176499367, 38.82923483848572, 51.72778710722923, 57.06809654831886, 49.53902095556259, 39.11682240664959, 68.16291600465775, 74.91254702210426, 52.83336438238621, 63.640052899718285, 71.89768239855766, 18.750388361513615, 6.182354707270861, 34.794254153966904, 67.76182472705841, 69.19871762394905, 62.50270552933216, 71.6817855834961, 58.89512591063976, 63.32577556371689, 52.64645241200924, 44.468918815255165, 58.1733014434576, 45.04006616771221, 12.97849427908659, 26.64922021329403, 29.644291698932648, 21.753796599805355, 23.403956852853298, 64.26752462983131, 45.11287026107311, 31.390875577926636, 30.35945702344179, 47.34889067709446, 20.25445405393839, 20.356142297387123, 30.23557987064123, 17.22341749817133, 20.763250552117825, 25.542972274124622, 24.121217764914036, 15.947290174663067, 11.053585968911648, 13.59170252457261, 27.843085750937462, 47.75066591799259, 43.52168284356594, 35.5735619366169, 20.186730287969112, 3.122596205212176, 0.3413491614628583, 0.469965134980157, 0.3029838966904208, 0.16165297420229763, 0.21639957558363676, 0.22843925922643393, 0.19600237399572507, 0.30901954625733197, 0.2439483199850656, 0.2302821900229901, 0.4523971339222044, 0.722054117359221, 0.8161066705361009, 1.926935501396656, 8.242720048874617, 7.7504887618124485, 14.142257831990719, 18.0053623393178, 2.423412585631013, 0.3482546081067994, 0.12210623259306885, 0.2116175915580243, 0.26184104033745825, 0.32412611064501107, 0.16591996711213142, 0.208197656320408, 0.5978913861326873, 2.472266089171171, 0.9968471783213317, 3.7770792609080672, 6.565516171976924, 10.632675904780626, 20.525432713329792, 31.21747948229313, 49.881146997213364, 9.041918814182281, 4.529791558161378, 7.424655295908451, 8.123800680041313, 16.88023131340742, 24.81875393539667, 27.303064428269863, 36.41217313706875, 28.838810920715332, 12.239078655838966, 8.053020928055048, 29.816925935447216, 24.900322258472443, 40.49576461315155, 36.291449815034866, 49.44706968963146, 62.40510776638985, 33.78428354859352, 12.68071660771966, 18.92337027937174, 15.801985021680593, 13.605351392179728, 46.84413716197014, 60.47444276511669, 55.58252066373825, 60.45938417315483, 56.03780083358288, 59.15120176970959, 58.101975470781326, 63.25060419738293, 64.33130040764809, 59.25371266901493, 54.54379320144653, 35.14868013560772, 18.55811107903719, 77.27962240576744, 51.573975160717964, 62.74251826107502, 45.57217441499233, 53.79000864923, 106.07290416955948, 30.29664259403944, 38.076898008584976, 47.34359756112099, 38.13012175261974, 40.568443313241005, 44.361935555934906, 31.04053057730198, 73.24689120054245, 67.49567940831184, 38.2112891972065, 58.82036492228508, 72.1516227722168, 65.51373615860939, 1.581296429503709, 0.24352379667107016, 0.24345014593563974, 0.2625590533716604, 0.12242935627000406, 0.2078362600877881, 0.1284371901419945, 0.19877718994393945, 0.23175413603894413, 0.1556608738610521, 0.1523919656756334, 0.22925734345335513], [0.031234416746883653, 0.009924055320880143, 0.027429164001659956, 0.031500313416472636, 0.024516534940630663, 0.05592991132289171, 0.03898557406500913, 0.05791048824903555, 0.037150213174754754, 0.15942218218697235, 0.030187140619091224, 0.07259956488269381, 0.032814263613545336, 0.08566563876229338, 0.07802584441378713, 0.5239163024816662, 0.5429349350742996, 35.47920159995556, 72.05905213952065, 45.44391989707947, 41.44585803151131, 37.71011509001255, 29.278190843760967, 39.70078267157078, 45.786471515893936, 24.896064586937428, 26.657287180423737, 22.279513590037823, 39.576491340994835, 40.78735716640949, 17.43467666208744, 30.743979290127754, 30.29346216470003, 37.77468882501125, 65.50875082612038, 64.89583611488342, 24.409181512892246, 5.37650297395885, 34.87189918756485, 62.55352400243282, 46.912700682878494, 53.32155078649521, 52.921181470155716, 50.187532156705856, 56.385463178157806, 17.58257992565632, 40.801568403840065, 57.61971294879913, 38.634540885686874, 10.089271813631058, 10.008554644882679, 9.96071046218276, 17.71729599684477, 60.62196604907513, 40.535575076937675, 31.20944671332836, 30.780037455260754, 21.340466178953648, 15.307533703744411, 12.069579251110554, 26.686245426535606, 21.224876381456852, 22.83163346350193, 22.656626254320145, 23.57412502169609, 18.134321719408035, 16.287250332534313, 4.814432384446263, 12.955113183706999, 20.908651649951935, 35.94893239438534, 27.574797347187996, 7.820889009162784, 2.4171821074560285, 0.5638193862978369, 0.1471476088045165, 0.12541243369923905, 0.18878806033171713, 0.34115362039301544, 0.15635099698556587, 0.21072431292850524, 0.2340144061599858, 0.041589803659007885, 0.0309091556846397, 0.1159400689357426, 0.0692108369548805, 0.26578430843073875, 0.8443595201242715, 0.059407504013506696, 0.8293484256137162, 4.767955178394914, 1.2027599103748798, 3.1853282265365124, 0.5179328110534698, 0.07090767598128878, 0.028710799233522266, 0.20352525782072917, 0.12499371398007497, 0.07147409793105908, 0.029233094937808346, 0.2982928405981511, 0.15736076311441138, 0.07243518659379333, 0.25058346160221845, 0.12173492868896574, 0.31431494804564863, 4.884414179250598, 2.1271491330116987, 20.41259966790676, 43.19166675209999, 6.077524507418275, 2.265374790877104, 3.6612631380558014, 5.084404572844505, 7.175816148519516, 15.25608541443944, 11.019438151270151, 22.942234128713608, 23.014802634716034, 30.668999813497066, 13.366198875010014, 5.232075098901987, 9.610987678170204, 11.90541286021471, 29.336276426911354, 40.63781999051571, 38.10928747057915, 56.029008105397224, 53.96387591958046, 17.53755424171686, 1.420981369446963, 5.059952884912491, 31.057777851819992, 21.76883239299059, 52.6775461435318, 47.10172154009342, 60.03786899149418, 48.952172845602036, 54.09368835389614, 45.53823843598366, 49.89692375063896, 52.63437286019325, 50.513756051659584, 19.674065597355366, 27.468832433223724, 71.3493338227272, 38.70879650115967, 53.65020275115967, 56.392226815223694, 71.85961604118347, 43.38570713996887, 22.018454298377037, 36.758171170949936, 31.65423184633255, 30.54561473429203, 22.94680718332529, 24.843522906303406, 52.040483728051186, 78.30804482102394, 26.919851191341877, 34.78291176259518, 46.9721332937479, 48.58719862997532, 4.517022343352437, 0.1597031592973508, 0.13515281025320292, 0.09060573735041544, 0.053381873440230265, 0.05324847239535302, 0.05214176322624553, 0.042092946387128904, 0.05196317652007565, 0.013120875919412356, 0.05336347188858781, 0.1309532785671763, 0.03153405887132976, 0.07222204920253716, 0.05131774552864954, 0.028314447845332325, 0.07618585994350724, 0.011332585745549295, 0.032295654527843, 0.0720362673746422, 0.06133643117209431, 0.04079891172295902, 0.18084509123582393, 0.010183370995946461, 0.038789216632721946, 0.11927323226700537, 0.15965537982992828, 0.08127156790578738, 0.5991993471980095, 0.7099559821654111, 42.11074635386467, 78.24726328253746, 51.37141562998295, 34.49773706495762, 36.45524002611637, 34.08954776823521, 49.829800352454185, 25.818066112697124, 28.777493610978127, 30.180866606533527, 26.16953395307064, 32.29624919593334, 43.85318085551262, 23.20802416652441, 42.869303449988365, 51.924958527088165, 40.29208414256573, 69.46873113512993, 70.85547432303429, 35.21917775273323, 7.3384222481399775, 36.2931939214468, 67.4707755446434, 55.2370698004961, 55.96584789454937, 60.60135595500469, 51.10826835036278, 65.31965777277946, 26.223397962749004, 40.9857939183712, 64.17177736759186, 44.992511719465256, 9.052283708006144, 3.8685702765360475, 2.0128477038815618, 23.63429669290781, 64.9755710363388, 44.522256553173065, 46.06751583516598, 46.315912306308746, 32.411063835024834, 29.099841713905334, 15.20905438810587, 25.892532616853714, 16.284712068736553, 22.397483959794044, 14.954440500587225, 19.37437567859888, 26.27409864217043, 15.980614386498928, 12.712031677365303, 20.189355947077274, 25.881566405296326, 36.07532121241093, 33.7315309792757, 22.988185063004494, 2.363866218365729, 0.7001529238186777, 0.23774300061631948, 0.15770880068885162, 0.12309258396271616, 0.361085421172902, 0.24318193376529962, 0.1142457606329117, 0.071126023249235, 0.08269893311080523, 0.07159333137678914, 0.27221774915233254, 0.03105565378064057, 0.0711696912185289, 0.9411834308411926, 0.04851021200011019, 1.7189956968650222, 4.121561888605356, 2.7517703035846353, 2.657875679433346, 0.34123582066968083, 0.08283303177449852, 0.24880515702534467, 0.35476552904583514, 0.11539607468876056, 0.056166637878050096, 0.2089547656942159, 0.43877323216293007, 0.10803345765452832, 0.28147239005193114, 0.09142392547801137, 0.4201118991477415, 0.8449819148518145, 4.282277589663863, 10.628327038139105, 23.328546099364758, 44.175236374139786, 13.107774741947651, 6.122869849205017, 5.683079548180103, 2.634475822560489, 3.071447149850428, 9.444535709917545, 13.549580834805965, 17.45761413127184, 19.474080428481102, 24.224435426294804, 14.680811483412981, 10.437285639345646, 13.348863255232573, 25.194318182766438, 47.120462134480476, 54.26761642098427, 44.27656553685665, 59.836631789803505, 58.181208819150925, 26.932713501155376, 4.818301051855087, 2.7755043050274253, 31.880536302924156, 31.749798618257046, 58.57337437570095, 52.39480711519718, 62.85513661801815, 53.31415258347988, 62.366680428385735, 50.88365860283375, 53.82105678319931, 58.61812077462673, 52.019755840301514, 21.235008537769318, 32.24589429795742, 72.33235627412796, 43.6145156621933, 56.52985543012619, 54.80355106294155, 69.29844707250595, 54.219617396593094, 24.296831041574478, 34.72675457596779, 25.530328452587128, 25.66951498389244, 20.421779975295067, 38.89455333352089, 40.30454367399216, 82.07865849137306, 32.23899006843567, 32.370170429348946, 60.17692632973194, 53.96113246679306, 5.137221263721585, 0.026136673004657496, 0.13237268052762374, 0.02552581310737878, 0.0722097369725816, 0.04098616300325375, 0.017262195397051983, 0.0820651018875651, 0.016597982503299136, 0.02757868634944316, 0.023956786753842607, 0.02769284721580334, 0.06204440665896982, 0.1358451449777931, 0.15552749508060515, 0.1535700508975424, 0.1900625802227296, 0.10736388459918089, 0.178750334889628, 0.21938692778348923, 0.10953258111840114, 0.14574897213606164, 0.4359516460681334, 0.10634075981215574, 0.15051911148475483, 0.25845669850241393, 0.21876306360354647, 0.15533342346316203, 0.5876326491124928, 0.605949922464788, 60.77403388917446, 88.61601769924164, 66.13520041108131, 57.17149280011654, 59.95617337524891, 43.07988815009594, 66.277274787426, 67.86802142858505, 38.43032844364643, 40.468706265091896, 32.379628121852875, 60.663589015603065, 53.70274633169174, 25.924975275993347, 41.689641550183296, 43.34999665617943, 42.667386084795, 81.44538447260857, 76.6504217684269, 36.10511161386967, 9.530448149889708, 41.119869723916054, 78.48195388913155, 56.986161544919014, 60.919490084052086, 65.40036544203758, 57.66871891915798, 66.6888915002346, 24.172839894890785, 45.41272357106209, 65.17344161868095, 48.514907509088516, 13.94492207095027, 20.163629427552223, 24.898067079484463, 24.57644283771515, 71.123116761446, 47.945223078131676, 39.67439688742161, 37.01601393520832, 24.57036316394806, 23.554147593677044, 15.351162012666464, 34.00818273425102, 26.44555874168873, 28.23789406567812, 26.831327341496944, 30.96230797469616, 27.034884318709373, 19.029338993132114, 9.420577995479107, 15.794340781867504, 30.447722487151623, 47.27896302938461, 36.238564252853394, 36.662256717681885, 10.362252965569496, 2.594189434312284, 0.23076359153492376, 0.18568781262729317, 0.34171895880717784, 0.6792578450404108, 0.3954397636698559, 0.16431832336820662, 0.39925781660713255, 0.2387003117473796, 0.14090533048147336, 0.36596447811461985, 0.12038361877785064, 0.5016914731822908, 2.208629585802555, 0.21768786973552778, 3.4074863931164145, 12.676851265132427, 27.506883591413498, 8.390803802758455, 2.095740968361497, 0.1140140621282626, 0.35757342993747443, 0.5667486134916544, 0.22512015217216685, 0.3356507438002154, 0.33376580744516104, 0.8661794930230826, 0.23029847274301574, 0.24706918455194682, 0.7963722513522953, 0.3510862577240914, 5.179326804354787, 6.834315648302436, 20.387032739818096, 27.00914829969406, 55.40238752961159, 13.458171989768744, 6.368861524388194, 7.817199882119894, 8.330764174461365, 11.697003543376923, 21.435656771063805, 18.696533851325512, 29.831543751060963, 25.43861087411642, 34.7392825037241, 15.455483514815569, 7.719180341809988, 11.11386688426137, 17.920672483742237, 36.645226031541824, 48.511046916246414, 43.886201083660126, 60.4921118170023, 62.80721738934517, 28.478430658578873, 4.90188374184072, 7.824141634628177, 37.86617271602154, 24.780470989644527, 63.982897102832794, 54.86152075231075, 65.79270958900452, 59.08647604286671, 68.83395999670029, 56.24675542116165, 59.263740330934525, 60.699466690421104, 59.864328503608704, 23.6437201872468, 32.226253151893616, 81.45065099000931, 47.112588956952095, 61.461800783872604, 67.32778921723366, 85.67988485097885, 57.88108192384243, 29.362464621663094, 46.28451079130173, 44.87379088997841, 42.32039250433445, 34.83976051211357, 39.27556648850441, 64.80584174394608, 96.52945026755333, 39.72980171442032, 47.80700549483299, 65.25264456868172, 78.90405043959618, 13.06426327675581, 0.22813612158643082, 0.29940701206214726, 0.26501075306441635, 0.18971338489791378, 0.17754839704139158, 0.16757434786995873, 0.2510318672284484, 0.06659443242824636, 0.09173079612082802, 0.17362178274197504, 0.3165993676520884, 0.165497031994164], [0.05908095161430538, 0.08735915296711028, 0.07680052891373634, 0.011147420827910537, 0.002133817665708193, 0.020944123607478105, 0.05828965520777274, 0.12307250886806287, 0.1332453719805926, 0.061674906173720956, 0.010522257889533648, 0.06492601765785366, 0.031605787444277667, 0.09776970371603966, 0.3239769389620051, 0.1638593347161077, 0.17024132976075634, 3.1985144689679146, 74.93877321481705, 59.39925245940685, 55.471277832984924, 60.24950623512268, 52.43119016289711, 23.79171844571829, 46.824815198779106, 26.94321993738413, 29.874207861721516, 27.236936576664448, 21.006374806165695, 46.25609211623669, 24.120471104979515, 19.05923768877983, 21.456458754837513, 57.38018900156021, 67.92807340621948, 61.37965299189091, 58.365198746323586, 13.359578680247068, 14.956097211688757, 54.52339969575405, 54.27736669778824, 63.66661347448826, 48.65376725792885, 64.84794348478317, 39.9638045579195, 25.54817419499159, 65.17383679747581, 51.668381094932556, 34.37333934009075, 5.970613444224, 6.984859295189381, 20.946659110486507, 64.51299905776978, 49.953179731965065, 47.27375730872154, 35.888200253248215, 10.475313998758793, 12.97709595412016, 15.608271416276693, 24.547513090074062, 26.552866883575916, 21.702499352395535, 17.15155765414238, 20.74443396180868, 29.41583465784788, 20.92709206044674, 17.34475828707218, 5.730129573494196, 21.862444169819355, 29.55295979976654, 35.94149239361286, 27.647968120872974, 8.172259479761124, 2.018001414835453, 0.5419187864754349, 0.1225420217087958, 0.12841369374655187, 0.05712360391044058, 0.15787066309712827, 0.10133794974535704, 0.4203956964192912, 0.08578076070989482, 0.11304140338324942, 0.041173084027832374, 0.07161763671319932, 0.015958221520122606, 0.14177989214658737, 1.0509960539638996, 0.3904801094904542, 0.6393623014446348, 2.2507553128525615, 3.909632060676813, 0.8347026945557445, 0.19485059048747644, 0.11048770291381516, 0.0597841884882655, 0.13593543466413394, 0.026640617252269294, 0.26846922060940415, 0.05802770676382352, 0.34637115604709834, 0.07622126038768329, 0.08363366068806499, 0.23991780501091853, 0.20082216302398592, 0.4153755126753822, 2.3972471896559, 0.7812649151310325, 20.5614110827446, 44.76382479071617, 18.240583017468452, 2.802832913585007, 1.670174729079008, 3.887081458233297, 5.066218748688698, 10.065313149243593, 13.348728362470865, 14.140154644846916, 23.97588886320591, 20.865869745612144, 28.866127654910088, 24.073931202292442, 19.215548001229763, 11.77657412365079, 11.671759597957134, 29.79032166302204, 44.803103283047676, 49.53397482633591, 59.86127346754074, 61.071098148822784, 12.81475156545639, 2.9694893583655357, 6.314513040706515, 39.59658086299896, 55.16578182578087, 55.98170064389706, 68.86628866195679, 52.96085134148598, 34.04768921434879, 39.530699998140335, 42.607828080654144, 52.32532784342766, 49.87611226737499, 38.01513992249966, 53.05471770465374, 61.54542289674282, 45.0727292150259, 54.58373285830021, 59.67483267188072, 51.42623528838158, 25.98588790744543, 28.56027066707611, 35.75762026011944, 33.83798986673355, 25.443732999265194, 26.513147614896297, 33.19458179175854, 79.91468220949173, 49.30094093084335, 23.54481529444456, 51.02574437856674, 58.547756150364876, 23.628549501299858, 0.4141949932090938, 0.27499293617438525, 0.43743243848439306, 0.03597736751544289, 0.06473689616541378, 0.013729773763770936, 0.13346000108867884, 0.02996965795318829, 0.14561638003215194, 0.032378882679040544, 0.09053276939084753, 0.10721239741542377, 0.10265569973853417, 0.22444469388574362, 0.0501088203600375, 0.058019635907839984, 0.08983207808341831, 0.07546103399363346, 0.04675498450524174, 0.02462044489220716, 0.09330628658062778, 0.1157010676979553, 0.13321338541572914, 0.10627748430124484, 0.0483212240942521, 0.05156816841918044, 0.15182603354332969, 0.1793103595264256, 0.14889692509314045, 0.22350923158228397, 5.03525136038661, 78.28458487987518, 68.08753564953804, 53.7478993088007, 62.163201346993446, 47.6478586345911, 33.388113006949425, 50.62145747244358, 24.134969227015972, 37.70962871611118, 26.060137823224068, 25.03768678754568, 37.06072233617306, 33.80805127322674, 23.21685679256916, 20.27179442346096, 53.38440701365471, 74.2477422952652, 64.81740832328796, 63.210900127887726, 16.612455882132053, 17.3891494050622, 67.34988883137703, 53.11404012143612, 64.66895028948784, 58.33633549511433, 67.97329857945442, 52.6098869740963, 24.907234087586403, 63.74080069363117, 57.50205226242542, 38.77032659947872, 3.752523078583181, 0.3548967110691592, 26.32889550179243, 67.36717030405998, 53.823435455560684, 57.77287133038044, 54.04946252703667, 22.12231982499361, 20.05112886428833, 18.58670264482498, 26.36906884610653, 23.995214626193047, 21.631652154028416, 15.908312816172838, 13.394826538860798, 33.85483056306839, 22.92356003075838, 21.197800934314728, 12.65500908717513, 25.334205776453018, 30.88069785386324, 37.68505163490772, 31.079860366880894, 23.719896599650383, 2.1219531493261456, 0.34363248269073665, 0.36310614086687565, 0.10369416471803561, 0.2631058974657208, 0.022527616274601314, 0.12995461496757343, 0.1116576319327578, 0.13314794283360243, 0.249037864850834, 0.1785327520337887, 0.04613394048647024, 0.012464526080293581, 0.4142037802375853, 0.2649599307915196, 0.13904328196076676, 1.7822386720217764, 3.060102383606136, 3.808994460850954, 1.4870871347375214, 0.298944950918667, 0.022599890326091554, 0.030622534541180357, 0.22579175129067153, 0.014075890103413258, 0.34872539690695703, 0.02053818552667508, 0.5488261627033353, 0.09912587469443679, 0.08862792121362872, 0.39652039005886763, 0.15210508106974885, 0.5276056670118123, 2.5642926385626197, 9.122763276100159, 22.946020625531673, 46.56896732747555, 23.445268236100674, 9.163015466183424, 5.634208470582962, 6.046696286648512, 4.915949637070298, 5.972038367763162, 11.579309608787298, 15.957348234951496, 17.089862264692783, 18.24581153690815, 22.266556285321712, 24.370849169790745, 18.53367079049349, 13.376707211136818, 17.836985774338245, 47.43261158466339, 58.311439231038094, 56.45217999815941, 63.83576139807701, 59.48509745299816, 21.368086896836758, 9.800579454749823, 3.588840924203396, 37.56292998790741, 62.42091491818428, 65.52709624171257, 68.86625066399574, 55.293162390589714, 41.723349541425705, 48.7664046138525, 47.2604314237833, 57.13311105966568, 54.64910455048084, 43.3408809453249, 57.546129897236824, 66.93204045295715, 48.95286060869694, 57.010362446308136, 58.41664798557758, 55.63862845301628, 35.44423967599869, 31.45905151963234, 28.581490628421307, 29.764395654201508, 21.487959064543247, 27.916816994547844, 39.5768903195858, 69.53596472740173, 63.41043122112751, 20.15891768038273, 53.95500339567661, 68.70437175035477, 24.62731070816517, 0.38514997519087046, 0.24243729247245938, 0.33866368525195867, 0.005112806557008298, 0.054477235171361826, 0.047619300821679644, 0.05587695908616297, 0.08331709017511457, 0.05091400606033858, 0.04579370288411155, 0.03323215954878833, 0.10272159503074363, 0.059795465422212146, 0.2669208333827555, 0.16924679250223562, 0.12979065970284864, 0.1571309645078145, 0.10666258473065682, 0.11583478044485673, 0.1373518828768283, 0.18158759514335543, 0.19990319124190137, 0.16150711249792948, 0.17645009269472212, 0.18655424035387114, 0.116600840119645, 0.29957785445731133, 0.41872461733873934, 0.45370865729637444, 0.4742034513037652, 9.81853349134326, 98.21929559111595, 74.48080658912659, 74.02406349778175, 82.84187033772469, 72.32785731554031, 36.4539784938097, 75.07368117570877, 39.97995749115944, 45.898941680788994, 39.89188961684704, 41.054904609918594, 64.5116539299488, 34.07544672489166, 35.87785340845585, 25.595958530902863, 70.03916412591934, 82.78307989239693, 71.43250375986099, 67.645193785429, 19.51587438583374, 21.437672562897205, 73.45885142683983, 61.10344581305981, 74.99895438551903, 62.293541952967644, 71.23680666089058, 54.08771887421608, 27.279708981513977, 74.62581440806389, 61.31583161652088, 42.73374192416668, 9.46547543630004, 19.792813025414944, 28.11706244945526, 73.79887998104095, 58.042257875204086, 54.510324597358704, 42.754515409469604, 15.353487487882376, 17.276152968406677, 18.488975688815117, 32.405310943722725, 31.640997156500816, 25.5349775031209, 21.167911738157272, 21.963237561285496, 40.65678857266903, 23.798603676259518, 23.913053534924984, 7.970210071653128, 28.449286222457886, 37.96885460615158, 48.08492258191109, 34.135920479893684, 37.14182138442993, 5.097844451665878, 1.8944819178432226, 0.5928623559884727, 0.14350560813909397, 0.3487935260636732, 0.2387972956057638, 0.22412378923036158, 0.5944811878725886, 0.21724473335780203, 0.47890507557895035, 0.225806609087158, 0.16385565366363153, 0.07148393880925141, 0.48863754083868116, 2.053445912897587, 0.7876042218413204, 2.665411150082946, 9.635576158761978, 11.69547887519002, 3.3855862682685256, 0.7258708344306797, 0.19921340950531885, 0.12702075677225366, 0.294824784505181, 0.14290236082160845, 0.515216609928757, 0.164663496252615, 1.3265404058620334, 0.11611454043304548, 0.18788440647767857, 0.6612051918637007, 0.45256616547703743, 1.7047043074853718, 4.50315878726542, 22.313668057322502, 27.106062099337578, 58.67652744054794, 26.32383607327938, 9.450837671756744, 6.330300243571401, 8.521170057356358, 9.882294069975615, 15.725657567381859, 17.349253445863724, 23.519829735159874, 30.732591301202774, 23.292698822915554, 33.59856091439724, 32.61744596064091, 24.317304342985153, 16.795400865375996, 13.195594679564238, 37.19644345343113, 48.66097927093506, 58.40074963867664, 65.57380333542824, 65.25528162717819, 18.795611634850502, 4.288436584174633, 10.237756446003914, 47.3252559453249, 65.93436598777771, 63.68704117834568, 72.97017484903336, 58.47513824701309, 46.9316540658474, 52.33761638402939, 52.808658108115196, 63.620871528983116, 59.44331869482994, 43.26607435941696, 64.20067861676216, 70.7043944299221, 54.36173357069492, 62.22307473421097, 66.83540403842926, 61.74738585948944, 37.974835485219955, 35.60519143939018, 43.33192482590675, 46.20803989470005, 36.24763436615467, 38.62887918949127, 50.16301967203617, 97.14339852333069, 67.43019372224808, 32.50446282327175, 68.33911255002022, 78.72174382209778, 52.799420803785324, 0.5749557574745268, 0.40885627968236804, 0.3856221295427531, 0.1441695779794827, 0.16145010071340948, 0.11506523267598823, 0.20324450335465372, 0.16884601791389287, 0.2538422617362812, 0.14163368905428797, 0.17607383866561577, 0.28209763462655246, 0.19490601407596841], [0.04329039795265999, 0.039265137384063564, 0.05430488621641416, 0.05987750984786544, 0.023408469496644102, 0.04425846280355472, 0.05579583492362872, 0.04853875499975402, 0.10735396950622089, 0.0640901738370303, 0.0695817252562847, 0.037298078677849844, 0.06132161790446844, 0.11496147300931625, 0.09494123791228049, 0.04629362469131593, 0.554012053180486, 0.21692727226763964, 33.859983086586, 82.81777963042259, 58.34185279905796, 51.111900955438614, 70.06711542606354, 46.66836239397526, 21.701627299189568, 51.555804535746574, 26.485148817300797, 42.33332701027393, 15.041575524955988, 49.21414598822594, 20.136531181633472, 68.95267322659492, 114.32227671146393, 59.26679536700249, 58.969628512859344, 61.81470684707165, 73.37486833333969, 35.87087698280811, 8.330151457339525, 41.79560266435146, 71.22213944792747, 48.01888972520828, 43.45480643212795, 51.90062463283539, 55.40119059383869, 55.125785171985626, 50.61382368206978, 53.60865198075771, 30.735462047159672, 0.6296117871534079, 15.172845181077719, 73.57298210263252, 58.05747605860233, 62.93015979230404, 33.199236541986465, 15.717251468449831, 23.536852821707726, 29.09614261239767, 24.831737838685513, 23.9702195674181, 22.641413770616055, 15.84866551682353, 16.650780625641346, 25.961407721042633, 26.049238108098507, 25.911508798599243, 18.77563040703535, 11.380262039601803, 23.36987268179655, 29.023351818323135, 36.151252537965775, 31.37535721063614, 8.3137078396976, 1.1486985487863421, 0.6587024324107915, 0.03909023173036985, 0.17701918637612835, 0.4016001831041649, 0.25111816416028887, 0.2756866661366075, 0.07918259288999252, 0.31483347178436816, 0.16877763642696664, 0.23027194838505238, 0.3192491614026949, 0.006060167343093781, 0.5874971626326442, 0.022360735092661344, 1.1962632089853287, 0.6568545440677553, 1.5660622157156467, 2.3348405258730054, 0.37334534456022084, 0.31154216558206826, 0.09432070597540587, 0.21344489272451028, 0.09462692352826707, 0.1392518699867651, 0.05570732268097345, 0.2731486991979182, 0.3103581431787461, 0.1679623723612167, 0.1406344020506367, 0.45343780308030546, 0.16037414985476062, 0.2174922841368243, 1.6654251026920974, 4.045773055404425, 20.673126988112926, 48.921918869018555, 20.689914487302303, 6.298330659046769, 5.804381389170885, 3.6163808964192867, 7.598210982978344, 11.623344495892525, 14.319556318223476, 12.548417206853628, 17.487115748226643, 18.7788450345397, 20.045731253921986, 21.245482675731182, 20.366956517100334, 20.819848515093327, 16.486935317516327, 12.770352847874165, 22.82498002052307, 41.627495884895325, 43.587749898433685, 56.258420795202255, 56.85007184743881, 7.55461972206831, 8.1846515648067, 69.11091953516006, 51.06641739606857, 44.31012533605099, 53.77889424562454, 64.88367676734924, 30.707193464040756, 35.44125683605671, 50.81755355000496, 50.764512196183205, 50.535487085580826, 53.121651113033295, 60.49529604613781, 54.51496794819832, 55.22432528436184, 58.95979464054108, 67.55964517593384, 55.7487503439188, 31.30114909261465, 29.27171029150486, 37.456387504935265, 25.589943453669548, 24.915983118116856, 33.234266862273216, 60.71207441389561, 81.24553799629211, 29.49108961969614, 45.14389179646969, 52.660051882267, 43.98949094116688, 0.7348904816899449, 0.11797366489190608, 0.21277173509588465, 0.06252741120988503, 0.07449348122463562, 0.04193896187643986, 0.11159142493852414, 0.06540222413605079, 0.07019709184532985, 0.032688888895791024, 0.12017002867651172, 0.022870891116326675, 0.02690882200113265, 0.0725617895659525, 0.03378074397915043, 0.06462728837504983, 0.02272280296892859, 0.021403763494163286, 0.054810889923828654, 0.0974993541603908, 0.024472414261254016, 0.011829423929157201, 0.13146981335012242, 0.026288304907211568, 0.04890968411928043, 0.11511187665746547, 0.16728963033528998, 0.08133050927426666, 0.11354388188919984, 0.13926079060183838, 0.5613265419378877, 0.2893218188546598, 33.809704184532166, 92.34272852540016, 62.50765286386013, 51.06162965297699, 72.04319179058075, 37.4836890399456, 28.94836474210024, 32.50511258840561, 23.428334444761276, 46.512498557567596, 20.26058692485094, 43.43055613338947, 24.801628254354, 70.25921791791916, 92.86914467811584, 67.05035090446472, 67.83002346754074, 68.43432024121284, 76.10729411244392, 44.41863611340523, 11.362083815038204, 49.22544278204441, 69.58526328206062, 60.79630449414253, 49.038318023085594, 59.28587034344673, 54.76769998669624, 45.620393827557564, 56.81621566414833, 64.03249204158783, 30.89005295187235, 0.9120628621894866, 21.963174864649773, 77.94292241334915, 62.871202155947685, 71.27153679728508, 50.990486070513725, 25.653911121189594, 23.52947361767292, 28.842764608561993, 26.22745994478464, 23.636540472507477, 19.3058767542243, 19.070314094424248, 16.38463720679283, 22.67944972962141, 32.35407069325447, 25.162225104868412, 25.073155984282494, 18.825831413269043, 23.117433227598667, 32.15510576963425, 38.45653183758259, 35.27357943356037, 25.431718043982983, 2.3712779581546783, 0.9670058952178806, 0.16114755679154769, 0.3015975945163518, 0.37997812614776194, 0.07989335514139384, 0.13686276302905753, 0.1417164533631876, 0.34784277551807463, 0.28568571084178984, 0.16798889671918005, 0.07239701051730663, 0.027155831012350973, 1.1239212658256292, 0.228977627994027, 1.898196218535304, 0.3303717583185062, 0.30557770282030106, 2.5153097044676542, 0.675977849168703, 0.40543868963140994, 0.3258001583162695, 0.3027863072929904, 0.07137746288208291, 0.2167040342465043, 0.09244965520338155, 0.13266044086776674, 0.4861948359757662, 0.1805983716621995, 0.08147686079610139, 0.40584793954622, 0.3174072102410719, 0.14032497099833563, 2.2558026295155287, 12.292546536773443, 24.210062697529793, 50.79471297562122, 23.5733175650239, 12.515008449554443, 10.31160643324256, 7.340359194204211, 8.600901179015636, 7.9443334601819515, 8.236730620265007, 12.707773055881262, 17.347881719470024, 18.600298315286636, 19.192017763853073, 18.737482354044914, 20.664890930056572, 20.825234726071358, 16.85922224074602, 19.343473836779594, 42.6430331915617, 56.397219747304916, 46.775182262063026, 59.18239049613476, 44.97264638543129, 15.20753351971507, 15.264719501137733, 43.84219944477081, 60.36762289702892, 50.382891073822975, 62.39808574318886, 63.998521864414215, 31.78978007286787, 41.39178693294525, 56.939899027347565, 52.87040859460831, 56.492959409952164, 56.88461199402809, 64.3234272301197, 59.07053589820862, 54.19067434966564, 59.27352100610733, 72.61684700846672, 55.59674710035324, 40.06316922605038, 30.571745932102203, 28.88724122196436, 27.07454089075327, 19.392569102346897, 41.09337754547596, 57.85761818289757, 79.9601049721241, 40.90420089662075, 41.71069622039795, 67.1304202079773, 42.48621940612793, 2.796578211709857, 0.04702355290646665, 0.3049086418468505, 0.03452319964708295, 0.1140161624061875, 0.04497293208260089, 0.014780675282963784, 0.062212922421167605, 0.005394751706262468, 0.030916987197997514, 0.036425027283257805, 0.043303318743710406, 0.04515975662798155, 0.07032863009953871, 0.12123790496843867, 0.1440978271421045, 0.17471976054366678, 0.10696629382437095, 0.28096096124500036, 0.24428528471617028, 0.23854300612583756, 0.16878317284863442, 0.37170968076679856, 0.1363022782607004, 0.22963137103943154, 0.2187647853861563, 0.2862938563339412, 0.23742246703477576, 0.26673936343286186, 0.2820051333401352, 0.5985071312170476, 0.5400802788790315, 54.40679535269737, 104.90355491638184, 76.00169017910957, 68.2787337899208, 92.6987998187542, 61.62089824676514, 40.22261247038841, 69.5743578672409, 39.883894845843315, 60.99389009177685, 28.64987935870886, 75.91242536902428, 26.051542684435844, 99.2490403354168, 130.29064625501633, 77.8542047739029, 72.70775333046913, 75.2660420536995, 86.74201145768166, 47.94277980923653, 12.484629079699516, 53.34941849112511, 77.42091402411461, 67.13379442691803, 54.138993322849274, 61.01473957300186, 59.24976848065853, 58.15200738608837, 66.75187692046165, 64.58945095539093, 41.244134455919266, 2.5054988684132695, 19.377185627818108, 81.64475217461586, 63.35008665919304, 67.95142695307732, 37.014911994338036, 18.873281367123127, 27.402013018727303, 34.628917425870895, 34.256856590509415, 29.90979105234146, 26.056003645062447, 18.973833471536636, 21.92834973335266, 32.6851811259985, 34.92026299238205, 29.799524769186974, 27.529089599847794, 15.173800829797983, 29.656116664409637, 37.078900560736656, 45.812503919005394, 37.356726452708244, 36.92137621343136, 3.3210462564602494, 2.752468278631568, 0.20560313772875816, 0.8355954091530293, 0.852000197628513, 0.3106602269690484, 0.4403295158408582, 0.09631516848457977, 0.8841798990033567, 0.5048226832877845, 1.6856226813979447, 0.5377320642583072, 0.268215881078504, 1.9156369264237583, 1.1913066124543548, 1.8332461849786341, 3.048551478423178, 3.580988645553589, 4.24135853536427, 0.7567241101060063, 0.5000220565125346, 0.20070693717570975, 0.31095206912141293, 0.14679511834401637, 0.32963100587949157, 0.3041036787908524, 1.5996887488290668, 0.791658426169306, 0.24603043013485149, 0.3477100795134902, 0.43048679712228477, 0.42846275260671973, 0.5470355681609362, 4.033216154202819, 26.323108412325382, 30.482598915696144, 60.49340754747391, 31.013894006609917, 12.915403414517641, 8.775297570973635, 10.24239694699645, 14.206690024584532, 17.63571247458458, 20.387177132070065, 17.44258403778076, 23.05913295596838, 26.826585195958614, 25.77599097043276, 27.450851798057556, 26.767333075404167, 28.854302689433098, 22.350260093808174, 15.202251803129911, 29.793334901332855, 46.76662132143974, 53.83188620209694, 64.39553216099739, 57.609005123376846, 13.371192757040262, 10.355403833091259, 84.73274007439613, 60.122357457876205, 54.30701270699501, 63.07031527161598, 71.90436244010925, 38.04029457271099, 46.001707166433334, 61.04413479566574, 59.80842210352421, 60.46565383672714, 61.350519955158234, 68.27311009168625, 63.57082061469555, 62.75953374803066, 67.71479085087776, 77.735445946455, 61.01817838847637, 43.194372206926346, 38.769205659627914, 46.85191914439201, 39.089532271027565, 36.928884610533714, 51.752717569470406, 76.16771087050438, 97.56551787257195, 47.61960715055466, 63.31852935254574, 69.1511669754982, 75.42565628886223, 5.547815831378102, 0.13491054356563836, 0.7387165201362222, 0.28949693602044135, 0.2936765336198732, 0.1451593209640123, 0.32934976159594953, 0.10935593512840569, 0.2577359543647617, 0.14060360292205587, 0.15398177958559245, 0.14141315245069563, 0.10007842123741284, 0.17930173577042297], [0.08107547764666378, 0.044243341544643044, 0.09846830216702074, 0.08627940973383375, 0.03163725821650587, 0.02783585721772397, 0.030146723256621044, 0.09966955723939463, 0.05241648403170984, 0.10404824337456375, 0.10219472213066183, 0.03222667190129869, 0.02916624041972682, 0.18812095862813294, 0.009671386505942792, 0.1469627843471244, 0.009546849487378495, 0.3518558945506811, 0.7597217930015177, 63.94467115402222, 60.52139684557915, 45.250248089432716, 59.65108014643192, 94.49608817696571, 39.542122185230255, 52.9466363042593, 37.909767776727676, 33.97535249590874, 17.49168310314417, 28.876955173909664, 35.23462012410164, 29.060247838497162, 50.638704746961594, 55.610677152872086, 66.0739628970623, 63.40517230331898, 63.32874320447445, 51.51263885200024, 13.168664574623108, 23.443999104201794, 57.87618398666382, 62.990732342004776, 43.13574135303497, 40.666371658444405, 56.553493961691856, 57.04912796616554, 52.58711859583855, 61.71401225030422, 9.055293146520853, 6.4863179717212915, 64.09915566444397, 59.80889707803726, 65.82347273826599, 48.035236448049545, 22.389209903776646, 29.42463878542185, 30.78077081590891, 26.175444535911083, 23.727059215307236, 25.29709316790104, 23.16813200712204, 16.048991717398167, 18.754374347627163, 27.774778716266155, 29.145598858594894, 31.60512138158083, 16.972617655992508, 15.051909070461988, 25.451621375977993, 24.836677573621273, 42.949266359210014, 34.00316320359707, 14.37120409682393, 2.2063100477680564, 1.374283181503415, 0.1498048091889359, 0.2551062579732388, 0.12384958201437257, 0.1006788706581574, 0.20644937903853133, 0.0997450113936793, 0.21144695696420968, 0.10977742305840366, 0.0751533469883725, 0.12885620672022924, 0.22522320679854602, 0.8546545333229005, 0.03284260252257809, 0.6856239878106862, 1.185378811787814, 2.315482939593494, 2.3695414513349533, 0.17024268046952784, 0.22489865077659488, 0.0707753881579265, 0.1187648759514559, 0.08001120077096857, 0.5348314542789012, 0.1462773367529735, 0.6886511784978211, 0.7268135400954634, 0.7829252479132265, 0.6096509238705039, 0.7228215574286878, 2.1625746320933104, 0.13100036041578278, 3.4057313622906804, 10.527545046061277, 21.30494188517332, 44.44733217358589, 33.067547008395195, 10.165746510028839, 9.355110358446836, 3.393919221125543, 6.234505483880639, 10.6988968513906, 18.08902435004711, 15.283712781965733, 20.720134265720844, 16.768471710383892, 20.509648360311985, 26.504449881613255, 23.268475122749805, 19.035661853849888, 20.111769810318947, 18.972495943307877, 15.378521494567394, 15.996336042881012, 31.802543587982655, 32.02717423439026, 53.90483468770981, 52.85289913415909, 5.236130431294441, 13.081784136593342, 40.025232061743736, 25.963980183005333, 41.51712700724602, 50.047000497579575, 61.68634593486786, 51.45214229822159, 59.97667707502842, 55.16428850591183, 52.39703759551048, 59.48094427585602, 57.19588749110699, 51.56058847904205, 59.52653802931309, 61.19709938764572, 60.48257052898407, 55.86616024374962, 33.328634798526764, 34.49797265231609, 38.19246880710125, 25.870797783136368, 32.04029493033886, 36.72526493668556, 75.18839702010155, 45.470165088772774, 32.756465300917625, 49.335636869072914, 64.48782920837402, 10.164414681494236, 0.6596659775823355, 0.1300587086006999, 0.37872532149776816, 0.02803854331432376, 0.061098936494090594, 0.01808902212360408, 0.013342748388822656, 0.13824137655319646, 0.06722715042997152, 0.05120728426845744, 0.006220426712388871, 0.05806722983834334, 0.030367194922291674, 0.1817895780550316, 0.04495722081628628, 0.05540690501220524, 0.1177223736885935, 0.06522028663312085, 0.04580492415698245, 0.013985889854666311, 0.07876694566220976, 0.0460360808938276, 0.04210322513245046, 0.043132661885465495, 0.19869436626322567, 0.028564824351633433, 0.03897301692632027, 0.10815781191922724, 0.004614323124769726, 0.07457495419657789, 0.06435946954297833, 0.30023563478607684, 1.4373221551068127, 70.64126461744308, 71.03844210505486, 48.85727293789387, 65.58546870946884, 75.99801957607269, 33.62127989530563, 47.871081456542015, 20.053653828799725, 38.98370414972305, 23.797532133758068, 27.14555338025093, 34.90294352173805, 43.88263687491417, 52.37797021865845, 66.67987078428268, 69.13333833217621, 68.88616919517517, 65.67721098661423, 64.81926262378693, 17.552012465894222, 25.872063115239143, 61.5544968098402, 66.91876396536827, 48.6085344851017, 44.02130663394928, 54.335032403469086, 54.038519114255905, 63.27629841864109, 67.50080153346062, 9.533338844776154, 10.363016724586487, 71.74439862370491, 58.797577545046806, 67.32813119888306, 64.96642112731934, 35.07310599088669, 29.486290477216244, 29.443554170429707, 25.5582607537508, 24.511308632791042, 23.50499913096428, 22.16121643781662, 15.431607495993376, 16.22752133756876, 28.87345176190138, 32.410687655210495, 33.41487877070904, 26.175400838255882, 19.262834563851357, 24.548012763261795, 31.32076743990183, 47.944216132164, 38.92935186624527, 29.249052107334137, 8.01031406968832, 2.033878150396049, 0.394286970840767, 0.03006231509061763, 0.01664810159127228, 0.062499083433067426, 0.17179050366394222, 0.04054770957736764, 0.3718227840727195, 0.09749847842613235, 0.15338800207246095, 0.40366596600506455, 0.18694398662773892, 0.5538263381458819, 0.027393036252760794, 0.42802883370313793, 0.9773129608947784, 0.948902063537389, 2.060442049987614, 0.5356455605942756, 0.6240727531258017, 0.14945307571906596, 0.11825864217826165, 0.1349886175012216, 0.33592824765946716, 0.06613202989683487, 0.8124636160209775, 0.6047697889152914, 2.4712964287027717, 0.8943103335332125, 0.8939713798463345, 2.4287282628938556, 0.16360103763872758, 6.954221064224839, 18.451526798307896, 25.254265666007996, 47.978657484054565, 29.421838335692883, 13.320124447345734, 12.054749596863985, 6.811271784827113, 8.57671357691288, 12.055444959551096, 11.181427258998156, 10.44510181993246, 19.607120789587498, 17.560360617935658, 20.556089468300343, 23.12035907059908, 22.416684329509735, 21.181053332984447, 18.60796630382538, 15.780873354524374, 22.446180246770382, 34.47738155722618, 49.32922661304474, 33.374384343624115, 55.732247829437256, 40.58328531682491, 12.446074448525906, 20.872156508266926, 37.13176712393761, 33.783462792634964, 45.03926441073418, 57.511357963085175, 61.23367242515087, 50.85571490228176, 66.71853750944138, 57.04972453415394, 53.59590746462345, 62.95488126575947, 59.039020389318466, 54.360149055719376, 65.38257479667664, 62.63088405132294, 67.64718487858772, 59.15562093257904, 43.06688144803047, 27.07077719271183, 30.89014794677496, 24.860090017318726, 27.92331464588642, 48.31792987883091, 71.75018951296806, 56.68863371014595, 36.943977400660515, 53.790996596217155, 71.33255392313004, 10.285303294658661, 0.5228961759712547, 0.13948759093182161, 0.5577242758590728, 0.08245000935858116, 0.0392054835538147, 0.06904585010488518, 0.023463904217351228, 0.00784602327257744, 0.09785312111489475, 0.03403566428460181, 0.015258454186550807, 0.06242510615265928, 0.051336262113181874, 0.05819565849378705, 0.13747089367825538, 0.12516235961811617, 0.21497405832633376, 0.2304474069387652, 0.11968167324084789, 0.1169638468127232, 0.24797502032015473, 0.18384566850727424, 0.25138928554952145, 0.14553380868164822, 0.22909378894837573, 0.13633696624310687, 0.15412303997436538, 0.3861776419216767, 0.1542561812675558, 0.23285275208763778, 0.2062917171861045, 0.7394301693420857, 3.9712904021143913, 92.48142868280411, 81.62398248910904, 65.71160674095154, 77.53644302487373, 120.78831374645233, 58.45758318901062, 80.73707208037376, 55.188459008932114, 47.65937581658363, 29.248561933636665, 54.363090097904205, 46.91550113260746, 49.4217212498188, 57.30580799281597, 71.77403703331947, 79.41991835832596, 77.02693596482277, 75.86900889873505, 68.54946926236153, 19.234115704894066, 28.718796260654926, 70.09561389684677, 72.96031057834625, 52.45401933789253, 50.68461388349533, 59.60902400314808, 67.65092387795448, 69.30000498890877, 71.10745400190353, 11.377959363162518, 7.876578820869327, 75.87165355682373, 59.574385061860085, 73.95657151937485, 52.31778144836426, 28.355843536555767, 35.03293834626675, 39.93800774216652, 30.85351411253214, 32.578992024064064, 29.627059623599052, 31.374067179858685, 21.956276334822178, 27.952156998217106, 33.83560739457607, 35.31886160373688, 39.53192353248596, 24.951957687735558, 19.923406317830086, 33.134313225746155, 31.921851485967636, 54.29533593356609, 41.83072417974472, 41.148649379611015, 7.405663440003991, 2.987967054359615, 0.6462420697789639, 0.30421829607803375, 0.21157517039682716, 0.15398557938169688, 0.3724924090784043, 0.2763465838506818, 0.5840017658192664, 0.5066076968796551, 0.5173661664593965, 0.5230016203131527, 0.25978330231737345, 2.302823206409812, 0.14304721320513636, 1.4397556870244443, 1.864126652944833, 2.960217143408954, 4.87048982642591, 1.6146819130517542, 0.5258562765084207, 0.19635508710052818, 0.2038843830814585, 0.23950910428538918, 0.5338221334386617, 0.259765075170435, 0.8210782881360501, 1.847180868498981, 2.7089513512328267, 2.149910149164498, 0.8576766180340201, 4.290480399504304, 0.18788483692333102, 9.314029812812805, 29.65061265975237, 36.99817769229412, 55.39561249315739, 41.76401875913143, 22.15890996158123, 14.09086273983121, 8.275262452661991, 11.94927865639329, 19.684108458459377, 26.231603622436523, 20.683859512209892, 26.855330653488636, 26.096245385706425, 27.751537263393402, 32.960632145404816, 30.45023985207081, 25.476722829043865, 25.47973606735468, 23.578433990478516, 19.82940886169672, 23.592884615063667, 38.35844770073891, 41.78953818976879, 66.02661743760109, 55.14140233397484, 10.188667830079794, 16.962762884795666, 48.43901418149471, 32.21258528530598, 49.39783573150635, 55.712952464818954, 68.63445550203323, 58.65275211632252, 71.1934357881546, 65.35653859376907, 60.75082093477249, 69.79438126087189, 66.51271775364876, 58.634364902973175, 70.65495908260345, 66.34418919682503, 71.86625048518181, 66.57501921057701, 41.62244975566864, 39.36993442475796, 54.08272214233875, 34.55304689705372, 44.76097114384174, 58.398830741643906, 94.11414787173271, 62.82934360206127, 50.613040924072266, 65.7215166091919, 88.51301282644272, 27.82614815980196, 0.8847808605059981, 0.3458547400077805, 0.6359535874798894, 0.2054921124363318, 0.3187968075508252, 0.2875202108407393, 0.1711991455522366, 0.19325431989273056, 0.34976274124346673, 0.14482366241281852, 0.24367387377424166, 0.09970379251171835, 0.13246666610939428, 0.2634609706001356], [0.09188217198243365, 0.044423304934753105, 0.07588442924316041, 0.02241248690552311, 0.032313414121745154, 0.08116726647131145, 0.0580760020238813, 0.033724463210091926, 0.004609713923855452, 0.24547166714910418, 0.09758867905475199, 0.12671224598307163, 0.004107190889044432, 0.2908734418451786, 0.014967789265938336, 0.21304535010131076, 0.09677246503997594, 0.8146822219714522, 0.1510752472677268, 28.316069170832634, 81.9217649102211, 63.99434208869934, 53.10701049864292, 80.95996052026749, 79.36545208096504, 26.59401297569275, 38.72936859726906, 41.933227479457855, 28.996633552014828, 16.946788541972637, 43.25408220291138, 16.936994567513466, 36.34065717458725, 42.339923456311226, 54.17328268289566, 61.75880424678326, 64.58293810486794, 70.2024793624878, 42.68215209245682, 24.332072250545025, 52.93356880545616, 64.12170365452766, 59.325061440467834, 45.70971563458443, 50.29946655035019, 50.88145852088928, 66.73832684755325, 42.90556490421295, 4.478252548724413, 42.310106456279755, 61.85506448149681, 54.993107691407204, 57.702506706118584, 23.031688928604126, 25.720840729773045, 27.54539642482996, 27.75284819304943, 29.204058721661568, 22.729954719543457, 27.476601116359234, 21.535247527062893, 19.084865413606167, 20.70605032145977, 27.692697420716286, 30.825218930840492, 34.9017845839262, 19.459821693599224, 22.437702901661396, 26.762235648930073, 26.67962048202753, 44.27739769220352, 42.96450354158878, 13.202533107250929, 4.343344112858176, 1.2007026770152152, 0.4366641672095284, 0.23551467253128067, 0.12831259839003906, 0.41269923909567297, 0.02883930952521041, 0.1891055956366472, 0.14376596838701516, 0.02859849002561532, 0.10481398392585106, 0.037998847910785116, 0.08002799557289109, 0.47512410033959895, 0.10322728703613393, 2.0597868226468563, 0.20396069070557132, 0.742067702813074, 2.3124846629798412, 1.421280603390187, 0.9284083975944668, 0.4934313101693988, 0.16458500671433285, 0.09346837163320743, 0.15761159418616444, 0.21285258466377854, 1.732209725305438, 5.028710961341858, 0.5803838255815208, 1.235473423730582, 0.7293258584104478, 0.29669838084373623, 0.5359785770997405, 2.4807094736024737, 12.131934855133295, 30.460691191256046, 39.648866057395935, 40.66829055547714, 18.09922680258751, 15.412128791213036, 8.424457646906376, 10.925331450998783, 13.49345214664936, 14.789629094302654, 15.849836803972721, 18.21980383247137, 23.266425132751465, 18.616513945162296, 19.547108709812164, 26.231622621417046, 22.49033957719803, 20.978968776762486, 23.875384256243706, 22.37464338541031, 13.079018834978342, 6.430998640134931, 20.33628836274147, 22.106014899909496, 58.78238596022129, 41.75645336508751, 3.365895012393594, 20.23722767829895, 44.80135917663574, 59.013147577643394, 45.72100102901459, 55.22226579487324, 55.925395265221596, 56.5070528537035, 59.799199998378754, 55.88134802877903, 56.286683678627014, 61.53704434633255, 52.325016260147095, 59.793849885463715, 57.933359518647194, 58.52949433028698, 56.26860424876213, 36.70808605849743, 41.65038205683231, 37.68545061349869, 25.213294364511967, 34.6708519756794, 56.60355627536774, 63.448174595832825, 25.8955230563879, 41.546708419919014, 55.323674753308296, 29.80371594429016, 0.6214590277522802, 0.13292420015204698, 0.18117942876415327, 0.0648738224117551, 0.1634058082709089, 0.04708478751126677, 0.03157863968226593, 0.031247422884916887, 0.04016874299850315, 0.10790571919642389, 0.03415021848923061, 0.037901533796684816, 0.0897284371603746, 0.09194584083161317, 0.029642420922755264, 0.13885836844565347, 0.07395744280074723, 0.042951700306730345, 0.08982178449514322, 0.0434437256626552, 0.08230152045143768, 0.029951415963296313, 0.04044225410325453, 0.06513665401143953, 0.3578034957172349, 0.0726022663002368, 0.12071172226569615, 0.017325634180451743, 0.174531017546542, 0.04278551117749885, 0.17273390694754198, 0.12600839312653989, 0.8619614818599075, 0.23618466861080378, 31.822465918958187, 95.19623100757599, 68.08378145098686, 53.378091752529144, 89.08113554120064, 67.7991995215416, 37.71662034094334, 33.53581488132477, 30.1986363530159, 36.06823459267616, 19.292638264596462, 40.95164135098457, 30.711863413453102, 38.82687136530876, 52.38515563309193, 61.859251856803894, 70.05350455641747, 70.85098296403885, 77.50302761793137, 45.35952642560005, 28.45190428197384, 58.50423328578472, 65.86911588907242, 60.71951441466808, 47.22849413752556, 53.30974481999874, 53.32189276814461, 74.67357024550438, 42.99396336078644, 11.217775158584118, 51.888925060629845, 68.24278011918068, 52.91493080556393, 75.3952807188034, 39.003121107816696, 25.933127738535404, 27.439676597714424, 26.98805183172226, 29.144749604165554, 22.220533154904842, 27.19098374247551, 18.568081744015217, 19.47057891637087, 19.170309528708458, 31.7546908557415, 30.496927946805954, 38.59127260744572, 24.423844926059246, 22.60877352207899, 24.93536777794361, 31.977214515209198, 47.35761500895023, 43.413476049900055, 30.855482406914234, 14.959750715643167, 6.583846863359213, 0.6955554080195725, 0.2945428277598694, 0.18429882387863472, 0.32288788177538663, 0.11563014064449817, 0.03706775685714092, 0.1181822751823347, 0.09335418479167856, 0.3895773907424882, 0.20451354619581252, 0.3278686723206192, 1.2056064326316118, 0.26412673643790185, 2.865840420126915, 0.6888067920226604, 0.6682387331966311, 3.408706127665937, 2.18843390699476, 1.2017849064432085, 0.2907818608218804, 0.22390752739738673, 0.19722623488632962, 0.08001405803952366, 0.42098175559658557, 2.541570095345378, 7.253304915502667, 0.9066225041169673, 1.443148786202073, 1.2000544555485249, 0.23021527798846364, 0.5789339065086097, 6.135275708511472, 16.943553015589714, 35.44410668313503, 43.90553444623947, 41.95336639881134, 22.39422183483839, 19.383536987006664, 13.652936238795519, 18.581172041594982, 15.82318028435111, 16.506363674998283, 8.062864299863577, 14.019780904054642, 19.220898114144802, 19.04983889311552, 20.862525925040245, 23.151266612112522, 20.630098097026348, 22.21067078411579, 20.71999367326498, 17.59323265403509, 18.05269069969654, 17.597617618739605, 36.83698274195194, 26.101183220744133, 53.93961802124977, 31.242687329649925, 13.051244225353003, 19.428712762892246, 29.564359188079834, 65.39496213197708, 48.75715211033821, 62.3139126598835, 55.81219173967838, 55.69723270833492, 68.56624156236649, 57.71263316273689, 57.726851999759674, 63.736009150743484, 56.93931385874748, 65.3227736055851, 60.917886570096016, 63.623709976673126, 62.16869205236435, 45.15975974500179, 30.716711953282356, 40.91433875262737, 22.32234489172697, 37.22184129059315, 65.49348324537277, 66.09750643372536, 35.918256640434265, 44.38520550727844, 65.15416145324707, 24.804265312850475, 0.8494635962415487, 0.16682419984135777, 0.2783699455903843, 0.04795456974534318, 0.19205877935746685, 0.009182600624626502, 0.10797297261888161, 0.056444178844685666, 0.019703493890119717, 0.06959118021768518, 0.04194657631160226, 0.016378507170884404, 0.09469006545259617, 0.07366532605374232, 0.03326779376948252, 0.24876260227756575, 0.1789371928316541, 0.2891572401858866, 0.1404021988855675, 0.12775704148225486, 0.16380990768084303, 0.11657955532427877, 0.08058581603108905, 0.14167465560603887, 0.3674618055811152, 0.17889972921693698, 0.3926446277182549, 0.1235871808603406, 0.25816280802246183, 0.08891824196325615, 0.2030632708920166, 0.24817401979817078, 0.9369936212897301, 0.2906822942895815, 46.72075018286705, 107.33060628175735, 79.78263169527054, 66.25038743019104, 105.61345562338829, 91.74199596047401, 44.47852090001106, 56.927112713456154, 57.5037507712841, 40.73636010289192, 34.933680072426796, 59.974108412861824, 32.85015307366848, 41.60262241959572, 58.69643077254295, 75.77931091189384, 75.37407025694847, 78.46958935260773, 89.51473027467728, 53.155188113451004, 31.36855937540531, 64.62960720062256, 73.58244359493256, 69.06026065349579, 57.295605540275574, 59.37077298760414, 60.267904847860336, 83.60934555530548, 51.507011353969574, 7.567112976685166, 58.15144121646881, 69.93525490164757, 60.29535077512264, 66.31376042962074, 26.019628196954727, 29.015936516225338, 33.148212879896164, 35.92150926589966, 37.14732728898525, 30.51819920539856, 32.971461564302444, 27.844837456941605, 26.972647458314896, 26.741074584424496, 35.53415805101395, 38.405481576919556, 46.769649758934975, 25.95624379813671, 29.000439047813416, 32.57732771337032, 34.649265334010124, 56.59610867500305, 50.03262586891651, 38.684200420975685, 14.072971399873495, 5.095069175586104, 0.752835493767634, 0.7439070416148752, 0.30892152339220047, 0.5794836301356554, 0.0830283056711778, 0.16235694580245763, 0.22369874641299248, 0.11346734419930726, 0.5292733618989587, 0.4273311555152759, 0.41145587456412613, 1.8158719735220075, 0.725069196196273, 5.474561937153339, 1.6216553701087832, 1.0318924603052437, 4.412739789113402, 2.610214836895466, 1.7395533062517643, 0.5741851113270968, 0.4332923825131729, 0.7217721012420952, 0.10357843420933932, 0.4664257139666006, 5.51078824326396, 8.755010459572077, 5.700556710362434, 4.265856295824051, 0.9299302159342915, 0.3102569142356515, 0.48232789034955204, 12.341063283383846, 25.799088031053543, 42.58449353277683, 53.10995154082775, 48.331996724009514, 24.39921274781227, 20.69897700101137, 14.479350093752146, 18.406594209372997, 20.90320084244013, 26.43960066139698, 21.875686459243298, 24.090061336755753, 27.971946336328983, 30.01452673226595, 25.305160135030746, 29.458141587674618, 27.544870153069496, 26.946723349392414, 29.313327558338642, 25.29604632407427, 17.051976397633553, 9.033192582428455, 24.82548527419567, 33.03141474723816, 67.69608065485954, 44.83569033443928, 7.613122332841158, 22.489786706864834, 51.64961390197277, 68.83694663643837, 54.47575785219669, 63.76816302537918, 63.81824433803558, 64.18882325291634, 74.61542576551437, 64.92201671004295, 64.52800065279007, 70.83097323775291, 62.65643388032913, 62.653675228357315, 70.14629557728767, 62.79517203569412, 68.4142117202282, 50.58424226939678, 48.43497879803181, 49.02920611202717, 35.867662355303764, 51.402136981487274, 80.03732442855835, 83.07351350784302, 42.043812945485115, 59.58627462387085, 73.83400529623032, 56.36638440191746, 1.0034932591952384, 0.25476573093328625, 0.2834469184745103, 0.14054990111617371, 0.2736998477485031, 0.13713520544115454, 0.28096018941141665, 0.19524894567439333, 0.16954547725617886, 0.21745513222413138, 0.07597644813358784, 0.19328566821059212, 0.20148653362412006, 0.2801311807706952, 0.13819946005241945], [0.1377193201915361, 0.04212191612168681, 0.0069447735131689114, 0.02136115865141619, 0.07122317780158482, 0.0681712142250035, 0.22432833997299895, 0.06610027339775115, 0.16622991766780615, 0.024532019851903897, 0.17183141084387898, 0.25182032492011786, 0.13981759431771934, 0.1425672069308348, 0.10101743842824362, 0.17896408826345578, 0.10349647884140722, 0.10346915296395309, 0.213589433406014, 1.9381741108372808, 64.45473298430443, 72.07233622670174, 52.39685520529747, 42.62873835861683, 92.7695520222187, 45.30389741063118, 29.794887118041515, 44.77760285139084, 37.80642092227936, 21.962154619395733, 34.388169944286346, 33.17237578332424, 58.58861915767193, 52.43174493312836, 46.41260951757431, 58.78768287599087, 64.27760168910027, 71.68511420488358, 59.087821170687675, 33.53768818080425, 69.95844885706902, 50.182470828294754, 37.762214094400406, 47.29819379746914, 40.79781040549278, 44.55031804740429, 75.58409258723259, 10.399560313671827, 15.616728812456131, 57.54771441221237, 37.78312437236309, 50.03388360142708, 26.67482703924179, 17.143845967948437, 31.960153430700302, 30.227562300860882, 30.11179581284523, 25.678985975682735, 29.503074176609516, 26.557367742061615, 19.268292970955372, 15.016948096454144, 18.8844071701169, 31.298871114850044, 37.262229323387146, 35.36425396800041, 18.762361519038677, 25.45926656574011, 24.258122518658638, 32.82468304038048, 50.01868061721325, 40.8597394824028, 28.40915087610483, 5.2841118816286325, 4.324558395892382, 0.31815268273930997, 0.4957954364363104, 0.3929726273054257, 0.20903801982058212, 0.5663645372260362, 0.42906433751340955, 0.13916211464675143, 0.009995888722187374, 0.06548178236698732, 0.02316722511750413, 0.27148976165335625, 1.3127717259339988, 0.49706130288541317, 0.40530263911932707, 0.8992371254134923, 0.2826782315969467, 1.8524154438637197, 1.2441227096132934, 0.33082987123634666, 0.02568492400314426, 0.21128427819348872, 0.05562891106819734, 0.31353432743344456, 1.7534550977870822, 2.1520107239484787, 3.870536433532834, 1.0165082733146846, 0.9594254801049829, 0.3654510900378227, 0.47787156072445214, 0.6407185911666602, 1.780520451720804, 8.467759173363447, 25.985471829771996, 50.17161101102829, 49.21090096235275, 17.469076216220856, 10.808837302029133, 7.598958592861891, 9.013148657977581, 15.99147230386734, 13.585902135819197, 17.030881829559803, 20.610192865133286, 23.067353814840317, 26.02222915738821, 21.628160141408443, 23.043606989085674, 28.60485177487135, 20.362144075334072, 23.4213238209486, 30.269728638231754, 27.21403520554304, 19.187528304755688, 6.893047671765089, 21.918637454509735, 25.349841937422752, 70.05214422941208, 21.248178631067276, 3.6557004740461707, 7.3267103265970945, 44.56736773252487, 60.924771800637245, 52.59030282497406, 59.35965858399868, 52.6422194391489, 54.94633600115776, 59.42616641521454, 54.865852519869804, 57.422074154019356, 60.4854279756546, 51.52145437896252, 62.68629267811775, 51.08776465058327, 57.57514514029026, 33.06791178882122, 39.79654133319855, 22.81843677163124, 29.042301401495934, 34.68100123107433, 56.79733447730541, 51.2017547339201, 29.55090221017599, 43.93932223320007, 43.48463103175163, 2.91579847689718, 0.599958059610799, 0.11727730772690848, 0.2894597395788878, 0.11941039600060321, 0.02393161124928156, 0.1266501282225363, 0.01721439737593755, 0.05530443668249063, 0.11459877801826224, 0.07994262632564642, 0.106173784006387, 0.01090613563064835, 0.07580228091683239, 0.03430497854424175, 0.08525704935891554, 0.07958037662319839, 0.0883808008802589, 0.06752403918653727, 0.018994839338120073, 0.12584296840941533, 0.050630090045160614, 0.2312956372043118, 0.07889230924774893, 0.08241973715485074, 0.051849160372512415, 0.0712415311136283, 0.1561332360142842, 0.08249407808762044, 0.05896718408621382, 0.06615010861423798, 0.05197827180381864, 0.10268170459312387, 0.13299586193170398, 0.21675344643881544, 3.3076807111501694, 69.14064154028893, 81.93827882409096, 55.00089727342129, 57.46435068547726, 97.45747447013855, 45.05533754825592, 33.19684647023678, 29.633241891860962, 34.88406613469124, 29.6101638302207, 28.747078143060207, 46.32656693458557, 57.65946261584759, 58.2985807210207, 58.630120530724525, 66.899324208498, 70.62139928340912, 76.77972123026848, 61.659245789051056, 41.3716784119606, 72.12415784597397, 59.49170149862766, 40.899530947208405, 54.51902613043785, 45.76220981776714, 51.89837135374546, 76.9188317656517, 17.663107104599476, 25.116135478019714, 59.50510337948799, 37.53852389752865, 64.71268594264984, 47.12499529123306, 21.366319991648197, 30.47413296997547, 26.08216904103756, 29.090228229761124, 23.71118936687708, 26.306731291115284, 26.747460141777992, 17.73699413985014, 17.45721325278282, 16.29994735121727, 37.02206701040268, 37.38402038812637, 39.37770500779152, 23.248847275972366, 20.654583983123302, 22.549908980727196, 37.76808097958565, 53.9577354490757, 44.95742440223694, 39.36352036893368, 9.533209651708603, 8.738507945090532, 0.5783635214902461, 0.8896755916066468, 0.12794559152098373, 0.4132022667909041, 0.506879382301122, 0.8311667467933148, 0.09840128623181954, 0.02604155564768007, 0.13598080957308412, 0.13378460163949057, 0.15629824512870982, 1.888190999161452, 2.1757535124197602, 0.20017067610751837, 1.2133923335932195, 0.6549779791384935, 4.068241724744439, 4.225070234388113, 0.33260998665355146, 0.7352110301144421, 0.20292481582146138, 0.06208203725691419, 0.37084160547237843, 3.0932898027822375, 1.9053699960932136, 3.007429135031998, 0.9328236419241875, 1.3333855010569096, 0.07263575942488387, 0.7406436104793102, 3.802088568918407, 4.3177092634141445, 15.172699838876724, 39.66875799000263, 51.1133486777544, 52.49341942369938, 18.35374664515257, 17.128128111362457, 10.876426175236702, 13.726356849074364, 19.048427268862724, 16.2811079621315, 16.266651637852192, 11.831799410283566, 18.644229657948017, 23.40539127588272, 22.36199576407671, 22.930285669863224, 25.212232321500778, 22.289161272346973, 22.713001929223537, 24.185194931924343, 22.385514602065086, 19.409402199089527, 15.421483889222145, 40.867563262581825, 28.019075207412243, 54.525717571377754, 19.500785395503044, 14.605912752449512, 2.4179734149947762, 37.02284976840019, 66.16812944412231, 52.71394819021225, 63.2535794377327, 57.044670805335045, 55.11692404747009, 62.43312746286392, 58.031553849577904, 57.92353704571724, 61.60593844950199, 52.141018733382225, 67.69567027688026, 55.91787546873093, 62.511327266693115, 33.80087345838547, 37.21670776605606, 27.69860990345478, 23.788405023515224, 43.359537944197655, 65.98112627863884, 60.77884443104267, 37.31141768395901, 50.14253497123718, 42.6006730645895, 2.985779559239745, 0.39295065973419696, 0.3188948897877708, 0.2094960436807014, 0.2474582925788127, 0.1505119720241055, 0.09752066864166409, 0.05224974942393601, 0.04408405067806598, 0.18748222180875018, 0.06628940973314457, 0.03704061651660595, 0.062022093989071436, 0.1297935243928805, 0.007242983292599092, 0.08375687946681865, 0.17848390387371182, 0.17859006067737937, 0.1700308418367058, 0.20032024855026975, 0.28265133616514504, 0.0943966573686339, 0.3991770709399134, 0.13674121408257633, 0.20329260936705396, 0.15063886443385854, 0.20764376182341948, 0.3431212023133412, 0.16305192257277668, 0.29401608102489263, 0.2618395263561979, 0.26527035632170737, 0.2946236031129956, 0.5913049739319831, 0.4672825976740569, 7.569059422239661, 97.20205217599869, 89.89215642213821, 73.1866492331028, 64.30411666631699, 116.44917458295822, 57.43126206099987, 43.611373230814934, 64.60936948657036, 48.97547699511051, 39.94726784527302, 50.41708163917065, 48.336731269955635, 71.37438967823982, 65.8401158452034, 63.581809625029564, 73.79038363695145, 82.63912841677666, 88.27684789896011, 71.69529005885124, 43.7674156576395, 80.78073933720589, 60.082645788788795, 48.53408508002758, 61.1150997877121, 52.33658663928509, 54.15306776762009, 95.2392067015171, 13.877176456153393, 24.841146133840084, 67.79998987913132, 48.15315932035446, 53.52858267724514, 32.88708709180355, 18.427166305482388, 42.01995022594929, 38.1363458186388, 39.057066813111305, 36.47944092750549, 35.65705485641956, 36.13420285284519, 25.89698787778616, 25.309729389846325, 23.5154789686203, 39.28090900182724, 46.08876809477806, 44.72076170146465, 26.20532613247633, 27.481789737939835, 33.04684951901436, 39.811056554317474, 61.79530888795853, 51.21402807533741, 40.98381422460079, 7.897480074316263, 10.97365915775299, 0.542885537724942, 1.4394879201427102, 0.5944572016596794, 0.5381094908807427, 2.5452326238155365, 1.2297421437688172, 0.23171750362962484, 0.09335505310446024, 0.5525506753474474, 0.8667233388405293, 0.8065468585118651, 2.553449207916856, 3.6850047390908003, 0.8014645718503743, 2.59515387006104, 0.9804983774665743, 2.978482525795698, 6.278518047183752, 0.22490003117127344, 0.5928311264142394, 1.1521599255502224, 0.2028839086415246, 0.9488666185643524, 4.430753672495484, 3.9367072703316808, 10.864236429333687, 2.0454834401607513, 0.9866141492966563, 0.2815895900130272, 0.5138366902247071, 2.0383393485099077, 12.118384782224894, 26.7723773047328, 41.850391924381256, 64.29857656359673, 58.6605416983366, 21.409793458878994, 15.942289642989635, 11.619400307536125, 15.555782932788134, 20.666555240750313, 22.969621159136295, 24.578779712319374, 29.39621441066265, 28.567725867033005, 34.390886798501015, 31.314125396311283, 28.618228957057, 34.54469874501228, 27.118546329438686, 29.809533432126045, 36.27161867916584, 30.791290551424026, 19.113409481942654, 7.854164773598313, 28.210199251770973, 35.32251700758934, 73.49209204316139, 21.951864771544933, 7.922316016629338, 7.472357461228967, 50.31691521406174, 67.34906047582626, 57.87738852202892, 66.46253004670143, 63.785330504179, 65.51283180713654, 73.67873042821884, 68.23827356100082, 66.23819008469582, 66.5715841948986, 60.4508688300848, 71.64896294474602, 61.163068413734436, 62.67167866230011, 39.210460782051086, 51.88017413020134, 32.28160098195076, 37.974732890725136, 52.831168100237846, 80.76430901885033, 71.82392835617065, 46.29155561327934, 65.96237808465958, 71.1358992755413, 9.470138736069202, 0.8055185386911035, 0.6489111296832561, 0.449845630209893, 0.4449484054930508, 0.4585509927710518, 0.20002132630907, 0.10273847889038734, 0.11754573512007482, 0.1874740284984, 0.24745909409830347, 0.14219797361874953, 0.15725040575489402, 0.15999688650481403, 0.11048663422116078, 0.2352069632615894], [0.035903111929656006, 0.08553759602364153, 0.1350034010829404, 0.04904868095763959, 0.06110239490226377, 0.031092855788301677, 0.15121935750357807, 0.05969299338175915, 0.17740713665261865, 0.053413867426570505, 0.2867874735966325, 0.14474803756456822, 0.08273788102087565, 0.0708895453135483, 0.13673808221938089, 0.07981672839378007, 0.2986143983434886, 0.24329848063644022, 0.9884693403728306, 0.4412024893099442, 16.29179298877716, 74.62458327412605, 59.775842651724815, 44.6232133358717, 74.30710271000862, 95.13965964317322, 41.06710575520992, 35.61487331986427, 50.54382383823395, 26.098244078457355, 30.455842651426792, 33.628647699952126, 62.88881801068783, 66.86963260173798, 51.84231676161289, 62.09423504769802, 62.50026226043701, 71.01185873150826, 66.98331490159035, 59.8409179598093, 66.60465762019157, 51.57342419028282, 56.46120451390743, 55.87815999984741, 45.778605937957764, 62.017593160271645, 29.02505412697792, 3.4849376371130347, 50.08925803005695, 44.64491777122021, 42.964530140161514, 26.967293545603752, 11.655011996626854, 31.114919185638428, 26.40933148562908, 27.014587707817554, 23.26276782900095, 31.213805079460144, 31.107995957136154, 21.418206207454205, 21.187387593090534, 20.203242301940918, 23.561445102095604, 33.840410336852074, 36.75719082355499, 33.441975116729736, 22.41057425737381, 28.43015804886818, 24.015450440347195, 26.656035147607327, 51.19179926812649, 41.6068097949028, 37.556151151657104, 9.977785795927048, 0.7027930696494877, 0.7861067459452897, 0.28791286633349955, 1.226525972597301, 0.33149011549539864, 0.7911024091299623, 0.4513497557491064, 0.40739448624663055, 0.008688520447321935, 0.09046558276168071, 0.2564654569141567, 1.9334550015628338, 2.7626412827521563, 0.959380476269871, 2.0132837304845452, 0.326202847645618, 1.1734823626466095, 2.653082236647606, 1.9450758467428386, 0.37499864178244025, 0.21067276335088536, 0.059601189714157954, 0.05035909853177145, 0.3802836831891909, 1.5258013573475182, 2.666579824872315, 0.48903301649261266, 0.5269556643906981, 1.1273555690422654, 1.257371292449534, 1.4021263062022626, 0.8464127162005752, 1.732141685206443, 11.491659712046385, 28.974020965397358, 47.04350106418133, 56.52853310108185, 35.63511483371258, 15.64887223765254, 9.07530477270484, 11.71114543452859, 15.95796950161457, 22.302023582160473, 17.641780748963356, 20.813844837248325, 25.180148743093014, 22.307605482637882, 24.452837370336056, 24.541368819773197, 28.045763075351715, 23.13779443502426, 17.38291773945093, 22.373208962380886, 22.147115394473076, 27.644624300301075, 18.495792523026466, 8.020830005407333, 23.739691637456417, 39.95284974575043, 59.406080693006516, 11.698508262634277, 3.477405491285026, 6.9255454279482365, 44.02677834033966, 43.17134164273739, 49.23077009618282, 55.83714880049229, 62.779079899191856, 56.107067316770554, 53.1280005723238, 52.67067611217499, 57.66576647758484, 63.62112231552601, 52.921181470155716, 49.65725161135197, 56.44573174417019, 37.53577284514904, 29.473507963120937, 25.70254661142826, 35.71893833577633, 46.7598082870245, 55.42620085179806, 36.71961843967438, 28.807489201426506, 41.55580133199692, 8.227212131023407, 0.3367199411150068, 0.03547496693499852, 0.15967000013915822, 0.0101808616091148, 0.07399534428259358, 0.03642101597506553, 0.0084848259575665, 0.04541540423815604, 0.06171881534100976, 0.040429003056488, 0.11512715747812763, 0.08940328742028214, 0.1339179210481234, 0.034040651516988873, 0.0723221871885471, 0.014929456410754938, 0.08894408354535699, 0.04643918582587503, 0.18531124689616263, 0.023515051179856528, 0.029628676347783767, 0.0035694144480657997, 0.07926290811155923, 0.08987903376691975, 0.1767122044111602, 0.08470016400679015, 0.1205845404183492, 0.00952253209106857, 0.056599718154757284, 0.02451930686220294, 0.06017232059093658, 0.034168861238867976, 0.1289976600673981, 0.355736703495495, 1.1414581560529768, 0.6138790876138955, 21.096399575471878, 85.35317838191986, 67.90218159556389, 53.25652487576008, 90.66267907619476, 79.79669854044914, 44.61736544966698, 32.47281052172184, 37.98257187008858, 36.02027736604214, 27.489457726478577, 38.96369442343712, 65.98133906722069, 70.20348250865936, 59.86241340637207, 70.56259363889694, 73.5877937078476, 75.89879170060158, 73.20935681462288, 62.0788648724556, 73.5353185236454, 52.60676734149456, 60.835066214203835, 62.240633592009544, 51.42571471631527, 66.8381778895855, 32.34446480870247, 12.434467021375895, 47.94547766447067, 46.02760277688503, 55.404435619711876, 50.081628039479256, 17.22041755914688, 26.374905332922935, 26.787629686295986, 27.2893338650465, 22.944067530333996, 25.915960259735584, 28.619082011282444, 21.57791543751955, 21.17555122822523, 15.762412045150995, 22.900134287774563, 37.52383768558502, 37.60756239295006, 38.9064846932888, 22.566922567784786, 20.821091048419476, 25.518254600465298, 29.21490903943777, 58.3802155405283, 52.950903475284576, 39.54545080661774, 11.851030178368092, 1.8295258283615112, 1.4588783984072506, 0.23802920244634151, 0.5704790039453655, 0.8913272561039776, 0.5512603477109224, 0.06187938270159066, 0.7114875968545675, 0.3366117359837517, 0.41785208915825933, 0.0951663164596539, 2.715488662943244, 5.765020726248622, 2.210852704010904, 1.928774246480316, 1.3889286643825471, 0.6856479146517813, 4.912983421236277, 5.356440050527453, 0.4838419903535396, 0.6148273742292076, 0.10415783632197417, 0.1630943437339738, 1.704591738525778, 3.4576092660427094, 3.455586349591613, 0.25354157318361104, 0.744808305753395, 1.766954348422587, 0.18514559953473508, 1.3546277862042189, 3.138495502062142, 9.598200414329767, 18.306929357349873, 45.56679770350456, 58.277362659573555, 65.93234449625015, 25.788870379328728, 19.755571223795414, 11.026827804744244, 13.35597837343812, 22.421831153333187, 24.829267971217632, 23.325601257383823, 18.618372045457363, 14.142764154821634, 17.712886333465576, 20.67463930696249, 22.002681344747543, 21.54436893761158, 23.113956414163113, 14.192134905606508, 20.742182582616806, 15.12631667777896, 25.129788145422935, 13.85269246995449, 12.692794259637594, 42.072866186499596, 37.516139298677444, 42.475401386618614, 18.387340642511845, 13.64077404141426, 5.489666126668453, 38.19307677447796, 40.01384787261486, 45.04328079521656, 57.52599477767944, 67.58650213479996, 58.369553312659264, 57.066485434770584, 52.46769480407238, 57.904085889458656, 62.304717153310776, 56.38408005237579, 54.639673456549644, 58.04459474980831, 39.14342097938061, 32.41427466273308, 24.01637189090252, 30.247534029185772, 54.19436775147915, 59.6675256639719, 46.40413597226143, 34.57477793097496, 52.0026795566082, 4.0264624916017056, 0.5291731422767043, 0.04022691253339872, 0.3404309169854969, 0.13423161202808842, 0.22416469641029835, 0.06686148684821092, 0.02596082296804525, 0.0938981790386606, 0.021205584089329932, 0.11589747708057985, 0.18020491464994848, 0.049607072869548574, 0.22105206968262792, 0.010238026461593108, 0.06725437240675092, 0.06519864560686983, 0.26087746548000723, 0.2863200689898804, 0.3389150061411783, 0.14472759881755337, 0.19567398849176243, 0.15707592683611438, 0.2165216885623522, 0.27900979563128203, 0.24855805153492838, 0.20211505849147215, 0.3056816628668457, 0.21913600765401497, 0.1831344683887437, 0.1671639402047731, 0.25765232916455716, 0.2487889039912261, 0.30499734333716333, 0.40998449258040637, 1.9006165699101985, 0.8906986867077649, 37.282911613583565, 107.88311183452606, 79.49511632323265, 65.68296387791634, 100.21578446030617, 109.64000836014748, 56.28534235060215, 56.0127791762352, 63.572617918252945, 48.529939502477646, 46.938117519021034, 47.759036868810654, 76.93036794662476, 84.43268537521362, 64.39660370349884, 80.19685506820679, 84.92940992116928, 89.72362026572227, 80.74211820960045, 70.25090396404266, 80.97608685493469, 61.36154696345329, 64.73404079675674, 68.10857132077217, 54.60639104247093, 80.47956749796867, 37.38643705844879, 8.438217658549547, 57.80089482665062, 59.53028842806816, 51.01711884140968, 32.31852360069752, 12.576643042266369, 37.24344313144684, 35.1355404406786, 34.597960487008095, 26.87932826578617, 40.831263810396194, 40.3083510696888, 27.694926001131535, 31.52004584670067, 29.50849648565054, 28.06153792887926, 46.19387045502663, 41.20793379843235, 46.20807409286499, 28.022757209837437, 32.8350754827261, 30.190204605460167, 32.06824243068695, 63.93169105052948, 57.20619633793831, 45.02957873046398, 11.464611813426018, 3.4249409940093756, 2.1600442053750157, 0.4552314552711323, 1.1008814396336675, 1.098425940144807, 1.0215181857347488, 0.8289053337648511, 1.2211996084079146, 0.49371338565833867, 0.3412466263398528, 0.5099356058053672, 3.8645852403715253, 11.07215367257595, 3.328326428309083, 4.967963146045804, 1.5959128201939166, 0.8496058511082083, 3.244193005375564, 6.92521009594202, 1.1082176584750414, 0.3832491865614429, 0.19434371846728027, 0.26679380738642067, 2.622681255452335, 3.7945110630244017, 9.001659974455833, 1.9718245114199817, 0.6356673559639603, 3.7691725976765156, 2.4674016376957297, 3.8938329834491014, 5.538862561807036, 18.310924842953682, 35.87265908718109, 45.10979622602463, 59.810572788119316, 74.93167519569397, 40.56436613202095, 23.83061695843935, 11.0198656283319, 16.652750819921494, 20.995887368917465, 31.440953090786934, 28.027894534170628, 30.21974802017212, 33.057025372982025, 34.404075890779495, 33.02499309182167, 32.728551998734474, 29.754457287490368, 33.994568064808846, 20.270511992275715, 27.769502699375153, 21.406567431986332, 33.80037948489189, 17.4956975877285, 7.196184955537319, 28.73883068561554, 50.197084844112396, 54.636029452085495, 18.345064111053944, 5.931154461577535, 11.415292359888554, 50.91859392821789, 49.35358710587025, 56.08235344290733, 61.64184272289276, 75.84978193044662, 67.45952054858208, 68.92523869872093, 63.27358536422253, 65.88197439908981, 72.09144920110703, 58.08213673532009, 57.88858272135258, 63.099482506513596, 45.288759022951126, 39.070092514157295, 34.05223377048969, 49.85687769949436, 68.45264285802841, 73.63194733858109, 60.343289002776146, 49.372304901480675, 77.39465743303299, 22.748777009546757, 0.6896283198148012, 0.15149515442317352, 0.4389163776068017, 0.251192586729303, 0.23937899095471948, 0.14260845549870282, 0.19536936655640602, 0.19564344169339165, 0.2095188869861886, 0.11245345915085636, 0.20401344256242737, 0.35600028466433287, 0.3491054952610284, 0.12017640372505412, 0.12057503350661136, 0.17629115434829146], [0.06385009648511186, 0.1285510355955921, 0.06180842967296485, 0.028706402008538134, 0.13534922705730423, 0.09657798524131067, 0.09556232645991258, 0.2716551418416202, 0.26345435064285994, 0.13343605940463021, 0.08933761477237567, 0.08736902353120968, 0.16785446408903226, 0.0889411149546504, 0.03210471106285695, 0.0909878988750279, 0.12079465726856142, 0.06004693474096712, 0.2149623620789498, 0.2538817439926788, 1.282737662550062, 46.05683080852032, 71.22939705848694, 57.02162504196167, 47.490927055478096, 96.42985761165619, 64.09155607223511, 34.04834657907486, 51.60508409142494, 35.851653814315796, 31.820868104696274, 32.346759885549545, 63.477357029914856, 71.30283951759338, 71.44101530313492, 63.39982219040394, 62.393590584397316, 66.53917193412781, 60.09633265435696, 65.55101215839386, 58.968283385038376, 58.30917075276375, 60.481605380773544, 53.78845453262329, 65.10335817933083, 33.32107700407505, 1.06651964597404, 24.885409958660603, 54.5386216789484, 38.60464408993721, 25.63489694148302, 12.582911755889654, 34.42873656749725, 30.288963206112385, 30.705692544579506, 26.316764652729034, 26.251900233328342, 39.304254949092865, 34.51706662774086, 24.53411690890789, 20.819548331201077, 20.607643201947212, 22.10359062999487, 36.884483993053436, 34.10622887313366, 32.83025734126568, 21.94322593510151, 25.266991183161736, 21.68577264994383, 30.457531660795212, 46.227654442191124, 37.31626622378826, 38.157598078250885, 16.419557332992554, 1.1310220160521567, 0.8522771077696234, 1.1263190559111536, 0.7493956689722836, 0.49390934233088046, 0.702100022463128, 0.1430890109622851, 0.15994273941032588, 0.3439800156047568, 0.1077948794409167, 0.988717395812273, 2.185752675868571, 6.300090439617634, 1.2339042266830802, 1.9620716222561896, 0.5336741788778454, 0.9641230374109, 2.5108461314812303, 2.6293123746290803, 1.1521463887766004, 0.32141929026693106, 0.19852995086694136, 0.20068540005013347, 0.8445548533927649, 1.6655152291059494, 1.29440956749022, 1.7131605162285268, 1.2275907467119396, 1.2355268583633006, 1.6442309087142348, 1.2894872878678143, 2.3252902133390307, 10.502034164965153, 16.600408628582954, 39.37334664165974, 46.58133566379547, 58.28047849237919, 38.35032753646374, 22.530341930687428, 13.929522447288036, 9.833569284528494, 11.69209610670805, 20.377043075859547, 19.81857944279909, 21.521596759557724, 29.90481711924076, 37.19529591500759, 33.20649795234203, 30.89955434203148, 29.230098724365234, 31.875425577163696, 30.668631233274937, 31.021189615130424, 36.3786855340004, 27.059746384620667, 38.324625715613365, 21.013769209384918, 9.062287621200085, 32.81960271298885, 52.25455664098263, 36.42272897064686, 11.969959046691656, 4.493096927180886, 3.1030215555801988, 13.578057456761599, 8.724324256181717, 16.834134086966515, 33.752327263355255, 63.302953988313675, 58.888825848698616, 52.26980522274971, 51.73173889517784, 59.46452155709267, 47.62137785553932, 48.2407446205616, 38.65910656750202, 26.943501122295856, 32.611176297068596, 29.12257019430399, 43.212884813547134, 65.33773720264435, 47.49696113169193, 30.141196735203266, 27.444701828062534, 18.762614205479622, 1.2717794068157673, 0.04547185199044179, 0.20486492343479767, 0.06363632826833054, 0.28840740385930985, 0.07863731472752988, 0.12997263431316242, 0.15973855974152684, 0.08432787304627709, 0.1494954078225419, 0.1426066446583718, 0.07298940763575956, 0.14948043128242716, 0.04309693489631172, 0.048271537307300605, 0.0728540844283998, 0.05645997174724471, 0.10433201096020639, 0.02715928014367819, 0.009438445831619902, 0.008390178936679149, 0.03165813111991156, 0.19358138437382877, 0.138120154151693, 0.2044206441496499, 0.255940550705418, 0.31211430206894875, 0.07672417676076293, 0.05059106420958415, 0.029541397925640922, 0.19275681377621368, 0.019382548416615464, 0.08236730442149565, 0.06554881314514205, 0.14044730662135407, 0.029208451924205292, 0.1784647416207008, 1.9336162554100156, 56.27146929502487, 82.76520565152168, 57.118109464645386, 60.733338072896004, 94.16293725371361, 65.10081231594086, 34.99548375606537, 33.89052964746952, 37.24159263074398, 29.665042385458946, 37.530931904911995, 68.24225574731827, 74.7499917447567, 74.24717992544174, 70.10577455163002, 71.43710151314735, 75.44470086693764, 70.21446391940117, 70.28184190392494, 66.67312234640121, 62.239786237478256, 65.74003681540489, 57.91649602353573, 73.24922427535057, 29.60981994867325, 11.119671072810888, 31.344286277890205, 41.84033006429672, 49.52052354812622, 40.7561494410038, 16.475325040519238, 29.216104075312614, 25.06417326629162, 34.42096218466759, 25.52462685853243, 24.765085615217686, 32.57839545607567, 31.586669571697712, 22.658246867358685, 19.776017926633358, 14.680551197379827, 22.11415596306324, 38.05430442094803, 34.52333629131317, 39.48975719511509, 24.597337916493416, 21.43237754702568, 22.312609814107418, 32.437878996133804, 58.31209659576416, 49.30417075753212, 40.673310086131096, 14.94964325800538, 1.3106303033418953, 0.4907580348663032, 1.416901694610715, 0.8578467776533216, 0.6012847821693867, 1.1516210669651628, 0.3513877181103453, 0.06115525808127131, 0.35290478670503944, 0.43325070349965245, 0.5790351948235184, 2.955680899322033, 9.488763436675072, 1.8391782604157925, 1.4538154075853527, 1.2986867129802704, 0.3190926573006436, 5.84381234832108, 5.866254419088364, 2.0319205429404974, 0.9865035396069288, 0.12874948588432744, 0.33410499861929566, 0.15915083815343678, 3.691272740252316, 0.4742255376186222, 0.8088631904684007, 2.643772498704493, 3.7718775775283575, 1.48000443354249, 1.1607057857327163, 0.3166981623508036, 13.49866546690464, 27.774081453680992, 55.91425806283951, 55.58401398360729, 66.46689221262932, 38.10611084103584, 21.108811609447002, 18.82732853293419, 13.596437070518732, 16.15348421037197, 26.298052556812763, 25.812932588160038, 24.478079415857792, 21.37113433331251, 21.265013627707958, 22.55179177969694, 17.72733125835657, 17.026595659554005, 20.922595001757145, 25.674971491098404, 24.145143181085587, 31.82276040315628, 19.108600839972496, 30.5579374730587, 18.11299156397581, 15.437581725418568, 45.8356598764658, 41.36711485683918, 26.92725319415331, 17.13427048176527, 12.60727509856224, 4.475995944812894, 8.515299372375011, 4.563006050884724, 9.641139060258865, 28.634079806506634, 62.766437977552414, 64.32237088680267, 55.846142917871475, 51.98110431432724, 58.62983174622059, 50.89984953403473, 49.35583658516407, 47.53213584423065, 29.969231262803078, 31.773026771843433, 19.581823647022247, 43.93178343772888, 77.94815853238106, 53.83472464978695, 46.20344594120979, 37.89835698902607, 29.239894598722458, 1.6539289383217692, 0.12951404642080888, 0.30152572493534535, 0.03509015223244205, 0.35672791593242437, 0.02861676170141436, 0.13633334456244484, 0.0732001182041131, 0.040285445720655844, 0.1399891046457924, 0.06189739462570287, 0.20274517155485228, 0.17576563957845792, 0.015215456933219684, 0.09974605782190338, 0.13465279567753896, 0.04097973600437399, 0.22594953188672662, 0.13775356288533658, 0.2501750725787133, 0.0789119242108427, 0.28952582040801644, 0.18279287265613675, 0.3775282669812441, 0.37375394138507545, 0.5035195907112211, 0.33302606432698667, 0.1775678264675662, 0.20018819079268724, 0.2787618589354679, 0.4299534601159394, 0.11553416610695422, 0.20017070579342544, 0.2624632272636518, 0.23705275874817744, 0.4827981744892895, 0.25600588938686997, 2.354389289394021, 82.1773087978363, 98.29178050160408, 77.22717002034187, 67.15931385755539, 113.9850752055645, 85.32357797026634, 55.88165581226349, 67.6525729894638, 57.77649253606796, 52.29547284543514, 47.84077048301697, 79.14527669548988, 85.35643860697746, 84.04730245471, 86.3036821782589, 82.32455849647522, 82.17409417033195, 78.44048291444778, 71.755790412426, 70.14266297221184, 68.81804645061493, 71.82121530175209, 64.44894209504128, 78.94755810499191, 44.61178734898567, 7.489308351650834, 30.66277004778385, 63.12969848513603, 55.052217319607735, 29.96239922940731, 12.810546141117811, 44.862999469041824, 34.45205971598625, 46.15442477166653, 29.72893975675106, 33.368475660681725, 50.9321516007185, 41.78308233618736, 33.517024889588356, 36.39724753797054, 26.585759818553925, 29.566325582563877, 44.19202387332916, 39.710118770599365, 42.68565930426121, 28.249749429523945, 27.705814316868782, 27.412965930998325, 37.90905341506004, 64.26194652915001, 54.657570496201515, 46.63280010223389, 20.442863143980503, 3.5983902867883444, 0.7117416488472372, 2.7215493377298117, 1.4940233062952757, 0.49111545318737626, 0.8164083980955184, 0.4835570353316143, 0.14252904569730163, 0.39650183636695147, 0.274665174074471, 1.6919926833361387, 3.685024450533092, 15.144019927829504, 3.462171871215105, 3.337500086054206, 3.0394963268190622, 0.5286479985807091, 4.330212017521262, 6.605184618383646, 2.7233727648854256, 0.7442063349299133, 0.16357237589545548, 0.5746634106617421, 0.6687148951459676, 10.018739998340607, 1.4641161798499525, 4.496316304430366, 12.697939183562994, 11.836235672235489, 4.498320696875453, 1.2588655622676015, 2.7882082108408213, 21.064555384218693, 59.48428429663181, 58.694956451654434, 52.15236492455006, 75.68481758236885, 47.88904309272766, 29.151990115642548, 19.406398460268974, 14.945404585450888, 16.64222728461027, 28.63953821361065, 30.628370493650436, 33.63898314535618, 37.52660013735294, 43.721540719270706, 49.863664135336876, 43.08184504508972, 37.74279333651066, 37.33480162918568, 40.5445121973753, 33.93602080643177, 40.247413739562035, 28.00885185599327, 44.37049649655819, 20.144543051719666, 7.099119164049625, 36.739536970853806, 51.90025985240936, 33.348762318491936, 17.03935917466879, 7.106614736840129, 4.690137254074216, 12.308093402534723, 10.380306746810675, 18.910694159567356, 38.90865057706833, 76.39842689037323, 74.87636536359787, 63.82549434900284, 63.374386355280876, 69.20263901352882, 62.03298233449459, 60.12928068637848, 49.528237134218216, 30.46901274472475, 41.95658102631569, 37.34779313206673, 62.946278527379036, 86.51402369141579, 67.45281770825386, 57.17835523188114, 58.60124208033085, 58.92588526010513, 1.865243436768651, 0.6626964930910617, 0.3905691672116518, 0.1236429977871012, 0.5849850224331021, 0.21106978267198429, 0.1884103220072575, 0.29447303619235754, 0.15380921540781856, 0.2531158772762865, 0.2051392212160863, 0.324001251719892, 0.27178911434020847, 0.21545767143834382, 0.20030870073242113, 0.2779593598097563, 0.09482983412453905], [0.053426123995450325, 0.08618635183665901, 0.04799388501851354, 0.2078561348025687, 0.03793797695834655, 0.02042112100753002, 0.10800225034472533, 0.17890752176754177, 0.36682343983557075, 0.06856551728560589, 0.07185666763689369, 0.11019670680980198, 0.13014249707339332, 0.01992342935409397, 0.15225812676362693, 0.04964324143656995, 0.11893027098267339, 0.03801433653279673, 0.2830371935851872, 0.02980416644277284, 0.1398413282004185, 9.826475065201521, 78.83232548832893, 68.25310796499252, 47.03458674252033, 72.48315498232841, 76.65542989969254, 44.21377010643482, 51.90299190580845, 33.30797150731087, 32.45330236852169, 30.576934553682804, 55.266639813780785, 75.30116736888885, 65.12317031621933, 64.65606898069382, 69.03180778026581, 65.33001601696014, 57.67906956374645, 66.59562930464745, 59.93311621248722, 66.12615689635277, 54.905469194054604, 65.17726421356201, 41.67202569544315, 5.389869706705213, 9.098558574914932, 50.37168547511101, 52.115028128027916, 30.437846817076206, 21.001913845539093, 33.57643850147724, 34.057766273617744, 26.85346495360136, 26.772293709218502, 19.471667557954788, 23.34956657141447, 34.94001053273678, 25.333886593580246, 24.991986639797688, 22.92604699730873, 21.316565461456776, 30.386633165180683, 31.475193053483963, 37.39203415811062, 29.12957701832056, 21.522582806646824, 22.445357590913773, 30.172898434102535, 33.385601341724396, 47.94923946261406, 37.9416024684906, 38.469751328229904, 22.861026786267757, 0.35562107688747346, 1.7226692684926093, 0.6233904522377998, 2.359623983502388, 0.11663596596918069, 0.4390802141278982, 0.13879368285415694, 0.24405140429735184, 0.11816683851066045, 0.14339814515551552, 0.6943639938253909, 1.0067226109094918, 9.606438372284174, 0.9275964286644012, 0.7587640068959445, 0.7765917596407235, 1.3094877521507442, 5.630434323102236, 2.624779217876494, 1.5803672606125474, 1.8790053483098745, 0.8612177311442792, 0.07245872751809657, 1.5155015350319445, 1.7646508407779038, 1.963162044994533, 1.0517433076165617, 0.8666272752452642, 0.7614870357792825, 1.010660387109965, 0.5836025497410446, 2.375917509198189, 6.155643565580249, 14.423335399478674, 38.827448934316635, 48.05224433541298, 61.06224462389946, 43.30840788781643, 26.11435141414404, 16.151814199984074, 9.358281288295984, 13.651317525655031, 17.21988368779421, 24.793565087020397, 27.17062633484602, 29.924116283655167, 41.57303720712662, 46.59566089510918, 44.52304311096668, 51.30999192595482, 49.89840567111969, 26.122256889939308, 22.57459055632353, 17.69697278738022, 27.720194645226, 26.09740812331438, 27.61910106986761, 12.558631058782339, 12.699650041759014, 47.00172610580921, 48.70601065456867, 29.68431305140257, 24.074301682412624, 3.230065838433802, 0.5742691818159074, 0.3241495625115931, 0.38492982450407, 0.10393425691290759, 9.896633550524712, 52.42944225668907, 61.242206767201424, 55.12236535549164, 58.32551367580891, 42.38895982503891, 35.31773306429386, 23.905138559639454, 34.70554031431675, 27.502574622631073, 28.040924035012722, 53.368238881230354, 57.16264687478542, 45.81857979297638, 32.11558789014816, 27.040088139474392, 8.445643410086632, 1.320321208331734, 0.25484148936811835, 0.031862544565228745, 0.0995529732608702, 0.17848954419605434, 0.21288270101649687, 0.1273983615101315, 0.09828470225329511, 0.15997175738448277, 0.024732266138016712, 0.07565350999357179, 0.007811735122231767, 0.2733690576860681, 0.14974862860981375, 0.02878349259844981, 0.07443404261721298, 0.061560329704661854, 0.020762011699844152, 0.06911293283337727, 0.053173749256529845, 0.08930525713367388, 0.07937333968584426, 0.05033539062424097, 0.16928781842580065, 0.24549342691898346, 0.2760970441158861, 0.07364082775893621, 0.13729672646149993, 0.07221933294204064, 0.21828333934536204, 0.030985890043666586, 0.013609749930765247, 0.04235453860019334, 0.048067224051919766, 0.10738273515016772, 0.2575472113676369, 0.07498087186831981, 0.29889098193962127, 11.82733939960599, 95.45033857226372, 75.00454768538475, 56.86969019472599, 87.54199013113976, 72.28761747479439, 54.862508699297905, 39.21360321342945, 36.54887080192566, 30.066179260611534, 32.85649113357067, 69.08340141177177, 83.10803845524788, 67.42569476366043, 74.23326507210732, 77.0218214392662, 73.49768534302711, 65.0509361922741, 69.86555144190788, 65.181375592947, 72.99603626132011, 57.41291664540768, 75.47122344374657, 38.04162070155144, 13.808440994471312, 22.69829861819744, 35.69356709718704, 55.94084523618221, 47.33433745801449, 21.820091642439365, 31.656635217368603, 30.326514691114426, 25.912502445280552, 24.372847862541676, 18.310624659061432, 21.73316180706024, 34.4985768198967, 27.581496387720108, 22.901131734251976, 13.046475481241941, 18.314401656389236, 29.756454080343246, 33.27385313808918, 37.18979001045227, 34.767689779400826, 23.057476244866848, 21.163034699857235, 26.321098320186138, 39.53964851796627, 61.983224004507065, 44.283127784729004, 49.85066123306751, 24.38266083598137, 0.924770567798987, 0.9913431736640632, 0.43205756752286106, 1.358845322392881, 0.5942346761003137, 0.6677948695141822, 0.19667142012622207, 0.344140556990169, 0.09900557255605236, 0.4587136715417728, 1.1320941522717476, 1.6559918713755906, 8.944701980799437, 1.6491581755690277, 0.5809771281201392, 1.2474512122571468, 0.7035261928103864, 6.740300143137574, 5.773965446278453, 1.9624796253629029, 3.198302867822349, 0.8259040885604918, 0.12879932852229103, 1.3489782018586993, 2.5065972469747066, 2.258025985211134, 1.3863970502279699, 0.935931756393984, 0.8230328082572669, 0.7646874734200537, 0.43650000414345413, 0.6337122421246022, 8.307828605175018, 13.562200907617807, 56.835290640592575, 56.36130027472973, 71.92903071641922, 43.68098549544811, 23.686669282615185, 23.145487122237682, 17.201308384537697, 18.386158905923367, 20.31588725745678, 33.02036873996258, 36.8724500387907, 34.65796306729317, 35.26492729783058, 33.86558398604393, 32.242698669433594, 45.83649963140488, 37.93211817741394, 22.858682312071323, 17.382463663816452, 12.68234197050333, 20.05768921226263, 20.79291746020317, 25.1033890619874, 8.960104454308748, 20.99572017788887, 46.32060505449772, 33.84381115436554, 24.16216056793928, 30.597248263657093, 10.1225589774549, 1.6742521477863193, 0.2054625452728942, 0.8942230569664389, 0.21154658286832273, 3.417683383449912, 41.71426422894001, 63.23842965066433, 58.66583101451397, 61.461227014660835, 46.53309725224972, 36.30865529179573, 29.990897700190544, 31.063371151685715, 25.377859733998775, 21.627443879842758, 56.45707793533802, 65.28434246778488, 59.42161425948143, 43.304699286818504, 46.66074760258198, 16.72919701784849, 2.0245076157152653, 0.2477397001348436, 0.1582870673155412, 0.04425790248205885, 0.4442674107849598, 0.19055882468819618, 0.10439620673423633, 0.09483137779170647, 0.04557101405225694, 0.04161639852100052, 0.11829324852442369, 0.09432507722522132, 0.19718222552910447, 0.19587929622502998, 0.0503102874790784, 0.07552061360911466, 0.06941313899005763, 0.11967521655606106, 0.1808474215795286, 0.19862076005665585, 0.40106081985868514, 0.20114444807404652, 0.13708499172935262, 0.24656103603774682, 0.25755519687663764, 0.4668076825328171, 0.34023786953184754, 0.1482146984199062, 0.2914186235284433, 0.2848924737190828, 0.206012966518756, 0.23149629909312353, 0.0898376367695164, 0.27877495042048395, 0.2979305834742263, 0.41968525329139084, 0.40116213785950094, 0.38296022394206375, 21.348630040884018, 123.55076551437378, 90.677460283041, 66.8886011838913, 102.36993446946144, 89.37114357948303, 70.73166936635971, 76.64154544472694, 48.06916482746601, 58.0261467397213, 47.73006722331047, 81.59932181239128, 92.29032173752785, 82.20478132367134, 84.28117230534554, 90.60668528079987, 86.93528428673744, 71.81638196110725, 76.71159848570824, 72.50843122601509, 78.58937412500381, 60.82248128950596, 77.98193871974945, 55.380603298544884, 11.567728780210018, 15.777153354138136, 52.423734962940216, 71.41238003969193, 43.48699830472469, 23.13997931778431, 38.82114887237549, 43.88511814177036, 33.65304999053478, 35.41693054139614, 22.346460297703743, 32.69658051431179, 43.5315965116024, 32.986983731389046, 38.33123356103897, 34.39619891345501, 24.836081005632877, 39.111217707395554, 38.166250213980675, 43.194311410188675, 36.56774438917637, 27.233083583414555, 23.3003269135952, 34.302435144782066, 45.37913717329502, 71.78801268339157, 50.20428165793419, 52.644871696829796, 29.37157653272152, 0.581688639940694, 3.502591964788735, 0.8460402768105268, 3.399000260978937, 0.7050662976689637, 0.5083641526289284, 0.26372161286417395, 0.5162519949954003, 0.20574644644511864, 0.5861057247966528, 1.8718975922092795, 2.589942212216556, 12.769954819232225, 3.5963136982172728, 0.8953632926568389, 3.3666628086939454, 0.7525458186864853, 4.717494836077094, 5.5142218340188265, 1.9856717996299267, 2.8969700122252107, 0.7603221014142036, 0.29963716689962894, 3.000698033720255, 4.7205042745918036, 5.77361349016428, 1.7002815823070705, 2.068401910364628, 0.6578402942977846, 1.3576297438703477, 0.5197463824879378, 3.4696033224463463, 19.221844263374805, 47.59470708668232, 75.67185267806053, 59.33996044099331, 84.42348226904869, 51.58436380326748, 33.88791158795357, 23.243478164076805, 15.9379293769598, 21.525396555662155, 20.34477900713682, 37.3786398768425, 39.758611768484116, 41.94348692893982, 48.926155641674995, 53.485865369439125, 54.28884208202362, 61.60106711089611, 54.93447683751583, 33.14413569867611, 24.24564588814974, 18.639398217201233, 27.858121544122696, 24.426347091794014, 31.39592170715332, 11.060318257659674, 10.997102949768305, 48.370104879140854, 50.226411670446396, 28.162490911781788, 28.98702386766672, 3.6445112619549036, 1.0569229046814144, 0.6716848514042795, 1.2979752011597157, 0.3487188066355884, 11.625885609537363, 67.11888402700424, 75.30217811465263, 64.41138491034508, 68.21947976946831, 55.82017131149769, 52.03272074460983, 36.307131573557854, 37.496604546904564, 33.97084213793278, 38.94506402313709, 69.18923333287239, 77.1994923055172, 70.62256962060928, 50.64355708658695, 67.50172108411789, 32.46679164469242, 1.5338059840723872, 0.3618863766314462, 0.30828410759568214, 0.14557740243617445, 0.48348810465540737, 0.45958257804159075, 0.1720239091082476, 0.17323168023722246, 0.19040459155803546, 0.19005774141987786, 0.17485071992268786, 0.3161799057852477, 0.41431706165894866, 0.2091753319837153, 0.12526177772087976, 0.3118580236332491, 0.10427453904412687], [0.14752386283362284, 0.05549797024286818, 0.1549326637177728, 0.025328045594505966, 0.14125826623057947, 0.15968849445926026, 0.16412165423389524, 0.036837754159932956, 0.4184497258393094, 0.32136451976839453, 0.18462636333424598, 0.082264932570979, 0.07525199325755239, 0.11337592644849792, 0.11047605861676857, 0.07156463994760998, 0.19381145015358925, 0.12569162965519354, 0.2553332067327574, 0.24629632680444047, 0.2147785172564909, 1.0188801772892475, 28.196618780493736, 78.29761058092117, 49.29491065442562, 54.64964412152767, 82.04180046916008, 58.222087025642395, 55.828401669859886, 35.75312130153179, 27.328526861965656, 32.173694372177124, 44.7839181125164, 71.45979389548302, 65.15476182103157, 68.37889641523361, 67.11870923638344, 68.1904037296772, 67.3359663784504, 68.74802380800247, 61.09124466776848, 58.21455582976341, 51.64028160274029, 34.00213725864887, 6.412871712818742, 5.780636938288808, 27.12156906723976, 71.00147768855095, 34.997976422309875, 15.379848573356867, 35.80280363559723, 31.77611030638218, 30.47594927251339, 34.32864993810654, 34.86627168953419, 35.02560093998909, 38.20821896195412, 31.123913303017616, 22.968583814799786, 26.352594830095768, 27.198670729994774, 22.40767501294613, 34.82197746634483, 38.88514123857021, 37.50341758131981, 25.253367014229298, 22.985373213887215, 27.618170119822025, 30.93992717564106, 35.37126079201698, 49.07957620918751, 40.015079006552696, 38.13697278499603, 19.526990689337254, 0.10076625854708254, 0.7792053662706167, 0.7276822091080248, 0.7731860142666847, 0.2786400279728696, 0.46126380970235914, 0.39798633952159435, 0.2790459827519953, 0.23421993653755635, 0.03824241706752218, 0.867482585599646, 0.4223239445127547, 6.279756780713797, 1.0906933550722897, 0.9378024435136467, 0.8018307771999389, 0.8886947692371905, 7.67778773792088, 1.7210995964705944, 1.3979777600616217, 2.9201131453737617, 1.1535943485796452, 0.23284249560674652, 1.381833020132035, 1.1240339535288513, 1.1417862446978688, 0.977559294551611, 1.0669682594016194, 0.8342960570007563, 1.2994947633706033, 0.7003556785639375, 1.9457928207702935, 5.09649314917624, 9.919937700033188, 24.307548366487026, 46.135668978095055, 63.2618173956871, 46.834926456213, 28.737071380019188, 19.043550230562687, 8.460857793688774, 11.122496221214533, 19.33058112859726, 26.79582204669714, 29.60988264530897, 33.53931449353695, 39.31941993534565, 38.89442794024944, 41.661952435970306, 41.17325305938721, 48.92069153487682, 48.177523612976074, 41.12238138914108, 49.858697801828384, 39.65349420905113, 29.47025913745165, 22.104487381875515, 32.95042209327221, 10.92200092971325, 24.2615632340312, 59.127137660980225, 29.737004823982716, 32.785165160894394, 12.488775607198477, 2.064859550446272, 0.25500784919131547, 0.3715907590230927, 0.5782513681333512, 1.185596943832934, 0.5395506229251623, 26.12963229417801, 42.81916134059429, 43.77533443272114, 36.25223211944103, 20.374770797789097, 14.862607028335333, 29.021999090909958, 23.512011654675007, 31.23339492827654, 43.34666043519974, 47.60599248111248, 32.09262952208519, 30.031741708517075, 25.90864185243845, 3.201204724609852, 0.33875188208185136, 0.49268135509919375, 0.33522558223921806, 0.33332016260828823, 0.0582160972408019, 0.24935710709542036, 0.13120206131134182, 0.10150465837796219, 0.2636538102524355, 0.2190763983526267, 0.12332955913734622, 0.17932849761564285, 0.121477477659937, 0.05310645130521152, 0.10542737640207633, 0.05689010940841399, 0.0774304119113367, 0.08273783649201505, 0.044388557580532506, 0.1235710465698503, 0.010125085500476416, 0.03423272675718181, 0.2660275547532365, 0.21475013752933592, 0.08857957771397196, 0.36413193738553673, 0.49379864358343184, 0.12381253400235437, 0.16534744470845908, 0.05413042956206482, 0.2010854473337531, 0.09254887292627245, 0.014315878397610504, 0.2634755166945979, 0.11988015321549028, 0.23340504354564473, 0.16414185549365357, 0.15566446585580707, 1.2450046185404062, 33.274388909339905, 90.94031497836113, 53.383734449744225, 66.13299652934074, 79.49093654751778, 68.64932790398598, 55.43680228292942, 35.175035521388054, 34.75659437477589, 33.101984560489655, 60.07315769791603, 77.8801041841507, 74.13235768675804, 76.84257745742798, 76.51471585035324, 76.18869334459305, 73.73133480548859, 71.44844770431519, 67.44741439819336, 61.63200505077839, 53.586126789450645, 28.67225255817175, 12.067885491997004, 19.85827211290598, 26.367790214717388, 54.84308034181595, 57.41765879094601, 27.731001265347004, 38.200224190950394, 32.35345132648945, 27.230342030525208, 33.074356243014336, 29.376124888658524, 25.277632512152195, 25.02309937030077, 30.693335607647896, 23.98362524807453, 17.053686305880547, 20.724046155810356, 22.276262864470482, 36.797248274087906, 39.61915545165539, 42.56341986358166, 31.087957732379436, 23.573976829648018, 25.544611886143684, 32.05664165318012, 40.69717280566692, 55.888297855854034, 47.67531596124172, 47.762734070420265, 30.035102628171444, 0.19458384776953608, 0.34828764852136374, 0.7188685226719826, 0.5741732963360846, 0.4083589813672006, 0.5466301774140447, 0.6080261548049748, 0.19837807776639238, 0.323667285265401, 0.04622020402166527, 0.6709679367486387, 1.6913818661123514, 8.95386328920722, 0.6345290201716125, 0.4778351658023894, 2.042031087912619, 0.7960609055589885, 10.367979258298874, 3.921038811095059, 5.189388664439321, 6.277144420892, 0.9811341902241111, 0.27339233143720776, 0.7860074762720615, 0.7899720885325223, 1.1055215843953192, 1.0081812576390803, 0.8185843750834465, 1.4389748289249837, 0.7356011623051018, 0.5950835742987692, 0.3943168942350894, 4.403383266180754, 6.356225777417421, 43.23141261935234, 55.46883076429367, 67.61854201555252, 47.89917714893818, 23.10743596404791, 24.333288185298443, 15.031875595450401, 19.624288268387318, 22.09147498011589, 32.71385818719864, 36.14331096410751, 41.77868977189064, 44.01063680648804, 38.29451233148575, 40.19927032291889, 39.33784134685993, 38.02118919789791, 28.265277296304703, 22.479289770126343, 26.20103996247053, 19.103256426751614, 14.644033256918192, 11.015202328562737, 19.91100948303938, 10.479481425136328, 34.565658420324326, 48.400153666734695, 27.335311397910118, 28.290310353040695, 12.484312746673822, 6.657726299017668, 0.4201436333823949, 0.35803863778710365, 1.6083166608586907, 2.3003801750019193, 1.3966405880637467, 22.632529847323895, 37.02187322080135, 38.622784316539764, 30.549912303686142, 20.845588333904743, 19.497804455459118, 21.917848996818066, 17.25958775728941, 24.238414876163006, 48.24026204645634, 55.54805651307106, 43.0434101074934, 38.22281017899513, 43.675532788038254, 4.362049559131265, 0.395576823502779, 0.7341267226729542, 0.09278756988351233, 0.20761784602655098, 0.1871478249086067, 0.42902111483272165, 0.12176636606454849, 0.11858002922963351, 0.1340554706985131, 0.34238012332934886, 0.0200768628201331, 0.16501433914527297, 0.2555361099075526, 0.058095249623875134, 0.11300871177809313, 0.0928418876719661, 0.05149065480509307, 0.3034064162056893, 0.16777843848103657, 0.2989634749246761, 0.2229814903694205, 0.15908478701021522, 0.5158907175064087, 0.46364239300601184, 0.14397295337403193, 0.511757192434743, 0.4702177917351946, 0.25353815930429846, 0.33808350388426334, 0.18762561958283186, 0.22467437374871224, 0.2358588806237094, 0.13812330085784197, 0.41175130871124566, 0.3642658208264038, 0.3572071949020028, 0.4113458882784471, 0.4485593398567289, 1.5565179591067135, 59.46495473384857, 105.25581881403923, 66.6860644519329, 77.83341228961945, 92.25410968065262, 83.25225591659546, 88.69911924004555, 50.1255688816309, 52.79308274388313, 58.05936075747013, 74.31850969791412, 91.28116428852081, 85.14846816658974, 95.65178856253624, 83.38954254984856, 84.65016290545464, 80.78858211636543, 81.84869483113289, 73.08170646429062, 66.0309948027134, 57.89738304913044, 47.074454203248024, 13.681048080325127, 10.743800941854715, 31.86859354376793, 79.20551866292953, 55.2844912558794, 16.988451406359673, 35.74376240372658, 41.241698786616325, 36.969531029462814, 41.88755393028259, 37.56880447268486, 42.41352550685406, 48.23380999267101, 42.123536467552185, 33.48595775663853, 39.86744932830334, 37.53465190529823, 30.883410908281803, 41.439253985881805, 45.42758457362652, 41.464268043637276, 30.098492726683617, 25.632575266063213, 28.81115410476923, 38.692423179745674, 53.74396272003651, 65.27373343706131, 46.17705635726452, 50.94667062163353, 38.23042497038841, 0.2674467785982415, 0.5072119832038879, 2.173846964724362, 0.8161842101253569, 0.3216157219139859, 0.6236120278481394, 0.647010994143784, 0.32750398095231503, 0.42671532137319446, 0.13180207286495715, 1.611991657409817, 2.1453237952664495, 13.35753059014678, 1.5172638092190027, 0.7459639187436551, 3.693119678646326, 0.9710480470675975, 7.033382216468453, 4.82411521486938, 4.03421170078218, 4.078552946448326, 1.1508664512075484, 0.3383803035831079, 3.5625109495595098, 3.392338980920613, 1.6599759575910866, 0.9109362820163369, 0.9967701137065887, 1.616930679883808, 1.3543002912774682, 0.62850491842255, 4.1410942655056715, 12.496597487479448, 32.58491970598698, 71.07109755277634, 59.716596230864525, 76.67474046349525, 61.129299625754356, 36.42934821546078, 26.48012738674879, 12.154205460101366, 16.767331771552563, 22.019050866365433, 34.36398044228554, 40.97526088356972, 47.79218249022961, 49.45552043616772, 43.94524231553078, 49.63564597070217, 52.18312807381153, 53.90560604631901, 58.8866675645113, 53.315262123942375, 59.638571217656136, 47.01765865087509, 32.871295139193535, 24.225094690918922, 38.359424248337746, 10.558428838849068, 28.378727808594704, 62.95290917158127, 38.17294545471668, 36.36746093630791, 14.166518580168486, 2.721540075726807, 0.2067179325968027, 0.46997127996291965, 2.1186278527602553, 1.576529941521585, 2.673883745446801, 47.396350130438805, 52.15556055307388, 56.34514734148979, 43.29001307487488, 30.582630448043346, 21.9710461422801, 39.3011999130249, 30.11088576167822, 46.59022718667984, 64.15413111448288, 66.90340518951416, 56.26369871199131, 52.9094211012125, 73.58596220612526, 7.784591456875205, 0.4481538600521162, 1.0689561464823782, 0.6179440976120532, 0.6538718822412193, 0.25712065456900746, 0.5327513033989817, 0.3293673653388396, 0.15974626323441043, 0.25155098468530923, 0.26504242792725563, 0.26785700814798474, 0.21430355758639053, 0.2791334077483043, 0.2673624409362674, 0.2177235225099139, 0.17884749686345458, 0.15743517084047198], [0.11295185584458522, 0.08313702288432978, 0.20695349026937038, 0.13823796267388389, 0.15808849828317761, 0.05528735615371261, 0.11478768428787589, 0.09321790421381593, 0.08961131141404621, 0.03802330538746901, 0.24262480350444093, 0.208519006264396, 0.23997267941012979, 0.10330309742130339, 0.06892952587804757, 0.07903115023509599, 0.33012972911819816, 0.16686516639310867, 0.006188532915984979, 0.3281589411199093, 0.3809389699017629, 0.33473428047727793, 1.1396268918178976, 48.86744499206543, 75.03927782177925, 44.79800395667553, 62.140991538763046, 81.16635024547577, 54.67329405248165, 44.29371781647205, 20.427405573427677, 24.191962368786335, 36.315802708268166, 65.75811624526978, 55.580860152840614, 64.64948773384094, 67.46043249964714, 63.658276721835136, 62.54796490073204, 76.9591324031353, 65.45187547802925, 27.988395653665066, 9.58311902359128, 1.7975701368413866, 4.399740686640143, 14.89504873752594, 53.248932883143425, 62.99092233181, 20.036569945514202, 15.147172808647156, 25.263417474925518, 38.98016653954983, 28.27979251742363, 26.482994332909584, 28.241954147815704, 50.952051132917404, 69.20146867632866, 46.42060808837414, 32.51388631761074, 33.485870361328125, 27.26936023682356, 32.07140386104584, 34.34747412800789, 35.291932448744774, 28.501104041934013, 21.586656868457794, 23.485494777560234, 24.4480724260211, 27.824531346559525, 39.11075033247471, 52.74843513965607, 43.35381165146828, 31.087433360517025, 14.307892844080925, 3.890930889174342, 1.3030719151720405, 0.6174633640330285, 0.2719534555217251, 0.05519146325241309, 0.6907987163867801, 0.5330536840483546, 0.5248150136321783, 0.28554957127198577, 0.40791790816001594, 0.38670735724736005, 1.8239911878481507, 1.9302543858066201, 1.6880600131116807, 2.1591422287747264, 1.0291422391310334, 0.9440407587680966, 8.945805821567774, 1.8730564112775028, 3.8364278012886643, 4.510856224223971, 0.061340397951425985, 0.16405851230956614, 0.32090064778458327, 0.42107571149244905, 0.6658886186778545, 0.046271831524791196, 0.6180431297980249, 0.6698565557599068, 0.7404552830848843, 0.12577356275869533, 1.0084025957621634, 3.447740483097732, 4.134543417021632, 14.957107957452536, 37.449278086423874, 60.208624228835106, 57.78968162834644, 33.1022809445858, 25.819635428488255, 19.55265261232853, 10.34071097150445, 22.145004607737064, 31.598443239927292, 41.405432000756264, 41.44338436424732, 41.51923589408398, 51.17279268801212, 46.13818824291229, 63.15304443240166, 71.16968706250191, 88.41779753565788, 90.28215229511261, 89.71703141927719, 100.36822468042374, 73.68523567914963, 68.18495482206345, 44.780825078487396, 38.85567381978035, 10.098451171070337, 45.981222465634346, 55.46283468604088, 46.8757476657629, 54.968420416116714, 13.834736533463001, 1.2769302679225802, 0.20383117109304294, 0.07306490631890483, 0.235851934121456, 0.3477278910577297, 1.201776119414717, 10.146769378334284, 16.464001648128033, 16.598485931754112, 11.038081850856543, 15.870823077857494, 46.97764679789543, 25.971663370728493, 35.813853442668915, 43.517981842160225, 32.73317635059357, 20.678321309387684, 28.6688669398427, 8.760187681764364, 0.9352098545059562, 0.5627620336599648, 0.5280208541080356, 0.2691764576593414, 0.3393472923198715, 0.44492471613921225, 0.1838561921613291, 0.44256308348849416, 0.11566400484298356, 0.1758529755170457, 0.07505972505896352, 0.1731907730572857, 0.017716812799335457, 0.06770933861844242, 0.10848188554518856, 0.07429500124999322, 0.10048493262729608, 0.09389422339154407, 0.0756541927694343, 0.024956841880339198, 0.1226151677838061, 0.08925383372115903, 0.17989493440836668, 0.10387720059952699, 0.154945369285997, 0.0030343248135977774, 0.15932614827761427, 0.1105602626921609, 0.11487497569760308, 0.0237810164981056, 0.08597052044933662, 0.014131468615232734, 0.11653108565951698, 0.030719889473402873, 0.35417564038652927, 0.1920695256558247, 0.06159844640933443, 0.27670798008330166, 0.6535521650221199, 0.13687916449271142, 4.514228543266654, 61.578465923666954, 83.62014457583427, 54.597947895526886, 70.39935439825058, 89.90537971258163, 61.64400480687618, 37.39722087979317, 28.21913067251444, 33.12945708632469, 54.06099870800972, 72.57881864905357, 66.47291108965874, 77.33220398426056, 82.66793847084045, 73.8545773923397, 65.65312787890434, 84.98209789395332, 70.26599675416946, 25.162458792328835, 6.896386267617345, 2.230374631471932, 16.658454313874245, 20.865233279764652, 37.769296914339066, 65.99779978394508, 37.456592693924904, 17.195644788444042, 29.189651794731617, 31.428998932242393, 23.573976829648018, 17.193382009863853, 16.4559555798769, 38.0024030059576, 52.71732620894909, 39.0877615660429, 23.41683816164732, 24.058114551007748, 23.35641000419855, 31.692661084234715, 31.936229914426804, 39.54469844698906, 34.21178720891476, 29.21100664883852, 25.720496848225594, 28.192475102841854, 31.017898991703987, 43.63128796219826, 60.16139276325703, 48.79392273724079, 46.32013387978077, 20.180565118789673, 2.2740359511226416, 0.3401385701727122, 0.2794989006360993, 0.19936203199904412, 0.01643091392907081, 1.1681899591349065, 1.542267536278814, 0.37196183286141604, 0.37966710689943284, 0.3436635044636205, 2.2404725896194577, 1.808499894104898, 2.940797097980976, 1.0440465831197798, 2.963111400604248, 2.069112709723413, 0.46031341538764536, 15.71133803576231, 4.63049185462296, 5.848152665421367, 6.222287239506841, 0.10744871207862161, 0.21964391868095845, 0.22602782846661285, 0.3234047134174034, 1.1344842240214348, 0.479306933702901, 0.43302966223564, 0.5395969923119992, 0.6259087077341974, 0.1242776305298321, 0.6645295978523791, 1.2252175365574658, 3.5297923302277923, 36.1127720028162, 52.268197908997536, 66.74571365118027, 54.888294115662575, 27.235298864543438, 24.13091104477644, 17.696898691356182, 16.294190660119057, 26.94072727113962, 36.42377771437168, 50.41980989277363, 47.55435325205326, 46.86627857387066, 49.25302930176258, 45.623635053634644, 58.474059104919434, 65.92024594545364, 72.92741194367409, 69.66702729463577, 66.02638185024261, 77.99285173416138, 58.92415255308151, 44.24777068197727, 25.334561057388783, 21.22876927256584, 14.145985431969166, 56.14814691245556, 45.641190111637115, 41.106809824705124, 38.27748164534569, 11.665553580969572, 2.37172847148031, 0.4111616575391963, 0.1467766537098214, 0.157449820835609, 0.3338091785553843, 0.737753271823749, 5.5244632344692945, 11.440600901842117, 12.51617593690753, 8.378751799464226, 16.27598013728857, 54.447897747159004, 22.01471909880638, 32.477412074804306, 54.416564628481865, 39.072828367352486, 33.60570453107357, 42.42869429290295, 16.18277683854103, 0.8283882052637637, 0.8249278971925378, 0.5617457069456577, 0.4407398938201368, 0.3413876047125086, 0.5486996413674206, 0.13712765037780628, 0.31629458244424313, 0.08024741153349169, 0.12134299307945184, 0.058992862395825796, 0.0661802694958169, 0.05976681110041682, 0.13720467046368867, 0.10200662480201572, 0.12433743278961629, 0.02201337101723766, 0.08865037118084729, 0.28639891475904733, 0.12112129130400717, 0.286755709676072, 0.18298201641300693, 0.37345449964050204, 0.2362616144819185, 0.19409992295550182, 0.2507096860790625, 0.19911471870727837, 0.2079519015387632, 0.42914567689877003, 0.4547311586793512, 0.3957597480621189, 0.17198583693243563, 0.1973038783762604, 0.19884347857441753, 0.70725676137954, 0.4146314354147762, 0.14388773997779936, 0.53959283628501, 0.7600562938023359, 0.375328422524035, 6.121919425204396, 92.3831507563591, 98.78840625286102, 66.12626329064369, 84.75636720657349, 96.58735156059265, 90.68359315395355, 65.75904339551926, 41.21543079614639, 49.12453919649124, 65.07948786020279, 90.2340316772461, 80.40673300623894, 89.89769652485847, 103.20496246218681, 85.52255809307098, 71.11004546284676, 89.58502650260925, 77.03586548566818, 34.715252593159676, 10.579180475324392, 2.320975069887936, 9.49922427535057, 21.7177327349782, 59.2280450463295, 79.48755472898483, 24.917185753583908, 15.19127419218421, 27.20709677785635, 49.72689427435398, 34.733115434646606, 28.8043125718832, 29.517300613224506, 60.486674308776855, 82.98675656318665, 62.44572378695011, 46.52414873242378, 47.168328166007996, 34.1806098818779, 42.770721539855, 37.60068856179714, 40.84769792854786, 34.49430964887142, 26.38458911329508, 25.955314747989178, 29.240124486386776, 35.48064932227135, 54.25893768668175, 69.40076798200607, 44.01744984090328, 57.390577644109726, 43.57761204242706, 5.182818342000246, 1.4031731500290334, 0.93917221063748, 0.476289598736912, 0.5209300189744681, 1.5500516560859978, 3.5242652893066406, 1.3449333189055324, 0.6787552032619715, 0.5528915289323777, 3.0778479063883424, 4.775470225140452, 6.494010658934712, 1.2244110298343003, 3.2251968747004867, 2.5313811795786023, 0.6570822943467647, 14.595051035284996, 7.453428776934743, 21.04395478963852, 13.31065820530057, 0.16125868598464876, 1.1487756134010851, 0.5827827437315136, 0.3345671488204971, 0.6970565649680793, 0.7212847773917019, 0.6298939220141619, 0.6681964604649693, 1.0159620526246727, 0.19868326373398304, 3.6645288253203034, 8.128992151468992, 23.501161336898804, 64.42311868071556, 58.42161051928997, 68.92337679862976, 64.01688247919083, 43.27901266515255, 39.41598415374756, 26.556533686816692, 15.79453932121396, 29.728992953896523, 41.74650929868221, 52.917142286896706, 52.48414032161236, 49.33734677731991, 59.589451253414154, 53.402710631489754, 83.0158706009388, 78.35522308945656, 87.49805688858032, 95.93417420983315, 92.27465897798538, 114.31053534150124, 80.64627975225449, 78.19167226552963, 57.84060649573803, 45.74132613837719, 13.133678901940584, 56.07535421848297, 62.33876712620258, 61.92496933043003, 68.04053977131844, 18.590502440929413, 1.5547629282809794, 0.4546464351005852, 0.2880407532211393, 0.4475988226477057, 0.7802852208260447, 2.1315359976142645, 14.206057358533144, 17.88148518651724, 21.35239753872156, 14.723895471543074, 29.343429543077946, 55.927108973264694, 33.33713874220848, 52.055242136120796, 69.55342099070549, 51.40532121062279, 45.162780582904816, 71.24568298459053, 33.43032494187355, 0.9559348924085498, 0.9061252058017999, 0.855867083882913, 0.6404934532474726, 0.42782545555382967, 0.7270778634119779, 0.3102723212214187, 0.4734024067874998, 0.23968405817868188, 0.22471115458756685, 0.10964950648485683, 0.22903265082277358, 0.13422761927358806, 0.2839979185955599, 0.21468150371219963, 0.08479765252559446, 0.1406608521938324, 0.1841053311363794], [0.04878291045315564, 0.1322056379285641, 0.04563317634165287, 0.09334717149613425, 0.02794258176436415, 0.04661643295548856, 0.039455717196688056, 0.14764176041353494, 0.111957207263913, 0.06585562441614456, 0.04377823388495017, 0.1505137828644365, 0.045889228422311135, 0.07198057661298662, 0.09533176344120875, 0.08529039405402727, 0.1376291789347306, 0.253508206224069, 0.11467355681816116, 0.13513859070371836, 0.5183821369428188, 0.240457717445679, 0.6239402352366596, 4.6632536966353655, 65.1569277048111, 57.80641973018646, 52.47318170964718, 79.59328025579453, 60.90708754956722, 48.6041609197855, 29.509881511330605, 18.14969189465046, 19.01517905294895, 50.644005462527275, 47.185795828700066, 61.115149185061455, 59.08222407102585, 54.34918664395809, 70.03480955958366, 48.75049106776714, 6.587775377556682, 0.26965077908243984, 0.13906615495216101, 2.956981617026031, 28.92727207392454, 39.22972574830055, 66.07402369379997, 39.43839535117149, 16.807858496904373, 36.81455634534359, 32.79046967625618, 44.77305069565773, 52.091925367712975, 80.77096626162529, 90.33330515027046, 96.915562748909, 84.89041641354561, 59.27612006664276, 56.17103688418865, 39.828018844127655, 30.970067158341408, 35.068379044532776, 44.1657330840826, 33.51791404187679, 27.000346072018147, 24.314999766647816, 25.03587808459997, 24.296470060944557, 28.55006631463766, 45.87690286338329, 55.62982052564621, 42.884008660912514, 27.723979242146015, 8.231083173304796, 3.9944539591670036, 0.12809526786440983, 0.1650965542648919, 0.14678370411274955, 0.6604104407597333, 0.28157302527688444, 0.5223046545870602, 1.0402176948264241, 0.40255093364976346, 0.6303240708075464, 0.39747197180986404, 5.397498272359371, 3.2973412284627557, 1.1287261079996824, 2.379168472252786, 1.3221877394244075, 1.6416884888894856, 6.711864843964577, 1.4045548508875072, 3.157724132761359, 2.7967126294970512, 0.46412440307904035, 0.36583611625246704, 0.691055558854714, 1.3396139605902135, 0.6246428412850946, 0.3927094617392868, 0.48977014725096524, 0.785005398793146, 0.16511690395418555, 0.06681714352453128, 1.4856225508265197, 1.078983808401972, 2.383064925670624, 11.67313702404499, 30.16124825924635, 51.52595333755016, 53.77523884177208, 36.073098331689835, 33.861841186881065, 27.60079935193062, 17.152291014790535, 15.601782314479351, 24.39477078616619, 25.572998262941837, 33.54203514754772, 49.31096859276295, 54.83735404908657, 62.00667254626751, 64.01798442006111, 63.60748864710331, 63.6011353880167, 72.31654912233353, 66.43251165747643, 65.93270927667618, 59.18758101761341, 70.81171587109566, 73.42723712325096, 64.54177871346474, 32.37209692597389, 17.597866505384445, 59.15256209671497, 43.72276425361633, 45.38680136203766, 57.306172773242, 14.324315562844276, 0.2647488343063742, 0.2441318827914074, 0.1488510158378631, 0.09159092354821041, 0.20155736419837922, 0.06672331379377283, 2.4599872855469584, 5.404907399788499, 6.049079233780503, 11.645502056926489, 30.486862286925316, 41.831491738557816, 38.397042229771614, 39.9146693944931, 20.761628039181232, 29.558870382606983, 10.099059138447046, 1.7822495964355767, 0.0754384727042634, 0.4850716993678361, 0.07411385042360052, 0.22035122994566336, 0.1457986218156293, 0.16563979152124375, 0.1058462297078222, 0.09760577071574517, 0.07333670306252316, 0.09967728299670853, 0.04385359898151364, 0.056310670188395306, 0.08618178762844764, 0.1622624258743599, 0.16496963216923177, 0.06154749426059425, 0.08278107401565649, 0.038286151830106974, 0.09260646358598024, 0.04252976337738801, 0.06759865471394733, 0.08665777146234177, 0.07761768545606174, 0.02111731118930038, 0.028767417679773644, 0.07643450167961419, 0.1360214495798573, 0.13580233789980412, 0.1742906210711226, 0.05414547660620883, 0.18345056392718107, 0.023046527785481885, 0.04737937189929653, 0.16888788988580927, 0.10298372159013525, 0.2958941302495077, 0.251522931503132, 0.04385482352518011, 0.3555413999129087, 0.21587879571598023, 0.9791352599859238, 10.82372110337019, 82.91505441069603, 67.87625178694725, 67.65135705471039, 86.26204401254654, 75.87652489542961, 35.92416912317276, 34.18346352875233, 30.083460733294487, 35.60658596456051, 66.28335446119308, 59.02145393192768, 75.35672038793564, 70.2481073141098, 66.29739090800285, 73.19275170564651, 50.30002512037754, 4.9271975085139275, 0.21822736656758934, 0.4603995638899505, 13.06844875216484, 36.024365946650505, 29.528728500008583, 53.47519554197788, 59.12123657763004, 26.32126171141863, 29.134340062737465, 28.38912785053253, 23.169165551662445, 29.496772214770317, 41.86130113899708, 55.26782914996147, 66.77458450198174, 70.65435111522675, 49.0005062520504, 40.78467831015587, 34.65852923691273, 33.757042810320854, 36.570913419127464, 43.7023289501667, 38.06615598499775, 33.68751794099808, 27.961692586541176, 23.25145773589611, 24.672070406377316, 30.21038342267275, 46.68543867766857, 60.15566647052765, 49.71282742917538, 49.580552726984024, 13.942011427134275, 2.5796632887795568, 0.20294454210670665, 0.24066945217782632, 0.5653135373722762, 0.5770233215298504, 0.38929754169657826, 0.5122988414950669, 1.2779303267598152, 2.415156103670597, 1.3646218436770141, 1.6865622997283936, 10.199362356215715, 4.524926394224167, 1.1774906725622714, 3.9058586256578565, 1.0368878860026598, 2.2518375422805548, 16.547369174659252, 4.490054715424776, 4.038934372365475, 0.7976954709738493, 0.20613935426808894, 0.328899277956225, 0.7744921941775829, 0.23664411739446223, 0.7275178679265082, 0.3018397424602881, 0.4307158832671121, 0.7919023255817592, 0.5405506817623973, 0.02536607138608815, 0.6332600070163608, 3.413196299225092, 11.565973274409771, 33.81180167198181, 42.937714979052544, 55.66924341022968, 59.24800917506218, 29.98570527881384, 23.519691042602062, 21.1209424585104, 18.976713716983795, 23.85273177176714, 34.243051931262016, 34.677220433950424, 40.01349829137325, 54.11660112440586, 55.99315702915192, 59.64858368039131, 64.27200838923454, 68.4124106168747, 62.794343680143356, 68.21177378296852, 68.32339659333229, 64.67575192451477, 56.112250238657, 63.253081664443016, 65.05622550845146, 48.343247920274734, 19.921662211418152, 25.584116466343403, 66.45810708403587, 42.3757441341877, 45.77664904296398, 46.132617741823196, 14.715525470674038, 0.14921644935384393, 0.5239522224292159, 0.25237390771508217, 0.2646191662643105, 0.24554015253670514, 0.08018805456231348, 0.2686671068659052, 4.0955218859016895, 6.209034975618124, 12.89213726297021, 40.239586159586906, 34.42135736346245, 43.051123693585396, 49.810128808021545, 34.34044070541859, 45.90379022061825, 25.921931639313698, 2.7811997244134545, 0.05011522509448696, 0.39377901528496295, 0.07662610936677083, 0.12227141982293688, 0.13019812846323475, 0.20690535457106307, 0.018655919047887437, 0.16543530015042052, 0.08680606741108932, 0.09281391612603329, 0.1625782245537266, 0.012532196033134824, 0.06417096403311007, 0.27111358183901757, 0.13538180734030902, 0.12167834735009819, 0.02137922067049658, 0.10991657574777491, 0.1677902534720488, 0.24363961623748764, 0.16989410854876041, 0.17759889276931062, 0.281867123558186, 0.17812369507737458, 0.2904053247766569, 0.18849845946533605, 0.2896988298743963, 0.30533436744008213, 0.38068714435212314, 0.20772018819116056, 0.4969280428485945, 0.17125011625466868, 0.12767816602718085, 0.3264544653939083, 0.24841076490702108, 0.6591513426974416, 0.3280240186722949, 0.180728618579451, 0.6552046013530344, 0.4628270398825407, 1.6634891065768898, 21.990259811282158, 110.59362798929214, 73.3492349088192, 80.44204831123352, 96.28483459353447, 96.07972159981728, 73.32630693912506, 50.80116122961044, 39.947180449962616, 42.78691627085209, 85.31712591648102, 81.60144209861755, 92.27386102080345, 82.88366049528122, 76.1139589548111, 86.72209292650223, 65.28060346841812, 8.96715022623539, 0.3519159194547683, 0.6041812361218035, 6.8466507364064455, 34.24404367804527, 46.455133035779, 79.6985574066639, 52.93954588472843, 20.846025310456753, 38.643048629164696, 41.08653411269188, 54.94047291576862, 64.58638831973076, 86.60606995224953, 100.56085154414177, 105.16714677214622, 98.49699229001999, 73.49032133817673, 70.99553480744362, 57.86449961364269, 41.02853402495384, 43.842055052518845, 46.92641794681549, 40.87784931063652, 32.29832008481026, 27.975653037428856, 28.09618826955557, 30.667035318911076, 40.771333426237106, 52.38311894237995, 64.26174893975258, 51.28196083009243, 64.13536012172699, 25.932932049036026, 4.878264209255576, 0.2502457844093442, 0.7768046075943857, 0.7571198232471943, 1.1056614643894136, 0.5807575711514801, 1.1763887316919863, 1.6186238452792168, 1.9258517283014953, 2.2727131471037865, 2.8514895401895046, 10.340412687510252, 4.6282746735960245, 3.6746156215667725, 4.457961637526751, 1.6046371520496905, 1.6589383757673204, 19.02095854282379, 8.744835555553436, 12.32197880744934, 8.348833154886961, 0.620675201062113, 0.384524671244435, 2.2710996586829424, 1.9341165223158896, 0.7398752204608172, 0.6970627990085632, 0.5948991654440761, 1.462347493506968, 0.9236477874219418, 0.18261462362715974, 1.7695730016566813, 6.900253985077143, 24.51082605868578, 52.09328569471836, 52.60133743286133, 62.05139234662056, 63.30595962703228, 41.562644764781, 42.707325741648674, 35.19472986459732, 28.30595411360264, 26.64104875177145, 38.79974462091923, 35.524191185832024, 45.66354811191559, 61.66527606546879, 63.0923692882061, 65.6534394621849, 66.34719103574753, 69.837356954813, 53.81115451455116, 65.05901455879211, 68.4535776078701, 63.16269971430302, 59.5894892513752, 71.85470670461655, 86.23226121068001, 84.28673520684242, 41.33228212594986, 29.67865325510502, 68.88511285185814, 54.7965594381094, 57.63667903840542, 64.76619467139244, 19.101523719727993, 0.4668800567742437, 1.3218582258559763, 0.20698440814157948, 0.45386338024400175, 0.2743098634527996, 0.24177360464818776, 3.4587311558425426, 7.290650261566043, 10.319091081619263, 21.67458415031433, 41.6580044478178, 52.288211435079575, 58.29945087432861, 64.32868614792824, 44.71902899444103, 69.2567253112793, 48.15176859498024, 3.5855187149718404, 0.2306123121525161, 0.49042071390431374, 0.43089307844638824, 0.6132097891531885, 0.3102465538540855, 0.24154885264579207, 0.15682028664741665, 0.3262314945459366, 0.1208081420918461, 0.28711199993267655, 0.24968056473881006, 0.10037201485829428, 0.3218386630760506, 0.2996504365000874, 0.3037835459690541, 0.31270790146663785, 0.12928139796713367, 0.19374124298337847], [0.11155324144056067, 0.14327021373901516, 0.04774216708028689, 0.0264959615378757, 0.06424495615647174, 0.2222179836826399, 0.2914467657683417, 0.10155977768590674, 0.07803900269209407, 0.011464113795227604, 0.0997276822454296, 0.04067937028594315, 0.038061102968640625, 0.04719208722235635, 0.04776723311806563, 0.06705150633933954, 0.17846349481260404, 0.05808851834444795, 0.20159887993941084, 0.15970060630934313, 0.29275668610353023, 0.5056419549509883, 0.2580584620591253, 1.6253435472026467, 50.80264315009117, 79.60502162575722, 45.61861552298069, 72.5218217074871, 66.36153146624565, 47.997230887413025, 44.638021141290665, 51.66051931679249, 22.45089389383793, 30.730020739138126, 30.867694951593876, 42.11182929575443, 49.76928099989891, 52.90938690304756, 24.002208150923252, 1.0362752876244485, 0.23458786366973072, 0.12497090036049485, 0.35618032969068736, 12.709691952914, 37.62119606137276, 38.23919489979744, 68.36349204182625, 18.515511564910412, 29.65717300772667, 42.038238644599915, 68.24051544070244, 97.00146093964577, 97.6349401473999, 93.45591679215431, 93.11200484633446, 92.17133492231369, 82.6796418428421, 75.96796318888664, 65.9441314637661, 59.57044467329979, 42.78191573917866, 33.29581595957279, 28.09612177312374, 29.90685760974884, 21.493417471647263, 26.5055613219738, 28.742102310061455, 32.70590901374817, 37.29705065488815, 47.61589854955673, 60.855706706643105, 47.99099162220955, 22.00249705463648, 7.7990135829895735, 3.0576028302311897, 0.17854156874818727, 0.10183353369939141, 0.08042594257858582, 0.1666881048004143, 0.12222930294228718, 0.5131707759574056, 0.06793977547204122, 0.8106620376929641, 1.2193133658729494, 0.8675319829490036, 4.406284410506487, 3.1894624046981335, 3.214737460948527, 4.271027818322182, 2.3040313040837646, 2.8092536190524697, 9.589194897562265, 1.162295644171536, 0.6925159273669124, 1.3711441936902702, 0.371465157950297, 0.12828752864152193, 0.7799985143356025, 0.07256464683450758, 0.2660217956872657, 0.07597618096042424, 0.17007177870254964, 0.038568939780816436, 0.08035341248614714, 0.4809737380128354, 0.7703852083068341, 1.905623513739556, 1.969320208299905, 10.046837590634823, 30.93197040259838, 46.2460720539093, 46.5703010559082, 27.129917219281197, 32.573136538267136, 26.62220936268568, 14.819296002388, 12.385191265493631, 17.095550559461117, 28.98401252925396, 37.45706006884575, 52.64764554798603, 56.84257484972477, 65.84133937954903, 66.34009301662445, 67.19016060233116, 72.07755714654922, 69.27461475133896, 60.70393905043602, 54.58871439099312, 58.030919283628464, 54.08132381737232, 64.63755637407303, 71.50889486074448, 79.17553827166557, 32.36755236983299, 37.50321999192238, 50.6177032738924, 30.148878023028374, 49.19934198260307, 51.852842196822166, 1.9763537496328354, 0.12801429955288768, 0.16810097586130723, 0.02177101527195191, 0.14507979241898283, 0.25683632295113057, 0.013667664352396969, 0.9865894506219774, 3.229896747507155, 8.85458031669259, 17.926379777491093, 33.36254797875881, 46.15707702934742, 32.87559650838375, 25.14564659446478, 15.913625881075859, 3.7081502471119165, 0.1409219397464767, 0.07700879039475694, 0.2631671098060906, 0.11768009353545494, 0.0861024743062444, 0.06611832985072397, 0.04671263013733551, 0.12843815493397415, 0.07893729823990725, 0.08452679088804871, 0.018845728882297408, 0.07550893220468424, 0.1844868395710364, 0.01152755350631196, 0.024864231127139647, 0.19145386962918565, 0.13798699801554903, 0.07343601726461202, 0.0876630179118365, 0.10370493328082375, 0.07078508802806027, 0.035932682803831995, 0.03844927217869554, 0.05107864781166427, 0.11948478146223351, 0.18117410014383495, 0.09978923597373068, 0.15694551664637402, 0.05241107748588547, 0.1146833754319232, 0.0649021056597121, 0.0767597701633349, 0.04130895271373447, 0.14683372486615553, 0.019880666804965585, 0.07572013259050436, 0.05609363281109836, 0.09661978299845941, 0.11835334022180177, 0.1434388296911493, 0.36676742252893746, 0.05666419594490435, 2.6013266388326883, 68.53603318333626, 86.45011112093925, 64.26359564065933, 76.68337360024452, 78.88310596346855, 42.16398909687996, 54.07311625778675, 78.01004961133003, 42.196872532367706, 46.845733076334, 43.6202609539032, 59.0396511554718, 62.45547406375408, 62.16854386031628, 23.70360877364874, 0.4300263983896002, 0.6049289647489786, 0.25504507531877607, 1.074221832677722, 28.48236344754696, 39.30079713463783, 33.90707775950432, 70.40086671710014, 39.87309202551842, 23.770319893956184, 30.852026492357254, 40.453518480062485, 69.7993665933609, 72.35876485705376, 80.46468749642372, 83.28879475593567, 84.24540862441063, 77.88520351052284, 70.17436847090721, 61.60044774413109, 60.519071370363235, 44.46309752762318, 37.91535347700119, 34.51594948768616, 43.89065444469452, 28.21632642298937, 29.552329033613205, 26.926711723208427, 35.39839893579483, 33.68360795080662, 52.260195538401604, 67.19386160373688, 56.968017518520355, 45.795963406562805, 11.901040244847536, 2.1856042463332415, 0.4306314862333238, 0.16955080587649718, 0.05021199001930654, 0.12461838021408767, 0.4401385464007035, 0.4477045638486743, 0.22897264076163992, 1.1859760922379792, 2.7906992146745324, 0.7528684451244771, 5.562219908460975, 4.663974707946181, 4.822842758148909, 3.2010277966037393, 0.8079242845997214, 5.330032892525196, 21.951188407838345, 6.379232592880726, 3.8247249042615294, 1.6298961779102683, 0.4076618968974799, 0.23629772738786414, 0.888677432667464, 0.1589753053849563, 0.8385488006751984, 0.6626013200730085, 0.11870010130223818, 0.16099201748147607, 0.25869430450256914, 0.63388162991032, 2.2242360608652234, 9.235740713775158, 14.305970147252083, 36.271124705672264, 41.1058446764946, 47.717577293515205, 47.32639588415623, 24.576268047094345, 29.824130348861217, 18.917547091841698, 17.720656916499138, 20.322364009916782, 22.967907451093197, 32.01025374233723, 42.65371821820736, 57.11642235517502, 56.644518077373505, 66.66357725858688, 65.98991140723228, 66.47788882255554, 76.03963494300842, 72.2601069509983, 64.18387591838837, 56.27684220671654, 57.3007732629776, 55.2060254663229, 63.660324811935425, 68.92561107873917, 70.2829210460186, 29.731662310659885, 42.34460860490799, 52.661883383989334, 34.685093611478806, 48.14924173057079, 56.830719485878944, 2.955930973403156, 0.09870690264506266, 0.3544897469691932, 0.21762107644462958, 0.35571233136579394, 0.15904113388387486, 0.02362426934269024, 0.5070779810193926, 2.986982907168567, 11.882360447198153, 23.95222943276167, 31.605982035398483, 53.8887083530426, 47.14514181017876, 40.63668765127659, 33.064271584153175, 7.69349324516952, 0.15536502411123365, 0.13029610679950565, 0.12263088647159748, 0.10710999587900005, 0.053043569132569246, 0.07860343568609096, 0.07905537393526174, 0.2180468910955824, 0.02310215731995413, 0.05857969394128304, 0.021408212669484783, 0.028263274907658342, 0.07984547919477336, 0.04849193661357276, 0.030324367435241584, 0.07352628468652256, 0.08382238884223625, 0.05623990269668866, 0.0024095222806863603, 0.23054571182001382, 0.18941817339509726, 0.14760680525796488, 0.09662987620686181, 0.1401846160297282, 0.2935463609173894, 0.3014576551504433, 0.14340716967126355, 0.22853153786854818, 0.24810413917293772, 0.33556278445757926, 0.2288559009321034, 0.15354780131019652, 0.16296461632009596, 0.19181096140528098, 0.20988562668208033, 0.3271719440817833, 0.10344415743020363, 0.25606166920624673, 0.27102523657958955, 0.24849470180924982, 0.5890277680009604, 0.3878224192885682, 2.7788998978212476, 92.49086737632751, 101.1016309261322, 67.65663877129555, 86.48195341229439, 87.22695663571358, 68.5342700779438, 65.77234268188477, 77.8369688987732, 48.23758698999882, 60.08236840367317, 68.06476727128029, 73.2814009487629, 78.10236945748329, 76.44165337085724, 33.02003435790539, 1.6524858470074832, 0.7829725672490895, 0.4056732082972303, 0.7993640564382076, 18.983872532844543, 39.66710887849331, 47.42900937795639, 79.79800567030907, 30.442315377295017, 32.53071941435337, 50.48930436372757, 84.57721441984177, 114.96360629796982, 97.08657637238503, 92.76756092905998, 89.02659326791763, 88.16571146249771, 86.73118203878403, 81.20747163891792, 69.05421897768974, 71.15600779652596, 52.69108861684799, 41.70436196029186, 32.51594580709934, 41.95404656231403, 25.193816609680653, 32.93425776064396, 34.500693306326866, 46.69441759586334, 46.08790174126625, 61.98793575167656, 66.84884771704674, 57.10846558213234, 52.59617730975151, 18.261559791862965, 4.793110778555274, 0.5413232278078794, 0.4143995884805918, 0.13908162130974233, 0.19455398374702781, 0.7404201349709183, 0.830479993019253, 0.2539267478277907, 3.5268287267535925, 4.253358291462064, 0.6117655104026198, 9.659544322639704, 4.835173096507788, 7.471248870715499, 4.819533610716462, 2.6551251020282507, 5.442405212670565, 27.692190147936344, 11.561390720307827, 7.482704780995846, 6.019091717898846, 0.2508193161338568, 0.704229095717892, 1.3009690842591226, 0.3000118921045214, 2.2459108103066683, 0.6693622260354459, 0.39672997256275266, 0.21856010105693713, 0.3085773152997717, 0.8735570346470922, 2.29724558070302, 9.617813061922789, 19.756350181996822, 44.982890635728836, 47.81789571046829, 52.73852527141571, 51.69097848236561, 27.93874181807041, 43.59061114490032, 37.00684882700443, 26.6404901817441, 20.76485026627779, 24.066532999277115, 39.72744204103947, 49.0151696652174, 59.84382480382919, 58.5344834625721, 65.03987118601799, 63.66255909204483, 68.7246322631836, 77.27270677685738, 68.41727435588837, 63.32591235637665, 54.97879385948181, 54.84167441725731, 51.66445970535278, 62.825505807995796, 77.53235444426537, 92.39324301481247, 44.00627464056015, 50.5854582041502, 55.41657216846943, 43.28573830425739, 59.11593206226826, 63.226171508431435, 3.36893271189183, 0.2140493571641855, 0.328424273757264, 0.11180343426531181, 0.2914796577533707, 0.2997155673801899, 0.14555325295077637, 1.5149314468726516, 4.431014908477664, 16.754657551646233, 27.6306239515543, 48.5106897354126, 66.18876233696938, 57.55814865231514, 56.203118562698364, 60.30353933572769, 13.885435312986374, 0.35272830398753285, 0.3999699221458286, 0.19657262542750686, 0.35754941403865814, 0.2015038998797536, 0.20096124149858952, 0.17275974852964282, 0.2858293609460816, 0.197056268225424, 0.2956879319390282, 0.10994971264153719, 0.19076787284575403, 0.3147867164807394, 0.23145007813582197, 0.17302711465163156, 0.2655758836772293, 0.2191800912260078, 0.12004515490843914, 0.1773379833321087], [0.06772789231035858, 0.03616657806560397, 0.004953001753165154, 0.031963736400939524, 0.07318362026126124, 0.09125258584390394, 0.061006335017737, 0.05718651205825154, 0.02765261167951394, 0.03317142960440833, 0.0883968015841674, 0.0592846711515449, 0.0821037677815184, 0.113903489545919, 0.048206298815784976, 0.05918405076954514, 0.14356144733028486, 0.06115669784776401, 0.19843857764499262, 0.06992289054323919, 0.33270652522332966, 0.14915183797711506, 0.0764908900600858, 0.20380901056341827, 14.518715981394053, 79.85436424612999, 54.965779557824135, 57.364431247115135, 84.02041509747505, 47.930799052119255, 50.06929770112038, 38.08203153312206, 25.03131452947855, 15.480945948511362, 23.029353953897953, 32.261667251586914, 19.070431888103485, 5.452610515058041, 0.36487999255768955, 0.01784272928489372, 0.16166708985110745, 0.08756224910030141, 1.2458106502890587, 26.285397335886955, 31.756317168474197, 69.07345354557037, 50.486530512571335, 19.57680031657219, 55.31212717294693, 80.25379881262779, 107.41135194897652, 76.05801835656166, 68.40150520205498, 59.8355108499527, 69.51600059866905, 73.18122312426567, 67.89767503738403, 57.9542887955904, 62.05596350133419, 58.4128025919199, 65.2696144580841, 52.49765619635582, 36.40850633382797, 21.923172511160374, 19.407650493085384, 24.37204420566559, 27.19135422259569, 30.392211265861988, 30.721159614622593, 47.96279713511467, 58.22642259299755, 43.066136687994, 23.504077680408955, 7.497294098138809, 2.3525380762293935, 0.20658998633734882, 0.15151658764807507, 0.13424235832644626, 0.2633460861397907, 0.44792272557970136, 0.3576009190874174, 0.17317475751042366, 0.03490853756375145, 0.9277134505100548, 3.5658599948510528, 2.4698477564379573, 3.4355545369908214, 5.174950864166021, 5.51269194111228, 0.7547065964899957, 10.278401914983988, 15.973941944539547, 1.5663855546154082, 4.376926710829139, 1.476625227369368, 0.15120573167223483, 0.40644548716954887, 0.2680142247118056, 0.2377226360840723, 0.16501699603395537, 0.191807146766223, 0.039464162837248296, 0.5587994400411844, 0.8962244808208197, 0.18697664112551138, 3.2795615075156093, 6.472659129649401, 4.964203247800469, 13.310048338025808, 27.71390788257122, 38.443099558353424, 45.43378584086895, 24.088881500065327, 29.026574045419693, 27.982158288359642, 19.832878075540066, 18.94642174243927, 32.15767443180084, 48.75035807490349, 57.670770809054375, 57.8211173415184, 69.6751968562603, 61.38626843690872, 66.62772998213768, 67.05540463328362, 67.44464054703712, 63.03876556456089, 60.45951336622238, 58.96900534629822, 59.74396236240864, 55.52633307874203, 60.14017090201378, 56.47135756909847, 70.45446664094925, 61.61248929798603, 38.49343545734882, 53.57062742114067, 47.906856536865234, 41.496596708893776, 64.24531862139702, 15.475532189011574, 0.6541618541814387, 0.4997814819216728, 1.234944777097553, 0.39050275983754545, 0.1955132096190937, 0.15436162560945377, 0.038414417213061824, 1.1210793745703995, 9.471746999770403, 33.59770596027374, 46.50940552353859, 49.22850541770458, 28.25626987963915, 19.518289156258106, 1.3540569855831563, 0.12497611023718491, 0.3230855305446312, 0.07554470372269861, 0.3284354356583208, 0.016880054281500634, 0.0278796494967537, 0.010923372938123066, 0.12193516013212502, 0.06513596381410025, 0.1509389592683874, 0.0654772923735436, 0.0962744394200854, 0.05475240497617051, 0.055783277784939855, 0.041972681356128305, 0.02966413987451233, 0.07832606541342102, 0.10274910644511692, 0.03733909717993811, 0.17716262867907062, 0.0350269546470372, 0.21585911395959556, 0.044166855805087835, 0.03676953223475721, 0.04595985490595922, 0.024895924543670844, 0.1657333318144083, 0.045604826300404966, 0.2123891282826662, 0.01869847565103555, 0.07704228351940401, 0.0528116145869717, 0.06001941961585544, 0.0035170890942026745, 0.11385576945031062, 0.08553311345167458, 0.005432585003291024, 0.023437222153006587, 0.1936048807692714, 0.04882486035057809, 0.4428349470254034, 0.05261504564259667, 0.14889377838699147, 0.3477713809115812, 22.328994534909725, 91.2025237083435, 63.23716811835766, 69.6677340567112, 87.13203772902489, 52.78326407074928, 52.57919982075691, 54.35139812529087, 43.10867540538311, 29.54721450805664, 39.96898368000984, 42.17359118163586, 22.652837857604027, 4.453964726999402, 0.335376535076648, 0.16918604029342532, 0.2110415365314111, 0.35562701406888664, 6.915159160271287, 32.42089010775089, 26.519909352064133, 60.086384788155556, 62.40358404815197, 22.708599865436554, 33.8135039806366, 63.00452560186386, 89.07093688845634, 75.9158755838871, 64.51329544186592, 60.311389714479446, 70.9036785364151, 74.05359551310539, 66.35352149605751, 59.288093224167824, 60.69463334977627, 60.31351380050182, 63.67150381207466, 52.45248422026634, 40.40547765791416, 31.495117284357548, 26.326739117503166, 29.330170154571533, 27.78884746134281, 32.249329313635826, 30.574595779180527, 52.300929352641106, 62.48418152332306, 54.93211716413498, 51.03683978319168, 16.13795444369316, 3.74311335850507, 0.810619646217674, 0.1950297597795725, 0.2996937482384965, 0.3805654321331531, 0.5413734563626349, 0.6302288384176791, 0.2703803399344906, 0.04136187526455615, 2.5945988623425364, 4.999334262683988, 5.978504195809364, 6.062928065657616, 5.896342154592276, 6.035614181309938, 0.5967895046342164, 12.417195048183203, 21.133048608899117, 12.470250651240349, 13.716142047196627, 0.4838354594539851, 1.8690420454367995, 2.538086394779384, 0.23653793090488762, 0.48990183393470943, 0.2467291770153679, 0.027630100485112052, 0.1302697605569847, 0.641463054344058, 0.5610559845808893, 0.16863057244336233, 4.893243480473757, 15.206480976194143, 17.08921629935503, 34.60355378687382, 40.18203064799309, 43.69410999119282, 49.75657448172569, 20.8363339304924, 27.07380373030901, 24.397894218564034, 21.54485911130905, 18.223409838974476, 27.348139509558678, 47.15061351656914, 60.29303289949894, 59.51971359550953, 67.25323721766472, 62.41020329296589, 70.06153732538223, 65.5218905210495, 71.1297208070755, 67.65272498130798, 63.25979970395565, 58.07709440588951, 60.03354862332344, 59.42120388150215, 60.66421218216419, 55.48919387161732, 69.77913647890091, 59.66034784913063, 42.171497493982315, 53.79546895623207, 49.26371432840824, 44.68711830675602, 70.85957810282707, 20.861342288553715, 0.6679285154677927, 0.4529217432718724, 1.9358979142270982, 0.7217085734009743, 0.23747700004605576, 0.1464041104190983, 0.03401118083274923, 0.8275828859768808, 13.981327917426825, 32.78116397559643, 46.10484503209591, 63.82025063037872, 40.66205509006977, 38.723114132881165, 9.955489542335272, 0.7861055585090071, 0.22549380868440494, 0.08676445519085974, 0.21339493134291843, 0.08280560199636966, 0.04269943688996136, 0.024933924360084347, 0.08881223358912393, 0.12548152764793485, 0.07813758216798306, 0.05294596187013667, 0.06760761985788122, 0.026089676503033843, 0.07727256452199072, 0.008990298101707594, 0.021473992928804364, 0.06089250440709293, 0.050060951834893785, 0.014299803478934336, 0.10460844612680376, 0.18883057055063546, 0.30451174126937985, 0.121682993194554, 0.1049392213462852, 0.15955101902363822, 0.184027643117588, 0.16080938978120685, 0.12414773984346539, 0.2732813061447814, 0.09692885039839894, 0.18360368383582681, 0.21683808095986024, 0.20615372224710882, 0.2521560725290328, 0.1573829384869896, 0.24975038599222898, 0.14441865758271888, 0.1820438972208649, 0.37269685592036694, 0.22074338077800348, 0.7021034660283476, 0.16176104574697092, 0.28640906733926386, 0.4464571620337665, 34.17304828763008, 110.97857773303986, 69.96943786740303, 78.384929895401, 94.1235713660717, 67.37462550401688, 65.5988059937954, 53.28037619590759, 53.149708807468414, 43.374338150024414, 59.72049482166767, 59.185844510793686, 31.098504066467285, 6.642892844974995, 0.2310683618998155, 0.16925326402997598, 0.2760876336833462, 0.8534398453775793, 3.6131394328549504, 31.749547831714153, 37.687943279743195, 79.24654886126518, 60.864719823002815, 23.026188723742962, 67.95600190758705, 95.8866235613823, 117.69282504916191, 76.96965783834457, 61.46910399198532, 54.57061216235161, 72.37062022089958, 77.22040638327599, 69.00242775678635, 58.26409377157688, 59.95629496872425, 61.41045793890953, 64.7631624341011, 56.85849219560623, 43.32457982003689, 30.64581535756588, 22.952858358621597, 33.08925524353981, 31.159061416983604, 40.03046818077564, 40.28299123048782, 60.47366000711918, 68.88718754053116, 56.63959354162216, 55.51857769489288, 21.52152456343174, 5.026404485106468, 0.5302709864918143, 0.20487991481786594, 0.37361216149292886, 0.5937834503129125, 0.45846279594115913, 1.2966793519444764, 0.36692633118946105, 0.10888948789215647, 4.924125373363495, 5.130409654229879, 5.703179044649005, 5.30845052562654, 5.8833948243409395, 8.462373912334442, 0.8915797644294798, 12.489821501076221, 27.30625245720148, 14.06202133744955, 19.81474544852972, 1.803755136206746, 3.2002519257366657, 3.380319750867784, 0.20598667964804918, 0.5828601645771414, 0.5043991841375828, 0.34561882610432804, 0.46700856706593186, 0.8605942677240819, 1.4208309212699533, 0.19891465053660795, 9.490986317396164, 11.383017841726542, 18.911780901253223, 37.3379972577095, 50.350357219576836, 48.65111880004406, 52.02165573835373, 25.91936107724905, 41.89437836408615, 43.21130409836769, 28.95865648984909, 22.73943141102791, 40.546172708272934, 60.86831822991371, 62.332653254270554, 56.822796911001205, 65.97219675779343, 61.600128561258316, 66.21808156371117, 64.6738064289093, 70.36368191242218, 68.62757787108421, 62.55476273596287, 58.44833828508854, 60.45905739068985, 58.871536776423454, 57.72844411432743, 53.144195303320885, 75.52268028259277, 68.25481027364731, 54.768319353461266, 65.261460095644, 56.36371314525604, 51.68128900229931, 74.6906541287899, 24.290149100124836, 0.7275874516926706, 0.8575828105676919, 2.3631941294297576, 1.091717875096947, 0.3161739686038345, 0.3822102095000446, 0.13938373478595167, 1.9662855961360037, 18.184110447764397, 47.094821110367775, 63.500269800424576, 77.05187782645226, 54.993829652667046, 63.83912801742554, 24.02183409780264, 1.4451130433008075, 0.4290481883799657, 0.1900934535660781, 0.4933467350201681, 0.09523993008770049, 0.17427902872441337, 0.07664156088139862, 0.4074489005142823, 0.2117914767586626, 0.14657967287348583, 0.3184969798894599, 0.2552130678668618, 0.09836731071118265, 0.16437440004665405, 0.13630788889713585, 0.16017945483326912, 0.2854104631114751, 0.16219587007071823, 0.22181925742188469, 0.33970105927437544], [0.021502704767044634, 0.03705121067469008, 0.07074189503327943, 0.024893918889574707, 0.0958069234911818, 0.05985707110085059, 0.04553735394438263, 0.040831636724760756, 0.11421573333791457, 0.07485938229365274, 0.0489212208049139, 0.03812130598817021, 0.04014166574052069, 0.017754265281837434, 0.06166232305986341, 0.070428248582175, 0.04986405263480265, 0.03274666509241797, 0.12162664934294298, 0.13473435770720243, 0.09041330587933771, 0.04674006733694114, 0.06847147233202122, 0.2151414126274176, 5.017719101160765, 70.3162832558155, 79.56877157092094, 57.19786338508129, 76.6089203953743, 63.40711399912834, 50.57653248310089, 37.18757092952728, 25.429025888442993, 10.502168107777834, 14.699591025710106, 7.082952931523323, 0.45788674091454595, 0.22795563127147034, 0.07318577991100028, 0.33813367306720465, 0.47817569284234196, 0.4509107902413234, 11.839269809424877, 42.63597697019577, 64.70396161079407, 82.20247864723206, 29.94821459054947, 55.669836178421974, 95.5878683924675, 88.53431448340416, 73.00103679299355, 66.8212080001831, 66.48765429854393, 66.37476995587349, 74.85350579023361, 79.42874908447266, 68.30331847071648, 66.70868843793869, 58.178328573703766, 66.87614545226097, 64.45730164647102, 64.46260616183281, 57.06387497484684, 46.68082572519779, 33.44198651611805, 25.46931702643633, 29.221328794956207, 32.73716613650322, 35.52715502679348, 37.047719433903694, 55.69770008325577, 39.601281210780144, 24.13128722459078, 9.225591458380222, 2.631892911158502, 0.29145012027584016, 0.03493370379146654, 0.03871864952088799, 0.012877203789685154, 0.7045219768770039, 0.36065833002794534, 0.7479522214271128, 0.23761601914884523, 0.3453381161671132, 2.2590780537575483, 5.4097687639296055, 8.37439438328147, 3.8550622388720512, 7.115165228024125, 1.1004978977143764, 12.55573846399784, 15.813169721513987, 10.736371390521526, 13.228647205978632, 0.6240758998319507, 0.5925184744410217, 0.37542116129770875, 0.2125506938318722, 0.6868716864846647, 0.7531382306478918, 0.10759633267298341, 2.97965785022825, 1.3316706055775285, 0.08487218641676009, 0.8332054561469704, 0.4974388482514769, 11.631481759250164, 12.374387495219707, 21.190072149038315, 29.155727215111256, 32.66072943806648, 38.16702917218208, 31.815483793616295, 29.582575410604477, 25.360692255198956, 21.65769785642624, 33.48031885921955, 58.91824007034302, 66.18455216288567, 61.65927618741989, 60.720946937799454, 60.883498415350914, 66.13692551851273, 65.94696611166, 70.11177062988281, 70.07134079933167, 64.56358954310417, 63.29518720507622, 63.36085148155689, 59.66121420264244, 61.019029542803764, 62.62369483709335, 62.018432915210724, 65.62202274799347, 73.56320142745972, 45.315220803022385, 40.18879808485508, 56.59045457839966, 37.49111384153366, 58.98981302976608, 26.650109365582466, 0.32678763032890856, 1.044677586760372, 3.472589487209916, 2.679089466109872, 0.2602362202014774, 0.07100740578607656, 0.1456440769834444, 0.1892367034452036, 12.643648646771908, 42.13103726506233, 54.97256979346275, 40.06222307682037, 25.453509874641895, 14.571404904127121, 2.6089955773204565, 0.11154157487908378, 0.08934708457672969, 0.07574936578748748, 0.08237218033173122, 0.08328303301823325, 0.030330425215652213, 0.10939489788142964, 0.17039446451235563, 0.0980595346482005, 0.187990058620926, 0.035500622980180196, 0.09163635782897472, 0.0440139325655764, 0.028922159181092866, 0.11460042558610439, 0.06793677719542757, 0.045083575168973766, 0.052906442506355233, 0.04108843095309567, 0.02111952464474598, 0.06768487000954337, 0.03875717811752111, 0.0341457284957869, 0.026979149770340882, 0.058437123661860824, 0.0853302251198329, 0.05431032615888398, 0.03698278094816487, 0.1627217113855295, 0.14119556959485635, 0.1440162947983481, 0.03686299460241571, 0.04879348234680947, 0.03568185544281732, 0.05506854875420686, 0.029584952717414126, 0.01575905320351012, 0.05256354430457577, 0.07912583343568258, 0.028634756927203853, 0.03436885148403235, 0.11503854504553601, 0.08975608958280645, 0.15242119145113975, 6.495946180075407, 82.70386934280396, 83.0601154267788, 67.794920951128, 83.09188172221184, 72.0541276037693, 44.45944592356682, 40.00484995543957, 30.323412157595158, 18.82327225059271, 18.17007590085268, 8.042583838105202, 0.502995871938765, 0.1950724481139332, 0.15019991376902908, 0.43781764281447977, 0.5399898556061089, 1.7739914520643651, 30.108402594923973, 35.93143813312054, 53.942904844880104, 78.11911135911942, 42.42060072720051, 35.95110587775707, 74.15818870067596, 80.30736073851585, 74.48459878563881, 68.92947167158127, 66.81075856089592, 65.87653309106827, 76.85868099331856, 83.55614840984344, 67.8221046924591, 66.09576612710953, 60.860707238316536, 68.70418176054955, 63.71558524668217, 62.72113300859928, 58.128627240657806, 46.043611317873, 27.468296661973, 26.762203350663185, 27.094459421932697, 33.23071405291557, 34.638067334890366, 45.71540392935276, 58.18512260913849, 51.09038271009922, 47.241466641426086, 22.342508509755135, 7.908954033628106, 1.0646406468003988, 0.34272436110768467, 0.05983180468319915, 0.1182494692329783, 0.715905869146809, 0.6908799964003265, 0.4833746748045087, 0.17366096813930199, 0.2917598036583513, 1.378785939887166, 11.321899071335793, 11.476264838129282, 3.9699006266891956, 6.567158633843064, 1.5200384915806353, 19.5367618650198, 17.651189044117928, 19.458921141922474, 25.309480503201485, 0.37851564993616194, 1.34271934395656, 0.3686047426890582, 0.2801131614251062, 1.1565680452622473, 1.4630764606408775, 0.5993398802820593, 1.3126840931363404, 0.4880030045751482, 0.1617460692068562, 0.8163142937701195, 1.61361274542287, 13.422948829829693, 22.59966731071472, 39.13459025323391, 41.523392871022224, 37.92343944311142, 44.39652509987354, 25.360682755708694, 34.16659243404865, 28.96062098443508, 25.199795588850975, 23.35397243499756, 48.72480824589729, 65.33518373966217, 59.57059666514397, 63.491822853684425, 62.82827965915203, 65.32295599579811, 63.78040596842766, 69.99197825789452, 69.04313877224922, 68.3205695450306, 64.718476831913, 64.91586104035378, 60.730731412768364, 61.61293767392635, 63.910609781742096, 62.28794105350971, 64.77251753211021, 74.57753419876099, 49.91068281233311, 44.760507568717, 57.02377572655678, 38.254257291555405, 61.91170424222946, 32.645393460989, 0.6627899443265051, 0.7238185883034021, 1.6127419983968139, 3.5194112872704864, 0.4453499667579308, 0.06926034562638961, 0.19493218220304698, 0.0939614990784321, 15.215047616511583, 37.83348686993122, 60.41756361722946, 54.07643347978592, 39.13557820022106, 31.472707986831665, 5.1369415037333965, 0.10980748746078461, 0.1918719511013478, 0.09303217433625832, 0.09979823080357164, 0.03202684492862318, 0.07915188281913288, 0.1017360451805871, 0.24967076838947833, 0.12571717437822372, 0.1554646500153467, 0.0751325223245658, 0.11077970833866857, 0.01918187725095777, 0.06453375550336204, 0.06205279663845431, 0.10082816108479165, 0.02706932256842265, 0.06833638661191799, 0.06653632226516493, 0.08720210709725507, 0.161230395315215, 0.21013017918448895, 0.1797355804592371, 0.08106919165584259, 0.4131292988313362, 0.23916851787362248, 0.15580578561639413, 0.13840291241649538, 0.1948246153187938, 0.1804993543191813, 0.15339984674938023, 0.1717554297647439, 0.1443987977108918, 0.1022418930369895, 0.13667105144122615, 0.18006942817009985, 0.13348562002647668, 0.12558329093735665, 0.2706446929369122, 0.23204832337796688, 0.2427820349112153, 0.32925536041148007, 0.24615016824100167, 0.37727843038737774, 6.5758060198277235, 102.07120209932327, 92.57263138890266, 80.66684424877167, 91.17948174476624, 86.19873940944672, 65.00735253095627, 51.81542940437794, 44.73157212138176, 33.775308430194855, 30.94331469386816, 11.483501549810171, 0.37382334703579545, 0.3300053154816851, 0.1643673941725865, 1.0846662847325206, 1.0526183294132352, 1.7908941325731575, 18.52197501808405, 48.97234596312046, 73.29813525080681, 94.24584120512009, 39.130786657333374, 66.80141106247902, 110.55211141705513, 91.16422176361084, 76.2374447286129, 68.20100516080856, 64.71552059054375, 63.76541957259178, 76.19256913661957, 85.13064712285995, 68.0558529496193, 68.32395136356354, 57.64892578125, 71.34579241275787, 61.737844571471214, 60.90723194181919, 58.579252660274506, 57.83966414630413, 37.15151086449623, 29.866154193878174, 36.58529184758663, 43.43359977006912, 42.61084511876106, 52.08703503012657, 60.1158332079649, 56.80695556104183, 52.3308489471674, 31.31577830761671, 9.19861575588584, 1.991657072212547, 0.26698299567215145, 0.17366179934469983, 0.32960102311335504, 2.221698984503746, 2.692932360805571, 4.027987634763122, 0.30709263402968645, 0.5809960083570331, 3.8612079340964556, 14.780311994254589, 17.413903176784515, 3.621408501639962, 10.847241841256618, 1.826025266200304, 24.613297060132027, 23.086348995566368, 22.75956653058529, 39.76029507815838, 0.6730793765746057, 1.3293608045205474, 1.476878032553941, 0.37538924894761294, 1.464837547391653, 2.627384215593338, 5.335860829800367, 7.821362558752298, 1.6933821025304496, 0.3544776054332033, 1.1159926350228488, 2.4646938079968095, 15.690041128546, 27.48376563191414, 42.86053352057934, 43.987404853105545, 43.69380980730057, 44.51535612344742, 37.22899250686169, 44.09786492586136, 31.501244455575943, 29.140222147107124, 42.29293517768383, 69.30540069937706, 69.29438129067421, 60.14975018799305, 59.35403488576412, 57.396972700953484, 66.03265911340714, 64.22053635120392, 70.15610665082932, 70.51975473761559, 66.55094370245934, 63.32121200859547, 65.07519409060478, 60.67735567688942, 61.19250163435936, 63.791189789772034, 62.89693437516689, 66.17423191666603, 78.55693906545639, 52.5239621847868, 52.48697116971016, 63.00690047442913, 44.06912326812744, 69.71560388803482, 38.63604560494423, 1.6276653413660824, 1.2550371489487588, 5.067290291190147, 4.490159209817648, 1.477504523936659, 0.49705818586517125, 0.5842365219723433, 0.5140256113372743, 19.183356128633022, 52.4822062253952, 76.02819755673409, 70.19719764590263, 59.13949079811573, 47.91608244180679, 7.279654601588845, 0.17086354637285694, 0.373499562847428, 0.10569062360445969, 0.1899435100494884, 0.23459274700144306, 0.14004141121404245, 0.29029320110566914, 0.321609458187595, 0.15457276662345976, 0.35814693197607994, 0.2467388694640249, 0.27267298253718764, 0.14294881926616654, 0.1174511706631165, 0.20063802134245634, 0.16013412445317954, 0.16287005186313763, 0.1506984737352468, 0.21154411893803626, 0.20057155459653586], [0.022510242597491015, 0.0036641707038143068, 0.03719793327036314, 0.11860129176056944, 0.1996575848897919, 0.0679278936877381, 0.060790355200879276, 0.04338407554314472, 0.09404465672560036, 0.12244412500876933, 0.012531795273389434, 0.06341642991174012, 0.13141943636583164, 0.06434883456677198, 0.034587024347274564, 0.016691626697138418, 0.06764241916243918, 0.09470170974964276, 0.05166499271581415, 0.21946409629890695, 0.04176728085440118, 0.08877277359715663, 0.05095336957310792, 0.23747925617499277, 0.24455722246784717, 44.021173641085625, 82.52404779195786, 65.44927641749382, 68.56987416744232, 84.90851104259491, 57.243419140577316, 44.287999123334885, 22.71015778183937, 5.934279793873429, 0.8262285555247217, 0.42754421127028763, 0.09431968923308887, 0.42420027195475996, 0.14777371427044272, 0.3070059511810541, 1.0517854616045952, 4.918551072478294, 21.798252314329147, 57.2338854521513, 69.57941919565201, 64.12638500332832, 35.92472389340401, 93.07704672217369, 86.11575946211815, 73.31809937953949, 66.28309607505798, 68.34764689207077, 65.90959131717682, 68.4407950937748, 69.9213020503521, 67.8570856153965, 64.75813910365105, 69.56386283040047, 68.30031663179398, 62.93608367443085, 66.42109706997871, 59.12187874317169, 67.81571343541145, 76.56265407800674, 68.91385450959206, 36.60763464868069, 32.53965273499489, 37.83341087400913, 28.53488612920046, 31.467878445982933, 51.242830529809, 41.66041351854801, 26.279009878635406, 9.276671167463064, 7.936209496110678, 2.795629450120032, 0.30182528542354703, 0.08995344891445711, 0.2082725687068887, 0.06697954027913511, 0.15758726658532396, 0.14575321722077206, 0.5326274537947029, 0.1621258707018569, 0.2548176812706515, 6.068775951862335, 5.548685509711504, 5.23915221914649, 6.504942197352648, 0.9117174963466823, 18.21008775383234, 12.82770412042737, 15.474295355379581, 20.011413395404816, 1.7737930314615369, 0.8019595546647906, 0.16237165516940877, 0.2851631795056164, 1.834528734907508, 0.5640406650491059, 0.43999813206028193, 0.4308716452214867, 1.8276169057935476, 0.285271147149615, 0.3069624910131097, 1.0336553282104433, 15.88310306891799, 19.702045395970345, 25.898363403975964, 33.057093769311905, 36.671611815690994, 40.80930098891258, 35.86185626685619, 27.522265166044235, 20.830529741942883, 25.531430393457413, 58.3196771889925, 69.13651496171951, 61.26416198909283, 60.841833651065826, 59.60898220539093, 63.176846355199814, 57.966478541493416, 67.16081857681274, 69.12795022130013, 68.0706949532032, 64.15533185005188, 60.257766991853714, 59.6664085239172, 62.257261499762535, 60.69545790553093, 60.249517634510994, 65.06887122988701, 65.67106291651726, 67.34562546014786, 65.4749858379364, 37.06430934369564, 47.8292191028595, 59.23649579286575, 54.72323477268219, 57.2778794914484, 2.793801985681057, 0.4113097011577338, 4.146102396771312, 1.2020202563144267, 0.5428962246514857, 0.09949573883204721, 0.1555941250990145, 0.11447937387856655, 17.37680956721306, 42.88505740463734, 48.61853554844856, 36.110127344727516, 32.88473881781101, 12.103432584553957, 0.2087733699590899, 0.13726877717999741, 0.10800999094499275, 0.10617321997415274, 0.054612818130408414, 0.055706046186969616, 0.11163578310515732, 0.26144494127947837, 0.07081559029757045, 0.05522414001461584, 0.09702817202196456, 0.09927410384989344, 0.0821312346670311, 0.003915117968062987, 0.08257391833467409, 0.08706860957317986, 0.04677012802858371, 0.05693025217624381, 0.12323318384005688, 0.17565783520694822, 0.04779094844707288, 0.0319657773070503, 0.046876648484612815, 0.11344582191668451, 0.1029716245830059, 0.1404418147285469, 0.026263418840244412, 0.07505724628572352, 0.04514231986831874, 0.23583802627399564, 0.11870030168211088, 0.03961559807066806, 0.05413099359429907, 0.0824446658953093, 0.023380976635962725, 0.014082870929996716, 0.032503418769920245, 0.031612889797543176, 0.051498944594641216, 0.0041471903296042, 0.07591885005240329, 0.06190339488966856, 0.03633891588833649, 0.08680776692926884, 0.20125830837059766, 0.5578061495907605, 56.432204470038414, 90.43530687689781, 73.88834998011589, 74.9204733967781, 84.87404689192772, 52.915675565600395, 30.868768393993378, 31.563032940030098, 10.660828594118357, 1.521703633479774, 0.39087971148546785, 0.5551806685980409, 1.184664568863809, 0.13746926095336676, 0.32834952464327216, 1.427795235067606, 13.590403944253922, 19.089938141405582, 35.611255913972855, 65.48147588968277, 66.63007065653801, 39.62115414440632, 77.23048344254494, 84.74679931998253, 73.02487671375275, 72.27548092603683, 68.8554972410202, 67.7952553331852, 65.80936789512634, 73.4777744114399, 72.4923124909401, 69.03816103935242, 71.05368688702583, 68.643689006567, 64.62215200066566, 65.94326511025429, 59.1350032389164, 70.64555078744888, 72.28657633066177, 48.45886051654816, 25.419661290943623, 28.46058491617441, 30.680980570614338, 25.165643021464348, 37.72409833967686, 57.499969974160194, 54.89634208381176, 40.366582944989204, 17.786564379930496, 17.492640651762486, 11.462501026690006, 2.427169634029269, 0.028260857361601666, 0.3919045877410099, 0.03623271455580834, 0.2025036618579179, 0.3057944099418819, 0.768124092137441, 0.301200634567067, 0.2270369415055029, 7.405905202031136, 6.006651660427451, 5.006860233843327, 7.657375708222389, 1.153706086333841, 21.93791002035141, 14.39292848110199, 18.98692186921835, 28.41764722019434, 1.530292360112071, 1.079903596546501, 0.5091453075874597, 0.31772140588145703, 1.2951349723152816, 0.3538408427266404, 0.48157832119613886, 0.4579170502256602, 1.6835061949677765, 0.01915604680107208, 0.266041774302721, 2.2634100588038564, 17.073699831962585, 20.521002151072025, 38.85545343160629, 43.577536046504974, 38.43018405139446, 44.97603960335255, 31.998896151781082, 28.355009481310844, 19.230317808687687, 18.43413133174181, 37.76828236877918, 66.41626372933388, 61.173058077692986, 63.28653126955032, 60.29586374759674, 65.85690334439278, 57.48134337365627, 62.80677281320095, 68.9688603579998, 66.98083743453026, 66.49669021368027, 64.17288690805435, 62.57023550570011, 62.50078283250332, 63.48933398723602, 61.46155759692192, 63.83084446191788, 66.2373161315918, 66.83743312954903, 69.71760258078575, 42.7559707313776, 49.74261783063412, 61.97820067405701, 56.84505991637707, 65.48641562461853, 4.953622715547681, 0.5602643801830709, 0.9014416008722037, 2.203730223700404, 2.508443472906947, 0.13191146543249488, 0.04341609921539202, 0.2782632544403896, 22.276317961513996, 44.792296662926674, 58.28767150640488, 47.54969470202923, 45.33207289874554, 22.195925675332546, 0.20566225721267983, 0.2659973641857505, 0.04529929894488305, 0.1357107123476453, 0.04516110733675305, 0.05589957603660878, 0.055084894556785, 0.1767405544524081, 0.04303672816604376, 0.0231292753960588, 0.13430422375677153, 0.0638625719875563, 0.11608028289629146, 0.019306088652228937, 0.06893987141666003, 0.041503347165416926, 0.022825595988251735, 0.04324384302890394, 0.059978801873512566, 0.12913461599964648, 0.032807398747536354, 0.13124197401339188, 0.16592008585575968, 0.16415537742432207, 0.21781106624985114, 0.35026354249566793, 0.10429284040583298, 0.17686465638689697, 0.10016238782554865, 0.5219831562135369, 0.20873308618320152, 0.10012360318796709, 0.16342011687811464, 0.2791353076463565, 0.111216054065153, 0.13217635278124362, 0.09807910508243367, 0.20077506633242592, 0.19269613578217104, 0.1231707469560206, 0.3490680316463113, 0.2016312227351591, 0.1805854434496723, 0.2709783922182396, 0.4000026360154152, 0.5990450398530811, 65.56412145495415, 104.72231224179268, 87.66342401504517, 90.09058177471161, 105.14000862836838, 78.32531109452248, 63.69976669549942, 39.938877895474434, 21.012074500322342, 3.542638965882361, 0.5851802369579673, 0.6017148122191429, 0.6003539508674294, 0.2211917715612799, 0.5108064715750515, 2.6946265948936343, 16.52274649590254, 26.45322673022747, 69.26406651735306, 85.76467350125313, 73.98392245173454, 48.13812352716923, 104.49055507779121, 87.64940276741982, 74.87403988838196, 72.2303469479084, 66.61318436264992, 64.34917464852333, 67.40331396460533, 72.87624388933182, 67.63598307967186, 65.83747118711472, 70.0374998152256, 71.55798062682152, 65.45060634613037, 63.429627791047096, 55.89649021625519, 65.83250105381012, 81.7531755566597, 73.65140989422798, 43.10946576297283, 35.628320798277855, 49.041243866086006, 32.15135917067528, 37.46689394116402, 59.85339269042015, 56.75664626061916, 46.64162702858448, 25.542749986052513, 23.983501754701138, 13.516070432960987, 2.650616643950343, 0.1467560516903177, 0.8721601346042007, 0.14535029040416703, 0.7454485120251775, 1.070893092546612, 0.9286164364311844, 0.23834991414332762, 0.2754958451259881, 10.362310912460089, 10.31374666839838, 7.010482745245099, 11.108390428125858, 2.4525099992752075, 29.10223178565502, 18.074887208640575, 27.425510957837105, 38.182646334171295, 3.089866661466658, 1.5390070737339556, 0.8069482713472098, 0.20310085325036198, 3.5797000396996737, 1.1119846813380718, 1.1335921031422913, 0.9615544346161187, 6.970720253884792, 0.3626011835876852, 0.522756592836231, 1.7997598880901933, 20.77478863298893, 28.723779693245888, 41.326001062989235, 43.92960235476494, 43.1787246465683, 50.24389833211899, 43.130254447460175, 33.53660523891449, 24.39934004098177, 37.43108466267586, 68.79566565155983, 70.6548298895359, 60.660621374845505, 59.97753582894802, 55.894799306988716, 64.47861090302467, 57.66715720295906, 65.46445280313492, 66.49722218513489, 66.0509817302227, 64.87874463200569, 59.213936403393745, 60.849885419011116, 61.336688697338104, 63.329810947179794, 61.2941537797451, 65.0315572321415, 65.66679194569588, 69.61565405130386, 69.3250760436058, 46.382515132427216, 56.70870043337345, 64.45871517062187, 63.00731845200062, 67.15722396969795, 6.340641863644123, 0.7832912751473486, 11.18457444012165, 3.5384553903713822, 2.7185674477368593, 0.8893860352691263, 0.310221528634429, 0.5546217423398048, 31.69744122773409, 62.02438339591026, 75.65691187977791, 64.67262849211693, 64.15060490369797, 28.17345902323723, 0.5452398676425219, 0.27201074932236224, 0.222094772325363, 0.1273048805887811, 0.38775808992795646, 0.22566902975086123, 0.18147992435842752, 0.30317744880449027, 0.11268465299508534, 0.29191197361797094, 0.256721141631715, 0.2470959463971667, 0.20328811195213348, 0.12378816187265329, 0.23054274322930723, 0.1537416354403831, 0.18367729004239663, 0.1575809286441654, 0.24474839970935136, 0.21381687198299915, 0.10292489896528423], [0.04106286396563519, 0.037446278147399426, 0.10114964461536147, 0.055238110944628716, 0.05961188406217843, 0.06631030861171894, 0.06731948102242313, 0.02707693143747747, 0.019025896363018546, 0.0597767521685455, 0.09017530654091388, 0.04264199465978891, 0.09780607637367211, 0.043635266556520946, 0.0400168402120471, 0.05555312665819656, 0.07352845175773837, 0.09865524174529128, 0.04377256387670059, 0.06739710224792361, 0.020747530543303583, 0.08785867030383088, 0.18598544353153557, 0.24927232414484024, 0.05762931818026118, 12.237460892647505, 72.85200119018555, 69.912820905447, 86.73264116048813, 80.28551191091537, 65.27470618486404, 63.88057619333267, 18.46925664693117, 4.053736478090286, 0.33433886419516057, 0.1744243412395008, 0.20377120556076989, 1.4668089291080832, 2.4208505731076, 0.36559352301992476, 2.509338562376797, 10.042943749576807, 75.6376089155674, 66.51799947023392, 86.27139151096344, 50.81139028072357, 65.21672129631042, 79.36133310198784, 67.69263803958893, 74.84792768955231, 69.4748792052269, 72.40465119481087, 70.95296189188957, 72.01302140951157, 69.33528989553452, 69.15805220603943, 69.83449950814247, 75.3143298625946, 72.00903922319412, 65.7203234732151, 66.61578342318535, 68.76551806926727, 64.03819173574448, 75.47683954238892, 83.3872702717781, 70.44302925467491, 34.555915743112564, 47.482445910573006, 41.815000623464584, 27.359878979623318, 49.97769981622696, 40.16418680548668, 26.105421893298626, 11.974133122712374, 10.406646933406591, 8.48218034952879, 3.18194973282516, 0.12433193347533233, 0.11125108343549073, 0.033801969402702525, 0.038072969909990206, 0.048124848108273, 0.5514049180783331, 0.005413345288616256, 0.7734674960374832, 0.46639139705803245, 3.5618032375350595, 5.921733817085624, 5.809757625684142, 1.290122210048139, 18.378038741648197, 10.358403772115707, 9.474019277840853, 19.968939274549484, 1.1545263673178852, 0.30307170760352165, 0.17110765358665958, 1.087337185163051, 0.3302317892666906, 0.06344601933960803, 0.5601424304768443, 0.4722873744321987, 0.2918835642049089, 0.5222664785105735, 0.7135957712307572, 0.9182356903329492, 11.063132956624031, 27.352733463048935, 29.76119052618742, 36.64530962705612, 33.740407302975655, 49.09112758934498, 48.365621119737625, 31.013943403959274, 42.2944550961256, 67.72284641861916, 80.06363421678543, 56.03650130331516, 62.77005158364773, 55.97905978560448, 60.86902879178524, 59.376632273197174, 70.17422407865524, 71.7461085319519, 67.20715329051018, 65.63397690653801, 66.03568375110626, 65.23030936717987, 65.62946274876595, 63.32949556410313, 64.94001254439354, 68.3106216788292, 66.05144530534744, 66.10358610749245, 65.7060058414936, 69.0186756849289, 56.7192030698061, 38.73539887368679, 53.00086319446564, 47.27675914764404, 61.23622968792915, 15.659265629947186, 0.24005391489481553, 1.5539333852939308, 1.847995212301612, 0.7993677968624979, 0.031000271010270808, 0.35490834794472903, 1.582284732721746, 22.298468872904778, 38.10754336416721, 48.568397238850594, 43.794249817728996, 37.732587084174156, 5.192920099943876, 0.12104772220482118, 0.07768049341393635, 0.17120307893492281, 0.013662826477229828, 0.037832265443284996, 0.058690359292086214, 0.2132450620410964, 0.11041539546567947, 0.136017263866961, 0.040627367998240516, 0.09675226378021762, 0.03730542965058703, 0.07573900540592149, 0.10168085165787488, 0.0812039508309681, 0.046290466852951795, 0.04153554153162986, 0.08595535837230273, 0.026168158619839232, 0.017462437972426414, 0.0474119558930397, 0.02090392888931092, 0.03466176975052804, 0.12122154803364538, 0.04090281239768956, 0.09043816782650538, 0.011806925722339656, 0.06240313858143054, 0.013087963525322266, 0.049210654688067734, 0.011959501080127666, 0.061108012960175984, 0.07499746629036963, 0.18687395757297054, 0.02321690077224048, 0.02045017794443993, 0.06349267816403881, 0.03339587361551821, 0.09959117160178721, 0.11220357802812941, 0.022258131320995744, 0.06495395951787941, 0.055480707887909375, 0.1893231488065794, 0.25889328913763165, 0.4210774035891518, 17.583792060613632, 82.77493312954903, 81.15286856889725, 97.58428886532784, 83.49765434861183, 70.0352655351162, 47.04084500670433, 24.052960127592087, 6.840074239298701, 0.2618271770188585, 0.12696738151134923, 0.39121412322856486, 1.5928362915292382, 0.40861371613573283, 0.14791396533837542, 5.377224460244179, 14.686003904789686, 34.12634119391441, 50.41649267077446, 82.22351431846619, 60.45923598110676, 59.42306198179722, 79.19295653700829, 70.412068516016, 76.16051405668259, 69.69623252749443, 72.25972697138786, 68.81873801350594, 72.01624363660812, 71.11774384975433, 71.72551363706589, 74.31902647018433, 75.92665180563927, 72.75136739015579, 66.85313388705254, 68.70107352733612, 66.54879301786423, 68.18856462836266, 77.24730134010315, 78.71317148208618, 51.12258218228817, 23.64820394665003, 43.68645340204239, 36.054429933428764, 33.74924562871456, 53.89998234808445, 54.57539610564709, 37.07231171429157, 15.741220582276583, 14.773729797452688, 14.993001781404018, 4.14326679892838, 0.3531162394210696, 0.08362643216969445, 0.18566133279819041, 0.06597490981221199, 0.06531045015435666, 0.19322542066220194, 0.09838970130658709, 0.9962990577332675, 0.6743190600536764, 3.0598720209673047, 4.663505908101797, 6.482708640396595, 1.0029560630209744, 20.516695082187653, 12.839396093040705, 11.804248988628387, 25.285344198346138, 0.5226491892244667, 0.4708951053908095, 0.49117981223389506, 3.0655370419844985, 0.44764216407202184, 0.14673887839308009, 0.8219632843974978, 1.1985338246449828, 0.6693917931988835, 0.6785225251223892, 0.33624232455622405, 4.7000751458108425, 17.78709825128317, 25.631477124989033, 38.12576338648796, 48.909998908638954, 39.753774628043175, 50.189211666584015, 52.27564550936222, 27.828228548169136, 21.354576721787453, 43.6325228959322, 73.6657427251339, 58.22263039648533, 64.22985345125198, 57.84836947917938, 62.51556783914566, 61.66424632072449, 68.49887117743492, 71.74768164753914, 68.34103524684906, 66.6472989320755, 67.90916562080383, 66.75027340650558, 63.998985439538956, 62.69635073840618, 64.80746045708656, 69.84128594398499, 68.51484552025795, 68.47633078694344, 68.2126097381115, 71.29172891378403, 62.37020283937454, 44.081981778144836, 57.28178948163986, 51.93934075534344, 70.81404894590378, 22.43999607861042, 0.6399462826084346, 2.7143586985766888, 1.308440314605832, 1.5501077030785382, 0.05672067709383555, 0.6049040285870433, 2.9901595367118716, 32.46035099029541, 45.43771483004093, 56.40846714377403, 57.58432924747467, 49.66846860945225, 9.016133397817612, 0.026714431260188576, 0.08697359240613878, 0.1629639632301405, 0.15789877565111965, 0.05544123676372692, 0.02180809482524637, 0.207723320054356, 0.08666940833791159, 0.14927246666047722, 0.018508420907892287, 0.03848313266644254, 0.050058072301908396, 0.14456348028033972, 0.024239676749857608, 0.054555453825742006, 0.014703264641866554, 0.09741851201397367, 0.12473446695366874, 0.022977066473686136, 0.05217561629251577, 0.051440140523482114, 0.18142999266274273, 0.08944924862589687, 0.1544373988872394, 0.1203429490851704, 0.22809358168160543, 0.13657571515068412, 0.15175107662798837, 0.10806009333464317, 0.14795896917348728, 0.1695075980387628, 0.20107612595893443, 0.09429568075574934, 0.26152182777877897, 0.07967221739818342, 0.26538360805716366, 0.15870084433117881, 0.15420856507262215, 0.17649074754444882, 0.16351612110156566, 0.2240925596561283, 0.2030467358417809, 0.18999406514922157, 0.3952083323383704, 0.3659900079946965, 0.68272236851044, 19.315157756209373, 103.29734310507774, 86.55430912971497, 105.10279342532158, 96.80986762046814, 85.88978558778763, 81.13497912883759, 35.5530696362257, 9.246940612792969, 0.3479335847077891, 0.28283476538490504, 0.5869743938092142, 2.9835780523717403, 7.009680038318038, 1.058999968226999, 10.459484998136759, 23.407908640801907, 88.4212477505207, 85.20804896950722, 99.16168302297592, 67.6023168861866, 76.28685727715492, 83.90578284859657, 70.94596266746521, 78.36406141519547, 72.37570434808731, 73.1224174797535, 68.84488061070442, 73.21774676442146, 67.78770133852959, 70.7393829524517, 71.32541790604591, 76.06595233082771, 72.5420594215393, 69.47142139077187, 65.94131961464882, 69.5938204228878, 61.07116274535656, 78.17803859710693, 84.26496997475624, 81.87546819448471, 36.946739852428436, 58.36671866476536, 47.35575690865517, 36.23456686735153, 58.29818934202194, 59.337957948446274, 43.148649260401726, 23.67805704474449, 33.274259716272354, 25.737101957201958, 4.910489805042744, 1.008617877960205, 0.13940782489953563, 0.41726306139025837, 0.18642319191712886, 0.08621432338259183, 1.492971950210631, 0.3824930271366611, 1.3392652105540037, 0.7259534799959511, 5.568456323817372, 9.415645860135555, 11.223891880363226, 1.6418417869135737, 21.868130564689636, 20.6163789331913, 16.214079558849335, 30.69535329937935, 1.4197484543547034, 0.3433482104446739, 0.3510196425486356, 7.3564988281577826, 2.5016171392053366, 0.35886132332962006, 1.1569898226298392, 0.8057905803434551, 1.6221011336892843, 0.6450752355158329, 0.9729874273762107, 5.568332355469465, 27.77852151542902, 35.518806874752045, 39.47271130979061, 49.483327344059944, 42.69168958067894, 57.07384184002876, 56.62108473479748, 40.173059329390526, 51.76444374024868, 85.03705814480782, 84.7723339498043, 55.041368901729584, 62.40872897207737, 54.470020160079, 59.649754017591476, 60.37453472614288, 69.06811103224754, 71.56672015786171, 66.81603267788887, 67.74487003684044, 68.33254650235176, 68.17955151200294, 64.20166656374931, 61.03644780814648, 65.60888305306435, 70.81823632121086, 67.8949847817421, 70.21180406212807, 71.85058772563934, 69.78833958506584, 61.90070003271103, 51.13165609538555, 63.22569653391838, 57.037295401096344, 74.03292462229729, 23.727883771061897, 0.9010417317040265, 5.330741079524159, 6.527105458080769, 1.9862538808956742, 0.13435767323244363, 0.9445726114790887, 5.324832396581769, 47.47435234487057, 58.92096072435379, 71.3674208521843, 67.89667189121246, 60.6486102193594, 9.87122431397438, 0.1468324929010123, 0.23595884791575372, 0.3259318450000137, 0.20880547526758164, 0.09077047929167747, 0.18197158235125244, 0.5060539953410625, 0.1716470465180464, 0.31742148916237056, 0.17434715788112953, 0.14471464091911912, 0.1716596184996888, 0.21033870783867314, 0.2842315169982612, 0.23412169102812186, 0.08212454049498774, 0.19104081991827115, 0.19969867018517107, 0.10764574486529455, 0.2709782437887043, 0.12197597083286382], [0.02512239276256878, 0.03723413894476835, 0.025555686406733003, 0.10417716926895082, 0.020754553115693852, 0.03966322539781686, 0.0617322630569106, 0.04707009298726916, 0.08691286246175878, 0.037768793263239786, 0.03767733469430823, 0.10744827421149239, 0.11231481854338199, 0.039983117021620274, 0.039824364212108776, 0.028103692748118192, 0.035799782708636485, 0.09014904193463735, 0.02531251244363375, 0.04124038568988908, 0.019825430608761963, 0.009036221272253897, 0.02742542914347723, 0.08505394580424763, 0.024100609407469165, 0.6390151544474065, 49.4218922406435, 82.3027628660202, 76.6395315527916, 78.89109313488007, 75.9839679300785, 52.466258481144905, 21.159160807728767, 1.306098096538335, 0.16711611620848998, 0.19827616604743525, 0.5797423725016415, 1.731530036777258, 0.32038672536145896, 0.5496891913935542, 1.7404301092028618, 34.26298946142197, 71.80649489164352, 71.80885836482048, 72.99032896757126, 44.95365880429745, 79.18412581086159, 75.37971675395966, 76.15342363715172, 77.89483219385147, 80.80049067735672, 70.77327713370323, 72.70685657858849, 71.84215977787971, 70.26736468076706, 74.10688385367393, 71.55724346637726, 70.55364891886711, 69.2905966937542, 68.57393994927406, 65.44667735695839, 66.34716063737869, 61.017057448625565, 64.69623282551765, 72.72967055439949, 81.18276536464691, 52.67465449869633, 29.09931354224682, 36.37326702475548, 32.74058595299721, 52.2823141515255, 44.59218420088291, 29.659194499254227, 12.22203467041254, 4.780666921287775, 4.509787056595087, 1.5221533156000078, 0.10851921557332389, 0.31740174803417176, 0.14070634584641084, 0.06699755220324732, 0.07856865122448653, 0.22624662844464183, 0.2992821531370282, 0.3002049692440778, 0.1969819495570846, 4.165235795080662, 4.34046576730907, 5.927702821791172, 1.4376231702044606, 20.716429464519024, 12.70806659013033, 6.6213613003492355, 12.290210612118244, 0.11458975350251421, 0.07461442161002196, 0.17207542899996042, 2.756809308193624, 0.5647322279401124, 0.1298906863667071, 0.2004932877025567, 0.35749452479649335, 0.10512591601582244, 0.1244248058355879, 1.5456519671715796, 1.91770187811926, 16.161803863942623, 26.803647726774216, 23.32602683454752, 41.46667331457138, 38.048486933112144, 49.41096402704716, 27.578519247472286, 39.81014080345631, 99.74633485078812, 62.28125341236591, 59.84068997204304, 52.35862925648689, 62.103259563446045, 58.26443575322628, 61.20697885751724, 63.47934812307358, 60.30639298260212, 64.20497998595238, 61.98988504707813, 62.571276649832726, 67.60139733552933, 69.99409094452858, 64.14961695671082, 65.84618031978607, 66.35439544916153, 65.97009927034378, 65.37736147642136, 64.9424596130848, 64.18806329369545, 64.98984307050705, 64.57500413060188, 44.796628430485725, 46.196252927184105, 46.271131709218025, 62.72016406059265, 30.9436908736825, 0.5568610690534115, 0.32409176405053586, 1.2584287044592202, 2.5008785538375378, 0.05360128569009248, 1.113282311707735, 5.612362967804074, 23.97856391966343, 44.61497537791729, 57.52689152956009, 48.55875335633755, 20.70478118956089, 0.39509226044174284, 0.05298118048813194, 0.055133520072558895, 0.05683366907760501, 0.051263839632156305, 0.14432796713663265, 0.11352217406965792, 0.24581529636634514, 0.14410852891160175, 0.07734320213785395, 0.02450676456646761, 0.0064804400062712375, 0.0498471094033448, 0.056011885244515724, 0.047908500928315334, 0.05983564900816418, 0.06708560060360469, 0.044140850950498134, 0.022350730941980146, 0.04021248889330309, 0.035509020381141454, 0.021144551719771698, 0.03648547892225906, 0.05333431290637236, 0.07626836450072005, 0.0801104556012433, 0.05784613291325513, 0.12655574188102037, 0.01782662653567968, 0.02585890753834974, 0.07326613223995082, 0.053140642048674636, 0.10193938622251153, 0.21269949444103986, 0.07019078359007835, 0.05249944129900541, 0.039356165507342666, 0.04882199194980785, 0.06700349680613726, 0.03735647085704841, 0.03946369899495039, 0.03317884365969803, 0.0846224017732311, 0.06764872741769068, 0.006538596553582465, 0.03038845374248922, 0.17395453207427636, 1.453006169758737, 65.34638553857803, 92.20002338290215, 84.03410196304321, 87.30104506015778, 80.4282246530056, 56.57378867268562, 25.67620262503624, 2.070947061292827, 0.04455689893802628, 0.07295920964679681, 0.9686922922264785, 0.5698526313062757, 0.250773006118834, 0.7283034163992852, 2.552461023442447, 43.0615009367466, 72.79693454504013, 74.19650584459305, 76.05162709951401, 51.12099386751652, 76.37042239308357, 77.34577685594559, 78.97517502307892, 78.28198581933975, 81.76966667175293, 72.16002032160759, 71.94836407899857, 70.73052942752838, 72.06943318247795, 73.82398903369904, 73.07027667760849, 71.89740121364594, 71.14063382148743, 69.90729600191116, 65.18750086426735, 69.22196477651596, 64.05495643615723, 67.91207626461983, 73.4698860347271, 70.833450704813, 37.75974802672863, 33.71247500181198, 39.41628433763981, 34.2361781001091, 57.44036257266998, 58.31496924161911, 35.5546123534441, 17.824645936489105, 9.925758987665176, 2.427673344500363, 0.8228724449872971, 0.15506663621636108, 0.1178887409332674, 0.18912846862804145, 0.09704505588160828, 0.10448997709318064, 0.15536417806288227, 0.22195661411387846, 0.18430430092848837, 0.36573349207174033, 7.256682459264994, 6.85116964392364, 7.401311723515391, 2.1005712216719985, 21.29186298698187, 15.838918089866638, 12.549531497061253, 13.4397629275918, 0.5941408092621714, 0.2467745667672716, 2.0493098348379135, 1.245271791703999, 0.256688249646686, 0.011762092581193428, 0.7176375668495893, 0.8984223660081625, 0.9951053280383348, 0.1860754215158522, 2.728153858333826, 7.96044459566474, 21.1649326980114, 23.62128049135208, 30.460769087076187, 53.3273720741272, 39.99431312084198, 52.16545522212982, 32.780252024531364, 41.46190457046032, 88.17615330219269, 57.1122881770134, 64.65061247348785, 54.45001043379307, 64.5074437558651, 58.46169076859951, 63.672974333167076, 63.53045918047428, 64.04406622052193, 68.64337742328644, 62.171758487820625, 63.243407383561134, 68.85064870119095, 70.77081486582756, 63.63502956926823, 67.01498240232468, 68.76217424869537, 71.13245666027069, 67.51767262816429, 69.92403030395508, 67.16657146811485, 65.95034033060074, 68.59831184148788, 52.22223937511444, 53.442452698946, 55.55645786225796, 70.3087292611599, 49.49345000088215, 0.940856410888955, 0.7137879577931017, 0.5334587185643613, 1.2242288771085441, 0.07259698220877908, 2.191817625425756, 12.910666968673468, 36.85008063912392, 48.17041799426079, 66.26586779952049, 59.03921037912369, 27.556871809065342, 0.9051922964863479, 0.144517867884133, 0.0761723009054549, 0.03542759193805978, 0.10290499456459656, 0.09572972528985702, 0.01061971115632332, 0.1144788766396232, 0.06922370579559356, 0.05437119340058416, 0.058659708593040705, 0.181950208498165, 0.09595665178494528, 0.03764311426493805, 0.024893735208024736, 0.02225179152446799, 0.014240394557418767, 0.07310513814445585, 0.03587656159652397, 0.01571935943502467, 0.05115757892781403, 0.048757399126770906, 0.16936169180553406, 0.17030174058163539, 0.14151150186080486, 0.41204745532013476, 0.15427333972183987, 0.2551610581576824, 0.14000995899550617, 0.07579013195936568, 0.19680076162330806, 0.1270585914608091, 0.2720587217481807, 0.2659521228633821, 0.17323794396361336, 0.11161652437294833, 0.11765045215724967, 0.17474634427344427, 0.10334633494494483, 0.14141107443720102, 0.1075406715972349, 0.07925639947643504, 0.27758887968957424, 0.24037495313677937, 0.32634017465170473, 0.12921099783852696, 0.3226293175248429, 0.996382653247565, 77.33753889799118, 108.0307187139988, 95.31972438097, 98.64770740270615, 98.24961796402931, 71.03860929608345, 34.78920802474022, 2.7047791751101613, 0.30832436168566346, 0.24117351887980476, 2.6569530414417386, 6.541044535115361, 0.9113854297902435, 1.5550923231057823, 4.298965819180012, 49.0570168197155, 86.72042861580849, 88.78587618470192, 83.92927318811417, 63.499874621629715, 85.8329026401043, 79.23602342605591, 81.07275366783142, 81.88778713345528, 81.14222913980484, 70.54946914315224, 70.07203996181488, 74.2356513440609, 73.72216209769249, 76.09739944338799, 74.6335431933403, 72.69009187817574, 69.00711670517921, 72.05513834953308, 61.188390254974365, 65.85201680660248, 59.05751019716263, 66.24759837985039, 73.37214767932892, 86.37299805879593, 55.48417814075947, 36.1932098865509, 43.028955683112144, 40.43062850832939, 59.68934029340744, 65.40030464529991, 42.84747742116451, 29.565090648829937, 29.049657806754112, 18.296892195940018, 2.3940501362085342, 0.46069455274846405, 0.4687681398354471, 0.37120374385267496, 0.22982447786489502, 0.2851381542859599, 0.5146641551982611, 0.485512416344136, 1.1793222930282354, 0.19382032623980194, 5.8638643473386765, 10.902318935841322, 11.278884429484606, 2.265085056424141, 26.568438448011875, 18.865476585924625, 19.7464707121253, 25.432001128792763, 0.7488145376555622, 0.16028231650125235, 0.46844488999340683, 14.0025944262743, 1.5119468257762492, 0.22046023659640923, 0.9993656119331717, 0.9009473898913711, 1.386400731280446, 0.22179317835252732, 6.326842429116368, 7.712661791592836, 25.604680962860584, 31.733983866870403, 34.36418563127518, 57.383768409490585, 44.6269067376852, 56.05626784265041, 31.836627759039402, 46.55347175896168, 113.42329055070877, 69.02209550142288, 60.612694546580315, 53.976339250802994, 62.29858808219433, 58.17438818514347, 60.204524248838425, 63.10306191444397, 60.157102793455124, 62.654146403074265, 61.39952592551708, 62.884220257401466, 66.77060231566429, 70.8739185333252, 64.36778604984283, 67.91947066783905, 68.17610889673233, 67.45600193738937, 68.16383555531502, 71.79171368479729, 69.04022812843323, 69.05348941683769, 64.99805822968483, 56.01380132138729, 64.74667131900787, 64.04508456587791, 75.77417358756065, 51.3128037750721, 1.514992006123066, 1.5607220772653818, 2.794594243168831, 7.540053203701973, 0.13659921154612675, 1.5538335219025612, 22.41545509546995, 55.30365362763405, 66.55206844210625, 76.28388583660126, 70.06162852048874, 30.72215896099806, 1.1359644820913672, 0.348496874794364, 0.23104293592041358, 0.2548180671874434, 0.24553939554607496, 0.19914378121029586, 0.22178344137500972, 0.4205766913946718, 0.1737407935434021, 0.24596966308308765, 0.25734703929629177, 0.3211551153799519, 0.1609499377082102, 0.25550223828759044, 0.16382313275244087, 0.10990306123858318, 0.11829938608570956, 0.08692412084201351, 0.1365185994654894, 0.1428774098167196, 0.23320283798966557, 0.16999697021674365], [0.08305110444780439, 0.08750160821364261, 0.04914222867228091, 0.11297556004137732, 0.06883390014991164, 0.043469222146086395, 0.029615657222166192, 0.053637758537661284, 0.04317815924878232, 0.08484050413244404, 0.019034857796214055, 0.05746373390138615, 0.01266058201508713, 0.10295537154888734, 0.06118948964285664, 0.039254487564903684, 0.10509078274480999, 0.0385783539240947, 0.160075286985375, 0.1281061180634424, 0.02321325311640976, 0.047991665996960364, 0.09376877074828371, 0.043448152573546395, 0.12119624079787172, 0.25235176202841103, 12.182166259735823, 73.9073033630848, 77.56953924894333, 71.61406561732292, 79.62289586663246, 58.01009260118008, 28.204216472804546, 0.8799218118656427, 0.08551507926313207, 0.07218693819595501, 0.4887362464796752, 0.4608941311016679, 0.3667737159412354, 0.9888917114585638, 4.340077713131905, 62.00463965535164, 62.99616605043411, 69.43718522787094, 55.31564578413963, 55.10694958269596, 82.45698899030685, 71.69554844498634, 77.2518002986908, 71.23660147190094, 75.39574429392815, 72.39334300160408, 70.2890919148922, 68.15843984484673, 74.33124661445618, 71.54942348599434, 74.37255799770355, 73.87126609683037, 72.09309071302414, 74.79720801115036, 68.35995823144913, 64.34086829423904, 71.5993832051754, 70.23758187890053, 71.4081546664238, 78.72395530343056, 67.43628859519958, 29.36496488749981, 25.350932478904724, 31.20246648788452, 52.734790071845055, 49.85796444118023, 28.284908942878246, 12.555706165730953, 5.208801347762346, 2.1509204199537635, 0.10090574520290829, 0.09406437558936886, 0.21194861910771579, 0.044737522839568555, 0.04616916652594227, 0.07789979805238545, 0.15003143140347674, 0.2502555213868618, 0.5235100805293769, 1.0431123082526028, 5.134309194982052, 5.352576607838273, 10.649470053613186, 3.934758687391877, 17.25910898298025, 14.448064472526312, 6.014071237295866, 3.841937743127346, 0.6659914506599307, 0.5741538223810494, 2.1870365319773555, 0.26923746219836175, 0.13891662703827024, 0.19988714600913227, 0.08838284178636968, 0.2282162883784622, 0.02127360006852541, 0.09690560633316636, 1.77876815199852, 6.24615803360939, 17.59438969194889, 27.721078097820282, 24.48151633143425, 40.07154397666454, 46.05654202401638, 50.6065508723259, 29.243474006652832, 17.390209548175335, 32.27163031697273, 51.87922038137913, 54.99926336109638, 64.91407513618469, 64.62294235825539, 63.06625708937645, 60.00333644449711, 66.57834783196449, 60.760916993021965, 61.89059257507324, 71.04617848992348, 68.37079524993896, 63.384615406394005, 66.34223610162735, 67.57800579071045, 64.92877274751663, 64.452133923769, 66.8793372809887, 67.24214181303978, 63.00469659268856, 69.60219517350197, 67.06374138593674, 67.6204951107502, 51.35205566883087, 39.570814445614815, 50.70119999349117, 57.488213405013084, 45.361646711826324, 3.014860348775983, 0.7677783700637519, 0.16082466318039224, 0.3817438439000398, 0.6248622201383114, 3.3864633087068796, 14.326489046216011, 32.66028866171837, 51.51057556271553, 61.24748848378658, 38.387892320752144, 4.024022547528148, 0.3124752233270556, 0.04503271949943155, 0.1361633779015392, 0.04044079207233153, 0.07057629220071249, 0.04640529565222096, 0.10263379896059632, 0.08183390062185936, 0.022810977534390986, 0.03420792789256666, 0.04578740947181359, 0.046199305143090896, 0.04859006709011737, 0.03696655388921499, 0.02107845233695116, 0.029450362380885053, 0.0407489206554601, 0.07409853249555454, 0.022465648798970506, 0.02887744292820571, 0.08500405121594667, 0.05606805469142273, 0.04953194526024163, 0.03468170383712277, 0.029200086064520292, 0.03180521736794617, 0.03885741258272901, 0.089874417608371, 0.05309261025104206, 0.05284075501549523, 0.1399626545025967, 0.08397927886107937, 0.09100322422455065, 0.0648810138227418, 0.032265296977129765, 0.16963683563517407, 0.07258359386469238, 0.0419641169719398, 0.11015300173312426, 0.01751858329953393, 0.08075572332018055, 0.15747728029964492, 0.05516470511793159, 0.02650027527124621, 0.0737798839691095, 0.08547348930733278, 0.21623708977131173, 0.7058018550742418, 21.66649628430605, 94.452253729105, 86.55277401208878, 78.74031722545624, 84.41601186990738, 67.87906363606453, 38.60376253724098, 1.6293032909743488, 0.050312109451624565, 0.20338226080639288, 0.1262587046949193, 0.3778756217798218, 1.1637912201695144, 1.7503897310234606, 7.404525401070714, 72.49175772070885, 71.75436168909073, 75.24710386991501, 62.771309316158295, 62.04849310219288, 82.69319951534271, 75.35272300243378, 80.87279319763184, 74.70039680600166, 77.58653953671455, 74.14285272359848, 71.90554037690163, 71.21172040700912, 74.37361434102058, 73.6255332827568, 75.70262342691422, 74.7512836754322, 74.45582672953606, 76.87221586704254, 67.64627292752266, 65.07130309939384, 71.24619215726852, 71.49284452199936, 72.00709372758865, 74.1263236105442, 57.74413727223873, 27.51274287700653, 25.889618173241615, 30.055228248238564, 59.89750072360039, 61.58228471875191, 34.21936020255089, 21.453941389918327, 11.135162841528654, 1.7067637969739735, 0.47375094902236015, 0.24071377323707566, 0.08469128792057745, 0.032535587160964496, 0.07509062808821909, 0.06698283541481942, 0.2834385767346248, 0.22870931192301214, 0.14174625801388174, 1.3326870510354638, 6.986857987940311, 6.63893535733223, 11.10265463590622, 5.787547817453742, 16.33707895874977, 15.963009931147099, 10.699345227330923, 8.858859837055206, 3.9936403278261423, 2.3891657358035445, 4.729572013020515, 1.8711558007635176, 0.12461867707315832, 0.10930849704891443, 0.21215587126789615, 0.3637168987188488, 0.06295262472121976, 0.1770618895534426, 6.195499151945114, 15.148523636162281, 22.443774975836277, 23.949166797101498, 25.923660546541214, 47.20070242881775, 52.22518801689148, 48.353891149163246, 28.851502239704132, 21.664322800934315, 45.69445185363293, 50.33213719725609, 58.37899960577488, 64.21973079442978, 67.15902507305145, 64.3394623696804, 62.05240689218044, 69.76321533322334, 59.18516054749489, 66.58808290958405, 73.05834531784058, 68.86199489235878, 63.632172122597694, 67.32181593775749, 67.59757474064827, 68.41880947351456, 67.53161028027534, 68.84505540132523, 68.68997812271118, 67.79348462820053, 69.48006972670555, 70.15662342309952, 68.51962566375732, 58.89806695282459, 47.98105135560036, 63.16081881523132, 68.41440171003342, 58.88179622590542, 8.738374952226877, 0.49934023059904575, 1.2854143814183772, 0.5586776684504002, 1.1171146435663104, 9.138787016272545, 28.8406690210104, 40.999055206775665, 58.388537093997, 69.78456258773804, 48.13454411923885, 9.283023476600647, 0.13635489653097466, 0.052524210477713495, 0.11035342613467947, 0.11404979653889313, 0.08823346230201423, 0.07164392358390614, 0.09775386628462002, 0.10508333900361322, 0.06550789854372852, 0.08986174914753065, 0.07344780999119394, 0.03189726594428066, 0.007953007570904447, 0.038345093198586255, 0.04758531787956599, 0.04170770866039675, 0.06714469782309607, 0.09504665256827138, 0.03595842790673487, 0.034025585919152945, 0.06258298322791234, 0.07947664664243348, 0.24740960769122466, 0.15018226549727842, 0.16444088163552806, 0.2527010760968551, 0.12342246118350886, 0.20556316565489396, 0.2114407971384935, 0.1614363116095774, 0.2675990969873965, 0.1902886977768503, 0.24444851267617196, 0.0731096207164228, 0.16171681374544278, 0.1704746758332476, 0.1950465768459253, 0.12007940502371639, 0.20724772213725373, 0.11207932766410522, 0.32395538699347526, 0.26216458703856915, 0.11178415326867253, 0.23216369765577838, 0.15566532674711198, 0.42272571357898414, 0.27166760992258787, 0.9455215511843562, 22.06663191318512, 108.26673924922943, 98.81041467189789, 91.76794856786728, 99.67679098248482, 78.4004482626915, 47.772526144981384, 3.2300439896062016, 0.1916857759351842, 0.2840012434171513, 3.0807074904441833, 2.1419635880738497, 2.662762454710901, 2.883043522015214, 11.52540760114789, 76.27975925803185, 76.25447541475296, 85.08099138736725, 72.75173217058182, 71.20829299092293, 83.43131750822067, 75.43688848614693, 82.42820933461189, 73.53645846247673, 76.93953305482864, 76.09722465276718, 70.15102252364159, 70.72576448321342, 72.82378390431404, 70.3641226887703, 78.98101150989532, 77.20358088612556, 74.26531255245209, 79.85390827059746, 66.88175395131111, 62.33217068016529, 70.36492824554443, 71.8138436973095, 69.44618314504623, 80.1376922428608, 70.12491032481194, 36.08552746474743, 28.09916350990534, 40.65910644829273, 63.10716949403286, 69.97740983963013, 41.80028401315212, 30.41286125779152, 26.971503719687462, 7.982074934989214, 2.9399616178125143, 0.7075517205521464, 0.4433193022850901, 0.36903765227179974, 0.4287231870694086, 0.288491741521284, 0.667514456436038, 0.6628269329667091, 1.1817839671857655, 4.383184500038624, 11.765160486102104, 9.196481220424175, 18.0760233476758, 6.763351131230593, 22.757546938955784, 19.131904989480972, 15.996461436152458, 14.522916655987501, 3.6859207274392247, 0.8079460740555078, 9.393762834370136, 8.030243050307035, 0.2215251442976296, 0.6085558701306581, 0.47296563803683966, 0.846506345551461, 0.16025956225348637, 0.3329181857407093, 12.613108735531569, 16.597904562950134, 29.585233367979527, 35.48174366354942, 32.44854502379894, 49.44042384624481, 60.58248616755009, 49.76399928331375, 37.06372417509556, 21.96275118738413, 44.928496554493904, 53.890897035598755, 59.56480197608471, 62.90935590863228, 68.24582755565643, 65.63044309616089, 61.79109111428261, 67.89023503661156, 61.52494199573994, 65.01298382878304, 73.3481253683567, 68.10823693871498, 65.19693955779076, 67.01220095157623, 66.96718856692314, 66.60646632313728, 68.93708646297455, 70.59875249862671, 72.44780167937279, 70.67242294549942, 71.81065186858177, 73.19733425974846, 68.90387624502182, 60.3730908036232, 58.53495083749294, 72.35481306910515, 75.57114288210869, 68.25198322534561, 14.12485571578145, 1.4853300852701068, 2.5050690164789557, 1.0756670613773167, 1.260551840532571, 10.738145895302296, 49.094384014606476, 59.26598221063614, 73.8010686635971, 79.60265815258026, 54.35517892241478, 8.45712449401617, 0.4094706295290962, 0.22930444014491513, 0.24178748280974105, 0.19394058384932578, 0.2558914799010381, 0.1505738968262449, 0.20561569486744702, 0.16808101208880544, 0.1711505645653233, 0.1386637773248367, 0.19364973617484793, 0.1532780157867819, 0.20856356481090188, 0.15875849436270073, 0.1545759430155158, 0.09446543219382875, 0.24849047156749293, 0.13310733251273632, 0.10939626343315467, 0.2821566502097994, 0.17680216755252331, 0.22538947756402194], [0.019666423613671213, 0.08082993808784522, 0.04289763113774825, 0.0038901089828868862, 0.01717536597425351, 0.10617249266942963, 0.011540232171682874, 0.07473664591088891, 0.07887033425504342, 0.08809621693217196, 0.06805664888815954, 0.029632027144543827, 0.09010929250507616, 0.07358314804150723, 0.03441643428232055, 0.04044910783704836, 0.07739963504718617, 0.07905420134193264, 0.08499711213517003, 0.005072909625596367, 0.027649173680401873, 0.13499422813765705, 0.09712714483612217, 0.09375131543492898, 0.162517101271078, 0.10032597943791188, 1.858554370701313, 46.99791871011257, 89.85210657119751, 76.42726734280586, 85.78045785427094, 65.77930390834808, 36.47483177483082, 5.02228788100183, 0.0857441579864826, 0.16645530791720375, 0.4409184248652309, 0.5016759177669883, 0.282194766914472, 0.7721049129031599, 27.381537817418575, 91.78058668971062, 66.7710354924202, 75.98633900284767, 46.21079094707966, 71.54087394475937, 78.5120102763176, 76.20938703417778, 75.36498114466667, 76.20199263095856, 76.36534586548805, 75.72529301047325, 71.79169088602066, 68.82169425487518, 72.94832602143288, 72.92794391512871, 71.31055310368538, 70.22156193852425, 71.30725488066673, 70.87496727705002, 67.07529276609421, 69.32916462421417, 70.20766988396645, 68.14099118113518, 71.05003908276558, 74.43252637982368, 83.6308827996254, 52.19480484724045, 32.051713317632675, 43.22806119918823, 49.67372752726078, 47.92391002178192, 27.12262351065874, 12.822471801191568, 2.614631149917841, 1.6912786778993905, 0.2660264860605821, 0.09205716298311017, 0.23072731535648927, 0.10079524683533236, 0.11022239996236749, 0.14442487678024918, 0.6113993644248694, 0.2003288723062724, 0.3852648596512154, 1.7217896156944335, 3.4182307915762067, 3.7300278106704354, 10.599046759307384, 3.360954327508807, 9.89227233454585, 12.111852932721376, 6.511900098994374, 2.6494166208431125, 0.71434878394939, 7.115579405799508, 8.213699106127024, 0.07301265170099214, 0.08954309319960885, 0.14351481077028438, 0.09020592755405232, 0.053927671106066555, 0.1519298303173855, 0.03154700934828725, 2.5749964267015457, 8.940720744431019, 20.46077538281679, 31.114505007863045, 23.72285284101963, 31.110577918589115, 43.98778483271599, 50.74998937547207, 41.73683121800423, 22.860927991569042, 34.534598886966705, 74.68450605869293, 59.53031122684479, 61.08199596405029, 59.00212436914444, 64.62264597415924, 60.13867758214474, 64.12386953830719, 68.99073958396912, 69.82196778059006, 62.51859247684479, 69.22281593084335, 66.76833003759384, 66.04979619383812, 65.84290489554405, 62.83746376633644, 66.80784791707993, 68.93337786197662, 66.97011440992355, 66.58346995711327, 68.42357441782951, 69.45877566933632, 68.37421506643295, 65.39664924144745, 39.190804436802864, 46.12377941608429, 43.805755600333214, 54.015769734978676, 19.333252385258675, 0.3272280504461378, 0.23840477369958535, 0.9017707582097501, 6.461439281702042, 16.797846034169197, 30.168025195598602, 39.58068251609802, 54.11372847855091, 46.312541887164116, 22.58429143577814, 0.8163116814102978, 0.057557916152291, 0.14991656178608537, 0.06507718571810983, 0.09041602213983424, 0.08077404694631696, 0.034853882098104805, 0.14406610775040463, 0.09015879375510849, 0.02930096619820688, 0.018271469853061717, 0.11982589479885064, 0.05995180254103616, 0.018714398429438006, 0.04726558952825144, 0.027749096443585586, 0.06510025908937678, 0.07809739487129264, 0.07158845546655357, 0.03275040922744665, 0.05202211417781655, 0.02012213382840855, 0.0167372001305921, 0.05216354526055511, 0.05820962571306154, 0.020117205967835616, 0.02110221961629577, 0.054902433839743026, 0.02477636455296306, 0.026394316992082167, 0.03166570473695174, 0.05179480918741319, 0.04072066338267177, 0.1524576309020631, 0.021099837322253734, 0.018961414862133097, 0.0248114124769927, 0.025118923222180456, 0.04659979029383976, 0.06253787549212575, 0.0665794410451781, 0.06634206511080265, 0.05375640197598841, 0.0318301090010209, 0.05770908792328555, 0.0524838858837029, 0.1149164023809135, 0.03170395131746773, 0.2616576408036053, 3.6099806148558855, 62.56748825311661, 97.39901840686798, 85.87039902806282, 90.66816598176956, 66.95851743221283, 52.46262967586517, 8.012486603111029, 0.22102986462414265, 0.13201408961322159, 0.1950307987863198, 0.2573713520541787, 1.0820716177113354, 0.4783237661467865, 35.60214780271053, 97.92638450860977, 74.83371645212173, 84.39775004982948, 54.40251678228378, 76.36582463979721, 77.43096828460693, 77.87055149674416, 76.90434694290161, 78.4988097846508, 79.32156443595886, 77.31471732258797, 72.74037837982178, 70.30554503202438, 73.76745566725731, 74.81292396783829, 73.18975746631622, 71.2268815934658, 73.91738042235374, 73.86586278676987, 67.69163489341736, 69.50440362095833, 69.80650261044502, 70.92309549450874, 74.17266592383385, 75.43010205030441, 76.22799083590508, 42.515173852443695, 28.662209697067738, 38.50523382425308, 56.575977355241776, 63.892978727817535, 31.610444895923138, 21.33899375796318, 9.899763632565737, 1.1866202764213085, 1.28505245083943, 0.17902495921589434, 0.08190343985916115, 0.05345394711184781, 0.2161411746055819, 0.20202037529088557, 0.8009429310914129, 1.5745134372264147, 0.4055831115692854, 2.1085911663249135, 5.923954797908664, 5.2309071365743876, 8.272660542279482, 3.4998276131227612, 8.180964812636375, 13.767361398786306, 9.638220816850662, 1.595729598775506, 1.0312027973122895, 9.679659493267536, 10.389121323823929, 0.4443943774094805, 0.5970836919732392, 0.12542289798147976, 0.02425322094495641, 0.08212730870582163, 0.2507628238527104, 0.4658253461821005, 8.255247976630926, 17.635330595076084, 23.060920760035515, 26.851665750145912, 25.46627528965473, 32.71049536764622, 51.35047495365143, 49.15848657488823, 40.90161703526974, 20.666439346969128, 38.3838265389204, 72.90699943900108, 60.190700590610504, 64.44944366812706, 59.43048678338528, 68.16991522908211, 59.26581121981144, 66.40808656811714, 68.32590445876122, 71.38866171240807, 63.95628333091736, 68.5871784389019, 67.16676905751228, 68.58866035938263, 66.10666394233704, 65.07219225168228, 69.4728273153305, 71.49422764778137, 66.66608512401581, 67.57179692387581, 70.05005434155464, 72.94829562306404, 69.60673213005066, 71.10876873135567, 47.11882062256336, 55.81711247563362, 53.43234904110432, 59.540540277957916, 26.125750802457333, 0.6754199916031212, 1.3788672792725265, 2.2993307188153267, 12.734923548996449, 26.74688257277012, 45.502888932824135, 46.91231690347195, 59.83433671295643, 55.23486211895943, 30.14470584690571, 1.2188347103074193, 0.05277896751067601, 0.017005371482810006, 0.1413773512467742, 0.021202468924457207, 0.009411789742443943, 0.06729710526997223, 0.07769984862534329, 0.09135900239925832, 0.08833442407194525, 0.09306890322477557, 0.019432500521361362, 0.13315895630512387, 0.02951447466330137, 0.05766162015788723, 0.0657653198868502, 0.09119214533711784, 0.09084570338018239, 0.056981976158567704, 0.06194750814756844, 0.05429498225566931, 0.03792912684730254, 0.08972427371190861, 0.18782721657771617, 0.15573269891319796, 0.11690907631418668, 0.08587390766479075, 0.14333028317196295, 0.1761122967582196, 0.11622438571066596, 0.18181856634328142, 0.16511905618244782, 0.1421447319444269, 0.28237745398655534, 0.09625033446354792, 0.09195179285597987, 0.13024657586356625, 0.17598666599951684, 0.266190945985727, 0.1621062631602399, 0.12730396032566205, 0.1291078986832872, 0.21826886746566743, 0.17650873720413074, 0.2489493860048242, 0.16003678436391056, 0.288654895266518, 0.14343388698762283, 0.5645060213282704, 2.5962935714051127, 71.68430864810944, 114.80190217494965, 98.00124049186707, 112.02871218323708, 82.23648682236671, 59.17340777814388, 11.99811078608036, 0.34732760628685355, 0.25143737671896815, 2.524509010836482, 1.5304734441451728, 1.7367409821599722, 0.9426060982514173, 45.83893910050392, 108.71250092983246, 85.04762917757034, 94.77501600980759, 62.05749861896038, 84.15473029017448, 78.89536410570145, 79.99732777476311, 78.4376710653305, 80.22174373269081, 80.54766744375229, 77.83562377095222, 72.10005953907967, 70.92813402414322, 73.03026482462883, 75.4700531065464, 73.33398252725601, 70.20922020077705, 71.93220734596252, 74.39740106463432, 63.35969254374504, 67.75275081396103, 66.97474256157875, 70.97015976905823, 70.99909901618958, 76.41112580895424, 85.9372678399086, 63.95318269729614, 35.67674160003662, 52.91385546326637, 58.75150881707668, 68.20655286312103, 39.831491857767105, 32.61636681854725, 22.537612840533257, 7.352425446733832, 2.3128701047971845, 0.2983959694392979, 0.2551215165294707, 0.1910712628159672, 0.5197839054744691, 0.9816959663294256, 1.5004066075198352, 2.4295777548104525, 0.4858973831869662, 1.7234332649968565, 10.068874508142471, 6.250012926757336, 13.258879333734512, 4.479734944179654, 14.85730156302452, 20.602182894945145, 14.150130059570074, 6.025998322293162, 0.6115840107668191, 19.555107280611992, 15.975243374705315, 0.2227810659678653, 1.3244830537587404, 0.4427852528169751, 0.15316449687816203, 0.2556770882802084, 0.32637763826642185, 1.136748071294278, 12.205687947571278, 22.39181086421013, 29.824248142540455, 40.21048732101917, 29.18240748345852, 35.56440822780132, 56.43855772912502, 58.24843481183052, 52.57772170007229, 26.157349906861782, 48.18007327616215, 77.11015909910202, 58.63854467868805, 60.97905568778515, 60.89687369763851, 68.77785980701447, 60.65809451043606, 64.30203437805176, 70.14931261539459, 74.01091620326042, 63.84485051035881, 68.94018709659576, 67.59882867336273, 66.20847567915916, 67.44949668645859, 65.68832919001579, 71.73510432243347, 74.0427128970623, 69.65826496481895, 67.93020129203796, 70.70298090577126, 76.3270591199398, 73.5336922109127, 71.80825039744377, 55.734151527285576, 66.39446809887886, 65.28890982270241, 75.05462899804115, 31.67757399380207, 2.07865328527987, 2.8914624452590942, 4.318043170496821, 16.608386300504208, 34.976632967591286, 63.79523277282715, 62.62242570519447, 73.18506851792336, 64.35444876551628, 33.89665871858597, 1.1722648842260242, 0.1692359719891101, 0.16704345995094627, 0.18442553817294538, 0.2507328410865739, 0.19525639683706686, 0.15554907673504204, 0.2803443849552423, 0.1145109893695917, 0.1735344171174802, 0.1338335537002422, 0.14148702583042905, 0.20817423413973302, 0.08397408382734284, 0.25988957786466926, 0.1292909716721624, 0.22194068762473762, 0.16930375975789502, 0.20753705583047122, 0.14458274643402547, 0.1965242819278501, 0.1220759455463849, 0.21539304521866143], [0.04426809216965921, 0.0418886257102713, 0.04231192448060028, 0.05268865555990487, 0.04190884923445992, 0.05208183851209469, 0.0373306886467617, 0.055219739078893326, 0.030689422455907334, 0.0784693073364906, 0.1571342596434988, 0.0730241253040731, 0.08794702298473567, 0.11960630072280765, 0.00992170549579896, 0.0463620841037482, 0.05474545105244033, 0.014675675301987212, 0.06813189524109475, 0.05888079809665214, 0.12357269413769245, 0.04461714648641646, 0.05972988925350364, 0.074960336642107, 0.183946066244971, 0.06326420058030635, 0.5381793715059757, 20.214028023183346, 82.49228909611702, 83.43312621116638, 81.12138345837593, 79.03958156704903, 54.95593808591366, 15.19052468240261, 0.3293457243125886, 0.31235410482622683, 0.3299785981653258, 0.12923373724333942, 0.8009004802443087, 0.1567660504952073, 49.855961948633194, 81.89711183309555, 69.499152302742, 60.0981679558754, 51.45448677241802, 79.75525796413422, 79.40679386258125, 80.40257602930069, 77.62867167592049, 79.38570499420166, 80.41969031095505, 76.22714728116989, 73.99754092097282, 74.41862672567368, 75.53714230656624, 77.00901612639427, 73.00349146127701, 74.58387225866318, 72.57550522685051, 72.5748136639595, 71.07985228300095, 69.06498000025749, 71.55162736773491, 74.63475152850151, 68.26339781284332, 68.67733240127563, 76.31412461400032, 64.04054760932922, 29.35923669487238, 38.27657729387283, 56.74524687230587, 47.28609524667263, 27.067708857357502, 11.828965712338686, 3.1174595933407545, 2.3588606994599104, 0.9200188040267676, 0.055532992191729136, 0.09893133552395739, 0.11021780606824905, 0.19456136069493368, 0.11908156520803459, 0.5249228328466415, 0.30579930811654776, 0.38043205335270613, 1.9180235546082258, 2.9791740886867046, 0.30150761653203517, 7.850677985697985, 0.42359239363577217, 0.4982543201185763, 8.185560666024685, 6.744018718600273, 2.8726225811988115, 4.053935967385769, 1.6323379031382501, 8.886908981949091, 0.8438562846276909, 0.3397350199520588, 0.18071477010380477, 0.041673911255202256, 0.021555406528932508, 0.09480152861215174, 0.3140105487545952, 6.487010959535837, 12.934201955795288, 22.142297253012657, 28.38731724768877, 26.109837256371975, 27.18858227133751, 32.47422404587269, 47.504192143678665, 28.934924863278866, 32.8779561817646, 52.776200249791145, 64.18284237384796, 59.593783020973206, 66.02678462862968, 64.35208529233932, 61.843011528253555, 61.422313302755356, 64.10344943404198, 65.82513704895973, 67.93372750282288, 69.91366446018219, 68.59692871570587, 71.19352698326111, 70.45754447579384, 64.87198859453201, 67.10394322872162, 67.89514437317848, 68.6770436167717, 66.30307540297508, 70.3745873272419, 64.34269219636917, 69.14939627051353, 63.85832458734512, 69.86191123723984, 38.80475655198097, 39.58239242434502, 43.800834864377975, 45.94256334006786, 24.20309767127037, 5.156851010397077, 1.504409455228597, 5.532644670456648, 17.410525158047676, 28.8227054849267, 43.669384717941284, 58.030653297901154, 60.13644330203533, 42.05998107790947, 8.936170488595963, 0.12242201642948203, 0.08412248367676511, 0.1881587487878278, 0.04567797979689203, 0.09664374694693834, 0.050766181375365704, 0.031189861911116168, 0.1097821505391039, 0.1125438378949184, 0.0303721691670944, 0.018450715215294622, 0.07185035938164219, 0.06481998701929115, 0.06454816801124252, 0.012495064529502997, 0.05123576047481038, 0.019323876076668967, 0.021312323478923645, 0.012749790021189256, 0.08250877261161804, 0.030491102043015417, 0.0329189992044121, 0.013319816025614273, 0.038171649575815536, 0.041274966060882434, 0.013339165670913644, 0.050972747048945166, 0.0358674146264093, 0.05143399554071948, 0.017452272404625546, 0.05226648485404439, 0.049883971878443845, 0.029066859424347058, 0.08340785483596846, 0.08367478309082799, 0.07737417938187718, 0.08003704977454618, 0.0458403246011585, 0.05732809157052543, 0.0673593937244732, 0.05100582828163169, 0.07827297959011048, 0.0627553767117206, 0.03196112775185611, 0.04325543537561316, 0.08546042008674704, 0.06312535959295928, 0.14906111784512177, 0.15047110937302932, 0.49858947400934994, 32.686689645051956, 97.50001698732376, 88.9244319498539, 95.13855770230293, 77.60680764913559, 60.13176575303078, 24.038794487714767, 0.6310338014736772, 0.1943521641078405, 0.24616125592729077, 0.1059643054031767, 0.8065169944893569, 0.9356970596127212, 60.831961780786514, 89.77985724806786, 77.49331533908844, 71.58049821853638, 60.26662051677704, 83.57868120074272, 79.89195182919502, 82.94534638524055, 77.03979447484016, 81.7047281563282, 82.2284996509552, 78.6937165260315, 74.7576293349266, 78.72438088059425, 76.48796528577805, 77.35881015658379, 75.5685818195343, 73.06611970067024, 75.23094713687897, 75.14521613717079, 69.12755504250526, 69.47954535484314, 72.26104170084, 75.62729626893997, 69.55109551548958, 70.59347838163376, 75.03172382712364, 53.42596538364887, 21.189093701541424, 39.172899797558784, 64.05188620090485, 57.45295129716396, 31.45281035453081, 22.811612337827682, 14.87882835790515, 5.570217054337263, 0.4607793060131371, 0.03102550959738437, 0.0666945926786866, 0.16910637816181406, 0.11253495438722894, 0.12517049355665222, 0.43719735578633845, 0.4115740838460624, 0.2258469077059999, 1.7537540942430496, 2.3229989362880588, 0.9270236687734723, 6.185715151950717, 0.8031904511153698, 1.247919537127018, 7.783231604844332, 8.887703139334917, 3.4500210732221603, 10.624299254268408, 16.257881708443165, 15.136638823896646, 2.089522364549339, 0.35324605589266866, 0.20846724888542667, 0.09001806771266274, 0.03700056651723571, 0.07051942142425105, 0.2092301766970195, 12.82828263938427, 21.954517029225826, 22.362199053168297, 25.66690642386675, 25.15409544110298, 26.02549698203802, 45.23498050868511, 44.460840448737144, 30.523355528712273, 28.45672432333231, 52.31438063085079, 64.94223162531853, 62.168156281113625, 65.31652674078941, 64.3068677186966, 66.27000957727432, 62.556681632995605, 65.81762105226517, 64.43620517849922, 69.28935036063194, 67.52793207764626, 68.67677763104439, 69.11006838083267, 72.4532201886177, 67.4027743935585, 70.08274778723717, 70.66532492637634, 69.8182363808155, 67.84631699323654, 70.75720399618149, 66.50378823280334, 71.44551426172256, 66.69243291020393, 73.86905461549759, 47.6392786949873, 51.285411044955254, 51.31365492939949, 53.34704741835594, 32.53929555416107, 8.519916124641895, 3.703510696068406, 7.22162364050746, 23.255464620888233, 42.93120592832565, 51.44741155207157, 59.952259585261345, 64.48744922876358, 47.864428013563156, 14.055622480809689, 0.11381209405953996, 0.06945944900508039, 0.06267146949539892, 0.09869528803392313, 0.057590878641349263, 0.030881588609190658, 0.027906839932256844, 0.05553093273192644, 0.22085964563302696, 0.029588667166535743, 0.009678476799308555, 0.054703983551007695, 0.012260966104804538, 0.05214102850004565, 0.07110151011147536, 0.07030870343442075, 0.01731982501951279, 0.038167400780366734, 0.018681107540032826, 0.07398098372505046, 0.041826927263173275, 0.009449975095776608, 0.08335775244631805, 0.1423550714389421, 0.24040689517278224, 0.12736263452097774, 0.144998749892693, 0.20532214577542618, 0.25302717578597367, 0.15742240590043366, 0.14822513301623985, 0.08487604558467865, 0.17091951915062964, 0.20507656910922378, 0.2405847137561068, 0.2333655464462936, 0.20661933085648343, 0.099027384276269, 0.13868762995116413, 0.30210742028430104, 0.10223718782071956, 0.18655520514585078, 0.16628228360787034, 0.21333036449505016, 0.16812892514280975, 0.25690703478176147, 0.29974543140269816, 0.23296897241380066, 0.34028144844342023, 0.9414957859553397, 31.081121899187565, 112.04526409506798, 105.20500794053078, 111.0524533689022, 101.60337880253792, 78.01545292139053, 35.23471511900425, 1.5321056940592825, 0.5456100509036332, 0.9532714728266001, 1.032806548755616, 1.4540367457084358, 1.8218344473280013, 66.87510430812836, 98.3263510465622, 89.4815656542778, 81.36936575174332, 70.6651121377945, 86.99426472187042, 81.32031798362732, 82.78893917798996, 79.14508670568466, 82.44074866175652, 84.09444272518158, 78.93375724554062, 74.07688826322556, 77.88963407278061, 76.31072759628296, 78.04718881845474, 73.65834072232246, 74.76272866129875, 75.1034639775753, 76.37947350740433, 68.14250349998474, 66.93514108657837, 70.61744749546051, 75.23585647344589, 67.34476670622826, 68.12632396817207, 78.48094314336777, 72.42434933781624, 31.741195879876614, 48.57525587081909, 65.92617362737656, 62.3819138109684, 39.4879636913538, 30.75493600219488, 23.6950858309865, 7.207430927082896, 3.9763647923246026, 0.7459426042623818, 0.2125557404360734, 0.1677573614870198, 0.3548941283952445, 0.3205513337161392, 0.823632285464555, 0.619662021053955, 1.3862192910164595, 3.112450037151575, 13.47966743633151, 0.5768140952568501, 14.864757712930441, 0.5871845106594265, 1.7688772827386856, 13.094286415725946, 11.365610975772142, 4.824120439589024, 12.89980810135603, 18.067245818674564, 23.170484080910683, 2.9856031062081456, 0.5758146895095706, 0.6039144191890955, 0.20205118926241994, 0.16957277344772592, 0.26353836175985634, 0.9104073978960514, 24.426320493221283, 29.40032958984375, 30.747161619365215, 36.3382975012064, 36.406108662486076, 31.357245482504368, 46.586279198527336, 53.61441247165203, 37.809042781591415, 41.79995723068714, 65.6427164375782, 62.527670189738274, 63.52446690201759, 65.51102310419083, 65.75631514191628, 66.6671946644783, 63.638441786170006, 64.73109975457191, 67.58866041898727, 69.31009724736214, 69.52734678983688, 69.67059910297394, 69.7695229947567, 73.06930392980576, 67.14533060789108, 71.1160035431385, 72.99994245171547, 72.29527026414871, 68.83820816874504, 73.7322011590004, 68.70035156607628, 74.40451428294182, 71.2217366695404, 75.25080487132072, 55.700998306274414, 61.49322509765625, 63.161601573228836, 68.68584394454956, 40.5203302949667, 10.373623855412006, 7.584751630201936, 10.404317658394575, 31.920141577720642, 54.72008474171162, 65.06739690899849, 74.27800387144089, 74.58336308598518, 55.01595966517925, 12.919563241302967, 0.11626523351878859, 0.13293877593241632, 0.19212953571695834, 0.14803155121626332, 0.10242961187032051, 0.11976175097515807, 0.20043759694090113, 0.16440928098745644, 0.26070968073327094, 0.23768187733367085, 0.1566326865577139, 0.14811269764322788, 0.23420732002705336, 0.2308252640068531, 0.14341712929308414, 0.1238893908157479, 0.11828889211756177, 0.09108376951189712, 0.11812534503405914, 0.19394944509258494, 0.14553800923749804, 0.25086761510465294, 0.13344359962502494], [0.032378218456869945, 0.04575363804178778, 0.06736448485753499, 0.06589557422557846, 0.022856625182612333, 0.062228689348557964, 0.047858535835985094, 0.027971406780125108, 0.05424728071375284, 0.03756173035071697, 0.09647370607126504, 0.045662743505090475, 0.03761657506402116, 0.04457669201656245, 0.04612128315784503, 0.056942041192087345, 0.04921671803458594, 0.04134746646741405, 0.04712986556114629, 0.10863857518415898, 0.022754581732442603, 0.057556431856937706, 0.07315754119190387, 0.023286254472623114, 0.14701773296110332, 0.04367961359093897, 0.24879862612579018, 5.301097445189953, 69.05417338013649, 84.22802835702896, 82.7336597442627, 91.73487514257431, 71.46514400839806, 39.93762016296387, 3.0283334758132696, 0.10191090259468183, 0.3512322827009484, 0.3355100622866303, 0.5031787964981049, 9.120650589466095, 66.12410500645638, 74.88020315766335, 71.28685757517815, 56.549435779452324, 57.72726237773895, 83.45676854252815, 76.58880427479744, 83.62200647592545, 78.9281715452671, 81.60395756363869, 80.88049158453941, 78.40978056192398, 76.59792378544807, 75.59271812438965, 74.5736888051033, 75.5246789753437, 70.90760752558708, 73.41239511966705, 73.73324990272522, 72.18462780117989, 73.84890049695969, 73.20596739649773, 72.07306578755379, 72.39996984601021, 70.70149898529053, 70.64870461821556, 77.45928436517715, 72.37585633993149, 41.733776181936264, 36.413601860404015, 57.103214263916016, 37.12054632604122, 27.689908370375633, 14.364936333149672, 5.7124899700284, 0.84657889790833, 1.5944085759110749, 0.08967075002146885, 0.09279146615881473, 0.015603710562572815, 0.09022370941238478, 0.03619055314629804, 0.08959358150605112, 0.14082007255638018, 0.04451963941392023, 0.6069425598252565, 1.2580467062070966, 0.4725954250898212, 0.2676719462033361, 0.33376604493241757, 0.6419241952244192, 6.80342473089695, 5.616355128586292, 7.794823832809925, 6.2148994859308, 15.663392208516598, 10.290809199213982, 0.8525693358387798, 0.2502664754865691, 0.04782898351550102, 0.09715789201436564, 0.4374497156823054, 0.04361383704235777, 0.9916053002234548, 8.446204829961061, 17.110882736742496, 22.459595426917076, 29.7075355052948, 26.49026334285736, 23.47061287611723, 24.00946956127882, 41.382770016789436, 30.691998079419136, 36.54571317136288, 56.30517728626728, 69.21241208910942, 64.23593312501907, 64.79980766773224, 63.76529797911644, 64.45465698838234, 64.78022351861, 68.1062762439251, 66.24124512076378, 68.76730397343636, 66.67217999696732, 66.9097812473774, 69.14306581020355, 68.94262656569481, 65.28558120131493, 68.86112853884697, 70.01783967018127, 70.29742106795311, 68.6009868979454, 69.718157351017, 67.09522649645805, 68.9255578815937, 61.966964676976204, 72.76606500148773, 50.160819590091705, 35.27204431593418, 47.155712842941284, 43.36148343980312, 29.05098583549261, 7.243498591706157, 6.3074112217873335, 14.99078270047903, 21.973096132278442, 45.724686831235886, 67.98398360610008, 74.29824158549309, 53.64940099418163, 25.453072898089886, 1.1413623299449682, 0.04515386768616736, 0.08911589815397747, 0.08141259822878055, 0.023549694633402396, 0.08269158584880643, 0.13970325904665515, 0.06821887494879775, 0.09643377110478468, 0.04318567349400837, 0.013863951280654874, 0.016577510359638836, 0.052813495931332, 0.0538615531695541, 0.03348703161464073, 0.05465360656671692, 0.013915331091993721, 0.023273806800716557, 0.03375010070158169, 0.010531948482821463, 0.05133089638547972, 0.07477083665435202, 0.04587519069900736, 0.010475620401848573, 0.05637561553157866, 0.010998987581842812, 0.01209761661812081, 0.07378539070487022, 0.07314128815778531, 0.01999359199544415, 0.06922790635144338, 0.03322374730487354, 0.005048261973570334, 0.06685024331090972, 0.046250932646216825, 0.0330300356290536, 0.06251814920688048, 0.075942947587464, 0.06351898729917593, 0.11138026908156462, 0.056207741727121174, 0.03190098039340228, 0.10142309634829871, 0.05511245421075728, 0.0046921461216697935, 0.08198422263376415, 0.006714331093462533, 0.04177614951913711, 0.10193756053922698, 0.09113943058764562, 0.43613077083136886, 10.22450940683484, 83.39452788233757, 92.34594315290451, 89.4318263232708, 98.05725708603859, 72.78375685214996, 57.234140038490295, 4.93629184551537, 0.16869430808583274, 0.17053127201506868, 1.6291503491811454, 2.008158043026924, 13.062622714787722, 81.07026100158691, 84.14566397666931, 81.72680497169495, 67.89032623171806, 65.16006633639336, 85.93756422400475, 81.86245769262314, 84.11038666963577, 80.03971070051193, 82.14352861046791, 83.60236153006554, 79.74303022027016, 77.00290605425835, 75.53559198975563, 75.59404045343399, 77.93431967496872, 71.1224327981472, 72.87062779068947, 74.62326854467392, 73.23443546891212, 74.07053500413895, 72.13362693786621, 71.97767570614815, 74.349614828825, 71.84122502803802, 72.23136529326439, 79.1094522178173, 66.49467632174492, 30.356510281562805, 38.19992780685425, 63.128338158130646, 46.81772477924824, 28.95515877753496, 25.283959172666073, 16.66310526430607, 7.1543957479298115, 1.9971027737483382, 0.21796322136651725, 0.06539306603372097, 0.13840407016687095, 0.1911688403924927, 0.050904718082165346, 0.052824598460574634, 0.09102218609768897, 0.01072194942025817, 0.7015399087686092, 2.285141092725098, 0.5988402070943266, 1.0259977891109884, 0.7418736163526773, 1.1768556316383183, 6.965782893821597, 10.467948094010353, 4.7081126645207405, 17.12144047021866, 13.95921215415001, 12.328403312712908, 0.4356869962066412, 0.22878630232298747, 0.07426140422467142, 0.06677208773908205, 0.22024516219971702, 0.027454374758235645, 1.5488359588198364, 22.53964763134718, 18.724021576344967, 19.559131264686584, 29.305190294981003, 27.023445032536983, 22.58696649223566, 31.34037058800459, 43.39229978621006, 31.707700677216053, 29.871867187321186, 53.69577370584011, 67.25614786148071, 65.48035115003586, 64.5373709499836, 66.43804416060448, 63.5429111123085, 67.9420718550682, 65.60075148940086, 67.08467066287994, 65.5857726931572, 66.83594360947609, 67.79977709054947, 69.78020042181015, 69.03229415416718, 66.1856997013092, 68.07234406471252, 70.90017512440681, 68.96931633353233, 67.28053495287895, 70.66653326153755, 71.34950861334801, 71.43907740712166, 66.03385224938393, 74.26816239953041, 55.2717125415802, 42.06850782036781, 52.62077338993549, 47.05880284309387, 41.766336634755135, 10.177843160927296, 8.151731081306934, 17.61314168572426, 32.389351800084114, 59.60398927330971, 68.03781151771545, 72.31179177761078, 64.5978257060051, 35.46481177210808, 3.1773047195747495, 0.024130907586368266, 0.03429008364037145, 0.0493426790490048, 0.03034653353097383, 0.10492873479961418, 0.04014794059912674, 0.07275629905052483, 0.049152655847137794, 0.034581825602799654, 0.03913319837010931, 0.09625605642213486, 0.08866536998539232, 0.05632902721117716, 0.0048010154750954825, 0.02861837958334945, 0.03653382613265421, 0.02506923829059815, 0.035841910721501336, 0.03598478899220936, 0.03764645764022134, 0.05681957940396387, 0.032681660377420485, 0.03534570707415696, 0.23864223127020523, 0.179679429566022, 0.1854131289292127, 0.18777403427520767, 0.14773193135624751, 0.15833937388379127, 0.15849896532017738, 0.14338815584778786, 0.11016564792953432, 0.15709063620306551, 0.17459703900385648, 0.16708638577256352, 0.16166523448191583, 0.2248916745884344, 0.12374476849799976, 0.16753394535044208, 0.1619130969629623, 0.15875377430347726, 0.21673423965694383, 0.1644732541171834, 0.16304402612149715, 0.12904386618174613, 0.18805312633048743, 0.13716005254536867, 0.36061849154066294, 0.2435991691891104, 0.5878617649432272, 8.37492635473609, 92.77451455593109, 110.96888065338135, 104.71908241510391, 116.58989623188972, 92.84838259220123, 76.59784778952599, 12.102822717279196, 0.4444778838660568, 0.35829461936373264, 3.9616918796673417, 5.203340090811253, 21.49591963738203, 94.10507395863533, 94.14403706789017, 93.80389451980591, 76.8185855448246, 74.17456582188606, 90.13592094182968, 82.6350474357605, 87.82493054866791, 84.20065462589264, 84.93168979883194, 84.34829950332642, 80.90091928839684, 76.78175792098045, 76.50102138519287, 77.38185212016106, 77.84569323062897, 72.36594647169113, 74.70628648996353, 74.81680735945702, 72.4187484383583, 74.18078228831291, 68.71575593948364, 72.3936165869236, 72.58401677012444, 71.04420259594917, 69.38622996211052, 82.89091810584068, 83.00231292843819, 47.00905591249466, 41.5523549169302, 69.20415133237839, 49.94678847491741, 37.51912973821163, 33.299197778105736, 24.034660309553146, 9.330392684787512, 3.328118626959622, 0.27412919502239674, 0.1676902119652368, 0.19446646969299763, 0.342409482691437, 0.23239288770128042, 0.2359250356676057, 0.2851761819329113, 0.09436441847356036, 0.6044142704922706, 7.42525708861649, 0.5038765934295952, 7.177920285612345, 1.325286473147571, 1.618498689495027, 9.676993936300278, 13.170053400099277, 15.52790192887187, 19.15890634059906, 25.69231566041708, 18.552578575909138, 1.4910949696786702, 0.38992231129668653, 0.2922804350964725, 0.18346971133723855, 0.686736200004816, 0.22540846170159057, 2.079550987109542, 29.62748520076275, 27.963782474398613, 28.340974934399128, 37.64907516539097, 34.02735270559788, 30.026243403553963, 33.884385377168655, 52.741033136844635, 38.105632066726685, 44.69647340476513, 63.078002259135246, 66.92575559020042, 66.11571505665779, 63.17742772400379, 65.68312346935272, 64.35295164585114, 69.0386626124382, 66.32901281118393, 66.33640721440315, 68.01441997289658, 66.28004863858223, 68.25997039675713, 68.47180142998695, 70.07019326090813, 67.43976920843124, 70.9434624016285, 73.90181645751, 72.8577084839344, 71.86754241585732, 73.36036071181297, 73.10386687517166, 75.39045497775078, 68.8768520951271, 80.35578534007072, 63.122858852148056, 54.425687938928604, 65.90411961078644, 61.8525680154562, 54.14959095418453, 12.930892333388329, 9.801388811320066, 19.110394343733788, 41.08031004667282, 72.20491871237755, 79.67649579048157, 85.57211503386497, 69.18654307723045, 33.69027279317379, 2.290881397202611, 0.15667319297790527, 0.13874706113711, 0.18767143978038803, 0.08431365349679254, 0.10235259178443812, 0.21491795196197927, 0.25052964105270803, 0.1784744340693578, 0.15792037214851007, 0.0809412899252493, 0.15224748436594382, 0.15708429826190695, 0.21162153978366405, 0.10674362725694664, 0.23790000937879086, 0.1774199164356105, 0.1680988830048591, 0.18066572898533195, 0.12159990234067664, 0.17840743297711015, 0.19208614976378158, 0.2129385550506413, 0.11827235706732608], [0.040588865376776084, 0.014427822097786702, 0.04978198965545744, 0.044103175823693164, 0.05820479433168657, 0.045082966607878916, 0.05038062452513259, 0.041828500616247766, 0.05611593063804321, 0.0150297446816694, 0.02120262292010011, 0.10030324003309943, 0.07000993704423308, 0.15848278650082648, 0.026189962918579113, 0.051421976459096186, 0.04784244236361701, 0.046447008062386885, 0.04262508482497651, 0.110188602557173, 0.03558037416951265, 0.05480699735926464, 0.03003704496222781, 0.01912802516017109, 0.04937669167702552, 0.05173692166863475, 0.052381484347279184, 1.0150106786750257, 40.577095448970795, 82.18640550971031, 80.79089239239693, 91.32747620344162, 69.79617476463318, 52.95395851135254, 22.501613572239876, 1.8264396814629436, 1.119193013291806, 5.579418735578656, 3.201731708832085, 17.49267105013132, 75.19056290388107, 72.20405995845795, 66.20417430996895, 45.84191054105759, 67.4060270190239, 84.77028965950012, 80.43070212006569, 81.72036811709404, 81.54975727200508, 81.43086925148964, 79.3065932393074, 81.22574865818024, 77.8941710293293, 78.70016098022461, 77.73996770381927, 80.62424093484879, 71.01182833313942, 76.72558173537254, 75.91718271374702, 75.03946781158447, 76.54125362634659, 74.1374722123146, 72.72413045167923, 75.87540775537491, 72.91605055332184, 72.4550212919712, 72.74915590882301, 71.5666289627552, 44.20447580516338, 35.08008621633053, 52.14063875377178, 30.13245340436697, 26.581154465675354, 18.78766056150198, 13.690212238579988, 4.340996788814664, 0.9976300550624728, 0.2209836436668411, 0.13832592201652005, 0.061117746226955205, 0.32379134267102927, 0.02861121785826981, 0.041553794653736986, 0.2820981392869726, 0.4238458222243935, 1.1720047169364989, 4.620367297902703, 0.09586423955624923, 0.45922744553536177, 1.1065263929776847, 1.7029794375412166, 5.001040371134877, 3.290999843738973, 4.072467098012567, 21.343260928988457, 5.866626324132085, 11.062773875892162, 0.575219071470201, 0.36403860489372164, 0.15207677555736154, 0.133141441619955, 0.11567963447305374, 0.1078261980728712, 1.5397398406639695, 21.12685304135084, 19.46700520813465, 21.958428919315338, 25.147151313722134, 28.296593315899372, 26.150398179888725, 15.586940310895443, 38.07493731379509, 32.43130534887314, 36.840406358242035, 58.17707844078541, 64.38491553068161, 64.13855195045471, 62.98615738749504, 68.30366045236588, 65.61997085809708, 62.905176132917404, 69.55256223678589, 68.14222231507301, 71.79387956857681, 68.66762012243271, 68.10417875647545, 70.46211943030357, 69.49163630604744, 68.08739125728607, 72.85432666540146, 69.64702516794205, 72.15584054589272, 71.53572142124176, 70.12715980410576, 66.84481993317604, 71.44075691699982, 66.22099980711937, 73.56940269470215, 54.63558487594128, 35.817824229598045, 38.44783030450344, 48.0641832947731, 38.951789662241936, 11.8378952331841, 18.148770444095135, 26.813840679824352, 37.94035993516445, 60.05313657224178, 84.15767133235931, 55.42292542755604, 27.158721573650837, 9.417046085000038, 0.1758874111692421, 0.16624817450065166, 0.0936207790800836, 0.05844822990184184, 0.11526176822371781, 0.05401928923674859, 0.12279389920877293, 0.12428706322680227, 0.06707371139782481, 0.03401419395231642, 0.03601221877033822, 0.056690790806896985, 0.047465516690863296, 0.03939603368053213, 0.07564496045233682, 0.05669848316756543, 0.08900499902665615, 0.07486035450710915, 0.01874099143606145, 0.07504425127990544, 0.04893060897302348, 0.031926291339914314, 0.05932347434281837, 0.07521363906562328, 0.033806674618972465, 0.0478744697466027, 0.06599428728804924, 0.10435918840812519, 0.16496253723744303, 0.0297547987793223, 0.026490699710848276, 0.01716517628665315, 0.04410432986333035, 0.03963142436987255, 0.08699470650753938, 0.08978712619864382, 0.04895774560282007, 0.04836146705201827, 0.10027261901996098, 0.016221908445004374, 0.030320005462272093, 0.049500737950438634, 0.09640852324082516, 0.09114840315305628, 0.08026589101064019, 0.028847141038568225, 0.02538890541472938, 0.09884892002446577, 0.0993350415956229, 0.10303608753019944, 0.3451471764128655, 1.4151644753292203, 52.9152537882328, 95.81030085682869, 93.21624845266342, 99.4511666893959, 78.5522349178791, 74.5043197274208, 34.09361734986305, 2.386277415789664, 3.80308601539582, 12.363441232591867, 4.4997703190892935, 24.449776634573936, 83.0612325668335, 80.8323785662651, 76.21039018034935, 59.25457902252674, 70.40468171238899, 87.73451060056686, 83.08649361133575, 86.7742945253849, 83.20218220353127, 83.97901251912117, 81.9367665052414, 82.86900848150253, 74.65997457504272, 78.19376215338707, 77.77586057782173, 81.94216221570969, 73.0884701013565, 76.68186128139496, 75.50106704235077, 77.05649837851524, 74.8860776424408, 74.86304327845573, 72.95724794268608, 78.60301539301872, 71.9369038939476, 73.87722417712212, 73.89194458723068, 71.71133279800415, 33.41158054769039, 35.3760789334774, 60.899191573262215, 35.17050616443157, 25.672364830970764, 26.971118040382862, 20.99722109735012, 8.522423040121794, 3.525132117792964, 0.06821395450970158, 0.01646787473873701, 0.052862306984025054, 0.3611989103956148, 0.06774279463570565, 0.04543718998320401, 0.12597970169736072, 0.2591577608836815, 1.3042543642222881, 5.408645924180746, 0.9656682482454926, 1.6688907542265952, 0.8434140833560377, 0.27042659057769924, 9.594017788767815, 9.883358012884855, 13.899378664791584, 22.15411651879549, 12.567691672593355, 5.461254101246595, 0.091435250651557, 0.09967649632017128, 0.060313926078379154, 0.06884005997562781, 0.15006785601144657, 0.2870019245892763, 2.042203741148114, 22.31371745467186, 14.101924896240234, 18.738865479826927, 28.085413947701454, 27.77756966650486, 25.19451007246971, 20.63132733106613, 41.66631080210209, 32.20536187291145, 32.26833589375019, 59.75989110767841, 63.62952746450901, 68.06159064173698, 61.38079673051834, 68.56679633259773, 63.97455275058746, 63.7760666012764, 66.2757320702076, 68.27510878443718, 68.60422432422638, 70.10544776916504, 67.27340653538704, 70.14009431004524, 70.09135812520981, 69.29208621382713, 69.94100019335747, 68.88797789812088, 70.39458185434341, 71.80515736341476, 70.9811943769455, 70.73381245136261, 70.16221672296524, 69.12130057811737, 73.72138693928719, 60.731890350580215, 39.86494906246662, 43.66308845579624, 52.471369206905365, 54.05799686908722, 18.106262125074863, 20.8572556078434, 31.155993081629276, 54.08836483955383, 68.35003316402435, 76.0640600323677, 76.46401897072792, 45.79584561288357, 14.660056047141552, 0.301829767995514, 0.08517450769431889, 0.024974441912490875, 0.03303475197753869, 0.06189886036736425, 0.0330158272117842, 0.10435691001475789, 0.027241129755566362, 0.0501762333442457, 0.17013037868309766, 0.10035657818662003, 0.026770418880914804, 0.041928902064682916, 0.09722222137497738, 0.032391933345934376, 0.04800753311428707, 0.010650681906554382, 0.049418860508012585, 0.04871195000305306, 0.0705112429568544, 0.07039310046820901, 0.059657926904037595, 0.016322413794114254, 0.04865301976678893, 0.1448873386834748, 0.20306799095124006, 0.24122037808410823, 0.1668938429793343, 0.32164030184503645, 0.25567358534317464, 0.15275172918336466, 0.1916745546623133, 0.1262866985052824, 0.12274842039914802, 0.2295181341469288, 0.17534303100546822, 0.10094225886859931, 0.26437844324391335, 0.15516305604251102, 0.09653319662902504, 0.1330361160216853, 0.11712562758475542, 0.21775779488962144, 0.2304656192427501, 0.21468711434863508, 0.1286815942148678, 0.10248021149891429, 0.15319998638005927, 0.22256824770011008, 0.10940369975287467, 0.29994590033311397, 1.1418964387848973, 51.247895658016205, 111.11005827784538, 107.03787758946419, 118.8112798333168, 88.24152499437332, 84.97142806649208, 47.73390881717205, 2.4135884502902627, 8.767685629427433, 22.24721722304821, 10.782647207379341, 34.07233469188213, 96.46086394786835, 92.20939368009567, 87.49492585659027, 70.18308520317078, 78.68211194872856, 89.4686995446682, 85.15967756509781, 86.85141518712044, 85.18369227647781, 84.33046326041222, 83.40369299054146, 83.14826309680939, 76.1465536057949, 79.37860697507858, 79.79140922427177, 81.73810556530952, 71.67423158884048, 78.96403402090073, 75.13070851564407, 78.5249599814415, 73.80702674388885, 73.41174155473709, 71.51274025440216, 79.44969356060028, 72.66423046588898, 72.43987530469894, 73.89415606856346, 81.50116547942162, 48.148189187049866, 41.23002581298351, 63.96221861243248, 38.743910416960716, 36.079846769571304, 30.468562468886375, 24.530408307909966, 12.970509007573128, 5.597428819164634, 0.4350475320825353, 0.19854198850225657, 0.11705223660101183, 0.41972437931690365, 0.06028507137671113, 0.11840385079267435, 0.6461984908673912, 0.8868986531160772, 2.5279763247817755, 12.614422515034676, 1.1172799346968532, 9.498166982084513, 3.547749691642821, 2.677820809185505, 14.896467961370945, 9.61292177438736, 13.300401605665684, 34.50493387877941, 20.367876067757607, 20.620670802891254, 2.3654754320159554, 0.38282212510239333, 0.2920085418736562, 0.4057232290506363, 0.3197556623490527, 0.22966525750234723, 3.3145011076703668, 36.80244639515877, 24.655735082924366, 30.1764702424407, 33.94563049077988, 37.80929356813431, 32.71469794213772, 24.886802583932877, 47.60033838450909, 38.659494146704674, 46.55934624373913, 65.8262237906456, 63.84173467755318, 67.43059650063515, 62.0768091827631, 69.66098561882973, 66.83161184191704, 64.29553672671318, 67.65223860740662, 69.21292126178741, 66.7146085202694, 68.15204098820686, 70.87192744016647, 71.6881388425827, 72.0176799595356, 69.8022848367691, 73.69494035840034, 73.1166721880436, 71.88735455274582, 73.83581399917603, 75.42706221342087, 74.13419678807259, 76.78491175174713, 72.80000478029251, 78.39270427823067, 70.57296708226204, 48.48570227622986, 53.88843476772308, 65.55397599935532, 64.12956923246384, 22.924247793853283, 23.71364403516054, 38.76139707863331, 63.6095405369997, 77.3521301150322, 90.27325317263603, 78.90170216560364, 45.87988190352917, 13.27590337023139, 0.25379716884344816, 0.2875835308805108, 0.17126712627941743, 0.10875431311433204, 0.23628926690435037, 0.19966585241490975, 0.29526763886678964, 0.12375716978567652, 0.21250785706797615, 0.14694874291308224, 0.21305130212567747, 0.16517838346771896, 0.16834952111821622, 0.1633457388379611, 0.22452987759606913, 0.18582058284664527, 0.14050710888113827, 0.2273593601421453, 0.11902097627171315, 0.19941027159802616, 0.202800476399716, 0.15295479563064873, 0.13901874655857682, 0.14091469638515264], [0.02862669905880466, 0.046135922020766884, 0.04960384081641678, 0.09641835669754073, 0.05407472395745572, 0.01684356844634749, 0.03507615903799888, 0.03511587136017624, 0.11823366890894249, 0.05639032860926818, 0.0637803717108909, 0.12734437768813223, 0.06416740172426216, 0.04463985620532185, 0.07542242005001754, 0.12363017347524874, 0.05573325703153387, 0.06914188401424326, 0.09008866822114214, 0.0029015295467615942, 0.05528703331947327, 0.027488033010740764, 0.0942019178182818, 0.12528720370028168, 0.045834261254640296, 0.05871968896826729, 0.10023798298789188, 0.36915028060320765, 10.061277765780687, 55.546851977705956, 75.83124652504921, 83.24110731482506, 89.39184486865997, 59.26968701183796, 38.42010319232941, 15.276956744492054, 8.605221547186375, 2.9703884851187468, 1.9773269724100828, 24.38534539192915, 76.26091226935387, 63.082588613033295, 58.091822415590286, 49.63354088366032, 73.59070435166359, 82.92336076498032, 85.61283364892006, 81.30248174071312, 84.0939411520958, 81.94921463727951, 84.17288571596146, 83.54995474219322, 80.756656229496, 80.26594296097755, 77.86279991269112, 76.29656955599785, 71.41554147005081, 76.38567477464676, 75.76216623187065, 76.06083020567894, 77.39755287766457, 77.45094001293182, 74.50438052415848, 74.64482098817825, 71.07599169015884, 71.06886327266693, 75.7496877014637, 68.2154443860054, 43.62156808376312, 43.63352604210377, 40.59456691145897, 24.220227152109146, 29.744707010686398, 21.91766280680895, 13.332024458795786, 8.137848526239395, 2.771804016083479, 0.11829206108814105, 0.10185082574025728, 0.22085866599809378, 0.02780175182124367, 0.05255507268884685, 0.20415412407601252, 0.2788524009520188, 0.365772558725439, 0.6432140478864312, 2.3241049144417048, 0.880240163533017, 2.286779754795134, 1.5881006768904626, 2.732283999212086, 6.445391792804003, 8.04436119273305, 19.441033601760864, 12.328781392425299, 1.994184055365622, 2.9602138185873628, 0.28511203068774194, 0.09610842098481953, 0.08054963633185253, 0.029698070866288617, 0.08979988371720538, 0.2118844530195929, 0.8473057276569307, 14.471425618976355, 14.681389052420855, 22.22042866051197, 25.640754327178, 26.62900909781456, 26.60342127084732, 18.326209522783756, 27.07644458860159, 41.07544630765915, 32.93053016066551, 56.376184076070786, 66.68148949742317, 64.37164664268494, 63.880560994148254, 65.16143426299095, 69.19658973813057, 64.33581456542015, 67.49044328927994, 70.24421632289886, 71.87913939356804, 63.00797961652279, 69.86544504761696, 67.7239939570427, 69.13301154971123, 71.35808855295181, 72.37153217196465, 67.72825732827187, 69.87617567181587, 72.4361515045166, 68.1964910030365, 67.77816385030746, 72.20337599515915, 69.33745577931404, 75.54026573896408, 49.897345528006554, 32.56791181862354, 36.78637705743313, 43.45646694302559, 40.68114906549454, 26.211738288402557, 38.43606233596802, 40.69791756570339, 46.74414932727814, 65.9724323451519, 66.8191409111023, 26.48783527314663, 16.044008284807205, 1.7283960361965, 0.14062775240745395, 0.14385085523827001, 0.04400806217745412, 0.04367647801700514, 0.04400783953315113, 0.05678973764588591, 0.10856948123546317, 0.18345311691518873, 0.009578135650372133, 0.08169252148945816, 0.05628286562568974, 0.07336374692386016, 0.022912202766747214, 0.02650138849276118, 0.08671669798786752, 0.10499002135475166, 0.1488391266320832, 0.08472913745208643, 0.033200250909430906, 0.05696509229892399, 0.02493680945917731, 0.05638007583911531, 0.0659252230252605, 0.022927062418602873, 0.0439189191092737, 0.03455824014963582, 0.01529635659608175, 0.04685302221332677, 0.06761400974937715, 0.04510377642873209, 0.06776497000828385, 0.07272670962265693, 0.023293991362152155, 0.03927906749595422, 0.014051715570531087, 0.0682875384518411, 0.03932115469069686, 0.053824928181711584, 0.11038251832360402, 0.05772604970843531, 0.08440803983830847, 0.05997010390274227, 0.08056902122916654, 0.13227773015387356, 0.04600538195518311, 0.07364392251474783, 0.04895135200058576, 0.057685209321789443, 0.03480445135210175, 0.06184492478496395, 0.1492761477129534, 0.7124870619736612, 20.648652501404285, 78.26806336641312, 91.27151280641556, 96.64564043283463, 92.08520114421844, 75.46065241098404, 59.878220558166504, 22.171722874045372, 15.887360740453005, 3.3635768992826343, 2.364758220501244, 35.08585050702095, 87.25172370672226, 75.86635664105415, 64.93566557765007, 60.436045825481415, 77.80809044837952, 87.97648161649704, 87.4968409538269, 85.89984744787216, 88.60246762633324, 85.57801231741905, 83.29303532838821, 84.3276210129261, 79.33873951435089, 79.6415376663208, 77.46338054537773, 78.33105638623238, 72.16202661395073, 77.19814717769623, 75.4274345934391, 78.06395351886749, 79.47930917143822, 77.13339865207672, 74.8165337741375, 77.50526949763298, 70.94511151313782, 76.18574470281601, 74.2849650979042, 72.91537418961525, 38.804680556058884, 41.06312736868858, 48.70725318789482, 27.843224443495274, 29.362595714628696, 26.64701633155346, 21.397307328879833, 12.769984267652035, 8.073418233543634, 0.469167860574089, 0.0689492818491999, 0.22996198298642412, 0.040888533476390876, 0.029983387685206253, 0.1335794126498513, 0.1410527210100554, 0.18625016760779545, 0.14577332942280918, 5.533409854397178, 3.509281030856073, 2.4097485188394785, 1.3831052393652499, 1.8881177343428135, 11.078842263668776, 11.187696922570467, 25.85267085582018, 2.4571056151762605, 6.626227414235473, 13.002546038478613, 2.057614764198661, 0.09628022817196324, 0.13866906141629443, 0.06277694352320395, 0.03496507808449678, 0.32050920941401273, 0.5677494441624731, 14.417816195636988, 10.63961623236537, 18.312034383416176, 25.539949536323547, 24.343469738960266, 27.618472203612328, 20.37345226854086, 32.879415303468704, 42.0502308011055, 30.1608207821846, 57.295761331915855, 66.01840987801552, 64.77554216980934, 65.73981642723083, 66.82350307703018, 66.47757723927498, 63.08450371026993, 66.35576337575912, 69.69047963619232, 71.08305931091309, 65.60452848672867, 69.14803594350815, 70.79030781984329, 68.60952123999596, 68.57746616005898, 70.05725875496864, 67.19668865203857, 68.78837004303932, 73.6230406165123, 72.10744634270668, 68.17733243107796, 72.64502629637718, 67.25591987371445, 75.43625771999359, 55.28499282896519, 36.41702547669411, 42.0293965190649, 53.90737295150757, 50.77061466872692, 29.217253513634205, 42.508254423737526, 54.36818562448025, 69.49463054537773, 71.31831228733063, 79.81787100434303, 53.817887753248215, 27.79776368290186, 4.452820988371968, 0.07698148678173311, 0.05177618128072936, 0.04170353407971561, 0.03806162618275266, 0.1265708965365775, 0.07338970724958926, 0.10748734828666784, 0.06083470594603568, 0.03299146621429827, 0.06319738502497785, 0.09417402048711665, 0.029173353905207478, 0.02031328509474406, 0.057046023503062315, 0.03782327061344404, 0.0439029184053652, 0.0981935442541726, 0.048212172914645635, 0.004539749807008775, 0.025929877265298273, 0.019598049548221752, 0.011972310549026588, 0.03318865114124492, 0.026326514380343724, 0.18983529007527977, 0.15832539182156324, 0.1483357575489208, 0.21252497099339962, 0.20382674789289013, 0.2657755510881543, 0.10292606413713656, 0.15508688200498, 0.20778653619345278, 0.1338894819491543, 0.19341542531037703, 0.23343101871432737, 0.10867809454794042, 0.1237642350315582, 0.23243986564921215, 0.1563371781958267, 0.16934153507463634, 0.1774100013426505, 0.1932669512461871, 0.2205819933442399, 0.11302373284706846, 0.14355846389662474, 0.13395520654739812, 0.17428861727239564, 0.1616915361955762, 0.19210972037399188, 0.1597789177321829, 0.7040385715663433, 16.017041131854057, 90.59250444173813, 96.79121062159538, 107.28649824857712, 107.5320714712143, 86.12204432487488, 68.48716780543327, 43.63591231405735, 29.991513267159462, 8.047514073550701, 4.079160913825035, 43.50989207625389, 98.15415188670158, 87.40734055638313, 77.95232310891151, 71.0056346654892, 87.55768328905106, 89.17072713375092, 91.66228383779526, 86.52688980102539, 92.07172706723213, 86.51253417134285, 85.55744782090187, 84.7847592830658, 80.19924134016037, 81.02449625730515, 78.22598442435265, 79.42451611161232, 73.09958830475807, 77.10830479860306, 75.90652048587799, 76.61090388894081, 79.23821970820427, 76.10490784049034, 74.21458527445793, 75.9342285990715, 70.2782092988491, 74.08574178814888, 74.24325853586197, 79.73502025008202, 47.71156221628189, 50.20516321063042, 53.68884667754173, 34.21104244887829, 38.467247262597084, 31.882227212190628, 25.025880821049213, 17.479255869984627, 7.437239745631814, 0.3419723577098921, 0.1874377077911049, 0.5550564033910632, 0.15962710400344804, 0.2534812217345461, 0.2984826819738373, 0.8231836720369756, 0.5763748625759035, 0.992725765099749, 10.00491539016366, 7.776181558147073, 12.018439695239067, 2.826524404808879, 2.6127564255148172, 15.651986170560122, 10.964213814586401, 33.79752963781357, 22.30768907815218, 14.3361053802073, 12.90339320898056, 3.04008933249861, 0.20088981720618904, 0.22737329767551273, 0.1696468546288088, 0.24840264581143856, 0.5402900988701731, 1.2277364451438189, 31.077804677188396, 19.71788864582777, 30.90133834630251, 31.52027953416109, 32.74570807814598, 34.62679713964462, 24.87180858850479, 35.81302888691425, 49.848871529102325, 41.78866423666477, 64.07266348600388, 64.30883601307869, 65.30559092760086, 63.38077761232853, 67.69377037882805, 69.0636956691742, 65.15409305691719, 69.28988993167877, 69.30138811469078, 68.58781680464745, 66.16856262087822, 70.05339056253433, 71.44659340381622, 70.72337061166763, 69.56305727362633, 74.1963766515255, 70.84371775388718, 71.08386486768723, 73.46661821007729, 74.73021760582924, 73.13849821686745, 77.48279750347137, 72.65156954526901, 82.20814034342766, 66.96986362338066, 45.4653013497591, 53.877863734960556, 62.7117171138525, 62.101253271102905, 35.74365980923176, 46.84857152402401, 64.03797134757042, 78.7641191482544, 82.72720009088516, 92.70495548844337, 56.642469987273216, 25.82661185413599, 3.142331396229565, 0.1468054490396753, 0.3134637343464419, 0.1345425719046034, 0.15386020095320418, 0.22366398421581835, 0.11226667542359792, 0.15735755703644827, 0.18868092389311641, 0.16539906850084662, 0.13649050175445154, 0.28799304796848446, 0.15377613046439365, 0.06336997146718204, 0.14129715476883575, 0.18243033351609483, 0.1791972413775511, 0.28800159750971943, 0.16020192706491798, 0.1682229107245803, 0.09915945687680505, 0.16707305680029094, 0.10143576480913907, 0.14175035466905683, 0.14088456518948078], [0.034763796502375044, 0.05936029971053358, 0.08475185459246859, 0.07370020699454471, 0.05101413291413337, 0.09363479824969545, 0.07730717086815275, 0.04938916717946995, 0.04983854872989468, 0.0801068042346742, 0.06710918605676852, 0.1427020996925421, 0.03401385998586193, 0.043852890230482444, 0.075521556136664, 0.012368161915219389, 0.08747209300054237, 0.04462189994228538, 0.06383577303495258, 0.03555515970219858, 0.07330464970436879, 0.046549910548492335, 0.020594688940036576, 0.03356366949446965, 0.036797232896788046, 0.06637299782596529, 0.0782201238325797, 0.1554191712057218, 1.5118423313833773, 43.08561064302921, 62.22736470401287, 81.20655208826065, 101.49475023150444, 70.6599672138691, 59.71466213464737, 29.804696291685104, 7.270636735484004, 1.32956029381603, 3.5306325601413846, 24.824311137199402, 70.6325326859951, 56.432728841900826, 54.10106375813484, 47.853013426065445, 76.02264985442162, 83.03877577185631, 89.75540935993195, 83.78059476613998, 83.34630087018013, 81.92280605435371, 83.38574275374413, 82.66134962439537, 84.02543842792511, 83.59113693237305, 86.90547868609428, 77.6576641201973, 80.19920334219933, 73.90399754047394, 76.77443191409111, 78.07756438851357, 75.19126206636429, 74.53506007790565, 79.74375218153, 73.91256988048553, 73.82570654153824, 72.22539961338043, 70.23912459611893, 67.50708639621735, 42.38751210272312, 42.34458960592747, 31.567222215235233, 27.749164290726185, 28.567703068256378, 27.75741934776306, 17.978338189423084, 10.559585876762867, 3.6467384174466133, 0.6816390110179782, 0.053763511750730686, 0.13337658368982375, 0.3480357042280957, 0.5147351638879627, 0.542323108529672, 0.1850197312887758, 0.2573006699094549, 0.026903541620413307, 1.807197395246476, 3.130526142194867, 1.3376972009427845, 0.7238416245672852, 1.1155796446837485, 2.3879479011520743, 6.760355941951275, 21.153033636510372, 1.4582901424728334, 0.5442218785174191, 8.842830397188663, 0.8067698590457439, 0.3472564194817096, 0.10813160668476485, 0.14240289543522522, 0.2830201241886243, 0.24764489819062874, 0.8540447254199535, 7.765977205708623, 7.7869307063519955, 18.42389278113842, 23.989828415215015, 28.882214091718197, 25.86711198091507, 19.486382268369198, 20.46337254345417, 41.65913298726082, 38.14947031438351, 49.773133993148804, 69.45819810032845, 67.33312413096428, 67.86726146936417, 66.10873863101006, 69.99776154756546, 63.01292695105076, 68.09251338243484, 69.68858733773232, 70.76318487524986, 66.57720029354095, 71.53641298413277, 69.88538637757301, 71.96214213967323, 68.98923486471176, 69.75943073630333, 67.62093588709831, 73.5175658762455, 68.44426050782204, 65.77118754386902, 68.52432981133461, 72.2199659049511, 69.54997077584267, 71.72692716121674, 39.66595374047756, 40.704616606235504, 39.905143305659294, 54.07940112054348, 47.710973247885704, 43.49262200295925, 47.561432272195816, 38.19181904196739, 43.83149541914463, 49.723801240324974, 18.108999878168106, 9.658677019178867, 8.549185954034328, 0.19382428930839524, 0.06834007508587092, 0.1116473160800524, 0.11113962769741192, 0.01793186122085899, 0.07646365324035287, 0.04939572034345474, 0.06322942354017869, 0.03644679076387547, 0.08486512859235518, 0.10590396879706532, 0.011662814558803802, 0.08565676267608069, 0.04032171818835195, 0.06145769439172, 0.04833194812817965, 0.10801969823660329, 0.07522922416683286, 0.052740090104634874, 0.015170936421782244, 0.05563312646700069, 0.03519193778629415, 0.02524424227885902, 0.04339577550126705, 0.07758333144010976, 0.04449832493264694, 0.052004944591317326, 0.04607956332620233, 0.06526729426695965, 0.014186798507580534, 0.03766012428968679, 0.05185796595469583, 0.04111449889023788, 0.0391119989217259, 0.037748399045085534, 0.06251998973311856, 0.0443603411258664, 0.03115482883004006, 0.045260002225404605, 0.05671735227224417, 0.033761366503313184, 0.010042923258879455, 0.032335277792299166, 0.0783356762258336, 0.022698516186210327, 0.07771834294544533, 0.004100589021618362, 0.0828598826774396, 0.021862345820409246, 0.013989541221235413, 0.04444695347046945, 0.11227908413275145, 0.44963631487917155, 2.9121159994974732, 58.54343198239803, 79.49822455644608, 89.52878192067146, 105.72012349963188, 74.56525325775146, 74.47692319750786, 51.54506631195545, 7.8440748900175095, 1.8647405575029552, 5.771567299962044, 36.73907719552517, 82.62718185782433, 66.54907420277596, 59.306111857295036, 57.22929149866104, 77.85741180181503, 87.47674003243446, 89.50412884354591, 88.7509636580944, 87.71515443921089, 86.84564709663391, 86.92338332533836, 84.52530920505524, 82.95685976743698, 84.23502758145332, 84.24115285277367, 78.6871200799942, 79.11667943000793, 78.96151095628738, 78.84889259934425, 79.85836163163185, 73.50670605897903, 78.31819027662277, 81.04858696460724, 76.44114419817924, 72.74273425340652, 75.1599745452404, 68.65888819098473, 71.97645217180252, 37.4135448038578, 45.46694666147232, 38.94556179642677, 29.380329363048077, 30.3124725446105, 30.404393412172794, 25.935227125883102, 14.798668809235096, 11.01894797757268, 1.0217550792731345, 0.2057926674024202, 0.13384323130594566, 0.46385129273403436, 0.7556580891832709, 0.6868787517305464, 0.25869448261801153, 0.45367647777311504, 0.26130892045330256, 2.80939444899559, 5.987606607377529, 5.458247512578964, 0.7081510196439922, 1.4323065429925919, 6.595405843108892, 7.071651387959719, 23.464358411729336, 0.938809864455834, 2.8770635928958654, 11.432691626250744, 0.5682883621193469, 0.285300892428495, 0.04062560910824686, 0.07876240371842869, 0.15444254939211532, 0.008141937032632995, 0.32308971625752747, 7.215714957565069, 6.947186216711998, 14.554525259882212, 25.27523674070835, 28.2052044197917, 29.321588315069675, 27.37926173955202, 26.723814010620117, 41.749169155955315, 37.33843423426151, 53.09830516576767, 68.94780188798904, 69.05078396201134, 69.30777937173843, 66.04131504893303, 68.34250956773758, 64.06322479248047, 67.55451545119286, 67.97047913074493, 73.34183290600777, 67.01334848999977, 72.85206958651543, 70.54075241088867, 68.38395774364471, 70.19972071051598, 69.71830174326897, 69.13465306162834, 74.5128844678402, 75.29332458972931, 69.82640594244003, 67.37826570868492, 73.16755905747414, 72.68882274627686, 71.00395515561104, 46.352595537900925, 46.245749071240425, 49.52677421271801, 63.3189245313406, 51.83713763952255, 46.355145201087, 65.82899764180183, 69.04709815979004, 67.21466168761253, 70.90956822037697, 53.3113369345665, 34.41583625972271, 13.368342909961939, 0.6725682446267456, 0.05811165850900579, 0.25259343499783427, 0.15812168712727726, 0.07950927145429887, 0.015604808941134252, 0.08959404163761064, 0.0956408011552412, 0.014098007031861925, 0.08157492076861672, 0.1233366911765188, 0.029658801977348048, 0.056014857545960695, 0.06874618571600877, 0.03482763233478181, 0.09556627468555234, 0.07457042709575035, 0.020055943532497622, 0.07824714542948641, 0.02275167622428853, 0.02663612725882558, 0.08321141576743685, 0.04868252384767402, 0.05034245958086103, 0.050505405524745584, 0.10365808891947381, 0.19545086921425536, 0.2388603039435111, 0.19661138037918136, 0.12172912509413436, 0.20075768523383886, 0.11699538066750392, 0.17502080532722175, 0.09599673518096097, 0.20690100558567792, 0.3194078919477761, 0.329544679261744, 0.13579203689005226, 0.15283582935808226, 0.18640615220647305, 0.17963599908398464, 0.2204367847298272, 0.11218154366360977, 0.18161468353355303, 0.17116031638579443, 0.15569127222988755, 0.14032267034053802, 0.22648947400739416, 0.18684064998524264, 0.11593262519454584, 0.15140116884140298, 0.33364768722094595, 0.4650948947528377, 2.172313746996224, 62.531606778502464, 88.06899905204773, 98.75226259231567, 128.17955553531647, 88.50815668702126, 83.45816686749458, 69.86892566084862, 17.066884897649288, 2.7525946218520403, 6.43542492762208, 49.63051624596119, 96.28187835216522, 80.42594477534294, 72.36099913716316, 67.02970281243324, 86.56572371721268, 90.59001937508583, 95.39152532815933, 93.74153226613998, 88.76904308795929, 86.59710243344307, 88.71000185608864, 86.31178334355354, 83.30243602395058, 84.237489849329, 86.52546867728233, 79.20931845903397, 82.02238351106644, 75.28505623340607, 76.92006289958954, 78.92633244395256, 74.58875879645348, 76.41645312309265, 79.55197647213936, 75.83383798599243, 72.24434539675713, 74.45427641272545, 66.93881928920746, 76.13662853837013, 44.576707631349564, 54.434598460793495, 43.36132004857063, 34.38371278345585, 38.325689658522606, 37.10555613040924, 26.730853132903576, 24.856734797358513, 20.642848312854767, 1.1881160899065435, 0.44743445178028196, 0.2571170328883454, 0.5674692091997713, 0.8529244980309159, 0.8063482004217803, 0.4213393817190081, 0.43076436035335064, 0.29797454830259085, 7.6492617186158895, 12.290621940046549, 13.276943564414978, 4.436731701716781, 1.644667291548103, 13.218173068016768, 12.239708472043276, 40.20831383764744, 1.7285551526583731, 1.6234808159060776, 17.770656533539295, 3.42937583103776, 0.7811386906541884, 0.3342206252273172, 0.24846960237482563, 0.5446185416076332, 0.4926181834889576, 1.332184646744281, 17.649102956056595, 15.3853221796453, 28.58314923942089, 31.449432335793972, 36.57884359359741, 34.05354470014572, 31.921938881278038, 27.85873331129551, 48.9246167242527, 46.41861319541931, 58.860543966293335, 68.68311569094658, 71.69635400176048, 67.64000326395035, 68.77571672201157, 69.96633723378181, 65.5326971411705, 66.32120802998543, 67.60712742805481, 71.19121670722961, 68.76839071512222, 72.41472825407982, 73.91556411981583, 70.6523448228836, 73.3300307393074, 72.27409780025482, 70.82755342125893, 73.57830181717873, 76.62639185786247, 76.22536897659302, 73.96131366491318, 75.24445921182632, 79.0537092089653, 78.82819131016731, 56.49774335324764, 53.92947256565094, 59.874207973480225, 72.70706936717033, 63.15665043890476, 53.49340416491032, 74.52945917844772, 72.88090243935585, 72.75623872876167, 81.3314437866211, 54.46585938334465, 35.80575227737427, 11.089508291333914, 0.7129930285736918, 0.205051425145939, 0.17861443280708045, 0.26411907747387886, 0.12069552118191496, 0.20881335687590763, 0.303038964048028, 0.17272590659558773, 0.08611463068518788, 0.19741291471291333, 0.3487977711483836, 0.11515075035276823, 0.23379921301966533, 0.08672052746987902, 0.08867300668498501, 0.1662714927806519, 0.14083844813285396, 0.17319129256065935, 0.26174652040936053, 0.17184120719321072, 0.10294063249602914, 0.09025370702147484, 0.18777698802296072, 0.29723151004873216, 0.16935011430177838], [0.019312331969558727, 0.040374818854616024, 0.09230060226400383, 0.05397031862230506, 0.05217756443016697, 0.07232777556055225, 0.0792166574683506, 0.10001056667533703, 0.01809914316254435, 0.13433398387860507, 0.062205682770581916, 0.03035999423445901, 0.10306694603059441, 0.05107341567054391, 0.014284879816841567, 0.19282197434222326, 0.06038376588548999, 0.08722320635570213, 0.05172307319298852, 0.03081199185544392, 0.02189357725001173, 0.024308080501214135, 0.14376831357367337, 0.13199037057347596, 0.03865659855364356, 0.07373817526968196, 0.0418029299180489, 0.20977865351596847, 0.08153416943969205, 17.612290531396866, 67.92333126068115, 86.16275534033775, 114.30453926324844, 84.40512165427208, 62.18319967389107, 44.95298244059086, 23.830113485455513, 11.685615554451942, 6.891769990324974, 29.64171353727579, 69.60146561264992, 64.08001229166985, 47.95820698142052, 51.396897062659264, 71.12445428967476, 88.37738290429115, 81.77540436387062, 89.83781933784485, 85.51446452736855, 81.96720287203789, 86.72902375459671, 87.38958790898323, 83.97227168083191, 84.06471312046051, 81.0785673558712, 77.16448858380318, 81.09426811337471, 74.90687772631645, 81.38412415981293, 75.41750952601433, 77.14646235108376, 76.07431948184967, 78.40555518865585, 74.71546679735184, 77.04302430152893, 75.88534042239189, 75.250523686409, 66.87062814831734, 41.72434888780117, 42.04977102577686, 24.198581613600254, 26.074064075946808, 26.661934331059456, 30.750488340854645, 20.324149914085865, 8.516613151878119, 3.314388538710773, 1.1484780418686569, 0.12669701711274683, 0.25299152301158756, 0.12280356939299963, 0.09515224533970468, 0.3421424579573795, 0.08751313376706094, 1.270873392932117, 0.39186086039990187, 0.9636865952052176, 2.3273390159010887, 0.49321721540763974, 0.23941773106344044, 0.5475103645585477, 3.86615835595876, 1.352630399633199, 10.244447886943817, 3.77435480710119, 1.2406182289123535, 7.425526874139905, 0.2363120805239305, 0.13434339431114495, 0.03979612549301237, 0.04900340623862576, 0.07703934461460449, 0.1625849335687235, 0.33691272139549255, 3.8114602910354733, 4.062504982575774, 13.947595227509737, 26.18785846978426, 26.2309405580163, 25.088628754019737, 26.625078208744526, 20.647280775010586, 34.26537573337555, 36.976974830031395, 49.776736199855804, 73.18816915154457, 67.49339953064919, 68.23193550109863, 65.11188492178917, 67.34868049621582, 65.6272740662098, 69.22571137547493, 68.20513173937798, 70.60197472572327, 66.7335695028305, 68.64070996642113, 74.30388048291206, 66.7181271314621, 67.84948602318764, 68.00172865390778, 69.11264464259148, 71.24176919460297, 66.15600049495697, 64.23975571990013, 71.34938701987267, 66.54266774654388, 70.70414364337921, 66.20398432016373, 37.129707634449005, 41.73685781657696, 46.33339896798134, 55.157547667622566, 49.391102492809296, 44.77778144180775, 24.868941642343998, 26.574233137071133, 28.6428402364254, 15.925414748489857, 5.7485543098300695, 13.965453319251537, 2.5224400218576193, 0.19473123829811811, 0.07967243262100965, 0.05602292098046746, 0.0978151528397575, 0.01925542779645184, 0.15194134844932705, 0.029219587850093376, 0.018358007982897107, 0.0652173328853678, 0.16267244762275368, 0.016064211340562906, 0.056822993283276446, 0.06245390890398994, 0.0693038354802411, 0.05572554611717351, 0.11041365141863935, 0.04883821900875773, 0.053522406524280086, 0.024963747564470395, 0.0829616459668614, 0.07923254685010761, 0.029703050677198917, 0.04752112210553605, 0.08283314309665002, 0.06603004396311007, 0.15256614773534238, 0.08633562742033973, 0.13281022111186758, 0.09008330991491675, 0.03288950625574216, 0.09805702618905343, 0.03818404715275392, 0.13642402016557753, 0.03818982106167823, 0.10814037144882604, 0.08938194325310178, 0.048006779834395275, 0.030597195764130447, 0.09606430030544288, 0.03463575747446157, 0.07569984969450161, 0.06846273725386709, 0.1093095880059991, 0.03207554836990312, 0.012748312219628133, 0.01704667756712297, 0.06677503406535834, 0.08116308817989193, 0.04246019816491753, 0.039884815851110034, 0.05831670649058651, 0.04531037178821862, 0.4152641608379781, 0.1602765722782351, 27.30030007660389, 80.97733318805695, 96.40195950865746, 115.86375519633293, 92.55963608622551, 82.02703446149826, 65.20379438996315, 31.73711869865656, 12.951984051615, 10.040284842252731, 33.79250630736351, 86.54045507311821, 78.68389785289764, 56.704201474785805, 57.18148626387119, 77.93924421072006, 86.93575546145439, 84.48596611618996, 89.08402338624, 90.71574702858925, 88.11265870928764, 89.88714829087257, 87.0458659529686, 86.10158622264862, 85.61933130025864, 81.77574634552002, 77.0193363726139, 81.3098381459713, 78.40381488204002, 81.71428844332695, 78.23959529399872, 78.7858159840107, 78.43476802110672, 78.35257843136787, 76.20868787169456, 77.44241327047348, 79.50083121657372, 75.0351132452488, 71.23511955142021, 39.2192193120718, 43.615936785936356, 27.942610010504723, 32.83467270433903, 28.682377114892006, 26.592234671115875, 25.99600486457348, 13.729626573622227, 7.48231197707355, 1.4889777707867324, 0.2891682833433151, 0.008539338559785392, 0.5089722387492657, 0.5026322195772082, 0.12043130918755196, 0.3181497735204175, 3.0521565349772573, 0.08699209414771758, 0.9662964614108205, 2.144429418258369, 3.437378676608205, 0.3374320169677958, 0.8155760646332055, 5.832828087732196, 5.681754369288683, 11.370099484920502, 3.397956029511988, 3.5056600626558065, 6.089846296235919, 0.42211661813780665, 0.04366418805147987, 0.06750206419383176, 0.017782646864361595, 0.002471039365445904, 0.13435201806714758, 0.9320864221081138, 2.3004623455926776, 4.52502328902483, 14.701173640787601, 29.504007026553154, 24.451059065759182, 28.969535306096077, 29.566488973796368, 22.958257868885994, 37.427463456988335, 39.95912320911884, 54.33826602995396, 72.90562391281128, 68.28351393342018, 69.01403993368149, 65.2596665918827, 68.27216774225235, 66.02597147226334, 67.67942994832993, 72.85283714532852, 69.86441150307655, 67.43691176176071, 71.69213622808456, 72.6386046409607, 67.15845510363579, 68.36122736334801, 71.5853163599968, 71.62608057260513, 76.80903285741806, 72.54858747124672, 63.803280740976334, 72.62782081961632, 73.35641652345657, 72.31434524059296, 67.68931701779366, 47.364922016859055, 51.19076192378998, 59.119317680597305, 60.13537555932999, 54.534620493650436, 62.36068814992905, 58.47181722521782, 55.27550853788853, 48.41802030801773, 41.595767587423325, 26.8646477535367, 20.79597819596529, 6.089546587318182, 0.24682369694346562, 0.07953499429277144, 0.07659732887987047, 0.12771977082593367, 0.14785269362619147, 0.14143690117634833, 0.04303075016650837, 0.014143091575533617, 0.12332103186054155, 0.08645513546071015, 0.10841142604476772, 0.025338439372717403, 0.1089875701291021, 0.027040844506700523, 0.0954450671270024, 0.13590821268735453, 0.08035281876800582, 0.08277849134174176, 0.03453062854532618, 0.031309963669627905, 0.009573745846864767, 0.02559268246841384, 0.01291677881454234, 0.13357366842683405, 0.0740451127057895, 0.24933442706242204, 0.1893012406071648, 0.44359060178976506, 0.15534203237621114, 0.15484687144635245, 0.20162745262496173, 0.15909093199297786, 0.19150681444443762, 0.10117301484569907, 0.2490771096199751, 0.26687191100791097, 0.09654939771280624, 0.11959427793044597, 0.1386227217153646, 0.16404076013714075, 0.36742671683896333, 0.12922069028718397, 0.15847489004954696, 0.277146203443408, 0.29142758867237717, 0.13599344092654064, 0.21758662594947964, 0.23922447580844164, 0.20577573159243912, 0.1339263518457301, 0.09988482459448278, 0.24741107714362442, 0.8019342622719705, 0.17204728676006198, 22.944624200463295, 92.46676906943321, 101.6447813808918, 143.66407424211502, 107.43785932660103, 86.90913408994675, 81.27654433250427, 43.39560940861702, 15.599809270352125, 14.048166330903769, 45.79523004591465, 102.92931005358696, 91.13104194402695, 70.50555869936943, 71.01302906870842, 88.06222781538963, 93.18137392401695, 87.68316775560379, 91.61945253610611, 94.61422383785248, 89.28878679871559, 90.38576513528824, 85.59816643595695, 86.87246605753899, 85.69614037871361, 82.70484209060669, 77.3943230509758, 82.1406027674675, 75.23930668830872, 82.61924028396606, 76.6282157599926, 78.79797533154488, 78.95593285560608, 76.4817564189434, 75.10319799184799, 76.97315365076065, 78.93739745020866, 72.25490123033524, 77.11397409439087, 46.983874663710594, 50.334056094288826, 31.592236272990704, 37.14281693100929, 32.51141645014286, 35.77676363289356, 29.4802924990654, 20.40200773626566, 18.557831794023514, 1.6908457386307418, 0.4146208375459537, 0.26221870444715023, 0.4703336855163798, 0.17667595791863278, 1.167001216672361, 0.34521735389716923, 5.425293305888772, 2.0228091068565845, 3.406622176989913, 9.626244809478521, 7.895365012809634, 0.3111387637909502, 0.755305242491886, 14.173105526715517, 17.482407800853252, 34.7373978048563, 4.285622360184789, 2.5014520855620503, 15.09840052574873, 0.802998561412096, 0.41321990021970123, 0.20198375772451982, 0.11580032252823003, 0.32529724936466664, 0.47726665099617094, 2.5893133459612727, 5.781730804592371, 11.485140211880207, 24.090777598321438, 36.36030212044716, 31.17022141814232, 31.475744023919106, 33.10224674642086, 28.46738465130329, 43.702157959342, 45.775364711880684, 60.81097550690174, 72.37604632973671, 70.34988105297089, 68.82471889257431, 67.59472489356995, 67.3970215022564, 67.24952101707458, 66.61177843809128, 72.18375384807587, 72.0559287071228, 66.00884199142456, 73.2807245850563, 75.18015146255493, 67.1709032356739, 70.52391171455383, 72.68022760748863, 72.75863260030746, 74.07798260450363, 75.42570948600769, 68.30461800098419, 72.0059309899807, 73.68432372808456, 79.13758590817451, 75.45686021447182, 54.94653359055519, 57.157718539237976, 68.46873879432678, 72.10202023386955, 68.90054002404213, 63.23095165193081, 60.72817035019398, 63.83989557623863, 51.97374790906906, 44.17299449443817, 37.58025325834751, 22.124345116317272, 4.760243492200971, 0.17206132819410414, 0.13927998254075646, 0.20696818479336798, 0.2774482872337103, 0.22763469693018124, 0.15024545195046812, 0.1545342936879024, 0.12748716690111905, 0.20025585981784388, 0.23681202088482678, 0.16630325670121238, 0.1409832263016142, 0.1823081314796582, 0.1315156780765392, 0.20031529100378975, 0.31073628226295114, 0.13866984809283167, 0.246831756667234, 0.14252288587158546, 0.16323325893608853, 0.17466291203163564, 0.20172860735328868, 0.09297792334109545, 0.2138231208664365, 0.16960266715614125], [0.028060395852662623, 0.008139547317114193, 0.06578370288480073, 0.054884956261957996, 0.08180799224646762, 0.021419426520878915, 0.04722142803075258, 0.048095477613969706, 0.013479017834470142, 0.13262695516459644, 0.19602305022999644, 0.05000782148272265, 0.07244819644256495, 0.14336232910864055, 0.12337053311057389, 0.060428881042753346, 0.08570446792873554, 0.17185456585139036, 0.16498732496984303, 0.09193462698021904, 0.05800722719868645, 0.09601318117347546, 0.06076070640119724, 0.02822564430971397, 0.09206335991621017, 0.07933632878120989, 0.06535604770760983, 0.03654968211776577, 0.26751508587040007, 0.8536881383042783, 43.48913758993149, 70.2183473110199, 88.99968311190605, 88.91493245959282, 67.32544094324112, 45.05302347242832, 29.130148887634277, 21.475590728223324, 14.570809286087751, 23.566052354872227, 68.90825361013412, 53.51227395236492, 56.380686834454536, 49.31300528347492, 72.22015589475632, 85.17127454280853, 87.8936916589737, 84.75057631731033, 90.95458701252937, 83.84675681591034, 85.04462733864784, 87.50754117965698, 89.4111630320549, 84.68817606568336, 86.37853816151619, 82.92046532034874, 85.50628736615181, 79.25431564450264, 79.80267941951752, 77.80975475907326, 76.97462037205696, 73.94419938325882, 81.28322437405586, 76.76101863384247, 79.835334867239, 71.98099672794342, 74.97344255447388, 61.39012522995472, 37.940929904580116, 31.086662001907825, 22.99559086561203, 34.51311103999615, 24.97292686253786, 34.90252934396267, 22.409128434956074, 6.040395274758339, 2.567661632783711, 0.3938743664184585, 0.06657207894022577, 0.24096136854495853, 0.569427291629836, 1.6674095462076366, 1.4292624313384295, 3.70032527949661, 0.45061992772389203, 0.2856937557226047, 0.44364106783177704, 0.2122924115974456, 0.1512141921557486, 0.058788341339095496, 2.0963204372674227, 0.398344470304437, 0.5711635015904903, 1.3112951489165425, 1.2319455505348742, 0.7811820914503187, 0.36280061351135373, 0.27802425320260227, 0.1940460133482702, 0.05473640427226201, 0.1451295756851323, 0.11164339754031971, 0.5006174964364618, 0.9589673671871424, 0.5647657730150968, 1.1115170689299703, 8.193770125508308, 23.102203644812107, 29.95270024985075, 28.192596696317196, 27.751590460538864, 21.594102568924427, 27.893784530460835, 36.78853914141655, 42.58418194949627, 66.46297842264175, 69.67752993106842, 66.28355205059052, 71.90402045845985, 63.10253754258156, 68.24150338768959, 69.32355612516403, 71.14239692687988, 70.30584141612053, 69.00878861546516, 72.84796580672264, 71.59010410308838, 67.5722225010395, 69.55633163452148, 70.4578484594822, 70.13905316591263, 67.96562299132347, 68.13913688063622, 68.26607286930084, 71.44529387354851, 63.84297341108322, 77.17697471380234, 48.42145532369614, 34.00275282561779, 50.312446653842926, 59.15490657091141, 56.80227801203728, 46.83601699769497, 24.427838511765003, 18.34780376404524, 24.317872412502766, 18.8000250980258, 8.109444100409746, 11.38441426679492, 4.122226377949119, 0.22457262530224398, 0.06257261542486958, 0.11684296579915099, 0.11091549167758785, 0.08628345443867147, 0.0861050866660662, 0.08382589177927002, 0.04057006677612662, 0.13001524843275547, 0.17320530430879444, 0.04758539580507204, 0.06188812149048317, 0.045155389088904485, 0.028006178254145198, 0.06324122368823737, 0.08448307096841745, 0.11144493240863085, 0.1086130749899894, 0.0883509665436577, 0.10511648331885226, 0.02506383174477378, 0.03912314597982913, 0.038239723071455956, 0.021381797778303735, 0.044773086556233466, 0.036865284127998166, 0.025335561695101205, 0.011848137182823848, 0.027232752763666213, 0.06076585690607317, 0.04809191159438342, 0.08990192160126753, 0.13005942106246948, 0.07416666907374747, 0.018222922262793873, 0.12525195168564096, 0.011440860453149071, 0.08156172538292594, 0.04743266181321815, 0.11781753186369315, 0.02598333972855471, 0.06316277125733905, 0.01913278603751678, 0.020999265179852955, 0.0485834879509639, 0.1656246665515937, 0.040996003881446086, 0.033342171809636056, 0.017215744373970665, 0.09222980137565173, 0.06709570123348385, 0.041584593782317825, 0.09610852488549426, 0.28842287021689117, 0.7234505424275994, 3.9174461038783193, 61.386021450161934, 95.01671344041824, 104.97412472963333, 104.25299182534218, 88.60993042588234, 75.1092928647995, 52.4713122099638, 31.508944742381573, 19.47479858994484, 28.894297443330288, 74.79757279157639, 75.75066044926643, 67.82642126083374, 63.91219049692154, 76.04935482144356, 86.42169624567032, 88.64300385117531, 88.6946202814579, 90.57855159044266, 86.40231728553772, 91.2098117172718, 92.48084351420403, 89.90305423736572, 85.43491959571838, 85.00963881611824, 84.25989344716072, 85.60734674334526, 81.61659568548203, 84.03610065579414, 83.38658630847931, 78.92459973692894, 76.5620993077755, 83.9864069223404, 77.5392396748066, 77.51869797706604, 72.2296629846096, 74.10063698887825, 66.42714634537697, 40.05345694720745, 36.0167283564806, 28.453695885837078, 38.1550408154726, 28.849243260920048, 26.068214289844036, 22.802908904850483, 11.706579979509115, 8.22683310136199, 0.7006751582957804, 0.2586589189013466, 0.18037115572951734, 0.7582312636077404, 3.1131703360006213, 4.230516292154789, 8.711497094482183, 2.0661274949088693, 0.4192172846524045, 0.1939039069111459, 0.3177776013035327, 0.7241229282226413, 0.06549193494720384, 3.3867178950458765, 7.090899730101228, 0.903474788647145, 3.3814520901069045, 2.5297584291547537, 5.786245437338948, 1.6196989500895143, 0.19469214195851237, 0.2532420720672235, 0.05026086786529049, 0.08917331811971962, 0.19195568020222709, 0.2974833355983719, 0.86039780639112, 1.381627474911511, 2.5965381832793355, 15.548206139355898, 21.92041575908661, 30.841297768056393, 30.088423267006874, 35.26509068906307, 24.360464327037334, 29.95252165943384, 41.83758281171322, 48.89567367732525, 69.39088091254234, 68.58390301465988, 67.76252388954163, 71.07501894235611, 66.76836803555489, 65.49249529838562, 74.77773025631905, 70.54596573114395, 69.21929731965065, 70.18702179193497, 73.24646562337875, 71.19498610496521, 71.59568980336189, 69.52795475721359, 75.68610951304436, 73.21197867393494, 77.49415889382362, 68.45478594303131, 72.03064486384392, 76.77184045314789, 72.94014886021614, 76.14581644535065, 55.37561796605587, 43.47083777189255, 63.117653131484985, 69.47460561990738, 60.74640557169914, 61.54280103743076, 51.69696316123009, 52.32442729175091, 49.430855959653854, 36.43004357814789, 24.784738160669804, 22.88203965872526, 8.961723167449236, 0.7913933310192078, 0.008504534616804449, 0.08815808978397399, 0.14390969270607457, 0.308199769933708, 0.1369509004871361, 0.11428436715505086, 0.1042086437519174, 0.12181272060843185, 0.09701079834485427, 0.05229254536970984, 0.05674264095432591, 0.022684055438730866, 0.04445496866537724, 0.023901652602944523, 0.08504820158123039, 0.15919679193757474, 0.09438984445296228, 0.07294039620319381, 0.04167927327216603, 0.06294420134508982, 0.04786874407727737, 0.03174992736603599, 0.055608249676879495, 0.07278999255504459, 0.02541918132919818, 0.06749372245394625, 0.21053101314464584, 0.2055542153539136, 0.15063622238812968, 0.18269128748215735, 0.17200076894368976, 0.17403109202859923, 0.18766248947940767, 0.19594049372244626, 0.32130327774211764, 0.2962815313367173, 0.15531626500887796, 0.10051455174107105, 0.20505889115156606, 0.20055157598108053, 0.14269760227762163, 0.10985931163304485, 0.19545003800885752, 0.19825917086564004, 0.2117952617118135, 0.14431411866098642, 0.17339749087113887, 0.1378779616788961, 0.10386424270109273, 0.1807693624868989, 0.12777734664268792, 0.24412067636149004, 0.5180250154808164, 0.6150000274647027, 1.916811775881797, 55.889171808958054, 97.42155879735947, 117.09344521164894, 122.1521669626236, 97.61369168758392, 77.70405203104019, 62.03258715569973, 39.347200244665146, 24.50791161507368, 42.52321042120457, 94.19700622558594, 85.3776566684246, 73.9820909500122, 74.37737613916397, 82.35444009304047, 88.96778002381325, 92.26870849728584, 91.06284320354462, 92.00495705008507, 90.71229681372643, 90.75333461165428, 91.94236680865288, 89.77774456143379, 86.51314973831177, 85.64267724752426, 85.5153688788414, 83.16685169935226, 79.68486294150352, 83.9336733520031, 79.55168768763542, 77.38752141594887, 77.99194738268852, 81.92016139626503, 79.2280362546444, 78.8707186281681, 75.06475165486336, 73.16638112068176, 71.1229495704174, 46.076988726854324, 42.98257537186146, 32.077035158872604, 45.46076059341431, 31.38852920383215, 37.71571598947048, 28.072566837072372, 22.884994000196457, 16.627104096114635, 0.2618964045541361, 0.2024038281524554, 0.20228259090799838, 1.4411286008544266, 1.9609515136107802, 5.637751780450344, 19.49036255478859, 3.410847787745297, 0.9046673309057951, 1.447818735614419, 0.639591773506254, 1.3821360538713634, 0.2824450784828514, 7.139163315296173, 13.036666307598352, 3.0579032516106963, 5.09539975784719, 3.6955769592896104, 6.34559964761138, 1.2201900500804186, 0.5476609314791858, 0.6243757868651301, 0.27281805756501853, 0.4611859138822183, 0.3606699965894222, 1.2110992753878236, 1.4984094584360719, 1.5126958605833352, 5.535105038434267, 21.76989633589983, 31.436000056564808, 39.768875017762184, 34.31592062115669, 38.75541999936104, 28.92344567924738, 36.5222342312336, 47.378384694457054, 55.31058065593243, 69.38297733664513, 73.81256684660912, 69.26617160439491, 73.81882131099701, 66.24814555048943, 66.70506343245506, 73.22121977806091, 74.00435775518417, 69.71797496080399, 69.19708371162415, 75.07951006293297, 72.95390412211418, 73.7172831594944, 70.7942596077919, 75.13665899634361, 70.70203855633736, 77.2360235452652, 73.65612924098969, 71.0427738726139, 75.66771849989891, 76.26440048217773, 80.44247388839722, 61.824213936924934, 50.2009454369545, 70.61857983469963, 77.12286561727524, 74.02926921844482, 63.5812396556139, 51.21317692101002, 54.359411895275116, 57.95561112463474, 47.773460894823074, 42.07003153860569, 29.124720878899097, 6.566172111779451, 0.36869549250695854, 0.16684397065546364, 0.18769230897305533, 0.20213925250573084, 0.4241013288265094, 0.28147414152044803, 0.16645507042994723, 0.3081932687200606, 0.24459142063278705, 0.24411012302152812, 0.16141844069352373, 0.1450051472056657, 0.14353701582876965, 0.16303577343933284, 0.1787985151167959, 0.21238111308775842, 0.22449122654506937, 0.1891809978405945, 0.16357537417206913, 0.2535287191858515, 0.27984177286271006, 0.16345424082828686, 0.14495370152872056, 0.15223534282995388, 0.1196710011572577, 0.15407402854179963], [0.05398532113758847, 0.048347447882406414, 0.07153302445658483, 0.05692118313163519, 0.11456688793259673, 0.10656480677425861, 0.09132254810538143, 0.09061337405000813, 0.09145945208729245, 0.061204202720546164, 0.08060082967858762, 0.04976605203410145, 0.06051161195500754, 0.0837114303431008, 0.08089742899755947, 0.11612274116487242, 0.11461614427389577, 0.14369399490533397, 0.014530174466926837, 0.07033532427158207, 0.08220396513934247, 0.03878680836351123, 0.07816308236215264, 0.10788205952849239, 0.04454828260350041, 0.09758492378750816, 0.1418010433553718, 0.16840127849718556, 0.24343338824110106, 0.10359116204199381, 11.928069144487381, 55.29121309518814, 78.07419776916504, 101.41734078526497, 85.30229151248932, 48.24071042239666, 30.11689893901348, 36.994845271110535, 23.99796187877655, 25.07545106112957, 57.09872670471668, 70.31727120280266, 53.0559716373682, 62.39975765347481, 58.2497039437294, 87.60682225227356, 85.0437381863594, 82.67031714320183, 89.35114905238152, 88.9093467593193, 87.98474237322807, 87.90275037288666, 88.17688286304474, 83.93030673265457, 85.09992957115173, 82.03062906861305, 80.27098909020424, 80.91598927974701, 76.82961255311966, 76.83668777346611, 78.93156856298447, 75.11113196611404, 76.63210675120354, 75.01258805394173, 80.18680840730667, 75.436782091856, 78.29675182700157, 50.59816852211952, 36.949278116226196, 32.734589874744415, 23.217814341187477, 27.990301251411438, 25.6584594771266, 30.559345297515392, 22.022782266139984, 7.645671861246228, 1.9925090577453375, 2.0029423478990793, 2.0369042130187154, 2.7631236193701625, 3.2391117280349135, 8.210382834076881, 0.3716997953597456, 2.3887983430176973, 1.8648178596049547, 0.1820539459004067, 0.06601474829949439, 0.384376390138641, 0.3208628873107955, 0.0445128524734173, 0.24897006223909557, 0.544822127558291, 0.868657969404012, 1.5394939226098359, 0.4719946417026222, 6.376930866390467, 2.454645484685898, 0.1807074376847595, 0.21670623100362718, 0.16565110185183585, 0.16431102063506842, 0.08103469663183205, 2.6779117668047547, 2.572246086783707, 0.11098523129476234, 2.0196118159219623, 7.138084648177028, 29.28080130368471, 23.541999645531178, 27.34524216502905, 35.45623943209648, 24.20308817178011, 22.736098989844322, 38.01967687904835, 38.306952863931656, 61.70128673315048, 70.42204678058624, 68.27919736504555, 63.88381361961365, 65.65716326236725, 71.01053640246391, 71.31704315543175, 71.69597402215004, 68.04502353072166, 74.7569377720356, 76.45958840847015, 70.83420306444168, 70.83561658859253, 69.01117488741875, 72.47934758663177, 67.5241930782795, 70.25866314768791, 71.66102349758148, 74.06545847654343, 65.93261048197746, 70.65767213702202, 65.78992053866386, 34.39254350960255, 46.974124386906624, 54.87553820014, 53.040213882923126, 42.194949835538864, 33.545648753643036, 18.90249989926815, 17.039663158357143, 20.500401556491852, 6.96928583085537, 4.931591972708702, 6.521337842568755, 0.4116199485724792, 0.2171116365934722, 0.10055261649540626, 0.2463805754086934, 0.23957632802193984, 0.10437170843943022, 0.06700993122649379, 0.03315153262519743, 0.07064989098580554, 0.08280481531983241, 0.10614538943627849, 0.055104591156123206, 0.14040736423339695, 0.06944352993741632, 0.0768490950576961, 0.06000686618790496, 0.1129551138728857, 0.13221489993156865, 0.06838879708084278, 0.07624630787177011, 0.02078119621728547, 0.11002836545230821, 0.033558374270796776, 0.028513933430076577, 0.038846937168273143, 0.036409249223652296, 0.02863454912585439, 0.025685235705168452, 0.05035645648604259, 0.07096183049725369, 0.017089638640754856, 0.07200584674137644, 0.06255329732084647, 0.0584833631728543, 0.027873126018675976, 0.10828707920154557, 0.08996023214422166, 0.05464167283207644, 0.03707114105054643, 0.054395561819546856, 0.0973840244114399, 0.04583694040775299, 0.040451133900205605, 0.012564509142976021, 0.023586933748447336, 0.009709677615319379, 0.11475098508526571, 0.022631819374510087, 0.08814533226541243, 0.04172072593064513, 0.13475409883540124, 0.04973954251909163, 0.020658886569435708, 0.047126533318078145, 0.018204865809821058, 0.810773300472647, 0.3325803007464856, 21.81135021150112, 72.5509737432003, 97.91178569197655, 109.41982537508011, 99.13652077317238, 76.39692217111588, 61.896546855568886, 55.358344092965126, 33.39333012700081, 28.42820305377245, 60.201822593808174, 77.0702612400055, 66.09782561659813, 73.06721404194832, 71.80650249123573, 85.46007424592972, 90.58822587132454, 84.8017443716526, 91.6416585445404, 87.84266799688339, 92.19075947999954, 93.09244349598885, 92.72721469402313, 85.13424172997475, 86.49483472108841, 84.05757710337639, 83.72800558805466, 81.43042087554932, 80.63915893435478, 80.33611759543419, 81.3229550421238, 75.6531272828579, 77.92954713106155, 79.04263660311699, 77.76696145534515, 76.90506890416145, 81.17487698793411, 58.19046892225742, 43.29476661980152, 33.06432858109474, 27.14779146015644, 34.93399925529957, 26.037933714687824, 25.411826111376286, 19.75933112204075, 10.589549168944359, 2.817546436563134, 1.6366456844843924, 0.4922876605996862, 1.1757038184441626, 0.805532312951982, 3.1036767829209566, 1.3891389593482018, 0.9412387060001493, 0.9898127464111894, 0.6538195163011551, 0.29423664731439203, 0.6277568929363042, 0.31335707288235426, 0.19224816060159355, 0.23543223476735875, 1.8269046815112233, 0.15543293062364683, 2.0676117902621627, 1.3610204681754112, 8.741017710417509, 4.611569344997406, 0.39561419805977494, 0.13341150915948674, 0.25568738928996027, 0.0471121133887209, 0.07871501016779803, 3.2956659933552146, 1.9000614434480667, 0.37678885040804744, 2.722578370012343, 11.651670075953007, 28.92407074570656, 26.289708204567432, 29.046452678740025, 37.80862480401993, 28.8962372392416, 28.270707204937935, 39.65137392282486, 47.29439400136471, 67.45415523648262, 68.96009802818298, 68.49591493606567, 67.25900530815125, 69.91235733032227, 72.56267711520195, 74.73556011915207, 69.8838360607624, 70.59970244765282, 74.79331701993942, 71.76605746150017, 74.5107489824295, 71.85643941164017, 71.98616445064545, 73.75056177377701, 76.8492878973484, 76.33573025465012, 69.96053874492645, 77.54425540566444, 74.69387635588646, 74.40047889947891, 67.03056156635284, 47.52270855009556, 55.32992921769619, 69.88020345568657, 56.77004434168339, 53.59756797552109, 52.626442685723305, 49.64180164039135, 50.988916754722595, 40.45316889882088, 28.43807492405176, 24.034837000072002, 14.05241260305047, 2.109511191956699, 0.21860292297787964, 0.09507814931566827, 0.4056297184433788, 0.3942375141195953, 0.12983790482394397, 0.155939357355237, 0.1892854625475593, 0.12918059946969151, 0.05131774923938792, 0.06062658176233526, 0.06245231328648515, 0.07721700734691694, 0.02044716296950355, 0.08959838320151903, 0.05734844868129585, 0.1621340640122071, 0.045932102293591015, 0.10194790607783943, 0.08418408193392679, 0.07112204533768818, 0.07211260468466207, 0.035050851802225225, 0.014439958067669068, 0.026266474633303005, 0.03693365819344763, 0.042686026281444356, 0.17392950685461983, 0.13531246106140316, 0.16677943349350244, 0.16201190650463104, 0.29723646759521216, 0.1717482606181875, 0.17341991857392713, 0.18416250619338825, 0.17177785746753216, 0.2434767148224637, 0.11438978181104176, 0.1110053138108924, 0.21044700202764943, 0.16980935528408736, 0.1573722664033994, 0.206286076863762, 0.18913835403509438, 0.24165120965335518, 0.09009722518385388, 0.22658862493699417, 0.1754567280295305, 0.17077184660593048, 0.21588776085991412, 0.3345036506652832, 0.13504813774488866, 0.11469197692349553, 0.15224132454022765, 0.1414579336415045, 0.8766134362667799, 0.237572202750016, 16.15928839892149, 71.70728221535683, 102.37446382641792, 130.8746901154518, 115.61765000224113, 80.00964671373367, 65.2232113480568, 61.833854019641876, 39.104720056056976, 40.40869228541851, 81.09127387404442, 91.21681094169617, 75.60860887169838, 85.04472613334656, 77.41030499339104, 90.4286952316761, 91.43896222114563, 88.52321907877922, 95.89703500270844, 92.85407468676567, 94.01325568556786, 94.12269741296768, 91.56393751502037, 85.19768312573433, 85.24394944310188, 80.94926789402962, 80.68006753921509, 80.38272589445114, 81.43102884292603, 77.57787600159645, 78.58397841453552, 75.406254529953, 77.6514020562172, 78.00906926393509, 79.73000451922417, 75.30719384551048, 78.22948023676872, 63.20768550038338, 50.9429582208395, 38.778613954782486, 33.038630560040474, 40.7087317854166, 29.59428448230028, 36.59137152135372, 30.2250487357378, 17.560185827314854, 3.0418476881459355, 5.96838628873229, 7.843452673405409, 4.96546620503068, 17.3569518327713, 14.382356498390436, 7.0633298344910145, 6.935131838545203, 1.4719796204008162, 0.844427797710523, 1.020741721149534, 1.2435424095019698, 0.8004700345918536, 0.30046534433495253, 0.3557882085442543, 4.51878497377038, 1.3884844444692135, 7.224666802212596, 3.4649141365662217, 13.151695635169744, 4.738900512456894, 0.3555940627120435, 0.49246488546486944, 0.6427447136957198, 0.28279718302655965, 0.1929154255776666, 6.430640984326601, 4.88983316347003, 0.18650421960046515, 3.1066178251057863, 16.718282103538513, 38.28266076743603, 29.231058172881603, 32.717353999614716, 42.67291098833084, 33.46478149294853, 35.5927699059248, 48.61570470035076, 52.43003502488136, 69.5753838121891, 70.55731952190399, 69.5976734161377, 66.98745667934418, 69.23252061009407, 71.55940935015678, 77.48011484742165, 73.01919981837273, 71.06200084090233, 76.92908361554146, 74.36815783381462, 72.26510748267174, 69.84694004058838, 70.31638205051422, 75.51787734031677, 72.21420541405678, 80.20316272974014, 71.23638868331909, 74.21770870685577, 74.64298948645592, 83.2861652970314, 69.56934973597527, 51.1799743026495, 63.18198747932911, 76.6814661026001, 72.18211993575096, 59.63208116590977, 51.52250312268734, 53.59118811786175, 60.671416595578194, 54.20997731387615, 34.37045909464359, 29.3090907856822, 10.008566994220018, 1.4762220927514136, 0.2921221201540902, 0.17777418805053458, 0.46511644672136754, 0.5160162888932973, 0.21741121192462742, 0.17565056215971708, 0.3237037098733708, 0.1699740081676282, 0.11747986951377243, 0.21554407227085903, 0.18723704590229318, 0.3368105721892789, 0.1368219597497955, 0.14464778825640678, 0.17860810970887542, 0.1777952947304584, 0.37475414865184575, 0.20180607272777706, 0.1758387262816541, 0.18724924681009725, 0.29944815672934055, 0.08497931543388404, 0.09335520153399557, 0.17446987942093983, 0.1809214730747044, 0.1078257750486955], [0.05525660155399237, 0.071213002956938, 0.08256396613433026, 0.0685008910659235, 0.19919598387787119, 0.07186709481175058, 0.14122285094344988, 0.0650906705413945, 0.09428209203178994, 0.06372571253450587, 0.017926573418662883, 0.11564402622752823, 0.007662509633519221, 0.032493481412529945, 0.08427018590737134, 0.19132669520331547, 0.17134177149273455, 0.25150277477223426, 0.07493701836210676, 0.06908832321641967, 0.05014584239688702, 0.08301670590299182, 0.12228611434693448, 0.23437218071194366, 0.14177411823766306, 0.0985963894345332, 0.0849661126267165, 0.31290679704397917, 0.4865076660644263, 0.07925969461211935, 0.8255639474373311, 22.931017130613327, 65.1667083799839, 92.84786581993103, 89.88663911819458, 66.65979266166687, 51.71538457274437, 26.02217596024275, 23.913194127380848, 35.64333759248257, 50.27129106223583, 89.20389175415039, 79.06186357140541, 78.48635405302048, 61.0377511382103, 79.70924243330956, 96.14984303712845, 81.11356347799301, 86.18979468941689, 89.97722625732422, 92.22246497869492, 89.57352072000504, 90.7518982887268, 87.67296150326729, 87.3520003259182, 88.56675714254379, 87.75298520922661, 81.27127781510353, 79.92161303758621, 78.83585929870605, 75.91676473617554, 75.20667403936386, 75.05567774176598, 76.04500025510788, 71.97238638997078, 76.09840258955956, 66.58961802721024, 43.295104801654816, 34.84318792819977, 27.665196396410465, 22.494492754340172, 34.252106845378876, 26.315163038671017, 23.110637292265892, 19.50700756162405, 6.306886374950409, 2.187771792523563, 0.12070105760358274, 0.1210819574771449, 0.36799003661144525, 0.06276690968661569, 0.2320089895511046, 1.3615175290033221, 1.6666176449507475, 2.535105454735458, 0.18531234527472407, 0.1781406012014486, 0.11770333760068752, 2.516084387898445, 0.13701520016184077, 0.3380939533235505, 0.19437376060523093, 1.275794010143727, 0.7317423506174237, 2.4773309798911214, 6.12719876691699, 9.286306500434875, 0.30532243370544165, 0.32045063911937177, 0.3140288352733478, 3.116625538095832, 1.2909169611521065, 2.3626749822869897, 0.7362373906653374, 0.17488996469182894, 3.06684915907681, 6.606663214042783, 17.098197117447853, 28.41972190886736, 26.25181093811989, 32.60290414094925, 29.18591469526291, 16.80251218378544, 27.522802837193012, 28.244735598564148, 41.675893887877464, 69.16915521025658, 66.2004505097866, 69.7411461174488, 67.32324466109276, 67.50608325004578, 69.82515200972557, 71.44069612026215, 69.40699964761734, 76.78811877965927, 74.14644733071327, 70.72508811950684, 76.21536031365395, 73.37352320551872, 75.0376059114933, 71.90933257341385, 75.66190481185913, 70.17091065645218, 72.46621549129486, 64.64830219745636, 82.97892898321152, 48.37761327624321, 32.00531020760536, 60.65912425518036, 54.35650885105133, 39.794215857982635, 33.866849318146706, 27.919750437140465, 22.984438464045525, 23.328859582543373, 14.219385143369436, 7.827899158000946, 4.814466582611203, 0.883376895217225, 0.2388226325274445, 0.26612629008013755, 0.05002175530535169, 0.2537256554933265, 0.3782713646069169, 0.056507569388486445, 0.2234048707759939, 0.10230176209006459, 0.10551012586802244, 0.06432863330701366, 0.04472470965993125, 0.045870901085436344, 0.12026350217638537, 0.009592019378033001, 0.033131899108411744, 0.09485477028647438, 0.038103468468762, 0.1567139962571673, 0.05312351328029763, 0.029608994591399096, 0.04368165820778813, 0.07849670000723563, 0.048692709824535996, 0.029689369184779935, 0.029776699557260145, 0.07051816719467752, 0.04040987420012243, 0.03584367332223337, 0.06208444552612491, 0.14359984605107456, 0.07608163272379898, 0.12097786384401843, 0.02259597364172805, 0.16182026913156733, 0.037649570949724875, 0.08461576697300188, 0.06111277012678329, 0.11319370692945085, 0.03818866331130266, 0.03591101209167391, 0.11215222140890546, 0.05670463928254321, 0.03756481768505182, 0.09011468791868538, 0.07014636605163105, 0.034643909966689534, 0.05955289816483855, 0.041604906364227645, 0.05241595710685942, 0.11052420915802941, 0.13476594351232052, 0.056899649716797285, 0.0397385311225662, 0.10821112780831754, 0.07753793426672928, 0.4178998834686354, 0.5119600659236312, 2.9019527323544025, 37.820765152573586, 83.14482808113098, 112.42421016097069, 114.02593821287155, 88.40337350964546, 77.19419538974762, 52.801256105303764, 41.548304334282875, 46.28835618495941, 56.436277851462364, 88.577571362257, 83.42273756861687, 86.91714406013489, 76.02131992578506, 90.41449159383774, 96.40326663851738, 82.83675581216812, 88.06208342313766, 87.12869390845299, 90.4698546230793, 93.51375728845596, 95.27048662304878, 91.27042606472969, 88.71181055903435, 91.55938535928726, 89.25186797976494, 82.88658633828163, 82.90623888373375, 81.1210186779499, 81.28064051270485, 77.52622917294502, 77.75873109698296, 78.5144953429699, 72.95538604259491, 75.81153318285942, 72.59962633252144, 50.74792988598347, 41.89439356327057, 30.359553918242455, 29.238064996898174, 38.20714361965656, 25.622931383550167, 18.62688548862934, 18.037027940154076, 6.9179467856884, 2.77346761431545, 0.33296039910055697, 0.0965163424552884, 0.07810449722455814, 0.2877029572846368, 0.18716217804467306, 1.4926045574247837, 2.99806643743068, 2.1545416256412864, 1.3623382849618793, 0.43563848943449557, 0.21352874056901783, 0.5949065869208425, 0.7010072248522192, 0.5435142852365971, 2.361561404541135, 3.4879083652049303, 0.3182744246441871, 1.9469591206870973, 9.279680605977774, 18.459905348718166, 0.6110785191413015, 0.6317605124786496, 0.11263770473306067, 1.1539973644539714, 1.9463921198621392, 1.8451421591453254, 2.662462033331394, 0.47395628644153476, 6.9711273070424795, 21.15965288132429, 21.52332566678524, 29.15951371192932, 30.64535178244114, 39.41347248852253, 30.564349628984928, 26.675231717526913, 34.28421892225742, 40.8380426466465, 51.54673062264919, 75.1083505153656, 65.83295702934265, 75.15486761927605, 70.02853989601135, 75.15609115362167, 72.20315560698509, 71.18098765611649, 72.88182199001312, 77.55525201559067, 72.54379212856293, 78.30109119415283, 73.55780571699142, 78.92687201499939, 77.05807909369469, 81.28136247396469, 70.90369373559952, 72.48235702514648, 81.05508461594582, 74.17141199111938, 78.47870886325836, 59.57048647105694, 42.34222613275051, 77.21615821123123, 61.77594892680645, 49.00987274944782, 47.57335603237152, 44.94139686226845, 58.89234445989132, 47.21220821142197, 28.783349096775055, 13.398675732314587, 14.605162292718887, 3.00277984701097, 0.26745274546556175, 0.18614286789670587, 0.05464347625093069, 0.6758375535719097, 0.24426802236121148, 0.13324249244760722, 0.435783356660977, 0.18528129381593317, 0.08461426041321829, 0.07758678242680617, 0.06052127842849586, 0.09580657468177378, 0.07057511218590662, 0.07882269579567946, 0.050354089034954086, 0.1972931023919955, 0.061230044302647, 0.19462116295471787, 0.09704429146950133, 0.06152098845632281, 0.04439627220563125, 0.023502199037466198, 0.036315653269411996, 0.029683632383239456, 0.03438261090195738, 0.17200915521243587, 0.023946810433699284, 0.12298589281272143, 0.1628340280149132, 0.2262905635870993, 0.18272897374117747, 0.2824104647152126, 0.16193982912227511, 0.2604185213567689, 0.15615309588611126, 0.22962344490224496, 0.21025236637797207, 0.22775602323235944, 0.23053973010974005, 0.09036077666678466, 0.2900500735267997, 0.1594466730603017, 0.22387270582839847, 0.3122556960443035, 0.4438201035372913, 0.10958627550280653, 0.12211648907396011, 0.2217209673835896, 0.20622581447241828, 0.2134899262455292, 0.6478768133092672, 0.25929339579306543, 0.19557791005354375, 0.20095658081118017, 0.25395705713890493, 0.586094978498295, 0.6419095303863287, 1.1485890671610832, 29.495784267783165, 79.69645231962204, 124.01921197772026, 122.11353063583374, 98.01691085100174, 88.09132665395737, 48.88126105070114, 43.13727647066116, 47.92841278016567, 71.29087015986443, 113.8461546599865, 100.9240360558033, 102.92467430233955, 84.25214946269989, 92.47580498456955, 96.30582466721535, 86.02182850241661, 89.41909700632095, 89.77640703320503, 95.10658621788025, 96.00472122430801, 97.59286880493164, 88.36669787764549, 86.05668023228645, 86.915183365345, 87.84143686294556, 82.23881989717484, 83.37739080190659, 79.778391122818, 76.24541670084, 76.04794129729271, 79.58829492330551, 81.2228836119175, 73.92285972833633, 76.9821971654892, 73.33761513233185, 53.77664856612682, 49.12703946232796, 36.581530049443245, 34.11228574812412, 42.33757518231869, 32.13098466396332, 26.393908113241196, 23.680437617003918, 17.271511517465115, 1.6771465237252414, 1.1661498248577118, 0.14270109037170187, 0.7790326536633074, 0.3541132406098768, 0.24047968501690775, 2.161331861279905, 5.542482817545533, 13.803283721208572, 4.623650321736932, 0.6209612544625998, 0.40583624329883605, 8.84376134723425, 1.3631977513432503, 0.693413985427469, 3.310856153257191, 6.897946083918214, 2.5771784596145153, 3.8579823821783066, 14.982231259346008, 32.12864778935909, 0.38365009473636746, 0.7788604754023254, 2.5059702806174755, 6.772996438667178, 8.960240297019482, 10.252283066511154, 6.967245815321803, 0.27999320067465305, 6.013349276036024, 20.763657130301, 21.742646098136902, 33.695653304457664, 30.813122279942036, 42.70344614982605, 31.45393129438162, 30.305330827832222, 39.87823694944382, 47.05308794975281, 54.08693611621857, 76.0334412753582, 68.07630345225334, 76.75722643733025, 70.53841173648834, 75.75316071510315, 76.50296688079834, 71.21927440166473, 72.52922371029854, 79.94523257017136, 73.61142084002495, 76.07333913445473, 73.58199521899223, 78.42609688639641, 76.1498898267746, 81.36813461780548, 78.66074949502945, 70.68889886140823, 76.3075889647007, 81.51388719677925, 85.40902778506279, 61.54092773795128, 50.651749446988106, 82.0711424946785, 74.38500612974167, 59.99746575951576, 49.72565554082394, 48.229694813489914, 72.87692785263062, 61.27943716943264, 37.674104422330856, 21.812262162566185, 15.82973113283515, 1.1498768418096006, 0.23933238408062607, 0.20303288736613467, 0.2062059991294518, 0.5544698098674417, 0.3654467855812982, 0.18083997041685507, 0.36175700544845313, 0.38290862983558327, 0.1600280567072332, 0.1946044497890398, 0.13199501641793177, 0.3021607064874843, 0.18278632691362873, 0.2590037800837308, 0.1917357521597296, 0.2860238926950842, 0.12979318300494924, 0.23703003418631852, 0.2714673784794286, 0.18920103582786396, 0.13147711608326063, 0.19942866201745346, 0.13238878513220698, 0.1686005451483652, 0.0700613010849338, 0.2075017147581093, 0.10715624652220868], [0.03190781928424258, 0.05003080208553001, 0.08654146949993446, 0.1086912231403403, 0.13203178241383284, 0.025716456002555788, 0.10300044959876686, 0.1260414780699648, 0.11280461374553852, 0.09903928832500242, 0.0814108616032172, 0.116491774097085, 0.06593177618924528, 0.05787909911305178, 0.1500066733569838, 0.07245610031532124, 0.2749515837058425, 0.055715374983265065, 0.025791060397750698, 0.10439451463753358, 0.1424676107126288, 0.07089724880643189, 0.06400907936040312, 0.09604216946172528, 0.28970663726795465, 0.29488371103070676, 0.1432269168435596, 0.1166389939317014, 0.3001498128287494, 0.1748090557521209, 0.29248615843243897, 3.6137374257668853, 33.25323924422264, 61.157038137316704, 66.29809767007828, 94.26952913403511, 62.607720494270325, 42.358892038464546, 22.695838250219822, 30.806037560105324, 30.391618497669697, 68.32645922899246, 90.4473066329956, 98.61194372177124, 70.0410184264183, 59.68250446021557, 95.6067305803299, 89.88858461380005, 89.00133982300758, 85.44919162988663, 91.91147446632385, 94.47233945131302, 90.84740996360779, 91.5749341249466, 89.50680390000343, 88.9543667435646, 88.23767960071564, 80.25541752576828, 82.99729719758034, 77.39394307136536, 76.01379632949829, 75.63610419631004, 72.16064348816872, 72.91208356618881, 70.12725859880447, 75.49662128090858, 62.786694690585136, 33.235904574394226, 28.51079162210226, 20.80777656286955, 20.214098319411278, 26.574499122798443, 25.637414306402206, 23.51194705814123, 15.795712508261204, 4.627633458003402, 1.7406729399226606, 0.19115509581752121, 0.20546751766232774, 0.16722593922168016, 0.38523529248777777, 0.6429534056223929, 1.7144070868380368, 0.83563809748739, 1.7340298276394606, 0.2344002784229815, 0.8638861973304302, 0.006191886495798826, 0.3671739710262045, 0.32649400702212006, 0.2360784969641827, 0.7567001832649112, 0.12433319512638263, 0.6683933967724442, 3.071073107421398, 5.012376112863421, 3.254877794533968, 1.7567744571715593, 2.541724699549377, 0.41560741898138076, 1.25102385180071, 5.286628296598792, 3.647441854700446, 1.3449901971034706, 1.0608787299133837, 7.462819023057818, 3.59345150180161, 11.710368376225233, 26.11077770590782, 28.680925592780113, 29.024202972650528, 28.069517500698566, 16.243921257555485, 22.449904046952724, 27.001632302999496, 31.234377175569534, 50.411207154393196, 73.38306829333305, 61.28259479999542, 70.94340160489082, 67.55989596247673, 70.10818362236023, 69.75045561790466, 70.75101792812347, 70.27944803237915, 71.93240493535995, 73.90912726521492, 71.51263386011124, 68.8706736266613, 70.14399290084839, 69.52002078294754, 72.44459465146065, 74.77089822292328, 67.04831421375275, 74.96259033679962, 66.65983065962791, 27.6511637493968, 53.71246241033077, 55.12186758220196, 42.39545747637749, 31.379210203886032, 38.66527363657951, 39.671417847275734, 23.78379587084055, 31.14556834101677, 10.648009981960058, 2.2342107631266117, 2.4585288763046265, 0.1802188967121765, 0.1160514578805305, 0.40578901302069426, 0.4477864078944549, 0.705133150331676, 0.16829360771225765, 0.16713700024411082, 0.04341933126852382, 0.2770827052881941, 0.12691195792285725, 0.06345137764583342, 0.009430080899619497, 0.015871269642957486, 0.025837633875198662, 0.06039083484211005, 0.04333592871262226, 0.07199901156127453, 0.11810273921582848, 0.11274911594227888, 0.11297084740363061, 0.03234570125641767, 0.09145458359853365, 0.1414762350032106, 0.04192538428469561, 0.05470697440614458, 0.06106425222242251, 0.010259914251946611, 0.06188383558765054, 0.061945444977027364, 0.033820927565102465, 0.15761214337544516, 0.09862836115644313, 0.1247671659803018, 0.006284687888182816, 0.20297738956287503, 0.07251630333485082, 0.07654594257473946, 0.08079599967459217, 0.060219985025469214, 0.05359787923225667, 0.019147736602462828, 0.1053879015671555, 0.12716874101897702, 0.03919472983398009, 0.11625301034655422, 0.06719386510667391, 0.05625701662211213, 0.024263553495984524, 0.06186716695083305, 0.1365374945453368, 0.2736841142177582, 0.27337745879776776, 0.3544951498042792, 0.17399919452145696, 0.09927820792654529, 0.1297759503358975, 0.19100718578556553, 0.7872704928740859, 0.7006118085701019, 8.864942360669374, 50.576680675148964, 86.57544359564781, 101.9467131793499, 110.47158613801003, 99.6777181327343, 69.85086143016815, 42.65182971954346, 45.39317362010479, 44.36511218547821, 73.53417858481407, 84.50286760926247, 106.07737272977829, 87.55336672067642, 77.65726134181023, 102.79022231698036, 91.76944568753242, 90.4189981520176, 91.04297026991844, 86.81374400854111, 89.28431063890457, 94.8412312567234, 95.55943071842194, 91.55018985271454, 91.7933464050293, 92.29591503739357, 83.05130749940872, 82.2549158334732, 81.473708152771, 83.15988287329674, 81.65040627121925, 69.7681474685669, 73.87807533144951, 70.729860663414, 83.434167355299, 69.41684111952782, 44.92304764688015, 37.65706993639469, 28.79152625799179, 28.190487809479237, 33.921061009168625, 24.896617457270622, 18.908731564879417, 17.677778117358685, 2.5636079628020525, 4.141789153218269, 0.032345100116799586, 0.36179141141474247, 0.16347794502507895, 0.34779317036736757, 0.719816928030923, 1.1103048152290285, 1.5789056452922523, 2.8146564541384578, 0.3189345798455179, 0.46895471576135606, 0.4675699275685474, 0.3340969537384808, 0.4053117526927963, 0.2035784104373306, 3.4813116816803813, 0.6143424252513796, 1.597163190599531, 6.48420718498528, 6.475568823516369, 8.356093615293503, 2.4773872643709183, 7.652340503409505, 2.328734491020441, 3.469160171225667, 6.750656487420201, 4.205846590921283, 1.849731719121337, 0.5345476570073515, 14.18086376041174, 23.25401309877634, 16.05477310717106, 24.356341548264027, 24.865183643996716, 31.089793033897877, 39.752668887376785, 30.04360467195511, 32.50492259860039, 43.62200506031513, 43.86167719960213, 57.76352383196354, 71.96060702204704, 65.25895982980728, 70.79047501087189, 77.86059603095055, 69.58531647920609, 72.58028537034988, 74.29727643728256, 65.55849775671959, 74.2726993560791, 78.54629203677177, 74.05286595225334, 72.6893699169159, 74.47928667068481, 73.86775508522987, 67.81117647886276, 80.37719339132309, 78.17881375551224, 78.70057135820389, 68.05623292922974, 41.55890956521034, 67.20917478203773, 69.79140982031822, 48.2604693621397, 44.87263195216656, 46.22069701552391, 60.8946318179369, 65.11313125491142, 40.98601810634136, 17.28796273469925, 10.979982018470764, 5.064121736213565, 0.14560147770680487, 0.23985917534446344, 0.0910942857444752, 0.5607674375642091, 0.47047329833731055, 0.31800407508853823, 0.18473669100785628, 0.2943793771555647, 0.17216905835084617, 0.12347116833552718, 0.010405381690361537, 0.06813262254581787, 0.01826260118832579, 0.05011240122257732, 0.07250721944728866, 0.04971625763573684, 0.12073929305188358, 0.1207770906330552, 0.2642580965766683, 0.18578369810711592, 0.1651156719890423, 0.036936604519723915, 0.01770106999174459, 0.06234456828678958, 0.0030986525507614715, 0.160657576052472, 0.09416399407200515, 0.03108527474978473, 0.16469396883621812, 0.19730745552806184, 0.26265102031175047, 0.21296619263011962, 0.32585065404418856, 0.21476064634043723, 0.26195438113063574, 0.24938070739153773, 0.2991952921729535, 0.17117432813392952, 0.23724463360849768, 0.14206125517375767, 0.1224736773292534, 0.24537376302760094, 0.24877048388589174, 0.17999300180235878, 0.3166729293297976, 0.13694122288143262, 0.15620765858329833, 0.1706217843457125, 0.15714243811089545, 0.17637722863582894, 0.35155535442754626, 0.39967252872884274, 0.39625642297323793, 0.314572443603538, 0.28711817460134625, 0.2820681862067431, 0.2767766732722521, 0.770587072474882, 0.7290552416816354, 4.705312689766288, 41.33779563009739, 79.9748557806015, 101.31625100970268, 126.56579732894897, 111.8171851336956, 76.64781510829926, 35.37991292774677, 50.07877059280872, 42.28386126458645, 89.10858526825905, 108.54426115751266, 122.07037255167961, 98.07791277766228, 82.66674533486366, 98.82518827915192, 91.19802474975586, 93.19466561079025, 87.9703639447689, 88.96341025829315, 95.73607563972473, 98.86044278740883, 96.62574470043182, 88.47879946231842, 87.6227205991745, 90.21601304411888, 81.39282569289207, 81.60476312041283, 77.93021589517593, 77.04037964344025, 81.1769212782383, 72.42305740714073, 75.05923435091972, 74.50065672397614, 83.14222902059555, 71.74161717295647, 48.313183933496475, 47.981659322977066, 29.68294322490692, 29.731533117592335, 35.281464010477066, 29.871884286403656, 26.539736688137054, 22.93736658990383, 7.362275468185544, 7.069376735016704, 0.24460605578497052, 0.23872367455624044, 0.21049346047220752, 0.44212411798071116, 1.3337424444034696, 3.7716298783198, 6.390583533793688, 4.145100200548768, 1.0784742794930935, 1.5034988103434443, 0.942377932369709, 1.4046778692863882, 1.6825029300525784, 0.6119221926201135, 5.16302615404129, 0.2371110173407942, 4.902042858302593, 8.098261300474405, 11.130403596907854, 9.41069757565856, 6.013589613139629, 11.550458706915379, 4.909831015393138, 4.941872321069241, 9.46712739765644, 12.206884883344173, 3.791372193954885, 0.9166692243888974, 13.425762578845024, 15.224166177213192, 20.59621151536703, 33.51778864860535, 29.56408180296421, 34.464435651898384, 40.04436403512955, 28.72570239007473, 35.803905576467514, 42.10863746702671, 47.88002997636795, 59.92134444415569, 76.03004425764084, 70.40358737111092, 72.30339422821999, 79.66002747416496, 75.818030834198, 70.55339813232422, 78.22975382208824, 71.99351325631142, 73.19271370768547, 76.6511969268322, 72.23713338375092, 71.5913200378418, 75.09011909365654, 79.55951526761055, 72.32005253434181, 75.54947644472122, 78.12465146183968, 83.64659875631332, 71.10316023230553, 46.515986770391464, 70.4811792075634, 80.71707755327225, 64.30499821901321, 53.61674174666405, 51.45507954061031, 74.30504322052002, 86.47391304373741, 57.20965415239334, 20.670149847865105, 15.402788892388344, 1.7913593701086938, 0.22019149007974193, 0.22008595668012276, 0.19415297167142853, 0.4758741147816181, 0.7337982184253633, 0.37565093021839857, 0.21512233943212777, 0.2877492376137525, 0.45381736708804965, 0.20533826522296295, 0.1598554034717381, 0.21486249868758023, 0.17374517221469432, 0.1700045698089525, 0.14457591867540032, 0.16966335999313742, 0.22958498680964112, 0.29445311694871634, 0.2464931592112407, 0.1915434468537569, 0.1985595774021931, 0.18741499807219952, 0.3326276200823486, 0.19223061623051763, 0.14249069150537252, 0.21668890927685425, 0.13244554458651692, 0.17791276186471805], [0.0755997933447361, 0.01549377344417735, 0.1312999802757986, 0.05071126244729385, 0.1375381471007131, 0.14361768728122115, 0.03406481213460211, 0.028275063923501875, 0.07866476677008905, 0.09296461663325317, 0.016984967987809796, 0.009358707629871788, 0.15892736264504492, 0.10743792867287993, 0.06267411154112779, 0.19502815674059093, 0.05962626317341346, 0.13723756244871765, 0.09603504484402947, 0.014000184546603123, 0.0653001936734654, 0.05872554080269765, 0.22743302572052926, 0.12538313370896503, 0.14675900543807074, 0.3723569225985557, 0.3798898996319622, 0.16495737188961357, 0.10116649136762135, 0.3274525055894628, 0.26208021969068795, 0.15270488482201472, 6.581637281924486, 27.933769784867764, 50.11147163808346, 61.78581319749355, 67.77963817119598, 52.92259119451046, 36.84921808540821, 24.338852986693382, 28.583745807409286, 39.58805792033672, 83.41788902878761, 76.41260012984276, 91.16994425654411, 56.96630761027336, 82.05527454614639, 101.8249449133873, 91.54496893286705, 93.28252449631691, 84.49597477912903, 92.26902768015862, 94.03579607605934, 90.55829107761383, 88.13222005963326, 92.04528048634529, 91.2881027162075, 86.71269223093987, 83.86011689901352, 82.04992443323135, 79.87044498324394, 73.45233097672462, 75.22858366370201, 70.72894871234894, 67.25136771798134, 65.1849702000618, 33.18243004381657, 17.95342292636633, 24.396678283810616, 11.91665455698967, 23.616333156824112, 28.435591757297516, 24.10772278904915, 22.616158425807953, 10.238324515521526, 5.083461748436093, 0.2978550625266507, 1.0047208308242261, 0.06745000253431499, 0.44740785320755094, 0.21092478185892105, 0.19931805232772604, 0.16170912509551272, 0.9016188851092011, 0.13700871379114687, 0.15057910670293495, 0.4453558148816228, 2.173339454457164, 0.12137742873164825, 0.03393910716113169, 0.04175218928139657, 1.791987286414951, 0.49936570110730827, 0.6507235730532557, 1.1905012931674719, 1.3950469298288226, 1.7387422872707248, 0.477676791488193, 0.8583604625891894, 1.020970658864826, 0.6283306027762592, 0.36286868329625577, 0.6048805173486471, 0.26197578466963023, 2.586708585731685, 8.386735171079636, 6.6798007395118475, 16.494635604321957, 23.837925866246223, 23.800041899085045, 34.15088787674904, 28.86842653155327, 24.886475801467896, 17.87555370479822, 21.17379382252693, 28.73102780431509, 36.738704815506935, 53.03643308579922, 78.76158848404884, 66.18626967072487, 62.80700460076332, 67.98190891742706, 68.67339581251144, 68.35540607571602, 64.02424648404121, 63.23777988553047, 64.86698806285858, 64.57520171999931, 66.62469774484634, 60.62720976769924, 74.00702521204948, 74.68195259571075, 68.68214294314384, 70.3353962302208, 80.6925156712532, 34.84609097242355, 45.55924750864506, 54.65351611375809, 38.235246911644936, 29.784202091395855, 27.612219639122486, 40.709727331995964, 35.027242451906204, 22.454695589840412, 15.990172773599625, 3.6699601588770747, 2.1332874661311507, 0.21439553936943412, 0.3577825374668464, 0.043506529909791425, 0.3677402000175789, 0.16623394010821357, 0.5277226294856519, 0.05711858699214645, 0.07697153458138928, 0.03774567165237386, 0.124516898940783, 0.06762892691767775, 0.09760453875060193, 0.11821314110420644, 0.17116266157245263, 0.07702712886384688, 0.06967095367144793, 0.07345359132159501, 0.11018699951819144, 0.11091234497143887, 0.0488505757675739, 0.1041082534356974, 0.09155135965556838, 0.03860406934109051, 0.11874552074004896, 0.10240048257401213, 0.03525899453961756, 0.1108604391629342, 0.055771284678485245, 0.032696670314180665, 0.12465490872273222, 0.0516916506603593, 0.08978941201348789, 0.032100068929139525, 0.08233822707552463, 0.0948403800430242, 0.17482795083196834, 0.03259210912801791, 0.06809639831772074, 0.06576898609637283, 0.0639020097150933, 0.009841118462645682, 0.031441038081538863, 0.047546499845338985, 0.09965423188987188, 0.03382302413228899, 0.03843634396616835, 0.11062977224355564, 0.025557020417181775, 0.03251691843615845, 0.04925240791635588, 0.16990265808999538, 0.3612550167599693, 0.3971543029183522, 0.3577224531909451, 0.2247730497037992, 0.28374244167935103, 0.17913078947458416, 0.21718525764299557, 0.2878638549009338, 0.7235463091637939, 0.8700689999386668, 17.872128188610077, 50.46766072511673, 75.77954649925232, 101.93210676312447, 110.91972649097443, 98.993329256773, 63.82413402199745, 38.53841744363308, 35.94368867576122, 55.20622305572033, 81.80708706378937, 76.66239112615585, 102.8071466088295, 77.65970081090927, 96.06832981109619, 110.4971207678318, 91.65042847394943, 97.23635673522949, 89.03695911169052, 88.58199432492256, 86.56092077493668, 96.04256719350815, 94.55923318862915, 94.59467768669128, 90.90526565909386, 86.16791546344757, 86.56215950846672, 83.81197348237038, 82.01270923018456, 83.93310338258743, 79.04577523469925, 70.96873104572296, 65.43370485305786, 74.28922846913338, 41.11710347235203, 31.21032066643238, 33.13883878290653, 22.15910565108061, 31.446356400847435, 36.631653159856796, 22.0825207605958, 17.314076833426952, 13.509227000176907, 2.005461137741804, 1.1832699249498546, 0.5776097963098437, 0.22721766930771992, 0.1361045552766882, 0.12072805693605915, 0.43329564796295017, 0.11534793899045326, 0.4232563194818795, 0.20342491945484653, 0.06193819048348814, 0.1912337337853387, 0.5368077638559043, 0.5254911398515105, 0.14297549205366522, 0.1404205002472736, 1.5717186871916056, 0.3079223254462704, 0.568585874279961, 2.2170981438830495, 3.069901345297694, 0.6965389614924788, 0.9128065535333008, 1.6125340783037245, 1.3075185078196228, 0.5585926480125636, 1.648718467913568, 1.7360656871460378, 1.8762468150816858, 4.735339153558016, 11.246074140071869, 18.99384319782257, 26.950606741011143, 22.464677654206753, 25.671055801212788, 29.473806247115135, 26.708907410502434, 32.197097316384315, 37.782786190509796, 38.76933105289936, 48.44495706260204, 50.9217781573534, 60.057707726955414, 80.405243486166, 69.41241055727005, 71.75334334373474, 69.53939214348793, 74.76237148046494, 71.59273356199265, 65.83149030804634, 68.54877009987831, 66.38167798519135, 70.03582030534744, 69.04154285788536, 73.75946089625359, 71.6616390645504, 71.55040383338928, 74.98877853155136, 81.54172450304031, 75.66499024629593, 43.18898409605026, 61.72237940132618, 69.44457203149796, 54.414755925536156, 42.16509483754635, 30.718305967748165, 45.62489278614521, 70.09170770645142, 51.15511603653431, 23.05338006466627, 8.617066461592913, 5.199727909639478, 0.5924540560226887, 0.09263589716283605, 0.32566942158155143, 0.20557671727146953, 0.8186344255227596, 0.34445353550836444, 0.2456562838051468, 0.17242115107364953, 0.19501646049320698, 0.04772931308252737, 0.02960677371447673, 0.13008973037358373, 0.1704835964483209, 0.05399823821790051, 0.009763754205778241, 0.04191792198980693, 0.06909263509442098, 0.16933985782088712, 0.07436580213834532, 0.14851865242235363, 0.08480277334456332, 0.10549197293585166, 0.045285602609510534, 0.13923634425736964, 0.0406105064030271, 0.08891485034837388, 0.14462871506111696, 0.019119503449473996, 0.0594674806779949, 0.21549250785028562, 0.1652413621195592, 0.24169938988052309, 0.2652257087174803, 0.20194414188154042, 0.26107627199962735, 0.23850564641179517, 0.14244467834942043, 0.2685918827774003, 0.2025814983062446, 0.17769921629223973, 0.13800218235701323, 0.23866415431257337, 0.2458406036021188, 0.2314204812864773, 0.2273352848715149, 0.14600545837311074, 0.2092089067446068, 0.1979268668219447, 0.1472023199312389, 0.12396824400639161, 0.3021241631358862, 0.3980999474879354, 0.448402538895607, 0.33162681909743696, 0.29485441104043275, 0.4305948835099116, 0.36341036204248667, 0.29510688968002796, 0.3266049432568252, 0.864847011398524, 0.5284189421217889, 10.244579929858446, 38.14824678003788, 74.29067239165306, 99.60327252745628, 115.5000539124012, 105.64108774065971, 70.98253190517426, 34.20619010925293, 34.96492199599743, 56.004655212163925, 102.36053377389908, 100.33982500433922, 112.97572776675224, 85.79673618078232, 98.82277920842171, 105.06451427936554, 88.24045345187187, 95.3567723929882, 85.46759024262428, 91.48209750652313, 99.42375496029854, 99.53472420573235, 92.35720574855804, 90.43980583548546, 92.86513969302177, 84.25594925880432, 84.47859451174736, 80.79363584518433, 82.79119625687599, 83.82322087883949, 78.70119452476501, 75.94397127628326, 71.07892513275146, 77.27399870753288, 46.356068551540375, 30.48759564757347, 39.72939133644104, 20.966596640646458, 35.94607874751091, 41.00305639207363, 27.79676243662834, 23.346783220767975, 18.43340177088976, 4.396831467747688, 7.936788015067577, 2.7096904115751386, 0.2612740098265931, 0.32966434315312654, 0.2732539357384667, 1.4747069240547717, 0.2812653605360538, 1.5177689446136355, 0.4658735857810825, 0.4465358593733981, 0.5170296470168978, 3.714443896897137, 0.43346562946680933, 1.0961493873037398, 0.6764737819321454, 2.887850501574576, 1.3773466483689845, 1.7897439817897975, 2.5177489360794425, 3.230766663327813, 2.7919286862015724, 1.9503794121555984, 3.026137906126678, 2.2208105446770787, 1.1113269603811204, 2.7016438683494925, 2.710246844217181, 1.446906547062099, 6.816734466701746, 12.008153647184372, 11.222720593214035, 25.322361811995506, 26.99953481554985, 31.960054636001587, 35.67854270339012, 32.64572024345398, 35.135453045368195, 34.81590919196606, 31.92008838057518, 44.55333888530731, 55.36180190742016, 65.19537404179573, 84.35520753264427, 72.98438608646393, 78.0980832874775, 70.68465068936348, 76.15489795804024, 76.79518640041351, 71.40147462487221, 71.3909263908863, 69.74146530032158, 73.05600464344025, 73.3590915799141, 73.30347776412964, 79.57270056009293, 71.32385239005089, 72.48641520738602, 84.2530158162117, 87.6111388206482, 48.881245851516724, 63.920641243457794, 76.9740580022335, 68.95198166370392, 54.916575998067856, 43.56869772076607, 62.14937008917332, 84.24258917570114, 61.75251558423042, 29.355345703661442, 11.318750940263271, 3.397823036648333, 0.37474865675903857, 0.20809903973713517, 0.3620149166090414, 0.17823489848524332, 0.5892203107941896, 0.5053820845205337, 0.2284739472088404, 0.24930744257289916, 0.1778971025487408, 0.13238376821391284, 0.17862519394839182, 0.15825318085262552, 0.3030075563583523, 0.1704148735734634, 0.2325798198580742, 0.1805531748686917, 0.2384647392318584, 0.19372954673599452, 0.24100695125525817, 0.183589122898411, 0.17115062393713742, 0.1752404513536021, 0.18889047671109438, 0.15305269975215197, 0.14815117057878524, 0.21809896017657593, 0.326905453694053, 0.07895816001109779, 0.21701745805330575], [0.0120620306370256, 0.02984481387102278, 0.0589169703744119, 0.05895220754609909, 0.07525434586568736, 0.019576510567276273, 0.016656534244248178, 0.0891062650771346, 0.04930747156322468, 0.04571126883092802, 0.029657584855158348, 0.014666794577351538, 0.049281863757641986, 0.2017424113000743, 0.12497729767346755, 0.11200848224689253, 0.05367195299186278, 0.09333024310762994, 0.024336996430065483, 0.021957029020995833, 0.04828193108551204, 0.13047178799752146, 0.23013610567431897, 0.3314700775081292, 0.12149293659604155, 0.19481545721646398, 0.42432388407178223, 0.42050716700032353, 0.19599073712015525, 0.1966543952585198, 0.43225221801549196, 0.567958967294544, 0.20909163256874308, 10.065843220800161, 27.793350219726562, 48.73403035104275, 51.89546450972557, 47.9323797672987, 47.46440067887306, 41.187631487846375, 26.952476240694523, 34.97350953519344, 48.76382075250149, 75.06177261471748, 76.1269922554493, 86.84416517615318, 56.23528003692627, 91.30933597683907, 100.53542330861092, 96.17970943450928, 90.38164615631104, 81.9978216290474, 87.882459461689, 86.65963187813759, 84.23877418041229, 83.43285262584686, 84.99483481049538, 84.75906506180763, 85.731630474329, 84.577077627182, 80.86239695549011, 80.14818727970123, 66.5013487637043, 69.47412684559822, 64.14053544402122, 44.29350882768631, 29.086472131311893, 25.581504106521606, 19.048121385276318, 28.496363796293736, 35.91150440275669, 22.965901158750057, 14.513570107519627, 19.8850017786026, 11.624859664589167, 1.642198849003762, 0.48129888775292784, 1.316678391303867, 0.11394855275284499, 0.17382857477059588, 2.0313593605533242, 0.5692538665607572, 0.2343942373408936, 1.3677199836820364, 0.6056061596609652, 0.3589656692929566, 0.17538050946313888, 0.04955634707584977, 0.935598739888519, 0.10765349288703874, 0.0985902147658635, 0.6188699416816235, 0.518624255200848, 0.382895449292846, 0.5725102324504405, 0.8192688727285713, 0.17589815746759996, 0.30041505640838295, 0.04175854577624705, 0.29069372336380184, 0.11864415821037255, 0.389383512083441, 0.10509382555028424, 1.5848675253801048, 2.0355932833626866, 6.934860628098249, 23.292379640042782, 30.623324364423752, 26.618464663624763, 18.61047226935625, 29.729365333914757, 44.38121572136879, 32.21993789076805, 12.285627108067274, 24.49398346245289, 34.6603037416935, 39.84159171581268, 34.8934668302536, 47.36240275204182, 72.74835035204887, 72.70432591438293, 66.67015850543976, 67.68573001027107, 65.06812646985054, 57.298265397548676, 56.068772971630096, 53.63669067621231, 57.319384664297104, 56.73398807644844, 60.19518435001373, 65.63290536403656, 65.62761604785919, 74.23817440867424, 78.91332194209099, 43.215423077344894, 40.58862783014774, 54.147003293037415, 37.361761182546616, 24.197855852544308, 21.642329581081867, 41.129851788282394, 33.18890109658241, 17.314156629145145, 17.462325878441334, 7.915246021002531, 1.8829884845763445, 0.6621878547593951, 0.7573457923717797, 0.3037565911654383, 1.0764685808680952, 0.4931581107666716, 0.6713634124025702, 0.14224468439351767, 0.22132556594442576, 0.08001351627171971, 0.14439719467191026, 0.11150100908707827, 0.05565965824644081, 0.11645114893326536, 0.08064362933509983, 0.19285792397568002, 0.16926050739130005, 0.28646751889027655, 0.06011409168422688, 0.1354000938590616, 0.16964974900474772, 0.13522085035219789, 0.10996853350661695, 0.1730233445414342, 0.09577155273291282, 0.16539068223210052, 0.10046552546555176, 0.1172950747422874, 0.15723143646027893, 0.15572267991956323, 0.044172618581796996, 0.06349900126224384, 0.06306241062702611, 0.06980813224799931, 0.04281979097868316, 0.09010434980154969, 0.06724298043991439, 0.0789989039185457, 0.141563170182053, 0.09736792722833343, 0.03542082355124876, 0.03019357503944775, 0.023062688051140867, 0.11685167861287482, 0.03803914281888865, 0.23971981485374272, 0.12265686906175688, 0.04554643041046802, 0.04897983562841546, 0.017221616617462132, 0.036704887461382896, 0.03739249841601122, 0.11618928212556057, 0.33584022894501686, 0.4064619628479704, 0.8200083486735821, 0.4792293644277379, 0.18924712319858372, 0.21707365347538143, 0.3125793021172285, 0.34927330969367176, 0.7076442812103778, 0.7537010754458606, 0.7823994511272758, 20.226555950939655, 51.49112060666084, 72.0392931997776, 88.74113738536835, 106.63470402359962, 96.31635770201683, 57.474321350455284, 38.67070734500885, 41.01686865091324, 62.025534734129906, 77.59409353137016, 78.28360453248024, 95.56949257850647, 73.96736294031143, 105.39331063628197, 105.45627325773239, 97.6989135146141, 98.03650259971619, 86.06459900736809, 83.13731968402863, 83.98819282650948, 89.03797745704651, 91.89733162522316, 88.92438635230064, 80.33856466412544, 85.6635457277298, 87.60824337601662, 82.25434586405754, 84.6551102399826, 72.38458067178726, 69.8301449418068, 70.88436037302017, 51.870781034231186, 40.391365215182304, 41.07841394841671, 38.77193011343479, 29.11677360534668, 35.31262993812561, 28.078179135918617, 16.607896126806736, 28.81132699549198, 25.289455577731133, 0.9380807192064822, 0.6617685116361827, 0.6336938962340355, 0.20269163302145898, 0.2247895995969884, 1.4168259361758828, 0.48134810698684305, 0.2763802179833874, 1.3650628575123847, 0.4685919836629182, 0.3612705128034577, 0.18948294804431498, 0.18915000575361773, 0.9825729473959655, 0.2494435227708891, 0.02445284011628246, 1.3273304072208703, 0.580637224484235, 0.19172415981302038, 0.6958398583810776, 0.5837889772374183, 0.9667348035145551, 0.3036102990154177, 0.48847732599824667, 0.9316609043162316, 0.1784178675734438, 0.2538266172632575, 0.14776215160964057, 1.7208032123744488, 5.866357963532209, 17.92689085006714, 31.944053694605827, 46.20249979197979, 30.65287157893181, 24.53996479511261, 30.951330363750458, 39.33446332812309, 34.69112008810043, 26.44603941589594, 37.39025965332985, 48.44238460063934, 54.38136711716652, 46.49213545024395, 50.90049169957638, 82.05721244215965, 77.73534715175629, 69.76771429181099, 74.78014692664146, 69.18423280119896, 62.17214606702328, 62.62787081301212, 61.690046936273575, 62.48456910252571, 64.86395582556725, 66.46326720714569, 64.4647416472435, 73.4453697502613, 84.46504443883896, 77.46975660324097, 46.36385813355446, 57.44965687394142, 65.14333963394165, 53.473508432507515, 42.8730196505785, 27.627608813345432, 35.498390570282936, 51.42151594161987, 42.80644342303276, 23.01689062267542, 11.387894880026579, 4.3510842975229025, 1.0752258100546896, 0.4937024909304455, 0.3808235807809979, 0.3346223052358255, 0.5428012297488749, 0.4119981767144054, 0.1742019344237633, 0.20028766826726496, 0.20509166439296678, 0.13884520274586976, 0.16382991598220542, 0.10689807560993358, 0.1795541847241111, 0.004713627122328035, 0.14483865379588678, 0.13401634467300028, 0.03393717386643402, 0.06470800435636193, 0.14556094160070643, 0.05544650601223111, 0.1349567496799864, 0.11777626845287159, 0.16750333918025717, 0.04416996911459137, 0.11158430032082833, 0.12164504718384705, 0.06232824845938012, 0.08438573087914847, 0.09048527193954214, 0.08676993966219015, 0.14794140995945781, 0.11294669049675576, 0.16165294451639056, 0.16539105330593884, 0.14087445713812485, 0.16592047177255154, 0.21012036799220368, 0.23949914466356859, 0.15080844517797232, 0.08431586509686895, 0.12695877259830013, 0.09812453194172122, 0.2512762713013217, 0.17153771332232282, 0.34532282792497426, 0.23965676198713481, 0.15173244872130454, 0.1708575795055367, 0.19764637952903286, 0.07566278683952987, 0.0776771166420076, 0.18238550779642537, 0.5373326106928289, 0.5498069257009774, 0.9057217149529606, 0.5517337191849947, 0.29803133744280785, 0.3896194259868935, 0.30821105057839304, 0.2758791495580226, 0.6317913858219981, 1.4209970436058939, 0.2035768816131167, 11.639479380100965, 42.717429399490356, 76.72118917107582, 95.61841875314713, 117.24488988518715, 108.17724645137787, 69.17812272906303, 35.73634520173073, 44.19561468064785, 63.97136852145195, 96.86734333634377, 103.41985613107681, 111.73479035496712, 88.50835427641869, 101.41860991716385, 97.01810404658318, 94.59356054663658, 94.11042407155037, 86.01913824677467, 87.66077935695648, 92.10244461894035, 94.91333618760109, 93.28106537461281, 90.8374696969986, 81.99376344680786, 85.43273091316223, 87.61939197778702, 84.07609730958939, 86.45205661654472, 71.31290137767792, 68.81765887141228, 67.66178369522095, 59.183819219470024, 39.196139350533485, 34.59169842302799, 35.01409135758877, 39.92837145924568, 47.398375421762466, 29.038503505289555, 22.29285467416048, 23.387043960392475, 26.511164121329784, 1.5310554066672921, 1.7764945677481592, 1.5315131633542478, 0.4599555517779663, 0.35478648729622364, 2.282587392255664, 0.6502480641938746, 0.2970161387929693, 3.5300547536462545, 0.9616954426746815, 0.6006952794268727, 0.22356349742040038, 0.20545583625789732, 3.054436887614429, 1.9498207233846188, 0.09320328390458599, 1.773806568235159, 0.666098854271695, 1.6549986996687949, 2.9239024920389056, 2.2056336840614676, 1.0609571007080376, 0.4377874522469938, 1.1537795886397362, 3.1673314422369003, 1.5076765674166381, 0.4830312979174778, 0.30136049317661673, 3.918365892022848, 14.162450898438692, 21.61544982343912, 38.0818035453558, 39.16395887732506, 41.71384625136852, 25.743052437901497, 44.20438081026077, 64.47763055562973, 48.428716734051704, 21.017375215888023, 33.44790279865265, 47.601751908659935, 55.39704501628876, 55.65324246883392, 60.03739021718502, 83.64533722400665, 80.10736986994743, 74.80377405881882, 82.55133032798767, 78.85772332549095, 66.37738421559334, 66.32332071661949, 67.27796629071236, 66.62233427166939, 67.68954500555992, 76.07786849141121, 68.73185187578201, 73.62259984016418, 81.66813611984253, 85.97587376832962, 56.69225491583347, 58.906137719750404, 71.4756390452385, 69.12033542990685, 54.990732818841934, 44.71498221158981, 59.264435693621635, 61.73523411154747, 60.17207399010658, 34.29885193705559, 14.167123697698116, 4.870526399463415, 0.47302922524977475, 0.5934161168988794, 0.37025311205070466, 0.6581094267312437, 0.39908014645334333, 1.2114455318078399, 0.2888897998491302, 0.21850377204827964, 0.20963927818229422, 0.3661254054168239, 0.3010361746419221, 0.22459960979176685, 0.21987825923133641, 0.0944758667901624, 0.23251883016200736, 0.22958163230214268, 0.2386109868530184, 0.19742247357498854, 0.3679136250866577, 0.2230219225748442, 0.2725422161165625, 0.22221835475647822, 0.2534205437405035, 0.2701604861067608, 0.271620349958539, 0.18513715389417484, 0.34793296130374074, 0.2763103670440614, 0.3231327311368659, 0.17532502650283277], [0.17145868943771347, 0.015325286440202035, 0.07105808705091476, 0.09135603380855173, 0.10539953102124855, 0.021755196394224185, 0.06376748802722432, 0.15986254293238744, 0.11338003052514978, 0.009342223602288868, 0.06675462500425056, 0.061658163322135806, 0.029441538245009724, 0.08416810349444859, 0.14451285096583888, 0.04298739389923867, 0.04539732552075293, 0.04289993550628424, 0.17665876977844164, 0.0806706138246227, 0.15608802437782288, 0.05439741347800009, 0.17925829044543207, 0.3603705845307559, 0.35991992277558893, 0.29638264153618366, 0.784099503653124, 0.6980087701231241, 0.2759403322124854, 0.09698927606223151, 0.3822908364236355, 0.27716600394342095, 0.7028655626345426, 0.3599455120274797, 7.944029476493597, 23.617294505238533, 35.144773945212364, 41.248557418584824, 36.65182247757912, 44.17156957089901, 50.531953275203705, 34.3550319224596, 35.59938155114651, 44.390935599803925, 73.67236956954002, 89.72783043980598, 81.43062606453896, 58.64777058362961, 93.74654039740562, 103.6875669658184, 95.91625437140465, 82.90221869945526, 78.88671576976776, 79.9487891793251, 75.57216122746468, 71.84382408857346, 76.99854388833046, 81.54073655605316, 80.30777871608734, 82.43631049990654, 81.02120563387871, 73.4874714910984, 70.59897288680077, 59.47514198720455, 35.43329246342182, 28.614632450044155, 30.150840617716312, 22.097908034920692, 14.450467843562365, 34.518092572689056, 38.90842258930206, 21.768477112054825, 21.62544708698988, 9.489946123212576, 7.540971804410219, 2.7088962541893125, 2.4037453159689903, 2.0025737676769495, 0.8351193659473211, 0.5132150079589337, 0.13423735625110567, 0.39754173369146883, 0.07501757107092999, 0.16049094905611128, 0.5313050060067326, 0.3910745104076341, 0.18976836319779977, 0.17341510945698246, 0.2726643142523244, 0.9747469704598188, 0.2640187391079962, 0.44125794258434325, 1.2391377333551645, 0.7843641832005233, 0.8574317686725408, 0.20264397229766473, 0.9420139237772673, 0.16104217182146385, 0.16223311104113236, 1.077219396829605, 0.9528803906869143, 0.41238816047552973, 0.25634442747104913, 0.33241741417441517, 2.834908179938793, 9.618681315332651, 34.71590995788574, 26.499637439846992, 18.54689408093691, 35.98938502371311, 30.597654841840267, 12.579897567629814, 9.944985955953598, 9.2901860922575, 17.426284812390804, 31.31371881812811, 42.8037303686142, 48.83587248623371, 42.598275393247604, 40.4075713455677, 58.86524811387062, 75.63719853758812, 73.01843985915184, 68.95657181739807, 66.20726734399796, 63.32142099738121, 59.822097569704056, 65.96589669585228, 71.37722432613373, 79.10033270716667, 80.9160728752613, 79.4966970384121, 67.50913828611374, 51.33014224469662, 45.0275344401598, 50.64775966107845, 34.230033829808235, 18.333807215094566, 16.771061271429062, 41.504777669906616, 42.05373041331768, 20.5557531863451, 12.739109974354506, 7.358969170600176, 1.21483922470361, 0.5902795039582998, 0.131076623511035, 0.513679354917258, 0.3620850940933451, 0.5248433933593333, 0.31178187928162515, 0.19467030797386542, 0.1201386952016037, 0.32195577397942543, 0.2619214594596997, 0.25660925544798374, 0.10469328102772124, 0.19300620508147404, 0.11489746277220547, 0.17057458375347778, 0.38192252337466925, 0.12394006465910934, 0.08395634649787098, 0.09430909136426635, 0.13667915569385514, 0.060223922118893825, 0.42553106148261577, 0.0856710564403329, 0.1299251220189035, 0.1311632024589926, 0.009324759939772775, 0.24180014384910464, 0.0792204869503621, 0.09558111763908528, 0.024690440550330095, 0.02076042721455451, 0.0869540665007662, 0.04704480059444904, 0.030867489658703562, 0.13530232332414016, 0.03537280659656972, 0.08473468871670775, 0.10758568285382353, 0.15374058159068227, 0.012853562675445573, 0.06351128380629234, 0.01841597528255079, 0.06477381801232696, 0.035533143891370855, 0.03402040572836995, 0.11275686396402307, 0.0993251487670932, 0.036755527908098884, 0.0720434587856289, 0.09579635530826636, 0.018393824029772077, 0.030705788667546585, 0.05207523710851092, 0.2600228082155809, 0.5712451972067356, 0.731587924528867, 1.0445193015038967, 0.7426706829573959, 0.30687640188261867, 0.27001579699572176, 0.7048590306658298, 0.5121493432670832, 1.2344281235709786, 0.6492329249158502, 2.6236017560586333, 20.02972461283207, 46.867699697613716, 66.44279390573502, 83.88329565525055, 99.3412233889103, 81.6012217104435, 53.409022092819214, 37.427619248628616, 41.43828123807907, 62.98875644803047, 76.08888790011406, 90.94850733876228, 87.85396859049797, 76.827332675457, 108.7336277961731, 108.28856527805328, 98.51992025971413, 95.56753948330879, 86.19866341352463, 77.43161424994469, 75.75910359621048, 78.6017918586731, 84.08504962921143, 83.7971542775631, 83.2338573038578, 84.06387716531754, 83.45453426241875, 73.5829071700573, 79.5531240105629, 67.12701559066772, 42.85874381661415, 37.15958923101425, 44.042543694376945, 30.162428095936775, 23.34928348660469, 40.28250865638256, 34.88234102725983, 24.64991569519043, 20.587948858737946, 15.360341370105743, 23.046318143606186, 4.900349574163556, 3.0004764581099153, 3.114952677860856, 1.272225882858038, 0.1190685924666468, 0.044931828233529814, 0.18530755100073293, 0.08565721538616344, 0.42276077263522893, 0.6293294741772115, 0.18096894084010273, 0.29356188664678484, 0.25404228537809104, 0.430825810180977, 0.5552403372712433, 0.6829307635780424, 0.41256155585870147, 0.797176145715639, 0.6526123685762286, 1.2915518833324313, 1.6200940101407468, 1.377541625406593, 0.17856273479992524, 0.22283457481535152, 0.6040331034455448, 0.6604757497552782, 0.2492293092655018, 0.908769448287785, 0.4249279329087585, 3.9662573346868157, 18.752189464867115, 40.5034402012825, 38.2718351483345, 30.082011111080647, 25.16060259193182, 32.275783494114876, 25.43670527637005, 20.797849595546722, 16.6631318628788, 18.503646701574326, 39.2605496942997, 53.674768432974815, 71.47961363196373, 61.22077591717243, 53.112527802586555, 61.051058024168015, 79.99468311667442, 84.52962577342987, 74.4738757610321, 72.81417801976204, 69.19407427310944, 68.8236853480339, 70.54432421922684, 85.46389684081078, 81.50358974933624, 82.8229321539402, 88.21408286690712, 72.548488676548, 50.34627243876457, 59.897291734814644, 60.795191153883934, 48.22155185043812, 39.669848531484604, 24.5568909868598, 34.19748097658157, 45.998534336686134, 46.86865344643593, 36.302347630262375, 12.193610295653343, 3.5024195490404963, 0.8061469893436879, 0.6351428653579205, 0.18655998457688838, 0.3993787569925189, 0.2192897064378485, 0.9792415355332196, 0.2065972296986729, 0.031474134157178923, 0.41941543808206916, 0.41731961304321885, 0.01683965361735318, 0.12527498794952407, 0.13515818340238184, 0.11246203095652163, 0.1649100228678435, 0.23755787929985672, 0.13291389914229512, 0.05267328568152152, 0.10800458068843, 0.06302209716523066, 0.12067151270457543, 0.2278679539449513, 0.39808715286199003, 0.18397587089566514, 0.09648817052948289, 0.05635676126985345, 0.1661998755298555, 0.07198723367764615, 0.02348068232095102, 0.060533215873874724, 0.019792599850916304, 0.2733229554723948, 0.09744917013449594, 0.18409413954941556, 0.29638335399795324, 0.1383201777935028, 0.14188030472723767, 0.14666291215689853, 0.3004330163821578, 0.1894151751184836, 0.2626640524249524, 0.09393208034452982, 0.14543614204740152, 0.05496882266015746, 0.14604204625356942, 0.285865607438609, 0.4147113795625046, 0.12583949515828863, 0.2206055194255896, 0.19798267632722855, 0.1848974105087109, 0.2250044365064241, 0.42465731617994606, 0.35840012307744473, 0.6134257244411856, 0.8462176204193383, 1.3780583976767957, 1.036505769006908, 0.4648942773928866, 0.3059124411083758, 0.5807243229355663, 0.3693002538057044, 1.0618035052902997, 1.3836906454525888, 1.3171674963086843, 10.788676533848047, 36.19803562760353, 61.12527944147587, 90.92526018619537, 106.33101671934128, 100.53535491228104, 73.55789691209793, 47.095147892832756, 47.024255096912384, 66.65160030126572, 97.82720983028412, 117.26646512746811, 106.02355241775513, 92.9496243596077, 105.67864492535591, 100.97695201635361, 96.96556806564331, 92.60887384414673, 82.87379622459412, 82.56560996174812, 84.93632555007935, 84.29731383919716, 88.87257993221283, 85.64055696129799, 81.71555757522583, 86.91803321242332, 85.69514483213425, 78.23438197374344, 80.22160694003105, 68.26083675026894, 46.95041745901108, 44.57753598690033, 45.55608227849007, 28.74883744865656, 19.923459514975548, 47.16357082128525, 56.826475113630295, 41.174408197402954, 29.050241075456142, 11.43295381218195, 16.826314106583595, 3.5376564832404256, 18.150681741535664, 6.501081129536033, 2.251429301686585, 0.44044995156582445, 0.14648635522462428, 0.3455332713201642, 0.18193052674178034, 0.31056659761816263, 1.5252601238898933, 0.8407162281218916, 0.492362380027771, 0.20203781576128677, 0.7933275459799916, 2.015816057100892, 0.9006479184608907, 3.109319480136037, 1.0363185103051364, 2.4972473736852407, 3.747236137278378, 2.8183812042698264, 2.6067610597237945, 0.22706354007823393, 0.41410364967305213, 2.314839349128306, 2.1762308618053794, 0.6295152485836297, 1.750463827047497, 0.29961324005853385, 8.242849241942167, 24.718450717628002, 54.10629227757454, 50.91061055660248, 28.00913494080305, 46.25719025731087, 41.689390763640404, 29.218961521983147, 26.181569807231426, 23.560449555516243, 34.85130809247494, 53.089193254709244, 60.18123909831047, 73.93425151705742, 63.23396489024162, 61.567302122712135, 72.5074052810669, 86.04886785149574, 91.71413585543633, 80.41275948286057, 74.69486430287361, 75.60745373368263, 77.53377556800842, 77.58438885211945, 87.53081873059273, 90.39436787366867, 84.62496265769005, 84.80394825339317, 80.4175016283989, 62.793861106038094, 62.424023151397705, 69.88775745034218, 66.27975985407829, 58.455219715833664, 48.474561274051666, 57.52800107002258, 60.132947489619255, 60.54921895265579, 43.578299805521965, 16.281924918293953, 2.7579129114747047, 0.28640428790822625, 0.40796166518703103, 0.351710730465129, 0.5518015217967331, 0.41567519190721214, 1.3217344949953258, 0.628786162706092, 0.3256527677876875, 0.4107496468350291, 0.6520453677512705, 0.19854406651575118, 0.38284539885353297, 0.30098265095148236, 0.11915281138499267, 0.14672295190393925, 0.34720672527328134, 0.158129004703369, 0.1618571687140502, 0.23596134153194726, 0.22977312124567106, 0.260488876956515, 0.5527879251167178, 0.48411153838969767, 0.26601704594213516, 0.1704465929651633, 0.16436877456726506, 0.24125184514559805, 0.16534740017959848, 0.35130896139889956, 0.12728844943922013, 0.16754614625824615], [0.06857470507384278, 0.07899166055722162, 0.03606701524404343, 0.11812081051175483, 0.10960154148051515, 0.18465082452166826, 0.014681959437439218, 0.08686880857567303, 0.15228485892293975, 0.03358053108968306, 0.08513697728631087, 0.08092111092992127, 0.03303045865322929, 0.12924771930556744, 0.030308969726320356, 0.13852272473741323, 0.08802338255918585, 0.06802392017561942, 0.06713102746289223, 0.10413577227154747, 0.06670378788840026, 0.2511405770201236, 0.18132558732759207, 0.08109433561912738, 0.16688085539499298, 0.4779824672732502, 0.4529770481167361, 0.5665038235019892, 0.6998314848169684, 0.47801393433474004, 0.079779517109273, 0.759278048062697, 0.3792612411780283, 0.7072876347228885, 0.5278126371558756, 5.058677578344941, 21.951640583574772, 25.071098394691944, 24.140950106084347, 27.829564176499844, 51.90239153802395, 56.181277334690094, 41.92585587501526, 34.28493328392506, 34.07202310860157, 59.06634472310543, 83.4205336868763, 80.78442513942719, 65.31667873263359, 83.80321115255356, 99.05326724052429, 98.79355877637863, 76.73897981643677, 77.16540813446045, 78.75557720661163, 75.89507550001144, 74.46545541286469, 78.60110029578209, 78.92736598849297, 81.47341936826706, 77.85244926810265, 74.16209489107132, 61.74310348927975, 36.269608587026596, 38.1764792650938, 49.019083455204964, 43.64918880164623, 38.104602321982384, 31.072914339601994, 22.12916325777769, 42.249058932065964, 31.667804718017578, 26.92492201924324, 18.791029080748558, 3.7297195522114635, 0.9629238455090672, 8.888731934130192, 11.848039738833904, 1.3812086661346257, 0.8745828608516604, 0.6462662341073155, 0.818875296972692, 0.2258373933727853, 0.1633359573315829, 0.4871498019201681, 0.23920280509628356, 0.3874285763595253, 0.2460036682896316, 1.3081086636520922, 0.4771514399908483, 0.6765379628632218, 0.10236542351776734, 1.4654187974520028, 1.0566585813648999, 0.7623418711591512, 0.5650768813211471, 0.2895817783428356, 0.1875635760370642, 0.37397634820081294, 1.0397770372219384, 0.20453245611861348, 0.2224359821411781, 0.21556408057222143, 0.8990896458271891, 14.934185687452555, 18.08727454394102, 25.3421226516366, 26.93311247974634, 12.584700509905815, 48.438630402088165, 42.35736072063446, 8.439520988613367, 11.193717699497938, 22.0411903783679, 33.83215717971325, 25.44975757598877, 30.010930225253105, 35.0466214120388, 42.960251569747925, 44.32138033211231, 49.34478297829628, 50.052601397037506, 63.68179365992546, 75.55557131767273, 85.05038782954216, 85.03717973828316, 87.9755924642086, 85.05065381526947, 85.82797810435295, 80.97878471016884, 72.21510216593742, 57.8768527507782, 48.03929843008518, 52.33587607741356, 48.530840054154396, 33.10016065835953, 19.283165372908115, 11.841880269348621, 23.913397416472435, 30.95944292843342, 28.64409986883402, 6.1137954611331224, 7.1199714951217175, 1.4602446625940502, 0.9286955196876079, 0.6845628947485238, 0.408687248127535, 0.4262618097709492, 0.25739070726558566, 0.31651624711230397, 0.31940801069140434, 0.12889825680758804, 0.4433293064357713, 0.3800556360511109, 0.5101898952852935, 0.2179532914306037, 0.16671661811415106, 0.11749912824598141, 0.18218190700281411, 0.011002048013324384, 0.09799309016671032, 0.1312532991869375, 0.11971245010499842, 0.06650637660641223, 0.048786454208311625, 0.14841239171801135, 0.046998783727758564, 0.2649643539916724, 0.12246870493981987, 0.06752154557034373, 0.13784422364551574, 0.09036686227773316, 0.03639179762103595, 0.002576843185124744, 0.04448838015377987, 0.09112388259381987, 0.1044169942906592, 0.06208994484040886, 0.04671767674153671, 0.041352245898451656, 0.10231192209175788, 0.010261722309223842, 0.06256658918573521, 0.1394823068403639, 0.22850514709716663, 0.012662262979574734, 0.06174005931825377, 0.05115164545713924, 0.08823129523079842, 0.14564897515811026, 0.20769773080246523, 0.08913801415474154, 0.2080987874069251, 0.20789635920664296, 0.04536297892627772, 0.018851794084184803, 0.08273816303699277, 0.153200090280734, 0.10976381949149072, 0.27950831106863916, 0.6281477375887334, 0.910141768399626, 0.5332940211519599, 0.3078001976246014, 0.26836006552912295, 0.6414763536304235, 0.6989061750937253, 0.7794052117969841, 0.7159055129159242, 0.381753402762115, 2.971165543422103, 15.533486679196358, 35.02438120543957, 55.23893930017948, 72.18671768903732, 88.95961046218872, 72.5637486577034, 51.11097000539303, 35.282630547881126, 42.37777702510357, 58.36903274059296, 65.92562645673752, 88.84951516985893, 93.75214889645576, 85.85377871990204, 103.75948950648308, 104.09287601709366, 99.5370800793171, 97.79643148183823, 87.98618629574776, 79.6193316578865, 80.4677577316761, 82.81663209199905, 87.65669837594032, 86.88998311758041, 82.62869417667389, 85.12506902217865, 80.83907380700111, 57.89408482611179, 45.77856793999672, 47.884734123945236, 68.81586536765099, 54.27451305091381, 43.305660635232925, 33.94771657884121, 40.22799678146839, 45.600311905145645, 29.888502694666386, 23.639078736305237, 18.52519914507866, 7.430835664272308, 11.779938843101263, 13.413006663322449, 7.544851396232843, 4.003334082663059, 0.11994674612651579, 1.143788737244904, 0.9262394858524203, 0.10748970089480281, 0.37821947364136577, 1.1258244886994362, 0.06519934322568588, 0.24017316318349913, 0.7304722687695175, 2.2430120408535004, 0.9083777130581439, 0.5626515427138656, 1.2118923640809953, 0.9150516986846924, 1.8032339704222977, 0.6682572572026402, 0.8220402896404266, 0.5294393061194569, 0.11065398110076785, 0.17890876857563853, 0.922984960488975, 0.5051513062790036, 0.16440892475657165, 0.08003041497431695, 0.9279432788025588, 10.023371949791908, 20.777818970382214, 25.360101386904716, 35.996513441205025, 26.872669123113155, 61.09693296253681, 48.05004425346851, 14.105870984494686, 25.806389339268208, 32.58608244359493, 45.99674463272095, 37.32828877866268, 56.12751021981239, 62.91737347841263, 67.80633553862572, 68.79635721445084, 68.20602849125862, 59.7956357896328, 69.07637938857079, 77.20316290855408, 87.8748370707035, 91.4117556810379, 92.3967844247818, 92.94827923178673, 90.08218422532082, 77.93763309717178, 73.67685332894325, 64.3006132543087, 59.82865981757641, 63.19100059568882, 61.01782500743866, 46.14540785551071, 38.26733998954296, 25.737117156386375, 22.90787637233734, 30.088573358953, 46.23858265578747, 38.46420742571354, 3.7208591401576996, 2.6848328579217196, 0.6666447781026363, 1.2783607724122703, 0.19822170725092292, 0.7059096149168909, 0.17420701071387157, 0.2812029904453084, 0.13018619472859427, 0.028914138420077506, 0.3769117797492072, 0.8223967580124736, 0.26793232129421085, 0.15213113045319915, 0.2700976113555953, 0.1926243255729787, 0.14162312087137252, 0.30328330874908715, 0.1488332636654377, 0.18801411904860288, 0.21663293649908155, 0.028535967794596218, 0.05903827812289819, 0.015404695313918637, 0.04873131634667516, 0.09089938292163424, 0.16212413407629356, 0.31385119480546564, 0.14448910224018618, 0.2101234850124456, 0.05115786836540792, 0.08802131938864477, 0.12098649502149783, 0.15519965876592323, 0.13429747021291405, 0.19831821613479406, 0.24048401915933937, 0.1647768370457925, 0.25247935205698013, 0.23942414321936667, 0.22502815554616973, 0.1998551594442688, 0.32514564343728125, 0.11259953607805073, 0.22074211912695318, 0.12023878865875304, 0.15786944597493857, 0.16943321999860927, 0.2319811738561839, 0.3670131030958146, 0.25909613294061273, 0.23398620454827324, 0.1488383102696389, 0.17074266535928473, 0.27675773366354406, 0.3484255395596847, 0.2873912552604452, 0.3349467128282413, 0.6972914992365986, 1.3862811564467847, 1.0813370696268976, 0.7001972151920199, 0.32875212491489947, 0.46393945987802, 0.4317242541583255, 0.5795448424760252, 0.7027020526584238, 1.266926710959524, 1.106136201415211, 8.09015728533268, 30.683904513716698, 55.61245545744896, 81.50614321231842, 102.74464756250381, 85.78237295150757, 77.88141131401062, 50.18669240176678, 49.99389834702015, 68.12595918774605, 88.05837482213974, 116.56987890601158, 112.24929794669151, 103.07488024234772, 107.0337662100792, 100.75063616037369, 97.96772629022598, 93.43698620796204, 83.61766710877419, 86.04011312127113, 91.83901235461235, 87.79735162854195, 93.4118239581585, 91.53340995311737, 91.08309611678123, 92.32495307922363, 88.77555593848228, 71.02866142988205, 51.81022748351097, 48.66566821932793, 59.76686753332615, 50.996436551213264, 47.10973910987377, 37.49617137014866, 39.046552777290344, 57.09559187293053, 32.077464535832405, 31.345338821411133, 24.875766076147556, 7.722248677164316, 9.541858937591314, 31.168767996132374, 27.34982091933489, 4.896392561495304, 0.7971939572598785, 1.201919442974031, 1.167102623730898, 0.20912023494020104, 0.30409477301873267, 1.6030867164954543, 0.3209958504885435, 0.5243447294924408, 1.5427743340842426, 7.381477737799287, 3.4598929435014725, 0.7104558334685862, 1.20964917819947, 2.3938888823613524, 3.5449238307774067, 0.8089315867982805, 1.3031597854569554, 0.7925880106631666, 0.5299678933806717, 0.36984546517487615, 1.55066282954067, 0.5179671279620379, 0.489801139337942, 0.15272676333552226, 1.3991475035436451, 24.185301326215267, 27.774617224931717, 44.963785260915756, 48.10338959097862, 31.26694142818451, 82.61306941509247, 59.15658228099346, 19.011084772646427, 33.179941177368164, 52.18335226178169, 63.56892451643944, 46.42555922269821, 52.840435802936554, 59.073028564453125, 68.3087369799614, 68.24437603354454, 72.44888082146645, 69.41234976053238, 80.15976145863533, 83.6933134496212, 92.02285408973694, 92.10143387317657, 94.5513904094696, 93.36925864219666, 98.37880343198776, 86.01724594831467, 79.78164374828339, 71.83083638548851, 66.48269936442375, 67.32596531510353, 74.61165636777878, 63.166712298989296, 55.02113118767738, 50.9285493940115, 51.00517988204956, 46.967299953103065, 53.97930309176445, 46.256734281778336, 11.673088576644659, 2.4198683258146048, 0.6015407934319228, 0.7199392339680344, 0.32417437992990017, 0.6376246071886271, 0.3569298394722864, 0.4456153587670997, 0.30892529350239784, 0.20311867963755503, 0.3324378380784765, 0.7620971999131143, 0.558982661459595, 0.23938339931191877, 0.4172057379037142, 0.22362991963746026, 0.22685097414068878, 0.23902817774796858, 0.12241532967891544, 0.2543877105927095, 0.2506712428294122, 0.08637315040687099, 0.1991023842128925, 0.28743634815327823, 0.24078674119664356, 0.3573378425789997, 0.4303942364640534, 0.30243242159485817, 0.2134331371053122, 0.2885365969268605, 0.21756027970695868, 0.21664176805643365, 0.13577216217527166, 0.20152010838501155], [0.0714682943362277, 0.1325504545820877, 0.010938817031274084, 0.060783994995290413, 0.14748766086995602, 0.03878429619362578, 0.13357145682675764, 0.13217618950875476, 0.13694640307221562, 0.04635200944903772, 0.046154902447597124, 0.023768234859744553, 0.09260202554287389, 0.024095937587844674, 0.030774068109167274, 0.22009866224834695, 0.0433821311162319, 0.06421950791263953, 0.05187098322494421, 0.055719872398185544, 0.27441037993412465, 0.06243033829377964, 0.24943915894255042, 0.29068648000247777, 0.1549921097466722, 0.11602651429711841, 0.14726495719514787, 0.03770056391658727, 0.4187543923035264, 0.9383079945109785, 0.6626784440595657, 0.4146692849462852, 0.7754069950897247, 0.16280533658573404, 0.4319997690618038, 0.9645341872237623, 3.241893178783357, 15.042399130761623, 17.43207760155201, 22.638250440359116, 36.121633127331734, 57.00961388647556, 55.605935007333755, 41.40447445213795, 27.98469465225935, 19.513966888189316, 48.21376606822014, 73.00815001130104, 73.17873045802116, 62.331000342965126, 69.1361577808857, 83.4395706653595, 101.76514372229576, 84.24945920705795, 88.81910920143127, 94.59608361124992, 89.28333029150963, 85.72075545787811, 86.74060553312302, 77.2687777876854, 74.33183938264847, 53.316531255841255, 49.691172391176224, 54.15812149643898, 54.42938894033432, 37.06199146807194, 25.064408853650093, 25.801548399031162, 26.894065774977207, 25.35746242851019, 22.67606981098652, 46.023704186081886, 30.46955991536379, 50.07062382996082, 19.996373802423477, 3.5294824093580246, 15.657550971955061, 17.51888394355774, 4.559046663343906, 2.5332411797717214, 0.15549653267953545, 0.39756468089763075, 1.1012185527943075, 0.757235954515636, 0.3494192159269005, 0.23999000113690272, 0.3618390276096761, 0.6317609280813485, 0.457367118797265, 0.8648480800911784, 1.2463147169910371, 1.3976062112487853, 2.233630819246173, 1.771549133118242, 0.9862835670355707, 1.2033111182972789, 0.36922784987837076, 0.44651870091911405, 0.06540780508657917, 0.5400739854667336, 0.7712470495607704, 0.8212423918303102, 0.4716127918800339, 1.577051819767803, 21.20741631835699, 27.793137431144714, 35.56136079132557, 38.67029696702957, 12.824515141546726, 14.20853577554226, 10.266675744205713, 6.217011222615838, 10.144838131964207, 8.967486508190632, 6.996582616120577, 14.559709131717682, 15.416091978549957, 20.555004626512527, 34.478654488921165, 34.78757791221142, 39.45647478103638, 52.721585780382156, 58.91216039657593, 59.411328211426735, 65.38743853569031, 70.72403937578201, 74.53167825937271, 69.37540054321289, 66.81531071662903, 62.185118570923805, 60.13629890978336, 57.1084313839674, 56.78684324026108, 46.65113031864166, 38.212505131959915, 19.74137518554926, 11.696104891598225, 12.39393174648285, 21.21376007795334, 17.02407829463482, 6.945644449442625, 7.400098163634539, 2.612261502072215, 1.5080709150061011, 0.7938025204930454, 0.8441523124929518, 0.7034206297248602, 0.8704372239299119, 0.7764558575581759, 0.48385166795924306, 0.4132524359738454, 0.08233951099100523, 0.40289819939062, 0.14256444614147767, 0.23200553114293143, 0.3502851241501048, 0.31561999989207834, 0.3572340606478974, 0.113964219490299, 0.24286508123623207, 0.16856373462360352, 0.2679596917005256, 0.15355228388216347, 0.0509193124162266, 0.18008651240961626, 0.09175093058729544, 0.310979142668657, 0.1824574515921995, 0.2078331875964068, 0.1399285305524245, 0.1996409014100209, 0.11732965882401913, 0.12899129244033247, 0.059324383473722264, 0.12166589411208406, 0.18192463408922777, 0.18814536044374108, 0.2025771196349524, 0.17047132132574916, 0.055139498072094284, 0.31621003698091954, 0.15528705407632515, 0.06332616248982958, 0.053765667689731345, 0.268749930546619, 0.1618869139929302, 0.13814681209623814, 0.07020032018772326, 0.0354063628037693, 0.05834195435454603, 0.04192859407339711, 0.03790749695326667, 0.24039660900598392, 0.0947833459940739, 0.03434027879848145, 0.01551586346977274, 0.12987746129510924, 0.09814707096666098, 0.20113689301069826, 0.5014597449917346, 0.6916171568445861, 0.8612965769134462, 0.7356160646304488, 0.6219933740794659, 0.3854639927158132, 0.6524106825236231, 0.8057908178307116, 0.7711390522308648, 0.9988894499838352, 0.9427452064119279, 0.25666150264441967, 1.7221679328940809, 10.523354820907116, 26.17625769227743, 42.61856250464916, 55.111258551478386, 76.94936692714691, 71.34328454732895, 46.314795166254044, 28.17629937082529, 33.694289177656174, 49.32829566299915, 60.26464842259884, 82.46838077902794, 87.12220385670662, 83.4564645588398, 86.22614353895187, 86.52711778879166, 98.16130310297012, 106.27450615167618, 94.15784552693367, 87.13295727968216, 90.4786017537117, 98.10666963458061, 94.24299895763397, 84.05368611216545, 70.5302345752716, 69.14369657635689, 63.432713225483894, 69.29475367069244, 75.1665785908699, 51.965665742754936, 32.57856644690037, 32.91264832019806, 36.83661796152592, 33.30462008714676, 37.56811670958996, 53.390406891703606, 36.41128398478031, 50.975393280386925, 31.959887444972992, 5.983595447614789, 18.87324906885624, 16.653343588113785, 9.74567810073495, 2.772297039628029, 0.3746468044118956, 0.5906283727381378, 1.014817007817328, 0.6990394648164511, 0.5916245724074543, 0.29325956536922604, 1.2545664492063224, 1.3022436783649027, 2.4681995948776603, 3.149823881685734, 1.8182251160033047, 1.2194791319780052, 1.7490323726087809, 1.7749926983378828, 0.6497828266583383, 0.8400249027181417, 0.192732842406258, 0.12246652302565053, 0.5040430719964206, 0.7796605699695647, 1.1979813105426729, 1.1160471383482218, 0.09308102249633521, 1.0810562409460545, 23.07707939296961, 23.26411295682192, 37.396430522203445, 26.54405325651169, 16.74290858209133, 28.415027260780334, 25.61941087245941, 19.550203643739223, 22.88989383727312, 24.564604572951794, 21.892249770462513, 22.494057677686214, 26.99184212833643, 44.234148412942886, 61.27188317477703, 53.42512182891369, 64.68987196683884, 78.09785529971123, 78.01998227834702, 72.47489422559738, 74.00495812296867, 74.67614650726318, 74.71280694007874, 73.71912986040115, 69.32613238692284, 68.3501547574997, 70.32633751630783, 68.9361061155796, 70.43008714914322, 64.70511674880981, 51.633624359965324, 36.725610718131065, 26.44936043769121, 16.667725816369057, 21.929537169635296, 34.29819457232952, 33.251004964113235, 4.431194448843598, 2.7524986770004034, 1.1192538100294769, 0.9323463519103825, 0.8789939491543919, 0.7961373764555901, 0.958270876435563, 0.6390049424953759, 0.5460749322082847, 0.2599943394307047, 0.02947781998955179, 0.723960546310991, 0.3051015408709645, 0.19080272410064936, 0.32645817613229156, 0.31084896996617317, 0.1975824954570271, 0.23442310688551515, 0.18339623871725053, 0.18561024335213006, 0.15461036382475868, 0.2990913321264088, 0.05457635270431638, 0.21648934576660395, 0.020063671145180706, 0.1527965845889412, 0.1724393930635415, 0.22988687764154747, 0.20153814257355407, 0.40137608419172466, 0.05713992373785004, 0.19379129342269152, 0.04501359806454275, 0.11176743268151768, 0.22431848425185308, 0.27934209967497736, 0.291196305770427, 0.33684254391118884, 0.162464824388735, 0.33882113930303603, 0.16416253172792494, 0.18952979240566492, 0.35135939775500447, 0.22701316309394315, 0.20960977039067075, 0.28576268639881164, 0.16150855226442218, 0.13873885298380628, 0.1581145476666279, 0.21378752746386454, 0.3697299276245758, 0.46647463634144515, 0.18490630143787712, 0.24587826017523184, 0.09468030621064827, 0.39477637270465493, 0.2554330404382199, 0.34621616592630744, 0.6586121872533113, 0.7555692095775157, 1.0287560848519206, 1.1954878130927682, 1.2710146978497505, 0.4339884576620534, 0.7462303200736642, 0.8699196204543114, 0.5489886039867997, 0.855960357002914, 1.3709343736991286, 1.281439675949514, 0.6571479002013803, 5.290151182562113, 21.68131358921528, 52.08610787987709, 66.4672189950943, 102.55723401904106, 91.1135096848011, 67.52464145421982, 51.2723321467638, 46.47210672497749, 58.58743742108345, 80.83898261189461, 115.57943925261497, 114.03505012392998, 100.46316638588905, 94.68624517321587, 93.29882562160492, 105.04379779100418, 100.66783860325813, 90.46377494931221, 92.88343951106071, 101.94206222891808, 104.46439728140831, 94.71307173371315, 88.22105169296265, 84.47968885302544, 78.35232004523277, 63.90044912695885, 70.06277605891228, 66.47268310189247, 40.96457205712795, 27.148378528654575, 29.87514641135931, 31.264023184776306, 25.35714704543352, 27.845010347664356, 59.96498130261898, 42.21364103257656, 66.1899022758007, 32.538440600037575, 4.17287671007216, 29.365696348249912, 33.20767588913441, 9.603979904204607, 4.295545052736998, 0.17976225324673578, 0.7571149547584355, 1.5292876702733338, 1.0414411104284227, 0.7375203561969101, 0.33424119756091386, 1.051933178678155, 1.316340328194201, 1.1616204679012299, 2.538886251859367, 3.3351378003135324, 2.7847344847396016, 4.531290577724576, 3.181096203625202, 1.0161886154673994, 1.898995719384402, 0.7037086423952132, 0.8018048910889775, 0.36932988034095615, 0.5841172439977527, 0.6646763056050986, 0.8476186764892191, 1.3255719328299165, 9.035257771611214, 38.646753430366516, 43.78457173705101, 57.98065938055515, 56.44621431827545, 26.17258708924055, 28.123256117105484, 21.041918098926544, 19.028128758072853, 28.49951382726431, 27.067857049405575, 32.01388634741306, 35.62997750937939, 37.33471803367138, 44.324864745140076, 61.21021248400211, 61.638305112719536, 62.73673117160797, 71.0530637204647, 74.41934108734131, 73.12028959393501, 76.99182584881783, 82.01498910784721, 84.88419234752655, 86.20036572217941, 77.94147089123726, 73.75399678945541, 75.40827602148056, 73.36292177438736, 77.71498784422874, 73.33151265978813, 64.77657571434975, 55.29320798814297, 56.46398216485977, 47.23481319844723, 43.94825555384159, 43.56858752667904, 41.10424116253853, 13.659759722650051, 3.5165260545909405, 1.0602549696341157, 0.4034636862343177, 0.6214323698077351, 0.4040417302167043, 0.8946033928077668, 0.6163980555720627, 0.7254291081335396, 0.31649965269025415, 0.18617791210999712, 0.5111201922409236, 0.33267844235524535, 0.33081318775657564, 0.5216661700978875, 0.43240477389190346, 0.2750609169015661, 0.24363532662391663, 0.22203375294338912, 0.2718120615463704, 0.2810290310299024, 0.3138880053302273, 0.13506544462870806, 0.35160353465471417, 0.31595215550623834, 0.3928047535009682, 0.4710040823556483, 0.33017146750353277, 0.24261034646769986, 0.4057570412987843, 0.3432909760158509, 0.3774600487668067, 0.14909702294971794, 0.2234950862475671, 0.40608133014757186], [0.11777387131587602, 0.0974147641682066, 0.14421651139855385, 0.013633981052407762, 0.102749707584735, 0.11860763712320477, 0.08217689901357517, 0.0738817140518222, 0.03591529428376816, 0.06447050225688145, 0.0702698074746877, 0.0657340903126169, 0.04490729283133987, 0.0432966579683125, 0.05063273951236624, 0.06347215778077953, 0.08299102017190307, 0.12310778314713389, 0.060084231372457, 0.07714144187048078, 0.13763435912551358, 0.059622500484692864, 0.1464829858741723, 0.5901627195999026, 0.19652281247545034, 0.15341581776738167, 0.11955942667555064, 0.281483581638895, 0.23398313205689192, 0.5821705015841872, 1.4947630790993571, 0.7994966336991638, 0.20689294586190954, 0.4523502301890403, 0.4138162900926545, 0.2161907945992425, 0.42800027586054057, 3.155786474235356, 14.945228844881058, 16.281199157238007, 20.657927803695202, 24.119264669716358, 45.37241153419018, 51.19377516210079, 35.721206814050674, 22.138016782701015, 9.878155142068863, 32.78708405792713, 64.5196259021759, 72.36186549067497, 60.353423058986664, 63.34157511591911, 65.55244848132133, 78.75385209918022, 65.97511500120163, 72.80036196112633, 72.19469726085663, 70.49602881073952, 69.55155149102211, 56.504476591944695, 54.161598309874535, 49.22592535614967, 46.81528151035309, 45.96240967512131, 27.828585729002953, 26.78181029856205, 27.506013438105583, 26.439938843250275, 23.94481413066387, 23.52641098201275, 16.164978593587875, 28.95052682608366, 33.07719849050045, 61.51135012507439, 54.06722657382488, 20.796314477920532, 25.094269551336765, 23.68170864880085, 12.648524735122919, 6.543960878625512, 1.3537989556789398, 0.14379605505382642, 0.975465428782627, 0.03896376976626925, 0.05008891967008822, 0.8905773900914937, 0.4077079991111532, 0.035448453709250316, 0.066855668410426, 0.6873169750906527, 1.1043783207423985, 0.6257136713247746, 1.4345030626282096, 0.1578853724640794, 0.14162944396957755, 0.17186038428917527, 0.25257238768972456, 0.5051749956328422, 0.3246149484766647, 0.3055808792123571, 0.11057083829655312, 0.42958185193128884, 0.41622322343755513, 0.5937392776831985, 5.854569571092725, 11.532269082963467, 18.394400663673878, 46.06738664209843, 43.52861367166042, 16.608486995100975, 15.919919293373823, 13.241438269615173, 10.493061896413565, 10.314708016812801, 12.284333277493715, 16.6145533695817, 12.1442442946136, 16.771845929324627, 25.25284644216299, 32.45143286883831, 31.555948220193386, 31.769090183079243, 45.932094901800156, 59.83948543667793, 65.5219741165638, 67.69988805055618, 69.911437779665, 65.87464079260826, 63.529706820845604, 58.1006683409214, 53.228387385606766, 50.83093263208866, 43.508660942316055, 35.50045765936375, 23.012498058378696, 8.226365726441145, 7.302784435451031, 13.15408855676651, 10.48305133357644, 5.923222862184048, 2.2094104439020157, 2.048661019653082, 1.7025139625184238, 0.5521357257384807, 0.8773779077455401, 0.7553637831006199, 0.6971228832844645, 0.452218484133482, 0.30690380197484046, 0.13317823730176315, 0.34429364721290767, 0.5749291589017957, 0.560539806028828, 0.2424694868386723, 0.18238604214275256, 0.3232699097134173, 0.24683122232090682, 0.13968307262985036, 0.20114280050620437, 0.06536631160997786, 0.23381087958114222, 0.0653326626343187, 0.04875910235568881, 0.10840151837328449, 0.0797385505575221, 0.05316092494467739, 0.12106549664167687, 0.27957997284829617, 0.3054206643719226, 0.1950226500048302, 0.2777285815682262, 0.0908550173335243, 0.04524180847511161, 0.044000974667142145, 0.022555500618182123, 0.041658014451968484, 0.16373308055335656, 0.05832061389810406, 0.14284793171100318, 0.22391962440451607, 0.10162316451896913, 0.15978917421307415, 0.07746826144284569, 0.15360433812020347, 0.10740004945546389, 0.03970193210989237, 0.06342011096421629, 0.025628147850511596, 0.07170031938585453, 0.05368033183913212, 0.052475714837783016, 0.08091753377811983, 0.06347009461023845, 0.07524500222643837, 0.04829121164220851, 0.018404312431812286, 0.012972948261449346, 0.09623204794479534, 0.13529104267945513, 0.16567008598940447, 0.6010624940972775, 0.4843100777361542, 0.5278354953043163, 0.40130875655449927, 0.7800838316325098, 0.2462257634033449, 0.6578626774717122, 1.4270936977118254, 0.9874830557964742, 0.7997318648267537, 0.6924719922244549, 0.579341909615323, 0.5663721961900592, 8.308324478566647, 18.795254454016685, 32.22526900470257, 52.77108192443848, 66.79526299238205, 53.57741005718708, 37.4259739369154, 24.270494654774666, 26.998199187219143, 38.66300515830517, 43.65219064056873, 64.25111711025238, 85.38590982556343, 83.40762957930565, 78.42628687620163, 71.59832686185837, 87.21894666552544, 86.41177117824554, 81.65680512785912, 76.26823827624321, 77.73578032851219, 78.4277991950512, 73.90383034944534, 71.84996455907822, 67.54647508263588, 67.44923830032349, 55.060459077358246, 46.14850088953972, 37.191868498921394, 25.556032173335552, 25.947270579636097, 26.30262181162834, 29.874131865799427, 30.569629445672035, 40.42141020298004, 46.58999539911747, 69.84691724181175, 62.763420939445496, 12.863268312066793, 12.276866678148508, 25.06450954824686, 19.0445913746953, 6.080792807042599, 1.5419090492650867, 0.23672719340538606, 0.20936235319823027, 0.024984635310829617, 0.18177896534325555, 0.35883107339031994, 0.40711606212425977, 0.1597690471680835, 0.6123738340102136, 1.7074655718170106, 1.7546636704355478, 1.2669566343538463, 2.4601625511422753, 3.2740254420787096, 0.054950550984358415, 0.1631156136863865, 0.22344692086335272, 0.5548614263534546, 0.34121744509320706, 0.5407305189874023, 1.0846350551582873, 0.4309388838009909, 1.1622004117816687, 10.411410927772522, 25.755116790533066, 30.903572626411915, 26.244551427662373, 53.62988144159317, 27.46388889849186, 14.03497438877821, 15.11275615543127, 17.714683637022972, 17.825100012123585, 17.343850135803223, 21.925404891371727, 24.508094005286694, 23.44845436513424, 30.751056410372257, 51.318324878811836, 57.402812987565994, 45.54212562739849, 47.41751879453659, 61.09785631299019, 76.71658381819725, 80.46490788459778, 85.40383726358414, 88.2892732322216, 76.93727597594261, 77.05418810248375, 74.39184576272964, 70.1229876279831, 61.43827244639397, 50.70728346705437, 44.89030860364437, 37.097033187747, 20.663959980010986, 5.335640916600823, 9.612957872450352, 16.510440856218338, 22.251028418540955, 8.595825601369143, 0.58818842866458, 0.9014141710940748, 0.3612135158618912, 1.207431759685278, 1.022019877564162, 1.0459682112559676, 0.7657897111494094, 0.7312400650698692, 0.35120675282087177, 0.28760612185578793, 0.6835571362171322, 0.8294959645718336, 0.4118654510239139, 0.28538938611745834, 0.3028864675434306, 0.09648575854953378, 0.14341137022711337, 0.0937508256174624, 0.19437111855950207, 0.24760975007666275, 0.03689448021759745, 0.09562918654410169, 0.22662246687104926, 0.12986057001398876, 0.06865168063086458, 0.03275762661360204, 0.07232790172565728, 0.07167871546698734, 0.1813238803879358, 0.18409724172670394, 0.0651166753959842, 0.043939246534137055, 0.04644051055947784, 0.06762100078049116, 0.02510436414013384, 0.34205277683213353, 0.1298273663269356, 0.14852263033390045, 0.30674257781356573, 0.19559184758691117, 0.31931797333527356, 0.15357085241703317, 0.19524389907019213, 0.14616334286984056, 0.12956789665622637, 0.17342775565339252, 0.2366973293828778, 0.1596310522290878, 0.1463262888137251, 0.10356674538343213, 0.13054909009952098, 0.21851220284588635, 0.18314279528567567, 0.2402917732251808, 0.13089999236399308, 0.16094359976705164, 0.22082448267610744, 0.32087823492474854, 0.4855603590840474, 0.9065175941213965, 0.5746331310365349, 1.0721774236299098, 1.1207807343453169, 1.2282586796209216, 0.7811954501084983, 1.285994325298816, 1.0573462257161736, 0.7301495829597116, 0.5058165674563497, 0.9621435811277479, 1.2291884422302246, 0.3539605066180229, 5.125471819192171, 16.955951750278473, 42.87085756659508, 61.77773483097553, 80.41473537683487, 65.26541948318481, 63.33123207092285, 50.39687052369118, 54.208727180957794, 55.48152968287468, 65.2919952571392, 105.66162943840027, 114.30019229650497, 94.49805647134781, 81.07963129878044, 77.32926294207573, 92.51982182264328, 86.85839161276817, 85.39177671074867, 88.5176333785057, 92.55012139678001, 87.54304647445679, 72.1159502863884, 67.10476398468018, 62.9970970004797, 69.90845113992691, 53.80902662873268, 40.50503231585026, 36.20051309466362, 31.46254163235426, 29.60332229733467, 27.08885282278061, 28.96567091345787, 23.526580072939396, 29.77088950574398, 44.064058139920235, 82.03657194972038, 69.06368806958199, 35.782364532351494, 30.016724914312363, 36.97168551385403, 26.553406454622746, 11.481934133917093, 3.50534800440073, 0.21555947925662622, 0.7793681044131517, 0.2038026726222597, 0.21313062286935747, 1.0390777559950948, 0.35340992209967226, 0.1733459858223796, 0.3321267000865191, 2.7343472884967923, 2.313077668659389, 2.195594860240817, 2.823001518845558, 4.208356831222773, 0.08776288872468285, 0.19670643465360627, 0.32278009224683046, 0.6589190801605582, 0.2651851577684283, 0.4162621119758114, 0.7890286110341549, 1.6885042330250144, 4.917971603572369, 22.45899125933647, 27.880012169480324, 25.679928325116634, 27.03392866998911, 68.92599865794182, 56.5777138620615, 18.332819268107414, 15.633164830505848, 17.337532974779606, 20.26176106184721, 25.31317390501499, 33.76396603882313, 42.670908495783806, 47.5880042463541, 55.139126256108284, 62.07342356443405, 56.5028540790081, 56.58848248422146, 56.57425984740257, 64.60501492023468, 81.37120485305786, 83.8608692586422, 87.17928439378738, 88.52626651525497, 83.21598306298256, 82.2573933005333, 77.6598148047924, 73.73809844255447, 72.56602093577385, 64.55878660082817, 60.70199355483055, 55.55438317358494, 58.34421627223492, 42.045914232730865, 26.636236310005188, 22.303600497543812, 26.00393883883953, 12.982488814741373, 2.6253527496010065, 1.4012536592781544, 0.29587646713480353, 0.7882538682315499, 0.7503889000508934, 0.7946445909328759, 0.5042246903758496, 0.8132057043258101, 0.38633396790828556, 0.23464831901947036, 0.5716001812834293, 0.8752674772404134, 0.3417349001392722, 0.49419438641052693, 0.4099972278345376, 0.2116196695715189, 0.19415458955336362, 0.18208061868790537, 0.21884783171117306, 0.23647507099667564, 0.23168893094407395, 0.17620052327401936, 0.4753189586335793, 0.25411088950932026, 0.2563446946442127, 0.30128072714433074, 0.4488939297152683, 0.4947466333396733, 0.35847543622367084, 0.31510554312262684, 0.1771654636831954, 0.1453641091939062, 0.1503310661064461, 0.15975469403201714, 0.16376707091694698], [0.23141311918152496, 0.11088532337453216, 0.03490743547445163, 0.07694861706113443, 0.09201474182191305, 0.049139000329887494, 0.21336767968023196, 0.1327015706920065, 0.05010471257264726, 0.13105839636409655, 0.07867345731938258, 0.15687005507061258, 0.09962837546481751, 0.09743619739310816, 0.0817915091465693, 0.06216070491063874, 0.07195838639745489, 0.11512989600305445, 0.010100552881340263, 0.06340667066979222, 0.00791082575233304, 0.19873551093041897, 0.23785831552231684, 0.2398288215044886, 0.4543753433972597, 0.14033886400284246, 0.07412113089230843, 0.24773886892944574, 0.24960700306110084, 0.15687101986259222, 0.35270413965918124, 0.710771691519767, 0.4677795694442466, 0.1779563704621978, 0.3093223721953109, 0.22905760182766244, 0.18316361994948238, 0.11628173146164045, 2.2245257953181863, 11.808659601956606, 12.687024269253016, 15.013042856007814, 20.111023150384426, 31.86429787427187, 37.83637851476669, 25.40120378136635, 19.98376987874508, 17.016245014965534, 31.38825561851263, 47.07058601081371, 59.41613495349884, 54.65191259980202, 55.78594654798508, 66.98789745569229, 62.7549359947443, 54.62381690740585, 69.8499646782875, 73.81867691874504, 63.41918595135212, 55.46260289847851, 42.80670940876007, 41.67910471558571, 41.34759150445461, 22.622893564403057, 20.490242801606655, 19.621235132217407, 27.2917353361845, 24.099642522633076, 20.037899874150753, 23.749671801924706, 24.770692214369774, 27.790494672954082, 40.13799861073494, 53.32065783441067, 59.893347546458244, 46.28651708364487, 35.643379390239716, 25.55328492075205, 23.87541275471449, 9.139437731355429, 3.0973942950367928, 1.3856423157267272, 2.013988592661917, 0.4298219515476376, 0.34003339300397784, 0.16039602836826816, 0.0667098438134417, 0.4894154006615281, 0.9585955808870494, 0.5970298417378217, 0.4312005947576836, 0.4797442664857954, 0.6935749424155802, 0.1877704868093133, 0.43485311907716095, 0.2616770553868264, 0.1442372173187323, 0.34477132314350456, 0.3475848346715793, 1.1998268240131438, 1.0551377129741013, 1.5518913511186838, 2.248799605295062, 5.552877634763718, 6.604202371090651, 15.277298726141453, 30.329212546348572, 49.56476837396622, 64.2531917989254, 69.30573508143425, 60.00964790582657, 32.877333015203476, 23.90280358493328, 20.003456622362137, 14.57996679469943, 9.30478585883975, 6.276614349335432, 10.992690436542034, 13.93246728926897, 14.943811520934105, 28.262421749532223, 31.135325990617275, 33.15531849861145, 38.27416442334652, 44.828219935297966, 50.58409407734871, 47.14593596756458, 48.955550864338875, 43.102873116731644, 42.23134808242321, 44.24533121287823, 44.971517845988274, 34.431267231702805, 16.654561422765255, 4.868865888565779, 6.585652716457844, 4.774003503844142, 4.879029868170619, 4.9762609507888556, 4.122415417805314, 2.928861938416958, 1.5109728905372322, 0.4227765358518809, 1.129808456171304, 1.3644664082676172, 1.2777488864958286, 1.0949517390690744, 1.021930226124823, 0.9019007231108844, 0.8860129443928599, 0.5355242639780045, 0.299104928271845, 0.06109290283347946, 0.16604629548965022, 0.1954378222580999, 0.24766325892414898, 0.1904134824872017, 0.1987954616197385, 0.3099613910308108, 0.5543837801087648, 0.5644753854721785, 0.3190376196289435, 0.26893330039456487, 0.24069352744845673, 0.15565135952783749, 0.13743920397246256, 0.13277407852001488, 0.14584082033252344, 0.039161017775768414, 0.45051884721033275, 0.38044012791942805, 0.22077351197367534, 0.042681803461164236, 0.07731961668469012, 0.05330808169674128, 0.03827219574304763, 0.33067820593714714, 0.29156355012673885, 0.09941257376340218, 0.11439359645009972, 0.1602718819049187, 0.08446018313406967, 0.48064986476674676, 0.2537451888201758, 0.1166852519963868, 0.2090430515818298, 0.04995330702513456, 0.21768300124676898, 0.11152665771078318, 0.05004233134968672, 0.051065137013210915, 0.08715033487533219, 0.037695461651310325, 0.05251216542092152, 0.050415230871294625, 0.15286610898328945, 0.06301879460806958, 0.03252435846661683, 0.13360694632865489, 0.11208012176211923, 0.1493402395863086, 0.22368330974131823, 0.41853222297504544, 0.29165242973249406, 0.3743079397827387, 0.5336464522406459, 0.08843363437335938, 0.4803767247358337, 0.6615801248699427, 0.4676592524629086, 0.5929393018595874, 0.7175323599949479, 0.5448481917846948, 0.13581789331510663, 5.2302193734794855, 14.142925646156073, 24.223228991031647, 39.45937782526016, 40.25446996092796, 37.71445445716381, 33.41593511402607, 23.8360183686018, 25.779821164906025, 37.39717148244381, 36.898349449038506, 46.94610469043255, 67.90943160653114, 76.83677136898041, 76.99868068099022, 77.84794270992279, 78.0800798535347, 78.1530511379242, 80.30726954340935, 84.65709373354912, 83.35851341485977, 75.8410196006298, 58.823731541633606, 45.22258177399635, 55.5671276897192, 58.17407660186291, 41.91504925489426, 35.143634006381035, 29.917605333030224, 30.327039062976837, 27.027117535471916, 33.881512731313705, 27.18734733760357, 27.5010110065341, 48.82663898169994, 57.00482614338398, 60.442418083548546, 44.56240899860859, 24.94790520519018, 24.40375540405512, 26.474232003092766, 8.004664722830057, 2.2945992602035403, 0.5898204410914332, 1.0403557936660945, 0.20025768550112844, 0.06300408524111845, 0.12201081466628239, 0.18373611266724765, 0.37748186790850013, 0.8926399075426161, 1.5314786089584231, 0.5824370216578245, 0.5081053508911282, 0.8326600072905421, 0.6781791779212654, 0.42189988133031875, 0.5675462738145143, 0.5439083359669894, 0.4479836410610005, 0.7796020293608308, 1.335916758980602, 0.08685638502356596, 0.6005758827086538, 3.2364433212205768, 9.61887700483203, 16.970573365688324, 25.010675936937332, 29.20196123421192, 63.86060446500778, 75.86881890892982, 57.85124972462654, 36.28362603485584, 20.811855643987656, 17.12083440274, 17.561093978583813, 14.788083527237177, 19.15699504315853, 15.204165950417519, 20.267992727458477, 22.82870002090931, 35.738400891423225, 53.21274742484093, 54.62277576327324, 58.96848477423191, 63.49388614296913, 66.6759341955185, 69.92457747459412, 66.28887176513672, 65.4732683300972, 55.62091760337353, 50.61429105699062, 55.505878776311874, 57.08465985953808, 55.20099073648453, 34.74642612040043, 12.958980426192284, 3.7576615903526545, 5.695443134754896, 10.368278492242098, 15.467079542577267, 4.307928113266826, 1.761791375465691, 1.1103297513909638, 0.45739445951767266, 1.5480074845254421, 1.001702486537397, 1.2793191522359848, 1.0976947168819606, 1.1356689292006195, 0.8148297015577555, 0.7010021188762039, 0.7360745931509882, 0.6126914138440043, 0.25486182421445847, 0.34252442652359605, 0.03772822747123428, 0.11766001101932488, 0.4498249391326681, 0.2591968869091943, 0.25387117580976337, 0.41905056859832257, 0.23763636883813888, 0.17709090752759948, 0.28990597813390195, 0.16657382890116423, 0.13672447123099118, 0.12933919642819092, 0.04082272724190261, 0.06416939068003558, 0.30642389960121363, 0.06676944569335319, 0.11081804026616737, 0.11938006442505866, 0.032763667695689946, 0.06766820137272589, 0.08295929335872643, 0.16640274901874363, 0.35884021664969623, 0.4557613783981651, 0.1616214626119472, 0.1288294597179629, 0.179184120206628, 0.20562526857247576, 0.48608526529278606, 0.27708605979569256, 0.15340061858296394, 0.3326895151985809, 0.1572509846300818, 0.20571171393385157, 0.13006613007746637, 0.23020810884190723, 0.12037412670906633, 0.1809396260068752, 0.3399515786441043, 0.16688238421920687, 0.15133792301639915, 0.2435987239005044, 0.1377159359981306, 0.34068369248416275, 0.3867853421252221, 0.28809160517994314, 0.5139163671992719, 0.40065801178570837, 0.5281330668367445, 0.9532039077021182, 2.0690903859212995, 0.7878004456870258, 0.3795683418866247, 0.7896553992759436, 0.6777442200109363, 0.38362008228432387, 0.5364712444134057, 0.9054296056274325, 1.3631968013942242, 0.30521737528033555, 3.4393783193081617, 13.881926201283932, 29.60711069405079, 43.68031673133373, 48.1290952116251, 51.692844182252884, 55.470601469278336, 46.94848716259003, 61.54618285596371, 62.42251083254814, 56.43255405128002, 81.0638165473938, 99.92247059941292, 92.35326915979385, 79.23066571354866, 84.78827029466629, 82.97277331352234, 76.79958656430244, 78.18299353122711, 89.0148138999939, 93.72572511434555, 77.00330123305321, 61.26629367470741, 49.889278560876846, 56.09342984855175, 55.66883683204651, 46.499841436743736, 39.125299751758575, 33.89508560299873, 36.18277944624424, 29.644375294446945, 34.95728440582752, 28.579206950962543, 32.676183208823204, 50.43272539973259, 65.70475950837135, 62.22393348813057, 61.76989205181599, 40.32724745571613, 26.310532987117767, 42.630174681544304, 27.388396449387074, 11.416882574558258, 3.584647374227643, 2.1848772978410125, 0.16822288103867322, 0.2315779056516476, 0.2271744911558926, 0.2708381263073534, 0.5255809100344777, 1.7997252149507403, 3.299693064764142, 1.9373564422130585, 1.5271342545747757, 2.1707551181316376, 0.5126358952838928, 0.6939409102778882, 0.4490928549785167, 0.5083487159572542, 0.620305611519143, 0.8521564642433077, 2.542787929996848, 2.2370271245017648, 1.271237579640001, 6.401184964925051, 10.78295024111867, 24.928167164325714, 38.542194440960884, 41.29227787256241, 79.4994404911995, 79.24986988306046, 91.03502109646797, 70.64377248287201, 41.06438510119915, 37.59453669190407, 30.359230935573578, 32.40686506032944, 37.007741779088974, 34.83698286116123, 38.234851732850075, 43.513068705797195, 50.771055445075035, 58.85561183094978, 60.19906014204025, 61.09638959169388, 69.04242441058159, 68.5212367773056, 77.13665127754211, 74.93222236633301, 75.57691857218742, 66.85334667563438, 61.29571549594402, 65.48714518547058, 65.4678650200367, 68.98922726511955, 64.94018733501434, 54.117083698511124, 30.10822780430317, 16.568306051194668, 13.488362319767475, 20.58823574334383, 10.498538352549076, 3.2272411650046706, 1.881697503849864, 0.2723485749447718, 1.0657273884862661, 1.0710590961389244, 1.381161049939692, 1.150875713210553, 1.0895413043908775, 0.9565027838107198, 0.8243729488458484, 0.7818709826096892, 0.9127930167596787, 0.29403650492895395, 0.5183937738183886, 0.5254806310404092, 0.2958732016850263, 0.44920664106030017, 0.33815273141954094, 0.5058641836512834, 0.5164267856162041, 0.44350077223498374, 0.399535647011362, 0.3708348667714745, 0.3916188608855009, 0.3592640720307827, 0.2767874195706099, 0.44148503977339715, 0.2546729921596125, 0.32116776157636195, 0.6329233688302338, 0.47080634452868253, 0.3276672534411773, 0.16433018288807943, 0.2284774204599671, 0.21546758653130382, 0.328303036512807], [0.15261324442690238, 0.21103736566146836, 0.02482429801602848, 0.04893888391961809, 0.2276720863301307, 0.0478848932107212, 0.05654758970194962, 0.06437638308852911, 0.15194495528703555, 0.2885559224523604, 0.16690026997821406, 0.10859392757993191, 0.02491997383913258, 0.19613643555203453, 0.06847315700724721, 0.05344758690625895, 0.14230083528673276, 0.07049059640849009, 0.0642565633461345, 0.25771173066459596, 0.1945408180472441, 0.02714252801524708, 0.1444727007765323, 0.153936953865923, 0.14707300812005997, 0.09195675040245987, 0.026325174803787377, 0.17152597254607826, 0.44312304875347763, 0.5331561004277319, 0.1657595147844404, 0.34755868138745427, 1.0264878440648317, 0.38370718073565513, 0.3731642011553049, 0.5952365160919726, 0.15660257020499557, 0.4470047482755035, 0.5294672108720988, 0.20983780268579721, 3.894472299143672, 8.203199319541454, 11.967764664441347, 11.33974576368928, 19.340703785419464, 24.835794121026993, 18.26662492007017, 16.156765334308147, 12.5243179500103, 21.193298175930977, 34.1327590495348, 42.094304636120796, 44.17116679251194, 46.856456100940704, 51.6256295889616, 48.002702593803406, 41.64506994187832, 48.19075830280781, 51.48077376186848, 43.160945400595665, 33.88932891190052, 32.45852708816528, 27.857990451157093, 25.290536619722843, 23.791422061622143, 19.15043469518423, 12.65857519581914, 9.413084797561169, 19.61753223091364, 31.15724701434374, 51.423609629273415, 57.99575977027416, 53.88890974223614, 43.9440605789423, 44.068321511149406, 22.33666632324457, 32.46722102165222, 18.68426240980625, 37.365473583340645, 30.826963037252426, 18.466182611882687, 7.367755249142647, 6.65160957723856, 4.220197470858693, 0.7364147342741489, 0.4352897097123787, 0.591481605079025, 0.5067781533580273, 0.6411001144442707, 0.09447145101148635, 0.8078490011394024, 1.111851332243532, 2.2774417558684945, 0.9479657106567174, 1.0111587541177869, 0.8319343056064099, 0.2479757327819243, 0.747643606737256, 3.2401937199756503, 1.6252004611305892, 3.370912643149495, 6.282045682892203, 3.3556968346238136, 6.86041122302413, 22.099965624511242, 37.355825901031494, 25.766056403517723, 45.782740116119385, 70.6027726829052, 77.89741605520248, 65.75696870684624, 43.51545877754688, 39.259158968925476, 35.95330595970154, 22.95977968722582, 14.492285549640656, 14.841618854552507, 19.425572231411934, 23.667544908821583, 23.410445004701614, 18.062247186899185, 23.26226245611906, 29.860146716237068, 29.613975025713444, 27.119576074182987, 33.307181149721146, 38.37067164480686, 43.05945664644241, 49.752280712127686, 55.04488751292229, 47.88454793393612, 31.399974189698696, 14.02357880026102, 1.4804313168860972, 4.185881512239575, 5.062151066958904, 9.184824395924807, 1.5680140047334135, 1.0274026449769735, 0.7176499161869287, 0.8214571396820247, 1.9940047524869442, 2.388173514045775, 2.5655444338917732, 2.1840453799813986, 2.085017943754792, 1.43600944429636, 0.9546790004242212, 0.5071182944811881, 0.038896664773346856, 0.30872434959746897, 0.31030497571919113, 0.397783376974985, 0.2828763553407043, 0.19379077391931787, 0.08480847303871997, 0.550961826229468, 0.637660170905292, 0.4351232905173674, 0.36008019698783755, 0.1303045524400659, 0.09684385964646935, 0.15230455552227795, 0.17857205617474392, 0.16083949129097164, 0.09154629078693688, 0.14121148124104366, 0.2204987985896878, 0.13853976444806904, 0.08107328831101768, 0.10538012385950424, 0.20267603307729587, 0.4427493328694254, 0.06111633985710796, 0.38653262599837035, 0.19028428941965103, 0.12329904202488251, 0.11724244905053638, 0.15342893893830478, 0.11812119642854668, 0.10321441077394411, 0.0340309071179945, 0.16300675546517596, 0.09348478051833808, 0.07079107715981081, 0.03530296678945888, 0.14616387721616775, 0.05687200842658058, 0.05628775637887884, 0.10675068508135155, 0.036266259630792774, 0.14342029084218666, 0.28269672591704875, 0.20606098347343504, 0.06303567104623653, 0.16859364317497239, 0.23778744041919708, 0.07110363265383057, 0.05692586237273645, 0.09307918939157389, 0.06916747326613404, 0.20839295990299433, 0.11630858978605829, 0.12846451601944864, 0.2236545440973714, 0.47938272182364017, 1.0236039175651968, 0.28999093919992447, 0.6294917373452336, 0.4682100150967017, 0.44836127548478544, 0.618549749488011, 0.31114505720324814, 0.28609718719962984, 0.28514385398011655, 2.1094435080885887, 7.456869492307305, 16.368529871106148, 24.302753023803234, 28.498170599341393, 25.83749257028103, 26.350484043359756, 17.08433546125889, 18.004047609865665, 32.82638914883137, 38.20422537624836, 44.40808027982712, 49.0565038472414, 62.14517891407013, 66.72692745923996, 59.254617020487785, 67.24826708436012, 75.55544972419739, 70.08273258805275, 63.05130869150162, 58.58939811587334, 53.610700070858, 59.376024305820465, 48.52811940014362, 31.6473276168108, 27.063268795609474, 26.971651911735535, 33.21382775902748, 27.50030044466257, 27.52972986549139, 26.806864254176617, 34.46317411959171, 52.30286344885826, 64.22036916017532, 56.77961602807045, 60.171097442507744, 47.01064042747021, 39.24009919166565, 29.531430155038834, 35.01982904970646, 21.129849180579185, 8.8779984600842, 6.262997779995203, 7.634422089904547, 3.869785498827696, 1.0127924289554358, 0.11743021983420476, 0.36495218868367374, 0.2637079870328307, 0.5194892431609333, 0.0617742018221179, 0.32509324781131, 1.7987266997806728, 0.9515632269904017, 0.5340839037671685, 0.3672902804100886, 1.0051283589564264, 0.8363936038222164, 1.1472895368933678, 3.632946819998324, 3.639205084182322, 5.948682921007276, 1.2183655542321503, 4.040017789229751, 6.909326948225498, 23.56157809495926, 52.20856010913849, 53.309148252010345, 64.24722611904144, 81.64196312427521, 99.87219169735909, 87.998748421669, 68.29667642712593, 38.51061813533306, 24.13539670407772, 21.176662668585777, 17.00300082564354, 15.806263592094183, 12.672200314700603, 19.00325909256935, 19.788146875798702, 20.862938202917576, 31.295886375010014, 36.19825221598148, 41.602721214294434, 41.41269341111183, 42.388218864798546, 47.833600267767906, 49.969978630542755, 56.54643394052982, 62.71584369242191, 62.02456958591938, 49.16453965008259, 24.440600126981735, 8.228649403899908, 5.663167666643858, 4.1912145260721445, 11.745722629129887, 12.032485641539097, 1.771779377013445, 0.8615005190949887, 0.7656594493892044, 0.9852284111548215, 1.462191583123058, 1.5288451127707958, 1.6810166160576046, 1.379251889884472, 1.295721447095275, 1.4116376708261669, 0.7815024023875594, 0.627848266158253, 0.32788692915346473, 0.41439136548433453, 0.3987326135393232, 0.33863646327517927, 0.31862480740528554, 0.34168547310400754, 0.4781099682440981, 0.6250625406391919, 0.4599761834833771, 0.25336473423521966, 0.19697693263879046, 0.06323927926132455, 0.11701237584929913, 0.18478895304724574, 0.08535259345080703, 0.21817715285578743, 0.2185686951270327, 0.24211585347075015, 0.22578158386750147, 0.0748708558967337, 0.23299491789657623, 0.15123846038477495, 0.10178154625464231, 0.02954005463834619, 0.2773220924427733, 0.08157555901561864, 0.2780650119530037, 0.35531379806343466, 0.18898284441092983, 0.4054977052146569, 0.26227068447042257, 0.09156377578619868, 0.2537238149670884, 0.19511691760271788, 0.29710017959587276, 0.2668821526458487, 0.1587373431539163, 0.1278669387102127, 0.199418761767447, 0.17685573577182367, 0.151124689145945, 0.2156221165205352, 0.2977112343069166, 0.2218272429308854, 0.11862377141369507, 0.16768987057730556, 0.2486580188269727, 0.257417454267852, 0.29827114020008594, 0.334568900289014, 0.2000839338870719, 0.20155305974185467, 0.32688790932297707, 0.3747583937365562, 0.8613707916811109, 1.4954464486800134, 1.0111904586665332, 0.46137391473166645, 0.9153685066848993, 0.38327682414092124, 0.42874200793448836, 1.2348299520090222, 0.3306912974221632, 0.5067794001661241, 0.3463523054961115, 1.253333177883178, 5.353262471035123, 16.63677267730236, 26.381222493946552, 31.101576201617718, 31.582145914435387, 43.593065813183784, 33.387451842427254, 43.11667777597904, 58.5428012162447, 52.7699875831604, 68.13067093491554, 80.40199846029282, 86.56104236841202, 80.30376613140106, 75.92615023255348, 77.66022518277168, 75.78848361968994, 71.62847444415092, 71.44187405705452, 64.04676407575607, 57.638400346040726, 58.298398330807686, 50.925399363040924, 38.81868660449982, 27.72212114185095, 28.895952254533768, 37.51171253621578, 35.595178976655006, 41.98144689202309, 44.45765241980553, 65.89298620820045, 80.76750084757805, 78.13374817371368, 63.87678399682045, 64.95360061526299, 37.60764978826046, 35.70449911057949, 30.040593333542347, 45.23872330784798, 45.65971791744232, 30.633367225527763, 16.829281747341156, 9.14262006059289, 5.3785795625299215, 1.222808703314513, 0.3299273899756372, 0.46078058250714093, 0.41241927130613476, 0.5725642608013004, 1.3826411892659962, 2.609788072295487, 2.9875514516606927, 2.6426653331145644, 0.8615756244398654, 0.9121908678207546, 1.4429989317432046, 0.6487180525436997, 3.4173333272337914, 9.485247675329447, 6.5599252469837666, 14.19684475287795, 11.809754893183708, 8.637283276766539, 26.38368096202612, 53.64121623337269, 57.55141541361809, 51.08311370015144, 63.215421885252, 93.65590006113052, 112.95971542596817, 105.74335545301437, 94.18072789907455, 75.5445671081543, 80.75012817978859, 66.27409815788269, 58.12710352241993, 53.94852854311466, 56.01559482514858, 52.63691872358322, 55.898245722055435, 53.06345343589783, 54.68444265425205, 56.91119536757469, 55.986682176589966, 57.3415906727314, 55.99568389356136, 59.696814492344856, 61.86895273625851, 67.33011469244957, 76.72240510582924, 83.74344035983086, 82.4655233323574, 68.69669616222382, 43.07912439107895, 16.735217794775963, 5.555919371545315, 14.987725764513016, 18.650847002863884, 7.575586996972561, 3.9631153782829642, 1.7464888840913773, 1.254865920636803, 1.5350820031017065, 1.5322709851898253, 1.6678190929815173, 2.0173184014856815, 1.138087974395603, 1.345712870825082, 0.7625775178894401, 0.7111334439832717, 0.9046696464065462, 0.7961754931602627, 1.022987044416368, 0.9617928718216717, 0.6855205027386546, 0.40359412610996515, 0.5818133801221848, 0.8360095869284123, 0.6097040022723377, 0.420154498424381, 0.34156275156419724, 0.23166142695117742, 0.2823555457871407, 0.19325605651829392, 0.23297765554161742, 0.389052247046493, 0.2609564003068954, 0.31253993860445917, 0.3286657092394307, 0.10914314654655755, 0.31705065281130373, 0.2920302125858143, 0.3571191168157384, 0.0900904271111358, 0.48595378641039133, 0.23428696731571108], [0.25936574034858495, 0.45303416380193084, 0.4105094581609592, 0.35954748338554054, 0.3938754351111129, 0.3167338151251897, 0.3949692420428619, 0.4495335422689095, 0.3870059677865356, 0.18223802821012214, 0.06642646956606768, 0.2878437872277573, 0.24401003698585555, 0.40354585682507604, 0.06432580572436564, 0.300586789380759, 0.16655598767101765, 0.02834338418324478, 0.07178481289884076, 0.1520411524688825, 0.12497689691372216, 0.2570652309805155, 0.38181651500053704, 0.09408471785718575, 0.3428021678701043, 0.23241012037033215, 0.07008430766290985, 0.23968061461346224, 0.17183666524942964, 0.3216485248412937, 0.8057648129761219, 0.7021697249729186, 0.20955822081305087, 0.09624063459341414, 0.5827570357359946, 0.8275998663157225, 0.2008381488849409, 0.21191908163018525, 0.4550561896758154, 0.2176275331294164, 0.27528317528776824, 3.7222869135439396, 4.905375754460692, 9.024062622338533, 14.238402172923088, 11.95314209908247, 19.128975346684456, 13.111368399113417, 10.651744231581688, 11.71103049069643, 14.079936426132917, 21.983051598072052, 29.09046571701765, 32.076176404953, 30.318614915013313, 37.04023003578186, 47.72507429122925, 36.48456685245037, 32.15285249054432, 34.28039252758026, 45.79574301838875, 51.331228986382484, 39.82717528939247, 28.66990428417921, 15.104794632643461, 14.315766021609306, 6.4381009340286255, 16.692910864949226, 37.850107178092, 56.61653257906437, 58.83723221719265, 57.13005602359772, 50.572272911667824, 44.50319677591324, 25.82074496895075, 21.18981186300516, 30.713691115379333, 41.22244521975517, 53.67102563381195, 49.209643229842186, 55.31685031950474, 34.15583521127701, 6.464384123682976, 4.952531699091196, 0.7137320889160037, 0.645689555676654, 0.06697060482110828, 0.7455467130057514, 0.8192328934092075, 1.254311625380069, 2.079954477958381, 1.6606684704311192, 0.6202883343212306, 0.4866574314655736, 1.5034628310240805, 0.43344473058823496, 1.639628999400884, 1.3741910364478827, 2.5420006597414613, 1.4803424966521561, 1.7581629264168441, 6.843124525621533, 11.624826416373253, 12.2019774466753, 24.155613519251347, 49.79759328067303, 45.24279288947582, 54.4233662635088, 76.39493107795715, 91.06340557336807, 85.41081368923187, 70.99384009838104, 44.8802999407053, 18.731189891695976, 9.20130506157875, 10.354204997420311, 7.27686507627368, 1.997166657820344, 17.798020765185356, 17.67829678952694, 30.429893843829632, 33.74710254371166, 37.958997935056686, 48.97080324590206, 58.10477212071419, 58.933887630701065, 54.64206352829933, 48.168263509869576, 36.18329621851444, 23.718104995787144, 12.635819166898727, 5.431031947955489, 7.544918367639184, 9.482973497360945, 7.331678560003638, 0.9672433824744076, 4.381867870688438, 1.4459165814332664, 2.3088100226596, 2.5040364218875766, 2.3324105562642217, 0.9996666270308197, 0.969408672535792, 2.2422359324991703, 2.2733135148882866, 1.2239481671713293, 0.8429530018474907, 1.0512570524588227, 0.4034329019486904, 0.5393073172308505, 0.7981375535018742, 0.6150100019294769, 0.3289617074187845, 0.19354265910806134, 0.2919367316644639, 0.5808922264259309, 0.08763057121541351, 0.15515054343268275, 0.012277323967282427, 0.18311965512111783, 0.24936319270636886, 0.26740376371890306, 0.0878565403399989, 0.11821518943179399, 0.06506661011371762, 0.13509870768757537, 0.17353196803014725, 0.3234901197720319, 0.2801290136994794, 0.21888882794883102, 0.0789986144809518, 0.17846702743554488, 0.056895541929407045, 0.14331233804114163, 0.05088204547064379, 0.12799812073353678, 0.08883554444764741, 0.12743278231937438, 0.26511180389206856, 0.491516895708628, 0.31727148627396673, 0.5733267136383802, 0.5744210549164563, 0.2602430776460096, 0.05740520813560579, 0.147827698092442, 0.09441645044717006, 0.177808178414125, 0.09175442610285245, 0.11543912667548284, 0.20103814284084365, 0.15030927665065974, 0.20538289798423648, 0.13487374788383022, 0.130139647226315, 0.07723896749666892, 0.036858319072052836, 0.1066072576213628, 0.17694586218567565, 0.05826056301884819, 0.18201486440375447, 0.059535446562222205, 0.08920224703615531, 0.23901072243461385, 0.11121515606646426, 0.383419138379395, 0.5433044652454555, 0.23621488886419684, 0.2183667864301242, 0.08804615164990537, 0.6178947002626956, 0.7545230782125145, 0.30263761058449745, 0.2267902813036926, 0.6932340888306499, 0.3139287937665358, 0.4755476291757077, 5.394370565190911, 8.828229680657387, 14.576177448034286, 23.82523264735937, 21.451608315110207, 12.784721776843071, 16.001095287501812, 16.519011296331882, 24.337163977324963, 29.73307393491268, 32.479494363069534, 36.479528322815895, 46.93386934697628, 54.32816997170448, 52.583421394228935, 55.57475008070469, 51.98159068822861, 49.43430617451668, 46.61228120326996, 53.11652898788452, 37.975777834653854, 20.899467542767525, 13.794770278036594, 24.94508195668459, 26.422974653542042, 31.77863147109747, 33.258695751428604, 34.98640604317188, 47.366764917969704, 55.24094179272652, 71.93365126848221, 65.76883167028427, 60.748457461595535, 52.551066130399704, 31.355915553867817, 49.759329333901405, 41.737944558262825, 50.94039335846901, 49.27202448248863, 44.48547452688217, 31.075129620730877, 13.371815923601389, 11.073637492954731, 3.7352278316393495, 1.3895945786498487, 0.0418682426243322, 0.3373199823545292, 0.20372669154312462, 0.21265311021124944, 1.0950824758037925, 1.9066399591974914, 1.976359924301505, 1.8552492605522275, 0.5914471100550145, 0.0323928573197918, 0.20681453053839505, 1.4753023046068847, 3.2990311877802014, 3.8884054496884346, 9.4838778488338, 3.753767986781895, 10.325221102684736, 12.832359820604324, 37.733734622597694, 52.52490073442459, 51.177158653736115, 67.57115095853806, 71.56206160783768, 77.02966421842575, 76.60439103841782, 75.75121521949768, 66.27326220273972, 49.29413549602032, 32.19386748969555, 28.40248793363571, 28.521404452621937, 26.789917163550854, 24.5300530269742, 31.98905847966671, 41.55509077012539, 46.56581349670887, 53.627578765153885, 58.41318257153034, 64.76062417030334, 72.31923177838326, 68.50765630602837, 64.72742155194283, 53.04385408759117, 39.420844092965126, 24.89013310521841, 10.20653447136283, 6.262342315167189, 7.233506077900529, 10.006771590560675, 7.5447108037769794, 3.110256604850292, 0.21854366990737617, 1.4277590182609856, 1.905351234599948, 2.730389325879514, 1.740906627383083, 1.6953438660129905, 2.126000407151878, 1.9634498795494437, 1.8654278456233442, 2.034830949269235, 1.1863516783341765, 0.7564419752452523, 0.31033106963150203, 0.5230919842142612, 0.2804120094515383, 0.22983350238064304, 0.0720087336958386, 0.12533167318906635, 0.28023585327900946, 0.41482664993964136, 0.4582948924507946, 0.3901114995824173, 0.3003712696954608, 0.19917220546631142, 0.13949723885161802, 0.02068461682938505, 0.07240680686663836, 0.009198831394314766, 0.06750659871613607, 0.14855788234854117, 0.0941372470697388, 0.08519542883732356, 0.07622148303198628, 0.2465319141629152, 0.12778988893842325, 0.1309028422110714, 0.1026161877962295, 0.1147984825365711, 0.10120532795554027, 0.6125963595695794, 0.70665194070898, 0.6532914040144533, 0.7585262227803469, 0.3578835289226845, 0.8229692804161459, 0.7494350324850529, 0.5071988620329648, 0.5557257018517703, 0.2275843793177046, 0.2305749524384737, 0.27452737209387124, 0.40348096343223006, 0.3780128597281873, 0.30176048108842224, 0.31325150979682803, 0.2918819908518344, 0.19847077201120555, 0.15974427427863702, 0.24210774921812117, 0.35145498637575656, 0.22563618229469284, 0.4829732025973499, 0.3155751741724089, 0.3843879676423967, 0.33670450444333255, 0.17569084593560547, 0.27404037478845567, 0.38717963034287095, 0.7226814399473369, 1.1704459693282843, 0.6268071220256388, 0.18631376966368407, 0.09504623696557246, 0.531104626134038, 0.7664761680644006, 0.41124807321466506, 0.22242045641178265, 0.4614176123868674, 0.3044401982333511, 0.43967075587715954, 3.4815223328769207, 6.150433095172048, 15.706783030182123, 31.508209481835365, 25.29520846903324, 17.126737385988235, 22.540793269872665, 29.530409909784794, 47.92239390313625, 51.06361694633961, 55.99260225892067, 65.32021254301071, 72.94103801250458, 68.66159364581108, 69.86485987901688, 77.73477718234062, 68.50298255681992, 63.95199716091156, 69.42855209112167, 83.54680091142654, 71.830053627491, 53.93390692770481, 41.93280570209026, 63.309094458818436, 65.90714424848557, 66.90294921398163, 81.56933382153511, 81.08344629406929, 86.42985060811043, 86.55212804675102, 97.31639564037323, 73.85014683008194, 62.22907081246376, 56.917054653167725, 31.43296591937542, 47.52162180840969, 52.58407115936279, 62.05077677965164, 71.95952787995338, 72.65432059764862, 44.53774832189083, 15.393292251974344, 9.635320622473955, 2.9875039542093873, 0.7788642158266157, 0.2382891470915638, 0.3580855415202677, 0.4211959394160658, 1.306019607000053, 2.772372798062861, 3.5280560608953238, 5.183611074462533, 3.3494670689105988, 1.5125202387571335, 1.186338379047811, 3.809938235208392, 4.051741110160947, 4.302701968699694, 7.965638441964984, 29.49445053935051, 27.259598560631275, 35.573113560676575, 43.60801041126251, 51.80102437734604, 63.11891846358776, 59.87972907721996, 78.44894886016846, 86.25521957874298, 93.38852360844612, 96.15561112761497, 89.80203285813332, 78.45885872840881, 64.99552756547928, 66.86297535896301, 85.3196869790554, 96.07284396886826, 102.89886608719826, 101.1676561832428, 105.65846040844917, 116.00794985890388, 120.03796800971031, 113.96311238408089, 111.35517552495003, 103.88824179768562, 98.77945393323898, 91.08695670962334, 82.4679172039032, 78.71802002191544, 73.45157861709595, 64.55713748931885, 47.825160920619965, 29.789690896868706, 12.626637909561396, 8.282737601548433, 6.733398763462901, 8.809181302785873, 4.82908914797008, 3.543070717714727, 2.649204069748521, 1.8286231392994523, 0.826239479938522, 0.6938584428280592, 1.9598705903626978, 2.659345488063991, 1.7392068123444915, 1.8390805344097316, 1.8941411236301064, 2.036320469342172, 2.1880824258551, 1.7689835582859814, 1.0507255559787154, 0.6222518789581954, 0.6518737832084298, 0.44277711887843907, 0.5087176524102688, 0.36642075050622225, 0.46958910359535366, 0.3602742834482342, 0.3546376124722883, 0.32242142711766064, 0.4467259382363409, 0.1424087435589172, 0.22940865252166986, 0.1128201097890269, 0.2737222606083378, 0.581907662563026, 0.5428952747024596, 0.2892291097668931, 0.3433943720301613, 0.36554733174853027, 0.4251855768961832, 0.4750211496138945, 0.5320174084044993, 0.34112188615836203, 0.35786313470453024], [0.273879625601694, 0.13923288584919646, 0.15745191369205713, 0.3082172549329698, 0.5730869108811021, 0.6640534359030426, 0.4397882823832333, 0.36264681082684547, 0.16298183414619416, 0.22537212615134194, 0.3818788850912824, 0.2519761462463066, 0.17802188725909218, 0.3263751743361354, 0.14327851095004007, 0.3023535164538771, 0.38497960777021945, 0.09695568645838648, 0.0942130277690012, 0.1465797916171141, 0.10977669575368054, 0.04427833751833532, 0.21737524744821712, 0.24167525523807853, 0.13230094453319907, 0.3962212451733649, 0.16844304656842723, 0.08558726796763949, 0.28442299109883606, 0.5498607759363949, 0.6183578004129231, 0.4766025475692004, 0.5114786198828369, 0.25589492346625775, 0.8822584489826113, 0.516547963488847, 0.22207807400263846, 0.22548646142240614, 0.38842465728521347, 0.2882582024903968, 0.46004677657037973, 0.13245777518022805, 0.5262909969314933, 2.097184178419411, 5.548084191977978, 12.391611970961094, 11.519189234822989, 13.759464472532272, 5.698083518072963, 10.598586034029722, 6.467028306797147, 5.251891510561109, 8.403644263744354, 18.013909980654716, 26.470996476709843, 27.404636777937412, 27.26688276976347, 34.70428258180618, 37.029712200164795, 40.32028242945671, 39.82864961028099, 30.056523978710175, 13.492706436663866, 4.301481759175658, 2.8156054532155395, 20.061703696846962, 34.45254608988762, 35.8987332880497, 33.862646743655205, 30.169376023113728, 35.09525500237942, 46.18057116866112, 41.113311275839806, 30.25971047580242, 24.746956788003445, 26.205715611577034, 44.97650697827339, 63.15637685358524, 58.07773657143116, 61.28897845745087, 48.41412931680679, 21.31745271384716, 4.197812872007489, 1.1548526748083532, 1.449821109417826, 1.2379203736782074, 1.6008878219872713, 1.5878388471901417, 2.489348785020411, 0.8458713639993221, 1.2045029480941594, 2.1846452727913857, 2.7716306503862143, 1.308914814144373, 0.12817316368455067, 0.28385269513819367, 0.7921570900361985, 4.237366849556565, 7.233972502872348, 6.209437754005194, 5.095212142914534, 9.052631389349699, 8.135720640420914, 12.587284371256828, 30.268434807658195, 77.33019769191742, 79.70580741763115, 45.748868733644485, 38.867236599326134, 52.46861055493355, 44.673146456480026, 47.385399118065834, 37.82708801329136, 19.806304201483727, 6.087843803688884, 8.024974633008242, 2.707359711639583, 4.908221326768398, 11.486409343779087, 14.664186425507069, 13.647236544638872, 6.591848758980632, 6.8431520741432905, 12.17092551290989, 15.276064742356539, 18.914782740175724, 16.14093728363514, 13.04114056751132, 6.049491036683321, 1.002918896265328, 5.059136878699064, 7.9932548850774765, 5.004414590075612, 4.520985530689359, 4.247119026258588, 3.420190536417067, 3.350203991867602, 2.1325346315279603, 0.3607368789380416, 0.6341391254682094, 1.6991720418445766, 3.008613958954811, 2.9131029965355992, 1.786443383898586, 0.9807509451638907, 0.4781768802786246, 0.2095347541035153, 0.7000859524123371, 1.192721442785114, 0.67751967580989, 0.1967251516180113, 0.15652940928703174, 0.22786062152590603, 0.2873597585130483, 0.08555319596780464, 0.1362851049634628, 0.14936835214029998, 0.18088908575009555, 0.3785522229736671, 0.21443006407935172, 0.25226009194739163, 0.12986451823962852, 0.19618566962890327, 0.2119819266954437, 0.09746131909196265, 0.4520414076978341, 0.27504954719915986, 0.12897168489871547, 0.22842352569568902, 0.09049143176525831, 0.17374815564835444, 0.1951258975896053, 0.11941979159018956, 0.22617970156716183, 0.19966487277997658, 0.1398151007015258, 0.3517455223482102, 0.2410407189745456, 0.3393997473176569, 0.3633031959179789, 0.7612581574358046, 0.5002126400358975, 0.05667265271767974, 0.5407182883936912, 0.3509999014204368, 0.312053119414486, 0.26099807932041585, 0.1975935386144556, 0.34074885305017233, 0.3049641544930637, 0.014792245365242707, 0.32443635805975646, 0.29024876130279154, 0.11597457880270667, 0.08896148690837435, 0.03841557125269901, 0.1173604950599838, 0.13938317075371742, 0.38651113340165466, 0.23223806085297838, 0.07081639181706123, 0.09665795165346935, 0.0629189980099909, 0.2637690509436652, 0.2732213999843225, 0.1466305396752432, 0.3117047849809751, 0.23550349578727037, 0.8984870812855661, 0.7243595842737705, 0.7182559242937714, 0.8542144694365561, 0.2790591336088255, 0.4328500624978915, 0.6501164962537587, 0.3701479348819703, 0.283528346917592, 0.2734316058922559, 1.6886422131210566, 4.0927010122686625, 10.755609758198261, 16.64355531334877, 16.938235200941563, 14.0850661508739, 11.065396685153246, 13.338358718901873, 18.333052955567837, 20.55148981511593, 23.128616027534008, 27.181503251194954, 32.298540472984314, 38.575545251369476, 42.65209570527077, 42.844255194067955, 49.58600543439388, 44.17275510728359, 35.56458301842213, 35.20048275589943, 43.950573429465294, 45.160044729709625, 31.788028366863728, 32.784857377409935, 29.07684914767742, 33.30329775810242, 51.63500748574734, 62.28703290224075, 66.56642407178879, 73.13524559140205, 55.96329063177109, 43.9598373323679, 34.39350105822086, 36.91719263792038, 58.79473149776459, 72.37532436847687, 78.13094392418861, 77.7526818215847, 81.55842080712318, 44.68874081969261, 12.996594607830048, 3.4746254654601216, 3.786450270563364, 1.0465360432863235, 0.2464226700249128, 1.7600351572036743, 4.189341701567173, 3.065123101696372, 2.4646144872531295, 0.9611670929007232, 1.7095653153955936, 2.1340125147253275, 0.2970066689886153, 0.10342400812078267, 1.458705032709986, 2.1816557832062244, 3.433093219064176, 2.66883737873286, 3.9849596936255693, 9.494462180882692, 16.8498994410038, 26.024130955338478, 44.262350499629974, 69.09861579537392, 68.9216896891594, 63.47313165664673, 61.967831030488014, 64.54422578215599, 56.382039561867714, 60.48050343990326, 61.15828447043896, 52.6459926366806, 37.60472014546394, 24.533611536026, 19.264916852116585, 17.61021964251995, 10.227387752383947, 2.269035894423723, 5.311068585142493, 9.302542079240084, 13.195599429309368, 16.880928575992584, 20.25826334953308, 20.698312036693096, 17.283836156129837, 11.642160136252642, 10.244085006415844, 11.678788270801306, 16.337341144680977, 15.140957292169333, 9.544812329113483, 7.309825932607055, 4.391326513141394, 2.618147386237979, 2.938931635580957, 3.386850650422275, 1.6754733072593808, 1.8153386958874762, 2.1098778722807765, 2.412852714769542, 2.486296836286783, 2.2720389207825065, 1.7480344511568546, 1.1327544855885208, 0.32621831400319934, 0.4408676619641483, 0.7066305074840784, 0.3383797692367807, 0.2211246665683575, 0.27807341306470335, 0.10920489323325455, 0.3033670230070129, 0.38091317284852266, 0.3347172407666221, 0.2786964311962947, 0.43347622733563185, 0.40553635626565665, 0.37170994793996215, 0.33107261289842427, 0.09571756148943678, 0.3505143290385604, 0.26560687576420605, 0.16977116436464712, 0.21759695664513856, 0.4326168796978891, 0.4929181595798582, 0.3435158170759678, 0.18576645059511065, 0.27090990683063865, 0.07547515706392005, 0.0637905762414448, 0.1847463389276527, 0.05405752839578781, 0.3023303020745516, 0.4690146812936291, 0.7647973706480116, 0.8845044253394008, 1.268126021604985, 1.310408371500671, 1.9884988479316235, 1.9095817138440907, 1.045277479570359, 0.307043296052143, 0.33454135176725686, 0.424939866643399, 0.5047320818994194, 0.41453513433225453, 0.21953605493763462, 0.19032556767342612, 0.4338304395787418, 0.5833215429447591, 0.3015879465965554, 0.14734632626641542, 0.1589434375637211, 0.30866705579683185, 0.18900966562796384, 0.3456939908210188, 0.3248096286552027, 0.19255776976933703, 0.5155731970444322, 0.22295866190688685, 0.24122092727338895, 0.3405024897074327, 0.6495195720344782, 0.8690330211538821, 0.9397889650426805, 1.2600585795007646, 1.6019619768485427, 2.1036763675510883, 1.9426063355058432, 0.583888425026089, 0.42051568685565144, 0.4095875029452145, 0.5002568126656115, 0.4823080007918179, 0.15720639639766887, 1.0594811174087226, 2.5407510017976165, 8.019057400524616, 18.405342176556587, 19.756684564054012, 17.506333217024803, 19.119859635829926, 25.37511818110943, 34.922668263316154, 38.79334956407547, 48.80023039877415, 62.284247651696205, 73.84092852473259, 79.47511419653893, 80.33154264092445, 84.53486949205399, 98.6759626865387, 96.2115441262722, 96.92152842879295, 96.06280490756035, 110.05246102809906, 113.91455858945847, 110.82208693027496, 109.754678606987, 111.74128040671349, 104.99092742800713, 96.85180217027664, 78.73346999287605, 68.98655980825424, 69.81331184506416, 58.541573882102966, 51.88612461090088, 56.67629957199097, 64.91405233740807, 77.80142560601234, 84.49678793549538, 94.32485416531563, 87.91944667696953, 87.11499944329262, 64.00798335671425, 24.033227786421776, 10.413750652223825, 3.152382094413042, 1.0716973431408405, 1.222322448156774, 2.732013026252389, 5.2542089112102985, 7.781733060255647, 3.6529327975586057, 5.349285984411836, 4.330239566043019, 2.7428761683404446, 0.24125120689859614, 0.2832735824631527, 1.0002858750522137, 5.742930136620998, 13.477579448372126, 14.262563176453114, 19.945201948285103, 24.88058041781187, 29.576757922768593, 40.83829343318939, 59.259735345840454, 93.34655106067657, 96.56013742089272, 99.88768726587296, 95.6007269024849, 85.8564005792141, 64.59086447954178, 70.39533421397209, 75.34968316555023, 72.59344026446342, 53.30201983451843, 37.3885003477335, 35.4198107868433, 48.2982013374567, 53.11051771044731, 48.58544312417507, 41.8673238158226, 43.14643017947674, 48.00812870264053, 59.06431943178177, 72.85224437713623, 72.19754710793495, 76.27003937959671, 75.58749720454216, 61.03200204670429, 44.40714173018932, 31.060754992067814, 18.605916313827038, 11.068939045071602, 11.303020734339952, 10.547348633408546, 7.477459162473679, 2.7747657196596265, 2.9033073596656322, 1.3764474028721452, 1.2360197631642222, 1.8066117516718805, 2.4212661758065224, 2.633063248358667, 1.5367283835075796, 1.0528870462439954, 1.0982093517668545, 1.141019754577428, 2.0113201858475804, 1.8236936163157225, 1.1555657302960753, 0.5876186967361718, 0.5896278389263898, 0.6566700164694339, 0.8005621796473861, 0.5912372306920588, 0.4669894790276885, 0.431516274693422, 0.4840872553177178, 0.4995777178555727, 0.3809740289580077, 0.3274573740782216, 0.17079133540391922, 0.3428654879098758, 0.291568567045033, 0.22034861758584157, 0.5886891111731529, 0.4791178344748914, 0.6023076397832483, 0.5182235548272729, 0.529196891002357, 0.31920641369652003, 0.3200781106716022, 0.47771630343049765, 0.3786517004482448, 0.3397810331080109, 0.4652430274290964], [0.0244175528496271, 0.057949543770519085, 0.03302780547528528, 0.4010487376945093, 0.17207216355018318, 0.49171012127771974, 0.7120135123841465, 0.2941051684319973, 0.08157272401149385, 0.15486175892874599, 0.22281309706158936, 0.15413461747812107, 0.2096755098318681, 0.12654964142711833, 0.08016776424483396, 0.025113759729720186, 0.04531181897618808, 0.1958053486305289, 0.04904134853859432, 0.09374354514875449, 0.1622094216872938, 0.059397540680947714, 0.15374170965515077, 0.09435521584236994, 0.025456286857661325, 0.062205166977946647, 0.1071045188291464, 0.06751758250175044, 0.39592774061020464, 0.41423260525334626, 0.05600470867648255, 0.7631167327053845, 0.46890531841199845, 0.666640562703833, 0.5723523034248501, 0.3719253488816321, 0.15350178815424442, 0.1007532115909271, 0.28068856336176395, 0.08282333190436475, 0.14551200438290834, 0.09833920557866804, 0.03317044254799839, 0.11349828433594666, 0.5636763595975935, 2.0564468018710613, 7.038252130150795, 8.080054577440023, 3.7731412472203374, 5.103631066158414, 1.7973805032670498, 5.413623182103038, 5.357584739103913, 4.758908338844776, 4.133130367845297, 4.495915425941348, 2.4284055177122355, 6.916895192116499, 7.283030720427632, 5.342438751831651, 5.877255778759718, 5.97509435378015, 2.4625150999054313, 9.490548390895128, 14.826278127729893, 15.075304415076971, 8.952972237020731, 2.1731031546369195, 11.835227776318789, 20.289417877793312, 26.61963500082493, 24.249134100973606, 18.458480425179005, 22.992628924548626, 29.734137877821922, 36.07907921075821, 37.266678884625435, 56.309125274419785, 71.83388382196426, 61.66292019188404, 14.585464149713516, 6.253090761601925, 7.873538509011269, 13.590275701135397, 4.260762194171548, 3.1736103678122163, 0.4020859336014837, 0.43187188217416406, 1.022374564781785, 1.295884600840509, 1.9838476600125432, 1.8521473207511008, 1.1212912132032216, 0.7063979480881244, 0.21409495471743867, 0.9247115522157401, 5.125948218628764, 3.67509035859257, 5.3750186786055565, 3.297692947089672, 1.9943792698904872, 3.5415090015158057, 14.978519808501005, 20.98686285316944, 53.50332163274288, 74.24953579902649, 72.22541481256485, 42.50430643558502, 21.5994393825531, 28.38966742157936, 20.91675851494074, 11.788207199424505, 10.608308762311935, 13.485100194811821, 4.133377354592085, 2.5497824046760798, 0.2904542174655944, 2.4311104975640774, 3.5571071645244956, 1.1882883869111538, 0.47379313269630075, 2.619952051900327, 5.74777202680707, 3.7737340154126287, 2.8732495475560427, 3.3520967653021216, 3.296092520467937, 2.9714987380430102, 1.3284404226578772, 4.236500021070242, 5.728804869577289, 2.2026513190940022, 0.9694461361505091, 1.2522612791508436, 1.217472127173096, 1.0003463155589998, 1.5142749133519828, 0.7472865446470678, 1.9327965681441128, 1.7822226416319609, 1.9559505069628358, 1.292112828232348, 0.9666840406134725, 0.4105661285575479, 0.6625269271899015, 0.6987386278342456, 0.5136401695199311, 0.0900198043382261, 0.17299208528129384, 0.35573248809669167, 0.507546424632892, 0.2088402968365699, 0.18575310677988455, 0.3331469156546518, 0.13995456509292126, 0.1527908255229704, 0.05011015251511708, 0.27233723492827266, 0.30963291646912694, 0.2624871244188398, 0.24843323713866994, 0.29107771057169884, 0.19801467773504555, 0.23455837072106078, 0.2001833519898355, 0.3903901908779517, 0.1925546972779557, 0.06146985077066347, 0.0913595367455855, 0.027063489287684206, 0.19405113416723907, 0.18317635520361364, 0.16450023860670626, 0.028561134022311307, 0.08261275492259301, 0.08299430788611062, 0.021590573196590412, 0.13703700446058065, 0.2791979449102655, 0.2706511050928384, 0.5289792339317501, 0.5698998318985105, 0.745396917918697, 0.43611450295429677, 0.1384330732980743, 0.06134463561465964, 0.0302620622824179, 0.21264821203658357, 0.18287471670191735, 0.1404624167480506, 0.07108424775651656, 0.09098185779293999, 0.06311642413493246, 0.1436232979176566, 0.16402925684815273, 0.42679743259213865, 0.39986394345760345, 0.05162871653737966, 0.2355322614312172, 0.04097326076589525, 0.048424159977003, 0.16168785514310002, 0.1328832484432496, 0.06725518134771846, 0.23989148845430464, 0.6576275650877506, 0.4498384759062901, 0.16120302490890026, 1.4954427676275373, 1.1889393394812942, 0.8073552057612687, 0.6135788443498313, 0.025040461514436174, 0.05029411979194265, 0.1854677509982139, 0.07760201129713096, 0.19204454496502876, 0.1891553937457502, 0.18303732125787064, 0.22888984676683322, 1.5885305288247764, 4.157032510265708, 7.632199684157968, 12.630904130637646, 12.006402891129255, 4.068896239623427, 7.697122050449252, 12.622406836599112, 12.739676143974066, 4.846646580845118, 1.9510036474093795, 1.8082887679338455, 3.332486255094409, 4.920775853097439, 10.323551092296839, 12.056437656283379, 17.26030021905899, 14.387577418237925, 20.13580732047558, 24.73091784864664, 20.71759220212698, 27.287167981266975, 30.908014588057995, 35.22185280919075, 44.63066093623638, 49.90350879728794, 55.88010549545288, 43.72935310006142, 32.612985000014305, 32.965948060154915, 41.11441321671009, 52.128627598285675, 59.537067264318466, 68.6120443046093, 92.97642812132835, 88.91562402248383, 53.77669416368008, 30.383652225136757, 18.094790540635586, 10.262719206511974, 3.2699705846607685, 2.255801442079246, 0.7038171146996319, 0.5957241368014365, 1.6514506400562823, 4.858516193926334, 4.066031193360686, 2.646393170580268, 1.1473449901677668, 0.4815745510859415, 0.23831120372051373, 0.47241814085282385, 5.1162307150661945, 15.26555260643363, 15.090301260352135, 10.31926492229104, 7.655692398548126, 12.918141167610884, 17.50632181763649, 31.80493365973234, 49.43088635802269, 81.7504321038723, 84.31231543421745, 74.08472344279289, 57.40245580673218, 45.94513960182667, 30.613834373652935, 24.629024416208267, 32.75992311537266, 35.78423023223877, 22.57150512188673, 9.67215584591031, 3.190349182114005, 3.5403816495090723, 4.319148911163211, 1.5519538102671504, 0.5022293224465102, 0.48358615720644593, 2.019323268905282, 3.7261154456064105, 4.212173251435161, 4.734280435368419, 5.059798518195748, 5.192872602492571, 6.740372339263558, 7.8892425913363695, 7.267020754516125, 4.71853313036263, 3.560046306811273, 2.0831707678735256, 1.2077077198773623, 1.5297673945315182, 2.7644354989752173, 0.8961452194489539, 0.8201313077006489, 1.8935909844003618, 2.1272486401721835, 1.9074760330840945, 1.4615780347958207, 0.688595250248909, 1.1687266803346574, 1.0661668586544693, 0.7587285025510937, 0.272591583780013, 0.4037411307217553, 0.4560590983601287, 0.46196822659112513, 0.3537636890541762, 0.25606912036892027, 0.12635162158403546, 0.18078517023241147, 0.29711540846619755, 0.28532927215564996, 0.19541549845598638, 0.28418565227184445, 0.627140732249245, 0.7170336367562413, 0.365010432433337, 0.040211739324149676, 0.1810482467408292, 0.14155007869703695, 0.49921839963644743, 0.23643698397791013, 0.10744022190920077, 0.243797738221474, 0.17049051326466724, 0.19940368132665753, 0.09959830364095978, 0.05797522950160783, 0.13564627908635885, 0.2458835145807825, 0.296399918734096, 0.3628046211088076, 0.23481356562115252, 0.33945205388590693, 1.0749563807621598, 1.3204565760679543, 1.536540649831295, 0.8937369799241424, 0.4197246761759743, 0.4568589257542044, 0.3001931542530656, 0.36920193408150226, 0.23150339402491227, 0.37168691167607903, 0.29702207597438246, 0.19990718399640173, 0.12853442633058876, 0.12002243776805699, 0.2725932758767158, 0.3191166138276458, 0.4398174933157861, 0.4440306359902024, 0.13096743874484673, 0.248155421577394, 0.17039415281033143, 0.11694097382132895, 0.21838067943463102, 0.20121275534620509, 0.2749960235087201, 0.6439351779408753, 0.578407219145447, 0.5532664619386196, 1.3797613000497222, 2.81662427354604, 3.0741295684129, 1.7773005994968116, 0.9338533272966743, 0.25121265440247953, 0.25493871071375906, 0.5405650497414172, 0.22961998649407178, 0.29235049383714795, 0.2543427364435047, 0.27565445692744106, 0.2069884751108475, 0.5108912545256317, 2.0271294750273228, 7.024359125643969, 14.033755604177713, 13.239475674927235, 8.319125398993492, 10.432624239474535, 20.145282112061977, 23.60466968268156, 30.433076173067093, 31.89793936908245, 38.762723207473755, 42.71481513977051, 45.0684430450201, 41.5796260535717, 35.63411928713322, 36.337241157889366, 40.726381838321686, 54.51235368847847, 64.94496747851372, 68.122318983078, 65.1131996512413, 46.589528024196625, 38.721073642373085, 39.82938677072525, 50.65550744533539, 72.00136363506317, 56.74958623945713, 45.19590720534325, 50.63760660588741, 73.85456219315529, 92.41017490625381, 74.80114459991455, 80.79516336321831, 112.52169013023376, 101.08772367238998, 63.723549619317055, 40.02705216407776, 37.71480783820152, 30.821926407516003, 15.78369090333581, 3.961295038461685, 1.0684594418853521, 0.36225543182808906, 1.0516791860572994, 4.3331582844257355, 11.572743561118841, 7.9407901503145695, 2.056246125139296, 2.1153519535437226, 0.44389791029971093, 2.0553396362811327, 7.09891919977963, 30.425147898495197, 28.430959805846214, 23.92130859196186, 20.046183429658413, 32.39314779639244, 47.08475545048714, 55.83554148674011, 64.98330742120743, 89.83015894889832, 91.07035160064697, 81.07434958219528, 71.97012171149254, 57.1710292249918, 29.636409021914005, 18.23761347681284, 25.014126151800156, 30.35283587872982, 18.885250724852085, 7.862700540572405, 3.6093933088704944, 3.3754538744688034, 4.11948150023818, 2.1641945326700807, 2.5691499654203653, 7.594945058226585, 18.221010267734528, 21.683874651789665, 25.297142565250397, 25.36752238869667, 24.87952407449484, 26.855554841458797, 26.03339485824108, 20.41328553110361, 13.337150383740664, 9.33936020359397, 6.143335551023483, 2.5763546163216233, 2.3995270673185587, 3.2848097383975983, 4.838202483952045, 2.2248029429465532, 1.559921745210886, 1.7970500397495925, 2.8287812462076545, 2.2115416545420885, 2.063497086055577, 2.140200245194137, 2.2467163670808077, 1.9246819848194718, 1.271450724452734, 0.6936429825145751, 0.42834507767111063, 0.9247144020628184, 1.1501994682475924, 0.9556919429451227, 0.7841622596606612, 0.4241605522111058, 0.38903203094378114, 0.49893293995410204, 0.8019150258041918, 0.7820834149606526, 0.7115161546971649, 0.7026848942041397, 0.654059675289318, 0.782506795367226, 0.8622931921854615, 0.5432809540070593, 0.22156686784001067, 0.47685995406936854, 0.6260900886263698, 0.3352683299453929, 0.746816557366401, 0.5498449236620218, 0.506152433808893, 0.7879598590079695, 0.6479471689090133, 0.7178364624269307, 0.5438000417780131, 0.39935358334332705], [0.08150658381055109, 0.03835811417957302, 0.04934419674100354, 0.08774003057624213, 0.08795400659437291, 0.03564065511454828, 0.08411236820393242, 0.10215873538982123, 0.0365857282304205, 0.2432553024846129, 0.06775626461603679, 0.16462340543512255, 0.03597138209443074, 0.08917917366488837, 0.095716537325643, 0.04075289485626854, 0.053576857899315655, 0.02111767669703113, 0.12228510502609424, 0.0672041141660884, 0.09284940562793054, 0.04112802453164477, 0.039894159490359016, 0.03954064486606512, 0.12018904249998741, 0.07095981185557321, 0.053596090656355955, 0.010622372683428694, 0.07366751538938843, 0.11145431315526366, 0.17628028930630535, 0.2740293910028413, 0.3871129854815081, 0.4401242971653119, 0.20934834145009518, 0.06686532375169918, 0.18589950283057988, 0.07896352573879994, 0.08082903266767971, 0.0733634278003592, 0.30773738224525005, 0.1052266477199737, 0.04144096594245639, 0.13779435132164508, 0.46402376785408705, 0.2935328538296744, 0.9364540502429008, 0.5228571686893702, 2.9938275273889303, 1.935125368181616, 0.9201384382322431, 0.9728330606594682, 2.873442624695599, 2.1165263280272484, 0.7731741399038583, 4.093746906146407, 3.649000246077776, 2.334409011527896, 2.6361615071073174, 0.14065714145544916, 2.160292617045343, 1.6590072470717132, 3.167390814051032, 3.300333092920482, 2.515123039484024, 2.6441707648336887, 2.8897924348711967, 3.3676350815221667, 8.46316047012806, 9.854607805609703, 12.461859751492739, 16.839493699371815, 9.873320851475, 7.139666313305497, 15.826857537031174, 33.065350726246834, 33.74569281935692, 50.718059688806534, 62.6153314858675, 44.28005374968052, 19.382087364792824, 8.881110493093729, 1.5604379237629473, 5.527413776144385, 3.9847763534635305, 1.7416377319023013, 1.4568160590715706, 0.3456665313569829, 0.2151114447042346, 0.3494882653467357, 0.9690399141982198, 0.6359759706538171, 0.24897844850784168, 0.055401179342879914, 0.8182559895794839, 3.6382444482296705, 3.966668900102377, 3.607913050800562, 4.757099160924554, 10.040835812687874, 11.132150553166866, 14.036559853702784, 17.30507131665945, 31.88071109354496, 52.71916911005974, 66.33469730615616, 37.65523083508015, 20.38863815367222, 5.559416133910418, 7.276287507265806, 9.014826267957687, 12.012891992926598, 3.146607829257846, 1.4441543072462082, 0.9807394864037633, 0.5223758413922042, 0.639215474948287, 0.24733894038945436, 1.1939226533286273, 1.011453119572252, 0.030424733631662093, 0.34961175872012973, 0.5783517064992338, 0.7702509092632681, 1.5713085466995835, 1.5361248096451163, 0.5461826326791197, 0.2903079550014809, 0.4355232190573588, 1.024052412249148, 0.32396061171311885, 0.328983110957779, 0.46055642422288656, 0.3633833775529638, 0.5513341468758881, 0.05626647158351261, 0.21196693531237543, 0.49653354682959616, 0.6191741628572345, 0.33805043378379196, 0.23458820505766198, 0.11038047741749324, 0.46641419583465904, 0.19715187168912962, 0.03562935220543295, 0.13850724353687838, 0.14651822304585949, 0.30232136661652476, 0.22183221532031894, 0.17265154339838773, 0.1359147732728161, 0.1311827209428884, 0.03829323191894218, 0.02449257099215174, 0.07416928143356927, 0.22451914614066482, 0.11360036674886942, 0.16115457750856876, 0.06484280063887127, 0.1396185948397033, 0.1651420776033774, 0.17577368445927277, 0.13879820995498449, 0.04767668368003797, 0.04591263576003257, 0.13720318616833538, 0.056257009200635366, 0.017216454980371054, 0.08956965466495603, 0.04000946326414123, 0.12338061889749952, 0.07478131577954628, 0.05703139577235561, 0.12969732721103355, 0.04763534976518713, 0.1722951789270155, 0.08862042552209459, 0.10169445522478782, 0.12287039979128167, 0.030078601521381643, 0.05103441209939774, 0.25507084268610924, 0.059252762512187473, 0.10808947496116161, 0.10593009981676005, 0.06626730115385726, 0.17077678930945694, 0.38430398621130735, 0.03243346021918114, 0.11718746332917362, 0.10503146288101561, 0.12956347345607355, 0.16192284878343344, 0.354918708326295, 0.17319405335001647, 0.19682096288306639, 0.06431177913327701, 0.04647973306418862, 0.06773101675207727, 0.054688836316927336, 0.043357951944926754, 0.11043227190384641, 0.07935995876323432, 0.045007293520029634, 0.09727748911245726, 0.15275840851245448, 0.5091208464000374, 0.7062233949545771, 0.8764914271887392, 0.9046159742865711, 0.1653197774430737, 0.05671335580700543, 0.19044411834329367, 0.09001296915812418, 0.017051581307896413, 0.2162714215228334, 0.4792033298872411, 0.3388728521531448, 0.47382495598867536, 0.11457867323770188, 0.26306582149118185, 0.8420257328543812, 1.7927100788801908, 3.5935381846502423, 6.576870437711477, 2.1083907270804048, 3.9908484276384115, 6.675670836120844, 7.361646126955748, 5.141146928071976, 2.41939477622509, 4.076334340497851, 2.5196025241166353, 2.5136342318728566, 5.902067497372627, 9.1382977925241, 11.482942029833794, 5.9078417625278234, 7.794215390458703, 11.121123544871807, 7.924581645056605, 7.5078109838068485, 12.01015044003725, 22.615919038653374, 28.602359108626842, 28.153492994606495, 27.412869036197662, 27.82071255147457, 20.081187151372433, 22.67466578632593, 41.802164912223816, 53.035547733306885, 54.7128689289093, 70.1836171746254, 83.80554422736168, 70.94824254512787, 31.867628395557404, 18.52208711206913, 13.131601363420486, 15.873899012804031, 14.125167299062014, 11.474747769534588, 3.5399468103423715, 0.7379493175540119, 0.26004388520959765, 0.5988785612862557, 0.13984696852276102, 1.016783402301371, 0.34832131233997643, 0.6132547336164862, 1.1144122760742903, 6.686830362305045, 9.150412492454052, 4.284082967787981, 11.626086998730898, 10.736361891031265, 18.004169203341007, 24.047777205705643, 32.6278991997242, 40.64191237092018, 61.17170535027981, 73.2086880505085, 67.30506643652916, 47.116001173853874, 35.46597830951214, 25.91983985155821, 16.943649910390377, 11.546635162085295, 9.203699883073568, 7.1975101344287395, 3.7361630564555526, 2.107898653484881, 1.5283979242667556, 1.987692816182971, 1.7335567530244589, 1.05581680778414, 0.2523376315366477, 0.4139477096032351, 1.8216198775917292, 1.520015811547637, 2.2793927136808634, 1.3918200717307627, 1.4264119905419648, 0.5198023107368499, 0.45760564506053925, 0.7062480936292559, 1.489928076043725, 0.7661476044449955, 0.47160459856968373, 0.5027832614723593, 0.08589534831116907, 0.27514635294210166, 0.4421679046936333, 0.25637197599280626, 0.17590730072697625, 0.5076102493330836, 0.1663834383361973, 0.6574986095074564, 0.7403482357040048, 0.3322413470596075, 0.14260458148783073, 0.19331275660078973, 0.08245901903137565, 0.19531909347278997, 0.266455952078104, 0.16547156148590147, 0.2675008960068226, 0.27851264574564993, 0.08900726257706992, 0.1397954041021876, 0.03327006474137306, 0.2078837575390935, 0.10143108185729943, 0.18764347565593198, 0.06357266684062779, 0.194368610100355, 0.2942419907776639, 0.20224298990797251, 0.21359721111366525, 0.06373876691213809, 0.10423143510706723, 0.08796473804977722, 0.04681318001530599, 0.047749195218784735, 0.08819890790618956, 0.11148321980726905, 0.17509144294308499, 0.08564318137359805, 0.051550434800446965, 0.09232151598553173, 0.12501393008278683, 0.14445166831137612, 0.3980445832712576, 0.40024116227868944, 0.26736202533356845, 0.2384682124829851, 0.1528581531601958, 0.2954030956607312, 0.14907881064573303, 0.16783786966698244, 0.19983099511591718, 0.3705996653297916, 0.42812406609300524, 0.47463514376431704, 0.5249859450850636, 0.24377329187700525, 0.25785662757698447, 0.32090067747049034, 0.25699368794448674, 0.38480903254821897, 0.44728937675245106, 0.39990422723349184, 0.31081331719178706, 0.15965141676133499, 0.21214522887021303, 0.18986898357979953, 0.22287799045443535, 0.17520600085845217, 0.13304276566486806, 0.19021949992747977, 0.19986912666354328, 0.3836378938285634, 0.8950061118230224, 1.3588668149895966, 1.2193086161278188, 0.9195003099739552, 0.39933182357344776, 0.21888525079702958, 0.31270831706933677, 0.276932583656162, 0.1423895516199991, 0.17592429590877146, 0.4516479803714901, 0.5065303354058415, 0.44156373711302876, 0.4240436787949875, 0.4821145674213767, 2.654555132612586, 2.2745263623073697, 3.2519008917734027, 6.190776955336332, 3.5843528900295496, 4.585120864212513, 6.280918568372726, 11.959721446037292, 7.125254161655903, 10.257239900529385, 9.498750250786543, 11.132421288639307, 11.858912855386734, 12.668041437864304, 14.09387407824397, 17.839866019785404, 15.623937025666237, 13.766387701034546, 12.420222535729408, 9.641154259443283, 9.873868972063065, 13.322806153446436, 26.9912151619792, 33.16369324922562, 34.78167682886124, 27.333381101489067, 32.17268742620945, 22.795430906116962, 30.15862450003624, 54.51340243220329, 63.39353732764721, 70.46198263764381, 100.98667189478874, 93.9799390733242, 88.42383921146393, 59.800092950463295, 43.24065752327442, 20.105131566524506, 19.453973807394505, 20.22061686962843, 12.190807946026325, 6.087650014087558, 1.3804979855194688, 0.24607331142760813, 1.2885816302150488, 2.6819217391312122, 2.174940831027925, 1.2638043472543359, 0.6067213998176157, 1.8468114570714533, 14.547803420573473, 16.677593886852264, 18.621178194880486, 24.355309903621674, 35.28097003698349, 59.57579858601093, 58.55750262737274, 59.71538029611111, 63.50284606218338, 72.41725891828537, 79.8082347214222, 65.74753761291504, 54.55967254936695, 37.63943508267403, 21.360352411866188, 14.552524667233229, 12.641437165439129, 5.026497580111027, 2.845117994584143, 1.888202279806137, 2.1563213551416993, 1.2674178346060216, 1.4630755106918514, 2.9041974619030952, 2.970346212387085, 0.8255928615108132, 0.551146175712347, 3.205092390999198, 3.61216027289629, 3.9978823252022266, 4.14360118098557, 3.175884308293462, 3.0288625974208117, 3.477715887129307, 4.572516465559602, 3.618224747478962, 1.8611005903221667, 1.5446090418845415, 1.2454087031073868, 0.9940420975908637, 0.4053748649312183, 0.39996751758735627, 0.9806853986810893, 1.3929754472337663, 1.7754473676905036, 1.4004275598563254, 1.5251895901747048, 1.3199073867872357, 0.8879155141767114, 0.47079117503017187, 0.32988360326271504, 0.5142657109536231, 0.5661626730579883, 0.665985275991261, 0.7349484879523516, 0.5121724389027804, 0.35046689095906913, 0.13025329972151667, 0.16027689882321283, 0.18499694735510275, 0.5423684092238545, 0.6887864274904132, 0.8035297016613185, 0.7193991879466921, 0.6681557314004749, 1.0229738638736308, 0.750296339392662, 0.4087382782017812, 0.2664290269603953, 0.2727481472538784, 0.2378439178573899, 0.2621908293804154, 0.1315655800863169, 0.20383078517625108, 0.2830291783902794, 0.3955591010162607, 0.279062963090837, 0.1825751710566692, 0.41941935662180185, 0.487878056592308, 0.5796629330143332], [0.11633135887677781, 0.13262118125567213, 0.11848701586131938, 0.01625895831239177, 0.02586976515885908, 0.025267649616580456, 0.04191758060187567, 0.1556682656519115, 0.11413817148422822, 0.06695633332128637, 0.06983004786889069, 0.08650766467326321, 0.07922289150883444, 0.07595431728987023, 0.13772812206298113, 0.1178528877790086, 0.045572130984510295, 0.07775045567541383, 0.03813361450738739, 0.05780356332252268, 0.01492272791438154, 0.030636269839305896, 0.0594984653434949, 0.060494290228234604, 0.035446880356175825, 0.031147292320383713, 0.03882465789502021, 0.07393709311145358, 0.09318378768512048, 0.09700258277007379, 0.10916532191913575, 0.11556849043699913, 0.014208215034159366, 0.0939252228999976, 0.05807140812976286, 0.05898771560168825, 0.06816030465415679, 0.06916581827681512, 0.04635362362023443, 0.08185925238649361, 0.15754480089526623, 0.17424680467229337, 0.247600176371634, 0.35215331765357405, 0.4297659936128184, 0.4868145292857662, 0.1888162619434297, 0.3505971230333671, 0.1689354467089288, 0.22673545143334195, 0.4632617306197062, 1.5793687454424798, 0.3559856198262423, 2.2075359569862485, 0.679207022767514, 0.6840171490330249, 0.48385671456344426, 1.4208201155997813, 0.34547303861472756, 1.6290919273160398, 0.5098520102910697, 1.171223265118897, 0.35117424675263464, 1.103530847467482, 2.4312168918550014, 0.6796330749057233, 0.5985919141676277, 2.5088289147242904, 2.7259286027401686, 4.159853858873248, 2.989581492729485, 3.797681755386293, 2.964046150445938, 3.4388000378385186, 7.008223766461015, 22.3625448346138, 37.07385443150997, 57.18502767384052, 55.076399222016335, 38.48066434264183, 14.86993683502078, 3.775410675443709, 2.3393366346135736, 11.677033714950085, 5.094711044803262, 3.5795846208930016, 2.099058902822435, 0.6719646707642823, 0.258304409799166, 0.290897962404415, 0.3205878473818302, 0.41095219377893955, 0.059665856751962565, 0.03108990946202539, 2.6055249385535717, 3.2801196025684476, 1.4484619698487222, 10.483825542032719, 13.744460977613926, 12.021266743540764, 15.38059238344431, 21.58335104584694, 17.659789882600307, 38.69604058563709, 60.91037057340145, 55.16586922109127, 44.85308580100536, 18.887693993747234, 6.52068997733295, 2.7324951253831387, 1.7168654361739755, 2.9237364884465933, 3.5172218922525644, 1.3682413869537413, 0.1666346107958816, 0.103476433432661, 0.09965285891667008, 0.21573495265329257, 0.1019355196331162, 0.19439756870269775, 0.31973544624634087, 0.06800567818572745, 0.04747558763483539, 0.2049423145945184, 0.023632976590306498, 0.1097695562930312, 0.188815712754149, 0.14100933505687863, 0.08498536393744871, 0.10316882806364447, 0.05694112835044507, 0.002584935145932832, 0.049395174864912406, 0.03421518980758265, 0.01817512424167944, 0.03999814922281075, 0.16979745123535395, 0.06277467997279018, 0.009252689978893613, 0.024226088025898207, 0.021393879942479543, 0.09625906212022528, 0.10394721481134184, 0.05477300328493584, 0.01943412582477322, 0.0517064787709387, 0.09153571518254466, 0.05744883528677747, 0.08344030153239146, 0.07799131970386952, 0.03218659963749815, 0.08215301670134068, 0.010204484169662464, 0.05567670908931177, 0.08062753215199336, 0.155511197517626, 0.20231420639902353, 0.09695883316453546, 0.04428002219356131, 0.02510730490030255, 0.06718113727401942, 0.03774572360271122, 0.055956034921109676, 0.12361274784780107, 0.04032766279124189, 0.0839394329523202, 0.0657240416330751, 0.052176759199937806, 0.03202239575330168, 0.15468833385966718, 0.07453167214407586, 0.04881064080109354, 0.022924526128917933, 0.10006282871472649, 0.04040189611259848, 0.0963946599222254, 0.0579348455357831, 0.09909849686664529, 0.11682893920806237, 0.06024697322573047, 0.048324738163501024, 0.03498847800074145, 0.03766008718230296, 0.05984137467748951, 0.33029012207407504, 0.310778139391914, 0.18599461647681892, 0.17731996398651972, 0.08197673436370678, 0.11396380388760008, 0.09016427822643891, 0.030575697601307184, 0.03359996422659606, 0.13305480330018327, 0.06744671482010745, 0.0324369223380927, 0.04190887892036699, 0.09962506548617966, 0.1256431228830479, 0.048800202494021505, 0.03574160575226415, 0.02836822943208972, 0.0682107855391223, 0.017790645360946655, 0.042949095368385315, 0.10017354972660542, 0.30558518366888165, 0.09397500616614707, 0.11816194775747135, 0.1348331375629641, 0.13048982218606398, 0.060360918869264424, 0.04135824245167896, 0.023710137684247456, 0.0940607613301836, 0.1516725425608456, 0.3342974226688966, 0.20168721035588533, 0.2717517100973055, 0.21416916948510334, 0.5601490207482129, 0.4120913310907781, 0.5060368962585926, 0.6626260187476873, 0.3682558739092201, 0.5599501251708716, 1.472533440683037, 1.3783189211972058, 3.3311496768146753, 5.929138669744134, 0.7980626856442541, 1.446395474486053, 1.8630298180505633, 2.329658791422844, 2.8769004391506314, 5.7137073297053576, 2.4684741301462054, 1.6118092671968043, 1.5918596251867712, 2.730552004650235, 5.588707812130451, 6.888941992074251, 7.675110781565309, 9.565227683633566, 9.014891814440489, 7.460911050438881, 10.874543376266956, 9.17111948132515, 8.556223176419735, 12.093289978802204, 22.515900805592537, 40.524213686585426, 44.43860024213791, 70.03583550453186, 69.25249233841896, 55.80820195376873, 30.200201869010925, 17.673267759382725, 9.177249502390623, 7.581204520538449, 8.113609626889229, 3.0266667902469635, 0.7402145897503942, 0.9080015332438052, 0.34021340834442526, 0.12447434419300407, 0.46053564408794045, 0.3442127234302461, 0.0161611284056562, 0.014046602173038991, 6.352739464491606, 11.16259166970849, 3.1702577602118254, 7.419943073764443, 13.18589000031352, 21.2217453494668, 26.257081255316734, 26.7037757858634, 30.569980926811695, 45.44896602630615, 61.43345430493355, 67.2479858994484, 52.84744642674923, 30.605326630175114, 22.09517978131771, 16.137992441654205, 7.9711695201694965, 6.281997710466385, 3.2928410824388266, 1.4573153760284185, 0.9745462937280536, 0.29549524071626365, 0.10127894158358686, 0.23603926703799516, 0.39271931746043265, 0.3293637139722705, 0.26295414310880005, 0.10563977906713262, 0.15670702006900683, 0.3801370644941926, 0.2066902059596032, 1.1263621598482132, 0.6583331397268921, 0.15775361156556755, 0.20259859738871455, 0.09278405210352503, 0.1892682001926005, 0.023124093349906616, 0.09004275896586478, 0.012113709162804298, 0.006006611647535465, 0.1358124311082065, 0.08440218429313973, 0.03350360748299863, 0.07566082756966352, 0.0868710053327959, 0.044208501421962865, 0.11340101846144535, 0.05917898190091364, 0.07234654447529465, 0.015105797192518367, 0.1172564533771947, 0.14889552985550836, 0.056425231814500876, 0.055387375396094285, 0.0027430494765212643, 0.03264074577600695, 0.04771597668877803, 0.09206995760905556, 0.22201980056706816, 0.0826590352517087, 0.11999792463029735, 0.10159497032873333, 0.1463441745727323, 0.13452726881951094, 0.09523263477603905, 0.21400506579084322, 0.018009833111136686, 0.024513321441190783, 0.07826930595911108, 0.12175123367342167, 0.21041903790319338, 0.10022554459283128, 0.04984265651728492, 0.014484260573226493, 0.12410529641783796, 0.06104553525801748, 0.005594125041170628, 0.083054421847919, 0.07320080840145238, 0.023645184919587336, 0.15470921789528802, 0.19463876669760793, 0.22416054038330913, 0.4169680131599307, 0.197811626130715, 0.16201871942030266, 0.17678894248092547, 0.16409971634857357, 0.39285489299800247, 0.5170266190543771, 0.32953823741991073, 0.3210617828881368, 0.16999156738165766, 0.24505575274815783, 0.24694251478649676, 0.45063963916618377, 0.29639822663739324, 0.3191254899138585, 0.2662762632826343, 0.1848774022073485, 0.1254403978236951, 0.30494281032588333, 0.17941417114343494, 0.18763553467579186, 0.26268981979228556, 0.07696858083363622, 0.132385861070361, 0.13080867851385847, 0.0748137550544925, 0.19979204720584676, 0.385766313993372, 0.5206712172366679, 0.29128408699762076, 0.2397944452241063, 0.22222926432732493, 0.08801866992143914, 0.11739078952814452, 0.15455808694241568, 0.12570335558848456, 0.1947642638697289, 0.26656813512090594, 0.519998415838927, 0.31524972757324576, 0.29857883462682366, 0.39807026158086956, 0.5418027739506215, 0.4980772139970213, 0.8056037966161966, 0.8172637084499002, 0.4618572606705129, 0.3124193544499576, 1.2384747876785696, 1.6825571958906949, 3.720476310700178, 6.949495067819953, 2.142830891534686, 7.324877874925733, 3.6050879023969173, 2.2141250409185886, 3.8028884259983897, 7.72649684920907, 3.968450529500842, 1.0876912786625326, 1.5825836104340851, 3.804042376577854, 7.5852513033896685, 8.028663285076618, 9.182259533554316, 7.073458191007376, 9.2064917832613, 6.213502110913396, 8.753256853669882, 5.209722323343158, 8.00404155626893, 10.884046666324139, 20.30150692909956, 46.54599756002426, 68.83720502257347, 87.7338494360447, 86.05579107999802, 72.70743414759636, 59.22615274786949, 50.54296888411045, 41.122993156313896, 25.452567525207996, 17.581812366843224, 10.595449302345514, 8.179005067795515, 4.038554392755032, 0.8453694940544665, 0.6251094443723559, 1.207701307721436, 0.8126946317497641, 0.0939503668632824, 0.1421304530231282, 13.810267746448517, 25.835197493433952, 22.747950553894043, 28.134976588189602, 38.876739889383316, 49.471536576747894, 52.541874423623085, 54.486537873744965, 54.1997292637825, 62.502606734633446, 73.40776696801186, 68.62883180379868, 63.30994561314583, 41.93920835852623, 28.994163684546947, 16.237410306930542, 7.540417034178972, 5.238721892237663, 2.8756619431078434, 0.9101497835945338, 0.3912990546086803, 0.2916573279071599, 0.15073491318617016, 0.3780587244546041, 0.30054237926378846, 0.27795330388471484, 0.5087705526966602, 0.2397415300947614, 0.2549577393801883, 0.6004221097100526, 0.6263061426579952, 1.2138091237284243, 0.695713396416977, 0.2767849853262305, 0.2223242147010751, 0.25259563175495714, 0.2563803771045059, 0.1461310891318135, 0.1695942660444416, 0.19297786988317966, 0.11807999238953926, 0.15629716159310192, 0.3059635899262503, 0.22064624849008396, 0.18156354955863208, 0.12297371416934766, 0.1468023913912475, 0.3081180149456486, 0.2674110367661342, 0.2456767373951152, 0.184276188374497, 0.26486603426747024, 0.2920756913954392, 0.304023259668611, 0.297389171901159, 0.15417245216667652, 0.09743663526023738, 0.11668807957903482, 0.18932362378109246, 0.2443204031442292, 0.2628912386717275, 0.35437100334092975, 0.5181070673279464, 0.45637293776962906, 0.30700556526426226, 0.23094210773706436, 0.41165278118569404, 0.20712505996925756, 0.09742332113091834, 0.1945897107361816, 0.2809858677210286, 0.3186819824622944, 0.27442359016276896, 0.2884975599590689, 0.22319055336993188, 0.45141476788558066, 0.15896352007985115, 0.3864339500432834, 0.17694865266093984, 0.46496510796714574, 0.3423608571756631, 0.2871186792617664], [0.06423887054552324, 0.06205631812918, 0.01688152930000797, 0.04949095644406043, 0.035335621287231334, 0.07437456690240651, 0.03848709944577422, 0.04708738502813503, 0.04138011354370974, 0.11987097284873016, 0.05393801664467901, 0.1282584067666903, 0.04081170634890441, 0.055458354399888776, 0.08176142247975804, 0.026967538869939744, 0.047062716039363295, 0.0866765106911771, 0.07676926965359598, 0.018942961360153276, 0.09939227602444589, 0.0694873537577223, 0.1562419458059594, 0.02788693738693837, 0.008133457067742711, 0.08829146856442094, 0.0218371035225573, 0.06353086908347905, 0.06899789994349703, 0.02540603789384477, 0.09205278431181796, 0.05113064267789014, 0.04653719013731461, 0.027437607786851004, 0.04811674385564402, 0.11311175898299553, 0.029251156956888735, 0.1117802421504166, 0.03430203221796546, 0.05619161485810764, 0.11890868190675974, 0.01601381580258021, 0.01751864081597887, 0.04287897354515735, 0.03867929342959542, 0.055059776568668894, 0.08295734893181361, 0.1358056627213955, 0.05160948006960098, 0.20987856143619865, 0.04408045126183424, 0.04539863541140221, 0.2379203590680845, 0.10379133411333896, 0.15580710663925856, 0.35051530867349356, 0.2842349011916667, 0.2599483262747526, 0.4781717446167022, 0.6162278959527612, 0.2773731225170195, 0.25865351606626064, 0.2805625170003623, 0.17892769334139302, 0.2738349779974669, 0.1557851242250763, 0.30436657718382776, 0.4996141721494496, 0.6470250058919191, 1.6931212227791548, 2.4989076470956206, 2.7857751538977027, 2.0892734779044986, 1.0354556003585458, 6.471270304173231, 9.990319423377514, 30.52036128938198, 45.98593421280384, 46.12917512655258, 30.1024654135108, 16.474449187517166, 3.4793723607435822, 1.5322610107250512, 5.273955976590514, 9.859679583460093, 6.522509129717946, 4.5587517041713, 1.681700460612774, 1.5887839277274907, 0.278825446148403, 0.015671834153181408, 0.3488220542203635, 0.7481352053582668, 6.416717106476426, 9.636916536837816, 7.995170932263136, 21.159768775105476, 25.51649149507284, 26.319648697972298, 15.715190079063177, 18.787628263235092, 15.114373918622732, 17.650073803961277, 38.483730778098106, 48.18820483982563, 54.95407238602638, 31.021501198410988, 14.313447196036577, 2.3756835842505097, 4.046082263812423, 4.718294693157077, 1.315692700445652, 0.05588225802057423, 0.214529111108277, 0.27851252700202167, 0.11910408196854405, 0.1965703841415234, 0.020571589593600947, 0.11424392010667361, 0.12492059759097174, 0.06141006335383281, 0.060522072526509874, 0.05491014846484177, 0.04159136959060561, 0.010401086510682944, 0.11472928468720056, 0.05029307707445696, 0.019732224282051902, 0.05320468939316925, 0.07667351776035503, 0.019261363122495823, 0.06861889254651032, 0.06581590467249043, 0.04349010618170723, 0.05626345475320704, 0.014699871171615086, 0.06520505776279606, 0.028628060899791308, 0.03353835112648085, 0.06632985678152181, 0.031224954364006408, 0.06074820863432251, 0.013564232158387313, 0.0540865241055144, 0.02975459097797284, 0.07595302595291287, 0.03404151982977055, 0.02533751910959836, 0.04770213934534695, 0.060720834517269395, 0.09697889341623522, 0.02890534025937086, 0.04213772757793777, 0.0845876766834408, 0.07657018111785874, 0.06057820857677143, 0.04587508308759425, 0.11784013026044704, 0.06825775606557727, 0.04220453942252789, 0.06412587856175378, 0.04741532524349168, 0.07942910466226749, 0.11656615213723853, 0.09115556487813592, 0.07287364001967944, 0.11061677723773755, 0.054109103948576376, 0.016944799244811293, 0.09889927474432625, 0.033710265925037675, 0.05338457485777326, 0.08303279566462152, 0.06996250638621859, 0.005141341671333066, 0.014926485036994563, 0.03800379061431158, 0.021972053800709546, 0.08218604969442822, 0.047750341836945154, 0.02541109006415354, 0.06757083159754984, 0.06100558544858359, 0.037784812520840205, 0.09014362425659783, 0.051242758927401155, 0.04887562696239911, 0.029880347901780624, 0.05768830407760106, 0.01964286970178364, 0.08994699222967029, 0.08299144319607876, 0.12451557791791856, 0.09856846983893774, 0.03854303511616308, 0.05313342837325763, 0.07278672710526735, 0.03941031260183081, 0.13180395792005584, 0.05118763590871822, 0.057507865712977946, 0.07309085922315717, 0.03436996470554732, 0.019217405715608038, 0.021460853204189334, 0.08168675500201061, 0.14273421984398738, 0.042235898872604594, 0.031290660408558324, 0.057822139278869145, 0.04657635327021126, 0.02090737430989975, 0.06685293730697595, 0.08920776861486956, 0.04033985998830758, 0.02178741488023661, 0.0847663264721632, 0.03964999661548063, 0.050117562859668396, 0.04659279926272575, 0.0721547809371259, 0.08653719472931698, 0.14430822600843385, 0.12600043730344623, 0.06483319724793546, 0.09626649843994528, 0.0931010085332673, 0.021482529482454993, 0.7732817810028791, 0.17256331688258797, 0.08960184903116897, 0.3950564592378214, 1.06223359471187, 0.8941680192947388, 1.3155000982806087, 0.7574972498696297, 0.6174028641544282, 0.42644927627407014, 0.8413121430203319, 1.360632770229131, 1.9643791671842337, 1.3993175444193184, 0.9658546163700521, 0.9672753838822246, 1.5790205891244113, 3.3379866974428296, 3.2093552872538567, 4.014759119600058, 4.76732631213963, 7.257158383727074, 12.885314729064703, 27.551584392786026, 46.284149810671806, 61.30201555788517, 66.85124918818474, 47.94084571301937, 29.008312225341797, 11.15658514201641, 10.726720858365297, 11.25542163848877, 6.036446811631322, 5.3083560056984425, 4.140216037631035, 4.719081250950694, 3.1657117791473866, 0.3643939452013001, 0.26179808482993394, 0.3744449996156618, 1.1070741573348641, 12.431915458291769, 24.38914518803358, 19.803036376833916, 16.18639424443245, 21.76208395510912, 25.145411007106304, 23.302057720720768, 24.17768083512783, 20.432162918150425, 27.70828988403082, 47.308669835329056, 61.19623303413391, 59.95294734835625, 46.33881367743015, 28.976528830826283, 16.747413240373135, 9.53673966228962, 6.464048316702247, 3.52946222294122, 0.9578821691684425, 0.22030742838978767, 0.10305253352271393, 0.2581919595832005, 0.2534976974129677, 0.1875468183425255, 0.12085555048543029, 0.08640960470074788, 0.05246217806416098, 0.10003718751249835, 0.07514887183788233, 0.11100434901891276, 0.12079373700544238, 0.11635435061180033, 0.11947147475439124, 0.03234747127862647, 0.03287275969341863, 0.059110325819347054, 0.018373403836449143, 0.02566789356933441, 0.09608295047655702, 0.026488792391319294, 0.06265650037676096, 0.05984999472275376, 0.060236397621338256, 0.02506902121240273, 0.04334642639150843, 0.09302255610236898, 0.06480541866039857, 0.049826373797259293, 0.0302682369510876, 0.032367947133025154, 0.03461488457105588, 0.08605299532064237, 0.1635960949352011, 0.042619225569069386, 0.023182287004601676, 0.03835552779491991, 0.07387678619124927, 0.04964652544003911, 0.04552072612568736, 0.022107699842308648, 0.09764482252649032, 0.06989198009250686, 0.07705403171712533, 0.059571733872871846, 0.01795508858776884, 0.03191754512954503, 0.03770322822674643, 0.12183211292722262, 0.05597685216343962, 0.09739129745867103, 0.05513858523045201, 0.04611720134562347, 0.028808124479837716, 0.06402211147360504, 0.059432039415696636, 0.06945147091755643, 0.06143353748484515, 0.07567010441562161, 0.052320858303573914, 0.037401259469334036, 0.0333480496192351, 0.03794039635977242, 0.14646438765339553, 0.1999470966984518, 0.13632114365464076, 0.2882147126365453, 0.15492723119677976, 0.14983814646257088, 0.14649909047875553, 0.12362811030470766, 0.21805886935908347, 0.2037184388609603, 0.14792088215472177, 0.3364495321875438, 0.22059558948967606, 0.2307555021252483, 0.11283389147138223, 0.12480262579629198, 0.17481195012805983, 0.2770251443143934, 0.13059410877758637, 0.13459594716550782, 0.1619679416762665, 0.13226397073594853, 0.337148635298945, 0.17546247225254774, 0.11387485748855397, 0.2468913362827152, 0.19577462371671572, 0.18148549046600237, 0.1141562576231081, 0.22682911047013476, 0.2649256435688585, 0.13535348698496819, 0.12383626788505353, 0.0974411029892508, 0.17189827834954485, 0.19826049188850448, 0.18454009608831257, 0.24232312047388405, 0.15331806207541376, 0.18751230847556144, 0.2529323589988053, 0.1041519436694216, 0.1955126752727665, 0.15509541670326144, 0.18470194365363568, 0.16035433451179415, 0.22352796338964254, 0.34767080505844206, 0.10585801501292735, 0.414051313418895, 0.4254899761872366, 0.04678563891502563, 0.6989411450922489, 0.2603064867435023, 0.4283331142505631, 0.6457194196991622, 1.651724937837571, 1.8219841830432415, 1.772877280600369, 1.099598533473909, 1.2440805556252599, 0.49702303775120527, 1.0112869972363114, 1.099997393321246, 1.2464042496867478, 0.6929433450568467, 0.3738140850327909, 0.6039776501711458, 0.7920096104498953, 2.6920339465141296, 3.5074207931756973, 4.344043275341392, 6.115650236606598, 8.414758667349815, 14.655894320458174, 29.596638455986977, 51.179233342409134, 71.03195205330849, 71.75890624523163, 66.11579865217209, 56.264371275901794, 39.539059549570084, 36.12780399620533, 36.15036718547344, 26.188019961118698, 15.147627834230661, 9.547511134296656, 18.96267917007208, 10.279216971248388, 0.652062229346484, 0.37965745897963643, 0.7134611159563065, 2.3688845615833998, 20.537649057805538, 44.05829004943371, 46.742390021681786, 52.36173748970032, 46.21460974216461, 46.3719516992569, 49.92380350828171, 54.932618737220764, 44.7067366540432, 52.86102309823036, 60.378300324082375, 62.33412377536297, 61.83630108833313, 51.80966131389141, 30.52137963473797, 17.216553166508675, 11.032302360981703, 5.781224956735969, 2.607485633343458, 0.4901695711305365, 0.19504817988490686, 0.2191378630232066, 0.2676343935308978, 0.29690552910324186, 0.15843310713535175, 0.17948322056327015, 0.15454938897164539, 0.16454292694106698, 0.19257813430158421, 0.2080769682652317, 0.21185573190450668, 0.13494082319084555, 0.3192728210706264, 0.3958635893650353, 0.23912412259960547, 0.1048274761706125, 0.13488265365594998, 0.18392899684840813, 0.1648958181613125, 0.2593061013612896, 0.08548191268346272, 0.1718932465882972, 0.09391432817210443, 0.12120957719162107, 0.10467532105394639, 0.11332003530696966, 0.13004008069401607, 0.16720219049602747, 0.14265951525885612, 0.12507116451160982, 0.1346554228803143, 0.16255714755970985, 0.19275782309705392, 0.17790482088457793, 0.16326509707141668, 0.16116998449433595, 0.18234425922855735, 0.2876933093648404, 0.1128400512970984, 0.14578211645130068, 0.16032347601139918, 0.23396695323754102, 0.15169228368904442, 0.24056708032730967, 0.21042159089120105, 0.10939865314867347, 0.14606392476707697, 0.14862016338156536, 0.3475444915238768, 0.21701966965338215, 0.26941967429593205, 0.2292384483735077, 0.16766120883403346, 0.29109997500199825, 0.1303475524764508, 0.15052393544465303, 0.22828122630016878, 0.1661276794038713, 0.11688117156154476, 0.16651751473546028, 0.237676979159005, 0.10843677038792521, 0.1603850891115144], [0.038515015330631286, 0.027748083412006963, 0.03426956696785055, 0.007944986809889087, 0.018274521935381927, 0.04359500133432448, 0.06949996284674853, 0.01060393773514079, 0.051957662362838164, 0.06180235890496988, 0.06688882756861858, 0.05213556258240715, 0.07162027875892818, 0.038933315736358054, 0.10317326610675082, 0.0842951146478299, 0.019783248790190555, 0.07171616423875093, 0.08254026935901493, 0.07575790790724568, 0.01603978540515527, 0.022248362802201882, 0.0456741577363573, 0.0865425901429262, 0.08406417313381098, 0.07821265040547587, 0.07575816023745574, 0.05261412909021601, 0.02931112248916179, 0.05826839267683681, 0.05100959839182906, 0.036331453593447804, 0.08092768635833636, 0.02760666531685274, 0.033400248576072045, 0.03405656687391456, 0.08955380981205963, 0.0272050465355278, 0.1249517677933909, 0.0788005352660548, 0.046997154713608325, 0.04190493440546561, 0.016889902581169736, 0.02247874585009413, 0.04687149797973689, 0.06271924154134467, 0.07824828833690844, 0.07550822716439143, 0.02831895268172957, 0.07319184325751849, 0.023186441176221706, 0.05771533309598453, 0.03130775578028988, 0.020868671308562625, 0.09965590172214434, 0.07697444380028173, 0.07009063076111488, 0.06509536091471091, 0.0734517136879731, 0.03573308960767463, 0.02684878410946112, 0.12224964521010406, 0.19760996976401657, 0.08748055348405614, 0.029467715648934245, 0.11645751656033099, 0.2074225721298717, 0.16723549808375537, 0.2553009381517768, 0.7035397295840085, 0.6013883266132325, 0.6161180580966175, 2.4860557867214084, 2.0798765821382403, 6.004766011610627, 12.421914394944906, 25.686591267585754, 40.05451329052448, 40.0225456058979, 34.459317326545715, 11.730987969785929, 2.2814650274813175, 2.7021580282598734, 2.7263532299548388, 2.6061153318732977, 7.798471637070179, 6.477496270090342, 0.8730331971310079, 10.61930252239108, 13.744815308600664, 11.117273401468992, 13.26549667865038, 19.36146017163992, 21.733403094112873, 26.467745751142502, 30.812016539275646, 34.891403540968895, 32.207162976264954, 29.833149164915085, 22.507759742438793, 12.543963845819235, 9.62041212245822, 13.616007920354605, 38.42366360127926, 60.55449306964874, 46.5801615267992, 24.899203218519688, 10.587344337254763, 4.231716077774763, 5.05435056053102, 0.278983197058551, 0.40814853797201067, 0.19110480789095163, 0.17085611005313694, 0.13038019213126972, 0.057432537723798305, 0.08800895520835184, 0.04490593099035323, 0.06437844625907019, 0.035371047706576064, 0.030288553243735805, 0.018913613130280282, 0.06021609988238197, 0.04592957528075203, 0.09836856494075619, 0.038850840865052305, 0.07047078106552362, 0.07878477947087958, 0.03490383234748151, 0.056848248568712734, 0.03077565816056449, 0.04265510469849687, 0.018967081159644295, 0.05827860833960585, 0.017044386186171323, 0.04977450880687684, 0.06751143009751104, 0.05104587457026355, 0.04316816251957789, 0.037901381656411104, 0.003280741498201678, 0.034093741051037796, 0.05956886176136322, 0.021263941016513854, 0.005787304226032575, 0.0530848325433908, 0.07715013984125108, 0.022127663614810444, 0.030929885724617634, 0.0750331710150931, 0.08610233329818584, 0.026694805164879654, 0.07828905450878665, 0.08931168413255364, 0.017588846130820457, 0.028020496138196904, 0.02280609420267865, 0.12799576070392504, 0.09410814003786072, 0.051588900314527564, 0.016521153520443477, 0.06934497272595763, 0.026435843865328934, 0.10111206225701608, 0.012707628611678956, 0.07462508627213538, 0.03561841665941756, 0.01503569577835151, 0.07188820149167441, 0.1161148224491626, 0.06596591498237103, 0.027705498978320975, 0.0472297437954694, 0.02660544130776543, 0.026363753495388664, 0.08198984811315313, 0.05093226660392247, 0.08314043676364236, 0.04335600009653717, 0.04510822931479197, 0.06290555771556683, 0.030028903602214996, 0.1329740576329641, 0.06094291849876754, 0.08760196142247878, 0.048001020768424496, 0.039933771622600034, 0.004566705074466881, 0.09521403655526228, 0.06299058557488024, 0.08856771819409914, 0.06603909816476516, 0.012548824779514689, 0.007272464181369287, 0.015489225006604102, 0.032068086075014435, 0.04007322117104195, 0.016755026517785154, 0.12838136579375714, 0.10362835848354734, 0.026382526120869443, 0.03192600190232042, 0.011472438836790388, 0.08973540592705831, 0.02358118952543009, 0.08853680774336681, 0.03310115193016827, 0.048341666552005336, 0.05840040590555873, 0.05468419047247153, 0.038109828674350865, 0.04615782650944311, 0.09766232236870565, 0.03973276092438027, 0.03574755406589247, 0.0049411561485612765, 0.06897239232785068, 0.07685371863772161, 0.03439496395003516, 0.07077857197145931, 0.0361265354877105, 0.015101081771717872, 0.08145756495650858, 0.08863276001648046, 0.026133003084396478, 0.048509373373235576, 0.08957954749348573, 0.04699208955571521, 0.05013940426579211, 0.01662544753344264, 0.0886722793802619, 0.03831862450169865, 0.0752239697612822, 0.0937196405720897, 0.037990973723935895, 0.07194847130449489, 0.026730671306722797, 0.14800633303821087, 0.3810680442256853, 0.3522926929872483, 0.2112401055637747, 0.26080333977006376, 0.28549524606205523, 0.3254360309801996, 0.4270065698074177, 1.1234409478493035, 1.1367478338070214, 1.3914645533077419, 3.4398198081180453, 2.9811827559024096, 6.714029302820563, 18.55133604258299, 40.71220479905605, 58.044264167547226, 60.15615664422512, 49.13795247673988, 25.64690239727497, 8.12704000622034, 7.105772607028484, 11.564341261982918, 10.68589299917221, 7.592481840401888, 6.834641955792904, 5.746902823448181, 16.93751323968172, 21.54967725276947, 19.525900147855282, 21.728326566517353, 31.763671673834324, 35.44085405766964, 38.98379534482956, 45.05893215537071, 50.09834334254265, 42.72437542676926, 32.67646439373493, 25.741496421396732, 17.11250524967909, 15.658653862774372, 28.848857581615448, 52.841328755021095, 61.85610942542553, 61.23062498867512, 39.73594978451729, 17.499742470681667, 9.337466955184937, 7.581195496022701, 2.5174858001992106, 1.1076381895691156, 0.4279185802442953, 0.13433334563160315, 0.06816681328928098, 0.09872590904706158, 0.222529225575272, 0.040249217781820334, 0.026838830053748097, 0.015717082897026557, 0.04554981831461191, 0.013161970491637476, 0.06895681464811787, 0.03885846643242985, 0.06881364693981595, 0.0429081547918031, 0.021714437643822748, 0.0857258566247765, 0.04171964610577561, 0.059481165881152265, 0.030599117926612962, 0.02791772723867325, 0.06524062890093774, 0.14484196377452463, 0.053189482787274756, 0.042846627038670704, 0.05507473826583009, 0.034585762696224265, 0.029133944008208346, 0.019511515129124746, 0.02222076233010739, 0.024284426399390213, 0.07017372161499225, 0.021663537445419934, 0.0030367551153176464, 0.04396591190015897, 0.06758552612154745, 0.07233448457554914, 0.04476834423257969, 0.03823262813966721, 0.09879965626168996, 0.023236222587001976, 0.004167945880908519, 0.07735064587905072, 0.020432114069990348, 0.04750257954583503, 0.06168668405734934, 0.08221808078815229, 0.04130860761506483, 0.07819105390808545, 0.0614037365448894, 0.010546414796408499, 0.03954063002311159, 0.025838105138973333, 0.013178343197068898, 0.06327603783574887, 0.024182601882785093, 0.05212649724853691, 0.10868809869862162, 0.08588526994572021, 0.10153737966902554, 0.03668391807877924, 0.08376320998650044, 0.08536016335710883, 0.01778691050276393, 0.046246617057477124, 0.18166080059017986, 0.15603172505507246, 0.11841547282529064, 0.10424423715448938, 0.20759785256814212, 0.11238807594054379, 0.3141077404143289, 0.15186364558758214, 0.10802052944200113, 0.15485764743061736, 0.23532288672868162, 0.0981212813348975, 0.26474791404325515, 0.25938218634109944, 0.17918253201059997, 0.2177923492854461, 0.13552527932915837, 0.2516673831269145, 0.22850759618449956, 0.30476641666609794, 0.2003794867778197, 0.08116071330732666, 0.3142722003394738, 0.1789730237214826, 0.1640150076127611, 0.17098215641453862, 0.159019106940832, 0.16208720480790362, 0.09909650791087188, 0.23378628480713814, 0.14556474139681086, 0.19807354488875717, 0.12527074286481366, 0.2769245981471613, 0.1470085303299129, 0.16995968471746892, 0.17506474046967924, 0.08987528592115268, 0.23318533814745024, 0.1162921437935438, 0.20338879170594737, 0.1899941690498963, 0.19912864139769226, 0.1711702166358009, 0.11793788595241494, 0.12755868025124073, 0.1829860091675073, 0.10558280438999645, 0.11141443013912067, 0.10991277595167048, 0.14949729287764058, 0.1302185672102496, 0.11066777762607671, 0.06961524064536206, 0.12540833704406396, 0.17385843879310414, 0.14691752818180248, 0.21094407769851387, 0.13722841918934137, 0.13502820365829393, 0.15457649220479652, 0.23519960115663707, 0.2977233164710924, 0.34903371473774314, 0.21415920986328274, 0.18954855389893055, 0.311338342144154, 0.2771578700048849, 0.27348183444701135, 1.0383980674669147, 1.2870320258662105, 1.3399602170102298, 4.26649228669703, 6.221658373251557, 9.78517983108759, 21.754533760249615, 46.44982472062111, 62.80620664358139, 71.15149363875389, 68.75407308340073, 53.45491982996464, 36.701573207974434, 34.75075028836727, 32.38394469022751, 28.53709001094103, 28.538032360374928, 27.729321755468845, 29.929888173937798, 38.674792125821114, 39.37723383307457, 27.46931880712509, 31.057276278734207, 45.78926436603069, 53.858868554234505, 57.17144340276718, 65.03888323903084, 67.73098558187485, 62.0420790463686, 51.12827807664871, 48.88081267476082, 35.5842811614275, 36.28684066236019, 44.612775295972824, 66.70425027608871, 69.94773343205452, 62.82998576760292, 38.99011440575123, 22.400419302284718, 14.988670013844967, 8.095959573984146, 0.9786889620590955, 0.4171872138977051, 0.19345674809301272, 0.16022669995436445, 0.23375523334834725, 0.14895191823597997, 0.30813728109933436, 0.12887470104033127, 0.10709778012824245, 0.11080454059992917, 0.17273953242693096, 0.14780014957068488, 0.11267680107266642, 0.11466419091448188, 0.2237540957867168, 0.14685613772599027, 0.10721884667873383, 0.16548155079362914, 0.2698996657272801, 0.2034046736662276, 0.19086987362243235, 0.1104685703467112, 0.10291202270309441, 0.127610630588606, 0.11279342958005145, 0.1581511355470866, 0.13193803431931883, 0.1815493596950546, 0.17591104115126655, 0.09736440944834612, 0.13576616562204435, 0.14219019591109827, 0.15362857666332275, 0.11846688881632872, 0.10865493211895227, 0.1253083549090661, 0.15484345756703988, 0.15907371416687965, 0.24092289560940117, 0.15919734112685546, 0.17799852445023134, 0.0935063102224376, 0.12307734024943784, 0.13128378661349416, 0.06898399951751344, 0.14873467676807195, 0.11185764815309085, 0.17608387250220403, 0.26137434819247574, 0.2419972137431614, 0.1447153088520281, 0.1661286293528974, 0.12698226899374276, 0.25815894885454327, 0.06891186276334338, 0.14987954345997423, 0.13019898935453966, 0.12831678410293534, 0.22675735963275656, 0.19103866769000888, 0.1386770320823416, 0.1667275870568119, 0.11722599563654512, 0.22853846952784806, 0.15470252372324467, 0.17096134659368545], [0.039134968392318115, 0.014638716347690206, 0.05867143452633172, 0.008452925667370437, 0.09094334774999879, 0.023769708022882696, 0.045415107379085384, 0.07581946905702353, 0.12918281106976792, 0.06641986445174553, 0.10318917033146136, 0.05311026965500787, 0.07316345610888675, 0.04322248030803166, 0.050088964198948815, 0.038752035034121946, 0.028425749587768223, 0.017925567808561027, 0.09789018396986648, 0.02613292701425962, 0.08900305459974334, 0.057120271667372435, 0.09559737067320384, 0.03901514493918512, 0.048544213495915756, 0.047666419777669944, 0.015021165454527363, 0.04591771576087922, 0.024884760787244886, 0.11934171765460633, 0.02210141385148745, 0.019369948604435194, 0.05625476420391351, 0.007300774796021869, 0.022527970650116913, 0.021096545897307806, 0.05336487083695829, 0.04739794043416623, 0.03251774593081791, 0.039559295037179254, 0.02483826709067216, 0.07775773614412174, 0.04918087972328067, 0.040276988947880454, 0.044479351927293465, 0.03382563649211079, 0.06150813445856329, 0.013178166936995694, 0.025105286258622073, 0.0707371230237186, 0.006436492340071709, 0.024952650601335336, 0.08984983767732047, 0.018505320585973095, 0.030073523375904188, 0.05211018113186583, 0.07407204524497502, 0.10706229804782197, 0.04301124281482771, 0.1005523641651962, 0.06954344527912326, 0.06563529561390169, 0.051008904483751394, 0.07170812677941285, 0.01120218576033949, 0.017025428023771383, 0.09321580393589102, 0.12982338841538876, 0.11208323136088438, 0.16350797232007608, 0.3936441818950698, 0.1953479927033186, 0.057458850569673814, 0.7893862074706703, 4.418050004169345, 10.638221707195044, 30.847415439784527, 31.8482893332839, 41.08817562460899, 35.4614869505167, 25.021208971738815, 4.995771953836083, 0.5378956336062402, 6.796396058052778, 3.835243689827621, 4.768805857747793, 5.979490717872977, 8.206460494548082, 15.455954689532518, 18.118997141718864, 17.22048595547676, 18.577571734786034, 27.67240460962057, 42.56368964910507, 44.58952434360981, 44.75410111248493, 40.48364706337452, 27.21528723835945, 19.308819696307182, 18.59150368720293, 10.867472905665636, 13.80503162741661, 25.591210685670376, 51.79057113826275, 49.81533072888851, 44.72246780991554, 24.24778327345848, 7.816836051642895, 3.267155410721898, 0.8441363414749503, 0.8386946772225201, 0.2063301604357548, 0.10507314931601286, 0.12301508148084395, 0.13636669667903334, 0.0021800569447805174, 0.09819789323955774, 0.03299454241641797, 0.041278205535491, 0.09577437289408408, 0.03903778415406123, 0.017533875252411235, 0.0427407262759516, 0.03661438255221583, 0.05876782837731298, 0.026453416066942737, 0.06863213988253847, 0.04141209268709645, 0.07626498772879131, 0.026713698389357887, 0.06282938367803581, 0.08455982388113625, 0.07436272222548723, 0.06305468486971222, 0.03664296636998188, 0.03449809650192037, 0.05594993446720764, 0.01083631159417564, 0.008852349546941696, 0.06340016203466803, 0.06388053196133114, 0.037862927274545655, 0.011011284041160252, 0.05145961818925571, 0.04642862877517473, 0.12779918062733486, 0.027430141781223938, 0.02579272466391558, 0.04453475325135514, 0.07306929241167381, 0.02568970714492025, 0.03182260217727162, 0.017019494553096592, 0.018121353787137195, 0.07159886037698016, 0.04611352771462407, 0.02138145824574167, 0.0430035430326825, 0.03792040290136356, 0.044719733559759334, 0.1124977579456754, 0.09049116459209472, 0.1015832889243029, 0.0504496739449678, 0.01777930163370911, 0.08861328606144525, 0.0634320150129497, 0.07029242813587189, 0.04944290609273594, 0.0695975478447508, 0.02703871639823774, 0.022520868296851404, 0.0362306662282208, 0.013579333008237882, 0.04497455738601275, 0.0465890922350809, 0.0792342983186245, 0.07072910040733404, 0.11061196069931611, 0.07209881558082998, 0.07917388749774545, 0.031291268969653174, 0.0264197837896063, 0.10869426594581455, 0.0768812300520949, 0.09674755856394768, 0.11708641250152141, 0.07541991159087047, 0.06168112166051287, 0.0476699709543027, 0.07765385031234473, 0.05266825763101224, 0.028793756500817835, 0.10206515798927285, 0.07381445320788771, 0.02281946213770425, 0.06012975471094251, 0.11750488731195219, 0.03851281857350841, 0.058491623276495375, 0.03247000728151761, 0.09875696792732924, 0.05785841916804202, 0.05157740073627792, 0.015794641039974522, 0.08883995280484669, 0.036841424080193974, 0.06042659893864766, 0.030360873679455835, 0.11068106949096546, 0.05816077013150789, 0.15338354918640107, 0.18169490969739854, 0.08876650987076573, 0.06503545475425199, 0.028384690267557744, 0.056139701628126204, 0.02752442793280352, 0.07084082331857644, 0.025673960626590997, 0.0440293358406052, 0.022854265153000597, 0.1288945460692048, 0.04702707439719234, 0.056002474811975844, 0.019460781913949177, 0.005842142445544596, 0.010306697386113228, 0.09575201198458672, 0.015700705553172156, 0.015483336992474506, 0.02001886212383397, 0.06899736559716985, 0.05630360865325201, 0.12683566514169797, 0.08217778959078714, 0.049896491909748875, 0.017858774517662823, 0.1495113639975898, 0.09409521182533354, 0.10379793922766112, 0.028532052965601906, 0.0012377301231936144, 0.04338135928264819, 0.2810448833042756, 0.20586078171618283, 0.37850546767003834, 0.5326858162879944, 1.5678124967962503, 2.2834625327959657, 6.428025299683213, 11.985314972698689, 33.667268827557564, 45.74932090938091, 53.93771052360535, 49.07661996781826, 36.227829828858376, 10.393622182309628, 7.895593950524926, 10.61236409470439, 10.269945468753576, 8.553911000490189, 9.504841323941946, 20.315815061330795, 29.656314253807068, 30.139935202896595, 31.367204748094082, 33.383705243468285, 44.395632147789, 57.80540518462658, 64.41459953784943, 64.54703763127327, 55.95411792397499, 39.21032018959522, 26.717236563563347, 24.073454327881336, 16.51191897690296, 24.43671863526106, 35.252547562122345, 56.782382279634476, 67.81175404787064, 51.594934836030006, 33.064982146024704, 14.524542018771172, 7.14970632456243, 4.8133940901607275, 1.654750406742096, 0.5728535202797502, 0.27586573152802885, 0.023754766734782606, 0.17395077680703253, 0.048914957078523, 0.052994130965089425, 0.02033651246165391, 0.03142488523735665, 0.05377079964091536, 0.009777793784451205, 0.04379595637146849, 0.16823380545247346, 0.08119494857965037, 0.04853232800087426, 0.018122090368706267, 0.05558802244195249, 0.04059235718159471, 0.034793267186614685, 0.06184288016811479, 0.06947904170374386, 0.053124196056160145, 0.02057369358226424, 0.03678795605082996, 0.0752467017446179, 0.01186516297821072, 0.04011408382211812, 0.036875035948469304, 0.08975120625109412, 0.05941463605267927, 0.051085701925330795, 0.04304373032937292, 0.022342240772559308, 0.05687353725079447, 0.03460204912698828, 0.098590103443712, 0.1337758739828132, 0.07679255082621239, 0.08576830747188069, 0.06683055413304828, 0.03806777858699206, 0.03752427044673823, 0.04182040378509555, 0.03255252668168396, 0.02069379719614517, 0.04781412200827617, 0.01024042081553489, 0.05604720405244734, 0.05699374290998094, 0.00880044466612162, 0.029986593763169367, 0.053775790584040806, 0.040885171547415666, 0.010669592757039936, 0.023312183257075958, 0.022095474814705085, 0.056474232114851475, 0.08794158304226585, 0.044984353735344484, 0.06574340426595882, 0.07906525192083791, 0.038004892703611404, 0.06849799668998457, 0.013266917594592087, 0.03750562398636248, 0.11959882729570381, 0.18320280534680933, 0.17846232221927494, 0.18866186554078013, 0.1904474728507921, 0.29068024596199393, 0.18910828221123666, 0.20275921298889443, 0.2555679331999272, 0.2206903469050303, 0.1967074885033071, 0.22366830351529643, 0.21161158016184345, 0.27474140748381615, 0.09060077238245867, 0.13796161656500772, 0.16271146974759176, 0.2377664970117621, 0.22458487073890865, 0.2168061982956715, 0.40348663344047964, 0.24001404672162607, 0.2737897069891915, 0.210195770196151, 0.13852964155375957, 0.11518067374709062, 0.16395401791669428, 0.13582335552200675, 0.13253519602585584, 0.09899996934109367, 0.17904757987707853, 0.13237417966593057, 0.15721460455097258, 0.08567357232095674, 0.18033238593488932, 0.13921743433456868, 0.2604086953215301, 0.24074429034953937, 0.2289283790742047, 0.10294846957549453, 0.12095233396394178, 0.08949886861955747, 0.14996256009908393, 0.1592732925200835, 0.13758999353740364, 0.10490601765923202, 0.17924683168530464, 0.24471951532177627, 0.13965383201139048, 0.32187113945838064, 0.2084322046721354, 0.08390170958591625, 0.1649446366354823, 0.22168832772877067, 0.13527001021429896, 0.07988588913576677, 0.1044643358909525, 0.23656335688428953, 0.30020989710465074, 0.19679918827023357, 0.3144469909602776, 0.30210219556465745, 0.10145417749299668, 0.2674726350232959, 0.32883399864658713, 0.18482374493032694, 0.13219321437645704, 0.12938258238136768, 0.14930138073395938, 0.23530183942057192, 0.18105130438925698, 0.35967385629191995, 0.290027690352872, 0.9994886303320527, 2.0767248887568712, 7.093677381053567, 16.32306531071663, 44.95068736374378, 52.81517095863819, 70.26107221841812, 64.3488858640194, 63.75285744667053, 46.47193193435669, 35.134389102458954, 37.908745631575584, 37.022697776556015, 37.7532921731472, 41.91430829465389, 49.72371764481068, 50.220297798514366, 46.23126804828644, 42.36098192632198, 41.03697717189789, 54.13065657019615, 73.17777290940285, 81.71146139502525, 80.46735495328903, 75.44483006000519, 61.34358152747154, 45.963435620069504, 41.66360154747963, 38.94990876317024, 43.974671736359596, 55.441821813583374, 71.01308226585388, 68.822051435709, 53.711668252944946, 39.78424899280071, 15.889310985803604, 8.773750104010105, 3.090276326984167, 1.2070444179698825, 0.24941181822214276, 0.18252669397043064, 0.24824159976560622, 0.18230710731586441, 0.1449699397198856, 0.19954449642682448, 0.15225177397951484, 0.09951969535904936, 0.15328935580328107, 0.1774597549228929, 0.07591660134494305, 0.23111056041670963, 0.14164155581966043, 0.11567949346499518, 0.17659190227277577, 0.1764458030811511, 0.09753282502060756, 0.20372698840219527, 0.2041768783237785, 0.16305600438499823, 0.10986631008563563, 0.1626963002490811, 0.19192073988961056, 0.14536166010657325, 0.09233723467332311, 0.08839287562295794, 0.08252707397332415, 0.1308126564254053, 0.23719453864032403, 0.11795943792094477, 0.24308904656209052, 0.12013689920422621, 0.08526639299816452, 0.11104489996796474, 0.24302289151819423, 0.1938925075228326, 0.1088846342463512, 0.1868107117479667, 0.1405896505457349, 0.1626157178543508, 0.10594141756882891, 0.1271982933394611, 0.07013087742961943, 0.13548245740821585, 0.1615077507449314, 0.13357479649130255, 0.11478136118967086, 0.26833973068278283, 0.23154263879405335, 0.2236629748949781, 0.18469477450707927, 0.16105903341667727, 0.0637768761953339, 0.11568067347980104, 0.12895653024315834, 0.1680285867769271, 0.37945791031233966, 0.3195568855153397, 0.3231884218985215, 0.23555752413813025, 0.12982502114027739, 0.148985953128431, 0.07330731401452795, 0.11380387106328271, 0.17066781234461814], [0.00912866782527999, 0.04349159047706053, 0.03421224719204474, 0.0468667148379609, 0.06727862579282373, 0.06253518891753629, 0.04001737826911267, 0.03151700060698204, 0.05947652374743484, 0.06082767780753784, 0.054567020197282545, 0.03442526955041103, 0.051473329367581755, 0.08369054630747996, 0.015538762436335674, 0.03255550269386731, 0.034100969569408335, 0.09339902535430156, 0.1563090507988818, 0.02152426230168203, 0.09617218631319702, 0.06350962881697342, 0.011262210664426675, 0.03403089227504097, 0.11829266222775914, 0.04478603332245257, 0.07820393017027527, 0.0470798670721706, 0.029528924278565682, 0.005423621250884025, 0.03099951773037901, 0.022184775589266792, 0.024204847759392578, 0.032051009256974794, 0.058318339215475135, 0.047416067391168326, 0.03388411772903055, 0.03673959399748128, 0.06438854688894935, 0.08449054439552128, 0.02473295262461761, 0.014581563555111643, 0.018248713749926537, 0.0315296690678224, 0.027627081799437292, 0.04513789666816592, 0.023374134034384042, 0.026483988840482198, 0.05233214636973571, 0.020923263691656757, 0.042767514096340165, 0.03320350151625462, 0.036829534874414094, 0.030532653036061674, 0.02577598366769962, 0.07985860778717324, 0.16300173854688182, 0.05259264391497709, 0.02687010601221118, 0.029971854710311163, 0.06436617855797522, 0.04944671702105552, 0.05296916882798541, 0.026761822955450043, 0.10958645361824892, 0.08217651309678331, 0.034046963482978754, 0.028607149033632595, 0.021736579619755503, 0.09884135753964074, 0.30404329765588045, 0.1984512386843562, 0.33129225892480463, 1.1434581549838185, 4.023426454514265, 8.982063475996256, 21.70135371387005, 36.90505228936672, 30.08593440055847, 47.95577511191368, 30.309107825160027, 13.224609922617674, 5.251186648383737, 8.450189866125584, 7.414552113041282, 6.3477574568241835, 7.236180659383535, 10.870507042855024, 21.15616086870432, 25.77564138919115, 34.95694242417812, 38.78070384263992, 51.91659897565842, 45.309441313147545, 42.211919724941254, 33.93830068409443, 39.97814118862152, 25.41017509996891, 20.315881557762623, 13.556125033646822, 8.814968392252922, 15.574153997004032, 44.23701345920563, 46.62491552531719, 44.58016164600849, 23.784314543008804, 16.686844490468502, 8.94463263452053, 2.760585593059659, 1.5073559596203268, 0.27906857372727245, 0.11011681461241096, 0.13914491166360676, 0.07964193035149947, 0.003659748895188386, 0.06520224502310157, 0.02019389023189433, 0.03549042216036469, 0.03105340507318033, 0.021089007532282267, 0.008802752745395992, 0.02946271913970122, 0.08079843391897157, 0.049387668041163124, 0.10778822237625718, 0.06830851154518314, 0.025541990071360487, 0.04332599135523196, 0.03524693463987205, 0.027432000861153938, 0.028217454710102174, 0.09006467458675615, 0.017232784084626473, 0.0568389160616789, 0.057860812594299205, 0.017560833766765427, 0.04843110276851803, 0.01638776360778138, 0.02820296798745403, 0.02412941958027659, 0.05001484591048211, 0.05635903224174399, 0.03680612753669266, 0.07909320862381719, 0.029179801313148346, 0.03307415630843025, 0.06279870329308324, 0.07055908179609105, 0.11107754704426043, 0.05645762284984812, 0.06418052289518528, 0.07912233049864881, 0.05888634936127346, 0.05205740701057948, 0.09375746783916838, 0.01903527525428217, 0.02192895542975748, 0.02324862016394036, 0.05994477069179993, 0.06401181046385318, 0.006227543908607913, 0.0678117030474823, 0.1357971428660676, 0.10630370437866077, 0.08069862247793935, 0.030023725266801193, 0.0819759996375069, 0.097873515333049, 0.041308373838546686, 0.03996180254034698, 0.08877060652594082, 0.07585735569591634, 0.07268962450325489, 0.039810166927054524, 0.06148347289126832, 0.040459523879690096, 0.13464314775774255, 0.11243768109125085, 0.06885859882459044, 0.016956495492195245, 0.058442485678824596, 0.037718791063525714, 0.09821369356359355, 0.06845814335974865, 0.07554601732408628, 0.04731576984340791, 0.042737286421470344, 0.06290287114097737, 0.07901941688032821, 0.015947775791573804, 0.06147471554868389, 0.02321372252481524, 0.06292392587056383, 0.08767297011218034, 0.029657826053153258, 0.051542549481382594, 0.12008118617814034, 0.05906276899622753, 0.04019308544229716, 0.04019662919745315, 0.03159009473165497, 0.09829781600274146, 0.06935531084309332, 0.07878693169914186, 0.08780960692092776, 0.03718653759278823, 0.021819542453158647, 0.05579339696851093, 0.04902802698779851, 0.029509730484278407, 0.10426777807879262, 0.10979335696902126, 0.0313733505026903, 0.040086917506414466, 0.02367711582337506, 0.07409908168483526, 0.04384592146379873, 0.06507361598778516, 0.03654324398667086, 0.03605823192629032, 0.024247027722594794, 0.07234276694362052, 0.027506577425810974, 0.031139102720771916, 0.044677642654278316, 0.034643969338503666, 0.01836081144574564, 0.029238340066513047, 0.05547889704757836, 0.042917813843814656, 0.10597181593766436, 0.05947477970039472, 0.018939228357339744, 0.07485599067877047, 0.010553423453529831, 0.05281903606373817, 0.05008304928196594, 0.09043770769494586, 0.01812997754313983, 0.01563193443871569, 0.0954923641984351, 0.026896769522863906, 0.03403973125386983, 0.06629387746215798, 0.04340287414379418, 0.016692125791450962, 0.15672820096369833, 0.23312805918976665, 0.9412396559491754, 1.8140271725133061, 4.663426587358117, 11.347884926944971, 27.71767348051071, 41.99736423790455, 46.75337143242359, 57.13419020175934, 46.74321837723255, 23.66289395838976, 12.47669605538249, 12.81036090105772, 15.361274220049381, 12.805271074175835, 21.579857133328915, 26.40674952417612, 34.50239181518555, 39.36498709022999, 42.869763225317, 46.610392704606056, 64.019435942173, 63.20909142494202, 61.78020469844341, 52.63665273785591, 52.916112542152405, 34.753565937280655, 19.93861310184002, 19.158171080052853, 19.089436568319798, 31.837505511939526, 53.76793943345547, 62.17024616897106, 53.17227199673653, 45.57371713221073, 26.312744468450546, 11.717408448457718, 6.0631646029651165, 2.873897412791848, 0.44470970111433417, 0.281866232980974, 0.2196145147900097, 0.025678890342533123, 0.0681635775254108, 0.09146544864051975, 0.030221717279346194, 0.11410912382416427, 0.056166660142480396, 0.01989430562389316, 0.11276372140855528, 0.08461713994620368, 0.06927112161065452, 0.0870569801190868, 0.015726981291663833, 0.03471341580734588, 0.04776465786562767, 0.02679716402781196, 0.07336313836276531, 0.07921972995973192, 0.0283197430690052, 0.06480593074229546, 0.0257828930625692, 0.07726466064923443, 0.04873718673479743, 0.03932950385205913, 0.021776254834549036, 0.006522079129354097, 0.031646501665818505, 0.03537329270329792, 0.04986848325643223, 0.007322798492168658, 0.02921937633800553, 0.009290656398661667, 0.08623568239272572, 0.10425764776300639, 0.05910558349569328, 0.04834543295146432, 0.028744676419591997, 0.02507159089873312, 0.02371018592384644, 0.036396313589648344, 0.020398047636263072, 0.0031505854940405698, 0.08621847940958105, 0.09320626733824611, 0.05901233264012262, 0.018470786599209532, 0.10585782947600819, 0.04419764380145352, 0.039855886934674345, 0.05972204475256149, 0.12443151485058479, 0.08293733320897445, 0.05866866260475945, 0.05576394483796321, 0.07453061087289825, 0.06496207119198516, 0.057588975032558665, 0.020831658548559062, 0.0894495974353049, 0.031513601570622995, 0.0680868914059829, 0.055326107394648716, 0.04995983050321229, 0.03531206551997457, 0.14964303583838046, 0.15356745338067412, 0.12953727564308792, 0.11598945144214667, 0.19150714098941535, 0.17999050818616524, 0.175988313567359, 0.20670935336966068, 0.15687345410697162, 0.1818428048864007, 0.15824299858650193, 0.21126085601281375, 0.22072237799875438, 0.11615475741564296, 0.15552425931673497, 0.15092653571628034, 0.18458918173564598, 0.29373928962741047, 0.2868743345607072, 0.1343727536732331, 0.30886761378496885, 0.1868275585002266, 0.13230541226221249, 0.09845194523222744, 0.14809163549216464, 0.21492754050996155, 0.20304531091824174, 0.25585354131180793, 0.1775417770841159, 0.1828403552644886, 0.10813849381520413, 0.19595192279666662, 0.18544033606303856, 0.16837626812048256, 0.17613653530133888, 0.17963162041269243, 0.08101983141386881, 0.14818850060692057, 0.14337835949845612, 0.20793079485883936, 0.14972781878896058, 0.2637676853919402, 0.15256040351232514, 0.13303540355991572, 0.09376471120049246, 0.22544107167050242, 0.11782529472839087, 0.12682370172115043, 0.22633470653090626, 0.16790840338217095, 0.1565359698724933, 0.09815183555474505, 0.16218748380197212, 0.1463060430251062, 0.11513253062730655, 0.20773942465893924, 0.15704374731285498, 0.12417046440532431, 0.13737591361859813, 0.13227786374045536, 0.17408905376214534, 0.16039862588513643, 0.10639110711053945, 0.11080200245487504, 0.17430924897780642, 0.1415385160362348, 0.12864778196671978, 0.1405934800277464, 0.19820919464109465, 0.2390249419840984, 0.37000487849581987, 0.26041855104267597, 0.7039355020970106, 2.638011295348406, 4.815386608242989, 15.500182416290045, 29.18829906731844, 53.661940321326256, 57.42690749466419, 77.54021242260933, 69.09745305776596, 53.0555422604084, 43.92568476498127, 41.56118184328079, 38.66866685450077, 42.53489479422569, 51.16043575108051, 53.57916176319122, 62.98624478280544, 67.26853519678116, 64.71061125397682, 71.04623928666115, 85.202546864748, 79.40952211618423, 81.08413025736809, 78.6310350894928, 69.07637938857079, 54.84813027083874, 40.83466462790966, 40.43987341225147, 41.4642034471035, 45.18932595849037, 67.14273914694786, 67.81473308801651, 55.363120436668396, 39.578319042921066, 24.993649050593376, 13.366515208035707, 5.191532224416733, 2.264673965983093, 0.3380745090544224, 0.25202871998772025, 0.20321919611888006, 0.19343881780514494, 0.22579452692298219, 0.18258870783029124, 0.0716775280307047, 0.1677811547415331, 0.11570946138817817, 0.11828342991066165, 0.1554322923766449, 0.21682392078218982, 0.22523736697621644, 0.19304344605188817, 0.2266390761360526, 0.20532613852992654, 0.14901816233759746, 0.1585315604461357, 0.14651329518528655, 0.14115314843365923, 0.1496933089219965, 0.23294752434594557, 0.09281324077164754, 0.1599717276985757, 0.17659671138972044, 0.10824893281096593, 0.196443343302235, 0.11124795899377204, 0.23368808382656425, 0.17416053742635995, 0.1565311904414557, 0.08419541452894919, 0.1261985907331109, 0.1384278485784307, 0.2716647007036954, 0.17844090383732691, 0.12349974844255485, 0.23102583683794364, 0.1889122513239272, 0.15079087112098932, 0.18867633742047474, 0.19038303958950564, 0.24996578693389893, 0.13939120079157874, 0.24968483950942755, 0.19398542441194877, 0.0912787984998431, 0.24836524156853557, 0.28132321836892515, 0.23156099952757359, 0.09672592495917343, 0.17800689587602392, 0.22275563998846337, 0.2119863498955965, 0.2565578988287598, 0.10874134037294425, 0.23179682437330484, 0.1698238865355961, 0.13588375149993226, 0.161455963680055, 0.2122595492983237, 0.14094033016590402, 0.1661320580751635, 0.17218477703863755, 0.19193700776668265, 0.14317458058940247], [0.048841788739082403, 0.029164752413635142, 0.050465014137444086, 0.054542414291063324, 0.16199739009607583, 0.08039843858568929, 0.10311878504580818, 0.13150212645996362, 0.11955261375987902, 0.007877444877522066, 0.06240887538297102, 0.13508848089259118, 0.06218903268745635, 0.016280484305752907, 0.07226031433674507, 0.020011457345390227, 0.06292722842772491, 0.10192085479502566, 0.15071468224050477, 0.09730998775921762, 0.0977323143160902, 0.08858354820404202, 0.06299054846749641, 0.033962700035772286, 0.03634798493294511, 0.08855609616148286, 0.06438827229430899, 0.057977326068794355, 0.038455086905742064, 0.012757713375322055, 0.08179507887689397, 0.03831739995803218, 0.0032297538655257085, 0.04115291987545788, 0.05849812820088118, 0.09334898233646527, 0.04990393194020726, 0.105868449609261, 0.05879480544535909, 0.0820850879244972, 0.028631500754272565, 0.059985492334817536, 0.02694369923119666, 0.060307718013064004, 0.02442815813992638, 0.04994681694370229, 0.09635199385229498, 0.0408535820315592, 0.031092891040316317, 0.010247963818983408, 0.05457386650959961, 0.0099385169960442, 0.04911562267807312, 0.06585972107131965, 0.06543416617205366, 0.013633239832415711, 0.034815550170606, 0.07860123892896809, 0.04266513482434675, 0.04621326123015024, 0.010010672303906176, 0.03407384778256528, 0.009675573146523675, 0.11111052066553384, 0.02320828443771461, 0.02604214008897543, 0.051542861183406785, 0.09925221049343236, 0.03429916010645684, 0.11365814294549637, 0.026495254642213695, 0.22602759097935632, 0.2849418710684404, 0.8421214402187616, 2.803848646581173, 7.833460634574294, 16.022516638040543, 29.51139573007822, 38.9200309664011, 35.11548891663551, 45.96035398542881, 28.36666915565729, 14.968915823847055, 7.427926445379853, 8.883002791553736, 8.943565841764212, 12.149006389081478, 17.61906746774912, 20.89883677661419, 24.908394925296307, 37.190025597810745, 35.43769642710686, 44.958853125572205, 38.4916989505291, 26.753929294645786, 31.039255745708942, 28.023817352950573, 11.577579751610756, 10.122058354318142, 2.677009552717209, 19.57186248153448, 39.21065077185631, 52.34134778380394, 52.23089151084423, 27.900455072522163, 16.745657734572887, 8.49226025864482, 4.77255673147738, 1.5624303231015801, 0.3228801040677354, 0.04515870277828071, 0.04387809727631975, 0.11618761971476488, 0.041740812157513574, 0.033174969648825936, 0.02417695413896581, 0.02603644967166474, 0.03119639281067066, 0.048911780686466955, 0.024885263592295814, 0.06102097759139724, 0.04295393417123705, 0.041578478485462256, 0.06083278749429155, 0.051931130583398044, 0.030605110769101884, 0.02758110760623822, 0.004663388363042031, 0.09497817460214719, 0.05861813719093334, 0.020850985929428134, 0.04277165156963747, 0.007783270975778578, 0.031184191902866587, 0.024552658978791442, 0.0322855835838709, 0.08030079421587288, 0.021527229037019424, 0.053945356485201046, 0.043534111828194, 0.013080983626423404, 0.0322002440225333, 0.03172416742017958, 0.04161778633715585, 0.024149047530954704, 0.04357369427452795, 0.04304734458855819, 0.016236263436439913, 0.07290569337783381, 0.005678366223946796, 0.10940501335426234, 0.04188416540273465, 0.0810167143936269, 0.053453538930625655, 0.07278521312400699, 0.05965450560324825, 0.01036573616147507, 0.0876085516938474, 0.02804090519930469, 0.05712629048503004, 0.0657664034224581, 0.10892023507039994, 0.0731951606576331, 0.11020504854968749, 0.08481817290885374, 0.08246333833085373, 0.04262173031747807, 0.08653470853460021, 0.09032172485603951, 0.043712553815566935, 0.04150230815866962, 0.039368039870169014, 0.036326633344287984, 0.03035339839698281, 0.012810289899789495, 0.0388366769766435, 0.09459370499826036, 0.03941290269722231, 0.032516684659640305, 0.04383447754662484, 0.15009138209279627, 0.10312996178981848, 0.11984253374976106, 0.04751967120682821, 0.017925716238096356, 0.01886974849185208, 0.05647706340823788, 0.04480393763515167, 0.050192853741464205, 0.02846887022315059, 0.07126460448489524, 0.05151370591192972, 0.0567795368260704, 0.033146578789455816, 0.06005436363921035, 0.10996745739248581, 0.07444396513164975, 0.06140345081803389, 0.062116962726577185, 0.052300812894827686, 0.050824328645830974, 0.16421455628005788, 0.05647600213706028, 0.10417190002044663, 0.06307985851890408, 0.11041592981200665, 0.0456258884514682, 0.10671823838492855, 0.05079819020465948, 0.02336493882467039, 0.09796803526114672, 0.07834786229068413, 0.09596123825758696, 0.06085055822040886, 0.02202412473707227, 0.04117163683986291, 0.05362085983506404, 0.051983474259031937, 0.10276806089677848, 0.0470055484038312, 0.023076987381500658, 0.02806515673000831, 0.07829376714653336, 0.008874180748534855, 0.02534133745939471, 0.03277778334449977, 0.10255244473228231, 0.03648142308520619, 0.0665040833700914, 0.013967692393634934, 0.03512434668664355, 0.0703415805764962, 0.02106863186781993, 0.05272144735499751, 0.09223258442943916, 0.08481251774355769, 0.08105782937491313, 0.008557626006222563, 0.07555734991910867, 0.09946413076249883, 0.022789002541685477, 0.054420657543232664, 0.048605103002046235, 0.07147206444642507, 0.02466827445459785, 0.07314551097806543, 0.02033210410445463, 0.2264712765463628, 0.7131272682454437, 1.182801362592727, 3.36740851867944, 8.321774806827307, 20.963157825171947, 33.264741227030754, 38.9773964881897, 56.81029558181763, 55.895707458257675, 40.989441722631454, 27.588602006435394, 13.937883898615837, 15.117502100765705, 16.396167688071728, 23.62561035901308, 29.718361124396324, 34.82388496398926, 43.317827582359314, 53.95692229270935, 53.009454533457756, 63.17174322903156, 61.78678214550018, 51.43768787384033, 44.38992865383625, 35.52598848938942, 21.400440260767937, 18.16216852515936, 14.401156939566135, 33.593077808618546, 48.69966879487038, 65.53950637578964, 54.1658578813076, 44.41119611263275, 27.282097153365612, 15.8703139051795, 9.470060840249062, 2.633260600268841, 0.9350423666182905, 0.17309790069703013, 0.07749438504106365, 0.08153389484505169, 0.03536984913807828, 0.02224545543867862, 0.020572790017467923, 0.03933164494810626, 0.07396179920760915, 0.026411909602757078, 0.08259418638772331, 0.02626339472044492, 0.02401621051831171, 0.03229103465855587, 0.03326911850308534, 0.013678059058293002, 0.02249093562568305, 0.057468984596198425, 0.04387413791846484, 0.030510399737977423, 0.012707469049928477, 0.05434443897684105, 0.05836256379552651, 0.015891513576207217, 0.0270435051061213, 0.09593532246071845, 0.027586005780904088, 0.03695662395330146, 0.04650425733416341, 0.06173725771077443, 0.06411803406081162, 0.04779157927259803, 0.002204692073064507, 0.05660922506649513, 0.03334304012241773, 0.04544039606116712, 0.022465570873464458, 0.07511300384066999, 0.03414763952605426, 0.09759238979313523, 0.03263011822127737, 0.08664582288474776, 0.01696443276159698, 0.08871120502590202, 0.0907027508947067, 0.03975735940912273, 0.00845439233671641, 0.031912487393128686, 0.0659102835925296, 0.07631983986357227, 0.018675827159313485, 0.010744883638835745, 0.01666180534812156, 0.034525170049164444, 0.02393801598373102, 0.01620803028345108, 0.01886304875370115, 0.05335024310625158, 0.01965721727174241, 0.03962672286434099, 0.08196963201044127, 0.009502803950454108, 0.044172395937494, 0.051241486144135706, 0.06761658500181511, 0.044993808696744964, 0.027646190246741753, 0.30413090076763183, 0.050695272875600494, 0.18526110739912838, 0.1662394468439743, 0.2598495612619445, 0.20775529177626595, 0.23957095487276092, 0.18385328294243664, 0.14815302594797686, 0.10612125479383394, 0.21116721181897447, 0.21198398986598477, 0.16786380030680448, 0.11100937335868366, 0.1369429743499495, 0.09768964824615978, 0.19607880036346614, 0.15325536543969065, 0.2982349827652797, 0.2449116573552601, 0.284514453378506, 0.1992118064663373, 0.12220414413604885, 0.16738397214794531, 0.10981822633766569, 0.22573668393306434, 0.1343475206522271, 0.16200631071114913, 0.13808827148750424, 0.19357654557097703, 0.23447104962542653, 0.1489213269087486, 0.07810077906469814, 0.13925195904448628, 0.2321633414248936, 0.2016997674945742, 0.2771869325079024, 0.15877859172178432, 0.11383069228031673, 0.18674167717108503, 0.17085229541407898, 0.15137393202167004, 0.13771406578598544, 0.165135131101124, 0.1431646358105354, 0.14987241884227842, 0.22771434421883896, 0.11093757057096809, 0.16633028571959585, 0.11709373749908991, 0.17508670804090798, 0.21234197221929207, 0.18614150234498084, 0.11268455651588738, 0.13415981666184962, 0.1203106359753292, 0.14427420595893636, 0.2821814379421994, 0.21505962795345113, 0.23960496007930487, 0.12324568160693161, 0.2402472888934426, 0.14604479219997302, 0.20924317912431434, 0.08469729189528152, 0.2047049460816197, 0.08972272262326442, 0.11770679600886069, 0.11008961490006186, 0.2795753418467939, 0.2021889467141591, 0.301314658136107, 0.6984448560979217, 1.567412093281746, 3.628394426777959, 9.739177599549294, 23.535315804183483, 38.40958155691624, 55.5141357332468, 64.21164482831955, 77.2776161134243, 65.1294095814228, 59.36829932034016, 36.68612323701382, 39.01194803416729, 39.27485212683678, 48.021139204502106, 56.45833566784859, 63.90744835138321, 72.2212502360344, 84.56905245780945, 79.56828519701958, 88.63510027527809, 86.5052081644535, 80.22295966744423, 65.11895254254341, 53.16176176071167, 39.45231020450592, 38.163335770368576, 32.49443516135216, 56.16950936615467, 68.17879915237427, 77.72012516856194, 63.75594288110733, 40.758991688489914, 27.580662332475185, 13.644524440169334, 8.612059280276299, 2.0597972720861435, 0.4839832062134519, 0.11697714609908871, 0.12025360934785567, 0.14438395475735888, 0.2098548275534995, 0.0856722067692317, 0.06741072065779008, 0.12357765910564922, 0.24347926781047136, 0.23103172949049622, 0.26602669386193156, 0.11972980893915519, 0.1620021992130205, 0.14938540669390932, 0.24025557126151398, 0.12890983431134373, 0.10049708158476278, 0.17011218122206628, 0.1501344860298559, 0.18771527102217078, 0.13301729515660554, 0.10970314149744809, 0.12845230026869103, 0.09362446755403653, 0.13510195829439908, 0.2055039125843905, 0.2795902144862339, 0.15238377236528322, 0.11237076905672438, 0.12031768637825735, 0.1464483721065335, 0.06551160186063498, 0.07125768024707213, 0.08789345476543531, 0.09945903220796026, 0.22406352683901787, 0.09280291749746539, 0.21840889588929713, 0.2060030959546566, 0.1981612667441368, 0.16813607944641262, 0.24688793724635616, 0.14222240512026474, 0.1956238193088211, 0.18801398546202108, 0.18118428240995854, 0.11790067466790788, 0.16684100206475705, 0.13782231544610113, 0.1659677317366004, 0.16348943347111344, 0.09404356576851569, 0.20515335170784965, 0.2900877152569592, 0.15584601002046838, 0.14526489889249206, 0.2152317319996655, 0.21449862368172035, 0.14307379693491384, 0.17054733209079131, 0.10873690975131467, 0.08522004587575793, 0.10909460266702808, 0.13306899316376075, 0.08918755251215771, 0.10482359473826364, 0.14391905860975385], [0.03855736227706075, 0.028890508438053075, 0.013580154009105172, 0.023811704304534942, 0.026266684290021658, 0.013100904725433793, 0.03544310282450169, 0.1489610763383098, 0.07375166009296663, 0.05133508580911439, 0.04064487155119423, 0.113861127756536, 0.12813154404284433, 0.058704660477815196, 0.021999448326823767, 0.08536368113709614, 0.0418197284307098, 0.06429096931242384, 0.0423254204361001, 0.11152074279380031, 0.16225297091295943, 0.0233537156964303, 0.03167520051647443, 0.016761588958615903, 0.03844809587462805, 0.03367504359630402, 0.051547380862757564, 0.023632826305401977, 0.026910161577688996, 0.10399077145848423, 0.017990416672546417, 0.010004126561398152, 0.04644440683478024, 0.03334846151119564, 0.08185346363461576, 0.02626000867167022, 0.0356695988739375, 0.08568512013880536, 0.029493342008208856, 0.016832888941280544, 0.046677738064317964, 0.03936776156479027, 0.014771382666367572, 0.04581498767947778, 0.0255755833859439, 0.034952264904859476, 0.05408817538409494, 0.06356314508593641, 0.03577697651053313, 0.02946654120023595, 0.04616070233169012, 0.027247399048064835, 0.11702592004439794, 0.03785192493523937, 0.07152621154091321, 0.04852146295888815, 0.06561930233146995, 0.06468956198659725, 0.03325397126900498, 0.027462039288366213, 0.018167335401813034, 0.059591779281618074, 0.05373486485041212, 0.09861158119747415, 0.12770893546985462, 0.07592120266053826, 0.0313881563488394, 0.07490554387914017, 0.008736624604352983, 0.024773941440798808, 0.06062592125090305, 0.013901131023885682, 0.1286916874232702, 0.5048558721318841, 0.6736521958373487, 2.08948056679219, 7.082372037693858, 17.850216664373875, 23.18259973078966, 37.787562534213066, 38.18103902041912, 45.253721103072166, 31.89844474196434, 15.06188828498125, 7.6082889921963215, 6.061737779527903, 10.00424187630415, 11.627347581088543, 18.86031836271286, 26.521590761840343, 32.106217592954636, 36.191537976264954, 26.686919890344143, 40.06810896098614, 37.58545897901058, 15.480864252895117, 4.406796433031559, 0.7053110282868147, 3.441141899675131, 15.502006318420172, 37.35625147819519, 44.15977880358696, 48.56876581907272, 25.940598137676716, 14.328012764453888, 9.599643386900425, 6.485974565148354, 2.164392597042024, 0.46144976222421974, 0.09795689562452026, 0.2436000300804153, 0.14997957012383267, 0.04004237009212375, 0.02611913048895076, 0.014142605468805414, 0.061048592906445265, 0.014582437434000894, 0.04588006289850455, 0.03183075838023797, 0.055490634113084525, 0.04384629624837544, 0.05218370570219122, 0.03860283366520889, 0.023474663503293414, 0.025480697950115427, 0.10428743757074699, 0.0315239582414506, 0.0390430571133038, 0.05699517154425848, 0.03130651639366988, 0.006956506867936696, 0.027256828034296632, 0.08466101571684703, 0.048861195900826715, 0.06746089726220816, 0.03303732351923827, 0.06564184135640971, 0.10138852710952051, 0.10894406543229707, 0.05586986786511261, 0.03441720240516588, 0.05864362625288777, 0.03972922459070105, 0.05937838584941346, 0.029292231120052747, 0.034064533829223365, 0.03173167795466725, 0.09984992881072685, 0.06710345667670481, 0.09021579069667496, 0.09884575105388649, 0.04351340219727717, 0.0723421286966186, 0.08306308271130547, 0.19473364285659045, 0.16288299491861835, 0.028875001262349542, 0.03665522664960008, 0.07228957721963525, 0.03829475703241769, 0.02448183953674743, 0.03836578056507278, 0.09076305039343424, 0.09599615630577318, 0.023508974845753983, 0.058684908217401244, 0.08835751228616573, 0.12400769657688215, 0.12831215310143307, 0.0645750411786139, 0.049118528186227195, 0.04671457456424832, 0.051044319770880975, 0.1686570671154186, 0.03835065559542272, 0.032119843453983776, 0.1621262269327417, 0.045083801524015144, 0.04131573223276064, 0.026192135555902496, 0.07541182960267179, 0.16640303103486076, 0.015514507194893667, 0.036627585359383374, 0.07425246134516783, 0.06840546571766026, 0.060803687883890234, 0.06313703357591294, 0.06799596347264014, 0.04502362076891586, 0.035978139349026605, 0.04254894418409094, 0.08991829337901436, 0.1293952137348242, 0.007515254083045875, 0.0413611108524492, 0.024808768575894646, 0.035835138623951934, 0.05019580006774049, 0.04477477865293622, 0.09559510712279007, 0.006248588897506124, 0.020194617536617443, 0.02617661168187624, 0.05401502188760787, 0.09180705179460347, 0.007629744277437567, 0.05021762292017229, 0.045362823075265624, 0.09552430623443797, 0.08166814193828031, 0.0182039047285798, 0.08365530171431601, 0.07114573469152674, 0.010467223928571912, 0.0463713795033982, 0.028065260630683042, 0.022722476423950866, 0.009340520373370964, 0.08851564169162884, 0.033613274645176716, 0.08267099125077948, 0.03357389628945384, 0.07533669457188807, 0.029862571609555744, 0.02270590983243892, 0.051654899507411756, 0.019460794901533518, 0.03442569257458672, 0.03867470695695374, 0.05539853358641267, 0.02086898486595601, 0.0862725597107783, 0.042238036257913336, 0.04996532981749624, 0.020209330614306964, 0.03276905197708402, 0.032899814686970785, 0.056466944224666804, 0.02027901828114409, 0.0941598232020624, 0.04427628176927101, 0.04544768024061341, 0.07304391838260926, 0.019548503769328818, 0.019020879444724414, 0.02302269742358476, 0.03238474564568605, 0.35912190622184426, 1.0884838923811913, 2.684113746508956, 5.536751300096512, 11.62229385226965, 23.579359240829945, 31.606377214193344, 42.39012636244297, 56.122547686100006, 55.280961245298386, 45.713735818862915, 25.22812496870756, 19.38164658844471, 12.477353420108557, 12.167428750544786, 17.601945586502552, 31.9451442360878, 41.87912978231907, 46.13147400319576, 49.67064589262009, 38.91099505126476, 67.99225196242332, 59.948159605264664, 26.201283149421215, 19.64872095733881, 15.570092014968395, 21.807254031300545, 27.79495183378458, 48.21477301418781, 59.3137152493, 60.58471664786339, 45.17248906195164, 27.178856693208218, 17.45322346687317, 8.39285284280777, 3.3893692027777433, 1.0624532704241574, 0.4250696237431839, 0.28336278861388564, 0.19576908729504794, 0.1871208255761303, 0.13850568502675742, 0.014442103802139172, 0.08000052126590163, 0.021511068771360442, 0.048944969530566595, 0.024467864895996172, 0.10544791904976591, 0.06481258780695498, 0.05135956555022858, 0.0554468399786856, 0.05123615752381738, 0.06138274860859383, 0.14832113723969087, 0.027133017392770853, 0.02128182863089023, 0.0748450291575864, 0.009718695637275232, 0.0060588351880142, 0.03198665021045599, 0.056054577289614826, 0.013073805203021038, 0.04421125107910484, 0.10252265492454171, 0.06635906771407463, 0.028310455090831965, 0.02037718029896496, 0.04688301240094006, 0.03526088330545463, 0.052906089986208826, 0.04553122751531191, 0.03752630764211062, 0.059801476818392985, 0.00636576520264498, 0.015886821347521618, 0.01583598423167132, 0.06801479918067344, 0.08053985482547432, 0.035283648685435764, 0.011101730506197782, 0.03003404854098335, 0.05938495756709017, 0.17956925032194704, 0.015982756922312547, 0.062388822552748024, 0.07812930722138844, 0.03920955423382111, 0.10421489263535477, 0.04657448305806611, 0.009378101804031758, 0.08249190359492786, 0.05435297738586087, 0.060076253284933046, 0.04171720443991944, 0.07596613970235921, 0.05825722706504166, 0.035314655615366064, 0.019484760705381632, 0.08138319433783181, 0.03243246945203282, 0.060264179919613525, 0.09320560682681389, 0.0920465354283806, 0.02915091135946568, 0.3030501853208989, 0.09213348545017652, 0.12045885028783232, 0.1740522580803372, 0.14151871553622186, 0.23221113573526964, 0.16968415497103706, 0.26747806754428893, 0.2169533068081364, 0.13463939249049872, 0.13425590994302183, 0.28188784432131797, 0.24244368978543207, 0.14970120537327603, 0.125346842687577, 0.1471353485248983, 0.21856872481293976, 0.3052588168065995, 0.3047490504104644, 0.361029552295804, 0.2607426617760211, 0.1556491627707146, 0.20106509764445946, 0.09814828066737391, 0.24633399822050706, 0.0517406509607099, 0.20483765692915767, 0.11889067740412429, 0.18370014819083735, 0.20305807585828006, 0.2125035526114516, 0.1909329413319938, 0.14512878900859505, 0.20004365011118352, 0.2493000210961327, 0.16414023761171848, 0.21450977073982358, 0.13676205358933657, 0.07658781454665586, 0.12105126967071556, 0.12782739708200097, 0.09332656205515377, 0.07781140084262006, 0.16418187209637836, 0.1385296118678525, 0.18475362681783736, 0.18521740974392742, 0.12476254982175305, 0.1906184191466309, 0.11614519113209099, 0.1355826176586561, 0.09051527697010897, 0.25970145827159286, 0.1104116476199124, 0.20241841877577826, 0.07045646503684111, 0.1642298890510574, 0.14616377331549302, 0.1362693714327179, 0.10441333550261334, 0.09445374336792156, 0.15753675601445138, 0.18249537533847615, 0.1325092653860338, 0.16789329325547442, 0.21472909022122622, 0.10141445032786578, 0.2751688548596576, 0.10116985329659656, 0.08830310543999076, 0.11096733069280162, 0.140838923107367, 0.37535246810875833, 0.985294432612136, 2.266137362457812, 4.68401150777936, 11.096808649599552, 23.929518051445484, 31.36582162231207, 57.91015416383743, 68.87756645679474, 80.06471335887909, 73.54321449995041, 53.92947256565094, 42.769775390625, 34.855001494288445, 34.00200046598911, 40.77854543924332, 53.47853556275368, 64.95750680565834, 71.49972975254059, 74.56444770097733, 63.427963480353355, 89.71418917179108, 86.09210953116417, 38.60502026975155, 32.69785724580288, 32.55418315529823, 42.538447603583336, 50.56503050029278, 66.3569413125515, 81.38534009456635, 65.32090410590172, 38.470515087246895, 25.510947592556477, 13.573286812752485, 8.121659494936466, 2.0601475657895207, 0.6636222184170038, 0.24937206879258156, 0.3705336735583842, 0.25457179290242493, 0.17081520287320018, 0.22717722225934267, 0.11933552072150633, 0.1390314966556616, 0.1359686828800477, 0.13618737895740196, 0.11308435146929696, 0.2135485113831237, 0.22782535466831177, 0.2750585717149079, 0.09647817380027846, 0.15352743677794933, 0.14466778171481565, 0.28933045745361596, 0.1089552347548306, 0.08281722402898595, 0.14947379648219794, 0.1769639557460323, 0.10669946204870939, 0.08682267667609267, 0.2978500456083566, 0.16620995389530435, 0.2149253140669316, 0.15349847817560658, 0.27478638163302094, 0.14488429587800056, 0.18538923177402467, 0.22448503703344613, 0.11886128835612908, 0.21484854631125927, 0.1320034175296314, 0.1517534366576001, 0.22509665577672422, 0.10880428933887742, 0.12749592424370348, 0.21374129166360945, 0.3156846557976678, 0.30443372670561075, 0.18260516866575927, 0.13581961509771645, 0.18693718855502084, 0.16953033744357526, 0.2278655197005719, 0.2695356571348384, 0.11322394944727421, 0.2258371707284823, 0.21332499134587124, 0.261508320691064, 0.11886855398188345, 0.1186025385686662, 0.16691680502844974, 0.11745641022571363, 0.1364280129200779, 0.12162326514953747, 0.14321237074909732, 0.14599346526665613, 0.30891042086295784, 0.11671302316244692, 0.1715468120528385, 0.18880569376051426, 0.0818174249434378, 0.2428422379307449, 0.11185228984686546, 0.12409081711666659], [0.03940804162994027, 0.06358001410262659, 0.06203376055054832, 0.02398089913185686, 0.06453782989410684, 0.12564054020913318, 0.14077161031309515, 0.06291827070526779, 0.033402371118427254, 0.03141563065582886, 0.07241646220791154, 0.05776978076028172, 0.054660797977703623, 0.015110108142835088, 0.10776667782920413, 0.029517161237890832, 0.059906780152232386, 0.07390480226604268, 0.164452577882912, 0.046518283925252035, 0.06871834033518098, 0.0377367881446844, 0.04294453487091232, 0.049099915122496895, 0.0712836925231386, 0.06438799769966863, 0.01732267115585273, 0.09628974992665462, 0.12830263876821846, 0.018544084814493544, 0.017397327501385007, 0.03640523420472164, 0.08744079663301818, 0.05440806700789835, 0.08692617659107782, 0.09519626953988336, 0.047471791549469344, 0.06925981870153919, 0.03121779634966515, 0.03651642276963685, 0.05393246538005769, 0.05400463182013482, 0.09303992977947928, 0.04253916267771274, 0.03513275150908157, 0.017111713823396713, 0.03907636470103171, 0.05630487772577908, 0.058770184696186334, 0.027519440700416453, 0.08104956184979528, 0.04511785497015808, 0.021981759236950893, 0.004929642191200401, 0.030450684680545237, 0.01797837161575444, 0.05913208929996472, 0.033613044579396956, 0.08655774479848333, 0.023409105888276827, 0.018715784390224144, 0.07055706315441057, 0.06883684647618793, 0.12206738858367316, 0.027925532776862383, 0.09710059821372852, 0.037788163317600265, 0.08328281037393026, 0.04212015352095477, 0.03729754433152266, 0.07284018400241621, 0.06243405645363964, 0.02679921792150708, 0.07098323403624818, 0.08668735346873291, 1.1072050128132105, 2.6927739568054676, 7.2341368440538645, 12.372123766690493, 27.555766068398952, 29.482844062149525, 35.95342755317688, 43.142174407839775, 25.82737371325493, 17.38233257085085, 11.977583337575197, 9.172134026885033, 2.6311543257907033, 6.9773670472204685, 17.881295196712017, 21.100256368517876, 29.98907569795847, 13.550752121955156, 25.953563041985035, 34.728217497467995, 6.662926319986582, 13.664883747696877, 14.016002956777811, 22.48824778944254, 34.17463280260563, 40.38258768618107, 28.54906316846609, 19.08200416713953, 10.848555620759726, 4.832974439486861, 4.054823694750667, 1.36082430370152, 0.4468906356487423, 0.26608464075252414, 0.07202633743872866, 0.05877922405488789, 0.03197427489794791, 0.06219112554390449, 0.02813612274621846, 0.038361019687727094, 0.034325372762396, 0.03651996281405445, 0.04062522319145501, 0.04249846329912543, 0.050470609930926, 0.06732270936481655, 0.08978189405752346, 0.07368718972429633, 0.01752873773511965, 0.028806692134821787, 0.04674948890169617, 0.10350080556236207, 0.06301726578385569, 0.083001350867562, 0.053523597671301104, 0.04487037469516508, 0.013905688738304889, 0.053849029427510686, 0.074821080052061, 0.050989649462280795, 0.04652217648981605, 0.06729781773174182, 0.0380764023429947, 0.007946422865643399, 0.002813982096085965, 0.0879877372062765, 0.12084743881132454, 0.026985829099430703, 0.07897632036474533, 0.02599672992801061, 0.01104412593122106, 0.025127014487225097, 0.0128635603323346, 0.05657014356984291, 0.06756892427802086, 0.02354071279114578, 0.05675401436747052, 0.05280949204461649, 0.03725097827555146, 0.08016684398171492, 0.029784334401483648, 0.07557393691968173, 0.02517256565624848, 0.08958446051110514, 0.060033828412997536, 0.08757348521612585, 0.04049561081046704, 0.08986807966721244, 0.056560414013802074, 0.029730289352301043, 0.08482166100293398, 0.03556617317372002, 0.18464668333763257, 0.1346007562824525, 0.02168607275962131, 0.07347951453994028, 0.008817442630970618, 0.06194113309902605, 0.09170007862849161, 0.04866823379416019, 0.08315323881106451, 0.06019689310051035, 0.02306771795701934, 0.027493894122017082, 0.015113289173314115, 0.17584794375579804, 0.12620334047824144, 0.1356419301009737, 0.01346506638583378, 0.0716320269566495, 0.021222592258709483, 0.10089231232996099, 0.044979203230468556, 0.12847998237702996, 0.035920782465836965, 0.05903113495151047, 0.029215172071417328, 0.03239118006604258, 0.06821808085078374, 0.06866474242997356, 0.047592828414053656, 0.08934253521147184, 0.10195686380029656, 0.0664519846031908, 0.06417138705728576, 0.10436389362439513, 0.026523125998210162, 0.020137598330620676, 0.08436497300863266, 0.07308038009796292, 0.0618084853340406, 0.014801755987718934, 0.042600059605319984, 0.06214361324964557, 0.10450198504258879, 0.018167725029343273, 0.09061751523404382, 0.06672432311461307, 0.03940853144740686, 0.027299885587126482, 0.0305125297018094, 0.05084322743641678, 0.007601946672366466, 0.0479383426863933, 0.019219481873733457, 0.036197726003592834, 0.02312933291250374, 0.02062985375232529, 0.019388342734600883, 0.06197949100169353, 0.031708552633062936, 0.018869351442845073, 0.028598256249097176, 0.039957757835509256, 0.015965965831128415, 0.08015111787244678, 0.08511143998475745, 0.007052381679386599, 0.023129826440708712, 0.019539477398211602, 0.021379786558100022, 0.07089358259690925, 0.020853739297308493, 0.10039332933956757, 0.08366046706214547, 0.022504563312395476, 0.10799634284921922, 0.14821532182395458, 0.03147140676446725, 0.03772243500861805, 0.022071239982324187, 0.033916096872417256, 0.18135000398615375, 0.1290931151015684, 0.5041345045901835, 0.6412389851175249, 1.909964068327099, 4.913190510123968, 12.568430732935667, 17.72473219782114, 35.493861213326454, 38.91620837152004, 53.50092016160488, 52.80114971101284, 38.387155160307884, 32.498565539717674, 28.986795879900455, 22.046776078641415, 11.892362460494041, 14.221509229391813, 31.525280065834522, 37.37517826259136, 42.54675395786762, 23.061089850962162, 34.42729264497757, 41.24847762286663, 19.170699007809162, 27.59917303919792, 26.72420158982277, 32.101775631308556, 44.33431103825569, 65.08728504180908, 49.4252360612154, 33.956896886229515, 18.811907060444355, 12.433053497225046, 7.387022115290165, 2.989429975859821, 0.9429065196309239, 0.5025309312622994, 0.22232314600842074, 0.06141738092992455, 0.0581616978161037, 0.07656352405319922, 0.046480285964207724, 0.06821048868005164, 0.043350793930585496, 0.0557585679780459, 0.07533454976510257, 0.059561199086601846, 0.01915827324410202, 0.008779188628977863, 0.047493803649558686, 0.03092845709034009, 0.01589629115187563, 0.05726140218030196, 0.03097378932579886, 0.059606919094221666, 0.04582296576700173, 0.03777260419155937, 0.03792842922848649, 0.018214949741377495, 0.010752803282230161, 0.0677171534334775, 0.0693732633953914, 0.08712844894034788, 0.02268335967528401, 0.06922087821294554, 0.04657941091863904, 0.035930100129917264, 0.03669918776722625, 0.014060298508411506, 0.08502593715093099, 0.03243287392251659, 0.07737311068922281, 0.023038032049953472, 0.02902803767938167, 0.01980936125619337, 0.021372144292399753, 0.07231839481391944, 0.04935444951115642, 0.059576001222012565, 0.07673935368075036, 0.028089373008697294, 0.07246915469295345, 0.12087311712093651, 0.016327851881214883, 0.03641234026872553, 0.04549930032226257, 0.08768381288973615, 0.11383657008991577, 0.015712143904238474, 0.033277252441621386, 0.0806124071823433, 0.04144172664382495, 0.0371372775407508, 0.09329335094662383, 0.06927470618393272, 0.017421734883100726, 0.003607403596106451, 0.02596666367026046, 0.04025908092444297, 0.056328982682316564, 0.15870118571911007, 0.10765061335405335, 0.03430387645494193, 0.09017725838930346, 0.11679491173708811, 0.10684642213163897, 0.1370891329133883, 0.125681922363583, 0.31965621456038207, 0.30122322554234415, 0.27345443435478956, 0.1595951322815381, 0.15072725422214717, 0.2542091201758012, 0.19704044563695788, 0.3436464647529647, 0.18906534154666588, 0.15707604557974264, 0.17717554204864427, 0.2497495844727382, 0.12063164453138597, 0.15511656791204587, 0.3033619764028117, 0.24097984802210703, 0.22655018168734387, 0.10609930206555873, 0.2123272034805268, 0.1551249690237455, 0.13366768369451165, 0.17020864557707682, 0.11577200217288919, 0.27467416890431195, 0.23168275627540424, 0.23019754065899178, 0.17789739940781146, 0.095402972510783, 0.1708899816730991, 0.24579335848102346, 0.1794285242795013, 0.3804596315603703, 0.21333118085749447, 0.35407651914283633, 0.1182456397509668, 0.152201367309317, 0.14531474153045565, 0.14827957696979865, 0.12972238211659715, 0.07807773537933826, 0.2029628583113663, 0.12911477097077295, 0.11110151099273935, 0.14468351524556056, 0.21598416584311053, 0.12459264253266156, 0.21746991580585018, 0.14033782499609515, 0.1968221800052561, 0.08009487050003372, 0.1703729570726864, 0.21455198409967124, 0.2175000766874291, 0.2025583284557797, 0.2711509563960135, 0.16071460267994553, 0.1263231082702987, 0.13770149380434304, 0.28603915125131607, 0.2543555310694501, 0.10174171518883668, 0.16694114747224376, 0.26540465536527336, 0.15507126721786335, 0.30036503565497696, 0.08074977871729061, 0.11248189824982546, 0.2432597108418122, 0.26934504392556846, 0.5183979298453778, 0.6676796881947666, 1.736694434657693, 4.279620107263327, 11.02966720238328, 18.578732572495937, 36.36797770857811, 47.934298664331436, 69.67949822545052, 77.27215200662613, 67.96535700559616, 54.95527692139149, 51.73180349171162, 42.18646489083767, 30.63708532601595, 29.102585166692734, 45.34195996820927, 48.90616871416569, 64.81256738305092, 37.98634126782417, 75.9710942208767, 73.96110847592354, 25.45299880206585, 48.41359734535217, 49.4597078114748, 59.713020622730255, 68.3573667705059, 83.33287239074707, 57.57769100368023, 33.07804584503174, 15.581387858837843, 9.589951056987047, 4.363862061873078, 1.903615202754736, 0.44911761302500963, 0.3554395178798586, 0.24140619701938704, 0.2451431777444668, 0.14391816803254187, 0.16734961071051657, 0.11999184644082561, 0.20891029620543122, 0.20804431376745924, 0.10673452852643095, 0.19034432916669175, 0.15924372535664588, 0.09988812715164386, 0.2156155410921201, 0.19714783440576866, 0.11607713619014248, 0.1415916092810221, 0.11262285435805097, 0.132521970954258, 0.17239471577340737, 0.1589991876971908, 0.1898409303976223, 0.27115457807667553, 0.10589098863420077, 0.17076448450097814, 0.11723078248905949, 0.21904834517044947, 0.12229854532051831, 0.15185944503173232, 0.18491713679395616, 0.10489383901585825, 0.1617045683087781, 0.1030708868347574, 0.21384847263107076, 0.3563339839456603, 0.15934375202050433, 0.16622783965431154, 0.14939126966055483, 0.13849005539668724, 0.11020625082892366, 0.07273732233443297, 0.25902800378389657, 0.15365572442533448, 0.23205941106425598, 0.1887702933163382, 0.14618651272030547, 0.17972523492062464, 0.26454907783772796, 0.12883935996796936, 0.21688719629310071, 0.19110106746666133, 0.22373523039277643, 0.17527602991322055, 0.24408490484347567, 0.1138352787529584, 0.15241835644701496, 0.14969661890063435, 0.21973900264129043, 0.13683969707926735, 0.13145149714546278, 0.3292869759025052, 0.2520049118902534, 0.16808359476272017, 0.12265797486179508, 0.11183852300746366, 0.2311986978747882, 0.15347677777754143, 0.13311644608620554, 0.1894958910997957], [0.04929382346745115, 0.00910449978618999, 0.03293579400633462, 0.033790184097597376, 0.05950924503849819, 0.03921971052477602, 0.01718785260891309, 0.03129583317786455, 0.11124362485134043, 0.07120590802514926, 0.09566263513988815, 0.05681691509380471, 0.04763418830407318, 0.014898464323778171, 0.09445632604183629, 0.047125178898568265, 0.027088336391898338, 0.12327838805504143, 0.07288462380529381, 0.006018772201059619, 0.08732517744647339, 0.08420819431194104, 0.07817509773303755, 0.04267248579708394, 0.03487907801172696, 0.04871180157351773, 0.022989920471445657, 0.030959861069277395, 0.01625586170121096, 0.016902122042665724, 0.02649421563546639, 0.053863293505855836, 0.08961275118053891, 0.021611407137243077, 0.02080779664538568, 0.04354300275736023, 0.03698815780808218, 0.060057065056753345, 0.06650705938227475, 0.051509100885596126, 0.0633700456819497, 0.042594103870214894, 0.019817936772597022, 0.08136458127410151, 0.03771911760850344, 0.024351950705749914, 0.032029138164944015, 0.029434161297103856, 0.10550986611633562, 0.043938040544162504, 0.05284244711219799, 0.0390971485467162, 0.045003497434663586, 0.029771754998364486, 0.04867633804678917, 0.040792892905301414, 0.05665576514729764, 0.03858167874568608, 0.006615343900193693, 0.04774468296091072, 0.02391202226135647, 0.06402456056093797, 0.026825575296243187, 0.07649495702935383, 0.05975887754175346, 0.02437558439851273, 0.056845955332391895, 0.09462888279813342, 0.10053571779280901, 0.059465020458446816, 0.014429721995838918, 0.07397188499453478, 0.014641669167758664, 0.050572655236464925, 0.08873646773281507, 0.061453905727830715, 0.8319585886783898, 1.510627109091729, 4.144714996218681, 6.578634493052959, 14.300241004675627, 18.736469708383083, 45.45504570007324, 19.137224704027176, 26.069996394217014, 19.00753766298294, 19.041707329452038, 21.196811087429523, 14.180211145430803, 8.434231672435999, 4.365743435919285, 8.509491384029388, 7.7977795992046595, 7.221785606816411, 9.810972847044468, 9.082755222916603, 16.404764726758003, 16.804320886731148, 23.250526785850525, 24.397369846701622, 7.7607211377471685, 8.149289712309837, 7.442537611350417, 1.4950604131445289, 1.3766270619817078, 0.5052568693645298, 0.10308475757483393, 0.08991530252387747, 0.05578137788688764, 0.15673425688873976, 0.1513855392113328, 0.02783507796266349, 0.03253812901675701, 0.07614533125888556, 0.0038944839434407186, 0.08191217493731529, 0.043082663396489806, 0.02899674502259586, 0.06076232428313233, 0.02729439926042687, 0.01368397768601426, 0.00950916415604297, 0.028407242280081846, 0.027111482122563757, 0.03125000926957, 0.05749012096202932, 0.009991678889491595, 0.040265170246129856, 0.06216415960807353, 0.024309527689183597, 0.0016228957224484475, 0.00770274795286241, 0.026059632509713992, 0.01198324980578036, 0.006337425829769927, 0.03922500945918728, 0.06625849928241223, 0.03361019102158025, 0.0502691650763154, 0.0477344635874033, 0.030651057131763082, 0.02764623106486397, 0.030397493101190776, 0.02780913247988792, 0.04943644940794911, 0.035687996714841574, 0.022850346613267902, 0.03713466889166739, 0.07392715575406328, 0.045879613899160177, 0.01773979154677363, 0.050663601723499596, 0.04585671122185886, 0.013799080152239185, 0.04735343754873611, 0.013618083321489394, 0.019688927386596333, 0.05247428249276709, 0.023910088966658805, 0.032562048436375335, 0.019635173630376812, 0.07006795072811656, 0.008116039789456408, 0.018657225227798335, 0.07087359655997716, 0.0706950506719295, 0.052165571323712356, 0.022307858926069457, 0.09969283841201104, 0.026483552828722168, 0.05192772041482385, 0.05090164559078403, 0.05230228605796583, 0.13386288337642327, 0.13411271997028962, 0.0431875474168919, 0.06197504553711042, 0.028346569852146786, 0.04816601132915821, 0.05213186297623906, 0.236271292087622, 0.052824899030383676, 0.025052200435311534, 0.003739578937711485, 0.05235335323959589, 0.045187668802100234, 0.04342664142313879, 0.02620927360112546, 0.037148150004213676, 0.060257994118728675, 0.035737687212531455, 0.05255259762634523, 0.06150184475700371, 0.08329041738761589, 0.07181130757089704, 0.1138206510222517, 0.06211988678842317, 0.06615237958612852, 0.06341458196402527, 0.0380825770116644, 0.0962794192309957, 0.12095460493583232, 0.07679572721826844, 0.04079132697370369, 0.08152167909429409, 0.16204833111260086, 0.09109929524129257, 0.13488254975527525, 0.04778787595569156, 0.05799331564048771, 0.10127787289093249, 0.07082450349116698, 0.005984473846183391, 0.07114862906746566, 0.03345912686199881, 0.007843010153010255, 0.05185269670619164, 0.023143634098232724, 0.025442872538405936, 0.03460056483163498, 0.043458665095386095, 0.018353315754211508, 0.01836014722357504, 0.12449215573724359, 0.026808619077201, 0.044318658401607536, 0.0370052160724299, 0.07124864088837057, 0.007298641585293808, 0.06562449736520648, 0.04797501220309641, 0.014846004687569803, 0.11060997916501947, 0.05634674227621872, 0.009877639549813466, 0.05009072679968085, 0.06722851598169655, 0.05640741655952297, 0.038851516219438054, 0.13182553957449272, 0.04695534211350605, 0.07336753929848783, 0.12144092688686214, 0.04673926952818874, 0.08720932077267207, 0.04975017007382121, 0.06309680175036192, 0.052922510003554635, 0.015984558485797606, 0.019912673778890166, 0.14955051970900968, 0.13028395042056218, 1.6186308511532843, 3.354992209933698, 7.359200483188033, 13.111874721944332, 20.908231772482395, 23.809708580374718, 55.71436978876591, 27.70180933177471, 50.4777567833662, 38.61148752272129, 32.256488129496574, 33.51403824985027, 31.39544863253832, 23.140843771398067, 16.56270705163479, 20.65489936619997, 20.724422335624695, 22.66356088221073, 30.825562812387943, 21.99689045548439, 32.36562207341194, 31.436423733830452, 40.56872829794884, 46.01352833211422, 28.571386970579624, 20.28063464909792, 12.541056051850319, 6.4124817587435246, 3.5204583685845137, 1.197859717067331, 0.3199013014091179, 0.238720320048742, 0.03621715914050583, 0.0867831869982183, 0.03298981122497935, 0.03806211600021925, 0.017701257384032942, 0.028309228691796307, 0.08587605247157626, 0.028595408257388044, 0.025877284970192704, 0.09258092628442682, 0.05146766307007056, 0.027458404620119836, 0.012698702430498088, 0.01064604812199832, 0.020963590141036548, 0.0648339393956121, 0.11400497081922367, 0.016806876665214077, 0.01907296151330229, 0.061646834437851794, 0.02676547988812672, 0.057684578496264294, 0.04165215890679974, 0.07554202456958592, 0.014378551841218723, 0.007803400803823024, 0.021857614628970623, 0.03558621487172786, 0.004507975681917742, 0.012820837673643837, 0.06289047727477737, 0.016048051074903924, 0.04944564090692438, 0.017900019374792464, 0.025589827055227943, 0.038104926788946614, 0.0574896163016092, 0.06199438219482545, 0.01026716039632447, 0.021897957776673138, 0.01984349077247316, 0.03181288375344593, 0.05262804435915314, 0.038602733475272544, 0.04657747762394138, 0.004757670803883229, 0.02729582232859684, 0.05753172576078214, 0.03373384024598636, 0.07446982155670412, 0.10240564792184159, 0.08595100938691758, 0.06051127798855305, 0.04768633902131114, 0.09906383857014589, 0.08349547279067338, 0.07290562658454292, 0.12226049540913664, 0.08647478753118776, 0.02300994732649997, 0.07671908562770113, 0.055870057112770155, 0.034677054281928577, 0.040698573357076384, 0.04105773943592794, 0.09447694290429354, 0.06939015467651188, 0.04615222700522281, 0.12966943730134517, 0.13616722222650424, 0.10651133503415622, 0.150763456185814, 0.26615689625032246, 0.21895584388403222, 0.12101272994186729, 0.11091089036199264, 0.1785431124153547, 0.2480028657009825, 0.13546555128414184, 0.29278260190039873, 0.15405727084726095, 0.14800186530919746, 0.10069100477267057, 0.12703905813395977, 0.171389075985644, 0.4323544859653339, 0.22565293998923153, 0.2320406644139439, 0.2625819412060082, 0.31442947627510875, 0.20854606496868655, 0.09957474787370302, 0.17951306974282488, 0.2633348945528269, 0.1427713272278197, 0.09975776891224086, 0.14342732640216127, 0.2359158924082294, 0.18245457205921412, 0.21360314829507843, 0.17610218870686367, 0.16890375700313598, 0.301332677481696, 0.1883999170968309, 0.17868397204438224, 0.13886308850487694, 0.1409069335204549, 0.15479756315471604, 0.16941672947723418, 0.13947270344942808, 0.13911817950429395, 0.11066788894822821, 0.1771081253536977, 0.07044159981887788, 0.07072020205669105, 0.2126288865110837, 0.18343027360970154, 0.12586159631609917, 0.07973845407832414, 0.1365046767750755, 0.09421861614100635, 0.14184889703756198, 0.1144590241892729, 0.18009921797784045, 0.17422526754671708, 0.1147216628305614, 0.09925188394845463, 0.1360233494779095, 0.1880742478533648, 0.23229869431816041, 0.19438832154264674, 0.19133686262648553, 0.13782277557766065, 0.15865938796196133, 0.1543206293717958, 0.24237603560322896, 0.24723811220610514, 0.13730606267927215, 0.1262931403471157, 0.10683238811907358, 0.1059220994648058, 0.2173851476982236, 0.3520945692434907, 0.24862036225385964, 1.465420697350055, 2.197224022820592, 6.944429939612746, 9.435283206403255, 21.6206631436944, 28.85289676487446, 61.74338087439537, 51.24380707740784, 80.75883731245995, 63.47914293408394, 65.51693558692932, 70.37595525383949, 62.75254972279072, 37.31948845088482, 24.017739817500114, 31.986455619335175, 35.60916602611542, 38.03991839289665, 45.719085931777954, 47.71582178771496, 72.40792661905289, 63.53584349155426, 64.76696982979774, 68.24844941496849, 34.302750527858734, 20.679079368710518, 9.523160140961409, 3.8338517770171165, 1.5038565848954022, 0.5296979891136289, 0.2465257840231061, 0.22277857235167176, 0.1444091135635972, 0.17141519958386198, 0.17888570262584835, 0.16364418610464782, 0.11833781449240632, 0.1257133300532587, 0.15978875861037523, 0.1319189165951684, 0.14183433610014617, 0.24601405835710466, 0.12373371049761772, 0.10398052239906974, 0.07662624295335263, 0.12910840334370732, 0.10639496627845801, 0.2104337769560516, 0.15043023187899962, 0.13821222499245778, 0.10876410946366377, 0.12084020287147723, 0.12079015985364094, 0.17980188393266872, 0.20019737858092412, 0.08245300763519481, 0.12677431921474636, 0.05381096838391386, 0.1508203789126128, 0.10869192075915635, 0.1286360263475217, 0.12339048204012215, 0.20800060126930475, 0.1483543706126511, 0.13050122157437727, 0.11079556061304174, 0.15442102710949257, 0.11034834242309444, 0.18226808519102633, 0.09157859647530131, 0.1031451609742362, 0.1274607316008769, 0.1934725558385253, 0.12502875819336623, 0.10823329575941898, 0.1196625258307904, 0.2868173673050478, 0.11207350180484354, 0.12342589732725173, 0.15279823215678334, 0.25243167649023235, 0.21294615464285016, 0.2801061555510387, 0.182555251813028, 0.1886452265898697, 0.14258636918384582, 0.17118164571002126, 0.2005127616575919, 0.1517624463303946, 0.18927750672446564, 0.18095708132022992, 0.09791763601242565, 0.2203547180397436, 0.12780173361534253, 0.10627326890244149, 0.1570853521116078, 0.09737313710502349, 0.17201981245307252, 0.21880293177673593, 0.2790093800285831], [0.03563334124919493, 0.06574932660441846, 0.0340905535267666, 0.046487677755067125, 0.019811661913990974, 0.024829262983985245, 0.02758002963673789, 0.05790689625428058, 0.08211073654820211, 0.0455708025401691, 0.08483625904773362, 0.10116735968040302, 0.015961869175953325, 0.09525604953523725, 0.06050217925803736, 0.07169704651460052, 0.058426948817214, 0.12954131292644888, 0.022913557186257094, 0.05411751990322955, 0.07584404898807406, 0.01578456452989485, 0.03092915656452533, 0.048427503352286294, 0.022645636308880057, 0.13125080557074398, 0.0349146788357757, 0.012534379802673357, 0.09739330125739798, 0.07172763042035513, 0.06356949787004851, 0.043153145161340944, 0.09535877019516192, 0.08549268866772763, 0.05365149198041763, 0.0642687345680315, 0.04481655043491628, 0.03614113724324852, 0.03639010181359481, 0.04412480200699065, 0.030216637278499547, 0.017317318415734917, 0.11734660205547698, 0.004065793427798781, 0.12968889641342685, 0.034978681651409715, 0.045251912815729156, 0.04212639127217699, 0.03231090566259809, 0.05304938385961577, 0.06703946870402433, 0.07916903385194018, 0.01918615944305202, 0.06370409377268516, 0.03906980411557015, 0.06409253386664204, 0.03683315655507613, 0.06862851078039967, 0.0386559046455659, 0.029942938781459816, 0.0513799894542899, 0.06329060619464144, 0.03388502314919606, 0.0782200793037191, 0.02389569130173186, 0.12637930369237438, 0.08449383210972883, 0.06859256856841967, 0.0778989891114179, 0.03700653338455595, 0.07009062333963811, 0.10797321010613814, 0.055965701394598, 0.053561332169920206, 0.05160699387488421, 0.07493235767469741, 0.08616422099294141, 0.13146672601578757, 0.32057336065918207, 1.1861489829607308, 3.786530066281557, 5.029656160622835, 5.22490868344903, 16.016497761011124, 9.57685885950923, 18.356410302221775, 10.770673099905252, 7.798999808728695, 12.468797229230404, 21.027904450893402, 18.669728189706802, 10.53132964298129, 19.45024810731411, 12.035730667412281, 14.586365651339293, 29.827067591249943, 12.954369373619556, 14.009700044989586, 22.05903422087431, 8.355884626507759, 0.877581553068012, 1.8281570705585182, 0.45790422591380775, 0.0837276091624517, 0.025952510914066806, 0.039664576106588356, 0.020013932407891843, 0.019161525706294924, 0.05705927083909046, 0.08308201489853673, 0.06638559207203798, 0.07400943024549633, 0.01982792979106307, 0.04039166189613752, 0.06400818878319114, 0.056017599781625904, 0.031221833633026108, 0.0556513387709856, 0.05517190023965668, 0.037372764709289186, 0.03560536970326211, 0.055510442034574226, 0.0638856527803, 0.0481849360949127, 0.014910608642821899, 0.12194651499157771, 0.06026227260008454, 0.014870039140078006, 0.042500693452893756, 0.05447809235192835, 0.0150295452294813, 0.018247320367663633, 0.057745686935959384, 0.06359128732583486, 0.035393152575124986, 0.023231675077113323, 0.018534924856794532, 0.024413383835053537, 0.07706393938860856, 0.026884177132160403, 0.0849301481503062, 0.05253582137811463, 0.08347504888661206, 0.026585909836285282, 0.058138906460953876, 0.06246340097277425, 0.04081215534824878, 0.06545360301970504, 0.00961707521128119, 0.021257597509247717, 0.03989734701463021, 0.03685494972160086, 0.01724609079246875, 0.05378300054871943, 0.10994966811267659, 0.05087369259854313, 0.05362148323911242, 0.0581852238974534, 0.04832786260521971, 0.0854867440648377, 0.03200691826350521, 0.03918335642083548, 0.020355190463305917, 0.04229243197187316, 0.03749436931684613, 0.048523143923375756, 0.014769270328542916, 0.042894380530924536, 0.027998062869301066, 0.023521647017332725, 0.06826802738942206, 0.07347046033828519, 0.043857517521246336, 0.14851924614049494, 0.03521507424011361, 0.0338989792362554, 0.06337860264466144, 0.16894564381800592, 0.07793660857714713, 0.07863658000133, 0.14502956386422738, 0.13203892187448218, 0.10361405729781836, 0.05050533130997792, 0.019545607538020704, 0.01865787275164621, 0.14689731207909063, 0.04562143556540832, 0.02288311985466862, 0.09476436185650527, 0.05845650484843645, 0.03880682408635039, 0.1133616994775366, 0.031037011031003203, 0.0239174158195965, 0.039369201331282966, 0.050950827717315406, 0.04115984040254261, 0.056468677139491774, 0.07628678460605443, 0.1468601156375371, 0.09816041478188708, 0.009049115160451038, 0.034193830797448754, 0.02038505448581418, 0.058741897737490945, 0.0567093111021677, 0.04153921145189088, 0.1421554633998312, 0.10745452309492975, 0.0337415326066548, 0.057235397325712256, 0.04536427397397347, 0.026801416533999145, 0.03491203679004684, 0.06107466826506425, 0.03994892998889554, 0.01443852572265314, 0.08741940793697722, 0.023136602248996496, 0.051145181350875646, 0.04130206558329519, 0.06539141104440205, 0.02611592812172603, 0.03186671914590988, 0.059588372823782265, 0.016121299195219763, 0.08215254914830439, 0.04585930873872712, 0.06234098371351138, 0.037275083232088946, 0.015354236693383427, 0.012862827461503912, 0.04542360868072137, 0.043177038605790585, 0.03215267606719863, 0.04478160641156137, 0.039964641255210154, 0.044438556069508195, 0.10161475598579273, 0.02362143248319626, 0.06221323041245341, 0.044272916129557416, 0.038442533477791585, 0.087746168137528, 0.03573614725610241, 0.07755030586849898, 0.024796532416075934, 0.032553064738749526, 0.028623546786548104, 0.09964543743990362, 0.08834059874061495, 0.18772629933664575, 0.2959393715718761, 1.158884852193296, 2.2243951773270965, 5.94175779260695, 8.587290309369564, 12.0373759791255, 21.193315275013447, 22.013736851513386, 37.814761474728584, 28.909261040389538, 24.908983893692493, 28.329693339765072, 36.01403430104256, 36.29458464682102, 31.27993483096361, 37.02998958528042, 31.200589388608932, 33.759014904499054, 40.000894367694855, 29.891521632671356, 34.572414457798004, 34.20148216187954, 13.094550501555204, 4.0823631919920444, 3.211304107680917, 1.7040627356618643, 0.2059156115865335, 0.07958181638969108, 0.06765224519767798, 0.05549844150664285, 0.026845514948945493, 0.1360664831008762, 0.04987466163584031, 0.013935195602243766, 0.059159352094866335, 0.07660946299438365, 0.03355859320436139, 0.015808942225703504, 0.03952064027544111, 0.024655012275616173, 0.038676833210047334, 0.12723252119030803, 0.01746662182995351, 0.04915372825053055, 0.06985857602558099, 0.08516871894244105, 0.02727962866629241, 0.04189851111732423, 0.05730626129661687, 0.04988675864296965, 0.01230989497344126, 0.07482844215701334, 0.018078363027598243, 0.038713428511982784, 0.02019989235122921, 0.06519804446725175, 0.031911797195789404, 0.027024597038689535, 0.03618496106355451, 0.044614664002438076, 0.03432350255025085, 0.04102655439055525, 0.018516306226956658, 0.10233296939986758, 0.05109352045110427, 0.02094522198603954, 0.01970892455574358, 0.10085922738653608, 0.025231291801901534, 0.08732099915505387, 0.03960407251724973, 0.055369931214954704, 0.06116277232649736, 0.10504618709092028, 0.02288597712322371, 0.050132535689044744, 0.0034488924484321615, 0.07677810863242485, 0.04197796915832441, 0.08535484215826727, 0.08484987745760009, 0.03802512364927679, 0.03486832800263073, 0.017106888008129317, 0.057700772158568725, 0.017310858020209707, 0.017597930018382613, 0.018674634156923275, 0.00908706859263475, 0.05016188762965612, 0.04771521227667108, 0.07469818039680831, 0.03401626454433426, 0.008123614334181184, 0.04484826611587778, 0.029544741300924215, 0.05233093295828439, 0.04733727728307713, 0.05002233046980109, 0.1744839653838426, 0.21765873301774263, 0.12916943756863475, 0.19414878595853224, 0.2784453774802387, 0.36848326795734465, 0.324629494571127, 0.09527639180305414, 0.16337843786459416, 0.1917089309426956, 0.24831290531437844, 0.25854652805719525, 0.07924997247755527, 0.21532260056119412, 0.11979698814684525, 0.1747423069900833, 0.2405241396627389, 0.24243334424681962, 0.15236581239150837, 0.29274516797158867, 0.14578679198166355, 0.1328091078903526, 0.1179645216325298, 0.1807719303178601, 0.34598176600411534, 0.2780029980931431, 0.17588367074495181, 0.11244014502153732, 0.18903667980339378, 0.1867798829334788, 0.13934609305579215, 0.1488612574758008, 0.28243326349183917, 0.1901140555855818, 0.19003920257091522, 0.22163369081681594, 0.1792777792434208, 0.21276677754940465, 0.11909591092262417, 0.16312480147462338, 0.24505382316419855, 0.16056516382377595, 0.2571262652054429, 0.08275009677163325, 0.2204066386912018, 0.14288499456597492, 0.15467064105905592, 0.12231825676281005, 0.1690739463083446, 0.16172662493772805, 0.1631287348573096, 0.13964357553049922, 0.13469101628288627, 0.15002371306763962, 0.1025022532849107, 0.11554086027899757, 0.08240337279858068, 0.09795005302294157, 0.1378167196526192, 0.11754344188375399, 0.20819480647332966, 0.20206028799293563, 0.23997275362489745, 0.25974571995902807, 0.10168900043936446, 0.4048589535523206, 0.27692525123711675, 0.1366465605678968, 0.15943074657116085, 0.11183947295648977, 0.12069449701812118, 0.17893748969072476, 0.161341272178106, 0.19142467353958637, 0.22725599381374195, 0.4343065421562642, 0.19869156094500795, 0.3424249490490183, 0.6904066249262542, 1.8103512260131538, 4.4784691371023655, 7.211467735469341, 10.020420458167791, 24.79515340179205, 43.545070588588715, 69.76241737604141, 59.66207675635815, 62.0642014592886, 66.75737142562866, 87.27783590555191, 87.51294448971748, 69.90053996443748, 73.11117008328438, 52.1431390196085, 62.39748157560825, 91.71824723482132, 63.45426566898823, 58.12136583030224, 54.081266820430756, 18.113396242260933, 5.023969765752554, 2.3757591051980853, 0.7292268855962902, 0.16537045128643513, 0.12024434734485112, 0.17467616678914055, 0.12237566930707544, 0.10849700309336185, 0.3956368187209591, 0.1951541140442714, 0.1637993543408811, 0.1395194884389639, 0.10598013541311957, 0.1224877113418188, 0.08455255083390512, 0.15456504828762263, 0.09325117469416, 0.25991160480771214, 0.2545563265448436, 0.1804000698029995, 0.1769268632051535, 0.14681594300782308, 0.30744322459213436, 0.17334519914584234, 0.15926440159091726, 0.13781579938950017, 0.22956475586397573, 0.1113078132038936, 0.22621292009716853, 0.12261719384696335, 0.14319497480755672, 0.10255057452013716, 0.1708753316779621, 0.15534880076302215, 0.09838961224886589, 0.13428592239506543, 0.14593718078685924, 0.10260038005071692, 0.1422224348061718, 0.11022692706319503, 0.14520625438308343, 0.1786472654202953, 0.15534191363258287, 0.10152366477996111, 0.2126603981014341, 0.1338322475203313, 0.10965263092657551, 0.12749524146784097, 0.11915016933926381, 0.17953662551008165, 0.2041140926303342, 0.10028813732787967, 0.10936294100247324, 0.170764647773467, 0.26584258186630905, 0.14612093655159697, 0.24412368948105723, 0.2041508734691888, 0.17454906657803804, 0.214955237461254, 0.19091800932073966, 0.15324543550377712, 0.09677160414867103, 0.16148933063959703, 0.12102365435566753, 0.1371652921079658, 0.10431974325911142, 0.14815170492511243, 0.1389863295480609, 0.10773531466838904, 0.16734288685256615, 0.15091863926500082, 0.1598135314998217, 0.13387742947088555, 0.14817187649896368, 0.12985360866878182], [0.022173979195940774, 0.00885715773620177, 0.08186336388462223, 0.062209170864662156, 0.05017321280320175, 0.05155078732059337, 0.0806335435481742, 0.03589469597500283, 0.05670584527251776, 0.03942447277950123, 0.05304153193719685, 0.014618836994486628, 0.04025396381621249, 0.011016403004759923, 0.016672347555868328, 0.041335443675052375, 0.05710729892598465, 0.030885180603945628, 0.0609027794416761, 0.03175357502186671, 0.07309615815756842, 0.018293042230652645, 0.03817491502559278, 0.03201936408004258, 0.08000344532774761, 0.013377750856307102, 0.026538681413512677, 0.04721127173979767, 0.08586918018409051, 0.02483304422639776, 0.0444136347505264, 0.04230604296026286, 0.08216975955292583, 0.055913424512255006, 0.036379054945427924, 0.010107946527568856, 0.041883549420163035, 0.03402069145522546, 0.014545782760251313, 0.04317434460972436, 0.01330745833911351, 0.04188453276583459, 0.03705695860844571, 0.05767363923951052, 0.0585973199486034, 0.03189239003404509, 0.007785396301187575, 0.07549756992375478, 0.059961450460832566, 0.007094362654243014, 0.09757494932273403, 0.06359500548569486, 0.05687207150913309, 0.026289345769328065, 0.017322878957202192, 0.015982948025339283, 0.04547562952211592, 0.03189244569512084, 0.020389075070852414, 0.08045312002650462, 0.017274795209232252, 0.024144299641193356, 0.03670934405818116, 0.01238107342942385, 0.04335206300311256, 0.03540319012245163, 0.03971353558881674, 0.05780049454187974, 0.046977257734397426, 0.04700951147242449, 0.047836690719123, 0.03104904495558003, 0.009127413595706457, 0.062167618016246706, 0.040085184591589496, 0.04542110764305107, 0.06906209571752697, 0.04055456702189986, 0.08488292529364116, 0.04155906390224118, 0.21171537693589926, 0.16720934479963034, 0.19401557045057416, 0.09975002831197344, 2.9270356614142656, 8.27206777408719, 13.018586877733469, 6.777446949854493, 2.6220991741865873, 9.571412801742554, 20.6822806969285, 22.284327931702137, 24.01010412722826, 28.982895389199257, 31.350734531879425, 22.656782045960426, 23.053273670375347, 23.304172307252884, 6.967400657013059, 0.14261575823184103, 0.022475860751001164, 0.009876665480987867, 0.07651469073607586, 0.04183059347269591, 0.14468081382801756, 0.0725415808847174, 0.045523943335865624, 0.03387454402400181, 0.05552143695240375, 0.042512200452620164, 0.06447909632697701, 0.028926255836267956, 0.09756019542692229, 0.053998420044081286, 0.05802093095553573, 0.01159658530013985, 0.07219358783913776, 0.03924905504391063, 0.034011147436103784, 0.04617594233423006, 0.037178811835474335, 0.0241262969939271, 0.00943040558922803, 0.02905795550759649, 0.04515941152931191, 0.0344109127036063, 0.02699203345400747, 0.016399470987380482, 0.013381223179749213, 0.0498879868973745, 0.03350406761455815, 0.06804195436416194, 0.06029450036294293, 0.006583265958397533, 0.022333780289045535, 0.00785783733590506, 0.024388165657001082, 0.014793465270486195, 0.02948752913653152, 0.030972724343882874, 0.029351255980145652, 0.06923694571014494, 0.052682748064398766, 0.037558138355962, 0.07397154360660352, 0.011156069631397258, 0.02495726861525327, 0.07076752881403081, 0.016080130408226978, 0.07611391614773311, 0.01698645228316309, 0.02288804029376479, 0.057688997985678725, 0.07594835784402676, 0.04162623568845447, 0.050446193272364326, 0.09928416737238877, 0.04177191927738022, 0.07195016340119764, 0.07250023583765142, 0.07326508581172675, 0.004218549220240675, 0.04636802870663814, 0.032976267029880546, 0.03737778162758332, 0.03574405855033547, 0.021265603427309543, 0.08292238635476679, 0.054221231330302544, 0.07448759599355981, 0.1015810773242265, 0.05514752439921722, 0.04126788968278561, 0.04271630219591316, 0.059929846102022566, 0.04198834067210555, 0.02217527053289814, 0.031512247151113115, 0.03854553615383338, 0.10371113021392375, 0.0721155658538919, 0.04533913372142706, 0.09841861538006924, 0.037981826753821224, 0.04665706925152335, 0.03571551183995325, 0.06262222799705341, 0.028992334810027387, 0.03945109732740093, 0.05832385337271262, 0.02077408273180481, 0.06030701668350957, 0.04771630323375575, 0.0837574212346226, 0.05947086487140041, 0.02915436605690047, 0.0543828488298459, 0.01792773859051522, 0.02721032691624714, 0.06282035174081102, 0.11024134699255228, 0.0454292898211861, 0.010063932531920727, 0.09437227039597929, 0.06341186570352875, 0.03867545281536877, 0.02381798101851018, 0.07059897223371081, 0.08059145635343157, 0.10019410721724853, 0.027278188899799716, 0.015292870357370703, 0.022287913707259577, 0.05481886430061422, 0.020449688126973342, 0.027232878928771242, 0.03268570508225821, 0.021810278594784904, 0.038185234589036554, 0.017191086517414078, 0.06090617105655838, 0.0208817126986105, 0.05177959887078032, 0.0457324979652185, 0.04719508549897, 0.03664645446406212, 0.047752007958479226, 0.03366494296642486, 0.052170710696373135, 0.020204376778565347, 0.056651085906196386, 0.06733157802955247, 0.02321306943485979, 0.022423760128731374, 0.06672263101791032, 0.06746258193743415, 0.028004050145682413, 0.060635420741164126, 0.013325315339898225, 0.018787299595715012, 0.0969040478230454, 0.03898249415215105, 0.016378945038013626, 0.04831625541555695, 0.04031550641229842, 0.04052399795909878, 0.0380186372785829, 0.0072821329740691, 0.047156185828498565, 0.01958685796125792, 0.008611778666818282, 0.0660540524404496, 0.028904557293571997, 0.09420191039680503, 0.02167980532249203, 0.05554971648962237, 0.4311717994278297, 0.5276999494526535, 0.27579127927310765, 0.27254800486844033, 3.4008581237867475, 10.665492843836546, 16.666361689567566, 11.987226270139217, 24.14491519331932, 31.43408875912428, 53.86697731912136, 49.928424060344696, 52.421211898326874, 57.08752490580082, 59.21237088739872, 43.907388746738434, 37.22137771546841, 31.09929632395506, 7.876748861745, 0.5085080105345696, 0.027352025172149297, 0.09830309267272241, 0.15101396071258932, 0.19811422942439094, 0.1813074789242819, 0.040053131233435124, 0.006494706403827877, 0.05573620706854854, 0.045113123778719455, 0.01931249709741678, 0.0265359317563707, 0.015549737872788683, 0.045925341328256764, 0.06157729520055, 0.022083066105551552, 0.0411534468003083, 0.10506218037335202, 0.059468486288096756, 0.023104448700905778, 0.058719336448120885, 0.022719123771821614, 0.07621481854585, 0.04562963258649688, 0.03597708921006415, 0.023898520739749074, 0.0554836245282786, 0.06551687853061594, 0.042985531108570285, 0.041842731297947466, 0.03395192034076899, 0.012993701493542176, 0.052999006875324994, 0.07664044023840688, 0.02453095486998791, 0.012138061811128864, 0.008233215630752966, 0.005632744087051833, 0.0181010579035501, 0.019020784820895642, 0.04729770225821994, 0.08257366600446403, 0.0696251483168453, 0.010490235144970939, 0.038860744825797155, 0.03312841843580827, 0.05489605508046225, 0.046997455283417366, 0.020010538937640376, 0.0666774416458793, 0.056151880271499977, 0.04347773086919915, 0.008609485430497443, 0.06738917611073703, 0.11296942248009145, 0.019967540756624658, 0.07428601384162903, 0.08088556205620989, 0.028639348965953104, 0.018895289504143875, 0.08218104761908762, 0.028589881112566218, 0.053288470444385894, 0.04119490688026417, 0.07190489981439896, 0.12054237158736214, 0.05046221995144151, 0.03152649638650473, 0.05957885477982927, 0.07857291857362725, 0.08141003039781936, 0.04107574393856339, 0.11264027256402187, 0.024795636272756383, 0.046492716937791556, 0.04542691494862083, 0.05422567679488566, 0.09992758714361116, 0.1397058565635234, 0.28522970562335104, 0.11883648578077555, 0.19952606147853658, 0.16729313327232376, 0.17334882082650438, 0.1382761387503706, 0.16733463417040184, 0.1291583795682527, 0.22015036025550216, 0.167906622227747, 0.11685740799293853, 0.10329598764656112, 0.0927130805212073, 0.17904201376950368, 0.11038121214369312, 0.172562648949679, 0.253231028909795, 0.16542228288017213, 0.2279337082291022, 0.13850446790456772, 0.1338725461391732, 0.22906687867362052, 0.2546936832368374, 0.18138902611099184, 0.14574880886357278, 0.17120855598477647, 0.24989958736114204, 0.14359036140376702, 0.13246797228930518, 0.19994017988210544, 0.34594103693962097, 0.28450477577280253, 0.15570786665193737, 0.09335474140243605, 0.14845154742943123, 0.1761900886776857, 0.1275407351204194, 0.13544671557610855, 0.13561815168941393, 0.07928676073788665, 0.09402971729286946, 0.15191927697742358, 0.11779998007114045, 0.11792780758696608, 0.21680195321096107, 0.2527995442505926, 0.13615411589853466, 0.14456543955020607, 0.1375641074264422, 0.14718179212650284, 0.215901906194631, 0.16465221560792997, 0.15926204156130552, 0.19409006723435596, 0.10373712022555992, 0.12132262854720466, 0.14382183726411313, 0.21095047501148656, 0.1612410822417587, 0.14470058464212343, 0.11431634629843757, 0.06495508758234791, 0.15398853312944993, 0.11100422285380773, 0.11352765854098834, 0.22907070815563202, 0.12939438252942637, 0.18883805139921606, 0.15970102191204205, 0.11925743194296956, 0.1552804044331424, 0.2563123370055109, 0.10603777060168795, 0.10793952402309515, 0.09756884886883199, 0.12635821185540408, 0.14650473080109805, 0.19584980327636003, 0.4183425597148016, 0.255520524806343, 0.24176521837944165, 0.38002544548362494, 3.6495837522670627, 15.44871037825942, 30.139627419412136, 42.833057194948196, 60.239330381155014, 66.27550408244133, 81.16556748747826, 69.07872006297112, 75.58815076947212, 82.82148063182831, 83.65910768508911, 74.81450468301773, 59.665162190794945, 45.08828178048134, 10.478035602718592, 0.9475027292501181, 0.12912110891193151, 0.07658505375729874, 0.21502963034436107, 0.30991896986961365, 0.23081436927895993, 0.1269931043498218, 0.14079319196753204, 0.12967736343853176, 0.08862354996381328, 0.19263137597590685, 0.14653398626251146, 0.07836509495973587, 0.27416832104790956, 0.18723063374636695, 0.11680262265144847, 0.09822406878811307, 0.20629332022508606, 0.19300846121041104, 0.07952004001708701, 0.20074885367648676, 0.10359594889450818, 0.1670518165337853, 0.13499881461029872, 0.1570435840403661, 0.13649203057866544, 0.14420906023588032, 0.15274708333890885, 0.10191922207013704, 0.18060374481137842, 0.17470965249231085, 0.1579810946714133, 0.11427462275605649, 0.1889578637201339, 0.12355414044577628, 0.12238422626978718, 0.10156071279197931, 0.1065937802195549, 0.10413059208076447, 0.12375408987281844, 0.1311829435871914, 0.11305812397040427, 0.1726932669407688, 0.12249712177435867, 0.12803280871594325, 0.20156904560280964, 0.1880046640872024, 0.11999317488516681, 0.15826067654415965, 0.1828223210759461, 0.30107161961495876, 0.2024136541876942, 0.15751236904179677, 0.1263328452478163, 0.28228115290403366, 0.13807819312205538, 0.17176626512082294, 0.26824040163774043, 0.1600112099549733, 0.24848741391906515, 0.22927987505681813, 0.16371284960769117, 0.11283974701655097, 0.15417565824463964, 0.12871227459982038, 0.13159876893041655, 0.21971224079607055, 0.11192190329893492, 0.16101156565127894, 0.11263584194239229, 0.16615573258604854, 0.1695016014855355, 0.20906307472614571, 0.16171383031178266, 0.15027449961053208, 0.1195710338652134, 0.1134077126334887], [0.072655648982618, 0.005580414790529176, 0.06077471072785556, 0.05677668326825369, 0.013014669948461233, 0.029925208873464726, 0.01713757766992785, 0.04057808568177279, 0.03822016376943793, 0.04198727197945118, 0.04300864529795945, 0.06689505418762565, 0.029597723223560024, 0.10434564421302639, 0.02750722680502804, 0.03397034415684175, 0.10915235659922473, 0.038801714399596676, 0.013778760148852598, 0.032785961811896414, 0.0871389577514492, 0.04214602849970106, 0.044292917009443045, 0.05377111134293955, 0.03214677970390767, 0.06495678710052744, 0.07260364669491537, 0.05750509008066729, 0.06633263983530924, 0.07285500469151884, 0.04449673302588053, 0.034983375735464506, 0.023417503289238084, 0.03500853825244121, 0.03794482327066362, 0.059416283620521426, 0.01887806982267648, 0.029217624869488645, 0.05826768021506723, 0.06362397893099114, 0.01422993676897022, 0.05547078537347261, 0.011506637001730269, 0.01745230023516342, 0.0053841436329093995, 0.07868326851166785, 0.03098954512097407, 0.01864208170445636, 0.051502236019587144, 0.0653174560284242, 0.014942114667064743, 0.015712687527411617, 0.060248665322433226, 0.028891836882394273, 0.061628336407011375, 0.048819847143022344, 0.0516397077444708, 0.029578800313174725, 0.058315689748269506, 0.03223596730094869, 0.04667154855269473, 0.021041541622253135, 0.030644470571132842, 0.046945768408477306, 0.03639960130385589, 0.03990847180830315, 0.027450437664811034, 0.03899439820088446, 0.09399458402185701, 0.06570907251443714, 0.04661949060391635, 0.06840024099801667, 0.03756101417820901, 0.04545478259387892, 0.03320806201372761, 0.09929237552569248, 0.02939374950074125, 0.05000258192012552, 0.030016314922249876, 0.00508095172335743, 0.012592145794769749, 0.11873713447130285, 0.05381119473895524, 0.028307963330007624, 0.125255350722, 0.12874868436483666, 0.19102852995274588, 3.634889703243971, 5.1874664425849915, 11.84488020837307, 25.108195804059505, 29.533882923424244, 34.03565526008606, 28.255967795848846, 21.95815723389387, 11.408180091530085, 9.181914702057838, 1.658886841032654, 0.07732075217063539, 0.14457183686317876, 0.03252117465308402, 0.008933027493185364, 0.0783022127870936, 0.029304589734238107, 0.014770786165172467, 0.02903545173467137, 0.01786142027413007, 0.08158556316629983, 0.02120514436683152, 0.10073627578094602, 0.00730193440176663, 0.04543143091723323, 0.07247790461406112, 0.04896349724731408, 0.03856415663904045, 0.013228465995780425, 0.012214349953865167, 0.027369784766051453, 0.06854800260043703, 0.0643716259219218, 0.0371392924716929, 0.027082846354460344, 0.0045147074251872255, 0.03469403091003187, 0.05304090853314847, 0.06476834838395007, 0.005699364364772919, 0.026508544651733246, 0.026136973574466538, 0.025038557905645575, 0.09588104177964851, 0.05314523594279308, 0.03997740619524848, 0.008653332442918327, 0.04919470964523498, 0.043185495378565975, 0.06381837709341198, 0.059713172377087176, 0.05260035854007583, 0.0066147562120022485, 0.023509295824624132, 0.01043029280481278, 0.023065317109285388, 0.05450828291941434, 0.05645051678584423, 0.03618566981458571, 0.0697007063718047, 0.047674512898083776, 0.03320458134112414, 0.04318266779591795, 0.01971545545529807, 0.022491883719339967, 0.035895764667657204, 0.06476606999058276, 0.025915329315466806, 0.07640051131602377, 0.041526112545398064, 0.022389298501366284, 0.0379442518169526, 0.07033985879388638, 0.01779519658157369, 0.03390119454707019, 0.036123077079537325, 0.035115437203785405, 0.023364632688753773, 0.048661357795936055, 0.04174974390480202, 0.06317737672361545, 0.03216407545551192, 0.054907550947973505, 0.07045682868920267, 0.05627820122754201, 0.027284888637950644, 0.048542962977080606, 0.02806079475703882, 0.048295883461833, 0.055597314130864106, 0.02442566637910204, 0.049782917340053245, 0.11858077879878692, 0.006275341002037749, 0.015838691215321887, 0.048637475483701564, 0.004254011355442344, 0.031401403684867546, 0.12059631088050082, 0.025866978394333273, 0.028883701088489033, 0.04047820744744968, 0.06851086553069763, 0.028651778084167745, 0.023576146631967276, 0.07419024710543454, 0.019303921581013128, 0.02397171876509674, 0.020592404980561696, 0.046892727114027366, 0.05488833303388674, 0.04031900563859381, 0.030140094022499397, 0.023779220500728115, 0.024226006389653776, 0.10874162238906138, 0.10078441147925332, 0.10456743504619226, 0.08942259068135172, 0.021558295338763855, 0.03499777340039145, 0.041678579364088364, 0.056207719462690875, 0.03061430783418473, 0.0480566595797427, 0.015880817372817546, 0.05628010112559423, 0.017902577928907704, 0.04667776775022503, 0.06747366220224649, 0.04067591558850836, 0.03573504145606421, 0.018613677857501898, 0.08280723472125828, 0.04983839287888259, 0.040784447264741175, 0.017195997679664288, 0.07169398886617273, 0.046466526546282694, 0.057856003477354534, 0.0023256774511537515, 0.0747047780896537, 0.018491034243197646, 0.015323409734264715, 0.0618398893129779, 0.07124352749087848, 0.052360347981448285, 0.015649224624212366, 0.02699360680708196, 0.03148862087982707, 0.021818579516548198, 0.024855941337591503, 0.09683801152277738, 0.027046970935771242, 0.03937316439987626, 0.034836000049836, 0.007019512886472512, 0.08207737701013684, 0.041223338557756506, 0.016466780070913956, 0.041276160918641835, 0.036210980761097744, 0.009812029056774918, 0.0548612075363053, 0.02607101334433537, 0.0488859873439651, 0.0609431040356867, 0.007913413992355345, 0.06440456985728815, 0.015994267632777337, 0.16827428218675777, 0.09580935031408444, 0.02165291916753631, 0.13265475601656362, 0.0836571422405541, 0.5410400242544711, 3.483917391858995, 10.738979950547218, 23.65694347769022, 35.14400638639927, 42.73817628622055, 53.543637469410896, 39.8015608638525, 29.821899868547916, 17.61617962270975, 9.915479589253664, 1.325804314110428, 0.03373250066943001, 0.12896619300590828, 0.0420950281113619, 0.03683264818391763, 0.022504939952341374, 0.039755337056703866, 0.02850800552550936, 0.013990298211865593, 0.03493565563985612, 0.04547690230538137, 0.0400397020712262, 0.00687653442582814, 0.027140448146383278, 0.05286517538479529, 0.04066254950885195, 0.027440489175205585, 0.031167775596259162, 0.04297520041291136, 0.02705613645957783, 0.03976904452429153, 0.021792942025058437, 0.039980385918170214, 0.0739459617761895, 0.010634735936037032, 0.037382379232440144, 0.01891146461275639, 0.07778306564432569, 0.013330241345101967, 0.03791685914620757, 0.03189017101249192, 0.028939393705513794, 0.01616708414076129, 0.09861458689556457, 0.03526200023770798, 0.019243568276579026, 0.017777342363842763, 0.05513162388524506, 0.0342163735331269, 0.012609705936483806, 0.04007575931609608, 0.01675574269029312, 0.015339210985985119, 0.007991733764356468, 0.013671843571501086, 0.029704954285989515, 0.032196280953940004, 0.0680297682993114, 0.09606061925296672, 0.07079860995872878, 0.04414237235323526, 0.03966496944485698, 0.02290665706823347, 0.015110923577594804, 0.049861032093758695, 0.020657732529798523, 0.04401385464007035, 0.03555807263182942, 0.03202019157470204, 0.10210432854364626, 0.06983218525419943, 0.054277452727546915, 0.026512511431064922, 0.009383220767631428, 0.08650330826640129, 0.05572720481723081, 0.03448490853770636, 0.03283102130808402, 0.05475652760651428, 0.013240757816674886, 0.047142370749497786, 0.0588519025768619, 0.0443466410797555, 0.04101767459360417, 0.019091361209575552, 0.03199145932740066, 0.03117557556834072, 0.09246077257557772, 0.024009150838537607, 0.27265730837825686, 0.12105251647881232, 0.17184364143759012, 0.2341960690682754, 0.19246430369094014, 0.1411123451543972, 0.15545470523647964, 0.15075511444592848, 0.06490899279015139, 0.16766738350270316, 0.11316922347759828, 0.17726186866639182, 0.1116264691518154, 0.26653595559764653, 0.14713497745105997, 0.1926125551108271, 0.2111757910461165, 0.1810844783904031, 0.11483849913929589, 0.11046064420952462, 0.2079476267681457, 0.08044973583309911, 0.15430871048010886, 0.1260144787374884, 0.1286250277189538, 0.16402665933128446, 0.22069249913329259, 0.12926930096000433, 0.21380627411417663, 0.15797937288880348, 0.19209213147405535, 0.11688529048115015, 0.1644590642536059, 0.11833141717943363, 0.14681450324133039, 0.2676202036673203, 0.1212505363218952, 0.12080797881935723, 0.08851579012116417, 0.24036229209741578, 0.15996105561498553, 0.10104723565746099, 0.10768478925456293, 0.17857830505818129, 0.14917730848537758, 0.15124233439564705, 0.1252650876995176, 0.06439717064495198, 0.18314396787900478, 0.1494719707989134, 0.12967532995389774, 0.1292689744150266, 0.16015201021218672, 0.10260561219183728, 0.12783979094820097, 0.14521320088533685, 0.12577397836139426, 0.11557846490177326, 0.2187046268954873, 0.18232491886010394, 0.18906473298557103, 0.11574486925383098, 0.07288732522283681, 0.1998718429240398, 0.17588435352081433, 0.09285255975555629, 0.18079642119118944, 0.09660206051194109, 0.2508116571698338, 0.14607709046686068, 0.14328480436233804, 0.16774003976024687, 0.07592287991428748, 0.16623049654299393, 0.13172821432817727, 0.14268869650550187, 0.16534692520508543, 0.1439848425798118, 0.16172594216186553, 0.12316063890466467, 0.1404187487787567, 0.22580202261451632, 0.19954480812884867, 0.10221264499705285, 0.23721735225990415, 0.14637948595918715, 0.966717170085758, 5.83683212287724, 22.99470741301775, 52.626134902238846, 85.97150400280952, 87.53770396113396, 89.64219823479652, 86.403419226408, 70.75953707098961, 41.24718949198723, 17.305544391274452, 3.319444879889488, 0.30127853038720787, 0.18915298918727785, 0.13567066605901346, 0.16336059663444757, 0.13303567073307931, 0.19590641430113465, 0.15108982304809615, 0.2082293014973402, 0.12417393765645102, 0.13747021090239286, 0.1496846554800868, 0.17320696671959013, 0.07200326406746171, 0.17895769095048308, 0.12340057524852455, 0.15054890129249543, 0.0818572634307202, 0.26492525765206665, 0.1557547110132873, 0.14237641560612246, 0.14013489213539287, 0.1491555487154983, 0.1646539819194004, 0.09247150403098203, 0.11867411871207878, 0.08353966768481769, 0.21143882302567363, 0.19080919562838972, 0.13838783197570592, 0.11267631125519983, 0.16873542306711897, 0.06401468999683857, 0.16745089902542531, 0.0975661697157193, 0.18411401426419616, 0.11277517274720594, 0.16732157237129286, 0.19602570711867884, 0.22883145458763465, 0.13605481653939933, 0.11032872746000066, 0.18569198349723592, 0.1004480553092435, 0.08753863396123052, 0.20364165626233444, 0.38900896499399096, 0.1528766326373443, 0.11774742117268033, 0.18451986514264718, 0.1826554417493753, 0.1348691020393744, 0.12410610535880551, 0.06457887808210216, 0.19486752629745752, 0.1574683893704787, 0.2972335880622268, 0.13976936956169084, 0.15679287171224132, 0.18216691561974585, 0.12126835528761148, 0.14055153384106234, 0.15899368096143007, 0.08363559027202427, 0.24144901894032955, 0.183792159659788, 0.12210605447762646, 0.0906780522200279, 0.16346424497896805, 0.16641037829685956, 0.1490201661363244, 0.1761873872601427, 0.1254003366921097, 0.21077246346976608, 0.16750498674809933, 0.1685798986000009, 0.12420141938491724, 0.13518116029445082, 0.11036947878892533], [0.030065059181652032, 0.02577186474809423, 0.1095664750027936, 0.031715228251414374, 0.036936122123734094, 0.013022789044043748, 0.015926995656627696, 0.03335584588057827, 0.02388527154835174, 0.06268128810916096, 0.01721655145956902, 0.039399529196089134, 0.021659500162058976, 0.027209575491724536, 0.05812910640088376, 0.029264860713738017, 0.013748625242442358, 0.027886562602361664, 0.03645820128440391, 0.09928685394697823, 0.1083004823885858, 0.030114848013909068, 0.025344463756482583, 0.08404066189541481, 0.09538737256661989, 0.06058745573682245, 0.047806091970414855, 0.03754129902517889, 0.03182095089869108, 0.06034138554241508, 0.07113670275430195, 0.07097184949088842, 0.11880639911396429, 0.05919683426327538, 0.04252729944710154, 0.07603299978654832, 0.06725672501488589, 0.013024299314565724, 0.064515483827563, 0.035283982651890256, 0.04402715763717424, 0.009625103393773315, 0.11976856389082968, 0.029222046214272268, 0.0902676816622261, 0.08707807937753387, 0.06603916495805606, 0.02913557673309697, 0.0512999154307181, 0.029987018642714247, 0.024781273859844077, 0.034004850313067436, 0.06756628965376876, 0.04360957340395544, 0.015473612074856646, 0.0561535129963886, 0.013555424720834708, 0.07622952049132437, 0.01826037474529585, 0.06486706144642085, 0.01240112718733144, 0.068400389427552, 0.0502605784276966, 0.022728491530870087, 0.046460949306492694, 0.0415719846932916, 0.04481348907575011, 0.006476190746980137, 0.040779434057185426, 0.07678950059926137, 0.1422640247619711, 0.012113353859604103, 0.0239827489349409, 0.03790556365856901, 0.07546875975094736, 0.08377171499887481, 0.04079394304426387, 0.08787337967078201, 0.016452653289888985, 0.020586298960552085, 0.03307680206489749, 0.03813681316387374, 0.03599471892812289, 0.021754970039182808, 0.03425651630095672, 0.027825571050925646, 0.04111744892725255, 0.16306879901094362, 0.1624583380180411, 2.3462040536105633, 1.3690518122166395, 3.562252800911665, 6.453510532155633, 1.6146673075854778, 0.7411087886430323, 0.7142168597783893, 0.06847838914836757, 0.019660239668155555, 0.017216981905221473, 0.028035877148795407, 0.025590422628738452, 0.11603967999690212, 0.03498566526104696, 0.01930324808199657, 0.008331824792549014, 0.09903960744850338, 0.05229876085650176, 0.03299122130556498, 0.05242245089903008, 0.06933077544090338, 0.0453208657563664, 0.07791842595906928, 0.08153065908118151, 0.07291148955118842, 0.05077236346551217, 0.019958093216700945, 0.023538597670267336, 0.07695226100622676, 0.0147396836837288, 0.04589288349961862, 0.03987837029853836, 0.07837071301764809, 0.0476303551113233, 0.03192650656274054, 0.08053404380916618, 0.06641245039645582, 0.019772216764977202, 0.0633018348889891, 0.03760801439057104, 0.04879348234680947, 0.011309042038192274, 0.156231852597557, 0.018065355034195818, 0.06787506761611439, 0.036303533997852355, 0.03611618623835966, 0.02759899707598379, 0.030470308920484968, 0.0589443482022034, 0.04221800198138226, 0.0285111837729346, 0.030172279111866374, 0.051000299281440675, 0.030589137895731255, 0.025954972988984082, 0.004246873286319897, 0.08390944276470691, 0.04328354792960454, 0.08027824034797959, 0.06236528162844479, 0.01990097382076783, 0.06457554583903402, 0.053596112920786254, 0.04603941684763413, 0.04015703932964243, 0.02905382545577595, 0.022091357750468887, 0.0716069720510859, 0.042912210628855973, 0.014714861626998754, 0.07456882405676879, 0.06430134453694336, 0.027675490237015765, 0.00894622566192993, 0.08916182967368513, 0.01994487927731825, 0.029160765225242358, 0.005348079894247348, 0.03303867793874815, 0.048538324554101564, 0.04679127552662976, 0.03571724475477822, 0.05402797236456536, 0.024389156424149405, 0.016378930195060093, 0.0054585082216362935, 0.032397670147474855, 0.0173969527168083, 0.09082521268283017, 0.04281091860320885, 0.03853321279166266, 0.03284639860794414, 0.02693375074159121, 0.011452681937953457, 0.030415130240726285, 0.07421605158015154, 0.0251342726915027, 0.054945077645243146, 0.00989101305094664, 0.05783481145044789, 0.028994895219511818, 0.060216634228709154, 0.02540872632380342, 0.04548172255454119, 0.024069036589935422, 0.08547819452360272, 0.03337132708111312, 0.05881895122001879, 0.03805896558333188, 0.05054699176980648, 0.0557556698913686, 0.03379983943887055, 0.0878712793928571, 0.042747754414449446, 0.01690529472398339, 0.05269027344183996, 0.028767486328433733, 0.06716973046422936, 0.12864298769272864, 0.0659522668865975, 0.09167750249616802, 0.060342294673318975, 0.019278556828794535, 0.029561951705545653, 0.06655435645370744, 0.052644382740254514, 0.027755846276704688, 0.0351310631231172, 0.058014025271404535, 0.028270486727706157, 0.03091662725637434, 0.068820764136035, 0.014813950401730835, 0.013224267295299796, 0.051228539377916604, 0.05501794170413632, 0.04513831598160323, 0.052020941584487446, 0.048083243309520185, 0.018977222607645672, 0.03326309597468935, 0.02574808633653447, 0.03306084588984959, 0.1210706916754134, 0.005627791178994812, 0.08912007644539699, 0.018864163830585312, 0.049272278920398094, 0.0537691075442126, 0.03290856460807845, 0.0365015167335514, 0.01727151120576309, 0.037864144396735355, 0.027103652464575134, 0.05075506029243115, 0.036759969661943614, 0.03535394491336774, 0.03787562542129308, 0.06987144486629404, 0.060275954092503525, 0.04750813823193312, 0.06345276546198875, 0.032800834451336414, 0.061655383979086764, 0.04281857756723184, 0.023246506898431107, 0.03613291795772966, 0.022756823018426076, 0.0399345323239686, 0.03810150177741889, 0.06004901275446173, 0.03916041663615033, 0.06836538974312134, 0.06681162194581702, 0.136679318966344, 1.57033437397331, 3.1945132836699486, 5.684462198987603, 7.335873059928417, 4.231143733486533, 2.256436957977712, 0.9508379409089684, 0.045252128038555384, 0.048389932126156054, 0.018790333124343306, 0.06353814213071018, 0.03995343853603117, 0.1114851345482748, 0.007159874348872108, 0.041025448590517044, 0.029400202474789694, 0.027466826140880585, 0.024320324082509615, 0.042313557205488905, 0.022617286267632153, 0.0416189032694092, 0.06781349162338302, 0.007297718539120979, 0.020379128436616156, 0.05088037192763295, 0.08826081786537543, 0.016486920103488956, 0.0324351077870233, 0.020869333675364032, 0.030365372949745506, 0.03258169308537617, 0.0451344271277776, 0.012851996743847849, 0.009063308734766906, 0.1082215624046512, 0.07396533183054999, 0.06670127200777642, 0.035747027141042054, 0.05360707815270871, 0.03289066029537935, 0.087198359251488, 0.050718902857624926, 0.04624574132321868, 0.02420696288027102, 0.04423794242029544, 0.052951234829379246, 0.02465815156028839, 0.022963600204093382, 0.03607829217799008, 0.0585565092478646, 0.024573157097620424, 0.037878694201936014, 0.021746832389908377, 0.014687971761304652, 0.1089315750868991, 0.04764534649439156, 0.046324973009177484, 0.061157762829679996, 0.0047707084831927205, 0.06213780965481419, 0.061759355157846585, 0.023678384895902127, 0.030108632527117152, 0.006685284824925475, 0.03766963491216302, 0.010782878816826269, 0.05807510402519256, 0.06898944688146003, 0.030164339987095445, 0.0509478851017775, 0.030473427796096075, 0.08225590805523098, 0.046805142555967905, 0.012048184016748564, 0.05803642328828573, 0.0764089792210143, 0.03274423084803857, 0.034622966559254564, 0.014616621683671838, 0.027666513960866723, 0.059768840874312446, 0.028000181700917892, 0.04112276641535573, 0.06720436649629846, 0.014992538035585312, 0.027167434491275344, 0.03555736388079822, 0.15763746545417234, 0.10552247520536184, 0.15038142824778333, 0.11202995257917792, 0.14400499931070954, 0.15323299710871652, 0.07837519558961503, 0.17364510102197528, 0.10504243182367645, 0.2035398336010985, 0.13687190628843382, 0.1035642295028083, 0.13902768201660365, 0.13462774077197537, 0.15925565909128636, 0.2362152747809887, 0.11869357782416046, 0.12616022169822827, 0.06569127581315115, 0.20628122321795672, 0.18283777259057388, 0.17769203230272979, 0.10334303238778375, 0.17228275537490845, 0.19020453823031858, 0.15634281851816922, 0.1905623424681835, 0.18179067643359303, 0.06408946879673749, 0.18916560569778085, 0.16167025140020996, 0.2611667843302712, 0.29173620336223394, 0.17642622522544116, 0.2057216883986257, 0.18237670592498034, 0.1397749356692657, 0.14975907804910094, 0.14663760492112488, 0.16640599962556735, 0.10600373570923693, 0.16217869677348062, 0.17372007278027013, 0.08812702348222956, 0.20145191985648125, 0.20077659515663981, 0.17792199418181553, 0.0703699306177441, 0.15138372837100178, 0.09906825434882194, 0.1663690703571774, 0.10318413114873692, 0.16449946677312255, 0.0882988455123268, 0.235656111035496, 0.11012821400072426, 0.1493454197770916, 0.21552600839640945, 0.07009785185800865, 0.24555291747674346, 0.1834538293769583, 0.13960939220851287, 0.15771540580317378, 0.1525454269722104, 0.1759091709391214, 0.12725897133350372, 0.16563259268878028, 0.07729756005574018, 0.10438920828164555, 0.18418436986394227, 0.2695547748589888, 0.12590315658599138, 0.1577811749302782, 0.13642593490658328, 0.15793845086591318, 0.15032153693027794, 0.1477485554642044, 0.13501625508069992, 0.1266888386453502, 0.12537323345895857, 0.16332580475136638, 0.12352622085018083, 0.1430656184675172, 0.1419821719173342, 0.1308550182147883, 0.17797387030441314, 0.234895127650816, 0.2647599665215239, 0.39313097193371505, 4.201332433149219, 8.418520465493202, 16.328626312315464, 21.902207136154175, 7.864038068801165, 3.4155486105009913, 1.198887205682695, 0.15343303559347987, 0.12095479789422825, 0.12128197369747795, 0.16666861600242555, 0.21140349679626524, 0.16753876931034029, 0.11092005588579923, 0.09570242167683318, 0.1511061206110753, 0.2267239333014004, 0.2846952702384442, 0.11730440353858285, 0.13742360402829945, 0.09323220539954491, 0.3062252711970359, 0.1613676332635805, 0.10256955865770578, 0.1298001888790168, 0.2508929668692872, 0.10797004113555886, 0.12103703527827747, 0.1282679062569514, 0.09957568297977559, 0.2038624303531833, 0.1412681516376324, 0.26554319949354976, 0.10819516421179287, 0.18735519581241533, 0.13456252083415166, 0.16299093287670985, 0.1677046244731173, 0.1941307814558968, 0.14563215809175745, 0.20916635199682787, 0.20001139637315646, 0.19650603993795812, 0.07055852518533356, 0.19896403304301202, 0.09374919289257377, 0.09780440654139966, 0.10717701923567802, 0.09329359585535713, 0.13026284374063835, 0.14816596900345758, 0.17487709585111588, 0.06409585868823342, 0.18252949928864837, 0.15651291876565665, 0.12150157519499771, 0.12410264695063233, 0.22338830603985116, 0.09555399214150384, 0.18825638573616743, 0.14933903730707243, 0.0958963151788339, 0.14912759943399578, 0.15656501753255725, 0.2877563622314483, 0.149634723784402, 0.1517358626006171, 0.19585179223213345, 0.14992298878496513, 0.1656619372079149, 0.14968038070946932, 0.1761460496345535, 0.13676425034645945, 0.16465043445350602, 0.17357824835926294, 0.3029190032975748, 0.16184998472454026, 0.1387992934905924, 0.1268998609157279, 0.10452686183270998, 0.12416591504006647, 0.13934477203292772, 0.20296729635447264, 0.1430982432793826, 0.1276198183768429, 0.11371191154466942, 0.09258989142836072], [0.03968191267631482, 0.043741230401792563, 0.06289574652328156, 0.05250116308161523, 0.043424422401585616, 0.016130065814650152, 0.06209472056070808, 0.02251718167826766, 0.042233167769154534, 0.010071738070109859, 0.07858905286411755, 0.01645760341489222, 0.03876521186612081, 0.056085535979946144, 0.02478377860825276, 0.008764362373767653, 0.019835648126900196, 0.0447947461361764, 0.022231716429814696, 0.01980622939299792, 0.05458009312860668, 0.050341925234533846, 0.04438816424226388, 0.038843601214466617, 0.02431260574667249, 0.09211282405885868, 0.03312906039354857, 0.030722911869816016, 0.06529292062623426, 0.06463844285462983, 0.02872421726351604, 0.035902032104786485, 0.0905079445510637, 0.0011468352386145853, 0.024466903814754914, 0.03998152882559225, 0.018881943833548576, 0.021804044554301072, 0.05072685125924181, 0.06342568449326791, 0.012868940902990289, 0.031556453177472576, 0.04518091525824275, 0.0854952639201656, 0.06785004239645787, 0.03960999114497099, 0.05003807513276115, 0.05032305241911672, 0.044414054063963704, 0.10337846993934363, 0.07332076915190555, 0.024763206274656113, 0.06894330013892613, 0.03686008167278487, 0.031432547912118025, 0.027929330717597622, 0.02078872530546505, 0.08098066828097217, 0.021655806121998467, 0.021020401545683853, 0.07032744266325608, 0.013236451504781144, 0.0690749051864259, 0.03180744010023773, 0.030201337904145475, 0.004358443593446282, 0.019846173636324238, 0.09052698063896969, 0.05327889673935715, 0.018993783633050043, 0.033725895555107854, 0.017138084185717162, 0.04400257399538532, 0.017393674279446714, 0.03584264173696283, 0.059690529451472685, 0.024911717446229886, 0.05106274358695373, 0.07342161959968507, 0.009246948538930155, 0.02192080850363709, 0.04555538071144838, 0.021419921904453076, 0.07630277788848616, 0.04934746590151917, 0.04774223758431617, 0.03250989771913737, 0.019482788447930943, 0.07088918166118674, 0.07154399339924566, 0.05625867903290782, 0.0762888923054561, 0.10132318842806853, 0.017994893678405788, 0.033179626625496894, 0.1331467108684592, 0.1041083424934186, 0.03812250084592961, 0.02710232773097232, 0.017239613698620815, 0.050578852169564925, 0.03223948137019761, 0.033578364018467255, 0.03824733750661835, 0.05313675690558739, 0.03196146913978737, 0.027444526458566543, 0.03195799588866066, 0.0020407732199601014, 0.11917230018298142, 0.01154338444393943, 0.04588038944348227, 0.040348758338950574, 0.04416228046466131, 0.01630550581467105, 0.03604316632845439, 0.07627588987816125, 0.088110770448111, 0.01387525697282399, 0.007963715834193863, 0.0410034142259974, 0.02127359821315622, 0.05313517613103613, 0.061553205086966045, 0.013952915305708302, 0.047732474631629884, 0.0476618926768424, 0.050586770885274746, 0.06412738512153737, 0.012740796119032893, 0.04845322619075887, 0.03459738472884055, 0.04006688322988339, 0.02025638834311394, 0.062412853294517845, 0.056241847123601474, 0.027904856542591006, 0.0289691816578852, 0.03422278939979151, 0.024369530328840483, 0.05369374615838751, 0.048520550117245875, 0.04346257250290364, 0.017845887123257853, 0.053348294968600385, 0.07868970293202437, 0.019695159571710974, 0.03785453358432278, 0.008489040428685257, 0.029386251953837927, 0.05670228667440824, 0.03859213560645003, 0.025498210779915098, 0.03515648910251912, 0.034537942410679534, 0.01712125784251839, 0.04401001031510532, 0.03297214068879839, 0.08145073719788343, 0.10038242719019763, 0.014033362258487614, 0.09655333851696923, 0.05283373800921254, 0.015772024089528713, 0.008699625759618357, 0.07549305766588077, 0.047152226470643654, 0.05380861577577889, 0.03879704629071057, 0.010364291756559396, 0.02793056824884843, 0.05057256617874373, 0.0538368099660147, 0.05210734612774104, 0.06322564600850455, 0.02977158801513724, 0.03275289542216342, 0.07097530789906159, 0.029400883395283017, 0.05035568094172049, 0.04652484079997521, 0.03966057593061123, 0.04912201256956905, 0.007263327879627468, 0.03443231624260079, 0.024252682887890842, 0.00700891872838838, 0.03798184159677476, 0.03853170252114069, 0.09717761087813415, 0.0674792579957284, 0.04681636011810042, 0.013254502391646383, 0.022777682934247423, 0.02922745461546583, 0.04701008292613551, 0.04546819691313431, 0.03911145715392195, 0.035550747634260915, 0.017920218779181596, 0.03597058057493996, 0.020455233825487085, 0.03824117025942542, 0.05136804458743427, 0.05276736774249002, 0.04004267066193279, 0.030834985445835628, 0.044416992968763225, 0.08545775577658787, 0.018944380717584863, 0.021284366775944363, 0.03902475204085931, 0.060859553050249815, 0.01631214803637704, 0.0558393507526489, 0.03606549013056792, 0.02935279222583631, 0.07472072684322484, 0.02376522545091575, 0.039220152102643624, 0.02380032903602114, 0.037259602031554095, 0.05433620113763027, 0.010426295411889441, 0.012053061782353325, 0.014268044196796836, 0.06932994423550554, 0.030114647634036373, 0.06703634426230565, 0.047309684232459404, 0.038252402664511465, 0.0171670019699377, 0.0305270034368732, 0.06578402942977846, 0.017952761954802554, 0.007639606956217904, 0.04570689387037419, 0.05333826855348889, 0.008651336993352743, 0.006460482727561612, 0.04251347323588561, 0.06828143799793907, 0.008749699391046306, 0.027075402613263577, 0.036347220520838164, 0.020198450729367323, 0.04062094842083752, 0.013249536496005021, 0.02179864914069185, 0.009477286130277207, 0.042003309790743515, 0.09066183629329316, 0.031047902048157994, 0.10899689892539755, 0.03251132264267653, 0.03210675567970611, 0.03400031208002474, 0.04390651040012017, 0.03175717814883683, 0.04177505485131405, 0.052050430822419, 0.04892764780379366, 0.025633359582570847, 0.07058933173539117, 0.08161367572029121, 0.05638376060232986, 0.050222287318320014, 0.07162021196563728, 0.032011475050239824, 0.021405704210337717, 0.04489300277782604, 0.17448767612222582, 0.1571267787949182, 0.0465814555354882, 0.04760679563332815, 0.023068974041962065, 0.010669538023648784, 0.02662834398506675, 0.04448639490874484, 0.034925640356959775, 0.020401526453497354, 0.0065427980371168815, 0.02935436186817242, 0.027664196604746394, 0.007234026497826562, 0.03367265388078522, 0.04956746815878432, 0.02662217117176624, 0.05012434980017133, 0.0402103181113489, 0.031068880707607605, 0.06710859976010397, 0.08834796084556729, 0.03284429090854246, 0.027478401789267082, 0.011365686459612334, 0.008210331507143565, 0.02560159937274875, 0.03375042724655941, 0.037176585392444395, 0.020002082164864987, 0.01462208760131034, 0.048373029712820426, 0.06227413105079904, 0.030809629970462993, 0.01332662430286291, 0.009903324353217613, 0.020247566062607802, 0.02922538587881718, 0.037175910038058646, 0.13383710116613656, 0.07023799902526662, 0.05707186879590154, 0.04884030815446749, 0.04105012871150393, 0.05533615236345213, 0.03599871168262325, 0.07634562949533574, 0.02272119436383946, 0.0736360483278986, 0.05391551472712308, 0.0488052268337924, 0.06572596379555762, 0.039012992710922845, 0.06721528348862194, 0.027712996525224298, 0.03622251002525445, 0.024134863233484793, 0.020235611918906216, 0.0036373541252032737, 0.06489634659374133, 0.03695402272569481, 0.02625986024213489, 0.030653357789560687, 0.021957099525025114, 0.024897776202124078, 0.005652392446791055, 0.04074375159689225, 0.047251503565348685, 0.012021918482787441, 0.011663086370390374, 0.0886376656126231, 0.04976333577360492, 0.02437958086375147, 0.019735150199267082, 0.03129273471131455, 0.05476806800288614, 0.034377798074274324, 0.006490036439572577, 0.03791936760535464, 0.058332592161605135, 0.040553624494350515, 0.10775052127428353, 0.13464087678585202, 0.12451363349100575, 0.1483778521651402, 0.178861434396822, 0.10086894952110015, 0.1598601383739151, 0.11162180846440606, 0.21181577467359602, 0.16279013740131631, 0.1704862088081427, 0.13676533388206735, 0.16724621469620615, 0.16770098794950172, 0.14036449778359383, 0.10432001043227501, 0.09775779224582948, 0.11116348032373935, 0.12514309346443042, 0.09959179500583559, 0.1479650250985287, 0.17894313001306728, 0.1055291471129749, 0.13556403428083286, 0.1229905238142237, 0.16779285098891705, 0.19510200043441728, 0.15455871034646407, 0.1284810807555914, 0.1728773195645772, 0.10969846596708521, 0.10555153770837933, 0.286891819559969, 0.09497615596046671, 0.07325060651055537, 0.15856339858146384, 0.12358137726550922, 0.10918245810898952, 0.15427241945872083, 0.11504792579216883, 0.10688286158256233, 0.28542503889184445, 0.11136019398691133, 0.16061389324022457, 0.16669395292410627, 0.07800895313266665, 0.11606330997892655, 0.2404932663193904, 0.11019357494660653, 0.13028069981373847, 0.15096316812559962, 0.11016987074981444, 0.17941569996764883, 0.11781111228629015, 0.14964671689085662, 0.13638953998452052, 0.1268841719138436, 0.1302696714992635, 0.07661168201593682, 0.0949420988035854, 0.13816947728628293, 0.09506286107352935, 0.22974255960434675, 0.13186515541747212, 0.11110968203865923, 0.13933613343397155, 0.20524714433122426, 0.17617235134821385, 0.20258765813196078, 0.21637216064846143, 0.15034136711619794, 0.08166361483745277, 0.14961667475290596, 0.07062599383061752, 0.06683977160719223, 0.1299960564938374, 0.07604892627568915, 0.21137081261258572, 0.09628741958294995, 0.12258729271707125, 0.11626055798842572, 0.13157478271750733, 0.0798649679927621, 0.15024150372482836, 0.1300348262884654, 0.2153158321743831, 0.18406926275929436, 0.19658191711641848, 0.24656142195453867, 0.16587356803938746, 0.19687528809299693, 0.18215640680864453, 0.11784821224864572, 0.12198143303976394, 0.16097344894660637, 0.22785314067732543, 0.2988905960228294, 0.11968526523560286, 0.09694606822449714, 0.10947355069220066, 0.11719794987584464, 0.11276576231466606, 0.16314308799337596, 0.17427141428925097, 0.1824685392784886, 0.1035418537503574, 0.13366799539653584, 0.10935104437521659, 0.11598379627685063, 0.27069037954788655, 0.1523787554469891, 0.13129018392646685, 0.16855865833349526, 0.1185135699051898, 0.08654698365717195, 0.12676473066676408, 0.19750620267586783, 0.12287123099667951, 0.14452398318098858, 0.17480510752648115, 0.13520568085368723, 0.10022796399425715, 0.15849739196710289, 0.1669646438676864, 0.18360730551648885, 0.10460100980708376, 0.137105445319321, 0.12386616901494563, 0.17965916893444955, 0.05738151878176723, 0.19842952344333753, 0.08055892802076414, 0.16222022735746577, 0.11275351687800139, 0.3098829311784357, 0.10255724642775021, 0.10952604279736988, 0.14569218299584463, 0.12993482931051403, 0.10727092318120413, 0.16433560056611896, 0.22449694108217955, 0.11168776312842965, 0.1106560071639251, 0.2066163919516839, 0.17887963185785338, 0.1280725433025509, 0.11163360119098797, 0.15247144969180226, 0.17949601518921554, 0.06492658911156468, 0.12437367186066695, 0.24029782915022224, 0.21974743343889713, 0.12397646700264886, 0.1084555170382373, 0.14197846117895097, 0.11611474823439494, 0.17124144796980545, 0.19641334569314495, 0.12504642130807042, 0.16832198743941262, 0.12895336869405583, 0.1949482868076302, 0.12155225645983592, 0.22267915424890816, 0.09336815201095305, 0.09184645241475664, 0.08436316958977841, 0.15972439956385642, 0.13738006964558735, 0.1591884353547357, 0.10157674318179488, 0.10043815505923703, 0.13453574414597824, 0.21845811512321234], [0.01255877048606635, 0.04604401074175257, 0.026367427126388066, 0.035309961531311274, 0.022626147510891315, 0.028127322730142623, 0.09328466781880707, 0.041703185270307586, 0.03303358309494797, 0.06278983462834731, 0.017550169104652014, 0.020571266759361606, 0.04269879122148268, 0.013651125591422897, 0.07094942178810015, 0.00855611944643897, 0.06836741580627859, 0.052149344264762476, 0.032332097689504735, 0.040526473021600395, 0.049965897560468875, 0.040453052351949736, 0.11298725628876127, 0.009036635947268223, 0.011368161522113951, 0.02057377336313948, 0.015164758970058756, 0.03939496869861614, 0.01858819436165504, 0.04272692232916597, 0.04565463925246149, 0.05545642852666788, 0.029632817531819455, 0.11286976689007133, 0.018083426330122165, 0.04991787689505145, 0.030025448904780205, 0.04654251133615617, 0.03710173608851619, 0.01981469729798846, 0.053284214227460325, 0.027373204211471602, 0.041772843251237646, 0.012251865518919658, 0.027915009122807533, 0.02916130699304631, 0.03991562240116764, 0.016292074797092937, 0.05262664541078266, 0.06727353465976194, 0.035346018776181154, 0.01658034721913282, 0.038066494671511464, 0.04969079454895109, 0.023661810882913414, 0.011543294458533637, 0.06047114264219999, 0.0028180379331388394, 0.02068490441160975, 0.004386986129247816, 0.05417626089183614, 0.03319753835967276, 0.025719836485222913, 0.019992751513200346, 0.06123737672169227, 0.02831360550771933, 0.08173944748705253, 0.11469221441075206, 0.026726672986114863, 0.016065714189608116, 0.009331247238151263, 0.029215938338893466, 0.03436065817368217, 0.040168657651520334, 0.08440113044343889, 0.007864413692004746, 0.0301434355424135, 0.07463361354894005, 0.021014811318309512, 0.032017363992054015, 0.04127762666030321, 0.022536444121215027, 0.07664075936190784, 0.02669169000000693, 0.10766803898150101, 0.02571914257714525, 0.015538581537839491, 0.02542610000091372, 0.04120029116165824, 0.04761760501423851, 0.045211224569357, 0.020921354516758583, 0.03177794715156779, 0.05636853544274345, 0.01540740786367678, 0.04870485507126432, 0.03697015701618511, 0.055664467363385484, 0.012267161182535347, 0.04736972397950012, 0.009274652911699377, 0.022430556346080266, 0.08578930282965302, 0.046196848634281196, 0.022327076840156224, 0.017684102640487254, 0.031579103524563834, 0.03330256338813342, 0.052449056893237866, 0.024257586628664285, 0.014791403955314308, 0.047455382664338686, 0.04423400903760921, 0.03237250020902138, 0.06831798134953715, 0.043064517885795794, 0.016279252340609673, 0.00634246454865206, 0.033505514802527614, 0.02544849987316411, 0.004102731973034679, 0.05299487311276607, 0.05992444697767496, 0.04982039208698552, 0.04962834653269965, 0.02904853579821065, 0.0444767544104252, 0.015700336334703024, 0.026710839265433606, 0.03450978532782756, 0.021084781001263764, 0.05980427100439556, 0.022158765168569516, 0.0959821668220684, 0.040642389067215845, 0.047283876047004014, 0.12594774481840432, 0.04744159727124497, 0.021539851113629993, 0.034284031426068395, 0.018492926719773095, 0.03833481816400308, 0.03279196949733887, 0.009444216957490426, 0.03062775926082395, 0.11946067650569603, 0.032652211957611144, 0.011294396681478247, 0.06460414821049199, 0.058367283854749985, 0.03623671473178547, 0.022357786911015864, 0.025969661946874112, 0.034576456164359115, 0.0047704756343591725, 0.008488824278174434, 0.056254081428050995, 0.03734137557330541, 0.09273236151784658, 0.036566992712323554, 0.01919614318467211, 0.0420045751525322, 0.06261192698730156, 0.031089102376427036, 0.03598219518607948, 0.041736158891581, 0.030079410462349188, 0.039596487767994404, 0.005971353602944873, 0.1048683314002119, 0.022985486139077693, 0.0762309528363403, 0.02428777348541189, 0.021713530368288048, 0.032488776196260005, 0.015288147515093442, 0.03379071473318618, 0.057200234368792735, 0.03152362427499611, 0.083505781221902, 0.02685565639694687, 0.035062143579125404, 0.002946905615317519, 0.05494109973369632, 0.03878844479913823, 0.050020463968394324, 0.003371877232893894, 0.0388678397575859, 0.03309446889034007, 0.037014158951933496, 0.07838252058718354, 0.04430873588717077, 0.05004312173696235, 0.02427305113087641, 0.00949579436564818, 0.014453164585574996, 0.030868124194967095, 0.013327714332262985, 0.04796036591869779, 0.023757609160384163, 0.015613610812579282, 0.04437681309354957, 0.03179165090841707, 0.049201325891772285, 0.022229684800549876, 0.025314488411822822, 0.029441185724863317, 0.071164666878758, 0.040652693787706085, 0.03448359122558031, 0.020515386750048492, 0.06803755342843942, 0.049387656908947974, 0.040605723261251114, 0.02252218189823907, 0.058859387136180885, 0.02599229002953507, 0.07290530003956519, 0.025730794295668602, 0.006908211607878911, 0.04119789773540106, 0.06019340129569173, 0.010224667803413467, 0.024039306154008955, 0.04798338362888899, 0.025404716870980337, 0.016495712698088028, 0.054479391110362485, 0.041895757749443874, 0.042105121319764294, 0.01849844087701058, 0.04778655493282713, 0.020579413685481995, 0.04829542704101186, 0.019922345818486065, 0.0193219650464016, 0.055991205299505964, 0.04652360141335521, 0.030117438109300565, 0.04559323024295736, 0.027086991249234416, 0.04054416211147327, 0.014080086020840099, 0.022339481838571373, 0.07073117099935189, 0.06888959091156721, 0.03178466729877982, 0.006667662528343499, 0.00519439548952505, 0.01850463781011058, 0.057624022956588306, 0.04154071430093609, 0.05416596730356105, 0.06302571142441593, 0.05439028886030428, 0.03200706298230216, 0.02899290255300002, 0.027666666101140436, 0.14047834323719144, 0.021002562170906458, 0.06455219787312672, 0.06729868604452349, 0.07057134949718602, 0.052569815452443436, 0.06460238189902157, 0.06446536659495905, 0.035760834798566066, 0.06549819125211798, 0.04568055133859161, 0.0269124399710563, 0.027355876918591093, 0.03315060865134001, 0.018621490817167796, 0.06307435920462012, 0.032469335637870245, 0.04330740797740873, 0.014508365529763978, 0.04198167618596926, 0.014798198317294009, 0.10131313974852674, 0.03254419978475198, 0.05150171280547511, 0.024425612573395483, 0.009055201699084137, 0.04953355200996157, 0.0755860710341949, 0.012066153267369373, 0.03196704637957737, 0.027637323437375017, 0.005464808591568726, 0.01868269573606085, 0.03934849541110452, 0.04051431293191854, 0.01593092532857554, 0.03147439019812737, 0.058285150371375494, 0.02793180578009924, 0.026577894641377497, 0.01268638092369656, 0.07744361471850425, 0.053880793348071165, 0.0272765765839722, 0.050350070305285044, 0.0258629448217107, 0.03543944032571744, 0.024134555242198985, 0.03960355301387608, 0.014050055942789186, 0.02060832775896415, 0.03004829221026739, 0.02338639988010982, 0.018769463931676, 0.026983584102708846, 0.02457798476825701, 0.021558959560934454, 0.02314866957021877, 0.03231410802982282, 0.05039067691541277, 0.04203736694762483, 0.023648546848562546, 0.0484254216280533, 0.07450227567460388, 0.0447278415231267, 0.05409703291661572, 0.08735581330256537, 0.013828889441356296, 0.014694888577651, 0.057416447962168604, 0.016920469788601622, 0.058206048561260104, 0.036801949245273136, 0.014164953390718438, 0.03609163970395457, 0.02987707317515742, 0.034432138127158396, 0.027136075041198637, 0.03334224231366534, 0.034808106429409236, 0.05279949902615044, 0.013836255257047014, 0.058542081897030585, 0.04167265331489034, 0.022701763082295656, 0.016079037595773116, 0.01920775779581163, 0.057487541998852976, 0.02532595088268863, 0.03187320180586539, 0.01791916678484995, 0.01638539986743126, 0.06589087643078528, 0.011268371417827439, 0.1491584282484837, 0.10460823090397753, 0.1391651129233651, 0.23147989762946963, 0.13725997530855238, 0.0955022570269648, 0.12637900683330372, 0.12257916620001197, 0.19435480615356937, 0.3248009900562465, 0.07238333273562603, 0.10625020295265131, 0.1338458139798604, 0.0996124638186302, 0.1979483148897998, 0.35214236355386674, 0.15945786464726552, 0.1307809370337054, 0.08854270039591938, 0.10001582108088769, 0.12444519263226539, 0.10890729201491922, 0.1853013614891097, 0.07967462195665576, 0.07248718888149597, 0.14499186276225373, 0.12330969926551916, 0.1686909535783343, 0.190471533278469, 0.12678888015216216, 0.10506816950510256, 0.1636741985566914, 0.08637244536657818, 0.17859950079582632, 0.1045858180441428, 0.1766523130936548, 0.0992568711808417, 0.12669116898905486, 0.15695347246946767, 0.12387638096697628, 0.15849518036702648, 0.22313271038001403, 0.12373100165859796, 0.09300060337409377, 0.1024561065423768, 0.12561536655994132, 0.11177908440004103, 0.13214040314778686, 0.20044053584570065, 0.1929107352043502, 0.1443897731951438, 0.1481963525293395, 0.16665251139784232, 0.08403492509387434, 0.07473510224372149, 0.08087557274848223, 0.13258883845992386, 0.08859505149303004, 0.13270280265714973, 0.08421683291089721, 0.1409468610654585, 0.1670166535768658, 0.10667021400877275, 0.1348956857691519, 0.09284668194595724, 0.14050396217498928, 0.171332064201124, 0.18675827159313485, 0.2919352473691106, 0.24054247071035206, 0.16675479419063777, 0.16981851338641718, 0.2102065907092765, 0.0909826741553843, 0.12532851163996384, 0.20384044793900102, 0.22627689322689548, 0.21357139921747148, 0.10181932157138363, 0.09605800689314492, 0.09022984697367065, 0.07132416183594614, 0.22657050169073045, 0.17177383502712473, 0.18252480891533196, 0.1613355873269029, 0.12538390554254875, 0.19000862608663738, 0.20452663768082857, 0.15217041975120082, 0.2106133321649395, 0.11223502282518893, 0.14788283966481686, 0.11860788945341483, 0.07360841074842028, 0.26436852815095335, 0.17477125074947253, 0.16179684695089236, 0.14255938469432294, 0.12794505717465654, 0.08259300637291744, 0.09381042007589713, 0.1901863852981478, 0.24550978385377675, 0.10084497815114446, 0.17946337553439662, 0.09461765410378575, 0.10674349367036484, 0.16575421585002914, 0.13538735860493034, 0.10128166526556015, 0.1498012914089486, 0.101304805430118, 0.1453797091380693, 0.1427718170452863, 0.13221062516095117, 0.15384626341983676, 0.14277480047894642, 0.13019208738114685, 0.10230564352241345, 0.17777506378479302, 0.11163033574121073, 0.10585071227978915, 0.20345696539152414, 0.12443616811651736, 0.05916277710639406, 0.09303302780608647, 0.1601552905049175, 0.10705497305025347, 0.09952478649211116, 0.19692563539138064, 0.1596321357646957, 0.14134883793303743, 0.1442800837685354, 0.15563299879431725, 0.16248964180704206, 0.16475550772156566, 0.0674630346475169, 0.1126142825523857, 0.11202237525139935, 0.08665162647957914, 0.20476151257753372, 0.10507899743970484, 0.06892657213029452, 0.143680710461922, 0.2149206236936152, 0.15616330783814192, 0.12478092539822683, 0.2168781717773527, 0.10883715163799934, 0.1882442887290381, 0.14152687916066498, 0.06545634154463187, 0.1161037347628735, 0.10888144301134162, 0.1582390206749551, 0.14885603275615722, 0.12696042016614228, 0.21035703888628632, 0.11338240539771505, 0.20184690569294617, 0.17988179839449003, 0.20161033869953826, 0.11240950174396858, 0.1458492362871766, 0.0998954447277356, 0.10519945542910136, 0.1443853648379445, 0.15772782935528085, 0.19220896036131307, 0.1961974400910549, 0.142475358734373, 0.062377037247642875, 0.14213426766218618, 0.15504941839026287, 0.09451839927351102], [0.043184152091271244, 0.043541073173400946, 0.044472398003563285, 0.016585462471994106, 0.028522998763946816, 0.010111350202350877, 0.021548517543124035, 0.06255791347939521, 0.009250951497961069, 0.03174666933773551, 0.060284570427029394, 0.059577322244876996, 0.045501934946514666, 0.06778507478884421, 0.05518630532606039, 0.013803044148517074, 0.025002342954394408, 0.09123518248088658, 0.047787734947633, 0.05158593172382098, 0.02193471635109745, 0.0363861201913096, 0.060846342821605504, 0.06623420136747882, 0.0602421195799252, 0.02118746269843541, 0.07308807616936974, 0.04976625612471253, 0.03751453717995901, 0.015404813129862305, 0.039318260314757936, 0.0913733703782782, 0.08663474261993542, 0.038971554895397276, 0.052410910502658226, 0.002751954552877578, 0.04573604172037449, 0.09098262220504694, 0.029840722781955265, 0.013399940144154243, 0.012526312657428207, 0.021419268814497627, 0.014957453931856435, 0.06291019613854587, 0.0025297244610555936, 0.015729200313217007, 0.03883068413415458, 0.03997945081209764, 0.045852221228415146, 0.026848902853089385, 0.01787601831892971, 0.009750787958182627, 0.026755915459943935, 0.014596880555473035, 0.02907695077738026, 0.09256736724637449, 0.04506885466980748, 0.031703398417448625, 0.0642121458076872, 0.05133868151460774, 0.03918137859727722, 0.04587107920087874, 0.029218470917840023, 0.023083883788785897, 0.0843550504941959, 0.02259330933156889, 0.03476995261735283, 0.030091021362750325, 0.01578999148478033, 0.1149732360499911, 0.029311167018022388, 0.0663275783881545, 0.08345688111148775, 0.03321940574096516, 0.06459644471760839, 0.0672872866562102, 0.039202526095323265, 0.055696108829579316, 0.02581790387921501, 0.06612027427763678, 0.027260460847173817, 0.04004347589216195, 0.06884221962536685, 0.05936718684097286, 0.010733130802691448, 0.02476268677128246, 0.020717200823128223, 0.01858051684394013, 0.06370396018610336, 0.010234702567686327, 0.01808367309422465, 0.044456456671468914, 0.05917516726185568, 0.03374306885234546, 0.044530801314977, 0.048956892132991925, 0.03303613237221725, 0.0333437340304954, 0.08154922019457445, 0.01997250201384304, 0.04029039955639746, 0.020790437811228912, 0.03826770574960392, 0.05445685950689949, 0.02157198981876718, 0.05272734000755008, 0.04441626566404011, 0.012415843975759344, 0.043678081055986695, 0.047132040053838864, 0.06096109369536862, 0.03377191613253672, 0.014764502957405057, 0.055340026374324225, 0.0639552588108927, 0.04097470795386471, 0.07038207957521081, 0.047837236197665334, 0.06430181208997965, 0.025260742077080067, 0.04017021616164129, 0.024984358860820066, 0.07244255612022243, 0.04273531601938885, 0.029761101468466222, 0.03864662779960781, 0.024599688877060544, 0.04635987992514856, 0.003923477797798114, 0.012814699184673373, 0.03981338413723279, 0.061283445538720116, 0.07466944443876855, 0.06978556353715248, 0.018395150618744083, 0.0360905710113002, 0.06858948123408481, 0.021136282339284662, 0.02115520524966996, 0.02577100385678932, 0.013600036145362537, 0.11059218246373348, 0.10478475072886795, 0.03968468830862548, 0.013023938445257954, 0.015348422894021496, 0.022337724803946912, 0.019900843944924418, 0.02704917325900169, 0.06330038770101964, 0.04973553863237612, 0.05215812758251559, 0.018127311377611477, 0.04925185130559839, 0.003136248592454649, 0.02296888800628949, 0.012069556014466798, 0.01658892273553647, 0.012795304082828807, 0.01656854150496656, 0.06863228089059703, 0.0866927117749583, 0.024764620065980125, 0.016620844362478238, 0.03434623453358654, 0.060169641437823884, 0.067993870616192, 0.02304925146745518, 0.0025576368670954253, 0.04815816311747767, 0.059608421943266876, 0.05287360989314038, 0.040816931068548, 0.017304041393799707, 0.02968624103232287, 0.04828315933991689, 0.05279513148707338, 0.039345894183497876, 0.0673840478702914, 0.03459444582404103, 0.036572328754118644, 0.043790520139737055, 0.01511186517745955, 0.07414505773340352, 0.10216082082479261, 0.08044839996728115, 0.01819846293074079, 0.017799207889765967, 0.016512496367795393, 0.050258964256499894, 0.0447222420189064, 0.049899234145414084, 0.03930904655135237, 0.05150840326678008, 0.007410319039991009, 0.0223130502490676, 0.03378423207323067, 0.0598727155738743, 0.011593444160098443, 0.05725910894398112, 0.024079194736259524, 0.03199382306775078, 0.014678835923405131, 0.04317167658882681, 0.04764920195157174, 0.028480820656113792, 0.03983206770499237, 0.056432152341585606, 0.041908107086783275, 0.014098927294980967, 0.03493829026410822, 0.06462505451054312, 0.027332926001690794, 0.042459229662199505, 0.015629977024218533, 0.06517249974422157, 0.0121489648881834, 0.015504192269872874, 0.0866021474939771, 0.033453887299401686, 0.11636833267402835, 0.03475576275377534, 0.0166624825578765, 0.04479520626773592, 0.019460013791103847, 0.044858144101453945, 0.024043209850788116, 0.06101045022660401, 0.039170795571408235, 0.02481422521668719, 0.019075195377808996, 0.043689202138921246, 0.03846108345896937, 0.02987038271385245, 0.027267847071925644, 0.021242262882879004, 0.019646088767331094, 0.08082855027168989, 0.021960431768093258, 0.014562391097570071, 0.013755801810475532, 0.042855235951719806, 0.05218933860305697, 0.02217319623014191, 0.027610845463641454, 0.05381860879424494, 0.02592247248685453, 0.0816401703923475, 0.071161965461215, 0.010903901766141644, 0.02291776330821449, 0.014838378192507662, 0.03661422299046535, 0.012565242941491306, 0.07141124544432387, 0.025414535484742373, 0.06254247680772096, 0.0500442164047854, 0.08738184042158537, 0.028002469371131156, 0.030617126139986794, 0.04504944750806317, 0.09321488367277198, 0.05438734995550476, 0.05212817450228613, 0.04854080703807995, 0.16236488678259775, 0.04095497424714267, 0.024566316351410933, 0.04056093835970387, 0.03888983330398332, 0.009552726369292941, 0.09038048068759963, 0.021259894456306938, 0.06191807457071263, 0.03975465428084135, 0.07452320423908532, 0.06855598068796098, 0.04173388791969046, 0.03437987237703055, 0.04912675118248444, 0.01623863645363599, 0.0738804969296325, 0.0645763696229551, 0.026988949830411002, 0.013450783753796713, 0.014575985387637047, 0.037037625661469065, 0.09059795964276418, 0.07353562832577154, 0.03935769804229494, 0.01794991025235504, 0.03136313855065964, 0.009479312193434453, 0.07103139199898578, 0.04838527886022348, 0.03607823280617595, 0.035009848143090494, 0.08554811225621961, 0.05529651425604243, 0.04753945686388761, 0.06293795246165246, 0.02870257438189583, 0.02426156268484192, 0.11590095775318332, 0.06510594394057989, 0.013279464528750395, 0.025540438982716296, 0.033396337457816117, 0.06741107688867487, 0.035071027086814865, 0.05877112351299729, 0.0745012960396707, 0.01971950758161256, 0.07425183794111945, 0.03352617619384546, 0.03999885426310357, 0.10819077069754712, 0.0662521761842072, 0.038667170447297394, 0.056097035558195785, 0.006924527260707691, 0.03336006870085839, 0.020412508383742534, 0.05168862269783858, 0.030595830212405417, 0.03511220886139199, 0.04732680186862126, 0.06838730536401272, 0.056277711410075426, 0.034529656331869774, 0.016817765826999675, 0.049978361930698156, 0.08756716953939758, 0.008526052261004224, 0.07963524360093288, 0.0215844671765808, 0.04100924008525908, 0.03484675005893223, 0.07132480008294806, 0.021463311568368226, 0.009330051452707266, 0.0657961264369078, 0.04633155956980772, 0.04840174711716827, 0.022472903292509727, 0.05154529913852457, 0.027668233888107352, 0.03764760425838176, 0.044660933199338615, 0.016363120594178326, 0.0042124269657506375, 0.10927294817520306, 0.1094123457733076, 0.12768929824233055, 0.0802630782709457, 0.15929892630083486, 0.10903416216024198, 0.11837851387099363, 0.21301958273397759, 0.1464081328595057, 0.18417881859932095, 0.18004483339609578, 0.24228242109529674, 0.1417145089362748, 0.20863629528321326, 0.15626823267666623, 0.1261998969130218, 0.10194588001468219, 0.12518573726993054, 0.18424546346068382, 0.1420944885467179, 0.11179177512531169, 0.15647555905161425, 0.13188615819672123, 0.1539686435717158, 0.13412161089945585, 0.11612113812589087, 0.14113535173237324, 0.12493327347328886, 0.15149981511058286, 0.12448709429008886, 0.121816846949514, 0.14505745377391577, 0.2446028497070074, 0.12496212817495689, 0.15536447492195293, 0.1499734102981165, 0.08572373408242129, 0.19483126496197656, 0.19797961867880076, 0.11863958658068441, 0.07515408171457238, 0.13567954214522615, 0.15640604950021952, 0.2159925817977637, 0.22001202392857522, 0.10735024392488413, 0.14026813732925802, 0.15735001681605354, 0.09899932367261499, 0.07980512120411731, 0.11697984009515494, 0.17736196954501793, 0.11175183273735456, 0.06874925820739008, 0.18379595945589244, 0.14120633073616773, 0.29811145970597863, 0.08469510255963542, 0.09279509526095353, 0.11027829110389575, 0.0916459241125267, 0.18336998153245077, 0.13453800027491525, 0.10477698044269346, 0.16767850087489933, 0.19637620862340555, 0.1141540905518923, 0.103992018266581, 0.13230309676146135, 0.1738933494198136, 0.10199765223660506, 0.237564543785993, 0.16156229859916493, 0.09700857190182433, 0.11740704256226309, 0.1003263505117502, 0.1003875257447362, 0.22333105676807463, 0.10730063877417706, 0.16378923144657165, 0.09106423618504778, 0.1874681210028939, 0.14870386279653758, 0.1214837191218976, 0.11397617548936978, 0.08724386774701998, 0.1437858134158887, 0.1511101727373898, 0.18375270708929747, 0.13699329196242616, 0.2962626510998234, 0.18953430466353893, 0.10546471385168843, 0.1875880965963006, 0.1635677894228138, 0.16130887001054361, 0.18025834928266704, 0.13573290256317705, 0.16047442884882912, 0.1535289062303491, 0.19216122542275116, 0.13179643254261464, 0.11884863473824225, 0.19275586382718757, 0.0762416174984537, 0.1680242971633561, 0.1921125702210702, 0.10386202367953956, 0.14720071689225733, 0.12707462185062468, 0.06888789881486446, 0.10541651878156699, 0.19122301717288792, 0.1514116331236437, 0.23810742481146008, 0.12873600848251954, 0.1043414139712695, 0.19071181101026013, 0.21876196522498503, 0.14017437439179048, 0.11590970767429098, 0.1671939526568167, 0.2116134503739886, 0.17662363650742918, 0.15392974019050598, 0.20660883688833565, 0.2079372515436262, 0.18705910857534036, 0.1876302357413806, 0.12522753502707928, 0.15225858689518645, 0.1275611441815272, 0.16168687550816685, 0.21118631470017135, 0.1162039914925117, 0.09927621897077188, 0.1969595070113428, 0.10279878581059165, 0.14177713135723025, 0.12622976093553007, 0.10873731051106006, 0.15929796150885522, 0.10819511968293227, 0.16161521372850984, 0.06506786434329115, 0.12575681990711018, 0.12205840117530897, 0.09655531262978911, 0.17483837058534846, 0.14433247939450666, 0.18706045928411186, 0.10615802078973502, 0.15985602687578648, 0.12326886630035006, 0.0967007661529351, 0.16929215256823227, 0.10951835414743982, 0.09574318042723462, 0.11371019718353637, 0.11244119887123816, 0.14679014595458284, 0.12450984853785485, 0.07660289498744532, 0.1520041935145855, 0.17784568655770272, 0.13232239260105416, 0.16378427390009165, 0.16913788975216448, 0.13868479494703934, 0.11446722492109984, 0.16086407122202218, 0.14948488416848704, 0.11056886418373324, 0.11901431178557687, 0.07392364539555274, 0.16354622261133045], [0.03485978959361091, 0.12295861888560466, 0.027443797298474237, 0.058074662447324954, 0.03296387687441893, 0.01142929686466232, 0.052730920870089903, 0.06160220909805503, 0.04937857302138582, 0.016883909738680813, 0.059383714469731785, 0.016798861470306292, 0.05252641836705152, 0.052850165448035114, 0.07080502953613177, 0.004955301483278163, 0.03990106146375183, 0.06416461867047474, 0.012015428401355166, 0.017158021983050276, 0.07353183595114388, 0.04540755231573712, 0.04688880857429467, 0.033941192596103065, 0.05876267416169867, 0.07236712423036806, 0.02173996010242263, 0.05046654296165798, 0.09341167155071162, 0.03264123559347354, 0.018750830458884593, 0.02677098847925663, 0.08153644783305936, 0.02481914565578336, 0.11682346957968548, 0.01391732097545173, 0.03718236672284547, 0.037633032188750803, 0.0922679626091849, 0.028593595561687835, 0.013464606254274258, 0.029676973463210743, 0.02961985406727763, 0.04310843447456136, 0.08561037844629027, 0.07483906971174292, 0.06293815284152515, 0.03572986868675798, 0.11066245642723516, 0.025428938715776894, 0.03522556078678463, 0.04651319279219024, 0.08527991492883302, 0.009384427685290575, 0.06467948362114839, 0.03940967806556728, 0.04339366780186538, 0.1390744373202324, 0.07757141254842281, 0.06678771736915223, 0.057808346464298666, 0.09178561114822514, 0.06283065275056288, 0.02214946049207356, 0.008828537738736486, 0.026814697266672738, 0.10391346935648471, 0.03936054417863488, 0.048342456939280964, 0.03571776054741349, 0.03408834192669019, 0.020582695833581965, 0.022536531323567033, 0.028986052529944573, 0.019058931211475283, 0.04359137223218568, 0.057111629357677884, 0.03800062906520907, 0.02870741875085514, 0.008935689020290738, 0.05763467648648657, 0.02477036428899737, 0.04348287395259831, 0.06165240425616503, 0.08891735880752094, 0.029703568325203378, 0.06301959612756036, 0.034936553638544865, 0.02289862331963377, 0.060120399939478375, 0.015682984922023024, 0.06399541642167605, 0.023953868258104194, 0.05927687860094011, 0.07601198216434568, 0.04409781380672939, 0.12636584113352, 0.023024601032375358, 0.007425770090776496, 0.02046078323473921, 0.012285823413549224, 0.0794918235624209, 0.05908688508498017, 0.05155703620403074, 0.03851862587907817, 0.018166945774282794, 0.03091841768764425, 0.043462795147206634, 0.029529280509450473, 0.06531388629809953, 0.012715198517980753, 0.05659929884131998, 0.04809489873878192, 0.013470850499288645, 0.026024176404462196, 0.0548809931933647, 0.10596915904898196, 0.03216956363758072, 0.07357859867624938, 0.010090199921251042, 0.10191245368332602, 0.0350257152604172, 0.03897269780281931, 0.04075919197930489, 0.046360147098312154, 0.07845867236028425, 0.04733902504085563, 0.03261226956965402, 0.1299563070642762, 0.007161360499594593, 0.02915781889896607, 0.03751009913685266, 0.03396659631107468, 0.06223745040188078, 0.046095126162981614, 0.010929129221040057, 0.027927896517212503, 0.0470247143675806, 0.04741985605505761, 0.02309221810719464, 0.02594849775050534, 0.05636946683807764, 0.00868395994984894, 0.02044274348008912, 0.08607424300862476, 0.0403266200737562, 0.0572888579335995, 0.048856156718102284, 0.019176160858478397, 0.009868042652669828, 0.0847873960447032, 0.06535037027788348, 0.06614562604227103, 0.014664871487184428, 0.10382551743532531, 0.018319128721486777, 0.034149513448937796, 0.010227133589069126, 0.0229523752204841, 0.004971333728462923, 0.03355895314598456, 0.03839465382043272, 0.08014813443878666, 0.02985865492519224, 0.0411293010256486, 0.05630765706882812, 0.00328292109315953, 0.01057379819030757, 0.03299180760222953, 0.03922787414921913, 0.04045461457280908, 0.05768568800704088, 0.01433716783139971, 0.086981243948685, 0.022637333531747572, 0.09373253167723306, 0.03405492301681079, 0.08981286388006993, 0.012343904818408191, 0.02647196419275133, 0.060585878673009574, 0.029400412131508347, 0.01693167807388818, 0.012091277749277651, 0.058956805150955915, 0.048090965356095694, 0.03423104950343259, 0.02958364839287242, 0.048334619859815575, 0.04067011199367698, 0.04704632570792455, 0.05159154978173319, 0.027849310499732383, 0.047982671167119406, 0.05698815453797579, 0.011800454194599297, 0.041335295245517045, 0.049297274454147555, 0.03223901381716132, 0.032558248640270904, 0.0806942512281239, 0.02374796680669533, 0.01813159356970573, 0.0023536508524557576, 0.043558606412261724, 0.004230089616612531, 0.017145388774224557, 0.03226831009669695, 0.046770966655458324, 0.09406426426721737, 0.05780197141575627, 0.01764542375894962, 0.03190175964846276, 0.027633009704004508, 0.012818359828088433, 0.12176834759884514, 0.04189788400253747, 0.053740902221761644, 0.020319739924161695, 0.027710219037544448, 0.03538346754794475, 0.04909857554594055, 0.0765938259428367, 0.023545113726868294, 0.11301804057438858, 0.014332790087792091, 0.08124162224703468, 0.007169085793066188, 0.06386540699168108, 0.026017276286438573, 0.01377873973979149, 0.08451496105408296, 0.016438879029010423, 0.029906033632869367, 0.0168760114320321, 0.029540460964199156, 0.019674310788104776, 0.07165277740568854, 0.013434259835776174, 0.013607858381874394, 0.03943387207982596, 0.010005608073697658, 0.007453400248778053, 0.03118249609542545, 0.030121694326226134, 0.05536458775168285, 0.06848071949207224, 0.03273541042290162, 0.04036980935779866, 0.0407660716882674, 0.035297007343615405, 0.015961366370902397, 0.08087744296062738, 0.02953298197098775, 0.016416733342339285, 0.013376264705584617, 0.05543564839172177, 0.028891842448501848, 0.05273298404063098, 0.011220684718864504, 0.019684452236106154, 0.004041203756059986, 0.044074718171032146, 0.0367908689804608, 0.0724043429363519, 0.04102340397366788, 0.021377207594923675, 0.031197123826132156, 0.06329356736387126, 0.06699900681269355, 0.04273951657523867, 0.03158357496431563, 0.035548246596590616, 0.09219060113537125, 0.035283511388115585, 0.01475600351113826, 0.030549416296707932, 0.02330911076569464, 0.042864735441980883, 0.04856324216234498, 0.017150641324406024, 0.01851221142715076, 0.015894942298473325, 0.0184862863534363, 0.038382872226065956, 0.045720720081590116, 0.029817621580150444, 0.0340861934091663, 0.08436521049588919, 0.019161265954608098, 0.0428735410241643, 0.011410625356802484, 0.05240648730250541, 0.015139169718167977, 0.040086516746669076, 0.04203873992082663, 0.09023256323416717, 0.025914433172147255, 0.03623423966928385, 0.022394359948521014, 0.046303803246701136, 0.038864897142047994, 0.014120838277449366, 0.028679998249572236, 0.025421253776585218, 0.04141094977967441, 0.040300169930560514, 0.036223675197106786, 0.030927388397685718, 0.02517852324672276, 0.04086635810381267, 0.02286086841195356, 0.02434112277114764, 0.008569603342039045, 0.04682044935179874, 0.028611052730411757, 0.0277584326613578, 0.03784500811889302, 0.03930165104975458, 0.04409494169522077, 0.1063308298762422, 0.03169652984070126, 0.05202985477808397, 0.036266604729462415, 0.10388422873802483, 0.05270034438581206, 0.0038558604910576832, 0.018907347548520193, 0.015182263450697064, 0.03327911523228977, 0.03196939898771234, 0.05152862308023032, 0.043199852225370705, 0.036629032547352836, 0.0301471537022735, 0.042286851021344773, 0.07009420049143955, 0.04997258431103546, 0.035243669190094806, 0.03219177982828114, 0.02797447370539885, 0.04457866984012071, 0.019157223105139565, 0.07308775704586878, 0.025187339961121324, 0.034312181087443605, 0.027612852973106783, 0.03632678919530008, 0.012428021691448521, 0.015881425933912396, 0.016038443973229732, 0.07411940910969861, 0.17281744309002534, 0.2524446789175272, 0.10867620207136497, 0.1276650745421648, 0.13331372378161177, 0.11483046167995781, 0.09818159567657858, 0.0913994197617285, 0.16788312583230436, 0.09501693697529845, 0.12243003904586658, 0.10452616421389394, 0.16389575932407752, 0.09745251722051762, 0.1696232840185985, 0.15296408731956035, 0.1430597109720111, 0.13822334236465394, 0.09782821463886648, 0.12651198485400528, 0.2127315997495316, 0.24964636657387018, 0.16511991707375273, 0.06993944043642841, 0.22502428153529763, 0.1205796274007298, 0.09526111098239198, 0.08009929370018654, 0.12946803326485679, 0.06990473018959165, 0.110016327816993, 0.13003334199311212, 0.23752782231895253, 0.13741088361712173, 0.20701148168882355, 0.11805498201283626, 0.11981209827354178, 0.12487326341215521, 0.10924184476607479, 0.16100089356768876, 0.0869109551422298, 0.14471781731117517, 0.2049668796826154, 0.10635495709720999, 0.21785280463518575, 0.09949023951776326, 0.12307769648032263, 0.09159711305983365, 0.28149560443125665, 0.10001185059081763, 0.1840032116160728, 0.1105022341653239, 0.2236777584766969, 0.18603451433591545, 0.14367033523740247, 0.21835022169398144, 0.11763995818910189, 0.26929226238280535, 0.15316154313040897, 0.16587514139246196, 0.14682820328744128, 0.1673139282502234, 0.10061839304398745, 0.1235435128910467, 0.14353164267959073, 0.08877102955011651, 0.1929587818449363, 0.08674052834976465, 0.2102477353764698, 0.17507041047792882, 0.17503452021628618, 0.18085513991536573, 0.10331379176932387, 0.17706145910779014, 0.14363002177560702, 0.11546603695023805, 0.1696307648671791, 0.1064288527413737, 0.13081330951536074, 0.1293995775631629, 0.12372906465316191, 0.06785737481550314, 0.1404017535969615, 0.11570112706976943, 0.13796307117445394, 0.10538057656958699, 0.15485812240513042, 0.15284762950614095, 0.14725156885106117, 0.12501609715400264, 0.19284275447716936, 0.3040336794219911, 0.16663955349940807, 0.10241220108582638, 0.18814067007042468, 0.14423865708522499, 0.21946976630715653, 0.15325977379688993, 0.133024716633372, 0.12705997185548767, 0.14022678486071527, 0.16663398739183322, 0.21928290836513042, 0.12551249004900455, 0.1030599772639107, 0.12132014235248789, 0.08734612085390836, 0.1288040040526539, 0.09468006130191498, 0.15135067311348394, 0.16905629803659394, 0.11709109545336105, 0.13283977343235165, 0.08141175218042918, 0.11721312679583207, 0.20139842585194856, 0.17542537971166894, 0.11035119969164953, 0.11077567847678438, 0.1141921107773669, 0.1476669340627268, 0.10777609568322077, 0.10828617378138006, 0.08877006475813687, 0.07496811434975825, 0.16204015264520422, 0.08588835728005506, 0.12205490565975197, 0.18603929376695305, 0.12749487039400265, 0.2634538459824398, 0.09664206969318911, 0.12894523475551978, 0.10173664632020518, 0.1360534509876743, 0.13591622788226232, 0.07562922692159191, 0.15892875788267702, 0.21952006907667965, 0.10692443669540808, 0.1312012004200369, 0.14909359422745183, 0.14683955814689398, 0.15770062222145498, 0.15804152033524588, 0.14000053372001275, 0.2002756009460427, 0.11946777143748477, 0.1285038498463109, 0.0939641559671145, 0.25925251829903573, 0.14851896412437782, 0.1426225563045591, 0.07758224048302509, 0.16314988606609404, 0.13877351128030568, 0.17185826174682006, 0.06787125297705643, 0.17615514836506918, 0.0653298053657636, 0.14994712342740968, 0.10656564540113322, 0.19424844154855236, 0.09191577642923221, 0.13257343147415668, 0.10843264404684305, 0.059729881832026877, 0.13761285168584436, 0.12614917854079977, 0.10624835500493646, 0.22318575909594074, 0.2187908347696066, 0.09169526209007017, 0.14498929493129253, 0.10689270988223143, 0.1815220041316934], [0.0723250889859628, 0.051267327726236545, 0.017860808002296835, 0.050440604900359176, 0.02816941178025445, 0.030776303829043172, 0.011976749519817531, 0.005225532295298763, 0.09870711044641212, 0.07934624387416989, 0.0248659900171333, 0.022373822866939008, 0.04652699673897587, 0.05446625880722422, 0.03965934767620638, 0.024585645587649196, 0.026306834479328245, 0.08901508481358178, 0.0538925378350541, 0.024850343688740395, 0.0371665367129026, 0.05545139676542021, 0.0315604978823103, 0.027995804884994868, 0.032699598086765036, 0.02199568934884155, 0.05480933512444608, 0.030711299114045687, 0.09583043472957797, 0.03797329205553979, 0.07418648441671394, 0.07950783910928294, 0.05536861761356704, 0.034282012784387916, 0.02621471168822609, 0.012347677711659344, 0.01704847913060803, 0.02065221095108427, 0.024125590098265093, 0.027440303638286423, 0.016358710381609853, 0.018259816279169172, 0.018722122331382707, 0.026546160406724084, 0.06505003053462133, 0.03376662833034061, 0.017604909917281475, 0.031733258729218505, 0.08345991649548523, 0.029993441930855624, 0.022170500378706492, 0.01382677060973947, 0.06903100715135224, 0.06145051040221006, 0.09698001405922696, 0.056851165209081955, 0.0043285582341923146, 0.039251767593668774, 0.13269217510242015, 0.08862612521625124, 0.050627429445739836, 0.03836832613160368, 0.054638756191707216, 0.04242953633365687, 0.06885750786750577, 0.043895971903111786, 0.03457073420577217, 0.04424466627824586, 0.03659290108771529, 0.02406320516456617, 0.015943805301503744, 0.06556290652952157, 0.009696135275589768, 0.015950358465488534, 0.03488736037979834, 0.012302134891797323, 0.015680469041399192, 0.030151511964504607, 0.009232003540091682, 0.02012825098063331, 0.023152756948547903, 0.040894626508816145, 0.040350687922909856, 0.06217517307959497, 0.017727137928886805, 0.044582039190572686, 0.06558017630595714, 0.0556328147649765, 0.062260787235572934, 0.019646296568680555, 0.028715580519929063, 0.09104120734264143, 0.08428452420048416, 0.020413096535776276, 0.03794665266468655, 0.0578739374759607, 0.014343750681291567, 0.06314371290500276, 0.060424442999647, 0.02922337836935185, 0.011521381620696047, 0.04062115622218698, 0.013121835145284422, 0.04400158693897538, 0.045734063896816224, 0.055006909678922966, 0.04333311597292777, 0.024657700705574825, 0.045995437176316045, 0.013006093504372984, 0.05535934447834734, 0.019109265522274654, 0.08005880212294869, 0.03685762145323679, 0.038674721799907275, 0.016652981212246232, 0.012580904112837743, 0.04862183101067785, 0.06031743272615131, 0.018211713977507316, 0.018831503766705282, 0.04793617190443911, 0.09767549548996612, 0.03462117056187708, 0.009841789178608451, 0.011336792795191286, 0.027761282508436125, 0.041013596492120996, 0.08971412855316885, 0.07307695879717357, 0.07711879152338952, 0.0697736075380817, 0.06165112034068443, 0.023077853838913143, 0.06861201283754781, 0.036317890844657086, 0.03785573957429733, 0.015417654140037484, 0.054273860732791945, 0.0380849221983226, 0.031205179839162156, 0.03468617156613618, 0.02687572592549259, 0.0498824541864451, 0.03232169648981653, 0.016891683735593688, 0.02621074119815603, 0.04141234130656812, 0.059699550256482325, 0.05393500723585021, 0.033255756134167314, 0.022235677643038798, 0.0696026835066732, 0.03154877194901928, 0.05347712438378949, 0.035483189931255765, 0.01491363382228883, 0.04956848490110133, 0.03948051977204159, 0.06321299239061773, 0.03340049719554372, 0.00444321587565355, 0.03251518923207186, 0.034639928344404325, 0.08868791643180884, 0.0232873194545391, 0.08033516307477839, 0.0500218629167648, 0.024739600412431173, 0.10421572384075262, 0.003098878441960551, 0.04961570775776636, 0.0178014139237348, 0.06102899649704341, 0.0213374971281155, 0.03534796691383235, 0.05004194172215648, 0.019778610367211513, 0.02622087708004983, 0.0317061258101603, 0.02188999638747191, 0.005023026633352856, 0.07557176984846592, 0.011111348740087124, 0.04085123313416261, 0.04463701377972029, 0.014110862884990638, 0.07900340875494294, 0.032441345538245514, 0.006134594550530892, 0.008764172198425513, 0.04687884524173569, 0.04021593616926111, 0.08262459217803553, 0.04171363470959477, 0.03709574695676565, 0.009398802158102626, 0.03369706682860851, 0.09482951500103809, 0.015396971411973936, 0.04441053999471478, 0.019911124545615166, 0.030615677096648142, 0.0540190665924456, 0.03840945595584344, 0.03858141528326087, 0.04191807413008064, 0.035774720381596126, 0.04643653264793102, 0.024677417713974137, 0.1365491165779531, 0.029434836651489604, 0.0444923358008964, 0.04351303483417723, 0.014549286624969682, 0.02285661961650476, 0.051406758720986545, 0.047595511277904734, 0.045634248745045625, 0.003519080833029875, 0.06476500129792839, 0.0374014004773926, 0.03142532681522425, 0.07019396740361117, 0.04715991140983533, 0.03896217414876446, 0.021711370718549006, 0.055400043856934644, 0.05317906674463302, 0.019798191933659837, 0.07788435395923443, 0.04363348169135861, 0.05653057225572411, 0.04665875392674934, 0.0747520751610864, 0.11609996465267614, 0.06437089119572192, 0.038678670025547035, 0.029258326103445143, 0.023986802916624583, 0.026596990101097617, 0.05941326679021586, 0.01843136371462606, 0.02582201166660525, 0.05785127228591591, 0.04837884443986695, 0.021857401261513587, 0.03450171076110564, 0.03763283551961649, 0.012125939756515436, 0.01856251976278145, 0.048130169307114556, 0.041653747102827765, 0.023629620227438863, 0.01481958423028118, 0.02201442672230769, 0.025299174194515217, 0.016008693128242157, 0.05167607669136487, 0.06381366445566528, 0.08252911487943493, 0.035202034705434926, 0.02564552523836028, 0.06563427145010792, 0.01566206006827997, 0.016132494492921978, 0.01881686861452181, 0.04487733975111041, 0.0391950823541265, 0.019824504779535346, 0.056871834021876566, 0.051611910603241995, 0.04769608342030551, 0.039334279572358355, 0.06642461419687606, 0.030246061578509398, 0.013995180615893332, 0.053962303427397273, 0.06568947981577367, 0.07438048924086615, 0.044166510706418194, 0.05600696851615794, 0.042738436750369146, 0.008761886383581441, 0.042483627767069265, 0.05468263567308895, 0.10080757390824147, 0.01612783566088183, 0.024715374856896233, 0.04742423101561144, 0.05630273662973195, 0.03022536122443853, 0.04030790310935117, 0.04594408055709209, 0.04436512797838077, 0.02780924380203942, 0.017735112305672374, 0.01106487452489091, 0.05951566461590119, 0.00875468940648716, 0.019940279817092232, 0.009174689330393448, 0.0272590043823584, 0.03372857470822055, 0.03463469991402235, 0.044418198958737776, 0.050516378178144805, 0.06322037676000036, 0.09664338329457678, 0.04748643783386797, 0.03380503818334546, 0.03745273483218625, 0.03678110231703613, 0.04502596224483568, 0.021920914259681012, 0.013293370520841563, 0.04427063773619011, 0.024142195652530063, 0.0067670124462893, 0.07429488250636496, 0.03726479335455224, 0.04837434331420809, 0.03630541163147427, 0.05273248680168763, 0.0346049880317878, 0.02807376193231903, 0.02362993749557063, 0.014327128428703872, 0.02468522325216327, 0.016703315523045603, 0.04757526548928581, 0.0485407513770042, 0.040175144022214226, 0.007476559894712409, 0.06282161339186132, 0.05655410946928896, 0.010251511284877779, 0.04077942292497028, 0.0023952496212586993, 0.0401285185944289, 0.027805416175397113, 0.030396118272619788, 0.05356688714527991, 0.08459181044599973, 0.010766619288915535, 0.017079647477658, 0.028487023155321367, 0.051566376132541336, 0.04569252960209269, 0.011594349580263952, 0.005242625811661128, 0.03616556874476373, 0.1021573030448053, 0.07602917030453682, 0.1448527694446966, 0.14387295639608055, 0.15148963284445927, 0.08705707659828477, 0.07903992242063396, 0.08286167867481709, 0.15181050781393424, 0.19269303360488266, 0.0950386373733636, 0.16861057898495346, 0.07605417325976305, 0.09533560776617378, 0.10320032481104136, 0.19264173635747284, 0.10309552613762207, 0.18009731807978824, 0.12802874174667522, 0.17448408412747085, 0.1055064819229301, 0.15702905278885737, 0.21924231288721785, 0.09723474882775918, 0.12023089962895028, 0.12836376205086708, 0.13939520838903263, 0.09965275501599535, 0.1975562679581344, 0.09077940732822753, 0.18352558021433651, 0.11682250478770584, 0.30505211383569986, 0.1524567700107582, 0.2177687786752358, 0.12986150512006134, 0.1334437183686532, 0.07494978330214508, 0.164264636405278, 0.1629297056933865, 0.17081952217267826, 0.12818955030525103, 0.09707143923151307, 0.10701736100600101, 0.23510972707299516, 0.10364101210143417, 0.14563787262886763, 0.1048896013526246, 0.21875206497497857, 0.10315057865227573, 0.12080073545803316, 0.14140037266770378, 0.1190265201148577, 0.09199224732583389, 0.11978307287790813, 0.1525002153357491, 0.19183221651474014, 0.1156448945403099, 0.21924581582425162, 0.20155357924522832, 0.14310447731986642, 0.15491290774662048, 0.1966516938409768, 0.10996108234394342, 0.18561637349193916, 0.1289233859279193, 0.1337697883718647, 0.17983906553126872, 0.10539582028286532, 0.17264712019823492, 0.07898609444964677, 0.19948561443015933, 0.1684393803589046, 0.08320824679685757, 0.1266709974152036, 0.16549961466807872, 0.11420546943554655, 0.12935366830788553, 0.11823560591437854, 0.10725068481406197, 0.09253649390302598, 0.13730129809118807, 0.16806069208541885, 0.18614225933561102, 0.33174078329466283, 0.1982538719312288, 0.190768540778663, 0.2739119535544887, 0.15965671569574624, 0.11374651789083146, 0.1289577325223945, 0.1852940587559715, 0.18171690695453435, 0.07714349761954509, 0.19033094082260504, 0.12936419196194038, 0.10132343333680183, 0.14461692975601181, 0.24661843373905867, 0.0919819314731285, 0.11296715150820091, 0.12874616106273606, 0.14469400921370834, 0.16212024522246793, 0.1903937413590029, 0.15687156905187294, 0.1447749329963699, 0.10891075784456916, 0.08654807461425662, 0.16907305573113263, 0.30249505885876715, 0.21968723041936755, 0.15024062799056992, 0.16993234399706125, 0.18786475440720096, 0.16847730410518125, 0.14115715603111312, 0.15702644042903557, 0.12038580811349675, 0.09081379845156334, 0.11026565232896246, 0.10656375292455778, 0.15994515881175175, 0.1315063121728599, 0.12309930782066658, 0.07785166977555491, 0.12378468862152658, 0.10439835154102184, 0.14284868870163336, 0.233303755230736, 0.14542670192895457, 0.13794377533486113, 0.2231727121397853, 0.09929445353918709, 0.1957085428875871, 0.17288585426285863, 0.12256506539415568, 0.06570362515049055, 0.20810858375625685, 0.13487097225151956, 0.1740239080390893, 0.16516689502168447, 0.13314656243892387, 0.12835558358347043, 0.1509009613073431, 0.15059699246194214, 0.14150437724310905, 0.13310783717315644, 0.16839154151966795, 0.13343087921384722, 0.11362402641680092, 0.11942479366553016, 0.1209987181937322, 0.10100589803187177, 0.11276340228505433, 0.12126889705541544, 0.13540197891416028, 0.16471900889882818, 0.14304949901998043, 0.11967708676820621, 0.12334745231783018, 0.12954250036273152, 0.06611799588426948, 0.145693474332802, 0.1303881182684563, 0.08392311312491074, 0.21102028142195195, 0.19320630293805152, 0.13607282104203478, 0.2105743990978226, 0.06911108488566242, 0.1704126174445264, 0.12777578813256696, 0.19600722764153033, 0.09981285111280158, 0.06820893016993068], [0.06276074986089952, 0.011175387735420372, 0.019265315058873966, 0.0447742071992252, 0.08473887442960404, 0.052949594683013856, 0.018247094012622256, 0.1029780441604089, 0.05078321737528313, 0.05552363370952662, 0.029117626036168076, 0.023144610022427514, 0.007244550151881413, 0.02424363610771252, 0.008755290546105243, 0.057263075723312795, 0.085390094172908, 0.017994535592151806, 0.02490674320142716, 0.04847536074521486, 0.012234682944836095, 0.05523673797142692, 0.04911190080747474, 0.025901269327732734, 0.056634699285496026, 0.04623858701961581, 0.01759569986461429, 0.03410807934415061, 0.028559983693412505, 0.01825964372983435, 0.046418342608376406, 0.10857360757654533, 0.028221449319971725, 0.06471069835242815, 0.05279284938296769, 0.0178950098779751, 0.08868722623446956, 0.048122732987394556, 0.01737641006911872, 0.020088883757125586, 0.033855849324027076, 0.023349491020780988, 0.04828905570320785, 0.003939383414035547, 0.05004839098546654, 0.06593787664314732, 0.017935855830728542, 0.02580760101409396, 0.031057752203196287, 0.05338219998520799, 0.06732863170327619, 0.022143974165373947, 0.025111056456808, 0.03597526723751798, 0.013723899664910277, 0.040578341722721234, 0.01813814858905971, 0.07622255172464065, 0.04422689184139017, 0.007262293047460844, 0.03878627401718404, 0.03117734559054952, 0.05405653762863949, 0.04860416418523528, 0.022112219521659426, 0.06446532206609845, 0.10666007627150975, 0.11978991547948681, 0.051186767595936544, 0.024041981596383266, 0.018539240445534233, 0.09803453911445104, 0.022187556787685025, 0.021249999772408046, 0.017659442928561475, 0.10787011837237515, 0.01681240195466671, 0.015283116681530373, 0.013081815759505844, 0.005671351073033293, 0.053957052732585, 0.04950174356054049, 0.05935856308497023, 0.018785121392284054, 0.05545514461118728, 0.029785182305204216, 0.03206759996828623, 0.02565820668678498, 0.03598939401854295, 0.08684373140567914, 0.025267725686717313, 0.03262177277065348, 0.057458702140138485, 0.03554081769834738, 0.02887484912207583, 0.03114976738288533, 0.07792319054715335, 0.056465534144081175, 0.04934076430799905, 0.07132281854865141, 0.027431329217506573, 0.043307333762641065, 0.02822222300892463, 0.07638156428583898, 0.08905287497327663, 0.09415978609467857, 0.0740751251578331, 0.05949945239990484, 0.07178776664659381, 0.018448136252118275, 0.03060493450902868, 0.035723619803320616, 0.04046472633490339, 0.02037546222709352, 0.05586408282397315, 0.04577775041980203, 0.1525121639133431, 0.03146973322145641, 0.0320525566348806, 0.034167150588473305, 0.045406880672089756, 0.05601718417892698, 0.0392037135316059, 0.03777363206609152, 0.05434444268757943, 0.013413026063062716, 0.02222131151938811, 0.055356598531943746, 0.0574748549843207, 0.054740638224757276, 0.039110284560592845, 0.07060367002850398, 0.008263465570053086, 0.05617890928988345, 0.009679781123850262, 0.06074289485695772, 0.06431023546610959, 0.06336618651403114, 0.038769338207202964, 0.016936002939473838, 0.06910417549079284, 0.045693345964537, 0.0071343801846524, 0.04828672535950318, 0.025979296879086178, 0.10135038071894087, 0.0061063757766532945, 0.0034115447942895116, 0.07226930174510926, 0.03130085009615868, 0.023602242399647366, 0.0755003752419725, 0.02908158548962092, 0.06120960555563215, 0.001892476575449109, 0.01806266103812959, 0.07843735787901096, 0.022752711520297453, 0.03371252947545145, 0.03365750293596648, 0.04797382476681378, 0.06364513756125234, 0.03640349015768152, 0.021850361990800593, 0.04918097620247863, 0.0060551675869646715, 0.08004430797882378, 0.05250494803476613, 0.042607829891494475, 0.07555680815130472, 0.06584658505744301, 0.029480794146365952, 0.025956423887691926, 0.0266828658641316, 0.016077362197393086, 0.04809669102542102, 0.08081288353423588, 0.008598359709139913, 0.006544301813846687, 0.026717631772044115, 0.06001176436257083, 0.07902339479187503, 0.028472217309172265, 0.05987850803649053, 0.0321810557943536, 0.03966462805692572, 0.03270676352258306, 0.03410124045331031, 0.031981778010958806, 0.0032701703003112925, 0.024930686740844976, 0.04130563902435824, 0.017720237810863182, 0.026801119674928486, 0.0979341784841381, 0.01051023324180278, 0.05158720821782481, 0.03361127084644977, 0.03227130095183384, 0.07605012855492532, 0.026170982491748873, 0.05177940220164601, 0.031740349950268865, 0.03547786131093744, 0.02376307878876105, 0.007655026465727133, 0.04898223647614941, 0.07173355275881477, 0.063330630218843, 0.04635549383237958, 0.03126646268356126, 0.024518512764188927, 0.07447171403327957, 0.03430101918638684, 0.06247300436371006, 0.034829669530154206, 0.056755068217171356, 0.03465735397185199, 0.04734557820484042, 0.01953186852915678, 0.01532726611912949, 0.030089817228144966, 0.019673874776344746, 0.0436234367225552, 0.04042486187245231, 0.016326452932844404, 0.01651912560191704, 0.04709546330559533, 0.019012689845112618, 0.032119958486873657, 0.040502902411390096, 0.012841220759582939, 0.08663559608976357, 0.04917781465337612, 0.01851054901635507, 0.06976170348934829, 0.04749319137772545, 0.03664250623842236, 0.011594615825742949, 0.048286588062183, 0.025860944733722135, 0.06305585004156455, 0.061929837611387484, 0.02893552340538008, 0.0261882615450304, 0.05482627093442716, 0.020711610595753882, 0.1031665645132307, 0.024876821662473958, 0.07287614105734974, 0.06454772272263654, 0.0915506471937988, 0.034160333962063305, 0.018019067283603363, 0.025218723530997522, 0.04205199467833154, 0.0447272218298167, 0.01049860749844811, 0.014555192265106598, 0.044522455864353105, 0.01592457811057102, 0.01392549665979459, 0.045389666556729935, 0.02931478313257685, 0.029610117089760024, 0.1258677858277224, 0.03735065613000188, 0.019521784597600345, 0.05739904459915124, 0.06762612902093679, 0.03426437564485241, 0.03196647492586635, 0.10953975026495755, 0.028909273642057087, 0.0386199179047253, 0.048810956213856116, 0.03251766429457348, 0.047060352299013175, 0.05851211397384759, 0.05517024525033776, 0.06535163192893378, 0.009642349050409393, 0.054219498415477574, 0.0762739306082949, 0.05136990366736427, 0.010592159851512406, 0.04038018458231818, 0.03688793818582781, 0.02833179369190475, 0.008154273382388055, 0.05963925817923155, 0.02961500227684155, 0.07735928447800688, 0.026025365696114022, 0.06760738237062469, 0.004936404548061546, 0.07090549406711943, 0.032059020741144195, 0.05006114108255133, 0.010532460564718349, 0.06393183663021773, 0.05436050647404045, 0.01380380206683185, 0.05681120426743291, 0.047282269297284074, 0.034396425980958156, 0.026631934124452528, 0.04353320269729011, 0.012813832727260888, 0.05179992629564367, 0.02069278973067412, 0.07381693940260448, 0.03376610511622857, 0.041259544232161716, 0.02886205264076125, 0.024319442782143597, 0.034723746503004804, 0.053925422398606315, 0.01121605557273142, 0.06478640483692288, 0.07561442849691957, 0.023753430868964642, 0.04160466145549435, 0.013890626851207344, 0.10119383950950578, 0.04965682644979097, 0.037985351955285296, 0.07209983974462375, 0.05445665170555003, 0.026453955979377497, 0.016271717686322518, 0.0443975227244664, 0.06574571976670995, 0.0952580533339642, 0.0416953259264119, 0.018817653435689863, 0.03867296290991362, 0.058811967610381544, 0.01824496404879028, 0.07759677173453383, 0.05629169347230345, 0.03959299596317578, 0.0427643414150225, 0.07020587145234458, 0.028965123965463135, 0.07990044265170582, 0.030492463884002063, 0.0462152167892782, 0.0031898947372610564, 0.01328169653788791, 0.041901617005351, 0.02924059434008086, 0.2032737439731136, 0.12738602701574564, 0.13708197860978544, 0.11068569307099096, 0.1872757711680606, 0.22450801392551512, 0.29304778610821813, 0.2654858463210985, 0.1521853220765479, 0.16141186526510864, 0.22325571393594146, 0.07773754230584018, 0.1417082006810233, 0.09143176997895353, 0.10587525510345586, 0.125745925179217, 0.1411019402439706, 0.15225196693791077, 0.2173969181603752, 0.21776845213025808, 0.11705672659445554, 0.1597707244218327, 0.15768586832564324, 0.18477042904123664, 0.14223598642274737, 0.1312281403806992, 0.08311406083521433, 0.09948799823177978, 0.12427443187334575, 0.11774975893786177, 0.12035463048960082, 0.19455518602626398, 0.12472398782847449, 0.14795980037888512, 0.07776187732815742, 0.10130694281542674, 0.18598199996631593, 0.16388861986342818, 0.13889724214095622, 0.15537626022705808, 0.09460582426982, 0.07549497240688652, 0.18573783338069916, 0.07311073393793777, 0.1762646745191887, 0.19410893262829632, 0.09587826614733785, 0.11535573154105805, 0.18131308956071734, 0.16913796396693215, 0.14550041203619912, 0.08794161272817291, 0.10218215014901944, 0.16416158177889884, 0.1388880395097658, 0.1332914296654053, 0.1816181419417262, 0.1629285331000574, 0.1369155297288671, 0.08857440494466573, 0.11121916366391815, 0.12365212620352395, 0.14862866839393973, 0.13085255428450182, 0.2572767133824527, 0.16904385964153334, 0.17819949804106727, 0.12651959928916767, 0.1421590257086791, 0.13443782518152148, 0.16926175419939682, 0.26062454155180603, 0.15135166759137064, 0.14797776035265997, 0.17542730929562822, 0.309229128761217, 0.0938076370221097, 0.12960019492311403, 0.12821056792745367, 0.08309774842928164, 0.12052870122715831, 0.11914697810425423, 0.14568447950296104, 0.12526694306870922, 0.14970828546211123, 0.18660835776245221, 0.1655701335403137, 0.14247642742702737, 0.08545849050278775, 0.18734213401330635, 0.15686897153500468, 0.11771420264267363, 0.11789072988904081, 0.2031914101098664, 0.13023094623349607, 0.13981774274725467, 0.20385376206832007, 0.12259521143278107, 0.15190312784397975, 0.1537379395449534, 0.1302046445198357, 0.21066234359750524, 0.19410660228459165, 0.1796115527395159, 0.1872273237677291, 0.3005951311206445, 0.18455600773449987, 0.14254400739446282, 0.1321264507714659, 0.11735032763681374, 0.11819311053841375, 0.14886155433487147, 0.16547861188882962, 0.07625141384778544, 0.10698153753764927, 0.09062896657269448, 0.22710596123943105, 0.1496577452053316, 0.126435024139937, 0.1258420481462963, 0.17867518501589075, 0.17449435545131564, 0.09464801536523737, 0.11573936993954703, 0.1752317088539712, 0.13650063949171454, 0.1512058504158631, 0.16382475063437596, 0.1468992416630499, 0.20537951379083097, 0.14353968756040558, 0.19283994915895164, 0.143958110420499, 0.1892079081153497, 0.1841835238155909, 0.14491249748971313, 0.11064667094615288, 0.21519434259971604, 0.14624647825257853, 0.06702830680296756, 0.16831477376399562, 0.18314319604542106, 0.07690521626500413, 0.17870911600766703, 0.19415378803387284, 0.1773690793197602, 0.11586950553464703, 0.08989004723844118, 0.23722649551928043, 0.10794356872793287, 0.1797501859255135, 0.19112071953713894, 0.09306729276431724, 0.1285083027323708, 0.10837778449058533, 0.1471869129454717, 0.190919745946303, 0.15955844050040469, 0.10354479265515693, 0.10313866718206555, 0.10607989490381442, 0.1332163836923428, 0.15478509507374838, 0.19307957380078733, 0.11260157698416151, 0.09568791268975474, 0.17902766063343734, 0.17444117314880714, 0.1329939768766053, 0.29486144660040736, 0.16579337156144902, 0.06857929896796122, 0.0678080294164829, 0.10796908376505598, 0.09392151958309114, 0.12629527773242444], [0.052092458645347506, 0.06819711517891847, 0.028292116621742025, 0.012270289334992412, 0.033853700806503184, 0.047666330719948746, 0.02146933966287179, 0.04159161078860052, 0.02680142395547591, 0.011924215668841498, 0.056185202702181414, 0.013969133087812224, 0.03693821498018224, 0.04024310619570315, 0.04685977204644587, 0.02761487903626403, 0.06387437955709174, 0.018055241416732315, 0.04085694396053441, 0.011511269858601736, 0.06408554283552803, 0.03188461603713222, 0.008706344051461201, 0.035062488677795045, 0.03778451195103116, 0.03983662820246536, 0.05746953378547914, 0.05046509577368852, 0.06166603008750826, 0.03689715565997176, 0.036582039756467566, 0.035923250106861815, 0.0629624210705515, 0.008183020472642966, 0.029545759898610413, 0.05059854134742636, 0.0373177418805426, 0.01866586197138531, 0.04002022440545261, 0.04483673314098269, 0.034857544596889056, 0.02841249297489412, 0.025822881834756117, 0.03741453278053086, 0.06477687566075474, 0.01667570206336677, 0.022126893636595923, 0.03999556654889602, 0.022058395261410624, 0.030078857562330086, 0.04077179364685435, 0.014809200656600296, 0.04270065030141268, 0.09875409581582062, 0.08654011879116297, 0.05499872379004955, 0.0736757086997386, 0.026473533835087437, 0.03255995186918881, 0.09663624383392744, 0.061819970069336705, 0.023438769530912396, 0.06139765464467928, 0.038452493099612184, 0.08609178737970069, 0.008666977755638072, 0.03776980629481841, 0.036105885228607804, 0.03906071280653123, 0.07660457224119455, 0.029902339592808858, 0.02279279120557476, 0.0713529868517071, 0.0188503784374916, 0.04981606536603067, 0.01516153804914211, 0.04179102958005387, 0.03392791928490624, 0.022715105042152572, 0.04230114478559699, 0.031354696620837785, 0.047014576630317606, 0.02375772975938162, 0.0557185105571989, 0.02431206954497611, 0.03342700671055354, 0.007331437091124826, 0.034622369130374864, 0.07002938131336123, 0.007544066111222492, 0.07565098669147119, 0.039461728592868894, 0.05029208630730864, 0.02169776344089769, 0.034563156877993606, 0.03585395206755493, 0.06861650283099152, 0.029592218343168497, 0.09072526765521616, 0.030940400101826526, 0.024701789843675215, 0.055868784329504706, 0.026648077691788785, 0.05459587860968895, 0.0174871403578436, 0.06763631128706038, 0.03829768109426368, 0.031120725288928952, 0.039779308426659554, 0.03856016388454009, 0.09363080549519509, 0.028068177271052264, 0.05981487629469484, 0.06639454237301834, 0.05391912898630835, 0.055482841562479734, 0.08613479483756237, 0.02724219473748235, 0.010334414746466791, 0.05042196957219858, 0.07630061081727035, 0.0065215150971198454, 0.005189009816604084, 0.029259188850119244, 0.053798856533830985, 0.02120392910001101, 0.024667549005243927, 0.03856176321278326, 0.004258565359123168, 0.12023247298202477, 0.059753278037533164, 0.029564929573098198, 0.022995911458565388, 0.016981936314550694, 0.055919231817824766, 0.009745072493387852, 0.05559332137636375, 0.016147491442097817, 0.021468013073899783, 0.04333568380388897, 0.07502094784285873, 0.03288090476416983, 0.053125643244129606, 0.04542569411569275, 0.005064957977083395, 0.03821921753115021, 0.06168309577333275, 0.030340570374391973, 0.059994809998897836, 0.035038101705140434, 0.04804128599062096, 0.038925007393117994, 0.050508897329564206, 0.023595986094733234, 0.04463154786208179, 0.023783606593497097, 0.05416235304437578, 0.0041531674014549935, 0.05124552713823505, 0.03153822974127252, 0.03240073150664102, 0.031610778387403116, 0.11338124022586271, 0.07913600085885264, 0.08395843193284236, 0.052821915596723557, 0.03648073659860529, 0.04767936283315066, 0.013922349953645607, 0.010290538975823438, 0.06757263501640409, 0.010048118292615982, 0.06157251576951239, 0.07130409416276962, 0.010798796956805745, 0.014477058030024637, 0.054283085628412664, 0.035041348601225764, 0.0344748747011181, 0.03175724494212773, 0.02557488205638947, 0.0275706655884278, 0.07980305803357624, 0.023762203054502606, 0.012928376727359137, 0.029442729392030742, 0.019268793876108248, 0.028777291954611428, 0.01325240953519824, 0.04088255918759387, 0.010041803543572314, 0.03326373793242965, 0.0422388860170031, 0.049342764395987615, 0.04432515961525496, 0.08034768310608342, 0.039932509971549734, 0.01111957823013654, 0.06363952692481689, 0.060540789490914904, 0.020439405670913402, 0.03800087397394236, 0.05427356758445967, 0.02671096914127702, 0.040943489511846565, 0.08153753879014403, 0.008473716934531694, 0.033469446425442584, 0.09223445464158431, 0.023109623325581197, 0.03130551820504479, 0.043509468814590946, 0.0728840968804434, 0.03272836001997348, 0.021756960850325413, 0.044848963734693825, 0.0666909190476872, 0.037431850796565413, 0.024882341385819018, 0.03942946743336506, 0.08473592068185098, 0.006857521530037047, 0.03216295852325857, 0.03140120330499485, 0.04302472763811238, 0.07265417210874148, 0.026495221245568246, 0.0394721297925571, 0.0189102233707672, 0.028217797953402624, 0.11186340721906163, 0.058240625221515074, 0.007845103009458398, 0.0017387944899383, 0.017756393390300218, 0.07226654095575213, 0.04434929425769951, 0.01464196880988311, 0.034318378020543605, 0.06199427829415072, 0.02778767142444849, 0.004240724592818879, 0.0347405227512354, 0.0580748516949825, 0.016889351536519825, 0.03557760966941714, 0.021069566973892506, 0.03436466206039768, 0.070613139832858, 0.05483320259372704, 0.03810547226748895, 0.05086119854240678, 0.04175161782768555, 0.039402490365318954, 0.039906416059238836, 0.04431599780218676, 0.025505333542241715, 0.05491305397299584, 0.04089871574251447, 0.07773568693664856, 0.047470518766203895, 0.031168940768111497, 0.01793399304006016, 0.02369486614043126, 0.022769491479266435, 0.048721798302722163, 0.028347464140097145, 0.012368154493742622, 0.005418691071099602, 0.04851962243265007, 0.009020702036650619, 0.025206735990650486, 0.06558332301210612, 0.03897267182765063, 0.026393890257168096, 0.07463793284841813, 0.043192041121074, 0.028341131765046157, 0.0444774186325958, 0.004458945695660077, 0.01979181688511744, 0.011349215419613756, 0.013359398471948225, 0.025980053869716357, 0.01758383663400309, 0.06719275188515894, 0.056282631849171594, 0.01677056152402656, 0.043105488148285076, 0.02177934587962227, 0.01831145305914106, 0.01742677592119435, 0.025493262510281056, 0.08046966249821708, 0.04946787565131672, 0.03580944918212481, 0.0748062296770513, 0.02750822684902232, 0.010407398476672824, 0.019169240331393667, 0.038120352328405716, 0.02597705188236432, 0.020435631849977653, 0.034915806900244206, 0.06221735675353557, 0.07367797225015238, 0.02784998399874894, 0.04506295459577814, 0.02747828304563882, 0.03288092331786174, 0.04726087689050473, 0.006188962897795136, 0.04207662284898106, 0.039745158501318656, 0.02395445084403036, 0.0446142817963846, 0.03654234227724373, 0.01354897267447086, 0.025768508385226596, 0.03909128929080907, 0.07294096023542807, 0.06313643243629485, 0.046307610464282334, 0.028068889732821845, 0.04326537273300346, 0.058204018787364475, 0.05154318030690774, 0.03736813370778691, 0.06289234748692252, 0.0779152347240597, 0.05322578494087793, 0.02362633436860051, 0.027968490139755886, 0.0554668260156177, 0.04795831388037186, 0.07779590479913168, 0.007904607482487336, 0.010126090182893677, 0.034778613480739295, 0.0445728959311964, 0.02213578271039296, 0.02747160557191819, 0.06471246466389857, 0.030629061729996465, 0.021904343957430683, 0.03439332380366977, 0.02858104584447574, 0.05708536475140136, 0.06242006696993485, 0.0464972885674797, 0.03720060871273745, 0.03593777022615541, 0.13470780366333202, 0.13382878911215812, 0.1099308991979342, 0.11440487709478475, 0.1342407998163253, 0.17353461007587612, 0.19986869621789083, 0.16763894440373406, 0.1788528700126335, 0.08244093289249577, 0.14139281760435551, 0.12446859996998683, 0.09912951121805236, 0.1836774087860249, 0.14030061371158808, 0.17996916401898488, 0.10855521715711802, 0.12147789326263592, 0.09599136945325881, 0.15150477265706286, 0.18188653222750872, 0.11827284688479267, 0.12932796031236649, 0.16186289809411392, 0.10522989090532064, 0.16358612047042698, 0.16184545762371272, 0.14869417034788057, 0.09967021775082685, 0.16207887791097164, 0.09373695487738587, 0.1885368285002187, 0.17637970740906894, 0.15080439305165783, 0.1330663511180319, 0.17093115602619946, 0.18738298182142898, 0.18206043227110058, 0.10301915914169513, 0.12953892321093008, 0.13948940177215263, 0.14990599360316992, 0.11183558410266414, 0.1466195855755359, 0.2657214633654803, 0.08234682856709696, 0.11898652577656321, 0.22106660093413666, 0.08030319135286845, 0.13524738955311477, 0.09066867889487185, 0.0927255189162679, 0.12622127076610923, 0.20051611616509035, 0.14419389073736966, 0.12143271873355843, 0.20111841353354976, 0.09992059611249715, 0.09830792405409738, 0.2201734558911994, 0.1544088262016885, 0.09035389695782214, 0.16161453095264733, 0.1638161565642804, 0.2135376908699982, 0.12845238932641223, 0.12794545793440193, 0.13435566943371668, 0.1404458371689543, 0.1421770450542681, 0.10327886629966088, 0.09593189373845235, 0.16975053265923634, 0.1264519599499181, 0.07537731231423095, 0.1953215870889835, 0.2150627301307395, 0.23486225050874054, 0.09274038413423114, 0.23592840501805767, 0.11542984240804799, 0.10332926554838195, 0.186628321534954, 0.21391246060375124, 0.15485402574995533, 0.061775890208082274, 0.09304174804128706, 0.11311699112411588, 0.11245627931202762, 0.12297417430090718, 0.19147825660184026, 0.09329125809017569, 0.15704901656135917, 0.1494477767846547, 0.10428197536384687, 0.27728985354769975, 0.12245211051777005, 0.13308094174135476, 0.12949213822139427, 0.25788186059799045, 0.19437147479038686, 0.17314986587734893, 0.11784349961089902, 0.11385386213078164, 0.09186530296574347, 0.11005310123437084, 0.07787171518430114, 0.10033487036707811, 0.17062325379811227, 0.14399695442989469, 0.1395622658310458, 0.1264822544180788, 0.1490598265081644, 0.17407588806236163, 0.08855654145008884, 0.1541313371853903, 0.10827822537976317, 0.1586272826534696, 0.0828053496661596, 0.08739342534681782, 0.1856496959226206, 0.14939552958821878, 0.08003511276911013, 0.08778441100730561, 0.07560009020380676, 0.08444136969046667, 0.1598650513915345, 0.1116451490088366, 0.130189222691115, 0.292635359801352, 0.13849958457285538, 0.134520084830001, 0.11065653408877552, 0.08480784963467158, 0.13274433324113488, 0.05594409376499243, 0.3222693462157622, 0.0905488220450934, 0.14670586766442284, 0.08774006768362597, 0.15488142584217712, 0.07024048521998338, 0.14686924405395985, 0.12318869950831868, 0.13080901990178972, 0.1107266744656954, 0.0962881617306266, 0.1427052909275517, 0.20445984438993037, 0.15455599408596754, 0.17924031562870368, 0.14656745712272823, 0.23458219366148114, 0.25766043341718614, 0.11721084840246476, 0.09541135877952911, 0.14761628990527242, 0.14798828400671482, 0.13951837521744892, 0.18500916310586035, 0.1578486361540854, 0.18006010679528117, 0.18678061023820192, 0.1409307713038288, 0.19009195442777127, 0.16188363370019943, 0.14981479849666357, 0.1563588489079848, 0.08520800824044272, 0.1092202185827773, 0.14903744333423674, 0.1106086878280621, 0.24388072517467663, 0.11221979395486414, 0.08511092790286057, 0.06360590021358803], [0.035232021182309836, 0.08633238423499279, 0.00620406050074962, 0.0557636591111077, 0.019007771261385642, 0.054324675584211946, 0.13814041478326544, 0.06521802308270708, 0.04652606905438006, 0.0420230101008201, 0.08810593906673603, 0.032909625879256055, 0.03816655844275374, 0.025273709252360277, 0.005194493824092206, 0.038994093920337036, 0.0727712904335931, 0.0634073163382709, 0.02630764527566498, 0.06326619695755653, 0.07769678355543874, 0.04516579028859269, 0.03233039446058683, 0.031239066302077845, 0.017441978816350456, 0.04212011270283256, 0.07840232850867324, 0.11160047171870247, 0.0365814794349717, 0.03567369552911259, 0.049402243821532466, 0.031647544383304194, 0.009926143538905308, 0.04593179059156682, 0.048668760719010606, 0.03327535254356917, 0.005072484282209189, 0.005189475978113478, 0.0058485879981162725, 0.03745485366380308, 0.09963989359675907, 0.060535189986694604, 0.024255282260128297, 0.0066159232392237755, 0.008514933033438865, 0.00637862151961599, 0.02262499347125413, 0.031784979000804015, 0.0258343721361598, 0.04247371638484765, 0.01178797312604729, 0.0425418492523022, 0.029939038795419037, 0.04703441423771437, 0.049586496825213544, 0.042823319890885614, 0.005988941111354507, 0.025139386088994797, 0.03097726628766395, 0.03318285867862869, 0.025205559686583, 0.09136930340901017, 0.03862994803057518, 0.03233514791645575, 0.028086033344152384, 0.020855867405771278, 0.013795788727293257, 0.040248564691864885, 0.00940190433539101, 0.04601309286954347, 0.026981289011018816, 0.034403368772473186, 0.022374182808562182, 0.03266518840973731, 0.04189421779301483, 0.022861298857606016, 0.041203931396012194, 0.04096248478163034, 0.03662688774056733, 0.0819116405909881, 0.020780402119271457, 0.08701922706677578, 0.0596260999009246, 0.03141660286928527, 0.04106597356440034, 0.06963398729567416, 0.02186385423556203, 0.029931229546491522, 0.023606120121257845, 0.033411863187211566, 0.02211046619777335, 0.0599243282340467, 0.061119857637095265, 0.013531857821362792, 0.014684551388199907, 0.029884965915698558, 0.05012268367863726, 0.03312961329356767, 0.014941809458832722, 0.043903612313442864, 0.024930137551564258, 0.05000641140213702, 0.049574425793252885, 0.08462989746476524, 0.04792954452568665, 0.06772880515200086, 0.02546821502619423, 0.02781588973448379, 0.0847255380358547, 0.02196882174757775, 0.03126413233985659, 0.026042618774226867, 0.02370680358581012, 0.09240732309990562, 0.018046981313091237, 0.06885622395202518, 0.086478275625268, 0.016936123538471293, 0.04112862196052447, 0.013395635687629692, 0.04512996310950257, 0.07964802338392474, 0.04700093966675922, 0.08883376329322346, 0.07156633204431273, 0.061010079152765684, 0.015610172813467216, 0.03049009457754437, 0.04059937047713902, 0.04767046448250767, 0.02296271519298898, 0.039079003036022186, 0.045302289800019935, 0.05350937070033979, 0.05826838154462166, 0.019155373302055523, 0.018017865004367195, 0.053327466594055295, 0.005392213561208337, 0.03432484583754558, 0.048525266465730965, 0.02484628599631833, 0.06941356943571009, 0.03606695216149092, 0.03963092342019081, 0.006533178875542944, 0.05966808690573089, 0.041644418306532316, 0.048969274866976775, 0.04445757360372227, 0.06043305933417287, 0.019247112031735014, 0.03235674441384617, 0.08507918624673039, 0.03907452046405524, 0.017545452756166924, 0.03765914465475362, 0.04039408500830177, 0.0374279359675711, 0.04461052652914077, 0.010123051088157808, 0.06284332863288, 0.03192237651092, 0.023387383225781377, 0.04833397048059851, 0.07466430877684616, 0.025823095202213153, 0.01978792432055343, 0.02829100896633463, 0.04221689247060567, 0.05491897631145548, 0.07117145010852255, 0.015631674687028863, 0.07967559417011216, 0.006146110363260959, 0.02294962185260374, 0.03241036829422228, 0.043870998633792624, 0.028255268989596516, 0.03498593614494894, 0.04024368136015255, 0.023390374080918264, 0.0834352697711438, 0.03362882634974085, 0.04695664829341695, 0.013010842321818927, 0.08344198620761745, 0.02442135079036234, 0.026113556959899142, 0.0400267775694374, 0.0322138104820624, 0.07712867693044245, 0.023659365506318863, 0.04771474101289641, 0.019901439518434927, 0.02518607274396345, 0.05649637780152261, 0.05423342852736823, 0.0883696018718183, 0.04586051472870167, 0.029964141940581612, 0.023184880810731556, 0.01487357269070344, 0.06287305906880647, 0.012962577675352804, 0.036486985482042655, 0.1103224117832724, 0.04079201717104297, 0.04471073130844161, 0.019641079270513728, 0.015073444192239549, 0.012497801199060632, 0.05224717788223643, 0.038042419400881045, 0.01915437325806124, 0.027389672468416393, 0.09861213780823164, 0.06009156750224065, 0.014765652358619263, 0.010574902134976583, 0.07454823688021861, 0.032067373613244854, 0.02562340367148863, 0.028171129852125887, 0.04903476197796408, 0.01368317431115429, 0.015423751810885733, 0.018258064810652286, 0.03318498493172228, 0.04332602475187741, 0.06401821519830264, 0.03488699672743678, 0.09210161762894131, 0.0238681502014515, 0.03195405508449767, 0.07072068445268087, 0.040008068026509136, 0.0626412418205291, 0.030945253747631796, 0.09598103875759989, 0.011895497336809058, 0.016036597880884074, 0.023157643990998622, 0.08010001358343288, 0.03328942366351839, 0.019336013901920523, 0.033208800450665876, 0.10151998372748494, 0.02085011947201565, 0.03622865871875547, 0.08335143676958978, 0.012267282709217397, 0.06595696468139067, 0.018707581803028006, 0.06463596408138983, 0.021607919043162838, 0.023388949157379102, 0.02387107797403587, 0.035741624305956066, 0.022795654040237423, 0.07840364953153767, 0.05547708991798572, 0.04307241062633693, 0.06545506505062804, 0.03435414582781959, 0.02068187644908903, 0.01712863664579345, 0.05468735202157404, 0.05045882091508247, 0.033834490313893184, 0.019670841247716453, 0.054661707108607516, 0.0607411508099176, 0.028753014448739123, 0.01731775813823333, 0.02598715993372025, 0.03333449058118276, 0.06989924571826123, 0.013528320559998974, 0.02733474797423696, 0.039058872280293144, 0.03992318859673105, 0.03938114248740021, 0.041880784920067526, 0.07345473422901705, 0.04792505453224294, 0.027346282804501243, 0.03202970590791665, 0.062184739363146946, 0.021107587199367117, 0.03773709984670859, 0.06887066614581272, 0.03691248100949451, 0.06063713510229718, 0.024736377636145335, 0.06540500718983822, 0.017559900516062044, 0.043376086323405616, 0.042001268884632736, 0.04329646872065496, 0.06850926991319284, 0.001789054354048858, 0.03900865856849123, 0.06866092036943883, 0.02609568789921468, 0.03565939063264523, 0.012908477892779047, 0.02364648553339066, 0.034398247953504324, 0.045199847445474006, 0.07683094212552533, 0.030300995349534787, 0.04599534811859485, 0.050850552433985285, 0.01938056873768801, 0.07572940943646245, 0.04518285968515556, 0.02386336520430632, 0.054153343371581286, 0.015218457992887124, 0.016611914470558986, 0.04807491641258821, 0.0755801635386888, 0.06463039055233821, 0.0215584845864214, 0.020269593005650677, 0.08717027638340369, 0.015499455512326676, 0.04111663998628501, 0.16528560896404088, 0.10750753470347263, 0.027155337484146003, 0.07058133138343692, 0.03637973772129044, 0.053166127399890684, 0.058984531788155437, 0.05144154689332936, 0.08474685251712799, 0.05553630959184375, 0.015552212007605704, 0.020198591737425886, 0.04816307242435869, 0.04703390957729425, 0.010884059520321898, 0.018018371520156506, 0.07420209920383058, 0.061317665968090296, 0.03877635892422404, 0.03187018497555982, 0.037116130042704754, 0.05383659103245009, 0.03650320511951577, 0.1786532619735226, 0.2798371121753007, 0.08333107965881936, 0.14354224054841325, 0.07800206600222737, 0.13985140656586736, 0.20997452113078907, 0.17687900952296332, 0.14748659217730165, 0.16199617297388613, 0.27215867419727147, 0.14141573512461036, 0.08691355265909806, 0.1575179203064181, 0.09742555499542505, 0.14877006236929446, 0.111423031630693, 0.1718632786651142, 0.15846297115786, 0.13503817812306806, 0.19180025963578373, 0.19893924531061202, 0.22296320385066792, 0.10931050826911815, 0.19227480370318517, 0.07782559070619754, 0.1663604614441283, 0.17445203819079325, 0.10236945337965153, 0.09656011432525702, 0.17518790729809552, 0.2011921236407943, 0.11957882641581818, 0.08898841944755986, 0.12590269645443186, 0.10278884845320135, 0.18224461848149076, 0.08704494248377159, 0.09278606332372874, 0.14890403486788273, 0.26420668058563024, 0.1488153779064305, 0.12432998904841952, 0.08176472503691912, 0.17298749880865216, 0.07169890188379213, 0.13979222771013156, 0.09753033140441403, 0.15436974470503628, 0.24604414502391592, 0.20185604895232245, 0.06349845207296312, 0.10940186664811336, 0.09772979843546636, 0.27546702011022717, 0.18370581819908693, 0.17018985439790413, 0.1482217785087414, 0.15035747172078118, 0.13202872476540506, 0.1604811823926866, 0.2011126247816719, 0.06198884206241928, 0.08924938825657591, 0.1850539888255298, 0.14076628169277683, 0.06736909359460697, 0.1918287284206599, 0.10225278776488267, 0.1097859354922548, 0.12573283369420096, 0.12130778559367172, 0.10484982223715633, 0.09945646437699907, 0.20718360057799146, 0.18456587829859927, 0.12881117319921032, 0.06453829002566636, 0.12659274536417797, 0.1175711907853838, 0.07673866348341107, 0.2246712864143774, 0.12301407958148047, 0.08816830915748142, 0.1695200364338234, 0.1782604432082735, 0.10809058818267658, 0.1409720050287433, 0.0914933682361152, 0.10050473312730901, 0.15129434410482645, 0.13120887422701344, 0.14274967135861516, 0.13348836597288027, 0.11711699640727602, 0.09777091341675259, 0.20748479379108176, 0.23455926129827276, 0.1184204377932474, 0.15641358972061425, 0.2194662782130763, 0.20057541376445442, 0.1030893217830453, 0.11222712637390941, 0.082788176368922, 0.13364791288040578, 0.22330083651468158, 0.09972115134587511, 0.22525241773109883, 0.11235483514610678, 0.08645393318147399, 0.09404568088939413, 0.16357025335310027, 0.13347059895750135, 0.10574265557806939, 0.1415888633346185, 0.20743995322845876, 0.1817476615542546, 0.1082610223966185, 0.1051745934819337, 0.13028856657911092, 0.1214079384226352, 0.15981381351593882, 0.16091575438622385, 0.10100375322508626, 0.06882318353746086, 0.1667886509676464, 0.11278302466962487, 0.09737796106492169, 0.1894640678074211, 0.19436993112321943, 0.09207053648424335, 0.17912621784489602, 0.15837740153074265, 0.2794755675131455, 0.14364511705935, 0.18549801578046754, 0.12489877844927832, 0.12820382922654971, 0.1798438746482134, 0.1848387363133952, 0.16234829236054793, 0.17167627229355276, 0.09799347608350217, 0.11452617371105589, 0.232742884545587, 0.13258447463158518, 0.2072016941383481, 0.12162192186224274, 0.13585369451902807, 0.14905074262060225, 0.08696122080436908, 0.1555258920416236, 0.22025814978405833, 0.17851400538347661, 0.098412648512749, 0.115021638921462, 0.12244055527844466, 0.1647179402061738, 0.13218836073065177, 0.13624816085211933, 0.19785156851867214, 0.16841079283040017, 0.13053721573669463, 0.14984414301579818, 0.25292802485637367, 0.11082674565841444, 0.056450717165716924, 0.08697901750565507, 0.10141654318431392, 0.1150622715067584, 0.1358620956307277, 0.15829005074920133, 0.17485823045717552, 0.09034877613885328, 0.1890438044210896], [0.0428964251477737, 0.012178770466562128, 0.07752919918857515, 0.08614915539510548, 0.06322097047814168, 0.005662959702021908, 0.051912287453887984, 0.04820377551368438, 0.05649061131407507, 0.054225201820372604, 0.017395511094946414, 0.041710495424922556, 0.028468488017097116, 0.08336964165209793, 0.014059863424336072, 0.01827242722356459, 0.02200045022618724, 0.05150978366145864, 0.03046421959879808, 0.03907263540895656, 0.018654802115634084, 0.020910157363687176, 0.015928179382171948, 0.06646900947089307, 0.03184673310897779, 0.026821072315215133, 0.040792985673760995, 0.05175889666134026, 0.08126876258756965, 0.02896832076658029, 0.011493325655465014, 0.06300965877017006, 0.024446131101285573, 0.017331016606476624, 0.019300862077216152, 0.010672591961338185, 0.011033721020794474, 0.0439525606634561, 0.05410841746197548, 0.05114483254146762, 0.02662794508069055, 0.05403790230047889, 0.01778641697455896, 0.021448865663842298, 0.02591681546618929, 0.063703685591463, 0.02339722039323533, 0.06724845748976804, 0.08380621002288535, 0.05738603103964124, 0.03348419661051594, 0.07117648186977021, 0.02967656713735778, 0.03280959921539761, 0.012983110118511831, 0.05504237320565153, 0.08490386870107614, 0.020746294867421966, 0.09737718923133798, 0.038657266486552544, 0.09624859783798456, 0.029645959111803677, 0.015689363681303803, 0.042343313616584055, 0.02083587951346999, 0.012068121814081678, 0.06020950218953658, 0.026660341682145372, 0.035438538616290316, 0.020515091746347025, 0.04978809010935947, 0.04511536506470293, 0.027148107110406272, 0.029968915805511642, 0.056199663449660875, 0.026738911001302768, 0.012455531250452623, 0.025702245729917195, 0.02194994336605305, 0.027516789377841633, 0.08059490734012797, 0.037709829630330205, 0.011024838440789608, 0.05533887604542542, 0.04539816785836592, 0.06549983881996013, 0.04415599076310173, 0.035739364466280676, 0.04023146189865656, 0.01725040638120845, 0.014264374276535818, 0.02034622160863364, 0.04444444872206077, 0.03468124741630163, 0.10751933485153131, 0.019424954734859057, 0.05031312248320319, 0.025396694254595786, 0.01792457333067432, 0.05356800036679488, 0.07605424005305395, 0.04012556484667584, 0.024933488348324317, 0.08476684597553685, 0.007304841765289893, 0.03694114275276661, 0.03824301820714027, 0.006784717770642601, 0.051532682628021576, 0.02408360680419719, 0.008041536511882441, 0.02517127060855273, 0.0859562044206541, 0.09738550128531642, 0.018243613340018783, 0.053050615824759007, 0.05362960604543332, 0.03764592329389416, 0.03602250864787493, 0.0384996528737247, 0.013210480974521488, 0.06859472079668194, 0.05604207210126333, 0.06023910274961963, 0.031053941274876706, 0.053804652707185596, 0.044727114218403585, 0.035531169778550975, 0.04677646225900389, 0.0432949547393946, 0.026796616693900432, 0.0382485657610232, 0.08255694541730918, 0.02556612842454342, 0.10109217269928195, 0.036183280099066906, 0.03024879453732865, 0.02885169040382607, 0.008179647411452606, 0.009162657261185814, 0.043127292447024956, 0.07282658043550327, 0.03174265431880485, 0.031347820622613654, 0.012084443496860331, 0.031410951414727606, 0.02478488069755258, 0.06116131400631275, 0.02307824161107419, 0.00996455524727935, 0.026698686597228516, 0.0269466344252578, 0.03297447845397983, 0.028073092144040857, 0.03284905920736492, 0.0360905932757305, 0.030270294555521104, 0.06166085360746365, 0.01603721386345569, 0.05309956046403386, 0.03558618147508241, 0.06243013791390695, 0.014205743682396132, 0.05190452829992864, 0.006838935369160026, 0.06596176637685858, 0.055816637323005125, 0.025048159441212192, 0.07598784010042436, 0.030072751542320475, 0.02254854483908275, 0.04106360240257345, 0.012809464260499226, 0.01665436902840156, 0.05927620324655436, 0.05797419049486052, 0.06909452014951967, 0.015299945807782933, 0.07253687566844746, 0.08150167821440846, 0.10392103184130974, 0.037013732217019424, 0.031767204563948326, 0.06282389920670539, 0.031976393729564734, 0.03815433898125775, 0.060295164585113525, 0.04033185221487656, 0.023193213273771107, 0.03535401541739702, 0.03127368006971665, 0.0345422431564657, 0.05408564837125596, 0.09168534699711017, 0.029516946015064605, 0.0516818691539811, 0.03421372406592127, 0.024732737401791383, 0.03181476138706785, 0.13819656567648053, 0.019023274726350792, 0.04350051109213382, 0.05933150809141807, 0.04522932184045203, 0.04473270630114712, 0.01123378548072651, 0.014805505688855192, 0.029839828494004905, 0.04909923234663438, 0.0662496751465369, 0.05903854900680017, 0.06011878947902005, 0.028416227833076846, 0.053422383571160026, 0.08411680624703877, 0.05337703834811691, 0.03194071126927156, 0.06012147605360951, 0.034444324192008935, 0.02530497222323902, 0.023554572399007156, 0.03219604346668348, 0.01711154869553866, 0.11958883798797615, 0.002829747400028282, 0.0506927050446393, 0.058621035277610645, 0.017205233707500156, 0.0038869230820637313, 0.06687241868348792, 0.03279594369814731, 0.017744429969752673, 0.03910294843080919, 0.07263889128807932, 0.03162785891618114, 0.04656541772419587, 0.011075347156292992, 0.026063708755827975, 0.07420711612212472, 0.020046551653649658, 0.02937223278422607, 0.02709652042540256, 0.08252924846601672, 0.04038602899527177, 0.03216694756702054, 0.017400355463905726, 0.017841400840552524, 0.018168355854868423, 0.031924821887514554, 0.0441786151350243, 0.06095719742006622, 0.03329868566652294, 0.09743117305333726, 0.011497026189317694, 0.008894221518858103, 0.01600639061507536, 0.054594390603597276, 0.0022010833799868124, 0.03135081518848892, 0.017254707126994617, 0.03938913170713931, 0.07107221754267812, 0.038671163201797754, 0.0978819461306557, 0.02702432615478756, 0.06310335491434671, 0.03590544598409906, 0.023291226862056646, 0.05590782129729632, 0.014513212681777077, 0.11097409165813588, 0.0299809868374723, 0.025099126432905905, 0.06247402110602707, 0.018165073706768453, 0.04311297641834244, 0.03459213774476666, 0.04915031066047959, 0.03854985916404985, 0.035360457259230316, 0.04334011071478017, 0.030049271845200565, 0.07349828345468268, 0.017708339328237344, 0.03188269016391132, 0.04603131259500515, 0.047610087058274075, 0.029589887999463826, 0.1007491372001823, 0.061821164927096106, 0.06420075384085067, 0.043467960495036095, 0.09465367795201018, 0.040206024787039496, 0.021947516543150414, 0.07788149669067934, 0.03547971668012906, 0.04840164321649354, 0.02845770646672463, 0.10685342800570652, 0.03599346840928774, 0.07353165041422471, 0.0024760579071880784, 0.031125916611927096, 0.028802101951441728, 0.044450181812862866, 0.07257952689542435, 0.01401965479089995, 0.041891950531862676, 0.03551066052750684, 0.05372138002712745, 0.028893467751913704, 0.00790945556218503, 0.05952371320745442, 0.009346409315185156, 0.02642444262164645, 0.042767914856085554, 0.08001206166227348, 0.09558602323522791, 0.07446671195793897, 0.0512633980542887, 0.008663120443088701, 0.05888221559871454, 0.059159671218367293, 0.052466578999883495, 0.10957762206089683, 0.04796575762156863, 0.06743244332028553, 0.01423389148840215, 0.037386041731224395, 0.023978069693839643, 0.03954003259423189, 0.014955630103941076, 0.03971671198087279, 0.01434412175512989, 0.045273186478880234, 0.008309907316288445, 0.01382081487463438, 0.030710916907992214, 0.09404000345966779, 0.025277449676650576, 0.04142342528211884, 0.023931809773785062, 0.023124520084820688, 0.04280196830222849, 0.03824022402113769, 0.04411176989378873, 0.017805469760787673, 0.012582414383359719, 0.08996268865303136, 0.058740198219311424, 0.06846121585112996, 0.11965311539825052, 0.08264266347396187, 0.10489560532732867, 0.1715071071521379, 0.26391234481707215, 0.16389936616178602, 0.1300837635062635, 0.18809956993209198, 0.17104675294831395, 0.18704747169977054, 0.18247235391754657, 0.15024154825368896, 0.06299437794950791, 0.18142490152968094, 0.1761481276480481, 0.17307694244664162, 0.1215877385402564, 0.16520564997335896, 0.08924624155042693, 0.12226917111547664, 0.12299758906010538, 0.06066183377697598, 0.08812663014396094, 0.20813579089008272, 0.10802870048792101, 0.11009152221959084, 0.21677035256288946, 0.178191942977719, 0.10662250133464113, 0.08639056119136512, 0.05535115487873554, 0.14127248578006402, 0.1176060939906165, 0.10621443143463694, 0.20227272034389898, 0.09788903364096768, 0.13988309627166018, 0.127295826387126, 0.15884416789049283, 0.1315776474075392, 0.11622847494436428, 0.16018083522794768, 0.16608150297543034, 0.06775048328563571, 0.08912095217965543, 0.15115669055376202, 0.09063963865628466, 0.2213836761075072, 0.19844588037813082, 0.08142859151121229, 0.13004451873712242, 0.15261395688867196, 0.14451711089350283, 0.11459080735221505, 0.12199465068988502, 0.1171749878267292, 0.15360775199951604, 0.1379601619555615, 0.11818675033282489, 0.16182541963644326, 0.2605923026567325, 0.10640082924510352, 0.14709444134496152, 0.10617265594191849, 0.20030632585985586, 0.11745951982447878, 0.1549602864542976, 0.2209502024925314, 0.09176772538921796, 0.10128195470315404, 0.13808971125399694, 0.11230229109060019, 0.13934846792835742, 0.08796150970738381, 0.16904869844438508, 0.15688924700953066, 0.1403065657359548, 0.08558746092603542, 0.08646033791592345, 0.16292774642352015, 0.13418178423307836, 0.1716695781215094, 0.06354694400215521, 0.07222069849376567, 0.14473316492512822, 0.1610312474076636, 0.08535704633686692, 0.2482339704874903, 0.11676858775899746, 0.11956554197240621, 0.08935714067774825, 0.12737321754684672, 0.24217044585384429, 0.09879587130853906, 0.16433862852863967, 0.14031910803169012, 0.12404285953380167, 0.1530373521381989, 0.09996965949540026, 0.18343434057896957, 0.2239834045758471, 0.09688717880635522, 0.08476847127894871, 0.08745278231799603, 0.10543726923060603, 0.17060094483895227, 0.10673707409296185, 0.08216326576075517, 0.10317817912437022, 0.1175687120121438, 0.12529462517704815, 0.09073817360331304, 0.16342912655090913, 0.2153551363153383, 0.11500826542032883, 0.13666251674294472, 0.15909254987491295, 0.17126081802416593, 0.12180960358818993, 0.14092732773860916, 0.16387131297960877, 0.11640533615718596, 0.1153055029863026, 0.15701466996688396, 0.12209026899654418, 0.1164655465981923, 0.12662823486607522, 0.12266642050235532, 0.08458147232886404, 0.14426406822167337, 0.13351944711757824, 0.10213932822807692, 0.13562747306423262, 0.12850192026235163, 0.3014032408827916, 0.22239967627683654, 0.12191809073556215, 0.12110287862014957, 0.13814647070830688, 0.17909823887748644, 0.17842898494563997, 0.24596636794740334, 0.13442500086966902, 0.14351685909787193, 0.18612581334309652, 0.17500551708508283, 0.11743312905309722, 0.18117893894668669, 0.11594393552513793, 0.14858400594675913, 0.20033157372381538, 0.10247898695524782, 0.07988406345248222, 0.11263412758125924, 0.17010752053465694, 0.16964851703960449, 0.050233983565703966, 0.12237299015396275, 0.0727931986330077, 0.11802422741311602, 0.10113775540958159, 0.1423795919981785, 0.10400856815977022, 0.28149735589977354, 0.11511899385368451, 0.08064869820373133, 0.14826091937720776, 0.07941866264445707, 0.1491120588616468, 0.10190510642132722, 0.07867231441196054, 0.11835462413728237, 0.06487403763458133, 0.23734991467790678, 0.14480809215456247, 0.1280188563396223], [0.04460992538952269, 0.005436498440758442, 0.04221543415042106, 0.080810686777113, 0.04091436763701495, 0.020745432120747864, 0.035742689287872054, 0.05058596936578397, 0.014556322184944293, 0.05918176866543945, 0.08683907813974656, 0.03934796477551572, 0.04341119732998777, 0.024279359386127908, 0.009089653121918673, 0.01749242073856294, 0.06563674280187115, 0.02081112517771544, 0.021739585317845922, 0.02012595403357409, 0.04057730271597393, 0.05864596401806921, 0.08842348179314286, 0.006743919593645842, 0.03396581334527582, 0.011852094685309567, 0.07548221488832496, 0.06112431794463191, 0.05528559355298057, 0.053755774861201644, 0.005205077313803486, 0.048411921961815096, 0.01492073153713136, 0.020405908835527953, 0.07119612651877105, 0.04007179995824117, 0.02119759301422164, 0.020494940581556875, 0.04667504777899012, 0.05668738805979956, 0.06893716999911703, 0.016118493877002038, 0.06554474617587402, 0.019055970042245463, 0.06742760451743379, 0.024999674933496863, 0.03166236878314521, 0.04346506240835879, 0.05221436011197511, 0.012351329078228446, 0.04687276705226395, 0.07247648711199872, 0.027646815506159328, 0.02637271307321498, 0.023580664455948863, 0.040801935974741355, 0.008866899352142354, 0.04298032865335699, 0.04644690045097377, 0.013876690245524514, 0.030294716780190356, 0.08792252468992956, 0.03515806245559361, 0.04587235569488257, 0.06999082674155943, 0.018886085017584264, 0.05522507140995003, 0.0267231236648513, 0.05040615811594762, 0.023972357012098655, 0.013499722826963989, 0.032420539428130724, 0.03519507707096636, 0.02441313521558186, 0.029331004625419155, 0.04895743761153426, 0.05093322026368696, 0.018731230338744354, 0.025086172245210037, 0.04025167800136842, 0.053880366613157094, 0.07357791590038687, 0.019874857644026633, 0.06270546728046611, 0.039590580272488296, 0.01634085987461731, 0.08372780212084763, 0.019394727059989236, 0.027787933031504508, 0.028554269156302325, 0.06959316175198182, 0.06068060269171838, 0.09518322258372791, 0.022501373932755087, 0.1000487279088702, 0.009384005588799482, 0.09645059559261426, 0.024636456728330813, 0.03093626262852922, 0.028397210298862774, 0.03027077324077254, 0.06395952616003342, 0.04147018429648597, 0.027964265464106575, 0.040012279714574106, 0.014257981601986103, 0.0037706406010329374, 0.044528537764563225, 0.041875307870213874, 0.014063714243093273, 0.03430920136452187, 0.019569337709981482, 0.019943589795730077, 0.028171423000458162, 0.0265058766308357, 0.017612975207157433, 0.04311395234253723, 0.02942152994364733, 0.03268025771831162, 0.07939342220197432, 0.03063473544898443, 0.012207087111164583, 0.0664668127137702, 0.013584985390480142, 0.01267689534870442, 0.018191147210018244, 0.006298810030784807, 0.02640645110659534, 0.04582317727908958, 0.03312091532279737, 0.061491614251281135, 0.0428857345104916, 0.03588218707591295, 0.04683839448262006, 0.02295212103490485, 0.022684561954520177, 0.058293458714615554, 0.04133449743676465, 0.046855167020112276, 0.039068420010153204, 0.11677879228955135, 0.008759501306485618, 0.037242836915538646, 0.023268561672011856, 0.02185491321142763, 0.09034584465553053, 0.0554277408082271, 0.048077079773065634, 0.05374276501243003, 0.03063622902118368, 0.03075920103583485, 0.010234363962808857, 0.07504384309868328, 0.04280390159692615, 0.05307388215442188, 0.02831959463946987, 0.01160471645562211, 0.04510443322942592, 0.04231141610944178, 0.03214738826500252, 0.06014207065163646, 0.03775235098146368, 0.04638922444428317, 0.012457561952032847, 0.03875253598380368, 0.012987489717488643, 0.0625520505127497, 0.08248667887528427, 0.02546910931414459, 0.06988253997405991, 0.02966665389976697, 0.013327840497368015, 0.05650750259519555, 0.027434544572315644, 0.05574061542574782, 0.050438252292224206, 0.03400546629563905, 0.03733030644070823, 0.018826757732313126, 0.033222155398107134, 0.02143141220585676, 0.0631917298596818, 0.033284065357293, 0.018076758133247495, 0.0490928313229233, 0.07772056938847527, 0.0260504020479857, 0.04904682187770959, 0.03520398284308612, 0.0256822374285548, 0.006040101989128743, 0.03270352775871288, 0.04758229733852204, 0.020894434965157416, 0.048136002587853, 0.033697827529977076, 0.02507570981833851, 0.06250310587347485, 0.10938457460724749, 0.040742252458585426, 0.04378296507638879, 0.04585984679579269, 0.06013805934344418, 0.06850584119092673, 0.03668227422167547, 0.02254511240607826, 0.0379679114848841, 0.03898016751918476, 0.009240151393896667, 0.07001015226705931, 0.0469640066876309, 0.052160932900733314, 0.058983429698855616, 0.014181424430717016, 0.038235270185396075, 0.08244492564699613, 0.04570444107230287, 0.04876829756540246, 0.01901929124869639, 0.028259285863896366, 0.07170672412030399, 0.013533169567381265, 0.013603980660263915, 0.09252764750272036, 0.07121202332200482, 0.023573747639602516, 0.10198330652201548, 0.052461977684288286, 0.026170741293753963, 0.04211581195704639, 0.05389459358411841, 0.052145418303553015, 0.03635720240708906, 0.0657252587552648, 0.06417817770852707, 0.01686515381152276, 0.06620594038395211, 0.0667703288490884, 0.07368520076852292, 0.02420505741611123, 0.09456080559175462, 0.07373493950581178, 0.010353660491091432, 0.007817801251803758, 0.044088225258747116, 0.02462544882291695, 0.003593644642023719, 0.06300359542365186, 0.01832172438298585, 0.005103522289573448, 0.05086387769551948, 0.04277039734006394, 0.1065453996125143, 0.07363855678704567, 0.039605727506568655, 0.008293419577967143, 0.0805430683249142, 0.03337654809001833, 0.015856966601859313, 0.051862218460883014, 0.04830867066630162, 0.012640507848118432, 0.03928490448743105, 0.01103995877201669, 0.023635759644093923, 0.031107921386137605, 0.03742359440366272, 0.11157292319694534, 0.07983851042808965, 0.06529002625029534, 0.059785583725897595, 0.06880480053951032, 0.03132635771180503, 0.028445008319977205, 0.021798719644721132, 0.02269067168526817, 0.031278715541702695, 0.04883308705757372, 0.05319840340234805, 0.029938920051790774, 0.03534706891514361, 0.07337594041018747, 0.05560089870414231, 0.04379929232527502, 0.014391147014976013, 0.04951187387632672, 0.010846687746379757, 0.03290806365839671, 0.012161386584921274, 0.0687732666847296, 0.045902368146926165, 0.016950411736615933, 0.020351290477265138, 0.08443060112767853, 0.03228987319744192, 0.037987266696291044, 0.05083226220449433, 0.07538345729699358, 0.03368047982803546, 0.042565931944409385, 0.03506991015456151, 0.08695979588082992, 0.07016192146693356, 0.020925466014887206, 0.0035616594686871395, 0.029686009111173917, 0.036015743971802294, 0.04522542185441125, 0.02802803264785325, 0.004639923972717952, 0.03832293637969997, 0.05345348698028829, 0.013798199779557763, 0.013363318867050111, 0.023670981972827576, 0.007932881453598384, 0.02248356795462314, 0.006460442373281694, 0.03212752468243707, 0.024594235947006382, 0.05311209533829242, 0.027982143801636994, 0.027982073297607712, 0.03590124542824924, 0.009577428754710127, 0.005413863400463015, 0.017030424533004407, 0.03492492418445181, 0.15494370687520131, 0.08803199147223495, 0.024019462980504613, 0.038205684468266554, 0.021836765845364425, 0.1185247243847698, 0.02645765373017639, 0.008357732240256155, 0.05410883677541278, 0.0258260285409051, 0.011968469007115345, 0.022546372201759368, 0.029710277340200264, 0.059325003167032264, 0.07385269607766531, 0.025166120103676803, 0.006282179892878048, 0.022467413255071733, 0.031114040393731557, 0.017555310332681984, 0.02898531409300631, 0.03802585095399991, 0.0550019001821056, 0.0748311732604634, 0.28069343185052276, 0.08845947595546022, 0.13887729321140796, 0.16862353688338771, 0.08516752408468165, 0.17198896879563108, 0.0767227666801773, 0.11123198797577061, 0.0804091032478027, 0.1767355078482069, 0.28319170873146504, 0.13602418068330735, 0.16191793576581404, 0.10608077063807286, 0.08397089259233326, 0.10938820370938629, 0.2055594846024178, 0.12230762920808047, 0.1719609452993609, 0.1028801771462895, 0.1640075267641805, 0.23649291222682223, 0.1996793446596712, 0.10529425737331621, 0.07321164375753142, 0.1552985276794061, 0.15299212565878406, 0.14466640132013708, 0.12881611590273678, 0.0785227345477324, 0.1466140491538681, 0.13040342135354877, 0.0887130010232795, 0.13935403403593227, 0.1612615358317271, 0.15811542340088636, 0.15348782093496993, 0.16491153684910387, 0.1275614113546908, 0.22568546090042219, 0.1146557526953984, 0.12999436439713463, 0.161725704674609, 0.09887832391541451, 0.19077189528616145, 0.07841264436137863, 0.1850410902989097, 0.17915240081492811, 0.2065810063504614, 0.08240935450885445, 0.1470826708828099, 0.14360852917889133, 0.16111666860524565, 0.1460990877239965, 0.08393410433200188, 0.16104945971164852, 0.12835666711907834, 0.16771119990153238, 0.14966589398682117, 0.09485956456046551, 0.2583565085660666, 0.1890781510155648, 0.16296460147714242, 0.117852620605845, 0.2046581165632233, 0.18657033011550084, 0.12224687699927017, 0.15919058758299798, 0.16160427447175607, 0.15357503812992945, 0.08176692179404199, 0.1675468438770622, 0.11474679937236942, 0.07414666819386184, 0.08802615077001974, 0.1423959044041112, 0.25798433634918183, 0.13218582258559763, 0.14613760518841445, 0.10010950980358757, 0.14330843434436247, 0.13420324714388698, 0.08620227832579985, 0.18369271187111735, 0.10528418642934412, 0.0832565977179911, 0.23807407269487157, 0.12101937958505005, 0.10132221621461213, 0.11130863698781468, 0.11717840170604177, 0.17669486784143373, 0.24838191020535305, 0.1433071430074051, 0.18083143571857363, 0.15807809337275103, 0.20589079416822642, 0.06348331968183629, 0.12744155450491235, 0.09730750898597762, 0.10201284399954602, 0.14545387937687337, 0.14086241950280964, 0.14661082823295146, 0.17446073616156355, 0.1432197031681426, 0.21981023397529498, 0.154253346263431, 0.11921432800590992, 0.11029203567886725, 0.1953909036819823, 0.11200659719179384, 0.10169199871597812, 0.17182973359012976, 0.18028389400569722, 0.11388463157345541, 0.16593118838500232, 0.1306472613941878, 0.12958987907040864, 0.12132403862779029, 0.18777992692776024, 0.1516817303490825, 0.08843004980008118, 0.11682435273542069, 0.14558629336534068, 0.1828996677068062, 0.11110852428828366, 0.14725444838404655, 0.06565780495293438, 0.11538016304257326, 0.18247318512294441, 0.12562528165290132, 0.11887609420227818, 0.13174473453545943, 0.12735458964016289, 0.17393109505064785, 0.16415450169006363, 0.18053282517939806, 0.10403095133369789, 0.10597917062113993, 0.1639058970613405, 0.1192722748965025, 0.08244664742960595, 0.0496340016979957, 0.17271939053898677, 0.2169282519025728, 0.1202997264044825, 0.22228872519917786, 0.14961369131924585, 0.0819650455377996, 0.10957326565403491, 0.11890774680068716, 0.22976433421717957, 0.17986140417633578, 0.14037911809282377, 0.2304325342993252, 0.1899645573575981, 0.2385755121940747, 0.1550481270533055, 0.153911275556311, 0.13622898375615478, 0.09552182746119797, 0.16441352607216686, 0.10605844683595933, 0.2026787048089318, 0.07906258761067875, 0.16155165620148182, 0.17108656174968928, 0.08569451572839171, 0.16128402290632948, 0.20464020111830905, 0.10656376034603454, 0.1669102444429882, 0.0889920633926522, 0.18070696271024644, 0.13649768574396148], [0.05637951551761944, 0.07255127333337441, 0.02301175074535422, 0.0609920375427464, 0.03326170815853402, 0.026897470852418337, 0.020479390732361935, 0.03974102844949812, 0.06047622635378502, 0.06646330977673642, 0.057325111847603694, 0.06497852460597642, 0.04302283516153693, 0.020775210796273313, 0.10650574666215107, 0.030589698217227124, 0.07146049436414614, 0.010078976793010952, 0.07008828557445668, 0.012045041021337966, 0.09249451803043485, 0.05945412201981526, 0.05746639821154531, 0.04181340533250477, 0.025277989589085337, 0.05578247997618746, 0.07378309746854939, 0.03541492347721942, 0.041626502861618064, 0.0213322742638411, 0.05119023713632487, 0.07417928558425047, 0.04182539843895938, 0.018150798496208154, 0.028952993561688345, 0.07393591309664771, 0.024880194723664317, 0.036149471561657265, 0.025027217889146414, 0.03521014266880229, 0.0293190875891014, 0.07192562057753094, 0.025043298373930156, 0.07708396253292449, 0.030805915521341376, 0.005921203901380068, 0.03337569833092857, 0.016892572457436472, 0.07376043969998136, 0.06211273619555868, 0.09199183172313496, 0.01566591552546015, 0.02456758727930719, 0.006852705455457908, 0.014253430381359067, 0.029796136404911522, 0.03931510618713219, 0.04305675873183645, 0.049406477774027735, 0.04118404183827806, 0.04688785491453018, 0.03390740261238534, 0.031266436708392575, 0.030594486925110687, 0.024026500395848416, 0.06427810789318755, 0.03545831685187295, 0.007286786240001675, 0.04807970326510258, 0.06279331530095078, 0.07402508213999681, 0.07564349099993706, 0.010996051460097078, 0.027548696161829866, 0.05981571492156945, 0.03056340206967434, 0.02321772826689994, 0.023195447138277814, 0.07158924214309081, 0.010876921915041748, 0.019417230832914356, 0.04714375485491473, 0.02829295895935502, 0.061475858456105925, 0.014159904931148048, 0.014724083739565685, 0.02301044085470494, 0.04397365992190316, 0.02889647159463493, 0.03198811966285575, 0.03849002721835859, 0.022163711582834367, 0.025844589654298034, 0.06094831020163838, 0.05437762039946392, 0.013454995441861684, 0.023357721438515, 0.03668984412797727, 0.022368859754351433, 0.023611433898622636, 0.011035546704079024, 0.017975150694837794, 0.05970669713860843, 0.027684564847731963, 0.050337138382019475, 0.03276740069850348, 0.02221347443992272, 0.06879783919430338, 0.053449568440555595, 0.029022746166447178, 0.04589682059304323, 0.03857500683807302, 0.04580482025630772, 0.10224170750007033, 0.0540506486868253, 0.04180118958174717, 0.019880206673406065, 0.04493135325901676, 0.012730743728752714, 0.04599288418830838, 0.04466571263037622, 0.03203187297913246, 0.07692919505643658, 0.016591540661465842, 0.04047158006869722, 0.027002686983905733, 0.01338492000286351, 0.017264620364585426, 0.03419551547267474, 0.020575133348756935, 0.057624423716333695, 0.0374614439351717, 0.055144203288364224, 0.05181644650292583, 0.03135845188808162, 0.022672416707791854, 0.05077716887171846, 0.05774283337814268, 0.03461737447651103, 0.0174000066544977, 0.027783420773630496, 0.07747298892354593, 0.04938641010085121, 0.014407778544409666, 0.08445436469628476, 0.03520824648148846, 0.05082973890239373, 0.07182071800343692, 0.09719164489069954, 0.021118372460477985, 0.017511072765046265, 0.023352170173893683, 0.02611359963339055, 0.03064554482989479, 0.0260072888340801, 0.11492518940940499, 0.006183826772030443, 0.00993225141428411, 0.05790869225165807, 0.051164265678380616, 0.04605342117429245, 0.041493602766422555, 0.012675130892603192, 0.062382328760577366, 0.011017746292054653, 0.040658742291270755, 0.02533692168071866, 0.049765851654228754, 0.009997166143875802, 0.007215561863631592, 0.06183990786666982, 0.04170384207100142, 0.02861773577023996, 0.0265229849901516, 0.024600803953944705, 0.02278321007906925, 0.022026434671715833, 0.03902733471477404, 0.017919448800967075, 0.03979429238825105, 0.015864163578953594, 0.08163652644725516, 0.037102797359693795, 0.09337999668787234, 0.04213926011289004, 0.00758568992750952, 0.0053214126728562405, 0.0555343725864077, 0.09425636919331737, 0.020072940569662023, 0.00821785502921557, 0.027944355497311335, 0.03875273636367638, 0.04807915407582186, 0.08895304868929088, 0.04997859199647792, 0.044684514941764064, 0.03367174474988133, 0.01842188463342609, 0.007983585910551483, 0.015382687852252275, 0.03799095888098236, 0.09363424906041473, 0.026744519782369025, 0.026259416808898095, 0.024678712761669885, 0.03721337365277577, 0.04796275192347821, 0.009613344991521444, 0.044541918687173165, 0.06428158856579103, 0.04767023441672791, 0.02744967510807328, 0.027375248828320764, 0.04886859511316288, 0.05193982484342996, 0.0157155021224753, 0.017174026397697162, 0.009691866071079858, 0.03393719613086432, 0.02411653218587162, 0.04297245446650777, 0.026713522129284684, 0.044786845974158496, 0.07043391859042458, 0.03792845891439356, 0.038512443788931705, 0.021438386538648047, 0.04972558643203229, 0.0646408622560557, 0.032081270328490064, 0.01911812119942624, 0.03427885865676217, 0.012218954052514164, 0.045032634152448736, 0.0353784988692496, 0.012267036872799508, 0.07731724923360161, 0.04951677576173097, 0.09746311508934014, 0.014036508964636596, 0.054821435842313804, 0.01917719615448732, 0.05286769868689589, 0.10083956047310494, 0.04351959170890041, 0.07371105719357729, 0.08048167786910199, 0.009431466860405635, 0.035108527808915824, 0.013472840382746654, 0.03320081494166516, 0.00967531525020604, 0.03622042830102146, 0.06662882355158217, 0.01679992459685309, 0.023173642839537933, 0.029252902859298047, 0.03176862948748749, 0.03202067397069186, 0.03149925214529503, 0.022783505082770716, 0.027112240968563128, 0.030709861202922184, 0.020273392801755108, 0.009096011472138343, 0.045526685571530834, 0.07031020257272758, 0.07183893030742183, 0.04353320640802849, 0.04872203578997869, 0.009194920276058838, 0.02969316341477679, 0.06827435048762709, 0.02945396179711679, 0.0702722862479277, 0.03281527664512396, 0.08837348330416717, 0.037355034801294096, 0.017097546224249527, 0.0061414858555508545, 0.05418729291704949, 0.07253320203744806, 0.0262694636330707, 0.05438018823042512, 0.06678213641862385, 0.017905173590406775, 0.047856402161414735, 0.07154725142754614, 0.06835200139903463, 0.046603549271821976, 0.021264586684992537, 0.06320879183476791, 0.04614226367266383, 0.0485641661362024, 0.02050619154033484, 0.04478320945054293, 0.013727427649428137, 0.05205130284593906, 0.0800286115554627, 0.014720048311573919, 0.03548713073541876, 0.059960689759464, 0.06038252649886999, 0.01054382933943998, 0.06363364911521785, 0.02965701525681652, 0.06462437173468061, 0.05822748920763843, 0.019638802732515614, 0.04270043136784807, 0.040675611307960935, 0.07393652907921933, 0.05188548479054589, 0.010809672203322407, 0.04966437780240085, 0.010510046777199022, 0.05175801721634343, 0.04340184255852364, 0.029195416100264993, 0.027181112272955943, 0.04494510525546502, 0.03944161639083177, 0.08524186501745135, 0.015257314989867155, 0.003999623077106662, 0.02048052250756882, 0.018098645923600998, 0.01925819415191654, 0.032250862204818986, 0.02661735277797561, 0.054296893285936676, 0.023652927375223953, 0.01649915997404605, 0.04804215059266426, 0.009883071143121924, 0.015217014515656047, 0.03245854109991342, 0.03469942632364109, 0.0517822594702011, 0.06913794321008027, 0.060663088006549515, 0.06732164067216218, 0.03714098085765727, 0.03447950199188199, 0.04471752195968293, 0.048902967682806775, 0.05762778935604729, 0.053423611825564876, 0.00932230435864767, 0.12380472660879605, 0.013063357619103044, 0.15111863322090358, 0.15562390006380156, 0.10302649898221716, 0.2044448975357227, 0.14782136015128344, 0.1607318947208114, 0.13091768516460434, 0.24066937796305865, 0.18188820948125795, 0.12722449115244672, 0.14324983436381444, 0.14131262112641707, 0.19631573843071237, 0.1490746546187438, 0.20715292019303888, 0.13028113025939092, 0.15457816945854574, 0.10535630834056064, 0.15322318591643125, 0.13457325228955597, 0.20654615509556606, 0.10346600625780411, 0.09040829638252035, 0.18850521300919354, 0.0948550523025915, 0.08833289524773136, 0.1919770540553145, 0.1329181739129126, 0.13026153756072745, 0.08098765931208618, 0.10122673149453476, 0.21754393761511892, 0.161608979688026, 0.11869735535583459, 0.09775023718248121, 0.2014199926634319, 0.163780830334872, 0.1588047598488629, 0.11805124158854596, 0.1396738551557064, 0.09621073346352205, 0.11911058318219148, 0.08247040357673541, 0.09856805423623882, 0.15783645008923486, 0.11490177465020679, 0.19170250394381583, 0.0967589950596448, 0.208038124255836, 0.15562894666800275, 0.14986507158027962, 0.12433077572495677, 0.1439911953639239, 0.2232916487264447, 0.084449177084025, 0.11778616128140129, 0.08443617465673015, 0.1306265257881023, 0.11888582375831902, 0.12788454245310277, 0.21226291864877567, 0.11464203780633397, 0.18401820299914107, 0.12790967157343403, 0.10920756496489048, 0.15107579645700753, 0.0918356838519685, 0.10389805494924076, 0.17940191086381674, 0.18602722644573078, 0.18148387258406729, 0.1906005630735308, 0.07819702819688246, 0.12036084226565436, 0.18552799854660407, 0.08369364848476835, 0.1237864994618576, 0.11765660456148908, 0.17508330900454894, 0.09946640173438936, 0.07303804057301022, 0.2148775345995091, 0.13781805551843718, 0.19087726541329175, 0.1431413323734887, 0.06615165970288217, 0.0786280156171415, 0.09802980421227403, 0.11779116335674189, 0.08814563654595986, 0.10480956072569825, 0.16907566809095442, 0.1360801386181265, 0.22313857334665954, 0.11779276639572345, 0.09531119852908887, 0.07968309728312306, 0.1162899099290371, 0.07097282912582159, 0.18381213827524334, 0.11751735539291985, 0.15001899300841615, 0.11228430143091828, 0.09470358738326468, 0.11299637728370726, 0.1741674987715669, 0.18989576026797295, 0.1249131464282982, 0.11338727388647385, 0.15853329707169905, 0.15941977762850001, 0.15053790266392753, 0.10236632151645608, 0.22291022934950888, 0.19683441059896722, 0.11182653732248582, 0.06780581039492972, 0.12454337876988575, 0.10511640168260783, 0.2649016573559493, 0.12942988687427714, 0.17358771816361696, 0.17183513642521575, 0.2690098009770736, 0.19383457547519356, 0.09728574921609834, 0.14533448265865445, 0.16503016173373908, 0.09660373034421355, 0.16459582722745836, 0.1024968949786853, 0.12144941705628298, 0.1647978398250416, 0.10302344133378938, 0.15779002133058384, 0.06422547477995977, 0.22088717931183055, 0.13206828123657033, 0.1135204745514784, 0.07720304012764245, 0.1369024976156652, 0.24617128976387903, 0.25956724828574806, 0.1548588793957606, 0.1432932648458518, 0.09276500859414227, 0.1151010487228632, 0.11843439016956836, 0.15999929106328636, 0.08700923033757135, 0.07713425788097084, 0.13157013687305152, 0.10946842245175503, 0.12010666410787962, 0.09944991121301427, 0.16107331233797595, 0.11322888472932391, 0.05917485927056987, 0.13945714803412557, 0.17763037467375398, 0.11502101551741362, 0.12161177670350298, 0.08514326327713206, 0.16598307935055345, 0.1287393778329715, 0.20408874086569995, 0.1602735443157144, 0.15997594309737906, 0.10452629037899897, 0.09401658870046958, 0.12872471299488097, 0.09582740676705725, 0.10102624029968865, 0.16874501161510125, 0.20348535996163264, 0.070897976111155], [0.05190473239053972, 0.043772571298177354, 0.09628015395719558, 0.0861395445826929, 0.05597943483735435, 0.009055811187863583, 0.03273355134297162, 0.029417783953249454, 0.018749591072264593, 0.02439988045807695, 0.01844338094088016, 0.015819606887816917, 0.08044120855629444, 0.02956473661470227, 0.011497338819026481, 0.037192526724538766, 0.02794005660689436, 0.04722027028037701, 0.042806877609109506, 0.04480301737203263, 0.051952511857962236, 0.06085096269089263, 0.03731240954948589, 0.03950622776756063, 0.04031279757327866, 0.101371287018992, 0.09642568169510923, 0.014423142856685445, 0.052758343226742, 0.037888794831815176, 0.046592027429142036, 0.022524623564095236, 0.08258928079158068, 0.03998854954261333, 0.011668270271911751, 0.03784962056670338, 0.04124921353650279, 0.031171953887678683, 0.04932264477247372, 0.0051200211601099, 0.03465594018052798, 0.02758379418082768, 0.04624214561772533, 0.035604831646196544, 0.03674714535009116, 0.030947079430916347, 0.00785018208262045, 0.06365483743138611, 0.047614951836294495, 0.033865693912957795, 0.10631419834680855, 0.04197796544758603, 0.01567750787216937, 0.047787708972464316, 0.04210129554849118, 0.03028525254194392, 0.03868121559207793, 0.07824490414350294, 0.03313305685878731, 0.028082615754101425, 0.05296055620419793, 0.012905081639473792, 0.016734964410716202, 0.020555581468215678, 0.03238038552808575, 0.02911355535616167, 0.023643598578928504, 0.021956676500849426, 0.07636025722604245, 0.013135697536199586, 0.0155056914081797, 0.05998545893817209, 0.015646454558009282, 0.03958343339036219, 0.06613497622311115, 0.08614417558419518, 0.07182215776992962, 0.09860749196377583, 0.035080162924714386, 0.07701276830630377, 0.06033998288330622, 0.06186815400724299, 0.02248757184133865, 0.02293253390234895, 0.04008838324807584, 0.012665418034885079, 0.024067556005320512, 0.04591779739712365, 0.05130653538799379, 0.0709363748319447, 0.033444647560827434, 0.009897034651658032, 0.046673723045387305, 0.018419461521261837, 0.033119033978437074, 0.07060510979499668, 0.036861988992313854, 0.03892564564011991, 0.03834949042357039, 0.061831354614696465, 0.02207921806984814, 0.026252705938532017, 0.04660258819058072, 0.07203137662145309, 0.030334137809404638, 0.05085955468530301, 0.07527409441536292, 0.023989257570065092, 0.014864915538055357, 0.003996070045104716, 0.022753802477382123, 0.03479855498881079, 0.04321395303122699, 0.05759615531133022, 0.07051539156236686, 0.012745579260808881, 0.07091970619512722, 0.03871997425449081, 0.020957357955921907, 0.0536389496846823, 0.0068047826607653406, 0.04009858406789135, 0.020010017578897532, 0.04128628010221291, 0.020563299804052804, 0.017287756818404887, 0.009829646714933915, 0.08447315587545745, 0.055296774007729255, 0.012359849861240946, 0.04074900229170453, 0.014893978968757438, 0.018800823381752707, 0.0429335176886525, 0.047546099085593596, 0.03143918642308563, 0.001901838188587135, 0.053971750967320986, 0.07287879794603214, 0.03733163117431104, 0.0823453813791275, 0.026452453130332287, 0.03582011013349984, 0.031231184693751857, 0.08263979136245325, 0.022322121149045415, 0.035053445608355105, 0.02947562879853649, 0.036940218778909184, 0.0666363415075466, 0.022439163403760176, 0.05346863421436865, 0.009209082309098449, 0.010556538618402556, 0.05266710359137505, 0.019411744506214745, 0.02598632316221483, 0.030961683041823562, 0.01541727007861482, 0.033070631106966175, 0.03927868528990075, 0.06470231950515881, 0.05962091228866484, 0.045022719059488736, 0.09688225094578229, 0.011291988412267528, 0.02401925332378596, 0.018676903273444623, 0.03641915689513553, 0.022908692408236675, 0.044975370037718676, 0.03591917200537864, 0.0182866115210345, 0.02007721534027951, 0.042482147182454355, 0.008873817096173298, 0.03681917820358649, 0.050531733213574626, 0.10570303973508999, 0.010872206494241254, 0.04274539809557609, 0.044884928211104125, 0.009951768042810727, 0.046241132586146705, 0.012903411807201337, 0.017417077906429768, 0.030951474800531287, 0.013178025928937132, 0.02284109388710931, 0.042992818998754956, 0.05252120106888469, 0.09943331679096445, 0.04796820670890156, 0.06748851999873295, 0.03602570359362289, 0.06606502138311043, 0.061077844657120295, 0.034544428781373426, 0.05396024396759458, 0.044208512554178014, 0.039619772651349194, 0.02107763782987604, 0.07530038870754652, 0.01841214208980091, 0.0463744557055179, 0.06087123816541862, 0.047746660784468986, 0.05007750543882139, 0.09055808404809795, 0.03737961102160625, 0.04083721767528914, 0.052370263074408285, 0.07420817739330232, 0.03370903395989444, 0.06690865033306181, 0.019960098870797083, 0.03443338493525516, 0.05648239573929459, 0.00732600503397407, 0.03277311894635204, 0.051470115868141875, 0.01597445228981087, 0.04744814672449138, 0.0697009290161077, 0.06463364115916193, 0.034488815945223905, 0.02778090118226828, 0.03848693988402374, 0.061703560495516285, 0.0656050605175551, 0.06420192643417977, 0.03487092923023738, 0.025204565208696295, 0.05472127188113518, 0.041388117606402375, 0.05879031174117699, 0.03090404785325518, 0.028516009588201996, 0.011773807382269297, 0.017393665002600756, 0.02320370724191889, 0.023436795418092515, 0.027229658007854596, 0.04395906929858029, 0.011880108904733788, 0.03125279974483419, 0.08531253974069841, 0.07301940524484962, 0.03463491142611019, 0.019207533296139445, 0.04082355102582369, 0.08895455524907447, 0.024470566313539166, 0.05615317160845734, 0.019278820291219745, 0.02388291894021677, 0.04908531336695887, 0.06821336821303703, 0.03604246870963834, 0.07883278900408186, 0.033595140266697854, 0.05264873914711643, 0.022812814349890687, 0.0076546164291357854, 0.026706685093813576, 0.013056080861133523, 0.05388895697251428, 0.0735418326803483, 0.022526879693032242, 0.028554855452966876, 0.03891685861162841, 0.014572099316865206, 0.024155613682523835, 0.025739963530213572, 0.055620561906835064, 0.06198668241268024, 0.0645133612852078, 0.05912155451369472, 0.040047520596999675, 0.03823791223112494, 0.06164435195387341, 0.02176120407966664, 0.04702396850916557, 0.03728096104168799, 0.04895931895589456, 0.027095401637780014, 0.037401177833089605, 0.050312684616073966, 0.039255693554878235, 0.04090771799383219, 0.034460332317394204, 0.084729055815842, 0.0346377649839269, 0.03432470482948702, 0.028251667717995588, 0.027782487522927113, 0.014555870402546134, 0.030812785953457933, 0.05985693380353041, 0.03389196965144947, 0.056531036098022014, 0.02225538351922296, 0.04661160157411359, 0.026296392461517826, 0.07659990413230844, 0.004280973116692621, 0.031246929356711917, 0.017835367179941386, 0.020228850953571964, 0.013070692821202101, 0.01627532452403102, 0.06553417057148181, 0.03504970889480319, 0.012883929503004765, 0.05888956286071334, 0.09566531429300085, 0.06649125905823894, 0.03313606255687773, 0.031421968596987426, 0.06482210956164636, 0.037026415520813316, 0.034254445708938874, 0.010867371402127901, 0.03078011290199356, 0.016749003989389166, 0.08704796302481554, 0.02874312904168619, 0.0471232901327312, 0.016548796666029375, 0.04213819884171244, 0.07494867750210688, 0.009435286137886578, 0.013894945223000832, 0.03978884131356608, 0.021124467348272447, 0.01770670474797953, 0.05031897802837193, 0.04558359716611449, 0.022319456838886254, 0.016374466176785063, 0.031089857511688024, 0.00626332748652203, 0.01299547986491234, 0.03486049463390373, 0.04931973926431965, 0.06317531355307437, 0.03176672958943527, 0.044652339129243046, 0.0366049164586002, 0.08657911123009399, 0.08753896050620824, 0.02664669544174103, 0.11543418397195637, 0.15914026997052133, 0.3202063834760338, 0.1349044727976434, 0.18053750070976093, 0.11911811598110944, 0.1155211785226129, 0.12439837795682251, 0.08922323497245088, 0.1170731800084468, 0.16957534127868712, 0.11126392259029672, 0.1929742778884247, 0.08464315222227015, 0.17778486013412476, 0.22528137633344159, 0.08954218777944334, 0.25961195526178926, 0.12859458482125774, 0.13283478619996458, 0.13575280696386471, 0.1459482981590554, 0.12830422696424648, 0.1836262154392898, 0.10591778016532771, 0.14339453831780702, 0.14540307194693014, 0.13146954617695883, 0.09642571880249307, 0.1975252610282041, 0.15116399328690022, 0.18659183755517006, 0.12379746840451844, 0.13927705847891048, 0.10385009736637585, 0.1510231039719656, 0.15144194243475795, 0.1241247406869661, 0.14045630145119503, 0.10311032456229441, 0.14424450520891696, 0.12565260753035545, 0.15882809297181666, 0.07707139055128209, 0.0870287191355601, 0.16421739128418267, 0.1336737841484137, 0.15630275738658383, 0.16167957277502865, 0.07867230699048378, 0.16071313322754577, 0.12032119673676789, 0.10067640672787093, 0.1297381304902956, 0.13207251147832721, 0.09263701780582778, 0.10644301291904412, 0.10404580170870759, 0.12853338732384145, 0.15265514608472586, 0.17598150065168738, 0.14029696234501898, 0.06769137864466757, 0.15941479039611295, 0.10122595966095105, 0.11683513614116237, 0.06181988101161551, 0.11112747873994522, 0.10152520102565177, 0.08462930374662392, 0.1529836651752703, 0.13921926001785323, 0.09914966794895008, 0.14794345828704536, 0.17638381890719756, 0.11469140546978451, 0.18932430655695498, 0.11857406236231327, 0.08205940961488523, 0.14828002225840464, 0.25524643482640386, 0.2160507216467522, 0.07135358799132518, 0.24111736798658967, 0.16510807239683345, 0.16536463284865022, 0.16390723292715847, 0.12188198525109328, 0.13005621498450637, 0.18719276937190443, 0.11906727144378237, 0.13750598242040724, 0.21007754607126117, 0.10333096506656148, 0.08097467172774486, 0.17616170895053074, 0.11283560583251528, 0.13272143056383356, 0.1649980415822938, 0.18788005749229342, 0.12058871870976873, 0.0950088030367624, 0.1509413935127668, 0.13279502192744985, 0.17413778317859396, 0.11488198899314739, 0.15521119174081832, 0.1417504288838245, 0.08223592201829888, 0.13228415715275332, 0.15693404304329306, 0.1694805541774258, 0.17269656207645312, 0.11788426578277722, 0.19056447985349223, 0.12191903326311149, 0.18689595483010635, 0.0943654055299703, 0.1543045396101661, 0.1745110092451796, 0.10820588082424365, 0.12961408792762086, 0.2366167469881475, 0.1680462498916313, 0.1171303253795486, 0.1517747066100128, 0.18576033529825509, 0.14719724364113063, 0.13294365926412866, 0.16790151625173166, 0.12200537472381257, 0.1103573149885051, 0.11136819433886558, 0.08263386160251684, 0.07672701918636449, 0.14630691875936463, 0.10774717418826185, 0.09685434619314037, 0.13652452180394903, 0.15211094403639436, 0.153807167080231, 0.11225936526898295, 0.09017077944008633, 0.12401430169120431, 0.15657359675969929, 0.16986865288345143, 0.11382500742911361, 0.16442072490463033, 0.10163774772081524, 0.10624844406265765, 0.11806515685748309, 0.13233373261755332, 0.08448586144368164, 0.2172538617742248, 0.18521260062698275, 0.04044469947984908, 0.11434604704845697, 0.16005581303033978, 0.0663898371567484, 0.13076216069748625, 0.19268063973868266, 0.1526452013058588, 0.15041452803416178, 0.10548461083089933, 0.19607108202762902, 0.11607479842496105, 0.14925507071893662, 0.10408911344711669, 0.11851659786771052, 0.14944449649192393, 0.08631133692688309, 0.1318403528421186, 0.13005937653360888, 0.14322978153359145, 0.19589013158110902, 0.1238896134600509], [0.06258414839976467, 0.021897540318605024, 0.06656448676949367, 0.05190694770135451, 0.040431819506920874, 0.07359588329563849, 0.05922595242736861, 0.039436759034288116, 0.06669598049484193, 0.05222128063905984, 0.036931383510818705, 0.05907747836317867, 0.11150632286444306, 0.05280510966258589, 0.01425450092938263, 0.0577841710037319, 0.045990041762706824, 0.030463683397101704, 0.01720739521260839, 0.08904946851544082, 0.04739338364743162, 0.009554276530252537, 0.018465454268152826, 0.032915867341216654, 0.027948489259870257, 0.07922664677607827, 0.02286483890202362, 0.046068779920460656, 0.03738067600352224, 0.05218240694375709, 0.06274852668866515, 0.08245402437751181, 0.059377517536631785, 0.01523914999779663, 0.005945074617557111, 0.037873039036639966, 0.05720716231735423, 0.02571897373854881, 0.01737053597025806, 0.03314331333967857, 0.05037184862885624, 0.022884452009748202, 0.06798457892728038, 0.04697431511885952, 0.03808206121902913, 0.01589365096151596, 0.013443230545817642, 0.05178451930987649, 0.044913066740264185, 0.006367669739120174, 0.03965818621509243, 0.006281348687480204, 0.03580544900614768, 0.022902951895957813, 0.05479251434735488, 0.086716015212005, 0.01879972500319127, 0.02500001632142812, 0.07705971656832844, 0.04039391060359776, 0.06017249499564059, 0.03167154914990533, 0.05466662754770368, 0.0777962536085397, 0.029562163217633497, 0.059413942144601606, 0.01977477346372325, 0.01752943906467408, 0.028714662112179212, 0.03472603602858726, 0.09605813305824995, 0.022859347009216435, 0.03395516723685432, 0.02851485369319562, 0.025175786577165127, 0.016504854102095123, 0.04365354194305837, 0.03950318867282476, 0.03846053055895027, 0.02956861433631275, 0.030479197994282003, 0.016681572451489046, 0.020681917267211247, 0.03300827585917432, 0.06540466580190696, 0.07976479289936833, 0.08054635603912175, 0.039110054494813085, 0.073313763277838, 0.04085505519469734, 0.0247532058347133, 0.08213758002966642, 0.019006424263352528, 0.05685242314939387, 0.04479916562559083, 0.10040243549156003, 0.07004616869380698, 0.023178233022917993, 0.03040755105757853, 0.04752028347866144, 0.03231189642974641, 0.027953778917435557, 0.051653303889906965, 0.06412238304619677, 0.029072733523207717, 0.0795402709627524, 0.08603104259236716, 0.03462217246124055, 0.03682662936626002, 0.03622716700192541, 0.0571681735891616, 0.039348291320493445, 0.009205315909639467, 0.01623197011213051, 0.0696957488253247, 0.01693743899522815, 0.03915138098818716, 0.04855559433053713, 0.06282448550336994, 0.018620080736582167, 0.031860993476584554, 0.012846387035096996, 0.044185331571497954, 0.06543940573465079, 0.014166025794111192, 0.054602732343482785, 0.04610310796124395, 0.06560101581271738, 0.05610162203083746, 0.041149765747832134, 0.05843370236107148, 0.04175595939159393, 0.016139023537107278, 0.008040933516895166, 0.01935729869728675, 0.0410574833949795, 0.032402616561739706, 0.010966818263113964, 0.05027141378377564, 0.02974695056764176, 0.03845521678158548, 0.011435347223596182, 0.06310883938567713, 0.07263764447998255, 0.048256056106765755, 0.002521007704672229, 0.03845433362585027, 0.02415920011117123, 0.045888768290751614, 0.08515033594449051, 0.02860113021597499, 0.011305676398478681, 0.0371602284576511, 0.07292674068594351, 0.03253623282944318, 0.026784217261592858, 0.019962136066169478, 0.08042591289267875, 0.030153046354826074, 0.05818000659928657, 0.009207308576151263, 0.055920701270224527, 0.005213513213675469, 0.020519075224001426, 0.01789766120054992, 0.04054776894918177, 0.02146859380445676, 0.01744606990541797, 0.01772826970409369, 0.0247841459713527, 0.028791635813831817, 0.051233968188171275, 0.010130119117093273, 0.0095709943343536, 0.055267648422159255, 0.056530947040300816, 0.06221359777555335, 0.03151505618006922, 0.027001980088243727, 0.11642562647466548, 0.10792791683343239, 0.043491267642821185, 0.05407346230640542, 0.042474113433854654, 0.006177238356031012, 0.07901176533778198, 0.03765019435377326, 0.02417006886389572, 0.0363354389264714, 0.023018571082502604, 0.040525474832975306, 0.0917190924519673, 0.04383079278341029, 0.01930692913447274, 0.04277200780052226, 0.03511171162244864, 0.07858911223593168, 0.03149381962430198, 0.03087946977757383, 0.08604109869338572, 0.012703833453997504, 0.09259098238544539, 0.07422477923682891, 0.020887826140096877, 0.07514366938266903, 0.0533069499215344, 0.03556403949914966, 0.03659336121927481, 0.0935496664897073, 0.03243567181925755, 0.03194000993971713, 0.04476802881981712, 0.10689418675610796, 0.03404849972866941, 0.015942911013553385, 0.04587036673910916, 0.027640568478091154, 0.11588466761168092, 0.026632605768099893, 0.05082600218884181, 0.03961710834119003, 0.04243952193064615, 0.03742714186955709, 0.02888558057748014, 0.036183372867526487, 0.01575362624862464, 0.028102284522901755, 0.026139084984606598, 0.0779710961796809, 0.019483170653984416, 0.02814417504851008, 0.05348507649614476, 0.05064379009127151, 0.032784596260171384, 0.07793516881065443, 0.07594883281853981, 0.023883811372797936, 0.0038941884758969536, 0.02887727037887089, 0.055483509495388716, 0.045086547470418736, 0.018397525491309352, 0.040895613565226085, 0.013088309551676502, 0.06912865152116865, 0.05149725249793846, 0.058700734516605735, 0.03522989863995463, 0.034613188763614744, 0.0076493388314702315, 0.03150055832520593, 0.012297321136429673, 0.01825353585445555, 0.03256348078139126, 0.03980749148468021, 0.029222090743132867, 0.026731663929240312, 0.036735367466462776, 0.0786563433939591, 0.04405329978908412, 0.034351314534433186, 0.06598142586881295, 0.06548187884618528, 0.02996177448949311, 0.030231979326345026, 0.10025477036833763, 0.08687130961334333, 0.05128293880261481, 0.02987957421282772, 0.050180240941699594, 0.023613074044988025, 0.06699767836835235, 0.02901165105868131, 0.042302907386329025, 0.09358292954857461, 0.02251396632345859, 0.03947542863897979, 0.01637687259062659, 0.030871827511873562, 0.03784316388191655, 0.06007769676216412, 0.01755230092385318, 0.019670169604069088, 0.031957301980583, 0.032713160835555755, 0.10683850341592915, 0.06811573868617415, 0.03150426535285078, 0.008016721876629163, 0.020966662632417865, 0.07940849522128701, 0.039172413453343324, 0.019586865382734686, 0.0392854017263744, 0.019401167046453338, 0.039666513112024404, 0.09478788793785498, 0.047670735366409644, 0.013677539554919349, 0.07971135826664977, 0.004636554622265976, 0.0647670347825624, 0.012726319600915303, 0.06177134455356281, 0.07138449844205752, 0.03567072322766762, 0.03189972245309036, 0.06370957824401557, 0.046135361699271016, 0.05029325147916097, 0.01389160834150971, 0.025508515500405338, 0.02025643287197454, 0.03214913602278102, 0.039248131070053205, 0.044162299018353224, 0.019822962967737112, 0.03955187727115117, 0.06661606603302062, 0.008362975513591664, 0.028139005989942234, 0.04555604864435736, 0.053870566553086974, 0.06222604359209072, 0.007961966221046168, 0.03826778367510997, 0.013181070589780575, 0.06653226271737367, 0.03694138395076152, 0.046916869177948684, 0.02079819139908068, 0.029593810249934904, 0.018700716937019024, 0.11077862480306067, 0.08906310176826082, 0.018897651389124803, 0.01122279056289699, 0.027224147561355494, 0.019415429269429296, 0.08729823748581111, 0.011002237260981929, 0.012009831680188654, 0.018639263398654293, 0.011169347581017064, 0.03856452400214039, 0.023454625516023953, 0.00339068139965093, 0.02065716849756427, 0.018317150897928514, 0.028103076765546575, 0.013467993230733555, 0.025245409306080546, 0.16291897423798218, 0.11416032459237613, 0.12673127464950085, 0.26739646098576486, 0.18105136376107112, 0.1524121520924382, 0.21469594590598717, 0.18707641545915976, 0.11769609423936345, 0.1335875317454338, 0.11995399690931663, 0.0924403041426558, 0.19098655408015475, 0.09262819366995245, 0.17711027758195996, 0.149449483724311, 0.14733237389009446, 0.16629221354378387, 0.1746567225200124, 0.22834751493064687, 0.15456258435733616, 0.10988946509314701, 0.20365096279419959, 0.12981273117475212, 0.07664040313102305, 0.13881199905881658, 0.19624910841230303, 0.15555345540633425, 0.21591099008219317, 0.2037781075341627, 0.13563375163357705, 0.2232245437335223, 0.18041001458186656, 0.08248111276770942, 0.15349108638474718, 0.21429477055789903, 0.13262953783851117, 0.12468696950236335, 0.2038194303167984, 0.14136828220216557, 0.13653166126459837, 0.21806594944791868, 0.14328467077575624, 0.1426801024354063, 0.09442327820579521, 0.16031747945817187, 0.125285541289486, 0.15253083634888753, 0.10907607123954222, 0.07775692720315419, 0.13883484236430377, 0.12307213037274778, 0.17534936894662678, 0.1269476700690575, 0.12250744504854083, 0.16780640260549262, 0.16311650426359847, 0.18408581265248358, 0.2482771486393176, 0.12522559060016647, 0.14668005576822907, 0.0776324764592573, 0.15418241178849712, 0.13574553391663358, 0.10544890610617585, 0.12235161630087532, 0.08152805414283648, 0.16081188339740038, 0.157382893958129, 0.14554219495039433, 0.19890991563443094, 0.137199861346744, 0.1837070204783231, 0.1040070912858937, 0.18943362490972504, 0.12326085852691904, 0.1338435133220628, 0.15579208557028323, 0.09671625477494672, 0.11698582922690548, 0.10589327444904484, 0.09219861633027904, 0.24880349461454898, 0.14906245371093974, 0.20193864998873323, 0.22693176433676854, 0.25850609585177153, 0.14268281869590282, 0.1227488879521843, 0.2095852795173414, 0.14795218594372272, 0.16073566483100876, 0.0892820575973019, 0.12566145393066108, 0.11302714672638103, 0.1938343231449835, 0.09315916322520934, 0.16381167399231344, 0.20452372846193612, 0.09412476414581761, 0.14529039908666164, 0.16245948092546314, 0.07782445522025228, 0.15974422974977642, 0.11320033430820331, 0.14575189619790763, 0.20982934220228344, 0.11647565464954823, 0.14648009149823338, 0.19495983462547883, 0.13109035324305296, 0.09050994092831388, 0.09669530394603498, 0.1382659119553864, 0.14146197092486545, 0.08798921408015303, 0.17290565476287156, 0.11972312961006537, 0.13049936620518565, 0.21211882325587794, 0.24792262469418347, 0.09007771412143484, 0.1306632175692357, 0.23254232655745, 0.09448134384001605, 0.16980899905320257, 0.09146469164988957, 0.14264214900322258, 0.14239370764698833, 0.19809621007880196, 0.18890113395173103, 0.11937686576857232, 0.10772896930575371, 0.13511058205040172, 0.18244814506033435, 0.1553457134286873, 0.09005662228446454, 0.15241529879858717, 0.19406824809266254, 0.2131999543053098, 0.10871405902435072, 0.08893258767784573, 0.24607182713225484, 0.1714846200775355, 0.165529256046284, 0.09145121424808167, 0.18371840502368286, 0.12354208796750754, 0.21852526464499533, 0.08193383080651984, 0.14720810868311673, 0.21131412737304345, 0.1898970070760697, 0.11981261035543866, 0.08076336744125001, 0.0713071518111974, 0.12117308579036035, 0.13349232904147357, 0.1377352318377234, 0.19593213713960722, 0.13951830100268126, 0.1445949770277366, 0.07714682986261323, 0.17846705712145194, 0.08762899044086225, 0.16494466632138938, 0.08459585515083745, 0.0705781698343344, 0.13512929901480675, 0.18025757744908333, 0.12424813015968539, 0.14331517304526642, 0.08311114419484511, 0.11170155965373851, 0.10487288076546974, 0.1221242593601346], [0.01788920442777453, 0.04961875056324061, 0.04678049583162647, 0.10396938276244327, 0.020585484453476965, 0.04635018376575317, 0.032051907255663536, 0.009301397130911937, 0.014906110300216824, 0.028084565747121815, 0.03766861445910763, 0.005773800849055988, 0.019704952210304327, 0.016398483930970542, 0.03531674847181421, 0.04329321069235448, 0.05662928531819489, 0.05529911177291069, 0.04491690364375245, 0.03507007713778876, 0.008527745285391575, 0.021684805542463437, 0.0358910742943408, 0.04346283967606723, 0.018520228477427736, 0.024515902259736322, 0.015787894917593803, 0.010730982285167556, 0.03146788527374156, 0.12163051593233831, 0.02516314409149345, 0.0626486781402491, 0.0437825643166434, 0.022910048683115747, 0.029545320176112, 0.01969458069652319, 0.04901274245639797, 0.023781949748808984, 0.016447957350465003, 0.029291262617334723, 0.02942561732197646, 0.03522250313835684, 0.06509583588922396, 0.044339590676827356, 0.03238585886720102, 0.046760491241002455, 0.008001556088856887, 0.013032020433456637, 0.04002594265330117, 0.049369927000952885, 0.10305186558980495, 0.05545690350118093, 0.039895087174954824, 0.07914751156931743, 0.021036827129137237, 0.06369945534970611, 0.0048521026019443525, 0.011150572172482498, 0.015411638105433667, 0.036286308750277385, 0.061812325948267244, 0.03655439104477409, 0.04547686890873592, 0.02941913280665176, 0.06554706909810193, 0.06839059307822026, 0.059751764056272805, 0.03079198726481991, 0.029280926355568226, 0.050598244488355704, 0.03073135008889949, 0.028845936903962865, 0.021675586212950293, 0.043232213574810885, 0.021876036589674186, 0.030749811012356076, 0.07167386182118207, 0.06199111303430982, 0.07763131870888174, 0.0394273337587947, 0.029639886488439515, 0.04361215978860855, 0.06788916842197068, 0.038327912479871884, 0.06426466759876348, 0.10006685115513392, 0.033970410950132646, 0.019731849497475196, 0.06426926891435869, 0.024284853134304285, 0.050383570851408876, 0.020309494575485587, 0.03522675935528241, 0.0067148190555599285, 0.024309616746904794, 0.003934440246666782, 0.015005676832515746, 0.04277183710655663, 0.03654621999885421, 0.0349011569051072, 0.0021886688728045556, 0.020081855618627742, 0.013287234814924886, 0.01239010536664864, 0.03492601514153648, 0.030937117953726556, 0.03796465345658362, 0.04147680054302327, 0.013101988261041697, 0.040892734032240696, 0.029961520303913858, 0.04164441088505555, 0.04042752247187309, 0.01670829162321752, 0.028630177876038942, 0.011525159152370179, 0.031137681507971138, 0.04421313984494191, 0.059794797489303164, 0.02352589766815072, 0.021283093992678914, 0.06675794982584193, 0.04014439684397075, 0.046764599028392695, 0.06150759640149772, 0.01993572117498843, 0.03449286065006163, 0.0352644085069187, 0.02923542713688221, 0.05516134689969476, 0.04038397324620746, 0.019029453105758876, 0.015160033344727708, 0.0484799101104727, 0.03422034773393534, 0.043118705798406154, 0.0995876315573696, 0.05386255135817919, 0.025484367870376445, 0.011793964113167021, 0.053140308082220145, 0.028537075450003613, 0.03063090411160374, 0.0160846408107318, 0.04143038662732579, 0.015743622097943444, 0.032513745754840784, 0.015401094970002305, 0.008073371864156798, 0.04545009222056251, 0.05126514210132882, 0.03247041175200138, 0.0460081946948776, 0.024083467651507817, 0.0478545505029615, 0.007055084024614189, 0.03161928339977749, 0.07583487604279071, 0.038576580191147514, 0.049622713631833903, 0.03807748216786422, 0.02016911548707867, 0.02538372893468477, 0.08383159147342667, 0.04559605040412862, 0.061951619645697065, 0.02267599385959329, 0.04929518901917618, 0.06764961057342589, 0.027136449825775344, 0.031345850220532157, 0.011031827616534429, 0.02603436052595498, 0.03947846402297728, 0.026792546013894025, 0.011389230166969355, 0.007553997438662918, 0.0016555230854464753, 0.016627121076453477, 0.010693336844269652, 0.015787954289407935, 0.01705735150608234, 0.05321582160831895, 0.01138455278123729, 0.03303451077954378, 0.022022623743396252, 0.08703143539605662, 0.021956568889436312, 0.054747039248468354, 0.03905457524524536, 0.03961942013120279, 0.05155072794877924, 0.056450134579790756, 0.07670704799238592, 0.03136913881462533, 0.05730757489800453, 0.029473927424987778, 0.016037486602726858, 0.05922542179177981, 0.037825471081305295, 0.04347720394434873, 0.03773138902033679, 0.023290377102966886, 0.03102182483416982, 0.0487074488773942, 0.06605981150642037, 0.024476566577504855, 0.05046798272815067, 0.1426548694144003, 0.07505952467909083, 0.03966928874433506, 0.037318999820854515, 0.11293927644146606, 0.0343835571402451, 0.0791078363545239, 0.05220951388764661, 0.10506324906600639, 0.049081532124546356, 0.02221775477664778, 0.05190715179196559, 0.019069150584982708, 0.022323030279949307, 0.05623593591735698, 0.011422780808061361, 0.05407557371654548, 0.01955021813046187, 0.0792653497774154, 0.058353075437480584, 0.01706031267531216, 0.10338048858102411, 0.038258989225141704, 0.01361437907689833, 0.039543802704429254, 0.04430862456501927, 0.052543031342793256, 0.014086987066548318, 0.05754056102887262, 0.005769892050011549, 0.06727688916726038, 0.009114095755649032, 0.07620130403665826, 0.07328962863539346, 0.02292214940098347, 0.04050684321555309, 0.03924623488273937, 0.02525682168197818, 0.052475462507572956, 0.027299638823023997, 0.04759362622280605, 0.04112472939596046, 0.03913380322046578, 0.04473853587114718, 0.011994324504485121, 0.0374892856052611, 0.0464620105776703, 0.030505225113302004, 0.021060061917523853, 0.014362922211148543, 0.037079890971654095, 0.016003282871679403, 0.037467392248800024, 0.06829959093010984, 0.03434440885030199, 0.009342825669591548, 0.05355378823878709, 0.02541562087571947, 0.05913811924983747, 0.06624711473705247, 0.08274916908703744, 0.02958365024824161, 0.04321427215472795, 0.03141556015179958, 0.04347661764768418, 0.02187015506933676, 0.028949067600478884, 0.08862717906595208, 0.03193163109244779, 0.04459248491912149, 0.060498847014969215, 0.019083219849562738, 0.03224540741939563, 0.05146201161551289, 0.02879593099351041, 0.03241407532186713, 0.02378863464400638, 0.04241230366460513, 0.035054362160735764, 0.044575037027243525, 0.016123002424137667, 0.08343928479007445, 0.04268946242518723, 0.0177669541517389, 0.06199277544510551, 0.03037638085515937, 0.05046212347224355, 0.03457353210251313, 0.02955254869448254, 0.03246343185310252, 0.02504487543774303, 0.05300010154314805, 0.01888774371764157, 0.01426691706001293, 0.05829697649460286, 0.05041812895797193, 0.01930783826537663, 0.013328840541362297, 0.08527328755008057, 0.04131272653467022, 0.062411465478362516, 0.06480332580395043, 0.014922044210834429, 0.02397553154878551, 0.07711383397690952, 0.003804410871453001, 0.04216667504806537, 0.020281858851376455, 0.0543232024210738, 0.03574417358322535, 0.05395284104452003, 0.03994945691374596, 0.019090147798124235, 0.08041721492190845, 0.06325638576527126, 0.02792624152789358, 0.02578651845396962, 0.04603897155902814, 0.07831546012312174, 0.015450835562660359, 0.048524268277105875, 0.03775068114919122, 0.018292789900442585, 0.07395002132398076, 0.03573552756279241, 0.08284718453069218, 0.025651709183875937, 0.03695037135912571, 0.03424452690524049, 0.04616540012648329, 0.05780167084594723, 0.04822820701519959, 0.0329136223444948, 0.03682490387291182, 0.041524702464812435, 0.056241353595396504, 0.026471914097783156, 0.02497245295671746, 0.0903371986350976, 0.02537069311074447, 0.030884944972058292, 0.030057595031394158, 0.06338871811749414, 0.029146256238163915, 0.12797161121852696, 0.16966148978099227, 0.11306396467261948, 0.11449821700807661, 0.07099285227013752, 0.1374293037224561, 0.12209400942083448, 0.0815396019606851, 0.11625689920037985, 0.1632299489574507, 0.20059359638253227, 0.06996970521868207, 0.20747655595187098, 0.11983701217104681, 0.13203644310124218, 0.12501198565587401, 0.18912318453658372, 0.1691443464369513, 0.13859291706467047, 0.21008811425417662, 0.14250655862269923, 0.054043735581217334, 0.130739287706092, 0.11137946014059708, 0.12705974921118468, 0.20547532505588606, 0.09425389784155414, 0.11215132341021672, 0.09717244553030469, 0.1780704385600984, 0.14284278120612726, 0.1276033723843284, 0.2406360555323772, 0.10746945510618389, 0.074351352523081, 0.09928910265443847, 0.18818364042090252, 0.15995361929526553, 0.12556865578517318, 0.13603077095467597, 0.18485601351130754, 0.09995236003305763, 0.1717183817527257, 0.15897106030024588, 0.10457285272423178, 0.0963662208232563, 0.10687265705200844, 0.10581189053482376, 0.2234799909638241, 0.09158637418295257, 0.13423461030470207, 0.10272371015162207, 0.07233080352307297, 0.2774768747622147, 0.17169826955068856, 0.12614336010301486, 0.09577538963640109, 0.13966748752864078, 0.12682092608883977, 0.1320570005918853, 0.13753408013144508, 0.2262434668955393, 0.2559643588028848, 0.13590095448307693, 0.14249619824113324, 0.22102829127106816, 0.20778211299329996, 0.11544866327312775, 0.1754135498777032, 0.08315919083543122, 0.14573441119864583, 0.150165849190671, 0.07984935320564546, 0.0857876478403341, 0.13766256073722616, 0.09575723670423031, 0.1757455719052814, 0.1610974024515599, 0.15204459603410214, 0.21062860556412488, 0.09879250937956385, 0.15150984894717112, 0.15352605638327077, 0.12828825594624504, 0.10650859650922939, 0.28889514331240207, 0.1452285930281505, 0.10743588034529239, 0.14131085481494665, 0.10565336036961526, 0.10904458933509886, 0.11341075543896295, 0.15556936705252156, 0.10769612184958532, 0.1077206053014379, 0.1780369528569281, 0.09025703926454298, 0.11015519106877036, 0.06993914357735775, 0.13205633265897632, 0.13460244837915525, 0.12713283591438085, 0.12531585060060024, 0.2558010269422084, 0.13839608465787023, 0.1895119363325648, 0.09549259426421486, 0.1398486309335567, 0.15193720726529136, 0.16329919133568183, 0.1360436249524355, 0.11171667720191181, 0.07019185970420949, 0.18871627980843186, 0.1605012797517702, 0.1993339046020992, 0.14841871481621638, 0.09741041518282145, 0.14185450767399743, 0.07310876724659465, 0.17867398273665458, 0.14859589515253901, 0.09114432134083472, 0.1133943020249717, 0.14801345765590668, 0.07791688229190186, 0.09865023966995068, 0.16475161886774004, 0.10391070114565082, 0.13689480896573514, 0.1638110654312186, 0.13581672072177753, 0.17384907288942486, 0.10876778309466317, 0.13105992518831044, 0.08647779322927818, 0.22890509048011154, 0.205698384961579, 0.14004360797116533, 0.1340290205553174, 0.19570468371966854, 0.1191866681620013, 0.175398365536239, 0.16212928458116949, 0.18366669217357412, 0.1268791253096424, 0.12906574469525367, 0.11881505997735076, 0.1013341944781132, 0.19375767413293943, 0.17300934763625264, 0.1466950768372044, 0.12085707930964418, 0.13489127741195261, 0.07367903352132998, 0.14403397275600582, 0.10077670056489296, 0.18380447931122035, 0.06563780407304876, 0.15886086621321738, 0.10507812170544639, 0.09187472081976011, 0.10144431435037404, 0.18098765780450776, 0.10295482978108339, 0.1346318077412434, 0.14724612148711458, 0.12369951233267784, 0.16728115500882268, 0.11348968284437433, 0.1695658714743331, 0.05421152032795362, 0.10547431724262424, 0.11855635471874848, 0.12468147760955617, 0.11228315852349624], [0.06499098526546732, 0.059407570806797594, 0.03630439859989565, 0.013562585518229753, 0.011450155852799071, 0.08089920273050666, 0.04303865403926466, 0.04603045170370024, 0.03641587660240475, 0.022957972869335208, 0.0026179301039519487, 0.04209534352412447, 0.0421699887374416, 0.08820927570923232, 0.04513844585744664, 0.01777585992385866, 0.04790869388671126, 0.11620990640949458, 0.07518215716117993, 0.06549779049237259, 0.06725598286720924, 0.05372451931179967, 0.06605581133044325, 0.08994592353701591, 0.05809666712593753, 0.08457112679025158, 0.026674607615859713, 0.03814876916294452, 0.04589250500430353, 0.025683358071546536, 0.010306266940460773, 0.02206196128099691, 0.03349340295244474, 0.01939890720677795, 0.013688612398254918, 0.05315963731845841, 0.05792425508843735, 0.06227815349120647, 0.04473028318898287, 0.0072079785059031565, 0.018689523494686, 0.0153849838716269, 0.03260088502429426, 0.046684680855832994, 0.02646683409693651, 0.06947192450752482, 0.03815690681221895, 0.031177913333522156, 0.05101618866319768, 0.06860001230961643, 0.0541974714724347, 0.017957892050617374, 0.0728356940089725, 0.08811525302007794, 0.08110111142741516, 0.058669452992035076, 0.020721204709843732, 0.025036524421011563, 0.06762376899132505, 0.03418916639930103, 0.06475801768829115, 0.02850607779691927, 0.022514018273795955, 0.08870408782968298, 0.038450337160611525, 0.0034477486133255297, 0.044551800383487716, 0.06032899909769185, 0.07932248772704042, 0.02076127511827508, 0.042824904376175255, 0.0852785048482474, 0.04097892335266806, 0.007908365532784956, 0.04488968166697305, 0.021417328098323196, 0.07860049678129144, 0.050504455575719476, 0.030480242567136884, 0.02941773200291209, 0.03558828917448409, 0.04598467603500467, 0.05422618516604416, 0.044942834283574484, 0.04678692654124461, 0.018263925921928603, 0.06592025063582696, 0.03548500077158678, 0.03792718984186649, 0.029720929014729336, 0.145517036144156, 0.00860552885569632, 0.03221454520826228, 0.06882717629196122, 0.04490999424888287, 0.04077381228853483, 0.0035905106915379292, 0.021963799263176043, 0.026807442773133516, 0.060806489491369575, 0.09633234178181738, 0.0418556929071201, 0.06705501669785008, 0.02391056579654105, 0.06647961476119235, 0.01557274445076473, 0.07935476372949779, 0.025094536249525845, 0.05249286587059032, 0.06106981461925898, 0.04574925565975718, 0.00440889803940081, 0.013222564066381892, 0.038411411514971405, 0.04879270680248737, 0.06976997101446614, 0.07402995805023238, 0.043250655944575556, 0.06876944462419488, 0.04134937007620465, 0.025955529599741567, 0.033938955020857975, 0.061270498772501014, 0.026067107792187016, 0.06632564138271846, 0.0344152060279157, 0.011253944994678022, 0.08640207190182991, 0.02678403543541208, 0.03827088214165997, 0.07152820049668662, 0.04455195623449981, 0.018158095663238782, 0.11134164771647193, 0.05200577950745355, 0.016265324084088206, 0.02672863040061202, 0.030544173023372423, 0.020535998046398163, 0.03450572206929792, 0.029428454181470443, 0.11569621405215003, 0.025335288955830038, 0.023595093662152067, 0.02751067964709364, 0.03677097942272667, 0.011104970908490941, 0.028916830560774542, 0.02931485363660613, 0.0910930908867158, 0.050586551951710135, 0.052018945207237266, 0.03222405954147689, 0.0294319385648123, 0.09390030158101581, 0.05669864272931591, 0.047695456305518746, 0.03857991243421566, 0.03972821526986081, 0.04914986166113522, 0.009511199496046174, 0.01741929507261375, 0.07374481006991118, 0.03361632116138935, 0.02306722442881437, 0.04044101471663453, 0.06585598064702936, 0.012525860875030048, 0.02030062776611885, 0.016579697839915752, 0.040275634528370574, 0.03304958008811809, 0.041306492494186386, 0.014790413188165985, 0.03710485310875811, 0.026322731282562017, 0.07201254833489656, 0.03539216180797666, 0.04277285755961202, 0.01651781756663695, 0.022382877068594098, 0.009770577325980412, 0.08020070075872354, 0.0053648552147933515, 0.0424966116406722, 0.10240295392577536, 0.0542483531171456, 0.029307706754480023, 0.041394006548216566, 0.031001161587482784, 0.046754387076362036, 0.056543385435361415, 0.0536371573980432, 0.06752072178642265, 0.08386834262637421, 0.040092780473059975, 0.01978693911951268, 0.02930761027528206, 0.02278974097862374, 0.04023718756798189, 0.10625280789099634, 0.06302712150500156, 0.05029607535107061, 0.027574046071094926, 0.037070343241794035, 0.03334097324113827, 0.022463632012659218, 0.02721565182582708, 0.013917013911850518, 0.05627478734822944, 0.044216386741027236, 0.05898207899008412, 0.05394229512603488, 0.06576517145731486, 0.004251311329426244, 0.08706524022272788, 0.021371884540712927, 0.01298386525377282, 0.0404412856005365, 0.008889341897884151, 0.05696340020222124, 0.0660824024816975, 0.02116593484970508, 0.04029153133160435, 0.060082517011323944, 0.07256694007082842, 0.03572160116164014, 0.03244063307647593, 0.0355462576408172, 0.07236039295094088, 0.049946171275223605, 0.026852745322685223, 0.04983417005860247, 0.04603611057973467, 0.020664667899836786, 0.0796916765102651, 0.04615029742126353, 0.036707433027913794, 0.017540866283525247, 0.07061871336190961, 0.0227541178901447, 0.010895891209656838, 0.024713395177968778, 0.014386177408596268, 0.01816894957300974, 0.03371650367625989, 0.059944132444798015, 0.058161682973150164, 0.0387046377727529, 0.0194190361071378, 0.020161653192189988, 0.05121613809023984, 0.034397869458189234, 0.027213451357965823, 0.01726842201605905, 0.05247007080470212, 0.06000642089929897, 0.06637527621933259, 0.02335653771297075, 0.049508003576193005, 0.038591879565501586, 0.024152778678399045, 0.0013229488536126155, 0.0449018862855155, 0.007507057061957312, 0.06362245752825402, 0.013089186213619541, 0.026414510830363724, 0.012538982973637758, 0.04045213951030746, 0.041209968767361715, 0.026158915170526598, 0.006544572233906365, 0.05515140583156608, 0.05547313798160758, 0.08315739483805373, 0.059780978699564, 0.07104516625986435, 0.10420842852909118, 0.030158679255691823, 0.022248023269639816, 0.037060016256873496, 0.019782649505941663, 0.05231250914221164, 0.01937737008120166, 0.04882681962044444, 0.025292010614066385, 0.046140790509525687, 0.05993811362714041, 0.08658004633616656, 0.02006265254749451, 0.02540287077863468, 0.037690752724302, 0.015565154135401826, 0.018291071828571148, 0.032861979998415336, 0.07753147016046569, 0.04557291395030916, 0.010450342851981986, 0.031375261532957666, 0.06852705919300206, 0.03827615139016416, 0.015539970281679416, 0.0566368515137583, 0.021755938541900832, 0.07074944267515093, 0.012540442221506964, 0.027782452270912472, 0.04354442768089939, 0.04664535816118587, 0.021793383602926042, 0.03240155157982372, 0.04522690243902616, 0.0686816188681405, 0.020365758646221366, 0.02593846948002465, 0.048425243512610905, 0.025998618693847675, 0.03644504300609697, 0.003525476058712229, 0.017766327036952134, 0.009976558558264514, 0.022806019987910986, 0.021919229584455024, 0.020980895169486757, 0.03665651427581906, 0.03008196159498766, 0.04421614183229394, 0.0249731301664724, 0.027359507876099087, 0.027369658600946423, 0.04883690540737007, 0.012365803740976844, 0.04505890989094041, 0.00939044000915601, 0.02680283403606154, 0.02437243027088698, 0.0450786547298776, 0.07311441499041393, 0.044345728238113225, 0.052209833011147566, 0.01723093428154243, 0.009174321039608913, 0.012330451536399778, 0.04007643095974345, 0.02983990456414176, 0.04872812511166558, 0.032409384948550723, 0.0581837841309607, 0.034844471665564924, 0.06179763513500802, 0.055794098298065364, 0.15898222220130265, 0.09586513013346121, 0.1449566552764736, 0.13418154674582183, 0.12426202316419221, 0.14883077004924417, 0.18938652821816504, 0.23954468284500763, 0.11378617084119469, 0.15157411893596873, 0.1627301421831362, 0.17189844162203372, 0.14093096426222473, 0.290950239286758, 0.12176134914625436, 0.14123364177066833, 0.14085407776292413, 0.17240078654140234, 0.10802121963934042, 0.13574353011790663, 0.12533306842669845, 0.19812841928796843, 0.09029257329530083, 0.14688132621813565, 0.16510787943843752, 0.1762972548021935, 0.11487467883853242, 0.08168278451194055, 0.1405467840959318, 0.1408665903727524, 0.1049848337424919, 0.09507067588856444, 0.08469045671517961, 0.09072845889022574, 0.10371882628533058, 0.17143403529189527, 0.11282423613010906, 0.2518615289591253, 0.13525604299502447, 0.15707659476902336, 0.09521763597149402, 0.1269211753970012, 0.11004593208781444, 0.1281176955671981, 0.1216148491948843, 0.08936927479226142, 0.09815113051445223, 0.12052713529556058, 0.2060838564648293, 0.17242413450730965, 0.10613440565066412, 0.14754712174180895, 0.1380428223637864, 0.17012758820783347, 0.11370313193765469, 0.10279242560500279, 0.10241226045764051, 0.13084002683172002, 0.21327882976038381, 0.13874376600142568, 0.1276344683719799, 0.1363296338240616, 0.09815653334953822, 0.18310135375941172, 0.13491014280589297, 0.08603277179645374, 0.12061620043823496, 0.2485438616713509, 0.12200731172924861, 0.10270058483001776, 0.1336344057926908, 0.17316600016783923, 0.10669874958693981, 0.1062630643718876, 0.11647781429928727, 0.1142012540367432, 0.14325777534395456, 0.12197968899272382, 0.13990173902129754, 0.12224669146235101, 0.13800773362163454, 0.12983921100385487, 0.1070650365727488, 0.24077097797999159, 0.0959200416400563, 0.1539993387996219, 0.12583136121975258, 0.1528531510848552, 0.09821108862524852, 0.1264129823539406, 0.21131430548848584, 0.1540891089825891, 0.1615557083277963, 0.11124718716018833, 0.1677526711137034, 0.12881587841548026, 0.06767046492313966, 0.11238111459533684, 0.10977744532283396, 0.27315941581036896, 0.21292565652402118, 0.14060219284147024, 0.16445885645225644, 0.09648972161812708, 0.1346097214263864, 0.1462623750558123, 0.14398766274098307, 0.16282053577015176, 0.12095242302166298, 0.14933022059267387, 0.12924262817250565, 0.1121719551156275, 0.18179636128479615, 0.1560948372934945, 0.1200864183192607, 0.18082014023093507, 0.14117253333097324, 0.07309022839763202, 0.12314983323449269, 0.18816523515852168, 0.17608048830879852, 0.18423885834636167, 0.133076770871412, 0.08339479303685948, 0.2160631155129522, 0.14425280241994187, 0.1284332716022618, 0.2510300267022103, 0.13488939235685393, 0.15093222056748345, 0.16182366816792637, 0.18001160002313554, 0.1245103903056588, 0.22716721810866147, 0.17089762579416856, 0.12310262522078119, 0.18817728763679042, 0.17850386764621362, 0.10467584055732004, 0.12829024490201846, 0.12074730824679136, 0.17899919184856117, 0.09353050423669629, 0.0869479140965268, 0.15667907078750432, 0.17705803038552403, 0.09497482009464875, 0.0868612238264177, 0.07324820195208304, 0.21015740116126835, 0.10376723657827824, 0.22858786687720567, 0.16957007203018293, 0.1312883582431823, 0.1230513205518946, 0.1630284558632411, 0.11685790523188189, 0.14009437087224796, 0.09916664086631499, 0.17812238889746368, 0.20377001812448725, 0.14677640137961134, 0.23853227467043325, 0.1909027952933684, 0.1957279723137617, 0.14045830524992198, 0.1299563961219974, 0.106171305233147, 0.09899732729536481, 0.11120813534944318, 0.11229380834265612, 0.1378099067369476, 0.19984061334980652, 0.13469438563333824, 0.11605470106587745, 0.1210444419120904], [0.02359654456085991, 0.015150497674767394, 0.03052460258913925, 0.01878780240076594, 0.04366703418781981, 0.04872114150202833, 0.08406513792579062, 0.03524082676449325, 0.02386832275078632, 0.12242891098139808, 0.051069036999251693, 0.03320579475257546, 0.07298692886251956, 0.013501723842637148, 0.04171691500232555, 0.019773697349592112, 0.03850980174320284, 0.035006167090614326, 0.06388496258296072, 0.02413957772660069, 0.07328113846597262, 0.04648721020203084, 0.07861303907702677, 0.027003627656085882, 0.04792761865246575, 0.04718300704553258, 0.016454044816782698, 0.0012239477450748382, 0.014797869916947093, 0.034366253967164084, 0.0658173295960296, 0.054735313315177336, 0.011989776066911872, 0.020444309411686845, 0.031799128046259284, 0.051894924908992834, 0.1262386073358357, 0.0608655978430761, 0.021418266915134154, 0.05063269127276726, 0.10082490305649117, 0.030730034632142633, 0.04807640812941827, 0.053479877751669846, 0.06312262106803246, 0.04383678562589921, 0.0500752678635763, 0.014498301079584053, 0.0783989072078839, 0.06992412250838242, 0.06580823828699067, 0.07131612437660806, 0.015296640467568068, 0.028090649502701126, 0.017443277574784588, 0.041037029805011116, 0.04047508671646938, 0.03494296208373271, 0.041133093400276266, 0.039787742935004644, 0.11182304180692881, 0.046522369448211975, 0.028730406775139272, 0.036054235461051576, 0.035597499227151275, 0.08281516085844487, 0.08593471924541518, 0.0869531165517401, 0.012841214265790768, 0.030423334683291614, 0.025266285920224618, 0.04124352868529968, 0.024881692006601952, 0.029130890070518944, 0.05012203058868181, 0.03933734093152452, 0.0849300813570153, 0.058944055053871125, 0.050985311609110795, 0.03612554843130056, 0.049754021820263006, 0.05171956654521637, 0.021421998062578496, 0.06576931264135055, 0.039486609093728475, 0.03866861392452847, 0.04053075521369465, 0.009608931068214588, 0.009163867889583344, 0.05011266839574091, 0.02307489081431413, 0.03454686673649121, 0.028822598214901518, 0.013851981366315158, 0.027190103392058518, 0.049437462439527735, 0.03823926665063482, 0.05228007728874218, 0.016910202175495215, 0.03434091333474498, 0.02163256205676589, 0.05737069084716495, 0.060893818008480594, 0.021671663962479215, 0.04965265186910983, 0.0326996055082418, 0.01919675174576696, 0.09151771810138598, 0.043357499234844, 0.059300434368196875, 0.00576029097828723, 0.03711496487085242, 0.06430820198147558, 0.07355283873039298, 0.05674314932548441, 0.037140517015359364, 0.02013295434153406, 0.09103199728997424, 0.013839483599440427, 0.016152688331203535, 0.056053508596960455, 0.07554186871857382, 0.03559905402653385, 0.009612525846023345, 0.009309809374826727, 0.11463577407994308, 0.011502322340675164, 0.01422130095306784, 0.04188225808320567, 0.017481546419730876, 0.026788265677168965, 0.03484126558760181, 0.036180604656692594, 0.06027358664141502, 0.05252065930108074, 0.035463233580230735, 0.025648035552876536, 0.013830361676809844, 0.027977221507171635, 0.0541020387026947, 0.020419026295712683, 0.04102277314814273, 0.009934783065546071, 0.007842467457521707, 0.0176659441422089, 0.009306729461968644, 0.033669804033706896, 0.006744992460880894, 0.04944837943185121, 0.04591226468619425, 0.004460848840608378, 0.02313676552148536, 0.09501231339527294, 0.07989798614289612, 0.05921337302424945, 0.03739435378520284, 0.0174145694472827, 0.10315828956663609, 0.04690898014814593, 0.01027072363285697, 0.06869059885502793, 0.028334083217487205, 0.029119657665432896, 0.026107458361366298, 0.020199714235786814, 0.15484293806366622, 0.016822320758365095, 0.07774476340273395, 0.0042145615680055926, 0.12493066111346707, 0.01893176606245106, 0.025530191778670996, 0.03901833246345632, 0.07708261924562976, 0.025946911409846507, 0.02648452133144019, 0.02779861810267903, 0.11930927095818333, 0.02616384117573034, 0.015304948810808128, 0.043403924282756634, 0.022197139769559726, 0.017730182589730248, 0.036991297092754394, 0.023290963399631437, 0.05173583442228846, 0.04554385886876844, 0.07885448940214701, 0.014588664980692556, 0.03720071632415056, 0.006751030759915011, 0.01581887401698623, 0.033984778929152526, 0.03221211467462126, 0.01104134844354121, 0.026627961779013276, 0.044709855574183166, 0.08843955671181902, 0.03925448014342692, 0.014067978809180204, 0.06388294394128025, 0.01359612502710661, 0.013687511236639693, 0.024268594534078147, 0.014350089550134726, 0.0399411040416453, 0.013652048637595726, 0.02188984795793658, 0.0124342455274018, 0.035682326706591994, 0.08400646373047493, 0.0826987401524093, 0.10913913894910365, 0.03805771506449673, 0.012606443269760348, 0.018855387934308965, 0.09193446370773017, 0.0059623471770464676, 0.071599468938075, 0.018669812052394263, 0.08990338363219053, 0.05740011329180561, 0.08148739929310977, 0.11263950073043816, 0.10345991322537884, 0.05438706051791087, 0.031649633529013954, 0.022243761486606672, 0.03526241212966852, 0.01835293911426561, 0.03291519940830767, 0.03833128554106224, 0.039185968780657277, 0.03684618495753966, 0.012843398963013897, 0.02616307305288501, 0.04083873536728788, 0.04286334391508717, 0.04183610391919501, 0.05095627137052361, 0.03906376674422063, 0.008197673250833759, 0.02269732503918931, 0.05621512980724219, 0.02092021346470574, 0.03703082758875098, 0.05208050264627673, 0.037455310084624216, 0.03694633036502637, 0.043716041909647174, 0.024489559727953747, 0.05575212613621261, 0.014741441646037856, 0.0189839446102269, 0.023454731272067875, 0.023756507071084343, 0.033916898391908035, 0.059148631771677174, 0.042542131268419325, 0.06972095216042362, 0.010898123218794353, 0.027259399575996213, 0.04370107650174759, 0.021666361317329574, 0.06119273282820359, 0.021580051397904754, 0.034148340855608694, 0.021955978882033378, 0.005567307998717297, 0.04138235482969321, 0.039912438587634824, 0.020228841676726006, 0.020616361507563852, 0.023312858611461706, 0.053077225529705174, 0.03493516953312792, 0.007652478116142447, 0.033780165103962645, 0.0026768603402160807, 0.04756287162308581, 0.04533575694949832, 0.04829497433092911, 0.07193570636445656, 0.024541602833778597, 0.04062206906382926, 0.05280356970615685, 0.011802758563135285, 0.017770445956557523, 0.04633160038792994, 0.021639575352310203, 0.10167720029130578, 0.05592669411271345, 0.018199329388153274, 0.02815171526890481, 0.03913833403203171, 0.021402568636403885, 0.02325763169210404, 0.07148868855438195, 0.03824378261924721, 0.005303298703438486, 0.03552693211531732, 0.00996820475847926, 0.05559776684094686, 0.006148367883724859, 0.03139615299005527, 0.0385318101325538, 0.035840567434206605, 0.07266289976541884, 0.05320388787367847, 0.052022147574462, 0.03403403898118995, 0.05546477026655339, 0.07654554923647083, 0.034416104026604444, 0.09157230306300335, 0.05663766416546423, 0.01974920462089358, 0.03744302754057571, 0.027313581922498997, 0.022576334558834787, 0.011909922832273878, 0.023059322411427274, 0.09282966449973173, 0.055967727457755245, 0.05398955137934536, 0.030527684357366525, 0.03209787959349342, 0.03261042533267755, 0.06214645938598551, 0.06469495740020648, 0.030745278345420957, 0.018922489216492977, 0.05549277149839327, 0.11106982128694654, 0.057004296249942854, 0.028988904232392088, 0.0236983542345115, 0.019717524191946723, 0.021661015998688526, 0.021362047373258974, 0.05095919914310798, 0.05285314517095685, 0.04018651743535884, 0.05916043934121262, 0.03309110696136486, 0.03277998752309941, 0.022236683253140654, 0.02005570975597948, 0.011239484247198561, 0.055958925586310215, 0.019435406029515434, 0.03275812014180701, 0.08330978744197637, 0.15134433517232537, 0.12397188053000718, 0.07226180605357513, 0.11240642183111049, 0.16204214160097763, 0.2636865834938362, 0.1630224593100138, 0.05802952131489292, 0.24036815506406128, 0.11395479421480559, 0.2067914349026978, 0.23569434648379683, 0.10471055822563358, 0.12561135896248743, 0.07198304054327309, 0.11088273327914067, 0.10851680359337479, 0.1335981147713028, 0.12371583958156407, 0.12939365522470325, 0.18216114171082154, 0.1340287088532932, 0.13260182604426518, 0.16535117028979585, 0.2310264008701779, 0.11787635448854417, 0.08036064842599444, 0.10653946243110113, 0.1259086187928915, 0.1572724326979369, 0.13914629205828533, 0.1388339517870918, 0.1115333593043033, 0.09685173383331858, 0.16401913395384327, 0.31023833085782826, 0.13043897022726014, 0.12439981030183844, 0.13415159366559237, 0.27090171352028847, 0.08247760983067565, 0.19161666714353487, 0.23847800883231685, 0.28902677062433213, 0.14911988109815866, 0.13001324463402852, 0.17789095756597817, 0.20980879955459386, 0.16614581749308854, 0.16500080237165093, 0.19910673319827765, 0.1479904362349771, 0.10726246269769035, 0.1611148429219611, 0.16425659152446315, 0.17444240511395037, 0.10587237557047047, 0.11495917235151865, 0.2112823337665759, 0.24526806635549292, 0.15890931361354887, 0.11230834701564163, 0.16199825098738074, 0.10623141919495538, 0.15581326646497473, 0.14961323118768632, 0.1362402644008398, 0.057943324572988786, 0.14514495298499241, 0.15049641660880297, 0.182939684309531, 0.1122215305804275, 0.08900217144400813, 0.18339981586905196, 0.1350326565443538, 0.17566406924743205, 0.09112095111049712, 0.11164902301970869, 0.09842064144322649, 0.10599505258142017, 0.12871749931946397, 0.09867341694189236, 0.13469592930050567, 0.18218429671833292, 0.09116345390793867, 0.12765373452566564, 0.11195138140465133, 0.10420814651297405, 0.1175973292265553, 0.08078659666352905, 0.07507867208914831, 0.12119072664063424, 0.10431272254209034, 0.10448723114677705, 0.11777975654695183, 0.10679289101972245, 0.1269111267174594, 0.15202673996100202, 0.0954168506723363, 0.09752581172506325, 0.16855625377502292, 0.10755215262179263, 0.11079691874329001, 0.2113757998449728, 0.08358643783139996, 0.15327908447943628, 0.1918381536961533, 0.1210621272912249, 0.2001621265662834, 0.10824085824424401, 0.15138074493734166, 0.14704103639815003, 0.09907016166835092, 0.2327098441310227, 0.08049213472986594, 0.06706668325932696, 0.11970889521762729, 0.07182738248957321, 0.0478427318012109, 0.16575120273046196, 0.17519445304060355, 0.11697054098476656, 0.12576176261063665, 0.13068500702502206, 0.15292362542822957, 0.29368609248194844, 0.07710129910265096, 0.20854291826253757, 0.11560176833881997, 0.21102523896843195, 0.12015774613246322, 0.11171221689437516, 0.13460290851071477, 0.06916258251294494, 0.12062376292305999, 0.18180655839387327, 0.14354354672832415, 0.21087893197545782, 0.12919259257614613, 0.09572348382789642, 0.07429418488754891, 0.14330107223941013, 0.1042174753092695, 0.1437291578622535, 0.15241660497849807, 0.17243157082702965, 0.18528258515289053, 0.1651704721734859, 0.12803683115635067, 0.1704965840326622, 0.15007257607067004, 0.16366515919798985, 0.17988927924307063, 0.1753359954454936, 0.10946416994556785, 0.18383995397016406, 0.24624538578791544, 0.13935529568698257, 0.1343464371166192, 0.12365328395389952, 0.16110197408124804, 0.100795194884995, 0.13868809008272365, 0.12783323036273941, 0.21306290931534022, 0.11285188855254091, 0.11204216832993552, 0.14556094160070643, 0.14887317636748776, 0.13123168784659356, 0.14673702302388847, 0.11777053907280788, 0.12004382646409795, 0.1210225337126758, 0.1111603261961136], [0.05452271769172512, 0.0015436827061421354, 0.023144140614022035, 0.017970078115467913, 0.01754772001731908, 0.016885679760889616, 0.04710305918706581, 0.0384898045740556, 0.036614078271668404, 0.01293822038860526, 0.020188355665595736, 0.11541500687599182, 0.00994010148133384, 0.029730335736530833, 0.028770204444299452, 0.056878112591221, 0.016007472295314074, 0.030694999695697334, 0.04461865304620005, 0.09227617818396538, 0.009403943386132596, 0.05720312874473166, 0.022403210059565026, 0.058113795894314535, 0.049872609597514383, 0.01444086256014998, 0.041249618006986566, 0.03426709561608732, 0.11194419741514139, 0.014860272476653336, 0.01859694984887028, 0.05790510396764148, 0.04436297946085688, 0.029728545305260923, 0.04745775382616557, 0.07055084395688027, 0.05736359962611459, 0.08230071151047014, 0.03100316724157892, 0.10395248405984603, 0.03748352282855194, 0.03684300114400685, 0.06339236206258647, 0.08213868582970463, 0.02385688068898162, 0.06963883352000266, 0.038359516838681884, 0.03945743155782111, 0.04505162942223251, 0.012593256233230932, 0.02055022316199029, 0.02414640548522584, 0.01618226848222548, 0.04852879166719504, 0.03698885171615984, 0.029602545328089036, 0.012751559115713462, 0.018669207202037796, 0.03314557689009234, 0.0500058622128563, 0.041415476880501956, 0.041547067085048184, 0.03386019459867384, 0.03352921157784294, 0.018748284892353695, 0.06806951030739583, 0.024360327697650064, 0.02461145748384297, 0.046950195319368504, 0.026544267930148635, 0.03967241689679213, 0.03356550630996935, 0.015206112366286106, 0.08110027280054055, 0.06435722083551809, 0.029395632700470742, 0.028064911821275018, 0.045157363201724365, 0.07141726426198147, 0.05470703006722033, 0.04093074683623854, 0.03818013603449799, 0.03272085690696258, 0.04713714974059258, 0.005702469788957387, 0.06521121016703546, 0.053567091235890985, 0.05335119305527769, 0.01755398745444836, 0.03377974950126372, 0.015553322446066886, 0.04280877379642334, 0.016458445752505213, 0.0684759252180811, 0.02768715494312346, 0.0063565908658347325, 0.024689737365406472, 0.04870282529736869, 0.027519531613506842, 0.02685661933355732, 0.03234322619391605, 0.028165771545900498, 0.04469946550671011, 0.053790730016771704, 0.012304416995903011, 0.07112349252565764, 0.01436518483387772, 0.014294791199063184, 0.02628102072776528, 0.04622562169970479, 0.027499224597704597, 0.07807421017787419, 0.005886694498258294, 0.026747892843559384, 0.031752985014463775, 0.02619273855088977, 0.01287123785004951, 0.015592756462865509, 0.036793284671148285, 0.06397203876986168, 0.05001739518775139, 0.024344954108528327, 0.029023078277532477, 0.017182175179186743, 0.05564798426348716, 0.025364820867253002, 0.01830784065532498, 0.058726015777210705, 0.015635784329788294, 0.039680354166193865, 0.016854151472216472, 0.09354326917673461, 0.02976308485813206, 0.06201346652233042, 0.08778291186899878, 0.031331537902588025, 0.045393488617264666, 0.03539061814080924, 0.048366832779720426, 0.02782530202239286, 0.04927087255055085, 0.0708420923911035, 0.014937709092919249, 0.08627886054455303, 0.013194656530686188, 0.011066058250435162, 0.026521224244788755, 0.00715498730642139, 0.02989099401020212, 0.009277264343836578, 0.05426971954875626, 0.035608308608061634, 0.03961611015256494, 0.015790859797562007, 0.021169649298826698, 0.05991252066451125, 0.09833947275183164, 0.01572572520672111, 0.02511862821847899, 0.018617678033479024, 0.02357663273869548, 0.0153245637739019, 0.0300324659110629, 0.007569458230136661, 0.08642075918032788, 0.03171167707478162, 0.06386164430296049, 0.09261211132979952, 0.015978404226189014, 0.026351604537921958, 0.029181977661210112, 0.048416486170026474, 0.026367716563981958, 0.028470291435951367, 0.03097106749919476, 0.0034158531934735947, 0.04512661231274251, 0.029582299539470114, 0.028690544168057386, 0.02403278082056204, 0.034983995428774506, 0.050596489309100434, 0.052711851385538466, 0.05708775817765854, 0.02755192635959247, 0.031538986731902696, 0.04491576815780718, 0.06222929419891443, 0.011162927075929474, 0.08045411450439133, 0.01827605075959582, 0.0419419638637919, 0.017807733311201446, 0.002196431505581131, 0.07608661253470927, 0.030304539104690775, 0.020696617357316427, 0.06882832662086003, 0.02022677108470816, 0.03389145014807582, 0.12468615313991904, 0.007896314909885405, 0.04108097607968375, 0.027688700465660077, 0.04639967388357036, 0.04523890296695754, 0.02702698860957753, 0.023723474077996798, 0.04993426351575181, 0.02831108035024954, 0.07988323224708438, 0.033380993554601446, 0.09024857878102921, 0.052283895638538525, 0.048023166455095634, 0.03444312562351115, 0.05510306975338608, 0.044990506139583886, 0.034374851747998036, 0.0496302835381357, 0.02309573959792033, 0.07980645706993528, 0.039209539390867576, 0.03067211371671874, 0.09177768501103856, 0.005137656444276217, 0.03647245423053391, 0.05882530771486927, 0.025108778063440695, 0.01787767330824863, 0.003990452914877096, 0.08983426741906442, 0.02059461101453053, 0.02268487551191356, 0.02793771698634373, 0.07021841374807991, 0.01484241547586862, 0.05647813210089225, 0.061361215193755925, 0.046138975958456285, 0.03425617491302546, 0.024022342513490003, 0.06481102929683402, 0.026407267469039652, 0.032978170638671145, 0.005574459519266384, 0.023309377938858233, 0.018807179876603186, 0.012636849060072564, 0.034036224606097676, 0.03157341867336072, 0.021035502395534422, 0.045093074659234844, 0.0386024774343241, 0.019148642022628337, 0.05626572572509758, 0.03545367100741714, 0.027185589278815314, 0.03071479091886431, 0.047561762112309225, 0.053155744753894396, 0.0394527189200744, 0.058966605211026035, 0.03575323891709559, 0.10172825262998231, 0.018291424348717555, 0.0222849432611838, 0.045173946491559036, 0.03023451932676835, 0.03120840818155557, 0.06787673002691008, 0.03781642430112697, 0.04277277592336759, 0.01163094952062238, 0.021123866208654363, 0.03252595408412162, 0.07053586741676554, 0.05029235719121061, 0.0276075150759425, 0.10383361426647753, 0.00339973560130602, 0.04912682910799049, 0.033300466820946895, 0.018126090544683393, 0.014833751829428365, 0.06555131418281235, 0.051361992373131216, 0.05469678100780584, 0.04453556590306107, 0.0634087338403333, 0.02448271341563668, 0.07518769358284771, 0.04244983407261316, 0.03963379182096105, 0.02519472433050396, 0.08479301410261542, 0.030502414228976704, 0.019613736694736872, 0.025127083135885186, 0.03822787097305991, 0.00412923916883301, 0.024511627489118837, 0.07786611939081922, 0.03036199061170919, 0.025154601971735246, 0.010469082080817316, 0.01768978934705956, 0.09750974422786385, 0.09640545074944384, 0.0319831509841606, 0.05092909392260481, 0.04501691546465736, 0.013655279763042927, 0.07458174484781921, 0.032150575789273717, 0.045019976823823527, 0.05407548465882428, 0.04604794041370042, 0.022926468700461555, 0.03936375767807476, 0.02297888288012473, 0.04995183386199642, 0.041758694205782376, 0.05256916607322637, 0.059752784509328194, 0.07053581546642818, 0.03354149041115306, 0.05648160535201896, 0.03383170726010576, 0.044590551624423824, 0.04820869224204216, 0.012329548899288056, 0.04019406878796872, 0.032019891004893, 0.013395448295341339, 0.02227348264568718, 0.05436944935354404, 0.004675601794588147, 0.03925445787899662, 0.026005168147094082, 0.019742989134101663, 0.013054680057393853, 0.053119019576115534, 0.029740915051661432, 0.006006146413710667, 0.027110767805424985, 0.02462387361447327, 0.04768154103658162, 0.025909989562933333, 0.021598070743493736, 0.036410833708941936, 0.03616831840190571, 0.15675083646783605, 0.13347082160180435, 0.17305283749010414, 0.10502601551706903, 0.1824674112140201, 0.13204220216721296, 0.21957578952424228, 0.1694451685762033, 0.13491210207575932, 0.169046412629541, 0.11498397492687218, 0.24825060943840072, 0.13411407067906111, 0.16763996856752783, 0.070510270743398, 0.16047781304223463, 0.07373986736638471, 0.1038739648356568, 0.12814796034945175, 0.30232510704081506, 0.04769598694110755, 0.13795140461297706, 0.08643218825454824, 0.13058919575996697, 0.22369978541973978, 0.15346416126703843, 0.09619774587918073, 0.10479255812242627, 0.16231453948421404, 0.12967961956746876, 0.06901292843394913, 0.20098959153983742, 0.18536246992880479, 0.0963600684190169, 0.14837161812465638, 0.1129703650076408, 0.18421531742205843, 0.10861850008950569, 0.07942958705825731, 0.207458091317676, 0.11404374803532846, 0.13752112223301083, 0.11858033351018094, 0.1602271749288775, 0.11112581632914953, 0.16813555994303897, 0.12957632745383307, 0.12028564044157974, 0.1966049979091622, 0.09411092309164815, 0.07226077446830459, 0.09435673724510707, 0.13304276566486806, 0.10299882429535501, 0.21094455267302692, 0.13988961232826114, 0.07939892151625827, 0.11419748392654583, 0.13303144049132243, 0.14552718872437254, 0.1247346302261576, 0.1181131812336389, 0.14645138522610068, 0.1051992030988913, 0.12111523537896574, 0.15209240518743172, 0.11246645415667444, 0.10860747919650748, 0.13582868414232507, 0.14321220747660846, 0.07690295271459036, 0.15385646052891389, 0.10111244817380793, 0.1415435181115754, 0.12767240696121007, 0.15841360349440947, 0.09661205724114552, 0.14115311874775216, 0.11468667798908427, 0.20434019534150138, 0.07313379246625118, 0.09567309942212887, 0.09840194674325176, 0.10816124064149335, 0.23642865708097816, 0.15064224862726405, 0.1246606232598424, 0.12686788919381797, 0.22751025360776111, 0.0978596149070654, 0.11359475611243397, 0.09015690127853304, 0.13150755898095667, 0.11166248557856306, 0.20756010693730786, 0.193999050243292, 0.12540654104668647, 0.1487608894240111, 0.11172434358741157, 0.12907840573461726, 0.24427364784060046, 0.12993874785024673, 0.14169273432344198, 0.2205815480556339, 0.08254768341430463, 0.20930691476678476, 0.14940321823814884, 0.14886321674566716, 0.1299768645549193, 0.12263685333891772, 0.13279387902002782, 0.16114595375256613, 0.1054905702767428, 0.2305846448871307, 0.08051390934269875, 0.12006339689833112, 0.15321944549214095, 0.10056049810373224, 0.09924370548105799, 0.09440586742130108, 0.11570175789529458, 0.09937120645190589, 0.12490446330048144, 0.14332789345644414, 0.13220759719843045, 0.0948763445194345, 0.1325179188279435, 0.18063386116409674, 0.06503781478386372, 0.10983582265907899, 0.0828684693260584, 0.2178617994650267, 0.2709066413808614, 0.13760787929641083, 0.2626042946940288, 0.16482157370774075, 0.08100613136775792, 0.1583862627740018, 0.13983314973302186, 0.16958734922809526, 0.10515243295230903, 0.20314921159297228, 0.11296329234028235, 0.1508739619748667, 0.08166657600668259, 0.09141678601736203, 0.15679554344387725, 0.16814402042655274, 0.1164113030245062, 0.20341442548669875, 0.15722864598501474, 0.09745055795065127, 0.16282601282000542, 0.12270523482584395, 0.11696098954416811, 0.12796542170690373, 0.19259784574387595, 0.08968476176960394, 0.08345227237441577, 0.07182484434451908, 0.1817258572555147, 0.1674125893623568, 0.1196413894649595, 0.08711641872650944, 0.14492259069811553, 0.1248280072468333, 0.15693680383265018, 0.19527417869539931, 0.09756620682310313, 0.13161680311895907, 0.11776112121879123, 0.18752771546132863, 0.16712965298211202, 0.07667448255233467, 0.22426565818022937, 0.11474283630377613], [0.04335663834353909, 0.04178942283033393, 0.025046374576049857, 0.06195486283104401, 0.03861757642880548, 0.032577897000010125, 0.012283557080081664, 0.0556441250955686, 0.04990655172150582, 0.023547169475932606, 0.024268973029393237, 0.052677011262858286, 0.14202532038325444, 0.009509974024695111, 0.03725098940776661, 0.039229978137882426, 0.035819189870380796, 0.05427009062259458, 0.09720325950183906, 0.030701612231496256, 0.006134584346000338, 0.01257800788152963, 0.047190795885398984, 0.022013491616235115, 0.020952647173544392, 0.009887709566100966, 0.04654014759580605, 0.027896538922504988, 0.03747004171600565, 0.042684913059929386, 0.06622073138714768, 0.05229324298852589, 0.05130541103426367, 0.013058110635029152, 0.03621660252974834, 0.005843401313541108, 0.0038869708578204154, 0.04767094687849749, 0.05126607349666301, 0.06073181459214538, 0.04770131185068749, 0.02576899634732399, 0.049949176973314025, 0.012818370032618986, 0.05615794361801818, 0.01544461636513006, 0.04651992036087904, 0.02985539689689176, 0.022777423182560597, 0.04292336881917436, 0.017341068996756803, 0.03705463568621781, 0.01232062457347638, 0.028937889001099393, 0.03720898756000679, 0.044469848726294, 0.014021602000866551, 0.026405057724332437, 0.02431932218314614, 0.05502118860022165, 0.05745225658756681, 0.033195189462276176, 0.015681402292102575, 0.02847387415386038, 0.01397138272295706, 0.020454152145248372, 0.05865788662049454, 0.10596574516966939, 0.052189104826538824, 0.05487029513460584, 0.021109594708832446, 0.0442158635269152, 0.019410801978665404, 0.05203576969506685, 0.05045793775934726, 0.0392545283830259, 0.013999145539855817, 0.022584123398701195, 0.06248632591450587, 0.02171434858610155, 0.027854956388182472, 0.04832417042052839, 0.035930857120547444, 0.11429000005591661, 0.07590130568132736, 0.05911470820137765, 0.0968384716543369, 0.05018893520173151, 0.10371457377914339, 0.03754454221052583, 0.09351835527922958, 0.09710185986477882, 0.014578452100977302, 0.06500608797068708, 0.05367843565181829, 0.0345570935314754, 0.043583820879575796, 0.04063893808051944, 0.033674301448627375, 0.032704796831239946, 0.1140731296618469, 0.08864823379553854, 0.04622372922312934, 0.0252115135663189, 0.07546183551312424, 0.010625585255183978, 0.018732195130723994, 0.023834627390897367, 0.03592332432162948, 0.05327642538759392, 0.004392991031636484, 0.05116399850521702, 0.010170225705223856, 0.0717176114267204, 0.03410192693991121, 0.02706901457713684, 0.027540779301489238, 0.012528761744761141, 0.032865813191165216, 0.026566565757093485, 0.026687437493819743, 0.027790742060460616, 0.048372810779255815, 0.011678626942739356, 0.0289816868462367, 0.026805309098563157, 0.02949774294393137, 0.0678922186489217, 0.030258713341027033, 0.03989663455286063, 0.030614716015406884, 0.01219653098814888, 0.047414679575013, 0.04673155119235162, 0.0449541186389979, 0.028198580039315857, 0.03837877186015248, 0.053120982556720264, 0.03877398034092039, 0.02652433013281552, 0.05077880159660708, 0.026985656550095882, 0.035747257206821814, 0.0218052115815226, 0.009048247775353957, 0.007234908725877176, 0.02903835538745625, 0.08139894271153025, 0.03259172692196444, 0.042249179605278187, 0.05451784178148955, 0.05074820284789894, 0.02473460390319815, 0.034680264070630074, 0.05783454798802268, 0.025383680695085786, 0.026855593314394355, 0.005003420483262744, 0.047459650013479404, 0.012199626671645092, 0.0240881413265015, 0.03065639131818898, 0.04593242141709197, 0.01567267278005602, 0.021963012586638797, 0.014437210265896283, 0.05891764572879765, 0.0184453198016854, 0.007845349773560883, 0.04092603790923022, 0.02479507038515294, 0.0015705954160694091, 0.049231301236432046, 0.020251748064765707, 0.020746417321788613, 0.024251415670732968, 0.016690404008841142, 0.03263152088038623, 0.01956079559022328, 0.026753516467579175, 0.034305742956348695, 0.0034358104721832206, 0.016765323816798627, 0.023448888714483473, 0.006098554931668332, 0.014846651283733081, 0.08457094867480919, 0.005359074812076869, 0.03994497063104063, 0.0249976080522174, 0.04446715844096616, 0.036490692509687506, 0.035345124488230795, 0.02072466682875529, 0.036183829288347624, 0.008105838041956304, 0.022846771316835657, 0.02577462924818974, 0.04885516595095396, 0.03408253462112043, 0.02696262028621277, 0.030847447960695717, 0.02560385921242414, 0.11372868408216164, 0.020135303238930646, 0.05635605251882225, 0.04390812828205526, 0.024063784039753955, 0.06045664849807508, 0.02406398627499584, 0.02593126137071522, 0.024900156640796922, 0.00774822676248732, 0.08964931679656729, 0.023126987725845538, 0.010159366229345324, 0.031163003586698323, 0.007228134772958583, 0.03588709267205559, 0.00448618066002382, 0.030107339334790595, 0.043923858102061786, 0.023743140991427936, 0.10811743908561766, 0.05096833127026912, 0.011065937651437707, 0.05606874117802363, 0.007514221106248442, 0.022984111310506705, 0.003892134582201834, 0.03078666235523997, 0.043516352234291844, 0.022323922712530475, 0.016027185592975002, 0.018454127239238005, 0.02989813161548227, 0.04358415855676867, 0.02046586509095505, 0.03787464949709829, 0.046191590517992154, 0.029986870213178918, 0.02473551303410204, 0.0608476267370861, 0.0401177834282862, 0.0329396494635148, 0.017243931142729707, 0.04887315189989749, 0.007841216938686557, 0.017746890189300757, 0.02869950189051451, 0.04862893336394336, 0.04893414159596432, 0.026131207087018993, 0.03446714152232744, 0.027330001939844806, 0.0671076869184617, 0.040442391400574706, 0.025090035123866983, 0.03297418159490917, 0.017213469691341743, 0.023024656693451107, 0.0312041297001997, 0.020214677788317204, 0.010682716711016838, 0.04366766872408334, 0.12139090613345616, 0.08352927019586787, 0.04486611105676275, 0.009027254272950813, 0.07452209843904711, 0.029161854326957837, 0.04097103803360369, 0.011265231205470627, 0.0446446467685746, 0.039223009371198714, 0.03307102815597318, 0.04365370892628562, 0.11336893541738391, 0.030498499399982393, 0.03663002331450116, 0.04989807268430013, 0.0025322136707472964, 0.0501850426371675, 0.053508268611039966, 0.03461265441728756, 0.0781149095564615, 0.024579897653893568, 0.06249417783692479, 0.036972042071283795, 0.020053258813277353, 0.03655661377706565, 0.036603832922992297, 0.021700659672205802, 0.018050148428301327, 0.011296585089439759, 0.06373540498316288, 0.03315800415293779, 0.007559089963251608, 0.04034486577438656, 0.04517766094068065, 0.09037234674906358, 0.03282608602603432, 0.027520065959834028, 0.05022180121159181, 0.02339278049475979, 0.041563145714462735, 0.04106474530999549, 0.016223576421907637, 0.036422433477127925, 0.030397917980735656, 0.03523258892528247, 0.009215044537995709, 0.042572347811073996, 0.010575410506135086, 0.04926971480017528, 0.02735114572715247, 0.019142684432154056, 0.040690161113161594, 0.011437684988777619, 0.05160993277968373, 0.0640854834637139, 0.03975112165790051, 0.014688104420201853, 0.045329589702305384, 0.06070915682357736, 0.02766582005278906, 0.06205687845067587, 0.045858314260840416, 0.07071436877595261, 0.04320209722209256, 0.04803786097909324, 0.02046072386292508, 0.055624870074098, 0.09764872622326948, 0.06246782417292707, 0.06622606742894277, 0.06874997066915967, 0.03253754272009246, 0.0077924856668687426, 0.03817256983893458, 0.04088797686563339, 0.04076965997228399, 0.027006913514924236, 0.03672095866932068, 0.04721922014141455, 0.02957792457891628, 0.032877687553991564, 0.042091410141438246, 0.012558851194626186, 0.03415677907469217, 0.04425812883710023, 0.01658544577367138, 0.1127221982460469, 0.13468757271766663, 0.1317532395478338, 0.14473174000158906, 0.1705166368628852, 0.08570552919991314, 0.08178860734915361, 0.13699231232749298, 0.13252957054646686, 0.06482110024080612, 0.1773352819145657, 0.14578619826352224, 0.2109033486340195, 0.16067391814431176, 0.08436982665443793, 0.1286479749251157, 0.07286423700861633, 0.1421247236430645, 0.15496990468818694, 0.1832891022786498, 0.09532161086099222, 0.09914941561874002, 0.20145773829426616, 0.1701510400744155, 0.12616832595085725, 0.08102373511064798, 0.13199767330661416, 0.1812153190257959, 0.10884608709602617, 0.22094775340519845, 0.18117680156137794, 0.08487583778332919, 0.13144977536285296, 0.09278685000026599, 0.16627119592158124, 0.06850360732642002, 0.091594908881234, 0.24104260402964428, 0.14615167630836368, 0.08113237810903229, 0.09146598298684694, 0.08188815161702223, 0.08860103320330381, 0.11805809161160141, 0.16492762661073357, 0.09258109697839245, 0.15768940094858408, 0.17237448482774198, 0.19979966164100915, 0.0928545041824691, 0.2442661818349734, 0.15846656315261498, 0.2372502739308402, 0.08578022636356764, 0.07995861218660139, 0.1794506105943583, 0.09204236455843784, 0.10515905290958472, 0.11374494453775696, 0.1363300791126676, 0.1983384322375059, 0.12215129579999484, 0.1330039810272865, 0.11147329729283229, 0.06315831837127917, 0.0870435695105698, 0.1588109345175326, 0.26812611089553684, 0.12185888961539604, 0.12529504077974707, 0.1215330942068249, 0.09676858360762708, 0.07565555089968257, 0.13933022593846545, 0.12272890191525221, 0.15451235580258071, 0.09833732794504613, 0.16031195787945762, 0.15359360666479915, 0.13577523466665298, 0.24145782081177458, 0.1769195604720153, 0.13575458811828867, 0.15917041600914672, 0.1407367887441069, 0.1723720208974555, 0.17012337280903012, 0.11072973211412318, 0.17275600810535252, 0.18445163208525628, 0.23825600277632475, 0.11911364825209603, 0.15555731457425281, 0.21107987588038668, 0.14699634426506236, 0.12553141481475905, 0.1547848279005848, 0.13552085612900555, 0.08831455677864142, 0.130339982570149, 0.20426495641004294, 0.19440141302766278, 0.16227199957938865, 0.14460774196777493, 0.16776306118117645, 0.12750885245623067, 0.2147717637126334, 0.07975159751367755, 0.1526622410165146, 0.15328911831602454, 0.09861596729024313, 0.21433077956316993, 0.10296274107531644, 0.10572894068900496, 0.17200393049279228, 0.0666936204652302, 0.1274689397541806, 0.09385293771629222, 0.07680510054342449, 0.14353710488649085, 0.15031617862405255, 0.12236985086929053, 0.11279455022304319, 0.12876827706350014, 0.18857542017940432, 0.08842083232593723, 0.11707257144735195, 0.14767230721190572, 0.14969698997447267, 0.10001800299505703, 0.20201359206112102, 0.14928067481378093, 0.2023449758416973, 0.19874968595104292, 0.1355487311957404, 0.06810632083215751, 0.17204366507939994, 0.08186216902686283, 0.15647849795641378, 0.1169144717277959, 0.24398645153269172, 0.11093255365267396, 0.18166617373935878, 0.13774913968518376, 0.16317657369654626, 0.09479671949520707, 0.15841391519643366, 0.13361368502955884, 0.1336840257863514, 0.09553954252623953, 0.16481985192513093, 0.17545463517308235, 0.15532303339568898, 0.1442099953419529, 0.21436558628920466, 0.12287262623431161, 0.10009529025410302, 0.17812976584536955, 0.15689044928876683, 0.1328081134124659, 0.18342375755310059, 0.14181760809151456, 0.11536895661265589, 0.13772588077699766, 0.05632652617350686, 0.118765031802468, 0.12096101709175855, 0.15802526730112731, 0.27908623684197664, 0.15254928614012897, 0.12695157376583666, 0.07256587137817405, 0.12724862579489127, 0.05361599505704362, 0.14697217993671075, 0.0920213469362352], [0.03845114239084069, 0.06935050914762542, 0.015350787562056212, 0.04629772876796778, 0.0775147569947876, 0.07498967373976484, 0.06114187715866137, 0.019865269096044358, 0.012756378437188687, 0.06149265696876682, 0.05185051850276068, 0.040202213858719915, 0.01865733283921145, 0.07272483941051178, 0.07166293740738183, 0.04789525359228719, 0.03639724869572092, 0.011807307000708533, 0.010967567832267378, 0.018948744545923546, 0.03184662549756467, 0.05639523049467243, 0.09116050758166239, 0.017279172025155276, 0.014706974452565191, 0.08099761893390678, 0.051059066245215945, 0.057849279619404115, 0.0045510230302170385, 0.05670362996170297, 0.048226678190985695, 0.039583062316523865, 0.036026568195666187, 0.033595555869396776, 0.021950583468424156, 0.05437659994640853, 0.005765280529885786, 0.09418973917490803, 0.08161844772985205, 0.05373516913095955, 0.06755247828550637, 0.045543532323790714, 0.025509009028610308, 0.04933620752126444, 0.03668466022645589, 0.0348062992998166, 0.05553078059165273, 0.05815597585751675, 0.024914088608056773, 0.025466868028161116, 0.028525134293886367, 0.04261694717570208, 0.01269876180231222, 0.01106144209188642, 0.04463947771000676, 0.017616107070352882, 0.040536261949455366, 0.041381954069947824, 0.05783104876172729, 0.015605727348884102, 0.032861107974895276, 0.04446755177923478, 0.07325651400606148, 0.022223988817131612, 0.02109386674419511, 0.07890301101724617, 0.014968236409913516, 0.022602072240260895, 0.1521685643820092, 0.024317413008247968, 0.010210248801740818, 0.03417670202907175, 0.04834639032196719, 0.014931720888853306, 0.01930675844050711, 0.050533510657260194, 0.011468861684988951, 0.05106990160129499, 0.024468909468851052, 0.06576888961717486, 0.04691149602876976, 0.005221046940278029, 0.0519563487614505, 0.06347859962261282, 0.012031847491016379, 0.037989010743331164, 0.01345909488009056, 0.055830660203355365, 0.01819594148400938, 0.02140800115739694, 0.027274541243968997, 0.08909931115340441, 0.008260791983047966, 0.031123823755478952, 0.08540984272258356, 0.06434165057726204, 0.04322320761275478, 0.07982251714565791, 0.041085354750975966, 0.06322117827949114, 0.008649172705190722, 0.014018711335666012, 0.061817788155167364, 0.03644395947048906, 0.011989380873274058, 0.12369292948278598, 0.04679065583331976, 0.016185784406843595, 0.03647299970907625, 0.035176694073015824, 0.1104216962994542, 0.05372757696022745, 0.030223830544855446, 0.051707562306546606, 0.08666742680361494, 0.008864143201208208, 0.03987460760981776, 0.04369174399471376, 0.03171164367813617, 0.054650860620313324, 0.02796257151203463, 0.04913401680823881, 0.021878092338738497, 0.020707484254671726, 0.03744262307009194, 0.1310009986627847, 0.0022831220076113823, 0.02500195518223336, 0.028396132329362445, 0.03053293690754799, 0.03534387768013403, 0.14570318162441254, 0.010993241503456375, 0.03203999578545336, 0.004493997330428101, 0.02540090037655318, 0.046669418588862754, 0.0078800488881825, 0.10146499058464542, 0.025021722285600845, 0.0363234421092784, 0.012136284367443295, 0.0322559050982818, 0.03832211259577889, 0.04482126678340137, 0.05692103841283824, 0.05439250417111907, 0.06493916851468384, 0.03583678248105571, 0.017916083161253482, 0.038081734674051404, 0.0659971074492205, 0.0586047340038931, 0.013794810020044679, 0.02925215885625221, 0.01897716138046235, 0.046451197486021556, 0.004843094320676755, 0.08180451899534091, 0.04097724238818046, 0.052121042463113554, 0.047129654049058445, 0.04096241798833944, 0.061261285009095445, 0.024557701872254256, 0.033724804598023184, 0.024740420485613868, 0.07826874192687683, 0.02928121579316212, 0.03246709064114839, 0.019618479018390644, 0.0635188833985012, 0.027837920388265047, 0.014951518605812453, 0.05056428381067235, 0.07505847825086676, 0.021079252001072746, 0.07457963714841753, 0.021360989812819753, 0.07609778927871957, 0.04547690230538137, 0.03395677027583588, 0.04068322945386171, 0.014193014922057046, 0.04103890743863303, 0.039453798744943924, 0.06308546915533952, 0.03134352358756587, 0.04681319485825952, 0.06442295285523869, 0.036984194739488885, 0.034357544864178635, 0.03674018029414583, 0.06986050560954027, 0.014494090319203679, 0.03914609318599105, 0.08102644394966774, 0.07100933537003584, 0.041686004551593214, 0.04106261163542513, 0.044347553921397775, 0.01568415194924455, 0.011302371985948412, 0.04659950456698425, 0.04065583678311668, 0.0253469165545539, 0.012521455300884554, 0.02043901233264478, 0.05875068476598244, 0.04774849017849192, 0.05289125445415266, 0.076349689043127, 0.04229561207466759, 0.02999717864440754, 0.08027489326195791, 0.05349751118046697, 0.02727064311329741, 0.021082370876683854, 0.03195335746568162, 0.09647567276260816, 0.015852036885917187, 0.07958255111589096, 0.04316704558732454, 0.038863750523887575, 0.06759426862117834, 0.07065723824780434, 0.04748884981381707, 0.07020459495834075, 0.05071784900792409, 0.012501268884079764, 0.04174079360382166, 0.02374531362875132, 0.05062970412836876, 0.03563579775800463, 0.03553357433702331, 0.0411287035967689, 0.00824826453026617, 0.0542302038957132, 0.03657294102595188, 0.04725955215690192, 0.028166170450276695, 0.07541533253970556, 0.03397665983357001, 0.042452357374713756, 0.031035736392368563, 0.0287786927583511, 0.024092941166600212, 0.033438176033087075, 0.009468785756325815, 0.054891498293727636, 0.04051832052937243, 0.018979924025188666, 0.0349662247026572, 0.03084375763137359, 0.07419748304528184, 0.017102364618040156, 0.09508850969723426, 0.03849986438581254, 0.023482491305912845, 0.0651799286424648, 0.040264034760184586, 0.03369280319020618, 0.05336567235644907, 0.030266483627201524, 0.002268099779030308, 0.027218598152103368, 0.011956760699831648, 0.011051725523429923, 0.02902188898588065, 0.02538688491767971, 0.016758375459176023, 0.0716750937863253, 0.042613681725924835, 0.08315739483805373, 0.05142310823430307, 0.03138072745059617, 0.08578563662013039, 0.006879929287606501, 0.02670900987141067, 0.021156472466827836, 0.02085197855194565, 0.03550719098711852, 0.02455312653182773, 0.08093481097603217, 0.012078883883077651, 0.05787657581095118, 0.04529258621914778, 0.03488491500320379, 0.011377597929822514, 0.09301186917582527, 0.04289686301490292, 0.06232255618670024, 0.020560121556627564, 0.06167768551677, 0.049709459563018754, 0.0765900855185464, 0.02750359028141247, 0.06606359645957127, 0.00929637464651023, 0.05340923642506823, 0.05888794497877825, 0.03294340473075863, 0.027769787520810496, 0.04295265767723322, 0.02626049106766004, 0.011037522672268096, 0.030864075779390987, 0.0505723954847781, 0.03950853213609662, 0.026760956498037558, 0.007817310506652575, 0.03416898369323462, 0.041715623665368184, 0.06472202352597378, 0.09651816813857295, 0.023633779965166468, 0.08584895665990189, 0.011697124973579776, 0.03193529359123204, 0.055484722906840034, 0.022298743497231044, 0.021470605024660472, 0.03960785747040063, 0.028244329732842743, 0.04244765957992058, 0.028442312468541786, 0.018977215186168905, 0.02630276565469103, 0.16341907787136734, 0.03398308683244977, 0.03735550977580715, 0.012592017774295527, 0.051386858031037264, 0.05512940486369189, 0.0065126404024340445, 0.046825696335872635, 0.027580849709920585, 0.026510069765208755, 0.02051344417850487, 0.08525220313458703, 0.023883110043243505, 0.0308997934916988, 0.033499559067422524, 0.044117922298028134, 0.017304726025031414, 0.04161948585533537, 0.055406849351129495, 0.08731329566217028, 0.01727696042507887, 0.04606562579283491, 0.02703177360672271, 0.034312696880078875, 0.1767547443159856, 0.22089393285568804, 0.10794248519232497, 0.09767626732354984, 0.18395500170299783, 0.09340932636405341, 0.09298606470110826, 0.16525863931747153, 0.11705012148013338, 0.18140146450605243, 0.11009575246134773, 0.15510925033595413, 0.11473483595182188, 0.17485627118730918, 0.13776620908174664, 0.10957282036542892, 0.13544352434109896, 0.12244891928276047, 0.09428352437680587, 0.0829737949243281, 0.11223842928302474, 0.317765103536658, 0.181809586356394, 0.2159137508715503, 0.13468898279825225, 0.24444707290967926, 0.11782017390942201, 0.16820649441797286, 0.08686380650033243, 0.1101264996395912, 0.17679832322755828, 0.10701573570258915, 0.11871149326907471, 0.11167096090503037, 0.09390614970470779, 0.24464815040118992, 0.11066731749451719, 0.13062833662843332, 0.23520604299847037, 0.13098709081532434, 0.1271803630515933, 0.1600001222686842, 0.2299249795032665, 0.2579447056632489, 0.18838587566278875, 0.15051689988467842, 0.1259188010590151, 0.1282511930912733, 0.08769947962719016, 0.13556381163652986, 0.14502579375403002, 0.1509696990251541, 0.17436455382267013, 0.06746984014171176, 0.21597891143755987, 0.12020859066979028, 0.1424697629408911, 0.1364107060362585, 0.12404106353642419, 0.12029082063236274, 0.0928148215461988, 0.16526928171515465, 0.16878838272532448, 0.15613222669344395, 0.11666968173813075, 0.20107008487684652, 0.09544051034026779, 0.14329498662846163, 0.21750055166194215, 0.10272054860251956, 0.0983211120183114, 0.0942615864914842, 0.1624125029775314, 0.0924889073939994, 0.10923708759946749, 0.10966574467602186, 0.12369946780381724, 0.11685558230965398, 0.10752007699920796, 0.17752815125277266, 0.19173973007127643, 0.14373386307852343, 0.14128787792287767, 0.13288505928358063, 0.20945519587257877, 0.2203614270547405, 0.1687532791402191, 0.11585495944018476, 0.10341988177970052, 0.12019630070426501, 0.07568177839857526, 0.41454965074080974, 0.12473810347728431, 0.19046212284592912, 0.1125239631801378, 0.18709145137108862, 0.13925008883234113, 0.2774231432704255, 0.13570492359576747, 0.12895648571429774, 0.22695343504892662, 0.10947643022518605, 0.2525098988553509, 0.10287303026416339, 0.1397921980242245, 0.18993712757946923, 0.12162301281932741, 0.12320821057073772, 0.16271976695861667, 0.1855196271208115, 0.23864188988227397, 0.13468574703438208, 0.0978264409059193, 0.18948722281493247, 0.16066667478298768, 0.21553435013629496, 0.1380141606205143, 0.11344022612320259, 0.31688904273323715, 0.11038257027394138, 0.18759654223686084, 0.1532588535337709, 0.08394818287342787, 0.13921237288741395, 0.17998504597926512, 0.1940813395776786, 0.17023208260070533, 0.18996380036696792, 0.09118300949921831, 0.11982223601080477, 0.12084910122212023, 0.2529435505857691, 0.19323520216858014, 0.11029631044948474, 0.08511683539836667, 0.10908020500210114, 0.12112356969737448, 0.18195987126091495, 0.23501566727645695, 0.14344227325636894, 0.14246829348849133, 0.11480991903226823, 0.15458704554475844, 0.11724981857696548, 0.11092430097050965, 0.28845819644629955, 0.12019803732982837, 0.20509283698629588, 0.10535726571106352, 0.1506247339420952, 0.13386337319388986, 0.1196837067254819, 0.22042508848244324, 0.12570596794830635, 0.10674479985027574, 0.08733008304261602, 0.17167892918223515, 0.12343645066721365, 0.13490886631188914, 0.22474933066405356, 0.14654822065494955, 0.18549841654021293, 0.21581001346930861, 0.20237081742379814, 0.11815531295724213, 0.09545811408315785, 0.11313507726299576, 0.1449298340594396, 0.13172785809729248, 0.10014423489337787, 0.15913779119728133, 0.12657873361604288, 0.11975870074820705, 0.10626572868204676, 0.09321932913735509, 0.11991505642072298], [0.05457487583043985, 0.11976388836046681, 0.038817251261207275, 0.03692092293931637, 0.04273597282008268, 0.06310544777079485, 0.012643763093365123, 0.012781217192241456, 0.03141266948659904, 0.023085238208295777, 0.05274431292491499, 0.004195390501990914, 0.025140977995761205, 0.026358038958278485, 0.09139974630670622, 0.034641293896129355, 0.04441252152901143, 0.020733426026708912, 0.026662052332540043, 0.02579478226834908, 0.028092332322557922, 0.029804173864249606, 0.024875578565115575, 0.05109750578412786, 0.026445992734807078, 0.031159771533566527, 0.0635797914583236, 0.06122353566752281, 0.03623254015110433, 0.013960026008135173, 0.0858101571793668, 0.034837046478060074, 0.02148247011064086, 0.057829965226119384, 0.03380447786184959, 0.12110482304706238, 0.02727468410739675, 0.014340691177494591, 0.03475165867712349, 0.014505300459859427, 0.040181660078815185, 0.06485357662313618, 0.11296422744635493, 0.033720778446877375, 0.07435555307893082, 0.039626244179089554, 0.02423359484964749, 0.09253886877559125, 0.04680192534578964, 0.017942071317520458, 0.032384908918174915, 0.009693362426332897, 0.0346737962536281, 0.010733361796155805, 0.023109046305762604, 0.037099802793818526, 0.016772902999946382, 0.09145574134890921, 0.013912978483858751, 0.0467135837971, 0.020777839854417834, 0.04041866122861393, 0.0155380926480575, 0.04529462712525856, 0.018911312472482678, 0.03458211875113193, 0.022816909149696585, 0.03172099473886192, 0.07881932644522749, 0.010096354180859635, 0.07730973127763718, 0.02112381611368619, 0.04893720295513049, 0.027488196283229627, 0.04060930041305255, 0.03307266830233857, 0.02566934075730387, 0.05349340339307673, 0.012844567845604615, 0.03067144763917895, 0.03304953184851911, 0.05348286860680673, 0.03514623633236624, 0.012865186563431052, 0.02571316457760986, 0.021901911568420473, 0.02813025606883457, 0.03380035523150582, 0.013781981069769245, 0.006415505795303034, 0.03174468409270048, 0.035123689885949716, 0.0020920822953485185, 0.02254869326861808, 0.026968976781063247, 0.017678976255410817, 0.041549582965672016, 0.023535621658083983, 0.0321988487849012, 0.025649777744547464, 0.046621323708677664, 0.06941683488548733, 0.046646790506201796, 0.03991049787146039, 0.03441548062255606, 0.019195870445400942, 0.040042563050519675, 0.03365104625117965, 0.03913612985343207, 0.0396709845517762, 0.022229467722354457, 0.03520073223626241, 0.034686576036619954, 0.05553110713663045, 0.021079548860143404, 0.01180870223834063, 0.018747422145679593, 0.01377202701405622, 0.0025864479675874463, 0.0481633581512142, 0.013823078425048152, 0.06735467366524972, 0.05800413615361322, 0.0646172025881242, 0.05883556048502214, 0.04483466997044161, 0.02137451545422664, 0.013570349310612073, 0.023032443677948322, 0.04005290487839375, 0.04964123021636624, 0.025243457457690965, 0.01307847702264553, 0.00734885622478032, 0.09423201932804659, 0.05944282282143831, 0.06121698250353802, 0.029444473439070862, 0.0279850418883143, 0.034646344211068936, 0.025318655571027193, 0.01631925224501174, 0.05430194731161464, 0.012960052517883014, 0.045256547527969815, 0.034343072984484024, 0.04161561926594004, 0.030072282133914996, 0.016338822679244913, 0.013356300005398225, 0.04244706957251765, 0.020202322884870227, 0.038899050778127275, 0.04712285597634036, 0.10483638936420903, 0.037154929523239844, 0.04806761739018839, 0.04318949184380472, 0.007498447221223614, 0.026008971653936896, 0.060945163495489396, 0.03581160512112547, 0.06794095548684709, 0.015035353462735657, 0.014272061071096687, 0.06312251716735773, 0.05545826905290596, 0.042293853184673935, 0.019499546142469626, 0.01943334656971274, 0.08268470613984391, 0.024566468491684645, 0.047768520744284615, 0.02350052734982455, 0.02168667946534697, 0.019609012924775016, 0.06719852579408325, 0.04581356275593862, 0.02977792039018823, 0.05073434324003756, 0.0718079530633986, 0.038298764629871584, 0.017463736730860546, 0.025254521024180576, 0.023010837903711945, 0.04452637811482418, 0.019762936208280735, 0.02913777163485065, 0.03417203020944726, 0.13519858592189848, 0.026515082972764503, 0.09485053262324072, 0.04974939081876073, 0.022288828404271044, 0.017742619129421655, 0.001195313484458893, 0.05788046837551519, 0.05325520738551859, 0.03781771934882272, 0.05636618283460848, 0.01560356769914506, 0.09916794704622589, 0.04619539402483497, 0.08342560700839385, 0.04562446723866742, 0.022684252107865177, 0.040241655296995305, 0.014924878287274623, 0.03751959120563697, 0.02924815682490589, 0.009193744899675949, 0.01924146057717735, 0.09673244101577438, 0.02845424991392065, 0.048811954402481206, 0.014178387191350339, 0.049388335974072106, 0.035529874730855227, 0.06976547359954566, 0.029324392089620233, 0.05662796429533046, 0.007312956686291727, 0.018671238831302617, 0.10603136586723849, 0.06294550010352395, 0.07419425470288843, 0.030645554106740747, 0.03236172051401809, 0.029776584524370264, 0.02366507818805985, 0.03654618660220876, 0.038090146917966194, 0.004832058120882721, 0.046133684445521794, 0.028809297073166817, 0.023238447174662724, 0.04349432900198735, 0.04167146216786932, 0.06382671883329749, 0.027297191591060255, 0.062057735631242394, 0.1437089269165881, 0.05276166062685661, 0.03249005269026384, 0.1148954218660947, 0.024596981893409975, 0.04900912077573594, 0.04102357466763351, 0.049102724151453, 0.030892269969626796, 0.00950942761846818, 0.041244166932301596, 0.04422859878104646, 0.056113333121174946, 0.044113988915341906, 0.06195973874127958, 0.03066402430704329, 0.042737071198644117, 0.05268089640594553, 0.018057558772852644, 0.023387368382827844, 0.02003834906645352, 0.06713077513268217, 0.040366269313381054, 0.030229142466851044, 0.010559229831414996, 0.039790911905583926, 0.10221039628959261, 0.021811093101860024, 0.04984020000847522, 0.04712991009000689, 0.018032613334071357, 0.0025177239331242163, 0.051765787502517924, 0.0420056809525704, 0.11655197711661458, 0.06862848851596937, 0.05541850106965285, 0.014956531813368201, 0.010291980597685324, 0.034729279213934205, 0.048625608542351983, 0.05015070717490744, 0.02271670993650332, 0.07075906090904027, 0.06680965525447391, 0.024695314605196472, 0.03866377883241512, 0.05482208522153087, 0.04824831921723671, 0.009305023449996952, 0.11685407574987039, 0.04566219802654814, 0.055294261837843806, 0.07733971404377371, 0.0025646603671702906, 0.07271100577781908, 0.026413132291054353, 0.033104610338341445, 0.030880469821568113, 0.020081551338080317, 0.057221567403757945, 0.03741569053090643, 0.07700328365899622, 0.014700622596137691, 0.03355917207954917, 0.05786407433333807, 0.013151637940609362, 0.025913947065419052, 0.09066224447451532, 0.06325812239083461, 0.04119786433875561, 0.06778672977816314, 0.011265271095908247, 0.046180046410881914, 0.10013461665948853, 0.03887663420755416, 0.014277049231168348, 0.0035233685912317014, 0.06936302917893045, 0.04039785511849914, 0.10396735669928603, 0.07592720663524233, 0.03763501743378583, 0.032516536230104975, 0.03819930941972416, 0.021234405394352507, 0.027983646650682203, 0.06704670464387164, 0.034081918638548814, 0.022794128926761914, 0.0657812760618981, 0.06579812281415798, 0.013902722002967494, 0.012710711307590827, 0.055409316992154345, 0.019318065060360823, 0.013666744089277927, 0.01304678824453731, 0.042775262118084356, 0.010211836070084246, 0.10062730623758398, 0.07059694617055357, 0.047436791865038686, 0.007849589292163728, 0.006637391716139973, 0.07922523669549264, 0.004983865819667699, 0.02548894135543378, 0.036474855078267865, 0.017016223537211772, 0.010618501455610385, 0.13101741496939212, 0.1759429683443159, 0.07203698725788854, 0.17776109656551853, 0.1727593329269439, 0.1261452748440206, 0.06272226208238862, 0.112454646587139, 0.14257309958338737, 0.091002482076874, 0.11325519386446103, 0.13503669382771477, 0.09346616745460778, 0.21960998768918216, 0.18283998419065028, 0.2423901660949923, 0.1732268265914172, 0.10621372639434412, 0.11969377024797723, 0.17191656486829743, 0.1659540762193501, 0.11185781142557971, 0.1448542537400499, 0.1343550905585289, 0.16463922802358866, 0.161361102364026, 0.14600140624679625, 0.10126215420314111, 0.12892864033346996, 0.09872058784822002, 0.15218432759866118, 0.12668281240621582, 0.2242008686880581, 0.19518090557539836, 0.16623567673377693, 0.15291955845896155, 0.166470967233181, 0.14365280570928007, 0.09742925831233151, 0.07469173113349825, 0.12178293080069125, 0.12711288698483258, 0.23527574550826102, 0.12513403926277533, 0.2106454671593383, 0.1260127272689715, 0.1342545889201574, 0.16786619002232328, 0.1229436497669667, 0.13129379076417536, 0.1154219385352917, 0.07203970351838507, 0.1350289606489241, 0.13085080281598493, 0.14308316283859313, 0.0996594491880387, 0.1572588217095472, 0.1876060268841684, 0.14722281805006787, 0.1644803787348792, 0.10638571169693023, 0.14048051030840725, 0.13829573144903407, 0.18501388316508383, 0.16706648137187585, 0.3107511845882982, 0.1432339969323948, 0.14814824651693925, 0.187196628539823, 0.13261420506751165, 0.18521197722293437, 0.1352071057772264, 0.11116808163933456, 0.10828954313183203, 0.09188423515297472, 0.15339238074375317, 0.09873923059785739, 0.16906873643165454, 0.1364478876348585, 0.2084921405185014, 0.12485561514040455, 0.12846266065025702, 0.14166131179081276, 0.13871360511984676, 0.06862399110104889, 0.10326881762011908, 0.09525883258902468, 0.08675751611008309, 0.16926650394452736, 0.0683667256089393, 0.1524148089811206, 0.24340581003343686, 0.08371692965738475, 0.15109148545889184, 0.08187768733478151, 0.07504882290959358, 0.1305079454323277, 0.11324205785058439, 0.08027940551983193, 0.28503009758424014, 0.17303652508417144, 0.2300718950573355, 0.10969754570396617, 0.07759007014101371, 0.09247499954653904, 0.12895688647404313, 0.13710525236092508, 0.13068910368019715, 0.16428958741016686, 0.20566196035360917, 0.11991233273874968, 0.24458208441501483, 0.0987572647863999, 0.19564390182495117, 0.14534741087118164, 0.18242203630506992, 0.08719149438547902, 0.1496065963874571, 0.15994023095117882, 0.11923565733013675, 0.09013954986585304, 0.19634782889625058, 0.13307763176271692, 0.14263046759879217, 0.18128653551684693, 0.1757394862943329, 0.0780579200363718, 0.1748833744204603, 0.1045248209265992, 0.2645361050963402, 0.1562049423228018, 0.12172266840934753, 0.06401667153113522, 0.18206556793302298, 0.18221139995148405, 0.19326111796544865, 0.15129645180422813, 0.12303080759011209, 0.1677013887092471, 0.312897713156417, 0.1595754802110605, 0.09181597983115353, 0.16049666359322146, 0.19938916491810232, 0.13710587576497346, 0.18400414672214538, 0.11707119105267338, 0.06612413344555534, 0.08697831988683902, 0.13140483089955524, 0.12590214726515114, 0.1104254812526051, 0.15866905072471127, 0.2058147091884166, 0.10173437534831464, 0.21984492195770144, 0.13437373330816627, 0.07848941953852773, 0.08412246141233481, 0.0899254996329546, 0.11652204630081542, 0.08118971643853001, 0.17645092390011996, 0.07066498626954854, 0.10008357174228877, 0.3100330528104678, 0.15038720215670764, 0.1469504795386456, 0.11942426674067974, 0.09042159566888586, 0.18328081991057843, 0.12485733692301437, 0.13212452118750662, 0.11501952380058356, 0.14749281137483194, 0.06560687135788612], [0.08413915973505937, 0.06010739380144514, 0.022763878987461794, 0.06724539241986349, 0.04027972747280728, 0.009354512640129542, 0.03640880393504631, 0.02871592005249113, 0.01637816763832234, 0.03167902628774755, 0.017670595552772284, 0.02992972298670793, 0.016867144622665364, 0.01876820042525651, 0.02113398539222544, 0.08682168219820596, 0.008509973631589673, 0.042624539346434176, 0.0145338787115179, 0.01233978404343361, 0.048024416973930784, 0.03818399149167817, 0.03869115294946823, 0.022852370821055956, 0.072819470660761, 0.061163165664765984, 0.015123605026019504, 0.05323945159034338, 0.008975597083917819, 0.09192940968205221, 0.032267007627524436, 0.007929804323794087, 0.05039291820139624, 0.05234019867202733, 0.022595155423914548, 0.033586260469746776, 0.021769555096398108, 0.04645903085474856, 0.023948988637130242, 0.03644316166173667, 0.07546101172920316, 0.038775468347012065, 0.048561828371020965, 0.03988569900684524, 0.014039676079846686, 0.021154164387553465, 0.008209447423723759, 0.08313672602525912, 0.0685441137466114, 0.00738728834221547, 0.08353832439752296, 0.1089033141033724, 0.020924033669871278, 0.08680381870362908, 0.05339277930033859, 0.02821409834723454, 0.019971841502410825, 0.03685234478325583, 0.09647270417190157, 0.030356457900779787, 0.057712316265678965, 0.07073233617120422, 0.11617152995313518, 0.04964015039149672, 0.08121856371872127, 0.04882858593191486, 0.014363344307639636, 0.07217422520625405, 0.036987868370488286, 0.05358791589969769, 0.05953680840320885, 0.025564814823155757, 0.025389128059032373, 0.04604271198331844, 0.03868454783514608, 0.017707723345665727, 0.02164355326385703, 0.037545095110544935, 0.04794285123352893, 0.060453104742919095, 0.05699072607967537, 0.03802120882028248, 0.04526711200014688, 0.062008219538256526, 0.08918016814277507, 0.05234505602857098, 0.08114474228932522, 0.04427245228725951, 0.13459755020448938, 0.018697470040933695, 0.05068192163889762, 0.0654453577590175, 0.011309840774629265, 0.028816061749239452, 0.027394335011194926, 0.1181690649536904, 0.028516286038211547, 0.01910112416226184, 0.028087810787837952, 0.031891889084363356, 0.05151900855707936, 0.0040410831570625305, 0.03661706541606691, 0.03897516544384416, 0.040766854654066265, 0.046187471598386765, 0.037267646912368946, 0.033987829156103544, 0.012701950254268013, 0.016412762852269225, 0.036950868598069064, 0.03673839913972188, 0.032409225386800244, 0.021019438609073404, 0.052819073171122, 0.038592280325246975, 0.07116319742635824, 0.019619868689915165, 0.03902548305632081, 0.043821345243486576, 0.031451472677872516, 0.015614785261277575, 0.026148920296691358, 0.046409102869802155, 0.028964695375179872, 0.03299696181784384, 0.04349495611677412, 0.05990757796098478, 0.0580052901932504, 0.05516685363545548, 0.04981133788533043, 0.058760547908605076, 0.048542573349550366, 0.05797099554911256, 0.05438738335215021, 0.04218441237753723, 0.009729699831950711, 0.08388734902837314, 0.026250399714626838, 0.058634991364669986, 0.026539113714534324, 0.005544846899283584, 0.013332753514987417, 0.0794509015395306, 0.05378380577894859, 0.0326260178553639, 0.04483218377572484, 0.06907348026288673, 0.04783548472914845, 0.05175213940674439, 0.0362542145740008, 0.07391804960207082, 0.013116615991748404, 0.007831822276784806, 0.03014883095602272, 0.03825058440270368, 0.02598795032099588, 0.09621523829991929, 0.08128806584863923, 0.051519049375201575, 0.048464124629390426, 0.01689398068265291, 0.048046670272015035, 0.03928495272703003, 0.03767154965316877, 0.039674821455264464, 0.024498689999745693, 0.04561692330753431, 0.10359418258303776, 0.04023366236651782, 0.016774745381553657, 0.06466835882747546, 0.014258887022151612, 0.04252811209880747, 0.0315290271100821, 0.047576152355759405, 0.03936592474929057, 0.05410433193901554, 0.05287558400596026, 0.012117740880057681, 0.06806844903621823, 0.011253526608925313, 0.04898657061858103, 0.009152045477094362, 0.03330856736283749, 0.09182026202324778, 0.046429552749032155, 0.062367560021812096, 0.058155040751444176, 0.06602183580980636, 0.027671458519762382, 0.15129487845115364, 0.06030055257724598, 0.04277968531823717, 0.017844543835963123, 0.05861225195985753, 0.044094043696532026, 0.02617432957777055, 0.020616098045138642, 0.05896480550291017, 0.05323695426341146, 0.025422582220926415, 0.021034021810919512, 0.014642737860413035, 0.026282835278834682, 0.06366191752022132, 0.0015646182282580412, 0.06412342947442085, 0.09714390253066085, 0.046942335975472815, 0.031280437324312516, 0.04900607054878492, 0.04900891668512486, 0.05025636302889325, 0.02314984772965545, 0.037388565033324994, 0.0056280889657500666, 0.009421531358384527, 0.06652431431575678, 0.03511765622533858, 0.1198868770734407, 0.06878481450257823, 0.03448307543294504, 0.023595548227604013, 0.014514540198433679, 0.05026670485676732, 0.06881784749566577, 0.033805583661887795, 0.08101833969703875, 0.06895236918353476, 0.03688966738991439, 0.036632487244787626, 0.038450622887467034, 0.009972860807465622, 0.043377429610700347, 0.04408538654388394, 0.020677223183156457, 0.034390848741168156, 0.0511816430662293, 0.03203079315426294, 0.041293326794402674, 0.03861683428112883, 0.025260372858610936, 0.030049227316339966, 0.00625893211690709, 0.027386954352550674, 0.02408060110610677, 0.00282895330201427, 0.019343658022989985, 0.03893910819897428, 0.026523125998210162, 0.008319635944644688, 0.04394723575387616, 0.046252951287897304, 0.03012718807440251, 0.04695580595580395, 0.021721964876633137, 0.01892276937724091, 0.03488990223559085, 0.021873392688576132, 0.10753793307230808, 0.0684610080497805, 0.005634749741147971, 0.058512095420155674, 0.02370887974393554, 0.045000684694969095, 0.03201069950591773, 0.020167833426967263, 0.05843864877533633, 0.06446164843509905, 0.028889476852782536, 0.046248535509221256, 0.03518691715726163, 0.030712859479535837, 0.0633246114011854, 0.014965266891522333, 0.056934961103252135, 0.0429341596463928, 0.045392731626634486, 0.06052854405425023, 0.016610224229225423, 0.0586715718236519, 0.06753523819497786, 0.0363403074152302, 0.10569925478193909, 0.05642277159495279, 0.030772648751735687, 0.03499433725664858, 0.03336352339829318, 0.028465369141486008, 0.039688239485258237, 0.013479810077114962, 0.0039023428234941093, 0.06740775206708349, 0.0406290749378968, 0.05683006595063489, 0.043101825649500825, 0.022868709202157333, 0.006376066212396836, 0.051140624564141035, 0.10533330918406136, 0.03860500444716308, 0.03542725055012852, 0.03549197695974726, 0.040216054912889376, 0.01543987775221467, 0.038554616330657154, 0.04171777589363046, 0.04062200227053836, 0.053657841053791344, 0.06537020046380349, 0.0666388202807866, 0.0804327629157342, 0.10086750233313069, 0.04547709155303892, 0.035019603674300015, 0.013990884508530144, 0.02059146801911993, 0.015141539024625672, 0.027974744589300826, 0.007463255969923921, 0.01322438603892806, 0.03728093135578092, 0.05533717281650752, 0.04982675229257438, 0.07710863894317299, 0.047014691663207486, 0.07899997261120006, 0.0835702961194329, 0.026248158428643364, 0.016953853446466383, 0.038094681440270506, 0.05582920559390914, 0.021723870340792928, 0.06763976969523355, 0.01936821012350265, 0.03425615264859516, 0.02201129300374305, 0.05826034779602196, 0.051044089705101214, 0.01630497703445144, 0.011226095903111855, 0.05440748813271057, 0.039275408707908355, 0.028605121115106158, 0.027371018586563878, 0.03455882644630037, 0.027569019875954837, 0.028188984069856815, 0.010882276510528754, 0.05957406421657652, 0.07556086769909598, 0.1525672757998109, 0.2247076664934866, 0.1335254733567126, 0.08246740530012175, 0.16574899113038555, 0.06645303845289163, 0.14566735073458403, 0.10617817752063274, 0.1661304698791355, 0.13328252389328554, 0.1254855649312958, 0.06881974739371799, 0.10054543992737308, 0.15712234075181186, 0.14243780606193468, 0.23729802371235564, 0.13676862901775166, 0.1456498508923687, 0.11842400752357207, 0.14867077785311267, 0.1308269501896575, 0.09843893538345583, 0.12486694031395018, 0.12429881884600036, 0.24524461448891088, 0.132481865293812, 0.06513970423839055, 0.155803024827037, 0.06801164505304769, 0.19108181615592912, 0.12728125060675666, 0.1813891003257595, 0.16145119909197092, 0.1687961455900222, 0.1186447667714674, 0.13214438105933368, 0.10032019068603404, 0.13617921533295885, 0.10366394446464255, 0.10132783427252434, 0.15234835707815364, 0.16011889558285475, 0.14326807635370642, 0.17922440398251638, 0.20074839354492724, 0.14094418933382258, 0.11148784338729456, 0.120842466421891, 0.13339988712687045, 0.11851349569042213, 0.15252475073793903, 0.24316634866409004, 0.17547342635225505, 0.15826937451492995, 0.1496844328357838, 0.06850040866993368, 0.16028172278311104, 0.05728734395233914, 0.23482250107917935, 0.14182850281940773, 0.09008843815536238, 0.11737383145373315, 0.26023889193311334, 0.2502644568448886, 0.21315983380191028, 0.08805908728390932, 0.11327048210659996, 0.1276760286418721, 0.0666155613726005, 0.15922266320558265, 0.1261864640400745, 0.08071089017903432, 0.08785967962467112, 0.14415856450796127, 0.18103190464898944, 0.07767386603518389, 0.07740605462458916, 0.13468500488670543, 0.15242462017340586, 0.16930481360759586, 0.14200467383489013, 0.15162209136178717, 0.18650439771590754, 0.1330506769591011, 0.2082940167747438, 0.26196385093498975, 0.1853512486559339, 0.17174509906908497, 0.24510746559826657, 0.10939896485069767, 0.18148146802559495, 0.2082293460262008, 0.19455653673503548, 0.23115847347071394, 0.14680127816973254, 0.20899819617625326, 0.10327814641641453, 0.09566389679093845, 0.21109388762852177, 0.11844072068925016, 0.14262551005231217, 0.1348595877061598, 0.10723338535171933, 0.281755356118083, 0.09366068436065689, 0.11344092374201864, 0.16633700957754627, 0.17405472201062366, 0.19400886143557727, 0.12478680320782587, 0.09899232522002421, 0.1733073199284263, 0.09438622277230024, 0.1474459224846214, 0.11979645380051807, 0.20580924698151648, 0.19647559704026207, 0.13061384990578517, 0.09893903901684098, 0.13914796931203455, 0.23220000352011994, 0.20670993224484846, 0.1023097698634956, 0.239599839260336, 0.10688839800423011, 0.14186348766088486, 0.14754413830814883, 0.17897299403557554, 0.15122612589038908, 0.23141270357882604, 0.1523345086025074, 0.16917694156290963, 0.16335649997927248, 0.2401997914421372, 0.17654159950325266, 0.11446890217484906, 0.2541892899898812, 0.21497306384844705, 0.10867668446735479, 0.13141666073352098, 0.11120918177766725, 0.10277670691721141, 0.05317863258824218, 0.17672876914730296, 0.15519510197918862, 0.1486476673744619, 0.1631673562224023, 0.18840594333596528, 0.1348802342545241, 0.12767380219884217, 0.10265566263115034, 0.13711907115066424, 0.1653775165323168, 0.14802133926423267, 0.0885171334084589, 0.18595874105812982, 0.2797654503956437, 0.23678799014305696, 0.1398806323413737, 0.1171128403802868, 0.11195299928658642, 0.08881392568582669, 0.2313568495446816, 0.14766867068829015, 0.11387601523892954, 0.18497996701626107, 0.1267941642436199, 0.13369719148613513, 0.1961076253792271, 0.1369053771486506, 0.12255237466888502, 0.09362558819702826, 0.17568173236213624, 0.11115026267361827, 0.1307108486071229, 0.1185182380140759], [0.05795245298941154, 0.029068139629089274, 0.0047384014033013955, 0.03357901339768432, 0.03979966924816836, 0.06106306849687826, 0.0830993292038329, 0.052195542957633734, 0.06511577739729546, 0.10482561337994412, 0.035632109284051694, 0.04217032270389609, 0.05459972293465398, 0.017319986436632462, 0.015612952156516258, 0.010189425065618707, 0.03990692814113572, 0.034260653774254024, 0.03243033206672408, 0.13803347130306065, 0.027892039652215317, 0.024836747543304227, 0.021218888941803016, 0.009124138869083254, 0.01392243344525923, 0.07083208824042231, 0.03328585022245534, 0.012945577855134616, 0.02644724696438061, 0.08968752255896106, 0.05551803049456794, 0.028955804446013644, 0.04122559097595513, 0.03305726502730977, 0.057553674778318964, 0.048770227149361745, 0.006577604763151612, 0.04469743573281448, 0.023963924359122757, 0.03835063333099242, 0.06358498649206012, 0.027696659999492113, 0.05914839799515903, 0.025346590009576175, 0.05605281468888279, 0.01918199413921684, 0.028967667676624842, 0.06247695258934982, 0.06610422162339091, 0.13066311366856098, 0.018679142704058904, 0.016657434098306112, 0.03473246302746702, 0.010897358806687407, 0.07133294144296087, 0.009325547543994617, 0.060040596799808554, 0.03653647559985984, 0.07376052875770256, 0.07301966499653645, 0.0175481801488786, 0.0372655540559208, 0.03605723373766523, 0.042152826572419144, 0.03421672976401169, 0.02318405702681048, 0.09022255166200921, 0.08426888714893721, 0.022698239736200776, 0.053885394663666375, 0.03624765027780086, 0.02030215473496355, 0.017134243571490515, 0.05892511173442472, 0.05104300616949331, 0.03917495901987422, 0.039339433787972666, 0.03926180514099542, 0.007629896881553577, 0.058529380039544776, 0.057209711594623514, 0.022788108253735118, 0.06201670599693898, 0.021503085117728915, 0.021155758149689063, 0.06962662519072182, 0.018693445745157078, 0.0632895746093709, 0.06015870960254688, 0.07819830469088629, 0.025719715886225458, 0.07286246327566914, 0.026262346436851658, 0.01724603327602381, 0.0331377954717027, 0.09077013790374622, 0.03341255338455085, 0.033949500939343125, 0.03597780167183373, 0.04695858158811461, 0.07656409550691023, 0.061911866505397484, 0.015073101876623696, 0.01513906303443946, 0.025107351284532342, 0.027741897611122113, 0.02875091046007583, 0.026067037288157735, 0.057869466036208905, 0.05203607026487589, 0.031005393684608862, 0.01893536733405199, 0.0435768038732931, 0.055808614706620574, 0.020397726657392923, 0.07502220207243226, 0.03396779859031085, 0.029725817912549246, 0.01178652593807783, 0.016122451379487757, 0.05058393959188834, 0.029626609466504306, 0.037548846667050384, 0.040382681909250095, 0.022810344853496645, 0.009375667559652356, 0.016820897690195125, 0.02860657015844481, 0.04155501548666507, 0.021857419815205503, 0.03838357726635877, 0.0695741108211223, 0.03035161909792805, 0.08407155008171685, 0.03936033637728542, 0.017113481990236323, 0.016133474127855152, 0.017125649501394946, 0.019129546562908217, 0.027833476779051125, 0.010813833796419203, 0.008799025308690034, 0.05751964359660633, 0.0685291965783108, 0.0421372117853025, 0.020538649368972983, 0.06963002422708087, 0.04283114583813585, 0.01585137451911578, 0.051726000965572894, 0.03996605875727255, 0.036849079333478585, 0.02452417535096174, 0.07268560206284747, 0.020902602300338913, 0.023657602905586828, 0.011321157599013532, 0.0016347201062671957, 0.0499816941737663, 0.02789492475130828, 0.025125381762336474, 0.07862580401706509, 0.04218516936816741, 0.012313047245697817, 0.09355445334222168, 0.0982342436327599, 0.020031816311529838, 0.027007792959921062, 0.007904930316726677, 0.041042903903871775, 0.029950445605209097, 0.037393166348920204, 0.07399521069601178, 0.038084202315076254, 0.023124000581447035, 0.03979424785939045, 0.0637075596023351, 0.018934487889055163, 0.04472952990909107, 0.01547374195070006, 0.03955281608796213, 0.0724226888269186, 0.026483849687792826, 0.05985087416775059, 0.012928416617796756, 0.052563273420673795, 0.036018441678606905, 0.03082207949773874, 0.028907490632263944, 0.002287111979057954, 0.020002217606815975, 0.016750263785070274, 0.016807449974294286, 0.013254617424536264, 0.050740614387905225, 0.181687681179028, 0.03314376233902294, 0.06041774511686526, 0.03798187870415859, 0.042801942327059805, 0.09033059352077544, 0.03892335982527584, 0.041513915348332375, 0.0344083448726451, 0.09715976964798756, 0.01572768818732584, 0.009525897730782162, 0.06337091399473138, 0.01779997044650372, 0.05094355838082265, 0.06813772110035643, 0.011421427316236077, 0.044948296490474604, 0.05408764845924452, 0.03911673011316452, 0.034648852670216, 0.04859500237216707, 0.04672518356528599, 0.04799889080459252, 0.0442456310702255, 0.032335173891624436, 0.014328408633446088, 0.028383857206790708, 0.08083937820629217, 0.04147097839449998, 0.06494941015262157, 0.045228720700833946, 0.03118281892966479, 0.024160189022950362, 0.07434448023559526, 0.030111860869510565, 0.007580633118777769, 0.09008195920614526, 0.014119674960966222, 0.022295186754490715, 0.11465909978142008, 0.0368745943706017, 0.08236226523877122, 0.04691866517532617, 0.0138993786276842, 0.05692329825251363, 0.07407537748804316, 0.0793172481644433, 0.027494242931425106, 0.05209413960983511, 0.09457849839236587, 0.023770852785673924, 0.042042279965244234, 0.010438141016493319, 0.02605830035463441, 0.030633362475782633, 0.03257481708715204, 0.03901890762790572, 0.03473044438578654, 0.03044619097636314, 0.10381709405919537, 0.035747053116210736, 0.05042837801738642, 0.013003918083995814, 0.017634137548157014, 0.023924399429233745, 0.04848695680266246, 0.032729870290495455, 0.060690651371260174, 0.031893848354229704, 0.03524473788274918, 0.008340029235114343, 0.029708537003898527, 0.00749391548197309, 0.02788969261018792, 0.04065894638188183, 0.019634945419966243, 0.03112675894954009, 0.01948982957401313, 0.009617943524062866, 0.01998223156988388, 0.023582514259032905, 0.034962432328029536, 0.0511315147014102, 0.012109901017538505, 0.027057622610300314, 0.034733546563074924, 0.05180903244763613, 0.014842643686279189, 0.11053994268877432, 0.015986929647624493, 0.06410071233403869, 0.033915451203938574, 0.05364981472666841, 0.0251740221210639, 0.008913522924558492, 0.05079607137304265, 0.042437633164809085, 0.00945825189774041, 0.06777546397643164, 0.05088787875138223, 0.045973840678925626, 0.007834837251721183, 0.07617029710672796, 0.06422603139071725, 0.03396573541976977, 0.04737042901979294, 0.030803308727627154, 0.05216395344177727, 0.12944146437803283, 0.018987924377142917, 0.07991164166014642, 0.04077659534232225, 0.023059287159412634, 0.08419827921898104, 0.01431026683349046, 0.023537104098068085, 0.028524538720375858, 0.028762037109117955, 0.006301772127699223, 0.013633383623528061, 0.06990671914536506, 0.04935799697705079, 0.004098558320038137, 0.015802236921445, 0.04331469957833178, 0.031017294022603892, 0.06082959625928197, 0.022344645331031643, 0.06727046216838062, 0.09221020867698826, 0.03134612110443413, 0.04326053393015172, 0.028367773011268582, 0.034581747677293606, 0.023505245553678833, 0.02107170435920125, 0.03076458531722892, 0.030275380122475326, 0.04159178519330453, 0.014699498242407572, 0.012664580335695064, 0.011088453484262573, 0.08010425124666654, 0.029698607067984995, 0.03985514849773608, 0.013263525052025216, 0.04884746245807037, 0.041399364854441956, 0.08506946411216632, 0.02859930453269044, 0.005735722179451841, 0.05555326024477836, 0.05808730493299663, 0.06035897444235161, 0.017306050758634228, 0.036973741589463316, 0.2669537253677845, 0.09207146416883916, 0.06683556362986565, 0.11930605745874345, 0.11741774433176033, 0.14373133977642283, 0.11601478836382739, 0.17686242994386703, 0.13581594888819382, 0.19020354375243187, 0.07442181202350184, 0.10313854843843728, 0.12065192000591196, 0.11842777763376944, 0.10351308068493381, 0.13623671693494543, 0.11752594204153866, 0.09534632437862456, 0.16521875630132854, 0.3415656607830897, 0.08341303502675146, 0.20677077351137996, 0.11477927575469948, 0.16893636697204784, 0.23301871115108952, 0.16191750532016158, 0.1954509731149301, 0.10531784282648005, 0.23260610672878101, 0.12151885239291005, 0.27803591976407915, 0.11779888911405578, 0.14041814021766186, 0.13929868466220796, 0.2883877814747393, 0.10829481980181299, 0.13930637331213802, 0.14919587702024728, 0.1026668022677768, 0.22284812643192708, 0.1886166093754582, 0.09042469042469747, 0.07048095591017045, 0.17676323448540643, 0.10858430934604257, 0.20426845934707671, 0.1674603539868258, 0.13438629044685513, 0.13547908805776387, 0.2662601735210046, 0.14304875687230378, 0.09264841719414108, 0.08215635636588559, 0.22454439400462434, 0.14778851269511506, 0.251691933372058, 0.17965115373954177, 0.11550830226042308, 0.13091064960462973, 0.20602846256224439, 0.14688493305584416, 0.2905045647639781, 0.1541419795830734, 0.08730951070901938, 0.11631548433797434, 0.18119208980351686, 0.13101058721076697, 0.14666622213553637, 0.11441942318924703, 0.1780753961065784, 0.1454673270927742, 0.08413438030402176, 0.09136605280218646, 0.16608142876066267, 0.09212356293573976, 0.19492045626975596, 0.07460271051968448, 0.12261254800250754, 0.0664717034669593, 0.150770224572625, 0.10212950961431488, 0.15478804882150143, 0.10759873723145574, 0.058132568519795313, 0.10830886865733191, 0.18014530534856021, 0.1194218176533468, 0.15199169574771076, 0.1841622983920388, 0.10820796625921503, 0.16298912203637883, 0.14171927352435887, 0.11433341569500044, 0.15994023095117882, 0.1007197704166174, 0.14682516048196703, 0.24343901372049004, 0.09559199010254815, 0.10817620233865455, 0.12702139501925558, 0.17083420185372233, 0.11709351485478692, 0.10801470358273946, 0.10763058278826065, 0.11322376391035505, 0.1599063296453096, 0.12320917536271736, 0.07870603760238737, 0.22987492906395346, 0.16781075159087777, 0.13529274961911142, 0.1259698608191684, 0.20567601663060486, 0.2588895190274343, 0.0896999535325449, 0.11505475355079398, 0.16941675916314125, 0.15353923692600802, 0.21123734477441758, 0.14128284616163, 0.09454676415771246, 0.12072870260453783, 0.17371679248753935, 0.21116655872901902, 0.134165842900984, 0.18164727865951136, 0.12301090318942443, 0.13117556663928553, 0.26738090557046235, 0.16402743116486818, 0.21673162729712203, 0.12204580692923628, 0.11238806109759025, 0.1630929484963417, 0.13775084662484005, 0.08736460775253363, 0.14626581862103194, 0.10144942774786614, 0.08274676452856511, 0.09541753344819881, 0.20609157480066642, 0.08555919252103195, 0.1539713449892588, 0.12746505090035498, 0.17308277572738007, 0.08742193123907782, 0.24391008453676477, 0.17163846729090437, 0.14442075043916702, 0.1768621924566105, 0.09647897531976923, 0.09961574411136098, 0.10675524928956293, 0.17547966039273888, 0.13059154094662517, 0.2046828597667627, 0.08263869298389181, 0.09063464400242083, 0.2137602015864104, 0.15646748448489234, 0.1517583942040801, 0.12459593766834587, 0.16591904684901237, 0.09962009309674613, 0.4422741802409291, 0.2225448700482957, 0.14718954014824703, 0.10215062371571548, 0.13307399523910135, 0.0906778073112946, 0.09432725913939066, 0.13728866673773155, 0.12947684997925535, 0.15883971500443295, 0.12364569920464419, 0.23427023930707946], [0.03945747979742009, 0.015580303224851377, 0.018215359777968843, 0.12444282518117689, 0.02523339950130321, 0.030754102481296286, 0.04871581659244839, 0.04568451811792329, 0.05660633440129459, 0.027933683413721155, 0.06017065446940251, 0.06663168824161403, 0.04769048020534683, 0.0610182427772088, 0.04528468976786826, 0.06386204506270587, 0.022706292038492393, 0.03866472878144123, 0.0650337255501654, 0.040717327428865246, 0.029433636227622628, 0.03266910323873162, 0.09537911246297881, 0.010273650477756746, 0.00792785618614289, 0.07805600529536605, 0.02281393128214404, 0.017527726558910217, 0.04607675058650784, 0.07565023712231778, 0.04411365123814903, 0.06259073124965653, 0.042915620797430165, 0.042627348375390284, 0.07797312966431491, 0.05261980651994236, 0.037495300712180324, 0.04106784377654549, 0.028463734561228193, 0.02223057352239266, 0.037448319053510204, 0.06278435015701689, 0.0778731846367009, 0.05237544697592966, 0.01608526235941099, 0.023568005271954462, 0.033914167288457975, 0.08908883944968693, 0.0513538287486881, 0.01651615515584126, 0.12648937903577462, 0.03920230345102027, 0.044099769365857355, 0.031715573350084014, 0.01767350477166474, 0.013291639461385785, 0.025287628232035786, 0.04638570666429587, 0.03786069712077733, 0.040262851034640335, 0.0869815111218486, 0.040874210026231594, 0.02272237623401452, 0.03980940251494758, 0.01670361052674707, 0.05017971030611079, 0.028582097838807385, 0.03447231800237205, 0.04024516936624423, 0.04411575151607394, 0.08100830586045049, 0.0673428586742375, 0.0599962126580067, 0.09328895743237808, 0.006851850130260573, 0.036579171355697326, 0.02583829624200007, 0.0336386635171948, 0.03693615180964116, 0.05735463819291908, 0.03979391018219758, 0.021570473982137628, 0.048055115912575275, 0.04064915745402686, 0.02566653914982453, 0.040879408770706505, 0.03837875701719895, 0.03418392312596552, 0.05668123936629854, 0.036426975420909, 0.050376936051179655, 0.07156586449127644, 0.04053215045132674, 0.04516037632129155, 0.015532461602560943, 0.034933054412249476, 0.11848146459669806, 0.023444359758286737, 0.05399242720159236, 0.05451734825328458, 0.03458765146206133, 0.06478736220742576, 0.007422525050060358, 0.04714608148788102, 0.029745724168606102, 0.013320052585186204, 0.10027284166426398, 0.04072759875271004, 0.09846626126090996, 0.023679642836214043, 0.04974718664016109, 0.02611572403111495, 0.013471751281031175, 0.017372881156916264, 0.04719413183920551, 0.05583400728937704, 0.050577579386299476, 0.05810424445371609, 0.01601658030267572, 0.06426170642953366, 0.043303971833665855, 0.027423401224950794, 0.08799733317573555, 0.027319726905261632, 0.048989769275067374, 0.04382535284094047, 0.03775509321712889, 0.02319625793461455, 0.04170653235632926, 0.010856346798391314, 0.01956465290277265, 0.013717196216020966, 0.028187857860757504, 0.016826048195071053, 0.028839610095019452, 0.08096673074760474, 0.058164254514849745, 0.0587280529725831, 0.03363955780514516, 0.01615370507352054, 0.058479893632465973, 0.010275388031004695, 0.08241790405008942, 0.04349327144154813, 0.048322489456040785, 0.09953516913810745, 0.03454454010352492, 0.04816977772861719, 0.07601873570820317, 0.005249076466498082, 0.07625604484928772, 0.01917058732942678, 0.03224017156753689, 0.03264600018155761, 0.01827570937166456, 0.03336751615279354, 0.024728124953981023, 0.011387001868570223, 0.02975968582177302, 0.09757730935234576, 0.04853413513046689, 0.015202875674731331, 0.013757644192082807, 0.07955839420901611, 0.04616748927219305, 0.06381480736308731, 0.07611858425661922, 0.041617519163992256, 0.04096812510397285, 0.055930338057805784, 0.0513006241817493, 0.022121546462585684, 0.024440420274913777, 0.018188351168646477, 0.05515448203368578, 0.027257371657469776, 0.06245312964892946, 0.04352509473392274, 0.07798012069542892, 0.05534397831070237, 0.042602883477229625, 0.02180736009904649, 0.029571169179689605, 0.03289753629360348, 0.0033897636876645265, 0.016294199194817338, 0.03498024758300744, 0.06641126296017319, 0.023985040315892547, 0.03243094062781893, 0.005715324714401504, 0.02673307215445675, 0.005573524877036107, 0.024908272025641054, 0.05033701592765283, 0.047124856064328924, 0.058752157929120585, 0.05614672234514728, 0.04225125019729603, 0.046337782478076406, 0.019952126349380706, 0.013453397041303106, 0.08855610358295962, 0.0440473292110255, 0.024747383686190005, 0.02659100468008546, 0.017917226068675518, 0.05833131195686292, 0.021256072395772208, 0.027397535523050465, 0.042845985080930404, 0.025953048971132375, 0.03805511754762847, 0.030602784136135597, 0.03737905812158715, 0.04178922616119962, 0.04853338927205186, 0.03858771982777398, 0.05399818255682476, 0.05579446937190369, 0.06994184499490075, 0.03553764501702972, 0.015745123091619462, 0.047065491671673954, 0.03759344603167847, 0.015676389084546827, 0.04994701732357498, 0.02587420320196543, 0.023576753337692935, 0.025482655364612583, 0.05294153495924547, 0.042169409862253815, 0.04102622784557752, 0.0111297456533066, 0.057868786971084774, 0.054122106375871226, 0.018530705747252796, 0.020558897012961097, 0.044974334741709754, 0.06121472266386263, 0.07162235677242279, 0.05451279888802674, 0.013248602317617042, 0.04672932474932168, 0.02073317184112966, 0.04791490195202641, 0.025900853725033812, 0.012473778806452174, 0.08570007441448979, 0.04961401195032522, 0.011099705370725133, 0.07829327732906677, 0.021845133560418617, 0.1111317312461324, 0.12129459020798095, 0.04156284514465369, 0.041714028047863394, 0.023941294421092607, 0.0624877359950915, 0.03339402566780336, 0.01723253917589318, 0.09065240359632298, 0.0499978952575475, 0.04737784678582102, 0.017335794182145037, 0.03703710615809541, 0.03670618621981703, 0.03773258016735781, 0.05666504941473249, 0.021216809072939213, 0.07272929971804842, 0.02635908909724094, 0.027266641081951093, 0.022373225438059308, 0.019276263592473697, 0.03699224333104212, 0.032628826884320006, 0.06257302360609174, 0.026685031079978216, 0.053737748094135895, 0.047246490357792936, 0.07000652316492051, 0.04300312742998358, 0.041456295002717525, 0.022428361444326583, 0.01874842775578145, 0.04848076729103923, 0.0025454600790908444, 0.02056565983366454, 0.03826594685961027, 0.038666550753987394, 0.05067589911050163, 0.0452873800531961, 0.05193733493797481, 0.0365783809684217, 0.04255350097082555, 0.046545594959752634, 0.046758643293287605, 0.016077601540018804, 0.03323814496980049, 0.06308208496193402, 0.026342520650359802, 0.06560002133483067, 0.054082742863101885, 0.023048075163387693, 0.007937170139484806, 0.02891699939937098, 0.003371581301507831, 0.04538813773251604, 0.03434846468735486, 0.02429437117825728, 0.014536147828039248, 0.04744155645312276, 0.04424179045599885, 0.04682862781919539, 0.012019119658361888, 0.02159887782909209, 0.06271886304602958, 0.11535970203112811, 0.09056283379322849, 0.05202886401093565, 0.06057301725377329, 0.0963142556429375, 0.026366955862613395, 0.07854179290006869, 0.061394404037855566, 0.03614213543187361, 0.011758123018807964, 0.03300648357253522, 0.044093605829402804, 0.04129895598453004, 0.025716329837450758, 0.08697593017132021, 0.04580265318509191, 0.057032115655601956, 0.03651456368970685, 0.04154351590841543, 0.032301228056894615, 0.04040029307361692, 0.03354356471390929, 0.04481433141336311, 0.10619289430906065, 0.026867245032917708, 0.06964773187064566, 0.048608739525661804, 0.00928264398680767, 0.0736662388953846, 0.05957638713880442, 0.05897096161788795, 0.055473776228609495, 0.023537451052106917, 0.033138233338831924, 0.24951037543360144, 0.08898413725546561, 0.1447998543153517, 0.20495794422458857, 0.1932972457143478, 0.08116213080938905, 0.12955954007338732, 0.10351880264352076, 0.20512428920483217, 0.08848644560202956, 0.1804386911680922, 0.14123297383775935, 0.14126016612863168, 0.09598092001397163, 0.11786029441282153, 0.1421911161742173, 0.1145950004865881, 0.13144072116119787, 0.11764011404011399, 0.15003043692559004, 0.12653528829105198, 0.19698707037605345, 0.2313497694558464, 0.1186074961151462, 0.10111841504112817, 0.15848870883928612, 0.11571404043934308, 0.15154835156863555, 0.10902136753429659, 0.18089085206156597, 0.11689167295116931, 0.16427254769951105, 0.1119548398128245, 0.08595895778853446, 0.10927899667876773, 0.09035238297656178, 0.10649702642695047, 0.14213668706361204, 0.081513641634956, 0.0767897380865179, 0.1953982064151205, 0.24424801405984908, 0.19660257850773633, 0.1893194529111497, 0.18154961202526465, 0.19471231353236362, 0.082936902763322, 0.18459271435858682, 0.08190577020286582, 0.10224708807072602, 0.17557777231559157, 0.09315323346527293, 0.15060438425280154, 0.10930884585832246, 0.18183305306592956, 0.14906043506925926, 0.151942906959448, 0.11081362448749132, 0.09578389464877546, 0.09413963678525761, 0.09820279883570038, 0.09063436940778047, 0.119507647032151, 0.12702774780336767, 0.15604998188791797, 0.1497579796705395, 0.08239545408287086, 0.16009339538868517, 0.11816495345556177, 0.1372442120919004, 0.19859325606375933, 0.1350529765477404, 0.20654780266340822, 0.19252419500844553, 0.09832515672314912, 0.15862802480114624, 0.15367553976830095, 0.1827151104225777, 0.134914209775161, 0.15573678072541952, 0.1478540591779165, 0.12719989637844265, 0.144764157012105, 0.08855535401380621, 0.1127197417372372, 0.17789981880923733, 0.0782857890590094, 0.07772810960887, 0.1244932170084212, 0.12663460249314085, 0.16307169338688254, 0.19309508468722925, 0.12508649728260934, 0.2134318309254013, 0.1360300139640458, 0.20843336242251098, 0.14244834455894306, 0.10999231191817671, 0.12032956816256046, 0.10304663344868459, 0.06563576316693798, 0.19165549630997702, 0.06946542329387739, 0.12681758642429486, 0.12990774092031643, 0.22654048923868686, 0.1477326438180171, 0.14876096363877878, 0.13330239860806614, 0.12369712261715904, 0.1926614626427181, 0.14781763456994668, 0.12646153365494683, 0.10322398447897285, 0.15012494201073423, 0.11614151007961482, 0.11364090285496786, 0.1200406278076116, 0.10753350987215526, 0.229306859546341, 0.2229428690043278, 0.13927692489232868, 0.16625014861347154, 0.14652392274001613, 0.1648820290574804, 0.1286707291728817, 0.0907062018814031, 0.10218238763627596, 0.11208260053535923, 0.1017471551313065, 0.14432707655942068, 0.14570895553333685, 0.11169119185069576, 0.11392038082703948, 0.11093465393059887, 0.18705600639805198, 0.16927235206821933, 0.13203436508774757, 0.19202038063667715, 0.1456901346682571, 0.1672250041156076, 0.19386231695534661, 0.24902887002099305, 0.1805730941123329, 0.13799398904666305, 0.27448916633147746, 0.2149597051902674, 0.17342352541163564, 0.20380476547870785, 0.2406352836987935, 0.16779158933786675, 0.16255259077297524, 0.2211112782242708, 0.09466098810662515, 0.12427328896592371, 0.10975933691952378, 0.19530248420778662, 0.17742169759003446, 0.15037759876577184, 0.1686955994227901, 0.15162424359004945, 0.08827021345496178, 0.0925519602606073, 0.2113172147073783, 0.12886748736491427, 0.14821928489254788, 0.15652045898605138, 0.11348016851115972, 0.13455881009576842, 0.17560880893142894, 0.16307935235090554, 0.1352254961966537, 0.16130504052853212, 0.13432055100565776, 0.0975464285875205, 0.14290109917055815]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.022219623133423738, 0.05596445458650123, 0.041426976458751597, 0.009420996084372746, 0.03789860231336206, 0.035732443939195946, 0.007533630123361945, 0.023027441602607723, 0.02444233872665791, 0.0470115894859191, 0.04151649060077034, 0.017589452836546116, 0.051154773609596305, 0.0456327496067388, 0.008519937891833251, 0.0039085536718630465, 0.010469831649970729, 0.0014478278399110422, 0.004662794644900714, 0.02011928583669942, 0.045832940231775865, 0.018194143631262705, 0.054717457242077217, 0.06766092832549475, 0.03509286849293858, 0.012660758275160333, 0.012907155014545424, 0.0728997858823277, 0.037293017230695114, 0.022677246233797632, 0.02718076531891711, 0.02499326834367821, 0.011277189987595193, 0.059891529017477296, 0.03413292644836474, 0.08192792331101373, 0.009922361368808197, 0.03280235956481192, 0.02110489320330089, 0.08643549081170931, 0.020341900453786366, 0.07160995548474602, 0.008943126267695334, 0.02651380647876067, 0.03291326982434839, 0.02441941378492629, 0.03781073944992386, 0.06208113183674868, 0.034537081519374624, 0.03504333755699918, 0.011737223212548997, 0.04400860023451969, 0.016655311555950902, 0.04195438370516058, 0.028806244990846608, 0.021207517384027597, 0.07779027189826593, 0.03843192447675392, 0.04514544431003742, 0.03161803288094234, 0.0361939484719187, 0.032486111886100844, 0.039222723644343205, 0.07958846603287384, 0.008704471056262264, 0.010468460532138124, 0.11690751780406572, 0.04490097344387323, 0.0036242777150619077, 0.02177270180254709, 0.02567349307355471, 0.03348597776493989, 0.011146726919832872, 0.06555517335073091, 0.03214938835299108, 0.01772134917700896, 0.019550348006305285, 0.033548010178492405, 0.005725177188651287, 0.05365338445699308, 0.037277458104654215, 0.011604759129113518, 0.036508273988147266, 0.019119226999464445, 0.049224221147596836, 0.05295648552419152, 0.11923499681870453, 0.022901556658325717, 0.04437873525603209, 0.025646688554843422, 0.054239718228927813, 0.007312569377972977, 0.08450160239590332, 0.014317845088953618, 0.05080771938082762, 0.09088019098271616, 0.04593061799823772, 0.07011462439550087, 0.025238358903152402, 0.07513842239859514, 0.10433823015773669, 0.05941018316661939, 0.011225125545024639, 0.0040052272197499406, 0.052785765583394095, 0.03367427547345869, 0.03432919111219235, 0.04922526757582091, 0.037547562751569785, 0.0396381408063462, 0.007893433521530824, 0.02977278287289664, 0.04575242091959808, 0.05381599272368476, 0.03006760474818293, 0.006800491191825131, 0.0732534340932034, 0.009016541371238418, 0.004724539476228529, 0.05202660046052188, 0.0679986723116599, 0.07451665849657729, 0.023333536701102275, 0.029890071891713887, 0.062240912520792335, 0.06925376277649775, 0.03337286332680378, 0.014155806420603767, 0.06291958430665545, 0.017493480154371355, 0.0704930083884392, 0.02003325422265334, 0.025303775510110427, 0.00960486038820818, 0.031116289101191796, 0.1122562334057875, 0.014576003013644367, 0.04328194489062298, 0.02803050956572406, 0.006327642004180234, 0.02237200089439284, 0.05302668527292553, 0.03818765027972404, 0.02133552301529562, 0.043031239983974956, 0.03694629325764254, 0.01738510989525821, 0.09679850700194947, 0.047948324572644196, 0.049241387023357674, 0.10549172802711837, 0.025910952499543782, 0.03956279055273626, 0.08315317201777361, 0.009285691430704901, 0.015342146180046257, 0.031244253914337605, 0.016252507193712518, 0.0336249412066536, 0.047614172581234016, 0.04449787222256418, 0.03322699049022049, 0.030035915042390116, 0.02832819242030382, 0.021002905414206907, 0.053041940118419006, 0.044643893488682806, 0.024091338127618656, 0.059064067754661664, 0.04403678700327873, 0.015693660716351587, 0.024429161894659046, 0.028972673462703824, 0.03745266061741859, 0.04542288137599826, 0.01564910402521491, 0.04774696135427803, 0.0841069505258929, 0.02936004300863715, 0.04509297818003688, 0.0762516439135652, 0.04284320202714298, 0.01734253288304899, 0.01991621196793858, 0.017829237040132284, 0.11964201286900789, 0.057665531276143156, 0.02765730576356873, 0.05612579749140423, 0.023009986289252993, 0.054105096351122484, 0.030363795885932632, 0.05459149993839674, 0.009985127580875997, 0.07681321221753024, 0.09210400734446011, 0.022055803310649935, 0.055410626882803626, 0.004231474185871775, 0.052360381378093734, 0.044553900661412627, 0.017859973086160608, 0.043515090583241545, 0.07943067059386522, 0.045888367531006224, 0.026993632782250643, 0.020754829565703403, 0.05765112990047783, 0.012454977422748925, 0.029207860061433166, 0.04204383476462681, 0.09601430923794396, 0.006995665362410364, 0.07362712029134855, 0.07541602273704484, 0.037156157777644694, 0.04908907605567947, 0.07382645373581909, 0.05526383378310129, 0.020197565718262922, 0.026498134175199084, 0.02224769301392371, 0.027457794203655794, 0.02059677066426957, 0.008441248901362997, 0.029284479387570173, 0.018884491255448665, 0.054421347740571946, 0.02441884975269204, 0.04338458020356484, 0.02885110596253071, 0.05196460886509158, 0.06980289268540218, 0.03675031060993206, 0.02165410103771137, 0.04024308764201123, 0.02640767936100019, 0.06016883620759472, 0.019707649917108938, 0.04008588592114393, 0.041819156976998784, 0.037616623303620145, 0.013018785157328239, 0.034319524638704024, 0.05595229449681938, 0.012763127342623193, 0.007436933383360156, 0.011065592552768067, 0.030172405276971404, 0.0876854159287177, 0.02287516774231335, 0.00887305732248933, 0.0668347546888981, 0.0407338699005777, 0.0159203330258606, 0.12845552118960768, 0.016574936962570064, 0.05101842623844277, 0.07897576375398785, 0.00904789061678457, 0.04076641678693704, 0.043784827867057174, 0.018287140301254112, 0.021694720635423437, 0.10158498102100566, 0.031280240655178204, 0.05104675030452199, 0.005458618152260897, 0.010801277585414937, 0.047291394002968445, 0.03942319999623578, 0.04433199479535688, 0.01124661535868654, 0.037901188698015176, 0.03151234734104946, 0.08907078299671412, 0.03617162838054355, 0.0698595482390374, 0.024855301235220395, 0.06600369029911235, 0.025391953786311205, 0.03876027658407111, 0.05537659199035261, 0.04212430583720561, 0.009565386480971938, 0.04692715905548539, 0.020003629542770796, 0.014602150731661823, 0.08023586371564306, 0.01915112265123753, 0.027614129467110615, 0.024725668445171323, 0.02887008638936095, 0.02960007212095661, 0.032663908204995096, 0.03147296156384982, 0.006002806285323459, 0.09294580318965018, 0.044317485808278434, 0.018396063460386358, 0.04786061013874132, 0.06670088609098457, 0.04934989272442181, 0.07272417889907956, 0.03989360287960153, 0.011425579632486915, 0.035431662618066184, 0.028858742662123404, 0.03454593534115702, 0.02343000662222039, 0.0052125822821835754, 0.049628647102508694, 0.014474095005425625, 0.01919909322168678, 0.055480511218775064, 0.012169807177997427, 0.02129102940671146, 0.0517120560107287, 0.04242705756041687, 0.07169585165684111, 0.04567993164528161, 0.0071319190374197206, 0.02469447597832186, 0.10955621852190234, 0.04297508538002148, 0.015413402561534895, 0.0578486859012628, 0.07117386950994842, 0.030985507837613113, 0.02640742332005175, 0.058288846266805194, 0.06572482830961235, 0.016571103769820184, 0.02409761855233228, 0.01992075576708885, 0.023859971734054852, 0.06835102176410146, 0.0381022736110026, 0.04425655548402574, 0.06725206432747655, 0.035708101495401934, 0.11198788022738881, 0.016464538784930483, 0.07313354755751789, 0.033463880317867734, 0.019022196756850462, 0.05181778236874379, 0.09111720326473005, 0.010691535280784592, 0.0178754895387101, 0.036959236313123256, 0.03152888239128515, 0.16462502331705764, 0.12470038753235713, 0.11252109849010594, 0.1259141106856987, 0.21942682564258575, 0.10925472844974138, 0.12962434440851212, 0.07269741705385968, 0.12284897398785688, 0.2567020832793787, 0.12003398558590561, 0.12080376342055388, 0.10658560917363502, 0.1466511862236075, 0.12969339382834733, 0.13531979348044842, 0.12967245042091236, 0.12239094270626083, 0.15833797864615917, 0.11115499015431851, 0.14365347364218906, 0.15524825459579006, 0.10764219739940017, 0.33852730819489807, 0.1263768842909485, 0.11776217506849207, 0.16999444691464305, 0.13205548661062494, 0.16851019609021023, 0.13678357587195933, 0.17867438349639997, 0.10987996560288593, 0.07583851998788305, 0.15135163790546358, 0.15377136587630957, 0.14922505826689303, 0.10891518846619874, 0.13037876720773056, 0.14328934630611911, 0.17059517093002796, 0.09617367060855031, 0.1590476350975223, 0.1569510085391812, 0.17611281626159325, 0.1176865873276256, 0.11684393059113063, 0.1424837004742585, 0.2628442755667493, 0.12148063178756274, 0.07889654691098258, 0.12033127510221675, 0.19543954404070973, 0.10305923511623405, 0.1450626933365129, 0.11210560711333528, 0.13879608741262928, 0.141714597993996, 0.1590104089700617, 0.13695407687919214, 0.10424640422570519, 0.07290791239938699, 0.12542369950097054, 0.16612242499832064, 0.09932933447998948, 0.12294334548641928, 0.05810426300740801, 0.22521323233377188, 0.0988326892547775, 0.18381488422164693, 0.09339464668300934, 0.13014214084250852, 0.10434431576868519, 0.1044295662723016, 0.14138768194243312, 0.10084408015245572, 0.1077129686018452, 0.14561838383087888, 0.1280700200004503, 0.08998897552373819, 0.1774161760113202, 0.13908736553275958, 0.1648256555199623, 0.19532268546754494, 0.11718709967681207, 0.15582892578095198, 0.14081518922466785, 0.25631450407672673, 0.09723809591378085, 0.16602599032921717, 0.15849365154281259, 0.15212928992696106, 0.08875058338162489, 0.17842666944488883, 0.18530274188378826, 0.10487728170119226, 0.21801055554533377, 0.09618047610274516, 0.1375114149414003, 0.0894889906339813, 0.15094050293555483, 0.24821842991514131, 0.2625486929900944, 0.15822664165170863, 0.24839063786203042, 0.14745364082045853, 0.16354276420315728, 0.11248478520428762, 0.20655678265029564, 0.21143126796232536, 0.10481929770321585, 0.12354059625067748, 0.09334942020359449, 0.1187475468032062, 0.11537059675902128, 0.12479354190872982, 0.06521973002236336, 0.15488055010791868, 0.08657447280711494, 0.08798657945590094, 0.14524478669045493, 0.17635750235058367, 0.2382517873775214, 0.07882181263994426, 0.13181387301301584, 0.12235650705406442, 0.19018369872355834, 0.13980803545564413, 0.12502930738264695, 0.21328289672965184, 0.07287401851499453, 0.10935610582237132, 0.10462555263075046, 0.10161480051465333, 0.09330100991064683, 0.1795474608661607, 0.2182483990327455, 0.16065793228335679, 0.13395378162385896, 0.19933902542106807, 0.05256179654679727, 0.11217974766623229, 0.14040120440768078, 0.08892591577023268, 0.17222789581865072, 0.12155174437793903, 0.11588776978896931, 0.10091943782754242, 0.14848000137135386, 0.15272743126843125, 0.11268152855336666, 0.16531637840671465, 0.11067735133110546, 0.1384162562317215, 0.25584629795048386, 0.10890895442571491, 0.12944732734467834, 0.1430803575203754, 0.09251285649952479, 0.15234541817335412, 0.14146326226182282, 0.08620503911515698, 0.09169187789666466, 0.06887013179948553, 0.08459645629045554, 0.0914142924011685, 0.2078403567429632, 0.10798106202855706, 0.18734850164037198, 0.1526052737608552, 0.075170809723204, 0.11006817425368354, 0.18563270074082538, 0.14352825848618522, 0.09192521654767916, 0.12988363596377894, 0.16487070388393477], [0.029727764194831252, 0.021268019117997028, 0.03925990153220482, 0.020884998557448853, 0.039589993975823745, 0.04108372944756411, 0.02465140543790767, 0.058809147449210286, 0.049031782255042344, 0.05000933917472139, 0.01299991976338788, 0.049587083121878095, 0.09445077477721497, 0.06089477908972185, 0.05704091010557022, 0.04280425040633418, 0.08017282569198869, 0.008811580592009705, 0.05470654767123051, 0.062480722699547186, 0.01951713133166777, 0.013183374030631967, 0.06388753041392192, 0.020055015847901814, 0.018512172464397736, 0.04091461996722501, 0.019297936160000972, 0.014998440892668441, 0.058671527294791304, 0.06928067305125296, 0.020201345105306245, 0.005467415849125246, 0.05240529615548439, 0.006726260653522331, 0.07572850401629694, 0.0293225181667367, 0.00390667835745262, 0.0797289471665863, 0.053148018996580504, 0.06751259526936337, 0.036833071208093315, 0.016533601192350034, 0.04586450377246365, 0.033416189908166416, 0.04225627453706693, 0.07839786077965982, 0.028147614902991336, 0.07419726040097885, 0.054549208653043024, 0.050105948248528875, 0.031309562909882516, 0.02249311382911401, 0.02941986567748245, 0.010531646985327825, 0.026704425254138187, 0.03823746694251895, 0.01789495421689935, 0.07541856830357574, 0.02902919728512643, 0.012179332643427188, 0.06114447096479125, 0.040935927027021535, 0.038715473128831945, 0.02736971426202217, 0.01575911071995506, 0.0396350868686568, 0.0794052891433239, 0.027766047096520197, 0.02198623067670269, 0.03513491858029738, 0.07291407964657992, 0.011620629957178608, 0.04273334561730735, 0.11271415336523205, 0.011400703770050313, 0.0107366161137179, 0.022776434270781465, 0.04944089858327061, 0.024932900196290575, 0.03734943900781218, 0.03511145929223858, 0.03627822305134032, 0.04126714382437058, 0.03238565848732833, 0.02239106295746751, 0.031024860218167305, 0.07891569432104006, 0.04743050958495587, 0.014531052056554472, 0.03315312824270222, 0.062499862688127905, 0.021702385165554006, 0.022732903598807752, 0.009460840137762716, 0.07040268159471452, 0.03356891276780516, 0.0533067940705223, 0.03576044888177421, 0.04552979888103437, 0.036684355945908464, 0.013912181602790952, 0.06886426141136326, 0.04643365311494563, 0.03090611473453464, 0.038409493063227274, 0.03158793137117755, 0.036892216667183675, 0.0379584824986523, 0.009827928643062478, 0.041134054481517524, 0.046821610812912695, 0.04405211606353987, 0.010351657620049082, 0.023137804528232664, 0.015394933288916945, 0.03744055618881248, 0.016635015672363807, 0.017933861308847554, 0.020043991244165227, 0.02220027719886275, 0.04149278269323986, 0.013896460131945787, 0.013758429013250861, 0.02585265494417399, 0.03950976039050147, 0.0746689694642555, 0.02758602990070358, 0.05368671801988967, 0.042212651096633635, 0.08451266039628536, 0.022333960259857122, 0.026412321494717617, 0.019496618369885255, 0.04100838290469255, 0.037520099576795474, 0.09724398114485666, 0.01836089308199007, 0.023860316832724493, 0.05386203185480554, 0.01127889043345931, 0.06945454340893775, 0.027060157044616062, 0.07828801550203934, 0.10135200602235273, 0.07351231746724807, 0.06663067892077379, 0.035810373155982234, 0.05711699137464166, 0.041647308971732855, 0.04721261873783078, 0.027444990300864447, 0.03390397389011923, 0.10157845754292794, 0.028225579371792264, 0.05712313635740429, 0.09100548035348766, 0.05446119364933111, 0.03433183315792121, 0.018356557084189262, 0.012235333251737757, 0.07886695748311467, 0.04402627077070065, 0.05208283670071978, 0.03670641628559679, 0.06641598301939666, 0.05901112293940969, 0.08498239534674212, 0.05736808219808154, 0.03232941853639204, 0.052679029904538766, 0.03969414327002596, 0.07162471680203453, 0.00966293251622119, 0.026749891076178756, 0.0036961308296667994, 0.11259466016781516, 0.004828980527236126, 0.01770334467437351, 0.008143019640556304, 0.0935165592818521, 0.022957547989790328, 0.017416567679902073, 0.04102405335288495, 0.005471539870995912, 0.02919772046880098, 0.029689103866985533, 0.040202362288255244, 0.038924973996472545, 0.040796978428261355, 0.0918417249340564, 0.029233026289148256, 0.05100217320432421, 0.020594906018231995, 0.012356567713140976, 0.029391163116088137, 0.06376818564604037, 0.040261979011120275, 0.04970853558916133, 0.015788227028679103, 0.06833028615801595, 0.025030292235896923, 0.04129244734940585, 0.04257087464793585, 0.034627085478859954, 0.020100361070944928, 0.03736512800969649, 0.08643146094982512, 0.009909151140163885, 0.07216275902464986, 0.09384628807310946, 0.04763468183227815, 0.027450051748019177, 0.009930800515576266, 0.04452088993275538, 0.05030458778492175, 0.040565947856521234, 0.08179098964319564, 0.011503919813549146, 0.04324664834712166, 0.04356468460173346, 0.03111599595285952, 0.04094730415090453, 0.005609471727439086, 0.017964821854548063, 0.05889510670385789, 0.030222186687751673, 0.003917826807082747, 0.01053397176292492, 0.035457081175991334, 0.04833765895455144, 0.09044555961736478, 0.038661663711536676, 0.07293862247024663, 0.06625913010793738, 0.05839331468450837, 0.00390088635867869, 0.06061231768399011, 0.05234712290985044, 0.025157090021821205, 0.032211613724939525, 0.03331585896376055, 0.03173414930643048, 0.09148302269750275, 0.05453468853374943, 0.02674976862181211, 0.044271057049627416, 0.02145576392649673, 0.028750515266438015, 0.036741505027748644, 0.13370725500863045, 0.04823910174309276, 0.04261319190845825, 0.03137402956781443, 0.036490083948592655, 0.03819127938186284, 0.01723663768643746, 0.040607652845210396, 0.08364787281607278, 0.033921811409527436, 0.024450506061839405, 0.027896865467482712, 0.014623358529206598, 0.014355978491948918, 0.02177538652176736, 0.022325277132040355, 0.03328570550365839, 0.019879141691490076, 0.04158380710578058, 0.05256742573692463, 0.0310894864378497, 0.015821256311028264, 0.011125593337055761, 0.07371159153990448, 0.018873310800699983, 0.06836521162767895, 0.05141636953339912, 0.02844120481313439, 0.0501527517917566, 0.05204165863688104, 0.019189205959264655, 0.02703534333704738, 0.0718872960715089, 0.05143003618286457, 0.059410416943137534, 0.11047537584090605, 0.0610583669913467, 0.019393691763980314, 0.0046107371599646285, 0.017024363041855395, 0.04049831593874842, 0.04951471259118989, 0.053468493206310086, 0.01524771067124675, 0.04365397238871083, 0.0020615528910639114, 0.03236124182876665, 0.07781776104820892, 0.029115722427377477, 0.030218206920835655, 0.08248290134361014, 0.020203499188937712, 0.02509017984266393, 0.02578352203272516, 0.046971795527497306, 0.03515863019856624, 0.0698545238992665, 0.05531181734113488, 0.014449879654421238, 0.010825367698998889, 0.03849358210572973, 0.011957526967307786, 0.039849367167335004, 0.014057854987186147, 0.04879829146375414, 0.029162127066229004, 0.01605842073331587, 0.06338884428259917, 0.015936643576424103, 0.04433648478880059, 0.01623807242140174, 0.05932832798862364, 0.02486707911884878, 0.006502472979263985, 0.0926253957732115, 0.01192047709992039, 0.04407527107105125, 0.0276974373991834, 0.0828948304115329, 0.03023866051080404, 0.0031587238390784478, 0.08164928396581672, 0.09979367401683703, 0.014111528962530429, 0.03872291687002871, 0.026228478527627885, 0.02743574314081343, 0.06950555864023045, 0.011405209534132155, 0.08632150435005315, 0.040240438174805604, 0.03689905926876236, 0.0060366101843101205, 0.044588199016288854, 0.04073015916219447, 0.026135652551602107, 0.052218646014807746, 0.005945838565821759, 0.07543721847468987, 0.014199186807672959, 0.03568624524632469, 0.016269841908069793, 0.03217350444174372, 0.19419503660174087, 0.13683184515684843, 0.10130950322491117, 0.23089548602001742, 0.11421890230849385, 0.07614317903062329, 0.1938134539523162, 0.12864917720435187, 0.15305805805837736, 0.1768969843396917, 0.14511505927657709, 0.16480683465488255, 0.1688029881916009, 0.13440016860840842, 0.22214658907614648, 0.14615509018767625, 0.16861485375557095, 0.09429770681890659, 0.0967655482236296, 0.11794919628300704, 0.09930321088177152, 0.10800398697028868, 0.22232506074942648, 0.16139400919200853, 0.17320184590062127, 0.10449120905832388, 0.1189646843704395, 0.11775783350458369, 0.1291344378842041, 0.25363843829836696, 0.17303116677794605, 0.16656428488204256, 0.13333350943867117, 0.15126022015465423, 0.30301812454126775, 0.10873719918890856, 0.14250443608034402, 0.25225243298336864, 0.12491875706473365, 0.21809713449329138, 0.12947560317115858, 0.10234197907266207, 0.13458015426294878, 0.11225232970900834, 0.0694392403238453, 0.18097012827638537, 0.15805471572093666, 0.13355860282899812, 0.18322941876249388, 0.16344160947483033, 0.08895164603018202, 0.06812347928644158, 0.09128473568125628, 0.09174370949040167, 0.2620879973983392, 0.11686529702274129, 0.15571102820103988, 0.20707273855805397, 0.09861492086201906, 0.16161153267603368, 0.18417801707983017, 0.17391073051840067, 0.14669017866253853, 0.13208107586251572, 0.143399941152893, 0.10419059472042136, 0.12609964760486037, 0.09731120488140732, 0.12916069506900385, 0.14471290429355577, 0.16250396525720134, 0.13800476503092796, 0.18339273578021675, 0.27369866031222045, 0.09535808741929941, 0.13859100232366472, 0.09640692762332037, 0.12377066203043796, 0.16537493385840207, 0.11357670708093792, 0.12264981865882874, 0.1601067095180042, 0.09135880944086239, 0.08915317623177543, 0.23267907468834892, 0.17214030754985288, 0.13061450299574062, 0.08813397740595974, 0.08259555936092511, 0.13313593488419428, 0.21143410296645015, 0.14140764571493492, 0.18625512515427545, 0.12790689594112337, 0.10897410014877096, 0.13806554692564532, 0.19715751201147214, 0.09633002628106624, 0.1630274168564938, 0.17581238003913313, 0.10380999170592986, 0.14066879317397252, 0.2996355341747403, 0.11762915251892991, 0.13124840101227164, 0.16936607047682628, 0.08344206042238511, 0.12793762085493654, 0.18632993364008144, 0.14946356968721375, 0.16479886398883536, 0.13632825342938304, 0.0681796895514708, 0.11338361509842798, 0.16665898292558268, 0.20785459113540128, 0.1378807966830209, 0.14559999341145158, 0.11323243219521828, 0.10298186622094363, 0.1531323025119491, 0.10157827200600877, 0.14503100363072008, 0.15242858324199915, 0.12324731433182023, 0.149276192241814, 0.16574403358390555, 0.1497405392001383, 0.12317669155891053, 0.22502993670059368, 0.21408515836810693, 0.158605151809752, 0.13143205287633464, 0.11726246477337554, 0.12865967117249966, 0.224408580979798, 0.09459929337026551, 0.10312702288501896, 0.1246429601451382, 0.09985104945371859, 0.12608508666744456, 0.14667923940578476, 0.22468519426183775, 0.23047056194627658, 0.18547849729657173, 0.10511778207728639, 0.116320516099222, 0.16290796076646075, 0.11358711941284128, 0.16843848978169262, 0.13266337977256626, 0.20767160720424727, 0.16690861171809956, 0.07951905296067707, 0.1775402037310414, 0.19575155776692554, 0.16846905142301694, 0.12746083550155163, 0.10619360677083023, 0.09840912331128493, 0.16751726187067106, 0.14594866923289374, 0.18208615510957316, 0.11496770704980008, 0.17876060621347278, 0.14507213345495984, 0.21378562756581232, 0.12650471180677414, 0.10654618628905155, 0.17498078872449696, 0.07523057487560436, 0.16044224932556972, 0.09133294559433125, 0.23740176111459732, 0.0817727847606875, 0.15760696318466216], [0.013721932973567164, 0.0081189851880481, 0.005223612915870035, 0.12458582961698994, 0.045264800210134126, 0.011605447471083608, 0.058759167513926513, 0.013718139671254903, 0.02102401209413074, 0.04318252678785939, 0.0594712433667155, 0.052203016384737566, 0.03666241063911002, 0.04627155693015084, 0.046619613058282994, 0.04554859748168383, 0.02868421550374478, 0.030151855207805056, 0.023532204068033025, 0.026333041569159832, 0.0231619206169853, 0.05234426564129535, 0.04687515305704437, 0.05606935344985686, 0.0281868188540102, 0.05670796781487297, 0.023418757518811617, 0.017670150264166296, 0.03855286486214027, 0.0848804390989244, 0.08205596604966559, 0.015674479909648653, 0.10331972895073704, 0.02401476704108063, 0.028251374569663312, 0.055787786332075484, 0.07448089440003969, 0.03166775677527767, 0.06829957608715631, 0.03884678502799943, 0.06771026630303822, 0.02564633232395863, 0.027836183762701694, 0.07318687086808495, 0.01682993704889668, 0.025931266936822794, 0.04032943652418908, 0.022046311241865624, 0.011223094843444414, 0.04336738464189693, 0.054829150467412546, 0.007187892742877011, 0.03952455510443542, 0.02169478186260676, 0.04335503159381915, 0.07662184201763012, 0.02508204404875869, 0.04428463464137167, 0.030521656262862962, 0.09386225166963413, 0.013704810698982328, 0.004969085484844982, 0.015454902531928383, 0.09196363011142239, 0.09025881299749017, 0.06541648079291917, 0.04529238955001347, 0.06817438319558278, 0.057127006657538004, 0.029254004948597867, 0.036122605815762654, 0.10806062025949359, 0.041085926204686984, 0.040828779456205666, 0.040427585554425605, 0.057846073541441, 0.0530527198134223, 0.029315452920855023, 0.11900690515176393, 0.03976406471338123, 0.028563750092871487, 0.024585985120211262, 0.0172007752553327, 0.06151247973321006, 0.06268998607993126, 0.0964766820834484, 0.011335252838762244, 0.02687569438421633, 0.02246673233457841, 0.06394757758243941, 0.032473387764184736, 0.0199730641907081, 0.005917013086218503, 0.02085107498714933, 0.08028003634535708, 0.0645081143011339, 0.058463692548684776, 0.02859491101844469, 0.05638504080707207, 0.013305126140039647, 0.042713637885754, 0.0862190879706759, 0.0196492744362331, 0.03143362031551078, 0.027287003758829087, 0.03118897875538096, 0.026879809593083337, 0.027072896009485703, 0.061889743083156645, 0.04650364506233018, 0.005573084690695396, 0.013488630502251908, 0.04440288103069179, 0.04700967845565174, 0.07064602439641021, 0.012545105691970093, 0.062298955890582874, 0.02460300071106758, 0.04167762570432387, 0.054580115393036976, 0.027158688280906063, 0.04743461366160773, 0.06408141649444588, 0.033316463814117014, 0.031261583062587306, 0.04911996053124312, 0.024553261973778717, 0.014409305513254367, 0.08073243472608738, 0.02349580914597027, 0.03558900163625367, 0.05545576801523566, 0.03903782868292183, 0.025102972613240127, 0.055148058745544404, 0.004738231173178065, 0.050021220959024504, 0.03413686354178935, 0.058865298342425376, 0.014188639961503213, 0.03184733424859587, 0.054730307529098354, 0.04776823872816749, 0.018777685072564054, 0.050942530506290495, 0.02048918522632448, 0.01882428266981151, 0.009656851543695666, 0.031585404358338565, 0.05759716463217046, 0.03413806582102552, 0.03596872520574834, 0.08226709964219481, 0.01781637747626519, 0.013604832274722867, 0.03380342401214875, 0.010820930583577137, 0.0368126695684623, 0.025643584522185847, 0.06105835585913155, 0.049616368269198574, 0.031087794341146946, 0.04107452310563531, 0.011549634255061392, 0.029460006589943077, 0.052390059863682836, 0.04766399666550569, 0.03589050655136816, 0.04268637880159076, 0.04195706656901166, 0.03861601420794614, 0.05613507433736231, 0.07974041334819049, 0.019627594447229058, 0.013296835422806907, 0.05365902106859721, 0.031047041156853084, 0.0382088385958923, 0.01456299316487275, 0.04883864203293342, 0.042978989076800644, 0.06944307722733356, 0.062061683856882155, 0.08730648274649866, 0.015256818678608397, 0.02699703738471726, 0.09212598233716562, 0.05998095410177484, 0.025633745499362703, 0.0159278361388715, 0.03969195393437985, 0.01694685128313722, 0.013183252503949916, 0.0377161156211514, 0.04893073513812851, 0.02948391487734625, 0.03319703369925264, 0.026086199541168753, 0.03787239707889967, 0.00974341750406893, 0.044180915792821907, 0.05806237990327645, 0.049269124792772345, 0.06248093050089665, 0.03270668188633863, 0.03657443274278194, 0.06206699021277018, 0.03792295217863284, 0.03764011969906278, 0.02402000845904695, 0.018157292288378812, 0.07016494942945428, 0.014817480241617886, 0.00732438715203898, 0.00739879255888809, 0.05195571793592535, 0.09510314484941773, 0.0598522656946443, 0.05430443350633141, 0.018426515634928364, 0.0760064680071082, 0.11755174651625566, 0.10693785472540185, 0.026573189425107557, 0.035673996098921634, 0.07822937099263072, 0.035475627446430735, 0.01998666033614427, 0.03430531251069624, 0.018776753677229863, 0.054417317878687754, 0.04911662086669821, 0.04349594688392244, 0.0426210586738307, 0.01904014374304097, 0.10531265521422029, 0.01438751141904504, 0.061116414071875624, 0.03683248862216715, 0.07335223621339537, 0.011706951008818578, 0.09565369968186133, 0.06002386879117694, 0.032136653098859824, 0.07323266880121082, 0.02428678642900195, 0.0354360190249281, 0.0235845069255447, 0.01638706413359614, 0.07914092871942557, 0.019056545206694864, 0.03387649958312977, 0.06155245180707425, 0.027561501919990405, 0.09833543546847068, 0.016316422806994524, 0.011233523873670492, 0.022061445488361642, 0.017957849377125967, 0.05430451885331422, 0.01493473864684347, 0.054896522633498535, 0.0018359737418904842, 0.039982968592084944, 0.07272383008967154, 0.03909011298674159, 0.02100716534187086, 0.045410528327920474, 0.02155187390599167, 0.022147566160128918, 0.009458605345571414, 0.07468059891834855, 0.0224953514043591, 0.014825295056652976, 0.04838871871470474, 0.06904611727804877, 0.023382631625281647, 0.02306880705873482, 0.026474904952920042, 0.03346059631439857, 0.052640208159573376, 0.014446841487369966, 0.03185703782946803, 0.013028254033997655, 0.031025901080283802, 0.07090953135048039, 0.025922882523445878, 0.030838195234537125, 0.03169008428812958, 0.030936609582568053, 0.033758212375687435, 0.022363492171280086, 0.006694719841107144, 0.009143737133854302, 0.061073725737514906, 0.006559340508829337, 0.06911840988323092, 0.0365713862265693, 0.023909088922664523, 0.08512824220815673, 0.06371730400132947, 0.09860332109383307, 0.05399043453508057, 0.00503412498801481, 0.019616827739810105, 0.036683105427073315, 0.04252275750332046, 0.07025515747955069, 0.015315512355300598, 0.06548188626766205, 0.05475047910294961, 0.0715465092798695, 0.06786158279282972, 0.02880984997318592, 0.012934031892655184, 0.03161686770909, 0.03209744543710258, 0.058177038008579984, 0.02286600778461434, 0.012628453514480498, 0.02873919380363077, 0.01014189607303706, 0.045740617060801014, 0.02103905913827475, 0.022095556450949516, 0.04526546072156634, 0.014307209185062675, 0.02708779833483277, 0.015829508993192576, 0.06755789596354589, 0.06889347234391607, 0.012249912742845481, 0.031131087525864132, 0.035040914444834925, 0.008132818820740795, 0.07776964019285515, 0.09164185714325868, 0.03924289150745608, 0.04073794429132249, 0.01389472443406703, 0.04355765275249723, 0.01356434348053881, 0.004773947957801283, 0.04418576201715041, 0.05285937921144068, 0.04934199998388067, 0.052462263411143795, 0.023584328810102306, 0.025212793771061115, 0.029744167513854336, 0.03760956918995362, 0.031049497665662784, 0.08956137229688466, 0.11677194968797266, 0.11331199042615481, 0.2580130723072216, 0.11619169410550967, 0.20234126510331407, 0.2612498454982415, 0.1551152765750885, 0.10819768751389347, 0.15045202133478597, 0.14496753516141325, 0.12667806266108528, 0.10895694911596365, 0.13686298567336053, 0.1334946000133641, 0.15319958562031388, 0.0945574213983491, 0.08943727778387256, 0.12096577425836585, 0.07991032805875875, 0.19937322358600795, 0.1077216220437549, 0.15779745765030384, 0.1525040002889, 0.1339771889615804, 0.1320486143231392, 0.1277105978806503, 0.19070766982622445, 0.09607558095012791, 0.1754070635070093, 0.14905127696692944, 0.1016501935373526, 0.2037008202751167, 0.08943336666561663, 0.12253506778506562, 0.08456625830149278, 0.08259608628577553, 0.08124692118144594, 0.13555279816500843, 0.16032978426665068, 0.1956851058639586, 0.16492933355038986, 0.11662561300909147, 0.1710334388189949, 0.17408022220479324, 0.24894264730392024, 0.22611405118368566, 0.12795543239917606, 0.1875300012761727, 0.19234164152294397, 0.1734501833561808, 0.10056423110654578, 0.18563661928055808, 0.14517955190967768, 0.12254673434654251, 0.11336078663589433, 0.14624465256929398, 0.16150133858900517, 0.11556020064745098, 0.29727200162597, 0.14850722334813327, 0.15071426663780585, 0.11237125887419097, 0.1940276674577035, 0.22430183045798913, 0.2058579763979651, 0.15022287581814453, 0.1522898906841874, 0.1417923008557409, 0.13259064930025488, 0.14925462543033063, 0.23305889102630317, 0.10139010788407177, 0.1660880635608919, 0.1391780559788458, 0.10465114930411801, 0.12274314372916706, 0.11408867765567265, 0.27677679201588035, 0.13051339279627427, 0.10009070378146134, 0.06902683628140949, 0.09816163932555355, 0.15264122339431196, 0.11493147540022619, 0.1890765331336297, 0.06484994752099738, 0.08731155161513016, 0.190781157289166, 0.13686947204405442, 0.07795309167704545, 0.16413649718742818, 0.1332938193809241, 0.11451651094830595, 0.15753362415125594, 0.1527338137384504, 0.06046906462870538, 0.07151621481170878, 0.14207777538103983, 0.07928534323582426, 0.11236826059757732, 0.11617801632382907, 0.09433803512365557, 0.102359523443738, 0.14184585423208773, 0.15311664319597185, 0.13070195767795667, 0.16050252655986696, 0.09752705853316002, 0.12070329146808945, 0.13491217629052699, 0.09328411862952635, 0.07942602474940941, 0.124153313372517, 0.15072615584358573, 0.09410235870745964, 0.12876024702563882, 0.17321296327281743, 0.21932335541350767, 0.2016345178708434, 0.13928209024015814, 0.17556790175149217, 0.25946872076019645, 0.13833654957124963, 0.12962495296960697, 0.1778971470776014, 0.16830987558932975, 0.10860491878702305, 0.1325897141941823, 0.14094979997025803, 0.20372793835122138, 0.24062029231572524, 0.16603367897914723, 0.22827714448794723, 0.23785273457178846, 0.18399530032183975, 0.12924225709866732, 0.13375165028264746, 0.2882538683479652, 0.09845783046330325, 0.07234670774778351, 0.06621164007810876, 0.07638988376129419, 0.1123316133453045, 0.24885553400963545, 0.10600177643937059, 0.07951647770823911, 0.1324677051161416, 0.14995571749750525, 0.21883907436858863, 0.1343412569258362, 0.1254546915879473, 0.1908653019927442, 0.17883388587506488, 0.15791493962751701, 0.084499769291142, 0.06743892226950265, 0.10901583853410557, 0.10909207194345072, 0.1982380196568556, 0.21055655786767602, 0.11993330583209172, 0.15749887679703534, 0.07895936229033396, 0.20413718826603144, 0.09118312824284658, 0.13221377186710015, 0.09903459795168601, 0.1317801052937284, 0.12731055059703067, 0.11929538537515327, 0.14845819707261398, 0.1322361995698884, 0.20845228718826547, 0.16378679720219225, 0.18634292122442275], [0.03422629233682528, 0.017622649102122523, 0.07288925480679609, 0.03238035955291707, 0.08090439034276642, 0.018587316772027407, 0.02854277514416026, 0.011499394568090793, 0.029427873450913467, 0.09323690319433808, 0.02955518888484221, 0.05543383755139075, 0.023630243631487247, 0.031842714379308745, 0.036160466479486786, 0.057225571290473454, 0.035686608898686245, 0.07360626594163477, 0.03821420803433284, 0.05004004924558103, 0.060323221478029154, 0.037360222413553856, 0.0024160580505849794, 0.10539893730310723, 0.007389027750832611, 0.0789726318907924, 0.02936080185463652, 0.014063657654332928, 0.022030497930245474, 0.04015575170342345, 0.06417746524675749, 0.031939568361849524, 0.04020062195195351, 0.06319705848000012, 0.05149917094968259, 0.027636714876280166, 0.0469837478158297, 0.02387159562204033, 0.03800822865741793, 0.0035532293668438797, 0.05782002044725232, 0.006542764640471432, 0.04095205760677345, 0.018065559124806896, 0.04114626281079836, 0.03378788343979977, 0.0387228092586156, 0.0756479513074737, 0.05844216655532364, 0.06203523742442485, 0.03735582889930811, 0.017789799312595278, 0.06479125106125139, 0.012685594247159315, 0.042998889766749926, 0.027483385310915764, 0.021304451147443615, 0.053768409925396554, 0.027941620683122892, 0.05236418488493655, 0.025283687427872792, 0.004710402026830707, 0.028379779105307534, 0.05983144474157598, 0.03128858239506371, 0.026688964462664444, 0.07625407073646784, 0.037960048430250026, 0.023820027490728535, 0.04586609938996844, 0.04998298179998528, 0.016218832242884673, 0.0543306387407938, 0.09491717006312683, 0.050621347545529716, 0.013018307399761397, 0.012436800370778656, 0.0272858719836222, 0.02999097985593835, 0.017797063082980458, 0.01543638965813443, 0.05619873947580345, 0.021509532525669783, 0.0329470635188045, 0.02618902966787573, 0.02816312393406406, 0.03384348514373414, 0.027758299074776005, 0.03194034019543324, 0.044930830044904724, 0.03925491801055614, 0.011697666741383728, 0.038442462973762304, 0.03772870244574733, 0.016205913307203446, 0.024306084123963956, 0.04522677627392113, 0.02050742165010888, 0.048823580145835876, 0.024144574235833716, 0.0420558761106804, 0.054977220061118715, 0.03656876644527074, 0.04365629160020035, 0.01278469786484493, 0.06714824528899044, 0.02223002247774275, 0.032079722950584255, 0.026668805876397528, 0.07312297195312567, 0.029804066252836492, 0.024089260114124045, 0.09055058835656382, 0.03728715055331122, 0.027824322387459688, 0.05342507014574949, 0.019347706438566092, 0.03204622240446042, 0.0815758781391196, 0.040269289165735245, 0.01433930150597007, 0.07422044509439729, 0.022201770771062, 0.023868888638389762, 0.043699002198991366, 0.03676071923109703, 0.08371498523047194, 0.04502009556745179, 0.05016444803914055, 0.013526344591809902, 0.05993508566461969, 0.04149482359935064, 0.06008086202200502, 0.04044045439513866, 0.030512396115227602, 0.04841492023842875, 0.07566321728518233, 0.02067098357656505, 0.009010318462969735, 0.00758998139644973, 0.018108349504473154, 0.04036467369587626, 0.038024092064006254, 0.022353139211190864, 0.05661161107127555, 0.04412748487084173, 0.03390294972632546, 0.02217039462266257, 0.017986360835493542, 0.03535765936248936, 0.05513450341823045, 0.04858460117247887, 0.01592978798726108, 0.05141065499628894, 0.021891823926125653, 0.03733999517862685, 0.014987065624154638, 0.0317780992918415, 0.033906133539858274, 0.03543464234098792, 0.028806528862332925, 0.052923738257959485, 0.056382780967396684, 0.12690976116573438, 0.049376231545466, 0.060402954113669693, 0.018988056108355522, 0.03217427998606581, 0.028100961644668132, 0.031103047331271227, 0.02409167580481153, 0.019965459032391664, 0.021815260261064395, 0.05008824802644085, 0.028604955987248104, 0.07747157142148353, 0.015273836124833906, 0.023169206651800778, 0.05769123185018543, 0.025845277996268123, 0.021068385103717446, 0.04295470971555915, 0.019609484188549686, 0.03446466274908744, 0.015975893911672756, 0.038500587979797274, 0.06689028217806481, 0.07979827860253863, 0.047171013939077966, 0.04899058934825007, 0.0506449441309087, 0.07376260677119717, 0.02375154581386596, 0.025056393569684587, 0.04290982091333717, 0.0391707361995941, 0.05050324587500654, 0.010520143696339801, 0.014071322184463497, 0.08019638888072222, 0.012787120977009181, 0.028065010155842174, 0.05706792799173854, 0.023935347962833475, 0.030035935451451223, 0.032117936134454794, 0.061955649507581256, 0.01660093810642138, 0.06636861915467307, 0.03784940163313877, 0.04001230568974279, 0.06110467329563107, 0.027696801007550675, 0.03975567102315836, 0.03727939511009026, 0.03647400902991649, 0.03658611043647397, 0.03844608465442434, 0.036642561899498105, 0.03909259547071997, 0.05027782222896349, 0.05774336772446986, 0.02459379807987716, 0.036168500228086486, 0.015653770278731827, 0.013528785329981474, 0.07647586156963371, 0.04022596629511099, 0.06022236731951125, 0.03238767712900881, 0.03834317103610374, 0.03682717855554074, 0.052485856285784394, 0.014332868940982735, 0.038464519602712244, 0.022709050972480327, 0.056930979480966926, 0.05104400064738002, 0.056217348828795366, 0.07438564716721885, 0.03789931477513164, 0.0654502707766369, 0.020191763978800736, 0.07591744739329442, 0.031233548434101976, 0.058852778311120346, 0.07286554318852723, 0.03140229426207952, 0.039965858377399854, 0.03608221813919954, 0.011224234967812663, 0.11025225656339899, 0.06860788649646565, 0.011550535036803922, 0.02798332010570448, 0.061690431903116405, 0.047865753222140484, 0.019881123225786723, 0.03469702918664552, 0.032823013534653, 0.031111409480217844, 0.025033978854480665, 0.07761191896861419, 0.010775205937534338, 0.039985721959965304, 0.035105982242384925, 0.023605005044373684, 0.0629501162620727, 0.02653698560607154, 0.016601088391325902, 0.08991011491161771, 0.04662444072891958, 0.02142629509762628, 0.017162211406684946, 0.034830931181204505, 0.03674010979011655, 0.052941765025025234, 0.03116740452242084, 0.020679468179878313, 0.0597624546935549, 0.05468808674777392, 0.004342505044405698, 0.013966156147944275, 0.03984309601946734, 0.03665498545160517, 0.09767239331267774, 0.032201457433984615, 0.11352947680279613, 0.05205203386140056, 0.03182047221343964, 0.04179226525593549, 0.07391156323137693, 0.026619458622008096, 0.027972644311375916, 0.04356363075203262, 0.06667727095191367, 0.013700574891117867, 0.013728317298955517, 0.04035762329294812, 0.031176970805972815, 0.10304048846592195, 0.018323418335057795, 0.10824405690073036, 0.010379256236774381, 0.09880162295303307, 0.03901061412761919, 0.03108750119281467, 0.04171377942839172, 0.07636670648935251, 0.04600887004926335, 0.04723735080915503, 0.03878324234392494, 0.037863546967855655, 0.0275387736473931, 0.001737829118155787, 0.02034353317867499, 0.031678566156188026, 0.03312980254122522, 0.0585457295528613, 0.05679827976564411, 0.056346931523876265, 0.04380644291813951, 0.015104969697858905, 0.023693508010182995, 0.02719915017223684, 0.03105186697212048, 0.05079946669866331, 0.05757229526352603, 0.03725516769918613, 0.020237472854205407, 0.00997498798824381, 0.014636703272117302, 0.0357942017581081, 0.06780212192097679, 0.006393491376002203, 0.01837078591051977, 0.020998656618758105, 0.03274925889854785, 0.04605563648510724, 0.049442727977293544, 0.0447967165382579, 0.0841913178737741, 0.03605785714171361, 0.04475345303944778, 0.029951300930406433, 0.022722867906850297, 0.024932748056016862, 0.015371579756902065, 0.0833694932225626, 0.02253182239655871, 0.03438298939727247, 0.07935409579658881, 0.07548469366156496, 0.1253273242036812, 0.11429491307353601, 0.10099472870933823, 0.15248022187734023, 0.16685303970007226, 0.10753558046417311, 0.15692654735175893, 0.07942566851852462, 0.19692569476319477, 0.14693805598653853, 0.13366404717089608, 0.18821699253749102, 0.11054432136006653, 0.10647872506524436, 0.17094380222260952, 0.1281432106043212, 0.22414847306208685, 0.16868497186806053, 0.10981213330524042, 0.12101301195798442, 0.10607023214106448, 0.09077496186364442, 0.15288953116396442, 0.06706601532641798, 0.19703507248777896, 0.14419527113204822, 0.15235658007441089, 0.11451182057498954, 0.17216448672115803, 0.20854616886936128, 0.15689754422055557, 0.1697296040947549, 0.10186176499701105, 0.1186188064457383, 0.18267439620103687, 0.08830004037008621, 0.1530176110100001, 0.14461166050750762, 0.12837162881623954, 0.121993062493857, 0.13438084308290854, 0.12799351941794157, 0.09189104064716958, 0.14711084280861542, 0.13648595981067047, 0.20068367826752365, 0.15335126576246694, 0.19822179630864412, 0.13318804849404842, 0.25086446839850396, 0.11055128270527348, 0.21998478710884228, 0.10351517354138196, 0.14638803550042212, 0.10719284924562089, 0.106758774491027, 0.12810357991838828, 0.19352584204170853, 0.22502790321595967, 0.09986496472265571, 0.1140548283001408, 0.1161854674865026, 0.2046226864331402, 0.0798565149307251, 0.13424796896288171, 0.11921124067157507, 0.1753364407340996, 0.11141937284264714, 0.2633617306128144, 0.11622592937783338, 0.11353815993061289, 0.11637630334007554, 0.12885503412690014, 0.20072231447556987, 0.1655732505605556, 0.1955609890865162, 0.1637967419810593, 0.1396049838513136, 0.19024220964638516, 0.1621825559413992, 0.11924179489142261, 0.19148793420754373, 0.15067172673298046, 0.12622106296475977, 0.0865193089703098, 0.12950177129823714, 0.10523789867875166, 0.18434728612191975, 0.1667364631430246, 0.12919530883664265, 0.16839415387948975, 0.1455066609196365, 0.14614777261158451, 0.18339557078434154, 0.08075158955762163, 0.1548950219876133, 0.11297937468043528, 0.08481343058519997, 0.1259751894394867, 0.08371589807211421, 0.1277738733915612, 0.11021187630831264, 0.24498658458469436, 0.14296045614173636, 0.18691133212996647, 0.07565046718809754, 0.11265264416579157, 0.0992868391040247, 0.17878613609354943, 0.1284772512735799, 0.21381439320975915, 0.22666776756523177, 0.09133112733252347, 0.1397700226516463, 0.17494667961727828, 0.12275271001271904, 0.0886249377799686, 0.276288547902368, 0.1611143976333551, 0.07226959860417992, 0.15187167562544346, 0.12435272845323198, 0.14228879765141755, 0.16358776803826913, 0.14507248968584463, 0.20470380317419767, 0.129210107261315, 0.27552268118597567, 0.13991662650369108, 0.13172478560591117, 0.110534391424153, 0.13387778570177034, 0.11897828793735243, 0.15431902633281425, 0.10471025394508615, 0.16121812019264325, 0.08424800311331637, 0.054100461638881825, 0.07931815358460881, 0.2020431443816051, 0.11146611330332235, 0.1099009758036118, 0.11079969437560067, 0.12072255020029843, 0.17246177623746917, 0.1123838679632172, 0.11310699439491145, 0.1221823769446928, 0.15534522361122072, 0.21177773218369111, 0.245876983681228, 0.09339072072179988, 0.10055334380012937, 0.09313229005783796, 0.10802850752952509, 0.0797334594244603, 0.1065255026333034, 0.08976901779533364, 0.12159543461166322, 0.15514113300014287, 0.11820303305285051, 0.17588983057066798, 0.22016760776750743, 0.16856147849466652, 0.16573489032452926, 0.15344479121267796, 0.13510617369320244, 0.1185629449901171, 0.118225898622768, 0.11072396562667564, 0.0724155196803622, 0.12408711379976012, 0.20866889040917158, 0.14567165519110858, 0.1933012533118017], [0.019286301139800344, 0.03861449280520901, 0.03984866583778057, 0.05056457324826624, 0.09818719889153726, 0.026952996486215852, 0.02302517805219395, 0.09246103232726455, 0.009889860866678646, 0.03167123373714276, 0.024885872153390665, 0.062084371311357245, 0.03659977708593942, 0.02243925988295814, 0.03293500361905899, 0.05271893518511206, 0.05093795516586397, 0.05201041421969421, 0.0476767875807127, 0.045155608022469096, 0.02386496082181111, 0.051669185850187205, 0.03642413670604583, 0.02710184719035169, 0.05623541270324495, 0.0812618903000839, 0.014908100183674833, 0.0617662126023788, 0.01053484378644498, 0.10851832499611191, 0.10930574368103407, 0.02453468416206306, 0.047106910933507606, 0.023957309967954643, 0.025627400136727374, 0.03737221923074685, 0.03885267396981362, 0.03357383691763971, 0.027590213758230675, 0.009923985744535457, 0.038176811212906614, 0.020692908474302385, 0.0254271445737686, 0.016481166603625752, 0.03933582323952578, 0.019603020082286093, 0.02100880734360544, 0.06113575444032904, 0.03814323645201512, 0.04443774341780227, 0.01272648194571957, 0.041576608273317106, 0.021818976565555204, 0.11661396129056811, 0.032846361500560306, 0.0580488245759625, 0.020764082291861996, 0.04289687785785645, 0.013701832831429783, 0.05627429382002447, 0.04595048158080317, 0.04768951912410557, 0.02561411940405378, 0.11568308545975015, 0.025660017527115997, 0.06631344047491439, 0.01099716004318907, 0.016845585232658777, 0.03222486477170605, 0.036998354917159304, 0.03230513917515054, 0.01937959466886241, 0.0730017495516222, 0.01948792782059172, 0.02874719415558502, 0.02932829022029182, 0.013515802384063136, 0.07266814674949273, 0.08744714941713028, 0.009132488958130125, 0.05185675996472128, 0.012781317382177804, 0.0376989868527744, 0.04375688971776981, 0.04027186441817321, 0.04347514077380765, 0.002236587724837591, 0.05370899358240422, 0.04531107311777305, 0.0661198289890308, 0.026234063188894652, 0.029331346013350412, 0.010224237357761012, 0.01229170029546367, 0.04423610560479574, 0.03602635297283996, 0.021564631424553227, 0.052291343090473674, 0.05229832298937254, 0.00932683053179062, 0.05402874048741069, 0.006705608539050445, 0.06779864124837331, 0.029162761602492537, 0.053752988096675836, 0.03661194830783643, 0.03527033455611672, 0.06488090992206708, 0.053430851476150565, 0.13465968280797824, 0.04831700869544875, 0.005641816378556541, 0.021157691444386728, 0.01868065111921169, 0.0722962936561089, 0.004295033104426693, 0.02495554683264345, 0.040246842909255065, 0.041750385862542316, 0.023912890574138146, 0.05565690116782207, 0.0575728555850219, 0.020675156301876996, 0.05819607038574759, 0.006364859782479471, 0.013667272869497538, 0.03601439697376918, 0.01562315668707015, 0.08157629374181852, 0.08095435172435828, 0.05498812963196542, 0.028939460498804692, 0.04482862517761532, 0.03925486977095716, 0.050440864652046, 0.04523273943050299, 0.026832330695469864, 0.026495380807318725, 0.01344894322755863, 0.0034689202311710687, 0.06603690882911906, 0.1554470314295031, 0.031230312670231797, 0.028116294415667653, 0.0525729881337611, 0.014962692566768965, 0.028978447371628135, 0.013023099818383344, 0.031114443008846138, 0.016493413895659614, 0.10421056591439992, 0.11807040384155698, 0.01734418787236791, 0.024729060060053598, 0.018328201476833783, 0.03461051332124043, 0.030938333220547065, 0.06390120819560252, 0.02625982313475106, 0.007762111881675082, 0.056438920728396624, 0.009696166816866025, 0.017122927674790844, 0.04470954758289736, 0.04004772468761075, 0.009670717645349214, 0.004282395721020293, 0.08375161763979122, 0.028229789204488043, 0.07931651343824342, 0.0822127224819269, 0.038288289215415716, 0.04941460058034863, 0.0500077212927863, 0.07216825833893381, 0.023492120672017336, 0.03778575875912793, 0.024905075224523898, 0.026444977847859263, 0.054837206480442546, 0.0877314290846698, 0.052608280966524035, 0.03420555673073977, 0.032746791257523, 0.1479166667559184, 0.06125353327661287, 0.058850492496276274, 0.04584298891131766, 0.03169085241097491, 0.048887898374232464, 0.039637216832488775, 0.012942382909386652, 0.027960033366980497, 0.04673738818382844, 0.01323158116065315, 0.0376243564824108, 0.038403689468395896, 0.019410668392083608, 0.098607454856392, 0.03913117230695207, 0.03648561621957924, 0.0275031190176378, 0.017748919963196386, 0.036858166931779124, 0.05046529244282283, 0.0077631564545299625, 0.0226490353452391, 0.03567599989764858, 0.04969091329257935, 0.05158303363714367, 0.07028743348200805, 0.07202371023595333, 0.023082273328327574, 0.02184284032409778, 0.04370026013930328, 0.030761733614781406, 0.035770508693531156, 0.030923436461307574, 0.017875910707516596, 0.029491894820239395, 0.05334987203241326, 0.016496020689373836, 0.04676682176068425, 0.028669292769336607, 0.03382267532288097, 0.0226254647350288, 0.01578848863573512, 0.028975849854759872, 0.043631878652377054, 0.08316923951497301, 0.02404966282483656, 0.0525110410671914, 0.04177519214863423, 0.030327432505146135, 0.08074719604337588, 0.04201412659313064, 0.04127009386138525, 0.05849583125382196, 0.06350561379804276, 0.04530683174380101, 0.0076325440295477165, 0.047063599195098504, 0.017549272961332463, 0.008046792772802291, 0.019369848414498847, 0.043248396104900166, 0.04622992615622934, 0.010684055359888589, 0.06267955890507437, 0.04272664031304885, 0.040258661611005664, 0.036763079260708764, 0.06884436443215236, 0.05794745833554771, 0.09820054270676337, 0.09980728500522673, 0.008966608747869032, 0.09456557760131545, 0.07924356032162905, 0.07082569092744961, 0.038683100647176616, 0.04592445446178317, 0.06406159373000264, 0.06555864660185762, 0.038554709099116735, 0.022637014408246614, 0.025829676196735818, 0.021318256949598435, 0.03925713332137093, 0.024050148931564763, 0.024307598105224315, 0.01616843670490198, 0.02915678731369553, 0.0691007096611429, 0.05160194727068301, 0.0379020236141514, 0.03336184614454396, 0.09587928288965486, 0.04326293848862406, 0.03937490844691638, 0.04397902564960532, 0.05191012409341056, 0.07185975497122854, 0.0260838209578651, 0.0494642502599163, 0.02925329805293586, 0.062259399419417605, 0.011472438836790388, 0.006873412767163245, 0.05582413672527764, 0.04165556536463555, 0.031114684206841048, 0.05065668861789163, 0.07777880571666174, 0.05915009380260017, 0.022550507819687482, 0.0848629986285232, 0.028762402616848703, 0.06359241539030336, 0.07517825346440077, 0.11285996311926283, 0.030756566411582753, 0.0310731313584256, 0.024315897171618417, 0.05554916358960327, 0.04270705132512376, 0.047654671579948626, 0.04221756040351465, 0.030237035207392182, 0.022253875104070175, 0.020114860781177413, 0.09555572134559043, 0.07900843309471384, 0.022819630976300687, 0.03147439390886575, 0.03548314169165678, 0.046614933817181736, 0.046883338945917785, 0.04630788505892269, 0.021930259754299186, 0.03742148299352266, 0.010209813717665384, 0.027821448420581874, 0.02635516499140067, 0.03805118416494224, 0.07614115296746604, 0.062087766636977904, 0.06814302745624445, 0.028220508647791576, 0.03443955589318648, 0.040733829082455486, 0.03271418499934953, 0.05538019511732273, 0.06063955821446143, 0.04341607324022334, 0.0349073538382072, 0.07158498221542686, 0.04967905377270654, 0.035397052561165765, 0.040278194937855005, 0.06986662090639584, 0.026955594003084116, 0.016157853679032996, 0.029067889154248405, 0.07127577380742878, 0.031511720226262696, 0.011955084373767022, 0.015461451057490194, 0.02561620854976354, 0.035214473100495525, 0.03816212039964739, 0.06903894813149236, 0.1629312345176004, 0.11375759073416702, 0.1208911142020952, 0.137328757555224, 0.21835639636265114, 0.14193696028087288, 0.0820568714698311, 0.16620778682408854, 0.19794319407083094, 0.189655571593903, 0.23388637084281072, 0.12491647124988958, 0.09395878281793557, 0.16540150274522603, 0.09823724190937355, 0.21350346301915124, 0.13274419965455309, 0.1381039308034815, 0.09479136861045845, 0.23024953552521765, 0.23748378327582031, 0.1465626183198765, 0.2178339392412454, 0.06601048837183043, 0.14125603978754953, 0.13741297647356987, 0.10741180507466197, 0.13218460546340793, 0.10305875272024423, 0.18764950189506635, 0.19401187455514446, 0.12438506382750347, 0.10068288567708805, 0.12180750331026502, 0.1611866828170605, 0.16217452590353787, 0.056797515353537165, 0.17186033976031467, 0.09160185538348742, 0.09596483025234193, 0.07906460625235923, 0.15896202094154432, 0.07924989826278761, 0.103182476159418, 0.1348957748268731, 0.06691004557069391, 0.08752779860515147, 0.12933673249790445, 0.25718406366650015, 0.12675529054831713, 0.09829320726566948, 0.1347552120569162, 0.09558526624459773, 0.23615787707967684, 0.10096395926666446, 0.16447013709694147, 0.10202485937043093, 0.13053249567747116, 0.1163801625079941, 0.1509736620937474, 0.20040359173435718, 0.11559603153727949, 0.07186351023847237, 0.1501227600965649, 0.13152977888239548, 0.17398286727257073, 0.13690031570149586, 0.05597771305474453, 0.10527957027079538, 0.20070248428964987, 0.14982683613197878, 0.14530064072459936, 0.27314792736433446, 0.08237311543780379, 0.0864707725122571, 0.10432907205540687, 0.13395395973930135, 0.14220445998944342, 0.15586186229484156, 0.16328103840351105, 0.17601412546355277, 0.12799298507161438, 0.17612981144338846, 0.162333226762712, 0.1510890363715589, 0.11369153959094547, 0.23221564799314365, 0.36612537573091686, 0.10890256453421898, 0.1256090434617363, 0.13789181015454233, 0.1528842025436461, 0.2091731203836389, 0.09498154395259917, 0.06954622833291069, 0.14656738290796056, 0.12726044078590348, 0.14956307684769854, 0.1806642150040716, 0.10490146087249741, 0.21083069237647578, 0.2107323578093201, 0.10478480267920531, 0.1190404650697019, 0.13906901964219287, 0.12727988505503163, 0.10088743641972542, 0.1691982412012294, 0.18859649717342108, 0.18182349420385435, 0.17054850468412042, 0.15377072762930766, 0.08685019551194273, 0.10859757894650102, 0.15598223864799365, 0.07234471137053333, 0.2016716994694434, 0.1594824594212696, 0.12927972071338445, 0.0700242530729156, 0.12109386152587831, 0.11257531237788498, 0.11400858507840894, 0.15697517286753282, 0.12161732054664753, 0.09672652609879151, 0.16070525161921978, 0.06218662812898401, 0.1887271151645109, 0.1507504834444262, 0.15644568018615246, 0.22187757538631558, 0.10202815450611524, 0.10971831099595875, 0.16169977403478697, 0.18033746222499758, 0.1484541449462995, 0.1524872425943613, 0.07365933692199178, 0.17849595635198057, 0.12178258199128322, 0.28567594417836517, 0.1345678642974235, 0.13644281134475023, 0.19775473308982328, 0.08344097688677721, 0.16070280253188685, 0.17674837668891996, 0.16622519760858268, 0.2177293854765594, 0.19293028337415308, 0.27201241173315793, 0.08116023091133684, 0.2806911163497716, 0.16017945483326912, 0.13872150157112628, 0.17548905598232523, 0.11706224817316979, 0.18860247888369486, 0.1812451088335365, 0.12091651049559005, 0.1451507120509632, 0.09200628875987604, 0.18120365246431902, 0.21527695847908035, 0.1271300602820702, 0.11440279908129014, 0.2407160442089662, 0.1858560723485425, 0.2431898599024862, 0.16322101349942386, 0.09267361310776323, 0.14685118017951027, 0.13334194023627788, 0.14609712845413014, 0.14007413992658257], [0.04152057983446866, 0.0343700129451463, 0.034844493929995224, 0.037340481285355054, 0.057985278181149624, 0.07052333996398374, 0.04455214919289574, 0.02665431358764181, 0.03159946805681102, 0.029915030318079516, 0.024797658625175245, 0.01086295840650564, 0.0837388972286135, 0.04543854440271389, 0.03849209038889967, 0.058569430038915016, 0.04890345378953498, 0.014576924204448005, 0.038393314243876375, 0.01990548422327265, 0.029908569922554307, 0.015531452281720703, 0.02365147647651611, 0.021369767564465292, 0.023041113818180747, 0.011094820183643606, 0.018335906825086568, 0.0818396893737372, 0.022330923020490445, 0.028570974900503643, 0.022712171703460626, 0.05354396591428667, 0.0006952154751616035, 0.03958572662668303, 0.043767476454377174, 0.03878098992572632, 0.03663620911538601, 0.04099089048395399, 0.021589901552943047, 0.04516704080742784, 0.06741314748069271, 0.031909181125229225, 0.006850606105217594, 0.026400051938253455, 0.03484551438305061, 0.016256750423053745, 0.04324215835367795, 0.05661436072841752, 0.025728630935191177, 0.04374718613689765, 0.07246193359605968, 0.024149485398083925, 0.042450060427654535, 0.06609678530367091, 0.02572697037976468, 0.02555653431045357, 0.016251035885943566, 0.1019080972764641, 0.08302143338369206, 0.012373563822620781, 0.03766208355955314, 0.04638106081984006, 0.010273588322888827, 0.028199717380630318, 0.019085913845628966, 0.014525697461067466, 0.021215252418187447, 0.024883770020096563, 0.03647100333182607, 0.024633293323859107, 0.05401565271313302, 0.01868796312919585, 0.07082563897711225, 0.0568179132824298, 0.06501016978290863, 0.01652568989811698, 0.059085723623866215, 0.0685216489364393, 0.05737658721045591, 0.013419694259937387, 0.04672993702115491, 0.004165675836702576, 0.0326222106377827, 0.0499067780765472, 0.01105654206185136, 0.05256445714621805, 0.03417574836930726, 0.03822234197286889, 0.016494586488988716, 0.04462453827727586, 0.009241590232704766, 0.034323944128118455, 0.02768153317447286, 0.032961817414616235, 0.04675050935475156, 0.011077800882048905, 0.009647987517382717, 0.0029914585957158124, 0.034854490659199655, 0.005235336066107266, 0.014012911451573018, 0.04624462810170371, 0.029954460624139756, 0.01945730680745328, 0.01916106186399702, 0.08006474672583863, 0.08073061646427959, 0.029706035966228228, 0.0667308020638302, 0.01809667366615031, 0.027826784462376963, 0.10601607762509957, 0.07656152025447227, 0.07114261024980806, 0.008279166631837143, 0.025245709875889588, 0.028835468910983764, 0.07079430550220422, 0.10475496834260412, 0.01592585460457485, 0.02102306028973544, 0.05696773805539124, 0.008924029880290618, 0.033515407631057315, 0.05294673741445877, 0.03721734414284583, 0.03458614861301612, 0.014505840372294188, 0.044502440141513944, 0.015129708262975328, 0.06234447180759162, 0.031032368897285778, 0.014316909982881043, 0.06413943017832935, 0.09160163273918442, 0.02431937969959108, 0.014062565769563662, 0.08345276961335912, 0.01632254738069605, 0.014501160203508334, 0.017501161382824648, 0.10969247683533467, 0.018767428591672797, 0.02873107099730987, 0.06015257575199939, 0.04520333182881586, 0.005765082005382283, 0.028287502318562474, 0.027923369416384958, 0.007686513936278061, 0.08392663832637481, 0.040187927515944466, 0.07975973887369037, 0.03131643148662988, 0.007336351964113419, 0.015704867146268953, 0.052134894649498165, 0.03255131698097102, 0.01889690367534058, 0.002277435069117928, 0.06872672660392709, 0.016789237670309376, 0.05177410326723475, 0.04902210093860049, 0.04210522150970064, 0.08727912718313746, 0.062320589495357126, 0.026815554447239265, 0.046639985012006946, 0.01940558653586777, 0.03089461701165419, 0.0669338165607769, 0.04981042133294977, 0.02129592015990056, 0.08593382124672644, 0.02943429302831646, 0.05012400099076331, 0.0377163382654544, 0.0058517977868177695, 0.018723602915997617, 0.0243246433819877, 0.03774221695493907, 0.05314751804689877, 0.03812065660895314, 0.005748638795921579, 0.0331124771037139, 0.013956244765722658, 0.048442134793731384, 0.08645465306472033, 0.013661875600519124, 0.02150902229914209, 0.08068369788816199, 0.02076898603263544, 0.036045626548002474, 0.033660119006526656, 0.0363403742085211, 0.01312875845542294, 0.04614116529410239, 0.042407312721479684, 0.08998522767797112, 0.0015648169846826931, 0.06817417539423332, 0.03531844056851696, 0.10314884202671237, 0.01785569646017393, 0.002879425373976119, 0.02034835342783481, 0.057781272917054594, 0.026099112910742406, 0.040631475785630755, 0.01832687674323097, 0.013134999917383539, 0.03650047401606571, 0.034741283452603966, 0.026484860864002258, 0.03866744133119937, 0.07914432033430785, 0.04516405737376772, 0.02122915469954023, 0.026872245252889115, 0.04999910495826043, 0.03976527070335578, 0.011747488042601617, 0.05009230757423211, 0.04804074422281701, 0.021596645819954574, 0.08413648058194667, 0.041070849474635907, 0.021270746510708705, 0.03844914972432889, 0.029674060533579905, 0.05053509885328822, 0.03029963350854814, 0.025378687896591146, 0.13498538173735142, 0.02348797021113569, 0.023152849717007484, 0.08986390879726969, 0.04008840180176776, 0.0107977004336135, 0.05961808099527843, 0.01845578593929531, 0.03568902458937373, 0.020000358526885975, 0.003020872923116258, 0.029115535035089124, 0.01881382951978594, 0.026373740947747137, 0.08101960876956582, 0.014555099496647017, 0.055654507741564885, 0.01634277832636144, 0.019437836563156452, 0.06898586230818182, 0.06615841324673966, 0.04247837707225699, 0.0015769657102282508, 0.01527467196865473, 0.02038005241047358, 0.03168047347571701, 0.04272142301488202, 0.10635702026775107, 0.061550002719741315, 0.05514176533324644, 0.029067083924019244, 0.03876959424815141, 0.03199133316229563, 0.02895926470955601, 0.08473393914755434, 0.038004298985470086, 0.030964093166403472, 0.008276187836600002, 0.017355266281811055, 0.060940217081224546, 0.06110076959885191, 0.031356622494058684, 0.039383465409628116, 0.024492999582435004, 0.0027171070087206317, 0.045683204516535625, 0.0019080173797192401, 0.03802129045652691, 0.04418282311235089, 0.05396919797931332, 0.04360826722404454, 0.03418146290641744, 0.031294701402657665, 0.09188403477310203, 0.05139929642609786, 0.023677062017668504, 0.039648957608733326, 0.04616701800841838, 0.03895591784385033, 0.05985200965369586, 0.05636077628878411, 0.05754612713644747, 0.06883283887873404, 0.05843408085638657, 0.030187333577487152, 0.015699811265221797, 0.0342219953017775, 0.026559964353509713, 0.022266415544436313, 0.012721056846203282, 0.11862066181492992, 0.06993298375164159, 0.009342817320430186, 0.03494871372822672, 0.019319538223498967, 0.021821490590809844, 0.0269906103858375, 0.03359504378749989, 0.009950710482371505, 0.04245502168487292, 0.042451771078049205, 0.07180239437730052, 0.027388056441850495, 0.038137610972626135, 0.035590259576565586, 0.02888504994189134, 0.061562225891975686, 0.007791903080942575, 0.012677728409471456, 0.051657033181982115, 0.01912424948386615, 0.01347293871731381, 0.03907348516804632, 0.043671642924891785, 0.010718825906224083, 0.007229503107737401, 0.03314526147732977, 0.052885157710989006, 0.028719050060317386, 0.021653600088029634, 0.040657881399965845, 0.014967121333029354, 0.01459193970731576, 0.02955834486783715, 0.02377642631472554, 0.06079067061364185, 0.04199377690383699, 0.07606638901052065, 0.04223501942760777, 0.011232969118282199, 0.04971116650267504, 0.02950267451524269, 0.06561750633409247, 0.10263894946547225, 0.0543449139513541, 0.03140724809782114, 0.05561256897635758, 0.005909928358960315, 0.15697202616138384, 0.06800673945690505, 0.10358645682572387, 0.1584972583805211, 0.12506868573836982, 0.10768579857540317, 0.10749793131253682, 0.19292442040750757, 0.13021368387853727, 0.1285825768718496, 0.18745038367342204, 0.1176717369526159, 0.21631253650411963, 0.19476279441732913, 0.18366290722042322, 0.20084839052287862, 0.10556556429946795, 0.10514902649447322, 0.23577353364089504, 0.11770307784900069, 0.11693813881720416, 0.21608150593237951, 0.1915586757240817, 0.21557959145866334, 0.07229362192447297, 0.15405986836412922, 0.0964566515176557, 0.23994760966161266, 0.1502526507829316, 0.0975080298667308, 0.09624312820960768, 0.10413486685138196, 0.1210729478043504, 0.10222267883364111, 0.10944808760541491, 0.12090536343748681, 0.1794616982806474, 0.1724426881992258, 0.1527470091241412, 0.15680631942814216, 0.25391006434801966, 0.1145346045086626, 0.08877407235559076, 0.16269128333078697, 0.1875675836345181, 0.18417625076835975, 0.09689784346846864, 0.18777097662677988, 0.1857783694867976, 0.138831116782967, 0.153886710468214, 0.10050803568447009, 0.16773582436144352, 0.1365517734666355, 0.14031796512426808, 0.179588160244748, 0.1067128949216567, 0.1757339053438045, 0.2585947676561773, 0.1754429389256984, 0.09665016652434133, 0.15116751106688753, 0.16747927875258029, 0.07311410328838974, 0.18557620845967904, 0.16560329269850627, 0.09934575078659691, 0.2674278983613476, 0.12173410490504466, 0.11770110373618081, 0.11767313961172476, 0.18586910446174443, 0.22004406986525282, 0.25249959784559906, 0.1431296212831512, 0.12884026538813487, 0.19275243510492146, 0.14227717561880127, 0.14817263348959386, 0.13860824983567, 0.13948809559224173, 0.089780446869554, 0.1316449008299969, 0.08771534674451686, 0.11158864930621348, 0.18410185788525268, 0.13892090180888772, 0.1538170376443304, 0.1615835982374847, 0.19413953879848123, 0.1759494250291027, 0.0858945467916783, 0.22153928963234648, 0.171365178830456, 0.0835787714459002, 0.1477053773123771, 0.1080873078899458, 0.10840083559742197, 0.16855307738296688, 0.12196569950901903, 0.20812097762245685, 0.12159467762103304, 0.1291590920300223, 0.1597144696279429, 0.12210721222800203, 0.1938066113507375, 0.2075438093743287, 0.15015004144515842, 0.1882533132447861, 0.14458543300861493, 0.13546835660235956, 0.16505601815879345, 0.13417286361800507, 0.11549673217814416, 0.16372996353311464, 0.1306807025684975, 0.16363283124519512, 0.1599505468038842, 0.17524839233374223, 0.25900392851326615, 0.10275018255924806, 0.19879494211636484, 0.05927349811827298, 0.18719227955443785, 0.18843220052076504, 0.15585580636980012, 0.10226545622572303, 0.11326841893605888, 0.16444744222098961, 0.18559483636636287, 0.10567065241048113, 0.08901858775061555, 0.13632396381581202, 0.11786980132455938, 0.1647762581706047, 0.16818718373542652, 0.07378933150903322, 0.2171163121238351, 0.10530748244491406, 0.19148855761159211, 0.1331457163905725, 0.2244411761057563, 0.10626581031829119, 0.11474550061393529, 0.22134834987809882, 0.17754707601852715, 0.20655278989579529, 0.12640300788916647, 0.14707511581946164, 0.08097297220956534, 0.19768121594097465, 0.15053876355523244, 0.11485699345939793, 0.22950707614654675, 0.0636204463080503, 0.11748387711122632, 0.1539664765005, 0.14846272417344153, 0.09237288002623245, 0.07022078862064518, 0.19468136597424746, 0.12146928434958681, 0.11985842313151807, 0.11970784136792645, 0.1771001101587899, 0.22645670076599345, 0.09975998051231727, 0.09649399638874456, 0.15324291220167652, 0.145070856960956, 0.1182458846597001, 0.2679646492470056, 0.10286681106663309, 0.14453912299359217, 0.18886472418671474, 0.14289366285083815], [0.045253519565449096, 0.05234248819760978, 0.04511242987064179, 0.006379865544658969, 0.00804278053692542, 0.06650528564932756, 0.008785830850683851, 0.047519474537693895, 0.11173523089382797, 0.047941656375769526, 0.05302931247570086, 0.057393337483517826, 0.0458180601708591, 0.024168154122889973, 0.04023669403977692, 0.06053981356672011, 0.03595695103285834, 0.02593188106402522, 0.02316940332093509, 0.0024896236709537334, 0.02738917522947304, 0.03702059337229002, 0.07451921148458496, 0.04572233054204844, 0.03507775836624205, 0.06746794024365954, 0.03489166854706127, 0.014620123693021014, 0.04135256131121423, 0.015269093801180134, 0.03384349627594929, 0.0009344199338556791, 0.03403494069061708, 0.033101823573815636, 0.00610388911809423, 0.00472293458187778, 0.042629322488210164, 0.03907856887963135, 0.017261681459785905, 0.04866540250077378, 0.042005295035778545, 0.01644802228838671, 0.058736127539305016, 0.050198935641674325, 0.05345705671061296, 0.04859508771914989, 0.08407716813962907, 0.027641518427117262, 0.06699803459923714, 0.09264391235774383, 0.05975050982669927, 0.009843293883022852, 0.06602477471460588, 0.0653621407400351, 0.010479125194251537, 0.049014935502782464, 0.038603653738391586, 0.04723461599496659, 0.07522239640820771, 0.09032096786540933, 0.0191562638792675, 0.12903982889838517, 0.030025239248061553, 0.028988143531023525, 0.015398618979816092, 0.0746700529998634, 0.007317849294850021, 0.026426951080793515, 0.0385169597575441, 0.007645037621841766, 0.04417372809257358, 0.047088101200642996, 0.02785463355394313, 0.07007042207987979, 0.021130673558218405, 0.05191617630771361, 0.04101354083104525, 0.03395146020920947, 0.0493805248697754, 0.05343072902178392, 0.01722199325740803, 0.020078072520846035, 0.018598608548927587, 0.06460096439695917, 0.05818654863105621, 0.013078990032227011, 0.06288157892413437, 0.07939359289593995, 0.052943271584808826, 0.10836152403499, 0.02296217342518503, 0.0161567682880559, 0.014193276529113064, 0.05643464966851752, 0.0350381313910475, 0.05646254699968267, 0.040339177212445065, 0.027883809234481305, 0.04237391607603058, 0.028967279904463794, 0.04813701190869324, 0.0017573972331774712, 0.01988136071304325, 0.06652138283243403, 0.05154477221367415, 0.04809900281543378, 0.02155616537493188, 0.07639105635462329, 0.03604381941840984, 0.0648306665243581, 0.036913905933033675, 0.044569240853888914, 0.031302445713663474, 0.023757557210046798, 0.06336367063340731, 0.018325266282772645, 0.030898767472535837, 0.008204690257116454, 0.032069900626083836, 0.022581716984859668, 0.032324364510714076, 0.047667785329394974, 0.0008592927883910306, 0.018502604325476568, 0.03826749794825446, 0.04522193376033101, 0.024320912234543357, 0.010825386252690805, 0.03373507963260636, 0.04637705693312455, 0.006957781506571337, 0.025556276414135937, 0.05260425110463984, 0.05080785296740942, 0.02777036639599828, 0.03966911062889267, 0.013835552999807987, 0.0290965954263811, 0.08788575869402848, 0.02830161425663391, 0.05454411751998123, 0.04062191321281716, 0.02522998005588306, 0.045470571785699576, 0.016400400527345482, 0.035245628459961154, 0.03774930075451266, 0.04582887326250784, 0.0032577704041614197, 0.006387847806763602, 0.03239256788219791, 0.07480154672521167, 0.08599679989856668, 0.0397931531915674, 0.047562426334479824, 0.040944042411865667, 0.01054080415997305, 0.04622405947884545, 0.01261687137230183, 0.06121543141489383, 0.0364302297384711, 0.017555768608872313, 0.03066626188228838, 0.04607266135280952, 0.031124951819947455, 0.043608768173726276, 0.008931671218306292, 0.023982849124877248, 0.024943850585259497, 0.023877180283307098, 0.016700812630006112, 0.033414891149732284, 0.022659659189230297, 0.04090177339094225, 0.03527338478306774, 0.044381429252098314, 0.03702846013766248, 0.01440338224711013, 0.038618088510702364, 0.03341816773172468, 0.09245464985724539, 0.04884177018539049, 0.047085897022043355, 0.03628433834819589, 0.023884521979198325, 0.026916460556094535, 0.039673596911598, 0.04502745396166574, 0.024122176218952518, 0.00926759879803285, 0.047440691851079464, 0.05265064646664541, 0.06867524381959811, 0.02601978474558564, 0.030393684028240386, 0.014003230135131162, 0.03988243726780638, 0.06930554984137416, 0.06546693199197762, 0.018873804328904953, 0.015704468241892755, 0.04608604227541946, 0.0477107148617506, 0.020702547117252834, 0.03242761580622755, 0.02312816217454383, 0.015529779666394461, 0.04534910447546281, 0.10253828455461189, 0.06782805998227559, 0.041283942337031476, 0.010280839105689665, 0.06606693612411618, 0.03134331578621641, 0.036122950914432295, 0.04420879457029514, 0.015080222783581121, 0.03040386814973317, 0.0580866258678725, 0.022361033807101194, 0.03149160431348719, 0.03644061980594415, 0.033536718401592225, 0.034792510195984505, 0.05246007407549769, 0.08053619603742845, 0.04409394721733406, 0.0005103633611724945, 0.04031904645671602, 0.006314934116744553, 0.02985795359563781, 0.028542704640130978, 0.013351379566302057, 0.01374180397760938, 0.050752629758790135, 0.00444674154095992, 0.006450899281844613, 0.12526952574262396, 0.019778196619881783, 0.00498308656460722, 0.029941755055915564, 0.06525254779262468, 0.019475465305731632, 0.030866749366396107, 0.04324840352637693, 0.04665796353947371, 0.03788999340031296, 0.048059498294605874, 0.009077753711608239, 0.08517588066752069, 0.06449739026720636, 0.034890833630925044, 0.02356356166274054, 0.021020472049713135, 0.016646509684505872, 0.037422982131829485, 0.061850312777096406, 0.01669034463702701, 0.04425401733897161, 0.037793269293615595, 0.04319036386732478, 0.04687375410867389, 0.06763919824152254, 0.04060868814121932, 0.06390283349901438, 0.046415711694862694, 0.05656649962475058, 0.02808437835483346, 0.05756225771619938, 0.004157488092459971, 0.01523397351775202, 0.03714465077791829, 0.018922580129583366, 0.09167299765977077, 0.06580656845471822, 0.04961910308338702, 0.029093790108163375, 0.01108785883843666, 0.02752377484284807, 0.07810411130776629, 0.0934881647117436, 0.06747289779013954, 0.011434798962000059, 0.0567081385088386, 0.05030489948694594, 0.09285123873269185, 0.05613041364995297, 0.0064968669812515145, 0.044716727861668915, 0.008603608548582997, 0.08402482446399517, 0.017497369008196983, 0.04432085144799203, 0.016801640813355334, 0.012640352924790932, 0.03233792354876641, 0.05351478095690254, 0.01672672100539785, 0.0063372300883202115, 0.03828573251666967, 0.09546549103106372, 0.05700772126147058, 0.06391435163095593, 0.014413035733014112, 0.023214095454022754, 0.054685667346348055, 0.02859356587578077, 0.03422584333748091, 0.026030347362393513, 0.04046774316520896, 0.07567090593511239, 0.017913335359480698, 0.0457894429564476, 0.04947921566781588, 0.019132812012685463, 0.05871445682714693, 0.014155902899801731, 0.02351077269850066, 0.01122912664868636, 0.04215311972075142, 0.015235085811582394, 0.03765426132304128, 0.05684471223503351, 0.020875040790997446, 0.04637431469745934, 0.02807499018672388, 0.08813779946649447, 0.0502841935667675, 0.08281662288936786, 0.04859241969825234, 0.018449407180014532, 0.014870586473989533, 0.06378459453117102, 0.04111895177629776, 0.07668822712730616, 0.021842146416020114, 0.012752032234857325, 0.06379208280122839, 0.01881378313555615, 0.006823182820880902, 0.04344139160821214, 0.10318407177692279, 0.030160406604409218, 0.041744222326087765, 0.05817184668558184, 0.033942936643143184, 0.029401671927189454, 0.08744962819037028, 0.04876146980677731, 0.033100936707342044, 0.014959051404730417, 0.05032454413594678, 0.10263832606142387, 0.1359839562792331, 0.0995603427872993, 0.13987419049954042, 0.17045800719643012, 0.1656960611580871, 0.1318203445407562, 0.09342031757114455, 0.2424088236875832, 0.13987001962959766, 0.11573403389775194, 0.20593654015101492, 0.14776755444472656, 0.055415053793694824, 0.16920322843361646, 0.17136519367340952, 0.16704810579540208, 0.11457520740805194, 0.1539882065844722, 0.10785140140797012, 0.14886615565046668, 0.1251323174801655, 0.19425207807216793, 0.11905973864486441, 0.15037495672004297, 0.28783007233869284, 0.17783658782718703, 0.11824411834822968, 0.10694593671360053, 0.11669711893773638, 0.16122856963193044, 0.1130235027812887, 0.24252795323263854, 0.09244803732144646, 0.15878323756624013, 0.14020833506947383, 0.17465142358560115, 0.08551566555979662, 0.07579404307762161, 0.09957983900676481, 0.19839848682750016, 0.18589988874737173, 0.1051222498062998, 0.1097297178057488, 0.1532699857489206, 0.22653179126791656, 0.10170108260354027, 0.11431991602876224, 0.10587846860289574, 0.22885858750669286, 0.17535138758830726, 0.11302081620669924, 0.1494079382973723, 0.1348102348856628, 0.11196186795132235, 0.08946789137553424, 0.08184894395526499, 0.11920929624466226, 0.1500787804252468, 0.17783266928745434, 0.12125713401474059, 0.28450726938899606, 0.11215470018214546, 0.1087355516210664, 0.07950379440444522, 0.1522201139596291, 0.0640805927105248, 0.11200663429917768, 0.1704819340375252, 0.12484469072660431, 0.10275043488945812, 0.10930645614280365, 0.1491601500310935, 0.242451541707851, 0.12688734830589965, 0.11555239325389266, 0.1268032778170891, 0.14637160435086116, 0.10078391424030997, 0.15192914754152298, 0.129554211453069, 0.08661238913191482, 0.15110344887943938, 0.2665768627775833, 0.09741456378833391, 0.13046591018792242, 0.19057611672906205, 0.1807690062560141, 0.16957606858341023, 0.1730321315699257, 0.15317959216190502, 0.11963096971157938, 0.18812020163750276, 0.17373316426528618, 0.15859798266319558, 0.19843988382490352, 0.23034035955788568, 0.16957111103693023, 0.144226040574722, 0.09482944820774719, 0.22279150056419894, 0.0946085924806539, 0.10485644961590879, 0.2168017454096116, 0.14412313437787816, 0.11941623670281842, 0.08399113838095218, 0.20183393295155838, 0.12207958207000047, 0.23113950417609885, 0.16499036777531728, 0.11694058048306033, 0.058073504696949385, 0.14699211402330548, 0.1524194102967158, 0.12369536372716539, 0.11818340324680321, 0.15777703374624252, 0.11129129299661145, 0.1219225065142382, 0.08526803314452991, 0.06404391577234492, 0.05667013683705591, 0.08285600124509074, 0.1737232640152797, 0.13289507827721536, 0.13593357929494232, 0.12305932832532562, 0.11982826224993914, 0.13003764644963667, 0.1507457930711098, 0.11001003440469503, 0.1249208944500424, 0.1304947945754975, 0.1543006210704334, 0.1400497677968815, 0.1735404136707075, 0.1331336490693502, 0.1865924461162649, 0.11282484469120391, 0.08887249598046765, 0.115450689336285, 0.1430700861965306, 0.10473755013663322, 0.08119244754198007, 0.1257148291915655, 0.12351663972367533, 0.22219769336516038, 0.13554306118749082, 0.09403480842593126, 0.23679199774051085, 0.1945505550247617, 0.2473436456057243, 0.17832051264122128, 0.16943556518526748, 0.11171908918186091, 0.26502188527956605, 0.16188471723580733, 0.107056004635524, 0.1591412050765939, 0.1297356517170556, 0.15660173899959773, 0.22909122111741453, 0.16543770470889285, 0.15701287396950647, 0.1578906417125836, 0.11274866323219612, 0.13143027172191069, 0.09682187723228708, 0.09692945895949379, 0.11649754058453254, 0.24807892099488527, 0.10879129433305934, 0.09053610905539244, 0.10191884357482195, 0.14755884767509997], [0.030383023076865356, 0.09123760188231245, 0.08665209403261542, 0.04132332069275435, 0.06530210841447115, 0.03254060778999701, 0.03681355643493589, 0.06648702139500529, 0.015953982001519762, 0.010238391041639261, 0.02438717488985276, 0.035941785245086066, 0.04796147914021276, 0.045190355376689695, 0.03869253705488518, 0.02975267623696709, 0.0397905630961759, 0.04264570539817214, 0.009584310319041833, 0.10405012842966244, 0.016461547929793596, 0.0383230180159444, 0.033783916660468094, 0.08146146865328774, 0.011511123284435598, 0.050870623817900196, 0.06255054395296611, 0.04046457048389129, 0.0810325815109536, 0.023145929189922754, 0.002582867568889924, 0.023227422570926137, 0.034755926026264206, 0.02710006789129693, 0.03017326245753793, 0.03570622386178002, 0.04725729231722653, 0.04655097181966994, 0.04109082066861447, 0.04733864283480216, 0.005927458814767306, 0.030927651860110927, 0.049020676015061326, 0.05774860728706699, 0.02492685911420267, 0.08798574825050309, 0.03324788936879486, 0.061403606669045985, 0.051725900775636546, 0.041091722378041595, 0.04062918997078668, 0.011380178748368053, 0.043943354321527295, 0.004077883941135951, 0.03262828140577767, 0.016379703884012997, 0.015842708089621738, 0.030665118974866346, 0.05632980646623764, 0.020446261260076426, 0.11032277543563396, 0.1447104403632693, 0.04258368782757316, 0.04781984396686312, 0.050810650864150375, 0.053510999714490026, 0.042802254029084, 0.030655879236292094, 0.060352966756909154, 0.006606147762795445, 0.0444457029516343, 0.06504384844447486, 0.07231378607684746, 0.012051928151777247, 0.03753460856387392, 0.0456952273088973, 0.018141033688152675, 0.027892338366655167, 0.01833231668570079, 0.09618182681151666, 0.03626241159508936, 0.029989254362590145, 0.009654020250309259, 0.06324705696897581, 0.022815393313067034, 0.009796903159440262, 0.038681864971295, 0.03644464224635158, 0.050594504064065404, 0.049290413298876956, 0.01133157549702446, 0.043089891914860345, 0.03729744043084793, 0.023974884024937637, 0.046834405438858084, 0.06041015294613317, 0.03002092180395266, 0.0666709330107551, 0.02055877270322526, 0.024988271834445186, 0.09228036389686167, 0.0253556145253242, 0.06944244640180841, 0.0264333279847051, 0.04094453222933225, 0.012746861320920289, 0.0013545851015805965, 0.027238137045060284, 0.03559182179742493, 0.07831501483451575, 0.048052889469545335, 0.04225351003697142, 0.03453582357906271, 0.05885867838514969, 0.035380402478040196, 0.025770606807782315, 0.036169624581816606, 0.0012437097461770463, 0.03623775744927116, 0.015631439055141527, 0.042472094792174175, 0.030454825864580926, 0.03645123622845858, 0.017893006079248153, 0.05774123776063789, 0.022601604687224608, 0.049822922810562886, 0.0029899144647060893, 0.056734766767476685, 0.032048946086433716, 0.0866990645590704, 0.04983721286407672, 0.01442517355826567, 0.03061613351746928, 0.010382728560216492, 0.026781755186675582, 0.04382303734018933, 0.045082243013894185, 0.08123120991513133, 0.024395123291469645, 0.0620396086742403, 0.06154988397611305, 0.06061018029868137, 0.06958799640415236, 0.04704470782598946, 0.04938081430736929, 0.024729653778194916, 0.03925408309441991, 0.043863588289241306, 0.01774142056092387, 0.006633208322455175, 0.049525021022418514, 0.058689546640380286, 0.03238322795368731, 0.012178442066215212, 0.06724554827087559, 0.04181891948974226, 0.012286332712392323, 0.0823986082104966, 0.04122116035432555, 0.03949699916120153, 0.044582736809388734, 0.02826267562340945, 0.01883396769699175, 0.03353399471961893, 0.041459003841737285, 0.057925720830098726, 0.012540342031570617, 0.03342684343806468, 0.04063033287820872, 0.0393920557689853, 0.031368663840112276, 0.022610447376791853, 0.05742711262428202, 0.04779777991643641, 0.018280592703376897, 0.03469377857982181, 0.016981969711196143, 0.04959946956660133, 0.06101412385760341, 0.021830003024660982, 0.02392860740656033, 0.03912495310942177, 0.03391934747924097, 0.039723754962324165, 0.029368785508268047, 0.05598278563411441, 0.014603869731217856, 0.029975506076880265, 0.04031025571748614, 0.0616621709195897, 0.04523009367403574, 0.030871866474626586, 0.017550664488226175, 0.036015057485201396, 0.10638347041094676, 0.02254939088743413, 0.032054968614829704, 0.06273929437156767, 0.04360239312518388, 0.03932147010345943, 0.065357027342543, 0.006458695543187787, 0.03370502636244055, 0.05980286092380993, 0.04692695125413593, 0.022028778003004845, 0.13464509218465537, 0.07025805185548961, 0.03103695165918907, 0.018777111763483845, 0.08404789041378535, 0.0481457840942312, 0.04157808143645525, 0.07297777818166651, 0.05008659674786031, 0.05462413217173889, 0.020649772995966487, 0.0997785416257102, 0.04784057957294863, 0.048498816322535276, 0.05096394888823852, 0.034457003785064444, 0.01171213398265536, 0.07579592813272029, 0.027953268690907862, 0.04582787136314437, 0.0688674600678496, 0.10066856964840554, 0.01576465456309961, 0.04506725905230269, 0.08860841757268645, 0.020327430429460946, 0.027102849089715164, 0.060049595340387896, 0.03599052579374984, 0.0384456950268941, 0.06790530271246098, 0.015983417433744762, 0.056011714550550096, 0.10276570828864351, 0.07534772288636304, 0.03643847499915864, 0.06667610578006133, 0.020231402086210437, 0.029174314986448735, 0.05356025605578907, 0.09911155866575427, 0.020495871976891067, 0.030386143807845656, 0.05512054362043273, 0.011060214765166165, 0.01715795704512857, 0.05077234120108187, 0.02293364526849473, 0.11678553841193207, 0.05137585198099259, 0.028095929883420467, 0.007943440359667875, 0.030890216075931676, 0.035914403706556186, 0.0025625510443205712, 0.02704143636947265, 0.05912761786021292, 0.03244405066652689, 0.03184964232787024, 0.04912409058306366, 0.12065570495906286, 0.01173627975731506, 0.04062341606186237, 0.025831600214587525, 0.041439722845098004, 0.04953384144755546, 0.00284735601326247, 0.030270858587755356, 0.023143224061641376, 0.040151365610654466, 0.018363344024692196, 0.06778888200642541, 0.024021758072194643, 0.05498783277289476, 0.023079117345332634, 0.017775563064788003, 0.016267099672404584, 0.034810332872439176, 0.03072609382797964, 0.03286827712145168, 0.019799008296104148, 0.05585596743912902, 0.0368205029371893, 0.06184269463119563, 0.02545507715694839, 0.08466468192636967, 0.026130949190701358, 0.01247438180143945, 0.015319019003072754, 0.0264308492114651, 0.07072006847010925, 0.010165443491132464, 0.046721094331587665, 0.09198304469464347, 0.08168890723027289, 0.01924015254189726, 0.03967009026382584, 0.03446570917731151, 0.025522866781102493, 0.0537909526610747, 0.031009757512947544, 0.02901025025494164, 0.06133895076345652, 0.06956483397516422, 0.022517493380291853, 0.032970838219625875, 0.0545432158105541, 0.07836937715183012, 0.06217953690793365, 0.01711083994450746, 0.029246691083244514, 0.029681945852644276, 0.01607952555787051, 0.04189561303064693, 0.043228736612945795, 0.038238643246586435, 0.05262909078737721, 0.046592520957347006, 0.02390070822002599, 0.007118740350051667, 0.030453998369921464, 0.04818636843992863, 0.014091350894887, 0.013630935463879723, 0.03251825430197641, 0.06927529248059727, 0.00511961390657234, 0.06435406670789234, 0.05060120194684714, 0.01807716445910046, 0.046728256056667306, 0.04178481780400034, 0.03295702685136348, 0.023106485896278173, 0.04991800677089486, 0.04690497255069204, 0.011248752743995283, 0.02331248568225419, 0.03539594305038918, 0.0386315362266032, 0.04049264593049884, 0.031455602729693055, 0.051857709913747385, 0.06345223853713833, 0.04660030979721341, 0.1362566658644937, 0.10265365141094662, 0.1779270704719238, 0.10411047245725058, 0.12141297760535963, 0.1871275345911272, 0.09953260872862302, 0.1597765725455247, 0.16976616228930652, 0.07752999328658916, 0.11137696652440354, 0.09998228342738003, 0.11992357627605088, 0.11186885458300821, 0.14432090189075097, 0.17546266521094367, 0.12883290328318253, 0.16823830286739394, 0.1284971705172211, 0.16195531032280996, 0.1566500379703939, 0.11509964606375434, 0.1396273373393342, 0.12281857561902143, 0.11943875346332788, 0.137551624502521, 0.1817907506483607, 0.17969684035051614, 0.13693696295376867, 0.09287470544222742, 0.10089825693285093, 0.1808426866773516, 0.13683514029253274, 0.13751518505159765, 0.14766208041692153, 0.19662277976749465, 0.1686171247274615, 0.12920265609864146, 0.1988685186370276, 0.16381004126742482, 0.13870042457710952, 0.06244377858820371, 0.16091234050691128, 0.15738933579996228, 0.17159214243292809, 0.17343808634905145, 0.23956874327268451, 0.14093201811192557, 0.24281697522383183, 0.14306581142591313, 0.22376407025149092, 0.16462661151308566, 0.19719849340617657, 0.10802201373735443, 0.11419260801631026, 0.16883559816051275, 0.12543812685180455, 0.14958520769141614, 0.24103381700115278, 0.13118197879521176, 0.224660747917369, 0.29933736892417073, 0.23663645843043923, 0.23971496120793745, 0.19647663604700938, 0.13981336407596245, 0.15934939234284684, 0.20639198133721948, 0.17256754712434486, 0.2637408790178597, 0.07728894372121431, 0.14980758482124656, 0.13338271382963285, 0.10735568386735395, 0.11667240542010404, 0.08853221384924836, 0.09393113781698048, 0.21139295829925686, 0.08047407085541636, 0.1737934266566299, 0.1087704325618688, 0.12356011473457329, 0.11593350835028104, 0.18075251573463902, 0.08455258051981218, 0.05729958567826543, 0.09936305024893954, 0.18934340943815187, 0.15870648465352133, 0.23356706922641024, 0.13757277571130544, 0.23553656588774174, 0.14379963220562786, 0.09996635693823919, 0.13393132423516363, 0.10530843981541693, 0.1284660745295696, 0.19250152981840074, 0.15977888804627582, 0.08912980600143783, 0.19752175809117034, 0.07764259193209, 0.13410388841293752, 0.12309929297771305, 0.18298390146810561, 0.0737518011010252, 0.07985311589436606, 0.11819521081633866, 0.18292283755727112, 0.15443557320395485, 0.1156734894902911, 0.14808249223278835, 0.13057432312052697, 0.2073830898734741, 0.17865020432509482, 0.10717398385168053, 0.13174768828321248, 0.09812729273107834, 0.10082894776132889, 0.10501517273951322, 0.08629285002825782, 0.14312764717033133, 0.13628129032440484, 0.08387845809920691, 0.22470760712167248, 0.13027934910496697, 0.10970931616611779, 0.07295386618352495, 0.13652190944412723, 0.08891205987310968, 0.14920234854798764, 0.0872828156570904, 0.1420210604555905, 0.18379732500761747, 0.11825364010292105, 0.0774257215380203, 0.17301114363363013, 0.18248825072078034, 0.16297990456223488, 0.1915121282218024, 0.17902969411807135, 0.10104168439283967, 0.11468664830317721, 0.1595257266308181, 0.12954702746355906, 0.0978547241538763, 0.09769042007974349, 0.10565847376710735, 0.17285723704844713, 0.13860621635103598, 0.07840336751542054, 0.07984103373019025, 0.13532801647670567, 0.17628070490900427, 0.07507460511988029, 0.19794472289504483, 0.17879722377983853, 0.05125159048475325, 0.1697673645685427, 0.1430708431871608, 0.07239801983814687, 0.14533329522237182, 0.12509074236731976, 0.1564916191273369, 0.13366379484068602, 0.17218819091795012, 0.24238424375653267, 0.18513372517190874, 0.08442260077572428, 0.1615770673379302, 0.16861040086951107, 0.14463953557424247, 0.08964476743130945, 0.12703457556199282, 0.17021921375999227, 0.12251698906766251], [0.017758020549081266, 0.017337204262730666, 0.03696728490467649, 0.038122278201626614, 0.06781807809602469, 0.03375032334588468, 0.013548732404160546, 0.09542253552353941, 0.008498251409037039, 0.0384326369385235, 0.035946880088886246, 0.03881640892359428, 0.0294753393609426, 0.03145031863823533, 0.06262259164941497, 0.057021784959943034, 0.07635867645149119, 0.01978280721232295, 0.01123094398280955, 0.04567299627524335, 0.04305401278543286, 0.04467248101718724, 0.016158371327037457, 0.03912530934030656, 0.03278096715803258, 0.03313966568384785, 0.036342103412607685, 0.024568809967604466, 0.05343524499039631, 0.027069927418779116, 0.007809244289092021, 0.06990202877204865, 0.04432098132383544, 0.04943349937093444, 0.012459353310987353, 0.02991573535837233, 0.10689944116165861, 0.03578803451091517, 0.044134757918072864, 0.03634899425378535, 0.030568721413146704, 0.07235904224216938, 0.1154676622536499, 0.059986145424772985, 0.007809817598172231, 0.027520396215550136, 0.04157079725700896, 0.08527960322680883, 0.0493494511465542, 0.02923348827607697, 0.05535074669751339, 0.0063623183905292535, 0.039540912039228715, 0.024942128802649677, 0.030991797539172694, 0.04507824283791706, 0.01858702362369513, 0.05828905035741627, 0.03081826671404997, 0.024916062720876653, 0.022454514728451613, 0.04337636833952274, 0.08857902110321447, 0.03546007945260499, 0.05497772101080045, 0.027357179387763608, 0.014638604097854113, 0.06693270333926193, 0.04406603875395376, 0.0847900751978159, 0.04765234494698234, 0.09130564198130742, 0.01739096358505776, 0.024921207659645006, 0.024109264704748057, 0.07198700361186638, 0.0486806684784824, 0.010790628693939652, 0.05017362840590067, 0.010553070005698828, 0.009091553019970888, 0.04511205879680347, 0.06084288812417071, 0.057864553018589504, 0.04526758326392155, 0.031768087719683535, 0.07087556325132027, 0.0241907228337368, 0.044544946649693884, 0.04343832282756921, 0.05856474337633699, 0.022218567428353708, 0.04808011515706312, 0.026493018922337797, 0.013690632895304589, 0.006739846130585647, 0.10052730183815584, 0.06981623650062829, 0.05691045167623088, 0.0430755833076546, 0.07727948133833706, 0.031197235148283653, 0.05797049088869244, 0.043013016547774896, 0.0778060351149179, 0.021104024890519213, 0.03331366962811444, 0.011183793485542992, 0.028325238672550768, 0.028380825533531606, 0.043333290377631783, 0.04472024564165622, 0.0353022765921196, 0.03325948542624246, 0.03833368267805781, 0.0607597416092176, 0.07206166366813704, 0.024685954267624766, 0.006743263720636605, 0.009276106593461009, 0.054784406383987516, 0.02524985477066366, 0.023180108801170718, 0.03464815876213834, 0.019538961605576333, 0.037422329041874036, 0.00640229603050102, 0.0440515112131834, 0.016709217452444136, 0.07999802022823133, 0.017444878758396953, 0.0881180731812492, 0.02958750570542179, 0.044012967773596756, 0.05030951935623307, 0.038875342870596796, 0.021974155934003647, 0.020363810508570168, 0.027443654435046483, 0.05590622567979153, 0.053135636262595654, 0.018298122231499292, 0.02709305645112181, 0.048986221809173, 0.09152111713774502, 0.05928655620664358, 0.02591888049209956, 0.03569104323105421, 0.05466944770887494, 0.0623525092669297, 0.014863248488836689, 0.036767313213204034, 0.08267612691270187, 0.08634567609988153, 0.019175283268850762, 0.032454578031320125, 0.07936640060506761, 0.040132956637535244, 0.07511060670367442, 0.006284534820224508, 0.01709368149022339, 0.05695246836694423, 0.011276665845798561, 0.0340284283447545, 0.007909169835329521, 0.035519339944585226, 0.005282622469167109, 0.06627706039580517, 0.04022423338028602, 0.03859330819977913, 0.06265290838200599, 0.04129588349314872, 0.059749723150162026, 0.02956647138489643, 0.07121285452740267, 0.0643918791320175, 0.010927742332569323, 0.04185120662441477, 0.03837621145066805, 0.019863211491610855, 0.033042663271771744, 0.02420176413579611, 0.04036471822473686, 0.08356350546819158, 0.046870095320628025, 0.02589552510471549, 0.03998281274107285, 0.02900953964854125, 0.03725715294422116, 0.05089810554636642, 0.033380373861291446, 0.0266348841614672, 0.07606497892993502, 0.05947871308308095, 0.040417028503725305, 0.051669404783751816, 0.01847563838964561, 0.08974477925221436, 0.022559311546501704, 0.041656982866697945, 0.03161991051456425, 0.02855859958799556, 0.03914779641490895, 0.0200889468396781, 0.009380970204801997, 0.02676252985111205, 0.04688768050982617, 0.021166675142012537, 0.04817968168936204, 0.05497636288055219, 0.055594764853594825, 0.024352802320208866, 0.06736847761203535, 0.02886763173592044, 0.019841509238176513, 0.05940529612416867, 0.012397678056004224, 0.0698135573475156, 0.04662311228457838, 0.02284864709508838, 0.04328799339418765, 0.023385260683426168, 0.04369785187009256, 0.025303725415142253, 0.023282465808733832, 0.022215259305085056, 0.07191370910732076, 0.08347001712536439, 0.029062927897030022, 0.052893569954903796, 0.02545549832575489, 0.019130492801195942, 0.051337078475626186, 0.055503992771264166, 0.05395721229433548, 0.04841136535105761, 0.06061237334506586, 0.06144977196527179, 0.09458462853217497, 0.06622414526646025, 0.030791653298365418, 0.058853086302406155, 0.04171228029008489, 0.03633613283454906, 0.011345503753545927, 0.07975313375936821, 0.04547479089524131, 0.021428833242680412, 0.013068342996120919, 0.023728379674139433, 0.06440433237003163, 0.030570096241717692, 0.01201966791995801, 0.015676986513426527, 0.04307791736209765, 0.025630982854636386, 0.05471710472193081, 0.04645752800570335, 0.05047775310231373, 0.029555185174103826, 0.014044968520465773, 0.027753168978961185, 0.03653041596408002, 0.08214140209020115, 0.08338895233464427, 0.010504311831027735, 0.04989995402866043, 0.04724413403891958, 0.015714856453996617, 0.05952485611487646, 0.03281186647654977, 0.021712485795433167, 0.08534893466276117, 0.02195388045947766, 0.04720704149804078, 0.03040290150238434, 0.054223595070652664, 0.04399335652124137, 0.04488200414925814, 0.04221792405587621, 0.053458693146239966, 0.04716140312666539, 0.043049370651715435, 0.007187462761066854, 0.08830368431517854, 0.027612110825430136, 0.056391846301266924, 0.0359548136475496, 0.039346547273453325, 0.023149500775616616, 0.07259212856297381, 0.031007453144411556, 0.06296558261965401, 0.037813719172845595, 0.004749004838231485, 0.05972728060442023, 0.07697333057876676, 0.03371731632796582, 0.041960035159718245, 0.0299023303159629, 0.0175361629226245, 0.05670618666044902, 0.04600243191816844, 0.05504878907231614, 0.024939972863649018, 0.047632807909394614, 0.004996895149815828, 0.019883156710420735, 0.04446574836038053, 0.03336196859891061, 0.009820432951528346, 0.026337351591791958, 0.020415254330146126, 0.027162881415279116, 0.06518943555420265, 0.011873055718751857, 0.04642646912543569, 0.020834276474488433, 0.019586299495131243, 0.08980907150544226, 0.007030358910924406, 0.0656895614520181, 0.0372600881382823, 0.05288224849209655, 0.0813898365595378, 0.07110622274922207, 0.047795683349249884, 0.03532110116793774, 0.038185431258170865, 0.05038612383941654, 0.011567161927814595, 0.03814066862105392, 0.05082997267891187, 0.005087941826786846, 0.0025499570301690255, 0.011922941957891453, 0.0066367608906148234, 0.048607318312861025, 0.007988288343767636, 0.022151026423671283, 0.04980158606485929, 0.03231945891457144, 0.010928452011285117, 0.07581607744214125, 0.05602495446510147, 0.05657198038534261, 0.03381028145668097, 0.06684382373350672, 0.07362227406702004, 0.042786828489624895, 0.038782971460022964, 0.0298582875620923, 0.10932039367617108, 0.12606435106135905, 0.1404024809016846, 0.11669174578855745, 0.19073299190495163, 0.11621714234934188, 0.11936058304854669, 0.1736466446891427, 0.12021342947264202, 0.16416107711847872, 0.222655197721906, 0.13562132808146998, 0.10095258956425823, 0.15242603025399148, 0.17377911804942414, 0.19247648975579068, 0.173695003031753, 0.09490963726420887, 0.10238503848086111, 0.15719048475148156, 0.18144443485653028, 0.15422584227053449, 0.06605831978959031, 0.08281996997538954, 0.11029290399164893, 0.08052395802224055, 0.10571581951808184, 0.08959349986980669, 0.09548593719955534, 0.12290608967305161, 0.1261520283878781, 0.15806629322469234, 0.12845826713601127, 0.16353258193703368, 0.14295100118033588, 0.1298173621762544, 0.21863780391868204, 0.21810572856338695, 0.0947622764215339, 0.12136617035139352, 0.16238208976574242, 0.11224853733438067, 0.18328139878576621, 0.1663916910183616, 0.2153220513719134, 0.10757500334875658, 0.16163048712769523, 0.17332198476651683, 0.1444353855913505, 0.14137859805487096, 0.20921300339978188, 0.10310400146408938, 0.10745262319687754, 0.10886994714383036, 0.32177857880014926, 0.26881746598519385, 0.1083207133342512, 0.15673753718147054, 0.13509587268345058, 0.13872433657525107, 0.14026035962160677, 0.1574391042231582, 0.17453713284339756, 0.20054289285326377, 0.15375361370388418, 0.15276010060915723, 0.09908867083140649, 0.1410202743136324, 0.10547364188823849, 0.1725668495055288, 0.09872380876913667, 0.15636404394172132, 0.09406228273292072, 0.10363358320319094, 0.15796300111105666, 0.12586668744916096, 0.19796078297076747, 0.12048512973706238, 0.10088761453516781, 0.10862092691240832, 0.15092427958734334, 0.10539463284658268, 0.13567456975579262, 0.16256517759757116, 0.16597393609117717, 0.16662114823702723, 0.17172756954096258, 0.15828956093173474, 0.21903725748416036, 0.11313109192997217, 0.10317432737792842, 0.11267847832641564, 0.10609396602376364, 0.17347117129247636, 0.28561968938447535, 0.16501276579219848, 0.2239820538670756, 0.11817317645181902, 0.16333156381733716, 0.1216409208427649, 0.12657913437578827, 0.16169940296094865, 0.2378702344140038, 0.15291892021195963, 0.2342667363700457, 0.07537043260526843, 0.11198915672139265, 0.170561165723484, 0.08716557858861051, 0.16779302910435945, 0.15946904139127582, 0.1111193151155021, 0.17348807741655037, 0.07497723534470424, 0.17131523229181767, 0.16109720949316397, 0.14149456605082378, 0.11715451939380728, 0.11815077843493782, 0.2066104844561778, 0.17258019332075492, 0.1014694879995659, 0.16616475710179657, 0.08181921351933852, 0.1678614254342392, 0.1569861566531472, 0.08514983870554715, 0.10663778957678005, 0.09234536861185916, 0.1272062343196012, 0.07032933513983153, 0.16933629551203921, 0.0972117274068296, 0.1358822375186719, 0.10194761664024554, 0.11920925171580166, 0.16466352593852207, 0.1416342827724293, 0.18441298103425652, 0.08687212597578764, 0.16432397853350267, 0.09358335999422707, 0.11014364325092174, 0.2085528036695905, 0.12365924339974299, 0.12184130071545951, 0.1808710812474601, 0.15068315580720082, 0.20882491953670979, 0.20135483209742233, 0.15326844208175316, 0.17816265783039853, 0.21844260423677042, 0.1415281111258082, 0.08713487593922764, 0.1145231160626281, 0.21993789821863174, 0.21192585001699626, 0.0981885867076926, 0.13211479905294254, 0.11079855146817863, 0.1119373325491324, 0.08661854895763099, 0.17917960794875398, 0.14218360563972965, 0.11001552629750222, 0.10959633902530186, 0.2856609527952969, 0.11863909676321782, 0.0669897670741193, 0.16806888539576903, 0.19826457370072603, 0.14290871360572055, 0.11041662000934593, 0.1945942675229162, 0.16222450212808326], [0.06040596723323688, 0.03265749604906887, 0.014081446006457554, 0.012599924430105602, 0.004082293226019829, 0.005903718438275973, 0.007757360281175352, 0.04966347980371211, 0.024850471709214617, 0.05021867676987313, 0.08583271846873686, 0.014380078810063424, 0.0036714006137117394, 0.05777142090664711, 0.05607516817690339, 0.016422093503933866, 0.027720004254661035, 0.028889313580293674, 0.016724574343243148, 0.032106703729368746, 0.004877007686445722, 0.06092539639212191, 0.041351900799782015, 0.02087218908854993, 0.017793146398616955, 0.03924657255993225, 0.036509891870082356, 0.027727444285119418, 0.08376577039598487, 0.07401319293421693, 0.05935985071118921, 0.08749642060138285, 0.0386043142498238, 0.03412045094592031, 0.04339442850323394, 0.04185767815215513, 0.05438454834802542, 0.022253908500715625, 0.08080307234195061, 0.10194634756771848, 0.03064595857722452, 0.013832100157742389, 0.004218925860186573, 0.02486695666448213, 0.024588007472630125, 0.014902389357303036, 0.03655029067886062, 0.031733566720504314, 0.018078223874908872, 0.08235357468947768, 0.03208986068784725, 0.09293463386711664, 0.04753099266963545, 0.04048081238579471, 0.01610332437849138, 0.04252296159393154, 0.022035475885786582, 0.027096800586150493, 0.03399389621336013, 0.05003012302040588, 0.02966435880807694, 0.055095948846428655, 0.04787637706613168, 0.04848047043196857, 0.04259205925336573, 0.03396679298020899, 0.0876023324963171, 0.036052213108632714, 0.03032554559467826, 0.033138314975076355, 0.09497699458734132, 0.0622286819270812, 0.004613379669535789, 0.039172149990918115, 0.0721240189159289, 0.05730458775360603, 0.014006668134243228, 0.05963157695077825, 0.01678513544902671, 0.05299997537804302, 0.042626201757229865, 0.03774852892092895, 0.019231068654335104, 0.011220567830605432, 0.030868823669152334, 0.03584069731005002, 0.026017391319328453, 0.06490894083981402, 0.034524598595453426, 0.026463295907888096, 0.032101033721119165, 0.03708454423758667, 0.05331780012056697, 0.07649982551811263, 0.026211164222331718, 0.04680054495111108, 0.10390571391326375, 0.0312678913178388, 0.03930697224859614, 0.03919239577953704, 0.06375942088197917, 0.019021640146092977, 0.010952821357932407, 0.023057554244587664, 0.012428042100509629, 0.027061147811764386, 0.052650716970674694, 0.028354913447401486, 0.06411698763258755, 0.051163323150831275, 0.05333579349098727, 0.015719608054496348, 0.06846480784588493, 0.07923964920337312, 0.04150995970121585, 0.014883898747939384, 0.04237299581291154, 0.04589310985466, 0.007899445845396258, 0.007758950332572567, 0.043484220950631425, 0.06427214844734408, 0.002492669955245219, 0.03186450012435671, 0.09072664804989472, 0.047933359164744616, 0.06419106881367043, 0.026804253393493127, 0.05049142346251756, 0.01779081048880471, 0.017158730734081473, 0.03430028446018696, 0.09809370312723331, 0.032187857577810064, 0.02734756486461265, 0.026297975091438275, 0.03328846629301552, 0.01656655625993153, 0.06716122545185499, 0.03632938300142996, 0.05907332233618945, 0.03689537079480942, 0.020020227675559, 0.028807528906327207, 0.008883686732588103, 0.046126270390232094, 0.04416751631652005, 0.049288806549157016, 0.03475772202364169, 0.05043509074312169, 0.0034052998535116785, 0.07335253307246603, 0.03193462565832306, 0.07166261828388087, 0.021033574666944332, 0.06488534796517342, 0.01993242603930412, 0.052216349067748524, 0.029077596445858944, 0.04826840173336677, 0.048643512855051085, 0.04821332695428282, 0.10459741781232879, 0.016713965342205483, 0.009029788707266562, 0.039825592466513626, 0.054454087585327215, 0.03474566954537295, 0.03474564728094265, 0.05469869945954997, 0.012724774078378687, 0.034327317189308815, 0.0298403164561023, 0.01904668391944142, 0.03088333636696916, 0.018383517453912646, 0.04955998359946534, 0.03332651249365881, 0.02349482208956033, 0.05801452622108627, 0.029783377030980773, 0.026260427985107526, 0.04804285192221869, 0.04296092149161268, 0.030625942854385357, 0.02618843223899603, 0.028778587002307177, 0.015575453289784491, 0.013902746122766985, 0.012598720295500243, 0.008605978782725288, 0.02077529799862532, 0.028439592497306876, 0.014101070246397285, 0.02478925380273722, 0.05910295629291795, 0.026247444111504592, 0.017852421733550727, 0.012158673107478535, 0.05546168293221854, 0.036529558783513494, 0.056345050179515965, 0.053238494219840504, 0.055396993629983626, 0.03439844833337702, 0.08023234593565576, 0.012005355602013879, 0.02500861224689288, 0.021427758983918466, 0.026162399553868454, 0.0346679963695351, 0.026884394210355822, 0.01868518749688519, 0.06383798463502899, 0.02141148183000041, 0.008823704501992324, 0.01613155567611102, 0.01135451064328663, 0.015146521618589759, 0.06044337889761664, 0.08128312314511277, 0.020717256484203972, 0.0646023076842539, 0.02088492619805038, 0.04375475604319945, 0.03871527274895925, 0.04147771709540393, 0.0346413940860657, 0.03617363589000888, 0.07829762631445192, 0.024259490237454884, 0.029537373629864305, 0.09019232398713939, 0.0486232151160948, 0.048665684516890906, 0.08150501787895337, 0.0793843976862263, 0.04475531583011616, 0.04109148489078507, 0.038989284803392366, 0.035665056930156425, 0.0336306742974557, 0.04129838082008064, 0.029547693193308078, 0.030067016596149188, 0.030240467640396673, 0.007940749146655435, 0.04792870589881204, 0.027434121548139956, 0.06981026221183129, 0.05710401492251549, 0.043309341272106394, 0.027188114436285105, 0.04936402692692354, 0.07198576422524638, 0.044975002674618736, 0.008544805405108491, 0.03521818383887876, 0.07124944240786135, 0.02023838384047849, 0.04113926806894597, 0.029009894024056848, 0.021063835738459602, 0.06490672923973761, 0.04022072673251387, 0.005206401119721704, 0.0693425236386247, 0.034301909763598815, 0.03524189545714762, 0.08936010184697807, 0.04703849604993593, 0.05295975468470715, 0.06275119099882431, 0.046697957877768204, 0.03260167912230827, 0.041329925807076506, 0.011117970552732004, 0.005203123610044713, 0.07540734703070484, 0.01988109539524885, 0.06469972940976731, 0.02710527776798699, 0.03998802261776291, 0.019284375266579445, 0.06172271903778892, 0.040727632149355486, 0.0343097913719248, 0.021534997467824724, 0.03215058321075048, 0.033736200275598094, 0.04042936670884956, 0.005085974207759136, 0.059585775306914, 0.02005905127589358, 0.05006784638680983, 0.05086224125989247, 0.05157909654371906, 0.051859661762136966, 0.04553625556582119, 0.0256720124889398, 0.07914838730357587, 0.03968554548919201, 0.04606378897733521, 0.04157968818617519, 0.016998120700009167, 0.0361352111940505, 0.08096019984805025, 0.015624863626726437, 0.14792307891184464, 0.03338592141517438, 0.024675738604855724, 0.06080479739466682, 0.022313981644401792, 0.0963040288479533, 0.01476967665439588, 0.008657203670736635, 0.004224661734042456, 0.02955998501420254, 0.020578406220010947, 0.026557546807453036, 0.05823560830322094, 0.04029933501442429, 0.029016200423939154, 0.03909754188498482, 0.04391210990434047, 0.03763850552786607, 0.049288632144453004, 0.055028791903168894, 0.011746094660338713, 0.02925825374404667, 0.009787808139662957, 0.05672868857800495, 0.059815488566528074, 0.09856844757450745, 0.03308865416329354, 0.01868608178483555, 0.06795510082156397, 0.03658245906990487, 0.06530918850330636, 0.03883519639202859, 0.1066421830910258, 0.020029241059091873, 0.06693315604934469, 0.05625540987239219, 0.009823308773775352, 0.06399068894097582, 0.03408325450436678, 0.06472692912211642, 0.022991521655058023, 0.09303039318183437, 0.033277515904046595, 0.045026448351563886, 0.1854918707977049, 0.12666425871429965, 0.1113884178630542, 0.1323019983828999, 0.12402907785144635, 0.13582089159172028, 0.14108546456554905, 0.10593344690278172, 0.1225344072736334, 0.22553691262146458, 0.11859404839924537, 0.08966444918769412, 0.1315261868876405, 0.15129854466067627, 0.1149721970432438, 0.07859621458919719, 0.08481330442009494, 0.12864625314250588, 0.13300246704602614, 0.07807297821273096, 0.10862820738111623, 0.14091073331655934, 0.09881852165563032, 0.11974610650213435, 0.11970134757575579, 0.16767879773397, 0.1364973740419373, 0.25488165440037847, 0.1385092770215124, 0.13857730227755383, 0.1669460753328167, 0.15668154956074432, 0.12951564945979044, 0.18137480656150728, 0.08076502243056893, 0.1872216834453866, 0.22933739150175825, 0.15703638520790264, 0.14488062966847792, 0.1489623825182207, 0.09416376400622539, 0.06928027229150757, 0.12473299750126898, 0.151814233395271, 0.2138263566303067, 0.07858805096475407, 0.14786746236495674, 0.1350830335286446, 0.06126140375272371, 0.11223722700378858, 0.07202403678093106, 0.1791921502444893, 0.11673646760755219, 0.2085628078202717, 0.1363106200005859, 0.17299610772170126, 0.13422643183730543, 0.1279755446012132, 0.11855427670525387, 0.1760117951198481, 0.11745007970603183, 0.1516117903520353, 0.1768738590180874, 0.1373246609000489, 0.08327659859787673, 0.13956311187939718, 0.21007554227253422, 0.0978126740665175, 0.26556599827017635, 0.11633072805125266, 0.24140218942193314, 0.13341970246983692, 0.11652376066194847, 0.12203996622702107, 0.16601123643340543, 0.14285346813267097, 0.11308050714433193, 0.2204206504393369, 0.0985179073177278, 0.17642094113398343, 0.0819775061972905, 0.13888541230699047, 0.14349229400977492, 0.08819844035315327, 0.10397713078418747, 0.12078977393684909, 0.09002530365251005, 0.25744307320564985, 0.16776643053162843, 0.19416214461671188, 0.14337954693473876, 0.12451615679310635, 0.0758751598186791, 0.26680016017053276, 0.1354710283339955, 0.11775856823078357, 0.16740941297030076, 0.13378270174143836, 0.14810548396781087, 0.1342786048189737, 0.23384320753393695, 0.1030697142414283, 0.12108606897527352, 0.13557804602896795, 0.16128175193443894, 0.2532334631541744, 0.18173032498452812, 0.15564291388727725, 0.23571514146169648, 0.15762104914756492, 0.16137070575496182, 0.11693784937961027, 0.2109064656542614, 0.16007841884857044, 0.08269584577647038, 0.08938929051510058, 0.08366795533220284, 0.13373478868743405, 0.14538788760546595, 0.1590367848984897, 0.15862596163060516, 0.15187891898676753, 0.09929821622790769, 0.1452634739689529, 0.18311638967134058, 0.10071805605548434, 0.12996835954254493, 0.16280867625027895, 0.13551459240261465, 0.1976820026175119, 0.16004810953745618, 0.17997410672251135, 0.27507668011821806, 0.12063360380125232, 0.1539377256995067, 0.1239289398654364, 0.13696448178961873, 0.1649700032430701, 0.10045952891232446, 0.07873247290262952, 0.20013343513710424, 0.11327561776852235, 0.1600585292908363, 0.1390520838322118, 0.10585476440610364, 0.12750965397572145, 0.11693461361574009, 0.14581008057575673, 0.08169868873665109, 0.136186265735887, 0.1589571821386926, 0.28631819877773523, 0.11313069859170355, 0.12285154181881808, 0.11344723199727014, 0.11603587277932093, 0.2329913407447748, 0.14169178437441587, 0.1384290657006204, 0.15639273537090048, 0.16292902291752398, 0.10847090918105096, 0.1487456011818722, 0.16143797402037308, 0.12023178278468549, 0.12061637113220058, 0.19766313722357154, 0.1795240238425322, 0.19100813573459163, 0.11613290116656572, 0.16692231176421046, 0.11577210607356392, 0.11567708890652284, 0.1672275274177082, 0.11536296748090535, 0.0744357198709622], [0.07595738235977478, 0.023419546050718054, 0.05487246220582165, 0.05187742135603912, 0.07095736276824027, 0.03321106400107965, 0.032606551321805455, 0.06043751222023275, 0.06556839100085199, 0.037823693637619726, 0.03963954346545506, 0.059211532498011366, 0.06657827587332577, 0.04369032278191298, 0.03839580043859314, 0.020572376270138193, 0.020360342823551036, 0.06739959586411715, 0.03950311816879548, 0.07782041051541455, 0.011329644985380583, 0.016531170658709016, 0.03832112182863057, 0.10444512168760411, 0.013301396847964497, 0.054659165252815, 0.02644394069648115, 0.017930764697666746, 0.043111915147164837, 0.028464239221648313, 0.017447416903451085, 0.010855272539629368, 0.0718164506542962, 0.01698789761576336, 0.01751110245095333, 0.06607865463593043, 0.05633135384414345, 0.04946088090946432, 0.0583630090841325, 0.02648046734975651, 0.05611538887023926, 0.054279964897432365, 0.03025751848326763, 0.013223869318608195, 0.03468637936748564, 0.02479691833286779, 0.055773911881260574, 0.02454474953992758, 0.031557518159388565, 0.0641595794877503, 0.04444146157766227, 0.055968781307456084, 0.015010400602477603, 0.017388200940331444, 0.03180154373694677, 0.03374096115294378, 0.07295861592865549, 0.06159963013487868, 0.04683779705374036, 0.02638682686665561, 0.013461209073284408, 0.05998354419716634, 0.061907061099191196, 0.026221016232739203, 0.036380101373651996, 0.08289937235531397, 0.04357526391686406, 0.052917266730219126, 0.04813375016965438, 0.022354296961566433, 0.006613629075218341, 0.04868173346039839, 0.106106857128907, 0.07591761808726005, 0.06137438089353964, 0.08118394995108247, 0.057507943638483994, 0.03539608405844774, 0.008911670338420663, 0.056403082417091355, 0.09121095135924406, 0.037916291403234936, 0.020273342706786934, 0.018197965691797435, 0.003917346730304416, 0.0349768262822181, 0.047572515832143836, 0.07662161937332712, 0.058462108063395135, 0.028767477051587775, 0.03766828049265314, 0.03436263599724043, 0.00905729455553228, 0.06063510532840155, 0.07745550392428413, 0.06354216457111761, 0.030361767967406195, 0.052937657237634994, 0.020885967060166877, 0.05227609937719535, 0.04859980777837336, 0.03808907822531182, 0.022559281860594638, 0.04106422951736022, 0.07340449083130807, 0.03377099215867929, 0.04229103302350268, 0.003265214841121633, 0.004519373678704142, 0.09722188740852289, 0.05265510677418206, 0.06151704023068305, 0.04601740845828317, 0.0384086024860153, 0.05488137168867979, 0.04169486208411399, 0.022009873646311462, 0.024603032252343837, 0.09130176797043532, 0.10625929426169023, 0.029085930764267687, 0.012971157830179436, 0.02423739650112111, 0.00045484743907309166, 0.04009156706160866, 0.039491622301284224, 0.03154756595904473, 0.009070596624951577, 0.03304093777842354, 0.05218108221015427, 0.03213867916201707, 0.02994441379996715, 0.02325153680430958, 0.04724698759673629, 0.021719358082918916, 0.014677258859592257, 0.01509709643869428, 0.017701285214570817, 0.021820047113578767, 0.060593715752474964, 0.010243292927043512, 0.002916176526923664, 0.010673596643755445, 0.02593501292722067, 0.03196392564859707, 0.10436172655317932, 0.10304925322998315, 0.08078626269707456, 0.027410055554355495, 0.05377189059800003, 0.02303556440892862, 0.045855293719796464, 0.022589322143176105, 0.0348577115801163, 0.09174601756967604, 0.0714597299520392, 0.012883933213743148, 0.014184294686856447, 0.06028631447406951, 0.029859233800380025, 0.0196356634478434, 0.008265666965598939, 0.01729947533021914, 0.029857281951990444, 0.040398849596385844, 0.040828374985721894, 0.015971322281984612, 0.0679614684486296, 0.026793742727022618, 0.0029337721525735105, 0.020999417320126668, 0.01553584394059726, 0.012570785856951261, 0.10488184590940364, 0.02497186480468372, 0.03666890443128068, 0.039472285643569194, 0.009795797359402059, 0.02517422806704417, 0.030125481134746224, 0.03599965792091098, 0.056023132492555305, 0.019999685027869418, 0.04391534566821065, 0.053234145234455355, 0.02147997834981652, 0.045146197589929216, 0.06213537912117317, 0.012833409655286232, 0.05723605783714447, 0.020071543476660736, 0.03973817118094303, 0.009964570090232883, 0.07098794667399488, 0.04549645418592263, 0.040066385990940034, 0.018233761329611298, 0.03226106673537288, 0.03933825748390518, 0.014169807036523707, 0.003783898605433933, 0.06659000180661678, 0.012629726297745947, 0.05236816650722176, 0.026004537321568932, 0.07448384072631598, 0.009282716346206143, 0.06546004486153834, 0.06589938144315965, 0.019887769158231094, 0.029286349599715322, 0.01973271409951849, 0.02588385668786941, 0.04272305945050903, 0.018295324334758334, 0.06811279978137463, 0.04132820773520507, 0.024434390325041022, 0.039000669348752126, 0.06522263181977905, 0.039547235137433745, 0.049512708792462945, 0.053457887916010804, 0.06918655388290063, 0.05843787694175262, 0.06770464082364924, 0.02837691627064487, 0.05070843115390744, 0.007876704585214611, 0.013693791661353316, 0.02736418155109277, 0.028606766827579122, 0.005393204792198958, 0.03507671193801798, 0.04638468992197886, 0.027174434799235314, 0.04460427393496502, 0.04909520619548857, 0.11118104695924558, 0.04156897899520118, 0.08163563587004319, 0.05790450653876178, 0.03593415596697014, 0.08714604526176117, 0.01758213711582357, 0.021114515147928614, 0.018569581297924742, 0.053774135594721884, 0.05068187339929864, 0.0533967386581935, 0.02040309238509508, 0.07844133579055779, 0.030381251199287362, 0.04776128480443731, 0.012802265428035753, 0.026582284444884863, 0.04461584772798233, 0.015341500511567574, 0.012709098991763312, 0.021946425586065743, 0.07188048315583728, 0.021356414472393226, 0.06850267964182422, 0.01288502602619701, 0.13121792842866853, 0.018007777362072375, 0.07450732227880508, 0.03452697717875708, 0.07047553081065416, 0.06809579717810266, 0.12057531552272849, 0.0756780750816688, 0.02867284209060017, 0.05625236706691794, 0.016418158265878446, 0.031247411752701737, 0.046516046350006945, 0.0060794399905717, 0.023245148768182844, 0.023517077243013773, 0.004159361087658908, 0.06974070813157596, 0.006555053678312106, 0.04802306626515929, 0.02521521131711779, 0.02658628462086199, 0.05532846371352207, 0.014086339542700443, 0.0017972854675463168, 0.01887434238597052, 0.07819520993507467, 0.04925197747070342, 0.03701726483996026, 0.041223794978577644, 0.05757671475294046, 0.07249506306834519, 0.04806295670277905, 0.05321850818290841, 0.012794191788998432, 0.05442465771920979, 0.004076569412063691, 0.01593131495610578, 0.03023827273864299, 0.05707578733563423, 0.038680425204802305, 0.03005227197718341, 0.03754286124603823, 0.04229193844366819, 0.060063800046918914, 0.03930076418328099, 0.023904354020487517, 0.03376752632902935, 0.02079487770970445, 0.060875561175635085, 0.027259000671620015, 0.0466349940688815, 0.032488030337844975, 0.01714293597615324, 0.02213940810179338, 0.019159119292453397, 0.05605081460089423, 0.050183294879388995, 0.0488419445900945, 0.1425397177808918, 0.02154393107048236, 0.033176828728755936, 0.049605603417148814, 0.03027523725904757, 0.013100496544211637, 0.01854598656791495, 0.03608994389651343, 0.038397306998376735, 0.02360023860092042, 0.014920079374860507, 0.029491583118215203, 0.11031507194275036, 0.019139528449159116, 0.03224388972739689, 0.008567088389099808, 0.04008786374470219, 0.08428925910266116, 0.0952394402702339, 0.014518635925924173, 0.024108852812787518, 0.052348436511238106, 0.04272677389963064, 0.031827199782128446, 0.06774133260478266, 0.05827238543133717, 0.0473451403377112, 0.020854145623161457, 0.03567104235116858, 0.14435512974159792, 0.07356705085840076, 0.11917264899238944, 0.1317279619979672, 0.1406905974727124, 0.19557746476493776, 0.10399342092568986, 0.14774330105865374, 0.2268043375806883, 0.1219965134805534, 0.11527511203894392, 0.1518226196640171, 0.12352063247817568, 0.19043688982492313, 0.10848399324459024, 0.09281802762416191, 0.07525836830609478, 0.11613630020292476, 0.10851997998543084, 0.16794821218354627, 0.12093467084923759, 0.1304780220380053, 0.10549949831329286, 0.17555771948536858, 0.14680224296171218, 0.15368138789199293, 0.07219099774374627, 0.16596636618487537, 0.11329928485793062, 0.12937541323481128, 0.06890052274684422, 0.14621612441260368, 0.18826616724254563, 0.12322327616857365, 0.0574245707684895, 0.17963672638870776, 0.17333992989733815, 0.112708498199936, 0.15772999642649665, 0.14019608963280916, 0.1383528026053682, 0.09289878071285784, 0.1129155870876275, 0.14258941198932007, 0.18206343054771423, 0.10149886220460758, 0.13765427836915478, 0.11811124422820285, 0.1720219646813348, 0.11306862536002882, 0.10115295459399931, 0.18080220994306728, 0.12412184631102718, 0.24538200086681172, 0.08849751844536513, 0.09825100874877535, 0.07449964847182855, 0.13582034240243956, 0.09359073694213293, 0.13848414790118113, 0.09159884226392023, 0.12453171220840886, 0.23959845886565745, 0.09953687607776374, 0.1353204614133574, 0.17608271475182846, 0.1040724670747295, 0.18765837798127905, 0.09466845411225222, 0.10016917847678997, 0.09934662652085535, 0.11058151780162007, 0.18023418495431542, 0.27000988950021565, 0.1586705053341575, 0.10461597150424495, 0.20505923253949732, 0.10094691955600865, 0.1461764343548566, 0.09247329260688275, 0.1521426485851407, 0.20355838729301468, 0.10820530194905587, 0.1443459716392681, 0.1356056984513998, 0.119083554163808, 0.16698530525900424, 0.15915128344204277, 0.17374169896356761, 0.16477447701618075, 0.1435283327009529, 0.1369627154781483, 0.14418148202821612, 0.17680020828265697, 0.2593458804767579, 0.1721174642443657, 0.15652148314984515, 0.29945676564238966, 0.09828090245719068, 0.1514359310385771, 0.1421854758518748, 0.09987805620767176, 0.10449324996443465, 0.14458212302997708, 0.15383081190520898, 0.1613221544539556, 0.0949406590370927, 0.11288325913483277, 0.06726799081661738, 0.14288195176050067, 0.1329937097034417, 0.13245348556665704, 0.16843626333866268, 0.10568405559752136, 0.1381216532899998, 0.1633671869058162, 0.10760913472040556, 0.07905941864009947, 0.16021697781980038, 0.15996641392121091, 0.09786206399439834, 0.14650608150986955, 0.16120116953970864, 0.12357280545984395, 0.09890331944916397, 0.13244673202279955, 0.15369400440249592, 0.1813617002335377, 0.14516953291604295, 0.08380056227906607, 0.11945330697926693, 0.12679080973612145, 0.09373119581141509, 0.07577861382742412, 0.13783107278868556, 0.1731346221640706, 0.14747529668966308, 0.15813317557331175, 0.06418801116524264, 0.1191008610476274, 0.14949416101444513, 0.06765744765289128, 0.08378582322620787, 0.0800301181152463, 0.11402437055949122, 0.13720158312935382, 0.19502438663039356, 0.20515286189038306, 0.09167223324766383, 0.06387396395439282, 0.11431729624746367, 0.1013206057541538, 0.06960801954846829, 0.16935153922531754, 0.12099183106329292, 0.12480442179366946, 0.25925355730578303, 0.15497401618631557, 0.16131543059600517, 0.1738033417495899, 0.16357899585273117, 0.07372883163043298, 0.07138472108636051, 0.07936944341054186, 0.18364916264545172, 0.1739938955870457, 0.09252692019799724, 0.10838580710696988, 0.15452584804734215, 0.13464529998600483, 0.10320099274395034, 0.15539196407189593, 0.1443569257389754, 0.1796823090990074, 0.14795340306591243, 0.11158941371832043], [0.045292237409739755, 0.022629234845226165, 0.08310442033689469, 0.005027176166549907, 0.053117702263989486, 0.05169952113647014, 0.0372482694365317, 0.062324686150532216, 0.02015769754507346, 0.025995002579293214, 0.006664328893748461, 0.06502562871901318, 0.07364504315773956, 0.03266983425419312, 0.011080980984843336, 0.07316191986319609, 0.036083717277506366, 0.05529261055926327, 0.025716828931763303, 0.020962860980944242, 0.044152569462312385, 0.025882377958623692, 0.021340747734939214, 0.08755176997510716, 0.039957297703949735, 0.01356208364086342, 0.1136418899113778, 0.053042878935229965, 0.0786702438199427, 0.008375338766200002, 0.0350691383209778, 0.00906612518519978, 0.01854924274084624, 0.07042649711365812, 0.06551698985276744, 0.02471461601089686, 0.021921641564404126, 0.05709398850740399, 0.031552768414258026, 0.037612790110870264, 0.03688610879180487, 0.07485935260774568, 0.017750894076016266, 0.06034048012224957, 0.007960979164636228, 0.07734912447631359, 0.027566941862460226, 0.029757997435808647, 0.006358476848618011, 0.05566713538428303, 0.039659087924519554, 0.05330831547325943, 0.019105907304037828, 0.024723709175304975, 0.018017890979535878, 0.011086262293247273, 0.015340791760536376, 0.02621173938678112, 0.023150992492446676, 0.02481893970980309, 0.020420172913873103, 0.0620785602950491, 0.0679256820876617, 0.050559608280309476, 0.07608502433868125, 0.043384197997511365, 0.029848170233890414, 0.04303695081034675, 0.02406436477031093, 0.058442140580154955, 0.04832384016481228, 0.026469160729902796, 0.0387363757181447, 0.007586926994918031, 0.019247319833084475, 0.05017360614147037, 0.04736073286039755, 0.025650191491877194, 0.061719223522231914, 0.06505942612420768, 0.019154525398334954, 0.019886785812559538, 0.032964114361675456, 0.021301573469827417, 0.018058692403428722, 0.03456944657955319, 0.06265396223170683, 0.057441673561697826, 0.020192083102301694, 0.04756755086418707, 0.033516212861286476, 0.07479232925106771, 0.04592864388541784, 0.03581710443540942, 0.014476133128482616, 0.024790029347059317, 0.03387013937754091, 0.06694838491966948, 0.04524863252299838, 0.004556212034003693, 0.05872720692423172, 0.05534336974960752, 0.03249449815484695, 0.06908511713845655, 0.03704577815369703, 0.02279491560329916, 0.06674471733276732, 0.05913795597734861, 0.053340235244832, 0.03619391507527325, 0.04617505175701808, 0.02747446469584247, 0.013050411780568538, 0.044782864351873286, 0.03659730573417619, 0.01266301440409734, 0.0394279979809653, 0.061671874500461854, 0.048538714181631804, 0.0274126215299475, 0.024462384135404136, 0.029185367420723196, 0.03230537666240707, 0.0718960385711398, 0.02981113335408736, 0.036139716030447744, 0.05039786090492271, 0.057269651151727885, 0.05710807447030675, 0.07947796766529791, 0.019640479986264836, 0.022416520478145685, 0.033678260806482285, 0.0652223572251387, 0.008273507755802711, 0.07304405196919106, 0.0680520327296108, 0.056759521103231236, 0.01880158408312127, 0.05483879467647057, 0.03716484832693823, 0.04296699968108442, 0.017999328010773752, 0.0026186237801084644, 0.08879646295099519, 0.04145680337387603, 0.10286072545568459, 0.020379473535285797, 0.02727835588302696, 0.0840350661019329, 0.009789158848434454, 0.06098570331232622, 0.03817323777184356, 0.08303392372909002, 0.00860513737279689, 0.023338151004281826, 0.06404191939509474, 0.011976343193964567, 0.0544756469753338, 0.04242063056153711, 0.07931320345960557, 0.045191950994194485, 0.07232548232423142, 0.08095999204670079, 0.019201520044589415, 0.04264338618668262, 0.06094542324717622, 0.0703651734511368, 0.020565674676618073, 0.03634982916992158, 0.10287969475029968, 0.04201241223199759, 0.03729483920324128, 0.023217837733682245, 0.03646198623755481, 0.09217817016178742, 0.04872128993156366, 0.03927071091311518, 0.015198625951597933, 0.07739544191281311, 0.08151549700414762, 0.01780313756171381, 0.058166217495454475, 0.06679749887553044, 0.03911869309376925, 0.029800535485264845, 0.011666964092000853, 0.03607298953284044, 0.06848718359833583, 0.04196857727947645, 0.031316976965172216, 0.06300089400610887, 0.01988688043638831, 0.021227967263257597, 0.04481940770347137, 0.04213701882690657, 0.03777385471039452, 0.0408658423111774, 0.048609118020976894, 0.053306868285289966, 0.04621879394107964, 0.031190396257443354, 0.053820879766135477, 0.031662164692534134, 0.019404777594900224, 0.021387321212387178, 0.018016662725131027, 0.07138069864595309, 0.09335152790299617, 0.0363860979268793, 0.024653364707774017, 0.03582401754101738, 0.02704716389416717, 0.03957822351367213, 0.023924941197037697, 0.013822103428537957, 0.052287279831944034, 0.03650401034974493, 0.09492205339483917, 0.02276953044201946, 0.031334521336248145, 0.10871374732232653, 0.07548810011940077, 0.021895256359130144, 0.09877484626485966, 0.012400212490319973, 0.057137337353196926, 0.016198371231439523, 0.030760091613046825, 0.06144848062831443, 0.07534617921919562, 0.024140087953128386, 0.041110565507551655, 0.058879239586531185, 0.007546927554358263, 0.0529423253465211, 0.022152796445880085, 0.043526371227926575, 0.0788464148354251, 0.09167949145194143, 0.021954976982669905, 0.03305948404886294, 0.020930019090883434, 0.03381842281669378, 0.04879953085037414, 0.04309655640099663, 0.036632439005188644, 0.029048161013633944, 0.03810467816947494, 0.02883267472498119, 0.017532747187942732, 0.016846212347445544, 0.008701503393240273, 0.045266050728969276, 0.06216717272764072, 0.06938763879588805, 0.009611993355065351, 0.03854421142023057, 0.031232605906552635, 0.009192968427669257, 0.023543980096292216, 0.08519590381183662, 0.05710271987481974, 0.05364873861253727, 0.07626052742125466, 0.012425069799064659, 0.01685977324086707, 0.05733937221521046, 0.007092664063748089, 0.04615664278389886, 0.022113145350886043, 0.04992245594621636, 0.04291782126529142, 0.03581590957765002, 0.03048485315957805, 0.062233316639321856, 0.034642269820324145, 0.03328567952848971, 0.0423819683783222, 0.018795129253703635, 0.021176026202738285, 0.06613962206756696, 0.05875668502994813, 0.01321425386777264, 0.046641120497952215, 0.041358695161761716, 0.03397477477847133, 0.07154509919928387, 0.02646532197104534, 0.0293348675040761, 0.01889817645860603, 0.0864620745414868, 0.033402393382857554, 0.024435193699900992, 0.027660413506964687, 0.07635535905137658, 0.008589885310357204, 0.048768839333206415, 0.06179741620144341, 0.07030466615105979, 0.04087328976311255, 0.032955149217741564, 0.046683040709467605, 0.02891946889576502, 0.012897042324766517, 0.08157912874594331, 0.041208005786756985, 0.0134878577409836, 0.060381461516954005, 0.033056010797736235, 0.022919327384443022, 0.021418558208097238, 0.04969952591636684, 0.03418822387175169, 0.05437776511826087, 0.06134643161203712, 0.04238461042405106, 0.028923901372763794, 0.03835753901512362, 0.045223358683870174, 0.08117417586618103, 0.03431393997743726, 0.054609686267212965, 0.037335731540224515, 0.012995306387892924, 0.052176228564349, 0.07180642423918471, 0.05073251013527624, 0.031688136150478385, 0.0154680227751669, 0.05264471299597062, 0.061189296684460714, 0.02871156179026002, 0.05127827811520547, 0.07681390241486952, 0.03920516071957536, 0.06279745648498647, 0.06303471367573366, 0.035537092117010616, 0.03565766513929702, 0.08139794081216678, 0.06405309613910504, 0.05192856646317523, 0.05303024016029667, 0.027345575908839237, 0.030693248227180447, 0.03571802029910032, 0.022538266093761194, 0.06006886891555041, 0.014535603277181508, 0.027102242383989505, 0.032585010485490784, 0.12811460823286325, 0.0843087924295105, 0.14759479730855674, 0.1452655074535869, 0.1483100198674947, 0.21718328353017569, 0.23235717555508018, 0.17128521983977407, 0.23190498497569934, 0.12458292039809749, 0.1032097204006277, 0.11919463882804848, 0.21418923715827987, 0.13666790473507717, 0.12690131552517414, 0.23239144793478772, 0.10727878252509981, 0.1410836834111251, 0.13612940238090232, 0.10434726209496148, 0.21261750196572393, 0.08973318690550514, 0.17429263971280307, 0.14108322327956557, 0.22283476777374744, 0.14280272007454187, 0.20492981682764366, 0.1668389982660301, 0.10502775956410915, 0.12499929493060336, 0.11604058541706763, 0.21200606133788824, 0.12061035231454298, 0.07939895120216534, 0.2069976183702238, 0.15935632400214672, 0.12491008877987042, 0.1503203494939953, 0.06660196522716433, 0.2204003304359503, 0.10602586655295454, 0.2683723554946482, 0.20267423707991838, 0.12207519597723149, 0.09000381847727112, 0.15861747146118432, 0.15989786916179582, 0.16918008826905861, 0.17904740176163614, 0.1747622262337245, 0.15169716702075675, 0.11403829324990511, 0.20241901249391958, 0.13042495847912505, 0.3165530873229727, 0.11760862471419387, 0.11481826077215374, 0.13149181060725823, 0.13827637623762712, 0.1306188222952187, 0.08362556385691278, 0.1415373879717663, 0.17584264482138678, 0.24979310401249677, 0.1267505853320472, 0.1779018374509178, 0.2521453856024891, 0.10312815837096423, 0.22893943707458675, 0.13397142989560962, 0.09832491181441583, 0.1772354036802426, 0.16985763941193, 0.13854377204552293, 0.18147403170587495, 0.13902397127822042, 0.15013225958682597, 0.11729648482287303, 0.15933015587506816, 0.21242820977931842, 0.13203868438722566, 0.2261542310588993, 0.10848602672922425, 0.23832514125388116, 0.09291340102208778, 0.22945997945498675, 0.15655621566111222, 0.12079429361619987, 0.16275194648187608, 0.1462857230217196, 0.16424894740339369, 0.1343216048553586, 0.08759962365729734, 0.09881154546746984, 0.0736794491240289, 0.13340604695258662, 0.1571930228965357, 0.16346788150258362, 0.14814370457315817, 0.1164881227305159, 0.13376774004427716, 0.18490023066988215, 0.20765649707755074, 0.18063300027279183, 0.21188464597798884, 0.1272479133331217, 0.2196341223316267, 0.16702563356375322, 0.13334220740944147, 0.11387649763491936, 0.09120672111748718, 0.127692207461223, 0.07424025301588699, 0.11480044180643745, 0.11115368397440761, 0.13519343541702256, 0.10748517379397526, 0.2030669667874463, 0.16515389259438962, 0.21543028618907556, 0.07993038088898174, 0.12311622136621736, 0.10504482153919525, 0.14395114907529205, 0.12902130489237607, 0.09194313941407017, 0.1684607838978991, 0.12406764726620167, 0.12900787201942876, 0.23685058287810534, 0.06351529140374623, 0.17609601403819397, 0.20025474659632891, 0.13481676578521729, 0.0958308058034163, 0.13698922499315813, 0.25928294635377824, 0.1403768322779797, 0.13659861782798544, 0.11078537834691815, 0.11402293079299852, 0.15055246360134333, 0.11050848304876126, 0.18942975089885294, 0.1779221574543044, 0.11631386645603925, 0.25018546264618635, 0.08987261418951675, 0.11494265214423649, 0.16033995168982074, 0.15357146097812802, 0.1427729005808942, 0.14663438400020823, 0.2566422364907339, 0.18391511868685484, 0.1144962948455941, 0.10800768286571838, 0.11889614703250118, 0.18819964112481102, 0.1740301717654802, 0.14636609761510044, 0.14956230501411483, 0.30338070821017027, 0.10979415106703527, 0.11906012456165627, 0.10677821133867837, 0.11786446528276429, 0.14308120356872678, 0.16534780093934387, 0.1583850011229515, 0.16857200214872137, 0.15842093591345474, 0.19018077466171235, 0.09310252993600443, 0.24454160768073052, 0.20118958549574018], [0.014097815001150593, 0.09573966264724731, 0.012700324950856157, 0.04795898181328084, 0.035884368990082294, 0.01988648895348888, 0.05664463293214794, 0.03229287518479396, 0.017939737263077404, 0.0319552425207803, 0.09148953133262694, 0.022564638311450835, 0.06021329827490263, 0.04499577909882646, 0.04402489779749885, 0.021647230605594814, 0.009841073006100487, 0.019296668942843098, 0.010893475518969353, 0.04177133669145405, 0.01835013936215546, 0.022904631005076226, 0.05318649564287625, 0.010427828874526313, 0.0756205957441125, 0.057115117451758124, 0.0454956860630773, 0.024587931402493268, 0.03466473091975786, 0.008987451965367654, 0.038646664906991646, 0.04679383222537581, 0.029696894562221132, 0.009412159888597671, 0.08508346101734787, 0.020805957974516787, 0.04511660445132293, 0.004659302840082091, 0.021329678602342028, 0.03509311340167187, 0.01935371597937774, 0.049079257441917434, 0.05286673389491625, 0.14292235428001732, 0.01598616894625593, 0.029759184872091282, 0.005731252131226938, 0.02866014950996032, 0.07745396767859347, 0.05255601521639619, 0.07176185827120207, 0.10084192050271668, 0.032682773598935455, 0.03778327627514955, 0.08628797411802225, 0.033134400146082044, 0.04647422261768952, 0.044347932416712865, 0.03540794728905894, 0.0053719139668828575, 0.024250792266684584, 0.06571457925019786, 0.07649881619727239, 0.016648737982905004, 0.05019761832954828, 0.08100599035969935, 0.04868937758146785, 0.01628670721402159, 0.020315938272688072, 0.08144390201778151, 0.04140188444580417, 0.03997435967903584, 0.038931022500037216, 0.08847505363519304, 0.036227608579793014, 0.028303970575507265, 0.018619333022797946, 0.02732131881202804, 0.027679106351570226, 0.0349079290026566, 0.04610384639818221, 0.01458974851630046, 0.033157421567011625, 0.059040897904196754, 0.03530520436470397, 0.015377762774733128, 0.036440530748222955, 0.02879067473259056, 0.01764765020197956, 0.0747716604382731, 0.03407269003218971, 0.026948697595798876, 0.06608333016629331, 0.06959123958949931, 0.0365788893395802, 0.08199428615625948, 0.05279583652736619, 0.010379442701378139, 0.022073774416639935, 0.007703131086600479, 0.07034975162241608, 0.047965995108825155, 0.010454131515871268, 0.08308156960993074, 0.024957127607194707, 0.04182416647381615, 0.04561620342428796, 0.05176454440515954, 0.021688464330509305, 0.041096553759416565, 0.06265717573114671, 0.041851681598927826, 0.031389213909278624, 0.037547035826719366, 0.016456028206448536, 0.051834425030392595, 0.00543326314073056, 0.05960532718745526, 0.0853834074223414, 0.07426138938171789, 0.02517424105462851, 0.06224789613042958, 0.06596376275410876, 0.016188571171369404, 0.037422592504299246, 0.10262041803798638, 0.014935165381757542, 0.04717875453934539, 0.016075211824500002, 0.0725105294259265, 0.034646674466785043, 0.007279001574715949, 0.030684546545671765, 0.04385359898151364, 0.033506297768326476, 0.04354054995928891, 0.1037366378295701, 0.06899829328176565, 0.02608698807307519, 0.05750670054112561, 0.01709898599074222, 0.08917378567275591, 0.03555072165909223, 0.032138434253283776, 0.08326199313160032, 0.02022302694967948, 0.04234541760524735, 0.013875885942979949, 0.03792513409280218, 0.02761858791927807, 0.014902850416547153, 0.02352370833250461, 0.030298607489385176, 0.09825224071391858, 0.046317091400851496, 0.04230465885484591, 0.02770118895568885, 0.054967397736618295, 0.042647189693525434, 0.019078579571214505, 0.048509555199416354, 0.032025167674873956, 0.020500105929386336, 0.040967969252960756, 0.04454318404896185, 0.05165714450413361, 0.03397826658328995, 0.042196090071229264, 0.03214859796571545, 0.012455688029149314, 0.013092846857034601, 0.05860733894223813, 0.06782233802368864, 0.08614040547399782, 0.01993717763980385, 0.06435374016291462, 0.01639469526708126, 0.07624232253874652, 0.049835602403618395, 0.02130015411239583, 0.030062777077546343, 0.05689841775165405, 0.06502599979285151, 0.0501941599213751, 0.006434753859139164, 0.007876657273300225, 0.0632015558949206, 0.05257935947156511, 0.010445132975291926, 0.003502373465380515, 0.021268347518343944, 0.08656802354380488, 0.030542267559212632, 0.038998520831228234, 0.01371201880829176, 0.039588216532138176, 0.0043995729538437445, 0.01768952588463435, 0.014529462932841852, 0.04661044753447641, 0.05313139488862362, 0.044403107385733165, 0.11510058116982691, 0.028684365788649302, 0.046394816527026705, 0.03399173656362109, 0.02239413544884883, 0.03532903843733948, 0.05151456680323463, 0.027147053260705434, 0.023278820008272305, 0.004223542018735316, 0.028494017897173762, 0.054695697472197935, 0.0292611017357558, 0.012988776416023029, 0.029907271164120175, 0.030834237732051406, 0.03522732338751666, 0.07687311095651239, 0.07804908105754294, 0.0451287830946967, 0.00990979866401176, 0.03607760569138918, 0.05171237513422966, 0.011770259916374926, 0.061684212705586106, 0.03684284158225637, 0.023091835901141167, 0.02640757360495627, 0.020507525550783612, 0.01735741851007333, 0.04807755845831707, 0.053416839728015475, 0.03212642259313725, 0.045845597560401075, 0.06905595073476434, 0.047788970623514615, 0.030059648925089277, 0.011194430317118531, 0.011413037336751586, 0.04636152007151395, 0.04371220500615891, 0.05345666337234434, 0.030678798611916136, 0.00928098621443496, 0.05030855456425343, 0.04307689319830388, 0.036584507397492416, 0.06323303779936396, 0.018182323074142914, 0.015208100394374924, 0.06820325274020433, 0.051966902101412416, 0.026759551983559504, 0.027933017336181365, 0.07487441078410484, 0.024012086032598745, 0.012893389102828223, 0.013717014389840188, 0.0451350468210876, 0.02157003982574679, 0.037989148040651344, 0.07033276386209764, 0.036028724134666845, 0.034567676557344384, 0.13232059660367668, 0.03769332426600158, 0.02736586808168795, 0.01919284990435699, 0.051632097020046785, 0.02121516521583544, 0.030378406918316614, 0.023582074536534492, 0.00926137960050255, 0.02733145469392184, 0.054027118894737214, 0.05345132733054925, 0.05144113500136882, 0.05158223211765289, 0.02057572335615987, 0.03416657171328552, 0.007916629347164417, 0.036956720432499424, 0.0759097735863179, 0.07476898128516041, 0.11934259338886477, 0.08958780017565005, 0.01791358954505995, 0.030764587172598112, 0.04992262664018199, 0.029235872425488196, 0.040355623204959556, 0.008159514800354373, 0.033326204502373, 0.011957110436924268, 0.02913168973464053, 0.03310679596324917, 0.06461902827140875, 0.05005894061469007, 0.01921610139106633, 0.09294076400692575, 0.032440198920085095, 0.011257408041274175, 0.017950776709767524, 0.046040834349696524, 0.04303463159885723, 0.019897316888091154, 0.05013611284084618, 0.04084719214006327, 0.008394533488171874, 0.008887950370990438, 0.0702760489366483, 0.10662912129191682, 0.05072615735116415, 0.034564670859253965, 0.007315800503420178, 0.0636059744283557, 0.01891535532195121, 0.021176798036321998, 0.010924627167696599, 0.04938744168612175, 0.052178596015437506, 0.061905773472972214, 0.014521481134579517, 0.06311203062068671, 0.049865199252963066, 0.036940174250048585, 0.04029471143439878, 0.02271664128784323, 0.0298864836076973, 0.06158326577860862, 0.04497878020629287, 0.007416860607918352, 0.003968792407249566, 0.02232723269116832, 0.006681835693598259, 0.03364814445376396, 0.03299193747807294, 0.05014999842387624, 0.04623944791092072, 0.10100963845616207, 0.015871265932219103, 0.10023270631791092, 0.018849617736123037, 0.03404252172913402, 0.06227541496627964, 0.011361833785485942, 0.026826584617083427, 0.035706346316146664, 0.05688064331479836, 0.004238880819684709, 0.10232003376586363, 0.1450133405160159, 0.08656871374114417, 0.1396463214769028, 0.16259717900538817, 0.06846603981102817, 0.12276662528165616, 0.11215982100111432, 0.09014300085254945, 0.10265409669955261, 0.2582039526896551, 0.1315857219742611, 0.12937498278915882, 0.2292224476695992, 0.12293156760279089, 0.12379072970361449, 0.13947314873803407, 0.11894037161255255, 0.08250428261817433, 0.11425206146668643, 0.07934542009024881, 0.11673001092276536, 0.0816103583201766, 0.15249470859998837, 0.12588812067406252, 0.1419113265001215, 0.19887706817826256, 0.10584345407551154, 0.18470611452357844, 0.16622491559246555, 0.11935347327380441, 0.13864005828509107, 0.11190477453055792, 0.08076591300778091, 0.2016700667445548, 0.12485833140090108, 0.13750797137618065, 0.09934037021594122, 0.08603015201515518, 0.07838191202608868, 0.16429503477411345, 0.08033479200094007, 0.13584934553364292, 0.22620391042437404, 0.18096552696079016, 0.12000380243989639, 0.08276974884211086, 0.19892443204298615, 0.2058445435250178, 0.1142557202547323, 0.17459602968301624, 0.15184440911980346, 0.09090860781725496, 0.067247537226649, 0.14038987923413515, 0.13462551432894543, 0.09922210898366757, 0.14045734045794234, 0.10971508265356533, 0.10806225298438221, 0.1456727387267165, 0.20341046241810545, 0.14974913327023387, 0.20122712332522497, 0.12270704566617496, 0.139701834123116, 0.22220330400159582, 0.09534685872495174, 0.0914810634276364, 0.18622524628881365, 0.10087839706102386, 0.1361336326226592, 0.08413371979258955, 0.19762136915232986, 0.14003056101500988, 0.14415075711440295, 0.24913535336963832, 0.14319963549496606, 0.15075297706061974, 0.08181171782780439, 0.17287099646637216, 0.08132690243655816, 0.21939501719316468, 0.15235444268910214, 0.1275640237145126, 0.133818814647384, 0.13797081919619814, 0.15744064789032564, 0.16642263857647777, 0.11921113677090034, 0.1685827039182186, 0.12016490785754286, 0.18675700994208455, 0.149518444086425, 0.11398322589229792, 0.1749520082375966, 0.09482702880632132, 0.11615814160904847, 0.11911866517039016, 0.12498360592871904, 0.1186235636123456, 0.13665392267284915, 0.24601937213446945, 0.1804913836531341, 0.1366813969798386, 0.1402941718697548, 0.1520614724722691, 0.08448567590676248, 0.1799599317018874, 0.16396878665545955, 0.23558842716738582, 0.15985610109055415, 0.17314317170530558, 0.11189710072358139, 0.12417020465363748, 0.13097209943225607, 0.1298906863667071, 0.09589949899236672, 0.12693995173322037, 0.1496532923192717, 0.10510380001505837, 0.15845888934563845, 0.1972143308375962, 0.13591278431704268, 0.1136557012796402, 0.17489746038336307, 0.10433225586893968, 0.2875038835918531, 0.10458650824148208, 0.18887517362600192, 0.09795038698939607, 0.1345512253465131, 0.14462176855886355, 0.0951551397156436, 0.10882168528041802, 0.14368093310622498, 0.16218331293202937, 0.15778259985381737, 0.12521137105068192, 0.18467988702468574, 0.06316769169643521, 0.20139544241828844, 0.08735645897104405, 0.102461153146578, 0.07587298532598652, 0.18009219726081938, 0.28668470098637044, 0.13812297431286424, 0.07736053870758042, 0.09724154690047726, 0.16218591044889763, 0.17993098794249818, 0.05966797187284101, 0.14133298565866426, 0.18276587332366034, 0.14454982476308942, 0.135850963415578, 0.1389685773756355, 0.13902759295888245, 0.1122921310889069, 0.18235133931739256, 0.12999644241062924, 0.13257904211059213, 0.20355725922854617, 0.151903469231911, 0.212451676488854, 0.10591400263365358, 0.19646586006274447, 0.16966558643616736, 0.16360673733288422, 0.09187768198898993, 0.19768485246459022, 0.28266472450923175, 0.13157987385056913, 0.10338065927498974, 0.15001899300841615], [0.05046902544563636, 0.025356562618981116, 0.03019162133568898, 0.03854707239952404, 0.04377212972030975, 0.015523354522883892, 0.0072486560839024605, 0.028767731237167027, 0.025786767073441297, 0.028734182451444212, 0.02550874742155429, 0.20592853979906067, 0.042131630834774114, 0.08775853231782094, 0.09375590190757066, 0.01233099330420373, 0.02454758268868318, 0.03215900287614204, 0.055126636652857997, 0.017688477601041086, 0.05212394054979086, 0.04760072486533318, 0.03972765123762656, 0.009595667961548315, 0.019088715453108307, 0.0649629469262436, 0.021245797361189034, 0.05326282924215775, 0.02502365558029851, 0.028714461732306518, 0.02128383428498637, 0.05214070937654469, 0.07393920823233202, 0.0279611836958793, 0.015871852228883654, 0.08706117325345986, 0.06973137191380374, 0.07746724470052868, 0.05678673194779549, 0.021464953570102807, 0.01667880052991677, 0.021977558681101073, 0.02148300816770643, 0.03199093982402701, 0.017609090064070188, 0.04975390307663474, 0.031023400042613503, 0.054088216202217154, 0.042260872141923755, 0.04268782227882184, 0.03465835216047708, 0.008341507964360062, 0.014485417395917466, 0.03982123234891333, 0.03827810323855374, 0.006079826371205854, 0.03983014925324824, 0.02246558571641799, 0.02678712276974693, 0.0480696063459618, 0.03524827792716678, 0.014868516809656285, 0.04028073308290914, 0.04224535012326669, 0.037808795023011044, 0.014337036100187106, 0.02288409577886341, 0.025358386446896475, 0.0250042261541239, 0.009073701585293747, 0.06253336323425174, 0.03972109807364177, 0.06508934951853007, 0.023204074605018832, 0.0041469653660897166, 0.02760387484158855, 0.027177640877198428, 0.03433655321714468, 0.037609899445669726, 0.031908205201034434, 0.011958655031776289, 0.04827678800211288, 0.043832807714352384, 0.06942456806427799, 0.0764342345064506, 0.014124008175713243, 0.056025058365776204, 0.028272713170736097, 0.05210228839132469, 0.07470898606698029, 0.01663087634369731, 0.06763005498214625, 0.033855125730042346, 0.04286811592464801, 0.002072680931632931, 0.0929485194501467, 0.02729441039264202, 0.031697524318587966, 0.046654453180963174, 0.02018447052250849, 0.03002516874403227, 0.08122841943986714, 0.028226122994965408, 0.010301429992978228, 0.06037234794348478, 0.04131346497160848, 0.03449964387982618, 0.036670908230007626, 0.015006293742771959, 0.04231526414514519, 0.0716383574763313, 0.07144871648051776, 0.01651837974350201, 0.018050133585347794, 0.09420016634976491, 0.05815533389977645, 0.05634348053717986, 0.015969027190294582, 0.03824028710369021, 0.037740276238764636, 0.06369440132402815, 0.006865079376439098, 0.01956327621883247, 0.04926289075228851, 0.04824986288440414, 0.024108112520480063, 0.044440392885007896, 0.046079370367806405, 0.05817673372803256, 0.018242804399051238, 0.07244706095661968, 0.012292643750697607, 0.03887832259351853, 0.03185022862453479, 0.007128388269848074, 0.006573633809239254, 0.019461678057268728, 0.02956320964585757, 0.02383099272265099, 0.021893157936574426, 0.023067300498951226, 0.026804685694514774, 0.02796576274704421, 0.020657185195886996, 0.036142862736596726, 0.013841201671311865, 0.03830669076705817, 0.07521579129388556, 0.03563597587344702, 0.01403102820404456, 0.048476481388206594, 0.019358109493623488, 0.007617145392941893, 0.055333736672764644, 0.05119225948874373, 0.01321217121585505, 0.020764915352629032, 0.04298335661587771, 0.020773435207956936, 0.011474453767732484, 0.04178235016297549, 0.04285941053240094, 0.043865239567821845, 0.024994342602440156, 0.0591315178462537, 0.02715900554903783, 0.056444256770191714, 0.09107536840019748, 0.03046607682335889, 0.008492451524944045, 0.10871417776797898, 0.01842612229665974, 0.05000772500352468, 0.043585598323261365, 0.05282777485263068, 0.012965149217052385, 0.049700531526468694, 0.027845655422424898, 0.03436325197981205, 0.048529626583331265, 0.058124835341004655, 0.028575038159033284, 0.07479568375856616, 0.1018733276578132, 0.022154241778480355, 0.06691039438010193, 0.05712042380764615, 0.029938931184005924, 0.03464976551185828, 0.08711103815585375, 0.08802776123047806, 0.029127322195563465, 0.041450914432061836, 0.054627301142318174, 0.029039620749244932, 0.03727472329046577, 0.030292076589830685, 0.026731561883934774, 0.016479207333759405, 0.009688848313089693, 0.021501387454918586, 0.07583373313536867, 0.03212908690329641, 0.032078505828394555, 0.015415046418638667, 0.02892131498811068, 0.016145010813488625, 0.06321470675175078, 0.0801959064847324, 0.06236894041649066, 0.03776626996113919, 0.021606609152513556, 0.04001972345577087, 0.06593429949134588, 0.03674389474326745, 0.05711034915293567, 0.03629296952567529, 0.013912378271925263, 0.04648260888643563, 0.011722955423465464, 0.017796322790673003, 0.03891897744324524, 0.004153215177211678, 0.030209247343009338, 0.0523604778572917, 0.06836504093371332, 0.0025524984221192426, 0.028404817312548403, 0.049827030597953126, 0.04130582827201579, 0.08272209553979337, 0.010514728801354067, 0.06022743618814275, 0.029799184776493348, 0.018242960250063334, 0.03936926441383548, 0.05323285760823637, 0.04761007221532054, 0.06695348347420804, 0.07309152715606615, 0.036748403290403076, 0.04493735352298245, 0.008124938140099403, 0.03921321673260536, 0.0775087159126997, 0.032295524651999585, 0.05898654300835915, 0.06084688830014784, 0.02324599481653422, 0.05257538527075667, 0.00462657227217278, 0.07231768235214986, 0.10475953255081549, 0.06437498042942025, 0.06828918601968326, 0.06405367501429282, 0.017310375624219887, 0.012200146175018745, 0.028859800222562626, 0.09897678464767523, 0.031976623795344494, 0.017075409814424347, 0.08616784267360345, 0.015010220631666016, 0.06031655699189287, 0.05682943512510974, 0.03493420845188666, 0.02601157102617435, 0.024160973844118416, 0.01621963190700626, 0.03854552131087985, 0.02971836118376814, 0.023663209831283893, 0.056333116444875486, 0.048856282883207314, 0.06785446559661068, 0.0273441676836228, 0.03278657779446803, 0.028927641797054093, 0.009237296908395365, 0.05053485765529331, 0.07188674688222818, 0.021487581652763765, 0.04887415008852258, 0.034718711031018756, 0.05217349375016056, 0.0642022084502969, 0.0787916146509815, 0.06381502258591354, 0.025307400901510846, 0.025094489865296055, 0.02734013040026184, 0.08682885134476237, 0.02190740346122766, 0.03405292292882223, 0.010921057437371928, 0.06406445099855773, 0.03075002066907473, 0.05930560342676472, 0.0740042352117598, 0.047946372724254616, 0.033970514850807376, 0.035980124594061635, 0.049824299494503066, 0.029691575218748767, 0.021304373221937567, 0.020891642634524032, 0.008738071792322444, 0.04801478760782629, 0.05606742386589758, 0.027407751185819507, 0.07133454448194243, 0.02532872837036848, 0.008164820228557801, 0.018520870435168035, 0.09599903583875857, 0.05113887309562415, 0.015196909735095687, 0.027542397183424328, 0.04841075307922438, 0.04617566031811293, 0.09043213416589424, 0.023102801133063622, 0.0080239949238603, 0.013838884315191535, 0.008252638563135406, 0.030090605760051403, 0.048277734240400605, 0.05630055471556261, 0.056527696433477104, 0.03498133482935373, 0.014896000393491704, 0.0006186614348280273, 0.034268360977876, 0.015338928969867993, 0.021800524918944575, 0.04529996316705365, 0.02733900233579334, 0.04774440836627036, 0.058452916564419866, 0.02509795012883842, 0.04287755975383334, 0.04440263241122011, 0.027384785425965674, 0.032301573155564256, 0.02971219022583682, 0.03779839753406122, 0.08844446972943842, 0.06783778953831643, 0.04112131551664788, 0.043442953829071485, 0.06994600102188997, 0.2618303830968216, 0.09693538129795343, 0.1701337777194567, 0.10979107115417719, 0.11893574061105028, 0.15477066772291437, 0.09228764436556958, 0.2163065251079388, 0.11423145944718271, 0.18091984034981579, 0.08223802229622379, 0.2742377563845366, 0.18405784852802753, 0.2821288938866928, 0.1771811823709868, 0.11325070387101732, 0.1453353138640523, 0.12088190414942801, 0.1618984914966859, 0.11766741023166105, 0.25206291815266013, 0.1665099003002979, 0.11866127213579603, 0.054405807168222964, 0.1111515391676221, 0.2386548329377547, 0.1499415870057419, 0.2054983761627227, 0.09395849338034168, 0.12912809994304553, 0.10906462732236832, 0.13541507039917633, 0.22527545399498194, 0.14628640579758212, 0.09718929970404133, 0.21748005354311317, 0.15013323922175914, 0.11815393256256357, 0.10510395586607046, 0.09661897405749187, 0.12121864623622969, 0.08176818344509229, 0.14694418612634763, 0.10400511717307381, 0.1080552174244076, 0.18836316594388336, 0.15748915466247126, 0.12483726924983785, 0.09576273601851426, 0.20151396340224892, 0.1461566932266578, 0.06292502424912527, 0.1786337880184874, 0.09625629390939139, 0.1570903541869484, 0.05194987723371014, 0.17644912790274248, 0.057685131396283396, 0.16689295240212232, 0.10940377396764234, 0.1831198629224673, 0.13292903895489872, 0.12879943242296576, 0.1417763001518324, 0.12796485767466947, 0.11589595567784272, 0.08753004731261171, 0.07774618090479635, 0.12038550383294933, 0.09497125036432408, 0.15815408929483965, 0.20302497607190162, 0.10788047875394113, 0.10428961206343956, 0.09484561218414456, 0.09599903583875857, 0.17925417894730344, 0.1442649439559318, 0.16103040135931224, 0.16447047848487273, 0.12811285676434636, 0.1065874051710125, 0.13930162356700748, 0.1561622688313946, 0.2585218887543306, 0.08370174531592056, 0.20129764219745994, 0.14568217884516343, 0.10773469868581742, 0.15243938891217113, 0.1488743192749098, 0.19245728297391906, 0.14815072529017925, 0.17896002129418775, 0.16448472772026435, 0.11232151271542534, 0.19911431794753298, 0.16551478416658938, 0.20466188667342067, 0.17073004884878173, 0.08448484470136464, 0.1682802935829386, 0.13298367586685345, 0.1429094112245366, 0.21106859523570165, 0.10359070191043429, 0.12469209032133222, 0.1828928547911346, 0.2332351659424603, 0.1327972928993404, 0.24586361018009484, 0.2266327233519405, 0.0922944127523806, 0.13133808213751763, 0.09843221152550541, 0.22539406403666362, 0.11220489162951708, 0.10737332471762784, 0.09004960898892023, 0.12462133396184072, 0.16673788806656376, 0.18665909097762778, 0.10511041255085729, 0.10855003696633503, 0.15302722924388945, 0.06828416167991236, 0.17590765695786104, 0.10664275454473682, 0.15309455688111484, 0.10334770049666986, 0.13013761374168098, 0.14178949553752318, 0.15129195438930765, 0.13245943759102374, 0.15449564263690263, 0.2166192067670636, 0.16379490145482123, 0.07765790243865922, 0.11930278458748944, 0.11297929304419085, 0.28204633737914264, 0.20309366926085204, 0.08822898715152405, 0.10543070864514448, 0.15186199801973999, 0.18241698970086873, 0.15510114608332515, 0.17548770527355373, 0.08708380133612081, 0.07809412942151539, 0.15510999248363078, 0.11716966662788764, 0.16596219531493261, 0.13134431617800146, 0.13659892953000963, 0.10907074261922389, 0.07287948072189465, 0.11955999812926166, 0.10894382794504054, 0.11066178849432617, 0.09502720087766647, 0.22227679146453738, 0.15244277310557663, 0.16960483422735706, 0.1880669896490872, 0.07187807859736495, 0.22150863893330097, 0.13261712912935764, 0.1655030285473913, 0.1464915502583608, 0.27995885408017784, 0.13441928633255884, 0.16714333818526939, 0.10188414074946195, 0.10220546842901967, 0.1410510140703991], [0.019404528975428548, 0.03145040027447976, 0.0068905925581930205, 0.02107661923218984, 0.06730365101248026, 0.018747116009762976, 0.026745196992123965, 0.035510890593286604, 0.053915815296932124, 0.02745148780377349, 0.0627170225197915, 0.01739022885885788, 0.02994567545101745, 0.04488749233132694, 0.016919408517424017, 0.030740012807655148, 0.042165521008428186, 0.044028779229847714, 0.026756136248877738, 0.06775078756618313, 0.033221814010175876, 0.08017086642212234, 0.0730985330301337, 0.026291754038538784, 0.04342229243775364, 0.05395961685280781, 0.013243447174318135, 0.012587706823978806, 0.030732776867807843, 0.04878833184193354, 0.06915197722264566, 0.01647720353503246, 0.007200204508990282, 0.0512330776109593, 0.029426422552205622, 0.10214356589131057, 0.07426615396980196, 0.024559800294809975, 0.09423512150533497, 0.009516480804450111, 0.032559591927565634, 0.06302628287812695, 0.05263421902782284, 0.04175941779976711, 0.023933214288263116, 0.05092472638352774, 0.12822978955227882, 0.03223448671633378, 0.011590792837523622, 0.04350516806880478, 0.030103413373581134, 0.02273850124765886, 0.004895489946648013, 0.02230176774901338, 0.042847536169574596, 0.01087939141143579, 0.04396871350763831, 0.02041577383351978, 0.054013567278161645, 0.015915160256554373, 0.06110578280640766, 0.005928717682763818, 0.01774668795405887, 0.11809663134044968, 0.034686461003730074, 0.00980831924607628, 0.028417263129085768, 0.052802107675233856, 0.036674808216048405, 0.022188723814906552, 0.016145059053087607, 0.01707204974081833, 0.017761885283107404, 0.07100440750946291, 0.0038769279763073428, 0.007192304346972378, 0.03168385766912252, 0.07233600597828627, 0.02150120933947619, 0.02893451222917065, 0.04319161809689831, 0.06346061738440767, 0.005029149815527489, 0.02920100076153176, 0.04167823426541872, 0.009578491881256923, 0.040965037769638, 0.036646888620452955, 0.02366064756643027, 0.08630709926364943, 0.047956332346075214, 0.04018880325020291, 0.09651876185671426, 0.026786260023072828, 0.0021349424832806108, 0.03535560732416343, 0.06636263002292253, 0.05282655773044098, 0.023609723248227965, 0.016276831083814614, 0.018868987790483516, 0.0817204856139142, 0.02841631318005966, 0.010566605851636268, 0.051844147164956667, 0.12492133973864838, 0.10379903018474579, 0.01714079116936773, 0.07086429002811201, 0.030914805283828173, 0.019634674536064267, 0.03590908621845301, 0.07275050287717022, 0.034030955357593484, 0.05364588876545895, 0.019530872195900884, 0.019569454598240554, 0.04118499920878094, 0.03349447164509911, 0.04834671315620653, 0.028111652281950228, 0.04548130324110389, 0.024305993210873567, 0.024018665171752218, 0.014697866445203545, 0.06815757355070673, 0.03868840329232626, 0.03739544474228751, 0.029345270559133496, 0.006427903836083715, 0.0492496582592139, 0.024823754392855335, 0.040449916778015904, 0.036721916039823554, 0.025582143971405458, 0.043430949590401724, 0.02415640035906108, 0.05208066591876559, 0.03129042663204018, 0.028391701707732864, 0.03509515801852103, 0.09519179438939318, 0.03182273205311503, 0.03328660721308552, 0.001979975786525756, 0.069719096791232, 0.01700105218333192, 0.05473890902067069, 0.03943925636122003, 0.07053949651890434, 0.09044787511811592, 0.038067470595706254, 0.027428599969425704, 0.031753445146023296, 0.04114009927434381, 0.014462729941442376, 0.08027651856536977, 0.056648458703421056, 0.04751175620185677, 0.027997200122626964, 0.030685945494042244, 0.04220012364385184, 0.011212307726964355, 0.06169360458443407, 0.02312020820681937, 0.035631938590086065, 0.012372700148262084, 0.04642463602067437, 0.05113366321893409, 0.06162268495245371, 0.018332439140067436, 0.02571304954471998, 0.014158000394672854, 0.0825559880468063, 0.023942461448314134, 0.03418201580643654, 0.07962159550515935, 0.04757954768138006, 0.02374179213802563, 0.015850207491894253, 0.04606898772181012, 0.04362346269772388, 0.038932065217522904, 0.10861167233088054, 0.046018009597901255, 0.011549853188626003, 0.018273854002472945, 0.007068299355523777, 0.051611613744171336, 0.044794074492529035, 0.040316088998224586, 0.07146695104893297, 0.04260764064383693, 0.07847269895137288, 0.07649244857020676, 0.025572030353941955, 0.029023612623859663, 0.050762073587975465, 0.01262936264538439, 0.07737261345027946, 0.011054301703552483, 0.05949348182184622, 0.03820130950771272, 0.0497890586120775, 0.0200667269382393, 0.12927166098961607, 0.05093957304779906, 0.031319626432377845, 0.0659958457981702, 0.017393227135471534, 0.014583042284357361, 0.039175786514533684, 0.044017602485837415, 0.04213531188725028, 0.06921177206095308, 0.02883712761104107, 0.0022504127764477744, 0.05510085073183291, 0.07025839324342087, 0.02607173508295091, 0.035155579971615225, 0.04931790244881995, 0.05111961436341517, 0.04222838091664016, 0.02136381925083697, 0.011700557406584267, 0.013369939752010396, 0.03952415063395165, 0.02662167949893046, 0.06102061764977407, 0.02538023156375857, 0.016025556578824762, 0.03976869200414512, 0.03917538946552668, 0.026564638028503396, 0.03780668732360937, 0.014832548622507602, 0.008047873525356408, 0.042243784191668965, 0.0036790057720281766, 0.05983950075460598, 0.03992194549937267, 0.012405084689817159, 0.0821954601269681, 0.004944426700603799, 0.011879952126037097, 0.05386107077356428, 0.025687590168672614, 0.03477386373560876, 0.035507024003891274, 0.027788903389591724, 0.01021011335978983, 0.009877309294097358, 0.029821595780958887, 0.06374756878358312, 0.08264342788606882, 0.08340245200088248, 0.046170613713911735, 0.040262164548039436, 0.009899089473037748, 0.024166133625840303, 0.029161694765207358, 0.06752395012881607, 0.02621072078909492, 0.06570475321495906, 0.024436332896584645, 0.023978496428753715, 0.009377996975672431, 0.03480626219243277, 0.022364913384080864, 0.09354061970952898, 0.004096473348909058, 0.05469649528095033, 0.05879045645997394, 0.07942462209030055, 0.03434477992414031, 0.01674254730460234, 0.060951438354095444, 0.04897492632153444, 0.011885623989655869, 0.03510475027724169, 0.08199049378163181, 0.0955815332417842, 0.02386459345871117, 0.06373386873747222, 0.022668570527457632, 0.028405420307535678, 0.03594736990635283, 0.03836474897980224, 0.031883361807558686, 0.010900565812335117, 0.009512056676612701, 0.03383493189176079, 0.08331832956173457, 0.030729965983482543, 0.04535820691671688, 0.05194802928599529, 0.05740233973483555, 0.012176674827060197, 0.03791276249103248, 0.12414060038281605, 0.06384723921655677, 0.017162424774141982, 0.07550070178695023, 0.003918465981769259, 0.043840693033416755, 0.0930749814142473, 0.03546940453816205, 0.02092460883432068, 0.036969633802073076, 0.04647993344406132, 0.04648848298529629, 0.028395464396453463, 0.04433622132637538, 0.08666646943311207, 0.07452289995853789, 0.04928788999677636, 0.06931602154509164, 0.04849165830819402, 0.03518450517731253, 0.07164967522840016, 0.03530526002577972, 0.029704750195378438, 0.01495837141192169, 0.034403676763758995, 0.035899679496651515, 0.018580127216409892, 0.057986209576483816, 0.03180616731697228, 0.029035653969913255, 0.029238727838674095, 0.011755143295886228, 0.03920607727195602, 0.07009555120021105, 0.1056046606390737, 0.014791369630984263, 0.013619976725749439, 0.06011879690049682, 0.041487717535346746, 0.0243012935607112, 0.006501903844764456, 0.006092974908824544, 0.025125175816356204, 0.026525883076828904, 0.008794733839749824, 0.007967959991219686, 0.017634621799516026, 0.025621127133490518, 0.0545816590602044, 0.022237084012886044, 0.01719731870252872, 0.025857180189632345, 0.14202198071870953, 0.14548004750395194, 0.19206004100851715, 0.0960651389323175, 0.10833851745701395, 0.14535561902448535, 0.08252935978816822, 0.17731527361320332, 0.22682654263917357, 0.13753433246165514, 0.10367871320340782, 0.06724538499838673, 0.13098496827296913, 0.10714540374465287, 0.07097356385202147, 0.2070183539763093, 0.12829254555981606, 0.15781120222527534, 0.13597315060906112, 0.10466628169524483, 0.1267270147218369, 0.13757792621618137, 0.10102786560310051, 0.2010040931054391, 0.12914154765894637, 0.12881948525318876, 0.1901399268535897, 0.13699992676265538, 0.07530473769293167, 0.14562978321919218, 0.13513318786863238, 0.1193590987531934, 0.16428952803835273, 0.1520761224674061, 0.15809013100806624, 0.18419340922264382, 0.19965347339166328, 0.10390046692918986, 0.1547982607735321, 0.1100075853173621, 0.14670902921352535, 0.0939007691340521, 0.1694822611170821, 0.11980705166934058, 0.10865508796996437, 0.15223587717628106, 0.15730876824818552, 0.14851857820758596, 0.19536816427716985, 0.14554462919477373, 0.0810288856155239, 0.21505431417608634, 0.120013316773111, 0.27386689034756273, 0.12761101650539786, 0.1291366049554199, 0.1840041615650989, 0.10352292898460291, 0.14872416795697063, 0.16282599797705188, 0.14392382319783792, 0.08962851439719088, 0.13712911983020604, 0.24126351170707494, 0.15724169294117019, 0.114976798358839, 0.18807968037435785, 0.17661620018770918, 0.11860972255817614, 0.054438008955912665, 0.10140879516256973, 0.1121493344544433, 0.08525221797754057, 0.12451761140255257, 0.20239884092006832, 0.06786697820643894, 0.08665235378430225, 0.14731367176864296, 0.17826592025812715, 0.11652002765913494, 0.16704525594832376, 0.18436079320963472, 0.15433382475748658, 0.24938409158494323, 0.1550869710627012, 0.09028347456478514, 0.1242276097764261, 0.12260511168278754, 0.10188185493461788, 0.1507503498578444, 0.08705894681042992, 0.09411420338437892, 0.32557496102526784, 0.21934961259830743, 0.134076384420041, 0.12164449799456634, 0.14986041089287028, 0.11829352311906405, 0.08904545349651016, 0.10604048686218448, 0.09491470613284037, 0.18338534398935735, 0.10874047206016257, 0.0885964764165692, 0.15681262768339366, 0.16721700376365334, 0.25009735487401485, 0.1278234933852218, 0.1405301599879749, 0.1069186108361464, 0.10171646732487716, 0.1461114815901965, 0.15526956907706335, 0.17497992783319205, 0.1120601876755245, 0.1141685624315869, 0.11469488614238799, 0.19103232974885032, 0.13452916871756315, 0.09896021249005571, 0.08879676723154262, 0.09919741773046553, 0.09684193006251007, 0.11726394164725207, 0.20438276493223384, 0.3861748514464125, 0.17016267694998533, 0.17894586111651734, 0.13153874402632937, 0.09706989556434564, 0.16059197019785643, 0.23378395446343347, 0.23485804995289072, 0.1061289657081943, 0.1448246865766123, 0.17351295420667157, 0.09734884661156684, 0.17174961132695898, 0.16527907806448638, 0.13505739974789321, 0.13357196148717776, 0.20306362712290138, 0.1680142484838143, 0.09849503432633355, 0.14063121081562713, 0.185123706178274, 0.08623456174973398, 0.16495309711899608, 0.11706875680829398, 0.18919791880762205, 0.2105813307571225, 0.13334287534235045, 0.11767575939302333, 0.12746432359563187, 0.12235129717737436, 0.17589152266737074, 0.07853572955355048, 0.10693912379792891, 0.1872276354697533, 0.1340624617296271, 0.09164420232991688, 0.09805118548683822, 0.1394715011701919, 0.13744197960477322, 0.1008919560990762, 0.08089995972113684, 0.0887752597918734, 0.1274405006552115, 0.11030086723621935, 0.1828972334624268, 0.14362773596076295, 0.14458335499512032, 0.16298639093292877, 0.16379965119995177, 0.09073563545825891, 0.1803802841459401], [0.030138735892251134, 0.017315654149570037, 0.05807294437545352, 0.029570573606179096, 0.01662733258854132, 0.0636542659776751, 0.20113238075282425, 0.021003911024308763, 0.09639845229685307, 0.020943129129591398, 0.012635961265914375, 0.044543707263073884, 0.011240829389862483, 0.06525202828925103, 0.05492964468430728, 0.030138941838231403, 0.01684826253040228, 0.010465762825333513, 0.01089921046514064, 0.023479886367567815, 0.05555828829528764, 0.02130703753209673, 0.040523719653720036, 0.012678631974267773, 0.13305115193361416, 0.014912110564182512, 0.047625508886994794, 0.02489221194991842, 0.0323823225335218, 0.05929827100771945, 0.06975277545279823, 0.03363627751241438, 0.03852378380543087, 0.06107495028118137, 0.03669075325888116, 0.04166682745562866, 0.0860529878991656, 0.03990563680417836, 0.029558602764154784, 0.023053932563925628, 0.037252384645398706, 0.0925248718704097, 0.031295540029532276, 0.031770358691574074, 0.026003418533946387, 0.061528198421001434, 0.027804317796835676, 0.050530412190710194, 0.03828388456895482, 0.034161606745328754, 0.03472072225122247, 0.08172497560735792, 0.02325694149476476, 0.04790707600477617, 0.02740930598520208, 0.06807052704971284, 0.048759269338916056, 0.08482881530653685, 0.04483099633944221, 0.020943709860148374, 0.039487020985689014, 0.07522435567807406, 0.054913024287088774, 0.03699159395182505, 0.04327916925831232, 0.04590971540892497, 0.03256501702708192, 0.01729292587697273, 0.09078866933123209, 0.023819266789359972, 0.04321454674936831, 0.0403756426385371, 0.046181044599507004, 0.04630089402780868, 0.0381203783035744, 0.05740218017308507, 0.06979936748393811, 0.05004351136449259, 0.04933399221044965, 0.036846255461568944, 0.05006946426874492, 0.07719983404967934, 0.03747536291484721, 0.026057532231789082, 0.06047290895367041, 0.04653691554267425, 0.029364230576902628, 0.04896708924206905, 0.04404911036544945, 0.08669606628245674, 0.01151616246716003, 0.04791090919752605, 0.006917838654771913, 0.008684615822858177, 0.012785209946741816, 0.020212237977830227, 0.05054799737990834, 0.11949438485316932, 0.01226061172928894, 0.034543749716249295, 0.03739413856237661, 0.053563154142466374, 0.028889419336337596, 0.0354863032407593, 0.020199324608256575, 0.01939545250934316, 0.08193981251679361, 0.04593531950376928, 0.035893274762202054, 0.02681088819372235, 0.10154579562367871, 0.008842680290399585, 0.013516418366634753, 0.028138696143287234, 0.04992258582205977, 0.04569765784253832, 0.018712147866608575, 0.033325072727166116, 0.024197259299398866, 0.04349548304162454, 0.04857404412177857, 0.021918804704910144, 0.016778240897110663, 0.07560489189927466, 0.048659680542186834, 0.051276760423206724, 0.05442371890239883, 0.03904630029865075, 0.017860785737866536, 0.025744685444806237, 0.03392065736989025, 0.020982360911148135, 0.024931742445915006, 0.022183851615409367, 0.03967075448599644, 0.04980130775948055, 0.07190415024524555, 0.04032621560327243, 0.06634590201429091, 0.07217326041427441, 0.03349837163113989, 0.022486300913442392, 0.0158530963017256, 0.030493564117932692, 0.017298568054684438, 0.047497098785243, 0.020864622892986517, 0.05275145609630272, 0.04481727402890101, 0.03571674751583487, 0.08585076007875614, 0.01360519685476902, 0.005324917001416907, 0.04965525680745486, 0.05195487930905074, 0.03679872832435649, 0.06069569426472299, 0.095339986437466, 0.12400492836604826, 0.05127725024067331, 0.03627332487667445, 0.048744018204160966, 0.1189128527767025, 0.015476024054805748, 0.03489913826342672, 0.02374198695179075, 0.05351989806513302, 0.043525729270186275, 0.01315520396019565, 0.03308806044515222, 0.034865737907239236, 0.029070757555018645, 0.03403718197660055, 0.0764525358681567, 0.013260911764518823, 0.022167897295730654, 0.04564820112136658, 0.006331978929665638, 0.04783165153639857, 0.025677105477370787, 0.031195461415336467, 0.08588937402237207, 0.10230948042590171, 0.020125697992625646, 0.06980526013649069, 0.010145438900508452, 0.02112483842211077, 0.015764773306727875, 0.03354182066686917, 0.07540474209235981, 0.007324190482904669, 0.09927421517204493, 0.04686376480094623, 0.06390713053406216, 0.05719341403164435, 0.022483426946564578, 0.03250875852245372, 0.025601773777452763, 0.08007270254893228, 0.07426443960866891, 0.0691241689492017, 0.02676007519767154, 0.024007635001908056, 0.007505354760724003, 0.07322321383981034, 0.014542667595378589, 0.05847631276992615, 0.03408378885069396, 0.040990367269841954, 0.0280098296207143, 0.03910260333213955, 0.014082222478464246, 0.04027868475532159, 0.08939248917158693, 0.0258244793076301, 0.026388979094917886, 0.08461719931801781, 0.0436852947314037, 0.04185397112451028, 0.008422737882938236, 0.06827420947956853, 0.062465011433232576, 0.08692419505678117, 0.025789544561121147, 0.0681734035606496, 0.030361064782482572, 0.027138917466800194, 0.054800151046947576, 0.0015349163186328951, 0.03229405148886144, 0.03302836950751953, 0.018907525663962588, 0.04411187008372508, 0.0098470677039586, 0.05651013350870926, 0.04102353013877291, 0.021772709224023856, 0.04883790730673354, 0.0738720216031652, 0.02222866620286368, 0.018338053487241268, 0.03413486345380079, 0.026769045907713007, 0.016086056457425002, 0.056752979071461596, 0.04420182951434981, 0.04796604334842414, 0.07498181439586915, 0.02721982640650822, 0.08163612568750978, 0.020570483793562744, 0.02200834667746676, 0.04553829647193197, 0.09057183604454622, 0.02418827745714225, 0.12630519282538444, 0.028264896500331815, 0.04473352637432981, 0.02662205613887636, 0.039736093167448416, 0.04810362639545929, 0.035010582869290374, 0.003320469591017172, 0.03458040067926049, 0.09113802792853676, 0.0271870531651075, 0.02576364731794456, 0.02045874047325924, 0.0024109107926051365, 0.039224549327627756, 0.051670748071046546, 0.033755766999092884, 0.03797979326918721, 0.04459038835193496, 0.020474815391935408, 0.01851861430623103, 0.06942372943740338, 0.004414113482198445, 0.0289186543886899, 0.02509515037672827, 0.061328968877205625, 0.08858497312758118, 0.04682875398430042, 0.05045424557465594, 0.05000621844374109, 0.014697960141347721, 0.060392397062969394, 0.022408061850001104, 0.0284910214759293, 0.031146917535807006, 0.028473837046476547, 0.06475585061707534, 0.05683339077222627, 0.030130062041280326, 0.06231392500922084, 0.031267802260117605, 0.0347213790519163, 0.00886175905179698, 0.020089996978640556, 0.039935608438099734, 0.011334747250657529, 0.03753719123778865, 0.0516223785962211, 0.012112767562939553, 0.06785665493225679, 0.02499519792763749, 0.017190832331834827, 0.011478812029963592, 0.03684864888782613, 0.025040199907380156, 0.03299919197161216, 0.021265195246087387, 0.001980973511308548, 0.050745753760566004, 0.05006341205444187, 0.011952275344810914, 0.0329512232565321, 0.036248117830837145, 0.07610312532051466, 0.016661467670928687, 0.005058384867879795, 0.0075431852746987715, 0.028976402754778974, 0.07089747887221165, 0.04420301323989406, 0.04330739684519358, 0.03734263722435571, 0.024679081980139017, 0.023452708919649012, 0.02554336861066986, 0.026886017658398487, 0.040830683064996265, 0.06451005130656995, 0.010443725677760085, 0.09458882166654803, 0.027942392516706605, 0.04172778004431166, 0.01271330882445909, 0.07339877629419789, 0.025498118011455517, 0.036846864022663794, 0.053309439826989546, 0.056745197653071955, 0.026079882009071298, 0.016834657108120155, 0.024962645475170575, 0.03902912329067476, 0.05452915211208165, 0.023165186066762544, 0.0886000609898474, 0.024429620170849375, 0.04027394243166782, 0.08026536408578977, 0.11731137230526656, 0.17076893738703802, 0.10872783328522928, 0.0762023801507894, 0.17457422538427636, 0.3015448129735887, 0.08499104878865182, 0.19215733656892553, 0.12399312079651281, 0.1414232753450051, 0.11751549260225147, 0.1257669724873267, 0.24610494176158682, 0.14116177218966186, 0.24644209945108742, 0.08751804678468034, 0.13012688228627667, 0.13834395620506257, 0.10582774280919693, 0.13790338765829802, 0.1687983571900986, 0.20227266097208485, 0.14490800007479265, 0.26050187938380986, 0.11339785691234283, 0.14571495208656415, 0.09918293842929415, 0.17271744611207396, 0.1332956153783016, 0.09529691960779019, 0.1409442932344973, 0.152999309648294, 0.13643307436723262, 0.09864249906968325, 0.10200541510130279, 0.18248388689244166, 0.14478468481684104, 0.1514979894272983, 0.08391564711928368, 0.17537651670863852, 0.18342559807933867, 0.09967040328774601, 0.08923213332309388, 0.17836535320384428, 0.16543399397050962, 0.15178184607066214, 0.16959751665126532, 0.1863210427109152, 0.13802305154968053, 0.1411854467005469, 0.19386543397558853, 0.07079570816131309, 0.1361374175758101, 0.11458262146334164, 0.17346774257021025, 0.08041242064791732, 0.18430946627631783, 0.13385687198024243, 0.20187086221994832, 0.14557247457560152, 0.15703979908721521, 0.11959230381762609, 0.08840014867018908, 0.10774111084174365, 0.11825663095805794, 0.11611782814725302, 0.10283463896485046, 0.13873914984287694, 0.10307787044439465, 0.18846568622393534, 0.16405184782342985, 0.11624028251389973, 0.1788137439871207, 0.1447126519633457, 0.23063184547936544, 0.14108276314800605, 0.16083202528534457, 0.1418593613198027, 0.19741036172490567, 0.15310721792047843, 0.1972162604215555, 0.11657861279672943, 0.1907180598936975, 0.1248065591789782, 0.14196732896380126, 0.11808923954959027, 0.09949268860509619, 0.2213555487105623, 0.15627238870365545, 0.12066360141034238, 0.13198312721215189, 0.12991145165869966, 0.07103913259925321, 0.17850051313871518, 0.09644433186622337, 0.12400613064528443, 0.2170118919457309, 0.07601436445838772, 0.09853499155724421, 0.2630786458030343, 0.1559508458012715, 0.17040339997038245, 0.12232305845827796, 0.176660061115399, 0.160816217539832, 0.1602604825166054, 0.09667102829553187, 0.1441881019854918, 0.11143696916406043, 0.245787747844588, 0.16248273983364925, 0.06174784073664341, 0.09149143123067915, 0.23473523935535923, 0.28195849678013474, 0.12747324421070516, 0.0789677411376033, 0.09006189153296873, 0.13887570501537994, 0.14069779630517587, 0.1093702511570882, 0.094166064664023, 0.1504683931125328, 0.15874170698225498, 0.13056265655905008, 0.1970418111886829, 0.0907288448070176, 0.15519447857514024, 0.1164654798049014, 0.08090222327155061, 0.09968263388145715, 0.0813650042982772, 0.052517508884193376, 0.12776222167303786, 0.18426570924930274, 0.12592172512086108, 0.07835488300770521, 0.1788532707723789, 0.18840313801774755, 0.09992916791816242, 0.07418207605951466, 0.1696727704256773, 0.12477466167183593, 0.11704082979122177, 0.13049811939708889, 0.10638433130225167, 0.14795399678405374, 0.08826130768284202, 0.09920480209984817, 0.17386507359333336, 0.09698379159090109, 0.08185212034732103, 0.10598272550851107, 0.11689264516462572, 0.1101304404437542, 0.13460005866363645, 0.16505794774275273, 0.3352964424993843, 0.1636001470615156, 0.1377842135843821, 0.09015727235237136, 0.1632590708322823, 0.11627802072325721, 0.15480504400329664, 0.14828774059424177, 0.09742917667608708, 0.10305358737241477, 0.0881406715780031, 0.09932182394550182, 0.19788202625932172, 0.08383971056900918, 0.1373460199101828, 0.17638816789258271, 0.11117557733086869, 0.10825795732671395], [0.0524417022097623, 0.02292388046043925, 0.07409815400023945, 0.0318451152270427, 0.04707432322902605, 0.04050170384289231, 0.018367631782894023, 0.02705590824916726, 0.05219971753831487, 0.10777747607789934, 0.07418474779115058, 0.034945262741530314, 0.04775318426254671, 0.06451940978877246, 0.06106576620368287, 0.07058405506541021, 0.04825213756703306, 0.00906455183212529, 0.016698254075890873, 0.06754047775757499, 0.017663376311247703, 0.061090661547495984, 0.06918455750565045, 0.03490305309242103, 0.06051367141481023, 0.01292922370339511, 0.02334026612516027, 0.05817583572934382, 0.02507364293705905, 0.028481961708166637, 0.13001719285966828, 0.04867118754191324, 0.014735858840140281, 0.039669244215474464, 0.015474690972041572, 0.028351907749311067, 0.04434401387698017, 0.03471030249784235, 0.10503598256036639, 0.06818258392740972, 0.01789734022167977, 0.04209003716823645, 0.010372013803134905, 0.03949191916035488, 0.07490919524570927, 0.038304868794512004, 0.039361557210213505, 0.060381428120308556, 0.06610670781810768, 0.039139065047493204, 0.0235866758521297, 0.0048885782325669425, 0.016959538297669496, 0.008262874634965556, 0.07672583175008185, 0.056361228998866864, 0.02619278307975037, 0.024522195672034286, 0.029284605552675202, 0.027591822363319807, 0.042292624930269085, 0.05511370472959243, 0.016244471589743625, 0.025975231765187345, 0.08544790747691877, 0.04417360192746855, 0.00756483511395345, 0.08340590298757888, 0.044870226265629753, 0.05768732444266789, 0.0529813437606208, 0.035851666252710856, 0.018087328171532135, 0.006780080739190453, 0.044176897063152865, 0.032203650480369106, 0.011525210175022949, 0.04754853704071138, 0.06249172874959186, 0.0627196794084739, 0.059826884244102985, 0.02704507474845741, 0.059932714502792805, 0.018187922578363214, 0.03642096031398978, 0.00853584211654379, 0.015411713247885928, 0.04850982608331833, 0.03048837650567293, 0.042682456551119685, 0.024669178019394167, 0.06694610652630217, 0.07384902986814268, 0.006757678083886276, 0.03384049799933564, 0.029663056338904426, 0.03326806836412288, 0.009609812368580606, 0.04212001251289621, 0.028680367468041368, 0.07879205993958749, 0.03523135696013924, 0.01440606232790742, 0.02739734813076211, 0.044803073033108376, 0.054977691324893385, 0.011200439857930178, 0.07252302719280124, 0.07406026736134663, 0.05399443100031931, 0.032376771268900484, 0.06328201212454587, 0.016808388791105244, 0.04290616954676807, 0.01659480982198147, 0.020204211650707293, 0.022529798188770656, 0.04351072675490286, 0.016841108226799406, 0.04615539226506371, 0.05211860450799577, 0.0033310758090010495, 0.03958042769227177, 0.11196687002666295, 0.04224576201522723, 0.004915763565804809, 0.11406890684156679, 0.013983248736622045, 0.016620718197373208, 0.0670195791462902, 0.08045845606829971, 0.07618571151397191, 0.035774111820501275, 0.06355519668431953, 0.04724623060610611, 0.0179881846634089, 0.008948212762334151, 0.01555457853100961, 0.033412861375836655, 0.026424119787407108, 0.02745363632129738, 0.0377695428323932, 0.02109512839524541, 0.012320541081862757, 0.0230605339675094, 0.01908745751279639, 0.08418214492849074, 0.06427653454011306, 0.026940044153889176, 0.07015200637397356, 0.01990065098652849, 0.021727605198975652, 0.035897315756301396, 0.018259795870108064, 0.042424378407304175, 0.06566415773704648, 0.034395631882944144, 0.04897733830148354, 0.01574243651703, 0.0017659831860328268, 0.03136248546070419, 0.023892012104624882, 0.04339814666309394, 0.06174346948682796, 0.06194951194629539, 0.050994239645660855, 0.030470010206045117, 0.09507037902949378, 0.014206335545168258, 0.05015818802348804, 0.04363415704574436, 0.06702012833557092, 0.04623465363692958, 0.033037442262866534, 0.02135505448677577, 0.02044679375103442, 0.0943183978961315, 0.03912464882887434, 0.06413666938897222, 0.007615460717715905, 0.08838946174364537, 0.04617950464307796, 0.027507197119120974, 0.03998393709480297, 0.004520645998127293, 0.023014578328002244, 0.07278392920852639, 0.0030682762144351727, 0.011582221031858353, 0.04720918630482629, 0.02275297312735347, 0.017799265406210907, 0.03483998909359798, 0.01544468686915934, 0.02386180669418536, 0.036581523963832296, 0.025329125419375487, 0.021574015881924424, 0.009979685783036985, 0.050204190047224984, 0.07794926961651072, 0.03856941846606787, 0.0015047876740936772, 0.03647188648756128, 0.04006222996395081, 0.0860208306403365, 0.030311461487144697, 0.03701360234117601, 0.07170603392296471, 0.05588667750998866, 0.024641623931529466, 0.03933776024496183, 0.029041251618764363, 0.03951746017264668, 0.09737692205817439, 0.05498672697285656, 0.0141081271431176, 0.02204692722443724, 0.025992833652708214, 0.028222456785442773, 0.02275937415106455, 0.024300642326124944, 0.041486500413157046, 0.03238782184780575, 0.016262509489024524, 0.025532980398565996, 0.021259274762996938, 0.03613260625570547, 0.004152501323915203, 0.03838137679849751, 0.024540647318644915, 0.028943230609002057, 0.019401220852159895, 0.053149763043620624, 0.08892477286281064, 0.07714459599810652, 0.00651185790047748, 0.050265368990949355, 0.011344762533553876, 0.03957406748668291, 0.04875508362601977, 0.047869415720924735, 0.060467955117928796, 0.04524365271208808, 0.06095458877098281, 0.04575210921757389, 0.0962769849866163, 0.023700953606748953, 0.057702208214323036, 0.008944425026129466, 0.06991607020609081, 0.030944840000302065, 0.019117622105113696, 0.018006460049946327, 0.018722554632404353, 0.06432828449760564, 0.042865781870204955, 0.04523815710854251, 0.05968108933302574, 0.09495591759332456, 0.04757398157380521, 0.06312307377811521, 0.0312388102611294, 0.06875335486256517, 0.04080209924723022, 0.03216733719455078, 0.06050187126675155, 0.039358814974548295, 0.034948179381899536, 0.035132948178215884, 0.03244702296797186, 0.01503716986917425, 0.022518803270941135, 0.06329474737867713, 0.1005484233610332, 0.05203618900850415, 0.01616838289919542, 0.026147768112423364, 0.04635534169210587, 0.03159759784466587, 0.09033498703502119, 0.07371246727416292, 0.02730678941588849, 0.035187277098884806, 0.08794656285317615, 0.06863867820356973, 0.00794454801507527, 0.04661743114411365, 0.04660404651076533, 0.042382332030683756, 0.06467268554843031, 0.03157454673782922, 0.030184398383426014, 0.038541075846296735, 0.05305410762957763, 0.03782425024837721, 0.036879948966088705, 0.03599151285015978, 0.09518724502413534, 0.06422080667107366, 0.02584995538200019, 0.03923289848899003, 0.02540484489145456, 0.030949832798796706, 0.0333212914847536, 0.04198685637675226, 0.03488108552119229, 0.04771134568727575, 0.038273884129012004, 0.03770254545088392, 0.05953368396149017, 0.022031060107110534, 0.05619514005957171, 0.05399347734055482, 0.05569399370870087, 0.05621487376629375, 0.047054073729668744, 0.05120967027323786, 0.032357664676965214, 0.012685533947660588, 0.020478199585340917, 0.0383596467145253, 0.04207543912343681, 0.08451832298305817, 0.05940905510215089, 0.023028155919746496, 0.01871176194981672, 0.02665640458872076, 0.08466696774121374, 0.04019605403300375, 0.04685341184085701, 0.010032521131506655, 0.03576554372557439, 0.03637577094195876, 0.04630953633750323, 0.042113340605283156, 0.025911126904247794, 0.022334179193421733, 0.06590232034795918, 0.004705114688476897, 0.056313538589165546, 0.07176278595579788, 0.020014650435769, 0.07574505390948616, 0.005120538344272063, 0.04079536796780303, 0.034450257662683725, 0.05171919547137804, 0.04141632292885333, 0.03663253548438661, 0.012349705630185781, 0.035786483422270976, 0.28048025735188276, 0.19329153117723763, 0.20627501886337996, 0.13209888740675524, 0.17058421683032066, 0.07998013446922414, 0.08366733192815445, 0.1518122444394976, 0.09007049302454107, 0.12254235567525029, 0.19246379903052002, 0.12902219546958804, 0.08858879518811591, 0.19839198561385274, 0.14173606090480462, 0.14698800252517685, 0.1361627841833979, 0.080450025270693, 0.10305116054951213, 0.16359584260499105, 0.15617169410688803, 0.2378896193113178, 0.12075754988472909, 0.13391781714744866, 0.26234602730255574, 0.07688765705097467, 0.12034602157655172, 0.12082842498784885, 0.12383119159494527, 0.24197091202950105, 0.2797020709840581, 0.16924149356782436, 0.150336439255625, 0.15808765223482624, 0.11915155715541914, 0.11497176659759134, 0.10700573897338472, 0.11085998645285144, 0.17445772304199636, 0.12356337276287377, 0.09812485106522217, 0.11212163750315085, 0.054456473590107635, 0.16614911262877285, 0.1596089659142308, 0.13271403877297416, 0.13052727095782757, 0.16207820997806266, 0.1411109944456257, 0.10266561483149417, 0.09733450089697726, 0.19663034967379645, 0.1387533248635009, 0.121906305430457, 0.148403218772728, 0.11882018821779639, 0.1217187572910916, 0.11850896116811782, 0.1434708756278269, 0.1610714866546914, 0.14105905895121396, 0.19767146412050352, 0.1680393033893779, 0.08335267615620978, 0.14579252136172727, 0.1521122205303982, 0.16694457619450986, 0.20591436477843672, 0.16154577839188278, 0.11265115244896151, 0.17378011252731085, 0.13356485171243548, 0.12987648166017607, 0.12352256948361173, 0.09986995937651955, 0.07300043595023453, 0.0612592589459382, 0.16789266985142604, 0.21219142014160752, 0.1513009492191486, 0.21443142963107675, 0.13854703749530017, 0.19620135863078758, 0.2186989865731448, 0.13615239411592484, 0.1725199309294112, 0.11225543930777349, 0.1915560633642599, 0.13542557921027765, 0.14985557209001854, 0.10909522607107647, 0.14163134386762977, 0.19490212522214279, 0.16635504376608878, 0.17783456918550655, 0.18137906648917124, 0.12066999130183831, 0.2093470055842772, 0.32185261545237154, 0.3267960314406082, 0.1778893990558572, 0.17487622011685744, 0.22904250654391944, 0.14497960248263553, 0.12345435126917437, 0.1319738503661938, 0.175019335874822, 0.21147033461602405, 0.19189464597729966, 0.1618435131967999, 0.09098173162783496, 0.1300104393158108, 0.09390367093146779, 0.141563615470659, 0.13178129273001105, 0.08955084122135304, 0.12566675286507234, 0.10226961225271225, 0.10856603767024353, 0.08941056046751328, 0.09945962592610158, 0.13823040761053562, 0.2940209791995585, 0.3109354746993631, 0.19916781195206568, 0.041403884533792734, 0.21914774843025953, 0.14012690662639216, 0.15314453310566023, 0.1276040106313303, 0.1837174699176103, 0.1423889133729972, 0.15922720514936373, 0.08197051516617648, 0.15236698498483747, 0.13889445166569203, 0.11633125497610308, 0.17485071992268786, 0.12402723732520826, 0.10975749639328569, 0.16059504268923774, 0.11916486386326142, 0.11820926709333435, 0.16347181488526985, 0.21899732993915677, 0.1259833382209763, 0.19350282062077895, 0.1953607428004034, 0.12096926977392286, 0.14242236939026043, 0.16271311731543392, 0.15543692337814718, 0.16757927573053166, 0.0889538205228746, 0.20820182719035074, 0.15135947498492897, 0.09858438890660182, 0.1129939356178511, 0.15307521651266143, 0.0967938537360169, 0.20918913593050092, 0.2306878479430452, 0.1438322867034003, 0.17601204745005816, 0.18507230503018945, 0.15814297192264348, 0.09506896152743138, 0.1871832401957363, 0.0848231378768105, 0.09826417444855906, 0.14262383279856294, 0.17860321153420955, 0.1606442322372459, 0.1293721329420805, 0.17445303266867995, 0.0903852230112534], [0.03695440864248667, 0.006650216491834726, 0.1063717296347022, 0.01573676836414961, 0.04964676663803402, 0.015073241956997663, 0.06887477764394134, 0.04704480059444904, 0.0375146930309711, 0.01387212974805152, 0.07675923581700772, 0.01964726692676777, 0.026864176252274774, 0.02912021427619038, 0.044555266213137656, 0.05349257218767889, 0.05134934988745954, 0.03578584888600744, 0.03751557618670631, 0.07772635814035311, 0.06197527560289018, 0.03665170515887439, 0.016928091645240784, 0.05450993419799488, 0.024698301749594975, 0.03522747181705199, 0.0669725269835908, 0.08520133633282967, 0.010339510517951567, 0.06111414681072347, 0.01177727042886545, 0.07509525908972137, 0.07523395906900987, 0.02260900761029916, 0.01213966299474123, 0.02867766233975999, 0.04599368941853754, 0.023932125186547637, 0.06297654414083809, 0.008271918632090092, 0.015205545550998067, 0.05542704318941105, 0.039472745775128715, 0.017459478658565786, 0.03191916301148012, 0.051508778051356785, 0.049666218328638934, 0.036475979431997985, 0.008620801327197114, 0.06503603362943977, 0.051014448326895945, 0.02278938289236976, 0.07701115784584545, 0.024498671446053777, 0.03913025575457141, 0.046200232827686705, 0.02400234719971195, 0.05417344444140326, 0.040973557624965906, 0.07320909819100052, 0.039447338349418715, 0.03678524350107182, 0.0855808483902365, 0.057211470484617166, 0.05264995255856775, 0.023553620594611857, 0.048572374289506115, 0.05702591501176357, 0.05306661652866751, 0.056641868432052433, 0.08704872743692249, 0.05996860476443544, 0.0595672513009049, 0.04340996536484454, 0.10683954984415323, 0.07024478967650793, 0.1037021576485131, 0.019918178659281693, 0.028755023813573644, 0.0341327372007072, 0.06040691718226299, 0.030138472429825924, 0.048317572727683, 0.04519122368947137, 0.010526065107114846, 0.041079625370912254, 0.040266832656925544, 0.03179975145030767, 0.05386307828302961, 0.046093085256870836, 0.04792549239937216, 0.024358776609005872, 0.060801543077104725, 0.06947949441382661, 0.07845783373340964, 0.06323560563032515, 0.05154949598363601, 0.04774169581651222, 0.08077650345512666, 0.06466958337114193, 0.044454838789533824, 0.002747994963101519, 0.02747031052422244, 0.030224945621739607, 0.074806430056924, 0.02785666332783876, 0.03589806532545481, 0.018206925269623753, 0.026556812081253156, 0.019351534065208398, 0.06628258939599618, 0.023318018393183593, 0.04580676839395892, 0.01753560260112863, 0.0196796394084231, 0.034220844972878695, 0.02993711292219814, 0.0713665310468059, 0.04968879817170091, 0.034011930401902646, 0.035585368823376484, 0.020983702343073674, 0.07615985508891754, 0.020589503183146007, 0.0706313521368429, 0.05065254372311756, 0.0030336088730109623, 0.014419407070818124, 0.0348677157307975, 0.03918133406841662, 0.04020847387437243, 0.04757046379381791, 0.05651564024446998, 0.08119084450299852, 0.027122165338369086, 0.03181265368766617, 0.037269357562763616, 0.020277303920011036, 0.026336639130022377, 0.03358548863616306, 0.02700780409213621, 0.020748981442011427, 0.028806404552597087, 0.019109721943095792, 0.015560713309241692, 0.017012898715620395, 0.025831453640421387, 0.01909593655000208, 0.019722873221326154, 0.035004560340894386, 0.0497220426768763, 0.03422528301598504, 0.025598909087420907, 0.033995632838923484, 0.02747942038695328, 0.05750072996306699, 0.02204836142482236, 0.012382718214212218, 0.030764542643737514, 0.053491844882955775, 0.021351087707444094, 0.033281968790106475, 0.032817109749885276, 0.031921875561238267, 0.05454402475152165, 0.05035480149672367, 0.06201106938533485, 0.019433376255619805, 0.015437198599101976, 0.0016311083982145647, 0.07868558401241899, 0.03018796254764311, 0.046221625234466046, 0.03090120357228443, 0.09374787186970934, 0.005873024601896759, 0.04858820429944899, 0.021475955909409095, 0.04271071753464639, 0.03938074914913159, 0.018789320092764683, 0.014599368605558993, 0.05675890512065962, 0.03912969172233716, 0.035267696221126243, 0.023564552429888863, 0.0660390239499975, 0.06539374138810672, 0.006978504588914802, 0.014944138874852797, 0.019630496244644746, 0.022676114458590746, 0.04764473422255833, 0.022989081844571047, 0.06987209053477272, 0.04094555268238764, 0.03076989909459371, 0.05555341238505207, 0.05716715684684459, 0.0689047752530314, 0.00953861072048312, 0.04341764288255945, 0.05166798728168942, 0.04026738926768303, 0.024930202489485964, 0.029068221265333705, 0.033487406399217434, 0.027459105949674267, 0.03060071168874856, 0.033797631549532525, 0.05407732147432398, 0.042999279394280165, 0.013595761374745052, 0.04258936154656112, 0.06359441176755354, 0.04137324867770076, 0.04976003692718223, 0.010519128809391987, 0.022368447862390894, 0.03385070252988953, 0.05107181263156235, 0.07130125915864483, 0.03680781963339541, 0.04399117089633364, 0.10049570861156099, 0.019803414797934238, 0.0189590678201057, 0.03383849048987031, 0.07333813540753908, 0.028091191270505078, 0.020092037884751335, 0.03586312501283828, 0.009395563611178659, 0.06011907149513718, 0.09714396932395175, 0.08210969011997804, 0.04829248442547396, 0.044270185026107356, 0.020104960531170946, 0.07554981712019071, 0.01657718195929192, 0.039046767851687036, 0.0206883238570299, 0.03327809477923438, 0.0524262098770123, 0.055804061630624346, 0.04857308304053731, 0.04843578200961929, 0.006360954694173415, 0.05074872977274936, 0.08616399834863842, 0.041110680540441535, 0.08284074268885888, 0.06876574130728841, 0.014221972596715204, 0.00911974442715291, 0.07810535069438629, 0.0326271236554021, 0.0565576643566601, 0.024376007422688417, 0.016576209745835513, 0.027052227196691092, 0.03256046024034731, 0.04200314280751627, 0.03000389137014281, 0.018787277331284713, 0.01366675429380848, 0.027569739759201184, 0.023228507961903233, 0.04907773974991869, 0.06757313967682421, 0.0951501153758727, 0.0672313806717284, 0.07496381731471047, 0.050458297700970434, 0.03270377637818456, 0.06730482360580936, 0.023296351391763892, 0.05778538070444483, 0.03109699140622979, 0.006140476534710615, 0.03200403501978144, 0.028048944514011964, 0.018118229345418513, 0.02651872877322603, 0.023005802431725897, 0.04211828330880962, 0.01555458316943259, 0.0544545996672241, 0.025850315323623363, 0.02121748257195577, 0.08805548786767758, 0.014070420475036371, 0.04584511145367287, 0.0407418813847471, 0.06317502411548048, 0.08307390322443098, 0.004570018763843109, 0.02982588910526829, 0.03605050245823804, 0.042929012852255255, 0.10345597984269261, 0.0021381935539466213, 0.026769229589262977, 0.014613326547987526, 0.031744309308123775, 0.009513401819276623, 0.03564639191608876, 0.011466244686744176, 0.049902748214663006, 0.03604607925808523, 0.04141709847317543, 0.028458044143917505, 0.024552464165026322, 0.009479507934884168, 0.04121500423934776, 0.03432091987633612, 0.013669023410329828, 0.01769780083122896, 0.037701922046835534, 0.03215388205717318, 0.01812756927392911, 0.05537672928767279, 0.051348989945836365, 0.10402965257526375, 0.012799372907466022, 0.037909541570115834, 0.048462529011885636, 0.0058929841998178745, 0.06525118966237642, 0.08594769198680297, 0.06369773356709629, 0.022511723182105925, 0.01718170020467369, 0.03694202590850182, 0.0702165138500277, 0.02509628586267354, 0.008684857020853087, 0.07866124899010174, 0.060811962830484845, 0.04505316937866155, 0.024603670499345753, 0.040626195404911414, 0.034821591252693906, 0.05720445347833447, 0.01597944508830551, 0.02631004241266055, 0.018025540666712914, 0.04258399952959735, 0.017384458660671953, 0.03895418863976374, 0.051201009409851395, 0.22891748434631154, 0.13801206776406616, 0.1813213125569746, 0.14376874401932582, 0.11167174758156762, 0.12372310520731844, 0.15675756032578647, 0.11623027094174176, 0.09970588536816649, 0.08982789237052202, 0.11207373929210007, 0.16515675728442147, 0.14249588653910905, 0.0935116239998024, 0.14709689043229446, 0.16017347312299535, 0.11720067355781794, 0.13800164801068604, 0.17235536710359156, 0.09133316823863424, 0.13470436009811237, 0.15375233720988035, 0.1362920959945768, 0.18340747483307496, 0.08526158388121985, 0.12498679716372862, 0.18742037122137845, 0.19525881623849273, 0.10511752232559957, 0.1292466654558666, 0.08817575289867818, 0.18721864063991234, 0.1978876517387107, 0.0740900868549943, 0.106982880824944, 0.11319598532281816, 0.1393420112435706, 0.08868798322509974, 0.17541681532748044, 0.13257553917355835, 0.11774544705986045, 0.19063298008404672, 0.0906392972683534, 0.11006323155015707, 0.08696629709447734, 0.23706929379841313, 0.20339848415460438, 0.11170359313837253, 0.23818505345843732, 0.13039458979619667, 0.13223426998592913, 0.09859031866653822, 0.16974550089798868, 0.12094278252334334, 0.1907252290402539, 0.1433478423859924, 0.1922559383092448, 0.18159421510063112, 0.164519950048998, 0.24104382115183398, 0.14231048320652917, 0.21341450919862837, 0.18211162561783567, 0.1983277898398228, 0.112010946177179, 0.1343641892890446, 0.14544188627041876, 0.1191594907140825, 0.11349631764460355, 0.1524802070343867, 0.17111039953306317, 0.13116496877046302, 0.13652787631144747, 0.10200184537097812, 0.210153185762465, 0.16070211975602433, 0.25383579020854086, 0.14880215283483267, 0.11107929109130055, 0.13421868381556123, 0.13264286681078374, 0.13830104522639886, 0.17383400729158893, 0.11321274301735684, 0.12399539176840335, 0.1568640288314782, 0.14000774739542976, 0.1361501676728949, 0.1577703989460133, 0.1041939714923501, 0.10092067721416242, 0.20017915143398568, 0.15310040500480682, 0.17700372001854703, 0.16652164107654244, 0.2696744684362784, 0.16107904171803966, 0.14605908596422523, 0.1669015910010785, 0.17798832734115422, 0.20044671051437035, 0.12310115576838143, 0.12301875511184335, 0.10827245147083886, 0.15902968996670097, 0.12505032500484958, 0.11006078246282414, 0.08767243576585315, 0.1704968066769652, 0.0706488371361047, 0.12448376204702072, 0.09009839777718298, 0.14958998712245375, 0.08081945896265097, 0.10840939998161048, 0.20034470973769203, 0.09442565307836048, 0.18485718610463664, 0.10963194727082737, 0.13671304215677083, 0.16565246740356088, 0.08866770032909699, 0.1017732045147568, 0.16398107662098482, 0.16036551125580445, 0.12930248980410397, 0.08981537233921699, 0.1568693871377036, 0.08287126722279936, 0.11439439054811373, 0.11236184844165109, 0.12152185809100047, 0.1599099810118787, 0.13030625937972218, 0.044022593428962864, 0.16065862990217283, 0.13860440551070496, 0.12547824735520408, 0.1045077144226525, 0.12825764977606013, 0.09694329259218648, 0.11750526580726728, 0.1038517226697877, 0.24772932491032407, 0.126368097262457, 0.09725500203785487, 0.19557764288038015, 0.07653780863620341, 0.20641958923079073, 0.10451666472363286, 0.18611036182846874, 0.12056652107276022, 0.21202917181653902, 0.19618471967987716, 0.23654673277633265, 0.1813445269363001, 0.1525122974999249, 0.07865458450396545, 0.2483168535400182, 0.1603532806620933, 0.12354875245364383, 0.11672451902995817, 0.15238028427120298, 0.18097621388733387, 0.1838413640507497, 0.121534489444457, 0.09521644111373462, 0.13344098726520315, 0.16077670559752733, 0.0919832376530394, 0.1904049626318738, 0.08769118983764201, 0.0940707654808648, 0.12180581863503903, 0.21942415391094983, 0.13536969549022615], [0.02026515681791352, 0.032858031772775576, 0.04597236751578748, 0.01578269246238051, 0.026157087631872855, 0.016926657444855664, 0.02466982368787285, 0.02131742574420059, 0.026408577359688934, 0.006428436327041709, 0.029161635393393226, 0.038029565403121524, 0.0071095423572842265, 0.03285069193225354, 0.023995801457203925, 0.050714127137325704, 0.036186000070301816, 0.05102237075334415, 0.041185032605426386, 0.03686075702717062, 0.05678068344423082, 0.0014544218220180483, 0.025465962607995607, 0.04342041851487011, 0.04382515988254454, 0.06984373307204805, 0.05159939799341373, 0.024534838157705963, 0.05564543498621788, 0.0038726251432308345, 0.02654926443938166, 0.012144631673436379, 0.004855731704083155, 0.03638320355094038, 0.009755973715073196, 0.020331124469521455, 0.03262309750425629, 0.03113847560598515, 0.02084026375086978, 0.022523304396599997, 0.0633069260220509, 0.044460634962888435, 0.035202461440349, 0.014229906155378558, 0.03237898286897689, 0.07396733562927693, 0.04626958652806934, 0.04595237405737862, 0.03911257779691368, 0.03115612387773581, 0.08103845189907588, 0.05507093475898728, 0.03409523647860624, 0.047708180427434854, 0.0922047316271346, 0.006105577504058601, 0.06210960062162485, 0.046959628016338684, 0.025773350898816716, 0.02554065049480414, 0.02691278135898756, 0.03625422941695433, 0.04908879775030073, 0.015357669126387918, 0.06593787664314732, 0.03624092641985044, 0.043844077226822264, 0.040432728637824766, 0.10728802968515083, 0.03258158547396306, 0.09806286689126864, 0.02374224113737, 0.018381626832706388, 0.06925458656041883, 0.02655779171618633, 0.024161109286069404, 0.03950784193875734, 0.06959815640584566, 0.0355841479904484, 0.03757842867344152, 0.04066782246809453, 0.025469549036643002, 0.04074642332852818, 0.03013285437191371, 0.04305515198211651, 0.08045077483984642, 0.06524014650494792, 0.037366304313763976, 0.05346871956135146, 0.024187229173548985, 0.0404042598529486, 0.07200891923275776, 0.0432323657150846, 0.05257452437945176, 0.05576772236963734, 0.011673494063870749, 0.013906968015362509, 0.026308326196158305, 0.05457294995721895, 0.024044699712248985, 0.03319026160170324, 0.05289455330057535, 0.054394207400036976, 0.010435378371767001, 0.02988550768350251, 0.009868605757219484, 0.024986114040075336, 0.05358103247999679, 0.03178447062964551, 0.07607602950884029, 0.07170153650804423, 0.022446560760727152, 0.07978979585459456, 0.0429911491664825, 0.049087291190517135, 0.030770904704695567, 0.012218361262057442, 0.02193175518186763, 0.01497804203609121, 0.04771494510350749, 0.011010104026354384, 0.059995221890858375, 0.029685422814509366, 0.09606037434423342, 0.033994415716733783, 0.04010351563920267, 0.030468794939224608, 0.05541127626202069, 0.04037519734993111, 0.06365413981257007, 0.0074333910197310615, 0.012328642551437952, 0.037813329545315355, 0.04113149036129471, 0.025328386982437223, 0.032812278368510306, 0.03898242735886015, 0.04121852201933507, 0.04150383698288351, 0.017651848902460188, 0.07973928528372198, 0.04350844465079717, 0.01339162159638363, 0.0783762197534088, 0.05385667725931853, 0.07811689851223491, 0.015483985444006976, 0.07331165557843633, 0.06902979745063931, 0.022067970821808558, 0.0699237959634047, 0.052316097426228225, 0.08048606396187097, 0.035790190449915826, 0.02794415326206945, 0.03307008191768546, 0.03986875948612578, 0.0252778652793495, 0.06449447362683713, 0.05364794451452326, 0.008435077015747083, 0.056186327055911534, 0.020397179323481396, 0.05062512878794223, 0.051561221916927025, 0.03782151914492715, 0.028803105706174392, 0.0132515774021158, 0.0799620409088675, 0.04171977227088064, 0.10096683879964985, 0.03153645600832533, 0.0256146463289042, 0.055263985923375, 0.04466101854632143, 0.01945854619407328, 0.04487956619414035, 0.03688432763738092, 0.005226518424024107, 0.02926445253251586, 0.05341513649909757, 0.033179763922817074, 0.023452254354197066, 0.03821265323495027, 0.02644004071044037, 0.03342212708957959, 0.016864307763171382, 0.023033775833027903, 0.009100808529183269, 0.026331334629503544, 0.0086771080714243, 0.08623416841146536, 0.04937446894473396, 0.04304391586629208, 0.05995689738483634, 0.031904809875413775, 0.029244084289530292, 0.019743300836125854, 0.07666266756132245, 0.022869733365951106, 0.016193630763154943, 0.06264198396820575, 0.029698879807256162, 0.06932371761649847, 0.04047792543133255, 0.06950230061192997, 0.014069357348489575, 0.040337054670089856, 0.01078497909475118, 0.027758542128140107, 0.030398812268686015, 0.03207937414117623, 0.02602002594358055, 0.04028865550935734, 0.1246704492950812, 0.021122367070347536, 0.03242497747123707, 0.019415139831835404, 0.0791575231414754, 0.03456306782027241, 0.02175773639464751, 0.010945419362542452, 0.0024591418105046614, 0.02551276429585414, 0.04116731011890806, 0.020433474055607803, 0.011094348919868935, 0.06568876735400409, 0.013892622300772928, 0.052691149176098406, 0.01686679581325734, 0.05642910211463459, 0.038199201808311045, 0.04781962503329851, 0.10397468169685453, 0.030531743905157782, 0.027006909804185852, 0.05845129497174639, 0.029383222135948017, 0.04703399863501545, 0.03631939740444068, 0.045483607609639876, 0.053090869914740324, 0.048293122672475874, 0.01699452128377743, 0.0007047760766454303, 0.06758169663953595, 0.020128885516896844, 0.013779929959127912, 0.04384642612421885, 0.046277041401481256, 0.02840561697666999, 0.0885396427474916, 0.10380614738096483, 0.004086405187990749, 0.051110203930875286, 0.06117977864050772, 0.049010965012712404, 0.0536217095941538, 0.014418938590097241, 0.06460275297285989, 0.06461243800004013, 0.042876925217569806, 0.028090762680221815, 0.049571739218663424, 0.041352576154167764, 0.04912171199976001, 0.04031499433040153, 0.05238513942458667, 0.008638676881673746, 0.05312611079716589, 0.044521409436129034, 0.019815207524516154, 0.020075183711014688, 0.022497882127936464, 0.042194772759103216, 0.02015296820900403, 0.014506325551337795, 0.058249130233889446, 0.05754020850872621, 0.05845815612701699, 0.05110336504003499, 0.04951928793161642, 0.010359822172176791, 0.02765692912362283, 0.03385149662790354, 0.047006977038108744, 0.04183682380244136, 0.07376533045317046, 0.047811038384679705, 0.03925631695892662, 0.034109437474398874, 0.0028322579464656883, 0.018974877420987468, 0.04483471821004059, 0.05662853203830309, 0.06726581632392481, 0.03438364248722792, 0.0327033681969624, 0.0035325916314832284, 0.016257819115708116, 0.1198386968462728, 0.03715190898219589, 0.07033189554931596, 0.06993620467255823, 0.06479203773778863, 0.01024293484078953, 0.0438384480366949, 0.033386674695066176, 0.05025297883548774, 0.043141957285115495, 0.049350271219736896, 0.05974229425191879, 0.04067374480655417, 0.0090488136629574, 0.024917246446420904, 0.10729663859819993, 0.03938934692996554, 0.049658782008918934, 0.013621861780848121, 0.03563966434739996, 0.022016450930095743, 0.005880712787984521, 0.043359926057746634, 0.020581578901328612, 0.03668941368232481, 0.05310057349561248, 0.006000667044645525, 0.010029985769506311, 0.023480025520257186, 0.00961256480877637, 0.03558805910870433, 0.014182635059114546, 0.06354000492137857, 0.025221426803909708, 0.07527951951487921, 0.022945395321585238, 0.11727852484909818, 0.03225636522984132, 0.030126985839160625, 0.015917655728117097, 0.035420727072050795, 0.03309150772111025, 0.008835741209622938, 0.04070347895321902, 0.014183101684466237, 0.08531463259714656, 0.011490580636746017, 0.020457771970541216, 0.07289174100151286, 0.01400623583322158, 0.04350981762399897, 0.15435291279572994, 0.10341702451114543, 0.08463782360195182, 0.07214856916107237, 0.09303624872700311, 0.10766324470750988, 0.1386089326115325, 0.10178460390307009, 0.11804281821241602, 0.18130454001948237, 0.16338621557224542, 0.13648055697558448, 0.07161623405409046, 0.21492924744961783, 0.11314531147945672, 0.18768389301840216, 0.08750236520427279, 0.1878162773209624, 0.12436636170605198, 0.12119267106754705, 0.0804837781470269, 0.12830219347961247, 0.19286979833850637, 0.13684045406989753, 0.17408719839295372, 0.19942778628319502, 0.17607309651793912, 0.19966334395576268, 0.0858574097219389, 0.1613478030776605, 0.07604462924064137, 0.16679579042829573, 0.08916598570067436, 0.10404458458651789, 0.11643743404420093, 0.10628673888277262, 0.07788030183291994, 0.09055231756065041, 0.25072375719901174, 0.13211632787715644, 0.10615734543534927, 0.10934751917375252, 0.23549061210360378, 0.1517286043963395, 0.05588459949649405, 0.12716771685518324, 0.08330089651281014, 0.14818866387940943, 0.1859977186541073, 0.10061691617011093, 0.1884144780342467, 0.10396337136626244, 0.08896570972865447, 0.11764413648052141, 0.13824997062329203, 0.08697791170561686, 0.14098626910708845, 0.12592234852490947, 0.17936539719812572, 0.12602210801560432, 0.09341795754153281, 0.13037841097684577, 0.11072250359575264, 0.2676723914919421, 0.21381314640166238, 0.16263021941995248, 0.09404549535247497, 0.07317003153730184, 0.18584924458991736, 0.14506082312436774, 0.22197286714799702, 0.12319528235821053, 0.08260496979346499, 0.22045437362976372, 0.13222874840721488, 0.10872204453335144, 0.18401052919216454, 0.1626394220511429, 0.06734250986482948, 0.09419057780178264, 0.13421095063677058, 0.158203145256266, 0.12413658536388539, 0.21974045725073665, 0.15065492450958118, 0.1508860886679031, 0.2530334098264575, 0.100967469625175, 0.12287121615372598, 0.1436327677220106, 0.1190078179934062, 0.21144807018572465, 0.15066491381730884, 0.2606856945203617, 0.1693923128186725, 0.14308561192592606, 0.17085658502765, 0.20941715338267386, 0.12950730771990493, 0.10153901239391416, 0.1260313848615624, 0.14049799530766904, 0.12451076137949713, 0.17077196534955874, 0.12573053303640336, 0.10071914701256901, 0.18628006131621078, 0.14057462947675958, 0.16445088578620926, 0.09745520379510708, 0.11864847008837387, 0.18099910172168165, 0.1785555062815547, 0.12010073434794322, 0.12438836638466455, 0.09242333864676766, 0.2243732547503896, 0.08292479833471589, 0.13992505730129778, 0.08406031396589242, 0.06733352987794206, 0.11870942267705686, 0.17165672412374988, 0.15929766464978456, 0.12848281738115475, 0.2363715710816905, 0.09838892947300337, 0.11474981991341338, 0.09854616087977774, 0.1511959353229031, 0.08000009824172594, 0.18152216740418226, 0.16219172888668254, 0.1412329589948058, 0.07223661756142974, 0.09874288196442649, 0.12624519760720432, 0.09665697201853618, 0.09321340679889545, 0.0778754630300682, 0.27763738646171987, 0.2253860339988023, 0.09401662580785342, 0.2643350721336901, 0.1821711755474098, 0.09490373719017953, 0.1937489613192156, 0.11570187663892284, 0.13585531240096316, 0.08720171375898644, 0.1575660560047254, 0.11125624136184342, 0.15358562115579844, 0.11663240366033278, 0.1402406333363615, 0.12045888739521615, 0.122065963660134, 0.141625362157356, 0.17116750037530437, 0.1619250010116957, 0.0886437957524322, 0.2307570754783228, 0.18474056501872838, 0.20088442921405658, 0.1124100064043887, 0.153314113849774, 0.13185614574467763, 0.10576240412774496, 0.180319175706245, 0.13313516305061057, 0.18760935170575976, 0.13087383907986805, 0.13280021696118638, 0.16864802775671706, 0.08564317395212129, 0.10998442288837396], [0.023833569830458146, 0.038563959969906136, 0.04432628396898508, 0.04473745975701604, 0.06665820517810062, 0.025676667610241566, 0.06811095183365978, 0.03307987084554043, 0.052721992833539844, 0.06761918251868337, 0.03729912139533553, 0.0700429774587974, 0.013517004663299304, 0.024374018466915004, 0.017420458389096893, 0.046466504281852394, 0.060372396183083765, 0.023911005519039463, 0.11488268661196344, 0.03998146203230135, 0.01702123488939833, 0.056923394731711596, 0.0566939300915692, 0.025679892241896596, 0.052131751654087566, 0.011459189645393053, 0.06163409547298215, 0.026253542710037436, 0.022071215862524696, 0.035969771633972414, 0.03556884861609433, 0.0748596568882931, 0.015638162913091946, 0.03429869255342055, 0.02403805006906623, 0.037706812800024636, 0.01936478140123654, 0.015216840110952035, 0.014040800433576806, 0.018715520927798934, 0.024862819191184826, 0.04285205213818699, 0.039846602667239495, 0.03368678437254857, 0.06668233982054517, 0.050739534563035704, 0.13305746018886566, 0.020724594469356816, 0.06179479642014485, 0.0836471826187335, 0.04465822064958047, 0.04083262749190908, 0.018054703359666746, 0.09837630554102361, 0.05394495201471727, 0.0031096228849492036, 0.01784950880391989, 0.031704890134278685, 0.03233714058296755, 0.022670934267807752, 0.0463014209526591, 0.014005950106366072, 0.04328150702349376, 0.029512700930354185, 0.01225597701704828, 0.0353146481938893, 0.03867861807520967, 0.05915708483371418, 0.11859404839924537, 0.061972551920916885, 0.052633113227784634, 0.05205661291256547, 0.040449675580020994, 0.06312037236057222, 0.03491231509542558, 0.08608801726950333, 0.00339259358952404, 0.029950568059575744, 0.03937606619729195, 0.05792504547571298, 0.047615560397389345, 0.05644677636155393, 0.02546852487284923, 0.03565805105608888, 0.04065423745487351, 0.036612783223972656, 0.05986201380437706, 0.0603915101964958, 0.013335774056031369, 0.029796750532113947, 0.019702668250829447, 0.021757934919151012, 0.04967831162502989, 0.017032142604875844, 0.011982366650045151, 0.02928510650235694, 0.03197126177838072, 0.009453659858991159, 0.06985619373153895, 0.04971365640813019, 0.012418216065270826, 0.02771509680314921, 0.020951506121491548, 0.04116379233892076, 0.06090374052291736, 0.04888318573648576, 0.015803576498001348, 0.01926139651914127, 0.04585919370583724, 0.016291280699078925, 0.01884309054730693, 0.0352209854463581, 0.015936599047563504, 0.051151411680621095, 0.046255923589342274, 0.021511484374059364, 0.05004352249670774, 0.037084974683239125, 0.017694097514322493, 0.01991649955016328, 0.036645385771407746, 0.14627073163865134, 0.0379839344532229, 0.037617528723785654, 0.022777297017455567, 0.018377995875198394, 0.027876788517460227, 0.06338786464766599, 0.021885857058805414, 0.01452063508622814, 0.02669724497536663, 0.034773848892655224, 0.007983630439412082, 0.066887892462546, 0.0264529373816913, 0.034352639268036, 0.05850952016771771, 0.020477967664191965, 0.07032811059616506, 0.060447861469583586, 0.06195390174980275, 0.04740491662232671, 0.02846164356014924, 0.029915920895291492, 0.0718723789032083, 0.024179653701139614, 0.03422449262870941, 0.07099940543412231, 0.06280303743551485, 0.029363273206399754, 0.0468376560456818, 0.01863469176896615, 0.03578017887775786, 0.02865438858862035, 0.008302795686176978, 0.007918896608316572, 0.05313668640155811, 0.02873267774702981, 0.055016364640323445, 0.02597255261207465, 0.02992341287608724, 0.05218044767389074, 0.014325965112220729, 0.049015429030987434, 0.0596776457678061, 0.024225648303399794, 0.06539809779496863, 0.026116438348253723, 0.012638299031095812, 0.016263760007859673, 0.03966388219851069, 0.05681213195202872, 0.04275799234164879, 0.006187078306538751, 0.005761255770266871, 0.05628470244118944, 0.016239078031503595, 0.04120643614442088, 0.04611699354427401, 0.02768408987321891, 0.04048064540256746, 0.015450480259460164, 0.04513344007136766, 0.024914628520491533, 0.09965054341591895, 0.010451868893142091, 0.08123336956487037, 0.04029720505059231, 0.028351479159027804, 0.018542134821473155, 0.02042787084064912, 0.02173438286263263, 0.10526682017371058, 0.010598053431749577, 0.040547909957240336, 0.04019021333078854, 0.04534987259830814, 0.044435067975427955, 0.00699830879966612, 0.049922185062314384, 0.042874387072515674, 0.046766239174758084, 0.006756599650543649, 0.06500846284325235, 0.03074792039114982, 0.039721313296468, 0.08190182197722606, 0.04774831948452629, 0.010857085235329578, 0.035649093333631754, 0.050678689585765824, 0.02685064318939112, 0.014404861904040445, 0.0769534039136488, 0.02920372073276667, 0.015536659375356976, 0.03844681195914745, 0.0276118751935428, 0.05799218015454244, 0.08033151912968606, 0.05392770079197362, 0.029842145850125235, 0.03927197998564225, 0.03364214047905989, 0.02840596207533963, 0.02670993755600648, 0.0332617786625633, 0.06125742584117688, 0.029631244178744964, 0.041397884269827046, 0.0223220580664929, 0.06905098576680757, 0.04998724543838762, 0.0028584592382685514, 0.04972863294824492, 0.07876711635617539, 0.056884398582042195, 0.018169600807595998, 0.03803173247433733, 0.0235858131054556, 0.03921221854398027, 0.03765879955608398, 0.04273124533938244, 0.050302687886869535, 0.15773628983879462, 0.05940504379395861, 0.025564649695297703, 0.04732151035568677, 0.01767698173352983, 0.012206760566186858, 0.025274672188970726, 0.013081366760161472, 0.031377280174638145, 0.07550770023954101, 0.02021761298237834, 0.0635165159474127, 0.03869831096380949, 0.046877312706783414, 0.06482833618065342, 0.030503239868266974, 0.03496155288303271, 0.03733923447725829, 0.03249130691983737, 0.028245040339243133, 0.04746697501104791, 0.011406703106331406, 0.07623585843248293, 0.022108304692665115, 0.040032132164924406, 0.07632275650394149, 0.005618780578515725, 0.03573472975404002, 0.018229881752631627, 0.016059650843089912, 0.02538966240535956, 0.025070943374885246, 0.01627253404876683, 0.038850347336847335, 0.0046814030702080345, 0.01443340212063049, 0.03205451590474695, 0.04464184145035688, 0.03300053154816851, 0.026541492297837976, 0.06104051833972335, 0.04804399111890234, 0.022061059571569785, 0.03444307738391217, 0.02134833990567131, 0.029679376166313887, 0.010840036247827811, 0.038815139851067215, 0.035525559142115526, 0.04045227680762764, 0.007785666257404955, 0.02528761153371306, 0.026116918888874352, 0.10443051622132771, 0.009240524323104182, 0.04113867806154303, 0.050385288923280314, 0.03804382577072829, 0.0309116121934494, 0.043937101727351546, 0.012329687124292832, 0.07162528083426878, 0.07131729696993716, 0.03915551475074608, 0.03875371599860955, 0.03679751120216679, 0.05257928896753583, 0.02883989396650577, 0.07076893889461644, 0.03306455662823282, 0.015468699057237245, 0.06977384502533823, 0.021808974270243198, 0.04770714513142593, 0.02455294470564695, 0.01159091714725946, 0.03241917758714408, 0.056377526561846025, 0.01698236861557234, 0.05177996994461864, 0.010364608097006567, 0.0381537304201629, 0.01826646963309031, 0.05022329292842187, 0.0285353963408852, 0.0593820075300755, 0.01745563804433914, 0.021496736044355202, 0.04030555792269297, 0.021341360006772447, 0.0879944016924128, 0.017923875711858273, 0.04484743119974155, 0.057311823693453334, 0.04115106079552788, 0.017991975182667375, 0.01791633178072516, 0.025359881874464918, 0.03579836149583571, 0.031700207182439044, 0.0448872140259482, 0.03726158356585074, 0.01801594284188468, 0.04180511925369501, 0.021712990455853287, 0.06272888946114108, 0.027849338330270257, 0.026827319343283307, 0.1737511539249681, 0.1548524820827879, 0.21881669119466096, 0.24621550692245364, 0.10762464560684748, 0.11807393646449782, 0.12776563555235043, 0.1697990988031961, 0.18760411214316264, 0.15783883980475366, 0.12127590292948298, 0.24369952239794657, 0.12883504066849127, 0.14999196399003267, 0.13894015311961994, 0.14891224302118644, 0.21429181681014597, 0.13336613425053656, 0.19777512730797753, 0.07208655530121177, 0.13909910630900413, 0.23343388340435922, 0.17035991011653095, 0.09074959525605664, 0.16691986267687753, 0.12305892756558023, 0.14080279535846785, 0.12255866808118299, 0.10315678300685249, 0.1043962586845737, 0.2153412433108315, 0.23272295045899227, 0.07812149240635335, 0.1150661232532002, 0.0924196575942915, 0.15308490896131843, 0.05640739058435429, 0.1896989278611727, 0.08622941124485806, 0.13239142717793584, 0.13855487457476556, 0.1526474129059352, 0.08278502224129625, 0.1735236114473082, 0.19423717574682087, 0.21044287568656728, 0.16010987106710672, 0.1820461533498019, 0.10805719895870425, 0.13566665846155956, 0.13158543995814398, 0.10828936501638964, 0.08375748060643673, 0.24920864787418395, 0.10940937718260102, 0.19197990390239283, 0.17291714320890605, 0.12463864084566012, 0.20240651472704485, 0.14665832568425685, 0.1465373407700099, 0.07714141960605048, 0.1295553395175375, 0.14368032454513013, 0.12710038921795785, 0.11811044270871207, 0.14700989588163793, 0.11736494052456692, 0.206255663651973, 0.1863619202049449, 0.0844450804288499, 0.1575408229837194, 0.18784660147503018, 0.18014122353633866, 0.07370345017989166, 0.14538129733409733, 0.13859857222996652, 0.15478849411010742, 0.14391715871170163, 0.18967664858791977, 0.25027425319422036, 0.11377866772818379, 0.1517337400582619, 0.1721478477702476, 0.23216616158606485, 0.12896263069706038, 0.11362794495653361, 0.16478777630254626, 0.0976662260654848, 0.17020915023749694, 0.21113014896400273, 0.13280150829814374, 0.28740372334141284, 0.2497043728362769, 0.12058004300342873, 0.13203660637373105, 0.15961990517098457, 0.10591877464321442, 0.13027654378674924, 0.12470820976886898, 0.15465122647583485, 0.13224179536337033, 0.11124443379230797, 0.08019339060410857, 0.16212362941587344, 0.12044487564708106, 0.11302125407382846, 0.11579695317777805, 0.10247244863421656, 0.13742140727117658, 0.09445663774386048, 0.09603085913113318, 0.08737346157431602, 0.20410128316143528, 0.1332057116087526, 0.17148795974208042, 0.20984544680686668, 0.07637785354745574, 0.11093460940173827, 0.09460356071940623, 0.11854900003527291, 0.24247545370599255, 0.1530704222386703, 0.08325565519044176, 0.0990152575832326, 0.1292218777234666, 0.11961579279159196, 0.1604023069376126, 0.11049614113289863, 0.06620053012738936, 0.11495529834064655, 0.14294503431301564, 0.0897493954107631, 0.226413908530958, 0.10405143460957333, 0.10150481422897428, 0.11306274012895301, 0.07844148422009312, 0.13576767960330471, 0.1478203063015826, 0.1647036909707822, 0.1112444931641221, 0.1125522909569554, 0.09335595852462575, 0.1519465583260171, 0.11718387875589542, 0.07579303375678137, 0.18341520801186562, 0.1383054387406446, 0.16347392258467153, 0.14266922255046666, 0.09412778468686156, 0.15161419491050765, 0.15823281632037833, 0.08818404268822633, 0.13768518139841035, 0.08600609900895506, 0.11157110493513756, 0.18279958167113364, 0.10639405343681574, 0.12741222482873127, 0.11403261582017876, 0.17033173819072545, 0.1784588341251947, 0.17696370341582224, 0.09429485697182827, 0.11272744523012079, 0.07574343602755107, 0.12402350432239473, 0.19216064654756337, 0.2047553230659105, 0.16382700676331297, 0.1759991340804845, 0.15000113693531603, 0.16687558614648879, 0.09218317223712802], [0.07354769564699382, 0.03604775651183445, 0.056857165473047644, 0.027644668844004627, 0.04561887515592389, 0.017766662858775817, 0.011058106138079893, 0.041992890037363395, 0.06235997527255677, 0.03776202858716715, 0.057672908224049024, 0.00863809615111677, 0.009277664175897371, 0.044447150139603764, 0.0597873537481064, 0.005368448601075215, 0.0319007985672215, 0.023757564631523564, 0.03130257558950689, 0.011486847633932484, 0.033355816194671206, 0.03377103668753989, 0.04419248587510083, 0.07263551451615058, 0.040216077177319676, 0.05680879228748381, 0.0363376950554084, 0.06960821992834099, 0.0649962990428321, 0.014142534037091536, 0.018679725289985072, 0.028886306026834063, 0.022102614275354426, 0.029187282161728945, 0.0249530569271883, 0.03474577715678606, 0.028348818559607025, 0.03291529217676725, 0.04959481258993037, 0.012799881278624525, 0.03674197258078493, 0.024788548762444407, 0.06349097122438252, 0.05347349899238907, 0.03846018546028063, 0.021676647484127898, 0.01517494309155154, 0.021523432951653376, 0.030794517988397274, 0.03996381376055069, 0.04977775570296217, 0.025515280176477972, 0.009972075986297568, 0.04944281703501474, 0.05542441227589734, 0.04329842056904454, 0.0410085498879198, 0.006597348674404202, 0.029019497414992657, 0.04470280517125502, 0.009239950086339377, 0.027562349823710974, 0.03591749475162942, 0.037372786973719485, 0.04635009099729359, 0.05519869548152201, 0.02582642002380453, 0.00565221201213717, 0.0749118001840543, 0.050329690930084325, 0.025214552661054768, 0.02503701423847815, 0.06289282988291234, 0.03486683628580067, 0.033296036199317314, 0.03202227329893503, 0.08663002998218872, 0.036822503025177866, 0.01744785848131869, 0.04035140409541782, 0.08883168527972884, 0.09276922399294563, 0.026906003695330583, 0.03846363273623865, 0.05166527473193128, 0.011539869447005913, 0.022270350782491732, 0.06928572707693093, 0.009698457270133076, 0.024129766534315422, 0.05963212242932059, 0.02718425155762816, 0.055593503202544525, 0.0018521437482377223, 0.029565142940555234, 0.015094215978024295, 0.021337638136174064, 0.03231892827898264, 0.0320563638524618, 0.02414436086837668, 0.042586118361214176, 0.022880876713315956, 0.06810393853811547, 0.04721169105323497, 0.020957894157618284, 0.0670120760332793, 0.04915001380140893, 0.040256954671349376, 0.056065579628921114, 0.0426886720379116, 0.028442991533665918, 0.054541761201107875, 0.016626532924419735, 0.021235093736322597, 0.044106367058702745, 0.070640183694195, 0.04149059335759375, 0.06438999407691881, 0.032382693607360125, 0.01890392439236166, 0.031934785220073536, 0.024399140165769495, 0.06002260714012664, 0.03686868316435721, 0.018226391803182196, 0.05238162164459936, 0.006656133264186792, 0.009656045385781908, 0.015105359325389145, 0.04647203328204341, 0.047191426710924134, 0.06527278615976684, 0.028304037368798163, 0.03609512779803481, 0.04049972973007243, 0.07523555468651466, 0.020858229290752206, 0.05407893935625907, 0.0645530216570478, 0.019759000970225316, 0.05845628220413346, 0.010538712231209502, 0.011134337692055851, 0.018528008040448185, 0.02736411290243268, 0.04805765776836779, 0.07185651920735836, 0.10864792624488473, 0.03986914911365602, 0.03204958433343563, 0.007195033131210948, 0.004715952363767428, 0.03097717166383518, 0.041752690231078304, 0.055320815881714225, 0.029545095676439814, 0.07273206792888232, 0.021787398181913886, 0.022852370821055956, 0.014527754137816373, 0.10550223683821969, 0.00734773419026169, 0.030531896045431495, 0.024173156198230572, 0.022712604004482273, 0.08096707955701277, 0.09081973563297652, 0.03037756643607281, 0.03768995120481122, 0.01568828200106509, 0.04484953518840484, 0.007453653970515006, 0.003084696695623279, 0.009267690638807835, 0.03500546947179828, 0.06235118824406527, 0.024113442996167578, 0.011093949087808141, 0.0401395172229968, 0.053572542310575955, 0.011973254931945121, 0.04110373403818812, 0.04229861777275801, 0.06706333617330529, 0.01707635234197369, 0.011397852995287394, 0.0390673587389756, 0.05871490953722969, 0.062364977347897366, 0.08219544528401457, 0.03845860839646775, 0.06766707330825739, 0.03460035331954714, 0.04914791352348402, 0.034100706106983125, 0.012237544851814164, 0.013747814446105622, 0.0394857185165165, 0.02797920304146828, 0.03200176033715252, 0.04168634222878609, 0.06418619290343486, 0.0357007393904496, 0.047124247503234074, 0.04243253461027052, 0.03967916301917285, 0.03134044738544617, 0.03204471584467683, 0.037507364322664216, 0.026279261837771628, 0.050723789900075644, 0.02469255938194692, 0.033856353984447196, 0.015037569701235043, 0.042693046998465434, 0.013025237203692086, 0.02218944555352209, 0.04239935318764765, 0.059743993770098314, 0.011449817247921601, 0.02411845991446171, 0.020618244707293343, 0.05290893983328715, 0.033114996695076115, 0.03864997488562949, 0.020674685038102325, 0.02628837726661004, 0.07200467414804734, 0.04191946194623597, 0.004327189899413497, 0.0658245878003072, 0.05824242492963094, 0.032305038985214196, 0.04145946768403519, 0.045547057525254786, 0.04270062803698238, 0.042507773541728966, 0.023930677998578176, 0.022247848864935804, 0.0336746502580354, 0.04940973209158983, 0.03774254349991679, 0.04109791560040321, 0.010794417357828934, 0.014209448854671791, 0.04105221785721369, 0.017640898513491265, 0.03680049834656529, 0.05003899168514181, 0.11290429159998894, 0.056587624858366325, 0.024361350006074645, 0.014544530386046972, 0.04051311807415914, 0.025515671659377404, 0.07408177480101585, 0.018269093125127256, 0.059508042759262025, 0.025615455269871745, 0.04988289947505109, 0.04872507488471456, 0.0740353534638416, 0.023381759601761587, 0.07411634403979406, 0.016431791518698446, 0.08379516686545685, 0.04383525680168532, 0.12918638822156936, 0.03551176632754505, 0.03585742160794325, 0.0067716286048380425, 0.01900238697999157, 0.05743438196077477, 0.020788189103768673, 0.0018895999414780817, 0.01537144153189729, 0.05088661338959355, 0.032521597677259706, 0.060782310320064425, 0.03296040362329222, 0.05771331074356567, 0.08708857334568165, 0.04115972536965273, 0.054317870090017095, 0.0068198927874618676, 0.020388870980241336, 0.06863137547043152, 0.06095858523622155, 0.19483706855680794, 0.03519268735544756, 0.03215026037651114, 0.014699953735544113, 0.08998726116260514, 0.0801737756410148, 0.03141556757327635, 0.015037191205919953, 0.041718035645317286, 0.05472054828715045, 0.0831349597137887, 0.05327408762241248, 0.09717141394503415, 0.004914036217087414, 0.038054045144235715, 0.027872639911947772, 0.009592879341653315, 0.03773238720896188, 0.05561594574828632, 0.04281236950191669, 0.029381565291259903, 0.046269660742837004, 0.05849631364981178, 0.05719385189877357, 0.053905143213341944, 0.04994371847715229, 0.06269869889365509, 0.04048169183079153, 0.09040324235684238, 0.019496471795719117, 0.0618312136066379, 0.0774480750260409, 0.014989960927778156, 0.04358992133347783, 0.06551376893185079, 0.0017604886261324282, 0.0563090782816289, 0.02383215047302656, 0.06911625023349188, 0.012048104235873325, 0.01745040590321878, 0.027250577295490075, 0.033182784463861026, 0.024648609396535903, 0.07850320864235982, 0.058116115105804056, 0.06884129194077104, 0.015370120509032859, 0.05102527626149822, 0.05602294324489776, 0.02176475896703778, 0.09614753958885558, 0.08709993562661111, 0.07410256235743873, 0.03910780949809123, 0.0577023269579513, 0.023129498040361796, 0.019086889769823756, 0.046171841968316585, 0.018770924107229803, 0.026122060116904322, 0.018535590934334323, 0.00464262446257635, 0.02749187362496741, 0.07675299435504712, 0.14329264144180343, 0.1049300780869089, 0.12427953784936108, 0.13150665356079116, 0.11700765579007566, 0.18202500214101747, 0.1559956418350339, 0.19453857676126063, 0.1212675315036904, 0.15021490515209734, 0.15318671677960083, 0.24755207035923377, 0.1504387814202346, 0.10946680456981994, 0.20618423935957253, 0.08175951516022906, 0.07817419231287204, 0.11260151761234738, 0.13303699175594375, 0.1326232444262132, 0.09473429003264755, 0.22051257285056636, 0.1598852823371999, 0.12749075889587402, 0.11528331277077086, 0.1810766858397983, 0.235430320026353, 0.15689545136410743, 0.058924258264596574, 0.1355264222365804, 0.09815689700189978, 0.15286827605450526, 0.12370674085104838, 0.17998112743953243, 0.1158074768318329, 0.12380437779938802, 0.11487673458759673, 0.17416012182366103, 0.09755336766829714, 0.08875948915374465, 0.17526638199342415, 0.13578071171650663, 0.168959878210444, 0.15529958152910694, 0.09063256598892622, 0.1397997234016657, 0.12083980211173184, 0.08693385781953111, 0.10684389882953838, 0.13367327948799357, 0.2490521437721327, 0.1851899057510309, 0.19020146573893726, 0.12401283966028132, 0.22559966862900183, 0.15033050207421184, 0.11864121188409626, 0.1486691302852705, 0.13736329710809514, 0.12404413602780551, 0.13509824755601585, 0.13554130971897393, 0.12678755912929773, 0.11597195159993134, 0.21530177589738742, 0.2222176274517551, 0.11778645814047195, 0.12808662926545367, 0.15269409399479628, 0.06226765952305868, 0.09512620337773114, 0.13160332571715117, 0.242620098288171, 0.20099901681533083, 0.09811216033995152, 0.1597774779656902, 0.1450595466303639, 0.09959350194549188, 0.19190206745406613, 0.13745091506280005, 0.20674846455221996, 0.11987639052676968, 0.10064275775221176, 0.11465401606983505, 0.1332597399596125, 0.1099565923504997, 0.1695460412884131, 0.06364363842294551, 0.17151825421024114, 0.15851201227633283, 0.15032587107270956, 0.12738473567878827, 0.0971348631719593, 0.16221748141106218, 0.0943310144066345, 0.11234759920625947, 0.11239355299039744, 0.10520696596358903, 0.13316260767169297, 0.1835094904527068, 0.18226139101898298, 0.18569049920188263, 0.09297387121478096, 0.09787911112653092, 0.12907634256407619, 0.13077501469524577, 0.13423567899735644, 0.17296956852078438, 0.12180083882412873, 0.1255628076614812, 0.25385300803463906, 0.40847864525858313, 0.12399804123560898, 0.10314358762116171, 0.23506819648901, 0.14854418230243027, 0.17186514887725934, 0.1683277465053834, 0.07503678527427837, 0.2523346629459411, 0.11346927378326654, 0.20618713373551145, 0.3014627908123657, 0.20618680719053373, 0.19619874627096578, 0.1446560409385711, 0.1212886901339516, 0.12269927538000047, 0.19556505605578423, 0.14337797358166426, 0.10052584722870961, 0.09864534149528481, 0.1785078752436675, 0.13590763381216675, 0.20092109130928293, 0.09004036182886921, 0.14205289859091863, 0.19556587241822854, 0.0877139663498383, 0.15605501364916563, 0.10216499169473536, 0.13341891579329967, 0.12845243385527283, 0.1539175392827019, 0.18996166298165917, 0.12243901161127724, 0.1730576911359094, 0.1765673965564929, 0.15604414860717952, 0.1408903390984051, 0.08410542912315577, 0.16466928500449285, 0.08548368641640991, 0.12760732060996816, 0.08289759120089002, 0.18640453432453796, 0.105886023666244, 0.17690422770101577, 0.11291850372799672, 0.2812001999700442, 0.12231189655722119, 0.18285473808646202, 0.14174230978824198, 0.15883542539086193, 0.21606782072922215, 0.11773291218560189, 0.17389746091794223, 0.15486554388189688, 0.06336751495837234, 0.1523315251688473, 0.09071518186829053, 0.06940274892258458, 0.10564458818407729, 0.13526414724765345, 0.13240131258498877], [0.026478456129552796, 0.0549251472693868, 0.07304161772481166, 0.03564078127965331, 0.032488568394910544, 0.016687615388946142, 0.028051881563442294, 0.06486286089057103, 0.0261768194832257, 0.04454600049939472, 0.03702508707647212, 0.04392369111883454, 0.042759272546391, 0.05232823525147978, 0.013408412687567761, 0.055539337554364465, 0.08542657073121518, 0.0581236738798907, 0.0473376594891306, 0.05228470829024445, 0.056307924241991714, 0.08051962387980893, 0.04245687334332615, 0.08411607152083889, 0.019098053526249714, 0.02517787757824408, 0.09008660505060107, 0.044269632126088254, 0.04456505514099263, 0.05077539142803289, 0.05685512827767525, 0.03860961318423506, 0.04594642945448868, 0.02970871140860254, 0.03492224132060073, 0.04073242271260824, 0.01517904438514961, 0.049687907594488934, 0.05132668469741475, 0.028328743464953732, 0.04132438938540872, 0.07255969670950435, 0.04947381283272989, 0.06139016266388353, 0.053817940861335956, 0.06607247254578397, 0.028061152843292803, 0.04481618678255472, 0.05437572421215009, 0.013053436032350874, 0.08209011968574487, 0.004367476922197966, 0.0458527629962191, 0.013473981434799498, 0.03862584024318494, 0.03504894448269624, 0.006606166780329659, 0.03747143695363775, 0.0945799975306727, 0.08525568380719051, 0.03936905661248602, 0.043014415496145375, 0.03366545875906013, 0.019761900912271813, 0.04086702974746004, 0.06984307256061584, 0.023601815664733294, 0.0893785516382195, 0.048693889839341864, 0.07125434058252722, 0.04179517818556633, 0.027792495384346694, 0.06404418294550851, 0.030787658688495867, 0.017665051709627733, 0.04195088447886519, 0.04369159556517843, 0.048213839036179706, 0.04613547302142251, 0.03475506884569768, 0.016957931547949556, 0.0446714494319167, 0.03960309659305494, 0.05291932247928344, 0.032355475341319107, 0.029952484655950684, 0.02664293089765124, 0.025332266559416894, 0.03374863495992031, 0.01834653623518534, 0.029275458582560532, 0.06835034640971571, 0.03561971170711331, 0.07705212439759634, 0.0371565548266517, 0.023744532518321648, 0.015263665918610059, 0.014255847927415743, 0.08648342613014393, 0.03376636857865378, 0.04316906051826663, 0.032155177104868926, 0.04890743912255857, 0.026200523680017795, 0.015095928483788157, 0.061369178438326344, 0.017228320066351444, 0.01995143058593385, 0.03308072431536857, 0.03841712976281997, 0.059584309565252624, 0.016270632295345422, 0.027267572477285285, 0.030242285902204458, 0.019796316155407112, 0.03169716437696479, 0.0806953570281621, 0.023330358453677036, 0.04063585445692297, 0.005104707870486891, 0.021097707358421758, 0.028639399060921278, 0.055265065748244524, 0.013995652807352599, 0.053253860387485474, 0.06349327930365689, 0.06593914571567439, 0.05494481047207955, 0.02093092265567975, 0.020331640262156725, 0.028652147302636877, 0.02949526417069137, 0.014102692766755354, 0.02723855821386678, 0.12862545816460624, 0.04654085263609886, 0.07264119936735369, 0.017738398164510727, 0.0492925506841857, 0.040980029152706265, 0.04648019319574814, 0.025463036690780427, 0.08748935535550117, 0.04605300186085515, 0.06391152404830791, 0.03624004697485361, 0.020907619218633045, 0.07992750877747312, 0.04723459744127467, 0.05252067785477266, 0.06790066428948194, 0.06728793232468888, 0.029735686621279456, 0.030194838545867242, 0.00995120308289188, 0.1325728080701083, 0.09872080307104625, 0.017617487465031445, 0.051786389522021636, 0.012191043733764673, 0.043536193552426994, 0.06850358506198972, 0.07987178832991049, 0.016166449604497757, 0.08787071536062285, 0.017650993577262852, 0.055352019480778836, 0.06269498815527186, 0.03146971095702611, 0.07442296235240065, 0.012798700336134061, 0.01883580636786064, 0.014977341634221375, 0.015508810283790808, 0.012638214611797594, 0.04930597613565624, 0.0007573513255465514, 0.0314736517611891, 0.07187975585111417, 0.026591937930788845, 0.07789620605763048, 0.004860107128479285, 0.0389360060216859, 0.038667229819111526, 0.020007733619422652, 0.05083984695374966, 0.03394387545995414, 0.09065028847544454, 0.031067390846146736, 0.07591787783894688, 0.04802959716471378, 0.09408830243046395, 0.05246020024060272, 0.04471037507755682, 0.05598423282208387, 0.025513242981105577, 0.04902336630038917, 0.035455474426271394, 0.015404690675495658, 0.03187495698512066, 0.02069495865725912, 0.0319969178235624, 0.023493243170378264, 0.09261235623853281, 0.05918470385950059, 0.05613471810647752, 0.05834985822730232, 0.06993345872615464, 0.05096364089695271, 0.00667273928229406, 0.07952861924422905, 0.050304892065469176, 0.04581987843266688, 0.08749774162424728, 0.021848918513569515, 0.03521144142723642, 0.05411339727288578, 0.03915649438567925, 0.024234426055045333, 0.039741221407894045, 0.026639255411282647, 0.022790913571952842, 0.07971236758749001, 0.07190279211499728, 0.04474802051845472, 0.020190268551232293, 0.1184478378854692, 0.06269545570830815, 0.06109847636253107, 0.03971356156398542, 0.08242549622082151, 0.05419269946287386, 0.023169291998783592, 0.03388713455933612, 0.06257676403038204, 0.022458212479250506, 0.022100801579654217, 0.04694199458754156, 0.027235832676524296, 0.038472234227810986, 0.018750708004517946, 0.13639847544254735, 0.027234211083850823, 0.05666629993356764, 0.02125281807821011, 0.06818265072070062, 0.05436574232589919, 0.04004296009952668, 0.03323206306959037, 0.03364334646903444, 0.0808580729062669, 0.02001561522774864, 0.026972828527505044, 0.05659470865793992, 0.014257492712204112, 0.03580194606911391, 0.04029188756248914, 0.048677377053536475, 0.09308834749390371, 0.019723366749531124, 0.03247414104407653, 0.026435361469339114, 0.014054874336579815, 0.016878848291526083, 0.046363820729311556, 0.021532316459342837, 0.05970719808829017, 0.08004628951312043, 0.03666771328425966, 0.05942793533904478, 0.02350659626245033, 0.02207298959547188, 0.014748846424481599, 0.054787308181403205, 0.035859399431501515, 0.015675782378821168, 0.03877251088852063, 0.08774305853876285, 0.05349680985091254, 0.05222053478064481, 0.036972513335058466, 0.030983225733507425, 0.029955113714095205, 0.00680222874507308, 0.026824139240488876, 0.026427717348269653, 0.05584725833614357, 0.06006976320350077, 0.043584210507106036, 0.00832887753858813, 0.07908195024356246, 0.05279996657918673, 0.027122887076984625, 0.0288734613059205, 0.09426425822312012, 0.02484953660314204, 0.017482763541920576, 0.056322845121030696, 0.03487189031147864, 0.04496431203733664, 0.0646755650814157, 0.029420186656352598, 0.014677278340968769, 0.03905962184944656, 0.04362233834399376, 0.0060706024032697314, 0.03451271310041193, 0.029190952081989963, 0.04824240801099222, 0.00928144449062529, 0.08391132781980559, 0.03869008054607548, 0.06691076545394026, 0.00802639391622506, 0.04352235249825753, 0.05806260625831783, 0.012433296506060287, 0.054354179665097035, 0.03175104800902773, 0.038636081881122664, 0.012652413752221037, 0.04156132745265495, 0.048157595374505036, 0.010700514339987421, 0.03208063208148815, 0.032828126932145096, 0.013939558502897853, 0.05672874794981908, 0.020568580184772145, 0.06614147743675858, 0.060511185220093466, 0.05872051646292675, 0.04141772929870058, 0.03547152708051726, 0.010998865127476165, 0.00892263278728933, 0.02860452739696484, 0.07417440225253813, 0.06221087780431844, 0.007270816613527131, 0.03055346656765323, 0.030305080872494727, 0.019798648354480974, 0.03838339544017799, 0.06817546673119068, 0.04688506443926599, 0.05623480785288848, 0.02942414972494589, 0.029519768031605054, 0.025832843311945908, 0.016403580630139913, 0.061856372412876226, 0.09559811282088049, 0.1922846000525169, 0.1670779549749568, 0.14009958074893802, 0.14884442556649446, 0.10877904889639467, 0.07926067424705252, 0.1747323028394021, 0.11004629574017599, 0.1092363528732676, 0.12112198150134645, 0.21240532194497064, 0.16574718029005453, 0.14968422503443435, 0.13999847054947168, 0.19192649895558134, 0.23641679756110534, 0.10045842311228625, 0.10601701273117214, 0.15812894533155486, 0.1324387761997059, 0.14512081834254786, 0.16073839593445882, 0.26417447137646377, 0.1405759950284846, 0.059162680627196096, 0.12889677251223475, 0.19866082118824124, 0.16654153063427657, 0.18164509674534202, 0.10317020103684627, 0.13239485590020195, 0.15471297316253185, 0.09230985684553161, 0.18298544513527304, 0.16278547671390697, 0.07586455452837981, 0.12195778079330921, 0.1377705135382712, 0.09750486831762828, 0.1248401339398697, 0.2355197339784354, 0.16756493743741885, 0.1521599554689601, 0.15399580617668107, 0.13604634121293202, 0.21457619295688346, 0.15665158163756132, 0.14565402176231146, 0.08700351580046117, 0.2378479254548438, 0.14372387377079576, 0.15252250945195556, 0.1530940373777412, 0.15797321306308731, 0.10734023235272616, 0.14160363207338378, 0.19752952095586807, 0.248133335262537, 0.15563240507617593, 0.11542579770321026, 0.11704226955771446, 0.12166202752268873, 0.23509366699727252, 0.10765829458250664, 0.16364286508178338, 0.115978445392102, 0.1758247590623796, 0.12810947257094085, 0.17224450508365408, 0.15608780173351988, 0.11699940310791135, 0.12578414578456432, 0.11426157579990104, 0.1778448701952584, 0.22830726084066555, 0.1069394354999531, 0.14472948387265205, 0.1186347626207862, 0.15993000415619463, 0.13590678776381537, 0.20988613134250045, 0.12958876584889367, 0.17634092277148739, 0.09292053306126036, 0.15042448765598238, 0.09153838691418059, 0.18578018032712862, 0.13815999263897538, 0.04650210510590114, 0.12754512863466516, 0.21977133059408516, 0.1971524060354568, 0.21062859072117135, 0.1878844213206321, 0.1316476467764005, 0.06354668425046839, 0.1272403879556805, 0.16135653073433787, 0.1111320652125869, 0.17969655833439901, 0.1202721927256789, 0.14401081774849445, 0.16901856724871323, 0.14720706967636943, 0.13168042001780123, 0.12778708362020552, 0.12438918274710886, 0.10948475712211803, 0.10316948857507668, 0.15118545619770885, 0.13091412285575643, 0.14242630277294666, 0.11366839200491086, 0.1327787688933313, 0.13208729506004602, 0.18622493458678946, 0.09128677658736706, 0.20738564286148176, 0.0688106709276326, 0.0844786106608808, 0.1844136934960261, 0.1127232817816548, 0.15267570357536897, 0.16131924523506314, 0.09928905812557787, 0.12710984417935833, 0.17329403548501432, 0.10504278805456124, 0.10066248403745703, 0.10183108461205848, 0.05051191787060816, 0.1289608346996829, 0.10394459503004327, 0.24826288456097245, 0.1781882470822893, 0.15076917072292417, 0.06984040825045668, 0.11116259716800414, 0.20343339478131384, 0.15640947822248563, 0.19910723785869777, 0.1493368999217637, 0.2959953888785094, 0.14558929164195433, 0.13551138632465154, 0.10531100022490136, 0.17487429053289816, 0.24296728981425986, 0.1779819597140886, 0.12872302089817822, 0.17834648780990392, 0.14697397593408823, 0.17163192154839635, 0.18852453853469342, 0.18153767829062417, 0.1958990076673217, 0.0996809195203241, 0.13415905967121944, 0.12327335629379377, 0.15116233087610453, 0.17167924088425934, 0.15746067103464156, 0.11294148804154247, 0.14584322489099577, 0.2121076316689141, 0.21826539421454072, 0.11211521792574786, 0.1421436929376796, 0.17170484497910365, 0.11170343728736043, 0.0874103834212292, 0.08813923923298717, 0.0923994043841958, 0.06610566881136037, 0.11205120768863708], [0.040449434382026084, 0.0392409841879271, 0.026037395909952465, 0.053339493097155355, 0.061303490947466344, 0.06732812704285607, 0.03766106681723613, 0.04080103797605261, 0.04879970154433977, 0.02579738720669411, 0.031418881262652576, 0.03542295722581912, 0.01874162411695579, 0.021261822184897028, 0.029191966968937777, 0.022211973446246702, 0.005436782776087057, 0.006934321754670236, 0.045677237649215385, 0.021243162736936938, 0.027261019313300494, 0.03314082343422342, 0.010563406267465325, 0.027824442986457143, 0.017682512589090038, 0.02223641236923868, 0.10867781253182329, 0.035670300203491934, 0.04632594151189551, 0.036201722468831576, 0.05601542899967171, 0.051369506618357264, 0.05378365363867488, 0.03467883914709091, 0.055209133788594045, 0.004822515493287938, 0.041874736416502856, 0.028389901999616995, 0.03335387918923516, 0.02910185168730095, 0.04131106412387453, 0.06404098428902216, 0.040459831870975904, 0.04559279608656652, 0.10521202741074376, 0.019983936654170975, 0.07600151788210496, 0.006327897117444081, 0.06831396633060649, 0.05131584191985894, 0.028639822085096966, 0.06529116173624061, 0.0043300156266923295, 0.07400301066809334, 0.022693961254844908, 0.014292036903498229, 0.04053071439557243, 0.053936369076836854, 0.039278956173802726, 0.07341992750298232, 0.0705533375730738, 0.06329397554509342, 0.009111820145335514, 0.049910678062587976, 0.02748110877291765, 0.082770824956242, 0.14822833909420297, 0.05333345943654422, 0.0180220470065251, 0.035697039784281515, 0.059568806100287475, 0.10162848571781069, 0.07655944966245443, 0.04096934964763932, 0.03945004347770009, 0.031792645386303775, 0.036586492642527446, 0.07411914193653502, 0.04978299897629768, 0.03424005175475031, 0.033499202836537734, 0.05087629382614978, 0.06870616911328398, 0.007780301921229693, 0.07041043703793548, 0.019700530865520705, 0.02020216332311975, 0.027825524666695856, 0.0019726403525055503, 0.02007247672736412, 0.07181841734563932, 0.08093924901913851, 0.09223291839589365, 0.032483013419550844, 0.015441315663338173, 0.01889249346277211, 0.04509080739808269, 0.04945996806782205, 0.07438166183419526, 0.03129313547105994, 0.06309094620519318, 0.09132911611231975, 0.06075386751035694, 0.05779182996775489, 0.05529989102797117, 0.08746510939090513, 0.060122626382508315, 0.07221383362775669, 0.05650759536365513, 0.028547003530547954, 0.07018277581664734, 0.09328566229669377, 0.053274172969395295, 0.05156951541721355, 0.02264601665956434, 0.027469124943308998, 0.0580568583245622, 0.009455888157390291, 0.046601756985182874, 0.02117970539984526, 0.07011455760220997, 0.06130682319053449, 0.005440060285764048, 0.049300521350232884, 0.010981597206409788, 0.03500961065583397, 0.043990243211737834, 0.1110425622027833, 0.07208437338704243, 0.02266066294396296, 0.054310548803186975, 0.03345956101838965, 0.019358634563104715, 0.07003817576332949, 0.03522735307342373, 0.04596542472427245, 0.009486644612479722, 0.018572627814137377, 0.07726412630290724, 0.014285783381637884, 0.0468071352224797, 0.08120504920952953, 0.03567545070836786, 0.013581578932644334, 0.030182346345100086, 0.010319416869606357, 0.10406072629848495, 0.0131184537349327, 0.07043535835691728, 0.01899119724839693, 0.02068401940050535, 0.04218449401378166, 0.059414446805021726, 0.02525432064430788, 0.0325353867810918, 0.03112301852524979, 0.08011015132069588, 0.041800339822657406, 0.03750947202206589, 0.04476693044125568, 0.05188457937038038, 0.04383186147606466, 0.02990049535583239, 0.04527940938714892, 0.0616125509259291, 0.012682626584137324, 0.07685662785661407, 0.04205697819998022, 0.008096666952042142, 0.07291635803994723, 0.04710708904895, 0.07267150867846794, 0.023957773810252547, 0.00453831235972757, 0.04883011104539037, 0.045346584884100594, 0.029704104526899755, 0.0388335785100935, 0.02621123658173019, 0.033708855844452046, 0.05481530199176632, 0.05150137883902062, 0.040668219517101534, 0.017052740913641173, 0.018871813517762348, 0.10343861358705908, 0.038715220798621885, 0.030837369595246855, 0.01884357294329675, 0.022966746910242364, 0.03053736567380838, 0.0434090005728649, 0.03287231069407426, 0.03276007199019659, 0.03858350442897063, 0.03479940103716217, 0.026538883648754563, 0.01492721605245606, 0.07335933856666088, 0.023866595402068924, 0.04343667525972705, 0.04321381202316843, 0.07041904595098458, 0.02441681997879641, 0.03011134878761368, 0.022446508810389787, 0.0875949407054577, 0.0318895772943506, 0.012180521935079014, 0.05285766485030763, 0.013527833525586175, 0.03918750131560955, 0.01406298229994718, 0.027013880426238757, 0.06836256216047332, 0.06867262403829955, 0.03015803358721314, 0.01844669648562558, 0.021419647309812717, 0.051570840150816366, 0.05532195507839788, 0.029206863728177268, 0.018942222923215013, 0.03621462470619008, 0.08244165277574211, 0.0864074524724856, 0.0175109762858483, 0.04891476783086546, 0.05192900433030445, 0.015294305485440418, 0.03610066793044098, 0.0368149479618296, 0.010253495602228213, 0.07507051588618197, 0.027986587410850916, 0.06307010669843294, 0.07025792569038458, 0.01193359270473593, 0.029000053145864513, 0.04935271659633145, 0.039596179776708595, 0.026673028696677648, 0.12793770991265774, 0.054346342585631646, 0.00895975037565222, 0.03103537645074539, 0.05350686224119272, 0.06893990110256709, 0.03255565854487941, 0.010305347605026327, 0.12047695126966573, 0.006792664316890296, 0.03757205362489913, 0.09454632629058324, 0.022928409416635986, 0.033022870193235576, 0.03178661543643102, 0.04329384522861801, 0.10830525439814664, 0.04158985189860687, 0.027686917455866933, 0.04790251550730318, 0.07084730226779357, 0.03978256274422165, 0.013663590889336774, 0.05553357848839369, 0.12380644839140587, 0.07263757768669166, 0.04331700023612939, 0.022047417041903827, 0.0243097707425477, 0.06800412709708326, 0.03381847476703115, 0.01663157767325174, 0.04411464942677412, 0.07109126847353764, 0.02063538646325469, 0.04816113541892264, 0.07006940533756278, 0.0060164747901580995, 0.047514977122773416, 0.06591570869204588, 0.06395850941771641, 0.062040959383011796, 0.050033789229928516, 0.10352105877245776, 0.016468661415274255, 0.06124266823462676, 0.04378975572763011, 0.06449619540944695, 0.019208991616324056, 0.02792223764117807, 0.07662303687538952, 0.03721525499713607, 0.04053158270835411, 0.006393963103619171, 0.11953267967328429, 0.09188983094645664, 0.05381703915190883, 0.030938366617192514, 0.017937405064003542, 0.09715171734569594, 0.02697782689210726, 0.0346110291138757, 0.0026432767663209233, 0.01586398731888039, 0.044066224290872924, 0.01784038595360471, 0.026134607978747226, 0.07092577696312219, 0.013577923855336849, 0.04055124591104686, 0.020038764669152442, 0.07770622367388569, 0.050739304497255944, 0.05190606083488092, 0.009312915262853494, 0.06084661741624586, 0.054315068482537754, 0.02549327920860378, 0.04417353884491604, 0.02383624898357084, 0.06643132321187295, 0.02803861196298385, 0.10640040622092783, 0.026342364799347706, 0.020801184109586757, 0.01840866512793582, 0.03778827463975176, 0.030283389751275536, 0.028659637428063434, 0.033811884495662525, 0.02136929444532143, 0.030317255805130117, 0.05533565883524716, 0.008106007808237337, 0.03613498483900912, 0.07027845349512063, 0.02689786604605615, 0.058124616407440044, 0.04801473565748893, 0.01599765553692123, 0.05440282002382446, 0.05211758776567876, 0.0502861194399884, 0.02640425991558004, 0.032162394491024315, 0.030607609951402992, 0.006730176874043536, 0.04645263725251425, 0.03121648645901587, 0.0129685983483796, 0.10203944257227704, 0.11764247406972572, 0.18416966049699113, 0.10545275785261765, 0.11185518422280438, 0.20764627028256655, 0.11402483069105074, 0.09691827479400672, 0.08991796683403663, 0.2202540828147903, 0.15854371682507917, 0.15541761269560084, 0.14605727512389421, 0.09322514757514, 0.1156822097254917, 0.14503260666970164, 0.1066422276198864, 0.17628017056267709, 0.13610851834528148, 0.13106250786222517, 0.17899870203109458, 0.09603877042536624, 0.2589665539562702, 0.1291266453335993, 0.12494988273829222, 0.1313515892252326, 0.21829356614034623, 0.09341296288766898, 0.14501843164907768, 0.15418630064232275, 0.1182618853636086, 0.2726148278452456, 0.18142378830816597, 0.18698441883316264, 0.111635189387016, 0.15356202085968107, 0.09644009420298971, 0.12350999008049257, 0.1562045415630564, 0.11149714991915971, 0.11332775364280678, 0.10861776536330581, 0.1041619478201028, 0.16321673872880638, 0.202576718875207, 0.08005861658602953, 0.17502620816230774, 0.13350576191442087, 0.13044367544353008, 0.15154866327065974, 0.14678388222819194, 0.16340190457412973, 0.15911286987829953, 0.14844853430986404, 0.1588551962049678, 0.15563028253382072, 0.11576841017813422, 0.2251511739450507, 0.0775893428362906, 0.19294496305519715, 0.1681971878861077, 0.18003379023866728, 0.08915343598346226, 0.13055023300694302, 0.18887055746745318, 0.3144418552983552, 0.2820470795268193, 0.19725590595044196, 0.08784724865108728, 0.09184961396385916, 0.2139720699051395, 0.18724491266766563, 0.16364148468710482, 0.1205512328306213, 0.1503351776045747, 0.0824224459938705, 0.08735496725421399, 0.15615069132763892, 0.0831784050387796, 0.08896526444004849, 0.15703580633271486, 0.15228275122353807, 0.18267947249114513, 0.22728685231413692, 0.18039917922578752, 0.13748828961979598, 0.11073022193158977, 0.15380753815406933, 0.10438741970574483, 0.15748018951853737, 0.24969573423732072, 0.285581661737524, 0.17280936852330342, 0.14109665615251288, 0.17844963149400428, 0.22796514560468495, 0.142564594571013, 0.17309502116404474, 0.21549602563027292, 0.11694579778122716, 0.10838316506124102, 0.16716266371076927, 0.1770360182854347, 0.12274453896679915, 0.1250136480666697, 0.14802350633544847, 0.2024859987432137, 0.19559981825295836, 0.12471166817704216, 0.23495740868384019, 0.1366809368482791, 0.20485719025600702, 0.10415512006147765, 0.266249070991762, 0.20066329889232293, 0.18046837707515806, 0.1434593871817924, 0.08053247787756845, 0.10915648294030689, 0.1346547104185447, 0.26484038564376533, 0.17930222558788955, 0.10463931204867549, 0.2818702405784279, 0.14068871241761371, 0.165035757527221, 0.14245343569200486, 0.3282261796994135, 0.2083615373703651, 0.1522321515949443, 0.15727780584711581, 0.11041433419450186, 0.1668159174732864, 0.16477370518259704, 0.09473949248786084, 0.1869455599808134, 0.18243840808281675, 0.14646848430857062, 0.22738745785318315, 0.14064442104427144, 0.09516330334008671, 0.1862357254140079, 0.12976272526429966, 0.15689766296418384, 0.19726236263522878, 0.09142415554379113, 0.2079926454462111, 0.1020085766504053, 0.17703861580230296, 0.10095720572280698, 0.06348363138386048, 0.16985713475150988, 0.10575500491540879, 0.07750507938908413, 0.26062575867399573, 0.14891022437950596, 0.20505716936895624, 0.12038796034175903, 0.16782894905190915, 0.14338687935378402, 0.11375231406418607, 0.3166711481753737, 0.11020414312952198, 0.13116421177983284, 0.2303866102010943, 0.12337287087575532, 0.1579233110533096, 0.14428259222768247, 0.14361868175910786, 0.1942308378056623, 0.1482750943978317, 0.1341001776745543, 0.15610310481861234, 0.11744268049369566, 0.1726556252106093, 0.17710972839267924], [0.07856057665776461, 0.05412836639152374, 0.04488026010221802, 0.09319346529082395, 0.03403765324037522, 0.09353214438306168, 0.015157831021497259, 0.05182715940463822, 0.027475997230794746, 0.03309619438368827, 0.024013713191379793, 0.08459728749585338, 0.07132927523343824, 0.06075414581573568, 0.028499199943325948, 0.05586820174357854, 0.015536216869804775, 0.06466215447289869, 0.03662542570964433, 0.05077600741060451, 0.13580748840468004, 0.023073818410921376, 0.02336499634111533, 0.08976832017651759, 0.053559161387966014, 0.046205754406400956, 0.03642356525233481, 0.02854049304005457, 0.02467851238179719, 0.017737813723215368, 0.08611636731075123, 0.00831774532343843, 0.017507718257547822, 0.04251086829754058, 0.017801721915020607, 0.08973019605036825, 0.06024479502229951, 0.013504748094419483, 0.048112791919265874, 0.038417356117861345, 0.05721547066059429, 0.037186938352533616, 0.01429177993486519, 0.027411352457420435, 0.04383038460218813, 0.013007793950237101, 0.03495282893709373, 0.05285045859636739, 0.018627513345563784, 0.04891841177595779, 0.04618390557880048, 0.03177844810124952, 0.020827098051086068, 0.021347872352635022, 0.02468412301823264, 0.007549113179265987, 0.08579295419622213, 0.018434653284202795, 0.0440119621634949, 0.049375103480997495, 0.014070313791307854, 0.0448579771182267, 0.02400856825261144, 0.02300727373949485, 0.051122939185006544, 0.0756406485743355, 0.06216569585376419, 0.03230764021282084, 0.010670354386093095, 0.009367312832182506, 0.05755494756158441, 0.03034469671547413, 0.045061392374918796, 0.004386364116726327, 0.10219780946499668, 0.03937244451662991, 0.014560602521669352, 0.034699222233030014, 0.06857094238512218, 0.03125441762676928, 0.040086056615109555, 0.03937326830055099, 0.04390733789477963, 0.04299237742088735, 0.05965703632682562, 0.04717958203400485, 0.07440653862431645, 0.015580531435261946, 0.034012353426078334, 0.04513641608355101, 0.044369024253683165, 0.04943511354213115, 0.049103688943432644, 0.05792975069198292, 0.023904086847323924, 0.018515753326937556, 0.08260801259893924, 0.04542790942650754, 0.06534459636895917, 0.12029625315335579, 0.0652456161333248, 0.07251870047184639, 0.015184341464191675, 0.05619187460979447, 0.049318919191136956, 0.04188826205790974, 0.0341147660947172, 0.03516188451612834, 0.03656411689007655, 0.019539052518666722, 0.044991470931563526, 0.02493314510502387, 0.07933936416520737, 0.014811233213549713, 0.032415470559499227, 0.05639109673211351, 0.028018406992487144, 0.05473002922371961, 0.018211897659057286, 0.025003958980960306, 0.06186157486808952, 0.010465127361385385, 0.041619493276812136, 0.025259886751882732, 0.06001120033033658, 0.003598582707127207, 0.037931642727926373, 0.08865028212312609, 0.05682610659277998, 0.0049088541709352285, 0.020162393484497443, 0.027726336629712023, 0.02881670370697975, 0.04811190505279228, 0.13593392068287358, 0.03638640591816511, 0.04818685083591845, 0.05742360597650986, 0.007724774432062986, 0.03563141908671241, 0.03838932891085278, 0.12340836037765257, 0.09962773721781559, 0.023202792544907425, 0.04464091747649945, 0.04779411370691378, 0.062009343891986646, 0.019856053477269597, 0.03044667337235296, 0.02458394978020806, 0.03342623487696983, 0.005755861284342245, 0.06930911215022206, 0.014499768676614622, 0.038041558509576134, 0.016283979821309913, 0.03720589280419517, 0.04150852735619992, 0.046250646919361316, 0.03588370105717331, 0.041120436071651056, 0.04928994574584067, 0.04485592507990077, 0.03042998432647437, 0.04296658778912388, 0.028755598978023045, 0.021914476128586102, 0.04735292917757761, 0.02538833210564917, 0.037267784209689125, 0.01671474274189677, 0.024843619830789976, 0.06084371190809179, 0.03189883929735515, 0.04633566735719796, 0.0336331308062654, 0.013499511314876145, 0.01416917342794477, 0.07793166587362066, 0.06769319690647535, 0.02550607568991836, 0.0557120909797959, 0.03630476967373397, 0.03257522897911258, 0.05760399239079561, 0.09581069360137917, 0.0035598052591012674, 0.09067111313925125, 0.015399680250993697, 0.06196914546308108, 0.06045130874554161, 0.06864169132313691, 0.024077808775473386, 0.09318953932961449, 0.04760284740768839, 0.02283180961967446, 0.04182192147709429, 0.10630473596393131, 0.014382264434971148, 0.0327685250522336, 0.018067427481582854, 0.06569221091922373, 0.029605421150336042, 0.01744510511343833, 0.019970978755736724, 0.017399240387021564, 0.02067313023871975, 0.07888403430115432, 0.06158667594718281, 0.019494438311085105, 0.007061473452267819, 0.03728215961018577, 0.08085542343906127, 0.05780927785963286, 0.02911643859988544, 0.061826040837331675, 0.03811782160482835, 0.0313864085910609, 0.002609126840980025, 0.030488183547277004, 0.035164084983989596, 0.05056788693764247, 0.009817936552281026, 0.044737982971128076, 0.0161961856065318, 0.08074710698565468, 0.05849232831678819, 0.027394244098104537, 0.02099229455780005, 0.014070874112803722, 0.0261755355677451, 0.007877748230384896, 0.04618101491359994, 0.046385313326027244, 0.02882343869714532, 0.07514447090215981, 0.01045856399287004, 0.0694898770598229, 0.07125550575437956, 0.13132755848346278, 0.03376717009814456, 0.05377181638323236, 0.028077129427401815, 0.03904084922396578, 0.04975763979018666, 0.0615617138100788, 0.03794468968408182, 0.078010912402533, 0.04690212270361371, 0.06745507882442325, 0.04544279690890107, 0.06050243158824742, 0.07849892645026557, 0.08985763764940202, 0.058579126198310405, 0.03400395602511708, 0.03101379294093931, 0.08140417485265061, 0.056855618095141836, 0.017070435569621623, 0.026053314977616537, 0.011933486948692007, 0.07630789128597826, 0.0082474611554062, 0.017580593448656145, 0.03337128626299091, 0.030835683064651676, 0.04570054850773886, 0.13730944687267765, 0.03782292922551278, 0.04675608659454156, 0.031627072239643894, 0.06585034032468684, 0.013764758605248062, 0.03129716162220575, 0.0143714745354373, 0.055475212284363806, 0.08619899803306907, 0.027324092588969506, 0.03290801541879773, 0.020938709640176967, 0.004446944703886402, 0.022871330838825088, 0.10013331047957763, 0.06745011385646649, 0.02155556794605218, 0.033999191437033005, 0.051101550488965586, 0.04211212719383184, 0.011486893090477679, 0.04774080152856186, 0.05160176915524062, 0.04822172806598246, 0.05182032422453631, 0.0657143714488484, 0.013927599720773287, 0.023244946532940958, 0.0807292212266475, 0.023919950253912248, 0.011210199099878082, 0.03923749609384686, 0.03164046800520737, 0.02018786770349834, 0.053721624935860746, 0.045686933808610775, 0.0476673140656203, 0.03625474149885122, 0.018922082890640013, 0.03263299404352438, 0.055807308526709676, 0.11357544542988762, 0.023742265257169493, 0.017950092078535818, 0.046540900875697844, 0.05892675930226687, 0.03425493181566708, 0.0832838196947705, 0.10766689607407898, 0.03515478587360121, 0.014595266384276329, 0.01952630242158193, 0.06883431575261056, 0.020883139477518853, 0.020143607871432323, 0.018966242532769684, 0.053857508464716375, 0.0386247863934841, 0.01986484792723786, 0.06421482496079989, 0.02158257098926697, 0.047295535187004134, 0.07199469226179644, 0.06429451677831821, 0.03298028947028797, 0.037464568376890384, 0.08071380681940354, 0.038587081580772065, 0.02979045526444679, 0.03280649703810923, 0.03764486944419332, 0.015555651862086961, 0.05823483275889885, 0.019505167911120225, 0.011280018497927813, 0.0443664044723846, 0.01484339603848639, 0.07066658930853009, 0.06632689561229199, 0.035883534073946066, 0.028645098755077925, 0.03916197514627129, 0.04075099866895471, 0.16364290961064398, 0.16017301299143583, 0.14918802509782836, 0.2514483605045825, 0.11503326837555505, 0.14238177391234785, 0.14879538444802165, 0.13971931912237778, 0.07326860359171405, 0.21032197983004153, 0.16123213194077834, 0.18623882759129629, 0.08611029654275626, 0.16867722384631634, 0.12594446452567354, 0.16171702154679224, 0.14332287653815, 0.25241279625333846, 0.10753129085060209, 0.15507307805819437, 0.2840840967837721, 0.2056261888355948, 0.11048408865462989, 0.17130824126070365, 0.09265703352866694, 0.1794043747941032, 0.1139282995427493, 0.20046581339556724, 0.12074309284798801, 0.15666507388232276, 0.1500079795368947, 0.09745748960995115, 0.17013414879329503, 0.13102850265568122, 0.07131843245588243, 0.14138787490082905, 0.1477362506557256, 0.12980277155293152, 0.1253796456148848, 0.20376179512823, 0.15764286828925833, 0.18949464429169893, 0.10855392582016066, 0.08811286330455914, 0.08349018869921565, 0.13826102862367406, 0.24694770982023329, 0.23552826867671683, 0.17665664723608643, 0.1643897476606071, 0.1470217405585572, 0.14894152816850692, 0.07477248422219418, 0.15511704288655892, 0.19156465743435547, 0.12659166182857007, 0.19409690983593464, 0.1158655721519608, 0.19193029875168577, 0.14057568332646042, 0.05389185876992997, 0.1308851790963672, 0.14849036175291985, 0.19178733142325655, 0.10756605304777622, 0.17516032909043133, 0.2049741824157536, 0.13955588336102664, 0.15829667070647702, 0.12130772622185759, 0.13111021311488003, 0.146483757707756, 0.11498128093080595, 0.1267778963665478, 0.2561303920811042, 0.15585349086904898, 0.1750938771874644, 0.15401777374790981, 0.1835376475355588, 0.22215460427105427, 0.14367884024977684, 0.1856044991291128, 0.1527200246346183, 0.15797944710357115, 0.32125301950145513, 0.12841399060562253, 0.18117279396392405, 0.17727648897562176, 0.2440539127564989, 0.10084372392157093, 0.21240965608740225, 0.15274035948095843, 0.1994672536966391, 0.23699470795691013, 0.13320735917659476, 0.07417840984999202, 0.15987639140803367, 0.12383951849187724, 0.1433541951701045, 0.24881272693164647, 0.22173162462422624, 0.15400150587083772, 0.20996842067688704, 0.16289810504531488, 0.15397323004435748, 0.1845179800875485, 0.12120309824240394, 0.17475995526183397, 0.10065000111353584, 0.1455123902997002, 0.20948655903339386, 0.131510631472338, 0.23913624929264188, 0.08042905959882773, 0.09937056820490398, 0.10707562702009454, 0.2120532322442159, 0.13692145206732675, 0.13609674788312986, 0.0760212961176876, 0.26203916408121586, 0.13985997095005587, 0.14650415192591026, 0.179498479119502, 0.12140347069362178, 0.1336699546664022, 0.11864254032843746, 0.16794913244666532, 0.15972990629961714, 0.09017774820677005, 0.12708272610325366, 0.11092310611275025, 0.10366799659095705, 0.13849437469616532, 0.23695013456745073, 0.1065603613096755, 0.0871646954328753, 0.19999768148409203, 0.12259149327292107, 0.11424712618463673, 0.15910259855445474, 0.2691892522852868, 0.13804749789414927, 0.1096446454175748, 0.13985918427351862, 0.12246476413565688, 0.18423906614771113, 0.1388258920633234, 0.20473659125855193, 0.19963340571848676, 0.054862450633663684, 0.08970028007752262, 0.12908688106108457, 0.08907827868824825, 0.16937787062488496, 0.13729623664403334, 0.18257509684190154, 0.15716807189164683, 0.26862471539061517, 0.25901645596604794, 0.1246346184052527, 0.18508365988964215, 0.09591833470040001, 0.22698337328620255, 0.13756490894593298, 0.11267954701907001, 0.10312867787433788, 0.14251469256123528, 0.08827787984046154, 0.16958142688963562, 0.17814986320445314, 0.18671406927751377, 0.1280975982081145, 0.11109199665952474, 0.11711369385011494, 0.16467829467728734], [0.10255378059810027, 0.10163362137973309, 0.034135397800127976, 0.034650348097784445, 0.04078697798831854, 0.044178997341077775, 0.010269115027767839, 0.045222256594570354, 0.053941211590426974, 0.028170497171231546, 0.05002277575840708, 0.022271194975473918, 0.06686636275844648, 0.080133981682593, 0.037045462740934454, 0.08830597013002262, 0.014215937080734875, 0.01450790261515067, 0.044240346978767775, 0.033138314975076355, 0.03150157135678455, 0.017903646621562075, 0.03796872042585164, 0.03352708532474935, 0.048630280361976475, 0.024485739522788208, 0.06085060646000784, 0.05192203556362074, 0.023055706296872813, 0.01914296459290199, 0.0007393911778308393, 0.028104416342102922, 0.032724430348025635, 0.028167168638901785, 0.05665102282364387, 0.04904514833469875, 0.02858680676581571, 0.013553679746109992, 0.012463318234949838, 0.07664190969080664, 0.017215093139384408, 0.0914102625392843, 0.06757817885954864, 0.04347164896898903, 0.13809205644065514, 0.06605616013985127, 0.04574971208057832, 0.04441550496267155, 0.06735055474564433, 0.06976363307330757, 0.04613317236362491, 0.09564919484546408, 0.05625764744763728, 0.02620024351926986, 0.04575369370286353, 0.08581264337408356, 0.020827723310503643, 0.04144829465076327, 0.030608084925916046, 0.06431056201108731, 0.049792350037023425, 0.035207574837841094, 0.05265067615255248, 0.03175470308633521, 0.02315477187949, 0.10520879164687358, 0.08342796703800559, 0.06978706267545931, 0.08373868942726403, 0.07385921955574304, 0.057025343558052555, 0.018219560333818663, 0.03291573375463486, 0.008611364919488551, 0.020209456779411994, 0.044671675786958076, 0.044896368417539634, 0.09322416794020683, 0.03315299465612043, 0.03693714628752787, 0.026205230751656927, 0.13610241789137945, 0.09843494262895547, 0.024397347879130393, 0.05618482049612794, 0.020669707082561217, 0.03769799237488769, 0.07196734411991201, 0.14629039855208248, 0.033980062580667436, 0.009286491094826488, 0.026021272751677316, 0.037182863961788826, 0.04875907638052013, 0.05029626459872816, 0.00508742742567847, 0.05576368508627638, 0.026564925610728096, 0.04188973893178627, 0.05274054652545601, 0.007591983803649782, 0.07281610873178579, 0.01505663918578648, 0.047920219440129586, 0.05351616506231949, 0.060707947122864425, 0.03006373630341841, 0.022543179111380596, 0.04414966024341993, 0.03650225517048966, 0.009027396208693972, 0.03580147480533924, 0.0867994771397207, 0.014469361030933214, 0.04296843573683873, 0.029034930375928525, 0.034218815198983066, 0.06577491585630924, 0.025579535322322045, 0.03466585898422636, 0.0345225688215578, 0.02834064380294876, 0.08027088566450402, 0.04943849031405989, 0.05210306393564679, 0.04392439986986574, 0.021561987523455173, 0.0711323315044865, 0.02394960461970186, 0.06175210437504575, 0.015255535690812394, 0.06076524834497832, 0.06029749121807981, 0.04402635611768346, 0.07420451860525645, 0.019388264809094835, 0.08125639840727672, 0.022562254162039608, 0.021285563489072956, 0.009461098961764947, 0.04993174763512798, 0.016545020989724435, 0.03850108892947901, 0.051900491016567685, 0.044113046387792565, 0.015441950199601706, 0.03570060209312942, 0.06602174675208516, 0.017095768780563958, 0.017583291155460756, 0.040216938068624586, 0.03350290244270582, 0.03259560093283653, 0.03073805168241961, 0.039807446955819614, 0.04859110609686468, 0.03497722704196349, 0.06771066706278361, 0.06291193276410922, 0.038081805178080685, 0.05983456547255628, 0.011134620635857573, 0.04518810295849107, 0.04133637878112495, 0.008239017370215151, 0.04694924908108078, 0.03696103973197751, 0.022703226968587842, 0.05028960382333025, 0.044268908532103524, 0.054329288032022305, 0.04133692797040567, 0.004998756548957317, 0.0317724775231909, 0.04810684360563755, 0.06335142519674264, 0.07762423119856976, 0.10663821260095574, 0.025218838563887402, 0.015645977728127036, 0.03350367798702791, 0.04862952708208468, 0.03210698574548587, 0.03365681644936558, 0.03336333786137402, 0.025487202874501236, 0.0406379287596792, 0.05213456439378206, 0.03257971526181791, 0.07782230299199, 0.05489183597092051, 0.0796023070870433, 0.017178551643155515, 0.026436244625074323, 0.08738121701753698, 0.04992739864974283, 0.028953900837223046, 0.008778977116890019, 0.026655296933313366, 0.05106589771457948, 0.014239379670470953, 0.036977504278183915, 0.022129719363874756, 0.01797232311218977, 0.017863756183942314, 0.04445033766387496, 0.026232736599922646, 0.08377794161788188, 0.023238359972310718, 0.020473297699936666, 0.005863094202140928, 0.04482133728743065, 0.033516832554596476, 0.01380110621539643, 0.0342721236665966, 0.015466875229321886, 0.12102184351533651, 0.05350426472432446, 0.06197618473379407, 0.06545946598635055, 0.0800508314569015, 0.05479831794218626, 0.026194888923782855, 0.02719161922868807, 0.05430117547803093, 0.06900754786329344, 0.07779106599627994, 0.03467500595434103, 0.030377110015251674, 0.01334231144937803, 0.02241386544483248, 0.05577893251029309, 0.01635950819036225, 0.04993621907487977, 0.043915330825257115, 0.09177887986879796, 0.03279910895798821, 0.016083039627119433, 0.03509683156153187, 0.040372915245825425, 0.07828086861991324, 0.04595107900968287, 0.08638053477625363, 0.07191432508989237, 0.08245012810220942, 0.06738383264746517, 0.029286605640663765, 0.03070976657909341, 0.05382185940106865, 0.038071407689130865, 0.007977281366038369, 0.03343760829011444, 0.01888678078103112, 0.09456429368583485, 0.019610870149335824, 0.024052586886682548, 0.012164530508016469, 0.06876169660245068, 0.007237244171847124, 0.05640416966343764, 0.08763533580349758, 0.040236708882730454, 0.037843557220185176, 0.020252885406080168, 0.07525358145358041, 0.07723921240540221, 0.05192700795305427, 0.09649913205066696, 0.09588550208718516, 0.08044125308515504, 0.08040980828809552, 0.025129816094704438, 0.043111006016260944, 0.06678123099845834, 0.024719093016756233, 0.019836132378259208, 0.017185709657496773, 0.026138888315472286, 0.03694249717227649, 0.07343922334257513, 0.08661028143251315, 0.024998231456265785, 0.023660000042582396, 0.052413793746382, 0.02944494099210715, 0.024986815369629767, 0.10449663415784016, 0.023618660561623983, 0.05664867763698567, 0.04795432854734827, 0.06477726899902336, 0.022230519716686103, 0.023042755819915328, 0.023216596491693053, 0.060494405261124484, 0.009740504574438091, 0.017818544547480997, 0.061547880177386105, 0.01604967637831578, 0.026066705177072436, 0.012448232228052802, 0.024656930727360304, 0.019477526620903518, 0.07182767934864387, 0.05741043285524938, 0.051909830945078284, 0.03765208683034871, 0.009871938927972224, 0.13768215343588963, 0.06698190030874684, 0.05810414055304136, 0.01980160210223403, 0.025438727643631864, 0.10822758864378557, 0.027221555610594805, 0.01069968684532796, 0.02590005777165061, 0.02234728181065293, 0.02108157492330065, 0.029578189896710683, 0.04224047050229274, 0.0366223124001408, 0.0327801433741115, 0.07476029815734364, 0.009453058719373075, 0.02246966938400874, 0.02485978195181815, 0.08018458131118678, 0.02227645123639377, 0.027567810175241902, 0.041585373037378304, 0.05948945938143879, 0.0025386295374119072, 0.049987252859864384, 0.033760049191187136, 0.034063272178173065, 0.04738150557386689, 0.05783766871900298, 0.01053744872479001, 0.07964514385093935, 0.025152663110930007, 0.04857354688283522, 0.0848929220228456, 0.028392184103722684, 0.05290735905873589, 0.09654562018113211, 0.056310577419935726, 0.01569213560287608, 0.014571577030437766, 0.03415825223783031, 0.032439660863019526, 0.059610451717162505, 0.32282506639603525, 0.23137697658967227, 0.142817874730099, 0.11913314447156154, 0.13586665241746232, 0.1256013844977133, 0.09134795182035305, 0.15839979954762384, 0.12703279440756887, 0.11056252624257468, 0.13004822947550565, 0.12497337913373485, 0.1602165325311944, 0.22114678256912157, 0.12813427514629439, 0.2391080476809293, 0.1215839535871055, 0.10356530561693944, 0.18493949028197676, 0.11509588337503374, 0.0994826399255544, 0.10669918745406903, 0.11200221852050163, 0.11086002356023528, 0.12637243140488863, 0.11030100824427791, 0.09182418056298047, 0.1277870242483914, 0.1778884936356917, 0.10266721044899896, 0.1428576686885208, 0.18681713874684647, 0.1986483679502271, 0.11366204664227553, 0.17671097244601697, 0.27036742656491697, 0.11832808493636549, 0.20462302782107145, 0.16508030123077333, 0.20678168308222666, 0.1551502020447515, 0.14608479395974427, 0.14816236216574907, 0.2041316221584566, 0.33364899340085685, 0.10685819259379059, 0.1658538862830028, 0.18086560419760644, 0.15665250190068036, 0.12318104054429568, 0.1865304767852649, 0.21597628423478454, 0.19856956670992076, 0.12096002261387184, 0.11318854900309816, 0.10488833228009753, 0.18095286592142656, 0.17851027980213985, 0.1283600809983909, 0.22244153340579942, 0.1308123001945205, 0.08899707288946956, 0.18183422565925866, 0.127910339506343, 0.12347382522420958, 0.15727796911960468, 0.21899587532971054, 0.25848148623481393, 0.18200223305029795, 0.15535360987996683, 0.16890641389181837, 0.1258333947043866, 0.08164230035617948, 0.0971617289178539, 0.16939078399445862, 0.1454896360519342, 0.27985257853288203, 0.21552424208493903, 0.10470014589373022, 0.09424670643056743, 0.1116410968825221, 0.2604511461686343, 0.1876984687987715, 0.15568076341878623, 0.1915558852488175, 0.12279789938475005, 0.10043508256785572, 0.12454645126126707, 0.27155872201547027, 0.19600884552346542, 0.1555639790603891, 0.20573135116137564, 0.2216636438970454, 0.1461539918091148, 0.18057882349239662, 0.1531418168451637, 0.1522211529663764, 0.20453915029065683, 0.14023226191056892, 0.13057775184279308, 0.13873937248717993, 0.24613715097075328, 0.16328506084391847, 0.11001856910297647, 0.13273563527036458, 0.27013166109099984, 0.12814280984457582, 0.11258867103606462, 0.16008165461244062, 0.22805822576628998, 0.15490403166040778, 0.1975107000907883, 0.13706674973946065, 0.11555452321772464, 0.18906357523519546, 0.21916949335718527, 0.11981871823081747, 0.20107407763134688, 0.18011989421211183, 0.15030328009743243, 0.1220537479093764, 0.11354339207173325, 0.17699251358862966, 0.08920540858525783, 0.09095202345633879, 0.10990778871928342, 0.08424048515735194, 0.1371245927293785, 0.20322499971371144, 0.07931653570267372, 0.11753566417610273, 0.17886545683722943, 0.21276210201904178, 0.1616983491112478, 0.22733654652256519, 0.1149449528020341, 0.21802248927997425, 0.23507489066105336, 0.07239001948619261, 0.13709576771361753, 0.20202635700115934, 0.08421793871093541, 0.09210783682647161, 0.21453203517012298, 0.16912089457036927, 0.07019128082902171, 0.20350232545752078, 0.1049293062533252, 0.1224456167255994, 0.14451181195909157, 0.2716624445747584, 0.16873004991794005, 0.1545918546617031, 0.12244100056705065, 0.322338662808761, 0.2558430621866137, 0.12128807415137999, 0.14188492088578641, 0.1767047680914402, 0.21721421624533832, 0.15551149437669665, 0.15212440659524873, 0.14298939990112558, 0.14469176792772487, 0.17724977165926248, 0.07942413969431072, 0.14939417887944728, 0.13753641047514975, 0.13787536416202784, 0.22890834108693525, 0.1670105234370567, 0.1587582123465836, 0.2203630152507685, 0.22086902637965977, 0.10235749738058075, 0.198565618484281], [0.04317196231568232, 0.05302239194861613, 0.042454145950614475, 0.022457501872850116, 0.13257521262858063, 0.059104577885591425, 0.028475002218328882, 0.036665167717728764, 0.04361851257272065, 0.04845103314437438, 0.04847250718739815, 0.03946565826481674, 0.068914734874852, 0.055453990571550094, 0.03166182701534126, 0.04796144574356731, 0.03564401704352349, 0.02304239031218458, 0.05597946081252303, 0.01492303312261356, 0.035072678365395404, 0.021332420838007238, 0.019601700914790854, 0.08409671630943194, 0.05472886776260566, 0.057506336888764054, 0.0506585551192984, 0.03678343637147918, 0.03921398485545069, 0.03625933539296966, 0.0710629926470574, 0.024015126982703805, 0.05265207881166134, 0.011196989798918366, 0.00822414936919813, 0.03556644034688361, 0.06612676064833067, 0.05493406788446009, 0.01884417222754564, 0.04701962694525719, 0.03341712130350061, 0.0032323694722435903, 0.03796480188611895, 0.046396308243856765, 0.027810115825559478, 0.02428139287076192, 0.03131123274215497, 0.06353589342324995, 0.021313284560164902, 0.018283633653481957, 0.013397614438872552, 0.02308917715708958, 0.018319813352718484, 0.04122144979191944, 0.013908564560551895, 0.10068783580209129, 0.03486797919322271, 0.02705518465518253, 0.06020162058121059, 0.10282649018336087, 0.009607324318494648, 0.0027952829896094045, 0.09589056353433989, 0.06414041723473929, 0.04863720831053797, 0.15779621084220707, 0.06025776034221053, 0.07440384462825023, 0.04301949549699202, 0.009385217144881608, 0.004815842657990288, 0.02756809590209741, 0.017594649725651834, 0.1132765602960717, 0.06686346838250756, 0.04996264324290678, 0.04466352329473011, 0.04682259415858425, 0.028717927561956458, 0.030290070935734548, 0.0066552839689393295, 0.11133522071759216, 0.07212831595097668, 0.03406842639378738, 0.008486783372063655, 0.09236551792128012, 0.04530630110821221, 0.1259011379443109, 0.020456120691960678, 0.04392183203890454, 0.05997584441502113, 0.07801335406838916, 0.028019162127748132, 0.01130681652284693, 0.03031381595064886, 0.019270823650003877, 0.030538657010765746, 0.05243530118605122, 0.017296818441536743, 0.008520041792507982, 0.07708060802542605, 0.021244101553747896, 0.04001691071607638, 0.047927102859830484, 0.07226534609799273, 0.03687380398332607, 0.016665102339175064, 0.05850433255545795, 0.022667199409625027, 0.02000402473640861, 0.07944615921587683, 0.030340908051584847, 0.06245989803574048, 0.04852471727645025, 0.06176434981171042, 0.08570840873289853, 0.061431285066646524, 0.04950021844706498, 0.06968075744225644, 0.026925640922854654, 0.0359107486292487, 0.029489746302715503, 0.1158209764980711, 0.0708746281452477, 0.0060156806921440875, 0.04679087476688437, 0.05212795556872152, 0.05814572679810226, 0.06556188978720456, 0.057893519042409025, 0.08477405222947709, 0.08522105519659817, 0.04548894736217335, 0.05089042802865151, 0.01515912328613922, 0.040524910800741054, 0.05554318930080626, 0.009064546266017715, 0.02016983722569421, 0.015417767317558173, 0.0916807159956079, 0.06419460143661126, 0.03776627367187757, 0.04091138791409321, 0.005588548729065224, 0.017462300675106235, 0.004754321862492361, 0.03406725751119666, 0.028425500968296546, 0.035572102933656424, 0.07529535694629885, 0.022054853361623827, 0.05040542338974774, 0.12170188085292466, 0.07209739807876758, 0.050427120077074505, 0.05230571849097032, 0.02786904420645442, 0.02861924047465436, 0.017996179449255578, 0.023811739556549583, 0.06874081998830661, 0.059605126807582565, 0.027001208254660014, 0.04347006819443777, 0.016816856696095783, 0.056080567301250994, 0.014960745356802363, 0.017831725090218242, 0.049032999377232045, 0.010413921954750549, 0.061416104435920715, 0.029942890541860834, 0.07238457212224603, 0.0389073888072744, 0.009684036413091235, 0.02784848300507292, 0.0067193800168752205, 0.029004173920839094, 0.0032874022735995823, 0.08512816799338907, 0.010936238068097737, 0.05195038189413026, 0.04714192917163018, 0.06529939215397462, 0.03332185180624947, 0.03737679828191176, 0.03887084545567632, 0.0611180134001188, 0.04048691283969674, 0.049540446561877616, 0.03275674345786683, 0.02724478854361223, 0.01469651944717043, 0.034813130769180134, 0.05785212946648244, 0.025055311889445875, 0.06040487998689059, 0.07039163101580925, 0.03408715820114594, 0.03233823896152899, 0.059778180802823044, 0.04723252684925683, 0.031231266329996288, 0.044104634143877774, 0.10116851000930183, 0.03695480940223206, 0.011826293921330944, 0.035830411143251695, 0.02697880467167124, 0.04715189250418916, 0.04282065558072645, 0.0707640555629041, 0.013462102433550172, 0.03457726510532666, 0.010290723585058004, 0.037755720331915654, 0.02325315283087548, 0.06310391894658096, 0.05426400872238446, 0.02712881498155184, 0.08050398682826199, 0.0585173572471831, 0.05647872581903357, 0.021781542636745144, 0.020234029288985766, 0.10492565488675609, 0.03629717008152511, 0.06352791533572599, 0.04235471671563573, 0.04654113465221599, 0.06426403677323833, 0.011568387399165658, 0.02090806265186984, 0.057563511945772916, 0.019302934524603188, 0.08398572070291266, 0.0485234667576151, 0.02285248956468422, 0.025629042138461955, 0.03416872765228618, 0.16207199078053236, 0.08407599554629996, 0.050488376946304925, 0.0437975705426652, 0.03178878250764683, 0.031499842152697966, 0.027052217919845134, 0.018145555222872645, 0.013991484720463632, 0.03179579209245276, 0.01300039102716255, 0.02595860765723046, 0.12071587829268537, 0.022320173011394218, 0.039925500386743806, 0.07684888725634664, 0.06137340868008323, 0.10422620296594687, 0.07425809424603358, 0.03774806136789266, 0.02502331048162887, 0.06146900101157371, 0.08804102340945974, 0.045845504791941494, 0.10521225005504675, 0.12458329147193581, 0.020251885362085886, 0.015182691113295732, 0.04732074223284144, 0.03158229104883503, 0.01222265551405144, 0.05595763424935285, 0.056907256730482914, 0.05807550849567633, 0.04825484640605282, 0.03304901605588384, 0.06111317459726706, 0.06332281540380791, 0.10879576206207275, 0.029490991255443078, 0.027722486738639418, 0.07320563978282735, 0.054794343741377816, 0.02758325426839292, 0.08183504352928139, 0.05476875448948704, 0.03874383801303338, 0.00794058401879738, 0.06234976332052611, 0.020721816981676966, 0.026386049466964323, 0.012895714808109915, 0.05380844508181326, 0.019736632639251184, 0.049279577942797914, 0.06659850681899115, 0.02910542141762562, 0.037321237396099605, 0.03620513634814415, 0.03654866166471038, 0.09864514111541212, 0.011932898796658264, 0.03739861371286679, 0.022502854517369997, 0.04380511076305993, 0.07448639371432364, 0.08535570304957218, 0.025109121306741145, 0.04972119291778654, 0.016555542788410094, 0.053482768416870385, 0.03292705150670372, 0.12337902327999473, 0.030934474052628502, 0.03814353702182416, 0.04108914341486525, 0.06074068325688131, 0.0061386823927023215, 0.02866267466743011, 0.02740216652455274, 0.08358591090654954, 0.06231595849385485, 0.07167237752582878, 0.04140042241488118, 0.016775949516159017, 0.05879613760043867, 0.017763135801942553, 0.028088204126106575, 0.01984390451980289, 0.02714275808102684, 0.0736710405908525, 0.02615665533085121, 0.014231634431780549, 0.012016763339488534, 0.012115440222260077, 0.040238293368020095, 0.023214097309391946, 0.04891302749456372, 0.048076185485115275, 0.0015391890019600396, 0.017446394595026504, 0.0034938206772494595, 0.026891383386100642, 0.044048253184882924, 0.021635564044117928, 0.07652113999938592, 0.05750725344114471, 0.03536128846462816, 0.06398476660251617, 0.0192231016990263, 0.06321918190224096, 0.21094069350510836, 0.18911217106506228, 0.1509357531904243, 0.10032456193584949, 0.20078070665476844, 0.1538370014168322, 0.1644828129792586, 0.091557949926937, 0.179275389527902, 0.22638595924945548, 0.12238113893545233, 0.08997500088298693, 0.09887362612062134, 0.24713850114494562, 0.12875619489932433, 0.1239266169432085, 0.16610851715086028, 0.1156151492614299, 0.12870975129771978, 0.10070322794490494, 0.0801031528681051, 0.10823214543052018, 0.12210547560243867, 0.2563243597978726, 0.16358377528376877, 0.10495694383280352, 0.1274235054734163, 0.16916865919483826, 0.12565652607008815, 0.12187659725896083, 0.08715870630112477, 0.2534702676348388, 0.10912521625868976, 0.1327836819109507, 0.16749710513977334, 0.13775978208286688, 0.17565630638273433, 0.14130539260804653, 0.13006802997551858, 0.12375437931041233, 0.20175149518763646, 0.09933100431226194, 0.16425942652858794, 0.13844157831044868, 0.08897730949684046, 0.1431728884926997, 0.13252081320388243, 0.12028900979203172, 0.14673632540507242, 0.14993524906458333, 0.16046570119215176, 0.19301892549265176, 0.10869723453652114, 0.11238775681704283, 0.1108344343083445, 0.1511553695308976, 0.12970587675226852, 0.12589794670930132, 0.30516622646246105, 0.2270005614263937, 0.14415773330256343, 0.16624709096504375, 0.15108247578609735, 0.10015091422246769, 0.1193748990772292, 0.24846645566867664, 0.1612538768677041, 0.17694860813207924, 0.1474861617316492, 0.1995937601896003, 0.10225575635558926, 0.0985380937345326, 0.12535892485175282, 0.16886525438167155, 0.1139072299702093, 0.12268282938748598, 0.10869884499697946, 0.15922298975056037, 0.152476065850351, 0.15396445785881951, 0.28684357996098697, 0.295201558037661, 0.19209622812923044, 0.15366103820269927, 0.2276175978477113, 0.15952614223351702, 0.1542233189684339, 0.26530793868005276, 0.14461930462857708, 0.217238410259597, 0.17119231779361144, 0.13875917298719287, 0.15998179122107103, 0.14641567307990044, 0.28821468295063823, 0.1333176126354374, 0.2387094104778953, 0.18040838185697794, 0.1982671266887337, 0.1085375391994603, 0.19829342840239406, 0.16684288711985573, 0.10163515020394698, 0.18650030106073245, 0.16986578819341958, 0.0938336196122691, 0.14652083540568128, 0.2394413758884184, 0.15788109769346192, 0.12412964628310874, 0.19107173779048026, 0.10445540043292567, 0.18612974672578275, 0.24310975248226896, 0.21861963614355773, 0.14814802387263626, 0.10076900449348614, 0.12700784340268, 0.13752992410445586, 0.10474681213963777, 0.12369984629913233, 0.11058974821935408, 0.1295218983432278, 0.17818515974795446, 0.06755803697160445, 0.24041504395427182, 0.11179350432939827, 0.13954311842098832, 0.1231753928004764, 0.10940932523226365, 0.16183018422452733, 0.14185173204168677, 0.09126385906711221, 0.127295826387126, 0.0691033888142556, 0.119739412330091, 0.15733432781416923, 0.20788662222912535, 0.10388578724814579, 0.13209780387114733, 0.20613427797798067, 0.15786677424330264, 0.17090430512325838, 0.16333873296389356, 0.1257492500008084, 0.1400767671293579, 0.10362464774516411, 0.1803073607152328, 0.13205829192884266, 0.11373735236702487, 0.23875536426203325, 0.0789034043555148, 0.1724831500905566, 0.13167362194508314, 0.12195393646834418, 0.1252466527512297, 0.13447270612232387, 0.05705783478333615, 0.10656303304131143, 0.13266910915262997, 0.1784471675637178, 0.12291876555536874, 0.16845983394887298, 0.12938019266584888, 0.13134243112290278, 0.08710927184438333, 0.1023633529257495, 0.14973552228184417, 0.12426013810909353, 0.11620296732871793, 0.1566061918856576, 0.18793175549944863, 0.14309156395029277, 0.1923689674003981, 0.0813140113314148, 0.09588815155439079], [0.014118797371338587, 0.0217531350790523, 0.015538896950602066, 0.03402140391699504, 0.03584839709219523, 0.06637411846895702, 0.044174017530167475, 0.010523296896280954, 0.02547864776715869, 0.049541422486072406, 0.03141472152492497, 0.021028769260738045, 0.08412528157350607, 0.030765624323976226, 0.08892699188436382, 0.022206132744031493, 0.028676218862528913, 0.034566288741189055, 0.04832508697290905, 0.06514928536489606, 0.01641966668103123, 0.008021715602808399, 0.016384076989197638, 0.008309311742777936, 0.0422897008684231, 0.07236854915390722, 0.04253951148712076, 0.02617627957079094, 0.0759133136307355, 0.06011881916492712, 0.024195912301365752, 0.10062789253424853, 0.017886469613586087, 0.09852041577687487, 0.09743382252054289, 0.010980531296809204, 0.14642892783740535, 0.05607857834547758, 0.02923991713032592, 0.02748075254203286, 0.04302016714063939, 0.05781850646599196, 0.06343452347209677, 0.03465399575361516, 0.04575837294396479, 0.036510281497612596, 0.0631646637339145, 0.04481234616832808, 0.07035044181975536, 0.020940487083862536, 0.02648119094374124, 0.03745337678992655, 0.08292182232253253, 0.0768057387904264, 0.03696280975418631, 0.057444783160462976, 0.022760748979635537, 0.016412141303590033, 0.0534988989966223, 0.015564736677333713, 0.03146189614199102, 0.06242981136892922, 0.04476138659811113, 0.028543300213641487, 0.003947344339394476, 0.10161088197492063, 0.052802256104769185, 0.07788516290020198, 0.018621078925207257, 0.04001882916782051, 0.04092942581337411, 0.030153519473969936, 0.06914469675393775, 0.023314903228310868, 0.017641323393036146, 0.08884303271770477, 0.022415602070395835, 0.0470326813228894, 0.015525312865065644, 0.06716155941830948, 0.06371826137183234, 0.12546610581921414, 0.03652021514426451, 0.038663578452542424, 0.03146704664686695, 0.12690541218034923, 0.019208253179385792, 0.0687002541963011, 0.07280679477844387, 0.0026742287309389212, 0.023291154502658173, 0.02641596358444076, 0.030247300965129398, 0.056736303013167344, 0.035245836261310615, 0.06159227545140311, 0.07462824039976113, 0.04924210690660402, 0.016402662222390063, 0.025336196231364738, 0.18878472066717222, 0.06721056342939846, 0.05134980630828068, 0.14048665529116988, 0.024056108377408236, 0.03421118592086714, 0.06845103358500637, 0.04010523742181249, 0.011267385289102094, 0.013191576617828105, 0.02061283445073059, 0.006693115410598693, 0.027174060014658608, 0.015076024083100492, 0.02973436003230745, 0.03941807917726692, 0.022117837579571642, 0.024951251652964856, 0.041487186899757944, 0.018869596351578366, 0.04805898992344737, 0.009958602295228047, 0.05052528766100295, 0.04164690450124908, 0.10701648527174257, 0.020331614286988042, 0.02366514683671994, 0.025703516657813452, 0.05721461719076615, 0.042127834749408066, 0.06908474606461823, 0.046012191160116345, 0.029652805424120743, 0.021772132204205263, 0.048015937936725095, 0.04430905872141011, 0.03125320050457958, 0.026304019884264562, 0.02040498857240891, 0.018505708358134143, 0.055140737458714284, 0.01909726870508166, 0.011589176810957724, 0.019648842135211453, 0.02553711601649411, 0.02093225295539014, 0.012265109144209418, 0.04069970142154489, 0.03686602627567481, 0.05617099057417363, 0.010939385701931315, 0.04952747382048983, 0.032465320618939586, 0.02487711110006785, 0.0841216895787511, 0.03292455789051019, 0.018572909830254503, 0.04359639286121819, 0.013954613896203227, 0.038434614762081765, 0.05882362303964328, 0.02697390278626699, 0.056006757004070096, 0.040795646273181774, 0.03382151015102863, 0.026927435064862948, 0.04921630985336378, 0.019065634660364594, 0.06238450325326994, 0.02566319948527962, 0.07621374985319562, 0.04411769594298676, 0.07758960258797742, 0.0799357243522536, 0.013430338512989692, 0.06322931963950396, 0.02495592718332773, 0.010509213716431987, 0.042553534367471, 0.07325905215111561, 0.04518483008723706, 0.0468649225513218, 0.04872577250353061, 0.026993660612788517, 0.06591570869204588, 0.009800502575671999, 0.021111934329383075, 0.027955187142651994, 0.0463393113022903, 0.035677933192346245, 0.053746754056192, 0.05729260577936657, 0.08375266406801529, 0.03508430781948846, 0.017049596062861383, 0.05924806100665592, 0.03112301852524979, 0.050444471489754505, 0.058417753607500345, 0.05867566847882699, 0.03800608385063242, 0.07458187101292424, 0.018253619346069172, 0.05259366436803248, 0.01381195548674441, 0.02507798264559824, 0.02084977437334601, 0.03738354811503086, 0.05911157262744382, 0.0784460038994439, 0.08044631453230977, 0.018215157542726956, 0.021071312876301818, 0.06260351845412515, 0.051227266594651155, 0.038926762572373264, 0.09393737927894108, 0.05275444324070122, 0.026961379044223577, 0.04113589500775561, 0.03494303258776199, 0.062059468546067365, 0.02944892446976155, 0.06544052637764253, 0.020847909727308434, 0.03629611623182427, 0.014820375545241404, 0.045028904860373586, 0.05355378823878709, 0.08834534848574549, 0.023137197822507005, 0.08432972099399194, 0.04804721575055737, 0.03756598656764254, 0.024452997822663747, 0.016836967042763717, 0.03550067493051756, 0.04871511155215558, 0.02588564711913932, 0.044541425158968195, 0.04582308822136838, 0.10332707621273585, 0.06141520272649359, 0.054372299200622365, 0.023293310441658832, 0.04109866145881824, 0.09305587111157365, 0.00968188418482896, 0.06953237985726446, 0.030782903377257753, 0.0074438390674913535, 0.04037307109683752, 0.09828637950704433, 0.12793245550710708, 0.017512942977191415, 0.05924473618506454, 0.10874860599869862, 0.09065203252248466, 0.10325979310437106, 0.060448306758189574, 0.04377623750769999, 0.02729854044446256, 0.13594748714240268, 0.08502378492266871, 0.11214384998311289, 0.032950915265246294, 0.07653416469111107, 0.03155036014504731, 0.04580498723953497, 0.038247125994530506, 0.05135852283274289, 0.024370689934585243, 0.035103930204059, 0.05419903369329404, 0.0944362732116133, 0.011742771694116527, 0.043803704393212683, 0.05916641363000963, 0.09571678965585306, 0.05005920407711528, 0.06000751927786041, 0.02989830416481709, 0.048164604959310964, 0.03587829080061056, 0.04778832124429755, 0.059866615119972266, 0.06977720695431344, 0.024343605255126022, 0.006070996205380652, 0.04523130708548706, 0.07724546128883958, 0.025916943486663513, 0.0700676983979065, 0.01679037686699303, 0.05114726307510864, 0.036811793834203854, 0.06227354475413449, 0.028757261388818733, 0.043665664925356396, 0.005279164060993935, 0.03407758820685558, 0.027109014481538907, 0.02351672843360575, 0.06116773729445413, 0.08494947367580608, 0.054421874665422365, 0.010843410236702766, 0.030426655794144608, 0.029082930632284842, 0.033437749298173, 0.04959421887178905, 0.014030816691956716, 0.04606041962688323, 0.03844336468318943, 0.06512849780847318, 0.04350187293312047, 0.008943715347413672, 0.039802248211344704, 0.0490835581877036, 0.052796437666984275, 0.023593575970153324, 0.020880113370367326, 0.008107807516353205, 0.055474073087680154, 0.029957893057144247, 0.029897576860093977, 0.056651738996151835, 0.02781601775495801, 0.06535391032230109, 0.014645293631474487, 0.02363026032980997, 0.04103440260223579, 0.014717402555106673, 0.04950736903992947, 0.04217027446429711, 0.0643331381434109, 0.03591005101043265, 0.06176305847475305, 0.034671521570999175, 0.030393567139981315, 0.025657293845142704, 0.03304673395177815, 0.05911298641876783, 0.039563117097713985, 0.0331105957593536, 0.027844644246215466, 0.04041648302518297, 0.059770481020677835, 0.05982007503916975, 0.02816351170622511, 0.03801200618909206, 0.020288651357986964, 0.15829814015887678, 0.12675686390139163, 0.11383377219317481, 0.21252837002975866, 0.14309849560959265, 0.15017034660559148, 0.20477963582379743, 0.08730850138817914, 0.10273355845129117, 0.13389576051849872, 0.1756590374861844, 0.16626206750515848, 0.21582368382951245, 0.16561681462917477, 0.176225830509793, 0.1265750970924273, 0.1635171304224059, 0.1507654451415874, 0.13682902499567717, 0.27861571521498263, 0.11764178387238644, 0.1440587456454523, 0.20722473040223122, 0.2055709730484523, 0.28389977698680013, 0.14137923630187288, 0.11480636414489709, 0.12034520521410741, 0.15470504702534527, 0.09021092962939292, 0.10299827510607429, 0.16298204194754362, 0.08670376235386357, 0.2340703789377585, 0.24320422788150609, 0.09299666999140754, 0.21314043406164274, 0.1480071642436087, 0.12913942511659116, 0.1241921128530521, 0.2167275157989934, 0.10631620956701227, 0.1014161053171847, 0.20128579752054065, 0.10878705666982569, 0.08415487100137398, 0.12464092666050419, 0.10420946011436172, 0.20483882952248678, 0.09452150887227617, 0.09483974921749905, 0.125689581327606, 0.21606744965538383, 0.2343950091744773, 0.15515514474827796, 0.24335526977665722, 0.1688382402062416, 0.15438788279425353, 0.1091359625570476, 0.16294477129122242, 0.16234667447861284, 0.09098755748709664, 0.16754415730247274, 0.13206506031565368, 0.18154585675802082, 0.1446157126338221, 0.1926955272210762, 0.19492453808197752, 0.16530057066120207, 0.1166020127129741, 0.12756423151586205, 0.19423260411713272, 0.1598133533843793, 0.08241146962973289, 0.10952510769129731, 0.206300726858899, 0.14750683796592057, 0.27531820465810597, 0.14510449109366164, 0.1451035708305426, 0.17020397004671395, 0.23156408686190844, 0.1700845139566809, 0.18834035232430324, 0.11529929863172583, 0.19864568137563765, 0.18580769916297868, 0.14101159118581563, 0.27586727519519627, 0.10711983675719239, 0.13215730927186087, 0.09611869230866432, 0.1514759921701625, 0.1952793143573217, 0.13438971916912124, 0.11160718073369935, 0.2506875107064843, 0.15403655008412898, 0.18726183363469318, 0.16420943546108902, 0.22526899731019512, 0.29284381424076855, 0.21031562704592943, 0.24223560641985387, 0.13070758315734565, 0.25751743640284985, 0.23703463550191373, 0.11714692722307518, 0.14498326869215816, 0.18956911138957366, 0.1307222034665756, 0.12569738872116432, 0.1580547750927508, 0.12259408336831257, 0.13317495700903237, 0.09244113534805365, 0.17284335888689384, 0.11142839735839516, 0.19012998207472265, 0.13859125465387478, 0.21171997825149447, 0.08451420406345278, 0.1463067703298293, 0.07758167645079084, 0.19820499408524483, 0.11580101272556931, 0.14309016871266067, 0.10864892072277144, 0.12612158549018204, 0.18949488177895546, 0.1805808421340771, 0.11622092730249278, 0.15194228355539963, 0.07079889939632267, 0.17781668342649937, 0.09987777419155464, 0.11340831377310678, 0.11352998146321625, 0.13278519589221105, 0.1377544683055021, 0.10155346200917847, 0.11183913156855851, 0.11249790637521073, 0.09418753499630839, 0.1270847744308412, 0.13741612317971885, 0.10291755170328543, 0.12932524405186996, 0.11907776541193016, 0.15669413638534024, 0.1437058692681603, 0.12063085785484873, 0.10964731714921072, 0.15097590337973088, 0.2934673964045942, 0.14794666436500847, 0.08374892364372499, 0.14251878921641037, 0.13910232722992077, 0.15052095201099291, 0.1719389035133645, 0.14684693509479985, 0.18521831516409293, 0.12460433878004551, 0.13878066558390856, 0.10409790789708495, 0.2644926152424887, 0.10113578871823847, 0.23005807626759633, 0.08005033421795815, 0.11782428540755063, 0.1787504684762098, 0.17450945073505864, 0.1327365852193907, 0.1653086897567846, 0.14725795132108033], [0.04377539145934861, 0.024848354732966982, 0.03118377258942928, 0.046827889382257126, 0.020986546624044422, 0.025235232606064528, 0.04598734405590221, 0.03594880225136876, 0.07472015538951382, 0.03256707277614623, 0.06515347849926911, 0.04115527248359285, 0.02652226139616687, 0.03157067272695713, 0.05455878606881015, 0.0725120582501404, 0.030951621374697424, 0.05000142045901157, 0.016173264375538565, 0.06050703661458101, 0.035885816178051755, 0.05126926102093421, 0.03987379866885021, 0.04261698428308591, 0.03850282184430398, 0.06324206973658875, 0.0473897359916009, 0.013292964194988599, 0.02251484020234784, 0.03941508832213003, 0.039273467991733924, 0.048667198498151265, 0.08216831236495636, 0.053997258582967333, 0.01703000336419791, 0.017522793132229708, 0.037671293612220325, 0.05804097265354358, 0.03822000420768745, 0.07317606519791298, 0.02902488355175592, 0.03953968749556225, 0.05586183782725129, 0.030193990642146673, 0.059510944556677714, 0.03552899899659678, 0.030289588539744727, 0.005959450945738354, 0.044353992052492686, 0.004234600946801947, 0.05951050668954849, 0.029187233922129963, 0.014785515941184713, 0.023668809335504193, 0.02219993210019311, 0.03958286193665117, 0.01081243577573332, 0.07075059300404973, 0.055956216747290455, 0.025024037786351983, 0.04554630795610137, 0.04541886264632922, 0.08247183592175134, 0.030892713402863592, 0.0530980242183432, 0.08740548524656333, 0.03864876147417817, 0.04875502796494402, 0.039521070721093565, 0.01890725292469142, 0.0013593518929155834, 0.04008574120234698, 0.06992819689912722, 0.07095152206602506, 0.026624449565133546, 0.05055180088675115, 0.2091617209953256, 0.3430849558208138, 0.0658048466721084, 0.11036283656721935, 0.2486342255724594, 0.5390702455770224, 0.15153729356825352, 0.02491818340786267, 0.0638858086313121, 0.2508297062013298, 0.19459132861811668, 0.1839935636962764, 0.1445806832634844, 0.1785753364674747, 0.19568102405173704, 0.13653133471962065, 0.09844028609222732, 0.10718664489104412, 0.038026745241950266, 0.27741343597881496, 0.3286044375272468, 0.3659179009264335, 0.261423151823692, 0.06276719912420958, 0.07412621460389346, 0.05573431830271147, 0.03814947420323733, 0.11287419751170091, 0.058003731683129445, 0.015399643143609865, 0.012781025161530124, 0.06099390775489155, 0.02867345065169502, 0.06509546481538564, 0.005895291815249948, 0.03197698744770605, 0.005566719846683554, 0.004057052783537074, 0.034697389128268696, 0.08502169948769733, 0.03658355002698954, 0.021951808012090623, 0.016099133099487517, 0.01410030768965953, 0.0522147831361508, 0.04181542397418525, 0.02881782806070987, 0.04207197700452525, 0.021505767981579993, 0.007849716384953354, 0.04639710234187078, 0.0630655350687448, 0.05344423982023727, 0.07555457428679802, 0.06887177194585092, 0.058121209949604236, 0.053427122184075415, 0.023017504245217424, 0.11929667671211064, 0.049971189073403366, 0.030079889147600625, 0.04336348836659454, 0.024729249307711143, 0.03852525325783063, 0.08493305736919865, 0.0433761345630046, 0.06951633462449536, 0.005757033877671347, 0.044835983571829274, 0.02098309192660963, 0.08995717449579388, 0.04304411995690316, 0.0410383396956604, 0.036132520908722654, 0.03606298167142086, 0.06099724370869808, 0.026963729796989355, 0.017253959413210396, 0.015120647567528067, 0.024227036119555123, 0.038109839806566015, 0.008716088450455572, 0.05901497839658987, 0.005253098906905507, 0.014849177368887467, 0.03960600952268578, 0.04429843487741891, 0.04058032325701788, 0.007586058682136354, 0.03183986453223042, 0.06584301532711834, 0.012217351941217203, 0.011862861392728519, 0.07643965218449011, 0.018920043839898426, 0.029221194599813316, 0.03292100300313905, 0.04095705226063728, 0.030474092018266674, 0.037447907161549665, 0.034575699173728935, 0.03736962913535535, 0.02523805833334336, 0.054657231958117336, 0.03315813031804282, 0.06055686440959107, 0.03308843522972893, 0.020456734819163103, 0.06640468011028133, 0.030095637521299068, 0.05411424703197554, 0.05627659076708369, 0.039913930304464884, 0.020304399731685407, 0.03048403865250293, 0.03327849553897977, 0.012628442382265348, 0.007630039281139034, 0.04765447120007593, 0.05485351517563686, 0.01942181359481765, 0.03722255030879751, 0.01764462223945884, 0.0018874390161727206, 0.06743428384652361, 0.036926244138157926, 0.03851764995488338, 0.03574729802494403, 0.021431438181025442, 0.03775579454668332, 0.07663399097509682, 0.03572401314158924, 0.038754480410716496, 0.033501911675557494, 0.06544745803694241, 0.04936019373417366, 0.03612148517277092, 0.054828553038532846, 0.031712166892248206, 0.03293441732239444, 0.050077130654244684, 0.012495769569795812, 0.0459016742388485, 0.04387378168758005, 0.0456396107620094, 0.006666698664048454, 0.009771999466465786, 0.024503124332113657, 0.04671758768381551, 0.08393818614422344, 0.06676954217255116, 0.014855503250146285, 0.01963597514986759, 0.06244115880690515, 0.01695441191259306, 0.06632679913309403, 0.024412430175289046, 0.04810597158211749, 0.050922744849231094, 0.07549808200565167, 0.058433086378499866, 0.02105714342178544, 0.018506363303458784, 0.09086557809496298, 0.0265527525334619, 0.14335602085338905, 0.0728317309403792, 0.05558015938731842, 0.003190705997440091, 0.020901834177493583, 0.059046348978881724, 0.0533718173392117, 0.06679864920442924, 0.029240072981338017, 0.03195675279130228, 0.03302810604509432, 0.23614570585777983, 0.4614236089400947, 0.11917594412807375, 0.20722876768559217, 0.27678747894242406, 0.27454031514935195, 0.12045623050653376, 0.11238274732022546, 0.11504339869134128, 0.09328356944024563, 0.21016866696299985, 0.0322690299799433, 0.14288549922639504, 0.16840809141285717, 0.18231200549053028, 0.1125883222266566, 0.20566334074828774, 0.36132976587396115, 0.010998982015735237, 0.23816310073016211, 0.09717168111819774, 0.18921063921879977, 0.40828571654856205, 0.17945206520380452, 0.06382817344274372, 0.03017723294760799, 0.12411530798999593, 0.07270537287695333, 0.08211318563553505, 0.07898040217696689, 0.05263994098640978, 0.04433101144968532, 0.09368326791445725, 0.041040276701096445, 0.06778760551242158, 0.010380599524069112, 0.050434764198143966, 0.03423287518671714, 0.06712139438604936, 0.10302177150151692, 0.023332345554081257, 0.05418539672973566, 0.01849676547863055, 0.001338947470230778, 0.056216888697235845, 0.007313316627914901, 0.02723848585446831, 0.024302020865434315, 0.11004686719388701, 0.04520185124420095, 0.07070073552313261, 0.05765904119471088, 0.037521376070799306, 0.04726687715447042, 0.0288707394793164, 0.05112690225359984, 0.04202990465273615, 0.010871745434997138, 0.03930162878532428, 0.09243881242582574, 0.035762233746936545, 0.0488232869975036, 0.06229715247172862, 0.023829805286368355, 0.06711283742333762, 0.01450570029192022, 0.04858079395489767, 0.06544845251482911, 0.04234387022734154, 0.012073059879185166, 0.018193729883932974, 0.04278809385141358, 0.040948973983176984, 0.04468838524189778, 0.09466558942222036, 0.009618213480280247, 0.016961286055448, 0.09436583597562276, 0.07903391102445312, 0.025584160757716745, 0.03389488629181869, 0.0349054724938469, 0.05787488000351004, 0.056005391452345066, 0.05512433228432201, 0.08076108162640594, 0.06273565042647533, 0.01841192501160549, 0.03269957953307312, 0.04143495454627555, 0.0181893864646554, 0.04717942247225437, 0.012901760528620798, 0.028776507133443374, 0.03758446233405266, 0.04312965989811346, 0.014494944716716418, 0.043219841973041184, 0.030450001904682722, 0.01740646519465372, 0.1272981270449236, 0.09104171942453831, 0.18227439344627783, 0.10343746325816028, 0.14041490445379168, 0.13676894071977586, 0.1009527083078865, 0.16098326013889164, 0.16266811348032206, 0.08505321107804775, 0.1449891465017572, 0.15107031940715387, 0.1374426920665428, 0.12947382201673463, 0.12339789609541185, 0.1200144893664401, 0.10707108507631347, 0.10848131409147754, 0.13596918754046783, 0.14337435190100223, 0.15274905745172873, 0.08893157835700549, 0.19835909362882376, 0.21422925376100466, 0.14461373852100223, 0.1804706480470486, 0.12332259779213928, 0.1486346055753529, 0.09356655777082779, 0.15711534972069785, 0.13391520478762686, 0.12261853713425808, 0.15362881415057927, 0.17316935467533767, 0.19619052327470854, 0.12305100884987041, 0.0841170659987256, 0.1548247702885419, 0.1312946664984338, 0.1671043160604313, 0.09575548523571342, 0.131592208344955, 0.14863798976875842, 0.12609250814421102, 0.16518136690137908, 0.07673656320548616, 0.15195343061350286, 0.09732011807500385, 0.16376134153688326, 0.16440983017673716, 0.23868275253335014, 0.14052984828595072, 0.17630837217438966, 0.20980670669814572, 0.07227059308206663, 0.132809508650098, 0.11237044993322343, 0.17163489013910294, 0.1386833848664537, 0.1725414680549875, 0.1944718131562695, 0.11920321063371375, 0.14043504634173587, 0.16968501586234197, 0.10592716091196053, 0.22708999022142962, 0.1300294976681471, 0.14937555097276345, 0.14038846915354952, 0.20776439050678164, 0.1786249119322747, 0.11624762235442176, 0.23006655159406364, 0.12213595560751855, 0.10084894864121452, 0.12087379247532226, 0.355809255852364, 0.6815495376940817, 0.18286944745341316, 0.22857676434796304, 0.6114584393799305, 0.7763280300423503, 0.3953513887245208, 0.24390580976614729, 0.11815199555712752, 0.2835298015270382, 0.3921810822794214, 0.21954418887617067, 0.16682342800777406, 0.2282647803076543, 0.3281383391004056, 0.2810104179661721, 0.2703435887815431, 0.2537806337932125, 0.1510632541612722, 0.3641062887618318, 0.5095185781829059, 0.6083916476927698, 0.5666421598289162, 0.2765920269303024, 0.22687371354550123, 0.17717557173455134, 0.1938936801161617, 0.18563773250207305, 0.2577930997358635, 0.129703383136075, 0.1215789069829043, 0.17252505174838006, 0.20870604232186452, 0.21960280369967222, 0.150106135988608, 0.12841584597481415, 0.144733743800316, 0.18787475855788216, 0.2532264869660139, 0.2407024332205765, 0.15017615020042285, 0.12816877017030492, 0.1450715694227256, 0.08787709783064201, 0.14285389857832342, 0.143896363733802, 0.08344669884536415, 0.09831768329604529, 0.1542273414088413, 0.09301462254370563, 0.1554297690745443, 0.21016264072386548, 0.09589163222699426, 0.15149977058172226, 0.3234281059121713, 0.13271947129396722, 0.10840882852789946, 0.08420516634942032, 0.17890308372443542, 0.1281134653254412, 0.11349095933837816, 0.14655547885922715, 0.13487961085047573, 0.12066979834344238, 0.19345661450643092, 0.12454952375264838, 0.14597454050090164, 0.12359019397990778, 0.13151863182429224, 0.07629479980096221, 0.1555121474666521, 0.08244367141742259, 0.12547076650662348, 0.2642021683277562, 0.254803016432561, 0.10544415636104532, 0.15634191309800372, 0.1984768724651076, 0.20661750517319888, 0.093413756985683, 0.11442956834798679, 0.11630895343841985, 0.11565132153918967, 0.11350327156833373, 0.1374084345297888, 0.18900515337008983, 0.1706087967613712, 0.0902005321404431, 0.059801384049933404, 0.20642465067794546, 0.1424480476998724, 0.1382395953987725, 0.13606878375867382, 0.20083238981897011, 0.07786260161083192, 0.11023480125004426, 0.122141788888257, 0.09787330753169954, 0.08286544878501445, 0.09487539457040839], [0.05103067167510744, 0.032220519497059286, 0.014965523860155372, 0.012838484090025304, 0.023307683986786287, 0.05139848748513032, 0.018321123243367765, 0.03873564099194482, 0.035672526646521874, 0.013939111358922673, 0.050869440092355944, 0.03385639109183103, 0.056795322307152674, 0.07795414552674629, 0.004085496520929155, 0.04601242493663449, 0.0652519689174369, 0.04394039686303586, 0.04574832426442299, 0.04785152254044078, 0.039794240437913686, 0.04015543257992249, 0.052284366902313195, 0.03515700489515439, 0.03772889911488164, 0.029327668671612628, 0.047221528220688924, 0.0864658372302074, 0.02925407730799634, 0.0571078852226492, 0.038425939055741765, 0.027771837703767233, 0.036298127452027984, 0.013188559787522536, 0.0336689616960939, 0.034022624749923125, 0.07190981283201836, 0.04474896675674245, 0.022993180355115328, 0.029401202518783975, 0.026300221943529323, 0.053695564420195296, 0.07212499855086207, 0.0519315387646202, 0.04488827158638742, 0.03272656773333438, 0.054208781803026795, 0.0239880608569365, 0.007240171016746899, 0.011728136541933054, 0.05612211643892806, 0.013487310407072073, 0.0321858352253912, 0.03556887459126301, 0.05750311596784741, 0.016709766641724855, 0.02753719101747265, 0.07539097525295801, 0.040674360789125785, 0.01090028843464097, 0.06102599079895299, 0.021469935236382298, 0.02312804714165395, 0.02804440628096927, 0.09656527967308648, 0.11371433094609529, 0.035322322000865825, 0.13306660344824195, 0.024158003398042638, 0.07061250158585608, 0.03750344207219314, 0.028031524452671874, 0.07124948693672195, 0.2956493105739355, 0.017829606258601416, 0.031285840159398504, 0.8632293075788766, 3.058031019754708, 2.9089968418702483, 5.303631909191608, 6.913098720833659, 15.458643045276403, 19.19507659971714, 33.68150666356087, 38.77080537378788, 29.327787682414055, 24.973924309015274, 31.784692145884037, 26.141987331211567, 27.94706717133522, 20.95804139971733, 34.04634788632393, 28.853029757738113, 38.7669637799263, 43.878251910209656, 34.729042053222656, 34.79941047728062, 12.738036531955004, 7.509654834866524, 0.3918365476420149, 0.6454036210197955, 0.4550963843939826, 0.4386311554117128, 0.33402514352928847, 0.11357425057212822, 0.05178802224691026, 0.021713146306865383, 0.013734773056057747, 0.011735526477423264, 0.02361122238653479, 0.03944652940845117, 0.0359739573468687, 0.04561761350487359, 0.04457594615814742, 0.09009450150188059, 0.03464397304924205, 0.025849814373941626, 0.04846633251872845, 0.07602936326293275, 0.06070130490115844, 0.020155233614786994, 0.012399265324347652, 0.006519720491269254, 0.041524631960783154, 0.01319202468948788, 0.08966559209511615, 0.05229326525295619, 0.022200089806574397, 0.03563699632650241, 0.062487847317242995, 0.06379548183758743, 0.03862002180540003, 0.032472378443344496, 0.026054986665258184, 0.01615567918634042, 0.052863691089442, 0.012726426284643821, 0.06379415339324623, 0.054012212858651765, 0.012729893969662953, 0.017893238000397105, 0.017171597719425336, 0.04794738575583324, 0.07596107825520448, 0.002348216012251214, 0.04249901248840615, 0.048471891204826534, 0.03716010229254607, 0.09023686026921496, 0.04164002479228657, 0.0505314957263181, 0.03597266229917295, 0.03336298534122761, 0.024725670300540514, 0.024475188038195483, 0.024571973372076172, 0.05338800729077775, 0.027195090624445584, 0.01860243246483151, 0.021071826813567895, 0.023277419204532634, 0.021771249048470054, 0.01526795924291946, 0.031385072725242935, 0.02568399260781007, 0.020743009008583613, 0.046015942716621794, 0.012797909948858432, 0.02743675431702286, 0.07270827467436902, 0.04544631468888838, 0.05614137517113704, 0.1284637293429114, 0.021558525404543616, 0.06881919820443727, 0.07114859196008183, 0.02057057285128394, 0.0165280313740368, 0.006569902661794913, 0.04857266743783839, 0.039738364139338955, 0.040753722350928, 0.07380172537523322, 0.0225015483374591, 0.02595211200969061, 0.03066394081542967, 0.06280049929046072, 0.04862506677454803, 0.013429278169496683, 0.10805337689816952, 0.023030946395010687, 0.04485802535782568, 0.083556596073322, 0.016881466217455454, 0.016209169480134733, 0.021830962250533048, 0.010712664225138724, 0.04841063062485773, 0.01658761284488719, 0.02471987969329348, 0.037217232820694335, 0.025232087755284738, 0.010562152037891792, 0.06832817103713751, 0.042373437390779145, 0.031379424981423654, 0.04434205460711382, 0.03214609321730677, 0.09130830629146658, 0.00979915464995429, 0.04388129964354448, 0.0028887026837765006, 0.04578499749186449, 0.046533902423107065, 0.02381865451752674, 0.04584820620948449, 0.02132755605998682, 0.04877277271589264, 0.02827038653776981, 0.038889343486516736, 0.049774712897487916, 0.11244603025261313, 0.015489357665501302, 0.04456576760276221, 0.0238807871210156, 0.012397367281664629, 0.0397529399197083, 0.08377410471439362, 0.05393511484726332, 0.052943765113013797, 0.05822707731567789, 0.054427129070973024, 0.030744161413167603, 0.012012575771223055, 0.04542105940345209, 0.040348012480535544, 0.017164220771519467, 0.06956867087865248, 0.01372486167383613, 0.046308552991831675, 0.06187062906974461, 0.23974476585863158, 0.10663749271770939, 0.13416002446319908, 0.07632228152942844, 0.038578339081141166, 0.11793226047302596, 0.0709268604987301, 0.1729275778052397, 0.136173871869687, 0.18068677629344165, 0.27381799765862525, 3.998185833916068, 9.003896154463291, 8.714700322598219, 14.019477870315313, 18.771433532238007, 31.632234826683998, 37.53134228289127, 57.44725160300732, 60.77889382839203, 49.31388683617115, 41.25017613172531, 51.57722778618336, 45.24389863014221, 49.01646539568901, 40.73559254407883, 53.92740547657013, 49.9219112098217, 64.68000009655952, 73.29148560762405, 64.46173220872879, 61.53303176164627, 30.40955163538456, 18.696349561214447, 2.9009320121258497, 0.1220103025843855, 0.3490973316365853, 0.5826080124825239, 0.3814748005243018, 0.2112010240671225, 0.08286157477414235, 0.04821039918169845, 0.040673039766261354, 0.056874149522627704, 0.06492510481621139, 0.09840006168815307, 0.14665891940239817, 0.028924222351633944, 0.06978282501222566, 0.04519304566201754, 0.015437866532010958, 0.03320017298392486, 0.033453360374551266, 0.02874248708394589, 0.08435923620709218, 0.02769614049611846, 0.01969833225302864, 0.03268767548433971, 0.028699153081106488, 0.026891019733739085, 0.037307674647308886, 0.03576468654500786, 0.030901251811883412, 0.04071471135830507, 0.019468782265903428, 0.06373621392413042, 0.0573235384945292, 0.008371041731152218, 0.051180466762161814, 0.06432228794437833, 0.044982724721194245, 0.033239039257750846, 0.06206799211213365, 0.011849703114421573, 0.03529674017045181, 0.002704236776480684, 0.02307735845533898, 0.06274742088862695, 0.06687361354124732, 0.04153445428528357, 0.03701224421092775, 0.058431594661669806, 0.08868964563589543, 0.03396244028408546, 0.03005218291946221, 0.008374036297027487, 0.05669388185197022, 0.0175853617474786, 0.02264991850097431, 0.030664243240607902, 0.026220398394798394, 0.05375951899623033, 0.053042648869450204, 0.020115597362746485, 0.03232569666579366, 0.023790913037373684, 0.018246463187097106, 0.02703209829633124, 0.02332183674297994, 0.010182011010329006, 0.03346689343743492, 0.11611537905992009, 0.013163747935323045, 0.039451999036828056, 0.029013916464464273, 0.021821804148203228, 0.05899737836443819, 0.03156371138175018, 0.00649004478873394, 0.07606796978507191, 0.04851014891755767, 0.1960980665171519, 0.18025028955889866, 0.07622342003742233, 0.10325636438210495, 0.08899492066120729, 0.1081433474610094, 0.14832548622507602, 0.09682474192231894, 0.11667937418678775, 0.1606116519542411, 0.1820521944318898, 0.11558342986973003, 0.10987508969265036, 0.300981582258828, 0.10588918521534652, 0.09292019909480587, 0.22603389923460782, 0.1101041461515706, 0.0945887845591642, 0.11278217862127349, 0.10815104353241622, 0.10873892097151838, 0.14713186043081805, 0.17071811511414126, 0.11333502669003792, 0.09202990389894694, 0.15676796523621306, 0.2120779754477553, 0.15597800840623677, 0.22225675347726792, 0.12479296303354204, 0.11656284215860069, 0.171059621789027, 0.05286882304062601, 0.14881270617479458, 0.143062827992253, 0.19322258565807715, 0.13100292824674398, 0.1504039004794322, 0.0899897250928916, 0.15104858932318166, 0.13750504731433466, 0.23540009977295995, 0.14011325110914186, 0.09274468859075569, 0.14988037466537207, 0.20663832983700559, 0.10970677802106366, 0.15850769297685474, 0.11203240166651085, 0.2290392410941422, 0.14861155446851626, 0.12948658695677295, 0.126116152969189, 0.17754296452039853, 0.22006137674907222, 0.19791845086729154, 0.15859116974752396, 0.0912258611060679, 0.14976589096477255, 0.14571518957382068, 0.12997882382478565, 0.18265382386744022, 0.15535874554188922, 0.19755727727897465, 0.2649713301798329, 0.22207679750863463, 0.2523843274684623, 0.19831303594401106, 0.20878417562926188, 0.18150822987081483, 0.2636090439045802, 0.32848774222657084, 0.36337426397949457, 0.22176380414748564, 0.15720553550636396, 1.852995150256902, 6.48280268535018, 5.662288013845682, 9.803685788065195, 14.767632074654102, 25.089071430265903, 33.177402913570404, 55.25600038468838, 61.59037448465824, 47.40093648433685, 40.45455202460289, 52.748989909887314, 50.71593940258026, 50.187779143452644, 42.86418132483959, 56.65535129606724, 52.110320180654526, 68.1534469127655, 76.695107370615, 63.680665120482445, 57.663885578513145, 29.152295999228954, 15.2923240698874, 1.76128885243088, 0.6288858479820192, 0.8058362372685224, 0.7554007123690099, 0.5727071687579155, 0.3864516131579876, 0.14782275538891554, 0.09820289531489834, 0.09057524992385879, 0.15359014825662598, 0.233774054213427, 0.1794134735246189, 0.28737492801155895, 0.13829279254423454, 0.20869777479674667, 0.20600374904461205, 0.1092292059911415, 0.09305573010351509, 0.11167864213348366, 0.17550614022184163, 0.25452088157180697, 0.12094701276510023, 0.1346724625909701, 0.10980470440699719, 0.11216072642127983, 0.13441894494462758, 0.19440328323980793, 0.19926911510992795, 0.1555176987312734, 0.14174320036545396, 0.10780082404380664, 0.13398731185588986, 0.11273726384388283, 0.1363715503248386, 0.07321882774704136, 0.10626942457747646, 0.1438963192049414, 0.18864867015508935, 0.15658737102057785, 0.23849907098338008, 0.10573262174148113, 0.12233668428962119, 0.09604349790606648, 0.10877475186134689, 0.22852040565339848, 0.10199244978139177, 0.17802862595999613, 0.1288196336827241, 0.20828524458920583, 0.21061869047116488, 0.09851256385445595, 0.1615803624736145, 0.16820189310237765, 0.15552989963907748, 0.1340769781381823, 0.16094109130790457, 0.15688880172092468, 0.12985280714929104, 0.11557103600353003, 0.13381808734266087, 0.16932477738009766, 0.07643821983947419, 0.09189210191834718, 0.13938570889877155, 0.1407738367561251, 0.07911965134553611, 0.168664681550581, 0.1827993887127377, 0.10815347035531886, 0.137507006584201, 0.16290705534629524, 0.09432303631911054, 0.22688989236485213, 0.25064547546207905, 0.08017701882636175, 0.15730444894870743, 0.19746994134038687], [0.04411922476720065, 0.05240596037765499, 0.04013100849988405, 0.01931252863869304, 0.06128738634288311, 0.055119415555964224, 0.0031487507658312097, 0.033670215925667435, 0.02094170977215981, 0.02571147804701468, 0.031587322810082696, 0.022833826405985747, 0.011966876172664342, 0.014827901850367198, 0.019506980606820434, 0.02964086612337269, 0.022586303457501344, 0.01857560197095154, 0.048239966345136054, 0.044221377684152685, 0.012907564123452175, 0.046526317673851736, 0.09397223053383641, 0.05300734490447212, 0.03136611085210461, 0.005617310662273667, 0.06775375615688972, 0.01764517328410875, 0.02889807834435487, 0.10597488842904568, 0.0293023558697314, 0.02691441408387618, 0.043945981524302624, 0.03303502657217905, 0.05813819770992268, 0.03254277115047444, 0.019548166092135943, 0.020989841759728733, 0.016922111790336203, 0.08922592896851711, 0.09228886890923604, 0.06722703168634325, 0.06660405808361247, 0.04865276743657887, 0.040653933174326085, 0.018872800574172288, 0.027482800869620405, 0.030400029390875716, 0.06437837946577929, 0.05564900842728093, 0.01497927492891904, 0.09089195402339101, 0.11323410202749074, 0.037272459740052, 0.0378085612464929, 0.02296458354976494, 0.09411678605829366, 0.060455112252384424, 0.009204795478581218, 0.009837641500780592, 0.03793264091655146, 0.08044421425438486, 0.03707574236614164, 0.1175451191375032, 0.010480100190761732, 0.3512905561365187, 0.24274571420392022, 0.14888971141772345, 0.07858787284931168, 0.13485118659446016, 0.6190249021165073, 1.8579613650217652, 5.755826644599438, 10.33450210466981, 25.3671196103096, 39.60555598139763, 65.20921289920807, 70.62125489115715, 92.83899709582329, 96.03500559926033, 105.41101008653641, 114.15748715400696, 112.86391496658325, 118.30176517367363, 119.12472501397133, 120.26876762509346, 113.54625195264816, 112.07471251487732, 113.46191167831421, 108.85112509131432, 110.7981026172638, 105.40384367108345, 111.53290718793869, 119.56510618329048, 126.3274285197258, 128.6029440164566, 117.70505279302597, 99.5022739470005, 89.59686666727066, 71.03860169649124, 38.50058667361736, 16.982320435345173, 9.033128935843706, 4.898747010156512, 0.9758913028053939, 0.28905319108162075, 0.3769467497477308, 0.16422274959040806, 0.060586672771023586, 0.08644130182801746, 0.03676880864077248, 0.004367194442238542, 0.060688254234264605, 0.09334536065580323, 0.03521225407894235, 0.032083418846013956, 0.03813746996456757, 0.06680685735773295, 0.05448179195809644, 0.017478208610555157, 0.05229854192293715, 0.05378936817578506, 0.03487977563054301, 0.08172366200597025, 0.023299737440538593, 0.03203507534635719, 0.024840829355525784, 0.05763693632616196, 0.08707883636816405, 0.027124206244479865, 0.023225838085636497, 0.041429006232647225, 0.03688245742523577, 0.09124593620072119, 0.03169559844536707, 0.05721848378016148, 0.05872499161341693, 0.0752960100362543, 0.009620356431696564, 0.033115178521256894, 0.014021794959262479, 0.06580279092304409, 0.03271584369940683, 0.03439266329223756, 0.027750000008381903, 0.04115243376872968, 0.05012983427150175, 0.037183665481279604, 0.06371119612595066, 0.021251079597277567, 0.08085364970611408, 0.04419204800797161, 0.08333021876751445, 0.03620627183408942, 0.027943084569415078, 0.03756574536964763, 0.02474999419064261, 0.054773515366832726, 0.05314873516908847, 0.008662589807499899, 0.02058444359136047, 0.020211801966070198, 0.07128614161047153, 0.06073817108699586, 0.00888456153916195, 0.004266411251592217, 0.028272757699596696, 0.06144718558061868, 0.02871896100259619, 0.06113769886724185, 0.008082548520178534, 0.03045515240955865, 0.022868230516905896, 0.03417851658014115, 0.04310311698645819, 0.019240605251980014, 0.01500473337728181, 0.02951870676042745, 0.033643224014667794, 0.05390533246099949, 0.07556766577181406, 0.03314807792776264, 0.035382213318371214, 0.0380918278824538, 0.009555334090691758, 0.059062932268716395, 0.05170204814930912, 0.09101427480345592, 0.042804042604984716, 0.04932160576572642, 0.043610144857666455, 0.015176393990259385, 0.018325950914004352, 0.03774204997171182, 0.06888205069117248, 0.08112394731142558, 0.06510446706670336, 0.043688868172466755, 0.02179687169700628, 0.005236925653662183, 0.04465835794690065, 0.05869592911039945, 0.039414472339558415, 0.08583240676671267, 0.037605813922709785, 0.023766117883496918, 0.03651372135209385, 0.02575689748482546, 0.029838585396646522, 0.024748311370785814, 0.04319190382375382, 0.04105202118807938, 0.044327838768367656, 0.020099715402466245, 0.06621059364988469, 0.11008772984496318, 0.09643065408454277, 0.03857251322187949, 0.09528150520054623, 0.05628222737868782, 0.0190456263590022, 0.07464705384336412, 0.010542754152993439, 0.047977220092434436, 0.09334630318335257, 0.0016972055777841888, 0.049674689944367856, 0.05134149425430223, 0.03871520595566835, 0.03998024491011165, 0.021234826563159004, 0.06373525655362755, 0.03176387232088018, 0.01180151361040771, 0.004962407083439757, 0.013037607877777191, 0.054320211565936916, 0.049612813381827436, 0.07704429473960772, 0.01971210465853801, 0.022641606446995866, 0.3818446572404355, 0.3837045980617404, 0.08671337316627614, 0.1809091682662256, 1.0260400618426502, 3.047869889996946, 4.73713313229382, 15.49045018851757, 23.764994479715824, 44.774753004312515, 64.49988976120949, 87.35761642456055, 95.59349209070206, 119.04910907149315, 119.72630113363266, 129.2096346616745, 134.4434890151024, 128.6251500248909, 130.60745805501938, 130.08829951286316, 135.35021156072617, 130.07267475128174, 124.84946742653847, 127.00064599514008, 121.90487623214722, 126.44849762320518, 116.80846810340881, 125.94097405672073, 131.7436882853508, 140.37986487150192, 140.91186672449112, 130.36015212535858, 123.32437366247177, 117.5434398651123, 100.77391371130943, 67.51288488507271, 36.32232315838337, 21.094853058457375, 11.560633610934019, 2.144073424860835, 0.36821556044742465, 0.07036912167677656, 0.2206474804552272, 0.16307682904880494, 0.06265404386795126, 0.04968091285263654, 0.0552876233268762, 0.04806488999747671, 0.11467394273495302, 0.08863929833751172, 0.06428403765312396, 0.05207838010392152, 0.05131193080160301, 0.022122531663626432, 0.012640830682357773, 0.05737160368880723, 0.05896658665733412, 0.02342950381716946, 0.10638618667144328, 0.029663833738595713, 0.043766181406681426, 0.05045577068813145, 0.022097712389950175, 0.115370923303999, 0.033752234376152046, 0.030667883474961855, 0.109365649841493, 0.018065486765408423, 0.0371169389836723, 0.026404892596474383, 0.01677629647019785, 0.007672972060390748, 0.1088285724108573, 0.08713416347745806, 0.04926056040858384, 0.0524608681735117, 0.008560161368222907, 0.011866697368532186, 0.059515282409847714, 0.053432217027875595, 0.02172660329961218, 0.03170861200487707, 0.0672141405811999, 0.07687938952585682, 0.039586825005244464, 0.020734129211632535, 0.05691228107025381, 0.045017828306299634, 0.018149616626033094, 0.033677411047392525, 0.024262236183858477, 0.03609243380196858, 0.04686194282840006, 0.08321965360664763, 0.02362277577049099, 0.04179293318884447, 0.07592449779622257, 0.05582378049439285, 0.028593139140866697, 0.022385376250895206, 0.02387741034908686, 0.015814736543688923, 0.016180335187527817, 0.06472588269389234, 0.06262184950173832, 0.11158611858263612, 0.026064330304507166, 0.032681304146535695, 0.01582343080372084, 0.17301175219472498, 0.03353810250700917, 0.07581578058307059, 0.1187651431246195, 0.15974513516994193, 0.11062060671974905, 0.15110190521227196, 0.15416273003211245, 0.09179194166790694, 0.11582300998270512, 0.11068494350183755, 0.163141084194649, 0.10286564589478076, 0.1748156757093966, 0.23514447442721575, 0.210651196539402, 0.1541364728473127, 0.13805689348373562, 0.11743430906790309, 0.12012962615699507, 0.1267109249602072, 0.14765281841391698, 0.23399874684400856, 0.13916977361077443, 0.1304431410972029, 0.10812999622430652, 0.15435421897564083, 0.09708786295959726, 0.22733841673471034, 0.09700309485197067, 0.12637252046260983, 0.1641028927406296, 0.11255550445639528, 0.1587286897120066, 0.07325426529860124, 0.11553555392310955, 0.16814939357573166, 0.08991163631435484, 0.21779917704407126, 0.15118636161787435, 0.08387647656491026, 0.148734929098282, 0.1581916568102315, 0.12474240793380886, 0.20937143708579242, 0.1341865339782089, 0.13362346653593704, 0.1484205256565474, 0.11317225886159576, 0.12053305763402022, 0.1780797599349171, 0.10774551177746616, 0.10616239203955047, 0.19197021145373583, 0.2279123046901077, 0.1199425826780498, 0.08735055889701471, 0.12524044839665294, 0.1696837690542452, 0.12062653113389388, 0.15370469132903963, 0.10412461779196747, 0.19753450818825513, 0.1664051684201695, 0.10358801533584483, 0.15042168233776465, 0.17705865378957242, 0.5781195033341646, 0.45901949575636536, 0.4416056239278987, 0.17710447398712859, 0.603366179857403, 2.0676865987479687, 3.7479155883193016, 12.046103160828352, 18.380430713295937, 41.49752765893936, 63.936531990766525, 93.06560173630714, 103.5834601521492, 130.43318420648575, 131.68378829956055, 143.75835478305817, 151.79699063301086, 147.75300443172455, 153.3082303404808, 149.81481939554214, 151.65969640016556, 146.18046641349792, 142.78437584638596, 146.01696878671646, 144.93930101394653, 149.7779157757759, 139.66135382652283, 146.3916438817978, 151.56956523656845, 158.65705132484436, 160.48507243394852, 152.82814890146255, 138.82386356592178, 130.46602964401245, 105.53685173392296, 65.70055693387985, 34.69548225402832, 18.508920818567276, 10.066565182060003, 1.626566844061017, 0.4897956771310419, 0.4386312741553411, 0.4337343462975696, 0.2361965281306766, 0.17086338310036808, 0.11486402901937254, 0.12735312018776312, 0.1520788238849491, 0.311306786024943, 0.2246329322224483, 0.13858430815162137, 0.2128567110048607, 0.129839715664275, 0.1721976458793506, 0.1406828049221076, 0.23418645083438605, 0.172774932871107, 0.07285958374268375, 0.2971490425989032, 0.10464914550539106, 0.20544930535834283, 0.21241105132503435, 0.09929153689881787, 0.1726208778563887, 0.10330740929930471, 0.14311728678876534, 0.18623294978169724, 0.11259883845923468, 0.20093277271371335, 0.11686903002555482, 0.10206177379586734, 0.0880215791403316, 0.22697607055306435, 0.17601109750103205, 0.16499850171385333, 0.1486121630296111, 0.2570293110329658, 0.09580256708431989, 0.16948536329437047, 0.13857357669621706, 0.07106611708877608, 0.11895802730577998, 0.2192574378568679, 0.19423120887950063, 0.0696843494370114, 0.15563580411253497, 0.09895064620650373, 0.09439399305847473, 0.12069689415511675, 0.07631256681634113, 0.1467226995737292, 0.07687661389354616, 0.15223541704472154, 0.15550350886769593, 0.13500055123586208, 0.09927432649419643, 0.1251475463504903, 0.21488931990461424, 0.12579376401845366, 0.14536250615492463, 0.1776980288559571, 0.12074541577021591, 0.1057978268363513, 0.09796780519536696, 0.13332138274563476, 0.2725993614876643, 0.1430746726691723, 0.22290313441772014, 0.10774013862828724, 0.2429335072520189, 0.0607584131648764], [0.07554097814136185, 0.03339215545565821, 0.02345656066609081, 0.04964108178683091, 0.016417820588685572, 0.04013395111542195, 0.03550077883119229, 0.05830627189425286, 0.023322324705077335, 0.02800275138724828, 0.0358276429324178, 0.043345250087440945, 0.026172958459937945, 0.04729154985398054, 0.07514677898143418, 0.04696580639574677, 0.07471256321878172, 0.11097481154138222, 0.03831320682365913, 0.047642667341278866, 0.021322181055438705, 0.02116799987561535, 0.024193103272409644, 0.06129181696451269, 0.04525795389781706, 0.022669628087896854, 0.03761051542824134, 0.01823040311137447, 0.035781741098617204, 0.06303446876700036, 0.018542275829531718, 0.022706535091856495, 0.053503734088735655, 0.018658702101674862, 0.046120923216221854, 0.032575763325439766, 0.03986870011431165, 0.04205918237857986, 0.009764572423591744, 0.0372376233281102, 0.04689979978138581, 0.03682179798488505, 0.021420439552457538, 0.024308182546519674, 0.059558456850936636, 0.04133153626753483, 0.054601893716608174, 0.05936189532803837, 0.03329409548314288, 0.0356065460073296, 0.044008767217746936, 0.035287251812405884, 0.020483292573771905, 0.019667364285851363, 0.0453829464095179, 0.03506135690258816, 0.05539140896871686, 0.03397412168851588, 0.06696645621559583, 0.05071960789791774, 0.025506470883556176, 0.06992923590587452, 0.10798495830385946, 0.046652872406411916, 0.046934049896663055, 2.619064562022686, 5.969925681129098, 12.631834130734205, 26.09970510005951, 45.256943330168724, 55.699729174375534, 60.22579550743103, 89.17818993330002, 103.2899259030819, 104.63861793279648, 104.71275955438614, 103.55119988322258, 116.64154306054115, 91.88508108258247, 89.0828150510788, 90.41566953063011, 97.98123836517334, 93.86325493454933, 83.25642809271812, 89.85447764396667, 97.27440029382706, 84.74810644984245, 92.79507145285606, 100.23866683244705, 97.52125024795532, 95.3700640797615, 91.81980058550835, 93.81861492991447, 87.33851104974747, 90.18028736114502, 93.38728487491608, 106.23744294047356, 100.38510337471962, 104.49788108468056, 107.44894713163376, 118.21888402104378, 113.14725056290627, 105.95090791583061, 80.19199132919312, 51.84890180826187, 33.695911690592766, 21.17532704025507, 4.845377923920751, 0.7894250366371125, 0.17193491075886413, 0.29953243501950055, 0.32509232754819095, 0.053344231710070744, 0.10011993697844446, 0.02385627212788677, 0.01746035624819342, 0.01095571573387133, 0.03539373887178954, 0.011952580553042935, 0.08214048182708211, 0.039859434400568716, 0.026273025941918604, 0.017556868842802942, 0.005039265752202482, 0.023892739409347996, 0.029549253558798227, 0.06832451224909164, 0.035724799818126485, 0.03382841212442145, 0.02198843485530233, 0.051927928216173314, 0.051500425179256126, 0.006622356731895707, 0.03513302239298355, 0.03327321886899881, 0.06597449420951307, 0.07983736009919085, 0.03604060591896996, 0.052126241207588464, 0.03820688303676434, 0.04303131419874262, 0.027772036228270736, 0.015531916124018608, 0.08695906115463004, 0.07934955385280773, 0.045996286935405806, 0.010612612513796194, 0.07136589279980399, 0.06117012329923455, 0.030993007239885628, 0.06848058590549044, 0.026258110628987197, 0.015294561526388861, 0.05416284657258075, 0.03721955945366062, 0.017401696895831265, 0.04397204575070646, 0.029182482321630232, 0.08451423374935985, 0.03973354760091752, 0.06524783515487798, 0.07693822699366137, 0.04284037815523334, 0.10090980475069955, 0.08282408889499493, 0.0356981938239187, 0.079765883856453, 0.005053035838500364, 0.04835000458115246, 0.03771010051423218, 0.06372983887558803, 0.04556476887955796, 0.05890806089155376, 0.029728764238825534, 0.07549290181486867, 0.032234163882094435, 0.006146710575194447, 0.04874011821812019, 0.00438075069723709, 0.010476825464138528, 0.04650246504752431, 0.015172720359259984, 0.030094073445070535, 0.03738775609235745, 0.045947765320306644, 0.018981413886649534, 0.0025616651055315742, 0.06417313110432588, 0.045005115316598676, 0.041723371687112376, 0.017936223193828482, 0.015190511494438397, 0.14629281795350835, 0.026861456281039864, 0.0027892936259377166, 0.031698188540758565, 0.02225028867542278, 0.030752898346690927, 0.02990242122905329, 0.03239803379983641, 0.06948450391064398, 0.0173431061921292, 0.04195725210593082, 0.026968494385073427, 0.06263561634114012, 0.09686036501079798, 0.026444103968970012, 0.04428356223797891, 0.07912408938864246, 0.02107766194967553, 0.0304093062368338, 0.014325597749120789, 0.00917263079827535, 0.03136437422654126, 0.032270247102133, 0.059442321871756576, 0.04933199583319947, 0.06043248788046185, 0.030836163605272304, 0.019100545287074056, 0.014791440135013545, 0.021012922552472446, 0.06668283705948852, 0.031794044334674254, 0.029221218719612807, 0.024973890867840964, 0.03628622340329457, 0.03890849831805099, 0.019503804214764386, 0.04468483035452664, 0.03941134418710135, 0.03009806063346332, 0.04407755688589532, 0.0323124530405039, 0.0687896681483835, 0.03747628317796625, 0.041800016988418065, 0.05688238736183848, 0.13394129869993776, 0.15538665029453114, 0.35416634869761765, 7.282325383275747, 12.800365537405014, 25.570722185075283, 47.401795238256454, 70.73410883545876, 82.42994964122772, 89.57515463232994, 113.34970369935036, 126.05749100446701, 121.26717165112495, 121.84606298804283, 124.39297512173653, 131.80367946624756, 99.83101710677147, 99.00583818554878, 99.07328456640244, 111.97016492486, 107.19707384705544, 98.41335877776146, 103.35982695221901, 111.6493709385395, 99.72507879137993, 109.67357575893402, 115.2311347424984, 114.16107416152954, 109.83138129115105, 109.72896158695221, 111.12230882048607, 99.59175154566765, 106.51409089565277, 107.59068712592125, 123.0536761879921, 117.0266143977642, 116.18378162384033, 120.66888615489006, 131.71347230672836, 130.1468923687935, 130.23801147937775, 102.97914057970047, 77.21893206238747, 55.336544662714005, 39.06271331012249, 12.34348090365529, 1.6250197333283722, 0.30552040901966393, 0.12113338088965975, 0.3338833636371419, 0.011569790985959116, 0.031188214343274012, 0.0759083115553949, 0.03405032170121558, 0.017952279558812734, 0.07492267264751717, 0.04576756815367844, 0.04446853512490634, 0.026849810128624085, 0.03430200995353516, 0.029278341826284304, 0.016895811932045035, 0.06553964762133546, 0.020454499099287204, 0.024201688065659255, 0.06355940466164611, 0.032677333656465635, 0.05078027104900684, 0.018749112387013156, 0.006864254200991127, 0.053764636104460806, 0.048364502436015755, 0.0469833062379621, 0.04882992921920959, 0.021753060864284635, 0.052263872494222596, 0.03814912539382931, 0.045007178487139754, 0.04711669615062419, 0.02786114961054409, 0.021164632380532566, 0.07138296961784363, 0.06341636311844923, 0.020591955981217325, 0.0428219728928525, 0.055647542685619555, 0.025280364461650606, 0.025843181429081596, 0.005601039074463188, 0.03770958472159691, 0.0418223185261013, 0.07624773279530928, 0.028274672440602444, 0.041560885874787346, 0.08525529789039865, 0.05341377094737254, 0.02999323227413697, 0.08845837015542202, 0.0165720518634771, 0.06249509067856707, 0.08472776447888464, 0.053699260315625, 0.058709892618935555, 0.031932295314618386, 0.07890631357440725, 0.0271274958140566, 0.06063885317416862, 0.005777938786195591, 0.03616974703618325, 0.06154370559670497, 0.08196503811632283, 0.0493755227944348, 0.018220434212707914, 0.03086378263105871, 0.10920264452579431, 0.05824671083246358, 0.0640765851130709, 0.21380989579483867, 0.10881700232857838, 0.13336920674191788, 0.12660139880608767, 0.13407249556621537, 0.1054585688689258, 0.1266303870943375, 0.07680201320908964, 0.14508191496133804, 0.08574628795031458, 0.18449041672283784, 0.11046078521758318, 0.12075594684574753, 0.17950425302842632, 0.18796098127495497, 0.15692703716922551, 0.1307504199212417, 0.10512040185858496, 0.18057116452837363, 0.10770213324576616, 0.15488858014578, 0.21758149028755724, 0.14092094526859, 0.13253429060569033, 0.11161469126818702, 0.21362029190640897, 0.3009961580391973, 0.11628925683908165, 0.08962797262938693, 0.2585851197363809, 0.10343489542719908, 0.1236043764220085, 0.17382796620950103, 0.11947210557991639, 0.10830682032974437, 0.03383725481398869, 0.13401912030531093, 0.23267376091098413, 0.14192113769240677, 0.10994145253789611, 0.10012912476668134, 0.14785051171202213, 0.13411426363745704, 0.24368156242417172, 0.0957439374178648, 0.15862754982663319, 0.21902829234022647, 0.10133101066458039, 0.21005887363571674, 0.12613573082489893, 0.1191667043894995, 0.23993177223019302, 0.24423732713330537, 0.2512801601551473, 0.14004709606524557, 0.19509726553224027, 0.19878648163285106, 0.2262490478460677, 0.14954847138142213, 0.1545204600552097, 0.2700213482603431, 0.28597152675502, 4.890282489359379, 9.66436056420207, 22.160595171153545, 43.09010960161686, 71.51591688394547, 86.66438922286034, 95.02454861998558, 125.18473103642464, 136.31119519472122, 136.2212160229683, 135.65416485071182, 135.1966693997383, 141.79066836833954, 113.00369426608086, 110.18797695636749, 112.10536926984787, 120.1074130833149, 115.66234320402145, 106.89135745167732, 113.79025965929031, 121.05423107743263, 110.45472264289856, 118.54695841670036, 124.82167571783066, 125.00317677855492, 120.36118626594543, 118.00942406058311, 119.05926212668419, 114.03900191187859, 116.41325891017914, 116.14165708422661, 129.84473258256912, 123.79040345549583, 128.80062460899353, 134.74289774894714, 147.93528825044632, 147.32820242643356, 143.3617776632309, 115.93692407011986, 80.94248905777931, 56.8074419349432, 37.54163973033428, 11.522370614111423, 1.4419956668280065, 0.28926704835612327, 0.4735663620522246, 0.46827683807350695, 0.12784731632564217, 0.19914645294193178, 0.15799157379660755, 0.12701002531684935, 0.22602975805057213, 0.16193944320548326, 0.07466313618351705, 0.186893550271634, 0.22234100208152086, 0.13392249267781153, 0.10856376669835299, 0.08644372122944333, 0.21899750805459917, 0.1140447128273081, 0.0860270275734365, 0.27353176614269614, 0.12995170574868098, 0.10534530229051597, 0.08965147644630633, 0.09119901762460358, 0.10063767404062673, 0.09191415112582035, 0.13408209895715117, 0.310183233814314, 0.1852446614066139, 0.12910743855172768, 0.12102807755582035, 0.10062047105748206, 0.18157052574679255, 0.16552710381802171, 0.07784492365317419, 0.2213970644515939, 0.25703987921588123, 0.1626776426564902, 0.11970807885518298, 0.20653327141189948, 0.15471634251298383, 0.12380061511066742, 0.17183758551254869, 0.09233224001945928, 0.11630986628006212, 0.2181334255146794, 0.11954360408708453, 0.19651602924568579, 0.1482992438832298, 0.14634982973802835, 0.1978589899954386, 0.17933585972059518, 0.23182386823464185, 0.1372098209685646, 0.2146260504378006, 0.1393219584133476, 0.10570920698228292, 0.08281053727841936, 0.1958598371129483, 0.08667440299177542, 0.16859382129041478, 0.1183958059118595, 0.13781011453829706, 0.1282281568273902, 0.15454662818228826, 0.16502493701409549, 0.1461502959136851, 0.17988783947657794], [0.03870975488098338, 0.07366332225501537, 0.0655281517538242, 0.024325107224285603, 0.08413823947194032, 0.05333196771971416, 0.020106602532905526, 0.05254346920992248, 0.0539910913357744, 0.021474740642588586, 0.10534145054407418, 0.019181047900929116, 0.03543001505022403, 0.08504984172759578, 0.06947312678676099, 0.06334392208373174, 0.026614829475875013, 0.09389066850417294, 0.07709554745815694, 0.10578199682640843, 0.028539624727272894, 0.024254681120510213, 0.021975575291435234, 0.057045162611757405, 0.04356150449893903, 0.03883109602611512, 0.05554473296797369, 0.05038848757976666, 0.005489351415235433, 0.043236781493760645, 0.09292369461036287, 0.06353460950776935, 0.015443071770278038, 0.05025801801821217, 0.013888138801121386, 0.07256299184518866, 0.016549804131500423, 0.051351743313716725, 0.06438136289943941, 0.07983332281582989, 0.04228130717820022, 0.06865017407108098, 0.07679357499000616, 0.025218753216904588, 0.04322328182752244, 0.06808085774537176, 0.06472232038504444, 0.039856885123299435, 0.010265106502629351, 0.006327769560812158, 0.18884413701016456, 0.11827353708213195, 0.060939137256355025, 0.056562273093732074, 0.023755442089168355, 0.036288086193962954, 0.02996398052346194, 0.0367568303772714, 0.09611454370315187, 0.06362829823046923, 0.051571103613241576, 0.0153880823381769, 2.2584282886236906, 8.278649970889091, 28.011694103479385, 55.96857234835625, 81.17334187030792, 88.77297967672348, 107.59420573711395, 107.02716216444969, 102.37909197807312, 95.38648679852486, 84.63857352733612, 78.04735600948334, 91.00127130746841, 82.53209576010704, 65.55655226111412, 62.386317774653435, 90.87157666683197, 93.85117918252945, 95.32853990793228, 84.89189073443413, 96.26052349805832, 93.804662078619, 96.43197029829025, 96.93590685725212, 88.62512201070786, 97.79171973466873, 94.35016080737114, 96.78876355290413, 101.97120666503906, 84.97165605425835, 95.80003380775452, 101.34427830576897, 75.70890069007874, 102.04087972640991, 87.97823712229729, 81.08726128935814, 85.50874203443527, 71.66680678725243, 96.2704485654831, 93.29976797103882, 100.32549977302551, 98.86663645505905, 104.96482282876968, 108.91055390238762, 109.47695910930634, 91.4776137471199, 56.85727246105671, 41.08642391860485, 22.993282489478588, 8.460242226719856, 0.3255174891091883, 0.26135772408451885, 0.2528279833495617, 0.03928570600692183, 0.040777515605441295, 0.04496679081057664, 0.048597080385661684, 0.018824538710759953, 0.01942779159435304, 0.056676445092307404, 0.07355628971708938, 0.030068215164646972, 0.05234162730630487, 0.056813215487636626, 0.06046101974789053, 0.04639854210836347, 0.023266056923603173, 0.04721587676613126, 0.07503079614252783, 0.03549661909346469, 0.00986641549388878, 0.06208140643138904, 0.0680559290049132, 0.020500588325376157, 0.04004448892374057, 0.035147156595485285, 0.02904042226873571, 0.01147452334407717, 0.034110253836843185, 0.06401889055268839, 0.03803916508331895, 0.05682243667251896, 0.0393077106855344, 0.02745364559814334, 0.1788031609612517, 0.017743172029440757, 0.025993913477577735, 0.028780935899703763, 0.026909504776995163, 0.015089098869793816, 0.035590018378570676, 0.05088989368232433, 0.14881344832247123, 0.038769902239437215, 0.03639997237769421, 0.03823349645244889, 0.07563258885056712, 0.011816132064268459, 0.08546217897674069, 0.08625177957583219, 0.03300863209005911, 0.024744053298491053, 0.03094556730502518, 0.021009649681218434, 0.04094687741599046, 0.012313317201915197, 0.020769138172909152, 0.035179955812054686, 0.01715999052976258, 0.08911553450161591, 0.0736102883820422, 0.03757251746719703, 0.08528281672624871, 0.06693593910313211, 0.035760088940151036, 0.12484923267038539, 0.06867010815767571, 0.09768725110916421, 0.006660252647634479, 0.03917341906344518, 0.06025852846505586, 0.011457526306912769, 0.007724619972577784, 0.06860623150714673, 0.13112486311001703, 0.03653983752883505, 0.030799534906691406, 0.03391424521396402, 0.01546533620057744, 0.006739693526469637, 0.039367835779557936, 0.0021505234099095105, 0.061795698129571974, 0.01534168512080214, 0.0530373388028238, 0.051109892228851095, 0.028338571355561726, 0.03354216576553881, 0.05524080122995656, 0.06290825913310982, 0.04347981630417053, 0.016244896469288506, 0.028768953925464302, 0.015381747180072125, 0.03686588526761625, 0.05657788417011034, 0.03413655926124193, 0.02115802541084122, 0.011203991034562932, 0.04006094233773183, 0.06498859554994851, 0.09358995768707246, 0.06535558015457354, 0.03315875743282959, 0.033340654117637314, 0.0056027975006145425, 0.05836625598021783, 0.10114462769706734, 0.03943347874155734, 0.03608644467021804, 0.016178420446522068, 0.0896851476863958, 0.004087987817911198, 0.04007925483165309, 0.06043131899787113, 0.0662631970772054, 0.05901762415305711, 0.04415852148667909, 0.07321254917769693, 0.06588694304809906, 0.07667149169719778, 0.04611074837157503, 0.14914380793925375, 0.027546375094971154, 0.04761419113492593, 0.38278688793070614, 6.655263556167483, 18.092622756958008, 45.809581875801086, 77.96411007642746, 100.02702578902245, 102.72057205438614, 118.74454021453857, 118.71246993541718, 115.99180832505226, 111.38913810253143, 97.31363698840141, 91.96246773004532, 108.36066260933876, 103.80438789725304, 80.37900969386101, 73.05360317230225, 116.3445433974266, 128.53944182395935, 122.2616770863533, 120.81346079707146, 127.51763105392456, 118.71004566550255, 123.6969056725502, 117.20520481467247, 117.75787755846977, 122.97875940799713, 123.05597886443138, 126.94159716367722, 125.42435377836227, 109.62569832801819, 125.38049653172493, 126.0408478975296, 100.13345047831535, 127.57573753595352, 123.75112876296043, 111.96644872426987, 109.40194353461266, 98.59453305602074, 108.37056487798691, 102.63411149382591, 110.45388668775558, 111.0468752682209, 116.9359664618969, 120.73888599872589, 125.54372057318687, 115.52563413977623, 84.17452722787857, 63.85452479124069, 42.535221576690674, 18.960127606987953, 1.7228000052273273, 0.02835412491549505, 0.531498558120802, 0.07367123354924843, 0.08872157282894477, 0.049181072681676596, 0.042784130782820284, 0.027373955635994207, 0.059311251170584, 0.08383870866964571, 0.05044314304541331, 0.04574596052407287, 0.05304308302584104, 0.049486566640553065, 0.0161158685295959, 0.04075214528711513, 0.029893836435803678, 0.0629869638942182, 0.03220012898964342, 0.026694734660850372, 0.07998550761840306, 0.0463441797910491, 0.04473042790777981, 0.0432825608731946, 0.027248625447100494, 0.031018299632705748, 0.0497139421349857, 0.017640820587985218, 0.035740062085096724, 0.024393048988713417, 0.016268411418423057, 0.03909189414116554, 0.02249305631266907, 0.04405928892083466, 0.04808910256542731, 0.009874876905087149, 0.05592821922618896, 0.06579919892828912, 0.03410268764127977, 0.024276129188365303, 0.04698195923992898, 0.035205084932385944, 0.10640797612722963, 0.0510347980161896, 0.08027824034797959, 0.03111606274615042, 0.047625304796383716, 0.04948255904309917, 0.022155737206048798, 0.0599129956390243, 0.04129118940909393, 0.04238105924741831, 0.025240383110940456, 0.01613319582247641, 0.05817984703753609, 0.05835472300532274, 0.023253022955032066, 0.04961331433150917, 0.015009041544544743, 0.0597543764160946, 0.020679019180533942, 0.08946629575802945, 0.04789046673977282, 0.05415731015091296, 0.09451638805330731, 0.2293306082719937, 0.20091064186999574, 0.19136454473482445, 0.2796124492306262, 0.11050104672904126, 0.20130160526605323, 0.18249812128487974, 0.11385240009985864, 0.24700921901967376, 0.25677935569547117, 0.12895856372779235, 0.17979682248551399, 0.17350446403725073, 0.15381908597191796, 0.37517491669859737, 0.11688667087582871, 0.13417394715361297, 0.19384763727430254, 0.2227607459644787, 0.13890027010347694, 0.1147995438077487, 0.15407295984914526, 0.11070084772654809, 0.13658258743816987, 0.12757937132846564, 0.13932084519183263, 0.16597892332356423, 0.17238609201740474, 0.160362379392609, 0.19246758398367092, 0.2140954593778588, 0.09753404214279726, 0.14232799789169803, 0.15443367330590263, 0.21860433305846527, 0.17431223241146654, 0.16444344946648926, 0.11616030868026428, 0.10840643139090389, 0.14007071120431647, 0.11366486680344678, 0.14463537954725325, 0.2214443837874569, 0.1609928486868739, 0.1369061935110949, 0.20563126512570307, 0.1846788777038455, 0.08092797579593025, 0.10946538706775755, 0.2864698047051206, 0.35332460480276495, 0.16463265259517357, 0.17351618997054175, 0.15959066455252469, 0.14663377543911338, 0.16553081455640495, 0.1293660918599926, 0.28843548672739416, 0.11661646232823841, 0.19501914706779644, 0.22441157925641164, 4.469142537564039, 14.80464968830347, 43.751304522156715, 81.835418343544, 109.93118673563004, 116.89950361847878, 135.20638167858124, 131.18821889162064, 126.76744490861893, 117.65700817108154, 107.75884330272675, 97.5145398080349, 111.53435871005058, 101.77525877952576, 84.11785706877708, 85.71282148361206, 120.86685553193092, 121.3208931684494, 121.41999185085297, 111.28902867436409, 122.34171599149704, 119.97932955622673, 118.236393481493, 120.23960798978806, 111.49386808276176, 123.40850874781609, 119.78228732943535, 123.86560142040253, 127.59991943836212, 109.65187892317772, 121.81624218821526, 127.61910080909729, 100.47192871570587, 128.94649118185043, 112.02819541096687, 107.82083317637444, 112.63136744499207, 97.75309100747108, 120.87836891412735, 114.35831397771835, 121.76562130451202, 124.24034491181374, 134.2751580476761, 136.43494695425034, 142.18563437461853, 127.68293738365173, 90.89445903897285, 64.11914259195328, 41.48454375565052, 17.037476375699043, 1.2297306256368756, 0.34548497234936804, 0.8055674016941339, 0.1530815099249594, 0.18369695695582777, 0.12786514271283522, 0.2387812949018553, 0.10696638288209215, 0.17364057392114773, 0.15936971234623343, 0.1856126479106024, 0.11829704832052812, 0.17172259715152904, 0.14232774556148797, 0.10934400881524198, 0.12923333648359403, 0.1195622691011522, 0.18082171358400956, 0.11992868967354298, 0.31471039401367307, 0.2324095118092373, 0.12148271722253412, 0.26260548213031143, 0.10841751907719299, 0.07013215392362326, 0.11741185910068452, 0.10076006161398254, 0.09429122786968946, 0.11923330472200178, 0.11358939780620858, 0.12190733701572753, 0.1853542766184546, 0.110593881981913, 0.10737860880908556, 0.3165970224654302, 0.07491165175451897, 0.10029387412942015, 0.13722895353566855, 0.1345806143945083, 0.1026868996268604, 0.13531727017834783, 0.22604923200560734, 0.22317891649436206, 0.09286726170103066, 0.15897655219305307, 0.1232299258117564, 0.23638840299099684, 0.09756436629686505, 0.14878066023811698, 0.17501777736470103, 0.18794073548633605, 0.10881456066272222, 0.09122644740273245, 0.11703382391715422, 0.1167989638634026, 0.135352729994338, 0.14486931933788583, 0.07254490570630878, 0.11372147040674463, 0.16929276112932712, 0.13861332612577826, 0.13122353906510398, 0.21620125888148323, 0.1830302263260819], [0.04168891748122405, 0.005923466524109244, 0.036293262674007565, 0.017059869242075365, 0.038875661994097754, 0.11603238468524069, 0.059610325552057475, 0.051074042785330676, 0.033481395003036596, 0.022248505665629636, 0.08813826701953076, 0.060587151456275024, 0.06418660850613378, 0.009310835393989692, 0.023342965687334072, 0.010973511507472722, 0.0752589620242361, 0.07751059354632162, 0.13109679508488625, 0.08882312831701711, 0.06068503702408634, 0.015894645439402666, 0.07335456655710004, 0.05010789267544169, 0.04485005840251688, 0.062131972663337365, 0.05592032277490944, 0.0065107864247693215, 0.04900826730590779, 0.053995136040612124, 0.049091914770542644, 0.0596342004428152, 0.0315344262344297, 0.03687922166136559, 0.014271369018388214, 0.019702158024301752, 0.018161965963372495, 0.029024499490333255, 0.04109155539481435, 0.015431294814334251, 0.031980516359908506, 0.10178085605730303, 0.022988907439867035, 0.05177976214326918, 0.05379280060878955, 0.014338593682623468, 0.02146948994777631, 0.053288437047740445, 0.07777158461976796, 0.016730721181374975, 0.043855428375536576, 0.04169725922110956, 0.0722629415395204, 0.04672622999351006, 0.054322564174071886, 0.057177424459951, 0.10082695138407871, 0.04840101239096839, 0.13501108973287046, 0.23881921864813194, 10.262530166655779, 40.63685484230518, 66.35088443756104, 78.02616074681282, 90.65700978040695, 101.42574593424797, 90.57709246873856, 83.69812399148941, 76.02980107069016, 74.28738176822662, 77.90174782276154, 63.58455687761307, 83.41757744550705, 91.15795969963074, 83.03914055228233, 76.7251181602478, 93.48234057426453, 102.17959508299828, 47.42734506726265, 38.66458207368851, 33.56301762163639, 33.43875668942928, 34.15081948041916, 43.53118993341923, 45.019874051213264, 44.59745451807976, 36.33400373160839, 38.017925173044205, 41.42497435212135, 34.32797737419605, 48.36313225328922, 40.82312844693661, 41.07748679816723, 43.04047666490078, 34.73811216652393, 36.67745590209961, 37.042540311813354, 36.50065518915653, 58.80426898598671, 46.62033297121525, 80.65982222557068, 100.0256958603859, 91.71740368008614, 79.56644609570503, 84.15786892175674, 88.85728195309639, 72.80192747712135, 90.67996054887772, 99.42494049668312, 96.83567583560944, 98.08523878455162, 91.43026068806648, 62.41285555064678, 20.981461443006992, 3.2203744584694505, 0.40932499046903104, 0.33157326572109014, 0.038291936871246435, 0.1535383315058425, 0.029921191999164876, 0.09656835958594456, 0.05460321102873422, 0.06847176919109188, 0.024855241863406263, 0.02909534305217676, 0.044005587114952505, 0.04673760340665467, 0.02568085146776866, 0.027344703885319177, 0.06445981533033773, 0.03453360826824792, 0.024533520845579915, 0.012708483936876291, 0.028125480348535348, 0.0705088977701962, 0.04816372551431414, 0.09155092920991592, 0.04754588386276737, 0.020600301431841217, 0.013926773153798422, 0.029822488213540055, 0.05751043725467753, 0.017460601156926714, 0.030503674024657812, 0.034789834753610194, 0.05514399177627638, 0.02380598605668638, 0.052391195349628106, 0.01720749911328312, 0.05209705253946595, 0.043735033468692563, 0.040022042667260394, 0.08741745608858764, 0.08617045503342524, 0.02178658738557715, 0.05149354175955523, 0.007509417091569048, 0.036771869999938644, 0.0457127345725894, 0.05067901984148193, 0.03730546675797086, 0.06232223706319928, 0.020935113934683613, 0.015836795028008055, 0.011436966960900463, 0.02371140304603614, 0.035415435559116304, 0.023655420991417486, 0.027700803038896993, 0.008867809410730843, 0.04240272995957639, 0.015191749953373801, 0.03581836608645972, 0.047175385188893415, 0.009258056634280365, 0.024231767310993746, 0.022653115302091464, 0.05140807232237421, 0.03795176977291703, 0.011359183390595717, 0.04822726077691186, 0.1709326551645063, 0.032821332570165396, 0.05213276839640457, 0.032658445998094976, 0.08325469781993888, 0.0390307968336856, 0.08697765195393004, 0.04993795941118151, 0.0503820383164566, 0.06909483927302063, 0.04496212270169053, 0.026596715506457258, 0.025191358690790366, 0.019126765364489984, 0.03185516019584611, 0.04780839262821246, 0.03277953110227827, 0.008028111060411902, 0.058548920787870884, 0.028775943101209123, 0.054919050526223145, 0.0313387812639121, 0.016376920830225572, 0.06068794253224041, 0.025986202563217375, 0.016649493118165992, 0.031628081560484134, 0.029266831115819514, 0.02485323064320255, 0.08499118979671039, 0.013554843062593136, 0.02064415308268508, 0.07635617541382089, 0.04783516931638587, 0.02687422307644738, 0.023488905317208264, 0.051749460253631696, 0.09521430372842588, 0.059963239036733285, 0.01861389679106651, 0.0720497225120198, 0.09599290569894947, 0.017987420251301955, 0.0946243928046897, 0.04875906524830498, 0.032373134745284915, 0.07862494312576018, 0.03878803661791608, 0.026378865477454383, 0.10709928668802604, 0.08098165533738211, 0.047939979122020304, 0.060791375653934665, 0.12382020038785413, 1.5150887821801007, 20.92220552265644, 61.60846911370754, 86.64408311247826, 95.4336042702198, 103.61978620290756, 110.69029480218887, 102.2569589316845, 94.68419328331947, 90.11862426996231, 92.16743633151054, 96.15531474351883, 90.58637917041779, 112.02476039528847, 124.92531895637512, 111.57060876488686, 99.9301689863205, 107.83945217728615, 109.55126792192459, 61.54169149696827, 64.79363679885864, 58.554580584168434, 50.28665743768215, 55.536242946982384, 58.24599914252758, 73.93292158842087, 61.495622768998146, 55.824259892106056, 59.55994203686714, 55.29361076653004, 52.800518944859505, 65.06726771593094, 54.1668838262558, 59.74321760237217, 69.79474604129791, 53.54546137154102, 60.00747062265873, 63.14752712845802, 60.495695024728775, 93.52904006838799, 77.42190197110176, 107.30445608496666, 126.90437436103821, 119.82801407575607, 102.24288448691368, 104.29463759064674, 106.48417130112648, 89.42194685339928, 102.47101664543152, 108.8475988805294, 107.30542123317719, 113.66501078009605, 111.07299506664276, 88.87567296624184, 40.17344310879707, 10.943760462105274, 0.9361407451797277, 0.19404905615374446, 0.08250594502897002, 0.04648338814149611, 0.060156605613883585, 0.04558023894787766, 0.12845178076531738, 0.06194865476572886, 0.02094753748679068, 0.01847027822805103, 0.03365323929756414, 0.022562916528841015, 0.04947180532326456, 0.019915818629669957, 0.03364511278050486, 0.06984156600083224, 0.030353162765095476, 0.059025175505666994, 0.029123591048119124, 0.08549400969059207, 0.11192731355549768, 0.06850270190625452, 0.055492170358775184, 0.04235672422510106, 0.042922344655380584, 0.041532632312737405, 0.05458118779642973, 0.021896098696743138, 0.06990975452936254, 0.02561056080594426, 0.056678742039366625, 0.05390143989643548, 0.030715609136677813, 0.016762830200605094, 0.03260971658164635, 0.015642094440408982, 0.018399800173938274, 0.09904218270094134, 0.04756739872391336, 0.018452247750246897, 0.07049416613881476, 0.012138063666498056, 0.047337355208583176, 0.07947276521008462, 0.02130329710780643, 0.0385393577744253, 0.057074941287282854, 0.028476082043198403, 0.05281454235955607, 0.04225815959216561, 0.039852009213063866, 0.02466129641106818, 0.04268960343324579, 0.013394797988439677, 0.0260682840962545, 0.024906863800424617, 0.113046850747196, 0.031349805867648683, 0.04239870380843058, 0.020279159289202653, 0.0109276588409557, 0.1251598956878297, 0.10459069395437837, 0.09896842064335942, 0.08358894629054703, 0.09498693936620839, 0.29442251077853143, 0.13083873549476266, 0.13352464215131477, 0.16144532128237188, 0.11686750120134093, 0.11438201894634403, 0.18878316215705127, 0.22897099319379777, 0.13460403657518327, 0.21841977577423677, 0.14612405357183889, 0.19949336245190352, 0.26226949703413993, 0.1913946314016357, 0.21925771987298504, 0.13208241172833368, 0.12172124348580837, 0.1497170576476492, 0.13355299219256267, 0.08831987055600621, 0.1616089351591654, 0.16940899629844353, 0.07637435061042197, 0.11242817417951301, 0.12572691135574132, 0.13962917786557227, 0.12187797765363939, 0.1371580784325488, 0.11573661657166667, 0.15228192001814023, 0.09923785735736601, 0.1390750310383737, 0.24946415447629988, 0.14507231157040223, 0.19893231365131214, 0.22098539513535798, 0.24909195257350802, 0.15794211707543582, 0.16150331270182505, 0.11047908657928929, 0.14338284207042307, 0.14210001012543216, 0.10037810046924278, 0.16185166197828948, 0.19828634831355885, 0.16489142464706674, 0.1929508853936568, 0.22183500579558313, 0.24106270138872787, 0.17076970922062173, 0.17083047627238557, 0.10923856447334401, 0.14520573487970978, 0.2735097985714674, 0.740117160603404, 17.78619769960642, 60.29542297124863, 92.17171490192413, 105.13648241758347, 118.44361916184425, 122.87104278802872, 113.91559213399887, 105.22935703396797, 96.6983512043953, 96.2129956483841, 98.42183992266655, 86.12501576542854, 106.0472783446312, 114.32388022542, 105.316501557827, 96.07310235500336, 112.60720834136009, 118.18791568279266, 63.20817947387695, 50.99964737892151, 50.27302756905556, 44.34292517602444, 49.56991329789162, 59.66197036206722, 65.41695535182953, 63.91240328550339, 50.438611283898354, 54.218348264694214, 57.00300604104996, 50.338710844516754, 66.42960101366043, 58.1701248139143, 57.527814880013466, 62.636036574840546, 53.19657929241657, 53.20463106036186, 50.627867728471756, 52.683416828513145, 80.7649701833725, 65.55211409926414, 106.24049037694931, 127.06760600209236, 120.09675085544586, 105.77927112579346, 106.97755202651024, 111.52557358145714, 93.1938524544239, 110.92809364199638, 122.54338636994362, 122.94050306081772, 128.5218259692192, 127.56306141614914, 92.85597458481789, 38.005526438355446, 9.69273554161191, 0.6818205106537789, 0.5525379104074091, 0.1630013674730435, 0.24699390109162778, 0.18078920751577243, 0.3348510945215821, 0.17370840621879324, 0.1951795251807198, 0.11521710577653721, 0.06618130108108744, 0.09677694761194289, 0.11252275347942486, 0.12077124993083999, 0.08653573269839399, 0.1623845536960289, 0.1544598859618418, 0.07698644432821311, 0.18396190367639065, 0.19254534621722996, 0.16388107964303344, 0.22882186603965238, 0.17433454137062654, 0.20939061418175697, 0.19805617863312364, 0.12792298570275307, 0.08407129033003002, 0.15573391603538767, 0.11305289925076067, 0.13664008904015645, 0.09281127408030443, 0.21817134926095605, 0.059157515279366635, 0.10112900548847392, 0.10785428836243227, 0.09443526389077306, 0.12758907862007618, 0.12833964225137606, 0.18305701785720885, 0.17955866729607806, 0.14084156515309587, 0.1401389591046609, 0.18274740868946537, 0.16844657919136807, 0.18208124209195375, 0.11066263454267755, 0.21349279093556106, 0.13761587964836508, 0.14428054390009493, 0.08752857043873519, 0.14684706868138164, 0.2187321605742909, 0.14186483836965635, 0.1224218679999467, 0.1534590998198837, 0.11237119950237684, 0.14481732447165996, 0.25775967340450734, 0.08867233875207603, 0.1378286533872597, 0.10270069615216926, 0.10440548358019441], [0.021585804897767957, 0.009006885102280648, 0.02459748098772252, 0.08144370905938558, 0.07119843459804542, 0.020734780446218792, 0.009634958187234588, 0.04442387267772574, 0.07270830436027609, 0.020862459532509092, 0.013999972106830683, 0.011724356227205135, 0.04366148292319849, 0.03948557008698117, 0.11833687938633375, 0.027483876983751543, 0.04726049468445126, 0.05580769073276315, 0.08543708696379326, 0.016438667516922578, 0.07688986122957431, 0.05684585885319393, 0.03382017799594905, 0.03207019006367773, 0.036422136618057266, 0.0455273349507479, 0.061783983328496106, 0.043840681901201606, 0.034348535191384144, 0.048472855996806175, 0.03624287084676325, 0.03777670084673446, 0.022253819442994427, 0.050176099757663906, 0.011022323487850372, 0.041091607345151715, 0.03783858112001326, 0.07043997451546602, 0.024229112277680542, 0.03398424087208696, 0.04806630749953911, 0.06194436515215784, 0.039124181275838055, 0.05291624256642535, 0.047579618185409345, 0.02125743052602047, 0.046585348100052215, 0.013509847576642642, 0.06249687183299102, 0.07904865007731132, 0.02398639844614081, 0.05274042778182775, 0.06238475558348, 0.06794105938752182, 0.0481849806237733, 0.24304566060891375, 0.08301283931359649, 3.1840073224157095, 19.57936517894268, 55.31170919537544, 82.80777096748352, 85.17969489097595, 85.62202915549278, 83.96826669573784, 79.99364957213402, 58.412190824747086, 73.88335704803467, 83.30220803618431, 86.09774082899094, 62.77258224785328, 55.88570639491081, 49.712413251399994, 45.45153468847275, 40.96725471317768, 37.79943309724331, 36.92213997244835, 25.53431823849678, 74.49412107467651, 134.71274256706238, 43.09390939772129, 32.03832283616066, 55.25588259100914, 48.60247381031513, 40.68598620593548, 32.64975942671299, 40.483677461743355, 44.85093131661415, 34.572938829660416, 50.282185077667236, 43.223064467310905, 30.305473320186138, 48.948099464178085, 45.81299789249897, 37.82443195581436, 42.87112735211849, 39.10247817635536, 38.40653792023659, 38.243427872657776, 24.152003712952137, 26.03280209004879, 29.938031136989594, 40.83622254431248, 42.50071942806244, 45.86575046181679, 77.08115145564079, 67.58075684309006, 88.5924057662487, 83.61273497343063, 80.9615108370781, 79.90486353635788, 78.69700714945793, 77.28084594011307, 82.26822271943092, 99.31488320231438, 67.49925881624222, 44.70417559146881, 12.848233468830585, 0.76865273877047, 0.40492013620678335, 0.1003379280155059, 0.10587757802568376, 0.009607496867829468, 0.042894551224890165, 0.03222289808036294, 0.04596834507538006, 0.014719303380843485, 0.04242722083290573, 0.09422729184734635, 0.09387017038534395, 0.05152158752025571, 0.021781488831038587, 0.08012816324480809, 0.03517852346703876, 0.03314950656204019, 0.04404039013024885, 0.003595251391743659, 0.011742008209694177, 0.11501066997880116, 0.04381617247418035, 0.04433951275132131, 0.046629977150587365, 0.022164670808706433, 0.004097959499631543, 0.0593422135716537, 0.09852644943748601, 0.08224227480241098, 0.051091921122861095, 0.02071040460577933, 0.029302697257662658, 0.007336738344747573, 0.00480974034871906, 0.030497029947582632, 0.05977450717182364, 0.025123361265286803, 0.007033805723040132, 0.0843042133783456, 0.02122840698575601, 0.02994372360262787, 0.03351681400090456, 0.03276118150097318, 0.0344990427402081, 0.09331959328847006, 0.08796972528216429, 0.022356764602591284, 0.024413368992100004, 0.026997087479685433, 0.02288776755449362, 0.06475571703049354, 0.03336646972456947, 0.06196593938511796, 0.017961981284315698, 0.050828024541260675, 0.05033700479543768, 0.050431836425559595, 0.004982324935554061, 0.007680168109800434, 0.004180529458608362, 0.02732310924329795, 0.02659215129824588, 0.04870421311352402, 0.06905785805429332, 0.08611744342488237, 0.019878833700204268, 0.07757691186270677, 0.044650216586887836, 0.044644980735029094, 0.021811774022353347, 0.026519469065533485, 0.012113463326386409, 0.03386154530744534, 0.0673540576826781, 0.059141978417756036, 0.04686120810220018, 0.06256656692130491, 0.052697813662234694, 0.04517452165600844, 0.015893424606474582, 0.03578638694307301, 0.04977677977876738, 0.04508538972004317, 0.0571724223846104, 0.0674717994115781, 0.009580507739883615, 0.02668158009328181, 0.031169304420473054, 0.02748422764852876, 0.01358921748760622, 0.008132416205626214, 0.04932908290356863, 0.04156316426815465, 0.03996539082436357, 0.04797112334927078, 0.03641407689428888, 0.02036931909970008, 0.05021171542466618, 0.04130497851292603, 0.1058750695665367, 0.0204261935868999, 0.019879464525729418, 0.03261585043219384, 0.0644473398278933, 0.06150281697046012, 0.10862322014872916, 0.05516020770301111, 0.05456833750940859, 0.047369427120429464, 0.07126567317754962, 0.04314701131079346, 0.07671751227462664, 0.05570135581365321, 0.0466002912435215, 0.0843823169998359, 0.09783319444977678, 7.137062977999449, 34.62606757879257, 80.96166282892227, 98.0995412170887, 96.28483459353447, 97.92324587702751, 102.2500129044056, 93.81587147712708, 78.0337755382061, 97.88976207375526, 119.96114373207092, 119.98809188604355, 85.93377202749252, 84.09375876188278, 75.57793691754341, 64.22999024391174, 57.7344173938036, 55.09509801864624, 51.037375554442406, 41.54363438487053, 98.51359739899635, 146.33595407009125, 53.62920127809048, 41.227069571614265, 56.19193956255913, 55.36602348089218, 54.15372893214226, 47.95012101531029, 53.87728996574879, 55.112098306417465, 44.99777443706989, 56.078443452715874, 50.11831507086754, 43.12522351741791, 53.171823620796204, 43.93818989396095, 44.52852241694927, 47.35515274107456, 43.131086602807045, 39.47100140154362, 42.16396629810333, 26.387665048241615, 36.21804915368557, 53.27920205891132, 62.41948239505291, 68.89096453785896, 75.10508269071579, 107.41085797548294, 102.38685116171837, 117.69697442650795, 114.98774260282516, 107.04923897981644, 99.3389967083931, 94.94420573115349, 87.2948893904686, 90.19303947687149, 111.3441713154316, 92.91732609272003, 66.81693702936172, 26.734255850315094, 2.963777552358806, 0.04977700984454714, 0.19138802628731355, 0.04664673484512605, 0.05546738262637518, 0.09404930999153294, 0.06261733724386431, 0.0631456276460085, 0.02172975928260712, 0.03983264286944177, 0.06097073419368826, 0.11535418045241386, 0.046249704391811974, 0.03538482567819301, 0.031965491580194794, 0.04188327853626106, 0.01961964604561217, 0.003960888998335577, 0.045653574270545505, 0.04108508386707399, 0.0719963843584992, 0.05487336020451039, 0.04257311222318094, 0.0701033734367229, 0.015307967496482888, 0.006688238108836231, 0.012740537295030663, 0.008597129599365871, 0.029435137221298646, 0.049689562583807856, 0.040372744551859796, 0.09694072476122528, 0.04326139111071825, 0.061174286747700535, 0.05734943944844417, 0.021470484425663017, 0.0605985100264661, 0.057462227341602556, 0.07786683927406557, 0.049710643288563006, 0.037670922538382, 0.052075667554163374, 0.020898917537124362, 0.1188293240556959, 0.013889061847294215, 0.074268313619541, 0.012100807853130391, 0.014511258978018304, 0.03631900035543367, 0.0053751576160721015, 0.029369746589509305, 0.043920711395912804, 0.06889087482704781, 0.03398535780434031, 0.03026623686309904, 0.05235163145698607, 0.08025280694710091, 0.025279883921029978, 0.029519159470510203, 0.08868720397003926, 0.08076093319687061, 0.10507981380214915, 0.15053309354698285, 0.1444659472326748, 0.1371861167717725, 0.1950168760959059, 0.18884535413235426, 0.1386996527435258, 0.10303991701221094, 0.17640241712797433, 0.13301140250405297, 0.09558409365126863, 0.18939927831524983, 0.1440212078159675, 0.17670335801085457, 0.09292248490964994, 0.08895331586245447, 0.1948955052648671, 0.10974948861985467, 0.22899655275978148, 0.22488100250484422, 0.19756852823775262, 0.15030158800072968, 0.15163804753683507, 0.15842669497942552, 0.13220164517406374, 0.1130323120742105, 0.10626685674651526, 0.12492199282860383, 0.12685467896517366, 0.09551669922075234, 0.11997040579444729, 0.17287582042627037, 0.07818643032805994, 0.20634595333831385, 0.1658040436450392, 0.18576873640995473, 0.23050867865094915, 0.1487280271248892, 0.24103987292619422, 0.109261541365413, 0.08277226472273469, 0.16497548029292375, 0.13533518562326208, 0.09151803722488694, 0.2461623988347128, 0.14689118193928152, 0.15571980038657784, 0.09897351177642122, 0.14271667547291145, 0.1295501593267545, 0.14099861844442785, 0.19145415164530277, 0.12683881184784696, 0.3109374636551365, 0.19552310986910015, 5.032535931095481, 31.56922660768032, 81.54173970222473, 108.445595651865, 108.61733883619308, 106.10505804419518, 104.07484218478203, 99.73597660660744, 79.04278099536896, 94.50060993432999, 103.44886377453804, 105.94216078519821, 80.69770619273186, 74.18258339166641, 66.10695272684097, 60.2057059854269, 51.33284769952297, 51.49032644927502, 49.275911673903465, 33.50557990372181, 84.44610625505447, 146.22387528419495, 61.13495372235775, 46.38667590916157, 71.32036417722702, 67.29389503598213, 57.50847391784191, 47.75600463151932, 58.462355732917786, 61.819437593221664, 46.980299055576324, 70.65420672297478, 63.33630859851837, 44.975659623742104, 72.04530447721481, 61.52795523405075, 55.05209192633629, 59.97733823955059, 54.70161773264408, 54.242248982191086, 58.94064746797085, 36.723448634147644, 38.619432896375656, 48.6297145485878, 58.83971348404884, 60.10245032608509, 65.21467700600624, 99.08925130963326, 89.54833567142487, 111.39727726578712, 109.1019344329834, 103.62412557005882, 103.90629082918167, 102.03401729464531, 98.42810198664665, 105.7946527004242, 131.26401722431183, 102.3674950003624, 72.47296392917633, 22.90296893566847, 1.9211899721994996, 0.5329154070932418, 0.23867659270763397, 0.24841444595949724, 0.12508873856859282, 0.2514414140023291, 0.1407322022714652, 0.15193667291896418, 0.07704628369538113, 0.10706241679145023, 0.3520855150418356, 0.3214310755720362, 0.1407799223670736, 0.3132876969175413, 0.184152249712497, 0.11916604387806728, 0.08754350244998932, 0.10008548648329452, 0.06493386958027259, 0.13627827720483765, 0.1696295477449894, 0.15542123437626287, 0.10903181697358377, 0.08181179946404882, 0.09252951029338874, 0.10484132464625873, 0.21829331381013617, 0.23569376760860905, 0.08781009673839435, 0.12194915703730658, 0.07486919348593801, 0.15945146733429283, 0.15112663357285783, 0.12776487856172025, 0.1762712944764644, 0.169374501274433, 0.13814639649353921, 0.24031071283388883, 0.22596821916522458, 0.09729251018143259, 0.09504422574536875, 0.0768752112344373, 0.14560358540620655, 0.23786725098034367, 0.2569184638559818, 0.19329213973833248, 0.14091401360929012, 0.10530011291848496, 0.13912441354477778, 0.10508888284675777, 0.13284522079629824, 0.13182941358536482, 0.19759851100388914, 0.12088601564755663, 0.1446554620633833, 0.16571176500292495, 0.13825562578858808, 0.09533764867228456, 0.1726444039377384], [0.06519141708849929, 0.04601373853802215, 0.04320504354836885, 0.003101715765296831, 0.04681138772866689, 0.06742288445821032, 0.021293287391017657, 0.006619203995796852, 0.03755982674192637, 0.0036430688942346023, 0.023193988818093203, 0.02870935575629119, 0.005398066323323292, 0.04075843498867471, 0.03298215968243312, 0.0303020770297735, 0.06615467282244936, 0.025215766072506085, 0.041312574394396506, 0.01071673304977594, 0.018656546162674204, 0.04518310830462724, 0.02532930167944869, 0.03716129343956709, 0.10135449221706949, 0.050867833342636004, 0.05676570690411609, 0.05676307970134076, 0.04602330482157413, 0.06945601286133751, 0.07567910666693933, 0.018832013993232977, 0.026273382172803394, 0.04868580785114318, 0.030966837257437874, 0.04512529128987808, 0.07393546780804172, 0.04807607416296378, 0.04085104388650507, 0.03219212492695078, 0.0880249188048765, 0.02864548467186978, 0.035529633532860316, 0.04645058521418832, 0.03624531251261942, 0.03979121247539297, 0.1266054212464951, 0.02919959995779209, 0.056826032378012314, 0.004762353291880572, 0.06600277745747007, 0.016128588940773625, 0.08387450245209038, 0.12246815575053915, 0.600943275494501, 8.595315478742123, 38.79010073840618, 58.26585307717323, 80.99223598837852, 81.48465916514397, 85.06049528717995, 81.93938836455345, 73.47497776150703, 72.83436253666878, 80.0330838561058, 79.71289783716202, 51.48414798080921, 34.81623217463493, 33.895583376288414, 39.459989592432976, 19.02060706168413, 33.376029655337334, 37.838327810168266, 42.63573378324509, 35.200117975473404, 49.18148674070835, 27.495391108095646, 13.87277439236641, 49.385657384991646, 68.99642407894135, 58.88597220182419, 48.59977215528488, 45.867076590657234, 39.614257514476776, 48.546514213085175, 45.151624381542206, 48.12325492501259, 46.352234557271004, 41.592568159103394, 50.70131778717041, 36.81388758122921, 41.71194635331631, 61.474526301026344, 57.08147943019867, 51.20779260993004, 61.03838950395584, 71.44809052348137, 75.49671247601509, 95.39448156952858, 66.26469746232033, 28.178051076829433, 27.512410394847393, 28.360663577914238, 22.028468661010265, 8.95246496424079, 22.565813027322292, 31.360384114086628, 35.95083609223366, 57.60856814682484, 66.28683507442474, 70.46696797013283, 79.10851746797562, 82.04763695597649, 73.19940894842148, 84.49728950858116, 90.41827619075775, 78.66676837205887, 55.601158663630486, 10.620606802403927, 0.6444355042185634, 0.5183519166894257, 0.24498796497937292, 0.05002754776796792, 0.053104929902474396, 0.06436885028961115, 0.05358592694392428, 0.029168930705054663, 0.010737858283391688, 0.08507936436217278, 0.03746138456335757, 0.017914088639372494, 0.026506077010708395, 0.036377403666847385, 0.050519202050054446, 0.0018906437026089407, 0.11694872926454991, 0.042581698871799745, 0.024046102371357847, 0.006576814375875983, 0.000940466060228573, 0.04966225897078402, 0.010688638121791882, 0.010316932530258782, 0.02822636604832951, 0.08987489258288406, 0.044481704535428435, 0.05868167987500783, 0.012880835674877744, 0.019401378558541182, 0.006045457976142643, 0.048539107519900426, 0.020420267537701875, 0.03433965168369468, 0.03416092768020462, 0.04187091064522974, 0.061388826798065566, 0.02375729745835997, 0.036135162954451516, 0.03326157828269061, 0.03833075490547344, 0.04425310078659095, 0.018050077924272045, 0.03454728233919013, 0.09279030098696239, 0.052325507858768106, 0.03492370335152373, 0.03781658386287745, 0.0462226085801376, 0.10701932769734412, 0.026239929866278544, 0.09855476237135008, 0.03061737290408928, 0.03448314222623594, 0.02204037591582164, 0.14568146638339385, 0.041389219695702195, 0.042424296771059744, 0.08044379865168594, 0.02457666560076177, 0.025664396198408213, 0.040700859171920456, 0.052100191824138165, 0.009814656259550247, 0.042364312685094774, 0.010856159406102961, 0.03562131845683325, 0.021635192970279604, 0.044518221911857836, 0.04906212867354043, 0.027845740769407712, 0.02824056333338376, 0.045004436251474544, 0.020532302150968462, 0.016791805501270574, 0.016153569631569553, 0.03611259424360469, 0.04151515102421399, 0.07772248412948102, 0.042541084840195253, 0.006426580030165496, 0.08081300227786414, 0.05201727537496481, 0.07983739720657468, 0.059868151365662925, 0.06383285639458336, 0.04217283858451992, 0.054412245299317874, 0.025992952396336477, 0.045921348573756404, 0.051973329100292176, 0.03312567248940468, 0.0740219428553246, 0.04000624976470135, 0.052633068698924035, 0.07836634176783264, 0.0651475487393327, 0.014032734216016252, 0.026610033346514683, 0.025486293743597344, 0.055978032178245485, 0.091328663402237, 0.042066622409038246, 0.06756384056643583, 0.01025117917379248, 0.05194540208321996, 0.033126518537756056, 0.06944245382328518, 0.04467865939659532, 0.041972198960138485, 0.4129268112592399, 2.313153902068734, 18.733236081898212, 61.285307854413986, 80.41620209813118, 94.43300396203995, 87.58992075920105, 95.24685189127922, 103.94275367259979, 103.2880412042141, 99.44871962070465, 122.87551894783974, 102.63237878680229, 72.17873811721802, 57.750802114605904, 56.504366397857666, 46.94455437362194, 24.44825291633606, 25.652427300810814, 30.66040087491274, 20.773299112915993, 26.816844418644905, 29.654028676450253, 15.030756555497646, 10.27175322175026, 48.12413647770882, 34.71739947795868, 33.04595656692982, 30.200855433940887, 20.994650535285473, 24.31707825511694, 29.773053489625454, 31.438612416386604, 32.8295923769474, 35.801428109407425, 32.70094268023968, 37.554350048303604, 20.162660479545593, 30.011545792222023, 39.56865236163139, 33.90350975096226, 28.628011532127857, 34.71663951873779, 29.247209206223488, 39.129141345620155, 59.77670140564442, 28.22172213345766, 27.975711934268475, 24.311361461877823, 26.91049039363861, 19.61550883948803, 18.546096123754978, 33.77652436494827, 40.69854073226452, 50.68640358746052, 74.41947788000107, 93.20424109697342, 94.14301872253418, 111.49250775575638, 106.99117049574852, 92.9511670768261, 92.96444356441498, 101.05183839797974, 96.47536396980286, 81.80561274290085, 26.045521907508373, 4.573998861014843, 0.2135061941226013, 0.40187985403463244, 0.02111510886606993, 0.04971223519532941, 0.036202742921886966, 0.12113418240915053, 0.03895653753716033, 0.065497523319209, 0.08991792230517603, 0.03147383358736988, 0.05522449624550063, 0.04262935217411723, 0.022973598788667005, 0.07340488416957669, 0.016554821049794555, 0.05626033773296513, 0.06281808819039725, 0.13236533326562494, 0.009941699881892418, 0.019187825564586092, 0.055701122037135065, 0.061757945077260956, 0.029886899210396223, 0.10655317732016556, 0.042128246641368605, 0.02513544342946261, 0.04561954679957125, 0.030523932800861076, 0.06551279671839438, 0.026593177317408845, 0.040664779662620276, 0.01052331544997287, 0.009812330554268556, 0.05623252574878279, 0.045533435404649936, 0.13632627931656316, 0.0630131691286806, 0.005671753688147874, 0.017655429765000008, 0.030213653844839428, 0.054661888934788294, 0.016085637143987697, 0.0332531697495142, 0.06430665831430815, 0.005544447067222791, 0.015628628170816228, 0.026373763212177437, 0.03146451592328958, 0.05105188967718277, 0.0076184506451681955, 0.017751189079717733, 0.021688690685550682, 0.050965251357411034, 0.008337102390214568, 0.017371547146467492, 0.040114480871125124, 0.18697857070947066, 0.1988822186831385, 0.17258074251003563, 0.1292843368719332, 0.16498653829330578, 0.19348478643223643, 0.11821669599157758, 0.08150639085215516, 0.09939188268617727, 0.09910076041705906, 0.11166510535986163, 0.13351869012694806, 0.18389712902717292, 0.21665005042450503, 0.07659127295482904, 0.1601813398883678, 0.22052803920814767, 0.17925162595929578, 0.15761656657559797, 0.06899515399709344, 0.12617697939276695, 0.18277102382853627, 0.1467225214582868, 0.1409256356419064, 0.15581080253468826, 0.12560070172185078, 0.23859652981627733, 0.14626455696998164, 0.15508793585468084, 0.1807022574939765, 0.17242184869246557, 0.09009505811263807, 0.1133309597207699, 0.22779609920689836, 0.1823397766565904, 0.11993814463494346, 0.15560739469947293, 0.21574543177848682, 0.11240180567256175, 0.14762011938728392, 0.11936512499232776, 0.12532465247204527, 0.11834026357973926, 0.1331541026593186, 0.18827997118933126, 0.1425184032996185, 0.3113237366778776, 0.12889405625173822, 0.13049863890046254, 0.10120891995029524, 0.11174256331287324, 0.35081875801552087, 0.17042317078448832, 0.38751232030335814, 1.4423454855568707, 14.186546355485916, 58.655468970537186, 84.7754193842411, 108.01834657788277, 101.21541202068329, 102.33900412917137, 100.63640668988228, 92.85728171467781, 91.35928049683571, 102.96315103769302, 98.99370923638344, 66.74400374293327, 43.7935658544302, 44.46267195045948, 53.73719908297062, 28.22958391159773, 46.016165390610695, 53.257079645991325, 57.77475982904434, 49.60203297436237, 63.429103419184685, 38.985087275505066, 19.265258833765984, 59.494824931025505, 87.07162857055664, 76.52786314487457, 65.00658497214317, 61.016544476151466, 51.523529067635536, 64.56260919570923, 61.350702345371246, 66.77171185612679, 63.49676638841629, 57.29844018816948, 71.41118690371513, 52.24469996988773, 60.57667627930641, 81.57459273934364, 74.65136423707008, 68.88855546712875, 77.27337554097176, 89.57221359014511, 90.32483920454979, 117.84651160240173, 82.0790308713913, 42.87863954901695, 42.14406676590443, 41.17665387690067, 35.269209668040276, 19.426858462393284, 36.745324060320854, 42.99045614898205, 50.501760095357895, 73.10170859098434, 89.61664840579033, 92.58437275886536, 106.34419441223145, 103.60938236117363, 94.10397961735725, 103.02981466054916, 113.45717713236809, 108.64807158708572, 86.7137561738491, 24.74676299840212, 2.321085026487708, 0.5910806672181934, 0.4102888621855527, 0.12210906759719364, 0.1639034628169611, 0.13989137863973156, 0.23107355693355203, 0.07706278905970976, 0.1565484082675539, 0.15565737092401832, 0.16394290054449812, 0.20180340099614114, 0.11756454856367782, 0.1372850895859301, 0.18076249019941315, 0.14675484941108152, 0.19336365308845416, 0.09510057701845653, 0.23739105934510008, 0.1157542945293244, 0.12971169519005343, 0.1184951126924716, 0.14095380756771192, 0.1559295758488588, 0.26462023495696485, 0.2000536839477718, 0.1606298197293654, 0.138605103129521, 0.15733481763163581, 0.10112035946804099, 0.1185272699513007, 0.1154989586211741, 0.11965936428168789, 0.16713394259568304, 0.15098188509000465, 0.1634425891097635, 0.27564742136746645, 0.175475652795285, 0.15602336847223341, 0.11699774069711566, 0.14564918295945972, 0.1925701042637229, 0.10823737015016377, 0.1994109692168422, 0.11213545629289001, 0.08959053870057687, 0.13509330485248938, 0.21520069538382813, 0.14853731001494452, 0.1657913826056756, 0.11358993957401253, 0.13534652563976124, 0.18175267847254872, 0.11335165079799481, 0.1392800864414312, 0.19924149237340316, 0.13381229859078303], [0.05120107249240391, 0.009076997648662655, 0.10536012297961861, 0.05494836164871231, 0.045839779122616164, 0.025938658727682196, 0.09564661959302612, 0.06831511665950529, 0.028942071003257297, 0.04360348408226855, 0.009484016482019797, 0.019541937617759686, 0.04486191050091293, 0.05781269173894543, 0.018760541461233515, 0.021991759676893707, 0.0175067274903995, 0.03052099018532317, 0.05851135698321741, 0.034271199692739174, 0.07237188881845213, 0.038108748849481344, 0.07155095474445261, 0.08409912086790428, 0.06362074316712096, 0.059356262427172624, 0.030090140062384307, 0.04816757355001755, 0.027147661821800284, 0.024556150783610065, 0.15694743138737977, 0.03687745163915679, 0.06645148736424744, 0.03803861960477661, 0.09082816643058322, 0.08334140293300152, 0.035144128632964566, 0.03646976394520607, 0.046315254585351795, 0.08320653985720128, 0.018288941864739172, 0.02854903144907439, 0.03596920389099978, 0.03733898585778661, 0.03636360714153852, 0.12043312002788298, 0.12116910787881352, 0.03456901613390073, 0.04396578573505394, 0.17309012298937887, 0.02721371296502184, 0.08355989120900631, 0.5603701807558537, 19.913080371916294, 49.29830767214298, 70.30595541000366, 80.98654389381409, 80.10936096310616, 80.72658464312553, 83.73916178941727, 82.01022416353226, 71.16913989186287, 46.541840583086014, 47.26123698055744, 24.32875692844391, 26.349300406873226, 35.11703923344612, 31.784302666783333, 39.233115166425705, 47.499723583459854, 72.95259699225426, 71.9399893283844, 54.673598036170006, 69.3706052005291, 88.02708730101585, 87.7847971022129, 79.55337479710579, 71.20461478829384, 52.66175039112568, 77.2359399497509, 62.37096659839153, 68.85702475905418, 79.39506769180298, 81.25677779316902, 86.67869925498962, 69.93421375751495, 70.02476289868355, 72.31553837656975, 67.23793923854828, 73.99630218744278, 74.61033403873444, 71.82081252336502, 57.23460741341114, 57.50595845282078, 77.94201046228409, 80.77909782528877, 108.12274217605591, 110.17260298132896, 106.27685442566872, 94.86088380217552, 73.0323851108551, 67.20190957188606, 67.76543453335762, 76.33652061223984, 53.55977140367031, 65.52455797791481, 47.17711329460144, 36.69886775314808, 23.51427063345909, 25.818615183234215, 27.647369652986526, 35.659878104925156, 38.18911358714104, 59.33666601777077, 60.79800300300121, 69.2960000038147, 79.60599437355995, 77.36785367131233, 76.04670256376266, 55.571239069104195, 21.087673343718052, 1.1908964719623327, 0.2301657322095707, 0.18494608055334538, 0.017954368704522494, 0.05727885749365669, 0.041072719686781056, 0.06974967327550985, 0.0562748392985668, 0.021643117252097, 0.051131295767845586, 0.05299296950397547, 0.036650514011853375, 0.05203081957006361, 0.05148420183104463, 0.028967174148419872, 0.07410199090372771, 0.030935863724153023, 0.022737475228495896, 0.034094865404767916, 0.016292649961542338, 0.03191220908774994, 0.07120357768144459, 0.04531965605565347, 0.055153339126263745, 0.09805540830711834, 0.06235780820134096, 0.029357395396800712, 0.028836281562689692, 0.0719839236990083, 0.04738303439808078, 0.03756383062864188, 0.054436884602182545, 0.031156862314674072, 0.030318411700136494, 0.09912616413203068, 0.003735222530849569, 0.04999637014407199, 0.030128015569061972, 0.05512749754416291, 0.028325016028247774, 0.06787937207263894, 0.047634347865823656, 0.026045784034067765, 0.06729228131007403, 0.05423551396233961, 0.03766551599255763, 0.027929974530707113, 0.12374565165373497, 0.02754354936769232, 0.02625339799124049, 0.046050819946685806, 0.027857461136591155, 0.04250488658726681, 0.037678247535950504, 0.01853080408181995, 0.05637211630528327, 0.030274858763732482, 0.144421641016379, 0.07049505671602674, 0.07498086444684304, 0.09442612063139677, 0.05536556738661602, 0.04658522564568557, 0.040226474666269496, 0.04289797623641789, 0.015279144336091122, 0.018113433216058183, 0.05169155789189972, 0.04083024148712866, 0.042386243148939684, 0.051472639170242473, 0.029374310797720682, 0.011824580487882486, 0.03708196156367194, 0.016999784966174047, 0.05581897137744818, 0.03366164783074055, 0.039941130016813986, 0.05996800733555574, 0.0417961578204995, 0.07876877134549432, 0.056818677694536746, 0.03307137325464282, 0.049034042094717734, 0.010935187001450686, 0.02678977594769094, 0.050424752625986, 0.03166235394019168, 0.033961987574002706, 0.0629204823053442, 0.029355612387007568, 0.006449510538004688, 0.03174609788402449, 0.028975508466828614, 0.08663347354740836, 0.04189829960523639, 0.031882627081358805, 0.02410190259979572, 0.018988872470799834, 0.1546391739975661, 0.07618688410730101, 0.04744729696540162, 0.06034982747223694, 0.09063183126272634, 0.2734278654679656, 0.08138657853123732, 0.1188507053302601, 3.380153034813702, 38.024510219693184, 72.35659137368202, 87.29331627488136, 90.69096475839615, 93.46948206424713, 105.22558003664017, 114.66189488768578, 107.47133553028107, 99.90922451019287, 73.18876951932907, 62.3997500538826, 32.762955352663994, 25.201281309127808, 30.924264416098595, 16.621660888195038, 22.14353408664465, 29.422926977276802, 34.43195499479771, 36.01920962333679, 29.63465541601181, 48.46687808632851, 51.41145408153534, 56.093984618783, 48.4480044990778, 41.91366232931614, 24.016168601810932, 39.40820597112179, 29.082459546625614, 27.1495146676898, 37.69282981753349, 37.604370564222336, 23.955829739570618, 29.129075445234776, 21.28207851201296, 22.583711966872215, 22.956226877868176, 22.406641468405724, 27.071390859782696, 37.32953131198883, 33.102140352129936, 33.283280432224274, 49.404709562659264, 56.31935052573681, 75.63716813921928, 78.13053354620934, 94.81931403279305, 69.43229109048843, 37.57958449423313, 45.637226924300194, 39.85174477100372, 46.56683184206486, 22.83844079822302, 35.2167534828186, 27.59093888103962, 22.67716035246849, 24.47644740343094, 34.123126566410065, 47.7330918610096, 51.75523683428764, 62.01663941144943, 87.08744332194328, 89.06769946217537, 90.4545034468174, 94.50141549110413, 85.30728444457054, 92.06430226564407, 80.17735451459885, 40.845748633146286, 5.4844428319483995, 0.285197229241021, 0.30901313410140574, 0.02773055759462295, 0.026173841615673155, 0.05450440519780386, 0.08261659924755804, 0.05456153943669051, 0.1081296474148985, 0.10702954707085155, 0.018445544301357586, 0.049501175817567855, 0.03167344162648078, 0.023648669302929193, 0.052798456308664754, 0.06196958704094868, 0.044765167840523645, 0.030283890700957272, 0.01467384312491049, 0.01376324091324932, 0.0005514086501534621, 0.016826543578645214, 0.058993159254896455, 0.067008335608989, 0.030029450936126523, 0.05394505962613039, 0.017701763899822254, 0.046627568881376646, 0.045302267535589635, 0.015897203993517905, 0.0368088846153114, 0.07896647206507623, 0.036164388729957864, 0.06667041350738145, 0.05425943709269632, 0.0386607286054641, 0.0402411914546974, 0.03825650303042494, 0.04012160177808255, 0.03295388385595288, 0.07133084116503596, 0.06399160920409486, 0.05055291410826612, 0.09245873166946694, 0.026386025347164832, 0.014895326894475147, 0.02288107523781946, 0.03946565084333997, 0.047719761641928926, 0.009154489926004317, 0.0501453377364669, 0.030390839747269638, 0.05650111270369962, 0.06095676697441377, 0.030545701847586315, 0.1144056860357523, 0.16859900148119777, 0.3013746830401942, 0.16729835799196735, 0.11558514423086308, 0.2146736963186413, 0.13175194821087644, 0.17490128986537457, 0.11460561319836415, 0.1567828527186066, 0.10495261711184867, 0.16403795481892303, 0.1447347382782027, 0.21244606585241854, 0.12885534582892433, 0.09708300189231522, 0.10114764823811129, 0.0937854393851012, 0.19803887174930423, 0.19810894533293322, 0.17474385065725073, 0.10254383581923321, 0.11424046169850044, 0.2386787746218033, 0.18904934084275737, 0.14648495998699218, 0.11101855372544378, 0.15411395608680323, 0.14741512335604057, 0.09851856040768325, 0.3207331005251035, 0.15563524008030072, 0.12594707688549533, 0.11472098747617565, 0.1765658232034184, 0.17513947474071756, 0.12421033257851377, 0.2200953522697091, 0.06567450327565894, 0.2038169070146978, 0.12607646291144192, 0.19765236123930663, 0.16775679745478556, 0.13980907446239144, 0.30505846661981195, 0.24231844494352117, 0.1729837732273154, 0.30457915796432644, 0.14088857278693467, 0.27974098920822144, 0.22273165377555415, 0.3014846099540591, 1.783168197143823, 32.66356788575649, 72.18830600380898, 101.33069783449173, 103.6192162334919, 102.73199424147606, 100.3647668659687, 105.84686189889908, 102.31451064348221, 91.49305611848831, 57.42364726960659, 60.49460828304291, 31.426753252744675, 37.815988808870316, 49.73708152770996, 42.783363461494446, 54.658634439110756, 67.46697574853897, 95.02340868115425, 98.04268106818199, 74.66900289058685, 95.07384717464447, 117.24914565682411, 117.8602060675621, 110.04184439778328, 96.63991793990135, 74.69206765294075, 109.54426869750023, 89.20679479837418, 95.64426496624947, 111.19094833731651, 110.85240170359612, 120.01054868102074, 94.8371122777462, 97.84790351986885, 100.6364218890667, 95.92472031712532, 99.86342176795006, 108.58577772974968, 101.76858633756638, 85.99877893924713, 87.19168692827225, 112.23804295063019, 108.38983744382858, 139.25007909536362, 139.41295355558395, 136.4030134677887, 126.80880188941956, 94.1149078309536, 92.32961922883987, 89.11406457424164, 101.8204003572464, 73.05427193641663, 88.28320875763893, 66.87656342983246, 54.19573187828064, 36.679921969771385, 38.70745897293091, 43.37892830371857, 46.36493727564812, 55.342787727713585, 79.52530950307846, 84.31249022483826, 89.28782925009727, 99.32240679860115, 97.38424479961395, 105.48324421048164, 86.51804387569427, 34.55840460956097, 3.013888313435018, 0.23859736102167517, 0.33668188378214836, 0.15835202008020133, 0.09840849990723655, 0.10235320776700974, 0.2035975578473881, 0.256520583643578, 0.24595482012955472, 0.1935029393644072, 0.143159722792916, 0.14096247585257515, 0.13215735380072147, 0.14841929369140416, 0.1264517373056151, 0.2180639308062382, 0.19545775634469464, 0.1361079839989543, 0.09857171302428469, 0.1274561748141423, 0.14863485790556297, 0.12413942036801018, 0.13435921689961106, 0.25741923542227596, 0.14012604573508725, 0.1726443148800172, 0.09736783817061223, 0.1326408630120568, 0.14843664510408416, 0.16626638680463657, 0.09016240801429376, 0.1826012204401195, 0.10543879805481993, 0.16505204024724662, 0.223216068407055, 0.13865945802535862, 0.16040940186940134, 0.12519186740973964, 0.15761276677949354, 0.12459525489248335, 0.18308517494006082, 0.21564258495345712, 0.13860078383004293, 0.24208606366300955, 0.2894942939747125, 0.12285589822568, 0.12520390504505485, 0.24713257880648598, 0.1882003981154412, 0.16933766106376424, 0.12834577239118516, 0.10577947352430783, 0.17941624915692955, 0.1263736336841248, 0.09537232181173749], [0.03744077883311547, 0.027774147638410795, 0.038669823625241406, 0.04543238457699772, 0.03192947886418551, 0.021932035342615563, 0.03843037709884811, 0.10341774439439178, 0.050278564376640134, 0.06298902706475928, 0.04491169376706239, 0.06995942647336051, 0.022709655822836794, 0.013284512060636189, 0.07920491669210605, 0.07045164849841967, 0.04001244669780135, 0.04045689296617638, 0.02822338261466939, 0.024677473375049885, 0.04550887031655293, 0.01793466097296914, 0.019292904398753308, 0.04008703625004273, 0.0360154100053478, 0.06392883835360408, 0.004614248910002061, 0.034713638451648876, 0.05718415945011657, 0.07090699320542626, 0.04304513298848178, 0.05644787474011537, 0.019258301763329655, 0.0086000889132265, 0.03485868750431109, 0.01854597358033061, 0.023812246072338894, 0.05823262115882244, 0.04345384113548789, 0.05863241611223202, 0.06311732955509797, 0.08079793668002822, 0.017618626661715098, 0.021589255884464364, 0.06575923427590169, 0.05199865117901936, 0.0497914705920266, 0.06323961322777905, 0.0655483604350593, 0.07157013184041716, 0.23416288022417575, 16.11662618815899, 60.66840335726738, 82.76103347539902, 81.50978341698647, 80.71690276265144, 76.95762008428574, 70.71967720985413, 60.64884580671787, 51.947312727570534, 43.1922747194767, 44.3310584127903, 32.42014914751053, 38.49177114665508, 66.6224330663681, 63.05462211370468, 53.20994317531586, 82.0198604464531, 85.59487581253052, 57.94385075569153, 68.89069855213165, 60.741108655929565, 59.30473633110523, 40.15819072723389, 68.51953446865082, 58.492146134376526, 54.6494959294796, 54.29991848766804, 83.88126656413078, 65.47466665506363, 57.461219653487206, 59.94152896106243, 55.02107039093971, 60.420189276337624, 77.77087524533272, 66.95296972990036, 78.44204843044281, 82.83060774207115, 76.95254355669022, 77.88043096661568, 63.75553250312805, 58.74112017452717, 61.28133326768875, 64.02179181575775, 58.69699314236641, 52.694333642721176, 36.22223652899265, 51.70159891247749, 52.132898569107056, 51.98294721543789, 71.98426455259323, 58.2587094604969, 53.20412188768387, 49.356467351317406, 76.6858358681202, 63.66910994052887, 57.79743701219559, 65.19147545099258, 62.97558255493641, 44.83515076339245, 28.63904044032097, 33.382470309734344, 27.25515279918909, 26.818791814148426, 35.088795349001884, 52.922329008579254, 58.80902253091335, 64.68475744128227, 66.91695526242256, 74.16334882378578, 80.25259807705879, 50.70227533578873, 17.152102924883366, 1.6869154432788491, 0.338090569130145, 0.16484067658893764, 0.04686076281359419, 0.04335593701398466, 0.06490293686510995, 0.04836078798689414, 0.02335364704777021, 0.06628759147133678, 0.07522355415858328, 0.06521207847981714, 0.057289859832962975, 0.04621358406438958, 0.03142393157759216, 0.10403575302916579, 0.026157601569138933, 0.01123936272051651, 0.028806209738831967, 0.0223515602920088, 0.061880985740572214, 0.0544893470214447, 0.059945175162283704, 0.046565347220166586, 0.06896399121615104, 0.015219189008348621, 0.03609903149481397, 0.030815908539807424, 0.04497400077525526, 0.04395487245346885, 0.01350201977402321, 0.029836336689186282, 0.007991934144229162, 0.0208379575269646, 0.03311469983600546, 0.08843439136398956, 0.03672870298032649, 0.04167400402366184, 0.09525592337013222, 0.050150039241998456, 0.020142567009315826, 0.04035383462905884, 0.04450505992281251, 0.02554880855313968, 0.018272152628924232, 0.03809534937317949, 0.024091942977975123, 0.06124726955022197, 0.0920339634467382, 0.03367731085745618, 0.039575522096129134, 0.022247702290769666, 0.029053179787297267, 0.018163663626182824, 0.024901522192521952, 0.016844102792674676, 0.03675051841128152, 0.0324034143704921, 0.06235309556359425, 0.052487830398604274, 0.04351657858933322, 0.07082621043082327, 0.06170940490846988, 0.055810774356359616, 0.013403821576503105, 0.025905753755068872, 0.016303234842780512, 0.0597222414216958, 0.06157635638373904, 0.015077945317898411, 0.04755135720188264, 0.0036895470520903473, 0.027222323733440135, 0.04949157242663205, 0.032074847040348686, 0.057471715699648485, 0.034499981557019055, 0.03684700874146074, 0.022148174721223768, 0.03945453718188219, 0.026559038524283096, 0.012791489443770843, 0.042010675606434233, 0.00802305889010313, 0.04621952866727952, 0.028095184025005437, 0.02515361862606369, 0.06781570322345942, 0.048750730929896235, 0.028254751341592055, 0.03948568511987105, 0.03618006288888864, 0.028914103168062866, 0.04530995989625808, 0.043523376662051305, 0.022650514074484818, 0.02186440528021194, 0.02298596296895994, 0.051205050403950736, 0.036295040117693134, 0.031687917216913775, 0.03451908443821594, 0.10869497840758413, 0.11452439255663194, 1.125940263736993, 32.65445217490196, 82.80405476689339, 94.71564799547195, 92.84323766827583, 94.80561196804047, 98.48234787583351, 99.34962093830109, 90.46065911650658, 77.97591984272003, 58.65307129919529, 49.751885533332825, 32.38823466002941, 22.276618145406246, 33.73735226690769, 49.90744158625603, 44.11456882953644, 57.26845599710941, 60.2246555685997, 61.008868888020515, 74.76947709918022, 64.3536128103733, 65.58986887335777, 45.68204551935196, 64.54445376992226, 60.30547723174095, 54.788720458745956, 54.50988382101059, 81.36684268712997, 70.72077915072441, 59.63985934853554, 61.37540102005005, 60.14699153602123, 60.93264877796173, 69.69807922840118, 62.296011820435524, 67.44953468441963, 70.4490253329277, 70.38483917713165, 76.64902344346046, 66.57318010926247, 67.06594526767731, 63.2061617821455, 64.30296912789345, 63.64070266485214, 56.981753781437874, 46.47281348705292, 58.1618944555521, 63.925520181655884, 57.16252528131008, 65.00780090689659, 57.51691706478596, 53.178290873765945, 52.98537142574787, 71.12944722175598, 58.51948946714401, 53.07153940200806, 59.138198867440224, 45.56467741727829, 30.80290462821722, 17.568927258253098, 26.153415217995644, 23.430511727929115, 31.609797030687332, 58.03606800734997, 77.75398895144463, 90.09239047765732, 92.60026350617409, 82.06127062439919, 83.3146333694458, 93.83395850658417, 72.51980021595955, 35.049744844436646, 3.874330767430365, 0.21937773999525234, 0.2515673713060096, 0.07829239417333156, 0.024196936465159524, 0.06989270739722997, 0.01489969072281383, 0.04540840207482688, 0.04861282133788336, 0.04884537702309899, 0.03349968152178917, 0.09468099640798755, 0.029457399796228856, 0.03944161639083177, 0.011797292645496782, 0.016982865854515694, 0.018105445851688273, 0.05409422388765961, 0.08123558116494678, 0.02134706712240586, 0.028640315613301937, 0.047310708396253176, 0.0544913174235262, 0.029312296937860083, 0.03655404223536607, 0.02184045431931736, 0.015899408172117546, 0.040904656634666026, 0.07720894762314856, 0.014168603829602944, 0.03617070811742451, 0.04786697405506857, 0.026933628287224565, 0.020183043743600138, 0.1017498120199889, 0.023950027643877547, 0.0456792711338494, 0.10390197348897345, 0.05662557829055004, 0.018321963725611567, 0.05589688204054255, 0.13143750024028122, 0.03499933191051241, 0.019329828101035673, 0.04035139296320267, 0.05302567966282368, 0.010077863571495982, 0.048531392894801684, 0.025176563976856414, 0.03875562331813853, 0.017751398736436386, 0.012791453264071606, 0.007474584390365635, 0.17185220582177863, 0.1364993184688501, 0.12202608064399101, 0.08692196119227447, 0.08482045872369781, 0.21522494876990095, 0.20432916702702641, 0.15766591939609498, 0.11835071301902644, 0.2069112769095227, 0.12076468192390166, 0.21463044395204633, 0.17452793021220714, 0.17939159501111135, 0.12636542553082108, 0.1704201428219676, 0.09462024419917725, 0.16243528691120446, 0.13942805584520102, 0.11382495547877625, 0.18932660721475258, 0.1644835848128423, 0.13330815767403692, 0.14300272887339815, 0.1380957820219919, 0.12401926665916108, 0.20289680716814473, 0.15822138724615797, 0.17836645158240572, 0.2318173521780409, 0.07300098513951525, 0.12075428443495184, 0.13876782642910257, 0.1880314407753758, 0.10436087308335118, 0.10573778708931059, 0.08039625667151995, 0.09770764532731846, 0.08251206032582559, 0.2738170773955062, 0.2735923253931105, 0.1823535212315619, 0.09640993332141079, 0.07815353834303096, 0.15091221226612106, 0.2606474590720609, 0.1141054650361184, 0.09394008069648407, 0.30025199172087014, 0.23154295049607754, 0.4738934710621834, 26.979490891098976, 84.50067892670631, 110.11232301592827, 103.41259092092514, 99.78277489542961, 96.40300065279007, 90.7856784760952, 78.33752363920212, 69.1255335509777, 56.37660205364227, 55.71585550904274, 41.335356160998344, 51.2250816822052, 92.11745381355286, 78.87955695390701, 72.09634333848953, 110.02761036157608, 118.84867742657661, 82.32167065143585, 99.05930891633034, 86.2958014011383, 87.21099749207497, 60.215372666716576, 99.36709240078926, 83.46087232232094, 81.2319727241993, 83.95204916596413, 120.30931904911995, 91.45187392830849, 88.18742349743843, 95.88121265172958, 90.33077448606491, 96.36792093515396, 126.66523799300194, 100.74986860156059, 119.98656436800957, 123.60593095421791, 114.87178042531013, 116.70647397637367, 96.12161055207253, 89.76244658231735, 92.00973719358444, 98.05936217308044, 90.18167808651924, 80.12900590896606, 60.23119121789932, 76.03331208229065, 74.87147122621536, 77.76934772729874, 103.16047444939613, 83.38436722755432, 81.27335250377655, 72.10972622036934, 111.44440993666649, 92.40663349628448, 82.37038403749466, 91.31131187081337, 84.54528853297234, 61.91996119916439, 38.925008699297905, 47.61142238974571, 41.210700049996376, 38.715157359838486, 47.39944316446781, 69.38019588589668, 79.89157184958458, 87.70036563277245, 84.49441686272621, 93.08010935783386, 108.76968026161194, 78.10883671045303, 33.02603043615818, 2.9459964064881206, 0.6334605056326836, 0.38908656395506114, 0.2043103164760396, 0.14099799504037946, 0.16043166629970074, 0.1437312804046087, 0.23399134021019563, 0.13788830721750855, 0.12930041179060936, 0.16754353389842436, 0.1690926039009355, 0.10057108855107799, 0.15129205828998238, 0.19582649983931333, 0.16447288304334506, 0.10607737160171382, 0.1360933785326779, 0.227680116367992, 0.13962165248813108, 0.12792544963303953, 0.16114392026793212, 0.145943385141436, 0.12080057960702106, 0.1270301078329794, 0.14336687105242163, 0.19295930134830996, 0.1352349214721471, 0.15945648425258696, 0.13774839753750712, 0.11656702787149698, 0.1376270712353289, 0.10079166968353093, 0.09650560357840732, 0.16466952249174938, 0.07935774716315791, 0.17542156507261097, 0.17000206134980544, 0.15702583186794072, 0.07243440733873285, 0.18193572177551687, 0.2498945704428479, 0.1355825731297955, 0.14079978223890066, 0.12799674033885822, 0.16574275708990172, 0.15225014125462621, 0.2130249558831565, 0.10905874951276928, 0.12191855086712167, 0.11555273464182392, 0.12541635223897174, 0.13007413042942062], [0.03911253697879147, 0.05277363889035769, 0.08249349179095589, 0.04869919619522989, 0.006461342227339628, 0.05322964039805811, 0.12757116317516193, 0.025791921289055608, 0.04134128808800597, 0.024364916025660932, 0.035765365610131994, 0.013558702230511699, 0.017107574494730216, 0.006744190477547818, 0.03479815051832702, 0.035099199012620375, 0.03719707608979661, 0.07519124847021885, 0.05518193407624494, 0.058182763677905314, 0.04000544453447219, 0.04303630885260645, 0.08627763600088656, 0.04496778528846335, 0.039085738026187755, 0.020809835696127266, 0.07039337506284937, 0.06193345929204952, 0.040473053231835365, 0.006370862365656649, 0.02804556588671403, 0.05250570873613469, 0.06437138101318851, 0.04868697302299552, 0.014553824858012376, 0.031767501423018984, 0.04440518910996616, 0.07361725714872591, 0.025184792539221235, 0.11334659677231684, 0.04088352026883513, 0.08028269323403947, 0.07682970273890533, 0.07890115564805456, 0.13642596459249035, 0.14288487582234666, 0.13855180208338425, 0.03227013206924312, 0.11932593217352405, 3.8717858539894223, 38.456725627183914, 78.09232279658318, 80.0880441069603, 77.13695526123047, 65.32021254301071, 70.39759889245033, 60.455683171749115, 52.54844047129154, 47.801545187830925, 32.707869708538055, 38.96411620080471, 43.74871306121349, 58.695549219846725, 65.36801397800446, 107.59276941418648, 81.3947331905365, 50.35281948745251, 45.92489428818226, 53.0360759049654, 41.17642968893051, 35.48411853611469, 37.249914184212685, 29.752431996166706, 41.75564020872116, 55.08629769086838, 34.61116097867489, 14.246281050145626, 11.663976665586233, 10.41172631084919, 14.861706476658583, 14.888719227164984, 12.137303967028856, 14.689324926584959, 17.73296445608139, 16.583197452127934, 23.40699478983879, 26.7948018014431, 31.22312217950821, 29.064828492701054, 28.754208460450172, 24.663811549544334, 18.687946312129498, 18.78263533115387, 18.163813836872578, 13.082285709679127, 14.143476616591215, 19.99196033924818, 21.79508138448, 26.48058146238327, 25.457161478698254, 18.265849761664867, 27.006022967398167, 27.12557975202799, 29.797269590198994, 31.36013712733984, 40.6759737432003, 45.06814286112785, 43.78706060349941, 50.26895418763161, 60.291083604097366, 78.37861463427544, 97.53100052475929, 157.44424760341644, 33.138644993305206, 25.8756710216403, 24.816983230412006, 25.940229557454586, 34.024795442819595, 52.520135790109634, 57.23795883357525, 61.200515404343605, 69.14976105093956, 72.01955705881119, 39.07287396490574, 6.63466296158731, 0.8210150571539998, 0.2870174206327647, 0.17357590317260474, 0.027272251718386542, 0.1491025445284322, 0.17164701683213934, 0.0818745925789699, 0.03546427258697804, 0.12091053620679304, 0.05422342808742542, 0.008398685804422712, 0.09933781722793356, 0.10431914211949334, 0.0619014615949709, 0.014448749734583544, 0.017283632332691923, 0.049352404894307256, 0.08202164171962067, 0.02865355181711493, 0.07961201437865384, 0.16803249047370628, 0.021729215659433976, 0.09673946173279546, 0.037271220353432, 0.022014339519955683, 0.0826616698759608, 0.046715309290448204, 0.019105619721813127, 0.013423405926005216, 0.008083022567006992, 0.027026287280023098, 0.060575173192773946, 0.015751017599541228, 0.010596390093269292, 0.052103613124927506, 0.079446344752796, 0.04711960908025503, 0.07641309071914293, 0.024958563662949018, 0.02224173913418781, 0.08784986843238585, 0.058764343993971124, 0.03879572526784614, 0.04155488932156004, 0.05706101859686896, 0.031083560388651676, 0.062427391967503354, 0.05604042082268279, 0.08719769874005578, 0.05064032055088319, 0.04435844122781418, 0.008378394559258595, 0.053060378777445294, 0.04261598609446082, 0.021086333945277147, 0.021907503651164006, 0.03861810706439428, 0.014468516837951029, 0.031426844507222995, 0.034012134492513724, 0.018199398036813363, 0.09475564162130468, 0.020641626069846097, 0.050741141312755644, 0.03521072525472846, 0.002091445439873496, 0.05639943105052225, 0.04399629542604089, 0.040602487497380935, 0.03400891728233546, 0.03796871671511326, 0.018670502249733545, 0.03630367500591092, 0.04716204137366731, 0.009018882847158238, 0.02380205081863096, 0.005346334455680335, 0.003112724830316438, 0.05258813165710308, 0.012721975253953133, 0.013827255788783077, 0.007206024338302086, 0.01260660654224921, 0.05616903872578405, 0.08710611771675758, 0.029622371803270653, 0.06908171810209751, 0.023001908011792693, 0.10036347273853607, 0.09328854925115593, 0.05770361458417028, 0.024658455840835813, 0.06166876119095832, 0.06819418369559571, 0.0069715998324682005, 0.10079979620059021, 0.15986294369213283, 0.08951852069003507, 0.18334044405492023, 0.1802017679437995, 10.171661842614412, 60.895710960030556, 90.07008567452431, 89.92921963334084, 91.68103203177452, 92.98669517040253, 97.39258915185928, 84.7404308617115, 71.19704559445381, 68.07331681251526, 35.52818477153778, 40.17030827701092, 22.63272173702717, 17.2151168435812, 48.091883808374405, 105.66801309585571, 86.10321253538132, 47.853313609957695, 46.98081582784653, 51.62526860833168, 39.70373131334782, 33.12137112021446, 35.963637605309486, 27.38106284290552, 39.51244577765465, 55.28533101081848, 27.862740196287632, 9.968611188232899, 8.068117517977953, 8.01125356927514, 10.631437171250582, 13.523758370429277, 11.863955184817314, 13.565843012183905, 15.646422319114208, 13.758323583751917, 21.913809813559055, 25.95539454370737, 31.90573275089264, 25.50292432308197, 26.245995350182056, 21.022949516773224, 13.098413944244385, 12.810985967516899, 10.728758499026299, 6.368218883872032, 7.077012425288558, 13.740178607404232, 15.80354293808341, 19.14942964911461, 19.38520699739456, 14.66707332059741, 19.529823437333107, 20.78996691852808, 23.974804021418095, 28.903624042868614, 42.466012090444565, 47.26881757378578, 48.33981670439243, 49.47225473821163, 53.19937974214554, 54.37173843383789, 73.62447693943977, 117.71611779928207, 23.960721977055073, 18.963783010840416, 29.018273390829563, 35.72635933756828, 50.99845804274082, 78.48766878247261, 85.03008931875229, 80.58865964412689, 81.28809571266174, 85.75211897492409, 62.0929279178381, 18.180016167461872, 3.5392162995412946, 0.27120023500174284, 0.4738501296378672, 0.01811318830732489, 0.09882539394311607, 0.10882418631808832, 0.012458951623557368, 0.0069365087711048545, 0.03214638265490066, 0.032396397364209406, 0.03794539843511302, 0.055645167813054286, 0.07237040452309884, 0.09863672516075894, 0.0227515500591835, 0.033564029436092824, 0.03344990938785486, 0.07348942963290028, 0.0433704014722025, 0.08404184191022068, 0.05952738683845382, 0.05717371743230615, 0.04320540348999202, 0.025683254170871805, 0.08335528109455481, 0.08424887142609805, 0.015563084471068578, 0.020330916668171994, 0.030633548012701795, 0.07730648067081347, 0.058844481100095436, 0.08921239219489507, 0.055472180611104704, 0.04005566566775087, 0.011613714068516856, 0.09019446137244813, 0.05347502410586458, 0.05266924468742218, 0.023698706754657906, 0.057069215617957525, 0.010520255018491298, 0.029210374086687807, 0.10275160006131046, 0.03403876646189019, 0.05105794560222421, 0.033755952536012046, 0.02224193394795293, 0.09154960076557472, 0.030673223227495328, 0.012226273483975092, 0.06412094327970408, 0.11115950241219252, 0.2242437202949077, 0.17772495397366583, 0.13421178184216842, 0.14620079164160416, 0.1475147789460607, 0.21099932317156345, 0.11743522933102213, 0.119743353134254, 0.11841170271509327, 0.14137516933260486, 0.0961552356602624, 0.22503594809677452, 0.14979778847191483, 0.10029267927166075, 0.1603217245428823, 0.2509334881324321, 0.1881474829860963, 0.13448225014144555, 0.09995120228268206, 0.1254748780047521, 0.08654930657939985, 0.15495868341531605, 0.10442613012855873, 0.0787373488128651, 0.10621910696499981, 0.11135105072753504, 0.1648595865117386, 0.19416261959122494, 0.07946772602736019, 0.12629208649741486, 0.08203973527997732, 0.24234246084233746, 0.21342657651985064, 0.19451847940217704, 0.19366236752830446, 0.11629244807409123, 0.1788447063881904, 0.11237781945965253, 0.2068901850725524, 0.08109423171845265, 0.1248650107299909, 0.15454631648026407, 0.19500068243360147, 0.2664237725548446, 0.17653898714343086, 0.32920100551564246, 0.1544988784007728, 0.3537077904911712, 6.7170278169214725, 60.789138078689575, 102.90468737483025, 100.78920409083366, 95.98638340830803, 87.20695450901985, 90.8691979944706, 78.74929994344711, 63.922358751297, 57.43020951747894, 45.8447527885437, 51.46107941865921, 59.492594450712204, 79.94034603238106, 89.77284282445908, 129.92623060941696, 95.72529181838036, 70.13033643364906, 68.39781939983368, 76.40875473618507, 59.45958562195301, 52.7292537689209, 58.346727937459946, 46.73886381089687, 67.81477108597755, 76.06251731514931, 48.67457114160061, 25.845635533332825, 21.432027965784073, 20.769391022622585, 28.862800933420658, 28.39241087436676, 26.295216009020805, 32.30702541768551, 38.1938823312521, 32.27867893874645, 46.93382374942303, 48.25351193547249, 53.19924674928188, 47.49867103993893, 47.3438635468483, 41.596025973558426, 33.040165677666664, 33.42223137617111, 31.477199345827103, 26.35532308369875, 25.293447263538837, 35.57057909667492, 34.11117620766163, 37.31823071837425, 39.11072373390198, 27.843138948082924, 39.47830840945244, 40.14923460781574, 46.64065048098564, 50.59712737798691, 62.952760979533195, 68.47391411662102, 66.01346254348755, 76.806410998106, 86.86086907982826, 107.84779652953148, 124.26008105278015, 167.29003608226776, 44.12436090409756, 36.94521613419056, 38.039002642035484, 35.8483973890543, 46.57083302736282, 75.41692435741425, 79.50204715132713, 78.28608959913254, 92.17021018266678, 98.80584731698036, 68.16778734326363, 15.85845759138465, 2.1654627146199346, 0.3996544500114396, 0.4652647575130686, 0.11226271977648139, 0.27122822881210595, 0.2975022455211729, 0.1686417343444191, 0.17800892936065793, 0.14962105342419818, 0.11539525090483949, 0.08723370774532668, 0.20273880392778665, 0.21338470454793423, 0.1624986217939295, 0.18204900319688022, 0.1437722469563596, 0.19541524612577632, 0.22913594293640926, 0.16552346729440615, 0.2253788648522459, 0.3734715096652508, 0.11871096634422429, 0.18868653452955186, 0.09921128847054206, 0.1663831266341731, 0.1903275863151066, 0.10493806359590963, 0.16685459821019322, 0.13619327160995454, 0.13265101559227332, 0.12279290473088622, 0.17852316348580644, 0.1307958096731454, 0.09085803787456825, 0.10254097112920135, 0.1937825806089677, 0.10494226415175945, 0.19569791533285752, 0.14526823855703697, 0.08000967194675468, 0.159083109756466, 0.15097695722943172, 0.13576567580457777, 0.11804565321654081, 0.11274528646026738, 0.1436799534712918, 0.20209985930705443, 0.2546349645126611, 0.14298442751169205, 0.11108787773991935, 0.13627450709464028], [0.02138973504770547, 0.03601821532356553, 0.02373151153733488, 0.050905771931866184, 0.028231837532075588, 0.0595053932920564, 0.051502120986697264, 0.01297617660384276, 0.03737958504643757, 0.046141740458551794, 0.051285803492646664, 0.06417136479285546, 0.0622620117792394, 0.0466514808795182, 0.04068632792041171, 0.05960211368801538, 0.04282926820451394, 0.033997688587987795, 0.0142523384965898, 0.016458551508549135, 0.01013904529827414, 0.019107163388980553, 0.012594401923706755, 0.045830428061890416, 0.03671513652079739, 0.039988018907024525, 0.016488293076690752, 0.017923875711858273, 0.014596560504287481, 0.07164501454099081, 0.08326397466589697, 0.030277617697720416, 0.04052940821566153, 0.03280796649050899, 0.03134788370516617, 0.05563468126638327, 0.010178870797972195, 0.04385457119497005, 0.024506790541636292, 0.006701715510644135, 0.01483052627008874, 0.010219040468655294, 0.03622771990194451, 0.016724950983189046, 0.07736850195215084, 0.026817183461389504, 0.028773189733328763, 1.5510650142095983, 16.57663520425558, 66.55603542923927, 87.89769664406776, 80.52429869771004, 83.33240121603012, 71.78536042571068, 42.42534287273884, 38.572319224476814, 40.45454442501068, 38.51229764521122, 39.68443214893341, 42.91008286178112, 39.003067910671234, 58.19966062903404, 58.07106412947178, 44.410831332206726, 41.78951919078827, 34.11885939538479, 49.247295409440994, 49.6706572920084, 31.339392140507698, 16.157287806272507, 10.38131084293127, 4.5429279282689095, 3.592613646760583, 2.5929580628871918, 1.2102624890394509, 0.041086523633566685, 0.5276840971782804, 0.8873080217745155, 0.2563705510692671, 0.2993865287862718, 0.7324425224214792, 0.4817637096857652, 0.7115286227781326, 0.11334952083416283, 0.3383815800771117, 0.5413697753101587, 2.1057892916724086, 2.3814606992527843, 1.0548776644282043, 2.0192361110821366, 3.1166955968365073, 1.7632730584591627, 0.9408227470703423, 0.6196613085921854, 0.9913947083987296, 0.7822464499622583, 0.5471777042839676, 0.247360403300263, 0.17944807244930416, 0.8530229364987463, 1.4758327323943377, 1.4993121474981308, 1.7601910675875843, 4.312214283272624, 9.952769838273525, 13.727526236325502, 26.70009758323431, 37.055702805519104, 33.84761095046997, 39.13177080452442, 41.15785628557205, 42.06784665584564, 30.868348516523838, 47.2722639888525, 74.5089402794838, 49.08592186868191, 39.78215150535107, 30.99539279937744, 25.03194149583578, 30.392741337418556, 36.4797905087471, 48.375432193279266, 55.786657109856606, 73.19275170564651, 65.98722875118256, 49.82019826769829, 19.820821322500706, 1.5048437006771564, 0.3811958717415109, 0.05079017129901331, 0.06380598322721198, 0.0389743824780453, 0.0350877068558475, 0.00946016200032318, 0.0855920028698165, 0.04326729118474759, 0.028761233734257985, 0.023847704032959882, 0.0370350281446008, 0.09678145244834013, 0.037216464697849005, 0.0661144484183751, 0.0067283122280059615, 0.023847279153415002, 0.04651753064536024, 0.03286398379714228, 0.02888982566219056, 0.07857741598854773, 0.06606344803003594, 0.0532428766018711, 0.0065956714206549805, 0.04429911765328143, 0.008442406651738565, 0.011787427647504956, 0.0450500152510358, 0.09844269065069966, 0.0710851680196356, 0.058793918578885496, 0.03689673263579607, 0.03421835877816193, 0.07181053573731333, 0.017412435772712342, 0.09335034046671353, 0.04549859157123137, 0.05959219117357861, 0.022467160924861673, 0.027232481879764237, 0.04468496765184682, 0.017124074292951263, 0.07245908374898136, 0.06624307745369151, 0.05640263341774698, 0.04326941001636442, 0.05855209346918855, 0.028793251840397716, 0.04789234066265635, 0.03318072500405833, 0.01013891913316911, 0.030027272732695565, 0.04322373824834358, 0.05801455590699334, 0.06905404341523536, 0.03251646201533731, 0.08410646812990308, 0.06269377845455892, 0.0502687457628781, 0.012915167426399421, 0.06357398786349222, 0.03307853497972246, 0.04570287885144353, 0.11278323247097433, 0.029081283064442687, 0.023155180060712155, 0.03244475199608132, 0.015810409822734073, 0.03438634019403253, 0.02957983931992203, 0.03923103569832165, 0.05972028215182945, 0.03483599633909762, 0.02057387726381421, 0.048562529700575396, 0.04885364825895522, 0.03744059329619631, 0.028249062779650558, 0.02440996810037177, 0.03042564832867356, 0.02284312551637413, 0.09679332681116648, 0.00360488516434998, 0.08200506956200115, 0.0516321155737387, 0.013508758474927163, 0.033592824765946716, 0.06243585987249389, 0.024969315527414437, 0.013583800737251295, 0.07213525503175333, 0.014039312427485129, 0.019431151667959057, 0.07261097911396064, 0.1999904084368609, 0.26825586799532175, 6.037803813815117, 33.37788015604019, 87.09653243422508, 98.9507107436657, 98.18791687488556, 102.44791388511658, 92.65304267406464, 65.05995690822601, 61.9384054094553, 58.248833790421486, 33.34691561758518, 15.716965533792973, 24.61795561015606, 29.76829044520855, 57.316641211509705, 56.050514951348305, 46.38530418276787, 39.192700535058975, 28.485517278313637, 38.416550382971764, 33.953028693795204, 19.096099510788918, 6.555560231208801, 3.5581865441054106, 1.3156981626525521, 0.7397020922508091, 0.3115124796750024, 0.435316902003251, 0.5127547576557845, 0.8055828383658081, 0.9377920534461737, 0.5113358306698501, 0.7253413565922529, 0.4968259233282879, 0.7896087924018502, 0.7102900673635304, 0.5681640969123691, 0.5351874476764351, 0.48761907673906535, 1.4045784808695316, 1.1153030907735229, 0.5758720426820219, 0.6855831400025636, 1.2722279014997184, 1.284403398167342, 0.5030506127513945, 0.27875651547219604, 0.3784954932052642, 0.5591986561194062, 0.6211609218735248, 0.8034182013943791, 1.2951879319734871, 0.7894318643957376, 0.7256959250662476, 0.525663971202448, 0.5658491305075586, 1.4232208742760122, 3.46758586820215, 6.657763347029686, 16.79112609475851, 25.320579707622528, 27.429265156388283, 33.9958143979311, 38.129506185650826, 43.43882828950882, 41.14129677414894, 39.698571190238, 40.40360815823078, 29.16558388620615, 25.868257619440556, 27.301223427057266, 37.481530755758286, 53.72802637517452, 61.26256987452507, 74.21887144446373, 73.68454411625862, 85.07887870073318, 88.28731253743172, 72.5066377222538, 36.28874436020851, 5.567086022347212, 0.17958102078409865, 0.0419506173057016, 0.07187873910879716, 0.03236470765841659, 0.03610598541854415, 0.02237276716186898, 0.07149446988478303, 0.051667901934706606, 0.025937256068573333, 0.028758109292539302, 0.07968196921865456, 0.01638594905671198, 0.015005121149442857, 0.024003250764508266, 0.01227527842274867, 0.02124814625858562, 0.1190167831373401, 0.051547533003031276, 0.02312732354766922, 0.021059258542663883, 0.059407849112176336, 0.04275557294022292, 0.02243851216917392, 0.07433736303937621, 0.01234781593666412, 0.06936472869710997, 0.04017873972770758, 0.09150654135737568, 0.013402392014540965, 0.07631365035194904, 0.019506847020238638, 0.02999569620442344, 0.052836762260994874, 0.06071429990697652, 0.11368681211024523, 0.027689860071404837, 0.051474223655532114, 0.022609723782807123, 0.01230564803336165, 0.09640316493459977, 0.05893523833947256, 0.02349958482227521, 0.04595995880663395, 0.03006649338203715, 0.036311727308202535, 0.019811752827081364, 0.030827372866042424, 0.02442699853418162, 0.1710711547639221, 0.12470601301174611, 0.12526290578534827, 0.10117397221620195, 0.10920306012849323, 0.1490187263698317, 0.1726288188365288, 0.13291378039866686, 0.2346359399962239, 0.1622752650291659, 0.09205595328239724, 0.19315895391628146, 0.16524569626199082, 0.08983375533716753, 0.1728983223438263, 0.15574976830976084, 0.11230564559809864, 0.1341443948331289, 0.21639512269757688, 0.0942306240904145, 0.14192526403348893, 0.16675798542564735, 0.1242290495429188, 0.1814559381455183, 0.10288419958669692, 0.09726312113343738, 0.2258661441737786, 0.13365710066864267, 0.13177967484807596, 0.1387161432649009, 0.1672012108610943, 0.15364502265583724, 0.12981154373846948, 0.1609409725642763, 0.21327915630536154, 0.15007524780230597, 0.13450470753014088, 0.13990414357976988, 0.15977348521118984, 0.1460777287138626, 0.08647230133647099, 0.2328017368563451, 0.1320408217725344, 0.15359176613856107, 0.20677406864706427, 0.22900254931300879, 0.4569117369828746, 3.277993854135275, 26.879444159567356, 91.59334033727646, 110.9066703915596, 101.7878133058548, 101.45413041114807, 91.96818262338638, 55.7526945322752, 46.59822955727577, 53.10580976307392, 50.46144425868988, 52.17052415013313, 58.37773807346821, 55.64900569617748, 83.07368069887161, 80.49136206507683, 57.803661078214645, 58.46501179039478, 53.65521088242531, 73.11690777540207, 68.57797533273697, 41.86420038342476, 24.440854713320732, 16.281617134809494, 7.945341356098652, 6.4373523741960526, 5.491370810195804, 2.14195195119828, 1.1459716013632715, 1.4386087423190475, 1.8057852960191667, 1.559917707927525, 2.513941302895546, 2.5483703054487705, 2.6265537226572633, 2.673185532912612, 2.4980612425133586, 2.4718853970989585, 2.634360403753817, 5.749271996319294, 6.7667073011398315, 4.316195519641042, 5.4869806207716465, 7.525946935638785, 6.995482100173831, 3.3986466424539685, 2.261404716409743, 3.0733857583254576, 2.09520329721272, 1.7689321422949433, 2.811802332289517, 3.153613703325391, 2.119164098985493, 4.313172781839967, 4.006130732595921, 3.372742719948292, 7.6093553099781275, 15.44807106256485, 19.614775478839874, 34.2506705224514, 46.28578372299671, 47.21200682222843, 58.37100103497505, 63.399142026901245, 64.01777923107147, 51.19467951357365, 66.21814996004105, 96.45077928900719, 68.02299991250038, 59.73932281136513, 45.563438683748245, 36.00312888622284, 43.07861901819706, 50.97360737621784, 67.88736999034882, 72.72172898054123, 94.67505097389221, 98.50522264838219, 78.58641788363457, 34.4292077422142, 3.6539269192144275, 0.6100467557553202, 0.1221986448217649, 0.1522658599424176, 0.12969988019904122, 0.16046650271164253, 0.1410067078541033, 0.12815395690267906, 0.12450587062630802, 0.09823796921409667, 0.16088554897578433, 0.16376824351027608, 0.16247105842921883, 0.18866530910599977, 0.14601764443796128, 0.1688670355360955, 0.14021238719578832, 0.19378243217943236, 0.14776828174944967, 0.060932940323255025, 0.2504802733892575, 0.1295926547027193, 0.09569854766596109, 0.09976832967367955, 0.20813049195567146, 0.15380443597678095, 0.10688168898923323, 0.17555394937517121, 0.1977651528432034, 0.14142763917334378, 0.13047057087533176, 0.16824204329168424, 0.08784456207649782, 0.13843813474522904, 0.10885541589232162, 0.17734743829350919, 0.0883375114062801, 0.12846285360865295, 0.08591140096541494, 0.2081388485385105, 0.1347393449395895, 0.15786879288498312, 0.15415624366141856, 0.16225758707150817, 0.20083556621102616, 0.07016057075816207, 0.09553540134220384, 0.0905102452088613, 0.16797461779788136], [0.04400115278258454, 0.022054675246181432, 0.016258440664387308, 0.014381295004568528, 0.05076819259556942, 0.03804537685937248, 0.03453442463069223, 0.05572956484684255, 0.03837710202788003, 0.030769639342906885, 0.01978218751901295, 0.028116030953242444, 0.03800275531830266, 0.05488166483701207, 0.044765123311663046, 0.010294759940734366, 0.04339656588854268, 0.03862907600705512, 0.001188070586977119, 0.07525185967097059, 0.11386579586542211, 0.050036152970278636, 0.020262900688976515, 0.0669103795371484, 0.031929872202454135, 0.044881547728437, 0.030082473676884547, 0.05312903485901188, 0.05549812238314189, 0.05436649560579099, 0.0784138021117542, 0.07879741824581288, 0.058961510367225856, 0.0868477909534704, 0.02208355777838733, 0.05619428658974357, 0.04122380982153118, 0.027025598938053008, 0.024213746110035572, 0.03920655966794584, 0.05584245292993728, 0.030461045062111225, 0.21683634433429688, 0.04561503454169724, 0.06238700429094024, 0.9844835917465389, 21.949111819267273, 61.47561304271221, 87.86818742752075, 84.4493056833744, 66.15294545888901, 55.16180343925953, 50.62516987323761, 49.20979902148247, 43.308438286185265, 40.84450989961624, 31.603401973843575, 39.881432577967644, 79.50437262654305, 51.69833488762379, 56.595561504364014, 37.7584332972765, 28.083084672689438, 28.080417215824127, 21.99435979127884, 20.635448209941387, 5.260202614590526, 0.8354640787001699, 0.3159517695894465, 0.4734109266428277, 0.38810164493042976, 0.2373569057090208, 0.1062034847564064, 0.11218438608921133, 0.17498448461992666, 0.03167423572449479, 0.17006854293867946, 0.22602867451496422, 0.05097761553770397, 0.09717252716654912, 0.024007241663639434, 0.00525304278198746, 0.013186898304411443, 0.09045898506883532, 0.035029574428335764, 0.06124338811787311, 0.07450213466654532, 0.09382958232890815, 0.02818583365296945, 0.017067971639335155, 0.08656354097183794, 0.03329874132759869, 0.1096456398954615, 0.09586251035216264, 0.07316082148463465, 0.05254982199403457, 0.07701696886215359, 0.13580576662207022, 0.3926015237811953, 0.07380066410405561, 0.07041632226901129, 0.07082722717314027, 0.04648580012144521, 0.17380268865963444, 0.47004157619085163, 0.4390071571106091, 0.6311032071243972, 0.3542741679120809, 0.2501214895164594, 1.6618240834213793, 6.810504226014018, 16.546911299228668, 30.079436749219894, 44.55822542309761, 51.891771107912064, 62.37098939716816, 52.08634726703167, 47.76194371283054, 30.609339214861393, 19.39409852027893, 26.390368603169918, 32.27780498564243, 39.61335316300392, 51.809136942029, 56.84359319508076, 67.78267040848732, 67.32946872711182, 53.68382714688778, 13.244063928723335, 0.25240688875783235, 0.2723312086891383, 0.07067343191010877, 0.04507091041887179, 0.15316201810492203, 0.02498318070138339, 0.03821501697530039, 0.02484021522832336, 0.04007071642263327, 0.01160752733994741, 0.055118614036473446, 0.05690208767191507, 0.04687349064624868, 0.010794469308166299, 0.02350519731407985, 0.0161430905063753, 0.06964922358747572, 0.009986649911297718, 0.03683730887132697, 0.021040014653408434, 0.0665644793480169, 0.06531242426717654, 0.043779157858807594, 0.0605142762651667, 0.019454894827504177, 0.047565847635269165, 0.021766846257378347, 0.019967935950262472, 0.05859022872755304, 0.05371385836042464, 0.016830697750265244, 0.07295189949218184, 0.037015684065409005, 0.027156487813044805, 0.0051798878939735005, 0.05465631540573668, 0.03722860994457733, 0.008739313961996231, 0.01260186607396463, 0.0322330877679633, 0.09624156969948672, 0.05007618812669534, 0.01762149691785453, 0.030713221276528202, 0.04844287694140803, 0.01698963053058833, 0.026780257903737947, 0.03467251604888588, 0.030183103335730266, 0.0541744537622435, 0.021492377782124095, 0.03936077424441464, 0.06947208778001368, 0.02228526795079233, 0.03756518504815176, 0.05566176965658087, 0.04796884495590348, 0.05552823502512183, 0.041973519983002916, 0.05604226877039764, 0.05600906879408285, 0.00782715602326789, 0.022861332254251465, 0.012175267529528355, 0.03882758566760458, 0.027755679293477442, 0.06917404869454913, 0.031171875962172635, 0.025905271359079052, 0.033307799239992164, 0.07384326338069513, 0.03743995133845601, 0.006629091258218978, 0.06428003005567007, 0.0508915375394281, 0.05174062498554122, 0.03659343172330409, 0.03883039469656069, 0.04034768593555782, 0.009936519691109424, 0.0571277822018601, 0.020071426588401664, 0.04502350573602598, 0.02732109987846343, 0.03577967050659936, 0.07270057118148543, 0.038376812590286136, 0.03124930794001557, 0.06347598726279102, 0.1362917249207385, 0.1078629789117258, 0.1234826270956546, 4.837922723963857, 39.48542162775993, 84.66872870922089, 101.56843587756157, 102.05585852265358, 89.8332367837429, 81.5793576836586, 78.4143403172493, 75.6915508210659, 49.06540296971798, 33.09774398803711, 17.616956681013107, 21.825132071971893, 64.81879904866219, 48.37328530848026, 51.23591110110283, 38.98681618273258, 26.10028836876154, 17.098345309495926, 12.569748312234879, 11.707305740565062, 1.842277825344354, 0.5357387149706483, 0.8031931822188199, 0.4782219137996435, 0.19033260323340073, 0.12823024968383834, 0.2109846138046123, 0.028065295882697683, 0.07893597721704282, 0.0278363154939143, 0.14202242600731552, 0.41027102095540613, 0.042262901915819384, 0.26008927496150136, 0.05294976908771787, 0.06998760582064278, 0.04247474797011819, 0.23712209018412977, 0.0679182235035114, 0.09996881344704889, 0.06149030064989347, 0.24509084149030969, 0.06913338642334566, 0.05185773959965445, 0.03677110929857008, 0.1433861520490609, 0.021588094423350412, 0.1506117166718468, 0.07075432600686327, 0.036972787929698825, 0.26084623590577394, 0.2130758375278674, 0.544777064351365, 0.07824505257303827, 0.06951199306058697, 0.06984384439419955, 0.0255629687308101, 0.18765621091006324, 0.332700825529173, 0.5482290009967983, 0.6482374970801175, 0.5472278734669089, 0.15724929253337905, 0.7518803200218827, 3.085303818807006, 9.357590675354004, 26.125230230391026, 39.30751137435436, 50.955011174082756, 57.01785944402218, 36.60317748785019, 32.87971928715706, 19.045429229736328, 15.919628608971834, 36.39633558690548, 50.13842359185219, 66.58524066209793, 78.94296035170555, 69.24333482980728, 76.81189030408859, 81.51309683918953, 75.83806335926056, 27.78735414147377, 1.3587474776431918, 0.31468934670556337, 0.10746805986855179, 0.028128228150308132, 0.030062827172514517, 0.023552622405986767, 0.06749928114004433, 0.014449476111622062, 0.06727962027071044, 0.07619425363373011, 0.015742030191177037, 0.01869946270744549, 0.05608221486909315, 0.01791075454093516, 0.005566039853874827, 0.06057495796994772, 0.07997764827450737, 0.037827226260560565, 0.02446040445647668, 0.024886126338969916, 0.02944367006421089, 0.05494551922311075, 0.06841482419986278, 0.0054556852774112485, 0.01697316227364354, 0.027954962642979808, 0.010103826680278871, 0.061423874722095206, 0.006735502247465774, 0.035628702826215886, 0.0462320153019391, 0.018705949078139383, 0.022635351997450925, 0.015726088859082665, 0.01813939725252567, 0.01592357992194593, 0.051982427830807865, 0.07100949122104794, 0.024565585335949436, 0.04671344649977982, 0.04630309449566994, 0.05393353778345045, 0.024527758068870753, 0.015567543850920629, 0.04417458527314011, 0.015553831744909985, 0.014271183481469052, 0.11518085186253302, 0.12230713196913712, 0.1437990681733936, 0.0817564500903245, 0.08829578044242226, 0.1423382098437287, 0.21257657994283363, 0.1792284709517844, 0.18297662842087448, 0.15024321066448465, 0.1386493945028633, 0.11498322535771877, 0.0927740331098903, 0.12787661631591618, 0.13292365096276626, 0.1782566582551226, 0.07132417667889968, 0.10396274796221405, 0.10797410068335012, 0.15118383831577376, 0.17931104230228812, 0.17035271128406748, 0.14490323548670858, 0.21084621810587123, 0.12107478833058849, 0.12925524468300864, 0.12822339223930612, 0.1315809425432235, 0.16218822594964877, 0.1874907416640781, 0.18293910543434322, 0.2064597245771438, 0.1542949362192303, 0.19701684534084052, 0.11367906408850104, 0.1877979759592563, 0.10150490328669548, 0.22708423115545884, 0.17470263177528977, 0.13739445246756077, 0.12172818256658502, 0.1123851741431281, 0.30949383799452335, 0.17397026560502127, 0.18679748667636886, 2.5595721043646336, 33.82063999772072, 91.57846793532372, 118.91059130430222, 105.82237601280212, 86.40080496668816, 73.71349096298218, 68.45413997769356, 60.2486664801836, 55.2354396879673, 53.10301311314106, 44.237602427601814, 58.89514110982418, 113.85487899184227, 71.47392153739929, 79.3839418888092, 54.299074932932854, 42.467117831110954, 43.26518900692463, 33.61300773918629, 27.08705361932516, 7.285770373418927, 2.550520752556622, 1.39675386948511, 1.5168483252637088, 0.6502808968070894, 0.4497109749354422, 0.38672038936056197, 0.39717345032840967, 0.33239645592402667, 0.2579684247029945, 0.34643699938897043, 0.6827397050801665, 0.19246578798629344, 0.34681985853239894, 0.10937999555608258, 0.12582975818077102, 0.09812304764636792, 0.44125488493591547, 0.20476513425819576, 0.17929959838511422, 0.1720266550546512, 0.5469369515776634, 0.10100140803842805, 0.2033587495679967, 0.14162399660563096, 0.1345088635571301, 0.10374299803515896, 0.3921915020328015, 0.23108474852051586, 0.21985921572195366, 0.42585220362525433, 0.3310542966937646, 0.5779297510161996, 0.2934212941909209, 0.2935913944384083, 0.13605397049104795, 0.14453685202170163, 0.6001054204534739, 0.9990778961218894, 0.97542351228185, 1.1223737988620996, 0.698720341315493, 0.7217363594099879, 2.363452040590346, 10.354441534727812, 24.30031355470419, 48.83333422243595, 64.33184757828712, 75.46180754899979, 88.03011953830719, 75.27819380164146, 64.46445286273956, 45.073914751410484, 29.300689436495304, 35.24898335337639, 43.42641055583954, 59.06596854329109, 73.43594625592232, 73.29328671097755, 86.87311202287674, 92.36573249101639, 82.61148869991302, 24.344075806438923, 0.8147484809160233, 0.6078047573100775, 0.17328561953036115, 0.1852246531052515, 0.3085433249361813, 0.13818973791785538, 0.17249011143576354, 0.14841231750324368, 0.1342704560374841, 0.13788110838504508, 0.13432901148917153, 0.11527072594617493, 0.11689759528962895, 0.06723178885295056, 0.09556825621984899, 0.11990962389972992, 0.24943304364569485, 0.05953322754066903, 0.1421164264320396, 0.12424572560121305, 0.13063063728623092, 0.11487092357128859, 0.1494930181070231, 0.10100609841174446, 0.1485392841277644, 0.13292719842866063, 0.07359621726209298, 0.1897466034279205, 0.13927042367868125, 0.1967763004358858, 0.15965150581905618, 0.12802777695469558, 0.13977998227346689, 0.07225506735267118, 0.16706520487787202, 0.08694385454873554, 0.09768193733179942, 0.1719521137420088, 0.06251707309274934, 0.18213396426290274, 0.1236169038747903, 0.13270339637529105, 0.09331993467640132, 0.11525600173627026, 0.156529750674963, 0.06084970103984233, 0.10960684783640318], [0.0850240966246929, 0.021061318002466578, 0.04712412504886743, 0.05487169408297632, 0.038220442074816674, 0.05696387517673429, 0.011737700970115839, 0.030225858463381883, 0.018418238832964562, 0.03059635157114826, 0.014327910466818139, 0.07752665362204425, 0.03406041119887959, 0.037526953310589306, 0.025609061667637434, 0.016223411294049583, 0.01768387999618426, 0.02517874960176414, 0.009195539041684242, 0.04564260161714628, 0.039265779341803864, 0.05647711906931363, 0.03665420248580631, 0.04561074121738784, 0.06119654375652317, 0.03688812372274697, 0.06943978209164925, 0.06891895027365535, 0.06570018158527091, 0.015072595360834384, 0.05471103766467422, 0.041209979899576865, 0.04175666814262513, 0.06382677820511162, 0.07206002352177165, 0.06452500558225438, 0.01632156960113207, 0.02531772046495462, 0.04181289696134627, 0.010226974027318647, 0.0868998451915104, 0.06653385833487846, 0.13004655222175643, 0.4547826340422034, 13.596877846866846, 54.76195469498634, 83.73090863227844, 84.99760866165161, 72.06768527626991, 45.947556272149086, 53.495623245835304, 49.227084293961525, 28.12406737357378, 24.864815063774586, 45.669130012393, 68.79865989089012, 89.51038330793381, 64.36605334281921, 31.004846692085266, 32.7596153318882, 26.629313081502914, 18.791842237114906, 9.30346067994833, 1.5558198653161526, 0.057652951873023994, 1.1824372946284711, 0.39441194850951433, 0.06485584017354995, 0.034354984454694204, 0.13865781045751646, 0.20307845523348078, 0.13922700803959742, 0.06356370911817066, 0.05819526515551843, 0.2806688519194722, 0.16894172527827322, 0.12704207125352696, 0.14534560003085062, 0.06541012800880708, 0.2034830889897421, 0.368263028212823, 0.6275755714159459, 0.3201067872578278, 0.24114245257806033, 0.16017825255403295, 0.28243103704880923, 0.39374517335090786, 0.2984483353793621, 0.09721397611428984, 0.35646187083330005, 0.8485506952274591, 1.1626405944116414, 0.34249031741637737, 0.15599917445797473, 0.3509140794631094, 0.4571355093503371, 0.14051297184778377, 0.26146120915655047, 0.13945146318292245, 0.20853986061410978, 0.1930599068873562, 0.24414877407252789, 0.1461435720557347, 0.3467794263269752, 0.5451449321117252, 0.34083111269865185, 0.36045774235390127, 0.3120659140404314, 0.03577214141841978, 0.043031596214859746, 0.0935002691403497, 0.4884200915694237, 2.568864980712533, 15.60988062992692, 25.26557955890894, 29.68338780105114, 45.20213507115841, 52.20749616622925, 70.98630890250206, 66.04033470153809, 34.326366260647774, 30.137645825743675, 35.984190702438354, 42.205824851989746, 58.57922986149788, 53.141527846455574, 59.64687377214432, 71.1582724750042, 78.09711813926697, 42.41890221834183, 6.522282566875219, 0.167566585005261, 0.1902845417498611, 0.03523734238115139, 0.10884908537263982, 0.0601882730552461, 0.03642669711553026, 0.014994052016845671, 0.02523246996133821, 0.016918605142564047, 0.06541300754179247, 0.04505015996983275, 0.027548673897399567, 0.09086368561838754, 0.03727316106960643, 0.0046797035520285135, 0.049982607015408576, 0.07683204792556353, 0.05246355474810116, 0.027903075388167053, 0.048139531500055455, 0.04397804230393376, 0.018898200578405522, 0.10634759499225765, 0.01515859450591961, 0.021783687443530653, 0.048545887038926594, 0.023708091212029103, 0.015209696011879714, 0.048165766420424916, 0.004479087119761971, 0.05184310815820936, 0.0788583634130191, 0.016705682974134106, 0.03791323375480715, 0.06400322381523438, 0.005454541442304617, 0.03209992792108096, 0.008882869442459196, 0.06633191995206289, 0.06421062440495007, 0.0342443042609375, 0.030181335168890655, 0.014956855575292138, 0.026627856022969354, 0.0780791231954936, 0.05306437153194565, 0.044766819119104184, 0.05913104658247903, 0.031145414686761796, 0.017413905225112103, 0.026893110734818038, 0.050427405803930014, 0.01016087186144432, 0.009278233774239197, 0.034034157724818215, 0.03404128234251402, 0.03512095136102289, 0.04623700995580293, 0.04344021530414466, 0.008912244575185468, 0.01666632502747234, 0.009348595867777476, 0.06545441938214935, 0.04205885954434052, 0.03225253945856821, 0.03096930118772434, 0.07480978456442244, 0.05822807550430298, 0.031603913521394134, 0.05638340437144507, 0.05984586838167161, 0.04297871819289867, 0.06723420825437643, 0.06422320380806923, 0.03416047868086025, 0.04113292270631064, 0.020539949982776307, 0.04428920627105981, 0.01583659464813536, 0.0661505464813672, 0.024615090296720155, 0.017101006487791892, 0.04161177494097501, 0.016433991986559704, 0.04937497360515408, 0.03461083986621816, 0.05018899086280726, 0.11178865810506977, 2.604576414451003, 29.814765751361847, 80.0022903084755, 98.02226096391678, 100.03355383872986, 93.49836051464081, 72.35026851296425, 85.39869233965874, 73.9937487244606, 43.59152689576149, 24.548835419118404, 22.92789939790964, 38.793440759181976, 67.5724808871746, 71.3920359313488, 36.93698577582836, 33.310832753777504, 20.09824823588133, 10.549866948276758, 3.3503754576668143, 0.33573742664884776, 0.30430744285695255, 0.9873824205715209, 0.260193680296652, 0.11251952513703145, 0.04154295187618118, 0.20767546637216583, 0.1108022770495154, 0.11193488346179947, 0.06187387596582994, 0.10659940569894388, 0.24646504665724933, 0.04378098725283053, 0.18835342896636575, 0.1663385087158531, 0.3925713925855234, 0.297797056264244, 0.4093266825657338, 0.55146120255813, 0.4193585005123168, 0.257913208915852, 0.3312712116166949, 0.4725806415081024, 0.6051619397476315, 0.5186595814302564, 0.27773401408921927, 0.2522277639945969, 1.0166240483522415, 1.1632265942171216, 0.35930741345509887, 0.34494605439249426, 0.4996405332349241, 0.15243134403135628, 0.17615422810195014, 0.12687495443969965, 0.006771302059860318, 0.036138959039817564, 0.15713494241936132, 0.1692293371888809, 0.21772453183075413, 0.3782458050409332, 0.3431315330090001, 0.2907886588945985, 0.22015660913893953, 0.28015383111778647, 0.044049826537957415, 0.0774652037944179, 0.02951008857053239, 0.31481684767641127, 0.4666256485506892, 10.000133346766233, 22.04421691596508, 30.282744839787483, 46.02580927312374, 42.317079082131386, 44.10131514072418, 29.16884981095791, 16.96160964667797, 24.493478089571, 45.116628259420395, 71.57372698187828, 91.45220071077347, 81.26536533236504, 75.18668711185455, 80.59871390461922, 95.46086400747299, 64.53044772148132, 16.38729516416788, 0.34806230280082673, 0.19277468469226733, 0.008535347660654224, 0.024616079208499286, 0.04942929881508462, 0.03768170965486206, 0.025440712888666894, 0.05786193323729094, 0.030450131780526135, 0.048770034190965816, 0.021324164445104543, 0.0446293770801276, 0.048792684538057074, 0.01698617583315354, 0.06949617047212087, 0.03942692928831093, 0.015273160770448158, 0.019502095419738907, 0.10339189539081417, 0.07264167434186675, 0.015139489769353531, 0.04004939823062159, 0.014178424298734171, 0.010771877405204577, 0.03277836221968755, 0.013271760108182207, 0.03792477786191739, 0.04081069702806417, 0.03570873974240385, 0.010203933125012554, 0.029389413502940442, 0.050560465460876, 0.04703710452304222, 0.026940619318338577, 0.041212020805687644, 0.04889975789410528, 0.13010538968956098, 0.03697842083056457, 0.06975739161134697, 0.07282037608092651, 0.1118470799701754, 0.0957761614699848, 0.052225473773432896, 0.022684524847136345, 0.034770672500599176, 0.21231486898614094, 0.0974990201939363, 0.18079925619531423, 0.09854383053607307, 0.09431260914425366, 0.18918833025963977, 0.10003787028836086, 0.08965676795924082, 0.09102151074330322, 0.16054491803515702, 0.14595453219953924, 0.18226339481770992, 0.1811773210647516, 0.11548816779395565, 0.16774539806647226, 0.1502043814980425, 0.07512494499678724, 0.11387754406314343, 0.14990253519499674, 0.23307799390750006, 0.16460939368698746, 0.19419088057475165, 0.12121178879169747, 0.15211517427815124, 0.14498672710033134, 0.1264927929150872, 0.18591419735457748, 0.22961749287787825, 0.1658627623692155, 0.1640477214823477, 0.19948622299125418, 0.09125038908678107, 0.19408574793487787, 0.14910224766936153, 0.310121487127617, 0.11450061414507218, 0.1843353672302328, 0.15456090710358694, 0.09730887453770265, 0.29435283795464784, 0.18968645978020504, 0.09263689906219952, 0.35208174493163824, 1.1583852977491915, 25.44487103819847, 82.1732734143734, 112.87135496735573, 106.39321938157082, 90.35260811448097, 63.98687168955803, 69.77659061551094, 61.773106679320335, 35.4227290302515, 35.50130881369114, 60.811389684677124, 88.65186497569084, 116.69694408774376, 87.82764360308647, 42.811858132481575, 49.8865807056427, 39.758011400699615, 28.879470638930798, 15.609775185585022, 2.9663417022675276, 0.8377852197736502, 1.3307971274480224, 0.4770539217861369, 0.19231148064136505, 0.27284403273370117, 0.4656270443229005, 0.5190735217183828, 0.4864686884684488, 0.19253065169323236, 0.5637494463007897, 0.8410501945763826, 0.4260351281845942, 0.45569767244160175, 0.46751643356401473, 0.7520571886561811, 0.9493119665421546, 1.1413808539509773, 2.4837108375504613, 1.2156678177416325, 1.1626234953291714, 0.798068979056552, 1.0871257027611136, 0.9278085641562939, 1.1474650399759412, 1.1236130073666573, 1.1612816923297942, 2.007233267650008, 2.6114564202725887, 0.9593081614002585, 1.0952811338938773, 0.9228441899176687, 1.1446072370745242, 0.44011580699589103, 0.6406290584709495, 0.5338210053741932, 0.4277790861669928, 0.617009288398549, 0.6519018660765141, 0.761147903976962, 1.111972094513476, 1.0625195293687284, 0.8533360040746629, 0.5442328029312193, 0.42505148565396667, 0.2971467864699662, 0.19698441348737106, 0.20698089036159217, 1.214137093629688, 4.697274221107364, 24.15166363120079, 39.26983259618282, 45.858177468180656, 66.50541454553604, 72.53053843975067, 94.49353471398354, 85.5268594622612, 46.62132851779461, 44.52756106853485, 46.62257485091686, 56.35634534060955, 80.21595284342766, 73.96255239844322, 76.44747465848923, 87.24999099969864, 105.92985704541206, 65.68058520555496, 12.710103280842304, 0.22124412265839055, 0.4318654106464237, 0.14590653008781374, 0.1550547915394418, 0.21288129093591124, 0.16927788848988712, 0.09729236175189726, 0.16270560678094625, 0.1589542580768466, 0.24021225952310488, 0.17334971140371636, 0.08448841443168931, 0.1634007616667077, 0.14063373411772773, 0.19138234143611044, 0.12049581666360609, 0.1677393718273379, 0.10315584790077992, 0.2222402481129393, 0.2542030642507598, 0.10010432219132781, 0.21899906656472012, 0.19181333627784625, 0.11818962986581028, 0.07744494316284545, 0.1795084387413226, 0.10493258654605597, 0.11410835199058056, 0.09257588710170239, 0.08388689631829038, 0.12390225965646096, 0.2018308753031306, 0.12989482755074278, 0.07851902380934916, 0.20915562054142356, 0.0966313605022151, 0.15656659088563174, 0.06417937256628647, 0.13988674763822928, 0.30186838936060667, 0.21244330506306142, 0.11419782531447709, 0.10900451336055994, 0.12107325208489783, 0.09892277113976888], [0.06854623628896661, 0.09455141000216827, 0.030748853641853202, 0.03109825491264928, 0.024451058961858507, 0.0511368470324669, 0.01840820870711468, 0.051805574039462954, 0.056779006190481596, 0.05883689264010172, 0.03805688756983727, 0.02753044303972274, 0.021960350131848827, 0.06883281661430374, 0.017393767047906294, 0.049605295425863005, 0.02771473129541846, 0.02203406394983176, 0.05284219478198793, 0.026662007803679444, 0.017848000388767105, 0.03155832710035611, 0.041879519558278844, 0.013581704170064768, 0.07315475813811645, 0.02011653246881906, 0.05725155759137124, 0.009937867616827134, 0.07647498583537526, 0.03962933522416279, 0.021449182931974065, 0.02820310528477421, 0.1362105636508204, 0.03836140931525733, 0.05129488366947044, 0.024724280629015993, 0.04873828511335887, 0.0392464278411353, 0.062330986984306946, 0.035706175622181036, 0.06710817673592828, 0.12054479841026478, 9.603100251406431, 50.40575064718723, 78.03676977753639, 91.18746891617775, 74.16186690330505, 68.98346677422523, 59.540779665112495, 46.373167634010315, 31.64540871977806, 24.88281849771738, 39.28273290395737, 72.43378043174744, 80.05078330636024, 64.33584496378899, 38.220720291137695, 22.254526130855083, 32.77253083884716, 14.472045935690403, 6.056318795308471, 0.3293138713343069, 0.12222461999044754, 0.07620597214554437, 0.015357824049715418, 0.42381393956020474, 0.19991914741694927, 0.09612897105398588, 0.10148629764444195, 0.08413081799517386, 0.033385913993697613, 0.05970846345007885, 0.08811767242150381, 0.06873308680951595, 0.0987855702987872, 0.09764114889549091, 0.06296748251770623, 0.14689882606035098, 0.11270647213677876, 0.1063721303944476, 0.23639015445951372, 0.17467178811784834, 0.019978381678811274, 0.06266516124014743, 0.13396117341471836, 0.11928057952900417, 0.37223265739157796, 0.03198203776264563, 0.056321364536415786, 0.20416864048456773, 0.0974009750643745, 0.12748609820846468, 0.24545237130951136, 0.10850470658624545, 0.06319343679933809, 0.030255781857704278, 0.06139265256933868, 0.041009600026882254, 0.161800735804718, 0.04007038987765554, 0.07214065044536255, 0.14270131301600486, 0.07445584691595286, 0.022179411716933828, 0.01866891405370552, 0.05338732822565362, 0.06913501172675751, 0.12350211589364335, 0.02658244029589696, 0.1301110300119035, 0.1797809256822802, 0.03786674191360362, 0.03236167598515749, 0.25246115459594876, 5.624669557437301, 16.94650735706091, 25.93853484839201, 36.817451789975166, 41.06139466166496, 56.17644019424915, 71.67721062898636, 88.92072334885597, 36.99840188026428, 21.76220554858446, 23.60420610755682, 23.98984931409359, 43.42297174036503, 48.6408631503582, 58.30743044614792, 69.84590649604797, 66.3584840297699, 32.78780981898308, 3.343084123916924, 0.19294009456643835, 0.1146656232594978, 0.02993485308252275, 0.023205497673188802, 0.029963442466396373, 0.011347040926921181, 0.1301321218488738, 0.018413804500596598, 0.01606454716238659, 0.03370062171597965, 0.01674312061368255, 0.08495739981299266, 0.09842925777775235, 0.028437330802262295, 0.03643179195933044, 0.06017327053996269, 0.011882861344929552, 0.05792773576104082, 0.02106376337906113, 0.08737023323192261, 0.02165209167287685, 0.05837001866893843, 0.06364205022691749, 0.09430606340174563, 0.009032880680024391, 0.08175654656952247, 0.039153559191618115, 0.0586717499390943, 0.04551228048512712, 0.008767458984948462, 0.08735667419387028, 0.028537444668472745, 0.04528316465439275, 0.019369132241990883, 0.032207780532189645, 0.05395177235186566, 0.05296726150845643, 0.040457353097735904, 0.01962770020327298, 0.06686787673970684, 0.04875160666415468, 0.03867233208438847, 0.0141085919131001, 0.006006547173456056, 0.01954730149009265, 0.039467973765567876, 0.016463748397654854, 0.025862091351882555, 0.06363706299453042, 0.02437679038848728, 0.06013781072397251, 0.03709676369908266, 0.04473437984415796, 0.04058764083310962, 0.046905577401048504, 0.10395174933364615, 0.06020034779794514, 0.061207427352201194, 0.033773726972867735, 0.03482344291114714, 0.06008056145219598, 0.016582349162490573, 0.029331833975447807, 0.047946680715540424, 0.032788614989840426, 0.030119690527499188, 0.06293673533946276, 0.03162152097502258, 0.0490614050795557, 0.023732090412522666, 0.01797662571334513, 0.010451240850670729, 0.042046962917083874, 0.020181273721391335, 0.03702005160448607, 0.06817182278609835, 0.0757125997915864, 0.04541476970189251, 0.021955058618914336, 0.03642641138867475, 0.049681918462738395, 0.05841767939273268, 0.03536971555149648, 0.04881952059804462, 0.21323214867152274, 21.765083894133568, 72.63328492641449, 94.49570819735527, 104.56174045801163, 99.45718556642532, 100.28858095407486, 85.03932282328606, 53.280034214258194, 29.813091941177845, 19.317080453038216, 15.932561215013266, 35.50649553537369, 62.687702402472496, 63.06607849895954, 42.95076347887516, 20.55205788463354, 18.136141821742058, 6.188145121559501, 1.3864009687677026, 0.24669138685567304, 0.3437028976622969, 0.06026746392308269, 0.04084826825419441, 0.4074225988006219, 0.1278122721123509, 0.07077929185470566, 0.09420631133252755, 0.11080837008194067, 0.1284444928751327, 0.011734948529920075, 0.031363119996967725, 0.09625308040995151, 0.0535907249286538, 0.06122236307419371, 0.06385094253346324, 0.23452233202988282, 0.10137864912394434, 0.1854293077485636, 0.11181008390849456, 0.04370791539258789, 0.06520149545394816, 0.031247916413121857, 0.1599296330823563, 0.173245899786707, 0.21061082370579243, 0.05957364490313921, 0.04342603657278232, 0.21312110853614286, 0.2329575878684409, 0.07697269975324161, 0.1860546413809061, 0.026119043286598753, 0.07815545308403671, 0.10485354039701633, 0.01980480446945876, 0.07147607946535572, 0.18683699861867353, 0.08946400252170861, 0.061507210484705865, 0.10350302458391525, 0.05364815231587272, 0.0884144424344413, 0.05116447719046846, 0.0938808498904109, 0.17686999985016882, 0.061556923246826045, 0.043901916506001726, 0.09562821433064528, 0.07980035661603324, 0.05772081385657657, 0.022811064736742992, 0.06325887195998803, 2.47559969779104, 12.766360212117434, 25.128433518111706, 42.05224469304085, 43.9806754142046, 52.89010673761368, 42.076612785458565, 55.27997709810734, 21.719674430787563, 22.513892613351345, 30.1548171043396, 40.25717541575432, 76.14297419786453, 77.08126544952393, 75.67033275961876, 79.13352772593498, 82.60631337761879, 51.802890077233315, 9.900577738881111, 0.27806394326034933, 0.19720411888556555, 0.11324403196340427, 0.04306104834540747, 0.027556677960092202, 0.02833706108503975, 0.06572314363438636, 0.09771051001735032, 0.04473543740459718, 0.06361747029586695, 0.021317646533134393, 0.08216635309509002, 0.03955635613237973, 0.016438997772638686, 0.07556345037301071, 0.039202641128213145, 0.07054376386804506, 0.04664600011892617, 0.025485961632512044, 0.06257863424252719, 0.03649346443125978, 0.010593231327220565, 0.006240615912247449, 0.010548272020969307, 0.0020065059425178333, 0.0846957036992535, 0.05453188692627009, 0.03502015657431912, 0.045216805519885384, 0.10372368735261261, 0.04433933463587891, 0.022785928194934968, 0.12472271133447066, 0.029938075858808588, 0.03338997354148887, 0.06234524364117533, 0.025391540038981475, 0.042183640543953516, 0.03383938477782067, 0.04393589202663861, 0.031185141851892695, 0.020413050151546486, 0.052623268638853915, 0.2187981820316054, 0.1290200580842793, 0.1489686907734722, 0.16972932207863778, 0.1309612492332235, 0.20433554949704558, 0.1546951913041994, 0.1469247863860801, 0.12408037509885617, 0.20036629139212891, 0.11750240111723542, 0.1178850895666983, 0.19833145604934543, 0.14757845521671697, 0.1501535443821922, 0.15981834061676636, 0.06342965498333797, 0.1182608018280007, 0.2560053253546357, 0.14900974638294429, 0.17784893716452643, 0.09363194840261713, 0.13123519078362733, 0.11414037566282786, 0.14615598076488823, 0.11536989171872847, 0.11663814788335003, 0.10781692864838988, 0.11390248022507876, 0.13325941341463476, 0.13171268859878182, 0.12583513132994995, 0.17995242116739973, 0.22312666929792613, 0.1973791469936259, 0.13633160793688148, 0.17752322339219972, 0.08436978212557733, 0.12941330729518086, 0.1549305411754176, 0.289717621053569, 0.15877627622103319, 17.474914602935314, 75.09357690811157, 110.13933196663857, 114.6287302672863, 95.34789606928825, 90.85055619478226, 78.65957915782928, 58.34739290177822, 40.302609577775, 38.07051435112953, 55.4082316160202, 88.92242565751076, 100.65588444471359, 86.74799993634224, 51.29929170012474, 32.21539333462715, 46.904375329613686, 23.284295573830605, 9.321872591972351, 1.409334756899625, 0.7587707752827555, 0.18429211486363783, 0.17617842211620882, 0.7012956531252712, 0.4910677776206285, 0.34633921401109546, 0.39567778527271, 0.2914086787495762, 0.2080863935407251, 0.19369153393199667, 0.34955651324708015, 0.20289885549573228, 0.22369202255504206, 0.16760590398916975, 0.3062196902465075, 0.5268148344475776, 0.4615929670399055, 0.7062787294853479, 0.562715723644942, 0.3182619862491265, 0.6623513053636998, 0.2710493712220341, 0.5363333830609918, 0.570959203178063, 0.7182063488289714, 0.3869751835009083, 0.6368742068298161, 0.9028992976527661, 0.6546764890663326, 0.315161946346052, 0.8272226178087294, 0.6974548904690892, 0.27832746505737305, 0.2187264757230878, 0.20545824081636965, 0.25679434707853943, 0.32378047762904316, 0.2830502256983891, 0.16216377960518003, 0.2433933419524692, 0.18418367224512622, 0.17047136585460976, 0.18796706688590348, 0.2454406305332668, 0.28430585050955415, 0.2811668626964092, 0.34889879229012877, 0.22292489418759942, 0.37446661095600575, 0.2286229853052646, 0.09908160558552481, 0.49775414227042347, 10.198256615549326, 27.25969735532999, 41.870112866163254, 59.640858694911, 61.20413281023502, 81.87550619244576, 96.4990746974945, 104.5889014005661, 49.76855143904686, 32.98082426190376, 31.71626541763544, 36.54162839055061, 58.40586416423321, 70.356325507164, 74.37484547495842, 87.38231509923935, 92.35864967107773, 51.873661279678345, 7.536826701834798, 0.34954817150719464, 0.2651745598996058, 0.11052272486267611, 0.19734220288228244, 0.12468668748624623, 0.1391236565541476, 0.3067483368795365, 0.38481250579934567, 0.10731972681242041, 0.15991041145753115, 0.08095232566120103, 0.22553248942131177, 0.23886650829808787, 0.1294682262232527, 0.1351417670957744, 0.12608581397216767, 0.20445208152523264, 0.2201754745328799, 0.18283504148712382, 0.18332778301555663, 0.11828850620076992, 0.18853798625059426, 0.11525554160471074, 0.11400347168091685, 0.11771221368690021, 0.22129963530460373, 0.10819529779837467, 0.10357877559727058, 0.10575421081739478, 0.2644095243886113, 0.17023595661157742, 0.10160733450902626, 0.20793457981199026, 0.15405443584313616, 0.12006443590507843, 0.1377638490521349, 0.08892056488548405, 0.12672933022258803, 0.1742818785714917, 0.12048106276779436, 0.11101404888904653, 0.10770656386739574, 0.14848801656626165], [0.06033969344571233, 0.017474891210440546, 0.023736198199912906, 0.03271790315920953, 0.04431669913174119, 0.047251629730453715, 0.055071584138204344, 0.0587149280909216, 0.03383921037311666, 0.06367818539729342, 0.02304817535332404, 0.024933223030529916, 0.0565451814327389, 0.032568853930570185, 0.026781825690704864, 0.0461577411624603, 0.10914402228081599, 0.023051689422572963, 0.025376459598192014, 0.029905230258009396, 0.004463404147827532, 0.054676190120517276, 0.03273754409747198, 0.03411417608731426, 0.033403302513761446, 0.0532510216726223, 0.04975211078999564, 0.05592869048996363, 0.05206443143833894, 0.07705412819632329, 0.03980189940193668, 0.005811077999169356, 0.02331290870642988, 0.05314407077094074, 0.033711861542542465, 0.028660112402576488, 0.027318984757584985, 0.04071586168720387, 0.06528255282319151, 0.133659950515721, 2.7303546527400613, 28.15937887877226, 70.82328245043755, 86.29495784640312, 72.59871438145638, 64.42258670926094, 46.62472553551197, 37.54193991422653, 32.96631284058094, 46.93146027624607, 72.26601183414459, 128.79326820373535, 116.1642050743103, 66.29319593310356, 39.47247952222824, 20.79296115785837, 20.50750147551298, 26.348363757133484, 7.312014615163207, 0.21040630264906213, 0.10356115701142699, 0.05272884285659529, 0.21187648235354573, 0.09781921980902553, 0.033463939689681865, 0.1589844486443326, 0.032362622223445214, 0.05862318750587292, 0.09363126562675461, 0.05920544688706286, 0.11323537852149457, 0.14005943055963144, 0.11014025905751623, 0.01078842265997082, 0.23610117699718103, 0.05240413469437044, 0.048188075379584916, 0.2829516981728375, 0.07587873697048053, 0.29297253233380616, 0.10042531590443105, 0.13546559581300244, 0.31700846913736314, 0.24218466540332884, 0.24166192626580596, 0.2834785933373496, 0.6200199143495411, 0.09363326200400479, 0.1881706528365612, 0.12662915512919426, 0.28466122050303966, 0.2495907648699358, 0.08579764456953853, 0.11638836323982105, 0.10112603689776734, 0.09579511592164636, 0.15676823240937665, 0.13216842664405704, 0.1311698224162683, 0.0806846923660487, 0.1844448785413988, 0.17137432208983228, 0.05486874404596165, 0.1354728837031871, 0.09480045991949737, 0.16154359647771344, 0.025294199949712493, 0.09266501903766766, 0.14704268396599218, 0.04969231224094983, 0.06747599254595116, 0.10704221553169191, 0.033689496922306716, 0.053478786794585176, 0.1260712233488448, 0.16374722588807344, 3.497481239028275, 9.773242771625519, 23.719273433089256, 33.03763121366501, 50.35875476896763, 55.43860338628292, 60.849182456731796, 59.24208529293537, 31.326869912445545, 25.222286581993103, 22.162971943616867, 27.550761736929417, 48.66303116083145, 55.987651124596596, 60.2881121635437, 71.72412291169167, 58.9725923538208, 22.501172795891762, 0.6363636092282832, 0.25810877967160195, 0.06536012951983139, 0.05526905850274488, 0.06014226732077077, 0.08428232744336128, 0.04811946753761731, 0.06443965117796324, 0.01531173389594187, 0.04790285318449605, 0.030351556015375536, 0.05103994481032714, 0.04605295733199455, 0.05447892726806458, 0.0667406058346387, 0.02700246433960274, 0.015084526312421076, 0.0394985762250144, 0.04219757807732094, 0.037613239110214636, 0.08378273589187302, 0.11695345674525015, 0.01943422972544795, 0.07317093695746735, 0.040142767829820514, 0.011725462954927934, 0.06621368098421954, 0.034168987403973006, 0.06805900891777128, 0.03008971889357781, 0.05535930366022512, 0.04084356303792447, 0.08411256116232835, 0.01036812866004766, 0.046229094950831495, 0.04168069819570519, 0.03338834452733863, 0.05315476140822284, 0.0701110769296065, 0.03231602277082857, 0.0547008182911668, 0.010686418172554113, 0.027439338846306782, 0.029022189555689692, 0.04645290442567784, 0.035936460335506126, 0.0469281090045115, 0.006525412763949134, 0.0169401719540474, 0.03609964747738559, 0.029539620481955353, 0.0959932322439272, 0.034140514908358455, 0.04978165197826456, 0.021184084071137477, 0.04634356751921587, 0.015462184856005479, 0.0339275073929457, 0.0846301052661147, 0.01921775081427768, 0.04311739590775687, 0.05391707694798242, 0.03146256036416162, 0.038122589903650805, 0.07095761509845033, 0.061769774911226705, 0.0040437168536300305, 0.023830519603507128, 0.009882256636046804, 0.0715687959745992, 0.09639045194489881, 0.03656849185063038, 0.030199740431271493, 0.05420219895313494, 0.022353853528329637, 0.06435176605009474, 0.03423073037993163, 0.12233106623170897, 0.013863016174582299, 0.06398397250450216, 0.1894958910997957, 0.08745020706555806, 8.699083160609007, 50.28969347476959, 87.39930018782616, 99.2090816795826, 91.27372428774834, 87.47208148241043, 75.45236125588417, 56.89757689833641, 52.17136390507221, 54.85818073153496, 45.849764719605446, 87.71611198782921, 87.8419840335846, 63.44868376851082, 45.422572642564774, 19.223886653780937, 10.05641782656312, 9.792543835937977, 2.4127857433632016, 0.33774977491702884, 0.10777209550724365, 0.07750783275696449, 0.07713393875746988, 0.11216537968721241, 0.1559124916093424, 0.10061881606816314, 0.06065210793167353, 0.08676533092511818, 0.1452901615994051, 0.11593726361752488, 0.07767204777337611, 0.10757504045614041, 0.040845359035301954, 0.07097322246409021, 0.17575964302523062, 0.1462760751019232, 0.2139160971273668, 0.2555388113250956, 0.2813163015525788, 0.5368628608994186, 0.16838355601066723, 0.10518533978029154, 0.5244597920682281, 0.39882849901914597, 0.6808279326651245, 1.2715585436671972, 1.2537285941652954, 0.6972454267088324, 1.0873900260776281, 0.7952880626544356, 0.3746085095917806, 1.0479242750443518, 0.8976868679746985, 0.4413049353752285, 0.38862444343976676, 0.16418672574218363, 1.0249852621927857, 0.8178805815987289, 0.30176273721735924, 0.12339300534222275, 0.043799103077617474, 0.32125483034178615, 0.08021495741559193, 0.18652424274478108, 0.45537136495113373, 0.15177025372395292, 0.23436389834387228, 0.09909394007991068, 0.1529573486186564, 0.052427330520004034, 0.036891678610118106, 0.10881493173656054, 0.03250253190344665, 0.01792278289940441, 0.1262454202515073, 0.2629666408756748, 1.4186428324319422, 7.066819472238421, 23.203192725777626, 38.73843491077423, 54.15321595966816, 54.676805064082146, 41.21359549462795, 26.10499631613493, 19.734203070402145, 21.22375164180994, 27.10572011768818, 44.97171923518181, 74.10776540637016, 80.76982632279396, 77.77301833033562, 82.70214423537254, 76.63450062274933, 39.07091327011585, 2.3127857968211174, 0.295648182509467, 0.15539476939011365, 0.028616848903766368, 0.04040333216835279, 0.10768297099275514, 0.03335756766318809, 0.03929232225345913, 0.0372712426178623, 0.019108172709820792, 0.03897557362506632, 0.029643834714079276, 0.023249709265655838, 0.03134033606329467, 0.031610192090738565, 0.006209415096236626, 0.02424921334750252, 0.021808135643368587, 0.12094252277165651, 0.019103550985164475, 0.021669227862730622, 0.04298529362131376, 0.042221096737193875, 0.05286765415803529, 0.037358155532274395, 0.005594824979198165, 0.048193203620030545, 0.026457119383849204, 0.03951743790821638, 0.049536806327523664, 0.033248954350710846, 0.02220323651272338, 0.062137768836691976, 0.03517121702316217, 0.021919773207628168, 0.06793097360059619, 0.0592834762937855, 0.03422179121116642, 0.016754672142269555, 0.02808485889545409, 0.037787450855830684, 0.026458557294972707, 0.1155881944578141, 0.18080350128002465, 0.17994336696574464, 0.15151318861171603, 0.18901693867519498, 0.07744757036562078, 0.12193878923426382, 0.09828534050029702, 0.13413933338597417, 0.17341555474558845, 0.18123247748007998, 0.09796984610147774, 0.19818964647129178, 0.1553047468769364, 0.12703413027338684, 0.09640615578973666, 0.2662415901431814, 0.12837581452913582, 0.09777561863302253, 0.2115928038256243, 0.06576911226147786, 0.1495386305032298, 0.15627874148776755, 0.22217906545847654, 0.08663632339448668, 0.19010273041203618, 0.06344512134091929, 0.13038963224971667, 0.1861710546654649, 0.17603814136236906, 0.1339376621763222, 0.18636098509887233, 0.07495228433981538, 0.12144221822381951, 0.18185556982643902, 0.22303439065581188, 0.19982360332505777, 0.16438413702417165, 0.266403675195761, 0.29187655833084136, 6.030791290104389, 49.36181366443634, 100.9242108464241, 111.76407158374786, 91.59747451543808, 84.93557319045067, 65.25506883859634, 50.27438409626484, 43.99981118738651, 62.227497696876526, 95.2591024339199, 139.85600978136063, 135.94022870063782, 91.16163790225983, 58.199577033519745, 32.370349019765854, 30.680946372449398, 36.518681421875954, 10.925759878009558, 1.3404673710465431, 0.3401198977371678, 0.1683930555009283, 0.635814598063007, 0.43717013380955905, 0.38644347921945155, 0.20046104880748317, 0.2133155512274243, 0.12289201855310239, 0.30437788751441985, 0.3661937126889825, 0.4568555118748918, 0.3547908808104694, 0.32631684152875096, 0.16607083089184016, 0.5546545155812055, 0.3001424507237971, 0.5028503516223282, 0.9311615279875696, 0.845605437643826, 0.9146036196034402, 0.9559838741552085, 0.7470003131311387, 1.8570209154859185, 0.6620824697893113, 0.9775008726865053, 1.9454371836036444, 2.240586346015334, 0.8014778117649257, 1.6411047452129424, 0.94267942244187, 1.5818779170513153, 1.4555774442851543, 0.738920996664092, 0.4313983622705564, 0.6766404386144131, 0.3537163103464991, 0.7155524881090969, 0.45064471545629203, 0.40750278043560684, 0.2555608976399526, 0.7965229370165616, 0.5347827693913132, 0.30990590807050467, 0.5153259728103876, 0.9158849820960313, 0.36685778643004596, 0.44036148756276816, 0.1839536361512728, 0.3138893115101382, 0.10628710995661095, 0.24870775756426156, 0.4583265969995409, 0.17756301735062152, 0.12036657906719483, 0.4107005463447422, 0.9341855719685555, 5.744121847674251, 16.598077453672886, 40.012206360697746, 52.93944329023361, 75.52249789237976, 78.85177284479141, 82.14812636375427, 76.04333594441414, 48.75326491892338, 37.57029019296169, 26.752952747046947, 38.44194062054157, 65.90411961078644, 76.20954662561417, 78.49384725093842, 95.3791455924511, 85.21149158477783, 36.56156212091446, 1.3353854999877512, 0.41484371933620423, 0.185173949575983, 0.06053805096598808, 0.15447924117324874, 0.2122361122746952, 0.16145675035659224, 0.13998447364429012, 0.1593349501490593, 0.12050529388943687, 0.12625014031073079, 0.20716057915706187, 0.17903080733958632, 0.13491680729202926, 0.14783479302423075, 0.09281850259867497, 0.09643765995861031, 0.15154236985836178, 0.20577190211042762, 0.15013266034657136, 0.1909444446209818, 0.27097200974822044, 0.10145701249712147, 0.212066576059442, 0.09722792106913403, 0.12509452732047066, 0.142669148335699, 0.14532523549860343, 0.12721126608084887, 0.20810809393879026, 0.14851978048682213, 0.11964925623033196, 0.26325875020120293, 0.10934717778582126, 0.0980620356858708, 0.19448796228971332, 0.17403633159119636, 0.1693276865989901, 0.100083564320812, 0.12782609090209007, 0.18289070256287232, 0.06742537065292709], [0.037025977653684095, 0.04201225638098549, 0.014953401805541944, 0.009118397429119796, 0.06305565708316863, 0.025573407037882134, 0.0424729297083104, 0.03942068782635033, 0.07509726288844831, 0.027038896369049326, 0.014473899263975909, 0.06676033954136074, 0.08164648606907576, 0.03413769845792558, 0.044327987197902985, 0.0490984530915739, 0.08827985395328142, 0.029090888310747687, 0.031662750989198685, 0.10227364953607321, 0.07525642387918197, 0.0397249423986068, 0.04125735860725399, 0.028322743200988043, 0.049221957597183064, 0.02572420402429998, 0.061345667199930176, 0.04691842397733126, 0.0549202119873371, 0.019082642829744145, 0.011655016442091437, 0.06736220646416768, 0.05608811123238411, 0.045064579899189994, 0.016094644961412996, 0.007869871260481887, 0.04855922714341432, 0.08785041762166657, 2.3267999198287725, 25.956694073975086, 71.27058684825897, 94.41030398011208, 77.26169496774673, 61.91984340548515, 70.41363403201103, 49.616646990180016, 29.43580448627472, 37.711593210697174, 28.228974044322968, 24.977990090847015, 42.76456207036972, 103.29304933547974, 54.816409572958946, 19.349281825125217, 17.711317017674446, 21.21656622737646, 7.552348868921399, 0.3705593221820891, 0.5075081891845912, 0.04961200073012151, 0.05676391832821537, 0.06073593351175077, 0.0894604847417213, 0.0099288894853089, 0.04977351432899013, 0.21627275738865137, 0.14633454149588943, 0.001544832107356342, 0.09472816731431521, 0.029712680043303408, 0.06682797888061032, 0.15458330512046814, 0.06305383882136084, 0.008593063557782443, 0.14996391080785543, 0.16322530311299488, 0.021217853645794094, 0.06145286672108341, 0.17371024674503133, 0.0269512153317919, 0.09750218916451558, 0.10377563768997788, 0.06912915618158877, 0.033794625851442106, 0.1372655265731737, 0.02476272016792791, 0.44447714171838015, 0.9294452075846493, 1.4013513852842152, 0.35829025553539395, 0.10286569042364135, 0.03704967813973781, 0.04073107571457513, 0.49692694447003305, 0.3970983746694401, 0.2053122455254197, 0.014040731784916716, 0.10367784489062615, 0.053586554058711044, 0.05168238123587798, 0.03620451294409577, 0.7679476391058415, 1.107430625706911, 0.0632410826801788, 0.03635278291767463, 0.12218905627378263, 0.04292841171263717, 0.018354319508944172, 0.0496611791459145, 0.028041591685905587, 0.033470114358351566, 0.05178687933948822, 0.13542954227887094, 0.15259605628671125, 0.20300527947256342, 0.02882153508835472, 0.11576251752558164, 0.223503606102895, 1.5068338438868523, 8.227015491575003, 22.720485627651215, 37.63750858604908, 46.35863721370697, 62.53801703453064, 56.335742846131325, 60.252451077103615, 51.97576940059662, 28.09738900512457, 35.136577785015106, 31.88313916325569, 46.55806951224804, 56.40942469239235, 67.80774906277657, 74.7721217572689, 47.3575846105814, 5.5661541223526, 0.2898170391563326, 0.03234875148336869, 0.03157124046992976, 0.08318322157720104, 0.095575247250963, 0.050552880711620674, 0.02471594445523806, 0.02849541684554424, 0.058356841836939566, 0.08475470443954691, 0.09363957768073305, 0.05510036091436632, 0.047078241768758744, 0.06954205746296793, 0.05911822598136496, 0.038900587023817934, 0.0741867812757846, 0.06587756972294301, 0.04542886308627203, 0.07029708140180446, 0.018700251239351928, 0.0070553859859501245, 0.027532411586435046, 0.01121195242376416, 0.019983409729320556, 0.015796678235346917, 0.04892063079751097, 0.016290640596707817, 0.0011165864589202101, 0.04755690104502719, 0.017542599198350217, 0.1182158944720868, 0.04970275425876025, 0.02964822451758664, 0.07999880690476857, 0.04770800231199246, 0.03593659392208792, 0.02213081403169781, 0.08557778332033195, 0.04830718637094833, 0.0438588756514946, 0.045339345233514905, 0.0456066334299976, 0.03684115690703038, 0.01318641219768324, 0.007041866374493111, 0.02820592730131466, 0.004756720854857122, 0.036268166950321756, 0.03807255801802967, 0.04346134053776041, 0.059926068570348434, 0.012140009021095466, 0.017948058593901806, 0.059507630867301486, 0.07214692159323022, 0.03794763601035811, 0.04457980532606598, 0.02102270405885065, 0.1224837705376558, 0.03155899132252671, 0.021899545972701162, 0.04541453221463598, 0.03928793244995177, 0.04320311396440957, 0.02489205424353713, 0.04149208507442381, 0.04699199307651725, 0.05156272847671062, 0.12276846580789424, 0.056762318999972194, 0.03611727719544433, 0.04144828722928651, 0.018406492490612436, 0.009929047191690188, 0.03547531945514493, 0.08680848681251518, 0.07196425678557716, 6.75215408205986, 46.22906416654587, 93.23911562561989, 112.04934507608414, 96.28222793340683, 85.74529454112053, 99.7607284784317, 76.05163469910622, 44.47429932653904, 41.357128992676735, 20.644919201731682, 9.158327467739582, 33.57600152492523, 90.19843518733978, 54.68356490135193, 19.724445194005966, 15.722123757004738, 8.645414840430021, 2.572398791089654, 0.8071012131404132, 0.3357828757725656, 0.042611696480889805, 0.2190396620426327, 0.1081470210920088, 0.04249441859428771, 0.07546982102212496, 0.059289439450367354, 0.18088335637003183, 0.19290736585389823, 0.22477732447441667, 0.26548833993729204, 0.05072924839623738, 0.13909308006986976, 0.4719272843794897, 0.524761697743088, 0.2251266682287678, 0.31557345238979906, 0.49702956865075976, 0.4998872824944556, 0.40037204744294286, 0.29180804325733334, 0.06205503050296102, 0.5127333244308829, 0.4820718494011089, 0.6368692789692432, 0.09773800658877008, 0.5624674900900573, 0.8452334732282907, 2.372759166173637, 4.10865493118763, 4.8089877516031265, 1.80117626208812, 0.32078594143968076, 0.416543148458004, 0.38297874794807285, 1.5367930987849832, 0.5502649792470038, 0.3781078546307981, 0.1596716180210933, 0.07058298637275584, 0.09987614888814278, 0.06807356985518709, 0.13039773650234565, 1.014666915871203, 1.6409231862053275, 0.04114617746381555, 0.04266641131835058, 0.05181280255783349, 0.08309641256346367, 0.03301279924926348, 0.1991268602432683, 0.09599705430446193, 0.1120340937632136, 0.052699472362292, 0.015512226018472575, 0.08402671694057062, 0.4042125429259613, 0.07369575410848483, 0.0936914241174236, 0.3230258321855217, 0.20725260546896607, 5.436485605314374, 22.1338028088212, 43.36862325668335, 52.062796130776405, 51.63948364555836, 37.29137755930424, 38.008980453014374, 28.493730537593365, 23.456775918602943, 45.231689885258675, 54.1339547932148, 73.7509037554264, 78.55537354946136, 83.21938768029213, 88.6417119204998, 67.47267544269562, 13.91045792028308, 0.1117034447088372, 0.1835582940839231, 0.04525210948486347, 0.08590533019741997, 0.07176303086453117, 0.05242051018285565, 0.04655849719711114, 0.041739023581612855, 0.04275490871805232, 0.011354685047990642, 0.033502991500427015, 0.055643572195549496, 0.06572020472958684, 0.025000710229505785, 0.015412062984978547, 0.02763496340776328, 0.04072160219948273, 0.02265644012368284, 0.011019496832886944, 0.042956668985425495, 0.0687685763114132, 0.007712436690781033, 0.06792904401663691, 0.010717712684709113, 0.029551600600825623, 0.027602574227785226, 0.03952149745600764, 0.017742147865646984, 0.07123500021407381, 0.07850985086406581, 0.03664496645797044, 0.02870064665330574, 0.0355283533281181, 0.04419340613821987, 0.032796567102195695, 0.05491128395078704, 0.027252492036495823, 0.025486306731181685, 0.012838793936680304, 0.01839339172875043, 0.18495687138056383, 0.12246593672898598, 0.10491854511201382, 0.11777292878832668, 0.21373039693571627, 0.08798967421171255, 0.07569257664727047, 0.17061678227037191, 0.12469473236706108, 0.11774342841817997, 0.10318188986275345, 0.15115059009985998, 0.17558137915330008, 0.11696835164912045, 0.11297173798084259, 0.2681241516256705, 0.13436463457765058, 0.1324409877997823, 0.10073741126689129, 0.2509031194495037, 0.1708675836562179, 0.11997799796517938, 0.14395113423233852, 0.1441365375649184, 0.18150866031646729, 0.10780419339425862, 0.20669908204581589, 0.20023987395688891, 0.17113854177296162, 0.21870216296520084, 0.15375827439129353, 0.13523971574613824, 0.15616079937899485, 0.15368030435638502, 0.10034871884272434, 0.16088364907773212, 0.23455506074242294, 0.2645717281848192, 5.119404969736934, 42.80489690601826, 105.15465304255486, 123.70876863598824, 99.84585911035538, 81.7085887491703, 94.80327889323235, 63.54782424867153, 38.7111409753561, 54.93668831884861, 43.884597569704056, 35.504648834466934, 51.395559534430504, 122.55556091666222, 70.33500105142593, 29.948328584432602, 28.700726330280304, 31.00907016545534, 13.921341486275196, 1.7276940238662064, 0.7405533059500158, 0.15691194188548252, 0.5956213641911745, 0.3625864000059664, 0.2777300658635795, 0.20434248115634546, 0.26689497695770115, 0.5277500592637807, 0.36633463168982416, 0.3978241950972006, 0.42749695130623877, 0.31106407404877245, 0.1991160397301428, 0.40183897654060274, 0.3102767444215715, 0.21886786969844252, 0.30792829231359065, 0.3930064692394808, 0.3433845459949225, 0.3733187756733969, 0.37083106697537005, 0.17436735914088786, 0.3069823211990297, 0.32522060035262257, 0.26687479054089636, 0.11781098612118512, 0.1715713771409355, 0.278219289612025, 0.9681169199757278, 1.8816167581826448, 2.2562937531620264, 0.6910622678697109, 0.2413947827881202, 0.1283850468462333, 0.16784085310064256, 1.199662007857114, 0.5202982435002923, 0.2452485478715971, 0.1748512839549221, 0.2924140216782689, 0.29736076248809695, 0.17725867743138224, 0.20041190378833562, 0.7996065902989358, 1.9218660984188318, 0.21976669959258288, 0.1011371542699635, 0.23501903662690893, 0.19474904984235764, 0.205460422730539, 0.2469227439723909, 0.18124188791261986, 0.1859074883395806, 0.20654649648349732, 0.17512274673208594, 0.4848507174756378, 0.9760488756000996, 0.13221923407400027, 0.3791373618878424, 0.9702472994104028, 2.6112146582454443, 14.146954379975796, 35.827908888459206, 61.09586521983147, 69.16516542434692, 91.5446649491787, 76.62784337997437, 79.51228380203247, 70.4435308277607, 42.35514163970947, 44.62556540966034, 41.997387036681175, 61.28610581159592, 75.16407072544098, 85.98073750734329, 102.89895728230476, 72.70348235964775, 9.96685853227973, 0.28199815715197474, 0.1982623917865567, 0.15089840831933543, 0.19463480362901464, 0.13439654692774639, 0.10823414922924712, 0.13545625959523022, 0.21840656554559246, 0.17893127049319446, 0.23630982439499348, 0.150661158550065, 0.11583892162889242, 0.10370707808760926, 0.17576074140379205, 0.13867835310520604, 0.09226919457432814, 0.2329983317758888, 0.16000598523532972, 0.17776283319108188, 0.11324917504680343, 0.16401543805841357, 0.17967168154427782, 0.1079398654110264, 0.14487438078504056, 0.10113080148585141, 0.07300532670342363, 0.1098776723665651, 0.12043038892443292, 0.12581481132656336, 0.18434715253533795, 0.12139959668274969, 0.21133302245289087, 0.10000263311667368, 0.12262648553587496, 0.17374987743096426, 0.16072891128715128, 0.1803376997122541, 0.1032422116259113, 0.14540889038471505, 0.14485174528090283], [0.032898334102355875, 0.06261107351747341, 0.0156085604976397, 0.029343893875193316, 0.03786650071560871, 0.044392605996108614, 0.0545928135397844, 0.0737528623722028, 0.04486747660848778, 0.03536437208822463, 0.029726806824328378, 0.04062175365106668, 0.027753452850447502, 0.03721649438375607, 0.02163575143640628, 0.027866322379850317, 0.048138132551684976, 0.024527038185624406, 0.010220486728940159, 0.04786565674294252, 0.013580786689999513, 0.03237916469515767, 0.010640857726684771, 0.050487961343606, 0.01082534543456859, 0.03872627508826554, 0.08028700511204079, 0.05126110110722948, 0.046498776573571377, 0.06617692983127199, 0.0355661323555978, 0.09937039751093835, 0.02335671026230557, 0.06798543239710853, 0.07858351644244976, 0.10219279996817932, 0.29123451153282076, 11.565881129354239, 60.303926914930344, 84.84775990247726, 76.89916402101517, 63.430912122130394, 52.03468143939972, 53.361019268631935, 39.74114030599594, 24.402689561247826, 39.34000723063946, 36.00590653717518, 63.863720297813416, 87.41335943341255, 48.01861993968487, 17.35858954489231, 18.300646394491196, 18.895242288708687, 6.649042339995503, 0.5302830983418971, 0.5106654635164887, 0.04722755074908491, 0.45248307462316006, 0.08699604979483411, 0.05123504059156403, 0.024124929586832877, 0.19327986461576074, 0.04864897135121282, 0.07167787684011273, 0.03517233766615391, 0.02642957457283046, 0.1679232611786574, 0.03361746777954977, 0.07613813242642209, 0.020232765782566275, 0.12450308015104383, 0.07354219633270986, 0.014295801447588019, 0.1380083421827294, 0.09118235640926287, 0.05225514483754523, 0.2959038078552112, 0.1690520826377906, 0.42328027600888163, 0.49036799173336476, 2.9242648975923657, 8.703467175364494, 3.2221482507884502, 6.663034614175558, 11.824633944779634, 19.736044071614742, 15.705250762403011, 14.669834822416306, 3.1061428505927324, 0.04251368474797346, 0.6443782697897404, 0.45543109299615026, 0.7755788171198219, 0.5390519590582699, 0.6939350324682891, 1.749079276341945, 1.4872330706566572, 0.10381401414633729, 0.06276718428125605, 0.4912520380457863, 2.4199165357276797, 0.5569940025452524, 0.2564504655310884, 0.11747682670829818, 0.049505020142532885, 0.20902601187117398, 0.12376918515656143, 0.04848478602070827, 0.07866187239415012, 0.02118828648235649, 0.1729047641856596, 0.14269230334321037, 0.14681463682791218, 0.1084246214304585, 0.07884021048084833, 0.12286805460462347, 0.043695399072021246, 0.018690838951442856, 0.1219769059389364, 0.17699039104627445, 6.469973148778081, 23.48051894456148, 40.595326870679855, 46.721791326999664, 50.83938717842102, 67.68180102109909, 52.19712272286415, 28.988929465413094, 28.07244524359703, 36.88529334962368, 34.929519295692444, 46.906750202178955, 56.18269845843315, 72.17628344893456, 67.07115098834038, 19.025928676128387, 0.34827215247787535, 0.23104017513105646, 0.038559907843591645, 0.05935970228165388, 0.0706788495881483, 0.054489988979185, 0.023543072820757516, 0.04450358675967436, 0.02132972684194101, 0.07553414296125993, 0.016923866969591472, 0.020524604224192444, 0.08059619867708534, 0.04004961345344782, 0.0383724598941626, 0.026243661013722885, 0.02497125809895806, 0.041883170924847946, 0.011449470293882769, 0.034445930941728875, 0.06091179282520898, 0.0350059963966487, 0.028551437862915918, 0.02028173639700981, 0.037733789868070744, 0.01499068823250127, 0.05158372012374457, 0.09136504348134622, 0.017437204951420426, 0.05567575542954728, 0.0474194367416203, 0.03427562660363037, 0.0178197171408101, 0.08675716730067506, 0.023196172587631736, 0.04372665462142322, 0.00817343841845286, 0.013965828675281955, 0.038029981005820446, 0.04560906396363862, 0.029059452790534124, 0.05362832955142949, 0.06002056623401586, 0.04159063857514411, 0.031246699290932156, 0.019950105852331035, 0.03885394304234069, 0.06462227887823246, 0.023114909272408113, 0.07195831960416399, 0.0468039922270691, 0.03771278337808326, 0.01970659792277729, 0.054280562326312065, 0.031848061553318985, 0.11291281145531684, 0.004431033057699096, 0.03909342296537943, 0.014989670562499668, 0.0689654829329811, 0.016917339780775364, 0.026593646725814324, 0.06497419788502157, 0.03370854785316624, 0.0603054173552664, 0.056301935110241175, 0.04487948084715754, 0.018066405173158273, 0.11074507230659947, 0.047148567682597786, 0.08700367165147327, 0.057576076505938545, 0.05819720958243124, 0.1129826030228287, 0.07206553025753237, 0.7269335305318236, 26.853531450033188, 81.80215492844582, 99.35207560658455, 94.52502742409706, 85.42691722512245, 80.90291798114777, 76.50489717721939, 63.833405524492264, 31.87998153269291, 28.005363643169403, 18.278985656797886, 32.44539499282837, 60.71151964366436, 46.5233089774847, 24.787519611418247, 13.624177481979132, 10.405236259102821, 2.1305264392867684, 0.6794574530795217, 0.36252646415960044, 0.13184051611460745, 0.4740974132437259, 0.11227264971239492, 0.06284190370934084, 0.020842839003307745, 0.08056034552282654, 0.1842167423455976, 0.12307125463848934, 0.09703272880869918, 0.04927129928546492, 0.04523568946751766, 0.09683772208518349, 0.5505650443956256, 0.17493655672296882, 0.21463841461809352, 0.3942152496892959, 0.9423703921493143, 0.48598011780995876, 0.8726207411382347, 0.8013078302610666, 2.1988080628216267, 0.9225236414931715, 1.8870887020602822, 2.1642885776236653, 10.879576206207275, 18.63571811467409, 10.741500165313482, 11.151652056723833, 21.62755597382784, 32.76440687477589, 27.457309551537037, 21.47112976759672, 6.646868856623769, 1.6695115459151566, 5.266562048345804, 3.642347753047943, 0.7750009512528777, 1.5732952463440597, 1.6565661155618727, 0.30581453698687255, 0.518484078347683, 0.22826984175480902, 0.26025156781543046, 0.18523847189499065, 2.430591587908566, 0.6883632251992822, 0.26020338758826256, 0.08994446150609292, 0.13063844467978925, 0.15960098040523008, 0.06458670774009079, 0.029144475083739962, 0.08768540108576417, 0.023500189672631677, 0.22528743225848302, 0.0386705546407029, 0.082337039639242, 0.10881410795263946, 0.06012420715705957, 0.1610978032113053, 0.0772237683122512, 0.05547356471652165, 0.23953837458975613, 0.32312530966009945, 3.690871624276042, 21.36960681527853, 44.86942112445831, 48.48948687314987, 47.541441544890404, 49.91003304719925, 36.83915242552757, 21.890821047127247, 32.80786134302616, 50.62991961836815, 59.23907205462456, 74.4665801525116, 74.63624864816666, 82.69772127270699, 85.4201839864254, 35.28182499110699, 1.550146413501352, 0.2528665156569332, 0.07395394728519022, 0.07240639126393944, 0.04196777575998567, 0.05778759230452124, 0.06898451159941033, 0.01823750360927079, 0.0304660081746988, 0.0368949774565408, 0.032889647263800725, 0.07006081126746722, 0.05566064530285075, 0.0389087617804762, 0.01088063079805579, 0.04844930022954941, 0.10005823482060805, 0.03550915025698487, 0.0843017568695359, 0.03811283808317967, 0.06452148038079031, 0.06191860149556305, 0.04486135389015544, 0.04472490632906556, 0.01633221942029195, 0.02656392000062624, 0.009888286585919559, 0.1274028143961914, 0.023499935487052426, 0.016025372897274792, 0.09753243168233894, 0.016012784217309672, 0.023070176321198232, 0.02104168634105008, 0.060643992546829395, 0.030251026546466164, 0.0002933883126843284, 0.027283320850983728, 0.029706379209528677, 0.13373933063121513, 0.11323927479679696, 0.14075650018639863, 0.14786821935558692, 0.12779521755874157, 0.13746859302045777, 0.14229608554160222, 0.09285765088861808, 0.16023351287003607, 0.1625577561208047, 0.0947438192088157, 0.13653372443513945, 0.17003229644615203, 0.11354412679793313, 0.15105412574484944, 0.12678126571699977, 0.19325240515172482, 0.14059953595278785, 0.11791514654760249, 0.17406910483259708, 0.16395260783610865, 0.13405518868239596, 0.1390305912354961, 0.1596178865293041, 0.08745996630750597, 0.14611309947213158, 0.14918383938493207, 0.13765806332230568, 0.1495332276681438, 0.22580938471946865, 0.07666382531169802, 0.2225027309032157, 0.13740319496719167, 0.17689836473437026, 0.29859257920179516, 0.17250219359993935, 0.632538580102846, 27.284842506051064, 91.39003604650497, 115.07842853665352, 100.1829694211483, 82.89682298898697, 73.18642124533653, 69.32637557387352, 52.99368917942047, 33.52938562631607, 58.01402159035206, 52.76679575443268, 88.02778646349907, 124.21571463346481, 71.09475508332253, 34.87175479531288, 29.541628807783127, 26.386893689632416, 10.764370188117027, 1.7442591162398458, 1.204423033632338, 0.29581522510852665, 0.8927230280824006, 0.3274020692333579, 0.2359575714217499, 0.18358291854383424, 0.5476691841613501, 0.28188900207169354, 0.24831740272929892, 0.38472971180453897, 0.15315792144974694, 0.2528844162588939, 0.23976024705916643, 0.34148144186474383, 0.22505813831230626, 0.2888056996744126, 0.16858313436387107, 0.3170906100422144, 0.3521317953709513, 0.26704794843681157, 0.1901119330432266, 0.8063328231219202, 0.4868841130519286, 1.3385635544545949, 2.6275746803730726, 9.37989167869091, 16.011875309050083, 12.209408897906542, 14.293788000941277, 20.860529132187366, 39.384442046284676, 31.33804891258478, 29.393381662666798, 6.544692339375615, 1.0798011207953095, 4.134381925687194, 3.9065703749656677, 1.4597666007466614, 1.754414546303451, 2.9762268718332052, 4.815783686935902, 4.126081271097064, 0.6383884255774319, 0.4866691573988646, 0.7789243594743311, 3.464136365801096, 1.5602167043834925, 0.8612833963707089, 0.7180953829083592, 0.39164744841400534, 0.7552938431035727, 0.3615626221289858, 0.14857226517051458, 0.21041744970716536, 0.2509813121287152, 0.39748987241182476, 0.24716076557524502, 0.3116180427605286, 0.2894391375593841, 0.39970598474610597, 0.46367742237634957, 0.15715398592874408, 0.12429288908606395, 0.4321579949464649, 0.6751218857243657, 10.11185685172677, 38.15004028379917, 61.0489035397768, 66.21086955070496, 73.06876435875893, 91.40869304537773, 70.42163640260696, 42.277880385518074, 37.27341212332249, 45.211341977119446, 47.40448549389839, 64.58923816680908, 72.04822272062302, 91.41967445611954, 96.9131688773632, 33.58123764395714, 0.7959179976023734, 0.4988695902284235, 0.16480520192999393, 0.20106667099753395, 0.18228748493129387, 0.225687182683032, 0.21566214796621352, 0.11983684147708118, 0.11942729470320046, 0.17713696521241218, 0.10865963733522221, 0.3498736477922648, 0.2037276266491972, 0.16658407053910196, 0.12862410745583475, 0.10127482266398147, 0.1511846695211716, 0.12258004935574718, 0.16064375726273283, 0.12044994451571256, 0.14996135781984776, 0.1580364885739982, 0.1003947616845835, 0.11379365168977529, 0.13100410084007308, 0.16314899548888206, 0.10419601239846088, 0.2388102386612445, 0.12147194123826921, 0.19994518195744604, 0.2005601255223155, 0.12643615220440552, 0.15475861524464563, 0.1815269616781734, 0.1422586664557457, 0.12864056829130277, 0.11831071868073195, 0.18496056727599353, 0.09020809462526813], [0.03236831820686348, 0.10466336505487561, 0.058285176346544176, 0.005361506737244781, 0.06857946966192685, 0.05444666981929913, 0.026714329214883037, 0.09803925175219774, 0.03743006964214146, 0.04507538928010035, 0.08280425128759816, 0.01843710422690492, 0.0313949284463888, 0.04971133348590229, 0.005488658434842364, 0.028308959663263522, 0.09950054794899188, 0.03255734693084378, 0.055809371697250754, 0.01832132547860965, 0.06436262367060408, 0.0337352688802639, 0.07354844521614723, 0.03331502033688594, 0.02990299639350269, 0.039778781501809135, 0.01304357474509743, 0.023889021249487996, 0.0324859226384433, 0.03910090381396003, 0.019370854024600703, 0.06550874459207989, 0.0629078435304109, 0.025737601645232644, 0.09922235389240086, 2.9941968200728297, 37.46474705636501, 81.07601389288902, 86.50318667292595, 75.21992772817612, 70.53661823272705, 69.92606699466705, 47.64371305704117, 30.840919688344, 31.654931008815765, 51.91331975162029, 59.684259966015816, 61.686839908361435, 60.72249345481396, 32.00050346553326, 20.32737024128437, 15.674050636589527, 8.466302901506424, 1.1261612456291914, 0.12005233147647232, 0.035675409890245646, 0.6331656652037054, 0.10528628670726903, 0.1530723221367225, 0.019833879960060585, 0.09077313618035987, 0.11102627948275767, 0.029663839304703288, 0.1853716725599952, 0.04579721324262209, 0.0465784238622291, 0.19878336461260915, 0.23939126607729122, 0.1666685417876579, 0.4924301232676953, 0.3415523318108171, 0.4206788999726996, 1.4757043705321848, 0.7204776769503951, 0.433453309815377, 0.4353749082656577, 1.6304085566662252, 3.6206207564100623, 1.8361368798650801, 2.2621414018794894, 3.0293758073821664, 4.253797642886639, 15.319721549749374, 16.613331735134125, 11.991401296108961, 20.97818221896887, 15.492189545184374, 13.273075371980667, 9.897512253373861, 6.374200712889433, 2.754430160857737, 4.959893329069018, 6.944786170497537, 1.7050066287629306, 0.8302260597702116, 1.1639981903135777, 0.5677475442644209, 0.4436880012508482, 0.20339314069133252, 0.1359838672215119, 0.09636918199248612, 0.12636486149858683, 0.17683194251731038, 0.06540867339936085, 0.06824333613622002, 0.07416425709379837, 0.04949368383677211, 0.028485895090852864, 0.2002727214130573, 0.15001290739746764, 0.5990728258620948, 1.2102533457800746, 0.3166666952893138, 0.6824471801519394, 0.11994460131973028, 0.03794225172896404, 0.036151007807347924, 0.09828422727878205, 0.11730442580301315, 0.0365752602374414, 0.08522891454049386, 0.24503071268554777, 0.13152198633179069, 8.087381534278393, 41.39450378715992, 52.55653403699398, 57.83747546374798, 55.36921910941601, 54.3016017973423, 48.79128947854042, 32.207926735281944, 22.805475667119026, 31.265833787620068, 43.25897254049778, 50.31395137310028, 65.398488342762, 71.40449166297913, 42.471886575222015, 3.1258526304736733, 0.268483113613911, 0.003347413030496682, 0.05282757818349637, 0.02934405714768218, 0.035723352630157024, 0.04708553708042018, 0.011423785490478622, 0.015874711352807935, 0.10167937478399836, 0.09737827276694588, 0.007508866510761436, 0.08598806482041255, 0.05763315508374944, 0.06337606449960731, 0.0733784562908113, 0.03312164262752049, 0.07272482456755824, 0.04204879231110681, 0.0022284904298430774, 0.09574418232659809, 0.021990663153701462, 0.014909862784406869, 0.04842436406761408, 0.0058433108642930165, 0.05329170620825607, 0.020171725991531275, 0.031749552581459284, 0.027673159893311094, 0.05716022518754471, 0.03239806719648186, 0.13931293389759958, 0.05416707310359925, 0.013399495783232851, 0.023903648980194703, 0.03591343149309978, 0.038305443958961405, 0.1294412714196369, 0.06674122181721032, 0.06822140567237511, 0.011532095450093038, 0.06259842732106335, 0.01758839156536851, 0.0546388044313062, 0.01353339406705345, 0.08515400957548991, 0.04128614651563112, 0.018696297447604593, 0.06013264166540466, 0.04025936665129848, 0.04388057976029813, 0.07781916370731778, 0.03903697521309368, 0.04713538713986054, 0.08682316649355926, 0.04203662851068657, 0.0649220249033533, 0.07558264973340556, 0.052550259861163795, 0.006374059630616102, 0.05075208799098618, 0.031659229498472996, 0.02881771302781999, 0.03415814833715558, 0.03609432256780565, 0.09920224169036373, 0.00989491489235661, 0.1046463476086501, 0.08327174495207146, 0.05558065662626177, 0.04975335759809241, 0.01184746832223027, 0.06480083960923366, 7.120225606486201, 60.83963356912136, 100.17240598797798, 95.8389513194561, 104.40540924668312, 104.19582769274712, 100.64703851938248, 71.70979768037796, 37.55979135632515, 22.422847598791122, 25.50804454833269, 31.677722185850143, 40.56687019765377, 53.71894106268883, 36.06191173195839, 21.05701468884945, 10.234259683638811, 3.2962262257933617, 0.7251372956670821, 0.02811561349517433, 0.1499888172838837, 0.5184121197089553, 0.24154885264579207, 0.038222876319196075, 0.042475605150684714, 0.031466389846173115, 0.31396233884152025, 0.25963623833376914, 0.4040364164393395, 0.42071953997947276, 0.2064238046295941, 0.8982268546242267, 1.042942504864186, 2.0191107178106904, 2.567503941245377, 2.620850703679025, 2.154229092411697, 3.9027394680306315, 5.280617969110608, 3.8347174180671573, 3.9732586964964867, 7.4863863084465265, 7.869887854903936, 8.783268593251705, 8.146835993975401, 6.764348577708006, 9.116480313241482, 22.07614090293646, 22.41786416620016, 14.526281375437975, 30.072739608585835, 17.324307784438133, 15.482113435864449, 12.581176199018955, 12.047864366322756, 4.686032049357891, 5.904065240174532, 0.5473622912541032, 1.2268328061327338, 1.027341966982931, 0.565112920012325, 1.2083124811761081, 0.9093162033241242, 1.5235058055259287, 1.6958967363461852, 0.948510862654075, 1.3748139655217528, 0.6079918378964067, 0.12217221694299951, 0.10233190070721321, 0.028298530633037444, 0.04594530510075856, 0.045767709161737, 0.33326266100630164, 0.1063197644543834, 1.067793765105307, 1.3779650651849806, 0.22826731845270842, 0.7732326211407781, 0.04479513947444502, 0.045560642538475804, 0.03301674747490324, 0.2073212541290559, 0.028050530854670797, 0.29050177428871393, 0.010249743118038168, 0.19041754945646971, 0.2429719059728086, 5.3551538195461035, 43.94013538956642, 52.28133760392666, 56.76429145038128, 43.45040626823902, 33.00801560282707, 24.374869354069233, 20.30705653131008, 27.374010421335697, 48.53834465146065, 69.80710297822952, 79.29185003042221, 86.0368224978447, 86.41680970788002, 65.32679378986359, 10.125583615154028, 0.1631120513775386, 0.03896153219102416, 0.024653578075231053, 0.038704329781467095, 0.06143180085928179, 0.15722129872301593, 0.0558237470977474, 0.03263358405092731, 0.11690348052070476, 0.08537530316971242, 0.049390009517082945, 0.03909552324330434, 0.0597196735907346, 0.04978908458724618, 0.024940002549556084, 0.055418256160919555, 0.010025237879744964, 0.03198237172910012, 0.015825445734662935, 0.02188728569308296, 0.03321508273074869, 0.04165153550275136, 0.0426732464984525, 0.05090409096737858, 0.0037726295568063506, 0.07777816004818305, 0.021662541112164035, 0.021477217560459394, 0.018478200654499233, 0.023672069219173864, 0.03990558485384099, 0.08031874676817097, 0.08728678614716046, 0.07274335599504411, 0.03391674625163432, 0.04059422739373986, 0.04851302845054306, 0.214285968686454, 0.2019722544355318, 0.0856961113458965, 0.2187197667080909, 0.17330528644379228, 0.21264338807668537, 0.08526803314452991, 0.1871345256222412, 0.2021986391628161, 0.10486159269930795, 0.13906857435358688, 0.08436508433078416, 0.19717713439604267, 0.15394614165415987, 0.13992608146509156, 0.09970536586479284, 0.22876614559208974, 0.0992111919913441, 0.10318407919839956, 0.16535819100681692, 0.13419367343885824, 0.1263672363711521, 0.1356404458056204, 0.16309165715938434, 0.1348972591222264, 0.19070474576437846, 0.11869406022015028, 0.16883559816051275, 0.20152948913164437, 0.12001112001598813, 0.14587423182092607, 0.21254232240607962, 0.18021577969193459, 0.18688918644329533, 0.3301226341864094, 6.455399505794048, 66.96908086538315, 114.25331801176071, 110.58384731411934, 99.85071524977684, 94.54917132854462, 93.12259867787361, 62.463708221912384, 43.07011127471924, 47.52364329993725, 74.53839629888535, 82.0785216987133, 87.03967988491058, 90.30826449394226, 53.71182024478912, 33.198309391736984, 22.912648916244507, 13.954566903412342, 2.594684357754886, 0.22783215274102986, 0.2438809775048867, 1.6484159091487527, 0.38834726612549275, 0.3087471780600026, 0.13806204398861155, 0.2766809955937788, 0.2916191815165803, 0.2222820310271345, 0.3385428339242935, 0.2763823850546032, 0.22378747758921236, 0.8009355096146464, 0.7377552310936153, 1.176142101176083, 1.2252456787973642, 1.1638034507632256, 1.0078420070931315, 3.1363360304385424, 2.4119623750448227, 1.3963177241384983, 1.5078609762713313, 5.87111578322947, 8.849450591951609, 7.113912245258689, 7.622093176469207, 8.65725215524435, 16.18859812617302, 25.15728536993265, 34.75087568163872, 26.272061951458454, 43.061926513910294, 30.690516158938408, 25.2590724080801, 21.54240634292364, 15.765050053596497, 6.034554038196802, 9.527485258877277, 17.208957374095917, 3.7780705327168107, 3.2564428355544806, 3.5212902864441276, 4.57642313092947, 1.3961677509360015, 1.1729180929251015, 1.300402795895934, 0.5724998423829675, 0.7970605487935245, 0.5028252373449504, 0.2856954181334004, 0.20047595113283023, 0.08726879648747854, 0.08917796396417543, 0.13750755577348173, 0.632703989977017, 0.5061222135554999, 2.188376197591424, 1.9763444876298308, 0.5221092619467527, 1.2144553265534341, 0.39719850523397326, 0.20242589962435886, 0.3510907699819654, 0.49945992417633533, 0.46900262881536037, 0.5925727996509522, 0.17016787198372185, 0.38027825066819787, 0.6007586885243654, 14.203995019197464, 62.59782962501049, 74.04804781079292, 78.00751134753227, 77.79122695326805, 73.65101471543312, 61.491017416119576, 44.25961844623089, 32.585140094161034, 40.89776784181595, 59.24143172800541, 69.31984752416611, 82.93791398406029, 96.98910400271416, 69.81328144669533, 8.772922698408365, 0.5341244547162205, 0.11630175460595638, 0.16519425058504567, 0.1259889340144582, 0.21542298345593736, 0.23511245817644522, 0.23514110507676378, 0.1156845771765802, 0.27215371665079147, 0.23161410761531442, 0.13289864058606327, 0.17064955551177263, 0.31506989034824073, 0.12305241893045604, 0.1502417412120849, 0.18759894679533318, 0.15903408348094672, 0.13488201540894806, 0.16384974616812542, 0.14880629401886836, 0.17828846670454368, 0.10782966390252113, 0.19024013163289055, 0.09994743959396146, 0.09764731614268385, 0.12833820248488337, 0.058302653924329206, 0.24363685544813052, 0.16461105609778315, 0.13948558713309467, 0.29118443140760064, 0.14934219885617495, 0.13871418399503455, 0.17105960694607347, 0.13107738050166517, 0.16501864360179752, 0.2211411570897326], [0.08455106653855182, 0.03579341879230924, 0.018484861429897137, 0.02471923959092237, 0.07349294741288759, 0.033576746136532165, 0.018281717057107016, 0.04879489613813348, 0.026411872495373245, 0.017700593161862344, 0.007412380355162895, 0.010126489087269874, 0.04364157110103406, 0.007196238657343201, 0.11106359466793947, 0.07687993871513754, 0.0637420843122527, 0.04075020828167908, 0.10909593111136928, 0.027125903907290194, 0.0625891430536285, 0.1068085058068391, 0.050575304703670554, 0.10455566458404064, 0.08429116642219014, 0.15220341563690454, 0.07200761305284686, 0.04649096175853629, 0.08722299855435267, 0.007450688626704505, 0.07374501044978388, 0.03551744746800978, 0.03559272350685205, 0.17665574181592092, 11.13897593691945, 68.07979166507721, 89.63280513882637, 79.8535966873169, 67.2963573038578, 58.91523063182831, 41.76261283457279, 26.341263838112354, 32.13412709534168, 35.47319032251835, 64.49387848377228, 59.34154495596886, 57.05855906009674, 50.8804439753294, 35.832187458872795, 15.439580418169498, 4.007164277136326, 0.7438030815683305, 0.22411195939639583, 0.16539074160391465, 0.13807531358907, 0.15986561542376876, 0.14320603280793875, 0.050187139204354025, 0.04659351543523371, 0.025874392449622974, 0.1894509614794515, 0.02641374827362597, 0.09819919199799187, 0.09446718366234563, 0.21788379672216251, 0.102084156969795, 0.12368339288514107, 0.16890956059796736, 0.836850410560146, 1.3291635713540018, 0.985816310858354, 0.8319026010576636, 4.386725435033441, 4.419640218839049, 2.3568325582891703, 6.425307970494032, 4.798339772969484, 11.541513986885548, 10.802069865167141, 7.46966578066349, 4.96752854436636, 8.963288683444262, 8.297562506049871, 14.609070383012295, 13.397462647408247, 12.25561061874032, 13.69247691705823, 14.701394978910685, 5.703008528798819, 7.103726891800761, 4.99074624851346, 4.605087842792273, 3.342831674963236, 1.3776949234306812, 1.5893622091971338, 4.484419617801905, 12.699341308325529, 23.677886053919792, 31.018744446337223, 34.79005917906761, 34.35843273997307, 31.812052577733994, 27.177217081189156, 21.363263055682182, 14.332601968199015, 8.551372736692429, 3.350958963856101, 0.8061422395985574, 0.06379766375175677, 0.18162096210289747, 0.042327891787863337, 0.027959339458902832, 0.16475794196594507, 0.029631405595864635, 0.12652458652155474, 0.01477182331655058, 0.053293279561330564, 0.02130561631929595, 0.027049830059695523, 0.05569338514760602, 0.12352236168226227, 0.2957408025395125, 0.10926566028501838, 0.3826439206022769, 1.5029462962411344, 12.235256060957909, 40.382610484957695, 50.06465055048466, 36.79626792669296, 64.65693533420563, 63.26798066496849, 45.386333987116814, 30.521890707314014, 27.23076570779085, 26.166148334741592, 35.7077669352293, 57.58910559117794, 76.40589728951454, 56.28048621118069, 9.310056176036596, 0.19080070545896888, 0.054170717048691586, 0.038562995177926496, 0.025968186928366777, 0.038874849342391826, 0.059217647794866934, 0.05071980456705205, 0.062012728085392155, 0.01923720436025178, 0.09654479639721103, 0.01870231997600058, 0.06855874889879487, 0.04471142892725766, 0.04272664402378723, 0.025312239704362582, 0.007579146040370688, 0.023006704141153023, 0.023025513874017633, 0.03595954112824984, 0.10927487775916234, 0.017738442693371326, 0.07410286663798615, 0.06543314200825989, 0.07335049958783202, 0.048298458714270964, 0.020074137282790616, 0.06648758542723954, 0.013667702387465397, 0.04713888636615593, 0.034534673250163905, 0.039610499516129494, 0.012302066243137233, 0.027205501100979745, 0.024617212839075364, 0.040784517768770456, 0.018270172949996777, 0.0742736719257664, 0.05657865229295567, 0.05843509017722681, 0.023258522269316018, 0.011660191066766856, 0.04002372734248638, 0.06494749541161582, 0.02869967258448014, 0.019132160778099205, 0.029604333903989755, 0.03418792701268103, 0.01579548894369509, 0.030699545350216795, 0.02471545092703309, 0.0650808890350163, 0.060632541208178736, 0.03026536483957898, 0.015055742114782333, 0.07635334783117287, 0.03214510245015845, 0.034996582253370434, 0.07522305691963993, 0.052675838669529185, 0.13308818510267884, 0.06607939678360708, 0.019351871742401272, 0.031775420138728805, 0.12912530946778134, 0.1020644826348871, 0.13235029735369608, 0.05984816532873083, 0.07789613926433958, 0.06080383260268718, 0.35456007288303226, 21.042767353355885, 91.6929329931736, 102.57963761687279, 94.76142033934593, 94.53202664852142, 84.6203725039959, 66.4078813791275, 36.644720658659935, 24.359168596565723, 15.260401032865047, 43.845828250050545, 47.41725280880928, 47.01850600540638, 54.33700829744339, 42.654778361320496, 13.512441627681255, 1.5034884796477854, 0.3896020003594458, 0.10192512214416638, 0.039164735935628414, 0.087252669618465, 0.28349610802251846, 0.12456436670618132, 0.0363954601198202, 0.10646050533978269, 0.20959425950422883, 0.31662219611462206, 0.385479221586138, 0.8001611230429262, 0.30237530590966344, 0.896526089636609, 1.0222978563979268, 2.0939484145492315, 2.0547528052702546, 2.6132663106545806, 3.252790281549096, 3.2952755643054843, 3.2376730302348733, 6.010250067338347, 6.417710278183222, 5.035111242905259, 9.997917115688324, 9.726467281579971, 9.889397788792849, 14.692295417189598, 13.135783039033413, 11.620561145246029, 12.145050801336765, 12.57499773055315, 18.538950607180595, 15.180455222725868, 12.810605987906456, 18.479367904365063, 17.77964875102043, 12.750156931579113, 10.164769012480974, 5.203611776232719, 2.333999346010387, 1.980887500103563, 0.7666253694333136, 2.6977711636573076, 7.934577958658338, 18.29763885587454, 30.429966039955616, 39.25026744604111, 44.43398728966713, 44.64223511517048, 44.69495348632336, 41.29671983420849, 34.00282122194767, 25.07611222565174, 17.12747074663639, 9.904340486973524, 4.1503572184592485, 0.7389493170194328, 0.384753608959727, 0.026977578272635583, 0.15874529897700995, 0.16292688553221524, 0.08241061615990475, 0.11113091488368809, 0.1322570093907416, 0.10603505434119143, 0.04200416326057166, 0.059882333807763644, 0.03620644623879343, 0.014056769596209051, 0.09021023943205364, 0.2193310292204842, 0.6351692858152092, 0.011301846916467184, 10.08246447890997, 40.91250345110893, 52.03421026468277, 29.156418778002262, 55.26892729103565, 50.32221592962742, 23.659192956984043, 18.134542107582092, 26.565075628459454, 47.35922992229462, 68.94822746515274, 78.87027785181999, 91.55809342861176, 75.69615617394447, 20.464662574231625, 0.05730509612476453, 0.09443475923035294, 0.07238121761474758, 0.02883616281906143, 0.12871252693003044, 0.04660397600673605, 0.10279149049893022, 0.051142264710506424, 0.05276479249005206, 0.01620177397853695, 0.056160760068451054, 0.07981401955476031, 0.02165605288610095, 0.06287091426202096, 0.05262787737592589, 0.03289504267740995, 0.022471387455880176, 0.07112666149623692, 0.0614470037544379, 0.13154022832168266, 0.03811244103417266, 0.09781894521438517, 0.07202790337032638, 0.01819704171794001, 0.03251086251111701, 0.08651070005726069, 0.058579745891620405, 0.026782460226968396, 0.023197803457151167, 0.04931983203277923, 0.038279865839285776, 0.03285783881437965, 0.06918929240782745, 0.05702895039576106, 0.05561954516451806, 0.01067084884198266, 0.16704720037523657, 0.13038087490713224, 0.16955767816398293, 0.0880882165802177, 0.2021956112002954, 0.08891105055226944, 0.13040275342063978, 0.18918224464869127, 0.08628947325632907, 0.12361694098217413, 0.09214658435666934, 0.11018551522283815, 0.13344239734578878, 0.14108939794823527, 0.2220862079411745, 0.1438863595831208, 0.14928382151992992, 0.1352410070830956, 0.21789886231999844, 0.13458981702569872, 0.1817531682900153, 0.11103814642410725, 0.14328769873827696, 0.32012554875109345, 0.14526832761475816, 0.292165283462964, 0.20384588045999408, 0.3240460477536544, 0.17458464513765648, 0.1848241308471188, 0.14223484351532534, 0.13643589452840388, 0.1553480140864849, 0.31896278145723045, 22.376674376428127, 101.15672037005424, 117.87018433213234, 99.0249815583229, 92.49304085969925, 79.35999557375908, 57.43706434965134, 35.978540405631065, 48.30237731337547, 55.71703724563122, 96.28489539027214, 89.65423598885536, 80.53868472576141, 73.51296812295914, 54.5611696690321, 27.078458480536938, 6.933979075402021, 1.567490582820028, 0.21175813948502764, 0.20855376846157014, 0.45927084633149207, 0.48008915735408664, 0.36363095801789314, 0.21166557882679626, 0.1966135177644901, 0.24000840639928356, 0.3442791011184454, 0.1924597765901126, 0.5602993501815945, 0.21068307920359075, 0.4408534721005708, 0.41007990308571607, 0.824204214150086, 1.248042555525899, 1.6973900562152267, 3.0657835537567735, 3.539669425226748, 3.1045182002708316, 9.946395680308342, 12.864585891366005, 8.096418399363756, 15.269798878580332, 14.496867153793573, 23.45615465193987, 19.373078048229218, 15.289135091006756, 15.649765189737082, 22.611718364059925, 18.708052933216095, 23.858260475099087, 22.61745795607567, 17.96712689101696, 23.98033082485199, 26.44591972231865, 15.680544488132, 17.28647891432047, 16.995272040367126, 17.14107021689415, 10.579420812427998, 3.806937108747661, 3.394932341761887, 4.589158147573471, 12.55921432748437, 23.811475485563278, 32.65108175575733, 35.48751935362816, 36.815255507826805, 36.10490642488003, 32.88203336298466, 24.862968362867832, 17.214864157140255, 11.062543038278818, 5.837775897234678, 2.1587313758209348, 0.35746157343965024, 0.37523164646700025, 0.089663944527274, 0.5069033685140312, 0.46607375785242766, 0.5709326639771461, 0.3774840052938089, 0.22278401971561834, 0.15097551746293902, 0.17366757325362414, 0.07282393838977441, 0.2909249172080308, 0.24245212058303878, 0.6317488162312657, 0.30238156963605434, 1.0680757812224329, 4.656422613188624, 26.75233718007803, 60.64159959554672, 70.12463673949242, 54.98233526945114, 93.35040405392647, 85.53087204694748, 60.40647201240063, 42.624653577804565, 35.30136354267597, 35.410588681697845, 53.84776555001736, 74.61704447865486, 97.4347972869873, 85.33860236406326, 18.63936971873045, 0.24969899968709797, 0.17844189831521362, 0.14128876850008965, 0.15453901374712586, 0.15176162996795028, 0.1317128518712707, 0.20200827828375623, 0.1328259546426125, 0.11239007231779397, 0.21251897444017231, 0.11971724437898956, 0.18292653345270082, 0.13396086171269417, 0.14006447716383263, 0.1328493026085198, 0.1173481457226444, 0.12721408624202013, 0.15394351445138454, 0.12555191293358803, 0.22734257276169956, 0.12091111508198082, 0.11081293429015204, 0.22962298477068543, 0.1076324975292664, 0.1730661664623767, 0.1367242931155488, 0.13980769406771287, 0.10189476830419153, 0.1347566072945483, 0.21970318659441546, 0.15532025776337832, 0.09502995424554683, 0.17008476628689095, 0.0645155728852842, 0.19855243794154376, 0.09035203416715376], [0.02288556152052479, 0.036577082209987566, 0.06798627102398314, 0.0037463364242285024, 0.01923091651406139, 0.01202043604280334, 0.05764931906014681, 0.05591032975644339, 0.012573302665259689, 0.08194869602448307, 0.006178936946525937, 0.06899464191519655, 0.067790388566209, 0.10737264194176532, 0.05722771609725896, 0.09990801670937799, 0.024819247701088898, 0.09833802556386217, 0.07223059132229537, 0.09710197860840708, 0.0275152030371828, 0.07699478606809862, 0.034872691830969416, 0.05259143792500254, 0.017775475862435997, 0.055383586732205003, 0.04524567135376856, 0.08458079697447829, 0.09990676990128122, 0.03254400682635605, 0.026149560399062466, 0.049724963027983904, 0.2732515905518085, 30.347979739308357, 82.64106631278992, 89.20391455292702, 75.10090291500092, 81.68465003371239, 35.56957595050335, 46.45111285150051, 36.89085625112057, 46.41626112163067, 59.230735301971436, 62.98064008355141, 41.67711742222309, 33.105415776371956, 45.69294713437557, 39.94677007198334, 18.212781809270382, 2.526850397698581, 0.07516738842241466, 0.09577929333318025, 0.1932293688878417, 0.16644796065520495, 0.042533180967438966, 0.06057895443518646, 0.1721794335753657, 0.17230182857019827, 0.19929250760469586, 0.06827794990385883, 0.04452126471733209, 0.8761950430925936, 2.055760226212442, 0.49325337284244597, 1.3022040179930627, 0.795645599719137, 1.3866611360572278, 3.924189554527402, 4.677913310006261, 7.665436025708914, 9.661313127726316, 7.8775206953287125, 9.682705029845238, 19.3780367821455, 14.991934038698673, 12.514908704906702, 10.470601301640272, 11.67392073199153, 14.854720551520586, 14.614860322326422, 8.467063810676336, 11.514411941170692, 21.14281978458166, 14.727538526058197, 20.89534856379032, 21.20482485741377, 15.24184187874198, 7.7546922862529755, 7.70972122438252, 5.692182434722781, 2.6815427094697952, 0.8906857436522841, 0.9531406767200679, 6.771876448765397, 34.20764543116093, 48.55508275330067, 61.243966072797775, 63.93242821097374, 68.38630601763725, 69.30544629693031, 68.47898304462433, 77.64638632535934, 74.56465288996696, 71.8991719186306, 64.16536331176758, 59.7671715170145, 50.89524798095226, 41.122024208307266, 28.88902522623539, 16.772837676107883, 7.829449474811554, 2.09835356567055, 0.600584966596216, 0.31908063450828195, 0.12432884614099748, 0.11006989603629336, 0.09478545369347557, 0.04673829360399395, 0.07417154498398304, 0.11875043375766836, 0.02083296472846996, 0.1882126583950594, 0.08768782048719004, 0.3091010340722278, 0.19958553719334304, 0.2357713962555863, 2.9527674056589603, 24.86888464540243, 30.987111143767834, 18.785707466304302, 34.48488235473633, 62.51923844218254, 58.68410803377628, 50.73539815843105, 33.934645280241966, 37.87268936634064, 52.79061667621136, 48.53383049368858, 75.96624568104744, 68.26459094882011, 15.473826080560684, 0.2524432836798951, 0.15203089598799124, 0.09984649266698398, 0.06536882006912492, 0.06513951127999462, 0.037247679429128766, 0.03400631605472881, 0.04186276928521693, 0.0222021919398685, 0.03616383211920038, 0.055003258312353864, 0.027984873049717862, 0.028455990250222385, 0.01786788066965528, 0.0626180051767733, 0.03834365343209356, 0.07592617504997179, 0.06610260374145582, 0.04803824318514671, 0.09828547408687882, 0.034791122379829176, 0.07005100749665871, 0.03146379232930485, 0.05861562873178627, 0.0873445623437874, 0.05371543542423751, 0.03644137679657433, 0.024747164752625395, 0.0484358673566021, 0.046699152735527605, 0.008483463188895257, 0.03690347133670002, 0.02537098069296917, 0.014324729436339112, 0.012617276770470198, 0.03990956276538782, 0.05440839355287608, 0.03490631854219828, 0.03879676427459344, 0.02235500571259763, 0.07683929870836437, 0.068829217198072, 0.055824166411184706, 0.051425394049147144, 0.013137415608071024, 0.048120573337655514, 0.04726806830149144, 0.06518739464809187, 0.10591208047117107, 0.07665927594644018, 0.02070292004646035, 0.05681107810232788, 0.059324394605937414, 0.07487821800168604, 0.1448258591699414, 0.014691932046844158, 0.027168581109435763, 0.04428196662047412, 0.09283090388635173, 0.02548683922213968, 0.031290029583033174, 0.042752092267619446, 0.035154214419890195, 0.057034835626836866, 0.0794050664990209, 0.15825040522031486, 0.14677864266559482, 0.9533431939780712, 46.347682401537895, 103.2293875515461, 100.0964404642582, 97.30602219700813, 109.88560438156128, 67.92287528514862, 57.50411555171013, 24.67279426753521, 22.80009515583515, 38.04148010909557, 52.473307102918625, 38.98497708141804, 38.719872906804085, 46.19863539934158, 41.670707166194916, 15.988584458827972, 1.5697125135920942, 0.20036501489812508, 0.10018301210948266, 0.24555594543926418, 0.2574882551562041, 0.11260894651059061, 0.041014420276042074, 0.004980162038918934, 0.5466104065999389, 0.41660640912596136, 0.34154847264289856, 0.29290461097843945, 1.1945263459347188, 3.402496073395014, 1.6912669222801924, 1.7200652207247913, 0.8986936951987445, 1.3369256048463285, 1.7033845908008516, 0.2924367313971743, 2.625200282782316, 0.929899342590943, 2.1015311451628804, 2.6142991427332163, 2.64242357108742, 2.300295392051339, 6.854192381724715, 5.567478351294994, 10.099582560360432, 16.2528944760561, 17.7768350020051, 16.929843351244926, 19.380519948899746, 27.436194084584713, 21.054018549621105, 27.62451957911253, 26.774712279438972, 22.18028761446476, 16.3760344684124, 15.363632943481207, 5.821933597326279, 4.2916659358888865, 1.5101492847315967, 0.6069541373290122, 9.932769611477852, 37.12735556066036, 52.748245149850845, 60.70499539375305, 61.81146562099457, 69.15637269616127, 68.51573467254639, 67.54341244697571, 75.31446665525436, 73.85420501232147, 70.89967355132103, 66.3781213760376, 63.95987033843994, 59.78812359273434, 53.5432118922472, 43.42246636748314, 29.07269597053528, 16.990873776376247, 6.723438547924161, 2.207457348704338, 0.7808001525700092, 0.15282486041542143, 0.04966924258042127, 0.1358496127068065, 0.01391309815517161, 0.0547365601232741, 0.0948265686747618, 0.034619099969859235, 0.03193031378032174, 0.09611213172320276, 0.16790227324236184, 0.11846158988191746, 0.3885842190356925, 0.9383784688543528, 21.938932165503502, 31.28406520932913, 20.98298706114292, 37.400032728910446, 44.54533651471138, 28.70752226561308, 27.027032040059566, 18.724722638726234, 47.91605964303017, 82.91728109121323, 72.79045209288597, 90.11949822306633, 85.88056728243828, 29.48470216244459, 0.6404257100075483, 0.08143225029925816, 0.13746642594924197, 0.016344897157978266, 0.0825043123040814, 0.036149783263681456, 0.05093540588859469, 0.03561150726454798, 0.06001970534271095, 0.011235773508815328, 0.0444360105029773, 0.006882083835080266, 0.03596490314521361, 0.03117203181318473, 0.08704019273864105, 0.019494093212415464, 0.09591850539436564, 0.05452102930576075, 0.061628050680155866, 0.044906955154147, 0.014462369072134607, 0.02346513247175608, 0.06372553441906348, 0.11430836078943685, 0.0635038549080491, 0.07291662521311082, 0.024344642406504136, 0.01030065073791775, 0.09752577461767942, 0.0566908538894495, 0.022792698437115178, 0.032244995527435094, 0.00828455184091581, 0.014175342530506896, 0.028376868031045888, 0.12474528746679425, 0.14045995281776413, 0.20618609472876415, 0.13679846335435286, 0.11884986670338549, 0.20066421915544197, 0.13820906344335526, 0.1703469076892361, 0.1670817399281077, 0.16825065220473334, 0.08677523859660141, 0.1825816128985025, 0.1164113920822274, 0.2297878306126222, 0.14403735694941133, 0.13060856581432745, 0.127950445166789, 0.15834918507607654, 0.21362168714404106, 0.2792980457888916, 0.14313181804027408, 0.1661066320957616, 0.12944823276484385, 0.20687749434728175, 0.2226780410273932, 0.10488440631888807, 0.1872721643303521, 0.13767936296062544, 0.23075367644196376, 0.18424780864734203, 0.20827737782383338, 0.26483047055080533, 0.8736639632843435, 49.758728966116905, 117.74785369634628, 111.35905131697655, 98.12290996313095, 108.12803149223328, 54.25645262002945, 65.3062216937542, 56.658976301550865, 70.68297877907753, 84.6480730175972, 83.44853818416595, 64.2016589641571, 53.79435941576958, 63.71379554271698, 60.459148585796356, 31.921577900648117, 5.007797358557582, 0.4222977615427226, 0.3022492298623547, 0.7414120004978031, 0.47048137290403247, 0.1378077841945924, 0.29777930409181863, 0.45994394458830357, 0.4435010690940544, 0.42266257165465504, 0.24987776821944863, 0.28224662819411606, 1.8420814233832061, 4.114689482375979, 2.5300115905702114, 3.239218359813094, 2.0745604299008846, 4.171399064362049, 9.336551204323769, 11.169546246528625, 17.766797840595245, 18.147252425551414, 17.640384323894978, 18.90576772391796, 36.251445561647415, 32.02357962727547, 27.05399539321661, 24.04474876821041, 23.006659671664238, 29.053280912339687, 26.316276378929615, 17.775140292942524, 23.203893788158894, 38.831495717167854, 29.927036426961422, 36.911504343152046, 37.66144350171089, 31.512165069580078, 17.99757655709982, 19.65330731123686, 20.897504948079586, 11.530424281954765, 5.154137955978513, 1.157475127838552, 6.760197775438428, 32.967954352498055, 48.67294102907181, 60.51691688597202, 64.6235503256321, 72.35086128115654, 73.32105562090874, 74.14339989423752, 81.24846383929253, 78.87438163161278, 76.78099796175957, 70.51663890480995, 65.15400186181068, 55.69786727428436, 47.20165237784386, 35.689041540026665, 21.4903624355793, 11.961699239909649, 4.110965682193637, 1.2250973680056632, 0.5603421572595835, 0.2850547665730119, 0.2386988719808869, 0.3079432836966589, 0.33005738456267864, 0.3100320138037205, 0.21919871913269162, 0.13212155259680003, 0.298718239646405, 0.1790156081551686, 0.23509310296503827, 0.44496725604403764, 0.8444200200028718, 7.5239472929388285, 38.43127839267254, 46.523757353425026, 30.309465005993843, 49.310581013560295, 86.75069779157639, 79.9203971028328, 72.48772993683815, 43.10088202357292, 46.04956179857254, 69.44430604577065, 66.73996835947037, 90.89607015252113, 97.73551315069199, 27.481899932026863, 0.5816451797727495, 0.21471347543410957, 0.19879949890309945, 0.14971964032156393, 0.2686387568246573, 0.13845466979546472, 0.128434028592892, 0.13765904295723885, 0.26253711548633873, 0.13412015629000962, 0.0999088330718223, 0.11326203646603972, 0.15058118471642956, 0.12531455926364288, 0.1383305381750688, 0.14735674601979554, 0.164058675582055, 0.2255772112403065, 0.1760268904035911, 0.2215725526912138, 0.06509390630526468, 0.19319684797665104, 0.1524341048207134, 0.16813515918329358, 0.1461558768642135, 0.22594702342757955, 0.08655246812850237, 0.12890073558082804, 0.2632512990385294, 0.18368563178228214, 0.12362764275167137, 0.13580089813331142, 0.09251093433704227, 0.12673994293436408, 0.08715219024452381], [0.08327849849592894, 0.14113778597675264, 0.0345913325145375, 0.036458720787777565, 0.012717990848614136, 0.07123950505047105, 0.03860744240228087, 0.06355673293001018, 0.011177460182807408, 0.024963853320514318, 0.04617351180058904, 0.0223254218508373, 0.060760094129364006, 0.013873319039703347, 0.036788705619983375, 0.018404587026452646, 0.07403662253636867, 0.0446075096988352, 0.00955626548602595, 0.04520307578786742, 0.057680103345774114, 0.01265049437279231, 0.03622534502937924, 0.011699284623318817, 0.05904732119233813, 0.05162687230040319, 0.03245626270654611, 0.02455472400470171, 0.05862928053829819, 0.10172011869144626, 0.08689682465046644, 0.5805136123672128, 37.33993515372276, 93.16707149147987, 92.4346911907196, 81.76549449563026, 66.78015500307083, 46.334725096821785, 21.957087591290474, 31.795992739498615, 62.23386615514755, 61.09920144081116, 57.442053481936455, 52.11159311234951, 55.52605949342251, 48.00755113363266, 16.45388849079609, 4.30148365907371, 0.48407763708382845, 0.31036069616675377, 0.12639024294912815, 0.5043411778751761, 0.07773644392727874, 0.1493968951399438, 0.09957617279724218, 0.10084626948810183, 0.04701702942838892, 0.05789292903500609, 0.0874745866167359, 0.19493613042868674, 0.14717549871420488, 0.9070503967814147, 1.484849767293781, 1.6767826932482421, 2.345343162305653, 2.3684359481558204, 7.0404598116874695, 4.1630566120147705, 2.6716677518561482, 5.891798073425889, 4.844060344621539, 4.205502709373832, 3.6779285687953234, 4.55412782728672, 3.3884066669270396, 7.3796771094202995, 7.456848118454218, 7.452115947380662, 13.146732151508331, 19.634059444069862, 16.42770789563656, 9.254255220293999, 15.698330383747816, 19.3000877648592, 15.006291568279266, 20.390505753457546, 17.312851399183273, 10.724231991916895, 13.650715257972479, 10.004406217485666, 1.548991275485605, 0.7694087200798094, 17.025792002677917, 48.361855521798134, 49.5833645761013, 55.821961015462875, 53.65360736846924, 48.16591143608093, 48.467630445957184, 47.86791242659092, 51.783089339733124, 52.24313825368881, 52.065505385398865, 50.417723804712296, 53.44678446650505, 54.47078391909599, 55.1780741661787, 57.244505882263184, 60.583907291293144, 58.42779278755188, 52.32858806848526, 34.06796492636204, 18.345185704529285, 7.648438587784767, 2.2601764323189855, 0.13113569846609607, 0.05750478580011986, 0.03688677301397547, 0.011049899840145372, 0.018264929676661268, 0.27720967191271484, 0.1467336536734365, 0.15804769500391558, 0.2496081608114764, 0.037826320840395056, 0.1891640917165205, 0.08993096183985472, 0.4011182620888576, 10.207240283489227, 27.80775524675846, 37.343434765934944, 71.7436234652996, 90.72331622242928, 59.30252484977245, 75.00331655144691, 38.122833743691444, 29.123235158622265, 43.98778483271599, 47.08298474550247, 60.31648904085159, 74.55570057034492, 25.42928047478199, 1.0300698643550277, 0.17419991578208283, 0.35901954921428114, 0.18775456032017246, 0.2399823718587868, 0.14506978826830164, 0.27661868487484753, 0.10849908852833323, 0.060208199720364064, 0.03673097395221703, 0.0387903558294056, 0.002934530766651733, 0.05935801389568951, 0.08608138989075087, 0.01380402563881944, 0.04599914791469928, 0.054239124510786496, 0.011351481753081316, 0.0878913322230801, 0.08398286343435757, 0.14723503380082548, 0.09110169237828813, 0.035206888351240195, 0.055604668814339675, 0.010116290122823557, 0.020990530101698823, 0.03612935935962014, 0.04725502134533599, 0.10840044225915335, 0.07352584681939334, 0.03721460932865739, 0.06616277707507834, 0.04918749968055636, 0.03633376909419894, 0.08502234515617602, 0.08810366809484549, 0.06252981576835737, 0.04034262448840309, 0.06760794640285894, 0.12983127002371475, 0.05276680371025577, 0.01666351414314704, 0.019454763096291572, 0.05494186785654165, 0.10390347262728028, 0.03798772311711218, 0.03864382248139009, 0.08579491346608847, 0.04631780015188269, 0.031390579461003654, 0.0478899620793527, 0.013801442037220113, 0.008126614466164028, 0.03675567262689583, 0.06616147089516744, 0.05179364772629924, 0.049276045319857076, 0.03737164406629745, 0.035486596389091574, 0.03382258626515977, 0.04522219351201784, 0.025197371942340396, 0.053089415305294096, 0.14742172847036272, 0.13985100580612198, 1.9684874592348933, 55.340618044137955, 107.08361953496933, 103.48423227667809, 107.25803017616272, 98.06772172451019, 79.89054590463638, 32.961145117878914, 18.354153223335743, 44.36747945845127, 65.60987859964371, 61.579871848225594, 56.37526452541351, 59.4518568366766, 46.783283427357674, 13.733194582164288, 1.4940837468020618, 0.37359426089096814, 0.21399890596512705, 0.1369095331756398, 0.21311159420292825, 0.10031845406047069, 0.1625231868820265, 0.10935613550827838, 0.740317718591541, 0.23767381760990247, 0.7094098802190274, 0.4922210454242304, 0.6060386833269149, 0.3579918824834749, 0.9915161831304431, 0.15762569499202073, 0.8439166063908488, 0.35020482377149165, 2.395087005570531, 2.540888744406402, 1.8918949691578746, 1.1745573487132788, 0.507608171319589, 1.0050313454121351, 1.674041971564293, 0.9703246015124023, 0.9090328810270876, 1.5443725045770407, 3.224807633087039, 0.8080492028966546, 4.748127842321992, 10.489965062588453, 19.21002309769392, 26.217453181743622, 14.12920743227005, 18.549267053604126, 23.97065844386816, 22.070710994303226, 29.52726937830448, 22.772725224494934, 14.453458283096552, 16.101919077336788, 8.0695091933012, 1.1154376273043454, 1.6423174738883972, 21.747452840209007, 49.45789910852909, 52.769657000899315, 58.44756692647934, 57.057001143693924, 53.507980182766914, 54.681376218795776, 54.967956840991974, 60.29756225645542, 59.20700937509537, 60.48586115241051, 59.51306015253067, 62.978743985295296, 63.16309109330177, 64.58106100559235, 64.91105809807777, 66.77478969097137, 66.50419101119041, 62.116414457559586, 47.634646743535995, 28.94719060510397, 13.620598074048758, 4.918946726247668, 0.9964692173525691, 0.048707040696172044, 0.021102249302202836, 0.07956968227517791, 0.059545543481362984, 0.14088581199757755, 0.030578235746361315, 0.029819937080901582, 0.3274441638495773, 0.06039513558789622, 0.14737362245796248, 0.07810215203789994, 0.3134786960436031, 6.623278772458434, 11.913744863122702, 21.505586318671703, 74.20633971691132, 87.97537207603455, 59.14835952222347, 50.26849061250687, 12.93983705341816, 33.13294529914856, 69.56283688545227, 75.86021617054939, 81.36044383049011, 89.30869773030281, 44.5950910449028, 2.058370211161673, 0.2233909332426265, 0.28984387521632016, 0.1908018928952515, 0.07445434777764603, 0.07735011153272353, 0.20305117388488725, 0.03911889718438033, 0.01065366348484531, 0.03221999628294725, 0.112022100656759, 0.02186851306760218, 0.09901237805024721, 0.03526408938341774, 0.021421478559204843, 0.031568936101393774, 0.027950541298196185, 0.05253191768133547, 0.09397594869369641, 0.08314022154081613, 0.04549633915303275, 0.026856374424824025, 0.006333137607725803, 0.04135877679800615, 0.01946497319295304, 0.017590816532901954, 0.05898254654312041, 0.023741853365208954, 0.010599273336993065, 0.03521492581057828, 0.09043041238328442, 0.0479722477030009, 0.036286112081143074, 0.07983574963873252, 0.15949804452247918, 0.2939714927924797, 0.09475522601860575, 0.11417340865591541, 0.1731561147607863, 0.23313883517403156, 0.23468174535082653, 0.14759645971935242, 0.12342033121967688, 0.11542354899575002, 0.2118562810937874, 0.10150211281143129, 0.11907954656635411, 0.14338187727844343, 0.1485587580827996, 0.16555744281504303, 0.21935679658781737, 0.08517700131051242, 0.10353976089390926, 0.12241922595421784, 0.2560399688081816, 0.13793967867968604, 0.1992537229671143, 0.13533583871321753, 0.12603721814230084, 0.13483178685419261, 0.08841468734317459, 0.237549893790856, 0.16507295396877453, 0.24321647331817076, 0.3490332991350442, 2.8998046601191163, 62.50766046345234, 120.68182066082954, 114.38293665647507, 105.6506860256195, 89.01652380824089, 62.781659960746765, 33.15626464784145, 52.052650675177574, 92.99791216850281, 90.78257784247398, 86.18399620056152, 76.01531624794006, 77.44498953223228, 65.73830410838127, 27.347512543201447, 7.301598424091935, 1.22709154849872, 0.513207942713052, 0.20201541774440557, 0.5416171182878315, 0.28060167271178216, 0.2897862845566124, 0.4339009436080232, 0.5312455154489726, 0.20720856642583385, 0.2382454345934093, 0.3542429086519405, 0.6057713320478797, 0.5526759498752654, 4.126703962683678, 4.910142123699188, 5.534116141498089, 6.388408150523901, 15.60792088508606, 19.217793680727482, 15.415889639407396, 12.10670230910182, 15.68838631734252, 14.7246677801013, 16.023099906742573, 14.330051355063915, 15.882814284414053, 14.494521729648113, 22.04507566988468, 18.68559803813696, 14.98802974820137, 27.34847579151392, 34.45011042058468, 33.46781373023987, 20.055378936231136, 25.746018178761005, 31.98866330087185, 28.577571138739586, 37.79143452644348, 31.46958265453577, 20.674284026026726, 25.2697479352355, 19.485211931169033, 2.7533476939424872, 2.2248675394803286, 19.827843345701694, 48.78726929426193, 56.866813749074936, 65.6649224460125, 64.87582638859749, 65.03040969371796, 62.08434037864208, 63.611353039741516, 69.2072519659996, 69.09587994217873, 70.28747320175171, 66.18788838386536, 70.13893157243729, 68.72186601161957, 71.14852219820023, 70.38501396775246, 71.00636422634125, 68.35560366511345, 64.25085112452507, 46.97857394814491, 25.531107410788536, 10.349982473999262, 3.241840456612408, 0.6024392077233642, 0.15181104216026142, 0.1071130609489046, 0.13245609792647883, 0.16213747789151967, 0.32788779004476964, 0.3555058065103367, 0.2884806983638555, 0.9615818643942475, 0.27446046005934477, 0.19994392030639574, 0.3842913103289902, 1.848329238127917, 17.221416905522346, 40.027375146746635, 48.30841898918152, 82.17179909348488, 110.19871518015862, 72.72438883781433, 104.0009817481041, 53.88680845499039, 34.5917022228241, 58.436912298202515, 65.88313713669777, 76.85234293341637, 99.41491663455963, 48.0825325101614, 1.729336129501462, 0.4094237257959321, 0.4194819345138967, 0.2864211198175326, 0.31266919104382396, 0.31747281609568745, 0.29466741951182485, 0.17615384218515828, 0.2562747843330726, 0.12504158250521868, 0.17382798105245456, 0.0908911821898073, 0.1435279764700681, 0.2085843004169874, 0.1387814077315852, 0.15786862961249426, 0.11466193478554487, 0.1797380592324771, 0.1467421289999038, 0.3578660439234227, 0.2168650209205225, 0.2403812317061238, 0.1195730450854171, 0.16682562476489693, 0.1263904952793382, 0.10390894225565717, 0.16936114261625335, 0.11134171450976282, 0.20466340065468103, 0.21444964193506166, 0.2594452095218003, 0.1779743007500656, 0.1710617888602428, 0.21029705851105973], [0.048904656068771146, 0.0846496905433014, 0.05140432076586876, 0.009907786516123451, 0.21255023370031267, 0.04211027182464022, 0.05286908279231284, 0.07061465381411836, 0.06071705327485688, 0.03776910867600236, 0.0407532585086301, 0.039599864539923146, 0.1345220737857744, 0.09455677572987042, 0.046650081931147724, 0.02027442624239484, 0.052369906843523495, 0.05272514325042721, 0.06756116141332313, 0.08424003986874595, 0.07234374657855369, 0.08979975755210035, 0.03487558991764672, 0.0356790723890299, 0.028289812253206037, 0.06754107889719307, 0.012792049765266711, 0.015551073738606647, 0.05213506534346379, 0.12318330409470946, 3.4708368312567472, 52.306853234767914, 95.5870932340622, 84.56983521580696, 78.59945878386497, 55.64944267272949, 37.59504586458206, 33.53962987661362, 64.87594798207283, 78.18430066108704, 41.96965992450714, 27.92302206158638, 33.73052403330803, 58.710888996720314, 22.661803476512432, 2.216957788914442, 0.8221305347979069, 0.09536436598864384, 0.026752965422929265, 0.1693268257076852, 0.22614731424255297, 0.23810978484107181, 0.041331324755446985, 0.04892771459708456, 0.07732438869425096, 0.15178153436863795, 0.034637082208064385, 1.250490217935294, 1.3549193018116057, 1.582257659174502, 0.22455525904661044, 0.4189314093673602, 3.59975203871727, 2.24012847058475, 3.436630591750145, 2.7203300781548023, 2.2431345842778683, 1.7256190977059305, 0.8167138660792261, 0.10108107017003931, 0.20584047655574977, 0.6548079976346344, 0.219913451874163, 0.8488374017179012, 0.8373281161766499, 3.142206002958119, 2.328026066534221, 1.8108297628350556, 3.229138213209808, 9.302461333572865, 9.383586030453444, 10.2621197886765, 9.538216833025217, 5.962149873375893, 6.669976366683841, 6.352400332689285, 9.262173045426607, 20.194679461419582, 8.399929013103247, 0.17937614349648356, 0.3589369630208239, 9.5903604850173, 39.74250063300133, 36.70172519981861, 41.32808335125446, 37.931187227368355, 39.528701305389404, 35.190386697649956, 40.61106562614441, 41.80244989693165, 46.012958362698555, 49.83108468353748, 53.22021022439003, 53.52308437228203, 55.75195737183094, 54.794078171253204, 56.01716414093971, 55.81639051437378, 54.96620513498783, 53.92229475080967, 52.698456421494484, 51.318161487579346, 43.10122400522232, 35.22263556718826, 22.93359149247408, 12.26061400026083, 3.1343900598585606, 0.7872779143508524, 0.055078263467294164, 0.1965550662134774, 0.07500574123696424, 0.19868988369125873, 0.07900155338575132, 0.09009721776237711, 0.049141549607156776, 0.043208735733060166, 0.07092374347848818, 0.19404800230404362, 0.12289631558815017, 3.4536864515393972, 21.60125758498907, 40.050295516848564, 93.0452348291874, 86.33546367287636, 91.31225422024727, 96.46754398941994, 56.91634029150009, 26.841668486595154, 28.451911881566048, 34.27239015698433, 57.658843249082565, 62.03167900443077, 42.68972508609295, 4.970654351636767, 0.5212563264649361, 0.20582153694704175, 0.23889810894615948, 0.01349513264358393, 0.03568094631191343, 0.03463954613835085, 0.004728581861854764, 0.23581545014167204, 0.014774162009416614, 0.07201663014711812, 0.08918606821680441, 0.10738757395301946, 0.026284534797014203, 0.05398226719989907, 0.07209339790279046, 0.08489290717989206, 0.1091844099573791, 0.053468444966711104, 0.15567708236631006, 0.01119885258958675, 0.06961511448025703, 0.027052724435634445, 0.055408801199519075, 0.05095859058201313, 0.13093738176394254, 0.015916151023702696, 0.1130358521186281, 0.12587911100126803, 0.061221728537930176, 0.02491834482498234, 0.0432937376172049, 0.013808463681925787, 0.026194107813353185, 0.0101223005913198, 0.09593432798283175, 0.05949457648966927, 0.23899766063550487, 0.06319625696050934, 0.07424316965625621, 0.06504777440568432, 0.049265714624198154, 0.020034862827742472, 0.011359406962583307, 0.001517622886240133, 0.10697269855882041, 0.047749711011420004, 0.027737995769712143, 0.011258993454248412, 0.05175756450626068, 0.05404746858403087, 0.01071302138370811, 0.03945663003833033, 0.02084313215164002, 0.0510755864524981, 0.03539098550390918, 0.04843603433982935, 0.0366867827688111, 0.1160205622727517, 0.02043351487373002, 0.027369285671738908, 0.06777635455364361, 0.2731304126791656, 8.305335938930511, 72.16788589954376, 107.71797269582748, 103.33329677581787, 107.58162081241608, 84.31725516915321, 65.54166465997696, 32.87360921502113, 32.531650364398956, 70.8448500931263, 53.55173483490944, 31.94758750498295, 36.28031641244888, 64.02985498309135, 19.085492379963398, 1.1877646087668836, 1.0749524622224271, 0.11630530949332751, 0.04094544507097453, 0.055264620459638536, 0.1868527173064649, 0.4043787543196231, 0.5843144771642983, 1.444183993153274, 0.8401554613374174, 0.41964862088207155, 1.3732666173018515, 1.139939900022, 0.9564215037971735, 0.02794373023789376, 1.2533446960151196, 0.557379147503525, 1.2871914985589683, 1.5023513906635344, 2.2832221956923604, 1.6028171684592962, 1.8438637652434409, 1.532166253309697, 1.4280907879583538, 1.2063971464522183, 1.0231156437657773, 1.3699516514316201, 0.9852466976735741, 0.3813499119132757, 0.6720597844105214, 1.891869439277798, 0.7692044810391963, 1.0620477609336376, 1.8315413827076554, 5.269377697259188, 9.763957969844341, 8.96928571164608, 10.102536901831627, 9.054254852235317, 9.171150829643011, 6.722933650016785, 12.705972902476788, 26.51923678815365, 10.296871773898602, 0.8283078751992434, 0.30928363208658993, 12.654110435396433, 39.1993273794651, 42.496171072125435, 47.856490239501, 44.22006256878376, 44.86448518931866, 43.70590455830097, 50.82460597157478, 53.110297322273254, 52.86267600953579, 57.183006182312965, 60.40560945868492, 62.47759647667408, 67.44797676801682, 66.25641390681267, 67.81714975833893, 66.27841472625732, 66.95024907588959, 64.31660279631615, 63.133524879813194, 59.44629393517971, 53.809577599167824, 41.619273126125336, 30.738914161920547, 20.17033226788044, 7.9084990080446005, 1.87513466225937, 0.22765279049053788, 0.13806980685330927, 0.03425997470912989, 0.10542782169068232, 0.0704024886363186, 0.17702113080304116, 0.09706202879897319, 0.05448580326628871, 0.048871407852857374, 0.12123384542064741, 0.17456677422160283, 1.0273739090189338, 9.41896403208375, 36.07674613595009, 92.01207026839256, 89.60225477814674, 93.95959496498108, 86.10644236207008, 24.6621111407876, 27.017391957342625, 47.86405183374882, 58.878251016139984, 78.80540773272514, 75.08311226963997, 63.29861082136631, 10.267402455210686, 0.45496161037590355, 0.20861305121798068, 0.09026194486068562, 0.08072929544141516, 0.02089252207952086, 0.009181494824588299, 0.008080181996774627, 0.11188078089617193, 0.031428852016688325, 0.09240019106073305, 0.05121418995258864, 0.07986484924913384, 0.030754328836337663, 0.02282322853716323, 0.05236958772002254, 0.09172128920909017, 0.10254840002744459, 0.060805650864494964, 0.037938014065730385, 0.03438782448938582, 0.04724383346911054, 0.017320550468866713, 0.02131123808794655, 0.04749925101350527, 0.10112310541444458, 0.026309046079404652, 0.022569653374375775, 0.06971378301386721, 0.13205746072344482, 0.03297012946859468, 0.06458030300564133, 0.051992079461342655, 0.15773378137964755, 0.12216852104756981, 0.261075203306973, 0.17289124225499108, 0.33258988929446787, 0.2272162592271343, 0.16917689703404903, 0.2694267692277208, 0.08196536466130055, 0.12867227284004912, 0.17692518595140427, 0.1219646233948879, 0.19216032000258565, 0.26306540588848293, 0.26058443589136004, 0.14006967219756916, 0.1315973440068774, 0.16484536696225405, 0.10675773548427969, 0.18171650619478896, 0.1894425306818448, 0.2840900933369994, 0.10846497199963778, 0.17989221814787015, 0.12229167303303257, 0.2572557551320642, 0.13742428680416197, 0.11284288630122319, 0.12910383171401918, 0.3368014289299026, 10.702561754733324, 85.03056049346924, 119.54096987843513, 104.7058667242527, 104.2029257118702, 72.01239064335823, 52.257110103964806, 49.1979094594717, 96.19935438036919, 113.94741162657738, 60.418148785829544, 48.32011096179485, 49.36190485954285, 82.80061975121498, 36.099940091371536, 5.057759927585721, 1.5400928654707968, 0.2509699127404019, 0.14284576463978738, 0.49952505505643785, 0.38588369206991047, 0.3111405746312812, 0.4236593353562057, 0.8056004717946053, 0.31815746217034757, 0.5002760491333902, 1.1795958783477545, 2.645248956978321, 3.7670318875461817, 3.576525547541678, 3.833243572153151, 1.9658561004325747, 9.707471150904894, 8.012961577624083, 8.059541378170252, 6.810693740844727, 6.287059988826513, 5.338030988350511, 2.5913628609851003, 2.036380316130817, 1.1135235987603664, 1.1697140336036682, 1.2656523543410003, 3.7084012711420655, 4.81481758877635, 10.3168511018157, 8.091666754335165, 8.48868940025568, 11.646353211253881, 19.978073984384537, 14.503275509923697, 18.50762128829956, 21.130749732255936, 13.530288320034742, 18.2391656935215, 15.106540638953447, 21.60057172179222, 34.94291737675667, 20.257461592555046, 2.28813533205539, 0.9306576394010335, 12.894981410354376, 44.16437275707722, 47.26187154650688, 52.74702161550522, 53.6734689027071, 58.61815117299557, 55.0021056085825, 59.554310739040375, 61.118189021945, 64.2950351536274, 66.45720273256302, 72.41750970482826, 70.8002632856369, 76.31877556443214, 74.83622431755066, 74.5707705616951, 73.31506714224815, 75.61735600233078, 70.34150630235672, 69.23462569713593, 63.79500478506088, 58.27303469181061, 43.26432645320892, 31.236985735595226, 18.722723945975304, 6.0881411377340555, 1.450240749400109, 0.21133223577635363, 0.40060852537862957, 0.2375653453054838, 0.5866012419573963, 0.18577169015770778, 0.254061640589498, 0.2172731576138176, 0.3174552717246115, 0.17181021510623395, 0.21480977651663125, 0.7196684391237795, 5.526336058974266, 33.21850910782814, 48.73639762401581, 105.03752052783966, 99.09333229064941, 97.85284325480461, 116.59071698784828, 74.88669320940971, 34.37380291521549, 36.26720331609249, 50.478117763996124, 72.78676629066467, 84.73162293434143, 69.06053423881531, 8.33877319470048, 0.7632128556724638, 0.309521178714931, 0.28318309981841594, 0.24473983532516286, 0.08379763821722008, 0.11564508749870583, 0.12731121852993965, 0.3507812647148967, 0.10517989983782172, 0.14249872154323384, 0.17105960694607347, 0.381704272585921, 0.1459467099630274, 0.24512196716386825, 0.15100561897270381, 0.2110582496970892, 0.22814136114902794, 0.43350448831915855, 0.1832232144079171, 0.13605999673018232, 0.14259313757065684, 0.19561819382943213, 0.20242153579602018, 0.15483520488487557, 0.28236789512448013, 0.11516472499351948, 0.2932569233234972, 0.2830444963183254, 0.23625956615433097, 0.06837819921202026, 0.11320621211780235, 0.14366951887495816], [0.042843346745939925, 0.05663396084855776, 0.06970468428335153, 0.09851271970546804, 0.03503181571431924, 0.03794595875660889, 0.03285033570136875, 0.0430940405203728, 0.08765994542045519, 0.04948442554450594, 0.11103318145615049, 0.013899752484576311, 0.04163369427260477, 0.03394446917809546, 0.05524031883396674, 0.04936322911817115, 0.056241253405460157, 0.04021321248728782, 0.1178500973037444, 0.05219031823799014, 0.0360036358324578, 0.05643355871143285, 0.05729435353714507, 0.041152556223096326, 0.07353282300755382, 0.12103866058168933, 0.05524889435037039, 0.12590955389896408, 0.04072779913258273, 12.953165788203478, 76.93379536271095, 94.6652626991272, 78.54577526450157, 67.3307378590107, 39.72303807735443, 38.51738557219505, 38.16930525004864, 71.3707722723484, 90.54300829768181, 33.702530935406685, 20.369848161935806, 36.496019437909126, 43.66675905883312, 6.780202751979232, 0.5189081118442118, 0.11487372146802954, 0.10955149846267886, 0.2675027959048748, 0.21021450200350955, 0.3486475604586303, 0.48295645974576473, 1.1871597287245095, 0.754101003985852, 1.0394069133326411, 0.9783919842448086, 1.8916242336854339, 2.565508335828781, 6.55488814227283, 1.839396629948169, 1.326892718207091, 1.3830640353262424, 0.667530664941296, 1.406407488975674, 3.5651256842538714, 10.316755156964064, 16.53551761060953, 22.186602875590324, 29.536421187222004, 43.751509711146355, 58.51335659623146, 66.81715741753578, 67.77427285909653, 58.010502979159355, 46.376743242144585, 28.856126591563225, 12.662181202322245, 0.8237971609923989, 1.9399158423766494, 2.326235412620008, 3.5274326568469405, 4.66124027967453, 6.941523095592856, 5.4790485464036465, 10.515981316566467, 17.493250519037247, 3.8934539537876844, 7.431063652038574, 10.138841103762388, 6.42302761785686, 0.7247338641900569, 2.5186615996062756, 15.38006991147995, 24.978136382997036, 41.92801035940647, 40.2911151945591, 38.37966576218605, 39.44550856947899, 49.199326783418655, 54.23078499734402, 57.09806554019451, 59.98379789292812, 56.35169818997383, 60.27289018034935, 58.217002898454666, 59.4293924421072, 56.90530568361282, 54.562609791755676, 52.826741337776184, 48.80706623196602, 50.142690762877464, 55.62900356948376, 53.81397396326065, 52.27247267961502, 44.591063261032104, 40.88001139461994, 34.18491505086422, 25.809531770646572, 13.359130304306746, 5.156405484303832, 0.5384696403052658, 0.052433011660468765, 0.08518627815647051, 0.20297130395192653, 0.08272444814792834, 0.07439761800924316, 0.007957739690027665, 0.03083246399910422, 0.01829510169045534, 0.13471408223267645, 0.334440004080534, 0.4820203740382567, 1.0249972552992404, 14.548027608543634, 49.01391193270683, 66.52539387345314, 65.27819439768791, 73.63296568393707, 61.21013268828392, 28.743540532886982, 32.86228582262993, 34.49378527700901, 52.24659226834774, 58.34798946976662, 66.1823558807373, 15.2308395691216, 0.28632564994040877, 0.021380617763497867, 0.058710764642455615, 0.08716710741282441, 0.0885645195376128, 0.05654078791849315, 0.006580919844054733, 0.03388602133782115, 0.061875523533672094, 0.021311497839633375, 0.025902555098582525, 0.043952649721177295, 0.09356537775602192, 0.06817523666541092, 0.019660458601720165, 0.09462024419917725, 0.06294753358815797, 0.036690586275653914, 0.10412307412480004, 0.09970843835617416, 0.07282774560735561, 0.04569227727188263, 0.06709455090458505, 0.02954037376184715, 0.1209194419789128, 0.06734225753461942, 0.08165856823325157, 0.04548130324110389, 0.08450653767795302, 0.02771231189399259, 0.029282039577083196, 0.07460413544322364, 0.07428864104440436, 0.02403442282229662, 0.23342243948718533, 0.1319840326323174, 0.10293547456967644, 0.027238495131314266, 0.050831868866225705, 0.05594611240667291, 0.05723641406802926, 0.05591953609837219, 0.01427173730917275, 0.07438852670020424, 0.0027109937991554034, 0.05060618546849582, 0.04532382321485784, 0.04505775956204161, 0.048422961408505216, 0.04286685427359771, 0.06023200410709251, 0.09743753325892612, 0.06285099501837976, 0.045349764986895025, 0.053206570737529546, 0.09536864075926133, 0.048087666509673, 0.046578520341427065, 0.06311597884632647, 0.1651931373635307, 22.049059756100178, 96.8716599047184, 108.32670763134956, 96.23711675405502, 94.26212713122368, 67.62719795107841, 58.932489305734634, 36.004770398139954, 37.183824330568314, 77.82086536288261, 46.090348809957504, 21.334188915789127, 36.98191076517105, 44.8212169110775, 5.214203232899308, 1.360739164520055, 0.12245615522260778, 0.20148834446445107, 0.052309384700492956, 0.5297876405529678, 0.7596891385037452, 1.2561678257770836, 3.3623623894527555, 1.865320976357907, 0.9942870656959713, 0.7161364099010825, 1.2648591469042003, 0.4348894249415025, 1.0125554166734219, 1.345038169529289, 0.5964997108094394, 1.1923425318673253, 0.9048783383332193, 2.2122505540028214, 5.209538033232093, 15.331510417163372, 22.38939229398966, 30.570256412029266, 41.75562500953674, 58.53959798812866, 74.9840895831585, 80.94375818967819, 80.6809414923191, 70.285664498806, 56.459722593426704, 35.494180396199226, 16.954264640808105, 1.321735444944352, 0.5205950431991369, 2.020909683778882, 2.2648653807118535, 1.7774027190171182, 2.166709522716701, 6.945619275793433, 12.235979922115803, 20.659698508679867, 9.190403446555138, 12.180404104292393, 12.489587813615799, 6.8208016734570265, 0.6933983112685382, 3.5090181324630976, 16.861114539206028, 33.35285849869251, 48.494848385453224, 49.13709372282028, 48.25655557215214, 52.12423883378506, 60.20191378891468, 62.963427007198334, 63.894658237695694, 67.75129929184914, 66.27380177378654, 70.33756211400032, 68.79825711250305, 71.7489355802536, 69.33814734220505, 66.08582586050034, 65.05100458860397, 64.46835145354271, 63.36167223751545, 64.90928739309311, 63.494224324822426, 60.743054151535034, 55.58605447411537, 50.67540317773819, 41.57424934208393, 36.01369231939316, 21.570777520537376, 10.231845863163471, 2.177987555041909, 0.15548710740404204, 0.1124013974913396, 0.13298967242008075, 0.11607735141296871, 0.04585497088555712, 0.027078751554654445, 0.031455443167942576, 0.04828793134947773, 0.10833224630914629, 0.26466998853720725, 0.5651636235415936, 0.3707191807916388, 12.523757480084896, 48.310584872961044, 66.02588787674904, 64.22660082578659, 88.68392005562782, 26.248672306537628, 16.340128295123577, 46.34402319788933, 55.035581812262535, 73.13858941197395, 66.28435000777245, 84.93253335356712, 26.839215718209743, 0.30559067556168884, 0.025881199799187016, 0.0685799001075793, 0.049925628627534024, 0.06389144153217785, 0.022900831208971795, 0.09021714882692322, 0.05276403921016026, 0.022362833515217062, 0.013348096490517491, 0.07283856612048112, 0.04712947964435443, 0.11612136077019386, 0.09385746481711976, 0.289616659283638, 0.023494126326113474, 0.04913798358757049, 0.007695367294218158, 0.09321069795987569, 0.027868715806107502, 0.02457348549796734, 0.033449527181801386, 0.05250925249129068, 0.042026583541883156, 0.09764258124050684, 0.022226883193070535, 0.04079358681337908, 0.028522696338768583, 0.032037387136369944, 0.05675727610650938, 0.048657639636076055, 0.1813318658969365, 0.14863202290143818, 0.1849610570934601, 0.34519072563853115, 0.2933690173085779, 0.17567926843184978, 0.13071570225292817, 0.1654310105368495, 0.2225720029673539, 0.11722345749149099, 0.18920513248303905, 0.10750735658803023, 0.12157166362158023, 0.13302603765623644, 0.1356896650395356, 0.12212323519634083, 0.19841917790472507, 0.13392932043643668, 0.15755936183268204, 0.1939537050202489, 0.14580390590708703, 0.16974155267234892, 0.20245628315024078, 0.3443021670682356, 0.24880775454221293, 0.3177230979781598, 0.11569368332857266, 0.25243794021662325, 0.23783857439411804, 29.992356821894646, 112.70749256014824, 120.96881926059723, 103.0016277730465, 93.59434336423874, 56.50800280272961, 55.48404134809971, 55.03579840064049, 104.70825299620628, 128.1048971414566, 51.11458361148834, 38.251255452632904, 50.82996368408203, 63.254221603274345, 13.9914895221591, 2.030398012138903, 0.4894508753204718, 0.5267632997129112, 0.7176307984627783, 0.6186357792466879, 0.4247382399626076, 0.8281308284495026, 1.4069129806011915, 1.4303242368623614, 1.1646638670936227, 2.2696709353476763, 6.68640336021781, 5.043485518544912, 12.740535847842693, 6.605232115834951, 4.086754806339741, 4.070963328704238, 1.8206662475131452, 1.4861642592586577, 3.6341874534264207, 11.534360870718956, 19.213190227746964, 28.25285006314516, 42.92065009474754, 62.458152920007706, 80.07546678185463, 84.82663303613663, 83.85788261890411, 72.72397845983505, 55.82060068845749, 31.740527115762234, 14.22792138531804, 0.618121144361794, 4.0629747323691845, 8.00893284380436, 14.551284983754158, 14.383961912244558, 17.38675933331251, 19.99722495675087, 21.214862018823624, 29.764274060726166, 13.494625333696604, 15.903128944337368, 20.387642607092857, 14.73676823079586, 2.2850631969049573, 3.7660897755995393, 18.842588514089584, 33.89559477567673, 55.01418896019459, 57.96019747853279, 61.086620315909386, 61.669509038329124, 69.56216052174568, 71.10371500253677, 75.03215700387955, 77.11763709783554, 75.47743991017342, 79.31572794914246, 77.87920743227005, 80.42691752314568, 78.85333076119423, 75.80754339694977, 74.87128123641014, 70.88752940297127, 70.76207533478737, 72.7596965432167, 71.42197832465172, 66.33839830756187, 60.732901096343994, 55.24839699268341, 45.76872646808624, 38.11772681772709, 21.425984390079975, 8.752936720848083, 1.3060977403074503, 0.20109939971007407, 0.18389609002042562, 0.3124972205841914, 0.28532850032206625, 0.25371375144459307, 0.1590320054674521, 0.34737308509647846, 0.2092714252648875, 0.33894662163220346, 0.9424288140144199, 0.9813421103172004, 2.0308095775544643, 26.147248148918152, 64.45784121751785, 84.84782829880714, 76.9845150411129, 101.18132025003433, 82.10446670651436, 40.97800433635712, 43.004534393548965, 51.504902467131615, 70.59592545032501, 78.00617381930351, 96.78943231701851, 25.05668006837368, 0.34069559653289616, 0.21207699581282213, 0.11999495603959076, 0.16754408308770508, 0.17186111159389839, 0.106939502293244, 0.16198992409044877, 0.13761936774244532, 0.1594861107878387, 0.16787528875283897, 0.1751997519750148, 0.22120694105979055, 0.22859024174977094, 0.20442561653908342, 0.3847908944590017, 0.2687575598247349, 0.3297376079717651, 0.12731541908578947, 0.15442246687598526, 0.13299434795044363, 0.11873447016114369, 0.09347886560135521, 0.1764020905829966, 0.13814338337397203, 0.25376602832693607, 0.13805668568238616, 0.1386646827450022, 0.1332962090964429, 0.11949424384511076, 0.1186747124302201, 0.17557784653035924], [0.07609756663441658, 0.059920639760093763, 0.10265680553857237, 0.06926350717549212, 0.16173702984815463, 0.019945357962569688, 0.05447984753118362, 0.045279420519364066, 0.09794135505217128, 0.10369173047365621, 0.04153143374423962, 0.060449698285083286, 0.0739175449416507, 0.07450881399563514, 0.0497801602614345, 0.06078156075091101, 0.04434394708368927, 0.011528031263878802, 0.04612414042640012, 0.10973395546898246, 0.026774289181048516, 0.086583400843665, 0.04831598824239336, 0.11536399164469913, 0.0873348476307001, 0.003814564611275273, 0.12250198284164071, 0.23486449179472402, 24.00368247181177, 84.8421362042427, 86.23783931136131, 88.00790593028069, 70.20396128296852, 55.90098537504673, 43.16443741321564, 32.76901222765446, 64.73911732435226, 75.20200788974762, 23.41440249234438, 27.428417801856995, 41.762563437223434, 41.00782133638859, 4.916351940482855, 0.95662004314363, 0.04009341872006189, 0.3768782940460369, 0.3225246153306216, 0.5708242510445416, 0.6394568807445467, 2.4295145832002163, 2.5929305143654346, 10.075679942965508, 6.394306384027004, 7.381336195394397, 8.439926616847515, 1.2763493740931153, 2.1275492990389466, 1.1248975759372115, 1.7139811534434557, 0.9298163407947868, 9.23024145886302, 28.78810454159975, 51.58443599939346, 71.94115206599236, 81.82730197906494, 78.88017252087593, 74.95401039719582, 76.10899642109871, 83.95231515169144, 80.51956415176392, 84.44071814417839, 77.74725571274757, 82.42390796542168, 92.96773418784142, 82.48460590839386, 80.19550994038582, 66.58716335892677, 36.480755656957626, 15.692185163497925, 2.6482593454420567, 3.0593224754557014, 2.556567178107798, 11.886130794882774, 16.03706795722246, 11.600265484303236, 6.14726691506803, 4.903757991269231, 6.091910060495138, 2.464954094029963, 0.193604925298132, 3.1927903136238456, 17.48586941510439, 27.547288723289967, 41.83094456791878, 52.323317751288414, 56.64439268410206, 60.8343518525362, 63.952430337667465, 63.772137612104416, 65.44018730521202, 68.5503888130188, 67.29235231876373, 69.01217043399811, 75.04158809781075, 71.09051451086998, 67.15330258011818, 70.14363572001457, 67.2090607881546, 66.92759469151497, 57.25266024470329, 53.42800587415695, 49.46736440062523, 49.431406930089, 49.55243803560734, 49.345926716923714, 46.65283262729645, 41.74197234213352, 31.2140254676342, 23.245828337967396, 13.653728496283293, 3.9540827879682183, 0.6983060447964817, 0.12227890809299424, 0.05620965275738854, 0.10180983692407608, 0.053124793485039845, 0.07544263615272939, 0.022420732166210655, 0.07150909761548974, 0.4001135128783062, 0.18992295255884528, 0.13596130593214184, 0.12985353445401415, 5.199043471366167, 51.18257336318493, 57.402471005916595, 15.877322629094124, 60.22030860185623, 72.96861693263054, 26.72248788177967, 34.373213946819305, 43.38862918317318, 52.29804910719395, 66.37857735157013, 67.51043021678925, 25.325261056423187, 0.3786829300224781, 0.05756276979809627, 0.03303815101389773, 0.04393787727167364, 0.04487697238801047, 0.05636693611450028, 0.0993933150311932, 0.01169030741948518, 0.05735686463594902, 0.10617884545354173, 0.06448947155149654, 0.1405577827244997, 0.07285104162292555, 0.07168460069806315, 0.03308355560875498, 0.05446499715617392, 0.012027479024254717, 0.01424688742190483, 0.1069160875340458, 0.06955662582186051, 0.11123785836389288, 0.12958064675331116, 0.08998893099487759, 0.049973241111729294, 0.0337941842735745, 0.0159944309052662, 0.02746540863881819, 0.02803164690703852, 0.04173087108938489, 0.028783379420929123, 0.03420631001063157, 0.07569660650915466, 0.01214203972267569, 0.038167964812600985, 0.0166460829495918, 0.039274558948818594, 0.05685727679519914, 0.022137777232273947, 0.07306904008146375, 0.07171777469920926, 0.02943357128970092, 0.08242579307989217, 0.048198205695371144, 0.0368052332487423, 0.04142971498367842, 0.07075982532114722, 0.0620053474267479, 0.02844292474037502, 0.04951218557835091, 0.053511148144025356, 0.029666132541024126, 0.08315080456668511, 0.06101963059336413, 0.09286119835451245, 0.10923820824245922, 0.06695721647702157, 0.005827651548315771, 0.10870901242014952, 35.15297390520573, 100.72210729122162, 95.9641546010971, 109.79336053133011, 97.90452048182487, 72.5375908613205, 63.437994942069054, 35.04852890968323, 36.31696544587612, 79.43519353866577, 33.162070736289024, 28.01115643233061, 40.93464486300945, 38.50983917713165, 2.803960503078997, 0.8623814780730754, 0.24529606016585603, 0.2958448516437784, 0.19397907162783667, 0.5989753373432904, 1.0009818314574659, 1.9706711545586586, 4.947173511609435, 6.8125090934336185, 5.130444802343845, 2.758865235373378, 2.6661055628210306, 1.1900611105374992, 0.5192423157859594, 1.0257337032817304, 1.9399745017290115, 2.265624152496457, 14.06815230846405, 40.5248748511076, 64.38980206847191, 84.47630703449249, 94.87602218985558, 92.11915612220764, 87.51971572637558, 90.66248148679733, 94.48255330324173, 87.12397456169128, 90.52223101258278, 85.93729823827744, 89.07089129090309, 100.57731226086617, 92.6573820412159, 93.37249606847763, 83.9314466714859, 53.854426592588425, 25.03437526524067, 5.269981389865279, 3.3955400716513395, 1.9552476634271443, 7.728558238595724, 17.37522315233946, 11.794486362487078, 12.366009894758463, 5.353658124804497, 8.296399768441916, 2.0228843903169036, 0.22061328229028732, 5.842894222587347, 20.68340353667736, 35.375987738370895, 49.95005249977112, 61.605220288038254, 66.10507562756538, 68.15186619758606, 68.71411442756653, 69.46880713105202, 71.44967123866081, 73.97021278738976, 72.81949773430824, 74.18431609869003, 80.31712621450424, 77.8445152938366, 74.75696057081223, 77.60439857840538, 76.19085922837257, 80.55829927325249, 73.86776268482208, 67.13658347725868, 62.249243929982185, 61.20631389319897, 56.87704659998417, 57.54145994782448, 57.99671731889248, 49.909626469016075, 41.70566149055958, 33.6800779402256, 19.97691884636879, 8.11341393738985, 1.990582204889506, 0.20650742982979864, 0.1403670062427409, 0.05828539528010879, 0.1708823672379367, 0.038822932401672006, 0.02493155134288827, 0.09696620269096456, 0.47670817002654076, 0.3749545878963545, 0.0880945025710389, 0.2702488610520959, 3.7209997326135635, 53.93506586551666, 55.53989835083485, 12.496497742831707, 64.6603475511074, 45.30608229339123, 20.328546278178692, 57.2581547498703, 66.58797651529312, 81.64013162255287, 77.58191138505936, 82.5118200480938, 45.760564506053925, 1.4085846533998847, 0.14638238033512607, 0.1783012761734426, 0.03514580588671379, 0.08597213833127171, 0.03241729624278378, 0.028408294274413493, 0.03910930121492129, 0.01937765580805717, 0.0542934794066241, 0.06429479137295857, 0.15033596428111196, 0.00735475444344047, 0.030727526172995567, 0.05145520241057966, 0.03201534163963515, 0.01741753803798929, 0.037191491428529844, 0.018522243408369832, 0.0384451198624447, 0.07780266576446593, 0.11869546287925914, 0.04502005103859119, 0.013306033415574348, 0.03702291629451793, 0.03157946717692539, 0.027287519551464356, 0.03187987000274006, 0.02030154431849951, 0.038185052762855776, 0.26953185733873397, 0.20823792525334284, 0.25526219804305583, 0.21386055479524657, 0.23782005038810894, 0.1676927352673374, 0.17452868720283732, 0.22697878681356087, 0.24612772569525987, 0.1491752007859759, 0.13081753975711763, 0.17904857435496524, 0.14463610685197636, 0.13918084645411, 0.12495135219069198, 0.17561683896929026, 0.13846468878909945, 0.12937847088323906, 0.18128444266039878, 0.2126715748454444, 0.18714427744271234, 0.3452171164099127, 0.14246642327634618, 0.26537066500168294, 0.2810611214954406, 0.23763518140185624, 0.18387263815384358, 0.4560047434642911, 45.61486132442951, 117.61170700192451, 107.60688945651054, 112.19973340630531, 92.35604301095009, 73.38793203234673, 60.85871994495392, 54.29449997842312, 93.08559626340866, 101.28861889243126, 38.305486142635345, 42.30239287018776, 56.94645747542381, 61.79963305592537, 9.323453307151794, 1.5243510226719081, 0.2954107546247542, 0.6964943732600659, 0.4588092304766178, 0.9835736593231559, 0.7104604050982744, 2.131137731485069, 4.019049564376473, 12.797431144863367, 11.22084729373455, 14.511391874402761, 21.436078548431396, 6.9802401680499315, 7.240061676129699, 4.580522160977125, 5.362139269709587, 1.234522880986333, 11.386041529476643, 39.893998503685, 68.0900739133358, 93.41050922870636, 105.35018295049667, 105.43138459324837, 101.6978645324707, 101.917644739151, 104.2043924331665, 94.70193833112717, 97.76014342904091, 91.6853865981102, 94.64064761996269, 104.04972553253174, 98.17312806844711, 94.971404671669, 87.47936949133873, 54.54523332417011, 24.97886024415493, 2.9031886160373688, 5.3362412843853235, 12.6230832003057, 21.849836446344852, 30.635717399418354, 19.877884760499, 15.605974439531565, 10.538434311747551, 14.44515097886324, 8.044782970100641, 0.6361293280497193, 6.3645820040255785, 23.117019049823284, 41.87724508345127, 61.09799310564995, 73.00160676240921, 79.48782071471214, 83.52749034762383, 82.7693398296833, 81.8504199385643, 82.29055792093277, 81.99665889143944, 82.61038675904274, 83.17961901426315, 89.97544035315514, 86.07149943709373, 81.69997841119766, 85.14709264039993, 83.25474098324776, 87.87230640649796, 79.22626554965973, 75.17716482281685, 72.02559873461723, 71.70516192913055, 66.81292444467545, 67.33136862516403, 64.33681011199951, 57.10518255829811, 45.363387018442154, 33.540880009531975, 19.014090411365032, 6.456173239275813, 1.0919983475469053, 0.20501743478234857, 0.19782682531513274, 0.37217456207145005, 0.24297671508975327, 0.12866648408817127, 0.11606444546487182, 0.2468427552958019, 0.7709988160058856, 0.559042152017355, 0.253621784504503, 0.5109434423502535, 10.465131495147943, 66.91442459821701, 75.16198843717575, 22.74005077779293, 92.36288264393806, 99.10311296582222, 39.981678798794746, 46.524502113461494, 57.538739293813705, 74.99382466077805, 82.94475361704826, 98.36513936519623, 46.93461410701275, 1.2715599685907364, 0.31059981614816934, 0.1933312657638453, 0.2570042264414951, 0.14396150945685804, 0.1549617707496509, 0.24966388125903904, 0.2951593743637204, 0.2161980528035201, 0.18849786574719474, 0.18701064633205533, 0.2109910556464456, 0.2070010470924899, 0.15082336234627292, 0.12659486790653318, 0.1910603087162599, 0.10412620598799549, 0.13452375103952363, 0.21221712813712656, 0.1696380676003173, 0.3193733672378585, 0.25959690450690687, 0.17386804218403995, 0.14106337825069204, 0.06627739436225966, 0.1169443951221183, 0.1548454910516739, 0.0990722471033223, 0.20274386537494138, 0.1724515642854385], [0.07695620923186652, 0.02908454480348155, 0.049458031062386, 0.0221067146412679, 0.061269708385225385, 0.04437555886397604, 0.022070434752095025, 0.03754991164896637, 0.04461608150450047, 0.02867403509299038, 0.06913812132552266, 0.039784024775144644, 0.0704830265021883, 0.024932820415415335, 0.04512350642471574, 0.1520490340772085, 0.051563355591497384, 0.05599357646133285, 0.05888397077796981, 0.03654437947261613, 0.04878573432506528, 0.09352218476124108, 0.07988525088876486, 0.08590272525907494, 0.10204782141954638, 0.10332176985684782, 0.21357326942961663, 30.951681844890118, 87.58128002285957, 89.48225721716881, 79.01696518063545, 64.40098866820335, 57.38787978887558, 43.966661766171455, 40.1800699532032, 57.75034233927727, 81.21213778853416, 36.779925003647804, 30.797953493893147, 63.15942049026489, 33.948149755597115, 2.903006700798869, 0.1907697579008527, 0.14217612479114905, 0.2261808147886768, 0.3441798611311242, 0.21145899459952489, 0.5469215742778033, 0.8905684249475598, 4.313378920778632, 6.295067109167576, 9.418517556041479, 2.1564773842692375, 0.7891892711631954, 0.37026887526735663, 1.2017400213517249, 1.2423111568205059, 6.666499078273773, 27.235785238444805, 53.45475643873215, 75.15887260437012, 73.25503796339035, 68.17267388105392, 59.28549416363239, 61.993969827890396, 61.61206752061844, 66.68879270553589, 70.15759617090225, 71.17836579680443, 72.18388304114342, 74.71887141466141, 75.14054238796234, 74.8396897315979, 73.70430305600166, 74.53228622674942, 77.81996101140976, 84.5558899641037, 80.97868591547012, 74.09672319889069, 78.24616134166718, 36.954662427306175, 5.702613824978471, 0.6593717308714986, 6.863812515512109, 11.916278377175331, 14.479535333812237, 11.3557125069201, 7.011335324496031, 4.173544999212027, 3.0591206112876534, 21.713262274861336, 35.87491236627102, 48.00250880420208, 56.03736765682697, 52.543614730238914, 51.53621658682823, 46.74655459821224, 55.87722525000572, 62.86153927445412, 63.48335690796375, 64.29779380559921, 66.74632161855698, 66.82739406824112, 67.64351427555084, 72.5406838953495, 68.79385694861412, 67.67689168453217, 71.15571901202202, 69.44471642374992, 68.70434895157814, 70.86272433400154, 68.50765630602837, 58.56461204588413, 47.792353481054306, 46.25839479267597, 44.556196331977844, 49.14008416235447, 48.950345143675804, 40.58425426483154, 33.77558581531048, 21.25854827463627, 9.3976547755301, 3.075380651280284, 0.5461349571123719, 0.08094260352663696, 0.0832629950309638, 0.1766493741888553, 0.09140962429228239, 0.04289361611881759, 0.1790638329111971, 0.09320004814071581, 0.12821116164559498, 0.10371282973210327, 0.2853046328527853, 10.815359652042389, 84.90495443344116, 96.18280246853828, 28.449818193912506, 27.237481847405434, 55.0370067358017, 20.00270426273346, 33.57751004397869, 33.95966313779354, 54.62502144277096, 62.43565432727337, 71.31295457482338, 33.98948773741722, 0.22977036045631394, 0.07630521213286556, 0.07909386171377264, 0.07835716882254928, 0.09950703431968577, 0.04270889927283861, 0.03616605114075355, 0.046883442846592516, 0.06751240231096745, 0.08432472634012811, 0.06300655659288168, 0.019633923111541662, 0.042697110256995074, 0.03368804602359887, 0.09948702601832338, 0.01880067866295576, 0.035118569066980854, 0.07652833141037263, 0.02156819373340113, 0.08379605002119206, 0.03959048008255195, 0.13715769251575693, 0.050161813414888456, 0.011429202240833547, 0.09878691358608194, 0.09277795164962299, 0.011183323149452917, 0.07617751820362173, 0.059929215276497416, 0.051141452058800496, 0.051381098965066485, 0.038537060827366076, 0.10080007821670733, 0.03431298631767277, 0.05974089159280993, 0.03877491915773135, 0.076585172500927, 0.020495721691986546, 0.06176203802169766, 0.031290949846152216, 0.013681592608918436, 0.0290135342584108, 0.08174039743607864, 0.02739627758273855, 0.02122798210621113, 0.11276835983153433, 0.08350097210495733, 0.013218593576311832, 0.03494732220133301, 0.05197511025471613, 0.05219560604018625, 0.048896967418841086, 0.040445348859066144, 0.21460388990817592, 0.074758093978744, 0.3352777106920257, 44.49170999228954, 102.62829780578613, 102.5540953874588, 110.63662648200989, 89.78162795305252, 83.72260227799416, 69.77975204586983, 35.576825961470604, 25.137159749865532, 73.58379632234573, 43.44621129333973, 30.350132323801517, 61.745117381215096, 28.74538153409958, 1.3110232260078192, 0.4105272103333846, 0.08249482023529708, 0.12591572856763378, 0.221757659164723, 0.286667364416644, 0.11779917113017291, 0.49209897697437555, 1.7310560122132301, 3.3239027531817555, 2.3378029419109225, 0.8971448033116758, 0.42453373374883085, 0.6588341190945357, 1.708894413895905, 1.928639116231352, 10.629409030079842, 39.033063501119614, 68.74148815870285, 91.56881645321846, 88.95390316843987, 81.4184059202671, 73.85597571730614, 71.57086953520775, 71.09200403094292, 74.47402775287628, 80.27626320719719, 79.73959520459175, 79.43203210830688, 79.87028539180756, 83.62712100148201, 82.38653317093849, 81.07232049107552, 82.60782569646835, 85.18205836415291, 89.6229712665081, 89.19902041554451, 85.99962249398232, 92.70655900239944, 53.444189205765724, 13.653025534003973, 0.8734099112916738, 2.5830555567517877, 12.197321746498346, 13.65242326632142, 9.064157120883465, 1.5370803396217525, 1.5443115890957415, 4.380407799035311, 26.428412161767483, 45.94007067382336, 61.55375584959984, 68.2382583618164, 62.51729674637318, 64.24363911151886, 57.63222947716713, 69.52981665730476, 75.25149643421173, 75.55821597576141, 74.91547286510468, 77.68026530742645, 75.17383620142937, 74.39522758126259, 76.05928748846054, 70.12258484959602, 70.85374161601067, 71.98352739214897, 71.76481112837791, 69.98893082141876, 77.03404918313026, 78.53776529431343, 70.19521415233612, 60.57954892516136, 57.10835158824921, 52.965179309248924, 57.603328227996826, 58.280774876475334, 48.89958746731281, 42.27849215269089, 29.081767983734608, 14.645441081374884, 5.534190237522125, 1.1842153617180884, 0.1027400596649386, 0.049296402430627495, 0.09089803221286274, 0.12063237925758585, 0.03951962724386249, 0.14399775594938546, 0.05091659986646846, 0.027526043959369417, 0.10146609638468362, 0.3568055742653087, 6.940364157781005, 80.84538906812668, 93.07635515928268, 30.746304765343666, 28.305258750915527, 27.840063013136387, 17.945599146187305, 51.44163206219673, 53.07258054614067, 78.39323624968529, 73.51583316922188, 81.2730485200882, 53.30523446202278, 2.8517419891431928, 0.08328428724780679, 0.12836776964832097, 0.032285171691910364, 0.020261629761080258, 0.08071087533608079, 0.048496634408365935, 0.023514613312727306, 0.04012409539427608, 0.13198235537856817, 0.06465850310632959, 0.0988861832593102, 0.05055650239228271, 0.015215779767459026, 0.047105519406613894, 0.006444126256610616, 0.037153842276893556, 0.05630143787129782, 0.03270439607149456, 0.05104189294797834, 0.045873955023125745, 0.06593833677470684, 0.013606080010504229, 0.07936754351248965, 0.06369776325300336, 0.0735770253231749, 0.04364267319033388, 0.0657514639897272, 0.01147742050306988, 0.20855958689935505, 0.19481521972920746, 0.1179633045103401, 0.26385424949694425, 0.1773728642729111, 0.09820121063967235, 0.15308948059100658, 0.21918815094977617, 0.14327462209621444, 0.1619997649686411, 0.12832889595301822, 0.1300571352476254, 0.16246289480477571, 0.4156265367055312, 0.1651165180373937, 0.3876855969429016, 0.20477316429605708, 0.13396424590609968, 0.1796916453167796, 0.10965379609842785, 0.14636011590482667, 0.21432364010252059, 0.12938084575580433, 0.1484921874362044, 0.29745828069280833, 0.30740035814233124, 0.6334086740389466, 54.600835740566254, 119.12018805742264, 110.41997730731964, 104.16879594326019, 85.4028645157814, 72.62199193239212, 62.21578672528267, 63.93107548356056, 84.29122656583786, 108.63057732582092, 55.064034685492516, 47.25722439587116, 86.66296809911728, 53.2637444883585, 4.755803430452943, 0.8519212331157178, 0.28774701117072254, 0.4829537286423147, 0.4201433068374172, 0.3945940121775493, 0.4474275349639356, 1.2235371954739094, 7.438730215653777, 11.274931691586971, 21.64553090929985, 5.326452534645796, 3.665430089458823, 3.9695130474865437, 2.7601296175271273, 1.340664247982204, 7.912923870608211, 38.7037655711174, 76.43140152096748, 105.7311961054802, 104.11971777677536, 94.60356920957565, 82.02008083462715, 79.43596109747887, 73.68759155273438, 76.62050977349281, 79.37488317489624, 79.67791691422462, 79.60087224841118, 78.57288300991058, 79.92823228240013, 80.1325549185276, 78.98914307355881, 77.04031124711037, 86.6899086534977, 88.17328825592995, 95.12870103120804, 89.28057923913002, 104.12398874759674, 59.83516126871109, 9.793049208819866, 2.3778169322758913, 14.163233656436205, 21.365351043641567, 29.44549396634102, 26.532116197049618, 16.585291139781475, 8.038712795823812, 3.0441781505942345, 28.135915137827396, 51.50306336581707, 74.72515627741814, 76.59831896424294, 71.09423071146011, 70.73785543441772, 64.453334659338, 71.79970845580101, 79.87084776163101, 80.96721053123474, 82.04354837536812, 80.24459570646286, 81.03849470615387, 78.66383492946625, 83.73255014419556, 79.05638426542282, 80.13446241617203, 80.80413848161697, 83.7409932911396, 77.4383094906807, 81.49435624480247, 83.2849569618702, 76.26071467995644, 68.4618079662323, 66.02597147226334, 63.948691338300705, 66.31384402513504, 63.19102339446545, 55.5027249455452, 46.14299118518829, 29.50116477906704, 14.467565976083279, 5.459271082654595, 0.9250731265638024, 0.21264157723635435, 0.4201385274063796, 0.3110474202549085, 0.2199631609255448, 0.2733923908090219, 0.5115893483161926, 0.376784605323337, 0.3814720397349447, 0.2622089080978185, 0.8218099270015955, 14.51805291697383, 95.68767383694649, 125.02370327711105, 38.74040700495243, 44.336267933249474, 78.16176027059555, 30.30301295220852, 43.91268566250801, 45.42611785233021, 73.89167100191116, 80.05028933286667, 96.43684163689613, 59.16662134230137, 2.9849436040967703, 0.2354699358693324, 0.25371909490786493, 0.21536447253311053, 0.19322360982187092, 0.15311728144297376, 0.1063583412906155, 0.1625365306972526, 0.2915152511559427, 0.23947830515680835, 0.1546563918236643, 0.14835168403806165, 0.12505707854870707, 0.12597998371347785, 0.16577183443587273, 0.04568644399114419, 0.1431526427040808, 0.19662010803585872, 0.19347783992998302, 0.16323688061675057, 0.17026797286234796, 0.20669871097197756, 0.13686586520634592, 0.18668910342967138, 0.24129018449457362, 0.20932088198605925, 0.20176709513179958, 0.16101244138553739, 0.18033686850685626], [0.11695753113599494, 0.07682656345423311, 0.13083674653898925, 0.054015804853406735, 0.0196762533596484, 0.030174945277394727, 0.05606782462564297, 0.024014590781007428, 0.058237367193214595, 0.08568102348363027, 0.04911958203592803, 0.05228909809375182, 0.023883681496954523, 0.04180786148936022, 0.08579578177887015, 0.02361313898290973, 0.03666046992293559, 0.07056612477754243, 0.06962799074244685, 0.016858758353919256, 0.0498912634793669, 0.029347721501835622, 0.043161475769011304, 0.07552473252872005, 0.06593136058654636, 0.8841744961682707, 38.381341472268105, 89.19514462351799, 84.68698292970657, 79.29918363690376, 59.11670342087746, 46.54024846851826, 37.04796642065048, 34.03546907007694, 62.46322564780712, 81.19216606020927, 47.07386143505573, 49.631105214357376, 69.38890501856804, 24.20158725231886, 0.5807019397616386, 0.047367363949888386, 0.24436721781967208, 0.5576965492218733, 0.28591271897312254, 0.32965614984277636, 0.4387378762476146, 0.3798433521296829, 1.743791385088116, 0.7212894677650183, 0.3067121794447303, 0.6460409180726856, 0.1367247532471083, 0.547367159742862, 3.0607269750908017, 18.192621991038322, 44.40999537706375, 72.98564001917839, 77.89766684174538, 74.56643119454384, 66.37014180421829, 70.26932537555695, 76.68285682797432, 85.39562970399857, 86.66611433029175, 89.10926163196564, 85.28504803776741, 83.03032502532005, 84.85280603170395, 84.41264525055885, 89.07298117876053, 93.59514132142067, 95.91920301318169, 90.92118680477142, 93.91557812690735, 94.1384893655777, 88.45549151301384, 82.57757931947708, 78.01897153258324, 69.76582199335098, 74.27303373813629, 80.74882864952087, 38.19080449640751, 7.598674558103085, 3.854967006482184, 5.699469968676567, 4.550814405083656, 1.9759174855425954, 0.9223622095305473, 8.920101150870323, 57.46625058352947, 45.73832809925079, 62.76032030582428, 69.60550859570503, 76.13013088703156, 83.45125883817673, 84.59384232759476, 92.13312417268753, 87.16465517878532, 78.87771785259247, 78.69554802775383, 79.46699783205986, 73.52046892046928, 71.12823128700256, 66.0311771929264, 56.99625380337238, 58.11870217323303, 59.337057396769524, 54.19062115252018, 60.37165068089962, 73.42911422252655, 74.87929880619049, 75.22066488862038, 67.12380096316338, 61.40206798911095, 51.95353299379349, 51.90924257040024, 48.71896415948868, 39.169229194521904, 39.879555478692055, 36.68458431959152, 26.174253299832344, 15.60504823923111, 6.186969084665179, 1.3846739614382386, 0.1394401231664233, 0.22908338403794914, 0.15313841780880466, 0.1619019647478126, 0.04534883359156083, 0.01350354488749872, 0.08161412843037397, 0.1211228795000352, 0.17563773784786463, 0.8597901952452958, 6.113579347729683, 77.02066630125046, 82.55028158426285, 47.05221399664879, 38.906298503279686, 66.1886103451252, 22.450975589454174, 30.591736659407616, 32.212490290403366, 53.16754885017872, 64.38604786992073, 74.83569234609604, 44.624360874295235, 2.1157200587913394, 0.057454523848718964, 0.03093907165748533, 0.07196640159236267, 0.06501968411612324, 0.03118754641036503, 0.0900865976291243, 0.02553946862462908, 0.035402410867391154, 0.11639599251793697, 0.06534920510603115, 0.02233923878520727, 0.008162095618899912, 0.03206087611033581, 0.04493945751164574, 0.00905122842596029, 0.0952804513508454, 0.012231140117364703, 0.0651095285138581, 0.08806663492578082, 0.039416045692632906, 0.051356092299101874, 0.1024522325315047, 0.1404565537814051, 0.013755621839663945, 0.09261120590963401, 0.07884537582867779, 0.07279178855242208, 0.06826431665103883, 0.05244844462140463, 0.068079388292972, 0.07628975319676101, 0.01597111262526596, 0.0296212771354476, 0.044370538234943524, 0.037915738503215834, 0.09854726667981595, 0.048055000879685394, 0.023656255907553714, 0.04985631203453522, 0.016775097901700065, 0.015490206496906467, 0.03417870211706031, 0.010361710010329261, 0.023898611652839463, 0.08434192190179601, 0.046812946238787845, 0.02607632526633097, 0.026658963142836, 0.054880607276572846, 0.058493701289989986, 0.013485777872119797, 0.028569672431331128, 3.3239474007859826, 55.87067820131779, 102.53597036004066, 94.46585699915886, 103.92662733793259, 79.78007063269615, 75.20415097475052, 56.18492893874645, 31.42248798161745, 31.539827585220337, 66.63532957434654, 52.429195269942284, 51.997211650013924, 66.68329060077667, 19.685255996882915, 0.2776151814032346, 0.025153008209599648, 0.11296019758447073, 0.5334305763244629, 0.18695029488299042, 0.5631732428446412, 0.13543877459596843, 0.29602362017612904, 0.7314998761285096, 0.3827409935183823, 0.771238321904093, 0.23824044736102223, 0.7229812676087022, 1.4371559140272439, 6.819685958325863, 29.10485364496708, 61.02149561047554, 88.96986991167068, 92.64652222394943, 86.36839270591736, 79.19584438204765, 83.54378387331963, 89.59376603364944, 96.80352196097374, 97.03005060553551, 97.62686178088188, 94.23835560679436, 91.91766053438187, 94.7818024456501, 92.55291044712067, 95.63835248351097, 99.15168195962906, 99.55486312508583, 94.92906734347343, 95.52591651678085, 101.0821683704853, 97.6819360256195, 91.82471752166748, 83.98281991481781, 78.34208339452744, 90.6134033203125, 96.3700108230114, 57.6146250218153, 14.165859315544367, 1.8245828873477876, 1.6328774741850793, 5.794982593506575, 2.57321004755795, 2.38882755395025, 14.981883578002453, 64.9950335919857, 59.8450293391943, 72.70882487297058, 79.38857764005661, 85.4435983300209, 94.68011230230331, 94.57464516162872, 99.83493089675903, 93.14130127429962, 87.85898432135582, 87.55376189947128, 88.06255459785461, 83.66451859474182, 81.77269890904427, 78.40709030628204, 68.30324247479439, 69.23509687185287, 71.59876763820648, 67.86597713828087, 70.91960728168488, 77.593614757061, 75.76535806059837, 74.29480656981468, 77.23746746778488, 72.74225547909737, 66.06370344758034, 67.35382542014122, 60.41087217628956, 55.424354150891304, 51.546373441815376, 44.16763678193092, 35.77094994485378, 23.21244142949581, 9.783045295625925, 2.8299057483673096, 0.36585297784768045, 0.17218450986547396, 0.060460014137788676, 0.36553385434672236, 0.14675652666483074, 0.12104159206501208, 0.0312258857593406, 0.09722122689709067, 0.08088289774605073, 0.9720118890982121, 2.7012667385861278, 77.65435829758644, 93.99917364120483, 48.97464103996754, 34.00086432695389, 26.061045974493027, 19.656504839658737, 49.064335227012634, 51.6330011934042, 76.29479125142097, 84.68214958906174, 81.13014578819275, 65.47124683856964, 5.449880361557007, 0.10102868196554482, 0.0953570038836915, 0.04292232610168867, 0.07609305437654257, 0.05085448581667151, 0.03226612818252761, 0.038655218158965, 0.04397481767227873, 0.07782171669532545, 0.03455057376413606, 0.0732657611661125, 0.028938840805494692, 0.03143208406982012, 0.05889872096304316, 0.043159731721971184, 0.03692920530738775, 0.05165990529349074, 0.054437315047835, 0.06730149878421798, 0.06905140879098326, 0.07110341743100435, 0.040824003735906444, 0.042125159307033755, 0.11457464337581769, 0.07218467464554124, 0.06489095860160887, 0.028828403665102087, 0.36277650855481625, 0.17008954571792856, 0.1840407494455576, 0.18082748749293387, 0.06748343628714792, 0.16430928400950506, 0.12316723659751005, 0.11817474980489351, 0.27043840556871146, 0.19764805678278208, 0.1577695380547084, 0.21855135855730623, 0.0965844419260975, 0.19480628427118063, 0.23041406966513023, 0.11189102253410965, 0.1679902771138586, 0.12654276913963258, 0.15321782761020586, 0.17358988523483276, 0.23283638030989096, 0.1304149246425368, 0.18023696058662608, 0.1772017843904905, 0.28701163188088685, 4.683045409619808, 71.07613608241081, 118.23780700564384, 104.86512377858162, 102.59192615747452, 75.47459006309509, 62.43148975074291, 53.84395815432072, 54.276025369763374, 86.68877631425858, 114.33336451649666, 64.43109825253487, 67.41108074784279, 92.5520820915699, 37.09808573126793, 1.3098489702679217, 0.2527195407310501, 0.3425672632874921, 0.8021890267264098, 0.5762423446867615, 0.46796608599834144, 0.40378747042268515, 1.5136551903560758, 4.0722286608070135, 1.780971558764577, 1.8893760605715215, 1.0788235045038164, 0.7193300197832286, 1.04873470030725, 4.602484982460737, 25.77695421874523, 65.79579502344131, 102.97028705477715, 105.6697230041027, 96.49199187755585, 88.70796516537666, 90.4189145565033, 92.1192929148674, 101.57750219106674, 99.4849544763565, 103.77281159162521, 98.00582304596901, 96.4399878680706, 98.87521639466286, 95.05550175905228, 97.5750021636486, 99.37860578298569, 100.55626139044762, 94.4072413444519, 93.92921939492226, 98.56595858931541, 95.96280187368393, 89.7150631248951, 81.20173394680023, 75.75608655810356, 106.47391945123672, 108.57299521565437, 57.481457367539406, 10.453348327428102, 6.514642126858234, 10.32423885539174, 13.555097188800573, 10.045117232948542, 2.4566396651789546, 13.232316859066486, 72.05525234341621, 66.23644217848778, 75.37208676338196, 78.87136459350586, 84.8720633983612, 95.75785607099533, 94.14159759879112, 102.76904225349426, 94.02423709630966, 88.63161966204643, 87.83677831292152, 89.70077589154243, 83.11314538121223, 83.13593655824661, 90.15992805361748, 80.01735270023346, 71.00903168320656, 74.45254370570183, 71.94180563092232, 75.02093240618706, 82.76422530412674, 82.28531420230865, 80.6642147898674, 79.70083728432655, 80.0235615670681, 69.82332050800323, 77.68864765763283, 72.22643315792084, 69.00161460042, 63.49542886018753, 53.503959998488426, 39.74019795656204, 26.803104355931282, 10.730568151921034, 2.727903784252703, 0.42776614311151206, 0.3396687610074878, 0.23500242736190557, 0.42825584183447063, 0.1430044654989615, 0.2288490583305247, 0.26321184646803886, 0.2186702803010121, 0.22579017793759704, 1.4448698563501239, 9.13019947707653, 86.61974921822548, 102.77040258049965, 64.16385099291801, 61.67907312512398, 90.77120885252953, 33.83232057094574, 43.92696909606457, 47.32525214552879, 74.33911979198456, 83.46912547945976, 93.07871863245964, 76.62789657711983, 6.964591657742858, 0.2897832862799987, 0.16841578006278723, 0.19770297571085393, 0.1958441035822034, 0.1639756589429453, 0.20359640009701252, 0.06429091736208647, 0.06961860257433727, 0.1588443311629817, 0.1258627837523818, 0.1568551527452655, 0.06294042381341569, 0.1934860332403332, 0.1739199331495911, 0.10141722596017644, 0.141148769762367, 0.1336642846581526, 0.13001208688365296, 0.18902225245255977, 0.12398636725265533, 0.21197239751927555, 0.13149507605703548, 0.19026356865651906, 0.23033939476590604, 0.2283653264748864, 0.20456134050618857, 0.13443748379359022], [0.07668988953810185, 0.1116304099559784, 0.08635579157271422, 0.03334565619297791, 0.15875236422289163, 0.10544179633143358, 0.006399496742233168, 0.044750744200428016, 0.10141053178813308, 0.10271478211507201, 0.06836643617134541, 0.07089427279424854, 0.06347779068164527, 0.02515723288524896, 0.026748262062028516, 0.04752197928610258, 0.02735101956204744, 0.07723803981207311, 0.06832858663983643, 0.13570167298894376, 0.07179738488048315, 0.03702988877194002, 0.12148159657954238, 0.07090151615557261, 2.644460261799395, 59.05634745955467, 99.07596722245216, 87.10561394691467, 81.93006366491318, 56.66312947869301, 73.01988378167152, 42.39326499402523, 43.81584785878658, 61.01935252547264, 54.0658700466156, 52.717554196715355, 64.23473998904228, 47.56677098572254, 21.67725920677185, 1.540554421953857, 0.41340071707963943, 0.3585957532050088, 0.3049236926017329, 0.3647180856205523, 0.549813040997833, 0.2090726187452674, 0.6591728352941573, 0.7094820763450116, 0.8265669748652726, 1.5165920765139163, 4.3503262382000685, 10.739842504262924, 20.9531282633543, 39.947412237524986, 66.06265470385551, 78.7828977406025, 76.36327117681503, 69.44884300231934, 74.09710317850113, 81.61358624696732, 87.30992138385773, 87.35790520906448, 86.84624746441841, 87.67239153385162, 86.42461448907852, 83.26213538646698, 87.79506415128708, 93.82273390889168, 96.53485357761383, 97.272287607193, 95.05125358700752, 91.5141373872757, 94.40647378563881, 91.31666958332062, 81.52815163135529, 89.84854996204376, 86.63412004709244, 87.86751866340637, 91.89303785562515, 92.04004436731339, 77.58311972022057, 77.81388893723488, 83.55133786797523, 79.83845829963684, 26.52264330536127, 0.5125078896526247, 0.570823538582772, 7.222414948046207, 35.57022571563721, 52.25540779531002, 53.07403206825256, 71.75662636756897, 93.52087810635567, 91.89079597592354, 92.46394202113152, 91.8423941731453, 95.06596639752388, 92.15789124369621, 87.84122407436371, 88.32663282752037, 96.79286733269691, 92.79770091176033, 90.32237693667412, 91.12296357750893, 89.28149878978729, 78.33173274993896, 81.67699724435806, 79.84915852546692, 84.26127657294273, 89.24099296331406, 80.66942811012268, 75.33393681049347, 64.29080218076706, 78.49827781319618, 80.21878749132156, 76.489637196064, 66.18730321526527, 56.951518803834915, 44.57972466945648, 43.20184260606766, 37.581199407577515, 34.71700809895992, 27.01314188539982, 18.940174877643585, 9.29897977039218, 3.3031126437708735, 0.39522976556327194, 0.055997483868850395, 0.09936767382896505, 0.22461807442596182, 0.15395948546938598, 0.06862387235742062, 0.0486355421890039, 0.05914617526286747, 0.5045962985605001, 0.24207577749621123, 8.486279379576445, 76.16903319954872, 93.30703318119049, 50.222748667001724, 49.16119582951069, 68.96927833557129, 30.02718385308981, 32.85103462636471, 35.29025673866272, 41.25653699040413, 52.785247564315796, 75.41950061917305, 57.3485367000103, 4.6156588755548, 0.5739330779761076, 0.04633138516510371, 0.12299384121433832, 0.012385886257106904, 0.03130372591840569, 0.037905537683400325, 0.03459451261733193, 0.10402947445982136, 0.03577337338356301, 0.0712712986569386, 0.032292092218995094, 0.022579830074391793, 0.047821929401834495, 0.012983080432604766, 0.019686901323439088, 0.031117036814976018, 0.09883170219836757, 0.007972251460159896, 0.04017201215901878, 0.030506727962347213, 0.11387056045350619, 0.11787244337028824, 0.0584231861284934, 0.012406620935507817, 0.0530887288186932, 0.11510050695505925, 0.06916117985383607, 0.1196266726765316, 0.057107592074316926, 0.02828307911840966, 0.05988287186482921, 0.04441700039023999, 0.042976591939805076, 0.062376703281188384, 0.045496862367144786, 0.12160492668044753, 0.0056166441208915785, 0.05747682909714058, 0.03170799602230545, 0.020124701659369748, 0.13429157756036147, 0.043934196219197474, 0.015652690453862306, 0.019802416609309148, 0.05632842978229746, 0.16834863054100424, 0.08600577246397734, 0.08916561462683603, 0.08095254830550402, 0.23334150086157024, 7.218036158010364, 81.01509556174278, 107.89362207055092, 100.72007060050964, 104.76486995816231, 79.42502528429031, 96.99571564793587, 50.789416059851646, 23.237774670124054, 33.46200384199619, 54.102815464138985, 59.6078422665596, 63.05194705724716, 48.58231969177723, 16.741048581898212, 0.9150138788390905, 0.3136117185931653, 0.3426124749239534, 0.28764124028384686, 0.17531018354929984, 0.3677659673849121, 0.18379771092440933, 0.5894441425334662, 0.5679064232390374, 2.5339268054813147, 5.84641283378005, 11.477767657488585, 21.085401065647602, 34.55442242324352, 57.0640953630209, 80.50730600953102, 90.04361629486084, 86.3878932595253, 83.82771223783493, 88.3919209241867, 93.31322684884071, 96.24169930815697, 94.92242529988289, 94.0336985886097, 94.29591491818428, 91.18224039673805, 89.53075781464577, 95.33495396375656, 98.43104302883148, 100.54494559764862, 101.85116350650787, 99.42584484815598, 95.76744675636292, 95.74084058403969, 93.0680564045906, 82.97158017754555, 90.11761352419853, 90.69557771086693, 92.47271195054054, 98.47705855965614, 100.93296557664871, 89.05850395560265, 85.35694018006325, 86.52399435639381, 92.8076183795929, 39.90939907729626, 2.75581328663975, 1.407919570337981, 12.261132672429085, 46.66192553937435, 59.92857925593853, 63.69890794157982, 80.74559882283211, 101.19545549154282, 97.07437142729759, 98.21849003434181, 96.01438790559769, 96.24331042170525, 95.23132592439651, 90.25065958499908, 90.17581880092621, 100.50719082355499, 101.30461603403091, 98.01374182105064, 100.42677193880081, 105.64554870128632, 92.39450454711914, 92.07206144928932, 88.89328882098198, 92.16915383934975, 97.35774502158165, 92.14268445968628, 86.74769595265388, 72.62060880661011, 78.65216955542564, 83.27462151646614, 81.85071632266045, 76.83297157287598, 77.05365613102913, 65.93316525220871, 64.89180073142052, 63.29432085156441, 54.09716136753559, 38.9166871458292, 28.429065607488155, 14.78294050320983, 5.206304881721735, 0.5802206718362868, 0.12226246952195652, 0.06902004563016817, 0.2906173118390143, 0.41953243024181575, 0.18115332000888884, 0.08630632000858895, 0.20538410026347265, 0.1496156951179728, 0.18416479200823233, 5.032922560349107, 69.06255573034286, 102.88190379738808, 55.74004501104355, 41.89051777124405, 27.497815378010273, 17.56629589945078, 45.49967810511589, 59.78533834218979, 62.678123116493225, 72.3883044719696, 86.27912789583206, 74.58413064479828, 10.995629578828812, 0.5046484863851219, 0.022071594357839786, 0.02786602737614885, 0.0590101024863543, 0.022622141768806614, 0.022799912112532184, 0.04231987659295555, 0.13126910693245009, 0.036391886678757146, 0.03080697493714979, 0.023155463932198472, 0.010595139574434143, 0.07377503032330424, 0.007227834666991839, 0.05476756334246602, 0.019714336667675525, 0.06912231358001009, 0.009801926571526565, 0.05614849978883285, 0.00994251160591375, 0.02101266465615481, 0.08040917746257037, 0.014013289019203512, 0.012287254830880556, 0.030971351370681077, 0.05462954613904003, 0.2119420436793007, 0.2571507857646793, 0.16234507143963128, 0.14295822969870642, 0.262470084708184, 0.2130709690391086, 0.25661525200121105, 0.17123013763921335, 0.22615308815147728, 0.24685313052032143, 0.18090023280819878, 0.17793208739021793, 0.15563593769911677, 0.19636593729956076, 0.241633546538651, 0.08837021785438992, 0.0849198545620311, 0.14741307502845302, 0.15603314997861162, 0.30039329663850367, 0.2110223297495395, 0.17614193813642487, 0.14433071308303624, 0.3822303662309423, 9.104116726666689, 100.56431695818901, 122.87107318639755, 110.40118351578712, 107.9128946363926, 76.75599530339241, 88.99782121181488, 56.40182889997959, 62.95039750635624, 89.09795343875885, 80.18144309520721, 76.05175629258156, 86.70113325119019, 68.97699192166328, 34.82963785529137, 2.6874478301033378, 0.5547923769336194, 0.5489541089627892, 0.39722522255033255, 0.39944976568222046, 0.6711861281655729, 0.2836031257174909, 4.235917702317238, 2.307876697741449, 2.5815494125708938, 3.095279708504677, 7.419228237122297, 16.07096403837204, 31.946907341480255, 55.642447248101234, 86.87374278903008, 101.71302571892738, 96.6399559378624, 91.27940878272057, 92.37540677189827, 98.04543972015381, 101.21833026409149, 99.94742766022682, 98.2389785349369, 98.38596984744072, 94.14215236902237, 90.47117695212364, 93.88720884919167, 99.1006962954998, 101.6633851826191, 102.33435317873955, 99.43879455327988, 97.10946634411812, 97.0974513888359, 91.94626539945602, 81.79976865649223, 90.10596334934235, 92.19471886754036, 95.57232722640038, 101.25990763306618, 98.74800682067871, 87.98240169882774, 87.95897975564003, 90.71791291236877, 102.53743708133698, 33.218273520469666, 3.1149294041097164, 2.098087342455983, 10.654454436153173, 45.46611450612545, 66.46554708480835, 70.15901729464531, 77.20813304185867, 98.99602711200714, 98.27860280871391, 100.151157528162, 99.73543703556061, 96.8028911948204, 96.81331023573875, 90.16346946358681, 89.14434134960175, 102.22152203321457, 102.75413945317268, 100.32687529921532, 105.20762220025063, 110.02518609166145, 88.45934450626373, 88.94926741719246, 91.5425218641758, 98.85912045836449, 105.19363135099411, 95.17190471291542, 92.45583325624466, 81.01091578602791, 85.87383404374123, 87.86587715148926, 89.86147686839104, 79.45250540971756, 80.675880163908, 73.52919325232506, 73.41383904218674, 71.93893298506737, 60.94800375401974, 44.16596867144108, 31.35065283626318, 16.803779415786266, 5.588222863152623, 0.6052882829681039, 0.24772435252089053, 0.28338368749246, 0.5730579374358058, 0.37427377130370587, 0.35592583240941167, 0.17652632610406727, 0.5875478661619127, 0.501796561293304, 0.5965408554766327, 12.458947207778692, 84.76474955677986, 110.00830739736557, 64.5371961593628, 74.17009726166725, 91.8447196483612, 41.17389142513275, 47.256574630737305, 48.075092509388924, 60.985260754823685, 71.31578162312508, 94.23415303230286, 87.81681418418884, 13.083525393158197, 0.7233275240287185, 0.16928483499214053, 0.2200915673165582, 0.20142414869042113, 0.10507766899536364, 0.10430295587866567, 0.11620117133134045, 0.18967195821460336, 0.15750680293422192, 0.1496861397754401, 0.09738673325045966, 0.1861738896695897, 0.2079626329941675, 0.1464281856897287, 0.13531683973269537, 0.10645217844285071, 0.17864359921077266, 0.13127507379977033, 0.13094483292661607, 0.10087956965435296, 0.2399585340754129, 0.3891538915922865, 0.13889149791793898, 0.18608498037792742, 0.2027621667366475, 0.3198015864472836], [0.02470344668836333, 0.053306649351725355, 0.13446782279061154, 0.05149543794686906, 0.11481400826596655, 0.05644642013066914, 0.0667590853117872, 0.033974233010667376, 0.03851902663882356, 0.08224470162531361, 0.05274440198263619, 0.03700129011122044, 0.030692524633195717, 0.03126418429019395, 0.06338428749586456, 0.02664905918209115, 0.057158451454597525, 0.07113703672075644, 0.0700343017524574, 0.05431589226645883, 0.09325175356934778, 0.009619815591577208, 0.050196297306683846, 7.379232058301568, 69.46480214595795, 90.97811535000801, 83.29786866903305, 86.36403053998947, 55.29079891741276, 46.51178799569607, 41.24413065612316, 57.02384032309055, 77.65378832817078, 58.335537537932396, 39.151351153850555, 46.36052571237087, 55.28187319636345, 21.34338442236185, 1.1202482879161835, 0.25715752446558326, 0.0876099691959098, 0.261296036769636, 0.3244158154120669, 0.16345749143511057, 0.26998492365237325, 0.631391101051122, 0.8764000539667904, 1.8759101768955588, 26.26127053052187, 56.159230917692184, 73.31603229045868, 74.92220610380173, 88.77835258841515, 85.58870494365692, 76.00194856524467, 72.51042991876602, 83.53179931640625, 87.50930428504944, 88.02299112081528, 84.33967396616936, 83.81530210375786, 89.23976182937622, 90.17765030264854, 95.5664375424385, 93.22809621691704, 98.26252207159996, 97.91797935962677, 96.16873562335968, 93.39375972747803, 93.35097402334213, 90.79726785421371, 85.11701345443726, 89.10329595208168, 85.2963562309742, 77.83927157521248, 80.95214053988457, 83.55229541659355, 82.93881073594093, 82.82560721039772, 85.03556102514267, 90.93611240386963, 87.64446303248405, 83.67128983139992, 80.59469372034073, 79.3648137152195, 45.3411316126585, 16.332238018512726, 33.458584025502205, 68.01003500819206, 66.75612509250641, 83.09877455234528, 93.62351059913635, 91.18041649460793, 85.13744875788689, 90.49100428819656, 92.15912997722626, 91.88182845711708, 89.83938485383987, 87.58943438529968, 89.435945302248, 94.0463899075985, 96.6819740831852, 92.04277262091637, 98.20807859301567, 97.10338667035103, 98.37165981531143, 93.09273228049278, 86.6123928129673, 86.01463168859482, 84.35093656182289, 87.35684126615524, 83.35950896143913, 81.61277309060097, 73.27885508537292, 75.68070620298386, 70.1236791908741, 72.87161573767662, 79.87185090780258, 63.42909201979637, 55.187037885189056, 69.14081633090973, 59.32393670082092, 42.85316951572895, 30.196728855371475, 24.461559802293777, 11.302314922213554, 5.010941689833999, 0.599260440794751, 0.39123137074057013, 0.6728943740017712, 0.05942403164226562, 0.1278214599005878, 0.03808157882303931, 0.08885271032340825, 0.12072256504325196, 0.1649316935800016, 0.41351343446876854, 7.432019300758839, 65.75601115822792, 90.52201822400093, 61.45959310233593, 55.96262946724892, 78.94179001450539, 32.9046231508255, 26.432742029428482, 34.84367050230503, 45.696328952908516, 55.12676551938057, 72.32121527194977, 64.49813425540924, 10.796584859490395, 0.43465526250656694, 0.0588916965352837, 0.018524751867516898, 0.0571562658296898, 0.11173355364007875, 0.07173895559390076, 0.015549813942925539, 0.0528401204792317, 0.07637648057425395, 0.03542295722581912, 0.01917295292514609, 0.04954344854922965, 0.05538458492083009, 0.026100049872184172, 0.05542434177186806, 0.047518268547719344, 0.09705475575174205, 0.04793213462107815, 0.046045665731071495, 0.09382486226968467, 0.014823975889157737, 0.043197406848776154, 0.07488872681278735, 0.020361741771921515, 0.05244741674687248, 0.04797651134140324, 0.06608569761738181, 0.057892728655133396, 0.01006051030344679, 0.044074065081076697, 0.11652646950096823, 0.014094019843469141, 0.012122474854550092, 0.08066057256655768, 0.008421844522672473, 0.0235037037418806, 0.02902519154304173, 0.008112066516332561, 0.019426166290941183, 0.032511359750060365, 0.019925505512219388, 0.03665716365503613, 0.03354118984134402, 0.036804646952077746, 0.02475520406733267, 0.026144259609282017, 0.051443183328956366, 0.2591802628012374, 12.479699794203043, 86.70367911458015, 100.7511605322361, 100.95142498612404, 111.83588773012161, 74.8858268558979, 59.160100892186165, 50.68100407719612, 24.793633483350277, 32.21720963716507, 46.728642359375954, 38.54070112109184, 47.860335633158684, 59.69713747501373, 18.304734975099564, 0.7566717441659421, 0.20832242618780583, 0.12296966204303317, 0.05767350194219034, 0.13304469524882734, 0.3432915697339922, 0.0969512335723266, 0.3648483770666644, 0.4092871706234291, 6.456463923677802, 45.70091150701046, 78.59438225626945, 94.589464366436, 87.79486656188965, 97.40438371896744, 90.75553089380264, 81.75933122634888, 83.33132967352867, 94.14865761995316, 99.0698267519474, 94.59933623671532, 92.30363622307777, 90.33645898103714, 92.89708077907562, 95.71268409490585, 98.22067871689796, 99.14984285831451, 100.77611759305, 100.22286728024483, 97.50617265701294, 96.47320568561554, 93.33897426724434, 91.3784770667553, 89.981330037117, 93.21912869811058, 90.16949594020844, 82.11666405200958, 81.63702338933945, 88.78897681832314, 87.43176564574242, 85.01055836677551, 86.74673840403557, 97.23616674542427, 94.29929673671722, 90.56266084313393, 84.1796949505806, 87.25868493318558, 58.90866078436375, 24.47283949702978, 42.89185144007206, 68.33075299859047, 71.8763655424118, 88.9755392074585, 99.01850670576096, 94.37960162758827, 91.73403158783913, 94.44491252303123, 93.57480481266975, 93.94510254263878, 92.69068345427513, 89.79253336787224, 92.23186567425728, 92.40689188241959, 95.60280159115791, 95.6862299144268, 99.16124984622002, 96.7116428911686, 98.27242434024811, 94.94580924510956, 95.73929026722908, 91.74575015902519, 86.8544702231884, 89.80337038636208, 88.20229589939117, 87.88688242435455, 84.04934674501419, 80.72036057710648, 73.85795161128044, 77.89309948682785, 83.67351651191711, 77.51457899808884, 72.29827970266342, 77.19227269291878, 79.8726412653923, 72.82533422112465, 54.81849946081638, 37.36129380762577, 18.188303522765636, 7.677478054538369, 1.2905249884352088, 0.2783313539111987, 0.1539323228644207, 0.0749203645682428, 0.20604308287147433, 0.04758096518344246, 0.03754725847102236, 0.1741343247704208, 0.11425754593801685, 0.36034253134857863, 4.799730023369193, 65.89153468608856, 97.69571408629417, 68.03376093506813, 47.374372109770775, 31.839519403874874, 13.552690017968416, 41.53745211660862, 55.134581699967384, 65.76668098568916, 72.97393664717674, 79.12392944097519, 81.40709772706032, 21.677796877920628, 0.19263425550889224, 0.06486707628937438, 0.03751230702619068, 0.03312469656520989, 0.16361761721782386, 0.007283242948687985, 0.033616577202337794, 0.030480001369141974, 0.09027432388393208, 0.03191012736351695, 0.014373118392541073, 0.052469744259724393, 0.013098821145831607, 0.0262585522068548, 0.08499205810949206, 0.04504441203607712, 0.0801997804956045, 0.04272388694516849, 0.07632286040461622, 0.07211468269815668, 0.03721665023476817, 0.008891111920092953, 0.10782846162328497, 0.06569092700374313, 0.047124882039497606, 0.1467148624942638, 0.1625144443823956, 0.1842664068681188, 0.15555157035123557, 0.14453508571023121, 0.21151063323486596, 0.1499355904525146, 0.10870342404814437, 0.34116899769287556, 0.1704244175925851, 0.13859079452231526, 0.15143486234592274, 0.09823365733609535, 0.09743280577822588, 0.1672455616062507, 0.12904503877507523, 0.18787030567182228, 0.2703982702223584, 0.17694699025014415, 0.19423897174419835, 0.18124491587514058, 0.09421705020940863, 0.30901156074833125, 15.093442741781473, 103.51971477270126, 114.49827566742897, 106.82653293013573, 110.30979841947556, 73.87169927358627, 61.427192240953445, 56.06606371700764, 83.81148710846901, 107.29637011885643, 80.6054699420929, 61.5646118670702, 60.68080209195614, 77.67006665468216, 35.720196068286896, 1.7689741775393486, 0.3323836316121742, 0.3468549472745508, 0.27199421427212656, 0.4763981304131448, 0.3621705895056948, 0.38875681289937347, 4.0035392716526985, 2.2768755862489343, 3.011042266152799, 40.14617197215557, 81.39427721500397, 99.3774202466011, 98.57402935624123, 106.62157192826271, 97.18939885497093, 87.48828381299973, 85.43437242507935, 97.20554038882256, 101.43443986773491, 101.34073689579964, 98.70325282216072, 95.08331626653671, 96.64117187261581, 96.77642181515694, 100.2587753534317, 103.79733547568321, 105.95829471945763, 105.55216491222382, 102.78595894575119, 101.95731461048126, 98.64930331707001, 97.23941177129745, 92.78989613056183, 98.5802686214447, 93.59498172998428, 82.17772677540779, 82.44112864136696, 87.93224439024925, 87.5962208211422, 87.78552666306496, 87.79659926891327, 98.66382613778114, 99.64725896716118, 89.73374292254448, 82.00758710503578, 94.79359701275826, 57.22723960876465, 20.354498885571957, 42.53773704171181, 81.20004683732986, 76.61328256130219, 82.71695584058762, 99.39665481448174, 95.95507308840752, 92.39650323987007, 91.46495282649994, 95.62933176755905, 94.49022889137268, 95.52427500486374, 92.95198783278465, 94.70416501164436, 95.41142866015434, 100.14907523989677, 96.43733561038971, 102.31087803840637, 97.22895473241806, 102.70969703793526, 98.29148411750793, 96.79726749658585, 94.02965560555458, 90.84650561213493, 94.18873026967049, 92.21114158630371, 92.12107121944427, 92.53718689084053, 87.84742534160614, 80.0439740717411, 79.96865451335907, 86.96240723133087, 81.04431599378586, 80.85954710841179, 85.10841831564903, 82.4874709546566, 76.65067255496979, 57.09583505988121, 42.02091917395592, 22.724764198064804, 10.019854288548231, 1.5129673085175455, 0.5514894041698426, 1.0588338458910584, 0.2633856871398166, 0.17487929260823876, 0.20933403284288943, 0.15050658403197303, 0.3796032228274271, 0.1865058671683073, 0.7212912489194423, 11.234885640442371, 77.45945915579796, 106.01176545023918, 74.92879495024681, 79.81807619333267, 109.32116746902466, 45.397687777876854, 37.349077463150024, 45.637124329805374, 63.2227972894907, 74.37112167477608, 89.107855707407, 95.12607157230377, 28.87976322323084, 0.8824613224714994, 0.2105819690041244, 0.16950710822129622, 0.18748815899016336, 0.2542962186271325, 0.10090377109008841, 0.12501390039687976, 0.1565688767004758, 0.14613662555348128, 0.082159362063976, 0.1305797853274271, 0.19166811282048002, 0.14404566900338978, 0.1713533786823973, 0.11066305756685324, 0.06252540741115808, 0.19554758589947596, 0.24873821530491114, 0.13248759467387572, 0.1452097127912566, 0.07713656596024521, 0.07792811098624952, 0.14245771046262234, 0.20123203634284437, 0.13285942550282925], [0.01186318422696786, 0.07097679961589165, 0.02126077019056538, 0.10999036006978713, 0.023929922863317188, 0.01145551415902446, 0.06526715325890109, 0.0905837029858958, 0.06147385836811736, 0.04168182997091208, 0.06499286289908923, 0.04618230253981892, 0.07888989726779982, 0.1108395254414063, 0.09095120709389448, 0.027936518417845946, 0.021893304510740563, 0.02724025402130792, 0.005575548157139565, 0.071639129309915, 0.09390537044964731, 0.17465517885284498, 12.961162459105253, 71.76697701215744, 86.70115604996681, 78.23425278067589, 66.13725990056992, 68.73486131429672, 58.549067080020905, 35.979414358735085, 43.82514216005802, 63.69285486638546, 90.41372403502464, 128.7800145149231, 113.7284217774868, 78.5307964682579, 27.98299614340067, 1.262224344536662, 0.04218710266286507, 0.22295888455118984, 0.2541964442934841, 0.06071716830774676, 0.17164790740935132, 0.42561136186122894, 0.16232283669523895, 0.8201812987681478, 5.818751268088818, 54.701655730605125, 85.88340952992439, 76.4730852842331, 83.83401229977608, 65.29625102877617, 68.67610886693001, 75.43733686208725, 82.56103500723839, 92.12637573480606, 82.9878357052803, 86.71181827783585, 88.71472120285034, 91.22346818447113, 94.60152491927147, 91.21020689606667, 92.64113411307335, 94.09815073013306, 89.32722553610802, 88.2733216881752, 90.05692318081856, 88.2051457464695, 88.71844500303268, 87.295922935009, 87.5551450252533, 88.81305232644081, 91.50595262646675, 86.64401471614838, 82.98667296767235, 82.3929776251316, 82.12393686175346, 84.83969673514366, 84.92921233177185, 83.91972050070763, 88.70964467525482, 81.84168040752411, 83.20560961961746, 90.04610136151314, 67.48281329870224, 51.2549252808094, 71.07399299740791, 75.79935103654861, 61.693227365612984, 81.29444897174835, 94.57699343562126, 89.45718616247177, 87.8153246641159, 89.01261001825333, 86.99752494692802, 86.47524297237396, 85.90619310736656, 83.88214811682701, 83.18313002586365, 85.11819899082184, 83.70380848646164, 85.37755787372589, 88.71302649378777, 87.94157668948174, 85.92931106686592, 89.4150160253048, 88.70731920003891, 88.81719410419464, 90.38363724946976, 89.2132468521595, 86.2314784526825, 83.16863760352135, 79.61269721388817, 82.02453419566154, 79.970144033432, 81.92542031407356, 76.93096831440926, 73.80768030881882, 72.10667118430138, 66.8405869603157, 70.72331741452217, 77.98852756619453, 65.8958588540554, 56.70873083174229, 37.889898642897606, 21.137728057801723, 10.406111162155867, 5.227494444698095, 1.414520291145891, 0.2800450916402042, 1.0682667209766805, 0.25210326130036265, 0.002775691682472825, 0.07405863463645801, 0.039214931093738414, 0.11709134778357111, 0.12840207171393558, 0.24455076578306034, 11.765906196087599, 64.46496203541756, 84.37348455190659, 68.55792760848999, 49.90374818444252, 62.1915440261364, 36.14832289516926, 25.599803924560547, 36.320989429950714, 39.20004554092884, 51.706660240888596, 68.11835199594498, 69.81671646237373, 24.363849945366383, 1.041993387043476, 0.0446774905140046, 0.1461063904571347, 0.016756343829911202, 0.07319939832086675, 0.041914144458132796, 0.01030381970849703, 0.01050236091032275, 0.007695635858908645, 0.03836174699245021, 0.046341237175511196, 0.022960976712056436, 0.03714217200467829, 0.013930231561971596, 0.02887987531721592, 0.0365384979522787, 0.009031702520587714, 0.04976043768692762, 0.036521343208733015, 0.01729697429254884, 0.043656506823026575, 0.03551163274096325, 0.05548641500354279, 0.05734834478062112, 0.06955025077331811, 0.03448074508924037, 0.025063035791390575, 0.031315036248997785, 0.028873303599539213, 0.028307744396443013, 0.04304669149860274, 0.04712175388704054, 0.049607566397753544, 0.05584235274000093, 0.024186045448004734, 0.025641231914050877, 0.024486554029863328, 0.01695346196356695, 0.07529604714363813, 0.024700450267118867, 0.020771663330378942, 0.03969520083046518, 0.09272004186641425, 0.11627151950960979, 0.04735799062473234, 0.7685866579413414, 21.848782002925873, 91.12921044230461, 96.89036250114441, 94.8725263774395, 92.48462051153183, 92.18751445412636, 85.18579736351967, 49.37230110168457, 22.68365040421486, 38.08467619121075, 98.95803675055504, 127.42619276046753, 107.6072770357132, 79.85316351056099, 25.976620204746723, 0.6783932133112103, 0.07663160125957802, 0.12939372943947092, 0.16590687562711537, 0.3672047849977389, 0.5339566105976701, 0.582349804462865, 0.1339524902869016, 0.37613947119098157, 13.042317554354668, 75.41212901473045, 92.940284460783, 82.8436030447483, 88.07090654969215, 73.79981473088264, 74.64437261223793, 88.4833212196827, 92.53113761544228, 101.1806058883667, 89.8044191300869, 92.26521268486977, 95.34025847911835, 99.66500401496887, 100.20193040370941, 97.63681724667549, 97.85826936364174, 94.73471537232399, 90.83126083016396, 89.91312369704247, 93.28351244330406, 93.00985112786293, 92.1168078482151, 92.89363816380501, 92.4101673066616, 91.66770994663239, 93.22863578796387, 90.1553151011467, 85.70647582411766, 85.71041241288185, 85.10764315724373, 88.07871893048286, 91.86123356223106, 88.3809395134449, 89.988352060318, 87.1976526081562, 89.57364991307259, 96.73701792955399, 72.27788999676704, 56.02550849318504, 81.80930614471436, 81.92015379667282, 68.04447636008263, 84.06766176223755, 95.6021024286747, 92.31469362974167, 91.99858859181404, 92.47857883572578, 91.50893166661263, 91.83608651161194, 89.49389219284058, 85.34886941313744, 84.79540631175041, 85.9296302497387, 86.8837970495224, 87.46448189020157, 90.39160922169685, 90.24315878748894, 90.37684321403503, 91.05405047535896, 90.66721603274345, 91.41143649816513, 91.82277202606201, 94.35690924525261, 91.9607426226139, 89.8250064253807, 86.54557719826698, 86.55538067221642, 83.35855901241302, 86.46708101034164, 84.21438708901405, 77.2838705778122, 77.69271343946457, 79.82575178146362, 75.07182687520981, 76.66129678487778, 74.12279739975929, 79.75854098796844, 74.56053391098976, 48.58747221529484, 20.941852368414402, 8.14987488090992, 2.6266249688342214, 0.3566996252629906, 0.3786569251678884, 0.6404064141679555, 0.07863589722546749, 0.13286939996760339, 0.018235477546113543, 0.07569947119918652, 0.17677996249403805, 0.3906514268601313, 8.766701482236385, 66.90285801887512, 92.70482629537582, 78.38585704565048, 54.86579932272434, 40.43875627219677, 13.005166947841644, 34.31733414530754, 55.679654851555824, 64.17963534593582, 73.78529950976372, 76.0956135392189, 83.39765131473541, 37.73392841219902, 1.760068405419588, 0.11202204870642163, 0.17357783275656402, 0.0853201764402911, 0.02066585533611942, 0.027921564142161515, 0.054541256540687755, 0.017974065303860698, 0.03273589652962983, 0.03183730412274599, 0.062316181138157845, 0.033306882687611505, 0.03690246201585978, 0.09454563609324396, 0.0135509115352761, 0.06512596708489582, 0.028038953350915108, 0.062059490810497664, 0.023156831339292694, 0.11749754004995339, 0.014535632963088574, 0.018970682431245223, 0.033454321455792524, 0.02242116075649392, 0.20422125875484198, 0.18364497693255544, 0.16366143361665308, 0.2404662818298675, 0.17506646225228906, 0.10035464118118398, 0.1485030970070511, 0.15983184770448133, 0.17968597530853003, 0.24166823452105746, 0.1475251096417196, 0.2023082395317033, 0.18969855678733438, 0.15468909085029736, 0.23759332427289337, 0.09385072611621581, 0.15191538812359795, 0.21589544950984418, 0.1932221106835641, 0.243770249071531, 0.2561967697693035, 0.6971726368647069, 25.454712510108948, 105.86582288146019, 109.36386957764626, 101.92864134907722, 89.14424255490303, 86.48374691605568, 76.9039137661457, 55.79887345433235, 70.76375484466553, 89.38266456127167, 116.96058914065361, 155.7733404636383, 135.57651221752167, 99.03017967939377, 43.91946069896221, 2.1723600570112467, 0.17436450929380953, 0.4042144725099206, 0.43968963611405343, 0.6506339809857309, 0.3371489024721086, 0.762043409049511, 3.0011886823922396, 1.6633440018631518, 9.378853384405375, 82.64596804976463, 102.63068407773972, 91.71375587582588, 93.42192381620407, 78.94710212945938, 79.58059653639793, 87.93997317552567, 96.09408482909203, 106.4954186975956, 93.83313775062561, 95.59923738241196, 96.65049657225609, 99.38836365938187, 102.23646283149719, 99.9546168744564, 101.03043794631958, 100.86463004350662, 94.10981610417366, 94.47544768452644, 96.51624217629433, 93.26649695634842, 94.2720977962017, 93.55704456567764, 94.13550272583961, 93.98494720458984, 93.680659532547, 90.28262346982956, 87.76721924543381, 87.46052250266075, 85.6524047255516, 90.55181622505188, 93.062903881073, 93.72618868947029, 93.10285493731499, 86.16333290934563, 94.33005228638649, 96.70321494340897, 72.04150468111038, 67.10765942931175, 85.31446605920792, 86.44479140639305, 70.9080559015274, 80.48842862248421, 100.11075049638748, 92.0910832285881, 92.1351608633995, 94.16117414832115, 95.13049453496933, 93.232861161232, 91.62471145391464, 87.36616596579552, 87.24307537078857, 86.22106701135635, 86.77339777350426, 88.1418639421463, 93.15802037715912, 89.93470653891563, 93.82765084505081, 94.55561578273773, 94.68632116913795, 96.35528281331062, 96.07765451073647, 98.6213368177414, 96.1364221572876, 95.03461807966232, 88.09978500008583, 88.68298530578613, 86.17988482117653, 89.82167020440102, 87.12455213069916, 79.82140481472015, 79.27474334836006, 79.9649079144001, 86.6551785171032, 88.32103952765465, 80.97065314650536, 84.71914440393448, 72.21916794776917, 48.29643443226814, 25.37937205284834, 10.43526129797101, 2.930867518298328, 0.7361923868302256, 1.8883358663879335, 0.7583266741130501, 0.1290559335029684, 0.26822683517821133, 0.12327250282396562, 0.33568375452887267, 0.29893064231146127, 0.5649409792385995, 17.758267298340797, 77.5900961458683, 98.73178169131279, 84.53647300601006, 72.0561034977436, 85.88613778352737, 48.89250464737415, 36.68853610754013, 50.39939358830452, 57.18950383365154, 68.69694694876671, 85.57780712842941, 95.01352161169052, 48.634608685970306, 2.549573415890336, 0.25163098820485175, 0.3697361022932455, 0.16615668253507465, 0.1481661619618535, 0.1779574985266663, 0.12424753644154407, 0.09330106928246096, 0.1181838040065486, 0.16400150052504614, 0.1859485439490527, 0.19560554763302207, 0.21558000706136227, 0.15035497810458764, 0.13027317443629727, 0.13387440150836483, 0.12639343418413773, 0.23857944557676092, 0.15133203036384657, 0.18889436556492, 0.18527051783166826, 0.08533659274689853, 0.1306488792761229, 0.13229178643086925], [0.07463506073690951, 0.038675938922096975, 0.0952654228603933, 0.07500910316593945, 0.0782177563814912, 0.056389987221336924, 0.01826969426474534, 0.05023881123634055, 0.06377127298037522, 0.04165432597801555, 0.05772105876530986, 0.0163423664344009, 0.0367207768431399, 0.05541955863009207, 0.03080740167206386, 0.0424357481097104, 0.058232869778294116, 0.06369077964336611, 0.08677508274558932, 0.08957384037785232, 0.5989780090749264, 33.55207800865173, 86.60230815410614, 81.32335782051086, 75.53838104009628, 75.94465523958206, 58.796616196632385, 51.553954035043716, 38.86520370841026, 43.19713085889816, 53.070946633815765, 37.097071185708046, 51.40784427523613, 74.13758620619774, 67.99988195300102, 21.338706873357296, 0.758603821741417, 0.12127242967835627, 0.07536589066148736, 0.07995346168172546, 0.1127694730530493, 0.059886868330067955, 0.07811885778210126, 0.9646284696646035, 1.2835508189164102, 4.067043839022517, 55.22598959505558, 76.76350370049477, 83.38179856538773, 81.70460656285286, 90.65548226237297, 80.70172637701035, 75.85477486252785, 100.84319159388542, 82.14433416724205, 89.86699417233467, 86.55093491077423, 94.68619957566261, 92.57756352424622, 96.47974133491516, 93.41820761561394, 93.43200847506523, 90.4436132311821, 91.49059385061264, 89.70817789435387, 97.48405784368515, 95.10192006826401, 92.69274294376373, 91.33256793022156, 88.06199982762337, 87.21260100603104, 89.42339837551117, 87.31852412223816, 88.87004926800728, 85.19289538264275, 81.33926376700401, 84.38286244869232, 87.14503303170204, 85.474201887846, 83.10980916023254, 78.50786849856377, 86.06950834393501, 83.75627607107162, 84.70709905028343, 79.65258747339249, 53.92647072672844, 64.52319771051407, 66.44755125045776, 64.61928695440292, 86.76964357495308, 82.05893754959106, 87.66847774386406, 82.94031545519829, 84.32749941945076, 86.30953386425972, 88.14705446362495, 82.80601546168327, 85.38490667939186, 87.89800062775612, 92.35286638140678, 86.45978540182114, 86.35282874107361, 84.52679872512817, 85.24682968854904, 87.09325700998306, 86.35607376694679, 84.53764334321022, 85.87280049920082, 83.6464011669159, 85.811897367239, 83.93320217728615, 82.60499104857445, 81.42425760626793, 80.76117798686028, 77.3228868842125, 84.55994814634323, 81.72109007835388, 83.44100698828697, 80.74697434902191, 79.23532426357269, 60.31167469918728, 57.17528119683266, 61.706082075834274, 65.1434688270092, 65.32579064369202, 60.32475359737873, 16.064033210277557, 9.418052081018686, 5.805334663018584, 1.4339310745708644, 0.5202136980369687, 0.7210442028008401, 0.3089298354461789, 0.12372640776447952, 0.02085447031276999, 0.1136654382571578, 0.09313661677879281, 0.21150601707631722, 0.32084745063912123, 16.350425742566586, 64.845390021801, 76.77321597933769, 68.56035187840462, 50.15962265431881, 72.55421876907349, 48.08402203023434, 23.969453908503056, 28.732173442840576, 35.18007405102253, 68.38097110390663, 65.89376896619797, 73.19513037800789, 43.134362027049065, 0.8303523436188698, 0.0757834229443688, 0.04607991213561036, 0.06658130383584648, 0.038251794103416614, 0.06568493045051582, 0.0334838069829857, 0.05381802249758039, 0.03584699072234798, 0.04001441709988285, 0.06330013537080958, 0.04466028753085993, 0.012502279132604599, 0.10906862749834545, 0.02876541573641589, 0.061964358610566705, 0.037822706581209786, 0.02651927981787594, 0.04511133149208035, 0.023914161502034403, 0.052164892258588225, 0.044778893861803226, 0.10123520682100207, 0.0346444925526157, 0.0719197205035016, 0.13045829575276002, 0.05317063594702631, 0.05365726588934194, 0.04394371797388885, 0.035288962462800555, 0.09231779782567173, 0.08477249371935613, 0.11659187497571111, 0.13219273940194398, 0.06147168387542479, 0.06251696177059785, 0.10475985909579322, 0.051424247430986725, 0.09154041297733784, 0.07932849912322126, 0.11223626221180893, 0.08178206160664558, 0.06153189802716952, 1.9763117143884301, 50.08804589509964, 105.0528185069561, 87.956722676754, 98.65867361426353, 106.07307136058807, 77.12786614894867, 70.50023138523102, 39.04038570821285, 32.202705815434456, 38.7334343791008, 40.496292784810066, 61.713662669062614, 82.4748632311821, 72.35376432538033, 19.766018763184547, 0.46295860782265663, 0.12459010438760743, 0.061917629282106645, 0.09973764928872697, 0.18544570921221748, 0.14325151161756366, 0.3467218059813604, 0.7083423156291246, 0.5042275995947421, 9.233481734991074, 79.62813958525658, 80.73103800415993, 91.9240289926529, 91.9614265859127, 99.90869253873825, 89.22457784414291, 90.16326427459717, 103.56247007846832, 90.49422651529312, 96.90908789634705, 93.68431493639946, 100.13564676046371, 96.39287039637566, 97.75700479745865, 97.0645147562027, 93.74024793505669, 95.77195331454277, 94.7523920238018, 92.52182811498642, 98.91244679689407, 96.61730915307999, 94.62971180677414, 94.09036874771118, 88.59404727816582, 89.24135014414787, 94.07192453742027, 89.67332616448402, 91.48636847734451, 87.33358651399612, 84.21953961253166, 88.18822905421257, 92.54578202962875, 87.26632252335548, 86.82050004601479, 83.68146568536758, 89.97556954622269, 88.9242571592331, 87.19598829746246, 87.49351233243942, 61.81556940078735, 67.33272135257721, 67.61278912425041, 66.38990834355354, 89.44612875580788, 85.0151789188385, 90.52884265780449, 84.59460228681564, 89.6202202141285, 87.80669152736664, 88.08332428336143, 83.2190228998661, 89.32270377874374, 90.25088757276535, 93.42458367347717, 89.44330170750618, 90.1867014169693, 87.5768418610096, 85.09445026516914, 86.30235224962234, 88.16850051283836, 88.58852237462997, 89.13740292191505, 87.60382041335106, 87.07683429121971, 87.25178450345993, 85.04117712378502, 85.99817857146263, 88.52564334869385, 82.55296424031258, 86.90623104572296, 82.43852198123932, 88.91484126448631, 85.58536872267723, 85.82711175084114, 69.86184284090996, 70.36356791853905, 70.79915374517441, 74.09589484333992, 76.1972276866436, 96.9906847178936, 55.97028225660324, 20.44317662715912, 9.39453324303031, 3.2785714231431484, 0.638941474026069, 0.2893927978584543, 0.2945411059772596, 0.25484460638836026, 0.03817117460130248, 0.01771527840901399, 0.30877796234562993, 0.07476855083950795, 0.42619991465471685, 12.987458948045969, 71.1619658768177, 83.96803110837936, 75.59937536716461, 52.51924283802509, 39.81136053800583, 13.749168924987316, 35.06230317056179, 45.90259328484535, 54.97253179550171, 92.46568232774734, 74.07971531152725, 84.97321397066116, 59.45721074938774, 1.1923710303381085, 0.05583114631008357, 0.06441936086048372, 0.018029021339316387, 0.021849180120625533, 0.027535539738892112, 0.09372260916279629, 0.03832050955679733, 0.019113922498945612, 0.022614866866206285, 0.0838576556998305, 0.09868425971944816, 0.01536396532173967, 0.08228914884966798, 0.025006127907545306, 0.0772262470854912, 0.06265317555516958, 0.030670727755932603, 0.023086746623448562, 0.025858152403088752, 0.03795740267378278, 0.024494127646903507, 0.05031753084040247, 0.08363242872292176, 0.14582446339773014, 0.24412239814409986, 0.20558893302222714, 0.20293112407671288, 0.20756258571054786, 0.06841662019724026, 0.1390963009907864, 0.30095750698819757, 0.2918952307663858, 0.23479167226469144, 0.15822961024241522, 0.14758835546672344, 0.21664136729668826, 0.08949033392127603, 0.16478798410389572, 0.17917239427333698, 0.22828784625744447, 0.16141456668265164, 0.1708599246921949, 1.996607375331223, 54.745653569698334, 120.3292527794838, 101.6306309401989, 98.28775271773338, 98.01342263817787, 80.09049877524376, 68.50026190280914, 53.829233944416046, 64.63894709944725, 75.93150034546852, 56.905119493603706, 72.20829293131828, 95.93317106366158, 89.5129443705082, 37.02187702059746, 1.4583273092284799, 0.22785386798204854, 0.23756561247864738, 0.24891839391784742, 0.23109767673304304, 0.31106971437111497, 0.16072485916083679, 5.0252963695675135, 1.9273290177807212, 5.7813916727900505, 88.20053279399872, 87.67115280032158, 96.15764781832695, 96.96587204933167, 104.42940875887871, 96.35635435581207, 99.9010169506073, 109.24220010638237, 95.04011258482933, 100.00081479549408, 97.9127736389637, 103.7396089732647, 98.15993517637253, 101.03471651673317, 101.09284579753876, 97.58156061172485, 100.85051000118256, 96.60965636372566, 95.96230790019035, 101.84095725417137, 103.60514178872108, 98.71055603027344, 99.33563008904457, 92.86818712949753, 94.34807851910591, 97.86336869001389, 94.07447800040245, 95.98273560404778, 93.06639209389687, 88.64090636372566, 90.93580842018127, 95.92974364757538, 89.61376056075096, 86.17081090807915, 88.76870110630989, 95.21835342049599, 90.95913916826248, 91.4463110268116, 85.54990902543068, 63.15769538283348, 77.04730287194252, 76.38324290513992, 69.93237465620041, 89.83739376068115, 86.3803468644619, 91.17048382759094, 88.31631258130074, 90.52534684538841, 89.46086436510086, 87.59172946214676, 84.52708750963211, 88.74832659959793, 91.96132019162178, 96.94075539708138, 93.16774785518646, 92.84602671861649, 88.24005827307701, 87.7034966647625, 88.90512138605118, 90.90180024504662, 88.8407376408577, 92.11449757218361, 91.50120288133621, 91.98943108320236, 90.00435680150986, 90.19477978348732, 89.8629891872406, 94.14110362529755, 86.94349944591522, 91.56557902693748, 88.06312456727028, 92.59500458836555, 89.57852125167847, 87.798772752285, 71.78938060998917, 75.55090516805649, 79.89889025688171, 84.98557090759277, 81.53203502297401, 85.96134334802628, 52.41515502333641, 24.519485794007778, 11.772696431726217, 4.6103135123848915, 1.1444465769454837, 1.3393759983591735, 0.623079581419006, 0.13399615825619549, 0.1839004093199037, 0.2160648224526085, 0.333923528669402, 0.23213853884954005, 0.5123470514081419, 22.710653655231, 79.8215340077877, 91.33642852306366, 82.21028342843056, 65.41345953941345, 101.35509252548218, 64.6727728843689, 35.77929049730301, 39.12001043558121, 51.86671145260334, 89.70636159181595, 80.79088479280472, 95.81058964133263, 73.18620085716248, 2.9542241524904966, 0.14323757408419624, 0.26683958305511624, 0.1914839117671363, 0.14819434873061255, 0.2196049559279345, 0.16824487829580903, 0.10043459275038913, 0.08618483043392189, 0.08544461976271123, 0.24550455913413316, 0.20243131730239838, 0.11620631441473961, 0.21150441403733566, 0.10657236183760688, 0.1696331545826979, 0.1936721638776362, 0.10008298544562422, 0.15549058065516874, 0.11997010151389986, 0.16126941744005308, 0.2358093051589094, 0.21107439883053303], [0.026314285642001778, 0.08415478936512955, 0.00396799042391649, 0.039047398677212186, 0.04652488903957419, 0.035229531276854686, 0.1005929744860623, 0.06023214882588945, 0.05531835195142776, 0.055001673827064224, 0.05012319204979576, 0.04937390491249971, 0.04196765701635741, 0.039484096923843026, 0.037679776360164396, 0.07589231827296317, 0.01809443609090522, 0.060097274617874064, 0.07880764504079707, 0.17933011549757794, 31.979859173297882, 90.86175799369812, 78.0299985408783, 80.66359162330627, 59.62746821343899, 49.99690778553486, 49.18457217514515, 48.58050338923931, 66.14210844039917, 75.63523784279823, 38.44622299075127, 46.122943460941315, 65.90142175555229, 51.29032798111439, 24.86439898610115, 1.4084357488900423, 0.02839327135006897, 0.1614981918828562, 0.060092858839198016, 0.10006472861277871, 0.2299086077255197, 0.13259208906674758, 1.372471391223371, 0.795945308636874, 0.5924132675863802, 41.613584831357, 88.89837294816971, 77.09600865840912, 90.89695170521736, 86.47634491324425, 88.03187504410744, 73.83740991353989, 79.31394964456558, 85.98268300294876, 93.57079222798347, 90.83126083016396, 88.37431266903877, 89.61167067289352, 96.18362322449684, 95.22922083735466, 94.46257397532463, 87.8539989888668, 90.16053602099419, 90.65948724746704, 87.31475472450256, 84.50198605656624, 87.21450090408325, 86.52551427483559, 88.65249574184418, 84.65208560228348, 88.0653740465641, 86.96344837546349, 84.11347210407257, 85.95787793397903, 87.1884723007679, 81.2144024670124, 84.10894274711609, 85.52089378237724, 83.20026710629463, 83.03977891802788, 86.87631145119667, 73.40036496520042, 82.49305665493011, 83.12901332974434, 86.28985852003098, 74.8899458348751, 59.01488408446312, 59.402805268764496, 67.27736592292786, 85.91198399662971, 90.29038265347481, 85.10857030749321, 80.66871374845505, 84.7035576403141, 87.64461502432823, 86.05309322476387, 82.69007608294487, 84.70073819160461, 84.71766248345375, 84.01062682271004, 85.0020544230938, 84.36257913708687, 83.68357837200165, 83.41772183775902, 86.09674528241158, 83.90724197030067, 82.65752702951431, 83.82989332079887, 84.41716700792313, 85.51181226968765, 82.8390584886074, 79.15770962834358, 77.42088362574577, 78.69915783405304, 76.11512169241905, 79.52416956424713, 78.7057238817215, 82.918291836977, 82.21963092684746, 79.66608434915543, 77.63209149241447, 74.43488225340843, 69.86147046089172, 62.66092523932457, 60.54870218038559, 77.2163937985897, 55.468560978770256, 11.579100620001554, 10.734117161482573, 6.514729047194123, 2.908837962895632, 0.579102166229859, 0.3185960714472458, 0.694803463993594, 0.14275130408350378, 0.08040459098992869, 0.17921969876624644, 0.2511784859234467, 0.3004177281400189, 0.15481659182114527, 25.97198825329542, 70.63646927475929, 83.50004822015762, 66.65289223194122, 54.15734253823757, 65.02064421772957, 42.6061637699604, 39.24748979508877, 45.642964616417885, 41.0321856290102, 54.11184757947922, 66.18881553411484, 68.97266775369644, 40.95639869570732, 3.422498912550509, 0.25776688707992435, 0.046158999102772214, 0.009762866411620053, 0.046814426823402755, 0.06555968560860492, 0.055212692386703566, 0.07801975138136186, 0.05946299439528957, 0.030803857916907873, 0.025966839930333663, 0.07816634781192988, 0.018690458600758575, 0.011950511816394283, 0.047228608309524134, 0.02066407418169547, 0.03974074643338099, 0.038117713993415236, 0.019851583892886993, 0.07207943068351597, 0.02891826290579047, 0.03669421166705433, 0.03753848999622278, 0.0027087745456810808, 0.06296826177276671, 0.03903073746187147, 0.029604458213725593, 0.09179514032439329, 0.03536799005814828, 0.01547666322949226, 0.10999597070622258, 0.12642384739592671, 0.09957595015293919, 0.021407767380878795, 0.01970248642464867, 0.04341812527854927, 0.013975423717056401, 0.08781498749158345, 0.053743221433251165, 0.017442732096242253, 0.046909447701182216, 0.4838438902515918, 48.921782076358795, 105.71650609374046, 87.63631626963615, 97.16653168201447, 84.10430699586868, 70.58582559227943, 69.37895715236664, 40.21777153015137, 22.112256065011024, 45.795397236943245, 33.94206628203392, 51.85941584408283, 76.21106654405594, 62.31557697057724, 26.328249536454678, 0.6294501177035272, 0.08360678752069362, 0.03490272654744331, 0.06016621642629616, 0.0874981794913765, 0.7524979650042951, 0.6680001178756356, 1.191880856640637, 1.2661508400924504, 1.9548290921375155, 60.5227267742157, 94.60527911782265, 86.62004560232162, 97.27397471666336, 92.08154574036598, 88.49852040410042, 80.641058832407, 88.50219860672951, 91.07717603445053, 97.69029557704926, 94.75990042090416, 95.2320858836174, 94.95932132005692, 100.07147580385208, 95.0917898118496, 97.75814473628998, 92.64151409268379, 92.10622921586037, 93.23232159018517, 90.5502887070179, 86.21774598956108, 89.99106511473656, 88.3070182800293, 92.99050256609917, 89.10689055919647, 91.57631725072861, 91.73197969794273, 90.54132118821144, 87.30579480528831, 86.1330409348011, 83.56673464179039, 86.23682096600533, 89.02554452419281, 89.9365684390068, 86.96949765086174, 90.2654255926609, 78.54164108633995, 85.43526917695999, 88.96752923727036, 90.00477477908134, 79.92507085204124, 63.52625660598278, 63.057832941412926, 69.42175045609474, 87.07689508795738, 94.669039696455, 85.27928754687309, 85.57561084628105, 86.24877512454987, 89.62813898921013, 86.91157355904579, 85.55048659443855, 85.34896820783615, 85.41050970554352, 86.1024297773838, 87.84038811922073, 87.18860149383545, 88.15359771251678, 85.80674484372139, 86.85521498322487, 87.00228989124298, 84.87553641200066, 86.24739959836006, 86.41665011644363, 85.86107432842255, 85.13337537646294, 85.30595451593399, 82.89940685033798, 81.62032708525658, 81.705412119627, 84.91455271840096, 83.13976675271988, 83.76743987202644, 85.29792174696922, 86.90155729651451, 86.51656955480576, 79.15002644062042, 81.45892694592476, 70.94042256474495, 70.78215345740318, 74.56901505589485, 98.51935029029846, 47.981374338269234, 19.727376736700535, 9.195144642144442, 4.548259042203426, 1.0031062737107277, 0.34650230838451535, 0.5710454110521823, 0.0490123379859142, 0.22691343328915536, 0.18826677580364048, 0.3241299994988367, 0.06837131208158098, 0.12285333781619556, 21.94738481193781, 78.31017270684242, 91.55790343880653, 73.32449823617935, 57.49503403902054, 41.6820153594017, 28.82833868265152, 53.94575089216232, 60.9282486140728, 62.9717143625021, 78.89314502477646, 75.44976979494095, 79.90749299526215, 56.263523921370506, 5.446694707497954, 0.11727716671884991, 0.03838744756649248, 0.02136409570084652, 0.04028606170322746, 0.040393676827079616, 0.031225559214362875, 0.04986937012290582, 0.09158352433587424, 0.07160396635299549, 0.02169686915294733, 0.02589699641248444, 0.024551480819354765, 0.05496144571225159, 0.08403747066040523, 0.08151287722284906, 0.03158627267112024, 0.019775456239585765, 0.057669293964863755, 0.07455115352058783, 0.06813138315919787, 0.023035547710605897, 0.09609050553990528, 0.12160431069787592, 0.1392414650763385, 0.32524164766073227, 0.15051246184157208, 0.16442899242974818, 0.22205273708095774, 0.10148407862288877, 0.21852535370271653, 0.23410206864355132, 0.16107669653138146, 0.17432633321732283, 0.10893789818510413, 0.2038720337441191, 0.14064456947380677, 0.2518201171187684, 0.15405379759613425, 0.13643924903590232, 0.19507703458657488, 0.5837936676107347, 55.65899536013603, 122.82812789082527, 99.29151445627213, 101.86080738902092, 82.59057462215424, 66.3559153676033, 67.41916671395302, 69.14832472801208, 90.4515928030014, 106.82180598378181, 54.54054057598114, 65.97048684954643, 89.30926010012627, 75.23828834295273, 42.97751784324646, 2.48481254093349, 0.24003531667403877, 0.30742811446543783, 0.1722299589891918, 0.2144532636157237, 0.8288369968067855, 0.5895198415964842, 6.039726985618472, 4.194353157654405, 2.070332206785679, 65.45012757182121, 102.60385751724243, 97.590771317482, 103.02391737699509, 96.6266718506813, 98.75250577926636, 86.6268016397953, 95.08737444877625, 95.03505885601044, 100.91156512498856, 98.80446419119835, 98.89646485447884, 95.99435538053513, 103.38805943727493, 99.69618514180183, 104.55984815955162, 97.65939563512802, 98.25713396072388, 98.32109972834587, 94.5092810690403, 88.28152924776077, 93.01628798246384, 90.71772292256355, 97.86897718906403, 92.5364801287651, 94.14506301283836, 95.68156376481056, 93.62965106964111, 91.25350937247276, 90.56923449039459, 83.6025059223175, 88.78956958651543, 91.69379934668541, 95.03676116466522, 90.20086705684662, 91.46268054842949, 82.88404047489166, 89.30318042635918, 92.53968715667725, 91.7015889286995, 78.7670449912548, 70.48585295677185, 71.9884443283081, 68.63535985350609, 91.47354036569595, 97.8131277859211, 90.40568366646767, 88.04147332906723, 87.69177809357643, 91.77965953946114, 90.86896240711212, 86.01515606045723, 89.32634398341179, 87.50612005591393, 86.5545067191124, 90.56291162967682, 90.83608657121658, 91.89514294266701, 87.23153918981552, 91.54910311102867, 89.05566170811653, 88.35643082857132, 88.82535606622696, 91.47009015083313, 92.42180988192558, 92.34715908765793, 86.07634037733078, 85.5714462697506, 82.99200788140297, 82.96329662203789, 87.50561848282814, 85.67711099982262, 86.94090038537979, 88.39712664484978, 90.72691082954407, 88.95426034927368, 84.13040399551392, 85.62237873673439, 78.3046706020832, 80.36691874265671, 85.43463081121445, 86.25690668821335, 50.060216188430786, 24.35320481657982, 12.443618830293417, 6.0777767188847065, 1.4508287678472698, 1.3039810163900256, 1.0787617578171194, 0.2320913234143518, 0.2433389870566316, 0.5919168598484248, 0.3800113743636757, 0.4378677229396999, 0.254787698504515, 33.5875529050827, 83.57805043458939, 99.85172599554062, 82.16050609946251, 72.14954808354378, 99.4919840991497, 59.09211494028568, 55.273346453905106, 60.91005519032478, 56.30378656089306, 73.85581612586975, 81.24060586094856, 90.58682754635811, 67.99694091081619, 6.739249499514699, 0.32800617744214833, 0.1410985560505651, 0.07710829755524173, 0.15657424984965473, 0.17070775473257527, 0.07948033511638641, 0.1303662991267629, 0.1494042424019426, 0.17031296185450628, 0.14208441018126905, 0.1638934141374193, 0.13309982197824866, 0.17649900022661313, 0.17152199463453144, 0.17123594123404473, 0.12787339539499953, 0.09525895875412971, 0.1438815801520832, 0.25355303194373846, 0.12393145574606024, 0.15321889630286023], [0.05694528437743429, 0.0513675510592293, 0.07778958912240341, 0.12676538375671953, 0.05647364210744854, 0.05353257765818853, 0.13541254709707573, 0.06895120401168242, 0.053926810214761645, 0.07354429661063477, 0.002185664334319881, 0.016816099705465604, 0.017314795113634318, 0.029451807713485323, 0.004203530006634537, 0.058124813076574355, 0.045434251078404486, 0.10043522357591428, 0.09436504187760875, 16.595634184777737, 83.64416688680649, 69.63460743427277, 78.09242159128189, 55.93482255935669, 53.5605313628912, 72.35124126076698, 48.71770262718201, 55.594486221671104, 111.16431936621666, 142.5102585554123, 102.78820842504501, 97.39043846726418, 80.553078353405, 31.31470486521721, 2.1461891988292336, 0.13808525836793706, 0.2082567906472832, 0.01988184310903307, 0.06288473305176012, 0.07930141815450042, 0.14667543960968032, 0.4277342901332304, 4.818909969180822, 0.5779197765514255, 9.246507436037064, 78.45290824770927, 76.35448604822159, 83.38052183389664, 84.65859085321426, 84.67413201928139, 78.45176830887794, 86.69541075825691, 89.86194044351578, 92.85591378808022, 91.55030384659767, 90.725307315588, 98.77000764012337, 97.41500034928322, 92.91707530617714, 89.82676953077316, 88.28814089298248, 89.49559450149536, 84.80758845806122, 83.84789675474167, 84.42334547638893, 86.47137477993965, 84.40335094928741, 84.33369308710098, 82.5531542301178, 88.4077736735344, 84.33376908302307, 84.39018845558167, 84.92120236158371, 86.2569522857666, 88.55268269777298, 88.06103467941284, 81.44014075398445, 78.356803804636, 87.21978262066841, 78.23103055357933, 79.15517136454582, 82.56571635603905, 76.6967336833477, 83.15853014588356, 82.73028552532196, 79.77526769042015, 39.43278305232525, 30.03084495663643, 58.75837504863739, 82.66038447618484, 81.98217406868935, 76.30220845341682, 78.81348609924316, 82.57300436496735, 87.3733551800251, 83.74720215797424, 80.02318918704987, 73.75447556376457, 79.36802834272385, 83.4493437409401, 83.71344476938248, 84.74573537707329, 81.98566228151321, 81.4260283112526, 82.66831085085869, 81.07804298400879, 84.66498211026192, 80.044224858284, 80.37017896771431, 80.8293767273426, 79.5278249680996, 82.12057784199715, 82.38790109753609, 78.21151480078697, 80.19552513957024, 78.14972251653671, 77.90183901786804, 75.13326197862625, 80.73142558336258, 83.27240243554115, 81.58599212765694, 77.48843640089035, 80.03756761550903, 72.14524671435356, 62.86036133766174, 62.59510517120361, 83.95747527480125, 41.894226372241974, 12.0151443220675, 11.619707141071558, 6.668761381879449, 1.8103929050266743, 0.3748445719247684, 0.2609445556299761, 0.31032358878292143, 0.13511797384126112, 0.5888077954296023, 0.3560060734162107, 0.06310559620033018, 0.08013962942641228, 0.059558156281127594, 35.145108327269554, 75.06098225712776, 78.72102946043015, 66.79669171571732, 46.93936005234718, 53.09309184551239, 35.95310837030411, 29.390516616404057, 36.31136454641819, 38.177569806575775, 50.12553088366985, 66.88859358429909, 73.8851049542427, 58.79848949611187, 9.144104830920696, 0.22339713759720325, 0.14428832160774618, 0.048146381523110904, 0.04616558195266407, 0.06675259151961654, 0.026612131769070402, 0.055195422610268, 0.03627807833254337, 0.08392422634642571, 0.027994448610115796, 0.03669318379252218, 0.09570052920025773, 0.08182551435311325, 0.022075447959650774, 0.015888654452282935, 0.014965247410145821, 0.045105895260348916, 0.053118826617719606, 0.05367273966840003, 0.03924872478819452, 0.034364958919468336, 0.08044229951337911, 0.07700974776525982, 0.09316031355410814, 0.08076324127614498, 0.022945989039726555, 0.08759025775361806, 0.013067818854324287, 0.05189085422898643, 0.04572273501253221, 0.06694624753436074, 0.06819132642704062, 0.031460812606383115, 0.04098490135220345, 0.048515499802306294, 0.03998367363237776, 0.1314240079955198, 0.2088930635363795, 0.25082359090447426, 25.291231982409954, 100.28582990169525, 82.25699812173843, 100.2284149825573, 81.89673185348511, 66.91478177905083, 86.40511393547058, 61.276792511343956, 44.972786977887154, 102.55994707345963, 127.6814478635788, 100.73119640350342, 105.5000165104866, 86.73387229442596, 30.33315483480692, 1.4362421818077564, 0.11554514247109182, 0.03779597442189697, 0.0557247074902989, 0.0879133740090765, 0.48096590093337, 1.791745643131435, 1.9721321761608124, 1.5247051161713898, 0.6835266191046685, 17.03250054270029, 89.38021749258041, 82.74320483207703, 93.05549427866936, 90.38631990551949, 94.7226320207119, 81.87290713191032, 93.05702179670334, 96.72209233045578, 99.28621754050255, 95.40081962943077, 94.7895996272564, 101.06851950287819, 101.8910613656044, 95.37582457065582, 94.8749278485775, 89.5554868876934, 91.62357911467552, 86.64383232593536, 89.5462153851986, 89.3548272550106, 92.94986754655838, 87.83801704645157, 89.16423708200455, 84.29308846592903, 93.50368782877922, 88.04982528090477, 88.09335574507713, 87.20709130167961, 91.74583375453949, 87.95239090919495, 89.6242555975914, 83.93040552735329, 79.49488833546638, 87.79840797185898, 86.24910950660706, 85.96559152007103, 87.68887504935265, 78.466906696558, 86.3218604028225, 87.28078454732895, 82.83025816082954, 41.38804413378239, 32.00951658189297, 54.9668624997139, 84.70028221607208, 83.88545393943787, 81.95576548576355, 80.39672434329987, 83.47338125109673, 87.10144177079201, 86.53537094593048, 80.37036895751953, 72.9148118197918, 79.47470381855965, 85.91636896133423, 84.18654218316078, 85.61776578426361, 82.40854158997536, 85.85123285651207, 84.24439027905464, 83.00181895494461, 83.6724753677845, 83.53395760059357, 84.1420465707779, 82.72237434983253, 83.52188184857368, 83.0831041932106, 85.97833603620529, 85.8008399605751, 86.07251778244972, 84.06465992331505, 82.01355278491974, 80.75949847698212, 82.01302841305733, 87.41231828927994, 84.99560996890068, 81.17328107357025, 83.63760083913803, 80.93453988432884, 71.42804279923439, 71.63782194256783, 79.89335015416145, 92.67531707882881, 36.756548658013344, 20.930224992334843, 9.027809221297503, 3.1847599195316434, 0.49669993633870035, 0.09285661188187078, 0.15212307072943076, 0.2000053256051615, 1.308405997697264, 0.24426405929261819, 0.5211545038037002, 0.07591867935843766, 0.18919594469480217, 31.08632192015648, 81.0411773622036, 85.46911776065826, 76.43808156251907, 48.58513534069061, 24.301290102303028, 22.555090002715588, 36.20560482144356, 52.78246231377125, 53.66530314087868, 72.23937526345253, 82.5158554315567, 81.18354812264442, 77.22767159342766, 11.796218119561672, 0.12594581523444504, 0.1163206051569432, 0.05894307170819957, 0.008637021892354824, 0.1071516377851367, 0.06343879082123749, 0.043284449639031664, 0.0320496140193427, 0.030280979626695625, 0.05121266112837475, 0.04467110433324706, 0.032242401721305214, 0.06304162307060324, 0.006896855820741621, 0.08809781997115351, 0.017226544478035066, 0.027077729246229865, 0.02973357892187778, 0.047412980056833476, 0.09513739496469498, 0.1377493326435797, 0.21257361135212705, 0.20252755901310593, 0.2824057446559891, 0.15422602038597688, 0.10262043288093992, 0.15583136002533138, 0.20600955263944343, 0.10189585183979943, 0.18554114940343425, 0.23919342434965074, 0.16546690079849213, 0.20534543436951935, 0.13765543611953035, 0.13664685742696747, 0.13960173324448988, 0.25905026821419597, 0.39251151611097157, 0.39956580789294094, 27.53186535090208, 116.70534163713455, 91.32086455821991, 104.05154943466187, 78.58331725001335, 74.30112183094025, 93.98082822561264, 67.93638736009598, 75.2515572309494, 123.67336973547935, 160.986630320549, 120.86129263043404, 117.96849265694618, 103.68255883455276, 49.128426387906075, 4.606745503842831, 0.22595109039684758, 0.41555377654731274, 0.20493637741310522, 0.24337511480553076, 0.25510076608043164, 0.739125651307404, 2.0698845433071256, 14.753998406231403, 3.037254447117448, 16.57199375331402, 101.82186707854271, 93.96157085895538, 100.98768264055252, 93.75169292092323, 98.94834727048874, 90.32929256558418, 100.38145557045937, 100.5185218155384, 103.31552892923355, 99.11565229296684, 96.31194993853569, 102.49839037656784, 104.83022645115852, 98.80419060587883, 97.71798089146614, 92.26945325732231, 96.3934251666069, 91.41599625349045, 93.68439093232155, 92.1843758225441, 96.79935738444328, 93.33256781101227, 93.19812342524529, 88.76234024763107, 100.04160180687904, 93.34256887435913, 90.17303735017776, 90.45891121029854, 96.99595123529434, 94.28766936063766, 93.39486166834831, 87.03901872038841, 82.98767611384392, 90.97461953759193, 88.51242005825043, 89.55885350704193, 90.23093104362488, 80.81100851297379, 89.2764450609684, 90.91264486312866, 82.03999936580658, 49.9316842854023, 46.44345246255398, 59.83391493558884, 84.84728872776031, 85.20638465881348, 84.09495949745178, 83.09023261070251, 83.50150734186172, 90.74155524373055, 88.04678544402122, 82.157321870327, 73.2267826795578, 80.46953603625298, 86.23467028141022, 87.56317019462585, 91.878332644701, 84.7476352751255, 89.06969055533409, 85.34074544906616, 85.72325572371483, 87.0837727189064, 85.21964594721794, 85.94356790184975, 86.74371376633644, 87.09126591682434, 85.47295555472374, 88.36827859282494, 89.73703354597092, 87.84000054001808, 85.05844339728355, 84.74984675645828, 81.84288874268532, 84.98624727129936, 92.85355031490326, 90.55712834000587, 85.20169571042061, 84.86293628811836, 83.05361777544022, 75.02404063940048, 81.60906448960304, 91.83228671550751, 81.83889135718346, 38.69697913527489, 24.486229978501797, 11.766111385077238, 4.132147170603275, 1.0187540715560317, 0.5262616672553122, 0.6748046027496457, 0.2517147618345916, 1.7098131333477795, 0.9823796327691525, 0.5201325961388648, 0.1740770012838766, 0.4022771108429879, 46.661431565880775, 84.65799048542976, 93.75849455595016, 84.69479531049728, 61.237156838178635, 74.85055714845657, 49.38728749752045, 40.98654627799988, 50.94352439045906, 54.081737995147705, 69.87530171871185, 86.55409634113312, 93.12186911702156, 93.045075237751, 17.00524650514126, 0.3684747184161097, 0.33239039999898523, 0.133004886447452, 0.14169579197186977, 0.16176394012290984, 0.21262912399834022, 0.13209511729655787, 0.11501924178446643, 0.13377927301917225, 0.08161409132299013, 0.24132135469699278, 0.20200289029162377, 0.16190500755328685, 0.06699468751321547, 0.15521818277193233, 0.1227207160263788, 0.11322028323775157, 0.13917541393311694, 0.1283108172356151, 0.209933020232711], [0.09828768568695523, 0.018615622284414712, 0.051680362594197504, 0.04541659167443868, 0.07764772017253563, 0.09665665289503522, 0.03114685445325449, 0.0903268159891013, 0.061839766858611256, 0.0633923991699703, 0.016880505136214197, 0.06987281041801907, 0.06056015954527538, 0.06029195850715041, 0.07066197314998135, 0.05972709877823945, 0.025099378763115965, 0.0674359685217496, 0.44421682599931955, 55.96613667905331, 81.10423117876053, 77.98777520656586, 58.524353206157684, 52.92227581143379, 68.53844225406647, 49.38474543392658, 43.2715118676424, 45.11613808572292, 90.41196092963219, 115.7028566300869, 91.98925629258156, 50.98518155515194, 24.474942684173584, 1.8395802075974643, 0.17924488725839183, 0.15450493432581425, 0.06959552920307033, 0.15257212944561616, 0.08329226533533074, 0.1503550968482159, 1.0222629457712173, 1.796856487635523, 0.4692750860704109, 0.9111528110224754, 41.13396316766739, 69.89556983113289, 63.44813659787178, 80.76174795627594, 93.04053828120232, 85.046306848526, 77.04545617103577, 89.43770840764046, 92.36349061131477, 93.68402615189552, 93.9548148214817, 95.11244550347328, 92.95075669884682, 97.56209805607796, 91.61236971616745, 90.08257940411568, 86.92508563399315, 89.22778487205505, 86.3963820040226, 82.04282641410828, 82.37672209739685, 83.18203568458557, 80.77503964304924, 84.53185245394707, 83.69859516620636, 86.152503490448, 84.64171975851059, 84.20133098959923, 89.69588175415993, 85.55316925048828, 84.75634440779686, 84.58817303180695, 87.97459691762924, 81.90862521529198, 76.15793779492378, 85.8610363304615, 83.83047088980675, 75.94435125589371, 76.63541257381439, 80.70899158716202, 86.30657762289047, 66.31649628281593, 35.800535157322884, 35.24286188185215, 28.148743249475956, 85.11889815330505, 82.4132989346981, 83.71468350291252, 78.64846095442772, 88.59281614422798, 77.2844709455967, 83.4686467051506, 70.94140291213989, 81.38260424137115, 84.65874284505844, 88.91604200005531, 81.95972487330437, 81.71222895383835, 79.73883524537086, 78.63174185156822, 76.05958387255669, 79.12974312901497, 77.67431482672691, 83.9153279364109, 79.02157053351402, 81.25807732343674, 78.44885766506195, 80.0750184059143, 80.08689656853676, 81.85549646615982, 80.28858974575996, 82.07348316907883, 76.53880655765533, 78.01392540335655, 75.09261935949326, 82.06993415951729, 81.41185507178307, 82.36609026789665, 78.23809057474136, 83.30980762839317, 72.8325766324997, 73.2593621313572, 69.06214535236359, 77.56255522370338, 27.767393812537193, 7.583311032503843, 9.618273787200451, 7.199130747467279, 0.9604916791431606, 0.2211295795859769, 0.0993173784809187, 0.5843360885046422, 0.15063623723108321, 0.3361002478050068, 0.2757879247656092, 0.04727999461465515, 0.1221677714784164, 0.37557196570560336, 42.72760905325413, 76.36476069688797, 80.4537744820118, 70.51518738269806, 64.25324499607086, 68.98192405700684, 41.02413006126881, 35.22538661956787, 42.081381529569626, 40.08734732866287, 52.99319140613079, 57.762509286403656, 61.89531572163105, 59.31070201098919, 13.951808251440525, 0.0925679609645158, 0.05806101064081304, 0.010439718080306193, 0.03954973988584243, 0.0719962062430568, 0.0074170224888803205, 0.04283449663489591, 0.06353996039251797, 0.11272097370238043, 0.018359258501732256, 0.022945343371247873, 0.06559961315360852, 0.04895724094239995, 0.06919128136360087, 0.04246555647114292, 0.05010515043977648, 0.0033351706088069477, 0.05103942901769187, 0.058587237872416154, 0.05079794529592618, 0.0819202717684675, 0.031168870264082216, 0.0734392752929125, 0.037674677805625834, 0.05061167736130301, 0.08103363536065444, 0.05448092364531476, 0.06335990052320994, 0.046452711467281915, 0.009316992436652072, 0.14221949590137228, 0.05472448538057506, 0.09163050228380598, 0.08552321320166811, 0.04090533569979016, 0.027355652418918908, 0.0553557227976853, 1.597225887235254, 72.66452684998512, 92.72449404001236, 91.9103117287159, 81.08786925673485, 68.95005896687508, 84.10708844661713, 59.48482006788254, 50.154739916324615, 50.056955963373184, 107.61332631111145, 119.46614429354668, 95.2059356868267, 60.16181834042072, 26.51747938245535, 0.8205831272061914, 0.09377471535117365, 0.15659310040064156, 0.04807563258509617, 0.052398987900232896, 0.13292767340317369, 1.194374947808683, 2.9681998025625944, 1.2651879480108619, 0.979496359359473, 2.0438060676679015, 58.865483701229095, 81.46439105272293, 73.96737053990364, 88.1916868686676, 97.78839111328125, 88.87536898255348, 83.06001663208008, 93.23771730065346, 95.12927860021591, 97.33550861477852, 97.48303949832916, 97.66839355230331, 94.42731186747551, 99.81701865792274, 96.29099026322365, 94.75363835692406, 91.57868072390556, 91.4803496003151, 88.75822886824608, 85.66418409347534, 84.74820524454117, 85.79959362745285, 83.7719464302063, 87.64436423778534, 86.91083639860153, 86.38095483183861, 88.0206048488617, 90.2128592133522, 91.60597085952759, 86.80158466100693, 87.75955885648727, 86.87595427036285, 89.52362939715385, 82.52166911959648, 80.67528739571571, 86.66746705770493, 89.77124691009521, 82.9823487997055, 80.86737468838692, 82.99076154828072, 92.92146027088165, 64.53749254345894, 41.09198302030563, 48.69774989783764, 28.68095599114895, 83.64740431308746, 84.89483937621117, 85.98269060254097, 82.3222254216671, 88.95365238189697, 82.2210368514061, 81.99880957603455, 73.65204825997353, 85.16818150877953, 85.5975204706192, 91.1147028207779, 87.54141256213188, 84.32226330041885, 82.46616169810295, 82.34646812081337, 80.21866589784622, 81.79773956537247, 80.04332810640335, 85.27506977319717, 83.57533738017082, 82.49367982149124, 82.96410217881203, 84.10860076546669, 81.68784186244011, 84.49242576956749, 82.61681601405144, 85.34826904535294, 80.36165222525597, 81.02391108870506, 79.82608616352081, 80.98602712154388, 83.75328183174133, 87.34998643398285, 82.53220975399017, 87.13183254003525, 81.84109523892403, 78.95727798342705, 74.22732219099998, 81.81489944458008, 81.87739849090576, 33.7697721272707, 18.45469582825899, 10.582322906702757, 1.9722306146286428, 0.11808060095063411, 0.14618099114159122, 0.6367819430306554, 0.6135232129599899, 0.6197996449191123, 0.0867050611122977, 0.42424812563695014, 0.1432348578236997, 0.42601143883075565, 39.713435992598534, 85.67844092845917, 86.32657214999199, 81.31511986255646, 53.887929394841194, 27.60338321328163, 22.48137015849352, 36.910045221447945, 57.50929847359657, 55.53314991295338, 70.15999764204025, 71.4429759979248, 69.74025696516037, 74.85116511583328, 17.826452739536762, 0.057396584379603155, 0.11395713940146379, 0.041375482542207465, 0.048859474118216895, 0.10798883231473155, 0.032098313749884255, 0.04805294513062108, 0.0733551305893343, 0.02716093327762792, 0.07716948020970449, 0.02208546324254712, 0.10464452934684232, 0.027397533667681273, 0.08740886943996884, 0.02034719382209005, 0.051489556426531635, 0.019484847907733638, 0.11237916274694726, 0.049077305593527853, 0.15702038450399414, 0.2199211998959072, 0.11959340961766429, 0.16291377920424566, 0.20934917265549302, 0.2439457521541044, 0.18329125450691208, 0.19880527281202376, 0.22617474402068183, 0.1991961768362671, 0.15850487281568348, 0.2765831508440897, 0.1415814270148985, 0.15347878157626837, 0.16436350531876087, 0.3713193704606965, 0.10660063024261035, 0.16317547531798482, 1.8458455963991582, 90.86961597204208, 105.49574553966522, 103.77663418650627, 80.79426661133766, 73.76926437020302, 91.99830740690231, 70.7046528160572, 68.47052469849586, 54.79426056146622, 101.00272983312607, 130.5117791891098, 111.52023866772652, 72.86932066082954, 40.327874422073364, 3.8525073509663343, 0.3302226756932214, 0.2603553200606257, 0.1888116606278345, 0.28470904449932277, 0.23379747639410198, 0.34940220590215176, 2.562425988726318, 9.852622412145138, 2.931508971378207, 1.6491904738359153, 66.86458647251129, 93.94292145967484, 85.95326498150826, 97.60954231023788, 108.4605060517788, 93.42305615544319, 90.46581164002419, 98.30273151397705, 100.66623508930206, 101.69181525707245, 101.15124106407166, 99.54250618815422, 96.24587148427963, 102.46274068951607, 97.9688510298729, 96.94290608167648, 93.42956900596619, 96.51024609804153, 90.47830536961555, 89.58348378539085, 88.19608703255653, 90.37102192640305, 88.27356487512589, 92.09378108382225, 89.02829557657242, 91.98582127690315, 90.90167105197906, 94.26550894975662, 96.7990306019783, 91.42636209726334, 92.24919274449348, 93.25462639331818, 93.73850762844086, 87.20650613307953, 83.36708575487137, 93.03130477666855, 92.16952621936798, 87.93159082531929, 84.01414543390274, 88.64580050110817, 91.88397914171219, 70.67620754241943, 41.74159616231918, 44.71364848315716, 37.27885723114014, 86.29462346434593, 85.33088877797127, 89.1370989382267, 83.99997219443321, 91.21248677372932, 83.39448988437653, 84.05930981040001, 74.85079273581505, 83.6828488111496, 88.35774555802345, 94.91705998778343, 89.21400681138039, 86.90304681658745, 87.55349591374397, 85.05866378545761, 85.86130991578102, 85.03277957439423, 83.73706430196762, 88.00407573580742, 89.31165397167206, 86.53200432658195, 86.1567896604538, 87.30979219079018, 87.02521026134491, 87.28481993079185, 86.7639134824276, 88.30297529697418, 82.67470210790634, 83.62785056233406, 80.55699214339256, 83.23116704821587, 90.22089958190918, 90.50045818090439, 84.1551710665226, 89.82750669121742, 85.33852636814117, 82.08090797066689, 82.44568839669228, 90.00801220536232, 72.57177382707596, 36.15351341664791, 22.668677307665348, 12.921237051486969, 2.548964973539114, 0.3633828728925437, 0.1936188479885459, 0.8488067064899951, 0.6553885946050286, 1.138554874341935, 1.5257650217972696, 0.23279545828700066, 0.1556417709798552, 1.0495435819029808, 55.71254588663578, 90.3575250506401, 95.6778247654438, 89.40320625901222, 87.3471137881279, 95.3501683473587, 56.612428799271584, 53.66687625646591, 61.67520873248577, 54.97290417551994, 70.05649879574776, 75.64376458525658, 77.59984642267227, 88.40712010860443, 24.881940744817257, 0.28748755634296685, 0.2220551564823836, 0.15730437473393977, 0.17349297559121624, 0.15164391050348058, 0.12171061593107879, 0.11263618333032355, 0.29836714442353696, 0.17614561918890104, 0.14370828866958618, 0.1416532669099979, 0.15467300108866766, 0.17777197645045817, 0.2107949208584614, 0.1564121647970751, 0.15401355834910646, 0.1730043307179585, 0.22009541164152324, 0.10631557132001035], [0.06679535406874493, 0.04637277845176868, 0.06977512151934206, 0.048733472285675816, 0.0134827230067458, 0.0732781105034519, 0.045800211519235745, 0.07181701468653046, 0.042116806434933096, 0.07843658604542725, 0.0773671364004258, 0.01713186127744848, 0.023628681410627905, 0.020132848585490137, 0.026929453706543427, 0.043740187684306875, 0.033534525355207734, 0.005508753474714467, 4.624796435236931, 68.5280992090702, 63.6016483604908, 63.21852631866932, 44.89106856286526, 57.7263618260622, 47.10338205099106, 54.508344903588295, 52.10413031280041, 37.966947108507156, 43.32360327243805, 52.739068642258644, 51.32889971137047, 32.52957187592983, 3.716416941024363, 0.04873112709901761, 0.11582663908484392, 0.04858469394093845, 0.051505508890841156, 0.06159707343613263, 0.054411592209362425, 0.8217744820285589, 6.859210012480617, 3.0300851818174124, 0.34246042370796204, 15.558812320232391, 72.7677521109581, 70.11349573731422, 75.4258082807064, 73.77386972308159, 83.55066150426865, 85.6978426873684, 97.22227469086647, 94.561847448349, 91.86814159154892, 90.8085760474205, 93.56598168611526, 91.99707627296448, 96.80569544434547, 97.409498244524, 93.54299291968346, 87.05513745546341, 88.14583092927933, 84.5104444026947, 83.91481876373291, 83.63140717148781, 84.37873587012291, 82.47772827744484, 85.5561862885952, 79.78875696659088, 80.78257843852043, 81.89572870731354, 84.59626659750938, 85.5052462220192, 85.38076490163803, 82.7091434597969, 84.35235768556595, 77.70154416561127, 79.37387242913246, 81.51916891336441, 73.73590216040611, 71.52749106287956, 85.10843351483345, 79.33407336473465, 71.99689507484436, 81.39655709266663, 89.46452736854553, 43.249792233109474, 45.14443516731262, 84.9795900285244, 25.624215714633465, 54.65602397918701, 86.13097384572029, 74.793301820755, 80.95299169421196, 80.5425377190113, 77.33601897954941, 70.29099181294441, 79.52514991164207, 78.04997026920319, 80.67175358533859, 82.30726182460785, 82.93744280934334, 82.87942752242088, 79.41605016589165, 82.64250263571739, 77.85912930965424, 76.36743575334549, 75.29749676585197, 79.33118551969528, 82.57403790950775, 79.57959339022636, 78.05791184306145, 82.63709932565689, 77.41512313485146, 80.89849501848221, 81.80585592985153, 79.3325686454773, 79.07098308205605, 82.02807560563087, 77.93725311756134, 79.37675267457962, 76.04474946856499, 76.00670590996742, 80.23235276341438, 77.21780732274055, 81.4585393667221, 77.46491566300392, 76.27125531435013, 69.71059575676918, 68.34806486964226, 20.22250536829233, 2.8087667701765895, 10.553093925118446, 5.338025763630867, 0.521621344378218, 0.14066251460462809, 1.588958480861038, 1.598111477214843, 0.03735559883352835, 0.7676961401011795, 0.4419785679783672, 0.07646639918675646, 0.14887056400766596, 1.2417851225472987, 50.72224326431751, 78.83356422185898, 73.14229041337967, 61.12609639763832, 48.80991607904434, 46.816641837358475, 43.850528597831726, 27.204938493669033, 41.59174360334873, 50.519364550709724, 58.46772104501724, 69.39943805336952, 64.68304753303528, 71.77490338683128, 14.856772441416979, 0.23991642461623996, 0.039665915683144704, 0.024307100866280962, 0.03115007908490952, 0.04097539444046561, 0.03078442477999488, 0.022985705072642304, 0.04187841375824064, 0.025418244367756415, 0.04696679345215671, 0.07802696505677886, 0.07278888675500639, 0.059038523031631485, 0.021196880552452058, 0.03222817103960551, 0.02073137955449056, 0.05027643441280816, 0.012879793885076651, 0.04654041847970802, 0.019889548457285855, 0.02827712523867376, 0.0229055661111488, 0.023999382319743745, 0.00694623229719582, 0.022325722420646343, 0.03691567966598086, 0.013707073321711505, 0.03447323826549109, 0.10060487853479572, 0.06876334417029284, 0.029481282108463347, 0.13349967630347237, 0.04380360791401472, 0.028396204688760918, 0.08089417839073576, 0.05696917782188393, 11.373657993972301, 89.8863959312439, 75.23228466510773, 82.82657995820045, 56.84205427765846, 79.36106711626053, 65.25495484471321, 54.45618890225887, 33.769331350922585, 32.2264089435339, 46.1204431951046, 60.25695003569126, 61.34487345814705, 36.49604983627796, 2.3381769843399525, 0.08001698952284642, 0.09476007224293426, 0.045440262474585325, 0.11459999514045194, 0.028319336743152235, 0.14793021837249398, 1.299711351748556, 5.082748336717486, 2.2865786030888557, 1.2775607965886593, 27.584752812981606, 87.95863017439842, 79.21802759170532, 89.85204577445984, 85.65897077322006, 89.39528748393059, 91.30167558789253, 103.5658822953701, 99.50317829847336, 95.73355257511139, 93.60037744045258, 98.57234224677086, 95.80865934491158, 100.52827209234238, 98.73721539974213, 94.02777850627899, 91.71234235167503, 92.35574662685394, 87.67951235175133, 85.43995812535286, 86.71063274145126, 88.70100393891335, 87.93824046850204, 90.26449084281921, 84.11243095993996, 85.84177896380424, 84.15744334459305, 84.69005316495895, 86.10522642731667, 88.85795071721077, 87.18087270855904, 86.9486291706562, 84.2597034573555, 82.67990782856941, 83.54571416974068, 77.95074999332428, 77.04838961362839, 87.99134641885757, 84.61078941822052, 76.9970315694809, 83.95561337471008, 90.72447136044502, 44.84430827200413, 49.178959876298904, 83.09908613562584, 30.417468510568142, 49.360719323158264, 87.56006196141243, 78.05858060717583, 85.17367601394653, 82.12176337838173, 78.90581354498863, 69.42164406180382, 78.8178862631321, 80.95803022384644, 83.90898987650871, 83.67938339710236, 82.45097771286964, 85.97699090838432, 81.35997265577316, 84.32699024677277, 80.57919055223465, 79.54425528645515, 78.67767378687859, 78.58006462454796, 82.21827059984207, 82.16277837753296, 79.64475229382515, 83.63026723265648, 78.81723269820213, 82.01683580875397, 84.10482376813889, 81.7773574590683, 82.1449801325798, 83.68976444005966, 83.2607826590538, 82.10575863718987, 77.87974700331688, 79.0796086192131, 81.66062772274017, 80.75593426823616, 85.01919150352478, 84.27506223320961, 80.09746760129929, 74.40982639789581, 80.07032945752144, 78.47485587000847, 33.221590742468834, 19.64978300035, 8.000029921531677, 1.2612835387699306, 0.23968769470229745, 0.444328355952166, 2.0631021447479725, 0.2306149690411985, 0.4241993516916409, 0.26790892879944295, 0.33262295939493924, 0.09155864754575305, 0.3580567758763209, 46.4229753613472, 88.60491469502449, 78.71242672204971, 72.11902052164078, 46.895404011011124, 28.38226731866598, 27.621111162006855, 40.48636771738529, 64.43634197115898, 69.64319497346878, 77.7236133813858, 85.54886788129807, 72.87768021225929, 88.13506230711937, 20.850993543863297, 0.2452952289604582, 0.05160910157428589, 0.0734912627376616, 0.05438420696009416, 0.026456033992872108, 0.028961541247554123, 0.03252156799135264, 0.019875364159815945, 0.036153453183942474, 0.0667044409783557, 0.051381499724811874, 0.09192358382279053, 0.027593245431489777, 0.05335160494723823, 0.030678212315251585, 0.04329909963416867, 0.0282688614242943, 0.05769233393948525, 0.14200888923369348, 0.12553411623230204, 0.11083219302236103, 0.13686825492186472, 0.147922336764168, 0.2077628468396142, 0.2234565539401956, 0.16797982767457142, 0.10798797142342664, 0.15996736387023702, 0.24256045930087566, 0.22936033870792016, 0.10713957788539119, 0.24424602510407567, 0.2072994943591766, 0.19468163314741105, 0.23810435232007876, 0.13747543562203646, 16.26715511083603, 106.28957614302635, 84.62249279022217, 88.78887802362442, 65.14653146266937, 80.02161607146263, 64.91507828235626, 79.55145210027695, 79.10666316747665, 53.89833323657513, 58.8673759996891, 76.11509889364243, 74.01126578450203, 54.19694781303406, 6.464896146208048, 0.18927260854979977, 0.23734558053547516, 0.3044101857813075, 0.35516967298462987, 0.09505250811344013, 0.1581250861636363, 2.3924836702644825, 14.332153592258692, 11.344686448574066, 2.095362888649106, 27.97381203621626, 102.42732658982277, 83.31717923283577, 96.03397965431213, 90.20750150084496, 99.11333441734314, 97.03162372112274, 107.77694553136826, 105.2777436375618, 99.36351299285889, 97.46410891413689, 100.34595027565956, 98.99893775582314, 101.31319597363472, 100.99593579769135, 97.70702227950096, 95.06080627441406, 95.0270564854145, 92.33403459191322, 89.44994375109673, 89.85125541687012, 92.47827485203743, 92.99789696931839, 95.02546817064285, 88.96882876753807, 89.05149713158607, 89.30511832237244, 90.86574777960777, 92.46871456503868, 94.11500662565231, 90.77723532915115, 91.60234585404396, 89.92835327982903, 86.62655845284462, 87.65048950910568, 77.70953133702278, 79.90838974714279, 92.27305546402931, 88.73942747712135, 79.29056569933891, 86.86447888612747, 92.62384504079819, 51.127886697649956, 49.945538341999054, 79.84795778989792, 31.123622618615627, 57.46775910258293, 88.67954269051552, 79.05352681875229, 87.10112258791924, 83.59153971076012, 79.67332676053047, 70.25515973567963, 80.23559018969536, 84.46333453059196, 85.85830047726631, 86.06955394148827, 86.77253901958466, 90.40766716003418, 86.73341631889343, 89.50510159134865, 84.11180019378662, 84.11914139986038, 82.20673441886902, 82.38712593913078, 87.39268854260445, 87.8954091668129, 82.72648572921753, 86.07254058122635, 83.63044202327728, 86.14760935306549, 89.84836757183075, 83.901686668396, 84.8931522667408, 87.37362876534462, 86.22155338525772, 83.04735571146011, 78.73736098408699, 83.17936062812805, 86.91661208868027, 83.02862271666527, 87.25448995828629, 85.57903066277504, 80.38834199309349, 79.78658348321915, 80.26772886514664, 68.17278787493706, 34.24019068479538, 25.48368025571108, 10.201221406459808, 2.0141073362901807, 0.634296223288402, 4.435207508504391, 4.050110997632146, 0.18021472584223375, 1.7387307691387832, 1.154595713596791, 0.2600277657620609, 0.17383293859893456, 2.3644497245550156, 62.349015176296234, 92.81221613287926, 85.75293213129044, 79.25379887223244, 71.6765570640564, 63.2211671769619, 65.23892730474472, 42.5744316726923, 57.292596101760864, 70.34467533230782, 77.14124903082848, 92.1312090754509, 80.3899835050106, 102.79456168413162, 24.814686253666878, 0.42825269512832165, 0.1749782357364893, 0.2501263580052182, 0.25041662680450827, 0.11192827834747732, 0.13875298347556964, 0.08864774397807196, 0.10194359419983812, 0.1058762198954355, 0.1654735504416749, 0.07964697695570067, 0.268908572033979, 0.14541530254064128, 0.14121320302365348, 0.19210975005989894, 0.27557584864553064, 0.2648999058874324, 0.14727706904523075], [0.06451259687310085, 0.15843494766158983, 0.03449480878771283, 0.05583715028478764, 0.18498249031836167, 0.12102049280656502, 0.051972134242532775, 0.07390761500573717, 0.09813068434596062, 0.056313594250241295, 0.09881476638838649, 0.020660600930568762, 0.013988885348226177, 0.0536396361712832, 0.21445384249091148, 0.052654676328529604, 0.10565127493464388, 0.15607340406859294, 16.24707318842411, 75.20506292581558, 63.39033789932728, 61.24688811600208, 56.586472392082214, 45.22089846432209, 42.457796931266785, 48.16109709441662, 62.06762507557869, 46.03585973381996, 34.113197699189186, 52.66172759234905, 46.48931600153446, 5.791714293882251, 0.08566704142140225, 0.30540332780219615, 0.08244535609264858, 0.21301325963577256, 0.03819556157395709, 0.11513180332258344, 0.24762322747847065, 5.029921671375632, 5.8115326054394245, 0.5293033446650952, 3.2822486758232117, 64.05483484268188, 73.93485188484192, 84.87207099795341, 82.54230961203575, 89.18736264109612, 77.08225339651108, 90.43566405773163, 94.59275498986244, 88.5116297006607, 89.86244201660156, 97.73031502962112, 99.61793214082718, 94.91451412439346, 95.85079148411751, 90.41798740625381, 92.61162489652634, 93.91082838177681, 85.53254395723343, 79.89646598696709, 82.79555082321167, 88.36305767297745, 83.65405395627022, 82.07803532481194, 78.91457587480545, 77.52532482147217, 80.22728383541107, 79.77292701601982, 83.09709504246712, 82.14127153158188, 84.06012296676636, 82.76560083031654, 83.20836067199707, 80.92801943421364, 78.54793354868889, 79.89993140101433, 77.85684183239937, 74.45619150996208, 79.3951740860939, 83.41978892683983, 75.70126309990883, 81.54094934463501, 80.8834782242775, 52.75512658059597, 56.03133738040924, 68.56338411569595, 49.35581758618355, 25.261988751590252, 75.69596618413925, 79.77874830365181, 78.45986947417259, 80.50523892045021, 74.76782038807869, 70.96232458949089, 76.95463344454765, 79.30039197206497, 80.69088935852051, 77.26360246539116, 80.080246925354, 78.17299246788025, 78.82838889956474, 77.89104759693146, 76.935725659132, 77.15122729539871, 72.84199252724648, 70.04002287983894, 70.78416734933853, 77.92923554778099, 77.29591593146324, 76.7041052877903, 75.26822313666344, 77.90490925312042, 80.15027716755867, 80.40140569210052, 75.59026345610619, 79.52758938074112, 79.77494090795517, 74.94743674993515, 78.45739960670471, 80.48921898007393, 79.75956693291664, 76.11710518598557, 78.90995532274246, 77.44636505842209, 77.07123398780823, 80.23786246776581, 75.7042421400547, 64.2956355214119, 19.831194765865803, 3.815713687799871, 7.549772132188082, 4.065987495705485, 0.5074213875923306, 0.4723825177643448, 1.276318144518882, 0.22434524609707296, 0.09691066035884432, 3.1509120482951403, 0.9027130482718349, 0.02285120564920362, 0.08380250670597889, 2.5251488015055656, 60.92647410929203, 79.06431064009666, 68.99241149425507, 53.066846653819084, 38.26922468841076, 45.44843025505543, 36.11936844885349, 27.80830431729555, 33.56786236166954, 49.95900101959705, 42.6196226477623, 58.244638815522194, 60.14938160777092, 70.58324933052063, 6.082963915541768, 0.11102224219939671, 0.10945670393994078, 0.10944802081212401, 0.04155549417191651, 0.02362719525990542, 0.05384045762184542, 0.015410952546517365, 0.02169441449950682, 0.041350958272232674, 0.07873282913351431, 0.0994660826108884, 0.013724874661420472, 0.02713912897888804, 0.010837520367203979, 0.08760424723732285, 0.03930047845642548, 0.0030341747606144054, 0.05224580119829625, 0.024235186756413896, 0.057320466003147885, 0.03211337934772018, 0.06179837728268467, 0.06814179549110122, 0.05825597654620651, 0.11830464049126022, 0.059170254244236276, 0.06499242503196001, 0.08177996875019744, 0.02365587370150024, 0.05450646836834494, 0.04774893917783629, 0.15576140518533066, 0.04931228068016935, 0.12125373497838154, 0.11656402959488332, 26.36573262512684, 94.84523624181747, 73.54696109890938, 79.24051478505135, 66.37223929166794, 59.98229317367077, 35.80699101090431, 30.45137219130993, 32.68083415925503, 34.23306226730347, 39.67226900160313, 58.065254241228104, 53.63626889884472, 4.3287253472954035, 0.14081713365158066, 0.16048697114456445, 0.12479000928578898, 0.05570272136537824, 0.037887358776060864, 0.1090533689421136, 0.4472003784030676, 1.5023041306994855, 1.9234745996072888, 0.7029512361623347, 8.329028617590666, 82.64150708913803, 77.55163460969925, 92.93377161026001, 87.48240932822227, 95.01269325613976, 85.13057872653008, 96.72930434346199, 97.6858726143837, 93.54087263345718, 94.0096002817154, 100.03666207194328, 99.44026127457619, 97.96065106987953, 98.37637156248093, 91.39016523957253, 94.0209312736988, 97.27980360388756, 91.59750491380692, 87.87242040038109, 88.14450860023499, 90.8452744781971, 86.60547718405724, 85.96411719918251, 80.92047303915024, 85.3892308473587, 83.02527889609337, 83.12233328819275, 83.81273344159126, 85.38714855909348, 87.76825278997421, 89.23358336091042, 86.39904946088791, 85.07928147912025, 86.04632198810577, 83.39436069130898, 77.42784485220909, 77.66353860497475, 82.10422351956367, 84.53763574361801, 80.85988909006119, 86.38536259531975, 81.26153513789177, 58.04229587316513, 60.52057608962059, 68.43064203858376, 53.68360675871372, 25.58200377970934, 74.54385280609131, 83.31826597452164, 79.69249293208122, 80.86029186844826, 72.88850203156471, 71.60930067300797, 77.86851480603218, 80.1863220334053, 83.98357227444649, 82.93455496430397, 82.58824154734612, 81.80790022015572, 81.62756949663162, 81.71203896403313, 78.22197183966637, 79.03268873691559, 79.28229734301567, 74.63548108935356, 72.70051091909409, 77.97186926007271, 77.12172567844391, 78.0122534930706, 76.54478743672371, 79.6299634873867, 82.3758253455162, 81.48176372051239, 78.18086564540863, 82.16809809207916, 83.04226398468018, 80.83481043577194, 78.69571521878242, 82.12228775024414, 76.98335990309715, 79.97354865074158, 81.06093630194664, 80.94729959964752, 80.86091503500938, 82.66899481415749, 78.94736811518669, 80.56959986686707, 71.02328851819038, 34.57339100539684, 18.367714695632458, 6.183080468326807, 0.6446438399143517, 0.5880812625400722, 0.2745157649042085, 1.8268476845696568, 0.3471474425168708, 0.9832722879946232, 0.879105746280402, 0.05373279425839428, 0.06340741281746887, 1.5723654837347567, 58.75815846025944, 84.84405890107155, 77.10231631994247, 56.50043360888958, 35.090288668870926, 28.301139771938324, 20.67607942968607, 33.52484107017517, 48.54571245610714, 69.42621901631355, 57.11050987243652, 72.93115854263306, 66.3415901362896, 87.07670509815216, 9.40444216132164, 0.19919528625905514, 0.05658064495946746, 0.09294492745539173, 0.05548168010136578, 0.031146238470682874, 0.06839763605967164, 0.07592895068228245, 0.009114943659369601, 0.026293063929188065, 0.05798760110337753, 0.027404259381000884, 0.024765586713328958, 0.037005435005994514, 0.10532044034334831, 0.07290384543011896, 0.027896284736925736, 0.021986499705235474, 0.11660013507935219, 0.19371474831132218, 0.17846426664618775, 0.13320013065822423, 0.340234930627048, 0.19206075347028673, 0.20676203101174906, 0.2207081436063163, 0.19700559438206255, 0.1524899440119043, 0.23056150472257286, 0.24584464088547975, 0.18078365625115111, 0.1617132662795484, 0.37063573370687664, 0.2109058274072595, 0.2513406303478405, 0.3446069819619879, 38.66786129772663, 109.7810035943985, 87.98926413059235, 87.12508410215378, 77.9696349799633, 70.0188048183918, 65.30101597309113, 74.46767449378967, 95.15001028776169, 70.07812723517418, 55.08209511637688, 70.35765543580055, 68.07401597499847, 10.489167105406523, 0.4311261425027624, 0.5267755303066224, 0.35151735646650195, 0.27038464439101517, 0.11182241098140366, 0.6020504410844296, 1.275360833387822, 12.99976458773017, 16.4857554808259, 2.2796601243317127, 6.439344892278314, 91.68540179729462, 84.0169344842434, 103.27860251069069, 97.54304587841034, 105.74558213353157, 94.0002603828907, 102.60093927383423, 97.86900758743286, 97.50279083848, 95.7391382753849, 105.96217051148415, 103.65389317274094, 101.20535016059875, 100.33436849713326, 94.78475108742714, 99.69018146395683, 102.0348608493805, 94.00167390704155, 91.21861204504967, 89.85997974872589, 95.54536387324333, 89.55408096313477, 88.51659223437309, 86.80489048361778, 87.45299890637398, 87.49746412038803, 88.79868909716606, 88.52510377764702, 89.33516710996628, 92.96380519866943, 92.73565784096718, 90.92561736702919, 87.7338494360447, 89.46159392595291, 88.20662766695023, 83.206247985363, 80.98954573273659, 84.2850860953331, 89.09359887242317, 84.79710102081299, 89.67675358057022, 86.39623001217842, 56.98953576385975, 56.79343968629837, 69.18202891945839, 51.50621719658375, 32.83746935427189, 78.7077833712101, 84.98286545276642, 81.9754408299923, 85.58274686336517, 76.83120086789131, 73.24051514267921, 81.1503455042839, 81.97928622364998, 86.7115218937397, 84.4345472753048, 84.77021366357803, 85.25117665529251, 85.01187309622765, 87.27565482258797, 84.26018223166466, 84.78984341025352, 80.45718669891357, 77.11119264364243, 75.73329538106918, 83.83022010326385, 82.5786280632019, 81.95165410637856, 78.78954738378525, 83.60502138733864, 85.55852696299553, 84.78157505393028, 80.63706144690514, 85.9033052623272, 84.93550479412079, 82.10727855563164, 80.74151784181595, 85.6379958987236, 82.07578584551811, 84.3701559305191, 83.41206774115562, 82.17837274074554, 82.64287501573563, 88.15464645624161, 84.71585378050804, 75.8685453236103, 60.00644847750664, 36.47513195872307, 21.109600067138672, 7.600086182355881, 0.6836019025649875, 2.422170052304864, 3.582393857650459, 1.0192150343209505, 0.39890312938950956, 7.181269805878401, 3.464266271330416, 0.12694621545961127, 0.1494194712722674, 5.1896612998098135, 73.54620113968849, 93.56856554746628, 85.08200973272324, 70.20785227417946, 53.83500583469868, 61.760244369506836, 52.016165032982826, 42.753143683075905, 48.595907762646675, 67.20819443464279, 59.56430420279503, 80.59408575296402, 77.48665809631348, 101.1921800673008, 11.43712978810072, 0.39654039836023003, 0.27403770305681974, 0.1588751599774696, 0.10788502811919898, 0.11665385172818787, 0.1690668662195094, 0.17900944832945243, 0.1515444033429958, 0.23290090262889862, 0.13790408527711406, 0.20524606079561636, 0.10158403107197955, 0.09121819472056814, 0.13620548736071214, 0.20005344646051526, 0.08134086223435588, 0.1477464329218492], [0.10027985495980829, 0.07934406196000054, 0.07289620873052627, 0.023487113030569162, 0.03412402809772175, 0.10907929958193563, 0.06240662667551078, 0.10018862274591811, 0.03925456177967135, 0.08534230728400871, 0.0651550518523436, 0.051393169997027144, 0.13497758918674663, 0.0685838409117423, 0.11262971180258319, 0.09709364428999834, 0.063725994550623, 0.041154712162096985, 29.512824453413486, 65.17843455076218, 57.960106283426285, 51.215225011110306, 57.09404915571213, 49.20044392347336, 53.378828912973404, 60.538419932127, 44.76978287100792, 45.68957291543484, 53.317466005682945, 52.09171637892723, 9.092345908284187, 0.1130186565569602, 0.2340410789474845, 0.07456880179233849, 0.10061124616186135, 0.05272877235256601, 0.12786736915586516, 0.7605769846122712, 0.6537518324330449, 2.6400617603212595, 1.6303874203003943, 0.37194007309153676, 41.782371774315834, 83.37210148572922, 76.53631389141083, 83.58180463314056, 77.06214487552643, 81.37711733579636, 86.28325447440147, 91.03014215826988, 97.11850225925446, 96.32151022553444, 95.36545112729073, 96.81602329015732, 92.20903649926186, 92.6091930270195, 94.28352758288383, 90.5506306886673, 90.13798043131828, 89.11127552390099, 84.4008506834507, 85.88671535253525, 84.44812014698982, 78.30009564757347, 81.37137204408646, 77.94645622372627, 74.45769622921944, 76.23935982584953, 74.6553236246109, 73.59699681401253, 77.37187385559082, 83.32178458571434, 81.84045687317848, 82.77228847146034, 78.36724564433098, 81.82727918028831, 80.04829064011574, 78.76943126320839, 70.87502807378769, 75.83842813968658, 78.04082795977592, 82.09049105644226, 74.80473920702934, 82.18273490667343, 75.4957777261734, 64.31848749518394, 72.86146268248558, 60.02003654837608, 63.95401105284691, 31.75728991627693, 59.10317234694958, 84.2518150806427, 69.25583615899086, 76.59920051693916, 67.81797051429749, 73.58160004019737, 70.13542056083679, 77.47165650129318, 80.38606971502304, 79.01273980736732, 77.55228817462921, 79.69510719180107, 80.39078906178474, 81.28319397568703, 79.63820904493332, 78.69827628135681, 75.32356336712837, 71.80590212345123, 68.68471160531044, 66.3601179420948, 70.07163718342781, 72.29869768023491, 72.69165739417076, 78.77168074250221, 80.89429244399071, 75.79704836010933, 74.99608933925629, 77.54313826560974, 78.50330114364624, 76.7858313024044, 75.12767627835274, 75.28249517083168, 76.41997173428535, 76.17097109556198, 76.2308406829834, 74.81394991278648, 75.95074251294136, 73.10284093022346, 80.37771016359329, 74.65837866067886, 59.819566905498505, 13.61520616337657, 5.408259769901633, 6.913435952737927, 3.5002059303224087, 0.2412275323877111, 1.1089145648293197, 2.628583051264286, 0.12048484772094525, 0.35578390408772975, 0.8216391142923385, 0.5044345103669912, 0.03311048072646372, 0.14253896079026163, 5.434704925864935, 57.10473418235779, 72.26383835077286, 70.95334947109222, 49.86636579036713, 39.117779955267906, 60.35975731909275, 50.75057074427605, 34.45029281079769, 37.36589916050434, 42.093772664666176, 45.600707083940506, 61.436041966080666, 58.64922970533371, 47.70628809928894, 1.521060043014586, 0.053067447734065354, 0.08080866071395576, 0.03760242230782751, 0.034978863477590494, 0.03113948492682539, 0.010172211877943482, 0.022225345092010684, 0.02472440308338264, 0.061791453044861555, 0.033702050350257196, 0.06438036100007594, 0.03795701304625254, 0.034169469799962826, 0.047301895392592996, 0.07174914528150111, 0.03627832695201505, 0.12918485939735547, 0.033319677313556895, 0.008481230252073146, 0.04856979903706815, 0.04701352278061677, 0.07180561529821716, 0.033834790883702226, 0.031018939735076856, 0.05943572788964957, 0.048510026463191025, 0.05079093942185864, 0.00612835819083557, 0.11684694371069781, 0.008109238933684537, 0.07731298930593766, 0.053067611006554216, 0.11460041816462763, 0.10176793526625261, 44.64541554450989, 80.38739964365959, 67.93844684958458, 69.06494960188866, 70.51293030381203, 60.53974226117134, 33.43381695449352, 37.63168729841709, 39.84867453575134, 49.17061172425747, 62.46401600539684, 60.98598651587963, 8.006454426795244, 0.1394793382496573, 0.09762578643858433, 0.1877873929333873, 0.06701459191390313, 0.18307999474927783, 0.014504490591207286, 0.4118302435381338, 0.1459751490619965, 0.8285868633538485, 0.6549542304128408, 1.8777483282610774, 58.43497820198536, 87.35045000910759, 85.85487306118011, 88.69978040456772, 84.45676848292351, 86.89860105514526, 96.41631513834, 97.3961153626442, 101.74144819378853, 101.83296248316765, 99.57947060465813, 95.73821872472763, 94.82214868068695, 96.1546839773655, 97.38400921225548, 94.43878725171089, 93.94438058137894, 92.68300026655197, 89.60234597325325, 91.20079100131989, 86.48799508810043, 83.09926852583885, 83.65469232201576, 82.39978685975075, 77.60720282793045, 80.75135931372643, 79.03276473283768, 76.84221267700195, 79.42203864455223, 85.1534914970398, 84.10876035690308, 84.4937252998352, 83.20622518658638, 82.92905285954475, 82.18820661306381, 82.89803132414818, 75.05136117339134, 76.15243569016457, 80.57482838630676, 84.66293022036552, 76.42354354262352, 85.34907460212708, 77.39576697349548, 67.53801673650742, 72.8325842320919, 61.19499050080776, 66.08730778098106, 37.04152576625347, 58.77820238471031, 84.34031993150711, 73.8793596625328, 75.96208870410919, 67.86682829260826, 74.57527711987495, 73.52841049432755, 79.77602005004883, 81.08080923557281, 82.13618740439415, 80.45392647385597, 82.4528244137764, 82.51289919018745, 82.2521723806858, 80.26240915060043, 78.26184689998627, 78.06126326322556, 76.38773426413536, 73.17107766866684, 70.84431812167168, 73.12788918614388, 76.37812837958336, 73.07862862944603, 78.45842555165291, 81.94787710905075, 77.98690125346184, 78.72275456786156, 81.68658033013344, 80.69224208593369, 80.06130874156952, 79.78059500455856, 77.41165772080421, 78.10990825295448, 79.39588084816933, 80.18479451537132, 77.16761961579323, 79.92166623473167, 77.2950191795826, 81.58296748995781, 78.8936921954155, 84.59733054041862, 58.083880841732025, 31.342333182692528, 14.216922875493765, 4.106736984103918, 0.28443528106436133, 0.41865075880195946, 0.6373159924987704, 0.49212898942641914, 1.7222195863723755, 1.2647398095577955, 0.1842291362117976, 0.02296813101565931, 0.0557662492064992, 3.9971062168478966, 55.67715458571911, 81.6417883336544, 79.35623377561569, 55.41653037071228, 38.13667260110378, 27.753862738609314, 29.465634785592556, 47.429921329021454, 57.83757425844669, 54.93601955473423, 62.79135704040527, 78.61815378069878, 66.11034214496613, 64.57111313939095, 2.3130764812231064, 0.09390534818521701, 0.017349067493341863, 0.0442345211195061, 0.025047910821740516, 0.06011111196130514, 0.03608907929447014, 0.037963696086080745, 0.038108863882371224, 0.014822980483586434, 0.012886902732134331, 0.06048277209629305, 0.01361463140710839, 0.10474235183210112, 0.04972681839717552, 0.08596678744652309, 0.043426292613730766, 0.1835002432926558, 0.29021483031101525, 0.1486167495022528, 0.1325523099512793, 0.12255785171873868, 0.163773394015152, 0.1521696924464777, 0.1491067005554214, 0.2017041016370058, 0.09596902338671498, 0.13134565204381943, 0.12935868522617966, 0.27490037551615387, 0.22708152973791584, 0.18629491911269724, 0.2054999495157972, 0.5197197839152068, 0.21851846657227725, 58.921162113547325, 95.18059864640236, 85.51994383335114, 80.21008595824242, 80.18380656838417, 77.23929896950722, 86.31378963589668, 88.32094073295593, 66.14228323101997, 68.2833543419838, 71.50657698512077, 76.40322983264923, 14.518874622881413, 0.35554784175474197, 0.38194027554709464, 0.36403153964783996, 0.25773565750569105, 0.2713848516577855, 0.2788302255794406, 4.700786182656884, 4.78774594143033, 9.219543132930994, 4.777157809585333, 1.2183869280852377, 61.74212694168091, 94.83778104186058, 89.74423035979271, 98.8215708732605, 91.57838433980942, 94.35548052191734, 95.73950305581093, 102.38390251994133, 105.48051595687866, 103.85629311203957, 103.44913735985756, 100.04712671041489, 95.25094047188759, 99.1091014444828, 98.81526321172714, 98.22023034095764, 96.8092292547226, 96.43832355737686, 91.28421172499657, 93.56425657868385, 90.57397663593292, 85.25724872946739, 88.65494281053543, 88.09991419315338, 83.4298811852932, 86.18401899933815, 83.70158180594444, 81.49722129106522, 84.46344092488289, 90.46490728855133, 89.31676849722862, 90.8384196460247, 88.48483353853226, 86.9460529088974, 86.60598635673523, 86.7615196108818, 76.90847352147102, 79.22206297516823, 84.51999709010124, 89.20633122324944, 80.02166166901588, 87.76212751865387, 78.66512686014175, 70.29255732893944, 70.71792930364609, 62.22715951502323, 62.35986739397049, 36.65646582841873, 60.83532840013504, 85.62936276197433, 75.50444886088371, 76.85070902109146, 69.77294281125069, 75.89945286512375, 75.08421421051025, 81.25578984618187, 86.63582235574722, 84.48237910866737, 84.09835651516914, 84.24831926822662, 87.36545160412788, 86.71085312962532, 85.09369030594826, 82.85544320940971, 84.49013829231262, 78.54647442698479, 75.87862998247147, 72.3961016535759, 76.36978402733803, 78.47460508346558, 76.78770080208778, 84.31473970413208, 85.8703838288784, 82.1847715973854, 80.43419793248177, 84.55642193555832, 83.84460613131523, 81.1428751051426, 81.37710973620415, 79.95613798499107, 81.6610836982727, 84.50453951954842, 85.07037475705147, 79.49317842721939, 79.9065962433815, 80.836231559515, 85.5934926867485, 82.90437698364258, 75.00582441687584, 49.55477111041546, 33.43973323702812, 17.881749272346497, 4.880918841809034, 0.7247333892155439, 4.278531465679407, 3.779492606408894, 0.2196537150302902, 1.0251657525077462, 3.1435542181134224, 0.9844837104901671, 0.23536493681604043, 0.3716983407502994, 8.901763334870338, 69.13295835256577, 88.43944117426872, 92.15866640210152, 69.35146942734718, 59.993764758110046, 82.65943452715874, 71.89390540122986, 51.39379642903805, 54.451241567730904, 60.975974053144455, 63.815956860780716, 81.14456221461296, 79.33829873800278, 77.14462324976921, 3.0756820226088166, 0.32459197158459574, 0.28682888543698937, 0.11830329720396549, 0.08584794733906165, 0.2314981396193616, 0.11665210025967099, 0.15247784700477496, 0.15253518533427268, 0.10008021723479033, 0.08210980144212954, 0.17352511058561504, 0.11219761858228594, 0.18171815376263112, 0.21862518740817904, 0.3194029937731102, 0.174141404859256], [0.016518776792509016, 0.005893737015867373, 0.024310434964718297, 0.05178696468647104, 0.05223329229920637, 0.04302356617699843, 0.10226725964457728, 0.05199103303311858, 0.05558402968745213, 0.02666388358193217, 0.05269574307021685, 0.0518224059487693, 0.10343540750909597, 0.049079179516411386, 0.08620986307505518, 0.13488253491232172, 0.09115191351156682, 0.14309064368717372, 29.317754320800304, 60.16757123172283, 53.385098576545715, 58.987217769026756, 55.775903686881065, 46.845892667770386, 39.96418833732605, 45.60942381620407, 55.708571299910545, 56.798846796154976, 76.76580637693405, 28.876981772482395, 0.5028795031830668, 0.0438992670387961, 0.09719325535115786, 0.08785346784861758, 0.09887540727504529, 0.12135018449043855, 0.16830031672725454, 0.3410346986493096, 0.21349385962821543, 0.9535676194354892, 0.18132625526050106, 17.537729032337666, 70.88208809494972, 68.37821245193481, 81.09259620308876, 76.77412793040276, 81.44195705652237, 90.22859036922455, 101.83742344379425, 96.63192316889763, 93.69015902280807, 94.24547642469406, 92.17120572924614, 91.54290944337845, 93.66878136992455, 96.95445746183395, 92.54743114113808, 91.83037161827087, 92.88987636566162, 88.54487791657448, 89.01623502373695, 83.37429776787758, 83.06739583611488, 74.61693048477173, 71.86399340629578, 71.74625292420387, 72.34346687793732, 75.23527890443802, 74.73086357116699, 75.9837095439434, 74.29569572210312, 75.56366488337517, 76.7738239467144, 77.21171244978905, 77.48030483722687, 76.85662910342216, 79.45732355117798, 81.5762722492218, 78.29099133610725, 77.3210021853447, 80.00466898083687, 74.23286229372025, 74.99497219920158, 77.40952223539352, 73.92564877867699, 63.15177530050278, 66.44154757261276, 57.505612671375275, 68.22001174092293, 55.63934661448002, 65.96883773803711, 82.91478082537651, 75.14003321528435, 74.78099808096886, 66.24482452869415, 73.06418940424919, 69.84855115413666, 75.20105794072151, 76.61548644304276, 78.66287738084793, 74.78004813194275, 74.33129221200943, 76.66884317994118, 74.34238001704216, 72.18102559447289, 71.43428966403008, 72.79573380947113, 68.78233596682549, 69.68944609165192, 69.49260905385017, 68.06541323661804, 75.45768857002258, 72.0490662753582, 74.15575683116913, 75.06737351417542, 77.68597260117531, 75.60439869761467, 74.76092755794525, 75.32579004764557, 79.40693825483322, 76.13864243030548, 72.99967646598816, 74.06197026371956, 78.26450675725937, 72.64330878853798, 76.05183228850365, 73.38622212409973, 72.48715236783028, 75.15425205230713, 79.47711288928986, 71.28319457173347, 47.1109664440155, 16.353940553963184, 5.768830021843314, 5.136261815205216, 2.6159848272800446, 0.30082095181569457, 4.059322653338313, 1.4049273496493697, 0.12086668270057999, 0.8508960600011051, 0.3607273497618735, 0.15654668648494408, 0.11375442918506451, 0.08788227802142501, 5.683818133547902, 48.0316836386919, 67.46413350105286, 63.24575565755367, 42.347538247704506, 42.36880950629711, 34.06516447663307, 30.273828618228436, 30.05883425474167, 32.64917805790901, 43.35450321435928, 48.21422964334488, 66.73298433423042, 60.58154761791229, 53.181824684143066, 0.8524976740591228, 0.024744420661590993, 0.030742105664103292, 0.06425907922675833, 0.03225517779355869, 0.04966788073943462, 0.013582531664724229, 0.009516195077594602, 0.059324531903257594, 0.020269797096261755, 0.08737385491258465, 0.10166348540224135, 0.03015761056303745, 0.01659990281041246, 0.04005320544820279, 0.015377254403574625, 0.0717521584010683, 0.05878188465430867, 0.0569672593701398, 0.05198207902139984, 0.03782533007324673, 0.024950999322754797, 0.07882967940531671, 0.033813491245382465, 0.08326596362167038, 0.04375661883386783, 0.08710530877579004, 0.05677723616827279, 0.04605612630257383, 0.03860833297949284, 0.0635869828693103, 0.05207589019846637, 0.031311960046878085, 0.3816327889217064, 38.86122152209282, 76.06545835733414, 60.87346315383911, 68.16967204213142, 62.4732381105423, 50.15917047858238, 32.22720310091972, 45.24425961077213, 64.05597478151321, 67.61342748999596, 89.5657767355442, 29.178039617836475, 0.6542995967902243, 0.05320942429534625, 0.0673257744347211, 0.060739803811884485, 0.3838986251503229, 0.09506941423751414, 0.2685184992151335, 0.5448420764878392, 0.3645387530559674, 0.7247346360236406, 0.6158356263767928, 30.420401953160763, 80.99174961447716, 75.5839329957962, 88.66527065634727, 86.2316532433033, 87.77348130941391, 96.65010139346123, 102.43304148316383, 98.30353707075119, 95.58571770787239, 96.27698421478271, 93.05508390069008, 92.11799338459969, 94.43258598446846, 97.23055064678192, 93.20652097463608, 93.65069434046745, 95.79922825098038, 91.7402708530426, 93.11819851398468, 88.27035784721375, 87.01854541897774, 80.20830765366554, 74.17676210403442, 73.67747649550438, 76.38856261968613, 77.6785098016262, 79.36045914888382, 81.55407384037971, 78.31490725278854, 78.49891617894173, 80.07979854941368, 78.4341524541378, 83.28654527664185, 81.19050174951553, 83.10662493109703, 83.87280821800232, 81.51870533823967, 79.8351600766182, 83.27510789036751, 79.2328391969204, 80.86878821253777, 81.5887887775898, 76.33118569850922, 67.48212173581123, 63.676481544971466, 58.57463590800762, 66.6995157301426, 62.00813926756382, 71.97107166051865, 83.53383600711823, 78.09014171361923, 74.26762282848358, 65.9383937716484, 73.98084461688995, 71.86905473470688, 77.99296572804451, 80.09657084941864, 80.87818130850792, 79.8013798892498, 78.23055937886238, 77.93853744864464, 76.60673931241035, 72.79827207326889, 74.08074885606766, 74.68007549643517, 72.05793499946594, 73.47292587161064, 72.38584220409393, 68.77243369817734, 75.34924238920212, 74.87451866269112, 75.65421402454376, 77.07399263978004, 79.06796604394913, 77.75541007518768, 78.2659050822258, 78.80163833498955, 79.27332982420921, 80.31404837965965, 77.39224076271057, 76.20653718709946, 81.78288236260414, 75.72432026267052, 79.95728552341461, 76.6380724310875, 74.32167872786522, 77.71862044930458, 81.25728696584702, 77.15587824583054, 76.36137127876282, 57.40278638899326, 24.76622175425291, 10.280553549528122, 2.994031053967774, 0.5112790712155402, 1.4197168685495853, 0.8784807391930372, 0.945541262626648, 0.42748193023726344, 0.24177928949939087, 0.0571525476698298, 0.06441553879994899, 0.09050646767718717, 3.852690691128373, 50.92450261116028, 75.0948004424572, 69.75326746702194, 47.86461420357227, 42.20241643488407, 17.77860190719366, 23.569190986454487, 42.276896238327026, 49.26295056939125, 57.12413214147091, 61.06764793395996, 83.28613489866257, 70.6206925213337, 68.67820635437965, 1.7159702279604971, 0.0338462385116145, 0.0448313303058967, 0.029547836056735832, 0.08835611704853363, 0.04072028859809507, 0.031990739444154315, 0.024634608780615963, 0.06791610096115619, 0.042281815549358726, 0.07426751952152699, 0.06426449690479785, 0.08796813708613627, 0.04850601515499875, 0.014033453171578003, 0.05079154798295349, 0.15351465699495748, 0.1111679628957063, 0.20666788215748966, 0.13676135597052053, 0.2090688783209771, 0.15245951595716178, 0.2523456170456484, 0.1551819362794049, 0.19823856884613633, 0.16437667101854458, 0.2176262714783661, 0.14446394343394786, 0.1652164408005774, 0.15732041996670887, 0.24642639560624957, 0.16316803899826482, 0.2793484227731824, 0.6803760537877679, 58.62158998847008, 93.72646227478981, 79.47606414556503, 82.92861208319664, 81.82831272482872, 70.18034934997559, 57.97389194369316, 64.8244759440422, 82.56469801068306, 80.09741440415382, 102.57920444011688, 42.5287277251482, 1.2437383364886045, 0.2362188370898366, 0.3051924688043073, 0.13844558590790257, 0.48544695891905576, 0.2283799764700234, 0.8550992875825614, 1.2527228356339037, 1.518924676347524, 2.0153966546058655, 1.135959376115352, 33.206988126039505, 93.22218373417854, 83.18696022033691, 96.11654922366142, 89.52866032719612, 92.0348234474659, 97.48678609728813, 109.01964604854584, 101.57229647040367, 99.51339974999428, 101.48016661405563, 95.57203844189644, 95.23909270763397, 98.21850523352623, 100.55979520082474, 98.3482226729393, 97.79298886656761, 98.6225375533104, 96.11642003059387, 97.33186081051826, 91.63469731807709, 89.41911980509758, 83.57700929045677, 77.99761667847633, 77.41351962089539, 81.02992236614227, 83.59285444021225, 85.58264046907425, 85.10914027690887, 83.36053490638733, 85.65431222319603, 84.09196525812149, 85.13009995222092, 84.91199925541878, 84.84258458018303, 85.50314113497734, 91.78731992840767, 85.70058614015579, 84.51863676309586, 87.85190910100937, 81.95705741643906, 82.84901395440102, 86.11523509025574, 77.91735738515854, 68.2522264122963, 68.17971110343933, 60.84615021944046, 67.70019203424454, 68.62225815653801, 75.8598817884922, 84.62529703974724, 83.33736374974251, 77.14834704995155, 67.98317044973373, 76.84307143092155, 74.0335401892662, 79.13669675588608, 81.33216574788094, 83.78293544054031, 83.13127040863037, 80.43553546071053, 82.8470304608345, 81.2319803237915, 79.59140315651894, 80.07591515779495, 79.60892021656036, 76.82347968220711, 78.20333003997803, 77.0886978507042, 75.11964350938797, 83.13769966363907, 78.09100046753883, 77.42251753807068, 81.78227439522743, 82.9826831817627, 81.66337877511978, 83.26838985085487, 82.20026716589928, 83.90199825167656, 82.23796114325523, 78.7695300579071, 80.58483704924583, 85.11952131986618, 78.551284968853, 82.88871422410011, 80.17347872257233, 76.53419360518456, 81.7822515964508, 83.08390974998474, 79.20559465885162, 65.93853816390038, 50.87414011359215, 27.099712640047073, 14.654633738100529, 3.0846419418230653, 2.348059304058552, 9.763406999409199, 4.416622705757618, 0.4975147551158443, 2.3279094602912664, 1.1781050520949066, 0.3672421001829207, 0.14982175984187052, 0.24426391086308286, 8.308960944414139, 65.57573363184929, 86.74588724970818, 82.103471159935, 59.843577817082405, 64.8261858522892, 44.84070986509323, 47.30271935462952, 46.05241544544697, 48.91121864318848, 59.769204407930374, 67.87064328789711, 91.32012739777565, 83.01897883415222, 77.43200942873955, 1.8208283325657248, 0.11865502325235866, 0.08559796973713674, 0.16587941616307944, 0.131637048907578, 0.1593745659920387, 0.11332889655022882, 0.12583428528159857, 0.18981719651492313, 0.12354697872069664, 0.24699614237761125, 0.15217594132991508, 0.23304771428229287, 0.12099056199076585, 0.14366459101438522, 0.21626043773721904], [0.0687697489047423, 0.013073742120468523, 0.00811941006759298, 0.022490295523311943, 0.033243340003537014, 0.03756019039428793, 0.09463033740757965, 0.038006054164725356, 0.06666048357146792, 0.017886146779346745, 0.0938434901763685, 0.05581338671618141, 0.0847886576957535, 0.040342194042750634, 0.12456703843781725, 0.12299502122914419, 0.16774624411482364, 0.3011847526067868, 25.489096865057945, 55.43913155794144, 57.352416291832924, 52.31213115155697, 51.8941155821085, 55.192395597696304, 30.309639796614647, 39.5629108697176, 46.03150136768818, 82.41511523723602, 49.94980551302433, 2.192344847135246, 0.2777018048800528, 0.0802704032685142, 0.04903134438791312, 0.16730796138290316, 0.16401223198045045, 0.1274211602867581, 0.19806321419309825, 0.18830668850569054, 0.37963448208756745, 0.4368360189255327, 8.649304881691933, 54.30773466825485, 69.38125222921371, 72.48208343982697, 72.70665898919106, 84.16850075125694, 90.30365154147148, 98.81006509065628, 93.17417711019516, 99.8098674416542, 92.1433000266552, 90.90065270662308, 93.67463305592537, 94.27276656031609, 93.75464156270027, 92.53806084394455, 93.47503736615181, 90.67444324493408, 88.10452714562416, 86.59696564078331, 85.23014858365059, 81.9353985786438, 77.37039193511009, 71.01341664791107, 71.14159896969795, 71.84657514095306, 71.09637379646301, 73.53297024965286, 73.05864930152893, 73.56897711753845, 73.24412494897842, 75.50269335508347, 76.80845528841019, 76.39964282512665, 82.59788542985916, 79.54499244689941, 80.18011316657066, 75.10392755270004, 76.55785873532295, 69.34720605611801, 73.6300778388977, 74.9163544178009, 76.93605244159698, 75.671396702528, 68.42077776789665, 67.71245017647743, 58.37515041232109, 65.94875201582909, 62.445427402853966, 53.5451839864254, 60.72557128965855, 77.84374013543129, 72.85178080201149, 71.89803957939148, 68.60369995236397, 68.2232415676117, 71.3753168284893, 79.24531012773514, 74.26573053002357, 77.90891423821449, 75.3255620598793, 72.72717028856277, 71.69548004865646, 73.83574560284615, 72.53886759281158, 71.68636813759804, 70.80847844481468, 70.28553530573845, 63.68244342505932, 62.05545052886009, 60.73535956442356, 65.3841707110405, 72.20372557640076, 75.4083140194416, 77.95656368136406, 75.09580358862877, 76.1079552769661, 73.50955590605736, 75.44877424836159, 74.45701226592064, 77.82917931675911, 73.91320064663887, 73.54308530688286, 74.95403319597244, 75.97183138132095, 73.67806926369667, 70.51594734191895, 71.90162658691406, 71.70779898762703, 73.41656729578972, 72.35807329416275, 64.72575724124908, 47.041019797325134, 13.604979012161493, 1.2148457556031644, 6.4549074321985245, 0.9433341748081148, 0.48563015065155923, 3.9412720128893852, 3.317344067618251, 0.9449881548061967, 0.03024178309715353, 0.004467709068194381, 0.12959830986801535, 0.07591315035824664, 0.053910790957161225, 3.040187177248299, 43.46655920147896, 65.57425931096077, 57.832490131258965, 38.01901951432228, 46.66863597929478, 52.44280993938446, 48.94937999546528, 32.90261685848236, 40.74141763150692, 34.340087324380875, 38.151423409581184, 54.69184845685959, 64.19240266084671, 28.6761112511158, 0.23022753826808184, 0.10000387992477044, 0.03260123383370228, 0.043739360189647414, 0.06472236491390504, 0.08164051178027876, 0.022187339709489606, 0.09698388807009906, 0.05721206791349687, 0.09882145313895307, 0.04973653682100121, 0.07051294247503392, 0.02745638968917774, 0.1366321332170628, 0.06153200563858263, 0.07608520245412365, 0.005265119380055694, 0.04764356905070599, 0.08098880221950822, 0.05829303940117825, 0.07008337997831404, 0.07372518026386388, 0.06399293022695929, 0.05054027904407121, 0.05631613981677219, 0.07872274334658869, 0.021191635423747357, 0.05817343117087148, 0.03049802628083853, 0.04058318052557297, 0.04981747915735468, 0.13820201304042712, 0.4262863303301856, 40.492056012153625, 71.28185704350471, 76.66656330227852, 62.480362728238106, 56.692479103803635, 49.47337947785854, 30.706148520112038, 48.886983543634415, 56.41138918697834, 93.437130600214, 54.60287243127823, 2.064745556563139, 0.21014337457017973, 0.08889208867913112, 0.10251507759676315, 0.05920722062001005, 0.11495844504679553, 0.7096658321097493, 0.20414827595232055, 0.19635621516499668, 0.382134688552469, 0.5167006677947938, 15.569975171238184, 70.49605920910835, 78.49808782339096, 86.54744669795036, 81.4184819161892, 91.05666473507881, 97.70588234066963, 101.16370439529419, 94.66840133070946, 103.15501794219017, 93.55547145009041, 94.9139441549778, 93.69075179100037, 96.26305416226387, 96.42071530222893, 93.63789662718773, 97.61828184127808, 93.18907231092453, 92.77721241116524, 90.49434050917625, 85.91217398643494, 84.48653608560562, 81.35952427983284, 75.50386369228363, 75.94036906957626, 75.77788218855858, 74.73545372486115, 77.61767506599426, 76.64686515927315, 78.0548644065857, 77.49991178512573, 79.75423201918602, 80.15474572777748, 79.72319528460503, 83.56848254799843, 81.58558174967766, 82.84671127796173, 78.3310715854168, 80.69132253527641, 75.21366566419601, 74.06402215361595, 77.86556616425514, 79.64755654335022, 75.83973526954651, 71.11658111214638, 73.25076699256897, 62.56383664906025, 67.50280782580376, 66.86334013938904, 65.01635044813156, 69.48403671383858, 77.58627355098724, 79.8471750319004, 72.08666145801544, 68.02297711372375, 69.38819825649261, 76.34032040834427, 81.58280029892921, 78.19029673933983, 79.07819509506226, 78.26626226305962, 75.50786107778549, 73.99499505758286, 74.77596715092659, 75.85048109292984, 72.66703471541405, 71.47670298814774, 71.48460656404495, 69.00207057595253, 66.07913061976433, 63.96025791764259, 65.86297541856766, 72.36821115016937, 77.31653362512589, 81.08820363879204, 78.29688861966133, 78.94162282347679, 75.53511321544647, 79.14270803332329, 78.49599033594131, 80.60077339410782, 78.22172865271568, 77.12418034672737, 75.27313247323036, 77.04462021589279, 77.60340303182602, 76.97784259915352, 74.24498364329338, 74.94788512587547, 75.6772255897522, 76.70036628842354, 76.0993829369545, 79.51267898082733, 42.70905464887619, 14.343116953969002, 7.714141337200999, 1.6847261670045555, 0.40109193068929017, 2.8433475270867348, 4.2528448440134525, 1.4629229251295328, 0.2307638290221803, 0.1029121785541065, 0.013234681482572341, 0.06263536401093006, 0.05201417319767643, 2.9511403804644942, 50.843901336193085, 75.32338097691536, 63.048527240753174, 44.15256679058075, 38.67321901023388, 21.066411584615707, 33.73319149017334, 46.30753755569458, 58.06109346449375, 46.568142771720886, 58.769105672836304, 65.81693708896637, 74.353908598423, 38.57984282076359, 0.26588832784909755, 0.08717000178876333, 0.06613101315451786, 0.02519340516300872, 0.037949662073515356, 0.04806454489880707, 0.0331050185195636, 0.017615706310607493, 0.026137886416108813, 0.04465934129257221, 0.057227753204642795, 0.052897551577189006, 0.032537605802644975, 0.09646727165090851, 0.030609808563895058, 0.1275844030897133, 0.15347956825280562, 0.09933812892995775, 0.2142978282063268, 0.1169515197398141, 0.20052652107551694, 0.20252022659406066, 0.12450762209482491, 0.16038627654779702, 0.11033310613129288, 0.17102503770729527, 0.095955738943303, 0.2298447088105604, 0.1445471975603141, 0.2034333799383603, 0.2136944918311201, 0.3018932364648208, 0.9762673045042902, 58.1472310423851, 87.7061565220356, 88.09638798236847, 89.09166097640991, 76.85680389404297, 81.9240827858448, 48.3715146034956, 65.09581178426743, 73.39060708880424, 105.39371341466904, 69.22164559364319, 4.392094071954489, 0.49779383232817054, 0.24579767778050154, 0.3108965861611068, 0.16273463959805667, 0.37682999507524073, 1.012953920289874, 0.46946516493335366, 0.357097772648558, 0.7621676742564887, 1.130139750894159, 15.574043802917004, 84.63245585560799, 83.09852376580238, 90.93403771519661, 89.4998274743557, 93.49738776683807, 98.1376987695694, 105.43988093733788, 98.88607621192932, 106.63520559668541, 99.12570655345917, 97.33999237418175, 97.68516585230827, 99.40488517284393, 97.76318326592445, 99.43434879183769, 102.45657742023468, 100.09384140372276, 96.1573438346386, 93.62553209066391, 90.21207645535469, 89.52160030603409, 85.78301131725311, 78.58154654502869, 81.09774872660637, 79.84003141522408, 79.01662319898605, 80.81034734845161, 79.81340244412422, 82.08072558045387, 78.3136685192585, 85.04912629723549, 83.87371256947517, 85.38723975419998, 89.2641869187355, 87.31814414262772, 86.04084268212318, 79.47289511561394, 83.70095103979111, 77.02210262417793, 79.88239914178848, 80.32976433634758, 84.67734664678574, 78.39342623949051, 70.62303319573402, 74.20834600925446, 67.46316075325012, 64.95363861322403, 63.465866446495056, 65.99055737257004, 72.40734905004501, 80.55131524801254, 81.23195752501488, 75.58490574359894, 68.4318807721138, 72.59029403328896, 76.91981211304665, 85.5973532795906, 82.63349711894989, 83.13391506671906, 81.01647108793259, 80.57289808988571, 76.98238715529442, 77.88523390889168, 77.72604525089264, 77.39105522632599, 76.28931194543839, 78.24217915534973, 71.94242119789124, 69.04721215367317, 66.74175426363945, 70.7302938401699, 77.95473217964172, 80.03721803426743, 84.12039533257484, 81.416255235672, 80.91953828930855, 78.96274968981743, 83.13188597559929, 79.66987654566765, 83.40629205107689, 80.71682676672935, 78.88372913002968, 79.39221784472466, 79.67981681227684, 82.70032033324242, 78.07498052716255, 74.6229113638401, 76.05224266648293, 80.9017476439476, 79.29959401488304, 72.38543942570686, 68.74972611665726, 38.27873557806015, 17.92187511920929, 10.017684604972601, 2.222460606135428, 2.787840818054974, 9.90557162091136, 13.291233647614717, 2.086236965842545, 0.6579841522034258, 0.19076310825766996, 0.3719401027774438, 0.3566553338896483, 0.13645792147144675, 5.3988666739314795, 65.13149186968803, 88.56842145323753, 76.44123539328575, 55.706128031015396, 66.1934968829155, 71.16433694958687, 72.25416406989098, 51.07099235057831, 60.68346194922924, 52.202100455760956, 58.019994869828224, 73.4533341228962, 88.88597801327705, 43.596375435590744, 0.46679295832291245, 0.19758881855523214, 0.12645095062907785, 0.2075694579980336, 0.159175269654952, 0.26675791712477803, 0.15930036606732756, 0.15208128781523556, 0.21511021273909137, 0.19577744387788698, 0.0907918308803346, 0.19848776719300076, 0.12518217496108264, 0.31408131995704025, 0.1358848498784937], [0.01371888181893155, 0.03996468207333237, 0.0365423274342902, 0.021343480693758465, 0.015944296974339522, 0.08130733200232498, 0.09931705935741775, 0.11670349398627877, 0.05763096945884172, 0.034152919906773604, 0.11599288016441278, 0.02932169067207724, 0.06471077998867258, 0.04091018192411866, 0.10417597441119142, 0.10006226468249224, 0.049565876252017915, 0.3810840449295938, 32.71788977086544, 60.409865230321884, 58.2896663993597, 52.25046806037426, 47.50501669943333, 44.92616347968578, 31.274079345166683, 46.40575468540192, 65.11906653642654, 51.327243000268936, 7.86222699098289, 0.29644023219589144, 0.07288029708433896, 0.06865785529953428, 0.044546623903443106, 0.1599445057217963, 0.12034672661684453, 0.26632284047082067, 0.19587598624639213, 0.17228541226359084, 0.09318561336840503, 1.7806643689982593, 32.027197033166885, 70.8139805495739, 68.50746631622314, 81.78495705127716, 79.21056479215622, 92.10647240281105, 96.28123238682747, 95.89498311281204, 94.48500797152519, 93.56148272752762, 90.23201778531075, 94.34066131711006, 91.8252494931221, 92.93579310178757, 89.52832594513893, 91.11651912331581, 88.74163895845413, 88.73676002025604, 89.4339770078659, 85.09486824274063, 80.43830931186676, 74.1420167684555, 75.27775302529335, 76.43732160329819, 74.7092655301094, 74.66684460639954, 71.72883465886116, 75.54546386003494, 73.32246914505959, 74.69772934913635, 76.0012798011303, 72.92445570230484, 74.26267549395561, 73.74809950590134, 76.51641055941582, 78.34853544831276, 76.60322070121765, 79.35943320393562, 79.01989102363586, 80.52768051624298, 72.33426377177238, 71.86867475509644, 70.41974410414696, 70.52374452352524, 70.45815244317055, 69.55431774258614, 61.32039897143841, 77.3397807776928, 77.70003944635391, 77.44421437382698, 66.82341948151588, 70.45580416917801, 78.31977099180222, 69.06500279903412, 65.41592940688133, 71.01050600409508, 75.81128239631653, 73.6756905913353, 74.67936873435974, 71.27056404948235, 71.55560195446014, 72.26420313119888, 68.85237380862236, 67.71188780665398, 67.5762502849102, 67.4703423678875, 67.62252420186996, 65.56405305862427, 67.561324685812, 67.21800550818443, 66.19462922215462, 65.85925161838531, 65.37780985236168, 70.2409864962101, 73.41415822505951, 78.03597941994667, 77.81256660819054, 77.01308190822601, 72.6390378177166, 73.02156329154968, 74.25699859857559, 76.75659567117691, 73.58101487159729, 72.44027808308601, 76.31903395056725, 74.75314557552338, 69.79424446821213, 69.62756261229515, 68.35661441087723, 72.14455515146255, 72.93321043252945, 70.86619734764099, 62.03670233488083, 32.41558939218521, 9.843927528709173, 2.869615280069411, 5.557066909968853, 0.15317500568926334, 0.66354930982925, 2.8399198735132813, 0.08289348712423816, 0.05886102357180789, 0.04714034468634054, 0.02636818782775663, 0.06009757889842149, 0.024725969014980365, 0.09049747284734622, 3.0029774364084005, 38.32000896334648, 59.09481659531593, 69.62814778089523, 43.144412487745285, 45.48951365053654, 40.82380101084709, 26.913098953664303, 29.088007248938084, 42.96199947595596, 43.415345549583435, 47.26554214954376, 53.88768620789051, 60.89459761977196, 8.372248448431492, 0.32830692536663264, 0.1419570279540494, 0.02924699536379194, 0.04009922602563165, 0.01599364051799057, 0.006123881648818497, 0.024102125244098715, 0.011273670352238696, 0.02619900413264986, 0.052297929651103914, 0.011341958143020747, 0.0213818942575017, 0.013603362822323106, 0.023574012957396917, 0.020764651890203822, 0.04532289553026203, 0.044892661389894783, 0.02837742093106499, 0.026587429383653216, 0.06467825165600516, 0.04542963863059413, 0.010027032021753257, 0.08933649412938394, 0.16218922042753547, 0.05045430865720846, 0.0237199989715009, 0.01924337902892148, 0.06202255412063096, 0.07836370714358054, 0.08296583167975768, 0.0706033137976192, 0.8914461184758693, 49.85587455332279, 72.03804686665535, 76.58151626586914, 75.50722271203995, 57.033590599894524, 36.862084195017815, 32.33545929193497, 59.50410783290863, 77.02634319663048, 60.77901542186737, 7.494446625933051, 0.339352042065002, 0.061760104727, 0.1557352370582521, 0.00747110186239297, 0.12221391822095029, 0.5701905163004994, 1.1492308764718473, 0.1800456942874007, 0.6782210350502282, 0.04402579950692598, 4.413966648280621, 51.11597813665867, 82.27921172976494, 80.94998225569725, 88.12845066189766, 89.06603515148163, 96.52721598744392, 97.61346369981766, 98.34995537996292, 96.97153374552727, 96.29233539104462, 93.28117176890373, 97.23691910505295, 93.07659074664116, 95.50203859806061, 91.13023638725281, 92.39100873470306, 90.80023169517517, 91.58447161316872, 92.5657993555069, 86.1815795302391, 83.49667400121689, 80.10078862309456, 80.47252267599106, 80.66571190953255, 76.81624487042427, 76.84786677360535, 75.22636458277702, 79.5602448284626, 76.63915157318115, 80.25254487991333, 78.84251654148102, 76.06990411877632, 77.40531206130981, 78.04239347577095, 78.99524554610252, 79.84424158930779, 79.23005774617195, 83.6664716899395, 82.53844901919365, 82.03331172466278, 74.28750336170197, 76.03889778256416, 73.55582222342491, 73.33566963672638, 71.12092047929764, 73.07145461440086, 70.58549121022224, 80.04222616553307, 81.5550085902214, 79.79652374982834, 68.09625998139381, 71.90826863050461, 81.10424637794495, 71.57684281468391, 68.89703661203384, 71.50646299123764, 76.88911736011505, 77.5796391069889, 77.76578351855278, 74.39561516046524, 75.87584093213081, 73.25297087430954, 72.00341552495956, 69.31377544999123, 68.73035475611687, 71.17138177156448, 70.08014872670174, 68.3223706483841, 70.30308276414871, 71.26703783869743, 69.70794349908829, 69.61944624781609, 67.21947222948074, 71.99919015169144, 74.3280927836895, 79.05582189559937, 77.94876649975777, 78.50050449371338, 77.19788119196892, 76.42662897706032, 77.70093619823456, 78.35289761424065, 75.85789069533348, 74.62750151753426, 76.00632593035698, 76.5048135817051, 74.99626412987709, 75.47431647777557, 74.80904057621956, 76.88832700252533, 75.27696266770363, 74.29821878671646, 78.62651333212852, 70.52651077508926, 35.025475546717644, 12.258943989872932, 6.234697848558426, 0.22775955585530028, 0.30719371454324573, 1.0427602333948016, 0.2881374105345458, 0.18121074739610776, 0.04352706513600424, 0.03837238567939494, 0.1841004626476206, 0.0692929036449641, 0.0869146733020898, 3.1735500460490584, 43.36877144873142, 69.76505443453789, 71.46082744002342, 56.4496873319149, 38.3864825963974, 26.518626920878887, 27.88933116942644, 26.9777961820364, 45.93438237905502, 56.36441610753536, 71.04180112481117, 64.59605500102043, 76.44945055246353, 11.565545797348022, 0.2954188588773832, 0.19609741342719644, 0.02427129595162114, 0.11220693995710462, 0.009141244445345365, 0.01483897376601817, 0.0041579510070732795, 0.05595391237875447, 0.0192314675587113, 0.05365438264561817, 0.02422190231300192, 0.028367270206217654, 0.044872166981804185, 0.057594299942138605, 0.15943542210152373, 0.24454609025269747, 0.12559648632304743, 0.16987524315482005, 0.07686136275879107, 0.13239831430837512, 0.14875608030706644, 0.15103874844498932, 0.2602207538438961, 0.529854433843866, 0.22859565942781046, 0.22584028774872422, 0.10733485920354724, 0.24969537800643593, 0.18189055466791615, 0.255788232316263, 0.22026986087439582, 1.2925237999297678, 65.29881209135056, 96.53201133012772, 77.41582989692688, 84.52813625335693, 79.91844400763512, 72.03722611069679, 49.38240475952625, 72.30787798762321, 93.78631666302681, 72.32367753982544, 14.00241393595934, 0.8665829245001078, 0.26383753633126616, 0.2863313793204725, 0.12788849067874253, 0.2710003894753754, 1.0378033993765712, 1.4180867560207844, 0.3048158733872697, 1.7870228528045118, 0.1655595505144447, 2.9146507009863853, 63.86507302522659, 82.42406755685806, 88.92389237880707, 95.01857534050941, 92.94921398162842, 101.53629720211029, 102.964678555727, 102.64006957411766, 100.37301242351532, 99.15162116289139, 96.23359814286232, 101.16132572293282, 99.42307859659195, 99.13471207022667, 93.76321390271187, 95.99705323576927, 93.97226348519325, 94.74032387137413, 95.76747715473175, 91.33090361952782, 88.12653556466103, 83.10889720916748, 84.51565012335777, 85.72655394673347, 80.39973378181458, 81.09693557024002, 76.96987822651863, 83.78950148820877, 80.20451545715332, 83.14697876572609, 84.31507408618927, 81.87668412923813, 80.98032742738724, 81.58884197473526, 84.20132339000702, 86.5211521089077, 85.67223966121674, 88.45384240150452, 85.93818739056587, 88.13881650567055, 75.86615145206451, 76.3751569390297, 77.26510718464851, 75.97282692790031, 72.75838181376457, 73.5829147696495, 71.92085355520248, 81.15929782390594, 85.48028916120529, 80.17964959144592, 67.58120521903038, 74.18555483222008, 86.07400730252266, 73.54870140552521, 71.18860244750977, 75.28160601854324, 79.88204196095467, 81.61936953663826, 81.32327422499657, 78.44828769564629, 78.36016282439232, 78.86851474642754, 76.60461142659187, 75.66915482282639, 74.3260332942009, 75.9776222705841, 75.7347697019577, 72.18800202012062, 75.803112834692, 73.89081224799156, 72.84811779856682, 72.82207399606705, 71.51587128639221, 75.7714681327343, 79.38329592347145, 84.92027521133423, 82.49408259987831, 82.10151046514511, 77.82860934734344, 79.178646504879, 81.09299898147583, 81.61449059844017, 78.26579868793488, 77.79705584049225, 80.97971186041832, 79.7723950445652, 79.62202191352844, 76.36398553848267, 75.62711387872696, 78.02647233009338, 78.25942263007164, 76.27120971679688, 73.64994317293167, 59.61424492299557, 34.01503376662731, 15.743656251579523, 8.379974383860826, 0.25447602616623044, 2.741905082948506, 6.120330635458231, 0.18653130799066275, 0.20167423761449754, 0.18614289758261293, 0.1692157707293518, 0.36644509295001626, 0.13919957826146856, 0.2144180264440365, 5.610439321026206, 57.08063207566738, 82.91421845555305, 85.77976629137993, 64.70322445034981, 66.1031149327755, 63.603145480155945, 46.80926263332367, 45.00015690922737, 58.379672169685364, 62.67780013382435, 67.25949928164482, 75.26059314608574, 90.75001358985901, 13.375165443867445, 0.49313397612422705, 0.31087892304640263, 0.12404116001562215, 0.1696756499586627, 0.17391261557349935, 0.14331753307487816, 0.08251554099842906, 0.30156502907630056, 0.16652821650495753, 0.18622922420036048, 0.0750892551150173, 0.08744653343455866, 0.14272371103288606, 0.13142201903974637], [0.054643839903292246, 0.04142486875934992, 0.06224787386599928, 0.03407531723496504, 0.04039592182380147, 0.03638096597569529, 0.031816906193853356, 0.02329640705283964, 0.08061531640123576, 0.04128111475438345, 0.036546108676702715, 0.11281454368145205, 0.022110913341748528, 0.10358329527662136, 0.07855104748159647, 0.041044796380447224, 0.2506459504365921, 1.9781402475200593, 39.484984651207924, 51.14705286920071, 50.71407750248909, 63.70268873870373, 50.776207968592644, 31.454191580414772, 35.09576037526131, 42.6262266933918, 45.312218964099884, 17.31121178716421, 1.4106240752153099, 0.10817664762726054, 0.18573004083009437, 0.047947348648449406, 0.1755949604557827, 0.11262056112173013, 0.2063980817911215, 0.5448806681670249, 0.28585174412000924, 0.1540898362873122, 0.175700998515822, 18.472224287688732, 73.33199143409729, 81.75210401415825, 76.59046098589897, 82.63345912098885, 90.03486916422844, 91.53049930930138, 91.51348382234573, 96.56027421355247, 88.29890191555023, 90.78641563653946, 93.19664150476456, 89.28783684968948, 89.05071437358856, 88.29465374350548, 85.8454267680645, 86.31553754210472, 85.84941655397415, 86.58912286162376, 77.2726383805275, 75.50736710429192, 80.23257315158844, 82.70295739173889, 81.89276486635208, 73.6441370844841, 75.62430962920189, 74.77354288101196, 76.60312950611115, 76.57061845064163, 71.8748152256012, 73.69513034820557, 69.04301717877388, 73.78726780414581, 72.70924285054207, 75.42599067091942, 75.67546248435974, 74.1520482301712, 75.82954421639442, 75.36257207393646, 76.37888833880424, 74.24648836255074, 72.41255477070808, 72.59085640311241, 71.94012612104416, 68.12799587845802, 65.67278042435646, 81.82790234684944, 77.89143517613411, 76.92519262433052, 74.08975437283516, 72.49567151069641, 68.77532914280891, 62.060382664203644, 67.69373998045921, 68.58030840754509, 62.26466730237007, 65.72524040937424, 70.61614036560059, 69.68038737773895, 71.14812701940536, 69.3178716301918, 66.57245814800262, 67.33003109693527, 64.57758039236069, 66.31154134869576, 66.67153403162956, 67.05622538924217, 69.02843356132507, 67.18501567840576, 66.12895354628563, 64.65177521109581, 66.55868008732796, 68.45185250043869, 68.0222475528717, 67.84470587968826, 66.75780460238457, 67.73157075047493, 71.81634396314621, 76.13035887479782, 77.68924042582512, 73.74157905578613, 73.57906937599182, 69.92864325642586, 74.36601474881172, 70.27704656124115, 70.0243829190731, 71.77459180355072, 72.02406361699104, 68.45268085598946, 73.65971624851227, 71.09278678894043, 76.28609731793404, 73.78334641456604, 67.43393272161484, 53.44587251543999, 27.938652522861958, 8.405328523367643, 5.183429159224033, 3.160412725992501, 0.5871819576714188, 1.8709205696359277, 0.5618969269562513, 0.23274065810255706, 0.09130888516665436, 0.05637438727717381, 0.012811130382033298, 0.08815835695713758, 0.02579602165496908, 0.12382515051285736, 3.442125809378922, 46.87263183295727, 51.932143941521645, 46.36384293437004, 29.53954841941595, 31.498525701463223, 74.36140179634094, 61.9865982234478, 33.111666440963745, 39.28519517183304, 41.89564749598503, 53.01627516746521, 63.83310154080391, 30.471038036048412, 0.23785224475432187, 0.017840543659985997, 0.01772558498487342, 0.054751777861383744, 0.03584549529477954, 0.05168356125068385, 0.10703543972340412, 0.08501081218128093, 0.002834113779499603, 0.06360792627674527, 0.04832193655602168, 0.00483258272652165, 0.04792060164618306, 0.020363394905871246, 0.1616976218065247, 0.042980837024515495, 0.051678826348506846, 0.02445472146064276, 0.013562695912696654, 0.04098205521586351, 0.016118228559207637, 0.09266966488212347, 0.015563504712190479, 0.03854084949125536, 0.04827046119316947, 0.07313102425541729, 0.053665644736611284, 0.11183719456312247, 0.11115858214907348, 0.031890671962173656, 0.07566801898065023, 3.66505628451705, 56.242264062166214, 67.32048600912094, 70.86503461003304, 60.344428941607475, 53.770466297864914, 30.4356125369668, 38.52884195744991, 56.08462952077389, 52.854198664426804, 18.6900931969285, 0.9395698830485344, 0.07520593557273969, 0.13692504406208172, 0.09923451027134433, 0.22966062650084496, 0.3053342190105468, 0.39928215905092657, 0.3974314802326262, 0.7016533089336008, 0.34160508366767317, 0.9005444927606732, 31.49800892919302, 91.53093248605728, 94.03964146971703, 85.89341819286346, 88.79447892308235, 95.33324405550957, 94.5353552699089, 95.16540706157684, 99.24058958888054, 90.93976020812988, 93.15975308418274, 95.96264228224754, 91.01272389292717, 92.74584129452705, 91.66756555438042, 90.15285283327103, 88.66884246468544, 89.42949324846268, 86.45588681101799, 79.64619621634483, 79.68070596456528, 85.14148414134979, 86.99795052409172, 81.42804220318794, 79.2921008169651, 81.0393838584423, 80.45853182673454, 79.05214369297028, 77.31081113219261, 75.24086460471153, 75.35276859998703, 72.42355898022652, 78.85136246681213, 77.85375639796257, 78.31600159406662, 79.19368609786034, 75.84609612822533, 76.34202271699905, 77.39744648337364, 77.59586423635483, 78.2920552790165, 76.1388248205185, 74.77116420865059, 75.24330407381058, 70.15049815177917, 69.30048376321793, 82.98227280378342, 81.6489015519619, 81.12475007772446, 77.6985651254654, 74.77364927530289, 72.75778144598007, 62.05284766852856, 68.9298440515995, 68.68290290236473, 64.62044209241867, 67.41755560040474, 72.41905242204666, 72.98261538147926, 73.62180188298225, 74.32639807462692, 69.42880287766457, 71.06559544801712, 67.60100975632668, 68.21400806307793, 70.6134881079197, 70.2677370607853, 71.77254751324654, 68.79568845033646, 69.67086508870125, 69.28731366991997, 70.52468687295914, 71.6902819275856, 73.63194733858109, 69.60096403956413, 71.39756083488464, 68.48339840769768, 73.48735749721527, 76.67650356888771, 77.56852850317955, 75.0370055437088, 75.20262345671654, 73.60603272914886, 77.10290148854256, 75.4463803768158, 73.10262814164162, 74.57400038838387, 76.86580941081047, 73.44874396920204, 76.59718662500381, 73.9710259437561, 77.66904830932617, 75.22587820887566, 73.52971002459526, 75.42088374495506, 63.68961364030838, 29.91970282047987, 11.085918433964252, 4.15791311301291, 0.5092399462591857, 0.41807621775660664, 0.42982207029126585, 0.08829077094560489, 0.052764536449103616, 0.058328462109784596, 0.03887736893375404, 0.0783241877797991, 0.09398158901603892, 0.14840838412055746, 4.3339077942073345, 55.818222016096115, 59.459152445197105, 50.97026355564594, 38.51525768637657, 20.72123810648918, 40.8608528226614, 53.059368655085564, 49.393545761704445, 49.47722867131233, 49.706831350922585, 68.28080847859383, 74.45575833320618, 42.60515682399273, 0.32856237259693444, 0.03727669369254727, 0.05442470595880877, 0.08286967160529457, 0.037097461317898706, 0.04121701174881309, 0.04797884168510791, 0.05566237450693734, 0.021770939201815054, 0.03829321707598865, 0.04719569034932647, 0.017955897528736386, 0.02441806864226237, 0.004366086322988849, 0.2317018888425082, 0.15171843697316945, 0.11732143582776189, 0.06574326325790025, 0.11999304872006178, 0.13212042453233153, 0.1004494505468756, 0.22327503946144134, 0.163389852095861, 0.15518773987423629, 0.13490638753864914, 0.15371681802207604, 0.1578547217650339, 0.24198698694817722, 0.1670432076207362, 0.08692110030096956, 0.2737208950566128, 4.869394535198808, 74.45774182677269, 78.35393115878105, 74.08692732453346, 86.9828425347805, 84.53056812286377, 57.20485121011734, 57.45466120541096, 72.93035298585892, 67.51771822571754, 27.81202621757984, 1.8657627026550472, 0.22867253108415753, 0.3229940979508683, 0.12410776034812443, 0.49707029771525413, 0.6031421106308699, 1.2317233812063932, 2.15489833150059, 1.1720186099410057, 0.47349003958515823, 0.4811825486831367, 40.702123939991, 90.97552388906479, 91.85610383749008, 92.09130361676216, 93.65225225687027, 100.67407786846161, 98.40625315904617, 98.5218657553196, 101.7978523671627, 95.00577002763748, 96.24780938029289, 99.98515963554382, 95.65368846058846, 97.28323101997375, 93.7964317202568, 95.72197079658508, 92.77101874351501, 93.37823376059532, 93.5703894495964, 86.16182819008827, 82.47985616326332, 87.83602595329285, 89.75096359848976, 88.70355740189552, 83.34894552826881, 82.77957648038864, 85.00294357538223, 84.40208941698074, 84.84134584665298, 80.93352153897285, 80.00871956348419, 77.92905315756798, 82.46493816375732, 79.78030622005463, 82.16176763176918, 84.8196642100811, 79.01356056332588, 82.53920897841454, 82.09063544869423, 81.23080238699913, 82.92193204164505, 79.33251544833183, 79.32009011507034, 77.6012447476387, 71.25031113624573, 71.00011736154556, 85.5137349665165, 83.69607970118523, 83.73499721288681, 80.5534203350544, 79.85268473625183, 74.38634365797043, 62.5011932104826, 72.57684275507927, 70.6687219440937, 65.42096793651581, 71.02411687374115, 77.36197918653488, 75.8217242360115, 78.18604856729507, 78.44428271055222, 72.45885908603668, 74.19520631432533, 72.23359197378159, 71.41871809959412, 72.60221779346466, 73.26180920004845, 75.29329419136047, 73.72983008623123, 71.98091313242912, 70.29697269201279, 74.18276578187943, 73.47716644406319, 74.23396423459053, 72.17642024159431, 72.57711634039879, 74.368135035038, 78.29434275627136, 81.83302447199821, 82.99943268299103, 77.96575158834457, 79.31012704968452, 75.12743309140205, 80.76215073466301, 76.34561732411385, 76.2793792784214, 79.07558843493462, 79.94637250900269, 76.52349337935448, 78.55599671602249, 74.77864980697632, 80.11770531535149, 78.16109910607338, 75.999486297369, 67.9973740875721, 54.0285674482584, 31.065607331693172, 15.310005471110344, 5.190327214077115, 2.215890996158123, 5.298367291688919, 1.8606675323098898, 0.6633269623853266, 0.24081498733721673, 0.21912946191150695, 0.1174447288212832, 0.32837119535543025, 0.15537021914497018, 0.26620115793775767, 7.875324413180351, 68.32697600126266, 70.02897307276726, 63.501785919070244, 47.35748581588268, 39.671820625662804, 92.80798316001892, 82.21553474664688, 50.91248765587807, 57.60289505124092, 60.82301326096058, 73.55089768767357, 88.26219588518143, 50.03491334617138, 0.369357310119085, 0.2464066247921437, 0.19871620024787262, 0.12452106981072575, 0.13453705032588914, 0.07791245167027228, 0.2736864297185093, 0.18061823153402656, 0.11910313201951794, 0.17627730587264523, 0.16057214001193643, 0.06799611190217547, 0.15292717289412394, 0.11120846931589767], [0.07071045765769668, 0.007153418591769878, 0.00943497350817779, 0.012629655793716665, 0.06147638167021796, 0.04042511420266237, 0.0580685211753007, 0.043391934887040406, 0.022222675215743948, 0.08992602655780502, 0.15698875417001545, 0.05994867438857909, 0.036911219358444214, 0.05360320043109823, 0.09263251296943054, 0.19744960649404675, 0.02751647767581744, 18.899817243218422, 54.67284567654133, 55.082444697618484, 41.49618253111839, 85.049909055233, 94.11823645234108, 27.348538488149643, 37.44771257042885, 40.14583759009838, 19.538876451551914, 4.509105943143368, 0.091370802547317, 0.21115273993927985, 0.10717647746787407, 0.2614349965006113, 0.1511698414105922, 0.10731635004049167, 0.8604788489174098, 2.754984931088984, 0.48514125344809145, 0.22300230019027367, 9.673609267920256, 69.25710529088974, 93.01336213946342, 85.40284171700478, 85.84083661437035, 90.86503341794014, 92.26491630077362, 90.45337110757828, 95.10667741298676, 91.22076272964478, 86.65678963065147, 90.09714782238007, 89.86542865633965, 88.89483913779259, 87.53514289855957, 88.60691338777542, 89.47578236460686, 84.48570013046265, 75.13241842389107, 75.3085009753704, 77.42009326815605, 85.53242236375809, 85.67000538110733, 80.05916565656662, 77.64148458838463, 82.53056064248085, 81.48758500814438, 78.63194704055786, 75.94135701656342, 74.2838403582573, 71.85232043266296, 72.22258776426315, 71.30204156041145, 72.59677648544312, 70.32972693443298, 67.0825731754303, 70.40111750364304, 73.73155519366264, 74.43246558308601, 73.73346269130707, 75.96905753016472, 72.63332292437553, 76.7048728466034, 71.90368607640266, 72.77785196900368, 65.60572162270546, 73.14450949430466, 74.28131729364395, 71.12918883562088, 76.03382125496864, 73.81705820560455, 74.77378606796265, 70.01428306102753, 64.89973470568657, 63.826778680086136, 65.81503719091415, 65.36965548992157, 67.7621591091156, 66.64941921830177, 72.92969182133675, 70.92639371752739, 71.18155762553215, 69.36453312635422, 68.90272870659828, 63.61366331577301, 64.26499396562576, 66.30053713917732, 68.62633913755417, 67.42519319057465, 67.769013941288, 70.63280627131462, 70.1753868162632, 68.34979757666588, 68.83879333734512, 71.496651917696, 70.90253859758377, 72.52680703997612, 70.08987620472908, 66.48137703537941, 65.55197730660439, 71.74270391464233, 74.4372609257698, 75.22125765681267, 69.73343253135681, 70.7759065926075, 72.95845627784729, 70.13613492250443, 70.42332351207733, 74.05074566602707, 71.3996659219265, 72.89565324783325, 70.42259395122528, 72.31834262609482, 76.37297585606575, 71.87004268169403, 61.70617327094078, 47.673902437090874, 29.13433436304331, 7.796365125104785, 5.925397295504808, 0.3114046307746321, 0.9369010012596846, 1.7167103569954634, 0.4763102898141369, 0.1681897960952483, 0.032295212949975394, 0.06085589797294233, 0.07208492999779992, 0.11135781911434606, 0.07396387722110376, 0.07768532479531132, 2.6196962781250477, 51.00935585796833, 51.64444997906685, 36.194061040878296, 53.40402536094189, 73.3378355205059, 24.9921253323555, 30.000089406967163, 38.615925684571266, 54.912400022149086, 43.400089368224144, 54.67092677950859, 53.11241000890732, 2.939012381248176, 0.15499123401241377, 0.059686328895622864, 0.031752090726513416, 0.04294922895496711, 0.04389838388306089, 0.030069582571741194, 0.026964230746671092, 0.09867475280771032, 0.004486346715566469, 0.10399863080237992, 0.04247874072461855, 0.06956053694011644, 0.009019735389301786, 0.05218023987254128, 0.07187204493675381, 0.08349994794116355, 0.0344486249377951, 0.020217284582031425, 0.04978724777174648, 0.029689998154935893, 0.024843387909641024, 0.024197914244723506, 0.06918986386153847, 0.04804349759069737, 0.04230348997225519, 0.03600204763642978, 0.020027879218105227, 0.08773016001214273, 0.21170838590478525, 0.01704182206594851, 30.42425874620676, 67.92020782828331, 73.72266367077827, 56.84441015124321, 111.449304074049, 100.31885012984276, 23.47571410238743, 48.367722406983376, 51.48771978914738, 25.64200635999441, 4.1917431727051735, 0.021918301899859216, 0.178544151422102, 0.149897919036448, 0.27383260312490165, 0.18747021385934204, 0.2786264318274334, 0.3351813502376899, 1.8642022926360369, 0.4088541422970593, 0.30147528857924044, 19.608980789780617, 89.67333376407623, 94.3506395816803, 90.07960796356201, 89.64631721377373, 94.8705580830574, 94.6137298643589, 95.7080027461052, 97.21889287233353, 93.60787823796272, 90.12741699814796, 91.40616238117218, 90.8860082924366, 91.66313499212265, 89.3711207807064, 90.52057430148125, 91.82527229189873, 88.14388543367386, 78.23260366916656, 76.61790311336517, 83.11696037650108, 89.30844694375992, 90.98892956972122, 83.2401117682457, 81.81617617607117, 86.62583649158478, 85.92141509056091, 81.74380525946617, 79.73031610250473, 77.70599752664566, 75.44058188796043, 75.77190890908241, 75.83722740411758, 73.3668127655983, 72.28030666708946, 72.03810006380081, 73.73913198709488, 76.36064171791077, 77.89723366498947, 77.42642372846603, 77.43724554777145, 77.41079896688461, 79.87439677119255, 75.77535912394524, 73.45524162054062, 66.33069232106209, 75.58647885918617, 78.63670438528061, 75.54690018296242, 78.13466772437096, 76.66505098342896, 75.829346626997, 73.65041434764862, 64.53479468822479, 66.29261076450348, 67.73252829909325, 68.40429425239563, 71.76715180277824, 72.27209910750389, 73.96440669894218, 71.25171706080437, 75.3849908709526, 72.11476475000381, 70.28434216976166, 69.58969384431839, 67.86318808794022, 66.9282254576683, 70.71663737297058, 69.96129110455513, 70.0790087878704, 71.69187784194946, 72.84053340554237, 72.58643344044685, 74.45314407348633, 74.36198696494102, 74.5756646990776, 72.00133323669434, 74.16438236832619, 70.26641473174095, 67.60327443480492, 71.18984118103981, 76.62054017186165, 77.28798195719719, 73.94794598221779, 72.55313202738762, 77.02385053038597, 73.67339551448822, 73.42104345560074, 76.59702703356743, 75.05358785390854, 76.32420167326927, 73.75798657536507, 75.21935015916824, 79.55199927091599, 76.33081331849098, 72.89978742599487, 70.5831429362297, 61.78088866174221, 27.778920494019985, 9.236469324678183, 0.9002610517200083, 0.5469525663647801, 0.9451218601316214, 0.17481088143540546, 0.16089552344055846, 0.08853282241034321, 0.09177517655189149, 0.07234801392769441, 0.22711755358614028, 0.07196135498816147, 0.7192911312449723, 3.2136086840182543, 61.623014733195305, 57.61658571660519, 41.30317188799381, 51.97578079998493, 58.05919736623764, 23.30933053046465, 32.09627352654934, 40.575826317071915, 59.45273458957672, 56.18225768208504, 63.49721476435661, 67.3697617650032, 3.7998953741043806, 0.13210483943112195, 0.08657204598421231, 0.039905863159219734, 0.11093506211182103, 0.028015559000778012, 0.07186337665189058, 0.027756130148191005, 0.062455793959088624, 0.004511472125159344, 0.03639117050624918, 0.0418459336651722, 0.043035106573370285, 0.04981551246601157, 0.16316750465193763, 0.1257665568846278, 0.16774473013356328, 0.23789686267264187, 0.07844120220397599, 0.2091663668397814, 0.14355582185089588, 0.12876659980975091, 0.14135070814518258, 0.17975668713916093, 0.23753839050186798, 0.16361404006602243, 0.14826146856648847, 0.07832530842279084, 0.1683535287156701, 0.3946874040411785, 0.2628936432301998, 34.48185011744499, 85.51054313778877, 80.4238548874855, 67.73719444870949, 113.27243104577065, 109.7480745613575, 38.78833383321762, 60.150852128863335, 66.60814583301544, 37.28896848857403, 6.372194420546293, 0.22949987731408328, 0.46444118139334023, 0.31220650649629533, 0.48180149984546006, 0.3303814656101167, 0.8543289382942021, 4.931585798040032, 9.783538319170475, 2.911289781332016, 0.28584687563125044, 22.78926383703947, 94.29192513227463, 95.87278470396996, 98.4681062400341, 94.6253876388073, 102.012138068676, 99.27853435277939, 98.63813191652298, 98.50170403718948, 97.21960723400116, 94.50101271271706, 96.80884167551994, 94.68780308961868, 94.97393533587456, 93.53657126426697, 96.8007481098175, 94.95488315820694, 92.27370142936707, 82.20545768737793, 79.71490412950516, 83.44096899032593, 91.6419929265976, 93.29629495739937, 88.13222005963326, 84.85934928059578, 91.55534997582436, 87.89341047406197, 85.46765103936195, 84.26071420311928, 82.10356995463371, 79.1102197766304, 79.4085493683815, 78.9857916533947, 77.89936915040016, 77.32705146074295, 73.93552824854851, 76.78280666470528, 81.01840898394585, 82.55005359649658, 82.17967227101326, 83.32725629210472, 78.83801758289337, 83.13912078738213, 78.53803887963295, 79.98813226819038, 70.4963555932045, 77.5372713804245, 81.39385923743248, 79.03583496809006, 82.22971558570862, 81.18332773447037, 76.86388671398163, 74.76403579115868, 66.25278890132904, 68.65546837449074, 71.21381029486656, 70.5573271214962, 74.57330882549286, 74.64060321450233, 77.92841479182243, 78.91864165663719, 79.50825601816177, 76.84725880622864, 76.21931970119476, 69.85388606786728, 72.65295267105103, 72.58800655603409, 74.33270573616028, 73.19820821285248, 75.06972178816795, 75.60844168066978, 75.0246562063694, 76.9373519718647, 77.36880362033844, 76.8911312520504, 76.62114053964615, 76.00691869854927, 73.97063836455345, 73.51169899106026, 72.1677415072918, 76.37836396694183, 81.82219505310059, 80.59108391404152, 73.8204476237297, 74.99077722430229, 78.92732799053192, 73.51086303591728, 76.56906053423882, 81.80590152740479, 77.00083136558533, 79.20348197221756, 75.73678359389305, 76.92917481064796, 84.39941436052322, 75.99804997444153, 71.06040492653847, 62.44919300079346, 54.701032564044, 27.037357985973358, 11.731877122074366, 0.9715941490139812, 3.0086785554885864, 5.765785910189152, 1.2490690941922367, 0.398309767479077, 0.18770275841234252, 0.38320507330354303, 0.22615904017584398, 0.3891839337302372, 0.37471917865332216, 1.126255290582776, 8.988285642117262, 77.99207657575607, 72.22814306616783, 55.99918730556965, 78.77242550253868, 93.64286676049232, 37.07935653626919, 40.61793565750122, 54.00680601596832, 74.45983171463013, 63.51679511368275, 77.98064678907394, 78.3523428440094, 4.849156346172094, 0.2489395154407248, 0.24921265547163785, 0.15591295174090192, 0.14463557250564918, 0.14458760007983074, 0.12884292227681726, 0.13555177400121465, 0.26777142367791384, 0.15253851015586406, 0.17427004873752594, 0.20275735761970282, 0.21084905310999602, 0.0808853616763372], [0.046130322516546585, 0.03686619325890206, 0.007421415539283771, 0.03331267515022773, 0.05672836945450399, 0.029514958914660383, 0.04744758269225713, 0.030985268494987395, 0.08161780948285013, 0.018844832738977857, 0.032371988127124496, 0.046237117567216046, 0.055124384234659374, 0.030992253959993832, 0.04133464586629998, 0.056299708667211235, 0.5511372105684131, 38.15220236778259, 59.092023745179176, 51.911925226449966, 56.27453193068504, 36.20977319777012, 37.70574912428856, 33.949164301157, 41.86949349939823, 24.522176049649715, 8.289480339735746, 0.3028838848695159, 0.14288653823314235, 0.05723768314055633, 0.17745611839927733, 0.2935148047981784, 0.15685374266467988, 0.3548452950781211, 0.21156669507035986, 0.0913595367455855, 0.15302295447327197, 2.653619907796383, 63.112815991044044, 100.01447886228561, 76.61966621875763, 79.39635202288628, 91.42207592725754, 93.92937898635864, 89.29787591099739, 92.40589633584023, 88.97558480501175, 87.35155194997787, 91.5364345908165, 88.3235701918602, 88.76994743943214, 88.84445384144783, 87.41003081202507, 83.06288927793503, 85.13893827795982, 75.06141543388367, 74.59369853138924, 84.60961908102036, 89.2935973405838, 85.62215834856033, 80.06093636155128, 83.72514814138412, 82.00969979166985, 84.74443584680557, 81.88404053449631, 77.93733671307564, 76.35618835687637, 75.11174753308296, 76.69395223259926, 76.89699813723564, 71.47129207849503, 67.75182366371155, 71.39916434884071, 70.23928418755531, 70.32884538173676, 71.64330884814262, 73.7546655535698, 74.40782770514488, 72.11648225784302, 71.72668397426605, 76.42984360456467, 73.38469460606575, 64.0534745156765, 69.04864847660065, 73.44300627708435, 73.72299045324326, 74.84067007899284, 73.42640116810799, 73.55334475636482, 70.80481544137001, 72.55769178271294, 64.97936323285103, 65.02511277794838, 66.97005361318588, 68.87798443436623, 68.9127753674984, 66.3532555103302, 69.86584022641182, 65.5174371600151, 68.08610692620277, 70.31676203012466, 68.72954159975052, 65.3777414560318, 65.34505560994148, 65.29812052845955, 64.07872036099434, 68.45458835363388, 69.97826099395752, 69.16787847876549, 70.2093417942524, 73.25614750385284, 70.63586130738258, 70.58124303817749, 69.23355415463448, 71.314178109169, 71.23916253447533, 73.64985957741737, 67.38683804869652, 66.77615761756897, 69.96262103319168, 71.94483786821365, 73.73579576611519, 70.55782869458199, 71.71661451458931, 70.30616819858551, 71.63859710097313, 70.78172788023949, 73.19280490279198, 72.15550616383553, 71.96298569440842, 67.76210591197014, 74.84510824084282, 70.14399290084839, 74.02508184313774, 55.02064101397991, 44.273240715265274, 27.140697240829468, 5.584690477699041, 4.035993805155158, 0.17441729083657265, 0.0784396511153318, 0.2606365940300748, 0.02088598190312041, 0.01408306017765426, 0.05638549722789321, 0.07071894782711752, 0.045439768946380354, 0.65584801370278, 0.5056671879719943, 0.30872375587932765, 5.652020014822483, 57.61463642120361, 41.70897111296654, 17.797825075685978, 20.920003540813923, 59.898348078131676, 52.055454924702644, 37.78122827410698, 31.080529130995274, 52.88169778883457, 49.427838921546936, 55.7152209430933, 2.6966877467930317, 0.14274918154114857, 0.0557816970103886, 0.06448823216487654, 0.08658228762215003, 0.051095112357870676, 0.04641560779418796, 0.09238109560101293, 0.026612825677148066, 0.054045067736296915, 0.003583505977076129, 0.028812358432332985, 0.0687588615983259, 0.09179626838886179, 0.01197857798615587, 0.0035740496241487563, 0.03577717317966744, 0.009247483812941937, 0.014556700680259382, 0.0021612620548694395, 0.03355802546138875, 0.03044420573132811, 0.05294255541230086, 0.02310286792635452, 0.04158197400101926, 0.08907332114176825, 0.020067333643964957, 0.025776837137527764, 0.01324627011854318, 0.007786359237798024, 0.9333319240249693, 51.14354945719242, 72.72454842925072, 71.11160337924957, 73.62815514206886, 66.61855727434158, 42.959522008895874, 30.45259952545166, 53.62676560878754, 31.442397013306618, 7.31656439602375, 0.15135350811760873, 0.1816354488255456, 0.054497811215696856, 0.13564149965532124, 0.38251742895226926, 0.25749941705726087, 0.45862220926210284, 0.4550549725536257, 0.4067495302297175, 0.06435751769458875, 8.114576674997807, 88.7846602499485, 101.94917544722557, 83.40611726045609, 84.89309147000313, 95.3664542734623, 95.36387801170349, 94.74399447441101, 95.23352220654488, 89.68176171183586, 91.14621832966805, 93.74156266450882, 90.87448731064796, 94.10411641001701, 91.09235242009163, 90.25822877883911, 86.85545057058334, 89.63931798934937, 77.43013232946396, 81.35055676102638, 89.63872522115707, 92.73741334676743, 85.40993973612785, 84.89136636257172, 87.6962922513485, 84.57855194807053, 88.20687085390091, 85.00792890787125, 81.71848341822624, 80.05588263273239, 80.69882333278656, 80.7172067463398, 79.84814018011093, 74.52142640948296, 73.07077065110207, 76.09103858470917, 73.56552690267563, 74.27262336015701, 74.25943806767464, 76.52984663844109, 77.21454709768295, 75.39486274123192, 74.34958443045616, 77.81935304403305, 74.28016975522041, 69.17809993028641, 72.75604873895645, 72.80545368790627, 75.22739052772522, 77.69689321517944, 77.09184408187866, 77.49472886323929, 76.79957136511803, 73.01891103386879, 68.9908155798912, 68.63074690103531, 69.98609617352486, 71.7974665760994, 72.96050056815147, 71.83591291308403, 73.33759233355522, 67.34646901488304, 70.12063175439835, 72.86908507347107, 69.69069242477417, 68.4175555408001, 66.22727707028389, 67.40133047103882, 66.31094098091125, 70.87026312947273, 73.02686020731926, 74.34728935360909, 72.34288170933723, 75.78860521316528, 74.63035136461258, 73.29351469874382, 72.54130706191063, 74.6037907898426, 75.20453855395317, 75.25864765048027, 69.9364860355854, 67.90035009384155, 69.26842108368874, 74.04680907726288, 76.01438149809837, 73.66553753614426, 72.9340235888958, 73.46187606453896, 76.67007431387901, 72.95292377471924, 75.06747990846634, 74.99018445611, 74.63418155908585, 71.81070506572723, 75.12197658419609, 72.92689517140388, 78.27637732028961, 71.97044089436531, 66.04636877775192, 54.91255201399326, 21.50553122162819, 5.99509553052485, 0.06343912478769198, 0.07333540430408902, 0.12241035728948191, 0.06368502057739533, 0.06998909753747284, 0.01630286747968057, 0.0254296233470086, 0.08557950510294177, 1.9760003685951233, 0.9704759402666241, 0.3099771839333698, 6.420742040500045, 65.21093040704727, 47.09337718784809, 22.939317785203457, 27.633604891598225, 59.257052689790726, 52.569153159856796, 49.347017258405685, 40.53759656846523, 59.90208327770233, 58.55629429221153, 67.99448624253273, 4.179893508553505, 0.14041999558685347, 0.02571752655057935, 0.09477770567173138, 0.05882253208255861, 0.012925818173243897, 0.00820934537841822, 0.06913501172675751, 0.033072030055336654, 0.00335460861606407, 0.039037298047333024, 0.021356434881454334, 0.08159886987414211, 0.07027371117146686, 0.08494704685290344, 0.06562481648870744, 0.1859192142728716, 0.09715901265735738, 0.15365186525741592, 0.12586717726662755, 0.11047977677662857, 0.12155870572314598, 0.1910884806420654, 0.06411030830349773, 0.1417663405300118, 0.22362773772329092, 0.10925480266450904, 0.11880427657160908, 0.11889740868355148, 0.14487831416772678, 1.4563250541687012, 63.05156707763672, 86.11997723579407, 80.04392847418785, 82.05791920423508, 50.36343231797218, 50.64872860908508, 53.79005804657936, 66.43440395593643, 46.681984663009644, 11.278110221028328, 0.5017830245196819, 0.32411518623121083, 0.23493480286560953, 0.41946893208660185, 1.1198151111602783, 0.6220690731424838, 1.8095873482525349, 0.8257430128287524, 0.6426143331918865, 0.27867621509358287, 8.113371189683676, 90.03764301538467, 100.61847165226936, 93.5191909968853, 88.25270399451256, 99.53369066119194, 100.19791021943092, 98.25455769896507, 97.91432395577431, 93.04186061024666, 92.5550003349781, 97.12192207574844, 95.08811920881271, 96.3250744342804, 95.7778961956501, 94.57060977816582, 89.52061995863914, 95.01767098903656, 82.73757353425026, 82.0638544857502, 91.50520026683807, 98.0965393781662, 90.46449691057205, 88.81440505385399, 90.17696633934975, 87.14725211262703, 92.63539642095566, 88.47613200545311, 86.31169214844704, 85.17337962985039, 82.38021031022072, 86.8262605369091, 84.7987425327301, 78.36998149752617, 77.0853616297245, 79.8174986243248, 77.21074730157852, 79.61376115679741, 78.13156709074974, 81.21597558259964, 81.90063044428825, 79.10180702805519, 78.37713271379471, 82.06228137016296, 79.26625460386276, 71.9935816526413, 73.40224206447601, 77.49624118208885, 79.21755641698837, 79.03591856360435, 79.10998418927193, 80.89092582464218, 78.53475585579872, 77.97322198748589, 68.75351071357727, 71.7258708178997, 73.66125896573067, 74.31099370121956, 76.63596734404564, 73.84963765740395, 78.7456901371479, 72.19682514667511, 77.04626932740211, 78.0107107758522, 74.51356083154678, 72.10212662816048, 69.26866427063942, 71.76955327391624, 70.42539820075035, 73.72968569397926, 75.66159322857857, 76.5104828774929, 74.53324377536774, 79.71634805202484, 79.74261224269867, 78.32971885800362, 75.6911252439022, 76.2240618467331, 76.83008372783661, 76.78254067897797, 73.2115226984024, 73.95930737257004, 72.2584730386734, 77.04832121729851, 78.29923689365387, 76.03151857852936, 76.2551061809063, 77.56931886076927, 79.08463194966316, 76.23017191886902, 79.99186366796494, 79.17344078421593, 76.3087061047554, 73.97490933537483, 79.25531879067421, 78.12525182962418, 77.73217052221298, 68.27402964234352, 58.78849983215332, 48.908695578575134, 26.85472648590803, 7.036581169813871, 0.2929442416643724, 1.7872913321480155, 0.41789017617702484, 0.26656944130081683, 0.18751354044070467, 0.1477088060346432, 0.22602846671361476, 0.38613542856182903, 3.0621685227379203, 2.156083155423403, 0.521125114755705, 10.286346338689327, 75.8858571946621, 58.33275608718395, 31.494885496795177, 33.70508439838886, 83.16916957497597, 78.69272857904434, 56.05521149933338, 46.8284098058939, 77.54716604948044, 69.24822136759758, 80.13817101716995, 6.122355926781893, 0.2986250852700323, 0.24923975870478898, 0.17595641606021672, 0.1550644394592382, 0.11704922348144464, 0.08073991557466798, 0.1494430418824777, 0.1451382736559026, 0.1294373974087648, 0.11196912615559995, 0.12257088383194059, 0.2686570433434099, 0.1496268273331225], [0.041345484933117405, 0.04282758352928795, 0.06410059359041043, 0.02860966676962562, 0.05022819481382612, 0.030618931414210238, 0.026808372313098516, 0.0575845852290513, 0.03186529051163234, 0.02027601072768448, 0.042628806695574895, 0.02108425964252092, 0.03935838452889584, 0.06972359420615248, 0.10069007708807476, 0.016607595171080902, 0.18877214868552983, 29.63110450655222, 57.67775483429432, 51.938387006521225, 50.60428999364376, 41.94891683757305, 30.131841637194157, 51.87258593738079, 28.350350931286812, 7.836003648117185, 0.5000782816205174, 0.04877111772657372, 0.13134887296473607, 0.014503317070193589, 0.137474782532081, 0.1499739001155831, 0.25339231244288385, 0.06164611455460545, 0.3816008468857035, 0.225627692125272, 1.3991368166171014, 48.15212197601795, 101.6314896941185, 82.56912097334862, 76.95993036031723, 91.89532533288002, 92.01115071773529, 90.24118289351463, 91.15959361195564, 92.09963276982307, 84.402135014534, 90.46713396906853, 85.27642250061035, 86.66843220591545, 84.05649796128273, 85.89331179857254, 83.51777046918869, 86.15374222397804, 76.35336130857468, 75.92101290822029, 84.77496340870857, 86.46659463644028, 85.11583551764488, 80.37983044981956, 85.46214133501053, 84.08910021185875, 81.69780492782593, 84.53470230102539, 78.09142604470253, 77.5677153468132, 78.30255791544914, 79.17388156056404, 75.1903273165226, 75.14331623911858, 74.2517700791359, 73.47636848688126, 75.74528753757477, 72.720155864954, 71.70276805758476, 69.8677097260952, 73.9704179763794, 72.2763092815876, 70.47755420207977, 72.49735862016678, 71.53512105345726, 66.12394541501999, 64.67211931943893, 75.67746117711067, 65.8824835717678, 72.0302040874958, 74.36992853879929, 74.80320408940315, 75.64556568861008, 73.64900082349777, 67.76449978351593, 67.135139554739, 66.8314978480339, 64.65907081961632, 65.90574592351913, 68.80211770534515, 67.72784695029259, 66.33022874593735, 65.16168504953384, 63.43908928334713, 65.38268119096756, 61.79085552692413, 64.33093562722206, 65.66181421279907, 65.9611089527607, 62.6923343539238, 67.97317698597908, 69.32159543037415, 70.71077048778534, 70.64403846859932, 72.49303445219994, 71.14707827568054, 69.04308557510376, 68.90319988131523, 72.7150109410286, 72.30053678154945, 71.20669707655907, 74.79682043194771, 68.71757224202156, 64.79229167103767, 69.67689916491508, 70.06698623299599, 73.93656939268112, 69.08726960420609, 70.39734050631523, 66.56058758497238, 72.01675280928612, 71.82503029704094, 71.63345217704773, 69.1365909576416, 70.0334720313549, 65.68373903632164, 70.46510607004166, 73.44799920916557, 67.5438380241394, 47.967106103897095, 38.11976730823517, 16.3851235806942, 6.686087977141142, 1.2252601655200124, 0.30166471435222775, 0.12592798884725198, 0.11566211236640811, 0.2134574350202456, 0.12143956875661388, 0.012630736546270782, 0.29309091973118484, 0.23836135806050152, 0.2801278856350109, 0.05315217873430811, 0.3783499135170132, 12.283728159964085, 65.13505607843399, 39.36706177890301, 18.689952604472637, 14.320849198848009, 19.187560603022575, 35.934265181422234, 54.0867917239666, 51.804432794451714, 51.731818690896034, 43.46820071339607, 2.0805280096828938, 0.10260519658913836, 0.1038199216418434, 0.023574111291964073, 0.0897012819768861, 0.017494309504400007, 0.027872968312294688, 0.019421498182055075, 0.015075237406563247, 0.05242839179118164, 0.10753518712590449, 0.05417504748038482, 0.01771884813933866, 0.04061838801135309, 0.014020135331520578, 0.05590706059592776, 0.008901280270947609, 0.03446904513111804, 0.03333794156787917, 0.06456231334595941, 0.03113469065283425, 0.06880849643494003, 0.14595917804399505, 0.02205765496910317, 0.0714545942901168, 0.0031900433987175347, 0.014878390156809473, 0.06058594175556209, 0.07497549129766412, 0.04411103145685047, 0.3550158109283075, 38.449437618255615, 70.96736311912537, 68.25074449181557, 72.85853683948517, 30.844687186181545, 22.538194209337234, 63.255498334765434, 37.47383236885071, 7.717764442786574, 0.5209087044931948, 0.058182637512800284, 0.08177574592991732, 0.02700211181945633, 0.13707003003219143, 0.07600945144076832, 0.7314614031929523, 0.11360254866303876, 0.40132974449079484, 0.06689612288028002, 3.2069699652493, 71.98668122291565, 104.5581990480423, 85.50201639533043, 85.66359892487526, 94.63817775249481, 96.94504916667938, 91.40064507722855, 94.06932547688484, 92.96486154198647, 87.14905321598053, 93.80818828940392, 90.51506459712982, 89.10503625869751, 84.76857975125313, 92.63994097709656, 88.62209737300873, 90.49405932426453, 78.9315077662468, 81.3165333867073, 87.58090004324913, 89.46574330329895, 88.23209390044212, 83.98190036416054, 89.51138645410538, 84.64280650019646, 86.5161743760109, 84.72020074725151, 81.48098096251488, 81.89798578619957, 84.50731337070465, 85.66881224513054, 79.47207435965538, 77.44227647781372, 77.85526871681213, 79.07683476805687, 79.79849964380264, 77.28745758533478, 74.77531358599663, 74.23234552145004, 77.96186059713364, 76.70297294855118, 74.56290498375893, 77.51530855894089, 75.02462580800056, 70.31890511512756, 70.458714812994, 77.4280196428299, 71.14194095134735, 73.34299564361572, 77.16197311878204, 77.77436345815659, 78.35696339607239, 74.71238896250725, 68.32629963755608, 67.81973361968994, 70.48004686832428, 67.75449112057686, 68.49484339356422, 72.96173170208931, 69.75418701767921, 70.25601848959923, 69.91729706525803, 68.21553558111191, 68.56029868125916, 66.24440655112267, 67.59610801935196, 69.52337980270386, 71.67445957660675, 66.97408139705658, 70.82953691482544, 71.44770294427872, 72.32344955205917, 73.54643672704697, 75.36635667085648, 74.71813425421715, 72.64303520321846, 71.67392760515213, 74.08264875411987, 75.48251643776894, 73.84452313184738, 74.57238927483559, 71.86191111803055, 68.50136384367943, 72.19316214323044, 71.5972401201725, 75.41779071092606, 71.21524661779404, 74.55128520727158, 70.7543009519577, 74.74429965019226, 72.04172506928444, 75.2808840572834, 73.09750601649284, 71.98008477687836, 68.01233008503914, 74.95482355356216, 74.49255555868149, 79.41886961460114, 67.35197871923447, 62.65749402344227, 39.64446969330311, 14.626592192798853, 1.9509543688036501, 0.09352587323519401, 0.10591152386041358, 0.08147458982421085, 0.3269242448732257, 0.036474213120527565, 0.09737684042192996, 0.6014337460510433, 1.5510690514929593, 0.2869624720187858, 0.02624298937007552, 0.31784323684405535, 14.108967818319798, 75.427685379982, 41.59031108021736, 23.579735420644283, 18.745114244520664, 24.600434750318527, 41.56275115907192, 53.34125652909279, 56.21034197509289, 61.49510219693184, 49.148287922143936, 2.627525757998228, 0.10849427941138856, 0.03443385248829145, 0.03888830076903105, 0.05737601575674489, 0.020201456427457742, 0.03363527561305091, 0.03381028516741935, 0.023428093736583833, 0.06838901972514577, 0.062015574221732095, 0.0654974565259181, 0.037578925912384875, 0.027620695618679747, 0.10975651675835252, 0.14266337442677468, 0.111347429046873, 0.09472734353039414, 0.1375523369642906, 0.19446200196398422, 0.16527186438906938, 0.166983628005255, 0.17610082315513864, 0.11673082728520967, 0.27731464128009975, 0.08125506996293552, 0.09201214430504479, 0.2927794848801568, 0.24092671024845913, 0.26530360453762114, 0.621761764632538, 52.541908621788025, 84.97146606445312, 77.35550433397293, 75.61798676848412, 59.672742784023285, 52.46124655008316, 75.88619157671928, 50.97834952175617, 13.082084320485592, 1.1041619698517025, 0.16821090277517214, 0.23613245110027492, 0.3187622531550005, 0.372166428132914, 0.4226459178607911, 1.1719994922168553, 0.3869361465331167, 1.0039679962210357, 0.3161059581907466, 2.3997571924701333, 73.62111791968346, 103.98157238960266, 98.88985320925713, 90.36564141511917, 100.53135752677917, 101.35130792856216, 95.23965507745743, 96.85206055641174, 98.11428442597389, 90.21873369812965, 97.86314830183983, 94.28093612194061, 93.31952691078186, 88.05986434221268, 94.28343638777733, 90.29523879289627, 94.05648976564407, 84.61765184998512, 83.28013122081757, 90.78071594238281, 90.53338721394539, 91.50649979710579, 87.62395933270454, 93.0068264901638, 90.21360397338867, 89.28543537855148, 87.93718412518501, 83.28226670622826, 83.74166205525398, 87.69756138324738, 86.85518458485603, 82.7117957174778, 82.16940522193909, 81.70810237526894, 81.36706307530403, 81.64801999926567, 78.87906298041344, 78.42466056346893, 78.41936364769936, 82.63260036706924, 82.07486629486084, 76.98744848370552, 79.77108791470528, 77.88929969072342, 73.53597208857536, 69.84406739473343, 79.8684310913086, 73.55864927172661, 76.7655099928379, 82.44786188006401, 80.69760739803314, 83.336071819067, 77.5028832256794, 71.94785490632057, 72.03571379184723, 74.12867948412895, 71.24001368880272, 72.11919531226158, 75.14032199978828, 72.86711677908897, 74.09777194261551, 72.49056458473206, 70.5631560087204, 72.56448581814766, 68.65253493189812, 72.34949335455894, 70.52075788378716, 73.21789115667343, 68.87615293264389, 73.8569788634777, 75.94379648566246, 76.23600080609322, 75.7643549144268, 80.30049830675125, 77.03381359577179, 74.5684526860714, 73.42008590698242, 77.83262193202972, 77.23293051123619, 78.1138676404953, 78.02604675292969, 74.00036796927452, 70.5069874227047, 75.95251321792603, 75.14021560549736, 80.2156412601471, 74.32797878980637, 75.88681474328041, 73.16236093640327, 78.2123051583767, 78.70214447379112, 80.88021039962769, 75.12535840272903, 72.82659575343132, 70.32484039664268, 75.7210448384285, 79.12769123911858, 76.59240648150444, 64.17613193392754, 55.83698160946369, 38.11116836965084, 19.45112396031618, 2.007999876514077, 0.4534193384461105, 0.6078226875979453, 0.32017939898651093, 0.40721218509133905, 0.29968220042064786, 0.1423751242691651, 1.3976006302982569, 6.126696718856692, 0.7512484851758927, 0.29836827248800546, 0.5744888575281948, 19.786590859293938, 88.46524178981781, 55.16619600355625, 32.677247151732445, 24.33078221976757, 28.161280676722527, 53.91198590397835, 78.51916149258614, 72.63769268989563, 71.96643590927124, 66.24882951378822, 3.8182849623262882, 0.23605547554325312, 0.29247443249914795, 0.08370946365175769, 0.11085657257353887, 0.1693042941042222, 0.08824965596431866, 0.13461746944813058, 0.15761868911795318, 0.14383960427949205, 0.18394323124084622, 0.24719579494558275, 0.1366242961375974, 0.10856006338144653], [0.03062339728785446, 0.030480955028906465, 0.04465500715014059, 0.039189813105622306, 0.02648428013344528, 0.03271329442213755, 0.033734745666151866, 0.09140681897406466, 0.036073204755666666, 0.03611643485783134, 0.028676465626631398, 0.09057271920028143, 0.06526598808704875, 0.025551984945195727, 0.02109081280650571, 0.021588140807580203, 0.09283122300985269, 36.93280220031738, 59.37310606241226, 36.63875497877598, 50.165405943989754, 54.10556271672249, 46.94871135056019, 44.72945183515549, 13.432673458009958, 2.0355842588469386, 0.16987144335871562, 0.13519171363441274, 0.07461640314431861, 0.028309236113273073, 0.10994980169925839, 0.058816431628656574, 0.10761789948446676, 0.21335313358576968, 0.15497843938646838, 0.1562450034543872, 26.044418066740036, 86.90509110689163, 83.01517903804779, 72.51239821314812, 87.80098423361778, 85.64787536859512, 88.6343403160572, 87.5884236395359, 89.52089354395866, 83.41838300228119, 86.82803884148598, 87.99187079071999, 86.72573313117027, 87.25413277745247, 87.85346701741219, 85.58522433042526, 85.13829231262207, 80.37251964211464, 75.72548300027847, 85.31855463981628, 85.15740528702736, 89.80612903833389, 79.62101876735687, 82.62066140770912, 82.06271454691887, 81.31160885095596, 82.31744527816772, 77.89116159081459, 77.83751606941223, 79.19464364647865, 81.2815448641777, 81.91811710596085, 74.58958715200424, 75.72875082492828, 76.50431200861931, 79.01118189096451, 75.33497035503387, 72.29223042726517, 71.92508652806282, 71.17693707346916, 70.29399365186691, 72.48180225491524, 68.98194685578346, 74.35753360390663, 71.37215539813042, 71.15719333291054, 67.08293795585632, 69.24589589238167, 67.18164905905724, 70.7266916334629, 70.30736893415451, 69.36568826436996, 72.67320558428764, 70.12459874153137, 68.37907880544662, 62.56741605699062, 65.24908795952797, 65.13748034834862, 65.22943541407585, 66.2675093114376, 68.44223901629448, 67.33019068837166, 66.86552122235298, 68.21774706244469, 68.66343274712563, 67.00691163539886, 65.05880936980247, 66.52838811278343, 71.71494260430336, 71.60724878311157, 69.20231223106384, 68.56224417686462, 68.679528683424, 69.22734528779984, 71.52852460741997, 70.09448915719986, 70.3822249174118, 70.20662114024162, 68.5012498497963, 71.43520161509514, 73.09845596551895, 71.8851962685585, 75.30073419213295, 70.18132969737053, 66.7952173948288, 67.23340228199959, 68.58096197247505, 70.20229697227478, 70.4913018643856, 68.23397219181061, 67.8471377491951, 71.83667287230492, 69.87530931830406, 73.06026801466942, 70.46541005373001, 66.47961392998695, 71.72931343317032, 72.23189726471901, 70.88245287537575, 60.47245167195797, 45.103594958782196, 25.999183394014835, 12.309216242283583, 5.094318240880966, 0.2544458059128374, 0.09088475519092754, 0.279022857430391, 0.4180945933330804, 0.2028013818198815, 0.09539654551190324, 0.6524973060004413, 0.4633666109293699, 0.05477021280967165, 0.13113682653056458, 0.02973960330564296, 0.29220230178907514, 35.099214389920235, 58.55793580412865, 28.82937602698803, 31.565215922892094, 36.95976175367832, 46.086875796318054, 52.88723409175873, 51.614450588822365, 48.04409757256508, 12.085798680782318, 0.03707248433784116, 0.0888320044032298, 0.06672052331850864, 0.06201062409672886, 0.002445409527354059, 0.08158017517416738, 0.03540185796737205, 0.04860771165112965, 0.04286965217033867, 0.03707196854520589, 0.02979680990392808, 0.03931065330107231, 0.027685195673257113, 0.028379489667713642, 0.03837906500848476, 0.026523855158302467, 0.03646113647846505, 0.08824271688354202, 0.0717325063305907, 0.02882037362724077, 0.04169207903032657, 0.052236984483897686, 0.030110255975159816, 0.014478693537967047, 0.03841698133328464, 0.0663216040993575, 0.01296975609875517, 0.02775269400444813, 0.021729247200710233, 0.03411201272683684, 0.17567900125868618, 48.03299076855183, 76.3961774110794, 62.26810611784458, 58.33438619971275, 33.9678630977869, 44.319058656692505, 57.145308405160904, 19.60058894008398, 2.3734526289626956, 0.07281691767275333, 0.11912700691027567, 0.1390160302980803, 0.1476681066560559, 0.08272234787000343, 0.15361180412583053, 0.2951726736500859, 0.559257137356326, 0.21347579575376585, 0.47670478583313525, 39.93527568876743, 95.42978927493095, 90.95970153808594, 79.88797724246979, 94.04593393206596, 91.11315250396729, 92.43557274341583, 89.91119340062141, 92.56842881441116, 85.67464113235474, 89.9604919552803, 90.56567788124084, 90.79273089766502, 92.74410098791122, 90.34039556980133, 88.17473217844963, 88.8266783952713, 79.82287153601646, 82.8348559141159, 88.56934860348701, 88.60480830073357, 88.30010265111923, 86.39040872454643, 86.2526661157608, 86.77851229906082, 85.62905117869377, 83.79460841417313, 79.57940340042114, 82.30340883135796, 83.22463139891624, 84.84854266047478, 83.34735721349716, 78.8575105369091, 78.38069692254066, 78.45780998468399, 80.3104005753994, 79.44308951497078, 75.73917746543884, 76.21882572770119, 72.73640379309654, 72.9809358716011, 74.77488800883293, 71.91978201270103, 76.03673949837685, 74.29666087031364, 74.59312856197357, 71.21869683265686, 71.27340629696846, 70.00335484743118, 73.46502229571342, 72.36741319298744, 71.95802316069603, 75.55398300290108, 74.04760703444481, 70.64181938767433, 65.65324947237968, 67.37131208181381, 68.59932258725166, 67.58858442306519, 68.92736658453941, 70.91466754674911, 70.6460827589035, 69.95917841792107, 69.58109110593796, 71.13967627286911, 73.03249910473824, 67.95287847518921, 70.61106383800507, 73.84896129369736, 74.20905277132988, 71.2670150399208, 70.99282935261726, 73.1657275557518, 72.87343204021454, 72.8523051738739, 75.4935510456562, 73.74170064926147, 73.10118421912193, 71.88576623797417, 72.54835948348045, 75.65950334072113, 73.5821396112442, 77.06285923719406, 72.21935793757439, 69.3637427687645, 69.02471736073494, 70.68639859557152, 70.9364403784275, 72.82616257667542, 72.80924588441849, 69.93500411510468, 73.4247824549675, 70.84323897957802, 75.01252725720406, 73.47942352294922, 72.25307732820511, 71.73605427145958, 74.39886778593063, 73.51938217878342, 74.82066795229912, 67.09613844752312, 51.92043676972389, 29.255156479775906, 9.935007691383362, 0.4222273762570694, 0.07914371919468977, 0.08664454639074393, 0.09379452327266335, 0.2532200451241806, 0.3337295609526336, 1.0849992418661714, 0.4544965806417167, 0.02842292386048939, 0.16570496693020687, 0.01573814504808979, 0.20400496723596007, 41.90840721130371, 70.02448931336403, 29.183087646961212, 26.489630676805973, 21.73147849738598, 43.21361817419529, 69.29561242461205, 59.48131285607815, 56.97902172803879, 16.097397319972515, 0.0683445057075005, 0.1235883757181, 0.0037830189285159577, 0.10183915175730363, 0.005503473557837424, 0.03172242337313946, 0.04412239744851831, 0.03756436868570745, 0.026390225903014652, 0.04500323768297676, 0.003513435176500934, 0.019652873852464836, 0.03432709083426744, 0.043529388058232144, 0.1379648968577385, 0.1311826318851672, 0.14384059875737876, 0.12537764181615785, 0.14344855182571337, 0.07744479473331012, 0.19717251823749393, 0.29547864629421383, 0.09957125235814601, 0.08931666394346394, 0.12135350931202993, 0.20541497360682115, 0.13822193228406832, 0.08452066816971637, 0.0981573126045987, 0.15537053084699437, 0.3960577351972461, 58.50719712674618, 84.13557931780815, 58.39008741080761, 78.0962897837162, 82.05443859100342, 63.63173894584179, 72.66093984246254, 32.04272300004959, 3.740918976254761, 0.3466753475368023, 0.30799369036685675, 0.2789611998014152, 0.319063980714418, 0.19722353346878663, 0.2053847978822887, 0.922163788927719, 0.7133557903580368, 0.5670616216957569, 0.34855562320444733, 42.93909810483456, 107.83871501684189, 96.241554915905, 86.40737101435661, 96.53289288282394, 97.92003124952316, 96.44060343503952, 94.32185232639313, 95.19043251872063, 88.26840475201607, 92.02246651053429, 97.52265617251396, 90.69757640361786, 94.10226970911026, 94.62102547287941, 92.66805946826935, 92.06434026360512, 87.71033629775047, 83.7681694328785, 92.38684415817261, 91.04469537734985, 94.45201054215431, 88.26123833656311, 89.26857188344002, 91.2937568128109, 88.95647943019867, 90.43102070689201, 86.57241135835648, 86.53181433677673, 86.71440973877907, 87.45642632246017, 88.8909025490284, 81.52566656470299, 82.97371566295624, 80.73357626795769, 81.87825724482536, 83.28330025076866, 78.16632002592087, 80.88960349559784, 78.10213387012482, 76.63448542356491, 78.67635145783424, 74.53221783041954, 81.14266231656075, 77.08922982215881, 77.18484789133072, 72.02979370951653, 74.829141497612, 71.46376848220825, 79.30397897958755, 76.28961592912674, 75.26231825351715, 78.9309909939766, 78.17610830068588, 73.34016099572182, 67.82874673604965, 71.47252321243286, 71.80571973323822, 72.03634455800056, 72.4334080517292, 74.53909546136856, 75.12114062905312, 74.7989559173584, 73.20912882685661, 75.16461029648781, 74.72772493958473, 69.17078152298927, 71.97098046541214, 76.67703554034233, 76.40319183468819, 73.77668157219887, 72.97952994704247, 73.330197930336, 75.13995721936226, 75.9381651878357, 77.78190225362778, 77.24106207489967, 76.96064472198486, 71.75680875778198, 76.91538915038109, 77.42606654763222, 76.35915979743004, 79.61788773536682, 74.7675696015358, 73.71806591749191, 72.92929664254189, 73.49814891815186, 75.01625865697861, 75.94308212399483, 75.28279915452003, 72.3158347606659, 77.8422886133194, 76.40180110931396, 80.71099787950516, 76.03008225560188, 72.6290975511074, 75.02883598208427, 77.58685871958733, 74.39889818429947, 73.31053778529167, 61.826444417238235, 48.32439333200455, 33.974888920784, 10.538079030811787, 0.4337069462053478, 0.25953952164854854, 0.45453944709151983, 1.3717857655137777, 0.5145670822821558, 1.1347573343664408, 4.306281376630068, 1.6387266665697098, 0.22015224531060085, 0.33512850932311267, 0.15491342724999413, 0.6512417702469975, 52.53915756940842, 77.64430403709412, 41.834398582577705, 48.27278830111027, 51.96355685591698, 67.9931791126728, 77.49005511403084, 70.841164290905, 71.53648898005486, 28.603176064789295, 0.13683239434612915, 0.21290330303600058, 0.11767523988964967, 0.1809287758078426, 0.08749613116378896, 0.29253843531478196, 0.07918294912087731, 0.18902044161222875, 0.15818478452274576, 0.14501126250252128, 0.1050420459068846, 0.13717692898353562, 0.1936482370365411, 0.08551244463887997], [0.09306575651862659, 0.020104387222090736, 0.027060251668444835, 0.07588389489683323, 0.012569669852382503, 0.027848260360769928, 0.01597314425453078, 0.05009519823943265, 0.03900418341800105, 0.06781721720471978, 0.03504592394165229, 0.038010321513866074, 0.1571824843995273, 0.04939012083923444, 0.07120535883586854, 0.19649434369057417, 4.661577036604285, 59.181033968925476, 49.90542769432068, 33.0221888422966, 34.61368024349213, 29.64860636740923, 41.45420238375664, 27.167369909584522, 2.449787207879126, 1.0091592301614583, 0.16575850546360016, 0.21202405099757016, 0.01174840366729768, 0.34480466041713953, 0.030934646601963323, 0.9432942769490182, 0.13321351900231093, 0.7807603140827268, 0.38127961568534374, 10.622743237763643, 65.57916104793549, 68.95326599478722, 89.23397094011307, 82.05435499548912, 94.76278826594353, 82.05143675208092, 93.22166696190834, 83.31055238842964, 87.31265723705292, 82.84520655870438, 89.90856394171715, 87.92985811829567, 88.91753911972046, 87.55059286952019, 84.77877840399742, 83.76292571425438, 80.31731620430946, 75.85029870271683, 88.43700930476189, 83.18363159894943, 86.33998543024063, 80.34413516521454, 85.76210483908653, 84.42573174834251, 80.75078934431076, 76.65929809212685, 74.43989038467407, 79.45993021130562, 79.25715029239655, 79.13802668452263, 81.27342090010643, 76.02290064096451, 81.29990547895432, 76.77326157689095, 76.5379250049591, 79.7537836432457, 76.24089494347572, 72.15305909514427, 75.97841262817383, 69.65296044945717, 71.64026901125908, 71.06241881847382, 74.04409602284431, 70.46157985925674, 74.8026493191719, 71.73498272895813, 69.36851531267166, 68.5773977637291, 68.31256717443466, 68.54940086603165, 67.95428439974785, 70.78298941254616, 70.8544559776783, 73.57104420661926, 69.98826205730438, 67.20809563994408, 64.19620245695114, 61.53629198670387, 61.19226984679699, 65.72338610887527, 65.17396599054337, 68.08675289154053, 67.17895120382309, 66.22112900018692, 69.30962607264519, 70.03589630126953, 68.68594273924828, 69.52943667769432, 70.59880569577217, 70.32222613692284, 69.26535084843636, 68.256945759058, 73.4995624423027, 69.29097667336464, 68.77358123660088, 71.48672685027122, 68.07374998927116, 68.04834455251694, 66.24164029955864, 70.6409378349781, 68.05228874087334, 73.98442402482033, 70.98456859588623, 73.45086425542831, 71.1104254424572, 66.90553307533264, 67.24943742156029, 72.0446053147316, 68.64786878228188, 68.43338549137115, 66.3630285859108, 70.54351106286049, 70.75993224978447, 72.4949723482132, 73.68973463773727, 71.78612038493156, 66.83560162782669, 71.92276865243912, 73.27367976307869, 68.08198794722557, 54.42409962415695, 34.22843411564827, 20.948824994266033, 14.747633747756481, 3.7664460064843297, 0.08410115435253829, 0.11812355645815842, 0.031129002090892754, 0.17822887224610895, 0.16586351935984567, 0.5702272080816329, 0.29412974836304784, 0.09118853107793257, 0.028371502303343732, 0.1048769625776913, 0.307826588395983, 7.12743429467082, 72.76418790221214, 52.34725646674633, 24.818900227546692, 36.498067528009415, 33.99107985198498, 30.767868608236313, 35.28632014989853, 46.53916172683239, 5.02638453617692, 0.16922912938753143, 0.1610679688747041, 0.02572239132859977, 0.04737199124065228, 0.02704613230889663, 0.08125547072268091, 0.04216079352772795, 0.18306347454199567, 0.03109149580268422, 0.04941369144944474, 0.04134287257329561, 0.08393691707169637, 0.02238223696622299, 0.05357340691261925, 0.011560515067685628, 0.017891631250677165, 0.07201681568403728, 0.0068536368507921, 0.017024166372721083, 0.014143234438961372, 0.018738900434982497, 0.017624784632062074, 0.015172610892477678, 0.07343894874793477, 0.048095395977725275, 0.16029625403461978, 0.030432288695010357, 0.02223158098786371, 0.11032431910280138, 0.16692058998160064, 6.9616534654051065, 72.17797055840492, 62.51228101551533, 50.38749262690544, 36.339220851659775, 30.631801709532738, 49.95383709669113, 39.524852111935616, 1.7990762810222805, 1.20379654224962, 0.2546390314819291, 0.45137798704672605, 0.057026089416467585, 0.4152468539541587, 0.07053373745293356, 1.0118503170087934, 0.13854288146831095, 0.7378251117188483, 0.2217878052033484, 14.367843177169561, 82.97141298651695, 79.19971257448196, 95.8766832947731, 86.37459397315979, 96.98060005903244, 89.09623593091965, 94.48148936033249, 85.78362688422203, 88.88865306973457, 87.35087558627129, 94.51512515544891, 90.0742806494236, 91.0329008102417, 87.61313751339912, 87.43004813790321, 87.4527557194233, 81.72194123268127, 80.74758991599083, 91.02473884820938, 86.5054589509964, 87.7230504155159, 83.85662868618965, 87.79830157756805, 84.60496053099632, 84.18188363313675, 79.84427958726883, 80.69497033953667, 82.17090994119644, 82.04793334007263, 82.03312933444977, 85.29111251235008, 80.57639390230179, 85.14379441738129, 79.23800691962242, 81.47389054298401, 81.64845317602158, 78.58135655522346, 75.28397709131241, 78.05724307894707, 76.07189521193504, 77.81520366668701, 76.88883617520332, 78.3128173649311, 75.49960792064667, 78.55199933052063, 74.40722733736038, 70.45341789722443, 73.16720187664032, 71.63589924573898, 72.82154962420464, 71.98743358254433, 77.39769726991653, 76.13416627049446, 77.49875664710999, 74.18621599674225, 68.53791028261185, 67.11158081889153, 64.68350350856781, 64.00754258036613, 70.02037033438683, 68.21943417191505, 69.54089686274529, 69.5456314086914, 70.42456984519958, 70.76374724507332, 71.95135831832886, 72.71611288189888, 72.93572589755058, 73.03501456975937, 72.66214817762375, 72.83547967672348, 70.26966735720634, 72.61104851961136, 70.55502444505692, 71.24648854136467, 71.33357986807823, 73.65728437900543, 73.29582497477531, 69.2923977971077, 71.87663152813911, 71.55609592795372, 75.8935783803463, 73.06035920977592, 75.98776772618294, 74.08710211515427, 69.44379687309265, 68.51869091391563, 73.0829755961895, 71.60773515701294, 69.83096569776535, 69.55288141965866, 70.62228843569756, 73.12524452805519, 73.24759796261787, 75.62563195824623, 74.0837886929512, 69.33461353182793, 73.62386897206306, 73.94429057836533, 75.38048431277275, 69.78317946195602, 59.56113517284393, 41.78972817957401, 25.822063498198986, 5.7533221039921045, 0.018646957614691928, 0.06687537243124098, 0.06769177940441296, 0.45610730827320367, 0.1320083305472508, 0.5510277289431542, 0.35269202780909836, 0.24599321885034442, 0.07588057749671862, 0.08157002259395085, 0.31163766514509916, 6.808345941826701, 84.76348042488098, 54.51429158449173, 29.118289723992348, 21.133795268833637, 36.4526941627264, 46.33088730275631, 41.83067858219147, 56.148314103484154, 6.739232875406742, 0.23748802836053073, 0.1417693981784396, 0.039904876102809794, 0.027073170604126062, 0.005234502541497932, 0.06913992474437691, 0.029806860438839067, 0.03092977811320452, 0.019008185008715373, 0.03622210926550906, 0.030119243383524008, 0.02224726998974802, 0.06452874600654468, 0.08268657635198906, 0.12276293680770323, 0.1488909582258202, 0.24185958987800404, 0.10384703971794806, 0.11050796354538761, 0.18382052454398945, 0.26629849802702665, 0.11771259960369207, 0.0912456690275576, 0.18248501495691016, 0.1676376975956373, 0.23757367220241576, 0.1590877110720612, 0.14477680320851505, 0.1779156710836105, 0.40766646852716804, 7.9673616494983435, 87.17165440320969, 68.46087321639061, 56.42312295734882, 53.17058868706226, 50.296863690018654, 60.9574044495821, 51.5385876595974, 4.912556894123554, 3.5274034459143877, 1.095372922718525, 0.7663521997164935, 0.1612584781832993, 0.8681479655206203, 0.1887744790292345, 1.6362999030388892, 0.6075233349110931, 1.4406937616877258, 0.43737279949709773, 12.31175260618329, 95.47479405999184, 81.44151628017426, 100.22701665759087, 89.7839306294918, 100.79113438725471, 92.46566712856293, 98.21420386433601, 89.79251816868782, 91.74488380551338, 91.7035648226738, 96.9714729487896, 95.714690387249, 95.37329390645027, 92.66923740506172, 89.46489974856377, 90.79944133758545, 86.15707844495773, 82.92044252157211, 93.55120047926903, 88.23342382907867, 92.43637070059776, 88.41771394014359, 89.30189609527588, 91.38539269566536, 86.76867842674255, 84.15925964713097, 82.94960975646973, 86.03503659367561, 85.79520106315613, 86.18820637464523, 86.88495218753815, 83.32904979586601, 87.42777585983276, 84.34298738837242, 84.32704344391823, 84.39499139785767, 85.11262089014053, 79.40874695777893, 82.51586303114891, 78.47497746348381, 79.84689384698868, 77.41630867123604, 80.54420962929726, 78.94432067871094, 80.50955548882484, 80.2887113392353, 72.86891788244247, 76.12027421593666, 75.03464207053185, 75.25183841586113, 74.15698796510696, 79.15945753455162, 77.56066292524338, 80.36792948842049, 77.92409062385559, 73.03749203681946, 71.04769840836525, 68.53689193725586, 67.30983898043633, 74.35209229588509, 72.17651903629303, 73.51656273007393, 71.54918029904366, 72.43730664253235, 75.69220438599586, 77.5149817764759, 73.27528327703476, 74.80891898274422, 76.56036660075188, 76.23175263404846, 74.52147960662842, 72.55677223205566, 76.79326370358467, 73.22230651974678, 74.35311064124107, 76.1675588786602, 73.31775739789009, 75.57378754019737, 72.62224271893501, 75.2405834197998, 73.62774476408958, 78.68962794542313, 77.44396358728409, 80.23711010813713, 75.60993120074272, 70.96671715378761, 71.23771861195564, 77.13678807020187, 73.34238767623901, 71.79097652435303, 71.91842928528786, 75.3565987944603, 77.64551997184753, 77.83110201358795, 78.64821776747704, 76.92016169428825, 69.98729690909386, 77.69794195890427, 77.75279581546783, 73.12263026833534, 66.34443238377571, 53.480184674263, 41.22137367725372, 32.22644694149494, 4.831388024613261, 0.13838703045621514, 0.3568874776829034, 0.16594895540038124, 0.7890253455843776, 0.32059746561571956, 1.5188677981495857, 0.7426383846905082, 0.1858427285333164, 0.16062576760305092, 0.27244300581514835, 0.48839384922757745, 9.933241736143827, 94.8717588186264, 65.33193111419678, 39.88381125032902, 51.52832441031933, 48.57794612646103, 45.80527290701866, 50.36371350288391, 68.90909716486931, 11.357074733823538, 0.5683951126411557, 0.26994211657438427, 0.2017726463964209, 0.24738585896557197, 0.1552599063143134, 0.16759705758886412, 0.1660802264814265, 0.19594022654928267, 0.14879775932058692, 0.17830152850365266, 0.08327543342602439, 0.1119609031593427, 0.13654990325449035, 0.13308741326909512], [0.03625862293120008, 0.05280490186123643, 0.030096952978055924, 0.021481397707248107, 0.06996231342782266, 0.06524658834678121, 0.04116581469133962, 0.14934503386029974, 0.046168409535312094, 0.02141406264854595, 0.011293379939161241, 0.05829463501868304, 0.06483552017016336, 0.04833676837733947, 0.08588463912019506, 0.17613401199923828, 28.759748563170433, 66.0689927637577, 53.188656717538834, 56.330160945653915, 37.007407397031784, 31.217219196259975, 41.85009554028511, 5.131211411207914, 0.6450688233599067, 0.14479302655672655, 0.1006451400462538, 0.4478532902430743, 0.25877953274175525, 0.1339163031661883, 0.2771670132642612, 0.19056073942920193, 0.12008510471787304, 0.5153493059333414, 0.4211516777286306, 33.6083909869194, 85.38476228713989, 79.75133657455444, 91.73183530569077, 90.26545599102974, 90.89059084653854, 87.1728627383709, 84.18616220355034, 86.16988375782967, 85.86422055959702, 83.8212525844574, 88.65214616060257, 84.57959309220314, 88.74833419919014, 84.81973260641098, 84.44071814417839, 82.60081887245178, 75.90894475579262, 85.98917305469513, 83.14849868416786, 87.60453477501869, 80.83098784089088, 85.52160814404488, 83.0987897515297, 79.62671086192131, 79.73693534731865, 74.53525766730309, 81.18588879704475, 82.4239307641983, 81.58079400658607, 77.22289904952049, 80.98529756069183, 78.83651286363602, 82.75001406669617, 78.12810927629471, 77.66755878925323, 78.14126417040825, 74.97734874486923, 75.93131795525551, 76.40839755535126, 75.06602838635445, 75.9813004732132, 76.58786952495575, 76.2579408288002, 75.27938693761826, 72.36546769738197, 68.56850624084473, 68.61347302794456, 69.77487310767174, 67.902622371912, 70.69193109869957, 72.83595845103264, 71.21121883392334, 72.62217432260513, 68.6262859404087, 68.84789004921913, 63.44769962131977, 64.15892645716667, 62.21052020788193, 63.80245238542557, 64.79739099740982, 63.924760222435, 65.11418759822845, 66.1247205734253, 66.06045842170715, 69.3797855079174, 69.50754225254059, 70.03240048885345, 69.82656553387642, 71.81164741516113, 67.02748373150826, 70.70813342928886, 69.90889951586723, 70.84618002176285, 72.96987846493721, 67.61027365922928, 68.25330555438995, 67.53940746188164, 69.94255051016808, 62.64438472688198, 67.97488689422607, 66.62897631525993, 69.08267945051193, 69.71251845359802, 67.72926047444344, 73.25639069080353, 72.239610850811, 65.11269807815552, 66.5853850543499, 68.01940530538559, 70.56826293468475, 67.88664042949677, 67.79495894908905, 68.31488505005836, 70.81113070249557, 70.01720130443573, 69.84076917171478, 67.08867564797401, 70.64978376030922, 73.78111213445663, 73.57249572873116, 56.91065199673176, 47.733620032668114, 23.391235135495663, 21.538621746003628, 14.390537459403276, 0.3862312249839306, 0.060853322720504366, 0.20900517236441374, 0.12350985649391077, 0.0602521237306064, 0.06314646627288312, 0.13339253986487165, 0.2496214007260278, 0.2061365934787318, 0.16255024558631703, 0.09945066078216769, 0.22819700738182291, 38.9503039419651, 76.36789932847023, 30.08562281727791, 28.252922259271145, 24.79925148189068, 51.90444342792034, 46.432490050792694, 48.67486372590065, 6.991147482767701, 0.3551676543429494, 0.1755618309834972, 0.06307481191470288, 0.10262697862344794, 0.01804809824534459, 0.190307488956023, 0.032874577955226414, 0.026389702688902617, 0.021780293973279186, 0.039666984375799075, 0.04460677126189694, 0.027912053519685287, 0.014858397626085207, 0.0788942833605688, 0.045612592875841074, 0.04684986066422425, 0.0624615084961988, 0.017600364262762014, 0.013077619842079002, 0.11129127073218115, 0.061274814361240715, 0.050365369679639116, 0.014046669894014485, 0.06606388589716516, 0.04960174424923025, 0.09354035995784216, 0.026523395026742946, 0.09782201028428972, 0.04983749116945546, 0.06487444581580348, 37.63566568493843, 77.63891592621803, 71.11158818006516, 70.44287726283073, 26.02522909641266, 39.11079593002796, 54.63774316012859, 6.1775940377265215, 0.9318068402353674, 0.23216635454446077, 0.7329265214502811, 1.1717203259468079, 0.6098679872229695, 0.036584377521649, 1.0202935826964676, 0.6053383334074169, 0.22359353955835104, 0.3600608417764306, 0.6957544223405421, 44.139434695243835, 94.34238642454147, 88.28048810362816, 93.65230545401573, 93.65789875388145, 93.04093345999718, 91.76413357257843, 85.74439018964767, 90.61173900961876, 89.39565226435661, 87.89621472358704, 90.55700674653053, 89.01693418622017, 91.4401325583458, 88.08436542749405, 89.9432484805584, 84.78597521781921, 80.22249609231949, 89.61281061172485, 84.86928194761276, 89.4567833840847, 84.60481613874435, 88.3235701918602, 82.03128263354301, 83.02164629101753, 81.04211211204529, 79.06384706497192, 84.65587019920349, 85.66599279642105, 85.68836599588394, 81.91912025213242, 82.10730895400047, 81.62972018122673, 83.93827870488167, 79.14330080151558, 79.93132531642914, 79.76740211248398, 78.3368168771267, 81.74375206232071, 80.09260386228561, 79.77092832326889, 78.00146207213402, 78.84594395756721, 79.77081432938576, 77.72105991840363, 74.5779749751091, 72.94814363121986, 70.64937338232994, 73.9220541715622, 69.28868919610977, 73.63180294632912, 75.48430994153023, 72.12807923555374, 72.82259836792946, 71.91398352384567, 71.38505950570107, 67.54211291670799, 66.7602288722992, 65.4022653400898, 69.50846180319786, 67.93634936213493, 68.61073717474937, 70.15003457665443, 65.83674162626266, 70.11674076318741, 71.12463667988777, 70.52504405379295, 71.44720137119293, 70.48487260937691, 74.70589131116867, 70.58575719594955, 71.8289364874363, 72.78184935450554, 73.20613458752632, 73.89559999108315, 71.57333940267563, 69.68632265925407, 71.12549543380737, 73.80856186151505, 68.18950697779655, 71.0510802268982, 72.65728443861008, 70.76748624444008, 72.3442268371582, 70.75991705060005, 74.43118885159492, 74.91246342658997, 69.75636050105095, 68.77545073628426, 72.79486745595932, 73.4138086438179, 71.74562975764275, 71.63743436336517, 70.59859290719032, 71.2024337053299, 73.69577631354332, 74.7386759519577, 70.28108194470406, 70.74357032775879, 75.53607076406479, 76.20934903621674, 66.90812453627586, 67.46366992592812, 48.191092684865, 39.34821859002113, 20.693176612257957, 0.45064557634759694, 0.012011825274385046, 0.10395548975793645, 0.09551873270538636, 0.09619330041459762, 0.006223748750926461, 0.024879459997464437, 0.3557430859655142, 0.2173527900595218, 0.17356296011712402, 0.15889736503595486, 0.18583932949695736, 44.988445937633514, 81.51230648159981, 32.703857123851776, 26.68437782675028, 24.443140290677547, 62.4320787191391, 51.876602321863174, 61.12948581576347, 9.050795137882233, 0.3823607467347756, 0.13882700528483838, 0.10630565622705035, 0.028648484803852625, 0.06417149095796049, 0.09518071412458085, 0.05213205222389661, 0.014362426827574382, 0.03883243560267147, 0.05789075083157513, 0.011972001630056184, 0.028706782359222416, 0.04973199487722013, 0.03435336286202073, 0.12955857528140768, 0.12256521382369101, 0.22487203736091033, 0.1851434473064728, 0.18815236631780863, 0.2391776759759523, 0.20275982154998928, 0.3623989928746596, 0.18110375938704237, 0.08442967344308272, 0.12173247218015604, 0.18800277903210372, 0.1305792509810999, 0.2550307963974774, 0.2174642903264612, 0.26035802147816867, 44.969545751810074, 89.5589143037796, 78.52480798959732, 85.16614481806755, 57.69906789064407, 54.538838267326355, 67.11888402700424, 11.18270494043827, 2.086000428535044, 1.0153540852479637, 1.594307643827051, 2.3103484651073813, 1.0306015983223915, 0.20844010112341493, 1.0355293401516974, 1.1629913630895317, 0.4050658643245697, 1.6553464997559786, 0.6967665336560458, 52.22055606544018, 94.50345978140831, 91.28387734293938, 99.3892452120781, 96.9245682656765, 97.73654669523239, 91.6701190173626, 88.37850004434586, 91.41834452748299, 94.612095952034, 89.78370264172554, 94.57482755184174, 92.32752174139023, 93.84582906961441, 91.58290609717369, 93.21559488773346, 92.1030829846859, 82.69757688045502, 92.88725450634956, 88.59551399946213, 93.04370731115341, 90.84578365087509, 90.86865082383156, 88.28612700104713, 86.47743165493011, 87.40051612257957, 81.37339353561401, 86.98126941919327, 88.67087915539742, 90.09817376732826, 83.69170993566513, 86.72713905572891, 83.24949726462364, 91.02901741862297, 86.33325979113579, 84.52529400587082, 85.65007165074348, 81.97411850094795, 82.3272867500782, 80.88927671313286, 82.24580392241478, 82.37479940056801, 82.86388635635376, 82.35226660966873, 81.57713860273361, 78.73929128050804, 75.5486860871315, 74.16204929351807, 76.97438478469849, 75.71654587984085, 76.74651861190796, 78.24262753129005, 77.95714884996414, 79.93827894330025, 76.16207957267761, 75.22717013955116, 70.14519363641739, 71.15885764360428, 68.7368980050087, 73.53246867656708, 70.63937231898308, 69.21146214008331, 74.34630900621414, 71.16877511143684, 72.82394349575043, 75.66929921507835, 74.27761629223824, 75.68259850144386, 74.40985679626465, 77.63226628303528, 73.79918396472931, 76.50423601269722, 77.29007184505463, 77.35048100352287, 77.17749148607254, 72.93454796075821, 71.35073214769363, 73.89070585370064, 77.46851027011871, 68.70092913508415, 73.61836686730385, 73.50955590605736, 74.49740409851074, 73.39924782514572, 73.13209936022758, 77.79326364398003, 77.26122379302979, 72.29968562722206, 71.76463633775711, 75.56003987789154, 75.1314988732338, 73.34218248724937, 71.07941150665283, 73.3755674958229, 77.82001420855522, 77.67737746238708, 76.54411867260933, 71.76624745130539, 73.98116379976273, 81.19584426283836, 77.57601410150528, 64.29805979132652, 61.0308925062418, 45.74315004050732, 47.03646004199982, 22.02061638236046, 0.4568654566537589, 0.44259502552449703, 0.7486290601082146, 0.5026752047706395, 0.25539370661135763, 0.19998724688775837, 0.41868249303661287, 0.8932639646809548, 0.7073609589133412, 0.24212582793552428, 0.38778148242272437, 0.6517536740284413, 53.948349952697754, 89.85387727618217, 44.072090908885, 43.68031673133373, 36.02949187159538, 73.53936150670052, 61.60900868475437, 70.98164275288582, 11.74705445766449, 0.5312079924624413, 0.38861758599523455, 0.1922327239299193, 0.15940414799842983, 0.16933907114434987, 0.29051177843939513, 0.1852273099939339, 0.11023251543520018, 0.132283786078915, 0.14524931379128247, 0.1063870252983179, 0.14699754654429853, 0.12869079684605822, 0.15678936877520755], [0.05210010276641697, 0.01543082355055958, 0.09630736851249821, 0.017301100633630995, 0.04821958325919695, 0.02812609076499939, 0.015985176323738415, 0.04270464305591304, 0.016072336002252996, 0.05467073533509392, 0.02391049529251177, 0.07835839336621575, 0.06953205331228673, 0.08779809621046297, 0.06528735451865941, 0.9172264882363379, 49.43006180226803, 50.61940178275108, 37.409551218152046, 35.18557995557785, 36.219211891293526, 44.81156922876835, 15.360464863479137, 1.9125481671653688, 0.12781326659023762, 0.09485928254434839, 0.29668472532648593, 1.049535151105374, 0.48130619048606604, 0.8261697180569172, 0.7916821155231446, 0.1500898681115359, 0.3670932847307995, 0.3069900692207739, 4.518834371119738, 71.56187921762466, 84.31125909090042, 82.06474363803864, 92.55256846547127, 90.96676915884018, 86.91035002470016, 86.76542580127716, 85.49158215522766, 87.92304888367653, 85.54749235510826, 87.9333159327507, 85.76103329658508, 85.64591467380524, 85.10475531220436, 82.7462750673294, 83.84198427200317, 75.99717602133751, 87.31600865721703, 83.38679149746895, 87.47996225953102, 83.02730038762093, 80.58381110429764, 83.03767383098602, 79.59764242172241, 79.82668653130531, 75.80625906586647, 79.48489487171173, 80.04348769783974, 81.15871265530586, 79.02723982930183, 79.17895048856735, 79.57352891564369, 79.5039014518261, 76.98354989290237, 73.7687399983406, 72.38488465547562, 75.75173959136009, 76.83164164423943, 81.30680590867996, 74.76413458585739, 73.91806438565254, 73.77894625067711, 73.75780418515205, 74.0776938199997, 69.65302124619484, 70.63448578119278, 70.0147694349289, 65.18897518515587, 65.5479571223259, 62.92656138539314, 62.737403735518456, 67.22983807325363, 67.66198888421059, 63.36853086948395, 67.21352934837341, 68.78684252500534, 61.50498166680336, 61.89917631447315, 62.14038357138634, 62.88316771388054, 62.69534379243851, 63.82633790373802, 65.13503327965736, 62.914789617061615, 68.22948843240738, 68.96781161427498, 69.68198329210281, 65.87746024131775, 66.33643001317978, 68.98504748940468, 67.30245217680931, 65.38518145680428, 66.59157112240791, 67.8650575876236, 68.94652515649796, 70.33266797661781, 69.37836438417435, 69.07794490456581, 66.76584497094154, 66.67464226484299, 62.237213775515556, 70.83272114396095, 67.11607217788696, 68.12323093414307, 68.93632650375366, 69.04291838407516, 71.529071778059, 69.88457322120667, 67.7486926317215, 67.47339740395546, 70.66214069724083, 71.61356404423714, 69.26168024539948, 67.4989852309227, 67.90804088115692, 71.60372257232666, 71.15309715270996, 70.8666305243969, 67.31607064604759, 70.94246685504913, 74.11599576473236, 64.36256512999535, 55.22953100502491, 33.71411271393299, 15.459877029061317, 26.607540249824524, 5.300201643258333, 0.1360112673137337, 0.15227945608785376, 0.0660276245616842, 0.10282772956998087, 0.1347711237031035, 0.07968686739332043, 0.03001844303071266, 0.05561664336710237, 0.05861614081368316, 0.05913368862820789, 0.29856206208933145, 21.96330215781927, 69.9077519774437, 58.208289965987206, 30.885939672589302, 26.385425068438053, 48.28047528862953, 39.614565297961235, 53.19247551262379, 11.764236185699701, 0.4778391437139362, 0.06388917798176408, 0.07687966412049718, 0.061460915312636644, 0.08100928549538366, 0.05646481426083483, 0.019967490661656484, 0.06648383758147247, 0.015511292767769191, 0.03370491132955067, 0.011675947789626662, 0.06304555645328946, 0.035596742236521095, 0.039144816691987216, 0.0142321984640148, 0.0388453749474138, 0.05409630190115422, 0.03645032338681631, 0.0484682027308736, 0.05699379114957992, 0.08762645229580812, 0.026694378429965582, 0.02447257753374288, 0.0431219044548925, 0.07507178495870903, 0.05857763819221873, 0.026562051643850282, 0.04609591283951886, 0.13545563619118184, 1.309692703653127, 61.771081387996674, 62.149924859404564, 66.68221145868301, 40.55122643709183, 28.781542293727398, 58.002682998776436, 23.411216363310814, 1.795168190728873, 0.15784830960910767, 0.13897990254918113, 0.45969312835950404, 1.6746451891958714, 1.7686031037010252, 1.3082339381799102, 0.75246412307024, 0.040390582071268, 0.20477289712289348, 0.1979919383302331, 6.267172330990434, 86.35357350111008, 85.78601315617561, 86.275305300951, 92.22491964697838, 95.92034295201302, 87.39557638764381, 92.0945942401886, 89.2339937388897, 91.3695627450943, 87.59743675589561, 92.98962861299515, 87.82375261187553, 87.26237833499908, 88.86702463030815, 86.98946937918663, 84.34532046318054, 80.45166179537773, 88.96803081035614, 86.42937943339348, 89.91835981607437, 86.22918337583542, 83.43796715140343, 81.87663853168488, 83.1772555410862, 82.92928844690323, 80.05223482847214, 82.40958273410797, 83.84654402732849, 82.45313599705696, 81.87819644808769, 84.7251708805561, 82.4795825779438, 81.98677182197571, 80.51648631691933, 78.52295368909836, 79.1893619298935, 78.16724717617035, 79.94543015956879, 82.5030805170536, 79.33022797107697, 78.09899523854256, 78.78056466579437, 76.84400618076324, 75.23093953728676, 74.52799245715141, 76.07444867491722, 72.8272645175457, 69.2375211417675, 70.6412722170353, 67.05345913767815, 67.66770377755165, 70.01930639147758, 73.0565594136715, 68.65638792514801, 70.1480358839035, 70.10616213083267, 66.23403310775757, 65.3809104859829, 64.80176836252213, 66.54358729720116, 65.0683468580246, 67.56650000810623, 69.09711107611656, 65.78881859779358, 68.96854117512703, 69.54617097973824, 70.72239026427269, 70.5172772705555, 70.87552964687347, 70.70390045642853, 70.9230574965477, 67.00905472040176, 68.35654601454735, 71.7117127776146, 71.43998175859451, 73.03797841072083, 70.82919493317604, 72.51022472977638, 69.78731364011765, 70.79245090484619, 66.78558111190796, 70.35421282052994, 71.15967839956284, 69.94456440210342, 69.57799047231674, 70.64027667045593, 71.18869364261627, 71.99798941612244, 70.69518372416496, 69.71828654408455, 71.94479987025261, 74.77056384086609, 71.44840210676193, 70.81737756729126, 70.53118452429771, 74.73940551280975, 73.09451937675476, 74.0102170407772, 67.79010280966759, 73.04443806409836, 75.9815588593483, 68.54298681020737, 67.82946109771729, 60.292223542928696, 35.02695366740227, 35.96000500023365, 8.057892266660929, 0.25584516988601536, 0.10558114940067753, 0.03921884963347111, 0.11906188345164992, 0.10339493077481166, 0.06108271685661748, 0.05324341094819829, 0.14429019181989133, 0.025503749056952074, 0.04382821010949556, 0.3401592909358442, 26.43117841333151, 77.50325560569763, 66.00236713886261, 35.17600066959858, 23.40550906956196, 54.23179194331169, 46.70191079378128, 64.0906973183155, 15.737175699323416, 0.6472210516221821, 0.08371076983166859, 0.06895773491123691, 0.03744955472939182, 0.05075128276075702, 0.08451897607301362, 0.029285093514772598, 0.06808668360463344, 0.01012655866361456, 0.0337898241559742, 0.018412902791169472, 0.044413849973352626, 0.014833518980594818, 0.05254433010122739, 0.1165722006408032, 0.12221143202623352, 0.1582106261048466, 0.14416148856980726, 0.17006357054924592, 0.11738691551727243, 0.19570486183511093, 0.09218758801580407, 0.12125415058108047, 0.08676832178025506, 0.16418829909525812, 0.18342298571951687, 0.2096598653588444, 0.41309637716040015, 0.232158339349553, 1.804841284174472, 72.83239424228668, 72.21804320812225, 55.185115188360214, 55.717086642980576, 56.41362726688385, 69.41976696252823, 34.06859569251537, 3.7797027826309204, 0.23814131127437577, 0.19655255775433034, 1.2667218782007694, 3.855524626560509, 4.045573091134429, 2.017301539890468, 2.1004724269732833, 0.3921909676864743, 0.6935473345220089, 0.8093765785451978, 5.950305908918381, 93.31238329410553, 89.31131199002266, 91.73663064837456, 95.69813087582588, 99.8679131269455, 91.836998462677, 94.73536893725395, 91.29174292087555, 96.62998527288437, 90.89584976434708, 96.55092671513557, 91.53538584709167, 90.77301755547523, 94.19909611344337, 89.53613832592964, 89.18050780892372, 83.98528978228569, 91.53853967785835, 90.48620134592056, 92.30137914419174, 90.44340804219246, 85.4934212565422, 87.81516507267952, 86.26850366592407, 86.98025107383728, 83.30792292952538, 85.11795580387115, 86.73945799469948, 86.1577320098877, 84.67211052775383, 87.41610288619995, 84.71383988857269, 86.69661909341812, 84.05740231275558, 80.12905150651932, 81.13744899630547, 82.24674627184868, 83.21780696511269, 88.22686538100243, 84.21035930514336, 81.3997033238411, 82.43921354413033, 80.73270991444588, 80.07862061262131, 76.96613922715187, 79.30511891841888, 76.70077666640282, 72.41515383124352, 74.71885621547699, 70.15109091997147, 71.82734817266464, 74.34877127408981, 76.7505843937397, 69.81199711561203, 76.04513704776764, 76.0777772963047, 71.18968918919563, 68.5193444788456, 68.20943310856819, 70.76084420084953, 69.9951320886612, 70.06383240222931, 72.39999264478683, 68.50178942084312, 73.32452103495598, 74.79814276099205, 73.88684526085854, 73.42216059565544, 73.37398678064346, 75.58434337377548, 74.48505476117134, 70.04627734422684, 72.3347881436348, 74.91681039333344, 76.60192117094994, 76.04469627141953, 74.36058104038239, 74.12341296672821, 72.14822575449944, 73.6055463552475, 68.13302680850029, 75.1822717487812, 71.74064442515373, 73.66493716835976, 72.15429022908211, 74.29142475128174, 77.58103743195534, 74.81094807386398, 73.44096958637238, 73.80060508847237, 75.3830985724926, 78.54038715362549, 73.94136473536491, 71.07907712459564, 72.5603212416172, 78.8888892531395, 78.70242565870285, 76.15436598658562, 70.0528509914875, 78.3152948319912, 79.26609501242638, 68.96291747689247, 63.69351223111153, 55.20667903125286, 39.65230867266655, 45.647645965218544, 7.175394371151924, 0.502871013013646, 0.8048620645422488, 0.1927109045209363, 0.21061827486846596, 0.2571473125135526, 0.17055122094461694, 0.22048276819987223, 0.3955499577568844, 0.15137117123231292, 0.2494039514567703, 0.3816743491915986, 31.864527761936188, 87.76492416858673, 72.51917704939842, 44.47604343295097, 38.161268681287766, 65.0487931072712, 54.1715157777071, 75.86721539497375, 18.06965298950672, 0.7051335065625608, 0.3378002409590408, 0.17807889904361218, 0.15765204123454168, 0.16101649351185188, 0.18435571691952646, 0.16333678853698075, 0.15257398481480777, 0.11257357575232163, 0.22512074589030817, 0.08883705842890777, 0.15420749637996778, 0.1369710423750803, 0.10312724552932195], [0.01964870112715289, 0.09498219704255462, 0.12810050742700696, 0.047224374357028864, 0.029538154740293976, 0.025909449650498573, 0.05923873221036047, 0.08495863919961266, 0.027010932244593278, 0.03854973299894482, 0.022007073894201312, 0.06174511705467012, 0.03310202024294995, 0.07964147021993995, 0.27355281345080584, 6.585524473339319, 60.45355148613453, 49.34012062847614, 35.78493319451809, 40.112851560115814, 34.8801713436842, 41.873551681637764, 3.8982136733829975, 0.30862285348121077, 0.14943462592782453, 0.04851911777222995, 0.22295284346910194, 0.10494056463357992, 0.2864774933550507, 0.5245948629453778, 0.20486017368966714, 0.0910844819736667, 0.09918884592480026, 0.19644503539893776, 15.133000519126654, 91.03091731667519, 83.47050100564957, 83.03061380982399, 87.77159661054611, 84.90461245179176, 82.45097011327744, 87.5458051264286, 85.67879810929298, 89.32138904929161, 84.91265282034874, 87.07449361681938, 84.69294100999832, 83.33448350429535, 83.23295295238495, 83.06105777621269, 78.8813504576683, 83.9620578289032, 82.71200090646744, 84.69405055046082, 84.55253854393959, 83.49772274494171, 82.85890102386475, 79.38126683235168, 80.36780029535294, 78.44988361001015, 81.87755048274994, 79.34844419360161, 82.07472190260887, 75.65619751811028, 79.45986181497574, 76.11539527773857, 75.36403119564056, 75.54432392120361, 75.25645896792412, 78.30364465713501, 75.28727531433105, 72.8304335474968, 75.32626122236252, 74.77663591504097, 74.03350979089737, 72.5026023387909, 71.5044566988945, 71.71539857983589, 69.18411880731583, 71.17593392729759, 65.59325829148293, 63.68739455938339, 65.03205120563507, 67.02346354722977, 67.92159855365753, 70.57488217949867, 70.44455677270889, 72.60664075613022, 71.71605974435806, 71.61699146032333, 66.5229544043541, 63.96219581365585, 62.48252861201763, 56.77341476082802, 60.47714821994305, 58.59212636947632, 61.44471310079098, 61.830483600497246, 65.24461179971695, 62.60226398706436, 65.96908852458, 64.6057216823101, 70.74767410755157, 67.40728095173836, 65.13349056243896, 66.13083824515343, 66.18028119206429, 66.45299255847931, 66.84602826833725, 66.46823734045029, 70.44451117515564, 67.81745374202728, 70.17319813370705, 68.56423527002335, 68.11899796128273, 64.94167685508728, 65.5726557970047, 69.78661447763443, 69.55184787511826, 66.6618749499321, 68.24138179421425, 67.78292879462242, 73.06767001748085, 68.00890266895294, 63.25166434049606, 65.37224695086479, 69.78683486580849, 70.01909360289574, 68.20339903235435, 68.38657960295677, 70.80628216266632, 68.82469609379768, 70.72047516703606, 67.2828072309494, 68.09207260608673, 69.53510597348213, 67.02225521206856, 54.46821145713329, 38.32308679819107, 16.504934951663017, 20.964390859007835, 18.514939695596695, 1.833535444457084, 0.08034621365368366, 0.16777729557361454, 0.1013084567966871, 0.05287802196107805, 0.08201670643757097, 0.022717906649631914, 0.06565253570443019, 0.18409225449431688, 0.039098762717912905, 0.5108021374326199, 16.60568844527006, 56.505635529756546, 66.08412355184555, 55.36185510456562, 34.73444916307926, 40.035400316119194, 35.27612529695034, 57.50847011804581, 19.671740122139454, 0.18808450433425605, 0.09508287679636851, 0.029742213810095564, 0.14530862623360008, 0.027392082592996303, 0.03588945641240571, 0.015562777407467365, 0.06539748181239702, 0.02749330782535253, 0.014567474809155101, 0.04301638589822687, 0.029027011660218704, 0.10274090571328998, 0.048266568628605455, 0.025049022187886294, 0.08448805077932775, 0.030317973833007272, 0.042374721306259744, 0.02999820095283212, 0.08684854052262381, 0.06427611893741414, 0.02784559976134915, 0.0809930769901257, 0.06351561794872396, 0.0403125452430686, 0.015434092711075209, 0.04294658690923825, 0.06138670054497197, 0.2995112392818555, 9.469347428530455, 73.46992403268814, 61.76793895661831, 50.59093751013279, 31.10339630395174, 40.155257284641266, 53.07600796222687, 5.608929852023721, 0.40704042243305594, 0.35005024925339967, 0.09446635987842456, 0.13732976687606424, 0.02294887599418871, 0.5426422914024442, 0.3884053020738065, 0.41369754646439105, 0.2124208031455055, 0.2387737249955535, 0.48903025570325553, 21.876946091651917, 97.9960423707962, 85.01820355653763, 89.05450657010078, 88.05496260523796, 88.44597682356834, 84.92869555950165, 91.46316692233086, 90.09770259261131, 91.49153620004654, 86.94847717881203, 90.60050681233406, 86.66501998901367, 88.83385241031647, 85.33025041222572, 86.68154150247574, 82.50789865851402, 89.3212142586708, 86.92686393857002, 89.0854749083519, 85.2455985546112, 85.85595220327377, 84.38958048820496, 85.37390246987343, 83.35563316941261, 82.90910392999649, 84.9237710237503, 82.35287457704544, 80.93017011880875, 79.10196661949158, 81.46261274814606, 77.4211648106575, 78.39266628026962, 77.95669287443161, 80.52722454071045, 82.3278035223484, 78.47131446003914, 79.72511038184166, 77.60471016168594, 79.02289286255836, 77.58495882153511, 77.2487224638462, 74.52337190508842, 73.94273266196251, 73.31276446580887, 74.41516131162643, 67.37907886505127, 66.56099036335945, 67.6168929040432, 70.18652021884918, 69.87086355686188, 74.48508515954018, 71.60208106040955, 74.24809947609901, 75.38305297493935, 73.0743956565857, 69.09052222967148, 66.58997520804405, 64.97866407036781, 62.10889846086502, 64.14436563849449, 62.90813997387886, 64.16746079921722, 64.68993276357651, 65.9158305823803, 63.51905219256878, 67.09531009197235, 66.57395526766777, 72.65429019927979, 70.07450222969055, 68.18144381046295, 67.85270065069199, 69.24436077475548, 68.65900218486786, 71.10129833221436, 69.84872594475746, 71.98753237724304, 71.43127262592316, 72.68419459462166, 71.61089658737183, 70.88415518403053, 70.1493202149868, 68.08785483241081, 71.63353577256203, 71.18528142571449, 67.52617657184601, 68.804731965065, 70.27934163808823, 74.26923394203186, 71.10422417521477, 67.24510565400124, 68.70093673467636, 73.3029305934906, 73.94421458244324, 69.74746137857437, 70.02946704626083, 72.36407697200775, 73.02407875657082, 73.43146249651909, 71.11702188849449, 69.99282941222191, 73.49434152245522, 73.66071939468384, 62.284855619072914, 56.763843074440956, 43.34347240626812, 33.17055948078632, 24.92564219981432, 4.160656565800309, 0.10411094001028687, 0.07196105812909082, 0.61931908945553, 0.17066156346118078, 0.16555067442823201, 0.043650896186591126, 0.03360539303685073, 0.052986557348049246, 0.06490229119663127, 0.5200273299124092, 17.508846782147884, 63.40266443789005, 69.5608077943325, 63.18509191274643, 29.897770397365093, 39.02133733034134, 45.853313729166985, 64.19300302863121, 25.120738931000233, 0.17657567892456427, 0.04385443760838825, 0.030170269747031853, 0.0673008753801696, 0.047126384888542816, 0.04491597966989502, 0.02846116116415942, 0.0388664890488144, 0.06022697234584484, 0.025225016943295486, 0.03796818607952446, 0.011346723658789415, 0.03203179134288803, 0.03507126086333301, 0.11526670350576751, 0.1568077740375884, 0.13974110857816413, 0.23838035704102367, 0.15230848890496418, 0.11700765579007566, 0.16811568522825837, 0.11436843022238463, 0.20524885127088055, 0.11993373627774417, 0.09574586700182408, 0.19110936467768624, 0.19350584858329967, 0.1970197248738259, 0.46236117894295603, 11.941148042678833, 83.5352723300457, 69.69469740986824, 52.70752273499966, 57.141956984996796, 55.9396331012249, 65.24301588535309, 12.607491686940193, 0.7324818859342486, 0.8157824410591274, 0.2526538755046204, 0.4436983319465071, 0.22929571248823777, 1.9574566511437297, 1.397845004685223, 0.720951760886237, 0.31125228269957006, 0.405131796724163, 0.6613246479537338, 22.1630422398448, 100.33581241965294, 87.60523393750191, 92.58675903081894, 92.24010363221169, 91.47389754652977, 88.73615205287933, 92.8526459634304, 93.32957357168198, 97.28763118386269, 92.03464865684509, 93.82579654455185, 91.01385623216629, 91.793771982193, 88.08768644928932, 91.44048973917961, 85.81339448690414, 89.49304863810539, 89.05335903167725, 92.42138430476189, 90.27761533856392, 88.34121644496918, 85.51883429288864, 88.80922973155975, 86.77769914269447, 86.20299518108368, 88.24557557702065, 84.48949992656708, 84.55439284443855, 82.81399503350258, 85.95388814806938, 82.14723721146584, 82.9476946592331, 80.40454432368279, 81.96257472038269, 85.80810517072678, 81.28911405801773, 82.13170364499092, 82.83946886658669, 83.63618731498718, 82.09579557180405, 81.57650783658028, 78.96017342805862, 79.87533152103424, 73.7566490471363, 77.97309279441833, 72.04275861382484, 70.90893745422363, 74.1423511505127, 75.39563789963722, 73.59790876507759, 77.29220733046532, 74.1426095366478, 77.0776404440403, 77.83824563026428, 77.05301776528358, 72.2815454006195, 68.60439151525497, 67.83645272254944, 63.56868892908096, 65.66603198647499, 66.35349869728088, 68.50788429379463, 68.5471361875534, 68.6817629635334, 67.88080394268036, 72.46295526623726, 69.29372772574425, 77.92562574148178, 74.02629777789116, 70.9108829498291, 70.56143090128899, 72.28238135576248, 71.26244768500328, 73.05687099695206, 71.58739104866982, 75.84601253271103, 73.5080511868, 78.83691564202309, 74.54674825072289, 75.22252678871155, 73.46316039562225, 71.96746185421944, 78.27104240655899, 74.88886669278145, 71.3158044219017, 72.81738504767418, 73.61025050282478, 78.23997527360916, 71.74935355782509, 69.96343418955803, 71.34777590632439, 75.49522295594215, 77.01634973287582, 70.95820561051369, 74.75795611739159, 76.46079674363136, 74.81518104672432, 76.57446384429932, 72.09492221474648, 72.32668697834015, 74.97624680399895, 73.95615354180336, 60.44849015772343, 51.203837022185326, 43.53119373321533, 43.19159835577011, 26.984882801771164, 3.0223371600732207, 0.2608508965931833, 0.21933735231868923, 0.6120197405107319, 0.16911740647628903, 0.29696736484766006, 0.15698045695899054, 0.16081128967925906, 0.3387048892909661, 0.19421025062911212, 0.4737480398034677, 20.292301923036575, 73.37782457470894, 77.00348362326622, 68.69839087128639, 48.44317875802517, 55.700663924217224, 50.6927340477705, 78.56844484806061, 30.313753075897694, 0.29562639305368066, 0.18934740219265223, 0.10857788976863958, 0.19720440090168267, 0.1028491924807895, 0.15997097070794553, 0.09877627118839882, 0.27404536202084273, 0.1481885599787347, 0.1142954251554329, 0.1299945721984841, 0.15150962630286813, 0.17030022660037503, 0.1299871358787641], [0.06629732844885439, 0.053242349677020684, 0.013985998393764021, 0.058054386972798966, 0.03382579605386127, 0.0764649074699264, 0.04767653896124102, 0.07381491333944723, 0.024051390173553955, 0.004457460472622188, 0.07692279032198712, 0.08047367009567097, 0.08039898035349324, 0.09853744064457715, 0.029600281777675264, 27.182111218571663, 60.821930319070816, 40.97521908581257, 47.33746849000454, 32.86912925541401, 45.160113126039505, 30.01487821340561, 0.6929289770778269, 0.32727976329624653, 0.6768000894226134, 0.04376526485430077, 0.30534826044458896, 0.013702817104785936, 0.20338631293270737, 0.08062650798819959, 0.3936007514130324, 0.16813751921290532, 0.2737241011345759, 0.6790699926204979, 37.933493703603745, 94.33407247066498, 86.54189139604568, 88.87937396764755, 84.95083317160606, 80.75962767004967, 84.80908557772636, 84.41083654761314, 87.98019021749496, 83.38398724794388, 81.63721337914467, 85.65990552306175, 84.00858253240585, 83.63861158490181, 81.20191633701324, 76.00727587938309, 84.96448203921318, 83.11848029494286, 85.09890362620354, 83.59933689236641, 81.03473290801048, 83.20245578885078, 78.76268282532692, 82.28317871689796, 77.24232360720634, 80.16912415623665, 76.03478640317917, 78.95794674754143, 77.64755666255951, 78.30909356474876, 76.81508973240852, 77.17588037252426, 77.71501824259758, 79.49689462780952, 79.96815294027328, 75.75330510735512, 76.14690318703651, 73.34469795227051, 73.89176979660988, 76.47431641817093, 75.14833956956863, 72.18818441033363, 70.46091109514236, 66.92042827606201, 64.86911594867706, 61.15777149796486, 58.54439713060856, 58.18628914654255, 59.79746349155903, 61.11856520175934, 67.1733047068119, 67.02399551868439, 67.0379863679409, 71.30926877260208, 69.86219242215157, 70.30529424548149, 67.40926444530487, 66.27961546182632, 62.07687757909298, 57.582360953092575, 60.208004862070084, 60.29817022383213, 58.02146919071674, 60.60397781431675, 61.88007473945618, 59.84727501869202, 62.737369537353516, 64.01964113116264, 65.52705824375153, 66.0460039973259, 64.9403241276741, 65.31706631183624, 64.66175347566605, 65.9204663336277, 67.31845691800117, 65.64123451709747, 67.72908568382263, 68.66027131676674, 66.60685390233994, 69.49420496821404, 65.94163119792938, 65.33256947994232, 62.79797248542309, 63.856447488069534, 66.94873675704002, 69.40527454018593, 65.59858560562134, 68.85501846671104, 71.719259172678, 73.17450508475304, 65.93685865402222, 61.7750483751297, 66.69614911079407, 68.98196205496788, 68.98200005292892, 66.1207839846611, 69.44688990712166, 68.69511544704437, 72.93658465147018, 68.63041251897812, 70.89718848466873, 67.20373347401619, 74.45084899663925, 48.0461760610342, 46.151928305625916, 32.737128138542175, 18.436675295233727, 28.695558607578278, 17.5679013133049, 0.051971217690152116, 0.13082904304610565, 0.23203518736409023, 0.2962356072384864, 0.1412421467830427, 0.15973418107023463, 0.08694871561601758, 0.1337369260727428, 0.1556441161665134, 0.14705996116390452, 4.081005714833736, 12.22392126917839, 31.780350878834724, 67.00772479176521, 28.128549233078957, 33.85903313755989, 21.27427563071251, 53.08246001601219, 19.068735279142857, 0.029888448443671223, 0.0661267754912842, 0.018074175459332764, 0.06696609256323427, 0.016071803511295002, 0.050738458448904566, 0.034274643257958815, 0.038231103026191704, 0.021277607665979303, 0.01551156736240955, 0.017678799995337613, 0.027963152242591605, 0.04375868942588568, 0.05688606841431465, 0.07230447212350555, 0.08362807231605984, 0.03758835118787829, 0.03175304438627791, 0.060155930259497836, 0.0556149772455683, 0.06760572738130577, 0.010952971642836928, 0.06125178551883437, 0.06632173026446253, 0.03031021282367874, 0.22854949784232304, 0.028407583668013103, 0.09023502716445364, 0.04504046381043736, 36.91167913377285, 70.98476618528366, 57.74712771177292, 49.72471699118614, 22.028898037970066, 59.87389259040356, 34.811904206871986, 0.495073712663725, 0.17591537529369816, 0.8793656167108566, 0.07245561049785465, 0.34665044106077403, 0.15616963093634695, 0.20886547048576176, 0.13590375980129465, 0.21767826634459198, 0.16202701663132757, 0.2890967403072864, 0.9183189296163619, 47.38129913806915, 99.2071133852005, 87.3931673169136, 92.31057465076447, 87.38524854183197, 83.88699665665627, 88.07590708136559, 88.52374345064163, 91.82092532515526, 87.067312002182, 85.00507906079292, 90.2182549238205, 86.2583202123642, 88.21233496069908, 82.54058450460434, 79.63222816586494, 86.25397324562073, 84.88510429859161, 87.13567033410072, 85.44838607311249, 83.34842875599861, 85.88087886571884, 82.2742871940136, 83.17089468240738, 79.67181444168091, 80.79007163643837, 79.69151258468628, 81.94592401385307, 81.48844376206398, 81.18758350610733, 79.93340760469437, 79.08528551459312, 78.77869516611099, 81.28305718302727, 82.12921857833862, 79.7287505865097, 77.92371824383736, 76.39886006712914, 76.93047434091568, 80.72485953569412, 78.19864109158516, 75.82024231553078, 73.24510529637337, 69.9215604364872, 68.28684255480766, 62.950279712677, 61.87124781310558, 60.46804390847683, 63.80584180355072, 65.12652173638344, 71.54749318957329, 72.07670599222183, 69.98285114765167, 73.15024718642235, 73.95823583006859, 72.83595085144043, 70.68005293607712, 69.52233105897903, 67.59990781545639, 62.491648122668266, 63.137301877141, 63.01153242588043, 59.85603354871273, 61.13553889095783, 62.76207201182842, 62.97989912331104, 62.802699431777, 65.86861431598663, 67.46625378727913, 69.24246087670326, 68.20896193385124, 68.51141810417175, 68.24781864881516, 69.47191536426544, 69.21346083283424, 67.63240367174149, 68.59496802091599, 73.32640573382378, 69.43416818976402, 71.38923168182373, 67.87693575024605, 68.62997934222221, 67.21547484397888, 66.96447551250458, 70.23106902837753, 72.58024737238884, 67.50898629426956, 69.94272530078888, 71.83233350515366, 73.53741601109505, 70.26316210627556, 64.39015924930573, 68.35431173443794, 73.48267614841461, 71.37163862586021, 68.79760354757309, 70.92277631163597, 72.60810747742653, 75.10391235351562, 71.530272513628, 72.05989569425583, 69.60847243666649, 73.36491286754608, 58.4208619594574, 57.88228265941143, 59.89957541227341, 40.1741536706686, 35.712649673223495, 23.013594299554825, 1.1305021564476192, 0.287320869974792, 0.18432278040563688, 0.3590252192225307, 0.262854071916081, 0.4512267670361325, 0.09885103514534421, 0.12961619562702253, 0.18805634725140408, 0.15297711943276227, 3.8787309313192964, 10.220857802778482, 29.26059778779745, 78.46176937222481, 20.259775668382645, 27.343935035169125, 34.08039025962353, 58.40620614588261, 27.189976796507835, 0.12908796459669247, 0.08066840964602306, 0.0753913982771337, 0.019852136792906094, 0.033000824696500786, 0.06615277292439714, 0.022779443679610267, 0.016948933007370215, 0.019822680951619986, 0.03317117727419827, 0.034796892578015104, 0.006573960818059277, 0.06245718177524395, 0.049059234297601506, 0.16510770132299513, 0.1625935870106332, 0.07566030806628987, 0.15259616018738598, 0.1913651087670587, 0.16217590629821643, 0.18692485406063497, 0.14541439712047577, 0.13226333248894662, 0.11073905348894186, 0.20844771555857733, 0.27269278303720057, 0.14497072639642283, 0.26085169811267406, 0.09143158444203436, 43.37881051003933, 86.00669011473656, 59.418935403227806, 66.5636882185936, 54.747739657759666, 69.41396087408066, 47.60267525911331, 0.9892544732429087, 0.6754474807530642, 1.1660421243868768, 0.18559062096755952, 0.6154706084635109, 0.29175348056014627, 0.44801231764722615, 0.2793318877229467, 0.9983247052878141, 0.5812763620633632, 0.5848228780087084, 1.061013622675091, 49.71873611211777, 104.85402077436447, 93.16685110330582, 96.67338654398918, 91.11730948090553, 90.8993911743164, 92.36671283841133, 92.30413779616356, 94.80947256088257, 91.73004180192947, 86.59657046198845, 92.52826496958733, 90.4406189918518, 92.00413629412651, 88.97677794098854, 83.87865990400314, 88.84879320859909, 87.82392740249634, 92.26903527975082, 88.49271431565285, 86.91564694046974, 89.75345626473427, 85.93952491879463, 86.95581078529358, 82.55962908267975, 84.65704813599586, 82.04115450382233, 83.95116001367569, 83.56325402855873, 83.02514210343361, 82.7481597661972, 82.79726833105087, 85.28818666934967, 84.09537747502327, 88.08789923787117, 81.63572385907173, 82.1358834207058, 81.42736583948135, 80.81889688968658, 83.72479856014252, 83.63762363791466, 79.21762481331825, 78.24497580528259, 76.011311262846, 73.08154687285423, 69.44660112261772, 64.45245310664177, 63.547964841127396, 66.52153328061104, 69.17750716209412, 75.51216244697571, 78.91771450638771, 75.49744963645935, 78.08846980333328, 79.59356144070625, 75.12663513422012, 73.43563467264175, 74.50743556022644, 70.9050540626049, 65.50352230668068, 67.31683060526848, 67.48820140957832, 62.3031934350729, 65.063885897398, 68.01724702119827, 67.85796716809273, 68.66266518831253, 69.94840979576111, 72.4943795800209, 74.09657120704651, 72.16708794236183, 73.58727693557739, 69.75379943847656, 73.34514632821083, 73.71739715337753, 71.97525903582573, 73.4196375310421, 75.57248800992966, 74.26794201135635, 75.61645925045013, 70.02246022224426, 71.49178057909012, 69.38974097371101, 71.74838840961456, 73.6424271762371, 75.68638309836388, 70.27320116758347, 74.78295117616653, 75.78831642866135, 78.99054899811745, 71.09046891331673, 66.86425969004631, 73.15962508320808, 76.40268266201019, 74.49585378170013, 71.11903578042984, 74.52758967876434, 75.85445567965508, 76.98764607310295, 72.95445889234543, 72.83848151564598, 72.35376432538033, 77.62341275811195, 60.44042319059372, 54.82420675456524, 56.258196607232094, 45.805474296212196, 44.122943580150604, 25.060996636748314, 0.7210255006793886, 0.7311480981297791, 0.43128220131620765, 0.45448369695805013, 0.26265191088896245, 0.4271861695451662, 0.4139096522703767, 0.3396228072233498, 0.3724899154622108, 0.27454616327304393, 6.041814498603344, 19.3855394795537, 45.60623958706856, 82.25151881575584, 42.813590839505196, 50.43463669717312, 31.765231490135193, 72.12500140070915, 31.270566433668137, 0.21949065034277737, 0.13475544954417273, 0.1545389840612188, 0.17989650776144117, 0.09986409640987404, 0.20797847042558715, 0.1267436982016079, 0.11892189213540405, 0.14555485598975793, 0.14505942788673565, 0.15260993444826454, 0.11042332160286605, 0.14765752363018692, 0.1410450620460324], [0.010103739477926865, 0.01822236936277477, 0.014844364541204413, 0.03795884986175224, 0.12369952717563137, 0.055000274878693745, 0.03597390910726972, 0.0980370253091678, 0.039825132334954105, 0.05396942804509308, 0.09327998486696742, 0.03423394759010989, 0.023686561507929582, 0.07783586203004234, 1.7803808092139661, 46.59265525639057, 54.015845730900764, 31.676610745489597, 37.748861610889435, 37.35620588064194, 47.16975308954716, 10.34672224894166, 0.20859930664300919, 0.15262728586094454, 0.5801901547238231, 0.0342744688532548, 0.07426673284498975, 0.14505297120194882, 0.13051704416284338, 0.2139521506614983, 0.18945137708215043, 0.07750201431917958, 0.10887218100833707, 2.87064787466079, 68.33793461322784, 84.07895475625992, 74.69368636608124, 85.80142512917519, 77.81547725200653, 77.66763478517532, 82.76534244418144, 85.26303201913834, 87.71963059902191, 83.79634112119675, 84.01264071464539, 84.22653883695602, 79.69266772270203, 79.95398730039597, 78.32816854119301, 79.6320229768753, 85.92399135231972, 81.44341617822647, 83.73552158474922, 75.17255187034607, 76.6898712515831, 80.60484677553177, 81.77043423056602, 76.99102029204369, 78.75747710466385, 75.32987862825394, 74.98223528265953, 77.02841028571129, 79.70434069633484, 78.11717346310616, 73.56430336833, 76.85182616114616, 73.33640679717064, 75.72558179497719, 73.34307163953781, 78.36425140500069, 74.38465654850006, 75.59589475393295, 75.05399063229561, 72.77706921100616, 68.8750509917736, 68.28213840723038, 62.12657891213894, 58.60605642199516, 54.75975081324577, 54.518737345933914, 53.93043011426926, 58.07226486504078, 62.96670623123646, 65.43006464838982, 69.5288135111332, 69.04915004968643, 67.21245780587196, 69.986392557621, 67.89803221821785, 67.0340421795845, 67.38878354430199, 65.94854682683945, 64.28207024931908, 61.680460050702095, 56.424658074975014, 55.205140113830566, 56.34980969130993, 55.34461922943592, 57.86233752965927, 57.77355149388313, 59.115305095911026, 61.25389873981476, 65.10867029428482, 64.81398850679398, 66.03282630443573, 63.986172527074814, 66.70361191034317, 68.13111931085587, 66.28675907850266, 66.49305000901222, 65.43222293257713, 69.7817887365818, 68.40738728642464, 66.4782004058361, 66.02738499641418, 62.7073435485363, 64.2579111456871, 62.377365455031395, 63.87084871530533, 67.9402631521225, 66.70148402452469, 66.02938368916512, 70.6288468837738, 67.43580222129822, 70.52739232778549, 67.7681627869606, 61.80143415927887, 68.41896146535873, 67.51109138131142, 65.69247856736183, 65.5863806605339, 72.29390993714333, 69.4534407556057, 69.3941031396389, 68.25208202004433, 70.86079403758049, 65.36724641919136, 56.89623177051544, 49.74917247891426, 47.285859659314156, 22.000163979828358, 24.393598549067974, 33.21287401020527, 8.182529378682375, 0.14832906337687746, 0.3857801476260647, 1.58788135740906, 0.07669947066460736, 0.07630985797732137, 0.15208580007310957, 0.07048246246995404, 0.030728312849532813, 0.04923452215734869, 0.5177246534731239, 0.584786661202088, 0.41785651235841215, 51.33114539086819, 45.67550987005234, 27.47387856245041, 34.90465722978115, 47.13594630360603, 33.15703980624676, 0.048960439598886296, 0.044228917904547416, 0.08348793257027864, 0.14595254324376583, 0.04823911658604629, 0.07441071691573597, 0.04666147389798425, 0.04673023759096395, 0.014668186104245251, 0.041232218354707584, 0.02165881738619646, 0.06344576700939797, 0.04954579744662624, 0.01271645831366186, 0.08057433500653133, 0.06618362400331534, 0.01958508051757235, 0.04028188341180794, 0.1584185313549824, 0.046940154061303474, 0.013192447713663569, 0.11736752319848165, 0.05126055562868714, 0.07525390057708137, 0.07545638814917766, 0.03237179516872857, 0.0558293020731071, 0.18596800306113437, 2.5483211455866694, 57.9067799448967, 67.52740770578384, 54.23769682645798, 20.64124669879675, 33.150485157966614, 62.72889979183674, 14.313025418668985, 0.12301527443923987, 0.41426662530284375, 0.4142262227833271, 0.17895326775033027, 0.1443013537209481, 0.20735500700538978, 0.05331100575858727, 0.3815814619883895, 0.25596901949029416, 0.7856375304982066, 0.10203899728367105, 5.268563590943813, 78.35493430495262, 84.44233685731888, 78.81671592593193, 89.84861835837364, 82.90094956755638, 82.40959033370018, 88.89474794268608, 89.6924239397049, 89.76187661290169, 86.40917211771011, 85.52882015705109, 88.25192123651505, 84.41202208399773, 85.03945961594582, 80.70286631584167, 83.65115091204643, 86.7306500673294, 86.15416780114174, 85.35368755459785, 77.90968179702759, 79.65326383709908, 83.5982197523117, 85.3973700106144, 79.38030168414116, 79.87045258283615, 76.7541030049324, 77.97933965921402, 79.09995272755623, 82.47998535633087, 80.91657444834709, 77.03260526061058, 79.16777148842812, 78.5969889163971, 79.62775200605392, 76.23279377818108, 82.13148325681686, 77.34306380152702, 78.18103283643723, 77.27317795157433, 77.20130860805511, 71.6528083384037, 68.35833951830864, 63.166643902659416, 59.07320335507393, 56.216839626431465, 58.331642746925354, 57.706340700387955, 60.50116293132305, 66.94643408060074, 69.56965371966362, 70.98673447966576, 72.11891412734985, 71.52502879500389, 73.05446952581406, 70.28259426355362, 70.81594124436378, 69.92555022239685, 68.96794080734253, 66.65642604231834, 64.85003337264061, 61.36589772999287, 56.26635856926441, 57.522206380963326, 56.915451139211655, 59.86394092440605, 62.436509281396866, 60.536102056503296, 64.00450274348259, 65.77501013875008, 67.35463097691536, 67.96810805797577, 68.61928671598434, 71.31973341107368, 70.6677795946598, 70.48611894249916, 70.09221687912941, 69.60553899407387, 71.14160656929016, 69.36636462807655, 70.01733809709549, 72.56914436817169, 66.93454071879387, 67.54139855504036, 66.96582064032555, 66.94613009691238, 70.15947327017784, 70.27231201529503, 67.24050030112267, 72.07191824913025, 69.71785336732864, 72.63305693864822, 71.71692609786987, 63.50348062813282, 69.9088767170906, 70.57826399803162, 68.23241427540779, 67.02645778656006, 74.26088958978653, 71.64995089173317, 73.69142174720764, 70.54541856050491, 74.0006947517395, 66.72041460871696, 64.54684004187584, 57.87809908390045, 65.33295705914497, 51.634395718574524, 39.50231172144413, 37.94379495084286, 15.94439473003149, 0.3030222508823499, 0.29013105668127537, 0.9063815139234066, 0.46723697043489665, 0.0225464538380038, 0.2151139680063352, 0.04895740421488881, 0.05001304620236624, 0.031139822604018264, 0.3380093484884128, 0.6060327461455017, 0.5007403367199004, 51.458066180348396, 52.32439689338207, 21.909196861088276, 36.874011754989624, 54.888149723410606, 42.46740661561489, 0.11081116055720486, 0.09473666490521282, 0.04045010602567345, 0.08060516382101923, 0.023725028877379373, 0.1561095318174921, 0.03503022380755283, 0.03740681815543212, 0.06047818191291299, 0.01743012671795441, 0.039833544578868896, 0.04972440641722642, 0.13339599827304482, 0.044077427010051906, 0.12680560816079378, 0.16140555700985715, 0.2036154584493488, 0.1227093389024958, 0.2808555169031024, 0.12293147112359293, 0.2370766262174584, 0.287091457284987, 0.1561208421480842, 0.14374888414749876, 0.22427962539950386, 0.0918602266756352, 0.24809064692817628, 0.3490513184806332, 3.056751675903797, 68.40518340468407, 73.4657746553421, 47.75420352816582, 59.08410117030144, 56.88102498650551, 74.85045075416565, 23.01407877355814, 0.29689273447729647, 0.7962003699503839, 0.9235735726542771, 0.3920953790657222, 0.17994543013628572, 0.3338395769242197, 0.3808325162390247, 0.3613371279789135, 0.5244641855824739, 0.8606624265667051, 0.5986976553685963, 4.977745246142149, 84.50888648629189, 89.59011822938919, 83.0722063779831, 94.49351951479912, 85.0893585383892, 83.42857405543327, 93.7350346148014, 91.9084270298481, 95.01540631055832, 89.81558293104172, 87.91901350021362, 91.12240880727768, 86.7824412882328, 86.46307602524757, 82.91058585047722, 84.61204335093498, 91.88046053051949, 87.50358939170837, 90.01344591379166, 80.72564229369164, 84.2824338376522, 86.92843705415726, 89.59247410297394, 85.03654137253761, 86.37917652726173, 78.44637259840965, 79.55746337771416, 81.2037706375122, 86.54503762722015, 86.55325278639793, 81.48677945137024, 83.10424625873566, 80.32183796167374, 85.61057657003403, 79.13618758320808, 86.87831774353981, 80.46711176633835, 81.31473988294601, 81.69713616371155, 81.97949901223183, 75.64384818077087, 73.13364967703819, 69.50085461139679, 65.89863270521164, 60.320342034101486, 60.17588898539543, 60.48689469695091, 63.044453859329224, 70.95139637589455, 70.17231658101082, 75.3848996758461, 75.8603909611702, 71.37138023972511, 74.60983246564865, 72.86711677908897, 72.62380063533783, 72.47895240783691, 71.4049780368805, 69.04334396123886, 67.79771760106087, 64.74227115511894, 59.20414052903652, 63.182473853230476, 60.18062733113766, 63.46304699778557, 66.97772160172462, 62.35461227595806, 66.7184691131115, 70.98399102687836, 72.08980768918991, 70.47040298581123, 71.23761221766472, 72.60206580162048, 73.1311646103859, 74.35491934418678, 74.07762542366982, 71.28272339701653, 75.49350544810295, 73.09736922383308, 74.59860026836395, 76.67648836970329, 69.80429872870445, 68.9850702881813, 67.54581391811371, 70.00123456120491, 74.34928804636002, 72.02018782496452, 67.81768932938576, 75.35250261425972, 72.31424644589424, 76.85786783695221, 73.10901939868927, 67.97110229730606, 73.52833449840546, 72.16900303959846, 70.90295657515526, 71.2393145263195, 77.31497570872307, 78.02697390317917, 74.74557638168335, 73.59846353530884, 75.6913760304451, 72.28884860873222, 64.78894025087357, 60.50415717065334, 60.526385977864265, 51.92659243941307, 47.87457346916199, 48.24474200606346, 15.517142806202173, 0.2412704285234213, 3.7519533466547728, 3.7424008967354894, 0.3751028096303344, 0.15442902746144682, 0.7266358996275812, 0.19508576224325225, 0.16066090087406337, 0.11383601347915828, 0.6561023031827062, 0.8502214774489403, 0.7911770395003259, 68.31247597932816, 58.34325112402439, 42.3559357970953, 48.93510416150093, 61.90426804125309, 47.34359376132488, 0.23385028762277216, 0.29601533780805767, 0.2253019338240847, 0.28433532861527056, 0.09127058292506263, 0.22567576845176518, 0.10953029530355707, 0.28195579536259174, 0.12861454859375954, 0.07620066578965634, 0.2027806907426566, 0.17552206671098247, 0.321701840730384, 0.13956321578007191], [0.07118601846741512, 0.03407655662158504, 0.04564956667309161, 0.01183190734082018, 0.05862107238499448, 0.036113358655711636, 0.059780615047202446, 0.031000694034446497, 0.047236104001058266, 0.009232571283064317, 0.0639765955565963, 0.04557334068522323, 0.05366215293179266, 0.20540499914204702, 6.79197927005589, 58.48923169076443, 42.01184146106243, 35.028743371367455, 39.3134580552578, 36.797521859407425, 25.95182653516531, 1.2846338795498013, 0.11574813470360823, 0.3427140897838399, 0.5099225440062582, 0.16634754807455465, 0.0539191178540932, 0.15778592467540875, 0.06883612659294158, 0.2169473102549091, 1.4409045316278934, 5.6320183631032705, 0.33650863682851195, 18.566723316907883, 85.60468688607216, 84.9308006465435, 78.9039896428585, 76.78051918745041, 77.49631717801094, 80.32826721668243, 89.95965600013733, 85.11651188135147, 87.29605972766876, 81.05310872197151, 81.1736610531807, 82.91050225496292, 82.45743736624718, 85.41091248393059, 78.9890518784523, 84.18457388877869, 81.80413082242012, 82.45587944984436, 78.91806408762932, 80.37139490246773, 78.09453427791595, 73.62085193395615, 77.28452414274216, 75.9590944647789, 72.79890283942223, 75.32651200890541, 76.18641346693039, 77.38554552197456, 75.4308620095253, 73.65711718797684, 77.48231112957001, 79.48276698589325, 76.59182131290436, 73.22071820497513, 73.28618109226227, 76.49777635931969, 75.21869659423828, 74.49349030852318, 70.43249621987343, 63.88706624507904, 61.568537056446075, 56.750293001532555, 54.898405373096466, 52.81613990664482, 54.59103226661682, 53.03003042936325, 51.72871805727482, 55.14040678739548, 60.43122008442879, 66.74784913659096, 68.88575881719589, 69.61330577731133, 67.0529043674469, 65.96962809562683, 67.09550008177757, 66.89610958099365, 65.50108283758163, 63.073199316859245, 63.83169561624527, 59.43329483270645, 57.46230259537697, 52.64838270843029, 51.97651796042919, 51.8687329441309, 56.48692913353443, 55.052441507577896, 55.776340663433075, 57.53458231687546, 58.04653264582157, 61.83629348874092, 62.97535076737404, 63.15893791615963, 63.07406947016716, 66.19421884417534, 65.65905556082726, 66.68543368577957, 66.40562430024147, 65.54433211684227, 65.77126353979111, 67.13418960571289, 69.53938454389572, 69.06577795743942, 63.173065558075905, 63.93267139792442, 65.07894828915596, 63.57555516064167, 67.32670247554779, 71.41536667943001, 66.32930159568787, 70.13810321688652, 67.71708592772484, 70.49132466316223, 63.087425753474236, 61.979082226753235, 67.93907761573792, 68.7055192887783, 63.69308665394783, 71.49555757641792, 64.0263819694519, 68.4610404074192, 64.087003916502, 73.53632926940918, 64.10382181406021, 67.0228935778141, 52.41314113140106, 48.30405682325363, 30.53324069827795, 21.408189944922924, 32.35920421779156, 26.277904137969017, 6.040663160383701, 1.3884606957435608, 0.26764279464259744, 2.693785415031016, 1.1404091748408973, 0.21910792478593066, 0.013890126829210203, 0.10968766029691324, 0.15426550264237449, 0.041369356113136746, 0.3423784609185532, 0.3284772334154695, 10.604739803820848, 53.769257962703705, 39.915699139237404, 39.10866044461727, 36.28807179629803, 45.98880685865879, 0.2712092298315838, 0.028253767995920498, 0.0893673526297789, 0.059345616318751127, 0.037670087622245774, 0.03520774182106834, 0.0812346683233045, 0.05166799470316619, 0.02165873574995203, 0.05563259583141189, 0.014650881075795041, 0.04330592739279382, 0.04914336786896456, 0.03165169669955503, 0.03679257592011709, 0.03140207161777653, 0.01864458274212666, 0.0724102281674277, 0.0501991619967157, 0.028726863019983284, 0.03281586294178851, 0.03475697616522666, 0.07287338026799262, 0.0157572868920397, 0.05029203064623289, 0.048264353317790665, 0.12055230152327567, 0.24659386865096167, 10.400246176868677, 67.98857375979424, 60.108757987618446, 48.44923183321953, 30.53824882954359, 46.97794318199158, 33.24393734335899, 0.811828396981582, 0.2326549994177185, 0.20291095250286162, 0.16672053665388376, 0.05377019479055889, 0.035666240655700676, 0.1927258662180975, 0.15164086769800633, 0.40937943442258984, 5.327411508187652, 8.818638995289803, 0.5400887690484524, 25.574580878019333, 90.50778418779373, 83.50061058998108, 83.13744887709618, 77.91345879435539, 82.12195336818695, 84.81299176812172, 92.27087438106537, 87.11126044392586, 89.16519463062286, 82.88101583719254, 83.93197104334831, 83.38883578777313, 85.13230383396149, 85.49005463719368, 82.35336095094681, 84.35997247695923, 85.39208069443703, 85.04931628704071, 81.01337045431137, 84.10311385989189, 83.61715793609619, 78.10309141874313, 77.42735087871552, 79.87062737345695, 75.5828158557415, 78.0465504527092, 80.34184008836746, 80.57024583220482, 76.05956107378006, 77.9645736515522, 79.68488574028015, 83.59286963939667, 79.36412215232849, 78.01941990852356, 77.10740804672241, 79.69811663031578, 78.65451022982597, 76.75428539514542, 71.51353061199188, 65.38888245820999, 62.711994498968124, 58.09745751321316, 57.23293550312519, 58.42653505504131, 57.90117904543877, 56.26655615866184, 56.12857796251774, 57.652565985918045, 62.67032213509083, 71.0011737048626, 70.21074771881104, 71.97899043560028, 72.58567348122597, 70.3513553738594, 71.58176735043526, 70.65324917435646, 68.22580263018608, 69.12879377603531, 67.97493249177933, 62.96047456562519, 61.40259236097336, 55.626609697937965, 54.14085142314434, 54.07216630876064, 56.93457551300526, 56.51001289486885, 57.031474113464355, 59.28015924990177, 59.97036561369896, 61.72480747103691, 64.62191641330719, 65.94111442565918, 67.7514436841011, 70.20962297916412, 67.16209530830383, 69.57218438386917, 68.8369770348072, 68.78949478268623, 67.3525182902813, 69.09451961517334, 71.88654139637947, 70.85791379213333, 65.95072790980339, 68.61201390624046, 68.62451523542404, 67.15522527694702, 67.34078451991081, 71.74908757209778, 65.92463091015816, 69.9676063656807, 71.29602268338203, 70.07979914546013, 69.14569526910782, 64.76189330220222, 69.19883921742439, 72.51251980662346, 67.73043841123581, 73.02521869540215, 64.68912720680237, 71.9543981552124, 68.5686506330967, 75.15968576073647, 69.83690857887268, 67.47430175542831, 61.337357461452484, 59.77712318301201, 55.45808494091034, 46.69811859726906, 44.2826946079731, 36.5258364379406, 12.130897510796785, 1.600585263222456, 0.38277053099591285, 1.638240886386484, 0.6953958165831864, 0.27463198523037136, 0.047591128895874135, 0.11962352597038262, 0.16275283705908805, 0.0791562837548554, 0.23866753850597888, 0.11046533458284102, 9.768298286944628, 59.21911932528019, 33.52284997701645, 48.04252825677395, 46.058373525738716, 53.670155480504036, 0.4180677275871858, 0.0695036884280853, 0.12435662472853437, 0.07462668188964017, 0.06561861213413067, 0.06134907736850437, 0.025856263637251686, 0.046447983986581676, 0.04401261525345035, 0.04330620198743418, 0.03621859890699852, 0.03989541371993255, 0.03156128455884755, 0.03870055967126973, 0.16481110942550004, 0.12185464453068562, 0.11053684051148593, 0.17215201864019036, 0.2470300139975734, 0.146420200180728, 0.1598877611104399, 0.19330294540850446, 0.21638511854689568, 0.14571931591490284, 0.2009775539045222, 0.22899036324815825, 0.373449067119509, 0.6295505748130381, 11.793886944651604, 79.83907386660576, 59.89830248057842, 50.21833710372448, 63.007607236504555, 57.30616897344589, 49.559931233525276, 2.557459892705083, 0.33840479445643723, 0.3216891351621598, 0.79165302333422, 0.4222323338035494, 0.2703462011413649, 0.5643515358678997, 0.2863799751503393, 0.8879807044286281, 5.768599659204483, 13.129241690039635, 0.7255781907588243, 28.267312087118626, 101.3979922235012, 87.52021729946136, 88.61110836267471, 85.84626272320747, 88.40320631861687, 90.75942948460579, 97.65445590019226, 91.33563816547394, 97.54761323332787, 88.24032425880432, 87.9765348136425, 89.56255450844765, 90.64734309911728, 91.60791635513306, 87.19069138169289, 88.17108437418938, 87.6234957575798, 90.24245962500572, 82.61067554354668, 84.36422064900398, 86.94334745407104, 81.91049471497536, 85.44165283441544, 82.64228224754333, 78.1751811504364, 80.7359929382801, 83.21084573864937, 83.01969319581985, 80.6701272726059, 79.56664368510246, 84.07380983233452, 88.25464949011803, 85.04050835967064, 80.7348757982254, 79.66587916016579, 83.92605856060982, 81.56725153326988, 81.48209810256958, 76.76459804177284, 71.15024730563164, 67.6251308619976, 64.45767402648926, 62.56180755794048, 61.11075662076473, 61.20941072702408, 60.26673071086407, 60.29240593314171, 61.63362756371498, 66.4595890045166, 75.88061347603798, 75.80723941326141, 76.86810448765755, 76.43273144960403, 71.58182054758072, 77.17568278312683, 73.74065190553665, 71.3035386800766, 71.20138496160507, 71.02533280849457, 63.7451134622097, 64.06149208545685, 59.23235021531582, 57.4367755651474, 56.488544046878815, 61.58365644514561, 61.33886978030205, 61.5045864880085, 63.37564408779144, 63.616798147559166, 66.09201952815056, 68.49992752075195, 71.67797818779945, 70.12240245938301, 71.81308373808861, 70.46206623315811, 73.80659356713295, 74.49147641658783, 72.57055029273033, 70.74578180909157, 72.24691405892372, 77.90505364537239, 74.19870972633362, 66.63077741861343, 70.33028170466423, 71.0804146528244, 68.4415702521801, 74.11974236369133, 74.69798773527145, 69.36139449477196, 74.888995885849, 74.89498436450958, 73.90392914414406, 68.77890855073929, 67.3512415587902, 72.39779636263847, 74.58776324987411, 70.65832570195198, 77.0720699429512, 69.55605044960976, 73.31915572285652, 67.34354317188263, 76.42588421702385, 71.91397592425346, 69.56401482224464, 63.137119486927986, 59.080403968691826, 53.26399527490139, 50.85135653614998, 53.902292624115944, 46.458001881837845, 11.69219110161066, 3.4173423517495394, 3.427559291012585, 5.703811710700393, 1.5262446273118258, 0.663956303615123, 0.3735630016308278, 0.39625859004445374, 0.4021727351937443, 0.4439618834294379, 0.30948784144129604, 0.4589179699542001, 16.079055704176426, 71.13693282008171, 55.51994562149048, 56.9701986014843, 47.687315717339516, 64.90844383835793, 0.35269081068690866, 0.18344106443692, 0.21057031728560105, 0.20268400374334306, 0.118188494379865, 0.19354252552147955, 0.13863841071724892, 0.1357604213990271, 0.1297067673294805, 0.14853719127131626, 0.09648975872551091, 0.14804137725150213, 0.20350047008832917, 0.10233975262963213], [0.022457650302385446, 0.06556614971486852, 0.03919483373465482, 0.09274258089135401, 0.057790935679804534, 0.01962502476089867, 0.048883115232456475, 0.008863570819812594, 0.029565693985205144, 0.04417364274559077, 0.11880884820129722, 0.048644188209436834, 0.08271560916909948, 0.08602879388490692, 21.221532560884953, 60.92545576393604, 33.131645768880844, 56.01103886961937, 19.251756258308887, 47.18963362276554, 8.140573929995298, 0.5246270424686372, 0.38687270774971694, 0.08266733988421038, 0.21332334377802908, 0.14549915038514882, 0.22626610239967704, 0.0691625454055611, 0.10344767521019094, 0.5228036153130233, 2.4939752742648125, 2.5214575370773673, 0.5210064898710698, 43.46924185752869, 84.0853764116764, 77.64821782708168, 78.70507791638374, 77.71868884563446, 68.82006794214249, 78.63332256674767, 80.52378952503204, 80.66099256277084, 79.10389691591263, 77.87387251853943, 80.41057839989662, 78.82442191243172, 80.05410432815552, 77.48108759522438, 78.68601813912392, 82.54412591457367, 79.5845103263855, 81.2166291475296, 78.79735216498375, 82.98798009753227, 75.78188717365265, 76.61759912967682, 70.14831706881523, 76.13323912024498, 75.8978645503521, 77.36007168889046, 78.41497868299484, 75.7434332370758, 75.20102754235268, 76.0780356824398, 75.74423879384995, 77.73693546652794, 74.61760684847832, 73.26819285750389, 74.36254933476448, 75.29069513082504, 72.72536158561707, 68.16732376813889, 58.87896917760372, 55.1749849319458, 55.53427465260029, 54.060660526156425, 53.6396811157465, 55.38195602595806, 51.636592000722885, 52.81931273639202, 51.7786967754364, 54.39213193953037, 58.96463178098202, 65.58983087539673, 65.31530320644379, 67.24261298775673, 69.39524307847023, 70.0064554810524, 67.65372812747955, 66.07735991477966, 67.50513330101967, 65.32239362597466, 64.55626353621483, 63.45156401395798, 58.05390805006027, 52.645118683576584, 50.358872562646866, 48.320901319384575, 50.89284650981426, 51.39728084206581, 52.53751985728741, 54.61560934782028, 53.67793366312981, 57.31502249836922, 60.876176208257675, 65.4325345158577, 64.62459146976471, 63.43971624970436, 68.7392158806324, 65.07652401924133, 60.70411764085293, 65.20833894610405, 69.05826956033707, 65.7952706515789, 67.81441390514374, 67.13108137249947, 66.35263234376907, 63.092734068632126, 63.36563162505627, 64.33921918272972, 65.30907914042473, 70.05116388201714, 68.83434757590294, 62.30464115738869, 72.02550753951073, 65.94823524355888, 69.79950338602066, 62.37904876470566, 64.91741895675659, 67.60181531310081, 65.90989530086517, 68.47864106297493, 64.19439375400543, 66.23651057481766, 66.6885495185852, 68.29899430274963, 68.84562537074089, 64.21488985419273, 57.409485429525375, 49.13097605109215, 42.08773858845234, 23.24534386396408, 31.597020216286182, 37.201181799173355, 21.68042253702879, 0.9755459963344038, 1.235594186000526, 1.0236465465277433, 0.5021772533655167, 0.12017388784443028, 0.031242294644471258, 0.07015152397798374, 0.05331855340045877, 0.07141281137592159, 0.14931609010091051, 0.061384407308651134, 1.2844835501164198, 37.19183050096035, 36.690709590911865, 18.511536978185177, 25.527070127427578, 51.31898984313011, 2.3141874466091394, 0.2575161895947531, 0.006069032297091326, 0.030205273142200895, 0.14220405922969803, 0.022656332512269728, 0.05533605217351578, 0.04449299260159023, 0.09566581895342097, 0.0026829770285985433, 0.10407582900370471, 0.013628675624204334, 0.023881720371718984, 0.07169715783675201, 0.049396354879718274, 0.1134546757384669, 0.08015187486307696, 0.04988870306988247, 0.03237209944927599, 0.062049887419561855, 0.019628655718406662, 0.01905339664517669, 0.07695735956076533, 0.019751097097469028, 0.04731187356810551, 0.013648879667016445, 0.02017045691900421, 0.06284579998464324, 27.049352042376995, 72.43860617280006, 47.28737197816372, 44.33575876057148, 21.227908618748188, 60.26524119079113, 10.91951871290803, 0.19428422790952027, 0.11648220781353302, 0.022006161052559037, 0.06916485348483548, 0.23330130614340305, 0.10650601383531466, 0.02370513931964524, 0.3275293030310422, 0.931207244284451, 4.33825571089983, 1.6546294069848955, 0.9767163929063827, 52.995741069316864, 87.67037764191628, 79.71744999289513, 80.19298687577248, 82.46686086058617, 77.01394066214561, 88.06261539459229, 87.28388518095016, 87.50380977988243, 84.96863141655922, 83.55905905365944, 87.18524247407913, 82.23940506577492, 85.57099789381027, 79.15530055761337, 82.29610562324524, 84.1970220208168, 84.10487696528435, 81.41285061836243, 82.75901958346367, 86.04075148701668, 78.99661347270012, 80.18373817205429, 76.48307874798775, 77.81907185912132, 77.08301335573196, 80.16560554504395, 80.25313764810562, 78.23292285203934, 79.42120268940926, 75.28106644749641, 78.04159551858902, 80.08586302399635, 76.37980788946152, 73.78453955054283, 76.33994042873383, 77.33896002173424, 74.86191853880882, 68.46606373786926, 62.07777053117752, 58.3713848143816, 57.62735813856125, 58.0218605697155, 57.302080392837524, 59.18589770793915, 56.43964447081089, 56.28261789679527, 56.98209196329117, 60.11018291115761, 61.457317024469376, 70.3967173397541, 70.90561643242836, 69.4564425945282, 71.65834844112396, 72.09592536091805, 71.02049946784973, 70.86669892072678, 68.34745690226555, 67.83861860632896, 68.13014656305313, 66.15339383482933, 60.245668441057205, 54.65107284486294, 54.264192804694176, 51.87179557979107, 52.53297530114651, 52.941384986042976, 54.65372510254383, 55.24799421429634, 54.94352035224438, 57.50054754316807, 59.97390702366829, 65.72601556777954, 66.91975951194763, 67.01004266738892, 69.0684986114502, 67.7321483194828, 65.3044281899929, 66.1264380812645, 70.00308126211166, 69.43910032510757, 70.31914830207825, 68.4731237590313, 69.1413863003254, 65.77046558260918, 67.9248359799385, 67.53945305943489, 68.71474519371986, 69.40295666456223, 70.52195101976395, 63.60381044447422, 73.59870672225952, 69.95873004198074, 71.08852341771126, 65.67865490913391, 66.97284266352654, 70.35571753978729, 68.3221198618412, 69.76313173770905, 66.67916402220726, 66.53928592801094, 68.36675226688385, 69.40642207860947, 73.55500906705856, 68.32363218069077, 62.3983783274889, 58.47485326230526, 61.89493954181671, 52.477106899023056, 48.175483122467995, 44.4578842073679, 30.63235267996788, 3.6458407156169415, 0.6953039090149105, 0.919745871797204, 1.7782696662470698, 0.27314644306898117, 0.08488168590702116, 0.0354769187833881, 0.09992758714361116, 0.07516137702623382, 0.21660917293047532, 0.08053584722802043, 0.9128154593054205, 41.076806634664536, 36.71136148273945, 21.59416526556015, 36.64504364132881, 56.491511687636375, 3.6666237004101276, 0.42345978668890893, 0.1631920103682205, 0.08927393850171939, 0.09919916177750565, 0.01941169255587738, 0.08337191262398846, 0.038138679665280506, 0.03764167078770697, 0.049955203212448396, 0.03919500071788207, 0.049375905000488274, 0.024120016569213476, 0.0471405079588294, 0.2176981113734655, 0.2617387130158022, 0.14221979276044294, 0.1413248517201282, 0.14733688614796847, 0.15246444381773472, 0.11122834403067827, 0.13729623664403334, 0.11759056826122105, 0.13499133376171812, 0.19616318255430087, 0.14460017206147313, 0.27410666341893375, 0.24222992156865075, 33.700627237558365, 83.03742304444313, 48.33551533520222, 80.31754419207573, 32.13999778032303, 72.91531339287758, 18.573239967226982, 0.4893007833743468, 0.5619178852066398, 0.15927219414152205, 0.33104132395237684, 0.8409113239031285, 0.35648873657919466, 0.18753357842797413, 0.5632091627921909, 1.438948824070394, 7.220243364572525, 6.476686438545585, 0.9611944039352238, 60.347103998064995, 95.00385493040085, 84.13443177938461, 82.20976665616035, 87.06779077649117, 86.84622466564178, 93.22379484772682, 91.38223126530647, 90.31942069530487, 89.3172624707222, 89.35203820466995, 92.38662376999855, 87.03698202967644, 89.0907034277916, 83.68548586964607, 86.78267687559128, 89.35051828622818, 89.58212345838547, 87.65000313520432, 83.32959696650505, 87.79409140348434, 82.67885908484459, 82.63801887631416, 78.47434669733047, 85.15885680913925, 80.54237052798271, 84.67751383781433, 83.08717757463455, 82.83994764089584, 79.95502844452858, 80.67346349358559, 81.28298878669739, 84.72409933805466, 81.42366483807564, 79.6791784465313, 79.13805708289146, 83.90955224633217, 80.97132951021194, 73.66255849599838, 65.96348002552986, 63.366813361644745, 63.33446189761162, 60.894115045666695, 59.81848016381264, 62.894817888736725, 58.8383873552084, 57.831779569387436, 59.533978030085564, 60.87358094751835, 63.31406459212303, 75.09336411952972, 70.90574562549591, 72.93014779686928, 77.07330867648125, 76.26382291316986, 74.36029225587845, 73.94776359200478, 73.41874077916145, 70.84651440382004, 72.13039711117744, 68.97759228944778, 63.369488418102264, 61.40643395483494, 56.19559496641159, 53.83266136050224, 54.7886748611927, 55.76722875237465, 57.72443912923336, 57.306978330016136, 59.9840334802866, 62.976847887039185, 66.3321590423584, 71.01584851741791, 70.55014550685883, 69.68858733773232, 74.27919700741768, 68.97126942873001, 65.92104390263557, 70.86225315928459, 74.49806526303291, 71.92401498556137, 76.00820302963257, 74.1445018351078, 71.30667731165886, 67.62560203671455, 71.31397292017937, 71.2562920153141, 69.81826677918434, 74.71950978040695, 74.01023983955383, 66.73672333359718, 78.03851768374443, 72.5230984389782, 74.57270845770836, 67.10142776370049, 71.82532668113708, 74.12181705236435, 70.30534744262695, 72.1391062438488, 68.50664556026459, 69.91370245814323, 70.10818362236023, 71.81844145059586, 74.50421333312988, 70.61037227511406, 64.20318648219109, 59.847617000341415, 60.03053918480873, 54.81930881738663, 56.18780918419361, 55.395190715789795, 38.564807027578354, 3.115995009429753, 3.1267717061564326, 6.088755279779434, 1.622931151650846, 0.2307289035525173, 0.28094107168726623, 0.17388402804499492, 0.2401391282910481, 0.2517617546254769, 0.41552287351805717, 0.25006603624206036, 1.8345169792883098, 50.24050511419773, 51.19837671518326, 28.562598042190075, 37.40790590643883, 70.17563000321388, 3.683932484127581, 0.4063057556049898, 0.1617236266611144, 0.16189780872082338, 0.38786994642578065, 0.20820288104005158, 0.19209410558687523, 0.181777362304274, 0.13802184927044436, 0.08956347257480957, 0.25888224598020315, 0.10583733135717921, 0.2543848310597241, 0.183490417257417], [0.060318252799334005, 0.02460429946950171, 0.048183173494180664, 0.1575842237798497, 0.05855996765603777, 0.023758347597322427, 0.031925144721753895, 0.02386158776062075, 0.06081895757233724, 0.021255378487694543, 0.060711676414939575, 0.03872064218739979, 0.0577185503061628, 0.17338518606266007, 44.84041728079319, 47.4445391446352, 37.24198400974274, 34.72089909017086, 38.311676010489464, 38.63835968077183, 0.8489859499968588, 5.002476694062352, 1.1521725123748183, 0.12026961005176418, 0.17356238124193624, 0.035272115710540675, 0.4035965009825304, 0.07629180894582532, 0.7897942105773836, 0.35667071118950844, 5.194725953042507, 0.6028270244132727, 9.346312880516052, 64.87461805343628, 72.79295235872269, 71.21374189853668, 73.08169886469841, 63.28917972743511, 58.8136962801218, 78.12756970524788, 83.19639131426811, 84.9045592546463, 81.55481100082397, 81.76461294293404, 78.01381140947342, 79.29144725203514, 79.97405782341957, 74.97053951025009, 78.33924874663353, 76.84271425008774, 78.9058667421341, 75.38504406809807, 80.37796095013618, 76.62909731268883, 73.93057331442833, 79.27516132593155, 75.11021241545677, 71.44980803132057, 74.27822425961494, 79.92730513215065, 78.60974103212357, 73.97792637348175, 73.7623031437397, 76.65371239185333, 75.77660545706749, 76.37566611170769, 74.76947709918022, 70.95236152410507, 69.9056088924408, 67.53381416201591, 69.77605104446411, 60.789609253406525, 57.864655405282974, 56.20777331292629, 54.40032050013542, 55.17293684184551, 54.272654950618744, 54.188421070575714, 51.229888424277306, 52.72473581135273, 55.606938153505325, 55.09726010262966, 54.54017199575901, 63.00758443772793, 67.54738703370094, 65.55858135223389, 63.01824286580086, 63.4721665084362, 62.09325850009918, 66.14854529500008, 63.891519606113434, 62.15975113213062, 63.996181190013885, 58.97758528590202, 53.8030419498682, 51.96514517068863, 53.64240936934948, 51.49843141436577, 52.59708546102047, 52.46039159595966, 53.78339320421219, 49.41917918622494, 51.702415868639946, 51.52419403195381, 54.326577857136726, 55.04264183342457, 60.84468349814415, 59.485298842191696, 66.61424830555916, 64.53175485134125, 65.87917014956474, 60.69416217505932, 64.89185392856598, 64.64891016483307, 69.90114033222198, 62.591221779584885, 67.93153122067451, 65.56306511163712, 64.08033147454262, 63.309406042099, 67.01718628406525, 62.72889219224453, 68.35789114236832, 64.811260253191, 65.38596421480179, 71.27931877970695, 68.4249347448349, 68.13811093568802, 62.89509527385235, 66.08027815818787, 67.49053448438644, 68.20092156529427, 70.11819988489151, 64.59010452032089, 65.33993348479271, 64.52081143856049, 69.59460318088531, 68.58270987868309, 58.277320861816406, 51.50444269180298, 43.6999274790287, 28.93076978623867, 22.2671889513731, 30.942163355648518, 30.97511898726225, 13.454053960740566, 0.07753037178190425, 0.38048433023504913, 0.12831935193389654, 0.14679160056402907, 0.11020018006092869, 0.030386271828319877, 0.36542324465699494, 0.18778167839627713, 0.060417370332288556, 0.24764234520262107, 0.6439941341523081, 22.294532284140587, 39.17074531316757, 27.66619384288788, 21.737691164016724, 47.39408165216446, 5.185143342241645, 0.33986465830821544, 0.127679813595023, 0.15121935750357807, 0.06289976154221222, 0.09318425523815677, 0.08871651138179004, 0.03524674910295289, 0.12369729331112467, 0.08091330353636295, 0.022660573886241764, 0.060359668350429274, 0.06938225822523236, 0.058669037389336154, 0.01018715131067438, 0.011630631324806018, 0.04948762791173067, 0.05579100354225375, 0.05797580837679561, 0.008861951082508313, 0.0721299709402956, 0.03211004710465204, 0.0532480122637935, 0.032813057623570785, 0.047681247888249345, 0.04845830248086713, 0.029985385917825624, 0.3091043292079121, 55.38933143019676, 53.70564177632332, 50.807286500930786, 30.57640828192234, 43.1689477711916, 45.83950147032738, 3.13413024879992, 10.172380954027176, 1.7470104061067104, 0.03410430181247648, 0.2874490537215024, 0.08591972044087015, 0.4466930462513119, 0.13174525403883308, 0.6228635273873806, 0.5257635971065611, 7.181427022442222, 0.5133813677821308, 11.392801366746426, 80.87851569056511, 72.78118818998337, 79.74028676748276, 78.00275400280952, 73.50632607936859, 68.6165888607502, 87.04173937439919, 86.27737998962402, 88.93743485212326, 85.5139933526516, 84.66774836182594, 81.13080695271492, 84.10296186804771, 83.59359160065651, 80.74366852641106, 82.94180497527122, 81.88399493694305, 80.93869686126709, 79.64116528630257, 83.61538723111153, 79.9248656630516, 77.85577788949013, 78.51357579231262, 78.46533358097076, 75.84610372781754, 77.94505789875984, 80.89442163705826, 78.7738162279129, 77.83948436379433, 76.98342829942703, 79.32781890034676, 79.64469149708748, 78.3903332054615, 79.617530554533, 74.0356832742691, 73.82005244493484, 70.36965519189835, 69.73392650485039, 63.64865563809872, 60.58512702584267, 59.99044753611088, 57.384874150156975, 56.024455949664116, 56.75759620964527, 56.22667349874973, 56.82967074215412, 54.58380505442619, 59.816352277994156, 58.9291986823082, 59.202992990612984, 66.33203744888306, 70.3308592736721, 68.1687068939209, 68.02261233329773, 66.825060993433, 67.9611012339592, 69.35788348317146, 67.44506612420082, 64.43557441234589, 65.46414881944656, 61.64327524602413, 57.433864921331406, 55.53313471376896, 57.62083388864994, 54.00580286979675, 55.82328334450722, 55.11386141180992, 55.90459518134594, 51.766590625047684, 52.21880055963993, 52.853461503982544, 55.390380173921585, 57.26134657859802, 61.913885325193405, 63.80255118012428, 70.066477060318, 68.23755919933319, 68.47803309559822, 65.68938553333282, 67.37385794520378, 66.0035602748394, 71.09141886234283, 65.71058079600334, 70.10939955711365, 68.65548357367516, 66.91659808158875, 66.79190397262573, 66.1616013944149, 67.44566649198532, 70.83526700735092, 68.53235498070717, 64.7244881093502, 71.11487880349159, 69.92148444056511, 70.2619081735611, 64.91781413555145, 69.10415589809418, 69.72152397036552, 71.0210770368576, 70.23861542344093, 66.6986645758152, 68.29488292336464, 67.02783331274986, 71.86042159795761, 72.18373104929924, 60.64110942184925, 60.152360647916794, 58.79331037402153, 52.76352033019066, 42.84644767642021, 43.4065680205822, 34.989290088415146, 18.380558006465435, 1.3030679966323078, 0.25660628685727715, 0.5340693576727062, 0.30107892234809697, 0.12065957896993496, 0.041202933207387105, 0.31627341639250517, 0.1159312151139602, 0.107235938339727, 0.1998762958100997, 0.6159899337217212, 24.62111324071884, 41.9250313192606, 29.66198544949293, 32.46073096990585, 52.57832206785679, 6.435155617073178, 0.31218934804201126, 0.2862687420565635, 0.07312286805245094, 0.0847130105830729, 0.01497303810538142, 0.08208443483454175, 0.05204909866733942, 0.05839542609464843, 0.05276092218991835, 0.060926973455934785, 0.10779052303405479, 0.041098835863522254, 0.08727616601390764, 0.2569489512825385, 0.08403419036767446, 0.19657090364489704, 0.3695592633448541, 0.1677958047366701, 0.09885985185974278, 0.17677789932349697, 0.09402864860021509, 0.1966384836123325, 0.16831131535582244, 0.13534484838601202, 0.1920346001861617, 0.14803823054535314, 0.34523421549238265, 64.45884436368942, 64.28220704197884, 56.987130492925644, 57.294165417551994, 63.29873241484165, 56.52263201773167, 6.848690751940012, 16.761559881269932, 1.9692925410345197, 0.33369640179444104, 0.2847571356687695, 0.22722007386619225, 1.4339752472005785, 0.6740188167896122, 2.532902997918427, 1.818592983763665, 12.573676351457834, 0.7649650366511196, 11.902031991630793, 90.6184646487236, 83.0590894818306, 87.41747081279755, 82.0773209631443, 81.14795163273811, 71.61433160305023, 90.81321939826012, 88.86856734752655, 94.2318807542324, 88.2505913078785, 88.57728257775307, 84.47769775986671, 85.70475831627846, 85.59586375951767, 84.95901793241501, 85.36906152963638, 84.25336539745331, 84.21636298298836, 81.87438905239105, 86.68215706944466, 82.61775836348534, 82.08533093333244, 84.49067026376724, 79.39677760004997, 80.84579944610596, 81.7812180519104, 85.45191988348961, 86.64078488945961, 82.54549384117126, 79.09895718097687, 83.38454961776733, 83.17540884017944, 83.29887181520462, 83.58530804514885, 79.33993265032768, 78.3708630502224, 74.60838854312897, 78.06460708379745, 67.48971372842789, 64.07982990145683, 64.15351554751396, 59.65979687869549, 61.441855654120445, 62.74233587086201, 60.509894862771034, 59.61273640394211, 59.14445713162422, 62.91153319180012, 61.52545876801014, 62.75058142840862, 70.71371912956238, 71.80500537157059, 69.8206302523613, 69.73072707653046, 68.94269496202469, 69.92887124419212, 72.77149870991707, 70.48117160797119, 69.22739088535309, 69.76618677377701, 64.5599265396595, 60.57462818920612, 58.585605919361115, 61.20212271809578, 56.80636279284954, 58.59113462269306, 58.636971563100815, 58.74400041997433, 54.2008426040411, 58.21899399161339, 56.3043337315321, 59.320345893502235, 61.19078412652016, 68.3449338376522, 67.08774849772453, 74.83297929167747, 71.05294972658157, 71.42073199152946, 69.1473063826561, 70.13824000954628, 72.01096951961517, 77.47845813632011, 69.34035882353783, 74.53708156943321, 70.91542750597, 70.04019767045975, 69.51771810650826, 72.24129796028137, 70.00934332609177, 76.29733711481094, 70.17768189311028, 70.43233662843704, 74.95618388056755, 75.43365865945816, 74.05313193798065, 67.6520562171936, 72.27332264184952, 70.98519176244736, 74.13616508245468, 72.8017070889473, 70.60547813773155, 70.02239182591438, 68.88308376073837, 73.41659769415855, 73.15905511379242, 64.27953198552132, 63.61462466418743, 62.1595611423254, 55.25685153901577, 48.84193316102028, 54.1522204130888, 45.619022101163864, 23.374764919281006, 1.2340556248091161, 0.6892641924787313, 0.39316914801020175, 0.2060542447725311, 0.14400140731595457, 0.10885806535952725, 1.4499606331810355, 0.23189827596070245, 0.25292006903328, 0.4152853862615302, 1.0061412421055138, 29.280742406845093, 54.527157694101334, 45.96670724451542, 31.158983521163464, 64.12973642349243, 7.390235792845488, 0.502683516824618, 0.432585293892771, 0.22989596152910963, 0.16882339725270867, 0.13991232204716653, 0.2895900310249999, 0.16116624407004565, 0.2396892532124184, 0.18362538423389196, 0.087607356836088, 0.2573709958232939, 0.20817086478928104, 0.17425985162844881], [0.04768348175275605, 0.009316637133451877, 0.0434194908302743, 0.07392208688543178, 0.02595266490970971, 0.03025647391041275, 0.03889100218657404, 0.025609955955587793, 0.0352302585815778, 0.11907438864000142, 0.10051857418147847, 0.1294144947314635, 0.08375110555789433, 2.3893749620765448, 59.640809297561646, 33.43214504420757, 48.663635328412056, 18.38115457445383, 48.039507418870926, 20.20940937101841, 1.931720394641161, 3.475800552405417, 0.42806240846402943, 0.3104545926908031, 0.3314825159031898, 0.061984155399841256, 0.16171022347407416, 0.11453983664978296, 0.2547798614250496, 2.5483748177066445, 2.72466279566288, 0.5295382789336145, 45.44607438147068, 70.35600632429123, 60.71671016514301, 66.18718162178993, 65.734983086586, 62.59176895022392, 72.42574766278267, 80.60306087136269, 86.69164896011353, 79.95555281639099, 83.72945711016655, 80.4037843644619, 80.50305023789406, 82.48869448900223, 76.49880230426788, 75.97894459962845, 82.38965660333633, 76.25652730464935, 73.96537184715271, 75.50042867660522, 78.15617457032204, 73.494843095541, 74.61474180221558, 75.06448566913605, 76.00735187530518, 74.15588602423668, 70.2716052532196, 75.35042032599449, 72.7756404876709, 74.21225219964981, 75.02597093582153, 76.2787713110447, 71.39243111014366, 71.18205919861794, 69.47560876607895, 67.05525264143944, 67.0585584640503, 64.24779608845711, 60.969567596912384, 59.61724676191807, 57.7107522636652, 55.42670242488384, 55.65712586045265, 56.69626750051975, 52.79667355120182, 54.118276834487915, 52.873562425374985, 49.477000683546066, 52.650119215250015, 51.2474624812603, 50.221608728170395, 60.85125334560871, 68.83901372551918, 65.4754950106144, 67.0355848968029, 63.45148801803589, 63.947627395391464, 64.09027174115181, 63.39084707200527, 64.42476779222488, 65.07605284452438, 62.1930867433548, 54.50256921350956, 48.3879791200161, 52.88836643099785, 49.40135434269905, 48.90697807073593, 51.57459452748299, 52.79320813715458, 51.8870859593153, 51.30021125078201, 50.92350326478481, 52.105954214930534, 53.50491754710674, 50.22686764597893, 57.49273516237736, 60.88641285896301, 64.82020497322083, 65.6161330640316, 62.390398755669594, 65.60262098908424, 65.49201652407646, 66.88609331846237, 66.64826408028603, 65.74314504861832, 66.52640461921692, 63.697156235575676, 64.86810520291328, 63.350607231259346, 65.22440448403358, 63.17866265773773, 70.65612182021141, 62.37762004137039, 63.24167087674141, 71.96642071008682, 63.2179069519043, 63.26160080730915, 64.63862031698227, 66.51598557829857, 65.8547830581665, 69.66536298394203, 66.44878998398781, 68.1186331808567, 65.7006861269474, 66.5489450097084, 71.35830894112587, 56.37426137924194, 52.33619526028633, 39.37647387385368, 39.69754904508591, 31.305558755993843, 17.344955876469612, 27.46704462915659, 17.379887402057648, 5.932251177728176, 0.27571430371608585, 1.7126331757754087, 0.5987916409503669, 0.08746600738959387, 0.08504385259584524, 0.3783294005552307, 0.12864749995060265, 0.2853803022298962, 0.24725956027396023, 0.47693004249595106, 15.671017449349165, 41.299022510647774, 21.48140251636505, 29.99970942735672, 46.91920593380928, 10.159429349005222, 0.7768842845689505, 0.3365779831074178, 0.1378320821095258, 0.11756928346585482, 0.03865902908728458, 0.12651781813474372, 0.019955625575676095, 0.07159693821449764, 0.09289890687796287, 0.05513395422894973, 0.04962607185007073, 0.03847999709250871, 0.03493294680083636, 0.0383018593856832, 0.04225788128678687, 0.06663137653958984, 0.06903115558088757, 0.07148591292207129, 0.06361988969729282, 0.02751714375335723, 0.06665925160632469, 0.0806102401111275, 0.04701933008618653, 0.05848347820574418, 0.09381972660776228, 0.14434450218686834, 3.8705316837877035, 65.34553438425064, 48.60822670161724, 57.54666566848755, 16.30382314324379, 59.60670232772827, 21.657576262950897, 1.3385754288174212, 4.392383331432939, 0.4176850465591997, 0.236650321749039, 0.15417138347402215, 0.04237648390699178, 0.33674461010377854, 0.28786756563931704, 0.1953033747849986, 2.9587017372250557, 2.2722533717751503, 1.8960219039581716, 55.557715594768524, 77.9865288734436, 71.16141110658646, 72.4100013077259, 75.25595739483833, 70.15761137008667, 79.28773105144501, 81.49396866559982, 89.18217971920967, 83.66468578577042, 83.63180235028267, 81.60544708371162, 82.80704900622368, 84.91082891821861, 77.69639164209366, 80.3260101377964, 84.25213426351547, 82.64187186956406, 76.73160061240196, 80.46683818101883, 81.9143933057785, 76.80352315306664, 76.47296369075775, 78.47141325473785, 78.84994894266129, 76.1196206510067, 75.55416539311409, 78.85584622621536, 77.28480532765388, 76.25588893890381, 79.47139799594879, 80.34989565610886, 73.56766998767853, 73.7629947066307, 72.91732728481293, 72.305468916893, 68.71498078107834, 65.07200226187706, 63.581536039710045, 62.58890390396118, 59.1768541932106, 57.07575313746929, 57.56730996072292, 57.42472641170025, 56.0746056586504, 59.24826376140118, 56.90281301736832, 54.793238416314125, 57.69135810434818, 55.18162317574024, 55.24420581758022, 63.066329285502434, 71.8424865603447, 69.87339422106743, 70.55918142199516, 68.3159489929676, 69.10735532641411, 66.4548772573471, 67.37330317497253, 67.22944289445877, 65.87953492999077, 65.67520469427109, 55.49729883670807, 50.77889442443848, 55.445192232728004, 54.69980902969837, 52.43692025542259, 53.72242167592049, 53.97272564470768, 52.699239179492, 53.37246045470238, 53.1735373288393, 54.34167444705963, 55.07060073316097, 52.044823095202446, 59.498229548335075, 64.55956175923347, 67.21058070659637, 67.68534243106842, 65.32343477010727, 67.3189128935337, 67.52321273088455, 69.78137835860252, 68.470129519701, 66.7355377972126, 70.93808189034462, 67.47199907898903, 68.06458488106728, 66.56987428665161, 66.98671951889992, 66.99149966239929, 72.46159493923187, 65.22736832499504, 64.1511444747448, 72.47946158051491, 66.9373145699501, 66.7345878481865, 66.84700101613998, 69.06712308526039, 68.66977840662003, 70.49506366252899, 68.43558177351952, 71.30862280726433, 67.09230065345764, 67.2971248626709, 76.1255407333374, 60.95353625714779, 59.094896391034126, 53.868121057748795, 46.64486065506935, 33.02988342940807, 29.482182897627354, 38.05520497262478, 23.61587718129158, 10.869581792503595, 0.2952774352161214, 0.16046924865804613, 0.9925513900816441, 0.5869292712304741, 0.09200862652505748, 0.6960354291368276, 0.1031575993692968, 0.2291815701755695, 0.22913995053386316, 0.4997335094958544, 17.567511834204197, 48.903524056077, 21.519001498818398, 37.10640728473663, 57.114431262016296, 12.272948138415813, 0.5087670497596264, 0.37296681955922395, 0.09686115168733522, 0.12630703335162252, 0.11328024877002463, 0.15326054563047364, 0.06117639073636383, 0.16688904870534316, 0.030161516115185805, 0.0810365000506863, 0.03758409497095272, 0.07459693661076017, 0.05806315544759855, 0.1312076422618702, 0.097287285461789, 0.118327750969911, 0.1836422161431983, 0.17111422901507467, 0.3370874823303893, 0.2127351620583795, 0.0861272397742141, 0.1273640149156563, 0.23123641381971538, 0.17017484817188233, 0.22523263207403943, 0.2373989557963796, 4.6004691906273365, 80.5484502017498, 49.257775247097015, 68.82886067032814, 32.887596264481544, 70.1991355419159, 27.642918191850185, 2.191693657077849, 7.503515789285302, 0.5570941627956927, 0.7935886632185429, 0.45438959263265133, 0.45914883725345135, 0.708810284268111, 0.4501981206703931, 0.4655696317786351, 6.770600192248821, 6.815424961969256, 1.9433893309906125, 62.504483833909035, 88.5419824719429, 78.47823768854141, 81.1554828286171, 80.78875690698624, 78.45651045441628, 84.61475640535355, 88.63169565796852, 95.70744037628174, 87.85462215542793, 87.91068434715271, 86.69175535440445, 88.81008848547935, 89.40736323595047, 81.38567447662354, 85.05598112940788, 86.75781100988388, 85.62160357832909, 80.98061621189117, 79.80650201439857, 84.18864727020264, 79.39976423978806, 81.19499310851097, 79.55630823969841, 82.29757994413376, 80.08508786559105, 78.58763381838799, 81.72672137618065, 80.60680747032166, 79.87892612814903, 83.30729976296425, 83.07416707277298, 77.69471973180771, 76.63098961114883, 76.65938928723335, 75.00011712312698, 72.11066856980324, 68.9587453007698, 67.70485818386078, 65.7334403693676, 64.16997626423836, 60.36335192620754, 63.11894506216049, 61.87610015273094, 60.16315586864948, 61.7545560747385, 59.95272696018219, 57.090161964297295, 60.010879039764404, 57.2578963637352, 56.958008855581284, 67.42349848151207, 73.79666849970818, 69.98842164874077, 74.8235633969307, 71.09176084399223, 72.6844909787178, 70.93184262514114, 68.69998678565025, 72.5844119489193, 70.8999091386795, 67.86716267466545, 59.52669382095337, 55.26557207107544, 60.22514954209328, 57.36788146197796, 54.83316667377949, 58.39812017977238, 56.33565165102482, 57.33692452311516, 58.04506592452526, 57.03514851629734, 57.3957871645689, 59.89062309265137, 55.985584035515785, 63.96756112575531, 68.31749930977821, 69.9845078587532, 71.38581186532974, 67.70045801997185, 71.05312451720238, 73.56770798563957, 74.6810482442379, 71.40414208173752, 72.61240124702454, 73.21941867470741, 70.00938132405281, 71.49255573749542, 69.46480974555016, 69.68279644846916, 68.66475507616997, 76.37356102466583, 68.67370739579201, 67.5433212518692, 76.18388280272484, 69.01846289634705, 67.95113816857338, 70.21599903702736, 73.19959133863449, 71.41101211309433, 73.7957413494587, 70.50236687064171, 73.6636832356453, 68.85166704654694, 69.59657147526741, 76.50311127305031, 62.6042664796114, 62.151023000478745, 55.20447514951229, 51.19681119918823, 43.61101984977722, 40.79704664647579, 46.75991088151932, 33.293631076812744, 12.713395804166794, 0.9117618470918387, 3.8054067408666015, 0.5822361668106169, 0.28800394269637764, 0.1650321952183731, 1.30204145796597, 0.1959292872925289, 0.3501143114408478, 0.47865886066574603, 0.8478381740860641, 24.30595625191927, 57.089690789580345, 32.63445004820824, 43.55788730084896, 61.68435864150524, 14.559332001954317, 0.9314293542411178, 0.7822794606909156, 0.1996334650903009, 0.2097374791628681, 0.2222555660409853, 0.46401177474763244, 0.11103318145615049, 0.27305750409141183, 0.10786094542709179, 0.12055825354764238, 0.11581470535020344, 0.2112653831136413, 0.09114529355429113], [0.03522061808325816, 0.05641501244099345, 0.06310742188361473, 0.03313473782327492, 0.018623349897097796, 0.1590237527852878, 0.04107508713786956, 0.016350826917914674, 0.04893702112894971, 0.04683469487645198, 0.07874035451095551, 0.043740933542721905, 0.19944335654145107, 9.390140678733587, 63.67907300591469, 30.669581182301044, 45.65469838678837, 27.53737885504961, 62.95263558626175, 6.918507730588317, 0.5985212617088109, 0.7243282359559089, 0.14135066361632198, 0.09225917558069341, 0.18989622039953247, 0.24837037723045796, 0.3757563151884824, 0.4127133102156222, 0.1746064642793499, 0.9041129169054329, 0.12280598137294874, 31.713103987276554, 69.52604725956917, 60.314535945653915, 65.34625634551048, 62.90345102548599, 66.60070583224297, 62.160841673612595, 69.65500473976135, 77.2347392141819, 81.07388600707054, 80.16183614730835, 81.90123841166496, 77.67162457108498, 85.18464222550392, 79.64154526591301, 77.06406757235527, 76.63105800747871, 79.04351055622101, 75.36023139953613, 72.83209025859833, 79.33481812477112, 74.7897832095623, 70.89566096663475, 72.59863078594208, 75.12963697314262, 74.72793772816658, 73.08061972260475, 72.2341239452362, 75.18795624375343, 74.96775045990944, 73.38252112269402, 74.52735409140587, 70.450818836689, 70.93288376927376, 68.2274517416954, 69.49038997292519, 66.05605825781822, 62.962826639413834, 59.35347631573677, 58.2649677246809, 60.764089822769165, 54.16444435715675, 52.69111521542072, 53.67285333573818, 54.97247859835625, 53.11377793550491, 53.205140233039856, 52.409174144268036, 51.967611238360405, 53.4317334741354, 52.31532298028469, 51.97731211781502, 59.28608313202858, 65.30379742383957, 65.41294276714325, 65.5049130320549, 65.43517157435417, 66.169064193964, 61.24121502041817, 62.025937512516975, 64.11110982298851, 63.449246138334274, 59.04374733567238, 52.15179115533829, 49.05174270272255, 52.24279247224331, 48.6568108946085, 48.912605568766594, 49.81442637741566, 49.49517510831356, 50.08607380092144, 48.1850054115057, 48.14526714384556, 51.9942782074213, 51.29273325204849, 49.997428357601166, 50.543014481663704, 55.724948421120644, 60.79469338059425, 62.05242209136486, 64.99587714672089, 64.9615877866745, 64.5663633942604, 64.39813122153282, 66.15347743034363, 63.04131522774696, 66.6138607263565, 65.40437042713165, 63.10966216027737, 64.79905530810356, 61.171196177601814, 65.99265486001968, 65.92917546629906, 72.26675659418106, 64.27016168832779, 68.2639829814434, 70.00401601195335, 66.49435713887215, 60.752831026911736, 64.45518895983696, 65.86769476532936, 68.30695107579231, 65.4158990085125, 69.59761261940002, 67.22935929894447, 67.44400978088379, 72.089883685112, 57.92191833257675, 52.647273167967796, 47.196180671453476, 37.370580509305, 31.636160016059875, 19.410996213555336, 27.27901551872492, 22.03995354473591, 19.782773964107037, 3.4262474114075303, 3.895098315551877, 1.6932409163564444, 0.12348640462732874, 0.2027084055589512, 0.104123615892604, 0.07751441560685635, 0.05400939269748051, 0.3129583317786455, 0.32960396201815456, 6.566407699137926, 41.526592299342155, 34.33870039880276, 30.872788578271866, 40.77855683863163, 14.751350898295641, 0.4643534595379606, 0.2629196777706966, 0.14860650786431506, 0.09222674372722395, 0.04230746788380202, 0.09529550210572779, 0.06468732812209055, 0.05476234233356081, 0.13137887057382613, 0.057536701860954054, 0.03320196898130234, 0.04409407338243909, 0.014766458516533021, 0.03609114988648798, 0.03658227724372409, 0.05449529904581141, 0.068598913931055, 0.01338622339972062, 0.09662457727245055, 0.0596689255326055, 0.04177794180577621, 0.042089172566193156, 0.07956612738780677, 0.10688076130463742, 0.14243486715713516, 0.28284848027396947, 12.816839553415775, 71.54506891965866, 42.83419333398342, 46.49519808590412, 27.974948175251484, 74.20076921582222, 8.155064452439547, 0.24847821128787473, 1.025945779401809, 0.0512597689521499, 0.10532992499065585, 0.21414767688838765, 0.32758502347860485, 0.3695021179737523, 0.8542733662761748, 0.7042079593520612, 2.0433674287050962, 0.27123778767418116, 39.36975583434105, 80.38426101207733, 68.6092172563076, 72.3345297574997, 70.62002375721931, 73.8002023100853, 68.85805830359459, 77.61686190962791, 81.74582675099373, 84.31173786520958, 82.34868720173836, 81.40606418251991, 79.97152715921402, 88.63380834460258, 81.41402095556259, 80.41866436600685, 80.62045633792877, 83.05684000253677, 77.55898341536522, 76.00906938314438, 81.59037709236145, 77.87895664572716, 71.86759561300278, 75.22296756505966, 78.9336508512497, 76.39169365167618, 75.40073722600937, 77.10093319416046, 78.73790055513382, 78.75500723719597, 76.1726962029934, 77.94566586613655, 74.5143511891365, 72.93631106615067, 72.45293140411377, 71.346415579319, 69.38405647873878, 66.51141822338104, 62.90159672498703, 62.377072870731354, 60.47760419547558, 56.46870531141758, 57.7026093006134, 55.93788139522076, 55.94315551221371, 57.538268119096756, 56.00760765373707, 57.32650928199291, 55.925326868891716, 57.42006406188011, 56.758105382323265, 55.67615903913975, 60.89169077575207, 68.0724960565567, 67.75286480784416, 67.62491047382355, 67.10867017507553, 68.65650951862335, 66.21226787567139, 64.75196063518524, 65.79455628991127, 65.37677630782127, 62.26178325712681, 56.52636721730232, 51.84961996972561, 56.43044136464596, 50.21343536674976, 51.428910344839096, 52.084774151444435, 52.11739920079708, 53.00747483968735, 50.02144306898117, 50.98716504871845, 54.58820901811123, 54.195633083581924, 52.43759661912918, 53.03578332066536, 57.35821098089218, 61.120191514492035, 64.90605756640434, 66.66849419474602, 67.5590144097805, 66.52214124798775, 67.54648268222809, 68.3822250366211, 64.46293294429779, 68.56915220618248, 67.93673694133759, 66.79947316646576, 67.4711175262928, 62.73933403193951, 69.93826434016228, 69.0956899523735, 72.89681598544121, 66.03911116719246, 67.07102179527283, 71.87360689043999, 69.72825720906258, 63.27455811202526, 66.5362536907196, 69.78377223014832, 69.83424872159958, 68.10819134116173, 72.02057540416718, 69.78039041161537, 67.91069313883781, 76.53367683291435, 62.20153748989105, 58.92290621995926, 55.834059566259384, 44.428838565945625, 31.610376499593258, 19.602257050573826, 38.524589985609055, 30.29917135834694, 27.168905027210712, 6.257325634360313, 0.6565628503449261, 0.10405795066617429, 0.35388655902352184, 0.18169758142903447, 0.06819888891186565, 0.177250231790822, 0.048788932981551625, 0.2924871677532792, 0.286306829075329, 6.612070323899388, 47.15185604989529, 32.781452760100365, 37.34621241688728, 50.80299653112888, 17.643471658229828, 0.3559736267197877, 0.21820781839778647, 0.058419738852535374, 0.10938104198430665, 0.08187148298020475, 0.15105102356756106, 0.028547947913466487, 0.11872191302245483, 0.08843903720844537, 0.0454313047521282, 0.07211094969534315, 0.022785738947277423, 0.16027479112381116, 0.11631768109509721, 0.1463389498530887, 0.16671526740537956, 0.22370840917574242, 0.1157391769811511, 0.4309100587852299, 0.21433208574308082, 0.1369344990234822, 0.1401118707144633, 0.17376644216710702, 0.27311821177136153, 0.362919713370502, 0.35057358210906386, 15.229499191045761, 86.61673218011856, 44.38800975680351, 67.31469511985779, 45.80807335674763, 84.07761722803116, 11.369742304086685, 1.066517864819616, 2.279765806160867, 0.282032088143751, 0.25327523122541606, 0.2865971572464332, 0.5631904012989253, 0.8236380445305258, 1.2566891103051603, 0.8452587062492967, 4.281838713213801, 0.6004422367550433, 42.32126645743847, 94.04066741466522, 76.6954493522644, 82.16651737689972, 76.92416667938232, 76.99642360210419, 75.27260810136795, 83.71342957019806, 87.1641232073307, 89.27553310990334, 88.10794696211815, 85.9671950340271, 83.3675417304039, 93.08497309684753, 83.52243661880493, 85.42006999254227, 81.85808032751083, 88.0849201977253, 81.25163286924362, 75.82758352160454, 85.1374639570713, 80.77039629220963, 74.11609455943108, 77.75797113776207, 79.65378820896149, 79.44381907582283, 78.38730856776237, 80.11264398694038, 84.14425045251846, 81.5981362760067, 80.8175441622734, 81.95146411657333, 78.10248345136642, 76.98006927967072, 75.7258477807045, 75.23506611585617, 73.2038015127182, 70.28963148593903, 66.19078382849693, 66.04782789945602, 68.90807121992111, 59.90147911012173, 59.22917738556862, 59.36074152588844, 61.94302596151829, 61.270959824323654, 59.043401554226875, 60.99301993846893, 59.910815209150314, 60.311431512236595, 60.031390339136124, 57.55920119583607, 64.32123094797134, 72.30119034647942, 72.66221657395363, 71.32201328873634, 70.74379071593285, 71.38090252876282, 70.51768764853477, 69.7889019548893, 70.79201772809029, 69.10454347729683, 66.62228107452393, 58.86372819542885, 53.98714207112789, 59.20910686254501, 52.521431520581245, 54.83097419142723, 55.416157990694046, 55.36409318447113, 57.216242998838425, 53.13330888748169, 53.83847884833813, 58.25825348496437, 58.674376755952835, 56.78652785718441, 55.820437297225, 64.04442340135574, 66.13986656069756, 69.5487928390503, 70.07204756140709, 72.01711758971214, 71.17347165942192, 73.55070769786835, 72.55958408117294, 68.73558327555656, 72.57903143763542, 71.7878682911396, 69.49986666440964, 69.88084182143211, 65.35274639725685, 73.40070694684982, 74.36368927359581, 78.50596860051155, 67.97409653663635, 71.8242247402668, 74.69169527292252, 72.12359547615051, 66.33937105536461, 69.33009937405586, 72.8578832745552, 71.98437094688416, 69.84494134783745, 76.08996704220772, 72.51304417848587, 71.15403190255165, 79.09346267580986, 62.48443230986595, 62.93017879128456, 59.40986528992653, 49.83065530657768, 48.7943597137928, 33.404680117964745, 46.106266155838966, 39.823003113269806, 35.964887738227844, 6.7819796316325665, 8.43341376632452, 1.9334097602404654, 0.36762020958121866, 0.3387267381185666, 0.19982575555332005, 0.2681112085701898, 0.1147649077756796, 0.45791707991156727, 0.800352122168988, 9.432838037610054, 55.621567368507385, 50.51567114889622, 47.41672083735466, 53.37215267121792, 21.73346009105444, 0.6083368475083262, 0.4762429918628186, 0.19163807068252936, 0.25362487183883786, 0.3041527792811394, 0.32990316627547145, 0.30466569238342345, 0.220714318274986, 0.1860296755330637, 0.08538848371244967, 0.18894123961217701, 0.1081904218881391, 0.2028177832835354], [0.04918924372759648, 0.08261625785962678, 0.027132791037729476, 0.054838019132148474, 0.03294028399977833, 0.11029852947103791, 0.07956826477311552, 0.010386038538854336, 0.1184749930689577, 0.06314753496553749, 0.1382670845487155, 0.18138316314434633, 0.4860859183827415, 24.9109198898077, 54.05859723687172, 47.330655455589294, 38.13333638012409, 27.118992805480957, 60.535448491573334, 0.8629602345172316, 0.046869453362887725, 0.39502686238847673, 0.10685890505556017, 0.05628329607134219, 0.10339149463106878, 0.20277735107811168, 0.07932632463052869, 0.20970923302229494, 1.7629925860092044, 1.0484900884330273, 8.870961237698793, 69.35450926423073, 56.92698732018471, 62.246508076786995, 60.91946728527546, 72.08437398076057, 58.70609365403652, 58.39976169168949, 72.35653057694435, 75.35114988684654, 77.88160130381584, 77.64754146337509, 77.21764773130417, 80.49052610993385, 81.24253615736961, 75.11569172143936, 74.1915813088417, 81.3605198264122, 77.0240481197834, 74.08557459712029, 81.9172203540802, 78.27841401100159, 70.52399531006813, 67.50476852059364, 73.41911315917969, 74.3620477616787, 73.01693513989449, 74.69487950205803, 71.79011017084122, 73.0768047273159, 73.1815043091774, 73.64020049571991, 73.16252812743187, 69.23215582966805, 66.81638225913048, 65.56008607149124, 65.3507325053215, 65.52637428045273, 60.51260031759739, 59.204159528017044, 56.717895939946175, 55.089725106954575, 57.17441484332085, 55.49306206405163, 54.09805431962013, 52.61298380792141, 50.82872115075588, 51.755195036530495, 53.6517720669508, 51.15512743592262, 52.66833543777466, 50.94816394150257, 50.59748835861683, 54.10768300294876, 63.766270726919174, 62.651171162724495, 65.55507034063339, 64.95679244399071, 64.81970340013504, 62.84839577972889, 60.30487306416035, 61.841039434075356, 60.90494066476822, 58.98146867752075, 53.81781555712223, 50.45124560594559, 52.30220228433609, 47.95710124075413, 47.504123747348785, 46.2227451056242, 48.17384161055088, 48.2518096268177, 49.63767506182194, 48.09697173535824, 49.76298473775387, 53.504628762602806, 52.36568167805672, 52.817507833242416, 50.221745520830154, 54.33190517127514, 57.69762396812439, 61.22887708246708, 63.416412100195885, 65.32280400395393, 65.13498768210411, 65.90531274676323, 66.4854048192501, 64.88447472453117, 60.75976565480232, 59.44543518126011, 62.59541675448418, 62.272654473781586, 64.1423973441124, 62.887142300605774, 65.90430960059166, 69.43045198917389, 67.23908677697182, 69.28852200508118, 65.86242824792862, 63.695054948329926, 58.76266121864319, 66.07315734028816, 67.2426737844944, 66.02828934788704, 66.94006562232971, 68.96904274821281, 66.31736263632774, 70.86536899209023, 60.742256194353104, 51.857892125844955, 51.378787234425545, 42.57784768939018, 30.40387474000454, 23.040265068411827, 31.604853495955467, 23.499962501227856, 23.58458586037159, 22.362960912287235, 0.7866533228661865, 3.271362497471273, 2.328036278486252, 0.2459947476745583, 0.3066009463509545, 0.08546229029889219, 0.037522040292969905, 0.05507291258254554, 0.003136811233162007, 1.403970632236451, 39.13148581981659, 29.150686785578728, 24.87367808818817, 44.007076397538185, 20.22157821804285, 0.24239985854364932, 0.1126245093473699, 0.03785894194152206, 0.019745974423130974, 0.025339739986520726, 0.048576745539321564, 0.020564010410453193, 0.09146044656517915, 0.010875969182961853, 0.07072517444612458, 0.016171080606000032, 0.049968962630373426, 0.03000587847054703, 0.03535635689331684, 0.00988361662166426, 0.04782618190802168, 0.06152312213089317, 0.0839447022008244, 0.023821094328013714, 0.08359291678061709, 0.08717885561054572, 0.023115920448617544, 0.009471805369685171, 0.10420474747661501, 0.22593033994780853, 0.4302873375127092, 30.37123829126358, 63.07914599776268, 60.23248694837093, 42.561436370015144, 36.55186124145985, 70.00378802418709, 0.7304266118444502, 0.21992038353346288, 0.3465677361236885, 0.4115799319697544, 0.018121353787137195, 0.41379871603567153, 0.7239871448837221, 0.5076160677708685, 0.5981761333532631, 4.071671040728688, 1.193117571529001, 12.319297101348639, 81.33229494094849, 61.97871744632721, 70.9259757399559, 70.63374102115631, 77.64648512005806, 65.58922290802002, 66.186383664608, 75.74957370758057, 75.66005811095238, 80.0726093351841, 78.36466178297997, 79.00657653808594, 82.49271467328072, 82.0410405099392, 77.71743491292, 78.71909156441689, 84.90342691540718, 77.6584392786026, 77.01476901769638, 82.39386677742004, 75.66686734557152, 72.22788468003273, 71.00107491016388, 77.37739875912666, 77.2084142267704, 75.23546889424324, 77.43070989847183, 75.75518980622292, 77.42619574069977, 76.3770492374897, 75.64667522907257, 75.36248087882996, 72.9875323176384, 70.54525136947632, 68.5772305727005, 68.01563590765, 67.39363208413124, 62.97599293291569, 62.91723668575287, 58.22338655591011, 57.18004234135151, 57.694257348775864, 57.888803109526634, 56.5698216855526, 57.128140926361084, 54.78554002940655, 53.966402783989906, 55.02417102456093, 53.83209519088268, 55.97443163394928, 55.412118807435036, 54.91863548755646, 57.826676443219185, 65.36451056599617, 66.52911767363548, 68.47630798816681, 66.27165868878365, 67.19912812113762, 64.64555874466896, 64.51400980353355, 64.18624699115753, 63.02553087472916, 62.64067232608795, 55.0770527869463, 54.0348257124424, 53.92541818320751, 50.17216198146343, 49.47555296123028, 49.21617887914181, 50.35634569823742, 51.19270741939545, 52.91505239903927, 49.89499345421791, 51.63033753633499, 55.27426980435848, 52.91826702654362, 55.91565638780594, 52.344516813755035, 55.58383919298649, 59.225692972540855, 64.06566426157951, 65.15447303652763, 68.99076998233795, 68.2518008351326, 69.76069986820221, 69.79469284415245, 67.20906838774681, 62.17218406498432, 62.02817939221859, 66.08467072248459, 64.40690115094185, 66.51741430163383, 66.69893056154251, 68.56279894709587, 69.93105992674828, 68.45596387982368, 69.94286209344864, 69.64889466762543, 66.97422578930855, 61.54990665614605, 68.74552354216576, 69.46419417858124, 67.5278028845787, 68.96262869238853, 71.26859575510025, 66.91931873559952, 75.10422393679619, 64.61340487003326, 58.5059317946434, 56.62042357027531, 52.899150252342224, 33.55195261538029, 23.17248087376356, 35.91856822371483, 30.232082158327103, 30.09198557585478, 29.151688031852245, 2.5019671954214573, 0.8924834034405649, 0.9875517489854246, 0.04114476738322992, 0.28270848153624684, 0.022369076832546853, 0.028904425562359393, 0.038186106612556614, 0.07745208262349479, 1.5805544005706906, 41.731933280825615, 33.356289714574814, 26.219005398452282, 52.03058145940304, 26.841146014630795, 0.28050320455804467, 0.13921715231845155, 0.01428421281161718, 0.11665982601698488, 0.062436757871182635, 0.07848861801903695, 0.04874825586739462, 0.023997250500542577, 0.027007844910258427, 0.06864296781714074, 0.02808072884363355, 0.037507008091779426, 0.07956410132464953, 0.18181055114837363, 0.22391187638277188, 0.1685871122754179, 0.23842497495934367, 0.21226217650109902, 0.2972661831881851, 0.22913462191354483, 0.19448635925073177, 0.30539323459379375, 0.1227081217803061, 0.2387532268767245, 0.263798261876218, 0.6252142949961126, 36.34170591831207, 72.89145067334175, 61.48032858967781, 53.963195756077766, 42.35021710395813, 81.33407324552536, 1.3019461068324745, 0.5636479798704386, 0.6105930951889604, 0.5795957241207361, 0.24528685753466561, 0.7668513979297131, 0.30916028714273125, 0.7072077796328813, 0.6794363760855049, 5.619919337332249, 1.7430222826078534, 16.121138446033, 96.32823586463928, 74.20637771487236, 80.35637810826302, 77.91376277804375, 81.79062634706497, 72.2356666624546, 73.87693539261818, 83.48152801394463, 84.38388079404831, 89.23248901963234, 84.2804579436779, 84.63386937975883, 89.27589789032936, 87.31125131249428, 81.94498166441917, 80.95179855823517, 88.67705762386322, 80.97185388207436, 79.1339685022831, 84.86709326505661, 81.60410195589066, 75.87399423122406, 72.59217113256454, 78.41595903038979, 80.68715795874596, 79.95166182518005, 81.44365936517715, 78.60400334000587, 79.46795538067818, 78.96583512425423, 82.06069305539131, 78.51648643612862, 76.0558220744133, 71.94814369082451, 73.18164110183716, 72.96806216239929, 73.84621024131775, 66.67545542120934, 67.03829795122147, 63.592152670025826, 63.41602452099323, 61.39077499508858, 62.65116736292839, 61.69010393321514, 61.160469353199005, 59.13670934736729, 58.873733058571815, 58.556092903018, 58.25084388256073, 60.29221594333649, 60.26611514389515, 57.273661717772484, 61.1870451271534, 70.01041486859322, 72.8235711157322, 72.8199765086174, 70.9517839550972, 72.95665517449379, 69.07053530216217, 68.64830195903778, 69.02402579784393, 67.37209483981133, 65.666214376688, 57.67604112625122, 57.04252012073994, 58.72511923313141, 54.14924517273903, 52.51124806702137, 51.08730487525463, 53.242655619978905, 54.71261814236641, 55.61946228146553, 52.489061057567596, 55.08499816060066, 60.36916561424732, 58.9743060618639, 61.24001428484917, 56.4356242865324, 60.59937246143818, 63.45016568899155, 66.39310777187347, 68.63095209002495, 73.38543176651001, 73.35368067026138, 74.72939684987068, 72.54682436585426, 70.03040939569473, 66.95322811603546, 65.39066836237907, 67.51562833786011, 67.23586454987526, 68.82525846362114, 70.16416981816292, 73.22097659111023, 74.50025394558907, 71.54155030846596, 72.23404794931412, 71.61345764994621, 69.94126617908478, 63.5483980178833, 71.17887496948242, 72.5870718061924, 70.27776092290878, 71.57587006688118, 73.40897530317307, 71.77743405103683, 77.62363314628601, 63.60162936151028, 60.69668523967266, 61.99870437383652, 59.25430163741112, 48.3570221811533, 38.894994109869, 47.61770345270634, 41.720682084560394, 41.65078863501549, 37.41549789905548, 2.6596556464210153, 8.893878757953644, 6.9601283222436905, 0.5804770393297076, 0.5769977322779596, 0.1440136379096657, 0.24555655400035903, 0.16644088056636974, 0.16662932670442387, 2.209169869311154, 56.00911617279053, 38.11183713376522, 35.58237366378307, 59.690161049366, 29.572464153170586, 0.4776604048674926, 0.2358783397357911, 0.20705651520984247, 0.1930522479233332, 0.19364667852642015, 0.17576133512193337, 0.12193638467579149, 0.13567246205639094, 0.1363796545774676, 0.1809529698221013, 0.1352242345456034, 0.21558662701863796, 0.20834614522755146], [0.03740094405657146, 0.03212620365957264, 0.02896715002862038, 0.06365467415889725, 0.025859495690383483, 0.0217797150980914, 0.05068381782621145, 0.08086498972261325, 0.0333437117660651, 0.05846025269420352, 0.04694657734944485, 0.06286725547397509, 0.13626800588099286, 41.351410299539566, 49.86089028418064, 42.24292226135731, 27.989108115434647, 42.46245928108692, 43.048653826117516, 0.4945669148582965, 0.1809141258127056, 0.33581710362341255, 0.08120455197058618, 0.5348351947031915, 0.13345134764676914, 1.2256369390524924, 0.6699343328364193, 1.562279756180942, 2.850537928752601, 0.43080060684587806, 33.058602288365364, 72.36072555184364, 52.06065684556961, 62.53418684005737, 67.60933130979538, 62.38306134939194, 60.753268003463745, 59.529399275779724, 66.37738421559334, 70.2921013534069, 71.70298084616661, 73.60920935869217, 78.8433600962162, 77.28881031274796, 78.71129438281059, 73.78154531121254, 80.51193416118622, 82.21560314297676, 72.19114825129509, 76.74431473016739, 78.30636531114578, 76.76518321037292, 70.83801046013832, 67.89835900068283, 74.98710662126541, 71.10199749469757, 72.72784665226936, 73.59467893838882, 74.54825296998024, 76.2515951693058, 74.05707612633705, 72.4837477505207, 72.48796552419662, 66.0276585817337, 67.8479129076004, 66.88214153051376, 65.83825394511223, 58.96009862422943, 56.11953064799309, 53.6892456561327, 51.48445576429367, 53.39027389883995, 55.321949645876884, 55.276314094662666, 52.9035010188818, 50.95983311533928, 52.7875692397356, 51.709342896938324, 55.117304027080536, 49.66663330793381, 53.534434363245964, 52.58504770696163, 48.132093250751495, 48.61451916396618, 51.95057675242424, 58.12297314405441, 57.591020688414574, 60.156297236680984, 61.65749408304691, 60.927549451589584, 60.72213627398014, 60.64495101571083, 55.10635681450367, 54.983308017253876, 48.73252183198929, 52.719499692320824, 50.30850246548653, 50.0151240080595, 44.19375278055668, 49.51524943113327, 47.402224615216255, 48.75215917825699, 48.71763043105602, 48.929799646139145, 48.44600960612297, 50.40740355849266, 49.351425021886826, 52.73300036787987, 51.39079459011555, 50.08519604802132, 51.46060064435005, 57.18205623328686, 60.51687128841877, 64.83549535274506, 64.93657752871513, 65.51564365625381, 67.30223938822746, 66.40275925397873, 62.66044646501541, 55.578211694955826, 63.189951851964, 63.348376750946045, 63.29030826687813, 64.94179084897041, 65.00555902719498, 67.50963225960732, 70.56738898158073, 70.29721587896347, 67.65424489974976, 66.95785626769066, 61.225502863526344, 62.9306423664093, 66.01964861154556, 67.58486822247505, 65.62370985746384, 69.62028980255127, 67.33215898275375, 70.99168941378593, 61.387153789401054, 53.37395377457142, 51.050640642642975, 48.243621066212654, 36.15661785006523, 23.14636867493391, 36.41114339232445, 25.082974657416344, 24.58880167454481, 25.542364306747913, 14.358869958668947, 0.5647910060361028, 0.7237770280335099, 0.06033715901139658, 0.10757725947769359, 0.012071574656147277, 0.12498224037699401, 0.04876726969087031, 0.045568435089080594, 0.09582141021382995, 22.38186489790678, 32.30525851249695, 30.472138077020645, 48.82300637662411, 20.955556333065033, 0.0817207527870778, 0.03982074624218512, 0.07178620071499608, 0.0446912128245458, 0.03766447327507194, 0.09675365901784971, 0.055353440693579614, 0.04251862374076154, 0.049728302692528814, 0.044766648425138555, 0.04341621053754352, 0.024938625865615904, 0.03723173067555763, 0.025375355653523002, 0.059634942590491846, 0.031118923725443892, 0.0640691042644903, 0.01828772288718028, 0.05359268790925853, 0.04753445478854701, 0.023029718140605837, 0.03273319140134845, 0.07559555568150245, 0.02880938056478044, 0.06627449256484397, 0.0869493983918801, 49.43547271192074, 57.36742168664932, 56.59387059509754, 30.6002140045166, 47.336754128336906, 49.581308886408806, 0.3154284961055964, 0.18614185857586563, 0.2427636890206486, 0.2263380610384047, 0.41013523761648685, 0.28534084965940565, 1.3933108979836106, 0.6505240243859589, 3.3699415577575564, 7.05636290833354, 0.8002264320384711, 40.420794636011124, 78.14094498753548, 62.3413547873497, 70.65464749932289, 71.63255542516708, 66.3547982275486, 65.05469039082527, 69.21379521489143, 69.81499135494232, 75.89329719543457, 75.77353522181511, 76.25478699803352, 79.67682257294655, 79.0200886130333, 81.03999182581902, 79.18224111199379, 83.04445266723633, 82.09555998444557, 73.68003755807877, 76.41635432839394, 78.88188242912292, 76.29778549075127, 70.83092764019966, 71.12221240997314, 78.04334342479706, 74.62510004639626, 75.099086612463, 78.43954056501389, 75.58664605021477, 78.38174566626549, 77.28051915764809, 78.06246399879456, 73.99577021598816, 69.10126805305481, 71.07881873846054, 70.07902398705482, 69.04376953840256, 61.81445986032486, 59.66691769659519, 57.409090250730515, 56.9617972522974, 56.762676537036896, 56.427428126335144, 59.08353120088577, 58.211865574121475, 54.67540293931961, 56.08690179884434, 53.858097195625305, 57.022666186094284, 52.748655527830124, 58.68954934179783, 56.34355142712593, 51.58665508031845, 51.498651802539825, 53.29413905739784, 61.559884920716286, 60.491177067160606, 61.00010275840759, 63.738384023308754, 63.350812420248985, 62.32537284493446, 64.31856349110603, 59.22539658844471, 57.065353095531464, 51.821265891194344, 53.60948033630848, 54.4042456895113, 51.111695766448975, 48.42241667211056, 52.16854065656662, 50.99871262907982, 50.889848470687866, 51.401126235723495, 50.893921852111816, 51.21647134423256, 52.389476001262665, 51.07061617076397, 52.673039585351944, 55.632962957024574, 53.607177659869194, 53.74221481382847, 60.17530381679535, 64.3588337302208, 67.64655411243439, 67.04959854483604, 66.86375811696053, 69.62785139679909, 67.96680092811584, 67.17509061098099, 58.115506544709206, 65.61496272683144, 65.32549425959587, 65.89509129524231, 67.79008761048317, 67.87402510643005, 68.89618545770645, 68.4053809940815, 70.35643190145493, 69.85456243157387, 69.15067300200462, 63.643586710095406, 65.7758840918541, 68.84656772017479, 70.90655118227005, 67.2389803826809, 70.25113195180893, 70.27355074882507, 70.8788126707077, 66.34698584675789, 58.10610204935074, 54.93434004485607, 56.70575939118862, 40.82696624100208, 25.014340840280056, 37.82190129160881, 34.39445100724697, 34.33342628180981, 33.57303008437157, 21.893632896244526, 1.3952421443536878, 0.8915504941251129, 0.3497158968821168, 0.12380198808386922, 0.12379740903270431, 0.08401274972129613, 0.057533128419891, 0.02341292980418075, 0.032248910356429406, 24.09168764948845, 33.19093018770218, 30.029459930956364, 56.01541243493557, 27.188126295804977, 0.10971205469104461, 0.05627360733342357, 0.0444842352590058, 0.03835518640698865, 0.03620032723119948, 0.08208076862501912, 0.009938748917193152, 0.04590822740283329, 0.025566313961462583, 0.11040573270292953, 0.07495615835068747, 0.04969444220478181, 0.038538333610631526, 0.15637342468835413, 0.12301247654249892, 0.15328304754802957, 0.18000839394517243, 0.07619648749823682, 0.1754352799616754, 0.08191537359380163, 0.11733611550880596, 0.14339749206556007, 0.1825086449389346, 0.17773522529751062, 0.17164924327516928, 0.23368949390714988, 58.16829331219196, 67.23000526428223, 57.15847849845886, 45.20598046481609, 63.29759247601032, 58.00200663506985, 0.5203331541270018, 0.6727445789147168, 0.5261300993151963, 0.682565983152017, 0.6340393214486539, 0.8421904302667826, 1.992416912689805, 2.1898167952895164, 5.088552525267005, 10.527404453605413, 1.8081801175139844, 50.60287266969681, 95.50995737314224, 75.0520147383213, 80.68147346377373, 77.08010271191597, 76.45489186048508, 74.09367576241493, 74.20719087123871, 80.65103709697723, 82.79121145606041, 82.61675521731377, 81.98508471250534, 85.69500043988228, 83.67168501019478, 86.04644358158112, 81.97591960430145, 87.28501752018929, 87.4478767812252, 75.28095245361328, 79.08636465668678, 82.86184966564178, 80.70595934987068, 74.0171630680561, 72.5851871073246, 82.5318069756031, 76.8756052851677, 78.8751719892025, 80.02603143453598, 79.36684280633926, 81.36922135949135, 80.71450129151344, 80.1500415802002, 80.32743126153946, 73.27101990580559, 74.17560696601868, 72.61641383171082, 73.56653764843941, 66.907729357481, 64.00625064969063, 61.201818734407425, 56.926231160759926, 59.61512267589569, 60.514029040932655, 63.35309609770775, 63.09382081031799, 57.081680819392204, 60.04365608096123, 57.78007574379444, 61.96560434997082, 54.70200911164284, 60.57924494147301, 58.450743556022644, 52.83534787595272, 53.33739213645458, 57.058099284768105, 65.05396842956543, 65.17745420336723, 65.1137924194336, 66.41405984759331, 67.64052003622055, 66.99911445379257, 66.76060125231743, 61.474321112036705, 63.21753837168217, 54.89652827382088, 56.29602737724781, 58.49047042429447, 55.52625708281994, 50.39312772452831, 55.552699863910675, 52.45721876621246, 55.176957026124, 55.494483187794685, 54.7238427400589, 53.893401101231575, 56.48692913353443, 54.32413838803768, 58.55825498700142, 60.394422858953476, 56.690548807382584, 56.965513452887535, 64.22610685229301, 67.27962300181389, 72.14083135128021, 70.59478551149368, 70.56159809231758, 74.72351476550102, 71.99240371584892, 70.40835231542587, 62.56927415728569, 71.10309183597565, 68.72882723808289, 70.07487460970879, 71.51209428906441, 71.79387956857681, 73.29458624124527, 76.3243992626667, 75.3583163022995, 73.64792168140411, 70.27202323079109, 66.18696883320808, 68.21613594889641, 72.33424097299576, 72.44555220007896, 69.855185598135, 73.07340011000633, 72.0152784883976, 75.59272572398186, 68.08757364749908, 60.15222765505314, 58.17379541695118, 63.49592283368111, 56.13667532801628, 42.39508889615536, 49.9447213858366, 45.51261641085148, 43.49471189081669, 46.847306191921234, 26.384913995862007, 2.5573962461203337, 3.4593170369043946, 0.5969767633359879, 0.243804506608285, 0.29602917144075036, 0.19451797474175692, 0.1115545401989948, 0.17795092309825122, 0.1697982379118912, 32.80345357954502, 43.87016974389553, 45.07253922522068, 65.5204389989376, 31.003982238471508, 0.24030769971432164, 0.16166149405762553, 0.19724861806025729, 0.16452569427201524, 0.17753765074303374, 0.1651692550512962, 0.11235003345063888, 0.17291641590418294, 0.13473676226567477, 0.16147068788995966, 0.2759564813459292, 0.2152614327496849, 0.20749525807332247], [0.01659528108575614, 0.05215941149799619, 0.05296677540172823, 0.04157135757850483, 0.010775709670269862, 0.13113654451444745, 0.07630463325767778, 0.015648146654712036, 0.03571386056137271, 0.01376035488647176, 0.10768077423563227, 0.10369711846578866, 0.9603735292330384, 53.79348926246166, 41.83720663189888, 49.661674574017525, 22.96151239424944, 56.535460129380226, 28.693368025124073, 0.6078482768498361, 0.10771729532280006, 0.289812705013901, 0.07232044314150698, 0.25429274537600577, 0.3966342058265582, 3.7335604336112738, 0.6295652396511286, 0.2744591241935268, 0.8814463019371033, 1.0335076111368835, 41.9676498323679, 70.63212990760803, 70.5322028696537, 62.28015527129173, 62.3272917419672, 55.537641271948814, 49.951705411076546, 61.135926470160484, 63.57436582446098, 65.46764463186264, 70.99278375506401, 71.12507745623589, 75.55626288056374, 79.32439148426056, 77.6949705183506, 73.03449019789696, 78.6199700832367, 75.52686005830765, 74.34634700417519, 76.72621250152588, 78.86721521615982, 68.25037971138954, 72.44745209813118, 71.18718132376671, 74.01214733719826, 73.36044430732727, 72.25806266069412, 75.44739112257957, 73.73304471373558, 75.65779343247414, 73.38872238993645, 73.87494429945946, 70.7897986471653, 66.81027978658676, 64.54040318727493, 63.64171341061592, 57.08572760224342, 55.97941316664219, 53.792204931378365, 53.54133099317551, 56.96352235972881, 54.00848552584648, 54.41396176815033, 55.082239508628845, 52.311914563179016, 51.14967852830887, 54.32911232113838, 51.916348189115524, 51.13676682114601, 52.757060676813126, 51.26703143119812, 47.913794964551926, 48.79940964281559, 47.168233171105385, 45.48199005424976, 51.28685496747494, 57.0007261633873, 59.32495504617691, 62.40077219903469, 58.95306520164013, 56.04316994547844, 56.79575376212597, 48.45738239586353, 43.82039621472359, 50.1321767270565, 48.49104478955269, 48.0836496502161, 47.17170998454094, 47.589258179068565, 48.86114493012428, 47.20962435007095, 47.64618292450905, 48.75717490911484, 47.128848284482956, 48.17872054874897, 50.15885889530182, 51.296259462833405, 50.705831944942474, 49.27777737379074, 49.7058130055666, 49.50073041021824, 53.17063428461552, 56.98836922645569, 59.419816955924034, 66.25581353902817, 63.91557991504669, 66.68328300118446, 64.67247650027275, 67.72645622491837, 60.34721799194813, 55.66203899681568, 61.65316231548786, 60.80625995993614, 63.75212028622627, 61.65773347020149, 66.76505461335182, 65.34931898117065, 68.72193440794945, 70.43232142925262, 68.73239144682884, 66.30353897809982, 63.57054702937603, 64.44942086935043, 65.76845929026604, 68.84776085615158, 68.62548798322678, 70.25281146168709, 68.88949781656265, 63.57312709093094, 53.816155046224594, 55.503340512514114, 50.07505439221859, 46.85707546770573, 29.92790848016739, 38.08234691619873, 33.39081086218357, 26.70074164867401, 14.162116516381502, 21.186625733971596, 6.928883548825979, 0.5006984795909375, 0.17995921924011782, 0.1146400636935141, 0.07177905383286998, 0.08631252436316572, 0.05412591730419081, 0.027837723719130736, 0.11355946699040942, 7.058819951489568, 46.45266316831112, 20.069352686405182, 35.525125935673714, 27.289613150060177, 0.10405163498944603, 0.005598566795015358, 0.06171125285618473, 0.018921544833574444, 0.09927073449944146, 0.0739634467754513, 0.05320476360793691, 0.0678214622894302, 0.03230091264413204, 0.05181162625376601, 0.07689596168347634, 0.13215857092291117, 0.028667784354183823, 0.0358369383320678, 0.08812320142169483, 0.0484553004935151, 0.030070823813730385, 0.04530297257588245, 0.0947346759494394, 0.07395092674414627, 0.08496175621985458, 0.13433923828415573, 0.044143641425762326, 0.08991877577500418, 0.06537539549754001, 1.2217940390110016, 62.84837298095226, 51.45855255424976, 53.96554782986641, 24.853434674441814, 63.27598683536053, 34.38945047557354, 0.6062856107018888, 0.1807666165404953, 0.26557261822745204, 0.178232271282468, 0.6186883826740086, 0.07724000650341623, 2.99518215470016, 1.021165398415178, 1.5703052817843854, 0.9829770913347602, 1.4928478631190956, 53.650852516293526, 74.37377393245697, 67.58217796683311, 65.01108393073082, 68.61484855413437, 60.64206697046757, 57.9634615033865, 64.99339208006859, 68.09982419013977, 71.26608029007912, 76.48173362016678, 75.67414775490761, 80.52386552095413, 81.52665451169014, 82.01314240694046, 77.30441987514496, 83.22498098015785, 74.07685026526451, 74.54946130514145, 78.42494934797287, 78.86551290750504, 68.75562340021133, 73.8615158200264, 74.28499549627304, 76.12460598349571, 78.5912436246872, 77.20182538032532, 78.11591193079948, 76.53014302253723, 76.07406109571457, 74.19785857200623, 74.93712410330772, 72.91217476129532, 69.33263003826141, 69.24359321594238, 66.60544037818909, 61.3029845058918, 58.50733391940594, 54.5150363445282, 58.48407156765461, 59.37585711479187, 57.50873610377312, 57.6822803914547, 54.41730558872223, 55.0546719878912, 54.829545468091965, 56.85140177607536, 56.97475075721741, 53.63399662077427, 55.99868193268776, 56.238354071974754, 53.26066665351391, 52.50351548194885, 52.48624920845032, 49.49715860188007, 53.640577867627144, 60.277936309576035, 63.61299455165863, 66.15462496876717, 62.85782307386398, 60.57767942547798, 58.70090313255787, 49.954756647348404, 46.0700199007988, 52.63748489320278, 52.46178612112999, 52.87338383495808, 49.93475832045078, 49.72801521420479, 52.03820005059242, 51.51071235537529, 51.88587762415409, 51.68484181165695, 50.01354329288006, 51.96689687669277, 50.81610582768917, 52.10225321352482, 52.4991001188755, 51.51794716715813, 52.21617490053177, 52.457982525229454, 57.32300966978073, 58.715049773454666, 61.6957276314497, 67.7276873588562, 64.31680798530579, 67.93205559253693, 64.72539246082306, 67.54509195685387, 64.63449373841286, 58.198212906718254, 65.70691779255867, 63.96727994084358, 66.21640205383301, 64.72052872180939, 66.6560460627079, 65.31993135809898, 66.85450941324234, 69.42213043570518, 70.53316801786423, 68.57387155294418, 63.76558676362038, 65.85200160741806, 67.83788904547691, 69.42380994558334, 69.39632222056389, 72.08248928189278, 68.63870367407799, 67.27864265441895, 58.352378234267235, 61.17839299142361, 56.000418439507484, 53.60436201095581, 38.48185747861862, 39.31932874023914, 39.90712679922581, 38.76034453511238, 25.343625470995903, 31.002891696989536, 10.860128849744797, 0.4572880355408415, 0.8169452974107116, 0.24391529441345483, 0.19442951073870063, 0.10938605148112401, 0.028418329966370948, 0.0518808129709214, 0.030053990049054846, 8.401675019413233, 47.70029202103615, 22.90335461497307, 42.04857029020786, 34.581469371914864, 0.03236173164623324, 0.03229778078093659, 0.09793486126000062, 0.057494518187013455, 0.13192583341151476, 0.03169458912452683, 0.038788608071627095, 0.059593812766252086, 0.06555795640451834, 0.0704690815473441, 0.03835233655991033, 0.032532993354834616, 0.06291829296969809, 0.10319461027393118, 0.21662296203430742, 0.11002101076883264, 0.13542323402361944, 0.25601678411476314, 0.3989024762995541, 0.1832640919019468, 0.21633037773426622, 0.3263804881135002, 0.17561712098540738, 0.22659993526758626, 0.15612563642207533, 1.7625619028694928, 75.02184435725212, 56.89610257744789, 62.40971311926842, 37.445162907242775, 75.22625058889389, 41.69685356318951, 0.9270486643072218, 0.6745973357465118, 0.4518937203101814, 0.47362855402752757, 0.4923390469048172, 1.0433272342197597, 11.091467086225748, 1.1922699795104563, 1.8211711454205215, 1.982611776329577, 2.84135524649173, 72.43660748004913, 91.38529390096664, 77.49378651380539, 75.72742849588394, 76.56402960419655, 67.11347311735153, 66.1576496064663, 75.65710946917534, 76.29861384630203, 79.85628694295883, 83.18667143583298, 79.39795553684235, 84.30330231785774, 87.71538242697716, 89.32048469781876, 79.71685722470284, 85.20798817276955, 74.93626534938812, 76.40601888298988, 80.86669072508812, 82.92723655700684, 71.05152100324631, 78.09321954846382, 77.90971219539642, 80.22037580609322, 81.30761906504631, 78.23192730545998, 83.42158243060112, 78.80156233906746, 81.35478973388672, 79.55442354083061, 79.69759225845337, 77.89414823055267, 72.65763401985168, 71.3994151353836, 71.03544786572456, 63.70099402964115, 60.958445593714714, 59.03751187026501, 59.36350017786026, 63.60762543976307, 61.01075358688831, 60.65663918852806, 60.5817262083292, 60.37190906703472, 57.86505438387394, 60.0679025799036, 59.768596440553665, 57.19714902341366, 60.57336285710335, 59.07913863658905, 55.17175890505314, 53.58091726899147, 54.46440786123276, 50.99678613245487, 57.55662873387337, 64.0265491604805, 67.21571803092957, 68.06498005986214, 68.62237975001335, 63.09524953365326, 63.480579257011414, 54.27252575755119, 49.17087011039257, 55.493050664663315, 54.769493490457535, 55.68189673125744, 51.588733568787575, 52.861102893948555, 56.074655055999756, 53.50761540234089, 54.3754356354475, 54.41790595650673, 52.85948038101196, 54.76230047643185, 54.25278201699257, 57.27768950164318, 56.293895691633224, 55.28717391192913, 57.3028327524662, 55.22901803255081, 60.226939246058464, 63.0982855707407, 65.71137115359306, 74.88099351525307, 67.89993971586227, 73.31024140119553, 69.87061277031898, 75.15871301293373, 66.33929505944252, 61.33127398788929, 67.57386401295662, 66.54110983014107, 69.96596485376358, 68.3452682197094, 70.38340285420418, 69.90531250834465, 73.72564271092415, 73.6734639108181, 73.75173211097717, 74.1107140481472, 68.65426003932953, 69.71304282546043, 69.92229759693146, 72.0700791478157, 73.07126462459564, 75.40478020906448, 71.6543510556221, 69.6992951631546, 60.840142741799355, 63.345564901828766, 61.96331687271595, 62.66217537224293, 52.81212352216244, 52.0453854650259, 48.62741947174072, 45.20056955516338, 34.039964228868484, 45.596770495176315, 10.340595077723265, 0.7342742616310716, 0.6614314578473568, 0.13335734722204506, 0.2882105566095561, 0.3357780072838068, 0.28129667916800827, 0.12332153652096167, 0.16113860649056733, 11.88319070264697, 60.736168920993805, 32.08019658923149, 48.96276667714119, 37.27809727191925, 0.4149062081705779, 0.27817933238111436, 0.2226978712133132, 0.1482059559202753, 0.21537046908633783, 0.19950847257860005, 0.1527759083546698, 0.2169869260978885, 0.07282830963958986, 0.22499716345919296, 0.24823457904858515, 0.2681291091721505, 0.19440409960225224], [0.02919635306170676, 0.037936715307296254, 0.017467868638050277, 0.06840752888820134, 0.05847194894158747, 0.07886314284405671, 0.02115488056006143, 0.09237783015123568, 0.08203414690797217, 0.039664538999204524, 0.01127712412198889, 0.21990837558405474, 3.2374022947624326, 60.428526028990746, 36.43223986029625, 45.08029840886593, 34.09587062895298, 61.07804797589779, 17.051419727504253, 0.7386810751631856, 0.14661182271083817, 0.36099945078603923, 0.18323139287531376, 0.2765933924820274, 0.9704623441211879, 1.2530914158560336, 0.4035988461691886, 0.6081764842383564, 0.149193947436288, 4.739586375653744, 29.21879433095455, 52.590667605400085, 81.96701288223267, 66.58499747514725, 58.44605080783367, 59.652736857533455, 43.53731520473957, 39.747364372015, 62.902930453419685, 64.22907069325447, 70.39626136422157, 69.96270462870598, 75.537279099226, 75.65566554665565, 74.9595732986927, 74.82404977083206, 82.1327143907547, 73.89428526163101, 71.73663184046745, 76.93121150135994, 73.06418940424919, 65.20852893590927, 74.09036234021187, 68.08867558836937, 74.07271608710289, 70.30239880084991, 71.06624901294708, 74.03530329465866, 71.85155287384987, 76.4846670627594, 73.0994363129139, 71.45518854260445, 69.13089886307716, 66.289973706007, 65.3812600672245, 59.945176765322685, 57.90971718728542, 54.2034986615181, 56.06670208275318, 57.54660867154598, 52.82471224665642, 54.33668531477451, 54.16577808558941, 52.616848200559616, 52.94740006327629, 51.868584752082825, 50.737089067697525, 53.68650980293751, 48.35860289633274, 50.7486442476511, 48.604757487773895, 48.98632921278477, 48.094619661569595, 44.07201491296291, 44.60682861506939, 47.36775666475296, 54.331422597169876, 59.12716805934906, 59.14787694811821, 55.26495270431042, 52.915873154997826, 49.060090854763985, 43.84294420480728, 44.12606701254845, 46.73240415751934, 49.29387331008911, 47.7109694480896, 51.6998054087162, 46.705163419246674, 51.13850712776184, 49.17101450264454, 50.097621381282806, 47.937942668795586, 49.55675460398197, 50.04903718829155, 51.34782649576664, 51.413859352469444, 51.053513288497925, 52.51490347087383, 48.28278936445713, 48.033967316150665, 52.09929317235947, 53.47858875989914, 58.338907957077026, 63.451442420482635, 64.59981679916382, 65.11899054050446, 64.73414719104767, 64.55999493598938, 62.69781365990639, 56.66043542325497, 59.60714690387249, 63.23033228516579, 62.562822103500366, 64.01513457298279, 66.01079508662224, 66.31966531276703, 66.17144286632538, 69.42161366343498, 71.86463937163353, 71.97091206908226, 67.24530324339867, 65.17195969820023, 69.0294823050499, 66.72040700912476, 68.37777927517891, 69.7086350619793, 67.15938225388527, 63.10553178191185, 51.093532741069794, 57.865943536162376, 55.408414006233215, 54.369067177176476, 49.55710418522358, 47.615719959139824, 44.78020191192627, 30.390315167605877, 18.458394929766655, 22.573539912700653, 17.046145610511303, 1.3016947265714407, 0.20769048744114116, 0.1376142172375694, 0.22418562497477978, 0.176689806394279, 0.10386031673988327, 0.03519530342600774, 0.10860595779377036, 0.6799399084411561, 34.46792386472225, 29.34182032942772, 29.44542557001114, 36.00258931517601, 0.02300970798387425, 0.05427255455288105, 0.033492282309453, 0.08511247899150476, 0.023211035950225778, 0.06915308302268386, 0.0141380273453251, 0.08255060005467385, 0.09297447235439904, 0.1334556075744331, 0.07845778920454904, 0.09397464993526228, 0.12018859721138142, 0.051951086934423074, 0.03783108542847913, 0.01040563773130998, 0.0318934067763621, 0.18589813727885485, 0.1084331635502167, 0.06680814127321355, 0.12003633077256382, 0.05020564465667121, 0.03312139400804881, 0.05830427922774106, 0.06778609895263799, 4.897905355319381, 69.90291103720665, 44.50776793062687, 41.44898146390915, 25.903842709958553, 71.28119587898254, 19.524615816771984, 0.41214651719201356, 0.21551924000959843, 0.14062653528526425, 0.17099974531447515, 0.10223892444628291, 0.35455677774734795, 0.6570548645686358, 1.2228480074554682, 0.8394506585318595, 0.24380919698160142, 6.486162655055523, 36.104587242007256, 66.30638882517815, 85.02381205558777, 67.21961662173271, 66.77779152989388, 63.24698679149151, 52.20524288713932, 47.69130550324917, 68.60902726650238, 70.13077720999718, 75.75914159417152, 76.44207134842873, 81.21664434671402, 81.35833874344826, 78.33944633603096, 80.68147346377373, 82.6485975086689, 75.18648952245712, 76.1808505654335, 77.95792400836945, 74.18330535292625, 69.08581048250198, 72.73571223020554, 72.09174558520317, 74.8884791135788, 75.19869446754456, 73.59736159443855, 75.54869368672371, 74.67220231890678, 78.67595627903938, 75.49759402871132, 73.16030904650688, 69.15321886539459, 70.60665607452393, 67.43919163942337, 62.882365956902504, 61.263098046183586, 55.53276613354683, 59.73763570189476, 59.829009398818016, 55.90788200497627, 56.66350565850735, 56.85857579112053, 55.18806003034115, 54.77774664759636, 55.18575735390186, 54.76398378610611, 57.931953594088554, 52.69355848431587, 52.57943540811539, 53.31450216472149, 55.23922808468342, 54.19682241976261, 49.53466638922691, 50.21545685827732, 54.11030866205692, 56.83841407299042, 62.41402968764305, 63.17626878619194, 58.47790829837322, 56.137708872556686, 51.95870831608772, 46.64755091071129, 49.32294934988022, 51.93334087729454, 53.903048783540726, 51.63105569779873, 51.57931387424469, 50.21147467195988, 54.67349924147129, 51.793595775961876, 52.5315085798502, 48.14217410981655, 51.20223730802536, 52.545989602804184, 51.59893602132797, 52.21323765814304, 54.810132309794426, 54.14025865495205, 52.4563942104578, 52.49058477580547, 55.72770707309246, 57.097005397081375, 59.64015193283558, 64.37540844082832, 65.16693636775017, 67.15204864740372, 66.36297538876534, 62.988228276371956, 65.19653677940369, 64.20603632926941, 62.2551754117012, 66.78300485014915, 65.42938068509102, 65.35136327147484, 69.56453159451485, 65.72550639510155, 65.56754127144814, 67.66672343015671, 70.7918581366539, 72.67924726009369, 67.09524929523468, 65.1458702981472, 70.48980474472046, 68.78897041082382, 69.95195880532265, 69.12781342864037, 67.88534089922905, 67.00938910245895, 55.86913548409939, 60.613397508859634, 62.82687373459339, 59.60909999907017, 56.36578023433685, 48.85951481759548, 51.144119426608086, 41.71848960220814, 29.377439618110657, 33.66319924592972, 23.822120614349842, 1.6832740511745214, 0.3060267021646723, 0.17978287010919303, 0.12049779819790274, 0.12376652084640227, 0.18867719831177965, 0.007455902214132948, 0.026332215929869562, 0.6434971920680255, 34.70650166273117, 28.21318209171295, 33.41374263167381, 45.63828706741333, 0.1267593278316781, 0.07385202814475633, 0.03637068723037373, 0.07237350670038722, 0.03582665216526948, 0.02056999768683454, 0.04065373650519177, 0.03960661437304225, 0.06685580941848457, 0.06694786541629583, 0.03809229914622847, 0.054960258275968954, 0.05889751497306861, 0.13121389114530757, 0.11731805163435638, 0.12404622146277688, 0.14554197230609134, 0.24605542566860095, 0.3029760892968625, 0.15729996637674049, 0.25380361068528146, 0.19055104698054492, 0.11854897034936585, 0.1642481013550423, 0.22513466858072206, 5.532575324177742, 85.89766636490822, 51.00400574505329, 62.04392574727535, 48.829640820622444, 80.6876215338707, 26.868039071559906, 0.5877451587002724, 0.5824181414209306, 0.5832499999087304, 0.6048593216110021, 0.3137852327199653, 2.1697130240499973, 1.681688823737204, 1.587661919184029, 0.766604826785624, 0.914282655576244, 9.235474728047848, 51.024194061756134, 82.37442702054977, 95.4647321999073, 76.3905157148838, 75.89235484600067, 71.40213578939438, 59.30382817983627, 57.1272973716259, 76.6483698785305, 76.20813310146332, 81.69487908482552, 82.60751411318779, 86.97466537356377, 86.75081938505173, 83.595901876688, 83.90948385000229, 85.6902202963829, 77.98639208078384, 79.68032598495483, 80.51866739988327, 76.36416032910347, 69.00280773639679, 76.797314286232, 74.35678124427795, 79.42250221967697, 76.9082835316658, 75.14966189861298, 78.91409710049629, 75.10204285383224, 84.71982076764107, 80.79045921564102, 77.20225095748901, 72.86296740174294, 75.69011449813843, 72.61272042989731, 65.01472413539886, 63.41274529695511, 58.85798290371895, 61.87445104122162, 65.09017288684845, 59.455945417284966, 60.9534602612257, 63.06046240031719, 59.54096965491772, 60.87926544249058, 59.499635472893715, 59.044944271445274, 61.332341730594635, 56.212929636240005, 57.04628571867943, 56.42580181360245, 55.384068712592125, 54.75794591009617, 50.65652199089527, 52.544678673148155, 54.52086143195629, 60.36659695208073, 66.81534111499786, 65.035250633955, 60.3096342086792, 60.32949574291706, 55.35509906709194, 51.22893087565899, 50.54005444049835, 53.220274820923805, 54.360483437776566, 53.60949173569679, 56.09137415885925, 54.28285360336304, 56.65663182735443, 54.71114382147789, 52.24368542432785, 52.254545241594315, 56.28202512860298, 56.761715188622475, 54.738202169537544, 54.74259473383427, 57.834462225437164, 58.99502255022526, 55.15193536877632, 57.216011211276054, 58.60525466501713, 61.01661667227745, 63.94085615873337, 68.27004745602608, 71.7869183421135, 74.08589377999306, 71.42396941781044, 68.57357516884804, 68.56270775198936, 67.80411645770073, 65.75434684753418, 69.40287306904793, 68.8003621995449, 69.41764667630196, 73.89363929629326, 73.82685407996178, 71.66128188371658, 74.16657105088234, 76.75552412867546, 77.22834795713425, 71.38420835137367, 68.49158316850662, 72.73215562105179, 71.1126597225666, 71.63575485348701, 74.6355950832367, 71.51201069355011, 68.83624747395515, 57.443888783454895, 64.12903726100922, 66.18961349129677, 68.30229252576828, 67.77146860957146, 59.32735271751881, 58.06589640676975, 46.815235912799835, 36.50133915245533, 43.76662150025368, 31.844820119440556, 2.558823307044804, 0.44325087626930326, 0.3100781753892079, 0.3580927848815918, 0.25476745271589607, 0.2113604819169268, 0.1588592038024217, 0.313045073999092, 1.3473837124183774, 47.147490084171295, 41.234881952404976, 42.06834442913532, 52.63461984694004, 0.15302334039006382, 0.29100394109264016, 0.14915263949660584, 0.18567740771686658, 0.15050312562379986, 0.20693590136943385, 0.19541643356205896, 0.20819115510676056, 0.1434322542627342, 0.27740553952753544, 0.293399267247878, 0.34094688773620874, 0.3142917633522302], [0.08146699765347876, 0.03266124760557432, 0.12493064627051353, 0.0667939885170199, 0.11207221046788618, 0.25635927042458206, 0.06615133315790445, 0.07370148348854855, 0.11116181791294366, 0.11040038923965767, 0.06274710176512599, 0.1430067661567591, 24.045446030795574, 58.85489746928215, 29.89894263446331, 43.14118646085262, 33.0143004655838, 54.21745151281357, 6.922551188617945, 0.4764057893771678, 0.12399098341120407, 0.3469925414538011, 0.32861191837582737, 0.43488948431331664, 0.2035875091678463, 1.572945190127939, 2.2887855721637607, 2.491744556464255, 2.7527140779420733, 15.856343004852533, 25.357451029121876, 39.720837995409966, 67.01170697808266, 72.4390621483326, 53.25924552977085, 50.15183687210083, 43.395503014326096, 43.91069836914539, 64.29489836096764, 64.63920548558235, 71.52480080723763, 68.32474172115326, 73.90965923666954, 73.49611982703209, 73.01790028810501, 76.73584878444672, 75.89754536747932, 67.64001086354256, 71.34707674384117, 71.29077896475792, 72.25013628602028, 72.23843291401863, 71.01351544260979, 70.82940772175789, 72.3887300491333, 73.17278757691383, 71.25055432319641, 73.56706961989403, 72.14216127991676, 71.40551000833511, 70.60092598199844, 68.8428895175457, 65.61357200145721, 62.94784024357796, 60.13069421052933, 61.73187509179115, 55.962112694978714, 57.02518165111542, 57.645509764552116, 55.088155791163445, 54.15525645017624, 52.87381701171398, 53.49061131477356, 51.9859604537487, 49.529411271214485, 52.209259271621704, 49.39849689602852, 53.20599518716335, 49.99115489423275, 49.361475482583046, 48.79748314619064, 47.51594491302967, 51.84820644557476, 46.68368697166443, 45.79627878963947, 51.293645203113556, 54.4799642264843, 56.69813320040703, 57.82017879188061, 57.966410145163536, 51.904223039746284, 48.83312903344631, 47.20070242881775, 46.51383228600025, 50.9374675154686, 50.32423362135887, 47.3468691855669, 47.12764374911785, 47.43681415915489, 52.87518873810768, 49.196727722883224, 50.42739808559418, 50.0302129983902, 49.90688681602478, 49.249560087919235, 48.04937928915024, 51.55876077711582, 51.78780108690262, 48.908232003450394, 49.638556614518166, 48.572721406817436, 47.42976173758507, 51.081023812294006, 55.04836052656174, 58.133977353572845, 61.41372196376324, 62.81548194587231, 60.42082004249096, 59.67619299888611, 60.374131947755814, 60.713522136211395, 59.60059605538845, 59.111341908574104, 65.39213508367538, 61.28486327826977, 60.74605979025364, 62.71420978009701, 63.177473321557045, 63.18567708134651, 66.74296259880066, 67.05352753400803, 68.31999957561493, 64.44405555725098, 70.85324764251709, 71.49197816848755, 69.06003266572952, 67.23175317049026, 69.41320851445198, 65.02260491251945, 51.63299359381199, 54.852294847369194, 66.49065613746643, 48.78046005964279, 54.6091078966856, 43.286433666944504, 41.73394337296486, 25.948230028152466, 17.165404111146927, 16.863084733486176, 25.97470510751009, 2.0146580692380667, 1.2219936470501125, 0.6445454014465213, 0.2365060630836524, 0.5135708826128393, 0.08025463263038546, 0.061187701066955924, 0.0346512646501651, 0.13235807506134734, 18.587152920663357, 35.487549751996994, 16.44379623234272, 39.93424974381924, 0.4354734061053023, 0.24018637341214344, 0.024082293202809524, 0.11300601036055014, 0.01656429270951776, 0.06470001884736121, 0.10295702653820626, 0.022862901896587573, 0.05480187654029578, 0.09912482084473595, 0.23639462218852714, 0.14171070914017037, 0.047861715938779525, 0.02369802397879539, 0.04325622947362717, 0.08129705325700343, 0.058676132321124896, 0.11377626316971146, 0.16491432732436806, 0.12455595075152814, 0.10242432035738602, 0.22066398581955582, 0.04240809939801693, 0.04102468788914848, 0.1121755174244754, 32.41447985172272, 69.79637235403061, 43.460897505283356, 41.85156986117363, 35.190899670124054, 63.32341209053993, 7.660675831139088, 0.2631383144762367, 0.08241336210630834, 0.1265595862059854, 0.3750232217134908, 0.04991265217540786, 0.11725165910320356, 0.5467262410093099, 2.0868667820468545, 1.5820618509314954, 3.86778371874243, 19.82417844235897, 27.532410621643066, 50.25208689272404, 76.86862125992775, 73.53845715522766, 60.780991315841675, 59.63011287152767, 48.59786465764046, 56.01171903312206, 69.05631646513939, 71.87210977077484, 74.2642030119896, 74.47416454553604, 76.47753104567528, 80.44644847512245, 75.55959910154343, 83.67422327399254, 76.00888699293137, 71.6529755294323, 75.32492369413376, 73.89981776475906, 71.53467267751694, 74.09946665167809, 71.85460790991783, 74.18563842773438, 72.36546009778976, 76.56538233160973, 73.81746858358383, 72.9743242263794, 74.61181595921516, 74.60059136152267, 72.86343857645988, 69.99836191534996, 67.62404412031174, 64.11158859729767, 64.25015196204185, 65.54499328136444, 58.34014669060707, 59.6854493021965, 61.178047209978104, 59.809843227267265, 57.30777628719807, 58.724344074726105, 55.749552100896835, 54.30255554616451, 52.62744963169098, 54.65512342751026, 54.41391997039318, 58.90672288835049, 53.54309409856796, 54.69690978527069, 52.34055742621422, 51.104217767715454, 55.2031984180212, 52.32846647500992, 49.38110142946243, 55.510142147541046, 60.95345266163349, 62.06403426826, 64.03577506542206, 62.1105095744133, 57.05542802810669, 52.12640851736069, 49.62599828839302, 52.05364242196083, 53.81550148129463, 52.306511253118515, 49.91884097456932, 48.17671425640583, 51.6881400346756, 54.09602902829647, 52.42591604590416, 52.90805697441101, 50.471129938960075, 50.00675305724144, 50.16743503510952, 50.6717249751091, 53.43068093061447, 54.29419219493866, 52.15793542563915, 55.4913255572319, 51.820692121982574, 51.71679429709911, 52.24977649748325, 56.608150228857994, 61.70395419001579, 61.8156073987484, 67.33206778764725, 63.23369890451431, 61.68798744678497, 64.90366369485855, 65.65795361995697, 61.653447300195694, 63.78542169928551, 67.99435704946518, 64.88379076123238, 66.89742431044579, 66.28776982426643, 65.6153655052185, 63.927055299282074, 67.06949427723885, 67.82488614320755, 68.09390410780907, 62.409067153930664, 70.17543241381645, 73.25766742229462, 69.93608325719833, 67.21602961421013, 70.75777396559715, 65.5519089102745, 56.33853569626808, 58.27360466122627, 74.15615200996399, 57.24661856889725, 64.95396539568901, 56.25068441033363, 50.966516956686974, 37.208523005247116, 29.303030110895634, 26.564855240285397, 35.30763700604439, 4.098205491900444, 1.268406375311315, 0.6590060004964471, 0.8269837650004774, 0.26815829041879624, 0.1424393942579627, 0.08628690542536788, 0.011589743626245763, 0.06279796856688336, 21.439492665231228, 37.719097808003426, 19.94747992604971, 55.08351244032383, 1.8365080724470317, 0.16375651757698506, 0.05149254357093014, 0.048795990805956535, 0.02468748680257704, 0.03704592658323236, 0.04841739159019198, 0.07598180643981323, 0.08931039279559627, 0.03111173602519557, 0.09588378030457534, 0.04761472548125312, 0.1143448447692208, 0.10161147569306195, 0.0926101669028867, 0.19179200695361942, 0.17621656850678846, 0.1709827352897264, 0.38189147191587836, 0.21211858576862141, 0.16648990684188902, 0.43425447307527065, 0.2656679990468547, 0.14244288235204294, 0.22228544490644708, 36.3507342338562, 82.9712837934494, 42.89812110364437, 64.32389080524445, 52.73936502635479, 72.17733979225159, 12.237743027508259, 0.5808657465968281, 0.36433516710530967, 0.3630612854612991, 0.8971299009863287, 0.5689773126505315, 0.2524287375854328, 2.864835374057293, 11.484191212803125, 5.322040496394038, 5.905925240367651, 31.517262496054173, 39.61638160049915, 68.51392596960068, 88.32765117287636, 81.62174820899963, 71.98436334729195, 68.02015006542206, 57.67291009426117, 63.7106379121542, 74.45626750588417, 76.4813232421875, 81.15384131669998, 77.74289354681969, 81.90011367201805, 85.44887244701385, 78.20679545402527, 83.64868104457855, 80.25369241833687, 74.26632329821587, 77.41515353322029, 75.6358154118061, 75.31783327460289, 75.92999562621117, 72.91967555880547, 77.35457718372345, 75.9352545440197, 78.90083581209183, 75.39658024907112, 77.05648317933083, 78.02084863185883, 78.04854914546013, 77.74563699960709, 75.47523602843285, 71.97353392839432, 68.78828644752502, 66.24466493725777, 68.68066862225533, 61.58599331974983, 61.327572986483574, 63.1752048432827, 61.747853234410286, 59.32977698743343, 60.303482338786125, 59.051384925842285, 59.511726424098015, 55.150369852781296, 58.051354587078094, 58.14935512840748, 61.938340812921524, 56.24848052859306, 57.04512678086758, 54.57122392952442, 54.46088545024395, 58.672241270542145, 51.86592869460583, 49.99918006360531, 56.79541938006878, 60.631970912218094, 62.39089272916317, 65.98052591085434, 64.33600455522537, 60.420010685920715, 52.80572846531868, 53.7957501411438, 53.415196761488914, 54.96983014047146, 56.229333356022835, 52.37393483519554, 51.903580874204636, 53.303247168660164, 57.8571318089962, 56.18670344352722, 56.55556485056877, 54.52949456870556, 53.8940204679966, 52.575969994068146, 52.73501046001911, 58.1810188293457, 59.085214510560036, 55.20312622189522, 58.75427886843681, 55.03208979964256, 52.73307256400585, 57.39761106669903, 60.43053612112999, 65.78093782067299, 67.91079193353653, 72.41896122694016, 69.75256830453873, 67.33113303780556, 69.39442232251167, 70.10381385684013, 65.55191650986671, 64.48750242590904, 70.91557189822197, 68.46794083714485, 68.67605566978455, 74.11338910460472, 70.90569242835045, 69.9279136955738, 74.2807625234127, 74.28739696741104, 73.80485326051712, 70.0454793870449, 78.08929055929184, 77.18761414289474, 76.82873100042343, 71.87150180339813, 75.29054313898087, 67.61408865451813, 59.8683562874794, 63.4760233014822, 74.9429301917553, 62.82666094601154, 70.44242888689041, 61.51609227061272, 55.89753895998001, 40.75236864387989, 36.3087160885334, 37.76646986603737, 50.34753017127514, 5.008995244279504, 4.022471755743027, 1.7349880887195468, 0.604444193886593, 0.8647479198407382, 0.23857448803028092, 0.19567201437894255, 0.146246463409625, 0.3311170527013019, 29.116154238581657, 53.2769525796175, 26.957543268799782, 58.68217773735523, 2.0663046604022384, 0.40716661722399294, 0.11994895030511543, 0.17200255009811372, 0.20849703869316727, 0.14405136869754642, 0.23556546511827037, 0.14808491163421422, 0.24781251966487616, 0.4116040072403848, 0.25286829681135714, 0.15156580688199028, 0.15530715143540874], [0.17180044844280928, 0.060405054391594604, 0.030879219302732963, 0.041734433398232795, 0.05194851539272349, 0.25196246104314923, 0.1625214799423702, 0.29538166243582964, 0.4293505393434316, 0.3482424665708095, 0.5016854766290635, 5.697493124753237, 66.89764469861984, 44.237097054719925, 23.470257595181465, 24.149343855679035, 35.39121352136135, 40.37282980978489, 1.2564986455254257, 0.14639490778790787, 0.13599345576949418, 0.14281000796472654, 0.34671732340939343, 0.2747464837739244, 0.11041882418794557, 0.4390738910296932, 0.11616652045631781, 1.692770691588521, 8.031354490667582, 19.82220444828272, 26.523832641541958, 43.972182869911194, 65.54365575313568, 64.54713642597198, 45.8951722830534, 43.5417153686285, 49.13781188428402, 52.06328250467777, 71.3440977036953, 62.77812235057354, 72.25663393735886, 68.7061956524849, 74.47988703846931, 72.64266282320023, 72.55263805389404, 80.99273756146431, 68.87736886739731, 68.73065873980522, 76.44745945930481, 67.24366173148155, 62.44965277612209, 71.49165898561478, 73.48731189966202, 70.1422829926014, 69.32270497083664, 72.01198786497116, 69.90343540906906, 70.75078994035721, 70.15465512871742, 70.75611725449562, 64.69734236598015, 64.40292656421661, 64.42035242915154, 62.67331637442112, 61.186349764466286, 58.815250396728516, 57.34348677098751, 59.391117095947266, 54.927131831645966, 58.517072796821594, 53.54107640683651, 53.97512711584568, 50.60542233288288, 50.57095818221569, 48.855050057172775, 50.16325905919075, 50.765412747859955, 50.68500146269798, 49.65819776058197, 50.30129425227642, 48.76003995537758, 49.02173951268196, 51.60458631813526, 52.77953267097473, 48.70931267738342, 52.13161803781986, 52.632427364587784, 58.44203822314739, 57.025892212986946, 55.07511869072914, 50.37946745753288, 50.947799161076546, 47.53196105360985, 50.60838237404823, 47.963435500860214, 45.07665440440178, 42.151920944452286, 47.9868346452713, 51.32518731057644, 49.088912308216095, 50.92278890311718, 50.31994745135307, 49.39160406589508, 49.87951688468456, 48.81068363785744, 46.957112699747086, 48.32160808146, 49.070817679166794, 51.2105018645525, 51.4163938164711, 48.70030716061592, 48.76415513455868, 46.499153673648834, 53.525352850556374, 56.23939521610737, 58.916856944561005, 62.39771716296673, 62.82703712582588, 59.330601543188095, 60.65593242645264, 63.88352483510971, 58.494065031409264, 56.328701823949814, 65.16579642891884, 61.31791390478611, 61.2965552508831, 58.73602084815502, 62.71945349872112, 57.07227632403374, 59.7984704375267, 66.85162916779518, 65.91584578156471, 60.6541883200407, 65.54000794887543, 69.36004936695099, 68.17614689469337, 64.43213179707527, 64.94641900062561, 69.34134677052498, 50.50310142338276, 47.681543827056885, 78.53746891021729, 50.2251273393631, 47.532986998558044, 29.772377125918865, 24.588058814406395, 18.25482465326786, 17.652952149510384, 12.486494779586792, 20.41512083262205, 7.113941218703985, 0.19947390333982185, 0.20752535958308727, 0.17301399348070845, 0.04556634965410922, 0.3172236622776836, 0.08819913055049255, 0.06962594241485931, 0.03502914398268331, 5.7871117908507586, 52.860544323921204, 14.680757336318493, 38.235349506139755, 14.665772840380669, 0.9057537757325917, 0.24509191018296406, 0.08721881284145638, 0.18879555602325127, 0.06694142357446253, 0.12207015679450706, 0.06087825146096293, 0.025439234159421176, 0.2943040046375245, 0.3838052926585078, 0.1720313899568282, 0.16970428201602772, 0.0051685539074242115, 0.05424522125395015, 0.05106910379254259, 0.1307680385070853, 0.09972817948437296, 0.10955555058899336, 0.26440809946507215, 0.2328295525512658, 0.3823537705466151, 0.695620538899675, 0.20063793228473514, 9.771600309759378, 76.10501423478127, 59.81203570961952, 39.053703993558884, 20.73693696409464, 40.92447280883789, 46.16018146276474, 2.7268669148907065, 0.1388745175790973, 0.09843294625170529, 0.13737897126702592, 0.4510022228350863, 0.057344403976458125, 0.14214752241969109, 0.3211754799121991, 2.0678447652608156, 1.032475729007274, 11.4066706225276, 25.003773607313633, 28.490671701729298, 52.46709443628788, 74.54474195837975, 66.5206441283226, 55.611045733094215, 55.92147387564182, 55.3235037624836, 58.755464404821396, 72.37364485859871, 70.74973359704018, 74.09871429204941, 75.49666687846184, 78.35922047495842, 78.00326317548752, 75.91529041528702, 79.52483832836151, 69.93543729186058, 72.59852439165115, 77.14054226875305, 70.0017437338829, 64.5706495642662, 70.54431661963463, 75.44874384999275, 72.87175253033638, 71.29301324486732, 72.46330484747887, 73.31809177994728, 71.88086450099945, 71.66021034121513, 72.56348267197609, 71.55656710267067, 66.26856565475464, 67.58059725165367, 67.08033889532089, 63.634900376200676, 59.72243271768093, 62.250186279416084, 62.26728916168213, 60.94229266047478, 60.166252702474594, 59.225290194153786, 57.2024991363287, 52.35036849975586, 53.40108811855316, 53.02150748670101, 52.67153486609459, 55.45438773930073, 54.253078401088715, 54.49769027531147, 52.410158291459084, 50.816778391599655, 50.242849588394165, 53.56176249682903, 54.96999733150005, 50.53224965929985, 55.24443380534649, 54.533085376024246, 59.52039755880833, 60.15780955553055, 56.73690252006054, 52.4533049762249, 51.70308843255043, 48.6224265396595, 52.292490005493164, 51.71355687081814, 48.60032692551613, 45.07612243294716, 50.11652536690235, 55.186118334531784, 50.73060281574726, 53.522506803274155, 51.02267034351826, 50.65942123532295, 51.39595851302147, 49.63483661413193, 48.28391410410404, 50.48222914338112, 52.81675927340984, 53.46273601055145, 54.39411923289299, 53.31200189888477, 52.32361413538456, 49.446644112467766, 53.47291946411133, 60.58085985481739, 62.024239003658295, 64.73874494433403, 64.85518589615822, 63.10482122004032, 63.99609759449959, 67.26383864879608, 63.73298071324825, 61.05869181454182, 67.693040817976, 63.064349591732025, 65.84744185209274, 63.04405868053436, 65.39718881249428, 62.07815431058407, 62.22765348851681, 69.02664005756378, 66.58451110124588, 62.56392024457455, 64.45165514945984, 70.85982128977776, 67.31341078877449, 66.89570680260658, 67.76703044772148, 70.57795241475105, 53.9269533008337, 50.65038152039051, 82.71285206079483, 62.833926156163216, 61.29448816180229, 45.676570013165474, 36.93371035158634, 26.13006167113781, 24.076307974755764, 21.686766296625137, 32.21641167998314, 15.379927419126034, 0.5998049397021532, 0.319624628755264, 0.6108738644979894, 0.20208642643410712, 0.11268485337495804, 0.05062191157776397, 0.0569424716377398, 0.06982880848227069, 6.469727111980319, 57.769462913274765, 18.675811663269997, 51.80640488862991, 25.117360912263393, 0.47725922951940447, 0.15563819382805377, 0.03624209901317954, 0.1958025136264041, 0.009270344744436443, 0.12945078575285152, 0.06879786888021044, 0.08745462284423411, 0.2474821897340007, 0.5002739711198956, 0.19075047690421343, 0.10256068999296986, 0.3128313651541248, 0.19148014165693894, 0.13058245705906302, 0.30105814221315086, 0.21470035426318645, 0.3028037922922522, 0.3595440398203209, 0.39453535282518715, 0.6896846042945981, 1.0014763986691833, 0.41617216367740184, 11.391478087753057, 92.04753756523132, 62.1797950565815, 37.35432118177414, 40.10934814810753, 54.084774032235146, 57.91193246841431, 3.999594608321786, 0.3657638904405758, 0.2403894398594275, 0.41520377970300615, 0.7504321227315813, 0.42107467248570174, 0.3808947082143277, 0.5383478093426675, 7.496929317712784, 3.1057526590302587, 14.290778562426567, 32.97033682465553, 48.02737846970558, 71.93531557917595, 83.85500997304916, 71.29305884242058, 66.1874172091484, 66.6574975848198, 63.43163028359413, 65.0965565443039, 76.92572459578514, 77.81016513705254, 75.73221623897552, 80.27561724185944, 85.01640245318413, 84.48431700468063, 81.44045993685722, 84.32915613055229, 72.14191809296608, 77.57815718650818, 81.5285924077034, 71.47880047559738, 65.53558498620987, 75.94446524977684, 79.79079365730286, 77.47027337551117, 75.36413758993149, 76.61164864897728, 75.34007728099823, 76.33019015192986, 78.32968845963478, 77.30236798524857, 75.51425993442535, 70.87110668420792, 69.45802330970764, 69.67889785766602, 67.67672449350357, 63.30771513283253, 66.01288497447968, 64.50527027249336, 62.90006920695305, 64.68437746167183, 62.693147510290146, 60.39972737431526, 56.251638159155846, 57.74422086775303, 53.76655250787735, 56.24761797487736, 57.081536427140236, 56.664763391017914, 57.628479078412056, 57.13551253080368, 54.016446098685265, 51.987978145480156, 55.91343350708485, 55.56157998740673, 51.41513988375664, 56.20268538594246, 56.97527512907982, 62.869530245661736, 62.427925541996956, 62.101245671510696, 56.73736609518528, 55.88156461715698, 50.078250020742416, 55.399925261735916, 53.09838876128197, 50.54217852652073, 45.7336201518774, 51.073355823755264, 59.191065430641174, 55.42386397719383, 57.38265126943588, 54.36464041471481, 56.564862951636314, 57.35756501555443, 53.96498166024685, 50.48232413828373, 55.05993090569973, 57.53515228629112, 58.23401838541031, 56.92424386739731, 55.918320044875145, 55.25529362261295, 52.46731482446194, 59.140763729810715, 63.82761463522911, 67.58627414703369, 72.60851785540581, 71.61657348275185, 65.28174340724945, 66.83775991201401, 72.07861348986626, 66.72197252511978, 62.668536230921745, 72.56347507238388, 66.49490430951118, 68.79611402750015, 68.5387310385704, 72.91878640651703, 65.83663523197174, 67.0119121670723, 75.7458271086216, 74.64415222406387, 68.35298180580139, 71.35116532444954, 76.79402366280556, 74.69788894057274, 73.75157251954079, 73.01546841859818, 71.63638561964035, 57.58928798139095, 58.551407754421234, 80.39389729499817, 68.71033743023872, 65.94786286354065, 50.159250274300575, 40.20948797464371, 30.614427141845226, 33.83778087794781, 31.367423236370087, 47.36986555159092, 20.952060520648956, 0.539891179651022, 0.7763865706510842, 0.882562967017293, 0.17471046885475516, 1.3237950531765819, 0.19767562014749274, 0.24183886911487207, 0.2382091138861142, 9.742808304727077, 74.80407804250717, 27.484498992562294, 55.760073736310005, 25.497158132493496, 1.2607310246676207, 0.3692666790448129, 0.1609182034735568, 0.328017754945904, 0.12010138743789867, 0.28047497326042503, 0.1999054176849313, 0.1579591419431381, 0.35816866206005216, 0.6191858591046184, 0.32587336376309395, 0.23065479268552735], [0.18963398993946612, 0.03334484725201037, 0.11135268345242366, 0.07317337862332352, 0.2467566216364503, 0.5928513722028583, 1.6104497713968158, 5.140989236533642, 9.67410134151578, 10.131945423781872, 4.7324204351753, 38.04232746362686, 61.450002416968346, 37.28528268635273, 33.417002856731415, 28.124380856752396, 47.43113346397877, 29.77225173264742, 0.020616010842786636, 0.06914497877005488, 0.03427830946748145, 0.2852933818940073, 0.02860988755855942, 0.20295693597290665, 0.24996038409881294, 0.27094947814475745, 0.5781610636040568, 4.334037462249398, 4.30779037065804, 32.32205741107464, 31.256547085940838, 48.34439545869827, 55.9428059309721, 53.117311745882034, 52.059931084513664, 52.89712116122246, 60.22606149315834, 58.976342752575874, 55.906631872057915, 58.47063168883324, 70.00020861625671, 73.24018836021423, 68.95049974322319, 70.68245440721512, 73.28686505556107, 69.03453603386879, 65.3708866238594, 72.23378956317902, 70.45943677425385, 70.04814684391022, 64.89025801420212, 65.90840578079224, 70.71070209145546, 69.55070033669472, 66.23549222946167, 67.3571540415287, 69.12506997585297, 69.21707823872566, 66.16718709468842, 62.75844320654869, 65.82484066486359, 64.34887066483498, 65.10587364435196, 66.20735853910446, 56.85107119381428, 55.82896023988724, 61.42911873757839, 56.934214532375336, 60.69829635322094, 55.99594607949257, 55.3853340446949, 52.812514901161194, 53.46082091331482, 48.256133794784546, 50.50535850226879, 50.92811241745949, 51.07129633426666, 49.453605338931084, 51.00302919745445, 48.55975650250912, 48.46709847450256, 49.34493117034435, 47.91625343263149, 51.24484822154045, 52.543504536151886, 53.40766556560993, 54.20077420771122, 55.14764919877052, 58.83339062333107, 55.48410974442959, 47.87865065038204, 50.783549174666405, 50.51306068897247, 50.77041707932949, 49.26849067211151, 44.601087123155594, 45.256403759121895, 45.19528403878212, 46.175905019044876, 46.5291378647089, 47.983209639787674, 48.02540637552738, 49.235128462314606, 50.373030602931976, 47.81201742589474, 46.34366221725941, 47.38321043550968, 47.77879200875759, 49.77677799761295, 51.20670586824417, 52.18602351844311, 48.04952748119831, 49.056883826851845, 47.24525883793831, 52.56629191339016, 56.15522973239422, 58.53818826377392, 60.83198457956314, 60.76287008821964, 59.345496743917465, 61.430878043174744, 60.164041221141815, 54.51337203383446, 57.15358056128025, 61.47679477930069, 58.61568510532379, 56.01163163781166, 56.677781492471695, 60.62343657016754, 57.71181620657444, 58.37202697992325, 66.40348121523857, 62.14419476687908, 64.09061372280121, 69.00228336453438, 64.34036672115326, 64.37765792012215, 68.2607151567936, 67.2997011244297, 52.33858533203602, 39.459586814045906, 85.0581394135952, 63.31742741167545, 40.33413648605347, 24.619519226253033, 15.275760758668184, 13.66295725107193, 13.559773787856102, 13.5949731990695, 13.167789671570063, 5.0047883950173855, 1.9643943663686514, 0.5164784984663129, 0.31585882301442325, 0.4930133029120043, 0.3041722532361746, 0.12909004261018708, 0.07408044635667466, 0.06740682438248768, 0.8253208792302758, 34.9732131510973, 36.16479501128197, 16.903303675353527, 43.12155671417713, 1.8393013975583017, 0.20797087083337829, 0.07989323639776558, 0.015104932590475073, 0.10387869973783381, 0.036784712865483016, 0.07088351907441393, 0.010404613567516208, 1.2474708049558103, 4.270608415827155, 4.063001805916429, 2.357036559842527, 0.37478718906641006, 0.06426963256672025, 0.048837807116797194, 0.02824302911903942, 0.08229300059610978, 0.44425099447835237, 1.429097258951515, 3.727784981019795, 10.322156567126513, 15.303170587867498, 7.038638284429908, 50.198334977030754, 66.83893784880638, 54.830043241381645, 35.344320237636566, 28.512262143194675, 52.37893536686897, 37.07027122378349, 0.5759741622023284, 0.08431099660811014, 0.0908537779469043, 0.32627551874611527, 0.2629688673187047, 0.24022435653023422, 0.13554789999034256, 0.603262041695416, 1.8098536902107298, 5.417450051754713, 10.223918538540602, 37.32190132141113, 36.80858686566353, 57.78199844062328, 65.91618776321411, 60.157361179590225, 61.470608711242676, 62.21010223031044, 62.87864215672016, 66.10258296132088, 59.46861773729324, 66.17175444960594, 75.50935819745064, 77.44069576263428, 73.1208747625351, 76.16010367870331, 77.60850235819817, 72.4530377984047, 70.2725476026535, 75.04122331738472, 69.72871318459511, 73.06241869926453, 68.22888046503067, 68.14387902617455, 70.71596100926399, 72.200678139925, 70.34519210457802, 70.09645745158195, 72.72391006350517, 73.13570156693459, 70.03796339035034, 67.6914145052433, 68.40973556041718, 67.9167652130127, 69.12757784128189, 68.40588256716728, 59.423548355698586, 60.915656089782715, 65.25808587670326, 59.53827179968357, 64.59828168153763, 57.23749525845051, 58.57121229171753, 54.16080795228481, 55.94854362308979, 51.91885605454445, 53.131067007780075, 54.93386887013912, 55.747458413243294, 52.8535944968462, 53.68261881172657, 50.83480842411518, 48.84898938238621, 49.99712057411671, 49.64895285665989, 53.38854879140854, 54.00594346225262, 55.675342082977295, 60.31877651810646, 59.494935125112534, 63.05809132754803, 60.68473868072033, 53.1299764662981, 50.69435656070709, 52.84265488386154, 54.306606128811836, 50.465992614626884, 46.77050091326237, 48.22448909282684, 49.9476358294487, 48.834709748625755, 50.16771242022514, 51.080670431256294, 50.07184736430645, 50.826528668403625, 51.53097286820412, 49.67261418700218, 49.52178128063679, 51.55064061284065, 49.8557947576046, 51.6255421936512, 51.98907628655434, 54.39941614866257, 52.3536629229784, 51.22256621718407, 50.59297800064087, 54.948919862508774, 61.34928122162819, 61.68066143989563, 63.96115466952324, 62.995824068784714, 63.61042968928814, 64.6187549829483, 63.94277125597, 58.03932063281536, 60.5661166459322, 62.94536277651787, 62.81361624598503, 61.1353413015604, 63.070524260401726, 63.89954477548599, 62.46512174606323, 61.324624344706535, 66.41317829489708, 63.497260361909866, 64.35190290212631, 70.69887712597847, 68.21010947227478, 65.93412280082703, 68.67478653788567, 67.75164127349854, 55.271279364824295, 46.535187140107155, 84.30594697594643, 74.43963959813118, 57.08904102444649, 43.52220341563225, 30.377640947699547, 21.29396427422762, 17.436667755246162, 18.256371170282364, 22.118647322058678, 19.734307564795017, 7.936479281634092, 0.5469801742583513, 0.31928371579851955, 0.5247529107145965, 0.19184118165867403, 0.14834896777756512, 0.052466957495198585, 0.02472421754646348, 0.4770949180237949, 40.66071756184101, 39.924001693725586, 17.07523874938488, 60.99517062306404, 4.242232963442802, 0.216264029731974, 0.08013752172701061, 0.026413154555484653, 0.08663597458507866, 0.0833803360001184, 0.08239781411248259, 0.053497284825425595, 1.363853334914893, 4.244719929993153, 5.0543268118053675, 3.2788143726065755, 0.6703085533808917, 0.15778258501086384, 0.22344983008224517, 0.18270093540195376, 0.28801557957194746, 0.7048117707017809, 2.4059677217155695, 7.387014040723443, 18.15974235534668, 26.108000054955482, 16.017272919416428, 64.08286973834038, 77.60222509503365, 57.36764207482338, 47.71936319768429, 48.18195417523384, 65.49931973218918, 47.049227356910706, 1.2124161422252655, 0.4602374491514638, 0.18713954254053533, 0.6311593728605658, 0.3916002775076777, 0.5166356556583196, 0.37004596379119903, 1.4154860330745578, 4.915103707462549, 9.799519311636686, 15.914309844374657, 56.047566309571266, 54.30516980588436, 72.83323779702187, 72.21438780426979, 69.20804232358932, 72.55899131298065, 72.2791363298893, 69.08709481358528, 71.89905032515526, 69.1570870578289, 76.15225329995155, 78.12268316745758, 81.77006185054779, 78.40067625045776, 84.19039517641068, 80.66939771175385, 77.30357632040977, 70.09068176150322, 79.55556347966194, 75.33715143799782, 75.09721711277962, 69.89745453000069, 70.77922761440277, 76.85210734605789, 76.83391392230988, 73.48662033677101, 73.41459140181541, 76.67653396725655, 77.33286514878273, 73.03698286414146, 68.7669163942337, 73.74782592058182, 69.79428246617317, 71.45309865474701, 71.47125408053398, 62.69891560077667, 62.570007517933846, 68.8680973649025, 64.95629847049713, 68.85434970259666, 61.54022857546806, 61.02495342493057, 58.101150915026665, 59.743624180555344, 56.53489775955677, 58.636466190218925, 61.150050312280655, 60.47837175428867, 54.930209666490555, 55.80437555909157, 56.302015855908394, 51.76298461854458, 55.01886650919914, 52.66464963555336, 54.54461395740509, 56.330837309360504, 57.99586996436119, 62.76918143033981, 60.4952884465456, 61.68642573058605, 61.076132878661156, 54.103689417243004, 52.28844702243805, 54.78934742510319, 55.06897822022438, 55.49664907157421, 51.96708306670189, 49.84290584921837, 50.26193216443062, 52.528385147452354, 53.77385571599007, 54.77350227534771, 54.42883417010307, 54.99882638454437, 56.8644692748785, 53.96796829998493, 50.311451107263565, 55.28024308383465, 54.83714506030083, 57.35367402434349, 57.72428713738918, 57.491523027420044, 54.87258955836296, 54.87615756690502, 54.10075217485428, 57.14117802679539, 66.84706941246986, 66.08713299036026, 68.65884259343147, 65.2528877556324, 63.37985806167126, 65.47574579715729, 67.28239685297012, 61.36049821972847, 61.76263824105263, 67.2084604203701, 66.8438395857811, 62.345766350626945, 65.44644176959991, 65.83175629377365, 66.14602223038673, 66.1933220922947, 74.16812896728516, 70.00859096646309, 71.28903865814209, 76.61926344037056, 70.46721875667572, 70.60693725943565, 75.22276237607002, 71.93829461932182, 58.811955973505974, 57.09174267947674, 85.12098804116249, 76.7526362836361, 61.4719158411026, 48.6208838224411, 36.55870467424393, 28.40602744370699, 25.716641955077648, 28.391635715961456, 34.67720903456211, 40.07413923740387, 9.521705769002438, 0.7633835496380925, 1.4022036083042622, 0.8858715801034123, 0.8347371302079409, 0.44183883641380817, 0.36141858610790223, 0.1350370203726925, 1.5736713074147701, 51.16610884666443, 54.960532039403915, 25.45486830174923, 64.9741119146347, 3.1889933673664927, 0.5157847981899977, 0.26857487275265157, 0.11948236948228441, 0.2793077233945951, 0.11824817047454417, 0.22670321253826842, 0.185904742393177, 1.4072028337977827, 5.137107269838452, 5.901747364550829, 3.3639295678585768], [27.340788803994656, 14.186569154262543, 7.806771341711283, 2.165074422955513, 2.5547772366553545, 14.84005143865943, 19.920678064227104, 20.818841569125652, 10.96263974905014, 7.621954008936882, 13.039783090353012, 56.77068270742893, 48.71830299496651, 37.68144182860851, 38.565004616975784, 22.024809457361698, 48.47762390971184, 14.471545312553644, 0.06065424531698227, 0.04331869233283214, 0.0690324988681823, 0.08507021368131973, 0.2598649979336187, 0.15619743178831413, 0.09006747990497388, 0.07049736479530111, 2.2269716765731573, 6.675670361146331, 2.4584345938637853, 47.380675971508026, 49.12246830761433, 61.08481161296368, 60.526093393564224, 58.30438680946827, 51.47663198411465, 50.543975830078125, 48.6157388985157, 54.95356321334839, 56.16057604551315, 59.146980196237564, 69.66599375009537, 66.86406970024109, 68.88878345489502, 65.70466071367264, 74.79780837893486, 61.6397300362587, 67.27994978427887, 73.521259278059, 65.41836127638817, 69.9621194601059, 67.90384590625763, 69.8569031059742, 68.73685240745544, 67.75005295872688, 68.71388643980026, 68.59788626432419, 67.51648709177971, 68.5976354777813, 66.74524247646332, 63.84390816092491, 65.44686734676361, 64.63312581181526, 66.74639761447906, 61.65570057928562, 55.93473516404629, 61.459425911307335, 56.990991085767746, 58.73237304389477, 60.51876358687878, 55.92014014720917, 55.872270315885544, 49.996098428964615, 51.099433824419975, 48.378741815686226, 49.030969217419624, 49.43414278328419, 51.00404754281044, 50.509899258613586, 48.53213958442211, 48.0350274592638, 46.76670491695404, 46.54069684445858, 46.2134850025177, 49.375101551413536, 53.52085009217262, 54.91136647760868, 58.509560599923134, 58.48910249769688, 60.59387795627117, 60.73407523334026, 54.9550337344408, 52.01001696288586, 52.77586966753006, 49.91191394627094, 42.476130947470665, 42.28975094854832, 45.59935435652733, 43.160516023635864, 45.91631814837456, 47.77765206992626, 49.113584384322166, 45.27742803096771, 46.61799229681492, 46.30659520626068, 46.12368822097778, 46.023890376091, 47.31212764978409, 47.10372023284435, 47.60045237839222, 45.57460628449917, 51.2481464445591, 47.95773200690746, 51.15539342164993, 47.556028962135315, 49.66410644352436, 58.737308979034424, 55.30021861195564, 57.839694544672966, 59.78520914912224, 58.08201514184475, 60.73300749063492, 60.18527448177338, 53.675402998924255, 51.60692699253559, 56.67781949043274, 60.34938387572765, 59.701666831970215, 60.393856689333916, 62.006702944636345, 58.7421765178442, 55.65214432775974, 59.223549887537956, 66.30850911140442, 64.77202355861664, 66.23512744903564, 66.13323211669922, 63.50496634840965, 63.57431262731552, 67.91374057531357, 51.35963246226311, 34.966289922595024, 82.96502932906151, 77.60245308279991, 50.33778369426727, 28.54120709002018, 16.55633669346571, 10.841042473912239, 11.385193224996328, 12.73608723655343, 17.98601757735014, 5.881536724045873, 3.670765715651214, 4.850139068439603, 1.3148142350837588, 0.5583412677515298, 0.09640064905397594, 0.3524207283044234, 0.11803902583778836, 0.0469467443326721, 0.11330001216265373, 14.648533165454865, 43.78762677311897, 17.53286149352789, 29.28773783147335, 38.737013787031174, 0.4882874252507463, 0.043087023514090106, 0.05458724372147117, 0.04518091525824275, 0.04775080567924306, 0.839305731933564, 14.276005905121565, 24.685447588562965, 25.27842476963997, 29.767131507396698, 29.755544029176235, 33.40536028146744, 15.383912455290556, 10.436862912029028, 3.1664446648210287, 1.786250900477171, 15.938290357589722, 32.16737151145935, 42.089775279164314, 33.33735153079033, 21.265277713537216, 22.401076667010784, 70.43947264552116, 58.8509114831686, 52.680483385920525, 34.34136405587196, 27.20555406063795, 53.76863479614258, 17.871096543967724, 0.08316811887198128, 0.025254315078200307, 0.053218114844639786, 0.27570317150093615, 0.4780425218632445, 0.30601735110394657, 0.20635157881770283, 0.3548851632513106, 3.117991089820862, 8.467442840337753, 4.368891566991806, 58.530417680740356, 50.13355225324631, 65.60574442148209, 65.86851552128792, 63.61900582909584, 61.31888285279274, 61.42236270010471, 56.926668137311935, 60.58993376791477, 62.37618371844292, 66.66945174336433, 73.69709104299545, 72.18340426683426, 72.26152047514915, 71.62231877446175, 75.1225009560585, 64.415093511343, 70.38739264011383, 75.75377628207207, 68.14849957823753, 72.11325243115425, 74.18937742710114, 71.71850681304932, 73.62915828824043, 70.75140550732613, 71.12480387091637, 69.98395308852196, 73.18671762943268, 69.58739876747131, 69.85933497548103, 67.08918482065201, 69.5680958032608, 67.08722412586212, 69.85240414738655, 62.99862451851368, 59.949010759592056, 65.78976854681969, 62.812958881258965, 62.06116922199726, 60.91505192220211, 58.27006325125694, 57.19404458999634, 52.667294293642044, 53.46556305885315, 52.1685254573822, 51.217865869402885, 50.92661149799824, 52.77347959578037, 53.43055173754692, 51.09548203647137, 49.231252670288086, 49.87687602639198, 48.13073672354221, 48.70938487350941, 50.61541959643364, 55.64517170190811, 56.18314303457737, 61.735059320926666, 61.79152429103851, 62.986366376280785, 64.37749832868576, 58.67944948375225, 54.05373729765415, 54.89382661879063, 51.421971917152405, 45.162514597177505, 44.231325164437294, 48.78373168408871, 46.727829203009605, 49.33989644050598, 50.97366817295551, 51.89736820757389, 48.79426471889019, 50.43454550206661, 48.96411180496216, 48.83573569357395, 50.17733730375767, 51.95343419909477, 50.53249664604664, 52.67882287502289, 48.55722203850746, 52.02984429895878, 51.33027903735638, 53.859195336699486, 51.638537496328354, 52.691966369748116, 60.59540547430515, 59.46130692958832, 61.734766736626625, 61.79791934788227, 61.5315156430006, 64.82836693525314, 66.28672868013382, 56.62616886198521, 58.7775032222271, 61.61045640707016, 62.079898416996, 64.25758436322212, 61.79981544613838, 66.03507578372955, 63.2514363527298, 59.49985206127167, 61.82346537709236, 65.47608017921448, 65.9774860739708, 67.13017702102661, 70.59962645173073, 66.19592875242233, 65.0753764808178, 67.17301592230797, 54.97218981385231, 42.49756559729576, 83.77157405018806, 82.47484803199768, 70.82952171564102, 45.43010763823986, 34.87620435655117, 20.85247166454792, 16.308747678995132, 17.327026538550854, 23.7806249409914, 15.977107174694538, 10.873034857213497, 16.134990602731705, 1.5125394752249122, 0.8124461607076228, 0.41106422839220613, 0.19539498549420387, 0.23231825733091682, 0.06835018313722685, 0.21408643486211076, 17.47026365250349, 56.43397897481918, 20.77092234045267, 37.04229712486267, 54.09397713840008, 1.3522361707873642, 0.09749648947035894, 0.04093063922482543, 0.17302015330642462, 0.051025294815190136, 1.527182583231479, 18.887627497315407, 33.554642871022224, 35.461688339710236, 42.83389315009117, 41.941321045160294, 42.7205566316843, 22.97036211937666, 15.743670500814915, 5.13721888884902, 3.6239698017016053, 27.461842708289623, 45.550017803907394, 51.505305245518684, 42.59025402367115, 31.27466831356287, 43.62598344683647, 86.17692098021507, 67.07370445132256, 55.61026677489281, 55.46977311372757, 40.28853513300419, 63.54691229760647, 26.56898181885481, 0.32643407117575407, 0.3239095222670585, 0.29712401737924665, 0.5801237770356238, 0.4505401023197919, 0.3492354601621628, 0.3615426138276234, 0.6513843813445419, 4.445576202124357, 11.290172673761845, 3.9160634530708194, 70.2677446603775, 65.78936576843262, 76.18468075990677, 77.5019408762455, 70.12752458453178, 71.21919080615044, 70.65236002206802, 65.78178897500038, 64.92051959037781, 72.82032608985901, 75.06842985749245, 80.07224455475807, 77.34385415911674, 76.05894550681114, 78.52765023708344, 81.82488530874252, 68.31972599029541, 70.38691386580467, 77.00890213251114, 69.66873720288277, 74.78301957249641, 74.98760059475899, 73.4488807618618, 75.00437289476395, 75.34164279699326, 78.02234575152397, 74.95603188872337, 76.34516134858131, 75.49326986074448, 74.74632874131203, 72.04575285315514, 73.87697339057922, 70.9964619576931, 74.74918618798256, 68.53123784065247, 62.02995389699936, 66.09713405370712, 64.47899848222733, 64.52299252152443, 66.14984482526779, 60.34266583621502, 62.02161714434624, 54.997747242450714, 56.14716276526451, 55.18508858978748, 54.65772248804569, 54.997732043266296, 59.17751915752888, 58.62945556640625, 54.18345473706722, 52.51631699502468, 53.10720808804035, 51.85413412749767, 51.78499683737755, 51.2074164301157, 55.94771146774292, 57.96079784631729, 63.00907775759697, 61.72160804271698, 65.77618807554245, 65.6608110666275, 58.83537031710148, 57.0234527438879, 57.851261124014854, 53.08565564453602, 48.348719626665115, 47.86066621541977, 50.40850929915905, 48.10747057199478, 53.47582250833511, 55.30298486351967, 54.952221885323524, 52.11731180548668, 53.98135498166084, 55.28699912130833, 53.190442621707916, 52.32188142836094, 52.486530393362045, 52.96975426375866, 55.74135974049568, 50.192608684301376, 54.84814167022705, 53.8367423415184, 58.115335553884506, 55.91059885919094, 57.16989308595657, 66.54972776770592, 62.27751821279526, 65.22717073559761, 66.64534583687782, 62.65406280755997, 67.43083968758583, 69.90031197667122, 58.955804854631424, 60.37867650389671, 65.46537235379219, 65.60634478926659, 64.8457320034504, 65.42788356542587, 72.60732471942902, 67.04437762498856, 61.556187719106674, 64.39258351922035, 73.1621253490448, 71.0694408416748, 72.02600911259651, 73.31599429249763, 71.2294502556324, 70.67771226167679, 73.33089709281921, 58.559641912579536, 52.885242998600006, 81.84893041849136, 80.21304979920387, 72.05889254808426, 52.30255946516991, 43.0783112347126, 29.444716908037663, 27.120096646249294, 27.546834647655487, 41.547027602791786, 34.999374747276306, 33.940432369709015, 18.544864989817142, 3.45176684204489, 1.8042248860001564, 0.3072206396609545, 0.7630674540996552, 0.29795543057844043, 0.20779156795470044, 0.44398337602615356, 23.659116961061954, 67.842767983675, 35.37095680832863, 42.331054732203484, 60.26066243648529, 1.14654335193336, 0.2962801360990852, 0.10074405348859727, 0.25916316371876746, 0.3029439691454172, 2.0434526866301894, 24.05375998467207, 41.5767952054739, 43.5835625231266, 48.891528099775314, 50.9975840896368], [18.23047176003456, 23.856869749724865, 22.651274241507053, 15.255628488957882, 22.151532657444477, 11.233340073376894, 10.353466887027025, 5.724414205178618, 3.354342682287097, 3.477479349821806, 22.78921253979206, 42.46575370430946, 50.08932642638683, 44.28001955151558, 28.959558941423893, 43.47327344119549, 39.143565371632576, 1.5989976609125733, 0.036799470472033136, 0.04964653657225426, 0.08818383488687687, 0.15402501710923389, 0.818142945645377, 0.10751483001513407, 0.13769364188192412, 0.22359181777574122, 0.8687471458688378, 1.974882516078651, 0.5973150639329106, 24.282308220863342, 70.90791910886765, 65.48535168170929, 56.009233966469765, 51.859700828790665, 53.53668384253979, 53.69278326630592, 49.905511289834976, 52.15307168662548, 48.8933178037405, 58.60102169215679, 66.17690697312355, 65.53028807044029, 67.74284094572067, 65.04180908203125, 64.34912905097008, 55.45348338782787, 68.5516807436943, 71.43218457698822, 69.0220195055008, 70.69534331560135, 70.9150855243206, 68.94088625907898, 70.17897382378578, 66.50254189968109, 65.13484328985214, 67.93698772788048, 68.34601297974586, 67.65928342938423, 66.99368834495544, 63.815227299928665, 64.47394475340843, 65.40148258209229, 63.01116764545441, 57.236875891685486, 59.925144240260124, 61.57433934509754, 60.754202753305435, 58.975913375616074, 55.862504839897156, 57.129197269678116, 51.62684552371502, 51.773365661501884, 50.900009125471115, 48.248321413993835, 48.17210890352726, 47.980526983737946, 50.4396790266037, 50.63311144709587, 50.01385107636452, 48.44151824712753, 44.00061674416065, 44.84990157186985, 43.32257352769375, 47.71712891757488, 52.53213174641132, 54.69081111252308, 61.758340671658516, 62.44062826037407, 60.75171388685703, 61.67002961039543, 56.04147903621197, 52.136249989271164, 50.616719126701355, 49.932068064808846, 41.46020986139774, 39.91386003792286, 41.7633917927742, 43.87131728231907, 43.33600580692291, 48.50213259458542, 50.88864393532276, 48.058046624064445, 47.48874977231026, 46.61762371659279, 48.87440621852875, 49.196419939398766, 47.95926712453365, 47.97813691198826, 47.9544185847044, 49.01935704052448, 48.27893257141113, 51.43404006958008, 51.87741547822952, 49.948498383164406, 49.45014372467995, 55.97902178764343, 56.478056609630585, 56.41138158738613, 57.92279988527298, 61.499342769384384, 57.89102219045162, 58.034848272800446, 54.145255386829376, 57.5458525121212, 57.29734964668751, 57.89951093494892, 61.549241691827774, 59.857272282242775, 57.90264576673508, 59.067746847867966, 55.905233547091484, 57.880983129143715, 62.469016537070274, 64.32278126478195, 61.906836703419685, 66.74981743097305, 61.32237866520882, 63.71937744319439, 63.630021438002586, 52.29794271290302, 52.66675852239132, 79.61154967546463, 56.86960279941559, 56.87478572130203, 34.625212624669075, 23.99596318602562, 14.426207095384598, 12.025536764413118, 11.289095431566238, 21.205805204808712, 11.029519960284233, 4.100436922162771, 9.194124396890402, 3.3001777762547135, 0.5734401138033718, 0.21699244767660275, 0.3010447241831571, 0.13052382739260793, 0.02642679708515061, 0.11669015759252943, 8.196024354547262, 39.89804908633232, 29.638478010892868, 18.26693270355463, 39.17666159570217, 18.662649169564247, 0.5629959586076438, 0.1872487718355842, 0.049688805593177676, 0.7062285009305924, 18.181330896914005, 26.67950838804245, 8.48286621272564, 12.695627007633448, 12.851574439555407, 8.275888469070196, 35.07418893277645, 37.561383470892906, 35.03673434257507, 26.707178503274918, 36.2973091006279, 38.39164651930332, 29.153428338468075, 18.898382820189, 12.425774987787008, 9.416383020579815, 34.184405878186226, 52.73308016359806, 60.91863892972469, 54.66022655367851, 30.399104095995426, 42.794785648584366, 50.55951699614525, 2.4176701437681913, 0.037564995800494216, 0.20925607765093446, 0.20330311817815527, 0.631574084982276, 0.7815374911297113, 0.8665279462002218, 0.1267952923080884, 0.8173931390047073, 0.7613702514208853, 3.2287986064329743, 0.6320102897007018, 37.911671474575996, 73.69286566972733, 69.52743798494339, 64.58886578679085, 64.18346554040909, 61.81952878832817, 62.0469655841589, 59.06176596879959, 58.25726553797722, 56.03305108845234, 63.829316943883896, 70.95540896058083, 69.81726363301277, 71.98524489998817, 71.1866569519043, 69.64858308434486, 58.79562824964523, 72.75711268186569, 73.92899259924889, 70.87814390659332, 72.46767461299896, 76.57510221004486, 74.27684873342514, 72.67418593168259, 69.29166063666344, 67.70532935857773, 72.0132265985012, 70.74068248271942, 68.60086530447006, 69.37958791851997, 64.37818989157677, 67.17521220445633, 68.94142583012581, 64.60094153881073, 59.450276121497154, 64.97104167938232, 63.77163603901863, 65.49748063087463, 61.68321490287781, 58.604247719049454, 59.048151299357414, 53.86923059821129, 55.72596296668053, 53.81905049085617, 52.115575298666954, 50.23972995579243, 50.473539009690285, 55.64543768763542, 54.62999537587166, 52.50657431781292, 50.61246335506439, 45.546966567635536, 48.039815202355385, 45.04289701581001, 49.52583186328411, 52.164900451898575, 57.91323959827423, 65.35379514098167, 65.94385027885437, 64.82176288962364, 65.27345225214958, 59.329632595181465, 54.06304679811001, 53.0124069750309, 50.9954410046339, 43.20873163640499, 42.48571403324604, 43.8794032484293, 45.1155187189579, 47.869280353188515, 50.70249192416668, 55.027469247579575, 52.066630125045776, 48.96905913949013, 50.98135516047478, 49.52639423310757, 54.3124084174633, 52.34583534300327, 52.42546766996384, 50.59316039085388, 51.01711504161358, 50.408437103033066, 51.48746520280838, 55.39409637451172, 53.12359660863876, 52.88740508258343, 58.22481147944927, 61.211937591433525, 61.501717641949654, 60.59923566877842, 63.26195798814297, 59.988061264157295, 63.880758583545685, 58.35528887808323, 62.220620065927505, 61.04294925928116, 58.89156170189381, 66.56648486852646, 64.38638985157013, 64.89560812711716, 63.05198885500431, 59.49029557406902, 58.1237331032753, 61.68171018362045, 67.13354364037514, 66.42222180962563, 69.44432884454727, 66.193588078022, 64.89700645208359, 65.99020019173622, 51.93799942731857, 58.819555565714836, 82.02641889452934, 64.54201430082321, 71.32871612906456, 51.25566244125366, 43.01800087094307, 31.364499293267727, 18.483243696391582, 17.396220825612545, 26.039142049849033, 18.658233806490898, 8.448857087641954, 16.759477593004704, 3.9940112829208374, 0.33882695774082094, 0.48067204013932496, 0.11633276153588668, 0.36950277106370777, 0.07534394535468891, 0.19501978531479836, 7.829888826236129, 48.63363593816757, 36.53397560119629, 23.75537909567356, 51.95330500602722, 29.237090349197388, 0.4765585233690217, 0.047734656545799226, 0.07892892681411467, 1.2534590461291373, 25.85098374634981, 40.66207408905029, 24.99425131827593, 28.743665926158428, 27.6825899630785, 26.526336707174778, 42.720704823732376, 52.86590963602066, 54.971448853611946, 45.94120301306248, 52.76729352772236, 42.22519241273403, 34.539743810892105, 24.941521547734737, 19.73122403025627, 24.399079754948616, 58.540585935115814, 66.23365312814713, 72.46509835124016, 60.91222867369652, 51.60498909652233, 64.03739377856255, 59.67531904578209, 5.449063405394554, 0.20300024771131575, 0.39464017376303673, 0.3462590620620176, 0.8439389301929623, 1.9353190390393138, 0.38562557310797274, 1.8843369372189045, 2.2811180585995317, 1.8369091884233057, 4.105974650010467, 1.4023741241544485, 33.27854588627815, 84.39174637198448, 73.01148623228073, 72.56616532802582, 74.00881111621857, 70.54740205407143, 72.84824699163437, 65.37236094474792, 66.12467497587204, 64.26431760191917, 72.55016818642616, 77.9971531033516, 73.59438255429268, 75.66240638494492, 76.70988857746124, 71.41993403434753, 61.03229083120823, 77.54477217793465, 75.56997254490852, 73.80299896001816, 75.85846066474915, 77.95738443732262, 75.27395322918892, 76.98858842253685, 72.65653967857361, 74.06544327735901, 76.27358078956604, 75.73028594255447, 75.23999065160751, 72.41989597678185, 69.0682478249073, 72.05361843109131, 70.03208130598068, 69.1111171245575, 63.24349097907543, 68.43466982245445, 68.02097842097282, 67.36483722925186, 66.65502771735191, 64.5327427983284, 62.44638875126839, 56.67873524129391, 59.02105875313282, 57.10737504065037, 55.809604078531265, 52.417157515883446, 54.415534883737564, 59.87112253904343, 57.69372917711735, 54.515564516186714, 54.2703902721405, 48.21941256523132, 52.356923148036, 47.650681883096695, 51.7381377518177, 55.956025421619415, 57.66557268798351, 67.27935701608658, 69.3142694234848, 67.18455970287323, 66.73166200518608, 60.91226287186146, 56.47073820233345, 55.26207625865936, 55.32730735838413, 46.682611629366875, 45.18805682659149, 47.94011615216732, 47.002638056874275, 49.54910561442375, 54.044959768652916, 58.07946927845478, 54.50888067483902, 53.61760050058365, 54.7045473754406, 52.849270328879356, 55.33547692000866, 54.712245762348175, 56.42148144543171, 54.81531523168087, 54.27028387784958, 56.215433701872826, 54.332957714796066, 58.72232258319855, 56.2968785315752, 56.20056889951229, 63.10812324285507, 64.71511021256447, 63.33237200975418, 64.69168826937675, 66.84064015746117, 62.3229143768549, 65.9718319773674, 62.8269649296999, 63.019595593214035, 61.55642330646515, 62.496261075139046, 68.19469749927521, 66.70168161392212, 68.83507713675499, 67.40565463900566, 63.69530953466892, 60.48787124454975, 67.4564579129219, 69.81955870985985, 70.21851450204849, 72.60648116469383, 68.32745477557182, 69.01961043477058, 73.38161677122116, 56.412088349461555, 61.383536383509636, 78.84560197591782, 67.07480639219284, 72.83976584672928, 58.20518933236599, 51.14436261355877, 42.65907593071461, 34.89473596215248, 35.543247163295746, 48.691058456897736, 50.89595094323158, 18.122437857091427, 30.053807124495506, 6.535817915573716, 3.043552846647799, 0.7360855175647885, 0.6254688219632953, 0.663243307499215, 0.19703511701663956, 0.31625073635950685, 13.83340185508132, 56.64513364434242, 44.3177705258131, 30.168055593967438, 60.75118191540241, 36.20259918272495, 0.6817426148336381, 0.3232011868385598, 0.2072121881064959, 1.501089739613235, 33.01353670656681, 50.34082733094692, 36.4865617454052, 44.708723947405815, 41.01939931511879, 34.82068553566933], [14.469913300126791, 3.7409379752352834, 9.416213929653168, 19.355462193489075, 7.2136554680764675, 8.652355168014765, 17.96576276421547, 26.360994279384613, 22.090124152600765, 10.321437455713749, 22.31351226568222, 43.36879424750805, 51.48444436490536, 42.158703580498695, 18.82221780717373, 46.2931477278471, 18.86229045689106, 0.02081407521473011, 0.07274889983818866, 0.09256037621526048, 0.07161672387155704, 0.14412209537113085, 0.8237707405351102, 0.4093792859930545, 0.8804389997385442, 0.07949544524308294, 0.2645695017417893, 0.5486752989236265, 0.21602044202154502, 6.549297692254186, 54.19752158224583, 70.00375762581825, 57.70684227347374, 50.22770740091801, 50.84518186748028, 52.13287957012653, 54.35576409101486, 54.218975231051445, 49.537892416119576, 54.685198813676834, 63.99067908525467, 60.94426475465298, 67.50222265720367, 62.42898568511009, 58.391257748007774, 56.04527123272419, 71.56257078051567, 67.56425812840462, 71.83251589536667, 68.21520119905472, 74.92823258042336, 71.33991792798042, 65.66757470369339, 65.66519603133202, 67.1577787399292, 63.052463829517365, 63.77203121781349, 66.58437430858612, 65.60173943638802, 64.9206791818142, 62.16655656695366, 65.5328719317913, 58.25429409742355, 61.82613283395767, 63.886906653642654, 61.64797559380531, 66.8839730322361, 55.8193239569664, 55.31547859311104, 51.49514079093933, 50.68485327064991, 49.03843581676483, 50.69819055497646, 49.76286694407463, 48.42027738690376, 46.50194272398949, 51.45800158381462, 53.23116883635521, 49.050032794475555, 46.52539886534214, 43.31666484475136, 43.33849087357521, 44.111623987555504, 44.61165815591812, 47.58263133466244, 48.415485844016075, 60.697418600320816, 64.48867276310921, 63.67508701980114, 61.61080598831177, 56.33891947567463, 49.099236354231834, 49.31817300617695, 45.255073830485344, 41.63926385343075, 39.832631796598434, 38.69284115731716, 42.51385152339935, 42.709016650915146, 50.932030007243156, 51.595276817679405, 46.261218041181564, 47.36934497952461, 47.47942507266998, 48.934036418795586, 48.12046967446804, 46.663335263729095, 44.02109384536743, 48.641664907336235, 46.76002487540245, 50.44986627995968, 48.8862007856369, 49.423902332782745, 51.59468024969101, 51.19488090276718, 52.889863550662994, 56.675201430916786, 56.82679049670696, 57.638563737273216, 59.59725223481655, 56.546848118305206, 57.58153259754181, 57.2572124004364, 56.740911304950714, 60.46231001615524, 55.55095575749874, 57.546232491731644, 61.16637423634529, 60.89329048991203, 59.94453839957714, 57.70699046552181, 55.125397592782974, 60.651627257466316, 66.88616171479225, 60.88808476924896, 66.5916395187378, 59.972634091973305, 63.875081688165665, 58.24949115514755, 61.512087285518646, 51.75654016435146, 68.06988939642906, 64.06345278024673, 65.54247781634331, 44.56020891666412, 33.93662877380848, 20.674506314098835, 13.887185119092464, 13.822456542402506, 24.23784300684929, 17.924373485147953, 15.959899798035622, 6.220091907307506, 1.6482242569327354, 0.5433315387926996, 0.3532020910643041, 0.18186696921475232, 0.21413783601019531, 0.04122448888665531, 0.0341654696239857, 1.9690035190433264, 37.1046631783247, 29.909032993018627, 15.868985876441002, 29.465273804962635, 32.45963282883167, 0.6057770317420363, 0.09461800291319378, 0.3849502484081313, 14.131048433482647, 20.58835543692112, 10.735793821513653, 32.05232888460159, 34.864348992705345, 42.59238190948963, 32.018081322312355, 23.10998372733593, 16.327872052788734, 22.301358617842197, 58.089265152812004, 33.92079882323742, 16.017409712076187, 23.906552083790302, 27.485340647399426, 29.73020128905773, 21.191878952085972, 38.10254283249378, 54.89701084792614, 61.91354714334011, 46.779658421874046, 18.662424981594086, 55.91763988137245, 23.570885695517063, 0.2764637244399637, 0.07828817135305144, 0.007834757470845943, 0.2184297947678715, 0.39252796210348606, 2.0509413722902536, 2.2616343665868044, 1.3401138712652028, 0.24903860699851066, 0.7566450862213969, 1.9900420401245356, 0.13028028421103954, 12.343660444021225, 70.42534500360489, 77.5322936475277, 64.06494230031967, 59.926637560129166, 58.74512895941734, 65.25800228118896, 63.79222333431244, 58.85042890906334, 56.85197934508324, 61.88974902033806, 70.26300251483917, 63.86167600750923, 70.75296342372894, 68.15206378698349, 61.164869517087936, 58.07196848094463, 73.3671623468399, 70.92781484127045, 74.60261285305023, 71.17471799254417, 74.89540994167328, 74.14366587996483, 68.25698375701904, 69.266247600317, 70.94752058386803, 67.90967479348183, 67.9593001306057, 69.22061204910278, 68.24442923069, 69.29530084133148, 66.31442919373512, 67.49322474002838, 59.4861613959074, 61.80638149380684, 67.71080106496811, 66.47884637117386, 67.5209404528141, 59.35690373182297, 57.59166285395622, 54.47188585996628, 53.09300824999809, 51.4333751052618, 52.93145231902599, 52.20365837216377, 50.605562925338745, 51.124026104807854, 54.0135582536459, 57.12608903646469, 54.16399598121643, 49.478045627474785, 46.25383883714676, 44.67066138982773, 46.294105276465416, 48.05148437619209, 46.50443539023399, 49.45053890347481, 59.974940568208694, 65.70705458521843, 65.13261660933495, 61.503974720835686, 58.86859953403473, 51.671861708164215, 50.50521411001682, 46.00407063961029, 44.174275025725365, 42.50757426023483, 42.003740295767784, 44.56246219575405, 46.77263639867306, 54.63612824678421, 54.12939503788948, 47.99247354269028, 49.42715495824814, 50.065437108278275, 50.57217791676521, 50.276986956596375, 51.62418946623802, 49.090120643377304, 50.28452955186367, 51.337232664227486, 52.30978287756443, 49.86889265477657, 52.5979670137167, 52.89301738142967, 54.04847078025341, 55.05123317241669, 58.55671986937523, 60.24315297603607, 60.872361212968826, 61.513603404164314, 58.78209337592125, 62.95391231775284, 62.664265260100365, 60.968727841973305, 61.77520036697388, 60.49216501414776, 64.31199744343758, 64.16727840900421, 65.12687131762505, 65.57636439800262, 62.70344115793705, 57.103092670440674, 62.613587379455566, 68.46818402409554, 65.54121628403664, 67.98883974552155, 66.31939932703972, 64.11609515547752, 61.52792863547802, 59.74935807287693, 58.36620569229126, 71.65837123990059, 67.24846467375755, 75.77293485403061, 59.106120988726616, 51.93218193948269, 38.67566227912903, 29.43921860307455, 23.579497933387756, 28.178659044206142, 23.265714570879936, 15.550706405192614, 4.495403878390789, 0.8538371615577489, 0.5326597520615906, 0.06961296967347153, 0.15321646205848083, 0.4504811461083591, 0.026677869354898576, 0.23167146078776568, 2.186680301092565, 42.66868181526661, 35.29460370540619, 23.38564183562994, 39.13365550339222, 45.37994273006916, 0.8628407784271985, 0.07623378041898832, 0.390542212408036, 19.766360744833946, 33.004124611616135, 25.557983368635178, 40.94815693795681, 47.01911777257919, 52.21740983426571, 46.58720634877682, 45.326540395617485, 27.495638094842434, 33.371416702866554, 97.92447701096535, 41.38218864798546, 33.90003673732281, 68.78520101308823, 79.37503516674042, 73.55304837226868, 45.73019653558731, 57.890775203704834, 67.67442181706429, 71.19321539998055, 59.935331493616104, 32.81950391829014, 66.64856806397438, 33.417595624923706, 0.9433406463358551, 0.2771414536982775, 0.345757162431255, 0.4816096991999075, 0.8013646490871906, 1.7279292549937963, 2.1899704495444894, 5.0533925369381905, 0.35936337138991803, 1.700587347149849, 2.190192500129342, 0.3413618967169896, 10.437051951885223, 72.64251843094826, 79.93104413151741, 71.84136182069778, 70.62650620937347, 67.96880722045898, 76.86999678611755, 71.5968905389309, 67.61193796992302, 65.7771684229374, 70.71584701538086, 74.59063589572906, 71.49893179535866, 76.57995074987411, 76.91456839442253, 63.372851237654686, 62.800860330462456, 79.15128037333488, 74.18459728360176, 78.95334139466286, 74.71648514270782, 80.9495110809803, 78.4939156472683, 70.17309173941612, 71.20804220438004, 72.28600636124611, 72.44463264942169, 70.47845095396042, 73.43136370182037, 72.22172901034355, 72.91137680411339, 67.43470788002014, 73.78640905022621, 65.34471362829208, 66.51534721255302, 70.73479279875755, 69.75628450512886, 72.24079638719559, 61.98667421936989, 61.34385131299496, 58.87625232338905, 56.00173696875572, 54.36332568526268, 57.64452941715717, 56.891337633132935, 54.320669174194336, 53.91965389251709, 57.89861038327217, 62.467515617609024, 56.031667962670326, 52.27160632610321, 49.42588582634926, 47.92033061385155, 48.84453222155571, 48.84388625621796, 48.3524814248085, 52.1090130507946, 65.63504084944725, 69.39998522400856, 71.41997203230858, 64.42090719938278, 59.787770211696625, 53.28365541994572, 55.204839929938316, 50.60517154633999, 47.559133395552635, 43.660029619932175, 42.48742014169693, 46.805949211120605, 47.08594098687172, 57.998807206749916, 57.150145545601845, 51.1547664552927, 53.91251027584076, 54.47150968015194, 53.39175961911678, 54.06435012817383, 54.89771381020546, 51.42422139644623, 53.742435202002525, 53.93977381289005, 56.52052313089371, 53.425486609339714, 57.040624022483826, 55.85917241871357, 57.73389682173729, 60.7464549690485, 62.168996036052704, 63.8212613761425, 62.6467178016901, 64.13267746567726, 60.049792751669884, 64.01570454239845, 66.00423663854599, 63.403112813830376, 65.32819971442223, 63.37642304599285, 67.59096309542656, 67.05450028181076, 68.12119424343109, 67.69178688526154, 65.68901315331459, 59.77914847433567, 66.53028801083565, 74.06528368592262, 69.21947211027145, 71.65767207741737, 68.0483141541481, 69.22742128372192, 65.52739262580872, 68.45304563641548, 58.09956260025501, 73.71035233139992, 68.48649144172668, 74.49005529284477, 63.409124091267586, 58.65746006369591, 47.05842666327953, 47.42585174739361, 49.00434024631977, 60.907767713069916, 56.60563476383686, 40.42507320642471, 19.004746712744236, 4.877331359311938, 1.9370861817151308, 1.936257944907993, 0.27268559904769063, 0.8765009266790003, 0.17551574361277744, 0.4879857273772359, 4.401351800188422, 53.97901430726051, 40.93127824366093, 31.599165201187134, 45.391566306352615, 59.69096660614014, 0.9298813529312611, 0.20069368241820484, 0.6863990274723619, 27.392334938049316, 46.44082300364971, 40.73081620037556, 74.7739988565445, 75.5821242928505, 86.50831639766693, 83.24049934744835], [25.384769663214684, 12.53242576494813, 10.103315860033035, 5.365742426365614, 8.091605957597494, 14.599962271749973, 25.82445167005062, 27.983138635754585, 26.685874946415424, 23.68747103959322, 18.482424840331078, 30.636492557823658, 47.834747806191444, 36.27922207117081, 25.60406729578972, 44.140601232647896, 5.237555354833603, 0.15551317163044587, 0.10297123124473728, 0.060700072936015204, 0.20363738149171695, 0.3268284781370312, 0.35404876281972975, 2.542570154182613, 0.3248763922601938, 0.107616207387764, 1.1302966112270951, 0.19685050036059693, 0.16342774615623057, 3.5634086513891816, 30.616870410740376, 52.675802037119865, 49.21808637678623, 44.23772022128105, 53.48609335720539, 54.637925550341606, 56.2352192401886, 55.65974771976471, 49.019281044602394, 44.16574448347092, 62.115985080599785, 59.07907024025917, 66.40278965234756, 59.047919511795044, 58.225670233368874, 56.49328239262104, 68.1954574584961, 68.5973010957241, 69.74686101078987, 68.67067515850067, 72.31904938817024, 67.69592866301537, 67.73541614413261, 64.96636033058167, 69.98430266976357, 63.14873546361923, 63.63642789423466, 63.678487837314606, 67.43528544902802, 67.41342142224312, 65.95154866576195, 58.936201706528664, 59.47559796273708, 61.97779029607773, 62.12501339614391, 64.80497539043427, 58.63864727318287, 52.23747655749321, 51.51494152843952, 52.52085015177727, 49.385657384991646, 49.63192597031593, 48.42943489551544, 49.470404237508774, 49.246455654501915, 44.61381644010544, 47.841051667928696, 53.55892784893513, 49.597188234329224, 47.513744831085205, 43.1596914678812, 41.896996423602104, 44.46245916187763, 46.19026064872742, 44.01461899280548, 44.49199117720127, 53.12600947916508, 58.06262858211994, 53.88237789273262, 54.09943364560604, 57.27962739765644, 46.63370065391064, 42.715772688388824, 44.37638998031616, 40.41925951838493, 40.827312022447586, 40.969933569431305, 42.43699684739113, 42.12428502738476, 48.36209870874882, 48.593076914548874, 46.46013356745243, 47.54338324069977, 47.20849581062794, 47.392500936985016, 48.5404497385025, 48.86363759636879, 46.15130513906479, 46.71392574906349, 47.14644134044647, 48.90783302485943, 49.271237924695015, 47.33458064496517, 48.45476433634758, 52.339174300432205, 53.467128574848175, 52.50762306153774, 51.33937954902649, 58.00323396921158, 54.64874356985092, 54.883943349123, 58.4179513156414, 57.32085518538952, 57.55499482154846, 57.69470952451229, 55.0280886143446, 58.27194035053253, 58.799659833312035, 60.35610571503639, 59.06009025871754, 61.00423313677311, 57.833151295781136, 54.97956521809101, 64.30409386754036, 59.87806476652622, 63.76735746860504, 58.791505470871925, 65.25804787874222, 55.77775798738003, 56.10525481402874, 48.75951558351517, 58.83481174707413, 57.48600572347641, 69.09990772604942, 53.279057666659355, 43.409034088253975, 30.871234461665154, 21.964121013879776, 13.608670514076948, 29.293306432664394, 25.995805375277996, 5.556315025314689, 2.5014083879068494, 0.07145757772377692, 0.4011484229704365, 0.232182459149044, 0.12212963993079029, 0.1891123640234582, 0.008026498744584387, 0.08553090927307494, 1.1615724954754114, 27.967071197926998, 42.19091445207596, 21.960972882807255, 31.043424122035503, 30.205776169896126, 1.5702413977123797, 0.13464773423038423, 4.090606374666095, 19.300815425813198, 3.6740017170086503, 25.973002798855305, 19.95165590196848, 12.795115169137716, 5.525374710559845, 17.95388650149107, 41.834603771567345, 20.201747082173824, 28.17458376288414, 50.888989716768265, 18.909286335110664, 33.638869151473045, 42.379616126418114, 53.008990958333015, 44.024346470832825, 34.67446558177471, 32.76808127760887, 40.76363883912563, 61.039198860526085, 41.71714827418327, 27.102064713835716, 55.320577919483185, 8.471254985779524, 0.11801115077105351, 0.21145513543160632, 0.09497697232291102, 0.5401425005402416, 1.079121669754386, 3.2127577671781182, 8.665531910955906, 1.2178643373772502, 0.16496641124831513, 1.447336517740041, 0.5838743539061397, 0.058874846072285436, 4.595403112471104, 47.543440237641335, 65.65150156617165, 59.85928237438202, 57.67607532441616, 63.76441642642021, 61.58840999007225, 65.56891679763794, 66.30148708820343, 57.89446100592613, 52.7157036960125, 68.97629275918007, 64.832364320755, 69.58255782723427, 68.14865916967392, 59.89181622862816, 59.83222782611847, 71.48003160953522, 69.75338146090508, 71.2223370373249, 68.82502287626266, 74.81993839144707, 72.63627916574478, 70.13613492250443, 66.9638067483902, 70.33196121454239, 67.16424599289894, 65.32557025551796, 68.34874123334885, 68.38949024677277, 71.08121261000633, 69.22492101788521, 60.611357018351555, 62.530406042933464, 67.75218844413757, 63.525884225964546, 67.24163264036179, 59.9213482439518, 54.839527532458305, 54.17273171246052, 56.372239887714386, 53.20822186768055, 51.65144920349121, 53.04575018584728, 52.16458886861801, 49.66010145843029, 49.020234793424606, 50.431752651929855, 56.248533725738525, 51.515294909477234, 51.87128260731697, 46.18898391723633, 45.159470960497856, 47.35486775636673, 46.5448272228241, 46.22589893639088, 47.76517353951931, 52.677910923957825, 57.40031652152538, 55.3862763941288, 54.489307925105095, 56.87401436269283, 47.760264202952385, 44.35343161225319, 45.605149045586586, 43.20799447596073, 42.74673342704773, 41.603572368621826, 42.892543002963066, 45.761867836117744, 54.027731493115425, 50.68434029817581, 48.769984021782875, 48.61593268811703, 48.868402540683746, 51.020405665040016, 51.55823640525341, 50.86559817194939, 49.12633270025253, 49.053745195269585, 50.37608943879604, 53.84031794965267, 51.68885439634323, 49.333451986312866, 50.44323183596134, 52.63579398393631, 57.642086148262024, 56.052487045526505, 55.96482194960117, 60.91160170733929, 56.462682634592056, 58.02986294031143, 62.826052978634834, 61.03594243526459, 60.204714238643646, 61.886272206902504, 61.40606537461281, 61.10444135963917, 62.1102511882782, 64.58369046449661, 65.13919785618782, 65.06399989128113, 61.37257777154446, 57.13238909840584, 64.42796722054482, 63.28672505915165, 66.03323668241501, 61.89534991979599, 65.9364102780819, 56.86288855969906, 57.33009248971939, 56.27098672091961, 65.80013439059258, 61.6531091183424, 75.05613371729851, 67.27725952863693, 59.50554795563221, 49.580879509449005, 41.35757356882095, 31.07127282768488, 36.10112942755222, 26.80554762482643, 1.6241911402903497, 2.4894454423338175, 0.5116939614526927, 0.35320868133567274, 0.6833284359890968, 0.22745686350390315, 0.28866199019830674, 0.09945487618097104, 0.25631468219216913, 1.4040076802484691, 37.37564943730831, 46.788720935583115, 26.825342662632465, 37.30836644768715, 42.80631422996521, 1.912218772340566, 0.31789037806447595, 8.147079180926085, 34.21118304133415, 16.53668224811554, 41.31202921271324, 38.49837899208069, 30.59331927448511, 24.698961563408375, 35.234376937150955, 93.27931746840477, 69.67137426137924, 56.49634502828121, 104.93685632944107, 56.85643270611763, 86.43324762582779, 80.66049858927727, 86.13803386688232, 76.5319213271141, 59.64561223983765, 46.832669377326965, 52.71179750561714, 69.45717975497246, 55.38281857967377, 43.10716688632965, 62.5260628759861, 14.89129738882184, 0.30893954273778945, 0.3362532489700243, 0.17655011935858056, 0.5357278499286622, 1.4684605342336, 1.0864330711774528, 6.479852618649602, 0.47703789139632136, 0.16251604742137715, 2.3639621632173657, 1.1546708783134818, 0.25287821190431714, 5.090569267049432, 48.6319450289011, 68.99422019720078, 67.6157757639885, 69.36658501625061, 73.31480115652084, 67.90727332234383, 71.84559479355812, 72.1391898393631, 69.91468280553818, 59.591689333319664, 74.65179741382599, 67.61066123843193, 77.25955188274384, 73.88759762048721, 64.37451168894768, 62.46307745575905, 77.91076853871346, 76.09562113881111, 73.7636786699295, 74.06674280762672, 78.31651076674461, 75.20766198635101, 71.79623544216156, 68.74945253133774, 75.71800500154495, 69.24267366528511, 68.84814083576202, 70.86539939045906, 75.50121143460274, 76.68367758393288, 69.75769802927971, 64.37883585691452, 65.86685881018639, 68.75095725059509, 69.11117032170296, 71.74084201455116, 64.13783758878708, 57.581555396318436, 57.964343056082726, 61.1379973590374, 55.34186437726021, 54.944272711873055, 54.16389338672161, 56.85446061193943, 54.21251177787781, 54.45751503109932, 55.99079355597496, 62.64718517661095, 54.03672181069851, 56.603066101670265, 48.528936356306076, 48.81833262741566, 51.32622845470905, 49.71128471195698, 47.38045938313007, 48.31503823399544, 55.19052229821682, 65.32304719090462, 59.9613980948925, 57.82157711684704, 61.19878649711609, 49.48691815137863, 46.77103668451309, 48.7566277384758, 44.29374821484089, 44.9922951310873, 45.615746676921844, 44.44221384823322, 46.96324937045574, 53.60806301236153, 53.40691700577736, 52.254982218146324, 51.642276495695114, 53.27440671622753, 53.330396711826324, 56.46634563803673, 54.48901154100895, 50.672929510474205, 50.813476368784904, 50.3154256939888, 58.35038334131241, 56.63058042526245, 51.84570997953415, 55.683162063360214, 58.61317344009876, 62.37200394272804, 59.13265876471996, 57.98758640885353, 64.09207284450531, 58.936657682061195, 57.89717026054859, 63.96937742829323, 63.11576083302498, 63.679935559630394, 64.72769513726234, 63.197840228676796, 63.82793381810188, 65.05801901221275, 67.71728351712227, 68.75759929418564, 67.36143261194229, 63.96931663155556, 59.71574127674103, 72.77428776025772, 68.52247551083565, 69.13188681006432, 62.378026619553566, 69.72568854689598, 62.75655470788479, 66.11741736531258, 56.69676147401333, 68.15546840429306, 66.57409206032753, 68.772312104702, 71.20597511529922, 61.80863477289677, 55.90136915445328, 52.41298533976078, 56.214799135923386, 66.10760629177094, 60.025173872709274, 22.406702265143394, 3.396611139178276, 0.9566278208512813, 3.2107775984331965, 2.154191331937909, 0.3367315186187625, 0.628145718947053, 0.17665839870460331, 0.42408954352140427, 1.954932517837733, 49.40359242260456, 53.14975060522556, 36.03297248482704, 49.81181971728802, 57.45446741580963, 2.9017252195626497, 0.45262850588187575, 11.437797602266073, 50.031995102763176, 29.934523925185204, 79.06218275427818, 71.75294056534767, 56.60539537668228, 42.998257130384445, 65.48671200871468], [8.049435820430517, 10.01026265323162, 38.12806226313114, 16.59662403166294, 2.9474443662911654, 3.988780863583088, 20.38185741752386, 19.185805097222328, 30.023401156067848, 23.940778747200966, 18.60846407711506, 27.18012772500515, 47.83182576298714, 20.35636268556118, 40.19085757434368, 31.674553155899048, 0.7585908193141222, 0.05308523330313619, 0.33496746327728033, 0.07359035429544747, 0.11489192635053769, 0.31331818434409797, 5.1750753074884415, 3.510969327762723, 0.47355291433632374, 0.5163400433957577, 0.5323758954182267, 0.3004922694526613, 0.3314745897660032, 7.2208204586058855, 23.099665381014347, 43.34879592061043, 56.960254535079, 52.47041545808315, 51.73281043767929, 55.46172134578228, 55.342111364006996, 56.00143678486347, 52.854464650154114, 44.38192628324032, 58.40762346982956, 56.344790160655975, 60.99021568894386, 55.90777941048145, 53.47430258989334, 60.891098007559776, 71.47905126214027, 67.70797401666641, 69.37950432300568, 66.00216954946518, 71.05833023786545, 68.6740493774414, 66.78296685218811, 65.62347427010536, 63.33052910864353, 62.92813070118427, 64.2172609269619, 63.10912258923054, 65.75906619429588, 66.36051312088966, 62.52019219100475, 56.74813851714134, 63.95540177822113, 62.75626212358475, 66.19240254163742, 59.05759759247303, 53.20633336901665, 52.9233967512846, 52.708404287695885, 53.13943795859814, 50.051503255963326, 48.07853512465954, 48.396859243512154, 50.37528768181801, 48.452134877443314, 46.39359913766384, 46.961125284433365, 53.74718114733696, 49.30332340300083, 46.770139932632446, 43.239426389336586, 43.98070201277733, 44.93929177522659, 44.03704158961773, 46.20305836200714, 44.11299951374531, 46.80904224514961, 46.38710528612137, 45.220157504081726, 46.079751178622246, 49.568256586790085, 44.31324116885662, 41.25873327255249, 42.922914773225784, 42.56444960832596, 37.5457701086998, 38.52426320314407, 41.19874969124794, 46.234129294753075, 50.31463533639908, 47.85517930984497, 45.368961319327354, 46.88558153808117, 49.54115264117718, 50.78375816345215, 47.822949439287186, 47.92530454695225, 45.95026932656765, 47.04100459814072, 46.751171350479126, 50.37694439291954, 48.478915840387344, 47.36459523439407, 48.889043033123016, 46.7264498770237, 51.78663454949856, 50.651396065950394, 53.190355226397514, 58.89580987393856, 55.03937020897865, 57.97725096344948, 56.30607023835182, 56.381940767169, 57.423472478985786, 58.46675969660282, 56.078504249453545, 57.67967753112316, 56.21990226209164, 57.35757641494274, 60.89753486216068, 58.78712050616741, 60.03388300538063, 56.59609727561474, 61.94319315254688, 58.64387959241867, 61.63808472454548, 58.7176488339901, 58.35047073662281, 55.802487060427666, 51.314354091882706, 45.33343322575092, 61.11636132001877, 61.03052772581577, 67.1606133878231, 63.72674524784088, 45.29246002435684, 33.78625564277172, 26.829440742731094, 22.530469223856926, 41.819545179605484, 10.947660952806473, 1.7975314264185727, 0.28477942978497595, 0.04288264717615675, 0.030636334777227603, 0.22267811524216086, 0.2001336874673143, 0.1548706053290516, 0.09320806333562359, 0.1324993948219344, 0.2690998383332044, 22.812942266464233, 43.10243234038353, 24.91599641740322, 24.766240753233433, 21.333176270127296, 1.5398744959384203, 0.21707096690079197, 8.87991925701499, 7.823280030861497, 12.719338685274124, 10.518167149275541, 8.124816175550222, 4.986538449302316, 2.2817922849208117, 3.0067406594753265, 25.16129605472088, 28.148707151412964, 36.784427762031555, 21.581673435866833, 30.344624519348145, 26.058893389999866, 43.96554842591286, 47.49042548239231, 53.036516681313515, 40.94181887805462, 30.34365937113762, 40.61194337904453, 60.99108584225178, 22.52706840634346, 46.10940858721733, 41.71551816165447, 0.7529105397406965, 0.07729399774689227, 0.37488390575163066, 0.15583070693537593, 0.4239765292732045, 0.27571742073632777, 2.143653784878552, 2.0182833122089505, 1.6301848436705768, 0.19728145067347214, 1.1905435658991337, 0.4203250736463815, 0.7916796812787652, 7.479598447680473, 27.295820116996765, 54.294332787394524, 69.83822330832481, 55.267832949757576, 59.774710312485695, 64.12856608629227, 62.339625880122185, 65.30999109148979, 59.595565125346184, 56.308646500110626, 62.88775026798248, 63.17184962332249, 66.96503028273582, 62.78056941926479, 57.45805822312832, 65.95550805330276, 72.99642384052277, 70.48535898327827, 72.2031632065773, 69.94087100028992, 70.2478489279747, 72.57439568638802, 69.03371527791023, 69.43605288863182, 67.02876806259155, 66.07002630829811, 65.52650347352028, 66.24804675579071, 65.22009551525116, 67.5256597995758, 61.53984099626541, 60.22675685584545, 65.80268025398254, 67.4784055352211, 68.45514312386513, 63.535186126828194, 56.03734105825424, 55.82531623542309, 56.6358507424593, 54.67901274561882, 52.35670655965805, 52.14416116476059, 51.527351662516594, 53.38070601224899, 51.46365188062191, 49.94258210062981, 49.619854018092155, 55.76330356299877, 55.002352595329285, 50.69643884897232, 45.73371134698391, 45.23653082549572, 47.497109323740005, 44.547449201345444, 47.0686025172472, 44.12355914711952, 45.47484263777733, 47.428617998957634, 47.50639222562313, 45.6524109095335, 48.228991851210594, 46.72728583216667, 43.28712522983551, 45.05204312503338, 44.603112414479256, 40.27067229151726, 41.66315697133541, 44.028043672442436, 50.913376808166504, 53.63949492573738, 50.071938559412956, 47.775801569223404, 49.15810279548168, 50.7759989798069, 50.35356044769287, 49.7811933606863, 50.255016535520554, 48.587023839354515, 48.72314773499966, 48.98299299180508, 51.791323497891426, 54.24356371164322, 50.577402636408806, 54.1866921633482, 52.53278911113739, 55.262558832764626, 53.77056509256363, 55.114875957369804, 62.472052574157715, 56.98713429272175, 60.454079657793045, 59.04141426086426, 58.78001108765602, 58.74131016433239, 61.977573707699776, 62.59015403687954, 59.456389993429184, 59.1558451205492, 61.678788140416145, 64.82140570878983, 62.31155678629875, 62.62899175286293, 56.93476550281048, 63.08056712150574, 63.36486026644707, 65.39555490016937, 60.97001977264881, 58.839508295059204, 57.435080856084824, 53.55431109666824, 52.361118122935295, 67.43940442800522, 68.72348472476006, 70.16191273927689, 71.35604426264763, 58.0425276607275, 51.973424926400185, 46.10581398010254, 40.38572631776333, 53.611080050468445, 15.642609223723412, 1.256416356191039, 0.27134251955430955, 0.040980073681566864, 0.11234415564103983, 0.17591806186828762, 0.04527368742856197, 0.20825713203521445, 0.13955105940112844, 0.2722389152040705, 0.3678063995903358, 32.49664284288883, 51.00094310939312, 32.19569519162178, 34.49063524603844, 34.18387770652771, 1.8081728741526604, 0.08013253449462354, 16.983623765408993, 20.105226561427116, 27.959332913160324, 29.995252266526222, 21.146988160908222, 13.933677524328232, 8.625634051859379, 17.146621719002724, 50.015332996845245, 84.84866425395012, 122.52441018819809, 95.08941873908043, 68.72534662485123, 36.73615135252476, 52.77124531567097, 75.59024065732956, 84.45877477526665, 64.12647619843483, 46.440560817718506, 57.73916333913803, 77.24561423063278, 37.94377975165844, 59.7540508210659, 49.58369515836239, 1.9491945882327855, 0.24402490962529555, 0.5230681167449802, 0.48096334794536233, 0.33583797281607985, 0.7570939371362329, 8.935236688703299, 4.377293391153216, 3.1192155741155148, 1.5183070907369256, 2.1665349695831537, 1.3670654688030481, 1.3803596491925418, 8.204533997923136, 28.706650212407112, 63.82514476776123, 77.2800175845623, 67.31737017631531, 68.43219995498657, 71.81026428937912, 70.82997009158134, 73.79023924469948, 72.48501688241959, 65.23543909192085, 69.13988918066025, 68.5991857945919, 76.01624339818954, 70.75389057397842, 61.42881855368614, 69.68426316976547, 78.45900312066078, 76.13785207271576, 76.9193409383297, 72.5421430170536, 74.04626950621605, 73.11854168772697, 72.93948009610176, 72.31231614947319, 70.10631412267685, 69.13139283657074, 69.6169763803482, 70.52489206194878, 71.02281734347343, 71.12349674105644, 66.57954096794128, 62.307821586728096, 68.56868103146553, 71.2039840221405, 72.07747355103493, 66.1189828813076, 59.16272275149822, 58.5317400097847, 58.996804654598236, 59.72090519964695, 56.55394233763218, 56.20717294514179, 52.716224268078804, 55.86586005985737, 53.189591467380524, 54.377863705158234, 54.830753803253174, 61.37490704655647, 56.70785687863827, 52.69110381603241, 46.70012108981609, 50.66887132823467, 50.07061243057251, 47.4558549374342, 50.71653977036476, 45.5324437469244, 48.57950024306774, 48.18422645330429, 48.23694862425327, 48.20566490292549, 50.6196715682745, 46.37999206781387, 43.71876306831837, 44.918335899710655, 46.46022476255894, 42.52324461936951, 45.01470632851124, 47.218090295791626, 53.18669602274895, 56.86431348323822, 53.8288539648056, 52.87557251751423, 53.950854018330574, 54.712656140327454, 53.4433114528656, 52.74350680410862, 55.14846995472908, 49.35317672789097, 51.034434512257576, 51.23542092740536, 55.429157093167305, 56.56949110329151, 53.60951453447342, 55.082847476005554, 54.626552760601044, 61.214981228113174, 56.463959366083145, 59.19421926140785, 66.25579833984375, 60.91098994016647, 62.93087035417557, 62.638472244143486, 59.044815078377724, 61.91881366074085, 63.70830483734608, 63.02232004702091, 62.93618626892567, 61.973078548908234, 65.15047565102577, 68.03357854485512, 65.54512247443199, 65.67737057805061, 59.787074849009514, 68.97338211536407, 67.12638482451439, 68.69529783725739, 65.33463656902313, 63.92993554472923, 63.026249036192894, 58.63765552639961, 57.11396008729935, 70.24789452552795, 72.20601305365562, 68.96479457616806, 74.09840270876884, 60.18763795495033, 58.579929023981094, 55.53289532661438, 64.39066082239151, 80.63376322388649, 36.21740318834782, 4.863382782787085, 0.46449482382740825, 0.1212527924508322, 0.3506127081345767, 0.45980062102898955, 0.5633665574714541, 0.7640121190343052, 0.1589125642203726, 0.48650407406967133, 0.6351533741690218, 44.699342250823975, 54.848521649837494, 42.9618588835001, 46.01366512477398, 51.28917284309864, 2.142357579432428, 0.2846390154445544, 27.582417838275433, 35.467072650790215, 59.91887457668781, 64.87067386507988, 35.760952681303024, 19.846965819597244, 20.50358198583126, 37.52156540751457], [12.307944260537624, 30.325813628733158, 52.28637233376503, 41.31291076540947, 2.23574873059988, 0.7903857319615781, 0.4391424951609224, 4.595756018534303, 9.686881005764008, 21.922541745007038, 25.527068227529526, 44.02670614421368, 25.009879879653454, 44.67851936817169, 57.75631561875343, 13.653508108109236, 0.3808419266715646, 0.10429840651340783, 0.3932669630739838, 0.0639132087235339, 1.0570150497369468, 1.1300571053288877, 10.643251687288284, 13.904199656099081, 5.162413436919451, 1.8059617490507662, 0.5582151026464999, 0.134532701340504, 0.18784443440381438, 4.086361052468419, 13.187967538833618, 26.380331441760063, 41.83755241334438, 45.96558630466461, 56.865407824516296, 52.8308717161417, 52.386930137872696, 51.291654109954834, 46.27959005534649, 48.606987968087196, 54.76567089557648, 56.5351827442646, 55.72588697075844, 52.242591083049774, 53.520527109503746, 65.6277984380722, 65.33218190073967, 68.64047437906265, 65.48443973064423, 69.65201810002327, 68.90024363994598, 70.63239589333534, 64.05488803982735, 64.0929239988327, 62.24976450204849, 63.345340713858604, 63.685038685798645, 64.56965401768684, 64.24695253372192, 63.1104601174593, 57.09097512066364, 63.0743620544672, 64.18120086193085, 65.83434775471687, 62.19140723347664, 53.75310502946377, 53.237468898296356, 54.33296151459217, 53.39180141687393, 52.62776121497154, 48.14597010612488, 50.047239884734154, 47.518931552767754, 47.5878294557333, 49.821079820394516, 48.620519042015076, 46.2077397108078, 47.10649788379669, 50.27582801878452, 46.88250370323658, 43.49685117602348, 42.37389363348484, 43.161021396517754, 44.12640519440174, 41.13526649773121, 44.18465606868267, 44.16036017239094, 46.02302402257919, 45.99760718643665, 44.23617370426655, 46.02702900767326, 41.632162034511566, 40.75389236211777, 41.60232223570347, 42.00635455548763, 39.0507173538208, 37.350612580776215, 41.23452477157116, 46.46397516131401, 47.69178427755833, 44.796662628650665, 43.14169563353062, 46.70248456299305, 48.51537488400936, 48.505731001496315, 47.71636135876179, 48.272742703557014, 44.27251115441322, 47.40467928349972, 45.65115697681904, 45.6920275837183, 50.49074828624725, 49.31908115744591, 51.88004873692989, 53.64547200500965, 50.84633320569992, 50.00469356775284, 50.61191238462925, 53.70190657675266, 55.983885526657104, 55.883111134171486, 54.75348114967346, 54.67769041657448, 53.64244356751442, 58.355209082365036, 57.017023488879204, 53.60796421766281, 57.27439507842064, 54.38240826129913, 56.48322053253651, 55.75748987495899, 61.94366432726383, 52.49469235539436, 56.66206553578377, 58.978968411684036, 58.19912485778332, 55.537538677453995, 55.521195754408836, 51.98935367166996, 44.533188566565514, 45.63854545354843, 60.243000984191895, 60.68653218448162, 60.0715009868145, 60.85118114948273, 49.494947120547295, 37.52786546945572, 26.705210208892822, 44.25814412534237, 28.93592420965433, 11.56837284564972, 0.17830748052801937, 0.09519567582174204, 0.13059850229183212, 0.017167881414934527, 0.04503378819208592, 0.11616499163210392, 0.06193019013153389, 0.0741395064687822, 0.1504609122639522, 0.3694720461498946, 19.402661360800266, 36.78245186805725, 16.818904504179955, 21.24559096992016, 7.828624919056892, 0.9750169340986758, 0.9050831117201596, 11.838279012590647, 4.729407671838999, 8.2620002143085, 4.220158997923136, 2.732307747937739, 0.5679638357833028, 1.1470803106203675, 1.017163738142699, 26.97370570152998, 5.180877596139908, 61.928256154060364, 30.602045506238937, 21.15036427974701, 2.107687764801085, 4.9053676798939705, 25.277030244469643, 33.77478785812855, 35.74790798127651, 36.86925061047077, 58.92245024442673, 38.678823709487915, 44.384358152747154, 68.58292266726494, 17.4659850820899, 0.07026876846794039, 0.14013793494086713, 0.24535237433155999, 0.13025652064243332, 0.821251772576943, 0.3135111427400261, 0.2835948730353266, 5.788121586665511, 1.7440204415470362, 1.089570396579802, 0.4135453765047714, 0.14467962639173493, 0.7008462678641081, 8.121768739074469, 20.037101916968822, 28.51505309343338, 50.29129318892956, 61.443793550133705, 64.5528057217598, 61.85374595224857, 58.06451328098774, 61.56935781240463, 55.99892891943455, 56.9918954372406, 60.62750995159149, 61.38409495353699, 64.22913148999214, 58.82307417690754, 57.94746816158295, 66.95443645119667, 65.58442756533623, 71.21973037719727, 66.5567421913147, 71.25941544771194, 71.44535467028618, 73.29523980617523, 69.68740180134773, 67.0712497830391, 65.22783949971199, 65.93802139163017, 65.77107354998589, 67.53905028104782, 65.34191697835922, 64.42011684179306, 62.910142466425896, 66.1995841562748, 68.45344081521034, 68.24788704514503, 65.95949783921242, 57.01091341674328, 57.57212050259113, 56.360061541199684, 56.610046327114105, 55.03151223063469, 50.879661217331886, 52.844440788030624, 51.17089658975601, 50.72624824941158, 50.73883697390556, 50.591936856508255, 48.07623244822025, 50.80722950398922, 57.75438912212849, 49.318169206380844, 45.72704650461674, 45.26871129870415, 45.07919266819954, 46.2930603325367, 43.00214432179928, 45.040480345487595, 45.08012741804123, 44.99477259814739, 44.59771670401096, 44.551522582769394, 43.21570426225662, 42.338859513401985, 40.653372555971146, 42.566273510456085, 41.71083681285381, 39.88631911575794, 40.924537405371666, 44.931137412786484, 47.35609509050846, 50.73662169277668, 47.06915348768234, 47.28993684053421, 49.61405172944069, 49.088988304138184, 50.91343380510807, 49.433181434869766, 49.67682056128979, 48.4244229644537, 49.25301790237427, 48.5180689394474, 48.36196951568127, 53.627004995942116, 52.86176025867462, 55.0890601426363, 57.16925472021103, 54.5148653537035, 51.67644806206226, 52.4136009067297, 57.144620642066, 59.73640076816082, 59.48520004749298, 58.96246589720249, 55.04257723689079, 57.205911353230476, 59.28100660443306, 60.57514116168022, 55.328424498438835, 61.02909900248051, 57.14028127491474, 60.30985839664936, 58.072888031601906, 62.8475446254015, 54.40833047032356, 57.554972022771835, 63.348315954208374, 62.402911484241486, 58.65501679480076, 57.6995200663805, 53.48853662610054, 48.62384386360645, 53.60228352248669, 68.63449349999428, 66.14176645874977, 67.73198112845421, 67.28910729289055, 63.45466464757919, 53.02811913192272, 45.020637810230255, 61.20092958211899, 40.17265275120735, 12.939157839864492, 0.3038050088798627, 0.17635907570365816, 0.054081585112726316, 0.03118413624179084, 0.07857895223423839, 0.03430473734624684, 0.07001603007665835, 0.055179306873469613, 0.16605802142294124, 0.16043104289565235, 27.299342527985573, 45.25936760008335, 27.733653523027897, 32.69799783825874, 20.386681258678436, 1.030803699977696, 1.0544858104549348, 22.033913768827915, 19.35780666768551, 29.24440685659647, 9.799772948026657, 5.440355697646737, 1.2711633648723364, 2.0333929639309645, 6.88856391236186, 52.108013704419136, 82.89440631866455, 133.0758512020111, 125.32560467720032, 37.06439293920994, 1.559836131054908, 2.3411681363359094, 46.51656433939934, 56.97932571172714, 61.28834009170532, 52.995209097862244, 71.7497107386589, 48.96627388894558, 64.49453204870224, 81.19687780737877, 23.603402450680733, 1.0555556905455887, 0.3008275124011561, 1.1836889712139964, 0.2161423026700504, 3.497831057757139, 2.2507272893562913, 21.88206821680069, 33.65008994936943, 13.871074933558702, 3.99436941370368, 2.1192588564008474, 0.1548104765242897, 1.576705682091415, 10.42038319632411, 25.000139102339745, 32.83585824072361, 57.293120473623276, 71.13841474056244, 72.53470301628113, 67.8106141090393, 65.58858454227448, 70.33314675092697, 67.5878244638443, 67.96845003962517, 69.69247072935104, 66.88476338982582, 72.11745500564575, 66.35640934109688, 59.515936598181725, 73.6247581243515, 73.03997710347176, 77.90885344147682, 70.7727375626564, 78.820720911026, 75.1784111559391, 77.33246996998787, 71.40555560588837, 71.68628454208374, 70.18012896180153, 68.6520029604435, 70.73315888643265, 70.88008940219879, 70.9147435426712, 68.38560685515404, 65.70066332817078, 69.12821620702744, 72.15228393673897, 71.94578021764755, 68.80930691957474, 60.43331757187843, 59.46593128144741, 60.44347442686558, 58.602644205093384, 58.00010293722153, 54.280220344662666, 58.00390273332596, 53.41608591377735, 53.915937691926956, 55.34961976110935, 54.00981925427914, 50.970248356461525, 54.109556302428246, 60.38021922111511, 53.334667682647705, 48.22927303612232, 48.61649505794048, 46.9572950899601, 49.251592978835106, 42.55289062857628, 46.58883646130562, 45.50300672650337, 45.98757952451706, 45.972817316651344, 46.49823032319546, 45.37322849035263, 42.40143075585365, 42.179199680686, 44.40145343542099, 44.385722279548645, 42.90022999048233, 41.13523989915848, 45.215388759970665, 49.42495867609978, 53.76444362103939, 50.46673737466335, 49.17951464653015, 53.19404482841492, 52.48301178216934, 54.30206537246704, 52.8903803229332, 53.96455608308315, 50.08542783558369, 51.10248506069183, 50.95459699630737, 49.71669562160969, 55.55930770933628, 54.853051006793976, 59.62492614984512, 58.40784765779972, 58.06950241327286, 55.51945924758911, 55.8222422003746, 61.10707461833954, 60.937968492507935, 61.22192345559597, 60.53282283246517, 56.53668366372585, 57.70812660455704, 64.87717911601067, 62.79980018734932, 58.43877799808979, 64.84446287155151, 58.484538942575455, 62.432348504662514, 59.18413460254669, 66.01365253329277, 57.98800438642502, 59.810914769768715, 68.90082880854607, 67.68576040863991, 60.155689269304276, 60.3805536031723, 61.754738464951515, 54.88438032567501, 56.86153583228588, 68.97562399506569, 68.16809132695198, 67.19272926449776, 68.22071850299835, 62.947984635829926, 57.07367464900017, 53.87555345892906, 79.49998766183853, 50.86690530180931, 24.081015922129154, 1.3387973606586456, 0.28093157219700515, 0.21922119136434048, 0.1361190271563828, 0.2806118252919987, 0.18534103670390323, 0.19154527253704146, 0.1956442283699289, 0.3571971313795075, 0.5202581675257534, 38.15516620874405, 52.03014828264713, 33.426460549235344, 44.14242513477802, 42.29912504553795, 1.0922225355170667, 1.548374283593148, 37.80322529375553, 44.04441699385643, 61.93747825920582, 34.15791369974613, 6.385743543505669, 0.9817027347162366, 2.153250644914806, 15.394812170416117], [5.9854506980627775, 25.467384830117226, 47.473869770765305, 53.587376922369, 4.604565845802426, 0.6585249106865376, 3.6878510238602757, 10.008728485554457, 6.244340306147933, 20.50765346735716, 39.0923935174942, 38.00997219979763, 28.78103692084551, 87.65561923384666, 52.74891011416912, 6.02605389431119, 0.3709944582078606, 0.16555442969547585, 0.12011811544653028, 0.037148847623029724, 0.46228601422626525, 0.29936221602838486, 0.07136592990718782, 1.3020629505626857, 0.6273541739210486, 0.9821105003356934, 0.21550703910179436, 0.12587321834871545, 0.0950511870905757, 1.7816233425401151, 7.5794618390500546, 17.67485797405243, 24.146549105644226, 27.563648745417595, 33.84089671075344, 44.15658317506313, 49.21297565102577, 50.53577587008476, 44.80151876807213, 47.23223693668842, 54.71015207469463, 53.58996458351612, 55.622004345059395, 51.51333041489124, 54.83670808374882, 65.9088845551014, 63.781690299510956, 67.69563987851143, 62.744117975234985, 63.24405334889889, 67.12885469198227, 66.65917709469795, 65.75947657227516, 61.98700860142708, 65.70258602499962, 63.61661955714226, 61.760244369506836, 62.56145417690277, 65.64191088080406, 62.78955973684788, 61.848798617720604, 64.39816921949387, 64.01673808693886, 66.56507134437561, 54.86748643219471, 55.24691887199879, 54.77857120335102, 56.20652697980404, 53.30814130604267, 50.76289728283882, 49.55246843397617, 48.34189899265766, 46.78237907588482, 47.76453897356987, 47.0153483748436, 47.26634010672569, 46.08223244547844, 46.84985965490341, 50.63811577856541, 45.08725203573704, 41.36553034186363, 43.42172920703888, 43.47203850746155, 42.94536016881466, 42.66090743243694, 43.31805557012558, 42.779255881905556, 43.799007162451744, 45.74436977505684, 40.63277766108513, 44.36440922319889, 39.12665627896786, 39.414076656103134, 36.61949001252651, 41.491751968860626, 38.66193361580372, 37.91560426354408, 42.21808299422264, 43.288021981716156, 44.96351547539234, 41.820001155138016, 43.66873495280743, 45.7907272875309, 47.18337915837765, 49.78998988866806, 44.81875844299793, 45.104845091700554, 44.91638660430908, 45.12627974152565, 46.039583534002304, 45.98867006599903, 46.557997316122055, 49.836187809705734, 51.41054593026638, 55.216330513358116, 57.28205166757107, 48.09498444199562, 46.70791067183018, 50.61126261949539, 55.18982693552971, 55.84302708506584, 56.11863769590855, 55.00600419938564, 55.41945241391659, 59.604981020092964, 55.52238129079342, 55.86345098912716, 57.00703002512455, 51.171645149588585, 53.413095474243164, 57.780045345425606, 57.33743369579315, 52.0813125371933, 55.364492163062096, 58.488536328077316, 59.22697350382805, 53.68369035422802, 51.227350160479546, 48.00293058156967, 39.964013546705246, 41.60337097942829, 62.73807629942894, 62.87111476063728, 59.431695118546486, 57.68229939043522, 51.90356567502022, 32.54298135638237, 41.2630308419466, 53.356638103723526, 10.332605056464672, 4.547028858214617, 0.4431057715555653, 0.08682611281983554, 0.14112448669038713, 0.08934272816986777, 0.012341764650045661, 0.06271446953178383, 0.08772460132604465, 0.2686166705098003, 0.062070923595456406, 0.19541003624908626, 16.829276047647, 25.729893743991852, 17.353507317602634, 21.148454882204533, 6.327806627377868, 0.5334685742855072, 1.0607250756584108, 18.653582856059074, 8.233477044850588, 12.982235178351402, 2.5050656916573644, 0.12177482654806226, 0.06789071951061487, 0.1350339181954041, 0.3530876222066581, 14.30571936070919, 15.20270112901926, 64.47066932916641, 32.29266598820686, 7.427018294110894, 1.2422766024246812, 7.314657373353839, 16.45504742860794, 25.678383708000183, 29.333671666681767, 49.216365069150925, 49.81895953416824, 38.0405605584383, 89.34303268790245, 61.58902555704117, 9.393361005932093, 0.3533109789714217, 0.08617744606453925, 0.07978331690537743, 0.1504830876365304, 1.522545525804162, 0.27424853236880153, 0.4079447442200035, 1.326768749859184, 0.21948156645521522, 0.529980183346197, 0.31327374454122037, 0.11200017761439085, 0.35717142338398844, 4.758599130436778, 12.263201661407948, 21.45757019519806, 27.76802647858858, 33.87062631547451, 39.16652753949165, 52.87079617381096, 61.29739120602608, 56.785923689603806, 53.72142992913723, 55.32855749130249, 63.678400442004204, 61.110046058893204, 63.5347643494606, 58.73265042901039, 59.762345775961876, 67.90514543652534, 67.41379380226135, 69.84383940696716, 66.96159526705742, 68.09584200382233, 69.13874924182892, 71.03679299354553, 67.91867271065712, 67.00058117508888, 68.16001296043396, 68.85723754763603, 67.60272726416588, 63.539422899484634, 66.4334388077259, 64.10478696227074, 66.85587733983994, 67.83925697207451, 68.46860960125923, 69.76929500699043, 58.8148932158947, 60.50272844731808, 56.783632412552834, 59.91707727313042, 54.19934168457985, 53.03990229964256, 52.59878396987915, 50.81224903464317, 51.12004391849041, 52.420706525444984, 49.88819941878319, 51.170315220952034, 49.6005130559206, 48.77709724009037, 52.800408750772476, 47.7119155973196, 47.46140643954277, 47.010055258870125, 45.280543863773346, 45.4959999024868, 45.31948037445545, 43.28400939702988, 43.75483073294163, 44.071243554353714, 44.973953515291214, 40.85158511996269, 42.84657306969166, 40.75171887874603, 41.0887835919857, 39.308997094631195, 43.51531818509102, 41.749161556363106, 40.195037350058556, 44.066623002290726, 46.3601191341877, 45.74908912181854, 45.08609689772129, 45.819107964634895, 47.516780868172646, 49.52037535607815, 50.59217244386673, 48.62757906317711, 48.66963900625706, 47.523221522569656, 48.922279849648476, 50.48730947077274, 51.38180047273636, 49.611133486032486, 52.94451601803303, 54.88233983516693, 56.12364582717419, 60.882692858576775, 53.01251336932182, 50.96098445355892, 54.13082756102085, 59.90381978452206, 58.74036401510239, 58.12516562640667, 55.95337316393852, 57.303075939416885, 61.73832714557648, 58.1923346221447, 58.424494564533234, 61.56078167259693, 54.998845383524895, 55.52761361002922, 59.822678938508034, 60.23328870534897, 52.92347654700279, 55.34898899495602, 62.18147076666355, 59.951822608709335, 57.92597271502018, 51.52573674917221, 51.30007825791836, 45.75339429080486, 49.820297062397, 70.1011312007904, 68.85048910975456, 65.98339855670929, 62.782533913850784, 62.47347369790077, 45.49112856388092, 56.05152189731598, 65.57492047548294, 10.908885933458805, 5.089681539684534, 0.3914443077519536, 0.16676534753059968, 0.19952591304900125, 0.12155167016317137, 0.061598053071065806, 0.07184980277088471, 0.1379763407749124, 0.06067673610232305, 0.20394875697093084, 0.24276024545542896, 22.804206535220146, 34.71852421760559, 23.72888121753931, 37.82572388648987, 6.24417026527226, 0.9724490437656641, 1.1220103246159852, 29.33409534394741, 22.420807108283043, 34.59424048662186, 5.607065577059984, 0.03564837716112379, 0.0631236303888727, 0.2066151748294942, 0.35552507266402245, 27.699215970933437, 81.8850588798523, 130.56765139102936, 133.23181003332138, 8.185431472957134, 1.2613256927579641, 7.848819410428405, 43.68923865258694, 48.51348638534546, 50.122540444135666, 63.250790387392044, 64.14576396346092, 53.39099206030369, 104.54101637005806, 72.55067735910416, 16.363744027912617, 0.8287868869956583, 0.2794877387350425, 0.4757203417830169, 0.2352101099677384, 1.4279328589327633, 0.8872939506545663, 2.972912024706602, 5.227951370179653, 1.6279189777560532, 2.9672816768288612, 0.7645203417632729, 0.48065951268654317, 0.47480257228016853, 5.185737060382962, 17.372956573963165, 35.207922756671906, 41.52443781495094, 50.22295005619526, 51.03512227535248, 66.48035109043121, 68.83212089538574, 66.5752699971199, 65.08913174271584, 66.49226725101471, 69.13963079452515, 67.70998030900955, 74.16116774082184, 66.6407860815525, 63.11724655330181, 73.05516108870506, 72.79917642474174, 74.37703415751457, 70.46901226043701, 71.66207984089851, 73.67952078580856, 73.9532732963562, 71.71423584222794, 68.89928609132767, 73.32851842045784, 70.94255045056343, 69.52056795358658, 66.00281551480293, 71.19658961892128, 69.02753680944443, 69.34235751628876, 68.97562399506569, 69.71267804503441, 72.76069208979607, 63.8297501206398, 63.97969767451286, 58.66432249546051, 61.89694203436375, 59.22510400414467, 58.88003692030907, 57.012402936816216, 54.18529763817787, 52.773722782731056, 55.36214388906956, 51.313563734292984, 52.56724186241627, 52.244521379470825, 53.03446479141712, 56.80806890130043, 51.07948109507561, 48.642223477363586, 51.37491524219513, 48.38868968188763, 46.236838549375534, 44.23272728919983, 43.83578918874264, 43.79048801958561, 45.52683524787426, 48.134992495179176, 42.347382456064224, 44.88075211644173, 40.51459640264511, 41.28810189664364, 39.74021315574646, 45.53539998829365, 43.68298038840294, 41.45208589732647, 47.0684315264225, 49.11270283162594, 47.9340934753418, 48.552354499697685, 49.600687846541405, 50.46441949903965, 53.698608353734016, 56.600296050310135, 52.35063448548317, 51.9239591807127, 48.23734000325203, 51.65019527077675, 53.15890431404114, 50.87782971560955, 50.24614781141281, 54.86504316329956, 58.74692626297474, 60.52515484392643, 62.94014185667038, 54.34530705213547, 56.67456306517124, 57.480454221367836, 62.39051274955273, 60.318282544612885, 61.67298585176468, 58.039537221193314, 60.18146328628063, 63.045776188373566, 62.3098848760128, 62.167084738612175, 64.87869143486023, 56.12850196659565, 59.73659075796604, 60.319988653063774, 63.76450762152672, 55.11698864400387, 60.590948313474655, 65.22910103201866, 65.27262389659882, 61.20600610971451, 57.44143791496754, 55.30122935771942, 49.86809469759464, 57.5016874819994, 71.87469363212585, 71.29292964935303, 68.50652396678925, 65.6326013803482, 67.31809213757515, 53.49933944642544, 71.83538094162941, 71.74494579434395, 18.893773667514324, 13.026899881660938, 0.44076263322494924, 0.3635872603626922, 0.5805057752877474, 0.19884586828993633, 0.18460058112395927, 0.16852517263032496, 0.5153857008554041, 0.4501382145099342, 0.38127542997244745, 0.5872413294855505, 34.60338659584522, 44.300819635391235, 30.480491928756237, 49.6966402977705, 25.277852900326252, 1.0125203873030841, 1.5252376813441515, 47.546647265553474, 50.06084695458412, 61.29548370838165, 20.150476433336735, 0.6238456559367478, 0.18542022386100143, 0.33678242994938046, 0.533281434327364], [2.7277539297938347, 17.422403320670128, 40.32467499375343, 21.851949132978916, 0.9515344316605479, 0.6498129875399172, 13.945353347808123, 14.154623318463564, 8.207929115742445, 23.16297948360443, 47.590553909540176, 32.34667249023914, 49.01366874575615, 70.8270138502121, 36.70467384159565, 2.8214711509644985, 0.183770518633537, 0.41078417154494673, 0.22796698613092303, 0.17439078132156283, 0.6785132631193846, 0.015358670098066796, 0.03952002429286949, 0.28519630897790194, 0.11426756493165158, 0.3440874785883352, 0.12238511684699915, 0.07869062319514342, 0.15840024483622983, 0.5929054005537182, 6.222905181348324, 11.00439665839076, 10.76015716418624, 16.804942153394222, 21.604538708925247, 24.381458200514317, 36.01938061416149, 37.75203824043274, 44.19165149331093, 44.20549035072327, 55.304386988282204, 54.70345303416252, 53.367972895503044, 48.67624685168266, 56.42853386700153, 63.756786435842514, 63.255353942513466, 62.51065470278263, 69.34022963047028, 67.20273792743683, 66.8721404671669, 66.1352764070034, 63.58090527355671, 63.57795663177967, 62.88909159600735, 65.37712588906288, 64.60539489984512, 63.055028691887856, 63.741917833685875, 61.62149481475353, 66.73140361905098, 63.47217410802841, 65.65724685788155, 57.70047761499882, 54.527579471468925, 56.626887023448944, 56.10142461955547, 56.03911556303501, 52.23428852856159, 47.22768098115921, 46.66435360908508, 46.291840597987175, 46.84057295322418, 47.75634281337261, 48.26815254986286, 46.85888037085533, 46.17791511118412, 46.39478087425232, 45.23936167359352, 44.36950474977493, 41.70464314520359, 41.812720745801926, 44.55861680209637, 43.47623348236084, 43.46375875174999, 43.27209323644638, 43.784909918904305, 43.00394922494888, 40.59077471494675, 41.10255025327206, 40.12259043753147, 39.51551601290703, 38.25540862977505, 38.24489839375019, 41.1259113997221, 38.278541788458824, 38.282717764377594, 40.620948895812035, 42.623992413282394, 42.652110904455185, 44.28098849952221, 44.77403484284878, 45.64468212425709, 45.1604513078928, 47.4907560646534, 45.92597723007202, 44.7013333439827, 44.92275506258011, 44.204316213727, 44.620382487773895, 48.620416447520256, 49.755495339632034, 52.945800349116325, 53.38026903569698, 53.45164440572262, 56.71574905514717, 57.1612561494112, 47.00401358306408, 48.16113889217377, 55.481465086340904, 53.268004059791565, 52.34477899968624, 54.98080015182495, 56.47523336112499, 57.222083285450935, 54.91006314754486, 55.66830866038799, 53.89511480927467, 53.205653205513954, 55.02433441579342, 49.462018087506294, 55.13706296682358, 51.75146743655205, 51.58323526382446, 60.23870341479778, 53.89011047780514, 56.6628634929657, 45.63165262341499, 44.77154217660427, 33.861772790551186, 34.51797857880592, 59.658474549651146, 66.77597522735596, 58.76626342535019, 57.64528177678585, 45.94075083732605, 32.10607320070267, 48.17674085497856, 44.17922995984554, 3.2553247455507517, 0.40648775990121067, 0.16099350177682936, 0.017849649811978452, 0.02670470541488612, 0.07401983515592292, 0.03411730795050971, 0.030164419767970685, 0.04741089833260048, 0.01257084801181918, 0.061807565070921555, 0.24113317573210225, 20.515378452837467, 20.163705423474312, 16.397488117218018, 14.932098649442196, 4.350887183099985, 0.25134404422715306, 0.5076285952236503, 15.11643910780549, 12.231710851192474, 19.37415149062872, 5.30150449834764, 0.1368008679128252, 0.014550859050359577, 0.13091021915897727, 0.24670039652846754, 1.8548273644410074, 12.264739628881216, 47.62098267674446, 35.882926136255264, 0.9395320632029325, 0.31224450445733964, 22.24203620105982, 22.466516755521297, 20.866331420838833, 35.861343294382095, 58.87852840125561, 44.90519240498543, 57.60404258966446, 82.61221066117287, 49.00893799960613, 4.0696466993540525, 0.5339319712948054, 0.1148951101640705, 0.48199128184933215, 0.24202878470532596, 0.22295581205980852, 0.07195085359853692, 0.18492308881832287, 0.26758781634271145, 0.327145226765424, 0.40220295544713736, 0.2117362164426595, 0.11711934901541099, 0.2726499759592116, 1.7041367129422724, 10.903401877731085, 23.828264884650707, 15.779038053005934, 21.264270767569542, 25.30111525207758, 25.651399455964565, 42.984023094177246, 51.736089661717415, 49.31678608059883, 52.24511034786701, 62.38188721239567, 63.9219331741333, 58.862060084939, 57.31017775833607, 58.264876529574394, 69.53651189804077, 66.67523503303528, 67.60876893997192, 70.74638977646828, 70.64061865210533, 72.38900363445282, 68.23115274310112, 65.19529044628143, 68.45262005925179, 65.68538814783096, 70.13374105095863, 67.27960780262947, 65.53364709019661, 64.59129005670547, 64.94634300470352, 69.3549120426178, 66.20459988713264, 66.69415041804314, 61.725350841879845, 58.33977431058884, 59.54146362841129, 59.91523437201977, 55.88323272764683, 55.54240241646767, 51.457781195640564, 49.066257923841476, 49.90326181054115, 49.99184265732765, 49.88572955131531, 50.79085238277912, 49.738552048802376, 46.977384611964226, 47.1564120054245, 48.049592077732086, 47.326677069067955, 43.380281031131744, 45.49323745071888, 44.888150319457054, 43.14647577702999, 44.488187581300735, 42.98670195043087, 42.66921378672123, 41.77281528711319, 38.96036960184574, 41.3177365064621, 39.89564761519432, 40.56326039135456, 40.16711264848709, 39.44771245121956, 42.313317283988, 42.16937340795994, 40.14891542494297, 44.585044384002686, 45.46742543578148, 43.62033694982529, 45.1481019705534, 47.399180978536606, 47.42010645568371, 48.56541059911251, 48.188748210668564, 48.35279680788517, 48.13221484422684, 47.38226808607578, 47.93635055422783, 46.2460682541132, 50.85504613816738, 53.13063383102417, 54.5014862716198, 55.000448897480965, 55.03331333398819, 61.384186148643494, 60.658246502280235, 53.88048939406872, 50.22536292672157, 57.26654089987278, 57.51767322421074, 55.714377388358116, 57.07907795906067, 59.69229653477669, 58.96286867558956, 57.956428080797195, 60.67395865917206, 57.29341685771942, 55.74732542037964, 58.09374511241913, 50.59580124914646, 58.91243778169155, 51.603301987051964, 53.08489568531513, 63.22068080306053, 58.94769988954067, 57.82393679022789, 48.09907682240009, 46.28962531685829, 40.810615718364716, 45.18820121884346, 66.76800325512886, 72.74515092372894, 66.77340656518936, 65.41906043887138, 57.22681403160095, 46.026823818683624, 59.7487311065197, 55.68008802831173, 4.05685231089592, 0.3864498023176566, 0.13545749156037346, 0.08010548321180977, 0.04162272532994393, 0.04900920612271875, 0.057454675988992676, 0.0105657356834854, 0.008705284635652788, 0.0907571057905443, 0.10065187132568099, 0.3117434657178819, 28.34661953151226, 26.103947572410107, 17.043470554053783, 31.40245545655489, 3.390134386718273, 0.6902160414028913, 1.071069783065468, 24.36234712600708, 27.679690718650818, 40.95605671405792, 26.552002429962158, 0.65816814545542, 0.3009926254162565, 0.2244164329022169, 0.2086473532835953, 5.756143452599645, 54.3486774712801, 87.6266647875309, 47.91222184896469, 0.6507076020352542, 0.5079483718145639, 28.528570868074894, 45.39990685880184, 40.687604919075966, 59.66351307928562, 72.87080258131027, 55.81495799124241, 72.5694939494133, 91.93941056728363, 58.95205445587635, 8.175215721130371, 0.7479912287089974, 0.6620517745614052, 0.6838265061378479, 0.4149462247733027, 1.4478162419982255, 0.24758401239523664, 0.2601455891272053, 1.5253215143457055, 0.8364516100846231, 1.3653633976355195, 0.4120541940210387, 0.23408252047374845, 0.5246309610083699, 2.2676216578111053, 16.992355696856976, 30.131203271448612, 20.1534041762352, 31.040906757116318, 39.98452864587307, 42.16398909687996, 56.939101070165634, 63.855315148830414, 62.02420860528946, 62.53862500190735, 69.6584701538086, 69.93714720010757, 69.81655687093735, 67.76474297046661, 66.32305473089218, 72.83400535583496, 71.64416000247002, 70.47149732708931, 75.3599426150322, 73.00266310572624, 74.67605531215668, 71.86087757349014, 66.69501677155495, 69.97809380292892, 65.98352774977684, 70.54345026612282, 72.09507420659065, 69.72660049796104, 70.29840141534805, 69.29457128047943, 72.57761031389236, 69.15169134736061, 69.86379593610764, 63.460060358047485, 60.92748485505581, 63.12027499079704, 61.71926736831665, 60.3781521320343, 59.29691255092621, 55.02683088183403, 52.03443065285683, 55.00970520079136, 53.349399492144585, 52.82442346215248, 54.30933058261871, 51.05286352336407, 51.68371707201004, 52.07475408911705, 51.48364640772343, 50.97366437315941, 48.57164606451988, 48.10094252228737, 48.18394526839256, 45.9278467297554, 46.57337129116058, 42.760116308927536, 44.85600024461746, 42.63326771557331, 40.37720337510109, 40.872947573661804, 39.81855735182762, 41.03668078780174, 39.54926960170269, 39.76867362856865, 44.063689559698105, 42.91957475244999, 42.6175631582737, 47.24157303571701, 48.83502133190632, 46.637618243694305, 49.51703913509846, 51.975233629345894, 50.32486438751221, 53.03500056266785, 55.13316437602043, 53.566265255212784, 50.8831874281168, 50.023076981306076, 50.62071271240711, 48.61869513988495, 54.20726805925369, 53.86398687958717, 58.620275259017944, 58.611110150814056, 58.54616403579712, 65.39310023188591, 64.19183269143105, 56.47859998047352, 55.01966826617718, 58.74139755964279, 58.35480250418186, 57.7089549601078, 59.646717980504036, 61.773714646697044, 62.857686281204224, 63.799997717142105, 61.7961448431015, 59.20470669865608, 57.752234637737274, 61.154629066586494, 53.18071894347668, 62.98958100378513, 54.734482169151306, 57.712925747036934, 69.35814186930656, 63.17478686571121, 59.162973538041115, 53.203947097063065, 51.582080125808716, 46.92356429994106, 54.21056628227234, 70.30112206935883, 69.62422639131546, 69.28766325116158, 69.41253215074539, 66.75761461257935, 59.19433705508709, 76.86474546790123, 62.79749371111393, 10.312507934868336, 0.610526183154434, 0.2612966008018702, 0.1246391751919873, 0.1422284313593991, 0.17076746793463826, 0.17824003414716572, 0.11985767356236465, 0.23536737106041983, 0.13291915354784578, 0.3218744939658791, 0.5748566659167409, 35.94525799155235, 38.18644233047962, 29.448026530444622, 49.88214634358883, 16.395025849342346, 1.9681413215585053, 1.8704420328140259, 42.92134925723076, 54.86775241792202, 59.498829916119576, 42.710183188319206, 0.38419325777795166, 0.6311005947645754, 0.3514489304507151, 0.5065280792769045], [1.675054260995239, 13.450396656990051, 21.395637318491936, 7.529884949326515, 0.758329761447385, 9.086908400058746, 28.776731751859188, 6.476947674527764, 14.984675478190184, 29.710508845746517, 46.391938626766205, 38.072121664881706, 42.922040820121765, 34.13212448358536, 35.08600629866123, 0.9022007288876921, 0.31876854656729847, 0.35632872954010963, 0.08182980396668427, 0.31222927558701485, 1.8524176999926567, 0.03525492757034954, 0.06352699507260695, 0.049092374902102165, 0.18960132059874013, 0.031224638951243833, 0.05448733580124099, 0.06228593862033449, 0.36840759858023375, 2.2827315470203757, 6.869928762316704, 5.404105642810464, 1.45421082386747, 5.248517766594887, 16.032663993537426, 27.158377692103386, 22.07391992211342, 27.151971235871315, 40.16944572329521, 42.99128070473671, 54.05653014779091, 53.23153741657734, 45.727703869342804, 45.15565976500511, 50.506091862916946, 62.52277985215187, 57.382731065154076, 63.880484998226166, 63.65696959197521, 64.33720529079437, 65.08973971009254, 66.84956207871437, 60.48248313367367, 67.64109760522842, 64.6657432615757, 67.51771062612534, 63.125731498003006, 62.26412013173103, 61.53088867664337, 65.74760600924492, 66.68514490127563, 68.39512154459953, 62.70488888025284, 54.76926930248737, 57.03746259212494, 58.34988176822662, 57.343532368540764, 51.06559284031391, 49.50942054390907, 47.90788248181343, 47.03021697700024, 46.87923587858677, 46.16180017590523, 47.76049979031086, 46.83373712003231, 48.10646362602711, 45.95497727394104, 42.297646924853325, 45.11607348918915, 44.382549449801445, 42.18942113220692, 42.80593045055866, 44.83444780111313, 41.280536502599716, 43.520417511463165, 42.95702934265137, 40.42591296136379, 43.562032878398895, 40.84805890917778, 42.25579597055912, 38.704882711172104, 38.58856715261936, 38.92820052802563, 40.844984874129295, 42.00024448335171, 38.84639471769333, 37.45097279548645, 39.378369972109795, 39.654679745435715, 38.33258628845215, 42.67240181565285, 45.04181407392025, 42.65553832054138, 44.937236085534096, 45.44091425836086, 44.40434888005257, 44.00822013616562, 44.65231977403164, 42.23669059574604, 43.65852490067482, 45.07586784660816, 50.19616909325123, 52.375720739364624, 53.36972080171108, 53.00168015062809, 55.074829906225204, 55.012634843587875, 54.61151696741581, 47.89137236773968, 52.889726758003235, 54.647022262215614, 55.62109239399433, 55.05901135504246, 56.13830544054508, 52.82976597547531, 55.77112354338169, 53.0189274251461, 51.09324015676975, 51.09370373189449, 50.68676836788654, 46.95462003350258, 51.774763986468315, 46.362003833055496, 46.46282002329826, 54.79195028543472, 52.426907792687416, 51.80740423500538, 41.606179028749466, 38.001616448163986, 35.26538327336311, 30.92076290398836, 31.4028924331069, 66.56099036335945, 48.763467371463776, 53.08842569589615, 26.062928773462772, 35.23197926580906, 62.37386964261532, 36.797350868582726, 2.403191733174026, 0.5173010949511081, 0.09583675040630624, 0.30935179092921317, 0.06047216309525538, 0.063662785833003, 0.08293353341287002, 0.04812615799892228, 0.1202763784385752, 0.06880831831949763, 0.15215532446745783, 0.7369764510076493, 27.10271257907152, 21.891909688711166, 19.875048212707043, 16.708851009607315, 6.304240291938186, 0.3402952227042988, 0.13138743495801464, 8.389212638139725, 16.016739048063755, 22.51881904900074, 34.81968618929386, 7.565719876438379, 0.22066049772547558, 0.07552035385742784, 0.03001445955305826, 3.469813261181116, 16.357303373515606, 31.17335245013237, 14.375063739717007, 0.6197304173838347, 12.106061093509197, 52.94880598783493, 22.462390176951885, 26.13963905721903, 40.51511697471142, 59.10500004887581, 46.040039509534836, 49.95313413441181, 45.15923537313938, 46.27879589796066, 2.250071349553764, 0.49155652639456093, 0.1979203210794367, 0.2848159137647599, 0.20008408231660724, 0.8199653041083366, 0.11955843219766393, 0.06635892670601606, 0.07843231127480976, 0.16097379033453763, 0.13898284145398065, 0.05493527387443464, 0.005813455190946115, 0.11011830632924102, 1.6025532013736665, 10.503072459250689, 12.963114604353905, 5.705354902893305, 11.881959568709135, 26.570494137704372, 32.80696079134941, 26.439895145595074, 37.25310601294041, 49.30892810225487, 52.659466713666916, 59.64315377175808, 57.39354908466339, 55.39466254413128, 53.965278044342995, 57.26912476122379, 65.881617218256, 64.9813087284565, 66.28058061003685, 65.87329566478729, 66.21866673231125, 69.68931689858437, 67.72047534584999, 64.72995221614838, 69.30198848247528, 67.62263059616089, 70.70240333676338, 65.79039171338081, 64.58116739988327, 63.74644339084625, 68.81990075111389, 67.97273620963097, 70.7481224834919, 62.32578702270985, 57.82091975212097, 61.80359244346619, 61.81618116796017, 58.66440609097481, 54.15293477475643, 54.653831496834755, 50.294883996248245, 51.44819810986519, 49.73197840154171, 49.810573384165764, 50.474139377474785, 49.66750346124172, 52.13900484144688, 49.29069668054581, 44.91767853498459, 47.881644889712334, 46.72581531107426, 46.86364531517029, 46.7066415399313, 46.142478212714195, 42.54771530628204, 44.44029115140438, 42.93329581618309, 41.26773878931999, 45.391763895750046, 41.497831642627716, 40.6022235006094, 38.69070567190647, 39.64765012264252, 40.496798157691956, 41.450349390506744, 42.3497611284256, 42.49227248132229, 39.594285786151886, 42.785730734467506, 42.46134214103222, 42.8418081253767, 44.24423687160015, 47.05693334341049, 45.342643931508064, 46.3507754355669, 48.468018025159836, 48.23555789887905, 46.12234689295292, 46.14274799823761, 46.66943773627281, 46.61846347153187, 49.11611884832382, 52.33157470822334, 54.82191167771816, 55.23242264986038, 56.47372484207153, 57.07811661064625, 58.33522215485573, 57.881351709365845, 51.47794671356678, 54.37095187604427, 57.564292922616005, 55.50295293331146, 58.29105332493782, 59.37804579734802, 56.163433492183685, 58.4347578138113, 56.092764884233475, 55.77494613826275, 54.86545734107494, 52.09447123110294, 50.09888671338558, 54.66543987393379, 46.1573202162981, 48.41836988925934, 60.0770752876997, 55.64642183482647, 52.61101171374321, 44.64574232697487, 43.466084226965904, 41.020474657416344, 38.529195338487625, 39.98496562242508, 66.6975474357605, 51.50395631790161, 59.92313414812088, 32.368403524160385, 45.38204401731491, 73.88504415750504, 38.59599955379963, 3.2952869636937976, 0.5341555655468255, 0.10425878324895166, 0.14955100952647626, 0.040037846702034585, 0.05074574633908924, 0.08571798243792728, 0.07697516368352808, 0.049009335998562165, 0.1402745197992772, 0.15985047561116517, 0.8370594587177038, 33.63783560693264, 26.576421819627285, 24.388850703835487, 36.97484314441681, 2.5799354491755366, 0.6712346943095326, 0.15664867241866887, 12.674609385430813, 35.11508993804455, 38.03643397986889, 68.68522837758064, 15.730158425867558, 0.4737795959226787, 0.06577708292752504, 0.16613094485364854, 4.737207228317857, 28.127962164580822, 40.63030019402504, 9.668501392006874, 0.7175286195706576, 13.422193620353937, 78.85249480605125, 36.06813959777355, 53.66905353963375, 59.5715656131506, 72.72052824497223, 60.77092185616493, 67.21429690718651, 54.47698138654232, 57.30467565357685, 4.955469416454434, 0.7120084064081311, 0.9011553099844605, 0.20791529881535098, 0.8643766085151583, 5.545725468546152, 0.26338996191043407, 0.2472264159587212, 0.1672460068948567, 0.4814480000641197, 0.5281439318787307, 0.22608565661357716, 0.12621613510418683, 0.4314384679310024, 5.717975925654173, 14.617549628019333, 12.352155838161707, 6.038354309275746, 14.380193464457989, 36.60616412758827, 46.39914683997631, 42.238537296652794, 51.794933304190636, 60.21069511771202, 62.1529570966959, 68.86799857020378, 67.4458184838295, 64.11863341927528, 64.36268672347069, 60.55251717567444, 71.87745228409767, 66.90774455666542, 72.05871015787125, 70.6964984536171, 69.50770944356918, 72.73214042186737, 71.72951102256775, 66.80123627185822, 72.03653454780579, 70.96563041210175, 70.97874730825424, 69.10822167992592, 66.7710354924202, 68.47275897860527, 71.2719851732254, 71.94731533527374, 73.48453804850578, 67.03082755208015, 60.077329874038696, 63.02837312221527, 63.64622376859188, 61.71050883829594, 58.573138788342476, 57.10416421294212, 52.8485331684351, 56.08818233013153, 53.027024790644646, 52.767111137509346, 53.696051090955734, 52.55610466003418, 55.63672095537186, 51.840261071920395, 48.18969815969467, 51.006684601306915, 48.497789427638054, 49.485592022538185, 49.98522721230984, 48.752596154809, 43.58743831515312, 45.51502168178558, 41.84395506978035, 42.223224118351936, 45.949741154909134, 41.82880148291588, 42.36291982233524, 41.07241027057171, 40.28655543923378, 41.1014749109745, 43.03692385554314, 44.45628449320793, 43.84302780032158, 42.232750207185745, 45.978828594088554, 43.91296684741974, 45.775615498423576, 47.12643541395664, 50.330522283911705, 49.15152534842491, 50.256715044379234, 51.07206769287586, 49.85797204077244, 49.9665854126215, 49.212018102407455, 48.83922390639782, 48.18609215319157, 51.18127003312111, 55.41264317929745, 56.683587580919266, 57.744612246751785, 59.799192398786545, 60.133889839053154, 63.21333959698677, 61.549834460020065, 56.65170729160309, 58.472713977098465, 60.512132942676544, 57.079210951924324, 57.420649230480194, 60.64038746058941, 58.432341143488884, 61.97215899825096, 62.65570431947708, 55.86732678115368, 56.663425862789154, 54.30855542421341, 53.168867379426956, 57.11773328483105, 50.56169427931309, 50.103150084614754, 64.23545435070992, 58.060443699359894, 62.433967217803, 47.36713729798794, 46.589417830109596, 47.36345909535885, 50.92196814715862, 60.753970965743065, 81.79499611258507, 63.3775781840086, 73.27950865030289, 50.450352653861046, 68.89727219939232, 85.34479603171349, 37.2439257055521, 4.256956223398447, 0.4944747994886711, 0.21220137976342812, 0.5831463960930705, 0.15663213736843318, 0.16071826888946816, 0.1413979532662779, 0.10586863514618017, 0.15573517768643796, 0.23239506961544976, 0.3359438624465838, 1.1946491268463433, 44.87149201333523, 37.39440903067589, 36.06328345835209, 57.66912929713726, 10.035249162465334, 2.394445315003395, 0.7260205107741058, 28.27422771602869, 55.59327028691769, 51.830905973911285, 86.2982788681984, 13.540440425276756, 1.0252386610955, 0.19629298418294638, 0.37118845561053604], [1.5629194281063974, 9.068848919123411, 11.951051261276007, 1.2602799176238477, 0.3731216018786654, 26.542276851832867, 22.488939352333546, 5.911936992779374, 17.017687037587166, 39.56959471106529, 44.64829199016094, 52.61085972189903, 99.62126836180687, 49.005818367004395, 36.29067845642567, 1.062064147554338, 0.33522513695061207, 0.26477748120669276, 1.28221400314942, 0.16296381480060518, 0.04657726611185353, 0.01687588341155788, 0.0867841592116747, 0.01043224465320236, 0.021751244457846042, 0.10932750345091335, 0.27012584265321493, 0.13072983274469152, 0.7393383211456239, 4.949436765164137, 4.931784812361002, 1.4836524752900004, 0.46022011258173734, 1.8147575645707548, 7.8574093244969845, 16.806539967656136, 23.70025545358658, 14.900513794273138, 28.29426024109125, 38.216217532753944, 46.74378074705601, 48.942422568798065, 43.855073153972626, 41.32314741611481, 49.70415249466896, 61.81039787828922, 59.81592670083046, 62.00909301638603, 63.03587771952152, 64.2016589641571, 65.74679285287857, 60.272825583815575, 67.99123361706734, 64.47066932916641, 67.06263944506645, 68.76456812024117, 62.96474553644657, 64.50485229492188, 64.48116436600685, 63.54965955018997, 66.94825038313866, 64.37738433480263, 55.75306311249733, 62.24915273487568, 60.8141103386879, 55.904667377471924, 53.714008927345276, 50.09866252541542, 48.07145230472088, 48.33257429301739, 49.27553929388523, 46.662829890847206, 45.298258513212204, 45.70576384663582, 48.16925905644894, 48.19977141916752, 47.75652900338173, 41.92545689642429, 43.55681195855141, 44.174377620220184, 44.58879858255386, 41.72103926539421, 47.76100896298885, 43.68999861180782, 43.872506618499756, 45.068298652768135, 43.23534160852432, 44.40895043313503, 44.905842170119286, 40.31999744474888, 38.64954628050327, 39.708747044205666, 38.37243475019932, 40.28104193508625, 44.55808103084564, 40.94342239201069, 38.096577152609825, 38.79985861480236, 38.81351128220558, 39.231211468577385, 43.49122367799282, 46.3957916200161, 44.46665793657303, 44.62282955646515, 46.7609254270792, 46.99607200920582, 45.879228338599205, 44.38833273947239, 42.62379862368107, 43.41439180076122, 44.0443941950798, 45.55255226790905, 50.7382670044899, 55.344003662467, 57.281208112835884, 53.96886885166168, 54.07605729997158, 56.73906460404396, 52.17645563185215, 50.27526184916496, 53.89061585068703, 54.22650262713432, 55.17254926264286, 52.17485211789608, 55.26248663663864, 55.91156020760536, 52.80794374644756, 53.058897480368614, 53.40312860906124, 51.000346541404724, 49.704414680600166, 49.29695874452591, 38.44063349068165, 40.72267323732376, 51.17044821381569, 42.8267989307642, 42.796970531344414, 39.90613505244255, 26.592567153275013, 25.88301792740822, 30.171046033501625, 10.370894651859999, 14.631634522229433, 33.03498275578022, 33.51883739233017, 22.257144190371037, 45.37874199450016, 38.15705470740795, 3.5025881649926305, 0.046847040503052995, 0.04061092571646441, 0.19157443894073367, 0.10294694075128064, 0.04893557765171863, 0.07577575655886903, 0.23286508658202365, 0.05503888882230967, 0.032908419889281504, 0.03651592924143188, 0.3560256364289671, 1.1554011516273022, 29.34913493692875, 22.768068574368954, 17.714463248848915, 11.406495831906796, 3.777660154737532, 1.1086712591350079, 0.3972236788831651, 4.83591073192656, 22.344790287315845, 22.679464928805828, 59.165701791644096, 28.426597639918327, 0.18392516736639664, 0.09605190643924288, 0.09470261516980827, 3.4006809582933784, 15.946150235831738, 22.277670688927174, 3.601036132313311, 1.5523607446812093, 36.911280155181885, 40.1205575466156, 15.896496400237083, 23.435673750936985, 50.0923852622509, 57.57937051355839, 61.04738362133503, 101.5314182639122, 59.13400009274483, 46.439607068896294, 2.801711023785174, 0.34067116503138095, 0.029113720484019723, 0.7652078079991043, 0.2628726849798113, 0.10167544140131213, 0.015299324259103741, 0.029597806715173647, 0.11046097075450234, 0.05526090601051692, 0.04232819606841076, 0.1895517748198472, 0.13030296424403787, 0.4197259229840711, 4.802495799958706, 7.227254938334227, 6.156199285760522, 1.6144890733994544, 4.588670348748565, 17.202919498085976, 28.024839498102665, 27.412065379321575, 20.24884555488825, 43.87084610760212, 46.15432597696781, 55.9189660102129, 54.35806296765804, 53.454976826906204, 52.12995372712612, 56.08479291200638, 65.28403088450432, 62.99631804227829, 67.02841088175774, 66.14294439554214, 66.2078221142292, 68.35671320557594, 64.30648773908615, 68.43327149748802, 67.4092036485672, 68.3827418088913, 69.39533427357674, 64.67689946293831, 65.5573882162571, 66.01203382015228, 67.59929984807968, 67.97120109200478, 65.8842770755291, 59.794484451413155, 65.559022128582, 64.7022745013237, 58.62828902900219, 56.43789276480675, 53.27877648174763, 51.58565953373909, 51.07300244271755, 50.99514462053776, 49.522662833333015, 46.231986209750175, 49.266556575894356, 48.154132068157196, 51.48133613169193, 49.417959451675415, 48.02302770316601, 45.140775963664055, 47.18309797346592, 46.599973663687706, 43.37735898792744, 47.18348175287247, 44.59175102412701, 44.41249944269657, 45.59345707297325, 44.20344986021519, 43.72982047498226, 45.91718070209026, 42.042836397886276, 39.70648996531963, 39.91547875106335, 38.457789570093155, 40.04928857088089, 44.61503617465496, 44.74047504365444, 38.592693731188774, 41.09247699379921, 43.61604318022728, 43.97372558712959, 45.004378482699394, 48.034396693110466, 46.21890731155872, 47.941955253481865, 47.399686351418495, 50.70257931947708, 50.22622548043728, 45.182623118162155, 46.10047906637192, 46.177386939525604, 46.77468828856945, 49.45602960884571, 52.81947232782841, 57.21492066979408, 58.067921698093414, 58.45029518008232, 58.024292439222336, 59.740702137351036, 55.598791390657425, 51.28965921700001, 56.21601887047291, 55.52942231297493, 56.78502693772316, 56.038431599736214, 55.006064996123314, 59.67645138502121, 55.43206013739109, 59.53122317790985, 54.9287923425436, 54.472216442227364, 52.694067656993866, 52.23287120461464, 42.14752458035946, 43.94571729004383, 54.41898509860039, 48.17315764725208, 46.63225293159485, 43.82562093436718, 29.384395144879818, 24.386002756655216, 39.33748796582222, 18.37761126458645, 29.498449824750423, 45.00811368227005, 43.300181329250336, 33.847075179219246, 51.40534780919552, 35.96070796251297, 1.9802625523880124, 0.057351127834408544, 0.06732346635544673, 0.059172376786591485, 0.023047746763040777, 0.05724459624616429, 0.03363364659890067, 0.028991755934839603, 0.03962036265875213, 0.029765279759885743, 0.3276358457515016, 0.43240305210929364, 2.113909930922091, 37.9197346419096, 29.072239995002747, 22.977355644106865, 30.440829657018185, 3.4387603774666786, 2.2540701599791646, 0.2411165219382383, 4.070697342976928, 41.308499202132225, 37.497128918766975, 77.36640214920044, 46.497037187218666, 0.8042729774024338, 0.12674433644860983, 0.030422178788285237, 5.70290450938046, 16.771593242883682, 22.82660063356161, 1.9573933607898653, 0.9643011528532952, 50.87388172745705, 65.85068687796593, 31.908643394708633, 47.38882653415203, 65.2584658563137, 72.82182320952415, 73.80104586482048, 121.25213965773582, 71.54739439487457, 57.47174508869648, 4.57115376368165, 0.8946980908513069, 0.4414114187238738, 3.1956342235207558, 3.0740519100800157, 0.7104816008359194, 0.20973736041923985, 0.1983292741351761, 0.2076278204913251, 0.3039676876505837, 0.28977776470128447, 0.2915422950172797, 0.24815372948069125, 1.0785896982997656, 6.315737525001168, 13.54052022099495, 8.919928260147572, 2.5958302337676287, 5.2559539675712585, 19.879172891378403, 39.271933883428574, 38.03125485777855, 35.69814585149288, 61.883779540658, 56.243191212415695, 66.13832384347916, 62.359255626797676, 64.12830010056496, 64.31927025318146, 65.32078251242638, 70.70643112063408, 67.31914848089218, 72.70194724202156, 71.70311003923416, 71.46275773644447, 72.84066259860992, 66.35859802365303, 73.75677064061165, 70.10170117020607, 71.78209260106087, 72.0621831715107, 65.7293289899826, 69.87680643796921, 72.5089555978775, 68.74795541167259, 70.03832817077637, 70.66470175981522, 62.70560324192047, 66.68483331799507, 66.59856274724007, 59.77448232471943, 58.90554495155811, 55.26336058974266, 53.877742141485214, 53.55635158717632, 54.41718019545078, 53.671002835035324, 48.056785091757774, 52.65320844948292, 51.16458132863045, 53.04586797952652, 52.25372068583965, 49.041627645492554, 49.294545873999596, 50.37034794688225, 50.069012716412544, 47.856125459074974, 49.85033445060253, 47.03553669154644, 45.77037177979946, 47.09915667772293, 43.965134248137474, 43.96365612745285, 46.54590256512165, 43.659824430942535, 40.221689119935036, 40.0036796182394, 38.39508153498173, 42.396973595023155, 45.85907801985741, 46.813461408019066, 42.73906923830509, 45.21675668656826, 45.6085042655468, 45.08659087121487, 48.063183948397636, 52.608332857489586, 50.0368208438158, 51.7581170797348, 51.29882052540779, 53.411423563957214, 53.174825459718704, 50.753029212355614, 47.85054735839367, 49.5728999376297, 47.74397827684879, 52.27075137197971, 57.11964078247547, 61.37644976377487, 61.60124570131302, 62.20531068742275, 60.18828012049198, 62.45596043765545, 57.366737723350525, 56.018942445516586, 59.102313593029976, 58.254457488656044, 57.852503657341, 57.9108989238739, 62.99159109592438, 63.96593481302261, 59.04786251485348, 61.34424269199371, 57.99472242593765, 57.34283320605755, 55.19106186926365, 57.066048458218575, 44.09300118684769, 46.48862823843956, 63.22826899588108, 56.30888968706131, 49.84862074255943, 45.31538799405098, 40.4080843180418, 43.45898620784283, 54.69052992761135, 35.393968373537064, 51.580974385142326, 65.07945746183395, 65.77643886208534, 56.22808322310448, 66.02088734507561, 33.32877539098263, 2.476220726966858, 0.1305394570226781, 0.29720654420088977, 0.19068996218265966, 0.16149356088135391, 0.15434057830134407, 0.12230690932483412, 0.3194594563683495, 0.20996059844037518, 0.12537593487650156, 0.5822232831269503, 0.7892174134030938, 2.958137230016291, 46.62754498422146, 38.68424981832504, 29.89668745547533, 51.67451396584511, 10.396837759763002, 5.808629561215639, 0.3851120069157332, 11.17373837158084, 75.42862012982368, 48.123980686068535, 100.01104384660721, 48.767259567976, 0.4416582570411265, 0.27578249224461615, 0.21202756877755746], [4.639242310076952, 8.448393512517214, 3.7955303583294153, 0.9007312171161175, 3.495089504867792, 15.023288056254387, 9.083612076938152, 17.737605907022953, 8.212415724992752, 34.512320682406425, 41.42367482185364, 50.78726537525654, 110.0271087884903, 44.71027046442032, 27.48474407941103, 3.6187752429395914, 0.7950153085403144, 0.21803673851536587, 0.5226769752334803, 0.03516964367008768, 0.14907805365510285, 0.012315030635363655, 0.05577073919994291, 0.00766158705118869, 0.058631651700125076, 0.13997917470987886, 0.04743374163808767, 0.2987657074118033, 2.282713735476136, 8.206689432263374, 9.068793822079897, 3.0787551077082753, 2.1861675661057234, 4.18433309532702, 10.582269709557295, 16.647016927599907, 17.499003410339355, 11.061825826764107, 17.358011975884438, 29.013329856097698, 42.04752154648304, 47.70266309380531, 40.201082825660706, 37.8359567373991, 43.97740378975868, 55.92722296714783, 60.461523458361626, 61.05063624680042, 60.50887271761894, 61.26667745411396, 66.61833688616753, 62.583796977996826, 66.1837238073349, 63.45778048038483, 67.65739113092422, 63.18051315844059, 65.29325678944588, 61.89456336200237, 61.98274523019791, 66.95990055799484, 64.03644382953644, 57.017547860741615, 61.34267717599869, 63.649605587124825, 60.56996963918209, 56.86622858047485, 51.35028876364231, 46.000901609659195, 48.822387009859085, 48.05884838104248, 47.035969868302345, 45.101398676633835, 46.51114583015442, 46.26144602894783, 44.93573136627674, 44.49173279106617, 46.524023339152336, 45.89753955602646, 45.1350686699152, 42.321821227669716, 42.411595210433006, 41.87333509325981, 45.39126992225647, 40.56138329207897, 43.71068090200424, 43.82073439657688, 45.05869276821613, 40.734802186489105, 41.28022491931915, 38.08336906135082, 40.00234968960285, 39.12110857665539, 36.82823181152344, 36.422983556985855, 45.57468228042126, 42.14862272143364, 37.4293177574873, 37.22434915602207, 41.05647012591362, 43.15024137496948, 44.02877323329449, 44.05178099870682, 41.921402513980865, 44.20922935009003, 46.23002931475639, 44.093555957078934, 44.17867138981819, 42.024038806557655, 44.8078378289938, 42.34428562223911, 43.82443159818649, 44.627096727490425, 50.7296072691679, 51.38617783784866, 54.211584627628326, 56.924137473106384, 56.919619515538216, 55.94131261110306, 53.310546576976776, 51.73730179667473, 55.95960482954979, 53.50437417626381, 50.94580426812172, 53.58665116131306, 51.36714465916157, 56.00744046270847, 53.32630813121796, 55.732863396406174, 50.28588607907295, 51.32973566651344, 49.30635184049606, 43.32855440676212, 37.340185940265656, 33.972631841897964, 37.97921285033226, 35.62086179852486, 35.38591280579567, 24.363430067896843, 11.949469596147537, 1.6572566097602248, 26.89128052443266, 21.194050535559654, 25.0060173869133, 29.857376664876938, 23.2115313783288, 22.05606658011675, 7.192219393327832, 0.037689220189349726, 0.06088516085583251, 0.12989073089556769, 0.03580390904971864, 0.049731916951714084, 0.10340339125832543, 0.09478975072852336, 0.07412930935970508, 0.10501503173145466, 0.042381575040053576, 0.07348598606768064, 0.11078658804763108, 0.2946944336872548, 1.9738828134723008, 37.14375548064709, 19.705431014299393, 23.122680746018887, 10.420840121805668, 7.042126497253776, 3.460397128947079, 0.1376895749126561, 0.018853434230550192, 9.163092412054539, 33.24357636272907, 56.1945766210556, 63.9020374417305, 6.336665377020836, 0.2599326818017289, 0.20765998517163098, 3.853096319362521, 12.951802611351013, 8.71448278427124, 1.2187500461004674, 11.755034029483795, 41.7886908352375, 21.04143362492323, 24.88715596497059, 14.926490150392056, 47.78528206050396, 56.438979506492615, 57.57703743875027, 127.08998680114746, 60.75215466320515, 33.64041566848755, 6.111783944070339, 1.0495163896121085, 0.27531431580428034, 0.5529899674002081, 0.0374088590615429, 0.17634785443078727, 0.03893690030963626, 0.0246756996421027, 0.11529589217389002, 0.015023185951577034, 0.07405450829537585, 0.06523228716105223, 0.0542433733062353, 3.479946367442608, 9.56053588539362, 11.007997915148735, 3.126601427793503, 1.3130963710136712, 4.776086267083883, 12.97403996810317, 23.23776137083769, 21.094049401581287, 16.640490777790546, 26.950623840093613, 44.333516880869865, 48.03068049252033, 55.483805760741234, 51.60914607346058, 47.27461986243725, 49.31639850139618, 61.38579346239567, 62.54219301044941, 64.86981511116028, 62.83371336758137, 66.62760078907013, 67.44912430644035, 66.63520038127899, 67.53887549042702, 66.4054723083973, 67.28797495365143, 64.46215018630028, 65.39451375603676, 63.99118825793266, 64.18452188372612, 71.1782518029213, 66.13155260682106, 59.5283505320549, 63.35148498415947, 66.75727263092995, 62.21244290471077, 59.687174409627914, 53.44714164733887, 49.80947144329548, 52.290407717227936, 50.33695913851261, 49.03307430446148, 47.88618564605713, 48.088942766189575, 49.01487708091736, 46.92600376904011, 45.803183019161224, 49.03005726635456, 50.786182433366776, 46.79191276431084, 46.92123502492905, 43.25297266244888, 45.26835411787033, 45.67872069776058, 40.469922199845314, 43.77874664962292, 45.335150733590126, 44.19738918542862, 41.59758388996124, 40.59676319360733, 38.01116153597832, 39.25056762993336, 39.55492749810219, 38.47430348396301, 37.02064968645573, 44.1310029476881, 44.639024287462234, 39.17586363852024, 41.533340737223625, 43.184929713606834, 46.26693673431873, 45.946499928832054, 46.063868030905724, 43.75108793377876, 46.10995955765247, 48.64418797194958, 48.22897665202618, 47.4652024358511, 46.66408762335777, 45.94132460653782, 45.325981825590134, 46.09596490859985, 46.00943215191364, 52.256870716810226, 53.33587981760502, 57.18513406813145, 58.43515299260616, 58.94659794867039, 59.15826179087162, 56.31322905421257, 54.66991603374481, 56.81388258934021, 57.97986902296543, 52.528145760297775, 56.58014953136444, 56.028441935777664, 57.857701778411865, 55.52449017763138, 58.70629504323006, 54.81624238193035, 55.90437859296799, 52.646604403853416, 50.7021651417017, 41.64228469133377, 38.450904339551926, 42.271329537034035, 38.49376983940601, 33.91978047788143, 22.442906722426414, 6.809178097173572, 0.29110908857546747, 31.684282533824444, 31.512890830636024, 40.614774227142334, 37.18663617968559, 30.05758412182331, 21.62725578993559, 5.772156743332744, 0.10374631543527357, 0.2902054792502895, 0.07903296849690378, 0.12257560389116406, 0.08562374452594668, 0.10022873582784086, 0.03642086383479182, 0.04084716616489459, 0.04190759500488639, 0.04123798855289351, 0.11338215306750499, 0.3041983174625784, 0.3764147189212963, 4.254496330395341, 48.29885110259056, 25.164542980492115, 27.81193122267723, 26.325694173574448, 6.921873399987817, 3.8020239723846316, 0.5129411851521581, 0.8380680670961738, 27.936917915940285, 49.1019494086504, 72.72970855236053, 81.44862949848175, 10.51375463604927, 0.21646531502483413, 0.3353246737970039, 8.936316780745983, 14.844083972275257, 8.520318903028965, 1.190777609590441, 15.212726891040802, 79.78116497397423, 45.85825726389885, 50.57059720158577, 22.353024445474148, 58.861113935709, 76.34668126702309, 61.715961545705795, 137.25605249404907, 60.24365454912186, 43.12561869621277, 8.553493022918701, 1.3884963188320398, 0.2939238172257319, 1.4683435717597604, 0.15736983215902, 0.2724317251704633, 0.1289377687498927, 0.18811579328030348, 0.1757483623805456, 0.16598414804320782, 0.2154483797494322, 0.1340691262157634, 0.47392090084031224, 3.1788930343464017, 10.068447031080723, 21.09606709331274, 13.62300144508481, 4.678382109850645, 16.30511697381735, 25.652565993368626, 31.989164873957634, 29.46980696171522, 28.654917888343334, 49.972824677824974, 56.570273861289024, 57.20271572470665, 65.27754843235016, 62.30687543749809, 59.66594874858856, 57.72616043686867, 66.5958420932293, 66.66957333683968, 69.3096412718296, 65.56011646986008, 69.48643818497658, 70.60907274484634, 69.03940737247467, 70.20822465419769, 68.85264739394188, 71.67584270238876, 68.7394666671753, 68.08850839734077, 68.73780995607376, 65.5741985142231, 73.60861659049988, 71.81267336010933, 61.16461493074894, 65.08574992418289, 70.08326455950737, 64.71159160137177, 63.17152664065361, 57.267205864191055, 53.48297372460365, 55.16472168266773, 54.09735895693302, 51.766849011182785, 51.17161475121975, 49.816713854670525, 51.67906612157822, 49.405568316578865, 48.412955179810524, 52.68016040325165, 52.14898310601711, 48.851653039455414, 49.84311863780022, 47.07063540816307, 47.417188212275505, 46.95576757192612, 41.24414965510368, 43.74300956726074, 45.518893674016, 46.18862673640251, 42.796955332159996, 41.30518577992916, 40.4792544990778, 39.60687831044197, 39.68835733830929, 37.43856646120548, 36.983920857310295, 49.06925216317177, 46.34916052222252, 42.10509605705738, 43.02639082074165, 44.17024724185467, 49.54079166054726, 49.430943354964256, 50.91317541897297, 45.787824243307114, 51.141793951392174, 50.316364243626595, 48.83154071867466, 49.284066036343575, 49.060657024383545, 49.82010327279568, 47.53052473068237, 47.936502546072006, 50.40733516216278, 54.880044758319855, 56.85577154159546, 58.73845651745796, 62.96856813132763, 61.849395185709, 61.0982970893383, 57.08954259753227, 57.6322066783905, 61.20897375047207, 62.100044935941696, 55.48395775258541, 59.61023233830929, 55.410370901227, 63.11644859611988, 59.31648910045624, 61.20344504714012, 57.956994250416756, 58.110859394073486, 56.60038344562054, 53.07366728782654, 44.55396585166454, 43.55565682053566, 46.67668014764786, 39.827794656157494, 44.0314406901598, 38.705851659178734, 18.325025886297226, 9.705923683941364, 43.99172522127628, 37.19681203365326, 50.920581221580505, 49.280885607004166, 45.50939038395882, 26.081608571112156, 7.028282890096307, 0.11678188704536296, 0.4298416629899293, 0.24443215574137866, 0.2916216751327738, 0.2632145775714889, 0.35447433998342603, 0.2322809273027815, 0.2438271717983298, 0.21550438221311197, 0.287789135472849, 0.3061691648326814, 0.7404907280579209, 0.5952140141744167, 6.214919909834862, 58.295233100652695, 36.08427733182907, 38.11535194516182, 55.50649434328079, 14.131009485572577, 7.645377852022648, 0.807220550486818, 2.753804144449532, 57.116479352116585, 56.800492107868195, 83.25832799077034, 94.09242063760757, 9.767673220485449, 0.4612845304654911, 0.477184658520855], [3.3261078223586082, 4.4426612835377455, 0.6531901156995445, 0.6484840682242066, 2.3965259408578277, 7.608794840052724, 5.5261189956218, 13.397732432931662, 4.8568423837423325, 24.86891694366932, 38.578030318021774, 36.31385341286659, 35.37242732942104, 25.421281903982162, 34.0789957344532, 6.153858136385679, 0.5423765431623906, 0.15727218036772683, 0.13191623002057895, 0.048224533384200186, 0.04965599895513151, 0.0735096531570889, 0.02483216107066255, 0.10840183749678545, 0.03252346417866647, 0.09945089084794745, 0.06974076750339009, 0.16651252750307322, 4.05754909850657, 15.624216310679913, 11.824655793607235, 3.5089789470657706, 0.6713343795854598, 4.497898919507861, 11.981927454471588, 9.382542036473751, 9.334831796586514, 5.0606900453567505, 5.364754954352975, 16.249391064047813, 38.63631919026375, 37.44683101773262, 39.310771599411964, 32.77835972607136, 40.48529997467995, 50.47393798828125, 56.320308074355125, 55.63489705324173, 58.0475889891386, 59.96678240597248, 63.089363649487495, 62.62936033308506, 63.421317636966705, 66.22913897037506, 63.868340849876404, 60.842441618442535, 62.81082719564438, 59.02457736432552, 60.63044719398022, 63.64177040755749, 58.62972915172577, 58.44106547534466, 65.55543512105942, 63.148119896650314, 59.63229015469551, 55.34294351935387, 49.50169935822487, 46.766245141625404, 48.081198781728745, 48.48742738366127, 48.017932176589966, 49.410774037241936, 47.20201715826988, 44.73876893520355, 45.24477258324623, 45.10271720588207, 46.903619170188904, 47.81785771250725, 45.67964404821396, 44.20874297618866, 42.27968908846378, 43.45923699438572, 45.89384235441685, 41.13055855035782, 43.325810953974724, 42.96107232570648, 42.39591345191002, 37.651575431227684, 39.60282392799854, 37.46771849691868, 38.50810647010803, 38.84947635233402, 37.027097940444946, 39.95172120630741, 43.399652391672134, 40.653604343533516, 36.8179951608181, 39.290533885359764, 43.03316205739975, 43.45789186656475, 43.92050564289093, 43.68091329932213, 43.79989631474018, 45.18261171877384, 43.54833461344242, 43.87716896831989, 44.129889607429504, 43.38399723172188, 41.245772168040276, 41.87739707529545, 47.703248262405396, 43.67518700659275, 44.88206684589386, 52.85884201526642, 56.22445821762085, 54.937790259718895, 55.7958260178566, 55.34053444862366, 55.970327854156494, 52.391269505023956, 53.83901081979275, 54.88610163331032, 52.083512619137764, 51.43531680107117, 57.98082277178764, 50.62041252851486, 48.9152692258358, 50.43402872979641, 52.68780559301376, 46.20095707476139, 42.076210007071495, 42.94226713478565, 30.107882022857666, 26.297771371901035, 25.611077919602394, 20.528297759592533, 12.620292250066996, 4.6743144281208515, 0.23581951711094007, 0.17230214027222246, 4.0338388457894325, 23.8096496835351, 13.668526802212, 5.660685924813151, 1.1109143262729049, 0.08818681832053699, 0.24297937197843567, 0.11257257385295816, 0.06681358863716014, 0.05208551214309409, 0.02748962491750717, 0.06136695941677317, 0.10575603650067933, 0.05632307889754884, 0.06195585730893072, 0.028442872790037654, 0.13055858958978206, 0.09033302776515484, 0.13201049761846662, 0.624765622196719, 7.3758606892079115, 42.82943598926067, 23.44369702041149, 24.228966683149338, 13.184615168720484, 8.201195877045393, 2.783991862088442, 0.4534591769333929, 0.2599157311487943, 9.393084570765495, 38.11666287481785, 53.38298209011555, 80.80388009548187, 21.059273667633533, 0.14878005167702213, 0.3683501563500613, 5.359080908820033, 9.307072386145592, 1.2516384688206017, 0.578297262545675, 18.47848255187273, 33.48815403878689, 15.35004012286663, 17.19588227570057, 8.008040841668844, 37.1240421384573, 53.97245965898037, 45.06074085831642, 54.10186931490898, 43.25955390930176, 38.66889864206314, 9.981315806508064, 0.728833309840411, 0.35231881658546627, 0.129422613827046, 0.03551311332557816, 0.06320469517959282, 0.1294962051906623, 0.00917042198125273, 0.04247851436957717, 0.18088647339027375, 0.08914622972952202, 0.022291168024821673, 0.06997046220931225, 4.345797831192613, 16.73065423965454, 15.37138357758522, 6.710844598710537, 1.3172393362037838, 9.224018342792988, 22.463864497840405, 16.07377588748932, 14.882112331688404, 14.725429639220238, 13.359059058129787, 29.885945431888103, 48.433314487338066, 48.780539855360985, 45.06220377981663, 42.89353474974632, 45.147919580340385, 56.09795160591602, 60.18191546201706, 61.301840767264366, 61.282674595713615, 64.89659607410431, 64.09432232379913, 66.41077682375908, 65.97215116024017, 70.97156569361687, 64.8495090007782, 64.24695253372192, 66.33852750062943, 63.88141214847565, 63.64077866077423, 65.6676734983921, 61.512702852487564, 62.42613583803177, 65.61854213476181, 66.36949583888054, 63.24533008038998, 57.055397629737854, 51.61219350993633, 50.3579568117857, 50.82236789166927, 50.97875989973545, 49.30933088064194, 50.568860694766045, 49.77685399353504, 46.97135433554649, 48.47703494131565, 46.95055805146694, 51.968033015728, 50.36133483052254, 50.00751681625843, 45.32777152955532, 45.15151798725128, 46.3720390945673, 46.09012462198734, 41.679697483778, 42.46220089495182, 42.395833656191826, 43.02593104541302, 36.9604267179966, 39.34618949890137, 38.40787164866924, 39.17150907218456, 39.39936764538288, 38.62739346921444, 39.950687661767006, 43.077121898531914, 44.24278914928436, 40.75499050319195, 44.39992591738701, 46.51072405278683, 48.56321431696415, 47.45403103530407, 45.87055340409279, 45.89699238538742, 48.309574127197266, 46.30431532859802, 45.994179770350456, 46.99188083410263, 46.30811132490635, 45.96923030912876, 45.5279865860939, 50.3865122795105, 47.07911275327206, 46.244643330574036, 54.98348280787468, 60.04137620329857, 58.75550240278244, 58.78713570535183, 56.59928150475025, 58.16036693751812, 54.76310983300209, 56.47716745734215, 56.24418295919895, 55.90402141213417, 54.1172356903553, 60.0993724912405, 55.014899522066116, 52.370294630527496, 54.80084180831909, 55.66079266369343, 50.565475076437, 47.23447881639004, 47.79581889510155, 33.58838886022568, 27.01219193637371, 24.553087390959263, 16.6450809314847, 8.162103574723005, 2.1843557758256793, 0.14287030004197732, 0.06683776780846529, 2.233049450442195, 18.286855034530163, 10.133233554661274, 5.061242440715432, 0.9963784972205758, 0.19476073124678805, 0.24474834033753723, 0.021888799674343318, 0.03672521859698463, 0.03587310689908918, 0.06686464839731343, 0.08080028928816319, 0.009148569442913868, 0.02801037138851825, 0.06575723789865151, 0.045811295494786464, 0.08981227758340538, 0.04796120825631078, 0.31153435818850994, 0.8340772124938667, 13.716450780630112, 54.68727730214596, 28.613815493881702, 30.443567410111427, 26.31556011736393, 7.9172024410218, 3.740683626383543, 0.6608389865141362, 0.17414328991435468, 21.49058662354946, 51.884980872273445, 64.09279480576515, 92.44734451174736, 31.579733043909073, 0.20957652217475697, 0.4792334313970059, 6.231622863560915, 8.026794735342264, 0.9363949159160256, 1.1101061571389437, 35.819667130708694, 70.43327137827873, 33.77582140266895, 33.3769454061985, 9.507987555116415, 51.22148707509041, 76.41489520668983, 49.990611523389816, 63.5749813914299, 41.794531121850014, 55.102340430021286, 11.32699839770794, 0.8297182526439428, 0.556637771660462, 0.2981786389136687, 0.16058223322033882, 0.3133720939513296, 0.18706884555285797, 0.13574136304669082, 0.2843218808993697, 0.2359881330630742, 0.12324393755989149, 0.19177851470885798, 0.4841919871978462, 4.797919420525432, 17.705465331673622, 20.93266636133194, 8.967571053653955, 1.3807150488719344, 13.980612605810165, 29.240485467016697, 21.129761785268784, 19.161562398076057, 27.25274182856083, 25.506556928157806, 43.8557381182909, 61.829187870025635, 56.749726831912994, 57.95146934688091, 58.091837614774704, 57.47968666255474, 63.809626400470734, 65.36378100514412, 64.63660642504692, 63.999053835868835, 67.28457793593407, 67.28762537240982, 70.96028789877892, 68.09078067541122, 74.30415406823158, 67.87116006016731, 68.45368400216103, 67.12225824594498, 64.24740850925446, 66.40165731310844, 70.00106737017632, 64.38891291618347, 63.057095780968666, 69.40401300787926, 69.82967376708984, 66.29166081547737, 60.91145731508732, 55.119583904743195, 54.57029677927494, 54.73758280277252, 54.84227478504181, 53.76813322305679, 53.78701061010361, 51.38828672468662, 49.630736634135246, 49.87267345190048, 49.293823912739754, 54.10708263516426, 54.50355336070061, 50.87940663099289, 50.06639465689659, 47.29666627943516, 49.754955768585205, 48.30194793641567, 41.050599440932274, 43.601280972361565, 44.615777134895325, 43.63759182393551, 37.70694985985756, 40.84767892956734, 38.20419117808342, 41.5349480509758, 40.83511680364609, 36.450801864266396, 39.92017909884453, 45.265021696686745, 45.60508444905281, 42.68369480967522, 46.03421062231064, 49.164562448859215, 50.916887819767, 48.89022096991539, 49.79553759098053, 48.86895731091499, 50.9139733761549, 49.25415024161339, 48.3279575407505, 47.439827397465706, 49.54462185502052, 46.46875150501728, 47.61402904987335, 52.736180797219276, 49.233901128172874, 49.09460060298443, 58.4714562445879, 63.92986714839935, 60.73382064700127, 61.04188911616802, 59.43288065493107, 60.20238496363163, 55.927435755729675, 60.43261460959911, 58.93406242132187, 57.467709705233574, 57.70041681826115, 63.75007599592209, 58.33405941724777, 56.0987039655447, 58.407946452498436, 59.753306061029434, 54.761149138212204, 50.05310297012329, 52.2999832034111, 39.02908131480217, 33.02185446023941, 39.86494146287441, 35.220750868320465, 20.332237780094147, 7.234908677637577, 0.825013630092144, 0.4531765077263117, 4.473413983359933, 25.150694623589516, 17.239876314997673, 8.811055552214384, 1.5046867216005921, 0.4595260857604444, 0.4174396925373003, 0.15847077855141833, 0.1387771181180142, 0.22908434882992879, 0.14685465343063697, 0.17556129663717002, 0.35121138382237405, 0.12239449759363197, 0.1815730193629861, 0.08950249772169627, 0.24173069366952404, 0.18112293648300692, 0.4731926164822653, 1.0292586078867316, 16.44359864294529, 64.22502771019936, 37.692978009581566, 46.18815176188946, 49.998670890927315, 20.237484164536, 6.12542568705976, 1.016582369338721, 0.5948044674005359, 42.82806046307087, 68.58450338244438, 69.13333833217621, 106.07101947069168, 32.87672504782677, 0.39845276449341327, 0.6572859990410507], [2.1211825031787157, 1.7640783777460456, 0.21446650353027508, 1.6858545877039433, 6.492644157260656, 5.072942962870002, 2.3505384335294366, 6.1380148865282536, 5.952358273789287, 24.91368994116783, 32.911481782794, 26.323554888367653, 26.730448454618454, 30.75589545071125, 37.67475798726082, 10.503846667706966, 0.27422362589277327, 0.04713956172054168, 0.08687978493981063, 0.05112751081469469, 0.1910774820134975, 0.053792336766491644, 0.043612393565126695, 0.02460082065226743, 0.07566969623439945, 0.060891179673490115, 0.06714551418554038, 0.045078305920469575, 1.8541267770342529, 15.889575071632862, 16.25860556960106, 15.000413283705711, 3.8833215599879622, 14.202815182507038, 10.808380376547575, 2.1059704944491386, 2.3559773666784167, 3.2380473101511598, 3.1952658807858825, 5.425711283460259, 24.00450322777033, 33.7580231577158, 29.214245975017548, 31.664789579808712, 33.09637226164341, 43.08705076575279, 51.93082541227341, 53.13402704894543, 55.30383221805096, 58.50213959813118, 60.266609117388725, 61.11885778605938, 64.66158628463745, 64.9756546318531, 59.744216948747635, 63.733163103461266, 61.659416779875755, 60.762847289443016, 65.25275856256485, 58.06364692747593, 59.87668164074421, 65.62194675207138, 64.46826785802841, 64.66876789927483, 61.75315015017986, 48.57437811791897, 49.98834304511547, 48.57655920088291, 48.3571095764637, 46.89720891416073, 46.903440579771996, 47.70856037735939, 45.91902360320091, 45.91180019080639, 45.59611313045025, 46.7123906314373, 48.90770383179188, 50.13527736067772, 50.15409395098686, 45.9507405012846, 41.64099656045437, 49.186506271362305, 50.096933618187904, 40.1384811848402, 41.517708376049995, 40.83697110414505, 41.59558519721031, 39.016481190919876, 37.75817111134529, 39.24107573926449, 37.23439961671829, 36.59353360533714, 37.20770984888077, 37.571707516908646, 43.6304672062397, 46.42618618905544, 39.42258819937706, 41.1325990408659, 44.52565737068653, 46.922450959682465, 45.97356967628002, 41.63840889930725, 42.98765569925308, 42.47141160070896, 42.712523862719536, 46.44922435283661, 43.41819919645786, 41.21794246137142, 44.06908147037029, 43.94978307187557, 46.56734101474285, 47.52101384103298, 41.20713584125042, 48.674293756484985, 55.04372477531433, 54.14612554013729, 57.227528393268585, 54.11622874438763, 55.45567587018013, 55.500262677669525, 49.34695266187191, 50.900541096925735, 53.80122184753418, 50.003447234630585, 49.807985723018646, 47.54880174994469, 46.48795187473297, 48.660264909267426, 43.79143416881561, 42.02335864305496, 37.29746863245964, 29.969316758215427, 20.603220239281654, 7.4253729823976755, 2.8390045976266265, 4.545885594561696, 0.8326337649486959, 0.2374089154182002, 0.14689943462144583, 0.10159529687371105, 0.05229706504906062, 0.5312933691311628, 1.2303194752894342, 0.20985027076676488, 0.05943845528236125, 0.0409508516167989, 0.09156305590295233, 0.05284021324769128, 0.04335044512117747, 0.04140963246754836, 0.07858770215534605, 0.04236987508193124, 0.0481272155593615, 0.04826657233934384, 0.10624350878060795, 0.025642046421125997, 0.050204535145894624, 0.016497944707225543, 0.069176468095975, 0.607024849159643, 15.595847982913256, 43.40358518064022, 26.716079525649548, 19.33501359075308, 9.354167059063911, 7.354363817721605, 0.5837109033018351, 0.2331185300135985, 0.2545731287682429, 4.280036184936762, 46.24999724328518, 44.93572376668453, 84.2136499285698, 35.45261822640896, 0.18470756913302466, 0.3787664364790544, 4.084063600748777, 4.664252093061805, 0.38663352839648724, 3.3501317957416177, 29.22786444425583, 31.475358344614506, 9.713061600923538, 9.801066778600216, 7.970716394484043, 35.168511271476746, 50.674894005060196, 37.176228538155556, 30.725356489419937, 31.314811259508133, 39.8383504897356, 18.593770265579224, 0.5680154892615974, 0.12643526162719354, 0.08324025562615134, 0.018888953418354504, 0.10305024770786986, 0.04676238000683952, 0.04814938351046294, 0.11481144043500535, 0.03080767626670422, 0.06839511275757104, 0.032223443558905274, 0.0810279801953584, 2.3731700191274285, 19.415521770715714, 21.023420691490173, 16.03386662900448, 1.5451931417919695, 12.9170610755682, 15.989447012543678, 6.0480504389852285, 7.076722215861082, 4.924485879018903, 5.699729779735208, 18.196600377559662, 28.117907904088497, 45.07201485335827, 40.05617380142212, 39.12939593195915, 43.39361451566219, 49.284993186593056, 56.2799846380949, 56.992370411753654, 59.702343195676804, 63.46297860145569, 63.31001780927181, 62.196411564946175, 67.3188216984272, 67.32202872633934, 63.41221332550049, 65.4192504286766, 64.0879462659359, 65.06410628557205, 66.26737251877785, 58.90328027307987, 63.68949204683304, 66.51937499642372, 66.14717736840248, 67.77572438120842, 65.18725007772446, 51.713450476527214, 52.30972968041897, 52.915667966008186, 48.76015014946461, 50.04879020154476, 49.81262527406216, 50.95517836511135, 48.19213382899761, 48.8438406586647, 47.04146817326546, 48.71931754052639, 50.6628904491663, 53.63651588559151, 54.59452427923679, 46.92248895764351, 44.65436786413193, 49.9431786686182, 50.334466472268105, 39.39794272184372, 41.457295417785645, 41.17014102637768, 40.34607544541359, 39.64985780417919, 38.865367099642754, 38.68928834795952, 38.29068973660469, 38.32325018942356, 38.96938271820545, 36.563427820801735, 45.27813099324703, 46.903972551226616, 41.251122280955315, 42.852546349167824, 47.6277045160532, 49.966232031583786, 48.15285533666611, 44.64316986501217, 43.9179939776659, 44.69263181090355, 44.60427515208721, 46.787512600421906, 45.54246760904789, 44.35063116252422, 46.76679991185665, 48.14102277159691, 48.97929199039936, 50.664421766996384, 46.48432306945324, 50.171299427747726, 55.89715518057346, 56.0174985229969, 60.06013959646225, 55.41207700967789, 56.701226234436035, 59.98798526823521, 52.419190406799316, 54.54075336456299, 55.97151339054108, 54.448954090476036, 53.04726630449295, 50.636193081736565, 51.00432112812996, 52.89407752454281, 49.62691783905029, 47.11818225681782, 41.330237835645676, 32.3588128387928, 18.905541636049747, 5.753452721983194, 1.2095398153178394, 1.5110087511129677, 0.25648469338193536, 0.2396576970932074, 0.06776468799216673, 0.058454556710785255, 0.03775383156607859, 0.5278088373597711, 1.181345209479332, 0.13881866354495287, 0.06307483417913318, 0.1058514321630355, 0.16840867028804496, 0.028271748378756456, 0.09745551549713127, 0.01598171791556524, 0.1013307880202774, 0.09998034642194398, 0.041879886921378784, 0.07028453168459237, 0.06938773527508602, 0.01948016866663238, 0.051595453478512354, 0.0935151195153594, 0.22747123148292303, 0.7373376691248268, 25.278346873819828, 52.5356275588274, 33.33101727068424, 29.47378534823656, 23.443024456501007, 6.338579999282956, 1.1707016243599355, 0.3765559644671157, 0.4487559199333191, 8.234548587352037, 58.85812729597092, 53.996227383613586, 95.16861408948898, 45.11449657380581, 0.07567128443042748, 0.3395531343994662, 3.824250642210245, 5.273745087906718, 0.518503017956391, 5.242344047874212, 56.94354683160782, 63.49340356886387, 31.56582199037075, 18.12861442565918, 9.388604611158371, 49.21520613133907, 72.97996312379837, 45.03926821053028, 46.300956308841705, 48.87911036610603, 54.81262497603893, 20.67536886781454, 0.7266842282842845, 0.1813186556682922, 0.24644206976518035, 0.15597248682752252, 0.24389632511883974, 0.15391696040751413, 0.16800543176941574, 0.34157266665715724, 0.09284903455409221, 0.187191893637646, 0.22756475693313405, 0.17995935282669961, 2.5426803482696414, 18.39260146021843, 24.215004332363605, 27.770338654518127, 12.255980148911476, 27.80003596097231, 20.605722405016422, 6.473320294171572, 10.5717689730227, 7.203919915482402, 11.962728034704924, 29.606535024940968, 41.11646890640259, 55.52223689854145, 51.70969247817993, 53.56119252741337, 56.71911187469959, 59.58338677883148, 59.58916246891022, 61.43202558159828, 62.775424495339394, 66.59325823187828, 65.07883429527283, 66.86577200889587, 70.61200618743896, 72.11221888661385, 65.17289444804192, 69.09461081027985, 66.06059521436691, 65.25690034031868, 73.52456510066986, 64.06581625342369, 66.94977790117264, 70.0794267654419, 69.69386145472527, 70.8905540406704, 67.2527052462101, 52.92791850864887, 55.55694043636322, 54.239315539598465, 52.75627791881561, 53.02397355437279, 52.80052274465561, 53.327524065971375, 50.7020815461874, 50.85133753716946, 48.83451595902443, 51.166036650538445, 54.93991434574127, 56.372471675276756, 56.276298835873604, 51.23094096779823, 47.56845809519291, 56.86597779393196, 52.91595675051212, 41.444056928157806, 41.649629697203636, 41.42882354557514, 42.40099377930164, 42.150959596037865, 38.599734753370285, 39.79393467307091, 38.914745450019836, 37.857911959290504, 38.48178908228874, 36.923397704958916, 45.52057318389416, 51.35249264538288, 43.12151111662388, 45.20112432539463, 49.60436224937439, 51.745425760746, 51.19247183203697, 49.93081793189049, 48.262813836336136, 47.56094589829445, 46.815501898527145, 49.7530672699213, 50.15237644314766, 47.51015402376652, 49.71309721469879, 49.19509761035442, 52.05632507801056, 51.06147766113281, 46.3410821557045, 54.91612382233143, 59.50459040701389, 57.525440007448196, 61.928077563643456, 56.3614446669817, 58.58586810529232, 64.47730377316475, 55.11421479284763, 58.90573114156723, 58.3109300583601, 56.7673122882843, 55.62668189406395, 52.566485702991486, 52.65605069696903, 55.26660181581974, 55.1503736525774, 51.709969863295555, 49.44747246801853, 39.560034424066544, 32.731090262532234, 27.90808316320181, 15.954743474721909, 5.1366066467016935, 1.7648497363552451, 0.3250376757932827, 0.23852163227275014, 0.30682246258948, 0.15267809329088777, 1.341209637466818, 1.9277236028574407, 0.41176193626597524, 0.2796217112336308, 0.3570596856297925, 0.3145054721971974, 0.1161754633358214, 0.22556965617695823, 0.10562806055531837, 0.27893828228116035, 0.226879917900078, 0.1359414609032683, 0.22624716279096901, 0.24279062898131087, 0.10880277535761707, 0.1571978913852945, 0.13630379224196076, 0.41912546614184976, 1.0210723034106195, 32.728605195879936, 61.43210157752037, 43.73157598078251, 42.57413148880005, 41.63051292300224, 15.860982555896044, 2.3339824844151735, 0.6514523026999086, 1.0919275763444602, 16.853735335171223, 85.0565055012703, 64.00432035326958, 112.14477315545082, 53.95677410066128, 0.39704630558844656, 0.6574877444654703], [1.0653738887049258, 1.0602616192772985, 0.20886790473014116, 3.593183853663504, 16.063617132604122, 1.4382769726216793, 2.427070839330554, 0.6591863126959652, 5.094520105049014, 14.662425220012665, 22.711936086416245, 25.662116780877113, 45.410603284835815, 52.34456621110439, 32.708648666739464, 21.353573575615883, 0.5439318472053856, 0.09551818351610564, 0.09160762929241173, 0.047210318080033176, 0.0397125485324068, 0.0047647485735069495, 0.0828179884410929, 0.021344291490095202, 0.026963084128510673, 0.05822576000355184, 0.15839542087633163, 0.060900337775819935, 1.5709118242375553, 15.367099307477474, 20.338991917669773, 22.711523808538914, 20.013632476329803, 24.02772568166256, 14.60068803280592, 6.478981990367174, 3.2265408150851727, 0.5960102495737374, 0.7773857389111072, 1.5467650699429214, 5.021843779832125, 18.525193445384502, 24.30739637464285, 24.675663113594055, 30.012885220348835, 37.83681929111481, 44.435150027275085, 49.783914014697075, 51.718956381082535, 58.50205220282078, 54.49431985616684, 54.472676217556, 60.66452756524086, 62.69641533493996, 60.375651866197586, 61.35520130395889, 60.36744810640812, 62.60179281234741, 58.9569865912199, 58.26613426208496, 60.84873408079147, 63.557312339544296, 59.9408145993948, 61.85497708618641, 53.30882526934147, 48.120747059583664, 51.935787945985794, 49.69729386270046, 49.89229179918766, 48.33331145346165, 45.632374584674835, 47.19808056950569, 43.56724999845028, 46.74938924610615, 47.26817160844803, 45.98085008561611, 47.15929605066776, 51.702818647027016, 50.302935764193535, 44.77178156375885, 41.33255571126938, 45.54836869239807, 53.35726127028465, 43.02827171981335, 39.19088803231716, 39.929093420505524, 39.67308595776558, 39.822034165263176, 38.22894684970379, 37.568663880228996, 36.84582106769085, 38.03761571645737, 35.99753558635712, 35.45756176114082, 46.630843207240105, 48.13204005360603, 41.24652452766895, 43.543904051184654, 45.92188484966755, 47.28052854537964, 46.265394017100334, 43.3116415143013, 41.40056066215038, 43.83086085319519, 42.66461223363876, 44.73104774951935, 43.73007506132126, 42.432771474123, 43.504047989845276, 46.68039634823799, 45.827201530337334, 48.768038526177406, 47.42813162505627, 45.34306190907955, 53.642147183418274, 51.347666904330254, 56.9674551486969, 53.55231240391731, 53.302946984767914, 54.562985971570015, 50.932808965444565, 48.52307327091694, 50.90440168976784, 49.30810734629631, 51.05686090886593, 45.13297878205776, 47.75846689939499, 43.73469941318035, 35.274464786052704, 29.330352544784546, 24.983779080212116, 13.90325540676713, 0.9750593255739659, 0.9806368919089437, 0.3958502603927627, 0.2680819679517299, 0.05119536166603211, 0.09076734000700526, 0.008042281442612875, 0.0445240069529973, 0.058088685327675194, 0.039605590209248476, 0.12711552903056145, 0.06975079391850159, 0.05784273016615771, 0.020169718482065946, 0.0661478895926848, 0.03290710628789384, 0.020546176601783372, 0.045311481298995204, 0.00633084529908956, 0.05603597535809968, 0.0071654557632427895, 0.03664316303911619, 0.021005163398513105, 0.01753629094309872, 0.0678673418588005, 0.09211457552737556, 0.05157521882210858, 0.41874070710036904, 23.94210297614336, 41.372632160782814, 29.251409880816936, 21.10591236501932, 10.309244859963655, 7.989264149218798, 0.28685768076684326, 0.0820181387825869, 0.17428762279450893, 0.15913305629510432, 32.17740677297115, 42.49796837568283, 74.37184363603592, 45.035464614629745, 0.1273178236442618, 0.07843041879823431, 2.812854638323188, 2.244829055853188, 0.2870766440173611, 9.064574148505926, 47.06282302737236, 17.78755232691765, 3.6128862714394927, 1.6258816933259368, 6.851887805387378, 23.04250694811344, 46.20137505233288, 37.27223798632622, 45.76501026749611, 47.72804573178291, 35.48006795346737, 34.0072213858366, 0.6705895008053631, 0.08665970104630105, 0.07793444892740808, 0.11835426048492081, 0.05557352087635081, 0.034241317116538994, 0.12212270827149041, 0.04543174261925742, 0.10055086502688937, 0.09127538462053053, 0.04849978111451492, 0.09298761578975245, 2.2587481839582324, 17.42594663053751, 23.89217745512724, 25.186215117573738, 17.40570891648531, 27.00855553150177, 18.71345814317465, 7.344589317217469, 6.405523857101798, 0.8917566330637783, 2.2691812366247177, 8.313906379044056, 12.935542333871126, 22.639521472156048, 34.92798037827015, 37.8007972240448, 38.66116985678673, 42.59100638329983, 49.12669748067856, 52.78770603239536, 55.92261761426926, 60.58143362402916, 58.354574516415596, 56.68645262718201, 65.16400292515755, 65.42767077684402, 64.19131591916084, 63.934388905763626, 63.29869441688061, 64.9699929356575, 61.35809674859047, 61.65732689201832, 65.14811977744102, 66.60732507705688, 64.35105174779892, 65.0186151266098, 55.22905223071575, 52.17069514095783, 56.47311307489872, 53.36532823741436, 52.64126569032669, 49.80312578380108, 47.84522384405136, 49.726776480674744, 47.51706585288048, 49.837483540177345, 48.759872764348984, 48.21835622191429, 48.79411652684212, 51.71201415359974, 52.429058477282524, 50.193250849843025, 47.70777381956577, 49.34006743133068, 55.65984271466732, 44.34508726000786, 40.47269605100155, 40.24254620075226, 40.18172286450863, 39.73162181675434, 37.85594746470451, 37.79664784669876, 38.077874556183815, 37.49395988881588, 36.49502769112587, 37.69331619143486, 49.504002034664154, 49.08888950943947, 44.98555809259415, 46.128662154078484, 47.62918643653393, 49.65902231633663, 49.203829541802406, 45.15111900866032, 43.40884789824486, 45.36525271832943, 44.94369573891163, 47.3771383613348, 44.79779876768589, 45.78962914645672, 45.84711246192455, 48.833414018154144, 47.958446368575096, 51.576684415340424, 52.499297708272934, 47.607170417904854, 54.65805307030678, 53.5661094635725, 60.72517231106758, 56.974963545799255, 54.81102526187897, 56.02601006627083, 56.28471538424492, 54.10807058215141, 54.20024983584881, 54.62315574288368, 54.697882533073425, 48.3403866738081, 50.93244418501854, 47.61098921298981, 39.33212265372276, 30.848038606345654, 23.151314109563828, 12.520567551255226, 2.5303599843755364, 0.7331861543934792, 0.2828621951630339, 0.17928702640347183, 0.029402226682577748, 0.1381320136715658, 0.09150631129159592, 0.04236887318256777, 0.04208154699881561, 0.06362558939144947, 0.18289721861947328, 0.06761152355466038, 0.07386183191556484, 0.17277189006563276, 0.07225245499284938, 0.04612684184394311, 0.05228582893323619, 0.008201597356674029, 0.015670830398448743, 0.030541154337697662, 0.013597170527646085, 0.013582989013229962, 0.07575641619041562, 0.06268003387958743, 0.04516675879131071, 0.009213717949023703, 0.11329193759593181, 0.6248174537904561, 36.45859144628048, 46.313586831092834, 38.488951697945595, 31.10898580402136, 30.577563419938087, 1.822931757196784, 1.1528899613767862, 0.088021311967168, 0.2070717589231208, 0.24687383644049987, 50.38262128829956, 55.23277223110199, 81.88653320074081, 56.3749111443758, 0.16861317650182173, 0.11424281430663541, 2.320818090811372, 2.386759277433157, 0.6593808741308749, 14.72468487918377, 79.522854834795, 44.10495534539223, 23.891744278371334, 10.32457323744893, 9.591943100094795, 38.98403853178024, 63.104456439614296, 48.04873712360859, 67.96302393078804, 69.83676418662071, 45.00461407005787, 41.364135816693306, 0.7183224207255989, 0.1610213323147036, 0.19514267012709752, 0.25501049123704433, 0.1189103294746019, 0.1473586162319407, 0.17636329110246152, 0.12770158820785582, 0.16170453862287104, 0.18109080148860812, 0.224061330081895, 0.1548698780243285, 3.6773044522851706, 21.192154437303543, 26.580360308289528, 33.00771161913872, 33.12985986471176, 33.98293688893318, 22.59935572743416, 12.880979161709547, 6.66770551353693, 1.671663774177432, 4.167963098734617, 12.686118967831135, 20.48680018633604, 39.24291484057903, 46.777127757668495, 55.50772927701473, 49.97808739542961, 53.71001534163952, 57.152383625507355, 59.510381296277046, 59.08186309039593, 65.14606028795242, 61.083576679229736, 58.90638470649719, 67.63067856431007, 70.41226610541344, 67.77830824255943, 64.5427742600441, 64.89838197827339, 68.07551309466362, 64.40887704491615, 64.10918712615967, 65.4261888563633, 66.93625822663307, 67.72943526506424, 67.4588593840599, 58.06209281086922, 56.492324844002724, 59.31330867111683, 56.0941594094038, 54.93741028010845, 52.50421464443207, 49.35733750462532, 51.99507236480713, 50.38919873535633, 52.26950503885746, 51.462120562791824, 51.72688655555248, 51.399161741137505, 56.99141666293144, 54.57426756620407, 49.517749696969986, 50.65074250102043, 50.04657492041588, 59.22431744635105, 44.40363071858883, 40.35641089081764, 41.42080597579479, 40.6703120470047, 39.464241564273834, 39.86778371036053, 37.44725279510021, 37.44925528764725, 38.02488259971142, 38.70060794055462, 36.08286380767822, 49.329249411821365, 51.26002840697765, 46.99500046670437, 47.38075576722622, 48.91078546643257, 53.47365282475948, 54.30162079632282, 49.04787831008434, 45.75022146105766, 48.553828820586205, 49.52822953462601, 52.121689170598984, 49.912825897336006, 48.442832976579666, 48.739585652947426, 50.324545204639435, 49.155678525567055, 52.55658343434334, 53.36631238460541, 49.522541239857674, 57.29625530540943, 57.38877274096012, 63.9472322165966, 60.36223478615284, 57.597932517528534, 59.986989721655846, 59.853662475943565, 57.37927705049515, 57.45411403477192, 56.01054109632969, 56.59369200468063, 51.870917826890945, 53.13425123691559, 54.35592748224735, 48.258953243494034, 44.09540265798569, 38.90695586800575, 30.240445509552956, 16.51843372732401, 2.2249352233484387, 0.9104794159065932, 0.6127186655066907, 0.2070799670764245, 0.20516268792562187, 0.20369819307234138, 0.12115091041778214, 0.21528923360165209, 0.17459435242926702, 0.26191347395069897, 0.14543734432663769, 0.21715252893045545, 0.3297958814073354, 0.157191137841437, 0.14374616788700223, 0.13884664251236245, 0.0909791786398273, 0.1505450124386698, 0.13332525675650686, 0.12186565800220706, 0.10927930095931515, 0.16405248607043177, 0.06522544455947354, 0.14993560529546812, 0.11746413598302752, 0.24280639219796285, 0.8335001184605062, 47.39789664745331, 58.16833510994911, 50.13518996536732, 41.46869860589504, 45.454851910471916, 14.32965237647295, 1.4278162526898086, 0.1902145572239533, 0.26875224604737014, 3.6704629193991423, 75.46072840690613, 63.74397352337837, 91.5700551867485, 66.24643564224243, 0.5397206638008356, 0.16375259903725237], [0.3156719799153507, 0.6556494743563235, 0.08313087048009038, 5.03331346437335, 20.662785843014717, 2.7466545905917883, 2.7793022012338042, 0.6416884297505021, 2.1232384303584695, 4.650743817910552, 16.676404550671577, 28.688962161540985, 61.54346600174904, 48.05505618453026, 30.35779081285, 35.21231912076473, 1.633821486029774, 0.028950227206223644, 0.15448385733179748, 0.04841076792217791, 0.01906046374642756, 0.050871106213890016, 0.03341404510138091, 0.10597437634714879, 0.059946013789158314, 0.144436736300122, 0.042735234383144416, 0.25753572292160243, 2.697712266817689, 18.724099472165108, 12.149645704776049, 18.561099618673325, 24.586892277002335, 19.604603424668312, 14.683553036302328, 22.066808603703976, 3.685412504710257, 0.9828421985730529, 0.8154694922268391, 1.6420554067008197, 6.830562399700284, 8.393930085003376, 12.203869745135307, 18.05290348827839, 25.40940374135971, 28.48167758435011, 32.65361621975899, 42.54273757338524, 42.836777195334435, 50.10492458939552, 52.467026039958, 53.94175350666046, 58.858435079455376, 59.10956360399723, 61.58297248184681, 60.798056200146675, 57.508458718657494, 64.3920287489891, 57.443296015262604, 62.74314522743225, 62.20547787845135, 63.15151311457157, 61.771769151091576, 61.98979765176773, 50.23111201822758, 54.58986572921276, 56.64082087576389, 50.49409210681915, 48.888279274106026, 46.71086311340332, 46.399443224072456, 45.01255564391613, 44.4904712587595, 46.10824204981327, 46.61505505442619, 46.134829223155975, 47.601463124156, 49.81475315988064, 49.011624455451965, 50.30024170875549, 47.71788127720356, 49.087206199765205, 49.627681598067284, 51.7963620275259, 43.481819182634354, 43.38730685412884, 42.00020648539066, 38.53141441941261, 38.74765321612358, 38.6100360006094, 39.40936490893364, 37.89334885776043, 40.57267248630524, 45.794367492198944, 50.095656886696815, 45.78813582658768, 46.05010896921158, 44.87786427140236, 48.15658673644066, 46.892960742115974, 44.20117758214474, 43.41705925762653, 41.542232260107994, 42.6955159753561, 42.20788054168224, 44.2297026515007, 42.81438499689102, 42.09124580025673, 42.5701455026865, 44.849760979413986, 48.52238170802593, 47.50417694449425, 49.04524505138397, 45.64505070447922, 51.33143797516823, 49.00975115597248, 53.50826896727085, 54.866342693567276, 47.99159578979015, 51.225188076496124, 51.69101268053055, 50.163399651646614, 50.207021310925484, 50.34702479839325, 49.23453189432621, 43.81838612258434, 41.02552838623524, 34.76200148463249, 22.27528441697359, 12.535361107438803, 4.210631484165788, 0.39146051625721157, 0.06093110721849371, 0.011563149691937724, 0.11193316910066642, 0.06908217081218027, 0.04897411366982851, 0.049036097843782045, 0.07550272042863071, 0.034754170847008936, 0.152654314879328, 0.057041147592826746, 0.13093822781229392, 0.08775283262366429, 0.0520046848396305, 0.03838141761661973, 0.06158170355774928, 0.07011294714175165, 0.11428841185988858, 0.004677976203311118, 0.06701822101604193, 0.06279381253989413, 0.07638029521331191, 0.014220503144315444, 0.05819241159770172, 0.011697197332978249, 0.01760879506036872, 0.015600361621181946, 0.037334043154260144, 0.9532666043378413, 27.289010882377625, 37.924043610692024, 28.12554359436035, 20.168310776352882, 28.79554644227028, 8.56636768206954, 0.46040588698815554, 0.21483419317519292, 0.4634385695680976, 1.8234814214520156, 36.34561590850353, 45.060486271977425, 77.7615961432457, 40.943882167339325, 0.09336786999483593, 0.064108965016203, 0.8457267936319113, 1.120889384765178, 0.17691819492029026, 14.008525907993317, 47.540423199534416, 15.086766500025988, 3.0788417905569077, 1.940292853396386, 2.9693760769441724, 13.230405561625957, 38.35472010076046, 34.410455748438835, 75.4236575961113, 57.16606669127941, 32.604108676314354, 49.24340821802616, 2.6278950506821275, 0.08706401567906141, 0.1018936253967695, 0.01850257092883112, 0.021115465096954722, 0.06579520617378876, 0.05053496155596804, 0.07457321757101454, 0.0479724926117342, 0.08007800148334354, 0.030830378564132843, 0.1503651009988971, 2.6516264397650957, 21.07369389384985, 14.960552472621202, 25.448623336851597, 27.10347443819046, 28.84751245379448, 16.135136894881725, 21.888263784348965, 3.565234928391874, 1.7199273593723774, 1.9073164416477084, 3.2917450787499547, 8.750463053584099, 12.28824706748128, 16.080227941274643, 28.192581497132778, 34.7144166380167, 33.78363378345966, 38.49234491586685, 46.33676938712597, 51.61360703408718, 54.47894208133221, 56.679119020700455, 56.632598116993904, 63.600238636136055, 62.338295951485634, 67.20028325915337, 62.46119275689125, 62.03240476548672, 66.6365759074688, 60.016951113939285, 65.55408239364624, 64.56512466073036, 65.9605161845684, 63.61047148704529, 62.761483043432236, 51.8405232578516, 58.12461465597153, 58.45252946019173, 52.43665426969528, 52.8575386852026, 50.15153668820858, 49.459567219018936, 48.60931344330311, 47.766077890992165, 48.97575058043003, 49.82353448867798, 48.486352041363716, 49.50889617204666, 52.91867360472679, 54.8428675532341, 52.702290415763855, 49.217770993709564, 52.95362412929535, 51.33532516658306, 51.06109008193016, 44.619508534669876, 42.98087686300278, 41.85940504074097, 41.259637624025345, 37.80835501849651, 38.59898239374161, 40.8099165558815, 39.90965746343136, 41.88655838370323, 47.26244531571865, 51.763668581843376, 48.81698749959469, 47.710167691111565, 46.85830660164356, 47.575768902897835, 49.584010541439056, 44.93160478770733, 45.479144006967545, 44.00195047259331, 43.92014466226101, 44.09268580377102, 46.30143128335476, 45.87439879775047, 44.56357553601265, 45.985645428299904, 48.20466935634613, 51.29192769527435, 50.89938975870609, 54.011437967419624, 51.009754836559296, 53.32839421927929, 53.13302390277386, 54.90985035896301, 57.35930532217026, 51.38305440545082, 54.87649194896221, 56.583823934197426, 53.85153494775295, 55.13240061700344, 52.883544489741325, 51.91973760724068, 46.54567077755928, 44.50907126069069, 39.84209708869457, 22.435685209929943, 13.754280600696802, 6.418516784906387, 1.0535708907991648, 0.11886585256434046, 0.08134137431625277, 0.1054298848612234, 0.13742388604441658, 0.045988620549906045, 0.08193360816221684, 0.036184471246087924, 0.07766252601868473, 0.0705632971948944, 0.09340767879621126, 0.092007847269997, 0.11668213497614488, 0.03736332459084224, 0.057592040102463216, 0.04496158835536335, 0.12447535351384431, 0.04243878720444627, 0.032250216536340304, 0.05308543739374727, 0.025521067072986625, 0.03029564075404778, 0.029909150653111283, 0.050831742701120675, 0.015007817000878276, 0.09738708205986768, 0.06074937751691323, 0.02702885882172268, 2.1439506439492106, 41.30116939544678, 47.83728986978531, 37.056922540068626, 25.178288742899895, 50.67366287112236, 29.838713966310024, 0.27610158605966717, 0.3155196615261957, 0.471143220202066, 10.601326636970043, 59.82338950037956, 48.502387180924416, 88.82646560668945, 43.552214205265045, 0.047833725839154795, 0.24983962182886899, 0.5963201110716909, 1.2001802050508559, 0.7357558258809149, 20.797617807984352, 79.79308113455772, 37.49024748802185, 27.26293098181486, 6.061935368925333, 2.525455397553742, 42.646870985627174, 59.087330996990204, 53.147729113698006, 84.69444572925568, 62.99903489649296, 41.64187051355839, 56.2695237994194, 2.035501138307154, 0.15577604033751413, 0.2597304910887033, 0.13313109608134255, 0.06927268754225224, 0.2862867317162454, 0.14089966047322378, 0.17903790227137506, 0.2215679216897115, 0.22014200367266312, 0.12446815468138084, 0.4137079365318641, 2.9065452609211206, 25.07590513676405, 18.336843252182007, 29.599509201943874, 30.282144472002983, 27.408062294125557, 19.948460273444653, 30.007926486432552, 10.292129628360271, 3.457374391146004, 2.4396709632128477, 4.754176642745733, 14.095437694340944, 17.48535454273224, 26.50966890156269, 42.021827325224876, 49.91040162742138, 46.977031230926514, 50.12084573507309, 57.14184679090977, 57.94624462723732, 60.83131581544876, 59.14533868432045, 60.97920387983322, 65.38797810673714, 65.7877242565155, 69.22746688127518, 66.81483194231987, 62.78389424085617, 70.06668984889984, 62.44263835251331, 68.5894127190113, 67.00539171695709, 69.37374383211136, 67.3515835404396, 68.43430504202843, 54.45849917829037, 58.401634991168976, 60.50859533250332, 55.53697630763054, 56.05599045753479, 53.954182639718056, 51.573408991098404, 49.927565306425095, 48.203138038516045, 50.78873589634895, 52.2107107937336, 51.981408298015594, 53.046164363622665, 55.63061088323593, 55.65228492021561, 53.62243764102459, 51.74419842660427, 55.571273267269135, 55.09287513792515, 56.30500249564648, 44.32478114962578, 44.52565357089043, 41.30277670919895, 42.010883912444115, 38.81424844264984, 37.65401490032673, 40.13395182788372, 39.11917448043823, 41.950839534401894, 49.663380682468414, 53.13399665057659, 50.57120516896248, 51.17049001157284, 49.12352845072746, 49.731518626213074, 50.86757406592369, 49.285437762737274, 50.406480208039284, 46.65560647845268, 46.82142578065395, 46.52147367596626, 49.16492722928524, 48.412939980626106, 49.899146631360054, 48.1123761087656, 51.85804411768913, 53.06444898247719, 53.09292085468769, 54.04788561165333, 54.67883035540581, 58.262862637639046, 54.44915547966957, 58.855760022997856, 60.023357570171356, 51.90855860710144, 58.642048090696335, 59.72559034824371, 56.59056477248669, 55.91217577457428, 55.90466357767582, 54.21604938805103, 49.22059424221516, 49.136538952589035, 49.42411132156849, 37.413476407527924, 36.30038693547249, 18.552158698439598, 6.4484387543052435, 0.6633275561034679, 0.2459802312660031, 0.21920723898801953, 0.2768729446688667, 0.21683152037439868, 0.13754000246990472, 0.2220372558804229, 0.157022581261117, 0.2789443085202947, 0.27600368193816394, 0.211791877518408, 0.21469349681865424, 0.1734821847639978, 0.3702493419405073, 0.1284683751873672, 0.3331542480736971, 0.25989601970650256, 0.24303016456542537, 0.16588140511885285, 0.1575793552910909, 0.1390639433520846, 0.10810776890139095, 0.18476137483958155, 0.1407136782654561, 0.25713995040860027, 0.16175114549696445, 0.16989884345093742, 2.5369927659630775, 57.192292883992195, 58.47041890025139, 47.699509263038635, 36.43233485519886, 62.756851091980934, 35.54540164768696, 0.5676182324532419, 0.34061532584019005, 0.8185414492618293, 8.830158077180386, 76.3577538728714, 63.38421642780304, 107.6251132786274, 59.036162942647934, 0.16668415657477453, 0.490247318521142], [0.11914766830159351, 0.06903895555296913, 0.4609556699870154, 3.700983594171703, 19.821890965104103, 2.0256561040878296, 7.539630001410842, 0.32803007459733635, 0.8380320877768099, 6.676911944523454, 14.164813421666622, 40.68214841187, 75.15884980559349, 60.261771976947784, 33.86271893978119, 45.33778019249439, 6.099225617945194, 0.5380493472330272, 0.24608977226307616, 0.1751613087253645, 0.0753381046524737, 0.11045486287912354, 0.04285237126168795, 0.05554294810281135, 0.06409856752725318, 0.09049534288351424, 0.13267143949633464, 0.07596143448608927, 6.073412653058767, 25.137710720300674, 11.347166765481234, 14.61554428562522, 21.212863326072693, 16.027845852077007, 16.290174275636673, 11.495871786028147, 8.567843902856112, 1.6482693795114756, 0.3846820065518841, 0.11714326101355255, 2.897494384087622, 7.168962741270661, 6.384048834443092, 13.557111080735922, 16.84040755033493, 25.188139714300632, 26.87425933778286, 30.416130982339382, 42.88987174630165, 48.15995715558529, 48.26497972011566, 46.33217163383961, 57.31345698237419, 57.7810674905777, 62.071660459041595, 59.290247708559036, 60.257698595523834, 61.334743201732635, 60.41560672223568, 62.679031267762184, 65.40601953864098, 62.6578664034605, 62.81497657299042, 56.96307398378849, 50.75050614774227, 58.60213503241539, 53.94585348665714, 49.81322564184666, 48.243955448269844, 47.2714052349329, 44.085230603814125, 46.89875543117523, 45.36765418946743, 47.513418048620224, 46.59878812730312, 47.29225091636181, 49.397987723350525, 47.67431281507015, 50.612345561385155, 51.001136898994446, 49.77523148059845, 54.911533668637276, 50.79358823597431, 48.11534754931927, 49.325708001852036, 51.64979629218578, 48.983798548579216, 45.734212920069695, 40.34154988825321, 42.74794936180115, 46.1505451798439, 47.233395874500275, 45.2787009626627, 48.020151257514954, 49.75463658571243, 49.57252375781536, 47.53844350576401, 44.946530386805534, 45.84848038852215, 45.302297696471214, 44.68660153448582, 41.924978122115135, 42.959256023168564, 42.28586755692959, 43.04419666528702, 42.23422832787037, 42.057249024510384, 40.466939359903336, 43.916565254330635, 44.1549264639616, 46.94649986922741, 48.253971710801125, 54.916051626205444, 49.5423723757267, 50.47524131834507, 53.45799006521702, 49.45982180535793, 53.83035108447075, 51.376739144325256, 46.88395902514458, 51.820828914642334, 48.33066299557686, 47.72922746837139, 47.78715915977955, 45.105867236852646, 36.85764603316784, 33.561554700136185, 23.61093744635582, 8.985868021845818, 7.109049456194043, 1.0610326216556132, 0.08674318523844704, 0.04552155362034682, 0.03759698236535769, 0.03286253660917282, 0.03933776024496183, 0.12343751935986802, 0.034068070162902586, 0.10184835438849404, 0.006357264364851289, 0.04621548767318018, 0.13696976588107646, 0.17085358675103635, 0.1555916908546351, 0.0489341453067027, 0.21444958256324753, 0.023003937785688322, 0.07482647546567023, 0.021558595908572897, 0.0906367962306831, 0.02394019789790036, 0.06096721641370095, 0.028516636702988762, 0.031519902404397726, 0.049485739145893604, 0.02659045178006636, 0.09756746105267666, 0.02096115960739553, 0.041388510944671, 1.4260748773813248, 34.53999079763889, 41.20730683207512, 34.867548421025276, 19.572244361042976, 34.84940819442272, 28.979703560471535, 2.3668122477829456, 3.0873025115579367, 12.270532418042421, 39.456448182463646, 40.36020688712597, 46.87477871775627, 74.44185867905617, 21.73768736422062, 0.45424303330946714, 0.13682172226253897, 0.3912559209857136, 0.30948211206123233, 0.48854771128389984, 13.627605848014355, 52.5173619389534, 11.191457770764828, 7.7364228665828705, 1.3992419047281146, 1.3956073997542262, 11.505998242646456, 39.25637751817703, 47.685214430093765, 87.05424830317497, 64.29729983210564, 39.27308902144432, 57.986226081848145, 9.447522349655628, 0.5970174330286682, 0.2477664322941564, 0.15111600601812825, 0.07108089324901812, 0.10431796210468747, 0.008520943501935108, 0.04137478492339142, 0.035081584137515165, 0.049585201777517796, 0.1610192988300696, 0.07707205848419107, 5.441944487392902, 25.009355507791042, 15.725305136293173, 21.633964329957962, 26.153381019830704, 14.070818815380335, 21.313512325286865, 17.299312725663185, 9.859422147274017, 2.0289550395682454, 1.0033323615789413, 1.086459313519299, 5.737419482320547, 7.132071470841765, 7.19122527167201, 15.274317786097527, 23.17611537873745, 30.5401012301445, 32.83489689230919, 35.700695514678955, 46.89723551273346, 51.711976155638695, 51.82981923222542, 49.06808942556381, 61.393826231360435, 58.836559653282166, 67.6646639406681, 61.40076085925102, 65.59027925133705, 64.46531161665916, 62.43410401046276, 66.2196546792984, 66.98489561676979, 63.79016384482384, 66.17740854620934, 56.51409387588501, 53.7480740994215, 59.652368277311325, 55.02043582499027, 51.09618119895458, 51.660070940852165, 48.60955663025379, 47.064567133784294, 48.74946132302284, 46.64542682468891, 49.07308615744114, 48.82430590689182, 49.58544686436653, 50.54079160094261, 49.004686027765274, 52.10861027240753, 54.310094341635704, 54.313791543245316, 56.552076637744904, 55.159690752625465, 49.17994782328606, 52.455812841653824, 54.42179694771767, 52.45753034949303, 46.848506927490234, 42.078790068626404, 44.19665962457657, 50.250627771019936, 50.883081033825874, 47.712405771017075, 49.92914222180843, 52.182907685637474, 52.89954923093319, 52.08466775715351, 49.63072903454304, 47.977517545223236, 46.4162041246891, 46.61219380795956, 43.039743304252625, 45.487856939435005, 44.14688229560852, 45.552461072802544, 44.53027792274952, 43.71448829770088, 46.40287823975086, 46.779795214533806, 47.341032698750496, 51.38952925801277, 53.0004908144474, 58.331027179956436, 53.139513954520226, 52.917723655700684, 57.853586599230766, 51.55758664011955, 55.62660209834576, 53.80641996860504, 48.28521743416786, 54.84857864677906, 52.90299944579601, 53.18298742175102, 50.536858811974525, 49.3253356218338, 39.58686478435993, 37.29024522006512, 25.825285725295544, 12.771328445523977, 6.790155842900276, 1.1225035856477916, 0.03920535738870967, 0.06744010228430852, 0.21136762137757614, 0.06472304026829079, 0.0690673798089847, 0.015606729248247575, 0.011049040804209653, 0.015125244244700298, 0.034980069467565045, 0.12164313986431807, 0.13312658382346854, 0.19680653553223237, 0.06842105824034661, 0.06728221036610194, 0.3530616470379755, 0.059589289376162924, 0.03460145540884696, 0.07254594471305609, 0.043075249341200106, 0.03573130474251229, 0.049365117884008214, 0.055441633812733926, 0.02070878486847505, 0.04087213572347537, 0.03986295960203279, 0.06645730580203235, 0.14868501224555075, 0.022671847109450027, 3.263808502815664, 51.403200924396515, 49.99028094112873, 42.2911074757576, 25.560852214694023, 45.66579759120941, 52.60140962898731, 3.980270982719958, 5.250905938446522, 23.565218299627304, 55.72399087250233, 53.30663658678532, 53.86954218149185, 87.15989783406258, 18.694421164691448, 0.512029827805236, 0.2608606335707009, 0.3517069306690246, 0.36483433563262224, 0.8213107287883759, 24.68359138816595, 87.88162350654602, 31.41880787909031, 30.676971785724163, 2.257608720101416, 1.5218531317077577, 42.80927047133446, 61.27367667853832, 66.82674810290337, 92.24616810679436, 69.13709253072739, 42.78160035610199, 69.96119230985641, 8.588506244122982, 0.6520702445413917, 0.20938929315889254, 0.24581531120929867, 0.20276702038245276, 0.2992399991489947, 0.15773639373946935, 0.18215671851066872, 0.19985913735581562, 0.22147472278447822, 0.1886294485302642, 0.5309075117111206, 6.139036081731319, 33.57612691819668, 18.958345502614975, 27.81476777046919, 37.423177286982536, 28.622665219008923, 24.920058399438858, 16.748213097453117, 14.516889229416847, 5.155116403475404, 1.3910151086747646, 1.126032171305269, 5.9323466476053, 9.90102231502533, 10.682647973299026, 21.34489294141531, 32.573273330926895, 45.23818753659725, 45.29234603047371, 45.435024574398994, 55.69713391363621, 58.88081967830658, 56.892743557691574, 55.09511701762676, 66.52886688709259, 64.24706652760506, 69.4609947502613, 62.99279183149338, 66.08443513512611, 69.7136127948761, 65.0228101015091, 69.08879712224007, 68.4142193198204, 68.91589879989624, 67.51033142209053, 61.35134071111679, 54.636021852493286, 62.75799863040447, 57.13445618748665, 55.24852618575096, 54.0843066573143, 52.27690704166889, 49.02016639709473, 52.852279767394066, 50.63700623810291, 51.1050309240818, 51.710836216807365, 54.30906839668751, 55.12456163764, 51.03761114180088, 53.38211573660374, 55.760237127542496, 54.98877972364426, 58.32333639264107, 56.058737710118294, 54.675011560320854, 55.304774567484856, 56.9695108383894, 54.05424267053604, 47.81391352415085, 43.70910778641701, 45.876313894987106, 50.47462575137615, 51.387678757309914, 50.81936605274677, 54.604677334427834, 53.972550854086876, 53.278388902544975, 55.86261123418808, 49.626936838030815, 48.58026780188084, 49.852523133158684, 51.409212201833725, 46.49979203939438, 50.06628826260567, 48.88747751712799, 48.38006794452667, 47.76084937155247, 47.917883545160294, 48.666488975286484, 48.5497972369194, 50.24696856737137, 52.9823961853981, 53.85660767555237, 61.12472087144852, 53.232168182730675, 57.461964413523674, 60.34992724657059, 55.61467833817005, 58.87519218027592, 57.08864964544773, 50.244426503777504, 57.40943223237991, 54.65969838202, 55.306910052895546, 53.43901768326759, 51.48578569293022, 44.60339739918709, 45.95883026719093, 42.47819043695927, 28.787260986864567, 12.629930432885885, 2.8979902574792504, 0.27304209710564464, 0.1913405436789617, 0.2531876874854788, 0.12499988864874467, 0.11395876470487565, 0.3017926309257746, 0.06739796313922852, 0.12233253568410873, 0.3268739866325632, 0.3406011953484267, 0.3591197688365355, 0.6371954677160829, 0.397671609534882, 0.24862445890903473, 0.802522636950016, 0.11628226580796763, 0.14684833033243194, 0.12301809460041113, 0.17923249339219183, 0.14723046217113733, 0.13035801675869152, 0.16873068816494197, 0.16237313946476206, 0.1382556851604022, 0.10975215293001384, 0.20230809110216796, 0.23962771432707086, 0.3573615913046524, 5.28485331684351, 65.63025310635567, 60.40142588317394, 54.06251862645149, 35.43521896004677, 56.222611516714096, 70.40329098701477, 5.004720948636532, 6.258389102295041, 22.936806119978428, 60.753773376345634, 70.7372398674488, 68.93852278590202, 106.24377340078354, 33.34070675075054, 0.534599726088345, 0.6168836576398462], [0.0502966542262584, 0.03774799457460176, 0.14637335581937805, 5.65150466747582, 22.572793252766132, 5.642266888171434, 9.349684249609709, 7.8337019216269255, 0.3683654742781073, 10.763767920434475, 19.11808893084526, 41.399481520056725, 90.91587468981743, 97.82443597912788, 65.00881925225258, 49.12145376205444, 16.17172323167324, 0.869723871583119, 0.10372950579039752, 0.14560124021954834, 0.12710773647995666, 0.07320307937334292, 0.06442192126996815, 0.04135666538786609, 0.025195039743266534, 0.06369060894940048, 0.06580731060239486, 0.4644343536347151, 8.894453477114439, 12.939856052398682, 10.01111950725317, 2.886642166413367, 18.34294382482767, 29.870744347572327, 22.379799708724022, 15.161804873496294, 19.743430875241756, 5.309312604367733, 0.8914834633469582, 0.3909783874405548, 1.0568180540576577, 5.116777885705233, 7.0853187795728445, 6.761659272015095, 10.678040720522404, 19.835289046168327, 34.80803221464157, 33.279568031430244, 33.68524946272373, 40.009850487113, 48.9275311678648, 46.57457962632179, 51.878627613186836, 52.783051282167435, 58.132818415760994, 56.95040166378021, 63.598376736044884, 60.34682661294937, 61.91349394619465, 62.46280387043953, 62.871107161045074, 63.921363204717636, 60.67370407283306, 48.82761932909489, 58.70241165161133, 58.834450766444206, 52.96999365091324, 50.22649526596069, 50.31408816576004, 45.939675495028496, 44.50957663357258, 44.49935898184776, 42.11640805006027, 45.75687110424042, 47.65390790998936, 44.38305862247944, 48.21182817220688, 46.41213834285736, 50.38638688623905, 50.52902743220329, 52.860202342271805, 56.07527442276478, 50.74061907827854, 50.05102068185806, 49.482384994626045, 47.95746602118015, 48.17710943520069, 48.868752121925354, 45.82058608531952, 45.870447009801865, 48.26190948486328, 46.92622795701027, 46.08827792108059, 46.66851058602333, 51.297350004315376, 56.518729627132416, 50.78015215694904, 46.785472109913826, 49.220738634467125, 43.134688809514046, 41.363516449928284, 38.347796872258186, 41.50744512677193, 42.17670701444149, 42.208397313952446, 42.32838347554207, 41.84958256781101, 41.88180483877659, 43.240007758140564, 44.486584067344666, 47.687125727534294, 50.285810083150864, 54.215247631073, 53.10465082526207, 50.48237733542919, 53.03575672209263, 50.462287813425064, 52.02390521764755, 50.99708631634712, 43.33518125116825, 45.93927651643753, 48.205041736364365, 48.844562619924545, 46.9228233397007, 39.98509481549263, 30.903167948126793, 25.08399300277233, 12.514163944870234, 6.892783110961318, 0.28545279521495104, 0.21523005474591628, 0.0438787058374146, 0.0508158013690263, 0.0521094352734508, 0.02626253197377082, 0.031716860976302996, 0.043061556716565974, 0.010700708226067945, 0.06804634045693092, 0.0926894653821364, 2.4360338458791375, 2.574773426167667, 2.975622941739857, 3.8894335320219398, 0.8936948259361088, 0.15763182513182983, 0.12866096250945702, 0.060467680523288436, 0.05293263660860248, 0.08669529444887303, 0.039314126552199014, 0.17512307327706367, 0.0674582997453399, 0.0704604281054344, 0.06020772845658939, 0.03132821679173503, 0.07672663326957263, 0.006498432449006941, 0.07826702756574377, 2.3550226679071784, 41.46456062793732, 48.79258140921593, 36.92472763359547, 24.87009108066559, 21.38681799173355, 38.10541547834873, 18.651044592261314, 13.771675117313862, 39.59966629743576, 32.946173921227455, 39.88965153694153, 63.68755415081978, 49.82547238469124, 1.273739745374769, 0.24896495626308024, 0.08085511915851384, 0.08720166180864908, 0.22613680543145165, 0.2541024883976206, 13.015083465725183, 54.850581139326096, 14.132234919816256, 11.054904498159885, 12.076711468398571, 0.5281081306748092, 15.423853062093258, 38.436943888664246, 52.712101489305496, 101.37750372290611, 102.51091450452805, 72.71622687578201, 60.5082343518734, 21.92665882408619, 0.8384833135642111, 0.21690708585083485, 0.07708765100687742, 0.26089189283084124, 0.09552605770295486, 0.08429337802226655, 0.028416938439477235, 0.041548332446836866, 0.06305357906967402, 0.014969908097555162, 0.3730297239962965, 11.424315925687551, 24.3410549685359, 13.93846146762371, 11.036939062178135, 29.53848447650671, 38.41476067900658, 20.82054577767849, 18.993149735033512, 14.206821117550135, 4.102877816185355, 0.09498974468442611, 0.293451544130221, 1.2897358182817698, 5.0094597693532705, 7.210988961160183, 6.990354275330901, 11.385458260774612, 25.275006853044033, 37.23877318203449, 37.5596621632576, 39.73927080631256, 45.07508888840675, 54.83521096408367, 51.3610003888607, 56.18334822356701, 53.24247322976589, 61.785858795046806, 57.515492141246796, 66.27158269286156, 61.32940448820591, 64.25101071596146, 63.30718316137791, 63.199622333049774, 65.81351727247238, 60.62716417014599, 51.8220866471529, 61.99563413858414, 61.01217471063137, 56.9776576012373, 53.8761880248785, 52.13654637336731, 48.2421163469553, 47.782918587327, 47.60509952902794, 47.673902437090874, 47.98583909869194, 48.82593221962452, 45.61753258109093, 50.54373264312744, 48.783009722828865, 52.83386215567589, 50.33687174320221, 54.26424980163574, 59.17302779853344, 52.910735830664635, 52.51282878220081, 52.92428210377693, 49.93025176227093, 48.787117302417755, 51.28838628530502, 48.173640221357346, 47.20148518681526, 50.207606479525566, 48.890315964818, 48.23274984955788, 48.650419637560844, 52.718325555324554, 55.85427448153496, 52.77168229222298, 49.89906303584576, 51.01328484714031, 44.7765427082777, 43.626697808504105, 41.304023042321205, 44.5657642185688, 43.80984038114548, 45.36414697766304, 44.43322733044624, 43.22981670498848, 44.83983211219311, 46.64605759084225, 47.61876359581947, 50.38910374045372, 53.1425803899765, 56.59308023750782, 56.110422536730766, 52.65106536448002, 56.10461264848709, 51.921185329556465, 53.097674399614334, 54.07407000660896, 46.26217558979988, 49.18201491236687, 52.98769690096378, 51.87796264886856, 51.50385372340679, 45.96032738685608, 36.3164334744215, 29.218264259397984, 14.990867245942354, 5.71492706425488, 0.5327515408862382, 0.077037548617227, 0.05059610339230858, 0.06828045094152912, 0.0333454595238436, 0.019829701668641064, 0.11325028084684163, 0.12768668588250875, 0.021200541195867117, 0.023967158267623745, 0.11662812146823853, 2.7877838211134076, 2.4658639077097178, 2.740594153292477, 4.965792987495661, 1.7335376353003085, 0.31308989971876144, 0.14737617544597015, 0.0658690053387545, 0.04169610889221076, 0.04859199296333827, 0.07577095486340113, 0.03819631485384889, 0.027406326262280345, 0.05800021390314214, 0.03226670334697701, 0.08712723181815818, 0.0795737121370621, 0.04064640037540812, 0.21723964222474024, 4.985914332792163, 54.26004722714424, 55.898184925317764, 44.2596298456192, 31.780265383422375, 32.87626527249813, 54.50527086853981, 35.319579765200615, 23.109294064342976, 50.81335477530956, 41.8331066519022, 48.603951930999756, 71.06130167841911, 53.05943325161934, 0.7773873419500887, 0.11476167943328619, 0.1810755577753298, 0.23852912796428427, 0.2645965456031263, 0.44253022118937224, 21.690809279680252, 91.59702613949776, 37.350585982203484, 33.16294088959694, 18.249913416802883, 0.4632000136189163, 41.60513028502464, 54.295191541314125, 60.659010261297226, 105.76036334037781, 110.84387496113777, 73.1966882944107, 74.9462816119194, 22.73933831602335, 1.4148585917428136, 0.21843329770490527, 0.2237860081368126, 0.33845140133053064, 0.20311355881858617, 0.09595973169780336, 0.1022355625173077, 0.2370187090127729, 0.11524538902449422, 0.1911464869044721, 0.6920901127159595, 13.875130265951157, 30.331574119627476, 25.54313186556101, 14.747116975486279, 33.28934110701084, 47.36636593937874, 27.563715241849422, 23.808830827474594, 26.384640410542488, 12.254037503153086, 5.440697679296136, 0.46796997485216707, 1.3440004689618945, 5.538559053093195, 8.65887276828289, 8.753715679049492, 15.090130269527435, 33.3205222338438, 47.216657772660255, 47.5422129034996, 49.141820669174194, 53.471277952194214, 59.47364866733551, 54.613150879740715, 61.23479336500168, 59.30240325629711, 64.27850604057312, 60.01309432089329, 71.71769365668297, 65.02974092960358, 68.88595640659332, 66.34942531585693, 69.40935552120209, 68.19234162569046, 66.45786389708519, 54.318936467170715, 63.891048431396484, 64.40402090549469, 60.914394557476044, 57.9812141507864, 56.93863369524479, 51.52829401195049, 50.26083402335644, 49.65118333697319, 46.95105962455273, 50.53244344890118, 53.245760053396225, 49.654549956321716, 53.85581731796265, 50.85577569901943, 56.525272876024246, 55.79569302499294, 59.12385083734989, 63.007162660360336, 57.51655988395214, 56.5782268345356, 55.61730779707432, 53.79605412483215, 53.82608391344547, 54.95439916849136, 50.31217306852341, 51.14373564720154, 53.37455414235592, 53.170512691140175, 51.404831036925316, 51.76816374063492, 56.55849449336529, 61.24243475496769, 55.442080199718475, 53.59242685139179, 53.54924216866493, 49.54986557364464, 46.84700220823288, 43.62558826804161, 48.645479902625084, 48.129794374108315, 49.47129338979721, 49.485223442316055, 46.77907705307007, 47.60840155184269, 48.60873207449913, 51.385775059461594, 52.239213064312935, 55.87237291038036, 57.24821448326111, 58.51992264389992, 54.63564947247505, 60.641952976584435, 54.26522254943848, 56.84480533003807, 54.600717946887016, 47.453084886074066, 50.65911345183849, 54.97996799647808, 56.56309984624386, 53.127354606986046, 51.3297014683485, 40.53097352385521, 39.555106088519096, 32.529951855540276, 11.660695541650057, 2.0870805205777287, 0.6874070421326905, 0.18482181534636766, 0.14437577628996223, 0.11162189010065049, 0.13549734489060938, 0.21476492111105472, 0.15736981731606647, 0.18603157543111593, 0.12599984358530492, 0.37931102444417775, 4.323994126170874, 3.8913854397833347, 3.8722743652760983, 7.409525457769632, 2.6129891630262136, 0.3169620700646192, 0.23330748081207275, 0.14268661849200726, 0.19855657912557945, 0.19278421386843547, 0.20075922890100628, 0.33541999524459243, 0.13905021362006664, 0.16451239498564973, 0.16740035876864567, 0.20940643677022308, 0.2934941730927676, 0.21268619515467435, 0.5153460998553783, 8.562885168939829, 69.80666220188141, 60.865627974271774, 57.37447030842304, 38.89445073902607, 34.61813360452652, 60.25496654212475, 43.09750020503998, 29.653192721307278, 66.69731944799423, 54.62988518178463, 73.68616282939911, 89.6989443898201, 91.01725324988365, 2.781546930782497, 0.3175697405822575, 0.2508189302170649], [0.19321014726301655, 0.647018178133294, 0.12576130247907713, 3.3061911910772324, 20.516774877905846, 10.105310752987862, 10.24914538487792, 23.596203736960888, 5.783388465642929, 23.122061379253864, 33.73899757862091, 42.72727847099304, 87.0595832169056, 95.95558226108551, 53.778202682733536, 49.031132608652115, 26.46978434175253, 0.9625775890890509, 0.37282723642420024, 0.24891431210562587, 0.04661300052248407, 0.08820198781904764, 0.03409578937862534, 0.09276509765186347, 0.046044667542446405, 0.2381740399869159, 0.03447124930971768, 0.8614886447321624, 6.4632004871964455, 8.801720403134823, 8.194417040795088, 2.253622259013355, 6.059302110224962, 28.416989855468273, 45.910390466451645, 30.869366861879826, 36.865891590714455, 18.048913702368736, 7.454222934320569, 0.7748617837205529, 1.4178718300536275, 0.929451797856018, 3.106597876176238, 2.93364018201828, 4.261987628415227, 8.294014446437359, 30.188017822802067, 33.38842459022999, 39.871845692396164, 38.93971011042595, 42.34937734901905, 46.557833924889565, 50.125386491417885, 49.95529621839523, 57.68896423280239, 55.820631086826324, 55.92798292636871, 56.61393731832504, 58.83865714073181, 61.293469816446304, 59.019922614097595, 61.95288263261318, 55.37830822169781, 55.5732187628746, 61.79060474038124, 58.35618942975998, 53.06865535676479, 51.3836395740509, 45.17084755003452, 44.08831223845482, 46.64691634476185, 42.41658054292202, 46.31716623902321, 44.287391155958176, 44.373802319169044, 43.17729972302914, 43.60307827591896, 45.98857507109642, 47.634509950876236, 50.337426513433456, 50.37346377968788, 49.89852346479893, 50.139571130275726, 47.49391369521618, 49.45112407207489, 47.99915358424187, 47.08394609391689, 48.78997474908829, 48.681680560112, 47.116130366921425, 44.76022258400917, 46.04934900999069, 48.22724014520645, 46.982229351997375, 47.42502339184284, 49.29714493453503, 46.693433448672295, 46.245422288775444, 44.70096476376057, 40.531611889600754, 40.778328850865364, 40.524453073740005, 41.735147908329964, 41.19292460381985, 40.29225133359432, 41.52481019496918, 42.5089155882597, 44.45576012134552, 43.74694615602493, 41.8316475301981, 47.22049556672573, 50.655188262462616, 55.67164108157158, 54.30742688477039, 49.721221178770065, 50.95337726175785, 51.77293248474598, 47.33755588531494, 50.316957011818886, 42.48196363449097, 45.25511182844639, 46.31878115236759, 47.67416462302208, 40.273894518613815, 36.48737870156765, 24.367712438106537, 11.719652228057384, 6.169580742716789, 0.3874435380566865, 0.20432158227777109, 0.039291383436648175, 0.08333946592756547, 0.050073082238668576, 0.08653503507957794, 0.09162763759377412, 0.106154970562784, 0.03915839428373147, 0.05145894654560834, 0.3704727877629921, 1.1055177845992148, 1.4106123195961118, 9.059002697467804, 13.954490907490253, 8.629830926656723, 3.1466807378455997, 0.6507937505375594, 0.6026176793966442, 0.07740413246210665, 0.05617833412543405, 0.027272073602944147, 0.06827801669714972, 0.07806633599102497, 0.0681051259743981, 0.010669533385225805, 0.04643918953661341, 0.07908498562755994, 0.024869229491741862, 0.10050965356640518, 0.3144753410015255, 8.01067790016532, 52.05261267721653, 53.79157416522503, 41.757342517375946, 25.69401226937771, 26.47162724286318, 27.68647525459528, 37.745912969112396, 33.13325688242912, 29.937164783477783, 30.617504976689816, 36.8235694617033, 33.95949974656105, 5.2625988610088825, 0.19210443628253415, 0.021311592463462148, 0.25548083474859595, 0.08197999981348403, 0.5189180269371718, 0.08614557082182728, 5.9379826951771975, 43.99142503738403, 18.8651555031538, 10.76638787984848, 33.02739076316357, 9.349497109651566, 29.73620306700468, 50.63121534883976, 49.70085047185421, 97.32291609048843, 101.33373767137527, 57.051787823438644, 63.06129075586796, 38.86094033718109, 0.8496354182716459, 0.35321536066476256, 0.03593663845094852, 0.10908551135798916, 0.015008531318017049, 0.05565708299400285, 0.029357688545132987, 0.034052358896587975, 0.09545928667648695, 0.08175392678822391, 0.6509072694461793, 7.969357017427683, 23.569035194814205, 14.710485991090536, 5.392498215660453, 14.287455640733242, 40.59047073125839, 45.677204579114914, 23.14942181110382, 34.832996875047684, 13.299432657659054, 3.274616072885692, 0.6936067063361406, 0.7602941372897476, 1.6541353147476912, 3.7353703239932656, 2.521923487074673, 3.930460880510509, 10.556110963225365, 30.2959643304348, 37.56004974246025, 45.327980518341064, 44.54502113163471, 47.97144167125225, 50.421204417943954, 54.52911838889122, 54.09855969250202, 57.69069693982601, 58.8641993701458, 59.19262334704399, 58.33019122481346, 58.93170274794102, 62.73102767765522, 62.27508634328842, 67.07356005907059, 56.7418422549963, 58.69206480681896, 63.49378354847431, 60.16669347882271, 56.971482932567596, 52.58607745170593, 47.24303975701332, 46.48262456059456, 50.224181190133095, 45.7238394767046, 48.673822581768036, 46.86546541750431, 45.17703741788864, 47.075415551662445, 46.10025867819786, 48.45807395875454, 48.58751781284809, 52.57027789950371, 50.53367458283901, 51.48445576429367, 50.52058048546314, 47.88338139653206, 53.96732233464718, 50.95473378896713, 48.8515542447567, 50.588463842868805, 51.47091329097748, 49.36005815863609, 48.77333544194698, 48.783370703458786, 51.13561548292637, 46.99921444058418, 48.63371193408966, 50.100372433662415, 48.764531314373016, 50.33193960785866, 45.83390437066555, 42.75846339762211, 44.013182669878006, 41.85350775718689, 43.196146711707115, 44.85036514699459, 42.74907410144806, 44.32030498981476, 45.205475091934204, 46.149534434080124, 44.999936521053314, 43.9534080773592, 50.591104701161385, 55.151407197117805, 56.30064032971859, 56.708651036024094, 52.518300488591194, 54.19202707707882, 56.19097821414471, 50.97918167710304, 54.041133373975754, 45.71793079376221, 46.59671723842621, 51.56867444515228, 48.788789212703705, 44.614473804831505, 38.53961057960987, 26.365842819213867, 14.153919406235218, 5.201431168243289, 0.567702065454796, 0.3392608469584957, 0.0460344221937703, 0.041459211643086746, 0.03510224552883301, 0.0805321587540675, 0.021531626262003556, 0.08616300387075171, 0.041679291825857945, 0.16333616513293236, 0.2728420734638348, 0.9873709618113935, 1.678243714850396, 7.876249188557267, 13.769385740160942, 9.615491386502981, 2.00320215895772, 0.5848881276324391, 0.2508364449022338, 0.06233579610125162, 0.10331158016924746, 0.11299077406874858, 0.041414753286517225, 0.02317080598004395, 0.018752149626379833, 0.08270499645732343, 0.04675990865507629, 0.06835105887148529, 0.061839755726396106, 0.1481406469247304, 0.41839020559564233, 20.607046633958817, 67.50603765249252, 59.53561574220657, 52.59958952665329, 30.944160148501396, 35.78192375600338, 36.67757369577885, 48.16124148666859, 41.90930396318436, 35.99239446222782, 34.49424125254154, 46.15650326013565, 37.19211928546429, 3.5617977753281593, 0.10965087945805863, 0.044854381412733346, 0.25413116498384625, 0.4005692509235814, 1.0421241237781942, 0.2874070778489113, 10.117769334465265, 77.87631958723068, 45.57893045246601, 30.01471482217312, 46.397178545594215, 12.787231542170048, 50.95793701708317, 66.74491569399834, 59.03207056224346, 101.79088354110718, 104.63321462273598, 60.50967827439308, 73.38886678218842, 42.095718160271645, 0.9998245560564101, 0.5376741767395288, 0.31169210909865797, 0.32460613176226616, 0.12724935309961438, 0.1731547640520148, 0.19780411559622735, 0.23565501265693456, 0.23980569618288428, 0.12506616243626922, 1.2339146761223674, 7.949710646644235, 28.13697338104248, 24.051782190799713, 10.30985377728939, 16.166420616209507, 55.19025631248951, 59.10121165215969, 38.367639407515526, 41.57025195658207, 29.689017198979855, 10.988060384988785, 1.250600174535066, 1.9123853696510196, 1.2824291666038334, 3.7383659882470965, 3.7475130474194884, 5.366134280338883, 12.967396024614573, 37.34501928091049, 47.50912807881832, 52.92981840670109, 49.84389379620552, 55.40420763194561, 54.34651538729668, 59.33110311627388, 57.46725752949715, 63.373820185661316, 61.51351220905781, 63.18047136068344, 60.69917410612106, 61.34962700307369, 64.59930002689362, 63.101925775408745, 72.00123444199562, 60.18642581999302, 59.29586000740528, 66.37317404150963, 62.48406372964382, 59.31064881384373, 54.747549667954445, 49.2496170848608, 48.4205661714077, 52.29434430599213, 46.60834461450577, 53.395806401968, 47.94337637722492, 49.31332066655159, 49.88102540373802, 47.645776346325874, 50.92523217201233, 51.81533820927143, 54.1890936344862, 55.170949548482895, 55.03523603081703, 53.79085220396519, 52.83477030694485, 58.73341418802738, 53.26024107635021, 54.2173071205616, 56.85230232775211, 53.59779976308346, 51.91469147801399, 50.645996555686, 49.07717853784561, 54.23716865479946, 51.64245888590813, 52.32002332806587, 53.74484047293663, 52.20216125249863, 50.738434195518494, 50.08846767246723, 45.547342747449875, 46.22286669909954, 44.742982909083366, 47.70513296127319, 48.61304484307766, 45.71802198886871, 46.13859102129936, 48.11020642518997, 49.258254021406174, 48.657905235886574, 47.988852337002754, 53.70755687355995, 56.33258901536465, 58.979215398430824, 60.37989243865013, 55.661089047789574, 56.04548022150993, 57.411054745316505, 53.538009971380234, 58.20719562470913, 46.32071904838085, 49.065091386437416, 54.6614158898592, 53.89990255236626, 50.95472238957882, 46.13799445331097, 34.362236335873604, 30.918604619801044, 11.983354277908802, 1.246688759420067, 0.47721063368953764, 0.20187663612887263, 0.12121777792344801, 0.2165930237970315, 0.2443803389905952, 0.16566732520004734, 0.19478226837236434, 0.12402892942191102, 0.22321817610645667, 0.6022468430455774, 1.6787558561190963, 2.8687961865216494, 13.121178522706032, 19.476835280656815, 13.386617079377174, 7.180355954915285, 1.3817787542939186, 0.9379259962588549, 0.1908826534054242, 0.1552389035350643, 0.3882582677761093, 0.1930467115016654, 0.17398954660166055, 0.15687401813920587, 0.16089258453575894, 0.12423297550412826, 0.5072030774317682, 0.1237904180015903, 0.21639605780364946, 0.5342646909411997, 23.554472476243973, 78.82939204573631, 68.04341241717339, 61.551798954606056, 39.35446545481682, 39.72890876233578, 41.71167656779289, 63.83254677057266, 54.37834247946739, 51.46751627326012, 66.9505150616169, 80.71201622486115, 77.48915836215019, 11.3505894318223, 0.7487228082027286, 0.16012121108360589, 0.5301489774137735], [0.27463685371913016, 0.8909666910767555, 0.17896110482979566, 0.7477370579726994, 11.678510885685682, 10.586164500564337, 5.538841662928462, 20.629872009158134, 22.098593898117542, 35.928554087877274, 42.78161935508251, 44.092621207237244, 78.26481834053993, 95.38336336612701, 49.031474590301514, 53.4273599088192, 38.36876034736633, 1.2551092263311148, 0.45312268717680126, 0.20118718093726784, 0.13498594576958567, 0.1562329361331649, 0.05975985717668664, 0.07780783111229539, 0.07494971650885418, 0.015145425095397513, 0.1313204487087205, 3.035360723733902, 6.087395427748561, 5.376538122072816, 2.8359692730009556, 1.1989875440485775, 2.284592972137034, 9.124975707381964, 31.671676710247993, 39.90408316254616, 36.80891364812851, 29.2257384583354, 21.049644984304905, 5.071416394785047, 1.1903261463157833, 1.6662389715202153, 1.3976495526731014, 1.8555603688582778, 2.0645182812586427, 5.030398545786738, 15.913925115019083, 33.34575667977333, 38.482967019081116, 41.585082560777664, 38.05677808821201, 47.010758221149445, 47.100574001669884, 50.45728728175163, 50.17584778368473, 54.709775894880295, 52.59201653301716, 55.68540394306183, 59.09499138593674, 62.36919589340687, 60.54524436593056, 57.2148484736681, 55.79143725335598, 59.65471275150776, 62.226467952132225, 58.82044091820717, 55.50556339323521, 49.85343888401985, 46.4691998809576, 46.996094807982445, 46.243982166051865, 43.77542182803154, 43.92649792134762, 43.85570392012596, 44.14093181490898, 43.715537041425705, 47.490995451807976, 45.80697901546955, 43.93781751394272, 50.40602423250675, 47.41317182779312, 52.107489332556725, 48.64263005554676, 46.593308821320534, 46.938349306583405, 48.618349358439445, 50.10749705135822, 48.11296887695789, 49.64438550174236, 49.37528774142265, 47.24049769341946, 46.4768260717392, 45.08501015603542, 43.26038986444473, 48.196192011237144, 48.534552454948425, 44.77114699780941, 48.434161841869354, 43.95095720887184, 39.65755619108677, 39.00789365172386, 40.16016662120819, 41.60948485136032, 38.45128811895847, 41.24368607997894, 40.348378121852875, 41.65963836014271, 42.14432135224342, 44.00569327175617, 40.3227598965168, 45.025672540068626, 51.900149658322334, 53.04865702986717, 52.28888779878616, 49.39902886748314, 51.41878008842468, 53.33856627345085, 48.587685003876686, 47.439793199300766, 42.956151589751244, 40.920327231287956, 48.09709332883358, 39.42487187683582, 38.41251119971275, 25.35821858793497, 14.648289978504181, 5.875430926680565, 0.7905822526663542, 0.16569560102652758, 0.11575496988371015, 0.0786999445699621, 0.04240519388986286, 0.03201897816325072, 0.018444221423123963, 0.048064737857203, 0.060366280886228196, 0.025092174364544917, 0.22695949097396806, 0.02549431264924351, 1.795436788816005, 3.9826351683586836, 21.00133627653122, 16.567960269749165, 10.60128578916192, 4.573110183700919, 3.557782103307545, 5.2514322102069855, 0.020689707962446846, 0.06875262755784206, 0.13088842970319092, 0.06048369235941209, 0.0371961038763402, 0.030693266780872364, 0.03841871795884799, 0.09749459699378349, 0.12448746536392719, 0.059584046102827415, 0.01968227959878277, 0.29730955429840833, 25.250275880098343, 56.28308147192001, 60.886895433068275, 40.87667517364025, 26.70742928981781, 29.572488851845264, 39.760944843292236, 42.842343896627426, 31.005376763641834, 13.529343120753765, 2.614482957869768, 3.8903231592848897, 2.6978022744879127, 0.23405498679494485, 0.02232713992270874, 0.07947459831484593, 0.08054721693042666, 0.2252460501040332, 0.6421223189681768, 0.2256982703693211, 0.6011861655861139, 22.89230290800333, 20.71399949491024, 11.333382055163383, 32.426844388246536, 34.11377526819706, 41.49003066122532, 57.14188478887081, 52.69183337688446, 82.67430692911148, 99.12698328495026, 46.310148015618324, 66.65194988250732, 58.425360918045044, 1.5911190211772919, 0.5113873654045165, 0.126641430251766, 0.14768449327675626, 0.09208853356540203, 0.058583315621945076, 0.12313390674535185, 0.04636043653590605, 0.023989704714040272, 0.01205136968565057, 2.119449321180582, 9.880949892103672, 16.837863586843014, 11.519717406481504, 1.5659377723932266, 2.455819146707654, 28.248693086206913, 49.67628099024296, 44.13683943450451, 44.06973883509636, 28.68406232446432, 18.8150741904974, 2.8284976864233613, 1.2536714784801006, 1.4261684473603964, 2.4043962685391307, 2.5102265272289515, 1.970518094021827, 5.4540905356407166, 16.986188627779484, 35.489453449845314, 45.27685426175594, 47.65807628631592, 43.15305322408676, 52.08809897303581, 51.35732598602772, 54.10937391221523, 53.31980288028717, 56.605931147933006, 55.58849394321442, 55.61927229166031, 62.34420843422413, 62.09686450660229, 61.74893997609615, 60.101682767271996, 58.88430029153824, 62.55639664828777, 64.83328387141228, 61.72108747065067, 57.95336164534092, 51.32080614566803, 49.71185088157654, 49.149196073412895, 47.625128254294395, 46.666986867785454, 47.89147116243839, 45.52222229540348, 47.50755876302719, 46.190199851989746, 49.6266670525074, 47.87204660475254, 48.240132853388786, 51.74777403473854, 48.93717125058174, 52.77172788977623, 52.67474189400673, 48.65757465362549, 51.38850711286068, 51.90579615533352, 52.08909831941128, 51.37601338326931, 50.837684869766235, 52.471977174282074, 50.506236255168915, 49.170110151171684, 46.88036821782589, 45.92094250023365, 48.949900567531586, 50.38174733519554, 46.35174818336964, 49.617718532681465, 46.57721288502216, 41.860278993844986, 41.42333284020424, 42.861928045749664, 41.396035104990005, 42.864492908120155, 44.052499160170555, 41.99644088745117, 44.675384536385536, 44.650172889232635, 46.99958302080631, 44.92871694266796, 48.26399177312851, 54.53555524349213, 58.52406062185764, 58.04974727332592, 53.69049198925495, 53.33768092095852, 56.442855298519135, 51.31083548069, 51.746884882450104, 44.812336787581444, 44.36265371739864, 51.20822958648205, 45.506354346871376, 39.82853941619396, 26.43001187592745, 15.127484165132046, 6.269951881840825, 0.7635862450115383, 0.3120208211475983, 0.140095736423973, 0.03373420018760953, 0.051601019586087205, 0.06192475761054084, 0.02840256674971897, 0.07652618660358712, 0.0653805979527533, 0.0778832333162427, 0.12577068322570994, 0.04813062943867408, 2.3997495928779244, 3.8579899817705154, 21.157502196729183, 19.84895881265402, 11.459980811923742, 4.5493006613105536, 3.8170253299176693, 5.609971946105361, 0.032843630397110246, 0.018000097988988273, 0.08608864067355171, 0.050077661289833486, 0.05202003616432194, 0.01557840147142997, 0.0029913270964243566, 0.021378985038609244, 0.06840214089606889, 0.06905546091729775, 0.08589794582803734, 0.4956750600831583, 38.14959570765495, 64.82896730303764, 69.6148332953453, 49.03602674603462, 36.77427850663662, 33.02207864820957, 46.229618936777115, 62.705135866999626, 35.95081329345703, 10.501570589840412, 6.682625887915492, 12.725392710417509, 2.99222472589463, 0.10680149251129478, 0.01280836124351481, 0.09183948364807293, 0.09439337707590312, 0.4071900394046679, 2.655360451899469, 0.5872561130672693, 1.4156292378902435, 41.37177340686321, 44.61964152753353, 30.237133987247944, 47.82705321907997, 51.10911190509796, 60.58205299079418, 72.71389380097389, 66.78727582097054, 87.61898919939995, 108.71805623173714, 56.93196125328541, 76.59513473510742, 68.5202944278717, 1.1111657065339386, 0.4625161096919328, 0.26544250489678234, 0.2029341965680942, 0.28337626601569355, 0.2180806439719163, 0.2841630612965673, 0.16928943630773574, 0.17139672010671347, 0.31136360485106707, 4.0307192131876945, 13.727644979953766, 28.021248690783978, 15.363758336752653, 7.227950775995851, 5.730465380474925, 31.2504256144166, 51.99935093522072, 48.378175646066666, 51.827193573117256, 32.442013174295425, 30.058281384408474, 7.054965533316135, 1.6101644304580986, 2.35985292121768, 2.362397122196853, 3.0954165011644363, 2.5116918236017227, 7.2553938534110785, 18.42960387468338, 40.86982034146786, 50.26453882455826, 53.85331705212593, 47.1155072003603, 55.41244558990002, 55.935821905732155, 59.29281257092953, 57.519633919000626, 61.044712364673615, 59.26617220044136, 60.059261843562126, 63.72522532939911, 67.02718734741211, 65.94153240323067, 62.51318156719208, 59.81367342174053, 65.51233023405075, 66.18351861834526, 63.61564300954342, 60.658117309212685, 56.280003637075424, 51.948312073946, 52.587673366069794, 51.070741564035416, 51.48840755224228, 49.56108637154102, 49.03235614299774, 49.59892854094505, 49.11741457879543, 54.005145505070686, 51.98049634695053, 50.687858909368515, 55.1645202934742, 53.16687248647213, 58.00633080303669, 54.79907490313053, 50.24729534983635, 51.94819428026676, 54.75766472518444, 54.14563536643982, 53.89212056994438, 54.18539643287659, 54.261456951498985, 51.475036069750786, 52.152775302529335, 49.43247087299824, 47.75754354894161, 52.952609583735466, 55.393021032214165, 50.04366047680378, 54.156119003891945, 48.335572332143784, 45.013786777853966, 43.92139099538326, 48.14171053469181, 44.41261723637581, 45.0218765437603, 48.038382679224014, 45.36213308572769, 49.71239425241947, 47.43772991001606, 50.148895829916, 48.04440915584564, 50.77911861240864, 58.41540165245533, 59.56411421298981, 58.515659272670746, 57.5603449344635, 56.3520135730505, 60.8460134267807, 52.63460084795952, 57.102621495723724, 47.91123770177364, 47.21725434064865, 57.04979673027992, 50.10260671377182, 46.420235708355904, 35.02658128738403, 30.008578151464462, 11.923538837581873, 1.9568985560908914, 0.5261037976015359, 0.266381588880904, 0.17821784393163398, 0.09444606956094503, 0.17980704928049818, 0.11081374323111959, 0.14033384708454832, 0.25024130183737725, 0.11824193643406034, 0.337061210302636, 0.1338208926608786, 2.965541845187545, 6.408090619370341, 26.887999400496483, 25.391400307416916, 16.934794485569, 10.030689407140017, 6.857239343225956, 8.515825644135475, 0.4472326469840482, 0.14751001435797662, 0.3166060469811782, 0.14526967832352966, 0.15672037872718647, 0.13858827122021466, 0.05804717329738196, 0.16776813747128472, 0.28058914525900036, 0.18098724220180884, 0.14827751379925758, 0.551002852153033, 48.63129526376724, 74.59911704063416, 75.96942991018295, 60.05644619464874, 41.32786676287651, 41.252699196338654, 55.883342921733856, 72.11769819259644, 55.004993453621864, 54.528377428650856, 45.12041665613651, 39.83016952872276, 8.130777105689049, 0.44933043129276484, 0.10659464111085981, 0.1509166503092274, 0.41559768200386316], [1.0735161392949522, 4.813097231090069, 1.0837242915295064, 0.12130262024584226, 2.145834155380726, 4.219844564795494, 3.1253881053999066, 1.7629886674694717, 9.956862218677998, 37.94388234615326, 53.06982569396496, 38.44570241868496, 75.66296875476837, 88.63085210323334, 41.03170305490494, 55.5900214612484, 51.22479289770126, 4.046921543776989, 0.54031663807109, 0.22007188556017354, 0.10316611180314794, 0.08513752647559159, 0.016105239119497128, 0.15356975403847173, 0.15430535597261041, 0.059932759031653404, 0.028589523026312236, 8.147029783576727, 11.020331103354692, 7.784625655040145, 11.59365763887763, 1.4891972090117633, 3.0662008188664913, 6.918130125850439, 5.210185423493385, 22.784206308424473, 49.42692317068577, 42.59335085749626, 21.45396988838911, 12.015753239393234, 3.683018870651722, 2.243294413201511, 1.8919598031789064, 2.063904139213264, 2.2421620739623904, 4.50354446657002, 11.847806051373482, 27.660651840269566, 37.016215324401855, 39.87049676477909, 37.68762789666653, 39.31192293763161, 44.08537499606609, 47.69622623920441, 50.39012968540192, 49.730815663933754, 49.75741803646088, 49.32238698005676, 55.838759914040565, 55.612751841545105, 61.7071346193552, 56.14948444068432, 57.08514243364334, 58.93538095057011, 61.41348257660866, 59.702825769782066, 55.12463003396988, 51.81722670793533, 47.672181129455566, 45.55993527173996, 45.32218582928181, 43.3707245439291, 44.36851680278778, 42.530266642570496, 43.02586264908314, 41.85622461140156, 43.36897283792496, 41.861890107393265, 50.20533800125122, 49.734383672475815, 43.93304497003555, 45.327345952391624, 44.265223145484924, 45.28788886964321, 46.91345304250717, 47.948977276682854, 48.30859757959843, 51.15953519940376, 48.573800548911095, 48.35313878953457, 48.48254844546318, 47.84634858369827, 48.348427042365074, 44.04868796467781, 41.02010227739811, 44.10977728664875, 41.665064468979836, 43.80533382296562, 46.869303211569786, 37.7407718449831, 38.79210323095322, 40.92866778373718, 40.49055129289627, 40.300812274217606, 41.421083360910416, 40.61142660677433, 42.719781473279, 41.45286865532398, 45.04509709775448, 44.10241328179836, 44.2096321284771, 53.054850697517395, 53.762551322579384, 53.68730776011944, 49.76676933467388, 47.93448105454445, 50.49504205584526, 45.00519163906574, 46.19038984179497, 42.17544548213482, 43.20674814283848, 38.77327524125576, 34.94404211640358, 24.788836240768433, 15.277328174561262, 3.912423485890031, 0.8370749547611922, 0.329967851866968, 0.12944312678882852, 0.061327532821451314, 0.07812258336343803, 0.01481611840063124, 0.025779994975891896, 0.05059576200437732, 0.07237362544401549, 0.013154115786164766, 0.09116985864238814, 0.039128025600803085, 0.2301672610337846, 3.589186705648899, 4.1531334444880486, 26.648167669773102, 28.792698495090008, 26.071710102260113, 21.936317905783653, 12.588519304990768, 6.519873971119523, 8.261947967112064, 2.104626791551709, 0.1890158699825406, 0.04326967718952801, 0.053839240499655716, 0.04106715728994459, 0.06080551727791317, 0.040306081136805005, 0.049018861463991925, 0.08630153315607458, 0.07607728373841383, 0.7602189132012427, 26.139110885560513, 51.22055612504482, 60.96097245812416, 45.19223280251026, 17.186130098998547, 32.458021715283394, 57.603746205568314, 47.94384375214577, 12.844172436743975, 4.807028481736779, 2.2377125127241015, 0.04688237044319976, 0.09689734622952528, 0.16000956238713115, 0.1413661299739033, 0.019105493556708097, 0.10006820928538218, 1.1411025188863277, 2.3150884732604027, 0.29397119593340904, 0.06804818840464577, 4.176970515400171, 11.654719412326813, 7.697130599990487, 6.783494800329208, 27.70608600229025, 50.851455330848694, 61.359688863158226, 48.06506484746933, 77.37095430493355, 93.5942217707634, 40.938395261764526, 60.638867542147636, 75.91514602303505, 6.75483388826251, 0.9523287077900022, 0.3261969401501119, 0.23153814137913287, 0.11499604966957122, 0.01860058822785504, 0.04903799403109588, 0.13576615077909082, 0.03727140217961278, 0.10517760660150088, 8.355238661170006, 17.515844106674194, 14.279142636805773, 7.76420365087688, 3.262231587432325, 5.0498150289058685, 15.60311984270811, 22.793950885534286, 36.67551040649414, 52.86258481442928, 41.31579861044884, 26.849155984818935, 11.882359497249126, 4.114124737679958, 2.4964095186442137, 2.844011066481471, 3.5118416184559464, 2.4262206349521875, 4.493426084518433, 14.497813303023577, 28.056525997817516, 39.262597784399986, 41.80088818073273, 42.768320068717, 46.78078696131706, 48.565858975052834, 51.047665402293205, 52.37949773669243, 52.935122922062874, 52.765739411115646, 55.014314353466034, 59.16844144463539, 57.91256323456764, 63.77625659108162, 59.76594038307667, 60.859419107437134, 62.13843807578087, 63.83371710777283, 61.109662279486656, 56.82555936276913, 53.408577516674995, 49.40379001200199, 49.11165788769722, 47.22429156303406, 48.67639124393463, 47.969841957092285, 46.22827760875225, 45.34155339002609, 46.78415738046169, 45.21650590002537, 45.17289184033871, 51.82575345039368, 53.87467570602894, 47.143758684396744, 46.88084699213505, 45.56761845946312, 46.50848977267742, 47.889689058065414, 50.001938715577126, 50.145650804042816, 51.63704797625542, 50.117007941007614, 51.520071253180504, 49.8144605755806, 47.350448593497276, 49.78567712008953, 47.23703607916832, 42.497276812791824, 44.731465727090836, 45.17514891922474, 47.00493313372135, 48.30730564892292, 41.73144310712814, 41.032816395163536, 43.85733783245087, 42.24556311964989, 42.953271344304085, 45.00144504010677, 43.93905624747276, 43.99493224918842, 45.68229250609875, 46.22487299144268, 49.66433823108673, 48.21959115564823, 55.85387550294399, 58.90255831182003, 58.38645100593567, 54.82455633580685, 52.133042961359024, 53.47387321293354, 49.4016545265913, 51.85403533279896, 45.82075707614422, 46.69955871999264, 41.287756115198135, 32.862282022833824, 22.503595165908337, 14.060563165694475, 4.446314312517643, 0.8824942738283426, 0.4306207102490589, 0.0280361665863893, 0.03546608342730906, 0.03433267178479582, 0.0073685138613655, 0.04665906191803515, 0.014622870567109203, 0.028212487886776216, 0.08543238916900009, 0.01647738907195162, 0.15783190814545378, 0.14146713627269492, 3.5608739499002695, 5.501712430268526, 28.343518897891045, 31.97262056171894, 26.914535276591778, 24.82791144400835, 13.50351495668292, 8.697033170610666, 8.240804951637983, 3.3695915015414357, 0.27921424247324467, 0.061120833561290056, 0.07856173440814018, 0.08709388712304644, 0.06544987743836828, 0.04890417738351971, 0.08596493207733147, 0.04515697728493251, 0.1569353195372969, 2.171396096237004, 34.08124901354313, 62.148511335253716, 68.10497671365738, 53.44713784754276, 26.19446061551571, 36.95781625807285, 65.10776594281197, 55.659838914871216, 9.996034316718578, 3.2253054063767195, 1.616356079466641, 0.6942314759362489, 0.09106305617024191, 0.04637161699065473, 0.08439626937615685, 0.08029477539821528, 0.08282351001980714, 2.0866941288113594, 9.41908372566104, 2.1215311344712973, 0.19495312561048195, 7.692900951951742, 28.025730550289154, 23.232561349868774, 24.140011556446552, 41.66542924940586, 71.06171205639839, 78.78885582089424, 62.36578367650509, 78.89426216483116, 106.14185526967049, 51.59541741013527, 67.85464614629745, 96.27803295850754, 4.660668885335326, 0.4396681732032448, 0.3200426953844726, 0.26087206264492124, 0.17576952843228355, 0.14703999739140272, 0.17253311147214845, 0.27450872934423387, 0.1837435193010606, 0.2566521515836939, 9.857504200190306, 19.484246782958508, 20.786771290004253, 29.12226051092148, 5.771452831104398, 12.29624753817916, 37.02558942139149, 23.217067681252956, 46.81105613708496, 59.042542800307274, 54.68980796635151, 30.557090118527412, 14.743596464395523, 6.5817375015467405, 3.314343416132033, 3.4910496091470122, 4.100709082558751, 3.1110030272975564, 6.53577801771462, 16.65742836892605, 28.568599820137024, 45.748104974627495, 51.22211404144764, 51.496413722634315, 54.13585469126701, 53.95352527499199, 57.94507049024105, 55.812415927648544, 59.51741471886635, 58.031443655490875, 56.451404839754105, 60.499810203909874, 61.262410283088684, 67.64245793223381, 64.50283840298653, 61.37070447206497, 64.4533422589302, 66.77201583981514, 62.13191382586956, 59.25167977809906, 57.40155905485153, 53.8358835875988, 52.794902846217155, 50.71162283420563, 49.995137080550194, 51.11461021006107, 47.1864265948534, 47.04523377120495, 48.17254588007927, 47.120477333664894, 46.74992881715298, 54.09628741443157, 56.82943895459175, 47.537292167544365, 51.17733344435692, 49.69931535422802, 51.13757237792015, 52.103149965405464, 53.111661449074745, 53.15843693912029, 56.43562808632851, 53.06221850216389, 54.22791615128517, 53.084238320589066, 51.83570511639118, 53.39794188737869, 49.02662605047226, 44.83672007918358, 50.05977161228657, 48.11845578253269, 51.44039332866669, 52.3090685158968, 44.49666492640972, 42.96652503311634, 47.88002997636795, 43.75723980367184, 44.91129107773304, 47.03569248318672, 46.98983654379845, 48.06961700320244, 46.604799404740334, 50.251733511686325, 51.66136287152767, 48.96055519580841, 60.13262830674648, 60.474761947989464, 60.0938855856657, 56.494213342666626, 54.205744341015816, 56.396026611328125, 51.665892228484154, 54.62536342442036, 47.12046593427658, 49.57882381975651, 51.65162019431591, 42.46928371489048, 33.38442720472813, 30.608845241367817, 15.630145892500877, 1.8360835639759898, 0.638695377856493, 0.34032066352665424, 0.12607328651938587, 0.1645036821719259, 0.1388096687151119, 0.14952504920074716, 0.14726182533195242, 0.16998763399897143, 0.11655087131657638, 0.19215034553781152, 0.19534935825504363, 0.24284450890263543, 6.494770143181086, 9.634703155606985, 32.84689284861088, 40.423264503479004, 37.490483075380325, 28.155883066356182, 18.45716379582882, 10.039351992309093, 10.976555552333593, 5.8259238582104445, 0.3905832680175081, 0.19194137159502134, 0.14207804255420342, 0.14424751832848415, 0.19381864898605272, 0.21899957122514024, 0.22448260278906673, 0.23829876532545313, 0.3606848692288622, 2.7022368740290403, 54.72537025809288, 72.93940410017967, 75.06236538290977, 66.36125028133392, 29.40972838550806, 45.1254627853632, 78.48291903734207, 73.12814757227898, 52.37933434545994, 13.327257614582777, 5.255450494587421, 0.7235273101832718, 0.2582677180180326, 0.2748939336743206, 0.18475894059520215, 0.2534255903447047, 0.30865990149322897], [1.8765009264461696, 17.780756391584873, 12.913029491901398, 0.17727899743476883, 0.2608344506006688, 1.4014938776381314, 1.7794472468085587, 3.7204831978306174, 6.0460759699344635, 13.646821416914463, 52.22981616854668, 41.00044213235378, 69.72585573792458, 83.91005381941795, 34.7985403239727, 52.91158698499203, 57.04026684165001, 15.089955478906631, 1.5514662489295006, 0.47773533209692687, 0.23134776565711945, 0.07385832897853106, 0.012735098280245438, 0.036464401928242296, 0.15536757709924132, 0.07821278399205767, 0.2333357121096924, 8.313625194132328, 8.16776717081666, 7.683628024533391, 9.662861544638872, 7.577304504811764, 2.3151960549876094, 7.290434148162603, 15.279265120625496, 42.38877363502979, 56.97210609912872, 56.473048478364944, 41.092131212353706, 17.291903123259544, 9.877944253385067, 2.6897481316700578, 1.6103391023352742, 3.49632253870368, 7.30505196377635, 7.4445144552737474, 17.189895696938038, 22.355549409985542, 24.473513960838318, 20.925938822329044, 26.18822705000639, 31.483417712152004, 40.677159279584885, 40.68222440779209, 45.55655725300312, 45.063263922929764, 51.60296380519867, 48.91954019665718, 55.01847133040428, 56.942893266677856, 58.97364869713783, 58.50942760705948, 58.30580413341522, 59.603814482688904, 62.889714762568474, 57.796354070305824, 58.68775963783264, 48.559900894761086, 48.09096425771713, 47.495350018143654, 45.3340145945549, 44.25795413553715, 42.51181103289127, 41.841481402516365, 42.53539256751537, 43.69702063500881, 42.00361110270023, 42.31206715106964, 48.032124415040016, 50.09099833667278, 50.51888957619667, 46.07127383351326, 42.72457301616669, 42.23935805261135, 43.26092183589935, 40.8176339417696, 44.82106871902943, 44.95314963161945, 48.44919763505459, 47.111095637083054, 42.902034893631935, 42.371161580085754, 41.42628148198128, 40.882063284516335, 40.05132146179676, 39.17920745909214, 45.844293013215065, 45.72489582002163, 44.06566925346851, 41.656119748950005, 40.120519548654556, 38.08053441345692, 39.690986797213554, 41.019703298807144, 41.8104712665081, 42.54258178174496, 38.081510961055756, 44.145616963505745, 44.11383546888828, 48.74962851405144, 44.07283566892147, 51.34405329823494, 53.80833126604557, 50.28474614024162, 51.543952971696854, 48.03842827677727, 48.65615352988243, 44.473797753453255, 43.59435394406319, 40.34127250313759, 35.00452347099781, 28.196035511791706, 17.300464063882828, 9.629180151969194, 2.5993649940937757, 0.896143913269043, 0.62892135232687, 0.41464966256171465, 0.12128713162383065, 0.08490855907439254, 0.03960449183068704, 0.028580097750818823, 0.006304962435024208, 0.03916820918675512, 0.02660978843778139, 0.07275931959156878, 0.06397874778485857, 0.07572402886580676, 0.23797722242306918, 6.936784749850631, 14.621585961431265, 30.261095501482487, 36.07712231576443, 36.24525189399719, 33.54378305375576, 15.792388636618853, 14.854677803814411, 12.117973454296589, 7.723039034754038, 0.8002363471314311, 0.2879479847615585, 0.17089995613787323, 0.0898920361942146, 0.03077748384384904, 0.08479378593619913, 0.06705015563056804, 0.09557667217450216, 0.04255351952451747, 2.403426133096218, 23.452772833406925, 48.00846688449383, 60.07669910788536, 38.23998525738716, 15.797873642295599, 41.64380080997944, 55.02006344497204, 25.18259011209011, 4.858811628073454, 0.3064275806536898, 0.21974176343064755, 0.09758861968293786, 0.2248164059710689, 0.13752520404523239, 0.10211066648480482, 0.11097703798441216, 0.3152548335492611, 0.8195647224783897, 6.987824561074376, 3.271705429069698, 0.13547606009524316, 0.07396458968287334, 2.215619310736656, 4.761515948921442, 3.666066792793572, 9.510661661624908, 28.223095759749413, 66.81797817349434, 49.95737090706825, 72.0009608566761, 95.19369274377823, 38.455046117305756, 56.56143553555012, 81.13814055919647, 19.957089610397816, 1.347569189965725, 0.3206471004523337, 0.1476799661759287, 0.21760112751508132, 0.04100339938304387, 0.02773744101432385, 0.13310893555171788, 0.08331664488650858, 0.1273377874167636, 12.232990432530642, 15.32673217356205, 10.665642935782671, 16.536163575947285, 6.270445380359888, 2.9967481456696987, 8.821210507303476, 16.4739628136158, 42.14038096368313, 68.75526621937752, 60.00922612845898, 43.87637101113796, 18.134099431335926, 11.03883421048522, 2.963548614643514, 3.4923648135736585, 4.53369109891355, 4.850689088925719, 8.798815459012985, 21.67189009487629, 26.728664450347424, 22.18057069927454, 23.409966230392456, 29.096533991396427, 35.731891840696335, 45.51770053803921, 46.452780961990356, 45.948190838098526, 47.33548119664192, 51.734364554286, 54.38510611653328, 56.507554426789284, 60.66604748368263, 59.214236587285995, 59.98501382768154, 59.90605026483536, 61.841142028570175, 64.09256681799889, 61.66129007935524, 60.32144397497177, 52.553501799702644, 50.813898146152496, 49.78997848927975, 48.08250971138477, 46.70945718884468, 47.31732577085495, 44.49084743857384, 44.44650761783123, 46.87728278338909, 43.910322189331055, 47.28745557367802, 49.031603783369064, 52.95137844979763, 52.732088416814804, 48.007881715893745, 46.28995209932327, 45.653265863657, 43.4796267002821, 43.11253979802132, 46.31981089711189, 48.55560712516308, 48.669088035821915, 50.68720534443855, 45.226168781518936, 42.68406338989735, 42.286498323082924, 43.768301010131836, 42.95991338789463, 40.51478259265423, 47.31477990746498, 48.35421413183212, 45.31397067010403, 45.98319835960865, 42.16930501163006, 40.35439319908619, 41.855004876852036, 44.31337036192417, 42.3816604167223, 44.12723734974861, 40.558617040514946, 48.06537643074989, 46.059445068240166, 50.21265260875225, 50.16617730259895, 53.402041867375374, 56.54998295009136, 53.19767363369465, 56.26048028469086, 49.75685566663742, 52.01034754514694, 44.67790760099888, 47.981598526239395, 42.33577027916908, 38.47022630274296, 27.214396186172962, 16.134570725262165, 12.414852473884821, 6.148242512717843, 1.359894066117704, 0.9782094752881676, 0.47431174549274147, 0.2322042634477839, 0.06188182065670844, 0.03368858036992606, 0.03572066234482918, 0.07714823994319886, 0.038759642047807574, 0.06628171366173774, 0.14729897724464536, 0.041956765999202617, 0.14668001123936847, 0.15483254799619317, 7.238998683169484, 18.582792654633522, 32.240813970565796, 42.73930102586746, 41.302214339375496, 36.090265810489655, 20.697892159223557, 18.01058705896139, 11.410183534026146, 8.344316147267818, 0.5209007486701012, 0.20251559559255838, 0.23806697776308283, 0.10391374395112507, 0.04779945345944725, 0.07704478455707431, 0.050237920659128577, 0.12452712573576719, 0.1517744839657098, 4.142177207395434, 40.045948550105095, 58.833789601922035, 66.8659695982933, 46.92596957087517, 20.016440525650978, 45.82189701497555, 70.12304082512856, 28.606966361403465, 2.416133601218462, 0.15318263496737927, 0.29445483873132616, 0.10186151266680099, 0.25024670467246324, 0.1970002063899301, 0.0646196368325036, 0.05870636741747148, 0.08333852340001613, 2.8927842993289232, 25.7761125639081, 23.72787047177553, 0.3097240818897262, 0.28449978854041547, 3.8582614297047257, 12.443755622953176, 19.333837553858757, 28.03225290030241, 43.14273677766323, 82.17287063598633, 65.34347489476204, 75.96589609980583, 105.3108398616314, 48.22442069649696, 64.27819445729256, 105.14513835310936, 18.008181788027287, 1.6830472508445382, 0.5719511874485761, 0.2594391832826659, 0.3253182669868693, 0.09218827821314335, 0.11397451307857409, 0.27321371133439243, 0.4646152595523745, 0.6212645256891847, 12.469111662358046, 23.207480795681477, 10.635726191103458, 21.78915560245514, 24.85435802489519, 22.66935557126999, 36.62413336336613, 37.42904417216778, 67.30240657925606, 70.30052930116653, 66.84069335460663, 51.68392226099968, 25.519008859992027, 13.103929348289967, 7.3192223533988, 5.492067122831941, 6.835901588201523, 7.588329138234258, 10.924947671592236, 23.78809154033661, 30.46991139650345, 33.007153049111366, 40.567371770739555, 43.9033267647028, 51.269641891121864, 52.30742320418358, 52.284274846315384, 52.592468708753586, 51.19816392660141, 56.62322781980038, 56.8626643717289, 59.094603806734085, 64.54676404595375, 60.749023631215096, 61.171830743551254, 62.24950231611729, 64.66579645872116, 66.77700877189636, 62.54047550261021, 62.876217886805534, 55.414896458387375, 54.174255430698395, 53.24651621282101, 51.66211523115635, 50.839029997587204, 47.22287803888321, 46.12302705645561, 45.8359182626009, 49.744734317064285, 47.337232902646065, 48.98985542356968, 51.70978367328644, 57.65469387173653, 56.965566650033, 50.42723469436169, 47.98859015107155, 49.296859949827194, 47.78580263257027, 44.526071548461914, 49.04858887195587, 50.72181388735771, 52.67995901405811, 54.350208789110184, 46.4521349966526, 46.775934621691704, 44.48833957314491, 46.07633136212826, 45.22398769855499, 45.04467912018299, 51.44489988684654, 53.889551907777786, 49.82242114841938, 49.0212569385767, 46.64914682507515, 43.88528533279896, 45.670756325125694, 46.53773680329323, 46.35525919497013, 48.45357120037079, 41.18898421525955, 51.15358091890812, 47.81379573047161, 52.276359871029854, 51.205079555511475, 57.100505009293556, 59.027913585305214, 55.37327729165554, 59.51472066342831, 54.45939972996712, 54.32536952197552, 50.85903972387314, 53.62460732460022, 48.688030019402504, 45.64841352403164, 39.030852019786835, 30.602387487888336, 27.852220460772514, 15.903461426496506, 2.697775438427925, 1.5548179065808654, 0.9034350095316768, 0.4505693132523447, 0.19877459242707118, 0.15693186112912372, 0.1671140530379489, 0.11505263842991553, 0.08103365020360798, 0.1697474453249015, 0.23667972563998774, 0.13390577951213345, 0.2072312167729251, 0.45668918173760176, 9.778777174651623, 22.2775661945343, 36.55663378536701, 46.27873130142689, 42.9237887263298, 39.66317988932133, 25.160583592951298, 23.697369508445263, 14.471878744661808, 12.009310685098171, 1.8376499111764133, 0.7590324268676341, 0.3099894738988951, 0.26020190329290926, 0.12953016586834565, 0.26746090909000486, 0.1616869942517951, 0.2468142271391116, 0.45573089097160846, 6.86940866522491, 59.59102436900139, 69.75094959139824, 76.36579424142838, 58.147010654211044, 27.721019200980663, 52.618983685970306, 83.71995761990547, 65.62014564871788, 20.751093104481697, 0.43133857485372573, 0.38629335758741945, 0.15763378440169618, 0.5821127921808511, 0.19601990352384746, 0.22028216568287462, 0.16228853462962434, 0.2892143261851743], [0.7170733564998955, 19.974300786852837, 25.607217326760292, 16.96974691003561, 0.88574078399688, 0.037839286160306074, 0.15107576677110046, 1.491428876761347, 5.312235122546554, 4.041058458387852, 32.77489051222801, 39.42504666745663, 69.6630223095417, 72.96776577830315, 35.573003366589546, 57.583671882748604, 65.45194387435913, 30.760398209095, 0.9305306430906057, 0.07902430763351731, 0.043604946113191545, 0.07048543106066063, 0.020054203196195886, 0.046984486252767965, 0.053259804990375414, 0.051023216801695526, 0.7331495813559741, 3.750491375103593, 8.013753835111856, 2.9614561144262552, 9.311299659311771, 28.68749164044857, 19.359792061150074, 34.043961614370346, 32.30117753148079, 50.592829808592796, 64.16155591607094, 60.196875259280205, 49.04247500002384, 21.71623181551695, 15.319174379110336, 11.001359671354294, 4.004070768132806, 9.683535285294056, 15.004138983786106, 21.79382935166359, 23.092650957405567, 18.247948922216892, 9.998119454830885, 7.362263118848205, 14.873103015124798, 15.427616760134697, 32.73734472692013, 40.136433094739914, 38.347599282860756, 44.9178571254015, 50.0602275878191, 51.9814994931221, 48.90954293310642, 52.72991493344307, 55.975696966052055, 58.75977337360382, 53.53937029838562, 55.89874729514122, 56.8051278591156, 61.358556523919106, 53.614594861865044, 54.608081951737404, 49.43778678774834, 46.058483719825745, 43.87740455567837, 43.857987597584724, 45.4317719489336, 42.28088982403278, 42.9496843367815, 42.65695184469223, 42.95747771859169, 43.8937246799469, 46.56616687774658, 46.144587099552155, 45.6510391831398, 43.858622163534164, 46.01615399122238, 45.119671896100044, 43.57511177659035, 43.25507394969463, 47.21756972372532, 49.522260054945946, 46.72448918223381, 47.53022834658623, 46.86281695961952, 42.29484647512436, 42.51762092113495, 41.1165677011013, 41.11344426870346, 43.635881915688515, 44.372825771570206, 40.91884531080723, 42.04541265964508, 42.6150818914175, 41.34764850139618, 40.9920559823513, 38.21809083223343, 42.50432163476944, 41.45020119845867, 41.62022307515144, 38.13703738152981, 43.92659671604633, 43.854909762740135, 47.11287014186382, 48.01040858030319, 47.83630192279816, 52.942353934049606, 48.710137233138084, 47.96096183359623, 45.023168474435806, 43.27153466641903, 39.496931210160255, 40.76411381363869, 29.257898032665253, 22.695872448384762, 13.204338010400534, 6.027266979217529, 6.171406069770455, 1.3710158318281174, 0.48868589918129146, 0.29619217675644904, 0.23552814993308857, 0.05489244082127698, 0.1826805411837995, 0.06577137581189163, 0.039563840691698715, 0.0160851714463206, 0.027211729575356003, 0.02976712214149302, 0.008246847028203774, 0.15180739079369232, 0.0901524632354267, 0.35122913599479944, 13.435648698359728, 21.82821560651064, 37.38774038851261, 58.86613726615906, 58.22050631046295, 59.83698897063732, 38.92693519592285, 35.08281446993351, 20.544549487531185, 15.938489846885204, 3.2652244018390775, 1.355160113889724, 0.654070955934003, 0.16929552191868424, 0.048377560524386354, 0.04925804823869839, 0.11194947408512235, 0.08145482643158175, 0.07716370630078018, 4.401889471337199, 22.207752540707588, 50.557377710938454, 52.23990462720394, 33.06893773376942, 19.42676156759262, 30.854454562067986, 42.28378526866436, 5.295626688748598, 0.966134020127356, 0.10573385370662436, 0.14399452018551528, 0.10878773202421144, 0.2186774939764291, 0.5475948506500572, 0.08828448495478369, 0.03788677247939631, 0.12490876775700599, 1.7954215896315873, 23.440450094640255, 26.161381490528584, 5.127447713166475, 0.04165524624113459, 0.03478409424133133, 0.2211615364649333, 1.2844494706951082, 4.677261169999838, 18.417944200336933, 48.77349503338337, 49.66766685247421, 69.62869495153427, 80.57260930538177, 43.826456889510155, 60.31244605779648, 87.33747750520706, 44.65515062212944, 0.1494977084803395, 0.02203379863203736, 0.02480754403222818, 0.03503256528347265, 0.07474371115677059, 0.07403334966511466, 0.05144779948750511, 0.051391496454016306, 1.13660842878744, 7.780986400321126, 11.554857920855284, 7.576555944979191, 12.119701411575079, 24.572728537023067, 13.921120148152113, 28.062983751296997, 37.082286179065704, 58.556674271821976, 73.38599413633347, 68.2097826898098, 61.94439768791199, 28.102104552090168, 18.621985651552677, 9.112872406840324, 7.060195952653885, 11.078303642570972, 13.181943912059069, 21.769892536103725, 30.51805481314659, 21.551415659487247, 10.460649635642767, 8.401087950915098, 16.932928785681725, 25.296076722443104, 39.255590960383415, 43.76474820077419, 40.8831462264061, 48.24390985071659, 52.71092355251312, 57.324290201067924, 50.186297222971916, 51.50993339717388, 56.94880194962025, 61.488144770264626, 55.3756445646286, 57.40682177245617, 59.36144068837166, 63.30481208860874, 56.31101757287979, 57.17044025659561, 52.12326228618622, 48.610005006194115, 45.480534732341766, 47.35498175024986, 47.009059712290764, 47.16564171016216, 45.779035314917564, 44.07847456634045, 44.72363814711571, 48.602451011538506, 49.857128486037254, 47.65482746064663, 47.63590827584267, 46.294842436909676, 47.50588305294514, 46.918867751955986, 46.32366009056568, 45.111107155680656, 50.56793354451656, 50.23102082312107, 46.965662240982056, 49.5673256367445, 48.36784780025482, 46.848867908120155, 45.24274729192257, 45.388864651322365, 43.776884749531746, 46.12741582095623, 45.27722664177418, 42.65259347856045, 43.898626416921616, 45.533621683716774, 43.80474105477333, 41.65622994303703, 38.85136865079403, 43.421683609485626, 43.27549405395985, 43.42580258846283, 41.020774841308594, 44.16043996810913, 46.45768649876118, 50.77982537448406, 52.90618747472763, 52.373782843351364, 55.878042206168175, 53.65003935992718, 53.37103933095932, 50.62364995479584, 49.64316576719284, 46.18110693991184, 44.25899147987366, 31.911322250962257, 22.878954224288464, 13.131540566682816, 13.766211960464716, 7.604470672085881, 1.9217766844667494, 1.0917442361824214, 0.9515386470593512, 0.49646883155219257, 0.3331183281261474, 0.15388984233140945, 0.05524276049982291, 0.12681501859333366, 0.06281541645876132, 0.02096172178426059, 0.05309849548211787, 0.03663462834083475, 0.0911019447084982, 0.10514792069443502, 0.5912342027295381, 14.889533333480358, 23.510318845510483, 41.91878065466881, 60.629029870033264, 61.50106407701969, 62.9777180403471, 40.956505089998245, 35.6505686044693, 21.851569153368473, 17.550135366618633, 3.8295121723785996, 1.8746117153204978, 0.3804092248901725, 0.034514338403823785, 0.01395574659909471, 0.05971923572360538, 0.05330950290954206, 0.03362282608577516, 0.31552369880955666, 5.636219987645745, 39.215389117598534, 60.59349037706852, 62.919273376464844, 43.05760234594345, 20.11473175138235, 37.01069802045822, 53.83470185101032, 9.394575990736485, 1.3297704700380564, 0.13245489564724267, 0.12230700580403209, 0.0554109645599965, 0.5439418216701597, 0.5675205658189952, 0.08362960114027373, 0.0700909795705229, 0.3072025906294584, 3.296050247736275, 32.53822401165962, 56.52244582772255, 27.060627937316895, 0.6656045245472342, 0.09920884680468589, 0.5544795468449593, 3.2299708435311913, 17.80092380940914, 40.21532826125622, 58.1323928385973, 63.60879197716713, 77.38795459270477, 88.89599427580833, 52.85821884870529, 69.39722657203674, 104.81972381472588, 53.92418324947357, 0.8348866878077388, 0.2733723825076595, 0.12098294013412669, 0.10443542181747034, 0.1394356702803634, 0.11843358122860081, 0.1585676139802672, 0.16609469836112112, 1.4814122579991817, 12.40292301401496, 15.248501971364021, 13.520646337419748, 22.726825587451458, 45.57096228003502, 39.09835159778595, 53.32392945885658, 58.428921326994896, 64.44732338190079, 73.76861840486526, 70.84618762135506, 65.84698587656021, 43.82804520428181, 19.38788015395403, 16.187889464199543, 11.365078054368496, 14.46747288107872, 15.380491688847542, 24.182504676282406, 34.647114649415016, 29.216852635145187, 23.669767789542675, 22.892540395259857, 33.1511577218771, 39.995673447847366, 47.81952202320099, 51.89241327345371, 45.62232032418251, 53.29878240823746, 57.34270401299, 61.134528145194054, 54.853890761733055, 57.03104093670845, 61.28698356449604, 66.39215782284737, 60.0148194283247, 60.45362368226051, 61.95283703505993, 65.99194809794426, 59.2313888669014, 59.48147624731064, 54.73151832818985, 50.201697796583176, 48.62214535474777, 49.42056231200695, 49.627525806427, 47.40829288959503, 48.259804397821426, 46.41096420586109, 47.21306696534157, 49.49728399515152, 52.96405836939812, 51.14023223519325, 51.83542013168335, 50.327588841319084, 50.763938426971436, 49.487488120794296, 48.71953792870045, 46.99792630970478, 53.17080147564411, 54.29116755723953, 52.54537783563137, 53.798653185367584, 52.86943964660168, 49.63506080210209, 49.31558154523373, 48.679172694683075, 45.24267889559269, 51.35425195097923, 51.45244628190994, 47.55063325166702, 47.562279626727104, 48.21012206375599, 47.63170950114727, 45.359264239668846, 43.77230979502201, 48.33804979920387, 47.62689895927906, 48.89295682311058, 44.462048783898354, 48.61873313784599, 48.6308278888464, 52.66143500804901, 54.064099341630936, 55.85324093699455, 58.09088006615639, 55.54309397935867, 57.79581069946289, 51.93063922226429, 52.537337467074394, 49.59811918437481, 51.54139190912247, 38.16701777279377, 33.07023346424103, 28.699191212654114, 23.93434949219227, 13.774182982742786, 3.16518503241241, 1.6611377452500165, 1.4787675999104977, 0.4656803305260837, 0.5287918564863503, 0.32380300923250616, 0.16198415018152446, 0.21876500803045928, 0.14306202647276223, 0.13153823936590925, 0.23666697554290295, 0.11459107452537864, 0.2984972874401137, 0.37098519620485604, 1.1698961863294244, 16.837018132209778, 28.614949733018875, 49.27537590265274, 65.28882622718811, 65.17436876893044, 63.48038166761398, 48.42241667211056, 39.01992380619049, 26.194559410214424, 17.685153521597385, 8.322675358504057, 2.09920353256166, 0.6526559474878013, 0.36933786584995687, 0.2263674500863999, 0.13071267429040745, 0.22662547999061644, 0.18399755645077676, 0.39935895649250597, 10.368781965225935, 60.99936559796333, 68.691026866436, 79.03337270021439, 50.72598226368427, 32.13786989450455, 42.16917961835861, 78.36707845330238, 42.55032956600189, 1.3844693661667407, 0.4334712994750589, 0.19922982581192628, 0.14070778561290354, 0.9893562365323305, 0.638240649132058, 0.14817545365076512, 0.27376643323805183, 0.4389554145745933], [0.7657819928135723, 18.71972020715475, 12.270419374108315, 19.067882224917412, 6.012100568041205, 0.2870877168606967, 0.06848091987194493, 0.12917846208438277, 1.6209241468459368, 7.008018102496862, 11.846018247306347, 33.63544553518295, 73.2052530348301, 73.95075783133507, 36.43843732774258, 57.61300630867481, 74.47530448436737, 46.03378884494305, 1.2837814190424979, 0.14499011129373685, 0.1385428072535433, 0.09279959267587401, 0.03079215981415473, 0.0631199567578733, 0.07231540395878255, 0.07579020617413335, 0.20849441149039194, 6.471290728077292, 7.338278330862522, 9.289762414991856, 28.757322393357754, 48.50552201271057, 42.15218313038349, 53.066299483180046, 51.284905672073364, 57.84586921334267, 62.702434211969376, 59.348661974072456, 57.49378390610218, 30.06120342761278, 8.220626134425402, 17.84716922789812, 1.2109413463622332, 8.393437061458826, 18.142170198261738, 25.176512338221073, 21.14698626101017, 14.155631214380264, 8.870072085410357, 8.322838749736547, 14.6830790117383, 18.569143787026405, 28.034933656454086, 35.53625173866749, 44.83468718826771, 46.65766216814518, 48.39212469756603, 46.85487158596516, 48.07900249958038, 47.66285263001919, 48.667613714933395, 54.96656991541386, 56.929274797439575, 53.921432197093964, 55.20487792789936, 58.447270542383194, 55.73694817721844, 58.286170586943626, 48.473702520132065, 46.05725638568401, 42.54339873790741, 43.613501116633415, 44.60682101547718, 43.42737190425396, 42.891642451286316, 42.58680760860443, 43.254355788230896, 47.20243513584137, 45.50807565450668, 45.72688311338425, 40.60958370566368, 39.7258423268795, 41.549778655171394, 42.60421447455883, 42.948589995503426, 43.69317904114723, 42.707625925540924, 45.398090556263924, 39.51735891401768, 43.04970256984234, 45.03855384886265, 43.17921482026577, 41.878920793533325, 39.930529743433, 41.91823348402977, 40.93867264688015, 40.04108861088753, 43.268118649721146, 41.66231341660023, 43.21095831692219, 41.739297285676, 40.70550575852394, 39.35595877468586, 40.82334503531456, 39.48444128036499, 38.33822138607502, 39.547593891620636, 38.968854546546936, 44.408574253320694, 46.548820808529854, 52.85624675452709, 50.04265733063221, 47.60807856917381, 48.29068914055824, 49.29192781448364, 47.48691067099571, 41.40768527984619, 39.26014691591263, 30.534361638128757, 20.098983496427536, 9.574635028839111, 5.606536455452442, 9.662595558911562, 3.4689571196213365, 1.595058934763074, 0.4468022903893143, 0.38675746705848724, 0.4855980898719281, 0.37804806721396744, 0.1102206930227112, 0.033869389808387496, 0.09407230914803222, 0.025912778182828333, 0.08371836200240068, 0.02855317263311008, 0.03023743411176838, 0.031733165960758924, 0.09786028283997439, 1.3871950074099004, 18.19481637328863, 30.867523960769176, 46.88261769711971, 54.214594066143036, 46.967094764113426, 47.08317093551159, 48.12624156475067, 41.480766758322716, 31.512495651841164, 27.48692136257887, 15.135887414216995, 5.731885554268956, 3.639598600566387, 0.5073212273418903, 0.11617173033300787, 0.03857293624605518, 0.08688873524079099, 0.049489015727886, 0.21915546676609665, 5.495735350996256, 24.124056212604046, 54.03915748000145, 46.90167747437954, 33.188885897397995, 23.68905745446682, 26.394909359514713, 30.388287976384163, 3.031394686549902, 0.4551831563003361, 0.14715151250129566, 0.3429586422862485, 0.027845826116390526, 7.746261013671756, 10.036740582436323, 0.41461504879407585, 0.020950203652319033, 0.17949364031665027, 1.2618942372500896, 32.048901468515396, 43.47635507583618, 30.767646320164204, 5.239871330559254, 0.5102327023632824, 0.03573354973923415, 1.990092743653804, 4.31034573353827, 16.43732137978077, 38.16177025437355, 41.89738020300865, 77.05681756138802, 84.09476190805435, 41.685378178954124, 65.24691447615623, 82.06314772367477, 65.47354191541672, 1.606015171855688, 0.09969914666726254, 0.09575442396453582, 0.07995766965905204, 0.06854113773442805, 0.04852066143939737, 0.012447509561752668, 0.054132192162796855, 0.5867177888285369, 10.307777188718319, 10.246236640959978, 7.458432158455253, 32.369311675429344, 52.88167119026184, 46.13929398357868, 58.522407710552216, 58.93039181828499, 66.87090933322906, 74.95798498392105, 65.01686722040176, 67.69653663039207, 40.80262094736099, 16.73215325921774, 21.366430185735226, 10.591164082288742, 13.556957188993692, 25.368512235581875, 32.839935421943665, 26.293682791292667, 14.040126912295818, 7.356808986514807, 8.810542579740286, 12.122619654983282, 24.448224417865276, 38.04267704486847, 44.20623131096363, 53.230788856744766, 51.081039011478424, 50.41013181209564, 48.72040048241615, 54.22578066587448, 47.06340819597244, 49.3509766459465, 54.16578568518162, 62.0541699975729, 58.18533159792423, 59.16934959590435, 60.45469142496586, 58.29809434711933, 61.648560762405396, 52.76703894138336, 47.39505060017109, 45.60359872877598, 47.09521248936653, 45.63441887497902, 45.383282750844955, 44.471783861517906, 43.224204406142235, 46.4771718531847, 48.60530845820904, 47.936939522624016, 49.04358074069023, 45.277317836880684, 43.45247335731983, 44.67142514884472, 44.54251706600189, 44.56985279917717, 47.39455282688141, 46.41161397099495, 46.986276134848595, 43.13069522380829, 46.377533599734306, 47.16023080050945, 45.86989223957062, 46.66875757277012, 42.86557585000992, 43.68695117533207, 44.30553138256073, 43.90747234225273, 45.82497105002403, 44.912222027778625, 44.20827180147171, 44.67401280999184, 42.79652215540409, 40.869938135147095, 44.77750405669212, 44.983962178230286, 42.25010007619858, 43.752642050385475, 41.92524790763855, 46.40836514532566, 50.56261382997036, 56.48931920528412, 52.80423514544964, 51.287949308753014, 53.37683022022247, 53.79104979336262, 50.03869794309139, 43.46775993704796, 41.51281423866749, 34.14295770227909, 20.68467076867819, 12.34769582748413, 11.972837392240763, 9.847068060189486, 4.258886994794011, 1.444806803483516, 0.5063570290803909, 0.9306881565134972, 0.5377805116586387, 0.30514440732076764, 0.06566785363247618, 0.08147106462274678, 0.07671264378586784, 0.02727464885538211, 0.04522849434579257, 0.022423531918320805, 0.051540497443056665, 0.07734316503047012, 0.08691671420820057, 1.796480545308441, 23.668967932462692, 34.932384341955185, 52.89728455245495, 61.3809335231781, 56.03634171187878, 53.796141520142555, 52.08141893148422, 43.96530523896217, 33.72501812875271, 29.992708303034306, 15.774714834988117, 5.624936493113637, 2.633265112526715, 0.6719896662980318, 0.24586081970483065, 0.20542831742204726, 0.04681108344811946, 0.061430461282725446, 0.5668333370704204, 12.019832320511341, 45.595611557364464, 61.28967382013798, 60.04094682633877, 42.11143031716347, 23.168154805898666, 34.128769263625145, 43.58205400407314, 9.7971510887146, 1.0505074239335954, 0.016419473722635303, 0.3190420428290963, 0.3122093266574666, 19.603647775948048, 18.358528688549995, 0.5541348340921104, 0.032764068455435336, 0.10504858422791585, 1.2316368171013892, 46.0817726701498, 59.44876380264759, 46.355441585183144, 9.905157443135977, 1.027826084755361, 0.11548889509867877, 2.4694504402577877, 6.5130742359906435, 41.053396090865135, 53.862683549523354, 51.283157765865326, 83.74754413962364, 91.18285596370697, 54.83059041202068, 72.1211788058281, 99.89088669419289, 82.08496615290642, 2.9699961561709642, 0.7823625812307, 0.2650963078485802, 0.335173275670968, 0.22988735261606053, 0.30173925566487014, 0.2781628567026928, 0.45265424356330186, 3.0439302138984203, 17.072166614234447, 13.369566444307566, 19.527997635304928, 46.67795307934284, 57.36455664038658, 56.51535540819168, 61.46919138729572, 63.663600236177444, 64.0584446489811, 73.2025171816349, 65.81366166472435, 74.44425255060196, 59.96572986245155, 34.25333797931671, 27.77322079986334, 16.889487616717815, 18.116211891174316, 30.158956982195377, 38.506419360637665, 33.21912467479706, 24.67223759740591, 19.56813108175993, 17.396536208689213, 25.733524449169636, 41.52821481227875, 48.801309540867805, 48.51803474128246, 55.4881489276886, 52.22650274634361, 56.47803381085396, 52.84709304571152, 56.787295415997505, 52.836381420493126, 53.48684571683407, 60.36018289625645, 62.2025216370821, 57.38876134157181, 61.871540397405624, 65.2751849591732, 61.40038847923279, 64.13200110197067, 53.68334457278252, 50.0265271961689, 48.69392350316048, 50.1182846724987, 51.86459116637707, 48.46246652305126, 48.883107751607895, 45.614906921982765, 49.24651265144348, 51.72033950686455, 49.634730219841, 52.28652812540531, 47.86022923886776, 45.458305925130844, 48.67175929248333, 46.604020446538925, 47.665345296263695, 49.511077255010605, 49.32813607156277, 50.64000807702541, 47.217695116996765, 49.21692743897438, 51.387678757309914, 50.3612170368433, 50.67740187048912, 45.117057636380196, 50.079458355903625, 48.88865165412426, 47.776960507035255, 47.456265315413475, 47.60282725095749, 47.3289455473423, 47.60490953922272, 46.96365214884281, 44.30240795016289, 49.86506246030331, 49.043326154351234, 44.228418320417404, 44.991139993071556, 44.62059907615185, 50.715206041932106, 52.02696405351162, 61.52151457965374, 56.629710271954536, 53.67464303970337, 53.99737872183323, 57.530755922198296, 57.3531648516655, 50.764743983745575, 52.998742908239365, 46.34934291243553, 33.59105631709099, 23.060155101120472, 21.983845755457878, 18.71838267892599, 7.181171011179686, 1.9119967217557132, 1.08936128905043, 1.201531863771379, 0.8865851105656475, 0.849628234282136, 0.18473256466677412, 0.12706641369732097, 0.2278971648775041, 0.1005362521391362, 0.09244713190128095, 0.13519398460630327, 0.11721611765096895, 0.17589395691175014, 0.2495365880895406, 4.364877557381988, 25.67471880465746, 40.84872007369995, 58.25970120728016, 61.443022191524506, 60.92402704060078, 59.24632966518402, 60.280071794986725, 52.545081451535225, 41.66201323270798, 33.3178585767746, 21.36001043021679, 8.285050727427006, 5.82024791277945, 1.1919312039390206, 0.28544667991809547, 0.24169333395548165, 0.21499195892829448, 0.23040713800583035, 0.510520952520892, 20.886251851916313, 63.44421520829201, 70.73655590415001, 72.19812467694283, 53.26236516237259, 34.33034084737301, 39.906180649995804, 65.37507399916649, 20.90863075107336, 1.4278256334364414, 0.35233119560871273, 0.3737337252823636, 0.17327332956483588, 12.246759943664074, 14.039380252361298, 0.5844122031703591, 0.09129101425060071, 0.23432714719092473], [0.06693175339023583, 8.008480668067932, 2.7278161514550447, 7.719266312196851, 6.53976590372622, 1.4952866197563708, 0.03482974003418349, 1.3067988026887178, 2.3244856065139174, 4.445380987599492, 12.817786652594805, 39.72857438027859, 60.61350390315056, 57.2271104156971, 32.348997965455055, 53.76258172094822, 73.19142177700996, 57.70722225308418, 6.47072883322835, 0.25626439426559955, 0.13352746231248602, 0.12998775928281248, 0.046192384616006166, 0.08660647421493195, 0.13413116976153105, 0.13756804080912843, 2.5120703782886267, 6.577061377465725, 18.065178729593754, 17.072316706180573, 31.297364495694637, 39.41237434744835, 43.30571383237839, 56.90380476415157, 62.981411442160606, 53.77756431698799, 58.49949114024639, 56.870062574744225, 65.05016103386879, 43.79267290234566, 13.221095111221075, 17.897261939942837, 8.39753894135356, 6.459689000621438, 14.135624337941408, 23.268836103379726, 20.615250393748283, 13.841916248202324, 4.967128615826368, 9.094541240483522, 9.167110696434975, 16.876855194568634, 34.24875162541866, 49.26330015063286, 52.57193461060524, 48.792133033275604, 45.859454199671745, 43.501741513609886, 49.82304811477661, 39.357026517391205, 42.793687507510185, 43.66265907883644, 53.95319849252701, 50.54385423660278, 53.090283796191216, 56.936984583735466, 52.46867515146732, 60.37336438894272, 50.78436613082886, 46.647847294807434, 43.60232591629028, 43.88150453567505, 41.604241132736206, 44.106908440589905, 41.44776552915573, 43.39043788611889, 43.70726868510246, 47.17549078166485, 45.13168305158615, 44.756745770573616, 43.319697082042694, 42.47343309223652, 42.927520126104355, 43.700470849871635, 40.5131296813488, 43.96617539227009, 43.07717889547348, 44.52644392848015, 39.389415979385376, 42.17223085463047, 41.588779762387276, 42.26335756480694, 40.82897253334522, 40.05127586424351, 38.934132009744644, 42.61429153382778, 41.7043087631464, 41.57197706401348, 41.55179254710674, 42.36380137503147, 42.54603199660778, 42.081750109791756, 40.666740238666534, 38.826179802417755, 37.130976766347885, 39.25479680299759, 39.47530657052994, 42.75499418377876, 45.09113162755966, 47.81000733375549, 51.73069775104523, 50.90459927916527, 45.967106223106384, 53.154211565852165, 41.31483346223831, 33.56583707034588, 29.572952426970005, 24.408299960196018, 18.565209098160267, 7.843147264793515, 5.0932196248322725, 7.271297900006175, 4.149573035538197, 3.0421937070786953, 1.7762174201197922, 0.3306593553861603, 0.4036681924480945, 0.37858591647818685, 0.34302018117159605, 0.12723256571916863, 0.03994128586782608, 0.0399914105219068, 0.03586114718928002, 0.04034198253066279, 0.0339436194190057, 0.2139868980157189, 0.06407040302292444, 0.5100332130677998, 1.3314629229716957, 27.735093645751476, 48.26447814702988, 52.848916947841644, 47.72325038909912, 49.87754479050636, 53.90950083732605, 56.97806417942047, 53.13732147216797, 60.158698707818985, 31.881737038493156, 31.963827833533287, 19.8982497677207, 13.817142527550459, 6.569752944633365, 1.6972345020622015, 0.9448000055272132, 0.7816954795271158, 0.126307018508669, 1.3640162511728704, 9.30863220244646, 33.6697006970644, 56.44117958843708, 41.718109622597694, 28.351238183677197, 25.020849891006947, 20.830410048365593, 20.01921247690916, 6.398546481505036, 1.8186658923514187, 0.1598152532824315, 0.5999440478626639, 35.41403889656067, 78.97166401147842, 59.08413916826248, 10.817763023078442, 0.17456641799071804, 0.06547016033437103, 0.45003648090641946, 25.90951770544052, 32.62271247804165, 15.132674686610699, 13.033351935446262, 2.369372835382819, 0.3702536760829389, 1.27821103669703, 3.339689956046641, 11.080711763352156, 45.25361090898514, 43.7909933924675, 56.57960616052151, 69.1506578028202, 37.66738258302212, 63.844288140535355, 81.27201497554779, 79.65501934289932, 12.789395526051521, 0.21000809589168057, 0.15522475820034742, 0.12842899683164433, 0.05064961966127157, 0.10414119737106375, 0.11896883297595195, 0.41283867380116135, 3.030384653247893, 7.840817514806986, 19.81939259916544, 22.006275951862335, 42.10788130760193, 49.743396788835526, 51.82681739330292, 68.26836794614792, 68.73221665620804, 65.42479053139687, 67.91158989071846, 64.83161196112633, 71.37541562318802, 51.295187920331955, 24.27830133587122, 25.526709146797657, 14.049150478094816, 11.962804980576038, 25.408043414354324, 35.32400652766228, 27.666687816381454, 13.935848157852888, 8.754889816045761, 15.967279002070427, 16.651857867836952, 26.661598049104214, 44.34425510466099, 57.33787067234516, 55.25989517569542, 55.255817994475365, 51.425384134054184, 48.57205644249916, 50.4179859906435, 43.28867554664612, 45.74564650654793, 46.384331434965134, 53.74625399708748, 49.94061000645161, 54.483460038900375, 61.84640854597092, 57.04976253211498, 63.66642348468304, 53.8026087731123, 49.36317019164562, 46.23802408576012, 45.89627802371979, 45.35093128681183, 44.59998518228531, 45.1420982927084, 46.23688414692879, 45.89108370244503, 49.49258744716644, 48.90664368867874, 45.317063704133034, 45.67446492612362, 45.012346655130386, 47.44251765310764, 46.70517481863499, 42.969564869999886, 46.02629564702511, 47.145981565117836, 48.45193348824978, 42.44620755314827, 45.00236839056015, 45.13710156083107, 45.21566614508629, 44.15917843580246, 42.63573758304119, 42.388853430747986, 46.13014027476311, 44.2814102768898, 44.01098258793354, 44.17283870279789, 44.834899976849556, 46.039773523807526, 44.05731350183487, 43.41674007475376, 43.24829511344433, 41.889974400401115, 44.729467034339905, 43.14995639026165, 46.831373646855354, 47.95593850314617, 52.527287006378174, 54.12304937839508, 52.34167076647282, 49.559270069003105, 58.253290951251984, 43.29813323915005, 37.03624404966831, 33.810433745384216, 24.846349954605103, 18.256549760699272, 11.50444507598877, 10.565327368676662, 11.158949565142393, 6.267622606828809, 4.814016306772828, 2.620803681202233, 0.25496700138319284, 0.2732506999745965, 0.4678290261654183, 0.5215696908999234, 0.12932027166243643, 0.033008880709530786, 0.044405953522073105, 0.10501974436920136, 0.10849295838852413, 0.056096690459526144, 0.16583945893216878, 0.07117964341887273, 0.9918910567648709, 4.432181920856237, 33.66758421063423, 55.72005048394203, 56.079078018665314, 54.83537815511227, 56.96662679314613, 57.90765769779682, 63.8341198861599, 56.77198223769665, 66.31015062332153, 35.098948404192924, 36.38002686202526, 21.92343659698963, 16.630865894258022, 8.130248934030533, 1.7201720899902284, 0.46977193909697235, 0.8164332155138254, 0.14970991818699986, 1.7778305523097515, 27.98339132219553, 50.67216195166111, 63.080479726195335, 56.77358575165272, 36.42136484384537, 26.024951711297035, 31.2567275762558, 34.535894617438316, 12.092019896954298, 4.238626956939697, 0.4637401783838868, 1.3632466737180948, 57.50663101673126, 101.18356972932816, 70.3596693277359, 13.73097075149417, 0.4428881441708654, 0.0422586716740625, 0.743402618682012, 31.384218335151672, 58.32956425845623, 24.179932214319706, 17.046763077378273, 2.785650473088026, 1.2350198230706155, 1.2570534157566726, 5.46000586822629, 18.389400132000446, 67.76522174477577, 56.48244917392731, 72.84512355923653, 73.85420501232147, 49.085800275206566, 69.52488452196121, 91.90186098217964, 97.3357518017292, 19.948965646326542, 0.6601931399200112, 0.4181840369710699, 0.5054546368774027, 0.16891103005036712, 0.23080546350684017, 0.22845095547381788, 1.3172689033672214, 6.586507670581341, 11.136846151202917, 29.10754770040512, 28.166414201259613, 46.81446075439453, 48.95929366350174, 49.35124263167381, 61.40000469982624, 64.83197674155235, 64.89964351058006, 66.54337450861931, 63.75576809048653, 68.84982794523239, 62.969054505228996, 48.00400972366333, 32.61492669582367, 27.832246832549572, 18.552933856844902, 33.072718530893326, 45.195922404527664, 32.04541705548763, 20.042847208678722, 19.975585117936134, 26.492018848657608, 22.14680191129446, 34.484844356775284, 51.80046580731869, 60.63139334321022, 61.901459991931915, 59.16045807301998, 54.781310856342316, 52.100596502423286, 55.43091259896755, 44.40779909491539, 48.63433130085468, 49.87938389182091, 59.154279604554176, 53.892724737524986, 57.845002859830856, 61.577462777495384, 56.65485352277756, 65.29818892478943, 52.79373250901699, 50.617156103253365, 48.99495095014572, 49.1723520308733, 46.52883008122444, 49.78713244199753, 47.700922787189484, 48.81042905151844, 47.387656196951866, 52.82562419772148, 52.41939939558506, 49.131101444363594, 49.21093136072159, 47.90894642472267, 49.93053674697876, 48.762635216116905, 47.76555351912975, 48.525394946336746, 47.48438760638237, 49.97143395245075, 46.47011183202267, 49.332859218120575, 47.22181789577007, 49.07860346138477, 48.617988377809525, 47.84014731645584, 46.673495918512344, 49.808354303240776, 49.23286758363247, 48.1393850594759, 47.86605812609196, 47.03521750867367, 47.95941151678562, 48.527633026242256, 47.896258905529976, 44.70686584711075, 43.478243574500084, 49.589102268218994, 44.30838122963905, 51.698342487215996, 50.328918769955635, 55.2790879458189, 58.972071781754494, 56.37268826365471, 54.98483173549175, 58.665492832660675, 52.62775741517544, 46.88181973993778, 41.52823381125927, 36.44968472421169, 29.178100414574146, 23.93262818455696, 21.160410940647125, 20.363158620893955, 9.643515832722187, 5.283118234947324, 2.9109727358445525, 0.5522690748330206, 1.1508461460471153, 0.7712996529880911, 0.5456373025663197, 0.31962177890818566, 0.16074779152404517, 0.15560944302706048, 0.18984977679792792, 0.1559915897087194, 0.10305254836566746, 0.4168487945571542, 0.16007789934519678, 1.6354356869123876, 8.582655508071184, 39.35394488275051, 62.42159128189087, 59.67458948493004, 62.19301834702492, 65.02972573041916, 66.74113869667053, 67.36893340945244, 60.25370500981808, 66.20376393198967, 39.498663917183876, 36.832415387034416, 30.86097691208124, 17.67782561480999, 13.84748199954629, 1.9689317978918552, 1.2335717445239425, 1.4361628610640764, 0.40371144481468946, 2.0698313461616635, 38.69556561112404, 63.38643930852413, 72.17475593090057, 64.75402772426605, 46.555956825613976, 35.699768364429474, 35.36889731884003, 47.97904886305332, 21.653708070516586, 5.654796240851283, 0.42443309852387756, 0.3344413993181661, 57.286543026566505, 119.32852327823639, 82.10018813610077, 19.19981874525547, 0.6719022116158158, 0.33002683776430786], [0.0910940631001722, 3.3574485406279564, 6.091598002240062, 3.4447391191497445, 5.090995319187641, 0.8118023327551782, 4.385049249976873, 2.9268869943916798, 0.9636338730342686, 1.9371925760060549, 4.582818662747741, 48.621993362903595, 62.48197764158249, 45.99500052630901, 34.68160919845104, 50.35626970231533, 74.75978761911392, 75.4138845205307, 28.50437566637993, 0.4975812812335789, 0.10772917710710317, 0.01573704110342078, 0.011496569768496556, 0.010907712694461225, 0.07003752267337404, 0.38947838824242353, 7.568804360926151, 2.367112669162452, 12.019731625914574, 31.222867593169212, 30.775063522160053, 33.208223059773445, 38.43087561428547, 58.35848830640316, 58.87933395802975, 51.6978295147419, 58.106398433446884, 60.08189722895622, 63.897720873355865, 50.55019609630108, 30.00290885567665, 16.245680563151836, 21.118957065045834, 4.277724958956242, 12.141498941928148, 26.750591173768044, 31.874473728239536, 24.389973543584347, 16.871658973395824, 13.908912353217602, 30.411054454743862, 35.43336845934391, 55.332342088222504, 58.29785875976086, 50.52497684955597, 46.16110481321812, 49.00202997028828, 46.149819418787956, 39.613938331604004, 42.46596269309521, 42.134153097867966, 37.864284217357635, 38.11434119939804, 38.42989146709442, 44.22336459159851, 57.305648401379585, 56.334637105464935, 59.52138550579548, 52.572341188788414, 46.001843959093094, 46.677261516451836, 42.15960033237934, 44.065783247351646, 42.88319170475006, 41.95155389606953, 43.95298629999161, 42.55441814661026, 45.15844501554966, 43.804786652326584, 42.67435871064663, 41.956847012043, 42.154861986637115, 42.868300303816795, 41.8697252869606, 41.33063301444054, 43.19723725318909, 44.621058851480484, 41.43826983869076, 40.54660968482494, 41.83749541640282, 42.71230347454548, 40.42504660785198, 38.66462767124176, 39.950550869107246, 42.33988545835018, 41.28273278474808, 41.16139389574528, 40.7380586117506, 42.2533755004406, 42.67263740301132, 39.724052622914314, 40.66037558019161, 40.38502715528011, 40.345900654792786, 38.13500069081783, 38.851030468940735, 39.498302936553955, 43.318120166659355, 46.070000901818275, 46.63944594562054, 50.033838003873825, 45.12013927102089, 45.122434347867966, 46.57605014741421, 32.175864055752754, 24.315324649214745, 22.97036971896887, 12.305435445159674, 4.148202734068036, 1.7903071828186512, 8.34335669875145, 8.328658137470484, 8.891104906797409, 7.034432860091329, 4.488545721396804, 3.063420318067074, 3.7406111927703023, 1.3236722722649574, 0.08549292615498416, 0.011782704805227695, 0.08110688533633947, 0.14223197882529348, 0.03851867782941554, 0.13632118818350136, 0.07658457136130892, 0.0983395024377387, 0.319653483456932, 2.1732734329998493, 3.3777306647971272, 31.436718218028545, 52.30306103825569, 51.974181085824966, 47.44237706065178, 54.85716238617897, 56.85224913060665, 64.7667646408081, 58.092156797647476, 55.18350787460804, 41.08889378607273, 46.87770076096058, 52.495790496468544, 44.59736332297325, 20.190891064703465, 8.323460966348648, 0.3716463904129341, 0.6711662386078387, 0.2520943555282429, 5.245843660086393, 31.262005493044853, 43.62247243523598, 55.04632003605366, 36.618635058403015, 26.859075352549553, 25.302794761955738, 25.009347908198833, 23.279213346540928, 4.334246926009655, 1.4804098242893815, 0.6912731565535069, 28.414918966591358, 44.7882878780365, 37.40562982857227, 20.18629901111126, 7.951134145259857, 0.17065442400053144, 0.04655803335481323, 0.2886029746150598, 6.872269436717033, 23.587359711527824, 0.9468669164925814, 5.7720764726400375, 1.5293447859585285, 4.780483581125736, 1.151063684374094, 3.6052807420492172, 7.812131904065609, 30.879210233688354, 54.36321549117565, 55.95552384853363, 56.26989997923374, 42.33898490667343, 56.83974780142307, 82.5507527589798, 86.39094829559326, 50.707994028925896, 0.6716280325781554, 0.11193578888196498, 0.013762284470431041, 0.00986013228612137, 0.015387983075925149, 0.031982650034478866, 0.33078109729103744, 8.308385275304317, 6.06071705929935, 18.05799901485443, 35.47379069030285, 39.061653167009354, 42.618505507707596, 47.37000614404678, 65.03728732466698, 64.59837287664413, 63.645456209778786, 65.22183582186699, 65.36858394742012, 68.96699085831642, 61.250277534127235, 39.124931171536446, 26.85926914215088, 32.05331303179264, 13.909649513661861, 17.481794133782387, 37.52229116857052, 43.2415808737278, 33.17607298493385, 22.092157043516636, 27.679850310087204, 40.67001186311245, 49.74322199821472, 57.93727330863476, 57.322842478752136, 54.47717897593975, 52.74739019572735, 51.69265039265156, 53.81593085825443, 46.2643338739872, 46.911990121006966, 46.70300513505936, 44.83458839356899, 41.18903361260891, 40.41867434978485, 44.43120963871479, 55.869063287973404, 58.39491315186024, 61.49357467889786, 54.55016165971756, 49.620857164263725, 48.32511529326439, 46.17887265980244, 45.174700543284416, 43.24802152812481, 45.11061318218708, 45.72463743388653, 45.68280167877674, 48.07046815752983, 47.364443242549896, 45.00754751265049, 45.13048991560936, 46.734114065766335, 45.84608651697636, 45.09218417108059, 44.4197266548872, 45.13588182628155, 45.21263390779495, 44.80580493807793, 41.86413958668709, 43.859952092170715, 46.2897203117609, 44.591287449002266, 41.51435695588589, 44.55308809876442, 44.574298560619354, 44.09405753016472, 41.68502479791641, 44.86746042966843, 46.018395870923996, 44.33914817869663, 42.33120672404766, 43.694056794047356, 43.612239584326744, 43.0460661649704, 41.49398624897003, 41.29996865987778, 41.35695040225983, 44.2413604259491, 48.637420535087585, 49.003006517887115, 52.22664333879948, 48.4552089124918, 50.23445583879948, 48.820878490805626, 36.67923800647259, 29.13134392350912, 23.26373677700758, 15.619036238640547, 8.556401766836643, 9.047113135457039, 13.552946504205465, 10.799465104937553, 10.465556122362614, 9.55503948032856, 6.157998964190483, 3.0416389368474483, 4.454222163185477, 1.5024518477730453, 0.025593901445972733, 0.06777392773074098, 0.0717767902824562, 0.1072385061706882, 0.009491435175732477, 0.15425440011313185, 0.11487604439025745, 0.09780804306501523, 0.1932976910029538, 2.612282163463533, 6.385404886677861, 39.672842770814896, 55.49317605793476, 56.95921719074249, 55.022350922226906, 59.74413715302944, 67.45341807603836, 69.31188315153122, 69.20300379395485, 61.34009711444378, 48.75447705388069, 49.30529549717903, 62.0624915510416, 48.75213257968426, 27.4479316547513, 13.26033465564251, 0.631416809046641, 1.013810655567795, 0.6583419267553836, 11.196598894894123, 49.07612219452858, 56.63151517510414, 66.14192605018616, 50.543367862701416, 31.102877631783485, 33.76937314867973, 32.73357912898064, 37.1026074886322, 12.415162157267332, 1.646853955462575, 1.575055739376694, 47.113352715969086, 62.22277075052261, 49.43291924893856, 30.88481493294239, 13.635481875389814, 0.29342696419917047, 0.15359546203399077, 0.41927757672965527, 7.502002045512199, 66.90865650773048, 23.40456862002611, 19.140750914812088, 1.936603132635355, 10.918668508529663, 7.507214890792966, 6.7902560625225306, 13.533818330615759, 61.95043556392193, 66.39629200100899, 76.82891339063644, 62.62743763625622, 50.15378996729851, 64.92469176650047, 87.80894100666046, 94.93963837623596, 61.196141839027405, 0.8493563113734126, 0.1584191992878914, 0.12895234453026205, 0.15135171212023124, 0.07083002506988123, 0.17067204258637503, 1.691328075248748, 12.116442136466503, 8.406616654247046, 19.10120263695717, 44.00566287338734, 44.92894873023033, 45.87233170866966, 53.01888942718506, 65.52046179771423, 63.535281121730804, 60.79071879386902, 63.32267493009567, 65.45059874653816, 66.05499431490898, 62.96078234910965, 57.8681930154562, 39.02251146733761, 45.36897271871567, 27.823864482343197, 23.81158947944641, 49.20913025736809, 55.26599004864693, 38.59007567167282, 28.947709277272224, 34.79874171316624, 46.32992595434189, 56.85922175645828, 65.14087736606598, 64.6799848973751, 58.22652518749237, 58.380933701992035, 58.879976123571396, 57.89607971906662, 48.49600352346897, 50.61893440783024, 48.76823611557484, 45.06524361670017, 42.38506883382797, 40.31347319483757, 48.324416130781174, 59.74088452756405, 58.319920375943184, 63.35023105144501, 55.10961703956127, 50.862311348319054, 51.29673443734646, 49.019212648272514, 48.081696555018425, 48.498321399092674, 48.26014257967472, 47.1489492058754, 47.91319079697132, 51.223120987415314, 49.50982332229614, 47.92888395488262, 48.42180870473385, 48.81248474121094, 49.8297281563282, 48.45548629760742, 46.418495401740074, 49.1909634321928, 48.37360829114914, 47.90960378944874, 48.74338544905186, 49.28995572030544, 49.3372555822134, 48.66068288683891, 45.23427374660969, 47.75406293570995, 46.987974643707275, 47.26398803293705, 48.07787016034126, 47.931665405631065, 48.11430260539055, 47.62514725327492, 44.9862914532423, 46.907624155282974, 47.326677069067955, 48.34466524422169, 46.74588963389397, 45.15749126672745, 45.29395334422588, 46.50994889438152, 52.656662464141846, 50.81886067986488, 55.43816260993481, 52.37920895218849, 53.59710820019245, 55.950356125831604, 40.77112443745136, 35.69586217403412, 36.039622128009796, 31.924123764038086, 23.283824399113655, 22.002958729863167, 21.309919618070126, 14.18851749971509, 11.52737494558096, 10.742991585284472, 7.473442777991295, 4.182657860219479, 5.005460483953357, 1.8500016233883798, 0.23827424476621673, 0.16143340239068493, 0.2010906275245361, 0.34814411716070026, 0.21838210435817018, 0.24731306912144646, 0.15295736346160993, 0.11202113586477935, 0.3039575647562742, 2.8611367475241423, 12.304255608469248, 47.36402906477451, 57.924297004938126, 60.409352257847786, 60.51408603787422, 61.77802361547947, 66.28843858838081, 64.233128875494, 66.40731900930405, 57.30722151696682, 53.947605192661285, 52.97320447862148, 65.59119120240211, 46.417347863316536, 30.505621880292892, 13.35742324590683, 1.1848792573437095, 2.01485067140311, 0.7847807358484715, 12.880940213799477, 64.77768525481224, 67.29539215564728, 75.63241839408875, 56.904602721333504, 42.18431040644646, 41.18263475596905, 37.44781136512756, 46.55016973614693, 21.875821352005005, 2.4473612755537033, 0.6376581522636116, 53.03864076733589, 95.74863016605377, 62.53510259091854, 53.784092366695404, 22.101115062832832, 0.4239721951307729, 0.46689062495715916], [0.07521506398916245, 0.8735625562258065, 13.863728027790785, 5.98722567781806, 1.5596894826740026, 3.9651278452947736, 5.719795553013682, 12.761939149349928, 8.613735940307379, 7.191176349297166, 16.9493306055665, 50.54629370570183, 52.534130439162254, 34.49488341808319, 32.1322537958622, 48.03066149353981, 77.85068616271019, 73.96195203065872, 49.66078162193298, 4.928979137912393, 0.2934801613446325, 0.016362589958589524, 0.0249230018016533, 0.028404529730323702, 0.16297407128149644, 0.2755198907107115, 9.35841903090477, 5.975136151537299, 16.920883432030678, 23.088522478938103, 27.202402129769325, 32.6103213429451, 47.83217154443264, 61.51652544736862, 60.8376082777977, 59.29462127387524, 55.69163180887699, 59.38833564519882, 62.57393650710583, 56.915975511074066, 44.11304511129856, 22.876681946218014, 28.179097920656204, 11.258985847234726, 8.659520633518696, 22.219138629734516, 40.549999102950096, 44.02776628732681, 36.20145924389362, 38.73612463474274, 49.0203981846571, 51.98558047413826, 57.53141708672047, 57.4794814735651, 51.38774335384369, 42.11081475019455, 43.298387825489044, 43.028279319405556, 44.097492545843124, 42.69704349339008, 40.00541612505913, 42.1256073564291, 39.6804765611887, 40.73749624192715, 38.03166143596172, 41.33542835712433, 50.331567227840424, 54.38834734261036, 48.26354719698429, 43.2195420563221, 47.084033489227295, 42.486591786146164, 41.15408308804035, 40.46425670385361, 41.90607413649559, 43.14058229327202, 43.37210386991501, 45.34457042813301, 44.37635578215122, 43.87708157300949, 47.08598278462887, 45.634339079260826, 43.372461050748825, 43.74026231467724, 43.04593317210674, 44.68215577304363, 43.27891767024994, 42.55624204874039, 40.07568195462227, 39.561767131090164, 42.62817978858948, 44.63546767830849, 45.21163836121559, 44.451492950320244, 41.92747078835964, 41.266412660479546, 40.886626839637756, 41.7681909352541, 43.498447090387344, 41.543091014027596, 39.35510762035847, 41.93410523235798, 38.697936683893204, 38.680693209171295, 35.850221291184425, 38.89416575431824, 37.346797585487366, 43.08114968240261, 43.99049028754234, 46.58162824809551, 47.018209621310234, 43.67063485085964, 38.8543438911438, 33.365842401981354, 25.71593329310417, 21.660129725933075, 9.706240016967058, 1.1788572929799557, 3.05300768930465, 9.205982610583305, 14.345960151404142, 14.006724804639816, 13.786093443632126, 14.76236555725336, 11.313791256397963, 9.516608342528343, 9.152439683675766, 4.435868198052049, 1.2612450658343732, 0.11780162021750584, 0.058515379423624836, 0.03745640846318565, 0.13255556055810302, 0.08201318865758367, 1.1295009101741016, 6.679205121472478, 3.0698113376274705, 4.301558705046773, 8.540872000157833, 45.65470598638058, 55.72400987148285, 53.77030290663242, 53.726134076714516, 58.22201482951641, 60.82322984933853, 58.17533053457737, 49.392219632864, 44.29472476243973, 46.58519245684147, 61.5997713804245, 35.47270014882088, 25.2786660566926, 28.612498864531517, 20.978032127022743, 1.2416358618065715, 0.15328974172007293, 0.5892936943564564, 16.217898353934288, 45.26202365756035, 49.36646841466427, 49.25845541059971, 31.534464173018932, 35.50751008093357, 49.437604397535324, 28.03937941789627, 42.49832555651665, 16.073080524802208, 2.307677920907736, 17.613515965640545, 37.14319311082363, 23.392109088599682, 20.115157328546047, 11.116806026548147, 1.8980866181664169, 0.14884473726851866, 0.14930399309378117, 0.2990915992995724, 1.5871406346559525, 19.112923108041286, 8.48282441496849, 5.063291480764747, 7.567190872505307, 3.033344456925988, 8.060960602015257, 5.3237090818583965, 7.009205538779497, 35.484540313482285, 52.39273622632027, 53.73025305569172, 46.15049958229065, 39.60482642054558, 56.09461158514023, 88.23906272649765, 77.57702484726906, 72.57381811738014, 12.868180498480797, 0.2118778627482243, 0.013113137174514122, 0.035671023797476664, 0.03391630467376672, 0.07165772753069177, 1.1797573696821928, 11.24245673418045, 7.67605978064239, 20.463581532239914, 32.66835942864418, 37.212896570563316, 39.558818489313126, 54.28111329674721, 63.63004423677921, 67.37804532051086, 62.442520558834076, 62.321257665753365, 65.19541203975677, 67.07526236772537, 64.02396529912949, 54.27458144724369, 32.693369686603546, 38.5465794056654, 22.72671539336443, 15.38668155670166, 28.282059095799923, 47.896627485752106, 54.3243283778429, 43.16753804683685, 49.4532785564661, 52.567918226122856, 56.899142414331436, 60.733391270041466, 62.351082265377045, 53.780904337763786, 47.469651997089386, 44.608367532491684, 47.79828496277332, 50.42986795306206, 47.82331041991711, 45.02183474600315, 44.29988108575344, 43.99399369955063, 40.510036647319794, 40.25416977703571, 43.75022158026695, 48.87995392084122, 53.63360904157162, 49.48078528046608, 44.88353356719017, 50.93679115176201, 44.97656397521496, 44.55750346183777, 42.47942917048931, 45.523700416088104, 46.75770699977875, 47.521120235323906, 47.524825036525726, 44.97203081846237, 47.60725021362305, 49.92781989276409, 49.63577516376972, 48.11869516968727, 45.500514060258865, 45.25710292160511, 47.4296173453331, 45.880660861730576, 45.39433255791664, 43.56234826147556, 43.247622549533844, 47.42675989866257, 46.56677484512329, 47.90329992771149, 46.94905713200569, 46.685890853405, 43.370591551065445, 44.29797738790512, 44.2997632920742, 47.31516368687153, 45.14875553548336, 43.33022631704807, 46.695766523480415, 41.467285081744194, 43.020862117409706, 39.331944063305855, 41.205064952373505, 39.66387905180454, 44.82264943420887, 44.489525109529495, 50.2757216244936, 52.40443579852581, 48.15081104636192, 41.58184893429279, 36.82171516120434, 31.410321034491062, 28.85336983948946, 16.077864468097687, 10.293172672390938, 11.478499118238688, 12.670647148042917, 16.38553775846958, 17.072937972843647, 16.3767222315073, 19.703324027359486, 15.364199113100767, 12.883923053741455, 10.647430513054132, 5.326105328276753, 1.3534265756607056, 0.036510144200292416, 0.05550851987209171, 0.02771012997982325, 0.19380803627427667, 0.03950022379285656, 1.14576178137213, 5.528363725170493, 3.945116219110787, 3.754182639531791, 18.128834813833237, 53.78655083477497, 59.38513621687889, 61.91850587725639, 59.252781718969345, 65.79796090722084, 63.711458668112755, 64.55695509910583, 57.73144595324993, 55.44045768678188, 53.54423023760319, 71.42420500516891, 43.68469029664993, 28.269504569470882, 37.456721886992455, 28.626837395131588, 1.2182246055454016, 0.32504005066584796, 0.4879670846275985, 26.039727218449116, 61.13586947321892, 60.41604369878769, 62.909036725759506, 41.55404582619667, 42.68947429955006, 45.627400651574135, 23.614742942154408, 56.57473482191563, 41.30599893629551, 7.65106899663806, 33.61658714711666, 60.405244678258896, 44.65489603579044, 29.820438846945763, 28.21252852678299, 3.416426838375628, 0.18051372229820117, 0.19845665636239573, 0.4662037524394691, 1.3289785687811673, 53.15468654036522, 50.00736482441425, 19.684148356318474, 16.059779338538647, 17.691729068756104, 24.26886834204197, 27.563263066112995, 33.24484929442406, 67.17898920178413, 59.03222255408764, 67.25937008857727, 48.82723554968834, 45.26740036904812, 62.98742271959782, 92.64248684048653, 86.13889262080193, 79.89616200327873, 14.587552137672901, 0.4589670110726729, 0.11094455418060534, 0.14553554530721158, 0.15224739530822262, 0.35617163171991706, 1.9603662262670696, 13.722260668873787, 9.18808177113533, 27.25630223751068, 40.03728121519089, 46.34713903069496, 48.515713065862656, 63.44621770083904, 62.134687677025795, 69.13957759737968, 60.22679105401039, 62.108628675341606, 62.72383466362953, 66.8112601339817, 61.0108257830143, 63.96600320935249, 48.93561713397503, 48.43817442655563, 43.18651042878628, 33.44561532139778, 37.42593213915825, 61.72109127044678, 61.55953533947468, 49.15232330560684, 58.987954929471016, 60.808319449424744, 68.31990838050842, 64.87477004528046, 66.15112915635109, 59.596955850720406, 56.13278053700924, 54.22135390341282, 53.44311386346817, 53.54184776544571, 51.94562181830406, 48.189082592725754, 50.56216545403004, 44.94445949792862, 41.7789139598608, 39.049087241292, 47.15621441602707, 54.546582251787186, 57.448604330420494, 50.6466843187809, 45.47948218882084, 52.792090997099876, 48.13901647925377, 47.83499859273434, 44.14213255047798, 46.45395129919052, 47.734554782509804, 48.02127219736576, 52.203301191329956, 47.06066094338894, 50.281360521912575, 51.551525965332985, 53.462257236242294, 50.79793520271778, 48.7164106965065, 48.882009610533714, 52.1029219776392, 49.67772491276264, 48.024053648114204, 46.526037231087685, 46.60703748464584, 50.38599170744419, 49.185202941298485, 50.47996066510677, 51.62559159100056, 50.20346850156784, 46.965308859944344, 46.29369109869003, 45.941222012043, 48.707530573010445, 47.68255837261677, 44.58697848021984, 48.35816591978073, 44.42691206932068, 45.39590187370777, 43.327448666095734, 44.85719718039036, 42.927314937114716, 48.11557553708553, 47.93483063578606, 55.11498995125294, 55.53808584809303, 50.84203943610191, 46.8099769949913, 39.068694189190865, 38.58287125825882, 34.55101780593395, 29.03933186084032, 18.93017191439867, 20.758269019424915, 21.444574892520905, 18.419429920613766, 19.88587573170662, 17.338971197605133, 20.318501517176628, 18.125092014670372, 14.464182257652283, 12.684572450816631, 6.6799152083694935, 2.116636522114277, 0.23771203821524978, 0.1388855607365258, 0.1767853059573099, 0.29635411337949336, 0.15715036424808204, 1.781199190299958, 6.58011831343174, 4.589767064899206, 4.920227732509375, 27.375214956700802, 59.95948679745197, 62.30880193412304, 64.67599511146545, 60.28515212237835, 65.73053732514381, 62.577363923192024, 64.76422637701035, 58.3412030339241, 58.09810347855091, 56.50011822581291, 69.94380444288254, 48.73654201626778, 33.44086937606335, 42.46913552284241, 33.02801012992859, 2.177375787869096, 0.4468655807431787, 0.5017950176261365, 28.798354491591454, 75.22745132446289, 70.17858624458313, 69.67884466052055, 47.14036166667938, 51.126864552497864, 65.73585703969002, 40.20774766802788, 67.84989640116692, 57.23810322582722, 10.000253040343523, 46.273935958743095, 87.97594964504242, 56.52235843241215, 50.794963762164116, 58.78426305949688, 5.057246955111623, 0.4667473607696593, 0.6218761741183698], [0.018537639261921868, 0.41906128521077335, 11.91604183986783, 4.599361550062895, 6.4283359330147505, 3.32518660929054, 2.5778244249522686, 30.264281630516052, 26.431640088558197, 22.463532015681267, 36.244328543543816, 47.11004689335823, 59.26115266978741, 31.14345945417881, 26.132335849106312, 45.64077213406563, 77.5223533809185, 68.15307453274727, 73.72577950358391, 28.395836390554905, 0.195248797244858, 0.055515455242129974, 0.05176012491574511, 0.06394659052602947, 0.39355966611765325, 1.0733117815107107, 9.136346597224474, 15.681973211467266, 22.494848035275936, 21.63743544369936, 31.245381385087967, 46.97070077061653, 54.306921511888504, 60.74005611240864, 59.32797588407993, 57.70670548081398, 59.09634791314602, 57.06970766186714, 59.00023207068443, 59.98808026313782, 52.09430783987045, 37.29355864226818, 36.27449132502079, 26.624162457883358, 25.751453787088394, 26.65104791522026, 39.368243515491486, 50.29986172914505, 47.95738622546196, 48.29002797603607, 47.656187787652016, 46.93729296326637, 53.762817308306694, 55.09790226817131, 45.91765947639942, 38.07265743613243, 32.017173171043396, 39.33832012116909, 42.803103402256966, 43.859883695840836, 42.50802643597126, 38.61079975962639, 38.34740549325943, 38.743978813290596, 37.688175067305565, 40.1948169618845, 39.91914935410023, 42.759755328297615, 43.855639323592186, 44.940150529146194, 47.789530232548714, 43.34548629820347, 41.466977298259735, 41.954536736011505, 44.00798074901104, 44.059315994381905, 44.16686162352562, 45.881371423602104, 43.64226937294006, 45.91742008924484, 45.22204980254173, 48.1070601940155, 44.408198073506355, 44.34258319437504, 45.802993029356, 45.41332393884659, 43.68992641568184, 43.306321799755096, 39.78424899280071, 42.21671126782894, 43.244499117136, 44.255807250738144, 40.69849893450737, 39.20877367258072, 41.116423308849335, 40.737306252121925, 42.28657431900501, 43.900134935975075, 45.11507414281368, 42.770174369215965, 41.24578736722469, 41.15792468190193, 40.134958773851395, 39.84249986708164, 37.80438043177128, 37.30006009340286, 37.6293770223856, 43.13699908554554, 41.43767327070236, 44.28798772394657, 47.76836156845093, 38.64895351231098, 31.85363944619894, 24.087963849306107, 19.00905378162861, 16.777230240404606, 5.3958263620734215, 11.741065979003906, 15.211002733558416, 15.497791394591331, 19.314513690769672, 17.133229337632656, 23.528645262122154, 25.72897609323263, 23.371696583926678, 23.444555774331093, 16.798207014799118, 4.453201442956924, 4.333777651190758, 2.284935428760946, 0.20063855568878353, 0.39102549897506833, 1.0816817823797464, 2.256154348142445, 16.826316006481647, 20.285885967314243, 6.209279587492347, 17.883280590176582, 47.23336547613144, 60.56465372443199, 57.130732387304306, 59.62196230888367, 54.740219861269, 57.50275522470474, 53.466976583004, 52.42347277700901, 47.09002956748009, 41.10551409423351, 44.40628297626972, 57.449238896369934, 38.99752780795097, 37.22794756293297, 35.11716842651367, 22.578413151204586, 6.546578463166952, 1.6033148230053484, 0.537539521465078, 29.406960234045982, 50.354738384485245, 54.40636597573757, 44.83548894524574, 24.007850848138332, 43.91916051506996, 80.2171915769577, 40.70283830165863, 58.128771632909775, 42.421866059303284, 34.89236868917942, 57.054713666439056, 20.54748672991991, 15.66687187179923, 13.502796795219183, 12.239614427089691, 0.5430271395016462, 0.1499074333696626, 0.07779465799103491, 0.1328564272262156, 1.435622340068221, 16.45437866449356, 15.756903290748596, 8.474200777709484, 5.850869519636035, 6.470675636082888, 24.168673418462276, 21.712346524000168, 23.943763487040997, 48.16993921995163, 46.56606428325176, 57.24480986595154, 41.57416194677353, 34.305307790637016, 53.73226694762707, 83.0644091963768, 77.74947479367256, 79.5675328373909, 37.48190313577652, 0.2857940347166732, 0.055723995028529316, 0.12064404581906274, 0.09798995830351487, 0.28873478004243225, 1.0240266448818147, 10.479575470089912, 16.39685545116663, 25.099714659154415, 26.61185871809721, 43.20899002254009, 54.6194851398468, 58.87429162859917, 63.73766966164112, 61.77649229764938, 61.70195169746876, 60.58509282767773, 61.8114922195673, 64.3112450838089, 64.21201720833778, 59.451640248298645, 46.58723674714565, 45.62494978308678, 38.36716063320637, 32.3883106559515, 34.45389501750469, 46.97612687945366, 53.12854394316673, 49.874949529767036, 51.24714329838753, 48.29567067325115, 53.278955072164536, 59.242989644408226, 58.43313530087471, 52.4003130197525, 46.23897023499012, 42.004830837249756, 42.31079801917076, 47.99074463546276, 49.79133501648903, 48.61531712114811, 43.566835820674896, 42.96289622783661, 40.027150958776474, 37.16055817902088, 40.336526557803154, 43.07167299091816, 42.143671587109566, 43.94296623766422, 44.99051682651043, 50.08505165576935, 46.244308948516846, 44.367593452334404, 44.15754072368145, 46.19911037385464, 47.336168959736824, 44.07147154211998, 46.95500001311302, 46.985880956053734, 46.965301260352135, 46.985041201114655, 49.20256420969963, 45.49563892185688, 46.77170544862747, 47.8540051728487, 45.317914858460426, 45.63129164278507, 46.22258171439171, 44.16947968304157, 45.327148362994194, 48.998777344822884, 47.05260917544365, 41.93920835852623, 42.67137587070465, 43.37058015167713, 44.453484043478966, 45.09585477411747, 46.601516380906105, 48.874318823218346, 45.81367805600166, 45.22155582904816, 43.63691546022892, 44.189375415444374, 42.55105532705784, 39.80930104851723, 40.05070969462395, 39.390392526984215, 41.43706150352955, 41.890453174710274, 45.77282264828682, 49.10694994032383, 40.15903428196907, 36.520604118704796, 28.508506044745445, 23.76132197678089, 21.818710416555405, 15.491141751408577, 19.441542774438858, 19.112700819969177, 17.61710487306118, 23.143509328365326, 19.652216769754887, 28.914753645658493, 32.16071426868439, 31.448489986360073, 31.68641421943903, 26.346566453576088, 16.166481412947178, 6.895842896774411, 3.5277193039655685, 0.2232653766986914, 0.17744270036928356, 0.8514537988230586, 2.279844176955521, 17.951781414449215, 27.536848783493042, 12.127473894506693, 28.480254560709, 52.84003682434559, 64.88813772797585, 61.447669342160225, 65.7563379406929, 58.92635263502598, 62.01151728630066, 57.56047412753105, 59.53223392367363, 55.83771117031574, 51.34612038731575, 53.86282794177532, 64.92387101054192, 45.72851322591305, 42.695390582084656, 44.66408014297485, 35.07728196680546, 14.913885276764631, 2.0058012194931507, 0.36550897755660117, 38.4796117991209, 61.5112779289484, 63.89880761504173, 57.06004098057747, 33.74810189008713, 51.245030611753464, 83.7689445912838, 46.74639880657196, 68.2632078230381, 62.23591044545174, 61.42645128071308, 76.63108080625534, 39.295542016625404, 26.01819757372141, 35.46764262020588, 22.94208023697138, 1.162210504990071, 0.3491382685024291, 0.11825171051896177, 0.14024551666807383, 1.289678702596575, 31.998348981142044, 60.98603971302509, 31.489096507430077, 18.595544770359993, 35.359162241220474, 58.12768489122391, 53.77604819834232, 60.51511198282242, 59.04824249446392, 60.21680139005184, 73.92450883984566, 45.281410217285156, 40.85228808224201, 58.63754913210869, 90.67504361271858, 84.32849496603012, 86.41025125980377, 38.75245615839958, 0.39355601475108415, 0.12144468957558274, 0.12381021108012646, 0.18363485403824598, 0.5942523689009249, 2.6348598394542933, 14.673608969897032, 24.311948530375957, 30.837199687957764, 42.23160646855831, 57.15689018368721, 58.88268157839775, 63.166727498173714, 63.163349479436874, 64.48950871825218, 63.19204553961754, 62.757709845900536, 60.29249332845211, 63.762934505939484, 62.75208234786987, 63.42951379716396, 54.8355757445097, 56.863614320755005, 51.26929230988026, 50.09034477174282, 49.90597486495972, 57.210592702031136, 64.7972010076046, 58.59961196780205, 62.169786393642426, 56.94168873131275, 61.59174621105194, 62.53956735134125, 61.97698473930359, 55.55124074220657, 52.27109335362911, 49.23591881990433, 49.91394303739071, 53.66574391722679, 52.85122722387314, 49.66158717870712, 48.00864167511463, 46.94698244333267, 43.61692853271961, 39.84232887625694, 43.05679678916931, 42.17158108949661, 45.792285203933716, 46.08792833983898, 45.78218914568424, 50.49146644771099, 49.248727932572365, 44.532006829977036, 45.05287908017635, 48.30198593437672, 48.95842730998993, 46.44017703831196, 49.56643268465996, 49.16967697441578, 51.51828154921532, 49.58665519952774, 53.60674448311329, 50.281531512737274, 49.56028461456299, 49.86691676080227, 49.48105126619339, 49.066470712423325, 50.56664161384106, 45.72814844548702, 47.3256891220808, 52.43459478020668, 51.420163214206696, 44.732905849814415, 45.274574384093285, 46.64706073701382, 48.76176506280899, 47.29933753609657, 50.07824242115021, 48.97850923240185, 46.66388623416424, 46.82625912129879, 46.94247588515282, 47.117194309830666, 45.494905561208725, 44.25595544278622, 43.09384860098362, 42.1605084836483, 47.6389367133379, 44.471920654177666, 50.440043807029724, 53.36168423295021, 45.16330495476723, 37.06037275493145, 34.615333154797554, 29.989482276141644, 38.594487234950066, 25.23771185427904, 24.866030998528004, 28.862035274505615, 20.201427899301052, 26.52661219239235, 24.234812669456005, 30.696120858192444, 33.59738677740097, 31.063044369220734, 34.24942798912525, 30.699637569487095, 20.687032341957092, 10.038172155618668, 4.28108730353415, 0.4073649487691, 0.5253346951212734, 0.8673678198829293, 3.090437105856836, 19.858891479671, 32.02691964805126, 16.556992158293724, 35.93477815389633, 56.48166261613369, 66.00196436047554, 61.04307845234871, 65.44011890888214, 57.788404896855354, 62.48543165624142, 57.25974306464195, 58.78343850374222, 58.64462435245514, 57.302912548184395, 55.9290886670351, 66.52897328138351, 50.78367076814175, 43.622746020555496, 51.15415468811989, 43.43619503080845, 15.607122927904129, 2.0425530849024653, 0.43365348188672215, 43.84430453181267, 71.6552098095417, 76.52890428900719, 63.83501663804054, 41.75372131168842, 58.21836702525616, 96.50846779346466, 53.93460988998413, 76.1534920334816, 76.68814614415169, 77.64018505811691, 93.86579319834709, 55.0400085747242, 40.52540302276611, 71.04948431253433, 36.568458750844, 1.2418991164304316, 0.4942007688805461, 0.3287509671645239], [0.05815312601043843, 0.2456166234333068, 3.395201414823532, 6.849984582513571, 3.2346973149105906, 7.501160390675068, 1.336663537658751, 34.85983103513718, 42.88699150085449, 39.56047140061855, 49.64052110910416, 48.979766964912415, 64.1991738975048, 33.72769318521023, 31.540141068398952, 40.35630449652672, 72.37161576747894, 75.89214205741882, 65.32430872321129, 41.89961068332195, 0.9893731574993581, 0.038613234864897095, 0.03441790373472031, 0.4086071555502713, 0.3600277123041451, 6.708245538175106, 12.887055985629559, 19.696746580302715, 30.26983693242073, 45.1769994199276, 53.456040769815445, 58.81648913025856, 58.683568462729454, 57.37217143177986, 58.04772958159447, 57.4625001847744, 56.714954897761345, 54.626879543066025, 60.07134899497032, 54.91038993000984, 53.71955282986164, 47.89673388004303, 45.83940267562866, 42.57476605474949, 46.136877313256264, 46.37627586722374, 48.227688521146774, 52.03491322696209, 46.948031187057495, 49.80370335280895, 47.25161969661713, 48.97818624973297, 55.199907794594765, 54.61239852011204, 47.15034373104572, 36.387474462389946, 33.891194611787796, 33.27750854194164, 37.54810318350792, 43.00151735544205, 41.47981680929661, 39.977537021040916, 37.63320341706276, 38.19785311818123, 34.0189665555954, 35.00599779188633, 40.960088297724724, 38.03538903594017, 41.610035821795464, 44.35504652559757, 44.72135066986084, 45.15165098011494, 42.621883526444435, 44.69620741903782, 41.73307701945305, 45.079986825585365, 44.0149761736393, 43.765162378549576, 46.83248698711395, 43.79728585481644, 43.0395533144474, 45.64502030611038, 46.11474350094795, 42.47304931282997, 43.17599639296532, 45.381857827305794, 44.91704776883125, 44.55848000943661, 42.45533466339111, 44.14414644241333, 43.26721429824829, 43.08534845709801, 42.33839973807335, 41.90601333975792, 43.58679234981537, 41.75282076001167, 40.23738607764244, 43.316615447402, 42.1028845757246, 41.77314206957817, 40.13483718037605, 42.44094863533974, 39.33273822069168, 40.89754745364189, 37.27634936571121, 38.3108476549387, 38.579086661338806, 39.695265367627144, 34.57889311015606, 35.30762940645218, 35.2899831533432, 34.691610261797905, 31.067822612822056, 19.794186651706696, 15.84578337147832, 5.9554152097553015, 16.013932898640633, 21.565140523016453, 16.112214624881744, 17.618885077536106, 13.481594882905483, 24.93329308927059, 37.05514803528786, 45.4284281283617, 37.32888534665108, 25.02445589751005, 23.721933290362358, 21.72657486051321, 19.949206933379173, 19.495967254042625, 8.202150575816631, 7.002664664760232, 9.35305941849947, 23.798301592469215, 34.553814455866814, 40.53183227777481, 48.545469269156456, 54.352234080433846, 58.786539137363434, 60.37147969007492, 60.904097110033035, 57.83943235874176, 50.79378582537174, 49.71532389521599, 51.12078867852688, 52.26891607046127, 45.78012965619564, 46.22058302164078, 46.61714494228363, 55.05723685026169, 56.92353330552578, 58.46601113677025, 44.82323080301285, 31.51190098375082, 23.74307345598936, 1.0319441137835383, 1.2164674373343587, 41.016283482313156, 52.614788711071014, 49.35172140598297, 34.33847241103649, 24.362326227128506, 46.07271395623684, 37.5259617716074, 30.266485512256622, 52.012004256248474, 60.474625155329704, 67.32452899217606, 33.10806043446064, 22.833907641470432, 18.922503925859928, 15.313868913799524, 8.634808659553528, 0.3298544220160693, 0.13168886565836146, 0.0620035996689694, 0.0827135459985584, 0.46391529554966837, 11.103843972086906, 24.784618467092514, 3.263518768362701, 10.795229282230139, 16.834968142211437, 38.23911130428314, 44.6875286847353, 48.91738571226597, 55.66867724061012, 49.67129945755005, 64.44620624184608, 38.86330761015415, 39.90586906671524, 48.66279177367687, 79.86181944608688, 77.26593554019928, 71.09672337770462, 52.33675003051758, 1.4737028279341757, 0.13495087187038735, 0.23560800502309576, 0.439506919356063, 0.4156641784356907, 7.432723687961698, 14.896535407751799, 26.41343716531992, 39.68559868633747, 58.24695289134979, 59.646227806806564, 61.7235117405653, 61.90519139170647, 58.08504357933998, 63.27755235135555, 60.14818087220192, 59.18821558356285, 60.58565139770508, 63.15872512757778, 63.013686910271645, 60.739170759916306, 57.52462685108185, 54.403101950883865, 51.870344057679176, 52.59205833077431, 54.32209029793739, 55.62790922820568, 57.818290293216705, 52.440651655197144, 54.486572071909904, 54.92042139172554, 57.31675900518894, 57.17659592628479, 57.55867302417755, 53.73781464993954, 45.821243450045586, 43.32625932991505, 40.52354492247105, 43.67914259433746, 46.662598103284836, 50.8888491243124, 46.94982469081879, 40.948932096362114, 40.78103810548782, 37.142630741000175, 37.09904707968235, 42.40423500537872, 41.345235630869865, 41.44024573266506, 43.55015091598034, 45.20983725786209, 48.77717703580856, 44.30247634649277, 46.75985008478165, 43.21393355727196, 47.51092918217182, 45.93039259314537, 48.022947907447815, 48.34860563278198, 44.90909859538078, 44.23351004719734, 48.312043994665146, 49.16322112083435, 46.906244829297066, 47.0333594083786, 48.91352131962776, 48.519786447286606, 47.10740223526955, 45.683010667562485, 45.84100618958473, 47.61059783399105, 46.670212894678116, 44.9764309823513, 43.91701363027096, 42.08879113197327, 43.47227789461613, 43.6333854496479, 47.26508617401123, 41.40052646398544, 44.46647174656391, 43.44763241708279, 42.55396977066994, 42.226807326078415, 43.971035331487656, 40.637516006827354, 43.00483837723732, 41.11638531088829, 40.24864487349987, 34.186024591326714, 38.190568909049034, 36.01528823375702, 38.39516133069992, 33.5739154368639, 25.93086116015911, 15.54528884589672, 13.05682422593236, 24.104720950126648, 27.645771838724613, 17.867467738687992, 23.54989942163229, 18.323103189468384, 30.74828065931797, 40.47715701162815, 48.3640556037426, 44.0748305618763, 33.93968380987644, 32.821156829595566, 32.83753015100956, 24.61929313838482, 22.462002597749233, 8.013759534806013, 8.738390151411295, 10.574919953942299, 28.866948410868645, 41.12319074571133, 46.422526985406876, 59.71467733383179, 60.09839974343777, 62.25796066224575, 66.81059896945953, 64.97399792075157, 63.08360695838928, 56.65881671011448, 55.093353912234306, 56.172925382852554, 57.89088539779186, 52.965034916996956, 56.39433190226555, 55.42275823652744, 63.23191300034523, 66.41070082783699, 70.52178382873535, 57.076201513409615, 45.17081715166569, 32.796811535954475, 0.7572746055666357, 1.7995738168247044, 49.90693621337414, 62.32723094522953, 57.95146934688091, 46.72629788517952, 30.800037682056427, 52.59317547082901, 51.05759806931019, 41.07517272233963, 74.05524462461472, 73.33835229277611, 72.21564933657646, 51.06905445456505, 41.208093389868736, 34.30490121245384, 38.736098036170006, 11.480422765016556, 0.2569609443889931, 0.10213417772320099, 0.049059842858696356, 0.39235308242496103, 0.5809757031966001, 9.72802709788084, 55.222148001194, 35.763259157538414, 24.443071894347668, 31.815390698611736, 58.92708979547024, 66.65404736995697, 69.11279663443565, 67.92296648025513, 66.34491115808487, 72.6624521613121, 48.64741399884224, 49.49110172688961, 55.517661944031715, 84.87330213189125, 87.659852206707, 76.4514796435833, 56.13920599222183, 1.3689694041386247, 0.15692010550992563, 0.2861717581981793, 0.36479387374129146, 1.2256166338920593, 8.530551753938198, 22.83798862248659, 37.48933173716068, 48.10313880443573, 67.39561557769775, 64.96545597910881, 66.90829932689667, 62.46939271688461, 58.717234656214714, 64.69568565487862, 62.55602426826954, 60.83975896239281, 61.538685858249664, 61.84225536882877, 62.304587960243225, 62.55533650517464, 60.172495767474174, 57.42710128426552, 59.00454483926296, 57.683359533548355, 64.34895426034927, 59.84829716384411, 62.7058844268322, 58.525717332959175, 59.39450651407242, 60.83605036139488, 60.35767883062363, 59.0838997811079, 61.15448847413063, 57.05299995839596, 50.926102325320244, 50.13979151844978, 47.942950800061226, 51.104039177298546, 52.385592609643936, 52.82093904912472, 48.79402533173561, 45.56419104337692, 46.44030623137951, 40.348549112677574, 42.485615238547325, 41.44949823617935, 43.60245890915394, 43.45480643212795, 44.95487093925476, 47.65007771551609, 50.50420716404915, 46.987484470009804, 49.61189344525337, 45.38841247558594, 49.15206491947174, 49.91330847144127, 50.38905434310436, 52.528616935014725, 48.994251787662506, 46.10493242740631, 52.82235637307167, 51.65007747709751, 47.68199600279331, 48.39907832443714, 51.850645914673805, 51.2004704028368, 51.085207387804985, 48.305698335170746, 49.41550478339195, 49.87308382987976, 48.69168542325497, 45.7746921479702, 46.698783561587334, 46.971244141459465, 46.43718279898167, 44.80677388608456, 51.29680663347244, 46.380706429481506, 47.88503810763359, 43.81151609122753, 45.72707690298557, 45.882564559578896, 46.84758737683296, 45.69027587771416, 48.18364128470421, 47.7187742292881, 42.86033973097801, 37.3429673910141, 39.33354377746582, 37.69436113536358, 41.47590681910515, 35.088932141661644, 30.166735164821148, 25.533318892121315, 21.96132816374302, 30.55357340723276, 34.38678301870823, 23.72907690703869, 31.898228153586388, 23.625562861561775, 33.72408717870712, 44.21093165874481, 47.56711296737194, 47.411769703030586, 42.05010920763016, 41.74406222999096, 42.606619745492935, 31.330677308142185, 25.757845044136047, 9.038667138665915, 9.849358387291431, 13.116158992052078, 33.21605823934078, 46.30612403154373, 52.44844123721123, 64.48474377393723, 61.40685573220253, 64.1222508251667, 65.67203566431999, 65.80964148044586, 62.53525838255882, 56.87320880591869, 54.414926916360855, 57.58131600916386, 59.04886186122894, 55.584659948945045, 60.54747864603996, 60.25750860571861, 62.16151423752308, 68.89891371130943, 68.6277374625206, 63.48525680601597, 49.304809123277664, 43.90797011554241, 2.73841330781579, 1.4916833443567157, 56.342696473002434, 73.79418343305588, 67.23462581634521, 50.122221261262894, 40.71256957948208, 65.10058432817459, 50.060926750302315, 45.815737545490265, 69.0040996670723, 75.76885387301445, 81.03448212146759, 58.44481587409973, 47.615119591355324, 60.08782111108303, 73.94794598221779, 13.80398003384471, 0.5065781890880316, 0.20424665504833683, 0.2621733443811536], [0.026281792561348993, 0.0889645965071395, 0.23696564545389265, 6.789933554828167, 3.3704265067353845, 4.326622160151601, 3.3318825624883175, 21.26804206520319, 48.55397701263428, 51.17754243314266, 25.375002287328243, 45.201523303985596, 63.90943184494972, 53.78327161073685, 34.112494736909866, 41.48694522678852, 61.39574512839317, 75.57576343417168, 59.834686294198036, 52.84064099192619, 4.74028411321342, 0.3926780540496111, 1.0783315496519208, 0.3024288296001032, 9.55803656950593, 15.394878666847944, 35.17554089426994, 52.02594570815563, 58.58551852405071, 58.78876581788063, 59.794150069355965, 63.24557326734066, 63.61294895410538, 56.17684677243233, 56.70757569372654, 54.555378779768944, 51.8097373098135, 53.54309409856796, 59.116239845752716, 56.12461097538471, 54.563620537519455, 48.62560696899891, 51.894062384963036, 48.41136306524277, 52.55873031914234, 54.41414795815945, 58.52705866098404, 58.20282585918903, 56.6981939971447, 57.4870240688324, 56.73220217227936, 54.652623161673546, 54.83533255755901, 53.4434824436903, 46.28353804349899, 38.67207907140255, 37.26551614701748, 34.19470712542534, 34.85699638724327, 38.59270893037319, 41.174810975790024, 43.34494672715664, 39.112008064985275, 31.63707196712494, 36.82336427271366, 31.437620669603348, 36.003398671746254, 39.32342492043972, 41.30107440054417, 40.832388550043106, 43.81405055522919, 46.53747081756592, 41.49581395089626, 43.804779052734375, 43.76567155122757, 43.24452191591263, 42.63605676591396, 46.514717638492584, 44.79078434407711, 43.65286700427532, 42.67282359302044, 42.01213404536247, 41.59163720905781, 42.30152651667595, 42.59800560772419, 44.776485711336136, 45.06905101239681, 44.080720245838165, 41.37444466352463, 44.81082446873188, 46.17041431367397, 44.24192279577255, 42.22195118665695, 41.24145559966564, 39.43082615733147, 40.76263189315796, 43.607831820845604, 41.11739605665207, 41.37087665498257, 39.37156833708286, 41.520657017827034, 40.52883803844452, 40.17590157687664, 39.454191103577614, 36.3429294526577, 40.296978279948235, 39.201926440000534, 40.08797809481621, 31.147897616028786, 35.08827857673168, 34.30155359208584, 31.72302905470133, 27.433802112936974, 21.152513064444065, 7.920240852981806, 13.928976226598024, 20.01287631690502, 15.86546441540122, 10.559015907347202, 8.508803620934486, 7.140588238835335, 26.919568106532097, 48.43320049345493, 55.01639664173126, 48.6395788192749, 40.478300750255585, 37.39247873425484, 31.74897976219654, 23.686169609427452, 24.83005452901125, 16.47908303886652, 21.67887791991234, 34.98560808598995, 49.985584393143654, 46.10945798456669, 45.26439853012562, 62.49803937971592, 56.985758766531944, 60.4754763096571, 57.57840536534786, 62.96131432056427, 53.53357940912247, 49.80052672326565, 48.558407574892044, 49.46311242878437, 47.53419533371925, 46.84211187064648, 45.30402660369873, 48.408581614494324, 53.47493715584278, 61.73333041369915, 59.44231174886227, 45.20398937165737, 45.19404150545597, 14.243971724063158, 0.016560487347305752, 3.8545554410666227, 49.186779856681824, 52.0254897326231, 45.814836993813515, 23.46677128225565, 27.365225292742252, 45.18459141254425, 29.463712088763714, 28.505340814590454, 31.39232710003853, 50.379486456513405, 34.400895461440086, 27.294944263994694, 18.629828430712223, 23.539457581937313, 12.410345915704966, 0.97647724323906, 0.052363182985573076, 0.08154614770319313, 0.06606544440728612, 0.15609883004799485, 0.16379059699829668, 1.9021165394224226, 18.972948119044304, 16.78504452109337, 2.836849638260901, 15.151413381099701, 47.41808496415615, 57.047277465462685, 53.65868769586086, 34.02021288871765, 54.17619712650776, 73.27795073390007, 55.38029171526432, 41.621142625808716, 48.41747313737869, 69.52953547239304, 80.44672966003418, 65.56152239441872, 60.663767606019974, 7.432436803355813, 0.3737853787606582, 0.892003501066938, 0.4364587407326326, 8.962019551545382, 15.95888715237379, 35.967881977558136, 57.1423065662384, 61.968689784407616, 61.641622334718704, 65.08786261081696, 69.25361707806587, 65.45043155550957, 61.853232979774475, 60.485937148332596, 59.52064074575901, 56.53405040502548, 58.08249391615391, 62.10211202502251, 61.52243793010712, 60.91702401638031, 58.21342349052429, 59.69932235777378, 58.06026890873909, 59.5910357683897, 63.031986728310585, 61.943212151527405, 63.09398800134659, 60.728595927357674, 61.75387591123581, 60.58081805706024, 57.37241081893444, 57.00167991220951, 54.40251298248768, 50.77164441347122, 44.69471789896488, 44.55768585205078, 43.58827047049999, 43.271660059690475, 46.26098245382309, 46.41749605536461, 49.29068148136139, 43.47235009074211, 34.57494892179966, 39.52343478798866, 37.70881935954094, 36.19971513748169, 41.17202952504158, 43.355969935655594, 40.49268297851086, 44.39923815429211, 47.044416815042496, 43.38449500501156, 44.86140735447407, 46.24051675200462, 45.650047436356544, 46.3812156021595, 49.14509989321232, 47.14666172862053, 45.860867723822594, 46.23670935630798, 44.87691432237625, 44.50918145477772, 42.93654464185238, 45.15871100127697, 46.31334364414215, 46.26303054392338, 46.86516523361206, 43.66718843579292, 45.84047041833401, 48.23618106544018, 44.95295204222202, 45.065065026283264, 41.177805215120316, 42.24298685789108, 44.43810626864433, 45.02055801451206, 44.27834764122963, 44.79253225028515, 42.457318156957626, 44.803186878561974, 42.85335950553417, 42.4694699048996, 42.245449125766754, 38.69507923722267, 43.72844874858856, 40.32812900841236, 42.00824685394764, 36.544330045580864, 37.13691584765911, 35.627275854349136, 33.71173024177551, 32.54781849682331, 21.831135749816895, 13.718951046466827, 22.459147050976753, 25.348375216126442, 17.373384051024914, 13.667418211698532, 12.637006603181362, 14.390503261238337, 37.46858865022659, 51.815068423748016, 54.94463749229908, 55.981373861432076, 49.952013194561005, 49.25301790237427, 43.072413951158524, 33.45655493438244, 33.15593786537647, 22.67930343747139, 31.016544364392757, 46.214586943387985, 57.56029933691025, 54.72286619246006, 53.41330446302891, 64.98833075165749, 62.25744388997555, 64.98795077204704, 65.01540809869766, 66.55819371342659, 59.23219062387943, 53.48983235657215, 51.99572592973709, 53.054242730140686, 54.458575174212456, 52.59058400988579, 53.36451128125191, 57.210531905293465, 61.34479746222496, 70.25737881660461, 69.45847928524017, 57.09849111735821, 59.22209836542606, 19.13019698113203, 0.09826305380556732, 4.740389557555318, 60.064209178090096, 57.5031466037035, 56.47801101207733, 29.888388700783253, 31.41551535576582, 52.562385722994804, 32.17664301395416, 35.023188069462776, 54.43738751113415, 70.05143746733665, 47.72207245230675, 46.55813790857792, 33.973137214779854, 40.160804986953735, 21.606467105448246, 2.503782073035836, 0.3364259912632406, 0.1350132271181792, 0.09276077835238539, 0.23509691760409623, 0.2252127425163053, 1.3751235301606357, 25.6828560680151, 44.155872613191605, 31.196880787611008, 29.480108208954334, 48.52305427193642, 66.617371737957, 67.58562058210373, 37.205528765916824, 57.95021541416645, 74.3158346414566, 64.31607082486153, 54.07794959843159, 55.495281144976616, 74.50880348682404, 84.60094794631004, 73.60159456729889, 70.36428987979889, 7.330184765160084, 0.7269286620430648, 2.724166684783995, 0.3568173001985997, 10.587195195257664, 16.42390999943018, 42.3080887645483, 63.225597739219666, 70.14320254325867, 67.30579599738121, 70.23963376879692, 70.41447758674622, 67.30633556842804, 62.140706554055214, 60.73660209774971, 60.31599126756191, 56.51591777801514, 60.29311649501324, 66.48421928286552, 60.74450567364693, 60.817769542336464, 60.29832981526852, 63.7686949968338, 62.10170924663544, 61.11159257590771, 63.52506347000599, 64.69273701310158, 61.74123398959637, 60.923141688108444, 63.85900855064392, 61.37638136744499, 57.881249114871025, 58.24634492397308, 56.90594784915447, 53.065877705812454, 47.982609272003174, 48.28193821012974, 48.670528158545494, 48.47992278635502, 50.51806882023811, 53.19097839295864, 53.54105360805988, 45.69458104670048, 40.03253906965256, 43.42744790017605, 39.849457293748856, 40.07867619395256, 41.60803712904453, 44.95913431048393, 41.071129739284515, 47.55734369158745, 47.90783688426018, 45.91218777000904, 48.186133950948715, 48.661936819553375, 47.759937420487404, 46.301051303744316, 51.8451552093029, 49.43831875920296, 48.71969372034073, 48.64218927919865, 48.58298845589161, 46.6928368806839, 47.358097583055496, 48.817842453718185, 51.261358335614204, 49.62048098444939, 49.43178690969944, 48.4174807369709, 50.25993347167969, 53.282040506601334, 48.84892098605633, 47.52289094030857, 45.74705243110657, 43.51226694881916, 47.94087991118431, 48.739954233169556, 49.468356147408485, 47.31223784387112, 45.05229391157627, 47.67134517431259, 47.65972539782524, 48.03595840930939, 47.526975721120834, 41.046887040138245, 47.44399957358837, 44.66936945915222, 43.684735894203186, 36.73694930970669, 38.93891215324402, 35.95051310956478, 35.087921395897865, 35.381261855363846, 33.49988020956516, 20.23868680000305, 25.270882174372673, 32.83073611557484, 23.072135858237743, 22.775187492370605, 22.5289474055171, 23.93019251525402, 48.89240965247154, 56.80347494781017, 61.719236969947815, 57.459657937288284, 52.45574064552784, 52.60845445096493, 49.05191369354725, 36.58261679112911, 35.916079357266426, 24.735449105501175, 34.50916685163975, 50.061169937253, 58.12524542212486, 59.07469667494297, 54.40298415720463, 68.713149279356, 64.6809196472168, 63.08796152472496, 64.71920639276505, 65.34586116671562, 59.712652042508125, 56.83884724974632, 55.85334353148937, 54.49518620967865, 56.319939494132996, 58.70432674884796, 59.1457262635231, 59.40514974296093, 62.590321227908134, 67.59999141097069, 71.01765722036362, 63.14056970179081, 67.75430873036385, 27.649503238499165, 0.19118996191537008, 4.669364718720317, 66.04112505912781, 69.46123793721199, 61.94712974131107, 35.53104601800442, 43.75755898654461, 61.41370676457882, 40.468877255916595, 47.893298864364624, 49.419794753193855, 70.07224515080452, 52.84067139029503, 57.50891849398613, 48.73300440609455, 66.62864953279495, 38.01210008561611, 1.7095717275515199, 0.3845552180428058, 0.3729091992136091, 0.24353144079213962], [0.029937476574559696, 0.113736394996522, 0.1698166283313185, 3.3519435860216618, 13.303266651928425, 11.907493248581886, 27.389236204326153, 25.06851263344288, 36.10319271683693, 53.1680466234684, 34.64236490428448, 33.45363289117813, 27.076682075858116, 29.270786941051483, 29.21234417706728, 40.38064979016781, 50.18369436264038, 73.72398599982262, 59.28027704358101, 56.237438321113586, 16.743700839579105, 0.43046488892287016, 0.8414289867505431, 0.9686769742984325, 12.571868598461151, 23.929709941148758, 52.92349934577942, 69.1307544708252, 69.4696506857872, 66.89677074551582, 64.2370654642582, 61.35293662548065, 59.708278477191925, 57.36815124750137, 52.525273114442825, 53.149279430508614, 52.064399644732475, 53.48091043531895, 58.33144135773182, 57.030771151185036, 58.44895005226135, 54.26047660410404, 48.11172254383564, 53.887253031134605, 54.81545202434063, 58.25709454715252, 59.97671887278557, 57.553376108407974, 60.35249970853329, 60.108765587210655, 57.872323393821716, 61.62578098475933, 59.89349193871021, 56.77085369825363, 46.64531663060188, 43.442065715789795, 41.22401833534241, 41.87953636050224, 40.19362382590771, 41.86244107782841, 39.133993685245514, 43.03258828818798, 41.197389364242554, 31.27461701631546, 28.21784634143114, 34.83119577169418, 33.70958335697651, 38.02903577685356, 39.31664228439331, 38.503839299082756, 39.23203602433205, 44.51245687901974, 44.59115445613861, 42.738104090094566, 40.780251547694206, 42.935169115662575, 43.3850459754467, 45.58153711259365, 42.361696287989616, 46.280581802129745, 44.14938636124134, 40.778784826397896, 42.63959437608719, 41.02628834545612, 42.81248889863491, 43.941757902503014, 43.903588950634, 43.39772969484329, 40.43242961168289, 40.367681086063385, 43.481477200984955, 42.01065592467785, 42.069605961441994, 40.91122291982174, 40.021842643618584, 39.32731971144676, 39.600031077861786, 40.02292558550835, 41.104822531342506, 42.634377256035805, 43.858375176787376, 39.15757901966572, 40.087864100933075, 38.54106590151787, 36.91819578409195, 41.12038269639015, 35.120497047901154, 41.021025627851486, 36.96850888431072, 38.69874224066734, 32.982188388705254, 27.25053794682026, 25.66047716885805, 11.337322443723679, 20.054339691996574, 23.569466471672058, 12.378924451768398, 6.49200864136219, 2.7354421047493815, 5.647567603737116, 8.047988098114729, 24.709312207996845, 47.351330146193504, 48.281223848462105, 55.09946398437023, 52.69420064985752, 48.65109600126743, 47.78446890413761, 44.905678778886795, 37.7727547287941, 36.3972133398056, 43.1621765345335, 47.28563167154789, 51.87479741871357, 56.05026416480541, 55.34885600209236, 60.80580398440361, 58.32007236778736, 57.74564579129219, 59.23922784626484, 56.015142649412155, 47.60031558573246, 46.86075747013092, 44.752018824219704, 46.42387591302395, 46.0249163210392, 45.954449102282524, 46.08438313007355, 48.33205372095108, 48.896657824516296, 55.810546427965164, 54.82949987053871, 50.574340000748634, 48.67264084517956, 14.987747613340616, 0.03790427974308841, 7.681663054972887, 58.72543461620808, 48.95072132349014, 35.41599579155445, 22.49392468482256, 33.236238956451416, 37.401704639196396, 40.5458877235651, 38.40231254696846, 29.140909910202026, 28.29781875014305, 33.9166646450758, 39.721875339746475, 38.73455911874771, 25.296893678605556, 2.854453856125474, 0.2849761879770085, 0.11829876268166117, 0.11903232370968908, 0.04561611065582838, 0.06224813361768611, 0.08438630233285949, 0.08610426288214512, 5.931119313463569, 19.2597833275795, 17.149102985858917, 12.242888901382685, 29.976321682333946, 49.1011780500412, 58.77803899347782, 24.827407971024513, 38.57086770236492, 43.911617919802666, 36.9920714199543, 33.3357860147953, 45.86397975683212, 59.63745027780533, 78.39895874261856, 65.65992191433907, 62.72923417389393, 22.954332679510117, 0.22899564733961597, 0.7823849644046277, 1.0512925568036735, 15.677313711494207, 26.31347592920065, 56.177557334303856, 73.38453501462936, 71.88451990485191, 72.23441272974014, 69.73180621862411, 64.30008128285408, 65.82959040999413, 61.22934065759182, 57.444781735539436, 58.5655277967453, 55.45854091644287, 57.980739176273346, 62.802695631980896, 61.71766385436058, 63.80411669611931, 58.304641395807266, 52.92861007153988, 61.87602035701275, 61.86544172465801, 62.03579418361187, 64.71029207110405, 62.729196175932884, 62.66771927475929, 60.88042438030243, 62.81150355935097, 64.56128686666489, 61.33952334523201, 58.92257943749428, 48.37878741323948, 46.097355633974075, 46.68362237513065, 48.095049038529396, 47.7779446542263, 45.93815557658672, 45.34409925341606, 48.55229750275612, 46.96899466216564, 36.98345348238945, 27.5805901363492, 34.63399775326252, 37.598169296979904, 39.11364197731018, 40.49461707472801, 41.20851516723633, 39.7501952201128, 45.18505498766899, 47.84589260816574, 43.482240960001945, 43.10148999094963, 46.08436033129692, 46.346979439258575, 45.99492833018303, 45.36421537399292, 47.673362866044044, 46.12274967133999, 43.072945922613144, 44.494628235697746, 44.901571199297905, 44.26044300198555, 45.94785265624523, 46.404971927404404, 46.90947085618973, 43.57033543288708, 43.60986851155758, 46.02825254201889, 43.18519949913025, 45.29041953384876, 44.968295618891716, 42.71520271897316, 40.38125015795231, 41.24380387365818, 41.57977044582367, 42.59871616959572, 44.20420601963997, 44.61814060807228, 42.995015904307365, 41.20955251157284, 41.2434770911932, 41.01482816040516, 43.12918670475483, 37.22190588712692, 40.831769183278084, 41.2827517837286, 39.0953079611063, 35.515934228897095, 31.20579320937395, 25.39059855043888, 14.261015709489584, 26.01380690932274, 31.03660348802805, 13.607146795839071, 9.271159563213587, 7.730511333793402, 11.907969173043966, 17.41053845733404, 37.07755163311958, 55.06667174398899, 54.80388164520264, 57.716117575764656, 55.226259380578995, 52.45141267776489, 54.047703221440315, 52.685130536556244, 47.38877333700657, 47.9344392567873, 53.81121911108494, 52.21120096743107, 58.18068824708462, 62.03593097627163, 60.62736555933952, 65.39645925164223, 64.40298736095428, 62.0797274261713, 65.05167335271835, 60.93634597957134, 52.172788828611374, 50.95536835491657, 48.79998341202736, 49.45257179439068, 53.64118203520775, 52.08362281322479, 55.15596695244312, 56.6941624134779, 56.459122225642204, 61.89072176814079, 64.19715240597725, 62.90919251739979, 57.83679910004139, 20.333128832280636, 0.13018585334066302, 11.269746869802475, 66.9762472808361, 57.55759008228779, 42.8606703132391, 26.639146953821182, 38.04537869989872, 47.4464276432991, 36.98142819106579, 42.599612921476364, 23.00052870064974, 25.25565069168806, 58.87839160859585, 40.5051539093256, 35.37924036383629, 48.287337720394135, 5.598377818241715, 0.5016385728958994, 0.12499047821620479, 0.10303196861059405, 0.045140560978325084, 0.13637561729410663, 0.2545841719256714, 0.24453687277855352, 4.284398350864649, 41.43025606870651, 38.01237367093563, 50.61513461172581, 54.365704357624054, 54.17356766760349, 69.5409120619297, 51.33047662675381, 41.90646931529045, 40.13486757874489, 39.739608988165855, 43.91578249633312, 57.66153730452061, 62.83214405179024, 85.09812086820602, 72.65286907553673, 76.08856871724129, 25.89775923639536, 0.47619460383430123, 2.9343020590022206, 1.557881967164576, 17.302998527884483, 29.189978577196598, 62.38616578280926, 75.35869628190994, 73.22321847081184, 73.77555683255196, 71.88556104898453, 64.65501263737679, 67.06597566604614, 62.82217338681221, 58.13845731317997, 61.12207241356373, 55.723344907164574, 58.36976610124111, 63.99541363120079, 61.57367818057537, 66.66495278477669, 58.71933214366436, 54.614761993288994, 61.87578856945038, 66.33209824562073, 63.30251321196556, 66.69452279806137, 63.437979742884636, 65.23577347397804, 65.44538542628288, 64.99966934323311, 66.574836820364, 62.03735210001469, 58.87407124042511, 52.41215318441391, 50.1998320966959, 49.62892033159733, 51.67581729590893, 51.4979412406683, 52.5748148560524, 52.93296463787556, 55.09074345231056, 52.31446422636509, 39.63525138795376, 39.014721885323524, 42.86688297986984, 39.172857999801636, 41.84795245528221, 43.025782853364944, 41.8026664853096, 41.24283492565155, 48.58262747526169, 49.83306057751179, 48.03685136139393, 45.945359990000725, 48.174814358353615, 46.90149128437042, 48.94084945321083, 47.656761556863785, 51.292049288749695, 49.4880086928606, 44.56474967300892, 48.29473212361336, 45.659060552716255, 49.08592186868191, 49.331229105591774, 49.09471079707146, 48.091541826725006, 47.43866465985775, 47.73900054395199, 49.17566925287247, 47.06935867667198, 48.75411607325077, 46.74313098192215, 45.04914008080959, 41.893926188349724, 46.88829839229584, 46.293436512351036, 46.19917497038841, 46.89887322485447, 49.78048659861088, 46.676471158862114, 47.11039647459984, 44.980223178863525, 44.36263091862202, 46.03933274745941, 39.81033459305763, 41.4684022217989, 40.55140882730484, 40.253622606396675, 38.16302798688412, 32.776547223329544, 35.74654005467892, 21.576300524175167, 31.727945990860462, 39.52099151909351, 18.40111680328846, 13.836068361997604, 15.963256917893887, 20.89079450815916, 30.09703930467367, 47.08160161972046, 60.969259813427925, 54.2516914755106, 59.69578854739666, 57.37499088048935, 56.376047283411026, 57.35696844756603, 55.71279287338257, 48.39224249124527, 49.638317227363586, 56.11181326210499, 54.52846102416515, 59.01647999882698, 60.8997767418623, 60.49131765961647, 64.96335849165916, 65.87477758526802, 61.41648821532726, 64.82461273670197, 61.62817485630512, 52.36818954348564, 52.94979013502598, 51.14956833422184, 53.50890353322029, 56.559881418943405, 55.10243162512779, 57.226000875234604, 60.61982676386833, 59.81220670044422, 64.58806782960892, 69.26747873425484, 68.978291451931, 65.67321360111237, 27.00331561267376, 0.2572336985031143, 12.149259075522423, 74.08133402466774, 66.82468101382256, 48.81963595747948, 34.792437851428986, 52.12375245988369, 49.48604039847851, 56.11380435526371, 49.66016225516796, 45.227282121777534, 35.52059277892113, 62.06913739442825, 58.32587085664272, 66.66560634970665, 77.88776457309723, 4.631230914965272, 0.6052403105422854, 0.34777963359374553, 0.2686469501350075, 0.1606172922765836], [0.03767792470171116, 0.03415274550206959, 0.15528813761193305, 0.39676313172094524, 3.754220400005579, 19.42496046423912, 51.13325200974941, 49.147052988409996, 23.927376866340637, 23.413593135774136, 45.63790708780289, 45.86857371032238, 33.496965765953064, 29.07395750284195, 24.470331631600857, 41.30320608615875, 42.19361610710621, 63.576049134135246, 63.5915333032608, 52.909193113446236, 37.02613279223442, 0.20635239518014714, 0.2613671642029658, 0.8445794333238155, 10.895249415189028, 38.98515947163105, 58.069586008787155, 71.93331688642502, 69.02692884206772, 65.46978771686554, 61.8533393740654, 62.081315740942955, 58.51240664720535, 55.764257311820984, 54.20379884541035, 54.070684388279915, 52.024661377072334, 50.47736540436745, 56.594121381640434, 61.110065057873726, 58.187546879053116, 56.11252762377262, 51.13407276570797, 50.81585504114628, 57.11903281509876, 57.3429623991251, 59.09912556409836, 62.59695567190647, 60.91777257621288, 60.629083067178726, 61.75794169306755, 60.24689957499504, 62.82254956662655, 59.20140467584133, 49.99075211584568, 45.48549726605415, 46.15509733557701, 47.23662570118904, 44.7905183583498, 45.38702555000782, 46.58413231372833, 42.26278379559517, 38.44054989516735, 37.923804223537445, 19.35400877147913, 19.859564043581486, 34.314465299248695, 33.40161748230457, 37.29268468916416, 38.86641964316368, 40.05865506827831, 41.715795546770096, 46.182387471199036, 42.9847564548254, 42.05159492790699, 40.524365678429604, 46.34539872407913, 45.317580476403236, 39.74433213472366, 41.160740330815315, 42.784735187888145, 41.14804521203041, 42.14323081076145, 42.676600590348244, 40.82884334027767, 40.40979042649269, 42.637584283947945, 45.241801142692566, 41.20138294994831, 41.86465635895729, 41.42503134906292, 43.00016462802887, 41.087533459067345, 43.09365101158619, 41.547396183013916, 38.127207309007645, 39.59740161895752, 39.006533324718475, 42.02953331172466, 43.70079003274441, 41.45964369177818, 37.52446465194225, 39.657107815146446, 36.49026654660702, 37.486348897218704, 38.71932953596115, 36.42263397574425, 35.09525880217552, 35.517993718385696, 35.40545895695686, 30.56785114109516, 26.242832019925117, 12.459900956600904, 20.036007575690746, 31.071903593838215, 17.6007429510355, 6.947686364874244, 7.561217593029141, 6.60961945541203, 16.971832998096943, 13.74445527791977, 33.36852505803108, 50.37675820291042, 53.87140788137913, 50.4475674033165, 47.810968682169914, 49.242614060640335, 50.913027226924896, 51.97079926729202, 49.68810215592384, 46.04223199188709, 48.79599742591381, 51.98232024908066, 54.574571549892426, 54.69652600586414, 55.87003983557224, 54.375146850943565, 56.44636631011963, 56.79858461022377, 52.46974289417267, 48.1595391780138, 43.72971788048744, 45.08896194398403, 45.24079039692879, 46.022374257445335, 46.24123491346836, 46.42934761941433, 46.525695249438286, 52.30697862803936, 50.59623062610626, 54.86017182469368, 56.77835449576378, 52.26483128964901, 46.408110558986664, 14.019789453595877, 0.19963723520049825, 16.996335983276367, 59.248666539788246, 50.89342787861824, 31.880999878048897, 24.519198909401894, 32.590380012989044, 35.66685073077679, 32.81617149710655, 33.58762130141258, 54.48784500360489, 44.176615700125694, 18.052529208362103, 45.21214373409748, 57.03249245882034, 12.09437957033515, 0.07018792632152326, 0.058922113457811065, 0.0812631296867039, 0.013921695936005563, 0.049313134149997495, 0.03809079258644488, 0.07580820325529203, 0.2727751911152154, 1.2872042041271925, 11.716768182814121, 20.09853322058916, 51.857401952147484, 40.77789947390556, 28.98571863770485, 39.74463991820812, 48.33565592765808, 39.454175904393196, 24.587885923683643, 17.69443642348051, 30.284205861389637, 47.51354344189167, 50.46135686337948, 71.87257334589958, 71.92505612969398, 58.43975454568863, 45.455022901296616, 0.8340304275043309, 0.11687927908496931, 1.5231355628930032, 15.971567071974277, 46.68032415211201, 66.9644147157669, 76.87198027968407, 74.49392348527908, 69.22422185540199, 65.09153321385384, 65.80625966191292, 63.271088898181915, 60.518881380558014, 59.22413885593414, 58.564243465662, 55.57350754737854, 53.22691686451435, 61.029216796159744, 66.58635020256042, 64.41038936376572, 62.25953757762909, 58.43156598508358, 55.00960260629654, 60.284684747457504, 62.86062352359295, 63.50227229297161, 63.3997043967247, 64.58755105733871, 63.600067645311356, 61.88388593494892, 61.74626111984253, 62.18748964369297, 61.167586371302605, 51.865077540278435, 48.197297751903534, 50.55281415581703, 50.165288150310516, 51.984280943870544, 50.47279804944992, 51.23422399163246, 50.907331332564354, 44.96714048087597, 43.53045277297497, 27.7891818434, 20.70811551064253, 33.80558520555496, 37.200976610183716, 39.05728720128536, 39.94933493435383, 41.15992337465286, 43.404721319675446, 48.54801893234253, 46.390361711382866, 45.237127393484116, 43.23512502014637, 47.959954887628555, 47.70827159285545, 41.766063049435616, 41.9083996117115, 45.49420639872551, 44.65346731245518, 43.70159938931465, 44.75455328822136, 41.555653139948845, 40.43827369809151, 45.17924129962921, 48.14468577504158, 43.270132541656494, 45.11531352996826, 43.32794263958931, 44.54026758670807, 42.60742910206318, 44.085599184036255, 41.161648482084274, 40.34731797873974, 41.49547956883907, 41.864496767520905, 45.17991006374359, 45.8209128677845, 42.55189508199692, 41.465210393071175, 43.42070326209068, 38.76864328980446, 39.907510578632355, 40.324572399258614, 38.596801310777664, 34.858698695898056, 34.33143138885498, 39.00811783969402, 36.09284207224846, 29.145593158900738, 16.44657388329506, 26.45026858896017, 35.366640239953995, 19.849057607352734, 10.793944951146841, 11.524079572409391, 14.193067755550146, 27.209882028400898, 22.501186095178127, 45.80053836107254, 57.30075426399708, 56.65381237864494, 53.55087228119373, 52.2034265846014, 53.99587020277977, 55.89584805071354, 56.48017689585686, 56.39928683638573, 51.171379163861275, 55.38154564797878, 59.04054410755634, 59.0604018419981, 59.63052324950695, 61.837532222270966, 60.17393209040165, 62.596366703510284, 59.80716437101364, 57.466862350702286, 53.31431597471237, 50.01161679625511, 50.31143970787525, 50.84851808845997, 51.14246651530266, 53.06892514228821, 53.83777588605881, 54.53711695969105, 58.82071070373058, 63.23281355202198, 62.75156557559967, 65.3121417760849, 58.78300152719021, 58.12674254179001, 14.710598085075617, 0.23557716136565432, 20.15391144901514, 67.4949498474598, 58.67096073925495, 39.96803753077984, 27.31885828077793, 41.6172706335783, 45.40116839110851, 33.252821266651154, 39.18580770492554, 40.649599358439445, 53.897945657372475, 29.7569727525115, 44.634487330913544, 71.31955862045288, 22.299857698380947, 0.3319050354184583, 0.04880661093920935, 0.09914956404827535, 0.07703052047872916, 0.09067244900506921, 0.18806473352015018, 0.13371316250413656, 0.2467070907005109, 0.7190383260603994, 9.415451120585203, 38.91143582761288, 82.70361855626106, 66.17725655436516, 34.090395122766495, 37.090904116630554, 63.94623667001724, 59.24859434366226, 42.46521793305874, 43.032934069633484, 40.84701396524906, 58.84954735636711, 57.476278245449066, 77.88769617676735, 77.33063846826553, 65.89783474802971, 51.409675776958466, 1.2541481154039502, 0.7240190275479108, 2.7928833849728107, 24.753686226904392, 48.317789286375046, 69.09007385373116, 74.80059742927551, 78.3469395339489, 70.7067047059536, 70.31948268413544, 66.14981442689896, 64.1393195092678, 61.53685435652733, 59.26429130136967, 59.41825143992901, 57.472239062190056, 52.988392263650894, 61.776914075016975, 66.63836181163788, 65.0186151266098, 63.42466525733471, 61.34229339659214, 54.78543743491173, 59.18788880109787, 62.53161057829857, 63.29779766499996, 66.21729880571365, 65.93274727463722, 64.44015696644783, 63.551935628056526, 62.09974855184555, 63.374830931425095, 63.47384221851826, 54.646258503198624, 51.17765262722969, 51.99296347796917, 54.79755498468876, 56.08296141028404, 55.466425493359566, 55.57739093899727, 56.278255730867386, 51.12819828093052, 44.80678528547287, 30.8314847946167, 30.998320542275906, 43.1795834004879, 39.413331896066666, 43.01407568156719, 42.174567729234695, 41.08453921973705, 44.92615967988968, 51.54942087829113, 49.74275842308998, 46.8513073772192, 45.256437957286835, 50.35230651497841, 47.753120586276054, 42.37336166203022, 45.235694870352745, 48.98157946765423, 47.70531915128231, 48.42225328087807, 49.52485911548138, 45.57603120803833, 44.400309696793556, 49.11362998187542, 53.72351221740246, 46.857254058122635, 46.76520399749279, 47.17310830950737, 48.4419210255146, 45.24140976369381, 47.77072124183178, 42.66232095658779, 43.46645660698414, 45.01727879047394, 44.43819746375084, 46.86578080058098, 50.160819590091705, 48.88346113264561, 44.60544928908348, 46.10178619623184, 42.565304562449455, 43.568481132388115, 43.097188621759415, 40.58883301913738, 37.440679147839546, 37.06036515533924, 43.788956701755524, 40.298615992069244, 39.990243539214134, 26.110678911209106, 28.588446155190468, 42.614329531788826, 27.241000458598137, 18.61061666160822, 17.297631315886974, 22.359461300075054, 39.76705111563206, 34.84269015491009, 52.73393131792545, 54.77145418524742, 55.9012171626091, 54.441749677062035, 51.422066912055016, 56.182238683104515, 56.073796302080154, 59.263432547450066, 57.75887668132782, 52.41736650466919, 58.09558801352978, 60.22780179977417, 59.98287074267864, 61.78728371858597, 63.33424150943756, 58.94636996090412, 64.14513319730759, 61.304591819643974, 58.35101030766964, 54.0168184787035, 51.58499836921692, 52.70855627954006, 54.48408700525761, 54.29438978433609, 56.031101793050766, 57.53835931420326, 56.79392226040363, 63.25208231806755, 63.52320916950703, 65.56595295667648, 69.26449209451675, 66.51074185967445, 69.57913801074028, 21.894761435687542, 0.25943312735762447, 21.012032702565193, 76.19617894291878, 66.72487556934357, 49.171766862273216, 36.497972533106804, 50.72210267186165, 50.68508505821228, 43.82407061755657, 48.86232666671276, 74.64499577879906, 57.14383028447628, 34.951497316360474, 70.2583135664463, 100.8401669561863, 26.648108772933483, 0.3748385753715411, 0.2380034647649154, 0.14427727845031768, 0.14315690263174474, 0.1671989992610179], [0.06837031018221751, 0.05129988945554942, 0.12599498993949965, 0.031431364186573774, 0.308794230222702, 18.52788370102644, 49.822793528437614, 66.03901237249374, 36.18522651493549, 19.69820760190487, 23.161531761288643, 53.1038186699152, 61.563726514577866, 36.19878798723221, 19.85674649477005, 37.86664389073849, 43.74523624777794, 55.8616878837347, 66.69439360499382, 50.50885051488876, 52.16608218848705, 3.488344866782427, 0.3116836189292371, 2.874104264192283, 8.990149442106485, 55.674768313765526, 57.06905409693718, 63.545570969581604, 62.709558829665184, 64.11854982376099, 58.80035899579525, 57.041995748877525, 51.68977774679661, 52.300936952233315, 52.58126690983772, 50.48177696764469, 50.20396627485752, 47.6404832303524, 52.16463066637516, 58.92592325806618, 59.019158855080605, 62.11098834872246, 56.39599621295929, 57.7218172699213, 56.61790430545807, 58.844843208789825, 58.58355402946472, 58.471916019916534, 56.47499017417431, 55.84179975092411, 57.493495121598244, 60.472216084599495, 62.025356143713, 57.9970782995224, 52.98295855522156, 46.04831166565418, 50.958833768963814, 48.441947624087334, 51.361893340945244, 50.02517826855183, 47.78483368456364, 48.36570091545582, 41.454559564590454, 43.515948951244354, 38.047210201621056, 15.672816652804613, 17.0294227078557, 30.38139894604683, 33.6461191624403, 34.680324867367744, 35.956740975379944, 41.16981044411659, 44.497801065444946, 40.722791031003, 40.0032502412796, 40.56805573403835, 42.70441509783268, 47.58579656481743, 44.40724812448025, 39.75165814161301, 41.727628111839294, 38.45610626041889, 40.976108238101006, 39.72482778131962, 40.488453805446625, 38.421911895275116, 42.53069221973419, 42.33476713299751, 41.397441029548645, 44.59211580455303, 41.61356583237648, 41.69332355260849, 44.72506687045097, 40.24982661008835, 41.60601943731308, 39.41182337701321, 39.87957067787647, 41.75552241504192, 43.15824754536152, 41.65262013673782, 40.4374947398901, 37.82353140413761, 37.34481029212475, 34.275107011199, 40.008767545223236, 37.10501275956631, 36.07215978205204, 28.89375977218151, 31.92997545003891, 32.16344632208347, 28.484236747026443, 11.552944723516703, 20.90147763490677, 34.30754207074642, 23.20596657693386, 11.765499617904425, 10.743432361632586, 7.755569089204073, 10.05734782665968, 26.142219118773937, 30.581224523484707, 49.002550542354584, 54.53688897192478, 46.000772416591644, 47.10506536066532, 45.498336777091026, 49.86587941646576, 52.86399833858013, 54.72858868539333, 53.20977218449116, 53.88174332678318, 55.71777440607548, 55.71896754205227, 52.031694799661636, 51.662369817495346, 53.36207181215286, 53.84715758264065, 49.843168035149574, 49.041012078523636, 45.41227139532566, 45.38627319037914, 46.10055886209011, 44.46158900856972, 46.39010712504387, 47.10525915026665, 47.65713773667812, 50.241933837533, 50.315456092357635, 53.029570654034615, 54.43668454885483, 56.48619197309017, 52.88591556251049, 54.134099185466766, 47.363542690873146, 11.587452571839094, 0.3123383119236678, 23.015070520341396, 60.06937690079212, 51.294777542352676, 33.865443393588066, 46.946127489209175, 27.01215583831072, 43.248918280005455, 28.517167679965496, 34.46594797074795, 64.0045939385891, 28.249061666429043, 33.37346099317074, 58.67354840040207, 50.72752498090267, 0.8678225486073643, 0.03814128831436392, 0.079925764730433, 0.06720041084918194, 0.07542293955339119, 0.13004534994252026, 0.08639507344923913, 0.023476652459066827, 0.05547980988922063, 0.06312602752586827, 1.7749683558940887, 24.44900717586279, 64.54690083861351, 66.54870182275772, 22.852329052984715, 18.61320622265339, 32.138553857803345, 56.67705953121185, 56.93236023187637, 24.40420377999544, 26.506805755198002, 42.546172589063644, 50.800245478749275, 62.8142774105072, 75.35491168498993, 56.264633461833, 59.7832028567791, 5.773558868095279, 0.3628183656837791, 3.710764031857252, 18.684214912354946, 67.47133031487465, 65.5656261742115, 74.35749560594559, 68.7779738008976, 68.06868106126785, 62.630701661109924, 62.55550369620323, 58.027404472231865, 58.464001044631004, 56.544427648186684, 56.61394491791725, 55.281861796975136, 52.29374013841152, 57.162304893136024, 62.71949149668217, 62.31779225170612, 66.14229843020439, 63.30029793083668, 61.03009454905987, 59.88293990492821, 62.55845993757248, 61.330335438251495, 62.26068511605263, 60.70933476090431, 57.85768277943134, 60.880488976836205, 62.89433531463146, 61.87570117413998, 57.260852605104446, 55.49287207424641, 47.54059799015522, 51.01866915822029, 51.70375719666481, 54.51850935816765, 54.18513044714928, 52.462561279535294, 50.90065889060497, 51.171652749180794, 49.41732868552208, 48.59993934631348, 25.65050270408392, 19.456806555390358, 32.03317031264305, 37.16158792376518, 38.48926328122616, 35.69463104009628, 43.65849830210209, 47.61943615972996, 44.137675389647484, 41.708127558231354, 44.553753063082695, 44.65032108128071, 50.72949327528477, 46.31580211222172, 43.11730854213238, 41.99836738407612, 42.67611801624298, 43.38029623031616, 42.986397966742516, 41.959320679306984, 42.9334744066, 45.1990420371294, 45.41086547076702, 46.201622039079666, 46.752353087067604, 44.37305375933647, 44.188562259078026, 45.45742817223072, 41.99906274676323, 42.22662873566151, 41.426330879330635, 42.466954439878464, 45.585116520524025, 45.10597363114357, 43.74026611447334, 41.736546233296394, 40.9023579955101, 39.3702308088541, 38.306918665766716, 42.934937328100204, 41.14474318921566, 37.60350041091442, 34.193004816770554, 35.37217274308205, 37.58972994983196, 30.058395378291607, 16.66869856417179, 26.42020270228386, 40.41585110127926, 29.54242866486311, 17.775639966130257, 15.813506953418255, 13.531698994338512, 24.138537235558033, 36.42180182039738, 42.11060956120491, 58.523555248975754, 61.12783670425415, 50.825020149350166, 49.29896883666515, 49.40589129924774, 50.556537955999374, 56.15242548286915, 56.947650611400604, 55.85567660629749, 58.84114980697632, 59.70262058079243, 59.453851729631424, 57.67517477273941, 55.92301279306412, 57.89990231394768, 57.35069498419762, 54.252238646149635, 51.889327839016914, 51.11723206937313, 49.602591544389725, 51.54211767017841, 48.970487862825394, 50.998230054974556, 52.346249520778656, 55.48922806978226, 58.56062225997448, 58.13698299229145, 58.41823250055313, 60.43376974761486, 59.192402958869934, 65.69812506437302, 61.40156641602516, 59.97592851519585, 13.650187086313963, 0.23369560920400545, 27.476147040724754, 71.88171565532684, 59.47115980088711, 44.580268040299416, 45.04540108144283, 38.12313012778759, 48.036608174443245, 36.14959582686424, 43.358998373150826, 70.31292423605919, 44.082205966115, 27.322720773518085, 63.73983934521675, 62.936406657099724, 0.8318989793770015, 0.1085373388195876, 0.040263953123940155, 0.028643633013416547, 0.04647359921364114, 0.05166508548427373, 0.1651692550512962, 0.12355602550087497, 0.1950623103766702, 0.13370099128223956, 1.779345483519137, 31.314942352473736, 78.10439094901085, 87.55296394228935, 50.110791474580765, 35.64894609153271, 36.98310770094395, 70.07953315973282, 80.23386508226395, 50.88903911411762, 34.95734520256519, 52.302403673529625, 59.00511100888252, 70.2701385319233, 79.1753026843071, 68.61091196537018, 66.32297113537788, 6.878339136019349, 0.6622728158254176, 4.3858172837644815, 28.528574667871, 66.42865866422653, 65.54955303668976, 72.68373861908913, 71.15588620305061, 69.64294418692589, 65.00689655542374, 65.60702875256538, 60.72967126965523, 58.78067225217819, 56.46721579134464, 57.634007781744, 54.31921765208244, 53.212967813014984, 56.06738984584808, 63.55469807982445, 63.65700379014015, 68.22191923856735, 61.72079488635063, 60.82490935921669, 60.802600756287575, 62.22161561250687, 64.80827361345291, 62.50780865550041, 61.40030488371849, 58.83484594523907, 62.66725569963455, 65.61057776212692, 64.48736563324928, 61.52734726667404, 57.73145355284214, 51.88370794057846, 56.13246515393257, 56.20723374187946, 58.9670180529356, 57.15858869254589, 56.94983169436455, 57.07738324999809, 56.3380379229784, 53.591545298695564, 49.708222076296806, 27.708373479545116, 26.432755328714848, 37.75317057967186, 40.15824392437935, 42.113725394010544, 37.99057424068451, 46.96969382464886, 51.446009427309036, 47.434329092502594, 45.329945012927055, 48.466353714466095, 48.081825748085976, 53.12053397297859, 49.70782309770584, 44.58646550774574, 44.56886865198612, 43.762829303741455, 47.32256568968296, 43.47089096903801, 44.544667750597, 45.35019412636757, 49.3657236546278, 49.53384183347225, 50.45558497309685, 50.73182635009289, 47.945196479558945, 45.39885811507702, 48.909159153699875, 45.452347844839096, 45.13739034533501, 43.52978400886059, 43.88720043003559, 49.00910139083862, 50.0441088527441, 49.09928575158119, 47.18609221279621, 43.67767967283726, 43.98888677358627, 41.81433945894241, 46.10122002661228, 43.04093264043331, 41.08758665621281, 36.557123959064484, 39.17258821427822, 43.57666589319706, 39.52911548316479, 29.66565415263176, 30.733928829431534, 46.34606368839741, 37.16616287827492, 27.5232645124197, 31.530291996896267, 31.281515546143055, 39.5024599134922, 47.83405244350433, 51.628411039710045, 60.06061837077141, 59.71596546471119, 52.046023830771446, 49.79581117630005, 50.884513556957245, 52.98767790198326, 58.25875125825405, 57.858541533350945, 56.85441881418228, 59.31590013206005, 61.24908059835434, 61.495922952890396, 58.94817106425762, 56.44621051847935, 58.64751219749451, 58.53595398366451, 54.596085995435715, 52.97614172101021, 52.3273341357708, 51.08364187180996, 52.932850643992424, 50.269501358270645, 53.82377743721008, 54.92284566164017, 55.842970088124275, 61.568837240338326, 60.43835610151291, 61.51070035994053, 60.97960665822029, 61.360004246234894, 70.3962005674839, 69.56227451562881, 70.71377992630005, 18.39811686426401, 0.37785365420859307, 30.07221333682537, 78.52586433291435, 67.87948921322823, 53.87149527668953, 65.38705095648766, 43.14853146672249, 60.24352915585041, 39.38479162752628, 53.441377356648445, 79.91567015647888, 45.18829621374607, 51.87427684664726, 83.81327301263809, 75.21814942359924, 1.1184895760379732, 0.14977430691942573, 0.2488710597390309, 0.15742209419840947, 0.12760487152263522, 0.1942644125665538], [0.09195807884680107, 0.06489290302852169, 0.05959877773420885, 0.0906168547226116, 0.7117694348562509, 2.919715829193592, 44.97796609997749, 61.92806616425514, 56.379501298069954, 42.09935836493969, 24.46236725896597, 25.76935462653637, 59.577215909957886, 31.19381245225668, 21.70123402029276, 36.590140387415886, 36.451968401670456, 50.70574454963207, 59.4749253988266, 49.83261600136757, 51.57077193260193, 7.9330965131521225, 0.12595944106578827, 1.7440601019188762, 4.046794725582004, 51.49764485657215, 52.95077808201313, 62.987859696149826, 57.95244589447975, 59.460619166493416, 53.2514863461256, 53.23586918413639, 51.34838506579399, 53.01521882414818, 50.051415860652924, 52.867387756705284, 48.880501091480255, 51.59416727721691, 48.01207669079304, 55.94163939356804, 57.569498643279076, 61.43716290593147, 59.909603074193, 59.69730846583843, 56.25044882297516, 58.16508628427982, 56.768000051379204, 60.04079483449459, 59.52855572104454, 58.75520221889019, 55.849159955978394, 57.22669243812561, 59.08834174275398, 55.49145095050335, 53.237100318074226, 45.39152830839157, 49.77529227733612, 50.4040103405714, 55.124557837843895, 55.74673265218735, 50.84381774067879, 50.652049630880356, 50.525847002863884, 45.22963419556618, 48.97382028400898, 38.53649474680424, 17.143408991396427, 20.07435131818056, 28.835218213498592, 32.346459701657295, 36.77645578980446, 40.6187754124403, 47.40462228655815, 39.60110642015934, 37.217517122626305, 40.875520035624504, 41.770546808838844, 44.440370947122574, 41.75773769617081, 41.1699016392231, 40.620451122522354, 42.63114742934704, 40.79143434762955, 43.1126119941473, 38.209024518728256, 38.75979736447334, 42.641452476382256, 43.456653133034706, 40.3012378513813, 42.87871554493904, 42.256073355674744, 40.75513109564781, 39.97979409992695, 38.07934507727623, 38.036335185170174, 39.619334042072296, 39.2788191139698, 40.767738819122314, 39.25087921321392, 40.342933014035225, 38.75207997858524, 36.94509454071522, 35.32850168645382, 34.740247651934624, 37.60532431304455, 36.514763832092285, 30.847660526633263, 34.02897521853447, 34.65800866484642, 24.934490025043488, 14.532763827592134, 14.044498577713966, 34.50170785188675, 47.326506078243256, 36.882717087864876, 26.633264869451523, 20.44961918145418, 24.92090955376625, 28.902491703629494, 44.422090128064156, 49.98886361718178, 57.43794970214367, 54.435043036937714, 51.02933518588543, 44.98520091176033, 43.689356446266174, 49.36942845582962, 52.23295480012894, 54.270185083150864, 55.72215557098389, 54.36818182468414, 56.76116041839123, 54.97044950723648, 55.014614537358284, 47.011753767728806, 48.66664096713066, 46.16186857223511, 47.60243967175484, 46.17732234299183, 44.905078411102295, 43.685017079114914, 43.735919147729874, 43.431441485881805, 45.866673812270164, 48.839691281318665, 50.97003936767578, 50.343376994132996, 56.808407083153725, 54.34440650045872, 57.57854975759983, 56.902159452438354, 59.2220451682806, 57.38488934934139, 50.444307178258896, 6.985421190038323, 0.46131501789204776, 26.701102629303932, 62.727851048111916, 46.73841543495655, 34.76824074983597, 35.50767347216606, 29.95897751301527, 40.03367140889168, 31.670265085995197, 41.38338178396225, 54.27401527762413, 31.932931691408157, 45.7716067135334, 69.84150633215904, 13.422933630645275, 0.6827515200711787, 0.11189602460945025, 0.10903039205004461, 0.15370583423646167, 0.1513758912915364, 0.026879898650804535, 0.0898409319052007, 0.019724825069715735, 0.02611764062748989, 0.08236670328187756, 0.782559517538175, 6.723428573459387, 59.26396071910858, 75.63599020242691, 50.57272128760815, 32.18527615070343, 25.28445314615965, 32.025232538580894, 74.63140770792961, 26.802762374281883, 28.247222565114498, 40.001228749752045, 44.22182187438011, 59.946746081113815, 65.17683863639832, 60.049177184700966, 61.941335052251816, 12.097241766750813, 0.2240535375312902, 0.8416624960955232, 15.062087774276733, 61.432705745100975, 63.059675842523575, 69.6175691485405, 64.0912900865078, 63.5842414945364, 56.347472816705704, 60.4445231705904, 54.35954488813877, 57.77942597866058, 55.241412967443466, 56.77492327988148, 52.9529819637537, 55.793447345495224, 53.13682369887829, 61.45190991461277, 64.34813350439072, 65.25354132056236, 65.94236075878143, 65.0409047305584, 62.95235440135002, 63.52806530892849, 60.82715883851051, 62.21181593835354, 61.01353503763676, 59.65602748095989, 55.97242534160614, 59.05214108526707, 59.964076951146126, 58.86629305779934, 52.15441681444645, 46.97368361055851, 50.1338030397892, 52.73667857050896, 55.714043006300926, 59.71741698682308, 53.72945889830589, 54.2817934602499, 54.50300619006157, 51.48481674492359, 53.37141931056976, 47.59248800575733, 28.15612245351076, 25.259220600128174, 32.47819863259792, 35.99766097962856, 39.68451954424381, 42.22028687596321, 48.9448544383049, 44.194204956293106, 41.569013223052025, 44.99523617327213, 44.283515363931656, 47.69729018211365, 44.86964911222458, 43.83429206907749, 42.98165962100029, 44.17940855026245, 43.472901061177254, 44.302586540579796, 40.76590731739998, 41.33092179894447, 42.58084572851658, 47.0568573474884, 44.520618841052055, 45.052126720547676, 43.916762843728065, 42.730067521333694, 41.21823504567146, 39.94569092988968, 40.379464253783226, 41.35421834886074, 40.977240577340126, 43.21077212691307, 41.93511597812176, 43.21730777621269, 42.04458810389042, 40.025916025042534, 39.14351597428322, 40.66295564174652, 43.351425379514694, 38.857737109065056, 34.182141199707985, 37.36837662756443, 36.852558106184006, 30.120864026248455, 20.019389167428017, 23.713511042296886, 40.14654815196991, 53.88299345970154, 48.14397141337395, 38.39321203529835, 31.541429199278355, 37.135889902710915, 39.96969424188137, 53.94694782793522, 59.54262636601925, 62.858039662241936, 56.95792146027088, 54.030626937747, 48.725135028362274, 48.04533250629902, 51.49255312979221, 54.94376353919506, 56.20085388422012, 58.68808642029762, 55.91736629605293, 59.76971358060837, 57.730625197291374, 59.517771899700165, 50.22840276360512, 50.66529951989651, 50.00449597835541, 51.43459104001522, 49.391649663448334, 51.253409162163734, 51.43506981432438, 49.514618664979935, 48.15694011747837, 53.70691850781441, 53.169680535793304, 56.11323818564415, 56.50077559053898, 61.74132138490677, 61.58396042883396, 66.71193346381187, 63.46764475107193, 67.86320328712463, 63.820372223854065, 64.14352968335152, 6.266832249239087, 0.23388849338516593, 29.09151066094637, 71.43158420920372, 52.16537542641163, 45.12905739247799, 37.39028625190258, 40.035320520401, 40.82697384059429, 36.46508909761906, 41.6817569732666, 73.35957035422325, 32.192218378186226, 43.28594349324703, 84.55163419246674, 15.838788896799088, 0.8585407747887075, 0.11315594645566307, 0.2100182484718971, 0.20180773513857275, 0.052193431547493674, 0.06737013260135427, 0.26287693006452173, 0.20697159867268056, 0.2636374830035493, 0.20096820284379646, 1.0609821556136012, 4.303633393719792, 65.03927081823349, 81.10474035143852, 66.70428827404976, 61.53857186436653, 44.57966387271881, 38.349947556853294, 74.99032884836197, 42.431437745690346, 35.869235470891, 50.21966703236103, 48.822413608431816, 67.73559093475342, 71.70884013175964, 65.75696110725403, 68.801638931036, 14.070530030876398, 0.45055313443299383, 3.361101094633341, 32.06092022359371, 63.320163264870644, 66.88572853803635, 70.46854108572006, 66.92071706056595, 65.9144626557827, 58.819958344101906, 61.92344941198826, 56.7720278352499, 59.365244284272194, 54.941673651337624, 56.739505380392075, 54.258223325014114, 59.09963093698025, 52.81545974314213, 62.14829854667187, 64.09660220146179, 67.55731210112572, 65.14397040009499, 66.54648274183273, 62.77018837630749, 61.82397834956646, 62.179114893078804, 63.43489430844784, 63.39514464139938, 61.65074564516544, 56.67832486331463, 60.031177550554276, 65.06641656160355, 59.48643118143082, 55.87978631258011, 48.106786608695984, 53.44069339334965, 55.656476095318794, 59.42584343254566, 63.47969390451908, 58.10251124203205, 58.54092411696911, 57.596184611320496, 55.95149226486683, 58.8201255351305, 50.463883727788925, 31.145623438060284, 33.440789580345154, 38.2075197994709, 40.32099299132824, 40.840440317988396, 44.374968856573105, 50.72628244757652, 47.08470605313778, 43.02575625479221, 47.88553208112717, 47.8165315836668, 51.511419117450714, 47.19958148896694, 43.837544694542885, 45.339839681982994, 46.977829188108444, 46.22528336942196, 47.907327711582184, 44.47941765189171, 42.74901330471039, 46.10795706510544, 50.166428089141846, 45.92202164232731, 49.39842849969864, 47.432820573449135, 45.120477452874184, 43.3380538970232, 42.37809620797634, 42.720788419246674, 45.72561018168926, 43.24522487819195, 46.663308665156364, 46.64549522101879, 45.989745408296585, 45.08520394563675, 43.90250600874424, 42.0480041205883, 42.45574504137039, 45.63887603580952, 41.594069078564644, 35.8838152885437, 42.52793736755848, 45.80911450088024, 40.38192272186279, 33.07160519063473, 30.23054514080286, 43.01937639713287, 55.6255229562521, 52.45196744799614, 47.44512431323528, 44.00542348623276, 51.70050077140331, 46.12078137695789, 56.926831528544426, 59.24670584499836, 58.72635796666145, 56.423955112695694, 54.2430317401886, 51.71110600233078, 49.1230458766222, 53.21379616856575, 56.51289314031601, 57.62432970106602, 60.68962141871452, 58.951191902160645, 62.99599125981331, 60.73737345635891, 61.65432125329971, 51.26904912292957, 52.0260065048933, 50.79939432442188, 53.02734777331352, 52.66396947205067, 53.34007479250431, 52.555071115493774, 52.06844262778759, 50.29509678483009, 56.14899806678295, 57.11081385612488, 60.686938762664795, 58.84671650826931, 66.79618254303932, 63.223701640963554, 71.00235924124718, 66.83376252651215, 70.59305280447006, 67.59789392352104, 72.34700828790665, 10.35236494615674, 0.457718659308739, 33.96592900156975, 79.8793289065361, 60.97012996673584, 53.081931844353676, 49.149591252207756, 46.13971196115017, 54.576482847332954, 40.97122170031071, 59.51665095984936, 68.74953612685204, 52.360741943120956, 65.1751971244812, 100.44859036803246, 19.227946735918522, 0.9495270706247538, 0.2850352629320696, 0.30575949931517243, 0.26931746571790427, 0.1820123114157468, 0.21572764992015436], [0.030230062729970086, 0.06655659031821415, 0.039744342138874345, 0.04980193487426732, 0.04270981953595765, 0.864392698276788, 12.753098923712969, 54.30997654795647, 52.04844810068607, 36.220351830124855, 25.401568561792374, 19.38884910196066, 22.870184294879436, 56.466573625802994, 26.72259047627449, 28.250383995473385, 32.67396032810211, 41.614565178751945, 59.31510977447033, 55.25316193699837, 59.75056640803814, 15.118991620838642, 0.030166546021064278, 0.5766157933976501, 6.479694452136755, 40.960544273257256, 49.786554872989655, 59.020633175969124, 59.01348575949669, 59.01562124490738, 57.41955868899822, 56.62159010767937, 56.528563499450684, 54.41290162503719, 50.84217622876167, 48.78840163350105, 46.63908876478672, 48.92792634665966, 47.617984637618065, 49.32028189301491, 56.40138812363148, 56.17576003074646, 56.60733327269554, 55.62023364007473, 53.6524598300457, 54.29445058107376, 56.720863580703735, 56.6664656996727, 57.63887532055378, 56.68240204453468, 56.56487055122852, 60.23998774588108, 56.79082162678242, 57.66356259584427, 54.131268337368965, 49.91492338478565, 53.98756384849548, 54.02443706989288, 51.19640842080116, 56.39269419014454, 56.19899198412895, 57.549390122294426, 53.23661394417286, 49.334728717803955, 46.266982331871986, 48.00179064273834, 38.036464378237724, 26.410395428538322, 23.675454184412956, 27.119796462357044, 38.73966604471207, 37.520151883363724, 49.321171045303345, 40.4496730864048, 41.44818350672722, 41.37906141579151, 42.06370487809181, 41.71207554638386, 45.821843817830086, 43.211976662278175, 42.6484365016222, 43.08657579123974, 40.13506896793842, 40.67122019827366, 37.956577464938164, 43.02858330309391, 43.15569028258324, 42.69266992807388, 41.96682147681713, 40.709221959114075, 38.00086788833141, 40.342522636055946, 42.803179398179054, 38.61131653189659, 39.4847908616066, 38.273225873708725, 39.300052374601364, 40.381212159991264, 41.57009616494179, 41.13360598683357, 39.09683167934418, 37.93991155922413, 37.30611316859722, 37.32377842068672, 39.21960689127445, 33.721009343862534, 29.0987416729331, 28.44215590506792, 20.636534951627254, 14.388179685920477, 12.588373012840748, 25.023110769689083, 47.28317320346832, 53.95050823688507, 49.99122329056263, 46.52925565838814, 43.48208896815777, 44.92440037429333, 50.2614039927721, 54.06940385699272, 59.48355853557587, 55.16436830163002, 54.42189574241638, 52.30258606374264, 48.42398598790169, 46.23819887638092, 46.460635140538216, 53.57295289635658, 53.81657302379608, 53.48956637084484, 53.3425522595644, 56.71944245696068, 55.288386046886444, 50.79045720398426, 47.58663631975651, 46.08832731842995, 46.23909942805767, 45.9163523465395, 45.17905130982399, 43.29932637512684, 45.386850759387016, 45.04471331834793, 45.19410990178585, 48.355536460876465, 49.583520367741585, 51.04784019291401, 55.68378522992134, 56.213727593421936, 57.88093753159046, 59.823476895689964, 63.23384329676628, 62.80598245561123, 68.65596994757652, 52.29294218122959, 1.8548783054575324, 0.36734893976245075, 30.12787465006113, 63.48360389471054, 34.96346287429333, 28.80792047828436, 28.210258148610592, 23.78618024289608, 49.74528528749943, 25.477853268384933, 45.003128349781036, 36.818257346749306, 38.33602510392666, 64.20429602265358, 44.61744524538517, 0.13607746688649058, 0.08854669315041974, 0.056974769904627465, 0.14767969900276512, 0.06414119648979977, 0.051449309758027084, 0.05258131874143146, 0.03361905226483941, 0.08686673798365518, 0.10479377524461597, 0.03081057806411991, 0.049202038353541866, 0.8387406903784722, 22.8023237362504, 69.8184871673584, 60.18891468644142, 41.20236709713936, 26.024488136172295, 16.551773138344288, 38.28410468995571, 61.41964204609394, 29.68190398067236, 34.68363828957081, 32.930077984929085, 53.97326901555061, 61.76780216395855, 66.75627708435059, 69.86017853021622, 23.04157979786396, 0.1339543901849538, 0.4669119988102466, 11.84838267043233, 55.2561941742897, 56.97797678411007, 68.07054296135902, 64.44667741656303, 67.12120190262794, 59.99936945736408, 65.37280932068825, 58.77781480550766, 60.93950740993023, 55.96897892653942, 54.23371843993664, 51.378677040338516, 53.65491829812527, 50.136808678507805, 53.197525441646576, 59.38037887215614, 63.17352533340454, 60.105421766638756, 60.981248170137405, 56.28679007291794, 59.92924802005291, 59.98181439936161, 61.50289177894592, 60.436270013451576, 60.17412967979908, 59.20813791453838, 62.560454830527306, 58.56365069746971, 58.399541303515434, 54.35175530612469, 52.479242384433746, 54.80347126722336, 56.49189546704292, 53.45119222998619, 58.13725657761097, 57.692380249500275, 58.27693708240986, 56.73828184604645, 52.72621773183346, 50.95225632190704, 49.93456453084946, 44.91768233478069, 34.16161090135574, 30.205107405781746, 32.058093175292015, 41.366476491093636, 39.341891929507256, 52.38147363066673, 44.22611944377422, 43.560068383812904, 44.23129856586456, 44.68977056443691, 45.717611610889435, 48.51932667195797, 45.63494324684143, 44.74829122424126, 46.098590567708015, 42.24803298711777, 42.70469628274441, 42.05875754356384, 47.54673846065998, 45.65233111381531, 45.116996839642525, 45.924385115504265, 42.930658757686615, 42.0563180744648, 42.39648722112179, 45.025072172284126, 41.05230554938316, 42.22784087061882, 39.71662022173405, 42.5114918500185, 43.9765640348196, 43.2332631200552, 42.74572268128395, 41.2203249335289, 40.69314122200012, 39.09952953457832, 40.355521738529205, 40.557192116975784, 35.95238260924816, 32.52231426537037, 30.774128772318363, 22.776276133954525, 17.003504298627377, 21.846599020063877, 33.03830377757549, 52.3576071113348, 56.306416019797325, 56.466273441910744, 54.89205211400986, 53.77452827990055, 58.12298834323883, 61.30703128874302, 61.49588495492935, 61.87681831419468, 59.08233426511288, 57.05477066338062, 57.002816051244736, 52.99245424568653, 48.32944706082344, 50.17437346279621, 56.72768421471119, 56.77471049129963, 58.184142261743546, 57.71320313215256, 62.23076552152634, 60.2484080940485, 55.45986324548721, 52.09358207881451, 50.10182775557041, 49.3388818949461, 50.11050648987293, 47.92584411799908, 48.55393521487713, 48.84431943297386, 51.187836080789566, 50.098974108695984, 52.23040133714676, 54.3448206782341, 57.380390390753746, 62.09148019552231, 63.22645269334316, 65.57691916823387, 66.6559548676014, 68.72783169150352, 69.2944572865963, 71.40225738286972, 56.13527700304985, 2.074506520293653, 0.6062986131291837, 35.77273204922676, 71.29377320408821, 41.13339699804783, 34.826145842671394, 29.998009018599987, 32.76994697749615, 51.90741866827011, 35.133507549762726, 44.21567000448704, 51.93601593375206, 31.019576601684093, 73.26962918043137, 46.70968517661095, 0.11059952230425552, 0.07315557450056076, 0.04269506192940753, 0.1032048073830083, 0.022170465126691852, 0.07737424617516808, 0.07454045175109059, 0.12817991722840816, 0.17892892530653626, 0.1770580155425705, 0.28969532693736255, 0.19412488880334422, 0.910424793837592, 18.180363848805428, 77.72694200277328, 76.06145337224007, 50.96767969429493, 51.45797498524189, 28.47733821719885, 38.75652953982353, 70.9444047510624, 39.76066365838051, 43.0224846303463, 45.63310034573078, 57.333037331700325, 71.40958338975906, 69.21904653310776, 78.751769810915, 25.242248810827732, 0.20861392695223913, 0.9485316427890211, 26.71816561371088, 64.11842823028564, 62.825513407588005, 72.14118093252182, 67.8462865948677, 68.29078674316406, 62.00277015566826, 66.42655357718468, 61.69172644615173, 61.12174563109875, 55.658140406012535, 56.785684302449226, 53.45227137207985, 55.50110623240471, 53.14080588519573, 53.57478819787502, 61.83513455092907, 61.581726148724556, 61.920667961239815, 60.178412050008774, 58.21922957897186, 60.998115465044975, 62.41054907441139, 61.0746243596077, 62.06800505518913, 61.00086651742458, 61.49809643626213, 65.61533510684967, 58.340887650847435, 59.70284476876259, 58.07966686785221, 52.97540836036205, 58.36447298526764, 58.55325825512409, 56.39454089105129, 61.705508306622505, 60.89671790599823, 60.24244621396065, 60.13594172894955, 57.014804407954216, 54.892006516456604, 55.557134225964546, 49.62103195488453, 39.44346807897091, 37.899417132139206, 38.098017275333405, 46.771553456783295, 41.20357923209667, 54.18743312358856, 46.695036962628365, 49.51002471148968, 48.228057101368904, 49.747804552316666, 47.36055605113506, 51.87897339463234, 49.37283307313919, 47.509010285139084, 49.65461075305939, 44.30780366063118, 46.303965747356415, 44.765732288360596, 49.97578091919422, 49.24697242677212, 48.68354246020317, 47.43008852005005, 45.79488426446915, 44.40387770533562, 45.86051054298878, 48.58561031520367, 43.8311268389225, 44.38015557825565, 42.50990353524685, 46.78127333521843, 47.43624038994312, 47.06278122961521, 46.89708352088928, 45.52617408335209, 45.07134988903999, 43.022404834628105, 44.521716982126236, 45.75332209467888, 38.38035352528095, 35.0502198189497, 37.98424378037453, 37.73955971002579, 29.106533154845238, 27.07094058394432, 36.34677104651928, 52.50134579837322, 56.80304557085037, 55.477760285139084, 55.249928310513496, 56.31898194551468, 56.15861915051937, 59.08519171178341, 59.09668229520321, 58.69056008756161, 58.36706064641476, 57.4847137928009, 57.374481707811356, 53.853115662932396, 50.38611710071564, 53.044363260269165, 59.14208985865116, 60.207628682255745, 59.18283887207508, 59.455018267035484, 63.14468868076801, 60.82703344523907, 56.88995070755482, 54.01683367788792, 52.20117710530758, 51.16835072636604, 52.44717590510845, 50.296548306941986, 50.27328595519066, 52.17384897172451, 54.82538089156151, 52.6272102445364, 56.87909848988056, 55.93413479626179, 59.82259914278984, 64.85308840870857, 66.43872812390327, 68.43808203935623, 71.05535879731178, 71.85523867607117, 74.1596782207489, 77.38518834114075, 64.14558157324791, 3.0129704251885414, 0.6325925490818918, 38.51374536752701, 80.56273743510246, 47.69728638231754, 45.681699737906456, 35.33583149313927, 39.98320631682873, 66.98115661740303, 35.7083673030138, 64.71466183662415, 56.358613818883896, 53.591169118881226, 84.96113061904907, 60.353955030441284, 0.1245513345929794, 0.13807547686155885, 0.21481776202563196, 0.2534558402840048, 0.1329882920254022, 0.2994402009062469, 0.13088507519569248], [0.046748086242587306, 0.047091221931623295, 0.03280834498582408, 0.1015735964756459, 0.021450986350828316, 0.07273218667251058, 1.1365447822026908, 29.826906099915504, 58.38401913642883, 42.8513228148222, 32.88657411932945, 29.214584156870842, 24.34766661375761, 46.23576320707798, 34.11005146801472, 30.628131106495857, 29.00876820087433, 29.523720368742943, 60.219119265675545, 54.64419521391392, 65.96978008747101, 28.490430414676666, 0.41477882594335824, 0.04495230779866688, 8.136130068451166, 33.96682195365429, 55.862033665180206, 57.526192367076874, 60.8200304210186, 59.07902084290981, 62.32049770653248, 60.867964848876, 62.09230475127697, 60.79131156206131, 56.94282487034798, 51.306385919451714, 46.1490860581398, 45.44244937598705, 47.932239174842834, 45.60271717607975, 46.91659927368164, 50.87845288217068, 52.82001569867134, 49.83806870877743, 48.16911466419697, 48.84131759405136, 52.47125141322613, 52.115206718444824, 60.80401808023453, 56.44478179514408, 56.31801299750805, 57.21415691077709, 55.84784522652626, 57.59911805391312, 55.37061743438244, 51.234733164310455, 49.852618128061295, 54.587175473570824, 56.06497697532177, 56.29581078886986, 56.89386069774628, 59.112877026200294, 54.17722687125206, 49.01059851050377, 45.46549133956432, 47.22173050045967, 42.29151025414467, 35.124999806284904, 25.2821808680892, 23.379326574504375, 33.32504019141197, 37.04835020005703, 47.48122237622738, 44.11241814494133, 37.562770396471024, 40.21417312324047, 40.13837479054928, 41.69662557542324, 42.20491670072079, 40.62345676124096, 38.798954263329506, 41.32639244198799, 39.34873916208744, 37.24785849452019, 38.393630012869835, 43.09468075633049, 42.5462181866169, 41.58721424639225, 40.82518793642521, 41.27350687980652, 42.9109226167202, 42.181916534900665, 42.47850961983204, 38.88935521245003, 39.40803878009319, 35.58548949658871, 38.99827636778355, 42.759386748075485, 43.90245281159878, 40.92908576130867, 36.54946357011795, 36.96401372551918, 35.62977232038975, 36.8431232124567, 37.97755993902683, 31.970789059996605, 27.320440895855427, 18.141389340162277, 8.404443170875311, 10.489119607955217, 24.623442515730858, 39.05674383044243, 46.75336763262749, 47.398949190974236, 48.50101925432682, 49.78735662996769, 51.879699155688286, 53.520424515008926, 54.90106523036957, 55.27244210243225, 54.72486488521099, 57.56120748817921, 53.301738649606705, 52.03144021332264, 50.4431976377964, 44.197453781962395, 47.56044812500477, 53.64199139177799, 53.19984711706638, 55.29044933617115, 53.370305970311165, 55.14636866748333, 54.09368075430393, 53.794845789670944, 47.52393588423729, 44.833896830677986, 45.91817244887352, 45.61211787164211, 44.00719419121742, 44.21249337494373, 45.131626054644585, 47.53651700913906, 48.611703515052795, 49.76440966129303, 50.59294380247593, 56.63582794368267, 56.553235575556755, 63.26517641544342, 62.38012410700321, 62.9344991594553, 64.19540449976921, 68.62513080239296, 68.36691185832024, 48.031463250517845, 0.4367263294989243, 1.572378189302981, 41.248188838362694, 63.32522839307785, 34.03851270675659, 30.725998654961586, 19.59489304572344, 31.657750457525253, 45.92736795544624, 23.35273750126362, 55.62356226146221, 38.30355204641819, 50.451929569244385, 72.04028114676476, 6.614368250593543, 0.2757437521358952, 0.1254290429642424, 0.049029073416022584, 0.044490955406217836, 0.05864665421540849, 0.06171662229462527, 0.028887764347018674, 0.05999862834869418, 0.0459059675631579, 0.055926311906659976, 0.09748419950483367, 0.058997831074520946, 0.12813353299861774, 2.1719454042613506, 39.25612673163414, 70.78631043434143, 50.63814997673035, 36.48423247039318, 31.296950317919254, 18.249090760946274, 57.154990285634995, 39.131884798407555, 34.095327258110046, 29.539113342761993, 38.49383823573589, 67.10123017430305, 61.86945050954819, 73.56618046760559, 36.52362875640392, 0.6559818971436471, 0.09898239528411068, 18.385507240891457, 51.09545923769474, 60.80446645617485, 63.180672749876976, 64.47096571326256, 65.71292906999588, 68.51641103625298, 69.8712283372879, 69.19548019766808, 65.4734355211258, 63.96816149353981, 55.792402401566505, 51.19303800165653, 52.778008952736855, 50.88737100362778, 50.40345937013626, 49.815000146627426, 55.64511850476265, 55.632130801677704, 53.98925855755806, 53.596675023436546, 53.19247551262379, 56.77906505763531, 58.23295824229717, 64.06397715210915, 57.16536372900009, 58.92416775226593, 59.94894616305828, 60.64674831926823, 59.39974643290043, 56.97792358696461, 53.22520315647125, 53.29924218356609, 55.246326103806496, 58.87733146548271, 56.989919543266296, 58.862652853131294, 58.80133934319019, 57.65623278915882, 51.2390573322773, 48.89864891767502, 50.63972309231758, 50.19924692809582, 38.95250782370567, 32.28543497622013, 28.383943028748035, 39.93580766022205, 39.691423773765564, 52.0301178842783, 47.97982022166252, 40.401955246925354, 46.08972564339638, 42.703415751457214, 44.54288564622402, 43.96890364587307, 42.73909583687782, 42.01286740601063, 42.07648739218712, 41.657913252711296, 39.735733196139336, 42.10762672126293, 44.13809336721897, 46.069305539131165, 43.566550835967064, 44.09861348569393, 44.21201840043068, 45.74404679238796, 41.74008384346962, 43.56020897626877, 40.67549116909504, 42.28146739304066, 38.51267382502556, 41.10897570848465, 43.84781174361706, 45.145054534077644, 42.874284982681274, 41.432383954524994, 39.21180970966816, 38.91234777867794, 40.8435333520174, 40.2649649977684, 35.19303895533085, 31.696312688291073, 21.219911947846413, 13.18734247237444, 19.997686631977558, 33.198362588882446, 47.72986963391304, 50.08171543478966, 49.00011487305164, 49.77978363633156, 52.85440005362034, 56.17711655795574, 58.04697722196579, 59.13727171719074, 60.91768138110638, 57.08340212702751, 59.43759620189667, 56.85506857931614, 57.93534301221371, 55.44697433710098, 48.84358987212181, 49.19469863176346, 58.73798914253712, 57.4488665163517, 57.16478995978832, 55.227486714720726, 58.650426641106606, 58.48238825798035, 57.36831843852997, 49.46000799536705, 48.2247968763113, 48.78405846655369, 49.834740087389946, 48.16514767706394, 48.947198912501335, 50.251665115356445, 53.7774009257555, 53.84528808295727, 55.80565609037876, 57.81867787241936, 62.343991845846176, 61.333534866571426, 68.86598467826843, 65.56323990225792, 69.9382795393467, 70.01583337783813, 72.75554716587067, 68.57137128710747, 48.39388020336628, 0.2509315882343799, 2.8309972397983074, 48.15588377416134, 70.52777990698814, 39.73873883485794, 37.50352397561073, 23.714271001517773, 37.44491592049599, 53.80147263407707, 26.765796057879925, 52.156609296798706, 44.63205546140671, 45.7174976170063, 84.4024769961834, 4.235713463276625, 0.17145425139460713, 0.052704667396028526, 0.07037434639642015, 0.08298605520394631, 0.03969233985117171, 0.0404195963346865, 0.06354652839945629, 0.07943162796436809, 0.08664039778523147, 0.1460799848427996, 0.14039574220078066, 0.29559632122982293, 0.15996022440958768, 2.4757032422348857, 37.22815655171871, 83.86918321251869, 67.72062733769417, 49.49449874460697, 49.61472809314728, 30.736683681607246, 62.75515258312225, 46.698468178510666, 43.21830712258816, 39.50707286596298, 41.49738326668739, 73.4194703400135, 65.85789889097214, 79.51087027788162, 37.60413497686386, 0.8803974988404661, 0.31416081881616265, 29.786757454276085, 60.15217065811157, 66.40723541378975, 66.67537182569504, 65.18867120146751, 65.72631195187569, 70.66012680530548, 68.90204474329948, 69.42457750439644, 65.74249908328056, 62.64541447162628, 57.742168977856636, 52.38385610282421, 54.17329788208008, 52.69717589020729, 52.48421631753445, 51.889696419239044, 56.8062411993742, 56.9052866846323, 54.749445766210556, 55.163608342409134, 53.77167843282223, 57.92005643248558, 58.74669447541237, 63.81586566567421, 60.28377279639244, 59.8299365490675, 61.574221551418304, 61.089458763599396, 62.91459962725639, 59.92987498641014, 56.94762021303177, 53.5296618193388, 57.6701932400465, 62.32410371303558, 60.65711796283722, 62.18027003109455, 60.961481630802155, 61.40519522130489, 54.02129843831062, 52.180232629179955, 53.85848477482796, 54.1511944681406, 44.47561025619507, 40.54047301411629, 36.634316816926, 44.548444747924805, 44.539184644818306, 52.020287811756134, 48.63687336444855, 42.59057700634003, 46.876420229673386, 46.09664887189865, 45.259637385606766, 47.03856132924557, 46.054178550839424, 46.62542849779129, 45.91280713677406, 45.880858451128006, 43.73906157910824, 44.8858742415905, 46.16394326090813, 48.09233598411083, 47.542592883110046, 48.46748985350132, 45.6908268481493, 48.40760886669159, 45.42697660624981, 48.36068898439407, 43.58387030661106, 45.622194930911064, 39.96609963476658, 43.822873681783676, 48.34515921771526, 48.987902328372, 47.531573474407196, 44.518844336271286, 41.576320230960846, 41.91670596599579, 43.7047304213047, 44.797658175230026, 36.97068236768246, 38.09933580458164, 34.319617822766304, 19.45231519639492, 24.607722759246826, 36.80576741695404, 48.26009698212147, 55.07601164281368, 51.978193670511246, 52.50051364302635, 52.3374529927969, 55.329420045018196, 54.52101342380047, 55.600436702370644, 60.222831666469574, 55.885227620601654, 58.63926663994789, 56.28278508782387, 59.1210275888443, 57.83516898751259, 49.9081065505743, 51.232004910707474, 59.96153108775616, 57.98006661236286, 60.54694287478924, 56.47983871400356, 60.53496591746807, 60.27259759604931, 58.98397274315357, 49.981359019875526, 50.39610296487808, 50.35431280732155, 51.84793286025524, 50.15523388981819, 50.23354008793831, 51.20493896305561, 56.522502824664116, 56.119948625564575, 59.25741367042065, 58.860004395246506, 65.55527552962303, 63.78568008542061, 72.46921733021736, 68.0410185456276, 73.68252262473106, 71.91997200250626, 75.59804543852806, 73.14723014831543, 56.40479654073715, 0.6821723480243236, 2.5784922391176224, 48.9554026722908, 79.36686560511589, 45.33784478902817, 44.47004735469818, 25.23838821798563, 53.31277325749397, 62.27790579199791, 30.784899294376373, 73.94438177347183, 59.59691405296326, 64.34706956148148, 101.06437772512436, 8.932128455489874, 0.34494537161663175, 0.28028908011037856, 0.2009619094314985, 0.2149916472262703, 0.10803172845044173, 0.11616480609518476, 0.21406862331787124], [0.06563316565006971, 0.09477756466367282, 0.004655823559005512, 0.039472229982493445, 0.030520492946379818, 0.03599656316509936, 0.5829534970689565, 2.0436393516138196, 32.232925593853, 48.09583179652691, 32.98379950225353, 19.306429624557495, 34.738043770194054, 70.17612397670746, 27.264055721461773, 24.9787500500679, 35.671847462654114, 20.489317551255226, 55.5624957382679, 54.1034310311079, 60.04187397658825, 37.767864391207695, 1.7823612154461443, 0.05494859542523045, 7.331906547769904, 40.50720579922199, 48.70746597647667, 58.684735000133514, 60.713214352726936, 65.93542993068695, 64.10537213087082, 63.93990620970726, 63.62632803618908, 64.26964491605759, 58.668570667505264, 55.62933035194874, 48.68898756802082, 45.98457008600235, 44.477536752820015, 46.09973430633545, 45.93375541269779, 43.755959272384644, 46.11876368522644, 49.84132893383503, 45.12308791279793, 46.42796069383621, 54.45237010717392, 56.09941452741623, 58.843034505844116, 55.095572993159294, 57.87271477282047, 59.60175879299641, 58.25684756040573, 54.31127227842808, 51.549819856882095, 48.848465010523796, 51.373934894800186, 52.57435888051987, 57.6785983890295, 58.99648167192936, 58.479086235165596, 59.884258434176445, 55.488110929727554, 48.442540392279625, 45.635273829102516, 46.71100750565529, 50.31987525522709, 38.69279935956001, 28.843237683176994, 23.01024667918682, 35.17638064920902, 37.347029373049736, 41.97439067065716, 44.594270288944244, 37.64217093586922, 41.52941554784775, 39.73908841609955, 43.12376819550991, 39.33330439031124, 39.17876288294792, 36.81742139160633, 37.4940624833107, 36.86918221414089, 37.666573226451874, 40.84557004272938, 39.62387099862099, 41.24350368976593, 43.25271047651768, 42.52391338348389, 41.65999934077263, 39.286547899246216, 40.654451698064804, 41.48516312241554, 38.90858978033066, 40.76402261853218, 40.903870314359665, 40.02529665827751, 40.208260640501976, 42.61150248348713, 39.57970976829529, 37.088384851813316, 35.225158631801605, 38.40447083115578, 37.69279941916466, 33.08132886886597, 28.948018960654736, 23.01129922270775, 10.965447798371315, 7.955172378569841, 25.949521958827972, 34.114508628845215, 42.475728169083595, 41.43579997122288, 41.65566377341747, 39.210897758603096, 43.772021010518074, 45.098628625273705, 51.83770760893822, 52.931247130036354, 54.46361370384693, 53.538807928562164, 49.83048051595688, 51.30180336534977, 51.787128522992134, 53.429947569966316, 44.56012912094593, 46.14240601658821, 53.06367762386799, 54.36588674783707, 56.02102093398571, 53.147436529397964, 56.41397684812546, 53.774858862161636, 51.24852642416954, 46.35319210588932, 44.41198647022247, 43.81892949342728, 44.55437242984772, 45.05536414682865, 47.17104882001877, 48.86507771909237, 51.142728701233864, 53.9896385371685, 56.306191831827164, 57.19370640814304, 58.98946724832058, 61.40256576240063, 62.33708381652832, 63.70338410139084, 66.15024760365486, 65.96075177192688, 69.33842852711678, 64.07257229089737, 20.865425169467926, 0.4550642642425373, 5.473607238382101, 51.77170515060425, 52.879273518919945, 36.60930655896664, 37.60694682598114, 13.333646021783352, 39.42892625927925, 48.90478938817978, 36.29333831369877, 59.00178998708725, 49.62034039199352, 66.32694572210312, 34.47235442698002, 0.16503262566402555, 0.32858514168765396, 0.027258310474280734, 0.07440740693709813, 0.10716325981775299, 0.023151061141106766, 0.024635096742713358, 0.09935657872119918, 0.03241774524212815, 0.05604884419881273, 0.011371894524927484, 0.03837355827272404, 0.09648603314417414, 0.07699293812038377, 0.7612126786261797, 3.5780162550508976, 45.93056358397007, 58.442520797252655, 38.518415316939354, 23.549931719899178, 27.4295786395669, 73.26779767870903, 33.36290515959263, 38.073903769254684, 35.55627666413784, 26.23227808624506, 63.51069264113903, 60.46150825917721, 68.218013048172, 42.92370893061161, 3.3239478757604957, 0.208816459053196, 11.292727086693048, 55.10433152318001, 56.5527606010437, 65.23977845907211, 67.02345594763756, 72.56061762571335, 68.0800348520279, 70.17558440566063, 68.90595853328705, 67.52173081040382, 62.00789228081703, 59.086312651634216, 55.08680686354637, 50.38833238184452, 47.22080335021019, 51.71683989465237, 50.20468823611736, 49.629611894488335, 48.562617748975754, 54.02431547641754, 49.4302099943161, 51.58353544771671, 57.03243546187878, 61.259461641311646, 62.900502383708954, 59.33176048099995, 62.06619255244732, 60.961139649152756, 59.826341941952705, 56.27016596496105, 54.165861681103706, 51.23064838349819, 53.25969770550728, 54.451165571808815, 57.454634606838226, 59.27918270230293, 60.79211711883545, 59.563658237457275, 54.96731847524643, 50.02692997455597, 49.28878918290138, 48.82953442633152, 55.782249346375465, 45.067227110266685, 36.826396510005, 30.736142210662365, 39.294143691658974, 38.12404207885265, 47.63682782649994, 49.125990718603134, 39.90569427609444, 43.93040411174297, 42.64964483678341, 46.039754524827, 43.55363912880421, 42.638914212584496, 41.803544238209724, 40.70740945637226, 39.79540139436722, 39.53310526907444, 43.965658619999886, 44.177782237529755, 46.50423400104046, 44.80658009648323, 45.88058866560459, 45.01804634928703, 42.30410657823086, 43.11061330139637, 43.5835587233305, 41.15685313940048, 42.5190344452858, 41.66374213993549, 42.02200971543789, 43.3992800116539, 43.640118688344955, 41.70895591378212, 39.77825291454792, 40.386254489421844, 40.09933948516846, 42.81770221889019, 35.923796743154526, 32.198229655623436, 28.28276965767145, 16.193085685372353, 18.73001005500555, 34.070886969566345, 43.00347425043583, 45.91705910861492, 47.07162335515022, 47.73639388382435, 43.724797144532204, 48.41851428151131, 49.349699914455414, 56.284567192196846, 56.57405845820904, 57.80323550105095, 55.369663685560226, 51.98079273104668, 54.61868338286877, 56.5935780107975, 55.57559363543987, 47.39850841462612, 48.97142641246319, 55.36578789353371, 57.530231550335884, 59.06806983053684, 57.58161619305611, 58.54850850999355, 58.70181888341904, 54.43172961473465, 48.27532276511192, 50.69054916501045, 47.83141918480396, 49.448589608073235, 50.69360040128231, 52.76562161743641, 53.08800011873245, 58.267673179507256, 58.53330932557583, 60.94018377363682, 63.43557067215443, 65.39056196808815, 65.63185662031174, 67.07033783197403, 68.42525392770767, 70.60218751430511, 70.97758457064629, 72.19669595360756, 65.31828224658966, 20.16556542366743, 0.8056616841349751, 7.040776619687676, 57.62221321463585, 56.8167020380497, 43.285654708743095, 41.17579132318497, 16.889407820999622, 38.993515223264694, 61.40726990997791, 33.818648904562, 56.3166830688715, 49.96388375759125, 72.70648419857025, 32.7003613114357, 0.31826418300624937, 0.301442634081468, 0.12744818930514157, 0.10761024794192053, 0.07406797827570699, 0.03307303566543851, 0.05982878043141682, 0.06467141647590324, 0.1531829169834964, 0.1377464976394549, 0.2027799337520264, 0.14767327200388536, 0.22278968972386792, 0.13450513797579333, 0.8709840977098793, 2.9630553536117077, 54.96535398066044, 74.95299965143204, 52.786816880106926, 39.74671080708504, 43.54072742164135, 85.16107589006424, 35.63626617193222, 37.6737966388464, 46.380071863532066, 31.231221444904804, 69.13757890462875, 66.8949544429779, 74.78562623262405, 46.653850972652435, 3.553124265745282, 0.29832496074959636, 17.57800117135048, 65.497275441885, 58.96291807293892, 70.54636850953102, 68.77108857035637, 76.01609900593758, 68.82724955677986, 70.04553258419037, 68.60640540719032, 69.43137153983116, 61.22381955385208, 62.18861438333988, 55.890125557780266, 51.16051934659481, 48.379007801413536, 52.768893241882324, 51.29061296582222, 50.26287831366062, 50.27821809053421, 54.73897732794285, 50.93607299029827, 50.98331205546856, 59.3585604429245, 61.53325594961643, 64.79750499129295, 60.49149625003338, 64.373759329319, 62.84282527863979, 60.539008900523186, 59.58269901573658, 57.215429842472076, 52.573560923337936, 53.444010615348816, 57.64461301267147, 61.04339003562927, 63.8023915886879, 61.57956786453724, 64.10446777939796, 57.68172562122345, 53.8678702712059, 53.15744139254093, 52.825232818722725, 60.587140917778015, 48.158239647746086, 42.671079486608505, 37.99209415912628, 46.132651939988136, 42.009804770350456, 49.472437128424644, 49.68346260488033, 43.959407955408096, 46.55450530350208, 47.06023916602135, 49.060288444161415, 46.59141272306442, 43.8651692122221, 43.4127426892519, 43.22795860469341, 42.455585449934006, 44.23013962805271, 47.515348345041275, 45.99425956606865, 49.59233209490776, 49.74152348935604, 48.70564207434654, 48.50535862147808, 45.58636665344238, 47.98637107014656, 46.397991701960564, 44.2679475992918, 45.43073460459709, 44.418788105249405, 46.13884560763836, 44.99953754246235, 48.57044532895088, 47.394412234425545, 43.449878096580505, 43.793296068906784, 43.232985734939575, 45.79063609242439, 40.316608026623726, 35.41542202234268, 36.22526116669178, 24.05587077140808, 21.537854187190533, 36.194961592555046, 42.73851066827774, 50.623775348067284, 50.37037834525108, 50.78201785683632, 45.067029520869255, 52.824864238500595, 49.147429168224335, 58.454440757632256, 58.48854012787342, 55.26872210204601, 56.66316367685795, 53.08178745210171, 55.06352171301842, 59.515207037329674, 54.61968652904034, 50.283119827508926, 52.5587797164917, 58.31878803670406, 59.15882796049118, 60.75338199734688, 57.5993612408638, 61.99205853044987, 57.70685747265816, 58.80673885345459, 50.68752832710743, 52.91939936578274, 48.97781386971474, 51.89234487712383, 52.04703077673912, 55.72633534669876, 54.805363565683365, 60.06459675729275, 60.42294792830944, 63.87833431363106, 64.52232375741005, 69.3214662373066, 68.16236883401871, 70.33148244023323, 74.15413811802864, 72.5363065302372, 74.10131335258484, 74.85325500369072, 70.77983558177948, 25.8934198692441, 0.5640484427567571, 6.622301274910569, 61.065508648753166, 65.65595492720604, 49.75516855716705, 52.82687433063984, 17.72803422063589, 59.77763995528221, 63.55909824371338, 52.131124064326286, 85.5464056134224, 70.5456617474556, 82.45997563004494, 45.57134605944157, 0.3142125019803643, 0.44798842049203813, 0.3506954130716622, 0.13548064656788483, 0.24221018044045195, 0.13121276308083907, 0.28857195284217596, 0.1787027483806014], [0.03944180563848931, 0.054219832381932065, 0.05879946613276843, 0.09673454871517606, 0.023178294250101317, 0.09525479530566372, 0.024033565641730092, 0.5897483043372631, 5.029232958331704, 29.50583092868328, 45.379612147808075, 28.324616812169552, 36.64884723722935, 54.83651429414749, 33.020649924874306, 12.171595226973295, 44.02323693037033, 23.12668763101101, 37.138652354478836, 59.50543776154518, 57.75965563952923, 36.435975059866905, 5.015184162184596, 0.0733783894975204, 0.9199027321301401, 41.512768641114235, 55.075791254639626, 55.76619900763035, 60.93728072941303, 62.04528607428074, 62.3731704801321, 63.63614670932293, 62.153983041644096, 63.05491469800472, 57.79207929968834, 52.77351759374142, 51.00430212914944, 47.648170217871666, 45.96804477274418, 46.40268065035343, 44.44825932383537, 49.40264627337456, 44.451143369078636, 45.92090830206871, 45.28814345598221, 49.58557985723019, 55.625150576233864, 58.57196465134621, 60.562856420874596, 53.472110107541084, 58.090021312236786, 58.980689719319344, 56.23917102813721, 53.68705317378044, 53.99075947701931, 50.92676728963852, 53.95781144499779, 56.6662111133337, 57.649890929460526, 56.9788621366024, 56.982722729444504, 57.422716319561005, 52.5995971262455, 47.484820783138275, 44.67581771314144, 44.288736283779144, 44.55325148999691, 45.67003816366196, 34.13812056183815, 29.922674261033535, 28.65246132016182, 33.019319996237755, 35.7256905734539, 43.64014908671379, 40.241163074970245, 37.60894551873207, 41.396137699484825, 41.11937195062637, 43.75985026359558, 41.429230123758316, 37.72623762488365, 37.745586186647415, 38.33539813756943, 38.54112669825554, 41.21358409523964, 41.51801995933056, 39.80824090540409, 41.08231633901596, 42.05665625631809, 43.203993290662766, 38.893177807331085, 39.54840324819088, 42.02692665159702, 43.5456557571888, 43.29931877553463, 42.05723002552986, 40.46036571264267, 43.87213423848152, 40.12918308377266, 38.718767166137695, 36.61229319870472, 36.402643248438835, 38.81894879043102, 37.49761909246445, 31.850352622568607, 28.016022071242332, 14.136203806847334, 9.813438914716244, 23.643594793975353, 37.38028518855572, 43.44659887254238, 39.73933160305023, 43.42339351773262, 40.87323255836964, 43.93328815698624, 42.333019226789474, 46.51615396142006, 49.065057188272476, 49.757133051753044, 52.47598975896835, 50.955782532691956, 51.313882917165756, 50.60708284378052, 52.90183290839195, 52.092354744672775, 41.71076841652393, 46.42078287899494, 52.162069603800774, 55.82916542887688, 54.678210988640785, 53.31829436123371, 55.001873821020126, 53.68587903678417, 49.37417060136795, 45.105833038687706, 44.915094673633575, 44.12897005677223, 44.542733654379845, 46.14080250263214, 49.55318659543991, 51.25371314585209, 57.19968728721142, 58.859951198101044, 59.271054938435555, 58.48719500005245, 61.99776582419872, 61.51357300579548, 64.85797494649887, 62.2186403721571, 69.08241346478462, 63.63626070320606, 69.12890776991844, 35.411576628685, 13.906072955578566, 1.4536439417861402, 9.485418666154146, 53.347400799393654, 50.325445756316185, 41.26613527536392, 30.575908608734608, 17.724403515458107, 51.59660294651985, 48.94231237471104, 39.13753129541874, 58.65216314792633, 43.98613952100277, 75.24942934513092, 3.737626690417528, 0.0655110452498775, 0.050450323324184865, 0.031194496623356827, 0.07206679933005944, 0.10344610927859321, 0.017291176263825037, 0.02556286668550456, 0.07318301912164316, 0.009909453565342119, 0.09357662871479988, 0.01743071301461896, 0.16621627699350938, 0.03583241123124026, 0.10392060881713405, 0.13868939626263455, 0.6072329473681748, 8.070356547832489, 45.98860926926136, 57.94682219624519, 29.489672295749187, 36.12733282148838, 68.93582493066788, 33.322916105389595, 20.340528935194016, 46.92261815071106, 27.083952985703945, 46.12526513636112, 64.92241948843002, 63.8222037255764, 44.37919422984123, 5.328674465417862, 0.09253876487491652, 1.4703790750354528, 47.13194511830807, 61.58594772219658, 62.039742171764374, 67.35090717673302, 67.31581225991249, 67.43962481617928, 68.58507335186005, 65.25266736745834, 65.40393725037575, 63.56004439294338, 57.99240455031395, 54.01551894843578, 52.175156101584435, 49.52456273138523, 50.99073305726051, 50.338395461440086, 51.38667181134224, 48.48784916102886, 49.86542344093323, 48.584778159856796, 52.908136770129204, 58.397740200161934, 61.771734952926636, 62.81877636909485, 54.96997833251953, 60.392260774970055, 59.5370976626873, 58.749065548181534, 56.68050214648247, 55.078169927001, 52.631443217396736, 57.440852746367455, 58.2015947252512, 60.002131909132004, 58.89859512448311, 58.73067833483219, 58.2498749345541, 55.81414483487606, 49.60911199450493, 47.999039590358734, 48.20148512721062, 49.033705070614815, 50.46112507581711, 40.861012414097786, 32.52091594040394, 31.826736889779568, 34.80527736246586, 39.50004704296589, 50.49354873597622, 44.188425466418266, 40.217212960124016, 43.87272700667381, 43.664539977908134, 47.92596571147442, 43.77263657748699, 38.167675137519836, 39.494932517409325, 39.74618263542652, 40.54024502635002, 43.34843493998051, 43.873809948563576, 42.84864015877247, 43.42763788998127, 42.67818510532379, 42.901639714837074, 40.15570566058159, 41.806169897317886, 43.457295298576355, 45.26468351483345, 43.93325015902519, 45.365910083055496, 41.621750593185425, 45.82807548344135, 41.37709692120552, 42.99905888736248, 39.4278509169817, 40.172588154673576, 41.07199229300022, 42.85900980234146, 36.456915736198425, 31.289149336516857, 19.02237206697464, 17.707028947770596, 34.31594341993332, 45.14565110206604, 47.485257759690285, 46.31257988512516, 47.45108239352703, 44.556652307510376, 47.18859247863293, 47.83387005329132, 54.57888051867485, 52.93081775307655, 52.44938738644123, 56.18913911283016, 55.71532353758812, 54.55996133387089, 56.19675770401955, 56.881853342056274, 55.63452087342739, 47.716034576296806, 49.96603064239025, 56.6165591776371, 58.556476682424545, 56.28862917423248, 56.272776424884796, 58.4589359164238, 58.905073776841164, 51.23971849679947, 46.85383044183254, 49.30116131901741, 48.3735740929842, 48.08146096765995, 51.90584935247898, 56.03751204907894, 57.011802569031715, 60.769371539354324, 62.85409927368164, 65.91862723231316, 64.79676023125648, 67.00549051165581, 66.82860240340233, 69.51310515403748, 65.92086911201477, 74.29226830601692, 66.44083321094513, 72.90148973464966, 38.671809285879135, 17.766782641410828, 2.4784103594720364, 12.028898634016514, 60.69842554628849, 56.964544504880905, 49.874888733029366, 37.47324340045452, 13.327134121209383, 51.18339791893959, 61.346370577812195, 34.96518798172474, 58.624880611896515, 48.07585246860981, 76.83981120586395, 1.91439023707062, 0.198681898182258, 0.10226947124465369, 0.012756650248775259, 0.05146910283656325, 0.05122416070662439, 0.0723708349687513, 0.061070018709870055, 0.050862842399510555, 0.11284319800324738, 0.3769642941188067, 0.11235395199037157, 0.3554793860530481, 0.18838572723325342, 0.4049547796603292, 0.36384932755026966, 1.4253713213838637, 8.438511192798615, 59.31903496384621, 77.9486221075058, 46.62022277712822, 55.12750267982483, 65.18495500087738, 42.394245341420174, 16.318566352128983, 58.89133371412754, 32.15302728116512, 50.46069569885731, 70.17835065722466, 72.42511689662933, 47.816535383462906, 6.4482183661311865, 0.3033306577708572, 3.1072367168962955, 55.077926740050316, 64.53801691532135, 63.82359445095062, 68.51440474390984, 68.59714150428772, 66.44764244556427, 69.24265846610069, 67.4648554623127, 66.68442294001579, 64.50055852532387, 60.207636281847954, 57.3733189702034, 54.52094882726669, 52.28563517332077, 53.51670451462269, 51.07169151306152, 54.48662146925926, 50.256517454981804, 50.86479261517525, 50.2975020557642, 53.98388184607029, 60.45433044433594, 62.70395413041115, 62.67847269773483, 55.24471879005432, 61.71741686761379, 61.20567552745342, 60.671572387218475, 57.27273836731911, 57.299234345555305, 54.66747656464577, 60.42201317846775, 60.50481453537941, 62.80133530497551, 59.98121403157711, 60.706868693232536, 61.46069124341011, 58.32072593271732, 52.00931780040264, 52.30527251958847, 51.46777465939522, 51.77645489573479, 52.98927001655102, 46.023472398519516, 39.06095780432224, 40.59914946556091, 40.087503120303154, 43.71144086122513, 50.300158113241196, 47.45006024837494, 43.332783579826355, 47.756483405828476, 47.44836553931236, 51.50699995458126, 47.35942751169205, 42.86253221333027, 43.78744438290596, 43.10107201337814, 45.37910297513008, 47.988046780228615, 46.72388881444931, 45.417925491929054, 46.506958454847336, 46.95797525346279, 48.17178592085838, 42.813967019319534, 44.50052171945572, 48.23376439511776, 51.69115707278252, 47.23489299416542, 47.90944039821625, 43.7430589646101, 51.1732030659914, 44.01268869638443, 44.25703078508377, 43.55923242866993, 43.56853812932968, 46.670779064297676, 45.567056089639664, 37.49698832631111, 38.32982383668423, 26.99792180210352, 24.371664226055145, 39.006062150001526, 47.886345237493515, 53.94402198493481, 48.04580368101597, 51.844410449266434, 49.36463691294193, 49.97883215546608, 48.32364097237587, 54.45105537772179, 54.63718079030514, 50.899682343006134, 58.39254587888718, 56.331540271639824, 56.827915236353874, 58.19912865757942, 59.9724555015564, 57.28247344493866, 49.534822180867195, 51.91618859767914, 57.603111639618874, 62.11160771548748, 58.68638031184673, 58.2593934237957, 61.49634853005409, 61.74701727926731, 54.72759693861008, 48.76035913825035, 52.102044224739075, 50.68614900112152, 49.22158978879452, 53.54766145348549, 58.90342466533184, 58.25989879667759, 64.34853628277779, 66.31780341267586, 69.40557092428207, 68.5779981315136, 71.38781815767288, 70.09090974926949, 72.08888053894043, 68.40402066707611, 75.59223935008049, 68.52079600095749, 75.65701067447662, 44.74767565727234, 17.739553302526474, 2.653475278057158, 11.308273952454329, 65.88654175400734, 64.01794642210007, 58.486967012286186, 42.94530317187309, 26.231596022844315, 71.64412960410118, 66.31263568997383, 52.36066594719887, 83.64895462989807, 57.44113013148308, 96.03419244289398, 6.099486378952861, 0.2602377044968307, 0.3904981288360432, 0.09922618337441236, 0.40476612572092563, 0.20041942916577682, 0.20177335885819048, 0.11178137763636187, 0.20476197270909324], [0.1737745018908754, 0.052657066044048406, 0.02538680699217366, 0.06453217472881079, 0.09803096938412637, 0.08520113595295697, 0.1226026848598849, 0.26058877003379166, 0.02195438511989778, 7.649673521518707, 33.311801701784134, 50.35017102956772, 25.097043402493, 31.259518526494503, 42.249727696180344, 20.797059237957, 45.85446886718273, 35.079516246914864, 30.014735721051693, 56.45048148930073, 55.02833940088749, 40.4242068529129, 6.890759719535708, 0.25614140555262566, 0.1526081532938406, 31.75146672874689, 56.03896737098694, 55.177397802472115, 62.98208400607109, 62.90986128151417, 62.798888236284256, 59.767593294382095, 65.73578104376793, 61.48394599556923, 59.34898115694523, 53.4570325165987, 50.16828618943691, 46.10905520617962, 48.018342554569244, 45.23550488054752, 45.49129195511341, 45.216855481266975, 43.64003129303455, 43.399447202682495, 43.6525060236454, 47.18278259038925, 57.214973866939545, 54.52518939971924, 58.05858559906483, 55.99899731576443, 59.012144431471825, 60.075904950499535, 54.462785348296165, 52.841526344418526, 51.157677099108696, 52.23366916179657, 55.61260364949703, 56.70314513146877, 58.739839643239975, 58.93631190061569, 58.328735902905464, 54.21068787574768, 51.54540829360485, 45.86848631501198, 42.58015416562557, 43.50460655987263, 46.77251100540161, 48.693691715598106, 41.87800504267216, 23.522880971431732, 21.951385997235775, 33.15854072570801, 31.706904619932175, 38.321779668331146, 43.129414692521095, 36.161663979291916, 39.76860523223877, 39.18432958424091, 43.33697095513344, 39.80819530785084, 36.47503696382046, 35.760036930441856, 37.04008564352989, 35.38706794381142, 41.147414445877075, 41.537851095199585, 42.000191286206245, 43.84447932243347, 42.50791244208813, 40.990144684910774, 38.25103506445885, 39.918488189578056, 40.990881845355034, 41.677189618349075, 41.13842412829399, 42.74830274283886, 40.40657959878445, 40.05314536392689, 39.07932221889496, 37.88451433181763, 38.16636420786381, 39.159060940146446, 36.50490716099739, 32.16602638363838, 33.08991640806198, 15.275906100869179, 15.259877610951662, 18.100885413587093, 32.68628306686878, 40.5479472130537, 39.22909878194332, 40.83502560853958, 40.04239194095135, 38.43797743320465, 41.55683487653732, 43.555345237255096, 48.505689203739166, 52.57885403931141, 51.04875974357128, 51.80114597082138, 51.053703278303146, 51.92017078399658, 52.325951009988785, 54.02358591556549, 48.51577386260033, 45.40805362164974, 45.94941057264805, 53.92812743782997, 54.627084732055664, 52.949033975601196, 51.85156546533108, 55.7179643958807, 55.5880493670702, 48.346815928816795, 41.68101221323013, 44.767301604151726, 43.01180340349674, 45.87554633617401, 46.43337540328503, 51.17846958339214, 57.25810915231705, 57.51288928091526, 57.183013781905174, 60.880515575408936, 60.868329629302025, 64.42621931433678, 59.510483890771866, 63.337657526135445, 61.432063579559326, 66.76544219255447, 60.71684695780277, 58.05643491446972, 29.20990850776434, 14.567941389977932, 4.743779925629497, 14.939794186502695, 47.767005041241646, 52.09253333508968, 34.15817208588123, 32.878043577075005, 39.10595118999481, 56.83312475681305, 46.30919426679611, 43.87775033712387, 50.062203481793404, 68.82636040449142, 29.653407409787178, 0.32056199095677584, 0.2743829204700887, 0.16191023227293044, 0.15752952749608085, 0.1458131827530451, 0.09839731574174948, 0.05937161004112568, 0.08084767541731708, 0.06327904353383929, 0.047304589388659224, 0.04028914903756231, 0.04392099341202993, 0.16717553255148232, 0.08029308330151252, 0.14301371265901253, 0.06723296144627966, 0.2722135337535292, 0.04183052296866663, 10.978785082697868, 44.7199447453022, 64.42828640341759, 19.61530365049839, 42.33307242393494, 43.19608211517334, 15.666118562221527, 56.128498166799545, 34.16401997208595, 37.17453382909298, 61.666404604911804, 62.446559742093086, 46.46022096276283, 7.690928382799029, 0.31635790248401463, 0.20858783303992823, 34.340611696243286, 60.62201924622059, 58.376157358288765, 68.20526093244553, 67.30264216661453, 67.86779344081879, 64.19172629714012, 69.50256451964378, 67.99492701888084, 63.795985132455826, 57.48011603951454, 55.409793332219124, 50.902615785598755, 52.578379064798355, 49.91034083068371, 50.79127795994282, 47.46549502015114, 47.77110882103443, 47.624672278761864, 48.14213991165161, 50.44833496212959, 60.39014048874378, 57.84265838563442, 61.42517074942589, 57.69049935042858, 62.73728974163532, 59.699455350637436, 57.664425149559975, 54.97551843523979, 53.45147341489792, 54.06130649149418, 59.06833201646805, 59.81473356485367, 59.994140937924385, 60.05086809396744, 61.497971042990685, 57.945416271686554, 53.88488195836544, 49.113120809197426, 46.621495708823204, 44.812234193086624, 48.51281762123108, 53.44604730606079, 47.004370763897896, 28.464198522269726, 24.415610767900944, 33.297841250896454, 35.22079646587372, 45.19985519349575, 47.67197214066982, 39.71779055893421, 44.9848323315382, 42.04012334346771, 44.10292245447636, 42.302894443273544, 41.90192095935345, 41.225473657250404, 38.018859922885895, 39.02381479740143, 44.050663858652115, 44.54054117202759, 47.264797389507294, 46.07016809284687, 43.65286320447922, 45.08474797010422, 40.88184669613838, 42.8075909614563, 43.18527549505234, 44.20679748058319, 41.43175698816776, 41.9602782279253, 42.73421689867973, 42.500354647636414, 41.15491144359112, 40.62167085707188, 42.04579643905163, 40.66515572369099, 41.66584722697735, 34.31823469698429, 35.61795495450497, 19.989938847720623, 18.02448481321335, 29.397151060402393, 41.723288744688034, 47.20465421676636, 42.89650239050388, 44.33548517525196, 43.85723143815994, 42.873620018363, 44.01213012635708, 48.97622935473919, 52.56379924714565, 55.35528905689716, 53.31479474902153, 55.4356699436903, 55.99438436329365, 55.56150399148464, 56.18209809064865, 57.32320345938206, 51.323785185813904, 46.6913815587759, 50.10644070804119, 56.273281797766685, 57.36806005239487, 56.128129586577415, 57.84068629145622, 60.00715143978596, 57.90788568556309, 53.32260712981224, 46.180020198225975, 49.513873904943466, 48.012118488550186, 49.41744267940521, 50.74395909905434, 55.57345435023308, 62.59942553937435, 62.66681872308254, 61.97214759886265, 65.35583943128586, 65.10576725006104, 68.32253783941269, 63.87272581458092, 64.50682818889618, 66.59740000963211, 69.7612090408802, 65.46072900295258, 60.07412664592266, 36.27502329647541, 21.6339548304677, 7.13787185959518, 15.880700647830963, 53.59334260225296, 59.95224438607693, 41.89057856798172, 37.57105775177479, 34.868798553943634, 59.5222632586956, 57.28723078966141, 39.70170982182026, 51.23361602425575, 72.593425065279, 24.022063985466957, 0.4028025217121467, 0.28301774931605905, 0.18711689219344407, 0.12846055295085534, 0.09687845114967786, 0.07734643048024736, 0.06290339806582779, 0.03362483359524049, 0.12171069756732322, 0.3240268409717828, 0.12730823509627953, 0.25378490856382996, 0.22322853648802266, 0.23297726962482557, 0.24602725374279544, 0.32944220351055264, 0.4653313133167103, 0.36209123907610774, 16.84063743799925, 61.88488908112049, 75.68951413035393, 38.36899593472481, 40.27258738875389, 52.92929403483868, 28.593450486660004, 62.10029952228069, 46.102758944034576, 43.607755824923515, 67.76667326688766, 69.22721609473228, 49.06441122293472, 8.629753980785608, 0.5416054220404476, 0.43536870391108096, 39.334311336278915, 61.08717888593674, 59.07053969800472, 69.10420149564743, 68.71919855475426, 67.81059890985489, 65.2987588942051, 70.58181300759315, 71.02353170514107, 64.58471640944481, 60.86004227399826, 57.55926199257374, 52.47390367090702, 55.99052757024765, 52.37643130123615, 52.000737860798836, 50.544268414378166, 51.086518317461014, 49.51578140258789, 49.605095610022545, 52.07883507013321, 62.42174707353115, 60.20920179784298, 64.23671588301659, 57.63952508568764, 64.92262467741966, 62.53914937376976, 61.895087733864784, 57.60361321270466, 56.86997137963772, 55.276990458369255, 61.80809140205383, 61.88565284013748, 63.54141779243946, 59.98326972126961, 64.05799627304077, 59.03631493449211, 57.68414229154587, 50.63944950699806, 48.415683433413506, 49.17916886508465, 54.58745285868645, 57.598335295915604, 48.97116042673588, 34.292916655540466, 32.72733986377716, 39.70886863768101, 40.23858301341534, 45.51483169198036, 48.33703525364399, 43.531509116292, 46.602622121572495, 45.81402003765106, 46.85305908322334, 45.45970804989338, 44.53231081366539, 44.89911653101444, 41.16572946310043, 40.432433411478996, 47.22033217549324, 48.770044818520546, 51.191255897283554, 49.5675004273653, 47.97589883208275, 47.317690551280975, 44.446169435977936, 45.530441254377365, 46.609397158026695, 48.43268372118473, 45.005640015006065, 46.06848858296871, 48.02818022668362, 46.50931052863598, 44.52876940369606, 44.19703580439091, 45.291483476758, 44.28366355597973, 43.928390219807625, 37.53688618540764, 41.633001789450645, 27.476228736341, 24.210775159299374, 33.72241146862507, 40.808221846818924, 52.21033841371536, 48.6327163875103, 50.231188014149666, 48.75890761613846, 44.46323812007904, 49.38028447329998, 52.42305099964142, 57.6635055989027, 59.47824642062187, 52.294351905584335, 58.37522640824318, 58.407011702656746, 57.06579007208347, 56.68865270912647, 59.03205916285515, 53.968648463487625, 50.10782763361931, 51.30468741059303, 59.406141489744186, 59.806970581412315, 57.69701600074768, 59.07802529633045, 62.366517037153244, 60.60894034802914, 54.43917341530323, 47.823530808091164, 53.616490960121155, 51.776667684316635, 52.44339890778065, 53.56600306928158, 58.826775178313255, 65.67588865756989, 66.07371971011162, 64.17493119835854, 68.68067622184753, 68.48545029759407, 72.0959785580635, 67.86725386977196, 71.17946773767471, 67.47890710830688, 75.4962944984436, 68.18373128771782, 66.791622787714, 41.27842001616955, 24.419066682457924, 6.955134440213442, 17.661427594721317, 57.9172445833683, 68.2989639043808, 46.60793423652649, 49.05268885195255, 53.83260816335678, 81.69240161776543, 60.04579916596413, 62.418604642152786, 70.64861342310905, 87.9734417796135, 41.69120706617832, 0.6210268009454012, 0.5245123361237347, 0.2788958908058703, 0.20558802760206163, 0.26544033782556653, 0.30453958665020764, 0.17918456549523398, 0.1328324113273993, 0.2190881985006854], [0.03246912041504402, 0.10025649215094745, 0.08364995825104415, 0.017509629287815187, 0.11850041162688285, 0.045574379691970535, 0.16632100887363777, 0.030979878647485748, 0.282031167880632, 0.12052012200001627, 12.484317496418953, 49.07449968159199, 38.89488011598587, 41.81104123592377, 49.81121554970741, 87.11474865674973, 45.837510377168655, 35.98090007901192, 27.23631341010332, 47.30274215340614, 54.588068425655365, 42.932098880410194, 5.65502755343914, 0.7085560541599989, 0.5712662148289382, 36.38913497328758, 64.5316332578659, 59.310671612620354, 61.26941330730915, 60.5393622815609, 62.878680154681206, 63.276944383978844, 60.65970562398434, 62.12738446891308, 55.73274180293083, 48.51078853011131, 46.17683216929436, 47.085895389318466, 43.7439139187336, 45.78570015728474, 45.83543948829174, 45.710365399718285, 42.68885873258114, 44.43426087498665, 43.41884896159172, 45.0500064343214, 55.75796104967594, 56.47945873439312, 53.61394129693508, 57.86917336285114, 57.187850922346115, 55.677382573485374, 54.65032048523426, 49.94642749428749, 54.33841422200203, 56.09820619225502, 57.44301103055477, 56.280569806694984, 58.67289863526821, 55.95140106976032, 55.3932224214077, 55.31935818493366, 48.80574010312557, 44.906339943408966, 46.089870035648346, 41.981515288352966, 42.91093401610851, 49.74531568586826, 52.01452352106571, 35.67694678902626, 17.62685514986515, 17.893120162189007, 29.51970588415861, 31.42615668475628, 40.1715774089098, 38.31757329404354, 36.887801215052605, 40.38296386599541, 36.91650867462158, 40.20202897489071, 41.20221130549908, 40.11955440044403, 35.95737174153328, 36.562553867697716, 38.51060293614864, 40.85230328142643, 40.75893089175224, 41.190196350216866, 41.16780415177345, 40.74296034872532, 40.689037442207336, 41.051355600357056, 41.39024801552296, 40.97300000488758, 39.912226125597954, 41.004226729273796, 40.16954071819782, 40.43429531157017, 37.780418917536736, 38.81230294704437, 35.59180475771427, 37.95105256140232, 37.87951000034809, 31.577660255134106, 19.0853213891387, 18.007874004542828, 16.137363575398922, 30.054158605635166, 42.65486195683479, 45.02622351050377, 40.66556230187416, 38.5100481659174, 39.29944060742855, 40.33707372844219, 40.91809295117855, 44.565372839570045, 48.897375985980034, 49.63386006653309, 50.68100407719612, 51.115202978253365, 50.187744945287704, 50.313286408782005, 51.808095797896385, 48.24919916689396, 46.588422283530235, 43.391874209046364, 49.1934484988451, 52.8642301261425, 55.32063111662865, 54.1750343888998, 53.85508015751839, 57.074427008628845, 54.59517024457455, 50.206645131111145, 42.62020401656628, 43.23202818632126, 43.479968681931496, 44.88402374088764, 46.693555042147636, 53.748575672507286, 56.49968504905701, 57.19342902302742, 58.980176746845245, 60.17931640148163, 61.460155472159386, 57.117740884423256, 53.87488089501858, 59.27690662443638, 61.9825704395771, 61.52232013642788, 59.541087448596954, 51.54961086809635, 32.362855821847916, 26.433591283857822, 8.363086190074682, 11.828865967690945, 47.34496928751469, 52.164763659238815, 30.790414698421955, 25.358478873968124, 39.420980885624886, 57.35859856009483, 46.98520839214325, 45.22218659520149, 53.09847615659237, 48.593874871730804, 1.7050199280492961, 0.024266642685688566, 0.047726589400554076, 0.06746284168912098, 0.03369224657944869, 0.050205396037199534, 0.028174142971693072, 0.03214891708921641, 0.04270784913387615, 0.06067884009098634, 0.038502610332216136, 0.09838959740591235, 0.05260361285763793, 0.05872381530934945, 0.2358498115791008, 0.035566043297876604, 0.12205365143017843, 0.07665737604838796, 0.27162213111296296, 0.020090039652131964, 16.20722282677889, 64.76548790931702, 35.508912205696106, 24.240223579108715, 53.91920551657677, 65.24446740746498, 57.634771540760994, 41.63448750972748, 31.686419919133186, 52.80922427773476, 63.427773490548134, 48.938151597976685, 7.711905632168055, 0.9259489795658737, 0.6705775076989084, 44.38440375030041, 67.23116800189018, 67.09259703755379, 66.810652166605, 65.19492566585541, 66.46706700325012, 66.23151764273643, 66.22417643666267, 63.58894184231758, 61.318757459521294, 52.27401539683342, 49.897999092936516, 50.153349190950394, 48.82544964551926, 50.32646030187607, 51.16180367767811, 49.548911824822426, 47.54359982907772, 46.27664901316166, 47.11877882480621, 50.020409524440765, 58.067853301763535, 58.43975454568863, 58.042223677039146, 58.47058609127998, 58.94466385245323, 56.953354105353355, 57.733190059661865, 51.6757906973362, 56.31244629621506, 59.10384111106396, 59.27682302892208, 57.2659595310688, 60.07598854601383, 59.52704340219498, 59.50790382921696, 58.79356496036053, 51.929107904434204, 45.83095572888851, 48.14927212893963, 44.371959418058395, 47.94454671442509, 49.26318235695362, 55.87261229753494, 44.70500394701958, 24.428790360689163, 20.67281160503626, 28.08304477483034, 38.223642334342, 43.79191294312477, 42.15255931019783, 38.02522078156471, 42.50104621052742, 41.39701925218105, 42.427466958761215, 44.043246656656265, 42.347580045461655, 40.94076633453369, 40.327874422073364, 41.07919670641422, 41.310361102223396, 39.69480559229851, 44.33407165110111, 43.118490278720856, 42.014261931180954, 40.628229305148125, 42.22874142229557, 42.30690322816372, 41.85609541833401, 41.022309958934784, 42.1750845015049, 39.85913537442684, 40.906811356544495, 38.420084193348885, 41.472756788134575, 35.76494246721268, 40.09976886212826, 41.79999142885208, 35.89480809867382, 22.339955046772957, 18.877170458436012, 24.235781617462635, 39.54293914139271, 50.239403173327446, 48.830833956599236, 45.93192771077156, 40.85920751094818, 42.00449265539646, 45.601710230112076, 46.383750066161156, 50.211128890514374, 52.57070727646351, 53.78206327557564, 54.877635687589645, 55.780919417738914, 53.09657245874405, 54.3067467212677, 55.41422389447689, 49.32877063751221, 49.79531720280647, 46.684283539652824, 53.85410740971565, 55.89614063501358, 58.266274854540825, 56.578789204359055, 56.95086523890495, 59.674509689211845, 58.46239373087883, 52.26347856223583, 46.24646343290806, 47.625306844711304, 47.24850006401539, 51.54448874294758, 51.18982717394829, 56.83417730033398, 62.11500473320484, 62.27121815085411, 65.19632399082184, 63.24439153075218, 63.703501895070076, 59.627251625061035, 56.376647651195526, 63.656756803393364, 65.87032422423363, 66.20574742555618, 64.8592820763588, 60.19067779183388, 47.685556411743164, 37.11422346532345, 11.909744627773762, 12.890275362879038, 51.1113727837801, 58.253275752067566, 38.89801114797592, 28.312932439148426, 37.84713193774223, 59.63748827576637, 59.10727992653847, 43.15909869968891, 62.1171972155571, 43.60241711139679, 0.5281335418112576, 0.012803187546523986, 0.09791559510631487, 0.08477645678794943, 0.035194999145460315, 0.03770344716031104, 0.01664440755121177, 0.1171401736792177, 0.08253809486632235, 0.08214368790504523, 0.17143721168395132, 0.19126531959045678, 0.3139082808047533, 0.14827551000053063, 0.26175892911851406, 0.15700282528996468, 0.44947330956347287, 0.15359189972514287, 0.3357090172357857, 0.2663280058186501, 30.92583753168583, 79.35088366270065, 53.32440443336964, 51.349365413188934, 59.64246980845928, 103.01409870386124, 62.28865161538124, 48.14347364008427, 40.6384963542223, 59.800153747200966, 71.19190827012062, 55.36600448191166, 7.972071971744299, 1.8680637166835368, 0.6917470623739064, 41.79736576974392, 68.21553558111191, 67.75663420557976, 67.72728458046913, 66.21101394295692, 68.33046421408653, 69.04446870088577, 66.86963260173798, 68.25072929263115, 62.53877319395542, 53.98874558508396, 51.36973612010479, 54.775162786245346, 51.91816449165344, 52.558965906500816, 55.37823602557182, 53.43678720295429, 48.366848453879356, 49.93101932108402, 48.16282220184803, 52.00416907668114, 60.880378782749176, 60.07517918944359, 63.25930953025818, 61.62697412073612, 61.501717641949654, 60.492590591311455, 58.550765588879585, 55.10297119617462, 59.652831852436066, 60.067845582962036, 61.393955424427986, 60.899799540638924, 62.379930317401886, 61.68064244091511, 61.86463236808777, 61.06784552335739, 55.15867240726948, 49.774919897317886, 51.74817681312561, 48.76886688172817, 51.21569998562336, 55.527617409825325, 61.1412537842989, 45.85666514933109, 29.857091680169106, 31.030708104372025, 36.10694691538811, 40.314875319600105, 47.48645469546318, 45.88703691959381, 43.23624975979328, 47.6175020635128, 44.910489320755005, 45.65041981637478, 47.160542383790016, 46.41686908900738, 42.25317031145096, 43.21957245469093, 45.292015448212624, 42.87222549319267, 45.373942852020264, 46.40838414430618, 48.14675286412239, 44.18446987867355, 44.29416999220848, 44.93255093693733, 46.059813648462296, 46.3736692070961, 44.726165011525154, 44.53236781060696, 43.78354199230671, 44.19492691755295, 41.463204100728035, 42.39720158278942, 39.91802841424942, 42.99164928495884, 44.45367023348808, 37.3093505948782, 30.43807290494442, 23.918069265782833, 33.07562157511711, 39.430206790566444, 53.35367426276207, 53.42242397367954, 50.073808059096336, 44.49195317924023, 47.70397402346134, 47.80762106180191, 48.738495111465454, 51.721631437540054, 53.89671832323074, 57.494730055332184, 56.87176488339901, 57.29256950318813, 55.09320951998234, 55.12633994221687, 58.0643916875124, 53.976460844278336, 52.34331987798214, 48.325043097138405, 54.47506248950958, 58.8087223470211, 61.3420882076025, 58.50252717733383, 58.17677065730095, 63.207339718937874, 61.95154130458832, 56.944006606936455, 48.179085329174995, 50.34176968038082, 51.19431093335152, 53.666579872369766, 55.34257873892784, 59.25209015607834, 65.53427025675774, 65.96905812621117, 67.65999779105186, 67.81685337424278, 68.12910541892052, 61.639471650123596, 58.90190474689007, 63.68789993226528, 72.07790672779083, 69.18789580464363, 70.41554912924767, 65.4111796617508, 51.38905048370361, 37.57219769060612, 12.800306640565395, 15.196178779006004, 57.16731682419777, 67.98363402485847, 41.9373806566, 37.37223722040653, 52.97924995422363, 81.13402917981148, 62.64408454298973, 62.23401814699173, 69.64808151125908, 64.40087467432022, 3.3895171573385596, 0.19238701643189415, 0.3056756069418043, 0.19023017201106995, 0.20432763820281252, 0.10392123222118244, 0.3290608583483845, 0.28768179123289883, 0.28915928851347417, 0.1530729010119103], [0.060601634468184784, 0.11473863574792631, 0.09383045064168982, 0.055765581273590215, 0.20884203346213326, 0.0777528082835488, 0.04293458638130687, 0.04875136546615977, 0.13942539895651862, 0.09519582425127737, 0.16415781166870147, 31.154081784188747, 56.15917772054672, 46.78797237575054, 58.73612344264984, 107.01367288827896, 71.88769653439522, 32.043840140104294, 25.478143952786922, 37.98290625214577, 59.30138111114502, 39.90657202899456, 6.986573003232479, 0.33074274309910834, 8.93620278686285, 59.81126435101032, 62.38224819302559, 65.57930544018745, 59.691221192479134, 62.03822985291481, 61.29688963294029, 63.0127027630806, 60.0215108692646, 60.564596727490425, 54.156145602464676, 48.719511330127716, 46.0226858407259, 44.413950964808464, 45.51561824977398, 46.5510018914938, 44.57308642566204, 43.945113122463226, 43.05030293762684, 44.92406599223614, 44.23864737153053, 43.75927269458771, 51.369910910725594, 58.06614339351654, 52.762984558939934, 52.65086017549038, 56.20028391480446, 54.118808805942535, 52.72176057100296, 53.40317040681839, 53.49677458405495, 55.623531863093376, 58.18871721625328, 52.95373052358627, 57.277685701847076, 57.497758492827415, 58.10781575739384, 53.194052428007126, 50.77492743730545, 46.31283067166805, 45.166800767183304, 39.954099878668785, 45.09624235332012, 45.52921772003174, 51.0114761441946, 46.272940412163734, 35.204844921827316, 13.253462724387646, 12.328357715159655, 28.744437284767628, 30.14165461063385, 38.169423043727875, 31.31639577448368, 37.59798690676689, 36.48890621960163, 35.9738552570343, 37.79286324977875, 37.158700078725815, 37.697229981422424, 35.497824400663376, 33.0118115991354, 36.14496007561684, 36.24730758368969, 39.445565566420555, 36.140533313155174, 42.337658777832985, 40.80910339951515, 41.400682255625725, 43.60631190240383, 46.764143854379654, 42.13717393577099, 45.85964418947697, 41.096056401729584, 34.51442576944828, 33.1107696890831, 39.3626844137907, 40.639917477965355, 40.64286231994629, 31.264477260410786, 25.938504450023174, 18.06040048599243, 8.66398349404335, 26.585423536598682, 37.19653084874153, 46.578569412231445, 41.11285910010338, 41.050025671720505, 37.19509832561016, 37.185215055942535, 41.22988522052765, 42.45343096554279, 48.06916482746601, 50.24851508438587, 50.32268710434437, 49.70053508877754, 53.575441762804985, 49.09436881542206, 49.27756078541279, 49.50214013457298, 45.44851765036583, 45.2955986559391, 44.83846418559551, 54.49335090816021, 52.505172193050385, 55.97347028553486, 48.8179412484169, 52.21935912966728, 57.58974015712738, 50.88948369026184, 48.33998389542103, 42.21029721200466, 45.344711020588875, 42.36315920948982, 45.20203247666359, 46.84849552810192, 53.83703112602234, 56.94523014128208, 58.58535513281822, 59.88357067108154, 60.85728362202644, 61.13759458065033, 56.41497239470482, 53.75782057642937, 61.65155880153179, 58.906627893447876, 61.66988901793957, 58.432743921875954, 58.141504749655724, 51.28504626452923, 43.09472635388374, 15.145922675728798, 11.59382862970233, 48.61275985836983, 47.40374073386192, 28.694732151925564, 27.61233553290367, 16.946203373372555, 54.678940549492836, 49.679674208164215, 36.473851427435875, 60.70001766085625, 16.562190279364586, 0.11309465247904882, 0.2674344589468092, 0.057401575322728604, 0.053694759189966135, 0.049236440609092824, 0.08338047700817697, 0.06684298510663211, 0.06765061247278936, 0.062325888429768384, 0.15096152055775747, 0.05007425854273606, 0.09160735469777137, 0.06270704805501737, 0.09017862394102849, 0.12907451688079163, 0.05709073790058028, 0.04829035446164198, 0.0565990724862786, 0.08120046273688786, 0.05128961071022786, 0.07791727563017048, 33.14587980508804, 71.26047939062119, 29.73423097282648, 53.88479836285114, 102.58311823010445, 73.06990429759026, 42.83344477415085, 31.71934325248003, 45.629965513944626, 66.0110154747963, 46.35718189179897, 9.221238791942596, 0.21022823173552752, 12.68108993768692, 67.06292062997818, 66.94664686918259, 67.46464267373085, 61.56865485012531, 67.63020738959312, 64.24089565873146, 64.76002380251884, 63.2137955725193, 63.647857680916786, 58.83700802922249, 52.365035712718964, 49.0775965154171, 49.7245953977108, 49.98643174767494, 50.74600338935852, 49.19379808008671, 49.624200984835625, 47.78453350067139, 49.13644775748253, 47.85253465175629, 46.506152898073196, 53.7785142660141, 62.56832420825958, 57.90093965828419, 56.22507378458977, 60.93981519341469, 56.88394322991371, 54.84213039278984, 56.80746093392372, 55.41075088083744, 57.61335588991642, 60.736898481845856, 56.55624881386757, 57.55923539400101, 59.83106888830662, 59.598266780376434, 55.799348428845406, 54.45181533694267, 49.38757248222828, 48.92009496688843, 42.68341362476349, 45.90922012925148, 47.97923885285854, 53.52899685502052, 50.92674069106579, 42.57461026310921, 16.31365891546011, 16.3027611002326, 32.45292618870735, 35.69426625967026, 41.33344106376171, 36.73144720494747, 42.942286133766174, 40.09586647152901, 40.729870051145554, 39.056766629219055, 40.61420425772667, 40.95525495707989, 37.09076352417469, 37.27414168417454, 41.82476229965687, 40.12817993760109, 39.948681369423866, 40.92582553625107, 46.20856046676636, 42.014786303043365, 43.720674365758896, 46.54524900019169, 47.84521244466305, 43.91751900315285, 45.41088446974754, 40.290332436561584, 35.89883968234062, 34.333167895674706, 41.81387208402157, 43.80414828658104, 42.90306083858013, 32.81314305961132, 28.276613987982273, 20.47552429139614, 15.421928465366364, 33.64961877465248, 43.873638957738876, 51.182732954621315, 45.07930286228657, 43.929951936006546, 39.95955638587475, 40.4942636936903, 43.9401999861002, 47.12371475994587, 51.150062307715416, 54.99735206365585, 53.630751594901085, 55.25185860693455, 55.250475481152534, 51.69237680733204, 52.415519803762436, 50.56002996861935, 49.054242968559265, 49.627176225185394, 49.201899245381355, 57.820338383316994, 53.83197359740734, 60.48103541135788, 50.81589683890343, 55.281527414917946, 61.584367007017136, 54.58581894636154, 51.86396799981594, 45.88766768574715, 47.244107499718666, 47.84090347588062, 49.10080187022686, 52.121605575084686, 58.13943386077881, 59.86498586833477, 61.787975281476974, 63.24215725064278, 65.24898156523705, 64.32734102010727, 61.786561757326126, 59.74374197423458, 66.02399557828903, 66.00960955023766, 67.70444020628929, 64.06124129891396, 67.43856847286224, 61.685912758111954, 50.52913002669811, 16.503529027104378, 14.233280047774315, 54.15500946342945, 55.01007378101349, 34.466502740979195, 31.544482335448265, 23.304026015102863, 61.72114446759224, 60.72874791920185, 39.892204999923706, 68.5656487941742, 13.797409236431122, 0.2137084590503946, 0.18293300498044118, 0.1110622142732609, 0.10564646581769921, 0.0999512393900659, 0.04289850316126831, 0.08704618929186836, 0.06366096014971845, 0.048928924297797494, 0.19189532875316218, 0.17013921024044976, 0.11579759142477997, 0.328757319948636, 0.17142018681624904, 0.30347412975970656, 0.16826266015414149, 0.21250227611744776, 0.16166993969818577, 0.25050589232705534, 0.17294304416282102, 0.4120716790203005, 53.39834466576576, 81.38774156570435, 63.19217853248119, 69.19637694954872, 115.29139190912247, 92.0556691288948, 42.51813009381294, 38.13451811671257, 52.43723563849926, 73.76386106014252, 49.36796173453331, 11.399943083524704, 0.43921246484387666, 10.883725583553314, 67.32076719403267, 70.65768733620644, 73.6709712445736, 66.50389462709427, 70.2184385061264, 69.64343816041946, 69.28206235170364, 65.32373875379562, 66.60609394311905, 60.914945527911186, 54.7648311406374, 51.776762679219246, 50.75090892612934, 52.525599896907806, 53.83418507874012, 52.39106431603432, 51.8087113648653, 49.69409063458443, 49.44345608353615, 49.48374532163143, 47.92645588517189, 58.055830746889114, 64.71628814935684, 59.50199514627457, 57.36698471009731, 63.34846034646034, 60.60536094009876, 55.95114268362522, 59.90980066359043, 57.94398754835129, 58.17017041146755, 61.73739239573479, 57.09913708269596, 60.18188886344433, 61.76270663738251, 59.67248819768429, 57.86563575267792, 57.99515560269356, 51.956120654940605, 50.61196558177471, 44.75154384970665, 51.778939962387085, 52.00191579759121, 57.81213842332363, 52.899511232972145, 47.181619852781296, 22.603556402027607, 24.34316575527191, 36.5685423463583, 35.71451537311077, 44.99794542789459, 39.68763157725334, 45.72147600352764, 43.854404389858246, 43.93820509314537, 43.89891900122166, 43.650032356381416, 46.25034302473068, 38.596166744828224, 41.1738496273756, 44.72072370350361, 44.00878630578518, 45.20485572516918, 44.640715196728706, 51.2124777585268, 46.29097804427147, 44.72541645169258, 48.751273825764656, 51.80316746234894, 48.10829892754555, 48.99206690490246, 44.05779987573624, 37.49347731471062, 36.077171713113785, 44.544242173433304, 45.9943887591362, 45.41879944503307, 37.37380273640156, 34.10576529800892, 22.807654850184917, 23.956713192164898, 36.332472413778305, 45.05696386098862, 58.1937101483345, 48.98658759891987, 48.415322452783585, 43.200862258672714, 43.56144770979881, 45.894355326890945, 50.73902316391468, 55.20747698843479, 57.33599357306957, 54.84245337545872, 55.48850990831852, 58.24868939816952, 56.038963571190834, 54.213571920990944, 54.6602151542902, 51.25141426920891, 53.240375742316246, 49.909626469016075, 61.06489308178425, 55.2501904964447, 63.74982140958309, 51.97067767381668, 57.19791658222675, 64.67602550983429, 57.398834601044655, 54.31671358644962, 48.507102727890015, 50.08347474038601, 49.58079971373081, 50.90739592909813, 55.24764843285084, 61.87979355454445, 62.99720339477062, 66.08593225479126, 68.49608972668648, 66.0785074532032, 66.04535803198814, 61.709752678871155, 61.02970317006111, 67.96379148960114, 70.32850340008736, 71.48535132408142, 70.252735465765, 72.22767949104309, 68.97990256547928, 52.32071489095688, 18.655733540654182, 13.937135338783264, 59.420770704746246, 59.03237074613571, 44.38805155456066, 39.39803771674633, 27.104454785585403, 75.09761229157448, 62.55129352211952, 55.21652050316334, 82.02328026294708, 25.944390334188938, 0.629028637195006, 0.599565077573061, 0.448545417166315, 0.23633952514501289, 0.2860903297550976, 0.33508086344227195, 0.28670714353211224, 0.24390337552176788, 0.1400770788313821, 0.33151134091895074], [0.03300227188447025, 0.07115943473763764, 0.06345905145280994, 0.11542100342921913, 0.01792941398889525, 0.12138660909840837, 0.03306458631413989, 0.07819869060767815, 0.3107716975500807, 0.19868706353008747, 0.03656339329609182, 3.6209746124222875, 55.59886358678341, 51.198038533329964, 57.391048818826675, 81.1766628921032, 89.60389629006386, 37.72836551070213, 27.057282216846943, 33.80041368305683, 53.41031402349472, 46.155545711517334, 11.565640792250633, 0.13631231209728867, 36.59148171544075, 59.70197841525078, 58.76712217926979, 57.79198810458183, 56.81642845273018, 59.802038446068764, 60.51096260547638, 59.147246181964874, 56.97367541491985, 57.488084211945534, 53.48451264202595, 48.573390170931816, 49.601630195975304, 45.972577929496765, 48.37955877184868, 45.31016327440739, 46.16053864359856, 46.35785445570946, 43.52020472288132, 45.239126086235046, 42.72824361920357, 42.78048321604729, 44.7026214748621, 56.8577816337347, 56.38709329068661, 55.15377067029476, 53.95705908536911, 51.66276499629021, 51.1443056166172, 54.41621504724026, 59.052456468343735, 53.98746885359287, 63.346172869205475, 57.082436978816986, 55.40154777467251, 58.596515133976936, 56.38979494571686, 54.42511036992073, 51.3813216984272, 48.15771147608757, 46.904477924108505, 43.81847731769085, 39.36031714081764, 43.58186401426792, 50.84722615778446, 47.90952019393444, 42.57345512509346, 17.65550561249256, 12.296500224620104, 15.866340268403292, 26.77966721355915, 32.523682191967964, 35.49840956926346, 34.14157457649708, 32.62315325438976, 34.04850237071514, 33.7187484651804, 37.471119314432144, 33.639933094382286, 36.21063195168972, 32.98228718340397, 36.94728322327137, 35.19443728029728, 36.01555421948433, 34.6260903775692, 35.7655618339777, 40.59625022113323, 43.987173065543175, 46.498750895261765, 42.25760467350483, 40.07298789918423, 47.78307817876339, 32.839969620108604, 39.38817344605923, 45.343981459736824, 37.458515390753746, 46.28970131278038, 30.905254036188126, 28.521546944975853, 24.305300787091255, 14.296682495623827, 17.071256563067436, 31.166376024484634, 44.60450313985348, 46.29806846380234, 42.491189539432526, 40.74607238173485, 39.31753143668175, 40.853542014956474, 41.45072557032108, 43.68785172700882, 49.67411130666733, 50.73860138654709, 51.215225011110306, 48.76024514436722, 49.39971283078194, 48.77539873123169, 47.64589414000511, 44.434659853577614, 44.897661209106445, 46.57562457025051, 51.07228048145771, 52.92329415678978, 53.6142984777689, 55.9243693202734, 49.64129626750946, 52.827307507395744, 55.35933203995228, 50.5596461892128, 43.89411985874176, 41.85213603079319, 43.857816606760025, 45.515150874853134, 47.04035483300686, 46.770010739564896, 49.216904640197754, 55.20900450646877, 58.09154883027077, 59.37518075108528, 58.21852661669254, 59.98565599322319, 61.94296516478062, 57.5741495937109, 61.57701060175896, 62.466915249824524, 61.12570121884346, 58.74444119632244, 62.9179510474205, 58.679563477635384, 49.49512951076031, 16.440349817276, 13.269106484949589, 52.41948679089546, 43.575890734791756, 23.243143782019615, 23.04040566086769, 20.119213610887527, 53.53680923581123, 46.949744895100594, 40.73146976530552, 63.91238808631897, 5.2216351591050625, 0.23828944395063445, 0.011126281679025851, 0.07131775710149668, 0.0179073814797448, 0.03497726414934732, 0.05441580018668901, 0.09310949870268814, 0.030862272360536736, 0.05577269104833249, 0.03028576833457919, 0.09318678596173413, 0.1244979519105982, 0.045576572738355026, 0.06182794815686066, 0.0820556543476414, 0.30187604832462966, 0.06813838161178865, 0.07288801542017609, 0.35257025621831417, 0.24969816848170012, 0.24929806182626635, 2.634345917031169, 61.87658652663231, 51.81232117116451, 51.022575348615646, 90.08953303098679, 86.63895338773727, 49.04908664524555, 35.607380121946335, 39.59758780896664, 62.377167865633965, 55.95847629010677, 13.902923874557018, 0.11264081433182582, 45.807795971632004, 66.60269692540169, 66.29274755716324, 61.79349638521671, 61.52390845119953, 63.43853831291199, 65.49855217337608, 61.003921553492546, 61.211637407541275, 61.024543046951294, 57.0586122572422, 51.74545615911484, 50.25789678096771, 50.69246806204319, 53.005491346120834, 50.06242386996746, 51.024528443813324, 49.6692019701004, 45.853408724069595, 49.47247892618179, 46.97466395795345, 48.00807550549507, 47.64064662158489, 61.52463421225548, 57.043162286281586, 58.14233310520649, 54.64600391685963, 52.801126912236214, 53.814973309636116, 56.35439984500408, 61.241727992892265, 55.98443269729614, 63.118150904774666, 59.40686345100403, 57.022761180996895, 60.29741786420345, 57.52740830183029, 57.81808130443096, 53.6156702041626, 49.29696634411812, 47.18916244804859, 47.34067551791668, 42.6685032248497, 46.35501220822334, 52.34956294298172, 54.98395398259163, 46.93737655878067, 27.381828501820564, 14.55433052033186, 19.922125786542892, 32.852824330329895, 34.882177636027336, 37.90899641811848, 39.02986027300358, 39.139807373285294, 37.132021710276604, 38.03260378539562, 39.662758111953735, 38.279400542378426, 39.69423942267895, 35.283341109752655, 37.65609338879585, 36.417941227555275, 39.032592326402664, 37.82115653157234, 38.849985525012016, 40.908053889870644, 43.23811165988445, 46.448354199528694, 43.29154059290886, 38.666261583566666, 49.25445802509785, 35.69028027355671, 41.33092179894447, 46.026987209916115, 40.21117888391018, 47.343939542770386, 31.170527301728725, 33.23074825108051, 28.171184845268726, 17.35244147479534, 25.86946975439787, 42.39030875265598, 51.03237122297287, 50.60417219996452, 45.82983858883381, 45.91235876083374, 39.964150339365005, 44.21480365097523, 45.51836170256138, 47.657335326075554, 53.76035124063492, 54.69301499426365, 54.08963017165661, 51.604460924863815, 53.42491663992405, 51.95663742721081, 51.055109202861786, 49.27170529961586, 47.96661593019962, 50.23047745227814, 55.15377826988697, 56.12904533743858, 58.6537666618824, 57.433408945798874, 53.00961412489414, 58.03263679146767, 57.31511749327183, 54.4242288172245, 47.38056197762489, 45.33884033560753, 46.15047678351402, 48.36638107895851, 50.10081321001053, 50.94641603529453, 53.181273713707924, 58.22395272552967, 62.67719976603985, 63.894992619752884, 61.61494396626949, 64.13358181715012, 66.23287796974182, 63.98064762353897, 66.05051055550575, 68.58158513903618, 66.66999131441116, 64.57016319036484, 68.17433059215546, 63.924638628959656, 56.119751036167145, 17.635324895381927, 15.303561016917229, 60.18439672887325, 50.21855369210243, 28.296910598874092, 28.334919959306717, 25.859654881060123, 62.362702041864395, 45.52830956876278, 38.162477016448975, 73.67765888571739, 6.229286938905716, 0.33596401917748153, 0.08195469999918714, 0.09970766652259044, 0.02332271062186919, 0.04840345405682456, 0.03689693672640715, 0.09846754517639056, 0.07618530333274975, 0.07405205920804292, 0.13733166677411646, 0.19880441192071885, 0.17004492779960856, 0.24850247951690108, 0.18732350610662252, 0.09359149393276311, 0.3728060406865552, 0.13117053487803787, 0.1594942744122818, 0.31112270371522754, 0.5463524360675365, 0.30105060199275613, 5.078304475173354, 78.26645225286484, 62.880819439888, 72.69112542271614, 89.76198300719261, 105.63981100916862, 53.911305740475655, 37.18774572014809, 50.10465480387211, 65.73983922600746, 59.5208915323019, 14.522193744778633, 0.18228828645078465, 47.142747938632965, 69.37170714139938, 69.040038138628, 64.96692270040512, 63.038393184542656, 64.96458202600479, 66.84199288487434, 65.3740556538105, 64.12158206105232, 64.22829553484917, 60.155278891325, 56.46351478993893, 54.92378421127796, 51.52333527803421, 55.21261431276798, 53.708176240324974, 53.385501354932785, 52.78344266116619, 48.238305151462555, 52.44016908109188, 50.299987122416496, 49.19390447437763, 49.832099229097366, 65.00010251998901, 61.858583092689514, 61.63503348827362, 58.29812854528427, 54.56165984272957, 56.21659263968468, 57.68753170967102, 62.47057445347309, 59.65137653052807, 64.69655200839043, 59.112611040472984, 59.34333086013794, 61.62092864513397, 61.13634064793587, 60.3703473508358, 58.102917820215225, 52.56545215845108, 52.24247328937054, 50.344687923789024, 45.348244830965996, 49.85960975289345, 58.564235866069794, 56.296665742993355, 50.21055892109871, 31.946162581443787, 19.275997057557106, 29.026849530637264, 33.47228989005089, 37.635042518377304, 41.63408853113651, 41.03782832622528, 41.76976405084133, 40.419654697179794, 40.164551585912704, 41.75899162888527, 41.83399200439453, 42.52662643790245, 39.52739417552948, 42.11287043988705, 39.921832010149956, 40.89066602289677, 38.802640065550804, 40.91326341032982, 43.58695574104786, 47.13812738656998, 50.08641958236694, 48.36805298924446, 42.33870752155781, 55.28001509606838, 39.761997386813164, 46.48072846233845, 46.43281303346157, 42.16957859694958, 53.011692613363266, 31.86407558619976, 33.62371936440468, 31.457624696195126, 24.267139434814453, 29.354371055960655, 43.10813583433628, 55.7622130215168, 55.12904539704323, 51.884483098983765, 49.846736043691635, 43.75191628932953, 48.12731310725212, 46.928656026721, 51.61215551197529, 55.035684406757355, 55.499369725584984, 56.68033875524998, 54.89759221673012, 55.90222030878067, 53.63000303506851, 54.07397501170635, 50.830909833312035, 49.79239895939827, 51.16915248334408, 58.400897830724716, 58.620412051677704, 59.72388043999672, 61.921766102313995, 53.30948643386364, 60.04630073904991, 60.70997692644596, 58.116319701075554, 49.07513044774532, 48.05252932012081, 48.38684298098087, 52.48973362147808, 52.493605613708496, 54.51592929661274, 57.95123375952244, 62.59078860282898, 64.2289263010025, 68.31918641924858, 64.33502420783043, 70.64424365758896, 68.37057486176491, 65.9580235183239, 69.84823197126389, 75.82095667719841, 69.74865451455116, 69.58539247512817, 74.07857537269592, 70.92819482088089, 58.692813366651535, 22.578867226839066, 17.307567782700062, 65.1353220641613, 57.95620009303093, 35.67415773868561, 31.434584632515907, 32.479418367147446, 67.99586176872253, 65.22875145077705, 60.06224848330021, 84.28023755550385, 9.844127018004656, 0.6403310713358223, 0.26040412369184196, 0.211826802988071, 0.2193703778903, 0.1500413316534832, 0.1497405392001383, 0.1618137233890593, 0.28660894255153835, 0.2636383142089471, 0.19914554752176628], [0.0293021128163673, 0.06908983719768003, 0.037047815349069424, 0.03614666253270116, 0.05922527336224448, 0.024742583846091293, 0.040865808914531954, 0.03681816888274625, 0.03397560227313079, 0.057291948978672735, 0.15579907660139725, 0.09796963087865151, 22.00938418507576, 66.96438431739807, 33.70966695249081, 55.470601469278336, 95.84084361791611, 45.63658855855465, 18.255744203925133, 36.29442885518074, 44.430312886834145, 54.805458560585976, 14.421837329864502, 5.285660773515701, 43.83693292737007, 58.822830989956856, 62.63816826045513, 61.925649493932724, 58.324852511286736, 59.535110369324684, 59.76080305874348, 53.46871688961983, 56.55471369624138, 53.56944568455219, 51.476073414087296, 47.33009688556194, 47.33276054263115, 45.71652486920357, 46.1761824041605, 44.8806419223547, 44.64016042649746, 45.257346108555794, 44.7640185803175, 43.37470293045044, 43.80577839910984, 44.25219364464283, 43.22480857372284, 48.21149758994579, 50.73699787259102, 53.90744894742966, 53.28280046582222, 50.57814359664917, 56.103115528821945, 57.91699759662151, 56.572880521416664, 57.59263560175896, 50.13389803469181, 52.63251096010208, 57.28195667266846, 55.849323347210884, 54.486606270074844, 56.522366032004356, 48.78611035645008, 46.1347646266222, 46.343350633978844, 44.39934454858303, 40.17692752182484, 44.61483098566532, 43.84487070143223, 53.40776816010475, 47.84558482468128, 34.7920198738575, 7.496410645544529, 8.52805433794856, 25.648876391351223, 27.303512804210186, 31.897358000278473, 31.66760142892599, 37.103690430521965, 35.52248127758503, 35.475246012210846, 32.524616941809654, 35.851722210645676, 34.97849866747856, 38.9885450899601, 29.887199364602566, 34.44607503712177, 39.85942415893078, 42.64350816607475, 42.90295444428921, 42.7913848310709, 44.891794323921204, 44.90629054605961, 43.40138889849186, 44.10738341510296, 45.568891391158104, 40.785696655511856, 46.40627905726433, 45.82248978316784, 44.61359605193138, 30.855415910482407, 36.48856043815613, 32.69759126007557, 21.901772059500217, 16.49122528731823, 25.97300849854946, 42.37911835312843, 47.647448256611824, 45.68787820637226, 42.7898421138525, 39.2818171530962, 37.95363262295723, 42.540229707956314, 42.24036879837513, 46.33510887622833, 51.415584459900856, 50.330419689416885, 52.5297074764967, 51.162392646074295, 50.13702526688576, 48.21891099214554, 46.401061937212944, 47.15753674507141, 48.25151704251766, 49.86470527946949, 52.09482841193676, 52.924901470541954, 54.29878614842892, 49.84527312219143, 51.56343072652817, 55.724564641714096, 53.540533035993576, 48.54967184364796, 41.69974900782108, 42.91895538568497, 42.606729939579964, 45.27257949113846, 46.131819784641266, 47.782344818115234, 44.898698553442955, 50.579511523246765, 54.26802679896355, 57.19920851290226, 59.06181916594505, 62.492666468024254, 60.96939280629158, 60.195469334721565, 60.80371409654617, 61.88475228846073, 58.42531532049179, 57.98656806349754, 61.03231742978096, 60.705599561333656, 54.51136574149132, 16.26864843070507, 10.844575334340334, 57.92778141796589, 29.905559979379177, 27.111566103994846, 13.708014283329248, 18.517316468060017, 57.48860478401184, 46.556728184223175, 39.521713480353355, 62.2098096460104, 3.341229585930705, 0.21051815914688632, 0.040533345309086144, 0.03146163639030419, 0.05210557981627062, 0.06996284035267308, 0.1233624733868055, 0.07861499834689312, 0.07481731736334041, 0.04016173341369722, 0.09051315442775376, 0.10543180702370591, 0.05210740178881679, 0.0852955445589032, 0.0566896367672598, 0.1301620007143356, 0.04077171201060992, 0.08817810550681315, 0.042929988776450045, 0.02804522264341358, 0.07335367597988807, 0.08930387673899531, 0.17337696306640282, 22.186378687620163, 73.34457635879517, 34.156895354390144, 65.40617153048515, 99.10267978906631, 54.157080352306366, 30.154459923505783, 43.69355522096157, 50.69077715277672, 63.91706943511963, 16.272655315697193, 8.577163852751255, 54.746143743395805, 63.89079764485359, 69.0702997148037, 65.2194495499134, 62.626252099871635, 61.815261617302895, 61.11756205558777, 58.197331354022026, 59.74074013531208, 57.733182460069656, 53.69976349174976, 51.14349626004696, 50.28349220752716, 47.89449580013752, 49.64146725833416, 47.22640044987202, 47.62848347425461, 48.54431793093681, 47.589558362960815, 46.94857455790043, 48.15752148628235, 48.555861711502075, 47.758995071053505, 50.14770269393921, 55.35051651299, 56.15904852747917, 57.93952278792858, 52.98487365245819, 59.77825552225113, 58.082748502492905, 59.87150251865387, 61.53859086334705, 51.199341863393784, 56.674840450286865, 58.35751935839653, 58.94773408770561, 57.9994797706604, 56.21165670454502, 51.64730742573738, 48.0652092397213, 48.669088035821915, 46.07313193380833, 44.232259914278984, 47.55544759333134, 48.68713706731796, 54.88706678152084, 55.265344083309174, 41.97910241782665, 12.874926086515188, 13.334445878863335, 29.095555543899536, 31.88312776386738, 34.722430408000946, 35.51709696650505, 41.664205715060234, 38.03731553256512, 39.875311106443405, 37.34776273369789, 40.306831151247025, 39.65973347425461, 41.712459325790405, 31.343387626111507, 38.4008002281189, 42.60224997997284, 43.85602690279484, 46.415554359555244, 47.109115943312645, 47.52420946955681, 47.038618326187134, 45.25820106267929, 44.779092371463776, 46.59906931221485, 39.925107434391975, 45.90566352009773, 45.186335518956184, 43.259002938866615, 33.807576298713684, 38.63230660557747, 32.908966317772865, 23.245199471712112, 27.31589064002037, 35.775650292634964, 46.115465462207794, 50.46328715980053, 49.03893738985062, 46.36512726545334, 42.67703756690025, 40.63321843743324, 45.94587296247482, 44.03390295803547, 49.57270994782448, 53.301567658782005, 52.40034341812134, 54.846849739551544, 53.264599442481995, 52.943205088377, 51.335431560873985, 51.631017699837685, 50.514341220259666, 50.53599625825882, 53.64833325147629, 57.23476700484753, 56.75652466714382, 57.96489402651787, 55.54581843316555, 54.90813285112381, 57.42514818906784, 57.47833013534546, 50.20515561103821, 43.779620602726936, 47.55878001451492, 47.05799728631973, 50.05663298070431, 51.39193072915077, 51.80185653269291, 50.764846578240395, 54.228698909282684, 60.03126114606857, 61.737912967801094, 63.40470112860203, 66.47086679935455, 64.28352177143097, 66.38444423675537, 66.2085972726345, 66.56353622674942, 61.00264102220535, 63.287895396351814, 66.81278005242348, 64.10001441836357, 61.97599679231644, 19.477467946708202, 13.480612635612488, 63.598764315247536, 35.08831277489662, 29.35082584619522, 19.843872785568237, 26.827109567821026, 63.653010204434395, 46.35989114642143, 39.224455431103706, 66.27721399068832, 3.011931893415749, 0.11395044522942044, 0.06281953537836671, 0.01964454510016367, 0.08386284331209026, 0.022495772573165596, 0.059262221184326336, 0.08308846416184679, 0.09462782894843258, 0.05133936429047026, 0.030341351484821644, 0.24127304088324308, 0.2487152532557957, 0.10558017718722112, 0.15372312627732754, 0.3775133052840829, 0.15231798839522526, 0.19717548682820052, 0.136743544426281, 0.18226363230496645, 0.16786483931355178, 0.2637339918874204, 0.2576579398009926, 38.92081372439861, 83.01412269473076, 45.011495500802994, 67.01242133975029, 102.07675740122795, 69.66494500637054, 23.519069775938988, 51.84629514813423, 55.95389373600483, 71.76362559199333, 15.393079463392496, 9.645762462168932, 58.240120857954025, 68.11069160699844, 73.55837568640709, 68.83110255002975, 67.48747184872627, 67.12383896112442, 66.75709784030914, 60.79306706786156, 63.91151413321495, 62.46349163353443, 57.0289396494627, 53.85618969798088, 52.08132013678551, 50.28735660016537, 51.83591790497303, 49.623034447431564, 49.96844731271267, 51.144461408257484, 49.358044266700745, 49.94006663560867, 49.97246369719505, 51.34617358446121, 48.485820069909096, 53.755829483270645, 57.078868970274925, 61.10316842794418, 60.7747520506382, 53.4297651797533, 62.87375941872597, 61.502773985266685, 63.15194249153137, 65.24487778544426, 52.002649158239365, 57.40603521466255, 60.414899960160255, 60.749418810009956, 58.90324987471104, 60.133924037218094, 56.74336977303028, 51.14481098949909, 51.93831481039524, 50.5970361828804, 46.5502305328846, 51.06799431145191, 51.36127397418022, 58.70171628892422, 57.131100967526436, 47.23945274949074, 18.44996888190508, 18.160766400396824, 34.9190204590559, 36.07956178486347, 37.61262372136116, 38.98072890937328, 44.690519124269485, 42.75340586900711, 43.80179241299629, 42.950166910886765, 44.0399332344532, 43.26245315372944, 47.5109975785017, 39.83506366610527, 44.2605721950531, 46.099525317549706, 46.622825637459755, 49.02351401746273, 50.06334342062473, 51.582680493593216, 50.45894779264927, 46.24263323843479, 46.956280544400215, 50.61923459172249, 41.78955718874931, 49.13564220070839, 45.91427765786648, 44.51768159866333, 35.727921053767204, 40.48010565340519, 38.40202756226063, 31.829322651028633, 30.13831838965416, 34.0855997800827, 51.57824233174324, 54.83771502971649, 54.00978125631809, 50.88961288332939, 48.36419619619846, 42.27740541100502, 49.62483175098896, 48.974922224879265, 51.75912782549858, 57.346868589520454, 56.246405839920044, 59.675083458423615, 55.525284335017204, 56.122255101799965, 54.27401527762413, 54.556913897395134, 53.50566990673542, 52.99398936331272, 56.04196920990944, 59.05702002346516, 58.5651820152998, 60.89395925402641, 59.071793630719185, 56.96320317685604, 62.30327323079109, 62.4343091994524, 55.65478898584843, 45.17124652862549, 49.5705858618021, 47.19464935362339, 53.87353576719761, 55.077736750245094, 54.45726804435253, 52.394826114177704, 58.797851130366325, 61.98324300348759, 66.24440655112267, 67.95825138688087, 70.14802068471909, 66.10465005040169, 67.9687388241291, 68.8445994257927, 71.84847503900528, 67.49397709965706, 68.08137997984886, 70.42941078543663, 73.31187531352043, 64.59499105811119, 22.988914623856544, 14.317002855241299, 71.86741322278976, 43.579895719885826, 37.7050119638443, 17.557425275444984, 31.10537599772215, 70.37148669362068, 61.01556792855263, 57.538910284638405, 82.43732884526253, 6.603041533380747, 0.3579155303305015, 0.2935436594998464, 0.16431979282060638, 0.21456847462104633, 0.16792737267678604, 0.21640808059601113, 0.21400129568064585, 0.15835562691790983, 0.22490576055133715, 0.22954142274102196], [0.06877146326587535, 0.09584090643329546, 0.10398790676845238, 0.01304408589930972, 0.056773013347992674, 0.06099154030380305, 0.05600969219813123, 0.05668431556841824, 0.07834408475901, 0.08262875562650152, 0.16559419396799058, 0.20596999616827816, 3.241396830417216, 62.463529631495476, 50.711079463362694, 42.25390747189522, 61.58374384045601, 52.36121691763401, 22.247547805309296, 29.9874284863472, 46.48907281458378, 57.28714719414711, 21.453707702457905, 11.289544757455587, 55.72494462132454, 60.530124977231026, 63.778080493211746, 60.81151507794857, 53.896703124046326, 53.11413511633873, 50.55367670953274, 48.94721031188965, 52.46660806238651, 50.158554911613464, 50.97737677395344, 46.7062995582819, 47.88346879184246, 46.150666773319244, 46.666679084300995, 46.53107576072216, 47.234930992126465, 44.08479742705822, 45.35405091941357, 42.115013524889946, 42.66222596168518, 43.88569191098213, 42.69377566874027, 40.111308842897415, 47.24587820470333, 49.54834185540676, 50.85787318646908, 53.93122807145119, 56.1513539403677, 54.79294963181019, 55.14827996492386, 58.284335285425186, 58.40737268328667, 53.40856231749058, 58.10137890279293, 55.660754665732384, 56.729815900325775, 50.82294546067715, 50.152931213378906, 46.069510728120804, 44.732605665922165, 44.49348829686642, 40.85297204554081, 42.59668707847595, 44.59313414990902, 49.75407041609287, 49.936954602599144, 40.017624869942665, 19.040307104587555, 12.109720297157764, 17.805795148015022, 26.821440272033215, 28.438042625784874, 33.28838735818863, 32.0799496024847, 31.914688870310783, 31.7685392126441, 33.26145440340042, 34.3412234634161, 36.72317124903202, 21.644934341311455, 16.143996119499207, 33.35219733417034, 38.07038515806198, 34.13767598569393, 38.010678961873055, 42.70865187048912, 41.947556510567665, 39.22608934342861, 44.491121023893356, 44.210669472813606, 41.774190813302994, 43.24289560317993, 42.89250500500202, 41.98415234684944, 38.8669478148222, 41.19908407330513, 32.095000594854355, 20.486306212842464, 19.7835149243474, 27.594662681221962, 37.951158955693245, 45.55164411664009, 48.032834976911545, 44.51016940176487, 40.45237094163895, 39.35305193066597, 40.619482174515724, 41.2996456772089, 43.6007110029459, 48.686795085668564, 51.51410937309265, 49.09077040851116, 48.12294714152813, 49.88575614988804, 48.79525266587734, 49.359537586569786, 47.92426720261574, 49.96652081608772, 48.99182751774788, 51.06372334063053, 53.75407017767429, 54.94035132229328, 52.69774205982685, 51.28792650997639, 52.63556979596615, 53.40828113257885, 49.32309754192829, 40.0559838116169, 40.424655228853226, 41.230721175670624, 44.745521172881126, 45.22229678928852, 47.08467945456505, 46.896992325782776, 45.192278400063515, 46.04843705892563, 50.38509875535965, 53.61812487244606, 57.86597013473511, 59.36332158744335, 62.19479285180569, 64.19722080230713, 65.73188245296478, 55.756034553050995, 54.99805502593517, 60.969552397727966, 64.34353575110435, 58.789172396063805, 59.111102521419525, 12.754961773753166, 16.633670143783092, 55.45318700373173, 30.568101927638054, 33.694710955023766, 15.38299860432744, 24.698644280433655, 56.81269325315952, 102.30722263455391, 55.553497821092606, 49.630117267370224, 0.909554046811536, 0.03236808814108372, 0.04742423101561144, 0.046112362542771734, 0.019637518817035016, 0.014247119343053782, 0.10065993847092614, 0.12178609234979376, 0.2108642374514602, 0.02879545045288978, 0.09603862941730767, 0.09810121366172098, 0.0840384725597687, 0.05027510225772858, 0.015868171176407486, 0.10614573824568652, 0.0889686708978843, 0.07781512642395683, 0.034397145864204504, 0.04388997534988448, 0.05545727086428087, 0.2567428717156872, 0.06109841699071694, 3.3434579288586974, 66.22270211577415, 52.48610861599445, 50.43039612472057, 68.4590645134449, 56.55336856842041, 31.083916649222374, 41.49167597293854, 52.048543095588684, 66.05031296610832, 24.002253748476505, 15.686940494924784, 64.85061094164848, 68.5402661561966, 70.14822587370872, 66.84391558170319, 60.58996416628361, 57.10992470383644, 55.57442329823971, 53.017369508743286, 58.2830623537302, 55.91384768486023, 55.50368629395962, 52.81626909971237, 53.205919191241264, 48.44111926853657, 50.64255014061928, 50.23803524672985, 52.275117337703705, 47.19406418502331, 48.471730425953865, 45.45688480138779, 44.549018517136574, 45.6747081130743, 44.61566314101219, 43.95936615765095, 52.57346212863922, 51.3803793489933, 52.52832815051079, 56.63193315267563, 59.980112090706825, 58.16865049302578, 58.31896662712097, 59.89062309265137, 61.22259981930256, 56.56974948942661, 60.344421342015266, 57.24859446287155, 58.437033891677856, 54.35376539826393, 52.21457898616791, 47.97059431672096, 49.34147335588932, 48.8184580206871, 43.67655873298645, 44.46826905012131, 48.324777111411095, 53.52066770195961, 51.799504458904266, 45.75655572116375, 31.07736960053444, 13.451322857290506, 21.787977665662766, 31.23469825834036, 31.18690252304077, 39.25817482173443, 33.80831725895405, 34.71368707716465, 34.64531734585762, 37.41845794022083, 38.07625964283943, 38.82383152842522, 21.461873464286327, 20.338933020830154, 41.96015663444996, 42.07516506314278, 33.96372511982918, 38.492417111992836, 42.72048823535442, 39.13771368563175, 39.580127745866776, 45.35500846803188, 45.719788894057274, 41.633609756827354, 43.827657625079155, 41.388925686478615, 43.280612379312515, 40.022708997130394, 42.70235560834408, 31.870757527649403, 21.8298552185297, 32.39078052341938, 37.03454174101353, 41.801674738526344, 48.617258816957474, 48.753158524632454, 47.57351562380791, 43.616381362080574, 41.38042934238911, 43.44394661486149, 44.948966056108475, 44.63846191763878, 52.4131715297699, 53.414193615317345, 52.55872651934624, 50.59187225997448, 53.35206314921379, 51.34874224662781, 52.08048798143864, 52.35518664121628, 52.49847695231438, 51.198958083987236, 52.91737787425518, 57.60119654238224, 58.899750262498856, 56.46652042865753, 54.98796656727791, 55.21971993148327, 60.49447149038315, 50.28297923505306, 42.94012404978275, 42.98009790480137, 44.292699471116066, 47.916872799396515, 46.89767248928547, 51.243009120225906, 49.80442151427269, 47.955820709466934, 48.9973334223032, 53.921998366713524, 55.62810681760311, 63.10427784919739, 66.32472664117813, 66.11380755901337, 66.22321888804436, 69.27695542573929, 59.21061538159847, 60.847689136862755, 66.31555393338203, 69.83656659722328, 63.774607479572296, 64.2591954767704, 12.910820860415697, 21.554206609725952, 60.68992160260677, 36.18550769984722, 36.54377527534962, 19.690701104700565, 32.77902849018574, 63.35385225713253, 97.70956814289093, 63.73642332851887, 61.70193649828434, 1.4686176320537925, 0.05036641981860157, 0.20329491002485156, 0.06572221594979055, 0.017139523952209856, 0.020075996362720616, 0.03520071739330888, 0.2324765722732991, 0.23395898257149383, 0.06923252993146889, 0.02236779848317383, 0.2164712076773867, 0.28848595276940614, 0.204265208740253, 0.13497080595698208, 0.28469307348132133, 0.22627141617704183, 0.14632820355473086, 0.23023136775009334, 0.3141269471962005, 0.16667667572619393, 0.6876213743817061, 0.5114410375244915, 7.297025844454765, 82.7594755589962, 60.90674176812172, 54.7439094632864, 67.90607258677483, 72.92453169822693, 30.140353180468082, 42.03761547803879, 59.63715769350529, 72.10636720061302, 26.162074953317642, 18.73890347778797, 68.24992373585701, 72.56434142589569, 73.19787383079529, 69.57155361771584, 64.83409702777863, 58.76652181148529, 59.26822029054165, 55.28365530073643, 63.97902891039848, 58.15603896975517, 60.520477294921875, 56.01054489612579, 56.379854679107666, 51.007558554410934, 54.48748022317886, 51.961660757660866, 54.83790881931782, 48.414285108447075, 51.04275606572628, 47.1116504073143, 47.15377874672413, 48.60563524067402, 48.403858467936516, 46.55653819441795, 54.26948592066765, 53.04012268781662, 55.74371941387653, 58.89075614511967, 63.06652307510376, 59.42067950963974, 59.85695309937, 61.410324946045876, 64.00447994470596, 56.38207755982876, 61.91854387521744, 58.36219310760498, 61.088695004582405, 55.406571105122566, 51.617384031414986, 50.07472760975361, 50.245395451784134, 50.99087744951248, 46.107371896505356, 49.18721303343773, 49.46323402225971, 57.81947202980518, 54.18760031461716, 48.95030714571476, 36.075894981622696, 21.189129799604416, 27.630498558282852, 31.957960948348045, 34.69183824956417, 39.56886135041714, 36.461467891931534, 38.39777559041977, 39.77867469191551, 39.60234135389328, 43.632906675338745, 42.854244858026505, 24.183800406754017, 24.50005743652582, 49.983380511403084, 44.21221598982811, 36.62515550851822, 41.861445531249046, 42.26552724838257, 40.434386506676674, 40.609929487109184, 50.68035051226616, 49.69062902033329, 43.366825953125954, 43.33838067948818, 41.849669963121414, 43.16591553390026, 40.32480038702488, 42.682228088378906, 39.391198083758354, 28.835014924407005, 36.75362281501293, 37.15435691177845, 46.69093698263168, 50.28915010392666, 54.184906259179115, 51.46080583333969, 48.036881759762764, 46.682448238134384, 47.40326575934887, 45.470396876335144, 48.95499989390373, 58.0249460041523, 56.63119599223137, 55.867262184619904, 52.05912172794342, 54.66898888349533, 54.736803844571114, 54.514348581433296, 53.42175520956516, 56.19017265737057, 55.63453987240791, 56.86150923371315, 58.27741585671902, 60.72557508945465, 58.90204533934593, 58.06317575275898, 58.24881099164486, 61.380576342344284, 55.70689558982849, 47.666587829589844, 47.247348725795746, 46.86621777713299, 51.26413218677044, 50.26928097009659, 54.68811705708504, 52.514759078621864, 51.93411223590374, 52.111794501543045, 59.433424025774, 58.96032281219959, 66.59084156155586, 71.4078126847744, 70.80972477793694, 74.51463237404823, 76.30298361182213, 64.45505976676941, 64.649708122015, 73.16167697310448, 78.28642398118973, 68.97011429071426, 70.83074524998665, 18.582192286849022, 21.467632055282593, 66.88189074397087, 42.22883641719818, 42.5920969247818, 20.619838647544384, 40.9644428640604, 71.75468847155571, 113.67862924933434, 73.1882755458355, 68.9128665626049, 1.7311130091547966, 0.16081363486591727, 0.33479495847132057, 0.17146296420833096, 0.11982361640548334, 0.07263256076839752, 0.3547489346237853, 0.33109576790593565, 0.41468846204224974, 0.12932810874190181, 0.20386272721225396], [0.13080649659968913, 0.1818151821498759, 0.0913469424995128, 0.07718459033640102, 0.026203187990176957, 0.043341416894691065, 0.17639455036260188, 0.04656247139791958, 0.13192338432418182, 0.16719226056011394, 0.1304662664188072, 0.08999192927149124, 0.17700720811262727, 35.425286293029785, 53.7467859685421, 37.60475814342499, 15.021726340055466, 41.15391969680786, 33.50842595100403, 21.12360991537571, 49.76573958992958, 55.797744914889336, 21.9361013174057, 10.333478059619665, 64.37036231160164, 68.41796591877937, 72.0251427590847, 72.49887093901634, 59.55963425338268, 53.91851395368576, 55.069153010845184, 46.68358817696571, 55.94943277537823, 53.73288631439209, 53.16930055618286, 52.43633508682251, 53.37775357067585, 43.70363987982273, 45.13727255165577, 45.49809738993645, 46.82142198085785, 45.28724670410156, 45.53353048861027, 41.744221821427345, 42.74035356938839, 38.84315349161625, 39.21005800366402, 38.825750425457954, 41.846660524606705, 47.828873321413994, 49.182828068733215, 51.952442452311516, 56.90899908542633, 54.689230397343636, 57.98880994319916, 57.103917226195335, 61.75701454281807, 55.7458359003067, 54.27346050739288, 55.944842621684074, 59.9426157027483, 52.14565448462963, 51.838463768363, 47.512502297759056, 44.317892119288445, 47.43985399603844, 45.05928173661232, 40.907567515969276, 44.13278505206108, 50.522176399827, 53.64220418035984, 42.797487303614616, 33.5287244617939, 13.901337459683418, 17.53563914448023, 31.35111641138792, 31.533704213798046, 36.48224137723446, 31.973190531134605, 27.363604679703712, 28.476939238607883, 33.59061174094677, 36.125657111406326, 33.10453042387962, 21.67940229177475, 56.000239849090576, 78.7333332002163, 66.46268203854561, 33.90794411301613, 47.1133641153574, 46.83017671108246, 35.72863161563873, 37.62162163853645, 38.121598809957504, 40.77205918729305, 40.03055177628994, 38.29852111637592, 35.854834243655205, 40.045921951532364, 40.92189274728298, 20.46929072588682, 20.934315472841263, 21.157785281538963, 37.28787034749985, 34.16835933923721, 39.47798542678356, 45.44472545385361, 43.00947032868862, 44.282253831624985, 40.22785238921642, 37.28520669043064, 42.4072178453207, 41.83927372097969, 39.83819089829922, 45.09311132133007, 50.482415333390236, 47.26571314036846, 47.76770040392876, 48.9784674346447, 51.87460742890835, 49.36127409338951, 50.21841309964657, 50.07915437221527, 47.87910282611847, 51.7720927298069, 54.975195452570915, 52.19467185437679, 54.405511021614075, 53.6904463917017, 54.347035959362984, 48.5677170753479, 42.41395868360996, 39.61324296891689, 39.45063069462776, 43.312048092484474, 47.35345423221588, 45.13750433921814, 47.286707013845444, 45.815642550587654, 44.80453200638294, 44.65963818132877, 47.05549322068691, 49.16308052837849, 53.56449455022812, 53.866578340530396, 55.5221951007843, 53.80774609744549, 56.20131365954876, 49.259454756975174, 57.302217185497284, 61.46796405315399, 63.59755218029022, 58.36207151412964, 53.380432426929474, 4.875895036384463, 26.446875371038914, 51.25771053135395, 38.08292828500271, 26.482815742492676, 17.507750540971756, 29.56522934138775, 57.58302591741085, 74.17581215500832, 39.70272436738014, 61.090857088565826, 1.6158815799281, 0.11266436267760582, 0.15345299936598167, 0.08104366177576594, 0.05378918634960428, 0.009423426618013764, 0.14553290326148272, 0.3099846647819504, 0.4420436394866556, 0.06013606667693239, 0.10953530480037443, 0.11049756605643779, 0.239853119419422, 0.1146323602006305, 0.17147759936051443, 0.08285453921416774, 0.07600723984069191, 0.03271258196036797, 0.07189353011199273, 0.20384433679282665, 0.21904729132074863, 0.11284010324743576, 0.1174262938729953, 0.16446952853584662, 42.022306099534035, 59.457746520638466, 40.666937828063965, 27.743289805948734, 48.11102718114853, 38.86641584336758, 30.055161751806736, 56.1138841509819, 63.15610706806183, 27.64716826379299, 13.37036345154047, 67.19358041882515, 74.24537122249603, 79.08755019307137, 76.48551061749458, 65.69101184606552, 57.52463445067406, 60.138324201107025, 53.20708952844143, 60.38042061030865, 59.093061089515686, 58.76551866531372, 56.20300076901913, 56.66616931557655, 47.34657660126686, 48.55081558227539, 50.35151615738869, 50.994559451937675, 46.92686252295971, 49.97925393283367, 44.00051794946194, 44.8668372631073, 41.85665778815746, 42.43185192346573, 42.33129791915417, 44.84959378838539, 50.7843167334795, 50.093897581100464, 55.28762988746166, 58.65798443555832, 57.74798646569252, 58.57539586722851, 58.9316875487566, 64.66367617249489, 56.10867083072662, 56.280698999762535, 57.95935392379761, 61.58031262457371, 51.28141365945339, 51.46500080823898, 49.588201716542244, 50.374478325247765, 51.995163559913635, 49.49630364775658, 44.65847924351692, 47.61928416788578, 53.994958251714706, 57.229036912322044, 50.33819027245045, 42.05686904489994, 24.95450545102358, 22.65655405819416, 34.90875720977783, 39.7145227342844, 42.030262872576714, 35.0217517465353, 29.366794489324093, 33.54687608778477, 36.939296051859856, 39.69020403921604, 35.56338608264923, 28.151082023978233, 78.90305489301682, 96.95603057742119, 68.3991265296936, 37.42965213954449, 50.7595344632864, 47.92608730494976, 38.41734454035759, 36.4375975728035, 40.311539098620415, 40.37752255797386, 39.84884172677994, 36.93093650043011, 33.68538245558739, 39.00317810475826, 38.083543851971626, 22.619544044137, 24.614520594477654, 31.787701584398746, 41.92483372986317, 36.28572732210159, 42.677698731422424, 44.33961175382137, 47.14788146317005, 47.640194445848465, 45.061318427324295, 40.83170838654041, 45.79657897353172, 43.79649169743061, 42.46325723826885, 47.58896939456463, 52.28588595986366, 50.68169943988323, 49.64522525668144, 50.81035673618317, 54.2778492718935, 52.21147075295448, 52.041889652609825, 52.51294657588005, 50.10382264852524, 53.08936424553394, 57.379892617464066, 53.32270212471485, 58.009773418307304, 56.93088211119175, 56.12658306956291, 51.17665708065033, 44.33384366333485, 44.37319055199623, 41.46385006606579, 45.374072045087814, 50.35656988620758, 48.29331859946251, 49.61594022810459, 48.66669036448002, 48.36834937334061, 49.87010858952999, 51.58504016697407, 52.05522693693638, 58.12250196933746, 60.10761424899101, 58.710239231586456, 58.42128373682499, 59.65926110744476, 56.43438555300236, 62.422248646616936, 67.5646685063839, 72.75442242622375, 64.21793729066849, 55.550590977072716, 6.034379722550511, 32.24060498178005, 56.81479834020138, 41.20538793504238, 32.2914956510067, 18.851804919540882, 33.98491658270359, 63.32865200936794, 86.55115529894829, 42.25401386618614, 70.21252602338791, 3.1809470616281033, 0.18977962899953127, 0.3753185668028891, 0.07190746764536016, 0.03702989619341679, 0.09685042765340768, 0.12664520036196336, 0.22082322102505714, 0.40736186143476516, 0.03196487930836156, 0.17146219237474725, 0.14849203900666907, 0.4722201655386016, 0.1605570298852399, 0.3621877182740718, 0.08427037886576727, 0.2746235841186717, 0.4001700645312667, 0.2005352042033337, 0.29805309721268713, 0.19104110193438828, 0.24476809630868956, 0.2807357639539987, 0.48093514633364975, 58.77228230237961, 68.1873182952404, 51.00968264043331, 21.084492914378643, 53.13175477087498, 46.892155185341835, 26.856632083654404, 64.27169680595398, 72.08287686109543, 31.22556544840336, 16.268654130399227, 74.98722061514854, 80.33279657363892, 84.2015665769577, 84.20079901814461, 70.29722347855568, 59.45596061646938, 64.2338128387928, 54.157380536198616, 64.1158975660801, 64.57979187369347, 62.614031955599785, 62.661316618323326, 61.70062176883221, 50.12181468307972, 48.81578676402569, 51.1920690536499, 52.0777103304863, 49.198460429906845, 52.18701146543026, 46.860924661159515, 45.543843135237694, 44.114249646663666, 44.538223296403885, 41.58937253057957, 43.43518428504467, 53.65819372236729, 55.41983999311924, 60.02498388290405, 62.33356520533562, 58.75548340380192, 59.081904888153076, 61.54843993484974, 69.28019285202026, 58.839029520750046, 57.054386883974075, 59.31719206273556, 63.67164060473442, 52.77394317090511, 52.14989885687828, 52.76016891002655, 50.97848631441593, 56.474522799253464, 50.3450109064579, 47.88909249007702, 50.45335829257965, 59.17636401951313, 63.49170506000519, 49.23704355955124, 46.95359408855438, 34.83401522040367, 31.398649960756302, 37.895241156220436, 42.40292027592659, 47.17344269156456, 40.894857197999954, 32.62902393937111, 34.76242706179619, 40.574078410863876, 44.707196429371834, 42.03886941075325, 24.669763930141926, 78.83364021778107, 94.61898118257523, 74.77963015437126, 37.028785049915314, 50.13529635965824, 46.852511912584305, 39.13598097860813, 35.68344444036484, 40.39666973054409, 42.922682985663414, 39.995073080062866, 37.57532112300396, 35.55141672492027, 38.495836928486824, 40.82602769136429, 27.73349393159151, 32.04426571726799, 39.12665247917175, 43.02950665354729, 41.654789820313454, 46.63026563823223, 49.585184678435326, 49.472961500287056, 51.020481660962105, 46.88967391848564, 43.52386012673378, 50.90388871729374, 47.81929783523083, 45.63535362482071, 52.21738703548908, 57.13035240769386, 53.821892738342285, 55.47080285847187, 53.16083461046219, 57.21749313175678, 54.67632248997688, 53.25111396610737, 56.526910588145256, 51.43633894622326, 55.0594787299633, 60.42147360742092, 57.640733420848846, 62.70593382418156, 60.14158062636852, 57.286174446344376, 54.08383168280125, 47.054448276758194, 44.2403344810009, 40.9722476452589, 47.25117512047291, 51.544887721538544, 51.844505444169044, 53.56598787009716, 51.8117967993021, 52.25662373006344, 54.00959886610508, 54.70872715115547, 59.535471349954605, 65.46278089284897, 68.77383962273598, 66.92469164729118, 62.876373678445816, 66.91675007343292, 61.61651328206062, 65.80935269594193, 73.75070616602898, 83.0777844786644, 71.80238351225853, 63.74800130724907, 7.989889215677977, 30.11629667133093, 63.77211481332779, 49.151073172688484, 34.594179689884186, 24.503805935382843, 44.164482951164246, 70.2095165848732, 93.36499527096748, 53.7725105881691, 80.90137526392937, 3.41465019620955, 0.2803377353120595, 0.6367466761730611, 0.22761560889193788, 0.17054362135240808, 0.16276399896014482, 0.1338174639386125, 0.3287699067732319, 0.8748385158833116, 0.28539844031911343, 0.21513885963940993], [0.13658042036695406, 0.20761679217685014, 0.10243967539281584, 0.30890163383446634, 0.026815966339199804, 0.12276207591639832, 0.1987815834581852, 0.16908032877836376, 0.2960602822713554, 0.2689478168031201, 0.042117919656448066, 0.040933908385341056, 0.13031152862822637, 25.239359065890312, 65.34701630473137, 46.16056524217129, 19.724034816026688, 31.213996969163418, 38.6009468883276, 23.791486658155918, 45.426338240504265, 56.712975203990936, 35.08615829050541, 10.773188564926386, 53.231560215353966, 63.138403818011284, 67.51611471176147, 67.48503997921944, 58.30273389816284, 56.17387913167477, 58.692615777254105, 54.61233392357826, 54.525812566280365, 49.160078689455986, 53.784179762005806, 52.02972650527954, 52.94274531304836, 48.487431183457375, 53.649495989084244, 51.12857826054096, 53.10226835310459, 46.21916949748993, 47.047528848052025, 44.39260371029377, 46.198920384049416, 42.962687239050865, 42.14422635734081, 40.883237421512604, 44.84964318573475, 42.3021686822176, 44.1335716098547, 49.75093178451061, 52.47077263891697, 55.90161994099617, 54.701621532440186, 49.37195532023907, 53.291946575045586, 51.440039947628975, 57.07898676395416, 52.72002786397934, 53.850490003824234, 53.09334643185139, 53.06896694004536, 49.178420305252075, 48.89423355460167, 51.95377618074417, 44.59552802145481, 40.426771715283394, 41.944083496928215, 49.62284065783024, 48.92194166779518, 48.44583101570606, 37.34385274350643, 19.355737678706646, 13.314013425260782, 14.307625908404589, 25.274478681385517, 31.199907325208187, 26.996614672243595, 23.45781896263361, 26.686363220214844, 33.8147047162056, 32.25063644349575, 26.6110797598958, 26.883724629878998, 59.90174889564514, 78.48160430788994, 46.505423337221146, 35.539337173104286, 45.530973225831985, 42.29431830346584, 45.487317368388176, 38.207626193761826, 42.22459204494953, 39.52891029417515, 39.24565069377422, 31.240741834044456, 31.385061889886856, 34.4527892768383, 21.0438521951437, 18.780515044927597, 36.92185878753662, 40.17461344599724, 32.96952746808529, 30.660699158906937, 43.45551699399948, 41.74124278128147, 45.36907531321049, 40.43396852910519, 39.89538162946701, 41.838635355234146, 41.13637983798981, 42.462865859270096, 42.320559695363045, 43.279780223965645, 46.46412335336208, 47.02614739537239, 47.442836835980415, 50.70378005504608, 52.66011267900467, 53.22586052119732, 52.665477991104126, 49.29135404527187, 50.022073835134506, 49.43107634782791, 50.18863409757614, 51.18042267858982, 51.71767584979534, 51.618729159235954, 50.767890214920044, 41.270801424980164, 42.27004140615463, 44.241402223706245, 45.35209782421589, 47.55768947303295, 46.25419221818447, 47.04302988946438, 48.31204019486904, 47.904523462057114, 45.995885878801346, 45.8860831707716, 48.30450139939785, 48.927534967660904, 46.43331840634346, 47.52224497497082, 46.81656204164028, 51.110118851065636, 50.74633777141571, 53.58405590057373, 58.76760475337505, 62.566139325499535, 60.23427665233612, 63.0670702457428, 38.59548658132553, 4.305572239682078, 41.294846534729004, 46.14392213523388, 42.39728517830372, 22.255992852151394, 25.12394405901432, 33.05210083723068, 55.04890389740467, 30.500315465033054, 42.12754525244236, 58.35987143218517, 3.6226868955418468, 0.22229084774153307, 0.12339925422566012, 0.20437921746633947, 0.041332230175612494, 0.14036947017302737, 0.18232104484923184, 0.09799793639103882, 0.060370756036718376, 0.061300496381591074, 0.3163414268055931, 0.0968470583029557, 0.09295433788793162, 0.17577439692104235, 0.18481572973541915, 0.03309274710773025, 0.11351732784532942, 0.15211366029689088, 0.09642008590162732, 0.2155727191711776, 0.03307128048618324, 0.022086652534198947, 0.12353212834568694, 0.10142853629076853, 34.16291423141956, 73.95216375589371, 43.307959511876106, 25.359664410352707, 39.0588603168726, 39.85184356570244, 28.464996479451656, 54.648188799619675, 62.18286909162998, 44.41478691995144, 14.554244074970484, 56.01923882961273, 67.74367690086365, 73.20905283093452, 72.54550963640213, 63.17868545651436, 59.607751071453094, 62.85124942660332, 58.8846118748188, 59.44579616189003, 57.85324841737747, 58.874736204743385, 56.79113321006298, 58.69079567492008, 52.997903153300285, 59.111634492874146, 57.13624969124794, 56.49322919547558, 49.74017076194286, 50.793497040867805, 47.1081317961216, 48.73917147517204, 44.72942143678665, 43.90930764377117, 41.69330075383186, 46.70627295970917, 45.5712890625, 45.69032147526741, 50.03635726869106, 53.45936179161072, 57.64427863061428, 56.033484265208244, 50.9977550804615, 56.03453300893307, 53.858594968914986, 58.18743668496609, 55.08217491209507, 55.242191925644875, 53.95199775695801, 52.97633931040764, 53.82373943924904, 52.01496049761772, 57.20852941274643, 50.48865459859371, 45.02718485891819, 46.2579920142889, 51.95797495543957, 53.22492577135563, 54.55144979059696, 44.14264552295208, 28.8129723072052, 26.787715181708336, 19.581819847226143, 24.592303186655045, 35.74648305773735, 30.766149200499058, 26.038473285734653, 27.988864928483963, 37.68205739557743, 35.88855743408203, 31.982279643416405, 30.86264692246914, 55.638244673609734, 71.93483680486679, 43.93692836165428, 39.41883020102978, 46.59776598215103, 42.37087279558182, 43.858143389225006, 38.80935810506344, 43.46724696457386, 40.98500356078148, 39.44520078599453, 32.50627912580967, 33.107558861374855, 37.364538833498955, 26.07349030673504, 28.161689154803753, 45.846154913306236, 45.02828299999237, 31.480862349271774, 36.30134828388691, 47.19400718808174, 44.53142926096916, 46.920015290379524, 46.30379095673561, 43.746691569685936, 44.4630291312933, 43.58642756938934, 45.3677985817194, 44.159850999712944, 48.26026037335396, 50.67938156425953, 48.6181403696537, 50.26268072426319, 51.01495675742626, 54.754469096660614, 53.22122476994991, 55.992058888077736, 52.01625242829323, 50.431828647851944, 52.094292640686035, 52.85967417061329, 54.507778733968735, 53.042364567518234, 53.52212302386761, 50.01458063721657, 45.54612681269646, 46.532451286911964, 48.68333727121353, 47.755411863327026, 50.83877541124821, 51.01906433701515, 50.58201178908348, 50.84153026342392, 52.81721144914627, 49.478345811367035, 49.54298794269562, 50.48046983778477, 52.851113229990005, 50.91442555189133, 54.571603909134865, 51.45796358585358, 53.87317478656769, 58.236982226371765, 60.89499659836292, 64.16892752051353, 70.32316848635674, 68.08310508728027, 68.18655833601952, 37.922440096735954, 5.752039672806859, 47.51582711935043, 49.95087705552578, 49.967482164502144, 32.113000229001045, 24.267730303108692, 39.062074944376945, 63.61164562404156, 49.04339075088501, 52.01244883239269, 65.22691994905472, 5.417917901650071, 0.20248484099283814, 0.10369420924689621, 0.20659359317505732, 0.06188628096424509, 0.08230037012253888, 0.14901140879373997, 0.08922419234295376, 0.19755380402784795, 0.07913770037703216, 0.16856720787473023, 0.3609998960746452, 0.2809117716969922, 0.40847532043699175, 0.49848212976939976, 0.11850603710627183, 0.21010386262787506, 0.379777597845532, 0.30934413196519017, 0.3157107497099787, 0.2704482019180432, 0.19711734697921202, 0.3322112752357498, 0.5254295712802559, 40.878616869449615, 83.2951708137989, 59.897926300764084, 25.43809600174427, 40.30153043568134, 52.28020526468754, 29.278886206448078, 59.94641549885273, 72.38839566707611, 46.7471169680357, 16.57413873821497, 63.82475718855858, 75.42913690209389, 81.30255773663521, 81.4945538341999, 66.99292078614235, 61.53103306889534, 71.3109178841114, 61.07366681098938, 66.53151914477348, 60.400802716612816, 62.4837901443243, 62.101416662335396, 62.80168868601322, 54.22362998127937, 59.26746033132076, 60.179270803928375, 59.531295374035835, 50.31616285443306, 53.54973994195461, 50.28739459812641, 52.85995155572891, 47.235257774591446, 47.83328868448734, 42.91150398552418, 47.50534348189831, 47.04299569129944, 49.75467458367348, 55.99141292273998, 57.42581695318222, 57.89669148623943, 58.265632688999176, 54.229059889912605, 60.07565416395664, 54.61106099188328, 60.69159351289272, 53.982669711112976, 53.66629108786583, 52.1914192289114, 53.4433114528656, 56.34912192821503, 56.074362471699715, 61.6655458509922, 55.491842329502106, 53.29587176442146, 53.1174523383379, 57.497800290584564, 59.83895346522331, 56.92691892385483, 50.51607012748718, 34.273963272571564, 35.321388468146324, 27.864664793014526, 35.8726666867733, 45.201401710510254, 36.847454980015755, 28.672830127179623, 31.394304893910885, 40.46281658113003, 42.856304347515106, 34.518639743328094, 38.60930643975735, 43.97612325847149, 62.72024765610695, 51.00981183350086, 41.74020543694496, 51.32938988506794, 45.79584941267967, 47.19571329653263, 41.54945947229862, 44.26710784435272, 40.96730791032314, 40.59012874960899, 34.90977555513382, 35.29108129441738, 39.446861296892166, 31.19698718190193, 33.66200231015682, 51.60000376403332, 48.56126122176647, 37.50938706099987, 39.20872427523136, 51.921683102846146, 48.43441642820835, 53.561473712325096, 52.27707043290138, 47.78608001768589, 50.072991102933884, 49.67631138861179, 47.95145094394684, 47.545533925294876, 50.23160219192505, 56.66236191987991, 51.5522251278162, 50.633480027318, 54.72749434411526, 56.9832357019186, 55.98280258476734, 56.78181231021881, 52.65451177954674, 54.6952910721302, 52.53212794661522, 58.16813752055168, 56.245797872543335, 59.72237952053547, 57.31004856526852, 55.722539350390434, 46.68110691010952, 49.8840956389904, 53.62290121614933, 48.90305668115616, 51.96089319884777, 52.81599931418896, 53.80588799715042, 54.07542273402214, 56.84798575937748, 52.571433037519455, 52.490311190485954, 52.14731119573116, 57.70863577723503, 55.33581890165806, 62.06793285906315, 57.46093086898327, 57.42189176380634, 62.31308050453663, 64.16745319962502, 69.26840588450432, 74.10312965512276, 78.37040707468987, 72.39952147006989, 48.07105712592602, 7.613676153123379, 46.34495794773102, 57.17110142111778, 55.88488183915615, 29.88205064088106, 37.70009882748127, 51.19903028011322, 69.30126652121544, 47.43814028799534, 55.445192232728004, 75.78275352716446, 5.99596188403666, 0.36422464647330344, 0.4020219901576638, 0.1934646297013387, 0.15579560335027054, 0.22458936815382913, 0.3780022618593648, 0.1297069899737835, 0.32460972375702113, 0.1256509599625133, 0.36563267873134464], [0.07108143501682207, 0.04826360374863725, 0.09679577589849941, 0.042227512603858486, 0.10441627440741286, 0.04398225399199873, 0.1702649300568737, 0.16878628986887634, 0.13133493543136865, 0.1172629397478886, 0.039029264298733324, 0.5127582012210041, 0.07920529518742114, 27.56818190217018, 58.71217332780361, 52.48802751302719, 58.098886236548424, 33.550922870635986, 42.25548438727856, 30.600825771689415, 36.41074821352959, 47.75128908455372, 57.84021891653538, 17.26500816643238, 42.07609601318836, 63.346207067370415, 64.28975343704224, 63.33259239792824, 60.624941289424896, 58.4797739982605, 54.73498374223709, 54.96315389871597, 54.47060152888298, 54.22921948134899, 55.22894583642483, 54.595041051506996, 58.56882601976395, 57.954265996813774, 57.965285405516624, 54.30046185851097, 53.35620492696762, 50.909527614712715, 48.569195196032524, 42.0572604238987, 45.031664818525314, 42.58891649544239, 44.12128306925297, 41.50225840508938, 40.26046223938465, 40.363881289958954, 41.9685085862875, 43.13543736934662, 47.80966155230999, 50.48709288239479, 49.62564870715141, 44.71545338630676, 48.415212258696556, 55.18171437084675, 58.213864266872406, 59.04966741800308, 57.821102142333984, 59.63779225945473, 55.048615112900734, 48.1876614689827, 46.625937670469284, 45.99549449980259, 44.21540401875973, 39.10755470395088, 41.59115083515644, 45.46734184026718, 49.23635199666023, 50.630379393696785, 38.337317034602165, 28.428951613605022, 29.021001644432545, 10.986546166241169, 8.001221157610416, 20.928192101418972, 23.9760522544384, 20.37292029708624, 18.56644593179226, 23.749808594584465, 24.0796821936965, 25.519871413707733, 21.24411854892969, 29.513278529047966, 34.16152350604534, 23.547201566398144, 38.42669203877449, 45.922644808888435, 41.70092694461346, 35.12843482196331, 34.592389985919, 38.117913007736206, 32.11357019841671, 27.92715433984995, 28.731700368225574, 31.91293716430664, 36.40111953020096, 42.2942841053009, 50.940997526049614, 46.797802448272705, 46.01438328623772, 25.173322409391403, 40.77726870775223, 47.13297486305237, 45.93571610748768, 41.50245979428291, 36.52282699942589, 38.55366602540016, 41.86819776892662, 42.46199190616608, 44.44478631019592, 41.221290081739426, 46.38332448899746, 45.142542868852615, 46.84883750975132, 48.32343578338623, 48.130660727620125, 51.63123428821564, 51.395722925662994, 53.32038804888725, 53.55558782815933, 50.52993178367615, 51.41388975083828, 51.99200592935085, 51.853123381733894, 52.941802963614464, 47.510195821523666, 39.54625256359577, 42.33672022819519, 40.74521362781525, 42.95932821929455, 44.73265126347542, 44.84310753643513, 41.92175209522247, 45.777465999126434, 46.937714740633965, 47.51715324819088, 46.84798635542393, 49.49183128774166, 50.467295944690704, 53.004146218299866, 49.25942815840244, 48.83334182202816, 47.65268437564373, 53.627441972494125, 55.975267589092255, 62.573092952370644, 61.41455411911011, 65.2497111260891, 60.71411110460758, 65.23438274860382, 18.437786735594273, 5.873939981684089, 51.0980810970068, 47.172876521945, 40.64320050179958, 16.5061641857028, 29.544412158429623, 27.699502855539322, 58.37102763354778, 31.99055179953575, 42.01714217662811, 59.66350927948952, 4.142882069572806, 0.19880421896232292, 0.10943223533104174, 0.22960264992434531, 0.07889284359407611, 0.04212584208289627, 0.15007959678769112, 0.06314448473858647, 0.3129829710815102, 0.28488650685176253, 0.1193739713926334, 0.05212031886912882, 0.10100799830979668, 0.06767317376215942, 0.03226000917493366, 0.0307504251395585, 0.050066458570654504, 0.08256023313151672, 0.12230857915710658, 0.1544425345491618, 0.1402862457325682, 0.08386745204916224, 0.3929869952844456, 0.11549464674317278, 31.22796881943941, 65.36570370197296, 57.57007621228695, 60.05722135305405, 37.12815351784229, 44.10560131072998, 31.71264611184597, 43.614736050367355, 52.279019728302956, 64.20964613556862, 22.84578200429678, 44.36086021363735, 69.50018584728241, 70.33332914113998, 68.15136462450027, 63.471319153904915, 63.340495973825455, 60.35175494849682, 60.42419046163559, 59.00112882256508, 58.25413450598717, 60.483345687389374, 60.7925920933485, 63.754977732896805, 62.27963089942932, 62.99673981964588, 57.84645818173885, 57.71004930138588, 55.56477561593056, 52.65629768371582, 46.62638984620571, 47.48080439865589, 43.761123195290565, 44.5703961700201, 43.66928972303867, 43.14826928079128, 42.98428528010845, 43.45993995666504, 43.79877917468548, 48.12175780534744, 51.137405186891556, 50.61983875930309, 48.46717067062855, 52.653292044997215, 57.44815595448017, 61.59016169607639, 61.118553802371025, 57.357109040021896, 61.60193346440792, 59.40973609685898, 52.49693043529987, 52.56970793008804, 51.97378970682621, 49.05591867864132, 41.86703883111477, 44.96167257428169, 48.44229340553284, 54.11368288099766, 52.895095869898796, 45.21643750369549, 32.57554940879345, 40.19785299897194, 27.544364780187607, 22.551248408854008, 26.867206916213036, 30.06873082369566, 26.083947345614433, 26.149153746664524, 28.770486786961555, 27.99470141530037, 30.828110575675964, 27.963674180209637, 29.20169524848461, 35.240498408675194, 31.37036807835102, 44.849510192871094, 51.49531938135624, 46.38246573507786, 35.869702845811844, 35.819230154156685, 35.15630252659321, 33.904801681637764, 33.52214701473713, 33.96292336285114, 37.16272406280041, 42.35210180282593, 51.93049483001232, 55.522951260209084, 48.49172495305538, 46.887815818190575, 28.953950442373753, 43.882625475525856, 48.86451914906502, 48.74929793179035, 45.99540330469608, 40.61899200081825, 41.54171548783779, 45.327277556061745, 45.74010640382767, 46.99951462447643, 45.25090545415878, 46.92113243043423, 46.95184998214245, 48.380250334739685, 48.44223640859127, 50.5104274302721, 51.791904866695404, 52.39594325423241, 54.620207101106644, 55.326931178569794, 52.94855140149593, 53.04321192204952, 55.45461192727089, 55.134581699967384, 55.7340033352375, 49.29721713066101, 43.15251745283604, 45.18457621335983, 46.30065232515335, 48.21513019502163, 48.107413575053215, 49.15578491985798, 47.46904782950878, 49.69439461827278, 50.557731091976166, 52.78770983219147, 52.632488161325455, 57.07560874521732, 57.05510504543781, 57.50592805445194, 54.76850934326649, 51.432349160313606, 51.533948108553886, 60.17190679907799, 61.95004418492317, 67.21050471067429, 63.332573398947716, 68.48267644643784, 64.32324483990669, 68.94705712795258, 16.58339124172926, 8.989211842417717, 60.9989058226347, 53.74372713267803, 52.032036781311035, 23.873748444020748, 31.959446668624878, 29.869437217712402, 72.31750667095184, 39.072794169187546, 41.91104806959629, 71.09042331576347, 6.035544835031033, 0.08054538382566534, 0.10378385326475836, 0.13284093118272722, 0.1742743086651899, 0.12872649414930493, 0.12089411247870885, 0.08639460589620285, 0.31202453188598156, 0.13529497606214136, 0.06937099242350087, 0.1666889656917192, 0.2704819547943771, 0.21498400310520083, 0.13028645887970924, 0.22601371281780303, 0.21344685199437663, 0.1841430619242601, 0.2188825493794866, 0.13617354532470927, 0.23553900013212115, 0.233474122651387, 0.420140071073547, 0.26554747426416725, 41.706421449780464, 77.62558624148369, 66.22218534350395, 77.3466432094574, 46.71538487076759, 57.01798863708973, 37.19578608870506, 50.877867713570595, 61.34784869849682, 67.21136346459389, 23.60604140907526, 47.03392177820206, 71.72301337122917, 71.58296048641205, 71.5161980688572, 68.11573773622513, 68.02741527557373, 65.94393387436867, 65.11896014213562, 63.48218657076359, 61.475993022322655, 63.42898942530155, 62.67924405634403, 68.18185418844223, 64.2862044274807, 65.61427876353264, 62.19472825527191, 60.155396685004234, 59.14230264723301, 56.16109661757946, 51.240683645009995, 50.84552004933357, 46.53647527098656, 47.823591604828835, 45.756988897919655, 44.46396008133888, 43.25968310236931, 44.42254990339279, 45.32545365393162, 49.852279946208, 52.34134778380394, 53.286345675587654, 50.85482954978943, 53.96388731896877, 59.683796390891075, 59.48296956717968, 61.13869272172451, 56.976764649152756, 63.285547122359276, 61.30201555788517, 56.582759991288185, 58.35754215717316, 56.62762798368931, 52.49834395945072, 46.455729603767395, 48.722528368234634, 51.701488718390465, 58.349763974547386, 59.339390471577644, 50.148899629712105, 37.05761410295963, 45.03660075366497, 34.99598912894726, 28.527235239744186, 36.0599510371685, 33.6138778924942, 32.87696063518524, 31.308081820607185, 34.2831701785326, 34.89700824022293, 37.27132223546505, 33.59112091362476, 37.97445550560951, 43.0980321764946, 38.55868935585022, 53.541802167892456, 59.26257759332657, 51.41830891370773, 41.082396134734154, 39.046108201146126, 40.24236001074314, 37.28258863091469, 37.578015178442, 39.290731474757195, 42.94098660349846, 50.151498690247536, 53.42210479080677, 58.78164499998093, 50.162784084677696, 49.34717305004597, 33.217604756355286, 48.43803383409977, 53.2009756565094, 53.6971340328455, 50.17520181834698, 43.59417535364628, 45.84059581160545, 50.04378966987133, 47.57953070104122, 51.05526879429817, 47.220275178551674, 52.358006089925766, 52.97815941274166, 52.5839913636446, 50.78333258628845, 53.037219643592834, 54.58614192903042, 53.46788093447685, 57.78242401778698, 56.291855201125145, 54.837221056222916, 57.64788843691349, 59.03995133936405, 59.648800268769264, 58.545955047011375, 53.12230467796326, 44.617202058434486, 48.167902529239655, 48.968584164977074, 52.06661492586136, 50.05390852689743, 50.546479895710945, 47.705699130892754, 53.42248857021332, 53.54463681578636, 55.77414818108082, 55.4547069221735, 58.8624020665884, 59.60660733282566, 62.096150144934654, 58.56361269950867, 57.419064715504646, 54.16519291698933, 63.8998107612133, 64.55507040023804, 72.43518635630608, 67.30017989873886, 73.46781134605408, 67.2389879822731, 77.94062733650208, 25.350941978394985, 9.51546460390091, 64.06743496656418, 63.312096297740936, 51.167564168572426, 23.651348277926445, 44.389632269740105, 41.84667572379112, 78.83839756250381, 42.54674635827541, 56.31351783871651, 85.1152503490448, 10.750880911946297, 0.34799043321982026, 0.3411483363015577, 0.2777558035450056, 0.3462311573093757, 0.17733733024215326, 0.2468326175585389, 0.24117265798849985, 0.49433717562351376, 0.21617317601339892, 0.2803708944702521], [0.08583069240557961, 0.04977385942765977, 0.04464993086003233, 0.014473259161604801, 0.08765783029957674, 0.04624539251381066, 0.02121684061421547, 0.06925561814568937, 0.05774494849902112, 0.09930532600264996, 0.10453507740749046, 0.2828937512822449, 0.09954357024980709, 15.145762134343386, 66.36272460222244, 54.501288682222366, 56.20136305689812, 37.355328127741814, 36.07232317328453, 26.113859340548515, 25.960978344082832, 47.65945941209793, 64.89534974098206, 27.35566310584545, 37.56851568818092, 66.78909212350845, 64.84576240181923, 68.58239069581032, 57.94737696647644, 57.550666853785515, 57.079982310533524, 57.05917842686176, 57.0497777312994, 56.96953743696213, 57.400962486863136, 57.395300790667534, 57.344220131635666, 55.43285429477692, 52.02710464596748, 53.696719855070114, 55.444154888391495, 55.25028929114342, 54.29226189851761, 49.33223985135555, 41.98510989546776, 45.24982251226902, 42.64052152633667, 43.11212562024593, 42.27522812783718, 42.4489776045084, 46.58896945416927, 45.24348445236683, 45.29774934053421, 44.64441999793053, 44.10923771560192, 50.359704717993736, 53.648724630475044, 56.94501355290413, 56.36265680193901, 57.88384057581425, 58.70595306158066, 54.157961905002594, 47.179662957787514, 44.65513542294502, 45.23744657635689, 46.782443672418594, 48.602192625403404, 44.20852638781071, 41.23219549655914, 45.05307286977768, 47.29646489024162, 46.143344566226006, 38.52126136422157, 28.279796317219734, 33.542149141430855, 28.72019838541746, 26.151572316884995, 18.927842639386654, 20.308732241392136, 19.58360195159912, 20.381500236690044, 21.952930614352226, 19.544015675783157, 17.67304167151451, 18.880867660045624, 16.989483051002026, 15.602884255349636, 19.853790253400803, 19.877742268145084, 15.038439743220806, 13.877641931176186, 11.680053602904081, 23.85480836033821, 30.34236554056406, 31.929724663496017, 35.08168213069439, 39.356118366122246, 47.051967009902, 51.46360628306866, 51.58404842019081, 44.74637992680073, 53.55023391544819, 40.39451144635677, 24.670432694256306, 41.09386771917343, 43.5837335139513, 46.61251299083233, 42.36333020031452, 38.86016897857189, 38.24762284755707, 43.01838085055351, 41.57731577754021, 42.69529938697815, 40.97048833966255, 47.374801486730576, 50.31680501997471, 47.216194197535515, 47.539537847042084, 50.897128880023956, 51.358139142394066, 52.15070441365242, 51.94030970335007, 50.24995140731335, 48.185970559716225, 48.99433918297291, 49.92555521428585, 53.72950829565525, 48.319761380553246, 42.76624917984009, 41.958712711930275, 43.12366180121899, 43.00566293299198, 44.851003512740135, 42.77803234755993, 45.494605377316475, 44.30918298661709, 46.807381734251976, 44.41383317112923, 49.10759970545769, 50.54646089673042, 55.440750271081924, 54.75478447973728, 56.61067709326744, 51.93288490176201, 52.72821642458439, 49.556492418050766, 60.35965092480183, 61.98377497494221, 66.53086557984352, 62.04137608408928, 71.09257400035858, 59.943983629345894, 52.15790122747421, 4.3569241091609, 14.580070339143276, 52.13613219559193, 48.89588266611099, 27.038777209818363, 20.941565483808517, 25.357521325349808, 34.723011776804924, 38.31859163939953, 44.05043967068195, 48.28215479850769, 47.22903370857239, 5.9900778997689486, 0.3841473930515349, 0.08979492617072538, 0.25899392436258495, 0.058214208474964835, 0.08169699663994834, 0.05265821637294721, 0.08712840441148728, 0.07991279198904522, 0.0891579408198595, 0.03273033413279336, 0.08280623282189481, 0.011873193016072037, 0.05327231017872691, 0.06349596587824635, 0.12583240022649989, 0.0572672577254707, 0.0881390314316377, 0.03547349748259876, 0.07978630033903755, 0.17744517914252356, 0.11442231014370918, 0.293031043256633, 0.14278606628067791, 20.547239743173122, 72.83269062638283, 62.11305923759937, 64.52555358409882, 40.984160006046295, 41.863493621349335, 27.41822674870491, 29.435758888721466, 53.619937375187874, 72.12391465902328, 33.15239265561104, 39.35137242078781, 69.0775117278099, 71.48230388760567, 70.39886802434921, 64.33927237987518, 60.27402251958847, 61.42794840037823, 61.16491511464119, 63.007162660360336, 61.104688346385956, 62.75489419698715, 60.47447316348553, 59.54657435417175, 59.06947575509548, 55.101071298122406, 55.60881145298481, 58.31675134599209, 56.14405833184719, 58.16696718335152, 51.934245228767395, 45.58867692947388, 46.007589250802994, 43.31501953303814, 45.608090087771416, 44.89488735795021, 43.83571319282055, 47.54362642765045, 46.9333715736866, 48.660599291324615, 47.46634617447853, 47.56183125078678, 52.79283955693245, 56.4513136446476, 58.126662746071815, 58.43424864113331, 59.670797288417816, 60.63595689833164, 57.780945897102356, 54.80997271835804, 48.943486511707306, 46.86154402792454, 48.59732508659363, 50.05746133625507, 47.21559002995491, 42.985033839941025, 48.016233667731285, 51.48152232170105, 52.35559701919556, 48.40464502573013, 29.839990697801113, 37.24028930068016, 41.80456258356571, 37.69494250416756, 31.632821895182133, 27.232620008289814, 25.798603557050228, 25.132119320333004, 25.358005799353123, 23.865523785352707, 22.258909195661545, 21.970694661140442, 23.009076341986656, 20.94092331826687, 24.938280321657658, 24.124844670295715, 19.738466441631317, 16.262032985687256, 14.976399522274733, 27.02978879213333, 34.63259942829609, 36.699164137244225, 39.698069617152214, 45.064989030361176, 51.47212542593479, 56.037781834602356, 54.39183175563812, 48.30956272780895, 54.440043568611145, 40.78739136457443, 27.057132124900818, 45.896764397621155, 46.611000671982765, 49.70304675400257, 43.1309650093317, 40.57475097477436, 41.37051947414875, 47.069943845272064, 45.88204778730869, 46.10333651304245, 46.04348212480545, 48.52553553879261, 50.56306600570679, 50.690267980098724, 49.0150860697031, 53.08438651263714, 52.71248906850815, 55.62532156705856, 53.04751329123974, 55.55639326572418, 51.753454729914665, 54.41054195165634, 53.66126015782356, 54.34452049434185, 50.59006355702877, 45.77835515141487, 44.734577760100365, 47.304904237389565, 46.413950845599174, 49.11855831742287, 47.04147957265377, 51.0374553501606, 50.024646297097206, 49.88051623106003, 48.89149010181427, 54.56037551164627, 56.69272609055042, 59.22554858028889, 58.333744034171104, 58.80228169262409, 53.527807518839836, 53.954908400774, 54.634691923856735, 65.55367961525917, 64.83814761042595, 69.97461318969727, 66.09008923172951, 73.73711049556732, 62.48645760118961, 47.667412385344505, 3.916741479188204, 19.73660074174404, 59.385816380381584, 55.481799468398094, 36.449532732367516, 25.927614234387875, 29.90571767091751, 37.73292526602745, 50.020470321178436, 47.63946108520031, 52.94460341334343, 60.76040402054787, 9.304892253130674, 0.42968358553480357, 0.335662261932157, 0.21969852590700611, 0.14482456783298403, 0.016144324326887727, 0.053025160159450024, 0.06750636865035631, 0.03037000209587859, 0.09639512005378492, 0.038669456262141466, 0.1441653328947723, 0.08870293750078417, 0.18499161873478442, 0.15528494637692347, 0.1899684313684702, 0.14744843094376847, 0.16255324386293069, 0.16448039357783273, 0.22309729509288445, 0.24685544602107257, 0.13893339957576245, 0.44130395574029535, 0.30895120929926634, 25.46145524829626, 85.64843013882637, 67.06734359264374, 78.68833601474762, 55.3038664162159, 50.83363428711891, 35.36258965730667, 34.18466046452522, 59.63538698852062, 73.6514250934124, 35.2273853123188, 42.291335463523865, 76.38738468289375, 76.92948639392853, 80.16244411468506, 68.52980151772499, 65.85107445716858, 64.58236813545227, 64.27007049322128, 65.14665305614471, 63.28680865466595, 64.14432004094124, 65.22530883550644, 64.28297460079193, 63.29669572412968, 58.59726369380951, 58.83483834564686, 61.704068183898926, 59.73714932799339, 60.92708967626095, 54.09051172435284, 45.969009920954704, 48.87759044766426, 45.94238094985485, 47.12330058217049, 46.815201714634895, 44.751334860920906, 50.74616298079491, 47.91672080755234, 50.58564059436321, 49.936088249087334, 49.093749448657036, 54.827307388186455, 57.18212082982063, 59.26819369196892, 59.868728667497635, 62.68137574195862, 64.78234380483627, 64.72761154174805, 59.112337455153465, 57.02761732041836, 53.8652940094471, 50.67859120666981, 51.4216261357069, 49.79932218790054, 46.494369730353355, 53.79606552422047, 56.27312980592251, 59.44502480328083, 51.3480468839407, 40.64180597662926, 45.495532527565956, 50.410219207406044, 44.51522693037987, 38.56920339167118, 34.78211760520935, 32.66180478036404, 33.97539049386978, 32.91021645069122, 31.295348703861237, 29.754804968833923, 28.991733714938164, 29.686136953532696, 29.27460003644228, 35.69706290960312, 33.26777346432209, 30.868755094707012, 23.32156777381897, 21.336594186723232, 34.04291287064552, 40.0817996263504, 42.58865050971508, 44.224705919623375, 50.34062594175339, 54.576585441827774, 55.48949405550957, 60.50858773291111, 52.63604857027531, 58.659781739115715, 46.78636886179447, 32.295094057917595, 48.90024483203888, 49.568598568439484, 51.5708327293396, 49.020869359374046, 43.95104840397835, 42.78774082660675, 51.46593175828457, 51.41714617609978, 51.41303099691868, 47.45309628546238, 50.806598737835884, 54.895832911133766, 52.168768644332886, 51.41832031309605, 51.89759999513626, 54.56020452082157, 56.93676419556141, 56.44126318395138, 57.70855598151684, 54.14191156625748, 56.864590868353844, 54.05776508152485, 58.0541018396616, 53.668266981840134, 49.468869119882584, 48.638894855976105, 48.17746661603451, 47.083695307374, 51.924316361546516, 48.247481659054756, 51.983885765075684, 51.055812165141106, 52.40160495042801, 52.170603945851326, 57.545917108654976, 59.52854812145233, 64.73219409584999, 61.26003921031952, 63.684833496809006, 57.12113410234451, 58.7372861802578, 56.15917772054672, 70.37377417087555, 69.91089060902596, 75.59068143367767, 70.82536473870277, 78.77296507358551, 66.55000135302544, 60.72447694838047, 7.613713201135397, 19.591313637793064, 61.983900368213654, 64.86324146389961, 35.26746176183224, 32.460183799266815, 36.64046488702297, 52.98789069056511, 53.382697105407715, 58.43377746641636, 64.07919153571129, 71.69970542192459, 11.387561447918415, 0.6599347537849098, 0.5681768618524075, 0.3864522959338501, 0.2166920856689103, 0.16652943362714723, 0.21681924525182694, 0.24719926819670945, 0.1847461608122103, 0.24705045274458826, 0.15543705696472898], [0.019324894674355164, 0.017765640550351236, 0.004602432063620654, 0.03995567240053788, 0.04350159091700334, 0.027025320632674266, 0.027257225083303638, 0.02100677756970981, 0.011145866028527962, 0.19851763121550903, 0.10444422368891537, 0.299621433368884, 0.027887998658115976, 15.85801586508751, 72.72089302539825, 32.611715868115425, 34.12104807794094, 38.40971454977989, 27.750057242810726, 21.876112036406994, 25.17086584120989, 38.169054463505745, 69.98838365077972, 35.52977688610554, 23.69951069355011, 56.78170971572399, 62.389285415410995, 59.697498455643654, 59.907737374305725, 53.380527421832085, 54.629425406455994, 57.0333132147789, 54.27366569638252, 56.02481693029404, 55.261924266815186, 57.10720404982567, 54.16695222258568, 54.92216929793358, 55.41143864393234, 56.97934091091156, 56.314992159605026, 56.356675922870636, 56.4237917214632, 55.000688284635544, 49.693239480257034, 43.100654035806656, 44.46479223668575, 44.03802193701267, 45.95602601766586, 44.35070335865021, 44.456193298101425, 42.66930118203163, 46.15900732576847, 47.442563250660896, 49.336229637265205, 53.17634537816048, 53.8559503108263, 53.6660934984684, 55.709813833236694, 54.96188476681709, 53.499491438269615, 50.7743726670742, 46.30833551287651, 45.447237119078636, 46.32325731217861, 46.833938509225845, 49.15321245789528, 46.437661573290825, 41.63417212665081, 40.687886103987694, 45.86933746933937, 42.431703731417656, 42.973550856113434, 20.820686370134354, 23.512895107269287, 30.574878863990307, 26.760846823453903, 34.32543531060219, 27.976768277585506, 20.202786326408386, 16.632558703422546, 16.99273757636547, 14.169752206653357, 16.008181907236576, 16.88967950642109, 14.645082000643015, 13.444262836128473, 9.604127146303654, 6.169712785631418, 3.69791217148304, 7.112966096028686, 12.385015524923801, 22.29899324476719, 30.797024443745613, 35.693491101264954, 34.40641276538372, 48.894503340125084, 54.60831753909588, 55.05205012857914, 48.71764563024044, 47.81710535287857, 52.23675459623337, 29.582307524979115, 24.894537068903446, 44.185628816485405, 44.207204058766365, 46.658661514520645, 39.821597188711166, 39.68027897179127, 41.49365186691284, 43.656112030148506, 40.487819239497185, 44.59542542695999, 46.73129841685295, 50.105011984705925, 49.794272258877754, 49.07954201102257, 50.10166436433792, 51.28911964595318, 51.4386910200119, 49.622263088822365, 50.90832307934761, 51.184765845537186, 50.53270563483238, 50.875903218984604, 49.055109322071075, 47.10465498268604, 42.97056041657925, 43.180324360728264, 41.53235279023647, 43.99078667163849, 45.0985374301672, 44.65229317545891, 45.779430493712425, 47.22125552594662, 47.011966556310654, 51.654017865657806, 51.544914320111275, 55.26295021176338, 55.97801484167576, 58.27840380370617, 55.59216074645519, 56.49245783686638, 53.19455400109291, 50.485063791275024, 56.02165549993515, 62.350352704524994, 63.4082767367363, 67.50389456748962, 67.14409947395325, 66.09588012099266, 47.98607848584652, 24.02822345495224, 1.263186049181968, 26.44951242953539, 57.78600722551346, 41.932961493730545, 14.79769416153431, 26.20230719447136, 24.661168791353703, 35.298046320676804, 29.913655444979668, 37.046347707509995, 55.894035547971725, 56.86587139964104, 7.725492753088474, 0.17215240455698222, 0.08135148978908546, 0.08409339890931733, 0.07740834043943323, 0.062202343106037006, 0.04438809002749622, 0.027245814562775195, 0.04238768662617076, 0.060014617920387536, 0.08541653689462692, 0.07141107475035824, 0.03055704557482386, 0.024637273090775125, 0.00323266169289127, 0.08956100122304633, 0.013547034741350217, 0.031870403909124434, 0.051984413075842895, 0.04930910799885169, 0.19217844324884936, 0.05767967661086004, 0.34426687052473426, 0.16314942593453452, 20.279996283352375, 78.29353719949722, 38.34374628961086, 37.875303626060486, 39.11827392876148, 33.52783530950546, 22.854664027690887, 28.153739981353283, 41.77242390811443, 73.26994076371193, 41.58883295953274, 24.44632261991501, 59.48634758591652, 66.7626379430294, 64.50280800461769, 64.79693502187729, 57.626746371388435, 57.28847332298756, 60.95313347876072, 57.23155617713928, 57.6656486839056, 57.94722497463226, 57.934526056051254, 57.87439428269863, 57.00619786977768, 56.875002309679985, 59.64153125882149, 59.814611971378326, 58.45072455704212, 58.80572430789471, 57.47453033924103, 53.406852409243584, 45.80925889313221, 48.27378384768963, 47.01733186841011, 47.885847464203835, 45.75662411749363, 46.400495767593384, 45.12369588017464, 46.44239991903305, 48.17992888391018, 51.80350944399834, 57.378357499837875, 57.80706189572811, 55.736552998423576, 57.91112691164017, 57.23896957933903, 56.57954916357994, 52.786832079291344, 50.18187806010246, 48.10274362564087, 49.546236768364906, 50.14092765748501, 51.641976311802864, 48.71155835688114, 44.75279398262501, 45.58941788971424, 51.47732354700565, 48.487655371427536, 49.20066811144352, 29.808154106140137, 29.579733163118362, 41.24016746878624, 31.971594616770744, 40.36886282265186, 37.92973950505257, 24.62937969714403, 21.03989850729704, 25.992955528199673, 22.538089714944363, 21.21221736073494, 23.711700439453125, 24.808395691215992, 20.813833437860012, 14.680289961397648, 12.152961026877165, 5.900638299062848, 10.601057801395655, 16.453745998442173, 24.49594795703888, 32.05779679119587, 38.527686819434166, 39.53252770006657, 54.48045440018177, 60.029368847608566, 56.77294358611107, 52.56077080965042, 49.33978244662285, 55.29636561870575, 32.65700563788414, 30.144401863217354, 49.395749643445015, 46.556017622351646, 49.18284706771374, 44.151757434010506, 44.64712165296078, 44.07688245177269, 46.87507130205631, 44.28206004202366, 45.393211618065834, 49.22448143362999, 51.85935504734516, 52.0547291636467, 51.88692256808281, 52.70423971116543, 54.362197145819664, 54.4972039014101, 53.856090903282166, 55.705827847123146, 54.456945061683655, 53.51643852889538, 52.540210112929344, 49.67123486101627, 47.51345984637737, 45.01449353992939, 44.53577242791653, 44.40080747008324, 46.07599318027496, 48.92321079969406, 48.41463848948479, 50.26686429977417, 52.76233859360218, 51.23171992599964, 56.471213176846504, 56.63315288722515, 57.78382994234562, 59.60489362478256, 59.8682726919651, 61.52124859392643, 59.69279810786247, 54.63854871690273, 52.541068866848946, 58.55150654911995, 66.32004529237747, 66.52933806180954, 70.06164371967316, 71.74329668283463, 66.43945768475533, 46.59278444945812, 20.064091868698597, 1.6359067428857088, 34.19340759515762, 61.568898037075996, 49.69395384192467, 18.0980621650815, 29.12011742591858, 29.20302327722311, 40.210669711232185, 41.85097709298134, 42.100992277264595, 60.79082518815994, 69.36800613999367, 10.457409359514713, 0.19908736314391717, 0.08898349158698693, 0.19760424038395286, 0.04244594892952591, 0.03595054629840888, 0.1241683418629691, 0.03992738544184249, 0.027408756795921363, 0.08139345081872307, 0.07675984437810257, 0.28380680072586983, 0.13038470438914374, 0.0939539291721303, 0.11898785422090441, 0.20260302058886737, 0.13789736141916364, 0.11473244623630308, 0.15608998364768922, 0.1014322173432447, 0.34175288979895413, 0.15700101444963366, 0.3699015418533236, 0.24361929623410106, 24.142053946852684, 93.05142849683762, 43.72588388621807, 46.47773042321205, 56.91450498998165, 38.757209703326225, 26.785049624741077, 31.548280231654644, 50.847606137394905, 80.58115124702454, 43.45553979277611, 29.217622093856335, 63.9125020802021, 70.32868579030037, 67.7500681579113, 69.62042659521103, 61.20996169745922, 62.02258609235287, 65.88952079415321, 60.042204558849335, 63.05327318608761, 61.221866458654404, 61.56168222427368, 61.54372438788414, 58.5035265237093, 59.97435919940472, 62.0375344902277, 60.95597952604294, 61.09904184937477, 60.27067109942436, 59.35634896159172, 54.24791447818279, 47.8665255010128, 50.72843313217163, 47.56101809442043, 51.19528368115425, 48.372798934578896, 50.468926057219505, 49.13094945251942, 50.870914086699486, 52.35288396477699, 53.10029625892639, 59.75820019841194, 58.89844313263893, 57.86430962383747, 59.88240413367748, 61.469176188111305, 60.78733317553997, 54.74175117909908, 52.58019536733627, 52.09064103662968, 51.594718247652054, 52.357713505625725, 56.394499093294144, 52.91695609688759, 49.021443128585815, 49.163327515125275, 54.827907755970955, 54.915287867188454, 54.35910411179066, 34.92865674197674, 39.48696434497833, 47.079496532678604, 42.35935181379318, 48.59814964234829, 43.01899641752243, 34.34255339205265, 31.41594473272562, 35.89714877307415, 31.16630382835865, 30.169305726885796, 32.245202735066414, 33.648429438471794, 29.0785875543952, 25.347227677702904, 20.924559496343136, 11.61893293261528, 15.276864599436522, 23.51288940757513, 32.184337601065636, 36.93510487675667, 46.09854497015476, 43.035875111818314, 59.04663138091564, 63.305116072297096, 63.17063368856907, 55.83030916750431, 51.4850827306509, 59.63256374001503, 37.29664787650108, 34.603439792990685, 54.34650778770447, 51.04189731180668, 52.997036799788475, 48.62418204545975, 47.148664221167564, 48.02037924528122, 50.65263859927654, 50.21905526518822, 49.59412559866905, 53.36405910551548, 54.61152836680412, 55.01097813248634, 54.59309555590153, 53.471638932824135, 55.553634613752365, 57.449007108807564, 56.26822046935558, 56.429453417658806, 56.2961869686842, 56.0947597771883, 56.29744470119476, 52.717580795288086, 51.12944081425667, 47.260340228676796, 49.28056262433529, 46.9326838105917, 48.41296657919884, 51.75396390259266, 51.30535617470741, 53.06252248585224, 54.12622220814228, 54.988924115896225, 60.75081333518028, 59.40611109137535, 60.44806458055973, 62.501208409667015, 61.07412278652191, 62.716531455516815, 63.5244745016098, 60.25751240551472, 57.80762806534767, 64.21822607517242, 69.38043147325516, 71.16303741931915, 75.92570185661316, 74.09362256526947, 74.00441855192184, 54.36361826956272, 29.098599180579185, 2.9127199295908213, 31.832210496068, 69.75775882601738, 57.168642953038216, 20.1821743324399, 36.40084594488144, 34.21557940542698, 54.831046387553215, 47.98548571765423, 50.67177437245846, 71.09069690108299, 80.20712211728096, 15.294716041535139, 0.4189162695547566, 0.27848097088281065, 0.26837467099539936, 0.20678704138845205, 0.15702511940617114, 0.24775522586423904, 0.15887621382717043, 0.1651516364654526, 0.16722791333450004, 0.13843062421074137], [0.07127696866518818, 0.04547826414636802, 0.11032305745175108, 0.03396103020349983, 0.06069279617804568, 0.05820513943035621, 0.012552138468890917, 0.09815890080062672, 0.04249810335750226, 0.07919172872789204, 0.14899140049237758, 0.38272478501312435, 0.1372393881320022, 20.266524106264114, 68.59700471162796, 38.5918577760458, 39.169031605124474, 38.16753074526787, 35.68819038569927, 22.22406506538391, 19.614323303103447, 30.119262412190437, 61.21572218835354, 44.764805138111115, 14.113346133381128, 44.25420753657818, 67.56893187761307, 60.60826778411865, 60.964893847703934, 51.39766462147236, 52.61002756655216, 49.93744097650051, 52.33744919300079, 52.428860887885094, 54.08462584018707, 53.2585159689188, 51.38635262846947, 51.755495220422745, 51.44847549498081, 53.30399952828884, 57.20804303884506, 58.68628911674023, 57.4176511913538, 55.19147224724293, 51.55195154249668, 46.2540440261364, 44.04699705541134, 45.779403895139694, 44.72979761660099, 45.756817907094955, 43.16082000732422, 42.86104269325733, 43.39757390320301, 43.180043175816536, 46.32745988667011, 55.292322635650635, 56.44898056983948, 56.42229080200195, 54.19657543301582, 54.434127286076546, 54.23317886888981, 49.7835910320282, 50.43370574712753, 43.813423588871956, 47.00465954840183, 47.420824617147446, 48.757155910134315, 46.07132323086262, 41.94269277155399, 40.25583788752556, 45.780597031116486, 42.91151538491249, 39.8459804803133, 27.393370382487774, 21.111583560705185, 33.82408641278744, 30.88684782385826, 29.351728297770023, 36.03237211704254, 15.551289673894644, 8.77802012488246, 19.43785697221756, 15.310307554900646, 10.08354077115655, 8.934251591563225, 9.708739332854748, 8.570326119661331, 9.26334623247385, 6.159269046038389, 0.8235509460791945, 5.277458438649774, 9.040531888604164, 14.83186287805438, 16.36189352720976, 24.08281322568655, 20.26378635317087, 37.6153139770031, 46.95336990058422, 46.644408479332924, 45.09564958512783, 42.04022213816643, 45.98387852311134, 21.491274386644363, 27.409373223781586, 44.524829015135765, 43.354932591319084, 46.79472081363201, 40.060038194060326, 38.82723614573479, 40.34348018467426, 44.27739389240742, 41.67724281549454, 43.53292264044285, 45.92505767941475, 48.541129902005196, 49.15739983320236, 49.22098942101002, 49.059748873114586, 50.357215851545334, 53.805401623249054, 51.4849117398262, 47.876416370272636, 49.370640590786934, 47.71956458687782, 45.23543268442154, 42.65936091542244, 40.68339854478836, 42.45778173208237, 42.88283072412014, 43.471023961901665, 44.34759132564068, 46.50076098740101, 48.22945162653923, 51.70088455080986, 48.44920143485069, 52.88070224225521, 53.572208136320114, 53.56381058692932, 53.15793916583061, 54.74813483655453, 54.201002195477486, 56.766996905207634, 53.87364976108074, 52.32080988585949, 50.531257912516594, 54.41915228962898, 61.77325867116451, 65.69104224443436, 62.368283942341805, 69.31286349892616, 50.12407936155796, 31.60178516060114, 8.362877201288939, 2.3785206070169806, 39.70638357102871, 51.944405883550644, 30.16899984329939, 18.68865877389908, 30.663423612713814, 26.90788183361292, 36.435245499014854, 35.49404360353947, 52.66342990100384, 32.827681079506874, 57.89080560207367, 5.028147641569376, 0.17292296164669096, 0.10050375349237584, 0.09274203912355006, 0.16536181268747896, 0.07718669803580269, 0.10634917576680891, 0.08459949909592979, 0.0949507522454951, 0.07176818879088387, 0.09469458513194695, 0.03730361881025601, 0.042077053294633515, 0.06770591731765307, 0.034035040880553424, 0.061619478874490596, 0.08611758443294093, 0.033148597431136295, 0.08171260400558822, 0.03657924557046499, 0.09306057632784359, 0.13739952875766903, 0.4351073788711801, 0.11984841898083687, 26.74794841557741, 75.14377221465111, 43.600114434957504, 36.462524235248566, 37.53940925002098, 38.95571485161781, 23.22690535336733, 23.44589900225401, 33.25093276798725, 62.9153785854578, 50.7914337515831, 15.05483016371727, 41.05243854224682, 69.22071844339371, 64.0623052418232, 65.09708851575851, 57.60512933135033, 55.99320262670517, 54.875929579138756, 56.07858024537563, 55.66798187792301, 56.54613375663757, 57.221448719501495, 56.960060745477676, 53.449102342128754, 54.48472537100315, 55.57971641421318, 59.1492410749197, 62.38854445517063, 61.294963136315346, 60.34577786922455, 55.31818404793739, 49.21255387365818, 47.96649053692818, 48.09009410440922, 47.599187046289444, 45.458066537976265, 45.16757972538471, 45.9865003824234, 45.81822641193867, 46.847435384988785, 50.882017090916634, 57.86001965403557, 57.714829444885254, 57.675786539912224, 56.61022111773491, 58.83532851934433, 56.20243459939957, 52.47915878891945, 51.782488971948624, 46.90538227558136, 47.41453975439072, 49.51339893043041, 53.0668580532074, 49.07962180674076, 46.374744549393654, 43.9469750225544, 49.79715630412102, 47.013193890452385, 48.13281141221523, 33.52116286754608, 27.152966782450676, 40.56524008512497, 40.292167738080025, 35.03133103251457, 41.509869396686554, 25.076028630137444, 14.748855382204056, 26.71430692076683, 24.14020534604788, 19.54780787229538, 22.45621170848608, 22.98420287668705, 19.420417807996273, 17.409596107900143, 12.9663054831326, 15.075541902333498, 20.489840023219585, 19.838376380503178, 20.537700355052948, 18.693096935749054, 25.478284545242786, 22.711252123117447, 42.31962114572525, 50.51827780902386, 49.85590495169163, 49.77929346263409, 46.449976712465286, 49.85421784222126, 27.74005237966776, 32.41867482662201, 48.52566473186016, 48.56306992471218, 49.04740333557129, 44.33861240744591, 41.978308260440826, 44.01858597993851, 47.07324966788292, 45.311276614665985, 46.2939190864563, 48.196663185954094, 51.23798958957195, 51.12162843346596, 53.429723381996155, 53.1961727142334, 54.708236977458, 55.411054864525795, 52.61858090758324, 49.656134471297264, 51.1175474524498, 48.68118278682232, 47.21687816083431, 44.43078026175499, 44.508425295352936, 46.73467643558979, 45.408433601260185, 45.60870185494423, 47.425376772880554, 48.276071324944496, 51.90683349967003, 53.802855759859085, 54.88435372710228, 56.003351882100105, 57.236522510647774, 57.06651583313942, 56.343665421009064, 58.357393965125084, 57.07508057355881, 61.884531900286674, 56.78216189146042, 54.67808939516544, 55.54624401032925, 59.01124767959118, 63.05923506617546, 66.72398641705513, 65.82755371928215, 72.46923252940178, 51.63724556565285, 29.735272116959095, 7.054394138976932, 3.762807701714337, 46.23596839606762, 53.33562523126602, 35.84794521331787, 21.131209507584572, 33.61535981297493, 30.218252800405025, 42.88625814020634, 45.174415558576584, 58.222691193223, 39.53723564743996, 65.12380108237267, 6.30739982239902, 0.2825885801576078, 0.10005958552937955, 0.1253702351823449, 0.20852277637459338, 0.04173670065938495, 0.14095355523750186, 0.0742657903174404, 0.11521095337229781, 0.04697641168604605, 0.10881184440222569, 0.11490721459267661, 0.10947441900498234, 0.24906220729462802, 0.16342445102054626, 0.09394141656230204, 0.21242742310278118, 0.100823700777255, 0.15897086734184995, 0.1305556803708896, 0.23113828705390915, 0.26840643491595984, 0.4064700671005994, 0.2908657828811556, 30.26178516447544, 85.08521676063538, 50.06076715886593, 52.679351046681404, 56.41714207828045, 51.232495084404945, 30.067740976810455, 25.638637840747833, 39.44446362555027, 73.09810638427734, 51.5638031065464, 17.21291296184063, 48.47172662615776, 73.5841079056263, 68.0234482884407, 67.98980489373207, 58.02217595279217, 61.1674115806818, 58.57522867619991, 61.71560816466808, 60.383411049842834, 59.8091022670269, 59.84793618321419, 57.21099928021431, 56.54266074299812, 58.90154756605625, 59.76370610296726, 63.27049233019352, 64.60581287741661, 60.72217807173729, 60.87464489042759, 58.638138100504875, 51.35335519909859, 50.302669778466225, 50.65956562757492, 49.89187382161617, 48.92630383372307, 48.124588653445244, 49.4391281157732, 47.38703303039074, 48.12616176903248, 51.79419234395027, 59.939895048737526, 59.692345932126045, 60.646687522530556, 59.201423674821854, 60.285216718912125, 59.81400020420551, 56.36415012180805, 56.62241846323013, 50.43972462415695, 53.02999623119831, 51.28348834812641, 55.65280169248581, 52.16503344476223, 49.501429572701454, 45.83327740430832, 53.023156598210335, 53.91471415758133, 52.26183325052261, 39.44622293114662, 37.68447406589985, 48.58695164322853, 45.9921582788229, 43.177641704678535, 49.623087644577026, 30.718758143484592, 25.053495839238167, 34.561490043997765, 35.04836171865463, 25.310550145804882, 25.822116695344448, 31.425372026860714, 27.40823708474636, 30.192816965281963, 24.8164626583457, 26.152539364993572, 30.612470246851444, 26.629381477832794, 25.757799446582794, 24.089274778962135, 32.2776035964489, 28.284764550626278, 46.86951979994774, 55.33236488699913, 52.49435417354107, 52.931197732687, 46.57304830849171, 55.631462037563324, 32.83917546272278, 40.55456265807152, 52.96948067843914, 54.1827479749918, 54.37720254063606, 49.73830506205559, 44.149321764707565, 47.756783589720726, 49.70844246447086, 48.018642738461494, 49.41443704068661, 51.30926236510277, 55.092160776257515, 52.966953814029694, 55.23538649082184, 54.724173322319984, 57.167047038674355, 60.977079793810844, 55.975541174411774, 52.57380411028862, 56.07476904988289, 52.64121249318123, 50.14549881219864, 47.17062704265118, 47.76706963777542, 49.30284462869167, 48.56530800461769, 48.811059817671776, 50.125926062464714, 51.40399508178234, 56.218572333455086, 58.27310688793659, 56.23003251850605, 59.76383149623871, 59.11659322679043, 60.678997188806534, 59.455223456025124, 60.65592862665653, 61.533540934324265, 64.80909436941147, 60.41234649717808, 59.3128564953804, 56.19221694767475, 59.186881855130196, 66.49678900837898, 71.00566506385803, 67.10009023547173, 75.91168820858002, 59.653610810637474, 38.71169574558735, 12.131637521088123, 3.635071855969727, 47.8890734910965, 61.304626017808914, 41.609222665429115, 24.28781982511282, 40.9379468858242, 36.85327246785164, 55.364457964897156, 55.620632618665695, 72.70128607749939, 42.464298382401466, 81.32976427674294, 11.447589676827192, 0.3645262256031856, 0.3078610240481794, 0.13748371799010783, 0.4361819790210575, 0.24653639673488215, 0.3198948595672846, 0.16005043988116086, 0.2248559772851877, 0.15546614915365353, 0.3180904610780999], [0.03208180467481725, 0.07939572285977192, 0.21062272775452584, 0.02087530981953023, 0.02400730660156114, 0.08957540630945005, 0.05923937787883915, 0.062076474860077724, 0.04316943901358172, 0.15945148217724636, 0.0486372676823521, 0.31776418327353895, 0.11833327254862525, 30.752359740436077, 66.13510921597481, 35.27788460254669, 35.74287325143814, 42.85812824964523, 37.16859094798565, 23.911125138401985, 15.210986584424973, 28.67472432553768, 50.70505678653717, 60.59919387102127, 14.862148202955723, 26.199132464826107, 70.0838041305542, 60.300001725554466, 62.11502753198147, 57.133814021945, 52.36984625458717, 49.51308734714985, 51.94387011229992, 49.58285540342331, 54.56583581864834, 50.88984467089176, 49.97869536280632, 48.72348211705685, 49.65126313269138, 51.75033889710903, 55.663942694664, 57.70130977034569, 60.16639329493046, 58.19874107837677, 54.54111434519291, 46.6665118932724, 45.563909858465195, 45.05889795720577, 47.13916473090649, 45.74704483151436, 45.46327605843544, 41.52499258518219, 42.09114320576191, 43.05725656449795, 46.647315323352814, 52.87451237440109, 52.44537480175495, 54.3952439725399, 52.74251125752926, 54.042919278144836, 51.54343619942665, 50.494137704372406, 49.151407554745674, 46.5774142742157, 46.12787939608097, 48.22920083999634, 49.61513087153435, 44.323173835873604, 42.85037286579609, 42.265489250421524, 45.40974833071232, 43.24301719665527, 40.78961044549942, 31.074012480676174, 19.624326266348362, 26.46196436136961, 32.63501241803169, 29.999270550906658, 29.712066762149334, 22.852475345134735, 10.929834209382534, 12.184803318232298, 7.3139396868646145, 2.61096125934273, 1.8100008135661483, 2.146985256113112, 3.5386997647583485, 2.3067160975188017, 0.48105935216881335, 3.4528884943574667, 8.805527798831463, 2.3102947929874063, 4.136178754270077, 6.752868443727493, 7.3775876965373755, 11.85743948444724, 30.02972971647978, 38.50572019815445, 38.627021089196205, 35.708386301994324, 36.26419007778168, 27.24600289016962, 19.05338980257511, 33.23280394077301, 45.67011035978794, 44.54801917076111, 46.07392989099026, 41.98879189789295, 37.50271461904049, 39.968900084495544, 42.84397780895233, 43.34216147661209, 42.4712748080492, 48.30825559794903, 51.74347646534443, 49.308095946908, 51.608139127492905, 51.9558584690094, 48.2928816229105, 47.87096746265888, 46.6071704775095, 42.83959284424782, 42.82951198518276, 42.81971991062164, 42.269950211048126, 41.19616962969303, 41.887006759643555, 42.20138669013977, 42.83602863550186, 43.13658870756626, 46.64888843894005, 46.95872761309147, 49.256205931305885, 51.934921592473984, 51.90707288682461, 53.101174011826515, 52.300773561000824, 53.927933648228645, 55.339607298374176, 53.143518939614296, 52.421204298734665, 55.18285050988197, 51.643975004553795, 51.636652797460556, 54.52879540622234, 58.89604926109314, 61.04930251836777, 64.70002502202988, 64.24458906054497, 66.14712417125702, 34.17587913572788, 15.31823867931962, 2.107504424639046, 6.991421543061733, 54.10173252224922, 44.592754170298576, 24.177884124219418, 15.159877426922321, 32.68610067665577, 32.49278984963894, 38.86825494468212, 34.39931094646454, 49.36828471720219, 36.65357418358326, 55.97982734441757, 5.469260746613145, 0.17651283385930583, 0.03980179550126195, 0.052595760935219005, 0.15596654964610934, 0.09369456340209581, 0.043378861955716275, 0.05735399994591717, 0.09455232284381054, 0.045429234160110354, 0.05047362676123157, 0.03517734345223289, 0.09245974841178395, 0.04971629474312067, 0.09348523322842084, 0.042762211451190524, 0.12752132053719833, 0.04286054230760783, 0.0484043965843739, 0.09590185902197845, 0.17775385320419446, 0.1256957114674151, 0.2048209437634796, 0.10547830257564783, 36.70016348361969, 73.8621161878109, 37.60248966515064, 38.61611187458038, 44.832327514886856, 39.3992954492569, 28.12915340065956, 22.219847291707993, 33.677756264805794, 56.769725158810616, 64.21425148844719, 18.73685348778963, 23.94822634756565, 69.48600500822067, 64.49623435735703, 66.52318999171257, 62.93470814824104, 58.68443101644516, 51.75054028630257, 52.99210466444492, 52.59841538965702, 57.075935527682304, 53.797437250614166, 53.74366253614426, 53.307005167007446, 53.62137369811535, 54.09961223602295, 58.98324318230152, 57.74970777332783, 60.41076198220253, 60.390493869781494, 56.38937696814537, 48.27415622770786, 48.32724317908287, 47.57220469415188, 50.044420436024666, 47.72788614034653, 47.516351491212845, 44.90601696074009, 44.513106644153595, 45.58696322143078, 48.204304575920105, 56.366004422307014, 56.031477972865105, 57.571341544389725, 55.47093965113163, 56.22208334505558, 54.94485408067703, 54.4795386493206, 50.27989000082016, 48.29516150057316, 49.58086811006069, 51.15515023469925, 53.53732220828533, 49.85066503286362, 46.86047628521919, 48.11464458703995, 47.86355026066303, 45.97618393599987, 47.42509938776493, 39.210460782051086, 26.06559243053198, 36.297236904501915, 39.288922771811485, 39.88047502934933, 38.54751035571098, 32.97997310757637, 19.774268120527267, 16.107369884848595, 14.763994719833136, 7.2966221161186695, 6.315612606704235, 7.312042163684964, 6.1672471929341555, 8.485117591917515, 5.192789006978273, 16.03162854909897, 20.791883915662766, 6.802110951393843, 9.22210419550538, 8.481554333120584, 10.81223526969552, 14.634730406105518, 38.21571595966816, 45.10631941258907, 45.57760052382946, 42.37366184592247, 39.53329525887966, 29.235914312303066, 23.990736566483974, 38.9864058047533, 48.632317408919334, 47.408946454524994, 50.401620268821716, 45.435427352786064, 41.48571789264679, 45.13365134596825, 46.51458464562893, 48.02123799920082, 47.541536539793015, 51.00338637828827, 53.74883785843849, 51.68201856315136, 53.023749366402626, 54.3389917910099, 49.84957069158554, 49.925817400217056, 48.061956614255905, 46.074176877737045, 45.21897956728935, 46.12312205135822, 45.23959346115589, 45.00147543847561, 43.94763618707657, 46.46279342472553, 45.68933732807636, 47.33677692711353, 48.16893607378006, 50.86359187960625, 54.06867429614067, 55.158421620726585, 53.67977276444435, 57.26057521998882, 56.27398855984211, 57.465156242251396, 59.324453473091125, 57.83939816057682, 56.762642338871956, 57.0478056371212, 53.3259167522192, 54.15849767625332, 57.290794998407364, 62.509157583117485, 64.49274614453316, 67.98987329006195, 67.0306071639061, 67.61815443634987, 34.9773283302784, 15.432913675904274, 1.3969451654702425, 9.330492429435253, 61.68442323803902, 47.24880404770374, 30.312759429216385, 14.243345707654953, 33.09988707304001, 29.0274802967906, 41.979892775416374, 33.55409950017929, 48.030836284160614, 41.36667028069496, 68.01172211766243, 11.052072700113058, 0.37982990441378206, 0.05315787100698799, 0.19201497780159116, 0.05252981740341056, 0.029479773693310563, 0.06543800307554193, 0.06252637962461449, 0.12093774334061891, 0.09847918947343715, 0.056414121863781475, 0.16674087150022388, 0.29601717833429575, 0.44385551882442087, 0.14464489388046786, 0.09168683129246347, 0.2681923104682937, 0.10454208328155801, 0.12940872082253918, 0.14494248025584966, 0.24324428901309147, 0.15911088092252612, 0.4138217226136476, 0.3194016282213852, 44.1339173913002, 84.5684976875782, 45.439424738287926, 48.31085465848446, 62.01187826693058, 54.00470472872257, 30.830012373626232, 19.293839000165462, 36.972764655947685, 63.380466029047966, 71.83392941951752, 20.195025242865086, 29.99409332871437, 77.53062933683395, 66.63664430379868, 70.75283423066139, 65.63075467944145, 61.14026963710785, 56.01422309875488, 59.77700538933277, 57.64116659760475, 63.5315877199173, 57.94814072549343, 59.68144811689854, 55.894499123096466, 54.91243042051792, 59.17386755347252, 61.173932030797005, 61.62819765508175, 65.18220394849777, 62.63846464455128, 59.73779909312725, 53.32022465765476, 51.244346648454666, 50.03607988357544, 52.436133697628975, 49.20004114508629, 50.78908547759056, 46.203806921839714, 47.25330300629139, 47.44688741862774, 51.32668823003769, 57.00452595949173, 56.91901534795761, 60.152714028954506, 59.15658228099346, 57.62287437915802, 57.02116146683693, 55.5703879147768, 52.762281596660614, 50.03149352967739, 51.44892007112503, 53.26725549995899, 55.478360652923584, 51.47548444569111, 49.09130997955799, 52.34592653810978, 53.057730942964554, 53.18087853491306, 52.13194102048874, 44.06641401350498, 35.572471395134926, 41.462432742118835, 46.14975102245808, 44.5804276317358, 45.34484401345253, 39.10255417227745, 24.6193615347147, 25.191399939358234, 12.43764080107212, 6.4184122905135155, 4.110753843560815, 5.474498765543103, 8.293615467846394, 10.415790192782879, 8.504943028092384, 23.3961558714509, 27.329512909054756, 8.36577644571662, 9.927771929651499, 8.440529834479094, 11.195852234959602, 19.97529823333025, 48.880664482712746, 47.13217690587044, 53.756293058395386, 47.610635831952095, 45.461034178733826, 34.912549406290054, 26.61312784999609, 43.864086270332336, 53.614613860845566, 51.19786374270916, 53.76643851399422, 50.411241352558136, 44.40904922783375, 46.974090188741684, 47.59702876210213, 51.0970551520586, 48.27514037489891, 55.718868747353554, 55.70441052317619, 54.70677025616169, 56.05091392993927, 57.3310424387455, 52.92360574007034, 52.90149472653866, 52.53195695579052, 49.96095031499863, 48.21862980723381, 48.297019600868225, 47.384791150689125, 44.81055088341236, 46.3091866672039, 49.41420905292034, 49.22147199511528, 49.39885787665844, 50.04017226397991, 52.70376853644848, 56.55477449297905, 58.55044640600681, 57.0244786888361, 60.78080892562866, 59.80840690433979, 58.60004894435406, 62.88614675402641, 60.65465569496155, 57.96637214720249, 62.203065007925034, 58.032420203089714, 55.15584155917168, 59.321383237838745, 59.992073848843575, 68.77542793750763, 72.44983837008476, 72.31663271784782, 68.83480355143547, 42.88177818059921, 20.83237074315548, 3.2071580551564693, 8.513237033039331, 63.31926651299, 57.66760937869549, 36.16320289671421, 21.065507233142853, 45.135623440146446, 43.77760291099548, 58.12593698501587, 50.51954314112663, 67.4333019554615, 51.83820158243179, 75.92658340930939, 13.856701254844666, 0.6093502056319267, 0.33473730843979865, 0.26636677561327815, 0.34507322881836444, 0.30473937280476093, 0.14909113029716536, 0.17906493128975853, 0.21857233165064827, 0.27145838364958763, 0.1645015596295707], [0.02162089920602739, 0.08407650020672008, 0.04607018257956952, 0.17647357424721122, 0.05055943758634385, 0.06126042040705215, 0.09322667639935389, 0.1541475605336018, 0.07385409131529741, 0.1789616243331693, 0.03470301460765768, 0.2611305675236508, 0.15186545642791316, 25.93896422535181, 64.45014283061028, 45.38314215838909, 32.90688782930374, 45.22352412343025, 42.79307574033737, 24.943799525499344, 15.746870879083872, 19.850944206118584, 42.184515595436096, 62.02446699142456, 25.891639664769173, 9.006550312042236, 54.153280556201935, 67.12358817458153, 66.96824491024017, 60.34142330288887, 53.80970299243927, 46.74748934805393, 46.931000500917435, 47.11123622953892, 51.848510429263115, 47.23841540515423, 49.64983440935612, 45.45138269662857, 49.10593159496784, 50.23575156927109, 56.25954933464527, 56.04892663657665, 58.25015611946583, 57.124428525567055, 56.462492644786835, 46.04282855987549, 47.89719745516777, 46.469963639974594, 47.41028018295765, 44.490923434495926, 46.40417397022247, 42.105673626065254, 42.45370835065842, 43.17541502416134, 44.28058572113514, 53.94439436495304, 53.40228125452995, 55.344452038407326, 55.06648935377598, 54.90843303501606, 54.607637375593185, 50.061534717679024, 47.63995125889778, 47.01800063252449, 49.43617187440395, 50.74310414493084, 48.225819021463394, 49.34254489839077, 43.85701484978199, 42.151164785027504, 45.8377231657505, 42.56706386804581, 40.1366762816906, 32.085816487669945, 21.534588262438774, 27.321016564965248, 32.71198868751526, 29.106453359127045, 27.59866576641798, 19.40900892019272, 26.942537873983383, 2.836426910944283, 1.2236061855219305, 0.6832815916277468, 0.5604423768818378, 0.2113836517673917, 0.11912115878658369, 0.22271830996032804, 0.14621002395870164, 0.11808563271188177, 0.5093630834016949, 1.2902409536764026, 0.4243427939945832, 0.030378028423001524, 0.7921141048427671, 5.684397602453828, 19.554731100797653, 28.01102913916111, 27.491693906486034, 24.256790690124035, 28.70715368539095, 23.014682941138744, 17.4773882701993, 40.33834666013718, 43.79864238202572, 45.889844968914986, 44.56873185932636, 43.81119690835476, 38.1682451069355, 43.91791418194771, 44.60218906402588, 41.89586788415909, 43.2516123354435, 46.625371500849724, 47.2777508944273, 51.18331052362919, 48.5981610417366, 49.10952240228653, 46.826392114162445, 46.794758811593056, 42.39685960114002, 44.546138271689415, 40.310877934098244, 41.82436712086201, 42.45814271271229, 41.67046777904034, 43.349540680646896, 42.536680698394775, 42.84032620489597, 43.06337043642998, 44.75749433040619, 49.402729868888855, 48.444949463009834, 50.31624644994736, 50.98081938922405, 50.89020185172558, 51.769679859280586, 52.411754205822945, 53.703734278678894, 51.944690868258476, 50.52977979183197, 50.31393617391586, 49.81792598962784, 50.26408664882183, 52.0503555983305, 64.46908101439476, 61.33997172117233, 65.23386597633362, 63.72525952756405, 68.80369082093239, 24.715967550873756, 9.962598960846663, 0.3821606043493375, 14.503544345498085, 63.94457995891571, 34.982309862971306, 19.65884741395712, 23.929483853280544, 36.093499436974525, 38.59952196478844, 40.276398584246635, 35.686393082141876, 53.32390286028385, 41.67476534843445, 65.4574079811573, 11.848600208759308, 0.4226869437843561, 0.015590735965815838, 0.1646971155423671, 0.09599696524674073, 0.08853435123455711, 0.05001663819712121, 0.03732242854312062, 0.033333989631501026, 0.03260324134316761, 0.008578995220887009, 0.04788266305695288, 0.1048561824427452, 0.004119985978832119, 0.0874126172857359, 0.04636216202925425, 0.13942666060756892, 0.05119067500345409, 0.22317801107419655, 0.038118927404866554, 0.071803173632361, 0.028456222171371337, 0.18169743299949914, 0.2724479336757213, 30.750482641160488, 68.85705515742302, 50.863709673285484, 41.42369382083416, 48.25499005615711, 47.16265507042408, 27.767600901424885, 21.716359108686447, 26.252821683883667, 45.81751964986324, 63.72494034469128, 31.7006653547287, 8.523790966719389, 53.95263992249966, 70.67706629633904, 71.80489137768745, 64.37065109610558, 59.3937161564827, 50.77704772353172, 50.91576308012009, 49.87474054098129, 54.983976781368256, 49.59835097193718, 51.85576803982258, 49.139214009046555, 50.97286641597748, 54.61744084954262, 58.93225371837616, 60.158330127596855, 59.712017476558685, 59.793576300144196, 59.22766126692295, 49.88458201289177, 50.444519966840744, 48.66840027272701, 48.35518307983875, 47.39071883261204, 48.018798530101776, 45.28373569250107, 44.818975031375885, 45.87822139263153, 47.766746655106544, 54.889734238386154, 56.727140843868256, 58.11278969049454, 56.42889104783535, 54.60761457681656, 55.76488047838211, 52.876974642276764, 50.658539682626724, 50.08214481174946, 51.48608587682247, 51.987624764442444, 51.364294812083244, 52.059596702456474, 47.86912076175213, 47.25448854267597, 47.482487708330154, 47.16176211833954, 45.69154880940914, 39.53045301139355, 26.157251112163067, 34.18703153729439, 41.264516562223434, 38.886292576789856, 35.95883846282959, 25.473401807248592, 38.79487708210945, 7.413377501070499, 7.168787000700831, 7.052951166406274, 2.8722580382600427, 1.341904525179416, 0.487009595381096, 0.8051107136998326, 0.685706336516887, 0.35113823774736375, 2.699631401337683, 2.449658252298832, 1.0458454303443432, 0.3071760217426345, 1.9822815502993762, 12.627342771738768, 29.158901944756508, 34.02980737388134, 32.241516932845116, 27.07947302609682, 33.16354125738144, 28.042527548968792, 22.54133854061365, 44.31118167936802, 47.4119520932436, 48.23976047337055, 49.3254230171442, 47.68786668777466, 43.53747479617596, 45.57390332221985, 46.72479696571827, 48.416196405887604, 46.03912375867367, 47.873011752963066, 49.50822740793228, 54.699717834591866, 51.961128786206245, 51.76758997142315, 49.349768310785294, 49.97329965233803, 45.70135608315468, 47.365119606256485, 44.17626231908798, 45.901840925216675, 48.02275791764259, 44.68783646821976, 46.28142535686493, 46.47419661283493, 47.05684594810009, 47.07137256860733, 47.4213869869709, 51.27406865358353, 51.213328912854195, 54.198205545544624, 53.06625388562679, 55.64065374433994, 56.495585069060326, 55.25599278509617, 55.913775488734245, 55.69819025695324, 53.703434094786644, 51.82828411459923, 52.21351124346256, 52.11301423609257, 55.09024187922478, 65.58248966932297, 64.02141183614731, 66.79902479052544, 66.58464789390564, 71.0307589173317, 27.929827496409416, 9.126497525721788, 0.816179282264784, 17.825329899787903, 68.71876537799835, 36.52927905321121, 25.94289891421795, 24.06783252954483, 29.439026713371277, 31.787701584398746, 45.93155913054943, 29.214559458196163, 54.31690737605095, 51.698657870292664, 73.12480375170708, 17.013552859425545, 0.44539865164551884, 0.031927931486279704, 0.10721025260863826, 0.15593698248267174, 0.0648452274617739, 0.03274817165220156, 0.12094857869669795, 0.007648220043847687, 0.01864383873908082, 0.057119997072732076, 0.16204387822654098, 0.16923992021474987, 0.08895673716324382, 0.29093976016156375, 0.14940985303837806, 0.18894054199336097, 0.24901007884182036, 0.30727006669621915, 0.1860632057650946, 0.24885336693841964, 0.09468787611695006, 0.31164143525529653, 0.37088090961333364, 42.25252814590931, 81.16136491298676, 57.95978710055351, 41.48545190691948, 61.688872799277306, 60.76800361275673, 34.23202492296696, 18.58434297144413, 27.44237445294857, 51.523939445614815, 71.62505462765694, 32.502878308296204, 12.063963152468204, 62.34647311270237, 73.35491180419922, 76.65153130888939, 65.83438575267792, 62.75509558618069, 53.450888246297836, 54.52576316893101, 52.86255441606045, 58.555104956030846, 53.85231390595436, 56.48748390376568, 51.88645899295807, 55.92164106667042, 57.324248403310776, 63.0037010461092, 61.64894834160805, 60.552779361605644, 62.18562014400959, 62.084317579865456, 51.970784068107605, 54.853522181510925, 51.873995661735535, 52.023787423968315, 49.41680811345577, 50.3095930069685, 46.8724874407053, 48.42271685600281, 46.96387633681297, 51.74768663942814, 57.7153842151165, 57.915815860033035, 60.34836173057556, 60.00517554581165, 57.61953815817833, 59.6225892752409, 54.86894555389881, 52.59910695254803, 52.71952249109745, 55.137978717684746, 55.11970169842243, 54.63629923760891, 57.08868384361267, 49.5891060680151, 50.68189702928066, 53.897466883063316, 53.22874836623669, 53.613755106925964, 45.47535181045532, 35.168450474739075, 42.60582558810711, 50.09990505874157, 46.30013555288315, 51.0532359033823, 34.30856801569462, 49.05279524624348, 6.211470169946551, 3.6691320408135653, 5.363404601812363, 2.2367506893351674, 0.6608253903687, 0.25485532300081104, 0.3325740073341876, 0.2727165911346674, 0.3502034879056737, 1.8951120902784169, 2.099235593341291, 0.4752507997909561, 0.16888612357433885, 1.5057558892294765, 13.953843042254448, 37.10138015449047, 38.927049189805984, 38.80875773727894, 31.135318391025066, 38.48607525229454, 30.58335240930319, 24.054177962243557, 50.41690684854984, 52.684959545731544, 54.996865689754486, 54.16566029191017, 50.69980166852474, 44.59781549870968, 50.135881528258324, 47.78302118182182, 48.29105772078037, 50.17834424972534, 51.47263839840889, 51.44770413637161, 57.74164080619812, 54.291642531752586, 55.36193870007992, 51.9666612893343, 54.44613464176655, 48.236941024661064, 51.148405596613884, 44.963990449905396, 47.19820976257324, 49.65428777039051, 47.30016969144344, 50.009063333272934, 49.108420461416245, 49.14717078208923, 50.582023188471794, 49.54450786113739, 57.15892307460308, 55.01192048192024, 56.35206297039986, 57.02381372451782, 55.57807870209217, 59.820630848407745, 58.168080523610115, 60.2318561822176, 60.11003091931343, 59.82491321861744, 57.26236492395401, 56.302479431033134, 56.242967024445534, 59.28543336689472, 71.50812730193138, 68.48901450634003, 71.63383215665817, 70.56697860360146, 76.05858832597733, 34.14946295320988, 13.001517243683338, 0.9408086759503931, 16.93591732531786, 74.7107246518135, 45.16598381102085, 31.880912482738495, 30.891542471945286, 51.96251191198826, 53.04034307599068, 62.725286185741425, 50.832581743597984, 73.6125759780407, 57.484561800956726, 86.98490962386131, 23.716621175408363, 0.8457542234100401, 0.20587831124430522, 0.21911078947596252, 0.318513247766532, 0.15594573982525617, 0.19522988732205704, 0.1766975098871626, 0.1203965766762849, 0.18835736234905198, 0.17159502196591347], [0.013319220452103764, 0.05419088862254284, 0.06086291126848664, 0.1251610237522982, 0.03984340401075315, 0.1392864392255433, 0.1083466959244106, 0.13113960216287524, 0.03148987882013898, 0.08403211977565661, 0.03205119108315557, 0.27601229085121304, 0.296905588475056, 21.511550098657608, 62.26558305323124, 41.36587232351303, 32.74298742413521, 45.289898961782455, 44.56402391195297, 27.338233441114426, 25.30866164714098, 19.43496722728014, 33.79477098584175, 59.23612721264362, 43.31794537603855, 5.11823795735836, 33.726085871458054, 67.57200211286545, 67.15093910694122, 63.70779186487198, 55.71203671395779, 48.62310290336609, 49.897193536162376, 52.22817845642567, 53.88614349067211, 50.107892230153084, 46.33918985724449, 46.614637076854706, 47.65114925801754, 51.08729727566242, 55.99219188094139, 58.85710135102272, 58.5085042566061, 57.272384986281395, 59.570570066571236, 50.810964703559875, 45.79357333481312, 46.72237269580364, 44.14337508380413, 44.43676494061947, 44.43134643137455, 43.96623618900776, 43.04050326347351, 43.8750296831131, 44.52681630849838, 49.4140038639307, 51.88936963677406, 52.92789191007614, 54.38722640275955, 50.05090668797493, 48.37813764810562, 50.155769661068916, 46.48311473429203, 47.51954331994057, 48.71806360781193, 46.96117468178272, 46.651183515787125, 47.44243025779724, 44.95092295110226, 42.08944469690323, 43.37001018226147, 42.70167924463749, 39.94012422859669, 33.355278968811035, 20.55696912109852, 24.667558148503304, 27.135018445551395, 28.277894519269466, 21.800779178738594, 14.078808836638927, 22.494188770651817, 11.446744222193956, 8.470301236957312, 3.9031999558210373, 2.6669253688305616, 0.48673054785467684, 0.37875862908549607, 0.07604223952512257, 0.17094691924285144, 0.07816015830030665, 0.33383025554940104, 0.3019105433486402, 0.6474271311890334, 0.8615908829960972, 0.32637398689985275, 7.081207875162363, 15.629262439906597, 22.069823741912842, 17.489186637103558, 17.512686476111412, 22.81902004033327, 24.1441248357296, 25.403515957295895, 39.28829960525036, 44.14128519594669, 43.92521359026432, 43.469515442848206, 42.25662052631378, 39.848807528615, 43.1578029692173, 45.31580217182636, 45.05705505609512, 44.7409538179636, 41.69330075383186, 47.13553972542286, 49.28701087832451, 47.65020310878754, 44.981028735637665, 47.03261464834213, 44.22647662460804, 43.80802407860756, 41.62162899971008, 41.135160103440285, 42.54848286509514, 41.29214867949486, 41.22740015387535, 43.575753942131996, 42.263323366642, 43.48311871290207, 42.67299838364124, 44.26266208291054, 44.49029266834259, 45.94263933598995, 47.740832045674324, 49.03388366103172, 52.33114153146744, 52.763611525297165, 52.372703701257706, 49.25128139555454, 49.59797479212284, 48.97654093801975, 45.83965726196766, 47.97767713665962, 50.069107711315155, 54.64707165956497, 59.63420905172825, 60.95206193625927, 65.52110776305199, 62.088869735598564, 67.66849413514137, 22.030343860387802, 5.927386963739991, 1.020329324528575, 26.91653586924076, 56.66494958102703, 28.824816271662712, 18.434467613697052, 24.527387470006943, 44.09723415970802, 35.463196858763695, 45.61535909771919, 37.977149561047554, 41.92564308643341, 28.191984929144382, 61.729458421468735, 9.900837074965239, 0.4559726233128458, 0.07079754868755117, 0.025739688935573213, 0.07451710378518328, 0.02111661171511514, 0.1470400270773098, 0.03641031791630667, 0.027741626727220137, 0.05566587373323273, 0.051202649556216784, 0.09003877363284118, 0.07614714952069335, 0.04732512832561042, 0.03777312369493302, 0.05626509489957243, 0.07608408923260868, 0.0740562894497998, 0.16436295612948015, 0.04922933083435055, 0.11797253682743758, 0.03304890102299396, 0.21275524457450956, 0.10274674641550519, 29.930085763335228, 68.18607196211815, 47.46086686849594, 38.34011748433113, 53.57953794300556, 43.68065871298313, 31.543395593762398, 28.166374303400517, 25.48122178763151, 38.62651951611042, 62.033654898405075, 51.74881897866726, 7.245747121050954, 31.442754194140434, 68.2590964436531, 69.95473265647888, 68.68829861283302, 59.713757783174515, 51.759158223867416, 53.30373354256153, 54.62692894041538, 59.30673502385616, 55.287949070334435, 51.09021171927452, 50.28125412762165, 51.453639417886734, 54.40426468849182, 59.0718088299036, 60.964817851781845, 60.88441036641598, 60.60140535235405, 61.20570592582226, 54.1011967509985, 48.19596402347088, 47.60194189846516, 46.96557864546776, 48.85413810610771, 46.88715845346451, 46.211756095290184, 44.96615633368492, 44.7542455047369, 45.737222358584404, 50.5458415299654, 54.07861836254597, 55.302646681666374, 56.076634749770164, 54.22646462917328, 51.47428371012211, 55.309680104255676, 49.780809581279755, 51.325647085905075, 49.1680658608675, 50.094661340117455, 48.7028644233942, 50.48019625246525, 49.59076277911663, 46.965001076459885, 49.37896214425564, 48.8760819286108, 45.53649812936783, 42.50738047063351, 27.103360444307327, 30.958367586135864, 32.81530514359474, 36.1011978238821, 29.10661295056343, 21.029357872903347, 32.85236455500126, 22.37119697034359, 10.069222189486027, 9.464150257408619, 3.8981673633679748, 3.3694606460630894, 0.6025293341372162, 0.20546125393593684, 0.31790097593329847, 0.24317203351529315, 0.3363758814521134, 0.4519927821820602, 0.4495372826931998, 1.6313925851136446, 2.7688824478536844, 13.16416371613741, 24.14953764528036, 28.574481904506683, 24.498748406767845, 22.73771770298481, 30.864185839891434, 26.914069801568985, 26.492427326738834, 45.06774768233299, 49.392884597182274, 47.94046953320503, 47.65427269041538, 47.21465528011322, 43.39058227837086, 47.923313453793526, 48.61279785633087, 48.52559633553028, 48.87349806725979, 44.934998005628586, 48.74094597995281, 50.789902433753014, 50.52538342773914, 47.09935046732426, 48.07359918951988, 47.271203845739365, 46.83342553675175, 46.436700224876404, 45.337559804320335, 46.4405570179224, 42.26766273379326, 45.77296704053879, 45.02225272357464, 44.52197536826134, 46.468781903386116, 46.85637630522251, 47.59679697453976, 48.3851482719183, 49.781014770269394, 50.51911376416683, 49.90939848124981, 54.33550737798214, 54.092293828725815, 53.66097517311573, 51.900715827941895, 51.886489391326904, 52.12323568761349, 49.95141662657261, 50.639658495783806, 53.5914921015501, 58.808167576789856, 65.1553925871849, 63.32593135535717, 68.50359052419662, 64.04346585273743, 70.87553724646568, 28.696071580052376, 5.710414331406355, 1.7734384629875422, 33.365793004631996, 64.63817194104195, 35.31919218599796, 23.176385164260864, 29.329115711152554, 44.141167402267456, 28.74386351555586, 47.90363430976868, 40.36348611116409, 41.71047583222389, 34.339384362101555, 73.85365784168243, 21.63548804819584, 0.4050941253080964, 0.06911851378390566, 0.051591735318652354, 0.06130603280325886, 0.050657449319260195, 0.07564985120552592, 0.04752536347950809, 0.0814169026853051, 0.018355423453613184, 0.10068261108244769, 0.14779780438402668, 0.18009160354267806, 0.1918807381298393, 0.2758904005168006, 0.14343958668177947, 0.34079596458468586, 0.2446593568311073, 0.20410912024090067, 0.12082167886546813, 0.19352256174897775, 0.22391799167962745, 0.29066875751595944, 0.33005572215188295, 37.667834758758545, 79.85645413398743, 52.028673961758614, 41.45544871687889, 62.60121524333954, 57.483927235007286, 36.95047505199909, 30.133813731372356, 27.47745417058468, 46.31465457379818, 71.48096635937691, 53.14471587538719, 7.783717978745699, 37.48511776328087, 75.40897518396378, 75.18644392490387, 72.93193370103836, 62.53571815788746, 54.65323492884636, 54.324955344200134, 56.05259343981743, 63.23442466557026, 58.512315452098846, 54.108990132808685, 53.20074766874313, 53.032967671751976, 58.2362412661314, 62.43454098701477, 63.95078882575035, 62.95965760946274, 63.41254010796547, 64.08131942152977, 56.46828353404999, 50.88317982852459, 53.14855366945267, 49.62682284414768, 50.26576615869999, 49.20843109488487, 50.1852522790432, 48.92965905368328, 49.52241584658623, 50.11568181216717, 54.38889071345329, 57.257558181881905, 59.74227525293827, 59.43769499659538, 55.19669696688652, 53.59319441020489, 58.04970167577267, 50.57219311594963, 54.13605608046055, 52.79505863785744, 53.12359660863876, 52.36110292375088, 53.07591296732426, 52.6029409468174, 50.7084272056818, 54.20733265578747, 53.40887010097504, 50.815919637680054, 46.1483146995306, 35.52950330078602, 38.84833261370659, 40.556850135326385, 42.43116036057472, 36.38624332845211, 24.083768874406815, 41.04109235107899, 25.24763312190771, 16.30578003823757, 12.691020704805851, 4.320581434294581, 5.598849942907691, 2.453294419683516, 0.17733761225827038, 0.5525199207477272, 0.37920106784440577, 0.33081778907217085, 0.5317113467026502, 1.2061429163441062, 1.9706363626755774, 3.02858782466501, 15.480204038321972, 29.620028100907803, 36.0683523863554, 26.791571974754333, 24.498279131948948, 32.34552875161171, 35.30635267496109, 31.070206984877586, 48.20177771151066, 52.91072443127632, 51.87015786767006, 49.831130281090736, 50.69516211748123, 48.185328394174576, 51.59008629620075, 52.06748507916927, 50.74283055961132, 52.32646778225899, 48.0891365557909, 50.353777036070824, 54.23314847052097, 52.65652187168598, 49.25902158021927, 51.963032484054565, 52.30793617665768, 50.53346559405327, 50.04146799445152, 48.44051510095596, 48.61772999167442, 44.931635186076164, 47.5720489025116, 49.31211233139038, 47.937889471650124, 49.70791429281235, 50.519554540514946, 52.086275070905685, 52.53420643508434, 54.39066141843796, 53.68968643248081, 55.012539848685265, 60.726487040519714, 59.511152654886246, 60.209539979696274, 54.90143001079559, 55.25045268237591, 56.71660780906677, 53.71057391166687, 54.6859397739172, 56.6523152589798, 60.467432141304016, 68.30319687724113, 67.09961906075478, 71.04373142123222, 68.60529586672783, 75.02771124243736, 35.8719789236784, 8.957184311002493, 1.8794628675095737, 33.91534611582756, 70.06261646747589, 42.3946101218462, 26.370109990239143, 33.284180983901024, 66.00693449378014, 45.9846156835556, 65.53343430161476, 50.023848339915276, 56.558441296219826, 39.40944090485573, 85.45532450079918, 28.03206291049719, 0.6466432451270521, 0.18084136565448716, 0.14515486807795241, 0.21248660195851699, 0.22752230608602986, 0.2881058841012418, 0.24758141487836838, 0.19405070372158661, 0.14591803337680176, 0.1676125536323525], [0.05519983467820566, 0.0821260544762481, 0.020530179608613253, 0.0572802267561201, 0.17928033223142847, 0.017108620922954287, 0.11091905398643576, 0.14719699131092057, 0.005639167839035508, 0.10586272765067406, 0.02863105917640496, 0.07491621596273035, 0.05583021120401099, 29.616857171058655, 58.7329164147377, 40.585762783885, 27.498227655887604, 47.87429228425026, 49.594513177871704, 31.45959109067917, 28.22654217481613, 24.07069757580757, 27.07673717290163, 51.01211450994015, 61.130450963974, 12.551821824163198, 18.823336847126484, 61.69870287179947, 68.67084234952927, 65.77051877975464, 56.06709726154804, 54.652151986956596, 55.11915072798729, 56.51992276310921, 58.64156171679497, 55.94275653362274, 47.64366365969181, 45.74254587292671, 47.62141205370426, 50.846139416098595, 50.96839025616646, 55.38849927484989, 59.510852470993996, 58.35042133927345, 56.392048224806786, 53.54138419032097, 46.81042917072773, 46.30654580891132, 44.964701011776924, 44.97208781540394, 43.48719209432602, 43.79762403666973, 44.71432484686375, 42.08021879196167, 43.85265648365021, 45.027447044849396, 47.23945654928684, 49.220628440380096, 50.02750754356384, 52.31895178556442, 49.30323600769043, 49.655724093317986, 47.380812764167786, 49.26428809762001, 49.10400129854679, 45.323933735489845, 45.85274375975132, 46.902350038290024, 48.09032969176769, 43.340500965714455, 42.87397339940071, 41.16609424352646, 40.19377961754799, 35.284017473459244, 24.217998571693897, 24.502871185541153, 28.005519434809685, 27.605152018368244, 24.694648794829845, 23.48405845463276, 17.542136795818806, 17.672118321061134, 10.97678354009986, 5.20246091298759, 4.589916681870818, 2.042839019559324, 0.2186872309539467, 0.16946159972576424, 0.3132396057480946, 0.3639512392692268, 0.13359547272557393, 0.7127318519633263, 0.10297004380845465, 0.49368610430974513, 2.256232243962586, 12.281535677611828, 16.063104160130024, 20.13834748417139, 13.364538364112377, 15.302294734865427, 18.150520250201225, 26.021178513765335, 34.94775451719761, 40.30394330620766, 48.79599742591381, 44.76356640458107, 45.86818993091583, 42.6961999386549, 37.80033364892006, 39.499074295163155, 48.35782773792744, 46.25364124774933, 46.422473788261414, 40.00013820827007, 42.88521319627762, 42.85426765680313, 45.44001750648022, 44.510636776685715, 44.04307946562767, 42.71919250488281, 40.68745672702789, 40.831461399793625, 44.73634846508503, 44.30281072854996, 45.3631666302681, 41.0455647110939, 41.07685223221779, 41.88956402242184, 41.454517766833305, 42.18150995671749, 43.53860333561897, 44.5029079914093, 44.53689716756344, 47.36921578645706, 47.85011798143387, 46.78655505180359, 46.54726289212704, 44.41632963716984, 47.60128453373909, 47.087008729577065, 48.342810943722725, 45.67932866513729, 46.90101630985737, 50.02339616417885, 57.01060563325882, 64.7657310962677, 64.57801356911659, 68.29683601856232, 60.00625468790531, 64.71966996788979, 21.215110905468464, 3.9978790003806353, 4.1492552775889635, 44.86208751797676, 53.35388705134392, 25.38777720183134, 18.54325007647276, 26.33656919002533, 27.545692808926105, 31.547508873045444, 41.83715343475342, 28.369260616600513, 41.78110644221306, 31.773617640137672, 57.992700934410095, 27.76102725416422, 0.5208325898274779, 0.06883153269882314, 0.02519473546271911, 0.062394871056312695, 0.08021375513635576, 0.0609418201202061, 0.06458200252382085, 0.08746176972636022, 0.1819691332639195, 0.059767382554127835, 0.013021922586631263, 0.06360429717460647, 0.06791826061089523, 0.023669937399972696, 0.05240296581177972, 0.014346566204039846, 0.09235492747393437, 0.21105992695083842, 0.021213872023508884, 0.10233722190605476, 0.07133984341635369, 0.14177848206600174, 0.01843820631620474, 39.127040058374405, 67.34820932149887, 40.86318589746952, 31.37241616845131, 51.90292350947857, 48.259580209851265, 32.07558363676071, 29.223361685872078, 26.753287129104137, 31.459680385887623, 54.37496066093445, 67.25251525640488, 16.364828869700432, 16.90767154097557, 63.127950578927994, 68.85362774133682, 70.76915815472603, 59.84850995242596, 57.735127955675125, 58.214669823646545, 60.77313333749771, 62.87706904113293, 59.637077897787094, 51.4003586769104, 50.44211849570274, 50.75882010161877, 54.32626627385616, 53.429415598511696, 60.772312581539154, 60.9212151914835, 60.923776254057884, 61.653747484087944, 56.60401985049248, 48.68490278720856, 49.15736183524132, 46.64685934782028, 47.091348096728325, 45.928792878985405, 46.67273975908756, 46.70757628977299, 43.60573053359985, 45.40410563349724, 47.81459368765354, 51.00103050470352, 52.04554125666618, 52.38882623612881, 54.514185190200806, 50.8550613373518, 52.6470185816288, 50.77459305524826, 53.46393294632435, 50.898242220282555, 48.421060144901276, 47.69019216299057, 52.93490253388882, 49.499552473425865, 49.46487553417683, 47.20905438065529, 48.674388751387596, 46.489722579717636, 44.08106602728367, 28.960698880255222, 31.303890645503998, 36.21488772332668, 35.484164133667946, 36.40257865190506, 36.441530361771584, 32.98553600907326, 25.266744196414948, 18.19996129721403, 6.597746517509222, 2.3885653680190444, 1.1709151254035532, 0.552104318048805, 0.08731079462449998, 0.4703514080028981, 0.11842751046060584, 0.45831700845155865, 0.2475667351973243, 0.8564312348607928, 0.35526128369383514, 5.608533248305321, 17.947717532515526, 24.527482464909554, 28.913666903972626, 22.360690534114838, 26.376784332096577, 30.451146103441715, 35.06695792078972, 34.59458626806736, 44.98224847018719, 49.014223515987396, 49.07378911972046, 48.74835938215256, 47.768642753362656, 41.118095219135284, 43.4905207157135, 49.985010623931885, 49.995403066277504, 48.218496814370155, 42.69334249198437, 46.0279181599617, 45.354803279042244, 47.892314717173576, 46.20607540011406, 46.81061156094074, 45.21046422421932, 43.550371304154396, 45.024152621626854, 46.1149562895298, 47.717087119817734, 47.66587346792221, 44.01431880891323, 43.368516862392426, 43.60072240233421, 44.569985792040825, 45.529240518808365, 47.96019047498703, 47.27134823799133, 47.77559258043766, 48.67057755589485, 49.99509908258915, 49.009549766778946, 51.23566411435604, 47.341245487332344, 48.87350186705589, 49.82207916676998, 50.688862055540085, 49.57381188869476, 48.96547593176365, 54.0827601402998, 61.04042239487171, 66.97785839438438, 66.87243685126305, 68.53732511401176, 64.01182115077972, 68.15299853682518, 29.369769729673862, 3.44387442804873, 6.342005990445614, 52.47245214879513, 57.94835351407528, 32.58651562035084, 21.24303750693798, 28.57654519379139, 32.735456228256226, 30.616752617061138, 45.87643928825855, 42.134324088692665, 55.035589411854744, 41.18896521627903, 67.24562242627144, 45.32558664679527, 0.23088395304512233, 0.04638596641598269, 0.07300477751414292, 0.05248472822131589, 0.027595733481575735, 0.04431734108948149, 0.024674239466548897, 0.07170455704908818, 0.043834254902321845, 0.045181739042163827, 0.12934525235323235, 0.17454746353905648, 0.10557781715760939, 0.15916167350951582, 0.24143748596543446, 0.19762225972954184, 0.14615327934734523, 0.29713393247220665, 0.10726862252340652, 0.20581269054673612, 0.221299086115323, 0.17745166551321745, 0.15351361798821017, 44.098890870809555, 76.24527230858803, 52.83540867269039, 37.83404164016247, 63.6118508130312, 68.22017893195152, 43.859496116638184, 32.86059491336346, 31.40093933790922, 36.54480122029781, 62.51725874841213, 70.86521700024605, 16.54632993042469, 21.22298788279295, 68.55401381850243, 75.13876408338547, 74.304678440094, 62.156665697693825, 62.306894436478615, 61.44210264086723, 64.15813609957695, 67.17316031455994, 64.64434280991554, 53.50484915077686, 53.94551530480385, 53.4205012768507, 55.827098339796066, 57.883016020059586, 63.27824391424656, 63.53001080453396, 64.09769654273987, 63.56744259595871, 60.44269546866417, 53.09406839311123, 54.60599586367607, 50.86846321821213, 51.827303767204285, 46.393534541130066, 49.407042637467384, 48.77010941505432, 46.669551730155945, 49.139745980501175, 49.623764008283615, 51.944295689463615, 54.78254199028015, 55.791946426033974, 57.28099912405014, 51.65953516960144, 55.47587178647518, 52.92165644466877, 57.51890055835247, 53.369610607624054, 50.66215708851814, 50.58683753013611, 55.226525366306305, 55.39060056209564, 54.26956191658974, 52.37013503909111, 54.84295874834061, 52.92759172618389, 50.07433623075485, 37.27314233779907, 38.22402611374855, 40.635699704289436, 45.609640404582024, 40.93063227832317, 42.76337273418903, 38.48799414932728, 36.53660885989666, 33.07365708053112, 14.283409807831049, 10.774792078882456, 6.306047569960356, 1.6694108513183892, 0.16239369695540518, 0.6775668764021248, 0.5718928249552846, 0.793271855218336, 1.6347029199823737, 1.456682353746146, 0.9810888301581144, 10.23965634405613, 28.249352350831032, 26.907838135957718, 33.55452507734299, 22.45320986956358, 26.47598560899496, 31.004056334495544, 41.084334030747414, 44.155899211764336, 48.90130877494812, 56.1594133079052, 55.83617985248566, 52.809558659791946, 50.033176839351654, 43.5966794192791, 46.360810697078705, 52.770333364605904, 52.86695837974548, 50.934610068798065, 44.89385761320591, 47.83947855234146, 47.122073248028755, 50.519588738679886, 48.8824237883091, 49.665884748101234, 46.872810423374176, 46.393766328692436, 47.40548104047775, 49.441601783037186, 49.13692653179169, 50.25536611676216, 47.7190288156271, 47.077353447675705, 47.9716582596302, 47.38183870911598, 48.88363592326641, 50.72543889284134, 51.313050761818886, 51.25884287059307, 53.610909059643745, 55.09003289043903, 53.91886353492737, 54.966687709093094, 51.94046929478645, 53.3889439702034, 53.54414664208889, 55.42479492723942, 53.34477134048939, 52.69133560359478, 56.96690037846565, 64.56561103463173, 73.2856035232544, 69.09271091222763, 74.14362028241158, 67.9805637896061, 72.21202433109283, 38.43546196818352, 5.082820532843471, 5.208046138286591, 54.53584402799606, 65.36249667406082, 39.61343675851822, 25.37927705794573, 36.11778773367405, 39.21888493001461, 42.730789482593536, 64.61636111140251, 43.841747269034386, 54.862105920910835, 45.970776826143265, 78.31163182854652, 50.90996839106083, 0.5898592108860612, 0.14228664542315528, 0.11898380209458992, 0.1930090697715059, 0.15855375066166744, 0.1648609817493707, 0.13712822925299406, 0.20308460021624342, 0.27328074211254716, 0.20931415812810883], [0.02856275561498478, 0.018733375145529862, 0.005906693986617029, 0.07416800493956544, 0.020889625848212745, 0.08230857827584259, 0.16308350837789476, 0.14711568161146715, 0.031580906943418086, 0.07751478668069467, 0.05244452608167194, 0.1328738231677562, 0.06387944842572324, 38.09754990041256, 57.77762487530708, 50.4531417042017, 30.989385321736336, 45.788329616189, 44.7202867269516, 32.91115500032902, 27.901030741631985, 28.98624300956726, 27.303959280252457, 44.202093333005905, 63.946084678173065, 23.57276849448681, 12.55052324384451, 52.58729338645935, 62.24137455224991, 65.58404758572578, 57.90760450065136, 57.97655180096626, 60.751672089099884, 58.623003512620926, 62.12282471358776, 60.63376821577549, 50.53528189659119, 46.75024040043354, 45.288671627640724, 47.98994667828083, 50.47079175710678, 53.42155002057552, 56.50646008551121, 60.23250974714756, 59.73656415939331, 53.76842960715294, 46.42847366631031, 44.48470316827297, 41.84807404875755, 40.53312800824642, 44.42875497043133, 42.76955120265484, 44.06862169504166, 45.38159564137459, 45.964457765221596, 45.61647243797779, 44.262882471084595, 48.23232427239418, 48.259348422288895, 48.011791706085205, 48.880242705345154, 47.98909932374954, 47.37778052687645, 49.37743082642555, 47.72960364818573, 45.2192759513855, 46.712668016552925, 45.9353931248188, 46.58208802342415, 44.60724659264088, 44.08759027719498, 42.739946991205215, 41.93685628473759, 38.538611233234406, 24.304607324302197, 23.592109456658363, 29.042158909142017, 28.594406135380268, 25.919159688055515, 30.943206399679184, 24.613500349223614, 22.895392142236233, 6.808007284998894, 12.524294201284647, 12.943794541060925, 4.194243913516402, 4.327863268554211, 1.914458752144128, 2.043462423607707, 0.9955630847252905, 0.44588680670131, 0.43225649278610945, 0.7316931313835084, 0.777732707792893, 3.946083504706621, 10.755720902234316, 23.026382513344288, 17.861357666552067, 10.188838820904493, 15.742603708058596, 25.670103952288628, 25.18123358488083, 33.35552215576172, 41.35711759328842, 50.04260413348675, 45.369466692209244, 45.682942271232605, 44.05300073325634, 42.79965318739414, 42.2908490896225, 46.87999963760376, 43.49083989858627, 47.42595434188843, 44.252854809165, 41.848830208182335, 40.39385788142681, 43.35278570652008, 43.814631924033165, 43.96004632115364, 42.076202407479286, 41.01585030555725, 40.7580341398716, 45.25817446410656, 43.94895851612091, 45.35137206315994, 41.688980385661125, 42.13447608053684, 43.21820452809334, 41.67042598128319, 41.45848475396633, 42.49067656695843, 43.128772526979446, 44.7500429302454, 43.03913913667202, 45.64193867146969, 43.92962135374546, 44.726301804184914, 43.541297391057014, 44.65867683291435, 43.170524686574936, 47.20360927283764, 46.5777600556612, 46.95102162659168, 49.22146059572697, 60.66358141601086, 59.74557347595692, 66.73573538661003, 66.01369053125381, 63.184822127223015, 64.2639148235321, 22.33260054141283, 2.2958436934277415, 13.082395903766155, 55.156818106770515, 39.46142591536045, 23.870632611215115, 31.415084078907967, 30.40729645639658, 32.72705867886543, 40.15175387263298, 36.04816786944866, 28.390795961022377, 71.0355694591999, 41.820130348205566, 45.78044503927231, 48.50479245185852, 1.6112107993103564, 0.06122467486420646, 0.0733250736084301, 0.07787748909322545, 0.04309616677346639, 0.12709976581390947, 0.05063347423856612, 0.16023327538277954, 0.07888467254815623, 0.02015916514210403, 0.012962261334905634, 0.05391948150645476, 0.037115180093678646, 0.10453844675794244, 0.04654926116927527, 0.14790353074204177, 0.15766201569931582, 0.09141996983089484, 0.044967933717998676, 0.08726521191420034, 0.009505740999884438, 0.09673877895693295, 0.25577392370905727, 47.107083052396774, 65.24202793836594, 55.80077335238457, 33.6707304418087, 50.56936226785183, 43.08616541326046, 31.43491331487894, 25.705759339034557, 33.70292991399765, 34.37151163816452, 48.76101650297642, 70.90636879205704, 29.87022377550602, 12.715025916695595, 52.11471654474735, 67.49917522072792, 69.68144372105598, 62.55852833390236, 60.46868987381458, 64.23040822148323, 62.82650515437126, 63.72623987495899, 65.44736132025719, 55.1544888317585, 48.428519144654274, 50.86332969367504, 51.20753422379494, 55.58467894792557, 56.03101819753647, 58.89167569577694, 62.91309490799904, 62.927891314029694, 53.92193377017975, 48.851843029260635, 45.29553405940533, 45.768977254629135, 44.70290265977383, 47.34252981841564, 45.843453258275986, 45.27944952249527, 45.44131703674793, 46.19928516447544, 48.115928918123245, 48.133689165115356, 51.59412927925587, 49.52948346734047, 50.159702450037, 51.23463436961174, 52.461257949471474, 51.4452912658453, 52.502162754535675, 51.43409326672554, 47.77887940406799, 50.31657703220844, 49.47246752679348, 47.219864800572395, 49.50630471110344, 49.77614343166351, 50.725503489375114, 46.39983460307121, 44.020607471466064, 29.96432952582836, 33.957523852586746, 36.22574374079704, 33.41674067080021, 36.104792430996895, 37.379810214042664, 41.27970054745674, 31.648642346262932, 15.725205391645432, 10.236763749271631, 7.92183106765151, 4.543758183717728, 0.8814242749940604, 1.6190704400651157, 0.9449932014103979, 0.03111918347713072, 0.0983559261658229, 0.22906545375008136, 0.3360788739519194, 1.4606757019646466, 8.009287174791098, 21.03276629000902, 27.36266802996397, 25.170151479542255, 21.94537851959467, 29.938394017517567, 40.51576294004917, 40.29201574623585, 38.14402520656586, 46.06082059442997, 51.01132035255432, 48.457306399941444, 47.89820060133934, 50.94243384897709, 44.58429202437401, 46.09727583825588, 49.49954107403755, 47.370135337114334, 47.9587047547102, 47.42590494453907, 43.808879032731056, 42.98124924302101, 46.55000254511833, 46.301085501909256, 45.39113312959671, 44.729657024145126, 43.854875564575195, 44.893690422177315, 46.168856397271156, 46.92809745669365, 46.18692062795162, 44.82397176325321, 44.47341777384281, 44.58415903151035, 44.95486333966255, 45.097823068499565, 46.40811815857887, 46.19728647172451, 47.39416904747486, 48.71437780559063, 48.09450946748257, 48.14269848167896, 47.25077614188194, 48.09349872171879, 46.11697398126125, 47.44276463985443, 47.1932852268219, 51.60213924944401, 50.01564837992191, 52.72895738482475, 63.8652478158474, 65.2703820168972, 69.04522866010666, 68.34348231554031, 65.23613065481186, 69.4457271695137, 28.471159748733044, 2.0045919343829155, 16.32714819163084, 60.99137842655182, 42.44582757353783, 28.759484477341175, 35.866856798529625, 22.66181867569685, 22.674027420580387, 39.989745765924454, 39.125497341156006, 40.991208627820015, 88.96246030926704, 47.62069009244442, 56.534893959760666, 64.61547955870628, 3.7922827200964093, 0.11404684279114008, 0.04842038244532887, 0.004190526651655091, 0.015818907413631678, 0.044189647160237655, 0.03327075122797396, 0.03888665320118889, 0.008174453305400675, 0.03395057705347426, 0.09830323368078098, 0.10231599648250267, 0.07928853447083384, 0.15703151671914384, 0.07845431595342234, 0.38001048378646374, 0.3414916538167745, 0.2902302669826895, 0.18593659537145868, 0.1958598816418089, 0.23464928381145, 0.18110270553734154, 0.38793659128714353, 57.52507142722607, 72.50504180788994, 64.44944366812706, 42.658783346414566, 61.834135204553604, 60.68650558590889, 44.45726104080677, 35.75609654188156, 36.867787688970566, 38.629232570528984, 55.20146191120148, 73.42731311917305, 29.858609698712826, 15.230344645678997, 59.076243191957474, 70.03124535083771, 74.43009451031685, 67.55707651376724, 62.889672964811325, 66.36966302990913, 65.76959922909737, 68.63041251897812, 68.88743072748184, 59.24131013453007, 51.08973674476147, 52.00613357126713, 55.97544237971306, 55.69020688533783, 60.33942461013794, 61.41401834785938, 66.16727828979492, 65.2610345184803, 56.85062661767006, 53.21761876344681, 49.59385201334953, 48.253473937511444, 46.94317884743214, 48.5431057959795, 48.123973086476326, 46.9447785615921, 48.78823824226856, 48.69073547422886, 51.13952927291393, 49.86461788415909, 53.834017887711525, 53.66121456027031, 54.280520528554916, 53.01328472793102, 59.14232164621353, 55.7235386967659, 56.461763083934784, 53.645551800727844, 50.10716646909714, 55.21998591721058, 54.06385235488415, 53.84789474308491, 56.39072589576244, 52.28071063756943, 57.672974690794945, 54.41063694655895, 49.61679898202419, 36.81768737733364, 36.55734434723854, 41.382279843091965, 40.88307023048401, 41.67941629886627, 51.25470869243145, 51.1337573826313, 51.46888419985771, 28.62691529095173, 29.696630090475082, 22.06646092236042, 14.553051888942719, 8.534165360033512, 5.618435516953468, 3.5369903314858675, 1.8775736563839018, 1.5374061721377075, 0.6557599059306085, 1.5428860718384385, 2.773563559167087, 11.654784008860588, 23.278920762240887, 33.982587307691574, 32.527447789907455, 21.047604493796825, 26.607268564403057, 41.66365474462509, 43.99864844977856, 46.88589692115784, 51.50585241615772, 57.07349605858326, 51.22605822980404, 54.004450142383575, 52.57398650050163, 48.57284680008888, 48.70419055223465, 54.13590028882027, 48.86633165180683, 52.840523198246956, 51.35544888675213, 45.46369023621082, 45.88531941175461, 48.924852311611176, 48.38457450270653, 48.571535870432854, 48.48705120384693, 46.30729816854, 46.81354120373726, 51.4528376609087, 49.3137576431036, 49.99049752950668, 46.54225096106529, 46.70993976294994, 48.04608106613159, 47.58682630956173, 47.78215102851391, 50.738418996334076, 50.78257642686367, 53.091989904642105, 51.347119733691216, 52.03309692442417, 51.51958487927914, 50.899640545248985, 51.20167873799801, 47.47770756483078, 50.91700181365013, 51.611551344394684, 54.230329021811485, 52.63683892786503, 54.27463464438915, 66.22932136058807, 67.06532210111618, 72.82530382275581, 71.36616691946983, 67.69957646727562, 73.29471543431282, 38.08466859161854, 2.5738909235224128, 15.895384009927511, 64.74375307559967, 49.24013279378414, 39.500833600759506, 38.699821382761, 41.56201779842377, 44.67427119612694, 53.25443118810654, 53.88082377612591, 45.82261137664318, 85.08766382932663, 60.398237854242325, 59.88031044602394, 76.16432145237923, 3.287383387796581, 0.26434157334733754, 0.19015940080862492, 0.17964772501727566, 0.17036333883879706, 0.1312876754673198, 0.15296065859729424, 0.21662928513251245, 0.2319864579476416, 0.10710664137150161], [0.13270304014440626, 0.073205142543884, 0.1144635587115772, 0.02702252644667169, 0.18202938081230968, 0.10405737179098651, 0.20379016001243144, 0.16061720321886241, 0.05614105975837447, 0.16157619160367176, 0.04474129294976592, 0.06740528813679703, 0.177904405281879, 40.876610577106476, 62.878277376294136, 43.85940872132778, 34.38158489763737, 42.55301222205162, 58.235644698143005, 39.97943311929703, 43.189124688506126, 28.472026102244854, 32.85911679267883, 34.10080276429653, 63.327477872371674, 38.80938470363617, 10.731504801660776, 37.165372520685196, 63.24066013097763, 61.510757356882095, 61.37860804796219, 61.15330673754215, 63.529965206980705, 61.50188483297825, 60.53072154521942, 61.793891564011574, 51.47412411868572, 45.90352803468704, 46.83983959257603, 44.79220926761627, 49.09654229879379, 49.75016802549362, 54.520530849695206, 56.323146522045135, 58.817583471536636, 54.90567438304424, 48.81589315831661, 45.44241897761822, 43.51428464055061, 39.841348528862, 43.05428132414818, 42.84881114959717, 46.718249917030334, 45.94412885606289, 47.05447107553482, 45.96439316868782, 45.798494070768356, 47.007209211587906, 48.28358352184296, 47.02223740518093, 48.25355373322964, 46.73869661986828, 46.30655340850353, 46.3205024600029, 46.15295425057411, 44.30637873709202, 43.1060915440321, 43.03721643984318, 46.08952425420284, 43.68565924465656, 46.37480914592743, 40.94683080911636, 44.70950670540333, 39.737971276044846, 26.706182956695557, 17.46785268187523, 15.262176487594843, 22.953432127833366, 28.188282027840614, 33.755739480257034, 36.22247211635113, 30.064877830445766, 20.993371903896332, 31.706355549395084, 18.131922148168087, 11.213836669921875, 12.731368839740753, 9.941739030182362, 4.523890949785709, 2.673734840936959, 1.2236471520736814, 1.3435607613064349, 1.957133668474853, 2.2935479041188955, 7.5617818627506495, 16.22672528028488, 26.976428255438805, 25.852078087627888, 11.529233995825052, 19.194985404610634, 31.881847232580185, 32.11674302816391, 31.069870702922344, 35.78918136656284, 49.76904161274433, 47.987712398171425, 49.77474130690098, 43.65656420588493, 44.37874585390091, 41.77726484835148, 44.64368283748627, 45.201789289712906, 47.60365180671215, 45.767803117632866, 43.90570543706417, 41.63623161613941, 41.58523455262184, 40.939071625471115, 40.755142495036125, 38.09997417032719, 40.66324062645435, 40.59851109981537, 43.645290210843086, 45.45056194067001, 45.23743137717247, 42.37558454275131, 41.35043755173683, 42.42578744888306, 42.753443866968155, 41.34178161621094, 41.59500002861023, 43.1674924492836, 46.599844470620155, 44.227175787091255, 45.16333535313606, 46.1273056268692, 44.833733439445496, 44.12572503089905, 43.80210019648075, 44.82905589044094, 46.23040549457073, 48.73580105602741, 49.22641932964325, 49.62030999362469, 62.17103272676468, 64.40593600273132, 68.96513655781746, 64.91978242993355, 67.799032330513, 64.36925277113914, 16.28567911684513, 1.5191248781047761, 28.425419703125954, 52.463978603482246, 39.06857639551163, 18.54009624570608, 63.95328149199486, 94.10820499062538, 41.93106159567833, 27.984878942370415, 24.44101620465517, 33.94773177802563, 64.53487828373909, 40.311204716563225, 44.52756866812706, 65.69847464561462, 11.305929478257895, 0.18189989088568836, 0.16799195436760783, 0.09996140681323595, 0.11086751925176941, 0.023015038459561765, 0.09496204031165689, 0.019925056512875017, 0.009677268026280217, 0.0016018704468478973, 0.11057196636102162, 0.01506222106399946, 0.08519248993252404, 0.0644622347317636, 0.03956541033403482, 0.09017024509375915, 0.17893098847707734, 0.2512432902585715, 0.061925121262902394, 0.08568857112550177, 0.03856629402434919, 0.004516012677413528, 0.160092193109449, 49.56746242940426, 67.71844625473022, 51.58385083079338, 36.392919570207596, 45.734117925167084, 52.448395639657974, 31.2328914552927, 39.47735086083412, 37.186981961131096, 38.4902436286211, 39.21320803463459, 67.57109016180038, 47.16491974890232, 12.240848410874605, 35.52750080823898, 65.5706875026226, 66.694545596838, 64.46389809250832, 64.10499975085258, 66.97956070303917, 64.75934743881226, 64.88091811537743, 64.21364352107048, 55.747914388775826, 49.481020867824554, 51.520971804857254, 51.012559086084366, 53.57215493917465, 56.62370279431343, 59.270712956786156, 60.66691383719444, 61.873839274048805, 58.226468190550804, 50.98184533417225, 47.613903656601906, 47.067937552928925, 43.662438690662384, 46.37824036180973, 45.98620019853115, 49.74144369363785, 47.325366139411926, 48.09585839509964, 47.71769888699055, 48.836921229958534, 47.80822142958641, 50.83629794418812, 52.22659394145012, 51.91078148782253, 51.41173906624317, 49.25306349992752, 48.202195689082146, 50.35971611738205, 46.80595301091671, 46.927322298288345, 47.811200469732285, 49.547479301691055, 48.73127169907093, 51.649978682398796, 45.69958917796612, 49.6269254386425, 43.71883146464825, 31.54874950647354, 21.6598504409194, 18.389041051268578, 30.966744236648083, 38.010773956775665, 37.118593230843544, 45.910314470529556, 40.07935255765915, 18.45077633857727, 23.03830247372389, 18.11123415827751, 14.335304573178291, 9.470265079289675, 5.856931619346142, 3.5712766041979194, 0.5419129086658359, 0.7891733001451939, 0.6719592679291964, 0.5314594914671034, 1.7381192394532263, 7.060934063047171, 18.07595495134592, 29.95805226266384, 27.6965257152915, 23.721439316868782, 30.14099534600973, 42.99121230840683, 47.85573408007622, 37.20677889883518, 39.68105413019657, 51.73520050942898, 49.240786358714104, 47.39581435918808, 50.20011708140373, 47.53175586462021, 46.66535675525665, 47.41523131728172, 49.443786665797234, 48.18175658583641, 48.37945617735386, 47.58091762661934, 44.617319852113724, 40.703100487589836, 44.172295331954956, 43.499621227383614, 40.77264815568924, 44.629471600055695, 44.01568293571472, 46.25642649829388, 46.71338237822056, 45.263049602508545, 46.767635866999626, 44.95965488255024, 43.81256103515625, 46.21232606470585, 45.026588290929794, 44.50991481542587, 47.19178430736065, 48.707686364650726, 48.48287522792816, 48.645096123218536, 48.43533217906952, 46.3615782558918, 47.99863301217556, 46.78418777883053, 47.322998866438866, 49.12168174982071, 51.89533531665802, 52.35930562019348, 53.731647580862045, 63.79815861582756, 69.27939489483833, 70.67537158727646, 67.52166241407394, 68.66837248206139, 67.9723410308361, 17.053754702210426, 1.7263168352656066, 35.0150641053915, 57.15793512761593, 43.31471174955368, 22.57058747112751, 69.96918708086014, 79.14798215031624, 30.051217563450336, 28.92465591430664, 31.4227007701993, 40.811060294508934, 87.27895304560661, 48.12068626284599, 55.309995487332344, 82.06543520092964, 25.885748080909252, 0.06508389473310672, 0.11610263638431206, 0.12122392290621065, 0.07494097400922328, 0.025424853192816954, 0.15310853894334286, 0.0416320726799313, 0.05582054473052267, 0.009818677772273077, 0.17284459085203707, 0.20462771819438785, 0.17539943422889337, 0.1363152064732276, 0.13667465827893466, 0.3542646090500057, 0.3754271875368431, 0.26023886224720627, 0.11127154444693588, 0.2525272947968915, 0.19595088378991932, 0.16229381872108206, 0.30984992044977844, 60.161476358771324, 74.71368089318275, 59.87086035311222, 47.300686463713646, 58.9470349252224, 74.48782101273537, 54.02399629354477, 55.19534803926945, 33.94003339111805, 43.63004542887211, 45.094692036509514, 73.52153286337852, 48.53185459971428, 12.433960698544979, 42.838544100522995, 70.48316270112991, 70.51501259207726, 68.2379923760891, 68.57590064406395, 70.46226382255554, 68.02135840058327, 69.25829842686653, 69.87541571259499, 56.96235962212086, 53.228584975004196, 53.00768382847309, 52.502436339855194, 57.37432971596718, 57.749525383114815, 61.17463879287243, 64.16808396577835, 64.80990752577782, 61.08854681253433, 54.49329771101475, 52.909364104270935, 51.20799399912357, 45.99619746208191, 46.02089233696461, 46.619044840335846, 51.10355280339718, 49.91484738886356, 51.627510488033295, 51.45602948963642, 51.809425726532936, 51.77450180053711, 55.75272873044014, 57.86785863339901, 53.82954552769661, 55.53720809519291, 54.109385311603546, 52.48860128223896, 53.07015247642994, 49.18010741472244, 50.129794254899025, 50.44040098786354, 54.36989553272724, 54.70004841685295, 58.02315250039101, 53.43468211591244, 56.176219806075096, 50.42251154780388, 38.88806328177452, 28.226551674306393, 24.71977684646845, 32.56879337131977, 40.78304439783096, 48.46809782087803, 54.84118804335594, 50.4689184576273, 48.39171051979065, 42.61698938906193, 29.024335965514183, 22.294507585465908, 24.08505890518427, 17.905099019408226, 10.940987560898066, 7.897749384865165, 5.8798961620777845, 4.616559902206063, 3.1497818464413285, 4.17229819111526, 11.193310171365738, 25.35639848560095, 34.71868760883808, 41.454525366425514, 21.072105579078197, 27.301058135926723, 45.379311963915825, 49.2815999686718, 44.401586428284645, 44.92663465440273, 54.8444938659668, 53.59607845544815, 54.55882519483566, 52.46737942099571, 53.07317331433296, 50.47551490366459, 51.680042669177055, 51.05596035718918, 53.02917167544365, 53.47473956644535, 51.04100815951824, 44.815125837922096, 43.31725001335144, 44.316881373524666, 44.24761489033699, 41.82257741689682, 47.26688727736473, 45.78324928879738, 51.32422976195812, 53.06317985057831, 51.66009373962879, 49.54377070069313, 46.12939931452274, 45.469317734241486, 49.174571111798286, 48.47019150853157, 48.55489656329155, 48.566957116127014, 54.108055382966995, 52.28594295680523, 52.60814666748047, 51.72282837331295, 49.237305745482445, 49.9870815128088, 48.902247324585915, 50.21490968763828, 52.54189342260361, 54.15057510137558, 57.68274776637554, 54.68741029500961, 66.95011988282204, 71.83595851063728, 75.08204832673073, 71.01070359349251, 71.13839194178581, 72.0428954064846, 25.638930425047874, 2.1172696631401777, 33.16611371934414, 62.526857033371925, 51.28731854259968, 30.503530092537403, 72.50128760933876, 106.32458746433258, 57.00689323246479, 39.0408568829298, 38.75358089804649, 51.29298023879528, 84.78890866041183, 55.42811594903469, 60.207355096936226, 94.36473682522774, 27.792065888643265, 0.47906398423947394, 0.25818192574661225, 0.37865089892875403, 0.11128613507025875, 0.1344219283782877, 0.1769541297107935, 0.12056666208081879, 0.16427631780970842, 0.13915881951106712], [0.07175796941737644, 0.060126756434328854, 0.013180962978367461, 0.0913027253409382, 0.15588719921652228, 0.12418528509442694, 0.13005308312131092, 0.1953241549199447, 0.020667039061663672, 0.09066265265573747, 0.03522686325595714, 0.13395724003203213, 0.24433254468021914, 49.98702071607113, 55.126298144459724, 47.43854686617851, 29.124601185321808, 43.453624695539474, 51.81021988391876, 45.53554058074951, 38.418746665120125, 22.177694253623486, 29.1986421123147, 29.285870231688023, 53.32079462707043, 58.650502637028694, 17.954868748784065, 17.313793748617172, 59.07647877931595, 60.25837115943432, 65.87025582790375, 61.61978870630264, 65.18063843250275, 60.862352550029755, 62.583177611231804, 59.79136101901531, 53.40624824166298, 45.929659232497215, 47.87920922040939, 46.44292429089546, 46.167260482907295, 47.68302954733372, 51.073321625590324, 57.18438930809498, 59.70029890537262, 55.592316538095474, 51.865472719073296, 45.80203928053379, 42.24267527461052, 38.68603192269802, 42.825210615992546, 41.00089430809021, 43.481948375701904, 44.9252325296402, 47.4588605761528, 44.76603627204895, 44.699942618608475, 45.969534292817116, 45.69972597062588, 44.567154943943024, 48.003268763422966, 47.11794666945934, 47.166698053479195, 44.60019037127495, 46.58380553126335, 42.34821081161499, 42.19603657722473, 44.56128045916557, 43.55593040585518, 43.90836529433727, 45.55523492395878, 41.70098394155502, 45.224367678165436, 38.29467952251434, 25.58928418904543, 13.73584683984518, 13.65459579974413, 20.304905846714973, 27.697884142398834, 41.44509807229042, 43.13960574567318, 39.45374272763729, 36.07208378612995, 35.953131169080734, 32.7306304872036, 23.57486218214035, 12.213418632745743, 14.037480354309082, 12.240269891917706, 4.709372296929359, 2.754675247706473, 3.0503692058846354, 0.2675207855645567, 2.7734961127862334, 8.89324514195323, 16.732618734240532, 29.84016738831997, 36.71194665133953, 14.420523550361395, 22.64229342341423, 37.25857771933079, 41.331719756126404, 34.547685384750366, 34.71868760883808, 46.75429858267307, 48.09764049947262, 49.96846631169319, 48.54866489768028, 45.601622834801674, 43.04214857518673, 41.97541281580925, 45.73981001973152, 45.976677909493446, 45.484049543738365, 43.76127518713474, 40.248777866363525, 39.071859419345856, 40.65799690783024, 41.10501252114773, 40.58723710477352, 40.15758275985718, 41.229915618896484, 43.049596175551414, 44.101524129509926, 42.700372114777565, 42.30297423899174, 40.26124879717827, 45.00702694058418, 42.176513224840164, 44.974956661462784, 43.624828308820724, 43.537292405962944, 45.7186983525753, 42.51367673277855, 48.879969120025635, 49.69385124742985, 50.096599236130714, 48.39692384004593, 45.238362327218056, 43.608295395970345, 46.694805175065994, 50.71205981075764, 49.663175493478775, 55.17162971198559, 61.60764455795288, 63.075600787997246, 67.20092162489891, 66.86503484845161, 67.22091615200043, 59.69097040593624, 9.537954647094011, 2.466417015530169, 44.54420417547226, 55.484364330768585, 31.841852478682995, 13.023034539073706, 48.17601889371872, 100.78643783926964, 45.36038137972355, 30.051213763654232, 26.5826078876853, 33.29086482524872, 36.56128853559494, 39.2224795371294, 29.62255496531725, 54.95855614542961, 43.132663518190384, 1.6873618005774915, 0.04818885092390701, 0.034693210836849175, 0.08501556192641146, 0.2147951116785407, 0.11330363384331577, 0.05560794910707045, 0.014612495342589682, 0.09514791861874983, 0.014732230665686075, 0.02042573531070957, 0.006336872929750825, 0.03488678521534894, 0.08091835756204091, 0.09029884444316849, 0.0726125376240816, 0.03094397168752039, 0.08099616432446055, 0.04468670427741017, 0.04706264182459563, 0.06680338410660625, 0.8722979365848005, 64.00229886174202, 62.030155286192894, 54.885455667972565, 33.06455656886101, 50.20072124898434, 47.627332136034966, 43.79676528275013, 43.27728755772114, 25.028846561908722, 31.780797354876995, 33.69412578642368, 57.623505145311356, 64.9009582400322, 22.687136717140675, 14.993710443377495, 56.23253658413887, 64.59496825933456, 68.62348929047585, 65.15716329216957, 67.94877469539642, 66.05387717485428, 65.81556916236877, 63.89121562242508, 56.4920474588871, 49.20325957238674, 51.26611948013306, 52.50596635043621, 50.77856384217739, 52.78989091515541, 56.20445989072323, 60.45255973935127, 62.196411564946175, 59.989801570773125, 55.29667720198631, 47.88020856678486, 47.71389529109001, 44.4186969101429, 46.16974174976349, 46.514470651745796, 46.03442721068859, 47.04968713223934, 47.55568318068981, 47.80412144958973, 45.772123485803604, 48.84021945297718, 50.362345576286316, 49.09771643579006, 50.4959350079298, 48.60377334058285, 48.99013660848141, 47.77050845324993, 49.673792123794556, 47.75416933000088, 47.619417160749435, 47.59542904794216, 46.457941085100174, 48.48968826234341, 52.148169949650764, 48.183166310191154, 48.36443938314915, 43.52020472288132, 31.615225039422512, 19.2801521345973, 19.143294878304005, 28.95328927785158, 32.373917028307915, 45.31384527683258, 50.088574066758156, 40.592993795871735, 44.01845298707485, 38.39954249560833, 33.00377883017063, 24.030455835163593, 15.43216796591878, 12.912857551127672, 8.3404840528965, 4.020411791279912, 2.104140417650342, 1.4068799698725343, 2.788747544400394, 2.7147574396803975, 10.97442576661706, 20.59434961527586, 29.744199737906456, 36.863543316721916, 35.22437587380409, 36.33382894098759, 44.62282195687294, 49.42370854318142, 45.31722329556942, 37.8453878313303, 48.54339078068733, 50.41775040328503, 48.693596720695496, 50.862030163407326, 47.949699237942696, 47.1974878013134, 47.62609340250492, 47.802472338080406, 50.17180100083351, 47.96711750328541, 46.36794671416283, 42.20780834555626, 41.62153780460358, 43.40569406747818, 43.13388705253601, 42.57924221456051, 42.23379895091057, 44.09797891974449, 47.60385699570179, 47.14093163609505, 45.16897805035114, 45.484794303774834, 43.7027545273304, 45.537353083491325, 43.116199001669884, 46.51165880262852, 43.992618173360825, 46.67528182268143, 49.36827711760998, 47.194455564022064, 51.79178327322006, 53.696917444467545, 51.56138263642788, 52.83731237053871, 49.272001683712006, 48.45785737037659, 47.67933614552021, 52.808460518717766, 52.56607912480831, 59.03313830494881, 62.45544746518135, 67.47829154133797, 69.17747676372528, 67.73080319166183, 65.71653887629509, 59.37383942306042, 10.819706618785858, 3.5882985033094883, 52.056279480457306, 60.64322970807552, 35.11186011135578, 18.48703969269991, 52.86325357854366, 76.80875167250633, 44.7345245629549, 27.63321541249752, 30.75331538915634, 35.537672862410545, 48.39039959013462, 44.837575033307076, 38.178880736231804, 61.81704752147198, 62.539677545428276, 4.83705067075789, 0.2661563619039953, 0.04703594677266665, 0.05429429576906841, 0.026440925721544772, 0.02521907790651312, 0.06744031008565798, 0.04055472287291195, 0.10050438431790099, 0.13210515113314614, 0.08123443083604798, 0.0875269748212304, 0.11585938264033757, 0.1918261160608381, 0.3819937101798132, 0.3539098327746615, 0.31349816999863833, 0.17473071464337409, 0.30479372770059854, 0.23167058505350724, 0.15470372600248083, 0.8459384541492909, 74.87983077764511, 66.39445289969444, 61.38797454535961, 40.624087527394295, 62.6912210136652, 68.30062821507454, 62.50286132097244, 48.14236409962177, 26.436595022678375, 37.72952064871788, 43.150697350502014, 62.13660657405853, 67.92338445782661, 21.84094302356243, 21.374155171215534, 67.06654563546181, 67.4957326054573, 72.5724121928215, 67.44545370340347, 71.69992581009865, 68.64730641245842, 71.98865711688995, 67.8275915980339, 57.85724200308323, 51.58099338412285, 51.65906399488449, 52.041384279727936, 52.7735897898674, 55.750623643398285, 58.29251244664192, 65.25186941027641, 65.79644098877907, 64.51429098844528, 57.52257876098156, 52.40455359220505, 50.91498412191868, 43.9415717124939, 46.81736379861832, 45.87623029947281, 45.843248069286346, 47.679837718605995, 51.957560777664185, 52.78481438755989, 47.957150638103485, 53.86175639927387, 55.6966133415699, 54.57619786262512, 54.86858457326889, 55.21695367991924, 53.897284492850304, 52.247986793518066, 51.40003189444542, 48.479584604501724, 47.39246293902397, 52.49098755419254, 49.23539824783802, 53.742100819945335, 58.925877660512924, 55.81594593822956, 54.3716624379158, 48.073576390743256, 40.69558069109917, 24.47227332741022, 22.73816227912903, 28.305021263659, 35.06529361009598, 56.37660585343838, 59.45358954370022, 57.382104098796844, 57.931414023041725, 46.829367354512215, 40.16469217836857, 31.395302340388298, 19.68342449516058, 22.673945724964142, 24.166762121021748, 13.744717463850975, 8.469660021364689, 6.5965377073735, 5.691310381516814, 4.793367739766836, 13.311317469924688, 24.849385991692543, 36.20052449405193, 50.660770162940025, 32.099803537130356, 32.291457653045654, 44.57670383155346, 51.927299201488495, 47.93250136077404, 45.03856524825096, 51.162822023034096, 58.273794651031494, 54.69976343214512, 58.116372898221016, 51.869751289486885, 51.732084676623344, 48.630577102303505, 51.7071808129549, 52.89231061935425, 51.18367150425911, 48.24235953390598, 44.06607963144779, 41.53668075799942, 45.17896771430969, 42.69050404429436, 42.53126218914986, 43.36911343038082, 45.67039534449577, 52.85183139145374, 51.14028163254261, 48.33371423184872, 47.76271887123585, 44.325677901506424, 48.69741551578045, 45.62768943607807, 51.33307948708534, 49.212652668356895, 49.19097863137722, 54.17965114116669, 51.18935599923134, 56.924156472086906, 57.58622534573078, 54.1275255382061, 56.053592786192894, 48.9293322712183, 50.66585808992386, 51.06980301439762, 57.13716544210911, 55.174981132149696, 61.19489550590515, 65.82357913255692, 72.1665407717228, 73.69785100221634, 73.20284396409988, 69.84105035662651, 67.93927520513535, 15.860963556915522, 4.619921296834946, 53.55120666325092, 66.42295137047768, 45.015192702412605, 24.1112395003438, 59.82584036886692, 107.12026476860046, 56.187512800097466, 40.92118218541145, 43.350258842110634, 50.61715230345726, 52.04030893743038, 55.49461618065834, 44.61844079196453, 75.54769814014435, 73.26791927218437, 5.894359136000276, 0.5777851806487888, 0.23401517799356952, 0.1284458435839042, 0.2359557308955118, 0.16829978238092735, 0.11224634799873456, 0.1583837840007618, 0.3288270818302408], [0.13858933991286904, 0.043235104240011424, 0.05399244946602266, 0.14294874505139887, 0.14425992703763768, 0.15793393860803917, 0.08463094389298931, 0.02634825559653109, 0.09161758891423233, 0.036499345951597206, 0.1607085022260435, 0.14673423254862428, 2.993374401703477, 59.955227226018906, 58.71931694447994, 42.3994966596365, 29.076149985194206, 39.78685565292835, 44.69279520213604, 23.61451305449009, 31.83910332620144, 59.06291350722313, 28.365774303674698, 23.737248368561268, 46.203309148550034, 63.41154836118221, 48.851352855563164, 7.980056293308735, 29.823662973940372, 64.0942995250225, 62.75830261409283, 67.2421646118164, 62.157608047127724, 63.588086888194084, 61.185122430324554, 59.25169877707958, 50.475571900606155, 48.62123340368271, 48.691727221012115, 48.349661976099014, 45.27211591601372, 46.57426044344902, 50.711809024214745, 55.2744559943676, 55.44183701276779, 55.82508824765682, 51.6378079354763, 44.10649046301842, 42.25324630737305, 38.50479684770107, 39.821509793400764, 42.99142509698868, 45.476940125226974, 45.67064993083477, 45.999305695295334, 46.463044211268425, 47.43723213672638, 47.26241111755371, 45.348947793245316, 45.42224586009979, 46.69375263154507, 47.479143887758255, 46.309574246406555, 43.73061083257198, 44.215916991233826, 44.55350607633591, 41.230713576078415, 41.47985860705376, 42.52524331212044, 42.235049083828926, 42.146244049072266, 41.457656398415565, 43.804744854569435, 36.71771854162216, 26.781145334243774, 18.499744310975075, 12.514392882585526, 15.715373419225216, 25.296289511024952, 40.97413994371891, 53.588262274861336, 51.96894496679306, 40.56339718401432, 27.66047704964876, 17.859917543828487, 27.46894832700491, 20.337534695863724, 16.024403236806393, 20.460914075374603, 10.229694228619337, 3.430696022696793, 2.2012249706313014, 1.2095286534167826, 1.6505782306194305, 5.0624441262334585, 12.228614967316389, 23.818848989903927, 31.384157538414, 16.893412806093693, 30.328579880297184, 41.67930230498314, 47.88642883300781, 41.98738597333431, 30.83519909530878, 41.516937017440796, 49.418662413954735, 46.10070325434208, 47.5911732763052, 45.01613885164261, 43.18392276763916, 43.63711304962635, 47.22914770245552, 45.887777879834175, 45.67237503826618, 46.425639018416405, 40.92746704816818, 41.98630303144455, 41.838445365428925, 43.48310351371765, 43.256833255290985, 41.79895028471947, 42.79418908059597, 42.84306965768337, 44.03805993497372, 41.791875064373016, 41.73283763229847, 42.55490452051163, 43.63813139498234, 42.955543622374535, 45.50869882106781, 43.715297654271126, 44.77511018514633, 42.49264866113663, 44.01955112814903, 50.468435883522034, 52.41928540170193, 52.906149476766586, 52.493871599435806, 51.27054624259472, 51.71062342822552, 48.97219017148018, 49.86328035593033, 49.285137578845024, 53.7847725301981, 61.48996867239475, 64.88464191555977, 63.636082112789154, 66.05965286493301, 66.91805720329285, 47.51077339053154, 6.764103965833783, 6.689484044909477, 54.61209833621979, 53.73026445508003, 25.400025844573975, 9.745649602264166, 31.433416195213795, 32.43372581899166, 24.345970004796982, 35.754360035061836, 22.968726307153702, 29.728474281728268, 36.48714691400528, 35.44206239283085, 42.60543420910835, 47.817975506186485, 56.34312205016613, 11.323723923414946, 0.45002997969277203, 0.04835524785448797, 0.1143574612797238, 0.14499521726975217, 0.08056024904362857, 0.03129144708509557, 0.052242754682083614, 0.052006677506142296, 0.11425229895394295, 0.07135371415643021, 0.06350579933496192, 0.09329792999778874, 0.08945565336034633, 0.04808309859072324, 0.2062823364394717, 0.058544720232021064, 0.13009899237658828, 0.15610761707648635, 0.16171955969184637, 0.12249146660906263, 5.229533985257149, 69.44282412528992, 67.90095046162605, 49.23057250678539, 29.37110535800457, 45.44545501470566, 48.604757487773895, 29.020961746573448, 30.876945555210114, 51.99457839131355, 36.908981278538704, 28.87358095496893, 50.16106657683849, 65.47852724790573, 57.146972715854645, 10.632600858807564, 21.578194722533226, 64.11117061972618, 68.20542812347412, 71.70167371630669, 63.95097881555557, 67.12220504879951, 66.03655010461807, 62.66007408499718, 51.888925060629845, 51.358686313033104, 51.877768859267235, 51.34322874248028, 50.228915736079216, 54.307514280080795, 57.80183717608452, 59.1127098351717, 59.50045622885227, 60.7953317463398, 53.39412309229374, 48.294773921370506, 45.76955862343311, 43.442229107022285, 44.085804373025894, 45.92996321618557, 47.70189933478832, 45.99802516400814, 47.918005138635635, 48.89967866241932, 50.39015248417854, 49.61193144321442, 47.35902853310108, 49.83794331550598, 49.087890163064, 48.84314529597759, 49.93022136390209, 48.165786042809486, 49.4687133282423, 48.05012404918671, 46.35680191218853, 45.44267736375332, 48.5958431661129, 49.74997043609619, 49.57604616880417, 47.30818346142769, 52.47055605053902, 39.41474922001362, 32.876044884324074, 24.981601797044277, 23.29278241842985, 28.307101652026176, 34.54545870423317, 46.7752430588007, 51.15743011236191, 53.47041539847851, 48.29877130687237, 35.22657975554466, 23.61206218600273, 34.37004491686821, 21.826059222221375, 20.623927228152752, 21.637731827795506, 13.32468705251813, 4.017288833856583, 0.9722010476980358, 3.2113715540617704, 4.193728091195226, 10.57686259970069, 24.19477041810751, 28.521273359656334, 39.28117498755455, 35.34497760236263, 43.69062937796116, 48.551282957196236, 51.97294995188713, 54.057419300079346, 35.84518276154995, 43.97735819220543, 51.92266345024109, 51.44273780286312, 49.826764315366745, 47.92058899998665, 46.398884654045105, 46.597838178277016, 49.59495775401592, 47.29663208127022, 46.41621172428131, 47.903041541576385, 43.72379779815674, 43.084763288497925, 44.82954226434231, 44.132515266537666, 44.5367755740881, 42.72928476333618, 46.075221821665764, 48.336963057518005, 46.79418884217739, 46.49909667670727, 45.21266810595989, 45.501346215605736, 45.693334713578224, 45.09240075945854, 46.235056445002556, 46.78312003612518, 47.23603293299675, 46.754815354943275, 49.423070177435875, 53.95287550985813, 56.915040761232376, 55.47445446252823, 57.81801290810108, 54.54138793051243, 53.53947289288044, 54.98211108148098, 53.1792826205492, 53.77747692167759, 57.77783006429672, 66.04047909379005, 65.94043046236038, 66.32973477244377, 66.70216798782349, 67.24474087357521, 50.44264666736126, 5.726369675248861, 10.088010281324387, 63.01518402993679, 56.78479515016079, 27.653322033584118, 14.958387538790703, 38.11489596962929, 34.637596160173416, 21.693186052143574, 26.545183695852757, 29.063741751015186, 31.689906232059002, 40.35807900130749, 47.40918204188347, 50.99960558116436, 67.28302001953125, 65.93049019575119, 28.357186764478683, 0.38426910527050495, 0.010266391345794545, 0.2165333105949685, 0.06649945979006588, 0.0647313374793157, 0.07867652238928713, 0.024298393618664704, 0.032938224539975636, 0.390353825641796, 0.14172250928822905, 0.14750073751201853, 0.18550010863691568, 0.19949005247326568, 0.27313516242429614, 0.29656390368472785, 0.2419942303095013, 0.22498692182125524, 0.25233685970306396, 0.439752985839732, 0.5547000537626445, 5.3773014061152935, 82.14615806937218, 71.43663793802261, 55.69065526127815, 40.55544041097164, 55.40120579302311, 61.22696578502655, 33.35709527134895, 38.300253823399544, 66.88581213355064, 37.828987911343575, 36.59601487219334, 56.850862205028534, 72.50062644481659, 56.638928577303886, 10.559122301638126, 33.451406210660934, 68.75494703650475, 68.6044979095459, 74.784896671772, 67.01490640640259, 70.35277649760246, 71.32884532213211, 67.10249930620193, 55.227049738168716, 54.32195730507374, 53.68236422538757, 50.54168075323105, 48.95955204963684, 54.18432489037514, 58.3422289788723, 62.6324837654829, 63.69378201663494, 62.63890162110329, 57.77859382331371, 50.40938325226307, 47.612839713692665, 44.20430101454258, 45.393941178917885, 47.61932976543903, 49.89214740693569, 48.28120484948158, 50.449193716049194, 55.67522428929806, 54.153177961707115, 52.603168934583664, 52.829313799738884, 54.42156136035919, 53.72323103249073, 54.5395640283823, 54.80046942830086, 51.193752363324165, 53.79798822104931, 49.22548457980156, 47.086096778512, 46.510944440960884, 50.697753578424454, 54.01365704834461, 54.48429599404335, 51.34719952940941, 55.48301920294762, 43.972236067056656, 42.02936232089996, 27.674583792686462, 24.88419972360134, 25.0681022554636, 33.705061599612236, 55.63150003552437, 59.57089304924011, 63.869002014398575, 57.91772335767746, 36.952097564935684, 21.869992464780807, 34.54758279025555, 24.39565233886242, 21.108596920967102, 32.768024280667305, 23.888784237205982, 13.095981124788523, 10.806477628648281, 6.772636407986283, 5.0586633291095495, 10.517073757946491, 26.478181891143322, 34.13509592413902, 40.86614973843098, 35.825807601213455, 38.17213609814644, 46.770250126719475, 53.95266652107239, 57.37157866358757, 44.81442287564278, 47.9424112290144, 58.47170703113079, 54.60291422903538, 55.096868723630905, 50.281223729252815, 52.10216581821442, 50.60716263949871, 52.23211504518986, 53.265355601906776, 50.7322633266449, 48.8088521361351, 43.9805044233799, 43.98433081805706, 44.42959472537041, 44.50949303805828, 45.18555276095867, 44.1224268078804, 48.49259130656719, 50.17617076635361, 52.32426390051842, 49.8959282040596, 49.14986103773117, 47.7799129486084, 48.27474519610405, 46.56152732670307, 51.14389903843403, 50.22668905556202, 48.23250286281109, 50.07031984627247, 54.50055152177811, 57.63350620865822, 60.95007084310055, 54.89634208381176, 59.18411560356617, 55.698349848389626, 56.01817108690739, 56.50186613202095, 56.822340935468674, 56.7912358045578, 59.80516567826271, 68.67208108305931, 70.81593364477158, 73.08720856904984, 72.81788662075996, 67.41682603955269, 58.50641056895256, 9.48401939123869, 10.078428145498037, 66.12747922539711, 59.748560115695, 37.523659095168114, 20.394518338143826, 40.82776419818401, 43.03015261888504, 37.303210124373436, 50.71255758404732, 38.561702594161034, 47.567751333117485, 50.222767665982246, 50.378525108098984, 57.357819601893425, 69.64272379875183, 82.5395205616951, 29.823851063847542, 1.2340829358436167, 0.10570088750682771, 0.2723690285347402, 0.2654393878765404, 0.2726070204516873, 0.14455835946137086, 0.3056138305692002, 0.16203871287871152], [0.18104593124007806, 0.07285898260306567, 0.020593655499396846, 0.02060217535472475, 0.09522324660792947, 0.1246977158007212, 0.10183802369283512, 0.05269277447951026, 0.046137666067807004, 0.05870045621122699, 0.5214002437423915, 0.3690334368729964, 8.299213517457247, 69.8605889081955, 48.910667672753334, 47.976221814751625, 37.51581631600857, 44.97809149324894, 37.440394163131714, 27.362286150455475, 62.23394215106964, 83.52887347340584, 37.53685958683491, 21.110202334821224, 44.18110705912113, 55.800214782357216, 68.59401807188988, 30.769171938300133, 1.4605427091009915, 29.408660642802715, 56.51377469301224, 65.03202080726624, 64.72564324736595, 63.99219900369644, 61.25566944479942, 56.20148845016956, 47.270037308335304, 50.94976745545864, 51.4005296677351, 54.0833643078804, 50.492602586746216, 48.463610261678696, 50.23058384656906, 50.18613003194332, 52.349764332175255, 53.046472147107124, 50.72225086390972, 47.6016379147768, 44.517275020480156, 40.327327251434326, 37.935089617967606, 41.802765280008316, 42.65861235558987, 43.85525554418564, 43.88736382126808, 47.276417165994644, 46.99713975191116, 48.39039959013462, 45.78949235379696, 47.271333038806915, 47.515321746468544, 48.76298099756241, 46.827592849731445, 46.72331124544144, 43.85403960943222, 42.830458134412766, 45.91818764805794, 43.38147796690464, 42.83653400838375, 43.47658686339855, 44.25337538123131, 43.62837731838226, 49.720655009150505, 33.72354380786419, 28.809375800192356, 21.016554459929466, 14.826925043016672, 16.128206066787243, 23.680393919348717, 43.09359781444073, 59.370689392089844, 45.61366818845272, 35.07415473461151, 16.811751388013363, 9.247033707797527, 22.35660955309868, 28.190934285521507, 18.692217282950878, 25.300347693264484, 21.866175569593906, 11.609000265598297, 1.7947677872143686, 3.341046483255923, 1.7909779655747116, 1.830662798602134, 5.0190837029367685, 13.174127731472254, 26.058401316404343, 29.902700632810593, 32.1418596804142, 49.208723679184914, 45.75871780514717, 45.89788153767586, 31.221488267183304, 38.80786098539829, 50.10392524302006, 48.946856930851936, 49.29122105240822, 43.45664173364639, 44.31303597986698, 42.60790787637234, 45.40840320289135, 43.71178664267063, 46.25497117638588, 44.41483251750469, 42.47542418539524, 41.41701377928257, 42.527504190802574, 43.20555500686169, 43.28163452446461, 42.2744719684124, 41.223835945129395, 41.60399794578552, 43.10859940946102, 41.84847302734852, 42.15866558253765, 45.95696836709976, 43.44931572675705, 42.810520604252815, 42.23370395600796, 43.73303510248661, 43.993374332785606, 41.74595072865486, 45.91561518609524, 52.54138045012951, 54.84378330409527, 55.55670864880085, 56.33431792259216, 54.454072415828705, 57.6481544226408, 54.640042036771774, 52.6810647547245, 49.17412653565407, 56.12354323267937, 59.763683304190636, 61.18388369679451, 61.730788350105286, 64.4678346812725, 66.24960467219353, 31.283755525946617, 1.2669660151004791, 17.764780148863792, 57.73292787373066, 51.33404463529587, 16.9636083394289, 16.133679673075676, 40.445637702941895, 34.65654194355011, 19.55355506390333, 36.103865280747414, 17.593800723552704, 28.701757974922657, 41.78228437900543, 38.702222853899, 26.751966699957848, 37.92433999478817, 58.063274547457695, 46.80571362376213, 2.895337762311101, 0.11578156845644116, 0.08883766699000262, 0.043383259180700406, 0.052650742945843376, 0.07035928822006099, 0.0750334159238264, 0.054176546618691646, 0.11117825648398139, 0.1277243869844824, 0.0890748128585983, 0.047642908539273776, 0.043234209952061065, 0.055533775157528, 0.11843713611597195, 0.0884872990718577, 0.06475099697127007, 0.09142060065641999, 0.1590025718905963, 0.09965885546989739, 13.270501010119915, 79.00735169649124, 53.4596923738718, 59.20136287808418, 39.7928973287344, 47.74608716368675, 39.93014216423035, 29.472520016133785, 42.22268834710121, 73.6943855881691, 43.73034864664078, 31.273195892572403, 47.212044820189476, 62.16456927359104, 71.91405951976776, 39.633009508252144, 1.6231936938129365, 18.877333849668503, 47.593365758657455, 65.68212792277336, 66.41504779458046, 67.55036607384682, 65.95843389630318, 62.135614827275276, 51.75817787647247, 54.359617084264755, 54.78654697537422, 56.60400465130806, 55.341260209679604, 54.40041929483414, 54.46535021066666, 57.31748856604099, 58.58212910592556, 58.207165226340294, 52.34494999051094, 49.81690004467964, 46.74672558903694, 45.347644463181496, 44.36309449374676, 46.26826286315918, 44.995882138609886, 44.09666799008846, 45.09620055556297, 49.60240915417671, 49.87978287041187, 49.7371993213892, 49.537299647927284, 50.28871692717075, 49.94478598237038, 50.233365297317505, 48.83833095431328, 51.03896386921406, 47.29148715734482, 47.32452258467674, 48.50886583328247, 47.95803979039192, 48.19190204143524, 48.12189839780331, 46.59852594137192, 48.93734224140644, 52.244418784976006, 36.88729204237461, 35.10125108063221, 32.90819875895977, 28.958686888217926, 28.866414539515972, 35.466198697686195, 48.934207409620285, 55.38124926388264, 54.10429358482361, 42.973543256521225, 19.091372564435005, 12.90833294391632, 27.965917959809303, 26.837175227701664, 21.881462149322033, 32.05743961036205, 20.572270900011063, 7.504817694425583, 2.215597224421799, 0.72241693851538, 1.0541125992313027, 4.647228056564927, 15.187371801584959, 22.65556041151285, 29.093556851148605, 37.752805799245834, 48.42661924660206, 51.79725497961044, 51.5276138484478, 55.50296813249588, 40.496239587664604, 39.67937082052231, 52.31329008936882, 50.09257145226002, 51.0116433352232, 47.526607140898705, 47.62893944978714, 46.61191642284393, 46.735812574625015, 47.51342944800854, 46.48290954530239, 47.831704169511795, 44.479106068611145, 44.28259201347828, 45.1807726174593, 44.82022516429424, 43.92258033156395, 42.35916182398796, 43.92940476536751, 45.49956031143665, 47.300032898783684, 45.211452171206474, 45.80476373434067, 47.10152395069599, 46.23935781419277, 44.16606746613979, 45.107805132865906, 45.429818853735924, 47.264018431305885, 45.63857585191727, 52.23709657788277, 56.48992337286472, 57.312997207045555, 59.42151926457882, 59.72851239144802, 57.61456422507763, 58.10086593031883, 56.49510629475117, 56.2282770127058, 52.008565440773964, 60.85422858595848, 65.04558607935905, 66.14827930927277, 66.98914378881454, 64.39747005701065, 64.01030883193016, 27.233218476176262, 1.1992084071971476, 23.321750164031982, 67.49622657895088, 55.84505997598171, 21.527539640665054, 20.282270461320877, 43.453617095947266, 40.61314411461353, 18.63898403942585, 30.26872169226408, 22.130591981112957, 35.882447361946106, 35.708283707499504, 50.59409134089947, 31.027941852808, 55.127035304903984, 66.64064168930054, 72.71975308656693, 8.903672732412815, 0.44881368870846927, 0.023960510479810182, 0.03196541736542713, 0.07251797316712327, 0.0503951631981181, 0.021243079245323315, 0.14071710698772222, 0.1982236813637428, 0.3378866269486025, 0.196827775798738, 0.130360480688978, 0.1831506472080946, 0.2286508900579065, 0.3407048585359007, 0.19353951240191236, 0.24685200245585293, 0.20497290592174977, 0.6318591884337366, 0.7783703610766679, 15.198908932507038, 94.54693704843521, 62.62860417366028, 59.70835827291012, 52.22511202096939, 62.030577063560486, 51.298128962516785, 35.72459243237972, 73.72024700045586, 88.56285855174065, 42.52811215817928, 32.685857489705086, 58.32648262381554, 66.083302795887, 80.49573943018913, 36.20362512767315, 2.8072466142475605, 33.9479673653841, 60.83608455955982, 69.92868885397911, 70.7708452641964, 70.07037565112114, 68.89782696962357, 66.18293344974518, 52.71884612739086, 54.720529317855835, 54.83345925807953, 54.01788242161274, 53.592369854450226, 55.42008697986603, 56.80345214903355, 57.76317425072193, 61.52982473373413, 59.88036744296551, 54.48746882379055, 51.89949989318848, 50.287166610360146, 46.03248551487923, 43.3317044377327, 46.532846465706825, 46.52254141867161, 47.39642612636089, 49.028586745262146, 55.641478300094604, 55.282701551914215, 53.79312068223953, 52.70097188651562, 56.378334760665894, 55.604570880532265, 56.026435643434525, 56.84021137654781, 54.79978546500206, 50.884137377142906, 48.687893226742744, 49.86026331782341, 51.0414033383131, 49.58440192043781, 51.40964537858963, 52.827231511473656, 52.73235060274601, 57.88183428347111, 40.59685438871384, 43.39763090014458, 30.5545499548316, 29.98684521764517, 24.696087017655373, 34.548730328679085, 54.039058685302734, 61.834290996193886, 68.2426281273365, 50.60626968741417, 22.970916889607906, 19.723120965063572, 26.80030770599842, 37.17475801706314, 25.25601927191019, 35.04510909318924, 35.73955982923508, 20.165516026318073, 13.988294843584299, 8.072863463312387, 3.1857452541589737, 5.796648804098368, 14.992915336042643, 26.39487136155367, 36.45452946424484, 48.546214029192924, 37.339748963713646, 49.77952904999256, 55.23135110735893, 53.72776038944721, 46.52859829366207, 44.69380594789982, 58.816485330462456, 53.34348700940609, 58.630257323384285, 48.326141238212585, 52.894229516386986, 50.330624878406525, 52.222638353705406, 49.615472853183746, 51.07028178870678, 48.659596145153046, 47.887606769800186, 44.42432060837746, 47.32352703809738, 43.365575820207596, 44.355289712548256, 44.33326609432697, 46.906708404421806, 46.872647032141685, 53.68383854627609, 48.00799570977688, 49.259473755955696, 50.46203322708607, 48.65197375416756, 46.48439906537533, 48.646448850631714, 46.20100647211075, 48.62614654004574, 47.692168056964874, 57.49798648059368, 62.85028427839279, 64.39211994409561, 61.57457113265991, 62.34850600361824, 59.427416548132896, 61.533730924129486, 58.07656243443489, 59.38523881137371, 53.90540845692158, 65.00434309244156, 65.98257780075073, 68.29042956233025, 72.14818775653839, 73.01183581352234, 64.41158249974251, 41.437513679265976, 1.4822784927673638, 22.290267013013363, 71.1408694088459, 60.01393407583237, 29.66736976057291, 27.109445817768574, 48.46216253936291, 44.23979490995407, 30.272758975625038, 55.58261565864086, 30.657009556889534, 48.69725592434406, 56.361630856990814, 58.50611038506031, 36.847344785928726, 58.52933093905449, 75.28604418039322, 78.66901025176048, 9.11027904599905, 0.5699273804202676, 0.1585756885469891, 0.17841366701759398, 0.33214519440662116, 0.17864187742816284, 0.2482833233079873, 0.26449205121025443], [0.11550868817721494, 0.15795197279658169, 0.1282613308285363, 0.09137716275290586, 0.23533686879090965, 0.13034819072345272, 0.025500479896436445, 0.08461096527753398, 0.03277552721556276, 0.027441589409136213, 0.5313167022541165, 0.1708527110167779, 23.28625436872244, 66.17496147751808, 51.11992232501507, 39.97970290482044, 39.72342565655708, 45.5024291574955, 39.05314162373543, 37.45902456343174, 61.70854054391384, 86.45081788301468, 34.227221980690956, 13.787920195609331, 33.70716288685799, 56.011369451880455, 59.28135998547077, 58.68044503033161, 6.662029568105936, 0.16142310138093308, 9.160693790763617, 50.70218414068222, 68.39669466018677, 61.77506357431412, 63.10175098478794, 49.78250049054623, 54.06694918870926, 53.689732030034065, 61.4179777354002, 60.07712088525295, 58.99359002709389, 54.04093958437443, 50.20745828747749, 52.95597240328789, 50.44211469590664, 55.05786381661892, 50.55327773094177, 47.7725375443697, 44.71468202769756, 41.78685173392296, 40.932152196764946, 41.83251768350601, 42.41979897022247, 42.73705534636974, 44.89853136241436, 46.508098393678665, 46.97134293615818, 47.775923162698746, 46.63774363696575, 47.40485407412052, 48.19209963083267, 48.408581614494324, 45.658760368824005, 46.40302263200283, 44.49284993112087, 43.301397264003754, 43.685712441802025, 46.09590031206608, 45.28984196484089, 44.29056778550148, 44.52699489891529, 45.98013952374458, 44.60857272148132, 29.7096785902977, 28.10225274413824, 25.362014584243298, 15.171654894948006, 18.27816490083933, 27.002076879143715, 48.753948882222176, 54.453069269657135, 40.153627172112465, 27.969487868249416, 12.793875485658646, 12.138866633176804, 19.591347835958004, 33.43933425843716, 18.507480695843697, 22.377048656344414, 20.96243016421795, 7.14685695245862, 1.52923732297495, 4.676145929843187, 2.1350683830678463, 4.033712977543473, 7.255433276295662, 14.42437844350934, 30.941483192145824, 39.61275279521942, 28.26986365020275, 46.87470652163029, 46.814840734004974, 48.2187931984663, 37.736804857850075, 33.03024061024189, 51.441704258322716, 47.97922745347023, 48.665546625852585, 49.85076002776623, 48.286334574222565, 46.944189593195915, 45.36083735525608, 44.382549449801445, 43.825788125395775, 43.354898393154144, 41.897828578948975, 44.6474826335907, 43.42133782804012, 44.40591059625149, 45.610662549734116, 43.30756053328514, 43.07806804776192, 40.210669711232185, 40.52528902888298, 42.4555778503418, 46.420991867780685, 44.82706479728222, 45.07125109434128, 43.07499021291733, 44.907213896512985, 43.091504126787186, 46.70813485980034, 43.7314809858799, 48.70922148227692, 53.429191410541534, 58.64520952105522, 56.132400557398796, 57.3644882440567, 56.40891171991825, 58.10046315193176, 56.06104798614979, 57.97539286315441, 50.533461794257164, 55.10850749909878, 59.989569783210754, 64.01255071163177, 59.167810678482056, 65.63460767269135, 53.43334838747978, 9.280214477330446, 0.5751314386725426, 34.77318808436394, 48.294713124632835, 53.877194970846176, 12.120854649692774, 20.639324001967907, 43.734137043356895, 30.797890797257423, 8.056745678186417, 26.209766194224358, 20.069476179778576, 18.66487205028534, 36.01832427084446, 31.745782233774662, 33.17342072725296, 29.136593341827393, 54.179058372974396, 66.49501070380211, 25.183885842561722, 0.6403000792488456, 0.20463993394514546, 0.029826788959326223, 0.11697302717948332, 0.06892681703902781, 0.0393730011273874, 0.03974705468863249, 0.07059301278786734, 0.10676067438907921, 0.08278664012323134, 0.060633836255874485, 0.17428597522666678, 0.1559560259920545, 0.1352645331644453, 0.08895356819266453, 0.03555443610821385, 0.014270551728259306, 0.18324806151213124, 0.1634455577004701, 35.10257340967655, 74.31571304798126, 56.049606800079346, 44.018437787890434, 41.60787753760815, 52.673107981681824, 39.65118773281574, 33.65331597626209, 44.9817430973053, 82.3628680408001, 35.87859436869621, 16.873659566044807, 34.853656366467476, 58.45946408808231, 63.20201240479946, 65.36808237433434, 11.90619371831417, 0.32193347986321896, 5.536282975226641, 49.97981250286102, 72.7673265337944, 63.564197570085526, 65.70254042744637, 54.55545857548714, 59.12007763981819, 57.85673663020134, 64.87847104668617, 61.063973531126976, 61.13987445831299, 60.13543635606766, 57.85572208464146, 58.19528706371784, 55.398165956139565, 58.887701109051704, 53.44172313809395, 49.99167546629906, 48.75920780003071, 47.6969937980175, 44.52624633908272, 45.27271628379822, 45.32469369471073, 44.99404303729534, 46.332160234451294, 49.364792704582214, 49.16573278605938, 49.430111199617386, 50.61228096485138, 50.03950349986553, 49.54055227339268, 50.5591332167387, 48.481883481144905, 50.65180644392967, 47.7920912951231, 48.35551366209984, 46.74271300435066, 49.94880236685276, 50.69477453827858, 50.309786796569824, 46.537759602069855, 50.7580753415823, 47.987343817949295, 32.16180860996246, 35.45541487634182, 35.73533445596695, 30.555302314460278, 32.09267131984234, 42.17575326561928, 51.400928646326065, 53.41146156191826, 55.21733745932579, 35.85592478513718, 21.020403653383255, 20.31615324318409, 22.59277068078518, 34.59296375513077, 19.407240115106106, 31.089747436344624, 32.616355419158936, 14.879970196634531, 0.29979693645145744, 2.634100830182433, 0.6631306791678071, 3.1705921422690153, 11.65935231372714, 19.298315159976482, 36.53802618384361, 44.07042659819126, 43.38046722114086, 50.04449263215065, 50.319673866033554, 55.8758345246315, 44.719237983226776, 33.2993383705616, 51.44681118428707, 50.98860137164593, 50.27799770236015, 51.14427521824837, 50.988753363490105, 50.834021866321564, 47.52078205347061, 47.13625408709049, 46.592830047011375, 46.57119780778885, 44.202503710985184, 45.679134875535965, 45.156537517905235, 44.5126810669899, 46.07512302696705, 42.503949254751205, 43.95892918109894, 45.270330011844635, 46.41013965010643, 45.85687033832073, 45.714807361364365, 46.858899369835854, 47.9469595849514, 45.15874519944191, 47.77233615517616, 45.56395165622234, 49.02506813406944, 49.168943613767624, 56.03662669658661, 58.52527275681496, 61.201210767030716, 58.24074402451515, 60.079875737428665, 57.333329916000366, 58.86198028922081, 57.38273486495018, 60.57753883302212, 53.23238477110863, 57.491222843527794, 64.02958139777184, 68.24088782072067, 63.49597603082657, 68.61886873841286, 49.278921112418175, 9.982814826071262, 0.7387005491182208, 41.56028889119625, 57.813950926065445, 60.15079513192177, 14.338562898337841, 20.855047926306725, 46.25972092151642, 43.63873556256294, 12.800489980727434, 28.996675349771976, 21.615814603865147, 24.635050892829895, 30.91623544692993, 41.65728248655796, 35.81387624144554, 39.99452590942383, 65.99303483963013, 72.42542088031769, 48.87824021279812, 0.5550137150567025, 0.09146606462309137, 0.06074462035030592, 0.05323370365658775, 0.1418795922654681, 0.08302403090056032, 0.03113211911113467, 0.2979200449772179, 0.25297718471847475, 0.32364775193855166, 0.14931938523659483, 0.3540545218857005, 0.30247594113461673, 0.3745197190437466, 0.15230948338285089, 0.23008865275187418, 0.1686900036293082, 0.6396132067311555, 0.33499103388749063, 41.69456608593464, 86.66416883468628, 64.04331386089325, 52.290286123752594, 55.755734369158745, 64.78584721684456, 54.448129534721375, 48.50304834544659, 67.26609572768211, 92.3160007596016, 37.969561368227005, 21.317973285913467, 45.493507236242294, 66.32328271865845, 68.65930616855621, 66.7535488307476, 8.699019514024258, 0.4194196534808725, 13.009120635688305, 55.38127966225147, 73.74556124210358, 68.36903974413872, 71.20135456323624, 57.942365035414696, 59.57576438784599, 58.21873560547829, 67.47812435030937, 60.933423936367035, 59.63015466928482, 58.11816640198231, 57.33924999833107, 58.62065903842449, 57.24845767021179, 65.36502733826637, 56.65007717907429, 52.489232048392296, 51.92391358315945, 47.820357978343964, 45.55540211498737, 44.79718320071697, 46.395016461610794, 47.37936124205589, 49.699338153004646, 56.20973780751228, 55.512156039476395, 54.029996171593666, 55.01232326030731, 57.35954090952873, 57.405438646674156, 54.98468354344368, 52.83717557787895, 55.31863622367382, 52.964803129434586, 49.94627170264721, 46.392136216163635, 51.624493449926376, 54.062298238277435, 52.001235634088516, 50.58719851076603, 53.851158767938614, 52.0940912514925, 40.320054441690445, 39.149816036224365, 37.89583392441273, 26.663684137165546, 27.45880287140608, 37.19436876475811, 56.86083287000656, 59.935719072818756, 61.61210171878338, 45.99950708448887, 33.05462010204792, 39.570643454790115, 35.02565033733845, 37.04642750322819, 25.684746466577053, 30.041978359222412, 35.917774066329, 23.627928234636784, 10.635737590491772, 8.195633925497532, 4.749934170395136, 8.1808565184474, 14.883105028420687, 25.08598979562521, 43.23730230331421, 49.84652325510979, 39.84299764037132, 49.337909147143364, 51.60043314099312, 59.6333122998476, 49.822185561060905, 38.93060199916363, 56.49356357753277, 57.36616015434265, 54.919080063700676, 56.90899148583412, 54.8379772156477, 55.226156786084175, 50.53136430680752, 50.51959253847599, 50.51564075052738, 47.05580860376358, 47.48663328588009, 45.77164851129055, 48.00742194056511, 45.98371513187885, 47.53150127828121, 41.651901975274086, 45.76069749891758, 48.792330622673035, 49.76273015141487, 50.39090484380722, 50.86638852953911, 52.04731576144695, 52.08221688866615, 47.39321909844875, 50.6223314255476, 48.833079636096954, 50.74172101914883, 49.25996392965317, 58.78802105784416, 63.24061833322048, 70.24771973490715, 62.358499467372894, 63.501641526818275, 61.31855607032776, 60.38159854710102, 59.0131513774395, 65.2893278002739, 58.038560673594475, 60.99142022430897, 66.78525432944298, 71.31489247083664, 68.36915373802185, 74.38702762126923, 60.83037346601486, 17.048324793577194, 0.7626484078355134, 43.8043724745512, 59.49590027332306, 65.09557619690895, 22.544650062918663, 32.61844530701637, 50.02200923860073, 40.87798610329628, 17.725188173353672, 45.43813280761242, 32.01330117881298, 34.162340462207794, 50.50859592854977, 48.37233155965805, 48.16310338675976, 42.39525988698006, 74.61721166968346, 86.80240541696548, 54.851344898343086, 1.2818727339617908, 0.3413965995423496, 0.14457666082307696, 0.1748950409819372, 0.21530051424633712, 0.13474672188749537, 0.17491028469521552], [0.06309099815553054, 0.11908569154911675, 0.05984207600704394, 0.04933367308694869, 0.1062258605088573, 0.15690230880863965, 0.054607942220172845, 0.013684414625458885, 0.06840653441031463, 0.04246332260663621, 0.3215779911261052, 0.357453795731999, 35.46810619533062, 67.92374923825264, 44.8688093572855, 44.80414442718029, 38.027599453926086, 42.9395654797554, 35.92494808137417, 39.03427943587303, 45.055067762732506, 44.58108879625797, 29.344322495162487, 15.690297614783049, 17.268718667328358, 42.472821325063705, 57.5874412804842, 61.69389992952347, 39.64361093938351, 1.2344294297508895, 0.05831680668052286, 35.17271384596825, 67.48734265565872, 61.486514657735825, 62.227163314819336, 54.857432171702385, 58.925311490893364, 58.78289133310318, 61.1960506439209, 64.59520384669304, 63.87758195400238, 54.630952924489975, 51.6357484459877, 51.96896776556969, 50.395711585879326, 51.8346031755209, 50.1805405318737, 47.409710213541985, 44.59505684673786, 45.89000076055527, 42.30237767100334, 41.193342581391335, 40.51207333803177, 42.36094392836094, 45.70108249783516, 45.33929631114006, 45.620652213692665, 48.21487180888653, 49.02649685740471, 49.97108817100525, 47.86456860601902, 47.71237537264824, 47.64128498733044, 48.16945284605026, 42.90751799941063, 41.92226126790047, 47.54385061562061, 47.24883444607258, 45.784981995821, 44.27161440253258, 43.96914683282375, 49.56523574888706, 39.66383345425129, 32.165935188531876, 27.911529578268528, 15.691129770129919, 19.431612007319927, 14.128671661019325, 23.391427025198936, 51.05660632252693, 42.7134358137846, 32.18340665102005, 21.887040250003338, 20.59003494679928, 25.426890403032303, 27.456382401287556, 30.950095430016518, 21.80057018995285, 22.907365299761295, 26.364913769066334, 8.341907076537609, 4.140591267496347, 4.483745628967881, 3.4668831434100866, 9.444440715014935, 13.976004403084517, 13.350663408637047, 25.747887678444386, 34.64619129896164, 27.891441956162453, 44.496915712952614, 43.81481431424618, 44.18607719242573, 40.41481755673885, 31.689393259584904, 48.042448461055756, 47.575331926345825, 49.5093597471714, 49.33635123074055, 49.084333553910255, 47.47965686023235, 46.43997944891453, 45.14891892671585, 43.239160403609276, 43.07564377784729, 43.00204172730446, 42.510002329945564, 43.9022172242403, 45.081597939133644, 44.29288186132908, 44.381246119737625, 43.55710454285145, 40.031524524092674, 40.00492215156555, 43.34821455180645, 43.91049697995186, 45.42230285704136, 44.54367220401764, 43.061918914318085, 46.21187388896942, 45.07271781563759, 44.3007056415081, 48.086541295051575, 52.550465762615204, 55.651426166296005, 57.34504468739033, 55.735489055514336, 56.22486859560013, 56.33322738111019, 58.29618684947491, 58.28691154718399, 61.194830909371376, 51.09805069863796, 53.717979714274406, 58.4329567104578, 60.30794329941273, 61.13202027976513, 61.23173072934151, 31.61588240414858, 3.97454468999058, 5.431957198306918, 47.689922377467155, 37.810748890042305, 40.725291296839714, 10.072415918111801, 13.396870829164982, 56.238810047507286, 61.897223219275475, 13.612151127308607, 16.009627729654312, 21.87895428389311, 18.461480364203453, 38.022059351205826, 26.827400252223015, 41.36911354959011, 28.754981718957424, 36.01016230881214, 53.8423166424036, 61.59274935722351, 4.08989486284554, 0.3891279164236039, 0.0305332226344035, 0.022300027412711643, 0.03831492489553057, 0.04924155029584654, 0.09403241871041246, 0.0067626912914420245, 0.0650957171455957, 0.08225374098401517, 0.05215636127104517, 0.0482810553512536, 0.14125511952443048, 0.04122616985114291, 0.06414563453290612, 0.030875695956638083, 0.03944732350646518, 0.2279025677125901, 0.3246559447143227, 49.25660490989685, 74.94236022233963, 51.419707238674164, 40.226807445287704, 37.1291908621788, 49.91939574480057, 38.34017068147659, 32.408654764294624, 40.46998679637909, 48.05175416171551, 32.879251912236214, 15.24837277829647, 19.487759694457054, 44.43880923092365, 60.67384086549282, 63.8486123085022, 49.9425745010376, 3.8886177632957697, 0.04857907217228785, 37.10763081908226, 70.0951275229454, 64.59967240691185, 65.90234130620956, 61.873539090156555, 62.949014380574226, 64.9735951423645, 63.11296418309212, 64.89644408226013, 65.35151526331902, 58.41159425675869, 58.56403827667236, 59.753735437989235, 55.50862602889538, 57.11004249751568, 52.89487548172474, 49.288644790649414, 47.1177376806736, 47.743636295199394, 46.10335551202297, 45.14684043824673, 44.91028033196926, 45.869117081165314, 47.022043615579605, 48.039986193180084, 47.53750495612621, 49.92981858551502, 50.59876888990402, 53.73537518084049, 50.882568061351776, 50.7988091558218, 51.05159819126129, 51.21104523539543, 46.81922189891338, 48.2085907459259, 48.904314413666725, 49.85148198902607, 50.527735501527786, 49.15046900510788, 48.48105512559414, 53.95840421319008, 40.87930463254452, 34.531467854976654, 37.223931178450584, 35.076943784952164, 31.27998612821102, 28.31531871110201, 37.1899875998497, 50.754583328962326, 50.41230909526348, 46.26901522278786, 30.170470364391804, 23.308239988982677, 29.551033303141594, 25.503006018698215, 33.36823247373104, 28.277869820594788, 26.713478565216064, 33.94705541431904, 11.564012579619884, 1.8828750844113529, 8.66990452632308, 4.523407900705934, 11.29998754709959, 12.973533645272255, 16.615328527987003, 33.010040894150734, 39.509854316711426, 39.94590371847153, 50.0882700830698, 49.96736817061901, 55.19679196178913, 49.007353484630585, 32.87739381194115, 49.30488511919975, 50.59388995170593, 52.8838674724102, 51.98503330349922, 52.12060242891312, 51.9446224719286, 50.789765641093254, 48.16548205912113, 46.863307133316994, 46.5744162350893, 45.67430533468723, 44.83268469572067, 44.990212842822075, 44.64905574917793, 43.965924605727196, 45.28804086148739, 45.44392369687557, 44.0566561371088, 44.61651809513569, 46.78753919899464, 45.939641296863556, 46.85366705060005, 44.57563228905201, 46.21478833258152, 48.19702796638012, 47.3980600386858, 47.9698533564806, 52.03782767057419, 56.92563459277153, 58.85671757161617, 60.20916759967804, 59.132943749427795, 60.61140261590481, 58.93703006207943, 60.19280567765236, 59.771461486816406, 61.64177052676678, 54.62035149335861, 58.943200930953026, 61.80021062493324, 66.37064337730408, 66.42214581370354, 62.25470423698425, 33.99646796286106, 3.475797465071082, 9.368858970701694, 55.95901966094971, 38.522154316306114, 47.11211398243904, 14.26066042855382, 17.31499258428812, 53.28562371432781, 70.9342896938324, 20.74608687311411, 21.14495526999235, 25.509146489202976, 23.546652495861053, 37.194965332746506, 31.269314400851727, 46.20433509349823, 30.283871479332447, 56.79779425263405, 60.02251401543617, 79.86339256167412, 9.435878824442625, 0.7538582920096815, 0.11301731326966546, 0.0484805075393524, 0.04083534004166722, 0.12048836550093256, 0.11287246830761433, 0.09814197241212241, 0.11740722809918225, 0.1046599808614701, 0.10214435256784782, 0.1871845463756472, 0.2559695835225284, 0.19633052201243117, 0.14017593290191144, 0.20949084864696488, 0.24789255287032574, 0.5638301919680089, 0.38698575168382376, 57.574480175971985, 86.10714912414551, 59.887138679623604, 56.231510639190674, 52.07521766424179, 60.2063063532114, 53.06268967688084, 48.55016201734543, 54.02972258627415, 48.246090933680534, 33.05981822311878, 24.371054358780384, 28.281384631991386, 53.70995454490185, 66.13905340433121, 69.07894045114517, 47.66238905489445, 2.1944273728877306, 0.19203863746952266, 42.284784615039825, 71.59268796443939, 66.42599880695343, 69.60053086280823, 61.648955941200256, 64.50672939419746, 64.31303098797798, 63.575524762272835, 66.62994146347046, 64.32859495282173, 57.04769544303417, 57.473945170640945, 60.81287920475006, 55.56922137737274, 59.21369321644306, 56.87200427055359, 51.81777007877827, 48.03704135119915, 50.14772169291973, 47.10177853703499, 46.750646978616714, 44.87162500619888, 46.21731899678707, 49.10145543515682, 51.94494925439358, 52.7434878051281, 56.10207438468933, 55.744604766368866, 59.07323755323887, 57.6702768355608, 57.0141926407814, 53.561241924762726, 58.96091178059578, 47.84411430358887, 52.391679883003235, 50.76288588345051, 52.36718259751797, 49.72413182258606, 52.07263760268688, 48.10472331941128, 57.188717275857925, 45.013296604156494, 45.46532414853573, 38.96340183913708, 34.363832250237465, 29.579666666686535, 25.41751440614462, 38.72534841299057, 50.53441934287548, 56.32389508187771, 55.39700701832771, 36.20293356478214, 34.81883503496647, 38.09811607003212, 36.1870352178812, 38.18074643611908, 33.03767301142216, 29.09012943506241, 37.393660470843315, 16.097021140158176, 8.642733134329319, 11.411852594465017, 10.834256038069725, 17.8561994433403, 19.39052101224661, 18.711902126669884, 34.78888124227524, 46.70613996684551, 39.23975721001625, 51.75133064389229, 51.410454735159874, 55.62970653176308, 52.67523966729641, 40.08618079125881, 54.98078875243664, 58.46210494637489, 57.56535306572914, 56.70618116855621, 56.06024622917175, 55.75223095715046, 53.328356221318245, 50.58750629425049, 52.94047683477402, 50.187839940190315, 46.95976875722408, 45.851531624794006, 47.087213918566704, 46.41780003905296, 44.80206213891506, 46.72895014286041, 45.54074250161648, 46.509477719664574, 46.71261101961136, 53.43000076711178, 49.59539473056793, 51.978193670511246, 49.12182614207268, 48.57808291912079, 49.9935145676136, 49.71990644931793, 49.861741438508034, 52.17894069850445, 60.97408555448055, 65.58787778019905, 67.98953890800476, 67.37763494253159, 61.293203830718994, 63.578887581825256, 63.06217610836029, 62.43202932178974, 67.23474740982056, 56.76898039877415, 60.463529750704765, 64.2043188214302, 66.64210841059685, 69.83084410429001, 68.81668612360954, 46.58972181379795, 4.733570823445916, 7.054814491420984, 58.055918142199516, 47.23251052200794, 53.61493684351444, 19.822829514741898, 23.25953420251608, 62.02545113861561, 72.4695973098278, 21.709722764790058, 29.131475016474724, 34.65424306690693, 34.34190362691879, 55.41522704064846, 38.925867453217506, 59.659443497657776, 37.76983268558979, 62.97535456717014, 69.3622076511383, 94.1310265660286, 10.42795903980732, 0.8298717287834734, 0.25083507935050875, 0.15907999273622409, 0.14339369226945564, 0.2666933205910027, 0.20907011028612033], [0.040085229120450094, 0.04485873410885688, 0.06029544289049227, 0.0804403550864663, 0.1240380058879964, 0.21826540905749425, 0.03169018076732755, 0.07307570456760004, 0.0757756971870549, 0.18427203234750777, 0.37621733732521534, 1.006163447163999, 53.39996337890625, 63.93568843603134, 44.91448670625687, 36.28870636224747, 45.50171859562397, 40.3159012645483, 29.332913607358932, 26.807299330830574, 19.28408682346344, 14.72104562446475, 18.668932132422924, 15.232938006520271, 13.668636046350002, 35.21946273744106, 54.96357947587967, 51.67361721396446, 58.09661775827408, 28.102889209985733, 0.15594401804264635, 20.03143262118101, 66.54948458075523, 62.36498571932316, 66.45244538784027, 60.102085545659065, 60.024695098400116, 63.780557960271835, 63.56645464897156, 64.56899285316467, 65.8119061589241, 57.99017786979675, 53.675300404429436, 49.968983083963394, 50.49709774553776, 51.29643805325031, 48.80435697734356, 47.34104409813881, 47.20137499272823, 43.58686074614525, 43.5631500184536, 40.58492302894592, 39.76457364857197, 43.6260100454092, 45.450991317629814, 48.619154915213585, 48.720058500766754, 48.531508818268776, 50.77337332069874, 49.31562714278698, 48.24328288435936, 47.36970596015453, 48.99336263537407, 47.87754110991955, 46.2729100137949, 46.74558185040951, 47.39464022219181, 46.915770918130875, 50.074750408530235, 44.64669227600098, 49.17871668934822, 47.01311029493809, 33.69167871773243, 27.83612262457609, 12.47471446171403, 5.4545835591852665, 13.106283321976662, 16.720582880079746, 31.481084637343884, 48.76746095716953, 26.414212323725224, 14.336675349622965, 3.4472125489264727, 11.649164110422134, 25.287956558167934, 28.62959984689951, 23.480461947619915, 23.133498765528202, 20.161917619407177, 20.572599582374096, 9.732804391533136, 7.533018831163645, 8.41636123135686, 10.165823455899954, 12.718165498226881, 10.972061343491077, 4.6964173670858145, 12.948576584458351, 28.297332376241684, 27.556850910186768, 38.68646129965782, 38.36610808968544, 30.455434173345566, 33.401807472109795, 28.61946389079094, 42.7347868680954, 47.097066789865494, 46.843988969922066, 49.24894072115421, 50.78124649822712, 48.73308040201664, 46.74650900065899, 46.90915547311306, 46.794166043400764, 41.85599282383919, 44.261837527155876, 43.49829889833927, 43.63015182316303, 44.58553835749626, 44.79007378220558, 46.014786064624786, 44.843791499733925, 42.45010994374752, 39.207063764333725, 42.14132331311703, 43.83703552186489, 44.29419279098511, 43.15895810723305, 43.550508096814156, 45.029460936784744, 43.24785813689232, 42.79161661863327, 51.84118062257767, 55.399305894970894, 57.423172295093536, 56.32571518421173, 55.95780752599239, 58.26684482395649, 56.854764595627785, 59.44871060550213, 60.32963253557682, 61.67115055024624, 54.86776381731033, 50.97788214683533, 55.77648885548115, 61.59292034804821, 62.26990342140198, 61.299009919166565, 21.235342919826508, 1.4954241248778999, 27.8676001355052, 59.90084834396839, 44.53665778040886, 48.54562506079674, 11.221473310142756, 8.700030259788036, 50.94551548361778, 71.59742251038551, 41.6403391957283, 12.668411917984486, 15.150857660919428, 10.906186178326607, 32.43304945528507, 18.830771148204803, 38.1949994713068, 27.643235474824905, 37.90220998227596, 51.83346703648567, 66.1331333220005, 25.617011301219463, 0.9129234566353261, 0.14858283335343003, 0.07492029035347514, 0.12111991833080538, 0.14217282965546474, 0.11935118745896034, 0.12991798255825415, 0.023184533856692724, 0.07755890736007132, 0.045266874512890354, 0.06697333592455834, 0.2009608704247512, 0.014808680225542048, 0.017229605837201234, 0.037258206793922, 0.20188186084851623, 0.031111374228203204, 1.4471934316679835, 66.88789442181587, 65.36326423287392, 52.62905314564705, 37.340056747198105, 42.56331726908684, 50.5221726000309, 34.18900363147259, 26.706283651292324, 25.07271520793438, 20.055352337658405, 23.648192547261715, 21.204211190342903, 13.598720747977495, 37.67612211406231, 61.447866931557655, 57.50552147626877, 62.749357894062996, 37.901723608374596, 0.3268701274646446, 18.359366543591022, 69.63528379797935, 62.20847211778164, 68.8464005291462, 63.62150229513645, 64.0037351846695, 67.4960669875145, 64.10884514451027, 64.30632054805756, 64.40063148736954, 61.96089260280132, 59.57199119031429, 57.500760331749916, 55.09922079741955, 55.112364292144775, 52.315197587013245, 50.46053230762482, 48.77423599362373, 48.093289732933044, 45.93267247080803, 45.47504402697086, 45.58064416050911, 45.85697293281555, 48.20855654776096, 51.84135161340237, 50.530991926789284, 51.37312173843384, 52.638689428567886, 50.63353322446346, 50.97781755030155, 51.43717870116234, 52.78042942285538, 52.96969726681709, 52.1271912753582, 51.40474744141102, 51.20545953512192, 50.27230940759182, 53.760347440838814, 50.53887650370598, 50.36270655691624, 52.38566480576992, 35.36066696047783, 34.16328281164169, 29.091689251363277, 24.447709545493126, 24.894793555140495, 33.337853103876114, 45.80402657389641, 46.04642316699028, 36.61285176873207, 31.82541076093912, 20.114142782986164, 28.95825371146202, 37.4574476480484, 34.84277755022049, 31.88457928597927, 27.617562152445316, 23.231679797172546, 26.85505136847496, 12.780153471976519, 9.671869911253452, 9.511643908917904, 7.962969560176134, 14.16021091863513, 13.626720495522022, 4.700760534033179, 20.39508830755949, 35.41746251285076, 38.48456673324108, 44.01139676570892, 43.15795116126537, 43.764003440737724, 45.98305016756058, 28.39732401072979, 43.88521693646908, 50.17606057226658, 49.497948959469795, 53.6649801582098, 49.00947377085686, 53.60184274613857, 51.9709512591362, 50.68249359726906, 49.91746544837952, 47.405431643128395, 46.00876718759537, 45.195056051015854, 43.17137584090233, 46.55591882765293, 44.329717084765434, 44.36051823198795, 44.66024994850159, 46.129581704735756, 43.04660193622112, 46.08960025012493, 46.013334542512894, 46.83171562850475, 46.21553309261799, 44.59230959415436, 44.50924225151539, 46.878057941794395, 46.38484440743923, 54.315592646598816, 59.93244364857674, 60.9403395652771, 61.30935676395893, 60.44661305844784, 58.4137487411499, 59.80145327746868, 60.27963101863861, 61.12405210733414, 61.06981381773949, 57.830122858285904, 54.832083731889725, 59.55702379345894, 65.52367642521858, 64.0063950419426, 65.00524744391441, 20.446142368018627, 1.8582860101014376, 35.35116367042065, 65.06856724619865, 48.123448714613914, 55.0083676725626, 14.377716947346926, 11.088541243225336, 52.14556708931923, 70.98773002624512, 43.70568037033081, 18.78182977437973, 22.142147161066532, 16.28101296722889, 39.43268805742264, 22.126968875527382, 52.34604813158512, 29.925592504441738, 45.69537900388241, 61.02638594806194, 72.69791945815086, 38.14265348017216, 1.085889225360006, 0.28979762457311153, 0.0035845943830281612, 0.10004632335039787, 0.04944137355778366, 0.02085126980091445, 0.2661625959444791, 0.15804068912984803, 0.11835925513878465, 0.10266054596286267, 0.19345189444720745, 0.3616036183666438, 0.11116961046354845, 0.18422281311359257, 0.11498548890813254, 0.3639713960001245, 0.687763747991994, 1.967827482149005, 72.99529150128365, 79.49691742658615, 56.83868765830994, 46.932406425476074, 62.318951189517975, 58.57875108718872, 46.13702550530434, 39.074842259287834, 29.021514616906643, 18.314629644155502, 22.857834957540035, 22.087185010313988, 25.630097799003124, 47.23806582391262, 67.35308825969696, 62.26465590298176, 65.28001070022583, 33.08391273021698, 0.2378875412978232, 24.60035875439644, 72.84237250685692, 64.7399228811264, 71.23533993959427, 68.19593623280525, 66.00266352295876, 68.9399591088295, 65.48049554228783, 65.26002377271652, 65.9107768535614, 58.17127615213394, 57.61629693210125, 55.65017223358154, 54.977862909436226, 56.830206513404846, 56.144628301262856, 53.33563283085823, 52.27503374218941, 47.88434274494648, 44.15348634123802, 45.34173958003521, 45.10682098567486, 46.821984350681305, 51.65091723203659, 57.08375170826912, 57.93012209236622, 59.89329054951668, 59.05642345547676, 58.60421732068062, 59.960611537098885, 58.520845994353294, 55.94819404184818, 59.522859826684, 55.736963376402855, 54.11192737519741, 50.88547870516777, 51.09638258814812, 55.2747143805027, 49.86130826175213, 52.5065553188324, 55.63699834048748, 41.12105906009674, 45.80914109945297, 31.254149414598942, 23.39167781174183, 25.47986526042223, 26.987763047218323, 48.704692125320435, 50.71091987192631, 38.60899865627289, 30.558577738702297, 26.150979548692703, 37.05765210092068, 42.84888334572315, 42.26335756480694, 37.16808557510376, 31.36439859867096, 23.686293102800846, 32.92108006775379, 21.244188845157623, 19.3990458548069, 18.33788439631462, 19.411742873489857, 17.161792404949665, 13.503790441900492, 5.535361999645829, 24.772842898964882, 44.216825142502785, 44.00401756167412, 43.11733514070511, 47.534009143710136, 45.107007175683975, 49.54072706401348, 34.63794194161892, 51.893701404333115, 54.752823784947395, 54.95012819766998, 58.41289758682251, 54.372042417526245, 57.96684332191944, 53.91452416777611, 53.3319166302681, 54.14469301700592, 50.383620634675026, 44.87956278026104, 47.55370728671551, 45.03772169351578, 49.38612475991249, 45.96665404736996, 46.786216869950294, 46.01852126419544, 48.550716787576675, 45.04454992711544, 50.803444907069206, 51.664889082312584, 51.6438078135252, 50.464810878038406, 47.73313365876675, 48.011529520154, 47.588650211691856, 47.309612184762955, 54.79475453495979, 64.78480607271194, 68.01758900284767, 73.93396273255348, 65.70535227656364, 62.41830065846443, 63.9125856757164, 62.809744253754616, 63.40507350862026, 68.3142314851284, 61.633365377783775, 55.297596752643585, 62.019626051187515, 67.77798146009445, 69.67394292354584, 71.11436203122139, 31.99375882744789, 2.6703608594834805, 30.55160131305456, 70.68744733929634, 53.779042437672615, 60.419512912631035, 19.947270937263966, 16.900094747543335, 56.88387103378773, 79.01557445526123, 49.10213179886341, 21.45487044006586, 25.77817965298891, 25.104561299085617, 48.73629882931709, 27.50854030251503, 58.80617268383503, 36.59944228827953, 52.541942819952965, 72.54211261868477, 88.4221900999546, 44.220180362463, 1.1419032071717083, 0.4134450381388888, 0.1052027876721695, 0.201265893119853, 0.22405270632589236, 0.14120676118182018], [0.03940548864193261, 0.030679531482746825, 0.0396245298179565, 0.13059482123935595, 0.09622526471503079, 0.37693739868700504, 0.01624338805413572, 0.03206945533747785, 0.10516490103327669, 0.5574883322697133, 0.18969478667713702, 2.1320867305621505, 55.809501484036446, 58.652372136712074, 29.217954576015472, 27.296937257051468, 44.86361123621464, 30.291338078677654, 22.883185297250748, 13.865126352757215, 10.325975362211466, 10.795288179069757, 27.15515736490488, 11.10590536147356, 9.354990664869547, 27.030341662466526, 55.24139016866684, 53.726905435323715, 51.220472529530525, 63.24650041759014, 10.35825653001666, 1.5156553080305457, 50.9906380623579, 67.04677909612656, 67.93816566467285, 64.97398272156715, 67.00382620096207, 59.79895681142807, 65.70374116301537, 64.84137743711472, 64.12899926304817, 58.17586250603199, 53.809946179389954, 52.06125721335411, 49.4144294410944, 51.22202664613724, 49.32975858449936, 49.06147018074989, 49.004317447543144, 49.5686099678278, 45.65428800880909, 43.91381420195103, 41.61982789635658, 41.29918970167637, 47.000339180231094, 48.54894608259201, 51.59749209880829, 48.57879728078842, 51.35695740580559, 46.90402574837208, 51.90513499081135, 44.78222340345383, 52.50293031334877, 49.17802132666111, 49.42840129137039, 48.375200405716896, 50.56138649582863, 50.866016149520874, 51.167032197117805, 49.59338843822479, 49.220328256487846, 45.85955299437046, 28.623767159879208, 22.203472070395947, 1.9096008315682411, 8.311348166316748, 13.625165428966284, 8.815150782465935, 27.828306443989277, 46.14964082837105, 23.11031810939312, 2.039755959995091, 3.2836745493113995, 1.8943429877981544, 1.6350354021415114, 5.4517812095582485, 4.486855287104845, 15.33623831346631, 17.07432109862566, 11.378902662545443, 8.890799973160028, 3.8822155818343163, 6.78180911578238, 3.593039223924279, 1.2908841879107058, 1.892928988672793, 5.322699286043644, 13.158931396901608, 31.00046932697296, 28.302323408424854, 35.382796972990036, 33.550459295511246, 23.47025189548731, 17.819774597883224, 23.629651442170143, 30.614088959991932, 46.88414141535759, 50.51126338541508, 49.013357162475586, 50.659295842051506, 49.51342172920704, 48.12349431216717, 45.67544527351856, 46.79333008825779, 45.05955532193184, 42.895449846982956, 43.86924259364605, 41.400955840945244, 43.933459147810936, 44.39175635576248, 44.52070243656635, 47.15314798057079, 43.19867357611656, 44.20944593846798, 43.12311463057995, 41.86427637934685, 43.80356311798096, 43.030148819088936, 44.130482375621796, 42.34349146485329, 43.80906142294407, 44.29245248436928, 56.84429995715618, 57.636333256959915, 59.702533185482025, 56.772795394062996, 58.326053246855736, 57.55655653774738, 56.02235086262226, 61.49893619120121, 59.758014008402824, 59.73143443465233, 56.06465399265289, 53.90534766018391, 57.595489248633385, 58.76622162759304, 66.91144555807114, 52.80127130448818, 5.427521886304021, 3.3172835083678365, 56.23060628771782, 50.36511182785034, 57.2338854521513, 46.08862370252609, 4.031825428828597, 11.067074295133352, 44.52971935272217, 71.23163133859634, 63.396637961268425, 21.64217758923769, 17.461727410554886, 9.590564724057913, 25.841869935393333, 29.401562623679638, 38.03463667631149, 60.91577768325806, 40.685701221227646, 46.06834039092064, 60.98618410527706, 48.16472589969635, 0.7262554450426251, 0.2535690029617399, 0.08912374265491962, 0.08227089201682247, 0.04277106527297292, 0.019490994745865464, 0.03422332003538031, 0.012482615002227249, 0.09964359691366553, 0.10823400822118856, 0.05018279764044564, 0.2181856578681618, 0.017786569114832673, 0.03205556233297102, 0.08217226059059612, 0.264216031646356, 0.3091403085272759, 4.180595995858312, 69.21295925974846, 65.65461739897728, 34.670935571193695, 25.78202124685049, 47.431844025850296, 38.097656294703484, 34.97800849378109, 22.48723704367876, 15.878273528069258, 14.506514836102724, 28.358484394848347, 18.824767470359802, 15.044022593647242, 25.182664208114147, 61.586149111390114, 59.290331304073334, 57.46489405632019, 67.52283275127411, 16.931568458676338, 1.3227862073108554, 43.43957684934139, 65.87220892310143, 70.66449657082558, 67.28948727250099, 69.27852854132652, 62.536143735051155, 66.11783534288406, 62.58645303547382, 64.70041260123253, 58.37374068796635, 56.808536276221275, 54.79657083749771, 52.630987241864204, 50.83459943532944, 51.8608445674181, 50.85856094956398, 51.81810446083546, 48.28904762864113, 45.86367957293987, 46.01330794394016, 44.37651917338371, 44.78227660059929, 47.7242611348629, 50.1521522551775, 51.4381742477417, 52.10845448076725, 53.673362508416176, 49.75213631987572, 55.121821984648705, 51.962458714842796, 53.84713478386402, 53.68536986410618, 53.596975207328796, 50.6995090842247, 52.98773869872093, 49.67865966260433, 55.53967036306858, 53.18696200847626, 52.664140462875366, 49.03408125042915, 28.37921418249607, 28.173945397138596, 12.894920613616705, 12.218838091939688, 15.741644259542227, 22.241494730114937, 40.121271908283234, 45.1860923320055, 30.81695057451725, 9.313242305070162, 3.283599503338337, 8.72567793354392, 13.272799886763096, 11.935717184096575, 18.716055303812027, 30.317875854671, 26.28137905150652, 14.393260013312101, 12.558988239616156, 6.431850269436836, 8.298923783004284, 5.960524035617709, 3.342907433398068, 1.8924753880128264, 2.6668284740298986, 12.357281763106585, 33.26329730451107, 37.48317986726761, 41.995422542095184, 36.06142155826092, 30.295413359999657, 34.16881151497364, 28.64870712161064, 30.623027980327606, 48.77379521727562, 53.677348494529724, 53.29810604453087, 51.93045683205128, 51.52343787252903, 54.87505182623863, 49.39055532217026, 50.05185283720493, 48.00956882536411, 44.97670076787472, 43.03924173116684, 43.334292098879814, 46.594072580337524, 43.37992765009403, 44.438683837652206, 49.326650351285934, 46.17400512099266, 46.95897080004215, 46.900309547781944, 44.84700992703438, 46.62698641419411, 45.90055659413338, 46.759454905986786, 43.863664492964745, 43.2306906580925, 49.70970779657364, 58.62405985593796, 58.8208094984293, 62.08176411688328, 60.409264862537384, 62.94439762830734, 58.66759032011032, 60.157129392027855, 59.29395630955696, 60.836266949772835, 61.80056780576706, 57.87668935954571, 56.87729738652706, 61.00193426012993, 61.75569601356983, 68.54282721877098, 54.35200609266758, 5.886297393590212, 5.545027730986476, 60.834766030311584, 52.73203901946545, 62.344033643603325, 46.455133035779, 4.396863766014576, 14.667228162288666, 48.99794518947601, 67.19072297215462, 61.81425467133522, 25.04830341786146, 24.634923599660397, 11.92625854164362, 37.69817993044853, 28.483431190252304, 42.1163472533226, 59.17560786008835, 44.95042137801647, 59.258090034127235, 68.69370192289352, 59.393320977687836, 1.3780203997157514, 0.21273979305988178, 0.04177029026322998, 0.06040839034540113, 0.07714260704233311, 0.020243641956767533, 0.1001420604006853, 0.11236261285375804, 0.27718633878976107, 0.1463442636304535, 0.19058157893596217, 0.5423171713482589, 0.1783892948878929, 0.1466372041613795, 0.45140137954149395, 0.8989576029125601, 0.509612801251933, 5.890002194792032, 81.91637679934502, 76.408351957798, 42.611791267991066, 36.52955263853073, 61.97061628103256, 45.26607044041157, 40.52754990756512, 22.72416763007641, 15.918455421924591, 14.897374212741852, 38.203089237213135, 15.648663248866796, 22.72680278867483, 38.70968945324421, 66.24069035053253, 63.2284589856863, 57.995068207383156, 69.75877717137337, 12.86619795486331, 2.3687577433884144, 57.76054859161377, 71.99059501290321, 73.2983024418354, 68.03852587938309, 71.02635875344276, 62.15294949710369, 66.42188742756844, 65.65479218959808, 63.115080669522285, 55.9428933262825, 55.68569652736187, 55.50309732556343, 51.86763480305672, 55.38221061229706, 57.32614450156689, 55.70764794945717, 52.65598230063915, 49.81372341513634, 47.60164551436901, 46.52799792587757, 42.78441220521927, 43.96023251116276, 51.35498531162739, 55.79497866332531, 60.391147434711456, 60.03466576337814, 62.826277166604996, 57.058057487010956, 63.90302538871765, 57.474040165543556, 59.29603099822998, 60.32637231051922, 53.935692831873894, 53.953057900071144, 53.77648897469044, 52.8283866494894, 56.04591719806194, 52.6242084056139, 51.377115324139595, 50.893621668219566, 35.09631134569645, 41.61654867231846, 12.723878491669893, 12.072069067507982, 15.767086744308472, 17.47962825000286, 41.48085035383701, 50.36143362522125, 41.402012184262276, 18.20371549576521, 5.366217400878668, 8.020088095217943, 10.844891667366028, 11.883963961154222, 21.145027466118336, 33.5502503067255, 25.954043716192245, 21.574009247124195, 20.549677312374115, 15.167119838297367, 14.228574000298977, 7.5087975058704615, 3.0161857651546597, 2.4251875653862953, 5.238569425418973, 17.65823196619749, 39.29294295608997, 40.110381692647934, 45.1815477758646, 42.78625890612602, 31.349712386727333, 36.90202385187149, 39.119923040270805, 37.93870322406292, 57.11836025118828, 59.13126803934574, 58.63278418779373, 56.28835938870907, 59.85619693994522, 58.48555348813534, 52.14694641530514, 52.628236189484596, 49.748446717858315, 44.69295099377632, 45.522241294384, 43.823147267103195, 48.985633850097656, 45.18637731671333, 48.5624885559082, 52.73814149200916, 48.72527562081814, 51.56744331121445, 53.83309833705425, 49.785456731915474, 53.2569732517004, 49.20889087021351, 52.2083131223917, 44.88104850053787, 47.10134916007519, 49.2757710814476, 59.95189480483532, 63.1307016313076, 69.14640203118324, 68.60245361924171, 70.63979789614677, 62.220080494880676, 64.22238305211067, 62.90752060711384, 63.64197179675102, 65.35907685756683, 63.29557478427887, 55.87795861065388, 62.62641169130802, 62.00892582535744, 72.16417729854584, 62.14475333690643, 11.085357964038849, 4.457226851955056, 65.01161590218544, 58.09168562293053, 68.77177253365517, 57.16807298362255, 10.479244887828827, 16.263885386288166, 51.186608746647835, 74.91786673665047, 74.46870043873787, 35.14726661145687, 31.643810905516148, 18.40413574129343, 48.19457709789276, 41.868972927331924, 52.64593943953514, 77.87969380617142, 54.41180728375912, 71.31527245044708, 78.64394679665565, 70.8880765736103, 1.5274621057324111, 0.4326603398658335, 0.17587711015949026, 0.321610348764807, 0.21180185198318213, 0.16149488190421835], [0.014276744950620923, 0.04582460591336712, 0.0838044288684614, 0.053854914658586495, 0.31394182587973773, 0.19162990705808625, 0.06346130758174695, 0.07502053966163658, 0.04278670603525825, 0.46139383397530764, 0.13636628107633442, 5.358750801533461, 59.4614627212286, 52.04645700752735, 36.19668669998646, 40.188760086894035, 32.850586250424385, 25.09536389261484, 14.680280461907387, 12.988032717257738, 18.112632483243942, 19.603131003677845, 27.07585372030735, 16.025467179715633, 5.888352133333683, 8.420603703707457, 42.06940837204456, 62.40371324121952, 50.21150127053261, 54.75098468363285, 42.63903960585594, 1.6986330645158887, 4.50564575381577, 39.01477888226509, 59.65932950377464, 68.27312529087067, 60.78449472784996, 60.16575112938881, 66.79258793592453, 62.71771319210529, 62.69612655043602, 54.52246494591236, 56.14404313266277, 49.03428263962269, 47.96805985271931, 48.84195975959301, 47.06189587712288, 46.94715343415737, 48.54840651154518, 46.929628774523735, 46.27161428332329, 45.276033505797386, 46.41707807779312, 44.22130510210991, 47.60972388088703, 49.981374219059944, 48.132667019963264, 50.5334085971117, 52.41784527897835, 44.52338129281998, 52.1759844571352, 49.272807240486145, 48.441442251205444, 49.94471378624439, 52.03880041837692, 50.71875125169754, 49.31033402681351, 50.329545736312866, 54.39384564757347, 54.382822439074516, 54.17558915913105, 43.322391137480736, 20.788532495498657, 13.052427861839533, 4.183434443548322, 9.864371381700039, 16.724388375878334, 13.181609530001879, 26.212389953434467, 36.47563353180885, 7.554626846686006, 9.41011430695653, 2.199558522552252, 0.438984566135332, 0.6506196723785251, 0.8195104566402733, 0.30093951732851565, 3.7302375119179487, 9.769862852990627, 10.460528992116451, 3.7023052107542753, 1.2844707258045673, 0.08343291716300882, 0.496977855800651, 0.23143421101849526, 0.08472153785987757, 1.1217486136592925, 12.574365064501762, 36.49785853922367, 27.836500704288483, 35.06845884025097, 32.71016478538513, 21.831375136971474, 11.219015792012215, 17.61234562844038, 19.881239980459213, 38.474786058068275, 43.91320243477821, 47.729831635951996, 50.95499977469444, 48.88108626008034, 45.21787002682686, 48.46428282558918, 48.00894185900688, 43.254826962947845, 43.19236971437931, 43.53367879986763, 40.709924921393394, 41.71797662973404, 43.322003558278084, 42.8463488817215, 43.55121485888958, 45.402551516890526, 46.50337904691696, 43.66485916078091, 41.67031578719616, 41.75210639834404, 41.61374822258949, 42.772651836276054, 41.9654231518507, 42.58456572890282, 50.84742374718189, 57.113496512174606, 57.157984524965286, 56.441544368863106, 56.095698326826096, 58.42974208295345, 55.87351284921169, 63.11761513352394, 60.38728304207325, 61.05875261127949, 60.50424836575985, 57.61399805545807, 54.71613675355911, 60.259020924568176, 62.422780618071556, 67.7562466263771, 30.648066736757755, 1.1746597057208419, 18.20690732449293, 70.43479889631271, 40.40781833231449, 53.97745259106159, 23.727522790431976, 0.6033793604001403, 12.728685233741999, 29.86186232417822, 51.13595366477966, 64.45192113518715, 37.824040576815605, 15.979692935943604, 12.105170991271734, 24.688286036252975, 33.535708487033844, 30.36832194775343, 43.6798607558012, 29.06275760382414, 47.72118330001831, 60.05754053592682, 52.819639518857, 2.1519591892138124, 0.21233600535197183, 0.03723187910509296, 0.08825798286125064, 0.019013717719644774, 0.0418936055211816, 0.020580035234161187, 0.0744345250132028, 0.06957327961572446, 0.07714073683018796, 0.2989569737110287, 0.15485740994336084, 0.1112978981109336, 0.1036189851583913, 0.1256126502994448, 0.09647724611568265, 0.2980027499143034, 8.341475799679756, 70.437101572752, 63.83556380867958, 36.60706847906113, 38.41012492775917, 40.722281858325005, 34.37374971807003, 27.354373075067997, 18.674572929739952, 17.237457744777203, 20.717744193971157, 28.350166641175747, 13.466516342014074, 10.339783821254969, 7.444499731063843, 44.092940390110016, 65.91409027576447, 53.09477895498276, 50.74451386928558, 51.17066480219364, 3.117609447799623, 2.0288821309804916, 26.048875227570534, 53.02491210401058, 62.637374103069305, 59.49426256120205, 63.41212972998619, 68.33080619573593, 61.42053119838238, 61.92869693040848, 54.34083849191666, 54.46742869913578, 49.5195621997118, 52.195291221141815, 49.626868441700935, 51.16107791662216, 50.24910785257816, 50.863633677363396, 47.70518995821476, 47.52482123672962, 43.73402304947376, 49.04456868767738, 46.90991163253784, 49.46504272520542, 50.64735688269138, 54.59646217525005, 55.27340725064278, 54.224823117256165, 51.54129311442375, 54.8163715749979, 53.079906553030014, 51.284073516726494, 53.17057728767395, 53.526606783270836, 52.44916319847107, 51.85397073626518, 53.8917101919651, 55.09024567902088, 54.18242499232292, 56.598031371831894, 41.437228694558144, 26.944770254194736, 21.611043959856033, 4.9418808706104755, 13.565696720033884, 14.522063601762056, 17.81138274818659, 29.91283468902111, 48.5399329662323, 25.200559347867966, 1.1240218416787684, 1.9242636510170996, 1.718264117371291, 1.5781414113007486, 2.1291984105482697, 0.317747974768281, 3.299771435558796, 12.471686974167824, 14.771231431514025, 5.301519222557545, 2.2934334352612495, 0.6513853906653821, 0.9532091917935759, 0.438679454382509, 0.523907218594104, 1.6651322809047997, 18.06578479707241, 39.796092957258224, 31.800561994314194, 41.16642862558365, 29.7546548768878, 24.21374849975109, 21.185345202684402, 24.6125466004014, 20.884315855801105, 39.316482692956924, 46.56734101474285, 50.67083202302456, 51.76464892923832, 51.93522937595844, 50.76268829405308, 54.70824457705021, 51.47559843957424, 46.04299575090408, 44.16617386043072, 45.98923243582249, 44.92179371416569, 44.67634588479996, 42.70229481160641, 43.598879501223564, 45.99423676729202, 48.35652820765972, 51.35458253324032, 48.2349119335413, 44.28902506828308, 47.38487474620342, 45.129946544766426, 44.587924629449844, 44.975610226392746, 44.94325876235962, 53.37596006691456, 56.73272654414177, 58.58964890241623, 64.10748481750488, 58.60559664666653, 64.26541954278946, 58.89596566557884, 67.37812131643295, 59.838030114769936, 62.89897486567497, 60.181945860385895, 60.435437858104706, 55.734862089157104, 63.409971445798874, 62.824202477931976, 67.48028263449669, 26.200777776539326, 1.9885990675538778, 26.594738736748695, 74.9381272494793, 43.48222956061363, 56.34581610560417, 22.96933237463236, 2.1845901757478714, 19.039336256682873, 29.65444665402174, 47.78275139629841, 60.07211275398731, 27.03356198966503, 22.510497495532036, 19.563976004719734, 30.736605785787106, 36.11345216631889, 29.237343035638332, 45.53413465619087, 32.991801872849464, 59.473147094249725, 66.83122426271439, 62.30881333351135, 3.1877890694886446, 0.4612495010951534, 0.053455305242096074, 0.14816090755630285, 0.03650152786576655, 0.01890373143396573, 0.0693051193957217, 0.18322305113542825, 0.27324698923621327, 0.15149142884183675, 0.44760547229088843, 0.40909833856858313, 0.2204463435919024, 0.2394616068340838, 0.46553391963243484, 0.704714460298419, 0.9102047618944198, 12.10991408675909, 85.94613656401634, 70.53623825311661, 48.00199203193188, 53.37987765669823, 47.08925440907478, 41.03111028671265, 26.80000752210617, 19.61084458976984, 24.275958761572838, 25.902925059199333, 40.86030565202236, 23.024062737822533, 13.829705603420734, 17.93205287307501, 56.287344843149185, 67.75560066103935, 57.46031150221825, 60.26464842259884, 52.06419065594673, 2.162052160128951, 6.470253858715296, 42.238263711333275, 65.5474479496479, 68.27944815158844, 64.67959731817245, 65.7695460319519, 71.60485491156578, 62.652732878923416, 63.0753044039011, 50.810603722929955, 50.56512549519539, 48.779012337327, 52.93307863175869, 56.765059009194374, 55.32515287399292, 53.19906435906887, 53.59154149889946, 46.79742246866226, 46.77200563251972, 43.90922024846077, 48.088950365781784, 45.26993863284588, 52.86850489675999, 57.215000465512276, 60.384174808859825, 63.981491178274155, 63.18216226994991, 56.93610683083534, 64.67505276203156, 62.798185274004936, 61.17184214293957, 63.75963628292084, 56.62365719676018, 53.48977155983448, 53.44684146344662, 54.26693245768547, 59.96014416217804, 53.26233856379986, 61.06702096760273, 45.68298786878586, 35.46899534761906, 32.7803698182106, 5.703309662640095, 17.877972275018692, 19.329967461526394, 18.058411292731762, 38.690287694334984, 53.6046127974987, 45.130664706230164, 16.247831247746944, 5.805454356595874, 1.928794076666236, 2.1794402645900846, 1.613303180783987, 0.31034950457978994, 7.263920595869422, 18.652081936597824, 18.215133883059025, 8.274414148181677, 3.4114474430680275, 0.8350065595004708, 1.2954882346093655, 0.25255692133214325, 0.3488100314280018, 3.663729918189347, 20.167231634259224, 41.17554813623428, 34.99809421598911, 43.50763499736786, 38.42843994498253, 31.325517185032368, 25.52022099494934, 35.8463378995657, 27.372534200549126, 46.98529578745365, 53.053444772958755, 54.31965842843056, 55.087376832962036, 58.49133297801018, 54.58028644323349, 57.472068071365356, 54.373482540249825, 49.470860213041306, 45.713238045573235, 48.90225492417812, 44.66526947915554, 46.3325972110033, 43.52571062743664, 43.82135756313801, 47.22742639482021, 53.73807683587074, 57.83099681138992, 57.81383693218231, 49.98522721230984, 51.59203179180622, 48.958586901426315, 49.14577625691891, 46.4917478710413, 46.7045022547245, 51.9472861289978, 58.63247640430927, 64.81180742383003, 69.53444480895996, 68.66997599601746, 70.36657735705376, 61.1536031216383, 71.52336448431015, 65.41355833411217, 65.91234996914864, 66.72519475221634, 63.63261669874191, 57.71790347993374, 63.819103091955185, 64.17674750089645, 72.86944225430489, 38.37998114526272, 3.6658245557919145, 23.322274535894394, 83.7717716395855, 48.087244257330894, 70.4791197180748, 30.35537414252758, 4.974993718788028, 17.00424335896969, 33.84108290076256, 55.17032638192177, 75.28241917490959, 53.553824722766876, 32.65130214393139, 21.586330085992813, 43.71474288403988, 47.046027928590775, 41.34504184126854, 61.80208012461662, 40.75669281184673, 74.47410374879837, 76.68874651193619, 77.500831335783, 4.610557174310088, 0.6365288409870118, 0.26538690319284797, 0.27478314586915076, 0.1573531932081096, 0.13795490755001083], [0.05085961405711714, 0.09653208340751007, 0.17402971163392067, 0.16893681226065382, 0.1597483264049515, 0.2870715083554387, 0.12698298145551234, 0.08099132552160881, 0.006100040618548519, 0.4797826800495386, 0.25567314005456865, 5.9682385716587305, 53.0533991754055, 53.68935205042362, 39.10434387624264, 29.302720427513123, 27.711191028356552, 23.32284450531006, 23.168308697640896, 22.808278016746044, 19.03325468301773, 18.275544941425323, 26.90911866724491, 22.786421589553356, 7.245216574519873, 2.464771466329694, 21.365237049758434, 57.55757488310337, 67.11427107453346, 50.30379831790924, 52.32369393110275, 14.930148404091597, 0.18695387203479186, 1.0681480960920453, 13.58244527131319, 35.409524738788605, 35.99312402307987, 53.752595856785774, 64.0789407491684, 65.59360787272453, 58.8858088105917, 53.96789610385895, 52.0761676132679, 48.02433863282204, 48.53380769491196, 48.2940823584795, 48.70485171675682, 56.142295226454735, 57.39498920738697, 55.02322867512703, 48.35300199687481, 45.80294743180275, 45.72688311338425, 47.06304341554642, 47.20192216336727, 46.01771950721741, 51.56330153346062, 52.92006053030491, 49.94422361254692, 46.43716759979725, 48.37522320449352, 48.392470479011536, 47.414691746234894, 49.11105751991272, 53.084701895713806, 48.43854680657387, 49.53324146568775, 54.45567972958088, 53.204771652817726, 56.8647276610136, 50.52813448011875, 30.084439180791378, 15.966986417770386, 2.5551413046196103, 3.9812791161239147, 5.100094880908728, 13.788702953606844, 16.477566920220852, 41.42215110361576, 24.962040446698666, 9.835369437932968, 5.210473258048296, 3.2415129616856575, 3.7551138270646334, 1.1028831009753048, 0.3783576318528503, 0.2774357300950214, 1.7097944905981421, 1.9796916330233216, 0.9828823932912201, 0.053988861182006076, 0.22974796243943274, 0.4108941578306258, 0.14440525439567864, 0.42629713600035757, 0.8125337341334671, 5.755640929564834, 22.307839170098305, 45.18374405801296, 47.75042273104191, 54.63453613221645, 32.48868227005005, 14.832777678966522, 12.68999570980668, 5.258946307003498, 10.375379361212254, 29.08512320369482, 43.06427098810673, 46.67108304798603, 48.226411789655685, 48.29649142920971, 49.73425827920437, 50.560208559036255, 46.47870697081089, 41.792346239089966, 40.48335827887058, 40.28958007693291, 44.031919464468956, 40.64482681453228, 43.52788411080837, 43.32499399781227, 46.97268806397915, 45.44346772134304, 48.019167110323906, 41.84294052422047, 40.3197580575943, 39.298380464315414, 39.989164397120476, 41.06774032115936, 40.54560273885727, 43.999556601047516, 52.04869128763676, 55.08001282811165, 54.46502722799778, 60.296844094991684, 57.269132360816, 54.83245611190796, 59.79093924164772, 60.39328671991825, 56.270469948649406, 57.83818982541561, 58.93411561846733, 58.881089463829994, 63.5737806558609, 60.84312938153744, 60.287010222673416, 52.712048292160034, 6.602632105350494, 1.2603869056329131, 48.004435300827026, 57.9325919598341, 40.095855072140694, 51.54523730278015, 14.348626658320427, 0.5566032172646374, 29.381891079246998, 25.034510158002377, 23.89800064265728, 47.6873879134655, 32.927763909101486, 22.724517211318016, 8.436313010752201, 29.385291896760464, 28.057487346231937, 28.382768891751766, 47.99573376774788, 17.642533108592033, 39.34704065322876, 52.16971859335899, 56.95884481072426, 3.2009206898510456, 0.13417268550256267, 0.08522511474438943, 0.101740846876055, 0.13549118506489322, 0.047875980017124675, 0.04068095106049441, 0.11902742553502321, 0.10129389585927129, 0.26588354841805995, 0.19841126661049202, 0.21309283270966262, 0.05773524120741058, 0.06316722414339893, 0.06225424891454168, 0.58425213675946, 0.5639981548301876, 10.948286019265652, 69.93449494242668, 63.2073625177145, 42.94175036251545, 28.49172994494438, 33.489635959267616, 29.41365547478199, 27.70876105874777, 21.972695253789425, 14.953019376844168, 18.33316694945097, 27.696647308766842, 14.160542450845242, 6.983078615739942, 6.154130296781659, 22.803632766008377, 58.352036252617836, 70.79344645142555, 55.96971608698368, 57.200618237257004, 20.436597280204296, 0.16136453108629212, 0.8198925736360252, 9.239633604884148, 34.433634504675865, 40.865230187773705, 61.73144571483135, 67.44413897395134, 64.0282666683197, 60.22170312702656, 54.3798054009676, 49.82858441770077, 47.96748988330364, 49.16020788252354, 49.99565005302429, 49.602162167429924, 55.02314127981663, 59.62591029703617, 57.1851796656847, 48.87898497283459, 46.66464999318123, 49.472205340862274, 47.10688926279545, 46.60850040614605, 51.36193133890629, 55.62354326248169, 59.30527590215206, 54.52053464949131, 54.122760593891144, 50.88412217795849, 48.9328470826149, 52.04975143074989, 53.854787573218346, 56.17137126624584, 51.81816525757313, 49.532584100961685, 54.52454723417759, 55.47845184803009, 55.724564641714096, 47.42191515862942, 29.639135375618935, 24.075415022671223, 8.862159010022879, 5.149443307891488, 7.466664416715503, 12.735596112906933, 22.87608727812767, 43.86785186827183, 40.66551670432091, 4.345300057902932, 6.983045367524028, 4.9890130665153265, 3.068625801242888, 1.238174841273576, 0.11712026927853003, 0.48019944049883634, 2.2441876027733088, 2.09752616006881, 0.8343391609378159, 0.07093920241459273, 0.1580987250781618, 0.25060171843506396, 0.22306128608761355, 0.3000706702005118, 0.6667093746364117, 5.9162944089621305, 14.878020901232958, 47.36867241561413, 54.09230522811413, 60.63303865492344, 32.04565644264221, 19.920565970242023, 14.849050305783749, 12.077258639037609, 17.592259906232357, 30.883093625307083, 44.251433685421944, 50.44406779110432, 52.105707228183746, 52.36100032925606, 54.0193073451519, 54.69109609723091, 49.13362830877304, 44.11559097468853, 47.226237058639526, 46.65985465049744, 47.57055178284645, 46.20352193713188, 45.90312525629997, 44.461414217948914, 46.83117985725403, 49.107082933187485, 50.95197893679142, 49.38595376908779, 45.939675495028496, 47.89031982421875, 45.71272127330303, 46.2521593272686, 46.039705127477646, 45.181988552212715, 50.66515892744064, 54.12653759121895, 56.876700818538666, 60.21049752831459, 64.89159554243088, 61.73192448914051, 62.73170404136181, 64.12924244999886, 62.71349921822548, 58.91257457435131, 61.67548231780529, 60.90000472962856, 64.53074410557747, 58.682333528995514, 60.56235484778881, 47.55617715418339, 2.633191728964448, 3.4719772450625896, 54.834648594260216, 55.86242504417896, 41.01390480995178, 55.27307666838169, 13.563639130443335, 1.7571936221793294, 27.53225862979889, 26.718391701579094, 29.436364956200123, 52.8192063421011, 25.966607742011547, 26.011813916265965, 13.959350846707821, 30.613044016063213, 30.297081470489502, 26.22809261083603, 58.95820252597332, 19.693279266357422, 48.34392808377743, 59.46286104619503, 65.60117706656456, 5.082091921940446, 0.3975955245550722, 0.008348620522156125, 0.15633913746569306, 0.019180118360964116, 0.05180336986086331, 0.17179258167743683, 0.17717147507937625, 0.3828064212575555, 0.37408410804346204, 0.22593629197217524, 0.739002573536709, 0.2917530352715403, 0.3899177990388125, 0.3804236522410065, 1.2017663824371994, 0.8205694716889411, 15.106963366270065, 86.30484491586685, 73.52643460035324, 51.11406683921814, 38.073808774352074, 38.15225176513195, 33.00223231315613, 33.32796223461628, 30.72943177074194, 24.07393880188465, 27.52974696457386, 41.21712550520897, 31.129176020622253, 15.53092846646905, 10.86363036185503, 29.402503073215485, 66.50905475020409, 75.52626729011536, 58.97555239498615, 61.9444926828146, 19.186641052365303, 0.31839937262702733, 1.848307626787573, 14.127414878457785, 37.91641741991043, 45.606030598282814, 61.89536511898041, 65.5036287009716, 63.66852097213268, 60.543260872364044, 50.330719873309135, 48.28553281724453, 46.14851228892803, 52.434135004878044, 53.873265981674194, 52.28367067873478, 58.553208857774734, 61.24305032193661, 57.39688150584698, 46.88966631889343, 49.12258990108967, 54.00366738438606, 48.927664160728455, 50.72715260088444, 53.90868008136749, 60.98268449306488, 63.235792592167854, 65.2569155395031, 60.85354462265968, 61.754575073719025, 64.52513560652733, 66.30793914198875, 60.40470130741596, 60.702768713235855, 52.06520140171051, 52.254279255867004, 59.2389352619648, 59.00207877159119, 58.87152537703514, 50.97975164651871, 35.099917352199554, 33.67534339427948, 23.346082158386707, 5.4518690798431635, 12.280100304633379, 20.303167439997196, 26.00304588675499, 47.69878730177879, 54.138541147112846, 32.46921971440315, 7.526330715045333, 10.244416538625956, 5.844919988885522, 3.9524315390735865, 1.134141767397523, 0.42440335324499756, 2.9011524002999067, 5.519673116505146, 2.9128474602475762, 0.44834379048552364, 0.2799187781056389, 0.422395309433341, 0.569861774565652, 0.52557562594302, 1.647226691711694, 10.553355161100626, 31.007831431925297, 48.527598828077316, 52.26573184132576, 59.786140099167824, 42.814696580171585, 25.703887939453125, 20.10911565274, 24.232755079865456, 25.88018137961626, 35.81076420843601, 46.349327713251114, 51.17145515978336, 56.59585028886795, 57.668190747499466, 60.148940831422806, 61.26669645309448, 54.13940370082855, 45.78411944210529, 47.59815730154514, 44.347177147865295, 44.626332968473434, 43.459157198667526, 44.686719328165054, 47.55494602024555, 53.41807320713997, 55.892698019742966, 59.95118424296379, 55.839804857969284, 47.99819603562355, 49.674871265888214, 49.34713125228882, 48.1562789529562, 47.87901923060417, 48.11473958194256, 52.10281938314438, 56.378885731101036, 61.05826623737812, 61.709520891308784, 68.32604125142097, 65.1042777299881, 66.39477208256721, 70.26883900165558, 68.12979698181152, 61.082459539175034, 64.47636902332306, 63.69401380419731, 68.1590174138546, 64.04563933610916, 63.8052262365818, 61.57049395143986, 8.5284305177629, 2.9746955540031195, 58.415834829211235, 67.6376473903656, 53.91806937754154, 61.4668545126915, 20.929371938109398, 2.7641543140634894, 33.100647032260895, 30.205612778663635, 29.66476120054722, 62.64128789305687, 48.6138503998518, 40.61037786304951, 12.403269745409489, 46.03818900883198, 40.30360512435436, 34.706615656614304, 64.30697411298752, 23.14519263803959, 61.685810163617134, 65.7789771258831, 79.50726807117462, 7.665088344365358, 0.690409237286076, 0.1459005632204935, 0.20930572733050212, 0.2587852324359119, 0.2562328678322956], [0.06396947836037725, 0.052407192342798226, 0.17396769777406007, 0.14704623143188655, 0.07404025905998424, 0.1976803847355768, 0.32794674625620246, 0.10795413691084832, 0.20550763816572726, 0.1854489598190412, 0.4241837962763384, 13.197401482611895, 57.92976871132851, 51.4555811136961, 32.18598671257496, 41.640445590019226, 29.979384317994118, 21.945612207055092, 27.294680178165436, 22.117315493524075, 17.615041583776474, 21.32159449160099, 21.90314568579197, 13.075935300439596, 9.831800479441881, 5.6958079151809216, 21.195353865623474, 47.47255124151707, 59.49405737221241, 37.35580310225487, 57.476320043206215, 31.311991810798645, 0.8475183974951506, 0.49457356450147927, 2.0199530851095915, 20.551166832447052, 33.70721988379955, 57.238186821341515, 72.71135553717613, 62.31381006538868, 56.79562836885452, 53.434758111834526, 52.784954980015755, 45.633335933089256, 50.84696017205715, 46.91624969244003, 52.00574979186058, 58.71931694447994, 56.11810192465782, 57.314927503466606, 56.933956146240234, 47.757760137319565, 45.497451424598694, 47.61968694627285, 45.845801532268524, 49.15929213166237, 54.88073252141476, 55.91113083064556, 51.53770990669727, 51.740394830703735, 50.083839520812035, 45.68762741982937, 46.446150317788124, 50.789560452103615, 55.86606524884701, 49.936722815036774, 46.64425268769264, 45.94243414700031, 58.179468512535095, 46.14680998027325, 45.54278679192066, 15.04489654675126, 10.334110725671053, 1.1455244128592312, 5.58861281722784, 4.3919962272048, 14.60115635767579, 51.55100919306278, 43.75280924141407, 10.652096662670374, 12.97049855813384, 6.26859487965703, 2.7040968742221594, 2.523072687909007, 0.6833676213864237, 0.07283380895387381, 0.03013058340002317, 0.46130789327435195, 0.7776592648588121, 0.461737863952294, 0.1848550932481885, 0.1385437126737088, 0.1471125052194111, 0.36007411137688905, 0.06772031498258002, 0.49754767678678036, 5.669767437502742, 11.81955361738801, 34.93975594639778, 69.76488724350929, 82.88129702210426, 28.971306011080742, 17.609613575041294, 5.344047490507364, 3.0565395997837186, 4.8689874820411205, 21.605779342353344, 43.38818080723286, 47.94685699045658, 47.316550612449646, 50.20287573337555, 52.3573487251997, 48.43365266919136, 43.29871080815792, 43.03536593914032, 44.726955369114876, 46.25388823449612, 44.803737848997116, 44.03848171234131, 45.499427318573, 45.82575000822544, 45.14957249164581, 46.646441370248795, 46.09226010739803, 43.21938246488571, 41.58912934362888, 40.70028483867645, 45.336454063653946, 43.697609603405, 43.48463863134384, 39.414669424295425, 48.945021629333496, 54.5796062797308, 53.511616587638855, 58.348939418792725, 58.18569257855415, 56.59494213759899, 58.84202755987644, 53.866278156638145, 60.568062141537666, 61.18012949824333, 59.64626580476761, 63.26967157423496, 57.96463564038277, 58.729128018021584, 60.918855518102646, 14.7568036057055, 0.12398302758811042, 12.849623244255781, 58.25420290231705, 44.31628480553627, 44.71022106707096, 51.01487696170807, 7.126911347731948, 1.823682573158294, 33.57432961463928, 28.365515917539597, 17.054413966834545, 45.77774338424206, 18.08527585119009, 23.990550376474857, 12.683758344501257, 24.166108556091785, 34.8558184504509, 29.78275816887617, 35.93494914472103, 35.31364448368549, 45.18014945089817, 55.735557451844215, 56.47814780473709, 4.60422576405108, 0.4649323644116521, 0.07249776448588818, 0.13377389986999333, 0.022366805860656314, 0.2992310933768749, 0.028975276545679662, 0.12568245670991018, 0.14192048460245132, 0.05345643701730296, 0.18417144165141508, 0.10014391576987691, 0.1604244823101908, 0.2878818742465228, 0.21740531927207485, 0.3761880670208484, 0.37864113226532936, 21.2086683511734, 76.23019471764565, 62.678791880607605, 46.149758622050285, 39.88491699099541, 31.50818668305874, 29.147633649408817, 27.841869816184044, 24.045808911323547, 21.5846885740757, 18.075326085090637, 23.183040507137775, 14.259355198591948, 10.557005815207958, 8.393864538520575, 25.230159759521484, 52.87757880985737, 62.41575859487057, 39.874539747834206, 61.80850937962532, 38.42201068997383, 1.4390305196866393, 0.7049863832071424, 1.4589369390159845, 21.867271810770035, 40.258174762129784, 61.66524946689606, 68.27923536300659, 59.300974532961845, 53.49204383790493, 52.992868423461914, 54.455212354660034, 46.88690006732941, 48.89991044998169, 47.16471455991268, 53.98910276591778, 58.149214535951614, 55.807761177420616, 57.40038111805916, 59.45431910455227, 54.539104253053665, 50.88262125849724, 51.968143209815025, 51.814373061060905, 52.56171315908432, 55.56778885424137, 54.527020901441574, 57.60455176234245, 58.20778839290142, 57.56411053240299, 54.09941464662552, 50.24323336780071, 56.268676444888115, 57.77666732668877, 57.20043584704399, 53.51157858967781, 50.39827264845371, 61.14484839141369, 45.18854700028896, 42.8448935598135, 21.57099600881338, 18.128215447068214, 1.7020491999574006, 7.07842499949038, 1.3734681252390146, 20.985057950019836, 57.70959712564945, 52.88052745163441, 27.2440554946661, 12.899025343358517, 10.07409542798996, 3.5692437132820487, 4.060045089572668, 0.9177260426804423, 0.1876253227237612, 0.006483223060058663, 0.21160221425816417, 0.4088098806096241, 0.5764754978008568, 0.07813186763087288, 0.2556051593273878, 0.16737248370191082, 0.3777753724716604, 0.08783088429481722, 0.7240058470051736, 5.332092856988311, 13.286972176283598, 48.673503398895264, 77.85434916615486, 80.72694942355156, 29.699780121445656, 15.932430122047663, 6.475582122802734, 5.503987558186054, 13.232388105243444, 24.1154420748353, 43.160542622208595, 50.76353944838047, 50.14540761709213, 54.38988246023655, 53.894567638635635, 49.872650653123856, 47.00644165277481, 47.949262261390686, 46.75430238246918, 48.03409270942211, 47.80296251177788, 48.74155014753342, 48.395343124866486, 50.11524483561516, 50.04989594221115, 51.20397001504898, 50.46485647559166, 48.644932731986046, 47.424339428544044, 47.23662190139294, 47.863877043128014, 47.21350394189358, 44.813624918460846, 41.535552218556404, 48.2187931984663, 55.44462226331234, 53.509652093052864, 56.060926392674446, 59.75034222006798, 58.374185264110565, 58.61564330756664, 60.04810184240341, 63.22215132415295, 67.0039401948452, 65.16467168927193, 65.96730262041092, 60.16980171203613, 60.26301071047783, 56.69347085058689, 7.45501471683383, 0.17230249650310725, 17.76065357029438, 58.525192961096764, 47.216501981019974, 49.93206046521664, 51.54572367668152, 8.25217204168439, 2.1486044442281127, 24.04399260878563, 29.536664374172688, 20.176537334918976, 54.67978410422802, 18.08823399245739, 22.29126825928688, 18.16826719790697, 26.904558911919594, 37.24071867763996, 35.47412507236004, 40.0103672593832, 33.15722219645977, 52.46255747973919, 60.48817902803421, 67.43319556117058, 5.47838025726378, 0.26783646550029516, 0.07325554921408184, 0.2038391269161366, 0.2543504547793418, 0.08122456027194858, 0.14058203611057252, 0.11865502325235866, 0.1766274808323942, 0.20057308342074975, 0.23905452399048954, 0.6138781970366836, 0.4391039034817368, 0.39399177418090403, 0.35487720742821693, 0.5565095285419375, 0.6367950048297644, 28.497727923095226, 87.86628752946854, 74.6115043759346, 43.341196328401566, 56.4454847574234, 39.3802584707737, 29.868914745748043, 37.22166649997234, 34.16271284222603, 28.315573297441006, 33.381030187010765, 35.468539372086525, 19.66500498354435, 17.912084944546223, 11.022377293556929, 30.708308704197407, 58.29273283481598, 70.62997162342072, 44.60145190358162, 68.16780254244804, 40.119558200240135, 2.1695377584546804, 1.2482161587104201, 2.822687798179686, 24.80899415910244, 43.61111104488373, 66.26661255955696, 70.0150354206562, 62.71362081170082, 56.525383070111275, 49.312442913651466, 51.26260086894035, 46.30855970084667, 52.88196757435799, 55.918320044875145, 54.36040744185448, 61.971193850040436, 60.501679703593254, 61.13515891134739, 58.43150518834591, 53.12968008220196, 55.33000521361828, 51.61712184548378, 50.37040874361992, 52.26257421076298, 61.24111242592335, 59.95678894221783, 66.14005655050278, 63.91166612505913, 65.47877043485641, 63.67108963429928, 64.9108225107193, 64.47894528508186, 63.30675758421421, 55.62708467245102, 55.30860476195812, 51.362820491194725, 63.72199930250645, 49.29373271763325, 50.310223773121834, 25.866688303649426, 28.35094939917326, 8.08304501697421, 8.830799292773008, 9.738247599452734, 25.03906611353159, 51.57634623348713, 42.507095485925674, 47.93486103415489, 17.4631542339921, 14.23271007835865, 13.272534850984812, 6.58814063295722, 1.2331738346256316, 0.2994895982556045, 0.07794187040417455, 1.2778818793594837, 2.1202437160536647, 0.40460997784975916, 0.20547321735648438, 0.30841917847283185, 0.280208601616323, 0.6169994920492172, 0.1826164493104443, 0.8081036468502134, 10.206134542822838, 30.920139737427235, 52.259819358587265, 64.11812424659729, 68.75425547361374, 45.01619204878807, 28.67125891149044, 13.945140559226274, 14.295435212552547, 22.059476897120476, 28.51369086652994, 49.10536162555218, 53.4641495347023, 52.567857429385185, 55.00361032783985, 60.12968346476555, 60.303250551223755, 51.003819555044174, 48.81232134997845, 47.38756500184536, 47.18620240688324, 46.054927110672, 46.03255771100521, 45.61681441962719, 52.39029675722122, 53.60465079545975, 56.70187599956989, 59.891041070222855, 56.068609580397606, 48.48439894616604, 46.29737310111523, 50.15967585146427, 49.686722829937935, 49.80733595788479, 46.221042796969414, 48.28378111124039, 56.91717244684696, 55.999654680490494, 57.22543090581894, 64.05569359660149, 62.7462724596262, 66.65219306945801, 64.77736607193947, 71.7407052218914, 69.08053636550903, 66.35139361023903, 66.22293010354042, 62.55338340997696, 63.64904321730137, 69.43341583013535, 19.678368866443634, 0.3230328974314034, 17.11969256401062, 69.7657535970211, 57.60695323348045, 57.84771591424942, 55.10691538453102, 12.037518471479416, 3.9319461258128285, 40.89090161025524, 33.88343542814255, 22.862662598490715, 61.255422458052635, 30.707413852214813, 41.37238897383213, 18.896602615714073, 33.63487936556339, 50.580480471253395, 41.46073803305626, 47.467945888638496, 40.67574955523014, 62.66462244093418, 68.47859546542168, 81.92371040582657, 8.012192118912935, 0.5894100037403405, 0.2780037996126339, 0.22289755346719176, 0.3124576492700726, 0.48951921227853745], [0.03664390889753122, 0.05826122724101879, 0.09951607367838733, 0.14053110993700102, 0.13033355557126924, 0.15636172844097018, 0.28007068089209497, 0.24223425571108237, 0.1452546424116008, 0.2568948338739574, 0.5542772077023983, 19.769964851439, 62.515803426504135, 53.49015153944492, 20.19724052399397, 32.518795654177666, 35.01860171556473, 25.292020440101624, 25.477450489997864, 22.78170984238386, 15.251225475221872, 24.1662073507905, 23.195253051817417, 12.735510617494583, 6.7226234916597605, 2.7969679282978177, 22.906419150531292, 54.78629618883133, 50.57812079787254, 46.951614394783974, 58.6288969963789, 48.88025790452957, 5.522648356854916, 0.15333744697272778, 0.9467945422511548, 13.5385063290596, 43.24661560356617, 62.05291986465454, 66.58391833305359, 60.94549208879471, 55.268604308366776, 51.44849069416523, 50.73513597249985, 47.329378724098206, 49.25779804587364, 49.835484847426414, 58.91647316515446, 59.01817090809345, 58.84993873536587, 57.60428957641125, 59.077196940779686, 52.809961438179016, 44.72991921007633, 47.60593928396702, 46.70251876115799, 53.90099689364433, 52.14848913252354, 54.05491143465042, 55.22833026945591, 53.609484136104584, 52.56841219961643, 50.27272738516331, 45.75206816196442, 49.062902703881264, 50.41550472378731, 53.08893106877804, 53.746474385261536, 48.433588072657585, 49.824594631791115, 39.494366347789764, 38.52633789181709, 6.195360459387302, 6.518698884174228, 2.6608036598190665, 5.082807708531618, 1.5096271689981222, 30.005418621003628, 67.57317245006561, 15.394276399165392, 2.9894658364355564, 5.437546698376536, 3.1639869092032313, 5.103095769882202, 0.24255458149127662, 0.12411184216034599, 0.31058188586030155, 0.285268891020678, 0.25693618634250015, 0.33759140060283244, 0.08115950360661373, 0.02576540435256902, 0.04371350005385466, 0.28061001445166767, 0.1636641498771496, 0.20135913655394688, 0.030616526855737902, 1.5258919587358832, 5.44679350219667, 12.314733546227217, 33.55775490403175, 66.80968701839447, 56.273084208369255, 13.570289723575115, 0.9580910392105579, 2.9550088103860617, 1.2843639752827585, 14.666942227631807, 38.792084231972694, 48.53873983025551, 47.366552129387856, 47.5195737183094, 49.67723473906517, 45.99049396812916, 46.84274643659592, 44.52220715582371, 40.60690104961395, 44.752885177731514, 44.322189688682556, 44.28898327052593, 48.70658062398434, 48.37448604404926, 49.74718138575554, 47.82469354569912, 47.194223776459694, 41.675483509898186, 44.69458110630512, 42.881504595279694, 42.06514120101929, 40.65569043159485, 40.342967212200165, 39.76833164691925, 48.22692096233368, 56.039959117770195, 55.08504755795002, 51.58688306808472, 50.66398859024048, 54.41808074712753, 56.5832843631506, 60.19104637205601, 52.23338417708874, 66.99866607785225, 64.27352830767632, 65.86937427520752, 66.42488166689873, 59.01557184755802, 14.75191231817007, 0.05768007365986705, 0.8788470039144158, 26.132567636668682, 65.21200954914093, 45.920406728982925, 46.139981746673584, 45.62664829194546, 10.42083727195859, 3.0057857232168317, 9.445754494518042, 32.42463670670986, 9.336370714008808, 28.50008949637413, 15.088426060974598, 24.601304903626442, 25.555460304021835, 20.814487002789974, 52.08642326295376, 18.457874357700348, 49.724804386496544, 30.35866666585207, 43.44882555305958, 53.20347972214222, 55.90608850121498, 3.8345756381750107, 0.12743169878376648, 0.03307133985799737, 0.22147720155771822, 0.13581870967755094, 0.41612615052144974, 0.0469392634840915, 0.05721643545257393, 0.09667031583376229, 0.1384794872137718, 0.15554120996966958, 0.15234224178129807, 0.3833799826679751, 0.19955628173192963, 0.2980367699638009, 0.41698745742905885, 0.5155102629214525, 22.73214530199766, 75.66157042980194, 62.41757109761238, 29.877998158335686, 31.117843128740788, 40.135764330625534, 32.012267634272575, 26.183361411094666, 21.97716001421213, 21.19102019816637, 21.148044504225254, 24.271387606859207, 21.032393909990788, 7.800606172531843, 3.944577598012984, 22.439728192985058, 59.193691089749336, 53.42815026640892, 48.96789640188217, 60.931923016905785, 54.92490895092487, 7.535285884514451, 0.1623343548271805, 0.48090234340634197, 11.878040079027414, 45.06952218711376, 65.94992995262146, 68.14213871955872, 60.27751453220844, 58.42084676027298, 52.725845351815224, 50.529380813241005, 47.50507369637489, 51.02337710559368, 55.36642625927925, 61.747724041342735, 57.13271968066692, 59.685810282826424, 61.478360295295715, 60.243491157889366, 53.61736871302128, 51.9074110686779, 51.50818929076195, 50.27715414762497, 55.34929297864437, 56.17480628192425, 58.7373735755682, 57.21213161945343, 58.926025852561, 56.69550374150276, 58.4086000174284, 51.721502244472504, 54.64781641960144, 56.02360479533672, 57.83544257283211, 60.173586308956146, 55.06875403225422, 51.29559449851513, 41.15719132125378, 41.6971081495285, 12.922043558210135, 11.948618441820145, 0.8495090156793594, 5.946334647014737, 9.843868631869555, 37.73647427558899, 66.4985217154026, 34.39520716667175, 1.2466359185054898, 6.171817872673273, 7.506567500531673, 5.285224746912718, 0.5026169016491622, 0.10158843942917883, 0.18524803075706586, 0.3846320154843852, 0.1472902050591074, 0.49173297942616045, 0.05658597357978579, 0.04033716599224135, 0.05021770455641672, 0.39926155703142285, 0.10248520615277812, 0.0378445925161941, 0.053705605678260326, 2.6218887604773045, 10.353259798139334, 19.432028084993362, 47.97554165124893, 72.49321684241295, 58.185316398739815, 17.34191793948412, 2.3117510648444295, 1.050984060857445, 6.904952432960272, 19.84157580882311, 41.02272413671017, 46.38700649142265, 52.37254410982132, 50.98877616226673, 51.47583022713661, 46.782170087099075, 50.92406563460827, 45.29247522354126, 44.651141837239265, 45.05734384059906, 46.47746063768864, 47.18709535896778, 50.70346087217331, 51.74165636301041, 54.32778999209404, 53.14133405685425, 51.9318513572216, 44.55841921269894, 47.33741529285908, 44.42764163017273, 44.39217813313007, 42.79016509652138, 42.54140384495258, 41.63102209568024, 51.371970400214195, 59.03430484235287, 57.71861024200916, 53.41203913092613, 53.04758168756962, 54.636192843317986, 57.732718884944916, 60.923244282603264, 60.311097130179405, 69.59878295660019, 67.713453322649, 62.77890890836716, 65.33016800880432, 49.43187050521374, 7.976419888436794, 0.09951531668775715, 1.5900502097792923, 33.701630383729935, 66.57248094677925, 49.375382736325264, 49.231362864375114, 45.87306886911392, 14.083527233451605, 3.0981981894001365, 8.022402171045542, 38.641015738248825, 13.398187458515167, 34.8056535422802, 15.916665717959404, 24.256908483803272, 27.667202688753605, 21.2632068246603, 52.21300587058067, 28.037625811994076, 50.32946594059467, 22.175980545580387, 47.36880160868168, 60.337809696793556, 66.93815812468529, 3.795006461441517, 0.05068032602139283, 0.04050434217788279, 0.25040237756911665, 0.2417684838292189, 0.4030656872782856, 0.1857611071318388, 0.2758369955699891, 0.15867973765125498, 0.20939618028933182, 0.15895954216830432, 0.22328805673168972, 0.43818138423375785, 0.30585131782572716, 0.4216026660287753, 0.539897057460621, 0.7759025716222823, 35.71269907057285, 88.48329082131386, 75.25401189923286, 30.31497471034527, 44.17325668036938, 42.096018344163895, 29.742493629455566, 38.12717691063881, 32.70104147493839, 19.79430254548788, 34.232564494013786, 37.59145125746727, 18.098968416452408, 12.603058274835348, 7.93291887268424, 29.64028101414442, 62.07074090838432, 60.89243173599243, 51.854897886514664, 65.43549075722694, 55.9822516143322, 8.012125622481108, 0.3528887563152239, 1.6820541978813708, 14.501996878534555, 53.104286044836044, 73.74537125229836, 72.59271070361137, 61.883084177970886, 62.618739902973175, 50.51640830934048, 48.04415076971054, 47.95898973941803, 56.63032203912735, 60.572314113378525, 66.44290789961815, 57.4521267414093, 66.36463969945908, 61.57681301236153, 63.3154933154583, 56.02030277252197, 55.862615033984184, 52.072922587394714, 49.450998678803444, 58.42376880347729, 64.03446033596992, 62.76235319674015, 64.78900864720345, 60.42277693748474, 62.31977954506874, 59.299876391887665, 65.51300659775734, 59.99537207186222, 62.529368698596954, 58.074757531285286, 60.31947948038578, 53.506977036595345, 58.6662831902504, 46.97279065847397, 47.680240496993065, 20.590367428958416, 19.91301767528057, 5.649522123858333, 8.437222111970186, 16.375677287578583, 35.54161325097084, 51.21986076235771, 37.02696114778519, 22.573121935129166, 20.586713925004005, 20.534035451710224, 9.662243127822876, 1.169971707277, 0.28986355697270483, 0.36266762064769864, 0.9286283701658249, 0.3756493568653241, 0.8167267497628927, 0.14325185300549492, 0.12410038340021856, 0.16864839883055538, 0.2995776169700548, 0.28221670479979366, 0.3282882826169953, 0.21094853058457375, 4.779359316453338, 21.67541440576315, 42.912187948822975, 54.51350502669811, 64.80451181530952, 65.4026149213314, 23.28885342925787, 8.24532575905323, 7.567388936877251, 14.674850553274155, 31.66324496269226, 49.54455725848675, 49.1724394261837, 50.9138859808445, 51.620017290115356, 58.57586324214935, 55.635356828570366, 53.93359534442425, 45.473672300577164, 50.405743047595024, 48.40752527117729, 47.465620413422585, 50.14680594205856, 54.04608830809593, 53.01464505493641, 54.23846818506718, 59.63734768331051, 58.453376814723015, 50.52407629787922, 49.20618921518326, 44.17112499475479, 43.8982692360878, 46.39024771749973, 46.53534293174744, 44.693194180727005, 50.86036205291748, 61.13884091377258, 58.40836063027382, 54.69285160303116, 56.951518803834915, 61.12337574362755, 59.131245240569115, 65.00144004821777, 65.1984366774559, 73.85292828083038, 67.59217143058777, 66.47765323519707, 68.49668249487877, 67.7821384370327, 18.657348453998566, 0.2415361173916608, 0.7987114414572716, 35.939660891890526, 80.53805395960808, 56.74706317484379, 54.09395433962345, 51.50199942290783, 15.122757218778133, 5.146649507805705, 14.93528002873063, 44.755457639694214, 12.011371124535799, 46.0758525878191, 23.656538799405098, 42.043375968933105, 36.17381952702999, 27.53305658698082, 65.16021072864532, 31.072692051529884, 61.660222336649895, 36.15852914750576, 56.49680480360985, 69.14184987545013, 80.05360275506973, 6.006409423425794, 0.47619433666113764, 0.17286955669987947, 0.2413655273267068, 0.3697377350181341, 0.30671811662614346], [0.21903419983573258, 0.07894870504969731, 0.048141943480004556, 0.15768430981552228, 0.06616698505240493, 0.30481483438052237, 0.041062837990466505, 0.0546522595686838, 0.20095819869311526, 0.35580607946030796, 0.4369551781564951, 10.650829430669546, 63.97866412997246, 39.85533557832241, 26.18236966431141, 39.96617183089256, 30.799830593168736, 36.388948783278465, 18.698234260082245, 40.83605535328388, 17.909048907458782, 19.380195066332817, 21.82597752660513, 21.319352611899376, 9.01809599250555, 1.1270595411770046, 14.216912426054478, 51.567595303058624, 67.57982209324837, 57.38161772489548, 55.66961579024792, 55.73923945426941, 14.289003107696772, 0.3213541000150144, 0.7487727398984134, 8.00141304731369, 37.59727634489536, 64.09864649176598, 67.64621213078499, 61.755312234163284, 61.96143977344036, 52.53284610807896, 51.47712595760822, 51.573093608021736, 50.35878896713257, 62.276606261730194, 57.55200818181038, 60.04630073904991, 58.411066085100174, 58.21596935391426, 55.78503459692001, 47.260374426841736, 45.70082411170006, 43.25925372540951, 47.212379202246666, 52.10843548178673, 53.90964902937412, 56.38504900038242, 55.91007448732853, 55.44198140501976, 52.7550657838583, 52.34099440276623, 43.74816969037056, 50.36457605659962, 47.41216108202934, 52.092791721224785, 52.348100021481514, 54.1884096711874, 43.715495243668556, 39.14021775126457, 27.04977761954069, 1.6141538601368666, 2.8682017559185624, 0.903469801414758, 1.3264659536071122, 15.283753629773855, 73.22093859314919, 43.93136166036129, 1.2721965531818569, 6.199432415887713, 0.49826738191768527, 5.158327231183648, 0.7458321726880968, 0.14808455540332943, 0.0902341736946255, 0.08113229647278786, 0.18902652722317725, 0.12198184864246286, 0.3783298161579296, 0.06363237262121402, 0.1743720643571578, 0.08452690963167697, 0.07000889061600901, 0.04278971544408705, 0.08193599045625888, 0.08394981559831649, 1.039547505788505, 5.680448664352298, 4.738457361236215, 8.603578135371208, 21.501028463244438, 33.262822329998016, 4.080167384818196, 2.8610904375091195, 1.6864274069666862, 1.302602996584028, 12.676611877977848, 39.8549821972847, 49.488232880830765, 50.36619856953621, 50.1763341575861, 45.08825898170471, 45.68906754255295, 47.91741617023945, 43.96765351295471, 40.089904591441154, 43.55345293879509, 43.50533992052078, 45.90318605303764, 48.27458180487156, 49.75641869008541, 50.29444321990013, 49.318522587418556, 50.86447723209858, 42.889309376478195, 44.84134443104267, 39.75232310593128, 42.75859259068966, 40.72947107255459, 42.458834275603294, 43.98579753935337, 45.35840168595314, 55.89137189090252, 60.1058055460453, 59.848012179136276, 53.73045064508915, 49.78301726281643, 54.06881108880043, 52.30871893465519, 57.91950926184654, 58.26490692794323, 64.2326121032238, 57.84934222698212, 39.140305146574974, 7.058892147615552, 0.38552033656742424, 0.6106605415698141, 4.569531725719571, 50.16864337027073, 47.8094981610775, 30.178894512355328, 50.118630453944206, 45.60727313160896, 33.73457461595535, 3.91147306188941, 4.832292851060629, 27.750783003866673, 14.648650959134102, 19.25151117146015, 4.7076367400586605, 22.275314815342426, 24.956682734191418, 24.2110563442111, 35.22796668112278, 26.683045998215675, 50.184401124715805, 35.33724881708622, 46.54994174838066, 60.14445327222347, 50.71110226213932, 1.6137563064694405, 0.12330740602919832, 0.10502769277081825, 0.1748245963244699, 0.04384508283692412, 0.23494807246606797, 0.08953325974289328, 0.04478190698137041, 0.1420924105332233, 0.19514275918481871, 0.03645261291239876, 0.2754407183965668, 0.10398707556305453, 0.12288373618503101, 0.12000312708551064, 0.26017102994956076, 0.5943126906640828, 18.534200862050056, 74.27693992853165, 47.500555738806725, 26.93127527832985, 40.254925936460495, 34.0520665794611, 42.346500903367996, 25.719881281256676, 36.68641582131386, 19.272109866142273, 18.696683943271637, 20.585952065885067, 28.364457674324512, 16.60582333803177, 2.337772543542087, 14.87541614100337, 54.056647941470146, 68.91856625676155, 57.89890296757221, 59.38111983239651, 61.665906831622124, 17.507851235568523, 0.9478166874032468, 0.5052527133375406, 7.9424297623336315, 40.52023530006409, 69.00648593902588, 70.82082778215408, 62.868329510092735, 63.42618137598038, 54.06710498034954, 53.842594027519226, 53.67391727864742, 54.76156711578369, 64.0466120839119, 62.54789650440216, 60.10490499436855, 61.601644679903984, 59.58219364285469, 58.172917664051056, 51.063958927989006, 48.80776159465313, 48.04467134177685, 50.16145035624504, 54.242761954665184, 58.43011066317558, 58.53232517838478, 58.94459545612335, 57.210695296525955, 56.280991584062576, 56.16762086749077, 51.41105130314827, 53.96561622619629, 51.47981621325016, 55.127172097563744, 55.50173319876194, 56.78213149309158, 44.19953227043152, 39.620644971728325, 30.779129303991795, 9.207534827291965, 3.7251229863613844, 1.9099803362041712, 1.7612021695822477, 18.05323027074337, 75.02874478697777, 65.47216638922691, 9.263729061931372, 12.606973964720964, 3.3861671620979905, 6.2053482234478, 0.0833819984109141, 0.1697013876400888, 0.13636531628435478, 0.02474468226864701, 0.08027530886465684, 0.19282322115032002, 0.9392436943016946, 0.026584028491924983, 0.14561869553290308, 0.10760492674307898, 0.12733238458167762, 0.03118807333521545, 0.09480626351432875, 0.047945099940989166, 1.0211344063282013, 6.046145791187882, 5.9601483307778835, 13.920022007077932, 34.507038965821266, 41.59192219376564, 7.142933662980795, 1.8014855892397463, 1.6873407829552889, 6.172337019816041, 18.52880895137787, 45.319335982203484, 47.82938249409199, 55.11593610048294, 53.19450080394745, 49.271108731627464, 48.27383704483509, 51.16789095103741, 46.245878264307976, 44.46589037775993, 43.8655985891819, 45.989718809723854, 49.92286495864391, 51.464392840862274, 52.64139108359814, 51.70826755464077, 52.717143818736076, 53.296095952391624, 47.13054679334164, 45.880455672740936, 41.51507131755352, 46.10141381621361, 41.32378578186035, 45.8024762570858, 46.12791359424591, 47.63082414865494, 56.194956600666046, 64.19592887163162, 60.47679863870144, 54.2046158015728, 51.861270144581795, 55.20410656929016, 53.626815006136894, 62.54608020186424, 59.58984263241291, 63.41489978134632, 50.806693732738495, 27.47598744928837, 2.5235799606889486, 0.5714713444467634, 1.0091602988541126, 4.777322625741363, 57.34441392123699, 46.432189866900444, 32.752296924591064, 56.59656465053558, 52.789704725146294, 41.217790469527245, 3.6745363008230925, 7.803132561966777, 37.50282481312752, 15.157204270362854, 25.3562293946743, 6.861000191420317, 24.91656258702278, 26.15203209221363, 24.85661130398512, 33.528257086873055, 30.61357218772173, 46.39966361224651, 40.43197363615036, 53.481715992093086, 66.94198071956635, 57.592255622148514, 1.0947814607061446, 0.21014717436628416, 0.07043039338896051, 0.21773789048893377, 0.08715287302038632, 0.03432699435506947, 0.22527640394400805, 0.3468829410849139, 0.23336159822065383, 0.2943724603392184, 0.1642139774048701, 0.48195954761467874, 0.17356309370370582, 0.4072592075681314, 0.45390704821329564, 0.45956179790664464, 0.7883973699063063, 27.941504269838333, 85.1414081454277, 60.42692631483078, 36.09125755727291, 52.256654128432274, 33.944566547870636, 43.96108366549015, 28.677610270678997, 52.68430218100548, 24.39702406525612, 26.94389060139656, 33.28993387520313, 24.876911714673042, 18.072630129754543, 5.986289503052831, 23.53955637663603, 61.10722281038761, 76.75823718309402, 63.0812206864357, 60.73355086147785, 63.13354767858982, 17.877478301525116, 1.2567573878914118, 1.358284258749336, 10.331108886748552, 44.01705086231232, 72.30455696582794, 73.85155275464058, 69.32937741279602, 64.11806344985962, 55.66353991627693, 55.16255959868431, 54.377814307808876, 60.65432511270046, 66.386359333992, 65.446517765522, 61.74797862768173, 62.68365561962128, 61.43644094467163, 60.48338368535042, 52.56450980901718, 51.49123080074787, 48.62915217876434, 52.68521033227444, 56.27681560814381, 61.463841274380684, 59.470943212509155, 62.81772002577782, 58.77698265016079, 58.80754441022873, 56.971129551529884, 56.62757858633995, 56.77993901073933, 54.93569657206535, 57.13730223476887, 61.07053957879543, 51.78532361984253, 54.49371948838234, 43.77843126654625, 36.73033006489277, 18.39611057192087, 10.242446344345808, 6.043229922652245, 3.4314785432070494, 15.606212876737118, 66.19731187820435, 62.290251329541206, 26.553560346364975, 24.21403918415308, 15.769362822175026, 11.30411222577095, 1.3540751533582807, 0.16835427086334676, 0.2343312290031463, 0.1885318264248781, 0.1979283956461586, 0.296814541798085, 2.2328563733026385, 0.08832581515889615, 0.21829944394994527, 0.27784892823547125, 0.21438261115690693, 0.07866115993238054, 0.1369925943436101, 0.2680542116286233, 1.8459294294007123, 12.086733430624008, 24.043605029582977, 31.08662400394678, 43.53728100657463, 36.64209879934788, 11.724882647395134, 9.491761475801468, 5.569069990888238, 16.0635981336236, 28.062423281371593, 45.618379935622215, 49.998610094189644, 56.60832121968269, 55.49931652843952, 51.588596776127815, 52.35642917454243, 54.137819185853004, 49.01787132024765, 48.142212107777596, 47.13337004184723, 49.515743404626846, 56.195188388228416, 54.202905893325806, 56.0936426371336, 54.85283061861992, 55.05860477685928, 55.52515894174576, 50.2818962931633, 48.19353215396404, 45.85957579314709, 47.20238953828812, 46.10708691179752, 49.31179314851761, 49.22789365053177, 51.52088440954685, 61.09815649688244, 64.94085609912872, 60.38600251078606, 55.075893849134445, 55.85142083466053, 55.96848875284195, 56.80683396756649, 65.06994277238846, 63.132274746894836, 65.0752092897892, 58.01216349005699, 41.5188255161047, 7.653781101107597, 0.8049755240790546, 0.7988174795173109, 3.2606342481449246, 57.54385381937027, 57.38217629492283, 40.54621070623398, 58.757900074124336, 55.744236186146736, 41.08398824930191, 7.835740987211466, 10.817064810544252, 40.764634385704994, 17.746030054986477, 33.572239726781845, 8.025400210171938, 35.09174399077892, 37.065247893333435, 34.57743398845196, 43.30251060426235, 38.12476024031639, 66.64773970842361, 47.77291752398014, 64.73085656762123, 77.01387226581573, 76.12623229622841, 2.00223321095109, 0.35754617827478796, 0.15975844929926097, 0.306414607912302, 0.15099554060725495, 0.31276774825528264], [0.04951536568114534, 0.07529746464570053, 0.007090601357049309, 0.05414451181422919, 0.04983109014574438, 0.022699642395309638, 0.015631674687028863, 0.1591600407846272, 0.04534407642495353, 0.2876596158603206, 0.3129738278221339, 17.219494208693504, 60.756133049726486, 41.23779259622097, 42.49053217470646, 33.61553840339184, 35.23779295384884, 37.86881357431412, 26.879273168742657, 33.0794707685709, 23.966187983751297, 16.679894663393497, 25.80497771501541, 22.200861610472202, 19.80577412992716, 2.277351035736501, 3.9369077095761895, 36.2462892383337, 62.93889932334423, 54.29137274622917, 50.91602526605129, 53.34616966545582, 22.10043679922819, 0.3531580965500325, 0.16361899761250243, 4.938695216551423, 36.653938964009285, 63.65077592432499, 68.6040723323822, 60.48104681074619, 59.35370810329914, 51.95264384150505, 50.30499905347824, 53.917446210980415, 59.78784620761871, 60.331068858504295, 61.99475258588791, 58.39498154819012, 60.64229875802994, 61.59841865301132, 57.14718170464039, 45.0309694558382, 42.247482016682625, 44.99486759305, 47.01197035610676, 53.98664049804211, 57.39665351808071, 56.606839299201965, 56.01617619395256, 55.296832993626595, 54.28953364491463, 48.58086436986923, 48.251536041498184, 50.88946469128132, 46.59767098724842, 49.4237769395113, 48.90855498611927, 53.382628709077835, 40.547776222229004, 32.98707872629166, 19.951598905026913, 4.912298507988453, 1.3611198565922678, 1.1483939713798463, 1.7045089742168784, 2.3549906071275473, 10.867616347968578, 14.214972630143166, 2.3265282344073057, 4.220035504549742, 1.52493144152686, 0.23093542840797454, 0.043814929376821965, 0.0035611415887615294, 0.04134167771553621, 0.061161020857980475, 0.01639688460272737, 0.1029408402973786, 0.5137313646264374, 0.04106703112483956, 0.03314885718282312, 0.06885852460982278, 0.08944736357079819, 0.06074387078115251, 0.05502155967405997, 0.02899752427765634, 0.0618609811499482, 0.3762792027555406, 0.3248208202421665, 0.7456946675665677, 0.1448194618569687, 0.594287991989404, 0.4635531274834648, 0.7952059514354914, 2.7607584837824106, 2.9914030199870467, 5.972529491409659, 34.17972452938557, 46.99300177395344, 47.02443368732929, 46.79427243769169, 49.572637751698494, 45.99270164966583, 44.09862108528614, 41.87869280576706, 39.340854585170746, 41.63691557943821, 44.428830966353416, 45.65922774374485, 48.76375615596771, 51.44432611763477, 53.88740882277489, 50.55400729179382, 50.36905221641064, 46.572926715016365, 43.80373030900955, 39.32122103869915, 41.33079260587692, 45.06002649664879, 44.92604188621044, 41.04111894965172, 40.86103901267052, 48.864078372716904, 57.59995400905609, 55.873121470212936, 58.042675852775574, 57.03526251018047, 55.08148714900017, 54.34183783829212, 55.242750495672226, 51.15018770098686, 36.20323374867439, 21.26124233007431, 1.8978485371917486, 0.09454441897105426, 0.37869358726311475, 0.15376910974737257, 5.992530193179846, 47.98856735229492, 55.12935698032379, 47.591891437768936, 56.286539286375046, 52.62212611734867, 39.79233875870705, 1.2387952767312527, 12.89879260584712, 24.581139385700226, 19.476495198905468, 21.8985403329134, 6.308099459856749, 26.116293109953403, 31.08086161315441, 24.401186741888523, 38.27119678258896, 31.81058395653963, 38.17842096090317, 34.18946720659733, 47.09429673850536, 55.945101007819176, 27.952882759273052, 0.8103971206583083, 0.16059866436989978, 0.1028228981886059, 0.043012018359149806, 0.016846561156853568, 0.06944989014300518, 0.07006341620581225, 0.09977175097446889, 0.026206401489616837, 0.016526509971299674, 0.0803933029237669, 0.0764080738008488, 0.0622274202760309, 0.05848636144946795, 0.07838593446649611, 0.440801729564555, 0.40372717834543437, 25.44341381639242, 72.94844761490822, 50.62342956662178, 42.81688146293163, 40.40651120245457, 33.73019725084305, 41.81320331990719, 28.439872227609158, 38.79375234246254, 26.483609899878502, 14.703378472477198, 17.618204914033413, 22.85084903240204, 26.19910966604948, 4.3423770647495985, 4.365356331691146, 38.6867880821228, 70.14723032712936, 58.11547614634037, 55.33376321196556, 56.34699784219265, 27.6573384180665, 0.3958937502466142, 0.4226351121906191, 5.324227279052138, 36.38659670948982, 65.82838967442513, 69.0869428217411, 63.217409178614616, 59.53610971570015, 55.37904538214207, 52.74115093052387, 54.653326123952866, 60.795947313308716, 62.756011337041855, 63.54447662830353, 58.96850757300854, 64.08024787902832, 63.50301705300808, 59.42730635404587, 48.918901830911636, 45.28157740831375, 48.94367650151253, 50.41183032095432, 58.06358613073826, 57.60102175176144, 60.13222552835941, 58.74974951148033, 59.82391007244587, 56.93259961903095, 53.07704530656338, 51.435297802090645, 52.63039447367191, 50.02573683857918, 52.0208615809679, 50.082125812768936, 57.80893139541149, 42.95750431716442, 34.5450559258461, 24.422114118933678, 7.3200264852494, 1.7839121259748936, 0.8848876703996211, 1.016113213263452, 1.9445138331502676, 10.226383656263351, 20.648454912006855, 8.786525968462229, 4.257008470594883, 1.1222929344512522, 0.12665910820942372, 0.061193749570520595, 0.022392499013221823, 0.04872874109423719, 0.029716570752498228, 0.051029803362325765, 0.1082773570669815, 0.5063471733592451, 0.36743505857884884, 0.04532073959126137, 0.015350369176303502, 0.06359538398100995, 0.1285814933362417, 0.04309988864406478, 0.058925545890815556, 0.03362326395290438, 0.25551179714966565, 1.2878494570031762, 1.7784205893985927, 0.4236941272392869, 0.9696431318297982, 0.9396725369151682, 1.8768857745453715, 2.6023084111511707, 4.692972376942635, 15.726281683892012, 38.020892813801765, 47.8714956343174, 49.849266707897186, 50.20932398736477, 48.85410010814667, 48.14643748104572, 47.49810107052326, 44.8899932205677, 41.986599415540695, 44.28871348500252, 47.41371139883995, 47.61885479092598, 52.47010387480259, 54.808828979730606, 54.12691757082939, 53.7652225792408, 54.13902372121811, 49.4700812548399, 45.34042485058308, 42.845516726374626, 44.650378078222275, 48.586955443024635, 46.71311639249325, 44.5566713064909, 43.69458116590977, 49.89422969520092, 59.41271893680096, 59.63869661092758, 60.67445643246174, 58.60893286764622, 58.356485813856125, 56.853297874331474, 57.19232328236103, 53.23869623243809, 34.25530627369881, 16.905925534665585, 1.2278815498575568, 0.09282855127821676, 0.33024271368049085, 0.6811423064209521, 8.15261548385024, 51.25482648611069, 60.39671033620834, 53.240786120295525, 61.06921344995499, 57.13976450264454, 38.34022767841816, 0.5901533388532698, 22.847243025898933, 33.7413914501667, 15.987864397466183, 27.125767841935158, 10.004334021359682, 28.608003705739975, 39.32859264314175, 27.018989771604538, 39.723288863897324, 31.739470772445202, 42.016465812921524, 38.8866763561964, 51.211854591965675, 65.52348643541336, 34.54421617090702, 0.807884446112439, 0.16946029354585335, 0.1247248487197794, 0.005282545007503359, 0.07637672548298724, 0.03262700491177384, 0.21241700334940106, 0.2073986452887766, 0.18723122746450827, 0.24761225853580981, 0.21576443075900897, 0.12042612899676897, 0.2642488939454779, 0.2908395108534023, 0.2652477356605232, 0.5340387218166143, 0.6365943280979991, 32.865823432803154, 86.63027465343475, 59.28816542029381, 55.87015762925148, 46.731807589530945, 43.31543371081352, 49.14623223245144, 35.657974407076836, 43.49887266755104, 35.377769842743874, 23.83776057511568, 37.15719535946846, 27.532572112977505, 31.232621669769287, 5.898522762581706, 9.129726402461529, 45.59903137385845, 74.36150059103966, 64.25078272819519, 60.73964573442936, 63.14355634152889, 28.677384182810783, 0.5625433078967035, 0.5563273758161813, 6.577532552182674, 39.78121675550938, 69.38145741820335, 72.87052899599075, 64.9756470322609, 64.04394462704659, 56.96468509733677, 54.893302246928215, 58.39981108903885, 64.40589800477028, 64.91287440061569, 66.76336750388145, 62.49257907271385, 66.29339352250099, 68.0694942176342, 62.22059726715088, 51.34817607700825, 47.558327838778496, 52.17970825731754, 53.51373307406902, 60.426534935832024, 62.171253114938736, 63.545255586504936, 62.31243073940277, 59.97191593050957, 61.68419525027275, 56.845785677433014, 55.84973752498627, 55.80705441534519, 52.12353587150574, 53.75256925821304, 54.210725873708725, 56.02168969810009, 48.07896450161934, 37.723471373319626, 32.23441891372204, 13.473811950534582, 7.866206802427769, 5.2191149443387985, 6.096292175352573, 2.14567385148257, 13.090578764677048, 33.74740272760391, 22.151211574673653, 8.40264206752181, 3.899491592310369, 0.24459930224111304, 0.20853661000728607, 0.09395721688633785, 0.194113519100938, 0.10464644408784807, 0.18568874773336574, 0.17646371852606535, 1.9540920504368842, 0.2546278398949653, 0.10740041310782544, 0.1912385132163763, 0.16805190505692735, 0.2550868137041107, 0.13024825311731547, 0.18937392655061558, 0.14434555603656918, 1.3376815267838538, 3.20136075373739, 6.236261939629912, 1.9339669053442776, 1.1033321893773973, 1.158232712186873, 8.39748004451394, 8.444891050457954, 16.27938475459814, 27.37819019705057, 44.65885542333126, 52.617429569363594, 52.697924450039864, 50.26404485106468, 53.131572380661964, 49.871183931827545, 49.60310451686382, 49.2167754471302, 44.329470098018646, 48.4059027582407, 50.303999707102776, 50.20499601960182, 53.82906675338745, 56.466155648231506, 57.7785824239254, 53.17843146622181, 57.178442627191544, 50.9252055734396, 50.202469155192375, 45.63098005950451, 47.0743478089571, 52.79484964907169, 50.20230196416378, 46.61621779203415, 45.39595127105713, 55.22753231227398, 61.23993068933487, 62.02448219060898, 62.992582842707634, 60.870894491672516, 59.89870525896549, 57.73532174527645, 57.999449372291565, 55.00407010316849, 42.57326513528824, 23.87739434838295, 3.4007612289860845, 0.17182707670144737, 0.9180606028530747, 0.6361281406134367, 8.257132675498724, 58.84736247360706, 62.789719328284264, 60.06774678826332, 64.18350353837013, 62.16884024441242, 48.581852316856384, 3.5358342435210943, 18.70808333158493, 32.829208597540855, 25.731373764574528, 31.744097024202347, 8.903970066457987, 39.23960141837597, 46.49942345917225, 35.76837368309498, 50.93449607491493, 43.15678842365742, 50.536019057035446, 44.45675186812878, 64.85516309738159, 73.64545941352844, 47.100137025117874, 0.9530462161637843, 0.46858975721988827, 0.34718956681899726, 0.16296434914693236, 0.200891153072007, 0.15350327244959772], [0.15620213700458407, 0.04806246317457408, 0.03941109556762967, 0.019467687598080374, 0.02833543207088951, 0.028396646266628522, 0.03121655696304515, 0.044607710078707896, 0.12626810028450564, 0.26356314949225634, 0.5546956008765846, 17.23547615110874, 61.96924075484276, 42.00568579137325, 28.890531845390797, 29.746181331574917, 42.60340131819248, 39.66685049235821, 35.63315033912659, 36.071760803461075, 23.41921493411064, 16.7916314676404, 22.15336035937071, 19.514360167086124, 21.848250031471252, 6.766969487071037, 3.9169298065826297, 29.607914350926876, 59.907771572470665, 52.93403998017311, 49.65220168232918, 57.65491046011448, 35.358219891786575, 2.2201524674892426, 0.16915549349505454, 2.9012735188007355, 27.467420808970928, 64.85453993082047, 65.63214540481567, 65.64305081963539, 58.29298362135887, 54.77265112102032, 50.76178394258022, 56.31271228194237, 58.812050968408585, 62.547934502363205, 61.33237212896347, 59.20973002910614, 59.086962416768074, 58.45762878656387, 55.014040768146515, 47.873661518096924, 44.42869037389755, 44.169601276516914, 48.158015459775925, 55.074134543538094, 55.62489978969097, 54.99011345207691, 53.603472858667374, 56.41579695045948, 51.0775887966156, 47.973512560129166, 48.63711275160313, 48.879532143473625, 47.53786973655224, 51.24388687312603, 48.4039306640625, 51.899138912558556, 37.56852328777313, 31.115407459437847, 14.032270833849907, 4.734727386385202, 0.6619191379286349, 2.4431169033050537, 0.19556385377654806, 0.05363753589335829, 0.24092201987514272, 0.06454724774812348, 0.14209261833457276, 0.035811419584206305, 0.09495509380940348, 0.012938556210428942, 0.01136678947659675, 0.0622756450320594, 0.11063087062211707, 0.02938733177870745, 0.018173385760746896, 0.03407230040465947, 0.5876293242909014, 0.11916195464436896, 0.1674566135625355, 0.05736722130677663, 0.09334385409601964, 0.0602755384898046, 0.017085881518141832, 0.04521986316831317, 0.049258990766247734, 0.059094146999996156, 0.06330353440716863, 0.03587156694266014, 0.12477204931201413, 0.03191361545759719, 0.10699530437705107, 0.5866737943142653, 4.661777950823307, 3.9518019603565335, 3.511287560686469, 18.09589058160782, 43.81425954401493, 46.47584572434425, 49.362649619579315, 48.2837925106287, 45.17479173839092, 45.32058231532574, 41.09460487961769, 43.8619963824749, 41.384175941348076, 45.81215813755989, 45.420197769999504, 50.03595069050789, 51.55979432165623, 50.59716157615185, 52.359678000211716, 52.99038715660572, 47.07088239490986, 40.75111471116543, 39.138633236289024, 44.05265875160694, 44.11340229213238, 45.67892208695412, 42.54942901432514, 42.54224359989166, 42.20340058207512, 54.24941919744015, 57.252139672636986, 59.220521450042725, 60.3980478644371, 60.194644778966904, 59.72064681351185, 61.2090839445591, 50.057693123817444, 23.709344565868378, 7.247721115127206, 0.2583994047017768, 0.25018059415742755, 0.395760698011145, 1.9934960547834635, 16.34947769343853, 42.12384045124054, 61.72386892139912, 49.599084332585335, 54.56397011876106, 61.392222717404366, 17.862900383770466, 0.7489551301114261, 25.087443217635155, 22.6968489959836, 24.760461263358593, 10.790386442095041, 12.773390784859657, 27.407399229705334, 23.39278545230627, 24.32043917477131, 41.453187838196754, 34.790036380290985, 30.677211172878742, 21.807385124266148, 43.56047496199608, 54.87321652472019, 25.115637704730034, 0.5995246453676373, 0.05723724156268872, 0.25708066765218973, 0.01578198000061093, 0.07772188298986293, 0.0138031489768764, 0.03666102282295469, 0.08196304916054942, 0.05139009379490744, 0.031242405966622755, 0.04542221715382766, 0.01489856636908371, 0.1083725671924185, 0.03405611787457019, 0.23768941755406559, 0.3931799833662808, 0.5523496423847973, 21.10519230365753, 69.57444906234741, 52.209920436143875, 30.4110012575984, 35.349712148308754, 39.71135750412941, 41.9654231518507, 34.86884795129299, 40.453442484140396, 29.38407026231289, 16.04024838656187, 11.73643497750163, 20.108997859060764, 31.696065701544285, 7.035017078742385, 7.519396562129259, 34.05819945037365, 68.06162104010582, 57.944508120417595, 56.168054044246674, 61.93554796278477, 40.32177954912186, 3.077247063629329, 0.2892315143253654, 3.10726307798177, 27.459161952137947, 67.404575496912, 68.36951851844788, 66.40100374817848, 61.88416711986065, 55.241686552762985, 53.607401847839355, 57.15381994843483, 62.30116434395313, 64.02608558535576, 65.5967465043068, 61.33363366127014, 61.36619031429291, 59.81751121580601, 57.4810241907835, 49.62515853345394, 47.563601955771446, 47.272070199251175, 52.84759841859341, 56.57383807003498, 58.46451781690121, 57.920197024941444, 57.20579735934734, 57.39895239472389, 54.07390661537647, 51.854050531983376, 54.06639441847801, 53.989288955926895, 50.71476526558399, 55.22066608071327, 50.8364537358284, 57.14364789426327, 35.9038820117712, 37.12015874683857, 19.377540908753872, 7.498849164694548, 1.599389158654958, 1.3860133895650506, 0.1625039504142478, 0.01954912531800801, 0.2649386163102463, 0.06590157820028253, 0.09536722325719893, 0.07035899136099033, 0.11092316548456438, 0.019127327541355044, 0.05725136463297531, 0.05899845818930771, 0.05935872264672071, 0.028060228869435377, 0.053406201041070744, 0.11610064742853865, 0.2838887635152787, 0.30564173532184213, 0.07032402136246674, 0.0845247351389844, 0.04781688650837168, 0.042910466581815854, 0.03532854861987289, 0.08214366564061493, 0.0352519923762884, 0.08664351480547339, 0.07398804154945537, 0.05044971105235163, 0.051392828609095886, 0.046444907784461975, 0.08993734430987388, 0.7475122762843966, 6.9761506374925375, 5.623242259025574, 11.5262521058321, 25.65259449183941, 45.54614581167698, 46.887747421860695, 51.687862649559975, 49.93869870901108, 48.98238882422447, 47.38654285669327, 44.50821250677109, 46.445644944906235, 45.7361052185297, 48.587426617741585, 49.21905532479286, 53.33981640636921, 53.5447546094656, 53.47733482718468, 52.687000036239624, 56.14524006843567, 48.734877705574036, 43.76223273575306, 42.62506775557995, 46.92092724144459, 46.78192690014839, 50.48249892890453, 47.293645441532135, 45.01290902495384, 44.41430814564228, 56.648025289177895, 58.921872675418854, 62.23674260079861, 62.42925927042961, 61.3941416144371, 62.04065032303333, 63.1499969959259, 54.73931930959225, 27.06930287182331, 8.99300403892994, 0.27564439340494573, 0.2497340290574357, 0.7341881131287664, 2.2048675501719117, 22.476667910814285, 47.12870389223099, 66.04329094290733, 53.92701409757137, 59.7410973161459, 71.31990060210228, 19.466273747384548, 1.0660686576738954, 33.2532012462616, 26.89338181167841, 22.879111915826797, 17.95241218060255, 12.138695642352104, 35.696150958538055, 27.162150889635086, 26.165713258087635, 38.10943566262722, 31.35050654411316, 36.14974021911621, 20.981522239744663, 50.60547932982445, 64.54520612955093, 29.789297617971897, 0.50266730831936, 0.13731205923249945, 0.2692400151863694, 0.03620181523729116, 0.07083273390890099, 0.017039432350429706, 0.20766948466189206, 0.15673149609938264, 0.18887495098169893, 0.17316153243882582, 0.18408725241897628, 0.13707786711165681, 0.15629288682248443, 0.16652268008328974, 0.4898256005253643, 0.49042679951526225, 0.8228641329333186, 30.723114609718323, 84.63544249534607, 65.80305263400078, 41.14969052374363, 37.98685424029827, 53.44642348587513, 53.74154984951019, 48.36497135460377, 48.94320912659168, 31.09042190015316, 26.13122820854187, 31.62546169012785, 26.439237780869007, 30.29891487210989, 13.207847122102976, 8.837049957364798, 36.96483828127384, 71.21295914053917, 63.91209930181503, 62.07327537238598, 67.91991904377937, 42.18961112201214, 2.7399344136938453, 0.5917179048992693, 5.15994499437511, 30.43022632598877, 69.39772814512253, 70.29834821820259, 69.68436196446419, 63.79688188433647, 57.83995293080807, 56.845880672335625, 61.38652302324772, 65.4213099181652, 66.81103214621544, 65.00083968043327, 61.03619322180748, 63.65017555654049, 62.907551005482674, 62.184620797634125, 53.001239374279976, 51.49453282356262, 48.681102991104126, 56.46110951900482, 58.7723620980978, 63.00849258899689, 60.60998909175396, 56.39487527310848, 63.065120950341225, 56.5410952270031, 56.334241926670074, 57.249232828617096, 59.822542145848274, 53.11181344091892, 58.73729757964611, 53.140061125159264, 59.2883288115263, 43.62648881971836, 39.989361986517906, 28.01049716770649, 14.658271092921495, 3.992060562595725, 10.231471583247185, 2.603849465958774, 0.12700583960395306, 0.37704358517657965, 0.16839626157889143, 0.420472671976313, 0.24399139423621818, 0.22460473061073571, 0.13385583297349513, 0.13745119707891718, 0.18070301448460668, 0.21153754350962117, 0.34789582423400134, 0.16859147610375658, 0.2749619440874085, 1.7015039292164147, 0.7300495414528996, 0.2330850443104282, 0.26445488445460796, 0.19613064680015668, 0.207388685666956, 0.07107198747689836, 0.16585517761996016, 0.09105554563575424, 0.14344988769153133, 0.1852982147829607, 0.30035200354177505, 0.24707375618163496, 0.10149118839763105, 0.301190244499594, 4.265017965808511, 16.042619459331036, 14.639902878552675, 22.153580747544765, 35.318884402513504, 49.33647662401199, 50.785813853144646, 54.341625049710274, 51.6671309620142, 51.13872371613979, 49.80757914483547, 46.35799124836922, 49.5873049646616, 49.680882543325424, 51.11008085310459, 51.3555096834898, 54.30832363665104, 55.54516866803169, 54.71899800002575, 56.58487267792225, 58.846507519483566, 52.194451466202736, 47.11596317589283, 45.30363902449608, 51.30278371274471, 48.92886109650135, 53.98137778043747, 47.38327123224735, 47.47235745191574, 47.87103205919266, 59.95512843132019, 62.040293142199516, 63.36313135921955, 65.8914814889431, 65.51600083708763, 65.39914190769196, 64.32116255164146, 54.66994643211365, 30.314741022884846, 10.929833259433508, 1.6385053284466267, 0.6583374144975096, 1.8849903834052384, 3.36739759426564, 20.6289429590106, 52.378046214580536, 68.52702006697655, 59.645224660634995, 63.91105815768242, 72.77412056922913, 25.381762124598026, 2.205183170735836, 34.19110871851444, 32.05167531967163, 32.96754017472267, 20.299460738897324, 15.54524039849639, 40.80988235771656, 31.5055800229311, 33.53331081569195, 52.60091945528984, 44.59115445613861, 41.095756217837334, 29.257160872220993, 62.17382937669754, 78.85188683867455, 39.41127620637417, 0.5335564445704222, 0.2146005057147704, 0.3524867497617379, 0.30848997936118394, 0.17917948920512572, 0.14925900410162285], [0.029814040717610624, 0.14370560209499672, 0.05718212225474417, 0.08268152974778786, 0.054839225122123025, 0.13070298184175044, 0.07327255923883058, 0.03564026548701804, 0.12672033539274707, 0.23620307387318462, 0.5588941380847245, 11.257294937968254, 53.889525309205055, 44.00347039103508, 42.518304884433746, 34.97939541935921, 36.044801250100136, 38.29167388379574, 33.43149907886982, 42.38473825156689, 25.436061210930347, 12.454284857958555, 25.527512803673744, 19.528955183923244, 9.956707376986742, 5.037496564909816, 7.732654418796301, 48.38393233716488, 56.02009758353233, 58.37589517235756, 52.339938059449196, 64.98007759451866, 43.96829567849636, 7.2948257625103, 0.15636726486263797, 1.8087366688996553, 22.24564030766487, 66.339530646801, 65.48706918954849, 66.41185596585274, 60.08466728031635, 55.26153288781643, 51.816516146063805, 57.694344744086266, 63.44954252243042, 63.81846472620964, 61.08008086681366, 60.186612010002136, 58.65714468061924, 61.73481233417988, 54.16023038327694, 49.17226083576679, 43.04882861673832, 47.23957434296608, 46.39220841228962, 55.765150263905525, 56.08753636479378, 55.93722403049469, 53.769060373306274, 55.23276083171368, 50.992887541651726, 48.92986424267292, 46.844631135463715, 49.37483936548233, 50.84738574922085, 49.50287349522114, 51.668620482087135, 42.51621499657631, 33.695953488349915, 31.523423865437508, 12.671181969344616, 0.9816887823399156, 2.361052706837654, 1.334002730436623, 0.17654606723226607, 0.031329255798482336, 0.10201061013503931, 0.07673104904824868, 0.1818085473496467, 0.14579651411622763, 0.01054558451869525, 0.05026506471040193, 0.02079403908282984, 0.012430047754605766, 0.011083455119660357, 0.02023050037678331, 0.08506046928232536, 0.03429848475207109, 0.4045608773594722, 0.8552776998840272, 0.05407449389167596, 0.08298327957163565, 0.045545714237960055, 0.03468403789156582, 0.02802914215862984, 0.05443887726869434, 0.053924758176435716, 0.060204793262528256, 0.02711226508836262, 0.1387453541974537, 0.038608908143942244, 0.06435425966628827, 0.04643998734536581, 0.1632191878161393, 3.055168348364532, 6.341827400028706, 5.759014198556542, 8.756836261600256, 32.91106000542641, 44.63091552257538, 48.140616193413734, 51.459540501236916, 44.7524444013834, 42.11627885699272, 42.01285220682621, 41.87259033322334, 41.97687193751335, 45.47432966530323, 47.208252623677254, 49.3077577650547, 51.807290241122246, 53.1077628582716, 50.860194861888885, 52.11093954741955, 48.57288479804993, 42.84470357000828, 39.554410725831985, 43.396308571100235, 46.54044605791569, 49.21621307730675, 45.64582206308842, 42.90836535394192, 44.618957564234734, 47.205680161714554, 53.30402612686157, 58.930114433169365, 57.57707543671131, 58.29084053635597, 57.69384317100048, 61.05576977133751, 62.190092504024506, 30.98355833441019, 8.474312871694565, 0.6386510271113366, 0.2010038704611361, 0.6529741804115474, 3.721879622898996, 41.4509953558445, 57.545597925782204, 51.68815903365612, 49.51202720403671, 52.6165746152401, 41.84472642838955, 4.067907817661762, 1.6081032785587013, 30.70387054234743, 29.566872753202915, 31.456910334527493, 11.792456321418285, 17.012268528342247, 24.575504288077354, 38.24127718806267, 29.163881577551365, 32.82217517495155, 30.09135100990534, 35.77077895402908, 29.92555070668459, 44.127385541796684, 52.28930577635765, 13.410286009311676, 0.4063257045345381, 0.013882891817047494, 0.17067404638510197, 0.0109490827890113, 0.03093242943577934, 0.056861332632252015, 0.04354003045591526, 0.07063135955831967, 0.0363050071609905, 0.0850142260605935, 0.03247123182518408, 0.054932750572334044, 0.045567025008494966, 0.07707923505222425, 0.12908774195238948, 0.23162475001299754, 0.6200508470647037, 16.201051957905293, 67.03931629657745, 55.35236321389675, 46.4316350966692, 38.60576122999191, 40.508991703391075, 43.04619535803795, 33.77664975821972, 39.57928039133549, 32.07124426960945, 13.491957876831293, 19.707104824483395, 10.03580393269658, 18.19740403443575, 7.733654715120792, 7.211620677262545, 51.498317420482635, 61.5892269462347, 62.2858739644289, 57.05477826297283, 64.80008125305176, 48.79655979573727, 8.955463953316212, 0.4329534585122019, 2.0802921848371625, 20.935166627168655, 67.30018749833107, 67.07501918077469, 67.95668587088585, 63.04303653538227, 58.93445760011673, 55.280360877513885, 59.3174010515213, 64.65199559926987, 65.05496397614479, 62.4632066488266, 60.76168455183506, 62.60724551975727, 63.79603832960129, 57.22036577761173, 53.31655405461788, 48.523825630545616, 49.44230854511261, 49.941449761390686, 58.764819502830505, 59.40871775150299, 59.43390280008316, 57.80676171183586, 57.708476185798645, 55.92023514211178, 52.06669472157955, 51.59442566335201, 52.894161120057106, 53.74305456876755, 53.246592208743095, 52.45558865368366, 47.36525259912014, 39.49453353881836, 40.31680941581726, 18.62426932901144, 1.8493580329231918, 2.9255858017131686, 0.8138724497985095, 0.06531338163767941, 0.15899311692919582, 0.12513717112597078, 0.13279756007250398, 0.16135430429130793, 0.020763048851222266, 0.04325206973589957, 0.022397875873139128, 0.03657749781268649, 0.04535282634606119, 0.0367246063251514, 0.06569293080247007, 0.0413647622190183, 0.044001215865137056, 0.15427805978106335, 0.8741052146069705, 0.07067571030347608, 0.07129452045774087, 0.07990225349203683, 0.011215508238819893, 0.023733055204502307, 0.08617838117061183, 0.04842021917284001, 0.06813980653532781, 0.05700525362044573, 0.126574280729983, 0.03679784516862128, 0.05119125758938026, 0.1181279202864971, 0.17357078235363588, 6.03323788382113, 9.627486392855644, 9.988710209727287, 16.771013773977757, 38.26088033616543, 46.848997101187706, 50.983540043234825, 53.53142112493515, 46.69370323419571, 45.49349583685398, 45.73444850742817, 45.82724332809448, 45.03506563603878, 48.003234565258026, 48.92864070832729, 52.00699992477894, 54.96321849524975, 53.550017327070236, 55.19365333020687, 55.50244756042957, 52.402630895376205, 44.177079275250435, 43.01584638655186, 45.301758125424385, 50.294891595840454, 52.817994207143784, 49.16544780135155, 46.312583684921265, 48.02107460796833, 47.69814133644104, 54.321679919958115, 59.353609308600426, 61.95699781179428, 61.11239053308964, 62.30904512107372, 61.26315884292126, 63.4278304874897, 36.80662617087364, 10.142980981618166, 0.7496343436650932, 0.29615886916872114, 0.22508283698698506, 4.867599131539464, 46.55754134058952, 61.856610998511314, 56.41267731785774, 53.357014283537865, 58.8150642067194, 47.81856067478657, 4.32886166498065, 2.6963911252096295, 34.68156740069389, 31.216333843767643, 29.635027796030045, 13.021597266197205, 15.203957911580801, 35.8558563888073, 31.3294480741024, 31.190652921795845, 35.94565697014332, 27.34828010201454, 39.660459235310555, 31.016056090593338, 53.78967426717281, 63.80011171102524, 17.25472591817379, 0.4216192604508251, 0.13534392812289298, 0.19156869471771643, 0.042751483706524596, 0.04247978715284262, 0.014759778259758605, 0.07626984137459658, 0.3529888275079429, 0.14462816587183625, 0.20250753586879, 0.17584389162948355, 0.185072319873143, 0.12062797090038657, 0.23117815522709861, 0.32771017926279455, 0.4808669281192124, 0.8822114858776331, 22.349661625921726, 80.31485393643379, 62.98417389392853, 54.818184077739716, 45.96835635602474, 45.46897195279598, 51.16678141057491, 45.75549937784672, 56.35389067232609, 36.0121876001358, 18.682611398398876, 38.25925402343273, 25.77768947929144, 15.764440186321735, 9.876738768070936, 13.336488269269466, 58.27656850218773, 67.70335346460342, 69.0844577550888, 63.901391476392746, 71.82318359613419, 50.52883364260197, 9.43983156234026, 0.7888563734013587, 4.1282006073743105, 26.965074464678764, 70.98155155777931, 67.76616409420967, 69.67248380184174, 64.54447656869888, 61.23619168996811, 56.73685312271118, 62.15944714844227, 69.90169510245323, 70.535197108984, 64.40443888306618, 62.40750543773174, 65.89931666851044, 66.17022693157196, 60.14334373176098, 55.99911130964756, 49.90292362868786, 52.84714624285698, 52.90518432855606, 63.213282600045204, 62.227231711149216, 62.72430203855038, 61.02689892053604, 60.27868866920471, 56.79051764309406, 57.813342958688736, 55.10978803038597, 59.62465636432171, 55.27040161192417, 59.49476793408394, 54.26365703344345, 54.79408577084541, 35.03638096153736, 47.67181634902954, 23.265790566802025, 7.618800653144717, 8.395202066749334, 5.485900528728962, 0.6150738266296685, 0.3191372752189636, 0.1319998552207835, 0.2395787474233657, 0.25615221122279763, 0.31803352350834757, 0.17173539177747443, 0.17082167440094054, 0.11043717007851228, 0.16585198638495058, 0.12243965727975592, 0.12548031052574515, 0.3318186494288966, 0.18053015344776213, 1.0446224897168577, 2.5968495290726423, 0.23476658767322078, 0.20530071255052462, 0.16387189185479656, 0.14203112397808582, 0.2936320344451815, 0.15103727899258956, 0.2219852907001041, 0.14299241302069277, 0.17451498715672642, 0.30425445351284, 0.16617237153695896, 0.13791975943604484, 0.21782346011605114, 0.794195324415341, 15.12520618736744, 16.30328357219696, 19.209219440817833, 28.60246740281582, 42.3347557336092, 47.11637355387211, 54.52386327087879, 56.75671465694904, 48.59729088842869, 47.733802422881126, 49.385486394166946, 50.37628322839737, 47.67311587929726, 51.40454605221748, 52.47110702097416, 54.09835450351238, 55.69603577256203, 57.61840961873531, 58.19702737033367, 57.17289112508297, 54.495421797037125, 47.015165984630585, 45.61268024146557, 48.747705817222595, 54.15302976965904, 56.13388627767563, 51.95843853056431, 48.186795115470886, 49.64859567582607, 50.18458731472492, 58.63955542445183, 62.72673010826111, 64.47596624493599, 63.515438586473465, 64.23296928405762, 65.12861922383308, 66.38148039579391, 37.378731071949005, 12.9123455286026, 1.2391358334571123, 0.5289881397038698, 1.5587375150062144, 6.435130443423986, 48.4886509180069, 68.86395558714867, 59.01432551443577, 60.485534369945526, 63.573982045054436, 50.878905057907104, 10.544994659721851, 3.8777976064011455, 40.74476145207882, 39.18694384396076, 38.75142261385918, 16.210959926247597, 25.075964033603668, 38.680427223443985, 49.02688443660736, 42.893192768096924, 44.73847255110741, 40.13001523911953, 51.3236939907074, 42.408498376607895, 64.56083089113235, 73.87894928455353, 23.66686474531889, 0.5291864415630698, 0.19553510297555476, 0.2838854683795944, 0.14142406202154234, 0.08961639512563124, 0.16147992020705715], [0.007890551205491647, 0.04825394840736408, 0.04881876731815282, 0.03293142275651917, 0.0664272413996514, 0.01622207728360081, 0.08474740912788548, 0.027526765697984956, 0.13007800444029272, 0.11047442589187995, 0.6461734953336418, 9.036676045507193, 52.01668940484524, 46.30078911781311, 29.291600324213505, 32.378104403615, 32.37439960241318, 35.71180611848831, 33.09770978987217, 49.186095893383026, 35.724877417087555, 11.697859447449446, 12.007335741072893, 44.12061810493469, 17.81722493469715, 8.889610636979342, 0.6826811644714326, 30.85303533822298, 63.83905962109566, 51.87882520258427, 54.50470469892025, 58.86620186269283, 53.30520026385784, 13.209092505276203, 0.2905217232182622, 0.5613165674731135, 14.024407155811787, 60.44448137283325, 68.23622927069664, 66.23442068696022, 61.0684534907341, 59.119712859392166, 54.53091949224472, 60.35738244652748, 62.53380686044693, 63.5604053735733, 59.49251085519791, 58.66052269935608, 59.36198025941849, 58.71013663709164, 55.29293820261955, 49.76844124495983, 48.91806207597256, 47.42622032761574, 47.18904085457325, 55.19334174692631, 56.46815054118633, 54.167301803827286, 56.53601489961147, 55.73948264122009, 50.41000261902809, 48.54935646057129, 46.151027753949165, 47.497443705797195, 48.04933749139309, 50.359651520848274, 43.18331480026245, 52.52288304269314, 46.51840724050999, 23.13740875571966, 8.06214613839984, 1.847520237788558, 2.182322172448039, 0.6874187977518886, 0.034769904377753846, 0.02758390735834837, 0.07062627584673464, 0.09666054174886085, 0.03877625502354931, 0.04975654141162522, 0.023914148514450062, 0.002523185676182038, 0.014439807782764547, 0.017796380307117943, 0.0314625640749, 0.051348897177376784, 0.08215598529204726, 0.03717594714544248, 0.27400819526519626, 0.5392347648739815, 0.08758336320170201, 0.040702970582060516, 0.03959821326134261, 0.020990383527532686, 0.029157006247260142, 0.055788591562304646, 0.06073687232856173, 0.009313205628131982, 0.04381648788694292, 0.03588055806176271, 0.024737305320741143, 0.011964748064201558, 0.012514293575804913, 0.05334453599061817, 1.2290537869557738, 4.7169695142656565, 6.457439046353102, 5.2223846688866615, 23.38618140667677, 43.843194991350174, 46.54852822422981, 47.27495804429054, 48.11144895851612, 45.40060602128506, 42.97560654580593, 44.14580315351486, 46.41650430858135, 48.49212013185024, 48.18006567656994, 50.57764582335949, 52.270245999097824, 50.03099575638771, 53.01090605556965, 52.03939698636532, 49.74364757537842, 39.916265308856964, 43.500145599246025, 45.424407944083214, 48.877199068665504, 49.8713169246912, 49.25495579838753, 44.010378420352936, 45.2900243550539, 47.62825548648834, 48.93646068871021, 51.657532677054405, 56.52165926992893, 54.54166151583195, 61.53579041361809, 58.496500700712204, 64.35079336166382, 43.967003747820854, 9.030240140855312, 0.22723862755810842, 0.09189533768221736, 0.4165672534145415, 11.650562435388565, 47.59112387895584, 58.07990625500679, 55.10262921452522, 43.38014043867588, 25.91520980000496, 35.38797229528427, 1.709652473218739, 4.631043775007129, 44.91060331463814, 25.79783219844103, 18.248883672058582, 15.399933345615864, 28.619418293237686, 25.05492266267538, 43.328634202480316, 31.212277561426163, 24.825739860534668, 34.92522552609444, 40.14440506696701, 33.79286728799343, 45.20001478493214, 59.70520444214344, 10.411030948162079, 0.3669329808326438, 0.04960911006492097, 0.08253711523138918, 0.07397241934086196, 0.038897488557267934, 0.019011799267900642, 0.09217238140990958, 0.06202427961397916, 0.04602121567586437, 0.07853072747820988, 0.03549438522895798, 0.08525048877345398, 0.06499956449260935, 0.09761560417246073, 0.09534263590467162, 0.21415889816125855, 0.6313565466552973, 11.732036713510752, 66.24421656131744, 57.396235540509224, 27.119429782032967, 34.097641333937645, 38.139864429831505, 38.25703114271164, 35.02541474997997, 44.59991678595543, 40.01461163163185, 17.20224693417549, 13.712948318570852, 22.13651016354561, 13.820957522839308, 14.759162329137325, 1.4930962747894228, 31.23198140412569, 69.49200108647346, 55.68782061338425, 59.870297983288765, 63.1129489839077, 60.380367413163185, 15.104380454868078, 0.2512439136626199, 0.4386139375856146, 15.356116946786642, 61.809789910912514, 70.6033730506897, 67.679323554039, 64.08448845148087, 61.12529844045639, 58.17729502916336, 63.14394772052765, 65.16497567296028, 67.18695357441902, 62.842080518603325, 61.65875181555748, 60.338862240314484, 60.69652184844017, 59.42585863173008, 52.68736481666565, 50.87511666119099, 47.90379770100117, 51.61118656396866, 58.33175674080849, 57.90724352002144, 57.57152013480663, 59.77870769798756, 59.81813818216324, 54.34750713407993, 51.71100340783596, 50.22768460214138, 51.87285952270031, 52.12155997753143, 52.12492659687996, 45.63582859933376, 54.96432043612003, 42.60935939848423, 31.412997990846634, 10.507700610905886, 2.2370760468766093, 3.4484607819467783, 0.8066658989991993, 0.027186142178834416, 0.07634459048858844, 0.08743790225707926, 0.03037079248315422, 0.06905241069034673, 0.053333043833845295, 0.05203847853408661, 0.023033896432025358, 0.05594286551058758, 0.02201175313530257, 0.05915716646995861, 0.07375981629593298, 0.03468580420303624, 0.035006129983230494, 0.10620145869324915, 1.14608452655375, 0.09315413888543844, 0.0969563024409581, 0.021869448173674755, 0.06233310210518539, 0.07233013559016399, 0.07762228677165695, 0.020840992910962086, 0.016707965078239795, 0.038226891338126734, 0.020101676527701784, 0.09385267796460539, 0.0696918525500223, 0.042584018083289266, 0.008535805009159958, 1.2331814342178404, 6.540387170389295, 10.203389190137386, 12.123435661196709, 30.266479812562466, 47.37264700233936, 49.965802654623985, 49.7127590328455, 48.65053743124008, 48.798041716217995, 45.50821624696255, 46.95106342434883, 48.320232555270195, 49.44242253899574, 52.55977526307106, 54.497196301817894, 53.8007240742445, 52.28133000433445, 57.01860800385475, 53.403679579496384, 51.08151018619537, 43.529145643115044, 47.10276648402214, 47.61697769165039, 51.823857352137566, 53.76944415271282, 53.22360344231129, 47.38190330564976, 48.30040901899338, 50.49500785768032, 49.841898903250694, 52.53831021487713, 58.060770481824875, 55.924091935157776, 64.72570404410362, 61.082478538155556, 65.36509573459625, 46.36617220938206, 10.061076376587152, 0.25431640504393727, 0.1339861095766537, 1.2619686895050108, 17.271956093609333, 55.200405567884445, 61.52976393699646, 60.8429279923439, 46.243074014782906, 31.67643405497074, 32.04889766871929, 1.3186773215420544, 6.117185829207301, 53.85270908474922, 29.98802125453949, 11.062360648065805, 15.64123559743166, 31.745219863951206, 29.077124632894993, 28.389532528817654, 35.41115865111351, 25.31839482486248, 34.25254002213478, 43.8577976077795, 33.660607784986496, 54.32917691767216, 73.54079023003578, 12.202332727611065, 0.5230640794616193, 0.06772071574232541, 0.13343530241400003, 0.019593014076235704, 0.14006872224854305, 0.025094729207921773, 0.15327420114772394, 0.16761090606451035, 0.17039492464391515, 0.16839081421494484, 0.1864456493058242, 0.14896992273861542, 0.176136817317456, 0.20456151862163097, 0.3544627921655774, 0.3201639623148367, 0.8088888390921056, 15.906222928315401, 81.00802794098854, 68.43305870890617, 38.727951273322105, 39.99349996447563, 42.72986613214016, 46.91294766962528, 47.23099820315838, 63.11291478574276, 47.78097689151764, 19.115440472960472, 21.80793609470129, 55.237810760736465, 23.863205909729004, 16.642529368400574, 4.762008022516966, 38.43353547155857, 75.4046206176281, 63.23095165193081, 64.74914118647575, 67.94307500123978, 63.785695284605026, 16.099753193557262, 0.879476226400584, 1.4603098528459668, 18.906698673963547, 63.91178771853447, 73.38869199156761, 70.71952521800995, 65.48215985298157, 63.44768442213535, 59.25991773605347, 65.42393937706947, 69.15894895792007, 67.89448320865631, 64.40156623721123, 62.345766350626945, 63.59395757317543, 62.92664498090744, 61.32731080055237, 52.84448638558388, 56.34393520653248, 51.59010149538517, 54.02395449578762, 60.92813082039356, 62.31603294610977, 59.82360988855362, 62.941946759819984, 61.37651436030865, 57.16575130820274, 57.986982241272926, 55.72561338543892, 57.61206015944481, 55.878942757844925, 59.60033006966114, 48.40344049036503, 53.71363654732704, 56.3863979279995, 41.14881657063961, 21.530302092432976, 5.304192379117012, 7.292211977764964, 1.9452020712196827, 0.08930953932576813, 0.1296544013894163, 0.23339441599091515, 0.13371648732572794, 0.12386288872221485, 0.1664761919528246, 0.09214040968799964, 0.13378567033214495, 0.12874335574451834, 0.09142078619333915, 0.14268342725699767, 0.20828422042541206, 0.18552523775724694, 0.12437373123248108, 0.6441718933638185, 1.58657256513834, 0.26669005514122546, 0.19368997542187572, 0.14986652618972585, 0.12865294731454924, 0.1316276384750381, 0.17299419298069552, 0.1475169014884159, 0.3172091458691284, 0.1877996977418661, 0.22515831340570003, 0.20207441848469898, 0.21622732310788706, 0.16780938603915274, 0.2939467941178009, 4.935434516519308, 17.673887126147747, 14.959697518497705, 22.06039074808359, 38.02705988287926, 51.289222240448, 51.07118993997574, 51.93979673087597, 51.937855035066605, 49.876587241888046, 48.374531641602516, 49.046920761466026, 51.945006251335144, 53.73054563999176, 55.488308519124985, 56.780417785048485, 56.98871500790119, 54.8973224312067, 57.82052457332611, 57.54055939614773, 55.76214462518692, 46.01150684058666, 51.335731744766235, 52.459004670381546, 53.66657607257366, 57.949748039245605, 54.52895499765873, 50.728471130132675, 50.78212045133114, 54.00234505534172, 53.98921296000481, 56.49533428251743, 63.02080012857914, 57.82429397106171, 66.66242972016335, 63.83696213364601, 67.92861297726631, 48.500612676143646, 14.19622728601098, 0.7457201974466443, 0.4289654834428802, 1.0730741755105555, 15.041262991726398, 55.967618599534035, 68.45156371593475, 65.93383401632309, 54.849919974803925, 35.375516563653946, 42.10260719060898, 3.6995916813611984, 7.645775405690074, 56.90124370157719, 32.10417330265045, 24.462074674665928, 21.923550590872765, 37.44397737085819, 33.569933250546455, 54.70183812081814, 46.281584948301315, 33.663993403315544, 45.261035710573196, 52.05689884722233, 47.74335891008377, 65.8245974779129, 87.23013326525688, 18.587356209754944, 0.71729083545506, 0.4900599707616493, 0.24423412105534226, 0.18927823402918875, 0.36770668462850153, 0.13066867977613583], [0.04392424030811526, 0.025468035055382643, 0.0587788678240031, 0.028117548645241186, 0.050835987785831094, 0.04565358911349904, 0.0797054433496669, 0.05465007394377608, 0.15191791142569855, 0.07393077001324855, 0.6207865825854242, 5.044601708650589, 57.072428315877914, 48.34933899343014, 43.08883287012577, 39.15933072566986, 34.50505547225475, 38.401605784893036, 31.861130744218826, 44.70666445791721, 36.85021363198757, 15.495348125696182, 17.20633551478386, 37.06019416451454, 32.419981956481934, 13.396431002765894, 1.0743700247257948, 19.358559027314186, 68.28262478113174, 58.1865057349205, 52.66822524368763, 58.13259802758694, 56.44026763737202, 12.933351751416922, 0.31225970364175737, 0.6045893579721451, 12.285758201032877, 56.78828336298466, 65.69798067212105, 66.87641143798828, 63.63425441086292, 60.255228728055954, 57.424122244119644, 62.59512037038803, 62.56985932588577, 63.95987793803215, 62.79494024813175, 59.567944407463074, 61.106968224048615, 61.786098182201385, 55.71224570274353, 48.88612858951092, 45.128692612051964, 46.49769835174084, 50.913232415914536, 55.353746339678764, 55.07148988544941, 58.91023389995098, 57.81019292771816, 53.215696066617966, 51.157179325819016, 47.30749569833279, 45.56963995099068, 48.55517394840717, 48.493871837854385, 43.438782691955566, 43.777785301208496, 48.81899379193783, 17.288827188313007, 19.22674410045147, 11.073797084391117, 3.7103788275271654, 2.1220422070473433, 0.29273014690261334, 0.08651135314721614, 0.10590905993012711, 0.10241028634482063, 0.027306553784001153, 0.13138109701685607, 0.05214684322709218, 0.04841518741159234, 0.1068902162660379, 0.047416156448889524, 0.0590558039402822, 0.04507452467805706, 0.05825380205351394, 0.0803647079737857, 0.04133533235290088, 0.15060570527566597, 0.8590199053287506, 0.294941509491764, 0.024208975955843925, 0.07572108996100724, 0.04804018019058276, 0.024827257329889107, 0.03178412553097587, 0.06390042151906528, 0.04306792063289322, 0.0494958768831566, 0.031904613206279464, 0.01111783418309642, 0.08130982561851852, 0.047028495609993115, 0.02149992171325721, 0.12671465054154396, 2.4405546532943845, 8.879420533776283, 7.8439604211598635, 15.597991067916155, 39.545921981334686, 42.36107312142849, 49.81076717376709, 48.37476722896099, 45.2514336258173, 44.41787615418434, 42.1379566937685, 44.80332747101784, 47.24183142185211, 49.545412212610245, 50.00159293413162, 48.18127401173115, 49.86275598406792, 52.14529350399971, 49.8547650128603, 47.986169680953026, 40.85321143269539, 42.99579106271267, 45.83615005016327, 51.81793347001076, 51.790962517261505, 51.31083548069, 47.31407314538956, 46.22963413596153, 48.003447353839874, 48.137067183852196, 47.66548968851566, 51.042398884892464, 53.08390773832798, 57.59690657258034, 57.80943676829338, 62.594850584864616, 46.97075016796589, 8.08784605935216, 0.010706911652960116, 0.3073469235096127, 2.766825808212161, 35.58452054858208, 50.07371686398983, 52.65203811228275, 47.092822417616844, 45.89529387652874, 57.994167655706406, 37.01653830707073, 0.4181563697056845, 16.124733053147793, 31.26447156071663, 14.869867488741875, 26.6512531042099, 10.736201349645853, 20.299118757247925, 35.83172008395195, 44.20135237276554, 26.9780108705163, 26.567845679819584, 30.204833820462227, 32.97664828598499, 28.885151334106922, 44.8406832665205, 55.763786137104034, 4.594780895859003, 0.15720590658020228, 0.09250196919310838, 0.10590507459710352, 0.04716989329608623, 0.08416341312113218, 0.07998309563845396, 0.07134109764592722, 0.02636313009134028, 0.04128318163566291, 0.08082892876700498, 0.07940096984384581, 0.06387681380147114, 0.09263519212254323, 0.102054411690915, 0.24281663383590057, 0.218162992678117, 0.6068236380815506, 7.024742905050516, 72.36769437789917, 57.82876253128052, 44.707359820604324, 42.56884217262268, 36.56414978206158, 46.642428785562515, 32.145800068974495, 37.29337625205517, 32.34297148883343, 24.78552281856537, 28.431714065372944, 35.95449149608612, 24.671492837369442, 16.90835550427437, 2.971208291128278, 18.120566457509995, 73.74144986271858, 63.74735914170742, 58.121620416641235, 61.902960911393166, 60.482293143868446, 16.174546480178833, 0.7105546281673014, 1.1445127171464264, 11.834955140948296, 55.13008274137974, 66.43491312861443, 68.07878851890564, 64.89705964922905, 64.1943709552288, 62.56586953997612, 63.90668839216232, 64.3043902516365, 65.92210784554482, 63.2209961861372, 61.75528943538666, 63.154936730861664, 62.679985016584396, 58.85235160589218, 51.357075199484825, 48.66529583930969, 50.984774976968765, 53.12266945838928, 59.2915016412735, 58.46304349601269, 60.908531472086906, 58.42730641365051, 57.226893827319145, 55.87502136826515, 53.0313565582037, 47.655587419867516, 53.253743425011635, 53.68608042597771, 45.57510785758495, 45.49359083175659, 47.18349315226078, 24.06361475586891, 28.599722050130367, 20.578601360321045, 6.78513441234827, 2.4475916381925344, 0.5319957376923412, 0.090456135221757, 0.09362238954054192, 0.0987882494518999, 0.0380699827655917, 0.09288827190175653, 0.09159465655102395, 0.0583593131887028, 0.02996417533722706, 0.03539322307915427, 0.01371525642753113, 0.06463114754296839, 0.07620597956702113, 0.023526099903392605, 0.06403896564734168, 0.15793294413015246, 0.6003788870293647, 0.34859091974794865, 0.027200474905839656, 0.029401590290945023, 0.04230854399793316, 0.030234385740186553, 0.0026019924825959606, 0.050430329865776, 0.0484093096019933, 0.03510778566123918, 0.034465853896108456, 0.04136353025387507, 0.031312705905293114, 0.07556927623227239, 0.024047577389865182, 0.6534390023443848, 1.9550860533490777, 10.698130242526531, 13.508486989885569, 23.07087242603302, 44.43032048642635, 46.80063709616661, 51.0759586840868, 50.82389920949936, 47.7640487998724, 47.0806098729372, 45.844232216477394, 47.273175939917564, 51.45739361643791, 51.07923410832882, 51.96249671280384, 48.63998539745808, 52.278651148080826, 54.958457350730896, 51.94534823298454, 51.02473743259907, 45.09572558104992, 46.88218832015991, 49.10653576254845, 53.882374092936516, 55.85240878164768, 53.67572598159313, 51.92542590200901, 48.251589238643646, 49.32767629623413, 51.72282837331295, 50.84711216390133, 52.63353690505028, 56.71910807490349, 59.460489973425865, 62.66341410577297, 63.51040005683899, 48.15378628671169, 8.733546361327171, 0.6461547932121903, 1.090762938838452, 6.230703787878156, 45.73242701590061, 53.982301130890846, 58.34491923451424, 49.838479086756706, 51.60269021987915, 60.13200893998146, 29.474773295223713, 0.34149865969084203, 19.37271136790514, 42.47491881251335, 12.57758254185319, 9.77445300668478, 12.873998936265707, 21.224224716424942, 28.763497062027454, 32.9742506146431, 35.694555044174194, 25.707902424037457, 30.34295830875635, 34.58806961774826, 31.485513299703598, 58.51320080459118, 65.96088856458664, 6.0815484914928675, 0.18775695003569126, 0.01975331426365301, 0.03480112653051037, 0.016489474946865812, 0.11293078627204522, 0.01904855413158657, 0.15389269217848778, 0.10354238809668459, 0.10328913762350567, 0.23867726064054295, 0.22393140970962122, 0.22337974165566266, 0.17098132520914078, 0.22501494531752542, 0.4665381641825661, 0.3986728854943067, 1.142673259600997, 10.455151330679655, 85.22332414984703, 66.84731259942055, 56.09992370009422, 53.998568058013916, 42.96233765780926, 50.79662427306175, 46.902950406074524, 59.46835175156593, 50.18420733511448, 22.5451535359025, 24.340391904115677, 43.45542959868908, 41.25060550868511, 20.759925730526447, 4.580933013930917, 24.570705145597458, 80.29023125767708, 68.31667095422745, 66.59633606672287, 66.72291487455368, 66.96597263216972, 17.17264462262392, 0.6527012481819838, 1.9115451397374272, 16.592064276337624, 62.773137018084526, 68.75575259327888, 70.56156009435654, 68.71233612298965, 65.75048625469208, 63.514572232961655, 67.07650110125542, 65.29174447059631, 69.28855240345001, 68.13622623682022, 64.63649243116379, 64.60965067148209, 65.87176814675331, 60.9579212218523, 55.66818326711655, 50.8380002528429, 53.29483062028885, 56.270253360271454, 60.79579912126064, 63.21560047566891, 64.35718461871147, 63.56607846915722, 58.72330293059349, 59.45102848112583, 56.229838728904724, 52.526720836758614, 56.79446943104267, 56.90375916659832, 51.362056732177734, 44.39870998263359, 56.149944216012955, 33.14224720001221, 31.786035373806953, 22.166526652872562, 10.039985608309507, 5.050700856372714, 0.9187025902792811, 0.3083343955222517, 0.3472933784360066, 0.26205379923339933, 0.1099494454683736, 0.2360117927310057, 0.20659838744904846, 0.1514855955610983, 0.1650111033814028, 0.14619384513935074, 0.18534937844378874, 0.10736827069194987, 0.19337460718816146, 0.2253524592379108, 0.18791732814861462, 0.35326312528923154, 2.4326798133552074, 0.7497790921479464, 0.20753626915393397, 0.19900081388186663, 0.11443036986747757, 0.05128348428115714, 0.13914366485551, 0.1854920489131473, 0.11306503336527385, 0.13085261365631595, 0.11827039779745974, 0.06532325220177881, 0.165488927741535, 0.16810024855658412, 0.21334057644708082, 1.0948768118396401, 9.227472357451916, 18.74806858599186, 20.076534301042557, 31.414012536406517, 45.74161112308502, 49.72644589841366, 54.43522162735462, 53.452001586556435, 51.34403049945831, 52.10276618599892, 50.261620581150055, 51.62702031433582, 53.322679325938225, 55.168787464499474, 54.79519531130791, 51.89715921878815, 55.75155459344387, 56.34083837270737, 54.24612857401371, 53.75364080071449, 47.257004007697105, 48.15344050526619, 51.41852930188179, 57.14229516685009, 58.809702694416046, 56.593479216098785, 54.336404129862785, 50.219378247857094, 52.58504390716553, 54.06718097627163, 52.05999568104744, 55.19661717116833, 57.08556801080704, 61.09628699719906, 65.27853637933731, 63.89388307929039, 54.41776156425476, 10.875076297670603, 1.3022598274983466, 1.014353670179844, 4.521799637004733, 45.75969435274601, 58.43642972409725, 65.21462380886078, 55.97906358540058, 58.23141932487488, 68.33294168114662, 46.739688366651535, 0.6427938141860068, 22.72296879440546, 40.72362318634987, 21.750762462615967, 38.16255301237106, 18.132459819316864, 27.060422748327255, 48.152912333607674, 57.59631760418415, 43.03564332425594, 38.14253568649292, 40.621781051158905, 43.394910246133804, 43.824192211031914, 69.84100475907326, 79.07355934381485, 10.845955610275269, 0.42192066146526486, 0.2672232437180355, 0.28358492825645953, 0.13522096909582615, 0.34771411679685116, 0.15017617988632992], [0.001019421586079261, 0.02969920820760308, 0.03247351764002815, 0.034232734178658575, 0.02362455506954575, 0.07297780786757357, 0.045171753445174545, 0.040364651431445964, 0.08078518658294342, 0.04349566486780532, 0.4148163489298895, 1.2443269486539066, 50.31534969806671, 54.64740224182606, 33.39811787009239, 46.283994019031525, 45.30096776783466, 31.458749435842037, 36.41953334212303, 62.86063872277737, 54.14626993238926, 19.79087322950363, 14.693540800362825, 48.86998325586319, 62.87508934736252, 42.730607092380524, 1.8402422033250332, 7.262373603880405, 51.11549936234951, 62.41605497896671, 57.01237253844738, 59.90503191947937, 55.41075088083744, 30.549591220915318, 2.9343362571671605, 0.2802535757655278, 1.8149475543759763, 29.10729691386223, 64.57089275121689, 67.85918310284615, 65.49167454242706, 63.92909958958626, 62.54106067121029, 61.913824528455734, 62.942212745547295, 62.317689657211304, 59.36689719557762, 62.699037194252014, 61.054265052080154, 57.70215332508087, 53.95694509148598, 49.30052675306797, 50.44626787304878, 49.04540844261646, 51.43544599413872, 55.502835139632225, 56.64253458380699, 56.25800281763077, 53.85486736893654, 55.093635097146034, 49.97587591409683, 50.18501669168472, 44.58656810224056, 48.74046340584755, 44.86474737524986, 38.606175407767296, 43.254895359277725, 20.965135619044304, 20.648092031478882, 31.119154058396816, 22.34163835644722, 9.441455025225878, 2.804989297874272, 0.2428297550068237, 0.06834769694251008, 0.2478978072758764, 0.0941037391021382, 0.07619268028065562, 0.01705080761894351, 0.07729607576038688, 0.07035873903078027, 0.028687551457551308, 0.040154349044314586, 0.025110496135312133, 0.05930018945946358, 0.021527366334339604, 0.04493182452279143, 0.042662407431635074, 0.0063055042028281605, 0.09643008263083175, 0.4620285186683759, 0.03556342351657804, 0.04718077318102587, 0.041674152453197166, 0.06995052070124075, 0.06974118310608901, 0.13628178014187142, 0.12074935657437891, 0.050052621227223426, 0.0914313766406849, 0.07498263817979023, 0.027535448825801723, 0.05511209797987249, 0.21762728079920635, 0.2616246300749481, 1.3894068449735641, 7.8306882083415985, 13.914567399770021, 16.618982031941414, 36.63126938045025, 49.98749189078808, 46.39609180390835, 47.997933849692345, 45.91240055859089, 45.01550808548927, 45.35778611898422, 44.96534317731857, 45.626173317432404, 49.238137900829315, 50.34410275518894, 46.024551540613174, 51.34113505482674, 52.576570361852646, 51.99131056666374, 46.17848888039589, 40.87395451962948, 45.203400403261185, 49.54147182404995, 52.48996160924435, 53.325844556093216, 54.01747204363346, 48.45995865762234, 45.39541929960251, 48.49570333957672, 48.98423172533512, 50.2033507078886, 52.78597712516785, 56.456010192632675, 59.73170422017574, 57.96156920492649, 61.57685860991478, 39.28393363952637, 4.8477295227348804, 0.031443735788343474, 7.872902043163776, 23.563248105347157, 47.67760343849659, 55.48675820231438, 47.74153120815754, 49.14066173136234, 49.91501457989216, 53.152786642313, 8.378678653389215, 0.3686749201733619, 25.637951977550983, 17.970738597214222, 24.722991473972797, 15.58335805311799, 10.999336279928684, 22.613570764660835, 41.484403163194656, 26.397149339318275, 23.042672239243984, 36.05161428451538, 48.44171963632107, 42.997124791145325, 34.415342286229134, 53.3210302144289, 54.60925608873367, 3.59303233679384, 0.1050864634453319, 0.14253725385060534, 0.11660147094517015, 0.10175246890867129, 0.07322923265746795, 0.120301077113254, 0.013520149514079094, 0.060121179194538854, 0.04793750405951869, 0.03899537412507925, 0.04131507172132842, 0.03208140762581024, 0.0725332168804016, 0.039376199783873744, 0.16361813672119752, 0.08868155622621998, 0.34629459609277546, 1.8211416970007122, 61.165382489562035, 66.7042350769043, 36.39955401420593, 50.762437507510185, 29.19948186725378, 31.94841206073761, 43.66933532059193, 44.27018187940121, 41.92573428153992, 18.60597711056471, 20.758618600666523, 54.711839184165, 63.023042008280754, 45.54651819169521, 4.959477726370096, 7.470686975866556, 54.536463394761086, 67.06960067152977, 67.0306907594204, 66.19373247027397, 59.07988339662552, 37.594852074980736, 4.6371581219136715, 0.5250333831645548, 1.6352272918447852, 28.505804389715195, 66.2203386425972, 68.74718025326729, 66.00402384996414, 65.89213505387306, 67.1481728553772, 66.78091496229172, 65.27764722704887, 66.10726431012154, 62.980320900678635, 63.77803489565849, 62.872969061136246, 59.18229930102825, 56.541984379291534, 51.765287294983864, 54.29266467690468, 52.601755410432816, 54.883225187659264, 58.10749277472496, 57.81246900558472, 58.09394270181656, 57.534160539507866, 57.49267436563969, 54.87015388906002, 53.21191906929016, 51.2079332023859, 54.5038877427578, 47.3945452272892, 42.7425042539835, 44.86364923417568, 29.494927413761616, 28.512784615159035, 33.66289906203747, 27.62083377689123, 15.57251438498497, 2.3472523223608732, 0.886965268291533, 0.271509027807042, 0.4442231490975246, 0.1316751804552041, 0.1025937452504877, 0.009459514476475306, 0.026088040067406837, 0.06402194820111617, 0.07264686937560327, 0.01781470207788516, 0.010082060416607419, 0.021478770504472777, 0.02522449187381426, 0.07974301828653552, 0.08500722018652596, 0.07610472835949622, 0.3372514375951141, 0.9486114978790283, 0.06596141014597379, 0.0437635096750455, 0.07685826800297946, 0.054669280725647695, 0.08220664429245517, 0.12062537338351831, 0.07708438555710018, 0.03207937043043785, 0.08197893112082966, 0.08871769139659591, 0.020015600384795107, 0.11534037650562823, 0.5935524345841259, 0.9420278761535883, 3.3101486787199974, 14.531634338200092, 20.934119783341885, 24.248541332781315, 38.50277915596962, 51.66193664073944, 49.50494058430195, 51.43547639250755, 49.57585237920284, 47.52944938838482, 46.02692261338234, 46.7492638528347, 49.7980872541666, 51.32616385817528, 52.001585215330124, 47.86712966859341, 54.32072997093201, 54.38359759747982, 54.17088881134987, 48.253834918141365, 43.896867111325264, 48.232525661587715, 54.200075045228004, 56.23570941388607, 55.9654451161623, 57.295426949858665, 51.21625475585461, 48.21197256445885, 51.19098611176014, 50.90954661369324, 54.57992926239967, 57.60737881064415, 59.281945154070854, 61.25210143625736, 59.916948080062866, 64.29680585861206, 37.34438471496105, 4.425737466663122, 0.30372637091204524, 13.828520067036152, 31.10046476125717, 57.087821289896965, 57.56019674241543, 52.496056482195854, 55.14070317149162, 55.12026786804199, 53.66837717592716, 8.158996291458607, 0.07551744463853538, 34.61735464632511, 22.23308388143778, 7.611677935346961, 11.683547515422106, 13.535014316439629, 23.530928939580917, 35.89070051908493, 27.568727172911167, 29.696595892310143, 30.943436287343502, 53.37425395846367, 45.632598772645, 38.98010194301605, 62.11364820599556, 64.07493576407433, 4.157245298847556, 0.23533533996669576, 0.039332168162218295, 0.10717626224504784, 0.04433870009961538, 0.04397386030177586, 0.12159566467744298, 0.10512546330573969, 0.16728068003430963, 0.24920754949562252, 0.17624686297494918, 0.19867884053383023, 0.29344994109123945, 0.21265861694701016, 0.20157909428235143, 0.2184694996685721, 0.30734894215129316, 0.730430114781484, 4.192708795890212, 79.75911095738411, 76.38336449861526, 46.591226533055305, 62.85370409488678, 58.633232563734055, 35.833285599946976, 53.57429042458534, 78.00783812999725, 68.52078840136528, 24.28275279700756, 19.364545606076717, 55.47630116343498, 70.12576907873154, 54.64302867650986, 6.136846924200654, 11.43397405743599, 59.39951464533806, 72.0253175497055, 68.63221362233162, 68.46973434090614, 64.91276040673256, 36.75593689084053, 4.9825263395905495, 1.1580477096140385, 2.8412049170583487, 33.486565724015236, 69.13132444024086, 70.31654164195061, 68.02014246582985, 69.80996042490005, 67.93409988284111, 68.25320675969124, 66.51081025600433, 66.38094082474709, 62.85242356359959, 69.14995104074478, 65.53546339273453, 61.45546652376652, 59.41268093883991, 53.27306158840656, 57.565501257777214, 54.90357309579849, 57.74372689425945, 61.763219609856606, 58.965513333678246, 61.08553737401962, 59.74859431385994, 61.66466049849987, 58.30669708549976, 59.36091251671314, 56.97988048195839, 56.688139736652374, 54.642033129930496, 44.811584427952766, 47.4348458647728, 35.88917680084705, 28.83857913315296, 36.280396208167076, 30.6296681240201, 18.945241905748844, 7.515454748645425, 0.6300903833471239, 0.4676245496375486, 0.5096522241365165, 0.25038180523552, 0.24776963837211952, 0.07988107259734534, 0.14390004478627816, 0.1548785759950988, 0.17710947606246918, 0.08559382855310105, 0.16598487534793094, 0.15474167943466455, 0.18799382873112336, 0.2089481902658008, 0.17874825687613338, 0.18676318461075425, 1.0867415671236813, 1.2483581760898232, 0.18113467725925148, 0.21282361121848226, 0.13307512330356985, 0.11623585931374691, 0.17208930716151372, 0.24899525073124096, 0.1809860547655262, 0.08339549065567553, 0.14676161779789254, 0.15398379822727293, 0.13777959742583334, 0.23594624624820426, 0.8095481037162244, 1.0758955241180956, 7.57933359593153, 21.684336327016354, 23.734605610370636, 28.65286409854889, 44.50709156692028, 53.899412378668785, 50.287371799349785, 55.61801075935364, 50.87928123772144, 49.74542587995529, 50.06559669971466, 50.76118737459183, 51.837312430143356, 54.90638114511967, 56.43732659518719, 48.73694099485874, 55.92219203710556, 59.789898097515106, 57.572869062423706, 51.02572537958622, 47.98963509500027, 52.30991207063198, 55.74515573680401, 58.582520484924316, 58.602773398160934, 59.42963182926178, 54.331661984324455, 50.02168245613575, 54.6577262878418, 53.940051198005676, 57.32745163142681, 58.458890318870544, 62.00755409896374, 64.17718827724457, 60.5953598767519, 66.47804081439972, 44.58948254585266, 6.483970172703266, 0.7450468023307621, 11.564104724675417, 31.67879182845354, 62.11959108710289, 63.87629762291908, 57.025238648056984, 60.02067491412163, 59.00707170367241, 63.152459263801575, 12.76172161102295, 0.5282830994110554, 33.49105708301067, 23.932582587003708, 36.2771587818861, 26.275027692317963, 15.86303349584341, 32.45546445250511, 53.42687353491783, 38.255621418356895, 33.89349728822708, 43.60690087080002, 64.82611745595932, 53.80116105079651, 52.46519833803177, 73.3525863289833, 75.36948770284653, 6.548666451126337, 0.47277950739953667, 0.2940165559994057, 0.24345645419089124, 0.14109998097410426, 0.2080132029368542, 0.3847041225526482], [0.03703394831973128, 0.0007002966935942823, 0.13971903710626066, 0.04721875629911665, 0.08670405921293423, 0.023996730997168925, 0.024299299038830213, 0.018518779434089083, 0.010492372530279681, 0.020886057973257266, 0.40469443425536156, 0.46780542586930096, 35.40616571903229, 62.29430191218853, 35.9342347830534, 49.73927401006222, 103.31743642687798, 51.60382255911827, 31.953636780381203, 56.037113070487976, 36.98599934577942, 31.076887026429176, 12.560204174369574, 32.68882133066654, 51.40581898391247, 54.96734507381916, 7.96727092936635, 6.635707430541515, 50.05332335829735, 61.8822368234396, 48.60817730426788, 49.939812049269676, 58.305515348911285, 53.243951350450516, 10.870110914111137, 0.5274444725364447, 0.7703385420609266, 8.608648013323545, 45.38794510066509, 65.59484660625458, 66.64702534675598, 63.38198974728584, 66.1688894033432, 63.07979576289654, 66.64716973900795, 61.93829521536827, 60.19864596426487, 63.111178278923035, 64.50944244861603, 61.45951330661774, 56.26106545329094, 52.63487063348293, 50.78239403665066, 47.78072990477085, 50.17281174659729, 56.08519189059734, 57.83359207212925, 56.41261272132397, 55.15084482729435, 53.815341889858246, 52.45786853134632, 48.88097986578941, 46.90448172390461, 49.61519546806812, 41.07247866690159, 46.275984048843384, 35.628313198685646, 25.56611493229866, 23.27562063932419, 31.524675898253918, 32.802325040102005, 17.441582791507244, 3.7730913748964667, 0.9150079416576773, 0.754943311912939, 1.8217789940536022, 1.1985328746959567, 0.058042909658979625, 0.166186353599187, 0.042789685758179985, 0.09175628889352083, 0.017895006167236716, 0.03500681275909301, 0.030902515318302903, 0.09307084023021162, 0.01613557255041087, 0.056123819667845964, 0.08922681954572909, 0.16554172412725165, 0.05843909035320394, 0.49555987876374274, 0.013902168175263796, 0.025646747926657554, 0.03748228344193194, 0.0411944356164895, 0.08319504398969002, 0.024801779400149826, 0.05239720303507056, 0.06770435138605535, 0.0985826893884223, 0.03700727924297098, 0.2194040862377733, 1.2963364203460515, 1.164561747573316, 0.33908952958881855, 2.4561682529747486, 10.039319694042206, 24.31811559945345, 32.263228967785835, 29.617421440780163, 44.475857242941856, 51.48430377244949, 48.071619495749474, 46.39778271317482, 47.44785636663437, 44.541901499032974, 45.42753517627716, 47.049793526530266, 49.90967206656933, 48.54465611279011, 49.57003489136696, 52.270975559949875, 49.398124516010284, 50.687866508960724, 44.61261950433254, 41.70029237866402, 44.17861819267273, 49.51556861400604, 52.44698591530323, 56.55665539205074, 53.22401002049446, 51.44626781344414, 44.8483170568943, 50.43929524719715, 52.7673277258873, 55.11680245399475, 58.99903893470764, 58.91186021268368, 58.43301750719547, 58.340663462877274, 58.65227714180946, 20.658573769032955, 1.096508230548352, 6.935915546491742, 41.03831849992275, 48.94235037267208, 49.1083824634552, 56.01909823715687, 51.23230129480362, 51.6871976852417, 50.04139579832554, 40.89407444000244, 4.214752838015556, 1.6652683611027896, 31.685734055936337, 18.891843371093273, 22.121578864753246, 10.541403852403164, 12.370858434587717, 22.127983421087265, 26.087663546204567, 24.731622710824013, 34.069059267640114, 34.334950000047684, 40.947955548763275, 20.96713051199913, 31.266610845923424, 56.28839738667011, 34.602197259664536, 1.1066592670977116, 0.030084822574281134, 0.03732156394107733, 0.07853072005673312, 0.017785448471840937, 0.09907613595714793, 0.05911188432946801, 0.024327322535100393, 0.02070490714686457, 0.05205589302931912, 0.0776027311803773, 0.06332623670459725, 0.07524066808400676, 0.03635574037616607, 0.060289160610409454, 0.06859553715912625, 0.029312209735508077, 0.29703451436944306, 0.3499574214220047, 46.81137152016163, 73.54527398943901, 38.61217528581619, 59.482604786753654, 86.72353684902191, 27.986972630023956, 42.076115012168884, 50.85031919181347, 48.29381637275219, 23.776270374655724, 8.323306124657393, 35.573816522955894, 54.74369667470455, 56.94649167358875, 10.174448043107986, 7.354677300900221, 55.098164454102516, 68.74614670872688, 53.97576928138733, 56.60411864519119, 62.45029494166374, 62.142329066991806, 17.854128554463387, 1.3931612810119987, 0.9514815907459706, 7.168305376544595, 42.70272418856621, 67.64366626739502, 69.53890576958656, 67.68107905983925, 67.93412268161774, 65.79309716820717, 68.76713678240776, 64.14972335100174, 60.24640180170536, 62.780295833945274, 64.73508194088936, 63.02607424557209, 59.33002397418022, 55.569335371255875, 52.19861224293709, 51.392781883478165, 53.574970588088036, 59.69668909907341, 60.49500346183777, 59.27121452987194, 58.23790557682514, 56.28145515918732, 56.951723992824554, 54.68315452337265, 51.696472987532616, 53.728011175990105, 46.75576150417328, 49.65020678937435, 39.20153506100178, 31.69964510947466, 32.835649251937866, 37.314408123493195, 35.26079311966896, 27.42274470627308, 13.506649788469076, 2.8100309148430824, 2.326676663942635, 2.410577586852014, 1.4673409005627036, 0.4263501847162843, 0.15309973707189783, 0.026667021011235192, 0.03806268374319188, 0.034782205475494266, 0.05129611563461367, 0.17605991597520187, 0.02217279361502733, 0.045471258272300474, 0.02283513815200422, 0.08556678469176404, 0.12566550605697557, 0.23159818112617359, 0.4747413599397987, 0.022375262633431703, 0.021234770902083255, 0.051910131514887325, 0.050394862628309056, 0.049902792743523605, 0.010362142311350908, 0.015653872324037366, 0.02028627091931412, 0.07835175856598653, 0.040614157769596204, 0.10087752132676542, 1.5576837840490043, 1.1209893669001758, 0.3688301774673164, 11.520459316670895, 21.804356686770916, 27.77387246489525, 38.526159301400185, 36.85859218239784, 46.847530379891396, 52.02147714793682, 52.48775772750378, 48.14509995281696, 50.564240142703056, 48.368501365184784, 48.98848369717598, 49.4665664434433, 52.24455937743187, 51.615111753344536, 50.57183213531971, 54.88232083618641, 53.036037907004356, 51.95332780480385, 47.6738416403532, 44.30474862456322, 46.89541541039944, 51.95226766169071, 55.00018671154976, 58.96473057568073, 52.97400243580341, 53.39456006884575, 48.498340398073196, 54.199862256646156, 55.657342448830605, 60.392921939492226, 60.10953314602375, 62.979842126369476, 62.47855022549629, 60.38684606552124, 58.727311715483665, 18.772068098187447, 1.4290095074102283, 13.073720019310713, 50.06484054028988, 57.647025883197784, 53.46838630735874, 61.26989208161831, 58.86466674506664, 57.04380825161934, 53.11111427843571, 48.25778670608997, 4.069137051701546, 3.4450815757736564, 42.60877802968025, 13.188226874917746, 14.382746927440166, 17.326391972601414, 14.438610579818487, 24.938481710851192, 30.296306312084198, 21.932360418140888, 38.47152583301067, 24.478058516979218, 51.195097491145134, 25.918722711503506, 35.88811665773392, 68.19527506828308, 43.46772953867912, 1.1660816660150886, 0.1310419652145356, 0.1140038130688481, 0.11765707211452536, 0.06066090238164179, 0.03461117754341103, 0.06032783021510113, 0.21807633951539174, 0.1440836224355735, 0.2389982988825068, 0.1350612737587653, 0.17920303012942895, 0.12609225581400096, 0.12598759814864025, 0.18737585720373318, 0.24369929975364357, 0.11118722904939204, 0.4417565173935145, 0.9772021137177944, 61.69729694724083, 83.33729535341263, 51.12070508301258, 59.73542422056198, 129.4252046942711, 68.38337257504463, 42.50997953116894, 71.40373170375824, 47.21006512641907, 47.62815289199352, 19.261324144899845, 43.17061968147755, 57.88773536682129, 70.79498156905174, 13.507570289075375, 10.362034477293491, 58.3848512917757, 73.27762395143509, 56.99397012591362, 61.20785281062126, 66.49722218513489, 66.293575912714, 16.78875122219324, 1.2188496720045805, 1.3284444599412382, 12.33225915580988, 51.0119017213583, 72.67013534903526, 72.4257780611515, 68.69418069720268, 71.62956118583679, 70.36984518170357, 71.5663629770279, 67.52730131149292, 61.907402873039246, 68.0751483142376, 70.25874674320221, 65.68306267261505, 61.505775824189186, 58.59422765672207, 56.37423478066921, 53.505175933241844, 56.367022767663, 62.095876559615135, 66.32722690701485, 62.14154630899429, 61.66124828159809, 60.750121772289276, 62.27711923420429, 58.99536833167076, 54.671641141176224, 57.76961110532284, 49.497082605957985, 50.734243020415306, 46.58694416284561, 38.89054834842682, 32.024263590574265, 33.36754471063614, 37.3206701874733, 27.052027098834515, 10.552788991481066, 4.189007319509983, 5.933538358658552, 4.5979314018040895, 2.1826969273388386, 0.9381344506982714, 0.45273104100488126, 0.24905252968892455, 0.189212093828246, 0.05286066312692128, 0.14084204012760893, 0.1495598113979213, 0.20755929057486355, 0.11241483778576367, 0.14598199166357517, 0.3137775737559423, 0.3715201065642759, 0.4027699265861884, 1.277118120342493, 0.11906792453373782, 0.14214051654562354, 0.2954072813736275, 0.14041683403775096, 0.17479903675848618, 0.09784892055904493, 0.19617401791037992, 0.16934193583438173, 0.25993499730248004, 0.09655382091295905, 0.20957444416126236, 2.0353213604539633, 3.7814407143741846, 1.235591929871589, 16.889915093779564, 29.039238765835762, 35.41983358561993, 41.09639838337898, 37.5865913182497, 51.48595668375492, 55.2498447149992, 52.852579951286316, 51.031774654984474, 53.77373032271862, 53.13031084835529, 50.96249297261238, 53.67959797382355, 54.71948817372322, 54.48621869087219, 53.69994968175888, 56.91994249820709, 54.965384379029274, 56.47836819291115, 51.50058209896088, 47.42628872394562, 47.42158457636833, 55.09574018418789, 58.43856140971184, 62.77972586452961, 55.97501680254936, 58.08944754302502, 49.969154074788094, 56.256175115704536, 56.634289026260376, 62.271917313337326, 62.56100580096245, 64.10854876041412, 63.10723789036274, 65.97479581832886, 61.206956058740616, 25.26377845555544, 1.7225642991252244, 8.58752304688096, 48.74155394732952, 59.339390471577644, 58.27770084142685, 65.5110839009285, 62.730955481529236, 62.680053412914276, 59.234618693590164, 50.57395622134209, 6.955940946936607, 3.8202140713110566, 40.214321315288544, 28.273186571896076, 32.11972966790199, 19.641596339643, 15.255325455218554, 33.64115662872791, 35.06652474403381, 36.45913101732731, 46.08988143503666, 41.12405709922314, 59.27080795168877, 30.477455891668797, 49.97329965233803, 77.99464523792267, 59.17680859565735, 2.317445771768689, 0.22428495401982218, 0.21299170766724274, 0.25009198172483593, 0.11589462723350152, 0.1833637326490134, 0.12992123316507787], [0.03830492445558775, 0.033250238266191445, 0.07828397821867839, 0.04305338938138448, 0.03973112819949165, 0.027145253552589566, 0.05086313183710445, 0.04248460740200244, 0.07350811691139825, 0.03021431064553326, 0.18267586565343663, 0.1966015246580355, 32.3531511425972, 59.009674564003944, 35.57459928095341, 31.250321120023727, 91.66992902755737, 87.19346523284912, 31.71622931957245, 32.980011105537415, 24.43559769541025, 20.11525422334671, 12.064620517194271, 21.68409314006567, 46.999465227127075, 52.587931752204895, 15.341667272150517, 1.0391485271975398, 25.060557760298252, 41.05428904294968, 36.622442454099655, 46.676163375377655, 56.29471264779568, 64.0394988656044, 43.05261321365833, 10.732408203184605, 0.5182759207673371, 0.6094554718583822, 15.280524753034115, 53.41819480061531, 71.06426551938057, 69.59850177168846, 65.27171954512596, 68.79526287317276, 64.43131864070892, 57.662358060479164, 55.31291373074055, 60.65310537815094, 58.44199262559414, 55.23090273141861, 56.78491294384003, 52.13986359536648, 50.74485585093498, 51.14897936582565, 54.58581514656544, 56.4955622702837, 56.331635266542435, 54.90116022527218, 54.99161817133427, 54.7617457062006, 49.409007132053375, 51.7535725235939, 49.42068390548229, 50.241451263427734, 46.72665126621723, 49.36345137655735, 23.62312339246273, 31.663514748215675, 36.691720336675644, 24.701104648411274, 24.737010821700096, 24.58599742501974, 11.293846126645803, 0.8427797548938543, 2.7081593312323093, 1.9630201463587582, 1.4702494069933891, 0.10058928601210937, 0.07354360641329549, 0.04677966091549024, 0.025631554308347404, 0.05828869412653148, 0.05431490149931051, 0.07082830328727141, 0.05288594438752625, 0.06262225768296048, 0.009452694139326923, 0.038732802277081646, 0.16799921257188544, 0.08270565696875565, 0.4519683209946379, 0.09056349430466071, 0.019874343706760556, 0.030314708383230027, 0.02901336170907598, 0.0691785683738999, 0.15750465070595965, 0.12732506700558588, 0.05198296217713505, 0.05323217854311224, 0.03307703213067725, 0.4549120942829177, 1.2003882438875735, 1.3698099902831018, 3.0127398250624537, 3.0128504941239953, 18.482379242777824, 19.256015829741955, 29.245356805622578, 42.30793297290802, 45.44552341103554, 47.843795120716095, 47.530946508049965, 45.49691945314407, 46.262084394693375, 46.93522967398167, 45.52222229540348, 45.7644858956337, 50.86128540337086, 47.60516032576561, 49.132104590535164, 51.38100251555443, 51.5824107080698, 48.99468116462231, 41.860750168561935, 42.19497263431549, 48.883168548345566, 52.678150311112404, 53.035186752676964, 56.8829020857811, 52.746151462197304, 48.112816885113716, 48.08818660676479, 49.86360713839531, 55.90801499783993, 55.168076902627945, 60.61736449599266, 57.56249941885471, 63.841286301612854, 56.783214434981346, 39.017833918333054, 6.241465285420418, 7.150126677006483, 46.6047690063715, 57.23049983382225, 53.09694483876228, 52.83259302377701, 52.48928524553776, 50.31473033130169, 54.32202950119972, 52.5597258657217, 35.304308384656906, 0.8032465574797243, 4.98093375004828, 33.06841716170311, 18.202767446637154, 21.3559028506279, 6.798572866246104, 14.137171804904938, 21.68541356921196, 34.16538029909134, 30.928854569792747, 32.07073889672756, 37.3057521879673, 26.181613504886627, 20.85654504597187, 33.802055194973946, 60.100987404584885, 18.235318399965763, 0.9859270986635238, 0.16727490612538531, 0.1589351997245103, 0.06083961154217832, 0.06809875092585571, 0.06255580577999353, 0.0450196057499852, 0.04495868655794766, 0.07718424152699299, 0.05795292054244783, 0.08473475550999865, 0.02432306075206725, 0.05109586192702409, 0.03291754088422749, 0.05146175557456445, 0.07712283622822724, 0.048499732874915935, 0.1813783688703552, 0.21947399654891342, 43.324465826153755, 70.65201804041862, 42.55510590970516, 32.80159927904606, 104.11214858293533, 88.61513614654541, 40.711152255535126, 31.148885563015938, 28.52493066340685, 32.41258755326271, 16.438206732273102, 31.91340833902359, 48.84802043437958, 57.81476028263569, 19.62494183331728, 1.3396487524732947, 22.62647107243538, 45.40534436702728, 41.78421847522259, 48.76138508319855, 64.17810782790184, 69.31031003594398, 49.91143137216568, 18.76139637082815, 1.2422798085026443, 0.8224484708625823, 13.047841507941484, 51.783210933208466, 71.83595851063728, 71.59933760762215, 68.84312510490417, 70.45569017529488, 65.93443438410759, 57.521871998906136, 57.5526237487793, 64.70783740282059, 61.68531998991966, 58.30509357154369, 57.3202396184206, 55.60851126909256, 53.13358247280121, 55.205010920763016, 57.99758367240429, 57.61346988379955, 59.00988735258579, 56.11978903412819, 56.09639748930931, 56.48886322975159, 53.56200948357582, 54.00090493261814, 54.73028339445591, 53.08366075158119, 51.30956254899502, 47.06607945263386, 30.749416798353195, 39.52787294983864, 41.79905287921429, 26.315736807882786, 25.675459764897823, 26.475142054259777, 13.285325914621353, 3.7867471296340227, 3.033790932968259, 3.3821061300113797, 1.4079271699301898, 0.16478439210914075, 0.03813672039541416, 0.01462504227674799, 0.03393640574358869, 0.01789850168279372, 0.01893088105134666, 0.042120316793443635, 0.028214573321747594, 0.031129469643929042, 0.02956163814815227, 0.055937280849320814, 0.24848330242093652, 0.09762983856489882, 0.2367267629597336, 0.05342773445590865, 0.09784830457647331, 0.02495633907528827, 0.04310108721256256, 0.09400878872838803, 0.08858037923346274, 0.1592550505301915, 0.07028879161225632, 0.10750974630354904, 0.07088501821272075, 1.1587561341002584, 2.256003306247294, 1.7249997309409082, 3.146854341030121, 5.4602675791829824, 21.46181456744671, 22.070416510105133, 29.6107641980052, 40.60065418481827, 46.915067955851555, 48.36975149810314, 49.29255858063698, 49.077653512358665, 48.90558734536171, 48.82778272032738, 48.005411848425865, 47.159923017024994, 53.40090952813625, 50.134278014302254, 49.884243831038475, 54.97376672923565, 52.76925042271614, 53.25012981891632, 46.75417698919773, 43.71452249586582, 51.4300274848938, 55.239912047982216, 55.9702480584383, 57.68763430416584, 55.51971763372421, 50.29427222907543, 50.92819981276989, 53.0202991515398, 58.91287475824356, 58.82249280810356, 63.94806817173958, 60.49521625041962, 64.41300362348557, 57.07416482269764, 35.63652455806732, 6.8158752378076315, 13.582022543996572, 57.07119718194008, 60.751356706023216, 57.81412951648235, 57.98415519297123, 57.13848017156124, 53.033138662576675, 60.093441009521484, 57.186315804719925, 33.031274154782295, 0.7930993800982833, 11.848281025886536, 32.96759337186813, 13.491127621382475, 21.635657139122486, 16.748038306832314, 16.89870212227106, 30.975877046585083, 26.445999518036842, 33.512848913669586, 32.56318487226963, 28.720152787864208, 37.74700351059437, 17.482407800853252, 41.90861240029335, 71.53134405612946, 24.241456612944603, 0.9025577316060662, 0.19611712486948818, 0.15260067244526, 0.21177120128413662, 0.051003753978875466, 0.07424906973028556, 0.07957832829561085, 0.14593424188205972, 0.17789895791793242, 0.18700605985941365, 0.19635677919723094, 0.1038979584700428, 0.11923181300517172, 0.24508392467396334, 0.13983499025925994, 0.19234878098359331, 0.19815498817479238, 0.2910288772545755, 0.5111990973819047, 55.52934631705284, 80.32457381486893, 54.46219637989998, 39.151582941412926, 93.31602349877357, 104.27596539258957, 43.06386061012745, 47.548037990927696, 32.74368278682232, 30.648214928805828, 25.18514547497034, 33.53417716920376, 47.842191606760025, 65.70656061172485, 21.92629214376211, 3.9405450643971562, 30.491165556013584, 52.03636474907398, 46.863497123122215, 55.80140791833401, 66.57476842403412, 70.60141995549202, 53.47133494913578, 17.684973031282425, 0.9822095325216651, 0.9933913825079799, 19.76622585207224, 60.63479036092758, 75.00927463173866, 75.12997895479202, 70.15277042984962, 73.72030779719353, 70.39100244641304, 57.31318339705467, 58.650563433766365, 64.44929167628288, 64.30932998657227, 60.80068185925484, 62.09305331110954, 56.916876062750816, 57.43088588118553, 57.00153172016144, 61.715429574251175, 63.399518206715584, 62.55920849740505, 61.99055381119251, 59.31484378874302, 62.24516674876213, 56.77085369825363, 59.618873074650764, 57.305811792612076, 57.83356927335262, 56.79867200553417, 55.001083463430405, 36.85979291796684, 40.219656229019165, 43.135851547122, 31.073328517377377, 29.915315955877304, 33.570628613233566, 24.71042174845934, 12.838222905993462, 8.405076786875725, 8.134876135736704, 2.390606333501637, 0.2608008461538702, 0.20592692191712558, 0.1441293238895014, 0.119062707235571, 0.1889512882917188, 0.23209164995932952, 0.10123665400897153, 0.17903163854498416, 0.11273413940216415, 0.18340150796575472, 0.20399643253767863, 0.37179728387854993, 0.16505607753060758, 0.8413513877894729, 0.2054555097129196, 0.20037040289025754, 0.11244566660025157, 0.12841899268096313, 0.25045343732926995, 0.1961398939602077, 0.2513427083613351, 0.11092591143096797, 0.287484914297238, 0.23100444814190269, 1.5527320560067892, 3.378740935586393, 8.05836534127593, 9.179419185966253, 15.24747222661972, 30.123873464763165, 26.31273876875639, 34.915011674165726, 48.271028995513916, 52.14061975479126, 51.32339380681515, 53.44537474215031, 50.496957153081894, 52.126416116952896, 50.23349829018116, 49.11116771399975, 49.775166884064674, 54.87035907804966, 52.57946580648422, 51.878661811351776, 57.6054485142231, 57.06041716039181, 55.71584410965443, 48.006585985422134, 48.204699754714966, 55.577755719423294, 59.067385867238045, 57.342453226447105, 60.92955954372883, 56.99979141354561, 53.16133238375187, 53.30827049911022, 53.048402443528175, 59.553907960653305, 61.55659809708595, 68.1818237900734, 63.97069975733757, 66.99025332927704, 59.55286681652069, 46.176486387848854, 9.977077133953571, 9.438342042267323, 57.38261327147484, 65.62156677246094, 62.68040679395199, 63.5624610632658, 60.3347584605217, 59.601963981986046, 65.47366350889206, 63.15484933555126, 45.58180309832096, 1.1905169673264027, 9.535964503884315, 46.0269720107317, 27.39899978041649, 29.283343367278576, 11.896595433354378, 20.46296026557684, 30.837560668587685, 44.446382224559784, 48.1256639957428, 37.401712238788605, 50.78747056424618, 41.0848394036293, 29.62554730474949, 54.41437974572182, 80.4857611656189, 36.0491444170475, 1.2041492108255625, 0.33702291548252106, 0.26180713903158903, 0.23984888917766511, 0.12019474961562082, 0.2263020075042732, 0.29251608182676136], [0.027767548090196215, 0.036990703374613076, 0.1379897736478597, 0.01893478289275663, 0.09628710788092576, 0.08852559389197268, 0.10651907563442364, 0.04111935995751992, 0.1309457977185957, 0.07528718590037897, 0.18925720156403258, 0.2202986116753891, 18.744975551962852, 69.3604901432991, 40.357691422104836, 49.48900043964386, 25.800710543990135, 15.755076538771391, 36.64182521402836, 43.4303243458271, 64.4784589111805, 19.856322817504406, 22.800309844315052, 20.85311383008957, 42.65325464308262, 73.00409182906151, 40.649409368634224, 2.5116476509720087, 5.825916733592749, 31.343068443238735, 54.001448303461075, 78.62619414925575, 56.17728374898434, 27.694950699806213, 36.027949154376984, 47.75336377322674, 29.162006378173828, 10.494308229535818, 0.8705953310709447, 17.345556244254112, 50.056374594569206, 63.170158714056015, 61.06343396008015, 64.17423203587532, 56.805458441376686, 55.4281235486269, 57.95244589447975, 61.57478392124176, 61.46329790353775, 61.448999270796776, 56.633886247873306, 52.11403638124466, 48.00403252243996, 55.00312775373459, 54.94895026087761, 57.518398985266685, 55.90575411915779, 56.821425184607506, 52.20503009855747, 55.1792749017477, 54.36855800449848, 50.988118797540665, 53.234303668141365, 48.26188288629055, 46.484687849879265, 32.96596705913544, 28.823395147919655, 48.19714576005936, 29.167630076408386, 20.347630754113197, 25.141022242605686, 16.32401905953884, 3.4638102957978845, 2.7437194855883718, 1.517454155255109, 1.4668832626193762, 1.2492379476316273, 0.08565663651097566, 0.06400210317224264, 0.028712029343296308, 0.07003456892562099, 0.06743713369360194, 0.031145448083407246, 0.06580281318747438, 0.1283857147791423, 0.045059199328534305, 0.07664737931918353, 0.08357225538929924, 0.1081024699669797, 0.16690659307641909, 0.08847962526488118, 0.2768048451980576, 0.006531616190841305, 0.045146082557039335, 0.07973308092914522, 0.05185297501157038, 0.04765176978253294, 0.038054434771765955, 0.06567922333488241, 0.08626542025012895, 0.15907469380181283, 0.5167900223750621, 4.0215531550347805, 0.7652796478942037, 6.198187032714486, 1.44487080629915, 10.490402039140463, 14.465124607086182, 26.958421021699905, 21.38820681720972, 34.753626734018326, 41.83381341397762, 48.53395588696003, 44.59322914481163, 50.18089771270752, 42.71586388349533, 49.25118640065193, 47.82435916364193, 51.50054790079594, 47.5408373773098, 52.972178533673286, 51.84488162398338, 51.60122349858284, 46.57711409032345, 44.88795652985573, 40.832069367170334, 49.45862866938114, 50.19508995115757, 55.509146600961685, 58.16922426223755, 54.29711423814297, 51.23934231698513, 52.21000783145428, 54.18123945593834, 55.64697280526161, 54.9421676248312, 58.39837096631527, 56.764587834477425, 55.98020352423191, 44.496129155159, 15.70622731000185, 6.646029576659203, 46.996524184942245, 52.88696430623531, 51.199634447693825, 39.253626465797424, 43.75867232680321, 55.83032816648483, 47.56120428442955, 54.10477235913277, 44.68926899135113, 2.680731453001499, 0.1921264038537629, 24.18562050908804, 24.45844776928425, 23.68536975234747, 19.249102100729942, 8.265984300523996, 22.209810130298138, 27.191050238907337, 40.46060889959335, 25.205548480153084, 36.841933876276016, 34.49957616627216, 27.92135015130043, 31.31560731679201, 45.46035401523113, 53.34642805159092, 10.055566672235727, 0.19375832722289488, 0.11237339625949971, 0.13310023758094758, 0.02179296985559631, 0.05307013059791643, 0.05528148205485195, 0.039097052067518234, 0.04544092669675592, 0.031877932997304015, 0.05730938573833555, 0.038753664048272185, 0.04267404801794328, 0.07188506220700219, 0.14282078394899145, 0.058961855465895496, 0.11113068481790833, 0.11846550842165016, 0.2870800578966737, 0.1784489190322347, 26.3175056129694, 82.96309143304825, 46.72957330942154, 49.03314270079136, 35.87188012897968, 20.947952941060066, 43.973136618733406, 46.05258263647556, 48.52433480322361, 25.39590686559677, 33.86944837868214, 33.585497215390205, 49.82563957571983, 74.35768559575081, 52.7844800055027, 4.759462159126997, 3.5328711150214076, 30.58503571897745, 53.12766619026661, 75.54241642355919, 57.19750240445137, 32.50785604119301, 42.34216533601284, 54.08580757677555, 40.92251591384411, 17.332424148917198, 1.2877650302834809, 13.190957978367805, 48.24167177081108, 62.6606060564518, 62.46642887592316, 63.17029930651188, 58.352883607149124, 57.59504087269306, 58.69001291692257, 63.403781577944756, 63.0091917514801, 64.12521466612816, 60.283115431666374, 56.53877355158329, 51.48060277104378, 58.11272129416466, 58.81083123385906, 58.882556185126305, 58.081882148981094, 61.078412756323814, 54.27231676876545, 57.34380595386028, 55.14927551150322, 54.685757383704185, 55.527822598814964, 49.86783631145954, 48.15873362123966, 32.44112402200699, 35.513095781207085, 48.97498682141304, 27.99427203834057, 25.50864301621914, 22.284160740673542, 18.442416787147522, 14.13422791287303, 10.296306554228067, 2.515761167742312, 2.081042407080531, 1.6026441589929163, 0.1901884633116424, 0.14006657002028078, 0.11094053174019791, 0.07205434609204531, 0.07048111918265931, 0.021971983296680264, 0.11839949438581243, 0.03066512454097392, 0.11137140783830546, 0.14324708841741085, 0.10730005989898928, 0.11789668191340752, 0.08443518017884344, 0.17322221043286845, 0.11813928998890333, 0.055119886819738895, 0.029580312439065892, 0.039653410494793206, 0.095513500564266, 0.03970112687966321, 0.14296513167209923, 0.03995087812654674, 0.13819413143210113, 0.017235103296115994, 0.5222128657624125, 4.417726546525955, 4.059126488864422, 7.517034513875842, 12.89336459711194, 15.296664386987686, 17.746235243976116, 32.25337229669094, 28.7062968313694, 31.31323054432869, 40.18090210855007, 49.81803238391876, 46.12365022301674, 50.64074523746967, 46.173169165849686, 51.244361847639084, 50.617729872465134, 52.948099225759506, 50.40547326207161, 53.74628059566021, 55.19227400422096, 51.58327706158161, 49.97907534241676, 47.624622881412506, 43.60744424164295, 51.750323697924614, 53.02593044936657, 58.82842428982258, 59.14997063577175, 57.77864322066307, 54.273521304130554, 54.145255386829376, 57.5201240926981, 59.792839139699936, 60.01302972435951, 60.607576221227646, 60.883525013923645, 56.62772297859192, 42.59054660797119, 15.593897737562656, 12.922508083283901, 55.22176422178745, 53.00599291920662, 55.64848132431507, 45.66702872514725, 48.572136238217354, 60.45376807451248, 54.2088183760643, 59.41310651600361, 42.875253930687904, 1.2971837748773396, 2.447862373664975, 31.859223246574402, 24.84416887164116, 24.873698987066746, 27.19368539750576, 15.695367492735386, 22.95027069747448, 32.47141219675541, 23.16008973866701, 36.02438874542713, 27.995981946587563, 39.21483054757118, 32.128735184669495, 27.74219736456871, 58.0350648611784, 63.95675450563431, 12.93209781870246, 0.26014407514594495, 0.13424026546999812, 0.09618751166271977, 0.05091450329928193, 0.016019515496736858, 0.0305167784972582, 0.017577784419700038, 0.29850577760953456, 0.12287200283026323, 0.27264365286100656, 0.13594621064839885, 0.20456552621908486, 0.1716154013411142, 0.22945916309254244, 0.1506529503967613, 0.30852711643092334, 0.2660767443012446, 0.48913923266809434, 0.3337001125328243, 35.157936438918114, 94.68163222074509, 56.831544041633606, 61.275720968842506, 34.85722817480564, 15.886835418641567, 44.7731076925993, 60.98328486084938, 84.51082438230515, 25.741447024047375, 31.34876623749733, 28.540981002151966, 48.7723208963871, 78.48805636167526, 52.9921692609787, 4.624551348388195, 8.64127591252327, 39.58448991179466, 53.68388034403324, 78.79738256335258, 61.74686908721924, 42.70212382078171, 50.236298739910126, 62.915963754057884, 40.015462785959244, 14.022911936044693, 1.586267868988216, 19.789433106780052, 54.78777810931206, 67.10861697793007, 64.33752447366714, 67.95882895588875, 58.733554780483246, 57.533594369888306, 59.604202061891556, 67.06437215209007, 66.91923514008522, 68.18459764122963, 63.277803137898445, 60.43033093214035, 53.03543373942375, 64.20243412256241, 60.91113053262234, 63.67466524243355, 60.234341248869896, 64.35073256492615, 57.04198814928532, 61.194462329149246, 58.85042130947113, 57.24824108183384, 59.31197874248028, 56.22823901474476, 52.77562268078327, 45.77055796980858, 36.43006257712841, 56.2325593829155, 36.134377643465996, 32.09660790860653, 30.698856711387634, 33.95630791783333, 22.45530165731907, 22.01028473675251, 3.979487274773419, 4.453705865889788, 2.688697250559926, 0.4347938363207504, 0.14679456915473565, 0.19602932879934087, 0.20116907253395766, 0.2082323146169074, 0.17639777128351852, 0.23876799561548978, 0.129085945955012, 0.23928510927362368, 0.2190740086371079, 0.18216452590422705, 0.47960720665287226, 0.5298046802636236, 0.25095848366618156, 0.2903368987608701, 0.1792150826076977, 0.14793260808801278, 0.18120494380127639, 0.18116894963895902, 0.13857749523594975, 0.17447485181037337, 0.12207482490339316, 0.33118013525381684, 0.21672465110896155, 1.2774725700728595, 8.717935848981142, 4.682264551520348, 14.745307322591543, 20.04422653466463, 23.96261427551508, 24.08566117286682, 33.593282997608185, 31.784139275550842, 42.70815409719944, 46.764075458049774, 51.94698214530945, 51.363557651638985, 52.67294839024544, 47.43503965437412, 55.06078965961933, 52.47576177120209, 56.50863736867905, 50.28317682445049, 57.543017864227295, 58.96006062626839, 54.97100807726383, 53.543173894286156, 51.569669991731644, 46.1031237244606, 54.04057860374451, 57.05010071396828, 60.18636882305145, 61.08046844601631, 59.21259507536888, 55.01952767372131, 55.88377609848976, 57.40302197635174, 61.18991777300835, 62.214772179722786, 63.69982369244099, 63.99535283446312, 61.12414710223675, 48.709107488393784, 22.131661623716354, 11.623288448899984, 55.30277207493782, 59.51130844652653, 57.03416436910629, 49.782473891973495, 52.83484250307083, 64.31230902671814, 55.835055112838745, 62.513565346598625, 56.99807770550251, 5.844831643626094, 1.2526064668782055, 35.059973895549774, 37.690215557813644, 31.873212195932865, 25.61423934996128, 12.219766192138195, 30.25951288640499, 37.07591772079468, 52.1585775911808, 36.82859279215336, 45.10780893266201, 51.020379066467285, 39.909414276480675, 48.47598619759083, 65.97016006708145, 77.36383348703384, 19.405697397887707, 0.3497486107517034, 0.3328755567781627, 0.29563449730630964, 0.17122485354775563, 0.09748303433298133, 0.1413061941275373, 0.09216807695338503], [0.018757786237983964, 0.07592087611556053, 0.055767291923984885, 0.09677998299594037, 0.016369497498089913, 0.045262295461725444, 0.05744149173551705, 0.048298792680725455, 0.20406499214004725, 0.14070777076995, 0.12013701794785447, 0.8450931776314974, 8.968447856605053, 69.89285677671432, 50.598274916410446, 30.511274076998234, 49.968743696808815, 46.358546018600464, 39.65391218662262, 24.846249260008335, 50.45853741466999, 38.99613328278065, 15.057882349938154, 19.444538913667202, 19.64754492044449, 59.36191186308861, 58.794378116726875, 13.909589666873217, 1.6246209922246635, 26.454835943877697, 54.97644178569317, 51.10850013792515, 65.07660761475563, 42.83051133155823, 32.77521349489689, 53.60269770026207, 63.39662276208401, 59.595926105976105, 21.626687720417976, 2.5807402934879065, 17.8365620970726, 52.310645431280136, 58.10690000653267, 57.606611251831055, 57.23945215344429, 56.072029396891594, 56.535938903689384, 60.87432190775871, 60.04566617310047, 61.46982215344906, 60.90566262602806, 56.326053366065025, 55.27688406407833, 58.09915982186794, 57.665025517344475, 54.54769939184189, 53.379414081573486, 54.915854036808014, 54.95431177318096, 57.833527475595474, 52.68542692065239, 53.15699301660061, 48.657502457499504, 43.033853620290756, 33.66736002266407, 19.79855641722679, 31.86370700597763, 21.918458864092827, 17.20410693436861, 15.588749013841152, 10.270339697599411, 10.881493203341961, 10.595824532210827, 2.9676590440794826, 2.793435542844236, 1.47356235422194, 0.5932019627653062, 0.015978877345332876, 0.15548467315966263, 0.04906776157440618, 0.05148541153175756, 0.040690680616535246, 0.03018093997525284, 0.102087875129655, 0.1039376411063131, 0.04975946918420959, 0.09069820895092562, 0.025705609514261596, 0.14252868946641684, 0.23709593690000474, 0.07135722451494075, 0.04387292079627514, 0.04067709931405261, 0.034068678723997436, 0.04454364789125975, 0.015024279691715492, 0.05345347213733476, 0.16842104931129143, 0.028403418364177924, 0.08703258572495542, 0.12228060761117376, 0.021686132131435443, 0.6124869373161346, 5.582089517265558, 4.2098805494606495, 8.719938341528177, 14.407236613333225, 11.074061170220375, 10.124913901090622, 22.97465968877077, 14.64591320604086, 19.331363886594772, 40.621043890714645, 48.66397351026535, 44.99916896224022, 49.20859828591347, 44.8243897408247, 47.187011763453484, 50.40139988064766, 51.252276822924614, 48.7660626322031, 52.63174720108509, 52.3693560808897, 48.825293853878975, 39.41330149769783, 43.712698593735695, 53.02517428994179, 52.85868622362614, 52.73632898926735, 56.34503334760666, 55.13036772608757, 53.06122675538063, 48.87995012104511, 57.00932890176773, 56.32378488779068, 62.013572975993156, 56.0030896961689, 61.576786413788795, 46.02579787373543, 30.3310801461339, 8.450060673058033, 37.54409059882164, 50.51369525492191, 46.840481758117676, 47.92536534368992, 39.53993730247021, 43.94779197871685, 49.421535059809685, 54.282363429665565, 54.37770031392574, 6.34889074601233, 1.0873066680505872, 28.39143432676792, 37.36673891544342, 30.837606266140938, 34.35017578303814, 8.618832416832447, 16.646207571029663, 27.01056942343712, 32.873396426439285, 35.353777930140495, 22.432898059487343, 37.45246231555939, 28.57972752302885, 22.787415236234665, 24.59670715034008, 54.622464179992676, 40.840140134096146, 1.780066138599068, 0.055398266413249075, 0.05816694851091597, 0.016702265384083148, 0.07843525017960928, 0.004148728894506348, 0.07038723008008674, 0.03935507826099638, 0.019446825826889835, 0.04123875667573884, 0.08811618070467375, 0.025599779255571775, 0.04244054238370154, 0.0315358437364921, 0.14287781057646498, 0.06506737452582456, 0.13078058080282062, 0.09853377443505451, 0.2245479414705187, 0.6663514219690114, 13.2642930932343, 82.8612644970417, 57.532754614949226, 28.37438654154539, 53.02266262471676, 33.92244793474674, 39.209001660346985, 33.42774488031864, 36.780225187540054, 40.31411536037922, 22.9853181168437, 24.84383638948202, 32.643254175782204, 62.92826749384403, 65.2912200987339, 23.306357190012932, 2.015737211331725, 20.13615310192108, 57.03957907855511, 56.622198075056076, 65.54734915494919, 49.62869614362717, 42.23049692809582, 61.79460592567921, 64.53113928437233, 65.70485830307007, 31.236909739673138, 4.628612380474806, 14.858554545789957, 50.717109739780426, 59.49881091713905, 58.41728255152702, 55.79112567007542, 56.64295256137848, 60.34269243478775, 63.8342110812664, 62.65446558594704, 64.27494183182716, 62.042736411094666, 60.57336665689945, 58.64756539463997, 60.31770117580891, 59.55404095351696, 57.0869093388319, 55.425752475857735, 53.71623560786247, 55.83139970898628, 59.18929472565651, 55.34012407064438, 57.931011244654655, 49.96160767972469, 50.60988329350948, 35.16550563275814, 22.44625434279442, 31.792838908731937, 25.143497809767723, 23.91142912209034, 17.94771373271942, 15.749899316579103, 20.292189829051495, 15.397396981716156, 5.222590807825327, 2.022967985831201, 3.544353386387229, 0.27033640479203314, 0.04321859516494442, 0.04532060229394119, 0.003413754538996727, 0.08624809852335602, 0.05753153280238621, 0.017447485552111175, 0.08374838929739781, 0.04459807329112664, 0.036129307409282774, 0.0851627520751208, 0.045059418262098916, 0.16507403750438243, 0.08799214556347579, 0.053319870712584816, 0.029618495937029365, 0.007450771190633532, 0.04482358228415251, 0.0473277889250312, 0.026871777699852828, 0.017199906942551024, 0.0628122771740891, 0.043932210974162444, 0.019393432012293488, 0.05040855896368157, 0.0804090364545118, 1.101626674644649, 6.377621004357934, 8.558670245110989, 12.603119071573019, 22.756937071681023, 17.93535489588976, 17.07999039441347, 30.050024427473545, 23.927475661039352, 21.697244234383106, 39.694064632058144, 53.67384508252144, 46.39800310134888, 50.59431932866573, 47.85780496895313, 50.556401163339615, 52.27324403822422, 54.50438931584358, 50.383533239364624, 52.82210558652878, 53.898846209049225, 52.237936332821846, 41.60487189888954, 47.64350786805153, 52.19844505190849, 60.236757919192314, 53.67246575653553, 56.20499186217785, 56.88794441521168, 55.2985505014658, 53.490368127822876, 60.22728122770786, 58.175987899303436, 61.31343014538288, 57.75572285056114, 62.35590800642967, 44.84297454357147, 32.17085972428322, 14.129227381199598, 47.859659269452095, 51.01236529648304, 50.59917166829109, 52.239486649632454, 41.38643302023411, 47.21731133759022, 59.363272190093994, 63.30317437648773, 54.061226695775986, 3.2363549759611487, 4.395266901701689, 40.893694460392, 36.21839493513107, 36.580287516117096, 40.83086483180523, 20.027330741286278, 17.43629727512598, 33.597861751914024, 26.693645529448986, 29.18481655418873, 30.185462459921837, 23.698556944727898, 40.762191116809845, 17.683958485722542, 28.6604617908597, 62.170523554086685, 52.17618204653263, 2.5977797666564584, 0.05838672070240136, 0.028797830891562626, 0.09614241876988672, 0.04161704047874082, 0.035773870622506365, 0.05011965200537816, 0.015779311979713384, 0.1183734524238389, 0.12991982308449224, 0.35733692231588066, 0.1611053731176071, 0.1727919132099487, 0.187129924306646, 0.3719140979228541, 0.12329277829849161, 0.382363626267761, 0.2938388561597094, 0.4970152897294611, 0.9530345199164003, 19.106463454663754, 97.4219311773777, 68.43336269259453, 44.09757234156132, 66.45410969853401, 59.206861183047295, 49.182337895035744, 38.998762741684914, 62.8870815038681, 54.10343863070011, 21.779770106077194, 24.32592038065195, 26.938266903162003, 66.24978706240654, 72.04609483480453, 23.473550118505955, 3.8390392111614347, 30.688848048448563, 62.095386385917664, 61.19138449430466, 68.12022909522057, 54.5707793533802, 49.906145855784416, 70.17157942056656, 74.07802820205688, 68.65573436021805, 28.112194910645485, 4.75678900256753, 21.117150261998177, 59.72973972558975, 61.81141622364521, 56.51727810502052, 58.18476542830467, 58.11793081462383, 59.40248988568783, 66.38220995664597, 64.92474496364594, 67.42792904376984, 66.4235745370388, 62.397078797221184, 58.72943200170994, 65.21649330854416, 63.46482530236244, 61.478831470012665, 57.08496004343033, 59.355110228061676, 57.288325130939484, 61.003697365522385, 57.85221487283707, 61.098555475473404, 56.0755518078804, 53.88234369456768, 46.50674946606159, 27.877304814755917, 40.34021236002445, 33.1511577218771, 29.604422338306904, 24.863354042172432, 24.153320342302322, 25.860262848436832, 25.007807090878487, 15.209176931530237, 3.108911239542067, 6.722578844055533, 1.2988977204076946, 0.10187470805249177, 0.2726089797215536, 0.16484303661854938, 0.13083949248539284, 0.4174136579968035, 0.10692324925912544, 0.18846486986149102, 0.19251653604442254, 0.193352313071955, 0.19217646913602948, 0.2561864984454587, 0.5944192630704492, 0.3612803091527894, 0.2526224678149447, 0.09914263238897547, 0.08620595937827602, 0.1959263632306829, 0.17186364973895252, 0.10920372063992545, 0.1697234294260852, 0.27512260421644896, 0.20260931400116533, 0.37555884453468025, 0.23050927236909047, 0.13186769356252626, 2.9666252620518208, 13.91465574502945, 9.281071331351995, 25.745590701699257, 29.00208815932274, 22.318070121109486, 18.841439075767994, 32.04306498169899, 24.280980192124844, 27.266869470477104, 45.9399376809597, 53.232966139912605, 51.01724423468113, 52.10390992462635, 49.62765499949455, 52.91131339967251, 55.41424289345741, 57.05793969333172, 53.89157719910145, 55.73210343718529, 59.2401397973299, 52.967519983649254, 45.2814482152462, 52.89019413292408, 57.695716470479965, 61.302311941981316, 55.63848786056042, 61.2559050321579, 59.16171580553055, 56.93090870976448, 53.71204823255539, 63.351215198636055, 60.585647597908974, 65.73539346456528, 60.70909917354584, 66.53296306729317, 51.63338877260685, 36.46244823932648, 14.23156064003706, 46.34934291243553, 60.21305099129677, 56.960395127534866, 57.18052491545677, 46.89764589071274, 51.57008036971092, 63.981080800294876, 62.243677228689194, 68.12250897288322, 11.743143517524004, 2.575512961484492, 35.81544555723667, 48.954855501651764, 44.096945375204086, 41.10486052930355, 11.91139753907919, 23.93423169851303, 38.08518536388874, 40.7035868614912, 49.36296880245209, 31.213841177523136, 46.959863752126694, 45.80462694168091, 29.561940617859364, 42.32496365904808, 72.6765950024128, 65.85694134235382, 4.823285434395075, 0.17513328522909433, 0.08533828484360129, 0.332691801013425, 0.21733005065470934, 0.11849247064674273, 0.24251219001598656, 0.17337976838462055], [0.023146444982558023, 0.022552366899617482, 0.015723526594229043, 0.03220186561520677, 0.044703280145768076, 0.014254239322326612, 0.011606338048295584, 0.06664584841928445, 0.03330778439703863, 0.04618192033376545, 0.04784026044944767, 0.262467383290641, 1.0386400669813156, 44.464716240763664, 65.66442087292671, 42.3946975171566, 41.93193554878235, 68.68797183036804, 43.51946376264095, 37.834030240774155, 36.11091010272503, 43.800945058465004, 16.157884374260902, 28.958289809525013, 20.677513852715492, 37.80115820467472, 86.84462875127792, 43.91948349773884, 4.11200350150466, 1.5765052428469062, 36.510356068611145, 63.2986032217741, 67.31167048215866, 73.07473763823509, 54.25239823758602, 41.745122373104095, 49.56531934440136, 54.96058903634548, 63.02839212119579, 26.89593907445669, 3.3068155450746417, 18.927166275680065, 50.63257947564125, 52.31514818966389, 56.97317384183407, 53.67922179400921, 61.53392091393471, 64.87264215946198, 66.49446353316307, 64.42214593291283, 62.6833326369524, 61.20501436293125, 59.750365018844604, 57.57832556962967, 56.302034854888916, 57.916116043925285, 59.56987090408802, 54.1940675675869, 52.17848852276802, 52.118276953697205, 54.77628372609615, 44.99728046357632, 40.08854426443577, 36.58067509531975, 13.569965790957212, 15.521699711680412, 20.637443102896214, 20.146268159151077, 14.126135297119617, 4.578454596921802, 10.279125776141882, 16.131261102855206, 9.244158212095499, 2.7133671892806888, 2.8856292832642794, 2.1660946682095528, 0.10412438030471094, 0.0755898559873458, 0.06451655252021737, 0.06853160113678314, 0.010223915451206267, 0.08750027976930141, 0.020295375215937383, 0.03321987700473983, 0.023246902092068922, 0.09195814564009197, 0.026051288914459292, 0.09106149766012095, 0.07428877463098615, 0.03616175781644415, 0.09109060469199903, 0.02422617151751183, 0.06992794456891716, 0.0632848619716242, 0.04566476585750934, 0.08745051134610549, 0.09123134557739832, 0.019323551387060434, 0.018732582902885042, 0.0679328067053575, 0.02649993017257657, 0.1563956742757, 0.25192036642692983, 0.844088428420946, 8.96314524114132, 5.835271356627345, 9.942077212035656, 19.63474340736866, 24.681881479918957, 11.089777126908302, 13.156220242381096, 14.177391696721315, 21.805832907557487, 44.14142958819866, 50.415329933166504, 45.47809146344662, 49.664281234145164, 51.0161042958498, 50.39291113615036, 48.72947059571743, 53.73243413865566, 48.30382123589516, 50.07236033678055, 46.27832852303982, 45.49359083175659, 45.34906938672066, 52.7970877289772, 53.43605764210224, 56.39334015548229, 53.83131243288517, 54.64857637882233, 53.7309218198061, 55.04753977060318, 53.234501257538795, 55.084838569164276, 54.625173434615135, 55.865677669644356, 39.70840886235237, 24.869118332862854, 29.067425653338432, 28.553491830825806, 47.123152390122414, 49.19072404503822, 51.22703477740288, 47.88762576878071, 44.8298804461956, 62.370256036520004, 39.00840662419796, 29.805501848459244, 8.177961073815823, 0.09991097787860781, 38.463132083415985, 54.602192267775536, 49.10284996032715, 45.91230556368828, 14.60753621533513, 9.883415959775448, 31.789400093257427, 22.283809259533882, 40.68278297781944, 22.56600111722946, 29.416530020534992, 37.44968846440315, 26.389773935079575, 25.2587703242898, 36.35850481688976, 55.015009716153145, 32.8434806317091, 0.5989561602473259, 0.018076759988616686, 0.11602940125158057, 0.07610774890054017, 0.060662653850158677, 0.07971327300765552, 0.081636563554639, 0.01962572794582229, 0.04349341987108346, 0.01684906404989306, 0.02036054320342373, 0.07372254563961178, 0.05849980174389202, 0.028203841866343282, 0.018174441465816926, 0.049024071340681985, 0.07476011262042448, 0.1485936835524626, 0.03426265757298097, 0.3009534697048366, 1.3263938762247562, 51.97453826665878, 76.57165199518204, 38.77145893871784, 50.6899031996727, 59.42276939749718, 27.12295789271593, 49.710406959056854, 28.295170292258263, 37.7577493339777, 20.49226239323616, 27.663207203149796, 29.204887077212334, 49.544279873371124, 80.27959942817688, 53.32723148167133, 7.710181949660182, 1.4592721522785723, 31.576324626803398, 71.37335613369942, 71.12456068396568, 71.17639750242233, 62.75496259331703, 49.70302015542984, 60.129140093922615, 63.2094220072031, 66.8421220779419, 36.33141607046127, 4.3705615773797035, 18.642895929515362, 49.382716342806816, 51.24249614775181, 57.55953177809715, 54.57104913890362, 60.6361772865057, 63.63163635134697, 68.5848681628704, 66.84413596987724, 65.09022608399391, 65.01111432909966, 63.6434119194746, 61.706074476242065, 57.4944868683815, 61.36989891529083, 63.60102139413357, 56.473470255732536, 52.01433353126049, 54.89501595497131, 55.74940770864487, 47.27821446955204, 47.656427174806595, 37.31406234204769, 13.774717804044485, 20.339677780866623, 30.978827588260174, 27.60724950581789, 16.334088519215584, 13.314866479486227, 23.350066244602203, 22.733889408409595, 11.835596356540918, 6.953927055001259, 6.9734095595777035, 1.204462694004178, 0.09151336169452406, 0.08814261600491591, 0.060077548332628794, 0.042047504684887826, 0.12132378629758023, 0.10190680593950674, 0.09571397691615857, 0.1596323584089987, 0.04674597854318563, 0.09663854449172504, 0.04967759545252193, 0.03585735110391397, 0.5098968953825533, 0.06910879164934158, 0.043922618715441786, 0.029308704943105113, 0.05383109542890452, 0.023226433659147006, 0.041109786252491176, 0.02118384843925014, 0.07989968566107564, 0.026772546989377588, 0.009900504192046355, 0.09626010112697259, 0.13244429777842015, 0.08530136299668811, 0.04881264831055887, 1.066713435575366, 13.91351580619812, 13.394951932132244, 14.150833021849394, 20.59099819511175, 26.527037769556046, 15.232811663299799, 16.240301951766014, 26.19612492620945, 26.05089481920004, 38.882287591695786, 53.851192966103554, 49.07834507524967, 52.48304218053818, 53.44739243388176, 50.961888805031776, 49.15671966969967, 56.236837953329086, 51.577801555395126, 51.06517866253853, 48.407263085246086, 49.19755607843399, 47.786874175071716, 52.58389636874199, 56.31382182240486, 59.30732399225235, 56.76831543445587, 57.934225872159004, 56.32508061826229, 59.178161323070526, 54.36180576682091, 61.32277764379978, 58.48256304860115, 56.628140956163406, 34.46641534566879, 21.993206553161144, 33.441108763217926, 38.221989423036575, 51.0469738394022, 56.15322344005108, 58.87297309935093, 54.54320803284645, 48.54057513177395, 60.27974121272564, 42.55781516432762, 26.119243651628494, 3.0305976793169975, 0.8870484482031316, 52.30951689183712, 55.52415959537029, 52.004545256495476, 50.926033928990364, 28.594710119068623, 16.115404553711414, 30.250288881361485, 27.854834720492363, 25.646984092891216, 30.44039838016033, 27.28554166853428, 30.593005791306496, 31.144443601369858, 18.360747769474983, 44.15336474776268, 63.768740594387054, 40.290761813521385, 0.6145644164644182, 0.16024967684643343, 0.2249347636825405, 0.14512212452245876, 0.0754235332715325, 0.04660420978325419, 0.03084571690123994, 0.011197341391380178, 0.10056753366370685, 0.2052831236505881, 0.11902044934686273, 0.13644272228702903, 0.12660974054597318, 0.18300445895874873, 0.2311720250872895, 0.184114400180988, 0.19599309714976698, 0.3703080606646836, 0.17299493512837216, 0.4924207128351554, 2.1488640177994967, 67.19281286001205, 87.38221630454063, 55.47690533101559, 54.25282761454582, 86.13710671663284, 55.85051268339157, 53.926037549972534, 55.28232917189598, 53.340754956007004, 25.99521640688181, 38.832620456814766, 25.67163147032261, 45.64601965248585, 92.6855993270874, 55.07660061120987, 7.030876250937581, 3.311201222240925, 46.58020332455635, 73.59576568007469, 77.94970124959946, 80.12159630656242, 68.1120291352272, 56.392192617058754, 63.24395075440407, 65.11057019233704, 71.00396275520325, 34.32499833405018, 4.451467311009765, 25.834048055112362, 58.77922832965851, 55.191187262535095, 57.1474514901638, 58.40264193713665, 63.326809108257294, 66.69044181704521, 71.05817064642906, 67.98681825399399, 67.3384590446949, 67.73259669542313, 66.70332312583923, 63.54836381971836, 60.85856415331364, 64.80158597230911, 68.15244376659393, 60.41729763150215, 55.57391032576561, 54.60565768182278, 59.829187989234924, 50.528541058301926, 51.19280241429806, 44.371058866381645, 19.039387553930283, 23.19292187690735, 33.49323816597462, 30.95990840345621, 22.557808756828308, 16.230321787297726, 25.651057474315166, 29.177389852702618, 22.077810913324356, 9.63765749707818, 9.781457930803299, 3.8726842682808638, 0.17811228084610775, 0.15875445707933977, 0.25915265490766615, 0.1338291453430429, 0.18308912316570058, 0.18143757741199806, 0.16238204523688182, 0.218964527011849, 0.15211225021630526, 0.205266855773516, 0.10043456306448206, 0.17779009969672188, 0.5746531393378973, 0.3771556494757533, 0.13629684573970735, 0.1275512736174278, 0.1837871575844474, 0.25159714627079666, 0.1482274930458516, 0.16199035453610122, 0.29013455961830914, 0.12006819859379902, 0.1547964647761546, 0.261748984339647, 0.25885163981001824, 0.3275403461884707, 0.31808511761482805, 3.482800251804292, 18.442960157990456, 17.39594154059887, 24.75768931210041, 30.937738493084908, 36.812158674001694, 17.926921248435974, 20.966921523213387, 24.11696769297123, 29.30902238935232, 47.61596314609051, 53.14881585538387, 53.05884808301926, 54.70575951039791, 57.14917279779911, 53.26705411076546, 51.95912629365921, 57.04021364450455, 52.889700159430504, 54.80351306498051, 52.99592345952988, 51.808601170778275, 49.74082812666893, 55.84569454193115, 58.74964691698551, 62.51625560224056, 57.10056960582733, 58.71451400220394, 59.16464164853096, 59.84710782766342, 58.27831640839577, 60.74990898370743, 59.69030164182186, 57.87800028920174, 42.3103154450655, 30.50013307482004, 36.39008492231369, 38.32855850458145, 58.975366204977036, 57.59430751204491, 59.87021818757057, 56.981138214468956, 55.20477153360844, 68.124028891325, 46.88288368284702, 40.196443274617195, 10.88773911818862, 0.6230970367323607, 47.04997591674328, 67.13887855410576, 58.997241631150246, 55.96022039651871, 20.206059850752354, 13.643255308270454, 44.30201657116413, 28.887064531445503, 53.34626846015453, 31.981063708662987, 37.673606649041176, 53.87879468500614, 39.29739631712437, 38.94692212343216, 54.8591610789299, 75.4422689974308, 53.74753072857857, 0.9091414127033204, 0.2764608449069783, 0.33635824802331626, 0.2308251304202713, 0.2919753530295566, 0.24603157304227352, 0.22746366157662123, 0.1561861511436291], [0.0217242748112767, 0.021317705904948525, 0.02672905713552609, 0.07464504262316041, 0.007739994489384117, 0.015069835499161854, 0.018172213167417794, 0.014137956841295818, 0.05995469691697508, 0.06813262254581787, 0.03685099036374595, 0.27464044571388513, 0.2673301723552868, 20.86732506752014, 66.74388214945793, 42.802271246910095, 26.27627022564411, 46.35184317827225, 46.92897140979767, 35.584626942873, 31.45936880260706, 39.18961130082607, 28.25415339320898, 37.69991263747215, 28.904173113405704, 18.30680776387453, 71.75329774618149, 61.988300532102585, 36.06694646179676, 1.1754444823600352, 1.4062514598481357, 28.03214840590954, 62.90597029030323, 54.415656477212906, 62.45210364460945, 56.065470948815346, 48.991755321621895, 55.26449292898178, 57.04590953886509, 54.48359303176403, 20.260222144424915, 7.602159921079874, 30.09095013141632, 37.92083278298378, 54.38030697405338, 54.64504636824131, 54.790023788809776, 60.243662148714066, 59.69557195901871, 57.94226624071598, 60.45439124107361, 60.004157200455666, 62.00397089123726, 57.58819364011288, 59.674346297979355, 57.283875569701195, 50.36381609737873, 45.78754685819149, 49.91039402782917, 47.43054449558258, 40.127343982458115, 43.6236085742712, 41.29064776003361, 10.140367671847343, 15.089831035584211, 31.310688480734825, 19.85595803707838, 14.616061057895422, 9.639094769954681, 18.078962489962578, 23.959118463099003, 16.058008633553982, 7.35193052329123, 6.862712949514389, 5.072978585958481, 0.09615357324946672, 0.0657735280401539, 0.04482695905608125, 0.07958182381116785, 0.06367848967784084, 0.050423045686329715, 0.03482153930235654, 0.07336480819503777, 0.06879757202113979, 0.023556926862511318, 0.03509479807689786, 0.012686152713285992, 0.05270419242151547, 0.33450145390816033, 0.06385746601154096, 0.05776316080300603, 0.02320874456927413, 0.05014900765672792, 0.020026777128805406, 0.05178398125281092, 0.11131871535326354, 0.0225742732436629, 0.05994062579702586, 0.08713355491636321, 0.03363138675922528, 0.01746108911902411, 0.07357985290582292, 0.06246229517273605, 0.2754556207219139, 4.852499216794968, 8.845107425004244, 8.927444256842136, 11.391068659722805, 23.816259428858757, 24.66637071222067, 10.13640258461237, 9.758824445307255, 19.63425323367119, 24.65078204870224, 38.65921676158905, 51.99407681822777, 53.09947170317173, 48.51401075720787, 51.78170621395111, 49.62491154670715, 48.73862810432911, 51.18196539580822, 54.055884182453156, 46.32439345121384, 44.127849116921425, 47.26520776748657, 53.56763318181038, 55.51184445619583, 54.11155119538307, 56.037884429097176, 56.712431833148, 52.88268193602562, 52.93019458651543, 51.78200639784336, 58.7593249976635, 50.8621783554554, 39.19488161802292, 10.63499853014946, 10.147397294640541, 39.722680896520615, 45.3215816617012, 46.71919986605644, 50.07628932595253, 47.85095393657684, 48.92172887921333, 55.11309005320072, 44.47307579219341, 26.766687110066414, 10.041605271399021, 0.0980890127539169, 19.351766891777515, 59.27901551127434, 45.50732709467411, 55.73538266122341, 30.86430173367262, 6.868016039952636, 24.788898937404156, 20.770977437496185, 32.24891893565655, 37.96022146940231, 25.607861392199993, 37.552765533328056, 32.85396046936512, 36.665532141923904, 31.549239680171013, 45.21364465355873, 45.791616439819336, 13.48132224753499, 0.11349426189553924, 0.06030997414200101, 0.1082967864931561, 0.04374593190732412, 0.04588170675560832, 0.10533663400565274, 0.053212088605505414, 0.06794727116357535, 0.05158755331649445, 0.027101184823550284, 0.019026644076802768, 0.10981599247315899, 0.018567371553217527, 0.09466748189879581, 0.03947451579733752, 0.019534087550709955, 0.07790181669406593, 0.008050172327784821, 0.026320052129449323, 0.3125451336381957, 0.273543877992779, 27.92216520756483, 76.38831183314323, 48.0889617651701, 27.944886088371277, 53.330491706728935, 19.69850968569517, 38.94364669919014, 31.584982462227345, 25.034451261162758, 31.623544692993164, 31.866537854075432, 30.734094120562077, 31.209131330251694, 70.24149566888809, 58.55539374053478, 49.723124876618385, 3.3491096505895257, 1.4464020053856075, 23.902345709502697, 65.94103842973709, 61.751995012164116, 67.09027156233788, 64.68658894300461, 56.060592010617256, 62.745231315493584, 60.43673358857632, 61.460155472159386, 28.37475512176752, 9.439684320241213, 32.44898959994316, 41.822068244218826, 53.78822274506092, 55.22939421236515, 57.21865586936474, 59.92694914340973, 60.979447066783905, 58.03364373743534, 63.379109501838684, 61.546061262488365, 64.81082707643509, 60.66330403089523, 61.722839176654816, 60.21313838660717, 51.58230431377888, 45.15791304409504, 50.11106126010418, 46.1315044015646, 44.25398334860802, 50.32763443887234, 36.91707864403725, 11.124293524771929, 21.240693032741547, 43.50064717233181, 31.15570619702339, 17.072784081101418, 18.845687247812748, 25.147331804037094, 29.79548178613186, 19.30251393467188, 13.568834401667118, 13.714608829468489, 1.9598690466955304, 0.09573187751811929, 0.032785872754175216, 0.14463146100752056, 0.059273891456541605, 0.040079893078655005, 0.04867565156018827, 0.04105527179490309, 0.036884528017253615, 0.045014696443104185, 0.04311528449761681, 0.045206857030279934, 0.017430200932722073, 0.23854970029788092, 0.8476893289480358, 0.030252343858592212, 0.012198549629829358, 0.026834675882128067, 0.13217031169915572, 0.03661188151454553, 0.04751136657432653, 0.03492169955279678, 0.08261989438324235, 0.019854652673529927, 0.07723555361735635, 0.05321324635588098, 0.04858772190345917, 0.12540891591925174, 0.03348988146171905, 0.18185107241151854, 5.8564708940684795, 16.823270469903946, 9.972270391881466, 14.715198688209057, 23.446126990020275, 26.24044954776764, 13.104658909142017, 13.120062332600355, 35.28776407241821, 28.183199800550938, 35.540636703372, 50.61670772731304, 54.13495793938637, 48.20428557693958, 50.830438658595085, 50.57685926556587, 53.12656044960022, 53.30401852726936, 56.58240281045437, 49.4975233823061, 46.60487160086632, 48.31058107316494, 55.5961999297142, 56.893450319767, 56.06907695531845, 58.92762556672096, 58.787876665592194, 55.83230026066303, 56.58291578292847, 54.418339133262634, 58.74477177858353, 48.37882921099663, 35.08575551211834, 9.898858331143856, 13.715547379106283, 44.94132086634636, 49.177793338894844, 49.694330021739006, 53.73319789767265, 49.910253435373306, 54.41654562950134, 54.66790594160557, 52.95835107564926, 27.04057451337576, 4.212487684562802, 0.4155456129228696, 27.366821207106113, 65.98256260156631, 55.58641165494919, 63.149810805916786, 41.84145860373974, 15.100771598517895, 20.13393972069025, 24.653785787522793, 27.702343203127384, 26.097685508430004, 33.833825290203094, 25.240956880152225, 35.716764852404594, 34.0637319535017, 28.768968768417835, 51.96756184101105, 56.469541266560555, 16.24864060431719, 0.06626429545576684, 0.1564689539372921, 0.08379861785215326, 0.10445010891999118, 0.09428731675143354, 0.043570391717366874, 0.030365207821887452, 0.023228392929013353, 0.13986411213409156, 0.27035011968109757, 0.1197380170924589, 0.19253339763963595, 0.10876612810534425, 0.22594043315621093, 0.17160073650302365, 0.07462183566531166, 0.13284761051181704, 0.13826380425598472, 0.18761298822937533, 0.3587003069696948, 0.2898578275926411, 36.899094209074974, 92.25698992609978, 61.384273543953896, 35.800253972411156, 59.027108028531075, 60.78945726156235, 46.22901476919651, 50.80613516271114, 49.90558348596096, 38.85251998901367, 48.72519202530384, 35.179865062236786, 24.38146010041237, 74.52945157885551, 75.7800404727459, 47.430677488446236, 3.057712074369192, 2.8484157426282763, 35.61571307480335, 72.3453363776207, 65.29859930276871, 71.54036477208138, 70.13857439160347, 65.98200023174286, 64.31730955839157, 64.13659125566483, 65.63155263662338, 25.134727880358696, 10.332231726497412, 37.08702452480793, 44.84894022345543, 58.96209731698036, 55.34942217171192, 59.51173782348633, 59.990238547325134, 62.11710222065449, 61.88194423913956, 65.36989867687225, 64.70580071210861, 67.5362080335617, 65.05022183060646, 65.60503765940666, 64.4788920879364, 52.948038429021835, 47.30397708714008, 50.0941027700901, 53.570372834801674, 45.128426626324654, 53.46775934100151, 44.591929614543915, 15.828823931515217, 24.078614450991154, 44.56895224750042, 32.08696402609348, 23.738076724112034, 19.34858076274395, 32.03845962882042, 35.92532806098461, 25.260636024177074, 17.94853448867798, 19.816221669316292, 12.150181476026773, 0.18679865926969796, 0.19349862006492913, 0.17939218872925267, 0.2912513731280342, 0.21129158092662692, 0.16268185805529356, 0.15044274448882788, 0.12813675391953439, 0.25248671416193247, 0.1683608314488083, 0.16682733170455322, 0.1407125502009876, 0.24041051685344428, 1.3280229200609028, 0.18963737413287163, 0.15012414049124345, 0.15735507826320827, 0.2581923158140853, 0.09304374441853724, 0.15112131979549304, 0.12520647287601605, 0.1937850148533471, 0.17393752204952762, 0.18048232945147902, 0.13305803906405345, 0.18624954420374706, 0.19536694715498015, 0.2030790044227615, 0.7080516312271357, 14.260552134364843, 22.73503504693508, 14.150701928883791, 18.334120698273182, 36.07566699385643, 40.42714409530163, 15.627368241548538, 16.712128333747387, 29.55113209784031, 30.912036672234535, 42.470617443323135, 54.0525783598423, 54.59768570959568, 52.240345403552055, 54.36307869851589, 53.4565195441246, 54.64987590909004, 57.41975627839565, 59.03652772307396, 51.49291791021824, 49.96348097920418, 52.97223553061485, 59.51808728277683, 60.62952384352684, 58.12431827187538, 62.582493647933006, 61.56121484935284, 58.21792624890804, 60.62550365924835, 57.57734142243862, 61.921602711081505, 55.64836733043194, 44.242979139089584, 15.810216329991817, 14.439801815897226, 44.01896595954895, 54.151874631643295, 55.38685776293278, 59.14585925638676, 57.043926045298576, 58.60748514533043, 63.15799176692963, 53.58933761715889, 34.18937601149082, 12.860148679465055, 0.33283423399552703, 23.85305665433407, 72.01705679297447, 57.325791120529175, 64.66302260756493, 38.16213883459568, 8.423019424080849, 35.45824572443962, 30.26338867843151, 42.83448211848736, 51.09287917613983, 34.99682128429413, 47.99956016242504, 49.48610499501228, 50.590299144387245, 44.92022059857845, 63.53530392050743, 74.00579407811165, 23.167056664824486, 0.14988533221185207, 0.2582652837736532, 0.20616175228497013, 0.23881049099145457, 0.13499415392288938, 0.17459215567214414, 0.12121917316108011, 0.1047455430671107], [0.08998076737043448, 0.03369986101461109, 0.02687738091481151, 0.03062583153223386, 0.015953399415593594, 0.05922534015553538, 0.07251058879774064, 0.04871472192462534, 0.07480607382603921, 0.13472751510562375, 0.14566831552656367, 0.15244121459545568, 0.236018234572839, 5.153433568775654, 65.87645709514618, 53.19457679986954, 46.81004539132118, 38.16633760929108, 45.64024776220322, 44.322299882769585, 33.669601902365685, 33.319006115198135, 24.169933050870895, 25.764306597411633, 47.11630895733833, 10.428204126656055, 40.510561019182205, 40.70800602436066, 38.113144263625145, 31.500740982592106, 0.621301158098504, 1.553032596129924, 29.091191478073597, 70.03903493285179, 56.574674025177956, 63.32884959876537, 53.050340339541435, 38.19144666194916, 55.91458484530449, 61.899358704686165, 44.02807407081127, 18.11979129910469, 22.104434184730053, 44.39260371029377, 37.44648523628712, 43.98801662027836, 54.763303622603416, 55.46769842505455, 68.06517004966736, 70.51877439022064, 65.92573285102844, 64.78954061865807, 56.072021797299385, 59.948391392827034, 54.54188950359821, 54.748579412698746, 48.840694427490234, 50.87982460856438, 42.01737396419048, 40.29448181390762, 43.969956189394, 31.019498705863953, 8.297559656202793, 13.370815627276897, 34.190082773566246, 17.644773088395596, 6.200491609051824, 11.384652704000473, 11.075773928314447, 27.432981356978416, 20.251777097582817, 18.33361342549324, 11.168806236237288, 9.597234316170216, 0.08267312121461146, 0.01599043629539665, 0.011873898056364851, 0.058279573131585494, 0.03877191345964093, 0.03977180160291027, 0.04826946671528276, 0.019235154177295044, 0.04912846183287911, 0.04345968925917987, 0.05323910649167374, 0.04167349936324172, 0.011391435273253592, 0.12050960576743819, 0.10431831091409549, 0.048826815909706056, 0.06474526759120636, 0.033594223714317195, 0.05480690459080506, 0.06073382210161071, 0.0574210084596416, 0.05874831731489394, 0.05540024423680734, 0.0288569949043449, 0.03635694636614062, 0.024557141550758388, 0.09702111419755965, 0.11217519087949768, 0.07540781458374113, 0.2554384432733059, 0.9509957511909306, 12.605732381343842, 7.235210761427879, 10.808931346982718, 13.764628395438194, 20.376598499715328, 9.931860510259867, 7.337834229692817, 9.666605293750763, 26.841444298624992, 22.876805439591408, 27.929415218532085, 46.65844112634659, 50.22124394774437, 42.4787338078022, 45.68676106631756, 53.92280392348766, 50.935947597026825, 47.58924677968025, 48.11073079705238, 47.32135735452175, 50.11882044374943, 53.21059674024582, 52.37351305782795, 56.58524125814438, 52.376374304294586, 54.88355576992035, 55.78406184911728, 50.159360468387604, 49.506772086024284, 47.42411524057388, 29.562882967293262, 8.539243787527084, 3.4614040749147534, 28.86498771607876, 49.96636122465134, 52.99738258123398, 49.15356583893299, 41.162036061286926, 41.01553492248058, 41.80194452404976, 50.979063883423805, 49.553919956088066, 16.599741764366627, 0.5952894757501781, 4.472340065985918, 42.07502447068691, 34.69573684036732, 64.34396132826805, 53.42417187988758, 10.64254492521286, 20.504607930779457, 41.01551212370396, 25.792964659631252, 37.77389846742153, 29.192944318056107, 35.3378339856863, 35.37599913775921, 30.890377834439278, 21.017426513135433, 26.674255169928074, 57.42123059928417, 36.64542742073536, 2.5160836754366755, 0.035290799278300256, 0.13082818215480074, 0.050515149923739955, 0.030877755416440777, 0.04659567137423437, 0.01859679956396576, 0.01785908250894863, 0.0490587927197339, 0.05649912003718782, 0.019874742611136753, 0.019496058048389386, 0.025913167810358573, 0.016802961836219765, 0.024169898169930093, 0.060596873590839095, 0.013222299676272087, 0.06012838915921748, 0.09239611666998826, 0.1323041060823016, 0.2354194995132275, 0.1263968480634503, 6.431853594258428, 74.20335307717323, 62.5640494376421, 35.40726765990257, 50.37544347345829, 37.452572509646416, 30.14436386525631, 44.690492525696754, 21.04787427932024, 25.332737155258656, 24.14795882999897, 42.55309961736202, 19.45071168243885, 52.064236253499985, 39.22070123255253, 47.39376246929169, 41.75502084195614, 1.765108359977603, 1.0181347047910094, 27.42049902677536, 73.48079904913902, 64.82702940702438, 68.2081487774849, 60.656943172216415, 43.47675785422325, 65.31723350286484, 70.43354496359825, 52.104297503829, 24.040739983320236, 23.6312435567379, 45.12184917926788, 38.843020498752594, 44.286095425486565, 55.45586585998535, 54.439279809594154, 66.39405772089958, 71.44533947110176, 69.08774837851524, 67.39680111408234, 61.26078777015209, 60.93918062746525, 56.08015336096287, 54.626947939395905, 49.843665808439255, 52.367661371827126, 45.58047316968441, 44.110518246889114, 47.01876059174538, 29.68584816902876, 11.569493785500526, 20.749111510813236, 42.24587470293045, 31.396166794002056, 10.544167254120111, 18.720383271574974, 16.972249075770378, 28.830248080193996, 23.712327405810356, 25.061792694032192, 18.064734153449535, 14.250559620559216, 0.11659302530460991, 0.008870865203789435, 0.039818256336729974, 0.03681755290017463, 0.076146429637447, 0.05935168337600771, 0.04475733447179664, 0.08481461060000584, 0.06066469104553107, 0.09940387579263188, 0.01221505963258096, 0.11407874771975912, 0.054578081908402964, 0.16444618056993932, 0.7205192372202873, 0.07057627735775895, 0.03852340531011578, 0.02842371424776502, 0.054729780604247935, 0.05767222544818651, 0.07006234751315787, 0.03759295621421188, 0.09221362255630083, 0.04626495923730545, 0.006587540729015018, 0.04871141194598749, 0.10688923663110472, 0.05950789061898831, 0.08861916387104429, 0.5571065715048462, 1.604494540952146, 15.820220243185759, 13.025907184928656, 13.87286938726902, 16.969194039702415, 18.622599318623543, 17.3872647061944, 12.512224148958921, 16.159522086381912, 44.425794929265976, 29.894099794328213, 30.22157572209835, 44.54638905823231, 51.92800596356392, 42.80216485261917, 47.066326439380646, 52.21022441983223, 53.868611231446266, 48.70365858078003, 48.58687944710255, 49.699440747499466, 53.29485721886158, 54.30781066417694, 55.1378533244133, 57.59492687880993, 54.242590963840485, 54.851284101605415, 58.15660133957863, 52.278958931565285, 51.95295922458172, 47.605019733309746, 28.08501686900854, 8.601269759237766, 6.312873903661966, 36.902122646570206, 54.559205174446106, 57.24488206207752, 51.852823197841644, 47.85850413143635, 46.370754763484, 44.8562890291214, 55.82785829901695, 53.632560297846794, 12.615930084139109, 0.5799911997746676, 9.84185853973031, 50.76412841677666, 43.024882301688194, 72.17790216207504, 65.68777441978455, 21.109411977231503, 24.085106402635574, 38.863216415047646, 32.137284725904465, 28.30432780086994, 28.544110134243965, 35.25964178144932, 30.081562735140324, 38.023636266589165, 19.197764955461025, 27.64017663896084, 69.83361035585403, 47.04223573207855, 2.519268854521215, 0.050730836592265405, 0.13460417016176507, 0.06630084622884169, 0.044296716805547476, 0.010631877739797346, 0.057199443981517106, 0.01604686363862129, 0.05289406719384715, 0.11492216886836104, 0.10206473496509716, 0.18075015570502728, 0.08562187431380153, 0.06798684989917092, 0.11523422712343745, 0.17991093511227518, 0.18690101627726108, 0.13379211217397824, 0.22361420094966888, 0.4090321093099192, 0.45026028295978904, 0.6368189910426736, 9.401334878057241, 87.75113850831985, 72.00105205178261, 62.07177445292473, 47.96236015856266, 58.24537217617035, 53.887849599123, 48.03643338382244, 50.850771367549896, 33.69229048490524, 35.925236865878105, 59.01870667934418, 15.632901694625616, 46.80617339909077, 47.79127433896065, 52.894339710474014, 39.17923405766487, 1.9359652418643236, 2.4739676853641868, 37.57128953933716, 81.70982748270035, 69.60219517350197, 71.69796511530876, 66.22590154409409, 50.6570615619421, 67.88157150149345, 72.73831129074097, 52.58423075079918, 21.824303716421127, 26.111723855137825, 53.61523322761059, 44.22891989350319, 51.13782316446304, 57.546395882964134, 58.90748284757137, 67.08507344126701, 70.83374708890915, 68.28345313668251, 70.27515426278114, 60.50620146095753, 64.25604924559593, 57.686095386743546, 56.77146166563034, 53.39016750454903, 53.77108186483383, 49.19901140034199, 45.515340864658356, 49.36231903731823, 35.226332768797874, 13.870011940598488, 20.916988402605057, 43.270964697003365, 27.919911928474903, 12.898379378020763, 17.97426860779524, 17.311506271362305, 38.07059034705162, 30.528340861201286, 27.155111767351627, 23.036754056811333, 22.113758884370327, 1.456337640993297, 0.1459797503775917, 0.24983703915495425, 0.14457520621363074, 0.11094882152974606, 0.16567967453738675, 0.11502635898068547, 0.1568576315185055, 0.1449707115534693, 0.25796676229219884, 0.2052387283765711, 0.18785231601214036, 0.17017400212353095, 0.1474993274314329, 1.7089391802437603, 0.17576667858520523, 0.1744483719812706, 0.10181097983149812, 0.10619146938552149, 0.14999424980487674, 0.16361178393708542, 0.15377344388980418, 0.22182641172548756, 0.16692522098310292, 0.1135352581331972, 0.1760882808594033, 0.263643657672219, 0.1726600484107621, 0.5182167864404619, 1.0822845250368118, 3.130225008353591, 26.04733821004629, 19.74924076348543, 15.418437402695417, 19.12319205701351, 29.51334122568369, 17.71016377955675, 17.201194390654564, 17.338150441646576, 38.08064080774784, 29.213316924870014, 35.06937839090824, 50.310189574956894, 52.03806325793266, 44.27822604775429, 49.64212842285633, 57.93449565768242, 54.546460658311844, 52.9264859855175, 52.688991129398346, 52.09068663418293, 54.84131723642349, 56.92651614546776, 56.19968734681606, 62.274797558784485, 53.5806854814291, 58.965623527765274, 60.33058248460293, 56.78381100296974, 57.73187913000584, 55.87692506611347, 34.601726084947586, 14.08441448584199, 5.384727157652378, 34.16198328137398, 57.75471970438957, 61.16652622818947, 58.17476436495781, 54.285114482045174, 50.1837969571352, 49.911332577466965, 58.108294531702995, 59.62717562913895, 22.113156616687775, 1.2917846208438277, 7.937445379793644, 51.96223832666874, 45.59138238430023, 74.32696804404259, 62.737403735518456, 13.981677498668432, 27.592973671853542, 55.0725120306015, 34.470549523830414, 49.95516322553158, 39.05819535255432, 49.149367064237595, 46.692954674363136, 45.98191402852535, 30.42419984936714, 39.94760222733021, 78.46268132328987, 61.56534902751446, 4.504252653568983, 0.14430786977754906, 0.3140146454097703, 0.16277752089081332, 0.18961087946081534, 0.14249475847464055, 0.13769481447525322, 0.10715352284023538, 0.142148160666693], [0.06476524620666169, 0.05230994131125044, 0.04461456381250173, 0.05196331752813421, 0.023485806850658264, 0.0284928805558593, 0.031399051076732576, 0.05919271534366999, 0.03529004970914684, 0.06127819484390784, 0.09079466588445939, 0.029742850201728288, 0.14744690211955458, 0.14919758395990357, 42.29356214404106, 68.86409237980843, 50.142116993665695, 23.841047398746014, 29.19215776026249, 40.882268473505974, 27.901767902076244, 28.767572343349457, 31.439763754606247, 23.77882193773985, 40.060079991817474, 19.72960341721773, 15.040533430874348, 27.24146593362093, 15.860373638570309, 51.563787907361984, 17.03991774469614, 1.0404716874472797, 1.6610232763923705, 24.96410373598337, 64.24066007137299, 64.30248275399208, 62.73518465459347, 64.80176836252213, 39.97475937008858, 39.10128504037857, 57.76600509881973, 42.105270847678185, 20.69341789931059, 10.703154522925615, 17.85859901458025, 25.564114339649677, 43.37203927338123, 54.47245202958584, 49.1798984259367, 55.90946651995182, 59.2767546325922, 63.125636503100395, 61.59719131886959, 61.732897236943245, 53.66846837103367, 46.51222497224808, 41.51539050042629, 43.72566729784012, 43.32162357866764, 43.6085119843483, 19.850446432828903, 5.248103113844991, 20.002348981797695, 34.62092645466328, 20.933718904852867, 4.085012599825859, 8.04464427754283, 9.520780518651009, 27.78309267014265, 22.672877982258797, 24.581806249916553, 21.35527018457651, 13.93972584977746, 8.462543953210115, 0.1691682287491858, 0.007213692579171038, 0.020551087764033582, 0.024947921265265904, 0.02304180587088922, 0.038102781982161105, 0.10810438470798545, 0.03002824123541359, 0.07894483846030198, 0.059296337713021785, 0.09333075518952683, 0.09305860963650048, 0.14783275953959674, 0.12890915153548121, 0.4030013282317668, 0.010369154679210624, 0.034473037885618396, 0.05975062114885077, 0.023696777170698624, 0.032862150692380965, 0.036938304037903436, 0.07157456988352351, 0.05699877096049022, 0.04229266203765292, 0.0524099419999402, 0.04924679727992043, 0.08044978778343648, 0.04054900833580177, 0.005612828554149019, 0.6074693659320474, 0.6790909508708864, 5.417313734069467, 5.865899138152599, 15.389076378196478, 14.829322714358568, 16.62409845739603, 10.973863396793604, 9.923635851591825, 10.365558788180351, 9.735528845340014, 32.32985459268093, 31.383099295198917, 24.916769675910473, 32.29502946138382, 44.93260033428669, 48.92442673444748, 46.44248351454735, 50.26710748672485, 54.30835023522377, 47.93146401643753, 46.45842365920544, 54.61292289197445, 55.89138329029083, 58.83513852953911, 54.10399340093136, 50.76298467814922, 55.418901443481445, 51.769258081912994, 45.39876312017441, 37.116792127490044, 26.13467652350664, 9.449793677777052, 6.6114903800189495, 31.139125786721706, 51.3195788115263, 52.22316652536392, 50.44100135564804, 46.41269691288471, 47.757589146494865, 59.03003387153149, 53.64915780723095, 54.70984809100628, 16.22567843645811, 0.9928715229034424, 1.7632972821593285, 38.426764234900475, 39.91002604365349, 22.26190533488989, 63.9682374894619, 22.95394130051136, 12.520660646259785, 36.71871028840542, 25.58666992932558, 37.62889824807644, 27.415243908762932, 34.34039130806923, 36.471989527344704, 28.852364793419838, 24.38283372670412, 23.12825884670019, 37.704673781991005, 58.09307634830475, 24.979361817240715, 0.6730305135715753, 0.13601445854874328, 0.12707033223705366, 0.025016124636749737, 0.09400531547726132, 0.06876907355035655, 0.060861067031510174, 0.03736326521902811, 0.07460924141923897, 0.08003928363905288, 0.04769316677993629, 0.06877509978949092, 0.024198248211177997, 0.03779119870159775, 0.07328755062189884, 0.025181174569297582, 0.02853493806469487, 0.06137046235380694, 0.14253355795517564, 0.0692331904429011, 0.03426131799642462, 0.1471870465320535, 0.12483737315051258, 47.96057425439358, 81.63086012005806, 50.27922123670578, 31.119159758090973, 35.362103283405304, 21.988086327910423, 40.17032727599144, 30.79294726252556, 29.83174704015255, 24.534852169454098, 34.768065959215164, 24.68616385012865, 28.551014363765717, 33.0429395288229, 16.103174909949303, 56.90888129174709, 30.330757163465023, 2.50089137814939, 0.7763363420963287, 20.85566159337759, 65.83228066563606, 68.39050099253654, 66.2416023015976, 67.87944361567497, 46.5448310226202, 47.61723607778549, 57.37179905176163, 48.65343287587166, 25.042628422379494, 10.218284390866756, 17.389628179371357, 27.67637349665165, 44.47396494448185, 55.38749232888222, 49.39641460776329, 51.95489712059498, 55.35281538963318, 60.11536583304405, 59.38843064010143, 62.41334192454815, 54.216661155223846, 48.71247410774231, 43.53760778903961, 43.3224443346262, 46.87464952468872, 43.707048296928406, 23.561403304338455, 12.451328616589308, 27.945457957684994, 44.930297657847404, 33.905489444732666, 9.882325418293476, 17.53552135080099, 13.511160146445036, 27.16655485332012, 32.84208230674267, 30.392604544758797, 25.04603683948517, 26.02864321321249, 13.829846195876598, 0.038976753639872186, 0.02278400417708326, 0.10364776564529166, 0.05757309678301681, 0.03610136925999541, 0.05274617200484499, 0.27507528488058597, 0.06226803801837377, 0.14635731058660895, 0.09017917313030921, 0.17142514436272904, 0.10299556626705453, 0.0888656236929819, 0.02575071539467899, 0.5264625221025199, 0.05300714081386104, 0.0326179395779036, 0.14393752324394882, 0.048196932912105694, 0.016190363458008505, 0.026816079516720492, 0.03874720736348536, 0.012100667772756424, 0.018653783517947886, 0.1286221036571078, 0.06096111595979892, 0.09414168511284515, 0.12297646753722802, 0.01198845968247042, 1.4121115766465664, 0.9210568608250469, 8.90596590936184, 13.498427029699087, 15.728248078376055, 18.120283372700214, 20.983513332903385, 10.91920142993331, 15.474505294114351, 18.16703986376524, 16.453215926885605, 48.508037477731705, 40.9208820015192, 29.564746767282486, 33.689307644963264, 45.086176693439484, 51.07725441455841, 49.921348839998245, 50.94816394150257, 56.221281588077545, 51.441233083605766, 49.18659366667271, 54.628612250089645, 57.52273455262184, 60.37507049739361, 55.89447632431984, 52.514785677194595, 56.676272973418236, 53.818651512265205, 47.73516654968262, 38.79951283335686, 23.613255321979523, 8.137583490461111, 10.633518509566784, 40.77183119952679, 56.169007793068886, 56.1072801053524, 53.138750195503235, 51.7585464566946, 54.6218828111887, 60.10850340127945, 57.14201778173447, 54.88119229674339, 8.847440499812365, 0.43767544731963426, 3.9693088084459305, 45.08240349590778, 42.475420385599136, 21.10970076173544, 56.2797262519598, 30.919130891561508, 20.691888481378555, 33.04960057139397, 29.16807845234871, 37.52594657242298, 20.295541249215603, 42.0055527985096, 33.86279113590717, 32.45225362479687, 29.718505516648293, 19.27076853811741, 43.40907208621502, 68.51916968822479, 29.508863165974617, 0.6647279590833932, 0.2510772569803521, 0.15660850738640875, 0.036506518808892, 0.0477566166955512, 0.047193241261993535, 0.0164725020295009, 0.060124151495983824, 0.05547671142267063, 0.11836644654977135, 0.1478251302614808, 0.2505841146921739, 0.2344438128056936, 0.10145517197088338, 0.1587854788522236, 0.1431432768004015, 0.15281283762305975, 0.2419177594128996, 0.2582130068913102, 0.2050639971275814, 0.19089951500063762, 0.22496767051052302, 0.3585423779441044, 64.47256162762642, 88.82167026400566, 69.2047592997551, 33.69683124125004, 40.76059140264988, 53.439336866140366, 38.57875607907772, 42.92483747005463, 42.66666792333126, 33.857870399951935, 52.3076131939888, 27.330455258488655, 20.14817375689745, 33.55025790631771, 22.387775480747223, 64.13881793618202, 22.40970980376005, 2.689729845151305, 3.2214165525510907, 31.718402802944183, 73.02746817469597, 73.76433983445168, 74.48361843824387, 76.5186296403408, 51.69845648109913, 52.56748124957085, 63.235458210110664, 54.08189378678799, 24.034667909145355, 14.84505956992507, 25.80482952296734, 39.00350108742714, 51.41029134392738, 54.87148001790047, 54.03025455772877, 57.60790318250656, 59.99572545289993, 62.34611213207245, 61.26915492117405, 64.32029619812965, 57.13556192815304, 51.42540693283081, 44.995486959815025, 47.06289142370224, 46.44579313695431, 51.11985772848129, 24.725894518196583, 14.598946776241064, 30.644911006093025, 46.22192434966564, 30.03754399716854, 9.384573977440596, 20.377356559038162, 14.652569498866796, 32.8580604493618, 37.8906662017107, 36.52380734682083, 28.209488689899445, 33.02958324551582, 17.214383482933044, 0.3719966544304043, 0.08580561523558572, 0.11816878293757327, 0.20162880333373323, 0.19579338520998135, 0.09985848577343859, 0.19980043347459286, 0.19481594703393057, 0.09720686633954756, 0.21100469632074237, 0.17631692171562463, 0.22624186385655776, 0.37017239606939256, 0.307841015746817, 1.714285493362695, 0.14997047139331698, 0.1468586758710444, 0.17998648574575782, 0.08901199005777016, 0.1610512111801654, 0.11053730064304546, 0.18618707021232694, 0.21162499819183722, 0.0822676117240917, 0.12417491729138419, 0.11684590470395051, 0.21064836153527722, 0.27836653171107173, 0.08231038169469684, 3.2030093902722, 3.685796046629548, 16.583775021135807, 21.839445903897285, 18.993771001696587, 20.505307093262672, 26.44481398165226, 16.309059262275696, 15.290582813322544, 23.35447210818529, 15.296584591269493, 44.41634863615036, 36.61454647779465, 31.71542566269636, 39.734798446297646, 45.98199762403965, 51.4531834423542, 51.17065340280533, 54.77111980319023, 58.570847511291504, 52.771131321787834, 49.89912763237953, 60.028339102864265, 63.63434940576553, 63.735667169094086, 57.051917016506195, 54.68332551419735, 58.597552478313446, 55.521537736058235, 52.604772448539734, 46.99286878108978, 30.55275645107031, 12.381915841251612, 8.688324987888336, 38.26451674103737, 58.5518903285265, 59.780797585844994, 57.918661907315254, 53.97805295884609, 56.13408386707306, 66.22614473104477, 64.0726026892662, 65.1347216963768, 21.304465010762215, 2.029668688774109, 3.0875625601038337, 44.429302141070366, 50.330453887581825, 27.900227084755898, 74.33130741119385, 29.333764761686325, 17.25900448858738, 45.83779536187649, 32.9746799916029, 46.34686164557934, 35.710024014115334, 46.902505829930305, 46.82818561792374, 40.032151490449905, 37.66908869147301, 32.359124422073364, 53.5391841083765, 79.20937925577164, 47.87800848484039, 1.5278733149170876, 0.2543884824262932, 0.2543197892373428, 0.1397337910020724, 0.14235288952477276, 0.16912620834773406, 0.17072823800845072, 0.17754716507624835, 0.20968020020518452], [0.03264059363573324, 0.04403042679768987, 0.04552495636744425, 0.013250742485979572, 0.08007159674889408, 0.04221213159325998, 0.03955532083637081, 0.035915182961616665, 0.03705717754201032, 0.04500931216171011, 0.11689812221447937, 0.09763634720002301, 0.2974979707505554, 0.1204335578950122, 7.038482967764139, 62.75844320654869, 50.19997648894787, 38.78152459859848, 32.86193244159222, 43.569921255111694, 26.00426372140646, 24.39046371728182, 24.044784866273403, 26.12124614417553, 31.01082757115364, 39.8396310210228, 7.503771800547838, 8.338059782981873, 27.43768360465765, 48.13288360834122, 46.302069649100304, 10.557220503687859, 2.4782728543505073, 1.9425219087861478, 28.65455500781536, 62.257535085082054, 50.18806032836437, 52.938029766082764, 66.12627848982811, 48.16534146666527, 62.138726860284805, 55.25312773883343, 50.56519769132137, 12.670172173529863, 1.5118913725018501, 5.119802048429847, 13.64744933322072, 39.73593458533287, 63.145634829998016, 59.710573554039, 60.17472244799137, 55.03696493804455, 50.45984834432602, 53.127457201480865, 52.46063098311424, 56.00899837911129, 54.24764469265938, 52.55360059440136, 32.09251172840595, 10.499415155500174, 11.486525237560272, 27.834344319999218, 37.35794998705387, 13.01327096298337, 6.782259866595268, 20.53022425621748, 8.49474722519517, 25.09468372911215, 37.14290052652359, 25.521433129906654, 25.718346163630486, 22.108610160648823, 19.26607768982649, 12.21627987921238, 0.1071726182999555, 0.10209018320892937, 0.020601826545316726, 0.042829932426684536, 0.05881951154151466, 0.09153997511020862, 0.06799452370614745, 0.16131669224705547, 0.028436273241823073, 0.08033348582102917, 0.08386791960219853, 0.05407459037087392, 0.26233991200570017, 0.9159973135683686, 0.45203291752841324, 0.037094626313773915, 0.08528320264304057, 0.09428083780221641, 0.015394516758533427, 0.052302267504273914, 0.022267771819315385, 0.04730298634967767, 0.10351047574658878, 0.042515105960774235, 0.025566636795701925, 0.08948789225541987, 0.13198554661357775, 0.11633769681793638, 0.09881728226901032, 1.090040858834982, 1.2285235966555774, 1.2382687674835324, 4.186725541949272, 10.435592830181122, 20.736281499266624, 17.96584066003561, 17.45579782873392, 11.379256043583155, 21.823444962501526, 13.099907264113426, 6.850809138268232, 29.194629527628422, 41.20465837419033, 28.0924853682518, 16.583714224398136, 38.01907651126385, 53.81814233958721, 50.41843816637993, 45.98485507071018, 50.70717327296734, 56.567066833376884, 55.39920710027218, 52.71110214293003, 53.896497935056686, 58.65866459906101, 49.51893903315067, 49.86700035631657, 44.85055133700371, 31.939885318279266, 18.39726760983467, 7.635359689593315, 5.965819526463747, 33.43836531043053, 54.026393964886665, 48.04336041212082, 54.87790547311306, 53.310614973306656, 51.18783228099346, 45.42797975242138, 47.982601672410965, 48.17828357219696, 16.692857667803764, 0.8916714938823134, 1.1583427875302732, 19.769710265100002, 61.66390813887119, 25.621723048388958, 21.624746024608612, 27.181575447320938, 9.898928627371788, 24.439536184072495, 33.0746678262949, 25.791258551180363, 34.32711862027645, 36.14348575472832, 32.6145239174366, 27.129668332636356, 30.889536179602146, 27.260943688452244, 37.685260623693466, 46.0069964826107, 53.93807910382748, 4.279677579179406, 0.10860882248380221, 0.25536992819979787, 0.16619013855233788, 0.112656443961896, 0.10507775063160807, 0.06483369448687881, 0.020052069521625526, 0.05557847842283081, 0.02992922945850296, 0.0694973356439732, 0.09934240370057523, 0.04056906487676315, 0.031172287854133174, 0.08288585784612224, 0.06432056616176851, 0.034012171599897556, 0.019028835267818067, 0.067293394531589, 0.08057309561991133, 0.0779251943458803, 0.200077670160681, 0.2821923920419067, 0.24880585464416072, 11.435395181179047, 72.63704672455788, 60.2016744017601, 25.498993434011936, 43.403596580028534, 30.43729394674301, 29.59368221461773, 33.01429286599159, 24.820473343133926, 28.21848850697279, 27.696444019675255, 37.76912972331047, 16.66473537683487, 18.13471879810095, 25.14710381627083, 55.68511515855789, 53.15868392586708, 19.885058775544167, 4.417571229860187, 2.1610613632947206, 23.47899902611971, 69.60115402936935, 57.31822572648525, 58.96196812391281, 66.37338683009148, 53.566652834415436, 66.92349091172218, 60.17408788204193, 54.01293508708477, 17.618847079575062, 1.5195428556762636, 4.511866495013237, 11.226093862205744, 38.79426151514053, 60.44543132185936, 64.6010023355484, 62.039339393377304, 61.2648269534111, 53.89835983514786, 54.17139798402786, 51.44564464688301, 59.67966601252556, 55.70547066628933, 54.333436489105225, 26.39856666326523, 17.050655968487263, 19.109545089304447, 34.56073008477688, 46.9340555369854, 25.42252253741026, 11.621740981936455, 28.074696622788906, 11.37700466439128, 24.78946890681982, 40.0208280980587, 32.51972660422325, 28.521537445485592, 27.663258500397205, 26.61338623613119, 15.626643430441618, 0.12067987670889124, 0.05376233173592482, 0.06014077189320233, 0.23580077046062797, 0.3608264116337523, 0.22807633416960016, 0.24421127774985507, 0.11278048652457073, 0.23489963990869, 0.6523054162971675, 0.02031600321060978, 0.05577873584115878, 0.041041170989046805, 0.43256142642349005, 0.15552829660009593, 0.077197429491207, 0.02421850698738126, 0.09909169137245044, 0.030979646726336796, 0.05468091389047913, 0.030292577539512422, 0.02831988222169457, 0.05943858886894304, 0.045767883566441014, 0.06838631088612601, 0.08607498515630141, 0.0827878869313281, 0.05970009202428628, 0.01992766516195843, 0.06771400672732852, 3.9396649366244674, 7.863460499793291, 18.85296195745468, 12.723477613180876, 23.448921740055084, 20.382032208144665, 22.326644361019135, 8.898348268121481, 27.00382098555565, 19.09947942942381, 11.836687847971916, 41.43328070640564, 53.116935566067696, 37.43975579738617, 16.999979987740517, 35.76807349920273, 53.752766847610474, 54.28754635155201, 47.487351447343826, 53.239087611436844, 58.360422402620316, 57.41773098707199, 55.75926437973976, 55.78663811087608, 60.49311116337776, 50.427002906799316, 47.8084722161293, 44.88079011440277, 31.686452217400074, 17.21054568886757, 8.269631154835224, 8.932213000953197, 38.83716121315956, 55.360452979803085, 50.56927107274532, 57.255886271595955, 56.828637197613716, 56.325882375240326, 48.00680257380009, 50.72233825922012, 51.72534763813019, 14.109058063477278, 0.48499451600946486, 2.9211991745978594, 31.624525040388107, 63.542835116386414, 29.74347397685051, 22.81482506543398, 32.961213514208794, 18.74163743108511, 27.318107821047306, 31.547277085483074, 31.283290050923824, 29.800934493541718, 32.444019466638565, 42.91350647807121, 21.81364718824625, 35.68445138633251, 28.219651244580746, 33.08092229068279, 56.61982320249081, 62.01109930872917, 4.956611255183816, 0.10091866599395871, 0.17640860663959756, 0.06035549005900975, 0.027141615173604805, 0.042141041267313994, 0.09832388022914529, 0.01558918858791003, 0.03385902942682151, 0.006213045589902322, 0.22660226561129093, 0.2468804712407291, 0.2209551155101508, 0.13981575379148126, 0.18841642246115953, 0.177444021392148, 0.24327191174961627, 0.14894017745973542, 0.16058496432378888, 0.20350478938780725, 0.20921557123074308, 0.513196662068367, 0.5723126430530101, 0.6769678741693497, 17.971633449196815, 87.40297839045525, 70.31298503279686, 51.95967346429825, 46.89369410276413, 62.501618787646294, 34.19823333621025, 37.800295650959015, 33.96594800055027, 37.39302970468998, 45.01671262085438, 56.86552181839943, 12.120973393321037, 14.928250405937433, 30.36420676857233, 64.26623269915581, 56.0743510723114, 17.09017764776945, 5.004591755568981, 4.7039965353906155, 35.34971974790096, 74.59791630506516, 60.4235976934433, 64.54334422945976, 74.56572443246841, 56.413452476263046, 75.23450374603271, 65.56580856442451, 54.104145392775536, 15.111027248203754, 1.6296375542879105, 7.8879644349217415, 19.44662120193243, 50.33160142600536, 65.84649950265884, 67.02507466077805, 65.2633447945118, 65.01435175538063, 57.2489820420742, 57.96615555882454, 54.840462282299995, 59.76511962711811, 56.59961208701134, 59.61878187954426, 38.23697201907635, 14.95475398376584, 20.396841913461685, 39.09360185265541, 45.665801391005516, 19.258006922900677, 10.15251561999321, 35.45907787978649, 11.868174858391285, 29.153494834899902, 44.291703924536705, 38.81814703345299, 34.265930503606796, 29.072162099182606, 37.430465295910835, 19.981252513825893, 0.3823106666095555, 0.28729100595228374, 0.16778654273366556, 0.160414878919255, 0.10906466442975216, 0.20710269163828343, 0.21608732437016442, 0.23404235544148833, 0.1635856306529604, 0.5905649636406451, 0.35943521128501743, 0.3466651652706787, 1.099741857033223, 2.2703344747424126, 1.1461050692014396, 0.14792778412811458, 0.10368388597271405, 0.2721890131942928, 0.1614396958029829, 0.24472897028317675, 0.10092864788020961, 0.14242098899558187, 0.28290476475376636, 0.10768596184789203, 0.13603589177364483, 0.3263455774867907, 0.24709039513254538, 0.43938425718806684, 0.5392914649564773, 3.6306878412142396, 4.041891563683748, 13.20377754047513, 25.037962272763252, 17.884868904948235, 26.690736785531044, 25.41240368038416, 28.044359050691128, 13.992670308798552, 29.09106608480215, 23.053000085055828, 10.584813673049212, 41.70484073460102, 47.51232750713825, 38.96082557737827, 21.462407335639, 43.54521118104458, 57.542485892772675, 55.51929585635662, 50.066835433244705, 55.71277007460594, 60.95098279416561, 57.282967418432236, 55.88290214538574, 59.663953855633736, 64.04411941766739, 48.06912302970886, 51.84224456548691, 48.271766155958176, 37.75472469627857, 23.79092998802662, 10.739047396928072, 8.55278816074133, 36.42744451761246, 60.42409926652908, 55.96425957977772, 63.93944263458252, 59.79090504348278, 60.94884730875492, 53.26420806348324, 57.509154081344604, 58.33709545433521, 23.6068032681942, 1.707089392002672, 2.217575730755925, 26.673328019678593, 72.87043780088425, 33.35669249296188, 28.714825473725796, 37.061003521084785, 15.024757627397776, 33.325461968779564, 43.4159155189991, 35.18008925020695, 43.84551666676998, 51.40559479594231, 47.69966885447502, 35.77709041535854, 45.40137358009815, 35.84115117788315, 50.54316267371178, 62.78101399540901, 78.61039459705353, 10.700214430689812, 0.3409604245098308, 0.5270695395302027, 0.2979549259180203, 0.2620086172828451, 0.23687029432039708, 0.19455175730399787, 0.1346418118919246, 0.12492870184360072, 0.16685124370269477], [0.03668949531856924, 0.03208029440429527, 0.10732020920841023, 0.060449271550169215, 0.05574880131462123, 0.06277973399846815, 0.010817419297382003, 0.04249250014254358, 0.049839123894344084, 0.0477530766511336, 0.006928557586434181, 0.06264288196689449, 0.08176945251761936, 0.1695322967134416, 1.200841013342142, 61.54773697257042, 56.464096158742905, 47.51184493303299, 26.46678440272808, 43.10805603861809, 36.4505510777235, 24.054594039916992, 31.153101436793804, 23.42030167579651, 30.498907640576363, 35.54735094308853, 26.952253952622414, 9.767529778182507, 23.382535502314568, 32.17921547591686, 70.2073734998703, 83.30251961946487, 13.58358521014452, 0.7524809252936393, 6.210985695943236, 42.7228669077158, 57.70596832036972, 55.663209334015846, 65.94776406884193, 55.56487821042538, 44.22726318240166, 51.00852370262146, 49.36007335782051, 53.14514525234699, 14.485825896263123, 0.5122248642146587, 0.1802180803497322, 1.3171316357329488, 9.825834799557924, 23.949506878852844, 38.4219004958868, 42.781322970986366, 52.36441254615784, 46.89621716737747, 45.04569746553898, 31.022715233266354, 20.053783021867275, 6.062125358730555, 0.6038649624679238, 20.040877014398575, 44.20671388506889, 35.122830122709274, 12.766894083470106, 4.6569873578846455, 24.74005825817585, 11.726279072463512, 21.410754807293415, 43.9348878711462, 28.126748129725456, 28.09065956622362, 27.09687039256096, 12.413984220474958, 14.81210583820939, 8.71405340731144, 0.17580886225914583, 0.03087409662839491, 0.11446640113717876, 0.05228891626757104, 0.13632052025059238, 0.490068846847862, 0.7661786559037864, 1.064495185855776, 0.7424316520337015, 0.1100160606438294, 0.17984049045480788, 0.3837246063631028, 0.1424353866605088, 0.027481617144076154, 0.42481082200538367, 0.06901600092533045, 0.0675477136974223, 0.05612416847725399, 0.03757806873181835, 0.041289174478151836, 0.07058496048557572, 0.020954656538378913, 0.09034742543008178, 0.047446695825783536, 0.04295239421480801, 0.14088771189562976, 0.8734290290158242, 0.11479256019811146, 0.4833695985144004, 0.04707998952653725, 3.6401139479130507, 2.5557903572916985, 10.23660035803914, 6.427632495760918, 15.871789176017046, 22.495153918862343, 16.905091479420662, 20.487638041377068, 18.733274079859257, 25.218465887010098, 15.077196713536978, 9.345263186842203, 20.346806198358536, 34.87110882997513, 35.88917680084705, 15.202855970710516, 28.609441928565502, 52.58691720664501, 56.58006213605404, 52.861178889870644, 48.829169645905495, 55.15951596200466, 61.56587339937687, 57.81833589076996, 55.81213854253292, 48.84231694042683, 45.50488382577896, 28.68634980171919, 13.92584329470992, 4.777140710502863, 5.997723564505577, 25.277615413069725, 41.76231265068054, 43.95940415561199, 46.80717274546623, 47.24488265812397, 48.77344563603401, 47.38787658512592, 46.46525949239731, 50.52175082266331, 42.86399133503437, 7.627777671441436, 0.28813951823394746, 10.374559555202723, 61.81769348680973, 50.56660361588001, 20.654190704226494, 7.8359319269657135, 10.015532970428467, 13.978882748633623, 35.0751768797636, 33.879069462418556, 38.48496191203594, 37.72786773741245, 36.7070335149765, 27.09637451916933, 38.92090491950512, 32.63348110020161, 28.21640431880951, 38.42878192663193, 60.52219480276108, 31.990631595253944, 0.32814472157042474, 0.07400889589916915, 0.10145736130652949, 0.02790265793009894, 0.045530151401180774, 0.04742772282043006, 0.08486539576551877, 0.05099999129015487, 0.051282556596561335, 0.09272347058868036, 0.029371570417424664, 0.04414525188622065, 0.023961412189237308, 0.018338977461098693, 0.07791373558575287, 0.031135970857576467, 0.025673340933280997, 0.08191077969968319, 0.04372757117380388, 0.11608427565079182, 0.054625490301987156, 0.0790261704241857, 0.10843654774362221, 0.111256953823613, 2.0752797788009048, 64.92153033614159, 75.79328656196594, 38.37677791714668, 35.641388297080994, 50.488107427954674, 23.85264627635479, 35.06182059645653, 28.0411634221673, 28.420679457485676, 25.02390492707491, 32.790234088897705, 29.70567550510168, 20.969182401895523, 30.54476547986269, 45.259705781936646, 68.39659586548805, 86.47195234894753, 19.998457990586758, 0.9848895168397576, 5.038136830553412, 40.6155151873827, 59.874200373888016, 61.8492241948843, 70.22395581007004, 57.40609981119633, 53.605695739388466, 55.74951410293579, 55.2182038128376, 56.829381957650185, 18.245431557297707, 1.5193035872653127, 1.1523949191905558, 2.07798452116549, 7.228157389909029, 21.778666265308857, 38.68742264807224, 41.407689079642296, 50.370062962174416, 47.18157045543194, 46.00108399987221, 31.405185610055923, 23.288163766264915, 4.495980022475123, 1.873144875280559, 24.04144674539566, 45.94811484217644, 47.02702894806862, 24.36259601265192, 6.9808652345091105, 27.95835066586733, 14.541725646704435, 15.85537500679493, 47.08041228353977, 30.60121525079012, 36.273260191082954, 37.23258711397648, 24.94960941374302, 22.110213674604893, 10.137021951377392, 1.0008039535023272, 0.3010794270085171, 0.6115083710756153, 0.11742795628379099, 0.08631263568531722, 0.11266674497164786, 0.16448468319140375, 0.3998744225827977, 0.2473639656091109, 0.204942136479076, 0.593054483179003, 0.6255476083606482, 0.11529822993907146, 0.02130887434759643, 0.17838197731180117, 0.13789972144877538, 0.07512234747991897, 0.06576739047886804, 0.05020333286665846, 0.08603378111729398, 0.04415972376591526, 0.04014364727481734, 0.10604437571601011, 0.13355131493881345, 0.14601708040572703, 0.2988159062806517, 0.16557430441025645, 0.02842465677531436, 0.3592825960367918, 0.13970339263323694, 3.43627673573792, 3.785396064631641, 20.837614461779594, 17.020050510764122, 17.682742550969124, 24.369220957159996, 20.44311013072729, 20.710862763226032, 12.619132362306118, 34.2364326864481, 20.84973581135273, 14.365624096244574, 23.26316110789776, 41.5229444950819, 44.78284277021885, 19.60789404809475, 29.17107079178095, 49.42608341574669, 61.10370419919491, 57.400343120098114, 52.36407056450844, 55.008835047483444, 59.327128529548645, 60.828644558787346, 58.88387091457844, 49.68396417796612, 46.65171168744564, 25.4098654165864, 12.006629928946495, 3.7386792339384556, 7.969654351472855, 32.05901272594929, 44.90793585777283, 45.996588841080666, 50.54038122296333, 51.37234278023243, 52.379459738731384, 54.38518591225147, 51.97107285261154, 57.27960079908371, 49.868653267621994, 9.59681348875165, 0.1466811986756511, 12.63113021850586, 70.421492010355, 61.86355322599411, 29.88362565636635, 12.873912490904331, 17.456016317009926, 20.880789645016193, 33.67866821587086, 30.957056656479836, 40.31018637120724, 26.39628678560257, 44.32824656367302, 26.645673103630543, 34.93588015437126, 37.26282589137554, 21.943186037242413, 41.4690063893795, 69.62206810712814, 38.91010969877243, 0.5928653839509934, 0.023347871283476707, 0.12464506784453988, 0.05574168040766381, 0.007553481182185351, 0.05296131690556649, 0.10678751787054352, 0.017309687282249797, 0.05212831179960631, 0.08559595851693302, 0.18443393928464502, 0.10521797943511046, 0.1714297159924172, 0.1456273638177663, 0.2178856817772612, 0.20746724942000583, 0.15339177218265831, 0.2137626803596504, 0.21363620355259627, 0.31685208377894014, 0.12273444575839676, 0.16591621184488758, 0.29374252539128065, 0.2753095660591498, 3.228338356129825, 84.89395782351494, 76.26379251480103, 66.36495888233185, 37.835325971245766, 68.12146782875061, 50.99508762359619, 34.606502428650856, 44.70444917678833, 33.56659322977066, 44.578508734703064, 52.28983394801617, 37.09459371864796, 15.060753095895052, 31.20547592639923, 45.43444700539112, 78.37603077292442, 96.54835805296898, 22.27345861494541, 1.5903435065411031, 8.364195730537176, 50.950671806931496, 68.66283237934113, 66.13084584474564, 78.80119755864143, 64.10043999552727, 59.87282104790211, 58.98454651236534, 60.43512627482414, 58.70558828115463, 17.6279703900218, 1.0856234771199524, 0.6526988733094186, 2.2402115911245346, 12.522651739418507, 30.016975700855255, 46.61279417574406, 48.621032014489174, 59.36312019824982, 54.88202065229416, 51.064593493938446, 34.162127673625946, 24.60720218718052, 9.212558157742023, 1.233288065996021, 27.986467257142067, 53.23445565998554, 42.107166945934296, 17.225438989698887, 6.498874397948384, 38.92172187566757, 16.410749405622482, 25.758519507944584, 52.45752654969692, 34.568504467606544, 40.09867452085018, 36.0658673197031, 26.82752374559641, 27.91352827101946, 18.653499260544777, 0.3294931148411706, 0.2570944419130683, 0.42275842744857073, 0.21639313374180347, 0.3366000991081819, 0.9330738941207528, 1.207494931295514, 1.7116946261376143, 1.363499122671783, 1.744460267946124, 1.4247525483369827, 0.9913711377885193, 0.5490643624216318, 0.1979954115813598, 0.8186183357611299, 0.3794208326144144, 0.11623815255006775, 0.17071226699044928, 0.1288474048487842, 0.18634180800290778, 0.28297512035351247, 0.21277041407302022, 0.18948898912640288, 0.16923747112741694, 0.40270443947520107, 1.0295329056680202, 2.204725770279765, 1.4079696801491082, 1.0010605584830046, 0.38622187392320484, 7.999553997069597, 6.4038533717393875, 23.525508530437946, 21.271606273949146, 20.575215741991997, 27.498201057314873, 23.945680484175682, 26.029463969171047, 21.555099561810493, 33.49140666425228, 27.823015227913857, 15.805962458252907, 30.358275286853313, 43.811766877770424, 44.1041573882103, 21.61586780101061, 32.21269927918911, 55.60256078839302, 59.710345566272736, 57.27066367864609, 54.14771005511284, 59.81560371816158, 65.30344784259796, 63.674026876688, 56.732696145772934, 52.21944272518158, 48.93780201673508, 30.9760632365942, 18.305449336767197, 6.061999490484595, 6.885471353307366, 28.71463168412447, 47.69942946732044, 51.591245234012604, 55.31975336372852, 55.37025265395641, 60.16161695122719, 58.964046612381935, 57.090135365724564, 60.489273369312286, 53.45081605017185, 10.06264379248023, 0.18816486408468336, 12.39677494391799, 69.36093091964722, 61.612151116132736, 30.289573073387146, 13.38086323812604, 14.504642486572266, 20.873708724975586, 45.394875928759575, 46.00990332663059, 48.546111434698105, 49.32090125977993, 50.38189172744751, 35.80607146024704, 54.400168508291245, 48.38691517710686, 37.76004061102867, 55.888753831386566, 75.98519146442413, 59.55933786928654, 1.2847769656218588, 0.245813203509897, 0.29625208291690797, 0.11342558354954235, 0.1247312460327521, 0.10795277878060006, 0.15360064222477376, 0.11462513168225996, 0.1818522301618941, 0.14938813779735938], [0.04464181176444981, 0.046929207383072935, 0.04476921254536137, 0.01626171168027213, 0.040425967672490515, 0.0713035227090586, 0.07388566227746196, 0.042897122766589746, 0.04784296928846743, 0.01883151304355124, 0.06439495904487558, 0.08291873498819768, 0.1047619667951949, 0.4647170822136104, 0.0843893080309499, 19.711691178381443, 73.3093674480915, 51.77459679543972, 29.81350801885128, 31.804042607545853, 50.62869228422642, 24.384585432708263, 32.88194976747036, 32.77893729507923, 23.280987851321697, 29.01713725179434, 38.36966469883919, 13.095119521021843, 10.200087167322636, 18.594283238053322, 24.6776295080781, 58.5487212985754, 50.07225774228573, 4.0483977645635605, 0.9153655380941927, 21.46566566079855, 62.591426968574524, 62.834165543317795, 61.01171113550663, 51.914797872304916, 49.042957574129105, 51.40648014843464, 55.56752286851406, 54.14892598986626, 45.70400454103947, 8.029689230024815, 1.7553849192336202, 0.10815169662237167, 0.46878182503860444, 1.6770168556831777, 11.61729047074914, 13.80838019773364, 7.096442682668567, 2.918112315237522, 2.1466330625116825, 0.9490466339047998, 0.43716648244298995, 0.48681384650990367, 24.64733563363552, 57.948786690831184, 27.74431575089693, 11.156137716025114, 9.066233709454536, 22.253866866230965, 14.202296510338783, 13.86434169486165, 47.19179950654507, 31.899801269173622, 26.913290843367577, 27.788078002631664, 20.344953797757626, 2.2311635641381145, 16.39665976166725, 4.820050857961178, 2.2277375729754567, 0.2512474462855607, 0.7159484387375414, 2.890395177528262, 2.5535567896440625, 0.7752051902934909, 0.6894634442869574, 0.28839852777309716, 0.1815562171395868, 0.5240735784173012, 0.25437084899749607, 0.08481678509269841, 0.0875155754329171, 0.01134857067881967, 0.11429109101300128, 0.2681493846466765, 0.04279361543012783, 0.03275964525528252, 0.07124231036868878, 0.0808557722484693, 0.01222154414790566, 0.043220072038820945, 0.03786489767662715, 0.10353073637816124, 0.6302212981972843, 0.0845272361766547, 0.030195623367035296, 0.0639840541407466, 0.06732952228048816, 0.13413336651865393, 3.5357658471912146, 6.100111920386553, 12.587355617433786, 4.943264946341515, 13.253406677395105, 23.24842929840088, 21.16863749921322, 19.529969729483128, 26.379622779786587, 18.768942765891552, 22.879719883203506, 25.52024569362402, 31.885103657841682, 20.83418894559145, 26.25802930444479, 40.98371922969818, 23.006296791136265, 26.66705835610628, 39.758148193359375, 48.641167134046555, 64.15299877524376, 53.38941514492035, 52.19837285578251, 50.67573755979538, 58.81905399262905, 32.38639555871487, 20.5345294252038, 9.816948026418686, 0.5201163876336068, 2.174384160898626, 18.232835233211517, 45.36401778459549, 49.668510407209396, 51.21614836156368, 50.107561647892, 49.37236949801445, 48.08403342962265, 54.874060079455376, 54.97804529964924, 47.3051892220974, 38.6179243773222, 6.2348175421357155, 0.8588262344710529, 21.97890032082796, 29.229129776358604, 38.797023966908455, 14.18535416945815, 9.70189020037651, 13.615550994873047, 21.71207293868065, 34.02632676064968, 29.003862664103508, 31.5246606990695, 35.54494947195053, 28.907385841012, 31.934379413723946, 38.22827808558941, 31.29609726369381, 32.06745587289333, 38.42727340757847, 72.03592658042908, 14.569293167442083, 0.5579108220990747, 0.11101099866209552, 0.13516646577045321, 0.01317284295510035, 0.030807932307652663, 0.03361747891176492, 0.09606587365851738, 0.05310458109306637, 0.051599275539047085, 0.04835063540667761, 0.04441631390363909, 0.09585357489413582, 0.011016789849236375, 0.013231781540525844, 0.05210870054725092, 0.014111746040725848, 0.039676728774793446, 0.027549499536689837, 0.10647328512277454, 0.04575592014589347, 0.08968461334006861, 0.054174238539417274, 0.06957840785617009, 0.5291866196785122, 0.11581260507227853, 24.397867619991302, 85.22787630558014, 58.84506359696388, 26.793441474437714, 49.50220473110676, 30.540471710264683, 28.970131874084473, 31.263523511588573, 34.92949649691582, 23.620218448340893, 26.32600575685501, 35.864592120051384, 22.024136893451214, 19.33433722704649, 21.085431464016438, 30.265140384435654, 58.81721869111061, 55.4167165607214, 6.186137879267335, 1.8070391099900007, 24.979454912245274, 69.48535904288292, 64.83582973480225, 66.77665919065475, 54.90895740687847, 53.803266137838364, 54.088178649544716, 58.56757968664169, 59.79222357273102, 48.96872095763683, 13.69424382224679, 4.62285378947854, 1.4859632262960076, 1.52999087003991, 5.052510034292936, 20.263550765812397, 22.113884277641773, 14.239313174039125, 9.467922504991293, 6.6237214487046, 5.6019477266818285, 1.4612738136202097, 2.424635882489383, 31.994568184018135, 60.74017010629177, 38.215385377407074, 19.96392734348774, 11.477652713656425, 16.242855414748192, 18.696896731853485, 12.462252080440521, 39.16585497558117, 33.182069063186646, 33.02684739232063, 35.890103951096535, 37.96402506530285, 4.616348063573241, 22.2199384868145, 6.932060178369284, 4.228398855775595, 0.6501619750633836, 0.7390794600360096, 0.5104647867847234, 0.7277601642999798, 0.164455501944758, 0.30076425173319876, 0.15701737138442695, 0.21439019590616226, 0.20565670594805852, 0.14012093975907192, 0.20020628435304388, 0.19733806169824675, 0.043379756243666634, 0.08027035131817684, 0.17848282033810392, 0.05099913782032672, 0.0258557960842154, 0.07162860565586016, 0.11243424494750798, 0.03442588924372103, 0.03264598533860408, 0.013368765303312102, 0.13408561673713848, 0.14988003327744082, 0.021820789261255413, 0.030547583191946615, 0.047882061917334795, 0.06454320304328576, 0.062105682081892155, 5.272109275683761, 8.363404422998428, 19.686122350394726, 16.385693550109863, 20.25245726108551, 24.847185909748077, 25.635001435875893, 23.401241898536682, 21.39798179268837, 12.685167118906975, 33.334296494722366, 32.991433292627335, 31.036328002810478, 19.674939550459385, 42.63957537710667, 51.19110390543938, 28.322665616869926, 29.21091355383396, 37.50490330159664, 48.26906070113182, 67.49668255448341, 57.335636392235756, 56.23756751418114, 48.73751476407051, 61.35097973048687, 30.562761314213276, 16.40056975185871, 8.114765714854002, 0.306692230515182, 3.4544364362955093, 23.812680020928383, 48.207914382219315, 53.312362879514694, 53.22233811020851, 52.73109287023544, 54.9311938136816, 53.5017067193985, 59.10622738301754, 55.78664191067219, 52.33526811003685, 40.25841794908047, 7.744015334174037, 1.8444374157115817, 28.504970334470272, 31.214481443166733, 47.77952156960964, 22.607094012200832, 12.884451225399971, 21.501410342752934, 24.774229824543, 31.893284618854523, 24.28785402327776, 28.487185388803482, 29.562003314495087, 40.09048216044903, 23.472085297107697, 41.635771840810776, 32.93884411454201, 28.4719805046916, 46.284301802515984, 79.51935142278671, 16.11826580017805, 0.32554946083109826, 0.07388587007881142, 0.1334241998847574, 0.028104089797125198, 0.038245404211920686, 0.08890992248780094, 0.09089947197935544, 0.05935130116995424, 0.026629464628058486, 0.06717761949403211, 0.07412444829242304, 0.2597399608930573, 0.17045221844455227, 0.11935435642953962, 0.15611591428751126, 0.1318659124081023, 0.16060970752732828, 0.11027081025531515, 0.15360776684246957, 0.19971155386883765, 0.2050440778839402, 0.30464126088190824, 0.2961600269190967, 0.65629419288598, 0.3143828990869224, 38.082343116402626, 95.21162018179893, 73.17357033491135, 39.7197512537241, 47.70581312477589, 70.56340679526329, 36.27608723938465, 46.85001164674759, 45.98650798201561, 35.58270424604416, 41.93479299545288, 54.20241191983223, 18.20081055164337, 15.535648763179779, 23.064756654202938, 38.014854937791824, 68.54569986462593, 59.6869046241045, 7.300237622112036, 3.906692680902779, 28.423905484378338, 72.7930435538292, 71.77134677767754, 68.99795919656754, 60.98727844655514, 60.490645095705986, 62.141496911644936, 65.26595905423164, 59.958544448018074, 48.7594585865736, 12.292849570512772, 3.5008300468325615, 1.0076426365412772, 1.9311180082149804, 5.7260979898273945, 17.488367781043053, 22.300332672894, 10.46843446791172, 5.736997704952955, 2.9280361952260137, 1.7591745033860207, 2.5989610282704234, 2.304612910374999, 31.82747595012188, 68.83795738220215, 35.53525619208813, 18.058080710470676, 11.853349953889847, 38.86431075632572, 20.13152875006199, 19.704745151102543, 53.759807869791985, 36.24925687909126, 38.41929383575916, 36.2985934317112, 33.72232407331467, 4.331221813336015, 32.38004229962826, 8.042448945343494, 4.195887325331569, 2.144220666959882, 4.537304705008864, 5.363190388306975, 4.391102800145745, 1.8317333911545575, 0.9659750224091113, 0.6627129390835762, 0.9283496788702905, 2.91740199085325, 0.4434660100378096, 0.20285291655454785, 0.12905148061690852, 0.1468177538481541, 0.31370481359772384, 0.7469249109271914, 0.1669266607495956, 0.2808986505260691, 0.23606899747392163, 0.23208088881801814, 0.1378276143805124, 0.15259993029758334, 0.16363032278604805, 0.5077921051997691, 1.102823729161173, 0.4416451952420175, 0.09621237360988744, 0.31003317155409604, 0.1446872705128044, 0.29176351439673454, 8.006832506507635, 12.295466680079699, 26.525597646832466, 15.956403985619545, 21.219594664871693, 29.232276007533073, 29.58825420588255, 26.03239171206951, 32.124114632606506, 21.73348668962717, 27.92049139738083, 35.95474988222122, 37.8296110779047, 26.36762112379074, 35.863512977957726, 47.49330572783947, 28.79781112074852, 31.159730181097984, 41.75997957587242, 51.513812988996506, 67.75710538029671, 54.04237970709801, 55.01553788781166, 49.696473106741905, 62.96356379985809, 35.06270594894886, 23.37288971990347, 12.767573297023773, 0.9205700713209808, 2.6579466881230474, 23.46163395792246, 49.61343236267567, 55.57830289006233, 59.44891199469566, 57.4729610234499, 61.06901966035366, 55.54402492940426, 64.9928905069828, 61.73097833991051, 56.66787922382355, 45.722422152757645, 9.754278939217329, 1.3241016492247581, 26.697494722902775, 40.62653839588165, 50.45071363449097, 18.332963660359383, 14.065922778099775, 19.784673862159252, 30.044657215476036, 44.655154421925545, 40.71384631097317, 42.21778281033039, 50.15133909881115, 43.48396986722946, 41.25324636697769, 57.59093329310417, 43.75957287847996, 46.243742778897285, 52.23944865167141, 96.23581722378731, 29.469863958656788, 0.45601296646054834, 0.17895169439725578, 0.19725044374354184, 0.1032604016654659, 0.12006396835204214, 0.1975658565061167, 0.24351693922653794, 0.20431156328413635, 0.09912010078551248, 0.15569565090117976], [0.07557133940281346, 0.02937349443527637, 0.025614982150727883, 0.0459377055085497, 0.08480285498080775, 0.07299746735952795, 0.07421100497595035, 0.04475968707993161, 0.02095715572068002, 0.03378972025529947, 0.09093060507439077, 0.08769959837081842, 0.23120666854083538, 0.3091892902739346, 0.13843013439327478, 2.55177088547498, 68.61973509192467, 59.76443186402321, 46.051735281944275, 24.73241686820984, 46.89045287668705, 39.05219167470932, 29.075359627604485, 35.95424450933933, 24.111057110130787, 23.733883649110794, 35.47316752374172, 36.17237560451031, 16.409706361591816, 29.886296913027763, 45.543417558074, 57.0624690502882, 60.7867594063282, 20.86293250322342, 2.346656466834247, 9.467997550964355, 44.727453142404556, 61.91883645951748, 63.551985025405884, 58.79233382642269, 52.00874783098698, 52.74721160531044, 53.88735182583332, 59.98409807682037, 39.01417091488838, 28.43766264617443, 22.156082913279533, 5.279626697301865, 5.980015564709902, 1.239478646311909, 3.5932831233367324, 3.490264951251447, 2.702105068601668, 0.6394780171103776, 2.719178977422416, 2.922400622628629, 11.21977100148797, 34.28810991346836, 47.97814831137657, 22.43185881525278, 9.62829289957881, 15.110841058194637, 22.85139810293913, 22.1483351290226, 10.415772143751383, 27.606567442417145, 30.63136663287878, 29.780729077756405, 26.52384404093027, 30.311815179884434, 5.93133257701993, 10.642751064151525, 13.192605189979076, 6.820434043183923, 2.78384224511683, 0.11540535153471865, 0.22791364055592567, 0.20709310309030116, 0.07025529848760925, 0.1586989444331266, 0.4777833045227453, 0.07639403236680664, 0.11654952060780488, 0.0642802898073569, 0.2179079462075606, 0.8037587581202388, 0.06591288853087462, 0.23462281882530078, 0.18511898611905053, 0.29413678392302245, 0.05355498680728488, 0.053049925627419725, 0.12271545419935137, 0.18163515196647495, 0.1344223736668937, 0.11428444136981852, 0.15033511823276058, 0.03701038513099775, 0.07981117712915875, 0.03487376423436217, 0.054817316922708414, 0.08115590419038199, 0.10176325973588973, 0.24530720722395927, 4.444951135665178, 2.915884447284043, 12.129082158207893, 10.778618473559618, 1.6164145013317466, 23.961073458194733, 21.308787278831005, 24.455605521798134, 25.15277501195669, 27.882210351526737, 10.528103616088629, 14.48409128934145, 19.572574943304062, 10.856428798288107, 5.146980090066791, 12.965825758874416, 32.647046372294426, 31.733584888279438, 29.212435372173786, 29.69830010086298, 32.5118800252676, 45.152737721800804, 53.08321997523308, 42.647505551576614, 23.29992413520813, 8.031146451830864, 2.914229636080563, 2.635659221559763, 0.4839596652891487, 16.784687340259552, 39.67346973717213, 48.83315563201904, 44.96036544442177, 46.49317279458046, 48.35978463292122, 49.73960839211941, 53.241515681147575, 53.89794185757637, 52.16472186148167, 51.58372163772583, 29.093093276023865, 2.466897452250123, 10.008220262825489, 45.97146458923817, 29.010233022272587, 23.63265138119459, 7.0861205365508795, 25.410986356437206, 16.650885120034218, 32.01158367097378, 33.120257779955864, 36.85631610453129, 39.463333413004875, 38.5675922781229, 29.866224490106106, 38.24746325612068, 37.229805663228035, 27.227336391806602, 31.85122087597847, 58.417772725224495, 44.64241370558739, 1.4870690857060254, 0.09562316030496731, 0.1357002480654046, 0.08392284595174715, 0.07493698125472292, 0.08138258577673696, 0.11000121769029647, 0.06773262721253559, 0.03835585433989763, 0.06629593321122229, 0.04242911330948118, 0.04720097815152258, 0.050496870826464146, 0.047474960520048626, 0.026921019198198337, 0.09031883048010059, 0.044928603601874784, 0.11945370773901232, 0.07270115005667321, 0.10348206633352675, 0.019381665260880254, 0.07957837282447144, 0.16730116331018507, 0.34300400235224515, 0.5382018734235317, 0.16437159472843632, 5.109933977946639, 71.04832157492638, 73.80679115653038, 34.68616895377636, 31.064153909683228, 43.186100050807, 28.57234261929989, 33.71768832206726, 33.02214324474335, 29.018894657492638, 19.929655082523823, 30.9547121822834, 36.91209711134434, 28.384961374104023, 32.225496992468834, 50.36522202193737, 62.40823119878769, 68.39211210608482, 28.558826744556427, 4.7353804763406515, 9.06120277941227, 46.96935184299946, 65.81958174705505, 68.26856553554535, 61.55136577785015, 53.23241896927357, 58.18085923790932, 58.03848847746849, 62.32792630791664, 46.870785132050514, 32.406941056251526, 18.305483534932137, 7.625216608867049, 14.150890968739986, 8.072442635893822, 8.00119360908866, 8.945226352661848, 7.95354369096458, 2.35909937415272, 4.843563046306372, 2.5883614970371127, 12.56077604368329, 40.5921084433794, 51.97351232171059, 39.01385933160782, 19.416146837174892, 24.10306803882122, 15.951078571379185, 24.918067306280136, 7.768104141578078, 19.1227949783206, 30.99220287054777, 32.952861562371254, 33.47363501787186, 45.74217349290848, 14.676035139709711, 11.254347246140242, 16.498851478099823, 5.052409339696169, 1.7995646735653281, 0.12286391342058778, 1.14328847033903, 0.15331913076806813, 0.04504414486291353, 0.12606159027200192, 0.2994133054744452, 0.025731349051056895, 0.11589577756240033, 0.09815694153076038, 0.2763973764376715, 0.15303754509659484, 0.2121958284988068, 0.274421809008345, 0.11615217474172823, 0.21246220014290884, 0.023907367140054703, 0.0944461883045733, 0.14560790470568463, 0.16234559094300494, 0.04704754283011425, 0.271147572202608, 0.26106451638042927, 0.17017858859617263, 0.08974995944299735, 0.0856948719592765, 0.034477123408578336, 0.07014349394012243, 0.08279628804302774, 0.24168062838725746, 2.521800468675792, 4.071443052962422, 19.10173460841179, 16.13217495381832, 13.76866852864623, 26.445642337203026, 25.024516694247723, 31.13430954515934, 27.300571762025356, 16.1825355514884, 9.126310385763645, 20.75539257377386, 28.577552139759064, 20.79707633703947, 11.157153211534023, 27.16605708003044, 46.76046945154667, 39.08111572265625, 36.140920892357826, 34.02797967195511, 30.022627897560596, 40.22550031542778, 51.02103643119335, 41.821046099066734, 19.04028430581093, 8.333785012364388, 4.718842813745141, 1.876929709687829, 1.1564821936190128, 21.15899171680212, 45.457705557346344, 51.60167567431927, 49.79450784623623, 51.71417623758316, 51.18317753076553, 54.86703425645828, 56.32142521440983, 56.96374274790287, 56.78337402641773, 57.64703348278999, 31.221163384616375, 2.444298639893532, 11.23587453737855, 53.0553712695837, 33.566562831401825, 24.062144234776497, 4.718484207987785, 24.09080419689417, 22.071041576564312, 30.41611958295107, 30.079231560230255, 41.165661066770554, 30.41672945022583, 44.63175147771835, 35.40262810885906, 29.475210271775723, 47.05105505883694, 24.82181467115879, 32.99399435520172, 64.43911582231522, 47.03906290233135, 2.1981977205723524, 0.11745035430067219, 0.16211083478992805, 0.02430083157378249, 0.0539936369023053, 0.19209953810786828, 0.04506448341999203, 0.013697046906600008, 0.08268216799478978, 0.04075894335983321, 0.045207877483335324, 0.32658508338499814, 0.1351913425605744, 0.09121373441303149, 0.10242832795483992, 0.18369891622569412, 0.24154788785381243, 0.24347398371901363, 0.21720133256167173, 0.14739397214725614, 0.147641790099442, 0.1635968519258313, 0.2772416139487177, 0.6739584950264543, 0.6066164304502308, 0.2706853923154995, 7.68789092078805, 89.65114295482635, 76.55976623296738, 65.12471303343773, 34.2174869030714, 70.61553999781609, 55.44567100703716, 45.15951655805111, 49.5028430968523, 34.117666259408, 35.24406261742115, 53.757330402731895, 49.604932218790054, 23.123645894229412, 38.6578032374382, 54.339911341667175, 67.87709534168243, 71.60348698496819, 29.9151848629117, 5.221449444070458, 14.082567784935236, 52.35779330134392, 72.68595770001411, 74.23890396952629, 68.86678263545036, 59.11193087697029, 63.46811592578888, 63.80224719643593, 68.23344022035599, 46.99998199939728, 37.6793747395277, 26.958806701004505, 13.01108418032527, 11.682451274245977, 5.045226300135255, 5.685334727168083, 7.25054626353085, 5.869250083342195, 1.692816645372659, 4.600202729925513, 6.78158207796514, 16.178389973938465, 44.28219683468342, 58.24479080736637, 30.125505477190018, 15.209876094013453, 21.901321783661842, 31.574487425386906, 39.3261493742466, 15.445907078683376, 38.16217303276062, 34.881258085370064, 36.569138914346695, 35.021128579974174, 39.97599810361862, 9.268746692687273, 21.960482709109783, 32.50199295580387, 12.418927755206823, 4.075898313894868, 0.93138167867437, 2.4203698989003897, 0.7823854393791407, 0.1758200241602026, 0.45405705110169947, 0.9216043876949698, 0.258321983856149, 0.2564743923721835, 0.468413868220523, 0.8798731269780546, 1.1362796276807785, 0.7549363060388714, 0.6366220547351986, 0.27970714727416635, 0.7051592145580798, 0.10985796092427336, 0.16719478386221454, 0.3702958597568795, 0.32889485475607216, 0.5254818184766918, 0.6118916161358356, 0.5881563085131347, 0.4349739704048261, 0.19228321965783834, 0.14368315954925492, 0.0974657793994993, 0.22781318344641477, 0.17557946441229433, 0.4038815450621769, 7.625235132873058, 17.586991488933563, 34.93600934743881, 22.10205551236868, 10.22101454436779, 28.053222075104713, 28.676776215434074, 35.977537259459496, 30.003077946603298, 32.35703453421593, 14.81316028162837, 15.793171394616365, 24.8514511808753, 16.770367808640003, 8.166113309562206, 17.40015361458063, 42.04663999378681, 41.974379271268845, 38.829952999949455, 36.3082031160593, 36.110811308026314, 49.67321835458279, 59.5456700026989, 47.84454368054867, 27.488180994987488, 13.033755663782358, 8.115412630140781, 4.344482151791453, 1.335013119969517, 19.830011129379272, 45.240007638931274, 58.98544706404209, 51.69555723667145, 54.17568415403366, 57.98971809446812, 56.4419661462307, 61.348240077495575, 60.74663735926151, 61.47006154060364, 60.05996860563755, 35.53044185042381, 3.836952648125589, 12.963828966021538, 49.401255548000336, 34.60065834224224, 31.84123881161213, 10.305807944387197, 34.27617475390434, 23.765494152903557, 40.31050555408001, 43.23444485664368, 47.96121262013912, 52.993229404091835, 56.290327683091164, 41.41951024532318, 49.2028833925724, 55.531759187579155, 35.495552122592926, 49.3570639193058, 70.64619675278664, 74.87106084823608, 5.92611450701952, 0.15966149512678385, 0.4522664862452075, 0.09207336406689137, 0.13384913880145177, 0.5101606843527406, 0.19597964943386614, 0.2539027913007885, 0.1499711096403189, 0.1423184687155299, 0.2029886850505136], [0.024368051599594764, 0.027447188913356513, 0.028901468103867956, 0.050273380475118756, 0.026556695192994084, 0.08068884097156115, 0.11291471135336906, 0.08319857661263086, 0.04579886081046425, 0.016555761721974704, 0.049503584086778574, 0.06293775208177976, 0.05532326496904716, 0.08766784929321148, 0.4995315265841782, 0.09136332912021317, 42.73110866546631, 70.19506216049194, 51.9278159737587, 33.517921641469, 33.53579208254814, 41.76498010754585, 27.134587168693542, 33.369007632136345, 32.10068888962269, 22.872295081615448, 30.42767096310854, 39.583874344825745, 20.752394534647465, 17.235692739486694, 32.06930257380009, 47.56520926952362, 60.55833466351032, 51.603431180119514, 7.798967035487294, 1.759589274879545, 17.903218120336533, 53.343946784734726, 61.63255602121353, 54.98111553490162, 57.306678146123886, 53.910792768001556, 50.0929020345211, 44.54365700483322, 43.608151003718376, 41.84800565242767, 20.160956270992756, 3.410804090090096, 0.7751550804823637, 3.6305128131061792, 5.183353638276458, 6.051615597680211, 7.483568759635091, 18.925201781094074, 17.465266920626163, 30.020568408071995, 38.44478286802769, 39.338179528713226, 22.87087395787239, 9.107995368540287, 14.750523492693901, 13.26961850747466, 24.592088498175144, 6.849670149385929, 24.465298801660538, 40.634555965662, 24.579302184283733, 29.11389146000147, 26.083029694855213, 18.565997555851936, 13.687003310769796, 11.159814018756151, 8.309952691197395, 1.9281611731275916, 0.585440166760236, 0.03488367561658379, 0.05518743710126728, 0.04998565353162121, 0.073739318177104, 0.09493940480751917, 0.27858683082740754, 0.24969407182652503, 0.07558322860859334, 0.2338248468004167, 0.16907792421989143, 0.21072426839964464, 0.42042104818392545, 0.09812463584239595, 0.03976648782554548, 0.03305428159364965, 0.025001352187246084, 0.061970611204742454, 0.11557746300240979, 0.14704094734042883, 0.1483249370357953, 0.029744074745394755, 0.09501168999122456, 0.11496069375425577, 0.10979176135151647, 0.16354644525563344, 0.0922868873749394, 0.1013343503291253, 0.11579525365959853, 0.1634660706622526, 0.3819203266175464, 0.883101528743282, 2.1877603931352496, 19.572772532701492, 3.674162020906806, 13.076360877603292, 25.155222080647945, 28.616469651460648, 31.776938661932945, 29.632234945893288, 28.93750112503767, 15.521014798432589, 2.995938789099455, 4.829929377883673, 18.455539382994175, 9.445164576172829, 8.630309700965881, 25.220721065998077, 26.610901169478893, 32.346904277801514, 26.634002029895782, 11.256818063557148, 7.32459906488657, 6.589857190847397, 4.0572550892829895, 0.20369326521176845, 3.454883862286806, 1.5159334056079388, 3.456811783835292, 20.213820934295654, 50.29822401702404, 52.43883155286312, 50.182136446237564, 54.80510137975216, 51.43550679087639, 52.23002515733242, 49.54321973025799, 57.29251250624657, 53.90658259391785, 59.336141645908356, 22.425883635878563, 3.332555601373315, 12.269489374011755, 56.21772117912769, 61.4436149597168, 62.21897095441818, 36.92732289433479, 25.823938697576523, 23.051653057336807, 34.336253330111504, 29.535298347473145, 30.849353335797787, 40.81156946718693, 30.249378830194473, 23.545609451830387, 57.75804452598095, 51.119603142142296, 22.310130447149277, 31.931126788258553, 58.42165991663933, 13.51501313969493, 0.430856000748463, 0.21740334515925497, 0.0764797355805058, 0.18843620811821893, 0.06943333282833919, 0.18648127239430323, 0.041167632953147404, 0.02109899498464074, 0.041552840993972495, 0.005808063951917575, 0.04700049066741485, 0.0823057878005784, 0.02374185893131653, 0.005691087098966818, 0.1113981771050021, 0.02005879709031433, 0.0308418966960744, 0.12413321601343341, 0.04827524804568384, 0.03549570625182241, 0.028814523648179602, 0.05858999124029651, 0.05708789547497872, 0.11639028540230356, 0.13597515440778807, 0.5208273651078343, 0.052876444897265173, 48.00274819135666, 81.5451443195343, 52.36456833779812, 28.409884236752987, 45.74402019381523, 27.56119977682829, 32.355678007006645, 27.532391622662544, 35.989806801080704, 20.024376399815083, 20.93243647366762, 33.855563923716545, 27.597446031868458, 27.777953445911407, 39.464028775691986, 52.14769497513771, 66.57624274492264, 61.509625017642975, 17.46577799320221, 1.5156519832089543, 15.944620817899704, 57.0356272906065, 68.17988589406013, 60.899715945124626, 59.58492949604988, 61.66935324668884, 55.41096366941929, 50.98254829645157, 50.1338904350996, 44.598009288311005, 25.031449422240257, 7.237717201933265, 2.1778087271377444, 6.367891151458025, 9.076185375452042, 10.077982619404793, 8.749116025865078, 17.22576007246971, 3.2457205234095454, 13.75759782269597, 40.26702828705311, 42.40603610873222, 39.332981407642365, 14.944603778421879, 17.60394047945738, 12.789822053164244, 19.90212745964527, 16.308365799486637, 23.11981000006199, 39.973847419023514, 28.447118438780308, 32.65262447297573, 37.93524160981178, 34.47105869650841, 11.552046071738005, 18.816255927085876, 13.532333560287952, 1.3494345336221159, 0.6019672611728311, 0.0855979994230438, 0.048286135352100246, 0.08343669469468296, 0.02820566569425864, 0.18876025947974995, 0.11107406637165695, 0.1007829123409465, 0.11519326799316332, 0.17120318283559754, 0.39988202217500657, 0.17615692951949313, 0.41646246216259897, 0.19915161828976125, 0.2807041781488806, 0.052222891099518165, 0.11142184419441037, 0.29090574011206627, 0.12375230129691772, 0.12203165417304263, 0.1211328168574255, 0.16222162259509787, 0.11726681375876069, 0.0341052925796248, 0.09314671740867198, 0.11218474232009612, 0.013073304253339302, 0.07839547106414102, 0.2748507109936327, 0.391855962225236, 0.4772930417675525, 0.9424522065091878, 10.01189086586237, 24.449584744870663, 9.551222585141659, 26.244861111044884, 25.888955108821392, 35.52384540438652, 32.78888896107674, 29.632248245179653, 19.741734266281128, 17.818640358746052, 6.491547916084528, 13.048743959516287, 18.987345546483994, 14.019004795700312, 20.46750672161579, 39.43590268492699, 33.63679826259613, 39.436940029263496, 35.405607149004936, 15.57245833799243, 5.6557514145970345, 3.2782410783693194, 8.337456565350294, 1.314768756274134, 9.722602888941765, 5.226152166724205, 7.861325964331627, 25.09880270808935, 54.61695447564125, 57.00005739927292, 52.99979545176029, 56.52565285563469, 54.40824307501316, 57.00562410056591, 54.619188755750656, 61.01241409778595, 57.26667009294033, 62.336643040180206, 24.866836555302143, 4.445673571899533, 17.022417783737183, 59.27977167069912, 59.932185262441635, 64.15252760052681, 22.21897143870592, 21.0773815959692, 29.513508416712284, 30.025394149124622, 28.038197681307793, 31.55015353113413, 34.919487833976746, 38.01376819610596, 17.61030323803425, 53.26013848185539, 55.385843217372894, 16.688324511051178, 39.79945957660675, 66.83291897177696, 18.023470267653465, 0.403229464427568, 0.1736862605321221, 0.18075432657497004, 0.08362322609173134, 0.027357346370990854, 0.12515930196968839, 0.05642283838824369, 0.09786126247490756, 0.07203995584859513, 0.04840157642320264, 0.049248641516896896, 0.16031923092668876, 0.12057552332407795, 0.20226708002155647, 0.27355447586160153, 0.1305906503694132, 0.21299464657204226, 0.208050740766339, 0.1525469112675637, 0.2373395542963408, 0.13927259074989706, 0.1677171073970385, 0.1331246690824628, 0.4264588945079595, 0.1972398310317658, 0.6905538670253009, 0.38812156417407095, 64.31241542100906, 88.82965743541718, 70.57215392589569, 43.40510129928589, 48.98727536201477, 60.00562012195587, 45.2895075827837, 45.71128495037556, 41.74189254641533, 33.15738558769226, 44.11891959607601, 57.821626514196396, 28.55930171906948, 25.428511016070843, 37.367780059576035, 58.712078332901, 69.74356278777122, 62.913288697600365, 16.161032505333424, 2.4314170936122537, 22.208409905433655, 62.34415143728256, 70.26918858289719, 65.48858910799026, 67.28468433022499, 70.81857830286026, 59.603875279426575, 56.18638426065445, 52.04355776309967, 49.57293413579464, 26.060681194067, 7.926785526797175, 0.9683078003581613, 6.585779059678316, 11.759741976857185, 14.425102304667234, 14.310946930199862, 34.843047335743904, 33.85393001139164, 42.039963752031326, 47.56232522428036, 46.734938621520996, 31.240422651171684, 13.049855399876833, 19.34254288673401, 18.26129760593176, 37.484600991010666, 15.510572958737612, 32.903965786099434, 51.68215915560722, 28.364666663110256, 36.68048053979874, 32.57476665079594, 27.32826467603445, 16.578850485384464, 37.70717404782772, 31.75560850650072, 4.619391700252891, 1.6688347072340548, 0.2679215156240389, 0.38366514549124986, 0.2989742805948481, 0.19163597782608122, 0.7477570662740618, 0.535869748564437, 0.5938332038931549, 0.16609156649792567, 0.5226188502274454, 0.7039632287342101, 0.45771984674502164, 0.7889922754839063, 0.1944848452694714, 0.9784189984202385, 0.1646033674478531, 0.10367885421146639, 0.6440985691733658, 0.3010869078570977, 0.1998959033517167, 0.4141808330314234, 0.34298886253964156, 0.4374071164056659, 0.12861342052929103, 0.21766299294540659, 0.1936661227955483, 0.32175744243431836, 0.20565369282849133, 0.2714146859943867, 0.5635040625929832, 1.6692547034472227, 5.5153152253478765, 18.30313716083765, 43.996315374970436, 9.573459941893816, 20.93883153051138, 29.496829211711884, 39.33869630098343, 38.088935762643814, 35.91336630284786, 37.065384685993195, 21.575928144156933, 5.07767085917294, 7.194271283224225, 27.561323270201683, 14.593562465161085, 12.534665744751692, 34.10076476633549, 37.0465224981308, 44.004177153110504, 35.144876539707184, 17.306612133979797, 8.828452918678522, 11.444662883877754, 11.560697257518768, 0.42059384984895587, 5.916508147493005, 3.7062520114704967, 6.972423987463117, 27.31160257011652, 57.344896495342255, 60.63794419169426, 59.58405174314976, 60.88510572910309, 60.64354509115219, 63.03659588098526, 56.33195824921131, 66.37158572673798, 63.94638106226921, 69.53980252146721, 30.652926675975323, 5.329130915924907, 15.726900100708008, 66.63919016718864, 71.24425426125526, 72.03896641731262, 41.647399216890335, 36.117810532450676, 33.13070721924305, 42.51558043062687, 38.785199001431465, 38.04618425667286, 54.687471091747284, 44.100030809640884, 29.845625795423985, 76.03659510612488, 65.82706734538078, 31.49823311716318, 49.45167884230614, 79.86317977309227, 35.951561853289604, 0.7095534412655979, 0.4607006086735055, 0.34844747744500637, 0.37096821586601436, 0.1296288863522932, 0.3591929149115458, 0.21668292756658047, 0.22841721744043753, 0.20547158463159576, 0.14892184641212225, 0.22377926943590865], [0.019115145187242888, 0.05171529919607565, 0.04618027276592329, 0.0614700214646291, 0.0625495272106491, 0.1364761040895246, 0.05056926733232103, 0.09637206894694827, 0.07885677521699108, 0.061869397104601376, 0.10736942844232544, 0.05174175305000972, 0.10248715057969093, 0.04690870555350557, 0.5447089648805559, 0.08920459222281352, 5.787523118779063, 77.57238149642944, 50.99044807255268, 39.52551327645779, 26.934957280755043, 42.56098039448261, 32.065802961587906, 35.16990199685097, 30.666444450616837, 27.888578809797764, 31.361744441092014, 40.32723605632782, 36.69024221599102, 18.493482246994972, 19.64498195797205, 57.76502475142479, 62.45048873126507, 47.27311514317989, 35.84405802190304, 9.162831176072359, 12.92415814474225, 44.25513468682766, 63.75329062342644, 57.42744706571102, 49.26947481930256, 50.785145089030266, 58.28994758427143, 54.33319330215454, 45.60437388718128, 46.647007539868355, 37.85237565636635, 16.59735929220915, 15.687582660466433, 13.152745328843594, 9.556493852287531, 8.322646860033274, 11.025065649300814, 2.147718616761267, 10.477940607815981, 41.75051428377628, 31.42878044396639, 19.5405787602067, 7.856355831027031, 24.907211288809776, 27.293943017721176, 25.368305146694183, 23.89571886509657, 5.169391762465239, 14.381241258233786, 24.532403200864792, 24.936260730028152, 31.382687017321587, 25.967506393790245, 14.282933883368969, 21.15145482122898, 12.401403095573187, 4.758480386808515, 0.4381877073319629, 0.18569564970675856, 0.15867184119997546, 0.3927792829927057, 0.049998214381048456, 0.08433595503447577, 0.07217646649223752, 0.6022356811445206, 1.1623013438656926, 0.8437237667385489, 1.1038729478605092, 0.602769908728078, 0.3728187462547794, 0.14376970881130546, 0.1138552647898905, 0.0881204851611983, 0.05662652452883776, 0.09820132196182385, 0.17597458383534104, 0.19886004331056029, 0.6093301379587501, 0.5572369520086795, 0.2718034229474142, 0.32137678004801273, 0.23745139595121145, 0.15197358734440058, 0.035090248711640015, 0.15788848948432133, 0.04705425555584952, 0.11515464662807062, 0.5744300200603902, 0.22851258341688663, 1.4806318748742342, 5.080472258850932, 16.043552309274673, 15.196571107953787, 7.542224787175655, 26.636823378503323, 29.413737170398235, 30.88854443281889, 32.03196577727795, 27.32901893556118, 20.56170366704464, 15.443104729056358, 16.190593019127846, 19.707817286252975, 28.42136152088642, 15.56326188147068, 9.350505955517292, 20.275732912123203, 25.090426057577133, 33.80239337682724, 41.06767952442169, 17.11859442293644, 1.3834880688227713, 2.6132933842018247, 1.280805584974587, 0.217152098484803, 0.2388527340372093, 8.42846168205142, 28.370807133615017, 54.45448659360409, 51.832414492964745, 43.45984876155853, 46.60834081470966, 51.02272354066372, 46.87124490737915, 52.21017122268677, 48.75608816742897, 56.43224626779556, 46.99927143752575, 17.792805545032024, 4.192317416891456, 29.59833886474371, 67.81724095344543, 52.24791459739208, 50.0772924721241, 59.62444357573986, 20.839723348617554, 19.56638317555189, 31.330909095704556, 27.92618729174137, 32.554973512887955, 36.8077889084816, 30.631480626761913, 44.03051353991032, 72.20810294151306, 36.754337176680565, 33.28632026910782, 47.84463867545128, 47.66901969909668, 4.190354347229004, 0.07131035046768375, 0.18251452274853364, 0.028373639688652474, 0.025096152276091743, 0.04412598202179652, 0.03196711317286827, 0.017833981219155248, 0.049032242386601865, 0.021887178081669845, 0.024602147241239436, 0.024936321497079916, 0.04253842053003609, 0.04136721501708962, 0.06798613743740134, 0.07926722741103731, 0.06930578732863069, 0.07505823334213346, 0.07720600871834904, 0.08349148745764978, 0.07751956611173227, 0.02387762928265147, 0.09710725527838804, 0.10110129369422793, 0.12322444134042598, 0.0715932942694053, 0.779772485839203, 0.25746046914719045, 9.501013979315758, 84.08936619758606, 61.39733724296093, 32.72843800485134, 34.15383271872997, 48.553821220993996, 37.05256037414074, 32.603424713015556, 32.44574837386608, 37.653832510113716, 26.98082461953163, 30.153707563877106, 39.38313111662865, 27.070041932165623, 18.32524247467518, 63.09456557035446, 73.56092154979706, 59.10877324640751, 42.77902789413929, 13.951873797923326, 11.7062664963305, 49.83280599117279, 66.30834951996803, 62.608457654714584, 58.23230467736721, 64.68156561255455, 61.475126668810844, 57.173187509179115, 49.189986884593964, 51.50035411119461, 41.49607993662357, 16.708712317049503, 8.085872065275908, 17.006460539996624, 11.007043216377497, 11.642469819635153, 8.43538586050272, 3.3150071930140257, 14.134110119193792, 42.435279339551926, 41.20747782289982, 35.11206530034542, 16.205754205584526, 22.36796524375677, 28.275477848947048, 16.871039606630802, 27.498176358640194, 9.450029265135527, 14.51541680842638, 27.273256927728653, 26.641474328935146, 35.41077867150307, 30.644124448299408, 17.511687129735947, 16.410340927541256, 17.533116079866886, 10.329467374831438, 0.3561070648720488, 0.3703763382509351, 0.21008700103266165, 0.35090383782517165, 0.0598324577731546, 0.11491520010167733, 0.3228576318360865, 0.013099863863317296, 0.4877944610780105, 1.086955068167299, 0.6463731033727527, 0.3711408097296953, 0.19334561889991164, 0.6505233119241893, 0.32892053306568414, 0.6400741694960743, 0.055412459987564944, 0.08934251294704154, 0.1461920194560662, 0.22515817981911823, 0.6702562468126416, 0.3627775772474706, 0.24632751184981316, 0.51691974978894, 0.22232145391171798, 0.21881581546040252, 0.09946611971827224, 0.08111916045891121, 0.11597430420806631, 0.34319310158025473, 0.04927980429783929, 0.20354770036647096, 4.330335035920143, 7.956407787278295, 29.4252410531044, 17.577039822936058, 18.496132604777813, 33.16460520029068, 33.82460318505764, 32.601623609662056, 34.21475864946842, 22.01370645314455, 18.6864909902215, 17.400987669825554, 18.21100540459156, 21.03924874216318, 25.34135889261961, 16.56758029013872, 22.548641748726368, 36.70980356633663, 33.09689663350582, 39.17862229049206, 52.78373144567013, 25.74404988437891, 3.1725670862942934, 3.1590718729421496, 3.0301488284021616, 2.717947131022811, 1.1607649200595915, 8.71335994452238, 32.24414259195328, 57.573545426130295, 57.424886003136635, 48.074115961790085, 49.982970133423805, 55.48689879477024, 53.74925583600998, 55.72701171040535, 53.36785890161991, 60.60002222657204, 52.02621549367905, 19.271321408450603, 7.968423692509532, 39.428493082523346, 71.26516073942184, 56.462158262729645, 56.26464866101742, 53.59257124364376, 23.62422913312912, 23.057371750473976, 27.720882408320904, 29.429101645946503, 29.213685505092144, 31.609513945877552, 35.8631481975317, 30.93588039278984, 77.26982653141022, 35.820491686463356, 30.168180987238884, 55.964050590991974, 54.63988624513149, 5.577431442216039, 0.16827349551022053, 0.24052402091911063, 0.03702536538185086, 0.029356449158512987, 0.02024848261498846, 0.04906006179226097, 0.05752391465648543, 0.0014662997796222044, 0.015611247072229162, 0.03420353437832091, 0.0025053720446521766, 0.14182949729729444, 0.19569472409784794, 0.18420823733322322, 0.17573423188878223, 0.2193521655863151, 0.2974551933584735, 0.17938887875061482, 0.17250729957595468, 0.1210894383257255, 0.1645870550419204, 0.24392382911173627, 0.1775674257078208, 0.3014107811031863, 0.3063095494871959, 0.8564432873390615, 0.3870548604754731, 15.295934826135635, 100.99765330553055, 67.86474600434303, 55.402668714523315, 35.780548229813576, 57.15845189988613, 48.89140650629997, 55.500768050551414, 42.12787203490734, 37.61588774621487, 44.68877121806145, 59.074195101857185, 48.724492862820625, 26.63375124335289, 24.510248489677906, 66.79234474897385, 76.38872221112251, 60.467747524380684, 46.00172996520996, 15.838962737470865, 15.809430722147226, 56.47076100111008, 72.91167318820953, 69.96522009372711, 61.47670738399029, 65.75139060616493, 68.94749790430069, 64.28999662399292, 53.364458084106445, 54.91949804127216, 45.33021479845047, 23.033214546740055, 26.350506842136383, 27.79268905520439, 23.91102634370327, 19.94324505329132, 18.978902399539948, 10.987167432904243, 15.384429227560759, 52.51720234751701, 41.455916091799736, 28.384765684604645, 11.248899288475513, 32.26306177675724, 31.654362939298153, 36.763228699564934, 35.6838434189558, 9.293296225368977, 23.078878596425056, 32.58231304585934, 28.605081662535667, 38.405147194862366, 31.327572874724865, 18.61775267869234, 32.29619599878788, 33.20796847343445, 26.19790893048048, 2.5755948945879936, 0.9300388069823384, 0.5755127244628966, 0.6549257913138717, 0.20005420345114544, 0.30113678018096834, 0.690383113687858, 1.6849878779612482, 1.2369193648919463, 3.662488334812224, 2.20980538520962, 3.0362209025770426, 0.7701321656350046, 1.4981301734223962, 0.33359342138282955, 1.2995962891727686, 0.21945050015347078, 0.33600608410779387, 0.31119724502786994, 0.28101430681999773, 1.577379077207297, 0.6042859086301178, 0.831069911364466, 1.2839803146198392, 0.5937594047281891, 0.45672311272937804, 0.1892215636326, 0.24990837438963354, 0.22200191480806097, 0.5975944676902145, 2.0421061338856816, 0.34090016211848706, 7.552077658474445, 16.923592686653137, 43.68537425994873, 32.41413027048111, 12.449776399880648, 33.401773273944855, 35.20638383924961, 34.2577001452446, 41.89728140830994, 32.921965420246124, 27.43727322667837, 21.1215428262949, 21.413180977106094, 24.795271195471287, 37.29732804000378, 19.507421739399433, 15.459689889103174, 27.635415494441986, 34.66687738895416, 45.760762095451355, 54.85903948545456, 22.39923756569624, 2.2978257620707154, 3.9039841387420893, 5.123623693361878, 1.8854355532675982, 0.3624398703686893, 13.753545340150595, 34.698419496417046, 65.37294611334801, 60.99123403429985, 54.34861667454243, 54.81120005249977, 61.94795809686184, 56.35709770023823, 63.42309594154358, 55.78992113471031, 68.3433835208416, 58.648488745093346, 23.36190640926361, 8.35372444242239, 38.51361237466335, 78.26136812567711, 66.2204298377037, 63.71894046664238, 71.4211955666542, 29.136578142642975, 26.597592383623123, 39.035396575927734, 35.86467571556568, 42.23938465118408, 53.25582571327686, 42.71273285150528, 54.54634286463261, 91.18062928318977, 46.09834738075733, 50.30209980905056, 60.668004378676414, 78.01692724227905, 9.050347711890936, 0.35158257640432566, 0.47046528314240277, 0.21052345808129758, 0.24047017068369314, 0.14531585475197062, 0.15557864389847964, 0.24484191031660885, 0.17669442255282775, 0.07725852308794856, 0.12479618395445868, 0.17567879345733672], [0.023217841444420628, 0.018632389255799353, 0.02750380735960789, 0.11750070902053267, 0.030935672621126287, 0.03855454211588949, 0.09702168565127067, 0.07321883516851813, 0.02677105898328591, 0.12483572558267042, 0.13015548465773463, 0.044240313582122326, 0.00866945467350888, 0.17005451634759083, 0.09862904393230565, 0.6261254742275923, 0.5113563733175397, 55.51709957420826, 62.64099530875683, 51.79675340652466, 41.22789412736893, 29.75236739963293, 32.57613457739353, 33.10233414173126, 40.47491513192654, 20.503764376044273, 12.452380210161209, 28.74629158526659, 41.82506248354912, 27.42710307240486, 44.87914480268955, 41.953062415122986, 48.20437677204609, 60.45737788081169, 70.98558694124222, 15.655697621405125, 9.678838737308979, 48.34525801241398, 63.38124878704548, 59.40436698496342, 36.66786141693592, 33.5469026863575, 57.611490190029144, 50.512908697128296, 57.324814572930336, 45.71673385798931, 46.46887689828873, 23.161204978823662, 6.4384006429463625, 8.781050462275743, 10.637212861329317, 9.96022978797555, 6.486934013664722, 18.701673075556755, 34.96523357927799, 22.18037500977516, 15.18765203654766, 9.211647156625986, 27.492415867745876, 24.696373902261257, 16.922846026718616, 14.622510261833668, 14.638821836560965, 11.606857180595398, 29.02391418814659, 20.855013728141785, 29.86898884177208, 37.32353903353214, 17.47719258069992, 19.35146100819111, 13.26908178627491, 13.171801306307316, 2.2536837682127953, 0.14009238191647455, 0.23409568617353216, 0.13840947300195694, 0.15473709296202287, 0.051109558262396604, 0.2101380014210008, 0.3183687070850283, 0.7240373734384775, 1.6603262512944639, 0.8268757676705718, 4.528323411941528, 1.1225221096538007, 0.7407321932259947, 1.7467450140975416, 1.3370990892872214, 0.47157989989500493, 0.22338468435918912, 0.5343056574929506, 0.5852274969220161, 0.26824951521120965, 0.4522229073336348, 1.3139177206903696, 1.5907257422804832, 1.8664896511472762, 0.8113494445569813, 0.20644744945457205, 0.06159154814668, 0.06527084915433079, 0.07141385780414566, 0.6476073840167373, 0.25349980511236936, 0.6376902724150568, 2.654212201014161, 2.2590051451697946, 13.207000717520714, 19.911647848784924, 8.866216242313385, 19.82353437691927, 35.01980245113373, 31.693090461194515, 34.358113557100296, 32.398760095238686, 21.398570761084557, 14.277143944054842, 24.66300029307604, 15.116181671619415, 16.79374985396862, 23.900970183312893, 15.651855077594519, 11.415092870593071, 18.709859736263752, 24.556613601744175, 27.477811351418495, 44.33749906718731, 32.51546323299408, 7.098507871851325, 10.134641379117966, 12.923641372472048, 3.724230509251356, 9.167884904891253, 37.93233476579189, 44.35989126563072, 48.42352241277695, 51.777807623147964, 48.23254466056824, 51.612976267933846, 50.75804114341736, 53.47165413200855, 50.419334918260574, 54.236572086811066, 45.69575518369675, 27.269354537129402, 22.505196779966354, 51.74730286002159, 52.088676542043686, 48.71022842824459, 25.981400348246098, 44.01410602033138, 16.70842733234167, 27.91628122329712, 31.167320273816586, 32.46050678193569, 38.23279224336147, 48.48768197000027, 25.066939517855644, 77.68103286623955, 45.08650727570057, 30.691044330596924, 54.06422473490238, 53.15314382314682, 27.788628973066807, 0.7982855080626905, 0.22609082196140662, 0.2546083659399301, 0.06441041798098013, 0.12915934436023235, 0.08973692732979544, 0.09330290238722228, 0.09973505177185871, 0.06474544570664875, 0.021591870099655353, 0.020205499276926275, 0.22616736707277596, 0.03591351312934421, 0.05300539676682092, 0.03977293337811716, 0.1690025071729906, 0.11096734553575516, 0.08277640590677038, 0.07190110001829453, 0.1345635301549919, 0.03817196498857811, 0.058001230645459145, 0.11491824290715158, 0.06278841712628491, 0.052954952989239246, 0.06332594726700336, 0.027832191008201335, 0.6646848551463336, 0.42965550266671926, 61.09068229794502, 74.41896870732307, 55.577216148376465, 40.3083510696888, 30.92061471194029, 35.69978356361389, 40.44308803975582, 29.177859127521515, 30.546731874346733, 18.214421421289444, 26.533444225788116, 38.87573294341564, 33.3593675494194, 45.850631073117256, 51.84078924357891, 56.81120753288269, 68.90877038240433, 70.09368360042572, 17.632528245449066, 13.32803562283516, 54.96383786201477, 68.99311065673828, 62.134953662753105, 51.16146929562092, 46.572626531124115, 62.087285220623016, 54.51708443462849, 56.907760351896286, 49.555823653936386, 49.74172107875347, 22.10025630891323, 5.7684799656271935, 10.202712826430798, 8.380350563675165, 7.34582282602787, 2.8132146690040827, 17.65932820737362, 40.62985561788082, 29.16818294674158, 32.16009110212326, 17.429725527763367, 27.67985600978136, 23.827911503612995, 22.72719606757164, 14.272997416555882, 16.04553010314703, 13.213490769267082, 25.50732258707285, 23.69591798633337, 31.678193360567093, 43.651685267686844, 27.722178138792515, 16.024034656584263, 17.028533555567265, 16.420243196189404, 13.637731354683638, 0.6793881068006158, 0.734664275078103, 0.07278395889443345, 0.12731758615700528, 0.029185241255618166, 0.2706161350943148, 0.16619766392977908, 0.43683100200723857, 1.5881321439519525, 0.4453254461986944, 2.7245594887062907, 0.9053801489062607, 1.2712512351572514, 1.4531375002115965, 0.8984358434099704, 0.3958209010306746, 0.6752735807094723, 0.2488044000347145, 1.3437826931476593, 1.2085019960068166, 0.9104313841089606, 1.5830872021615505, 1.0350087680853903, 1.1631126003339887, 0.6332837557420135, 0.20932346465997398, 0.07554060706752352, 0.008632960489194375, 0.07812163341441192, 0.3055780887370929, 0.2841149998130277, 0.3792021068511531, 5.419248780235648, 11.968799158930779, 25.39675422012806, 19.785274229943752, 15.486126970499754, 34.43368770182133, 35.73611341416836, 37.03229986131191, 36.64485365152359, 26.610714979469776, 12.515154741704464, 15.02739468589425, 18.66814747452736, 19.47040982544422, 19.134300760924816, 21.85881156474352, 17.136185579001904, 22.14145179837942, 37.795956283807755, 38.68343286216259, 30.325253158807755, 51.63973443210125, 40.71154743432999, 11.568976063281298, 2.679097540676594, 1.6818842757493258, 7.996854241937399, 6.224275957792997, 45.00977419316769, 52.317538261413574, 56.78699903190136, 55.1641783118248, 53.19254390895367, 55.76850928366184, 54.99112419784069, 59.96848091483116, 55.246462896466255, 56.84363879263401, 51.3214673101902, 30.283312909305096, 28.970158472657204, 54.42626550793648, 54.44133549928665, 51.59375309944153, 28.33375722169876, 52.09865100681782, 22.479686848819256, 29.0051431953907, 26.16981703788042, 30.208732411265373, 30.151243396103382, 48.92921067774296, 24.276806116104126, 63.259066343307495, 55.11562831699848, 27.158917263150215, 56.76967956125736, 65.23168489336967, 32.839498445391655, 0.8075045852456242, 0.34588739450555295, 0.14986991038313136, 0.042646102447179146, 0.12974645738722757, 0.021049438073532656, 0.10243664743029512, 0.03350873572344426, 0.08788730236119591, 0.07361957264947705, 0.05693210754543543, 0.1506325413356535, 0.20804155297810212, 0.10061986991786398, 0.28210799500811845, 0.2603195485426113, 0.21676092728739604, 0.16359116707462817, 0.3023912769276649, 0.2682912239106372, 0.15240242995787412, 0.28556794684845954, 0.177825529826805, 0.2348318966687657, 0.17858235718449578, 0.319269941537641, 0.13424586126348004, 0.791304154554382, 1.219066260382533, 76.46243065595627, 84.87327933311462, 70.74477106332779, 55.6843513995409, 38.14315885305405, 45.08922033011913, 51.79521828889847, 52.528977915644646, 28.3900436013937, 20.76642908155918, 43.55792909860611, 60.535243302583694, 35.03513462841511, 54.777435064315796, 53.30622240900993, 57.803832069039345, 70.33036530017853, 80.28661385178566, 22.45754923671484, 14.109759125858545, 58.4623709321022, 71.58295288681984, 67.97817751765251, 46.406191661953926, 45.12068264186382, 66.20389312505722, 62.048379108309746, 64.86652448773384, 56.37084536254406, 56.07130743563175, 28.129816465079784, 14.980294313281775, 20.03104504197836, 19.85219433903694, 22.73060068488121, 16.82877067476511, 31.219780258834362, 46.57908238470554, 31.144869178533554, 22.540223300457, 13.198607917875051, 33.40370737016201, 34.7055821120739, 19.053444899618626, 24.77348506450653, 22.012260630726814, 19.93402484804392, 39.585736244916916, 28.358245007693768, 34.046199694275856, 43.619151413440704, 23.534776233136654, 27.128790579736233, 29.829163178801537, 31.10429685562849, 31.256529986858368, 3.271663631312549, 1.4425931847654283, 0.27272793115116656, 0.3393165080342442, 0.22118849126854911, 0.2635762112913653, 0.3065817692549899, 1.2869103136472404, 3.373545426875353, 3.6851412942633033, 5.094143925234675, 3.1724485801532865, 2.504609953612089, 1.9169173389673233, 2.9494594456627965, 0.6490058870986104, 0.7319027138873935, 1.0844450653530657, 2.056497149169445, 2.238774080760777, 2.6856607384979725, 5.1298468094319105, 9.468257836997509, 4.352436549961567, 1.9219276076182723, 1.1171749653294683, 0.195380394870881, 0.18569171632407233, 0.2554918185342103, 2.1998458821326494, 0.300222632358782, 1.530307203065604, 6.565589793026447, 28.45976036041975, 30.6469913944602, 42.00909800827503, 13.686935864388943, 28.735507763922215, 40.10129638016224, 38.41638319194317, 37.79564470052719, 38.65192875266075, 29.371485337615013, 19.296626150608063, 29.890978261828423, 19.17437721043825, 21.850231625139713, 31.476929560303688, 20.468099489808083, 15.139897149056196, 25.626617185771465, 32.16014049947262, 35.88676393032074, 58.102993816137314, 41.84509880840778, 12.498681675642729, 23.157684467732906, 30.082772970199585, 14.215637594461441, 13.934204746037722, 48.62768165767193, 55.47888122498989, 56.6521442681551, 59.57817725837231, 57.759404852986336, 61.78025409579277, 58.58221270143986, 63.212450444698334, 61.24528080224991, 61.394324004650116, 55.150772631168365, 35.241493955254555, 27.171821370720863, 58.08442801237106, 64.89833638072014, 58.09298135340214, 35.99877052009106, 58.10470372438431, 23.482933714985847, 34.643356651067734, 40.69773517549038, 39.619949609041214, 49.461915493011475, 71.880302131176, 32.14738458395004, 91.8631486594677, 62.8588680177927, 43.03166873753071, 71.50490507483482, 74.7681775689125, 50.95776982605457, 0.8769312535878271, 0.45445585157722235, 0.31749359623063356, 0.18238400865811855, 0.3238650824641809, 0.21601247135549784, 0.27451056987047195, 0.22117810120107606, 0.17269172327360138, 0.1727839870727621, 0.11897523771040142, 0.4455448844237253], [0.03054513410461368, 0.055225279211299494, 0.06086900059017353, 0.10001395829021931, 0.02110558154527098, 0.02124916671164101, 0.06167141436890233, 0.09507678376394324, 0.01026985160933691, 0.13517189829144627, 0.06005925068166107, 0.12677414109930396, 0.06436496143578552, 0.07280154779436998, 0.10794920162879862, 0.354240860324353, 0.021676460091839544, 15.42884124442935, 87.02320396900177, 54.564581885933876, 44.37960460782051, 35.155595764517784, 44.400351494550705, 28.191981129348278, 50.41370742022991, 31.057340875267982, 20.023257359862328, 13.401651922613382, 47.849437817931175, 20.15126869082451, 31.234603263437748, 44.38576027750969, 27.825447097420692, 58.24698708951473, 48.28280836343765, 12.129730973392725, 18.832272067666054, 58.21787305176258, 59.98904161155224, 71.45709604024887, 37.2404944896698, 30.675968639552593, 59.30148370563984, 50.762471705675125, 51.892827451229095, 43.83609317243099, 43.585941195487976, 24.602775424718857, 6.294926041737199, 13.052719496190548, 9.204435143619776, 5.666037937626243, 11.99925547465682, 32.68540531396866, 26.24782495200634, 17.888590805232525, 9.444970786571503, 17.64425251632929, 27.875028736889362, 20.725890956819057, 23.10220744460821, 24.393370561301708, 22.731387242674828, 21.19321648031473, 22.61692028492689, 17.904272563755512, 19.744800701737404, 19.301524087786674, 5.648477654904127, 14.201356060802937, 12.967415023595095, 11.872288137674332, 1.2815635255537927, 0.7610249449498951, 0.13838078157277778, 0.061742337711621076, 0.14456380682531744, 0.04549676217720844, 0.5292877298779786, 0.645351551938802, 1.5178376971744, 3.0126339057460427, 1.0321362409740686, 12.763682305812836, 4.441488096490502, 2.423719894140959, 1.9212634745053947, 5.462672375142574, 0.3027732454938814, 0.6794307357631624, 0.37023598328232765, 0.4848120070528239, 0.7406693778466433, 2.351026232354343, 4.9679142236709595, 7.927539786323905, 4.975080639123917, 0.9554042271338403, 0.0855013272666838, 0.07103749245288782, 0.29269229737110436, 0.5771684856154025, 0.2340740303043276, 0.13636619201861322, 0.24757325125392526, 1.5751335164532065, 3.6662717442959547, 14.22538597136736, 20.42836122214794, 20.71824386715889, 11.031894832849503, 27.868031412363052, 32.161664217710495, 29.49773546308279, 36.16316109895706, 30.59756364673376, 10.14600656926632, 24.985800571739674, 17.672000527381897, 20.744770243763924, 19.89661395549774, 23.245932832360268, 14.363445863127708, 8.80841564387083, 16.268756724894047, 36.568340957164764, 32.82189778983593, 47.73784160614014, 59.68891091644764, 16.781404316425323, 6.808673674240708, 5.537918787449598, 7.234552446752787, 27.010153345763683, 45.382492393255234, 53.289887085556984, 47.29809120297432, 52.589672058820724, 48.493510857224464, 55.64133010804653, 47.45305448770523, 55.485428273677826, 50.49553602933884, 55.58114513754845, 17.777707055211067, 38.84366266429424, 69.23521846532822, 53.11251640319824, 45.06474204361439, 43.170722275972366, 57.278388664126396, 17.090217545628548, 30.81669218838215, 33.00278328359127, 33.2821024954319, 41.75725132226944, 23.763347268104553, 29.413233697414398, 71.66888147592545, 21.800137013196945, 29.13015838712454, 41.32532089948654, 57.89747804403305, 6.683892169967294, 0.09436800304683857, 0.26932052336633205, 0.02314030185516458, 0.0770091985759791, 0.03177623279043473, 0.00733808905351907, 0.03314374749606941, 0.03871140244882554, 0.058212360527249984, 0.052747652589459904, 0.008909694370231591, 0.12604875111719593, 0.030526001537509728, 0.10056161874672398, 0.07967926780111156, 0.07039433985482901, 0.035691841039806604, 0.04041418607812375, 0.015372162342828233, 0.113820227998076, 0.07643680233741179, 0.14234318223316222, 0.14985436981078237, 0.10553444604738615, 0.055920434097060934, 0.0781694203033112, 0.05682996204996016, 0.4232057643821463, 0.13460743561154231, 17.953888401389122, 92.46445879340172, 62.059808894991875, 43.615568205714226, 37.40473687648773, 41.954133957624435, 41.406351551413536, 39.41624253988266, 27.786911465227604, 25.407391749322414, 12.949387840926647, 44.06290300190449, 26.11293599009514, 41.027207896113396, 56.317196041345596, 36.957611069083214, 55.16055330634117, 58.84364627301693, 16.470565795898438, 24.887366853654385, 60.74575960636139, 65.38195922970772, 74.05829206109047, 40.78538127243519, 35.94706669449806, 66.80080309510231, 54.40009631216526, 59.120362624526024, 49.26549643278122, 46.644708663225174, 24.494760520756245, 4.396927887573838, 8.474641554057598, 5.151638640090823, 1.5774832153692842, 16.08533676713705, 41.48877292871475, 33.315840885043144, 36.10662393271923, 17.805565260350704, 20.18010914325714, 26.61305945366621, 23.850043416023254, 20.092197060585022, 25.963786393404007, 18.30406241118908, 12.618626039475203, 27.57658515125513, 21.087502352893353, 22.89315026253462, 30.657062754034996, 11.986148077994585, 17.56287608295679, 14.623183775693178, 17.98159271478653, 16.32101722061634, 0.6461600179318339, 0.3992619726341218, 0.09056726441485807, 0.3946009586798027, 0.14194491610396653, 0.14294144231826067, 0.33515086281113327, 0.7042530225589871, 2.274380070157349, 3.419560007750988, 8.059757966548204, 4.628434265032411, 2.6908021001145244, 1.523684395942837, 4.529291884973645, 0.3996173129417002, 1.3311772258020937, 0.6846550991758704, 2.068957155570388, 0.6818670581560582, 4.313589809462428, 9.658373035490513, 10.923432502895594, 4.006586708128452, 0.36749870516359806, 0.3093065199209377, 0.04276840467355214, 0.13155968743376434, 0.2265230190823786, 0.2800625469535589, 0.08531231709639542, 0.46818317903671414, 4.56438965164125, 10.511187873780727, 27.33198657631874, 24.107065424323082, 18.039739094674587, 24.427422434091568, 32.99063913524151, 34.42084439098835, 31.766950897872448, 39.255161583423615, 21.36994119733572, 12.464238423854113, 17.21868485212326, 12.294832114130259, 22.676801271736622, 21.515811569988728, 21.637216955423355, 14.638056177645922, 13.478726036846638, 31.768936291337013, 54.94361914694309, 38.96057479083538, 51.683857664465904, 64.77512419223785, 27.3325527459383, 10.970558524131775, 3.553295969031751, 4.121985565871, 31.30729716271162, 53.414923176169395, 59.90985386073589, 50.74319913983345, 56.00406624376774, 52.79515743255615, 57.559353187680244, 50.54932974278927, 60.63191771507263, 55.5453472584486, 59.26923483610153, 20.349954329431057, 44.020565673708916, 67.3508919775486, 58.13703238964081, 48.24238993227482, 50.452966913580894, 62.9877495020628, 24.100729264318943, 30.57055089622736, 30.62954843044281, 29.052722342312336, 33.888234570622444, 34.557743445038795, 22.871134243905544, 74.17689129710197, 29.662255235016346, 28.410429507493973, 52.550553157925606, 64.71271634101868, 6.9325869251042604, 0.0338530774024548, 0.2411520856549032, 0.009260091046598973, 0.07240971608553082, 0.05952475963567849, 0.03616283393057529, 0.03937998473702464, 0.055608732072869316, 0.03559575889084954, 0.03704350718180649, 0.0896638109406922, 0.12006673656287603, 0.11187649870407768, 0.2350198381463997, 0.13613406306831166, 0.2908819913864136, 0.21498811460332945, 0.08262910443590954, 0.15325299056712538, 0.2382880635559559, 0.2692908077733591, 0.20845507766352966, 0.4197178781032562, 0.30790368269663304, 0.18049325386527926, 0.17887972091557458, 0.2992032183101401, 0.5947285902220756, 0.29136260622181, 25.696495436131954, 107.84820690751076, 72.79732972383499, 60.80214858055115, 51.70205868780613, 61.83461017906666, 44.067736342549324, 76.0314653813839, 44.653775095939636, 26.209068931639194, 20.755046792328358, 71.83507695794106, 25.102828592061996, 43.928527012467384, 49.11720559000969, 36.85967892408371, 62.61826492846012, 59.38427746295929, 15.068416334688663, 25.05595240741968, 66.6776593029499, 67.34421953558922, 88.09608399868011, 45.42701080441475, 36.007893830537796, 72.9110424220562, 58.13352517783642, 63.196476101875305, 53.15811015665531, 49.31587792932987, 30.184250324964523, 11.717044617980719, 22.052823454141617, 23.24301838874817, 13.100793566554785, 21.395103447139263, 44.96365986764431, 33.25330764055252, 25.12955065816641, 13.766787629574537, 24.43726770579815, 36.41879618167877, 25.946351028978825, 27.699823938310146, 31.60479459911585, 29.61769312620163, 28.9446884393692, 31.96416601538658, 25.357604920864105, 23.225892707705498, 28.50839965045452, 7.447594190016389, 22.123710550367832, 25.597727335989475, 33.371906876564026, 32.018415704369545, 3.8571153162047267, 0.4665093094808981, 0.17942142934771255, 0.7395227893721312, 0.16701928077964112, 0.5264799774158746, 0.6841484201140702, 1.681929042097181, 5.815937994047999, 5.658112512901425, 14.660528171807528, 10.992770232260227, 4.846600033342838, 2.6675665844231844, 6.1984349694103, 0.5720428575295955, 1.4553585997782648, 1.512807598337531, 3.2699670223519206, 1.5619514300487936, 8.759858999401331, 14.576915558427572, 17.151048481464386, 6.869054809212685, 1.8453088751994073, 0.36849258933216333, 0.28173653525300324, 0.5078284407500178, 1.1450829240493476, 0.5764621391426772, 0.17620942904613912, 0.45593946415465325, 5.834387904033065, 26.822574511170387, 33.90217982232571, 37.442685440182686, 31.954829916357994, 17.165668196976185, 31.27857830375433, 36.563625410199165, 33.047172501683235, 43.93972501158714, 35.839794650673866, 19.00606334209442, 33.059495240449905, 20.841395258903503, 26.051352694630623, 27.466311268508434, 28.04617155343294, 19.678737446665764, 10.85597662255168, 22.715238109230995, 42.695132195949554, 39.96532827615738, 56.07925280928612, 72.0185387134552, 27.155351154506207, 16.93216312676668, 14.923375267535448, 11.155644692480564, 30.40686707943678, 55.373676270246506, 63.652976006269455, 52.747713178396225, 60.686999559402466, 56.05731278657913, 64.26041901111603, 57.39052064716816, 64.49656873941422, 60.98460339009762, 65.09554579854012, 23.57328526675701, 47.76955470442772, 76.21022298932076, 61.142598912119865, 55.89716657996178, 53.89579877257347, 68.67857113480568, 25.6125408411026, 37.818534672260284, 41.90557636320591, 40.99914260208607, 60.45362368226051, 37.64555275440216, 36.50038920342922, 92.67576545476913, 33.7882961332798, 44.33194376528263, 58.391018360853195, 86.57747268676758, 13.697933424264193, 0.24070304178167135, 0.5620630492921919, 0.1698503366787918, 0.26248299807775766, 0.13262412016047165, 0.1580708203255199, 0.1385162235237658, 0.18322710326174274, 0.15020601422293112, 0.16383677342673764, 0.17321410618023947, 0.35726576519664377], [0.029906345334893558, 0.13629433728056028, 0.047451308273593895, 0.02813095554301981, 0.10392546246293932, 0.06476507551269606, 0.18736294383415952, 0.06076265453884844, 0.07664023985853419, 0.12364531328785233, 0.04005486785899848, 0.04875080143392552, 0.11590774098294787, 0.08188104926375672, 0.1710922466008924, 0.10247544691083021, 0.30364375503268093, 0.9370424249209464, 56.8248526006937, 72.09892719984055, 56.57178997993469, 32.450072541832924, 41.61132775247097, 36.041404232382774, 38.90397682785988, 55.151817575097084, 22.83668529242277, 19.184543564915657, 32.42966003715992, 34.03847090899944, 23.686642684042454, 20.299377143383026, 14.681068919599056, 67.40193083882332, 57.57562771439552, 20.820764265954494, 6.949616661295295, 35.18408663570881, 59.81104016304016, 49.008596017956734, 52.82698832452297, 54.58642691373825, 54.849558994174004, 56.43213987350464, 42.96814754605293, 37.95012541115284, 43.42940479516983, 20.04150778055191, 3.5548595851287246, 8.233896922320127, 3.629390923306346, 5.409744065254927, 36.15459255874157, 29.87276963889599, 23.828656263649464, 11.676201559603214, 22.322616577148438, 24.39445350319147, 25.409071259200573, 20.27399070560932, 29.993682950735092, 18.030898869037628, 16.883776523172855, 36.981690376996994, 15.751790665090084, 18.827339932322502, 21.80260308086872, 14.772349521517754, 15.553288366645575, 17.253775969147682, 11.861472018063068, 14.168820306658745, 1.0995909338817, 1.0508779040537775, 0.2626009105006233, 0.12039104767609388, 0.14608581812353805, 0.20239122648490593, 0.10501190728973597, 0.5278089561033994, 3.0814885860309005, 4.887924715876579, 8.897980637848377, 10.876511670649052, 7.889579348266125, 6.129028843715787, 3.398891491815448, 6.23819793574512, 0.9424882452003658, 0.8909667504485697, 1.8087943783029914, 0.6097611179575324, 2.3028783034533262, 1.9166015996597707, 3.0515438178554177, 6.38595063239336, 2.8213450452312827, 0.3521201584953815, 0.12480318982852623, 0.2833735052263364, 0.6685811898205429, 0.23494409455452114, 0.11565089109353721, 0.09975235123420134, 0.5528049054555595, 1.471012334804982, 2.384922313503921, 17.642035335302353, 22.79954608529806, 30.278432071208954, 12.09244167432189, 23.37877370417118, 36.09742842614651, 34.423549845814705, 35.165140852332115, 35.72259373962879, 9.622254073619843, 17.200485728681087, 31.695457734167576, 18.32945264875889, 17.405042052268982, 18.594167344272137, 30.294702798128128, 22.80650731176138, 6.6294667404145, 8.506164662539959, 43.6042296141386, 42.634457051754, 55.25890722870827, 65.46404242515564, 16.277663446962833, 0.8996048744302243, 1.320410503540188, 8.696488849818707, 36.44208513200283, 57.168718948960304, 53.86585257947445, 60.065941885113716, 50.75392596423626, 55.5877947807312, 48.76461870968342, 57.79330663383007, 51.02722629904747, 49.98173899948597, 22.62865025550127, 55.22991858422756, 54.71032686531544, 50.24967022240162, 51.78259916603565, 62.6516879349947, 33.66376921534538, 17.174415327608585, 35.364041179418564, 28.072773925960064, 32.19540260732174, 41.36506296694279, 15.352305751293898, 63.88395041227341, 57.91721038520336, 27.3975083604455, 42.910052463412285, 59.102678373456, 23.49329575896263, 0.8596607646904886, 0.28450988174881786, 0.3942521195858717, 0.047206299350364134, 0.17457824782468379, 0.07166365729062818, 0.028108043588872533, 0.04299779509892687, 0.06933875352842733, 0.148259227280505, 0.02494574677257333, 0.026856866097659804, 0.14213002257747576, 0.07614422545884736, 0.049073268310166895, 0.056878212781157345, 0.02219787820649799, 0.05514979537110776, 0.03988759890489746, 0.09081884505576454, 0.03407447489735205, 0.18285028520040214, 0.16807997308205813, 0.1084827835438773, 0.0168233597651124, 0.058616767928469926, 0.06740012278896756, 0.16263069439446554, 0.05585103957855608, 0.23936684941872954, 0.8705158322118223, 62.784961983561516, 84.14592236280441, 54.542782455682755, 42.41774708032608, 45.89049853384495, 33.560893535614014, 53.870651721954346, 36.16496980190277, 29.63954195380211, 14.663172829896212, 23.52330654859543, 29.637066386640072, 36.22509017586708, 24.155868105590343, 13.393641952425241, 70.44388800859451, 64.69919666647911, 28.676012456417084, 10.31675610691309, 35.66387929022312, 64.05459925532341, 61.72334834933281, 60.467663928866386, 58.23619946837425, 62.186627089977264, 57.762687876820564, 49.64434750378132, 37.77989074587822, 53.59944507479668, 19.475782737135887, 3.1719885673373938, 5.195906739681959, 1.0724708391353488, 12.491490561515093, 42.92796090245247, 39.13202919065952, 43.18502090871334, 18.260170966386795, 21.216237545013428, 22.846902944147587, 25.75506169348955, 21.091687828302383, 26.178661063313484, 30.180600620806217, 23.322094045579433, 23.663893304765224, 21.049483492970467, 25.000788867473602, 27.724098935723305, 24.59018100053072, 15.385606214404106, 20.642888210713863, 16.111673153936863, 23.58238197863102, 17.13385820388794, 0.09699959933641367, 0.21637532219756395, 0.10800432093674317, 0.28067526407539845, 0.1292056098463945, 0.8453355927485973, 1.2850827304646373, 1.6503992839716375, 5.1889117900282145, 5.647783242166042, 15.97078051418066, 11.08000785112381, 6.1681724432855844, 2.578278500586748, 5.645988313481212, 1.0817923326976597, 1.7075047572143376, 2.3197705345228314, 0.9064911736641079, 4.788938602432609, 9.737446792423725, 7.683337340131402, 13.915721587836742, 5.29669395647943, 1.0642375121824443, 0.11641144403256476, 0.07329934334848076, 0.5469078000169247, 0.1187405335076619, 0.1701574819162488, 0.2461815017159097, 1.5511728334240615, 1.6982454853132367, 10.492023602128029, 30.447494499385357, 26.46113220602274, 25.84680777043104, 19.968715086579323, 35.18372565507889, 35.65308026969433, 36.388143226504326, 39.69663329422474, 28.445657417178154, 10.236614607274532, 22.173237092792988, 17.85852301865816, 12.768161315470934, 19.56171702593565, 20.435440242290497, 27.20092210918665, 19.316814467310905, 9.292996041476727, 19.949662908911705, 61.745561957359314, 47.651289850473404, 56.40727400779724, 63.2933709025383, 28.347037509083748, 8.58650280162692, 0.906978378770873, 6.4613238628953695, 41.99425980448723, 61.32530450820923, 62.00805947184563, 61.61061979830265, 54.87173840403557, 61.80258169770241, 54.05477084219456, 59.682793244719505, 59.27998445928097, 56.664292216300964, 25.668162256479263, 56.07437387108803, 60.604616180062294, 52.92143605649471, 59.41526859998703, 69.9092946946621, 41.37149982154369, 23.064530566334724, 29.16392907500267, 26.150253787636757, 28.557137735188007, 39.64307516813278, 23.925619460642338, 57.18594342470169, 69.25788044929504, 28.130477629601955, 47.44351699948311, 70.87111428380013, 22.756923772394657, 0.6587496923748404, 0.1799934174050577, 0.4190920991823077, 0.045445071591529995, 0.021941711092949845, 0.041013054724317044, 0.1518276662682183, 0.015406088696181541, 0.07639190240297467, 0.11887800152180716, 0.02563751746492926, 0.05990689889586065, 0.14878615213092417, 0.10782383062178269, 0.23191690386738628, 0.18763339729048312, 0.11142125047626905, 0.17133388988440856, 0.21610172203509137, 0.3624964220216498, 0.19755353685468435, 0.23383792344247922, 0.24435932136839256, 0.33467980683781207, 0.17828938696766272, 0.37387675198260695, 0.2394172115600668, 0.3924136416753754, 0.29340472945477813, 0.4141862358665094, 2.071993430145085, 83.17945182323456, 91.8525168299675, 73.17040890455246, 46.57967895269394, 61.80270329117775, 43.974816128611565, 61.56005211174488, 75.88031709194183, 33.625440672039986, 26.384494118392467, 54.08747188746929, 41.00432552397251, 35.359557420015335, 22.538492493331432, 14.111389238387346, 85.82875326275826, 68.47050949931145, 29.15445238351822, 10.764847062528133, 43.33988919854164, 64.60779637098312, 70.88770419359207, 60.62141887843609, 62.67253741621971, 71.96436882019043, 60.082440599799156, 56.26136563718319, 37.81377352774143, 54.73018079996109, 26.239664889872074, 7.324914922937751, 19.910369217395782, 6.266275579109788, 9.760207571089268, 47.30300433933735, 37.42550656199455, 35.37058062851429, 14.347349926829338, 28.99931240826845, 30.981050468981266, 32.340585216879845, 24.14997462183237, 38.12421686947346, 22.24720772355795, 21.04494083672762, 48.596584126353264, 22.288975082337856, 26.26811396330595, 28.824508488178253, 21.809837892651558, 21.10466793179512, 25.394930317997932, 25.692712739109993, 39.8729058355093, 32.287369072437286, 5.382301462814212, 2.076961901038885, 0.39502232044469565, 0.4429514048388228, 0.3965531336143613, 1.1245317268185318, 2.029271610081196, 4.381615659222007, 9.198862742632627, 11.90401928499341, 16.41146756708622, 13.052831590175629, 8.530555553734303, 7.287087952718139, 6.395547492429614, 3.3977821888402104, 4.629546655341983, 4.799280697479844, 1.6271397820673883, 7.711258716881275, 19.380193166434765, 12.396043483167887, 11.850086878985167, 5.152961919084191, 1.2135027651675045, 0.34216436615679413, 0.4228630702709779, 1.2804613471962512, 0.29271405714098364, 0.35877253278158605, 0.6359450379386544, 1.228982184547931, 8.56456657871604, 26.59403007477522, 40.6523922085762, 35.91091923415661, 44.539500027894974, 19.008164629340172, 30.056128799915314, 41.40603996813297, 38.26388977468014, 41.50339834392071, 43.506935834884644, 13.30771241337061, 25.347373969852924, 42.082187086343765, 22.19164900481701, 26.378680430352688, 24.878602623939514, 40.7340270280838, 29.42626129835844, 9.067783076316118, 12.572565861046314, 50.57485677301884, 49.15258169174194, 62.97762684524059, 70.09296923875809, 26.580126620829105, 4.595679547637701, 5.031400742009282, 11.01995112374425, 43.76882158219814, 65.83418056368828, 66.0766151547432, 65.16333416104317, 58.15603516995907, 66.9797582924366, 59.48638558387756, 68.74343365430832, 61.50065749883652, 61.44379734992981, 26.95938427001238, 59.941034987568855, 68.84076163172722, 64.5831660926342, 60.25930590927601, 71.48391500115395, 49.85514499247074, 22.280250750482082, 44.024870842695236, 35.251046642661095, 43.106270134449005, 58.57320338487625, 25.885407999157906, 80.88062077760696, 74.33638393878937, 39.24312002956867, 60.18797613680363, 78.35596024990082, 44.705585315823555, 0.7047142821829766, 0.5786163860466331, 0.5375092418398708, 0.11853275442263111, 0.1976283304975368, 0.23447781801223755, 0.165667399414815, 0.09878724013105966, 0.4574529704404995, 0.2561400696868077, 0.11009829802787863, 0.19142755307257175, 0.3342304809484631], [0.08291490550618619, 0.10423664498375729, 0.0791050458792597, 0.07143641909351572, 0.021627183341479395, 0.03977837332058698, 0.035047753335675225, 0.068295264209155, 0.0828686474415008, 0.06350652663968503, 0.2080421763821505, 0.16919010726269335, 0.10461996425874531, 0.07737564141280018, 0.20539095770800486, 0.11803009037976153, 0.5938820668961853, 0.13121916039381176, 18.58017649501562, 87.75847971439362, 54.540734365582466, 38.03200341761112, 39.51151482760906, 48.446374386548996, 18.786606118083, 52.159120962023735, 35.50730489194393, 19.68658782541752, 31.882181614637375, 43.078759610652924, 18.556684255599976, 45.61098173260689, 62.659659907221794, 79.38446626067162, 64.29062739014626, 53.90018753707409, 24.084095656871796, 17.7318150177598, 46.24775916337967, 54.6986348927021, 29.9643200263381, 30.976133532822132, 55.92227563261986, 58.90285849571228, 37.2478698939085, 22.608526535332203, 42.50576175749302, 14.663354270160198, 2.854553838260472, 3.0769466422498226, 6.341093564406037, 43.35924535989761, 35.14476254582405, 29.144208133220673, 10.549913495779037, 23.23875691741705, 30.21669488400221, 23.516780398786068, 26.69548463076353, 23.01492042839527, 25.399672463536263, 12.488703411072493, 7.327044233679771, 29.953391812741756, 24.672723971307278, 16.506612561643124, 26.48802526295185, 12.256168238818645, 17.912430725991726, 21.672477163374424, 11.768365614116192, 16.47500965744257, 2.6975001906976104, 1.3904063100926578, 0.49499819171614945, 0.14245385129470378, 0.9061798278708011, 0.15371442830655724, 0.4185418115230277, 1.7366583365947008, 2.6109322858974338, 3.0924804462119937, 6.554821170866489, 9.24862202256918, 7.468626536428928, 7.6137616485357285, 5.815531415864825, 12.023045048117638, 4.316582148894668, 0.5405155336484313, 1.8291409802623093, 1.4662958378903568, 3.8619484193623066, 6.792387748137116, 9.595628902316093, 3.777631656266749, 1.1253013042733073, 0.18684223818127066, 0.09437449683900923, 0.11125490549602546, 0.04969311376044061, 0.06392782903276384, 0.5331454135011882, 0.05349657978513278, 0.40454944828525186, 2.619081661105156, 1.7084713303484023, 18.054828085005283, 27.30098593980074, 27.179455161094666, 16.96496296674013, 7.354690600186586, 29.861446246504784, 29.505963921546936, 37.98573710024357, 40.17877422273159, 28.927703350782394, 8.554637711495161, 18.49162794649601, 32.8224753588438, 22.653746008872986, 17.004036270081997, 18.805048428475857, 26.850844994187355, 26.624760925769806, 10.226849131286144, 9.061062186956406, 46.25120937824249, 54.205109775066376, 58.8040865957737, 43.363413736224174, 8.40468730777502, 1.0783498361706734, 11.38876598328352, 57.903952896595, 42.41496942937374, 54.31167125701904, 70.84295019507408, 47.488062009215355, 40.79789400100708, 50.188774690032005, 49.9872525036335, 55.19865766167641, 52.09324769675732, 39.34318765997887, 61.90738007426262, 51.62945978343487, 53.26351270079613, 54.789396822452545, 57.16945990920067, 27.945399060845375, 20.68306155502796, 39.219428300857544, 25.448079966008663, 35.05889855325222, 35.077563151717186, 33.47243048250675, 76.05535089969635, 41.1081625521183, 28.764961883425713, 46.6992699354887, 42.23694518208504, 2.021200843155384, 0.2696726575959474, 0.11420778493629768, 0.17550885648233816, 0.07577359690912999, 0.2309994015377015, 0.05977147178782616, 0.08501377335051075, 0.058345078796264715, 0.07050601823721081, 0.031515263981418684, 0.022425617353292182, 0.06259099842282012, 0.07801040032063611, 0.03694387756695505, 0.16753574134781957, 0.12897989305201918, 0.07123840667190962, 0.05306543280312326, 0.022140382170618977, 0.09468607269809581, 0.02681956390006235, 0.0976616470143199, 0.16711068368749693, 0.20947941957274452, 0.0836479989811778, 0.15416831098264083, 0.03487865498755127, 0.08316097941133194, 0.18002553755650297, 0.6863707664888352, 0.36823818110860884, 20.42961325496435, 93.4182608127594, 62.422693222761154, 32.84425958991051, 33.00256289541721, 31.46028645336628, 16.451382525265217, 33.75916689634323, 22.88239113986492, 22.462217286229134, 26.376525945961475, 39.071935415267944, 29.922723658382893, 39.91217292845249, 46.558004915714264, 90.34050956368446, 62.448436841368675, 55.184317231178284, 25.47716360539198, 20.93817226588726, 48.3985311537981, 65.33442378044128, 31.479420326650143, 34.74927596747875, 59.62460696697235, 60.073393285274506, 43.961988016963005, 28.9349552616477, 49.43568930029869, 16.38135228306055, 1.9847553363069892, 2.051448170095682, 14.772414118051529, 53.330130726099014, 42.792589366436005, 44.336032345891, 19.227804243564606, 24.03840310871601, 28.14450267702341, 21.25146735459566, 23.679905645549297, 22.81503975391388, 23.161716051399708, 16.289507411420345, 14.674872402101755, 40.2956597507, 28.545875139534473, 21.875931546092033, 35.794508680701256, 19.576220847666264, 17.681697607040405, 23.995693400502205, 16.46235253661871, 31.891950890421867, 21.36867966502905, 0.3944823337951675, 0.8945626043714583, 0.41311421839054674, 0.6668855308089405, 0.29804238060023636, 0.5752057128120214, 0.3139980509877205, 1.8134554219432175, 6.602163780480623, 10.643500573933125, 11.182128321379423, 9.570584446191788, 8.153040111064911, 6.501166624948382, 9.825069140642881, 4.292638683691621, 4.201463051140308, 3.872013366781175, 1.4752214401960373, 8.152790274471045, 12.898542769253254, 11.496827434748411, 5.01179569400847, 1.1822740221396089, 0.49627296393737197, 0.1813312721787952, 0.224249494203832, 0.14168277470162138, 0.011772067973652156, 0.5343690665904433, 0.10237278562271968, 0.8820803335402161, 2.4853865476325154, 8.638009987771511, 35.214678794145584, 29.662426225841045, 23.74719623476267, 16.96993689984083, 16.851569451391697, 33.26621934771538, 30.91569397598505, 41.3750184327364, 38.01113113760948, 19.617640525102615, 10.89952228590846, 27.25534848868847, 24.514897540211678, 15.024733878672123, 17.576103173196316, 19.74586084485054, 24.471015594899654, 22.83805511891842, 13.656492847949266, 20.279285721480846, 67.17325910925865, 62.7280068397522, 65.80297663807869, 46.44535236060619, 19.88121908158064, 7.315338486805558, 5.81244645640254, 61.15569680929184, 46.73284113407135, 57.3248715698719, 72.16467127203941, 52.70688436925411, 45.36533251404762, 54.954596757888794, 53.35612893104553, 59.30810675024986, 57.64415703713894, 45.85256516933441, 63.989303559064865, 59.219510704278946, 67.45716467499733, 58.87755185365677, 59.17056933045387, 39.22409825026989, 25.557134114205837, 31.329389177262783, 25.181531868875027, 29.444127939641476, 32.291491851210594, 36.46427594125271, 71.73862293362617, 53.00202593207359, 28.24928965419531, 56.60703308880329, 44.96217414736748, 3.079020855948329, 0.34870675415731966, 0.15199604473309591, 0.1267780299531296, 0.014869075275782961, 0.027797261827799957, 0.11019053214113228, 0.031574524473398924, 0.1316614804090932, 0.02054530086752493, 0.04952629009494558, 0.06643489294219762, 0.0538435152702732, 0.027744699218601454, 0.25725153973326087, 0.2196425382862799, 0.2926043083425611, 0.23531619255663827, 0.07653757114894688, 0.10163284954614937, 0.3087031241739169, 0.22178480692673475, 0.17170451843412593, 0.3124130016658455, 0.32164638745598495, 0.2868161501828581, 0.2672353258822113, 0.17558592109708115, 0.3914385783718899, 0.24453629390336573, 1.2474221200682223, 0.5773271864745766, 31.03639829903841, 111.86870276927948, 74.63247165083885, 53.46924506127834, 57.53942705690861, 66.6147954761982, 30.379373654723167, 82.12495520710945, 50.0450474023819, 26.150363981723785, 53.717918917536736, 58.54815512895584, 28.706967495381832, 60.69443196058273, 63.52656438946724, 101.36729747056961, 65.88692173361778, 61.30509339272976, 27.44356758892536, 23.817760348320007, 51.05165138840675, 68.31862404942513, 35.30339263379574, 35.85672654211521, 67.13365003466606, 67.25730299949646, 46.26307234168053, 29.893123246729374, 53.732677325606346, 21.697588115930557, 6.802378362044692, 7.611524518579245, 10.212453603744507, 60.65779812633991, 40.06907030940056, 36.408715322613716, 14.259183257818222, 30.061207227408886, 37.641688361763954, 30.212971083819866, 32.367160990834236, 29.688331335783005, 35.395066514611244, 15.83902258425951, 11.004173420369625, 39.33842271566391, 35.59193395078182, 24.012123718857765, 34.92044538259506, 16.408857107162476, 23.65080490708351, 30.300058610737324, 24.433939084410667, 43.70706729590893, 35.609181225299835, 7.293068356812, 1.7937128688208759, 0.3687745163915679, 0.7934689102694392, 0.3213191597023979, 0.9888571570627391, 3.078708085231483, 3.5138718970119953, 7.933735828846693, 11.32127020508051, 15.328857209533453, 14.6202446334064, 10.749538633972406, 12.654947340488434, 11.122151389718056, 6.564400931820273, 10.320068579167128, 7.513400483876467, 3.4860350657254457, 16.544260941445827, 25.667134411633015, 15.427358373999596, 4.099510721862316, 3.3268939051777124, 0.7637894153594971, 0.3371323080500588, 0.6611554382834584, 0.23715682269539684, 0.1359053628402762, 0.7357944175601006, 0.2027465816354379, 1.1117866169661283, 10.682121701538563, 19.085230194032192, 41.21875561773777, 40.017898455262184, 39.24602307379246, 25.017583966255188, 14.406830985099077, 35.532862320542336, 36.07728950679302, 45.75319670140743, 50.57400181889534, 38.39941330254078, 12.38001499325037, 26.009942516684532, 45.85985317826271, 25.85666634142399, 27.11366929113865, 25.527476705610752, 36.97041638195515, 33.810980916023254, 15.266329664736986, 11.841126959770918, 50.986348092556, 63.78000319004059, 72.57869705557823, 45.80203928053379, 15.441993288695812, 2.644844753667712, 16.52672678232193, 71.80075719952583, 47.679142355918884, 61.19599364697933, 80.33031910657883, 53.377715572714806, 51.521195992827415, 61.57556667923927, 59.63945657014847, 68.59600156545639, 61.46972715854645, 46.11622542142868, 71.91233441233635, 56.08836472034454, 69.3236169219017, 62.9708594083786, 66.5648053586483, 38.221423253417015, 29.71310980618, 49.28277790546417, 33.8149669021368, 47.306671142578125, 47.43367172777653, 43.57049122452736, 93.13367128372192, 58.807567209005356, 42.97100119292736, 65.28223738074303, 75.50378769636154, 5.2946696151047945, 0.4508219106355682, 0.2790562540758401, 0.3909971489338204, 0.13264175358926877, 0.2755926508689299, 0.23242300405399874, 0.20079608395462856, 0.2275619813008234, 0.18608463898999617, 0.18852722510928288, 0.14703195251058787, 0.12764975661411881, 0.20916069683153182], [0.16411417338531464, 0.05991082114633173, 0.10308175929822028, 0.06285606388701126, 0.09862166698439978, 0.057866523420671, 0.08377716978429817, 0.025808341306401417, 0.0718301061715465, 0.04924594752083067, 0.07687325196457095, 0.16456202982226387, 0.010685371744330041, 0.06013569189235568, 0.10104884611791931, 0.18894897279096767, 0.14275489607825875, 0.7800774194765836, 0.8695944410283118, 45.39393737912178, 76.14016994833946, 44.96148258447647, 64.87090945243835, 81.90651252865791, 92.53198876976967, 81.22069492936134, 43.15470993518829, 12.271182183176279, 10.820056200027466, 40.52327133715153, 24.09703206270933, 75.39464235305786, 66.16246774792671, 56.87908709049225, 63.048143461346626, 71.81958138942719, 47.15853609144688, 13.982193320989609, 32.95522503554821, 63.039069548249245, 100.28548792004585, 57.67014004290104, 41.35127350687981, 58.271678164601326, 38.544569313526154, 26.794336326420307, 54.32580269873142, 9.608924388885498, 3.788613067008555, 4.493854511529207, 31.1344026401639, 32.27222688496113, 28.886559158563614, 13.158939946442842, 19.67870894819498, 28.511283695697784, 21.809885390102863, 28.82546603679657, 20.177126303315163, 25.445429608225822, 27.427914328873158, 27.09006115794182, 20.75297400355339, 9.573052413761616, 17.955436818301678, 23.955140076577663, 19.6151402592659, 15.628058854490519, 18.03832557052374, 22.25369967520237, 12.621178552508354, 15.683284141123295, 6.215141247957945, 2.9098582081496716, 1.4714850531890988, 0.4092193383257836, 0.6390675797592849, 0.38274529797490686, 0.6608707504346967, 1.7208401416428387, 5.247712209820747, 2.979105692356825, 13.162126075476408, 13.879302442073822, 12.881943359971046, 8.586580697447062, 4.643471008166671, 17.447911351919174, 11.341904047876596, 6.835897313430905, 1.9756237138062716, 0.7525603054091334, 4.641442866995931, 8.685715477913618, 4.9608423281461, 3.045056853443384, 0.857635117135942, 0.14180589700117707, 0.287986071780324, 0.041296770359622315, 0.13937493291450664, 0.25395322765689343, 0.07574069008114748, 0.43903966317884624, 1.2278129160404205, 3.2690783450379968, 4.423569208011031, 15.75637986883521, 32.035256400704384, 28.76046672463417, 27.609413489699364, 12.648960761725903, 18.269467167556286, 33.0342797935009, 34.22278381884098, 42.664475440979004, 42.68729701638222, 27.361237406730652, 9.218067862093449, 14.053429048508406, 24.071976207196712, 25.915181301534176, 19.43862073123455, 19.438434541225433, 25.21710556000471, 25.417455509305, 15.076267663389444, 9.192612078040838, 38.99016760289669, 46.61970980465412, 55.39168730378151, 26.156616546213627, 6.843547727912664, 4.130645776167512, 37.82509692013264, 50.40145307779312, 43.57603892683983, 59.455052465200424, 65.99031418561935, 50.39914280176163, 39.128985553979874, 53.06299366056919, 56.48155242204666, 55.61289243400097, 60.64326770603657, 63.09334583580494, 63.75167950987816, 69.72448021173477, 57.78977282345295, 61.7567827552557, 17.23991621285677, 30.330512076616287, 33.031015768647194, 23.794230110943317, 40.88287264108658, 34.52312350273132, 49.45120766758919, 67.02370673418045, 27.728972174227238, 39.32875983417034, 52.448885813355446, 6.946852309629321, 0.9222273761406541, 0.2516528667183593, 0.4875078139593825, 0.060645714329439215, 0.23022225417662412, 0.11871526337927207, 0.052220115467207506, 0.09979827533243224, 0.01986513365409337, 0.014648892120021628, 0.1373193322797306, 0.03619981886004098, 0.07284120074473321, 0.055794235595385544, 0.05273461305478122, 0.07834599207853898, 0.11484038419439457, 0.02584928002761444, 0.09961812640540302, 0.11949543870287016, 0.06378130681696348, 0.03501045299344696, 0.02432807581499219, 0.08997955766972154, 0.09419165391591378, 0.15828541974769905, 0.020905596866214182, 0.030136158784443978, 0.08673353731865063, 0.14981942949816585, 0.20880646974546835, 0.6800595426466316, 1.6316700889728963, 50.55933080613613, 88.02187398076057, 42.98690713942051, 59.15768042206764, 71.63871109485626, 67.54953771829605, 67.84776091575623, 15.996425338089466, 18.15188817679882, 23.581646718084812, 36.9185795634985, 31.043663509190083, 70.79036861658096, 57.77989715337753, 68.7555930018425, 61.87266893684864, 65.22117465734482, 49.779943227767944, 16.110799200832844, 30.32764133065939, 64.28525447845459, 77.08843186497688, 46.97212569415569, 51.926022469997406, 60.354916378855705, 44.755811020731926, 32.316771894693375, 59.15268748998642, 8.581272382289171, 1.8958097090944648, 11.727367714047432, 43.30202803015709, 42.596098110079765, 45.44816806912422, 23.480916023254395, 19.751570038497448, 27.035589180886745, 21.108944602310658, 26.000811606645584, 22.703964114189148, 22.669275775551796, 26.30593903362751, 25.26955794543028, 20.590038746595383, 10.968360342085361, 25.366333052515984, 27.421762458980083, 22.909337393939495, 20.201144814491272, 15.451483279466629, 23.097484298050404, 19.315741024911404, 32.14499071240425, 25.059906095266342, 2.3622111696749926, 1.5810636919923127, 0.31015004497021437, 0.6550147302914411, 0.4508629662450403, 0.23525138822151348, 1.3344291388057172, 3.57160409912467, 5.456686271354556, 10.272100903093815, 14.994915928691626, 14.96269365772605, 8.329040016978979, 7.476413743570447, 15.729079283773899, 12.493077926337719, 10.873584877699614, 6.478215381503105, 0.9451760072261095, 7.1383031364530325, 13.646897412836552, 10.2139488235116, 4.2492046393454075, 1.1592328897677362, 0.24159660242730752, 0.10620246801408939, 0.09099199553020298, 0.11650853921310045, 0.31312555249314755, 0.018191427370766178, 0.5103545333258808, 1.4210541592910886, 5.438916524872184, 11.710947845131159, 29.02613326907158, 40.94709299504757, 27.91982263326645, 14.426782764494419, 12.04599391669035, 28.390769362449646, 36.515098214149475, 37.99663871526718, 42.25722849369049, 31.92983865737915, 13.566132746636868, 11.738586612045765, 22.0135335624218, 26.599807664752007, 20.760621093213558, 20.034839138388634, 19.19284611940384, 24.781599529087543, 19.734879434108734, 17.240163199603558, 19.617064855992794, 64.85770896077156, 59.62519973516464, 60.005221143364906, 28.192057125270367, 20.347199477255344, 8.311600852757692, 31.679131910204887, 59.43008400499821, 43.729668483138084, 63.96442249417305, 68.0275596678257, 51.50391452014446, 48.23890931904316, 63.421712815761566, 61.48179531097412, 60.494555085897446, 63.66405241191387, 68.90153557062149, 71.22690439224243, 75.38816750049591, 64.57586288452148, 65.22234499454498, 27.220171876251698, 29.67035260051489, 26.941004656255245, 23.129341788589954, 28.92615493386984, 37.78794251382351, 46.736310347914696, 74.35223668813705, 35.66916860640049, 41.89162351191044, 65.12087523937225, 8.57466833665967, 0.5745862273033708, 0.04249579898896627, 0.550594077212736, 0.04988306274753995, 0.16699818894267082, 0.11262215673923492, 0.08820269285934046, 0.11305730018648319, 0.03879608520946931, 0.0697364036750514, 0.062967489939183, 0.04782333577168174, 0.07260456695803441, 0.20857837807852775, 0.2536923182196915, 0.15956234419718385, 0.2147882542340085, 0.22815474949311465, 0.27417250676080585, 0.1673054083948955, 0.08681918858201243, 0.09892274145386182, 0.08531619852874428, 0.25872666214127094, 0.23183494107797742, 0.29167374421376735, 0.16239742253674194, 0.14333672501379624, 0.14740678161615506, 0.4639159486396238, 0.4442936828127131, 0.9662208810914308, 2.3552024457603693, 73.12487974762917, 95.86106613278389, 62.55248285830021, 80.19677147269249, 105.55313766002655, 102.19330474734306, 118.40142622590065, 66.79277032613754, 17.213391736149788, 26.742717996239662, 60.0339438021183, 29.939146377146244, 98.26866254210472, 69.89220321178436, 73.88247549533844, 65.72886541485786, 80.80086305737495, 53.602135330438614, 17.003551796078682, 32.63949237763882, 76.22118920087814, 104.96431365609169, 63.98432582616806, 54.5169248431921, 66.33137628436089, 45.053479447960854, 32.225481793284416, 62.20083072781563, 13.310908041894436, 6.789862783625722, 6.970072388648987, 47.722490429878235, 41.442153230309486, 39.87820655107498, 16.674928329885006, 25.97310919314623, 35.74062757194042, 29.44885678589344, 36.349837481975555, 29.25471380352974, 32.00900360941887, 34.654968827962875, 33.857938796281815, 31.12422488629818, 14.341485891491175, 27.377257347106934, 36.13634213805199, 28.47047008574009, 20.406797379255295, 25.89267510920763, 31.190694719552994, 29.217399805784225, 42.63552099466324, 40.652513802051544, 9.098322037607431, 3.145832670852542, 0.3187541489023715, 1.1157150124199688, 0.3455780673539266, 0.6367294583469629, 3.3162428392097354, 6.9766270369291306, 6.203909525647759, 13.0973120033741, 21.88937522470951, 22.074930667877197, 11.390737127512693, 14.176999367773533, 17.230076640844345, 20.625944919884205, 18.895696364343166, 9.690688401460648, 7.432761210948229, 13.282092288136482, 24.12149515002966, 14.077583402395248, 6.581151857972145, 1.3585428823716938, 0.2759267360670492, 0.5386413435917348, 0.17471797938924283, 0.23917210986837745, 0.5230906186625361, 0.2103448676643893, 0.5244806909468025, 2.8112136013805866, 13.83707720786333, 24.196001552045345, 35.8400834351778, 50.13979531824589, 42.32290796935558, 38.01575168967247, 18.426412045955658, 26.08596693724394, 40.12242704629898, 41.18513122200966, 49.526504427194595, 52.07851588726044, 35.22998437285423, 11.55582781881094, 21.518655717372894, 32.998234927654266, 32.345600947737694, 27.4516611546278, 29.12031501531601, 35.05120776593685, 31.92006178200245, 19.580068141222, 12.035986203700304, 46.16000287234783, 61.679320111870766, 69.91951614618301, 29.636667408049107, 14.82291055843234, 6.040896847844124, 48.948570638895035, 61.6163194924593, 48.90520356595516, 63.77216041088104, 72.41330713033676, 51.65967956185341, 54.04358424246311, 65.47314673662186, 68.54691579937935, 67.25892931222916, 70.14593079686165, 70.94274803996086, 77.46217980980873, 69.8971277475357, 72.40565434098244, 75.57712376117706, 26.2198793515563, 38.57849769294262, 47.747006714344025, 31.185722686350346, 58.09902302920818, 50.53183928132057, 64.75987941026688, 85.91845124959946, 45.41620418429375, 56.97988048195839, 77.53260523080826, 24.879759661853313, 1.1111528822220862, 0.38960945152211934, 0.9023112792056054, 0.12530111154774204, 0.3443286765832454, 0.22408165008528158, 0.23622847016667947, 0.3591187298297882, 0.21318600192898884, 0.279565931414254, 0.20069059508387, 0.19393111404497176, 0.31901740352623165, 0.3445475804619491], [0.025298882901552133, 0.043175776954740286, 0.1293905678903684, 0.03485365574306343, 0.023386565007967874, 0.06524045078549534, 0.06419852739782073, 0.03256349933508318, 0.02358500045374967, 0.04251599282724783, 0.04158606694545597, 0.36620252940338105, 0.0732830680499319, 0.4656549490755424, 0.17977175273699686, 0.18642029754118994, 0.03312385051685851, 0.642294556600973, 0.24856183648807928, 14.443263430148363, 85.11043220758438, 52.689906880259514, 38.19004833698273, 99.58229005336761, 90.64868062734604, 78.24392706155777, 46.49495489895344, 24.177950620651245, 12.443182803690434, 39.34488616883755, 26.964388601481915, 29.59263537079096, 57.969898357987404, 64.8681204020977, 57.33381249010563, 58.105163499712944, 70.98474338650703, 26.95203546434641, 29.253036193549633, 54.12798151373863, 79.6773013472557, 84.36931997537613, 46.38717368245125, 57.72774875164032, 39.29641216993332, 45.37924736738205, 57.33505882322788, 2.99830368719995, 1.1048980616033077, 19.686061553657055, 32.58232444524765, 28.07140599936247, 15.521091744303703, 16.06649737805128, 28.921720571815968, 25.62693826854229, 27.09101490676403, 24.12004742771387, 20.288323536515236, 25.798903740942478, 25.211679451167583, 22.66187947243452, 21.00769143551588, 9.819164257496595, 8.385751973837614, 23.48939336836338, 21.722288690507412, 16.51145540177822, 21.829129457473755, 19.817221015691757, 16.709595769643784, 22.494101375341415, 10.16507014632225, 2.268506297841668, 5.559594249352813, 1.0840653232298791, 0.7756481633987278, 0.3132828581146896, 0.3221477527404204, 0.24752777244430035, 5.39652599953115, 7.937431130558252, 15.915125850588083, 16.102878525853157, 11.003319416195154, 4.667647685855627, 5.621681967750192, 16.246056742966175, 21.54815163463354, 13.372286148369312, 3.1717330310493708, 2.9563508508726954, 2.041491041891277, 2.624435336329043, 2.8185533825308084, 0.43602648423984647, 0.5472140992060304, 0.06506268415250815, 0.04202642769087106, 0.10940107255009934, 0.19918829522794113, 0.3136915439972654, 0.5136883200611919, 0.1856361294630915, 0.7195944618433714, 6.593030970543623, 11.825240012258291, 11.631473209708929, 29.32236347347498, 22.07884445786476, 24.230441004037857, 23.195914216339588, 10.98144019022584, 26.22352335602045, 27.36623603850603, 33.896373733878136, 41.65679611265659, 37.2274573892355, 23.54899886995554, 12.987881675362587, 13.306496478617191, 24.456302784383297, 26.474216803908348, 21.61194071173668, 24.9818791821599, 28.622099049389362, 29.864831864833832, 14.920556768774986, 8.444659262895584, 32.248101979494095, 49.87608566880226, 49.683679193258286, 16.536165475845337, 2.4952299194410443, 9.98643983155489, 49.627263620495796, 35.33487394452095, 31.056862100958824, 59.33989964425564, 58.1383091211319, 48.685647547245026, 60.42247675359249, 56.907357573509216, 60.631203353405, 63.17375712096691, 58.38434211909771, 53.6775878816843, 41.221890449523926, 66.19267612695694, 48.63984100520611, 20.397715866565704, 31.55532505363226, 27.39741336554289, 25.568539202213287, 45.628096014261246, 38.23982946574688, 79.46962729096413, 39.33691419661045, 20.129313468933105, 41.7257434129715, 22.17060763388872, 0.2720270468853414, 0.12678723258432, 0.016084301278169733, 0.04956071461492684, 0.006072080668673152, 0.09299068828113377, 0.09397561472724192, 0.013847890277247643, 0.011703722666425165, 0.06309198521194048, 0.09451629899558611, 0.09588086366420612, 0.03564892635040451, 0.04599423860781826, 0.07524843837018125, 0.01119678106988431, 0.058330859246780165, 0.07554688563686796, 0.04878124804235995, 0.038364281426765956, 0.18034556647762656, 0.06953615738893859, 0.03437953469983768, 0.030675525740662124, 0.13331425812793896, 0.018617991590872407, 0.31689364404883236, 0.023563097820442636, 0.31074269441887736, 0.17660533514572307, 0.18202883162302896, 0.09135048254393041, 0.6811763858422637, 0.27799373609013855, 19.07612968236208, 98.54249104857445, 56.80585741996765, 47.27659955620766, 110.60631170868874, 89.12633031606674, 93.33998501300812, 47.43636958301067, 27.014441415667534, 20.85271865129471, 32.34307788312435, 32.44240075349808, 39.981952384114265, 55.585689693689346, 67.2910375893116, 57.77084983885288, 60.19475497305393, 69.4365468621254, 30.35341154783964, 29.631322994828224, 56.89408868551254, 74.1577859222889, 73.24002876877785, 50.32144457101822, 64.10520493984222, 35.9963234513998, 43.05395074188709, 56.527054980397224, 2.0740574318915606, 3.170438250526786, 33.03901433944702, 39.8811399936676, 42.507319673895836, 28.873292170464993, 17.627330124378204, 24.018940553069115, 26.00767783820629, 23.80445536226034, 23.70663721114397, 22.462610565125942, 23.054358512163162, 24.65399857610464, 23.705938048660755, 20.9376060962677, 12.284181285649538, 9.190087113529444, 34.82775695621967, 19.51313093304634, 16.718420796096325, 21.20306935161352, 19.033989943563938, 23.48905708640814, 37.441613897681236, 29.45210751146078, 6.260734526440501, 1.426883521489799, 0.5871018650941551, 1.2552977912127972, 0.17635514232097194, 0.32097536721266806, 0.5052921955939382, 3.4177600918337703, 4.722012793645263, 17.76717022061348, 18.532107174396515, 14.804995469748974, 6.768978154286742, 7.696181600913405, 19.633238688111305, 22.99099501222372, 19.36961453408003, 7.791174128651619, 4.889738643541932, 1.2353406683541834, 5.904245730489492, 6.7066458240151405, 3.004320664331317, 0.16883740900084376, 0.0401291160233086, 0.1400425095926039, 0.10258094320306554, 0.14478631754172966, 0.33264068188145757, 0.4707272019004449, 0.28913574758917093, 1.2858736817725003, 13.998122066259384, 15.601277891546488, 21.874244436621666, 47.30189099907875, 22.79838714748621, 22.370444610714912, 27.390239350497723, 19.438926614820957, 29.636072739958763, 29.18361011892557, 38.9321219176054, 37.16566130518913, 20.060155279934406, 15.868375059217215, 13.35309337824583, 22.001756094396114, 26.783280819654465, 22.742748633027077, 17.859778851270676, 27.173633873462677, 25.760689191520214, 24.015169255435467, 15.957958102226257, 18.9838345348835, 60.22017560899258, 59.74548988044262, 47.081168442964554, 22.836850583553314, 13.109615743160248, 10.548473373055458, 46.25566653907299, 42.89190083742142, 39.499366879463196, 63.28430838882923, 57.028130292892456, 53.24594244360924, 65.21003365516663, 63.927389681339264, 65.78636392951012, 67.17834323644638, 62.46188051998615, 62.42166347801685, 48.38694177567959, 73.19434002041817, 54.08734269440174, 34.23900134861469, 21.11857518553734, 29.75862756371498, 24.40806247293949, 41.40070505440235, 46.70888341963291, 72.34044224023819, 50.95563054084778, 26.99274268001318, 51.02949097752571, 26.286400482058525, 1.0458930465392768, 0.059031327909906395, 0.1348536802106537, 0.15990909043466672, 0.07317814321140759, 0.07675445638597012, 0.06955017655855045, 0.08589643184677698, 0.11071877801441588, 0.027627588315226603, 0.06709915964165702, 0.04542418013443239, 0.018587268532428425, 0.08755173286772333, 0.08094740522210486, 0.14140436542220414, 0.2558693935861811, 0.24569064524257556, 0.08324579946929589, 0.130002869409509, 0.36341638828162104, 0.12007018754957244, 0.1847952019306831, 0.13109547406202182, 0.2905824308982119, 0.12450116541003808, 0.28261167579330504, 0.1629444447462447, 0.35142515203915536, 0.3402025136165321, 0.32034106843639165, 0.28143317496869713, 1.0565530182793736, 0.5107454967219383, 31.88801810145378, 113.44570934772491, 64.1487430036068, 50.87275318801403, 108.4839203953743, 93.65444853901863, 96.98955237865448, 66.7953009903431, 31.405343301594257, 25.925146266818047, 60.530732944607735, 35.51105909049511, 42.3116909712553, 59.63206596672535, 73.0366712808609, 62.05013081431389, 67.77944058179855, 76.9795449078083, 31.797734946012497, 32.08660304546356, 60.92971533536911, 89.89748373627663, 92.01099872589111, 63.612732365727425, 73.7355449795723, 46.21934808790684, 50.37887468934059, 64.28669080138206, 4.384661195799708, 0.8453976956661791, 31.158721335232258, 42.06136800348759, 38.68611551821232, 21.607838831841946, 18.349063396453857, 34.61590312421322, 32.56592072546482, 34.23675946891308, 31.884507089853287, 30.515222065150738, 32.719086706638336, 31.8936076015234, 31.7623645439744, 29.68577977269888, 21.331109181046486, 14.405735693871975, 34.73743200302124, 30.560014061629772, 23.14517553895712, 31.33606541901827, 28.418561071157455, 30.87239719927311, 55.35713195800781, 40.87279178202152, 16.259724609553814, 8.186620809137821, 0.6988309510052204, 0.8840049302671105, 0.48298507696017623, 0.2943162352312356, 0.8739195589441806, 5.178915951400995, 5.886767143383622, 13.815101087093353, 19.268828742206097, 20.969984158873558, 12.431274242699146, 14.354698732495308, 22.88100801408291, 30.229372903704643, 27.373417653143406, 15.260876007378101, 15.489758625626564, 7.835792284458876, 12.179204318672419, 12.659586891531944, 6.630698824301362, 1.01802593562752, 0.10169477434828877, 0.26853025483433157, 0.40314776881132275, 0.27467244712170213, 0.5822207895107567, 0.5780882737599313, 0.31206523126456887, 1.0717176483012736, 19.836812764406204, 27.328036688268185, 33.92682150006294, 54.331893771886826, 38.88859145343304, 34.518502950668335, 31.26372490078211, 16.141552850604057, 31.17455318570137, 30.254301466047764, 41.3968026638031, 53.59232425689697, 45.02029202878475, 31.5015921369195, 16.164231933653355, 23.3487344160676, 31.78731020539999, 35.3088453412056, 27.10879795253277, 36.44629530608654, 36.27791114151478, 39.519011825323105, 18.037337623536587, 12.25073168054223, 41.61977469921112, 66.03104799985886, 63.163813054561615, 23.961375541985035, 8.500036541372538, 13.324903640896082, 61.047543212771416, 46.49366296827793, 38.768270909786224, 65.36440417170525, 65.1541918516159, 54.10914212465286, 77.01239794492722, 68.69971320033073, 72.7966533601284, 75.37610694766045, 69.05928030610085, 62.837083786726, 52.854654639959335, 77.48168036341667, 61.78531542420387, 32.96076513826847, 42.45389834046364, 40.57975150644779, 34.35235306620598, 71.52689069509506, 54.25068452954292, 99.40955132246017, 58.14358703792095, 39.763961881399155, 65.33848196268082, 57.58397586643696, 2.5418790662661195, 0.1756992915761657, 0.4486201365943998, 0.5086005118209869, 0.1393517036922276, 0.15755655651446432, 0.2193447292665951, 0.2812901482684538, 0.25453943526372313, 0.12510773754911497, 0.1671494683250785, 0.2584475849289447, 0.13419457885902375, 0.23927498637931421, 0.20630768820410594], [0.03785193606745452, 0.09174704915494658, 0.0272778827638831, 0.07663833996048197, 0.02036369918641867, 0.04307985807827208, 0.014389256393769756, 0.043851469017681666, 0.12885162024758756, 0.16280655370792374, 0.28246796631719917, 0.12791832501534373, 0.04571784054860473, 0.02074533378618071, 0.0545109472295735, 0.06477309812908061, 0.09941971322405152, 0.19295884121675044, 0.05305402970407158, 2.2349213249981403, 67.61066883802414, 79.4094081223011, 49.85196836292744, 49.4135744869709, 72.03613176941872, 28.436775393784046, 23.523175455629826, 42.982856556773186, 24.0800678730011, 32.18713045120239, 38.91928240656853, 26.493111290037632, 48.42338941991329, 57.443459406495094, 76.36723056435585, 63.04146721959114, 82.03945219516754, 63.66705805063248, 34.081674590706825, 50.98140075802803, 62.22673013806343, 58.085887134075165, 58.88922482728958, 54.51340243220329, 48.76819811761379, 66.5277573466301, 26.430610343813896, 0.1249024149728939, 5.7989652547985315, 24.695300459861755, 23.06534942239523, 14.816938228905201, 16.136191338300705, 21.874542720615864, 25.094577334821224, 22.42767333984375, 23.46774972975254, 23.00489466637373, 26.212851628661156, 28.992748260498047, 26.39280617237091, 25.73425780981779, 15.642586424946785, 4.173965826630592, 7.80778968706727, 10.73044465854764, 11.076417043805122, 20.44651474803686, 18.78918807953596, 18.70894778519869, 21.445640735328197, 27.226247750222683, 16.789250895380974, 1.8385719554498792, 2.4769745115190744, 0.3670658846385777, 1.125381337478757, 0.45106625533662736, 0.7819853920955211, 0.3896566521143541, 4.445494506508112, 6.797519372776151, 8.715196195989847, 8.68881706148386, 6.168749062344432, 2.276834975928068, 6.364632826298475, 21.004015132784843, 32.7061066031456, 14.902186654508114, 5.60652838088572, 5.576418796554208, 1.5646997513249516, 2.0101061509922147, 0.563935695681721, 2.7309096604585648, 1.1144051514565945, 0.35822426376398653, 0.3691363875987008, 0.08142624632455409, 0.2825223805848509, 0.5378562107216567, 1.068203430622816, 0.2862714137881994, 2.6798738865181804, 6.317711044102907, 11.714913882315159, 8.207675479352474, 21.62605695426464, 29.603413492441177, 10.64878799021244, 9.63125579059124, 13.153780773282051, 25.260816514492035, 29.688399732112885, 26.677935272455215, 30.874749273061752, 35.78728906810284, 26.391901820898056, 21.437174789607525, 21.324868015944958, 16.98576495051384, 21.00806761533022, 20.25807525962591, 21.274932995438576, 25.63029918819666, 24.904756620526314, 24.663298577070236, 18.89745756983757, 8.173275925219059, 38.74493256211281, 60.09480133652687, 44.42338205873966, 10.092213805764914, 2.762758363969624, 8.557575903832912, 49.21451076865196, 41.056397929787636, 42.763323336839676, 45.190047919750214, 53.72780978679657, 61.11456781625748, 58.11569273471832, 58.36689345538616, 58.48201967775822, 61.853035390377045, 42.480306923389435, 63.22471238672733, 57.1073142439127, 40.193243846297264, 15.281299911439419, 36.065046563744545, 17.23459269851446, 37.15631380677223, 36.83516263961792, 52.63266295194626, 67.8763809800148, 25.743565410375595, 31.57305870205164, 28.094229474663734, 4.501525824889541, 0.20162727450951934, 0.22061549389036372, 0.14319310459541157, 0.06124094645201694, 0.05768083065049723, 0.05631476313283201, 0.0694624324387405, 0.05646072131639812, 0.05301247314491775, 0.09289608671679161, 0.028087938808312174, 0.04337753351137508, 0.03360175651323516, 0.06036028062226251, 0.09359659990877844, 0.05754688041633926, 0.0317531779728597, 0.05160117172636092, 0.08480528180371039, 0.057188909195247106, 0.052009041246492416, 0.09288511777413078, 0.09138174922554754, 0.016102367007988505, 0.10810019157361239, 0.1412125350907445, 0.2395733297453262, 0.04490121835260652, 0.09028009037137963, 0.01964145034435205, 0.09207760915160179, 0.0900370221643243, 0.25312564393971115, 0.06774553316063248, 2.4752755276858807, 77.22749680280685, 85.26727259159088, 50.39839804172516, 62.771214321255684, 81.3829842209816, 36.53505094349384, 40.016424134373665, 35.73043271899223, 32.463151440024376, 31.833489127457142, 38.24380025267601, 38.321528881788254, 51.94147624075413, 59.69515398144722, 72.54297897219658, 63.98212194442749, 78.21921318769455, 62.73535564541817, 39.354378059506416, 51.74052022397518, 65.5443625152111, 58.699816390872, 59.00139480829239, 62.08587549626827, 45.20411476492882, 64.96395125985146, 24.363561160862446, 0.3226330876350403, 13.166817873716354, 25.342899709939957, 34.43659454584122, 28.91729760915041, 17.618805281817913, 19.420155622065067, 23.991131745278835, 22.62678075581789, 20.769991390407085, 23.097305707633495, 25.846281498670578, 27.749711461365223, 23.42562709003687, 25.980294607579708, 13.230907134711742, 9.856147672981024, 10.870154611766338, 21.571163199841976, 15.719873327761889, 16.20527733117342, 16.89552739262581, 21.183137521147728, 28.895555175840855, 45.9177240729332, 33.526482582092285, 8.295256979763508, 0.6121681106742471, 0.48646049515809864, 1.03977418737486, 0.6271431071218103, 0.5177000735420734, 1.2329299352131784, 3.0750560062006116, 9.530659038573503, 16.460300646722317, 11.02217685431242, 6.626101545989513, 5.230681523680687, 9.762274660170078, 26.14952802658081, 36.000252440571785, 19.743423275649548, 10.56915471330285, 9.950870890170336, 3.0817766580730677, 3.226262954995036, 1.9476474775001407, 3.5129449842497706, 1.2202755454927683, 0.5786747485399246, 0.48744992644060403, 0.18850904249120504, 0.16357685846742243, 0.4238197876838967, 1.9053021934814751, 0.38646218134090304, 5.296276928856969, 10.957894753664732, 8.748010285198689, 16.24861590564251, 41.13203667104244, 30.113570317626, 12.656208872795105, 13.129951301962137, 20.810542814433575, 32.003281116485596, 29.515189826488495, 31.262915544211864, 35.16270138323307, 27.78878666460514, 13.40360976755619, 17.407042644917965, 21.325491182506084, 22.09532607346773, 22.83825270831585, 18.52949481457472, 18.91563579440117, 26.04373600333929, 22.01163936406374, 24.751478545367718, 18.71116876602173, 13.839613571763039, 67.4789223074913, 61.55810281634331, 37.86025643348694, 19.630217850208282, 9.7719612903893, 7.253286391496658, 45.75100041925907, 44.56411890685558, 47.83274531364441, 54.769998863339424, 58.27722206711769, 66.07998937368393, 66.44774124026299, 68.82643640041351, 66.07219219207764, 69.33983445167542, 49.53648269176483, 70.83154320716858, 67.83820822834969, 54.51470196247101, 20.621527656912804, 26.627291589975357, 23.898690305650234, 22.723519764840603, 47.314019948244095, 55.45278802514076, 71.1641013622284, 36.58590741455555, 38.29496830701828, 48.521834537386894, 9.275159798562527, 0.4654787335311994, 0.14858201699098572, 0.09903913989546709, 0.11410414401325397, 0.08054364720010199, 0.018282774617546238, 0.020412873891473282, 0.08877883694367483, 0.03707485921040643, 0.07835094220354222, 0.06086421744839754, 0.027283022136543877, 0.09393337910296395, 0.056891983331297524, 0.03802395105594769, 0.1514017180306837, 0.14297678339062259, 0.12734969146549702, 0.20326890517026186, 0.19772397849010304, 0.1909475467982702, 0.1890108233783394, 0.13499103690264747, 0.17033954558428377, 0.19809953490039334, 0.40428503591101617, 0.33390173921361566, 0.1411018066573888, 0.15749987127492204, 0.11562286759726703, 0.17006618290906772, 0.28070821543224156, 0.5545567302033305, 0.16696269944077358, 5.578464036807418, 100.92830702662468, 91.88705697655678, 70.23157060146332, 66.58601582050323, 91.37587800621986, 40.23179657757282, 37.929625511169434, 56.129140332341194, 37.1243841201067, 56.972930654883385, 51.072550266981125, 37.672972083091736, 51.705991476774216, 66.847874969244, 79.26823049783707, 71.30059003829956, 89.32072028517723, 71.14662230014801, 40.21260380744934, 52.591670751571655, 65.96352562308311, 63.89536499977112, 68.61459016799927, 71.26789659261703, 52.47558318078518, 73.71577844023705, 35.62984071671963, 0.17714928486384451, 6.808476559817791, 30.01221265643835, 32.897749319672585, 21.766014844179153, 18.448673151433468, 27.79906891286373, 32.5523516535759, 30.783217884600163, 30.19238568842411, 30.505682677030563, 33.36019970476627, 38.91331672668457, 32.43189051747322, 35.87079718708992, 26.203853711485863, 16.765737757086754, 21.095846705138683, 19.93105910718441, 17.674656584858894, 28.6721233651042, 25.608868338167667, 29.876352846622467, 34.5466024428606, 63.221231773495674, 42.62334644794464, 21.421903409063816, 5.829848097637296, 0.3359829884720966, 1.2693940848112106, 0.7050297246314585, 0.538942061830312, 0.8437919849529862, 3.574424972757697, 8.002575784921646, 10.425111092627048, 11.516372635960579, 11.444677133113146, 13.077206332236528, 16.838045977056026, 33.69755320250988, 39.69050422310829, 26.541076116263866, 20.91326840221882, 23.470508381724358, 16.655879952013493, 8.943191561847925, 8.698505591601133, 10.63543550670147, 2.6024064933881164, 0.7324301730841398, 0.5290779692586511, 0.31563148833811283, 0.4206355882342905, 0.5190232337918133, 2.688640016131103, 0.6398018903564662, 5.4968249425292015, 20.1498893648386, 20.839312970638275, 31.04038618505001, 47.24664196372032, 46.922089979052544, 14.843271765857935, 14.223622865974903, 20.448547638952732, 30.146132670342922, 34.820666536688805, 32.116268053650856, 42.045758441090584, 47.668525725603104, 38.18898819386959, 27.849372513592243, 26.776260696351528, 25.58189168572426, 29.801000989973545, 29.59452386945486, 27.01445661485195, 37.57560610771179, 31.791111901402473, 36.551542058587074, 23.678841702640057, 13.444679863750935, 54.16787937283516, 77.28366538882256, 57.955402135849, 23.055124171078205, 7.164147449657321, 12.567367739975452, 56.40633165836334, 48.9885862916708, 50.080700889229774, 57.10219591856003, 64.25658121705055, 69.57406908273697, 71.22937425971031, 75.40783524513245, 71.30206435918808, 75.99501013755798, 52.1485461294651, 74.84116405248642, 70.53457394242287, 60.00375062227249, 22.42790512740612, 54.236469492316246, 24.09506756812334, 54.62601698935032, 56.05822093784809, 73.3339673280716, 89.27028939127922, 44.61366064846516, 53.64099584519863, 70.46507567167282, 17.489218935370445, 1.0767153301276267, 0.4327320016454905, 0.3126535168848932, 0.16487496381159872, 0.2940283709904179, 0.2002408535918221, 0.3844845062121749, 0.09931917447829619, 0.15163196192588657, 0.2480045281117782, 0.15583320055156946, 0.16144941793754697, 0.23612746386788785, 0.154382687760517, 0.19186948717106134], [0.19203687115805224, 0.08190669788746163, 0.04223404350341298, 0.0442797142022755, 0.04040448991872836, 0.02689522400032729, 0.22739729873137549, 0.026787568058352917, 0.13501451845513657, 0.11138364585349336, 0.17159671406261623, 0.14398604485904798, 0.0804103203699924, 0.02441599062876776, 0.1086662795569282, 0.05533389252377674, 0.15427290927618742, 0.10510301333852112, 0.7478268281556666, 0.3414511919254437, 24.336369819939137, 93.05234044790268, 65.61031937599182, 49.94991950690746, 76.7713312804699, 60.23476302623749, 23.713733330368996, 67.98810258507729, 20.760214515030384, 25.907026939094067, 38.15489262342453, 22.419040203094482, 39.305250495672226, 67.21852988004684, 57.24227540194988, 62.223158329725266, 69.10711973905563, 74.38801556825638, 57.30302654206753, 56.83246359229088, 70.66499054431915, 51.11764244735241, 66.29174441099167, 58.83355401456356, 48.22071209549904, 66.29224598407745, 8.414871711283922, 3.253637161105871, 21.938607282936573, 42.245775908231735, 20.675080083310604, 16.556330993771553, 21.046082675457, 21.89319781959057, 23.645724579691887, 20.7454352080822, 22.76384510099888, 24.640875980257988, 23.651424273848534, 22.59102087467909, 24.834979064762592, 19.885317161679268, 14.482476375997066, 4.87238734960556, 2.8460028721019626, 17.25558467209339, 7.981647457927465, 19.16580107063055, 18.288836628198624, 19.72835898399353, 27.07833308726549, 36.31398640573025, 23.741618134081364, 3.8577047595754266, 1.131853221450001, 2.3633667826652527, 0.7071719190571457, 0.6527812813874334, 0.4053831472992897, 2.2595665650442243, 3.452046839520335, 3.20522490888834, 5.48202283680439, 4.262763736769557, 2.4326779134571552, 5.366473412141204, 4.515443528071046, 26.34356841444969, 35.180818811059, 14.383846018463373, 6.507429638877511, 6.269661672413349, 3.3052217680960894, 3.4941253066062927, 2.912817536853254, 3.921551308594644, 0.12678994884481654, 0.039441553308279254, 0.029375360936683137, 0.3734374005580321, 0.40431855130009353, 0.46701578074134886, 0.5269504990428686, 0.1271791459294036, 4.111265866085887, 3.12345614656806, 7.311734855175018, 7.338547641411424, 12.804247979074717, 26.45851794630289, 22.055616304278374, 19.930010363459587, 15.52879773080349, 13.369203563779593, 27.37909834831953, 24.334642812609673, 21.22931644320488, 24.146254621446133, 31.161314696073532, 20.942551530897617, 18.019655272364616, 22.945604547858238, 20.955436639487743, 21.92696090787649, 28.43657400459051, 29.451649636030197, 29.172476716339588, 23.75679261982441, 34.242998734116554, 32.36045055091381, 13.538770414888859, 50.956930071115494, 63.50172132253647, 32.058556750416756, 9.081335999071598, 0.19935514486860484, 13.713702578097582, 76.19849681854248, 56.47968292236328, 47.632442861795425, 52.030904442071915, 59.36234503984451, 61.47151306271553, 63.71314957737923, 56.366243809461594, 54.63616244494915, 54.07030440866947, 55.35054691135883, 47.63753078877926, 26.232361681759357, 23.57614081352949, 21.705793775618076, 19.830296114087105, 47.98268526792526, 29.04759831726551, 55.270386412739754, 45.79742252826691, 34.64776821434498, 42.489867210388184, 23.463387563824654, 1.2779370951466262, 0.00866133001181879, 0.21447107515996322, 0.04013983634649776, 0.08774481000727974, 0.09818924721912481, 0.11548849433893338, 0.11272802410530858, 0.046895458217477426, 0.07336159469559789, 0.05940052040386945, 0.07436647749273106, 0.06915102727361955, 0.0808443060668651, 0.06010672957927454, 0.05377605033572763, 0.1533491729060188, 0.056595012938487343, 0.06841850525233895, 0.016665170987835154, 0.05779870225524064, 0.08485524318530224, 0.21670207497663796, 0.055237457854673266, 0.1951049838680774, 0.08078163169557229, 0.1895787741523236, 0.08183177807950415, 0.05164568574400619, 0.03451961878454313, 0.07928443781565875, 0.019145068581565283, 0.07551080241682939, 0.11158139110193588, 0.5855247122235596, 0.4414506338071078, 29.511817507445812, 99.09154638648033, 68.15748989582062, 49.05550830066204, 86.09484538435936, 58.40797305107117, 30.948273427784443, 49.89986099302769, 25.345325879752636, 29.961665868759155, 32.99653261899948, 34.948446080088615, 40.508991703391075, 68.08574974536896, 57.56753034889698, 63.21726478636265, 69.89116966724396, 77.73446559906006, 58.75608757138252, 58.72017949819565, 70.30664697289467, 54.12764713168144, 63.64460505545139, 60.76847478747368, 45.94827823340893, 61.343600526452065, 9.472693149000406, 9.212699700146914, 18.574476800858974, 46.945800706744194, 34.6287502348423, 16.512927822768688, 17.69135668873787, 19.561154656112194, 22.233106680214405, 20.78800242394209, 19.692070931196213, 24.725628532469273, 22.660595141351223, 24.900240562856197, 25.740058198571205, 20.913597084581852, 11.706503033638, 11.112978681921959, 6.947899153456092, 27.972770892083645, 9.634774401783943, 15.845575332641602, 20.23868680000305, 24.614896774291992, 32.982549369335175, 56.41233533620834, 34.28168445825577, 17.140344455838203, 2.351617575623095, 1.315176165662706, 1.151805950794369, 0.38088440720457584, 1.1760288197547197, 2.697251779027283, 2.645809664390981, 6.685469560325146, 8.052848037332296, 5.30497276224196, 3.030720460228622, 6.0025830287486315, 12.304841727018356, 36.123058050870895, 38.535480201244354, 19.578933902084827, 17.394634410738945, 15.138420928269625, 6.610374189913273, 3.768907799385488, 3.3767339307814837, 4.03510607779026, 0.11992623316473328, 0.03985494069638662, 0.12771001900546253, 0.5548621388152242, 0.16432387463282794, 0.6203107174951583, 0.8186897006817162, 0.37973903585225344, 4.265088737010956, 4.404590651392937, 5.006486428901553, 10.994301550090313, 32.35579200088978, 33.40612784028053, 19.944801069796085, 15.908710844814777, 21.89076405018568, 20.093899369239807, 27.018790282309055, 25.117723792791367, 27.343277670443058, 25.244370996952057, 15.891651660203934, 11.929043792188168, 17.995028793811798, 24.94806669652462, 25.062619149684906, 20.304579064249992, 29.36162866652012, 26.378551237285137, 29.483949802815914, 19.921202436089516, 32.4171207100153, 22.88192566484213, 29.42846328020096, 77.3686896264553, 58.65154758095741, 29.90020226687193, 25.41991587728262, 2.2281880863010883, 9.270139317959547, 75.57042092084885, 56.3608480989933, 52.16856725513935, 51.52086541056633, 67.52106964588165, 63.98586854338646, 72.65294507145882, 62.386644557118416, 64.47842091321945, 59.414774626493454, 64.19956147670746, 56.928803622722626, 41.591093838214874, 21.688953079283237, 26.118320301175117, 20.829708985984325, 25.931087248027325, 36.37699082493782, 57.203209698200226, 59.03920277953148, 42.69267372786999, 54.378517270088196, 36.53306744992733, 1.7747020139358938, 0.011179981629538815, 0.21035930985817686, 0.03342416799569037, 0.062012442358536646, 0.07647408041520976, 0.049374676746083423, 0.06346127789583988, 0.011494721820781706, 0.14062481350265443, 0.009726924199640052, 0.05461741573526524, 0.03989946584624704, 0.018192946918134112, 0.0606895604141755, 0.14433293952606618, 0.4666850797366351, 0.13506675080861896, 0.17799263179767877, 0.11433161227614619, 0.2003276106552221, 0.18888780497945845, 0.2604708872968331, 0.133180879347492, 0.28701587696559727, 0.26332803710829467, 0.34196238324511796, 0.12433724725269713, 0.32866143446881324, 0.1255925529403612, 0.1613158907275647, 0.32481443777214736, 0.19755217130295932, 0.28280754340812564, 0.9769863565452397, 0.7343120221048594, 45.02820700407028, 112.97150239348412, 81.50965422391891, 67.3724976181984, 98.15773129463196, 73.7009060382843, 44.3282313644886, 99.23167526721954, 33.13728466629982, 48.1835462898016, 51.04068897664547, 31.91672556102276, 42.6255389302969, 72.88282513618469, 65.5671688914299, 65.76278999447823, 74.27438646554947, 82.99849033355713, 65.07343858480453, 60.56093372404575, 73.4461297094822, 65.69215178489685, 71.35943368077278, 67.71196380257607, 48.76019574701786, 71.67920932173729, 9.538429621607065, 3.8843762408941984, 24.344294294714928, 53.650791719555855, 29.003121703863144, 18.505738489329815, 26.372450664639473, 26.909076869487762, 29.333781860768795, 28.307612724602222, 30.386006198823452, 33.321905359625816, 32.03660912811756, 31.39284387230873, 33.946709632873535, 28.75539019703865, 26.961362063884735, 20.18947184085846, 13.253184389322996, 31.515541188418865, 12.019091360270977, 29.010208323597908, 26.144231110811234, 31.33262660354376, 40.71765370666981, 69.76975858211517, 49.47706148028374, 26.466721706092358, 6.787506910040975, 2.176261735148728, 1.9039286859333515, 0.4421725060092285, 1.9209953513927758, 2.0086152059957385, 2.9937429819256067, 5.187674481421709, 6.2587363086640835, 6.571018751710653, 9.0005599334836, 16.296343244612217, 24.588624984025955, 43.700505048036575, 43.36817868053913, 27.6849914342165, 28.24286799877882, 29.22641672194004, 20.847127251327038, 12.325042393058538, 14.006783701479435, 9.84258335083723, 0.16707038506865501, 0.181281385011971, 0.18695405015023425, 0.5602034053299576, 0.8650603343266994, 0.49925924744457006, 0.717883959878236, 0.3520375129301101, 5.144542995840311, 4.735655011609197, 17.1973242983222, 28.74589830636978, 42.22385488450527, 43.73760245740414, 33.66280406713486, 25.40704596787691, 28.288391456007957, 18.234233558177948, 31.540445052087307, 26.742710396647453, 32.194163873791695, 33.54950934648514, 45.402414724230766, 31.327228993177414, 25.459369160234928, 30.749749280512333, 32.475139796733856, 29.534399695694447, 39.85805243253708, 39.33765895664692, 36.99245899915695, 28.770298697054386, 46.96297578513622, 33.698484152555466, 24.49659962207079, 65.86029276251793, 84.19209748506546, 40.72714559733868, 27.499599382281303, 1.0227034846320748, 21.822293624281883, 82.23497450351715, 65.40859580039978, 57.965490594506264, 60.320144444704056, 72.02149495482445, 73.90831410884857, 73.19575354456902, 71.88460350036621, 67.9725082218647, 67.9483263194561, 69.54660415649414, 58.52586552500725, 40.81628501415253, 36.9317040592432, 36.78605027496815, 30.8148055896163, 72.1707433462143, 46.16456642746925, 73.82400423288345, 65.28498843312263, 52.93530531227589, 68.81312191486359, 55.25402069091797, 2.751008444465697, 0.2954022941412404, 0.27104506676550955, 0.13824866444338113, 0.1650203950703144, 0.21178941358812153, 0.31109408650081605, 0.17017829173710197, 0.15758511435706168, 0.2074224830721505, 0.19225454307161272, 0.19961256621172652, 0.20072486746357754, 0.11150186255690642, 0.17465379845816642, 0.16415375954238698], [0.041487268536002375, 0.037643258983734995, 0.020505061620497145, 0.13881465594749898, 0.024482095577695873, 0.1026187110983301, 0.05169682714040391, 0.09274514872231521, 0.06478802271885797, 0.06017081774189137, 0.07383095115073957, 0.13529218558687717, 0.08682268409756944, 0.1149014852126129, 0.053441189593286254, 0.021859316002519336, 0.08002956150448881, 0.06431163812521845, 0.18226376589154825, 0.43000324338208884, 1.4446854474954307, 73.20085287094116, 75.69767609238625, 54.38691481947899, 48.46702627837658, 88.5378710925579, 52.419824972748756, 50.99656954407692, 43.56527790427208, 29.73084345459938, 44.91475269198418, 24.308209531009197, 44.70483675599098, 62.32016332447529, 53.02719958126545, 65.43076381087303, 69.78617370128632, 68.1787383556366, 72.85681933164597, 73.01905542612076, 59.06355567276478, 52.98071667551994, 65.48166587948799, 52.87466436624527, 58.58323484659195, 34.291259944438934, 1.6936528380028903, 10.30723286792636, 43.258831948041916, 27.931037731468678, 15.966557040810585, 20.78645210713148, 23.899229876697063, 21.250627599656582, 20.971414782106876, 20.823027044534683, 21.28108486533165, 27.472105957567692, 25.329471230506897, 23.285061232745647, 22.596857361495495, 18.637391924858093, 11.253067664802074, 2.8310865350067616, 2.6231904281303287, 18.14690474420786, 16.425929591059685, 13.333368636667728, 13.673266097903252, 24.020399674773216, 34.507912918925285, 40.96570439636707, 25.05559902638197, 10.134440939873457, 5.009042741730809, 2.1343022491782904, 0.9364869422279298, 1.3902132329531014, 1.6102625126950443, 2.361741657368839, 3.4397675609216094, 2.45351979508996, 2.937437128275633, 2.937285848893225, 2.389016356319189, 2.962294206954539, 16.416986770927906, 35.8157267421484, 38.65256331861019, 16.26910250633955, 9.891150444746017, 9.298309106379747, 4.624957451596856, 3.2435477524995804, 0.7403181935660541, 3.7108310032635927, 0.13498984946636483, 0.2551956125535071, 0.27402897540014237, 0.10528912171139382, 0.8134950825478882, 2.5955993961542845, 0.4134283843450248, 0.5435021140147, 2.3269891971722245, 1.184109679888934, 4.606089564040303, 5.8393285889178514, 8.351858742535114, 20.123851262032986, 17.417873963713646, 20.63036598265171, 17.20758754760027, 19.579127691686153, 20.344328731298447, 19.577497579157352, 16.831818111240864, 21.944724954664707, 23.201967291533947, 26.401027031242847, 22.05172721296549, 23.31137292087078, 18.921426683664322, 20.40708616375923, 19.68325350433588, 30.62245801091194, 25.70015273988247, 29.530263617634773, 27.02222339808941, 45.7337911427021, 29.021695107221603, 14.23717388883233, 61.43809385597706, 49.38234396278858, 33.882249891757965, 2.884453246369958, 1.7950693960301578, 37.70109437406063, 62.036200761795044, 57.62429930269718, 59.81393940746784, 57.69719839096069, 67.14736729860306, 60.32330207526684, 65.69720551371574, 56.74306198954582, 69.80778694152832, 58.91301155090332, 48.15634734928608, 24.63693179190159, 22.26055260747671, 15.654627028852701, 31.86321873217821, 47.784016728401184, 104.07247111201286, 54.394157230854034, 50.53671821951866, 38.32512728869915, 35.20583666861057, 7.776596210896969, 0.525818575406447, 0.19901605759514496, 0.09101328032556921, 0.18715736892772838, 0.17544347327202559, 0.13666121056303382, 0.10383445289335214, 0.022905170917510986, 0.07072044696542434, 0.07757912346278317, 0.037543213766184635, 0.13736207998590544, 0.10031569327111356, 0.09450848418055102, 0.030619558528997004, 0.06065582980227191, 0.04730985492642503, 0.04223648145853076, 0.08902375309844501, 0.056320306975976564, 0.03296805887657683, 0.11183751368662342, 0.02966134197777137, 0.08539503687643446, 0.06532494429848157, 0.10980129794916138, 0.05496971323736943, 0.03598234732635319, 0.19324719527503476, 0.06555443120305426, 0.07362149481195956, 0.15280991356121376, 0.032068935834104195, 0.12225341532030143, 0.12405388042679988, 0.27422312123235315, 1.9169287383556366, 75.45013457536697, 87.16419160366058, 55.64432814717293, 61.613933220505714, 88.4765575826168, 49.72808741033077, 46.0761109739542, 35.75117960572243, 37.57332623004913, 36.365967616438866, 35.26687279343605, 43.63588571548462, 66.62175670266151, 56.35395526885986, 64.97709855437279, 72.33020558953285, 69.39196765422821, 73.65293741226196, 72.15054363012314, 61.88581243157387, 53.861004039645195, 68.66051450371742, 52.86806792020798, 58.70270423591137, 22.887306176126003, 5.8635123912245035, 13.124972619116306, 29.128647968173027, 36.16762585937977, 9.212826043367386, 15.762727428227663, 19.63757235556841, 18.854430578649044, 20.41331022977829, 18.36817067116499, 19.762013778090477, 28.832879438996315, 23.045740574598312, 23.269077390432358, 22.95419968664646, 17.273930087685585, 9.308410864323378, 7.914843242615461, 7.5760681461542845, 21.88628789037466, 20.179685465991497, 12.777445167303085, 15.072393771260977, 26.30900736898184, 41.258927062153816, 61.84990055859089, 36.16392865777016, 19.091794341802597, 10.408271346241236, 1.442876032087952, 0.9566762088797987, 1.1264825658872724, 2.6147216325625777, 1.4152325154282153, 4.344842182472348, 5.952826123684645, 3.8068886613473296, 2.460010559298098, 1.962570226751268, 10.406865421682596, 27.854648530483246, 41.55602551996708, 44.14176017045975, 22.622367292642593, 22.530239336192608, 18.408288918435574, 9.13844883441925, 4.101619608700275, 2.264025625772774, 3.1478731613606215, 0.2234127969131805, 0.1795284915715456, 0.19956024480052292, 0.17030772229190916, 0.6073949136771262, 2.4583968333899975, 2.7609931211918592, 0.5733330070506781, 4.278024667873979, 1.6450950060971081, 3.4785670414566994, 7.367149656638503, 23.120611757040024, 31.14069890230894, 21.76928646862507, 15.877134539186954, 22.915717251598835, 25.569996424019337, 32.177399173378944, 22.44179528206587, 24.432909339666367, 24.832022823393345, 20.99067784845829, 9.14082845672965, 9.32544345036149, 20.8336740732193, 18.343519493937492, 22.10547722876072, 19.659529477357864, 30.1374539360404, 28.333033360540867, 26.373685598373413, 26.62818644195795, 54.82235625386238, 29.797915555536747, 31.975679397583008, 84.40693035721779, 47.79267646372318, 48.837555795907974, 24.208759367465973, 4.594056559726596, 32.751757353544235, 67.68012151122093, 61.11889958381653, 63.88297766447067, 62.96496972441673, 73.0534815788269, 67.99730569124222, 71.49037465453148, 65.22454887628555, 73.6101821064949, 68.34249436855316, 54.627445712685585, 35.34541077911854, 21.92116241902113, 24.350039586424828, 19.39882356673479, 43.414608389139175, 96.69705167412758, 59.18898694217205, 63.98408263921738, 45.52948750555515, 53.29910919070244, 15.714873746037483, 0.9309456520713866, 0.06638398903305642, 0.22605359583394602, 0.26815802324563265, 0.14860290102660656, 0.02757163038040744, 0.22915532783372328, 0.06844692950835451, 0.1494791844743304, 0.0969661507406272, 0.06138257420388982, 0.12030015685013495, 0.19708467763848603, 0.017567054819664918, 0.12526771490229294, 0.03787777393881697, 0.1645259911310859, 0.1420803728979081, 0.18893994827521965, 0.1719453453551978, 0.10411783456220292, 0.31524120771791786, 0.249685047310777, 0.17591816576896235, 0.1053552767552901, 0.11095420952187851, 0.3105108771706, 0.23723546066321433, 0.21372316841734573, 0.22498408681713045, 0.2639233286026865, 0.20802262821234763, 0.1774703527917154, 0.28241806430742145, 0.4216347268084064, 0.6971268018241972, 3.083785562776029, 96.72857478260994, 95.66145524382591, 74.40563902258873, 72.12500900030136, 105.28453007340431, 71.63905307650566, 78.78763988614082, 59.31329347193241, 49.12388563156128, 65.52971050143242, 33.9124620705843, 48.64769898355007, 67.78827130794525, 65.4694913327694, 69.53547835350037, 76.84418097138405, 71.99200093746185, 79.7014756500721, 74.42804262042046, 65.76416552066803, 61.78581699728966, 75.29032275080681, 54.076961651444435, 61.73392318189144, 32.47027225792408, 2.919591385871172, 11.555032711476088, 44.155462235212326, 42.138370871543884, 18.791388161480427, 30.290139243006706, 30.17628025263548, 27.070773392915726, 29.542536959052086, 27.148277834057808, 27.37940803170204, 38.328140527009964, 33.348196148872375, 31.942963153123856, 31.47145215421915, 29.53995119780302, 24.769970253109932, 16.69980749487877, 16.28080777823925, 28.550136610865593, 22.143000215291977, 23.3680297806859, 19.966307915747166, 33.690344989299774, 49.33016136288643, 76.12867176532745, 48.47711853682995, 25.26270691305399, 16.669817604124546, 2.5616456056013703, 0.8970888750627637, 1.6071916837245226, 2.3679412622004747, 2.802136125974357, 5.00466775149107, 4.240746293216944, 3.126404550857842, 5.723377810791135, 5.5722209718078375, 24.130776152014732, 37.99101501703262, 44.61392663419247, 45.67131869494915, 30.375307872891426, 31.541581191122532, 31.31305005401373, 27.00452394783497, 14.918801262974739, 11.93460764363408, 5.370332580059767, 0.3366773121524602, 0.4514635121449828, 0.556860831566155, 0.1230725459754467, 0.7211367634590715, 3.6284362245351076, 4.6663913782685995, 0.42112641502171755, 4.348056335002184, 1.0354285268113017, 8.826811406761408, 27.596629075706005, 37.39032804965973, 38.790849298238754, 32.288850992918015, 25.92146046459675, 27.975345253944397, 30.723355896770954, 31.210204772651196, 23.922649919986725, 26.47913184016943, 33.39147962629795, 37.98443756997585, 38.823367953300476, 33.36925841867924, 36.32628634572029, 29.027356803417206, 30.150456838309765, 25.540665797889233, 41.05835862457752, 36.04979798197746, 36.21166929602623, 30.397042706608772, 56.117170974612236, 31.31136104464531, 24.159185327589512, 86.52639582753181, 67.30872943997383, 51.280216723680496, 20.3475908562541, 4.132699090987444, 52.42093451321125, 73.39211940765381, 69.52277183532715, 71.15426748991013, 71.0140398144722, 82.70984262228012, 72.1736691892147, 72.81544715166092, 67.33774468302727, 81.93149998784065, 74.41062435507774, 63.786903619766235, 40.26853300631046, 35.77853813767433, 30.353037267923355, 45.8224555850029, 74.0933945775032, 106.34460479021072, 71.99180334806442, 73.55765372514725, 51.03510707616806, 73.09396460652351, 25.058519169688225, 1.3574006874114275, 0.269642288913019, 0.4245840513613075, 0.4971587914042175, 0.22438701416831464, 0.3483208967372775, 0.310695196967572, 0.1776514368248172, 0.1743438033736311, 0.19901173829566687, 0.15551536838756874, 0.3924413683125749, 0.36409580963663757, 0.22470443072961643, 0.3013222280424088, 0.11214697442483157], [0.06877445412101224, 0.04078205383848399, 0.09764724192791618, 0.11727213495760225, 0.0162828536122106, 0.12045684648910537, 0.15582908905344084, 0.1472172370995395, 0.03788067573623266, 0.21758054033853114, 0.07264493237016723, 0.24057769303908572, 0.11871093665831722, 0.08252172308857553, 0.09563412182615139, 0.23603137058671564, 0.20386784803122282, 0.33206830790732056, 0.07809306072886102, 0.6460999336559325, 0.5671890336088836, 17.238280400633812, 95.20737200975418, 68.5053688287735, 43.351862356066704, 82.1968549489975, 78.51217746734619, 39.93166968226433, 49.03462462127209, 28.726059570908546, 47.05489285290241, 23.06524682790041, 45.17884612083435, 64.75322216749191, 52.16721832752228, 65.18280431628227, 65.29197245836258, 71.64818778634071, 62.1796240657568, 66.99370354413986, 61.551240384578705, 59.429757222533226, 61.62988856434822, 57.50616744160652, 40.61187118291855, 3.285678466781974, 4.552486315369606, 28.937181942164898, 48.615244925022125, 25.414751954376698, 38.19908045232296, 17.383780293166637, 23.072694428265095, 19.044388085603714, 23.19853987544775, 20.333111733198166, 23.814851604402065, 25.384190194308758, 21.542562134563923, 21.169712841510773, 24.913883730769157, 14.704838544130325, 11.879779435694218, 3.6840930255129933, 6.770514696836472, 17.999347262084484, 9.512181580066681, 15.300011057406664, 20.148606933653355, 22.673066072165966, 36.51465363800526, 45.21316207945347, 23.827930502593517, 14.015555530786514, 13.863356597721577, 1.6657389421015978, 2.112821526825428, 1.875175628811121, 2.102656834758818, 0.7481513544917107, 3.2353354431688786, 1.8723378935828805, 0.5790059245191514, 3.033932950347662, 3.7361635314300656, 9.03098775073886, 35.40953613817692, 36.622852832078934, 25.74713721871376, 20.24324655532837, 18.353784643113613, 6.177499992772937, 4.4307194743305445, 4.866338549181819, 0.6886399572249502, 3.5752913262695074, 0.39268010237719864, 0.2650360157713294, 0.5288730177562684, 2.56842824164778, 2.672825027257204, 1.473569122608751, 1.3480805000290275, 0.5540768872015178, 0.6161774299107492, 2.47736185323447, 4.246778944507241, 5.549867246299982, 3.1448342744261026, 20.695866867899895, 18.55882354080677, 19.087272584438324, 14.43537600338459, 10.037530940026045, 7.72883134894073, 17.066512517631054, 12.809927724301815, 14.467888958752155, 17.268416583538055, 25.22133093327284, 25.66418956965208, 27.798156961798668, 28.398990221321583, 33.92672270536423, 39.54482764005661, 34.02813546359539, 38.603678941726685, 35.35562463104725, 36.44138976931572, 23.851914815604687, 30.753157697618008, 20.855897180736065, 31.65449023246765, 65.61209008097649, 33.567668572068214, 27.303733192384243, 2.2552473843097687, 7.418722864240408, 31.40792526304722, 38.891315907239914, 44.57524470984936, 40.93942880630493, 55.749183520674706, 66.02075055241585, 59.89048629999161, 60.57165674865246, 63.702137768268585, 61.58185534179211, 52.9159339517355, 19.195798560976982, 15.908665247261524, 22.7680666744709, 39.636672511696815, 51.21741369366646, 69.60126802325249, 61.20031401515007, 41.54572807252407, 32.92604640126228, 29.912553504109383, 5.112056639045477, 0.17573323741089553, 0.1482954144012183, 0.025868345801427495, 0.07339922158280388, 0.07602955622132868, 0.013960191135993227, 0.037439862280734815, 0.05038811650592834, 0.144279905653093, 0.08740620512980968, 0.12086038186680526, 0.08966784080257639, 0.01543296835734509, 0.02303284258232452, 0.05962121285847388, 0.13882065250072628, 0.05623530138109345, 0.06291622237768024, 0.02674443443538621, 0.11477123087388463, 0.11683843127684668, 0.1359518212848343, 0.13449618767481297, 0.17876353027531877, 0.023483350341848563, 0.2419722924241796, 0.10508742823731154, 0.24674182321177796, 0.04708778207714204, 0.03599455194489565, 0.14465354732237756, 0.14404154266230762, 0.09653676635934971, 0.23229585931403562, 0.14639502653153613, 0.47314315976109356, 0.8449735434260219, 16.99901293963194, 106.94257870316505, 71.06225162744522, 52.953156754374504, 90.24549946188927, 70.39561539888382, 41.979577392339706, 38.01086135208607, 43.89051005244255, 41.29429556429386, 26.56545750796795, 51.23274967074394, 62.160731479525566, 58.86098854243755, 64.06100571155548, 69.57438826560974, 71.7615433037281, 64.12712976336479, 65.96182331442833, 61.31638638675213, 64.16295424103737, 62.35206261277199, 59.4260486215353, 30.729794651269913, 3.105536070652306, 10.51640784367919, 16.075134314596653, 50.878528878092766, 36.93844869732857, 37.04219073057175, 20.533341988921165, 21.322462745010853, 18.671470396220684, 16.85310646891594, 18.789678253233433, 24.06796932220459, 25.978193320333958, 22.545706406235695, 24.65506061911583, 18.86385027319193, 12.902774792164564, 12.343238666653633, 8.026730138808489, 10.247503872960806, 20.836472623050213, 14.475767835974693, 17.958486154675484, 18.06390579789877, 25.97051963210106, 43.32644172012806, 70.05673438310623, 36.09462797641754, 19.839765205979347, 13.877990562468767, 1.880883991252631, 2.9750384856015444, 2.5371578196063638, 1.4005483221262693, 0.6231111078523099, 2.2999082878232002, 3.7553532142192125, 1.1351742432452738, 2.8639310225844383, 1.7105093272402883, 19.174457006156445, 41.70659624040127, 39.79854382574558, 30.66258005797863, 23.831025436520576, 29.605699069797993, 19.570477455854416, 14.299341402947903, 8.262061011046171, 3.3194553293287754, 4.193750889971852, 0.6399143405724317, 0.1216220851347316, 0.7868116674944758, 2.612902242690325, 5.231088101863861, 2.583213485777378, 2.378081255592406, 0.6215496885124594, 1.8909633066505194, 4.96210053563118, 3.4113434236496687, 5.482532009482384, 21.123742908239365, 31.31386511027813, 21.944610960781574, 15.211368463933468, 18.748098984360695, 16.1470340564847, 21.434028558433056, 21.742735393345356, 13.07722058147192, 19.409837275743484, 19.29157432168722, 18.87639530003071, 11.820168234407902, 14.875071309506893, 21.237867884337902, 32.31329508125782, 36.52025453746319, 35.028477385640144, 35.14579989016056, 31.740418821573257, 28.910697363317013, 24.28979951888323, 28.063325732946396, 24.246631935238838, 53.15051056444645, 79.4374506175518, 36.27927906811237, 45.20654283463955, 16.847572065889835, 9.734859131276608, 25.518150106072426, 38.11230830848217, 44.91324037313461, 41.006438210606575, 57.14492082595825, 72.89069071412086, 67.12761595845222, 70.25158792734146, 70.54151996970177, 72.6664799451828, 59.792614951729774, 27.847142033278942, 23.208233155310154, 29.426137804985046, 28.15210036933422, 62.86959484219551, 71.72891065478325, 67.33881622552872, 48.51432994008064, 42.038728818297386, 47.1986885368824, 7.224872466176748, 0.3043755720136687, 0.12760194746078923, 0.08406537541304715, 0.09571872666128911, 0.07782052183756605, 0.03000401567987865, 0.11359946875018068, 0.04230176447890699, 0.12150311144068837, 0.04487621539738029, 0.05690380203304812, 0.07019545169896446, 0.11778771237004548, 0.025295799277955666, 0.06301097237155773, 0.02172782227717107, 0.20368268218589947, 0.09243902764865197, 0.17845772090367973, 0.2609648311045021, 0.18057109031360596, 0.2553136140340939, 0.411578388302587, 0.29031424841377884, 0.1190177553507965, 0.5148676224052906, 0.18881700409110636, 0.3480802330886945, 0.22700491041177884, 0.19763272401178256, 0.20810276531847194, 0.31672482029534876, 0.28959424642380327, 0.4850844939937815, 0.24386154807871208, 0.6922962516546249, 1.2353984965011477, 27.720259241759777, 122.46992111206055, 82.8270435333252, 62.0660025626421, 98.2697568833828, 96.33728697896004, 67.31823652982712, 67.16454237699509, 40.32011143863201, 67.9379452764988, 28.812959007918835, 54.96893338859081, 65.64183488488197, 66.27831593155861, 68.17487016320229, 71.39731004834175, 75.65220013260841, 71.81329652667046, 67.65948101878166, 69.93440374732018, 75.52214071154594, 68.8181072473526, 59.48856666684151, 42.457033172249794, 3.392430176027119, 4.707889901474118, 30.911402106285095, 67.79959470033646, 38.621670976281166, 43.8456192612648, 23.233384005725384, 25.58163519948721, 27.037861458957195, 29.32852104306221, 29.121905229985714, 31.786620542407036, 34.841497018933296, 28.592027463018894, 30.755000598728657, 36.69740103185177, 27.214542478322983, 24.33169227093458, 20.633789598941803, 20.377138070762157, 30.832727327942848, 12.776233982294798, 22.74801515042782, 28.420025892555714, 30.864144042134285, 56.410279646515846, 82.7312658727169, 50.78285001218319, 25.882871635258198, 25.06864372640848, 4.631856931373477, 3.143724496476352, 2.473850604146719, 1.6968099935911596, 1.8983093812130392, 5.578045584261417, 2.324772016145289, 0.5186959763523191, 5.28032585978508, 7.652162862941623, 34.802735298871994, 43.94253306090832, 43.562101274728775, 35.08727163076401, 31.248886696994305, 41.404482051730156, 32.93646164238453, 30.03221668303013, 21.776726469397545, 14.877757765352726, 3.6639488814398646, 0.4465086373966187, 0.36029040289577097, 1.4613894699141383, 3.73474502004683, 5.162353590130806, 1.5776353259570897, 2.997301728464663, 0.4131375811994076, 3.1087986705824733, 4.45479498244822, 3.272178741171956, 17.54868384450674, 31.943555921316147, 41.87736287713051, 33.401370495557785, 28.776762150228024, 24.479625932872295, 17.62875884771347, 18.609548918902874, 25.673445872962475, 17.956867441534996, 23.112700581550598, 28.12983926385641, 39.01005953550339, 40.25360740721226, 45.54880566895008, 42.38634556531906, 46.33861228823662, 49.86522205173969, 43.718717470765114, 45.95905065536499, 44.01592992246151, 41.076806634664536, 31.16032674908638, 38.657487854361534, 24.506165608763695, 44.00437854230404, 92.57254779338837, 48.06208200752735, 42.26973742246628, 10.12457286939025, 17.269425429403782, 44.118098840117455, 47.89225772023201, 54.04791980981827, 50.37153348326683, 69.58307459950447, 85.43378725647926, 73.91028240323067, 70.98316267132759, 76.20748713612556, 80.55185481905937, 70.23040786385536, 34.775448963046074, 30.942357145249844, 35.33008620142937, 53.60103338956833, 74.62722793221474, 80.37682861089706, 74.37476187944412, 60.99561519920826, 52.41748429834843, 70.05839109420776, 10.17638023942709, 0.6628175522200763, 0.31773966271430254, 0.12371651493594982, 0.1918822224251926, 0.19246192881837487, 0.08709518588148057, 0.1783182268263772, 0.16416064667282626, 0.24002669291803613, 0.11773180638556369, 0.20572257897583768, 0.14446190994931385, 0.24594771035481244, 0.1727844323613681, 0.20503753214143217, 0.16780974227003753], [0.0463930465048179, 0.015214639643090777, 0.07931315150926821, 0.0333480050903745, 0.10168486667680554, 0.030184351999196224, 0.06569096411112696, 0.16723849636036903, 0.05451472847198602, 0.1102271348645445, 0.14391273551154882, 0.22745046619093046, 0.06630890595261008, 0.04050808260217309, 0.1354239316424355, 0.17564688110724092, 0.023790376835677307, 0.1623470158665441, 0.19741797616006806, 0.3670603927457705, 0.699905640212819, 0.45436234096996486, 47.25345499813557, 78.98763075470924, 48.562302365899086, 62.74316802620888, 96.87544450163841, 48.00406292080879, 53.08597482740879, 26.32566947489977, 42.31186196208, 39.2308808863163, 26.77153754979372, 80.1624745130539, 68.70135471224785, 69.791911393404, 65.4322001338005, 73.6946439743042, 70.39137482643127, 72.05219730734825, 50.88395118713379, 51.98067493736744, 58.57626222074032, 64.13173511624336, 10.99167114123702, 2.7299756230786443, 13.035814203321934, 43.94459255039692, 21.277815140783787, 11.026100143790245, 8.692509513348341, 11.75202839076519, 14.388360176235437, 18.444637767970562, 22.26447969675064, 24.106580950319767, 23.606833666563034, 31.164234839379787, 24.186338670551777, 23.804259672760963, 23.092417269945145, 18.111306354403496, 6.785821225494146, 6.6876620426774025, 8.921896554529667, 15.371986795216799, 14.125540629029274, 13.494293801486492, 19.331795163452625, 26.656525321304798, 41.70767918229103, 47.95987889170647, 22.401183061301708, 16.24346148222685, 16.168632097542286, 1.796407161746174, 1.7087987065315247, 1.2114281952381134, 2.1992573887109756, 1.1811560508795083, 0.380975067964755, 1.1374310846440494, 0.7683367026038468, 2.704096636734903, 3.5278708208352327, 8.668054025620222, 31.480706557631493, 36.37857533991337, 22.54865124821663, 24.169762060046196, 20.22551480680704, 4.268856709823012, 2.1092874789610505, 2.506579435430467, 1.2963621877133846, 1.6257361136376858, 0.2742044784827158, 0.7710315298754722, 0.08359752551768906, 1.2053448404185474, 0.8932503091637045, 0.33421361935324967, 1.2631025724112988, 0.7415974186733365, 2.3715912038460374, 4.601399190723896, 5.351617159321904, 4.850510973483324, 4.420774932950735, 24.76931668817997, 21.416724286973476, 17.88734447211027, 22.15119067579508, 13.936472274363041, 10.393642131239176, 13.796454537659883, 16.672595255076885, 9.197166133671999, 11.942311730235815, 12.763482816517353, 14.007781147956848, 19.18349862098694, 20.735795125365257, 30.14203079044819, 41.53268717229366, 39.42257300019264, 44.41667541861534, 43.46910126507282, 47.558806613087654, 52.4477344751358, 39.428964257240295, 43.80108945071697, 19.224912598729134, 58.408923000097275, 65.24219512939453, 30.61733778566122, 13.764548599720001, 2.91247246786952, 3.1701055308803916, 9.955942668020725, 12.23876802250743, 15.419314205646515, 18.832171373069286, 31.219814456999302, 59.01659019291401, 62.672404423356056, 58.91132824122906, 60.57603791356087, 49.736560955643654, 19.02117893099785, 25.544868372380733, 33.20706032216549, 36.594787538051605, 65.2204754948616, 38.05409923195839, 54.55969154834747, 34.88805212080479, 37.82854713499546, 21.775440238416195, 0.7670949411112815, 0.02128592343069613, 0.1341440386022441, 0.05470337870065123, 0.18398210493614897, 0.13164861156838015, 0.04304134061385412, 0.19785762444371358, 0.18217466364149004, 0.2665025886381045, 0.11771384641178884, 0.23001302790362388, 0.06019434011250269, 0.09016289041028358, 0.032241919325315394, 0.041395910157007165, 0.002508464017410006, 0.004546743621176574, 0.04829422847251408, 0.08015464307391085, 0.06037940205715131, 0.04614935860445257, 0.02712456989684142, 0.1877197832800448, 0.14760575140826404, 0.05209549402934499, 0.0915031274780631, 0.11815006597316824, 0.2698560571298003, 0.08570804508053698, 0.05971267142740544, 0.06225436394743156, 0.1379849051591009, 0.14285719371400774, 0.07854692856199108, 0.18680925713852048, 0.2990730159217492, 0.7257654494605958, 0.7535961060784757, 53.66338424384594, 89.92134645581245, 49.04674217104912, 75.2710197865963, 92.09071084856987, 50.357474237680435, 36.48130662739277, 28.563783578574657, 50.73814921081066, 34.26515534520149, 34.814244881272316, 70.51160037517548, 71.12849727272987, 74.23910155892372, 68.55222031474113, 73.25397402048111, 72.13019952178001, 74.25544068217278, 55.04687860608101, 57.62609660625458, 60.53580567240715, 65.90505436062813, 6.108282431960106, 10.623531695455313, 12.595864310860634, 31.567267812788486, 34.77406583726406, 19.36792552471161, 18.54004494845867, 11.742204017937183, 15.462870318442583, 16.221884340047836, 18.575911223888397, 19.383295699954033, 24.06309988349676, 33.44342663884163, 24.3221889808774, 23.3758744597435, 19.21672973781824, 13.480538539588451, 8.5508768633008, 10.270797573029995, 13.546611294150352, 18.543939739465714, 14.437552336603403, 17.188820354640484, 22.525246404111385, 26.95226725190878, 47.54038520157337, 68.57631862163544, 37.05512523651123, 18.43245182186365, 19.203362055122852, 0.7535972341429442, 1.257971185259521, 2.9802936036139727, 1.4847639156505466, 1.7187338671647012, 0.3414622350828722, 1.3971415674313903, 1.8017969350330532, 1.2647996563464403, 3.2766978861764073, 16.755884885787964, 40.45182377099991, 40.108637586236, 28.679012395441532, 28.080766797065735, 28.500171191990376, 18.20257555693388, 12.313574608415365, 7.820259667932987, 0.5186006845906377, 2.258060658350587, 0.28840333689004183, 1.0710790450684726, 0.20214130083331838, 2.4410937493667006, 1.2373283179476857, 0.4523884953232482, 1.0144658829085529, 1.0580924106761813, 1.558206018526107, 8.510301690548658, 3.707666010595858, 3.1008323980495334, 19.296669848263264, 37.139089331030846, 26.480269879102707, 13.950992245227098, 23.63503385335207, 16.661731638014317, 19.57343179732561, 21.651675179600716, 17.088279649615288, 13.601024374365807, 13.88308608904481, 16.919183023273945, 13.392888642847538, 11.713163126260042, 21.55435860157013, 31.421957910060883, 38.46171095967293, 36.013346537947655, 37.304486855864525, 39.24695782363415, 40.35704165697098, 45.106570199131966, 36.99536204338074, 37.32874095439911, 28.39192260056734, 76.68570667505264, 64.21484425663948, 30.953482948243618, 24.8819350451231, 9.757140185683966, 4.614194054156542, 7.580075031146407, 10.699397474527359, 14.3085359595716, 17.570555470883846, 29.37485385686159, 68.92037495970726, 68.34070086479187, 65.40455281734467, 71.50683537125587, 63.920306861400604, 23.82318075746298, 37.72443652153015, 35.21275229752064, 34.6946083009243, 78.63057151436806, 50.017939656972885, 65.18795683979988, 42.95130304992199, 46.473463252186775, 31.96134276688099, 0.8770764176733792, 0.1055812013510149, 0.200513934250921, 0.12249306222656742, 0.09650325097027235, 0.03468598602921702, 0.02826485753757879, 0.0444736782083055, 0.1671267140773125, 0.15621257160091773, 0.1335695420857519, 0.1519350550370291, 0.028899848366563674, 0.06153973510663491, 0.13897522701881826, 0.05190263211261481, 0.017437314418202732, 0.17500499758170918, 0.2521021035499871, 0.22302503959508613, 0.09838584213866852, 0.27969782589934766, 0.23767228878568858, 0.3044611861696467, 0.4280359286349267, 0.10361477718106471, 0.39210553164593875, 0.31409749877639115, 0.3366042551351711, 0.12319956455030479, 0.21126364648807794, 0.22212693700566888, 0.19382722821319476, 0.21842102258233353, 0.21590549818938598, 0.40965444466564804, 0.449807780678384, 0.7876886485610157, 1.0558245261199772, 78.81699711084366, 99.23805892467499, 63.39023910462856, 85.44706374406815, 109.57997918128967, 69.98703852295876, 77.97566905617714, 37.141669392585754, 60.72791576385498, 49.95497703552246, 31.788602136075497, 83.70817065238953, 71.67195171117783, 77.51813560724258, 71.44102290272713, 82.43865117430687, 71.72853827476501, 78.53879123926163, 60.13246491551399, 63.27367275953293, 61.094740480184555, 72.45263502001762, 9.193852711468935, 4.655742924660444, 14.510518871247768, 50.70740506052971, 35.72255954146385, 15.360384117811918, 15.97985252737999, 17.593734227120876, 21.238451153039932, 24.792689234018326, 32.34666109085083, 31.95367857813835, 31.872552931308746, 41.74155056476593, 32.35596679151058, 37.62218400835991, 33.68035152554512, 29.140288643538952, 17.48961791396141, 22.03987754881382, 21.14291287958622, 28.71722124516964, 20.929161049425602, 17.531622759997845, 29.191963970661163, 34.570639953017235, 61.34133204817772, 76.49751037359238, 52.374375611543655, 27.538397200405598, 33.90450909733772, 4.003500798717141, 1.47601583506912, 3.9967784844338894, 2.618531878106296, 1.3609449472278357, 0.2923965663649142, 2.308266651816666, 0.9644760028459132, 3.5429514991119504, 5.777323041111231, 28.33819918334484, 42.27178171277046, 41.3971446454525, 33.781809881329536, 38.45785416662693, 40.42639933526516, 34.39688667654991, 26.010818369686604, 24.12163384258747, 9.219077657908201, 4.636661298573017, 0.2663629164453596, 1.6918484098277986, 0.25046353053767234, 3.152920715510845, 1.8215485126711428, 0.3766371257370338, 1.5508453384973109, 0.8021169493440539, 4.656235948204994, 7.760166367515922, 2.4845992773771286, 12.321575079113245, 27.914014644920826, 49.65238407254219, 33.29079642891884, 23.01819585263729, 34.48699124157429, 20.24685826152563, 21.21805004775524, 23.610460571944714, 24.510136395692825, 16.782202273607254, 19.642945267260075, 25.13106867671013, 26.217097900807858, 30.792200602591038, 33.83596457540989, 39.196671321988106, 47.404660284519196, 48.29017996788025, 53.88495795428753, 50.051263868808746, 59.02675464749336, 60.69536671042442, 49.01301898062229, 51.25953063368797, 23.921365588903427, 77.02410131692886, 86.0905060172081, 41.89239487051964, 28.059569634497166, 9.937309417873621, 10.976619198918343, 16.203671917319298, 16.359419859945774, 23.334882259368896, 22.921563237905502, 44.23403821885586, 83.01156923174858, 73.88002842664719, 69.67762112617493, 76.74525707960129, 71.26884654164314, 31.88756972551346, 37.492428570985794, 43.42301733791828, 51.23902693390846, 76.82714268565178, 53.31343822181225, 80.69795697927475, 49.01411332190037, 66.01227700710297, 49.75519135594368, 0.6642427726183087, 0.3062908770516515, 0.3288594988407567, 0.23414359922753647, 0.2008276994456537, 0.11518799132318236, 0.11184478673385456, 0.3746317239711061, 0.2967575745424256, 0.32902428531087935, 0.28673035791143775, 0.2773223596159369, 0.18068410456180573, 0.35422785789705813, 0.1206355556496419, 0.12791072542313486, 0.09173651807941496], [0.10057155610411428, 0.025866134201351088, 0.049084916317951865, 0.11221742650377564, 0.08454940412775613, 0.05957455774478149, 0.028983699921809603, 0.07658256756258197, 0.07667271624086425, 0.10646095804986544, 0.054247855878202245, 0.17183117335662246, 0.12331766251008958, 0.022204674423846882, 0.15291623363737017, 0.16386452974984422, 0.22052950866054744, 0.17651464469963685, 0.3111676184926182, 0.284874543431215, 0.8594319457188249, 0.22417781758122146, 8.851868212223053, 80.78727498650551, 65.31195178627968, 56.33285500109196, 80.89356288313866, 64.56023052334785, 48.06856445968151, 48.81229855120182, 29.870263673365116, 41.16204746067524, 22.637273892760277, 73.63048061728477, 74.73801478743553, 68.44543844461441, 70.2847221493721, 74.5040537416935, 65.9118027985096, 57.981810718774796, 63.25189992785454, 62.11248926818371, 64.20952454209328, 43.49165305495262, 1.8273855932056904, 3.2815224397927523, 23.20755109190941, 33.258824944496155, 14.49380261823535, 13.489816691726446, 11.675089169293642, 22.47174147516489, 19.081382900476456, 19.02777347713709, 21.059095077216625, 30.45175787061453, 38.544459119439125, 31.752338781952858, 23.727184608578682, 29.209973104298115, 15.081165600568056, 13.49633714184165, 8.09021808207035, 4.795142719522119, 11.395163889974356, 14.528728444129229, 21.47602390497923, 24.41401295363903, 21.55194193124771, 37.801538184285164, 46.48653455078602, 53.449626713991165, 20.927869118750095, 18.417364731431007, 17.568247094750404, 0.5508447450120002, 1.828104704618454, 2.531030885875225, 1.7314428789541125, 1.3211340084671974, 0.7816381857264787, 1.6092258808203042, 1.063180100172758, 1.4752523135393858, 0.48930004122667015, 0.360336831654422, 20.743124932050705, 38.137626349925995, 29.34728443622589, 23.145316131412983, 21.63692247122526, 5.081045553088188, 0.30658625182695687, 2.3592924512922764, 1.998246037401259, 0.7024598750285804, 0.17855215177405626, 0.6239057402126491, 0.4473144019721076, 0.8373336971271783, 0.4862707725260407, 0.4899941274197772, 0.8600261388346553, 1.623880744446069, 0.7824617915321141, 2.4915844900533557, 6.54897945933044, 3.1590334000065923, 8.82352078333497, 26.24369077384472, 28.296553418040276, 14.64033605530858, 23.24014764279127, 18.25826346874237, 15.944962799549103, 12.977358140051365, 13.951775953173637, 11.702672839164734, 9.586254805326462, 11.302341520786285, 10.28659712523222, 16.228418089449406, 19.402112290263176, 26.42877124249935, 35.75661711394787, 45.21523676812649, 52.85118542611599, 56.48231618106365, 48.80944110453129, 43.113010972738266, 47.81978040933609, 54.23569053411484, 39.260101318359375, 35.27211271226406, 84.96900379657745, 64.14046704769135, 41.22551545500755, 35.20419515669346, 10.450029205530882, 0.6616525584831834, 1.396242321934551, 0.8002967282664031, 3.5985693521797657, 4.21351695433259, 22.105215042829514, 59.29416909813881, 53.57718586921692, 58.657543659210205, 34.075936898589134, 20.454904697835445, 32.877352014184, 37.07424961030483, 32.60521061718464, 42.76201240718365, 47.475302293896675, 43.567778170108795, 32.51494646072388, 38.306618481874466, 12.793331164866686, 0.13953390094684437, 0.409068979206495, 0.06934398566954769, 0.012861737432103837, 0.040741447228356265, 0.1095227625046391, 0.048917944222921506, 0.02353597603359958, 0.16678409418091178, 0.09468571646721102, 0.09224062931025401, 0.2519855269929394, 0.056899857518146746, 0.019699913027579896, 0.07345971403992735, 0.010454866242071148, 0.04645702334528323, 0.017735262590576895, 0.05329356528818607, 0.11438418601755984, 0.07567091335658915, 0.051455840657581575, 0.04025873953651171, 0.04732958863314707, 0.04733777452202048, 0.12867395009379834, 0.10237414375296794, 0.18737459555268288, 0.15595366596244276, 0.19023653963813558, 0.08340587330167182, 0.15592346055200323, 0.16970679047517478, 0.042569316137814894, 0.12190501409349963, 0.2318589124479331, 0.42337280698120594, 0.7362165511585772, 0.3795766836265102, 13.361185044050217, 92.75604754686356, 67.90082886815071, 67.69772976636887, 87.56420373916626, 64.45336505770683, 44.7334948182106, 30.844470597803593, 36.4984817057848, 33.38044881820679, 30.72931967675686, 68.2847298681736, 75.85763230919838, 69.72220793366432, 69.86943483352661, 75.89041694998741, 69.30664703249931, 57.49884903430939, 65.86662322282791, 62.572177201509476, 64.15340155363083, 32.732196003198624, 3.4606752265244722, 6.7001058999449015, 13.521270453929901, 41.602139845490456, 21.285118348896503, 14.926660191267729, 12.055647298693657, 19.707686193287373, 17.29042500257492, 16.94960229098797, 22.224760428071022, 30.157273672521114, 35.210461020469666, 31.300035752356052, 24.48526483029127, 27.52277433872223, 16.25809069722891, 14.883244670927525, 9.44191100075841, 8.4364403039217, 16.349198408424854, 18.302145414054394, 22.654758654534817, 26.87034174799919, 23.332469388842583, 36.47149175405502, 55.30674286186695, 75.73743715882301, 34.65657614171505, 21.186291351914406, 27.667290084064007, 2.897738046012819, 1.898275539278984, 2.6950315106660128, 1.495646412950009, 1.6929948795586824, 1.0761735029518604, 1.0774895385839045, 2.8212923230603337, 1.7348261224105954, 1.5192788885906339, 5.343277556821704, 26.9085942953825, 41.419092267751694, 33.48561577498913, 31.207237131893635, 33.43919366598129, 19.76672362536192, 7.9974679090082645, 5.113919964060187, 1.753722745925188, 0.6635613623075187, 0.131051613134332, 0.5393874691799283, 0.22772276017349213, 0.9354076813906431, 0.327322332886979, 0.5807774013374001, 1.244730083271861, 1.4224778953939676, 0.6953470723237842, 2.823578375391662, 4.6289177890866995, 2.561432817019522, 23.815085291862488, 36.82944014668465, 36.635209769010544, 18.11928402632475, 23.703924156725407, 19.85215824097395, 21.40870861709118, 21.363010369241238, 25.556984022259712, 17.73533172905445, 14.720396809279919, 15.25966102257371, 14.038087371736765, 16.168949380517006, 18.69558770209551, 21.971690207719803, 26.96250770241022, 32.11572468280792, 38.73367756605148, 41.18630535900593, 42.90700122714043, 36.513521298766136, 40.389058738946915, 43.20871263742447, 33.925229385495186, 50.85209749639034, 85.6642296910286, 53.98592233657837, 39.41656172275543, 44.21808287501335, 12.940944693982601, 0.6570349156390876, 0.9160419018007815, 0.8886365848593414, 2.746442989446223, 3.576093795709312, 23.938162587583065, 62.33692802488804, 61.00300960242748, 68.74404162168503, 41.72014631330967, 27.73255918174982, 43.636037707328796, 31.750397086143494, 34.54041637480259, 52.76874125003815, 51.46574176847935, 53.355076387524605, 41.977073326706886, 53.4075515717268, 16.307250559329987, 0.30922960373573005, 0.3624539414886385, 0.05494631332112476, 0.055195444874698296, 0.002177816122639342, 0.15902540035312995, 0.07550857597379945, 0.06166874634800479, 0.12857598660048097, 0.054214919364312664, 0.14330815232824534, 0.24201481748605147, 0.10857264278456569, 0.06237685171072371, 0.05807170498883352, 0.017803128284867853, 0.04957368735631462, 0.13003993226448074, 0.1630386826582253, 0.19307930662762374, 0.17721689451718703, 0.30767955409828573, 0.1286188975791447, 0.21758022863650694, 0.17201740789460018, 0.2776663895929232, 0.2296758405282162, 0.21571628021774814, 0.282127617392689, 0.3677648096345365, 0.22556325886398554, 0.29967801470775157, 0.3103289025602862, 0.35665367147885263, 0.22776182682719082, 0.37081818329170346, 0.6963167921639979, 1.4358664769679308, 0.6315103790257126, 20.752709917724133, 114.18635800480843, 83.40499252080917, 76.22842401266098, 100.15863552689552, 82.77241006493568, 77.30023249983788, 66.95906460285187, 43.67846243083477, 54.32676784694195, 31.30223773419857, 83.216872215271, 74.05114844441414, 76.46281823515892, 72.49050378799438, 83.37685883045197, 72.70512387156487, 68.76653641462326, 72.24305346608162, 68.18407326936722, 62.65965610742569, 45.401992946863174, 1.9563346426002681, 5.7278957683593035, 26.38416163623333, 49.58988502621651, 18.223046958446503, 20.821649618446827, 16.03577222675085, 32.71714121103287, 26.634898781776428, 25.460001826286316, 26.028675511479378, 38.60114827752113, 47.63618566095829, 42.658080384135246, 33.496684581041336, 42.662659138441086, 26.436336636543274, 27.09285780787468, 19.962287731468678, 16.427791491150856, 25.176531337201595, 25.832292549312115, 29.023710899055004, 32.18263529241085, 27.578061372041702, 49.033138900995255, 65.3884644806385, 91.94096848368645, 48.51553447544575, 29.080048575997353, 36.92439705133438, 9.992282018065453, 1.846221776213497, 3.712330972775817, 1.1377028888091445, 1.56390939373523, 0.5392189719714224, 2.805240321904421, 2.120910342782736, 3.682657415047288, 0.9149470261763781, 19.85133558511734, 31.720437593758106, 41.94646216928959, 38.373665884137154, 39.92796868085861, 48.74231390655041, 41.73278823494911, 21.54678750783205, 21.329290978610516, 7.097520874813199, 1.8367094616405666, 0.52626249846071, 0.6474325340241194, 1.1175118410028517, 1.1514313146471977, 2.0214231312274933, 0.5184780817944556, 1.9932825537398458, 1.3512605731375515, 1.5354065294377506, 5.416895756497979, 3.807610860094428, 6.3135274685919285, 31.164337433874607, 44.40739631652832, 42.41881862282753, 19.959352388978004, 36.781194135546684, 26.121825613081455, 25.332588963210583, 18.919583782553673, 26.8020062148571, 23.705396577715874, 19.538543969392776, 20.991409309208393, 23.20932749658823, 27.293272353708744, 26.54573656618595, 37.59581342339516, 41.27691529691219, 52.66760967671871, 59.798652827739716, 63.422088995575905, 58.50185841321945, 52.37822860479355, 56.09481677412987, 65.93094617128372, 43.006582483649254, 50.105441361665726, 103.61769631505013, 83.93225222826004, 58.52467618882656, 57.090059369802475, 15.622519701719284, 1.7636881861835718, 2.4182458128780127, 1.3307305122725666, 5.854553896933794, 4.750176407396793, 35.62232851982117, 77.0207878947258, 63.865050226449966, 74.48950052261353, 50.39546459913254, 31.041507124900818, 46.35781645774841, 52.28036105632782, 45.04483871161938, 58.03213521838188, 59.2934737354517, 62.82714731991291, 52.22705751657486, 72.98206061124802, 22.154456600546837, 0.3612241434166208, 0.5263469845522195, 0.1385074364952743, 0.2762352616991848, 0.14240084710763767, 0.22942113544559106, 0.2534827060298994, 0.16018965194234625, 0.15241041546687484, 0.15745007316581905, 0.17712207773001865, 0.32025233726017177, 0.3485772939166054, 0.2256467950064689, 0.09247825757483952, 0.09379223745781928, 0.12432237461325713], [0.0353827031358378, 0.10776325652841479, 0.0792700401507318, 0.12611137353815138, 0.05713617218134459, 0.018592281739984173, 0.05806922621559352, 0.10585313168121502, 0.013668342489836505, 0.22878533753100783, 0.1792001654393971, 0.05026264159823768, 0.08852521539665759, 0.12343895912636071, 0.07220983345177956, 0.16920791880693287, 0.3345250542042777, 0.2537428733194247, 0.09003731902339496, 0.7908018690068275, 0.21540255955187604, 0.9534474508836865, 0.8845054940320551, 54.44771155714989, 63.521879240870476, 40.354096814990044, 71.94262638688087, 76.92727491259575, 50.517050474882126, 48.402752727270126, 33.41642528772354, 39.52888369560242, 23.862102068960667, 60.48770785331726, 69.77683380246162, 70.65288439393044, 75.28694093227386, 68.2620906829834, 61.79989144206047, 67.25849613547325, 63.144175708293915, 42.20607943832874, 35.69382168352604, 9.274670574814081, 2.7080498496070504, 18.79881676286459, 29.09849088639021, 22.488990649580956, 10.826635546982288, 20.152002051472664, 19.72758572548628, 17.91112929582596, 17.925129644572735, 21.24194886535406, 18.69114574044943, 23.77823106944561, 35.648018941283226, 41.063856929540634, 30.55287044495344, 25.543555542826653, 14.842159375548363, 8.348182439804077, 6.236922154203057, 8.473891094326973, 13.8281324878335, 14.317504428327084, 19.42182943224907, 26.645049937069416, 25.437670424580574, 35.508809611201286, 56.92525081336498, 57.530926913022995, 26.933636851608753, 15.661972984671593, 15.20700154826045, 3.934892392717302, 5.636517321690917, 0.9899845684412867, 2.0294625498354435, 2.3365072114393115, 0.8628245699219406, 1.4528670022264123, 0.5740996159147471, 0.5895190103910863, 0.25276401021983474, 3.471487071365118, 10.128404013812542, 36.96496367454529, 37.34951823949814, 19.779198355972767, 18.653052784502506, 4.071229314431548, 1.8578263535164297, 2.9698945116251707, 2.665536543354392, 1.4672831911593676, 0.1388463011244312, 0.7388037967029959, 0.46648045477923006, 1.3761856919154525, 2.313147964887321, 0.5452593415975571, 0.43854589748661965, 1.6333700227551162, 1.9549250369891524, 1.7906364588998258, 5.6012870371341705, 1.945279254578054, 9.71475251019001, 29.005815759301186, 30.16070108860731, 16.600667014718056, 26.02876290678978, 29.624242074787617, 25.256720334291458, 18.815431371331215, 11.769827585667372, 11.396420672535896, 7.539446661248803, 7.649228470399976, 11.004235167056322, 15.337022971361876, 25.411484129726887, 47.84548602998257, 66.85420542955399, 96.31286948919296, 110.40292382240295, 117.10834801197052, 103.53180572390556, 92.35415071249008, 82.65301287174225, 65.6802736222744, 59.84032519161701, 31.039075255393982, 55.51133148372173, 72.92219862341881, 46.71117849647999, 54.12848688662052, 50.47772258520126, 11.158741526305676, 0.7656871760264039, 0.7612658163998276, 0.3629227710189298, 0.3742088779108599, 0.7399541849736124, 14.745063185691833, 50.80945238471031, 51.05893559753895, 32.55465053021908, 29.0668822824955, 29.899411909282207, 44.1063878685236, 39.130820855498314, 54.58044223487377, 50.38973830640316, 35.072726011276245, 48.309547528624535, 35.4277865588665, 0.8933447697199881, 0.009236440655513434, 0.23197526636067778, 0.11020187215763144, 0.16381395980715752, 0.04977902106475085, 0.1582093199249357, 0.17090605659177527, 0.19666724925627932, 0.13880922342650592, 0.21120926190633327, 0.3179224388441071, 0.09984180971514434, 0.03804866828431841, 0.10941265005385503, 0.04042748907522764, 0.1796837933943607, 0.03542394799296744, 0.04374424352135975, 0.1360237502376549, 0.08308149539516307, 0.11934493857552297, 0.06838101937319152, 0.06840772184659727, 0.07133219187380746, 0.09621905293897726, 0.1448274325230159, 0.10956741753034294, 0.1884102329495363, 0.0827307638246566, 0.07082935713697225, 0.2840369852492586, 0.06838836663519032, 0.16565893893130124, 0.1828066914458759, 0.24649976432556286, 0.19050631031859666, 0.7249025988858193, 0.33223775506485254, 1.421140842139721, 1.3493801490403712, 68.9182622730732, 72.32293277978897, 51.25683657824993, 87.26132959127426, 75.63042730093002, 58.553467243909836, 27.182848379015923, 30.863108597695827, 33.687574937939644, 26.13163858652115, 67.11555540561676, 69.08875152468681, 73.50784599781036, 74.64671328663826, 73.6138679087162, 57.22337521612644, 72.9831625521183, 63.792056143283844, 44.093308970332146, 26.416144520044327, 7.649710094556212, 8.089620564132929, 14.276923555880785, 26.25985700637102, 32.446694523096085, 13.940314818173647, 18.896665312349796, 18.099293299019337, 16.876034438610077, 16.57516658306122, 19.121050871908665, 17.001642398536205, 20.329294838011265, 33.28042298555374, 35.9691397100687, 23.92142828553915, 25.964367762207985, 18.404190838336945, 11.844021454453468, 12.378912102431059, 13.872367814183235, 21.01879633963108, 19.312397204339504, 21.586417481303215, 27.061218805611134, 24.245773181319237, 37.13360242545605, 65.50819605588913, 74.808728992939, 41.50620259344578, 18.004182502627373, 25.483602359890938, 4.055935135111213, 5.361876133829355, 0.8846986305434257, 1.948882055003196, 1.685465108603239, 1.469384003430605, 0.8625229017343372, 0.8673165226355195, 0.701730907894671, 0.30940014927182347, 4.235093621537089, 15.747831277549267, 48.031197264790535, 41.69119566679001, 27.090874314308167, 31.044402569532394, 16.385670751333237, 7.564423670992255, 2.1016164030879736, 1.3784564263187349, 2.0500477077439427, 0.17261504457565024, 0.5743108014576137, 0.16128690243931487, 1.8715727096423507, 1.8816593871451914, 0.786492662737146, 0.4876780032645911, 0.8683739346452057, 0.5177771381568164, 5.345967337489128, 5.611546961590648, 1.9295836030505598, 28.143049255013466, 40.51371105015278, 38.251213654875755, 20.830970518290997, 25.511608757078648, 26.10735408961773, 26.418629586696625, 24.765634685754776, 21.678720228374004, 20.995353497564793, 15.175872668623924, 15.642394535243511, 18.928741291165352, 22.15492967516184, 24.688078947365284, 38.814252242445946, 45.33487714827061, 68.50444167852402, 88.81399467587471, 90.78291982412338, 79.05828416347504, 73.11961323022842, 60.4362016171217, 48.66951361298561, 42.79647655785084, 32.42001995444298, 70.73708787560463, 66.67029529809952, 54.16413277387619, 59.52657602727413, 54.977536126971245, 14.893614314496517, 1.1100763524882495, 1.0791539680212736, 0.22295863222097978, 0.187342876160983, 0.6419312604703009, 11.433071605861187, 56.065873727202415, 54.542584866285324, 43.52498106658459, 40.20104102790356, 32.71539330482483, 31.251491457223892, 43.26652653515339, 56.622832641005516, 58.05387005209923, 47.32197292149067, 57.713921293616295, 45.90489596128464, 2.291934653185308, 0.05719126922485884, 0.20192555850371718, 0.04631839015928563, 0.09792606681003235, 0.02453291970596183, 0.14009696838911623, 0.19745889818295836, 0.06317506122286431, 0.02767766287433915, 0.07328398089157417, 0.25559702538885176, 0.09208629227941856, 0.1443500682944432, 0.047388396415044554, 0.043902718025492504, 0.22422532987548038, 0.06507436555693857, 0.13188522309064865, 0.19715512229595333, 0.1377624092856422, 0.19362126738997176, 0.20184775174129754, 0.10595399697194807, 0.24233552918303758, 0.2533240942284465, 0.2499768597772345, 0.3454442135989666, 0.29596030013635755, 0.20291782479034737, 0.11066906896303408, 0.3842527186498046, 0.15952642424963415, 0.3361751156626269, 0.3296833124477416, 0.3218891588039696, 0.24963493749964982, 1.2598575465381145, 0.5160636676009744, 1.5647290810011327, 1.9259963580407202, 92.56455302238464, 87.35266909003258, 61.215471401810646, 91.45160794258118, 90.77880844473839, 80.5928622186184, 67.64086961746216, 48.31057347357273, 55.56235894560814, 31.41343306750059, 74.24812227487564, 72.17635944485664, 78.1720121204853, 81.35335341095924, 78.20655226707458, 66.1197504401207, 76.40876233577728, 72.08549872040749, 48.66192162036896, 38.014581352472305, 7.649636948481202, 6.047211159020662, 23.412548191845417, 38.349081203341484, 37.196181267499924, 16.860459074378014, 29.462788738310337, 27.047089263796806, 27.570353485643864, 24.016031809151173, 29.300423450767994, 24.252434223890305, 30.927146561443806, 45.1261505484581, 54.429392740130424, 38.32586444914341, 37.44146570563316, 25.54799560457468, 21.211174316704273, 20.92764113098383, 24.698110409080982, 22.628999836742878, 21.013472825288773, 27.462093494832516, 35.40950194001198, 34.35543470084667, 44.35354940593243, 81.33797943592072, 89.22193318605423, 57.50255763530731, 26.975932382047176, 29.109343104064465, 6.860145712271333, 8.085582330822945, 0.7113149436190724, 1.6270677046850324, 2.9786083940416574, 2.516368185169995, 1.7838065628893673, 2.0723795844241977, 1.1471998854540288, 0.18945449410239235, 17.174774408340454, 26.615540720522404, 47.69051134586334, 42.89300657808781, 35.72030246257782, 44.114352241158485, 36.55420571565628, 23.742243200540543, 17.418797314167023, 5.6083817314356565, 3.1132168835029006, 0.1382076385198161, 0.8488432201556861, 0.6279858900234103, 2.2165794717147946, 4.439465655013919, 1.1520979413762689, 0.6741126836277544, 0.9848651150241494, 5.501532889902592, 14.527038484811783, 5.462001236155629, 4.927209857851267, 33.4074729681015, 40.538352727890015, 42.32509285211563, 22.121103890240192, 39.16720770299435, 39.4931124150753, 37.117821872234344, 24.51232697814703, 19.513474814593792, 25.135470740497112, 18.579131551086903, 19.213775396347046, 23.519485853612423, 25.703211575746536, 35.24858437478542, 57.577379420399666, 71.09855487942696, 95.17055958509445, 118.23447838425636, 125.43224215507507, 104.47612345218658, 100.24901747703552, 93.42129305005074, 74.33074504137039, 69.34634730219841, 41.21047206223011, 77.5497955083847, 85.9960962831974, 63.44471678137779, 66.38560697436333, 63.961656242609024, 17.234155721962452, 3.6885836720466614, 1.4014577795751393, 0.33271626220084727, 0.40013494610320777, 0.46785859332885593, 20.639690682291985, 65.60201302170753, 65.46155735850334, 53.484220057725906, 38.78057844936848, 42.97836519777775, 56.89693473279476, 58.75354930758476, 70.84469810128212, 70.67739307880402, 55.666431561112404, 70.17665594816208, 62.745181918144226, 2.4205432645976543, 0.20116893894737586, 0.33387721865437925, 0.10645777423633263, 0.200737023842521, 0.22634371620370075, 0.4293576639611274, 0.24393135448917747, 0.19032694806810468, 0.15524095186265185, 0.22369120619259775, 0.5858636659104377, 0.18498375196941197, 0.37892190157435834, 0.18899146816693246, 0.4404706723289564, 0.22597955918172374, 0.1954411025508307], [0.10696249402826652, 0.07897692892584018, 0.09111934807151556, 0.04640833845769521, 0.016528946071048267, 0.11166933560161851, 0.21548885648371652, 0.15657361160265282, 0.0781853096850682, 0.06222460753633641, 0.02042813615844352, 0.15839322411920875, 0.051317155521246605, 0.04624344808689784, 0.09891514186165296, 0.2897220739396289, 0.20234942872775719, 0.0755651350482367, 0.47449161240365356, 0.425765966065228, 0.49699548922944814, 0.14529540116200224, 0.29899874178227037, 12.807156722992659, 64.20804262161255, 48.15813705325127, 43.793520256876945, 79.53298509120941, 60.94012677669525, 39.7161490470171, 34.350969940423965, 32.0340670645237, 24.40262496471405, 46.733266711235046, 78.17259728908539, 68.60829010605812, 77.52102345228195, 62.983622923493385, 68.0989046394825, 50.605923905968666, 26.824003234505653, 10.537831094115973, 4.503747280687094, 1.1003622924908996, 11.575960088521242, 21.958282627165318, 29.326121471822262, 20.29133677482605, 14.582945834845304, 19.294800348579884, 19.140849709510803, 27.622545585036278, 27.784282006323338, 37.69591525197029, 53.185502886772156, 68.32805514335632, 60.567632764577866, 63.848232328891754, 51.647413820028305, 32.618369311094284, 16.660435907542706, 13.155219946056604, 8.237237893044949, 10.793819557875395, 12.155753877013922, 15.166626814752817, 21.843990460038185, 28.3099078014493, 33.27457509934902, 33.403247594833374, 56.75715923309326, 63.258971348404884, 23.809858672320843, 15.057478621602058, 19.064439609646797, 3.5002280166372657, 3.7849370017647743, 2.3479802208021283, 0.9353861887939274, 2.1971211908385158, 2.414191192947328, 1.6408727201633155, 1.934497570618987, 1.0046696523204446, 0.2348269391222857, 5.195875866338611, 9.752475935965776, 27.313135787844658, 21.753317825496197, 9.050619397312403, 15.72993328794837, 3.1158672412857413, 5.6562449131160975, 3.6678759707137942, 2.6338512310758233, 1.797164271119982, 0.4204139829380438, 0.8488028473220766, 1.0017417906783521, 2.2991283796727657, 1.2573963473550975, 1.040187415201217, 1.2591526843607426, 0.7551141839940101, 0.9728213050402701, 7.424894208088517, 6.231663236394525, 1.8960841256193817, 8.128407932817936, 31.603420972824097, 41.97052627801895, 25.839899741113186, 27.07642938941717, 37.83860519528389, 36.38035364449024, 24.583892337977886, 16.836786344647408, 15.561719164252281, 12.996775098145008, 13.147871140390635, 15.591408871114254, 21.838260367512703, 49.92843545973301, 59.949884712696075, 86.22242733836174, 78.82064491510391, 78.13229665160179, 86.84714421629906, 96.68881371617317, 88.68710428476334, 110.86281314492226, 94.79330062866211, 85.52219331264496, 49.95236277580261, 33.73682029545307, 69.59779500961304, 34.73917230963707, 31.74590192735195, 54.53978441655636, 37.20087021589279, 2.893544496037066, 4.282799111679196, 1.343986694701016, 0.44248845311813056, 0.5487397173419595, 0.7245384121779352, 12.249510996043682, 52.15837620198727, 34.03908267617226, 30.605286732316017, 43.251182958483696, 40.13601891696453, 50.60157313942909, 68.51032376289368, 51.69305317103863, 38.341534808278084, 52.58129730820656, 16.028678007423878, 0.09450588666368276, 0.4480633180355653, 0.30837272002827376, 0.2753293071873486, 0.08057754850597121, 0.021793819614686072, 0.06434502734919079, 0.14214119932148606, 0.17133866931544617, 0.2702080726157874, 0.03101728103501955, 0.07478369065211155, 0.17394267255440354, 0.05786689820524771, 0.0406768135871971, 0.08800449490081519, 0.09284960600780323, 0.012848775822931202, 0.04425024351803586, 0.08462279511149973, 0.08964746142737567, 0.06454954098444432, 0.14947916963137686, 0.017929579116753303, 0.09101933625061065, 0.13019489269936457, 0.12777894968166947, 0.034257247316418216, 0.010782645967992721, 0.07741611814708449, 0.017018702310451772, 0.049638873897492886, 0.09996433829655871, 0.1950404912349768, 0.09096121866605245, 0.050214876973768696, 0.2017776930006221, 0.3372221376048401, 0.4064930143067613, 0.34127194841858, 0.26245194661896676, 21.79723396897316, 84.24806848168373, 52.52526171505451, 61.04099616408348, 83.1257227063179, 69.04120847582817, 34.840159490704536, 25.186245515942574, 32.42280900478363, 27.475820258259773, 56.875063106417656, 72.1625129878521, 69.41081464290619, 76.87054395675659, 69.04438510537148, 68.42429637908936, 51.15367591381073, 21.566928327083588, 8.12244700267911, 1.7791218892671168, 2.286645811982453, 13.36749555543065, 23.570190332829952, 28.07681880891323, 26.95347558706999, 16.81395336985588, 21.303598657250404, 15.128214675933123, 24.81593068689108, 20.22528301924467, 29.20498587191105, 35.50439804792404, 46.94145753979683, 45.77377259731293, 53.337642922997475, 39.145545065402985, 29.29872114211321, 19.114857204258442, 14.88304328173399, 11.230164393782616, 16.871888861060143, 17.031940072774887, 21.178300380706787, 21.109455674886703, 24.926943629980087, 26.81590396910906, 33.73311549425125, 64.63832393288612, 81.66853129863739, 38.36429938673973, 16.48798406124115, 19.09071519970894, 3.625733144581318, 1.532543026842177, 2.384220538660884, 0.6894813745748252, 2.321322038769722, 2.6065698824822903, 1.8393671815283597, 2.3088066978380084, 0.8020405378192663, 2.071122326888144, 3.8796008471399546, 13.929032273590565, 35.1481481641531, 28.20669014006853, 18.078960590064526, 29.678497463464737, 17.499655075371265, 11.924099307507277, 2.08010979462415, 3.9382350258529186, 0.9543652203865349, 0.5633264221251011, 0.9512859012465924, 0.9291317837778479, 2.0448723854497075, 1.205514168832451, 0.5019479594193399, 0.5972217314410955, 0.4040796688059345, 1.9097282434813678, 2.532602814026177, 6.360491523519158, 2.695627841167152, 25.47261904925108, 46.15692883729935, 43.01549680531025, 26.830119006335735, 26.901619769632816, 35.216848477721214, 32.87762939929962, 27.572196386754513, 23.57132837176323, 23.529878295958042, 18.745114244520664, 19.004634618759155, 23.95810391753912, 27.36345648765564, 44.99236352741718, 53.71432051062584, 74.33282732963562, 71.04326024651527, 73.89260575175285, 80.24534806609154, 85.79880326986313, 78.29381078481674, 91.80704846978188, 78.38493749499321, 62.70114988088608, 47.725902646780014, 46.77746593952179, 69.27258566021919, 32.253410294651985, 30.189756229519844, 62.967355996370316, 45.40958873927593, 3.8665670715272427, 3.661215165629983, 1.2535045249387622, 0.22814027761342004, 0.5404124048072845, 0.8238199597690254, 8.333233091980219, 50.18801853060722, 49.064035043120384, 36.13530099391937, 33.70865240693092, 32.188274189829826, 53.0806665122509, 67.72900968790054, 62.63806186616421, 50.976062044501305, 62.510521709918976, 22.154950574040413, 0.19671151094371453, 0.28295659634750336, 0.17685126804281026, 0.043429836368886754, 0.027138112236571033, 0.06790921383071691, 0.14666856732219458, 0.08449765417026356, 0.24379870301345363, 0.16898938600206748, 0.06688847133773379, 0.08104499022010714, 0.0841835253231693, 0.031130263741943054, 0.03199354476237204, 0.07320536518818699, 0.0794858270091936, 0.03919416951248422, 0.19115502160275355, 0.14210052962880582, 0.14924997958587483, 0.1615866262000054, 0.20160704356385395, 0.1320941376616247, 0.26624544931109995, 0.39426598290447146, 0.17474331631092355, 0.16792308306321502, 0.1481416859314777, 0.1932619491708465, 0.16080550092738122, 0.18836589704733342, 0.5939127027522773, 0.371638672077097, 0.29537530965171754, 0.1895098583190702, 0.45360140211414546, 0.7200741267297417, 0.695872453507036, 0.8555068157147616, 0.49089298699982464, 29.446221627295017, 101.56466647982597, 65.10164827108383, 70.58786228299141, 93.31202611327171, 89.22981396317482, 59.73558381199837, 50.442076697945595, 50.230500251054764, 36.16330549120903, 60.36298714578152, 83.89749929308891, 74.11908119916916, 83.84842872619629, 74.88207265734673, 78.76674100756645, 58.21862541139126, 31.20917122811079, 10.56838620454073, 3.4105497412383556, 1.1210717749781907, 13.98925619199872, 26.861695311963558, 39.4787909835577, 29.84260305762291, 20.04446592181921, 31.642815358936787, 24.282095432281494, 36.90042033791542, 33.561117723584175, 44.767909571528435, 60.32899037003517, 80.59684440493584, 71.75526604056358, 78.21171998977661, 60.6603591889143, 47.28073373436928, 30.00797588378191, 24.375351928174496, 18.174401968717575, 24.971215054392815, 18.313892483711243, 24.173789843916893, 30.546619780361652, 34.459412321448326, 38.32155168056488, 41.628157049417496, 74.84976679086685, 93.70688572525978, 50.66122233867645, 24.71034575253725, 29.78912852704525, 7.596944700926542, 4.793956708163023, 2.7845110092312098, 0.7131181843578815, 2.767247585579753, 3.5799802746623755, 2.5390073703601956, 4.289556574076414, 0.7314455509185791, 1.4710606634616852, 20.32849308103323, 25.785807743668556, 43.853595033288, 33.81850831210613, 28.210311345756054, 42.35867165029049, 41.260511577129364, 30.88501252233982, 12.972106821835041, 3.892207145690918, 3.025274877436459, 0.36736948241014034, 1.6080036526545882, 1.591000515036285, 6.1475234013050795, 1.5834116097539663, 0.8097518677823246, 1.9290519878268242, 0.43052369670476764, 8.382952474057674, 16.606427505612373, 11.244312934577465, 5.450020479038358, 31.274313032627106, 44.44422394037247, 51.08092121779919, 33.560285568237305, 37.21753232181072, 51.41126409173012, 46.44275709986687, 34.42753203213215, 27.698647901415825, 27.276414558291435, 25.67264411598444, 21.95389576256275, 27.43052288889885, 32.83897027373314, 54.702119305729866, 59.79132302105427, 84.19867113232613, 74.63965326547623, 75.41415050625801, 87.3904998600483, 97.38340884447098, 87.50526890158653, 117.17485964298248, 104.56066891551018, 99.79925081133842, 59.791250824928284, 49.839729219675064, 78.16409334540367, 42.730994671583176, 44.7397530823946, 69.46148112416267, 50.58062106370926, 4.793870262801647, 9.577496275305748, 2.862068172544241, 0.6657735561020672, 1.3591107144020498, 0.8343395171687007, 13.865841664373875, 64.50382634997368, 56.72518774867058, 40.72010837495327, 57.2295992821455, 54.28235962986946, 67.44581088423729, 82.49661326408386, 73.85144636034966, 55.802984833717346, 81.26145914196968, 25.971860960125923, 0.5006874958053231, 0.4874146595830098, 0.31594520900398493, 0.2695785532705486, 0.20437077182577923, 0.2141054189996794, 0.2959905203897506, 0.20560123783070594, 0.2697217877721414, 0.3392628952860832, 0.1709511791705154, 0.17928393906913698, 0.36785826086997986, 0.14343679620651528, 0.17413276626029983, 0.14679859159514308, 0.12798265437595546, 0.10838593327207491], [0.06644624780165032, 0.01481955547205871, 0.07247211586218327, 0.06969643160118721, 0.060294693321338855, 0.12247443431988358, 0.09202116882079281, 0.10178019554587081, 0.06324903108179569, 0.0694439306971617, 0.00714477999281371, 0.06930298201041296, 0.07525883585913107, 0.04709964901849162, 0.12975871766684577, 0.15305112639907748, 0.12804232304915786, 0.016846774524310604, 0.04325446316215675, 0.09817120560910553, 0.288059099111706, 0.3125025343615562, 0.2011836928431876, 3.3441627910360694, 36.110476925969124, 61.84700891375542, 50.51354706287384, 67.56662160158157, 82.96209588646889, 40.617175698280334, 27.82035157084465, 22.707091346383095, 21.46413814276457, 43.96788910031319, 76.41361087560654, 75.5179837346077, 69.05640006065369, 48.49761463701725, 27.72713117301464, 7.309351433068514, 1.998708425089717, 0.553609156049788, 0.5993210594169796, 5.836479691788554, 13.612121678888798, 21.874613016843796, 32.76434227824211, 16.25366773456335, 18.84905006736517, 26.487726978957653, 44.07933332026005, 56.15739181637764, 63.06239269673824, 71.91685616970062, 81.42670467495918, 86.29947200417519, 82.9938393831253, 79.33459773659706, 74.68691512942314, 55.06101004779339, 36.176232397556305, 22.92451187968254, 17.488852255046368, 17.810565792024136, 21.03521715849638, 18.460000343620777, 21.826642490923405, 27.87995897233486, 32.13037669658661, 39.53366003930569, 61.15444667637348, 46.45430848002434, 15.90945940464735, 10.763943661004305, 14.215170219540596, 3.0478589655831456, 2.0263740280643106, 1.0791070642881095, 0.7519181398674846, 1.0356232663616538, 2.9367781011387706, 2.3886370891705155, 2.1237198170274496, 0.4735686775529757, 0.09677535941591486, 1.440368047915399, 9.973477777093649, 27.039244584739208, 18.56180638074875, 6.782252267003059, 10.192002151161432, 2.1880149794742465, 4.153480650857091, 6.430031592026353, 3.3194679161533713, 0.44712545117363334, 0.18959428503876552, 0.6992872827686369, 0.628924974007532, 0.8476146392058581, 0.11208113108295947, 0.2870279591297731, 0.9807093255221844, 0.4943044320680201, 1.8457409832626581, 5.500165913254023, 3.72670560143888, 2.5974719831719995, 13.205665089190006, 32.7342326939106, 50.422131568193436, 40.3244736045599, 26.852129325270653, 29.52556896954775, 29.718393422663212, 29.697350151836872, 24.480613879859447, 20.6659871712327, 22.11207177489996, 25.75812242925167, 38.219587951898575, 56.605680361390114, 59.83978562057018, 71.99708506464958, 65.37618353962898, 68.72183561325073, 71.5789783000946, 74.87851604819298, 77.50526189804077, 82.39333480596542, 74.34204563498497, 80.44256508350372, 81.89395800232887, 57.53903567790985, 35.16631118953228, 48.90613071620464, 61.971741020679474, 51.131264716386795, 40.9779891371727, 43.067785799503326, 7.968434616923332, 0.41876080445945263, 0.7680236943997443, 0.5208581790793687, 2.017340725287795, 1.0012440173886716, 1.238177572377026, 22.52372268587351, 29.172740802168846, 33.563655987381935, 42.681867107748985, 39.504340812563896, 59.66758646070957, 53.866156563162804, 46.95890620350838, 52.181623354554176, 45.414349883794785, 1.3196106464602053, 0.2339817219763063, 0.09583462786395103, 0.07206357840914279, 0.20261152560124174, 0.014007362970005488, 0.03238758807128761, 0.026334516587667167, 0.052816817042184994, 0.03419363041757606, 0.0054919382637308445, 0.06782676864531823, 0.0324982497113524, 0.03972378464823123, 0.03555082184902858, 0.04585523434798233, 0.016837380790093448, 0.08694003248820081, 0.09968581769498996, 0.05665069998940453, 0.1407331373775378, 0.031004723896330688, 0.04528551726252772, 0.005486219552039984, 0.07832483344827779, 0.14400189713342115, 0.033051316713681445, 0.023698775403317995, 0.044262151277507655, 0.04687083746830467, 0.02862907393136993, 0.0874820452008862, 0.049120914191007614, 0.1595975665259175, 0.0977483818132896, 0.05091310435091145, 0.07746167859295383, 0.17212280770763755, 0.137403343396727, 0.32392199034802616, 0.17185704462463036, 0.1717311912216246, 5.15391044318676, 55.49411080777645, 72.25765988230705, 57.49484784901142, 77.80093163251877, 83.0150118470192, 46.18657484650612, 21.05855170637369, 30.743278227746487, 29.131381921470165, 54.643370658159256, 77.65628099441528, 73.91598969697952, 72.87334084510803, 52.194124683737755, 29.715444780886173, 5.534119941294193, 1.8262823461554945, 0.3913061792263761, 3.144942568615079, 15.587815213948488, 15.037178210914135, 24.07389510422945, 31.42838716506958, 21.69712644070387, 19.607599563896656, 27.764823250472546, 33.32429923117161, 41.14652909338474, 50.04415825009346, 58.63328576087952, 63.69130454957485, 73.09651806950569, 72.68107116222382, 65.44247478246689, 62.45917126536369, 47.21220821142197, 31.74778662621975, 21.106444336473942, 19.210800155997276, 21.152881644666195, 22.81148884445429, 23.970411457121372, 19.046559669077396, 24.181714318692684, 26.573967151343822, 34.58638250827789, 68.72093126177788, 74.99358907341957, 26.1066872254014, 11.725502964109182, 14.076949786394835, 4.367889845743775, 2.28078106418252, 0.462830335018225, 0.7948709756601602, 0.8604210207704455, 2.4642941169440746, 1.7337815347127616, 2.0313356118276715, 0.9425350895617157, 1.188370082527399, 11.966805215924978, 18.305671624839306, 36.262499168515205, 22.42788802832365, 14.31740278378129, 26.419811323285103, 19.42286867648363, 11.412533707916737, 2.613558894954622, 3.3399089192971587, 0.16362474183551967, 0.2836645458592102, 0.815960259642452, 1.4692881773225963, 0.2211101946886629, 0.19181955547537655, 0.3408450650749728, 0.3905465762363747, 0.28439306770451367, 1.805398310534656, 1.8921756790950894, 4.239028310403228, 3.3198813814669847, 20.845848619937897, 46.585910618305206, 52.131834626197815, 38.209434896707535, 26.21202327311039, 33.89575056731701, 26.785887479782104, 29.011751040816307, 23.416116200387478, 23.79052720963955, 23.511247895658016, 27.377327643334866, 38.47621098160744, 56.38141259551048, 60.82451418042183, 68.93042162060738, 66.03528097271919, 68.67468774318695, 68.46933916211128, 75.04854932427406, 75.75402706861496, 76.8331691622734, 71.5427814424038, 74.77668911218643, 74.37760412693024, 55.69265015423298, 37.91798673570156, 54.57994066178799, 56.12564072012901, 53.340283781290054, 45.81459380686283, 49.91798982024193, 11.68323878198862, 0.16371933597838506, 0.7032230403274298, 0.14099124149652198, 1.427521649748087, 1.2751113530248404, 0.8440216351300478, 20.990778543055058, 35.6192696839571, 36.48861363530159, 30.390311367809772, 34.50884006917477, 63.956906497478485, 62.9142652451992, 57.79921531677246, 59.86257679760456, 52.928135097026825, 2.970699593424797, 0.05451812750834506, 0.051776656255242415, 0.06521996750961989, 0.22211932257050648, 0.08203324890928343, 0.057761936259339564, 0.10146127984626219, 0.047968807848519646, 0.05487507827638183, 0.044275335530983284, 0.1092515149503015, 0.054058392997831106, 0.07287286818609573, 0.06129185407189652, 0.048641757675795816, 0.06416062591597438, 0.02897367721743649, 0.09701493210741319, 0.26778246683534235, 0.3057228965917602, 0.12228673775098287, 0.13818157429341227, 0.13965366873890162, 0.14776733180042356, 0.24373278545681387, 0.21905618224991485, 0.11849153554067016, 0.17902861058246344, 0.1392322772881016, 0.15513570047914982, 0.3283283585915342, 0.17963041813345626, 0.3141687746392563, 0.20250333531294018, 0.2537106937961653, 0.15852566779358312, 0.19424516125582159, 0.34630433307029307, 0.6067649193573743, 0.3025820682523772, 0.36636440665461123, 4.118627021089196, 79.68697562813759, 83.45604658126831, 69.476338326931, 86.20522946119308, 102.07702338695526, 64.6663436293602, 46.53137594461441, 37.77673311531544, 33.05157646536827, 62.5972368568182, 86.41054764389992, 82.51850008964539, 83.37149351835251, 60.41764721274376, 36.288729161024094, 9.117538556456566, 2.198503604158759, 0.6281317071989179, 2.298047337681055, 10.05263987928629, 21.065062656998634, 25.35604890435934, 42.86601282656193, 24.19387176632881, 27.00869992375374, 34.69610922038555, 54.79977406561375, 65.56494981050491, 68.58544573187828, 73.48063945770264, 85.06443947553635, 88.97997736930847, 88.80200251936913, 80.99209919571877, 79.4160957634449, 66.69361844658852, 49.11547668278217, 32.88383826613426, 28.31627056002617, 26.820667013525963, 25.48645220696926, 29.562180005013943, 25.107029266655445, 36.147350147366524, 36.70298293232918, 48.271268382668495, 83.3679749071598, 81.67743802070618, 36.89917400479317, 17.559644356369972, 27.071620747447014, 13.655212316662073, 2.1109532145783305, 0.6971937732305378, 0.916779002873227, 0.7632901577744633, 4.972495352849364, 4.175869049504399, 4.767647869884968, 0.782942168880254, 1.246257007587701, 27.038283236324787, 28.024512715637684, 49.24233667552471, 31.039972007274628, 26.70585237443447, 40.071133598685265, 38.01588848233223, 32.935146912932396, 13.029043916612864, 4.340207856148481, 0.8607570652384311, 0.43745244678575546, 1.6394082549959421, 1.5734588750638068, 0.6182116863783449, 0.3111039422219619, 1.089290042873472, 1.20496925432235, 1.262044922914356, 2.97238836530596, 13.114974405616522, 10.554227214306593, 7.83438540995121, 26.03586472570896, 48.02102521061897, 61.48296184837818, 44.55501839518547, 32.11269624531269, 38.63261818885803, 38.94924379885197, 41.7446132004261, 31.14170014858246, 28.351262882351875, 33.450669050216675, 34.8689391463995, 45.34259453415871, 60.715228244662285, 58.73093672096729, 70.34871071577072, 63.68239402770996, 71.15349993109703, 72.48813271522522, 78.1630066037178, 79.39022675156593, 83.28140035271645, 72.87887334823608, 82.8652922809124, 87.15479090809822, 64.16629806160927, 44.97437909245491, 65.98627120256424, 74.02171522378922, 63.86203318834305, 53.978698924183846, 56.68698459863663, 11.40170618891716, 0.8628138236235827, 1.7409700364805758, 0.8803473296575248, 2.830184558406472, 2.0667224004864693, 2.2627137461677194, 26.524286717176437, 42.31922596693039, 47.746406346559525, 57.65331074595451, 53.90305258333683, 81.69771373271942, 70.26733428239822, 64.128847271204, 71.56059488654137, 66.3675807416439, 2.597569590434432, 0.303172372514382, 0.18751192255876958, 0.19989916880149394, 0.3759810671908781, 0.18987872055731714, 0.1305848319316283, 0.21675424795830622, 0.1793112204177305, 0.13148704601917416, 0.13398320035776123, 0.2234095017774962, 0.18241360550746322, 0.13784392678644508, 0.15260904387105256, 0.15231414407026023, 0.14724269276484847, 0.16250878921709955, 0.19363792118383572], [0.0322776611574227, 0.04932931668008678, 0.042884728900389746, 0.12638893676921725, 0.0914734712569043, 0.15417979942867532, 0.03443288027483504, 0.08685744629474357, 0.028220293424965348, 0.022171763885125984, 0.2103060533409007, 0.08071236705291085, 0.01079552686860552, 0.0825934368185699, 0.01552152698423015, 0.1494323994847946, 0.15343432693043724, 0.290866406285204, 0.1353802636731416, 0.06588749223737977, 0.10532455184147693, 0.2582686679670587, 0.3200946457218379, 0.7112974883057177, 21.73219095915556, 59.591476544737816, 77.47453674674034, 60.456059351563454, 89.8734538257122, 52.09451302886009, 30.959705114364624, 25.184151828289032, 23.490012735128403, 37.30297453701496, 76.95809125900269, 58.24905417859554, 20.365620888769627, 8.488733097910881, 1.9237430789507926, 1.3505155756138265, 0.12698937876848504, 3.738239645026624, 5.809592809528112, 14.422841425985098, 23.88977788388729, 42.00519561767578, 35.05614750087261, 21.212660036981106, 32.97364264726639, 38.38110588490963, 68.76707598567009, 84.0539900958538, 78.19291099905968, 68.46911877393723, 75.73678359389305, 69.89226400852203, 72.04579845070839, 85.1623222231865, 81.96029484272003, 79.60460364818573, 56.133745685219765, 39.55749236047268, 26.03935293853283, 30.04562236368656, 28.618430346250534, 28.964935652911663, 21.319985277950764, 26.133652478456497, 26.388430707156658, 47.629938796162605, 56.49521268904209, 35.31986854970455, 14.522741865366697, 10.496533960103989, 6.721641244366765, 4.226706996560097, 1.2187044485472143, 0.7524400181137025, 0.5977823794819415, 0.6089850096032023, 0.6709440692793578, 0.9798632771708071, 0.537686466705054, 0.4095976852113381, 0.7669437804725021, 14.735832531005144, 14.77608472108841, 22.58043274283409, 16.406917311251163, 5.235397070646286, 11.214152052998543, 3.552906014956534, 3.839572132565081, 4.033002415671945, 0.8736275089904666, 0.17940124293090776, 0.049186523756361566, 0.5666188267059624, 0.6797736673615873, 0.7488282525446266, 1.6342950356192887, 0.0878886308055371, 0.13669258856680244, 0.2427269527106546, 0.9230221272446215, 3.123635924421251, 3.2707773288711905, 5.476765343919396, 13.543564807623625, 31.686254628002644, 44.74407345056534, 36.4309973269701, 28.596606217324734, 23.651302680373192, 25.03705222159624, 26.591204926371574, 28.247271962463856, 32.337807565927505, 39.51057247817516, 51.72583781182766, 61.975848600268364, 63.78954067826271, 60.54122418165207, 61.07578709721565, 64.614377617836, 62.853810489177704, 69.73382771015167, 73.28933492302895, 72.4246533215046, 72.90507674217224, 69.42707017064095, 69.23432931303978, 69.29573401808739, 79.13600519299507, 55.8622008562088, 48.654227033257484, 55.77724501490593, 48.416230604052544, 33.935580030083656, 49.79766547679901, 17.56763342767954, 0.49251932941842824, 0.29587999975774437, 0.6825757795013487, 0.8082179969642311, 1.1263290303759277, 0.6162166746798903, 4.939314583316445, 36.64801128208637, 40.28359539806843, 38.07582646608353, 50.71212440729141, 62.219814509153366, 48.28343912959099, 49.486431777477264, 57.8892020881176, 10.416222419589758, 0.1794011687161401, 0.2915259974543005, 0.11043725913623348, 0.07043504665489309, 0.1668011338915676, 0.17286174930632114, 0.01731485448544845, 0.0497313603409566, 0.04154429516347591, 0.14616445609135553, 0.13256128993816674, 0.06348389113554731, 0.14352862956002355, 0.017477698384027462, 0.007955498404044192, 0.0613516600424191, 0.02761799049039837, 0.036751568550243974, 0.07313557362067513, 0.08150492882123217, 0.06709196823067032, 0.08531205734470859, 0.05178538391191978, 0.07967888188431971, 0.13555403013015166, 0.029046839990769513, 0.0268331192273763, 0.06189228493894916, 0.037509909889195114, 0.03840581572148949, 0.05165368609596044, 0.03467183698376175, 0.03047363003133796, 0.05517644218343776, 0.07264249812578782, 0.18406204908387735, 0.17240516521269456, 0.03545284351275768, 0.03871632659866009, 0.07990328507730737, 0.148725014005322, 0.5373139679431915, 1.3128136424347758, 32.00320512056351, 75.0159926712513, 79.53319787979126, 73.23087126016617, 87.3446287214756, 59.62806478142738, 28.69761999696493, 29.194895513355732, 30.902288295328617, 52.34041303396225, 83.31597849726677, 60.08830368518829, 21.942023299634457, 8.05837294086814, 1.4614056190475821, 0.9027971187606454, 0.38124167709611356, 5.266941552981734, 16.487064510583878, 17.239568531513214, 24.119057580828667, 40.56107170879841, 37.530031353235245, 23.18899668753147, 27.346270009875298, 34.72497247159481, 53.190913796424866, 73.0356453359127, 66.19922697544098, 63.55092868208885, 70.6014047563076, 69.08645644783974, 72.88198158144951, 78.69927942752838, 74.43951800465584, 73.0479946732521, 52.59974151849747, 38.43706928193569, 24.421399757266045, 28.6647080630064, 25.5646900087595, 28.155883066356182, 19.651152826845646, 27.990563437342644, 22.98429597169161, 43.93492966890335, 68.08679088950157, 64.7218282520771, 21.060312911868095, 10.464954804629087, 9.255922380834818, 5.6876378785818815, 0.5933931993786246, 0.6767466547898948, 0.1947639076388441, 0.533479736186564, 0.8523304236587137, 0.9989047679118812, 0.45681027055252343, 0.664923886070028, 0.16590727638686076, 19.207876212894917, 23.733602464199066, 34.797643572092056, 25.2468940615654, 13.957280907779932, 29.4642136618495, 20.290516018867493, 11.523653045296669, 2.604609662666917, 1.2895254045724869, 0.1169576721440535, 0.5141430487856269, 0.8404264342971146, 1.0254557244479656, 2.404779097996652, 1.3444151217117906, 0.06667459922027774, 0.1558499434031546, 0.42729125765617937, 1.6348216636106372, 3.7753496412187815, 4.0977072436362505, 5.687307771295309, 19.187078028917313, 43.59026536345482, 51.8297204375267, 39.09995511174202, 29.113796465098858, 25.105431452393532, 25.006005987524986, 24.956954419612885, 25.88262464851141, 27.0386803150177, 35.199817791581154, 49.529316276311874, 62.14451014995575, 64.21714693307877, 62.58975885808468, 62.16498725116253, 65.35663738846779, 63.94068896770477, 68.74314486980438, 73.6366818845272, 73.31303045153618, 71.4780405163765, 69.18876975774765, 70.76126217842102, 65.59314429759979, 67.92046621441841, 50.533495992422104, 55.13998880982399, 56.98570176959038, 53.98777283728123, 39.71377417445183, 54.37893904745579, 24.727085754275322, 1.0412610950879753, 0.30254228913690895, 0.9325980290304869, 1.0861193505115807, 1.0491101676598191, 1.4702762430533767, 4.642425589263439, 40.66574849188328, 33.992827758193016, 26.803843416273594, 48.89755077660084, 65.80429896712303, 57.337144911289215, 60.79964831471443, 69.94527116417885, 15.54120596498251, 0.11955110720009543, 0.3665706643369049, 0.20242250058799982, 0.023478934563172515, 0.14217906369594857, 0.14349492121255025, 0.03231563685403671, 0.1202326659404207, 0.12544945202535018, 0.045723336152150296, 0.0979354623996187, 0.04090684597031213, 0.13601760525489226, 0.040802462899591774, 0.09631077497033402, 0.06296698527876288, 0.06273922757827677, 0.042419547025929205, 0.04449143038073089, 0.11483494425192475, 0.16999371960991994, 0.21724403573898599, 0.18062974966596812, 0.2519702090648934, 0.20105993229663, 0.12352984253084287, 0.14558862370904535, 0.09785263871890493, 0.21272592974128202, 0.40404986415524036, 0.15638173674233258, 0.13051410525804386, 0.20086551929125562, 0.22381729708286002, 0.40041268744971603, 0.36414295085705817, 0.4805489326827228, 0.2444295582245104, 0.23579891509143636, 0.2627519523957744, 0.2792805014178157, 0.7142943993676454, 1.0961590055376291, 37.91439212858677, 92.15000286698341, 82.7958396077156, 84.07889395952225, 102.02218472957611, 79.38969478011131, 43.98912616074085, 40.96806026995182, 31.824270822107792, 58.00804451107979, 93.2219785451889, 72.36335501074791, 27.708373479545116, 11.652387287467718, 1.6464710072614253, 3.094911128282547, 0.6150096456985921, 8.986836019903421, 11.991115361452103, 21.492182537913322, 31.12023700028658, 51.506711170077324, 45.253523513674736, 29.718421921133995, 44.24035727977753, 53.396459966897964, 80.87340876460075, 92.24837198853493, 72.25601837038994, 64.44533228874207, 74.68117743730545, 70.59159368276596, 76.90851911902428, 89.10275638103485, 82.49074637889862, 84.42702367901802, 61.36925294995308, 51.26865394413471, 36.97023019194603, 37.26668268442154, 36.06412701308727, 40.14118663966656, 27.771552689373493, 35.98484046757221, 28.40613193809986, 56.0327585041523, 74.31464910507202, 69.9132464826107, 30.16288597136736, 20.480597019195557, 13.289510440081358, 6.9237561989575624, 2.48962783254683, 0.7865759020205587, 0.6221138988621533, 0.5892657896038145, 1.1240940378047526, 2.056071334518492, 0.3364096046425402, 1.6577666136436164, 0.7955998240504414, 30.891542471945286, 29.835206754505634, 51.313727125525475, 32.512081414461136, 25.15429113060236, 47.369158789515495, 36.102124974131584, 30.425480380654335, 6.337711745873094, 1.901500141248107, 0.27390782721340656, 1.2343995063565671, 2.194625912234187, 2.693494255654514, 7.075843038037419, 3.5048673301935196, 0.2495482546510175, 0.35120755434036255, 0.6144729838706553, 1.3781126635149121, 3.731546779163182, 9.283615294843912, 12.909652423113585, 28.001573346555233, 45.28956837952137, 56.37031339108944, 45.718116983771324, 37.946287617087364, 32.67328396439552, 36.309335455298424, 34.88581404089928, 34.425050765275955, 39.87957067787647, 49.4915197044611, 56.86960279941559, 62.542086616158485, 63.43399375677109, 58.691665828228, 60.37191666662693, 63.35493139922619, 66.16458803415298, 71.27655252814293, 76.86964720487595, 72.99928888678551, 70.89120000600815, 68.2041209936142, 70.86305871605873, 69.77864250540733, 78.6926981806755, 61.46258734166622, 67.31874570250511, 65.83148270845413, 58.86571168899536, 43.823918625712395, 61.17496557533741, 29.494366943836212, 1.3601908064447343, 1.7786804004572332, 1.8504371750168502, 2.083746436983347, 1.476180769968778, 2.209702553227544, 7.326107583940029, 49.328348860144615, 47.002208679914474, 51.715441569685936, 68.22934404015541, 77.27510064840317, 70.26073783636093, 68.87998312711716, 83.60480859875679, 14.840349722653627, 0.23057793587213382, 0.511016232194379, 0.3130589966895059, 0.18833187699783593, 0.32489331322722137, 0.29243661265354604, 0.1214686461025849, 0.14594198990380391, 0.2002630289644003, 0.3142905462300405, 0.2674121054587886, 0.09702503273729235, 0.23757582443067804, 0.14446155371842906, 0.26406463352032006, 0.2723801013780758, 0.1619126516743563, 0.14828174404101446, 0.20216009201249108], [0.06198348375619389, 0.01792187562386971, 0.02565870207035914, 0.07178264582762495, 0.03190360017470084, 0.1320362649857998, 0.07993026956683025, 0.0631842935399618, 0.018168643437093124, 0.02966583753732266, 0.06425226631108671, 0.028773545964213554, 0.05722199042793363, 0.061130025060265325, 0.07533316194894724, 0.06462677629315294, 0.061095481796655804, 0.047453223014599644, 0.04793785286892671, 0.09071406122529879, 0.07361679701716639, 0.2193670827546157, 0.13828364928485826, 0.20869007130386308, 6.804793132469058, 65.49127176404, 79.90846574306488, 75.08823439478874, 80.81055253744125, 78.93038302659988, 42.95635297894478, 38.119660913944244, 26.16288810968399, 35.315806567668915, 58.0709083378315, 8.328100517392159, 3.576071234419942, 1.1015583970583975, 0.5102492077276111, 0.1610378673649393, 0.5719498218968511, 2.692046770825982, 7.917922977358103, 44.462006986141205, 32.397027388215065, 62.88591496646404, 28.602138720452785, 43.236466348171234, 61.77440620958805, 82.09688991308212, 84.43908423185349, 69.62070018053055, 69.21278446912766, 69.6443273127079, 64.74289432168007, 72.70599022507668, 68.96429300308228, 71.60535648465157, 74.77404445409775, 72.8419241309166, 76.03831261396408, 66.96882247924805, 56.29657834768295, 43.29073503613472, 40.76697885990143, 32.81298726797104, 27.08517462015152, 20.780513025820255, 23.22883564978838, 30.791881419718266, 50.71340873837471, 37.27671794593334, 9.296821486204863, 6.115775154903531, 6.75354765728116, 0.9045669925399125, 0.8598959958180785, 0.34667059779167175, 0.5671060911845416, 0.2133669820614159, 0.32421534648165107, 0.44540004688315094, 0.39009241154417396, 0.14372130593983456, 1.3547027134336531, 9.906792305409908, 22.993322387337685, 22.970977686345577, 12.827994804829359, 3.1021682638674974, 12.594640776515007, 7.001679567620158, 4.682259801775217, 6.736473273485899, 0.36423524434212595, 0.12247997816302814, 0.6583333772141486, 0.5474205943755805, 2.3088629823178053, 1.0092222830280662, 0.4546832456253469, 0.08431272581219673, 0.22413570812204853, 1.1575297499075532, 0.7012223883066326, 1.18720413884148, 3.263818477280438, 5.224141124635935, 16.18117332458496, 32.427547350525856, 43.598776906728745, 33.70112121105194, 29.266876950860023, 27.37626940011978, 27.003910280764103, 26.709739565849304, 34.11358527839184, 50.961106047034264, 59.88744266331196, 66.69194653630257, 64.9906562268734, 64.73735421895981, 62.35375352203846, 62.672583013772964, 65.75525879859924, 67.0491349697113, 69.26166504621506, 72.5109314918518, 68.8270291686058, 69.18888375163078, 66.84267684817314, 65.04370898008347, 66.07265576720238, 82.677491158247, 71.23448878526688, 54.27430786192417, 45.79917423427105, 47.34886787831783, 39.41206656396389, 44.24216978251934, 30.520304292440414, 1.4142905222252011, 0.4389017721405253, 0.42910242453217506, 0.46001762500964105, 0.6413495948072523, 0.9678963536862284, 2.982575143687427, 22.11704570800066, 38.27018603682518, 42.06531219184399, 59.3491255491972, 61.56431168317795, 63.44277888536453, 54.625944793224335, 38.48615124821663, 0.967367053963244, 0.03391156977158971, 0.04691223075496964, 0.05237322795437649, 0.06291663798037916, 0.04454747737327125, 0.08836959445034154, 0.020999897860747296, 0.06335015612421557, 0.09771771627129056, 0.08146732419845648, 0.03600669348088559, 0.02647036857524654, 0.04460307536646724, 0.046620600114692934, 0.08724768238607794, 0.0743341792258434, 0.023634407079953235, 0.054730088595533744, 0.027169731438334566, 0.03850995017273817, 0.08285876945592463, 0.005367147059587296, 0.03553394170012325, 0.04020630309241824, 0.16028038691729307, 0.06584771312191151, 0.057796145556494594, 0.04656408927985467, 0.06396276934538037, 0.07970810023834929, 0.0538850124576129, 0.021155474278202746, 0.051290809278725646, 0.05344185381545685, 0.060908831655979156, 0.040729305692366324, 0.058190418931189924, 0.022837832148070447, 0.06328786024823785, 0.05702875001588836, 0.2932155114831403, 0.22680408525047824, 0.42502331372816116, 13.694664649665356, 79.31338727474213, 82.85501763224602, 86.9190363585949, 87.50330060720444, 78.44249680638313, 38.84643651545048, 30.65403051674366, 31.51778306812048, 49.60903599858284, 69.09470200538635, 10.31986529007554, 2.533351848833263, 1.072625562082976, 0.49744600255507976, 0.14471229573246092, 1.0375173459760845, 5.859836563467979, 8.493615835905075, 18.853258341550827, 32.28430263698101, 53.366566970944405, 34.87455144524574, 38.78856562077999, 49.115495681762695, 66.21514052152634, 79.16797667741776, 69.21972289681435, 68.94506603479385, 67.70760163664818, 69.9435992538929, 77.91331440210342, 70.67794784903526, 75.0299683213234, 70.27662098407745, 73.5299152135849, 69.77591425180435, 63.319289311766624, 50.04434823989868, 35.03103844821453, 34.00774195790291, 30.038070268929005, 23.886508159339428, 20.29252041131258, 21.618026085197926, 34.18759010732174, 61.854562908411026, 57.9501698166132, 14.889789819717407, 7.973061818629503, 5.442566704005003, 2.079090974293649, 0.512838828144595, 0.34140105242840946, 0.3082423098385334, 0.365197928622365, 0.49222445930354297, 0.19671850197482854, 0.4415310232434422, 0.4905383591540158, 0.8809902076609433, 7.86610278300941, 31.445592641830444, 35.4657769203186, 20.241067372262478, 6.882649529725313, 32.04194024205208, 21.549451164901257, 15.208688657730818, 4.993679216131568, 1.9380252063274384, 0.9840960125438869, 1.544891414232552, 0.8215253578964621, 2.687422181479633, 0.7029364525806159, 0.3683398850262165, 0.18818369979271665, 0.42363294458482414, 1.0588195966556668, 0.7573689473792911, 2.121334969997406, 2.2456481494009495, 4.8538376949727535, 19.93217244744301, 39.24563929438591, 51.88072890043259, 33.55292536318302, 30.334264375269413, 26.862377375364304, 27.814832367002964, 23.750933334231377, 26.982078552246094, 40.914760529994965, 56.166708916425705, 67.2364953160286, 64.0982361137867, 64.72078710794449, 66.4159445464611, 61.676318272948265, 64.5207430422306, 69.49143871665001, 70.55344372987747, 73.22581753134727, 66.57292172312737, 67.99963116645813, 67.51245930790901, 65.10992422699928, 65.35063371062279, 76.62920370697975, 64.30271074175835, 57.42149658501148, 50.480956211686134, 53.18115592002869, 45.072337836027145, 46.04511223733425, 35.508878007531166, 3.2793078711256385, 0.7470498292241246, 0.5792219191789627, 0.640924908220768, 0.8941399957984686, 0.8973824686836451, 3.481911337003112, 23.246821984648705, 30.899883024394512, 34.588810577988625, 62.63538680970669, 69.43704083561897, 75.02522617578506, 63.523060977458954, 51.983380392193794, 1.7304183589294553, 0.08974972937721759, 0.06052060307411011, 0.02824291594151873, 0.0483084109146148, 0.0776141528331209, 0.0903952048975043, 0.040251151076518, 0.05652700623613782, 0.07021348588750698, 0.025126808541244827, 0.1160258760501165, 0.03397156127903145, 0.05821787468448747, 0.05285446619382128, 0.09963133663404733, 0.023420835532306228, 0.061377716847346164, 0.0604547411785461, 0.005098888041175087, 0.14014736021636054, 0.12107990172808059, 0.19801142712822184, 0.13681124313734472, 0.1464949789806269, 0.3395691647892818, 0.16997863916913047, 0.19715452857781202, 0.13533518562326208, 0.12450170717784204, 0.18925006210338324, 0.12698099249973893, 0.15602970641339198, 0.2829928428400308, 0.2560539508704096, 0.23843073402531445, 0.1697765226708725, 0.12540367635665461, 0.1895860323566012, 0.19171902415109798, 0.19169301929650828, 0.5278264114167541, 0.689643993973732, 0.5077223433181643, 13.14859215170145, 101.45362123847008, 87.86679670214653, 91.55239373445511, 95.6191635131836, 102.92679458856583, 62.18104898929596, 56.4056096971035, 39.69603672623634, 55.743841007351875, 74.80328008532524, 14.029690772294998, 3.839564057998359, 1.468135651666671, 1.0364549467340112, 0.17301526997471228, 1.4421045547351241, 9.364394210278988, 12.89378447458148, 57.74816885590553, 43.290541246533394, 76.4362120628357, 38.570506721735, 52.46817357838154, 72.35917523503304, 87.47583568096161, 90.96445128321648, 73.80916982889175, 68.46792563796043, 68.53129863739014, 66.92309573292732, 76.50671347975731, 70.51722407341003, 72.88339510560036, 72.49931931495667, 72.48593643307686, 74.14843082427979, 68.61954510211945, 64.00330200791359, 53.731184005737305, 53.17112445831299, 43.658220916986465, 36.18164710700512, 29.710155464708805, 27.222151570022106, 38.3198531717062, 64.96259853243828, 65.62373265624046, 19.110177755355835, 17.790732756257057, 6.942830225452781, 1.731718957889825, 3.1635936303064227, 0.8630557637661695, 0.5849921470507979, 0.3727918508229777, 1.3677877862937748, 0.5354118731338531, 0.6376038864254951, 1.1913088685832918, 1.8217154662124813, 19.304047152400017, 38.43096300959587, 49.42336656153202, 27.090203650295734, 18.40048223733902, 48.20029579102993, 34.603466391563416, 35.53055204451084, 6.870117327198386, 1.8273378582671285, 1.4203101117163897, 2.8039353294298053, 1.187625559978187, 6.833041766658425, 3.397803087718785, 1.5097172954119742, 0.618405060376972, 1.0422841901890934, 1.9310695608146489, 1.4658516179770231, 1.1556837614625692, 9.870856683701277, 12.10040794685483, 31.362926177680492, 40.607752203941345, 53.78876991569996, 41.04781799018383, 39.912682101130486, 35.48160307109356, 36.98248453438282, 34.0735050290823, 40.89443542063236, 60.85091896355152, 65.55855095386505, 67.78552785515785, 62.34587274491787, 63.0314015597105, 66.2337975203991, 65.51624402403831, 67.69795775413513, 71.29795297980309, 73.0029746890068, 74.30402487516403, 66.95158660411835, 68.29297542572021, 66.92123383283615, 64.83687847852707, 64.0195195376873, 83.97446796298027, 69.39253762364388, 68.91330733895302, 58.53737510740757, 58.88956680893898, 52.771834284067154, 54.417567774653435, 41.765067502856255, 4.08711246214807, 1.13993170671165, 1.0641800402663648, 1.829307577572763, 1.6527051664888859, 2.051401622593403, 4.0312739834189415, 30.557983070611954, 47.01023004949093, 57.85737879574299, 77.83819243311882, 80.16255050897598, 81.9445712864399, 69.65628147125244, 60.689838007092476, 1.3756481395103037, 0.09302485676016659, 0.10227908947854303, 0.19766331533901393, 0.13862223189789802, 0.1619776786537841, 0.24199946987209842, 0.11031467118300498, 0.12336078129010275, 0.22329457278829068, 0.24965815187897533, 0.16096509236376733, 0.16682216635672376, 0.18573225243017077, 0.13207637064624578, 0.2114066286594607, 0.15714432316599414, 0.09135531392530538, 0.20199962484184653, 0.26687568111810833], [0.005151291552465409, 0.01691187200776767, 0.03514389485644642, 0.1476247058599256, 0.08078077822574414, 0.05613617271592375, 0.12103665678296238, 0.06141469435533509, 0.024739771106396802, 0.06347647708025761, 0.0443756998720346, 0.09718339963001199, 0.0831723194278311, 0.05984081064525526, 0.09732033329783008, 0.014472645962086972, 0.08843678850098513, 0.05436999854282476, 0.08433413677266799, 0.08712765484233387, 0.06444704296882264, 0.05037224567786325, 0.03522418410284445, 0.3005703433882445, 0.7136886881198734, 47.01024904847145, 85.0745165348053, 58.12831185758114, 64.43870544433594, 89.0440571308136, 58.727038130164146, 53.231104239821434, 25.364121571183205, 47.258417531847954, 14.048403818160295, 2.233127821236849, 0.059242183197056875, 0.6518313917331398, 0.13089034444419667, 0.7401603239122778, 0.7287969742901623, 2.921059294603765, 50.86298011243343, 50.032789260149, 52.93112933635712, 62.46085837483406, 36.17707595229149, 58.62584576010704, 84.48133036494255, 75.66318154335022, 65.87932214140892, 65.78734427690506, 70.1516304910183, 69.89287197589874, 70.87755113840103, 69.28566455841064, 71.35643184185028, 66.43637225031853, 72.72073343396187, 70.77009290456772, 74.85545888543129, 73.27101990580559, 73.92879500985146, 73.21480572223663, 51.44303418695927, 35.456482619047165, 39.52115871012211, 45.83619564771652, 28.042753636837006, 29.78329014033079, 47.82677203416824, 36.95103742182255, 11.26637740060687, 4.427085444331169, 6.014858745038509, 1.3222716911695898, 1.5708146919496357, 0.8800155005883425, 0.41821295104455203, 0.18065639276755974, 0.9151314944028854, 0.3668338595889509, 0.9110451105516404, 0.3364877082640305, 1.1691102222539485, 2.646708316169679, 2.672935458831489, 17.425891533493996, 13.247080966830254, 2.558282073587179, 14.449840877205133, 10.419107414782047, 6.3544203992933035, 7.101825093850493, 1.7170592257753015, 0.48454931646119803, 0.38756807043682784, 0.5302060337271541, 0.21893435128731653, 0.11705088589224033, 0.08084063985734247, 0.3179077443201095, 0.2596629556501284, 0.5519947176799178, 0.7411653699818999, 2.372874110005796, 4.41168487071991, 6.747188223525882, 16.705119609832764, 26.292385160923004, 45.293577164411545, 34.92233768105507, 28.25642567127943, 31.384049244225025, 27.35995877534151, 36.422322392463684, 56.829321160912514, 68.38657960295677, 61.878813207149506, 60.52063308656216, 66.35554298758507, 60.98591811954975, 65.08951932191849, 71.24065965414047, 65.75245454907417, 66.1347596347332, 66.62446975708008, 66.81844174861908, 69.73227739334106, 65.93957930803299, 69.63219076395035, 70.01847043633461, 67.66065135598183, 73.1743834912777, 75.0936833024025, 58.615970090031624, 54.54772599041462, 50.217105969786644, 46.904443725943565, 49.30730178952217, 36.090729385614395, 2.6773294480517507, 2.3648468032479286, 1.8222553934901953, 0.48982503649313003, 0.12081362656317651, 0.7068567140959203, 1.7733789724297822, 11.975368056446314, 30.517192259430885, 38.12586598098278, 63.01844425499439, 51.82767994701862, 52.5245663523674, 51.0636131465435, 12.083448506891727, 0.3325268067419529, 0.09068450890481472, 0.05008846696000546, 0.16013584623578936, 0.06573439459316432, 0.04423374186444562, 0.07801173618645407, 0.015503681115660584, 0.021304688634700142, 0.09268779554986395, 0.046532707565347664, 0.011456710872153053, 0.13392983993981034, 0.05537963479582686, 0.020754037323058583, 0.0442302055307664, 0.010282850325893378, 0.046859274807502516, 0.05180652398848906, 0.02046485577011481, 0.08044379865168594, 0.06391435163095593, 0.029950061543786433, 0.16599726921413094, 0.020534550858428702, 0.009282720984629123, 0.1014808205945883, 0.0133937970167608, 0.004713402158813551, 0.045923048091935925, 0.054070304468041286, 0.05235820688540116, 0.023276005413208622, 0.010604662256810116, 0.12786542472895235, 0.0539359386311844, 0.06066794907383155, 0.08026002062251791, 0.05180855005164631, 0.03888236729835626, 0.029347469171625562, 0.032771697733551264, 0.05154978913196828, 0.3582691488554701, 1.4416529727168381, 64.2466713488102, 88.59067305922508, 64.30614575743675, 73.7598180770874, 90.69422498345375, 57.34340697526932, 35.2470226585865, 23.40216714888811, 59.46918770670891, 21.85599211603403, 2.0903288712725043, 0.1008407850167714, 0.7724999135825783, 0.12971242249477655, 2.0732471253722906, 3.6503007262945175, 10.359448716044426, 37.67649069428444, 44.919836819171906, 50.17066866159439, 58.36633488535881, 40.409364849328995, 52.57243238389492, 73.89725670218468, 68.99602890014648, 67.88140431046486, 65.05465999245644, 69.46119993925095, 67.73372143507004, 71.38018056750298, 72.5685515999794, 72.58937448263168, 66.82785004377365, 75.96005961298943, 70.2181725203991, 76.77687898278236, 71.8285945057869, 69.34548854827881, 62.50731848180294, 41.982860416173935, 24.12161484360695, 26.852245219051838, 39.42507706582546, 26.564872339367867, 32.2695442289114, 56.155028343200684, 50.20909979939461, 15.42499490082264, 3.9733883645385504, 3.127491530030966, 1.2783113750629127, 0.6535674235783517, 0.3884892538189888, 0.12724331201752648, 0.014864261520415312, 0.5216113105416298, 0.6477380613796413, 0.5497961794026196, 0.5694402346853167, 0.538892011390999, 1.5860667172819376, 9.265734404325485, 28.000621497631073, 16.4766226708889, 3.7822821317240596, 29.86863736063242, 21.083902046084404, 13.954669497907162, 3.302079336717725, 1.5233060787431896, 0.9000430977903306, 0.5581676645670086, 0.26705130294431, 0.07685760007007048, 0.3696005267556757, 0.17453486187150702, 0.07072704465826973, 0.2011750839301385, 0.2033346297685057, 0.374307167949155, 3.801847519353032, 3.542031473480165, 6.275069732218981, 19.711170606315136, 31.321639493107796, 56.11221984028816, 34.859967827796936, 29.87707670778036, 27.16943319886923, 15.203678626567125, 21.80839776992798, 43.75725120306015, 59.61625501513481, 62.37841419875622, 63.461629673838615, 65.77780678868294, 62.51222021877766, 66.4817950129509, 68.47009152173996, 66.23640418052673, 68.75791847705841, 64.61915016174316, 65.90302526950836, 68.2307043671608, 66.98800384998322, 71.40506163239479, 69.48627859354019, 68.36977690458298, 74.43647056818008, 71.69188544154167, 60.32740205526352, 58.96426700055599, 53.28026980161667, 51.436122357845306, 53.247158378362656, 48.597838059067726, 7.445808760821819, 4.236988294869661, 4.111638721078634, 0.8285457780584693, 0.227921002660878, 0.4961340338923037, 2.1796753769740462, 17.141647785902023, 34.08932738006115, 39.37323644757271, 64.79923009872437, 64.03893649578094, 60.20294353365898, 63.824308812618256, 20.04000686109066, 0.3174786642193794, 0.05709953977202531, 0.08558429195545614, 0.10841361538041383, 0.06421671743737534, 0.0829020440869499, 0.026227847702102736, 0.009307724867539946, 0.044527446807478555, 0.07086894329404458, 0.08513776396284811, 0.029775452749163378, 0.019563190871849656, 0.02638757086970145, 0.03584742487873882, 0.020692082835012116, 0.011969086845056154, 0.035271737215225585, 0.03936977649573237, 0.06613480552914552, 0.14436468860367313, 0.20320549607276917, 0.12565296376124024, 0.3058001393219456, 0.15596794488374144, 0.13748842320637777, 0.5102481984067708, 0.1449169058469124, 0.10412676259875298, 0.11072107867221348, 0.16311902756569907, 0.10536975605646148, 0.1672967104241252, 0.23425180435879156, 0.2752797317225486, 0.14453386858804151, 0.19222101283958182, 0.1740234182216227, 0.17267263523535803, 0.2165026153670624, 0.1849463625694625, 0.18054679239867255, 0.17420488817151636, 0.6012827635277063, 0.9137976472266018, 73.30946624279022, 106.31210893392563, 70.1639798283577, 79.89472568035126, 110.81872031092644, 79.30955708026886, 67.17176958918571, 41.997292041778564, 65.77282905578613, 27.890191823244095, 2.033446398563683, 0.43165054405108094, 1.3643133477307856, 0.3046035300940275, 4.850538047030568, 7.6162647642195225, 13.05659718811512, 61.860471591353416, 64.36159238219261, 65.62303349375725, 74.83880057930946, 48.00859987735748, 68.97845104336739, 95.67337900400162, 76.53569832444191, 71.16201907396317, 64.26269888877869, 68.62881660461426, 69.00561198592186, 73.63972932100296, 70.25293305516243, 73.00729885697365, 64.83374744653702, 73.60427722334862, 72.57225260138512, 77.15436592698097, 73.74090269207954, 75.2017343044281, 80.07428884506226, 63.01901802420616, 46.11894987523556, 47.97933764755726, 57.68953040242195, 33.1563900411129, 36.69689565896988, 62.097240686416626, 57.94372536242008, 23.623830154538155, 11.872898004949093, 5.068276338279247, 1.7484887642785907, 2.9737819405272603, 0.9372888773214072, 0.49362955265678465, 0.14627393771661445, 1.680116776842624, 1.2913034716621041, 0.9757684031501412, 0.5247105786111206, 2.1515948837623, 6.899869730696082, 26.14803660660982, 40.887337401509285, 21.643055342137814, 8.424908872693777, 45.82977779209614, 33.1310947984457, 34.46604296565056, 7.021258492022753, 3.7210023449733853, 1.7900053365156054, 1.4902749261818826, 1.0951799643225968, 0.17682590143522248, 0.4446199012454599, 0.2895760192768648, 0.47339825076051056, 0.46555582783184946, 1.3779901200905442, 0.6924480060115457, 3.510382496751845, 8.656386751681566, 14.111317042261362, 31.949521601200104, 37.00817495584488, 60.999316200613976, 42.99687020480633, 40.759326070547104, 40.05511365830898, 37.71638095378876, 45.539864748716354, 64.17896658182144, 71.44977763295174, 62.40297608077526, 62.31876499950886, 66.33269861340523, 63.5094653069973, 66.87027096748352, 74.72037613391876, 65.67013576626778, 66.72564312815666, 67.10060700774193, 68.4836719930172, 67.84364953637123, 66.9211958348751, 69.78620409965515, 71.93701788783073, 68.63573223352432, 73.09325784444809, 73.93422871828079, 65.2800714969635, 66.41396105289459, 61.9886577129364, 57.64698788523674, 59.085161313414574, 48.37699390947819, 8.46516391262412, 7.1149305906146765, 6.37129339389503, 1.815312928520143, 0.6425423151813447, 1.1187666049227118, 2.913948451168835, 21.161182299256325, 41.59284554421902, 54.65291954576969, 77.73093938827515, 74.8278495669365, 66.2649254500866, 74.30199578404427, 19.780646078288555, 0.6894966925028712, 0.15142383403144777, 0.26541501574683934, 0.189412651816383, 0.11137238747323863, 0.14759415906155482, 0.2758331364020705, 0.13890549482312053, 0.35482605861034244, 0.17201841721544042, 0.1319877285277471, 0.19428502942901105, 0.32330918416846544, 0.19590430660173297, 0.17791610152926296, 0.10591193204163574, 0.1331760108587332, 0.10209728556219488, 0.0792983901919797, 0.1333424894255586], [0.07156941937864758, 0.06095330114476383, 0.024135464373102877, 0.08161956095136702, 0.03864335121761542, 0.014006597630213946, 0.05530721973627806, 0.026289037778042257, 0.06200952200742904, 0.11066877952544019, 0.049801508139353245, 0.07224270317237824, 0.04948533096467145, 0.1654825304285623, 0.08601285255281255, 0.05061110219685361, 0.040495213761460036, 0.08355080732144415, 0.05699832196114585, 0.031745778760523535, 0.03348286074469797, 0.02252176072943257, 0.19027045578695834, 0.10538113318034448, 0.4399207409005612, 7.510902117937803, 94.7989547252655, 59.55374076962471, 61.429027542471886, 88.18073585629463, 70.59245243668556, 50.035783499479294, 45.11847876012325, 36.06913514435291, 2.858285238035023, 0.4382730246288702, 0.2687760244589299, 0.4167182953096926, 0.037449410010594875, 0.8680748788174242, 1.3328582793474197, 17.076067104935646, 72.69017547369003, 41.62650793790817, 66.4175708591938, 61.82313859462738, 50.61025187373161, 78.07328581809998, 81.78906083106995, 72.75585114955902, 75.12823104858398, 75.7136732339859, 75.7510632276535, 70.45962676405907, 76.66315108537674, 76.60468742251396, 70.60417100787163, 74.4726674258709, 70.36688894033432, 74.21355932950974, 70.47755420207977, 71.34668156504631, 71.4873880147934, 70.35185694694519, 62.41132043302059, 43.04979756474495, 47.96199157834053, 39.71982724964619, 25.613477490842342, 28.14587440341711, 48.542475029826164, 32.84466236829758, 10.31022995710373, 2.9358784994110465, 2.9885690845549107, 0.30572592455428094, 1.5009151864796877, 0.6219480733852834, 0.34452187246643007, 1.4587031328119338, 1.310133954975754, 0.585223400266841, 0.45127865800168365, 0.4981263738591224, 1.127616805024445, 1.5643194154836237, 5.696176495403051, 13.331867717206478, 8.0232666246593, 1.8709044205024838, 10.981588382273912, 14.418095480650663, 3.2061413722112775, 3.411015453748405, 0.1415269830613397, 0.2818933065282181, 0.03376761538675055, 0.7361568824853748, 1.4642301737330854, 0.007044974117889069, 0.12540239986265078, 0.0781806638406124, 0.04710196822998114, 0.6543363479431719, 0.39337677124422044, 3.2491358276456594, 2.01416552066803, 7.347343694418669, 12.81447323039174, 24.600938223302364, 36.675590202212334, 28.346733525395393, 29.883008189499378, 41.57640002667904, 95.03713354468346, 56.051176115870476, 60.27142345905304, 64.57906231284142, 59.12087179720402, 63.26519921422005, 56.21057756245136, 67.55431786179543, 65.17446756362915, 70.71711614727974, 63.89189198613167, 62.32671037316322, 70.73673829436302, 71.03442952036858, 66.48010030388832, 65.15295311808586, 71.55687108635902, 73.19677948951721, 66.37639626860619, 69.39809292554855, 72.04761475324631, 63.947490602731705, 51.05148799717426, 48.028495609760284, 45.08394241333008, 52.32620559632778, 39.103766307234764, 3.6230851616710424, 0.48828843457158655, 2.488846736960113, 1.0522565175779164, 0.6379855878185481, 0.3854555025463924, 1.2486641784198582, 7.450025109574199, 23.93815878778696, 44.597142934799194, 68.78615096211433, 51.094399094581604, 49.58407513797283, 40.80243855714798, 0.2646133181406185, 0.10809050654643215, 0.14595003478461877, 0.10625169466948137, 0.04303754823922645, 0.07973639090778306, 0.08740883975406177, 0.0702883092162665, 0.019617163561633788, 0.03684274139232002, 0.024636898306198418, 0.05998766311677173, 0.027720707439584658, 0.16333272156771272, 0.02616551471874118, 0.022905387995706405, 0.08416164680966176, 0.09119339956669137, 0.012017087101412471, 0.021300167099980172, 0.10635506841936149, 0.10200431672274135, 0.0880760453583207, 0.018873540866479743, 0.02419470445602201, 0.026446961237525102, 0.02098897530231625, 0.03231077949749306, 0.05204678687732667, 0.07815409495378844, 0.08210482163121924, 0.05578820935625117, 0.13745567965088412, 0.0609859741962282, 0.1449089648667723, 0.0753632486157585, 0.05790140065073501, 0.0719255834701471, 0.07980196707649156, 0.06886506293085404, 0.020337289861345198, 0.06027039169566706, 0.023998272808967158, 0.10004386684158817, 0.2179827546933666, 0.6394887634087354, 14.171635005623102, 106.01050391793251, 68.59325051307678, 72.97053962945938, 93.43362718820572, 67.74613156914711, 40.19659906625748, 35.716035291552544, 45.202404856681824, 3.648947523906827, 0.9511946467682719, 0.621357086347416, 0.6339403486344963, 0.03698660671943799, 1.7746377736330032, 1.5082599548622966, 25.119779482483864, 74.46916401386261, 52.21976190805435, 68.8639783859253, 60.60783080756664, 48.06781589984894, 69.90024358034134, 78.81743028759956, 72.06979796290398, 75.32088071107864, 78.01153153181076, 73.8785769045353, 70.13872638344765, 75.1929871737957, 79.65470775961876, 71.68607175350189, 73.12142193317413, 70.26921138167381, 77.20450043678284, 71.87317371368408, 71.14432722330093, 71.32973447442055, 67.27170422673225, 51.963161677122116, 35.27237869799137, 48.33936832845211, 44.586013332009315, 24.429668113589287, 30.378687791526318, 58.2603357732296, 46.44771583378315, 15.292866490781307, 3.880417328327894, 2.1302552288398147, 0.8240459288936108, 0.72634058422409, 0.04966653374140151, 0.4595940961735323, 1.1254459340125322, 0.4322470526676625, 1.320006181485951, 0.642752016428858, 0.6282470666337758, 0.8291370025835931, 2.241361979395151, 4.198142504319549, 23.03297895938158, 15.384642016142607, 5.262754177674651, 23.980292826890945, 29.19361688196659, 13.66814587265253, 2.2300670854747295, 0.2471680089365691, 0.4295697103952989, 0.28612761525437236, 0.6997561419848353, 0.2336901766830124, 0.11281651779427193, 0.11920813849428669, 0.014271464569901582, 0.0926958181662485, 0.4647379514062777, 0.9209526632912457, 2.8472910029813647, 3.639561077579856, 6.375566739588976, 12.729602884501219, 26.637032367289066, 47.64926835894585, 27.45642989873886, 35.15980213880539, 42.57032409310341, 75.90348824858665, 43.48789885640144, 54.98657204210758, 62.622744888067245, 56.71015575528145, 65.78768625855446, 55.21582514047623, 70.30261918902397, 66.60577476024628, 77.39805445075035, 63.87757435441017, 64.31360855698586, 70.65687417984009, 72.48652920126915, 66.02860853075981, 65.39344981312752, 70.33915042877197, 77.36514821648598, 69.3000353872776, 70.4514268040657, 73.54342728853226, 66.91172674298286, 59.282013550400734, 56.77178084850311, 53.098567351698875, 57.11055546998978, 49.626097083091736, 5.930830053985119, 1.2327013537287712, 4.559931065887213, 1.7251284490339458, 0.8483019273262471, 1.1761018470861018, 1.7132170381955802, 16.276310719549656, 28.72085005044937, 45.50673432648182, 73.70837643742561, 57.18076430261135, 57.68930621445179, 55.15587195754051, 1.369237289763987, 0.04167141021753196, 0.05473213692312129, 0.01975792856683256, 0.09918322044541128, 0.20587292325217277, 0.002984276461575064, 0.022960767055337783, 0.06308634488959797, 0.09660845782491378, 0.09239545615855604, 0.03426749637583271, 0.029307673357834574, 0.10222101642284542, 0.09355420843348838, 0.05871396329894196, 0.14585889904992655, 0.037363502706284635, 0.0569487798929913, 0.055969998429645784, 0.0622695148922503, 0.18014425149885938, 0.10947213319013827, 0.10487291045137681, 0.22058919217670336, 0.17347436252748594, 0.13611678587039933, 0.12867200566688552, 0.16311132407281548, 0.15243242756696418, 0.14392713317647576, 0.21346939844079316, 0.23587128933286294, 0.1377727251383476, 0.39224514446686953, 0.20511728333076462, 0.23496224748669192, 0.17100784956710413, 0.1886954699875787, 0.2008386980742216, 0.2087464151554741, 0.1387577480636537, 0.17999200732447207, 0.25889406097121537, 0.4505707084899768, 0.6467789097223431, 14.170901644974947, 123.02740439772606, 76.05391457676888, 82.29834750294685, 108.40790167450905, 86.69375404715538, 64.60957467556, 61.167476177215576, 47.56419472396374, 6.509039327502251, 1.170465205796063, 1.4867311413399875, 1.9124200427904725, 0.1574343693209812, 2.610277533531189, 4.106235885992646, 29.614638090133667, 83.43199387192726, 52.83471331000328, 80.53603246808052, 75.58062717318535, 62.19142243266106, 86.01131066679955, 85.14502555131912, 75.10072812438011, 77.8600412607193, 80.23581817746162, 74.34791252017021, 69.35080826282501, 78.76455992460251, 81.75731733441353, 71.47382274270058, 72.74015799164772, 72.09693610668182, 77.4289619922638, 67.08284676074982, 68.42178851366043, 70.80728530883789, 75.7375131547451, 67.23682969808578, 52.05055318772793, 54.09791752696037, 51.13512150943279, 29.51556410640478, 34.51852574944496, 58.265913873910904, 52.50291131436825, 23.187750354409218, 9.765565283596516, 2.2305080993101, 0.5098900676239282, 2.9339311039075255, 1.44984545186162, 1.927997781895101, 5.0435928627848625, 2.0118956174701452, 3.0934277828782797, 0.6067378458101302, 0.9074820892419666, 1.2965334160253406, 2.835119068622589, 14.50612535700202, 34.73953329026699, 22.717607282102108, 6.583507731556892, 38.29581566154957, 38.9607609808445, 30.694340653717518, 4.038215260952711, 0.17756834597093984, 1.2342209159396589, 0.21456786605995148, 2.3186811804771423, 2.430039905011654, 0.19102996971923858, 0.30770817131269723, 0.1848842596518807, 0.14712948555825278, 0.8680548111442477, 0.776159354718402, 4.190867319703102, 7.34552264213562, 15.402411762624979, 24.821218103170395, 36.92370928823948, 50.5812594294548, 37.82797336578369, 40.817732736468315, 50.571691542863846, 111.25263422727585, 60.96155762672424, 64.00306642055511, 67.59597882628441, 58.633156567811966, 64.29777100682259, 56.474522799253464, 70.00878855586052, 65.64685821533203, 71.6688434779644, 63.87197345495224, 65.3910331428051, 72.40318447351456, 75.60018852353096, 65.29650181531906, 64.21208560466766, 69.7342000901699, 74.55826923251152, 67.34795093536377, 71.3633094727993, 74.3136003613472, 69.28583934903145, 65.3452380001545, 61.49614714086056, 58.3674406260252, 63.266544342041016, 48.124254271388054, 7.548817433416843, 2.896879529580474, 6.868078261613846, 4.100539041683078, 1.1964992713183165, 1.9585766410455108, 1.8593045929446816, 18.111667335033417, 33.398695439100266, 62.54544943571091, 81.10395759344101, 70.09035497903824, 65.04419535398483, 61.79680980741978, 0.8707578317262232, 0.14872164465487003, 0.22216591460164636, 0.23757604707498103, 0.18327938014408574, 0.37863837147597224, 0.20051627943757921, 0.11991965773631819, 0.1489771660999395, 0.3585687093436718, 0.150939449085854, 0.10237865601084195, 0.11060942255426198, 0.3614501719130203, 0.16228302789386362, 0.12247436752659269, 0.1904189892229624, 0.09386933175846934, 0.13866644905647263, 0.16914157080464065, 0.31344372604507953], [0.06068649163353257, 0.04453035973710939, 0.01950751309777843, 0.09094692490180023, 0.03701660432852805, 0.022604562145716045, 0.040027586510404944, 0.09715211810544133, 0.15970854728948325, 0.025956190111173782, 0.0805801163369324, 0.02365219079365488, 0.039045918092597276, 0.08934206023695879, 0.03877791001286823, 0.10334089500247501, 0.018357696280872915, 0.055206358156283386, 0.0929932709550485, 0.02335751363716554, 0.05217409860051703, 0.06007297670294065, 0.05241986822511535, 0.1107599820534233, 0.025942252577806357, 0.17985484359087422, 39.05621185898781, 78.09245198965073, 60.66785618662834, 87.73846998810768, 79.08099174499512, 51.76917068660259, 41.6854427754879, 35.90429998934269, 4.305260181427002, 0.4013890866190195, 0.142324598855339, 0.052238932621548884, 0.8556452707853168, 3.3958758786320686, 2.268747347407043, 21.462884210050106, 48.43795403838158, 45.620754808187485, 57.76008501648903, 63.59629824757576, 63.1207499653101, 79.47728767991066, 80.88457256555557, 75.88650315999985, 72.6254953444004, 70.3031587600708, 76.72578692436218, 73.82924795150757, 73.87571945786476, 72.97205194830894, 72.36933588981628, 75.14507934451103, 73.2224889099598, 71.26686304807663, 71.10360860824585, 70.41834577918053, 73.26953798532486, 81.59597799181938, 76.66416943073273, 43.01891662180424, 21.398112885653973, 22.932784035801888, 31.686600409448147, 31.6036394611001, 44.98512111604214, 33.78596305847168, 10.813383758068085, 1.9024807261303067, 1.7622296581976116, 0.3246462671086192, 1.601764268707484, 0.15508777258219197, 0.3825654013780877, 0.2830198867013678, 0.7210626674350351, 0.22154305974254385, 0.6529887858778238, 1.0055905091576278, 1.3382234727032483, 4.10495962947607, 7.285273550078273, 11.574387922883034, 10.34936310723424, 2.0962337544187903, 22.49669473618269, 18.80995586514473, 5.09868610650301, 5.845147501677275, 1.1102022207342088, 0.09697085595689714, 0.3515373350819573, 0.03601758449804038, 1.9716947246342897, 1.266872207634151, 0.3531142504652962, 0.14364625996677205, 0.05930579638516065, 0.4291218984872103, 0.46648490766528994, 3.763004341162741, 0.49400537624023855, 3.997887074947357, 16.631063483655453, 26.977879777550697, 34.38843593001366, 26.983942352235317, 19.04524113982916, 22.850296162068844, 59.46469634771347, 45.02439200878143, 50.99428966641426, 62.07351475954056, 68.4601816534996, 63.88300806283951, 59.92989018559456, 67.52435266971588, 54.13154952228069, 56.01474367082119, 67.39066824316978, 66.22473880648613, 63.32040645182133, 69.68594267964363, 68.76400575041771, 69.90764558315277, 73.17590340971947, 62.09492281079292, 68.59981656074524, 68.66419270634651, 71.2911893427372, 68.68569195270538, 59.264580085873604, 46.65885530412197, 66.35868161916733, 54.98303443193436, 53.48840743303299, 16.76221914589405, 0.909934442024678, 1.5760555607266724, 0.5595459218602628, 0.8379123941995203, 0.30497644445858896, 0.5765671678818762, 17.176072038710117, 38.545135483145714, 62.58609585464001, 64.4361823797226, 51.2539829313755, 57.8924623131752, 9.807740170508623, 0.09866770982625894, 0.0528053063317202, 0.04758869836223312, 0.057894309429684654, 0.045695527878706343, 0.07948855069116689, 0.09016808544402011, 0.09384308199514635, 0.04461812612134963, 0.02581920263764914, 0.05084115684439894, 0.03602367010898888, 0.026937448492390104, 0.08264342046459205, 0.05436329323856626, 0.10090770447277464, 0.015544081779808039, 0.02756069297902286, 0.012777514803019585, 0.14361002831719816, 0.13181761343730614, 0.13219354092143476, 0.04508991682087071, 0.03332107997266576, 0.11626707404502667, 0.056976250489242375, 0.05964010793832131, 0.03682824724819511, 0.0833991717081517, 0.13221953093307093, 0.02358281853958033, 0.05486969770572614, 0.058531996110104956, 0.020167569964542054, 0.059879316977458075, 0.016136361082317308, 0.12088565199519508, 0.02727519990003202, 0.02003334513574373, 0.014992492579040118, 0.025703865467221476, 0.06820068490924314, 0.08343032706761733, 0.05964711010165047, 0.030625282342953142, 0.10237481910735369, 0.27764739061240107, 58.561545610427856, 87.11097925901413, 68.81292432546616, 96.3773064315319, 79.60909500718117, 47.32804499566555, 32.91913457214832, 39.93187487125397, 8.102283384650946, 0.5004508991260082, 0.27105682238470763, 0.2501011249842122, 1.522125885821879, 7.501999670639634, 4.997666152194142, 30.070417933166027, 65.73992282152176, 51.17684327065945, 61.243536695837975, 69.71707820892334, 61.465995758771896, 75.79100668430328, 81.62166461348534, 76.24398797750473, 74.69940885901451, 74.00814235210419, 78.06219801306725, 72.75085061788559, 74.89351764321327, 74.1553084552288, 73.17981719970703, 75.58460175991058, 74.66517269611359, 72.56171196699142, 72.6579076051712, 68.15329492092133, 72.7409939467907, 75.45372918248177, 64.92827877402306, 40.852272883057594, 27.41669923067093, 25.900365896523, 26.37049186974764, 29.284338913857937, 54.969054982066154, 45.31387947499752, 14.346462674438953, 0.9903640137054026, 1.3494107848964632, 1.186778680421412, 0.7074579130858183, 0.2246624548570253, 0.2900450269225985, 0.6165408447850496, 1.8706790450960398, 2.0319134183228016, 1.311860487330705, 1.05519934091717, 3.0359297432005405, 4.751688251271844, 2.9660875909030437, 23.197352439165115, 22.003319710493088, 12.85647427663207, 32.668895199894905, 34.4298081099987, 20.90469416230917, 2.603413201868534, 2.5334917288273573, 0.2862695435760543, 0.7167767349164933, 1.02977977367118, 4.736262504011393, 3.4705354599282146, 0.7058666890952736, 0.09597002528607845, 0.13339448429178447, 0.5104242358356714, 0.5592830828391016, 2.1907403832301497, 4.890761263668537, 2.8023408399894834, 15.373542811721563, 30.112836956977844, 42.486257404088974, 27.087912373244762, 21.518640518188477, 25.12005116790533, 72.4086181819439, 47.988844737410545, 48.26737739145756, 62.89920285344124, 66.06403782963753, 66.98709189891815, 61.27585016191006, 72.1854941546917, 55.329522639513016, 59.30421955883503, 69.07435789704323, 66.71210825443268, 64.20633271336555, 70.60572132468224, 69.72755804657936, 70.82200571894646, 74.6980257332325, 66.87689781188965, 69.00467723608017, 71.08245134353638, 73.6245909333229, 69.59445118904114, 62.07648999989033, 55.20793296396732, 68.21571037173271, 64.88271921873093, 58.427857384085655, 19.087118692696095, 1.0253036138601601, 3.32863159943372, 1.2242185464128852, 1.3607144658453763, 0.9309621574357152, 1.541817735414952, 27.07346174865961, 37.83126778900623, 62.18766823410988, 72.15884238481522, 57.21889145672321, 71.72770231962204, 19.793707877397537, 0.06721654513967223, 0.05401887363404967, 0.06507061028969474, 0.12567628204124048, 0.0524068657978205, 0.026486992683203425, 0.04299223641282879, 0.05993615435727406, 0.0405814698751783, 0.01191340164950816, 0.04788685248058755, 0.048195040435530245, 0.0669425813248381, 0.004224026270094328, 0.028486229057307355, 0.06413040566258132, 0.033361356327077374, 0.014950205004424788, 0.00980170856564655, 0.08019161687116139, 0.13395444955676794, 0.23187632323242724, 0.13569586939411238, 0.21523541305214167, 0.2598469192162156, 0.12676998507231474, 0.1899759122170508, 0.11908930580830202, 0.29033695813268423, 0.31205593957565725, 0.1763741413014941, 0.19196620385628194, 0.12408585214870982, 0.11441934897447936, 0.13793697726214305, 0.1171898382017389, 0.23964285413967445, 0.08286320749903098, 0.11871461771079339, 0.2449254909879528, 0.11336268653394654, 0.14131981995888054, 0.13860741863027215, 0.3827316127717495, 0.2708389871986583, 0.24407605844317004, 0.37479484803043306, 68.1434914469719, 106.04208782315254, 78.66613760590553, 114.1747610270977, 94.56406652927399, 70.18646702170372, 55.17777398228645, 47.62327395379543, 11.773957014083862, 1.1543644010089338, 1.08079737983644, 0.6171849102247506, 3.0926528619602323, 12.697587702423334, 8.934815861284733, 32.332791835069656, 63.92916038632393, 61.409116610884666, 71.34335294365883, 80.5077163875103, 74.06137749552727, 84.44804415106773, 84.47454392910004, 79.3342025578022, 76.29768669605255, 72.10864707827568, 79.0322707593441, 73.72118934988976, 73.78006339073181, 74.34006214141846, 72.97728046774864, 73.95910978317261, 74.64600652456284, 72.92032152414322, 70.21683499217033, 70.46693757176399, 74.11458224058151, 79.58912327885628, 81.07191771268845, 49.89114046096802, 28.241405077278614, 28.867351189255714, 39.09017063677311, 38.33298146724701, 59.44724768400192, 55.34941837191582, 26.130141466856003, 7.689716247841716, 1.2293555145151913, 0.8823821204714477, 2.2065309109166265, 0.6293847493361682, 1.141079601366073, 2.3255198635160923, 2.8486320935189724, 3.303241836838424, 1.7677562241442502, 0.9651293302886188, 4.345023622736335, 6.071166023612022, 8.874932024627924, 37.11690232157707, 29.513622410595417, 10.815315954387188, 33.74827668070793, 49.22454223036766, 34.473577961325645, 8.186496365815401, 1.6710207774303854, 0.4972478491254151, 1.86233873013407, 3.605115213431418, 4.3458225298672915, 5.018647676333785, 0.911330688977614, 0.1439613164984621, 0.5286484735552222, 1.1329025588929653, 0.4307527531636879, 3.1650966871529818, 12.011740654706955, 12.231486663222313, 30.433380156755447, 41.35406255722046, 50.091256722807884, 38.722513765096664, 25.329195745289326, 33.249272257089615, 70.33829927444458, 49.94692146778107, 55.38074009120464, 64.10249188542366, 68.90122398734093, 68.27324688434601, 61.5747307240963, 71.87938258051872, 54.942342415452, 58.3467773348093, 69.03904259204865, 67.50305861234665, 63.11700716614723, 70.92920556664467, 69.73511204123497, 69.27378639578819, 77.86675170063972, 64.53458189964294, 71.54970467090607, 70.69612607359886, 75.17251387238503, 70.30543103814125, 67.13220611214638, 57.34837330877781, 78.63624081015587, 70.37334099411964, 64.45535615086555, 25.264553613960743, 1.876778311561793, 5.98922579549253, 3.231195565313101, 3.300195587798953, 2.7818231284618378, 2.769046314060688, 36.21142990887165, 51.61998689174652, 77.82948330044746, 80.5401362478733, 67.59641200304031, 83.00610512495041, 20.179750062525272, 0.2609918749658391, 0.22527952096424997, 0.17596300633158535, 0.2536791970487684, 0.24761320848483592, 0.10103846347192302, 0.24407776538282633, 0.3063523565651849, 0.09159565102891065, 0.09790063340915367, 0.1243938434345182, 0.30588907829951495, 0.14750579895917326, 0.2129079043515958, 0.20432012766832486, 0.19093582086497918, 0.12908219068776816, 0.2779598644701764, 0.14784338709432632, 0.09532149211736396, 0.2847771142842248], [0.07750807766569778, 0.028798357816413045, 0.03624904922617134, 0.08399782513151877, 0.04906705282337498, 0.05792015101178549, 0.09389544793521054, 0.03899482493579853, 0.041365085053257644, 0.018198182769992854, 0.05021487326303031, 0.02684676361241145, 0.03281371442426462, 0.052496472708298825, 0.049955065915128216, 0.05442450557893608, 0.02792310780932894, 0.01846850078436546, 0.06290287856245413, 0.07975190179422498, 0.09834966986090876, 0.030200246947060805, 0.062276246171677485, 0.20748078619362786, 0.11499418687890284, 0.8306147670373321, 6.770433951169252, 83.75382900238037, 64.64145496487617, 84.98518332839012, 89.32744592428207, 68.18429365754128, 40.15881389379501, 26.577117182314396, 2.94383289758116, 0.4371404182165861, 0.9713767888024449, 1.408001622185111, 0.9331297036260366, 2.158904504030943, 4.725767942145467, 45.52655406296253, 44.48903873562813, 58.18459443747997, 67.16869175434113, 57.85249225795269, 67.44300663471222, 83.16675290465355, 78.91709893941879, 78.66350054740906, 74.88880589604378, 73.85152995586395, 71.04753881692886, 71.968465000391, 73.06864276528358, 73.86704832315445, 74.05789688229561, 79.01011794805527, 73.93674418330193, 72.2193655371666, 72.71573290228844, 73.41150596737862, 71.96839660406113, 75.2710197865963, 83.48294153809547, 74.0876416862011, 47.31414534151554, 28.969351015985012, 36.551393866539, 34.40257877111435, 43.12229387462139, 27.67799600958824, 13.604808021336794, 1.2757013901136816, 2.7852837927639484, 0.8128784468863159, 0.23575388157041743, 0.12053439349983819, 0.3340903337812051, 0.2281831143773161, 0.2284056696225889, 0.09995869055273943, 1.8407087470404804, 2.672842126339674, 2.80565544962883, 3.0094746127724648, 7.319649355486035, 12.717388439923525, 20.893670953810215, 5.680661452934146, 16.18603326380253, 28.65181155502796, 11.925820615142584, 6.262915134429932, 1.54862305149436, 0.5189817328937352, 1.5276847500354052, 0.3144273685757071, 4.789456324651837, 1.8346829828806221, 0.8621394191868603, 0.19032435055123642, 0.18507959292037413, 0.5469907424412668, 1.7696712026372552, 2.9368464974686503, 1.4606824703514576, 9.239766597747803, 12.744518034160137, 18.94274163991213, 26.761302798986435, 33.01808886229992, 36.461623683571815, 28.804107382893562, 15.815650038421154, 43.71900625526905, 69.67849507927895, 64.47742536664009, 66.76807925105095, 62.32253439724445, 62.57355272769928, 64.62656736373901, 69.74102452397346, 69.0283651649952, 71.41378596425056, 69.76671874523163, 71.7464429140091, 65.49834698438644, 68.17189872264862, 69.85113501548767, 67.55247876048088, 68.88594880700111, 75.688716173172, 66.12856596708298, 71.42980590462685, 69.31717246770859, 64.93169859051704, 48.70124951004982, 57.51938313245773, 53.62883649766445, 68.80574271082878, 42.982332184910774, 0.8001469331793487, 0.8160339994356036, 1.0711293923668563, 0.668106215307489, 0.06698885423247702, 0.19725540129002184, 32.122047543525696, 50.620594918727875, 61.28803990781307, 58.60753834247589, 66.00603774189949, 35.85006929934025, 0.0737455819034949, 0.24784855835605413, 0.07655748297111131, 0.06548466932144947, 0.013587231314886594, 0.08306735748192295, 0.07511586853070185, 0.12772867659805343, 0.07706310076173395, 0.05485899222549051, 0.06207673832250293, 0.005143679436514503, 0.04981533806130756, 0.027227659775235225, 0.12043564332998358, 0.11985749544692226, 0.025779596071515698, 0.07449745913618244, 0.023766355370753445, 0.06809847633121535, 0.1752668124390766, 0.004556126687020878, 0.18157477083150297, 0.07781330816214904, 0.11364042788045481, 0.01618701822735602, 0.12633719423320144, 0.04341467429185286, 0.05164423113455996, 0.015950842716847546, 0.05983563416521065, 0.0703912450990174, 0.0748076471791137, 0.18469110829755664, 0.024718844397284556, 0.009845154818322044, 0.09590257148374803, 0.031025121825223323, 0.04687320120865479, 0.03981214846135117, 0.019914210024580825, 0.05325564525264781, 0.08974774784292094, 0.12386852904455736, 0.04288265459763352, 0.1500881463289261, 0.2663802827009931, 1.5254914364777505, 15.911134164780378, 101.3064019382, 72.66831144690514, 95.45833334326744, 90.31735360622406, 62.990036979317665, 37.99469701945782, 34.49524059891701, 5.802964065223932, 0.5545783415436745, 1.5019692736677825, 3.3864438347518444, 2.304725479334593, 2.1960052382200956, 9.092190116643906, 52.94374845921993, 51.813917085528374, 65.49862056970596, 73.52366834878922, 64.95845675468445, 69.83275160193443, 80.12871712446213, 80.14167442917824, 80.20358830690384, 75.79023152589798, 73.63903015851974, 74.07993569970131, 73.70954677462578, 74.26839798688889, 74.28077012300491, 76.67437568306923, 78.32299321889877, 76.339400857687, 73.63538235425949, 74.20919716358185, 72.27552652359009, 73.66255089640617, 74.58280071616173, 75.25117725133896, 62.72460602223873, 40.59271261096001, 27.15415231883526, 30.997701175510883, 35.8222433924675, 51.57663121819496, 36.24855391681194, 17.328502759337425, 5.1000934559851885, 1.1040546256117523, 1.138882131781429, 0.34556168073322624, 0.14781699632294476, 0.606927004409954, 0.3248329024063423, 1.4884391496889293, 0.3705276473192498, 1.0537315509282053, 2.5476203206926584, 3.243738692253828, 4.706331510096788, 5.863923719152808, 23.821438550949097, 28.122809641063213, 11.540984865278006, 22.40795809775591, 38.40359687805176, 28.675037808716297, 1.080701791215688, 3.739325199276209, 1.1624801717698574, 1.5741668245755136, 0.5386869411449879, 6.222020303830504, 3.994245920330286, 1.5116832149215043, 0.1945549188531004, 0.26596215669997036, 0.7392440980765969, 1.3966702739708126, 1.8834680900909007, 1.6966360341757536, 6.127190217375755, 14.226113632321358, 22.486123703420162, 33.4934813529253, 30.93087036162615, 33.714621886610985, 24.91866197437048, 25.393133014440536, 45.22668935358524, 62.46610589325428, 65.96822217106819, 68.6099848151207, 64.45009723305702, 63.72454896569252, 67.48145297169685, 69.84174951910973, 68.53566080331802, 69.59552273154259, 72.13179543614388, 69.18086618185043, 66.57087743282318, 68.55678766965866, 69.86468508839607, 72.27763921022415, 71.41173407435417, 75.57859808206558, 69.633269906044, 73.33015233278275, 71.41400635242462, 68.13367277383804, 57.617235481739044, 65.13039752840996, 62.12715268135071, 70.04775926470757, 50.44339902698994, 1.75581572111696, 0.8382493886165321, 3.4005021303892136, 2.514864415861666, 1.326213029678911, 1.2217743275687099, 42.294998466968536, 49.84170891344547, 70.01970157027245, 66.04625478386879, 69.51313555240631, 54.072287902235985, 0.6851902767084539, 0.08853668899973854, 0.05699274472135585, 0.04129828805162106, 0.07006458879914135, 0.0382733089645626, 0.14734093827428296, 0.06674428688711487, 0.02048406626272481, 0.10875300693442114, 0.041730770899448544, 0.03806416432780679, 0.042113132803933695, 0.017059546407836024, 0.11003641033312306, 0.0520828107255511, 0.021589051793853287, 0.09548976668156683, 0.01878208786365576, 0.09245053835911676, 0.1217795762931928, 0.07632059685420245, 0.24977840948849916, 0.15386257582576945, 0.1605906937038526, 0.15771625185152516, 0.17343155544949695, 0.17129826679592952, 0.14766457403311506, 0.14491647540125996, 0.14160459686536342, 0.23093431518645957, 0.24945714860223234, 0.17491804755991325, 0.15997457754565403, 0.25035820493940264, 0.18402747984509915, 0.08492669716360979, 0.16604148637270555, 0.21597710059722885, 0.2822680020472035, 0.22980443987762555, 0.1450321910670027, 0.21655563439708203, 0.21754561486886814, 0.2901160652982071, 0.3434754739282653, 1.8950372817926109, 16.128639243543148, 126.7467588186264, 82.56003946065903, 117.89131879806519, 107.00588330626488, 88.26322942972183, 55.58931089937687, 36.557975113391876, 9.062223974615335, 1.098862204235047, 2.721508014947176, 6.481755841523409, 4.421549616381526, 5.382838658988476, 18.075753562152386, 60.517399460077286, 55.84778442978859, 73.51134940981865, 83.72742041945457, 73.08325678110123, 76.6370464861393, 87.75276482105255, 81.78671255707741, 81.2208241224289, 76.46087273955345, 76.29233658313751, 73.59407097101212, 74.20994192361832, 75.30378922820091, 75.8765172958374, 76.88871458172798, 79.75325927138329, 75.26454493403435, 72.41518422961235, 73.63429561257362, 72.79963240027428, 71.80856198072433, 76.53143495321274, 83.98861840367317, 82.06552639603615, 54.18640337884426, 38.75416226685047, 45.23495391011238, 43.66674765944481, 58.78567658364773, 47.128753289580345, 29.515303820371628, 12.16455040499568, 2.6558366138488054, 1.0150403645820916, 0.22561017744010314, 0.2563078247476369, 0.7242313411552459, 0.8180256863124669, 3.5102661279961467, 0.20651658793212846, 13.245595246553421, 3.0387613037601113, 4.355838317424059, 7.440352728590369, 14.6545016951859, 36.15066356956959, 35.32047651708126, 12.136210575699806, 21.279943026602268, 48.9608021825552, 38.52106757462025, 18.65382794290781, 2.6016899943351746, 1.6827774653211236, 5.9698601346462965, 0.8620372402947396, 10.579862538725138, 7.993195988237858, 3.774685626849532, 0.29405336652416736, 0.3761764895170927, 1.493545244447887, 3.4871647926047444, 7.1370520535856485, 12.808156069368124, 18.529739901423454, 22.4642463773489, 27.802509628236294, 44.92235608398914, 41.351425498723984, 50.43792352080345, 34.71754387021065, 22.91278760880232, 51.33865758776665, 72.17312961816788, 63.607587441802025, 69.42785292863846, 66.37722462415695, 62.35066428780556, 68.8638111948967, 72.38319754600525, 72.85869643092155, 73.37297603487968, 73.84880930185318, 72.52505913376808, 68.17770481109619, 68.56243416666985, 72.90398240089417, 71.72271698713303, 73.33866387605667, 78.93307328224182, 70.40367096662521, 73.2112567126751, 73.23173001408577, 71.91152885556221, 64.99618873000145, 72.04715117812157, 67.09056034684181, 81.86577871441841, 55.61697721481323, 2.6832585548982024, 2.915043029934168, 6.178905917331576, 4.817942446097732, 1.8176043243147433, 3.1740805925801396, 58.0710831284523, 61.744612008333206, 83.85733544826508, 76.02107673883438, 83.13140720129013, 58.20771999657154, 0.7834630971774459, 0.24450389173580334, 0.15641538571799174, 0.14493914059130475, 0.10898238251684234, 0.16180027567315847, 0.2807952545117587, 0.1697667411644943, 0.08519687602529302, 0.21343993517803028, 0.24487741466145962, 0.10661984444595873, 0.24332386208698153, 0.1449285724083893, 0.34383974969387054, 0.2807035844307393, 0.2281628834316507, 0.21030053176218644, 0.10251963438349776, 0.2674131147796288, 0.3404626215342432, 0.18086354102706537], [0.12581202085129917, 0.08641719687147997, 0.02577547715191031, 0.09456407104153186, 0.03468089489615522, 0.06470647553214803, 0.03578112882678397, 0.0038038874254198163, 0.010817591846716823, 0.06791601190343499, 0.07735241219052114, 0.07463961010216735, 0.037891010142629966, 0.029712628092966042, 0.020521986298263073, 0.11163842515088618, 0.04419264914758969, 0.05216483288677409, 0.05282488418743014, 0.03314585890620947, 0.03041907290025847, 0.02100903555401601, 0.02049992781394394, 0.11295836447970942, 0.04697338001278695, 0.7585819729138166, 1.6755865886807442, 63.15666563808918, 64.38239246606827, 70.93783110380173, 98.22012394666672, 79.5376892387867, 39.6338264644146, 10.951694436371326, 2.2597380308434367, 1.1481862887740135, 0.7531755161471665, 0.9109379444271326, 2.403174634091556, 1.9188927579671144, 4.181305607780814, 68.75237837433815, 59.325395822525024, 61.466364338994026, 55.1722414791584, 62.91026026010513, 73.83332893252373, 83.39899644255638, 78.97857204079628, 80.10981693863869, 76.025720089674, 77.09554508328438, 75.1424802839756, 76.98259994387627, 75.44425249099731, 76.0412460565567, 79.0125422179699, 78.92785996198654, 75.96052318811417, 72.9193563759327, 68.86121213436127, 72.10049271583557, 68.26695442199707, 71.74581974744797, 73.77085268497467, 80.56775316596031, 58.72609198093414, 34.51453596353531, 33.1896648555994, 34.24184739589691, 32.85087503492832, 29.64754432439804, 13.294553719460964, 1.6605994803830981, 1.9965613028034568, 0.8280353585723788, 0.5306951387319714, 0.07680872964556329, 0.11846154535305686, 0.3372084820875898, 0.3558312827954069, 0.5700454115867615, 0.1696853424073197, 3.4413613379001617, 6.041296301409602, 4.432843085378408, 4.267552904784679, 18.17144762724638, 26.54654022306204, 8.832126371562481, 6.103216828778386, 34.54253286123276, 26.464679315686226, 5.9652153588831425, 5.603201184421778, 1.453436496667564, 0.1721793890465051, 1.0113601433113217, 1.2540355464443564, 1.9246323499828577, 2.286561978980899, 0.33514468814246356, 0.05406882017268799, 0.19355082273250446, 3.342806026339531, 2.7350108278915286, 0.6277180637698621, 4.761840356513858, 14.329396840184927, 23.110354207456112, 22.8715256229043, 28.30544114112854, 33.530282378196716, 32.59946532547474, 32.3293150216341, 56.13014727830887, 66.56741961836815, 66.83704555034637, 63.55057530105114, 63.438424319028854, 62.86492869257927, 62.57333233952522, 66.25916495919228, 71.26241728663445, 69.62788179516792, 67.05649137496948, 69.59166213870049, 66.80831909179688, 70.65967082977295, 69.78554293513298, 64.78753432631493, 73.17650377750397, 74.37419950962067, 68.14962431788445, 68.72244358062744, 67.91958466172218, 68.29497411847115, 53.473903611302376, 46.36325016617775, 59.83006574213505, 55.94651073217392, 49.07055549323559, 3.59956466127187, 0.14867598772980273, 0.7319636293686926, 0.7924258662387729, 1.723954549524933, 4.324629167094827, 48.26569028198719, 47.58357748389244, 65.32124608755112, 62.030721455812454, 73.2393828034401, 18.802629858255386, 0.09801206688280217, 0.11548922906513326, 0.09731582846143283, 0.07309803579119034, 0.03580185701139271, 0.020844339996983763, 0.04606169241014868, 0.06318387793726288, 0.017863169887277763, 0.06001790563459508, 0.050698256309260614, 0.016297755937557667, 0.0344889495318057, 0.02018565053731436, 0.025204578196280636, 0.004859987457166426, 0.05174298872589134, 0.0460038345772773, 0.03839405639155302, 0.06097404046158772, 0.036683402286143973, 0.06398345300112851, 0.059969962894683704, 0.07978282708791085, 0.060494382996694185, 0.07597540170536377, 0.08255987690063193, 0.08927012386266142, 0.007557257786174887, 0.07045570804621093, 0.029096415455569513, 0.04081887178472243, 0.04911416435788851, 0.0772062610485591, 0.09830074006458744, 0.02528375422116369, 0.04122029204154387, 0.04999673008569516, 0.030366484315891284, 0.06111777591286227, 0.05316586022672709, 0.03555937139026355, 0.04465158584935125, 0.06325723181362264, 0.007660669571123435, 0.11727092525688931, 0.11864206535392441, 0.5599816516041756, 1.6178162698633969, 85.06203040480614, 81.90882280468941, 82.82259777188301, 107.37954005599022, 83.08714717626572, 44.32304844260216, 22.213435135781765, 6.058294214308262, 0.7989928044844419, 1.3247490394860506, 1.4191720727831125, 5.180298602208495, 4.472179049625993, 8.915565144270658, 76.8938747048378, 65.73199644684792, 70.00492036342621, 65.24132117629051, 70.10338827967644, 73.20411309599876, 83.03992331027985, 79.46949809789658, 83.15364360809326, 76.03617712855339, 78.46126779913902, 74.64170515537262, 78.8590456545353, 74.83616352081299, 75.4478394985199, 77.44428277015686, 78.484226167202, 77.9397077858448, 74.25062254071236, 71.37923821806908, 71.92912951111794, 67.87379711866379, 74.74084183573723, 73.43360558152199, 78.00995841622353, 46.85653209686279, 28.822540193796158, 31.878613606095314, 32.93689861893654, 38.44249539077282, 36.57189376652241, 17.38913230597973, 2.83606403041631, 1.6184300556778908, 2.015487849712372, 0.2239591215038672, 0.13777144864434376, 0.6591350748203695, 0.7809524412732571, 0.45052407192997634, 0.9479805536102504, 0.20813675568206236, 4.646577816456556, 8.58907526358962, 7.462999038398266, 5.223200675100088, 30.533510483801365, 30.79716693609953, 9.348596557974815, 12.09947794675827, 37.9538644105196, 40.41165992617607, 7.2028502728790045, 6.402263157069683, 5.709055429324508, 0.46061739907599986, 1.3665086799301207, 2.8624398401007056, 3.7390347523614764, 3.516390211880207, 0.23547418095404282, 0.1483526933589019, 0.5197041691280901, 8.228088933974504, 1.2144256406463683, 1.5677910041995347, 6.216931901872158, 18.354255817830563, 28.185926154255867, 29.225759357213974, 30.229958072304726, 33.46543125808239, 27.20114439725876, 33.652290031313896, 54.59387071430683, 67.26404383778572, 67.61598855257034, 66.46072894334793, 64.08496722579002, 63.99049669504166, 64.59591060876846, 67.57832497358322, 72.24185273051262, 68.77133935689926, 68.94608438014984, 70.92495739459991, 65.36531612277031, 72.03386709094048, 69.86369714140892, 70.52132025361061, 73.7272310256958, 74.23030883073807, 68.32938507199287, 72.77523010969162, 71.5348094701767, 74.14783045649529, 63.41634750366211, 57.27192901074886, 65.89142829179764, 61.5365731716156, 59.981020241975784, 4.393926998600364, 0.16320749156875536, 1.175128030590713, 2.761676609516144, 3.4176178369671106, 4.901705151423812, 49.29188221693039, 52.45520867407322, 69.13086846470833, 69.68998566269875, 83.09117496013641, 25.38744281977415, 0.090520583325997, 0.057978038530563936, 0.09116063374676742, 0.018909084174083546, 0.036991460365243256, 0.04898980267171282, 0.08608305230154656, 0.025537075198371895, 0.07297511387150735, 0.05353744614694733, 0.06575639185030013, 0.0014440462496168038, 0.05353163884137757, 0.025721098136273213, 0.034017392608802766, 0.026922028519038577, 0.05852375084941741, 0.04997695556085091, 0.012518449602794135, 0.035923777031712234, 0.06365698223817162, 0.02800351765472442, 0.19216095824958757, 0.28152344981208444, 0.10612443118588999, 0.15569979208521545, 0.15283324668416753, 0.15943833132041618, 0.08092197182122618, 0.14843248907709494, 0.2865047153318301, 0.1316240761661902, 0.24434376595309004, 0.15960439428454265, 0.17555071361130103, 0.22255610616412014, 0.20947072160197422, 0.12429167196387425, 0.19758599839406088, 0.13713989581447095, 0.16670686629367992, 0.16003154480131343, 0.11163021699758247, 0.12759948353050277, 0.1166902095428668, 0.23592122102854773, 0.20713267440441996, 0.7213557267095894, 1.808450378011912, 98.0847980082035, 98.99978891015053, 101.68184459209442, 123.45632538199425, 102.28692412376404, 59.36341658234596, 21.946911737322807, 8.345800917595625, 3.3847930608317256, 4.032567339017987, 3.395966123789549, 7.739689741283655, 7.055701743811369, 14.354206658899784, 86.68911829590797, 70.16360744833946, 81.5914486348629, 71.01226910948753, 80.14434188604355, 84.17717188596725, 88.97303134202957, 82.59968653321266, 85.71203872561455, 77.12220445275307, 78.93229052424431, 77.45885118842125, 79.57202419638634, 75.86430475115776, 77.630655169487, 77.91335240006447, 80.17356231808662, 77.76787340641022, 75.65577194094658, 69.4030174612999, 74.57140892744064, 65.8294840157032, 74.4779871404171, 75.96634447574615, 89.89536345005035, 61.64563111960888, 41.14522956311703, 39.95997056365013, 43.286897242069244, 46.59451715648174, 49.36508148908615, 24.29118074476719, 7.207294134423137, 2.9684793250635266, 1.9345175195485353, 1.1812730133533478, 0.5439814226701856, 0.966809552628547, 1.8923542695119977, 1.2434089416638017, 3.813091591000557, 0.5054595647379756, 10.561861004680395, 9.595263171941042, 10.47168044373393, 15.320643000304699, 42.695363983511925, 36.83944121003151, 10.390013325959444, 10.715004187077284, 46.10519461333752, 46.06448359787464, 25.535085797309875, 9.142913594841957, 6.300513166934252, 0.33132467593532056, 2.7500924561172724, 4.667644361034036, 7.387320399284363, 6.801576130092144, 0.7810056977905333, 0.17026531597366557, 0.9913194843102247, 11.680454481393099, 13.008159287273884, 10.571056511253119, 12.442681230604649, 29.429369531571865, 36.969626024365425, 36.18320122361183, 37.91914947330952, 47.420136854052544, 39.16530400514603, 40.591724663972855, 64.14815783500671, 72.48294219374657, 65.71484416723251, 67.21141666173935, 66.03547096252441, 63.9823043346405, 65.79701095819473, 67.93165281414986, 73.48358809947968, 69.324392080307, 68.64749640226364, 69.9276553094387, 65.20310282707214, 70.107811242342, 71.2518310546875, 68.25177043676376, 77.402553409338, 79.5161671936512, 70.03258287906647, 72.10337296128273, 72.34998732805252, 75.37423744797707, 68.26780557632446, 61.9754496216774, 76.9203668832779, 72.30736881494522, 63.91523793339729, 5.003470815718174, 0.3041993861552328, 1.6496010893024504, 6.656347922980785, 7.733303708955646, 10.887161549180746, 67.00086236000061, 59.66714948415756, 84.05102625489235, 78.90354126691818, 91.55456721782684, 27.204294428229332, 0.23097596451407298, 0.27231568295974284, 0.2227409157785587, 0.31273458909709007, 0.13370161468628794, 0.11912306610611267, 0.19500314636388794, 0.1635540003189817, 0.13063054822850972, 0.09866693799267523, 0.17112740955781192, 0.11953900277148932, 0.12958588631590828, 0.18619909300468862, 0.14946719136787578, 0.10807906262925826, 0.15387326275231317, 0.15472275466891006, 0.18019854702288285, 0.09712810220662504, 0.11194650549441576, 0.11764218463213183], [0.11666994148981757, 0.0781445657776203, 0.06668375732260756, 0.05631510081002489, 0.0636380203650333, 0.014374265938386088, 0.032073021357064135, 0.07699463021708652, 0.06933011492947116, 0.04434971357113682, 0.08007058742805384, 0.056757509883027524, 0.0071113675767264795, 0.016514813723915722, 0.012409538503561635, 0.0304656537991832, 0.08845358330290765, 0.008390781003981829, 0.15024853928480297, 0.06990353533183224, 0.04812957929971162, 0.06272530488786288, 0.05143051115737762, 0.014584823438781314, 0.12125800974899903, 0.19319524493766949, 1.8904130486771464, 39.87062595784664, 65.2086353302002, 71.7964406311512, 97.34453693032265, 87.98650547862053, 54.09919425845146, 25.425024703145027, 1.4213780919089913, 0.9580034657847136, 0.3478400147287175, 1.3885560468770564, 1.6203069174662232, 3.208132227882743, 13.724310658872128, 72.28054225444794, 60.459319576621056, 62.75118939578533, 61.82139828801155, 65.44425308704376, 76.48421868681908, 84.19786557555199, 82.82024949789047, 81.0017278790474, 78.36850717663765, 77.79609069228172, 73.54897499084473, 77.94866010546684, 75.49013882875443, 77.40353375673294, 75.8731734752655, 78.62112522125244, 75.90330585837364, 80.23267194628716, 71.61316126585007, 74.91063952445984, 73.60945254564285, 66.8066243827343, 74.56808030605316, 74.99162077903748, 69.94619831442833, 40.67669950425625, 27.775016203522682, 38.50458785891533, 31.153830997645855, 24.935584366321564, 18.73526517301798, 15.175530686974525, 6.779889268800616, 1.7690170439891517, 0.3706487361341715, 0.014081628760322928, 0.13784229406155646, 0.24758107349043712, 1.0071468818932772, 0.476586606237106, 1.3029994815587997, 0.7604599627666175, 6.644861614331603, 10.198845583945513, 6.999156028032303, 27.29464028030634, 10.15714282169938, 6.64157004095614, 9.669631831347942, 25.641728974878788, 34.82618764042854, 6.898681819438934, 3.323252988047898, 4.737016763538122, 1.3068157830275595, 0.4685188375879079, 2.206133119761944, 5.1000844314694405, 3.007512968033552, 0.44695965538267046, 0.032239796782960184, 0.14423313550651073, 7.425871705636382, 5.153001341968775, 2.114934688434005, 4.280043784528971, 16.43694519996643, 24.20091088861227, 27.122216932475567, 26.96250770241022, 37.04597532749176, 28.92700608819723, 37.687008529901505, 61.34113825857639, 68.4829880297184, 65.44657856225967, 65.30109956860542, 67.4123802781105, 66.81495353579521, 66.07477605342865, 70.55040389299393, 71.010612398386, 70.89697569608688, 71.49191737174988, 68.23998346924782, 69.3695792555809, 69.35400009155273, 67.74879142642021, 67.98728182911873, 71.4694681763649, 71.86800599098206, 74.02885884046555, 73.84915128350258, 70.47846615314484, 71.79149329662323, 58.04176390171051, 41.83778420090675, 55.337547808885574, 47.69352078437805, 39.16212357580662, 4.546292647719383, 0.1623725754325278, 0.11573684663744643, 0.3859222837490961, 0.7527302869129926, 11.60747179761529, 52.708328291773796, 44.62708532810211, 74.07772421836853, 62.231578677892685, 58.66258978843689, 4.515337133780122, 0.09560739708831534, 0.08199605988920666, 0.07948767495690845, 0.10453768234583549, 0.13108929939335212, 0.02877140857890481, 0.04434062968357466, 0.08485686106723733, 0.06043036533810664, 0.027558058354770765, 0.06599742657272145, 0.017717373120831326, 0.06724114733515307, 0.06616944156121463, 0.014387651499419007, 0.09439474262762815, 0.035836734241456725, 0.04440463992068544, 0.06855496394564398, 0.06973957264563069, 0.022705904266331345, 0.04545463416434359, 0.09155027611996047, 0.05390642341808416, 0.01592377473571105, 0.03175348225340713, 0.023080033897713292, 0.025965509630623274, 0.09890128596452996, 0.06154261092888191, 0.026404297022963874, 0.06773318382329307, 0.04760633179103024, 0.04841332462092396, 0.04148372478084639, 0.04181333853921387, 0.06787342004827224, 0.017272568766202312, 0.06689272384392098, 0.042441340192453936, 0.06264066294534132, 0.038804363866802305, 0.021195893496042117, 0.11348555650329217, 0.027541061317606363, 0.05312780289386865, 0.04822087459615432, 0.30053587805014104, 1.6390362312085927, 57.43667297065258, 86.4325712621212, 83.01326394081116, 104.49823066592216, 91.11926257610321, 58.4915229678154, 36.737811863422394, 5.079962611198425, 0.29918220068793744, 0.4071948188357055, 5.591503037139773, 3.5353661561384797, 5.425924547016621, 21.64690263569355, 88.65716949105263, 72.32926324009895, 71.98480412364006, 65.87997570633888, 71.91095128655434, 77.2870472073555, 84.66080993413925, 82.9742780327797, 82.68610909581184, 78.35833892226219, 79.24015760421753, 75.21063342690468, 78.15264835953712, 75.35470649600029, 78.85426551103592, 74.49585378170013, 81.08195677399635, 75.72238236665726, 78.83525133132935, 69.643894135952, 74.21737432479858, 73.71138587594032, 69.82738628983498, 74.29299786686897, 70.54176315665245, 61.249547973275185, 32.56006523966789, 29.10313993692398, 35.44023089110851, 35.46358823776245, 32.303951382637024, 12.364328484982252, 12.794314362108707, 7.9108567815274, 3.680338589474559, 0.5533794465009123, 0.09179424974718131, 0.005886024246137822, 0.20688117539975792, 0.43447079428005964, 0.12953392113558948, 1.6589254327118397, 0.7615545415319502, 10.099186431616545, 15.216614082455635, 9.655366446822882, 39.62053097784519, 16.625874862074852, 6.720017306506634, 11.56987376511097, 29.04634438455105, 48.147528022527695, 10.158896427601576, 5.379044562578201, 7.459051525220275, 3.7097416492179036, 0.43914115929510444, 5.01834511756897, 8.260707333683968, 4.386082794517279, 0.6043196318205446, 0.24540196463931352, 0.15569486422464252, 10.215304400771856, 6.627641888335347, 1.255269292742014, 3.4455152275040746, 18.44955090433359, 30.49586210399866, 29.782735370099545, 27.930169478058815, 34.89061698317528, 27.609508484601974, 34.31825749576092, 58.146436884999275, 68.2764083147049, 67.48583793640137, 67.02312916517258, 67.76808679103851, 66.54547199606895, 66.28346085548401, 70.21935045719147, 70.56085333228111, 68.44244420528412, 71.12583741545677, 69.46684643626213, 69.49292063713074, 70.72782397270203, 69.18406561017036, 70.04663452506065, 73.86813506484032, 72.44863003492355, 72.58761897683144, 74.21311095356941, 71.98079913854599, 76.73610717058182, 63.03090378642082, 49.479451552033424, 66.80375933647156, 58.74645508825779, 50.01133941113949, 6.518337903544307, 0.13436215580441058, 0.23729478794848546, 0.20482760824961588, 1.344946261961013, 15.06076069548726, 63.684635907411575, 54.535023272037506, 81.12832188606262, 74.10971090197563, 74.17214155197144, 7.526384387165308, 0.02378766057518078, 0.056980981680681, 0.06219538176083006, 0.045634066918864846, 0.03395823230675887, 0.0020629764230761793, 0.06050126641639508, 0.019659319405036513, 0.0552189486916177, 0.04114016606763471, 0.03481626263237558, 0.054815550611237995, 0.06251926984987222, 0.09072687811567448, 0.07210116818896495, 0.04747236300318036, 0.009792978125915397, 0.021815213876834605, 0.0774378037021961, 0.06753600260708481, 0.07848671812098473, 0.02891402709792601, 0.2935699018416926, 0.2327989463810809, 0.1775027549592778, 0.20108780736336485, 0.17357965843984857, 0.1777473816764541, 0.2556107996497303, 0.2013748255558312, 0.25958117097616196, 0.1846219995059073, 0.13831452262820676, 0.2320162477553822, 0.24719570588786155, 0.15619738725945354, 0.08568738368921913, 0.10453200491610914, 0.1102243666537106, 0.12146500957896933, 0.25594242091756314, 0.11338490643538535, 0.11292582130408846, 0.1232756940589752, 0.11884798906976357, 0.12403632121277042, 0.1453746180050075, 0.40943675790913403, 2.073166142217815, 62.790612280368805, 104.33379828929901, 105.26991605758667, 120.65997943282127, 108.07486474514008, 76.00118860602379, 46.78278185427189, 10.159900523722172, 3.1673217052593827, 1.3663123967126012, 11.808327119797468, 6.677656704559922, 11.892871633172035, 30.576275289058685, 92.48376935720444, 74.45856258273125, 80.38505136966705, 73.32306951284409, 84.50450912117958, 82.98434749245644, 90.09980767965317, 86.90267443656921, 83.62525150179863, 76.86543703079224, 81.16916209459305, 74.0743499994278, 79.46121454238892, 74.9778351187706, 81.57585427165031, 72.98623278737068, 80.7611931860447, 74.17510539293289, 79.76894482970238, 70.10340347886086, 74.4719834625721, 71.15154683589935, 69.65227648615837, 73.95551517605782, 79.02065098285675, 74.53274220228195, 46.49621643126011, 35.55840075016022, 49.295761808753014, 44.065061286091805, 44.427603632211685, 32.84034200012684, 26.018389463424683, 17.797030918300152, 9.091853834688663, 0.7951914053410292, 0.2001958794426173, 0.21859689673874527, 1.3424617890268564, 2.4071114603430033, 1.529435149859637, 3.7167308991774917, 2.3004374094307423, 19.92435436695814, 16.42687004059553, 16.410080641508102, 47.6259908080101, 23.18107981234789, 10.258922260254622, 13.921033702790737, 35.65592251718044, 55.69086045026779, 29.422911778092384, 6.926114922389388, 7.395043484866619, 3.490939890034497, 2.4065018305554986, 11.085558403283358, 12.945452202111483, 5.520674837753177, 1.6534126410260797, 0.5153267446439713, 0.3288070438429713, 10.325450990349054, 12.740862630307674, 12.164015583693981, 10.57952530682087, 24.629588685929775, 36.828049421310425, 37.18182183802128, 34.78274457156658, 46.31395921111107, 33.93420070409775, 46.253561452031136, 65.2567483484745, 71.93758025765419, 65.21634891629219, 70.13777643442154, 67.87023290991783, 67.39392846822739, 64.65221598744392, 70.49552723765373, 71.3006280362606, 70.5001249909401, 71.65653973817825, 69.44211736321449, 68.7771226465702, 70.35051181912422, 68.4053809940815, 69.88824382424355, 75.21488159894943, 74.83975812792778, 75.51943525671959, 78.76395955681801, 73.36829468607903, 81.82061433792114, 70.91495633125305, 60.218184515833855, 74.43402349948883, 68.38064432144165, 56.44780643284321, 8.609084989875555, 0.21994514157995582, 0.5166824406478554, 0.603374254424125, 1.9436867837794125, 26.777459532022476, 69.37748283147812, 62.233953550457954, 94.02603819966316, 81.86546713113785, 80.11416390538216, 5.807868652045727, 0.2532908756984398, 0.12484872800996527, 0.18033118365565315, 0.1990095860674046, 0.24408183235209435, 0.1382165146060288, 0.1320869685150683, 0.13430720719043165, 0.1206988534249831, 0.11688646307447925, 0.14332581544294953, 0.26227095164358616, 0.1148097483383026, 0.23396377684548497, 0.16063629125710577, 0.17800088447984308, 0.13714917266042903, 0.12288213314604945, 0.27535038418136537, 0.08417677920078859, 0.16585103643592447, 0.33174318785313517], [0.06297307088971138, 0.013375985472521279, 0.0729967920051422, 0.2223242147010751, 0.04849756951443851, 0.027843406714964658, 0.034258119339938276, 0.04389756009913981, 0.10701046645408496, 0.02442851066007279, 0.04076993456692435, 0.019115840950689744, 0.1069433540396858, 0.05053483539086301, 0.03881781158270314, 0.023159219199442305, 0.012257771159056574, 0.08648495495435782, 0.039967602424439974, 0.03638771580881439, 0.07971548460773192, 0.06489307372248732, 0.03920064104022458, 0.06949799615540542, 0.04391789865621831, 0.05678397857991513, 1.1251994222402573, 5.570320123806596, 55.88667154312134, 71.7572571337223, 93.49232643842697, 99.1338837146759, 59.47980433702469, 58.81159879267216, 6.021550660952926, 0.771475393557921, 0.6183415919076651, 1.2929462897591293, 0.2753239934099838, 0.7225897698663175, 14.408857226371765, 71.36769443750381, 67.94433653354645, 65.68039521574974, 57.36931398510933, 74.16961088776588, 75.37147879600525, 80.36799788475037, 84.09970164299011, 79.80467051267624, 79.9944095313549, 78.2869103550911, 76.80376634001732, 78.18645134568214, 77.99596756696701, 78.97342711687088, 80.82838878035545, 80.28710782527924, 77.77114123106003, 77.2923593223095, 76.74225524067879, 70.49517005681992, 74.8556412756443, 72.28529959917068, 69.80522587895393, 73.77835348248482, 65.69241777062416, 50.827231630682945, 28.830966241657734, 32.858330234885216, 30.64997423440218, 22.206924185156822, 19.64414220303297, 4.475089693441987, 4.101720778271556, 2.365340539254248, 0.17531321151182055, 0.03843490419967566, 0.16273345216177404, 0.08651950935018249, 0.07412763210595585, 0.31979983497876674, 0.12114837969420478, 0.5519912741146982, 1.9306452898308635, 5.597116760909557, 2.0003563491627574, 37.157354950904846, 7.167082792147994, 12.832489963620901, 8.6141406185925, 24.20196533203125, 33.575344160199165, 4.838094664737582, 4.7348428051918745, 7.534439954906702, 5.805413033813238, 0.07011616064119153, 3.131181369535625, 3.4545544674620032, 4.129341971129179, 0.961344555253163, 0.5518261610995978, 0.03476873920590151, 8.463171869516373, 4.475471097975969, 4.688057340681553, 4.661622159183025, 18.44477456063032, 26.72539472579956, 29.1025547683239, 27.963130809366703, 31.185798682272434, 31.395993903279305, 47.476039454340935, 63.581999614834785, 68.2921926677227, 70.22642567753792, 69.09128978848457, 67.62374013662338, 67.21188023686409, 68.97782787680626, 70.96553161740303, 73.59421536326408, 69.23207983374596, 69.54117804765701, 67.62987300753593, 71.70929610729218, 69.9711325764656, 71.24439105391502, 71.9806395471096, 75.904301404953, 71.35973006486893, 73.92992734909058, 70.26627033948898, 70.74721813201904, 72.52823576331139, 61.060413122177124, 39.616742581129074, 45.43189734220505, 46.38346128165722, 41.478802263736725, 3.2354093017056584, 0.1205859801848419, 0.14550767024047673, 0.15409473446197808, 2.9113828763365746, 21.178178787231445, 37.378867864608765, 63.08323077857494, 52.85693071782589, 59.19308692216873, 35.864523723721504, 0.379817703505978, 0.06151524794404395, 0.0573950258694822, 0.027327680872986093, 0.08329400938237086, 0.06526719778776169, 0.06864599577966146, 0.16517532581929117, 0.056080314971040934, 0.02874480629543541, 0.1102330868889112, 0.07568688437459059, 0.06400890866643749, 0.026222914275422227, 0.09337244162452407, 0.049996102970908396, 0.02106929608999053, 0.021847159623575862, 0.0763991309213452, 0.014406085520022316, 0.06789838589611463, 0.06302997877355665, 0.021038560043962207, 0.10019718713010661, 0.07652404179680161, 0.0347127033455763, 0.2556927624391392, 0.07543675092165358, 0.03817071446974296, 0.0490278303186642, 0.013540094732888974, 0.0823641502938699, 0.09409458099980839, 0.05376319262722973, 0.08019402885111049, 0.1619479333749041, 0.06669137917924672, 0.036291128999437205, 0.02403252849035198, 0.030487459953292273, 0.0841367180692032, 0.08067983872024342, 0.06682624967652373, 0.09289858033298515, 0.05423097201855853, 0.04547524731606245, 0.0922866202017758, 0.16861954412888736, 0.0417460517201107, 2.21709743142128, 18.740430995821953, 83.69316905736923, 87.20148280262947, 105.37626475095749, 105.30102878808975, 68.0297863483429, 63.50844316184521, 5.679045589640737, 2.066220589913428, 3.4496821789070964, 4.1446461249142885, 2.267209142446518, 1.5130663407035172, 17.274640649557114, 75.64512491226196, 70.20365729928017, 70.41411280632019, 63.86039927601814, 81.13200008869171, 77.06013098359108, 84.01606813073158, 84.39027205109596, 85.12594297528267, 81.50136306881905, 79.54397410154343, 77.24733173847198, 78.47950682044029, 76.3486647605896, 79.69072222709656, 76.41096621751785, 80.83698391914368, 76.80347755551338, 76.60871520638466, 74.36803624033928, 71.03388994932175, 76.17706596851349, 74.8804235458374, 72.22776308655739, 75.75510621070862, 64.40807908773422, 40.368410646915436, 26.944211684167385, 33.24484549462795, 33.315730690956116, 27.576237469911575, 21.916665360331535, 7.542967647314072, 1.792053545359522, 2.7753656124696136, 0.4406143818050623, 0.11143690237076953, 0.1315040560439229, 0.130451527365949, 0.23786851263139397, 0.20497103570960462, 0.3808504465268925, 0.3562467370647937, 3.672214150428772, 4.118670718744397, 8.893194794654846, 50.82760401070118, 10.671741608530283, 7.526348289102316, 7.282259836792946, 30.73659248650074, 47.03385338187218, 8.741419538855553, 4.54722692258656, 5.6364156771451235, 4.08711863681674, 1.6569755435921252, 5.574543597176671, 8.893271740525961, 5.670757759362459, 0.5569849186576903, 0.38230113743338734, 0.12529697036370635, 9.06439745798707, 6.589327594265342, 2.523362897336483, 3.393299854360521, 18.799295537173748, 29.950021393597126, 31.337340250611305, 28.468159809708595, 31.300647519528866, 31.187599785625935, 40.37080451846123, 63.38613912463188, 72.39776596426964, 71.75832107663155, 64.77399945259094, 68.02844882011414, 65.00675976276398, 66.619773209095, 66.4139686524868, 72.1246974170208, 69.72378864884377, 70.16942113637924, 68.72537702322006, 73.75829815864563, 70.62991082668304, 73.30560564994812, 72.24812239408493, 74.8552916944027, 70.47275125980377, 75.64054235816002, 71.17881417274475, 74.01831820607185, 74.08075645565987, 67.35306546092033, 46.67068026959896, 56.613492742180824, 53.886025696992874, 41.91193722188473, 3.9746373100206256, 0.19860873726429418, 0.1971129237790592, 0.17041064333170652, 4.051873153075576, 29.435071125626564, 51.01595230400562, 60.3865534812212, 74.65007230639458, 71.13820195198059, 49.56031881272793, 0.7465150079224259, 0.03779227852646727, 0.028304543884587474, 0.08740489152842201, 0.06641103289439343, 0.05153315018105786, 0.02532425136450911, 0.06091260918765329, 0.038630185517831706, 0.006181895796544268, 0.17090479494072497, 0.05499065293406602, 0.051199001900386065, 0.041906166370608844, 0.0737079772807192, 0.00585833100558375, 0.037177631820668466, 0.07147463969886303, 0.04874858241237234, 0.0823493221832905, 0.019747928126889747, 0.07071718893712386, 0.13319618243258446, 0.2991003269562498, 0.13750350364716724, 0.14241313707316294, 0.3688253980362788, 0.15661670069675893, 0.14996920974226668, 0.16461295599583536, 0.11652071785647422, 0.27771219494752586, 0.12458749202778563, 0.12336337880697101, 0.11918487216462381, 0.2703039877815172, 0.22351197752868757, 0.20755955774802715, 0.14092704572249204, 0.10246484162053093, 0.18982328212587163, 0.2828455116832629, 0.20085984928300604, 0.18421537679387257, 0.13043883664067835, 0.1762779738055542, 0.13012511597480625, 0.34815272607374936, 0.2208812569733709, 2.0459197042509913, 15.817184206098318, 106.53102278709412, 102.06244736909866, 123.68174448609352, 120.5048793554306, 83.39480146765709, 80.34133091568947, 12.770745176821947, 3.458658247254789, 9.430584758520126, 9.476605039089918, 5.61695977114141, 3.4168386412784457, 23.319635577499866, 90.58739751577377, 84.52335610985756, 84.39408704638481, 74.56653758883476, 88.73152390122414, 83.39068248867989, 85.62331348657608, 89.3052627146244, 86.66791543364525, 83.77509266138077, 80.00200152397156, 77.13901475071907, 78.65944996476173, 77.14931979775429, 80.35994991660118, 78.32648903131485, 81.06469050049782, 77.70826980471611, 78.34939420223236, 73.53918671607971, 72.53515899181366, 76.92561820149422, 74.1852356493473, 71.86210110783577, 77.165537327528, 74.11913439631462, 55.97584515810013, 34.68736208975315, 42.43241049349308, 41.3576989620924, 45.642554238438606, 32.52083994448185, 13.239147942513227, 6.73758233897388, 6.997480317950249, 0.29250791820231825, 0.2837742055999115, 0.14795656461501494, 0.19083123741438612, 0.423080786713399, 0.904160711215809, 0.327430063043721, 2.050614827312529, 5.88509333319962, 16.028968691825867, 18.9192645996809, 57.99712389707565, 13.17914156243205, 20.770249776542187, 17.83901486545801, 33.031437546014786, 55.93899853527546, 29.98924858868122, 6.775162322446704, 14.574117008596659, 8.956729285418987, 7.58962201885879, 10.508701857179403, 13.107046131044626, 6.922700330615044, 1.3089577993378043, 0.8125335560180247, 0.18541614204877988, 11.779827699065208, 10.634906385093927, 5.778929879888892, 11.80386520922184, 28.55801358819008, 39.04130145907402, 39.54246036708355, 36.621412709355354, 38.668807446956635, 37.90098264813423, 58.346100971102715, 70.53294003009796, 75.34222036600113, 72.28441044688225, 68.59118342399597, 67.26732686161995, 68.03059950470924, 67.88586527109146, 70.01392588019371, 70.82724183797836, 70.2943204343319, 70.70848301053047, 68.84751006960869, 73.87418434023857, 71.41762375831604, 73.43849211931229, 76.27751737833023, 76.82558476924896, 71.86407700181007, 74.90159600973129, 74.53316777944565, 76.61353334784508, 79.65701043605804, 72.8942397236824, 56.976111084222794, 65.71326345205307, 66.51014909148216, 55.72973996400833, 6.388711184263229, 0.2765846945112571, 0.2926477981964126, 0.5764674232341349, 5.045414865016937, 42.1983240544796, 48.681805953383446, 77.06482753157616, 83.64942580461502, 81.70316264033318, 49.89015631377697, 0.4595095507102087, 0.14938243810320273, 0.14155355194816366, 0.18534054688643664, 0.2520819765049964, 0.18709412310272455, 0.12765990919433534, 0.3179933881619945, 0.11251395160797983, 0.08822604082524776, 0.3672711626859382, 0.19956714677391574, 0.14088330353843048, 0.2139504288788885, 0.2368121247855015, 0.0923276758112479, 0.12116230238461867, 0.18006968050030991, 0.19556173123419285, 0.08060425097937696, 0.14043584786122665, 0.13267967733554542, 0.2032400356256403], [0.04691013047704473, 0.014521803968818858, 0.12190523673780262, 0.04272626181773376, 0.05175215796043631, 0.04244839430612046, 0.022115191823104396, 0.02206838456913829, 0.0254132014742936, 0.10723619809141383, 0.004893127133982489, 0.03324248653370887, 0.07235971759655513, 0.04955862917995546, 0.04389548579638358, 0.08236872934503481, 0.06680206308374181, 0.11407209807657637, 0.11041428966564126, 0.07134477127692662, 0.07774408062687144, 0.16986509057460353, 0.04016105805931147, 0.0780134134402033, 0.04080486003658734, 0.007237004365379107, 0.4354387032799423, 1.331471591256559, 40.26381365954876, 73.34595948457718, 85.38344755768776, 106.10163822770119, 72.00702533125877, 59.94131237268448, 22.11088053882122, 2.888600961305201, 2.259087790735066, 1.1879264563322067, 0.14873387524858117, 0.22900343989022076, 20.201783180236816, 76.57892480492592, 76.67518883943558, 69.32659596204758, 60.28840094804764, 69.38310652971268, 82.14341461658478, 82.87871316075325, 85.15498101711273, 83.13503220677376, 81.76760718226433, 78.97170960903168, 79.72153097391129, 80.70858120918274, 79.40241649746895, 79.44992914795876, 79.99013856053352, 82.49370262026787, 80.00515535473824, 79.25547078251839, 76.26396730542183, 74.13373321294785, 74.82969626784325, 71.55869498848915, 71.28783032298088, 72.01923787593842, 66.32849603891373, 54.06911127269268, 35.03787808120251, 30.801639296114445, 30.430144630372524, 24.117007590830326, 10.720077864825726, 1.0180924320593476, 0.16537689312826842, 1.3200781401246786, 0.509053043788299, 0.04206509729556274, 0.2307203836971894, 0.01229037463417626, 0.11798859690316021, 0.4399862576974556, 0.14510750421322882, 0.1390031911432743, 0.44754865346476436, 2.8581740939989686, 10.564413517713547, 34.739803075790405, 10.79064292833209, 12.946302406489849, 4.452623398974538, 26.899404488503933, 33.49756993353367, 6.479742424562573, 2.576730321161449, 0.5946705245878547, 0.14560962648829445, 0.5304328934289515, 1.854720376431942, 2.3083462100476027, 3.269346705637872, 0.5604636913631111, 0.10786020327941515, 0.32819358457345515, 4.284318555146456, 2.4602261977270246, 6.2225237768143415, 3.9018538780510426, 14.379635844379663, 28.51944375783205, 30.56367326527834, 31.4783962816, 29.155142046511173, 33.887854591012, 48.02001066505909, 63.020857125520706, 68.55243310332298, 70.27079969644547, 66.20753332972527, 67.93705612421036, 69.3483991920948, 73.058542907238, 75.5288815498352, 75.42026817798615, 72.81350165605545, 71.08394086360931, 71.62693932652473, 71.2209615111351, 71.26321524381638, 73.52934524416924, 71.75478726625443, 74.34811010956764, 73.34648385643959, 72.56749525666237, 73.86823385953903, 69.42130208015442, 73.12857314944267, 58.99034880101681, 41.12191781401634, 38.90173114836216, 50.34258283674717, 35.525581911206245, 2.2145648673176765, 0.3676296496996656, 0.32133329019416124, 2.0559889264404774, 12.6793572306633, 40.23352548480034, 51.73077754676342, 68.4133529663086, 42.25542739033699, 50.55177301168442, 11.359018329530954, 0.1286208865349181, 0.04922108186292462, 0.07263598949066363, 0.07404738367768005, 0.10507069280720316, 0.06554453837452456, 0.04291453726182226, 0.046055261700530536, 0.02696302475669654, 0.07062468765070662, 0.11114028820884414, 0.03828220360446721, 0.030935752402001526, 0.031237893708748743, 0.022125988216430414, 0.02992960980918724, 0.053689938940806314, 0.04801768940524198, 0.05737404906540178, 0.027124054104206152, 0.05982434238831047, 0.010344545989937615, 0.03558826691005379, 0.19360719627002254, 0.05316843176842667, 0.10261907475069165, 0.025041173976205755, 0.03047355952730868, 0.05720480599848088, 0.05964264608337544, 0.022758038285246585, 0.05939788949035574, 0.08505007179337554, 0.03388535711565055, 0.03298578136309516, 0.036648380337283015, 0.0392079623270547, 0.12049773140461184, 0.025326657778350636, 0.039001174009172246, 0.07441499168635346, 0.049949922831729054, 0.06970543385250494, 0.02695206323551247, 0.09186677983962, 0.02881004664232023, 0.06706395957735367, 0.16105587186757475, 0.02949767429527128, 0.9453668282367289, 1.8086543795652688, 63.67979496717453, 89.00619596242905, 97.81266421079636, 114.8311910033226, 74.95806857943535, 70.32825261354446, 28.680042140185833, 5.922134220600128, 6.380011076107621, 1.080093348864466, 0.14967417635489255, 0.372045636177063, 24.91888616234064, 81.95475473999977, 82.87270188331604, 80.36306574940681, 67.34304919838905, 77.68047049641609, 85.70956125855446, 87.70700767636299, 86.30922988057137, 83.4321078658104, 82.28143841028214, 81.14637091755867, 80.05578383803368, 85.66796109080315, 80.09887352585793, 79.47910398244858, 79.82665613293648, 84.34806391596794, 78.80934432148933, 77.39359349012375, 74.6926300227642, 76.84908270835876, 78.07558089494705, 72.74635925889015, 69.59438279271126, 74.0192985534668, 66.0010676085949, 48.568252846598625, 29.750997573137283, 33.35700787603855, 32.46222048997879, 32.594350799918175, 18.523924313485622, 2.4949461221694946, 0.5697128700558096, 3.5201562847942114, 0.7902112975716591, 0.21033366123447195, 0.17873949953354895, 0.10611871664877981, 0.23603110341355205, 0.8971562026999891, 0.2133590856101364, 0.2609019563533366, 1.0956689505837858, 5.799009902402759, 9.894815348088741, 42.03911639750004, 11.831836458295584, 5.47159762121737, 3.8042057678103447, 35.86415894329548, 45.17178989946842, 6.498190434649587, 3.3182424819096923, 0.34679418022278696, 1.8702141637913883, 3.203068762086332, 2.951143467798829, 6.664900789037347, 6.67491277679801, 0.7760760560631752, 0.0646430738561321, 0.19308223068946972, 3.9340476505458355, 5.513280909508467, 3.8928433740511537, 3.5690069384872913, 14.774676896631718, 32.006583139300346, 31.705920472741127, 30.206403136253357, 28.385269157588482, 32.89667397737503, 43.52952182292938, 63.4637575596571, 72.90403559803963, 69.99253302812576, 66.47293388843536, 68.5877788066864, 67.1708120405674, 72.32226401567459, 71.59499064087868, 74.29906234145164, 71.94108366966248, 72.20760136842728, 73.0005656182766, 72.23046854138374, 72.22055867314339, 73.35528418421745, 71.91755533218384, 74.63754817843437, 73.75200569629669, 73.71045112609863, 74.66101571917534, 70.46186104416847, 75.46639010310173, 67.02455788850784, 48.710505813360214, 44.72273759543896, 57.654762268066406, 42.406860664486885, 2.264915728010237, 0.20242919476004317, 0.1968365628272295, 2.701247502118349, 14.833850171416998, 54.087551683187485, 48.142006918787956, 76.4624534547329, 56.56229808926582, 69.41874101758003, 19.300150461494923, 0.18705915310420096, 0.1514556721667759, 0.058342447882751, 0.10598559019854292, 0.04561603273032233, 0.07224392771604471, 0.045081278221914545, 0.09216929407557473, 0.04313927442126442, 0.08345259149791673, 0.09808297909330577, 0.021376224249252118, 0.012129744191042846, 0.021362863735703286, 0.034396585542708635, 0.03595194895751774, 0.041768126902752556, 0.04026099566544872, 0.07502196458517574, 0.031233318368322216, 0.01729129686282249, 0.04974163166480139, 0.031155682299868204, 0.28082927456125617, 0.1852786962990649, 0.17119659256422892, 0.13929218344856054, 0.16131430253153667, 0.18096028739819303, 0.11710388265782967, 0.0996707817830611, 0.17006848356686532, 0.20530718407826498, 0.12182904043584131, 0.1144524932897184, 0.15399521245853975, 0.12082134489901364, 0.23001535824732855, 0.1257732807425782, 0.20924001757521182, 0.13984941761009395, 0.23127754364395514, 0.12816345639294013, 0.1421076394035481, 0.24801956402370706, 0.11540158884599805, 0.21823729650350288, 0.2730651630554348, 0.05584128033660818, 1.0948536568321288, 1.5974697866477072, 72.52427637577057, 106.0938410460949, 111.05277255177498, 128.46589297056198, 88.05926397442818, 82.56874099373817, 42.90993086993694, 13.63261017948389, 13.773445822298527, 2.9968913504853845, 0.7128841406665742, 0.8990347268991172, 32.497133016586304, 97.36295074224472, 91.67122095823288, 85.70544987916946, 77.77965277433395, 87.88131952285767, 92.09444224834442, 92.44649335741997, 89.50830861926079, 86.70719772577286, 82.58447974920273, 81.94467008113861, 79.29314956068993, 85.67445114254951, 80.54207414388657, 79.20301839709282, 78.47979560494423, 83.14086109399796, 78.48909750580788, 78.28885585069656, 73.47892194986343, 75.40923357009888, 77.84345895051956, 71.52308329939842, 68.33203732967377, 76.89208880066872, 71.50424391031265, 62.46093437075615, 37.857338190078735, 43.48193697631359, 41.95492811501026, 38.488841503858566, 14.765891768038273, 7.346297325566411, 6.041932767257094, 6.672066254541278, 1.2008613185025752, 0.23909733106847852, 0.22956837754463777, 0.2080085570923984, 0.24493619275745004, 0.8519092400092632, 0.23098650301108137, 0.2786635688971728, 1.4961617602966726, 11.328960042446852, 20.345424972474575, 57.73206152021885, 16.82217612862587, 27.424277924001217, 13.103253934532404, 37.27113984525204, 58.77189092338085, 23.276323601603508, 3.0534722143784165, 0.999801519792527, 2.5853603705763817, 7.025329973548651, 9.059069193899632, 10.483187176287174, 5.6632346380501986, 1.1729671340435743, 0.44763129903003573, 0.38911829818971455, 6.504567917436361, 12.096447609364986, 6.062043663114309, 10.66753713414073, 25.25501422584057, 38.32351237535477, 40.92553675174713, 36.85520276427269, 36.272215247154236, 37.68858164548874, 59.30443614721298, 67.85240426659584, 73.69786620140076, 71.97114765644073, 64.91478189826012, 69.8160021007061, 66.98709189891815, 74.1848024725914, 73.56023758649826, 76.33973523974419, 72.52268806099892, 73.6561444401741, 73.37861493229866, 73.00915315747261, 71.36606052517891, 76.2433648109436, 74.41891551017761, 76.38290852308273, 74.60444435477257, 76.00780785083771, 79.21841517090797, 73.66569712758064, 79.60987016558647, 75.46153396368027, 57.83136539161205, 57.714624255895615, 73.02030935883522, 54.29907873272896, 3.7839352805167437, 1.1330350767821074, 0.3765937843127176, 4.130186000838876, 27.76558130979538, 57.05785229802132, 62.06141620874405, 90.02885028719902, 66.06137037277222, 77.80991435050964, 16.345372013747692, 0.19200579001335427, 0.1987166900653392, 0.12848826474510133, 0.29679506784304976, 0.2612488658633083, 0.1480711967451498, 0.16775446711108088, 0.15547886956483126, 0.21614231751300395, 0.17232361802598462, 0.25874830316752195, 0.12438705278327689, 0.12557665613712743, 0.16875503060873598, 0.10620201530400664, 0.19197401124984026, 0.13222987647168338, 0.17936328949872404, 0.26862602157052606, 0.13315003569005057, 0.10476502444362268, 0.1690034571220167, 0.08781092052231543], [0.051967269464512356, 0.042981686783605255, 0.08677346486365423, 0.04385373627883382, 0.09870261303149164, 0.017470640559622552, 0.06284000381128863, 0.08651544238091446, 0.0640121370088309, 0.04676371958339587, 0.08159324439475313, 0.11303459788905457, 0.04506921461143065, 0.06140409277577419, 0.036209500176482834, 0.04787850702996366, 0.030004678046680056, 0.04434264461451676, 0.06029671567375772, 0.06669568363577127, 0.028193312646180857, 0.057784579184954055, 0.017850861368060578, 0.011453443567006616, 0.06388409427017905, 0.016562082964810543, 0.06981510101468302, 0.502712371526286, 34.41601105034351, 92.92714476585388, 84.8987303674221, 110.32238334417343, 84.7411984205246, 56.14332877099514, 27.404851466417313, 0.9312652505468577, 0.21574559505097568, 0.3954961965791881, 0.44028320582583547, 0.20056695328094065, 24.94413770735264, 68.90165716409683, 64.50327157974243, 60.510065853595734, 59.801669865846634, 70.35036742687225, 82.15215414762497, 80.31804576516151, 85.51052793860435, 83.17584201693535, 83.5316701233387, 82.06892341375351, 83.03569033741951, 80.21918267011642, 82.08886474370956, 79.11679342389107, 82.49917432665825, 80.92543557286263, 76.9533871114254, 77.122493237257, 75.7475446164608, 73.22812020778656, 75.49986630678177, 77.36771687865257, 70.56740418076515, 70.7533510029316, 66.12693965435028, 52.25688211619854, 34.22058753669262, 29.60028626024723, 28.9262917265296, 26.90785713493824, 18.699340000748634, 2.921801204793155, 1.1367764510214329, 1.585316495038569, 0.5311002326197922, 0.32224562717601657, 0.14221915451344103, 0.17611571063753217, 0.08716670665307902, 0.13496844592737034, 0.30047157837543637, 0.438443748280406, 1.5189510374329984, 2.321768752299249, 5.339548531919718, 21.451555117964745, 10.065145958214998, 6.9548409059643745, 3.984236544929445, 14.484106488525867, 14.769732411950827, 2.6935728639364243, 0.34255737788043916, 0.1814347572508268, 3.3042532950639725, 0.3545742033747956, 0.1490565759013407, 0.10176975352806039, 0.5473194248043001, 0.08771019623964094, 0.12235903777764179, 0.12315236395807005, 1.0213583568111062, 1.9498453033156693, 5.3208620846271515, 3.892535353079438, 15.229391846805811, 27.845325730741024, 30.323539450764656, 28.67547858506441, 29.65558849275112, 34.04381722211838, 47.63282664120197, 62.34545096755028, 69.50358286499977, 73.52280959486961, 67.74616956710815, 69.66762766242027, 68.77795100212097, 70.8415138721466, 71.08296811580658, 74.4200174510479, 70.37965625524521, 71.98953106999397, 71.40776708722115, 73.78342241048813, 73.97643685340881, 73.15064236521721, 74.18879225850105, 75.11519774794579, 74.2336830496788, 73.57555076479912, 72.87315845489502, 74.70953911542892, 73.0884701013565, 54.35924090445042, 38.16882647573948, 37.27073706686497, 51.710912212729454, 21.39330994337797, 1.2180867441929877, 1.2167249922640622, 2.8507846780121326, 11.335212606936693, 31.97754129767418, 44.78833727538586, 69.6831688284874, 50.34119591116905, 44.214511066675186, 42.2802172601223, 1.7374121211469173, 0.04998088152206037, 0.031802720041014254, 0.10150000511202961, 0.1134001427271869, 0.12594038271345198, 0.07737360792816617, 0.0800572732987348, 0.10076706006657332, 0.01365823351079598, 0.021775748318759724, 0.10282916933647357, 0.058873536181636155, 0.04743581965158228, 0.071514396549901, 0.07713844359386712, 0.02305790676473407, 0.04618383878550958, 0.08930862648412585, 0.05671262108080555, 0.020191500516375527, 0.013143645010131877, 0.052058282744837925, 0.1125596604833845, 0.024753938705543987, 0.030911320900486317, 0.07311897177714854, 0.12187556567369029, 0.07961108669405803, 0.04198287846520543, 0.027206154190935194, 0.026405638454889413, 0.08168056549038738, 0.071546397957718, 0.04183676443062723, 0.02940308015240589, 0.035343287672731094, 0.0465561371674994, 0.030330041154229548, 0.025706216219987255, 0.036767279816558585, 0.10540275936364196, 0.015864735032664612, 0.13228388997958973, 0.03842486294161063, 0.004468648348847637, 0.07168086769524962, 0.032846509930095635, 0.06804726072004996, 0.0703157093084883, 0.49062622943893075, 0.282325028674677, 46.286395490169525, 104.26036342978477, 93.20820048451424, 116.62693664431572, 87.95584112405777, 72.37328007817268, 44.565467834472656, 2.3244977183640003, 0.08248954356531613, 0.5812790931668133, 0.32018972968216985, 0.3188413067255169, 27.00529720634222, 79.2053210735321, 74.25166368484497, 69.49145391583443, 68.45369920134544, 80.38400262594223, 83.80677536129951, 86.34301766753197, 88.03171545267105, 85.23509591817856, 85.91215118765831, 82.76661917567253, 82.61737078428268, 81.94746673107147, 80.67522659897804, 79.61708977818489, 84.48098078370094, 83.66565093398094, 78.8583616912365, 76.25367745757103, 78.12798008322716, 75.44207140803337, 74.49480503797531, 75.41355773806572, 72.61316120624542, 74.8271656036377, 68.57093811035156, 50.65377093851566, 30.080510191619396, 30.73363434523344, 32.22612015902996, 30.623694844543934, 25.918832905590534, 6.356442840769887, 0.5952825292479247, 3.742674244567752, 0.4569952731253579, 0.09772596895345487, 0.0633664388442412, 0.18142202199669555, 0.2208267239620909, 0.27597132429946214, 0.2085468071163632, 0.9990062937140465, 0.8771838806569576, 4.600505763664842, 6.101221460849047, 16.66876696050167, 10.598736125975847, 2.140201907604933, 0.9907120512798429, 14.708927124738693, 10.090944673866034, 2.406709394417703, 1.5731360111385584, 0.2091204427415505, 4.985844511538744, 2.475146809592843, 0.17204848903929815, 0.33353957114741206, 1.273391826543957, 0.11667156679322943, 0.04805074837349821, 0.02442415239784168, 0.6398721865843982, 4.280454162508249, 3.9119717851281166, 5.424030348658562, 18.257391415536404, 33.17453786730766, 29.946250095963478, 29.351454712450504, 29.60228495299816, 35.74076056480408, 50.029772222042084, 67.78493508696556, 72.54297897219658, 71.73192009329796, 66.99788331985474, 68.2331058382988, 68.50086227059364, 68.03411051630974, 71.18508383631706, 71.99235051870346, 70.84978982806206, 73.14116567373276, 70.60703605413437, 73.32519739866257, 76.81135833263397, 71.63171947002411, 76.22653931379318, 73.02604705095291, 75.92572465538979, 74.83459040522575, 74.51388001441956, 73.8146111369133, 78.74739244580269, 62.36395977437496, 46.84447154402733, 42.4768453091383, 60.19942872226238, 25.713541321456432, 1.880975542590022, 1.0719369677826762, 3.4724025847390294, 15.957657918334007, 42.200345546007156, 53.37820194661617, 68.42697903513908, 72.68066838383675, 55.106250420212746, 57.45377205312252, 2.867726068943739, 0.018346105789532885, 0.04781855262990575, 0.09159627443295904, 0.12667804781813174, 0.03871424858516548, 0.022967975164647214, 0.019634591044450644, 0.0802826635481324, 0.05193856319237966, 0.027920517713937443, 0.08711998103535734, 0.027404500578995794, 0.05149106669705361, 0.041391802369616926, 0.0608588034810964, 0.025577217966201715, 0.06776365640689619, 0.05913732144108508, 0.05121307673107367, 0.024133922561304644, 0.07256954500917345, 0.05765990950749256, 0.03066591678361874, 0.1566961401840672, 0.10151321534067392, 0.22683727409457788, 0.20665485004428774, 0.1825568696949631, 0.12073394958861172, 0.1537469492177479, 0.2281120463158004, 0.11892209993675351, 0.11230479954974726, 0.15626018779585138, 0.18234514980576932, 0.1736418652581051, 0.18936255684820935, 0.10823431250173599, 0.14043161761946976, 0.16905945958569646, 0.2687439933652058, 0.2278254585689865, 0.15351636393461376, 0.11456530715804547, 0.08234780078055337, 0.12996384728467092, 0.0783861348463688, 0.1515785718220286, 0.11032002948923036, 0.6114317814353853, 0.37872158107347786, 54.45800140500069, 125.33438220620155, 105.65712288022041, 132.79386073350906, 105.30435740947723, 76.84391498565674, 58.48198167979717, 3.808102933689952, 0.5600226181559265, 0.8180845831520855, 1.0166166862472892, 0.5819062970113009, 35.79519644379616, 89.4514712691307, 86.51273176074028, 80.99030569195747, 78.44596222043037, 89.37431260943413, 90.77412709593773, 88.8639771938324, 90.00620350241661, 88.8531705737114, 88.3962070941925, 83.90456691384315, 82.01007217168808, 82.46511295437813, 80.7453328371048, 78.56565579771996, 83.6960569024086, 83.67809906601906, 77.20358848571777, 76.93287581205368, 77.76176333427429, 74.03129070997238, 75.62396764755249, 79.12194594740868, 69.5151798427105, 76.0544465482235, 73.13439443707466, 63.11915025115013, 36.52302458882332, 39.03358407318592, 37.77428984642029, 37.54797779023647, 28.278261199593544, 12.447740659117699, 6.428520223125815, 5.768778249621391, 1.3898581895045936, 0.6341842480469495, 0.21320669300621375, 0.24675769032910466, 0.2239629509858787, 0.4775838745990768, 1.0484302416443825, 3.9919061958789825, 2.6808789325878024, 8.021410424262285, 12.298745904117823, 46.965187266469, 16.05324938893318, 27.148954197764397, 13.018002659082413, 33.75067815184593, 42.49156191945076, 6.800446640700102, 2.429620740003884, 0.34280691761523485, 8.042828924953938, 2.0242981519550085, 0.22494791453937069, 0.39062108786311, 2.5472006807103753, 0.2242979861330241, 0.2639208943583071, 0.28902691905386746, 0.9081848140340298, 9.310905430465937, 5.081293014809489, 8.020880352705717, 28.099357299506664, 39.37482476234436, 38.6578868329525, 36.611757427453995, 35.9116829931736, 40.64771845936775, 59.20411393046379, 73.23222398757935, 74.19136092066765, 72.2371181845665, 66.8037973344326, 70.10057643055916, 68.7777230143547, 71.45018801093102, 69.42077770829201, 74.79815796017647, 68.64753440022469, 75.21859019994736, 73.73320430517197, 75.7157251238823, 76.91204532980919, 74.80996012687683, 77.50429674983025, 76.2229523062706, 73.80602359771729, 76.32597237825394, 77.16354623436928, 79.0747980773449, 82.80188888311386, 69.92500305175781, 54.70253728330135, 54.84931580722332, 72.00714692473412, 33.35265710949898, 2.5120072066783905, 1.4076375542208552, 5.892530484125018, 20.636301264166832, 53.642310574650764, 54.82892610132694, 86.454176902771, 74.69836011528969, 73.24597924947739, 60.687580928206444, 1.9522623298689723, 0.2398681256454438, 0.12040831003105268, 0.19943186809541658, 0.24359910981729627, 0.18139398365747184, 0.1802302961004898, 0.14286967663792893, 0.2736555563751608, 0.17139885749202222, 0.1298482800484635, 0.18213684379588813, 0.10530510757234879, 0.17268216441152617, 0.13418307557003573, 0.15377580391941592, 0.18452363525284454, 0.25552016857545823, 0.11285076048807241, 0.19728942133951932, 0.10780545504530892, 0.1436241588089615, 0.16545469989068806, 0.18104778660926968], [0.021948421963315923, 0.02670128411409678, 0.013009311642235843, 0.08479525538859889, 0.0423558299371507, 0.0103879940979823, 0.05470984280691482, 0.02200807022745721, 0.019905269000446424, 0.028929207728651818, 0.05424286122433841, 0.01703969024674734, 0.012920540575578343, 0.03327100355818402, 0.032834631856530905, 0.036604003616957925, 0.16236056748311967, 0.09997083951020613, 0.04493393222219311, 0.030052429683564696, 0.05478582388604991, 0.11884445644682273, 0.12046836462104693, 0.02362001312576467, 0.032711702515371144, 0.08710899724974297, 0.28672964544966817, 1.1446745647117496, 10.336515996605158, 87.70472019910812, 82.25917920470238, 114.38804358243942, 106.08446314930916, 57.68096946179867, 44.51438717544079, 5.584253976121545, 0.1425793781527318, 0.18182830332079902, 0.2677859697723761, 0.20480286504607648, 18.35362885147333, 69.82842743396759, 77.97646701335907, 59.07628878951073, 53.87900747358799, 67.68314614892006, 77.96335771679878, 84.25237745046616, 84.01800602674484, 84.92973670363426, 83.69740962982178, 84.56367194652557, 83.45419988036156, 85.59655532240868, 82.86150008440018, 82.46017321944237, 79.98486444354057, 82.42732018232346, 81.4891429245472, 81.08125761151314, 77.56324678659439, 78.10081914067268, 74.817825704813, 72.48045712709427, 73.26771408319473, 72.01143309473991, 63.081577867269516, 46.83319754898548, 35.22353231906891, 33.07584576308727, 25.710921362042427, 29.41290881484747, 20.882311463356018, 2.248709835112095, 1.5951422927901149, 2.7590079652145505, 0.9179993311408907, 0.3258805477526039, 0.13335316150914878, 0.07884838152676821, 0.15914763207547367, 0.0405684563156683, 0.16540966636966914, 0.10926969756837934, 0.2251764663378708, 2.4555498361587524, 1.466692085377872, 2.7404177002608776, 5.775246452540159, 0.6381007097661495, 1.7060899268835783, 1.8521252344362438, 1.7096319305710495, 0.35375451610889286, 0.1513768857694231, 0.5123941926285625, 1.9150523515418172, 2.2503095492720604, 1.3060066639445722, 0.265710509265773, 0.3037844365462661, 0.1735009759431705, 0.19367170374607667, 0.07820413055014797, 0.5375211162026972, 1.1254177917726338, 4.220213619992137, 3.405208890326321, 9.993434306234121, 22.97470148652792, 31.296914219856262, 26.9395075365901, 29.243426509201527, 31.812442056834698, 38.86086814105511, 56.056989803910255, 69.10193681716919, 70.75652003288269, 70.702935308218, 72.54198342561722, 72.06041246652603, 73.91256988048553, 73.93627300858498, 76.23327255249023, 76.07906922698021, 76.66027083992958, 71.882703602314, 73.90768334269524, 70.75098752975464, 74.55231875181198, 74.13782179355621, 76.57314911484718, 74.94723156094551, 75.24321287870407, 75.97531959414482, 75.85615798830986, 68.58179792761803, 54.47988063097, 36.92245535552502, 41.96193493902683, 51.148021817207336, 11.750453375279903, 3.9954058080911636, 6.9038618914783, 10.305821243673563, 27.64988511800766, 43.25087517499924, 50.953852236270905, 71.34880945086479, 40.521743819117546, 66.2182791531086, 17.798313349485397, 0.1450461582862772, 0.06569739853148349, 0.08332578814588487, 0.02595497113361489, 0.10300413065124303, 0.0751140651118476, 0.039525260144728236, 0.013082462355669122, 0.017411908847861923, 0.06402305400115438, 0.04118401586310938, 0.08059094427153468, 0.1427675868035294, 0.022396872118406463, 0.03429952746955678, 0.026092248044733424, 0.04559599845379125, 0.08851629478158429, 0.03582993245800026, 0.06322369416011497, 0.05640678202325944, 0.12728815258014947, 0.05962481227470562, 0.0218498517642729, 0.02179395320126787, 0.03280244491179474, 0.017480822825746145, 0.019969787608715706, 0.047527541682939045, 0.02649608584761154, 0.02047695277724415, 0.0747953646350652, 0.021829169963893946, 0.04038522376504261, 0.11166912037879229, 0.02907590434915619, 0.06172405861434527, 0.045618893709615804, 0.019845001042995136, 0.014090951062826207, 0.05000300494430121, 0.023240961199917365, 0.08587792268372141, 0.04867709503741935, 0.09114714150200598, 0.045904331127530895, 0.05754747413448058, 0.03169857074681204, 0.04446471306437161, 0.20989606127841398, 0.2880078909220174, 0.9325071307830513, 23.654220923781395, 108.64401340484619, 92.2358326613903, 118.64559352397919, 100.43903768062592, 68.83973568677902, 61.103525608778, 4.240963831543922, 0.044660725397989154, 0.12501344026532024, 0.3554705990245566, 0.4963486036285758, 23.04338850080967, 81.05817005038261, 85.43002545833588, 66.86234459280968, 63.75215068459511, 72.68984869122505, 84.07418221235275, 87.65327095985413, 86.76566898822784, 86.7554323375225, 86.7461608350277, 85.96186771988869, 86.08256444334984, 86.58840090036392, 83.88768061995506, 85.57095229625702, 82.55966708064079, 82.59124338626862, 81.41714438796043, 79.72542956471443, 80.11243879795074, 76.96842670440674, 76.44600793719292, 73.74945223331451, 74.31451991200447, 74.77647632360458, 68.95885169506073, 50.575430542230606, 33.75852853059769, 35.52313484251499, 28.235606588423252, 36.76971115171909, 27.202162742614746, 4.998325891792774, 2.3624823801219463, 3.611252121627331, 0.4147256584838033, 0.3228610457153991, 0.06509063343401067, 0.35096089413855225, 0.37108695949427783, 0.11191517201950774, 0.5252492590807378, 0.37013944471254945, 0.38760467316024005, 1.5486306510865688, 1.458183154463768, 3.0587365943938494, 4.253784343600273, 2.2003849782049656, 1.583327658008784, 1.2329621147364378, 3.1861865054816008, 1.9601511815562844, 1.9459018274210393, 0.29622964037116617, 5.949679417535663, 2.127327248454094, 0.32789743796456605, 0.4453718749573454, 0.1982308059814386, 0.13799994107102975, 0.20786698500160128, 0.03877343115163967, 0.505365994758904, 4.712336612865329, 3.414158122614026, 6.529477005824447, 7.2148538287729025, 22.287172079086304, 29.61002703756094, 27.869368940591812, 29.887628741562366, 35.786764696240425, 43.952230140566826, 60.288955718278885, 73.8261017203331, 69.49390858411789, 69.00826424360275, 68.8120199739933, 68.85123386979103, 73.68711277842522, 72.96005979180336, 75.51084771752357, 74.501051902771, 75.9062696993351, 71.60417094826698, 74.87875163555145, 70.20906060934067, 71.23338684439659, 72.69859582185745, 75.2354384958744, 77.07818001508713, 75.89639022946358, 75.13089090585709, 76.96610882878304, 74.47930186986923, 61.83682546019554, 43.48814204335213, 47.834508419036865, 58.24917197227478, 16.915075443685055, 4.213427184149623, 10.210775043815374, 18.52948721498251, 35.93168891966343, 52.38992057740688, 58.9199423789978, 78.0794794857502, 55.571505054831505, 71.13653004169464, 29.568761251866817, 0.3907661628909409, 0.09648514256696217, 0.08317192608956248, 0.04773401087732054, 0.056152841352741234, 0.06996422074735165, 0.05527135173906572, 0.0694837914488744, 0.033782610480557196, 0.053064935564179905, 0.060021605240763165, 0.027717924385797232, 0.056196932346210815, 0.06127871063654311, 0.05083006544737145, 0.06603981062653475, 0.023647854795854073, 0.11274724573013373, 0.04344819339166861, 0.04549061348370742, 0.044041688888682984, 0.05981511749268975, 0.07297031959751621, 0.01758381065883441, 0.1446248558931984, 0.10649491872754879, 0.11678593917167746, 0.16129423485836014, 0.09517344107734971, 0.12902373913675547, 0.11394401823054068, 0.15052353468490764, 0.11535947938682511, 0.1333964435616508, 0.20197733072564006, 0.12367786388495006, 0.12743362836772576, 0.15714254201157019, 0.20004856312880293, 0.14566552505129948, 0.3789636102737859, 0.2022376612876542, 0.17432382475817576, 0.10804807796375826, 0.2338385913753882, 0.13209222292061895, 0.3365895606111735, 0.12880802649306133, 0.22806266380939633, 0.38550127821508795, 0.8595636917743832, 1.289482181891799, 20.28252884745598, 123.15910533070564, 101.37232080101967, 135.37200719118118, 121.47555246949196, 75.85134744644165, 76.40554010868073, 12.992088049650192, 0.23180522548500448, 0.22186754154972732, 0.9887220861855894, 0.8130953321233392, 28.450513556599617, 94.03195068240166, 97.51063361763954, 75.42000979185104, 74.06067833304405, 85.3476382791996, 89.7881332039833, 91.14897698163986, 90.76993212103844, 89.75521177053452, 90.46291619539261, 87.0715905725956, 86.00585415959358, 89.00089144706726, 83.81278663873672, 84.4715116918087, 81.88109189271927, 83.90011355280876, 81.52787044644356, 79.27620247006416, 78.07108953595161, 79.95743751525879, 75.80752059817314, 73.6441370844841, 73.85988190770149, 75.77782899141312, 72.18577533960342, 58.69096286594868, 41.54562547802925, 43.40544708073139, 32.13479965925217, 42.13584780693054, 36.35152459144592, 11.148118246346712, 8.634509425610304, 6.61594326607883, 1.2900844495743513, 1.5280948905274272, 0.19868783536367118, 0.3901907312683761, 0.20650809776270762, 0.2206052967812866, 0.6819673965219408, 0.3219897049712017, 0.3988565522013232, 9.629524983465672, 3.7788632651790977, 13.601950574666262, 13.5991539247334, 8.441486433148384, 10.534460674971342, 4.638782059773803, 6.5748456213623285, 3.3117220317944884, 3.831304726190865, 0.6086560897529125, 10.658110789954662, 6.604719143360853, 2.2321997210383415, 0.5367333709727973, 0.36450989835429937, 0.35885315970517695, 0.4161025502253324, 0.17076875927159563, 0.5068243446294218, 11.351127102971077, 4.299143934622407, 8.671174608170986, 18.18144679069519, 31.085343472659588, 40.35812459886074, 32.48114347457886, 34.863216653466225, 38.37844602763653, 47.85819634795189, 62.478329837322235, 75.90427860617638, 69.30437475442886, 70.92466101050377, 72.6260045170784, 72.68647447228432, 74.75072130560875, 72.1921817958355, 80.26234075427055, 76.5222242474556, 80.9136714041233, 73.44444260001183, 77.6280029118061, 72.10414811968803, 76.44448801875114, 73.93379554152489, 76.80750533938408, 78.3375996351242, 79.91065442562103, 78.98847430944443, 80.38299947977066, 78.92261624336243, 71.78133264183998, 52.20476791262627, 60.388316586613655, 66.51328012347221, 22.136472165584564, 4.398477729409933, 11.272507421672344, 24.78483695536852, 46.88529655337334, 53.65321218967438, 71.93419083952904, 92.03262716531754, 68.26643764972687, 86.11251443624496, 25.589449480175972, 0.2055542598827742, 0.18173912685597315, 0.2549003268359229, 0.17130838969023898, 0.14496852963929996, 0.17845585069153458, 0.11912845409824513, 0.25500247604213655, 0.11700599337927997, 0.1725378166884184, 0.1853987609501928, 0.21384945226600394, 0.1636189382406883, 0.1950057884096168, 0.16242905287072062, 0.21872592653380707, 0.11598212644457817, 0.2316967531805858, 0.11981695191934705, 0.0919829482154455, 0.1446425635367632, 0.21337082638638094, 0.35113040066789836, 0.15268555929651484], [0.03877819202898536, 0.0405760039575398, 0.028329919769021217, 0.08900142929633148, 0.09544634362100624, 0.049370030901627615, 0.03193893011484761, 0.029757309093838558, 0.11112543041235767, 0.035972528712591156, 0.15287692949641496, 0.02843827704055002, 0.04145623192016501, 0.07140539732063189, 0.12371349439490587, 0.04542709677480161, 0.09127384837483987, 0.03923916221538093, 0.0769709779706318, 0.05715452178264968, 0.03046300247660838, 0.025411878596059978, 0.04736218004836701, 0.02092131555400556, 0.07431383695802651, 0.04645750203053467, 0.0698183813074138, 0.3253315662732348, 0.4283577832393348, 51.466364935040474, 88.58488976955414, 83.30705657601357, 118.79019096493721, 79.25304651260376, 42.34801322221756, 28.073486387729645, 1.7915050685405731, 0.12267737460206263, 0.17663705453742296, 0.24776753067271784, 5.2365208603441715, 52.440302073955536, 57.06732898950577, 57.71286495029926, 54.32321883738041, 70.7282343506813, 79.80597764253616, 85.35112649202347, 86.70715972781181, 88.348778039217, 85.6709249317646, 86.56543493270874, 87.15265542268753, 86.1853489279747, 81.83072939515114, 84.3700723350048, 83.88379722833633, 81.62899821996689, 81.16583347320557, 81.12911984324455, 78.42064797878265, 77.64281451702118, 76.61598801612854, 73.89334291219711, 71.90719708800316, 66.16380527615547, 55.42485952377319, 44.3118504434824, 35.296670794487, 26.1667126044631, 29.108144268393517, 29.976766258478165, 22.941648960113525, 4.606147035956383, 1.8897541402839124, 3.9779523946344852, 0.22883146943058819, 0.025458819436607882, 0.21977852942654863, 0.07715152023592964, 0.21789813501527533, 0.3581133869010955, 0.06631814569118433, 0.24559811427025124, 0.9072548733092844, 0.49418821174185723, 1.01009386125952, 1.1857985705137253, 1.3042765692807734, 0.6276699726004153, 0.3868836321635172, 0.09707225559395738, 1.3753358437679708, 0.6232247455045581, 0.366844724630937, 0.6520998710766435, 2.8730213223025203, 0.05629108862194698, 0.3188017354113981, 0.06494690911495127, 0.02257534935779404, 0.11193980390089564, 0.2800350578036159, 0.013701689040317433, 0.2499236329458654, 2.018347908742726, 4.303603945299983, 4.821539428085089, 23.115122951567173, 31.45132653415203, 29.196964502334595, 30.307067334651947, 26.802224703133106, 34.04532194137573, 36.84379197657108, 50.48455461859703, 68.99593770503998, 69.3050891160965, 77.32597231864929, 71.51119753718376, 71.0542568564415, 75.62315449118614, 72.60043948888779, 73.31677705049515, 75.88006630539894, 72.45471730828285, 74.75623100996017, 74.25670221447945, 74.5549938082695, 76.57022327184677, 79.30546090006828, 76.41158938407898, 74.1466449201107, 76.51216998696327, 76.54224917292595, 74.92352083325386, 61.05034366250038, 54.81934681534767, 36.42360672354698, 48.016526252031326, 38.4773813188076, 17.337426580488682, 17.4861354008317, 13.341525848954916, 22.875602804124355, 37.819579616189, 35.608417466282845, 72.86975383758545, 53.31788018345833, 53.64359110593796, 51.129961386322975, 1.1880917474627495, 0.10988136084051803, 0.04883148772933055, 0.05022084755182732, 0.09899526412482373, 0.04345793779066298, 0.022437363695644308, 0.05489156137628015, 0.0789530020847451, 0.01737766244332306, 0.015953178626659792, 0.07385873715975322, 0.04245735573931597, 0.02618411665025633, 0.07684332114877179, 0.04953626455971971, 0.08831638246192597, 0.08885219824151136, 0.13665641628904268, 0.017166226425615605, 0.06623016408411786, 0.010389252965978812, 0.03580496661015786, 0.09886771120363846, 0.027785654638137203, 0.08073587086983025, 0.015512253849010449, 0.1068652058893349, 0.07906070255558006, 0.06921482970938087, 0.053564233967335895, 0.013058807326160604, 0.04444442645763047, 0.0763668846047949, 0.020405164832482114, 0.1470356632489711, 0.02883129804104101, 0.0528885678795632, 0.0419134357071016, 0.03523681174556259, 0.03550602952600457, 0.06714569972245954, 0.0377534308063332, 0.06841471287771128, 0.1261298530152999, 0.05120821937453002, 0.02917747839092044, 0.01858323310443666, 0.02521186052035773, 0.015412049997394206, 0.14817586925346404, 0.03909804283466656, 0.6262105540372431, 1.9533798261545599, 80.14014691114426, 102.14184790849686, 103.80748853087425, 121.41131311655045, 75.64422056078911, 63.23024868965149, 36.53032399713993, 0.6689706689212471, 0.3291147679556161, 0.43140996946021914, 0.2663475985173136, 9.819572735577822, 62.80335299670696, 79.25545558333397, 62.95762851834297, 60.99789507687092, 78.13094392418861, 84.53356996178627, 89.49912071228027, 89.84902873635292, 89.51426669955254, 88.52057442069054, 90.39986997842789, 90.26639074087143, 88.47143545746803, 82.95131966471672, 85.79286798834801, 85.43876498937607, 82.63865724205971, 85.50170481204987, 81.10243767499924, 81.5221555531025, 74.56969141960144, 75.41866466403008, 72.58894890546799, 73.94457936286926, 69.28647771477699, 64.2299522459507, 49.78894114494324, 36.124532371759415, 28.162027336657047, 29.69870287925005, 34.08636353909969, 29.751943722367287, 7.464754544198513, 2.363694990053773, 5.744868982583284, 0.27401647763326764, 0.44769138330593705, 0.3160323965130374, 1.0213272459805012, 0.44224128825590014, 0.30724317126441747, 0.5645623651798815, 0.9403931919950992, 1.432526099961251, 0.8010692743118852, 0.05010665699956007, 0.4781125212321058, 0.3654870099853724, 0.9604489314369857, 0.893885112600401, 0.1104749231308233, 2.2216184763237834, 1.870632735081017, 0.15578669757815078, 0.2610511874081567, 3.618685472756624, 0.6269106664694846, 0.28920678596477956, 0.09120450951741077, 0.03641718649305403, 0.101327114389278, 0.14019776688655838, 0.02017168517340906, 0.6161848513875157, 5.234715007245541, 3.427637661807239, 8.910872396081686, 21.92412246018648, 33.590600341558456, 29.736123271286488, 33.00363063812256, 29.253697358071804, 35.72933457791805, 43.32771085202694, 58.87084901332855, 78.61799418926239, 71.98996424674988, 74.65661555528641, 66.7802082002163, 69.1877894103527, 72.95826628804207, 72.22498163580894, 74.37385752797127, 73.76674890518188, 73.14821809530258, 74.70953911542892, 76.33790373802185, 74.88931506872177, 75.61753079295158, 78.32214966416359, 77.83015966415405, 77.2741051018238, 75.90689286589622, 74.13011580705643, 78.03553864359856, 67.39898979663849, 56.29290014505386, 33.96899923682213, 52.03272454440594, 41.70435816049576, 18.908934853971004, 22.397501058876514, 23.471097350120544, 34.28672678768635, 48.26036676764488, 57.547083646059036, 70.15628144145012, 77.60037079453468, 61.746147125959396, 65.42795956134796, 4.857561020180583, 0.02960579779028194, 0.12139626443968154, 0.04741545511933509, 0.07685083168325946, 0.08573330036597326, 0.05989053453959059, 0.09911228597047739, 0.06271588703384623, 0.021924279899394605, 0.04288331881980412, 0.12853524269303307, 0.0732780659745913, 0.016503316001035273, 0.03546180494595319, 0.049855970646603964, 0.08997167606139556, 0.007218120417746832, 0.025406197455595247, 0.04910080569970887, 0.057682778788148426, 0.014274714249040699, 0.010548188529355684, 0.023774238834448624, 0.055071012684493326, 0.1616656649275683, 0.06967571083805524, 0.2435260676429607, 0.1731806353200227, 0.1624099351465702, 0.19022006395971403, 0.2470393353723921, 0.1656867249403149, 0.13116657180944458, 0.09442220209166408, 0.238157193234656, 0.1533448536065407, 0.21200367162236944, 0.22643733071163297, 0.15974650072166696, 0.12457487551728263, 0.14427051006350666, 0.13810872507747263, 0.3217192069860175, 0.19706458027940243, 0.11057597395847552, 0.1829605535021983, 0.10400978528195992, 0.09004419873235747, 0.16544582380447537, 0.274706199998036, 0.15194166015135124, 0.4487227904610336, 0.7934752630535513, 79.22892540693283, 115.7059496641159, 102.16614380478859, 141.7020419239998, 98.43501761555672, 67.58100762963295, 55.31869702041149, 3.2896803645417094, 0.5188939813524485, 1.132910514716059, 0.3010982181876898, 12.539429739117622, 70.89670211076736, 83.57854440808296, 74.55688610672951, 74.02288556098938, 87.76298627257347, 92.84161895513535, 93.91393661499023, 93.99182483553886, 91.42294988036156, 92.00751051306725, 92.09394067525864, 91.74392625689507, 89.6612960100174, 81.85160547494888, 84.24445107579231, 86.44755005836487, 82.1401695907116, 83.40256825089455, 81.62291094660759, 83.85683387517929, 75.48630103468895, 76.92818686366081, 71.53929322957993, 74.40573021769524, 70.87279379367828, 65.18684729933739, 56.10958278179169, 41.67623586952686, 34.3328183144331, 33.05935084819794, 39.9110671877861, 36.969420835375786, 15.769642107188702, 7.411768762394786, 10.537622105330229, 0.17073270573746413, 0.4229184048017487, 0.5266871850471944, 0.9560988773591816, 0.27793382992967963, 0.4151803575223312, 0.6501068186480552, 2.537557748146355, 2.596623203717172, 0.9464253683108836, 1.4589851489290595, 2.9170633340254426, 5.747367823496461, 3.551769875921309, 2.775822300463915, 0.22593580215470865, 4.579408820718527, 3.139538071118295, 0.6617418536916375, 1.750956375617534, 10.975547656416893, 2.502814787440002, 0.8469985972624272, 0.16970306489383802, 0.12323564777034335, 0.23388144298223779, 0.23288708383915946, 0.0752452619781252, 0.26053112000226974, 9.218542836606503, 4.44092477671802, 9.63603213429451, 34.69727195799351, 38.420076593756676, 35.72248734533787, 39.295173436403275, 35.111742317676544, 42.76501804590225, 48.563073724508286, 62.06127181649208, 78.81316691637039, 70.72100713849068, 75.52097797393799, 71.94644898176193, 70.45321270823479, 78.03767412900925, 73.29989835619926, 74.12012234330177, 74.35669764876366, 74.14824083447456, 74.95526432991028, 79.39391255378723, 75.53749188780785, 77.76037260890007, 81.01330205798149, 77.33813926577568, 79.01517167687416, 78.85948643088341, 77.55196899175644, 80.81331878900528, 74.8939660191536, 67.93742090463638, 49.440245255827904, 64.90219697356224, 50.12769676744938, 23.42233646661043, 23.81127029657364, 30.70942774415016, 42.397581562399864, 46.997990906238556, 57.81276538968086, 91.76553189754486, 86.14647701382637, 81.95893451571465, 62.60963559150696, 2.803707579150796, 0.21483987802639604, 0.2013778089894913, 0.11179386798175983, 0.11623251222772524, 0.12064976777764969, 0.2519631735049188, 0.22286592313321307, 0.2263485550065525, 0.13944453152362257, 0.12036053798510693, 0.19846861978294328, 0.16370257828384638, 0.15151068015256897, 0.25181370496284217, 0.15556863974779844, 0.23656966513954103, 0.12592476792633533, 0.1984011140302755, 0.16969785501714796, 0.25363487598951906, 0.11901719131856225, 0.10978246224112809, 0.1516110185184516, 0.09282377184717916], [0.017044054075086024, 0.06379102895152755, 0.02524782499676803, 0.0071778987967263674, 0.04204463628411759, 0.027042325091315433, 0.09797536025871523, 0.02702312387555139, 0.026894771290244535, 0.04756582166010048, 0.07059713170747273, 0.07756046587019227, 0.05057980211859103, 0.03762850879866164, 0.07324826874537393, 0.10748050568508916, 0.08795097121037543, 0.052880014627589844, 0.028224731468071695, 0.03660040420072619, 0.04662140163418371, 0.08421439866651781, 0.14578216098016128, 0.03284487349446863, 0.03886811435222626, 0.11395093504688703, 0.04965499334502965, 0.5695162306074053, 1.5078645385801792, 12.559647504240274, 96.56084418296814, 82.17176109552383, 105.43044984340668, 109.26424652338028, 51.565288826823235, 39.22881759703159, 15.616201590746641, 2.4551577446982265, 0.13446020835544914, 0.29695658886339515, 1.9574232841841877, 23.90366043895483, 46.33603982627392, 46.253234669566154, 59.879542887210846, 65.4069846868515, 72.34950855374336, 87.0197157561779, 85.3166775405407, 88.4415690600872, 84.19373899698257, 85.21738886833191, 84.52044546604156, 88.18927019834518, 80.43134808540344, 84.04448300600052, 81.98810935020447, 88.12183901667595, 83.94407719373703, 83.93506407737732, 80.73010325431824, 82.83395156264305, 76.5337148308754, 73.01315814256668, 73.53084996342659, 64.10006001591682, 49.762372970581055, 41.947719901800156, 30.90692024677992, 31.51993565261364, 29.270952232182026, 34.91222262382507, 20.184699296951294, 4.982357248663902, 1.7363824951462448, 9.300817921757698, 1.883342934306711, 0.7062546839006245, 0.3467196092242375, 1.591895604506135, 0.985602691071108, 0.7849010825157166, 0.42117251723539084, 0.09622001030948013, 1.0228994116187096, 0.3323438228107989, 0.8055348659399897, 0.7529317948501557, 0.054001952667022124, 0.04144840226217639, 0.6489775667432696, 0.3099026426207274, 0.42038373299874365, 0.4052640177542344, 0.4745660943444818, 0.047379720708704554, 0.7871129200793803, 0.1904989333706908, 0.4366034595295787, 0.2921327773947269, 0.5304449459072202, 0.17769571335520595, 0.5817201070021838, 0.43686276592779905, 1.301090915221721, 2.9972699051722884, 4.669027486816049, 18.470307290554047, 22.31556985527277, 19.553824849426746, 26.809094734489918, 33.32460701465607, 29.642995968461037, 38.55933532118797, 38.03245559334755, 42.591500356793404, 55.52753381431103, 69.55422654747963, 70.04190757870674, 73.07648554444313, 73.32536458969116, 75.19114807248116, 72.75638312101364, 74.27522242069244, 74.36669871211052, 77.15219244360924, 73.84327679872513, 78.0272550880909, 70.88888972997665, 81.16090133786201, 78.31740751862526, 72.4887102842331, 72.13545843958855, 78.57625722885132, 78.79959404468536, 68.2196393609047, 56.77493467926979, 46.19802363216877, 51.22827351093292, 50.63071757555008, 21.896427646279335, 24.555124081671238, 16.19237322360277, 18.466893173754215, 27.75254800915718, 39.48954440653324, 69.07718494534492, 68.75272035598755, 42.925213649868965, 59.25603814423084, 12.783270254731178, 0.11182349451701157, 0.16291441745124757, 0.027255898494331632, 0.07864979022997431, 0.1420833118027076, 0.0905588484602049, 0.024623248355055694, 0.07435278486809693, 0.13607807544758543, 0.004721238774436642, 0.054994111342239194, 0.04168099876551423, 0.051237467414466664, 0.03015654187038308, 0.024231327588495333, 0.005218238375164219, 0.1053506754396949, 0.003926532199329813, 0.08418958124821074, 0.06533704872708768, 0.10175551171414554, 0.005635580946545815, 0.09340001983218826, 0.008760848304518731, 0.06057800448616035, 0.023338080500252545, 0.05614228801277932, 0.0287690207187552, 0.04107517619559076, 0.019336088116688188, 0.017714688401611056, 0.066938707313966, 0.03663928902824409, 0.023456731360056438, 0.04024423426017165, 0.035338170564500615, 0.04564364062389359, 0.03347577694512438, 0.044480624710558914, 0.012832952306780498, 0.12388283765176311, 0.05420648114522919, 0.0228550388419535, 0.02551377361669438, 0.07881740428274497, 0.038232090082601644, 0.08721421894733794, 0.054886574143893085, 0.056106457122950815, 0.018787281042023096, 0.027599357017606962, 0.00903788275536499, 0.352174483705312, 0.46557470806874335, 28.83127212524414, 105.48585847020149, 91.22536048293114, 122.16591462492943, 101.56304016709328, 60.71350693702698, 62.68825337290764, 21.56412597745657, 1.3582219183444977, 0.3261651168577373, 0.16088868083897978, 2.612631982192397, 31.718387603759766, 53.70721109211445, 63.83739531040192, 66.02753698825836, 74.16296124458313, 76.53461918234825, 90.2394425868988, 87.06111073493958, 90.3275066614151, 85.29263243079185, 90.73451042175293, 87.7165375649929, 90.66403940320015, 85.77455297112465, 90.58448687195778, 84.97498467564583, 87.38224670290947, 84.4174025952816, 84.91638422012329, 79.71108913421631, 79.71523091197014, 75.84074601531029, 75.29130309820175, 75.04734098911285, 70.53182289004326, 54.744042456150055, 51.81175880134106, 33.642676547169685, 32.77926027774811, 30.82220569252968, 37.35196530818939, 27.57654145359993, 9.32898486033082, 5.172568866983056, 9.678754191845655, 4.976891241967678, 1.87949457205832, 0.3824805887416005, 0.3533709148177877, 0.43490129930432886, 0.39975443214643747, 0.17544725822517648, 0.47847299720160663, 1.329601735342294, 1.7136519961059093, 1.5186756709590554, 3.4971974417567253, 0.14753342169569805, 0.1980689138872549, 0.16963037895038724, 0.2870418521342799, 0.20013992150779814, 3.834235081449151, 1.2296572420746088, 0.16758219979237765, 1.4263977413065732, 0.5765531561337411, 0.8296370320022106, 0.3511051379609853, 0.7395884545985609, 0.07197023107437417, 0.6465928978286684, 0.21836267493199557, 3.747106706723571, 5.825690170750022, 5.2445845026522875, 33.885525315999985, 35.137930512428284, 31.346170976758003, 27.81513635069132, 34.81513403356075, 31.803480237722397, 39.25242193043232, 41.00154407322407, 51.49927876889706, 67.85541370511055, 69.78412181138992, 67.61568456888199, 70.01642614603043, 70.89340388774872, 73.86457845568657, 76.32278814911842, 75.63751772046089, 73.51663112640381, 76.78889393806458, 74.049833714962, 76.92974478006363, 71.49161338806152, 78.85254040360451, 78.36694926023483, 76.63459181785583, 74.876479357481, 77.6050217449665, 80.33873945474625, 70.89187636971474, 59.78007182478905, 44.83860857784748, 42.19150722026825, 52.368664517998695, 25.894310921430588, 30.915405191481113, 31.615869104862213, 36.85022883117199, 40.92696167528629, 56.28964751958847, 63.36479566991329, 80.17768889665604, 61.76411256194115, 66.1699229478836, 22.57879503071308, 0.15838304185308516, 0.04335786659794394, 0.07407436816720292, 0.07941881849546917, 0.015103965015441645, 0.13135147048160434, 0.06092124407587107, 0.09391844709170982, 0.05675028507539537, 0.025068121358344797, 0.05172285054868553, 0.01776773340679938, 0.015340312147600343, 0.08051353826886043, 0.037914751446805894, 0.05819756210257765, 0.0816386638325639, 0.020393353552208282, 0.1819477742537856, 0.08471430192003027, 0.06865154704428278, 0.07573264520033263, 0.010530296276556328, 0.056755135010462254, 0.03502524770738091, 0.14318314497359097, 0.14797906653257087, 0.13473590137436986, 0.09508862844086252, 0.15454459469765425, 0.11188061762368307, 0.1410971162840724, 0.14628014207119122, 0.2474003456882201, 0.13757713953964412, 0.11443661132943816, 0.1876424514921382, 0.13230515993200243, 0.13429162208922207, 0.17995188682107255, 0.21794270840473473, 0.2075003195204772, 0.25324020185507834, 0.21492595231393352, 0.30901818070560694, 0.1795221387874335, 0.20299088180763647, 0.30257820908445865, 0.15025024622445926, 0.1680626958841458, 0.21852176170796156, 0.17364288942189887, 0.7068769598845392, 1.6837997292168438, 23.165563344955444, 125.55047661066055, 103.59060376882553, 132.56952077150345, 127.19834938645363, 74.12724316120148, 68.17637488245964, 42.97571673989296, 3.654379094950855, 0.8169406070373952, 0.3624056722037494, 3.0484191980212927, 42.99766816198826, 65.67997723817825, 63.96469607949257, 78.49523797631264, 85.21252512931824, 87.71235018968582, 97.2221226990223, 90.52837908267975, 93.27928707003593, 88.54357838630676, 93.04765909910202, 88.98022055625916, 91.2014901638031, 84.14354369044304, 87.7785350382328, 85.05578354001045, 86.46881371736526, 83.25078159570694, 83.86957839131355, 82.38794669508934, 80.19559353590012, 77.08983778953552, 74.05589058995247, 75.3888438642025, 69.89563062787056, 57.40081809461117, 56.08148328959942, 40.019270181655884, 39.02999706566334, 38.80131393671036, 43.88916492462158, 33.8837394118309, 17.659590393304825, 11.17929082363844, 21.456745639443398, 6.450671134516597, 6.4650799613446, 0.7103417802136391, 3.5881137382239103, 1.8560915091075003, 1.228353912010789, 0.9233715897426009, 1.832549397367984, 8.81449056789279, 1.9516228954307735, 1.3193995202891529, 5.559317339211702, 0.17664615326793864, 0.47372990171425045, 1.5571357822045684, 0.5634831637144089, 0.7893811608664691, 4.412021152675152, 1.0048221191391349, 0.27613150945398957, 6.629075361415744, 1.8072077259421349, 0.7370690710376948, 0.9036141342949122, 1.246439041569829, 0.2062333101639524, 1.074714856222272, 0.6062285543885082, 1.7963024298660457, 10.113219078630209, 3.809362566098571, 36.611647233366966, 29.740306846797466, 22.652374282479286, 31.323347501456738, 38.642311468720436, 37.590546905994415, 45.353997722268105, 48.79829250276089, 54.64895635843277, 66.08080253005028, 71.31728634238243, 69.43656966090202, 73.65600764751434, 70.37306740880013, 77.4559785425663, 77.47823014855385, 77.45954275131226, 76.58142507076263, 81.79688081145287, 76.3375997543335, 82.24347084760666, 71.09463348984718, 81.57690301537514, 79.66546878218651, 76.8425090610981, 77.66454175114632, 81.6012293100357, 81.93367347121239, 77.84272938966751, 69.14517849683762, 59.853901863098145, 58.743286058306694, 67.94490650296211, 36.11973702907562, 34.80591952800751, 42.07325756549835, 41.40660233795643, 34.649763107299805, 57.20774285495281, 86.71701639890671, 92.85297274589539, 78.74778002500534, 75.50159901380539, 17.80179586261511, 0.17448733473429456, 0.19122049387078732, 0.22719288157531992, 0.18974373873788863, 0.15105378435691819, 0.2527995442505926, 0.25803738506510854, 0.31230209511704743, 0.18163988686865196, 0.13623242732137442, 0.19533328333636746, 0.2214886454748921, 0.14790225424803793, 0.24454917758703232, 0.0844451694865711, 0.21191381238168105, 0.24836941243847832, 0.14196551812347025, 0.24127261043759063, 0.18832481175195426, 0.19516350963385776, 0.16415418998803943, 0.20372789382236078, 0.16646942356601357, 0.1521386409876868], [0.07413114988594316, 0.02482271724147722, 0.03405000257771462, 0.03572525623894762, 0.014311832765088184, 0.020711120778287295, 0.11553707532584667, 0.08137271521263756, 0.042291741774533875, 0.0160560681251809, 0.09575204167049378, 0.03742483379028272, 0.08683430613018572, 0.08131631941068918, 0.07086803045240231, 0.08432712347712368, 0.17501093476312235, 0.08526655627065338, 0.09925053323968314, 0.03815736694377847, 0.11328869441058487, 0.03903638520569075, 0.02202597268478712, 0.04689440807851497, 0.05612290682620369, 0.01887710503069684, 0.03588576793845277, 0.16486316366354004, 0.2723232825519517, 0.9976615221239626, 74.59768071770668, 86.4874555170536, 84.86696407198906, 112.3485866189003, 91.6577772796154, 33.8725908100605, 35.84677867591381, 11.486032214015722, 2.275008223950863, 1.6714701033197343, 1.2350870319642127, 12.913078889250755, 51.95753037929535, 49.91531856358051, 50.034882947802544, 65.88086485862732, 71.66523367166519, 81.7380903661251, 86.55141368508339, 90.08531525731087, 87.53746077418327, 85.7551284134388, 87.6451849937439, 87.15937346220016, 87.16593950986862, 83.85352805256844, 86.22229814529419, 85.883067548275, 81.34925723075867, 81.01450279355049, 80.61642095446587, 77.90255337953568, 74.87413868308067, 76.05455294251442, 69.53167855739594, 56.03750064969063, 41.60927206277847, 35.63643716275692, 38.15437585115433, 27.893569841980934, 34.80098359286785, 33.4308797121048, 24.01557583361864, 2.2080099815502763, 4.1060881689190865, 7.12643257342279, 2.7109740301966667, 0.25430423382204026, 0.08202075856388547, 0.09603596510714851, 0.19725121557712555, 0.05550590009079315, 0.030336800264194608, 0.03899842435203027, 0.06477631904999726, 0.06366491579683498, 0.028545200111693703, 0.4050557711161673, 0.11860381506267004, 0.08845362041029148, 0.10309271339792758, 0.042541051443549804, 0.6173498451244086, 7.902046479284763, 1.2433900614269078, 0.28761775873135775, 0.16798465163446963, 1.4396726852282882, 1.2608876475133002, 0.4613252595299855, 0.05209288538026158, 0.4219336045207456, 0.06620050044148229, 0.5767151818145066, 1.1074732546694577, 1.8942962028086185, 5.859205322340131, 8.871422912925482, 9.156948141753674, 22.541555128991604, 28.276194110512733, 31.26117143779993, 30.526258572936058, 38.84598433971405, 42.203997150063515, 31.41834430396557, 44.03250463306904, 65.45030236244202, 70.08072629570961, 71.94048330187798, 70.31179949641228, 70.80502063035965, 71.42605930566788, 71.92291304469109, 71.44975483417511, 74.98919650912285, 79.26927164196968, 76.84336021542549, 77.33392909169197, 80.5179150402546, 76.82474121451378, 73.6037528514862, 81.58454820513725, 80.91035038232803, 68.73957306146622, 66.82705208659172, 53.331434056162834, 51.530285105109215, 66.07308134436607, 36.09792239964008, 29.560270607471466, 17.19451054930687, 17.92793769389391, 27.729287557303905, 46.346652656793594, 72.55715981125832, 71.39746204018593, 36.38364426791668, 55.979941338300705, 29.920922555029392, 0.280724631738849, 0.03187844136846252, 0.011020220426871674, 0.0690363728790544, 0.132801849686075, 0.21110637055244297, 0.043158577682334, 0.11836527395644225, 0.09902808931656182, 0.055462577220168896, 0.1221849002467934, 0.03514862233714666, 0.06926801201188937, 0.08020505716558546, 0.030529831019521225, 0.07078896946040913, 0.04102066173800267, 0.14573415886843577, 0.05349806779122446, 0.04100178150110878, 0.03463688924966846, 0.03592604800360277, 0.043764734218711965, 0.13103803183184937, 0.04436520590388682, 0.056046198442345485, 0.08245894481660798, 0.025730697816470638, 0.06812260355218314, 0.05130730351083912, 0.022216246361494996, 0.04690882429713383, 0.10441409249324352, 0.04603663008310832, 0.035881433796021156, 0.032871883959160186, 0.12799990188796073, 0.001331116304754687, 0.09428248537005857, 0.06629720228374936, 0.05182029453862924, 0.03765891458897386, 0.047186265073833056, 0.02624860000651097, 0.11407760481233709, 0.0770735576224979, 0.047280432481784374, 0.023985368716239464, 0.09736711828736588, 0.03414974351471756, 0.0629573967307806, 0.014682728487969143, 0.11096946807811037, 0.19099640980130062, 0.5238803825341165, 3.6663180543109775, 93.57024505734444, 95.73479130864143, 102.41728752851486, 118.60189586877823, 86.4227905869484, 57.926842868328094, 58.27715367078781, 16.986788995563984, 1.7306951503269374, 1.4208775875158608, 1.2651189579628408, 13.527438472956419, 58.357796743512154, 53.17838206887245, 62.206899002194405, 77.57659167051315, 76.67471766471863, 85.70415034890175, 86.98269814252853, 90.04944518208504, 90.59800654649734, 86.67290076613426, 89.22947958111763, 87.75822132825851, 88.39499115943909, 85.76330557465553, 85.83322942256927, 88.5480697453022, 87.61246114969254, 83.6643286049366, 81.35097473859787, 79.94524016976357, 73.62768396735191, 76.50178134441376, 73.65549087524414, 61.60988263785839, 52.147371992468834, 42.7210696041584, 40.2353759855032, 29.681273214519024, 36.11830070614815, 37.090432941913605, 25.389300920069218, 8.350135535001755, 6.321576861664653, 6.914552142843604, 6.987617947161198, 0.039389892408507876, 0.19244935683673248, 0.10458289398229681, 0.15945079940138385, 0.08046723567531444, 0.09049397733178921, 0.2135235455352813, 0.18258406198583543, 0.2205334568861872, 0.1283597989822738, 0.8468685729894787, 0.1595941378036514, 0.019907783025701065, 0.14171436050673947, 0.11398745613405481, 0.9861278941389173, 10.147772524505854, 2.0429418515414, 0.2654105331748724, 0.19100120407529175, 1.92366257077083, 1.0643891477957368, 1.5244506485760212, 0.10155692783882841, 0.30482225585728884, 0.07004580504144542, 0.17021853098412976, 2.76670896448195, 2.54869447555393, 17.660646736621857, 21.28964200615883, 17.03558597713709, 28.682755194604397, 33.10103461146355, 39.11461092531681, 35.26612803339958, 40.575860515236855, 49.593878611922264, 41.247580870985985, 56.33532106876373, 70.87665438652039, 67.66819775104523, 70.82463517785072, 68.45470994710922, 70.49929663538933, 73.70111882686615, 73.74119907617569, 73.24906468391418, 75.01362159848213, 77.94847011566162, 77.79412999749184, 77.96615436673164, 82.13689416646957, 81.93535298109055, 78.94400909543037, 78.51900950074196, 79.674291908741, 74.65648636221886, 70.82599550485611, 49.74647082388401, 47.49288395047188, 62.62647248804569, 42.85748988389969, 44.77453641593456, 37.12373435497284, 36.41050882637501, 41.31172522902489, 58.20944890379906, 69.08388778567314, 75.84309428930283, 68.47591280937195, 56.05176128447056, 45.29787853360176, 1.7393753095529974, 0.02070862345135538, 0.14750511618331075, 0.11831552779767662, 0.10962899352307431, 0.022092203798820265, 0.1073448485112749, 0.04978870609193109, 0.1309413745184429, 0.07672341977013275, 0.03777533529500943, 0.034668181906454265, 0.04907434071355965, 0.03106761163508054, 0.019280607011751272, 0.04305468813981861, 0.0516656458057696, 0.06084330001613125, 0.08853181308950298, 0.058914758774335496, 0.017484515010437462, 0.03604645033192355, 0.04965837382769678, 0.09127559984335676, 0.0651874762843363, 0.030101357624516822, 0.16078914399258792, 0.18967029580380768, 0.14103715075179935, 0.17331882321741432, 0.16154303244547918, 0.14079378568567336, 0.18545268540037796, 0.12969363131560385, 0.1060821139253676, 0.15148405189393088, 0.3026597265852615, 0.15199408546322957, 0.17705852020299062, 0.17068701912648976, 0.14298448688350618, 0.1184813458530698, 0.27811271720565856, 0.20380418660352007, 0.2659004396991804, 0.12741017650114372, 0.17014940734952688, 0.18428991810651496, 0.08442782549536787, 0.1488030730979517, 0.2340384220588021, 0.13278144062496722, 0.1576239732094109, 0.2918558969395235, 0.3653472487349063, 1.5593649563379586, 101.66403874754906, 107.50280544161797, 109.67727676033974, 135.83029299974442, 116.87058717012405, 58.33233430981636, 68.76516088843346, 36.165247187018394, 4.437222350388765, 1.9343455787748098, 1.3408099464140832, 18.53109832853079, 82.567388266325, 67.62285858392715, 67.73090198636055, 88.80827218294144, 88.85470569133759, 94.46702733635902, 91.83174714446068, 96.12911134958267, 94.01653110980988, 90.42241796851158, 89.60917040705681, 87.34198406338692, 89.26549404859543, 86.74958065152168, 87.5484573841095, 86.78512394428253, 85.24840280413628, 84.58190336823463, 84.40907344222069, 78.45537811517715, 74.59581881761551, 75.85620358586311, 73.63466799259186, 64.37708795070648, 52.33555689454079, 48.423966988921165, 48.87370705604553, 32.66025826334953, 47.72788994014263, 39.01162125170231, 35.74202969670296, 11.081198137253523, 14.174113422632217, 17.935094609856606, 7.981386221945286, 0.4630148329306394, 0.2442662708926946, 0.3247328015277162, 0.44712824164889753, 0.23736987845040858, 0.19421283330302685, 0.2444533514790237, 0.5433266703039408, 0.18071512633468956, 0.21204655291512609, 1.0732088307850063, 0.3191243321634829, 0.1624178167548962, 0.18987233808729798, 0.36496097571216524, 2.4106291215866804, 20.141790099442005, 2.4105521757155657, 0.6118867476470768, 0.4865442094160244, 6.351500255987048, 3.263853150419891, 3.701378060504794, 0.19550209224689752, 0.8133998501580209, 0.20046156831085682, 1.3070295215584338, 5.039480058476329, 7.863417277112603, 12.343047726899385, 19.885965026915073, 14.60215475410223, 27.312106043100357, 34.40380610525608, 37.80588895082474, 38.339992091059685, 47.32872895896435, 58.21658872067928, 43.25283966958523, 58.676185458898544, 71.4473457634449, 75.598334223032, 73.60783383250237, 73.73123601078987, 75.67356258630753, 77.45036244392395, 75.90607210993767, 76.12526714801788, 78.56215238571167, 79.88207995891571, 78.23515713214874, 77.72194147109985, 82.97983333468437, 81.75225600600243, 77.44053617119789, 84.97223362326622, 80.26947677135468, 77.60531052947044, 81.06046512722969, 64.9843941628933, 57.84784510731697, 81.52637332677841, 58.03062669932842, 48.22390392422676, 39.33904588222504, 36.695322543382645, 40.01792125403881, 62.84774221479893, 92.83062234520912, 93.36523845791817, 75.23583367466927, 73.43461632728577, 40.5555734038353, 0.6412753800395876, 0.17147820792160928, 0.22178281797096133, 0.15405790909426287, 0.24472441349644214, 0.24225999339250848, 0.2738625858910382, 0.21358922560466453, 0.2574626659043133, 0.16321209288435057, 0.17301835730904713, 0.130315417482052, 0.18721512285992503, 0.1316453015897423, 0.08598231317591853, 0.16103708068840206, 0.17011206247843802, 0.20759497303515673, 0.15265666006598622, 0.15908597444649786, 0.10498317133169621, 0.11135561493574642, 0.17025894834659994, 0.3196509601548314, 0.17714710294967517, 0.11928217514650896], [0.025896543702401686, 0.03596081762225367, 0.02671737202035729, 0.009075966991076712, 0.09168949560262263, 0.07363587021245621, 0.09273996853153221, 0.0525482226657914, 0.09836310273385607, 0.030579977938032243, 0.1200082701689098, 0.1800479504163377, 0.09091881976928562, 0.042576730193104595, 0.05466748101753183, 0.05309877378749661, 0.14638742693932727, 0.0939987029414624, 0.04740581462101545, 0.04371120681753382, 0.10812750260811299, 0.018540797100286, 0.058786586159840226, 0.12806589365936816, 0.06375550976372324, 0.03580568649340421, 0.02417580381006701, 0.1611979040899314, 0.2411109409877099, 0.7878630235791206, 18.086233399808407, 99.70956042408943, 74.75672498345375, 100.60810580849648, 111.85712099075317, 75.96439138054848, 35.065548196434975, 28.88345092535019, 9.578735008835793, 5.553375408053398, 4.800585452467203, 7.38585795275867, 38.49455639719963, 69.25993993878365, 58.26178729534149, 57.70752623677254, 64.69885468482971, 73.7637622654438, 83.68487030267715, 90.94278484582901, 94.0023122727871, 85.91424107551575, 85.8618874847889, 90.28224349021912, 89.22228276729584, 83.8089108467102, 81.24959617853165, 89.65344563126564, 88.6927355825901, 86.6711376607418, 82.61793315410614, 82.5588995218277, 76.94253489375114, 73.49735856056213, 65.35006374120712, 53.89251194894314, 25.441941395401955, 34.90762107074261, 36.40404537320137, 34.22243043780327, 39.64655578136444, 26.220764704048634, 24.152630679309368, 3.7129225535318255, 4.398944629356265, 1.8334479304030538, 0.7513110630679876, 0.09416199769475497, 0.0644832375110127, 0.08952339660027064, 0.036290542702772655, 0.16446693101897836, 0.007512537822549348, 0.17448880418669432, 0.21716302289860323, 0.24958055291790515, 0.05874974965990987, 0.14104106929153204, 0.022758116210752632, 0.19290142867248505, 0.4236140049761161, 0.30858791316859424, 1.739351679570973, 3.905708296224475, 2.797983423806727, 0.4655314260162413, 2.9939590953290462, 1.2256059469655156, 1.700593640562147, 0.22187462163856253, 0.5486169958021492, 0.4317459842422977, 0.49842655775137246, 0.1747594802873209, 1.0394409927539527, 1.2546214275062084, 1.8868054985068738, 2.289088130928576, 15.190457236021757, 28.665507920086384, 34.75997619330883, 29.958551935851574, 29.33309979736805, 50.1083330065012, 32.290059328079224, 20.55353220552206, 30.160761885344982, 47.72678039968014, 66.87566667795181, 62.924650087952614, 70.68420231342316, 71.07682764530182, 68.82321417331696, 70.0739398598671, 74.29409220814705, 81.66040733456612, 76.27750977873802, 78.91738772392273, 79.67473268508911, 79.93942648172379, 74.62991818785667, 81.04575231671333, 84.33325231075287, 74.62992578744888, 68.91010031104088, 56.125530526041985, 57.0204509049654, 61.94790489971638, 38.292468041181564, 37.43461087346077, 19.982935823500156, 11.355229932814837, 23.503161929547787, 42.67850048840046, 75.7414573431015, 68.66486147046089, 37.483347058296204, 46.86960719525814, 38.96842136979103, 3.107017516158521, 0.008933535864343867, 0.03469501796644181, 0.10411635026684962, 0.09797270337003283, 0.08750091059482656, 0.20380779344122857, 0.01285993957935716, 0.055945871208678, 0.0636183682945557, 0.05352142688934691, 0.1250090467510745, 0.16186923603527248, 0.20515149633865803, 0.2201676819822751, 0.030940364849811886, 0.011288601435808232, 0.08392228934098966, 0.08405110391322523, 0.06711928668664768, 0.040635424011270516, 0.045320123608689755, 0.03213516880350653, 0.07486318208975717, 0.03534536939696409, 0.030473752485704608, 0.02171005711716134, 0.0159191159036709, 0.0378605932201026, 0.0648244473268278, 0.06531990511575714, 0.19543446775060147, 0.04945075430441648, 0.08080624131252989, 0.0428127220220631, 0.15720069670351222, 0.04156300470640417, 0.07748585034278221, 0.14001065661432222, 0.07652440544916317, 0.04329656519985292, 0.0473024705570424, 0.005976514312351355, 0.05102015915326774, 0.0678104191320017, 0.05894689747947268, 0.04095034695637878, 0.061994033385417424, 0.03146627852402162, 0.13027793902438134, 0.18509347108192742, 0.014389752705028513, 0.06634196121012792, 0.06729219225235283, 0.07871923298807815, 0.4390013386728242, 0.6730162643361837, 36.847610771656036, 100.42983457446098, 90.36761730909348, 119.17249605059624, 107.72337600588799, 69.94145616889, 62.596454098820686, 58.589413315057755, 23.248556591570377, 9.293052088469267, 4.647966166958213, 8.784917704761028, 39.2875662446022, 74.67923194169998, 64.67434599995613, 72.3077791929245, 75.63412070274353, 80.56580007076263, 85.88674575090408, 91.26890614628792, 91.75497606396675, 84.54383701086044, 88.79909947514534, 96.69862478971481, 94.58887919783592, 87.75372996926308, 84.39703568816185, 92.93896973133087, 89.04678538441658, 85.45282423496246, 81.55652090907097, 82.8627236187458, 76.19569256901741, 79.31193575263023, 73.37510392069817, 61.29699222743511, 37.39318549633026, 42.414467856287956, 43.88210490345955, 37.83471800386906, 43.2574488222599, 26.898169554769993, 29.020047895610332, 7.428965689614415, 10.67621111869812, 4.057058924809098, 5.477101625874639, 0.0721635011723265, 0.13131290848832577, 0.11019839148502797, 0.053047354085720144, 0.09649922110838816, 0.10439507124829106, 0.22467704548034817, 0.4777642758563161, 0.3519664448685944, 0.11252038602833636, 0.38235374086070806, 0.01826497606089106, 0.28010131674818695, 0.2389683754881844, 0.5674317455850542, 0.0665695259522181, 2.6986724277958274, 3.214020486921072, 0.7968595158308744, 2.2068071085959673, 4.684902084991336, 1.200214996933937, 0.645402492955327, 0.35520968958735466, 0.1257522334344685, 0.7043568044900894, 0.18187928886618465, 0.41716245585121214, 2.721842871978879, 10.209556259214878, 10.709204748272896, 14.139783214777708, 24.186205677688122, 31.53673455119133, 29.750953875482082, 33.53214427828789, 42.965328097343445, 42.89676837623119, 40.89180216193199, 41.378601640462875, 56.37373700737953, 68.50427448749542, 64.29908573627472, 70.94468593597412, 75.64168989658356, 72.17388957738876, 74.6721339225769, 75.90371623635292, 80.43250322341919, 77.77475863695145, 79.35824006795883, 77.79926732182503, 80.90434670448303, 80.18974184989929, 78.29636424779892, 82.80944287776947, 78.57142388820648, 71.27619534730911, 55.53118921816349, 56.25568874180317, 55.56703269481659, 45.721589997410774, 59.8674101382494, 42.586389631032944, 28.213761560618877, 37.627822905778885, 56.932474225759506, 76.33343517780304, 74.63844493031502, 74.00565728545189, 49.71663102507591, 50.636725053191185, 7.931147217750549, 0.19732859189389274, 0.05630115956591908, 0.09829048358369619, 0.0803723001445178, 0.12002858275081962, 0.10410458722617477, 0.03022483429958811, 0.09734748105984181, 0.1034033318865113, 0.06906212540343404, 0.05688573815859854, 0.15541293716523796, 0.09020888872328214, 0.0787246209802106, 0.024434841179754585, 0.05134899736731313, 0.03908927807060536, 0.05017462659452576, 0.042139389988733456, 0.0789937905210536, 0.01249287519385689, 0.049782364440034144, 0.04956502278218977, 0.027029827324440703, 0.02310733008926036, 0.01362260114547098, 0.2348478528438136, 0.1418261873186566, 0.20913038752041757, 0.21964106883388013, 0.39497283403761685, 0.1327821085578762, 0.16420179134001955, 0.09894669798086397, 0.329050705768168, 0.163389184162952, 0.1295575956464745, 0.17308762937318534, 0.19215138454455882, 0.1415697010816075, 0.192950529162772, 0.1661030697869137, 0.14652171113993973, 0.2574188495054841, 0.18790405854815617, 0.14167388377245516, 0.22877110313856974, 0.0901137082837522, 0.25314879894722253, 0.35573676286730915, 0.14305591117590666, 0.4374213359551504, 0.10858982350328006, 0.22558835829840973, 0.5821797635871917, 0.8874384022783488, 24.618954956531525, 126.48807629942894, 94.0213568508625, 128.30344408750534, 128.24241936206818, 104.62170124053955, 65.55266886949539, 75.1134118437767, 41.89302943646908, 13.91216117888689, 6.042555458843708, 9.707136768847704, 52.57163442671299, 103.45597699284554, 83.32036346197128, 79.56720605492592, 85.28235778212547, 88.2447624206543, 93.80244299769402, 95.34992516040802, 96.83360114693642, 90.26188418269157, 92.78804183006287, 95.8417783677578, 97.2637152671814, 87.89646551012993, 83.73786985874176, 91.37786909937859, 89.46051478385925, 84.83838200569153, 81.94479167461395, 82.30919972062111, 77.03575149178505, 77.91259244084358, 73.83048668503761, 62.01817072927952, 34.46264214813709, 52.19805747270584, 48.321904465556145, 41.94026470184326, 53.40777575969696, 28.7278625741601, 35.43823219835758, 10.975452661514282, 21.42056778073311, 11.173670925199986, 6.693365536630154, 0.15787584328791127, 0.23540112393675372, 0.22621928772423416, 0.08263819574494846, 0.3802244004327804, 0.17170064442325383, 0.2818250883137807, 0.9468568826559931, 0.5400537396781147, 1.2402285123243928, 0.524311006302014, 0.0823143744491972, 0.7817359711043537, 0.47692553023807704, 0.9268785640597343, 3.806203748099506, 11.954703815281391, 7.855607746168971, 1.3510207110084593, 6.693506129086018, 13.881419878453016, 2.9166161455214024, 0.71738725528121, 0.7821231347043067, 0.4330922698136419, 1.216133174020797, 0.41156250634230673, 1.0752429091371596, 3.781222701072693, 6.134213665500283, 8.856780398637056, 21.264496855437756, 32.50281371176243, 37.645951732993126, 29.423223361372948, 34.74535457789898, 60.91513551771641, 42.93131232261658, 33.71567443013191, 46.98314890265465, 59.22934077680111, 77.11575239896774, 68.62985014915466, 73.23711052536964, 78.85837689042091, 73.17425429821014, 76.1048774421215, 80.26773646473885, 82.45870649814606, 78.58201771974564, 80.46433791518211, 79.06773805618286, 82.25963518023491, 80.89619994163513, 81.12188503146172, 84.9628709256649, 81.31314396858215, 78.07649284601212, 67.97373175621033, 66.6677874326706, 69.9923886358738, 62.71248087286949, 63.7789848446846, 42.597127854824066, 24.570315666496754, 33.59994404017925, 60.45393526554108, 87.69414156675339, 89.53502118587494, 80.5927786231041, 69.81458857655525, 51.36350065469742, 4.233000408858061, 0.2546789590269327, 0.15831286436878145, 0.2578223106684163, 0.13501686364179477, 0.15678594005294144, 0.24898293107980862, 0.11020617661415599, 0.13134655746398494, 0.27664353197906166, 0.18927805591374636, 0.28532033669762313, 0.3022511297604069, 0.4243154829600826, 0.2642667054897174, 0.15768546756589785, 0.1566584687680006, 0.18572028900962323, 0.1945608708774671, 0.31541985750664026, 0.1547033549286425, 0.16260186937870458, 0.11788306350354105, 0.14387564297067001, 0.10835765744559467, 0.10423736486700363, 0.19208110315958038], [0.060500476029119454, 0.032878674610401504, 0.06493147986475378, 0.04590641656250227, 0.10456791002070531, 0.06679545796941966, 0.036692011199193075, 0.09118037487496622, 0.0623897576588206, 0.09399036862305366, 0.0674159379559569, 0.025234251115762163, 0.028692542400676757, 0.05353349421056919, 0.09284399537136778, 0.03577784853405319, 0.07489378083846532, 0.05354345383238979, 0.03166370835970156, 0.11823246662970632, 0.0743946865259204, 0.05598466326773632, 0.020981193883926608, 0.10720671998569742, 0.0141719555540476, 0.06623724417295307, 0.07364065706497058, 0.20038615126395598, 0.030352956819115207, 0.2222861276823096, 1.3755714311264455, 44.98154930770397, 97.25667044520378, 81.39746904373169, 104.56906646490097, 114.36570838093758, 57.304018288850784, 21.624594032764435, 20.328008607029915, 13.557222224771976, 12.44453838095069, 10.071294978260994, 17.49314982444048, 55.60104466974735, 65.2921624481678, 68.57846930623055, 67.40839049220085, 72.07231342792511, 85.88829606771469, 86.82433784008026, 90.89693650603294, 95.2080787718296, 87.73744404315948, 90.66078677773476, 89.2943648993969, 84.08471524715424, 84.43786069750786, 84.45220872759819, 89.69986394047737, 85.76597303152084, 78.61800938844681, 80.46814531087875, 76.20179504156113, 70.10744646191597, 58.79943564534187, 27.86821950227022, 14.343440886586905, 30.126214139163494, 43.09428557753563, 31.943787708878517, 22.734755761921406, 32.74722419679165, 27.844520173966885, 5.7295524794608355, 2.3066227650269866, 4.653051719069481, 2.546811676584184, 0.09017997464979999, 0.28723561204969883, 0.14295607747044414, 0.07358553775702603, 0.05865580118552316, 0.16400820954004303, 0.9145015594549477, 0.35471357870846987, 0.1234519986610394, 0.947951105190441, 0.27554037398658693, 0.06000332243274897, 0.12204445622046478, 0.1908593054395169, 1.3697883789427578, 0.2304844549507834, 0.400096295052208, 0.14301801711553708, 0.6224938784725964, 1.1972612491808832, 6.405779393389821, 8.612778391689062, 1.1745463055558503, 0.5995884106960148, 0.6760351429693401, 0.6058628833852708, 1.2935091345570982, 4.735699659213424, 3.5951899085193872, 7.468773778527975, 9.855212923139334, 53.54375146329403, 38.9044252038002, 34.11222495138645, 32.000640258193016, 29.424386098980904, 50.250798761844635, 15.719965472817421, 11.794189028441906, 27.749806456267834, 40.79734303057194, 48.8996596634388, 57.25218527019024, 64.50128048658371, 61.49256773293018, 69.23472449183464, 68.71959373354912, 77.911406904459, 75.30308246612549, 73.82582053542137, 75.86866691708565, 82.17828154563904, 82.56385445594788, 77.99907580018044, 87.05108687281609, 80.39530321955681, 67.43240520358086, 57.439120039343834, 62.790441289544106, 67.71177381277084, 56.207431331276894, 42.871868312358856, 19.179866015911102, 9.594221077859402, 20.009766183793545, 54.45976451039314, 86.5672816336155, 73.57753425836563, 30.99462904036045, 44.480333402752876, 45.563480481505394, 6.389001393690705, 0.11406882520532236, 0.07642552911420353, 0.12073031306499615, 0.17863276385469362, 0.12274353706743568, 0.1914075596141629, 0.09467749347095378, 0.03376065033080522, 0.06393482006387785, 0.011244007637287723, 0.03820774392806925, 0.031180429214145988, 0.2105436148121953, 0.092071055987617, 0.10298706125468016, 0.05757813596574124, 0.09296213786001317, 0.10542644129600376, 0.1207038555003237, 0.04721018449345138, 0.12193815840873867, 0.0352197460597381, 0.10901589048444293, 0.03543423044902738, 0.03830770750937518, 0.05047322600148618, 0.019491291604936123, 0.1516293644090183, 0.04149233369389549, 0.008128887293423759, 0.05036892827774864, 0.07920098330941983, 0.08456064766505733, 0.05009209977288265, 0.14281058683991432, 0.08012184756807983, 0.07437502703396603, 0.04285372939193621, 0.041333239496452734, 0.0281467818422243, 0.05873615722521208, 0.04443755045940634, 0.053077485281392, 0.05190385665628128, 0.017958521020773333, 0.059630393225234, 0.058773490964085795, 0.0772754885838367, 0.0954387811361812, 0.2283290057675913, 0.20009991974802688, 0.08124686923110858, 0.06509375045425259, 0.02431507524306653, 0.21002777764806524, 0.12055685831001028, 0.6210644426755607, 2.829799116589129, 72.09178358316422, 92.13761553168297, 97.73585513234138, 120.658368319273, 103.26903462409973, 68.20970669388771, 55.9333710372448, 50.88940009474754, 36.42817407846451, 18.750243969261646, 12.877504248172045, 22.203821651637554, 57.329503521323204, 75.75430825352669, 75.4241743683815, 81.74436002969742, 79.78478997945786, 90.95631211996078, 88.88672277331352, 90.59973925352097, 92.7398832142353, 85.79857528209686, 92.9406264424324, 93.29196318984032, 87.46689096093178, 87.75673940777779, 90.1390215754509, 90.57122558355331, 85.61447516083717, 83.04397389292717, 81.71339929103851, 79.64297398924828, 75.560602247715, 56.595648899674416, 40.68482726812363, 26.61864325404167, 41.44629880785942, 40.52601858973503, 30.741931200027466, 27.673443853855133, 38.53838324546814, 35.49846276640892, 12.781199365854263, 13.48662106320262, 8.60995514318347, 3.334196163341403, 0.14265838719438761, 0.3037459636107087, 0.1510021902504377, 0.22957032197155058, 0.11621150202699937, 0.09836370387347415, 0.9338161011692137, 0.4237497883150354, 0.014833214700047392, 0.6244855653494596, 0.2087135676993057, 0.07966244331328198, 0.04365067354228813, 0.5680769984610379, 1.5797400567680597, 0.29005375457927585, 0.4476497636642307, 0.3551103308564052, 0.9278148575685918, 0.7985722145531327, 8.546196464449167, 4.511730652302504, 1.057673126924783, 0.23110975889721885, 0.6799865153152496, 0.4717304074438289, 2.254749136045575, 6.926419856026769, 6.389441695064306, 14.320928994566202, 26.756687946617603, 52.5953983515501, 39.55893248319626, 26.50117825716734, 27.963100410997868, 21.07318852096796, 51.279384568333626, 31.71150617301464, 23.71823988854885, 35.73076330125332, 40.89737646281719, 54.18334074318409, 62.24170133471489, 71.97876244783401, 67.77576237916946, 71.81757509708405, 70.92222914099693, 82.34035044908524, 79.8535966873169, 74.7987051308155, 77.13882476091385, 82.73861467838287, 86.7900712788105, 83.62795695662498, 82.89263561367989, 82.30359882116318, 72.14700222015381, 59.83797311782837, 62.904594764113426, 65.26190847158432, 60.102112144231796, 77.54457458853722, 47.035403698682785, 24.159736298024654, 32.960426956415176, 60.90967521071434, 76.35310292243958, 78.81175339221954, 66.28967732191086, 50.67363627254963, 50.760393217206, 16.88546173274517, 0.22521962964674458, 0.0445697306713555, 0.0372718845756026, 0.041854364462778904, 0.015340328845923068, 0.09085603407584131, 0.0253698897358845, 0.0186569228026201, 0.037423946923809126, 0.0381940995430341, 0.04481657641008496, 0.027979438673355617, 0.08656464677187614, 0.09381275784107856, 0.038753790213377215, 0.04729847038106527, 0.09817747675697319, 0.04017618302896153, 0.08205068195820786, 0.07911431530374102, 0.05699678942619357, 0.06894045771332458, 0.06216871268406976, 0.03671211969049182, 0.1297910010907799, 0.02613101969473064, 0.040306849259650335, 0.2818266616668552, 0.14888614910887554, 0.13944194884970784, 0.14228330575861037, 0.27009001176338643, 0.19836932042380795, 0.19989343942143023, 0.19902739761164412, 0.20144899579463527, 0.18930437247036025, 0.14164626103593037, 0.12610711361048743, 0.20929115155013278, 0.10925723690888844, 0.1691733644111082, 0.09172978679998778, 0.16708755836589262, 0.13574321841588244, 0.15553889446891844, 0.1362481905380264, 0.11374671084922738, 0.1728971052216366, 0.22717974556144327, 0.16015796223655343, 0.13168050907552242, 0.2335896305157803, 0.2702067664358765, 0.4330273764207959, 0.17392077919794247, 0.5244629981461912, 1.0353597742505372, 61.936190128326416, 119.61986124515533, 99.07335296273232, 131.2091025710106, 130.09076178073883, 92.33440697193146, 51.195682659745216, 59.31775443255901, 53.69596749544144, 24.771378077566624, 14.917174950242043, 31.800315007567406, 74.70120996236801, 93.27763795852661, 85.32460391521454, 89.19727250933647, 89.52824994921684, 98.82391154766083, 95.71994930505753, 95.77331364154816, 94.65659156441689, 90.91261446475983, 96.90479412674904, 99.18607011437416, 86.13927260041237, 86.71166628599167, 89.06185537576675, 93.20923402905464, 85.62071442604065, 83.76270532608032, 82.74660184979439, 78.87893378734589, 74.80423763394356, 63.011038452386856, 38.97960416972637, 23.92950475215912, 46.711201295256615, 54.30063284933567, 36.4245680719614, 30.92982541769743, 39.76181499660015, 42.01860889792442, 14.10636305809021, 17.008620724081993, 13.376535270363092, 6.871507577598095, 0.28045974439010024, 0.3710873454110697, 0.24379223148571327, 0.3089284402085468, 0.09569588335580193, 0.25373969692736864, 1.7629168275743723, 0.543620620155707, 0.1683044430683367, 1.3296435330994427, 0.40634939388837665, 0.21931738854618743, 0.2763779618544504, 1.1728948191739619, 3.1401289394125342, 0.5021870497148484, 0.5409537570085377, 0.5137986328918487, 1.8288312968797982, 3.0910134874284267, 15.276591964066029, 10.549162086099386, 1.2586470739915967, 0.42534757289104164, 1.2378534022718668, 0.6358242756687105, 2.6263677701354027, 16.86326902359724, 10.181479565799236, 12.934111710637808, 25.983661226928234, 59.278996512293816, 46.06011003255844, 41.8794109672308, 37.96879380941391, 34.50979381799698, 65.39937749505043, 28.22395831346512, 18.64578377455473, 42.865332663059235, 52.5985711812973, 71.13523811101913, 66.1732591688633, 78.44158485531807, 71.32046297192574, 77.52293854951859, 73.57818022370338, 89.21905294060707, 81.83783501386642, 77.96387448906898, 77.82275006175041, 84.01413783431053, 89.81622129678726, 84.77304071187973, 87.99923479557037, 85.81750586628914, 76.09103858470917, 74.97186943888664, 72.72644832730293, 73.36129546165466, 73.24044674634933, 77.0766980946064, 39.15129795670509, 17.338192239403725, 31.21079944074154, 70.36269396543503, 92.56475821137428, 91.72630280256271, 72.84310966730118, 75.15177458524704, 59.86078329384327, 10.882387105375528, 0.1947086027939804, 0.2243102909415029, 0.22634873312199488, 0.2639981667743996, 0.20538666809443384, 0.19888296083081514, 0.24907978135161102, 0.13704920536838472, 0.1452429758501239, 0.21640938677592203, 0.15479357040021569, 0.11456975262262858, 0.43839883350301534, 0.22189636656548828, 0.2058571155066602, 0.14400165964616463, 0.2694697247352451, 0.21010260097682476, 0.21970907924696803, 0.17376780771883205, 0.15525971335591748, 0.17325879831332713, 0.15716473222710192, 0.36849155032541603, 0.16821486584376544, 0.10419918879051693, 0.11044326311093755], [0.046599634442827664, 0.031739741389174014, 0.0425516975519713, 0.041874725284287706, 0.11583973056985997, 0.07250195019878447, 0.018849821826734114, 0.10902054375037551, 0.03272513538831845, 0.06958833779208362, 0.02760182280326262, 0.05139666180184577, 0.18811689165886492, 0.1356774047599174, 0.08777187613304704, 0.0258108460548101, 0.04362375213531777, 0.1558813065639697, 0.06348647380946204, 0.11329650922561996, 0.18999446590896696, 0.16132791351992637, 0.187354824738577, 0.028405574303178582, 0.06356857760692947, 0.11073439280153252, 0.13411913212621585, 0.01432722212484805, 0.06863418821012601, 0.01733196470013354, 0.15962786099407822, 5.353272445499897, 57.387002035975456, 103.34325224161148, 90.69314584136009, 108.15210700035095, 116.89265638589859, 61.44654080271721, 23.91268115490675, 20.88704600930214, 13.999046366661787, 22.501655369997025, 17.43356142193079, 23.21302279829979, 58.05463761091232, 72.97195315361023, 81.05430945754051, 75.09306773543358, 72.60786429047585, 84.71476703882217, 86.9667997956276, 94.21719834208488, 95.77346563339233, 90.18251404166222, 85.54157987236977, 88.2819852232933, 83.7277016043663, 84.404536485672, 90.31109914183617, 87.12555527687073, 85.93225210905075, 79.47287231683731, 69.15892615914345, 61.62794686853886, 43.42093124985695, 27.037680968642235, 21.76790714263916, 20.879678204655647, 39.875732883811, 45.68943612277508, 33.43632861971855, 30.525244027376175, 18.8264811784029, 4.363073604181409, 4.381728703156114, 4.580139331519604, 2.4212243780493736, 0.13996971974847838, 0.036722754666698165, 0.1274281513178721, 0.1268025059835054, 0.21616260783048347, 0.32316921511664987, 0.17164557706564665, 0.21587849885690957, 0.24171470780856907, 0.22938052512472495, 0.19075957563472912, 0.26553476869594306, 0.05418967150035314, 0.04087881876330357, 0.2293599527911283, 0.12298976682359353, 0.2037262314115651, 0.2546108001843095, 0.2419976145029068, 0.252898873295635, 4.440885353833437, 7.943525528535247, 5.67081855610013, 2.1777389058843255, 0.055611244242754765, 0.3373477980494499, 0.6246293045114726, 0.6258049851749092, 1.863586250692606, 10.432607140392065, 13.162979129701853, 20.3682978451252, 12.042297665029764, 32.58017756044865, 30.17050076276064, 49.30435314774513, 28.570513017475605, 10.198609996587038, 16.66597221046686, 16.216752715408802, 39.34512935578823, 41.627351492643356, 50.03871314227581, 45.595261976122856, 60.09149931371212, 65.29169127345085, 74.29857596755028, 75.53197458386421, 67.03761398792267, 69.87164631485939, 70.50492033362389, 75.2452951669693, 71.03986322879791, 79.7816513478756, 78.9544129371643, 62.65902914106846, 62.35192582011223, 71.725954413414, 70.78935787081718, 68.2855886220932, 49.195982962846756, 16.012217290699482, 11.114297211170197, 30.117221921682358, 59.58682559430599, 94.83946055173874, 81.0762494802475, 36.94445617496967, 38.918887227773666, 52.939899265766144, 15.144778937101364, 0.599033284233883, 0.06014024496835191, 0.09916722716297954, 0.06984388150158338, 0.15032662806333974, 0.23198374168714508, 0.1917793756001629, 0.0620824120414909, 0.08110850321827456, 0.06288759774179198, 0.006245921340450877, 0.04424219863722101, 0.23883462563389912, 0.15712269698269665, 0.09174811784760095, 0.10012968137743883, 0.04221274015435483, 0.041942602110793814, 0.05419161592726596, 0.00849098300022888, 0.09324337472207844, 0.06141110978205688, 0.04505918077484239, 0.04280433575331699, 0.09421881652087905, 0.08320157488924451, 0.09120917762629688, 0.029325358736969065, 0.09380856470670551, 0.07310442568268627, 0.0830471636436414, 0.11688754661008716, 0.015829946860321797, 0.06032151453837287, 0.056731345466687344, 0.038493036627187394, 0.025076093879761174, 0.07716698659351096, 0.07664798788027838, 0.12278275957214646, 0.1363090318045579, 0.0983755559718702, 0.12301384209422395, 0.09731984348036349, 0.09499091727775522, 0.11536629230249673, 0.04450699321751017, 0.03442843852099031, 0.05602164819720201, 0.046507255610777065, 0.13528181036235765, 0.03804075327934697, 0.10288379140547477, 0.07552970491815358, 0.08717902630451135, 0.06376003686455078, 0.024618099705548957, 0.2670446236152202, 0.3858264279551804, 13.02007544785738, 87.02529385685921, 91.48989468812943, 107.37664461135864, 118.70569109916687, 96.6205769777298, 70.81689119338989, 54.35439236462116, 50.07691249251366, 41.93878658115864, 30.87406910955906, 24.179149456322193, 32.6225832849741, 59.98941779136658, 74.95997607707977, 91.3661277294159, 88.27224254608154, 82.72233635187149, 89.95549142360687, 89.54576700925827, 96.59267127513885, 95.17964869737625, 91.35991126298904, 91.0654878616333, 95.1770344376564, 92.4984061717987, 87.13006943464279, 87.24293857812881, 83.85780662298203, 86.89419329166412, 81.27300292253494, 77.71228238940239, 70.58613717556, 46.24824173748493, 30.64307190477848, 23.600332215428352, 34.80319507420063, 41.100129783153534, 37.84186542034149, 27.80805353075266, 22.62455217540264, 27.403118759393692, 18.869137689471245, 8.039252366870642, 6.678524008020759, 1.6912840213626623, 0.19656311109429225, 0.12432558069122024, 0.04089832611498423, 0.12781589379301295, 0.0440690630057361, 0.2680542116286233, 0.14552512555383146, 0.14032713806955144, 0.3881682304199785, 0.7156731910072267, 0.1337270555086434, 0.1961313741048798, 0.21553420170675963, 0.40470019332133234, 0.28701694565825164, 0.021201756462687626, 0.2679396537132561, 1.293104812502861, 0.3348165698116645, 1.3135195733048022, 6.9119739811867476, 12.879487741738558, 7.08721250295639, 1.4924332103691995, 0.09929736275807954, 1.1019044159911573, 1.2564778653904796, 0.9931640478316694, 1.0702726570889354, 15.879153180867434, 29.96899377554655, 24.871459007263184, 17.909601777791977, 29.619745016098022, 25.03676913678646, 33.55666056275368, 36.43112272024155, 19.665702246129513, 15.429406464099884, 27.611265890300274, 49.125758931040764, 50.731146186590195, 55.031132251024246, 60.048721209168434, 69.13053408265114, 70.14877304434776, 81.08460143208504, 82.56985813379288, 71.3463319838047, 70.91522231698036, 72.34681829810143, 77.82436117529869, 79.98186260461807, 75.70163547992706, 78.951745480299, 69.94973972439766, 69.16206479072571, 69.15530875325203, 64.07685846090317, 70.40900588035583, 83.24047654867172, 39.682942628860474, 18.23350589722395, 33.143060356378555, 61.77297368645668, 82.56355807185173, 87.25278005003929, 72.66489163041115, 52.711079344153404, 54.04131576418877, 25.90408779680729, 1.093852291814983, 0.14257850241847336, 0.017645175139477942, 0.028867737491964363, 0.07542833496700041, 0.14172004535794258, 0.06593056648853235, 0.07351663676672615, 0.08374315715627745, 0.04376044460514095, 0.06045592119335197, 0.048354060418205336, 0.07210863419459201, 0.16658205189742148, 0.04042171887704171, 0.04756658978294581, 0.047183945862343535, 0.03602507276809774, 0.03265271661803126, 0.08181719487765804, 0.06428993030567653, 0.08239290851633996, 0.024506016852683388, 0.009623522619222058, 0.06759618336218409, 0.02617313472001115, 0.12285731572774239, 0.03790233160543721, 0.18514053808758035, 0.1617214595898986, 0.2277956242323853, 0.3315165062667802, 0.1222086489724461, 0.1512514628120698, 0.11784699512645602, 0.22407991345971823, 0.12131972674978897, 0.17789321369491518, 0.19677048199810088, 0.23896013764897361, 0.26224827161058784, 0.2353721801773645, 0.1709387853043154, 0.1390589858056046, 0.12370302269118838, 0.2584397775353864, 0.11169282457558438, 0.17792989063309506, 0.315977685386315, 0.17291479802224785, 0.2779311581980437, 0.10236768706818111, 0.14470830297796056, 0.16621618793578818, 0.3026940138079226, 0.17987397615797818, 0.1625783581403084, 0.2447757701156661, 0.3360386495478451, 5.91553539969027, 83.50048139691353, 111.39079481363297, 113.47676888108253, 129.8820161819458, 134.4197478890419, 98.17806020379066, 52.82378509640694, 52.77337320148945, 47.37778052687645, 37.27713592350483, 27.04979281872511, 46.26744210720062, 83.30395594239235, 99.94755685329437, 100.21561726927757, 94.7284685075283, 88.49021404981613, 94.67456459999084, 91.58046662807465, 100.21895349025726, 99.77968946099281, 95.45457914471626, 93.45283895730972, 96.65965408086777, 89.8646230995655, 85.19091948866844, 89.45615261793137, 81.98027417063713, 85.75803145766258, 82.96849474310875, 73.41644570231438, 74.54883053898811, 55.34490801393986, 37.07184433937073, 27.944644801318645, 32.8117523342371, 54.00434374809265, 54.23862397670746, 42.94265851378441, 32.99011096358299, 33.76149237155914, 18.895456977188587, 11.583168301731348, 11.985884942114353, 3.0096926260739565, 0.4366443963954225, 0.29828506289049983, 0.156943705806043, 0.17857512866612524, 0.4385710711358115, 0.528779091546312, 0.3129648033063859, 0.28699266258627176, 1.4550498663447797, 1.083294558338821, 0.38643902633339167, 0.5059581098612398, 0.24321105564013124, 1.0652129910886288, 0.3797933313762769, 0.12960227293660864, 0.4081762646092102, 1.8817496323026717, 1.063940771855414, 2.583991256542504, 9.26669955253601, 15.132949221879244, 15.371976345777512, 5.699210157617927, 0.11860890619573183, 2.855362482368946, 1.2404523440636694, 1.839023418724537, 4.959631143137813, 15.724108200520277, 24.862791672348976, 30.917937755584717, 21.365993209183216, 49.657627791166306, 43.955273777246475, 67.57940411567688, 39.23260219395161, 14.675763454288244, 30.430024936795235, 31.510498858988285, 52.5392259657383, 55.76011173427105, 65.88713452219963, 65.36861434578896, 74.69878569245338, 78.6218623816967, 89.26481008529663, 90.93670517206192, 73.89167860150337, 76.40944629907608, 76.67598679661751, 84.86308827996254, 87.26522818207741, 85.35773813724518, 88.07190209627151, 76.06903776526451, 81.30480721592903, 78.31999137997627, 73.01149383187294, 78.83736401796341, 75.70301860570908, 28.7181730940938, 13.167447689920664, 37.031220719218254, 73.24252143502235, 101.81194961071014, 95.28204560279846, 80.795588940382, 76.9157463312149, 66.3285568356514, 18.41334454715252, 0.6736530270427465, 0.23729235370410606, 0.1510394609067589, 0.16134094563312829, 0.2437735442072153, 0.24471887707477435, 0.23832469596527517, 0.11479277542093769, 0.3163513418985531, 0.20563291269354522, 0.25615149876102805, 0.17354093317408115, 0.2832821320043877, 0.2767804730683565, 0.17068872606614605, 0.19554948579752818, 0.19955542084062472, 0.2207407238893211, 0.07378338690614328, 0.11491610552184284, 0.172282547573559, 0.26300033438019454, 0.1193848809634801, 0.14703126973472536, 0.21769781451439485, 0.1643464804510586, 0.15738051908556372, 0.20763593958690763], [0.03602454213250894, 0.02467748821800342, 0.12189946282887831, 0.133518215152435, 0.08005854237126186, 0.03652147308457643, 0.04301300912629813, 0.05946812634647358, 0.04400449244712945, 0.02077680270303972, 0.01843700960307615, 0.0800288119353354, 0.11721248854883015, 0.12928963580634445, 0.15798829350387678, 0.08480099219013937, 0.23554097424494103, 0.06855399173218757, 0.277319717570208, 0.18172087002312765, 0.1374115070211701, 0.06087889712944161, 0.26966113946400583, 0.10964512039208785, 0.08319096959894523, 0.17715237219817936, 0.18652706290595233, 0.048492181522306055, 0.09296880234614946, 0.11890561683685519, 0.11070826920331456, 0.26447551616001874, 13.161161877214909, 69.9413649737835, 88.47947582602501, 86.21628686785698, 100.98627671599388, 110.93804150819778, 69.01863008737564, 24.457406625151634, 19.01103727519512, 17.402868568897247, 30.924125723540783, 26.73110581934452, 31.997965201735497, 63.411130383610725, 75.99280625581741, 75.70491090416908, 77.51560494303703, 82.83658862113953, 89.55490171909332, 90.73078662157059, 93.21180269122124, 94.13604989647865, 90.11716514825821, 87.07912176847458, 86.59664645791054, 83.73600795865059, 80.6505735218525, 78.80810558795929, 73.864084482193, 69.5060983300209, 55.266461223363876, 48.55851396918297, 36.05366997420788, 35.338992923498154, 20.752924606204033, 13.508251402527094, 21.969093047082424, 42.425639256834984, 38.81160378456116, 52.322367802262306, 20.070853605866432, 5.320364311337471, 1.90358551684767, 0.6476140336599201, 1.3274458260275424, 0.35985909635201097, 0.10768872263724916, 0.17337714118184522, 0.12104137684218585, 0.10041118541266769, 0.17448080383474007, 0.47170330421067774, 0.05446566137834452, 0.4112228995654732, 0.3977557393955067, 0.1545600313693285, 0.11971809042734094, 0.08104372114758007, 0.1960110868094489, 0.07675222252146341, 0.1493502437369898, 0.15467404009541497, 0.1425250677857548, 0.16478825127705932, 0.39911850064527243, 2.7152784867212176, 6.1200974229723215, 9.480021055787802, 1.803124607540667, 1.0457627847790718, 1.2336420407518744, 0.3091714787296951, 0.35022290248889476, 0.34273368248250335, 8.28486928716302, 8.747697751969099, 37.498937621712685, 27.771501392126083, 11.461232844740152, 30.322948582470417, 31.565715596079826, 12.796990368515253, 17.264025919139385, 32.19615496695042, 20.563962645828724, 25.78838400542736, 37.84585140645504, 48.95203225314617, 40.50702340900898, 48.60192283987999, 51.77110858261585, 58.80360022187233, 60.82180492579937, 62.14557409286499, 64.88042414188385, 74.586121737957, 67.31617704033852, 67.79190391302109, 69.16255876421928, 64.0578518807888, 62.750463634729385, 72.39902749657631, 74.49209198355675, 67.90367871522903, 50.53253844380379, 12.39436112344265, 14.87461058422923, 49.52035255730152, 78.10221746563911, 96.94716945290565, 79.19272854924202, 43.900100737810135, 28.651207387447357, 35.03479644656181, 17.871237136423588, 1.1784498835913837, 0.28774665493983775, 0.2735733857844025, 0.020662873757828493, 0.12987078196601942, 0.18941419548355043, 0.14970886433729902, 0.15626904903911054, 0.08147263797582127, 0.02277066592796473, 0.07410987993353046, 0.03617339098127559, 0.06102977575210389, 0.2401397516950965, 0.017731716980051715, 0.06804579868912697, 0.03506503424432594, 0.17943257640581578, 0.07697002802160569, 0.10023891067248769, 0.05276157899061218, 0.1764167405781336, 0.0460881796607282, 0.08898736559785903, 0.1074031442112755, 0.05660077200445812, 0.03392335507669486, 0.041503632892272435, 0.043910581080126576, 0.02424822629109258, 0.03534256036800798, 0.14656919374829158, 0.03933213105483446, 0.05699663728591986, 0.028074661786376964, 0.05485547073476482, 0.06735370145179331, 0.051622456521727145, 0.1371926031424664, 0.06294098784564994, 0.029372858043643646, 0.027006922791770194, 0.10174548529903404, 0.027528982864168938, 0.08933456454542466, 0.20015448244521394, 0.03817713033640757, 0.07438514250679873, 0.004057756432302995, 0.14684591093100607, 0.11176092404639348, 0.10274097250658087, 0.2926689642481506, 0.07112448700354435, 0.29138525656890124, 0.1571795009658672, 0.2810575591865927, 0.12250576779479161, 0.070911832008278, 0.8747583639342338, 0.8310282917227596, 25.881644301116467, 92.243462651968, 92.99098894000053, 106.30434215068817, 120.73912918567657, 101.65342971682549, 80.11739373207092, 60.484823808074, 40.83224415779114, 41.96074940264225, 40.5053249001503, 34.70973528921604, 46.030467823147774, 69.40706804394722, 76.22753486037254, 85.34355729818344, 88.93803521990776, 85.3593036532402, 90.68940684199333, 88.52574214339256, 91.8229392170906, 87.53331899642944, 88.14088359475136, 92.29795932769775, 95.1272951066494, 89.40629929304123, 89.33712020516396, 84.44962486624718, 78.4719680249691, 76.88760504126549, 63.880082219839096, 54.66962344944477, 44.972786977887154, 35.14127053320408, 16.47843897342682, 15.869711637496948, 31.438658013939857, 41.30424723029137, 22.716028466820717, 27.246759049594402, 14.762181267142296, 10.609395503997803, 9.919324032962322, 6.142367552965879, 2.9605016531422734, 0.33191011170856655, 0.1620739945792593, 0.07970945094712079, 0.21086918015498668, 0.14256456488510594, 0.22965540178120136, 0.20882644836092368, 0.17783780494937673, 0.817756672622636, 1.1709894589148462, 0.1147937253699638, 0.10450528759974986, 0.12833462533308193, 0.29965002089738846, 0.3111835598247126, 0.5284025555010885, 0.10880342102609575, 0.4499313037376851, 0.560231072595343, 1.1188648059032857, 6.556034730747342, 16.698414869606495, 14.310528952628374, 2.6117034070193768, 1.115253099706024, 1.3971796841360629, 0.8057479513809085, 1.4468157081864774, 0.789381101494655, 19.047439321875572, 19.740824215114117, 51.364465802907944, 32.028876543045044, 16.91592089831829, 18.09692982584238, 35.90565651655197, 20.647271275520325, 18.148867338895798, 31.06157574802637, 24.835205152630806, 43.89772206544876, 58.0499030649662, 59.49547089636326, 64.3067917227745, 66.85263991355896, 66.71419814229012, 70.99876463413239, 65.68777441978455, 70.19250109791756, 72.5218217074871, 81.45399481058121, 80.82163274288177, 76.8526317179203, 68.71362805366516, 70.4528859257698, 72.22560480237007, 74.80046823620796, 68.04015979170799, 77.08187341690063, 76.47991731762886, 30.566551610827446, 18.501074239611626, 39.44456622004509, 68.33964452147484, 86.64254799485207, 92.54500687122345, 75.216393917799, 50.28063476085663, 48.34938459098339, 30.67513268440962, 2.873116792179644, 0.1052764013002161, 0.016256689195870422, 0.055786398515920155, 0.12893278151750565, 0.05622564232908189, 0.017523705973871984, 0.061245102479006164, 0.04382379433081951, 0.04904172332317103, 0.14519947115331888, 0.10246081918012351, 0.056185228677350096, 0.13763231079792604, 0.05688761950295884, 0.020790862690773793, 0.07316997958696447, 0.02394531315076165, 0.04984134291589726, 0.06067835398425814, 0.15601003949996084, 0.005736513958254363, 0.04743478064483497, 0.09043153302627616, 0.025755381648195907, 0.018680313442018814, 0.052365776791702956, 0.047810166361159645, 0.07801494226441719, 0.15026957174995914, 0.2073791713337414, 0.22272236208664253, 0.15900533267995343, 0.2796670119278133, 0.10747229753178544, 0.14225287770386785, 0.14680623571621254, 0.14891350467223674, 0.3112345008412376, 0.20265442173695192, 0.22121057758340612, 0.2892810007324442, 0.2641823381418362, 0.2400656111421995, 0.1670185980037786, 0.3017463209107518, 0.08671082759974524, 0.2208067601895891, 0.21461754542542621, 0.22174366225954145, 0.13104199490044266, 0.24507224326953292, 0.29063779511488974, 0.1213595800800249, 0.32763154129497707, 0.18700668326346204, 0.39924110344145447, 0.13926004845416173, 0.1965419005136937, 0.8741282508708537, 0.32631345733534545, 16.20514813810587, 93.54135900735855, 102.09192618727684, 110.01342952251434, 124.9954479932785, 128.4586277604103, 108.40206518769264, 60.436551198363304, 41.236561462283134, 40.69377958774567, 44.332726523280144, 40.265044793486595, 58.40313971042633, 91.0561403632164, 102.31697291135788, 93.15260946750641, 98.1767226755619, 94.67123597860336, 99.52466234564781, 94.41849634051323, 103.20612519979477, 96.41912698745728, 96.53540834784508, 95.04179209470749, 101.72175765037537, 95.23910790681839, 91.31052151322365, 82.02071160078049, 82.78592973947525, 80.63918173313141, 70.68211242556572, 54.343650341033936, 47.10969351232052, 46.496144235134125, 34.51721481978893, 20.86543656885624, 32.436602264642715, 55.57543784379959, 57.806902304291725, 79.1141639649868, 43.26331190764904, 11.157792527228594, 12.704840563237667, 10.965818278491497, 3.786373562179506, 0.8231127820909023, 0.26011869369540364, 0.2713038388174027, 0.4727206699317321, 0.33470026042778045, 0.2775718696648255, 1.3290696451440454, 0.30294195050373673, 1.8331940565258265, 2.7204806450754404, 0.3051600814796984, 0.21660895028617233, 0.13038353179581463, 1.013436613138765, 0.6345087150111794, 0.5941413436084986, 0.23784372489899397, 0.5659933446440846, 0.5832620523869991, 1.7868721671402454, 6.773251499980688, 20.847904309630394, 24.839069545269012, 11.024637222290039, 5.1875994354486465, 5.624241130426526, 0.5510644207242876, 1.2444220623001456, 3.338193786330521, 20.37485059350729, 20.97775474190712, 57.40579202771187, 39.97308366000652, 33.04382108151913, 45.89051753282547, 47.69796274602413, 17.3834915086627, 28.44026930630207, 45.58327741920948, 25.20927608013153, 38.40313330292702, 57.12471731007099, 64.1316819190979, 65.46478718519211, 71.7154061794281, 72.77914389967918, 80.9508866071701, 77.81966462731361, 79.84556391835213, 81.72026932239532, 88.11809241771698, 88.46939116716385, 86.52554467320442, 78.40880781412125, 77.84236460924149, 79.07520845532417, 78.60392734408379, 79.0711958706379, 78.8352133333683, 68.05469781160355, 26.096081994473934, 21.39142144471407, 53.029973432421684, 86.38402506709099, 107.49986439943314, 101.37254878878593, 81.68505281209946, 66.01872146129608, 54.68620955944061, 23.88386160135269, 1.2607585731893778, 0.36141579563263804, 0.33905553922522813, 0.10188162486883812, 0.2276783500565216, 0.13664599653566256, 0.14680723019409925, 0.16416109196143225, 0.2614688384346664, 0.10798947798321024, 0.17813657876104116, 0.16574336565099657, 0.1664135992177762, 0.31391356489621103, 0.23955361830303445, 0.16890006110770628, 0.2550350414821878, 0.14762883220100775, 0.11785026799771003, 0.2266776529722847, 0.204473648336716, 0.26780882792081684, 0.1081669848645106, 0.18559375283075497, 0.1460482060792856, 0.16433577868156135, 0.25689364643767476, 0.16649758064886555, 0.14526702143484727], [0.10925348164164461, 0.0311800061899703, 0.048899134490056895, 0.06821774688432924, 0.017667823631200008, 0.008023171139939222, 0.030264889865065925, 0.057420834054937586, 0.010850069156731479, 0.11089382838690653, 0.0695368846936617, 0.09224099296261556, 0.11389332954422571, 0.04371955226815771, 0.19455972797004506, 0.0922285026172176, 0.03218736033886671, 0.10369297728175297, 0.04787555699294899, 0.1649799183360301, 0.1822889395407401, 0.06857240441604517, 0.04390967565996107, 0.3045751800527796, 0.1357397303218022, 0.09654282970586792, 0.18273171968758106, 0.10643577697919682, 0.13061704114079475, 0.09853712894255295, 0.34720678464509547, 0.4864081589039415, 0.5681630282197148, 25.71449127048254, 66.45553842186928, 79.05371680855751, 81.90411105751991, 96.55414894223213, 106.70115485787392, 73.30414652824402, 30.30766010284424, 16.48070365190506, 21.3457003980875, 25.95711015164852, 27.928917445242405, 32.28611893951893, 63.17420169711113, 70.41500195860863, 75.14466896653175, 77.30019450187683, 81.34312435984612, 82.1220825612545, 81.31636619567871, 86.71447053551674, 83.88249769806862, 79.40572991967201, 78.34878623485565, 74.47364777326584, 75.54588943719864, 68.65660071372986, 70.97035735845566, 64.4469054043293, 55.16874186694622, 48.06378431618214, 34.046404883265495, 31.174936965107918, 29.874711334705353, 28.492172621190548, 18.841887451708317, 28.257742300629616, 23.266786113381386, 39.67633098363876, 59.0092945843935, 19.108530543744564, 3.683133339509368, 3.038455657660961, 0.32205744821112603, 0.26955527951940894, 0.058977139997296035, 0.27213860652409494, 0.4265931638656184, 0.17936455114977434, 0.12030061698169447, 0.1649093846208416, 0.15482762013562024, 0.25119279453065246, 0.15492399543290958, 0.056806191059877165, 0.15033798292279243, 0.032431753279524855, 0.2870199439348653, 0.17713714332785457, 0.30784303438849747, 0.28587522567249835, 0.29741458303760737, 0.03978485598054249, 0.0933265768981073, 2.442135368473828, 10.433792676776648, 7.672209637239575, 0.42739441618323326, 3.8047937862575054, 0.178224389674142, 0.1797744244686328, 0.2877133770380169, 3.3001305162906647, 8.799000699073076, 16.596874818205833, 11.815657876431942, 15.849345680326223, 35.838232934474945, 20.91246284544468, 14.773405864834785, 16.746942065656185, 20.07748045027256, 9.481089748442173, 12.270812653005123, 17.69290890544653, 32.644078731536865, 35.86127109825611, 31.96918934583664, 42.063860669732094, 50.5101652443409, 57.09895849227905, 63.79453361034393, 63.52694056928158, 70.00968530774117, 62.08430618047714, 56.10392488539219, 63.66482377052307, 63.16770404577255, 62.13963121175766, 69.26296457648277, 63.50188851356506, 61.852393224835396, 37.49103024601936, 16.689361855387688, 33.19308087229729, 60.66778019070625, 73.9256563782692, 99.66080144047737, 78.48284304141998, 55.10170206427574, 40.58240756392479, 28.13713487237692, 15.97604513168335, 0.8136039704550058, 0.2570476272376254, 0.0718176455120556, 0.18354588537476957, 0.10772416018880904, 0.2289799286518246, 0.12207009742269292, 0.20989307784475386, 0.20746637368574739, 0.03261102276155725, 0.13013626303290948, 0.10776236595120281, 0.10545828685280867, 0.08928472190746106, 0.1206889383320231, 0.04998413955036085, 0.019900970110029448, 0.18188923364505172, 0.15057956683449447, 0.06470038992119953, 0.05798959005915094, 0.040188498969655484, 0.07875998431700282, 0.04335410390922334, 0.09173799495329149, 0.052049699806957506, 0.027825159158965107, 0.03919314905942883, 0.06505173005280085, 0.03690772384288721, 0.05431545811006799, 0.039205405628308654, 0.05160017353773583, 0.02847151226887945, 0.03677062690258026, 0.042404756022733636, 0.029589975201815832, 0.009268137782783015, 0.11236138831009157, 0.08144068109686486, 0.06250126534723677, 0.06682536652078852, 0.07789152310579084, 0.01528523087472422, 0.08140040474245325, 0.2124257161631249, 0.09380521762068383, 0.09869634188362397, 0.03958257249905728, 0.06170132663100958, 0.09093771484913304, 0.11724887604941614, 0.11305167470709421, 0.29429952206555754, 0.09794706216780469, 0.06554382591275498, 0.3224018047330901, 0.1841617640457116, 0.4478837182978168, 0.03547580185113475, 0.24066216428764164, 1.0548957134597003, 1.3986576860770583, 35.54360054433346, 86.61588862538338, 87.72932007908821, 101.58011645078659, 118.10714721679688, 104.80740487575531, 84.66018676757812, 62.31719948351383, 40.082950964570045, 43.171508833765984, 38.791415467858315, 38.96453037858009, 54.171717166900635, 78.53710412979126, 82.18941494822502, 85.10537847876549, 89.17752876877785, 84.81996819376945, 89.4260810315609, 86.4637903869152, 88.47419410943985, 84.90202099084854, 86.89300775527954, 85.40310010313988, 80.07506400346756, 80.61537221074104, 75.80838695168495, 75.39022698998451, 72.61265203356743, 68.93992111086845, 67.97781273722649, 56.47348925471306, 44.584170430898666, 34.6001111716032, 25.81068690866232, 26.208364069461823, 33.21571625769138, 26.595012322068214, 47.32758142054081, 54.03786554932594, 28.51230014115572, 17.05007839947939, 6.520198853686452, 0.646398514509201, 0.3799297974910587, 0.0285546068334952, 0.13963147852336988, 0.2688169019529596, 0.13843101012753323, 0.06620361004024744, 0.3361622616648674, 0.47005024447571486, 0.5258786003105342, 0.17693296365905553, 0.19039052043808624, 0.08359532876056619, 0.06630692441831343, 0.5597594822756946, 0.3626712423283607, 0.8279863768257201, 0.4803064581938088, 0.43258968740701675, 0.1643303906894289, 0.12493263522628695, 3.2227077707648277, 17.469351701438427, 18.131648562848568, 5.671063642948866, 2.1305729867890477, 0.35165008215699345, 0.19027438916964456, 0.0011856224273287808, 1.6830075904726982, 19.297642596065998, 30.23502890020609, 23.72571788728237, 22.987071722745895, 34.75542403757572, 25.371455177664757, 23.514601215720177, 21.056383922696114, 28.228215985000134, 21.4167869836092, 22.32812438160181, 26.004670299589634, 46.37305364012718, 52.38765209913254, 54.949573427438736, 63.91060218214989, 73.18936228752136, 71.79645583033562, 73.07574078440666, 73.3468334376812, 77.9915902018547, 72.80816674232483, 69.78648528456688, 66.1721496284008, 65.92806592583656, 74.84094366431236, 81.99823200702667, 67.46567621827126, 72.59613052010536, 60.4707645624876, 32.521204724907875, 36.48439206182957, 53.71474228799343, 63.25257249176502, 91.64292007684708, 100.4476860165596, 73.4263327717781, 55.35519026219845, 41.985919252038, 24.517373107373714, 3.898532618768513, 0.19350244954694062, 0.07277701239218004, 0.07384675147477537, 0.012891095866507385, 0.05476778598676901, 0.09939363415469415, 0.11668163773720153, 0.08861310794600286, 0.010311432288290234, 0.09013028044137172, 0.08761143864830956, 0.08615262122475542, 0.03594067944504786, 0.0438954598212149, 0.015774517705722246, 0.04972398710378911, 0.04782442301802803, 0.06599662505323067, 0.1455929281655699, 0.045940399504615925, 0.08271793209132738, 0.028088068684155587, 0.08690795686561614, 0.0716097847907804, 0.03845201441436075, 0.019040937841054983, 0.048416118806926534, 0.02906288151280023, 0.03264933613536414, 0.16814231348689646, 0.13616412004921585, 0.14243289304431528, 0.1594478011247702, 0.1780757078086026, 0.11328185923048295, 0.17292970034759492, 0.1075742686225567, 0.22496298013720661, 0.1224083905981388, 0.08552236715331674, 0.25959203601814806, 0.17102389479987323, 0.16329714300809428, 0.3146581765031442, 0.37971555429976434, 0.17320153419859707, 0.1752048431080766, 0.17081190773751587, 0.22879621741594747, 0.2599275461398065, 0.31834525521844625, 0.2650785556761548, 0.35290348052512854, 0.2539712766883895, 0.13847504917066544, 0.3993965982226655, 0.24879329750547186, 0.4322518320987001, 0.1423503810656257, 0.27883156144525856, 0.9073382907081395, 0.37195930955931544, 24.968332909047604, 88.03958103060722, 93.4804254770279, 105.69785669445992, 125.2471312880516, 127.58122444152832, 119.15080681443214, 63.23225878179073, 39.00962255895138, 45.380907878279686, 36.3792859017849, 44.279373586177826, 59.06438022851944, 91.47264361381531, 99.21117916703224, 95.6880310177803, 92.12211236357689, 93.71678799390793, 98.67464795708656, 96.84948429465294, 97.56284281611443, 95.73135629296303, 96.51931241154671, 92.3801489174366, 82.94567316770554, 86.66756585240364, 75.11245429515839, 78.63089069724083, 78.7912268936634, 75.51796853542328, 66.55779093503952, 46.06750063598156, 40.68005092442036, 40.5973369628191, 37.3088376224041, 31.067469231784344, 43.70142459869385, 43.81720058619976, 62.255160212516785, 81.38527929782867, 37.8535345941782, 21.79925736039877, 8.85635482147336, 3.555536661297083, 0.6438711157534271, 0.1385896367719397, 0.45255049131810665, 0.7302044425159693, 0.34848847368266433, 0.48182020196691155, 0.4783495928859338, 0.6626293435692787, 1.348009966313839, 0.39128136180806905, 0.2938557177549228, 0.2754878893028945, 0.06265471180086024, 0.6842900812625885, 0.7693496451247483, 1.7911248514428735, 0.6366608245298266, 1.434582145884633, 0.22246448061196133, 0.16828133258968592, 4.442072790116072, 26.168855689466, 31.994062811136246, 12.067631855607033, 7.860381714999676, 0.6398283108137548, 0.3381645167246461, 0.2560023864498362, 4.949546484276652, 21.255768723785877, 34.58025723695755, 28.112810477614403, 32.247372418642044, 51.96751244366169, 39.088863506913185, 25.40503777563572, 26.20676625519991, 36.81079834699631, 15.494861751794815, 20.35977490246296, 24.471769854426384, 47.35231049358845, 56.63528077304363, 56.13535299897194, 62.244338393211365, 77.10790202021599, 77.58770227432251, 84.33408826589584, 81.60952046513557, 84.04427021741867, 76.2294727563858, 77.62729614973068, 74.78486627340317, 71.22669920325279, 73.30954983830452, 85.78779146075249, 74.2427721619606, 72.78174296021461, 50.231959372758865, 31.64131633937359, 44.287261962890625, 67.70440220832825, 80.43805092573166, 102.66861364245415, 105.19163265824318, 83.48473504185677, 71.6053868830204, 49.91361625492573, 21.42522633075714, 1.69383748434484, 0.2843321819091216, 0.14312656363472342, 0.17980060743866488, 0.09318749842350371, 0.16237579635344446, 0.2105488395318389, 0.2864453138317913, 0.2873318240744993, 0.10899529588641599, 0.3149425971787423, 0.2289341381401755, 0.1612039451720193, 0.2182391518726945, 0.19645593012683094, 0.20046652585733682, 0.13252433098386973, 0.2508849813602865, 0.14692005148390308, 0.33428617171011865, 0.1597216833033599, 0.18974482227349654, 0.14848611666820943, 0.1275977469049394, 0.19556569430278614, 0.16397524334024638, 0.13516710401745513, 0.21187765494687483, 0.14411367941647768, 0.17117527808295563], [0.027964909277216066, 0.07426895186654292, 0.0346991814149078, 0.011575938751775539, 0.10764942591777071, 0.025126186992565636, 0.04536927604931407, 0.0841268029762432, 0.03732988341653254, 0.07033460438833572, 0.08968813854153268, 0.13535559468436986, 0.025692022645671386, 0.04110991983907297, 0.09568889232468791, 0.020800354759558104, 0.038188644757610746, 0.021034233323007356, 0.09953780376235954, 0.21853840065887198, 0.07927830767584965, 0.061868833072367124, 0.05927587299083825, 0.23931933712447062, 0.12720020808046684, 0.09148293363978155, 0.20375424006488174, 0.13470057514496148, 0.1945003858418204, 0.13106246333336458, 0.12308849472901784, 0.08203485194826499, 0.3977215412305668, 0.5756688129622489, 21.558855660259724, 79.84126254916191, 81.78146123886108, 81.35566368699074, 88.95571947097778, 102.98847287893295, 92.36602127552032, 42.91973054409027, 23.443474732339382, 17.117108702659607, 16.486169658601284, 22.073948420584202, 24.668014124035835, 41.80889435112476, 55.87524175643921, 75.54522827267647, 78.21560338139534, 65.3897488117218, 68.90566974878311, 73.76145198941231, 75.50884142518044, 72.66923099756241, 66.62830755114555, 65.04966706037521, 63.71920645236969, 67.42030665278435, 55.80405257642269, 54.67555113136768, 62.59138137102127, 48.54045733809471, 24.091776944696903, 8.266880102455616, 8.94603380933404, 9.085234589874744, 11.216287538409233, 19.42084338515997, 14.247091356664896, 12.479316964745522, 36.439113691449165, 25.959323532879353, 16.364344395697117, 10.33554894849658, 0.41983893723227084, 0.16308867372572422, 0.05764209054177627, 0.08261292561655864, 0.07843746177968569, 0.15535384736722335, 0.4141066182637587, 0.830914000980556, 0.16973436868283898, 0.3982209472451359, 0.3216876508668065, 0.17129348736489192, 0.29262158554047346, 0.5950274085626006, 0.4231567826354876, 0.16027446457883343, 0.5825701332651079, 0.5572869430761784, 0.04539359993941616, 0.22007901017786935, 0.04388438326714095, 0.706139977555722, 3.042780300602317, 3.179439017549157, 0.824653540039435, 1.2024597264826298, 0.13742253533564508, 0.3987818624591455, 0.3909663646481931, 5.987122133374214, 24.773893542587757, 31.097696609795094, 11.944403517991304, 33.14912483096123, 28.32383405417204, 6.446696547791362, 8.59661690890789, 10.281884428113699, 10.219422429800034, 13.3225173689425, 8.746164534240961, 12.620453741401434, 25.614765621721745, 33.63777481019497, 37.111502811312675, 40.19980609416962, 45.78580655157566, 53.582680374383926, 61.74988612532616, 72.09788605570793, 66.76369428634644, 61.036633998155594, 66.76720529794693, 70.34741878509521, 60.432272627949715, 49.732753559947014, 51.56355232000351, 51.05225555598736, 36.07558719813824, 23.03756721317768, 38.62073242664337, 53.67743968963623, 68.85963901877403, 87.96439826488495, 66.48997217416763, 51.344649866223335, 50.57025521993637, 33.020057156682014, 15.50220675766468, 0.963971164310351, 0.09461407695198432, 0.08457483010715805, 0.03815920375927817, 0.10099395687575452, 0.0914810411632061, 0.12724871485261247, 0.3379910025978461, 0.0738546701904852, 0.06972127870540135, 0.07507797447033226, 0.02032876629527891, 0.038847835166961886, 0.040783278382150456, 0.04422561534738634, 0.08216513597290032, 0.08226689926232211, 0.13495197024894878, 0.24606908118585125, 0.08062194377998821, 0.10121005543624051, 0.02321549069165485, 0.1488910472835414, 0.03270069646532647, 0.12372708311886527, 0.03776364275836386, 0.0061728341734124115, 0.04448312203749083, 0.07363120952504687, 0.14195048221154138, 0.05274635012028739, 0.04647771442250814, 0.060785052555729635, 0.009376812322443584, 0.06829917532741092, 0.05163742564036511, 0.047792184122954495, 0.010061516841233242, 0.028866698485217057, 0.06150731067464221, 0.06729308282956481, 0.030092294146015774, 0.13082044897601008, 0.05637396425299812, 0.04777217953233048, 0.09161893220152706, 0.1222335257625673, 0.01639983463974204, 0.019839815286104567, 0.06460674572736025, 0.03556530115019996, 0.12027424847474322, 0.03065802218770841, 0.10429585352540016, 0.14497253723675385, 0.13722027040785179, 0.09610974942916073, 0.3207919973647222, 0.36793758161365986, 0.2962207345990464, 0.4426845582202077, 0.14621851412812248, 0.11168301338329911, 0.9746901516336948, 1.7008033418096602, 33.77327173948288, 82.02750563621521, 91.96789383888245, 98.78531321883202, 114.97527927160263, 113.9878186583519, 90.74223160743713, 67.80312091112137, 55.9227392077446, 34.600662142038345, 32.86299638450146, 35.38047529757023, 44.93212155997753, 65.65616011619568, 79.57767069339752, 93.87647062540054, 94.04566794633865, 77.55589038133621, 78.34555640816689, 79.90986406803131, 77.71224439144135, 72.4158301949501, 77.97462791204453, 80.30258819460869, 79.53806921839714, 83.63015323877335, 77.48532056808472, 70.65557464957237, 80.1391589641571, 74.36041384935379, 41.02808564901352, 19.06438071280718, 21.09455857425928, 25.07340297102928, 22.953646816313267, 29.895917996764183, 26.23050358146429, 23.825278244912624, 54.727946519851685, 38.8138684630394, 33.6510095000267, 13.522252701222897, 1.3358020526356995, 0.4910240205936134, 0.07452592049958184, 0.030391986365430057, 0.08750024266191758, 0.07229841619846411, 0.3566221450455487, 0.5979900027159601, 0.09284013620344922, 0.5110883095767349, 0.033289690836681984, 0.14913114689989015, 0.2088778791949153, 0.6349963357206434, 0.34996303205844015, 0.10676657446310855, 0.23976513039087877, 0.214085410698317, 0.028245157227502204, 0.13082393707009032, 0.09849672642303631, 1.052210326306522, 13.177032675594091, 12.512448336929083, 3.900912953540683, 2.4209700291976333, 1.0134755610488355, 1.1110038589686155, 0.1714771837578155, 5.026646722108126, 26.28698755055666, 41.64261907339096, 18.895092196762562, 40.60416139662266, 46.756985038518906, 26.610234305262566, 18.458187840878963, 14.848978109657764, 19.732977636158466, 19.60501380264759, 22.116473838686943, 18.751984275877476, 30.586318150162697, 55.47208718955517, 49.924787655472755, 53.959403559565544, 60.66416658461094, 68.99919793009758, 74.2642030119896, 79.48914304375648, 74.03655722737312, 80.50851434469223, 80.45081824064255, 79.4056311249733, 73.77386972308159, 68.22107568383217, 57.22091294825077, 61.98390796780586, 54.2660129070282, 32.399668246507645, 43.70710529386997, 54.86716724932194, 58.89890290796757, 81.60547748208046, 86.1257453262806, 74.5222395658493, 64.01647210121155, 48.26936088502407, 24.060291834175587, 3.262281697243452, 0.06439443212002516, 0.06592197241843678, 0.040062222542474046, 0.019089290617557708, 0.01265660688659409, 0.043401812872616574, 0.11114886743598618, 0.08362364911590703, 0.15329505549743772, 0.044078710925532505, 0.013831261530867778, 0.054582787124672905, 0.07464553986210376, 0.08116697703371756, 0.009663077235018136, 0.06436441966798156, 0.07218640384962782, 0.20468340895604342, 0.09968332407879643, 0.2321733010467142, 0.10712356233852915, 0.061305053168325685, 0.08320521141286008, 0.04089132395165507, 0.04221788694849238, 0.04629864160961006, 0.06504522883915342, 0.06473076602560468, 0.006701266047457466, 0.010977842866850551, 0.16936273081228137, 0.19885867775883526, 0.10545275043114088, 0.2799908851739019, 0.25136396347079426, 0.10429949004901573, 0.12003139549051411, 0.23656390607357025, 0.20946824282873422, 0.1858357375022024, 0.126804583997, 0.22237690718611702, 0.14378944993950427, 0.2468637135461904, 0.26164125418290496, 0.19182532938430086, 0.1479658266180195, 0.14070161094423383, 0.2029572328319773, 0.2869757416192442, 0.15758720721350983, 0.12250581974512897, 0.13284961431054398, 0.22243779298150912, 0.2043094258988276, 0.28430403966922313, 0.22039445262635127, 0.2554462803527713, 0.20577588002197444, 0.38001170090865344, 0.16949606506386772, 0.11087465871241875, 0.856348886154592, 0.33232470508664846, 23.75430755317211, 91.66419133543968, 105.77569931745529, 111.99114739894867, 130.08080631494522, 133.36519807577133, 130.4964280128479, 87.28113412857056, 54.34046611189842, 32.793775498867035, 27.318996973335743, 33.13201054930687, 47.47792415320873, 66.80005833506584, 86.63841381669044, 96.3865627348423, 93.9006981253624, 76.50032222270966, 84.19628486037254, 84.67025622725487, 89.07333076000214, 87.02281638979912, 91.24870643019676, 83.21960806846619, 79.18098717927933, 83.59215527772903, 74.89144295454025, 69.64146986603737, 79.33347299695015, 61.8998184800148, 31.950885728001595, 11.336014363914728, 20.971792861819267, 24.388050846755505, 28.15236635506153, 37.27207079529762, 33.01164820790291, 29.53851867467165, 68.72684374451637, 46.713910549879074, 42.36752897500992, 15.539123676717281, 0.9200267004780471, 0.6356503756251186, 0.2553083002567291, 0.1262693470926024, 0.21883404260734096, 0.4350515396799892, 0.8771750936284661, 1.5249212295748293, 0.34382452082354575, 1.1158626107499003, 0.5671057349536568, 0.40641618717927486, 0.6141160998959094, 1.143279920797795, 1.7220462206751108, 0.3820873098447919, 2.345814099535346, 2.2746759792789817, 0.10470673616509885, 0.6751420127693564, 0.10355366131989285, 1.2157296831719577, 12.476810049265623, 12.105971798300743, 4.568196097388864, 5.476750144734979, 5.736177423968911, 2.447526091709733, 0.21111302019562572, 9.325151816010475, 36.84325620532036, 51.62312172353268, 23.47916431725025, 47.299759313464165, 47.38819196820259, 23.194325901567936, 17.96782035380602, 14.156236331909895, 16.69625088572502, 20.087952688336372, 22.44446463882923, 24.087996147572994, 41.70302823185921, 52.58100472390652, 58.1562365591526, 62.75148198008537, 66.87846332788467, 69.57239717245102, 75.33406600356102, 83.6931386590004, 77.505634278059, 82.88332611322403, 80.07426604628563, 81.96820601820946, 73.14401552081108, 66.74297779798508, 63.67651954293251, 64.00401636958122, 52.79385790228844, 34.18948620557785, 55.4126013815403, 70.56569427251816, 84.70628589391708, 92.56966754794121, 89.75309148430824, 85.08265569806099, 80.16638830304146, 55.84059901535511, 21.876024641096592, 1.5030676522292197, 0.258895693696104, 0.17714797868393362, 0.13142819370841607, 0.14997934747952968, 0.17184983094921336, 0.21594747406197712, 0.26007024629507214, 0.16415916237747297, 0.3492159565212205, 0.25107372435741127, 0.1338757819030434, 0.22561584744835272, 0.24106846045469865, 0.2174203997128643, 0.1740909685031511, 0.23707217333139852, 0.22699404536979273, 0.30660243064630777, 0.14386470371391624, 0.33217719581443816, 0.18530176224885508, 0.15955884126015007, 0.25006369105540216, 0.319613823085092, 0.16608929552603513, 0.19680497702211142, 0.12681743799475953, 0.1857736791134812, 0.2267650334397331, 0.11058749209041707], [0.06865076036774553, 0.11529057097504847, 0.03904444492945913, 0.02985241160786245, 0.08367168833501637, 0.04684825020376593, 0.0864323292626068, 0.03139525499136653, 0.043020085504394956, 0.08723872466362081, 0.0353615890344372, 0.053685166931245476, 0.04489860970352311, 0.0207401127772755, 0.08634580968646333, 0.0720163258665707, 0.05345683035557158, 0.13459464098559693, 0.07455551734892651, 0.0953670080343727, 0.10726875610998832, 0.043886962230317295, 0.05289950342557859, 0.08808529993984848, 0.23513524211011827, 0.45870072848629206, 0.3346602735109627, 0.1892875405610539, 0.20222854771418497, 0.09559079524478875, 0.261264955624938, 0.34693631634581834, 0.31881099741440266, 0.5159803095739335, 0.7480226363986731, 12.639238983392715, 56.44631691277027, 74.61774364113808, 74.09987702965736, 73.22144016623497, 100.91306984424591, 97.1199081838131, 54.75481867790222, 26.09678875654936, 21.419057361781597, 23.626547008752823, 22.82190978527069, 22.376241199672222, 38.120185285806656, 47.56289139389992, 53.096466064453125, 63.565645292401314, 70.16129717230797, 68.07685062289238, 61.889730021357536, 61.99390523135662, 58.9216522872448, 59.91797022521496, 60.136393904685974, 58.074955120682716, 50.27689576148987, 54.47193905711174, 48.6868254840374, 31.76522959023714, 22.409992888569832, 15.313731171190739, 9.329876862466335, 5.452663712203503, 5.219153417274356, 2.048854334279895, 6.352643994614482, 2.351027657277882, 10.178011301904917, 20.190873965620995, 13.221887368708849, 9.370151851326227, 0.8771334146149457, 0.46358688035979867, 0.20021704549435526, 0.22499754937598482, 1.042477386072278, 0.08024655064218678, 0.3336665080860257, 0.08088993330602534, 0.10207436062046327, 0.37641875620465726, 0.20169225696008652, 0.2371753318584524, 0.7111995248124003, 0.5520219693426043, 0.41471713862847537, 0.3731523861642927, 0.10646246460964903, 0.18596309004351497, 0.546372503740713, 0.1456943352241069, 0.14830093597993255, 0.3822482074610889, 2.441561361774802, 0.3940556582529098, 0.19444117730017751, 0.5114776105619967, 0.07421336500556208, 0.9253984841052443, 3.272671764716506, 11.526498142629862, 28.069673292338848, 35.74713662266731, 21.41930054873228, 36.52232922613621, 9.725723471492529, 4.613698655739427, 5.86938782595098, 9.930998906493187, 13.06774104014039, 15.948967784643173, 15.604802202433348, 22.269987501204014, 12.76109654456377, 9.100803304463625, 17.13551301509142, 23.7066638097167, 27.118842713534832, 40.290727615356445, 51.210114285349846, 62.12781764566898, 53.86281654238701, 50.36479264497757, 43.48957076668739, 36.78818956017494, 33.15757177770138, 30.043325386941433, 38.17033879458904, 38.57252061367035, 35.029841512441635, 54.54464055597782, 64.00112092494965, 67.27323174476624, 74.04975771903992, 62.92667157948017, 50.67372366786003, 43.952108547091484, 34.217000529170036, 10.458004977554083, 1.8014008062891662, 0.19966703985119238, 0.20755414006998762, 0.06664103930233978, 0.13558062870288268, 0.15248523879563436, 0.1398384931962937, 0.34531335812062025, 0.011413374086259864, 0.03869911619403865, 0.021221757342573255, 0.1284143765224144, 0.04267732088919729, 0.13043589773587883, 0.03871841574436985, 0.07063652490614913, 0.048372651217505336, 0.023473286819353234, 0.11664314995869063, 0.08209653926314786, 0.16193773626582697, 0.16601796029135585, 0.045584279941977, 0.03967940792790614, 0.0545749537559459, 0.05029033112805337, 0.04932021052809432, 0.039097293265513144, 0.16851165069965646, 0.019388285218155943, 0.024696579966985155, 0.16237196687143296, 0.0425931724748807, 0.03531640337314457, 0.054631215971312486, 0.03160622531140689, 0.10814544031745754, 0.03785450018767733, 0.04155918264586944, 0.019326115507283248, 0.04852970450883731, 0.05663333002303261, 0.19276612030807883, 0.0762209932145197, 0.04688027758675162, 0.06229537873878144, 0.06809547063312493, 0.07618455376359634, 0.06444752536481246, 0.21886059665121138, 0.20240779122104868, 0.18458409060258418, 0.1363094474072568, 0.11185510258655995, 0.008881798894435633, 0.0780740320624318, 0.2142706062295474, 0.4392358276527375, 0.5656925076618791, 0.46696222736500204, 0.4043068550527096, 0.4835718189133331, 0.383739568060264, 0.3921712265582755, 0.4446913255378604, 0.6956527184229344, 1.9941054470837116, 33.563948571681976, 80.33884584903717, 87.4076597392559, 94.03467133641243, 108.37402269244194, 113.5305891931057, 97.18000575900078, 70.89315310120583, 53.23139302432537, 34.583597257733345, 31.155915185809135, 35.76225981116295, 38.93674246966839, 63.8721938431263, 72.61885330080986, 75.61281904578209, 79.79924440383911, 79.15923714637756, 81.81702733039856, 71.77795082330704, 64.05557960271835, 66.16543158888817, 70.57947993278503, 73.10900419950485, 74.99466061592102, 64.24302354454994, 72.86288380622864, 69.77403715252876, 45.11257767677307, 31.962452307343483, 23.534322157502174, 23.527066446840763, 16.453540809452534, 17.389386892318726, 15.949049480259418, 19.443098790943623, 17.943946234881878, 29.066390208899975, 26.279387958347797, 29.181360639631748, 15.897808279842138, 1.2053406843915582, 0.7498376921284944, 0.1546457048971206, 0.1297873942530714, 0.7368227967526764, 0.1951491119689308, 0.2810566686093807, 0.06430819455999881, 0.26207440125290304, 0.6091428792569786, 0.2632554550655186, 0.270074040745385, 0.25612593919504434, 0.19084331957856193, 0.14410956791834906, 0.3499691770412028, 0.23536453605629504, 0.34575407509692013, 0.4566673329100013, 0.19747402315260842, 0.4256518237525597, 0.581995117245242, 6.000417619943619, 3.904455788433552, 1.1448436556383967, 3.191733257845044, 1.050353532191366, 1.6524421493522823, 1.4537624479271472, 7.654573833569884, 28.884186185896397, 40.265371575951576, 30.944751016795635, 41.01652666926384, 23.074917308986187, 10.21383672952652, 9.276201892644167, 14.560782574117184, 20.190180502831936, 22.319778129458427, 23.035519123077393, 32.235942631959915, 26.028717309236526, 26.164827905595303, 37.93360389769077, 43.699570298194885, 45.145947486162186, 56.5728235244751, 69.8409515619278, 85.83216547966003, 81.93912237882614, 67.30128943920135, 51.41540966928005, 46.29703111946583, 48.86599726974964, 44.04632069170475, 49.15632829070091, 50.37649601697922, 42.0137869566679, 50.579629316926, 60.44073097407818, 61.54601566493511, 77.22628086805344, 79.8076343536377, 70.42691051959991, 62.162247598171234, 48.737526163458824, 20.594480708241463, 2.946145785972476, 0.24121843365719542, 0.16842400305904448, 0.13538528059143573, 0.06620798871153966, 0.1077480721869506, 0.030219552063499577, 0.1387792406603694, 0.051906023727497086, 0.02283672263729386, 0.08912353485357016, 0.034798499327735044, 0.052010599756613374, 0.05260947953502182, 0.02354961856326554, 0.019153588436893187, 0.010456792115292046, 0.11019252851838246, 0.11719003116013482, 0.145598835661076, 0.16458485828479752, 0.20248467772034928, 0.07120905473129824, 0.10383244909462519, 0.07875002469518222, 0.04225651573506184, 0.02839149019564502, 0.08671822681208141, 0.17193553416291252, 0.022229660680750385, 0.00919682295716484, 0.021895276768191252, 0.2182462764903903, 0.1777173246955499, 0.11490227931062691, 0.09513306824374013, 0.17957791860681027, 0.14872606785502285, 0.14843429991742596, 0.1163345278473571, 0.20012829947518185, 0.2183694878476672, 0.20998915628297254, 0.17186871118610725, 0.16713610966689885, 0.16422929533291608, 0.1760786329396069, 0.19178048882167786, 0.1570762533810921, 0.4845076077617705, 0.3578195854788646, 0.18312168860575184, 0.19279132364317775, 0.1969083581934683, 0.1669935876270756, 0.12014478823402897, 0.26587372238282114, 0.43785341433249414, 0.46802869357634336, 0.2912015898618847, 0.29164670035243034, 0.3661897941492498, 0.4624711652286351, 0.3596832073526457, 0.2509078098228201, 0.3425892011728138, 0.4775492014596239, 17.096061632037163, 76.1115574836731, 103.06797981262207, 107.18792393803596, 116.82231456041336, 128.55094760656357, 133.13503682613373, 98.89354661107063, 63.57975773513317, 35.95082089304924, 30.151059105992317, 28.57647679746151, 36.026577427983284, 57.956101298332214, 70.76180174946785, 69.19307112693787, 72.31486201286316, 71.50563463568687, 78.80812838673592, 75.06523042917252, 73.2372473180294, 74.5394678413868, 76.55855029821396, 76.49250984191895, 67.07162976264954, 58.580958768725395, 63.575095385313034, 55.782249346375465, 40.4097106307745, 35.03668114542961, 25.172708742320538, 18.75506781041622, 12.113414648920298, 11.45908311009407, 13.18930696696043, 18.188903890550137, 17.509867027401924, 32.34721586108208, 37.75160886347294, 37.59199842810631, 25.384486578404903, 0.5904053128324449, 1.424094708636403, 0.2693977957824245, 0.2372188662411645, 1.861006545368582, 0.34753383428324014, 1.435441137291491, 0.7021035254001617, 0.5775472184177488, 0.9714086714666337, 0.6031311862170696, 0.9324982843827456, 0.9399270638823509, 1.0373883903957903, 0.8704920241143554, 1.168720624409616, 0.6208669720217586, 2.1052962681278586, 1.6109651187434793, 0.8796808810438961, 0.7715659949462861, 1.3318956247530878, 5.113435015082359, 2.7143361372873187, 0.6301914341747761, 4.385943626984954, 3.0574116529896855, 2.2185546532273293, 4.012004267424345, 15.085937194526196, 39.12327826023102, 47.902235984802246, 39.28600832819939, 51.02314531803131, 17.548303864896297, 8.29073142260313, 4.6092291455715895, 8.84832775220275, 16.766064539551735, 30.390149876475334, 35.51419772207737, 46.67192280292511, 30.644567124545574, 31.03819940239191, 39.8631327599287, 42.80600264668465, 47.495669201016426, 57.94383555650711, 63.38365785777569, 73.1114436686039, 72.00172081589699, 67.22530111670494, 56.65825054049492, 50.23379847407341, 51.744380816817284, 49.33551147580147, 55.39657764136791, 58.65569695830345, 49.04634699225426, 69.84766200184822, 83.32401886582375, 84.27542701363564, 84.45948153734207, 84.97202083468437, 75.96787199378014, 72.6282387971878, 49.83619920909405, 15.819950457662344, 1.903951009735465, 0.35424246336333454, 0.3225774859311059, 0.19587303249863908, 0.2264160310733132, 0.16393853671615943, 0.19653256429592147, 0.2379865141119808, 0.14379020693013445, 0.1659512412152253, 0.11202643479919061, 0.211688214330934, 0.14118690130999312, 0.18851388129405677, 0.2138770601595752, 0.15626266656909138, 0.13285332504892722, 0.15364809514721856, 0.3147631458705291, 0.18648719473276287, 0.2537257148651406, 0.3221988718723878, 0.19557042920496315, 0.28849091031588614, 0.13446860946714878, 0.0924539373954758, 0.10169181317905895, 0.16026244178647175, 0.412941713584587, 0.16250193177256733, 0.09150971032795496, 0.16408092516940087], [0.012704796390607953, 0.07944062279420905, 0.024767328904999886, 0.0257018022966804, 0.026750260294647887, 0.16910750622628257, 0.04301788874727208, 0.03391652731806971, 0.0546599185327068, 0.12847318430431187, 0.21693083457648754, 0.03803449697443284, 0.058461900262045674, 0.05164429050637409, 0.12620800116565078, 0.12445604283129796, 0.1839387189829722, 0.11023290135199204, 0.09815345343668014, 0.08323599569848739, 0.08427618988207541, 0.026589358967612498, 0.05380761016567703, 0.04250091609719675, 0.12010907608782873, 0.3327362408163026, 0.3977956669405103, 0.41117195854894817, 0.319488518871367, 0.33659944601822644, 0.2166537314769812, 0.15477458626264706, 0.16910804057260975, 0.7680111669469625, 1.1556468321941793, 0.2295865601627156, 15.82007110118866, 54.81406129896641, 63.80836486816406, 81.08908519148827, 75.94765707850456, 87.34395995736122, 92.18037843704224, 84.79280725121498, 56.50749742984772, 52.56652370095253, 37.09751196205616, 37.296134904026985, 33.87303538620472, 35.608212277293205, 32.79099404811859, 40.068234354257584, 48.45954068005085, 56.445556953549385, 48.71296048164368, 53.43409314751625, 62.513367757201195, 73.65973144769669, 59.213165044784546, 39.424985870718956, 37.97768533229828, 39.21173371374607, 26.067053452134132, 22.652598470449448, 20.49261387437582, 29.877737872302532, 29.630996212363243, 14.670142605900764, 4.909531781449914, 2.873745420947671, 3.26581503264606, 1.382340886630118, 10.425839703530073, 22.616931684315205, 15.264881942421198, 8.038386013358831, 0.35160222847480327, 0.5100383190438151, 0.4341112682595849, 0.4584297852125019, 0.5224837199784815, 0.5427649535704404, 0.6639690091833472, 0.41087207151576877, 0.06367575857439078, 0.24385298369452357, 0.41716290113981813, 0.2657306659966707, 0.6857265229336917, 0.8075470360927284, 0.229229794931598, 0.3241384302964434, 0.2775760256918147, 0.31300170288886875, 0.3295755822909996, 0.33793649927247316, 0.38598382263444364, 0.33190497604664415, 0.8137996005825698, 0.6022630515508354, 0.12078098690835759, 0.022168923314893618, 0.4485289118019864, 2.639410332776606, 6.164545062929392, 16.18663363158703, 37.342819198966026, 48.751855194568634, 29.261418543756008, 31.693314649164677, 31.858495585620403, 24.829049482941628, 20.62965352088213, 13.20293778553605, 12.201774157583714, 11.43018376082182, 14.899137318134308, 22.159010656177998, 13.442704919725657, 19.245760180056095, 16.483682692050934, 14.363463912159204, 17.21864875406027, 23.997543901205063, 28.532539755105972, 22.193774990737438, 22.037899754941463, 29.072532579302788, 33.56909729540348, 30.736881271004677, 32.35062047839165, 32.91874319314957, 38.148311376571655, 41.71369045972824, 53.08205343782902, 67.05660536885262, 61.29549130797386, 62.415405213832855, 69.45334196090698, 53.8231048732996, 32.1333709359169, 21.84226155281067, 6.950045563280582, 0.7940134685486555, 0.256279029417783, 0.10135438831639476, 0.06815933986217715, 0.049972346823778935, 0.12277424713829532, 0.3048269165446982, 0.1533622940769419, 0.3268340294016525, 0.10900381574174389, 0.075314801215427, 0.05800873746920843, 0.07996802261914127, 0.032433567830594257, 0.15636342053767294, 0.1352372221299447, 0.12502501776907593, 0.10560075694229454, 0.08617705272627063, 0.10192878093221225, 0.11823555396404117, 0.11543030996108428, 0.05101460046716966, 0.08701661470695399, 0.08295071413158439, 0.007985054435266647, 0.019255078987043817, 0.034001176682068035, 0.03422662259254139, 0.07847125918488018, 0.05436197963717859, 0.024947546480689198, 0.03406532792723738, 0.019766645091294777, 0.0636132548970636, 0.10106743691721931, 0.03628344406024553, 0.06360509869409725, 0.05511803516128566, 0.0668223162938375, 0.05299911819747649, 0.041991684047388844, 0.15592102630762383, 0.12228275983943604, 0.13539915875298902, 0.03897084985510446, 0.04947623594489414, 0.14016300468938425, 0.10151340087759309, 0.06483501550974324, 0.16642514703562483, 0.19456000998616219, 0.11633387475740165, 0.06365318986354396, 0.027815733883471694, 0.061441912621376105, 0.04390272544696927, 0.1063783495919779, 0.20192842319374904, 0.6829342665150762, 0.6484749843366444, 0.562016264302656, 0.5395327520091087, 0.643190952250734, 0.455866793054156, 0.17333421536022797, 0.5549523839727044, 0.4620332387275994, 0.5844683095347136, 29.57439634948969, 73.31271886825562, 77.43679717183113, 92.14224368333817, 102.72760167717934, 107.57355764508247, 102.44694113731384, 89.80406954884529, 60.9442837536335, 52.89560504257679, 37.201181799173355, 43.22278708219528, 45.910185277462006, 59.066914692521095, 61.85514807701111, 62.739417627453804, 68.72443467378616, 69.54275876283646, 61.48866534233093, 59.79454144835472, 63.59073154628277, 81.62114024162292, 87.49729692935944, 65.24146556854248, 57.74319492280483, 60.366836339235306, 45.27893655002117, 38.2158337533474, 37.563834339380264, 41.21571198105812, 37.80013985931873, 24.448678493499756, 13.092129081487656, 11.152066234499216, 9.71329528838396, 11.513898968696594, 22.686192467808723, 31.479000449180603, 24.22628402709961, 14.831708036363125, 0.8416570932604373, 0.2501212520292029, 0.2569768263492733, 0.18853705114452168, 0.4153909196611494, 0.526666761143133, 0.4464606649708003, 0.35554525908082724, 0.12185953528387472, 0.13348348264116794, 0.37755510304123163, 0.410123600740917, 0.4335890634683892, 0.45028124121017754, 0.028151839578640647, 0.08710528651135974, 0.48625017050653696, 0.5413323710672557, 0.567588071571663, 0.33165537694003433, 0.42798020818736404, 1.0165953123942018, 1.6142786596901715, 1.6577409650199115, 0.4673525376711041, 0.19708797277417034, 0.30944313446525484, 2.390883006155491, 6.823097700253129, 16.18577677756548, 36.59982606768608, 55.70943385362625, 45.10158486664295, 47.25769557058811, 26.323480792343616, 23.839196898043156, 18.200219683349133, 19.08844482153654, 27.12972342967987, 30.52883293479681, 32.88633853197098, 32.76608258485794, 25.978455506265163, 28.45093533396721, 25.33410508185625, 25.26233833283186, 28.588968627154827, 34.157248735427856, 34.32139612734318, 29.05721180140972, 23.49613420665264, 25.100752003490925, 33.36929641664028, 42.250791639089584, 44.5870316773653, 39.88411523401737, 44.34799790382385, 46.028556525707245, 52.1457114815712, 65.29578745365143, 64.68359470367432, 69.26180183887482, 78.16654801368713, 75.89483231306076, 53.07752788066864, 35.497687608003616, 13.501641657203436, 1.3162635010667145, 0.2169346937444061, 0.012165239259047667, 0.05156999781320337, 0.09047716768691316, 0.1425788289634511, 0.07651806008652784, 0.18973900383571163, 0.18966682255268097, 0.13658091018442065, 0.0347746726765763, 0.06792875457904302, 0.04173659304797184, 0.1373612933093682, 0.16746802779380232, 0.06222516414709389, 0.07138902554288507, 0.05460832442622632, 0.022163696739880834, 0.08859218680299819, 0.10549805854680017, 0.11020547899533994, 0.02952300194010604, 0.10715946002164856, 0.10908099167863838, 0.03655735963548068, 0.024348967272089794, 0.1028516267251689, 0.08790092077106237, 0.11338862459524535, 0.10089182993397117, 0.04073734315170441, 0.04324604720750358, 0.17014222336001694, 0.21564003196544945, 0.15294366341549903, 0.10128441863344051, 0.18073271523462608, 0.15506584953982383, 0.11603426974033937, 0.15419108007336035, 0.20045810990268365, 0.26256466400809586, 0.2621376916067675, 0.22237025754293427, 0.1538733221241273, 0.21540156507398933, 0.20428992225788534, 0.2384672180050984, 0.2686952194198966, 0.38010346004739404, 0.3659247880568728, 0.2804399438900873, 0.23699758748989552, 0.2295735280495137, 0.13164059637347236, 0.1399836127529852, 0.2277078726910986, 0.2770297456299886, 0.718865969683975, 0.6365220132283866, 0.34750684979371727, 0.28737172193359584, 0.38399566838052124, 0.32952090085018426, 0.16085767390904948, 0.42244227253831923, 0.8964438003022224, 0.16520703036803752, 18.214138336479664, 66.94893434643745, 79.52055215835571, 106.13596558570862, 115.26847913861275, 126.54315054416656, 133.13883662223816, 124.2114968597889, 86.09875917434692, 70.74545502662659, 51.23846456408501, 49.87778797745705, 48.75754728913307, 64.02868464589119, 60.37244103848934, 60.34243784844875, 63.32634933292866, 64.51274067163467, 61.47058591246605, 65.72241336107254, 74.7530847787857, 87.69802495837212, 89.17715638875961, 63.927990049123764, 50.91546669602394, 52.46106036007404, 40.461228266358376, 37.451884746551514, 39.6195088326931, 43.32852400839329, 34.4725976139307, 18.11236459761858, 7.208549017086625, 6.351514030247927, 6.245680684223771, 9.527646750211716, 30.59375625103712, 42.977118864655495, 30.207438580691814, 24.73835974931717, 0.7570600952021778, 0.8612021163571626, 1.2383125838823617, 0.4451035737292841, 1.4444429730065167, 1.3320635282434523, 0.887534050270915, 0.8185106352902949, 0.151370978273917, 0.32904960738960654, 0.7206326373852789, 0.5506602174136788, 2.1099286945536733, 1.7311565880663693, 0.4825840797275305, 0.8722928306087852, 1.5607492695562541, 1.2309856270439923, 1.2535025062970817, 0.4349929396994412, 0.7835341652389616, 0.9330002730712295, 1.0006954218260944, 0.9539137571118772, 0.3042095387354493, 0.13573888427345082, 1.1642179847694933, 5.375151671469212, 12.329914681613445, 21.140207424759865, 47.39404745399952, 67.90468946099281, 45.747272819280624, 51.217060312628746, 48.80472555756569, 45.52633747458458, 32.72306889295578, 27.816365584731102, 28.123997077345848, 34.064233526587486, 36.68209545314312, 42.526098266243935, 33.35629731416702, 37.93280974030495, 31.03349145501852, 31.915365234017372, 29.433131329715252, 34.497262090444565, 34.85826171934605, 31.606911085546017, 31.98031894862652, 37.79831975698471, 43.447769209742546, 49.21236388385296, 52.69793584942818, 48.055071383714676, 57.05968759953976, 54.837384447455406, 72.10333496332169, 94.36983615159988, 86.02520272135735, 84.82691422104836, 90.50499513745308, 80.87469309568405, 60.85248447954655, 35.15188716351986, 9.708678536117077, 1.0695655387826264, 0.31767693639267236, 0.21835654479218647, 0.10024058050476015, 0.19807560805929825, 0.16951222904026508, 0.26924912875983864, 0.32468851015437394, 0.43338126211892813, 0.21216195687884465, 0.22516171244205907, 0.20982226211344823, 0.16298956732498482, 0.1924671238521114, 0.35241303965449333, 0.31235027534421533, 0.1498946239007637, 0.1653073390480131, 0.20209052308928221, 0.24853796901879832, 0.22924478631466627, 0.163974842580501, 0.107944867486367, 0.20479704660829157, 0.3167056431993842, 0.12120923580368981, 0.13718596834223717, 0.1376363035524264, 0.13042598264291883, 0.17204448144184425, 0.183763082313817, 0.13042884733295068, 0.13455189327942207], [0.013873611260351026, 0.008041940982366214, 0.03181258689437527, 0.10569672405836172, 0.07190082542365417, 0.14186322048772126, 0.08235289933509193, 0.07929317289381288, 0.09903156256768852, 0.17087901273043826, 0.131051390490029, 0.17860628402559087, 0.0390120501833735, 0.04885342190391384, 0.027412589988671243, 0.024657474350533448, 0.14701797044835985, 0.09333205394796096, 0.16992959805065766, 0.2145255042705685, 0.08655045690829866, 0.18068302102619782, 0.08863945418852381, 0.10647906645317562, 0.19615160505054519, 0.10363355351728387, 0.2000167843652889, 0.4458250303287059, 0.6211875798180699, 0.4103185184067115, 0.34408207575324923, 0.10754298709798604, 0.13438017514999956, 0.16006160178221762, 0.3032608958892524, 0.848586733918637, 0.38717396033462137, 7.116089528426528, 45.91254875063896, 61.15807548165321, 67.53375336527824, 67.57747381925583, 75.69647535681725, 90.68887487053871, 96.29058748483658, 86.8048144876957, 70.87789312005043, 62.578025087714195, 51.33336067199707, 43.54632072150707, 36.40486232936382, 37.35276326537132, 32.243059650063515, 36.732951924204826, 41.263718605041504, 42.27917231619358, 36.53395280241966, 36.67794227600098, 38.25378231704235, 32.60841004550457, 34.09129947423935, 33.20409268140793, 27.624301090836525, 21.20963729918003, 17.46140442788601, 23.421318121254444, 26.28021251410246, 21.86371710151434, 13.40255532413721, 7.413511918857694, 4.502536095678806, 11.927940901368856, 28.120999038219452, 23.20762898772955, 20.414233580231667, 9.44222828373313, 2.460202923975885, 0.5196685460396111, 0.10932057179161347, 0.2121864032233134, 0.1289342064410448, 0.11286915090749972, 0.3240736556472257, 0.3275334293721244, 0.13080180622637272, 0.0968311243923381, 0.21555939019890502, 0.20522096136119217, 0.5288199987262487, 0.4714078997494653, 0.22782051586546004, 0.590446813730523, 0.07309730848646723, 0.13592065108241513, 0.5170389683917165, 0.16510709276190028, 0.13918069802457467, 0.5405873735435307, 1.086951030883938, 0.2310766591108404, 0.2103114264900796, 0.16983246576273814, 1.2981032067909837, 4.386597666889429, 9.279551412910223, 17.138615548610687, 32.779514864087105, 44.50793892145157, 41.1670745909214, 52.91648492217064, 57.62283258140087, 51.85283839702606, 54.96372006833553, 55.27409501373768, 27.391415387392044, 14.44480424746871, 8.65430636331439, 10.126004442572594, 6.3451664708554745, 10.6621727719903, 5.687569007277489, 7.716510510072112, 14.494178798049688, 23.28392319381237, 37.07171894609928, 41.8495711684227, 41.14677608013153, 39.47637051343918, 37.850361764431, 39.24556329846382, 47.285422682762146, 48.59040945768356, 49.11150209605694, 56.84780716896057, 57.406707778573036, 48.851972222328186, 47.570160403847694, 53.75583328306675, 39.01927024126053, 23.095711693167686, 15.994924418628216, 4.180166143923998, 0.5307942302897573, 0.34595783916302025, 0.008594456940045347, 0.05200311519729439, 0.05753545876359567, 0.05818238147185184, 0.2559345244662836, 0.08374260796699673, 0.18793082039337605, 0.13115637470036745, 0.06060004627215676, 0.12388712726533413, 0.2403199451509863, 0.04451483771845233, 0.0788574579928536, 0.041088186044362374, 0.16773521580034867, 0.16232031339313835, 0.1307351465220563, 0.0342961358546745, 0.2679908322170377, 0.09039528653374873, 0.15279642131645232, 0.08386244255234487, 0.15602302708430216, 0.06767921484424733, 0.14540721313096583, 0.04283077105355915, 0.019000268148374744, 0.02978969827381661, 0.00949032566495589, 0.06904299283633009, 0.056522820523241535, 0.08080772560788319, 0.026834616510313936, 0.02742924934864277, 0.07941678501083516, 0.09917704577674158, 0.0315891150967218, 0.0751760344428476, 0.09719093985040672, 0.13799643813399598, 0.07452744932379574, 0.14811056025791913, 0.07119283880456351, 0.11258150931098498, 0.03629634258686565, 0.05600372162007261, 0.06315265578450635, 0.07024605132755823, 0.0851965049514547, 0.06021437067829538, 0.09633622321416624, 0.12820773292332888, 0.07204267210909165, 0.035944824339821935, 0.03357095738465432, 0.03134647733531892, 0.13180054404074326, 0.10570118436589837, 0.31739984813611954, 0.5617099651135504, 0.6406222900841385, 0.641083549708128, 0.46482620760798454, 0.35121886467095464, 0.15057973010698333, 0.2278109866892919, 0.2917741419514641, 1.1471588001586497, 1.0394544107839465, 16.530539877712727, 56.992731392383575, 80.98590552806854, 78.2984009385109, 89.75906476378441, 103.05702120065689, 113.45249578356743, 102.16166004538536, 76.1695347726345, 64.44014936685562, 54.08296912908554, 55.16103208065033, 56.90754756331444, 57.49058447778225, 65.7678285241127, 60.743886306881905, 54.60187308490276, 53.03676746785641, 52.226521745324135, 41.80590011179447, 35.42866811156273, 32.35424168407917, 38.285787999629974, 43.85580651462078, 36.09471157193184, 31.299788765609264, 30.305648110806942, 30.819108858704567, 38.03106106817722, 39.702169597148895, 30.77471774071455, 25.12081302702427, 16.462521627545357, 12.827309891581535, 20.03702972084284, 43.908247500658035, 46.39069989323616, 31.22090119868517, 19.22224324196577, 1.285891612060368, 0.7873230369295925, 0.4436285106930882, 0.18207732355222106, 0.1166182137967553, 0.013669848121935502, 0.07654230605112389, 0.4042857780586928, 0.21795023378217593, 0.2980542549630627, 0.3108796355081722, 0.5340963718481362, 0.29891517595387995, 0.03248323606385384, 0.26295292598661035, 0.687854764983058, 0.23691471928032115, 0.3089401958277449, 0.1915606646798551, 0.20240623271092772, 0.21756801288574934, 1.0416903533041477, 1.4974373043514788, 1.061200168915093, 0.5933654133696109, 0.4956833424512297, 1.7111814161762595, 3.485804940573871, 8.855761103332043, 18.840977400541306, 40.72496451437473, 53.84518928825855, 48.1920350342989, 59.06005226075649, 65.30534774065018, 58.412893787026405, 51.84048146009445, 40.44112354516983, 30.88175229728222, 28.34222886711359, 25.4243141412735, 34.889492243528366, 25.47689002007246, 23.30945212393999, 21.090023517608643, 15.355888959020376, 13.589072115719318, 12.750288974493742, 23.363747410476208, 31.370913349092007, 37.75241822004318, 43.54784443974495, 46.189067512750626, 45.37818722426891, 46.2007062882185, 47.931904792785645, 53.84732477366924, 61.71933576464653, 67.30455726385117, 62.319680750370026, 64.9147666990757, 76.04278117418289, 61.967762634158134, 43.80339972674847, 26.335328556597233, 6.807092009112239, 0.4831888113403693, 0.11676768233883195, 0.013556422909459798, 0.07210654133814387, 0.23970241891220212, 0.1730666117509827, 0.06873073420138098, 0.1208910696732346, 0.07388045982224867, 0.08486709528369829, 0.04193408225546591, 0.03915603425411973, 0.08960750419646502, 0.09192644851282239, 0.1493605150608346, 0.11861181541462429, 0.05314488342264667, 0.09455382198211737, 0.05590504937572405, 0.038810456899227574, 0.332270854851231, 0.39534162206109613, 0.2554874250199646, 0.17013072007102892, 0.04315014688472729, 0.027158461925864685, 0.04765830068208743, 0.056464376393705606, 0.027008538818336092, 0.1259549436508678, 0.024086412122414913, 0.02698613523534732, 0.04924340195429977, 0.012169696783530526, 0.18782467843266204, 0.14079396380111575, 0.22166181821376085, 0.39917805057484657, 0.14459074678597972, 0.1916154648642987, 0.1849566338933073, 0.31562703545205295, 0.2918311092071235, 0.37450941803399473, 0.2787774143507704, 0.3054464020533487, 0.07163624235545285, 0.21484945173142478, 0.14402005006559193, 0.147631875006482, 0.2224513891269453, 0.17890378134325147, 0.3802154946606606, 0.43245880224276334, 0.287292935536243, 0.23534071311587468, 0.21018489031121135, 0.3203212085645646, 0.3183031902881339, 0.2595557598397136, 0.23079387116013095, 0.35086539457552135, 0.6004894967190921, 0.6933094910345972, 0.4461041372269392, 0.2403522582608275, 0.2714429469779134, 0.1518290615058504, 0.3226636641193181, 1.011136311572045, 0.26442228932864964, 6.674639191478491, 52.24099136888981, 80.33378452062607, 91.15393951535225, 104.28852751851082, 125.03259479999542, 136.31080001592636, 138.87295693159103, 115.56783467531204, 95.29764756560326, 78.72206300497055, 71.2662398815155, 64.84295815229416, 58.59967276453972, 65.85694134235382, 59.563753232359886, 53.15616846084595, 51.86632767319679, 55.545392856001854, 51.25398673117161, 46.21581427752972, 44.67868275940418, 45.802875235676765, 47.00255826115608, 38.590174466371536, 29.906483329832554, 30.217977315187454, 25.144761241972446, 31.11974112689495, 35.34839741885662, 32.483662739396095, 26.153082735836506, 13.861015923321247, 11.971153132617474, 19.985559582710266, 52.84341484308243, 44.040244817733765, 44.02671754360199, 18.85594479739666, 2.2940364154055715, 0.9340738342143595, 0.3392609063303098, 0.3983794996747747, 0.5389324435964227, 0.1149955895380117, 0.35628803016152233, 1.068063194397837, 0.3757951146690175, 0.5835536273662001, 0.5280292849056423, 0.6495018792338669, 1.2448227033019066, 0.5423015565611422, 0.344333010725677, 0.8005306532140821, 0.14760532096261159, 0.3729346103500575, 0.6549175386317074, 0.5371299153193831, 0.30899312580004334, 1.508192508481443, 1.8460792838595808, 0.6916152569465339, 0.6678658188320696, 0.34963538870215416, 1.7124078003689647, 8.69606327265501, 16.096126288175583, 25.633897595107555, 51.59521222114563, 65.30066639184952, 57.919665053486824, 71.75794869661331, 77.9594287276268, 78.27529817819595, 85.3252574801445, 83.65501910448074, 52.167446315288544, 35.419240817427635, 35.717521011829376, 46.63093060255051, 41.72964580357075, 42.24914252758026, 31.634959280490875, 30.139203742146492, 34.48490895330906, 37.9193052649498, 58.25160004198551, 62.366604432463646, 62.262733206152916, 60.695446506142616, 62.30730101466179, 65.50057366490364, 69.63442504405975, 67.6619964838028, 74.6386881172657, 89.285708963871, 88.13658222556114, 72.1517063677311, 70.5381153523922, 85.14991968870163, 64.94242921471596, 46.57053284347057, 28.37426494807005, 5.6742326728999615, 0.7696215680334717, 0.27987525856588036, 0.20100538444239646, 0.24680634553078562, 0.2974565885961056, 0.4466191283427179, 0.3032477747183293, 0.1582202294957824, 0.47108352184295654, 0.16487488959683105, 0.1387072671786882, 0.27225809230003506, 0.3066907462198287, 0.25396103505045176, 0.4146994458278641, 0.36800292029511184, 0.35223498358391225, 0.2639035281026736, 0.2039021797827445, 0.11789087089709938, 0.4224794392939657, 0.5051953601650894, 0.47947920102160424, 0.27718503260985017, 0.1824605092406273, 0.22162566077895463, 0.2762660459848121, 0.17353603499941528, 0.1181601666030474, 0.13225635630078614, 0.09091303101740777, 0.18259647069498897, 0.15863019187236205, 0.1461008985643275], [0.047695649263914675, 0.07469356423825957, 0.024329283660335932, 0.0454846874345094, 0.050784772174665704, 0.025625802663853392, 0.06891850498504937, 0.12722935964120552, 0.10382129461504519, 0.14706236572237685, 0.3223793028155342, 0.17741150048095733, 0.028260432482056785, 0.12099370127543807, 0.0961333274608478, 0.12383391527691856, 0.1868620386812836, 0.13696687150513753, 0.14258129289373755, 0.13290655188029632, 0.3117375879082829, 0.1265496711130254, 0.10528975253691897, 0.1086764395586215, 0.10693381744204089, 0.09095863599213772, 0.11295937380054966, 0.17452797474106774, 0.3638941829558462, 0.4208289325470105, 0.47116260509938, 0.20012979861348867, 0.2715451258700341, 0.15350049681728706, 0.3273096273187548, 0.13650673994561657, 0.469271523761563, 0.5222492606844753, 4.484560685232282, 24.58364725112915, 63.62914748489857, 71.85542106628418, 70.50168290734291, 71.6582116484642, 68.78283753991127, 81.02469384670258, 88.95515710115433, 71.78695634007454, 60.63786059617996, 52.25486442446709, 39.48963940143585, 42.074108719825745, 43.97562928497791, 31.80688675493002, 29.92636576294899, 34.16771337389946, 42.08036318421364, 51.07884272933006, 54.01852458715439, 46.86122864484787, 31.667648926377296, 34.07705783843994, 34.53472428023815, 27.318199016153812, 26.229677125811577, 29.892735667526722, 28.659701831638813, 28.83404217660427, 31.25652238726616, 24.060839004814625, 38.38285759091377, 64.35934290289879, 59.82087403535843, 34.62881863117218, 6.888482216745615, 15.078127663582563, 11.192353572696447, 5.690092071890831, 1.9154873094521463, 0.8321905543562025, 1.1357011087238789, 0.5586225120350718, 0.3651666396763176, 1.1536566889844835, 0.4178318730555475, 0.29608815733809024, 0.4100773500977084, 0.3555160778341815, 1.3228086498565972, 0.8724878670182079, 0.5839156173169613, 0.2917540742782876, 0.1270505614229478, 0.23238513967953622, 0.3011333366157487, 0.1175380613130983, 0.3144641197286546, 0.7053976517636329, 0.05916761219850741, 0.4204522183863446, 0.42922621476463974, 1.0277117346413434, 3.7977838749065995, 12.757787872105837, 18.257930986583233, 9.526881091296673, 29.499139487743378, 41.10818915069103, 40.034594759345055, 54.29677225649357, 63.37108053267002, 57.60976508259773, 58.40218596160412, 69.06437203288078, 62.44788207113743, 54.08672712743282, 38.20951849222183, 24.541674703359604, 13.58975512906909, 14.142246432602406, 18.22019711136818, 24.372382387518883, 33.97889010608196, 39.980915039777756, 41.9505849480629, 45.46909734606743, 31.073968783020973, 28.13136488199234, 32.50129759311676, 35.80594226717949, 43.52538384497166, 43.9171352237463, 46.992287412285805, 36.00347846746445, 24.26315724849701, 38.43225874006748, 51.09949082136154, 31.413778848946095, 11.351848114281893, 10.072015039622784, 1.9207888562232256, 0.06898079343955033, 0.03578310293960385, 0.05016336821427103, 0.309844309813343, 0.15755053027532995, 0.10736851560068317, 0.25112148898188025, 0.06344860943499953, 0.23860108660301194, 0.17708470317302272, 0.14087680232478306, 0.09623660473152995, 0.06052179422113113, 0.23369678179733455, 0.15762498253025115, 0.1306231415946968, 0.07081942720105872, 0.05824946791108232, 0.11559524486074224, 0.20379827910801396, 0.3016273397952318, 0.15695937996497378, 0.1267537914100103, 0.13908028544392437, 0.1029110950184986, 0.11147989498567767, 0.13325594016350806, 0.39366891025565565, 0.30404537566937506, 0.019112376976408996, 0.03330059669679031, 0.02896399219025625, 0.054108688345877454, 0.043239041333436035, 0.06786058089346625, 0.07129619029001333, 0.027520598450792022, 0.16945073468377814, 0.0372209806664614, 0.024667192774359137, 0.053044738015159965, 0.056222295243060216, 0.057591999284341, 0.021456860449688975, 0.06948045920580626, 0.0736078541376628, 0.03561982674000319, 0.026259854676027317, 0.09571109738317318, 0.06250501319300383, 0.05342555625247769, 0.0707892217906192, 0.09481832341407426, 0.06336322534480132, 0.0964728748658672, 0.036437591843423434, 0.03978357206506189, 0.08713056406122632, 0.056960127330967225, 0.03765198664041236, 0.16273063200060278, 0.26135318214073777, 0.42755863862112164, 0.7648532395251095, 0.6690109230112284, 0.7331109896767884, 0.23169577354565263, 0.3251774370437488, 0.40309133590199053, 0.46965800458565354, 0.22834849456558004, 0.4110720951575786, 0.6145545013714582, 10.70559399202466, 37.4137119948864, 73.84966805577278, 76.34940952062607, 86.80419892072678, 105.06297156214714, 108.38859111070633, 105.12717291712761, 86.71797394752502, 63.61480325460434, 55.66885203123093, 48.36824677884579, 39.405587911605835, 56.36226922273636, 59.569745510816574, 56.297163516283035, 44.275832176208496, 46.32945857942104, 47.69478231668472, 44.08345229923725, 39.07728172838688, 33.85607309639454, 31.16946905851364, 33.07361528277397, 24.575376994907856, 28.172271586954594, 33.25005121529102, 30.3712971881032, 23.16819280385971, 21.268680430948734, 19.11175277084112, 20.05600780248642, 30.958538576960564, 52.01015755534172, 62.518451884388924, 46.26912161707878, 41.076601445674896, 25.885311104357243, 11.153298318386078, 5.092609282582998, 3.1194575736299157, 0.59436280047521, 0.2367897267686203, 0.12619427143363282, 0.5015489214565605, 1.3060355186462402, 0.5054115923121572, 0.83124571130611, 0.49320501449983567, 0.2980055403895676, 0.727893632138148, 0.11191343539394438, 0.3739075956400484, 0.25555519794579595, 0.16359373490558937, 0.09333103720564395, 0.6566303560975939, 0.031055371764523443, 0.4177731543313712, 0.8611615060362965, 0.6023107271175832, 0.16332561179297045, 0.8741330006159842, 1.0604924568906426, 5.532003454864025, 8.863638080656528, 14.422446247190237, 21.876552812755108, 41.58269628882408, 59.15120556950569, 55.14902092516422, 62.92014352977276, 64.01859238743782, 72.2311221063137, 79.09554496407509, 77.22757279872894, 55.841632559895515, 44.4181839376688, 33.90275739133358, 30.605404525995255, 29.84187539666891, 29.28559474647045, 20.834238342940807, 21.254516690969467, 32.00823985040188, 46.85720846056938, 52.48401492834091, 53.46113249659538, 50.32335206866264, 46.01392351090908, 43.42374309897423, 45.33748000860214, 48.70599925518036, 52.84276507794857, 54.76761259138584, 54.237446039915085, 44.33050364255905, 56.274550929665565, 63.72203730046749, 47.248625457286835, 28.876791782677174, 16.99781410396099, 3.1984508223831654, 0.13041541446000338, 0.027752157802751753, 0.0558331760839792, 0.13782954396447167, 0.15814417420187965, 0.15557761973468587, 0.08699178986717016, 0.03797277626290452, 0.1276611560024321, 0.06554165884153917, 0.03852128276776057, 0.03699586130096577, 0.01010478312309715, 0.06683320360025391, 0.1661503891227767, 0.1334561567637138, 0.12772552989190444, 0.03826977263088338, 0.017047139554051682, 0.13269072049297392, 0.2780909277498722, 0.4610045033041388, 0.35832391935400665, 0.18325143086258322, 0.167455262853764, 0.09836705095949583, 0.013676610942638945, 0.13359612581552938, 0.16176821489352733, 0.025170227891067043, 0.1458979953895323, 0.1162313247914426, 0.17584687506314367, 0.2033459846279584, 0.03411967169085983, 0.1398914380115457, 0.148361302271951, 0.16993278928566724, 0.10350747004849836, 0.07434609069605358, 0.07693765553995036, 0.1977041334612295, 0.21797285444336012, 0.1660731018637307, 0.28261479281354696, 0.48101595137268305, 0.22577468189410865, 0.2540952153503895, 0.21628449816489592, 0.19819049251964316, 0.19179261551471427, 0.19405959465075284, 0.3305815189378336, 0.33856462338007987, 0.36652607610449195, 0.39868769876193255, 0.28423445590306073, 0.14468694396782666, 0.18411977333016694, 0.2038524262025021, 0.16931579739321023, 0.15471629798412323, 0.29746487096417695, 0.39512904128059745, 0.5291252885945141, 0.694437496131286, 0.5241292691789567, 0.6268667313270271, 0.4279723414219916, 0.3591577667975798, 0.19202018767828122, 0.41923637269064784, 0.35789050511084497, 3.6578568583354354, 30.813595354557037, 81.92937970161438, 92.27674126625061, 107.53193467855453, 124.75857630372047, 123.51092085242271, 129.73122507333755, 121.52865082025528, 99.10269498825073, 82.61074393987656, 77.75240823626518, 57.898975163698196, 67.40802571177483, 70.12580707669258, 61.75637237727642, 50.57417280972004, 52.48862408101559, 56.316561475396156, 58.443197160959244, 61.157665103673935, 57.56477929651737, 50.52658036351204, 52.73284837603569, 53.41762863099575, 45.52779659628868, 44.075453728437424, 47.22549989819527, 44.38223026692867, 41.426228284835815, 48.745897114276886, 38.63410770893097, 56.925003826618195, 86.8096174299717, 83.26760709285736, 52.60636456310749, 37.22432255744934, 31.14209532737732, 16.43294021487236, 8.512453325092793, 6.515824813395739, 0.6110488926060498, 0.6146474776323885, 0.6139299692586064, 0.4017544904490933, 2.2572334902361035, 1.333737694658339, 1.8213955708779395, 0.7034955569542944, 0.676118500996381, 2.2873418871313334, 1.7282606684602797, 1.3188341818749905, 1.1719148280099034, 0.269175834255293, 0.921549528138712, 0.9927898866590112, 0.2757458301493898, 1.6324106929823756, 1.5297980303876102, 1.2420252221636474, 1.115992753766477, 1.6161812888458371, 3.191374414600432, 9.086631014943123, 17.80713837593794, 26.60909816622734, 20.879013240337372, 46.669224947690964, 64.17843461036682, 57.52894341945648, 67.4785803258419, 71.26354202628136, 72.98028230667114, 82.26775154471397, 96.02423697710037, 95.07231205701828, 93.7050162255764, 88.84752407670021, 75.24128258228302, 64.68659654259682, 70.82214251160622, 70.07750406861305, 66.85637891292572, 75.27855098247528, 75.96289426088333, 72.66121342778206, 70.56558027863503, 66.59595608711243, 69.28523138165474, 72.78734385967255, 74.42839980125427, 76.745865046978, 85.65061122179031, 81.04560792446136, 63.46265181899071, 52.927405536174774, 62.54311256110668, 68.14671367406845, 47.147832065820694, 30.12223195284605, 15.526913031935692, 1.8810412078164518, 0.28430071484763175, 0.23835381784010679, 0.11462156937341206, 0.26217720354907215, 0.23102833045413718, 0.28427010867744684, 0.28016306343488395, 0.25438634504098445, 0.30668540275655687, 0.21114448725711554, 0.18324400938581675, 0.2210523813846521, 0.19705764862010255, 0.2604071516543627, 0.34398013434838504, 0.28629201580770314, 0.20302700955653563, 0.17785812495276332, 0.14480212528724223, 0.2670662052696571, 0.3143153339624405, 0.40992129128426313, 0.30214262777008116, 0.32096652081236243, 0.2332734310766682, 0.16066743177361786, 0.3152416826924309, 0.33642637718003243, 0.32823760877363384, 0.1129476330243051, 0.25330717326141894, 0.22214345721295103, 0.13993681292049587, 0.3434428194304928, 0.16998019767925143], [0.044857902903459035, 0.04274363920558244, 0.0732757430523634, 0.07112820516340435, 0.02972715377836721, 0.08055024489294738, 0.03008472795045236, 0.05723274785850663, 0.024357871188840363, 0.15765125455800444, 0.294375903904438, 0.21102240396430716, 0.1735627226298675, 0.10605142611893825, 0.02538432636356447, 0.12522127130068839, 0.0740067362494301, 0.07650942890904844, 0.26124604570213705, 0.018971020108438097, 0.0829415040789172, 0.03337730136991013, 0.06968334753764793, 0.2368581824703142, 0.2212986259837635, 0.1648480090079829, 0.12687275768257678, 0.2350916335126385, 0.15768606128403917, 0.0443205249030143, 0.027042237888963427, 0.13560584688093513, 0.24706617143237963, 0.3394801961258054, 0.5609968502540141, 0.13576710072811693, 0.2444205485517159, 0.2433415103587322, 0.16934677463723347, 1.6402088245376945, 15.14834314584732, 36.13470442593098, 62.941874563694, 61.83743342757225, 57.058536261320114, 58.92759516835213, 69.09878298640251, 80.10841101408005, 64.11001548171043, 54.20723386108875, 65.59192076325417, 53.83633956313133, 52.23782233893871, 37.303688898682594, 29.578296840190887, 29.75685115903616, 36.46398335695267, 33.03434818983078, 44.033899158239365, 61.51389978826046, 50.788488909602165, 43.78474272787571, 51.159690991044044, 50.76447419822216, 50.658463686704636, 49.939990639686584, 52.108013704419136, 66.18889153003693, 79.8992246389389, 72.27940231561661, 76.09787061810493, 62.47861862182617, 46.72898054122925, 33.69399659335613, 20.816512294113636, 16.89761348068714, 29.72205452620983, 19.006013944745064, 9.471466764807701, 5.255677057430148, 2.764152414165437, 0.4586953850230202, 0.6631036649923772, 1.9088399223983288, 0.9273717063479125, 0.9376775845885277, 0.10680148508981802, 0.8837713021785021, 1.770887018647045, 1.1624509608373046, 0.16857505979714915, 0.3073516138829291, 0.3433187323389575, 0.5884056107606739, 0.9386237931903452, 1.0694127157330513, 0.8390677103307098, 4.208361580967903, 3.1335130194202065, 1.6786045767366886, 0.4359940375434235, 2.7127634966745973, 11.335270553827286, 19.161209017038345, 27.84467026591301, 29.55663040280342, 41.720047518610954, 48.884335085749626, 46.14765353500843, 48.26300762593746, 55.5305128544569, 60.257098227739334, 67.02645778656006, 71.39397382736206, 77.28973746299744, 79.90490913391113, 64.70665946602821, 43.28250087797642, 30.82031909376383, 14.0034094825387, 17.112433053553104, 16.365611627697945, 15.439359080046415, 14.230024572461843, 23.99629756808281, 29.76926889270544, 24.591503329575062, 24.71229124814272, 19.9399259313941, 16.23789858072996, 18.565731570124626, 20.34623432904482, 19.399313740432262, 14.459420163184404, 19.790402054786682, 22.73550432175398, 21.476232893764973, 7.609931929036975, 2.5040292972698808, 0.23208066617371514, 0.15758441673824564, 0.12653598590986803, 0.3104065015213564, 0.4862967773806304, 0.3214303927961737, 0.18356440938077867, 0.15821262990357354, 0.05808242902276106, 0.1373142411466688, 0.11734836094547063, 0.15033863601274788, 0.0648512908082921, 0.0689497048733756, 0.12112253069062717, 0.14216747134923935, 0.06377035271725617, 0.030688123697473202, 0.07045669510262087, 0.09952229287591763, 0.21448720945045352, 0.5120243655983359, 0.4520907753612846, 0.28757017222233117, 0.22795389464590698, 0.2208712973515503, 0.2415800080052577, 0.10057746359962039, 0.11574961899896152, 0.153765027935151, 0.3002313006436452, 0.20929049846017733, 0.11001384162227623, 0.29663556546438485, 0.18026069446932524, 0.09280296944780275, 0.07077998205204494, 0.15683079545851797, 0.08153414717526175, 0.05693004437489435, 0.16558885050471872, 0.05751982542278711, 0.08738581091165543, 0.022778775746701285, 0.04616379337676335, 0.07938842754811049, 0.16078221233328804, 0.1112704980187118, 0.03456274869677145, 0.08721537669771351, 0.08680594866746105, 0.10860590584343299, 0.10323116104700603, 0.07133963561500423, 0.019982699122920167, 0.07730826924671419, 0.05688070639735088, 0.12465208856156096, 0.03876830291119404, 0.11634227586910129, 0.026723704395408276, 0.09483574162004516, 0.1686338527360931, 0.3993051656289026, 0.7920549111440778, 0.4219441133318469, 0.6801882013678551, 0.708914838032797, 0.7533234707079828, 0.9844243386760354, 0.8940635249018669, 0.5891070293728262, 0.29198719770647585, 0.2763685811078176, 0.13736880384385586, 0.5902401404455304, 3.8902464509010315, 25.299868918955326, 60.553508922457695, 78.05870220065117, 78.5383352637291, 88.35127830505371, 94.88207146525383, 92.24455699324608, 83.82999211549759, 69.19009208679199, 60.057031363248825, 57.19002440571785, 53.2486516982317, 61.60449452698231, 53.02002176642418, 49.96091611683369, 40.4453831166029, 44.055808782577515, 43.899234384298325, 52.22662054002285, 57.94280581176281, 56.12721763551235, 59.66688349843025, 58.18637654185295, 47.73432299494743, 34.40151862800121, 27.440288364887238, 26.092969961464405, 30.0672660022974, 39.5250952988863, 46.89725451171398, 70.52230820059776, 80.62153548002243, 73.24123710393906, 58.237848579883575, 40.61357729136944, 39.21066977083683, 34.44871589541435, 18.75536609441042, 11.270186696201563, 6.044860985130072, 2.6056838175281882, 0.4955208714818582, 0.09198223575367592, 0.5278394732158631, 1.0881978389807045, 0.7605169003363699, 0.51693239598535, 0.5509657447692007, 1.2297720671631396, 0.45431885111611336, 0.09259192491299473, 0.15380606870166957, 0.18963654292747378, 0.26265606691595167, 0.9894746239297092, 0.7206639263313264, 0.5783618590794504, 1.630844702012837, 2.089033853262663, 1.115692094899714, 0.9911258728243411, 2.504532770253718, 7.922039581462741, 19.55677919089794, 29.738872423768044, 30.62648769468069, 53.59553888440132, 59.98260095715523, 61.18576839566231, 67.52104684710503, 63.70480902493, 64.85753417015076, 66.6189980506897, 81.20664328336716, 75.10433793067932, 70.21141648292542, 63.67263235151768, 47.85463593900204, 36.716855987906456, 37.40602120757103, 36.23450227081776, 30.525293424725533, 32.53907896578312, 35.4462231695652, 38.267887160182, 42.05447517335415, 39.04193602502346, 42.77748517692089, 36.75301484763622, 33.83243836462498, 32.10967160761356, 37.44070954620838, 38.203229829669, 33.6261398345232, 47.992994114756584, 44.25172246992588, 30.532636530697346, 13.405219931155443, 3.34321569185704, 0.8613554737530649, 0.08705559972440824, 0.039667938035563566, 0.08488775667501613, 0.44557145331054926, 0.6579327362123877, 0.2202894535730593, 0.018450980533089023, 0.055339933605864644, 0.08895350139937364, 0.08514138564351015, 0.04789415150298737, 0.05797230915050022, 0.017174204513139557, 0.029608465811179485, 0.03724629532371182, 0.07933355314889923, 0.04612141303368844, 0.0868874290608801, 0.07459840606315993, 0.05022855846618768, 0.21272956626489758, 0.4317674768390134, 0.4124582192162052, 0.32024565793108195, 0.3694535815156996, 0.17544783710036427, 0.0414387506316416, 0.062204706846387126, 0.10429655114421621, 0.09245054578059353, 0.19872564036631957, 0.4418417753186077, 0.36851607088465244, 0.2427636890206486, 0.1799755316460505, 0.1684976537944749, 0.330747106927447, 0.23001080146059394, 0.27358499297406524, 0.17691080312943086, 0.10866080250707455, 0.12234283669386059, 0.08806205587461591, 0.1277222199132666, 0.27139966492541134, 0.2786233741790056, 0.2356581890489906, 0.14901228452799842, 0.31114199955482036, 0.4214041860541329, 0.35697285435162485, 0.2618964936118573, 0.1412361502298154, 0.26119970600120723, 0.29052071389742196, 0.1422597945202142, 0.3364601300563663, 0.11800118372775614, 0.15367794432677329, 0.21125013940036297, 0.2670780796324834, 0.292066132533364, 0.45000091718975455, 0.5920068081468344, 0.2408600802300498, 0.43051482061855495, 0.6816157966386527, 0.7703711371868849, 1.2532846117392182, 1.3002758589573205, 0.9964005835354328, 0.3506806294899434, 0.2621619153069332, 0.180339228536468, 0.31100648338906467, 1.1731660296209157, 16.697873398661613, 60.31421296298504, 93.07640835642815, 98.28465208411217, 110.26860862970352, 111.19159430265427, 114.22889292240143, 112.36713722348213, 107.48852580785751, 99.91766005754471, 95.53186699748039, 81.54789537191391, 86.68332740664482, 72.74727880954742, 67.72929847240448, 58.98767754435539, 61.26282826066017, 59.314205422997475, 65.9391537308693, 80.06361901760101, 74.15216222405434, 78.22019353508949, 74.14761006832123, 79.11251485347748, 80.49963802099228, 69.25648972392082, 71.15008771419525, 82.8128170967102, 92.16321095824242, 83.35255533456802, 93.36162105202675, 82.77026697993279, 68.71819540858269, 67.19425678253174, 46.84734418988228, 35.55625006556511, 46.43763117492199, 33.077529072761536, 17.810503095388412, 9.501166921108961, 3.724655373953283, 0.38573644997086376, 0.5597540794406086, 2.102719768881798, 3.2322369469329715, 1.3473180471919477, 1.9832850527018309, 1.202164173591882, 2.884146887809038, 2.4558775685727596, 0.26420831331051886, 0.3734580025775358, 1.0520580969750881, 0.5360136064700782, 2.513054287992418, 1.8403595220297575, 1.806787254754454, 5.214139586314559, 3.7272461224347353, 4.378009177744389, 1.8275277293287218, 3.972693239338696, 14.854723401367664, 27.547079734504223, 41.94249898195267, 45.40461100637913, 58.35124209523201, 66.24450534582138, 62.347806841135025, 70.8896952867508, 72.3750963807106, 75.82680076360703, 79.65419858694077, 94.49098885059357, 104.36387747526169, 117.54879757761955, 108.67053598165512, 95.76298579573631, 87.9779103398323, 78.77662807703018, 75.05270630121231, 70.21213844418526, 69.03931617736816, 65.50706371665001, 76.95313632488251, 75.17250627279282, 75.83310842514038, 72.19507724046707, 65.10476410388947, 58.88630658388138, 58.02705109119415, 53.444816172122955, 52.6871520280838, 49.2853731662035, 63.186459839344025, 49.06517118215561, 28.870679810643196, 10.489821620285511, 2.5270135514438152, 0.550186667824164, 0.16420189524069428, 0.12858042464358732, 0.3360044216969982, 0.5134375928901136, 0.9830030368175358, 0.5265763378702104, 0.3018507262459025, 0.19647617591544986, 0.28802487126085907, 0.17924263112945482, 0.20524327032035217, 0.17724833189276978, 0.10975624216371216, 0.13329848006833345, 0.2027385515975766, 0.22453014476923272, 0.085404966812348, 0.125094453105703, 0.18418667052173987, 0.24645956960739568, 0.46276873676106334, 0.67489217617549, 0.546453605638817, 0.382843617699109, 0.531478252960369, 0.3532153309788555, 0.16100788459880278, 0.2733827428892255, 0.2967199624981731, 0.25995013711508363, 0.27681802574079484, 0.6421568733640015, 0.2872878889320418, 0.23637897771550342, 0.19175803143298253, 0.35516047035343945], [0.08954583914601244, 0.14333069877466187, 0.08257271605543792, 0.10320966845029034, 0.09103754855459556, 0.07396339482511394, 0.03488535287033301, 0.12455457035684958, 0.08456449199002236, 0.18126709124771878, 0.15316863806219772, 0.11721714923623949, 0.06881535387947224, 0.0986211771669332, 0.11449705183622427, 0.11427343531977385, 0.15461129893083125, 0.18453337223036215, 0.13760716683464125, 0.1073127580457367, 0.13125463505275548, 0.036763242533197626, 0.06778899332857691, 0.012713224405160872, 0.09239468432497233, 0.14393897785339504, 0.3675230476073921, 0.2751800761325285, 0.06686066306428984, 0.10487614621524699, 0.05844588842592202, 0.14147117355605587, 0.7510830159299076, 1.3054174580611289, 1.0582438088022172, 0.41465123591478914, 0.34329952555708587, 0.10061611465062015, 0.553134597139433, 0.7700553978793323, 0.7560528523754328, 8.847820479422808, 34.641076773405075, 58.78091923892498, 60.844250321388245, 54.29244428873062, 61.96681268513203, 77.23933696746826, 64.89177793264389, 53.367228135466576, 62.31615453958511, 50.41763260960579, 32.326145991683006, 30.913526192307472, 28.613678701221943, 31.422472782433033, 44.43635456264019, 57.06142410635948, 70.92654570937157, 84.73555952310562, 73.54026585817337, 70.10931596159935, 70.92645451426506, 71.73681423068047, 62.54969000816345, 67.77439445257187, 74.33994814753532, 73.79552856087685, 70.46484768390656, 69.07066449522972, 75.63858926296234, 55.65595172345638, 45.27344964444637, 43.02742816507816, 42.93388478457928, 46.90197005867958, 51.00176386535168, 41.33370324969292, 20.988846346735954, 12.196309100836515, 6.49097747169435, 1.6425339435227215, 0.856646338943392, 1.7102042748592794, 0.15069782064529136, 2.6915454352274537, 1.0072926990687847, 0.5296887864824384, 0.09451117817661725, 0.524719306267798, 0.7564011868089437, 0.2177062156260945, 0.09907329353154637, 1.9730833126232028, 1.120708656962961, 0.9882461617235094, 0.9551542717963457, 1.4384820428676903, 1.2980504846200347, 0.26836502307560295, 1.1087059322744608, 1.7773612774908543, 3.4544283617287874, 25.007753893733025, 28.81611853837967, 44.38202127814293, 50.62641620635986, 57.76909053325653, 52.500259056687355, 57.780242934823036, 47.28210166096687, 42.15792082250118, 46.00142978131771, 51.99411481618881, 65.05972892045975, 62.184613198041916, 59.114636331796646, 57.57934391498566, 47.01211094856262, 27.79420707374811, 19.788638949394226, 17.370021231472492, 13.872145526111126, 11.85679541900754, 14.396630432456732, 17.226062156260014, 12.67851747572422, 7.000583801418543, 7.690317565575242, 4.908589906990528, 5.691563542932272, 9.74464550614357, 10.932414270937443, 9.22760060057044, 7.436262248083949, 5.554261710494757, 1.7349681397899985, 0.6478384591173381, 0.6085669132880867, 0.6023083522450179, 0.5155112722422928, 0.12670115829678252, 0.43109286460094154, 0.46260522678494453, 0.1957518546259962, 0.27464513608720154, 0.1581387416808866, 0.04894101388345007, 0.06067489186534658, 0.061993035196792334, 0.2897159883286804, 0.2892647625412792, 0.06645726869464852, 0.1987463017576374, 0.20968196651665494, 0.15687735780375078, 0.06357121223118156, 0.11332661073538475, 0.0765168503858149, 0.300298806396313, 0.34987703198567033, 0.2819070214172825, 0.3999565338017419, 0.4291945992736146, 0.6945063080638647, 0.32838868035469204, 0.053728244893136434, 0.08610027012764476, 0.17797964421333745, 0.3100990445818752, 0.2696790103800595, 0.23169586260337383, 0.4569324874319136, 0.1461003048461862, 0.15935069852275774, 0.18529307912103832, 0.07641588119440712, 0.07567533655674197, 0.14096841303398833, 0.05404292664024979, 0.07893424059147947, 0.03413945363718085, 0.030202451125660446, 0.03939854585041758, 0.06072443022276275, 0.16216432879446074, 0.11038339405786246, 0.12196054158266634, 0.02539603374316357, 0.015240080465446226, 0.2305566510767676, 0.0561900526372483, 0.1001292435103096, 0.02134760517947143, 0.05646832833008375, 0.07679534872295335, 0.13670872285729274, 0.1102320033533033, 0.09103536664042622, 0.012160689893789822, 0.014367872336151777, 0.33388912270311266, 0.4413826233940199, 0.5771441431716084, 0.5461414880119264, 0.3514954185811803, 0.22545998159330338, 0.642514469800517, 1.211728141643107, 1.4121593115851283, 0.7852063723839819, 0.31151862465776503, 0.12598894885741174, 0.1487837772583589, 0.3132157679647207, 0.3478876902954653, 2.8482062788680196, 18.39201059192419, 53.509180918335915, 74.85259383916855, 85.7432122528553, 78.30832600593567, 84.99083742499352, 83.76777425408363, 79.29931282997131, 77.19979628920555, 71.49641633033752, 60.93551382422447, 56.02845333516598, 51.15086406469345, 45.719610303640366, 46.00108779966831, 48.06882664561272, 47.44454674422741, 49.33929607272148, 57.991868779063225, 59.94410902261734, 70.71798250079155, 65.39749279618263, 68.28574061393738, 60.61429426074028, 50.95660708844662, 58.533658906817436, 63.19815181195736, 78.1100070476532, 77.13640809059143, 75.40255352854729, 62.56931975483894, 56.008796989917755, 64.57878112792969, 60.19545413553715, 45.56041784584522, 49.01882886886597, 41.98881469666958, 28.69785748422146, 14.7229322232306, 7.958785984665155, 4.000698924064636, 0.4778142966097221, 0.3761746786767617, 0.1458114164415747, 0.693312103394419, 0.7500823633745313, 2.010442432947457, 2.737996755167842, 2.021778174676001, 0.28902718622703105, 0.29261689516715705, 0.5474411963950843, 0.6496932345908135, 0.5244448303710669, 1.0685014771297574, 1.5454046241939068, 1.1637864704243839, 0.8655195753090084, 0.08384813394513912, 0.9352454182226211, 3.3259615302085876, 12.408722452819347, 30.394926220178604, 40.21666958928108, 53.191890344023705, 59.635227397084236, 73.80539283156395, 66.01201862096786, 68.56038987636566, 68.9862710237503, 65.37161618471146, 69.26630079746246, 70.9494736790657, 73.84004697203636, 72.91449263691902, 68.96474897861481, 69.56095978617668, 69.62703824043274, 57.58514240384102, 47.31585144996643, 33.48654292523861, 27.007584683597088, 28.4519137814641, 29.136543944478035, 26.15560010075569, 25.173214115202427, 22.04145636409521, 24.375988394021988, 22.419515177607536, 20.56120779365301, 23.72977986931801, 23.564089760184288, 23.547167368233204, 20.161136761307716, 11.885426882654428, 4.166471203789115, 0.8068293496035039, 0.08138603676343337, 0.5032549111638218, 0.5213691922836006, 0.681964784162119, 0.4538649832829833, 0.12275644301553257, 0.36901791114360094, 0.21895968820899725, 0.0735805876320228, 0.028787143965018913, 0.05492538104590494, 0.11046322688343935, 0.032718348447815515, 0.13578614423749968, 0.19769487145822495, 0.20519405108643696, 0.08622777109849267, 0.09473362209973857, 0.13073053036350757, 0.30849300732370466, 0.16371103876736015, 0.29519345378503203, 0.11457887361757457, 0.22641190473223105, 0.36488138779532164, 0.5142006988171488, 0.5104372382629663, 0.36948748282156885, 0.15702114149462432, 0.030628742606495507, 0.05743153211369645, 0.07450605320627801, 0.2231851505348459, 0.3633396205259487, 0.5277777859009802, 0.2506227063713595, 0.3184535790933296, 0.2258286508731544, 0.15299730584956706, 0.24691701459232718, 0.2532977034570649, 0.19428253581281751, 0.19288945040898398, 0.150788021273911, 0.1932651997776702, 0.25987497239839286, 0.20307605067500845, 0.36520692345220596, 0.274409192497842, 0.16994650417473167, 0.24334614136023447, 0.21362419560318813, 0.3651029634056613, 0.25490549218375236, 0.26620430464390665, 0.23943583946675062, 0.14669225667603314, 0.40495970752090216, 0.3085417515831068, 0.1509107873425819, 0.10929229596513323, 0.1602615215233527, 0.20531227521132678, 0.42797447880730033, 0.5118326540105045, 0.503720564302057, 0.43059336952865124, 0.279776849783957, 0.24395811633439735, 0.8007378608454019, 1.7247663997113705, 1.5829154988750815, 1.2203327799215913, 0.5993272340856493, 0.31322262540925294, 0.19599288934841752, 0.34292512689717114, 0.6482155888807029, 1.5451544313691556, 14.368964117020369, 51.54607705771923, 86.94801360368729, 102.3883330821991, 99.43519234657288, 101.91171705722809, 98.70361760258675, 99.97952073812485, 106.80506408214569, 106.31811261177063, 93.95562797784805, 88.69011372327805, 79.68127593398094, 70.54072201251984, 69.34808000922203, 76.0939872264862, 78.58568832278252, 89.90158751606941, 108.89328002929688, 109.68559071421623, 118.58619511127472, 116.10030010342598, 115.90710327029228, 104.17606875300407, 88.40874642133713, 89.01813492178917, 85.78287452459335, 89.1816933453083, 90.8957889676094, 90.42327672243118, 72.04353377223015, 69.88896578550339, 78.47189202904701, 68.01265686750412, 55.140961557626724, 62.91510879993439, 52.782982885837555, 34.45746682584286, 23.182377442717552, 16.427432410418987, 6.168001452460885, 0.8196048578247428, 1.2470162543468177, 0.3902593650855124, 3.816088680177927, 1.4550596033222973, 2.6508845295757055, 4.39341782592237, 3.687535640783608, 1.4607147686183453, 0.39451475080568343, 0.9895886771846563, 2.635453320108354, 0.9231567231472582, 2.7373961498960853, 3.524533174932003, 1.2452247692272067, 1.6361210751347244, 0.3828105179127306, 1.2429712526500225, 5.045847091823816, 15.000410433858633, 43.494195118546486, 51.46140240132809, 64.36548337340355, 67.39816904067993, 76.18674024939537, 68.430505245924, 77.68787249922752, 77.2533430159092, 70.80945879220963, 79.51834067702293, 80.29469221830368, 86.1348344385624, 89.51484426856041, 90.34949228167534, 104.21816289424896, 105.06158843636513, 92.88314312696457, 83.73891100287437, 70.60220271348953, 60.597928538918495, 54.47467491030693, 50.89240953326225, 51.0501504689455, 48.77474136650562, 39.04920503497124, 38.30916054546833, 33.6210785061121, 31.067256443202496, 39.86523784697056, 37.800732627511024, 36.73187658190727, 24.855809547007084, 13.549805972725153, 3.3663649996742606, 0.9404991706833243, 0.593720575561747, 0.8331492904108018, 0.6019761075731367, 0.6152549106627703, 0.5910915322601795, 0.655683494405821, 0.629232341889292, 0.6158603250514716, 0.27336145809385926, 0.11838492602691986, 0.2272258626180701, 0.1813607502845116, 0.16503042890690267, 0.29400738305412233, 0.2649777423357591, 0.2543297637021169, 0.20326497178757563, 0.30580435472074896, 0.30809310846962035, 0.5732885969337076, 0.3095371794188395, 0.47558046178892255, 0.295692800427787, 0.7465318695176393, 0.7359250355511904, 0.6250471039675176, 0.6234048202168196, 0.41836268675979227, 0.2238083170959726, 0.1872539965552278, 0.2477813049335964, 0.20110866171307862, 0.3493239835370332, 0.3148819785565138, 0.48305917298421264, 0.28355880465824157, 0.46266611258033663, 0.39776289369910955], [0.11105293742730282, 0.11062453268095851, 0.10836931658559479, 0.015025223146949429, 0.14359447290189564, 0.1836651930352673, 0.023672046954743564, 0.04649119553505443, 0.04593315614329185, 0.17200919974129647, 0.15398102259496227, 0.07521852239733562, 0.08925080575863831, 0.2542333141900599, 0.2882039366522804, 0.1018882002972532, 0.05967551580397412, 0.04452687906450592, 0.04776377842063084, 0.05847715510753915, 0.033419941464671865, 0.04103757157281507, 0.12823755241697654, 0.10572030209004879, 0.2502514247316867, 0.06554882798809558, 0.18263106961967424, 0.3082451596856117, 0.1490027256659232, 0.035585691657615826, 0.26701021764893085, 0.17713108740281314, 0.5089627986308187, 0.9510741813573986, 0.6875682366080582, 0.281672888668254, 0.18158446328015998, 0.12457496457500383, 0.640779328532517, 0.8160034823231399, 0.06122087506810203, 0.3063652402488515, 1.6738295392133296, 9.629212450236082, 18.15364558249712, 47.73621529340744, 64.42162916064262, 59.77093331515789, 60.207389295101166, 46.870956122875214, 49.12868097424507, 53.118778467178345, 34.24557879567146, 26.342669762670994, 17.826139256358147, 22.769307307899, 29.367364458739758, 44.416591823101044, 51.82614482939243, 53.16745005548, 50.69839954376221, 45.19271917641163, 48.18121701478958, 53.70407626032829, 57.989167124032974, 61.06252580881119, 65.09534820914268, 62.07031913101673, 57.51372903585434, 59.30891990661621, 50.41694484651089, 46.22245632112026, 41.19397334754467, 47.502786219120026, 57.661012932658195, 57.20016226172447, 58.50293755531311, 61.795229092240334, 40.993275716900826, 20.735551938414574, 2.634403626434505, 1.3209015084430575, 1.5186320920474827, 0.9923846740275621, 0.9280104876961559, 4.67617585323751, 2.5695555936545134, 0.8944731310475618, 0.3919225774006918, 0.3157816990278661, 0.5412140430416912, 1.2476111599244177, 0.3884975065011531, 1.3016190868802369, 1.1120661394670606, 0.9240907011553645, 2.499968740157783, 0.7691402407363057, 0.3278183547081426, 1.4921758929267526, 6.212218729779124, 6.33117894642055, 12.14255053550005, 29.76294033229351, 38.10189686715603, 48.36627088487148, 43.09466555714607, 58.06447148323059, 53.17312695086002, 40.730436220765114, 35.93333043158054, 33.96278657019138, 30.041567981243134, 29.90063164383173, 28.58355961740017, 30.260158851742744, 36.45907402038574, 44.530650302767754, 39.108637645840645, 34.66153487563133, 17.000947035849094, 11.702306158840656, 3.121689478866756, 2.8177456883713603, 9.239462614059448, 6.424023639410734, 2.890275246463716, 3.142849118448794, 3.856080584228039, 6.335919667035341, 2.5453159818425775, 2.9252036847174168, 6.666399808600545, 4.479097528383136, 1.5699136652983725, 0.1586653251433745, 0.08858280605636537, 0.3750652866438031, 0.7123249769210815, 0.8616066758986562, 0.970804919488728, 0.5422447377350181, 0.7461538491770625, 0.22580880584428087, 0.10612308789859526, 0.053865301015321165, 0.09632964778575115, 0.042499339033383876, 0.17987283325055614, 0.09358010196592659, 0.11599745179410093, 0.35932786704506725, 0.21531642589252442, 0.05801428502309136, 0.11964803910814226, 0.15818359708646312, 0.17488453217083588, 0.06126561544078868, 0.15309302805690095, 0.21805975993629545, 0.11360904987668619, 0.22109250188805163, 0.09314110677223653, 0.13219330343417823, 0.17587583366548643, 0.11576643606531434, 0.10729782603448257, 0.12089813491911627, 0.09437578817596659, 0.24391146493144333, 0.25284365750849247, 0.2854869340080768, 0.1990846320404671, 0.2159014460630715, 0.0746887773857452, 0.021276290353853256, 0.1894638896919787, 0.15943466511089355, 0.08084719302132726, 0.05387446653912775, 0.021142169425729662, 0.054832059686305, 0.0524287109146826, 0.14834418834652752, 0.04773994063725695, 0.10150010901270434, 0.06608070296351798, 0.06899156942381524, 0.07826332424883731, 0.12804201134713367, 0.10026799543993548, 0.046289665333461016, 0.03818331613729242, 0.09657646383857355, 0.03552909547579475, 0.23334935278398916, 0.2672889386303723, 0.06299244094407186, 0.07904149577370845, 0.028198027139296755, 0.15147196972975507, 0.31174316885881126, 0.3360772709129378, 0.4716797039145604, 0.3377492702566087, 0.042502010765019804, 0.4540132940746844, 0.7133706333115697, 1.1675406689755619, 0.754527352983132, 0.49886881839483976, 0.36649817135185003, 0.13703701930353418, 0.08867729629855603, 0.5563192418776453, 1.2337189866229892, 0.8839570172131062, 2.966650673188269, 12.191680949181318, 34.42645289003849, 50.447882786393166, 68.98495629429817, 78.7960222363472, 74.22195687890053, 75.00609040260315, 66.42054229974747, 66.4296542108059, 72.64952525496483, 61.94884344935417, 50.54109178483486, 39.258034229278564, 35.073470771312714, 34.060175344347954, 37.76179991662502, 47.86803402006626, 60.7962778955698, 73.52556824684143, 84.32439118623734, 96.41794145107269, 94.26235511898994, 81.26643687486649, 68.5236306488514, 72.5628063082695, 82.69037246704102, 87.46363833546638, 88.50681155920029, 85.20507752895355, 76.72928273677826, 75.65146297216415, 72.20879450440407, 64.18022811412811, 59.2689498513937, 66.0922247171402, 59.739535599946976, 34.986432641744614, 28.156838715076447, 15.463059358298779, 5.629450650885701, 3.0744615755975246, 1.39086703537032, 0.6490612216293812, 2.8550815349444747, 1.6192514053545892, 1.996399573981762, 1.208113229367882, 0.24355741596082225, 1.9686985854059458, 0.5044400913175195, 0.31600232468917966, 3.4044952411204576, 1.494690051767975, 0.609548685606569, 1.1664786259643734, 2.3867003805935383, 1.876590815372765, 4.084626920521259, 2.533903056755662, 4.427612191066146, 12.348239198327065, 37.480425015091896, 45.797437727451324, 59.92972679436207, 65.08423760533333, 74.7759747505188, 70.59027135372162, 65.77633246779442, 58.48050355911255, 56.57057024538517, 61.433332711458206, 58.11409682035446, 58.34952458739281, 54.97360333800316, 59.83675338327885, 67.45417043566704, 72.01543048024178, 68.77554193139076, 48.4352295845747, 34.266606867313385, 26.66766632348299, 20.523986890912056, 20.158220417797565, 19.39130377024412, 17.68689762800932, 13.193758428096771, 13.304203301668167, 15.962662249803543, 13.254255931824446, 15.628254543989897, 10.376967675983906, 7.347516110166907, 2.3488240130245686, 1.0842565004713833, 0.38274146849289536, 0.24284700251882896, 0.44334471342153847, 0.6983964086975902, 1.2415191368199885, 2.147535039111972, 0.9420541778672487, 0.18407094001304358, 0.05495438788784668, 0.03118526430625934, 0.11995007094810717, 0.029846813959011342, 0.18143383698770776, 0.14483669452602044, 0.044526585916173644, 0.24567238840973005, 0.4318154195789248, 0.16738026140956208, 0.06714869799907319, 0.09079641735297628, 0.2705628192052245, 0.2258691721362993, 0.3283146140165627, 0.30100527161266655, 0.07992659593583085, 0.17134053952759132, 0.12879129848442972, 0.2977836976060644, 0.21680509991711006, 0.313959073391743, 0.21125775383552536, 0.19677701289765537, 0.06846658157883212, 0.08653255630633794, 0.12273500979063101, 0.07311771012609825, 0.13379937037825584, 0.28503051318693906, 0.31362706620711833, 0.24333217414095998, 0.3015422006137669, 0.40846095245797187, 0.350328020285815, 0.3782791126286611, 0.24853366456227377, 0.23291920399060473, 0.14575128763681278, 0.19370183494174853, 0.14333605708088726, 0.24190561787690967, 0.2771847654366866, 0.19751469284528866, 0.17727126425597817, 0.29305897769518197, 0.3450211003655568, 0.35771342867519706, 0.22125341434730217, 0.24893265799619257, 0.31368278665468097, 0.32867351663298905, 0.3024917043512687, 0.17352064285660163, 0.19448149076197296, 0.18362946604611352, 0.20819304016185924, 0.46644426765851676, 0.43164131173398346, 0.5196899198926985, 0.38231191341765225, 0.11970213425229304, 0.5174127139616758, 0.6425549020059407, 1.3823417178355157, 0.9892666444648057, 0.9425057005137205, 0.7741795422043651, 0.2997336757835001, 0.2616346045397222, 0.639210072113201, 1.4540753373876214, 0.9448391909245402, 1.7168570053763688, 5.184575272724032, 21.043977588415146, 41.424221992492676, 68.70839193463326, 85.79884126782417, 80.20303353667259, 93.78009259700775, 90.80973878502846, 87.94464692473412, 94.62405011057854, 78.57887908816338, 72.8737436234951, 60.89156158268452, 57.91575886309147, 58.67154210805893, 65.93276247382164, 74.46802407503128, 91.02600798010826, 105.84916457533836, 115.69126725196838, 120.33652558922768, 114.11828845739365, 98.42744842171669, 79.77280542254448, 77.93527722358704, 86.56773000955582, 94.60399478673935, 100.89339450001717, 96.16280794143677, 99.20438513159752, 95.64902991056442, 78.4243793785572, 76.92233517765999, 77.27939441800117, 82.36112013459206, 81.32893592119217, 48.239498287439346, 41.41989782452583, 23.68840578943491, 9.737881869077682, 3.6363371880725026, 0.8747643604874611, 1.4487990830093622, 5.102073149755597, 5.027753412723541, 3.7806294579058886, 1.221832511946559, 0.4909720702562481, 2.751551577821374, 1.9036939297802746, 0.8707378234248608, 6.259769853204489, 3.2605912629514933, 1.6401551524177194, 5.898243952542543, 1.8387770256958902, 1.2665090896189213, 4.207939803600311, 10.992115717381239, 12.879843022674322, 26.24943796545267, 48.63063409924507, 52.479059994220734, 58.72933320701122, 53.930901288986206, 69.53908815979958, 70.08130386471748, 70.23221656680107, 69.05130073428154, 72.00162202119827, 72.7491407096386, 62.767235934734344, 58.125306218862534, 57.39579476416111, 68.7236063182354, 79.46194410324097, 87.3518331348896, 91.99880138039589, 70.60271188616753, 60.582562163472176, 48.69876444339752, 41.51379078626633, 39.577331095933914, 35.2809776365757, 30.608254373073578, 25.810922496020794, 23.256652057170868, 21.075840778648853, 17.253580279648304, 17.297785207629204, 15.3238813765347, 7.666064416989684, 1.9048743601888418, 0.6261691718827933, 0.5803974810987711, 0.5806280812248588, 1.166178798303008, 1.79407705552876, 2.4620113894343376, 3.0899844551458955, 1.1572868004441261, 0.37549620727077127, 0.13351603323826566, 0.21852104924619198, 0.2953283168608323, 0.1559757225913927, 0.2662531676469371, 0.3228250960819423, 0.26615894457791, 0.5702761898282915, 0.44408228946849704, 0.28554974938742816, 0.15346791653428227, 0.36310795170720667, 0.6288631679490209, 0.5681636219378561, 0.8444270258769393, 0.601430480601266, 0.3695544839138165, 0.6360732216853648, 0.3192431351635605, 0.3889506321866065, 0.30919498996809125, 0.4327716620173305, 0.2297892258502543, 0.3397559782024473, 0.22392979182768613, 0.2862185728736222, 0.32155958586372435, 0.4571789695182815, 0.281121235457249, 0.3951041348045692, 0.5235780018847436, 0.4159807786345482], [0.164313989225775, 0.05332031229045242, 0.0813106494024396, 0.09192866753437556, 0.024459385858790483, 0.18198399106040597, 0.04791854960785713, 0.111869656102499, 0.10579531095572747, 0.05780850973678753, 0.09582211525412276, 0.08642081113066524, 0.08166219733539037, 0.2161909281858243, 0.08415392105234787, 0.14783736085519195, 0.052914235056960024, 0.05968736790237017, 0.12313139086472802, 0.09040795499458909, 0.05471889329783153, 0.14104182628216222, 0.14804219361394644, 0.04458864059415646, 0.18735915888100863, 0.0490508034999948, 0.08576446314691566, 0.060726467418135144, 0.20638545043766499, 0.30760649708099663, 0.037021710304543376, 0.06008853582898155, 0.4117967578349635, 0.482626233715564, 0.2218724397243932, 0.1314666518010199, 0.34124101570341736, 0.2869065140839666, 0.8106312237214297, 0.269122191821225, 0.6932868110015988, 0.771357718622312, 0.7273054355755448, 0.39624196593649685, 2.7105339663103223, 17.0842157676816, 28.68883866816759, 29.38959326595068, 32.0343254506588, 34.78166922926903, 50.67519038915634, 41.496296525001526, 34.97034430503845, 23.18887699395418, 14.13233371451497, 15.680367797613144, 22.263617143034935, 34.9558936804533, 36.79394245147705, 34.21358831226826, 38.43335308134556, 38.85966360569, 33.70501220226288, 37.94066771864891, 43.61619137227535, 41.90695568919182, 35.464758574962616, 27.618536800146103, 24.82418194413185, 16.255763322114944, 16.63057330995798, 27.219121232628822, 36.88975431025028, 44.83266569674015, 39.5153184235096, 49.11445453763008, 53.6800691485405, 54.28528547286987, 57.68023230135441, 41.75469785928726, 8.201684150844812, 2.688018986955285, 1.6776266042143106, 1.2249676999635994, 1.610936620272696, 4.701941795647144, 7.403575927019119, 2.0284719904884696, 0.06090296868933365, 0.09091188810998574, 1.1302975611761212, 1.6215793741866946, 0.9128715062979609, 1.6388045623898506, 1.8041352345608175, 0.25661002728156745, 2.4543970730155706, 0.4450297151925042, 0.8663700765464455, 3.080465728417039, 4.846607157960534, 14.037467055022717, 30.92736314982176, 51.823686361312866, 59.619902819395065, 65.83026677370071, 66.75313085317612, 57.24216140806675, 44.06552866101265, 35.0268130749464, 17.486794665455818, 10.679132211953402, 3.0094883870333433, 4.006073260679841, 5.6104079727083445, 9.9511824734509, 17.36464262008667, 26.212158165872097, 27.71441325545311, 27.190018594264984, 10.387825593352318, 3.8284012069925666, 5.415968606248498, 2.785604875534773, 1.261760056950152, 2.318098386749625, 1.3723906455561519, 0.12520527059677988, 1.0915414220653474, 1.0438957787118852, 1.1800339235924184, 1.9624678697437048, 0.8679380267858505, 0.21545979398069903, 0.0703935902856756, 0.13911583431763574, 0.02990005934407236, 0.19290959229692817, 0.3548846289049834, 0.3161199699388817, 0.0936951200128533, 0.45049094245769083, 0.405423401389271, 0.1386883869417943, 0.12557959504192695, 0.15243223460856825, 0.040287260271725245, 0.11379010422388092, 0.06833540697698481, 0.08762404031585902, 0.06234214888536371, 0.10646457230905071, 0.047483268863288686, 0.01584102526976494, 0.02566369486885378, 0.17596797872101888, 0.0863718219625298, 0.0279691506511881, 0.07748947202344425, 0.08874494305928238, 0.0617558114026906, 0.1463598635746166, 0.0353293427178869, 0.11568632864509709, 0.12499911681516096, 0.01650524187425617, 0.2371467591729015, 0.14632841135608032, 0.07242172403493896, 0.022505092092615087, 0.14791308960411698, 0.17360962636303157, 0.07128345503588207, 0.09837330726440996, 0.2333594163064845, 0.10564203519606963, 0.10345668488298543, 0.044884182352689095, 0.10038961117970757, 0.08239912771387026, 0.1080592250218615, 0.0852607972046826, 0.09671258856542408, 0.0804640592832584, 0.06292377001955174, 0.03661720642412547, 0.05603081743174698, 0.021348733243939932, 0.012569848895509494, 0.08346151953446679, 0.10476166251464747, 0.05267888518574182, 0.034524813818279654, 0.05322042663465254, 0.08303688489831984, 0.09622429992305115, 0.18582873162813485, 0.13567321904702112, 0.18737885548034683, 0.07795534780598246, 0.11112151187262498, 0.08252758605522104, 0.19632997282315046, 0.1661966842948459, 0.3025359660387039, 0.4205200506839901, 0.6613160984124988, 0.8697340835351497, 0.7547871046699584, 0.4645402729511261, 0.3423298057168722, 0.27330529235769063, 0.2526823146035895, 0.4013096768176183, 0.8867752191144973, 1.3453787262551486, 1.625370739493519, 1.8180543626658618, 2.2486155526712537, 1.5092901745811105, 7.594718970358372, 27.401775531470776, 48.33100497722626, 53.841290697455406, 53.60604532063007, 53.632860481739044, 65.47490984201431, 72.04433932900429, 60.81729456782341, 49.84735541045666, 46.04718692600727, 35.189828127622604, 36.0078976303339, 49.19895440340042, 58.48263144493103, 71.62119403481483, 86.56103476881981, 93.56658205389977, 92.56952315568924, 81.43457785248756, 68.54191526770592, 60.041406601667404, 55.98170064389706, 66.1977070569992, 73.5775874555111, 78.41174125671387, 74.55868721008301, 70.32923296093941, 72.78580114245415, 64.44878250360489, 65.18545657396317, 66.3943313062191, 70.51106080412865, 70.64814984798431, 55.22184781730175, 38.13116669654846, 20.120900720357895, 6.939704418182373, 2.5126287108287215, 0.47109124017879367, 3.0968542490154505, 2.1646882686764, 4.738094005733728, 2.240827395580709, 0.15954341943142936, 0.9148001996800303, 3.2617454510182142, 1.6694800788536668, 0.8873115247115493, 0.4919009719742462, 2.2437860118225217, 1.3924004905857146, 1.0343119804747403, 0.6262324622366577, 1.0601179394870996, 4.794697193428874, 9.831111766397953, 14.686034303158522, 23.190896585583687, 51.89614087343216, 56.657536178827286, 61.644350588321686, 62.58049875497818, 65.88718771934509, 65.5949530005455, 55.89481830596924, 50.20211957395077, 44.41889829933643, 44.54790897667408, 39.25363026559353, 32.394747510552406, 33.564951717853546, 37.95033439993858, 45.526041090488434, 47.02740892767906, 54.431957602500916, 40.190903171896935, 33.774073496460915, 17.377202846109867, 12.212200798094273, 10.614042654633522, 3.932605152949691, 4.465440111234784, 8.034172989428043, 7.963218921795487, 8.492159564048052, 3.456817246042192, 3.1824907287955284, 1.7214092798531055, 0.09886948493658565, 0.11863218736834824, 0.15085172723047435, 0.04957930541422684, 0.08597755600931123, 0.18686849536607042, 0.36991130851674825, 0.7789852749556303, 0.8753379515837878, 0.6458964664489031, 0.279707889421843, 0.16289200459141284, 0.1685588512918912, 0.0950909142557066, 0.10486368555575609, 0.08391177310841158, 0.0494690296909539, 0.11158223715028726, 0.14347825257573277, 0.1905395436915569, 0.08028877142351121, 0.056723508387221955, 0.07014126749709249, 0.027110962619190104, 0.04378475736302789, 0.08913108991691843, 0.09706657816423103, 0.07110436738003045, 0.21414407005067915, 0.08776539718382992, 0.0712726938945707, 0.1755028302432038, 0.09500319240032695, 0.273085527587682, 0.17183273186674342, 0.03468968192464672, 0.10439729026984423, 0.05716397674405016, 0.043550309201236814, 0.08026841431274079, 0.20699641609098762, 0.21782555297249928, 0.10842761970707215, 0.19763086864259094, 0.38350294169504195, 0.38887416129000485, 0.43749949894845486, 0.4207889753160998, 0.6406338082160801, 0.2849001029971987, 0.2501887280959636, 0.1683448307448998, 0.1302556152222678, 0.15058636490721256, 0.38165410340297967, 0.18209240399301052, 0.3450603748206049, 0.2184271824080497, 0.1310000487137586, 0.09922014229232445, 0.17835257342085242, 0.21698659955291077, 0.19106124382233247, 0.2026899706106633, 0.19470440223813057, 0.15634369425242767, 0.15099565935088322, 0.2921634429367259, 0.21358009718824178, 0.2488433924736455, 0.27187932981178164, 0.46036073472350836, 0.552544619422406, 0.6795294117182493, 0.8700988639611751, 0.728533185319975, 0.48302328272257, 0.35374801489524543, 0.42428315500728786, 0.4621676862007007, 0.5343045294284821, 1.385798582341522, 1.8794835289008915, 2.5591154163703322, 2.4485133262351155, 1.6778864152729511, 0.40545276075135916, 3.3171885134652257, 17.412934228777885, 37.75923125445843, 46.661036387085915, 57.23686829209328, 61.064247116446495, 90.0582455098629, 86.25202775001526, 80.91654404997826, 70.80315873026848, 68.24072822928429, 55.168943256139755, 61.116125732660294, 75.97403526306152, 85.87728425860405, 102.57892325520515, 115.68688988685608, 117.93107226490974, 111.420668810606, 91.70821577310562, 75.55261507630348, 68.80602389574051, 54.2336880415678, 61.185722798109055, 70.30262678861618, 79.25473362207413, 81.72713175415993, 73.92236575484276, 75.92729777097702, 69.98153641819954, 68.1484767794609, 81.50358214974403, 77.7107472717762, 78.93763303756714, 74.02484625577927, 61.60101771354675, 31.145110465586185, 7.982117682695389, 3.0517563689500093, 2.2483077691867948, 4.891395829617977, 10.871944315731525, 19.104897938668728, 4.151660548523068, 0.19214013358578086, 0.8093902934342623, 4.747732663527131, 3.517529438249767, 3.830459746532142, 5.5985022615641356, 4.814837062731385, 5.649466551840305, 6.755941528826952, 1.0052142105996609, 2.687581772916019, 7.659278456121683, 16.06063049286604, 39.341755136847496, 57.56355196237564, 79.68582049012184, 75.45339480042458, 76.67423129081726, 71.82412594556808, 69.76859584450722, 67.23421543836594, 65.65682888031006, 52.82240957021713, 50.210589319467545, 49.033910259604454, 49.56497736275196, 39.988564029335976, 45.17696142196655, 41.74794942140579, 47.19140812754631, 49.416492730379105, 54.96385306119919, 42.11807616055012, 36.06262229382992, 23.577552437782288, 16.082923896610737, 16.59860372543335, 8.235187903046608, 6.14208304323256, 9.035467710345984, 8.868833351880312, 8.299321811646223, 4.081698702648282, 3.637995799072087, 0.9522852476220578, 0.24903219484258443, 0.47603934654034674, 0.7210670015774667, 0.07616941395099275, 0.22778087033657357, 0.5384420917835087, 0.59645761619322, 0.8758179133292288, 0.5481080606114119, 0.5881833226885647, 0.36142995581030846, 0.25012401281856, 0.3049034171272069, 0.2268834356800653, 0.26307532098144293, 0.15965560247423127, 0.34597202902659774, 0.34000382584054023, 0.16357537417206913, 0.12425241235177964, 0.15035831776913255, 0.11910366636584513, 0.3353749617235735, 0.25196427188348025, 0.21198735921643674, 0.21961314923828468, 0.19116128532914445, 0.17747134726960212, 0.3972967655863613, 0.3006309026386589, 0.27345939190126956, 0.2542616048594937, 0.2068127048551105, 0.2572045469423756, 0.1822556764818728, 0.16176569159142673, 0.2631697815377265, 0.28780578926671296, 0.2352765470277518, 0.16009182203561068, 0.3106033487711102, 0.35688014526385814, 0.10831644598511048], [0.02805297808663454, 0.02597026679723058, 0.08723874692805111, 0.11663399185636081, 0.04324599154642783, 0.0887353322468698, 0.0383613944723038, 0.06687557281111367, 0.08859456909704022, 0.08065723290201277, 0.06922783955815248, 0.08260840593720786, 0.031843575270613655, 0.09265762724680826, 0.07682229610509239, 0.042838723165914416, 0.060922498305444606, 0.1677167066372931, 0.009440762260055635, 0.041349685488967225, 0.20577303017489612, 0.015716381567472126, 0.054170947114471346, 0.05956493580015376, 0.15813523874385282, 0.08939643739722669, 0.05408983037341386, 0.14947725489037111, 0.09081545344088227, 0.2793689357349649, 0.10817331538419239, 0.1724861780530773, 0.13542810251237825, 0.2469324364210479, 0.2888770052231848, 0.6350248341914266, 0.950440684100613, 0.9566963952966034, 0.9132097475230694, 0.4780765122268349, 0.3220532328123227, 0.40296879247762263, 0.27668797178193927, 0.5103487148880959, 0.7703491696156561, 0.18432420532917604, 0.8766399754676968, 1.2186393770389259, 10.145468898117542, 12.97823779284954, 19.56152133643627, 21.71216033399105, 24.47537586092949, 25.35349164158106, 14.305099043995142, 15.87369667366147, 11.50139668956399, 26.94784428924322, 27.41634014993906, 24.17535725980997, 19.65847123414278, 21.161602176725864, 17.089444287121296, 23.2731868699193, 27.84891463816166, 25.142614357173443, 15.51301147788763, 7.947942316532135, 4.92374824360013, 9.773436561226845, 13.198622167110443, 17.44200076907873, 21.395646817982197, 14.723772928118706, 26.394510380923748, 40.015481784939766, 40.34631863236427, 43.95430862903595, 69.28102880716324, 70.94451114535332, 29.39220182597637, 4.226852813735604, 2.9450500197708607, 2.897212724201381, 0.30044506886042655, 1.1935881525278091, 2.3896421352401376, 2.4079668894410133, 1.3957832590676844, 0.7390387309715152, 0.7198792684357613, 1.3150088558904827, 0.6376728171017021, 0.8248985675163567, 1.5735741751268506, 2.7003381634131074, 1.4037668681703508, 2.6401762291789055, 3.396366289816797, 7.070410279557109, 12.256762906908989, 25.346017442643642, 42.69347168505192, 57.69306041300297, 72.29415312409401, 65.28036028146744, 66.77149906754494, 61.03270500898361, 38.64875592291355, 29.582007341086864, 21.663258858025074, 8.965059388428926, 2.656421782448888, 2.205380047671497, 4.170577358454466, 5.430143270641565, 4.09193535335362, 6.27639158628881, 8.91175964847207, 8.249160703271627, 4.9329788982868195, 4.426384381949902, 2.1913269767537713, 2.579857553355396, 1.7636155150830746, 0.4563662881264463, 0.30389507592190057, 0.19117704854579642, 0.3410805930616334, 0.5119066312909126, 0.46394732664339244, 0.1451798784546554, 0.03489110451482702, 0.2157659744261764, 0.15524086280493066, 0.05633040389511734, 0.1401628414168954, 0.137383067922201, 0.0990421901224181, 0.1504159381147474, 0.13133739936165512, 0.03521782760799397, 0.14886682358337566, 0.09385477082105353, 0.09221082465955988, 0.00436451482528355, 0.07416339620249346, 0.022252841663430445, 0.11468946846434847, 0.05727197778469417, 0.051151137085980736, 0.07299259144929238, 0.1366802243865095, 0.12243956822203472, 0.0994264222390484, 0.02504108677385375, 0.10401767431176268, 0.035405936068855226, 0.03366259035828989, 0.030505505274049938, 0.04227236429869663, 0.028554612399602775, 0.17657045420492068, 0.048631909376126714, 0.05386458113207482, 0.04437680196133442, 0.013506626655725995, 0.03955835250962991, 0.06104557978687808, 0.04864902701228857, 0.02129057113052113, 0.1318846590584144, 0.14865290693705902, 0.1388520750333555, 0.14387421804713085, 0.08212790984543972, 0.06230070735909976, 0.033278295159107074, 0.0871128193102777, 0.07784529472701252, 0.08039175925659947, 0.07516101337387227, 0.10446632484672591, 0.08671972595038824, 0.02522635095374426, 0.06953742646146566, 0.06443439677241258, 0.043853866154677235, 0.04684162653575186, 0.0760573719162494, 0.15686941682361066, 0.14626222662627697, 0.14326380158308893, 0.04563641210552305, 0.07897545947344042, 0.09544002794427797, 0.17641794285736978, 0.05025117912737187, 0.038312880278681405, 0.0898223411059007, 0.0888483168091625, 0.21437893010443076, 0.12557848182041198, 0.31547204533126205, 0.5233427707571536, 0.7988564274273813, 0.5088944616727531, 0.5223576142452657, 0.4057667782763019, 0.41477386839687824, 0.19764826458413154, 0.3729681554250419, 0.6665048387367278, 1.0210003447718918, 0.9613325621467084, 1.0856012720614672, 1.5287809912115335, 0.9690420515835285, 0.754481814801693, 0.38234617095440626, 0.9831400669645518, 0.5077822494786233, 2.5475310254842043, 10.801082868129015, 22.22388457506895, 23.1644956022501, 40.97466431558132, 48.23689542710781, 57.92261369526386, 47.668879106640816, 40.57498276233673, 36.63134157657623, 32.489647418260574, 46.35842442512512, 45.57244420051575, 52.30479754507542, 54.63102512061596, 58.35509888827801, 45.889852568507195, 41.23514413833618, 40.156807601451874, 33.673983067274094, 37.490980848670006, 40.12839272618294, 44.73965048789978, 48.87035943567753, 50.247188955545425, 55.7256855815649, 53.50245147943497, 55.06940759718418, 52.00610317289829, 60.44373661279678, 65.64471513032913, 64.42586213350296, 69.11718159914017, 58.29356499016285, 21.939961910247803, 4.903797414153814, 2.6259557297453284, 1.9970944616943598, 3.106198185123503, 5.0265218038111925, 9.353555291891098, 3.636700068600476, 0.7463453232776374, 0.9545818681363016, 1.0232346248812973, 1.4619803382083774, 2.2260974859818816, 2.497147391550243, 1.6348753357306123, 3.7260216381400824, 2.327262070029974, 1.5158374607563019, 1.5679830126464367, 6.134913302958012, 13.456000406295061, 31.419824324548244, 49.88326348364353, 67.26674929261208, 75.89583545923233, 67.02398791909218, 66.43570348620415, 66.25778183341026, 61.201115772128105, 51.12403750419617, 42.62821018695831, 39.516112580895424, 24.611203372478485, 19.429250434041023, 21.074047274887562, 21.955166794359684, 20.812051333487034, 23.82366333156824, 29.2446044459939, 24.799378775060177, 17.991259396076202, 16.42363641411066, 12.387864422053099, 9.068342596292496, 7.553042806684971, 3.1018063332885504, 2.6332558505237103, 4.088204428553581, 2.95445641502738, 1.9385057617910206, 1.1315114772878587, 0.3668852458940819, 0.07848397217458114, 0.06566549360286444, 0.09763000925886445, 0.04721014738606755, 0.09889338209177367, 0.20982818445190787, 0.16425996087491512, 0.25070564879570156, 0.23145559971453622, 0.3249312221305445, 0.11705486380378716, 0.030656634371553082, 0.08815736247925088, 0.10555759363342077, 0.12121936611947604, 0.06297428801190108, 0.06412616799934767, 0.08981736871646717, 0.08180477874702774, 0.09770904798642732, 0.17264250403968617, 0.06013475307554472, 0.057412971000303514, 0.029160357044020202, 0.05638869588437956, 0.1026745280250907, 0.05315380032698158, 0.08766818325966597, 0.11403158423490822, 0.1224205395556055, 0.2455657863174565, 0.16257374198175967, 0.11373455447028391, 0.019784248834184837, 0.16888888436369598, 0.1311758634983562, 0.09832498602918349, 0.013567358455475187, 0.030726411096111406, 0.10532768370467238, 0.034389056454529054, 0.2505997888511047, 0.24685489683179185, 0.07434789411490783, 0.15127329679671675, 0.07898225754615851, 0.3116823424352333, 0.2389983434113674, 0.22908973682206124, 0.18347457982599735, 0.26889114640653133, 0.21147618273971602, 0.2061122955637984, 0.25083733547944576, 0.26671695057302713, 0.21208940452197567, 0.17411207518307492, 0.22177242790348828, 0.19756177469389513, 0.3094748093280941, 0.3122025582706556, 0.25536514876876026, 0.21540588437346742, 0.2805435477057472, 0.32140406139660627, 0.17832175944931805, 0.12868629943113774, 0.30803943634964526, 0.1646250084741041, 0.33491325681097806, 0.24520974839106202, 0.3462664835387841, 0.7118543959222734, 0.6522065622266382, 0.3492531826486811, 0.46995590266305953, 0.5471622082404792, 0.47010602429509163, 0.44656872167252004, 0.5377291550394148, 0.8996849076356739, 1.0427570273168385, 1.098328095395118, 1.1510076373815536, 1.5377361606806517, 0.857533710077405, 0.6418337719514966, 0.5314252933021635, 0.5572693690191954, 0.10481198012712412, 0.5341304512694478, 6.109581012278795, 17.5388727709651, 22.751191779971123, 43.66832077503204, 53.46179746091366, 66.06010124087334, 59.22927998006344, 52.252238765358925, 53.52653458714485, 44.13495093584061, 61.158805042505264, 59.44738067686558, 62.34413243830204, 59.940305426716805, 63.669467121362686, 47.16911092400551, 42.225196212530136, 43.34365859627724, 38.38462449610233, 44.40308354794979, 43.20370450615883, 40.74927560985088, 44.42571133375168, 45.35717435181141, 49.04009252786636, 51.33726306259632, 51.3260954618454, 59.30204227566719, 65.71881875395775, 76.87839433550835, 79.23375874757767, 91.94583222270012, 88.79870429635048, 59.083181619644165, 26.99510045349598, 12.945079822093248, 6.092509953305125, 3.7831978825852275, 4.59112074226141, 7.60690301656723, 5.797325167804956, 1.9214598764665425, 2.7844017650932074, 3.0982293002307415, 4.515620218589902, 4.796059420332313, 4.096374465152621, 7.2163252998143435, 7.858407245948911, 3.1899141054600477, 2.8990435134619474, 8.755254596471786, 14.506593681871891, 25.99195998162031, 48.08037802577019, 68.04217368364334, 82.75252193212509, 90.4552710056305, 85.09625136852264, 82.28660613298416, 77.39377588033676, 64.25501570105553, 52.60070286691189, 50.97907528281212, 45.11466756463051, 31.206731759011745, 25.77527090907097, 28.9798878505826, 34.94650438427925, 26.53865184634924, 23.500502072274685, 22.481083273887634, 17.612691409885883, 13.21513893082738, 15.149921011179686, 12.311653811484575, 10.342024751007557, 11.022831369191408, 5.259098298847675, 4.20461118221283, 4.335057232528925, 2.534450702369213, 2.2736725956201553, 0.9832100663334131, 0.3303368773777038, 0.19461271731415763, 0.25505377328954637, 0.2760898898122832, 0.30625314626377076, 0.2806378895184025, 0.42555326654110104, 0.20781467843335122, 0.27495772868860513, 0.39280602999497205, 0.3950302762677893, 0.21268940123263747, 0.1647910862811841, 0.26115274289622903, 0.23477654729504138, 0.27987413050141186, 0.23510328523116186, 0.24145491159288213, 0.2541837387252599, 0.15715465386165306, 0.2673607488395646, 0.2480719002778642, 0.2629268914461136, 0.21198764123255387, 0.0813684775494039, 0.19722765980986878, 0.23976725293323398, 0.1708165238960646, 0.15610739443218336, 0.2372368410578929, 0.20507772685959935, 0.3717790567316115, 0.36810587102081627, 0.11038858167012222, 0.09022425118018873, 0.2217158317216672, 0.18210657901363447, 0.1580022755661048, 0.08189409621991217, 0.1357925118645653, 0.2693441533483565, 0.26113412983249873, 0.48299332964234054, 0.19224449439207092, 0.12644203001400456], [0.08212081491365097, 0.07041022181510925, 0.03557689720764756, 0.03955510561354458, 0.011774889990192605, 0.061564174029626884, 0.05560735167819075, 0.06494264918728732, 0.03633132000686601, 0.10947652670438401, 0.08469784108456224, 0.09624154001357965, 0.05309138199663721, 0.08213289707782678, 0.11013431445462629, 0.04347084744949825, 0.07723581336904317, 0.07621179800480604, 0.20801704726181924, 0.1399129899800755, 0.058774077260750346, 0.040696302385185845, 0.10191150373429991, 0.07653881795704365, 0.07472521683666855, 0.10203812897088937, 0.05894703106605448, 0.07746504794340581, 0.09258758334908634, 0.17509246710687876, 0.14643634931417182, 0.2622976986458525, 0.2195264070178382, 0.13466048432746902, 0.14879447902785614, 0.22368213714798912, 0.34304280183278024, 0.1610375556629151, 0.32511120778508484, 0.24575360905146226, 0.07046710001304746, 0.0535683046473423, 0.11171428006491624, 0.15529079450061545, 0.342738936888054, 0.5780104966834188, 0.6560573587194085, 1.1456321133300662, 0.6322539516258985, 1.8360695522278547, 3.388422578573227, 4.756748154759407, 4.934337800368667, 9.730447567999363, 8.766275905072689, 8.201448563486338, 11.810117773711681, 13.933042958378792, 18.549299351871014, 16.04165431112051, 8.017851915210485, 9.025484696030617, 4.908733824267983, 4.990671677514911, 14.584840033203363, 10.184529852122068, 0.6882154487539083, 3.0779823241755366, 4.839573260396719, 7.27348705753684, 7.6366848684847355, 5.695376163348556, 9.985523130744696, 24.449803233146667, 29.629607386887074, 25.854796841740608, 34.35137651860714, 45.868182331323624, 65.38285598158836, 80.84270641207695, 66.38504460453987, 36.25616870820522, 13.137002773582935, 9.593258779495955, 4.031272558495402, 0.2676249237265438, 2.1705352049320936, 3.632759917527437, 2.538313907571137, 2.6297365268692374, 1.6060405829921365, 2.1978894621133804, 1.0504625388421118, 0.7381258299574256, 2.2001128178089857, 2.383152083493769, 4.143219776451588, 3.4738177713006735, 7.436649352312088, 10.795967392623425, 24.505352452397346, 42.52813495695591, 60.928742587566376, 68.72941240668297, 73.11555504798889, 72.65791520476341, 60.34117631614208, 47.095995247364044, 41.04567490518093, 33.243568763136864, 19.677280224859715, 6.293346276506782, 2.3001355631276965, 1.9346456439234316, 7.816022420302033, 3.0209400225430727, 5.60842115432024, 7.016238011419773, 3.6446428298950195, 2.301094299182296, 2.214328092522919, 2.382426322437823, 1.9668392976745963, 1.4137490512803197, 0.7562869554385543, 0.22392444836441427, 0.08013356607989408, 0.18245797109557316, 0.10348399591748603, 0.017674289592832793, 0.039072345971362665, 0.06301803019596264, 0.03676121647004038, 0.020580948075803462, 0.05783610278740525, 0.04874408870819025, 0.09693206389783882, 0.1018141265376471, 0.03937143519578967, 0.10760498611489311, 0.13111503707477823, 0.04076289158547297, 0.08181289784261025, 0.05080443537735846, 0.038316873033181764, 0.1252249671961181, 0.06412561881006695, 0.03285905964730773, 0.02036697020230349, 0.03745538429939188, 0.039408950760844164, 0.022867126572236884, 0.019661365877254866, 0.04439370066393167, 0.03595514390326571, 0.004021348058813601, 0.021461660289787687, 0.10199369658948854, 0.12132899617427029, 0.0516600017726887, 0.1439431041944772, 0.11274726799456403, 0.04063130880240351, 0.012926574236189481, 0.049868193818838336, 0.015275418754754355, 0.014662264693470206, 0.04362902880529873, 0.03666213604446966, 0.022394417464965954, 0.10386721871327609, 0.07372471271082759, 0.1146549363329541, 0.03480536048300564, 0.04990236971934792, 0.049392614455427974, 0.051501248963177204, 0.040771099738776684, 0.014254176239774097, 0.06895380895002745, 0.005717584090234595, 0.0332116057688836, 0.0332891564903548, 0.07885861574322917, 0.012114402143197367, 0.11892689421074465, 0.01812478065403411, 0.017614719254197553, 0.026363642173237167, 0.02710400498472154, 0.09026638290379196, 0.06258722831262276, 0.10485382241313346, 0.07704456933424808, 0.2192252138047479, 0.2058535977266729, 0.16041459690313786, 0.05268416556646116, 0.14554431749274954, 0.09213164492393844, 0.07240079547045752, 0.09770904056495056, 0.3261200833367184, 0.15165517630521208, 0.36497106892056763, 0.2529697632417083, 0.20776804187335074, 0.382029214524664, 0.2584947261493653, 0.2081578623619862, 0.16589639650192112, 0.35523046972230077, 0.39710710232611746, 0.4072853905381635, 0.6377004843670875, 0.4851359693566337, 0.47773159167263657, 0.08030630837311037, 0.1102505496237427, 0.1079910364933312, 0.34410632913932204, 0.5664273526053876, 0.4026962461648509, 0.9418221528176218, 2.443642937578261, 6.508660297840834, 10.438208039849997, 12.906244955956936, 15.731630846858025, 22.68007479608059, 20.57229369878769, 21.681566275656223, 26.225767135620117, 26.8788380920887, 39.417310282588005, 37.66695320606232, 34.43616136908531, 25.590823106467724, 20.43636169284582, 20.619257278740406, 26.51622734963894, 25.886350348591805, 21.370518766343594, 24.176301509141922, 22.577512599527836, 28.583692610263824, 30.84539394825697, 27.917177975177765, 33.619007617235184, 38.55734042823315, 44.90938737988472, 55.000543892383575, 60.10714687407017, 69.9934221804142, 80.58050528168678, 85.65073281526566, 49.178925678133965, 12.40608824416995, 3.6606195475906134, 5.449154125526547, 3.8923940481618047, 3.1848190538585186, 2.143066953867674, 6.309746196493506, 7.123055504634976, 3.5973966401070356, 1.082957920152694, 2.452292935922742, 2.390641481615603, 2.0531101059168577, 5.116814933717251, 2.963822912424803, 3.611724483780563, 3.1097821053117514, 7.9144152905792, 15.019298270344734, 26.87432013452053, 41.185188218951225, 57.75578364729881, 70.6720657646656, 79.80578765273094, 73.72359082102776, 64.80375185608864, 61.3832475990057, 52.895874828100204, 43.524000719189644, 35.3669898211956, 25.46888954937458, 18.41994099318981, 13.674801215529442, 13.047765512019396, 19.61664117872715, 15.3502500616014, 15.528594441711903, 13.01973631605506, 10.16452582553029, 7.226069401949644, 7.131104897707701, 3.8751291995868087, 3.6896675638854504, 2.603071932680905, 1.0077156638726592, 0.4740969085833058, 0.412349984399043, 0.3056960605317727, 0.15784704795805737, 0.03743389912415296, 0.03574618851416744, 0.054683544803992845, 0.12749046203680336, 0.013431583465717267, 0.16369766526622698, 0.10221489370451309, 0.12006981647573411, 0.10358569983509369, 0.10050759781734087, 0.016099118256533984, 0.05196514321141876, 0.03543798200553283, 0.05984924144286197, 0.04268856813723687, 0.01063855428583338, 0.08317321742651984, 0.04598431238264311, 0.09678903719759546, 0.04856869694776833, 0.03898173716152087, 0.04406419822771568, 0.04815697939193342, 0.03844845210551284, 0.0476445189997321, 0.047410030019818805, 0.05017030729504768, 0.02453803681419231, 0.06321143388049677, 0.07911365479230881, 0.10007553428295068, 0.09548382950015366, 0.047713115709484555, 0.045563830062747, 0.04168777457380202, 0.04068507369083818, 0.04582941503031179, 0.04877216415479779, 0.02078674191579921, 0.04519132387940772, 0.031820208751014434, 0.09618204945581965, 0.04868371870543342, 0.05201713436690625, 0.01986280516575789, 0.09291469978052191, 0.0859859051706735, 0.1411387656116858, 0.09052975627128035, 0.17498541972599924, 0.07942650714539923, 0.14193586190231144, 0.10429781279526651, 0.16250375745585188, 0.10503999015782028, 0.22073912085033953, 0.1616462058154866, 0.17155905748950318, 0.13407506339717656, 0.17677736497716978, 0.38651478476822376, 0.22277609357843176, 0.14886899065459147, 0.2083177209715359, 0.2822937991004437, 0.2939503564266488, 0.18271352222654969, 0.16166432906175032, 0.16685137728927657, 0.20517946046311408, 0.23954803735250607, 0.1944238704163581, 0.2765076298965141, 0.19362799124792218, 0.35902545670978725, 0.300084266345948, 0.20082910952623934, 0.33765774860512465, 0.29097265214659274, 0.19648382003651932, 0.1901673269458115, 0.3755477420054376, 0.297387836035341, 0.27643151523079723, 0.36457713693380356, 0.5351732578128576, 0.26823152555152774, 0.13705696823308244, 0.2312924459693022, 0.18170288036344573, 0.35225804953370243, 0.5415712832473218, 0.4760653217090294, 1.2249741121195257, 1.4749895338900387, 4.534480506554246, 8.17218728363514, 11.082848198711872, 12.499134801328182, 21.181754395365715, 18.803608305752277, 18.216667100787163, 29.96341947466135, 29.562261700630188, 43.40827792882919, 40.577190443873405, 36.50256268680096, 26.004628501832485, 21.99752502143383, 21.11453030258417, 31.931206583976746, 29.20677177608013, 23.512129448354244, 24.488355964422226, 25.715929493308067, 30.656734071671963, 39.46703061461449, 35.32700076699257, 44.32795777916908, 59.72382344305515, 59.10741291940212, 64.27903801202774, 74.49833884835243, 82.58678242564201, 93.84190768003464, 95.36716103553772, 84.21838447451591, 63.77031370997429, 38.203852996230125, 22.280469238758087, 10.674277022480965, 7.167874099686742, 8.308119289577007, 13.800351228564978, 10.82905126735568, 7.8250393364578485, 4.355773720890284, 5.248758578673005, 4.144170675426722, 3.2713551353663206, 8.515113182365894, 5.501506291329861, 7.661947812885046, 9.844730235636234, 18.117308132350445, 29.702333584427834, 52.139947190880775, 67.43131846189499, 78.8625718653202, 83.45563620328903, 88.46296191215515, 82.43765562772751, 73.70912879705429, 68.65212455391884, 72.99811094999313, 68.85411411523819, 54.676383286714554, 36.44704766571522, 27.75834459811449, 24.009733647108078, 28.559681698679924, 23.352175131440163, 23.901277966797352, 22.931201420724392, 12.87832310423255, 8.806518595665693, 6.77005872130394, 5.9669167175889015, 2.941230512224138, 2.3486798582598567, 1.214586419519037, 0.583550005685538, 0.16739704879000783, 0.2873354160692543, 0.1643443133798428, 0.21169326093513519, 0.19413508591242135, 0.1415125557105057, 0.17970433604205027, 0.19558831496397033, 0.2625179977621883, 0.29899642628151923, 0.26897227799054235, 0.22747602575691417, 0.1475094206398353, 0.12730116985039786, 0.11609474735450931, 0.15997018403140828, 0.14783859282033518, 0.13218925130786374, 0.12410806462867185, 0.20201289444230497, 0.255800848826766, 0.17662083118921146, 0.19911255163606256, 0.25852634164039046, 0.15873566590016708, 0.13997375703183934, 0.088471654598834, 0.17385140323312953, 0.18098221044056118, 0.15357527561718598, 0.18574513611383736, 0.19833915954222903, 0.27080621395725757, 0.13546139525715262, 0.12243860343005508, 0.16645854368107393, 0.07905737773398869, 0.12808455125195906, 0.12920694571221247, 0.16977460792986676, 0.2600065403385088, 0.18046762008452788, 0.11507634262670763, 0.15045288222609088, 0.1577134762192145, 0.1973704935517162, 0.25692843832075596, 0.12187943226308562, 0.12744997045956552, 0.18922297371318564], [0.023904613772174343, 0.009440766898478614, 0.02129632091964595, 0.044075656987843104, 0.06295175640843809, 0.04035741920233704, 0.03576850860554259, 0.03802046296186745, 0.06960821992834099, 0.04705365812696982, 0.050294424072490074, 0.024052974658843596, 0.02185667210142128, 0.007227428804981173, 0.017125178237620275, 0.11913728565559722, 0.047437882822123356, 0.08225811223383062, 0.04339513725426514, 0.022620618510700297, 0.013684087152796565, 0.17526841547805816, 0.021176289665163495, 0.06260477268369868, 0.015804031063453294, 0.029903194918006193, 0.038735533380531706, 0.014562633223249577, 0.02701308261748636, 0.04935915843816474, 0.024185700349335093, 0.06289773547905497, 0.059914995727012865, 0.06841595968580805, 0.04449231724720448, 0.06554375169798732, 0.0978773225506302, 0.05265277643047739, 0.09171118115773425, 0.02806057582347421, 0.05955829728918616, 0.07034790367470123, 0.011940997483179672, 0.018129682539438363, 0.0640582614869345, 0.021818254826939665, 0.17807394149713218, 0.02097083350236062, 0.22164240363053977, 0.06655621182289906, 0.0984525760577526, 0.22019436961272731, 0.4021426633698866, 0.8754518860951066, 0.6008502992335707, 2.867533704265952, 4.779662825167179, 5.3461202792823315, 5.467683356255293, 9.212925788015127, 9.798520915210247, 7.674426818266511, 4.545725053176284, 3.3406007196754217, 5.2391118463128805, 2.299990220926702, 0.6084898486733437, 3.7943450594320893, 4.71577875316143, 6.9343063328415155, 3.0070952279493213, 6.836702870205045, 7.596545247361064, 13.420488461852074, 20.760051123797894, 25.215057469904423, 39.375026151537895, 45.54826609790325, 54.18211340904236, 65.88274195790291, 72.96088054776192, 63.32497000694275, 42.06370867788792, 22.656174078583717, 13.693285323679447, 10.646951738744974, 4.191199326887727, 6.722709937021136, 6.9392232690006495, 3.2428371906280518, 4.420843804255128, 6.439025234431028, 6.166749894618988, 7.617029473185539, 9.537415076047182, 8.989169094711542, 9.772443864494562, 16.641552820801735, 22.761785611510277, 33.92568156123161, 44.768912717700005, 61.33589833974838, 71.83300226926804, 71.84504002332687, 71.45434498786926, 69.09287050366402, 53.547281473875046, 54.55021485686302, 37.05520503222942, 25.431117676198483, 8.87488167732954, 5.580880232155323, 3.9378878194838762, 7.219092501327395, 4.914418319240212, 6.3227904215455055, 5.850374596193433, 5.071025965735316, 3.3810298377647996, 3.370032752864063, 3.611567267216742, 1.9240173767320812, 0.7479189138393849, 0.22714624501531944, 0.07851754693547264, 0.1449814875377342, 0.12534173671156168, 0.0802779286459554, 0.06783425691537559, 0.046851953520672396, 0.05479169798491057, 0.06741788980434649, 0.03214061616745312, 0.02092402253765613, 0.1048511135741137, 0.06926098387339152, 0.04921643601846881, 0.020010288462799508, 0.038666446853312664, 0.04369059737655334, 0.07146583040594123, 0.03761388477869332, 0.009787767321540741, 0.04804920841706917, 0.05984929339319933, 0.0909158363356255, 0.08995616517495364, 0.04405404193676077, 0.048705422814236954, 0.027917018487642054, 0.0676702571217902, 0.07812496565748006, 0.04634833210729994, 0.012892649738205364, 0.0599404179956764, 0.0525991043105023, 0.02093712886562571, 0.026175908496952616, 0.09831920469878241, 0.05276219126244541, 0.07542299892520532, 0.05885614395083394, 0.009375045083288569, 0.012795499824278522, 0.08859104389557615, 0.017825936338340398, 0.04473612760193646, 0.1021016642334871, 0.13153752690413967, 0.0764574266213458, 0.09399565271451138, 0.01776815643097507, 0.07960877861478366, 0.07121942995581776, 0.01494888769229874, 0.02391302044998156, 0.04369957736344077, 0.04307829585741274, 0.03957157758122776, 0.042678589961724356, 0.0277473004462081, 0.08715057236258872, 0.03821303173026536, 0.023478368675569072, 0.08026246970985085, 0.018168402239098214, 0.024607570485386532, 0.01157980719654006, 0.0900520061259158, 0.030396205474971794, 0.02466129641106818, 0.05320928328728769, 0.034103837970178574, 0.022950911334191915, 0.14118768798653036, 0.019784623618761543, 0.008353041866939748, 0.039445698203053325, 0.029439899954013526, 0.03612253160099499, 0.08499205810949206, 0.05285600615025032, 0.05786633046227507, 0.01839241765992483, 0.17387291067279875, 0.21147452032892033, 0.09947290294803679, 0.05276538991893176, 0.00602265177803929, 0.15151048719417304, 0.0638090111897327, 0.1856208115350455, 0.10842652132851072, 0.07129273930331692, 0.16695400147000328, 0.15034628013381734, 0.1434819187852554, 0.14495707087917253, 0.048246359947370365, 0.02647812772920588, 0.013683701236004708, 0.04187330407148693, 0.13058457960141823, 0.015140365503611974, 0.17644798499532044, 0.37338996247854084, 0.7211896637454629, 1.1197664262726903, 1.8031210452318192, 2.911330391652882, 3.616699604317546, 4.869085801765323, 8.922884501516819, 10.074011832475662, 14.167826659977436, 15.915880110114813, 15.93303618952632, 13.660868313163519, 11.503125596791506, 10.053234547376633, 17.558916695415974, 13.533053621649742, 12.525544334203005, 12.455166410654783, 12.56782941520214, 14.840465616434813, 16.80739302188158, 15.709411539137363, 24.111148305237293, 32.40943752229214, 38.55626128613949, 43.18458013236523, 53.74797150492668, 65.06966158747673, 78.47640618681908, 93.10094743967056, 79.05376240611076, 54.04286228120327, 30.2358952537179, 15.698207840323448, 9.041513185948133, 4.96055306866765, 10.583402998745441, 9.417339619249105, 6.817648792639375, 5.355238365009427, 6.409908821806312, 9.92259280756116, 9.77979552000761, 10.743180625140667, 11.61533072590828, 10.744342412799597, 11.327607315033674, 16.668708063662052, 25.483744852244854, 37.87937320768833, 53.18091653287411, 66.28721505403519, 75.42010098695755, 78.47591981291771, 80.19811660051346, 78.36359024047852, 64.42099839448929, 60.47946609556675, 50.09256385266781, 42.49335542321205, 30.00710193067789, 19.161568097770214, 9.904788862913847, 6.1786081083118916, 12.04123467206955, 11.6701646335423, 9.723724778741598, 10.164341535419226, 5.531064430251718, 4.173173094168305, 3.7394083198159933, 3.2013545790687203, 2.198699056170881, 1.1026074970141053, 0.5298392940312624, 0.4802270483924076, 0.20710514072561637, 0.25089281843975186, 0.26427148492075503, 0.12259683673619293, 0.029131541305105202, 0.05579469943768345, 0.08256113855168223, 0.01997382118133828, 0.060630886218859814, 0.09981390496250242, 0.03257275020587258, 0.011507351318869041, 0.030635325456387363, 0.03951248407247476, 0.16212337708566338, 0.04562691261526197, 0.06635865953285247, 0.0398705703264568, 0.07795701763825491, 0.07086585595970973, 0.11591819042223506, 0.0675947658601217, 0.012667721475736471, 0.10686253415769897, 0.02700624187127687, 0.037251134126563556, 0.053659562836401165, 0.007607863444718532, 0.09303588507464156, 0.038445828613475896, 0.03629740385804325, 0.034470455211703666, 0.05203785884077661, 0.10015129271778278, 0.1841438189148903, 0.040412104353890754, 0.07257371587911621, 0.013841539348504739, 0.05373493906517979, 0.029170253583288286, 0.049108119565062225, 0.06924918372533284, 0.04392775437736418, 0.028429586491256487, 0.08229732731706463, 0.06326648639515042, 0.05306379636749625, 0.0664914445951581, 0.14247960381908342, 0.09076497255591676, 0.14753953699255362, 0.13082962192129344, 0.146387976128608, 0.11973900414886884, 0.16858917544595897, 0.10663806417142041, 0.105827549850801, 0.09758899075677618, 0.1589517793036066, 0.12470460293116048, 0.1875750199542381, 0.1719843377941288, 0.27749504253733903, 0.13326831918675452, 0.14690633659483865, 0.2095052759977989, 0.1909245699062012, 0.2903239260194823, 0.3124285867670551, 0.09660904412157834, 0.14742125349584967, 0.18576055794255808, 0.11018821664038114, 0.12310940845054574, 0.12800999509636313, 0.09436372827622108, 0.08838658963213675, 0.2715102449292317, 0.30104282428510487, 0.40235055377706885, 0.14180614933138713, 0.2285590863903053, 0.1463549950858578, 0.24595766997663304, 0.1032877572288271, 0.2227092260727659, 0.2618248912040144, 0.18359986919676885, 0.24657561181811616, 0.3166198212420568, 0.17438996495911852, 0.23927896429086104, 0.12479167169658467, 0.08360594147234224, 0.2233153529232368, 0.09890204295516014, 0.18049150239676237, 0.22809123649494722, 0.23153731017373502, 0.2364988494082354, 0.3798263717908412, 0.5766271334141493, 0.8281659171916544, 1.4250448951497674, 1.7839855095371604, 3.217176217585802, 5.591601831838489, 6.265052044764161, 8.141215145587921, 13.029563538730145, 14.578249286860228, 16.83560650795698, 16.74819029867649, 16.929362677037716, 25.8291083201766, 23.334684669971466, 20.06914559751749, 19.2581570148468, 28.699130415916443, 34.75979760289192, 30.68593930453062, 32.71967947483063, 40.7657553255558, 45.37608213722706, 59.451245069503784, 64.26127016544342, 74.99257832765579, 81.97147384285927, 86.98768347501755, 93.56006160378456, 86.98793426156044, 81.51302084326744, 69.51530143618584, 50.22325783967972, 36.959678158164024, 22.405965104699135, 19.455353133380413, 14.348023440688848, 13.510899860411882, 10.25173494592309, 10.540936477482319, 12.589135821908712, 12.409516610205173, 13.981128428131342, 14.997588135302067, 14.730431120842695, 16.48922849446535, 28.79084039479494, 43.20807047188282, 64.67421680688858, 74.25552427768707, 84.17306810617447, 87.42407485842705, 88.94270896911621, 85.1788741350174, 87.73191154003143, 71.23524874448776, 75.22661536931992, 67.57606789469719, 54.7395358979702, 39.88742105662823, 33.612243980169296, 29.003353491425514, 25.959228537976742, 23.23350179940462, 19.282779693603516, 16.1147927865386, 11.902156434953213, 6.733194999396801, 6.700770864263177, 5.341039476916194, 4.032538840547204, 1.992265870794654, 0.6323440186679363, 0.37616880086716264, 0.43900068558286875, 0.25740178010892123, 0.33675624697934836, 0.42138106073252857, 0.4654342640424147, 0.14623395079979673, 0.1786510503734462, 0.16526527411770076, 0.1532474986743182, 0.13394900219282135, 0.2013996132882312, 0.14992098498623818, 0.18739163526333869, 0.14467849832726642, 0.1327040049363859, 0.2600808144779876, 0.12117595790186897, 0.1613291900139302, 0.14345346484333277, 0.1891649080789648, 0.26290302397683263, 0.30091594671830535, 0.22542527876794338, 0.09295584444771521, 0.15648326254449785, 0.10064165195217356, 0.2193978225113824, 0.10507016588235274, 0.18519795063184574, 0.11868156245327555, 0.11408296311856247, 0.17740201583364978, 0.12534510606201366, 0.14803008176386356, 0.15412157052196562, 0.18978151405462995, 0.13805186172248796, 0.16763217601692304, 0.12222698002005927, 0.2017589908791706, 0.10865816046134569, 0.15567418799037114, 0.19003501685801893, 0.24764529895037413, 0.22406990930903703, 0.13607911445433274, 0.1235098936012946, 0.17658603930613026, 0.09349880710942671, 0.31228164152707905, 0.20861054275883362], [0.10365109046688303, 0.06255875210626982, 0.0711151582072489, 0.01162189995739027, 0.07973759318701923, 0.06920417989022098, 0.05765825080743525, 0.05243775398412254, 0.032315996795659885, 0.028101696370868012, 0.032623227380099706, 0.065013717248803, 0.0377836844563717, 0.026956703513860703, 0.1224765791266691, 0.08035865947022103, 0.08030164026422426, 0.048711174458730966, 0.014924266943125986, 0.08829763581161387, 0.040719976896070875, 0.04734257250675, 0.026766951195895672, 0.07683258227189071, 0.003542881740941084, 0.05089881058665924, 0.024301219345943537, 0.06296312611084431, 0.023193808847281616, 0.10076602105982602, 0.055646622422500513, 0.034759963309625164, 0.03461239095486235, 0.03303620658698492, 0.02843421563738957, 0.008726682608539704, 0.02848455736966571, 0.040264160925289616, 0.03369068435858935, 0.029670878575416282, 0.03911777283065021, 0.07538279678556137, 0.0778532431286294, 0.027168707274540793, 0.07864789775339887, 0.05136276420671493, 0.046685831184731796, 0.06641230938839726, 0.045711365310125984, 0.11646596962236799, 0.060050363463233225, 0.08675366436364129, 0.13522652036044747, 0.31457262171898037, 0.2223551325732842, 0.3624925034819171, 0.9675078245345503, 1.28788543632254, 1.6779869911260903, 1.4488053764216602, 2.772741853259504, 5.1740536373108625, 6.583727169781923, 6.395671460777521, 10.533358734101057, 7.841741815209389, 4.415258103981614, 6.127527449280024, 7.203468214720488, 7.719098646193743, 8.654597997665405, 5.017360020428896, 4.627541312947869, 16.165647357702255, 14.162927772849798, 26.734487637877464, 42.727187275886536, 46.132792532444, 49.47478920221329, 64.4535930454731, 70.18994763493538, 76.73764988780022, 66.48272976279259, 52.485056072473526, 35.40296249091625, 25.03039687871933, 16.702085472643375, 14.891475029289722, 13.368929978460073, 15.02676011994481, 20.904108993709087, 18.693792298436165, 18.10427103191614, 17.99233663827181, 18.9069589599967, 22.310744114220142, 30.3703111410141, 35.16501545906067, 40.72920508682728, 50.51640830934048, 65.51625922322273, 70.99092945456505, 70.95448181033134, 70.1814740896225, 65.89683160185814, 61.806807070970535, 56.40682563185692, 49.23311457037926, 33.38672608137131, 24.47485338896513, 15.835564769804478, 12.37634439021349, 5.6977548357099295, 5.750336889177561, 7.637507049366832, 7.203336646780372, 3.129142066463828, 2.704603672027588, 0.5696993926540017, 0.4810451326193288, 0.3985203296178952, 0.16375950101064518, 0.09435045867576264, 0.08280609923531301, 0.04610777978086844, 0.080481009936193, 0.015026568289613351, 0.04510178005148191, 0.023116475204005837, 0.0996152097650338, 0.06642027263296768, 0.014412636828637915, 0.027679412487486843, 0.03564383521734271, 0.030172817168931942, 0.05607265229627956, 0.02699859775020741, 0.10093631426570937, 0.05193862256419379, 0.014549621519108769, 0.03904205892467871, 0.04829683712159749, 0.054378277200157754, 0.008775034457357833, 0.04958414050634019, 0.10277607609168626, 0.03904395140125416, 0.056014627480180934, 0.03199701059202198, 0.0816201175621245, 0.0017590063021089009, 0.0938796995615121, 0.006876180050312541, 0.03304465593828354, 0.0387951352604432, 0.008636292732262518, 0.021075394688523374, 0.06380708160577342, 0.06718104079482146, 0.055362379862344824, 0.06768549341359176, 0.10073553363326937, 0.05085409247840289, 0.06421898840926588, 0.03431104931223672, 0.026527821937634144, 0.08334188532899134, 0.14663849549833685, 0.04574005302856676, 0.09254203032469377, 0.05197948521526996, 0.018004400590143632, 0.02320845698704943, 0.04001077315479051, 0.01838637843320612, 0.019286609131086152, 0.08250401544501074, 0.015453459054697305, 0.022270924091571942, 0.04402913174999412, 0.0752776641456876, 0.04188839564449154, 0.09970696148229763, 0.10154575851629488, 0.16406553302658722, 0.022200143612280954, 0.035447670743451454, 0.006896885042806389, 0.05509020833414979, 0.03069168971705949, 0.0844488876464311, 0.09826823399635032, 0.11990335275186226, 0.08241838644607924, 0.04974452604074031, 0.04220168586471118, 0.033315614055027254, 0.03843200611299835, 0.0417347636539489, 0.049512204132042825, 0.08402014151215553, 0.04343574386439286, 0.06189511623233557, 0.03621332965849433, 0.10540198753005825, 0.017321196137345396, 0.018695603539526928, 0.028536157042253762, 0.038708849460817873, 0.07946988567709923, 0.044499297146103345, 0.00746391787288303, 0.051152847736375406, 0.05275655465084128, 0.12342262445599772, 0.024538960788049735, 0.14249420928535983, 0.07094636413967237, 0.09343725338112563, 0.010128030899068108, 0.006392889308699523, 0.04454332134628203, 0.04029403979075141, 0.1363322461838834, 0.12530543084722012, 0.09826477558817714, 0.05983023875160143, 0.12318993889493868, 0.193319643731229, 0.398842035792768, 0.3225737455068156, 1.0517433076165617, 2.6390256034210324, 3.180928537622094, 3.9689193293452263, 6.854638382792473, 8.39304568246007, 6.684947088360786, 7.579352119937539, 7.529058018699288, 12.937078401446342, 9.597095623612404, 5.207374049350619, 4.6456102933734655, 6.745490664616227, 7.738719843327999, 7.5198492128401995, 10.821713861078024, 17.219374515116215, 27.043737843632698, 36.63220413029194, 42.50065103173256, 54.74889479577541, 61.124557480216026, 69.36935886740685, 82.40173995494843, 91.23230651021004, 89.55229505896568, 67.76578411459923, 44.61589492857456, 30.060950741171837, 24.485979191958904, 20.184028632938862, 19.556851387023926, 18.916137367486954, 18.17444186657667, 22.55161128938198, 20.317519269883633, 22.92823188006878, 24.675387628376484, 25.30177641659975, 27.671884037554264, 34.66126888990402, 41.365876123309135, 50.923837646842, 60.954828187823296, 73.58401671051979, 77.90175542235374, 80.45100823044777, 79.03977915644646, 74.82259064912796, 73.52989241480827, 64.40108746290207, 63.72645266354084, 50.4046943038702, 37.37677797675133, 20.50274983048439, 8.787493966519833, 6.691268524155021, 7.344456799328327, 9.670248348265886, 7.767474800348282, 7.601342489942908, 6.141312634572387, 3.750318721868098, 1.559659440536052, 1.8686864082701504, 1.1130143073387444, 0.41385182412341237, 0.3436106338631362, 0.13491747522493824, 0.10307746968464926, 0.04351283445430454, 0.06782803029636852, 0.07666438934393227, 0.21725350554334, 0.034019010490737855, 0.039650148755754344, 0.09399076938279904, 0.04074797070643399, 0.04968988912878558, 0.050709228962659836, 0.041542042745277286, 0.06451668610679917, 0.03151871125737671, 0.05365126191463787, 0.03401949659746606, 0.016381173336412758, 0.08685918292030692, 0.06132850503490772, 0.11073704226873815, 0.09074563960894011, 0.03249838700867258, 0.039067343896022066, 0.019371603593754116, 0.04373525611299556, 0.03641599163529463, 0.04658417550672311, 0.05417488791863434, 0.05352664789825212, 0.011070540822402108, 0.059635963043547235, 0.023959629179444164, 0.04995868388505187, 0.02288650404807413, 0.05053539942309726, 0.07480106432922184, 0.04148415151576046, 0.05137949592608493, 0.04008177071227692, 0.010020607805927284, 0.03135721250146162, 0.015790731777087785, 0.05856792347913142, 0.018170250186813064, 0.024110947524604853, 0.1253271460882388, 0.029086274007568136, 0.007756295763101662, 0.027529417020559777, 0.16407387476647273, 0.05008434432966169, 0.19586403766879812, 0.10755256080301479, 0.3176937683019787, 0.0892645058047492, 0.13088133477140218, 0.14867934223730117, 0.11162678827531636, 0.15932061185594648, 0.25523583695758134, 0.1456029768451117, 0.17082428676076233, 0.11376547234249301, 0.28096784837543964, 0.12375408987281844, 0.25471989589277655, 0.10924896196229383, 0.15956986957462505, 0.1392873891745694, 0.2506413491209969, 0.11860353304655291, 0.12241546326549724, 0.0649593178241048, 0.2568718569818884, 0.09733465674798936, 0.21264151786454022, 0.1288369405665435, 0.16019536647945642, 0.13118658011080697, 0.16330949234543368, 0.1895434776088223, 0.156690425646957, 0.1404676859965548, 0.1485254950239323, 0.22719777974998578, 0.17827997653512284, 0.07399869879009202, 0.1693479620735161, 0.15171852603089064, 0.24719503795495257, 0.0845347392896656, 0.21304073394276202, 0.19538910768460482, 0.26176216488238424, 0.16203170700464398, 0.10497652910999022, 0.14321636350359768, 0.15616608347045258, 0.2706236159428954, 0.12979215884115547, 0.19817904860246927, 0.18811064277542755, 0.42364936089143157, 0.43488877185154706, 0.4177398467436433, 0.625125712249428, 1.0585471987724304, 1.8835005071014166, 3.080480215139687, 2.907155128195882, 4.327871343120933, 5.516017712652683, 7.467939248308539, 9.659973699599504, 12.935497686266899, 18.943220414221287, 18.510625027120113, 16.77471287548542, 19.57806944847107, 25.230176858603954, 28.523142859339714, 32.924005910754204, 34.35551829636097, 40.10283909738064, 49.285574555397034, 49.99823771417141, 66.35458543896675, 76.34174153208733, 77.40721195936203, 81.81584179401398, 91.77949234843254, 92.66739070415497, 94.06529009342194, 86.5893204510212, 79.83806312084198, 67.05374792218208, 55.226259380578995, 42.22909480333328, 36.68475531041622, 32.31813982129097, 30.85272755473852, 32.10760451853275, 28.316129967570305, 30.305982492864132, 32.814039811491966, 33.980641812086105, 37.18402951955795, 46.38774365186691, 59.57533121109009, 76.20516166090965, 82.54671737551689, 87.85582289099693, 84.28061753511429, 82.90301665663719, 84.7305665910244, 80.64058005809784, 83.80141764879227, 74.91756275296211, 79.49569389224052, 67.29165315628052, 61.104859337210655, 49.85292211174965, 37.22400717437267, 23.75152800232172, 19.888643883168697, 18.407464362680912, 13.624612558633089, 7.307456284761429, 6.052399780601263, 3.3434831025078893, 1.788901851978153, 1.2404835736379027, 0.6257311266381294, 0.23517196357715875, 0.5430756462737918, 0.19997808878542855, 0.29469407745637, 0.18793614901369438, 0.2509192982688546, 0.18272526300279424, 0.31908001110423356, 0.22214945376617834, 0.1439743782975711, 0.15984360332367942, 0.26091249485034496, 0.2704186941264197, 0.1273622634471394, 0.15785570139996707, 0.3513399831717834, 0.14284177188528702, 0.2533305063843727, 0.0875815300969407, 0.1349301659502089, 0.11044542276067659, 0.23934648488648236, 0.3224054560996592, 0.17749956372426823, 0.12504205747973174, 0.19490705308271572, 0.07432157013681717, 0.16961572895525023, 0.1401136815547943, 0.12575627071782947, 0.17751146777300164, 0.13607325148768723, 0.11061061741202138, 0.12029024175717495, 0.11803806104580872, 0.1606260347762145, 0.11855041011585854, 0.268715227721259, 0.12279678616323508, 0.21330925781512633, 0.13297736761160195, 0.11416776091209613, 0.10942919252556749, 0.20664278272306547, 0.24670023325597867, 0.2126765323919244, 0.09742921378347091, 0.17217413464095443, 0.14276267378591, 0.06144725608464796, 0.11413042346248403, 0.14856693655019626, 0.23314027494052425, 0.11610478119109757], [0.09868908367934637, 0.06298657797742635, 0.030015407646715175, 0.07735289458651096, 0.046229013314587064, 0.0038071978678999585, 0.06455168579122983, 0.09020848796353675, 0.02053788681223523, 0.12118866347009316, 0.0337520451284945, 0.03533218514348846, 0.06325844893581234, 0.04033892859297339, 0.10435806776513346, 0.039636608271393925, 0.11232299701077864, 0.04510355749516748, 0.04792150706634857, 0.04247608383593615, 0.06695863397908397, 0.04207886042422615, 0.013863827898603631, 0.013744261414103676, 0.016838067276694346, 0.022006869803590234, 0.0021965887481201207, 0.07525850931415334, 0.03527527725964319, 0.01531844662167714, 0.02502705276128836, 0.042452676498214714, 0.0056181446507252986, 0.04898121231235564, 0.07541176280938089, 0.05428846619906835, 0.011848842223116662, 0.023008390671748202, 0.10026398784248158, 0.0252877803723095, 0.024260952268377878, 0.06092753006669227, 0.04000786393589806, 0.039520428763353266, 0.032517304352950305, 0.008118644727801438, 0.02276906288898317, 0.027855787593580317, 0.036687892279587686, 0.023178372175607365, 0.016742979605623987, 0.002752957148004498, 0.09469644050113857, 0.09993582498282194, 0.01931882947246777, 0.03368028315890115, 0.05413981401943602, 0.07836438991944306, 0.08532114865374751, 0.07599300544825383, 0.3195597947342321, 0.5356731091160327, 1.2288382672704756, 2.5503951217979193, 3.481521145440638, 3.3171569276601076, 2.3417495051398873, 7.61310713365674, 12.720376029610634, 12.42115918546915, 11.307517793029547, 17.278313152492046, 17.21649806946516, 16.80344693362713, 19.020479768514633, 26.419769525527954, 37.13914252817631, 41.4567406475544, 39.80763293802738, 58.677120208740234, 66.73587217926979, 71.11462041735649, 74.61504578590393, 79.76292595267296, 64.13228988647461, 53.721160143613815, 43.64244796335697, 38.90284448862076, 32.202010452747345, 33.40933866798878, 36.91612109541893, 41.78960278630257, 39.80522006750107, 36.913142055273056, 35.67830711603165, 44.28027033805847, 51.40505522489548, 52.71573789417744, 58.594079464673996, 71.41345158219337, 75.80523312091827, 72.0440961420536, 69.37914714217186, 70.63697084784508, 67.12102711200714, 51.49739407002926, 44.67758461833, 39.32985797524452, 37.18169644474983, 25.769187435507774, 12.19329396262765, 8.318839464336634, 11.955166440457106, 10.132202859967947, 5.862725833430886, 2.68976713065058, 1.1612552125006914, 1.805873760022223, 0.5092500988394022, 0.1490611326880753, 0.23894654150353745, 0.06005454917612951, 0.05017876406782307, 0.08112768773571588, 0.028266041263123043, 0.07343694494920783, 0.11207693794858642, 0.012173684899607906, 0.02147377213987056, 0.04865297152718995, 0.004965514826835715, 0.0966884168155957, 0.00621440928625816, 0.012347276951913955, 0.08413040239247493, 0.04488867234613281, 0.012950743202964077, 0.01968907396076247, 0.021178191418584902, 0.0462041513674194, 0.08284825322334655, 0.01767349363944959, 0.06209955194208305, 0.0388651828689035, 0.009791917782422388, 0.016623503106529824, 0.0928221020149067, 0.024577884578320663, 0.036265951639506966, 0.06587948446394876, 0.021586010843748227, 0.056109347788151354, 0.03357203349878546, 0.05791849973320495, 0.03709070406330284, 0.018445568421157077, 0.04818201203306671, 0.034713534550974146, 0.15461293165571988, 0.03008105617482215, 0.05834900846821256, 0.055056184573913924, 0.07231960451463237, 0.04913445096462965, 0.04077078432601411, 0.0343066929053748, 0.07305588180315681, 0.1591045132954605, 0.09628117812098935, 0.024645768826303538, 0.07541964441770688, 0.04018731524411123, 0.02027438356890343, 0.03078188849030994, 0.0667568737117108, 0.04770585750520695, 0.08366011083126068, 0.07415215266519226, 0.08744605103856884, 0.04078698540979531, 0.02720399268582696, 0.02097219905408565, 0.0511263790394878, 0.028913999267388135, 0.05939329930697568, 0.023124931976781227, 0.017842046509031206, 0.064508047507843, 0.03939004825951997, 0.05268855908070691, 0.05863865757419262, 0.04698766264482401, 0.045598833457916044, 0.016456866833323147, 0.07300043595023453, 0.0359399410081096, 0.0319397279236, 0.01660186579101719, 0.019070521702815313, 0.020839341632381547, 0.021816204643982928, 0.057605476686148904, 0.08284882467705756, 0.03575962138711475, 0.09338162199128419, 0.027172447698831093, 0.012760107729263837, 0.028631382010644302, 0.08182723613572307, 0.06339004656183533, 0.0419822884578025, 0.042894276630249806, 0.07588123800815083, 0.07680311900912784, 0.03297925417427905, 0.06588968899450265, 0.02475779601809336, 0.04303727735532448, 0.05563105587498285, 0.04858575892285444, 0.020112638048885856, 0.05292977191857062, 0.010207310824625893, 0.028187043353682384, 0.0402530992141692, 0.018401718625682406, 0.06677127879811451, 0.049051645837607794, 0.06941618921700865, 0.13380744494497776, 0.012089150568499463, 0.13982088945340365, 0.09620941244065762, 0.15076743409736082, 0.37992121826391667, 0.5579756561201066, 1.076623066328466, 2.7056319918483496, 4.817960495129228, 5.747400121763349, 8.737492449581623, 8.230399210005999, 7.0467969216406345, 6.106563499197364, 10.178111046552658, 10.15361376106739, 9.687409177422523, 9.57029851153493, 10.911952368915081, 21.286423578858376, 29.636067040264606, 40.847067162394524, 56.495121493935585, 59.490356370806694, 60.01009628176689, 78.0472420156002, 83.58697235584259, 96.38972416520119, 93.3458822965622, 90.08922904729843, 72.9197895526886, 61.46948017179966, 49.61600102484226, 44.72150646150112, 41.89937889575958, 40.70225313305855, 45.34989774227142, 49.25333708524704, 54.94690217077732, 51.42422139644623, 51.61228850483894, 58.835993483662605, 63.94003540277481, 65.99699422717094, 72.51013353466988, 83.88335645198822, 86.6075898706913, 81.32114633917809, 78.11474919319153, 76.01744413375854, 71.21691092848778, 64.13061037659645, 56.85977652668953, 51.218808218836784, 40.34623883664608, 33.737508058547974, 21.442612297832966, 14.68193432316184, 10.904446821659803, 10.524539407342672, 8.36768014356494, 5.642028925940394, 3.8861507456749678, 2.87878988776356, 1.4211489167064428, 0.7547847297973931, 0.4907357704360038, 0.16224946797592565, 0.05174262878426816, 0.09889009437756613, 0.06521803792566061, 0.0696277161478065, 0.07683284944505431, 0.12144104563049041, 0.06729344648192637, 0.03671976752229966, 0.06672255680314265, 0.041672831430332735, 0.047038640768732876, 0.07698475965298712, 0.05572049580223393, 0.04959525787853636, 0.03595737405703403, 0.017335629054286983, 0.037593946981360205, 0.031324123847298324, 0.04431528162967879, 0.02118328626238508, 0.08537833113223314, 0.0573545008955989, 0.10640909677022137, 0.07172291036113165, 0.15359320590505376, 0.03346552046423312, 0.06554894673172385, 0.07034001464489847, 0.06982883074670099, 0.020416679253685288, 0.05527203822566662, 0.05477802020322997, 0.024129102312144823, 0.024381631046708208, 0.08681778592290357, 0.023585002309118863, 0.04474517438211478, 0.0907288893358782, 0.008371097392227966, 0.02870029227779014, 0.05257195654849056, 0.059979213765473105, 0.04165227393968962, 0.03425850154599175, 0.043068109880550765, 0.16921939241001382, 0.005957936036793399, 0.04489751503570005, 0.10757935233414173, 0.09048440362676047, 0.06875492821563967, 0.046155154777807184, 0.08604332513641566, 0.07007844469626434, 0.1959156317752786, 0.1310524740256369, 0.14018495741765946, 0.32604913401883096, 0.1393781538354233, 0.07393839186988771, 0.12200322991702706, 0.15076816140208393, 0.07524518776335754, 0.20520102727459744, 0.0950024725170806, 0.10336097751860507, 0.15869078080868348, 0.18336745823035017, 0.18543460668297485, 0.10364537592977285, 0.18563660443760455, 0.14461461425526068, 0.10724358988227323, 0.18022820324404165, 0.17472822102718055, 0.12832990527385846, 0.18281144119100645, 0.21449372550705448, 0.17523096670629457, 0.10178335709497333, 0.15820204687770456, 0.08972718293080106, 0.21549467492150143, 0.13865312008420005, 0.13282123458338901, 0.11994448999757878, 0.2258585742674768, 0.15133755194256082, 0.1815687891212292, 0.13427731348201632, 0.17092658439651132, 0.15471181541215628, 0.13808795978548005, 0.32989158877171576, 0.21147618273971602, 0.1262208996922709, 0.14593471685657278, 0.1274386007571593, 0.08930915340897627, 0.12044893519487232, 0.17298101243795827, 0.08909623124054633, 0.14389814488822594, 0.09651441287132911, 0.1593598269391805, 0.0685960566624999, 0.25440688768867403, 0.3047434100881219, 0.11566913308342919, 0.1233042222156655, 0.11857507168315351, 0.15633806877303869, 0.18476542696589604, 0.239736394432839, 0.3620408324059099, 0.9713880100753158, 3.361697900108993, 6.101336404681206, 8.867080695927143, 9.328767322003841, 9.109516236931086, 16.093857809901237, 23.794357404112816, 28.001147769391537, 32.98261396586895, 43.22481997311115, 44.579428285360336, 43.84426273405552, 58.75522501766682, 64.29171413183212, 71.88113808631897, 75.05632370710373, 71.31480127573013, 89.803476780653, 93.31333324313164, 98.15409108996391, 94.72407594323158, 98.42218190431595, 87.46110007166862, 83.91956090927124, 70.70542797446251, 63.148891255259514, 61.05007767677307, 58.19813311100006, 56.49978004395962, 59.718287140131, 61.560732275247574, 62.426029443740845, 62.7969541400671, 69.41863462328911, 83.17131265997887, 87.32112318277359, 91.54267385601997, 96.38714030385017, 93.99785131216049, 88.33176255226135, 85.23648664355278, 87.76743203401566, 83.53471755981445, 75.08561253547668, 68.4357413649559, 63.47992189228535, 64.00529310107231, 48.90707686543465, 37.90903441607952, 23.4641570225358, 26.38311669230461, 18.955241069197655, 12.054363917559385, 6.46345934830606, 2.8859145054593682, 2.4217250011861324, 0.8135638351086527, 0.41610213462263346, 0.3603713563643396, 0.16442492546048015, 0.14284039149060845, 0.16603451018454507, 0.14665986935142428, 0.17973264155443758, 0.26767191651742905, 0.22116095758974552, 0.21378013567300513, 0.12776397314155474, 0.17544173664646223, 0.2547537081409246, 0.09808884948142804, 0.20197323407046497, 0.1908114814432338, 0.2034188190009445, 0.09740636305650696, 0.1462186625576578, 0.11638772499281913, 0.22791059775045142, 0.18431050528306514, 0.08312842881423421, 0.2067179771256633, 0.15830501244636253, 0.14599494956200942, 0.22522215294884518, 0.2588561817537993, 0.13651300367200747, 0.1531112106749788, 0.21940515493042767, 0.18731495656538755, 0.15620541729731485, 0.11690806699334644, 0.1212886901339516, 0.10283213792718016, 0.1782884815474972, 0.21870235592359677, 0.1637166939326562, 0.15814441168913618, 0.1702576718525961, 0.1562782219843939, 0.20580932119628415, 0.28229854884557426, 0.18028990540187806, 0.11999039925285615, 0.08931376956752501, 0.12900209811050445, 0.20631138409953564, 0.1581908849766478, 0.10529895516810939, 0.20017791946884245, 0.18194237141869962, 0.09870787485851906, 0.14141125255264342, 0.1642215918400325, 0.14912078651832417], [0.008560089008824434, 0.0337898241559742, 0.007829872283764416, 0.03335321867780294, 0.03268330423452426, 0.05851935362443328, 0.04808422294445336, 0.07695210515521467, 0.06348248105496168, 0.0254559825771139, 0.020020351985294838, 0.05139203080034349, 0.06836076616309583, 0.027174941315024626, 0.07080872543156147, 0.12101314554456621, 0.011556135468708817, 0.05661583389155567, 0.0957590104371775, 0.050649300537770614, 0.05677032677340321, 0.06808516220189631, 0.048461471451446414, 0.024121174319589045, 0.01662792816205183, 0.08479338517645374, 0.03560723620466888, 0.028005050189676695, 0.007557047665613936, 0.013525686863431474, 0.020372272847453132, 0.0401673588930862, 0.044175520379212685, 0.02829009055858478, 0.03732413548277691, 0.0996250803291332, 0.03598833274736535, 0.0030802690889686346, 0.045663878991035745, 0.023654194592381828, 0.043756874874816276, 0.08692894480191171, 0.024629192957945634, 0.06309301679721102, 0.07731062185484916, 0.01177126830953057, 0.0703761275508441, 0.07115396510926075, 0.07026553270407021, 0.015710273692093324, 0.03601505006372463, 0.020765139852301218, 0.0431114141974831, 0.014779750381421763, 0.012852986583311576, 0.06360224884701893, 0.11693370077409782, 0.05951064398686867, 0.052340265465318225, 0.08415106378379278, 0.07429450401104987, 0.11078661773353815, 0.2602768602082506, 0.5810008768457919, 2.505760579369962, 2.325547174550593, 4.009416606277227, 6.400703815743327, 8.337316922843456, 10.158517397940159, 13.637713305652142, 16.004877984523773, 22.302720844745636, 29.064135029911995, 28.785391487181187, 28.84633831679821, 31.78795237094164, 33.81105311214924, 38.87653090059757, 56.17516726255417, 62.50163398683071, 71.09152525663376, 72.31860861182213, 75.82665637135506, 81.17330387234688, 78.62513020634651, 74.13519233465195, 68.09663236141205, 57.37793192267418, 66.7785894870758, 58.173559829592705, 47.60410398244858, 50.86768426001072, 65.23164689540863, 57.66876071691513, 52.94501379132271, 69.1688284277916, 71.43944218754768, 70.1122722029686, 75.7064688205719, 70.59100851416588, 71.63039714097977, 75.29399335384369, 66.62802636623383, 51.23499155044556, 41.842191964387894, 41.10981546342373, 41.10191188752651, 35.862749218940735, 31.64042718708515, 21.298448033630848, 12.551045715808868, 9.837874453514814, 5.4577383399009705, 2.5258774124085903, 1.7461467836983502, 1.4501951518468559, 0.6219237903133035, 0.0835394005116541, 0.05472631848533638, 0.03949642399675213, 0.039837099466240034, 0.08082791202468798, 0.056470228228135966, 0.07402734569041058, 0.19076395430602133, 0.014997494654380716, 0.025623244109738152, 0.02628060512506636, 0.11021611397154629, 0.04321834654547274, 0.055928341680555604, 0.07783490465953946, 0.025906293667503633, 0.06231164661585353, 0.04435890878085047, 0.07581965459394269, 0.0750654173316434, 0.11613869733992033, 0.055641460785409436, 0.08623454690678045, 0.013638207583426265, 0.050736688426695764, 0.04819336689251941, 0.02406449093541596, 0.0424440045026131, 0.0647959636989981, 0.07201408458058722, 0.028344361962808762, 0.07469196862075478, 0.08034904865780845, 0.036135667614871636, 0.10540068135014735, 0.03433564037550241, 0.0105477423130651, 0.017958203752641566, 0.020473151125770528, 0.06249582540476695, 0.11195073573617265, 0.08584439987316728, 0.06375001044943929, 0.062315594841493294, 0.08278313718619756, 0.05512326730240602, 0.026352945969847497, 0.057126283063553274, 0.03014385114511242, 0.0952466094167903, 0.05173530007596128, 0.07934934605145827, 0.03281125791545492, 0.07488190647563897, 0.09565414497046731, 0.011341402459947858, 0.05686113225237932, 0.02822831789671909, 0.07882561985752545, 0.1339480819297023, 0.03667967670480721, 0.04751482127176132, 0.035582812124630436, 0.07897965260781348, 0.02985883675137302, 0.037655652849934995, 0.04728834748675581, 0.06012464131345041, 0.023839319619582966, 0.07107843674020842, 0.0467253802344203, 0.047072389934328385, 0.0388647858198965, 0.060120618873042986, 0.05154284634045325, 0.03446315990004223, 0.06228377897059545, 0.07859270423068665, 0.04600480679073371, 0.06579502805834636, 0.07121016795281321, 0.010543751413933933, 0.00935692554776324, 0.0555089206318371, 0.08191394867026247, 0.06075273202441167, 0.022937185312912334, 0.09692422681837343, 0.026163214060943574, 0.060569941051653586, 0.04106433341803495, 0.04351250419858843, 0.02531454221752938, 0.059787086574942805, 0.0069888737834844505, 0.02117145271768095, 0.08844602823955938, 0.09456564439460635, 0.06294184873695485, 0.06602081164601259, 0.03956955893954728, 0.06749200067133643, 0.03710789591423236, 0.0278399891249137, 0.0748228092561476, 0.012111826890759403, 0.034759803747874685, 0.03375039013917558, 0.032209799173870124, 0.04210150334984064, 0.037776734243379906, 0.06059465456928592, 0.030288900197774637, 0.06251365921343677, 0.111985935800476, 0.08006618649233133, 0.01822230071411468, 0.02627711888635531, 0.08422165687079541, 0.25340727414004505, 0.6823281990364194, 1.5616932814009488, 4.9702501483261585, 5.274178264662623, 5.6019211281090975, 10.017835646867752, 13.178145065903664, 15.109558627009392, 17.820716947317123, 20.05207121372223, 21.51048995554447, 27.39098411053419, 27.066063545644283, 39.26759071648121, 45.8245986700058, 54.69187505543232, 55.03196060657501, 74.70513135194778, 78.6180853843689, 81.12566962838173, 89.68820616602898, 98.31254258751869, 100.70268273353577, 94.61531817913055, 87.41329863667488, 81.2217664718628, 72.05342084169388, 77.50260204076767, 68.15014109015465, 63.06491196155548, 67.42462322115898, 80.61509862542152, 77.0306521654129, 68.50739032030106, 82.5443235039711, 81.23391821980476, 81.73552930355072, 88.28757092356682, 81.63589864969254, 80.04519000649452, 80.80110624432564, 76.49245664477348, 68.46013605594635, 54.88586224615574, 52.5725881755352, 44.41976845264435, 38.60680617392063, 32.86631740629673, 21.959671452641487, 16.343333423137665, 11.96257034316659, 8.608483672142029, 6.11795861274004, 4.003640916198492, 1.6272939112968743, 1.4562275656498969, 0.48751811496913433, 0.2584149898029864, 0.019304604356875643, 0.05383652423915919, 0.021205127668508794, 0.001653069591611711, 0.12104088702471927, 0.09196362268994562, 0.06030503885995131, 0.0683047562779393, 0.04447216422704514, 0.15316699049435556, 0.05338828559615649, 0.0443911922047846, 0.08743252910790034, 0.09673858599853702, 0.020470689050853252, 0.029763379861833528, 0.1425610767910257, 0.03758826213015709, 0.07656974325072952, 0.014759733730898006, 0.05186949892959092, 0.07347246413701214, 0.04437280549609568, 0.029710049129789695, 0.04162777564488351, 0.04577648876875173, 0.015236029266816331, 0.04000883243861608, 0.02016126727539813, 0.01427605939170462, 0.03191210147633683, 0.05804041604278609, 0.05955978900601622, 0.06755960290320218, 0.021747197897639126, 0.018598248607304413, 0.04429083157447167, 0.04406751562783029, 0.04334799603384454, 0.05369252903619781, 0.022009127787896432, 0.06101863611547742, 0.07143195878597908, 0.04547875767457299, 0.04080890474142507, 0.02366746233747108, 0.025215135246980935, 0.025412082686671056, 0.049173588122357614, 0.04156861163210124, 0.03432414450799115, 0.0358592918200884, 0.06298770604189485, 0.017113621142925695, 0.04393472685478628, 0.004582604196912143, 0.14963936962885782, 0.2243341732537374, 0.16329635633155704, 0.16873338958248496, 0.09759083128301427, 0.1797588838962838, 0.09610543755115941, 0.14959279244067147, 0.2632895641727373, 0.09544258093228564, 0.10644941765349358, 0.1510307629359886, 0.1212678432057146, 0.11118768918095157, 0.16208812507102266, 0.1867590582696721, 0.17176500346977264, 0.1395890276762657, 0.2006528791389428, 0.18054380896501243, 0.14776877156691626, 0.1648199261398986, 0.13443889387417585, 0.04694026538345497, 0.08143961240421049, 0.14432011521421373, 0.20223561296006665, 0.10942984561552294, 0.10845216253073886, 0.15970281790941954, 0.1209677112638019, 0.16739372396841645, 0.15127172344364226, 0.23018436011625454, 0.14154452743241563, 0.19331723917275667, 0.10144207306439057, 0.07767969931592233, 0.24132444203132764, 0.1684682202176191, 0.18612516025314108, 0.3249947202857584, 0.13880904531106353, 0.22483530105091631, 0.1677521812962368, 0.0666565501887817, 0.1146695640636608, 0.18103766371496022, 0.19686906889546663, 0.14688010909594595, 0.11399934533983469, 0.19920235150493681, 0.1423778702155687, 0.1372531772358343, 0.10250149629428051, 0.21688649867428467, 0.21386742708273232, 0.13175325439078733, 0.15355471812654287, 0.2118504181271419, 0.16035192995332181, 0.20212708128383383, 0.28462138201575726, 0.6912041071336716, 3.0263259960338473, 5.105748977512121, 7.442155731841922, 11.250222567468882, 14.258086066693068, 18.522229604423046, 26.909703835844994, 35.35988040268421, 44.99193035066128, 53.401468098163605, 58.27187195420265, 62.04665780067444, 62.03828305006027, 66.04664236307144, 73.12586769461632, 89.65573310852051, 91.00037455558777, 94.05446827411652, 101.36786743998528, 101.3413068652153, 100.77245458960533, 102.29491129517555, 97.13722005486488, 91.76632985472679, 82.25450545549393, 89.45459470152855, 79.22390207648277, 66.95176139473915, 74.26722764968872, 90.86588457226753, 86.68963506817818, 79.99060213565826, 96.3147009909153, 96.83011293411255, 95.33392041921616, 97.76658788323402, 86.15898594260216, 88.18932339549065, 88.14972952008247, 87.0722821354866, 76.28605172038078, 69.23647239804268, 73.38078081607819, 68.03912624716759, 59.735770002007484, 48.81118141114712, 36.514961421489716, 24.23674486577511, 16.24631892889738, 9.48068792000413, 4.981186436489224, 2.7897765766829252, 1.91212413366884, 1.0955903423018754, 0.6144004908856004, 0.26414241059683263, 0.14580881892470643, 0.13729966536629945, 0.15529432712355629, 0.19088272762019187, 0.30762849433813244, 0.34452118969056755, 0.22260574100073427, 0.1981954649090767, 0.23398960358463228, 0.36061795719433576, 0.2174246299546212, 0.20315939385909587, 0.22665590804535896, 0.13496433442924172, 0.12920347246108577, 0.1875459574512206, 0.24179068888770416, 0.23774960573064163, 0.3474734234623611, 0.1509343579527922, 0.18360211048275232, 0.2850045380182564, 0.20013488974655047, 0.13119081035256386, 0.1135664209141396, 0.09811921074287966, 0.18097734195180237, 0.19212336104828864, 0.12981050473172218, 0.17844587622676045, 0.19342965970281512, 0.13810088799800724, 0.2833830937743187, 0.15405140788061544, 0.18467215384589508, 0.09972149273380637, 0.09488167313975282, 0.12462489627068862, 0.17424549849238247, 0.26647836493793875, 0.11278381134616211, 0.13916359894210473, 0.2365287728025578, 0.1250634016469121, 0.2141516251140274, 0.3162969573168084, 0.0692071855883114, 0.1945573085686192, 0.0960005572414957, 0.1362513966159895, 0.13216045597800985, 0.18497481651138514, 0.17857262020697817, 0.07616425602464005, 0.13179003522964194, 0.13488925877027214], [0.07503409127821214, 0.04927291716740001, 0.06147831867565401, 0.042431644033058546, 0.029858129855711013, 0.0315916161343921, 0.011627388139459072, 0.029922043613623828, 0.06539557449286804, 0.06307437404757366, 0.012955415022588568, 0.06545672003994696, 0.14198102900991216, 0.09054830996319652, 0.015547543898719596, 0.03049965343961958, 0.04338738181104418, 0.09598126882337965, 0.06140221514215227, 0.020925772150803823, 0.049787232928792946, 0.053773037216160446, 0.002619614315335639, 0.03480560168100055, 0.016229906941589434, 0.09981794966734014, 0.05024680416681804, 0.01701677272649249, 0.06651471092482097, 0.025105596105277073, 0.024425519804935902, 0.0420032912370516, 0.011281354363745777, 0.04239749410771765, 0.05145549926965032, 0.038198949478100985, 0.004068451244165772, 0.001060114007032098, 0.03983481365139596, 0.07484534828108735, 0.012847811030951561, 0.029315786887309514, 0.019849500313284807, 0.05311202854500152, 0.06829291902249679, 0.033330534934066236, 0.04165425918472465, 0.027651645032165106, 0.08445685089100152, 0.045419137240969576, 0.06708062821417116, 0.03596075825043954, 0.02160349213227164, 0.031432043251697905, 0.04794591630343348, 0.025179423100780696, 0.036767706551472656, 0.028333656482573133, 0.0418408202676801, 0.06587572919670492, 0.033843592755147256, 0.03825572377536446, 0.06322783534415066, 0.1436857570661232, 0.13994555542012677, 1.0467083402909338, 0.7125060015823692, 2.844950803555548, 2.993410499766469, 6.225368874147534, 10.25805115699768, 15.843110214918852, 16.556906662881374, 27.053431123495102, 28.851846121251583, 43.39261136949062, 39.7128090262413, 45.9512572735548, 45.67112870514393, 49.336469024419785, 57.12985463440418, 67.13887095451355, 67.6078949868679, 67.72609904408455, 65.34551158547401, 74.13945570588112, 78.05834501981735, 75.02144917845726, 71.25540286302567, 81.8878023326397, 91.38429075479507, 65.55291965603828, 73.2220633327961, 90.08769392967224, 85.67861571907997, 52.49424397945404, 56.8440567702055, 62.92809650301933, 61.00970484316349, 62.83891908824444, 61.981422901153564, 67.79881194233894, 62.939742878079414, 60.183583572506905, 55.49503795802593, 56.58812530338764, 46.55436851084232, 43.280372992157936, 32.35733851790428, 25.73499497026205, 19.113580472767353, 10.296746380627155, 4.530359152704477, 2.899140170775354, 1.6235739109106362, 0.6469757272861898, 0.05357528083550278, 0.04410722423926927, 0.0628534441057127, 0.10556350112892687, 0.04196470326860435, 0.02097219905408565, 0.013135411809344077, 0.031178829885902815, 0.036447544043767266, 0.10146832282771356, 0.03194065189745743, 0.09079335970454849, 0.019160197261953726, 0.040831247097230516, 0.06839365072664805, 0.03688583419716451, 0.03850599823636003, 0.047474522652919404, 0.03689560457132757, 0.03596820941311307, 0.05645701428875327, 0.04139233671594411, 0.09440061301575042, 0.14530878950608894, 0.018705386901274323, 0.03323013719636947, 0.03647272882517427, 0.008771642842475558, 0.030839276914775837, 0.08108778987661935, 0.045702021670877, 0.014524638045259053, 0.06173868263431359, 0.024579459786764346, 0.07396660090307705, 0.03601509830332361, 0.05000632976589259, 0.0311583169241203, 0.0452700286405161, 0.1348736885120161, 0.04356222438218538, 0.021878665647818707, 0.058334588538855314, 0.04183914672466926, 0.04346678419096861, 0.08064057910814881, 0.015956026618368924, 0.02974853134219302, 0.06996063617407344, 0.09906374209094793, 0.05594872847723309, 0.05867878920980729, 0.019544807873899117, 0.026175027196586598, 0.04845100345846731, 0.05245257096248679, 0.06068587565096095, 0.06393373652826995, 0.021542949580179993, 0.03365613738424145, 0.05261845210043248, 0.05378737550927326, 0.042017299274448305, 0.060823922540294006, 0.022420871318900026, 0.06910306226927787, 0.06320097701973282, 0.0642203539609909, 0.06624945992371067, 0.07173776073614135, 0.03556376861524768, 0.13304209773195907, 0.05205096516874619, 0.03962874150602147, 0.08325218936079182, 0.03192863652657252, 0.07022291116300039, 0.03482925763819367, 0.061122440311009996, 0.041042328739422373, 0.06946821376914158, 0.03894024368491955, 0.04488912505621556, 0.05575696864980273, 0.05601349941571243, 0.03814955212874338, 0.05007057749025989, 0.009364396191813285, 0.06717741169268265, 0.03353570165927522, 0.004651814106182428, 0.013565047593147028, 0.04590315482346341, 0.032408802362624556, 0.015865462337387726, 0.04294800812203903, 0.014081128738325788, 0.023247722165251616, 0.0826628202048596, 0.030393947490665596, 0.034934245559270494, 0.004429888294907869, 0.058529895832180046, 0.03704534399730619, 0.049700991658028215, 0.04178235387371387, 0.07371881263679825, 0.014143047974357614, 0.028933860994584393, 0.036171138563076966, 0.056937347108032554, 0.0064016554642876144, 0.05917939750361256, 0.02302516506460961, 0.0926450701081194, 0.09235561767127365, 0.023387036271742545, 0.025126769578491803, 0.051196890490246005, 0.05948447585979011, 0.03914247150532901, 0.09957042857422493, 0.06429310669773258, 0.48462498583830893, 0.7541407237295061, 1.6788982297293842, 2.1907741064205766, 5.203715320676565, 8.295380473136902, 12.297124341130257, 16.71639360487461, 23.503416515886784, 26.549948640167713, 31.23578120023012, 33.56033116579056, 39.594000801444054, 37.136292681097984, 52.089550495147705, 54.68438945710659, 71.4618381857872, 80.87446510791779, 85.28989657759666, 84.07570973038673, 79.09845560789108, 81.68662592768669, 91.35776057839394, 95.01703262329102, 88.55901315808296, 80.66633507609367, 93.33863228559494, 98.85745614767075, 72.64105930924416, 86.1186321079731, 112.36313223838806, 99.28242534399033, 68.23925390839577, 71.56912162899971, 78.80419179797173, 78.54630723595619, 83.9865817129612, 75.41449248790741, 77.92874917387962, 79.50580134987831, 68.07217687368393, 63.73969115316868, 52.25629314780235, 49.41730208694935, 46.80314116179943, 36.1665391176939, 29.66116849333048, 21.161070205271244, 13.192896824330091, 9.166275691241026, 5.089179966598749, 2.995145106688142, 1.094960526097566, 0.37511447619181126, 0.3568895853823051, 0.19495046872179955, 0.08649218347272836, 0.04425109327712562, 0.03573611757019535, 0.048085985545185395, 0.048414296834380366, 0.03366818986251019, 0.009056104336195858, 0.07876203264459036, 0.08818220958346501, 0.03380811438546516, 0.050153527336078696, 0.026802069623954594, 0.021109320114192087, 0.04818694360437803, 0.02837531137629412, 0.05533383315196261, 0.018058692403428722, 0.08762315716012381, 0.059883896028622985, 0.06421629441319965, 0.06602834444493055, 0.03406640033063013, 0.06544950636452995, 0.028241837972018402, 0.04371450195321813, 0.028472243284340948, 0.07034015565295704, 0.023357107311312575, 0.043862048332812265, 0.09457173742703162, 0.04314493700803723, 0.06470963708125055, 0.032052731039584614, 0.01878258139186073, 0.07400218688417226, 0.03232442388252821, 0.047798436717130244, 0.06710856265272014, 0.03232786002627108, 0.023492933323723264, 0.061091604075045325, 0.04048115006298758, 0.0663278900901787, 0.031476201038458385, 0.019294637313578278, 0.03873245346767362, 0.019249316210334655, 0.042621336979209445, 0.08374028504476883, 0.00839354272102355, 0.025118477933574468, 0.09229084302205592, 0.07280364807229489, 0.05674695654306561, 0.08041242806939408, 0.03199278777174186, 0.03144249269098509, 0.12792188732419163, 0.15503031550906599, 0.20139337924774736, 0.1978148618945852, 0.07259708610945381, 0.17269273259444162, 0.14186872722348198, 0.1193243068701122, 0.17816681385738775, 0.20952801540261135, 0.19496749358950183, 0.2608781185699627, 0.13318847893970087, 0.1375529306824319, 0.14357039763126522, 0.13986630889121443, 0.13392970635322854, 0.15171085222391412, 0.19329528644448146, 0.15638265700545162, 0.19777247041929513, 0.0841553979262244, 0.12833189422963187, 0.1865371858002618, 0.10908722571912222, 0.22764425579225644, 0.19835084094665945, 0.1114457190851681, 0.26456380204763263, 0.1468429423402995, 0.19006011629244313, 0.1341936140670441, 0.24559946497902274, 0.16218426288105547, 0.11654091911623254, 0.20593027642462403, 0.10395212040748447, 0.1416721916757524, 0.1424831958138384, 0.20562982535921037, 0.07372124688117765, 0.11750401899917051, 0.08600713801570237, 0.21630376431858167, 0.1401402652845718, 0.07983320407220162, 0.160209140740335, 0.06318262370768934, 0.17651100817602128, 0.13427746191155165, 0.19967634638305753, 0.09538890881231055, 0.11383994686184451, 0.09388605976710096, 0.1854775770334527, 0.16865767567651346, 0.20434518257388845, 0.07011978232185356, 0.20860306191025302, 0.0850861550134141, 0.13722512405365705, 0.1045088870159816, 0.21925221313722432, 0.38960977806709707, 0.335700586438179, 1.4329724572598934, 1.2203828897327185, 3.7102009495720267, 5.420621456578374, 11.452496163547039, 16.12552721053362, 27.109204530715942, 32.27304004132748, 44.484475180506706, 52.766244783997536, 66.49360477924347, 61.967067271471024, 76.9000531733036, 75.06802707910538, 85.86550489068031, 94.26084280014038, 96.09486758708954, 94.07516956329346, 90.00706225633621, 91.40627637505531, 95.94016268849373, 100.30126467347145, 97.756617218256, 100.02277761697769, 107.530277967453, 116.74802854657173, 85.10197386145592, 97.2873803973198, 113.21197628974915, 107.02353715896606, 78.50211560726166, 84.88274082541466, 94.15676638484001, 90.66361382603645, 91.11191377043724, 76.53233170509338, 83.79332408308983, 88.93365785479546, 84.78937983512878, 86.61740854382515, 76.92681893706322, 75.55681005120277, 61.852298229932785, 48.28537702560425, 36.57250553369522, 27.272460870444775, 13.535337299108505, 6.71573493629694, 3.9875806029886007, 2.073346870020032, 0.761296214768663, 0.24620306852739304, 0.3811996121658012, 0.2835553017212078, 0.1670959743205458, 0.2045984924188815, 0.15330727124819532, 0.08533197658834979, 0.12450358481146395, 0.15906874177744612, 0.21581828099442646, 0.15438001602888107, 0.2053080449695699, 0.1495505345519632, 0.13530204130802304, 0.1427358970977366, 0.1266776619013399, 0.18968764721648768, 0.10832074302015826, 0.1489471981767565, 0.23009165102848783, 0.12583214789628983, 0.27815837413072586, 0.3359059238573536, 0.2102357571129687, 0.13098905008519068, 0.1574244096991606, 0.1170580401958432, 0.11011001653969288, 0.1253383673611097, 0.14257317379815504, 0.14754413830814883, 0.13517648476408795, 0.2810141583904624, 0.09756667437613942, 0.08917372630094178, 0.09274960902985185, 0.10967465044814162, 0.14680555294035003, 0.09408699625055306, 0.1634188849129714, 0.2127795573323965, 0.1011248939903453, 0.12596379005117342, 0.08678651181980968, 0.17117737093940377, 0.19970805093180388, 0.18086708849295974, 0.2643403265392408, 0.15065900632180274, 0.20757281250553206, 0.20471671654377133, 0.11478543558041565, 0.06323151639662683, 0.10586108750430867, 0.19861841486999765, 0.23283361952053383, 0.11071240296587348, 0.12358338106423616, 0.09704494455945678, 0.11175470484886318], [0.09794529585633427, 0.06517838497529738, 0.07767627059365623, 0.009880562683974858, 0.07380450100754388, 0.057732480418053456, 0.09820198247325607, 0.02760644452791894, 0.09678788686869666, 0.037241597528918646, 0.042479898474994116, 0.13890923524741083, 0.08487365586915985, 0.07797007201588713, 0.02664110706973588, 0.053152152759139426, 0.03976148946094327, 0.08398280406254344, 0.11157963963341899, 0.09441944130230695, 0.0598015399009455, 0.018714682300924323, 0.012421620667737443, 0.05171738834178541, 0.03606781305279583, 0.011072102115576854, 0.03750107833184302, 0.06218105831067078, 0.016051056772994343, 0.10538812421145849, 0.028022770820825826, 0.01929736099555157, 0.014465120584645774, 0.054817535856273025, 0.043327134262654, 0.028144598072685767, 0.026076297435793094, 0.03079200952925021, 0.03377645436557941, 0.061621657077921554, 0.11697751717292704, 0.10095103105413727, 0.06124048632045742, 0.010893313174165087, 0.038347512600012124, 0.02822935133735882, 0.041530405869707465, 0.021107997235958464, 0.024393036001129076, 0.04745402453409042, 0.12747170054353774, 0.040646381821716204, 0.0758043811947573, 0.033281645955867134, 0.06832909872173332, 0.033699170817271806, 0.09280707352445461, 0.13809318450512365, 0.07414013729430735, 0.04187587561318651, 0.031717892561573535, 0.0672895873140078, 0.05802060441055801, 0.13524308509659022, 0.06236986810108647, 0.08682805724674836, 0.2007788364426233, 0.27933182835113257, 1.7451842478476465, 1.3484781724400818, 4.6206955052912235, 6.494715046137571, 14.873292054980993, 17.282669618725777, 19.404684752225876, 25.743909291923046, 39.898284673690796, 49.4925494492054, 51.23542472720146, 50.78022055327892, 54.961706176400185, 61.22801832854748, 62.205097898840904, 67.81620740890503, 58.93355704843998, 55.49207031726837, 53.79503957927227, 49.21498954296112, 54.65178340673447, 56.700318083167076, 62.19919301569462, 72.59961873292923, 54.03377316892147, 88.85714516043663, 99.54699754714966, 26.451986096799374, 27.879723384976387, 31.776997558772564, 59.22833763062954, 66.01859226822853, 64.64932054281235, 67.18517526984215, 67.85802036523819, 57.808213233947754, 54.96874339878559, 48.66609759628773, 44.14040744304657, 28.628439009189606, 16.234854944050312, 12.321731820702553, 7.399842627346516, 3.2129128463566303, 1.2495272071100771, 0.35067994671408087, 0.02321861142263515, 0.03990800054452848, 0.03180204839736689, 0.027245124365435913, 0.027885369599971455, 0.05119659363117535, 0.050627911841729656, 0.03458487211901229, 0.017129697916971054, 0.05089302925625816, 0.025066560992854647, 0.04450454784091562, 0.07258143421495333, 0.05198946710152086, 0.04086206477950327, 0.02553474114392884, 0.05762608612712938, 0.02974227689264808, 0.03306492399133276, 0.055537407970405184, 0.07199458836112171, 0.04326821515860502, 0.02717154784477316, 0.03694557337439619, 0.03456427752098534, 0.03286913059127983, 0.030221863853512332, 0.012138651818531798, 0.03441530992859043, 0.02314238914550515, 0.03510915121296421, 0.08289044431876391, 0.0463100743945688, 0.008998930206871592, 0.06307477480731905, 0.07254713214933872, 0.04834895815292839, 0.0021132335041329497, 0.050705993198789656, 0.011921760087716393, 0.026230884941469412, 0.02207638306572335, 0.048797000126796775, 0.03828502376563847, 0.02165167978091631, 0.050209667097078636, 0.037264043785398826, 0.06474425084888935, 0.07234107484691776, 0.06344700639601797, 0.049865566616063006, 0.08004088667803444, 0.019933429794036783, 0.033261782373301685, 0.040147450781660154, 0.030557140198652633, 0.058054134642588906, 0.05482063803356141, 0.0220552800965379, 0.10179515724303201, 0.05200552346650511, 0.049647286141407676, 0.02579538711870555, 0.03272701673267875, 0.08841942966682836, 0.08046610018936917, 0.11172619895660318, 0.05835741700138897, 0.056732128432486206, 0.04809916979866102, 0.044648505936493166, 0.020107012569496874, 0.1033546173130162, 0.12621140020200983, 0.0815237571077887, 0.050590581813594326, 0.07852973300032318, 0.022551919755642302, 0.04884648653387558, 0.05344634009816218, 0.09344617399619892, 0.08196379130822606, 0.04644989130611066, 0.01591965581610566, 0.021932424970145803, 0.11046378349419683, 0.06400028491043486, 0.016958723790594377, 0.022370047190634068, 0.07234350909129716, 0.0955109549977351, 0.04155055146839004, 0.020628287820727564, 0.019542644513421692, 0.02291703971422976, 0.052996943704783916, 0.0029376368865996483, 0.02150474381778622, 0.0601243555865949, 0.019148115097777918, 0.09148189463303424, 0.026651521257008426, 0.09123429932515137, 0.055569346295669675, 0.022352669802785385, 0.07438261920469813, 0.05201626234338619, 0.052729406888829544, 0.041952402170863934, 0.026592290450935252, 0.06536157670780085, 0.05523081934370566, 0.048233873312710784, 0.08174628266715445, 0.010286149172316073, 0.06693157527479343, 0.08911903743864968, 0.06911662872880697, 0.029627323783643078, 0.08295579042169265, 0.09444723473279737, 0.03396414722374175, 0.01434025331036537, 0.023034809273667634, 0.06704450788674876, 0.07316568997339346, 0.12919097469421104, 0.5094457883387804, 0.6490317732095718, 1.2463021301664412, 3.6946170357987285, 5.577073786407709, 10.666620433330536, 14.075069837272167, 20.998509228229523, 29.951195530593395, 34.16331700980663, 44.467676281929016, 47.50532068312168, 54.295088946819305, 56.53058119118214, 64.67038661241531, 74.0341329574585, 75.82456648349762, 79.52384278178215, 80.04413366317749, 70.05625560879707, 73.71953263878822, 70.65055131912231, 71.69655919075012, 66.50413781404495, 70.48112601041794, 78.10831233859062, 79.22792226076126, 70.55587559938431, 106.23822569847107, 107.15184107422829, 40.164635181427, 47.7532459795475, 56.54253154993057, 82.65368923544884, 79.89965781569481, 74.0095254778862, 76.59498274326324, 68.29284623265266, 68.19138407707214, 63.24281461536884, 60.632392689585686, 52.42572605609894, 40.27417570352554, 27.415519393980503, 22.797805778682232, 15.557141359895468, 8.207748625427485, 3.6322336457669735, 1.0660181916318834, 0.5695754836779088, 0.14201712707290426, 0.12166503322077915, 0.02612754273286555, 0.015571211915812455, 0.026060979507747106, 0.05480591382365674, 0.024946622506831773, 0.0487197982147336, 0.0442449223191943, 0.05390504673414398, 0.07458872103597969, 0.02489299491571728, 0.015859079867368564, 0.018395586630504113, 0.05992777551000472, 0.022237109988054726, 0.029357952007558197, 0.019211594699299894, 0.08425796273513697, 0.04856106395891402, 0.10622825764585286, 0.034745138909784146, 0.026920802120002918, 0.050889533740701154, 0.019385702544241212, 0.06885885857627727, 0.037885395795456134, 0.07563337552710436, 0.08005398558452725, 0.0998778038774617, 0.02550139273807872, 0.009007117951114196, 0.016960733155428898, 0.056746722766547464, 0.024762324974290095, 0.07669335536775179, 0.07066834077704698, 0.16436105623142794, 0.03188825627148617, 0.04657765573938377, 0.025660405299277045, 0.07021779034403153, 0.06296347492025234, 0.010976855810440611, 0.05712858372135088, 0.07562066995888017, 0.09369215142214671, 0.10358208557590842, 0.031045529030961916, 0.03993622070993297, 0.027094498072983697, 0.011515404548845254, 0.031048582968651317, 0.023709158049314283, 0.06954360113013536, 0.04948548310494516, 0.09648008111980744, 0.051983600424136966, 0.10531296691624448, 0.049829772833618335, 0.045938080293126404, 0.17083047627238557, 0.21004550013458356, 0.18150475661968812, 0.2594404894625768, 0.22582023491850123, 0.11567582725547254, 0.24295894807437435, 0.08209423860535026, 0.14102825982263312, 0.082117445563199, 0.18748121248790994, 0.1615217179642059, 0.12528557097539306, 0.17539195338031277, 0.2505541022401303, 0.12811532069463283, 0.19911963172489777, 0.16656306775985286, 0.28706399782095104, 0.22335110959829763, 0.1860713545465842, 0.12644090194953606, 0.11144293603138067, 0.1282614644151181, 0.11036019452149048, 0.14752120594494045, 0.14016827393788844, 0.18736337427981198, 0.1390706078382209, 0.23244240379426628, 0.18727998656686395, 0.1505140055087395, 0.10416982200695202, 0.09904294711304829, 0.159852197393775, 0.13206513453042135, 0.13741588569246233, 0.08716004216694273, 0.1998313216608949, 0.1574494646047242, 0.29702180880121887, 0.17425480502424762, 0.1399069934268482, 0.14445284090470523, 0.1244362942816224, 0.1315560657531023, 0.21154898742679507, 0.09386513862409629, 0.10714905511122197, 0.17307514644926414, 0.2788909332593903, 0.17308219685219228, 0.12061147295753472, 0.12726009939797223, 0.2404987285262905, 0.182498462672811, 0.21586568938801065, 0.3141743259038776, 0.18622214411152527, 0.18680879700696096, 0.09806290399865247, 0.18647934281034395, 0.300835557281971, 0.2111957102897577, 0.1735964755062014, 0.22707755182636902, 0.4437227040762082, 0.453107695793733, 2.4155876180157065, 3.5036392835900187, 9.447001777589321, 11.334696784615517, 23.783199302852154, 30.52075456827879, 37.108595967292786, 50.97132369875908, 61.53175503015518, 71.85021534562111, 80.17941400408745, 82.75966554880142, 89.89271879196167, 93.37019339203835, 94.30959418416023, 95.13932526111603, 84.5637783408165, 85.21470621228218, 81.14263191819191, 77.75213465094566, 80.45306012034416, 77.82129853963852, 83.28168913722038, 93.57928857207298, 78.14993530511856, 116.64547964930534, 116.46514132618904, 41.72278717160225, 53.079967349767685, 62.158527597784996, 92.121861577034, 87.87384912371635, 84.08232137560844, 91.35367199778557, 88.70925709605217, 85.36464616656303, 81.94941982626915, 72.94144839048386, 63.992981761693954, 42.27846175432205, 26.46939106285572, 17.630767039954662, 11.85041081160307, 5.55391687899828, 2.334338240325451, 0.6151707808021456, 0.3277461288962513, 0.11993355074082501, 0.10894491148064844, 0.11294547337456606, 0.16991754557238892, 0.12257963375304826, 0.10496634684386663, 0.1405470067402348, 0.12051554294885136, 0.21462189441081136, 0.1593449988286011, 0.15063669736264274, 0.14761750702746212, 0.11417375004384667, 0.19790627964539453, 0.10331390309147537, 0.23426513333106413, 0.07285880448762327, 0.19770619663177058, 0.13425231794826686, 0.11010201618773863, 0.14847351500065997, 0.14506897190585732, 0.15039800782687962, 0.1149287517182529, 0.13872929412173107, 0.13701181596843526, 0.06677929399302229, 0.23138279502745718, 0.12404731241986156, 0.21701729478081688, 0.17294391989707947, 0.10708371642976999, 0.12406659341650084, 0.1515277347061783, 0.17369155946653336, 0.23181251337518916, 0.12753818213241175, 0.2291363140102476, 0.0939565192675218, 0.1548641041154042, 0.10836380984983407, 0.1406309733283706, 0.1327086062519811, 0.10946137204882689, 0.07761616405332461, 0.1882161761750467, 0.19438128598267213, 0.2027088508475572, 0.22453119861893356, 0.15890772541752085, 0.16910649690544233, 0.14724696753546596, 0.1393445790745318, 0.10705311025958508, 0.17000568303046748, 0.10000714537454769, 0.19330321258166805, 0.1836426169029437, 0.18925003241747618, 0.18927891680505127, 0.1614387458539568], [0.09880884404992685, 0.07493390134186484, 0.13729592494200915, 0.04201055315206759, 0.04194447603367735, 0.047180376132018864, 0.08997424389235675, 0.06280365341808647, 0.02441741555230692, 0.052388360345503315, 0.05145906157849822, 0.05688823548553046, 0.03740196079888847, 0.07558497265563346, 0.06514234628411941, 0.03688871001941152, 0.05502250962308608, 0.04255640276824124, 0.04222664800181519, 0.019795987755060196, 0.013681489635928301, 0.04755760979605839, 0.09639725743909366, 0.030862194435030688, 0.024153927151928656, 0.006513389043902862, 0.015217795626085717, 0.03848441287118476, 0.04829595396586228, 0.08844865544233471, 0.029352020392252598, 0.008268950041383505, 0.029303598967089783, 0.03421886714932043, 0.01776772227458423, 0.025283106697315816, 0.005475356829265365, 0.10529738923651166, 0.04846272568101995, 0.034749717960949056, 0.0375685840845108, 0.005078200210846262, 0.01395940260408679, 0.051753924271906726, 0.028392505082592834, 0.0024249132638942683, 0.05167415081814397, 0.0839951608213596, 0.004034599105580128, 0.025917518651112914, 0.006778813985874876, 0.08581037982366979, 0.013875992626708467, 0.04408818815136328, 0.10804960678797215, 0.09879852077574469, 0.025335368736705277, 0.0791881293116603, 0.10181915829889476, 0.05978446308290586, 0.024684186100785155, 0.01634481923247222, 0.039752238590153866, 0.0486478469974827, 0.08426255662925541, 0.020639548056351487, 0.09684945543995127, 0.13265138666611165, 0.20657777058659121, 0.3242183447582647, 0.9255080844741315, 3.0088341096416116, 6.617110753431916, 10.821720510721207, 13.136018626391888, 16.985742151737213, 24.66073751449585, 31.827779933810234, 48.115723729133606, 54.815311431884766, 58.168312311172485, 60.48361927270889, 65.84953933954239, 67.31295481324196, 75.5977338552475, 75.2627894282341, 66.26485705375671, 53.5554738342762, 48.27051222324371, 27.869294844567776, 23.20434596389532, 29.36677549034357, 45.51258221268654, 42.50493340194225, 45.516078025102615, 26.285163648426533, 34.091630056500435, 41.72484666109085, 57.70381383597851, 68.08023244142532, 65.82242399454117, 62.304192781448364, 54.9232142418623, 46.06814280152321, 38.83474454283714, 33.52873966097832, 19.40974038094282, 11.608556639403105, 9.830837231129408, 4.154529869556427, 0.8257516217418015, 0.6191730941645801, 0.17533068166812882, 0.05096273176604882, 0.04677816919866018, 0.01945368327142205, 0.06867730699013919, 0.0408524094382301, 0.04093425719474908, 0.06851885103969835, 0.01603012264240533, 0.04437482784851454, 0.04455201931705233, 0.017899709528137464, 0.018011599422607105, 0.007083518485160312, 0.00825915554742096, 0.11307203181786463, 0.009649714866100112, 0.05239475394773763, 0.023526224213128444, 0.03259871053160168, 0.019877855920640286, 0.0470283212052891, 0.03332684274937492, 0.026720066016423516, 0.044741044330294244, 0.020905281453451607, 0.045581953309010714, 0.012892940103483852, 0.04048085320391692, 0.06006169605825562, 0.04627801361493766, 0.06135029820143245, 0.028215298771101516, 0.030296735421870835, 0.05209455150179565, 0.06399743506335653, 0.022373759784386493, 0.03734832578629721, 0.05346974743588362, 0.02169458519347245, 0.03164752954035066, 0.03361186456459109, 0.04649662063457072, 0.04394588875584304, 0.09944525052560493, 0.06661234787316062, 0.020965252551832236, 0.04402440426929388, 0.028957732174603734, 0.061658115082536824, 0.061229658385855146, 0.04243227856932208, 0.05644463155476842, 0.07269187321071513, 0.06677877448964864, 0.08012464546482079, 0.06305576840532012, 0.028599848155863583, 0.027802275035355706, 0.04147915686189663, 0.03209892973245587, 0.014415005207411014, 0.0848095046239905, 0.04572259771521203, 0.0651714533159975, 0.06637428174144588, 0.08566166085074656, 0.05863487262104172, 0.021199507755227387, 0.08040363361942582, 0.05420406916528009, 0.031331871869042516, 0.03778373640670907, 0.018773300835164264, 0.05428986143670045, 0.06492556494777091, 0.10179805161897093, 0.0499970974487951, 0.03846394443826284, 0.00830749626402394, 0.06308819283731282, 0.020019704461446963, 0.07010341054410674, 0.038401036290451884, 0.07512498952564783, 0.030133310792734846, 0.10633278172463179, 0.03709985103341751, 0.04501561670622323, 0.010633674664859427, 0.006739493146596942, 0.05004425722290762, 0.09985140568460338, 0.017936811345862225, 0.036248726391931996, 0.052111724799033254, 0.03337922724313103, 0.052835226015304215, 0.03413969483517576, 0.06922510103322566, 0.024294584545714315, 0.030756809464946855, 0.02669117420737166, 0.05442849091195967, 0.0256323298526695, 0.09092195163248107, 0.011397019934520358, 0.04610028780007269, 0.024938646274677012, 0.05022611680033151, 0.029730001770076342, 0.12819839670555666, 0.10883973431191407, 0.024949210746854078, 0.016342294075002428, 0.05567841602896806, 0.015398914911202155, 0.048666864531696774, 0.03690095916681457, 0.033638210807112046, 0.03749096656974871, 0.058250473521184176, 0.05026612227084115, 0.005746873412135756, 0.03219615107809659, 0.020390652134665288, 0.05571250287175644, 0.012335952706052922, 0.06380325954523869, 0.0541162693843944, 0.11509209100040607, 0.23039232473820448, 0.5626916186884046, 0.9047559730242938, 3.055089502595365, 5.5534400045871735, 12.387520540505648, 16.62709839642048, 20.27301035821438, 27.873486019670963, 38.6151847243309, 50.90843707323074, 61.11394464969635, 64.41877171397209, 72.73095488548279, 80.28119534254074, 81.06937944889069, 81.54074415564537, 86.7507965862751, 84.43760231137276, 80.67740008234978, 65.16176864504814, 66.3091778755188, 43.137740045785904, 38.1562415510416, 49.908364936709404, 61.26791998744011, 60.41448958218098, 70.65389513969421, 38.37466523051262, 46.31156153976917, 51.605163887143135, 70.64080104231834, 79.81032460927963, 75.4626739025116, 72.25148141384125, 68.50497364997864, 58.43548357486725, 49.64084029197693, 44.80396203696728, 33.570712208747864, 21.17251329123974, 14.382342249155045, 8.055991418659687, 3.3790484815835953, 1.9907298032194376, 0.6195970682892948, 0.23387994384393096, 0.06241010734811425, 0.07306834988412447, 0.049820521962828934, 0.04865268951107282, 0.0036815093608311145, 0.0419172206602525, 0.04963243205565959, 0.08653582175611518, 0.06809166341554374, 0.03172692820953671, 0.007604209758937941, 0.018013894514297135, 0.06351278294459917, 0.07711625337833539, 0.10674538614694029, 0.05449411160952877, 0.00604441618634155, 0.020386529504321516, 0.028336549003142864, 0.06029145384673029, 0.020002171222586185, 0.07364821212831885, 0.062484967784257606, 0.035609618498710915, 0.021123315164004453, 0.06695142030366696, 0.10511839805985801, 0.031604499818058684, 0.025496416637906805, 0.03940903981856536, 0.09572488648700528, 0.09377173191751353, 0.016406404502049554, 0.025977374716603663, 0.029072510878904723, 0.017767406861821655, 0.043390120335971005, 0.028878225894004572, 0.02608220307593001, 0.09697014349512756, 0.0006669635945399932, 0.01127786348661175, 0.06736446259310469, 0.08678310536197387, 0.05048682214692235, 0.06846923104603775, 0.012686549762292998, 0.04168180028500501, 0.054471702460432425, 0.06648644994129427, 0.11075224887463264, 0.04837884443986695, 0.01736487894959282, 0.01679108005191665, 0.0363675293920096, 0.03338921284012031, 0.016223800921579823, 0.06207626334798988, 0.05734953963838052, 0.0654749471868854, 0.024802386105875485, 0.05452946752484422, 0.14385938993655145, 0.2716695098206401, 0.1509729347890243, 0.17114194080932066, 0.1277778809890151, 0.1538597111357376, 0.2590986859286204, 0.11662141245324165, 0.1335604433552362, 0.12619630491826683, 0.09800917992834002, 0.19561072782380506, 0.1743347046431154, 0.19486348901409656, 0.13102220924338326, 0.1304060485563241, 0.1729231100762263, 0.09647691214922816, 0.20179027982521802, 0.15479771158425137, 0.17117523355409503, 0.1572409804794006, 0.14029181184014305, 0.21389754343545064, 0.20535684860078618, 0.13789203279884532, 0.07387493082205765, 0.10863720221095718, 0.21022959728725255, 0.22543719765963033, 0.1553302025422454, 0.20325198420323431, 0.15276631980668753, 0.1561588846379891, 0.14101939857937396, 0.33139610022772104, 0.12313211074797437, 0.36112867353949696, 0.18353408522671089, 0.1138413198350463, 0.2226351003628224, 0.3155259252525866, 0.12087393348338082, 0.18264178623212501, 0.14341626840177923, 0.17527408548630774, 0.18859841191442683, 0.24738649721257389, 0.17026467772666365, 0.12699926417553797, 0.11357160110492259, 0.1819543942110613, 0.09436990294489078, 0.11325832572765648, 0.17901713697938249, 0.23517677269410342, 0.07132462938898243, 0.204977061948739, 0.21664052124833688, 0.12319919347646646, 0.19552302081137896, 0.11596904980251566, 0.16298803850077093, 0.1264388090930879, 0.2407658868469298, 0.1933212616131641, 0.24662539508426562, 0.19288919807877392, 0.33442516112700105, 0.5879708903376013, 1.2652291520498693, 5.215420592576265, 10.386774949729443, 16.900548823177814, 20.111648216843605, 27.244558967649937, 41.0272116959095, 51.605908647179604, 72.07809671759605, 80.88350862264633, 93.59669923782349, 95.40287151932716, 104.1197481751442, 100.46614542603493, 107.90629059076309, 101.09874308109283, 91.99780583381653, 87.15839311480522, 79.92509365081787, 50.274114310741425, 38.42006519436836, 53.09555411338806, 66.6550961136818, 70.5273163318634, 79.25195217132568, 47.527766078710556, 63.60085800290108, 72.8837750852108, 88.44441130757332, 102.28645294904709, 91.78988099098206, 85.28343692421913, 80.47690764069557, 65.906832665205, 57.505380883812904, 46.17255359888077, 29.89685084670782, 19.029950760304928, 12.978281490504742, 6.375777153298259, 1.431056410074234, 1.1938713560812175, 0.5225262301973999, 0.19510375190293416, 0.15479291731026024, 0.1902242942014709, 0.11411966232117265, 0.25805718556512147, 0.12014487729175016, 0.14146344037726521, 0.1285998392268084, 0.18321537732845172, 0.16111248289234936, 0.10493973342818208, 0.08643396198749542, 0.1234781371022109, 0.20083145471289754, 0.22365265904227272, 0.16440319537650794, 0.1544146446394734, 0.09052885085111484, 0.11212385652470402, 0.131699018238578, 0.1556370806065388, 0.1763216417748481, 0.1707821773015894, 0.1373428583610803, 0.20688135351520032, 0.10653513571014628, 0.15979995019733906, 0.1957727683475241, 0.16328014782629907, 0.18657064181752503, 0.14531676017213613, 0.21733524568844587, 0.14482343976851553, 0.11999886715784669, 0.1753459995961748, 0.1916348497616127, 0.11122503405204043, 0.1800799072952941, 0.2215984684880823, 0.10945023983367719, 0.1150291642989032, 0.2017789101228118, 0.11939298521610908, 0.23324177105678245, 0.19189586309948936, 0.11453443381469697, 0.14870037470245734, 0.16826027043862268, 0.10732912240200676, 0.1820959959877655, 0.21359246136853471, 0.33891479833982885, 0.18710768956225365, 0.18970965931657702, 0.09567984554450959, 0.12808996892999858, 0.118200094148051, 0.11087356033385731, 0.0758206045429688, 0.19653682422358543, 0.16548362880712375, 0.15353420516476035, 0.1770324114477262], [0.057421591045567766, 0.070740574010415, 0.11631048226263374, 0.0067263807886774885, 0.06047643786587287, 0.021838804896106012, 0.09835658667725511, 0.05844943218107801, 0.012793460773536935, 0.09772229532245547, 0.04680187710619066, 0.11899809585884213, 0.13005064887693152, 0.054303754441207275, 0.03607055899919942, 0.06128337132395245, 0.04680525016738102, 0.04732525077997707, 0.09158836313872598, 0.06024483584042173, 0.1046698068967089, 0.055051412564353086, 0.09297986776800826, 0.04481728516111616, 0.02511437200155342, 0.021953852628939785, 0.020691017853096128, 0.028672686239588074, 0.03875029840855859, 0.05029065767303109, 0.09195449427352287, 0.07608882413478568, 0.004941524439345812, 0.009829949140112149, 0.050316124470555224, 0.16606815916020423, 0.045117806730559096, 0.07270359172252938, 0.0314341472403612, 0.015904786887404043, 0.06710019122692756, 0.004866003491770243, 0.0582531897816807, 0.06739917283994146, 0.0345727862440981, 0.03460881380306091, 0.07224494445836172, 0.08209835752495565, 0.01864257523266133, 0.04916025915008504, 0.04062137886648998, 0.029001248003623914, 0.019760765426326543, 0.013232436485850485, 0.038437702096416615, 0.030895411109668203, 0.07531680501415394, 0.055650904614594765, 0.08712824113899842, 0.014236744118534261, 0.11796098900958896, 0.017477449764555786, 0.03335899629746564, 0.00349212974015245, 0.03948209312511608, 0.013100753512844676, 0.04061339706822764, 0.08099448707071133, 0.030482277907140087, 0.08423380582826212, 0.030210345721570775, 0.1264083365094848, 0.5368673731572926, 0.9995975182391703, 1.6235924349166453, 4.234902206808329, 5.5290552880615, 10.362304262816906, 21.682088747620583, 29.634022749960423, 40.844487100839615, 45.60744032263756, 44.249830171465874, 53.16778063774109, 71.46146580576897, 81.18698313832283, 82.6556271314621, 83.15908491611481, 61.66621081531048, 65.25591999292374, 48.657221272587776, 49.07634638249874, 55.798250287771225, 32.13874764740467, 24.610893689095974, 45.7446813583374, 62.26848229765892, 66.40668824315071, 59.98948998749256, 67.39135980606079, 43.322991505265236, 34.051553606987, 25.09153939783573, 21.86402678489685, 13.575468845665455, 9.102637656033039, 6.572037572041154, 2.8252709470689297, 0.5788627790752798, 0.2305601688567549, 0.09840191705734469, 0.00844257827338879, 0.032579136386630125, 0.06221310053661, 0.19838175881886855, 0.02388643300946569, 0.06359314269502647, 0.07211508345790207, 0.038710148219252005, 0.013307090048328973, 0.01156631309640943, 0.08734390925383195, 0.07593350746901706, 0.09303210012149066, 0.019418778210820165, 0.03203985106665641, 0.039932981235324405, 0.061654408054891974, 0.03554200513463002, 0.07177209248766303, 0.03063652773562353, 0.016629163837933447, 0.03446327864367049, 0.01075024287274573, 0.014073624697630294, 0.035042795789195225, 0.0695827865274623, 0.10407956200651824, 0.07493511104257777, 0.014712404190504458, 0.09797484817681834, 0.055777871239115484, 0.023994400653464254, 0.027913793855987024, 0.03927706369722728, 0.06014321726979688, 0.028045872022630647, 0.03834042880043853, 0.057506945449858904, 0.028149919271527324, 0.03632631793152541, 0.0889798253774643, 0.09786826092749834, 0.009482500645390246, 0.01463105552829802, 0.021720974109484814, 0.047806025177123956, 0.043818554768222384, 0.0063371670057676965, 0.006597094024982653, 0.03870726126478985, 0.07664941280381754, 0.049418240814702585, 0.04368149864603765, 0.08368199676624499, 0.027846785342262592, 0.04130564644583501, 0.15915673080598935, 0.085254778387025, 0.06425965810194612, 0.08937559046898969, 0.02778220921754837, 0.1141748484224081, 0.034622335733729415, 0.006883854321131366, 0.05749901931267232, 0.06149619701318443, 0.01653962001000764, 0.09013094095280394, 0.01303730266954517, 0.03681584967125673, 0.025280537010985427, 0.07427130447467789, 0.03618285707489122, 0.04235073509335052, 0.04452182874956634, 0.013162583691155305, 0.0850971313775517, 0.0306181651467341, 0.030186565454641823, 0.02773323118162807, 0.020193864256725647, 0.04303431989683304, 0.011981650477537187, 0.013561822961491998, 0.031228635416482575, 0.05884427700948436, 0.0442728975758655, 0.11760814973968081, 0.07723436618107371, 0.01875681587989675, 0.061479346550186165, 0.13601337501313537, 0.06379463578923605, 0.0649828439054545, 0.05103176263219211, 0.12622772745089605, 0.057559919951017946, 0.04992416659661103, 0.00850048434585915, 0.03871856788464356, 0.08647184862638824, 0.07633653818629682, 0.052022225499968044, 0.09928936982760206, 0.026637338814907707, 0.013504488342732657, 0.04338356346124783, 0.05921936586673837, 0.005563883914874168, 0.03160692664096132, 0.05623917168122716, 0.032762643531896174, 0.08578436754760332, 0.00674876906487043, 0.04521289811236784, 0.030321140948217362, 0.05523956555407494, 0.02742549779213732, 0.01309169838350499, 0.010352047247579321, 0.05274431292491499, 0.07865045074140653, 0.044347450020723045, 0.01730980417050887, 0.01811657435609959, 0.051120816642651334, 0.07316330767935142, 0.08870791731169447, 0.018151223375753034, 0.06224956967344042, 0.03302911536593456, 0.044128620356786996, 0.0558274207287468, 0.04751136286358815, 0.11547109839739278, 0.24534253345336765, 0.7758754387032241, 2.581039289943874, 4.340387396514416, 7.647889042273164, 10.440794751048088, 18.893536180257797, 25.44950868934393, 39.287858828902245, 49.00680631399155, 58.625454381108284, 66.1168321967125, 71.89364701509476, 74.7388507425785, 85.9923192858696, 101.31185844540596, 96.01932764053345, 91.54077395796776, 72.1164670586586, 68.61122354865074, 53.11603881418705, 61.21628075838089, 62.92878046631813, 49.13531921803951, 47.14392967522144, 58.29064294695854, 70.10322868824005, 70.64590036869049, 71.21942639350891, 82.5689309835434, 61.5176197886467, 52.95697934925556, 40.61320871114731, 31.670743860304356, 23.71260479092598, 18.449959382414818, 11.606946475803852, 6.557288663461804, 2.938398951664567, 0.9798626240808517, 0.22720108972862363, 0.04496227855270263, 0.09351541637443006, 0.014374156471603783, 0.12670482450630516, 0.04664179214159958, 0.03987722739111632, 0.03689010154630523, 0.06756710601621307, 0.08241313204052858, 0.010557886544120265, 0.10121468643774278, 0.07282288454007357, 0.06901203043526039, 0.022509051450469997, 0.04424338236276526, 0.06181812954309862, 0.12429658498149365, 0.0169441776961321, 0.01834006470744498, 0.027089089671790134, 0.019167778300470673, 0.02796141561702825, 0.06929345283424482, 0.0856176737579517, 0.03362854062288534, 0.11919058670173399, 0.050978621147805825, 0.04407845117384568, 0.06896100778249092, 0.016653602760925423, 0.06148174739792012, 0.021435260241560172, 0.06650770505075343, 0.019111328692815732, 0.06764704274246469, 0.04065123917825986, 0.032293698968715034, 0.049712858599377796, 0.015267139169736765, 0.042828277437365614, 0.05494709257618524, 0.06371630952344276, 0.01152525192082976, 0.014285397464846028, 0.03478352278762031, 0.0550063716218574, 0.03307035280158743, 0.03484752931399271, 0.05194499019125942, 0.049175896201631986, 0.05569337401539087, 0.06107685017923359, 0.043522630803636275, 0.01618222209799569, 0.07925972429802641, 0.009946480240614619, 0.0604758552799467, 0.019661512451421004, 0.11685299221426249, 0.2014481497462839, 0.07229739203467034, 0.12369666248559952, 0.03044510001927847, 0.04258316090272274, 0.09886593747069128, 0.20630982558941469, 0.22203783475561067, 0.21736377384513617, 0.14178363257087767, 0.12118558355723508, 0.08464163824100979, 0.1928589036106132, 0.14982040913309902, 0.13867780391592532, 0.14390927710337564, 0.22075391927501187, 0.15556662110611796, 0.16267094848444685, 0.14246864971937612, 0.1215180657163728, 0.19105110608506948, 0.16356943699065596, 0.21128451568074524, 0.15032029012218118, 0.13845609471900389, 0.2597409998998046, 0.13239491527201608, 0.21083265164634213, 0.13688516104593873, 0.14948705123970285, 0.11069865839090198, 0.24907173647079617, 0.17053918330930173, 0.11155913409311324, 0.13194695493439212, 0.2733916783472523, 0.1865696324966848, 0.1627748046303168, 0.1557748974300921, 0.126527406682726, 0.2553690376225859, 0.1654854544904083, 0.2408521986217238, 0.14803437137743458, 0.15401885728351772, 0.1814258366357535, 0.13062244397588074, 0.15005802997620776, 0.11898383178049698, 0.1077302532212343, 0.12662612716667354, 0.21351682167733088, 0.17880661936942488, 0.09672685264376923, 0.16896277258638293, 0.1547049728105776, 0.15171064442256466, 0.09108954342082143, 0.1867757417494431, 0.09895112118101679, 0.17732548556523398, 0.17807138850912452, 0.17508632212411612, 0.16422625252744183, 0.09280495840357617, 0.15738691639853641, 0.22667132987407967, 0.20438435312826186, 0.1548701897263527, 0.20700287277577445, 0.13684302190085873, 0.1766352288541384, 0.1375974595430307, 0.18000548472627997, 0.2009285127860494, 0.1622837848844938, 0.34252267505507916, 1.2666274770163, 2.3608517926186323, 4.157475661486387, 7.519288267940283, 15.361971482634544, 22.719877660274506, 36.03431761264801, 48.73406834900379, 63.20574000477791, 76.68364718556404, 87.02723935246468, 87.94518649578094, 104.46305975317955, 117.22227349877357, 116.59384042024612, 112.21111759543419, 96.17248982191086, 98.09520944952965, 81.2865985929966, 85.33593490719795, 83.90379175543785, 60.195108354091644, 57.74061866104603, 79.08879652619362, 102.26456612348557, 97.86408305168152, 93.79941076040268, 91.3210241496563, 58.9142806828022, 53.541372790932655, 36.45658515393734, 29.014674983918667, 18.82756222039461, 12.63709969818592, 9.64513834565878, 4.491800246760249, 1.4936150657013059, 0.4447998869000003, 0.2083367941668257, 0.11054990231059492, 0.11919585595023818, 0.17834243568358943, 0.39254013332538307, 0.17555166356032714, 0.1724953658413142, 0.14065086288610473, 0.18939041707199067, 0.15890460839727893, 0.1135838613845408, 0.242386425670702, 0.13098186609568074, 0.24840267549734563, 0.08974859389127232, 0.17249967029783875, 0.14469623565673828, 0.23984039900824428, 0.06691119589959271, 0.16997020837152377, 0.17021992622176185, 0.14781373087316751, 0.09295855328673497, 0.1488911808701232, 0.3346404433250427, 0.12191065441584215, 0.26643315330147743, 0.1879056912730448, 0.17486563709098846, 0.09287065331591293, 0.17601099360035732, 0.1897428630036302, 0.14238644944271073, 0.09837356701609679, 0.10585797048406675, 0.14649981778347865, 0.12243510791449808, 0.20305970858316869, 0.14043949922779575, 0.17232047131983563, 0.09172991296509281, 0.29214655165560544, 0.19228042918257415, 0.07969358382979408, 0.12023668838082813, 0.14038650988368317, 0.12986249959794804, 0.09943426673999056, 0.09314394919783808, 0.09571091926773079, 0.07899952732259408, 0.1430163547047414, 0.14604360476369038, 0.14446781744481996, 0.1601085500442423, 0.1708514493657276, 0.13403454213403165, 0.1588795831776224, 0.12704000808298588, 0.29286842385772616, 0.4012476035859436, 0.1444520690711215, 0.15661083773011342, 0.10775247312267311, 0.08191256085410714, 0.1706670256680809], [0.14156892924802378, 0.042643185806809925, 0.017681694371276535, 0.020355748929432593, 0.036859224492218345, 0.06239547219593078, 0.016299839517159853, 0.12078384417691268, 0.0625568967370782, 0.039795453849365, 0.036014196593896486, 0.07512957599828951, 0.05996648222208023, 0.06402807091944851, 0.023290686949621886, 0.05510843919182662, 0.017038372934621293, 0.07541671293438412, 0.05146405252162367, 0.02005791578994831, 0.014364291473611956, 0.0640223192749545, 0.025507626778562553, 0.0863440879038535, 0.13167906930902973, 0.06426683466997929, 0.051662094629136845, 0.024201389351219404, 0.018869631603593007, 0.027839259964821395, 0.025061299165827222, 0.04509708596742712, 0.045475251026800834, 0.05305192942614667, 0.033771834496292286, 0.017103130885516293, 0.03099172517977422, 0.019671076879603788, 0.04230201680911705, 0.04986343665223103, 0.07425921488902532, 0.0053498322904488305, 0.09970092040020972, 0.058820862250286154, 0.034511481135268696, 0.03493967065878678, 0.01914197753649205, 0.057500807888573036, 0.04253167069691699, 0.014289688006101642, 0.0381445686070947, 0.04846013187489007, 0.033982997774728574, 0.05545799074752722, 0.028707802812277805, 0.03395643630938139, 0.07738217231235467, 0.056330600564251654, 0.00872061276822933, 0.019704625665326603, 0.06072692383895628, 0.030789055781497154, 0.057981192658189684, 0.026122805975319352, 0.04574812759528868, 0.051473811763571575, 0.031945512964739464, 0.05261274869553745, 0.022636613648501225, 0.0625459649018012, 0.013777021667920053, 0.03592477150959894, 0.05920391435211059, 0.1715554209658876, 0.09552068455377594, 0.21935945347649977, 1.0869959159754217, 1.0075584473088384, 2.3253992199897766, 4.838126013055444, 10.687943939119577, 15.25092339143157, 12.884156741201878, 22.06517469137907, 20.848048701882362, 13.165990468114614, 52.98244558274746, 61.24832443892956, 67.89394363760948, 63.149613216519356, 71.60359337925911, 66.77528366446495, 68.0460798740387, 67.77425765991211, 67.2168579697609, 66.61966681480408, 68.32127630710602, 51.14888437092304, 31.989430859684944, 15.935145076364279, 6.6431825794279575, 2.410722691565752, 1.2337496224790812, 1.2736769299954176, 1.1574765527620912, 0.46872120641637594, 0.1748087292071432, 0.08258211164502427, 0.056759268773021176, 0.18392222846159711, 0.0799024835578166, 0.08067515576840378, 0.03916152614692692, 0.028169369106763043, 0.027549453152460046, 0.03601348042138852, 0.07231902563944459, 0.02546129635447869, 0.014044135459698737, 0.07259292266098782, 0.05643625641823746, 0.05178803337912541, 0.05234025062236469, 0.03981081630627159, 0.004485966828724486, 0.054675017527188174, 0.04017286191810854, 0.014760498143004952, 0.04034635749121662, 0.05966227960016113, 0.08257118723122403, 0.05478913757542614, 0.048237272349069826, 0.06186638398503419, 0.0476531279127812, 0.053482527218875475, 0.016940272143983748, 0.08863201044732705, 0.036985697588534094, 0.04515845786954742, 0.04691532551078126, 0.08474989532260224, 0.0483777720364742, 0.10368459101300687, 0.0591153390269028, 0.11994762186077423, 0.00797407436039066, 0.06448068452300504, 0.043336756207281724, 0.02342957246582955, 0.09189401665935293, 0.014913396335032303, 0.014720842409587931, 0.03784883760090452, 0.03709105287271086, 0.05617246002657339, 0.09129433907219209, 0.056653048886801116, 0.054379368157242425, 0.04296540777431801, 0.040490838800906204, 0.07117511631804518, 0.03534972209308762, 0.06311579330940731, 0.033706570029607974, 0.039172610122477636, 0.0426298011734616, 0.010931308352155611, 0.049307408480672166, 0.06907158036483452, 0.04428427841048688, 0.047113334221648984, 0.1730443027918227, 0.13982115662656724, 0.039261534257093444, 0.03275646515248809, 0.06348880415316671, 0.017632656963542104, 0.012976228554180125, 0.041314040136057884, 0.02735241851041792, 0.04634341908968054, 0.07821568578947335, 0.06142266131064389, 0.02020218929828843, 0.02147373503248673, 0.09439441608265042, 0.0335190404439345, 0.044060936488676816, 0.08900183005607687, 0.044543043040903285, 0.02782250969175948, 0.04347906302427873, 0.01774280652171001, 0.01358059280391899, 0.07598839671118185, 0.028802951710531488, 0.03977858112193644, 0.01613752439880045, 0.08103553525870666, 0.07042212586384267, 0.10932694684015587, 0.018640962916833814, 0.020245317355147563, 0.039409318123944104, 0.0087799994253146, 0.0114695370393747, 0.025370874936925247, 0.06216594447323587, 0.05972572209429927, 0.018170791954617016, 0.06232020357856527, 0.026320927863707766, 0.04265340889105573, 0.053562330358545296, 0.056371006794506684, 0.06838388406322338, 0.03187663423886988, 0.07522587708081119, 0.06930119343451224, 0.06986529246205464, 0.015025925404188456, 0.01692969282885315, 0.08422080340096727, 0.04810739650565665, 0.01373170056467643, 0.05023272562539205, 0.07944327226141468, 0.0860640087921638, 0.051194010957260616, 0.054409157964983024, 0.005271593227007543, 0.03461349675490055, 0.103705719957361, 0.06541449183714576, 0.11766075316700153, 0.03262976199039258, 0.08817406080197543, 0.04553946164378431, 0.017722792654240038, 0.043470565433381125, 0.008652224787510931, 0.021240906607999932, 0.031166562184807844, 0.05037978589825798, 0.023455996633856557, 0.05658208843669854, 0.04648621201340575, 0.06604581460123882, 0.2853930968558416, 0.5828474590089172, 0.9528173971921206, 2.5777230178937316, 3.1361712142825127, 9.489530995488167, 12.538721077144146, 20.893190279603004, 27.14659832417965, 25.06423406302929, 32.83358596265316, 31.58455688506365, 26.816534735262394, 62.05965310335159, 80.76091200113297, 85.27323827147484, 77.5237289071083, 81.18705913424492, 79.43066418170929, 83.3639395236969, 76.27918168902397, 79.45069670677185, 81.56227380037308, 80.13222813606262, 66.10129863023758, 46.22190535068512, 28.25497604906559, 14.921903796494007, 6.934890551492572, 5.3310849610716105, 5.224498780444264, 2.2659074747934937, 1.5824565547518432, 0.6245549710001796, 0.34361021826043725, 0.11024004081264138, 0.10558579524513334, 0.07235760989715345, 0.025329895397590008, 0.017148529914265964, 0.10587846118141897, 0.03879512041748967, 0.0544118853576947, 0.06400034428224899, 0.06977083190577105, 0.036553359459503554, 0.056109911820385605, 0.023882191635493655, 0.038237162661971524, 0.05428559408755973, 0.03559317992767319, 0.03743936133105308, 0.05170536183868535, 0.014746397337148665, 0.01890504874609178, 0.04217269386572298, 0.014779760585952317, 0.05366456491174176, 0.005520590266314684, 0.009563882704242133, 0.04925242275930941, 0.03749769784917589, 0.02151056225557113, 0.0328044895286439, 0.056518230339861475, 0.07539747646660544, 0.08838527603074908, 0.05980881665891502, 0.058061099698534235, 0.13600672536995262, 0.0025913804665833595, 0.040298140156664886, 0.05473852310387883, 0.03091700389632024, 0.04871863675361965, 0.036190668179187924, 0.05117633299960289, 0.041440594868618064, 0.026154172846872825, 0.037644876865670085, 0.06716978241456673, 0.059890586489927955, 0.049338196477037854, 0.13125309138558805, 0.03224835003493354, 0.1010181063611526, 0.02724764395679813, 0.027546408491616603, 0.022742397522961255, 0.035191280985600315, 0.11383814344299026, 0.038516748245456256, 0.010528419570619008, 0.018131623255612794, 0.04573152575176209, 0.0019795149592027883, 0.02437077713693725, 0.03743509769265074, 0.058492302341619506, 0.21840794594027102, 0.1397744903806597, 0.029529683124565054, 0.05442705856694374, 0.26923173281829804, 0.12781427591107786, 0.10085158326546662, 0.15711097104940563, 0.1350425716373138, 0.1609799501602538, 0.3315368707990274, 0.20411194040207192, 0.16287723585264757, 0.26714353705756366, 0.20958976208930835, 0.18834256392437965, 0.10353409830713645, 0.184474712878, 0.1200677384622395, 0.16964517737505957, 0.17007814632961527, 0.17648221284616739, 0.18534526694566011, 0.16524504317203537, 0.17978656600462273, 0.19495493645081297, 0.16964341106358916, 0.17836422513937578, 0.24566278501879424, 0.22144286980619654, 0.08642873726785183, 0.17518093110993505, 0.11455274259787984, 0.11272868461674079, 0.11763198010157794, 0.15404297708300874, 0.2438151786918752, 0.15767663600854576, 0.14243878569686785, 0.21386499283835292, 0.12080700660590082, 0.14962887566071004, 0.2448869141517207, 0.19057883298955858, 0.133842934446875, 0.09122073286562227, 0.24294075061334297, 0.12029974124743603, 0.14601003000279889, 0.11566134795430116, 0.07581940226373263, 0.15378172625787556, 0.16203728795517236, 0.08751868503168225, 0.2215344805154018, 0.21075794706121087, 0.1917290431447327, 0.16043010778957978, 0.16679761611158028, 0.15356809162767604, 0.18488077155780047, 0.17367662745527923, 0.179392114514485, 0.21088187088025734, 0.18584424251457676, 0.2082893264014274, 0.12627794116269797, 0.13175208179745823, 0.16009630460757762, 0.16127982235047966, 0.0939107287558727, 0.1373545842943713, 0.1326123348553665, 0.21971932088490576, 0.11713773201336153, 0.08385956301935948, 0.1890364571590908, 0.24848539527738467, 0.41174652928020805, 0.4328762157820165, 2.325000478886068, 2.5547708244994283, 6.604702994227409, 9.019371774047613, 16.576559208333492, 24.31160654872656, 24.980298466980457, 34.40805807709694, 33.18600185215473, 33.76801282167435, 71.4850701391697, 104.31198745965958, 108.71461361646652, 104.044459015131, 109.19922441244125, 102.58998826146126, 106.56926393508911, 100.43138489127159, 103.40863913297653, 101.01824060082436, 102.37868919968605, 83.5791751742363, 49.49304722249508, 20.94614613801241, 10.446218959987164, 3.8956236373633146, 3.5126523999497294, 3.1697371881455183, 1.3321096007712185, 1.1450250959023833, 0.30351788678672165, 0.20680737623479217, 0.23126647080061957, 0.45960700954310596, 0.15181191789451987, 0.17515600979095325, 0.09461288951570168, 0.15262192755471915, 0.17780005931854248, 0.20205107051879168, 0.1421169756213203, 0.2071442815940827, 0.21124169375980273, 0.15954901522491127, 0.08321992820128798, 0.11817742153652944, 0.19810265192063525, 0.22394344734493643, 0.11523770779604092, 0.12176163858384825, 0.15738563990453258, 0.0739162164973095, 0.1581381628056988, 0.13191042642574757, 0.2084722658037208, 0.061083937689545564, 0.11672522407025099, 0.31263926764950156, 0.19682269950862974, 0.25779253570362926, 0.1566746921162121, 0.17623433552216738, 0.17040164850186557, 0.2042082414845936, 0.17384752922225744, 0.14128646784229204, 0.31419620441738516, 0.20658557798014954, 0.2241625590249896, 0.28697458386886865, 0.07988996352651156, 0.10128409950993955, 0.11134527681861073, 0.14730230206623673, 0.15968809369951487, 0.1402493313071318, 0.15129462612094358, 0.1516098013962619, 0.08200958924135193, 0.14727355126524344, 0.157290734059643, 0.19544879120076075, 0.12244651472428814, 0.27337573701515794, 0.09847127817920409, 0.14622221002355218, 0.13466162723489106, 0.1942053672973998, 0.1289158160216175, 0.07888420499511994, 0.18296306196134537, 0.11884415958775207, 0.11587617002078332, 0.18604061478981748, 0.08478665389702655, 0.14062634232686833, 0.2652214339468628, 0.23807009478332475, 0.1400462945457548, 0.11928785257623531], [0.03283274680143222, 0.04667178603995126, 0.01675795800110791, 0.016079343731689733, 0.03605016849178355, 0.08158206765074283, 0.03816812808508985, 0.01637900626519695, 0.023258023175003473, 0.04662799561629072, 0.08127376466291025, 0.09764197267941199, 0.04282643320038915, 0.07520216546254233, 0.03408103177207522, 0.019527857220964506, 0.030356788156495895, 0.03558708318450954, 0.02735645764914807, 0.053650590270990506, 0.034117059331038035, 0.054981617286102846, 0.022522152212332003, 0.007000880341365701, 0.024664686170581263, 0.051419404917396605, 0.03553275055310223, 0.04231045502820052, 0.04748630424728617, 0.037369480705820024, 0.06966820772504434, 0.05514791402674746, 0.04858983331359923, 0.06274027400650084, 0.015806656410859432, 0.008399063372053206, 0.033650489640422165, 0.09361678632558323, 0.04939808408380486, 0.042132469461648725, 0.02570779328380013, 0.02402364683803171, 0.042757380069815554, 0.08406777255004272, 0.02973292768729152, 0.0642243838228751, 0.07491249780287035, 0.019693166905199178, 0.07513033298891969, 0.0757385823817458, 0.06420677265850827, 0.059232795028947294, 0.07555110845714808, 0.09353126864880323, 0.04500783899857197, 0.036665627849288285, 0.06886158225825056, 0.07681422153837048, 0.0221789311763132, 0.03051465224416461, 0.05306846447638236, 0.034189114448963664, 0.03449830801400822, 0.05086477569420822, 0.0322900995524833, 0.0379691286070738, 0.031691464682808146, 0.04751845779537689, 0.041194981095031835, 0.012732460872939555, 0.06117579701822251, 0.05134834427735768, 0.018260001816088334, 0.020643505558837205, 0.07128672790713608, 0.023412109730998054, 0.07374178210739046, 0.12160208425484598, 0.22665325115667656, 0.041624046352808364, 0.20642016810597852, 0.3255034179892391, 0.059184392157476395, 0.5424329463858157, 0.0880088513076771, 0.29122913838364184, 0.6297081476077437, 6.220793444663286, 14.541906137019396, 17.07890935242176, 35.70689298212528, 54.70307305455208, 74.90867882966995, 76.99754074215889, 50.65281338989735, 49.01133947074413, 32.36749157309532, 14.995613191276789, 2.2933085169643164, 0.27378875704016536, 0.05776844118372537, 0.048706732704886235, 0.10525928737479262, 0.06152499234303832, 0.06007596013660077, 0.024225178894994315, 0.03702732836245559, 0.07731522317044437, 0.0856254440441262, 0.057934637734433636, 0.011430444410507334, 0.02805375919706421, 0.016747182016843, 0.01769315127603477, 0.03415221857721917, 0.019812684222415555, 0.05163635694771074, 0.09723393246531487, 0.0025198184130204027, 0.042459893884370103, 0.03793536830926314, 0.021724326761614066, 0.01734338449750794, 0.03554267677827738, 0.013790928587695817, 0.05855794530361891, 0.05407976314018015, 0.03827808839560021, 0.019668074892251752, 0.02423981590254698, 0.033430235052946955, 0.007233462929434609, 0.06274923172895797, 0.036133188841631636, 0.0223895601084223, 0.033123234534286894, 0.027139182784594595, 0.014009112583153183, 0.03900993506249506, 0.05257024589809589, 0.0656475336290896, 0.055556069273734465, 0.03306917649751995, 0.04308402152673807, 0.07736173356533982, 0.044535721754073165, 0.031698611564934254, 0.006837222399553866, 0.04118336277315393, 0.03259833945776336, 0.025945690576918423, 0.041098271831288, 0.018501949380151927, 0.013828970149916131, 0.06868987897178158, 0.043254630145384, 0.02545052037021378, 0.0630577647825703, 0.06424471124773845, 0.026245761291647796, 0.06089101640100125, 0.048951233256957494, 0.02989298853208311, 0.051710156112676486, 0.05871046036190819, 0.06588676493265666, 0.048227717197733, 0.018857866707548965, 0.001222679600232368, 0.0474406621651724, 0.03552902126102708, 0.02147355135093676, 0.007971485192683758, 0.12199326287372969, 0.07276281510712579, 0.09627547100535594, 0.0574309458170319, 0.034303308711969294, 0.061230151914060116, 0.029779681135551073, 0.06101591614424251, 0.1299879077123478, 0.04393880495626945, 0.03912894586392213, 0.0782922976941336, 0.013917479609517613, 0.11383009114069864, 0.06173007743200287, 0.09334848509752192, 0.029331179030123167, 0.028201676650496665, 0.0747715268516913, 0.12115734483813867, 0.0032283704558722093, 0.013827153743477538, 0.08895360530004837, 0.04803343406820204, 0.07707638520514593, 0.021242392758722417, 0.03734650010301266, 0.004823080453206785, 0.04949539448716678, 0.056897011381806806, 0.14079549262532964, 0.059285940224071965, 0.05921378491620999, 0.04795885193743743, 0.035741360843530856, 0.030126351302897092, 0.05580740129516926, 0.06224936558282934, 0.0964179856237024, 0.0443546748283552, 0.04527021788817365, 0.03034716435649898, 0.0671520821924787, 0.014489206987491343, 0.032999102913890965, 0.055175499655888416, 0.054025089120841585, 0.024788893861114047, 0.04295889913919382, 0.03988755066529848, 0.023468752297048923, 0.06919478430063464, 0.03703049733303487, 0.02515438860427821, 0.11945912541705184, 0.04513095016591251, 0.02899144237744622, 0.06047814109479077, 0.03650316059065517, 0.030809056661382783, 0.03049361977900844, 0.027337440114933997, 0.015271836964529939, 0.08079320177785121, 0.05697866617992986, 0.033612332117627375, 0.060270744215813465, 0.03249252404202707, 0.0414261118567083, 0.025333910416520666, 0.08605226801591925, 0.0633391723386012, 0.015350158591900254, 0.06974830030230805, 0.03491357674647588, 0.021401216072263196, 0.0035564681456889957, 0.04317185470426921, 0.06480590847786516, 0.28600489371456206, 0.16242378362221643, 0.39356809691525996, 0.217952742241323, 0.5279373179655522, 1.1160862050019205, 0.9468808688689023, 1.6740967123769224, 0.9040207124780864, 0.5861652153544128, 1.215466191060841, 9.065381605178118, 22.2928698733449, 32.14217886328697, 56.40953488647938, 72.57810428738594, 95.1784859597683, 92.94324830174446, 63.87085631489754, 62.29626640677452, 38.24268311262131, 21.167191676795483, 4.416230376809835, 0.5263108864892274, 0.1434683523257263, 0.11580032252823003, 0.16651101352181286, 0.07534075411967933, 0.06198223323735874, 0.050811489491024986, 0.02011911514273379, 0.07601357778185047, 0.038551621764781885, 0.022009994245308917, 0.0360385835665511, 0.05452100704133045, 0.042120969883399084, 0.0226824097262579, 0.01391228364809649, 0.02021445514401421, 0.0064974138513207436, 0.07749802156467922, 0.03348139871377498, 0.01382612865199917, 0.08890992248780094, 0.02141635588486679, 0.01706514034594875, 0.07258305209688842, 0.02142044140782673, 0.014037021046533482, 0.010952051379717886, 0.00659875458040915, 0.027275893808109686, 0.09006914973724633, 0.021453715598909184, 0.012722881601803238, 0.047665135862189345, 0.03233665818697773, 0.09896527393721044, 0.02813206876453478, 0.01968279539141804, 0.11784481321228668, 0.015153273307078052, 0.03135943894449156, 0.00825369797894382, 0.03772901414777152, 0.017529006763652433, 0.03200354891305324, 0.02677948050404666, 0.025242151277780067, 0.07348522907705046, 0.051716408706852235, 0.04169260966591537, 0.06669802140095271, 0.0932473452121485, 0.04590688782627694, 0.0389408299815841, 0.044425909873098135, 0.05655980174196884, 0.041440791537752375, 0.034706361693679355, 0.02516866381483851, 0.04313415731303394, 0.060261426551733166, 0.010900902561843395, 0.0069720692408736795, 0.03753007775230799, 0.01198746149384533, 0.08361965636140667, 0.08102095205686055, 0.04332598022301681, 0.03386174197657965, 0.010684580429369817, 0.10283339957823046, 0.057164247627952136, 0.024137353138939943, 0.053191445767879486, 0.05875012815522496, 0.019538985725375824, 0.06334695004625246, 0.15436791902175173, 0.20733300974825397, 0.11701581199304201, 0.210748536628671, 0.20173300086753443, 0.20663417381001636, 0.14580390590708703, 0.08073876524576917, 0.1829170636483468, 0.09940693344105966, 0.2986916113877669, 0.14045644988073036, 0.2193198524764739, 0.13358346477616578, 0.0928790915349964, 0.1729944156249985, 0.1279520185198635, 0.1361203333362937, 0.2544937189668417, 0.13020848884480074, 0.19362085178727284, 0.16374088794691488, 0.18194860545918345, 0.11807179165771231, 0.06918495084391907, 0.1970697010983713, 0.16292780579533428, 0.16986296803224832, 0.2496000862447545, 0.1196268062631134, 0.15694331988925114, 0.13526956492569298, 0.11935555128729902, 0.16108111973153427, 0.1667450720560737, 0.20472534029977396, 0.2076414760085754, 0.15787962824106216, 0.10408613001345657, 0.17995881848037243, 0.12446831053239293, 0.179476838093251, 0.10612057943944819, 0.15842535911360756, 0.17678589967545122, 0.2058112359372899, 0.18168882408645004, 0.140461926930584, 0.14773727481951937, 0.11669730447465554, 0.21138537355000153, 0.13143233489245176, 0.131190647080075, 0.1441887699184008, 0.13671277498360723, 0.07377917892881669, 0.09272757466533221, 0.17467247089371085, 0.07244297914439812, 0.07086171477567405, 0.18268506828462705, 0.10909141885349527, 0.1548094375175424, 0.10752039612270892, 0.11170350408065133, 0.11336971467244439, 0.060182335873832926, 0.1461533980909735, 0.16119698382681236, 0.1954149641096592, 0.10693053714931011, 0.17940679419552907, 0.09480224849539809, 0.09569383502821438, 0.23520585004007444, 0.201225342170801, 0.26472876663319767, 0.21853443759027869, 0.2487903882865794, 0.12527169281383976, 0.224492191337049, 0.6045096216257662, 0.8499442704487592, 0.9603633172810078, 0.526156994746998, 0.3127236646832898, 1.5811875415965915, 11.629819348454475, 35.4048053920269, 58.04205648601055, 90.70243254303932, 101.52791485190392, 128.50323736667633, 116.79623275995255, 86.46843373775482, 85.4363939166069, 46.29397228360176, 21.868320554494858, 3.0103870388120413, 0.36465883255004883, 0.24406698939856142, 0.1774050437961705, 0.2544712764210999, 0.14080721855862066, 0.14751700538909063, 0.1269453248823993, 0.19069281202973798, 0.2060281953890808, 0.1424481812864542, 0.170816479367204, 0.15508398762904108, 0.2866891835583374, 0.09025273480801843, 0.11502258887048811, 0.1508242974523455, 0.1277588671655394, 0.09448505457839929, 0.1929811353329569, 0.09627474370063283, 0.14688270661281422, 0.17440768744563684, 0.1439068280160427, 0.058232788142049685, 0.19621544459369034, 0.0917476206086576, 0.2780201268615201, 0.12440755090210587, 0.10522761251195334, 0.11439485810115002, 0.12185782092274167, 0.09095782705117017, 0.1202425365045201, 0.12338081927737221, 0.12765769759425893, 0.20606644568033516, 0.13448977551888674, 0.07047694089123979, 0.19529291050275788, 0.11661596508929506, 0.14373044919921085, 0.11984733544522896, 0.09140238835243508, 0.15611916489433497, 0.21561074681812897, 0.22515262855449691, 0.09491034230450168, 0.24540505197364837, 0.1009996268840041, 0.10066677365102805, 0.20851853128988296, 0.28697004192508757, 0.24648002319736406, 0.14154575939755887, 0.10688933311030269, 0.1705840535578318, 0.14677993400255218, 0.0653339020209387, 0.2433068075333722, 0.15431196108693257, 0.11914363101823255, 0.09947549304342829, 0.09798802871955559, 0.12270553910639137, 0.10947390692308545, 0.20714917976874858, 0.18554907554062083, 0.20628592843422666, 0.10205052283708937, 0.11788308576797135, 0.18801428232109174, 0.11484077011118643, 0.17556476988829672, 0.12934277357999235, 0.19011867174413055, 0.1020009844796732, 0.18843505036784336], [0.01685318668023683, 0.024823229323374107, 0.03760387691727374, 0.08117616482195444, 0.01582243447046494, 0.03600048541557044, 0.03608328683185391, 0.018765762470138725, 0.09024948420119472, 0.01013932638670667, 0.02970534947962733, 0.03762774067581631, 0.022790856055507902, 0.11063896003179252, 0.04702300742792431, 0.032900044752750546, 0.027856346059706993, 0.045388887301669456, 0.05769684248662088, 0.013939752388978377, 0.041663743832032196, 0.0073668551613081945, 0.09151022983132862, 0.023320691980188712, 0.03645854267233517, 0.06528325786348432, 0.04327726936026011, 0.011408558475523023, 0.0363153860962484, 0.022716149615007453, 0.08589951918111183, 0.04110263937036507, 0.04902055727143306, 0.057722966084838845, 0.10526331723667681, 0.03132189369353, 0.04605071975674946, 0.007082159427227452, 0.030714887398062274, 0.032652122899889946, 0.019588000868679956, 0.008975352175184526, 0.0378836554591544, 0.04726573795778677, 0.00957317439315375, 0.030618649398093112, 0.051831385935656726, 0.04302184439438861, 0.02391567362792557, 0.03541254118317738, 0.04036721926240716, 0.008588442760810722, 0.049226525516132824, 0.126353669911623, 0.042599280350259505, 0.08139604833559133, 0.053128006984479725, 0.0750347666325979, 0.05757664795964956, 0.04282732377760112, 0.041443682202952914, 0.007233136384456884, 0.02927341582108056, 0.07366036850726232, 0.07938150331028737, 0.03943000549043063, 0.017414862595614977, 0.07639546471182257, 0.010594401137495879, 0.0313218491646694, 0.05421276713605039, 0.024157417101378087, 0.04684687351982575, 0.004119773075217381, 0.025381600826221984, 0.047214080768753774, 0.02329886170628015, 0.09856930846581236, 0.011018864151992602, 0.06061760548618622, 0.05951512655883562, 0.028546261382871307, 0.05609410778561141, 0.04856862644373905, 0.05389165467931889, 0.1726748765213415, 0.164155570382718, 0.024278710006910842, 0.04188035447441507, 1.354379968252033, 4.3352823704481125, 7.3459757678210735, 10.18522521480918, 8.656501695513725, 8.05353770032525, 2.026395401917398, 1.2201930186711252, 0.043568877736106515, 0.06073976299376227, 0.06491710446425714, 0.02283945188537473, 0.04076888442796189, 0.0591184597578831, 0.019616894533101004, 0.04401453370519448, 0.03906059035216458, 0.03531838119670283, 0.041739791704458185, 0.07186925446148962, 0.06237964960746467, 0.02872939374356065, 0.038994802671368234, 0.07587585743749514, 0.05647058816975914, 0.07630345324287191, 0.06611074510146864, 0.03701479348819703, 0.0352922279125778, 0.04231625120155513, 0.051256599981570616, 0.12025594711303711, 0.05168195450096391, 0.08722997474251315, 0.02685218129045097, 0.02336422636290081, 0.06363859181874432, 0.038048215574235655, 0.04648907299269922, 0.013154415428289212, 0.02020545845880406, 0.02788395395327825, 0.026767841773107648, 0.05021447992476169, 0.04159423799137585, 0.004998117374270805, 0.04625169334758539, 0.019631054710771423, 0.05505366869329009, 0.028047662453900557, 0.03187247450114228, 0.012142661271354882, 0.06596593724680133, 0.042227338199154474, 0.043386917968746275, 0.052138371611363254, 0.04491791296459269, 0.02237517914181808, 0.09141901246039197, 0.021573847043327987, 0.012022964911011513, 0.029457958262355532, 0.012746767624776112, 0.053611237890436314, 0.012263862336112652, 0.023117892706068233, 0.02684183018573094, 0.06465967569965869, 0.024304232465510722, 0.08059069936280139, 0.0336063281429233, 0.04350104172772262, 0.017718050330586266, 0.059882920104428194, 0.015255905836966122, 0.0280922043020837, 0.04152795678237453, 0.025833611434791237, 0.06943492844584398, 0.05244071886409074, 0.02206781311542727, 0.02933370604296215, 0.01610733012057608, 0.022106647847977, 0.023162651632446796, 0.0688204079051502, 0.09266812121495605, 0.11047458174289204, 0.023083308624336496, 0.018360946887696628, 0.0332859689660836, 0.04947444365825504, 0.08533742395229638, 0.05630215775454417, 0.022809335532656405, 0.0515044364874484, 0.044485675025498495, 0.0346272969909478, 0.019850492935802322, 0.04840593654080294, 0.014792732399655506, 0.027612903068074957, 0.027600234607234597, 0.028529615010484122, 0.05499364007846452, 0.008855657670210348, 0.03122126217931509, 0.015336927954194834, 0.032829021220095456, 0.05179942163522355, 0.008745552640903043, 0.04406124076922424, 0.044658109327428974, 0.014491631955024786, 0.043782775828731246, 0.041240229838876985, 0.10288585457601584, 0.06788536862586625, 0.02473173550242791, 0.049653928363113664, 0.0339658838493051, 0.06452799643739127, 0.03840577861410566, 0.03820278638158925, 0.025418806544621475, 0.03165317728416994, 0.017442928765376564, 0.03901603922713548, 0.02718123472732259, 0.021131892535777297, 0.04880937915004324, 0.045012239934294485, 0.0396920095954556, 0.018785355168802198, 0.031920988694764674, 0.0353096015896881, 0.05855226787389256, 0.0017140353998001956, 0.021772119216620922, 0.0328980409540236, 0.11608737782808021, 0.06494307963293977, 0.0814837850339245, 0.010341076449549291, 0.030047746731725056, 0.05442454639705829, 0.032789086253615096, 0.07398059038678184, 0.039411225443473086, 0.08668072608998045, 0.07357800495810807, 0.028502053501142655, 0.028268841015233193, 0.09004051025840454, 0.14922737376764417, 0.028122083167545497, 0.02724522270000307, 0.043545147564145736, 0.06410571440937929, 0.024998266708280426, 0.013507558051060187, 0.03274003400292713, 0.028699383146886248, 0.0257977434375789, 0.028242140397196636, 0.04208571415801998, 0.08695774755324237, 0.03147133254969958, 0.05515888668014668, 0.09711279170005582, 0.020782578467333224, 0.04932446674501989, 0.1608593066339381, 0.18545304163126275, 0.052121639891993254, 0.14244089339626953, 1.9628592487424612, 5.600059702992439, 10.012805666774511, 13.304284997284412, 12.774648517370224, 11.241665426641703, 3.416404752060771, 1.8636783957481384, 0.03605286248784978, 0.09143223011051305, 0.07505046305595897, 0.00863655341163394, 0.01887634804006666, 0.08333284597028978, 0.06720549456076697, 0.010144261668756371, 0.018028904451057315, 0.060481944601633586, 0.01775952710886486, 0.011314194398437394, 0.14256889902753755, 0.07319684533285908, 0.050568191218189895, 0.05572562775341794, 0.02857666531781433, 0.05373513944505248, 0.025241346047550905, 0.038371509945136495, 0.02386396448855521, 0.04500077375269029, 0.0164450147349271, 0.07384285519947298, 0.015514496062678518, 0.05990710669721011, 0.09507454247795977, 0.041060518778976984, 0.04468950217415113, 0.033813261179602705, 0.017195442924275994, 0.044934585312148556, 0.07810640454408713, 0.023062257605488412, 0.0475218197243521, 0.08660439620143734, 0.0947944114159327, 0.027563312760321423, 0.011019828016287647, 0.03713135149155278, 0.040249518351629376, 0.06705987034365535, 0.07717342101386748, 0.01668719978624722, 0.059648906099027954, 0.033980611769948155, 0.012829584811697714, 0.054966158349998295, 0.07586443578475155, 0.027410458169470076, 0.03643920972535852, 0.05660743649059441, 0.032489407021785155, 0.04867308001848869, 0.03999159605882596, 0.02047177629719954, 0.01085622156097088, 0.008648599396110512, 0.03670297272037715, 0.07878775548306294, 0.015236468061630148, 0.0831856409786269, 0.05332714004907757, 0.047127750440267846, 0.042126064727199264, 0.05380568058171775, 0.04897950537269935, 0.024447615396638867, 0.1405694938148372, 0.10288819976267405, 0.08045627415413037, 0.06599298110813834, 0.042163739854004234, 0.015386795639642514, 0.08401987433899194, 0.049978335955529474, 0.04695182062278036, 0.015751713362988085, 0.004458310231711948, 0.15280652936780825, 0.16738705948228016, 0.11173750186571851, 0.10535235269344412, 0.08891797479009256, 0.11234982564928941, 0.15136033587623388, 0.08312058431329206, 0.1715936861000955, 0.14243029552744702, 0.18953748105559498, 0.12586852797539905, 0.16782670776592568, 0.16646792442770675, 0.1588809338863939, 0.10723414234234951, 0.1016555073147174, 0.19029055314604193, 0.13048878317931667, 0.21089102898258716, 0.1360370495240204, 0.14751868264283985, 0.1860472941189073, 0.12187935804831795, 0.11927046405617148, 0.15709332277765498, 0.10638113264576532, 0.10769875647383742, 0.057770957064349204, 0.18143644934752956, 0.173457486089319, 0.13204402785049751, 0.1730378164211288, 0.12790778651833534, 0.22412052378058434, 0.11042865764466114, 0.15411434200359508, 0.11739381749066524, 0.09254639415303245, 0.08976231620181352, 0.09984951320802793, 0.16088338190456852, 0.16241545672528446, 0.18484020576579496, 0.1335641392506659, 0.08591845878981985, 0.09987698009354062, 0.10547208337811753, 0.12107881077099591, 0.16731930139940232, 0.2577510051196441, 0.17060299316653982, 0.12550180312246084, 0.22663836367428303, 0.15674691792810336, 0.27848845173139125, 0.12051685655023903, 0.1303884299704805, 0.18233140523079783, 0.11318653778289445, 0.17872896103654057, 0.08681736289872788, 0.20370828628074378, 0.14006705983774737, 0.12845430406741798, 0.11928699910640717, 0.2198201193823479, 0.21769294602563605, 0.09894070884911343, 0.10671628653653897, 0.23482106131268665, 0.22155297483550385, 0.1509044345584698, 0.1128038196475245, 0.12886460783192888, 0.11853731863084249, 0.15621772210579365, 0.20232551672961563, 0.0886658598028589, 0.27028107026126236, 0.14803567755734548, 0.09399423521244898, 0.18107865995261818, 0.15324295673053712, 0.14695248333737254, 0.23381387785775587, 0.28428052843082696, 0.17694382870104164, 0.1986074459273368, 1.9450120814144611, 7.083216067403555, 16.29694551229477, 25.21664008498192, 22.201044000685215, 13.10340117663145, 3.8803353952243924, 1.9586173701100051, 0.09032655623741448, 0.2382379092159681, 0.15708334831288084, 0.07724934272118844, 0.12996890873182565, 0.09182411376968957, 0.10866700686165132, 0.12075146427378058, 0.0812645026599057, 0.11724698357284069, 0.0905648227490019, 0.13143824238795787, 0.21035742480307817, 0.15923907951219007, 0.13965012127300724, 0.18924203206552193, 0.11258128666668199, 0.16198554541915655, 0.13426569144940004, 0.1336802853620611, 0.10463696686201729, 0.09643243523896672, 0.1453898468753323, 0.3100081463344395, 0.1469404308591038, 0.10341359578887932, 0.14566709840437397, 0.15330372378230095, 0.2105171646689996, 0.13124111312208697, 0.15799878747202456, 0.10905746559728868, 0.19340497587108985, 0.07805330387782305, 0.13338103657588363, 0.1896325798588805, 0.19166737067280337, 0.121555559016997, 0.13288502959767357, 0.14694978191982955, 0.16009143611881882, 0.18998158222530037, 0.19235681102145463, 0.1771894350531511, 0.10785433289129287, 0.12514242553152144, 0.11936731432797387, 0.1301732665160671, 0.15842981199966744, 0.09792720971745439, 0.13979595329146832, 0.17272416997002438, 0.07195077196229249, 0.18631158774951473, 0.114525661629159, 0.14736007084138691, 0.14824781304923818, 0.08183884332538582, 0.10417969257105142, 0.19377590127987787, 0.15678065596148372, 0.2281042537651956, 0.11251586634898558, 0.17082784906961024, 0.14389624499017373, 0.126113228907343, 0.12581638467963785, 0.21180516196181998, 0.1669269279227592, 0.33408855262678117, 0.1465891723637469, 0.162786619621329, 0.15298531274311244, 0.0822908706322778, 0.18571559863630682, 0.18523378152167425, 0.08588674681959674, 0.1703081972664222, 0.17255061131436378], [0.014167861681926297, 0.04087524161150213, 0.12101072614314035, 0.044016697065671906, 0.019749497769225854, 0.020069602760486305, 0.02994316142576281, 0.08215087931603193, 0.01959967856237199, 0.04346784175140783, 0.050331846869084984, 0.015907070846878923, 0.03334855427965522, 0.03452062439464498, 0.010571209950285265, 0.030578773803426884, 0.040164917227230035, 0.015143683831411181, 0.05262054124614224, 0.028180317640362773, 0.023663519677938893, 0.035590890402090736, 0.10752226633485407, 0.0256319977415842, 0.08184132952010259, 0.030194818136806134, 0.054244942948571406, 0.03256202246120665, 0.016379451553802937, 0.00635432963463245, 0.06320235741441138, 0.01281489028770011, 0.03609752493503038, 0.11071695233113132, 0.025114464770013, 0.05696580104995519, 0.08106156979920343, 0.06258650100789964, 0.03280981814896222, 0.04608847280906048, 0.017556852144480217, 0.09008739172713831, 0.06809548547607847, 0.031606785632902756, 0.04968415974872187, 0.0476222100405721, 0.03061226692807395, 0.023335690784733742, 0.018870765234169085, 0.05695354819181375, 0.022632496584265027, 0.013000842809560709, 0.03591120505006984, 0.07891801724326797, 0.06681663886411116, 0.030763819049752783, 0.016709093142708298, 0.05143573216628283, 0.07995758060133085, 0.01712504650640767, 0.057148272899212316, 0.059351215822971426, 0.08637993363663554, 0.04874187339737546, 0.04717740754131228, 0.027235031157033518, 0.02994813010445796, 0.02103471942973556, 0.04225288663292304, 0.06283679773332551, 0.0793033254740294, 0.013206652420194587, 0.027762293684645556, 0.06633928205701523, 0.03890954474627506, 0.06631385607761331, 0.03534942523401696, 0.03205391847586725, 0.02293980880494928, 0.0042514634696999565, 0.039316998663707636, 0.013836271027685143, 0.06350608877255581, 0.03337819565786049, 0.0513817594764987, 0.10838923582923599, 0.11851757750264369, 0.033728144262568094, 0.057327316026203334, 0.056548892171122134, 0.07594030554173514, 0.21675445575965568, 0.1023224754317198, 0.014345994750328828, 0.04260002249793615, 0.06245833952561952, 0.07575020441436209, 0.09754128550412133, 0.02870414959033951, 0.05431155441328883, 0.08608209493104368, 0.03820688303676434, 0.05655846958688926, 0.043215689656790346, 0.10290960330166854, 0.02863495916244574, 0.021408639404398855, 0.06658367128693499, 0.019637483565020375, 0.010474035916558933, 0.015867514375713654, 0.04688061526394449, 0.05966128141153604, 0.08078571350779384, 0.050886034514405765, 0.045363468743744306, 0.0615172072139103, 0.08932861994253471, 0.030260950916272122, 0.07657646710867994, 0.048533838271396235, 0.07001268299063668, 0.033825599384726956, 0.0014740348137820547, 0.015252239627443487, 0.05044936224294361, 0.07645465098903514, 0.011331866789987544, 0.04628409551514778, 0.03321287484141067, 0.03626140969572589, 0.054508023167727515, 0.033366992938681506, 0.02390676600043662, 0.041068700957112014, 0.046721899561816826, 0.011176410971529549, 0.0270705285583972, 0.02304849633219419, 0.028228308619873133, 0.05246634522336535, 0.06471604181570001, 0.04818676177819725, 0.01819013417843962, 0.028855349191871937, 0.07181564171332866, 0.022428821575886104, 0.01886811020085588, 0.07340670243138447, 0.04980859564966522, 0.0513502887042705, 0.036580043379217386, 0.04297175684769172, 0.07510099589126185, 0.040378848716500215, 0.01761191579134902, 0.017290486066485755, 0.017281520922551863, 0.050525157785159536, 0.023512227307946887, 0.08095288227195852, 0.02630094182677567, 0.008374541885132203, 0.0559539494861383, 0.015816311752132606, 0.02905258421378676, 0.02501164206478279, 0.045414420892484486, 0.06826117736636661, 0.01202275989271584, 0.08827750876662321, 0.04449633968761191, 0.03674878549645655, 0.01580765274411533, 0.019643379928311333, 0.013725832031923346, 0.016325465876434464, 0.03711254918016493, 0.04867594841925893, 0.028633105648623314, 0.03773689575609751, 0.05215875840804074, 0.024656932582729496, 0.08072577766142786, 0.03429397620493546, 0.05364899094274733, 0.043627507402561605, 0.03865501406835392, 0.03232089125958737, 0.039715676684863865, 0.014486480522464262, 0.05408720317063853, 0.014201067224348662, 0.09844288360909559, 0.0168874980226974, 0.037300431285984814, 0.030176329382811673, 0.03298489078588318, 0.027955177865806036, 0.034412259701639414, 0.034181448063463904, 0.04722828176454641, 0.027231146013946272, 0.028600861187442206, 0.05798085498099681, 0.03950217935198452, 0.06451399211073294, 0.08347518247319385, 0.04096372416825034, 0.01566583388921572, 0.042060354971908964, 0.03349241960677318, 0.06201882482855581, 0.10569095014943741, 0.04203016069368459, 0.060232735122554004, 0.041077102068811655, 0.02967337775771739, 0.004208174459563452, 0.03343019423482474, 0.011607540327531751, 0.04519289723248221, 0.04376276381663047, 0.0326136017247336, 0.05681365706550423, 0.015036532549856929, 0.033329789075651206, 0.030321155791170895, 0.04914114884741139, 0.0420504547219025, 0.07965859156684019, 0.03246877160563599, 0.06293864265899174, 0.0536303407716332, 0.028715322623611428, 0.019493082036206033, 0.057668844965519384, 0.02769980113953352, 0.046156739263096824, 0.025054161560547072, 0.04766048259625677, 0.11273763491772115, 0.04068685484526213, 0.013824331726937089, 0.034391041699564084, 0.05259091100015212, 0.045837853249395266, 0.05741511580708902, 0.04187351558357477, 0.022261873600655235, 0.011547432859515538, 0.05512194999027997, 0.014356287410919322, 0.047402144700754434, 0.031152951196418144, 0.10718491568695754, 0.008409168640355347, 0.07434630591887981, 0.05750954667746555, 0.019819636290776543, 0.04576404666295275, 0.1330542837968096, 0.17332407762296498, 0.05275394600175787, 0.03443322908424307, 0.09979029724490829, 0.08622492125141434, 0.1862143218750134, 0.08807131787762046, 0.03629799757618457, 0.056328221980948, 0.01274699583518668, 0.05566255633311812, 0.04671228503866587, 0.03808949753874913, 0.013532910743379034, 0.03315274232591037, 0.02126273131580092, 0.03777453748625703, 0.04119612400245387, 0.04142424535530154, 0.01126936496802955, 0.022937155627005268, 0.016704807239875663, 0.009045499045896577, 0.016033855645218864, 0.04938361220411025, 0.037714924474130385, 0.006247566125239246, 0.0331936569273239, 0.04920633538858965, 0.021316375605238136, 0.04188402439467609, 0.0812867670902051, 0.021162873490538914, 0.047344847189378925, 0.05205318047956098, 0.014640904755651718, 0.009047475941770244, 0.054781434082542546, 0.07205099158454686, 0.04224029238685034, 0.049653538735583425, 0.030326361957122572, 0.04967913540895097, 0.05074684100691229, 0.044382909836713225, 0.007300615698113688, 0.11158349880133756, 0.06508223232231103, 0.04924101223878097, 0.029765847502858378, 0.02545459290558938, 0.0445566725829849, 0.015475960972253233, 0.02097767239320092, 0.06368600763380527, 0.037976583480485715, 0.017907997462316416, 0.06238504502107389, 0.05426000483566895, 0.02825180872605415, 0.02642685460159555, 0.07209039220470004, 0.04222937910526525, 0.05578849508310668, 0.04666474305849988, 0.017594905766600277, 0.04161673990893178, 0.057252195838373154, 0.05729529235395603, 0.020066263095941395, 0.013485991239576833, 0.006519398584714509, 0.013385065649345051, 0.05312904228048865, 0.11036923388019204, 0.03343966032844037, 0.021045224530098494, 0.033515441027702764, 0.04309538009692915, 0.0316070416738512, 0.13696319045266137, 0.04715208175184671, 0.05332467982952949, 0.04998892269213684, 0.021839561886736192, 0.028172571473987773, 0.024887660729291383, 0.03553182657924481, 0.010650464828358963, 0.03197446043486707, 0.10525586607400328, 0.18583358527394012, 0.29648954048752785, 0.12465618521673605, 0.14388019975740463, 0.1629690988920629, 0.17040881764842197, 0.17137306043878198, 0.1374870873405598, 0.12029020464979112, 0.12560444214614108, 0.13503651571227238, 0.1480109937256202, 0.14757802477106452, 0.09035623472300358, 0.18231823953101411, 0.08686903121997602, 0.20504229672951624, 0.09332017958513461, 0.1151321892393753, 0.13230680749984458, 0.11794894395279698, 0.15944112179568037, 0.24729739496251568, 0.30085019243415445, 0.1434431193047203, 0.10901201647357084, 0.09717131746583618, 0.12136234829085879, 0.16089714132249355, 0.16936899453867227, 0.1362492740736343, 0.11964252495090477, 0.1557231103652157, 0.1538748954772018, 0.05967523749859538, 0.25246827921364456, 0.3382038208656013, 0.12974424578715116, 0.126150633150246, 0.0803668973094318, 0.18646559823537245, 0.1907188762561418, 0.1342486814246513, 0.2637961838627234, 0.14458660560194403, 0.18732454511336982, 0.11463683535112068, 0.11373490327969193, 0.132548792171292, 0.13581191160483286, 0.12546931189717725, 0.16639409557683393, 0.11500989072374068, 0.1529208052670583, 0.1575065209181048, 0.1412574647110887, 0.12297032997594215, 0.16506925807334483, 0.1268354128114879, 0.14155410113744438, 0.11439770052675158, 0.20419730222783983, 0.09121005336055532, 0.21046714391559362, 0.13946188293630257, 0.09421132082934491, 0.12380906075122766, 0.20695924933534116, 0.11991481151198968, 0.16264598263660446, 0.08697325843968429, 0.0780220891465433, 0.22784096945542842, 0.1428016513818875, 0.12702454172540456, 0.17463191994465888, 0.08832416759105399, 0.12270191742572933, 0.16890492959646508, 0.17555062455357984, 0.11859635647851974, 0.1707978663034737, 0.12964022636879236, 0.20276688679587096, 0.2490168175427243, 0.38227329205255955, 0.10637532162945718, 0.07673600659472868, 0.28088226390536875, 0.23951327515533194, 0.35213740600738674, 0.19845601811539382, 0.17808857664931566, 0.2556653326610103, 0.11723086412530392, 0.22205196524737403, 0.21224754134891555, 0.10733350107329898, 0.12932462064782158, 0.1920072891516611, 0.1360322255641222, 0.13468491582898423, 0.16034198517445475, 0.14903411851264536, 0.2168258058372885, 0.07544803156633861, 0.13989836967084557, 0.10138072713743895, 0.12943034700583667, 0.12537597940536216, 0.14016968401847407, 0.1767108091735281, 0.16373297665268183, 0.0927217116986867, 0.15031761839054525, 0.14077981846639886, 0.14412746852030978, 0.10688951864722185, 0.17538738175062463, 0.1352430702536367, 0.19569963711546734, 0.1063630316639319, 0.24359244533115998, 0.1482049614423886, 0.14252818480599672, 0.21951557166175917, 0.08072022639680654, 0.14059837820241228, 0.1470509811770171, 0.24102038412820548, 0.17289456707658246, 0.2881187974708155, 0.12022468043141998, 0.1033447912777774, 0.18828552245395258, 0.07292242138646543, 0.10824282493558712, 0.10497350856894627, 0.14173552655847743, 0.150458344432991, 0.1410958101041615, 0.13006847526412457, 0.07056011338136159, 0.12032504848320968, 0.253841252415441, 0.1551191505859606, 0.20643824682338163, 0.15839001804124564, 0.18823444785084575, 0.2117779548279941, 0.07675732107600197, 0.14914791943738237, 0.10680538136512041, 0.16128129180287942, 0.14156701450701803, 0.14403024717466906, 0.09155967170954682, 0.10960687752231024, 0.1286532441736199, 0.16740441089496017, 0.11276439676294103, 0.14599555812310427, 0.13158431189367548, 0.15688103885622695, 0.07451297744410113, 0.21398646757006645, 0.14823629491729662, 0.1269497035536915, 0.13047787360846996, 0.19511288031935692, 0.1929880224633962, 0.11021732367225923, 0.07836541408323683, 0.132353191729635, 0.15469876845600083], [0.034956487725139596, 0.00045643766441116895, 0.0544186797196744, 0.0499370762554463, 0.04802991999895312, 0.012877750195912085, 0.01629401922400575, 0.03786951754591428, 0.040153039153665304, 0.03193629549059551, 0.015326200209528906, 0.04686001324444078, 0.048931069104583, 0.06399180958396755, 0.07727243835688569, 0.015202067661448382, 0.030897166288923472, 0.02473292850481812, 0.07690082275075838, 0.015477143770112889, 0.008325100934598595, 0.05734802565712016, 0.09441676957067102, 0.09952212960342877, 0.0367077855480602, 0.018930934857053217, 0.020068686208105646, 0.018568633204267826, 0.045546641922555864, 0.04014304984593764, 0.06672853851341642, 0.020595675996446516, 0.06701246937154792, 0.05681541595549788, 0.07060801159241237, 0.00463917625893373, 0.04658503268728964, 0.04901024884020444, 0.09241031395504251, 0.021408413049357478, 0.025281097332481295, 0.024155589562724344, 0.08505630583385937, 0.05458915846247692, 0.02128143529262161, 0.035934026091126725, 0.04204058786854148, 0.019524404378898907, 0.04157676041359082, 0.01387002947012661, 0.07630692649399862, 0.01664560055360198, 0.029793833891744725, 0.022781286061217543, 0.023631197291251738, 0.005434187578430283, 0.06524203898152336, 0.04099494261026848, 0.08461224919301458, 0.06904636960825883, 0.012887672710348852, 0.07511963121942244, 0.07839763071388006, 0.04215788059809711, 0.05675177679222543, 0.013266517762531294, 0.04170088461250998, 0.02653017083503073, 0.03786343564570416, 0.03687663527671248, 0.025804424622037914, 0.05895512418646831, 0.03557881937013008, 0.0799706498219166, 0.03637042005721014, 0.020355053165985737, 0.044319508160697296, 0.023666471570322756, 0.13206690084189177, 0.06018187945301179, 0.0644845214264933, 0.04043277687742375, 0.01287594770474243, 0.06624233530601487, 0.12295131615246646, 0.13242949935374781, 0.024549933441448957, 0.011865534979733638, 0.053544288748526014, 0.07024153906968422, 0.10035714221885428, 0.013228940970293479, 0.07783642606227659, 0.05291825007589068, 0.07764362351736054, 0.12700656690867618, 0.08393995987717062, 0.09434419494937174, 0.032176061140489765, 0.046489629603456706, 0.056816106152837165, 0.01159944906248711, 0.027701240906026214, 0.11606931395363063, 0.012940943142893957, 0.06900852749822661, 0.15088040381669998, 0.037176251425989904, 0.02130826578650158, 0.027975800294370856, 0.016263730321952607, 0.07409276600810699, 0.055684690887574106, 0.020172241784166545, 0.08374782526516356, 0.04603575434884988, 0.07141336056520231, 0.052597575486288406, 0.018428532421239652, 0.05979002176900394, 0.029134519172657747, 0.01800876070774393, 0.023119041179597843, 0.03772649455640931, 0.01887989365059184, 0.07716683816397563, 0.03284894417447504, 0.05644101358484477, 0.004157207004027441, 0.017772583341866266, 0.12145486442022957, 0.0697739192401059, 0.03519865051202942, 0.0342713703867048, 0.04657346260501072, 0.014551816420862451, 0.022323970952129457, 0.027709918467735406, 0.03595806054363493, 0.0545128731027944, 0.043662692623911425, 0.0423019834124716, 0.042449819229659624, 0.050730194634525105, 0.016022302261262666, 0.048786925472086295, 0.045296931493794546, 0.04922539374092594, 0.0328992580762133, 0.033398181694792584, 0.03653706931800116, 0.027818008566100616, 0.05541987033211626, 0.02283373734826455, 0.050115232515963726, 0.0104242906854779, 0.05065502620709594, 0.025221608630090486, 0.031864244083408266, 0.04347004221926909, 0.04419562144903466, 0.04035092541016638, 0.016059214831329882, 0.021635883167618886, 0.03353050662553869, 0.027263468400633428, 0.07914321453426965, 0.02742077031143708, 0.16651948884828016, 0.03874331479892135, 0.038165289370226674, 0.06434606635593809, 0.04785691053257324, 0.019676856354635675, 0.012251396110514179, 0.0640843108703848, 0.030795124694122933, 0.014246921746234875, 0.031727154564578086, 0.04625230190868024, 0.03567558429494966, 0.05139566361322068, 0.015198968267213786, 0.05807402420032304, 0.01874005261925049, 0.10630573044181801, 0.009272593451896682, 0.05654378990584519, 0.04537002561846748, 0.017908696936501656, 0.06438743366743438, 0.05168982497707475, 0.042514946399023756, 0.020782005158253014, 0.06939667815458961, 0.06122304213931784, 0.01615584802493686, 0.023534302490588743, 0.05371946899686009, 0.030286966903076973, 0.05964695053989999, 0.025924470719473902, 0.030159909365465865, 0.08026565352338366, 0.031083515859791078, 0.02119236087310128, 0.04815389205759857, 0.048282587886205874, 0.029965887842990924, 0.0811047553725075, 0.019979530152340885, 0.009121734310610918, 0.02646761520736618, 0.04168998988461681, 0.10659038860467263, 0.03561983416147996, 0.05345688230590895, 0.010713401734392392, 0.0616570575220976, 0.02127525134710595, 0.01886065161670558, 0.008473548095935257, 0.06828307814430445, 0.017676820316410158, 0.017888234069687314, 0.03277895964856725, 0.06337548562441953, 0.022996759362285957, 0.03519841302477289, 0.03355992535944097, 0.025182306344504468, 0.036949321220163256, 0.04893877630820498, 0.0398705257975962, 0.0609859964606585, 0.009141062619164586, 0.023565062656416558, 0.0017976564254240657, 0.030352619141922332, 0.06233140258700587, 0.04044733039336279, 0.03243995030061342, 0.05728794880269561, 0.04786414276168216, 0.01554640748508973, 0.024997426226036623, 0.08942074273363687, 0.03850907814921811, 0.019867317423631903, 0.08256642264313996, 0.03621548930823337, 0.040519530230085365, 0.014579786111426074, 0.02975843530293787, 0.05293379806971643, 0.024250437891168986, 0.06224770317203365, 0.039369223595713265, 0.08729165463591926, 0.04837042848521378, 0.006190148478708579, 0.09111758176004514, 0.05181659493246116, 0.062001896440051496, 0.07577286218293011, 0.08031624573050067, 0.059682621867978014, 0.026227801317872945, 0.11407667712774128, 0.02600837979116477, 0.035927851422457024, 0.0616763348079985, 0.08036926476052031, 0.0347845877695363, 0.040618566126795486, 0.005551719186769333, 0.03893404304108117, 0.03449209994869307, 0.005829181764056557, 0.030301455481094308, 0.04332223608798813, 0.018024329110630788, 0.03701318673847709, 0.018973827282025013, 0.020941737602697685, 0.049759495159378275, 0.030261409192462452, 0.054700710679753684, 0.023883028406999074, 0.024070554281934164, 0.04138491894991603, 0.03629775637818966, 0.04590710304910317, 0.037820869765710086, 0.039804144398658536, 0.05878366209799424, 0.05608462684904225, 0.017746337289281655, 0.00632087500889611, 0.025400609083590098, 0.06290250006713904, 0.1266297636902891, 0.010187741318077315, 0.011918631935259327, 0.03525076412188355, 0.02111770081683062, 0.020947804659954272, 0.052867116100969724, 0.014064912811591057, 0.014025659693288617, 0.09512793258181773, 0.048344419919885695, 0.08839418180286884, 0.059857386513613164, 0.03482960644760169, 0.0840211656759493, 0.04389330017147586, 0.06875800070702098, 0.022454390418715775, 0.01691794463113183, 0.010392831045464845, 0.08054409248870797, 0.012014166750304867, 0.008524970580765512, 0.004685413914558012, 0.022085917807999067, 0.06738061914802529, 0.044807184531237, 0.010458067681611283, 0.031606418269802816, 0.04641954117687419, 0.05846646075951867, 0.036086448380956426, 0.008357738734048326, 0.03937314584618434, 0.012759398050548043, 0.01271042743610451, 0.034066404041368514, 0.013273331605887506, 0.026625271493685432, 0.033523990568937734, 0.02141298467904562, 0.033480808706372045, 0.04639877959562, 0.01412021301803179, 0.01535811348730931, 0.06818279172875918, 0.019831137724395376, 0.06150631990749389, 0.03251230969908647, 0.018080706358887255, 0.027676019017235376, 0.07290025343536399, 0.11633647969574668, 0.11528950970387086, 0.0789094231731724, 0.10217718518106267, 0.1500281214248389, 0.07157073298003525, 0.15031203744001687, 0.12775325652910396, 0.1683888104162179, 0.07751844546874054, 0.10243935626931489, 0.1869560984778218, 0.13342448190087453, 0.10276429078658111, 0.10178234035265632, 0.12612321821507066, 0.12095550293452106, 0.2476701608975418, 0.1273382772342302, 0.20854444708675146, 0.09953655695426278, 0.13175147323636338, 0.11740091984393075, 0.13908493128838018, 0.21569722186541185, 0.1520514683215879, 0.15771214035339653, 0.13355884031625465, 0.15808382275281474, 0.1432114208000712, 0.22915843001101166, 0.20511593262199312, 0.16364547744160518, 0.1450914441375062, 0.06857220403617248, 0.1559097011340782, 0.13094999827444553, 0.19181574083631858, 0.08173300564521924, 0.07192253324319609, 0.0697914042393677, 0.15614818286849186, 0.1412495831027627, 0.06542321207234636, 0.08931562493671663, 0.16365565970772877, 0.19049661786993966, 0.1017173653235659, 0.14980783715145662, 0.21255121333524585, 0.13298389851115644, 0.13736933819018304, 0.11243127635680139, 0.12662694352911785, 0.13985314319143072, 0.1932476257206872, 0.10129871981916949, 0.18527816195273772, 0.19454205001238734, 0.08703652652911842, 0.11092936241766438, 0.13455103238811716, 0.1790539178182371, 0.23742574732750654, 0.10938219231320545, 0.19218268833355978, 0.095720255485503, 0.09881395744741894, 0.07758127569104545, 0.20934363623382524, 0.1577000433462672, 0.17035386903444305, 0.13517265528207645, 0.23233449552208185, 0.08195350514142774, 0.10478078766027465, 0.11889002431416884, 0.23367696645436808, 0.12127136840717867, 0.12474421877413988, 0.1873862324282527, 0.2338607667479664, 0.08826641365885735, 0.14591190323699266, 0.14634905790444463, 0.1610424686805345, 0.14529366453643888, 0.2145337569527328, 0.19708590960362926, 0.28265941073186696, 0.1048411762167234, 0.2755397802684456, 0.14928266376955435, 0.1363741626846604, 0.2523415203904733, 0.2919792418833822, 0.26180470478720963, 0.1386588643072173, 0.1523438299773261, 0.13756591826677322, 0.1029295967600774, 0.12107380869565532, 0.13617966062156484, 0.06016060578986071, 0.15021417784737423, 0.26594974799081683, 0.1796563933021389, 0.14081938978051767, 0.14846621226752177, 0.1611312889144756, 0.24024617567192763, 0.1099742777296342, 0.10006711090682074, 0.15099886542884633, 0.1800135147641413, 0.226716096221935, 0.061409102272591554, 0.10596152234938927, 0.11833252297947183, 0.11417822519433685, 0.1493553793989122, 0.07948261350975372, 0.1371398809715174, 0.19443647208390757, 0.25073661119677126, 0.12566550605697557, 0.2348218034603633, 0.0991058218642138, 0.1800317715969868, 0.17191465012729168, 0.1687828908325173, 0.1861060573719442, 0.08970636568847112, 0.16111977078253403, 0.1565107813803479, 0.16347104305168614, 0.1259100585593842, 0.18130502983694896, 0.144528450910002, 0.1549802502267994, 0.1371741236653179, 0.11209657517611049, 0.11083232660894282, 0.14738653582753614, 0.21716811403166503, 0.15844751964323223, 0.12453751580324024, 0.12802578799892217, 0.12120503524783999, 0.13759428315097466, 0.07743625261355191, 0.13524243200663477, 0.09898583142785355, 0.12568928446853533, 0.11439206762588583, 0.103113293153001, 0.09897118885419331, 0.14984065492171794, 0.12364483831333928, 0.18803532962920144, 0.13457081804517657, 0.09853372990619391, 0.07505159112042747, 0.16202294966205955, 0.13844576402334496, 0.17383612983394414, 0.08064759982516989, 0.23588049196405336, 0.07820098384399898, 0.14404954301426187, 0.16767559165600687, 0.2064067797618918, 0.16765589505666867, 0.13243157736724243, 0.2241082486580126], [0.003651180568340351, 0.02357261586439563, 0.0177170243114233, 0.01645708762225695, 0.0497195193747757, 0.07443279580911621, 0.007081594931150903, 0.04150729539105669, 0.013892447896068916, 0.11107019236078486, 0.04325807742134202, 0.01757926871505333, 0.01983806196221849, 0.052132427008473314, 0.02109826211381005, 0.02849172095011454, 0.04450421758519951, 0.045745771276415326, 0.06204921206517611, 0.0769742731063161, 0.021498554306162987, 0.0741408126486931, 0.036468691541813314, 0.02255141323985299, 0.008210158957808744, 0.08879014727426693, 0.022685565709252842, 0.055344813226838596, 0.05128143966430798, 0.060582494479604065, 0.0010268758796883048, 0.06578570668352768, 0.012827900136471726, 0.02328041933651548, 0.018953746621264145, 0.03458645660430193, 0.01544138060125988, 0.04295561884646304, 0.0118714526797703, 0.026531692237767857, 0.03358443107572384, 0.01601696993020596, 0.07566308369860053, 0.057405237821512856, 0.0720348053437192, 0.05642045980494004, 0.02576576986029977, 0.032671470689820126, 0.026382943578937557, 0.014263762004702585, 0.007729404042038368, 0.040750753760221414, 0.020106255578866694, 0.05595725946477614, 0.011809575189545285, 0.06740731419995427, 0.015897723496891558, 0.042844608396990225, 0.05428200209280476, 0.006728098860548926, 0.04417920885316562, 0.06992313545197248, 0.014249026662582764, 0.02306402391695883, 0.05465547306812368, 0.06484138313680887, 0.05857731906871777, 0.023274812410818413, 0.01937969671416795, 0.1006365756620653, 0.029251123560243286, 0.03888494255079422, 0.03270493783929851, 0.06386680965078995, 0.09890604313113727, 0.022376678280124906, 0.03939920636184979, 0.06391524962964468, 0.015309693917515688, 0.03098140561633045, 0.039625854551559314, 0.02995947012095712, 0.01858980111137498, 0.015789329117978923, 0.04918575934425462, 0.018381853187747765, 0.022381279595720116, 0.03945915334043093, 0.11275817014393397, 0.03605796104238834, 0.12656915991101414, 0.08719870063941926, 0.016089889650174882, 0.03914444190741051, 0.08436800097115338, 0.022562306112376973, 0.047847956520854495, 0.06211004962096922, 0.07426756405038759, 0.024137241816788446, 0.017712183653202374, 0.02776439952867804, 0.021810209946124814, 0.05057477406808175, 0.06416064075892791, 0.02554518130637007, 0.05678852794517297, 0.007087328485795297, 0.08380404295166954, 0.019826937168545555, 0.010146617059945129, 0.03600558025937062, 0.05183066605241038, 0.07983605391927995, 0.05319288553437218, 0.06306614362983964, 0.08044054804486223, 0.09122221716097556, 0.06359855295158923, 0.02249180764920311, 0.029961267973703798, 0.023136542877182364, 0.07588079271954484, 0.01083027422282612, 0.0052069465982640395, 0.09300855919718742, 0.054083833820186555, 0.07812478754203767, 0.030335581286635716, 0.08908152187359519, 0.026220964282401837, 0.10136370969121344, 0.005530995640583569, 0.09075515394215472, 0.01379954584990628, 0.05501448700670153, 0.043037607611040585, 0.04475199843000155, 0.03875843976857141, 0.06330364572932012, 0.010480539913260145, 0.014377536026586313, 0.06123831553850323, 0.06225002980499994, 0.1112816524982918, 0.035185681481380016, 0.020506017135630827, 0.03881184100464452, 0.0655556854326278, 0.04558403503324371, 0.055003878005663864, 0.0779399556631688, 0.023027673523756675, 0.02192654530517757, 0.041397138411412016, 0.019143328245263547, 0.014208766078809276, 0.0213049409649102, 0.05165438742551487, 0.030462996910500806, 0.03320550902571995, 0.05477122213051189, 0.025276013620896265, 0.0649656706082169, 0.005347039032130851, 0.02498293022654252, 0.07086050507496111, 0.1203206623904407, 0.024702660011826083, 0.03641381343186367, 0.055994188733166084, 0.04576923056447413, 0.04185026409686543, 0.02177638471039245, 0.05177658204047475, 0.016437494923593476, 0.07389107995550148, 0.03473897166259121, 0.06686471519060433, 0.06552570266649127, 0.03634445231000427, 0.05761542517575435, 0.021706030966015533, 0.026677765454223845, 0.04839096742216498, 0.008258940324594732, 0.011034477083740057, 0.03527070191921666, 0.005022486720918096, 0.029780352779198438, 0.019185532328265253, 0.05947993391600903, 0.0668582362413872, 0.04742621254990809, 0.047643654397688806, 0.03331670130137354, 0.050244288286194205, 0.02458049693814246, 0.021949214205960743, 0.026172650468652137, 0.056137259962270036, 0.06233103893464431, 0.08269780504633673, 0.015565959365630988, 0.042997602140530944, 0.02270691915327916, 0.017932345472218003, 0.04062660729687195, 0.02055544788163388, 0.028607043277588673, 0.0022056299621908693, 0.019627909859991632, 0.03891465443302877, 0.023560351874039043, 0.012139046084485017, 0.007166892746681697, 0.019084010236838367, 0.03376541491888929, 0.05195168065256439, 0.024069535684247967, 0.04557586398732383, 0.03538700388162397, 0.012601636935869465, 0.10043910500826314, 0.031004089360067155, 0.015160925777308876, 0.0061241729417815804, 0.024743806534388568, 0.02922017785749631, 0.03375918458914384, 0.04484295604925137, 0.006372526631821529, 0.02848311203706544, 0.03299822717963252, 0.03976167499786243, 0.04308409203076735, 0.05630877771181986, 0.06065759611374233, 0.0635513078304939, 0.026738037122413516, 0.030871495400788262, 0.024795543504296802, 0.061517685899161734, 0.014515348211716628, 0.05472119395562913, 0.1396041378029622, 0.04365963497548364, 0.011665624515444506, 0.038148398089106195, 0.03607921986258589, 0.028395458830345888, 0.02201295912527712, 0.0344704477902269, 0.03189725110132713, 0.05243559804512188, 0.023206074693007395, 0.02155539539671736, 0.052524529601214454, 0.00740200605832797, 0.029034620529273525, 0.0464383731741691, 0.04169252060819417, 0.022399536428565625, 0.057198698123102076, 0.01765704950230429, 0.03906387064489536, 0.07704104413278401, 0.11856982469907962, 0.06985774482018314, 0.0567118344042683, 0.11165323841851205, 0.08974634518381208, 0.0588309443264734, 0.026854732423089445, 0.054457059886772186, 0.05557299024076201, 0.022150228614918888, 0.029424253625620622, 0.024782051259535365, 0.02910835661168676, 0.024899149175325874, 0.06111998751293868, 0.0234581785480259, 0.009549318983772537, 0.02218578491010703, 0.052794419025303796, 0.011672892924252665, 0.0015917710925350548, 0.009640308144298615, 0.04498098809563089, 0.0119250784155156, 0.01518083017799654, 0.019776361659751274, 0.11089639621786773, 0.03969169789343141, 0.042969248388544656, 0.045810148876626045, 0.027429965521150734, 0.06596495019039139, 0.009065910890058149, 0.05680668087734375, 0.018096371240972076, 0.02098628130625002, 0.025269827820011415, 0.012207036088511813, 0.04253273938957136, 0.027320593362674117, 0.05268036577035673, 0.01290922096814029, 0.06743055084371008, 0.01614613145648036, 0.018031004728982225, 0.08415881922701374, 0.02897015387134161, 0.013650197906827088, 0.03448725001362618, 0.07010007830103859, 0.06576566869625822, 0.03885812133376021, 0.02089726254780544, 0.0768962362781167, 0.03999905093223788, 0.11844975262647495, 0.03548520115145948, 0.11479172899271362, 0.025248125566577073, 0.045176102430559695, 0.027504213685460854, 0.0454374348919373, 0.06028518640960101, 0.053688206025981344, 0.026171342433372047, 0.0460343554004794, 0.08127903391141444, 0.02932371116912691, 0.03947840094042476, 0.028411376042640768, 0.06764877936802804, 0.031999507918953896, 0.016394082995248027, 0.01543917178423726, 0.020930041355313733, 0.029453496099449694, 0.052897573841619305, 0.015485928943235194, 0.04155967246333603, 0.05820327663968783, 0.05253550967609044, 0.016871686566446442, 0.05726338000386022, 0.03612199354392942, 0.10165088373469189, 0.18974014674313366, 0.07388538026134484, 0.18780330457957461, 0.14171205984894186, 0.12726075248792768, 0.1238549328991212, 0.10201358614722267, 0.1492840886930935, 0.09162712551187724, 0.22387252771295607, 0.1113971158338245, 0.1267193112289533, 0.09897254698444158, 0.11919602664420381, 0.1655025832587853, 0.15651941997930408, 0.14680063992273062, 0.12947495008120313, 0.15130571380723268, 0.11260289800702594, 0.14153569587506354, 0.1887935373815708, 0.1357052501407452, 0.09669397550169379, 0.1839228963945061, 0.16202965867705643, 0.18072498205583543, 0.10397788035334088, 0.15825430891709402, 0.11835800833068788, 0.0937148166121915, 0.1673300625407137, 0.15067852480569854, 0.17433730215998366, 0.1862704727682285, 0.12110629249946214, 0.15750779741210863, 0.1209481482510455, 0.16766907559940591, 0.06509422542876564, 0.12401332205627114, 0.1398220768896863, 0.15089147666003555, 0.14030163787538186, 0.1070895348675549, 0.20724521367810667, 0.11852475407067686, 0.1955886563519016, 0.13372655084822327, 0.0984102810616605, 0.12062632333254442, 0.08986166008980945, 0.2259412792045623, 0.1806404662784189, 0.10397782840300351, 0.15194338193396106, 0.07655888563022017, 0.12160652229795232, 0.15189591416856274, 0.1398808549856767, 0.14898277673637494, 0.23969088593730703, 0.1419118608464487, 0.09266021734219976, 0.13170439138775691, 0.17460735485656187, 0.18267809209646657, 0.10070691641885787, 0.09394353910465725, 0.2125108108157292, 0.15778086322825402, 0.12176803589682095, 0.08839294241624884, 0.17881138395750895, 0.22831379174022004, 0.10137965102330782, 0.11378130235243589, 0.16471273032948375, 0.31261412368621677, 0.11381859527318738, 0.07559548146673478, 0.15107085375348106, 0.07332311433856376, 0.07848336361348629, 0.17130951775470749, 0.1609265452134423, 0.13464850606396794, 0.17693333473289385, 0.20789879345102236, 0.12093263736460358, 0.19774947868427262, 0.3090098686516285, 0.21945202897768468, 0.15340112324338406, 0.20168556278804317, 0.11423422765801661, 0.183844881830737, 0.10603786708088592, 0.2510643732966855, 0.14654532627901062, 0.10331856377888471, 0.13807676819851622, 0.1955625179107301, 0.1350711888517253, 0.18781765771564096, 0.15442579169757664, 0.16007004742277786, 0.1535335075459443, 0.19265236391220242, 0.12755741860019043, 0.16441545565612614, 0.09382270261994563, 0.2675971674034372, 0.19646097673103213, 0.09019717763294466, 0.14251259970478714, 0.09730695237522013, 0.2392018848331645, 0.14237356575904414, 0.228116603102535, 0.1070104812970385, 0.08801434320048429, 0.2317899966146797, 0.08236685913288966, 0.11912823145394213, 0.243137493962422, 0.13386579259531572, 0.17764644959243014, 0.1433890315820463, 0.1949660389800556, 0.1303718949202448, 0.16276990645565093, 0.09019516641274095, 0.22713088255841285, 0.1868775495677255, 0.1092464015528094, 0.12920081557240337, 0.11774786646128632, 0.16214568604482338, 0.09134715030086227, 0.08574136751121841, 0.13649289146997035, 0.15609773166943341, 0.10889922486967407, 0.23233074025483802, 0.22737965045962483, 0.21302408014889807, 0.09153321414487436, 0.24304080696310848, 0.08122591840219684, 0.16080538218375295, 0.1626966119511053, 0.20093618659302592, 0.09909239641274326, 0.14420735329622403, 0.09433058396098204, 0.11473372273030691, 0.26535795943345875, 0.19443007477093488, 0.1476307024131529, 0.09969133185222745, 0.13794748607324436, 0.2135954299592413, 0.1445053849602118, 0.08939151695813052, 0.1464002364082262, 0.2140070399036631, 0.1980150636518374, 0.16038483678130433, 0.1296901432215236, 0.14962883113184944, 0.10282612653099932, 0.12626887211808935, 0.16933015052927658, 0.11046219529816881, 0.14406171423615888], [0.04650885864975862, 0.07629101484781131, 0.023787194877513684, 0.02197807076299796, 0.0077878045703982934, 0.01817095522710588, 0.024335608613910154, 0.027765002523665316, 0.03493998236081097, 0.01721392425679369, 0.01746076999552315, 0.00927904549826053, 0.08671683157444932, 0.013036455693509197, 0.0405486929230392, 0.03917897403880488, 0.041597173185436986, 0.022254678478930146, 0.018394662656646688, 0.061800919138477184, 0.06595962899154983, 0.06995035000727512, 0.02522054550354369, 0.06045843336323742, 0.008750062115723267, 0.03209774229617324, 0.02443325298372656, 0.03468845738098025, 0.041041115327971056, 0.02483290692907758, 0.034070478432113305, 0.05063779724878259, 0.042969534115400165, 0.037337074827519245, 0.032844031156855635, 0.01851615965279052, 0.039600918389623985, 0.019372362439753488, 0.0418135760264704, 0.03753909113584086, 0.050050598874804564, 0.10888746182899922, 0.06619115680223331, 0.0561255377397174, 0.032994946886901744, 0.02850666223821463, 0.10388889684691094, 0.05886908700631466, 0.05540556172491051, 0.02542439120588824, 0.03080538117501419, 0.03240822348743677, 0.022642730800725985, 0.06285699157160707, 0.06757570750778541, 0.01878269456938142, 0.08321099274326116, 0.009496865841356339, 0.04515049833571538, 0.03134671482257545, 0.12931653123814613, 0.06301140281721018, 0.04527391378360335, 0.1189969974802807, 0.0607844180194661, 0.09940964228007942, 0.01256597024621442, 0.06861461035441607, 0.05119103494507726, 0.03481731648207642, 0.152783656376414, 0.016818615586089436, 0.08461712510325015, 0.02388473349128617, 0.040178802810260095, 0.045553940944955684, 0.04677965720475186, 0.04917610029224306, 0.037791662543895654, 0.03825147126917727, 0.031406016132677905, 0.03164711393765174, 0.020481503997871187, 0.039913403379614465, 0.051188604411436245, 0.019166676211170852, 0.06575647348654456, 0.022415292223740835, 0.00916548206078005, 0.0286019911072799, 0.004213478032397688, 0.019228766141168308, 0.09263726271456107, 0.011330895504215732, 0.04952716582920402, 0.04223697127599735, 0.02631969404319534, 0.05758756866271142, 0.04835177089262288, 0.07312254892894998, 0.05687662087439094, 0.02283259258547332, 0.022447881783591583, 0.06732000794727355, 0.021599013271043077, 0.023249154510267545, 0.012151246064604493, 0.02805147523758933, 0.06630106145166792, 0.09345875339931808, 0.03198896571120713, 0.04814551321032923, 0.05130636098328978, 0.07313298352528363, 0.018898631024057977, 0.03301144854049198, 0.07964873584569432, 0.018785112115438096, 0.03783667380048428, 0.01839358654251555, 0.03591183587559499, 0.03170069328916725, 0.019883993481926154, 0.04063431821123231, 0.02643394582264591, 0.013866584977222374, 0.0285292439366458, 0.05087074256152846, 0.0194970951997675, 0.03179416307830252, 0.07657788461074233, 0.07918418850749731, 0.037336959794629365, 0.06612379205762409, 0.014433660016948124, 0.03810778776824009, 0.01613686759810662, 0.006350053008645773, 0.048591733211651444, 0.031708526657894254, 0.029149653419153765, 0.04351801464508753, 0.06447528910939582, 0.05900118929275777, 0.028775590581062716, 0.013635230643558316, 0.058532819894026034, 0.01153009443441988, 0.09115351655054837, 0.04858535074163228, 0.026476374405319802, 0.04748185878270306, 0.019676982519740704, 0.08827664045384154, 0.047470322097069584, 0.038843541842652485, 0.04889871888735797, 0.04113624381716363, 0.036528148702927865, 0.030451578968495596, 0.023867035124567337, 0.008956728906923672, 0.03925347082258668, 0.021108696710143704, 0.06880962449940853, 0.0296426342902123, 0.01046882882292266, 0.07960366521729156, 0.047458481130888686, 0.039988545831874944, 0.01107803002014407, 0.028602395577763673, 0.009255976765416563, 0.03873639056109823, 0.05651309838867746, 0.025247748926631175, 0.04154258822381962, 0.061189114858279936, 0.02852032888768008, 0.01627332629141165, 0.016500540368724614, 0.06531244653160684, 0.013701338375540217, 0.05367486592149362, 0.037759119368274696, 0.06466757957241498, 0.058172622229903936, 0.0643495618714951, 0.060802552397944964, 0.05362834439438302, 0.024747725074121263, 0.04038539445900824, 0.01634037933399668, 0.0035167157011528616, 0.01832780813856516, 0.03942897019442171, 0.06528748810524121, 0.12150960523285903, 0.021042645566922147, 0.03822376318566967, 0.025342793924210127, 0.06736386887496337, 0.03481351297523361, 0.0074903313725371845, 0.03170434836647473, 0.0139722148560395, 0.023960269281815272, 0.03710227414558176, 0.04995409370167181, 0.12990239745704457, 0.0396815861313371, 0.07386437748209573, 0.044167727828607894, 0.04251209655194543, 0.021854575534234755, 0.046282147377496585, 0.018221833161078393, 0.0449739042960573, 0.03584347294236068, 0.07899490374256857, 0.01944135619851295, 0.01953627132024849, 0.06130306050181389, 0.0555138781783171, 0.04107313900021836, 0.020675568193837535, 0.026243892934871837, 0.02292547607794404, 0.040251960017485544, 0.030681691132485867, 0.08413453615503386, 0.011913538019143743, 0.01778157446096884, 0.011033095761376899, 0.08217918482841924, 0.058351654224679805, 0.12278554262593389, 0.02921123683336191, 0.021318294056982268, 0.032919002915150486, 0.06084261724026874, 0.04734497706522234, 0.009734074792504543, 0.0210998892725911, 0.013348887805477716, 0.06373419528244995, 0.024337412032764405, 0.02957297816465143, 0.0048856249486561865, 0.12801378004951403, 0.02477006371918833, 0.10150559348403476, 0.02233717004855862, 0.031063995520526078, 0.02725651447690325, 0.03699106331623625, 0.03515622564009391, 0.009667449412518181, 0.06483719742391258, 0.06318171828752384, 0.0012725916985800723, 0.06746439277776517, 0.03677941393107176, 0.04705055594968144, 0.0498309751128545, 0.027202161436434835, 0.0398946493078256, 0.05135243722179439, 0.05197203776333481, 0.042960502178175375, 0.07351232488872483, 0.03956542146624997, 0.043386851175455377, 0.027804258425021544, 0.035159665494575165, 0.039417626467184164, 0.0297911176312482, 0.10531589839956723, 0.015071668603923172, 0.027598427477641962, 0.053916171527816914, 0.0035996558062834083, 0.027315392762830015, 0.018727616079559084, 0.08597976760938764, 0.0963437782775145, 0.03878114577673841, 0.025776334332476836, 0.003181158731422329, 0.007853397437429521, 0.02155395006411709, 0.06960616417927667, 0.02286355313117383, 0.039032926797517575, 0.07296719515579753, 0.01744331468216842, 0.04066041212354321, 0.023102734339772724, 0.06904794296133332, 0.07212491691461764, 0.03655755630461499, 0.017627461929805577, 0.01640610022150213, 0.046640786531497724, 0.05317131130141206, 0.03342788986628875, 0.06763412937289104, 0.06977269469643943, 0.013734352814935846, 0.06526800672872923, 0.01938603279995732, 0.048010475729824975, 0.04565241280943155, 0.07305571853066795, 0.01743500448355917, 0.0798553200729657, 0.02562476736784447, 0.05742710520280525, 0.03087244349444518, 0.05775213248853106, 0.016244250800809823, 0.034959367258124985, 0.03311087406473234, 0.025874531602312345, 0.02744656736467732, 0.01422470462784986, 0.031295848020818084, 0.0426070283720037, 0.043590830464381725, 0.0173061231180327, 0.028394148939696606, 0.02496825054549845, 0.022870983884786256, 0.022116843101684935, 0.015050537804199848, 0.030161525392031763, 0.08224845689255744, 0.04729532367491629, 0.03312072978587821, 0.00599206091465021, 0.01908525147882756, 0.02496984801837243, 0.03858963827951811, 0.012025380601698998, 0.024503525091859046, 0.04336499492637813, 0.06005730996548664, 0.02033389453572454, 0.025080734158109408, 0.012429279631760437, 0.04224660435284022, 0.058747118746396154, 0.1824559672968462, 0.19835939048789442, 0.0844726363720838, 0.14696827623993158, 0.08428820525296032, 0.14741706778295338, 0.07249748246977106, 0.16938756307354197, 0.1276938253431581, 0.16969956195680425, 0.13215233688242733, 0.14009986276505515, 0.17110186483478174, 0.13796790997730568, 0.19117403542622924, 0.1489805948222056, 0.10861726070288569, 0.10998022233252414, 0.08813795531750657, 0.1056766341207549, 0.15930526424199343, 0.17857066093711182, 0.1716714186477475, 0.1477332375361584, 0.12647088471567258, 0.19285957154352218, 0.15824774833163247, 0.129263749695383, 0.13326422253157943, 0.13323818799108267, 0.1468283517169766, 0.09812108095502481, 0.21899514802498743, 0.295033892034553, 0.09029136359458789, 0.14085104980040342, 0.10459016702952795, 0.17295346391620114, 0.08364395427634008, 0.12417465753969736, 0.16669307718984783, 0.1596306069404818, 0.27812471031211317, 0.155175672553014, 0.14323815295938402, 0.06802406118367799, 0.20656524313380942, 0.17598124832147732, 0.22766993410186842, 0.14905832736985758, 0.14057267020689324, 0.11369929503416643, 0.13589570007752627, 0.12501738849096, 0.1523289128090255, 0.08154429975547828, 0.1258317322935909, 0.0670059904223308, 0.2372827651561238, 0.12666724214795977, 0.24030008527915925, 0.17425827827537432, 0.13391606567893177, 0.1568726377445273, 0.2281853705062531, 0.1495629729470238, 0.0831249332986772, 0.10443163686431944, 0.16035028238547966, 0.16637292952509597, 0.19033819902688265, 0.11943832301767543, 0.174761543457862, 0.19214304280467331, 0.17494998959591612, 0.24796645593596622, 0.1516881276620552, 0.1280454549123533, 0.12294793938053772, 0.12941342603880912, 0.10519195973756723, 0.120173420291394, 0.11676282869302668, 0.14358378597535193, 0.14477056916803122, 0.153202569053974, 0.13116539921611547, 0.18469394330168143, 0.16760061989771202, 0.13795694103464484, 0.2078522607916966, 0.1302364974981174, 0.23617770726559684, 0.12201969817397185, 0.1373178034555167, 0.19606164190918207, 0.20089792145881802, 0.1736496578087099, 0.1798406388843432, 0.10441930979141034, 0.14630371268140152, 0.18034994514891878, 0.11208423326024786, 0.18838137824786827, 0.1279588759643957, 0.08043809153605253, 0.1040043008106295, 0.091271428973414, 0.1515780226327479, 0.17149419378256425, 0.1794406064436771, 0.13657302857609466, 0.11485585797345266, 0.13909465342294425, 0.13683794561075047, 0.21116504474775866, 0.14685118017951027, 0.08987299268483184, 0.0995667178358417, 0.0565619799453998, 0.10520069481572136, 0.2591697539901361, 0.14180696569383144, 0.14295086759375408, 0.12708277063211426, 0.12809905281756073, 0.12744606676278636, 0.1375889396877028, 0.17974129499634728, 0.17832536628702655, 0.18144743313314393, 0.21203586598858237, 0.0899575233052019, 0.12428269939846359, 0.12511940411059186, 0.1685501533211209, 0.10736877535237, 0.14609712845413014, 0.11202644964214414, 0.16397190367570147, 0.09184540598653257, 0.21716982097132131, 0.1251204579602927, 0.1687824010150507, 0.17333538795355707, 0.13549304043408483, 0.2702577965101227, 0.09906254723318852, 0.30110181018244475, 0.12086749164154753, 0.1306527087581344, 0.17379502969561145, 0.1617582849576138, 0.1811404066393152, 0.09239539678674191, 0.04368670481198933, 0.14885996613884345, 0.09751077581313439, 0.0966674585652072, 0.12375191538012587, 0.1782432253821753, 0.11180823596077971, 0.12695552199147642, 0.128386263968423, 0.16055409098044038, 0.07704531148192473, 0.14864285825751722, 0.16375886276364326, 0.08481638433295302, 0.07890736000263132, 0.24165769602404907, 0.07776123908115551, 0.06909100236953236, 0.08459748787572607, 0.13721596595132723, 0.12305740616284311], [0.04954480296873953, 0.04030101597891189, 0.03825275147391949, 0.05510280629096087, 0.03103308321442455, 0.10156734017073177, 0.022808983012509998, 0.02448521445330698, 0.009897520758386236, 0.03694194427225739, 0.030470167912426405, 0.07591854577185586, 0.06683065803372301, 0.030140882554405835, 0.06140424120530952, 0.03008550535014365, 0.049865221517393366, 0.03157374150760006, 0.05526980436115991, 0.008077736620180076, 0.02012164957704954, 0.029975598845339846, 0.03116779786068946, 0.021796600813104305, 0.01745654717524303, 0.03076456305279862, 0.012564078697323566, 0.05035918016801588, 0.028043022175552323, 0.005477850909301196, 0.017009653674904257, 0.04454930676729418, 0.01984425889531849, 0.008148428969434462, 0.03342603820783552, 0.07929407831397839, 0.04064798114995938, 0.028721766320813913, 0.06089708345825784, 0.03047680642339401, 0.037444715926540084, 0.022788575806771405, 0.08287304837722331, 0.041594520007492974, 0.028863297593488824, 0.012991453713766532, 0.041719319560797885, 0.0082581286005734, 0.06590201606741175, 0.02584061545348959, 0.08153728645993397, 0.016130084368342068, 0.013849452498106984, 0.018542513316788245, 0.026578339929983485, 0.026993784922524355, 0.05211746160057373, 0.06113035160524305, 0.028885242900287267, 0.03022527031134814, 0.0770849124819506, 0.0634260184597224, 0.02773861360765295, 0.03908994600351434, 0.05120828245708253, 0.03692445927299559, 0.07818953250534832, 0.04774653833010234, 0.01030006629662239, 0.13162805407773703, 0.048321743597625755, 0.03790699971432332, 0.03057991856621811, 0.08599268840043806, 0.038001219072612, 0.044343364497763105, 0.03131594909064006, 0.09470159842749126, 0.09700299837277271, 0.04557314401608892, 0.02251833757327404, 0.07375424276688136, 0.013942875903012464, 0.10196549497777596, 0.09214680700097233, 0.022054725341149606, 0.020271780485927593, 0.01841276178311091, 0.016680266271578148, 0.03741835484106559, 0.06896044375025667, 0.04274421065929346, 0.10045089773484506, 0.04561629248200916, 0.09160915069514886, 0.0025996607473643962, 0.06089122049161233, 0.12435542987077497, 0.05087696546979714, 0.0260417040772154, 0.028834346412622835, 0.05391412691096775, 0.02290943084517494, 0.029539989700424485, 0.02221541330072796, 0.034774988089338876, 0.0016485187188663986, 0.03395586485567037, 0.03497101897664834, 0.007318929119719542, 0.03366659795574378, 0.036493720472208224, 0.03324888755741995, 0.08247138321166858, 0.08665870656841435, 0.017648887733230367, 0.04564013397612143, 0.0522533154435223, 0.023951369075803086, 0.04217460118525196, 0.05105319585709367, 0.03221883853257168, 0.017421582742827013, 0.09248123358702287, 0.04641004168661311, 0.03134610997221898, 0.10874060564674437, 0.01863624100224115, 0.02155664962629089, 0.02745837307884358, 0.04848644101002719, 0.04140496064792387, 0.006053348397472291, 0.025551847647875547, 0.017597516271052882, 0.021739757867180742, 0.013747832072112942, 0.020684036098828074, 0.007496484240618884, 0.010754431368695805, 0.02122522873833077, 0.0561349667259492, 0.02620208961161552, 0.036211511396686547, 0.04262654314516112, 0.06564804571098648, 0.04809703983482905, 0.07910687156254426, 0.033855745423352346, 0.008511929190717638, 0.01472789837862365, 0.03362608411407564, 0.044991619361098856, 0.0281071659992449, 0.027382642474549357, 0.05755912214226555, 0.011615383900789311, 0.0745537065085955, 0.043627173436107114, 0.0545557655277662, 0.0475924870261224, 0.058100311071029864, 0.05449931777548045, 0.07324872145545669, 0.01141940589150181, 0.03674463318020571, 0.051006655776291154, 0.011957094666286139, 0.025216582434950396, 0.014293195581558393, 0.0337569804105442, 0.053827236260985956, 0.04240571339323651, 0.021724133803218137, 0.05343687029380817, 0.04856922758335713, 0.04519092311966233, 0.0508456134411972, 0.04122156482480932, 0.047379368188558146, 0.07590676788822748, 0.024375638204219285, 0.04883672729192767, 0.03866240585921332, 0.037986706374795176, 0.019401898061914835, 0.012129441765864613, 0.024493767705280334, 0.11150862352224067, 0.03842995778541081, 0.06659159000264481, 0.05008124957385007, 0.010774871043395251, 0.08625797650893219, 0.0733745822799392, 0.052946425712434575, 0.05957121065875981, 0.06415537893190049, 0.053075782052474096, 0.04193614542600699, 0.03563915226550307, 0.03330842264404055, 0.06774397465051152, 0.05198721839406062, 0.021648943111358676, 0.03537591990607325, 0.028872585571662057, 0.03866764913254883, 0.05837457545567304, 0.0013882017242394795, 0.07681848146603443, 0.06111959046393167, 0.036219552566763014, 0.06877760082716122, 0.07057135691866279, 0.032545201684115455, 0.07926036254502833, 0.008535008128092159, 0.07811240109731443, 0.04215271896100603, 0.047498338171863, 0.04139035889238585, 0.05167129354958888, 0.012433653664629674, 0.061927533242851496, 0.036468142352532595, 0.0932310773350764, 0.02208985675679287, 0.03260507444792893, 0.050136691716033965, 0.038174963265191764, 0.04156720155151561, 0.037831953741260804, 0.022311159627861343, 0.030542935492121615, 0.03496229874144774, 0.0755092513281852, 0.055647646586294286, 0.0085836670405115, 0.00797502802015515, 0.03765011271752883, 0.03074870150157949, 0.01501378943430609, 0.011522288896230748, 0.08006685442524031, 0.10155060474062338, 0.016253952526312787, 0.032200448113144375, 0.03304917561763432, 0.06474619527580217, 0.029870236139686313, 0.009869603018159978, 0.012784046630258672, 0.0833656637405511, 0.00699867384355457, 0.059294237435096875, 0.053446607271325774, 0.018955607556563336, 0.03281598168541677, 0.0948388066899497, 0.07141269263229333, 0.03122110261756461, 0.0160799040531856, 0.04012261109892279, 0.02080760368698975, 0.07943828502902761, 0.044927434719284065, 0.041044603422051296, 0.08788497201749124, 0.043924637357122265, 0.024342601500393357, 0.04846986514166929, 0.06115946976933628, 0.013991415144118946, 0.018838804644474294, 0.03191988660546485, 0.07615630762302317, 0.039507930996478535, 0.02912978241511155, 0.07256943368702196, 0.03560980774636846, 0.015273560602508951, 0.03602938464609906, 0.01798867633624468, 0.021288430034474004, 0.05950972743448801, 0.057753857981879264, 0.0044792680182581535, 0.044922658998984843, 0.041244129824917763, 0.029651451004610863, 0.09167116455500945, 0.0783888807927724, 0.0956085548386909, 0.050941209483426064, 0.09363622317323461, 0.012372604596748715, 0.025599205946491566, 0.010192248937528348, 0.02816566950059496, 0.028088035287510138, 0.049392054133932106, 0.02756425157713238, 0.02738440136454301, 0.030013964169484098, 0.05294030299410224, 0.038715725459042005, 0.010000776692322688, 0.04047409223858267, 0.03956090920837596, 0.007647681986782118, 0.0349551147519378, 0.033518806667416357, 0.018711769371293485, 0.02900708499510074, 0.047452009603148326, 0.04425262210133951, 0.07576806790893897, 0.04684156345319934, 0.013374583741097013, 0.0347542673262069, 0.0659992745204363, 0.05203799613809679, 0.08300834189867601, 0.039953991436050273, 0.015598528516420629, 0.020778802791028284, 0.03035772326256847, 0.028691056249954272, 0.05248142566415481, 0.04158397779974621, 0.04970539259375073, 0.012374254947644658, 0.035759320817305706, 0.025947310314222705, 0.02361544335144572, 0.03442325090873055, 0.00582006262447976, 0.013920354504080024, 0.06932396994670853, 0.02644074946147157, 0.014073492038733093, 0.032689705258235335, 0.04569335709675215, 0.04800603026524186, 0.015538605657638982, 0.06917289094417356, 0.05868591011676472, 0.051137778427801095, 0.0329475050966721, 0.06995386036578566, 0.04972649927367456, 0.12713089148746803, 0.06879234730149619, 0.10606618001474999, 0.10856174805667251, 0.09252404066501185, 0.31404459848999977, 0.1132975408108905, 0.1216134762216825, 0.15536140243057162, 0.14467958186287433, 0.17451506137149408, 0.1357215180178173, 0.2015005305293016, 0.15199087938526645, 0.13777438754914328, 0.22365889308275655, 0.10727482687798329, 0.15149021171964705, 0.10779818941955455, 0.10155597046832554, 0.09766924660652876, 0.14853935834253207, 0.2234216729993932, 0.08766973434831016, 0.20886604936094955, 0.09413595573278144, 0.18416445062030107, 0.18481869832612574, 0.11898027689312585, 0.0872751121642068, 0.12579956761328503, 0.13163951283786446, 0.20813795796129853, 0.09172381993266754, 0.09978226720704697, 0.21642783656716347, 0.12065398317645304, 0.19302226515719667, 0.1654114475240931, 0.09745852119522169, 0.13129212835337967, 0.07562435101135634, 0.17205512383952737, 0.16658132459269837, 0.15266510570654646, 0.09350258464110084, 0.23194320558104664, 0.09888745233183727, 0.1556455114041455, 0.0997996557271108, 0.15953006077324972, 0.04150114669755567, 0.07511672942200676, 0.10777184317703359, 0.1652202257537283, 0.08075756384641863, 0.18695734528591856, 0.1268334238557145, 0.13000969716813415, 0.11752295860787854, 0.19579752639401704, 0.15421122196130455, 0.08623325556982309, 0.12483864964451641, 0.07642477954505011, 0.11507115501444787, 0.1972148651839234, 0.07199143423349597, 0.1815005115349777, 0.15867967827944085, 0.1457861388917081, 0.07660600458621047, 0.09770758595550433, 0.18309970619156957, 0.2674340136582032, 0.11192395904799923, 0.11968179940595292, 0.2493494184454903, 0.2473019517492503, 0.21006066963309422, 0.18795326293911785, 0.18316109664738178, 0.12452558206859976, 0.2223307901294902, 0.29905746050644666, 0.10917551160673611, 0.12965278350748122, 0.14944540191208944, 0.07324481033720076, 0.1517192236497067, 0.2161697472911328, 0.12848615704569966, 0.16744919208576903, 0.07308802421903238, 0.16916852560825646, 0.20769777533132583, 0.12557499372633174, 0.18525374529417604, 0.11541383428266272, 0.2151224878616631, 0.181402844900731, 0.1679721983964555, 0.07077202622895129, 0.1420271905953996, 0.13053469243459404, 0.119898276461754, 0.10693449279642664, 0.16491990827489644, 0.08668848895467818, 0.10169747576583177, 0.21853630780242383, 0.12502782308729365, 0.09681164301582612, 0.3069931565551087, 0.12550046725664288, 0.17218924476765096, 0.15271215786924586, 0.17995633970713243, 0.12407333953888156, 0.13925866805948317, 0.15492365404497832, 0.11755544241168536, 0.12893344945041463, 0.12690725270658731, 0.15267135458998382, 0.09869286863249727, 0.21319187973858789, 0.12850174214690924, 0.08304443254019134, 0.1400582876522094, 0.08641097767394967, 0.19525541720213369, 0.10112024072441272, 0.09641251599532552, 0.14463367260759696, 0.10806222329847515, 0.06365638109855354, 0.06594768783543259, 0.20026752637932077, 0.1399050044710748, 0.11749334691558033, 0.15001679625129327, 0.1740868273191154, 0.14860465249512345, 0.14984769048169255, 0.12898514745756984, 0.1320480354479514, 0.15807775198481977, 0.12885543488664553, 0.12737746263155714, 0.1632802071981132, 0.17346306703984737, 0.13915328308939934, 0.11772431069402955, 0.13550598348956555, 0.14553829125361517, 0.1261253556003794, 0.2115332687390037, 0.1328708545770496, 0.11631085333647206, 0.14641126472270116, 0.1288604666478932, 0.16276756126899272, 0.11358506366377696, 0.09802218977711163, 0.14238806732464582, 0.1236750882526394, 0.09346463120891713, 0.1633488855441101, 0.10430667403852567, 0.13810272852424532, 0.18318849673960358, 0.14198531862348318, 0.09434236926608719, 0.1308208200498484, 0.16181675135158002], [0.04992340960598085, 0.0282494078783202, 0.04667567860451527, 0.01250194238309632, 0.03812867922533769, 0.061867779222666286, 0.05098034664115403, 0.07605357954162173, 0.05662328134349082, 0.048830671366886236, 0.018137640217901208, 0.03187877533491701, 0.04148183601500932, 0.001821944135826925, 0.014065265331737464, 0.010570386166364187, 0.02866487699066056, 0.09291738635511138, 0.04983642247680109, 0.041161758854286745, 0.027357852886780165, 0.033111679294961505, 0.09682871983386576, 0.05302387995470781, 0.03876778340782039, 0.020476590980251785, 0.0719976905384101, 0.011545284341991646, 0.0094936653295008, 0.048551167419645935, 0.02458438579196809, 0.06740724740666337, 0.04633174881746527, 0.05180406747967936, 0.039248234970727935, 0.02517032808100339, 0.06251280574360862, 0.017460844210290816, 0.04820082918740809, 0.02321947416930925, 0.059538533896557055, 0.013392543714871863, 0.06327218608930707, 0.03691390222229529, 0.03704647577251308, 0.0274683939278475, 0.05191137461224571, 0.0676788660348393, 0.010132250008609844, 0.041150559845846146, 0.032214378225035034, 0.03205578126653563, 0.023499981871282216, 0.013363631496758899, 0.038117194490041584, 0.002855923412425909, 0.03879674201016314, 0.022124097595224157, 0.06984088322496973, 0.024399338690272998, 0.019904389555449598, 0.0808763520035427, 0.072287773800781, 0.05260830694169272, 0.026475977356312796, 0.054549657652387396, 0.03711857170856092, 0.03250609792303294, 0.0267616114433622, 0.006363728007272584, 0.020638746536860708, 0.044654702869593166, 0.04956356446200516, 0.0731416666531004, 0.03286774648586288, 0.0568215646489989, 0.0671176465402823, 0.008784398505667923, 0.06584034359548241, 0.058032846136484295, 0.021230110214673914, 0.06240164686460048, 0.036858077874057926, 0.07052364424453117, 0.047451297141378745, 0.020862826895609032, 0.06601957968086936, 0.05190603114897385, 0.10157893993891776, 0.02000177602894837, 0.046973446806077845, 0.03033160523045808, 0.04797748726559803, 0.05498680860910099, 0.05406863092503045, 0.014337383054225938, 0.03837877186015248, 0.0219839931014576, 0.04261560759914573, 0.07093359177815728, 0.01700185184745351, 0.05105443524371367, 0.02308349601662485, 0.04130498964514118, 0.056739301289781, 0.01000371559712221, 0.05148794225533493, 0.01067908668119344, 0.015020498449302977, 0.0355660655623069, 0.0530576773599023, 0.017750545266608242, 0.04622302047209814, 0.053612098781741224, 0.06382136794854887, 0.06886434304760769, 0.03666435135528445, 0.05405775475082919, 0.11465774907264858, 0.10571511447778903, 0.06163775055028964, 0.020386709475133102, 0.03676264881505631, 0.04066208937729243, 0.010924131784122437, 0.0482686392206233, 0.04987490283383522, 0.03334960441861767, 0.036859465690213256, 0.040741951888776384, 0.0264600861191866, 0.014922317877790192, 0.05708129778213333, 0.05625281606626231, 0.011877515098603908, 0.040023100227699615, 0.05514162432518788, 0.028960717463633046, 0.02167692578950664, 0.03692041827889625, 0.013633314974867972, 0.01778564699634444, 0.005084261701995274, 0.030272036747192033, 0.040690116584300995, 0.028107653961342294, 0.047937834315234795, 0.0322610184957739, 0.051582729356596246, 0.046077544684521854, 0.060307740277494304, 0.05035399255575612, 0.061358127859421074, 0.07118043009540997, 0.0529511346394429, 0.06293836064287461, 0.07743516907794401, 0.019323143205838278, 0.04888013550953474, 0.009762888676050352, 0.02274794507684419, 0.07178072366514243, 0.042282216309104115, 0.009177727497444721, 0.04089363203092944, 0.019571384182199836, 0.029098860832164064, 0.04701655816461425, 0.01885766632767627, 0.03697933367220685, 0.06282835951424204, 0.05753669443947729, 0.07186229311628267, 0.022047083075449336, 0.017042278486769646, 0.04265908632078208, 0.06137548669357784, 0.05748292212956585, 0.04544413277471904, 0.0009856545625552826, 0.022929739716346376, 0.03905135432432871, 0.017528182979731355, 0.06443301637773402, 0.06756541391951032, 0.07393661813694052, 0.06272615835769102, 0.05833084440382663, 0.02760696403129259, 0.03518580022500828, 0.0430625697481446, 0.03833657334325835, 0.035347718294360675, 0.059949765345663764, 0.0528480874345405, 0.06864965456770733, 0.07280375197296962, 0.034654170158319175, 0.028070646767446306, 0.008522186599293491, 0.09679120426881127, 0.04575167506118305, 0.016981589360511862, 0.0206784087640699, 0.06474787995102815, 0.030124080331006553, 0.11986858313321136, 0.03668830046080984, 0.0328423353494145, 0.0065796220133051975, 0.03929121645342093, 0.02202275732997805, 0.0408201185928192, 0.028723016839649063, 0.03290964072220959, 0.018713572790147737, 0.025288396354881115, 0.053568423390970565, 0.02997118492203299, 0.01836479306803085, 0.02642868956172606, 0.05616299393295776, 0.10999741047271527, 0.06643744593020529, 0.029193299124017358, 0.04218620095343795, 0.013732903771597194, 0.07230206014355645, 0.02811617752740858, 0.05696873995475471, 0.05059645962319337, 0.053264833040884696, 0.05356070876587182, 0.02687882810278097, 0.04329629060521256, 0.018180959377787076, 0.046763359641772695, 0.01270307089725975, 0.0497331303631654, 0.0257819635226042, 0.05835441130329855, 0.0945403148944024, 0.046794848967692815, 0.016222344456764404, 0.0255647610174492, 0.005228554691711906, 0.023347711721726228, 0.07469266623957083, 0.02927802641352173, 0.0319838152063312, 0.011784766120399581, 0.05091916027595289, 0.06268717334023677, 0.05330981090082787, 0.039717706458759494, 0.01730339015921345, 0.03712688747327775, 0.0732435412646737, 0.03535451636707876, 0.04762488177220803, 0.07982792740222067, 0.03172884666128084, 0.04360863829788286, 0.02439811229123734, 0.026817227990250103, 0.043887307328986935, 0.04748671984998509, 0.02739868770731846, 0.08000547139090486, 0.02995526770973811, 0.066532411146909, 0.014699454641231569, 0.009934489917213796, 0.08675494827912189, 0.01424187885277206, 0.04720005046692677, 0.06913570192409679, 0.026678014073695522, 0.0013119095228830702, 0.030178511296981014, 0.004211178766126977, 0.02308534581970889, 0.025194043410010636, 0.03771831237827428, 0.010263735384796746, 0.08393490585149266, 0.11749066034099087, 0.048872843908611685, 0.011141405720991315, 0.033688647163216956, 0.0847042235545814, 0.02234791078080889, 0.053908289919490926, 0.021605314104817808, 0.032658687196089886, 0.016223611673922278, 0.17366522806696594, 0.05187346941966098, 0.029002318551647477, 0.02374719497311162, 0.02451493746775668, 0.09806419533560984, 0.042937161633744836, 0.00273310655302339, 0.03786152090469841, 0.0683915356057696, 0.0284014980570646, 0.0137018291206914, 0.035636358079500496, 0.07972597857587971, 0.10076722333906218, 0.024380139329878148, 0.033124670590041205, 0.07027308776741847, 0.0650844736082945, 0.02957256256195251, 0.07371161380433477, 0.028653099107032176, 0.02705878778215265, 0.026021159574156627, 0.07682235547690652, 0.00502198113281338, 0.013569546863436699, 0.030909170527593233, 0.06177448754897341, 0.023305479808186647, 0.09766245595528744, 0.022975079373281915, 0.08889668999472633, 0.1035591161053162, 0.04075159609783441, 0.012366486516839359, 0.0819043823867105, 0.04613743971276563, 0.02497402445442276, 0.043661546005751006, 0.05547386157559231, 0.030362627003341913, 0.04095266245712992, 0.04675400487030856, 0.028689507016679272, 0.012130729392083595, 0.03279048891272396, 0.03720263106515631, 0.038241259317146614, 0.05814725191157777, 0.036515881001832895, 0.07447083087754436, 0.021301766428223345, 0.045225299400044605, 0.009314743729191832, 0.020282400619180407, 0.2438864842406474, 0.1510301692178473, 0.09598849734175019, 0.10329817698220722, 0.147704427363351, 0.1658032718114555, 0.10620251996442676, 0.1967921230243519, 0.1711084699491039, 0.09724230389110744, 0.11226136906770989, 0.18244317267090082, 0.1263297430705279, 0.11995459062745795, 0.12802357639884576, 0.14079359272727743, 0.14539039606461301, 0.22234037867747247, 0.23589724965859205, 0.2973733493126929, 0.16616610781056806, 0.10908404932706617, 0.1252425560960546, 0.18502412480302155, 0.20158862345851958, 0.09802443848457187, 0.15606659115292132, 0.11774778482504189, 0.1477844754117541, 0.11179377150256187, 0.14151369861792773, 0.14025517943082377, 0.15291293850168586, 0.111110928846756, 0.10399058592156507, 0.1108258476597257, 0.13367146864766255, 0.09736104751937091, 0.1555902065592818, 0.10656898506567813, 0.18358909321250394, 0.11762959038605914, 0.11295037154923193, 0.1507435814710334, 0.134938552218955, 0.10669316863641143, 0.15738638205220923, 0.17663660924881697, 0.12499987380579114, 0.12724818050628528, 0.12762413767632097, 0.1252943283179775, 0.09892266723909415, 0.13710446568438783, 0.08492798850056715, 0.12537231319583952, 0.1146585876995232, 0.07815607648808509, 0.09687379788374528, 0.1345610959106125, 0.16648779914248735, 0.18022621428826824, 0.13966649305075407, 0.1376594734028913, 0.13017393444897607, 0.27357801678590477, 0.13607748172944412, 0.1053578000573907, 0.21607144240988418, 0.13615892501547933, 0.15013936936156824, 0.2331237992621027, 0.13496543280780315, 0.14092287485254928, 0.14152272313367575, 0.1341713941656053, 0.1491844331030734, 0.13772516831522807, 0.15780201443703845, 0.09557492812746204, 0.1626972947269678, 0.2196582272881642, 0.15065505809616297, 0.14048879267647862, 0.1289857114898041, 0.07787791211740114, 0.22608001629123464, 0.16280600451864302, 0.1449220860376954, 0.06856277876067907, 0.22036222857423127, 0.17433464527130127, 0.20076157408766448, 0.08135220225085504, 0.1673097870661877, 0.05878163232409861, 0.14667086797999218, 0.18724605557508767, 0.08351968906936236, 0.14608332450734451, 0.16868768812855706, 0.17744327924447134, 0.13508085161447525, 0.10862096401979215, 0.12652881676331162, 0.05391878017690033, 0.09083315366297029, 0.11710574544849806, 0.11375968359061517, 0.14186561020324007, 0.20770956063643098, 0.13518626627046615, 0.18955383799038827, 0.1132353043067269, 0.19941310660215095, 0.07501533720642328, 0.12068936135619879, 0.20043562282808125, 0.19922709470847622, 0.15736824396299198, 0.3395660180831328, 0.13663039659149945, 0.14998716971604154, 0.07111844592145644, 0.10454346367623657, 0.16016148001654074, 0.11283307510893792, 0.13146190205588937, 0.1322429085848853, 0.10286157150403596, 0.12888347322586924, 0.058166447561234236, 0.140179569425527, 0.17782854294637218, 0.24812019924866036, 0.1262350004981272, 0.1251597175723873, 0.10073839832330123, 0.21561735193245113, 0.14330151752801612, 0.1915172193548642, 0.10873759994865395, 0.101558657042915, 0.11306220578262582, 0.23746999417198822, 0.08402947030845098, 0.09638399526011199, 0.11996074303169735, 0.11665602622088045, 0.12523602519650012, 0.16778324759798124, 0.12094017016352154, 0.16959054046310484, 0.23023065528832376, 0.1475659426068887, 0.12430849645170383, 0.2155221492284909, 0.10145681211724877, 0.1641515627852641, 0.13410414074314758, 0.15597066114423797, 0.17415842972695827, 0.23197398986667395, 0.13416518981102854, 0.1463110451004468, 0.07742476416751742, 0.15773011517012492, 0.08879977292963304, 0.0890317237644922, 0.0959532824344933, 0.18501444719731808, 0.1700717193307355, 0.1854995297617279, 0.1507696753833443, 0.09734745137393475, 0.14331048267195], [0.014098787214607, 0.013845089597452898, 0.00607111402132432, 0.0596614446840249, 0.03705754119437188, 0.028815340010623913, 0.03943181633076165, 0.049783525901148096, 0.023639373903279193, 0.014470258101937361, 0.02230090871307766, 0.05152753212314565, 0.05670576363627333, 0.05574470094870776, 0.06699148143525235, 0.0518820300931111, 0.06731361063430086, 0.017630018628551625, 0.028255306096980348, 0.06663341002422385, 0.05475914367707446, 0.02282089633808937, 0.01468438254960347, 0.04453294612176251, 0.033285226818406954, 0.011386169735487783, 0.018400683329673484, 0.07526426838012412, 0.0661715047317557, 0.0547743836796144, 0.03296749484434258, 0.09640491640311666, 0.03433597805269528, 0.03908802755177021, 0.021732395762228407, 0.1121992661501281, 0.01602734329935629, 0.05217605044890661, 0.04699548488133587, 0.04851996753131971, 0.016820842029119376, 0.06852372694993392, 0.008153505259542726, 0.027259364323981572, 0.06543004725244828, 0.05077958827314433, 0.03202136045729276, 0.03902821415977087, 0.018267887135152705, 0.048825691555975936, 0.0602031011658255, 0.005302297731759609, 0.03054042888834374, 0.09528175010927953, 0.03985953087976668, 0.0019284470818092814, 0.04214164240693208, 0.02434424535749713, 0.03702390706166625, 0.0475503701454727, 0.08039796361117624, 0.029666375594388228, 0.03418101019633468, 0.04981150115781929, 0.05025270795158576, 0.014693191842525266, 0.0032459860267408658, 0.0731813492893707, 0.03658788416942116, 0.037744510191259906, 0.09917219213093631, 0.04168118801317178, 0.03169523108226713, 0.05456202554341871, 0.06916155834915116, 0.02683885602891678, 0.043247371941106394, 0.02693635567993624, 0.04453939538507257, 0.026681882518460043, 0.02624895623739576, 0.035230113862780854, 0.055309765302808955, 0.03068955789785832, 0.02270051812956808, 0.10588162273052149, 0.0014624701816501329, 0.05918142356676981, 0.0637545895006042, 0.012477014570322353, 0.0513562852574978, 0.047418727990589105, 0.027012780192308128, 0.03853527225146536, 0.023590705714013893, 0.05248208617558703, 0.05940126997302286, 0.013962086395622464, 0.05425922186987009, 0.05111902435601223, 0.037395808394649066, 0.010731794009188889, 0.04377691657282412, 0.018951752099383157, 0.04726278049929533, 0.04406400526931975, 0.0536806472518947, 0.019501716924423818, 0.01495352889833157, 0.009852426937868586, 0.021839979344804306, 0.033589221638976596, 0.054788881534477696, 0.05172548888367601, 0.03739121450053062, 0.026661300908017438, 0.012508860127127264, 0.04530017467914149, 0.05033935740357265, 0.04980161946150474, 0.05827448570926208, 0.10628292424371466, 0.04010044314782135, 0.05488965776748955, 0.028617383250093553, 0.034474607527954504, 0.0345634685800178, 0.02651810907991603, 0.06809679907746613, 0.046474434129777364, 0.08022480571526103, 0.01860876855062088, 0.05591643763182219, 0.023359734514087904, 0.03166378999594599, 0.03434845355513971, 0.042389456648379564, 0.02235539534012787, 0.03371764287294354, 0.033271192805841565, 0.05072199761343654, 0.04006710587418638, 0.08945718218456022, 0.044943914108444005, 0.07712873630225658, 0.04642561194486916, 0.04975645977538079, 0.022123260823718738, 0.018199490805272944, 0.016769784124335274, 0.016506247484358028, 0.04749194828036707, 0.06384190317476168, 0.03781312916544266, 0.02133598129148595, 0.023153951806307305, 0.016312897605530452, 0.05460366744955536, 0.013590628495876445, 0.043480903550516814, 0.039368626166833565, 0.02312832173629431, 0.026098404159711208, 0.01934994215844199, 0.017833348538260907, 0.05074091866845265, 0.005440394716060837, 0.0323041966476012, 0.08947984737460501, 0.07906979386461899, 0.03861432211124338, 0.021058252932562027, 0.01675129351497162, 0.023474800800613593, 0.045882664126111194, 0.041942969473893754, 0.030103034878266044, 0.012159169418737292, 0.027345414491719566, 0.023834258172428235, 0.06836781656602398, 0.04415317060193047, 0.041381427145097405, 0.03572573492419906, 0.03221845632651821, 0.03524373969412409, 0.029106586589477956, 0.09068421946722083, 0.027324385737301782, 0.031477867159992456, 0.10681450978154317, 0.05040188705606852, 0.11395754016120918, 0.019696937015396543, 0.025055094811250456, 0.05272264221275691, 0.0699486950179562, 0.08487751503707841, 0.10999075340805575, 0.05418637265393045, 0.05518232370377518, 0.05073043212178163, 0.048650960306986235, 0.05338830414984841, 0.0762953118828591, 0.008007695505511947, 0.06216555484570563, 0.05833474438986741, 0.04020436237624381, 0.038933924297452904, 0.03820229285338428, 0.10151469963602722, 0.04679081168433186, 0.07827013716450892, 0.06639758517849259, 0.02701273751881672, 0.03225504049623851, 0.024361637588299345, 0.06307645206106827, 0.03927177589503117, 0.027726052758225705, 0.050723674867185764, 0.03640515998995397, 0.056433091158396564, 0.020176520265522413, 0.032194295708904974, 0.06784854325815104, 0.024231258939835243, 0.0398642620712053, 0.07139635796193033, 0.05856211617356166, 0.06606212700717151, 0.015282759522960987, 0.07366613499470986, 0.03500793711282313, 0.008488691619277233, 0.03818769851932302, 0.027509885549079627, 0.026539766804489773, 0.02560526001616381, 0.03237776574678719, 0.02683732906007208, 0.07463285655830987, 0.03869596577715129, 0.026801609492395073, 0.055748701124684885, 0.03853473790513817, 0.016823537880554795, 0.0510472141468199, 0.06020737964718137, 0.029247310776554514, 0.01425686466973275, 0.023405864558299072, 0.03539613229804672, 0.057971414862549864, 0.03936174645787105, 0.06172880093799904, 0.020503534651652444, 0.012645754832192324, 0.012440482350939419, 0.009198874067806173, 0.06541248061694205, 0.06821810311521403, 0.00990148568234872, 0.07371877552941442, 0.0559792678541271, 0.04406731895869598, 0.08874063118128106, 0.0032322372771886876, 0.026912328648904804, 0.03414279701246414, 0.021304337969922926, 0.04109954461455345, 0.03987858923210297, 0.03826732354355045, 0.0551809247554047, 0.022224636340979487, 0.030792514189670328, 0.03741546788660344, 0.0957661795837339, 0.05202777676458936, 0.0574146556755295, 0.05810954709886573, 0.014777503529330716, 0.02077568948152475, 0.02407006817520596, 0.026368967082817107, 0.03285567545390222, 0.030520090331265237, 0.03354337917699013, 0.06285537368967198, 0.02808261946483981, 0.0460274497163482, 0.08553978535928763, 0.013777365838905098, 0.023048618786560837, 0.07602426470839418, 0.11812976081273519, 0.03188079768733587, 0.06096263736253604, 0.029192501315264963, 0.0804801267804578, 0.0914291873050388, 0.024414882973360363, 0.05990721801936161, 0.032898723729886115, 0.039448681636713445, 0.04110181187570561, 0.04357375735708047, 0.019435925532889087, 0.017304546054219827, 0.06881648936541751, 0.02507196753867902, 0.05088779340439942, 0.06946419132873416, 0.036337661658762954, 0.011244221004744759, 0.013956180755485548, 0.027163898157596122, 0.03321625161333941, 0.07884416612796485, 0.05957399742328562, 0.057471660038572736, 0.01059064958099043, 0.04843576345592737, 0.022566504812857602, 0.043595031020231545, 0.0922212889418006, 0.04024365538498387, 0.032731625469750725, 0.0760916962462943, 0.05955681670457125, 0.026837002515094355, 0.04752162305521779, 0.05998283544613514, 0.031489581961068325, 0.014181606256897794, 0.022414136328734457, 0.033808062435127795, 0.042898647880065255, 0.015116992490220582, 0.041255766700487584, 0.06404934829333797, 0.013501013236236759, 0.04679568017309066, 0.06555971529451199, 0.02812751383316936, 0.09269828209653497, 0.05101901253510732, 0.02462820033542812, 0.03286419159849174, 0.04435517948877532, 0.07617643466801383, 0.07824667045497335, 0.11306728949421085, 0.13815988873830065, 0.1118224480887875, 0.14478032098850235, 0.11253686912823468, 0.08855994790792465, 0.07542601946624927, 0.13952771143522114, 0.08568701261538081, 0.1819230310502462, 0.1520291593624279, 0.10905883857049048, 0.24106630822643638, 0.11882377279107459, 0.2825945767108351, 0.0991216889815405, 0.16166596178663895, 0.12061608169460669, 0.14799451804719865, 0.2888385619735345, 0.21943668136373162, 0.14801920187892392, 0.1515418800408952, 0.10404651417047717, 0.10311635822290555, 0.14885509765008464, 0.24755232268944383, 0.096678746631369, 0.13051817222731188, 0.25044907350093126, 0.13129815459251404, 0.1068741265044082, 0.10704843472922221, 0.26371837710030377, 0.06320541506283917, 0.17745297169312835, 0.09465692113735713, 0.13337756332475692, 0.11789291922468692, 0.1137091507553123, 0.1683119684457779, 0.09542277301079594, 0.1812123355921358, 0.17500823334557936, 0.10677060432499275, 0.12210169807076454, 0.1485811560996808, 0.120526422833791, 0.17640047270106152, 0.11667205661069602, 0.13441032118862495, 0.3652265458367765, 0.16095235710963607, 0.11691448657074943, 0.07778659826726653, 0.22025933722034097, 0.12266670993994921, 0.11901048230356537, 0.09875808114884421, 0.09735154802910984, 0.12521770899184048, 0.21244674862828106, 0.11448263190686703, 0.15774292463902384, 0.1398014006554149, 0.30096472066361457, 0.14111571450484917, 0.1649114626343362, 0.31271817279048264, 0.07246517678140663, 0.15617936791386455, 0.19211420294595882, 0.11482536312541924, 0.11337328440276906, 0.13410479383310303, 0.071872579283081, 0.17559087864356115, 0.3016089939046651, 0.10459910248755477, 0.11154060266562738, 0.12667945789871737, 0.08065470959991217, 0.14165947126457468, 0.1854710461338982, 0.12037460910505615, 0.1141058212670032, 0.09869604502455331, 0.15068092936417088, 0.1673598968773149, 0.21600965119432658, 0.10691864794353023, 0.08546561512048356, 0.0546722901344765, 0.1232251018518582, 0.1059284299844876, 0.09515566664049402, 0.18980806809850037, 0.10019328343332745, 0.12139881000621244, 0.11017305456334725, 0.12399105020449497, 0.12534103909274563, 0.20934060827130452, 0.0928021827712655, 0.17299095721682534, 0.13521795597625896, 0.11548135487828404, 0.12991477648029104, 0.06745397302438505, 0.11332333786413074, 0.15642723039491102, 0.14827271952526644, 0.12444450243492611, 0.1200230760150589, 0.2501897671027109, 0.1985507903737016, 0.13227128831204027, 0.11827073176391423, 0.21168684877920896, 0.22569982887944207, 0.14707380963955075, 0.12044146176776849, 0.14490687201032415, 0.1224145430023782, 0.15858924016356468, 0.10446414293255657, 0.23666725755902007, 0.1047419362294022, 0.12436102566425689, 0.1774128363467753, 0.13611165020847693, 0.07791985088260844, 0.1800114515936002, 0.11200598120922223, 0.10577916182228364, 0.19546465831808746, 0.14886014425428584, 0.11019940822734497, 0.21122030506376177, 0.14992015378084034, 0.12555133405840024, 0.08766131097218022, 0.13616996817290783, 0.10532731263083406, 0.13875583332264796, 0.11176788539160043, 0.07771031290758401, 0.09458952670684084, 0.26342398195993155, 0.13259231171105057, 0.21017258550273255, 0.11863902996992692, 0.1335429138271138, 0.10526178841246292, 0.082360142696416, 0.1700397624517791, 0.1268664642702788, 0.19764050171943381, 0.12769717985065654, 0.07530640010372736, 0.09445752832107246, 0.13583971245680004, 0.15326018939958885, 0.14873809064738452, 0.17632609466090798, 0.10563817602815107, 0.21782513736980036, 0.23058823688188568, 0.10578133631497622, 0.18057451903587207, 0.11823320877738297, 0.057641719467937946, 0.1433955624816008, 0.10456007294123992], [0.04021812550490722, 0.02565492453868501, 0.01848388921644073, 0.07356442365562543, 0.019077297511103097, 0.009018703804031247, 0.030396749098144937, 0.0660338214947842, 0.08544020398403518, 0.024669602898939047, 0.023917410253488924, 0.041963604890042916, 0.026848283159779385, 0.06435255272663198, 0.0472237027133815, 0.02125718747265637, 0.0396375879063271, 0.048904103168752044, 0.023076228535501286, 0.038544912749785, 0.08453619389911182, 0.058002481164294295, 0.04217979992972687, 0.04660159371269401, 0.03481276711681858, 0.06526825163746253, 0.03523083003528882, 0.031122222571866587, 0.07007080799667165, 0.011728524314094102, 0.07936325389891863, 0.08075364530668594, 0.0413213836873183, 0.07432326223351993, 0.028204958798596635, 0.027670716372085735, 0.0410828908206895, 0.0354367500403896, 0.035191555580240674, 0.08578865716117434, 0.04399134159029927, 0.018070529658871237, 0.01755274621245917, 0.0262697289508651, 0.036197648078086786, 0.009161697107629152, 0.01973642298253253, 0.039673893770668656, 0.009050448243215214, 0.03366243821801618, 0.06070215837098658, 0.06497613489045762, 0.019179109040123876, 0.030158295194269158, 0.04249188415997196, 0.022289308944891673, 0.045841363607905805, 0.016946103569353, 0.021285858492774423, 0.04961083555826917, 0.0776213665085379, 0.0337172755098436, 0.04942072700941935, 0.03805136228038464, 0.032469027646584436, 0.009033004062075634, 0.03381086775334552, 0.0077516142027889146, 0.03536575619364157, 0.058742276232806034, 0.0699338669073768, 0.009305264647991862, 0.021864835725864395, 0.05196542522753589, 0.018772384282783605, 0.0291012208617758, 0.06393715782905929, 0.0687202402332332, 0.04152047593379393, 0.06994030132773332, 0.046003459792700596, 0.08866672069416381, 0.037391630103229545, 0.07145919560571201, 0.03768750211747829, 0.09003811312140897, 0.038230268110055476, 0.05333401233656332, 0.07229916576761752, 0.046097638332867064, 0.04381453232781496, 0.027678620244842023, 0.03217582736397162, 0.11590777066885494, 0.030086060105531942, 0.03378687040822115, 0.051769783967756666, 0.06979438767302781, 0.10808263235958293, 0.058863301965175197, 0.051840358501067385, 0.046358529216377065, 0.04702930826169904, 0.04097822202311363, 0.02400031742581632, 0.05643027841870207, 0.02772216575976927, 0.021745203375758138, 0.04415946401422843, 0.012341609726718161, 0.013176382999517955, 0.018723191024037078, 0.027036013125325553, 0.03605420948588289, 0.04356730067229364, 0.029113243654137477, 0.01271988425287418, 0.04827420903893653, 0.033986211274168454, 0.06207021855516359, 0.05581588775385171, 0.021050770228612237, 0.04887614646577276, 0.037767861867905594, 0.05178872357646469, 0.043280390091240406, 0.032896682823775336, 0.09409440288436599, 0.010083570687129395, 0.02963260416436242, 0.0645542387792375, 0.02952809492853703, 0.01469282819016371, 0.01385517909511691, 0.033228292959393, 0.024532880743208807, 0.06789140228647739, 0.031723677602712996, 0.02515484502509935, 0.026936945687339175, 0.05196900980081409, 0.015055715211929055, 0.03868678912112955, 0.025393729374627583, 0.02529131856135791, 0.0689642212819308, 0.0302874919725582, 0.015432084273925284, 0.06277252032305114, 0.050061159636243246, 0.08061579137574881, 0.01716815044346731, 0.037325163357309066, 0.04604629284585826, 0.036734057575813495, 0.0217366464130464, 0.020249614390195347, 0.009749177497724304, 0.026826365683518816, 0.034303687207284383, 0.03721899171068799, 0.08114571450278163, 0.027590319514274597, 0.01633050876989728, 0.025800663788686506, 0.09811420866753906, 0.0024475357804476516, 0.032958192023215815, 0.0999547126411926, 0.023293234371521976, 0.038613683864241466, 0.10121296465513296, 0.028572032460942864, 0.037473396223504096, 0.04991904577764217, 0.013626105937873945, 0.05195231889956631, 0.031907162483548746, 0.03863204088702332, 0.08348656701855361, 0.02676971569599118, 0.049746448203222826, 0.028403754186001606, 0.06475109345046803, 0.11112439882708713, 0.0634866593463812, 0.036046602472197264, 0.06495143621577881, 0.04462506891286466, 0.03516266377118882, 0.017538433894515038, 0.02696102652407717, 0.07970366219524294, 0.020533096248982474, 0.04155813992838375, 0.024200057196139824, 0.06308336145593785, 0.023520042122981977, 0.02909433558670571, 0.09395075278007425, 0.020595605492417235, 0.07977292683790438, 0.031467480803257786, 0.052847664410364814, 0.05403031755122356, 0.03623245480412152, 0.04404387822432909, 0.04308997355110478, 0.033871200648718514, 0.01262757870790665, 0.013313656199898105, 0.025829572296061087, 0.031138909762375988, 0.017394249443896115, 0.05754507328674663, 0.0327572369860718, 0.037748721879324876, 0.057457451621303335, 0.05440623761387542, 0.07865946783567779, 0.035863674202119, 0.0404762110701995, 0.028692355008388404, 0.048037029773695394, 0.03924234973965213, 0.0170031376183033, 0.03599561321607325, 0.09909739848808385, 0.06725162646034732, 0.029753288508800324, 0.01906589255668223, 0.024686607357580215, 0.040325313893845305, 0.04412708411109634, 0.05844589955813717, 0.037707959418185055, 0.09186813796986826, 0.0360720024764305, 0.019686739906319417, 0.017306967311014887, 0.015645105704606976, 0.02628777798236115, 0.04417894910147879, 0.03349411541421432, 0.02372925911913626, 0.019483135401969776, 0.07608249361510389, 0.06756367729394697, 0.039261545389308594, 0.04439596421434544, 0.01684276692685671, 0.03631895211583469, 0.07622011748026125, 0.04857612955674995, 0.009897877916955622, 0.054405855407821946, 0.010398397153039696, 0.046738100645598024, 0.09737894069985487, 0.030459453155344818, 0.051725002776947804, 0.040252913677250035, 0.022489577495434787, 0.03381670845556073, 0.029595658197649755, 0.02592994034785079, 0.045727043179795146, 0.04855629937082995, 0.0337614963791566, 0.03318211282021366, 0.05572509340709075, 0.05936638903222047, 0.05375437220209278, 0.07343851830228232, 0.024018531585170422, 0.021456331669469364, 0.029397308098850772, 0.0318834248901112, 0.05653094332956243, 0.007231096869872999, 0.04667934852477629, 0.08701078142621554, 0.038311848693410866, 0.040525289296056144, 0.09512616627034731, 0.07541518411017023, 0.022677442902931944, 0.024756148450251203, 0.027040584755013697, 0.03126901196083054, 0.03183660650392994, 0.02099875495332526, 0.020362405994092114, 0.020146121896686964, 0.10994713738909923, 0.026097869813384023, 0.06276207088376395, 0.06678198056761175, 0.08553246036171913, 0.035005317331524566, 0.04737588009447791, 0.03762102423934266, 0.03331169922603294, 0.11119339629658498, 0.0988624567980878, 0.011042869846278336, 0.010591922364255879, 0.03474785517028067, 0.06986212349147536, 0.042993932220269926, 0.06840270492830314, 0.024951795276138, 0.06346395704895258, 0.03060304017708404, 0.050345205527264625, 0.053536084305960685, 0.05268554225040134, 0.03741376094694715, 0.017727852246025577, 0.08213545006583445, 0.032282945248880424, 0.037625276745529845, 0.03294035079306923, 0.0287473091884749, 0.04753727866045665, 0.011481355741125299, 0.05332479486241937, 0.016506234496773686, 0.04201654970529489, 0.08989049994852394, 0.060024280683137476, 0.015006799330876675, 0.015458626257895958, 0.017843111490947194, 0.07757037354167551, 0.008499892483087024, 0.055637846526224166, 0.036856745718978345, 0.0708362739533186, 0.024965690136014018, 0.05219477854552679, 0.060820879734819755, 0.050312246748944744, 0.07466014532838017, 0.13372770859859884, 0.01842062483774498, 0.021453181252582, 0.0028790828264391166, 0.0378004829690326, 0.04343156557297334, 0.044825255827163346, 0.0577685450844001, 0.16135405196109787, 0.23086455330485478, 0.08709514877409674, 0.25698184326756746, 0.13984689430799335, 0.15969922591466457, 0.22473594231996685, 0.17559325351612642, 0.20812120026675984, 0.14129109884379432, 0.2591667853994295, 0.13920156721724197, 0.2641291409963742, 0.1494489939068444, 0.11861239428981207, 0.12208134838147089, 0.1846691407263279, 0.15906265616649762, 0.10648930809111334, 0.10335352635593154, 0.1768999084015377, 0.15212017635349184, 0.09911659042700194, 0.23144564009271562, 0.19846023351419717, 0.14984654757427052, 0.14583203330403194, 0.14821406017290428, 0.2825478807790205, 0.10771958113764413, 0.19798836117843166, 0.16514828195795417, 0.12955732847331092, 0.28815866564400494, 0.1409272089949809, 0.15320086211431772, 0.10610133555019274, 0.15666100691305473, 0.12386656977469102, 0.22317873837891966, 0.0811853600316681, 0.18081742397043854, 0.10700487808207981, 0.09595475930836983, 0.15843883651541546, 0.09135405227425508, 0.17004762921715155, 0.10744181752670556, 0.099285176693229, 0.1519027419271879, 0.16563373559620231, 0.18954770785057917, 0.14205263141775504, 0.10418876161566004, 0.13317026663571596, 0.13129159400705248, 0.18266694503836334, 0.13757801527390257, 0.1124060210713651, 0.16054006438935176, 0.22640163340838626, 0.13254474004497752, 0.1419693327625282, 0.14298123627668247, 0.14713122218381613, 0.14279080118285492, 0.11693079897668213, 0.13475031388225034, 0.09367197242681868, 0.10336164545151405, 0.17105441191233695, 0.12185185405542143, 0.09529214017675258, 0.09703886636998504, 0.18344284559134394, 0.2339057408971712, 0.18455392972100526, 0.1926073303911835, 0.17024481785483658, 0.13907685672165826, 0.11467124873888679, 0.19127228093566373, 0.33686863782349974, 0.16218645963817835, 0.16853413777425885, 0.13909919536672533, 0.1396377570927143, 0.1403622713405639, 0.1057683487306349, 0.2104074158705771, 0.1097832563391421, 0.2369215025100857, 0.15808474301593378, 0.1512107189046219, 0.13990506384288892, 0.17689177446300164, 0.15029933187179267, 0.18158441875129938, 0.19681167119415477, 0.16602003830485046, 0.14089830976445228, 0.19502463896060362, 0.15578176971757784, 0.16518988675670698, 0.0864596180326771, 0.20775615266757086, 0.15700717427534983, 0.24368907295865938, 0.1610625215107575, 0.14391963748494163, 0.16341110720532015, 0.10117622834513895, 0.11177615291671827, 0.16407212329795584, 0.0686111742106732, 0.07721736357780173, 0.06703354636556469, 0.1669133169343695, 0.24656113993842155, 0.2341147296829149, 0.14930529927369207, 0.22681165515678003, 0.1403718747314997, 0.18370690173469484, 0.27287508419249207, 0.14224176033167168, 0.1279998425161466, 0.3141247801249847, 0.17076736403396353, 0.10020762172644027, 0.13656278693815693, 0.1927666991832666, 0.1323755452176556, 0.21503107011085376, 0.1927496594726108, 0.08522208678186871, 0.2781888615572825, 0.1257044984959066, 0.12104263107175939, 0.06843140377895907, 0.1735127018764615, 0.07722121532424353, 0.13973006542073563, 0.1396026386646554, 0.06571134348632768, 0.10639836531481706, 0.1414131376077421, 0.10981082712532952, 0.1439820372615941, 0.08377482459763996, 0.22479158855276182, 0.09160662739304826, 0.09161936264717951, 0.1998333106166683, 0.15530434611719102, 0.12194373935926706, 0.14573208085494116, 0.07190955308033153, 0.21469345228979364, 0.06782999698771164, 0.11260863480856642, 0.19142314471537247, 0.12435494005330838, 0.07761239394312724, 0.10800403892062604, 0.1737501594470814, 0.17474497872171924, 0.1637436932651326, 0.2565804007463157, 0.13433045125566423, 0.0755144092545379, 0.13239179825177416, 0.1680567438597791, 0.11704382806783542, 0.12543897290015593, 0.17922697181347758], [0.023112937014957424, 0.03210933835362084, 0.013338837270566728, 0.06669390990282409, 0.02967453736346215, 0.0231798026652541, 0.11415101806051098, 0.024838812569214497, 0.015004185115685686, 0.01688293010374764, 0.04036363468912896, 0.15217907319311053, 0.020889605439151637, 0.04931995448714588, 0.026127064047614112, 0.009991782790166326, 0.02967963220726233, 0.0364345898560714, 0.04870520388067234, 0.053588802766171284, 0.0039622837721253745, 0.01775886288669426, 0.032244490867014974, 0.03722170054970775, 0.07666211837204173, 0.0498111449269345, 0.01688706201093737, 0.07778422339470126, 0.05593663147010375, 0.03341147727041971, 0.029169147783250082, 0.06469088300946169, 0.01684853898041183, 0.04670819209422916, 0.058116471336688846, 0.022377355489879847, 0.05508200018084608, 0.03951269558456261, 0.08796938389423303, 0.05280261975713074, 0.02526554191717878, 0.040232578830909915, 0.07847261731512845, 0.02008173687499948, 0.019124739301332738, 0.05618311355647165, 0.023087230874807574, 0.0350177705695387, 0.03156412327371072, 0.02793755742459325, 0.03834974646451883, 0.03022167646122398, 0.036319245264166966, 0.026551817427389324, 0.00437001228419831, 0.07321199256693944, 0.03443238674663007, 0.028365667167236097, 0.041618320683483034, 0.04414759336214047, 0.02969739551190287, 0.025290665471402463, 0.0167648210117477, 0.030850566836306825, 0.07282655074959621, 0.03481715692032594, 0.0443931626068661, 0.03932090607122518, 0.0886013226408977, 0.03432731347857043, 0.09326929051894695, 0.1003315084381029, 0.03585242695407942, 0.011238983297516825, 0.005077373643871397, 0.032756539367255755, 0.06377832338330336, 0.0826481702097226, 0.04674519186664838, 0.02870088785130065, 0.03366072014614474, 0.02661273847479606, 0.04262329624907579, 0.026308944034099113, 0.004996243451387272, 0.10537587877479382, 0.022203757871466223, 0.037622304444084875, 0.029159742916817777, 0.03937552071874961, 0.07123295930796303, 0.08438064716756344, 0.17187604360515252, 0.014890075271978276, 0.038410721317632124, 0.05353668544557877, 0.016888579702936113, 0.06701550475554541, 0.08074928147834726, 0.021379810677899513, 0.022393408144125715, 0.02880785359593574, 0.02796695760480361, 0.07806511886883527, 0.03629533326602541, 0.035127864466630854, 0.011153796804137528, 0.016731802861613687, 0.0978335877880454, 0.03336396868689917, 0.02829603516147472, 0.017835584258136805, 0.059217532761977054, 0.04357528989203274, 0.04922927888401318, 0.041120710666291416, 0.036905586457578465, 0.06524122261907905, 0.045045143051538616, 0.044564457712112926, 0.03757453610887751, 0.009770570832188241, 0.033536811170051806, 0.02951191239844775, 0.017668764303380158, 0.011593330982577754, 0.03461884392891079, 0.03212053736206144, 0.050176875301986, 0.06509770610136911, 0.0242278821679065, 0.025176576964440756, 0.020302310585975647, 0.02194015629356727, 0.0209744013773161, 0.0047787501171114855, 0.06688958455924876, 0.051345731917535886, 0.02695407445571618, 0.07037230549030937, 0.07388781450572424, 0.04304341862734873, 0.04289748270821292, 0.05750667827669531, 0.023609209310961887, 0.028600783261936158, 0.03920454844774213, 0.03718840780493338, 0.05889028274395969, 0.03907040896592662, 0.029140736514818855, 0.043467812065500766, 0.03580183103622403, 0.05581956880632788, 0.024609618812974077, 0.012887331322417594, 0.05639842172968201, 0.026970715261995792, 0.02084036579617532, 0.04216583642119076, 0.023725353566987906, 0.0547310274123447, 0.05818578792968765, 0.03039133698621299, 0.05350023857317865, 0.057312491626362316, 0.017791313293855637, 0.04263664748577867, 0.05202280437515583, 0.009441602742299438, 0.05500122482771985, 0.008790807878540363, 0.003381763567631424, 0.033804815539042465, 0.03813315437582787, 0.016913907347770873, 0.025256606459151953, 0.02652452494658064, 0.08824895834550261, 0.0386249199800659, 0.030690287057950627, 0.032686974154785275, 0.03318380120617803, 0.06074466116842814, 0.00768170713854488, 0.06649803486652672, 0.06797705354983918, 0.08238096736022271, 0.08009067736566067, 0.07076329115079716, 0.01783744890417438, 0.015374715330835897, 0.0330109364585951, 0.0233716422735597, 0.01649496869504219, 0.005178218061701045, 0.020752849886775948, 0.008671333234815393, 0.016802431200630963, 0.013237010898592416, 0.0019640499931483646, 0.016649333556415513, 0.0203818632508046, 0.022229313726711553, 0.014944405120331794, 0.02444819241645746, 0.03686981122882571, 0.029139235521142837, 0.03857694384350907, 0.03889858693582937, 0.022595773261855356, 0.04555904321023263, 0.0640903964813333, 0.03166832080751192, 0.031776258765603416, 0.046967442831373774, 0.06126973807113245, 0.05111922473588493, 0.04238423935021274, 0.05681478884071112, 0.02909179929702077, 0.032361342018703, 0.015495002626266796, 0.021784639247925952, 0.08503600067342632, 0.03204483458830509, 0.06517151268781163, 0.012958926308783703, 0.059505230019567534, 0.0687066737737041, 0.06956275596166961, 0.046151451460900716, 0.051873762567993253, 0.03550356188497972, 0.029675010482606012, 0.024814553617034107, 0.06399926816811785, 0.03513698546157684, 0.03999476874014363, 0.03369328929693438, 0.07040718643111177, 0.0429663169052219, 0.02566873219620902, 0.029905413939559367, 0.03205853463441599, 0.031239585805451497, 0.04033382632769644, 0.06957995894481428, 0.02652808168932097, 0.03582133838790469, 0.024196619197027758, 0.047172357226372696, 0.0910013094835449, 0.03596511836803984, 0.04122953178011812, 0.040101949707604945, 0.04566831332340371, 0.038801298796897754, 0.013497631825885037, 0.007219871886263718, 0.05771531454229262, 0.04277362568245735, 0.014125293018878438, 0.03495334844046738, 0.01390213199556456, 0.02213417781604221, 0.03374410414835438, 0.0476852851716103, 0.030459642403002363, 0.03143170557450503, 0.05526275766897015, 0.07789023176883347, 0.038741533644497395, 0.012376329250400886, 0.085350211156765, 0.009098261107283179, 0.015558891336695524, 0.024471323304169346, 0.04140346893109381, 0.04225790355121717, 0.04068426103913225, 0.03306324673758354, 0.04364659915154334, 0.018364114002906717, 0.039823087718104944, 0.01467352678446332, 0.021257410116959363, 0.05111906888487283, 0.0603734722972149, 0.036397968578967266, 0.060818642159574665, 0.043652146705426276, 0.015072694623086136, 0.0316832862154115, 0.03356858251208905, 0.02664493840711657, 0.040761095588095486, 0.0514854041102808, 0.034490066464059055, 0.05979188827041071, 0.10672631295165047, 0.028943848446942866, 0.004936311315759667, 0.02844118254870409, 0.027483303674671333, 0.018023880111286417, 0.016525320679647848, 0.0062676050401933026, 0.06500065544969402, 0.016073412116384134, 0.08687665307661518, 0.03740489228221122, 0.0425963154702913, 0.00025475306131284015, 0.05976651795208454, 0.07211984062450938, 0.0194841484335484, 0.0689842295832932, 0.03145992573990952, 0.03779772589041386, 0.03278064432379324, 0.04332355340011418, 0.04209687605907675, 0.04152069115662016, 0.0892274132638704, 0.03199385646439623, 0.025081051426241174, 0.02806282638630364, 0.008698002311575692, 0.08152985756169073, 0.036871722259093076, 0.03442837914917618, 0.08025480332435109, 0.023233660322148353, 0.02280712764331838, 0.03580452503229026, 0.025629021729400847, 0.013190398458391428, 0.03452452438068576, 0.06818101057433523, 0.05334141154889949, 0.04823947652766947, 0.0743987609166652, 0.01833914629969513, 0.018787097360473126, 0.06110081412771251, 0.040313825447810814, 0.015241161218000343, 0.0665473283152096, 0.017852592427516356, 0.030114489927655086, 0.028474386235757265, 0.10973605574690737, 0.1227168865443673, 0.11665958110825159, 0.11858745812787674, 0.13062581332633272, 0.06309177741059102, 0.15793993516126648, 0.1120999148406554, 0.11189801356522366, 0.15471545193577185, 0.13254557125037536, 0.3832725196843967, 0.10551262690569274, 0.25286271586082876, 0.09291600596043281, 0.11936416020034812, 0.1246714437729679, 0.0877401047910098, 0.13269460934679955, 0.16439184051705524, 0.05573885653575417, 0.13267859379993752, 0.14378832187503576, 0.10666020243661478, 0.2202905371086672, 0.0985117771779187, 0.15758722205646336, 0.1084891363279894, 0.19122334371786565, 0.21045529923867434, 0.1582648474141024, 0.12122202300815843, 0.19038056081626564, 0.15376722469227389, 0.13835422752890736, 0.0905888163833879, 0.12938672356540337, 0.12153565461630933, 0.10673336335457861, 0.22846229549031705, 0.17923296836670488, 0.11966995472903363, 0.23334650293691084, 0.19304829969769344, 0.12172644594102167, 0.10016733795055188, 0.12476679490646347, 0.12388131624902599, 0.18148884497350082, 0.06666055036475882, 0.15667133760871366, 0.12775987648637965, 0.24726846604608, 0.11124160620965995, 0.18419854488456622, 0.1902816622168757, 0.10883823517360725, 0.13222606183262542, 0.1376600968069397, 0.12034856714308262, 0.15455860644578934, 0.059271390418871306, 0.0799095859110821, 0.1974552171304822, 0.1801944206818007, 0.15222777292365208, 0.09831372764892876, 0.1396840819506906, 0.18314162269234657, 0.12744308332912624, 0.2058495010714978, 0.2840671461308375, 0.1591956935590133, 0.10204588441411033, 0.07540035599959083, 0.1481076658819802, 0.20986818621167913, 0.16736451303586364, 0.14185516076395288, 0.15156120556639507, 0.19814758154097944, 0.12979831866687164, 0.12762309866957366, 0.10015607957029715, 0.12977767211850733, 0.17080133955460042, 0.06495278692455031, 0.1078470004722476, 0.08958356993389316, 0.13705382152693346, 0.13097171351546422, 0.13639679818879813, 0.32597589888609946, 0.132799370912835, 0.14062062778975815, 0.14424683555262163, 0.08607296651462093, 0.14408411225304008, 0.21129772590938956, 0.09831327493884601, 0.09948465114575811, 0.16344762087101117, 0.12537832459202036, 0.15084285114426166, 0.09294088275055401, 0.10032800550106913, 0.15043705963762477, 0.08203513396438211, 0.2921091177267954, 0.14270883839344606, 0.1422224793350324, 0.1494369117426686, 0.1868104891036637, 0.08038667554501444, 0.13520244508981705, 0.15847199567360803, 0.11521570311742835, 0.15444666089024395, 0.08954303382779472, 0.09367692255182192, 0.12409647228196263, 0.13570599228842184, 0.16176808130694553, 0.13577354256995022, 0.18183386942837387, 0.12905833806144074, 0.08507419159286655, 0.17597396043129265, 0.06448423941037618, 0.15554254583548754, 0.23924709646962583, 0.18712067714659497, 0.14460198290180415, 0.09161286885500886, 0.15702878561569378, 0.16918618872296065, 0.12694468663539737, 0.39783351647201926, 0.1216419153206516, 0.27337564795743674, 0.20571980334352702, 0.12419574937666766, 0.11349393535056151, 0.15669873770093545, 0.0848145289637614, 0.1345843548187986, 0.1048917684238404, 0.1384803481050767, 0.23836257518269122, 0.09151653066510335, 0.09345853075501509, 0.1462376318522729, 0.07606015497003682, 0.22375189902959391, 0.1509772244025953, 0.13691167056094855, 0.18973735626786947, 0.22977482818532735, 0.21943059575278312, 0.10596092863124795, 0.08191543296561576, 0.1898297091247514, 0.0954759182059206, 0.12569707701914012, 0.15651045483537018, 0.14267336373450235, 0.18344096053624526, 0.11822187618236057, 0.1651706948177889, 0.17124759295256808, 0.21811487182276323, 0.13030287518631667, 0.1868023254792206, 0.09628752348362468, 0.12533364730188623, 0.1205562794348225], [0.07362677148194052, 0.020393383238115348, 0.016686630187905394, 0.03880834177834913, 0.02490607712388737, 0.0480088986660121, 0.02014706813497469, 0.01149700485257199, 0.05797987163532525, 0.07330410051508807, 0.04339426894148346, 0.04588967371091712, 0.04290545708499849, 0.02792444924125448, 0.028861620339739602, 0.03371888968104031, 0.0256815732063842, 0.020339045040600467, 0.05247681692708284, 0.033094513419200666, 0.04204747128824238, 0.01609716269740602, 0.03246395877795294, 0.03890604180924129, 0.02269190921651898, 0.1029641437344253, 0.015496884898311691, 0.02415965653199237, 0.016406591894337907, 0.016582556963840034, 0.04272006488463376, 0.028016985779686365, 0.03659676767711062, 0.03832018672255799, 0.03499257094517816, 0.0457516639289679, 0.06903282541316003, 0.11168669443577528, 0.013165953041607281, 0.06280728252022527, 0.04057115031173453, 0.06457222101744264, 0.018611748273542617, 0.10283280586008914, 0.014539538515236927, 0.027255813147348817, 0.05194106051931158, 0.06737851887010038, 0.04571795929223299, 0.06990444817347452, 0.06191875734657515, 0.03441758832195774, 0.06139624827483203, 0.050842485288740136, 0.010491649863979546, 0.06421630183467641, 0.011083691679232288, 0.03115377498033922, 0.03805255713814404, 0.03640886330686044, 0.030063216800044756, 0.042325398171669804, 0.07526747445808724, 0.055023641398292966, 0.06473093671957031, 0.031130608840612695, 0.010785608992591733, 0.01482162699176115, 0.053329039947129786, 0.0786058625089936, 0.01221258549776394, 0.02613254480820615, 0.03147062008793, 0.027579411798797082, 0.05517799698282033, 0.05245735039352439, 0.074850031232927, 0.033100881046266295, 0.03380581743840594, 0.042121671212953515, 0.024251903632830363, 0.057080336700892076, 0.03884308542183135, 0.01403722513714456, 0.06101225364545826, 0.01103410044379416, 0.0784926775668282, 0.04558826156426221, 0.027762753816205077, 0.027729854409699328, 0.1155768618627917, 0.07890204622526653, 0.05439703869342338, 0.04959951780620031, 0.049021395898307674, 0.020103500355617143, 0.01573002966324566, 0.02696974675927777, 0.02700010059925262, 0.005421608639153419, 0.09781595435924828, 0.005436065675894497, 0.09574617870384827, 0.017240604465769138, 0.023513529777119402, 0.03349378515849821, 0.04816936583665665, 0.015553655484836781, 0.003053024847758934, 0.010164188333874336, 0.042141226804233156, 0.04282036985387094, 0.026615508540999144, 0.03743827408470679, 0.010609064120217226, 0.04830662604945246, 0.029570343540399335, 0.052173820295138285, 0.00940126887144288, 0.039308838750002906, 0.0506119890633272, 0.03457697937847115, 0.028879617420898285, 0.03604223864385858, 0.021906058318563737, 0.0779314358078409, 0.028061813354725018, 0.05199851388169918, 0.06742420548107475, 0.04411838614032604, 0.029569529033324216, 0.013784516431769589, 0.02213291616499191, 0.018329639387957286, 0.02546745989093324, 0.019485660559439566, 0.0441545584180858, 0.059325852926122025, 0.03452104370808229, 0.014509537195408484, 0.06838994740974158, 0.05757177947089076, 0.049725137432687916, 0.018362754017289262, 0.03843933482130524, 0.015082873178471345, 0.026428973433212377, 0.09194460886646993, 0.03892825799994171, 0.02772096162516391, 0.033159280646941625, 0.033273051885771565, 0.03934659551305231, 0.04351346527982969, 0.04306352340790909, 0.0452018401119858, 0.054084015646367334, 0.0376914169464726, 0.05489642244356219, 0.0034801442870957544, 0.05303719408402685, 0.03556469629984349, 0.023551267986476887, 0.028692462619801518, 0.03204116837878246, 0.020820476238441188, 0.08424544270383194, 0.060897951771039516, 0.0380745209986344, 0.03095351941738045, 0.06008090655086562, 0.05222659441642463, 0.07270669389981776, 0.01908330334117636, 0.042302573419874534, 0.06245517055504024, 0.01978130436327774, 0.0224423676263541, 0.03603816425311379, 0.06361808627843857, 0.004516154149314389, 0.028462899645091966, 0.04483136741328053, 0.05085453776700888, 0.022322939366858918, 0.03620928124291822, 0.021617329475702718, 0.04897317856375594, 0.04823470822884701, 0.015954510781739373, 0.05431937664980069, 0.02209436901466688, 0.030277211371867452, 0.062368843937292695, 0.07883201717049815, 0.033786532731028274, 0.06810181599576026, 0.05707449228793848, 0.04823411079996731, 0.017916393007908482, 0.031795469258213416, 0.04099623023648746, 0.09070874002645724, 0.02203893986006733, 0.03296910159406252, 0.02550266552134417, 0.048470239926245995, 0.03332457548822276, 0.029062749781587627, 0.02409239939879626, 0.029622110196214635, 0.05793313859612681, 0.030742636299692094, 0.049835405734484084, 0.035263324971310794, 0.03394673272850923, 0.021055299184808973, 0.04328389302827418, 0.04504177370108664, 0.08456289637251757, 0.027767971114371903, 0.012549443545140093, 0.020180720821372233, 0.03697001971886493, 0.02267545209178934, 0.0284039545658743, 0.021991859866830055, 0.04333300094003789, 0.006458597672462929, 0.04093410505447537, 0.04432893714692909, 0.06722703910782002, 0.03395172367163468, 0.05724444410589058, 0.016440754807263147, 0.018177296879002824, 0.036223857023287565, 0.024775635392870754, 0.009254347751266323, 0.07445449620718136, 0.044461173019954, 0.013131458017596742, 0.14346395881148055, 0.03292272478574887, 0.02893514491006499, 0.053524825925705954, 0.022667780140182003, 0.03875388669257518, 0.0458019258803688, 0.005068152922831359, 0.02113912476488622, 0.02241240712464787, 0.0217490180148161, 0.05461629880301189, 0.057987114996649325, 0.02642087474669097, 0.023766997328493744, 0.013427193662209902, 0.03238641547795851, 0.04026723712740932, 0.03166555630741641, 0.027822723059216514, 0.0412434136524098, 0.026581097008602228, 0.02250001209176844, 0.04405507352203131, 0.03888556966558099, 0.012951724693266442, 0.05126527197717223, 0.041786580404732376, 0.03652212617453188, 0.03645742574008182, 0.07873066948377527, 0.020998255859012716, 0.044293262108112685, 0.010044552273029694, 0.04676374555856455, 0.01902733427414205, 0.09024444501847029, 0.021435139642562717, 0.009337920073448913, 0.06688859750283882, 0.04786790545040276, 0.048012976767495275, 0.05992158970911987, 0.035675339386216365, 0.08143950850353576, 0.05743001813243609, 0.020890850391879212, 0.04667911845899653, 0.02510094469471369, 0.04414002345583867, 0.06971359747694805, 0.07489012205041945, 0.08527059355401434, 0.0317874837492127, 0.040381832150160335, 0.012457647299015662, 0.01967919040907873, 0.008157495230989298, 0.06423570157494396, 0.035481490413076244, 0.013689570696442388, 0.0593359721096931, 0.019286431015643757, 0.01882852775452193, 0.04830798046896234, 0.04080184691702016, 0.024416884916718118, 0.011769574357458623, 0.01852837911428651, 0.0454927434475394, 0.06953571952180937, 0.04776076901180204, 0.049184523668373004, 0.021305998525349423, 0.02912562824349152, 0.030632664856966585, 0.056647367746336386, 0.01591526230185991, 0.05289721018925775, 0.06201850941579323, 0.010001146838476416, 0.062388651858782396, 0.04219197857310064, 0.051661233737831935, 0.029547268313763198, 0.0427110477903625, 0.03700292654684745, 0.05546954969759099, 0.01853319936344633, 0.031204730839817785, 0.05049930507084355, 0.03546765678038355, 0.07936045600217767, 0.04654457821743563, 0.01358893639917369, 0.05118552078783978, 0.040546062009525485, 0.027942665255977772, 0.025813790525717195, 0.03829165856586769, 0.03866039463900961, 0.06105313485022634, 0.05301649187458679, 0.0042156511335633695, 0.06031899123627227, 0.059810326929437, 0.0176377035677433, 0.02370080146647524, 0.021765343408333138, 0.05601695411314722, 0.22189837036421522, 0.19383141392609105, 0.12555013177916408, 0.16048219171352684, 0.08259644251666032, 0.10117387573700398, 0.11034604176529683, 0.13098079740302637, 0.11376287482562475, 0.1722651071031578, 0.12208549698698334, 0.19324235647218302, 0.25562635506503284, 0.07943734992295504, 0.17075071024009958, 0.13312000839505345, 0.1747188699664548, 0.12989788519917056, 0.13874104974092916, 0.17408422980224714, 0.2035155802150257, 0.16907216515392065, 0.1404776456183754, 0.1083279938029591, 0.1019815327890683, 0.11564608939806931, 0.24326184822712094, 0.12716226949123666, 0.20545264502288774, 0.10942111795884557, 0.16075730585725978, 0.13168390811188146, 0.15282996639143676, 0.12534800043795258, 0.0949954146926757, 0.15030057867988944, 0.16886783705558628, 0.18352296785451472, 0.0709429725247901, 0.19702883844729513, 0.11724918032996356, 0.13622411526739597, 0.11380586001905613, 0.17348162073176354, 0.15751076600281522, 0.0689620319462847, 0.1483921310864389, 0.14106198301305994, 0.14039560861419886, 0.15344876912422478, 0.12717169476673007, 0.11273007243289612, 0.14320192130981013, 0.1250546591472812, 0.0919064179470297, 0.16732278949348256, 0.16109873831737787, 0.14222659083316103, 0.09746777577674948, 0.15741752256872132, 0.09802312488318421, 0.11244418230489828, 0.15863703447394073, 0.12257262787898071, 0.23825290059903637, 0.09634294707211666, 0.16289181163301691, 0.15315346856368706, 0.12991526629775763, 0.2048693911638111, 0.19621232757344842, 0.10657019476639107, 0.09680687100626528, 0.12642322399187833, 0.11029061817680486, 0.16371586272725835, 0.15487125841900706, 0.08804935030639172, 0.20318204420618713, 0.09577885546605103, 0.10450292014866136, 0.14494199043838307, 0.14239906595321372, 0.11031761750928126, 0.1521748281084001, 0.12454088515369222, 0.09733233382576145, 0.1726686127949506, 0.10940217092866078, 0.09096810579649173, 0.2793276426382363, 0.17802521208068356, 0.15411481697810814, 0.11903642778634094, 0.11436692366260104, 0.10863011470064521, 0.12543572229333222, 0.1334306417265907, 0.10167836546315812, 0.09804697750951163, 0.08973094561952166, 0.07031489294604398, 0.12449044137611054, 0.09453243328607641, 0.1137203052348923, 0.19077725359238684, 0.08640087704407051, 0.07759159154375084, 0.11113962769741192, 0.14276861096732318, 0.15495169238420203, 0.11236858714255504, 0.12612312915734947, 0.0862466216494795, 0.08920865177060477, 0.146739293995779, 0.15924973675282672, 0.18763038417091593, 0.1409235576284118, 0.22867535124532878, 0.10889922486967407, 0.11650695101707242, 0.10737813383457251, 0.1873015088494867, 0.16567480604862794, 0.18842112767742947, 0.1292568031931296, 0.1566540900967084, 0.16352505655959249, 0.2038484186050482, 0.15973082656273618, 0.11650743341306224, 0.17795288236811757, 0.12603275041328743, 0.1036178793583531, 0.20636038068914786, 0.12150030612247065, 0.13993198896059766, 0.0835986238962505, 0.1483242097310722, 0.127657727280166, 0.2105618716450408, 0.15318717691116035, 0.08945835477788933, 0.1402012846665457, 0.27801027114037424, 0.09464162547374144, 0.18965794646646827, 0.12275696251890622, 0.13288548972923309, 0.12079119886038825, 0.12371207689284347, 0.09839704114710912, 0.11842633786727674, 0.09466828341828659, 0.0988661526935175, 0.12699555343715474, 0.08599665146903135, 0.10466414430993609, 0.10893668106291443, 0.10980751714669168, 0.1288955850759521, 0.09637515628128313, 0.11811162272351794, 0.18376185034867376, 0.13680017029400915, 0.17623169347643852, 0.12444168227375485, 0.1660517873824574, 0.1374343948555179, 0.14945960661862046, 0.2560300240293145, 0.1591925320099108, 0.09117796289501712, 0.22556106210686266, 0.17579781910171732], [0.04670733120292425, 0.05098695917695295, 0.03031097166967811, 0.0182692823727848, 0.045684147044084966, 0.015447894802491646, 0.07475752252503298, 0.06263001312618144, 0.017156997819256503, 0.00937276297918288, 0.03399728040676564, 0.04887110357230995, 0.016981383414531592, 0.008230544826801633, 0.07988480560015887, 0.025904354806698393, 0.023248547804541886, 0.03369675512658432, 0.02539110959332902, 0.08251768580521457, 0.05143796603078954, 0.09341396478703246, 0.0882147453376092, 0.05340053845429793, 0.03463627697783522, 0.05930968894972466, 0.07253203686559573, 0.02413023408735171, 0.02980941342684673, 0.09012485534185544, 0.06067580841772724, 0.04650590490200557, 0.03947305376641452, 0.033053049628506415, 0.020633605308830738, 0.0806620049115736, 0.018480486469343305, 0.042432675618329085, 0.055328044400084764, 0.055060774757293984, 0.006500516028609127, 0.015198894980130717, 0.046829562925267965, 0.041301661112811416, 0.047655105736339465, 0.01279071111639496, 0.015121456508495612, 0.06649842078331858, 0.03076493041589856, 0.05716360938095022, 0.02109952190949116, 0.01593350800249027, 0.018563252633612137, 0.015620559170201886, 0.02751349238678813, 0.012776131625287235, 0.038357865560101345, 0.01585061567311641, 0.026840711398108397, 0.029918657564849127, 0.008617857783974614, 0.06263678151299246, 0.022653048508800566, 0.041021641372935846, 0.07308240616112016, 0.04276427091099322, 0.031931835183058865, 0.03019609834154835, 0.019250522200309206, 0.04040121704747435, 0.01525759051219211, 0.05228641894063912, 0.024677015098859556, 0.06143564518424682, 0.044002384747727774, 0.025186629354720935, 0.07145201903767884, 0.07525427907239646, 0.06737410309142433, 0.009574630857969169, 0.010060519580292748, 0.06291873083682731, 0.02480415983882267, 0.03953436258598231, 0.03958973422413692, 0.04915111217997037, 0.04943056046613492, 0.01812014408642426, 0.049489045413793065, 0.039003767815302126, 0.02701752066059271, 0.041251477086916566, 0.02672642807738157, 0.07837811222998425, 0.0687759458378423, 0.06949771413928829, 0.022195633209776133, 0.03510460926918313, 0.050708483104244806, 0.021586227921943646, 0.024514551550964825, 0.03851754234347027, 0.03617213304096367, 0.01644665673666168, 0.042427306179888546, 0.007832068113202695, 0.038479844952235, 0.058480528168729506, 0.01429112684490974, 0.06133941460575443, 0.024687867153261323, 0.043352088978281245, 0.010880738409468904, 0.09800316111068241, 0.029289403537404723, 0.040746037411736324, 0.018296726993867196, 0.11235830097575672, 0.018942157985293306, 0.05582085643254686, 0.08427946275332943, 0.04395508025481831, 0.06522373019834049, 0.037921512412140146, 0.023922302862047218, 0.04161401622695848, 0.010772169625852257, 0.0333870902977651, 0.051682841367437504, 0.03573644040443469, 0.04038349827169441, 0.0184750428161351, 0.04202970056212507, 0.06487682810984552, 0.12120056751882657, 0.05645817203912884, 0.025866004325507674, 0.025266267366532702, 0.08750747860176489, 0.019252383135608397, 0.037516140218940563, 0.10986926383338869, 0.043873789109056816, 0.02385620533459587, 0.07181248758570291, 0.061712670358247124, 0.14322688715765253, 0.02035619421803858, 0.01735684334562393, 0.015827284405531827, 0.03647032426670194, 0.04922881875245366, 0.013383442201302387, 0.05841810241690837, 0.03444797926931642, 0.15589450194966048, 0.05489094910444692, 0.00807781083494774, 0.05460745611344464, 0.018110850542143453, 0.0495516492810566, 0.009060288193722954, 0.08396341916522942, 0.049202312948182225, 0.015060245095810387, 0.035078222208539955, 0.00758968917580205, 0.03633368745795451, 0.03532874157826882, 0.0497796073614154, 0.10618325381074101, 0.04226413388096262, 0.04412089088873472, 0.03614394256146625, 0.007940273244457785, 0.014033620154805249, 0.0424810525146313, 0.08333987410878763, 0.02222306855401257, 0.06758510309737176, 0.02752166157733882, 0.04847379481361713, 0.020124469738220796, 0.08483673402224667, 0.0022540968438988784, 0.018419587686366867, 0.005623626802844228, 0.062000734978937544, 0.004490249948503333, 0.01969351200386882, 0.028789741481887177, 0.02997078230691841, 0.00998242894638679, 0.05362646305002272, 0.08498314491589554, 0.059866099327337, 0.06917942184372805, 0.08459613716695458, 0.023957597550179344, 0.012894889168819645, 0.040338902617804706, 0.016256486960628536, 0.03226910419471096, 0.02118663705914514, 0.014850822153675836, 0.01844834776420612, 0.058029966603498906, 0.0364034938684199, 0.05554658091568854, 0.036077861732337624, 0.022936083223612513, 0.021671778995369095, 0.01848187985160621, 0.059702259095502086, 0.09794413068448193, 0.06442454847274348, 0.008927339858928462, 0.03661103546619415, 0.04682455713918898, 0.030999031623650808, 0.039663062125328, 0.050640142435440794, 0.04854540835367516, 0.01720243952149758, 0.024722629350435454, 0.021776681569463108, 0.02572507604782004, 0.018595151996123604, 0.020617272493836936, 0.029196822470112238, 0.07457914733095095, 0.06923923152498901, 0.04250768819474615, 0.022642821713816375, 0.030843419954180717, 0.0453340129024582, 0.024612116139905993, 0.020321205665823072, 0.0480591383529827, 0.02730275027715834, 0.05200764600886032, 0.007371958818112034, 0.02067809706204571, 0.00806222573373816, 0.09238950413418934, 0.011678036935336422, 0.01733987228362821, 0.0681337877176702, 0.03037395032151835, 0.057986840402008966, 0.0548005666496465, 0.02457062637404306, 0.05193559089093469, 0.05119874585943762, 0.05886906474188436, 0.018863881814468186, 0.039233636925928295, 0.03603049415687565, 0.02562596037023468, 0.032231499571935274, 0.016513796981598716, 0.022211951181816403, 0.030917207986931317, 0.02554200305894483, 0.024385588549193926, 0.08572236853069626, 0.024244266933237668, 0.02018768402194837, 0.07512417316320352, 0.1282537609222345, 0.026796778111020103, 0.0075736379130830755, 0.019613245021901093, 0.04714489776233677, 0.03889336592692416, 0.03782725594646763, 0.01355668358883122, 0.06466357197496109, 0.02532507700379938, 0.028480022847361397, 0.05537399818422273, 0.07410012069158256, 0.017262967230635695, 0.042484763253014535, 0.04538353641692083, 0.008618281735834898, 0.03117866290267557, 0.06608047289773822, 0.026538792735664174, 0.027221030541113578, 0.054534543814952485, 0.050025091259158216, 0.0396982065285556, 0.06319453517789952, 0.03854568458336871, 0.030477637628791854, 0.023244035546667874, 0.011429954593040748, 0.0859723164467141, 0.012515640573838027, 0.012561861531139584, 0.02555453793320339, 0.024137093387253117, 0.025611679593566805, 0.010442594830237795, 0.04717607909697108, 0.041112391190836206, 0.06588561460375786, 0.010952534703392303, 0.05762432352639735, 0.04884050111286342, 0.02394246701442171, 0.022010805041645654, 0.05968578712781891, 0.030178359156707302, 0.04473131848499179, 0.01270858598218183, 0.040982485661515966, 0.05983915936667472, 0.028284507752687205, 0.03805477244895883, 0.06926729212864302, 0.10577772205579095, 0.04569078555505257, 0.012219538493809523, 0.0800595294276718, 0.0077871412759122904, 0.022918219729035627, 0.044608099706238136, 0.017515444014861714, 0.028184004258946516, 0.05767746130004525, 0.03649062942713499, 0.08352991586434655, 0.09443821763852611, 0.03946815188101027, 0.027020548623113427, 0.06962304803892039, 0.042697878379840404, 0.013261394160508644, 0.048093306832015514, 0.021717037016060203, 0.036372653921716847, 0.029921303321316373, 0.013987590300530428, 0.07421464149956591, 0.026856806725845672, 0.10496473638340831, 0.05988987773889676, 0.03823524421022739, 0.014865795910736779, 0.04116068645089399, 0.09491868404438719, 0.4014654684579, 0.09235134290065616, 0.08611353230662644, 0.17015578981954604, 0.08741598663618788, 0.1333135605091229, 0.2684205654077232, 0.11884877574630082, 0.07337660834309645, 0.099158981902292, 0.19868934934493154, 0.11145704425871372, 0.0693958840565756, 0.1769369564135559, 0.15678386203944683, 0.13421463168924674, 0.127514181076549, 0.1990583006408997, 0.19654788222396746, 0.16458770813187584, 0.31240002892445773, 0.3700418374501169, 0.10158046876313165, 0.06983206651057117, 0.1771655527409166, 0.18324681470403448, 0.13785810180706903, 0.15267460519680753, 0.28222391847521067, 0.21659590333001688, 0.2031334038474597, 0.14940399007173255, 0.14606693788664415, 0.0873112992849201, 0.14624490489950404, 0.15675588307203725, 0.09509063223958947, 0.17481962393503636, 0.08649803159642033, 0.06289012846536934, 0.08996308941277675, 0.16933451435761526, 0.10428562673041597, 0.13445873890304938, 0.16944274917477742, 0.16898549714824185, 0.12607315293280408, 0.06383453364833258, 0.1996656446135603, 0.07498197766835801, 0.12091895216144621, 0.09451266989344731, 0.09958536800695583, 0.1335954133537598, 0.16407393413828686, 0.0977097827126272, 0.20654910884331912, 0.1412641885690391, 0.16733923548599705, 0.10826152705703862, 0.24793736374704167, 0.08343189299921505, 0.21568711381405592, 0.22227970068342984, 0.08652126081869937, 0.06717518524965271, 0.10349958844017237, 0.17140437907073647, 0.13298355712322518, 0.13117952970787883, 0.1482923567527905, 0.09159839697531424, 0.1343597809318453, 0.20301182521507144, 0.08179882672266103, 0.09876192547380924, 0.10803001408930868, 0.10732472146628425, 0.08148595210514031, 0.19862027023918927, 0.1520770724164322, 0.08777661845670082, 0.0745621150417719, 0.09336084185633808, 0.11550232797162607, 0.12981633801246062, 0.0843499370967038, 0.07483306573703885, 0.29470984067302197, 0.07183563517173752, 0.1461694433237426, 0.13086352322716266, 0.1827022118959576, 0.17422125994926319, 0.08682909625349566, 0.12847064615925774, 0.1661302027059719, 0.1491977323894389, 0.14237092371331528, 0.13822497508954257, 0.10776127499411814, 0.160959986387752, 0.0863480064435862, 0.14572749438229948, 0.2113935668603517, 0.10830382205313072, 0.2241320864413865, 0.09844671309110709, 0.14539459662046283, 0.22893501387443393, 0.13751482882071286, 0.0869630093802698, 0.28590185393113643, 0.15637504257028922, 0.19453835411695763, 0.09105429140618071, 0.19069027388468385, 0.130702328751795, 0.14716436649905518, 0.20350870792753994, 0.15347112261224538, 0.19178966176696122, 0.11027132975868881, 0.08941042688093148, 0.11524378598551266, 0.1978273448185064, 0.1274232828291133, 0.10508227773243561, 0.14009854174219072, 0.10945525675197132, 0.22944433498196304, 0.12235034722834826, 0.19354262942215428, 0.15099586715223268, 0.10872686849324964, 0.08073512130067684, 0.2040888596093282, 0.15526182105531916, 0.13325896812602878, 0.142617094097659, 0.26052999193780124, 0.09922961209667847, 0.14486071042483672, 0.17157590424176306, 0.14004270255099982, 0.26160236564464867, 0.11378967377822846, 0.10819745002663694, 0.11849056332721375, 0.13575501856394112, 0.16909275233047083, 0.08904259622795507, 0.15887544199358672, 0.11112563821370713, 0.148529413563665, 0.1619789403048344, 0.17957670148462057, 0.2637507050530985, 0.06488496946985833, 0.17418640869436786, 0.11070507796830498, 0.1949176806374453, 0.09693605665233918, 0.1132095666253008, 0.1495071782846935, 0.09465527356951497, 0.1093516158289276, 0.12103172892238945, 0.19270731252618134, 0.10194852206041105, 0.15501422574743629, 0.17171339452033862, 0.1371339289471507, 0.1458500378066674, 0.13486656389432028], [0.025359809515066445, 0.08205325721064582, 0.06388393099769019, 0.01716376435069833, 0.03653894324088469, 0.0004237884428448524, 0.04781602561706677, 0.09052008608705364, 0.027557160356082022, 0.016996009289869107, 0.0408658423111774, 0.019866666189045645, 0.03729331408976577, 0.015185253378149355, 0.05845923224114813, 0.030849683680571616, 0.025056905651581474, 0.021304252622940112, 0.060066278820158914, 0.03263096798036713, 0.05369580190745182, 0.02512210518034408, 0.017243226102436893, 0.09068266837857664, 0.025750503882591147, 0.11450599471572787, 0.06292257516179234, 0.08280144596938044, 0.06372923773596995, 0.04512365485425107, 0.030341466517711524, 0.01832821075367974, 0.030787291325395927, 0.045681838964810595, 0.023647776870348025, 0.034273979035788216, 0.04062390587932896, 0.04349942384578753, 0.04956214324920438, 0.0040557577358413255, 0.15197590284515172, 0.04364821332274005, 0.03471186100796331, 0.03760797357244883, 0.046367171526071616, 0.04555062354484107, 0.01557336414407473, 0.04294490223401226, 0.09123003939748742, 0.04219440910674166, 0.02838149532180978, 0.06512074236525223, 0.02246904969069874, 0.05415347695816308, 0.033700580897857435, 0.06602806242881343, 0.035941599708166905, 0.028403579781297594, 0.02801985046971822, 0.06146220664959401, 0.025757455950952135, 0.018145030153391417, 0.010060685635835398, 0.020569546832120977, 0.022878995368955657, 0.0215795764233917, 0.008348813480552053, 0.06788421829696745, 0.02543712831538869, 0.03601468270062469, 0.04042180422402453, 0.0247227518048021, 0.012559772385429824, 0.07303300139028579, 0.07433108447003178, 0.04261293215677142, 0.009509246719971998, 0.04477851907722652, 0.015813810714462306, 0.04221003873681184, 0.014178532837831881, 0.03277484815043863, 0.03583630379580427, 0.029877778215450235, 0.02278250132803805, 0.056429213436786085, 0.062353763496503234, 0.05750277829065453, 0.08036125698708929, 0.034548981857369654, 0.0278663260905887, 0.03017991766682826, 0.0241170015942771, 0.060239666781853884, 0.03522845887346193, 0.11071205415646546, 0.03521701495628804, 0.02359403053560527, 0.0768296211026609, 0.04017985294922255, 0.01105519877455663, 0.016879204522410873, 0.04607074661180377, 0.036729055500472896, 0.03830483910860494, 0.02705880076973699, 0.042584615512168966, 0.021425506565719843, 0.025420827041671146, 0.019884603898390196, 0.02425137299724156, 0.036919965568813495, 0.003961575021094177, 0.019552105040929746, 0.0715426575334277, 0.0351981013227487, 0.05709928744181525, 0.058814977019210346, 0.04625231304089539, 0.021444923004310112, 0.05298156269418541, 0.049804135342128575, 0.11857781020808034, 0.026816749304998666, 0.0139847413811367, 0.011561325864022365, 0.04408257380418945, 0.111063832155196, 0.03339216287713498, 0.06429090994060971, 0.009061186192411697, 0.00904680615349207, 0.036238674001651816, 0.08017426545848139, 0.021692709415219724, 0.052348492172313854, 0.02307808204932371, 0.06839390305685811, 0.026982342860719655, 0.01528168526419904, 0.06426926149288192, 0.061441671423381194, 0.01636028002394596, 0.03867451028781943, 0.01591578737134114, 0.04777321111760102, 0.05249870286206715, 0.023143520920712035, 0.027951446718361694, 0.07838618679670617, 0.03426898438192438, 0.05435639126517344, 0.018332253603148274, 0.018565078316896688, 0.05662377858243417, 0.034931514455820434, 0.01758960868755821, 0.03674795800179709, 0.014661843524663709, 0.04594459634972736, 0.009283357376261847, 0.07081336385454051, 0.029537533191614784, 0.03359400849149097, 0.04831720165384468, 0.03803676794632338, 0.012877329027105588, 0.07157678890507668, 0.022816840501036495, 0.05715538267395459, 0.09796629863558337, 0.03937857094570063, 0.004431079905771185, 0.05357159978302661, 0.018598846036184113, 0.0643331826722715, 0.04101739999896381, 0.03628156271588523, 0.06343027096590959, 0.037668748045689426, 0.03139047184959054, 0.043150714627699926, 0.05796596007712651, 0.08638970772153698, 0.004326996941017569, 0.007486795966542559, 0.04762081851367839, 0.026401176291983575, 0.09446603333344683, 0.015328409954236122, 0.058832773720496334, 0.02461383421177743, 0.04703592450823635, 0.04411960326251574, 0.05972900980850682, 0.011323485159664415, 0.0370518266572617, 0.06539855792652816, 0.013342343918338884, 0.013153630607121158, 0.0822907147812657, 0.12939536216435954, 0.03894883775501512, 0.06053997312847059, 0.021291758566803765, 0.01014541941913194, 0.06168284344312269, 0.004708589331130497, 0.02637992860400118, 0.06824982250691392, 0.010801393545989413, 0.0221500931729679, 0.037955261577735655, 0.042853031773120165, 0.058727496361825615, 0.04705151332018431, 0.03186045913025737, 0.024137789150699973, 0.03104392599198036, 0.09620961282053031, 0.011969976494583534, 0.08843505187542178, 0.05648772435961291, 0.02385159103141632, 0.07412872306304052, 0.03657890047179535, 0.014375680657394696, 0.050897051696665585, 0.029476801391865592, 0.04753132292535156, 0.04055393619637471, 0.00967669193414622, 0.025479514224571176, 0.02278694122651359, 0.03569597480236553, 0.012303307485126425, 0.035278015784570016, 0.057073449570452794, 0.04928329239191953, 0.02029251238127472, 0.01994749534787843, 0.05440735083539039, 0.008467507013847353, 0.09167368043563329, 0.021158424315217417, 0.0602980478288373, 0.06687782151857391, 0.016315955253958236, 0.020180848841846455, 0.016153651267813984, 0.05336051443009637, 0.05330537285772152, 0.015339549590862589, 0.05459665786474943, 0.030057773146836553, 0.08201301796361804, 0.04015902828541584, 0.059811265746247955, 0.0709015606844332, 0.032769048266345635, 0.02581818032922456, 0.02789642760035349, 0.05348050486645661, 0.0036915320652042283, 0.02637916048115585, 0.016279584451694973, 0.025934782861440908, 0.009777065552043496, 0.01467065838369308, 0.05084354655991774, 0.016336481203325093, 0.044332521720207296, 0.02998291456606239, 0.010042934391094605, 0.020635507062252145, 0.027137783836224116, 0.0315474175295094, 0.01145367270510178, 0.021707867781515233, 0.07647707869182341, 0.02728263436438283, 0.03829979992588051, 0.06582946371054277, 0.012663513498409884, 0.04355802753707394, 0.04250608886650298, 0.03281244164099917, 0.015177007189777214, 0.014616062289860565, 0.02515895652322797, 0.0654352200217545, 0.03534380717610475, 0.03312356107926462, 0.06593357960809954, 0.10614475861075334, 0.014956624581827782, 0.0176625580934342, 0.04068563772307243, 0.09386129429913126, 0.00732191069801047, 0.07857288146624342, 0.03453001998423133, 0.03769882729102392, 0.03101384860201506, 0.012369068263069494, 0.05443814996397123, 0.03362851835845504, 0.07506373265641741, 0.0457412404648494, 0.10545899189310148, 0.034812774538295344, 0.033033174913725816, 0.062126176489982754, 0.0757670882740058, 0.04544918308965862, 0.03607984326663427, 0.026902461795543786, 0.15871984331170097, 0.01809330060495995, 0.009499836287432117, 0.027646535345411394, 0.01187280060548801, 0.019297579929116182, 0.03892763830663171, 0.06401086793630384, 0.011502202669362305, 0.05157745639735367, 0.018031156869255938, 0.016924867013585754, 0.03820555088168476, 0.09896937059238553, 0.055714469563099556, 0.054640808230033144, 0.04412079812027514, 0.04907879731035791, 0.027945524379902054, 0.08191820859792642, 0.05376902219722979, 0.029376860074989963, 0.022256626616581343, 0.03691420650284272, 0.008329287575179478, 0.0305257863146835, 0.030500117281917483, 0.05090448059490882, 0.12337940919678658, 0.12198902521049604, 0.01608402482816018, 0.07656854097149335, 0.03055492303246865, 0.01920006729051238, 0.042716792013379745, 0.08619363230536692, 0.2737186092417687, 0.18106242176145315, 0.13009001238970086, 0.13254088087705895, 0.1527315576095134, 0.13980904477648437, 0.23113926668884233, 0.11007870532921515, 0.12336187224718742, 0.09646898601204157, 0.1303438120521605, 0.18407898489385843, 0.07716450782027096, 0.09186656461679377, 0.13838030659826472, 0.18648952507646754, 0.09690760271041654, 0.12582309369463474, 0.199921730090864, 0.1851531842839904, 0.14099839580012485, 0.12630488112336025, 0.21867480740183964, 0.09010556692373939, 0.21386637323303148, 0.15798259380972013, 0.22428706171922386, 0.18806255160598084, 0.15528583695413545, 0.11511632954352535, 0.1198694811319001, 0.14328845572890714, 0.13437738467473537, 0.07769766671117395, 0.08916728445910849, 0.13013252260861918, 0.11745280338800512, 0.11386671612854116, 0.06535821477882564, 0.1961903748451732, 0.0893091682519298, 0.09599209675798193, 0.18401689681923017, 0.16559603449422866, 0.14505058148643002, 0.1885230393963866, 0.13222649227827787, 0.18007343576755375, 0.11860965576488525, 0.10800161951920018, 0.22748680174117908, 0.09147059172391891, 0.15584464446874335, 0.158661940949969, 0.1744524241075851, 0.1046325807692483, 0.1758950701332651, 0.14726201829034835, 0.12778469390468672, 0.15548557857982814, 0.15520412649493665, 0.0740972337371204, 0.10903662609052844, 0.06880481538246386, 0.14416447200346738, 0.07514333541621454, 0.18148197268601507, 0.11042617887142114, 0.12712590425508097, 0.08967306552221999, 0.09522221502265893, 0.09465715862461366, 0.17988859646720812, 0.14108813629718497, 0.11253706950810738, 0.10239907991490327, 0.14290926279500127, 0.12841152667533606, 0.16237731033470482, 0.1462110481224954, 0.20614183304132894, 0.09174543869448826, 0.17271959834033623, 0.11382307042367756, 0.1667718042153865, 0.16468297020765021, 0.0822663055441808, 0.18503634055377916, 0.13845855864929035, 0.05557619260798674, 0.19890203402610496, 0.14316712942672893, 0.12759270030073822, 0.10679360348149203, 0.21403080347226933, 0.1300739819998853, 0.07575121373520233, 0.1772220153361559, 0.12951082549989223, 0.12310019097640179, 0.08732483605854213, 0.18704108922975138, 0.20537724281894043, 0.1688410306815058, 0.1422258189995773, 0.12264048986253329, 0.08622089138953015, 0.11991493025561795, 0.13186441326979548, 0.1142382575199008, 0.08098558872006834, 0.1563354118843563, 0.10712765899370424, 0.1339940950856544, 0.09692767038359307, 0.18388356256764382, 0.16017335437936708, 0.17607238405616954, 0.148281981528271, 0.09413292777026072, 0.202076006680727, 0.23935757257277146, 0.15508015814702958, 0.1986339851282537, 0.0894518312998116, 0.13915507908677682, 0.23591973673319444, 0.1499597547808662, 0.16593147040111944, 0.10053792939288542, 0.13664157333550975, 0.21838376676896587, 0.12078636005753651, 0.10162182865315117, 0.17030861286912113, 0.1918471188400872, 0.16438732825918123, 0.10730962618254125, 0.12303710100241005, 0.1425161471706815, 0.16952005127677694, 0.12401978616253473, 0.1321607083082199, 0.13518488587578759, 0.15570659015793353, 0.16869214101461694, 0.12696197867626324, 0.1565300178481266, 0.16972426063148305, 0.15983757708454505, 0.16910655627725646, 0.12208020547404885, 0.11939541203901172, 0.16349688463378698, 0.17269392003072426, 0.13857163226930425, 0.13316530908923596, 0.20411321689607576, 0.10795446345582604, 0.23100277088815346, 0.15198782173683867, 0.11816982936579734, 0.16900238842936233, 0.10188719097641297, 0.11190403238288127, 0.15645788109395653, 0.12306557720876299, 0.1737202805816196, 0.2951923554064706, 0.244226343347691, 0.17804820381570607, 0.1543735890300013, 0.12573255167808384, 0.09784105379367247, 0.12967921880772337], [0.021840279914613348, 0.0281724991145893, 0.04368466390587855, 0.040148322805180214, 0.012178963424958056, 0.02884979978261981, 0.043905267302761786, 0.05736398554290645, 0.023584978189319372, 0.017873313190648332, 0.00679620668051939, 0.02252256039355416, 0.07179613807238638, 0.03884095545799937, 0.037612675077980384, 0.08138321660226211, 0.0494568584690569, 0.0809485036006663, 0.05384022013458889, 0.04717751515272539, 0.03949838697735686, 0.018679534186958335, 0.020794265437871218, 0.02522117632906884, 0.022554765891982242, 0.027365012756490614, 0.057359599450137466, 0.04909062714432366, 0.04009649121144321, 0.01854115333117079, 0.01152786335296696, 0.025656924626673572, 0.021365490938478615, 0.051598381251096725, 0.06903354529640637, 0.0672401899646502, 0.07625767757417634, 0.03305080834252294, 0.025502060670987703, 0.023256154818227515, 0.025664305285317823, 0.007742513616904034, 0.04911967109364923, 0.037158888881094754, 0.04894692880043294, 0.02324603749002563, 0.03724540845723823, 0.028779720632883254, 0.014860612009215401, 0.048401695166830905, 0.02594669618702028, 0.044889830096508376, 0.026578824181342497, 0.036481627175817266, 0.04825842726859264, 0.03606980943004601, 0.0067086170201946516, 0.04364633197837975, 0.04883098306891043, 0.06778664072044194, 0.03001097331434721, 0.040842227172106504, 0.07587198342662305, 0.043562153878156096, 0.018068401550408453, 0.04723940284748096, 0.03939785936381668, 0.04251787788234651, 0.011680977695505135, 0.06376083838404156, 0.019112226691504475, 0.05431143566966057, 0.07519743056036532, 0.06257945802644826, 0.056707604162511416, 0.025107445908361115, 0.0645666549098678, 0.024057403425103985, 0.03729577802005224, 0.027063901179644745, 0.015228251559165074, 0.08286489959573373, 0.09663930890383199, 0.05145078292116523, 0.038689984066877514, 0.013254678651719587, 0.01460569912524079, 0.006183979839988751, 0.026590741217660252, 0.09943067474523559, 0.02567864543379983, 0.02286948660184862, 0.04686274434789084, 0.042046035232488066, 0.02891083586291643, 0.01642765219003195, 0.08245098157203756, 0.056888187245931476, 0.020120324843446724, 0.01876115558843594, 0.051588054266176187, 0.0215845339698717, 0.036889062539557926, 0.022906248887011316, 0.008491675980621949, 0.03362992843904067, 0.044323259717202745, 0.06686282271402888, 0.0325886581413215, 0.05020444979891181, 0.014094739726715488, 0.010207387822447345, 0.03949467994971201, 0.03657253284472972, 0.013693569017050322, 0.028311189817031845, 0.02977893156639766, 0.01778442987415474, 0.018373145940131508, 0.03328180180687923, 0.04557272099191323, 0.0612103699677391, 0.04266323863703292, 0.017871917953016236, 0.07072910782881081, 0.04867246032517869, 0.026443085371283814, 0.037405964685603976, 0.0856427509279456, 0.03974236431531608, 0.057902666012523696, 0.01389727834975929, 0.02986720446642721, 0.032084142439998686, 0.0272164218040416, 0.08068020979408175, 0.011630819644778967, 0.03786048560868949, 0.021645341839757748, 0.02104839721141616, 0.043569360132096335, 0.016200840727833565, 0.03703794107423164, 0.01934545587573666, 0.028139766691310797, 0.028792205412173644, 0.045809714720235206, 0.04978673568984959, 0.02970667977933772, 0.009385315479448764, 0.06547148877871223, 0.07430889425450005, 0.009161240686808014, 0.0135484327620361, 0.021218614347162656, 0.03584564743505325, 0.026021441590273753, 0.028709994003293104, 0.03159643638355192, 0.027013993603759445, 0.012595158914336935, 0.034210046724183485, 0.05969346093479544, 0.025771996479306836, 0.08394896212848835, 0.027552354949875735, 0.043127210810780525, 0.025777056071092375, 0.0779547837737482, 0.04068334819748998, 0.021668348417733796, 0.04303617526602466, 0.03291983412054833, 0.04122499725781381, 0.06417658209102228, 0.04384804400615394, 0.03858546740957536, 0.026291091671737377, 0.017676046627457254, 0.021875040256418288, 0.036527117117657326, 0.10544715463765897, 0.05403295588621404, 0.03919366114132572, 0.07737407548120245, 0.03273950336733833, 0.025297404172306415, 0.0328694014751818, 0.025257856977987103, 0.05586424238572363, 0.023432275738741737, 0.08627714618341997, 0.042320934153394774, 0.039233855859492905, 0.06790844941860996, 0.022059784932935145, 0.03661685019324068, 0.010922162309725536, 0.03971536127210129, 0.01762945088557899, 0.05897784874832723, 0.0766669274889864, 0.05381049712013919, 0.034257199076819234, 0.040156768445740454, 0.06551860031322576, 0.0254597230014042, 0.04854425431403797, 0.027743921818910167, 0.05939102091360837, 0.022598007126362063, 0.06428199674701318, 0.08179196185665205, 0.0924501969711855, 0.03251452500990126, 0.07747256589937024, 0.04769279570609797, 0.03930074934032746, 0.05432238605862949, 0.024825398249959107, 0.006402842900570249, 0.03541940233844798, 0.0184837630513357, 0.03897837523254566, 0.012612926857400453, 0.024797597397991922, 0.0018905071010522079, 0.018996689141204115, 0.017242125868506264, 0.019910747905669268, 0.01291038057388505, 0.04046619949804153, 0.03424686838116031, 0.05798385325761046, 0.0018147184005101735, 0.051626438144012354, 0.06218715505383443, 0.08120259270071983, 0.055498426663689315, 0.024821472288749646, 0.03179511673806701, 0.02842810961737996, 0.023520030990766827, 0.05140214998391457, 0.026957219306495972, 0.0373214600404026, 0.02523772622225806, 0.02435674312437186, 0.06078370184695814, 0.12261101917829365, 0.03173728116962593, 0.024470573735015932, 0.023154042719397694, 0.02785926826618379, 0.03387635115359444, 0.05371591410948895, 0.043819174461532384, 0.016426707807113416, 0.08536518769687973, 0.03452265416854061, 0.021922593368799426, 0.01693911624897737, 0.06369964088662528, 0.01404748347340501, 0.0609659658948658, 0.04923685250105336, 0.04238454363076016, 0.025236494257114828, 0.01630965998629108, 0.04063819593284279, 0.05178707971936092, 0.01472249368816847, 0.03831872840237338, 0.05127385120431427, 0.0302072416889132, 0.06114064890425652, 0.03204853790521156, 0.019432045955909416, 0.033141535895993, 0.0244122854564921, 0.061139847384765744, 0.050617076485650614, 0.04526235112280119, 0.06875786712043919, 0.030697792026330717, 0.04487573300139047, 0.06839772511739284, 0.02638215504703112, 0.04774450484546833, 0.024912337139539886, 0.02121149158483604, 0.009816088604566175, 0.029230955697130412, 0.07371956220595166, 0.05504247710632626, 0.029579974761873018, 0.04977580385457259, 0.04320909938542172, 0.013721628693019738, 0.01456492553188582, 0.03700696011947002, 0.04039991457830183, 0.04238062509102747, 0.02277942512591835, 0.06241148032131605, 0.019369247274880763, 0.03673983890621457, 0.03657111163192894, 0.01352902096186881, 0.042059104453073815, 0.03165136273310054, 0.054304110672092065, 0.026515982826822437, 0.023197215305117425, 0.08504354089382105, 0.03316192269267049, 0.02190592473198194, 0.04161306998867076, 0.02680485453311121, 0.05137801534147002, 0.009899170181597583, 0.0018669720907382725, 0.02222909108240856, 0.041646722675068304, 0.03235280732042156, 0.03558300879376475, 0.01176831363409292, 0.02664274536073208, 0.023508264239353593, 0.04595655977027491, 0.05102253402583301, 0.03775335288082715, 0.03836574345768895, 0.0249173800330027, 0.021447266335599124, 0.021240726637188345, 0.04979435012501199, 0.09091571017052047, 0.016986778828140814, 0.03753148041141685, 0.08382792526390404, 0.015615254669683054, 0.0066179706391267246, 0.06384548032656312, 0.04033628283650614, 0.03711837875016499, 0.017985023114306387, 0.034936542506329715, 0.020960051951988135, 0.030161363974912092, 0.021762669821328018, 0.02282672776345862, 0.05355232991860248, 0.07133921259082854, 0.18400220229523256, 0.08616569044534117, 0.14082231384236366, 0.15439150447491556, 0.2706686791498214, 0.10784118203446269, 0.2253690388170071, 0.1569893627311103, 0.10331958794267848, 0.13057724718237296, 0.11016102434950881, 0.14057740510907024, 0.16893813328351825, 0.17832929966971278, 0.11577966113691218, 0.2380807074951008, 0.16985835187369958, 0.18875049281632528, 0.10781217148178257, 0.0902809809485916, 0.10310363039025106, 0.12811741355108097, 0.12930983706610277, 0.07846155931474641, 0.1734529886743985, 0.16910624457523227, 0.1232768666523043, 0.1234417718660552, 0.21618715807562694, 0.11909015185665339, 0.09434016508748755, 0.12869100464740768, 0.11581681304960512, 0.28015273273922503, 0.2297657888266258, 0.19391705776797608, 0.07314250527997501, 0.16396584775066003, 0.1120555418310687, 0.15113786968868226, 0.12051514218910597, 0.16825701983179897, 0.25079218321479857, 0.14049409161088988, 0.10649512652889825, 0.0785510177956894, 0.06816572975367308, 0.13400552415987477, 0.13580618222476915, 0.146519351110328, 0.08559964699088596, 0.07952737985760905, 0.13593435112852603, 0.1030596432974562, 0.08540037291822955, 0.16759679041570053, 0.07588463704450987, 0.10589089957647957, 0.20563067140756175, 0.1559635513694957, 0.13172621052945033, 0.15289680421119556, 0.13245954149169847, 0.11657534734695219, 0.19588756375014782, 0.2143649331992492, 0.08083975670160726, 0.18373274331679568, 0.19893871096428484, 0.14715868164785206, 0.15976385213434696, 0.2045143922441639, 0.12463259976357222, 0.1527636926039122, 0.19208022742532194, 0.08446957872365601, 0.10615876293741167, 0.18095259874826297, 0.1381625307840295, 0.12102320906706154, 0.17031600465998054, 0.09866168358712457, 0.0783851626329124, 0.09406925149960443, 0.14690644049551338, 0.14947502844734117, 0.13800601183902472, 0.15928829874610528, 0.07593576359795406, 0.0948327210790012, 0.12267641723155975, 0.16961172135779634, 0.15455869550351053, 0.11281942701316439, 0.18123222514986992, 0.1697028719354421, 0.15090545872226357, 0.11466687006759457, 0.1495163215440698, 0.09191084856865928, 0.24019790638703853, 0.14577580819604918, 0.07248335939948447, 0.18601365998620167, 0.08541508970665745, 0.17925245716469362, 0.1299351261695847, 0.08131661626975983, 0.1951766011188738, 0.1044954764074646, 0.10710948379710317, 0.07530539078288712, 0.09362417069496587, 0.14556653739418834, 0.0951536999491509, 0.15563817898510024, 0.0966733660607133, 0.1450064533855766, 0.15898006997304037, 0.19179956201696768, 0.09746482945047319, 0.11916009927517734, 0.21600261563435197, 0.11945405654842034, 0.14452027244260535, 0.10374890553066507, 0.3122464340412989, 0.10626052622683346, 0.13787432515528053, 0.10435271688038483, 0.1697183382930234, 0.08651962809381075, 0.07959283728268929, 0.1779571719816886, 0.10140144790057093, 0.11701202703989111, 0.1943018168094568, 0.16298174508847296, 0.14940810156986117, 0.08348048882908188, 0.13699479110073298, 0.13910271314671263, 0.11042322512366809, 0.08634219542727806, 0.18169251998187974, 0.220126626372803, 0.11264705579378642, 0.06526958008180372, 0.1288206726894714, 0.11286866109003313, 0.0691712656407617, 0.12799188669305295, 0.12129051581723616, 0.09980203802115284, 0.09541359264403582, 0.08953400189056993, 0.1201858364220243, 0.16878087219083682, 0.10441479753353633, 0.2889179717749357, 0.14541430806275457, 0.14614477433497086, 0.13519217376597226, 0.17489705962361768, 0.1592864582198672, 0.1377785881049931, 0.18595465924590826, 0.10432337978272699, 0.09792286073206924, 0.13957414019387215, 0.13775909930700436, 0.10469557426404208, 0.2273189279367216, 0.15834468766115606], [0.06143237973446958, 0.08401060491451062, 0.025807803249335848, 0.034890399474534206, 0.04823209215828683, 0.001989218540074944, 0.06907722068717703, 0.03713761892868206, 0.024460398890369106, 0.027925760987272952, 0.06733718866598792, 0.05717858592106495, 0.01415601607732242, 0.02055321030638879, 0.017458929469285067, 0.02067379631625954, 0.012409681366989389, 0.023462032149836887, 0.022150903969304636, 0.015680187025282066, 0.03957766690291464, 0.01503807065091678, 0.05168800300452858, 0.030663235775136854, 0.033988575014518574, 0.053357349170255475, 0.030240799751481973, 0.01666769057919737, 0.07876765070250258, 0.04330205709266011, 0.04256812870153226, 0.040021630775299855, 0.042878450331045315, 0.04644929758796934, 0.011897487220267067, 0.03833527458482422, 0.04318528757721651, 0.05237249322817661, 0.03175324105541222, 0.04309172130888328, 0.028542827094497625, 0.02908437225414673, 0.044088099093642086, 0.031780607750988565, 0.019782436138484627, 0.025993970994022675, 0.09242548345355317, 0.0729668018175289, 0.031205098202917725, 0.047360948083223775, 0.10382315740571357, 0.011400285384297604, 0.06346594600472599, 0.011689289749483578, 0.02039287115621846, 0.025028947093233, 0.02099380668369122, 0.015664190032111946, 0.008942619751906022, 0.006277103138927487, 0.05503413536644075, 0.005663866513714311, 0.04691569658461958, 0.018638589899637736, 0.02218078097939724, 0.09470197692280635, 0.0288374745650799, 0.056539678407716565, 0.019794527579506394, 0.018856981696444564, 0.036613217380363494, 0.02006001606787322, 0.08298579545225948, 0.014592582592740655, 0.08090257208095863, 0.054868165170773864, 0.038200255658011883, 0.024250426758953836, 0.032646430627210066, 0.06225459401321132, 0.046508172163157724, 0.04477375448914245, 0.026002453741966747, 0.024062086376943626, 0.04731152846943587, 0.08756565555813722, 0.04638749895093497, 0.023185279715107754, 0.0473104152479209, 0.05775207682745531, 0.039307747792918235, 0.0456301817757776, 0.04315097066864837, 0.03253277071053162, 0.013468740944517776, 0.10654443482053466, 0.023752000379317906, 0.04139308257435914, 0.045682792624575086, 0.06776692185667343, 0.028184987604618073, 0.08656891412101686, 0.05392979735916015, 0.05616199203359429, 0.06329465832095593, 0.03550073059159331, 0.08609635900938883, 0.08764554033405147, 0.032710006707930006, 0.029535883768403437, 0.05862841222551651, 0.06809294733102433, 0.06420991936465725, 0.035050966835115105, 0.0750891437928658, 0.027307448071951512, 0.011539386123331496, 0.02267368578031892, 0.027697474506567232, 0.060878592848894186, 0.00698720951731957, 0.03307801176561043, 0.03451882097579073, 0.05213705429923721, 0.064486977935303, 0.021616628146148287, 0.04251762555213645, 0.04839065943087917, 0.04760880314279348, 0.10081970802275464, 0.011666063310258323, 0.053873943325015716, 0.016861192598298658, 0.02814567047607852, 0.020980986082577147, 0.07142858201405033, 0.04965799904312007, 0.006975536925892811, 0.022898079696460627, 0.061912178207421675, 0.019393580441828817, 0.07843716492061503, 0.04076694371178746, 0.026109694081242196, 0.042087747642653994, 0.029208412961452268, 0.06618514540605247, 0.04583081397868227, 0.028413624750101008, 0.029330015713640023, 0.06477145056123845, 0.012648548090510303, 0.01999839183554286, 0.06076126672269311, 0.09439630855922587, 0.03874384914524853, 0.025781232507142704, 0.009531436935503734, 0.044899351851199754, 0.009227651771652745, 0.016387960276915692, 0.018193798532593064, 0.10287090772180818, 0.023981928861758206, 0.02334397315280512, 0.03732982775545679, 0.010875969182961853, 0.014549710576829966, 0.051806791161652654, 0.018223020597361028, 0.07631788059370592, 0.08737370648304932, 0.04445320235390682, 0.11121673684101552, 0.00870334763021674, 0.012383468711050227, 0.011678610244416632, 0.052199480051058345, 0.03645434211648535, 0.041676252731122077, 0.04505820856138598, 0.05781915955594741, 0.03740614280104637, 0.07145293187932111, 0.03546265099430457, 0.05757803577580489, 0.027803798293462023, 0.05040915639256127, 0.016256115886790212, 0.04233743209624663, 0.03455203950579744, 0.02305823702045018, 0.023700816309428774, 0.03462828404735774, 0.029637524603458587, 0.06117142576840706, 0.022924839686311316, 0.01857384679169627, 0.025396701676072553, 0.018233479313494172, 0.0715973018668592, 0.027481596735015046, 0.10011304242652841, 0.06644218083238229, 0.04989098146324977, 0.03201449930202216, 0.03997840438387357, 0.033318382265861146, 0.026708406876423396, 0.047203019057633355, 0.01860123018559534, 0.06900709515321068, 0.020423998685146216, 0.042766159676830284, 0.04874363599810749, 0.025953900585591327, 0.040766661695670336, 0.05034688649175223, 0.04849706485401839, 0.05133522310643457, 0.023277781001525, 0.042458313109818846, 0.09216837381245568, 0.04437516181496903, 0.03284561935288366, 0.07451668076100759, 0.007049450659906142, 0.016745078028179705, 0.020030851519550197, 0.01528402488474967, 0.026575150550343096, 0.03580039498046972, 0.04393382514535915, 0.03200997962267138, 0.04082309089426417, 0.01331024232058553, 0.04588218915159814, 0.04938874415529426, 0.013978230890643317, 0.05517618243175093, 0.021420998018584214, 0.012506306211435003, 0.014487026001006598, 0.042922760258079506, 0.0217955172774964, 0.051304739390616305, 0.03635863104136661, 0.02724149340792792, 0.07267081848112866, 0.028229111994733103, 0.018861688768083695, 0.014897104338160716, 0.06259168119868264, 0.011669084778986871, 0.1313413179013878, 0.02666300228156615, 0.018461622930772137, 0.020830964640481398, 0.04875530627032276, 0.034552358629298396, 0.02390359888522653, 0.015383045938506257, 0.036925635577063076, 0.026995562366209924, 0.07728592318017036, 0.06931288226041943, 0.03333764470880851, 0.029819950068485923, 0.009942369670170592, 0.026140055342693813, 0.029501331227947958, 0.0412824098020792, 0.015406123020511586, 0.046170992209226824, 0.007376279045274714, 0.0252586325223092, 0.020115059305680916, 0.02862778816052014, 0.05064274366304744, 0.044107480280217715, 0.07276546457433142, 0.05761186657764483, 0.06203961980645545, 0.028325537386990618, 0.026872252674365882, 0.012228255945956334, 0.03341089097375516, 0.06671344322967343, 0.041353782144142315, 0.04074114665854722, 0.03281574790889863, 0.01834255461290013, 0.03225832449970767, 0.06664701359113678, 0.020090004400117323, 0.030274355958681554, 0.012574642241816036, 0.05832505936268717, 0.037935995424049906, 0.05419799839728512, 0.025573748425813392, 0.028667532023973763, 0.023599667147209402, 0.014318302437459351, 0.006676514030914404, 0.05343973127310164, 0.029256125635583885, 0.027284636307740584, 0.05382284645747859, 0.051351813817746006, 0.017833975653047673, 0.09325933089712635, 0.05759870087786112, 0.01918276226206217, 0.062493539589922875, 0.026020998157036956, 0.014281638486863812, 0.06407188731827773, 0.05621637661533896, 0.0465909290505806, 0.027509289975569118, 0.036363978215376846, 0.0476370826800121, 0.0065262499992968515, 0.014695166883029742, 0.08948930975748226, 0.05297696880006697, 0.020771897106897086, 0.06790741041186266, 0.0466125515231397, 0.02736739319516346, 0.05261099722702056, 0.06108420486270916, 0.012549146686069435, 0.02954402512841625, 0.03566601801139768, 0.027859541005454957, 0.08228512640926056, 0.05394721927586943, 0.009110591890930664, 0.034736229426926, 0.021014308513258584, 0.04151117682340555, 0.009766963994479738, 0.012191965852252906, 0.048112424556165934, 0.06437861695303582, 0.03505071821564343, 0.045826123605365865, 0.07806290726875886, 0.02526438231143402, 0.006646698248005123, 0.1307112938957289, 0.1851143699605018, 0.07794224889948964, 0.14244812191464007, 0.0907556882884819, 0.09498109124251641, 0.17413493333151564, 0.1286711893044412, 0.1563762003206648, 0.12354109348962083, 0.16215677373111248, 0.16394110454712063, 0.1054484756605234, 0.146784579847008, 0.14737816440174356, 0.13290389499161392, 0.0781717654899694, 0.1696873313630931, 0.1136962670716457, 0.10962588392430916, 0.12950249860296026, 0.11274485601461492, 0.10125515575055033, 0.07856214258936234, 0.19059085578192025, 0.12524274905445054, 0.13259838247904554, 0.185262517479714, 0.1999197411350906, 0.17397783551132306, 0.11624951483099721, 0.16084887203760445, 0.12930909491842613, 0.14960626984247938, 0.13433959451504052, 0.11822748681879602, 0.11939138959860429, 0.1450671165366657, 0.17181404458824545, 0.11065807033446617, 0.131663647480309, 0.13229664007667452, 0.10339782515075058, 0.19615245109889656, 0.07786362577462569, 0.11634314418188296, 0.18321812327485532, 0.15813132020412013, 0.1543964323354885, 0.1382830407237634, 0.26270849222783, 0.07022777965175919, 0.1526174004538916, 0.10757319992990233, 0.10678078659111634, 0.10367745155235752, 0.14461743441643193, 0.14908137847669423, 0.0974606437375769, 0.1796105137327686, 0.13211260229581967, 0.1913738512666896, 0.10082399763632566, 0.08824253134662285, 0.11751618279959075, 0.1443538977764547, 0.11006148750311695, 0.14745888038305566, 0.09955343339242972, 0.11847281857626513, 0.1316096488153562, 0.13729068537941203, 0.15280066640116274, 0.11116892026620917, 0.12002371426206082, 0.1360458810813725, 0.14581625524442643, 0.12319374611251988, 0.21732984285335988, 0.17686982173472643, 0.13817588944220915, 0.14952631085179746, 0.21831899211974815, 0.1458828110480681, 0.19045056018512696, 0.2087850810494274, 0.21403396502137184, 0.15703116048825905, 0.16997271683067083, 0.1783810867345892, 0.09796034661121666, 0.17852590943221003, 0.13041486527072266, 0.1752562145702541, 0.05394608378992416, 0.1874039846006781, 0.13257233309559524, 0.14056667365366593, 0.16389001510106027, 0.2093391536618583, 0.10770289765787311, 0.11240508596529253, 0.13189816614612937, 0.16533074638573453, 0.16827453451696783, 0.10885573501582257, 0.16324096242897213, 0.1068700521136634, 0.13623370381537825, 0.09088831007829867, 0.1819989676005207, 0.14847611251752824, 0.253084113355726, 0.11297199773252942, 0.18437977734720334, 0.10965217821649276, 0.252977303462103, 0.23696313699474558, 0.09129485857556574, 0.2011482181842439, 0.12233726316480897, 0.14419533050386235, 0.1274266670225188, 0.14620476955315098, 0.12595865438925102, 0.13803084410028532, 0.09767819690750912, 0.10639685875503346, 0.12178916484117508, 0.289279991411604, 0.13343540631467476, 0.1631281856680289, 0.11724287949618883, 0.17490068130427971, 0.17225128831341863, 0.1480366720352322, 0.121486947464291, 0.10977923389873467, 0.12026437791064382, 0.1729566848371178, 0.11877919940161519, 0.20729046984342858, 0.2754903235472739, 0.16409164178185165, 0.2501932700397447, 0.10970124159939587, 0.21547025826293975, 0.12043798851664178, 0.24181578832212836, 0.1923045192961581, 0.1362111870548688, 0.07895871662185527, 0.16478841454954818, 0.13738548732362688, 0.1171476767922286, 0.13067872845567763, 0.15900997852440923, 0.13256446633022279, 0.09554009171552025, 0.1600450073601678, 0.10922616318566725, 0.09746293697389774, 0.25412864168174565, 0.13143067248165607, 0.08641715234261937, 0.12968947528861463, 0.11723766219802201, 0.14050465979380533, 0.10031241297838278, 0.16940881818300113, 0.22656386689050123, 0.1636556300218217, 0.12027749908156693, 0.3514773992355913, 0.08257048219093122, 0.0973020690435078], [0.03749848452571314, 0.04127291773329489, 0.031625361589249223, 0.015974708330759313, 0.06736726048984565, 0.04753428409458138, 0.06568209544639103, 0.03519614205288235, 0.05376537454139907, 0.03827469678071793, 0.018106627721863333, 0.03588376785046421, 0.06269930745474994, 0.07979616348166019, 0.015969361156749073, 0.08004441930097528, 0.01637152541661635, 0.0241509956686059, 0.03812571805610787, 0.09380351810250431, 0.0285419476495008, 0.015884106942394283, 0.08130403686664067, 0.03267715554102324, 0.013221302415331593, 0.06352053096634336, 0.04489135892072227, 0.02470525196258677, 0.10802069271449, 0.028475443796196487, 0.038475020992336795, 0.03506876353640109, 0.06998860029852949, 0.02493866482836893, 0.05218576145125553, 0.013820941967424005, 0.04828475495742168, 0.025522686810290907, 0.08928450668463483, 0.054287928142002784, 0.06115589632827323, 0.07305379636818543, 0.010496885715838289, 0.01357476323391893, 0.02780579095997382, 0.011232851302338531, 0.00999029663944384, 0.014837824364803964, 0.06013610378431622, 0.029084335146762896, 0.02229084519058233, 0.02211704162618844, 0.027429496112745255, 0.031005510572867934, 0.06303659130935557, 0.01358971750960336, 0.03885966871166602, 0.012992232041142415, 0.051766856195172295, 0.07389365520793945, 0.0517933248920599, 0.027181926780031063, 0.007966619486978743, 0.03258794567955192, 0.02172577580495272, 0.13606060529127717, 0.05470233969390392, 0.05379380992962979, 0.04073789234098513, 0.04036917111079674, 0.026156436397286598, 0.038650887727271765, 0.01814530845877016, 0.017589061353646684, 0.054839006188558415, 0.08982452302007005, 0.041641583302407525, 0.0706760813773144, 0.04608885501511395, 0.040323247012565844, 0.036590667223208584, 0.051125417958246544, 0.030149994272505865, 0.03404922332265414, 0.02249537552415859, 0.024998183216666803, 0.06939695274922997, 0.08695360636920668, 0.04711175715783611, 0.033092654339270666, 0.026395059139758814, 0.015222550009639235, 0.043917854127357714, 0.03121938083495479, 0.030232632416300476, 0.040601433647680096, 0.090944453550037, 0.03744122412172146, 0.11283426996669732, 0.07357257243711501, 0.06291657118708827, 0.014879802092764294, 0.015710240295447875, 0.003298157153039938, 0.05692117199942004, 0.01682620404608315, 0.03748522976820823, 0.14496893039904535, 0.0557747913262574, 0.0369742536713602, 0.025612872595957015, 0.017380729368596803, 0.00361686968972208, 0.07938041977467947, 0.05275625408103224, 0.026787115348270163, 0.02919389655289706, 0.08147036700393073, 0.052781483391299844, 0.01765345936291851, 0.011082784403697588, 0.04182301614491735, 0.05554843999561854, 0.006078503956814529, 0.040354762313654646, 0.049394989327993244, 0.015564740388072096, 0.04277152169379406, 0.03666121207061224, 0.02192161187849706, 0.10377309954492375, 0.04907084890874103, 0.05609004452708177, 0.03713898448040709, 0.03892915970936883, 0.03315118381578941, 0.020906472600472625, 0.0514939684944693, 0.04871450670179911, 0.025335789905511774, 0.09271414179238491, 0.04969334011548199, 0.03127766540274024, 0.053270157950464636, 0.013693317614524858, 0.06196045862452593, 0.05185734626138583, 0.036598608203348704, 0.01452412318030838, 0.06345136280287988, 0.034111574859707616, 0.020056292341905646, 0.038032070151530206, 0.03735644117114134, 0.01718679504847387, 0.056085513715515845, 0.06193048699060455, 0.03037868893443374, 0.035692059973371215, 0.025816913112066686, 0.020537122400128283, 0.012856839257437969, 0.07156333376769908, 0.05605626938631758, 0.04147333471337333, 0.07317682961001992, 0.019931067909055855, 0.01990293680137256, 0.059515193352126516, 0.06439249511458911, 0.009515384281257866, 0.0375952976901317, 0.04082294246472884, 0.023885666741989553, 0.07522398460423574, 0.03467710623226594, 0.0167502359545324, 0.05924104028963484, 0.02461595675413264, 0.0356188285513781, 0.10559205155004747, 0.03142001303785946, 0.04905816189420875, 0.050625948861124925, 0.028793376150133554, 0.04234835651004687, 0.06780944691854529, 0.032452318191644736, 0.030393014239962213, 0.07446438903571106, 0.03612374501244631, 0.028776280778401997, 0.0049303305331704905, 0.040474337147315964, 0.04721290446468629, 0.0026025606894108932, 0.03518424913636409, 0.008964996432041517, 0.025034038226294797, 0.03224511798180174, 0.048019288733485155, 0.07806860696291551, 0.05089979022159241, 0.046409091737587005, 0.0738769791496452, 0.006281293026404455, 0.054886607540538535, 0.02813413564581424, 0.03700157583807595, 0.07443703347234987, 0.04690209301770665, 0.05030785694543738, 0.07970218532136641, 0.061947489593876526, 0.05641073395963758, 0.03517494631523732, 0.0862564031558577, 0.012676852675213013, 0.02648843244969612, 0.03625142038799822, 0.020143127330811694, 0.06178396848554257, 0.08077053658780642, 0.027147183136548847, 0.040420895093120635, 0.005563036474995897, 0.013280048970045755, 0.044091242089052685, 0.04626648806151934, 0.024769982082943898, 0.04081169892742764, 0.02545428491430357, 0.013033792311034631, 0.02762866442935774, 0.036313322925707325, 0.024769414339971263, 0.040789004051475786, 0.03812940281932242, 0.04308413655962795, 0.0440305084339343, 0.05057122660218738, 0.06418060453142971, 0.022549433560925536, 0.05738565625506453, 0.04652143063140102, 0.049735809516278096, 0.023476533715438563, 0.058146513474639505, 0.02237872475234326, 0.023365818269667216, 0.02761360625299858, 0.0904311693739146, 0.07438861575792544, 0.01859343763499055, 0.013327230080903973, 0.01631463794183219, 0.014867069621686824, 0.05376006447477266, 0.026736567670013756, 0.057452642504358664, 0.014817412520642392, 0.043876163981622085, 0.03986095209256746, 0.01986605206184322, 0.049702483374858275, 0.05118064487760421, 0.04703706370492, 0.03869468557240907, 0.020094926694582682, 0.015831082346267067, 0.04201650517643429, 0.08519429335137829, 0.09138850276940502, 0.016991682568914257, 0.030113981556496583, 0.025043088717211504, 0.03248399305448402, 0.03834048817225266, 0.015281098039849894, 0.0221773374141776, 0.025206214631907642, 0.023631915319128893, 0.013234364214440575, 0.048205037164734676, 0.05616315720544662, 0.02240868710941868, 0.07017017414909787, 0.021567809671978466, 0.06949241520487703, 0.03294928254035767, 0.04349729388195556, 0.010147349003091222, 0.026039609365398064, 0.1161333019263111, 0.03302045079180971, 0.038202003415790386, 0.02125307968526613, 0.006054322930140188, 0.04386525812151376, 0.012752528546116082, 0.02763237145700259, 0.012943305955559481, 0.03433125799347181, 0.023087531444616616, 0.04924402906908654, 0.04002026893431321, 0.051048932218691334, 0.047645706436014734, 0.027023537622881122, 0.05187371061765589, 0.03669714315037709, 0.013901682996220188, 0.03203922766260803, 0.05091674087452702, 0.023018721367407124, 0.008857407283358043, 0.07772478478727862, 0.07665382116101682, 0.00902910964214243, 0.05439225926238578, 0.03998176631284878, 0.014524143589369487, 0.035042439558310434, 0.022740718413842842, 0.03416295374336187, 0.023069389644660987, 0.02719008298299741, 0.021957626449875534, 0.13424908218439668, 0.023131616871978622, 0.015611228518537246, 0.03488106325676199, 0.04696050375059713, 0.052087604999542236, 0.016446283807454165, 0.04745674079458695, 0.03861688994220458, 0.049628684209892526, 0.08067004237091169, 0.028626762141357176, 0.02905797777202679, 0.0958879289100878, 0.03699140470416751, 0.00864931927935686, 0.02326080808416009, 0.03562326659448445, 0.04385754349641502, 0.031030780701257754, 0.04823615541681647, 0.02168731029087212, 0.1076460862532258, 0.029352933233894873, 0.1006278108980041, 0.210550234769471, 0.11520914995344356, 0.14392839482752606, 0.2280735585372895, 0.11832310512545519, 0.20207418099744245, 0.12513135268818587, 0.14059696812182665, 0.12740884063532576, 0.10541169482166879, 0.0913680120720528, 0.11303850158583373, 0.2773780206916854, 0.09423672454431653, 0.21616502723190933, 0.09006837048218586, 0.09150864163530059, 0.15816914004972205, 0.19482103816699237, 0.19662557024275884, 0.08990461559733376, 0.16484996827784926, 0.10093241799040698, 0.08004378105397336, 0.17693139030598104, 0.16186220047529787, 0.11657544382615015, 0.162521390884649, 0.13328483939403668, 0.15951745910570025, 0.10239838229608722, 0.15740996750537306, 0.19964530976722017, 0.15492429229198024, 0.19368169305380434, 0.1313727255910635, 0.17523475165944546, 0.15273221069946885, 0.15148733218666166, 0.15613960364134982, 0.19228881545132026, 0.13197640335420147, 0.11805057365563698, 0.11441007212852128, 0.10584904986899346, 0.12986776884645224, 0.12055092855007388, 0.1193838419567328, 0.08856739907059819, 0.09156245476333424, 0.2112380720791407, 0.13629982917336747, 0.14681327127618715, 0.1251733730896376, 0.07544451378635131, 0.12351965284324251, 0.105292134830961, 0.18139947555027902, 0.09322058336692862, 0.14961847075028345, 0.111823576153256, 0.1618282843264751, 0.09851665308815427, 0.11088769824709743, 0.22088020312367007, 0.11964837307459675, 0.24235979741206393, 0.16316183464368805, 0.1830116577912122, 0.11066926192143, 0.15099545154953375, 0.1240518840495497, 0.22642934520263225, 0.1173048785130959, 0.13448582729324698, 0.20840260782279074, 0.16891799139557406, 0.14023382042068988, 0.11592462484259158, 0.19450874242465943, 0.07454977312590927, 0.11589589630602859, 0.12937986612087116, 0.17753034800989553, 0.141922147013247, 0.1218267175136134, 0.1400436376570724, 0.1545468656695448, 0.14683112734928727, 0.15267392242094502, 0.0919434882234782, 0.08940682004322298, 0.20326794037828222, 0.09944022618583404, 0.12643123918678612, 0.19441359909251332, 0.08778889357927255, 0.14234036207199097, 0.1492041297024116, 0.20190097857266665, 0.14781956415390596, 0.04676639873650856, 0.10528946309932508, 0.14991142612416297, 0.13825945527059957, 0.10333435668144375, 0.2328791725449264, 0.1250873284880072, 0.07348946674028412, 0.13362126977881417, 0.09952774766134098, 0.168746703711804, 0.21159734576940536, 0.09687504469184205, 0.09301844460424036, 0.09190033975755796, 0.31954613921698183, 0.1820456635323353, 0.1385561510687694, 0.1696849416475743, 0.08217545924708247, 0.241179931035731, 0.14969332376495004, 0.14018282003235072, 0.18151661613956094, 0.09388979276991449, 0.09303880171501078, 0.15066727384692058, 0.1710476286825724, 0.188998696685303, 0.18041497212834656, 0.12244595811353065, 0.17251040175324306, 0.11299458870780654, 0.07966200544615276, 0.1812812514253892, 0.16784652310889214, 0.1903281206614338, 0.08058341147261672, 0.20255200535757467, 0.1739682024344802, 0.10467234504176304, 0.20484121923800558, 0.09229340343154036, 0.17576065234607086, 0.1387068664189428, 0.15800159279024228, 0.09185086077195592, 0.10060984350275248, 0.14158433623379096, 0.15267267561284825, 0.13659532269230112, 0.11537031474290416, 0.10926193470368162, 0.1219583374040667, 0.154241175041534, 0.1229215189232491, 0.13644864462548867, 0.11968418912147172, 0.08644021087093279, 0.11555518372915685, 0.15062310121720657, 0.1530419386108406, 0.12015185347991064, 0.1484690621146001, 0.12746417516609654, 0.059398691009846516, 0.1739566694595851, 0.13883182924473658, 0.10052933532278985, 0.1337893959134817, 0.1038110232912004, 0.12307259792578407, 0.24765047914115712, 0.12073758611222729], [0.032069314329419285, 0.01299920915698749, 0.060821373263024725, 0.01633584852243075, 0.049642488156678155, 0.07795037541654892, 0.04814608095330186, 0.056377801156486385, 0.02578307674411917, 0.07933195010991767, 0.06560546127730049, 0.025868425582302734, 0.03382814124051947, 0.03574932779883966, 0.041726240087882616, 0.03833048773230985, 0.0863837928045541, 0.013469406094372971, 0.054179081053007394, 0.0026182220926784794, 0.043323824284016155, 0.015507723965129117, 0.011994514679827262, 0.04432829147845041, 0.028164435680082534, 0.06629594805417582, 0.029535019166360144, 0.021859169428353198, 0.06389052869053558, 0.06170993554405868, 0.028208138901391067, 0.0219570141780423, 0.05246654189249966, 0.060975331798545085, 0.021520392001548316, 0.02688137552468106, 0.013554999841289828, 0.05992480320855975, 0.07912391127320006, 0.022815521333541255, 0.028023023151035886, 0.0226865045260638, 0.08950465737143531, 0.025259818103222642, 0.01622356900043087, 0.011979307146248175, 0.0656882998009678, 0.016834235939313658, 0.020551100751617923, 0.041227194014936686, 0.030788105832471047, 0.0368583932868205, 0.06012366167851724, 0.07744712507701479, 0.02916336088674143, 0.008741611836740049, 0.009582002239767462, 0.01445867688744329, 0.023540549518656917, 0.03113868340733461, 0.06675253214780241, 0.03145804439554922, 0.023723333069938235, 0.03955575499276165, 0.042382421088404953, 0.042008645832538605, 0.003099128452959121, 0.023254536936292425, 0.0255749414282036, 0.05669424921507016, 0.043158366170246154, 0.007573293742098031, 0.07522882340708748, 0.023999345212359913, 0.04573447207803838, 0.023043314286042005, 0.018457309197401628, 0.012850656239606906, 0.039444321519113146, 0.014677217113785446, 0.059182510813116096, 0.013044390179857146, 0.027806976540887263, 0.05840641359100118, 0.043179803105886094, 0.008379210921702906, 0.04866579212830402, 0.05562315200222656, 0.06652642943663523, 0.03933825748390518, 0.07552963070338592, 0.03561360383173451, 0.04260300593159627, 0.06417257449356839, 0.12255881651071832, 0.08811047358904034, 0.011892995371454163, 0.029354389698710293, 0.0419642505585216, 0.07820467973942868, 0.06475190239143558, 0.025477421368123032, 0.04000309192633722, 0.06051653981558047, 0.060626711638178676, 0.03314073066576384, 0.011902337155333953, 0.07956980101880617, 0.033462870997027494, 0.02466491252562264, 0.08027819581911899, 0.07555107134976424, 0.08396884426474571, 0.05498131300555542, 0.03462832857621834, 0.05830945570778567, 0.07048535684589297, 0.04008662806882057, 0.04719125972769689, 0.022551819565705955, 0.026209115894744173, 0.016676601917424705, 0.09804104032809846, 0.03506054425088223, 0.06511245999718085, 0.04189896382740699, 0.026874000432144385, 0.0120525803140481, 0.03069650996621931, 0.0715959956869483, 0.035619325790321454, 0.0065485784398333635, 0.03602780016080942, 0.06621844557230361, 0.0036387252430358785, 0.01145599655501428, 0.03454821002378594, 0.00281007028206659, 0.031419857186847366, 0.0732756985235028, 0.03386381627933588, 0.0700202900043223, 0.013136823745298898, 0.0680795664084144, 0.08064202629611827, 0.07058667484670877, 0.04111113325052429, 0.04402602215122897, 0.0700156218954362, 0.020587208091455977, 0.06649934104643762, 0.028926567538292147, 0.06717730037053116, 0.043880765297217295, 0.020555073097057175, 0.03670549231173936, 0.033890607810462825, 0.08270644364529289, 0.04843216775043402, 0.003411934421819751, 0.07721887013758533, 0.0150905850205163, 0.01293029703447246, 0.04717688432720024, 0.05025954313168768, 0.03175038378685713, 0.0560041669086786, 0.012373681638564449, 0.00963034759479342, 0.03684995506773703, 0.035915594853577204, 0.034261113905813545, 0.04402615573781077, 0.052853156303172, 0.05746171525970567, 0.013971892021800159, 0.08009222103282809, 0.043862107704626396, 0.030782127832935657, 0.04580919892759994, 0.0787879632844124, 0.10556945315329358, 0.03992308098531794, 0.021692388436349574, 0.04530830119620077, 0.03353481850354001, 0.03746652764675673, 0.1328994717914611, 0.11873173905769363, 0.06039923595380969, 0.025358304810652044, 0.02212179322668817, 0.021340220810088795, 0.014141385563561926, 0.01185842149425298, 0.05180325482797343, 0.04724633450678084, 0.03929315716959536, 0.025926088601408992, 0.0570433703251183, 0.02412690555502195, 0.0066724758198688505, 0.05112137325340882, 0.023739925636618864, 0.04673112816817593, 0.04463368524739053, 0.043810981151182204, 0.02955871408630628, 0.034709289466263726, 0.06359406295814551, 0.03111268968496006, 0.11012751638190821, 0.014250931199057959, 0.027399173814046662, 0.051891711409552954, 0.07293994349311106, 0.012663159122894285, 0.03444275826041121, 0.05847784901561681, 0.026001099322456867, 0.030827343180135358, 0.03156142556690611, 0.041343406919622794, 0.030604906678490806, 0.053584283086820506, 0.04618169026798569, 0.04145724124100525, 0.020618576818378642, 0.04221358249196783, 0.03814576717559248, 0.008890764966054121, 0.03459549967374187, 0.010958353141177213, 0.010539072172832675, 0.05900273667066358, 0.027465963394206483, 0.06218031245225575, 0.012697944512183312, 0.02602053245936986, 0.07834290474420413, 0.05514067808690015, 0.024597764859208837, 0.020681086061813403, 0.0957749666122254, 0.01443460161681287, 0.05441038993012626, 0.0404024230374489, 0.033761518643586896, 0.018711171942413785, 0.0192060823974316, 0.049485304989502765, 0.021096048658364452, 0.03638367481471505, 0.06590944496565498, 0.05210347211686894, 0.010968847109324997, 0.038075597112765536, 0.016977017730823718, 0.028492210767581128, 0.03189479830325581, 0.01924981716001639, 0.022346606456267182, 0.03651857128716074, 0.07846222724765539, 0.04818289518880192, 0.01548004742289777, 0.07288051972864196, 0.03982500988058746, 0.04579677166475449, 0.039078483532648534, 0.05928903497988358, 0.019969019485870376, 0.041975572021328844, 0.039276017269003205, 0.022759598650736734, 0.06632366726989858, 0.02762231721135322, 0.022425264833145775, 0.02008409133850364, 0.0462754160980694, 0.03752196607820224, 0.007694464657106437, 0.03905212244717404, 0.058004444144899026, 0.03975259111030027, 0.03453681063547265, 0.10409220078145154, 0.031000797935121227, 0.06066455003747251, 0.054385713519877754, 0.020224366526235826, 0.047453902079723775, 0.037824461760465056, 0.003497017942208913, 0.035254341273684986, 0.041918192873708904, 0.029312360020412598, 0.05080935581645463, 0.06766568549210206, 0.034792153965099715, 0.03646966004453134, 0.07486905989935622, 0.055720035670674406, 0.049437911438872106, 0.024143496266333386, 0.07691041872021742, 0.05930645689659286, 0.030572051800845657, 0.02641014514665585, 0.02931777769845212, 0.09902245641569607, 0.035501584061421454, 0.029257413261802867, 0.008914724276110064, 0.07520644023315981, 0.028064177095075138, 0.016959913082246203, 0.05668993733706884, 0.01238944578290102, 0.03861795492412057, 0.07515179589972831, 0.04690632697020192, 0.013125798213877715, 0.0469081229675794, 0.0481236309860833, 0.03537111078912858, 0.01926528351759771, 0.05398591856646817, 0.04631923991837539, 0.014147264300845563, 0.02018618117290316, 0.05786473484477028, 0.06310916593065485, 0.03772621254029218, 0.058402561844559386, 0.005133031008881517, 0.059156346396775916, 0.14688380499137565, 0.04155518989136908, 0.04219028647639789, 0.04455514746950939, 0.06927897353307344, 0.0644511915743351, 0.05617446753603872, 0.031580227878293954, 0.05216808720433619, 0.01383928600262152, 0.023358988655672874, 0.03110660964011913, 0.03721075387147721, 0.08572456528781913, 0.06737081537721679, 0.19416533585172147, 0.061909907235531136, 0.08448298933217302, 0.14199477358488366, 0.14093434845563024, 0.28089574130717665, 0.15033605333883315, 0.20344675343949348, 0.10499669326236472, 0.13678462972166017, 0.08888808108167723, 0.1932433806359768, 0.15536266408162192, 0.35547261766623706, 0.11303885039524175, 0.10301780843292363, 0.20633600855944678, 0.11432925224653445, 0.14795597089687362, 0.17384583712555468, 0.11553338685189374, 0.07516404133639298, 0.18235706869745627, 0.22934107255423442, 0.14307446486782283, 0.10081210100906901, 0.23114027600968257, 0.09779484767932445, 0.1684839092195034, 0.1551632341579534, 0.18013910099398345, 0.10963940585497767, 0.07938675029436126, 0.28511027921922505, 0.16038255096646026, 0.11423544478020631, 0.11706970675732009, 0.13858876103768125, 0.2354374001151882, 0.13577349804108962, 0.09545218432322145, 0.18404839356662706, 0.16163635009434074, 0.11781755412812345, 0.20038963935803622, 0.1504958377336152, 0.16502916725585237, 0.17314180615358055, 0.149862993566785, 0.11891941336216405, 0.13183469767682254, 0.1631902885856107, 0.18915146036306396, 0.2329305440071039, 0.0747781913378276, 0.1369634724687785, 0.12739677331410348, 0.1013887497538235, 0.258235449437052, 0.1118295059131924, 0.12513840309111401, 0.14639824745245278, 0.0772734105703421, 0.1275660571991466, 0.1095759670715779, 0.12196146184578538, 0.10718760968302377, 0.19579967862227932, 0.15265337977325544, 0.11102116608526558, 0.09932550499797799, 0.08514796107192524, 0.10893481827224605, 0.10127389497938566, 0.17683556419797242, 0.16276870417641476, 0.12209775726660155, 0.12811662687454373, 0.12703435291768983, 0.06410395551938564, 0.18759064958430827, 0.13198253349401057, 0.10918305182713084, 0.13278978236485273, 0.11394860470318235, 0.12894480430986732, 0.12525852711405605, 0.18650362588232383, 0.15421022748341784, 0.19244668510509655, 0.21381503145676106, 0.1393950599594973, 0.09605661907698959, 0.1318409465602599, 0.1677021011710167, 0.20358569832751527, 0.17265304253669456, 0.09800306463148445, 0.1650570720084943, 0.16800385841634125, 0.16114552330691367, 0.09186197072267532, 0.08380276645766571, 0.20988486969145015, 0.1244136068271473, 0.13989299652166665, 0.11592797935009003, 0.16282215365208685, 0.11952703192946501, 0.10893501123064198, 0.2516124345129356, 0.18614429282024503, 0.2137474960181862, 0.15522805333603173, 0.13135592336766422, 0.1724047347670421, 0.18900650407886133, 0.14208755688741803, 0.2039569799671881, 0.19720506883459166, 0.11739356516045518, 0.10383357715909369, 0.2709362976020202, 0.13061005010968074, 0.11723735049599782, 0.21045224159024656, 0.1525749496067874, 0.08683213163749315, 0.17967001913348213, 0.17529062053654343, 0.18211766669992357, 0.1717535001807846, 0.14152352465316653, 0.18579794734250754, 0.1812926062848419, 0.1439579323050566, 0.10686718000215478, 0.08419725505518727, 0.12158249897765927, 0.1484150337637402, 0.13027376815443859, 0.16282823926303536, 0.1369571196846664, 0.23144915787270293, 0.1690418558428064, 0.22358254092978314, 0.16474373725941405, 0.1229398648138158, 0.1605877696420066, 0.11902248283149675, 0.1997209939872846, 0.1836910197744146, 0.17337224300717935, 0.08661877902341075, 0.08615480313892476, 0.10319411303498782, 0.139594356296584, 0.23139419441577047, 0.1886297602322884, 0.06874320970382541, 0.19331237068399787, 0.3455998271238059, 0.08018765380256809, 0.17604729946469888, 0.15015096170827746, 0.1930952924885787, 0.2180802432121709, 0.13392180990194902, 0.07152772552217357, 0.1073489674308803, 0.10126878900337033, 0.06988974622800015, 0.1093268948898185, 0.2109886659309268, 0.29263654723763466, 0.12559032649733126], [0.032335218420485035, 0.02986273859278299, 0.033349032964906655, 0.026355150148447137, 0.04566416100715287, 0.053181278344709426, 0.0057711685440153815, 0.02858372128685005, 0.02111917954607634, 0.014556221995007945, 0.06983456754824147, 0.035886424739146605, 0.02954838339064736, 0.002529769917600788, 0.06054294171917718, 0.028834333425038494, 0.0300340151443379, 0.043018627184210345, 0.025819284273893572, 0.05270015142741613, 0.05943386880971957, 0.04445726932317484, 0.043219764047535136, 0.03393726292415522, 0.01883795117464615, 0.02520064481359441, 0.08899252352421172, 0.0557562673202483, 0.06675204975181259, 0.04356582008767873, 0.007260358361236285, 0.0016544804839213612, 0.04747976221551653, 0.019235300751461182, 0.03203789550752845, 0.03963896830100566, 0.05747464718297124, 0.0033814743619586807, 0.020219702128088102, 0.029236939262773376, 0.02819741486746352, 0.022412362595787272, 0.03533922812493984, 0.02499084523151396, 0.026400066781206988, 0.023891015771368984, 0.012101244792575017, 0.06771903848857619, 0.08473753856378607, 0.028576654185599182, 0.05073480337159708, 0.03425269795116037, 0.0767104618716985, 0.04115158400963992, 0.015358375094365329, 0.04677425436966587, 0.03386494434380438, 0.0374583009397611, 0.011620985260378802, 0.07435095176333562, 0.09640272706747055, 0.0029651060913238325, 0.013378623807511758, 0.024305765000462998, 0.03691839963721577, 0.015796034422237426, 0.039154223413788714, 0.05087118785013445, 0.061824756921851076, 0.022606545535381883, 0.0535658258741023, 0.02156456463126233, 0.04744599078549072, 0.0676716968882829, 0.06163413629110437, 0.051131054569850676, 0.02576771985332016, 0.04305330032366328, 0.037301039847079664, 0.008833672472974285, 0.04354647971922532, 0.04145145991060417, 0.09255724435206503, 0.03933045009034686, 0.033421707776142284, 0.02304664652911015, 0.04719452146673575, 0.04637593257939443, 0.06548312565428205, 0.04000506974989548, 0.043752878409577534, 0.0729373682406731, 0.10137289747945033, 0.02371567225054605, 0.06908864233992063, 0.01260952596567222, 0.01259156135347439, 0.08272490827948786, 0.019602710235631093, 0.07132304861443117, 0.04536182859737892, 0.02177662776375655, 0.030045993407838978, 0.09510707081062719, 0.014134485445538303, 0.019256533596490044, 0.04410305336932652, 0.034246827563038096, 0.02519019351893803, 0.02897742135246517, 0.025596792111173272, 0.033345440970151685, 0.043496867147041485, 0.04890761723800097, 0.03150432101392653, 0.017344239822705276, 0.013895807041990338, 0.10970016548526473, 0.07471963588614017, 0.020947016128047835, 0.03282596357166767, 0.052897481073159724, 0.029564584474428557, 0.01952454538695747, 0.012213111494929763, 0.049055022609536536, 0.06968106914428063, 0.016104630558402278, 0.08240182913141325, 0.07939717746921815, 0.00384036885407113, 0.03784126769460272, 0.026486116948944982, 0.04139982869673986, 0.022847288964840118, 0.048238251984003, 0.044022389338351786, 0.06793754902901128, 0.017863687535282224, 0.06372399075189605, 0.06270993500947952, 0.03203466716513503, 0.041942650350392796, 0.010426836252008798, 0.05919613664445933, 0.019353834723006003, 0.047771953177289106, 0.03506109715090133, 0.046001519076526165, 0.02705436087126145, 0.02915352557465667, 0.04728626205178443, 0.03153216268401593, 0.0264755561875063, 0.026820268940355163, 0.01932429167936789, 0.019719054871529806, 0.010634651516738813, 0.023499864983023144, 0.020735184916702565, 0.05837566641275771, 0.04981409125321079, 0.022368609279510565, 0.012354741102171829, 0.04293019286706112, 0.05090493330499157, 0.04500048060435802, 0.04672444141760934, 0.04726021637907252, 0.09993910527555272, 0.015114403322513681, 0.04961986378475558, 0.04940647035255097, 0.03370789847394917, 0.03685140596644487, 0.022922156822460238, 0.05102743591123726, 0.037260065873852, 0.04201931049465202, 0.07242583553306758, 0.06401381426258013, 0.04160752985626459, 0.02313128105015494, 0.023533120620413683, 0.021105711421114393, 0.021988201078784186, 0.028981553259654902, 0.00968170699707116, 0.03573466296074912, 0.035579676550696604, 0.061446562176570296, 0.02450185525958659, 0.062053167712292634, 0.08626261493191123, 0.041473071250948124, 0.06638951803324744, 0.07155056882766075, 0.017359778539685067, 0.0325094264553627, 0.03467729547992349, 0.03808675530308392, 0.03396670763322618, 0.06545056021423079, 0.019609116825449746, 0.059446348022902384, 0.03552866131940391, 0.04195665467705112, 0.02306320940988371, 0.08087108275503851, 0.01979519922315376, 0.035968591619166546, 0.01906051013065735, 0.045668814273085445, 0.02687684285774594, 0.02549604556406848, 0.01724643774650758, 0.053093567621544935, 0.027931892982451245, 0.06338406485156156, 0.0853690023359377, 0.07157169777201489, 0.04118548531550914, 0.027876992608071305, 0.07260779530042782, 0.054610547158517875, 0.042698958204709925, 0.03247374770580791, 0.013758119166595861, 0.03407466414500959, 0.0046810737421765225, 0.06741958932252601, 0.04324906774854753, 0.00781459146310226, 0.05366447956475895, 0.040684780542505905, 0.013924856557423482, 0.08421681064646691, 0.0950261099205818, 0.013196819891163614, 0.022145822113088798, 0.0397626991616562, 0.04431539295183029, 0.03180741783580743, 0.06881201421492733, 0.021549710545514245, 0.03248452369007282, 0.030696656540385447, 0.008092689040495316, 0.11146803546580486, 0.0379716741736047, 0.0410927613847889, 0.029507064318750054, 0.029191456742410082, 0.031694652207079343, 0.0323308657243615, 0.05091366096166894, 0.03800531201704871, 0.029558155620179605, 0.022601222481171135, 0.042059252882609144, 0.03252690032240935, 0.045793406025040895, 0.06425928702810779, 0.08826539691654034, 0.05068089747510385, 0.021582541303359903, 0.08926809779950418, 0.09063246950972825, 0.04947760149661917, 0.09310411071055569, 0.04258784756530076, 0.051196831118431874, 0.11060810153139755, 0.10771049725008197, 0.0398978368320968, 0.061480415242840536, 0.01912393963721115, 0.09805549736483954, 0.005762478922406444, 0.09916901573888026, 0.021309560834197327, 0.014017730773048243, 0.014788857461098814, 0.023608945848536678, 0.019678817479871213, 0.05085576973215211, 0.01786231827281881, 0.013275570108817192, 0.030088770799920894, 0.04062998777953908, 0.006771726011720602, 0.014052968872420024, 0.013552056298067328, 0.10512419423321262, 0.030454747939074878, 0.03957277614972554, 0.00549762497030315, 0.0181345213422901, 0.07781828055158257, 0.03374566265847534, 0.010340738772356417, 0.09359169431263581, 0.04105911240912974, 0.0090870574604196, 0.06641927073360421, 0.030077373266976792, 0.05280788158415817, 0.07928965511382557, 0.022078882248024456, 0.10501814875169657, 0.03639305927208625, 0.04026019785669632, 0.03409896577068139, 0.06576866697287187, 0.030289026362879667, 0.04226740675221663, 0.05085541350126732, 0.07450832417816855, 0.05754344427259639, 0.0025067626438612933, 0.11516685495735146, 0.07722891881712712, 0.05054126610048115, 0.0695072730013635, 0.027130549751746003, 0.08648809423903003, 0.06472772322013043, 0.053829737298656255, 0.04503377705987077, 0.04063143867824692, 0.023713969021628145, 0.051109398700646125, 0.03967579366872087, 0.009680901766841998, 0.03262179874582216, 0.06806388482800685, 0.07310644432436675, 0.022358714595611673, 0.05967193123069592, 0.0516884631360881, 0.02496447486919351, 0.010571101411187556, 0.013766581505478825, 0.01653772753343219, 0.07337837465456687, 0.05060979972768109, 0.02394782717601629, 0.03082658618950518, 0.04157106071943417, 0.03810873400652781, 0.02307001304870937, 0.009760537923284573, 0.13702370517421514, 0.10376300633652136, 0.09966001322027296, 0.11025270927348174, 0.11246660258620977, 0.10054191472590901, 0.1573413930600509, 0.08892172263585962, 0.10293578627170064, 0.10900155961280689, 0.1736802194500342, 0.13937347830506042, 0.1022555485542398, 0.10266591169056483, 0.13978965987917036, 0.08772454195423052, 0.1888267559115775, 0.1323113197577186, 0.11983267060713843, 0.11226264556171373, 0.22982324589975178, 0.10029198907432146, 0.17165394849143922, 0.12554281420307234, 0.09629153108107857, 0.13489598262822255, 0.22261366713792086, 0.18610442464705557, 0.14464850071817636, 0.1201000070432201, 0.12127801062888466, 0.11042080572224222, 0.19665006111608818, 0.12614876293810084, 0.09551423529046588, 0.15723514719866216, 0.09967274847440422, 0.08721058242372237, 0.10122431209310889, 0.1579577021766454, 0.14985154964961112, 0.11130530474474654, 0.10105578519869596, 0.1395797508303076, 0.16084550268715248, 0.13613066403195262, 0.11361086813849397, 0.16674388461979106, 0.3020058054244146, 0.08108911089948379, 0.11421051603974774, 0.13615270581794903, 0.12501011544372886, 0.08335505845025182, 0.1016196318960283, 0.14435144868912175, 0.1451032145996578, 0.1292366613051854, 0.07430864192428999, 0.12000016591628082, 0.14167585788527504, 0.126066577504389, 0.10336073260987177, 0.11848593232571147, 0.24425637064268813, 0.20047608471941203, 0.13994085020385683, 0.10740525933215395, 0.1417527740704827, 0.14808185398578644, 0.11369214073056355, 0.08719619960174896, 0.1818351013935171, 0.20646564691560343, 0.1158618762565311, 0.1114951164345257, 0.08358630424481817, 0.16891108942218125, 0.10854605163331144, 0.15644085622625425, 0.1307293280842714, 0.08753475252888165, 0.23523051902884617, 0.0838083474081941, 0.16329689067788422, 0.12143429950810969, 0.21939274622127414, 0.1874683436471969, 0.12690483330516145, 0.1376898420858197, 0.13697093847440556, 0.2440042482339777, 0.1554330493672751, 0.16900041431654245, 0.17391246714396402, 0.09686754900030792, 0.12773364898748696, 0.2590318926377222, 0.16041140566812828, 0.23259007633896545, 0.1226674669305794, 0.18361328722676262, 0.13029276713496074, 0.1755635824520141, 0.07495062192901969, 0.08123855717713013, 0.13071491557639092, 0.1715383812552318, 0.11418298236094415, 0.0939353606372606, 0.12611821613973007, 0.107870504289167, 0.10523494493099861, 0.12213296475238167, 0.13641594559885561, 0.10024810588220134, 0.18314671382540837, 0.19185985409421846, 0.14351081801578403, 0.18344663054449484, 0.08466178012895398, 0.08690934468177147, 0.19162707205396146, 0.17648513690801337, 0.07464027803507634, 0.29702163068577647, 0.2522966649848968, 0.15528499090578407, 0.17310873605310917, 0.19161761709256098, 0.15099589683813974, 0.21223761141300201, 0.13016275770496577, 0.1425624274997972, 0.1872798232943751, 0.1738194315112196, 0.1872239841031842, 0.15155384346144274, 0.11039963224902749, 0.07918533883639611, 0.154040171764791, 0.1900387424393557, 0.12822272430639714, 0.09473942569456995, 0.22861321864183992, 0.16396124643506482, 0.14253636327339336, 0.13544512738008052, 0.15522238332778215, 0.13903511833632365, 0.2384436919237487, 0.07468790165148675, 0.07504061475628987, 0.2112617317470722, 0.12692746880929917, 0.09357622053357773, 0.18373761180555448, 0.11017102107871324, 0.0605000901123276, 0.10801436961628497, 0.11991843319265172, 0.11907555381185375, 0.13985796715132892, 0.1260211135377176, 0.08773688387009315, 0.10743026228738017, 0.15742063958896324, 0.10440930564072914, 0.10496348957531154, 0.24201891414122656, 0.10626653020153753, 0.10432283801492304, 0.12514496367657557, 0.19553495454601943, 0.1038345716369804, 0.1982811384368688], [0.007157668314903276, 0.07932415013783611, 0.10200104385148734, 0.030441671297012363, 0.04567513366055209, 0.04773943226609845, 0.01780870366928866, 0.03404084076464642, 0.06184909194416832, 0.02433529505651677, 0.019591605851019267, 0.014395932939805789, 0.07675188113353215, 0.11692591564496979, 0.010784857568069128, 0.044180444529047236, 0.018683387788769323, 0.07818970319931395, 0.011159688529005507, 0.00984844438789878, 0.04491332278121263, 0.0645107934542466, 0.05426486590295099, 0.05096515487821307, 0.05455478218209464, 0.01915971857670229, 0.06545902811922133, 0.02431243319733767, 0.04673522482335102, 0.07186290909885429, 0.0763011748495046, 0.0326502081588842, 0.03766192028706428, 0.03422156114538666, 0.027189366810489446, 0.02536226045776857, 0.07094451619195752, 0.08176151153747924, 0.004803980818905984, 0.04993366608687211, 0.05587046158325393, 0.0364203591743717, 0.00869915356815909, 0.04213400941807777, 0.04649606402381323, 0.04452319801202975, 0.014490463072434068, 0.0127992448869918, 0.03697907020978164, 0.03036105179489823, 0.061938398284837604, 0.03398922810447402, 0.04760877345688641, 0.09500574538833462, 0.035541155375540257, 0.05561591977311764, 0.028868379449704662, 0.0844713969854638, 0.03841345984255895, 0.04572843470668886, 0.029971876974741463, 0.02784698943287367, 0.013497625332092866, 0.09574244570103474, 0.04171022454102058, 0.0943667117098812, 0.06712203263305128, 0.06831340229837224, 0.03056495130294934, 0.027080538275185972, 0.07049245919915847, 0.02282173310959479, 0.018430662385071628, 0.015029525748104788, 0.021739843214163557, 0.03869176151056308, 0.021722386045439634, 0.05768117945990525, 0.04285619332222268, 0.02114282251568511, 0.0347760011209175, 0.028775980208592955, 0.06447986816056073, 0.04297330051485915, 0.02080423990264535, 0.045063696743454784, 0.022096688226156402, 0.027025736235373188, 0.03595909583964385, 0.06610076321521774, 0.036201032271492295, 0.04306189810449723, 0.034828430143534206, 0.019645652755571064, 0.07230367802549154, 0.016851535401656292, 0.014205769657564815, 0.03633269669080619, 0.03260491488617845, 0.04171925647824537, 0.055444190511479974, 0.028557701589306816, 0.04248912708135322, 0.07598336494993418, 0.07326099657802843, 0.04740468655654695, 0.05669505073456094, 0.04713476373581216, 0.06255339380004443, 0.04939294471114408, 0.04692762660852168, 0.05473254881508183, 0.05944919786998071, 0.017180722425109707, 0.07105582350050099, 0.041636165624368005, 0.01530617892058217, 0.08001606925972737, 0.054731606287532486, 0.01109917473513633, 0.010442061411595205, 0.028513358265627176, 0.04846468866162468, 0.03330716099299025, 0.016010472427296918, 0.0313139490026515, 0.07864118131692521, 0.046420316721196286, 0.011890812529600225, 0.01446260284865275, 0.029530903957493138, 0.060166876937728375, 0.025434287745156325, 0.030092848901404068, 0.023391279501083773, 0.0825326623453293, 0.028718116809614003, 0.034513911668909714, 0.040223123869509436, 0.12944300804520026, 0.020634688844438642, 0.05118080443935469, 0.022206574321899097, 0.019349812282598577, 0.07552232797024772, 0.0859327673970256, 0.03617050402681343, 0.028989737293159124, 0.0552170673472574, 0.047778803200344555, 0.04019876658276189, 0.045721291535301134, 0.016794197072158568, 0.0460901945916703, 0.043773009165306576, 0.05057380556536373, 0.07023995829513296, 0.03033389846677892, 0.08094066652120091, 0.023376601675408892, 0.07379719827440567, 0.00738060669391416, 0.009746095729497029, 0.06160205324704293, 0.0488938652415527, 0.02314982732059434, 0.024896486720535904, 0.010206721744907554, 0.056778590587782674, 0.005085053016955499, 0.04386275337310508, 0.06976729928283021, 0.0703069668088574, 0.047612680864403956, 0.08520797113305889, 0.052481796737993136, 0.052174510492477566, 0.11247028363868594, 0.025308478871011175, 0.0161880628002109, 0.029423175656120293, 0.060317518073134124, 0.028753613732988015, 0.015952646135701798, 0.0351608529308578, 0.022533134142577183, 0.08531930812750943, 0.02338204903935548, 0.049570169576327316, 0.0460127329279203, 0.05175934194994625, 0.05606255908787716, 0.022766218608012423, 0.024891532884794287, 0.07474011174053885, 0.052185134336468764, 0.03272231522714719, 0.012571268252941081, 0.06256190623389557, 0.05607179511571303, 0.023181043907243293, 0.05817802135425154, 0.020598633454937954, 0.02762860505754361, 0.019760277464229148, 0.04206589510431513, 0.028143182425992563, 0.03624548691732343, 0.04772060026880354, 0.03602157725254074, 0.04681759208324365, 0.07010496163275093, 0.05470583892019931, 0.0203632501870743, 0.00750331710150931, 0.013381313165155007, 0.024956802917586174, 0.00106579595922085, 0.052710886593558826, 0.024265586980618536, 0.034800176581484266, 0.03374959975189995, 0.07966258432134055, 0.050617354791029356, 0.04136171941354405, 0.02794454288959969, 0.06406854765373282, 0.014895537478878396, 0.0289187211819808, 0.015028394900582498, 0.05945505341514945, 0.012682858505286276, 0.0883588258875534, 0.027237079484621063, 0.045855226926505566, 0.0009278998766149016, 0.06865974777610973, 0.049446791235823184, 0.036250904595362954, 0.013048346754658269, 0.09188449490466155, 0.06586809249711223, 0.036868980023427866, 0.025513081563985907, 0.01504904794273898, 0.026206054535578005, 0.05966492535662837, 0.004070511167810764, 0.082578720030142, 0.016003848759282846, 0.013591259321401594, 0.08560711299651302, 0.04266825184458867, 0.02143110235920176, 0.04563934729958419, 0.030382644581550267, 0.019231382211728487, 0.04181103788141627, 0.04006997427495662, 0.022722598878317513, 0.03146541021123994, 0.013336533829715336, 0.02074542655464029, 0.029942662331450265, 0.08859894776833244, 0.00838760925034876, 0.05712196747481357, 0.06300367705989629, 0.03309465813799761, 0.028737171451211907, 0.06521285031340085, 0.03719229294802062, 0.019067644025199115, 0.018414975238556508, 0.03766475900192745, 0.04655014803574886, 0.01633305804716656, 0.017341124657832552, 0.015846697133383714, 0.01031598814734025, 0.08079325372818857, 0.06938665173947811, 0.03494476179184858, 0.010007368819060503, 0.024008724103623535, 0.018358714878559113, 0.023830551144783385, 0.08033224643440917, 0.05745272785134148, 0.024499734572600573, 0.05689335630449932, 0.03616152775066439, 0.03890804189722985, 0.05801650775538292, 0.05775761695986148, 0.08954262564657256, 0.011374263831385178, 0.05818010678922292, 0.0068339393237693, 0.023831963080738205, 0.044879729466629215, 0.020810052774322685, 0.052237500276532955, 0.06125064261141233, 0.07400086586130783, 0.059043447181466036, 0.019304650741105434, 0.04136650626605842, 0.08678008482092991, 0.0057577143343223725, 0.10203087818808854, 0.06519321308587678, 0.028901343794132117, 0.01821465844841441, 0.034430197410983965, 0.009789258110686205, 0.07446761737810448, 0.010516044258110924, 0.07003309205174446, 0.047432750870939344, 0.047191589983412996, 0.0616578775952803, 0.06759587908163667, 0.08011296406039037, 0.011124052452942124, 0.017553685029270127, 0.021606941263598856, 0.04633872871636413, 0.02878827759559499, 0.057888149603968486, 0.012845616129197879, 0.027117139143228997, 0.051786857075057924, 0.02925107160990592, 0.045724093142780475, 0.014453562562266598, 0.04580595203151461, 0.024311709603352938, 0.07211690914118662, 0.06281583948293701, 0.03579733362130355, 0.04718118507298641, 0.018689670068852138, 0.01093068680347642, 0.019483606665744446, 0.04750777086883318, 0.09679052891442552, 0.1218021524255164, 0.027630597724055406, 0.053275148893590085, 0.03566290470189415, 0.031198671204037964, 0.17674165283096954, 0.23579125612741336, 0.16774395829997957, 0.0948689972574357, 0.16404883470386267, 0.10466180654475465, 0.09461558351176791, 0.1694582006894052, 0.20555685739964247, 0.06685778353130445, 0.23785530240274966, 0.08085934940027073, 0.13419560302281752, 0.17834577534813434, 0.08674124823301099, 0.14159425132675096, 0.10014528874307871, 0.24281888996483758, 0.27587511227466166, 0.10816615365911275, 0.2101818920345977, 0.13887490349588916, 0.278079558047466, 0.21996660449076444, 0.09787302551558241, 0.16952989215496927, 0.1131649932358414, 0.12817261449526995, 0.09668146289186552, 0.18696032871957868, 0.11342093770508654, 0.18285913160070777, 0.12374593366985209, 0.1898165582679212, 0.08111439587082714, 0.1144685162580572, 0.12311763144680299, 0.1844306441489607, 0.08259774869657122, 0.09525129236862995, 0.13644628459587693, 0.18076596345053986, 0.18374138191575184, 0.0869034075003583, 0.13756861968431622, 0.1452756006619893, 0.16428905306383967, 0.15290424053091556, 0.1493127504363656, 0.15739629714516923, 0.1734238222707063, 0.0890217418782413, 0.11297720018774271, 0.11833534314064309, 0.1564664306351915, 0.14741794351721182, 0.16895067557925358, 0.12234788329806179, 0.1714935852214694, 0.12447769870050251, 0.2583557367324829, 0.1349720379221253, 0.08269689962617122, 0.1627359606209211, 0.16600558126810938, 0.1666874368675053, 0.15591170493280515, 0.18436062993714586, 0.10560473485384136, 0.18692967802053317, 0.1832434453535825, 0.12048330405377783, 0.23586821684148163, 0.11532545933732763, 0.13524942303774878, 0.14949751552194357, 0.12479532306315377, 0.12045450872392394, 0.09545409164275043, 0.1477992589934729, 0.11651760825770907, 0.166592427121941, 0.10302182345185429, 0.1475097768707201, 0.1188740755605977, 0.12131172639783472, 0.132638028007932, 0.1726796114235185, 0.22338835056871176, 0.10163529121200554, 0.13271771982545033, 0.13343309081392363, 0.07766493057715707, 0.08726760162971914, 0.16048743127612397, 0.07851723523344845, 0.15273216617060825, 0.10764179663965479, 0.18562458164524287, 0.21506112709175795, 0.1842835356364958, 0.07630164240254089, 0.14964480214985088, 0.1785630316589959, 0.1797367530525662, 0.16062514419900253, 0.20451688586035743, 0.12230689448188059, 0.10501023745746352, 0.07532407806138508, 0.1953104994026944, 0.1547655914328061, 0.0954998005181551, 0.10382863445556723, 0.1648107828805223, 0.12102318680263124, 0.18779255828121677, 0.24590632820036262, 0.15612146555213258, 0.17647934815613553, 0.15492009173613042, 0.15961506636813283, 0.1511264406144619, 0.14256975991884246, 0.14519451360683888, 0.11432957879151218, 0.1953338918974623, 0.19262150541180745, 0.19657826574984938, 0.10541538329562172, 0.17388267733622342, 0.1466232814709656, 0.15303701075026765, 0.09909015512675978, 0.1688523855409585, 0.18829099950380623, 0.10981217041262425, 0.08853606559569016, 0.11696573928929865, 0.23993390961550176, 0.09427798795513809, 0.08965251545305364, 0.0940259694471024, 0.16878318769158795, 0.13205688184825704, 0.25344197696540505, 0.3105111146578565, 0.23041182837914675, 0.12188917666207999, 0.10762037083623, 0.10234123692498542, 0.10931850119959563, 0.07070919600664638, 0.16229732165811583, 0.15787434414960444, 0.14422647102037445, 0.1500443447730504, 0.1109445393376518, 0.1758095747209154, 0.10316626023268327, 0.15876918128924444, 0.21333725162548944, 0.15173020743532106, 0.15501280082389712, 0.14222276135114953, 0.14809709769906476, 0.10831030842382461, 0.09128955221967772, 0.12579891452332959, 0.16635735926683992, 0.2377135818824172, 0.21193971333559602, 0.09202157700201496, 0.1375682486104779, 0.14367797935847193, 0.12114575991290621], [0.01964692368346732, 0.05949552643869538, 0.043664425538736396, 0.014508853491861373, 0.009739296729094349, 0.11966278558247723, 0.06330038027954288, 0.047642025383538567, 0.03321200281789061, 0.04154323018155992, 0.03958906629122794, 0.027398468773753848, 0.03139859465591144, 0.047052043955773115, 0.024309284635819495, 0.04798633737664204, 0.08851035017869435, 0.02889424515160499, 0.026718988046923187, 0.038435349488281645, 0.029151256458135322, 0.013305677184689557, 0.03164659814501647, 0.07851060785469599, 0.035518809308996424, 0.04198873772111256, 0.01756894915160956, 0.02111043704644544, 0.09673527601989917, 0.05691704936907627, 0.042198958471999504, 0.03648810241429601, 0.04703800252173096, 0.009618539097573375, 0.039128897624323145, 0.05362526819226332, 0.04299398045986891, 0.028034218448738102, 0.01589265277289087, 0.014519387350446777, 0.032517029758309945, 0.021999171876814216, 0.039110113866627216, 0.053608209927915595, 0.07745151116978377, 0.14595408691093326, 0.04923113796394318, 0.044963191394344904, 0.035450379582471214, 0.029936146274849307, 0.03387313765415456, 0.03600046686187852, 0.02102350928907981, 0.005326908276401809, 0.012446183900465257, 0.05595415357674938, 0.06573279155418277, 0.03840688070340548, 0.06621277556405403, 0.061140455945860595, 0.03364756557857618, 0.05387030680140015, 0.020118573374929838, 0.021730831685999874, 0.03784454056585673, 0.056292491281055845, 0.03194425502442755, 0.02796287208184367, 0.02169414918171242, 0.030322959210025147, 0.02624937926157145, 0.033564133336767554, 0.022540134450537153, 0.024005646046134643, 0.04750879874336533, 0.020729988027596846, 0.0020502052211668342, 0.0015102824659152247, 0.06905394693603739, 0.01991247154364828, 0.07787382288370281, 0.029413312513497658, 0.020134570368099958, 0.027931017248192802, 0.04815744323423132, 0.05016970244469121, 0.05545679588976782, 0.05067599930043798, 0.01934718879056163, 0.029982346823089756, 0.08508301572874188, 0.029097704937157687, 0.03542126883985475, 0.04337658727308735, 0.05558108336117584, 0.011733683168131392, 0.003516026663419325, 0.03778263802814763, 0.03406912030186504, 0.019222764021833427, 0.03362207280588336, 0.03941963397664949, 0.03520563041092828, 0.023525971882918384, 0.038211617938941345, 0.037854585534660146, 0.0705845894117374, 0.04397340017021634, 0.027872933060280047, 0.01901754720165627, 0.07123485178453848, 0.03704548500536475, 0.06860959343612194, 0.017704038582451176, 0.07451455079717562, 0.07434580867993645, 0.057041477848542854, 0.022751268043066375, 0.05258627257717308, 0.08087032576440834, 0.021787869445688557, 0.044918310013599694, 0.0744382877019234, 0.027015643026970793, 0.05598527925030794, 0.04398020566441119, 0.03302592413092498, 0.03408496886549983, 0.01119693599321181, 0.035531273679225706, 0.026491467833693605, 0.00891040497663198, 0.0430401939956937, 0.038770314131397754, 0.026232541786157526, 0.03749012052139733, 0.0738260307116434, 0.0303835221711779, 0.03686367366753984, 0.05037494338466786, 0.04532661369012203, 0.061319224478211254, 0.008247563200711738, 0.014132331361906836, 0.03885524180077482, 0.05049255894846283, 0.024589753375039436, 0.03071801740588853, 0.028432890903786756, 0.01977727450139355, 0.00925795366129023, 0.054644207266392186, 0.11364984573447146, 0.016697912687959615, 0.016628050616418477, 0.07355686859227717, 0.025312250836577732, 0.014349200828291941, 0.13611481175757945, 0.0492515618680045, 0.011723940624506213, 0.04377363256935496, 0.025490119514870457, 0.019448143139015883, 0.012928424966958119, 0.050748922731145285, 0.04514849824772682, 0.006222615584192681, 0.016482259416079614, 0.04089985122845974, 0.0215516456955811, 0.07430721700075082, 0.05677569621184375, 0.05757981321949046, 0.05878268617379945, 0.018161246080126148, 0.041744496920728125, 0.07449053489835933, 0.04694600960647222, 0.006331965014396701, 0.021101397687743884, 0.04817332148377318, 0.004382374145279755, 0.023307507726713084, 0.03505146778479684, 0.08382052605156787, 0.03542060461768415, 0.029470266781572718, 0.03404074799618684, 0.037846195555175655, 0.10034896375145763, 0.0012915157685711165, 0.038785565266152844, 0.027952652708336245, 0.05201205065532122, 0.025411064088984858, 0.03265175182605162, 0.05466008551593404, 0.018633110994414892, 0.01946537580806762, 0.07347821578150615, 0.04061393141455483, 0.0006967136857838341, 0.021951820999674965, 0.060826445842394605, 0.004014893229395966, 0.07188095813035034, 0.023846601943660062, 0.0162147096125409, 0.01623406667931704, 0.03911118627001997, 0.04799128008016851, 0.049466335694887675, 0.015125713653105777, 0.023151986970333382, 0.042308692427468486, 0.07229052716866136, 0.07541027109255083, 0.01464311542804353, 0.016362076021323446, 0.02379079243837623, 0.032576219746260904, 0.02569275180576369, 0.026071705397043843, 0.017437331116525456, 0.06430781606468372, 0.018467715963197406, 0.1017482386669144, 0.03600408112106379, 0.053927934568491764, 0.04384557636512909, 0.03177207676344551, 0.006469379222835414, 0.005686091981260688, 0.06493474531453103, 0.0584428827278316, 0.040215984408860095, 0.016729077324271202, 0.010058765328722075, 0.025602844325476326, 0.054122874498716556, 0.032698655559215695, 0.05027787046856247, 0.01198635940454551, 0.03956043052312452, 0.004150227568970877, 0.06802832111134194, 0.03751150179596152, 0.004661671682697488, 0.01196792816699599, 0.08829344267724082, 0.09005285217426717, 0.010752622383733978, 0.06830034792074002, 0.036462323914747685, 0.007675673477933742, 0.011608614586293697, 0.024763564360910095, 0.047599366735084914, 0.033386110662831925, 0.05604065088846255, 0.020557509196805768, 0.02696443669265136, 0.07872102898545563, 0.021740744923590682, 0.04052671793033369, 0.017950563342310488, 0.048374005637015216, 0.03290796717919875, 0.04229520389344543, 0.022927511417947244, 0.004571432091324823, 0.02513415580324363, 0.03243013910832815, 0.05195854922931176, 0.035691566445166245, 0.024424927942163777, 0.08714342548046261, 0.06382817344274372, 0.033383056725142524, 0.09352398818009533, 0.02985283463203814, 0.028828001049987506, 0.024641460659040604, 0.0410636135347886, 0.025215487767127343, 0.05348055681679398, 0.036119303258601576, 0.039111293881433085, 0.026098077614733484, 0.10494423084310256, 0.060896619615959935, 0.07600472396006808, 0.025303461952717043, 0.03198760387022048, 0.13753866660408676, 0.04246118522132747, 0.052459313374129124, 0.032627932596369646, 0.03187005138897803, 0.040032855758909136, 0.047860658378340304, 0.038968500957707874, 0.011276856948825298, 0.04257485627022106, 0.0332190420886036, 0.10209513333393261, 0.04530673897534143, 0.07494856617995538, 0.018455255303706508, 0.060069403261877596, 0.06458593590650707, 0.06143822043668479, 0.017143340446637012, 0.024638249014969915, 0.055690817316644825, 0.09502012078883126, 0.06049473551684059, 0.04287470248527825, 0.01936831402417738, 0.023938550330058206, 0.08396629869821481, 0.04191360640106723, 0.023979815596248955, 0.052120745604042895, 0.058129737226408906, 0.0283817124000052, 0.04902795277303085, 0.03558608870662283, 0.03978992855991237, 0.03166413509461563, 0.10976639474392869, 0.02323987580894027, 0.035046595585299656, 0.02780400052870391, 0.030790653254371136, 0.009669144292274723, 0.009344764530396787, 0.060146820396767, 0.03334722212457564, 0.06101999795646407, 0.021523405121115502, 0.07532227464253083, 0.03751582480617799, 0.021657145698554814, 0.05406146177847404, 0.03992996069428045, 0.03380762085726019, 0.02264943796035368, 0.10192045403528027, 0.0363874263712205, 0.002913692883339536, 0.15662355814129114, 0.0984845774655696, 0.1200666326622013, 0.08533063330105506, 0.07276407675817609, 0.15408050006954, 0.16697832907084376, 0.08998700141091831, 0.07064243982313201, 0.19430857035331428, 0.18311443040147424, 0.16532136563910171, 0.07497086029616185, 0.1202066833502613, 0.1354162281495519, 0.16753813106333837, 0.17028787726303563, 0.10289469355484471, 0.18924881529528648, 0.16767351364251226, 0.13666594546521083, 0.12052000325638801, 0.1025295197905507, 0.1460194552782923, 0.23887933260994032, 0.14592790394090116, 0.09824700857279822, 0.12320110079599544, 0.17738220049068332, 0.1404487167019397, 0.14906061318470165, 0.09576610536896624, 0.20780960214324296, 0.1132465033151675, 0.0939093112538103, 0.12241872871527448, 0.11001041290001012, 0.09416278437129222, 0.11925628161407076, 0.1051138190086931, 0.1066025449836161, 0.07618262417963706, 0.1432891088188626, 0.11873118986841291, 0.14558862370904535, 0.3607841982739046, 0.10618444124702364, 0.10836316418135539, 0.18244461243739352, 0.17131782980868593, 0.12009366910206154, 0.12787908024620265, 0.09786601964151487, 0.23723514896119013, 0.1229611347662285, 0.194648488832172, 0.18127270188415423, 0.1001965934119653, 0.2128135328530334, 0.13924625935032964, 0.09889097011182457, 0.11725526594091207, 0.16686849121470004, 0.12347117575700395, 0.10278105590259656, 0.1708657282870263, 0.12323327289777808, 0.11002478087903, 0.20394541730638593, 0.09736677689943463, 0.2035136506310664, 0.11750132500310428, 0.23140623205108568, 0.12666314549278468, 0.14535490656271577, 0.20654318650485948, 0.10073902914882638, 0.10381161700934172, 0.2466783398995176, 0.18495954311219975, 0.13505471317330375, 0.13157974026398733, 0.20067113597178832, 0.10808960854774341, 0.24153205042239279, 0.18706952832872048, 0.10630660617607646, 0.13301161030540243, 0.10785128266434185, 0.0729435206449125, 0.15033718140330166, 0.1444459389313124, 0.16533105808775872, 0.17133914428995922, 0.09682413336122409, 0.12960199092049152, 0.14358608663314953, 0.1311103763873689, 0.12881803064374253, 0.09297271346440539, 0.10804450823343359, 0.15123230055905879, 0.21044394437922165, 0.09902085337671451, 0.22755742451408878, 0.14706957939779386, 0.15798306878423318, 0.09125065625994466, 0.12155814169091173, 0.10515161658986472, 0.14081187924603, 0.13922819547588006, 0.12148636858910322, 0.08889872347936034, 0.2815966255730018, 0.12068570998962969, 0.23664576496230438, 0.137693359865807, 0.25278835266362876, 0.15931099362205714, 0.11857228862936608, 0.1698688606848009, 0.14997703197877854, 0.06331852579023689, 0.12059533124556765, 0.12120110928663053, 0.19159530813340098, 0.20297957147704437, 0.09044109188835137, 0.2523892553290352, 0.14041913469554856, 0.16919629677431658, 0.16950405057286844, 0.12950291420565918, 0.21630659932270646, 0.1390108055784367, 0.17710886750137433, 0.1468153641326353, 0.12662954104598612, 0.19587040529586375, 0.2068456562119536, 0.13221779430750757, 0.1322438140050508, 0.10969387949444354, 0.16295516135869548, 0.15052237693453208, 0.16003942640963942, 0.10629962256643921, 0.15731611551018432, 0.2177935664076358, 0.11303219333058223, 0.14040568697964773, 0.16497546544997022, 0.07639562056283467, 0.16853795241331682, 0.24739089072681963, 0.11070521155488677, 0.15190663078101352, 0.25868073804304004, 0.18461885279975832, 0.13414129265584052, 0.12181288388092071, 0.10803861558088101, 0.07102187766577117, 0.2601993503049016, 0.10334050908568315, 0.20595289708580822, 0.15815285732969642, 0.12095925078028813, 0.20330288069089875, 0.12716565368464217, 0.11152090606628917, 0.12493135873228312, 0.1658305383170955, 0.19190303224604577, 0.053401291734189726], [0.06033730744093191, 0.03518014134897385, 0.0135445596788486, 0.032946521751000546, 0.055016353508108296, 0.057798902635113336, 0.025636237260187045, 0.06117159275163431, 0.018648824116098695, 0.02831756486557424, 0.051709695981116965, 0.02933484338427661, 0.021229694611974992, 0.052292159452917986, 0.0044169971897645155, 0.04749725463625509, 0.03095407046203036, 0.07635679881786928, 0.026699842492234893, 0.035590441402746364, 0.04788029189512599, 0.04654412179661449, 0.043636112604872324, 0.08917192288208753, 0.02819116041791858, 0.029100155879859813, 0.02843525835487526, 0.04898521248833276, 0.034756200620904565, 0.015283407974493457, 0.050381032706354745, 0.06200402640388347, 0.05128506134497002, 0.020006176964670885, 0.007823435080354102, 0.03208330752386246, 0.02714907004701672, 0.02390319998085033, 0.045530819334089756, 0.036173442931612954, 0.03704964845383074, 0.09544202432152815, 0.05058177623141091, 0.0304117404812132, 0.035997509403387085, 0.02945312502561137, 0.04168306935753208, 0.026118412461073603, 0.04635711542505305, 0.02586395599792013, 0.0535038788075326, 0.03827970998827368, 0.08799855029792525, 0.03239452344132587, 0.010990324863087153, 0.049658255084068514, 0.020078796114830766, 0.06723680577124469, 0.07241605402668938, 0.012921407960675424, 0.06540926711750217, 0.08218340022722259, 0.011730072619684506, 0.04456194554222748, 0.01767826750437962, 0.04504752163484227, 0.09169916578684933, 0.04705590312369168, 0.04790300903550815, 0.024743518952163868, 0.0661692040739581, 0.08273139465018176, 0.010877271652134368, 0.012694423021457624, 0.03931710256438237, 0.02591743515949929, 0.0309701509468141, 0.07638996539753862, 0.023868365424277727, 0.046539572431356646, 0.02691837344173109, 0.03110983427177416, 0.017329985021206085, 0.026273634503013454, 0.04039779945742339, 0.03174963050696533, 0.03911390624125488, 0.02659357251104666, 0.04367840017948765, 0.03434036785620265, 0.058802523781196214, 0.08384941786061972, 0.03459357380052097, 0.05722284389776178, 0.09585546737071127, 0.07330293534323573, 0.03168969094986096, 0.020299688949307892, 0.04603969515301287, 0.08438993143499829, 0.04523799383605365, 0.056336281704716384, 0.0448746865731664, 0.05110857862746343, 0.04820161215320695, 0.06175984497531317, 0.012646205686905887, 0.010242210319120204, 0.013363537800614722, 0.07475352977053262, 0.07475786391296424, 0.009021728055813583, 0.053073874732945114, 0.013732168117712718, 0.025906377159117255, 0.027614073806034867, 0.03638837632024661, 0.06580209330422804, 0.015838795115996618, 0.014151361883705249, 0.06588851640117355, 0.030536373051290866, 0.051930006229667924, 0.06274799234233797, 0.053920750578981824, 0.024133774131769314, 0.011813635665021138, 0.048148860296350904, 0.007649599510841654, 0.032858250706340186, 0.03416402243601624, 0.02641863902681507, 0.03846646774036344, 0.02051153871434508, 0.05829487992741633, 0.03006265833391808, 0.03242823178879917, 0.04788336438650731, 0.025080706327571534, 0.045752198275295086, 0.04755993271828629, 0.059085126194986515, 0.018747698595689144, 0.02547015388699947, 0.05510518487426452, 0.03637275040091481, 0.029353775571507867, 0.020249660774425138, 0.007653203101654071, 0.05111986669362523, 0.05641264498990495, 0.023283671798708383, 0.049301141043542884, 0.023153903566708323, 0.011406442426959984, 0.066505144641269, 0.018515180017857347, 0.039624247801839374, 0.01414689322700724, 0.030093305322225206, 0.09146518888883293, 0.018202190367446747, 0.04603511610184796, 0.03303919002064504, 0.014673134373879293, 0.04522526229266077, 0.017407650775567163, 0.028460901412472595, 0.024888222906156443, 0.05748713010689244, 0.06244551521376707, 0.036179907037876546, 0.017880248560686596, 0.09045709259225987, 0.10069899028167129, 0.07228856789879501, 0.11770229859394021, 0.023401968282996677, 0.07740749439108185, 0.07665952827665024, 0.012312451672187308, 0.03996713487140369, 0.07244009961141273, 0.07996525440830737, 0.02289933392603416, 0.04639780367142521, 0.039817157958168536, 0.046937779188738205, 0.032676357732270844, 0.061682375890086405, 0.02082189188513439, 0.07784902030834928, 0.04353863150754478, 0.03911307874659542, 0.03819075987848919, 0.01236467382113915, 0.025504726836516056, 0.015349786590377335, 0.008825683253235184, 0.06019033622578718, 0.022297242503555026, 0.039469843977713026, 0.04456626484170556, 0.04945083594066091, 0.05894951355003286, 0.03617449678131379, 0.0561056630249368, 0.03620454634074122, 0.03331500178319402, 0.024406943848589435, 0.052830209097010083, 0.061631160278921016, 0.07186419301433489, 0.03145009970467072, 0.011980391609540675, 0.03575295319024008, 0.04555869811156299, 0.036294168094173074, 0.08210310727008618, 0.060092398707638495, 0.11465420160675421, 0.039858447344158776, 0.06663548803771846, 0.04632491363736335, 0.046163578153937124, 0.025485093319730368, 0.014901089671184309, 0.01659020665101707, 0.11092557004303671, 0.015221617686620448, 0.05711041965696495, 0.006574226599695976, 0.017860820989881177, 0.016137066122610122, 0.049641408331808634, 0.03460614578216337, 0.01624167740374105, 0.0656336999963969, 0.031658698862884194, 0.09889390901662409, 0.06534907894092612, 0.08666140056448057, 0.059736134426202625, 0.11129934529890306, 0.044752016983693466, 0.07473571080481634, 0.08803333475952968, 0.03485455745249055, 0.02791614089801442, 0.06613336576265283, 0.028065310725651216, 0.07407922181300819, 0.016907595381780993, 0.06193759305460844, 0.023359691840596497, 0.05247966306342278, 0.024999012566695455, 0.032896590055315755, 0.016870842373464257, 0.010551081049925415, 0.030715304856130388, 0.07235471552121453, 0.013634215756610502, 0.028871255271951668, 0.07320710181375034, 0.005657121319018188, 0.04632607880921569, 0.06569595876499079, 0.01244638242496876, 0.03812246744928416, 0.04018515559437219, 0.07138104745536111, 0.03713580808835104, 0.10820328330737539, 0.034462065232219175, 0.008630462234577863, 0.0349911237572087, 0.04000848733994644, 0.03843603597488254, 0.030177585467754398, 0.06470237887697294, 0.018840140510292258, 0.020568732325045858, 0.058543885315884836, 0.0172919369651936, 0.060907184088137, 0.10269339341903105, 0.016007084523153026, 0.018592298438306898, 0.022835809795651585, 0.038508117067976855, 0.06743869962519966, 0.03415857136133127, 0.03902828466380015, 0.08683217616635375, 0.02620415463752579, 0.04245920368703082, 0.019481526796880644, 0.05529812471650075, 0.060051521213608794, 0.06750786778866313, 0.021654722586390562, 0.019149031650158577, 0.027654133082251064, 0.02477681169693824, 0.036554357648128644, 0.03577911018510349, 0.03217562327336054, 0.025890756805893034, 0.022426840041589458, 0.020286619728722144, 0.029029200995864812, 0.06703850391204469, 0.041095462802331895, 0.08259955953690223, 0.0440299555339152, 0.05011579654819798, 0.028074843612557743, 0.02831541634805035, 0.030022541541256942, 0.009454094015381997, 0.021060577710159123, 0.08850165962940082, 0.021086500928504393, 0.017330673363176174, 0.08116509197861888, 0.007355528132393374, 0.04320397485571448, 0.04482981261389796, 0.09277201446820982, 0.008798815651971381, 0.005343684988474706, 0.06643096698098816, 0.07363202588749118, 0.03968974604504183, 0.016390049422625452, 0.009998935238400009, 0.013725318094657268, 0.006712303174936096, 0.0445765918266261, 0.03403775714104995, 0.027886985626537353, 0.01282595385418972, 0.13593589479569346, 0.008709977792022983, 0.06978407924179919, 0.017919114834512584, 0.007044955564197153, 0.039761901352903806, 0.008799990100669675, 0.055507376964669675, 0.04441629534994718, 0.21234206127701327, 0.06859368178993464, 0.11962987875449471, 0.2147378772497177, 0.12539003568235785, 0.1661153300665319, 0.11889250308740884, 0.15398967603687197, 0.09826516892644577, 0.16433076176326722, 0.09873386487015523, 0.11392041793442331, 0.18105427297996357, 0.15911591268377379, 0.12107094400562346, 0.14707174646900967, 0.20020990603370592, 0.15793462138390169, 0.1733235878054984, 0.16172315168660134, 0.0918452427140437, 0.12241544100106694, 0.13431293657049537, 0.1768567896215245, 0.12591712380526587, 0.16259605094091967, 0.1055118402291555, 0.11578099700273015, 0.1701485167723149, 0.07554221010650508, 0.15051587572088465, 0.11520309402840212, 0.08125754131469876, 0.08816326997475699, 0.10646967828506604, 0.14586357458028942, 0.10635952872689813, 0.11824451910797507, 0.11435964319389313, 0.10647568968124688, 0.18963151116622612, 0.18001151096541435, 0.18043535150354728, 0.15175377804553136, 0.1931836229050532, 0.1061377750011161, 0.16709131363313645, 0.09699008500319906, 0.15836877777474, 0.132130102138035, 0.11027265820303, 0.14988893904956058, 0.21796997491037473, 0.08948597009293735, 0.12157432793173939, 0.1773123347084038, 0.12761998164933175, 0.12215198599733412, 0.1315662034903653, 0.07570284797111526, 0.10613873237161897, 0.22079170943470672, 0.1188581193855498, 0.3128900838783011, 0.13554418925195932, 0.19818960194243118, 0.2171110428753309, 0.2331109155784361, 0.1240468819742091, 0.15493515733396634, 0.2352659046300687, 0.18138881830964237, 0.1620579048176296, 0.18943515373393893, 0.07592717694933526, 0.16219483106397092, 0.14932119607692584, 0.13994928100146353, 0.16534382302779704, 0.12949109921464697, 0.17925827560247853, 0.11588877168833278, 0.11625417551840656, 0.08181838973541744, 0.07982487717526965, 0.11412572566769086, 0.15189019963145256, 0.13093248358927667, 0.18886343284975737, 0.10441438935231417, 0.13476111955242231, 0.20057286077644676, 0.15499066998017952, 0.10722065009758808, 0.15555801219306886, 0.17382373596774414, 0.21723913756432012, 0.18809257890097797, 0.14933422819012776, 0.263266884139739, 0.12768086744472384, 0.23317940096603706, 0.11376937603927217, 0.2332611262681894, 0.15121128293685615, 0.21926453278865665, 0.1371705168276094, 0.18867516482714564, 0.0677410580101423, 0.1545316813280806, 0.19454028370091692, 0.06527625941089354, 0.198295209556818, 0.07437467822455801, 0.08428698813077062, 0.1627748491591774, 0.11368741324986331, 0.11942875673412345, 0.19952815433498472, 0.1434585262904875, 0.21272710233461112, 0.18279805284691975, 0.18555216287495568, 0.2132137879380025, 0.12301957147428766, 0.11141063034301624, 0.17161972064059228, 0.10974504315527156, 0.14576791174476966, 0.1380760854226537, 0.1330360269639641, 0.09795950798434205, 0.08564871037378907, 0.0968630812712945, 0.13871603936422616, 0.13602097460534424, 0.1562993583502248, 0.10500193282496184, 0.15410193329444155, 0.265060180099681, 0.1555533811915666, 0.10179408855037764, 0.07987100907485001, 0.15284492808859795, 0.166061969648581, 0.1190859216148965, 0.3164060233393684, 0.1218492491170764, 0.14102141722105443, 0.15960449818521738, 0.25759954762179404, 0.09591072768671438, 0.15746840421343222, 0.32254518766421825, 0.08932839729823172, 0.2275097934762016, 0.10380368345067836, 0.30745426774956286, 0.1582190569024533, 0.10583234412479214, 0.08210219442844391, 0.09472560690483078, 0.20577985793352127, 0.07246657201903872, 0.1496758239227347, 0.10281096445396543, 0.0741942843887955, 0.20951617072569206, 0.10184768645558506, 0.12489549815654755, 0.17851320386398584, 0.11517021688632667, 0.10444353349157609, 0.19062953651882708, 0.21456001413753256, 0.27560915623325855], [0.08168366766767576, 0.0796484093007166, 0.0529181573074311, 0.025361334628541954, 0.04913952354399953, 0.08798355891485699, 0.06354662487865426, 0.04889107476628851, 0.012427405708876904, 0.03540293408150319, 0.031222256657201797, 0.061878451306256466, 0.055020910294842906, 0.043054695561295375, 0.01096228003007127, 0.0642416239134036, 0.06155274124466814, 0.013947229526820593, 0.04975713512976654, 0.02972024623886682, 0.04261516602127813, 0.011187410527782049, 0.012232756143930601, 0.03510391907184385, 0.0445431729167467, 0.019938411460316274, 0.06914313824381679, 0.023548542449134402, 0.029315842548385262, 0.01956918556970777, 0.04392489339807071, 0.046869085999787785, 0.010143447161681252, 0.0547458555229241, 0.05828662353451364, 0.04391835136630107, 0.01988216223253403, 0.017281858599744737, 0.045245968212839216, 0.011469034234323772, 0.012089815718354657, 0.04421197096235119, 0.015058850785862887, 0.034005343841272406, 0.020138125255471095, 0.03531895636115223, 0.05284338221827056, 0.043274193158140406, 0.023172347791842185, 0.019113176640530583, 0.030509828284266405, 0.020717870611406397, 0.06089362876082305, 0.02203110278060194, 0.046239811563282274, 0.029475198352884036, 0.00927669289012556, 0.034882514155469835, 0.04528656369075179, 0.03638519250671379, 0.013164440915716114, 0.042564380855765194, 0.027628862953861244, 0.11178387867403217, 0.016203104278247338, 0.0889249361352995, 0.015735050292278174, 0.0078100940481817815, 0.031836446942179464, 0.06312271012575366, 0.05494620570971165, 0.053212340935715474, 0.029972314841870684, 0.012894021783722565, 0.015705305013398174, 0.0429100138717331, 0.04542796879832167, 0.038065177359385416, 0.05402192386100069, 0.04533642117166892, 0.029863423224014696, 0.05306135841237847, 0.03143192450806964, 0.11141693859826773, 0.05502527412318159, 0.04395928081066813, 0.04101261314644944, 0.0758317590225488, 0.00839356034703087, 0.02765236120467307, 0.024798400772851892, 0.1156402264314238, 0.059508180056582205, 0.01848663330747513, 0.09682460833573714, 0.035021703952224925, 0.010594278683129232, 0.04852426085562911, 0.05821343664138112, 0.03577452000172343, 0.0212334109164658, 0.03732007593498565, 0.033466221793787554, 0.0504552289203275, 0.046628589334432036, 0.02235013722383883, 0.012021543698210735, 0.01933910865773214, 0.06185432408528868, 0.037064710340928286, 0.01424509049684275, 0.0697946548461914, 0.055598516410100274, 0.052636682958109304, 0.016407439798058476, 0.018727608658082318, 0.021200771261646878, 0.04253821272868663, 0.04595512000378221, 0.04460477859538514, 0.03987477830378339, 0.03962360213336069, 0.025805391269386746, 0.07760164022329263, 0.016626610849925783, 0.04230495571391657, 0.02407838765066117, 0.044412540082703345, 0.03116029103694018, 0.062401090253842995, 0.00825121456728084, 0.02461627773300279, 0.016749263741075993, 0.003954856729251333, 0.05955486856692005, 0.04435768052644562, 0.03824455074209254, 0.0030564649341613404, 0.044284163377597, 0.046277119326987304, 0.029806780657963827, 0.032850962816155516, 0.030051795147301164, 0.049239104919251986, 0.07828190762666054, 0.004860786193603417, 0.02333853506570449, 0.021634033364534844, 0.002310259565092565, 0.04853384198213462, 0.1291238548583351, 0.04035956029838417, 0.05651067156577483, 0.018925368749478366, 0.04273979488061741, 0.03420823588385247, 0.02818272219883511, 0.048017247827374376, 0.01722285414871294, 0.034020914099528454, 0.06972035102080554, 0.015385450496978592, 0.004862239411522751, 0.004401231190058752, 0.04725822371256072, 0.005143822299942258, 0.04540604575595353, 0.03769250790355727, 0.0008150676285367808, 0.027204797916056123, 0.05543725514144171, 0.017560112028149888, 0.02960522262583254, 0.034434327462804504, 0.032701457166695036, 0.02403085494734114, 0.022920284754945897, 0.05806389759527519, 0.04170695166976657, 0.027691036375472322, 0.11463498740340583, 0.05521259219676722, 0.03664183459477499, 0.10206765160546638, 0.022832987779111136, 0.046664219844387844, 0.023907452487037517, 0.035413943842286244, 0.06687628527288325, 0.08408524270635098, 0.04224332034937106, 0.09138373818132095, 0.04596406659402419, 0.0571921189839486, 0.007126339942260529, 0.0237289622600656, 0.003216035265722894, 0.02105833827954484, 0.023023671492410358, 0.029950440039101522, 0.003616143080762413, 0.03553381553501822, 0.032850847783265635, 0.03317698457976803, 0.03955582549679093, 0.04368724657979328, 0.011823644454125315, 0.055127393643488176, 0.042830333186429925, 0.05844034087203909, 0.024113728723023087, 0.012483011123549659, 0.06784856552258134, 0.017696542890917044, 0.042077546822838485, 0.017479295856901444, 0.018338838308409322, 0.05289130269375164, 0.025388324684172403, 0.02553340713348007, 0.03942449504393153, 0.06084382323024329, 0.07711050173384137, 0.03477663194644265, 0.026957889094774146, 0.0021598904731945368, 0.03540316414728295, 0.022386645323422272, 0.03908099570253398, 0.012349596163403476, 0.07197639090009034, 0.03405430332350079, 0.011066787410527468, 0.02556283328885911, 0.06052698183339089, 0.052388612675713375, 0.02164853307476733, 0.02878602703276556, 0.026373483051429503, 0.036086734107811935, 0.08514737477526069, 0.08613380778115243, 0.024928215389081743, 0.01508664792709169, 0.10029097233200446, 0.09690605904324912, 0.051831831224262714, 0.028945904196007177, 0.029597374414152, 0.04395919546368532, 0.007560739386462956, 0.0198909102982725, 0.04949307156493887, 0.018132562072423752, 0.04385602951515466, 0.04397339274873957, 0.04263979790266603, 0.03671000085887499, 0.03999684675363824, 0.034446331701474264, 0.10212226625299081, 0.03901732314261608, 0.027362090550013818, 0.0693893531570211, 0.014582354870071867, 0.14372872741660103, 0.023084123131411616, 0.034697515293373726, 0.03153365811158437, 0.004833323482671403, 0.13740649010287598, 0.06641758605837822, 0.07053620138322003, 0.03232260190998204, 0.045039484175504185, 0.011167686097905971, 0.020978525863029063, 0.02166329253668664, 0.06410754009266384, 0.04241992181050591, 0.008512347576470347, 0.014808326777711045, 0.05062985626864247, 0.041469746429356746, 0.12863621930591762, 0.08421923004789278, 0.039672550483373925, 0.0621741489158012, 0.039220074177137576, 0.028191678065923043, 0.06558659588336013, 0.04322184577176813, 0.04922164589515887, 0.027925302711082622, 0.03748676601389889, 0.023392531875288114, 0.040130318302544765, 0.02134789276169613, 0.04148939478909597, 0.03024903759069275, 0.027413777424953878, 0.059157975410926156, 0.030174193852872122, 0.05480995481775608, 0.03578850577468984, 0.008097400750557426, 0.04733889516501222, 0.03464982488367241, 0.04664694635721389, 0.02894289107643999, 0.019357018536538817, 0.018053178246191237, 0.1252676110016182, 0.04900781459582504, 0.044992305847699754, 0.009654398745624349, 0.06469469764851965, 0.013463406758091878, 0.023555336811114103, 0.04139632575970609, 0.015401653436128981, 0.03146700582874473, 0.03800585007411428, 0.02395074196101632, 0.003942175280826632, 0.028412678511813283, 0.028218764600751456, 0.052072431790293194, 0.06705599633278325, 0.03498792138998397, 0.0867123415810056, 0.02225438718596706, 0.025600237531762104, 0.07271691327332519, 0.06420117686502635, 0.04594436257320922, 0.09027155567309819, 0.015319006015488412, 0.061190777269075625, 0.01800047277356498, 0.064715247717686, 0.022661633302050177, 0.03356571411131881, 0.04971796086465474, 0.06301770365098491, 0.06002480018651113, 0.07191671480541117, 0.05304056714521721, 0.08554012674721889, 0.06934932171134278, 0.02745884434261825, 0.05726343937567435, 0.1096185292408336, 0.1873938913922757, 0.12547277030535042, 0.08839737303787842, 0.2074727858416736, 0.1661091108690016, 0.20162530039669946, 0.20902080199448392, 0.11774861603043973, 0.11194283186341636, 0.1335830194875598, 0.14899656584020704, 0.12448193636373617, 0.1304529671324417, 0.14624057075707242, 0.24231194372987375, 0.23470726038794965, 0.1811167469713837, 0.11129125588922761, 0.1501346196164377, 0.06519572896650061, 0.14728456473676488, 0.15430338185979053, 0.17878845159430057, 0.12878298643045127, 0.1319106193841435, 0.10052177283796482, 0.13156657456420362, 0.07510547104175203, 0.18718395265750587, 0.13736038788920268, 0.12056534847943112, 0.0856354704592377, 0.13014892407227308, 0.19550219614757225, 0.0929313461529091, 0.15856363606872037, 0.07274751202203333, 0.17225796764250845, 0.06309577758656815, 0.09257463287212886, 0.14649919437943026, 0.11847062181914225, 0.10046749957837164, 0.12470717076212168, 0.19374041177798063, 0.17308068287093192, 0.17267308052396402, 0.08598458414780907, 0.07008804066572338, 0.12831488420488313, 0.1471570786088705, 0.09432825361727737, 0.10176662166486494, 0.21197529189521447, 0.14528417988913134, 0.20917570305755362, 0.12751645204843953, 0.14888705452904105, 0.135199046053458, 0.1374875326291658, 0.10643562112818472, 0.12540320138214156, 0.29397597536444664, 0.2425643036258407, 0.14871069055516273, 0.16520321572897956, 0.08516770220012404, 0.20354703243356198, 0.23862934758653864, 0.1231482153525576, 0.09660351512138732, 0.14598386187572032, 0.13223694171756506, 0.10775633971206844, 0.11880544174346142, 0.12655621685553342, 0.21803008887218311, 0.18343745759921148, 0.17276895116083324, 0.19059130107052624, 0.12018282330245711, 0.09140224734437652, 0.20378359942696989, 0.1964879166916944, 0.1325709675438702, 0.21953786577796564, 0.22170646581798792, 0.11324365346808918, 0.1650316163431853, 0.19924178923247382, 0.17416904243873432, 0.17842704051872715, 0.08730495392228477, 0.2863588684704155, 0.14093284931732342, 0.12248345141415484, 0.12954962498042732, 0.1415739461663179, 0.0975784745241981, 0.12481216981541365, 0.11439101377618499, 0.1368378268671222, 0.22910309548024088, 0.11999646259937435, 0.10129476417205296, 0.1790293972590007, 0.12040526722557843, 0.24881749151973054, 0.1424914930248633, 0.11393782129744068, 0.23661837971303612, 0.11404832708649337, 0.20673895021900535, 0.21008645184338093, 0.08593099366407841, 0.16880283976206556, 0.07792361357132904, 0.15780422603711486, 0.10830923973117024, 0.10298606677679345, 0.18735510675469413, 0.23159458913141862, 0.17753063002601266, 0.0909455370856449, 0.22580393735552207, 0.10823000062373467, 0.13287979003507644, 0.16388783318689093, 0.1348957748268731, 0.0623834939324297, 0.10194097441853955, 0.09318841868662275, 0.11257454054430127, 0.2083060989389196, 0.10597168977255933, 0.18537569500040263, 0.13473723724018782, 0.19901369756553322, 0.14358614600496367, 0.1240430970210582, 0.10874851694097742, 0.17648479552008212, 0.13049173692706972, 0.312289270805195, 0.06922142740222625, 0.08238976923166774, 0.08533987303962931, 0.11651745982817374, 0.12445425425539725, 0.2470736374380067, 0.2479240347747691, 0.21903507556999102, 0.1812788617098704, 0.1601391562144272, 0.0841912733449135, 0.0959522211633157, 0.18542121833888814, 0.14368844364071265, 0.1265220483765006, 0.17632363073062152, 0.10427289147628471, 0.13826885086018592, 0.07280927355168387, 0.22022485703928396, 0.09498301340499893, 0.11814514553407207, 0.10629183001583442, 0.1399203817709349, 0.14778634562389925, 0.1385693167685531, 0.2261609846027568, 0.1891086235991679, 0.10747896201792173, 0.04453547684533987, 0.13526891183573753], [0.07490009651519358, 0.07036868380964734, 0.07536079952842556, 0.07522508298279718, 0.02262220670672832, 0.02892095875722589, 0.02020973879552912, 0.03160184664011467, 0.021535719206440262, 0.035956060455646366, 0.07240958992042579, 0.020041703573951963, 0.04004808462923393, 0.020345288357930258, 0.02542085672757821, 0.045934202571515925, 0.021818859677296132, 0.05606638856988866, 0.041577064694138244, 0.03758401333470829, 0.029232935376057867, 0.010789054413180565, 0.07744532165816054, 0.0015224684148051892, 0.0419901440909598, 0.024176729639293626, 0.0370963332534302, 0.055431280852644704, 0.012464968585845781, 0.031613613391527906, 0.04617105529177934, 0.01124349462770624, 0.009192935031023808, 0.014875686883897288, 0.0639948078605812, 0.016191588001674972, 0.030676388487336226, 0.08135879252222367, 0.04645695284125395, 0.04639847160433419, 0.029018117020314094, 0.015332643906731391, 0.045584513718495145, 0.016208974666369613, 0.06361764098983258, 0.07972127335960977, 0.06696433367324062, 0.009339034222648479, 0.028529858063848224, 0.033437441306887195, 0.036821252506342717, 0.0262970177209354, 0.030036467942409217, 0.03301280667074025, 0.0535386484261835, 0.08054522797465324, 0.02557277064624941, 0.021259400928101968, 0.011949868930969387, 0.02797442917653825, 0.042529358906904235, 0.034123968725907616, 0.05373913219955284, 0.02733554763835855, 0.04115848227229435, 0.06329026480671018, 0.04744619858684018, 0.01602917083801003, 0.03117112268228084, 0.044055474281776696, 0.01813991675589932, 0.03302185345091857, 0.04160564480116591, 0.06313727848464623, 0.05789359325717669, 0.05685412266757339, 0.017976232375076506, 0.04666729233576916, 0.01916023436933756, 0.025026323601196054, 0.07463437053957023, 0.04296429826354142, 0.036702649886137806, 0.006963316536712227, 0.01440584339434281, 0.0939777001622133, 0.05827019609569106, 0.05123131129948888, 0.034805156392394565, 0.04423615384439472, 0.07475574137060903, 0.06046631126082502, 0.05817564648168627, 0.04033996017824393, 0.05076155037386343, 0.01247497459189617, 0.024962224306364078, 0.019436380098341033, 0.058738212974276394, 0.0392316665238468, 0.02295258302183356, 0.032873030577320606, 0.030699244780407753, 0.024984416377265006, 0.01731250373268267, 0.04897153841739055, 0.03982457572419662, 0.05517765188415069, 0.030619385979662184, 0.05181882508622948, 0.07523323918576352, 0.016821025710669346, 0.040160623902920634, 0.04161840974120423, 0.03253984708862845, 0.004848380731345969, 0.020502812913036905, 0.024989670782815665, 0.04743235753267072, 0.016037263958423864, 0.005925839077463024, 0.05625951394904405, 0.07904807120212354, 0.03446208007517271, 0.03817293720203452, 0.011635369937721407, 0.02671398782695178, 0.06562791124451905, 0.08828727543004788, 0.031326120224548504, 0.03390161014976911, 0.023653699208807666, 0.07791747601004317, 0.0737454928457737, 0.032459064314025454, 0.06654504992184229, 0.07242797291837633, 0.02280406071804464, 0.05725722017814405, 0.047713817039038986, 0.06770975422114134, 0.04459597672394011, 0.03604190467740409, 0.03430931639741175, 0.050656198800425045, 0.009909179898386355, 0.028925281767442357, 0.059731221408583224, 0.03747371163626667, 0.07264665415277705, 0.05837660522956867, 0.03847756284812931, 0.04937016077747103, 0.011801252931036288, 0.014916906693542842, 0.03241282480303198, 0.012277205223654164, 0.06242255316465162, 0.04142209312703926, 0.034206020573037677, 0.08390274859266356, 0.039514736490673386, 0.03938171394111123, 0.028360605720081367, 0.01909242619149154, 0.03634116459579673, 0.050787173022399656, 0.03391251229913905, 0.06420977093512192, 0.040881037784856744, 0.0888569257222116, 0.10517765855183825, 0.03784746091696434, 0.03754631594347302, 0.02538824119255878, 0.041793452692218125, 0.0381766813370632, 0.04936576726322528, 0.028704971518891398, 0.042131274603889324, 0.023502473632106557, 0.05703780050680507, 0.041139279201161116, 0.04728857384179719, 0.016613471125310753, 0.04083495783561375, 0.03256374053307809, 0.07090518236509524, 0.025497930619167164, 0.03935704124160111, 0.052196507749613374, 0.017792604630813003, 0.009407303459738614, 0.045257478923304006, 0.02499216810974758, 0.014944240920158336, 0.032814126316225156, 0.020081471557205077, 0.02835389670508448, 0.0443677106522955, 0.013515140944946324, 0.02081581926177023, 0.05614861111098435, 0.05940070594078861, 0.04342849679233041, 0.032935170602286234, 0.13164032920030877, 0.02091531343467068, 0.008258580382971559, 0.03338953938509803, 0.020884551413473673, 0.04089906455192249, 0.02776003570033936, 0.0061379031376418425, 0.08209341482142918, 0.005132942878844915, 0.019981409641331993, 0.03529164161591325, 0.023961786973814014, 0.030289723981695715, 0.055870676806080155, 0.06768746752641164, 0.03328241407871246, 0.047000127015053295, 0.024149591154127847, 0.04693387549195904, 0.04876731793046929, 0.02433614296023734, 0.027302445996610913, 0.0227952161731082, 0.019699499280250166, 0.09063776102266274, 0.0838490245223511, 0.08173111316864379, 0.027255557106400374, 0.028973423031857237, 0.03979326822445728, 0.0456989899976179, 0.03498542035231367, 0.05117603614053223, 0.033671065684757195, 0.028562553379742894, 0.06024031245033257, 0.014737627006979892, 0.07294433700735681, 0.04208205165923573, 0.04893136596365366, 0.1285543158883229, 0.028512347089417744, 0.0710863851418253, 0.05639869632432237, 0.054098728724056855, 0.04772275249706581, 0.06993616014369763, 0.030579443591705058, 0.02486432760633761, 0.05914199697144795, 0.045786129267071374, 0.06044709705747664, 0.02721065717196325, 0.04023600384243764, 0.008434070477960631, 0.043567397151491605, 0.030614704883191735, 0.018084255680150818, 0.07224147120723501, 0.07926286358269863, 0.05040969073888846, 0.035771699840552174, 0.03835072981019039, 0.05848301436344627, 0.03846733605314512, 0.009807310852920637, 0.006873314432596089, 0.0752314951387234, 0.04108316912606824, 0.025427172404306475, 0.07467183415428735, 0.04309311283577699, 0.0076071180501458, 0.022152475467009936, 0.027628541974991094, 0.031518696414423175, 0.04218221933115274, 0.07548562876763754, 0.05430953206086997, 0.04360607417766005, 0.0915306166280061, 0.09383042095578276, 0.031014110209071077, 0.017711714244796894, 0.011594683546718443, 0.05788749651401304, 0.0492193155514542, 0.027220420124649536, 0.011312375208945014, 0.10436187498271465, 0.07121148897567764, 0.03409598604775965, 0.03885675949277356, 0.011794136662501842, 0.03233567484130617, 0.00977244568275637, 0.011020758483937243, 0.012922466448799241, 0.030665068879898172, 0.0386688291473547, 0.022583110367122572, 0.027440259109425824, 0.02537735017540399, 0.05886491242563352, 0.02948836776340613, 0.041572912377887405, 0.05501345913216937, 0.052493099647108465, 0.015510736157011706, 0.09721434718812816, 0.017037480502040125, 0.02858087329514092, 0.06989444402279332, 0.05029064283007756, 0.03999337350251153, 0.057753249420784414, 0.02315750483830925, 0.05360353068681434, 0.019329477436258458, 0.027481251636345405, 0.08461964840535074, 0.011659974916256033, 0.08281717950012535, 0.05855997136677615, 0.009672128653619438, 0.060706203075824305, 0.05802976251288783, 0.010654648685886059, 0.021326518908608705, 0.026525549110374413, 0.09566560373059474, 0.005199114621063927, 0.028565985812747385, 0.032115824724314734, 0.038213547522900626, 0.039545042091049254, 0.012587254113896051, 0.039387814395013265, 0.025839426161837764, 0.012606778163899435, 0.0496532789838966, 0.005663449519488495, 0.03955779960961081, 0.0216527447628323, 0.03235120057070162, 0.2229953240021132, 0.08133464303682558, 0.11474386788904667, 0.19445070647634566, 0.16746897774282843, 0.15214664133964106, 0.10072544784634374, 0.11587397326366045, 0.0894232140854001, 0.08736165400478058, 0.14548978448146954, 0.21224672498647124, 0.1077256296412088, 0.15003459295257926, 0.1218629936920479, 0.12476639414671808, 0.10937517159618437, 0.18028963822871447, 0.10314766943338327, 0.10847714322153479, 0.17055880569387227, 0.0953635793121066, 0.19728593324543908, 0.2016643522074446, 0.1352962970850058, 0.09092040796531364, 0.1966821070527658, 0.17009309318382293, 0.12450976690161042, 0.14811983710387722, 0.2396134502487257, 0.08756894327234477, 0.11828496615635231, 0.14594308828236535, 0.12282705094548874, 0.1225197795429267, 0.09034266826347448, 0.10328395743272267, 0.14781919308006763, 0.12670909927692264, 0.10296148684574291, 0.20450783165870234, 0.1993997479439713, 0.04949970265442971, 0.19349164387676865, 0.16151490504853427, 0.09951568776159547, 0.1212800144276116, 0.06998262600973248, 0.08265108685009181, 0.19164803030434996, 0.1946602889802307, 0.21410230197943747, 0.08958688733400777, 0.11395798544981517, 0.19558930944185704, 0.14326332660857588, 0.12625006609596312, 0.12769830791512504, 0.13474597973981872, 0.19297868624562398, 0.09224479275872, 0.1378719205968082, 0.11047311971196905, 0.15675209811888635, 0.188279852445703, 0.17289848561631516, 0.15441780618857592, 0.1423627749318257, 0.09648576597101055, 0.19545397139154375, 0.12038016779115424, 0.09531893170787953, 0.1495479221921414, 0.14980771840782836, 0.2193175518186763, 0.1328093750635162, 0.14922827918780968, 0.18421650485834107, 0.16579221381107345, 0.13234118378022686, 0.11404317658161744, 0.12849786813603714, 0.11403694996261038, 0.13616934476885945, 0.10751131965662353, 0.14177739853039384, 0.18018742965068668, 0.12374369238386862, 0.12113911026972346, 0.16571510466746986, 0.2932116820011288, 0.13745798030868173, 0.13178733381209895, 0.23925309302285314, 0.09318147218436934, 0.10360355590819381, 0.16689237352693453, 0.12474126502638683, 0.15265761001501232, 0.20206034736474976, 0.1931886249803938, 0.1298888903693296, 0.07877119816839695, 0.08489320403896272, 0.09441854330361821, 0.1638069242471829, 0.1482829314772971, 0.09760999353602529, 0.12856868386734277, 0.1809854610473849, 0.15270222793333232, 0.21279258944559842, 0.1586167441564612, 0.10275591193931177, 0.15624850639142096, 0.13711541978409514, 0.1424780156230554, 0.1129332056734711, 0.15198123146547005, 0.1263070630375296, 0.16417002741945907, 0.28106934449169785, 0.1476714017917402, 0.15849209303269163, 0.110826886666473, 0.09049775486346334, 0.10921367284026928, 0.17694461537757888, 0.11807941351435147, 0.17907891335198656, 0.11044868821045384, 0.1594776354613714, 0.10786971761262976, 0.1063135452568531, 0.194043668161612, 0.1666610164102167, 0.12855370732722804, 0.15988382772775367, 0.10183434264035895, 0.2483760769246146, 0.14603368967073038, 0.09530148381600156, 0.15812306752195582, 0.07971879458636977, 0.12006483666482382, 0.12457321310648695, 0.1870683260494843, 0.16671712277457118, 0.1548467527027242, 0.23403226223308593, 0.2245020173722878, 0.12073644320480525, 0.16477297787787393, 0.08782643883023411, 0.11918021147721447, 0.11028163076844066, 0.20316295616794378, 0.1468767545884475, 0.09548982605338097, 0.16531866422155872, 0.14265386009356007, 0.10683547545340843, 0.10931928787613288, 0.08648263203212991, 0.08048174466239288, 0.08385197084862739, 0.1614227006211877, 0.12460778234526515, 0.11552934214705601, 0.1391096893348731, 0.1601379836210981, 0.08736212897929363, 0.12807089573470876, 0.10006878816056997, 0.19925572676584125]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.011249884519202169, 0.04083774831087794, 0.01756875619321363, 0.09274228403228335, 0.013046312342339661, 0.026946558355120942, 0.0888777503860183, 0.04125676859985106, 0.016561075499339495, 0.042814588523469865, 0.0668643663811963, 0.04319703577493783, 0.053614967182511464, 0.02996800481923856, 0.01668235912802629, 0.022197906037035864, 0.08443346581771038, 0.0322541573405033, 0.014290970993897645, 0.04465833568247035, 0.04677554199588485, 0.09822756430367008, 0.015857202233746648, 0.03140277665806934, 0.04653973941458389, 0.027848855934280436, 0.03726156130142044, 0.009487229981459677, 0.00998301988147432, 0.06613887991989031, 0.013654357644554693, 0.048887052325881086, 0.029749976674793288, 0.02400981877144659, 0.08551862672902644, 0.027796571630460676, 0.036036331148352474, 0.09233620308805257, 0.008648074326629285, 0.036079468482057564, 0.08605381910456344, 0.030140377893985715, 0.057309174226247706, 0.021277045489114244, 0.05915036097576376, 0.07202968452475034, 0.023256190070242155, 0.03188056762155611, 0.03948522498831153, 0.06408659668522887, 0.052630623322329484, 0.02486010478605749, 0.06483958713943139, 0.1088524101942312, 0.05254900192085188, 0.005939677348578698, 0.11260867191595025, 0.03443636836891528, 0.038183319848030806, 0.02321225307241548, 0.09980326998629607, 0.049021317972801626, 0.044192756759002805, 0.009981604234781116, 0.03649987658718601, 0.058890716900350526, 0.08589334451244213, 0.07301727528101765, 0.04035630598082207, 0.05243765008344781, 0.056392926126136445, 0.05317311472026631, 0.04080516802787315, 0.02729181658651214, 0.06605302085517906, 0.05604300349659752, 0.10338405831134878, 0.053070950671099126, 0.026932733999274205, 0.025156479605357163, 0.013588811161753256, 0.014362875826918753, 0.026406927936477587, 0.016766579901741352, 0.03756835401873104, 0.028379055511322804, 0.009405840501131024, 0.035244734172010794, 0.012642879009945318, 0.0690474160364829, 0.02064209918898996, 0.055755254288669676, 0.005588643352893996, 0.039713505902909674, 0.010002043909480562, 0.047479572967858985, 0.001671155614531017, 0.04215696775645483, 0.046467699139611796, 0.02470990893925773, 0.03587721468647942, 0.019260828776168637, 0.03900389769114554, 0.031028157209220808, 0.11634312933892943, 0.0937604067439679, 0.07267893015523441, 0.02677450996998232, 0.05080488808744121, 0.0608458567148773, 0.03112947706540581, 0.04989829903934151, 0.038439089912571944, 0.06131475674919784, 0.045017624215688556, 0.03837768090306781, 0.011632340119831497, 0.021253766171867028, 0.1514586852863431, 0.01360414114969899, 0.00773614506215381, 0.03443220863118768, 0.07074058885336854, 0.027329922158969566, 0.014386819366336567, 0.03530393158143852, 0.026535612632869743, 0.06641342260991223, 0.05606720864307135, 0.0378630719933426, 0.035026524201384746, 0.050634832368814386, 0.02237492495623883, 0.036213800922269, 0.02281437842611922, 0.11541921485331841, 0.04088252208021004, 0.03959858062444255, 0.0752340407052543, 0.04105393592908513, 0.029308248522283975, 0.025507413411105517, 0.04948982095811516, 0.015506330582866212, 0.02225004747742787, 0.02450520420097746, 0.0278092920416384, 0.05503624677658081, 0.08802180178463459, 0.059260773996356875, 0.030449768128164578, 0.0303578271632432, 0.041682297523948364, 0.038761638425057754, 0.05663591640768573, 0.03567191066395026, 0.01627765486773569, 0.06959585574804805, 0.035836767638102174, 0.03847854248306248, 0.013934627859271131, 0.016029625403461978, 0.026625917162164114, 0.03185937188391108, 0.06116945907706395, 0.013632017144118436, 0.02595117319287965, 0.0272613940978772, 0.06439594610128552, 0.05000638171622995, 0.04923132721160073, 0.06694856303511187, 0.022667897028441075, 0.07194923571660183, 0.019769146128965076, 0.07045700680464506, 0.04334703495260328, 0.04932107141939923, 0.05477033897477668, 0.07437562075210735, 0.049326548469252884, 0.028075361260562204, 0.05484835353854578, 0.034805327086360194, 0.0018902641636486806, 0.04086931927304249, 0.015932823371258564, 0.0516440233332105, 0.014112097633187659, 0.03165532951243222, 0.03020475178345805, 0.017624179781705607, 0.05825876331073232, 0.027879104018211365, 0.03462755303189624, 0.013861350980732823, 0.10169472239795141, 0.047089615181903355, 0.014337880293169292, 0.07065517507726327, 0.02560475535574369, 0.09448983400943689, 0.023822346702218056, 0.038113097834866494, 0.057087027162197046, 0.03371237362443935, 0.0550491304602474, 0.021009080082876608, 0.05725946517486591, 0.036601903339033015, 0.08785898200585507, 0.06161609468108509, 0.03702117595821619, 0.0189879503523116, 0.06639199680648744, 0.049345254301442765, 0.024912839944590814, 0.042269098848919384, 0.01320530171142309, 0.07930553707410581, 0.02613589560496621, 0.05157004976354074, 0.032391703280154616, 0.013674617348442553, 0.04392213260871358, 0.03495465462037828, 0.04037670019897632, 0.006338297389447689, 0.08794986541033722, 0.08449179862509482, 0.03729221200046595, 0.010628181844367646, 0.09132683771895245, 0.048526747050345875, 0.027300637011649087, 0.021681638427253347, 0.04604807028954383, 0.0450966481002979, 0.04486964739044197, 0.03528134060616139, 0.06929347509867512, 0.04636189856682904, 0.01779587379132863, 0.06773877961677499, 0.020818296179641038, 0.019202768708055373, 0.05311790264386218, 0.04260509507730603, 0.0537604541023029, 0.024861151214281563, 0.047004535372252576, 0.09250447765225545, 0.035512256145011634, 0.05616649686999153, 0.03472550910373684, 0.04785002340213396, 0.040334138029720634, 0.05426698102382943, 0.03751636286324356, 0.031055681611178443, 0.010378941751696402, 0.07516030091210268, 0.04201092793664429, 0.015631401947757695, 0.06395808639354073, 0.01619856418983545, 0.06198814073286485, 0.007494423853131593, 0.02429939737339737, 0.040620124636916444, 0.03947913195588626, 0.039635346620343626, 0.05221005936618894, 0.0215141765147564, 0.03896816699125338, 0.040139602569979616, 0.030061368852329906, 0.08353427227120847, 0.05579007585765794, 0.016535864742763806, 0.022283735415840056, 0.03165348156471737, 0.05072109219327103, 0.04810173391888384, 0.01839619333622977, 0.07150109726353548, 0.03040912441065302, 0.023807453653716948, 0.020271795328881126, 0.049042996106436476, 0.06368010013829917, 0.06569981051143259, 0.047038707562023774, 0.011871513906953624, 0.07444608767400496, 0.013506709219655022, 0.061047171693644486, 0.04788949081557803, 0.01838761967519531, 0.021953004725219216, 0.06966267872485332, 0.04706258616351988, 0.0472119508049218, 0.0489552148792427, 0.04857229636400007, 0.08817705165711232, 0.032500401939614676, 0.0553911789029371, 0.05713373051548842, 0.019643908708530944, 0.030253778058977332, 0.016303969568980392, 0.10025192794273607, 0.013018548597756308, 0.049627051485003904, 0.024831652699504048, 0.09647955419495702, 0.027190745349798817, 0.037795907628606074, 0.07628188643138856, 0.03595059453800786, 0.004868511023232713, 0.10479581615072675, 0.028989403326704632, 0.03047358179173898, 0.010382738764747046, 0.03893630659149494, 0.03648015030194074, 0.06726346371578984, 0.04416910080180969, 0.005845965433763922, 0.08176479183021002, 0.05676613734976854, 0.03041107254830422, 0.040189281935454346, 0.014711903240822721, 0.007978780504345195, 0.05412491169408895, 0.028154284955235198, 0.002893837186093151, 0.0609755062032491, 0.05171403012354858, 0.0232229158791597, 0.0077092422088753665, 0.06574009428732097, 0.012423641164787114, 0.012044847135257442, 0.04578924999805167, 0.03607617334637325, 0.062130377045832574, 0.022724344780726824, 0.07624388104886748, 0.21048010181402788, 0.14570187544450164, 0.12354064820101485, 0.13285952940350398, 0.15391863766126335, 0.12183578655822203, 0.1822811469901353, 0.1565032560029067, 0.09254122138372622, 0.17192789004184306, 0.20206105982651934, 0.15788109769346192, 0.15052213944727555, 0.08479210868244991, 0.1316957379458472, 0.13611504924483597, 0.11890987676451914, 0.09176663443213329, 0.1422551041468978, 0.14905417134286836, 0.17146308295195922, 0.18100104614859447, 0.10055280203232542, 0.12423406646121293, 0.14948764495784417, 0.18324675533222035, 0.1253665392869152, 0.07940687733935192, 0.17637768876738846, 0.2201812039129436, 0.1587458184803836, 0.12105690999305807, 0.12786343577317894, 0.09664152792538516, 0.18565039354143664, 0.13550142670283094, 0.2129312523175031, 0.19592826312873513, 0.1710286593879573, 0.19208384910598397, 0.16369408811442554, 0.13564034190494567, 0.10970060335239395, 0.18008505780017003, 0.11520510524860583, 0.1895033719483763, 0.16364181123208255, 0.13093082117848098, 0.1013344171224162, 0.14232039829948917, 0.166240663966164, 0.15446181554580107, 0.16590626706602052, 0.20092978928005323, 0.16677146282745525, 0.09654515262809582, 0.1954493997618556, 0.10293545972672291, 0.15419119881698862, 0.11194522900041193, 0.2057696459814906, 0.10303515984560363, 0.1959168934263289, 0.1706957764690742, 0.12504683691076934, 0.1361135797924362, 0.17379998724209145, 0.29918499116320163, 0.08477415613015182, 0.14181993843521923, 0.17387084750225767, 0.21985857747495174, 0.16302553180139512, 0.1293996220920235, 0.11174346873303875, 0.2571916929446161, 0.16322349227266386, 0.11797302664490417, 0.07736967454547994, 0.2857561258133501, 0.13511178432963789, 0.1318227787851356, 0.11142845673020929, 0.1300038638873957, 0.1615205453708768, 0.16396991471992806, 0.14796517352806404, 0.12076115672243759, 0.13523904781322926, 0.15411147731356323, 0.1950421536457725, 0.09829235379584134, 0.1820931164547801, 0.13236236467491835, 0.08608708216343075, 0.12167629160103388, 0.1276142819551751, 0.16905191936530173, 0.10249208586174063, 0.10572926723398268, 0.11416699649998918, 0.19908077287254855, 0.10542644871748053, 0.08985714041045867, 0.2531660464592278, 0.22369120619259775, 0.15020926482975483, 0.114970824070042, 0.10851343424292281, 0.21626778499921784, 0.13711847743252292, 0.09385517158079892, 0.2258842228911817, 0.3688303555827588, 0.2371234557358548, 0.20164936082437634, 0.0935114904132206, 0.08996080359793268, 0.207835532783065, 0.10513865869143046, 0.10402977131889202, 0.19720532116480172, 0.17407663021003827, 0.18394017359241843, 0.16433966753538698, 0.14182730054017156, 0.25231895910110325, 0.10875892185140401, 0.11272283649304882, 0.1505982837988995, 0.16961016284767538, 0.07664061093237251, 0.11855864795506932, 0.08196680442779325, 0.08083282504230738, 0.2024676083237864, 0.19714825000846758, 0.12347680123639293, 0.1446536957519129, 0.12606902659172192, 0.19085451116552576, 0.1281240038224496, 0.16812050918815657, 0.1524461869848892, 0.05653821266605519, 0.08385942943277769, 0.1901222934247926, 0.10010805519414134, 0.1503964641597122, 0.10106827554409392, 0.14251084823627025, 0.23067668604198843, 0.12763768929289654, 0.1401985387201421, 0.1326919227722101, 0.1698718886473216, 0.09854349656961858, 0.0931333439075388, 0.1518341526389122, 0.08799664297839627, 0.12253625522134826, 0.1477212889585644, 0.1318847926449962, 0.1003006350947544, 0.11643664736766368, 0.1793557938071899, 0.18800185876898468, 0.19942036480642855, 0.20901462732581422, 0.1100892957765609, 0.1523903477936983, 0.15261042426573113, 0.1050223047786858, 0.1470911907381378, 0.11324786144541577, 0.16045642434619367], [0.04300598469853867, 0.05511300711077638, 0.11966273363213986, 0.09744954862981103, 0.04497264635574538, 0.00656932564197632, 0.0543698797991965, 0.03709830736625008, 0.028352716690278612, 0.04055235542182345, 0.02882090055209119, 0.027528611790330615, 0.04233706473314669, 0.027783606310549658, 0.06695309013593942, 0.04841864210902713, 0.01723034798487788, 0.045989607606315985, 0.049051738606067374, 0.046462971658911556, 0.041859667107928544, 0.011681376599881332, 0.059277691252646036, 0.12688884744420648, 0.017438726354157552, 0.01870587671874091, 0.0275244539079722, 0.018808808890753426, 0.044728041902999394, 0.07368045844486915, 0.06446266517741606, 0.02980701443448197, 0.03225480300898198, 0.00808390386737301, 0.05235444048594218, 0.06513214917504229, 0.02390977540926542, 0.10788102052174509, 0.008609965971118072, 0.059361691237427294, 0.07180505126598291, 0.03293615394795779, 0.021619049402943347, 0.03219472615455743, 0.05176646285690367, 0.10287832177709788, 0.020586621794791427, 0.015192164628388127, 0.04659431324398611, 0.023411345318891108, 0.01993646888877265, 0.020693140395451337, 0.012983350388822146, 0.06567938660737127, 0.020650520709750708, 0.030540432599082123, 0.05806105516967364, 0.025105243585130665, 0.032286366549669765, 0.027481147735670675, 0.04921984989778139, 0.036521413712762296, 0.05637814996589441, 0.03906511003151536, 0.04869470991252456, 0.00787291592132533, 0.011732364000636153, 0.06593214726308361, 0.016212074988288805, 0.025148262175207492, 0.023377408761007246, 0.06721806654240936, 0.03805965206993278, 0.05476914040627889, 0.057439688316662796, 0.04502785101067275, 0.020151519165665377, 0.007986752098076977, 0.017777208777260967, 0.02831989335390972, 0.011581635662878398, 0.012869795300503029, 0.029453277165885083, 0.05374671694880817, 0.043617740739136934, 0.0034003821974692983, 0.05494269906193949, 0.07100645583705045, 0.052990516705904156, 0.038370073889382184, 0.02276925770274829, 0.03701756169903092, 0.035695640835911036, 0.024512059790140484, 0.03184479610354174, 0.023845793002692517, 0.03899097690009512, 0.03437701510847546, 0.03341022675158456, 0.029917815227236133, 0.006709182907798095, 0.07676248642383143, 0.05431286059319973, 0.029115045217622537, 0.030864406035107095, 0.030115868466964457, 0.08221929791034199, 0.10597414628136903, 0.04724328427982982, 0.009196990868076682, 0.045756257823086344, 0.020058565169165377, 0.0398996513831662, 0.06058364480850287, 0.023309715616051108, 0.014989135288487887, 0.01058475136233028, 0.06569751727511175, 0.03777687896217685, 0.03781978623010218, 0.0389881270530168, 0.07476184924598783, 0.0438862089504255, 0.0795057017239742, 0.0023185456439023255, 0.044315018167253584, 0.04347011272329837, 0.04670841844927054, 0.047955048430594616, 0.017477835681347642, 0.0457571966398973, 0.10453274706378579, 0.025891754994518124, 0.022569592147192452, 0.020196239129290916, 0.03564773149264511, 0.06675644326605834, 0.06206389545695856, 0.027053455451095942, 0.05299991600622889, 0.02839604698237963, 0.05374272419430781, 0.04318718747526873, 0.03389102341316175, 0.043003205355489627, 0.036525506657199, 0.023545770527562127, 0.04380761180073023, 0.03763684682780877, 0.01929080783156678, 0.10011860853410326, 0.018128717747458722, 0.11729902296792716, 0.04701421668869443, 0.1077142970461864, 0.029366176859184634, 0.04181658172456082, 0.048814384936122224, 0.07240351915243082, 0.006423114200515556, 0.03068813482968835, 0.05141166802786756, 0.045622819670825265, 0.013239485961094033, 0.023917334183352068, 0.0231503449685988, 0.029847966143279336, 0.04942625229887199, 0.053697917028330266, 0.01467206846427871, 0.013585880606115097, 0.052416027610888705, 0.037426815324579366, 0.050556647111079656, 0.05068160993687343, 0.03933053172659129, 0.11240699328482151, 0.047051435394678265, 0.08721885737031698, 0.0827658006164711, 0.04037095597595908, 0.06808194128097966, 0.03330157633172348, 0.0483354325115215, 0.0326648804184515, 0.012273102074686904, 0.02436588823911734, 0.011626076393440599, 0.06485443751444109, 0.09248357877368107, 0.009440839257877087, 0.014008512371219695, 0.06334290534141473, 0.020492873700277414, 0.00902678579222993, 0.12010710197500885, 0.006030712429492269, 0.04487935468205251, 0.01242403357537114, 0.06374188393238, 0.09034413029439747, 0.017075202013074886, 0.029880808033340145, 0.08689033827977255, 0.05039096264226828, 0.041175310470862314, 0.08650044357636943, 0.013092254994262476, 0.03896152848028578, 0.060174817917868495, 0.0056333614611503435, 0.010491712946532061, 0.04672448594646994, 0.0424997769005131, 0.04254737083101645, 0.02128830943547655, 0.02044935416051885, 0.022502121646539308, 0.05637133333948441, 0.06134521448984742, 0.04195238361717202, 0.03318112205306534, 0.04138426585996058, 0.015126748949114699, 0.012914594117319211, 0.07432664642692544, 0.17868260649265721, 0.05096835353469942, 0.006408208628272405, 0.006424815574064269, 0.015489184188481886, 0.03701508292579092, 0.04573783771775197, 0.04771964289830066, 0.08442764737992547, 0.02483466396370204, 0.06209075749211479, 0.007411557035084115, 0.10006599768530577, 0.0802840365213342, 0.022941361748962663, 0.011561189494386781, 0.024967454592115246, 0.03575808885216247, 0.02476555331668351, 0.02629064823850058, 0.0736350538500119, 0.032612095164950006, 0.03345269615238067, 0.0366755614959402, 0.06630337695241906, 0.02870645581424469, 0.03137664192763623, 0.004249664225426386, 0.008698965248186141, 0.04507977908360772, 0.007413716684823157, 0.012850005005020648, 0.025921285050571896, 0.034532446807133965, 0.07192167977336794, 0.024974968837341294, 0.07978896464919671, 0.045294263472897, 0.04887488852546085, 0.026595149574859533, 0.04175014837528579, 0.029892699094489217, 0.018286407430423424, 0.06386276494595222, 0.06149514316348359, 0.06229161605006084, 0.05597998031589668, 0.015143922246352304, 0.05328519757313188, 0.027052509212808218, 0.04436389972397592, 0.022759763778594788, 0.05513879674253985, 0.07256072829477489, 0.029913983889855444, 0.027076766309619416, 0.020381976428325288, 0.10501273849513382, 0.03688719974888954, 0.044149619425297715, 0.03024245103006251, 0.057609205978224054, 0.012864077980339061, 0.025704954568936955, 0.04326446731283795, 0.028041311525157653, 0.03559849370503798, 0.06597134008188732, 0.055980922843446024, 0.010740521665866254, 0.045795873666065745, 0.06572606027475558, 0.021659270096279215, 0.08629777046735398, 0.05688889970770106, 0.013291052237036638, 0.07428448501741514, 0.07563606952317059, 0.020233307550370228, 0.02282736786582973, 0.034226296047563665, 0.054015552523196675, 0.021144351339899004, 0.06288749384111725, 0.03381376955076121, 0.016710223062545992, 0.05347248225007206, 0.022517209508805536, 0.01922019619087223, 0.03927843295969069, 0.009796479207579978, 0.04845322990149725, 0.07791177631588653, 0.059861679837922566, 0.04085531865712255, 0.05264267208985984, 0.03558173972123768, 0.048181188249145634, 0.02446521357342135, 0.027492326335050166, 0.03420704473683145, 0.042356534977443516, 0.05305851598677691, 0.07015030685579404, 0.059639369501383044, 0.03968642864492722, 0.045640226744581014, 0.036938348566764034, 0.029407423571683466, 0.08384428219869733, 0.07322225646930747, 0.06730103865265846, 0.02891693075071089, 0.02879572504753014, 0.023224370488605928, 0.0163033925491618, 0.012942619468958583, 0.09229102113749832, 0.025105440254264977, 0.024883118785510305, 0.028750641431543045, 0.048974714809446596, 0.010271256123814965, 0.027823376149171963, 0.037387121556093916, 0.049288932714262046, 0.2714341599494219, 0.21128714288352057, 0.2028140873881057, 0.15668623993406072, 0.15121975826332346, 0.14895726169925183, 0.13351937290281057, 0.1508503023069352, 0.11010823538526893, 0.10825830613612197, 0.1430817972868681, 0.11000378552125767, 0.105617299414007, 0.22560238488949835, 0.11109391140053049, 0.10856959997909144, 0.14206089894287288, 0.12793076341040432, 0.11708064601407386, 0.20676090294728056, 0.09816626290557906, 0.10020562534919009, 0.2483938736259006, 0.1726285961922258, 0.1488483589491807, 0.11603872262639925, 0.12210681146825664, 0.24678932066308334, 0.23449640139006078, 0.07668798221857287, 0.12964790017576888, 0.09669888851931319, 0.1575300024705939, 0.15988810249837115, 0.0876161438645795, 0.1295578182907775, 0.0971684156684205, 0.1667005431954749, 0.10258399343001656, 0.14255380374379456, 0.10441222970257513, 0.12833238404709846, 0.13817363331327215, 0.11959262294112705, 0.13145792414434254, 0.20817659416934475, 0.091493501822697, 0.07684282390982844, 0.3212819038890302, 0.14330815232824534, 0.23729100299533457, 0.1661549459095113, 0.11237631289986894, 0.17169613216537982, 0.1274159355671145, 0.1808362003066577, 0.252567637944594, 0.15793491824297234, 0.11364223872078583, 0.16781510057626292, 0.15517893800279126, 0.13371702167205513, 0.15625888161594048, 0.13046895299339667, 0.11430362588725984, 0.13008404552238062, 0.044930269723408855, 0.16263749246718362, 0.11499116633785889, 0.1494737371103838, 0.18572155066067353, 0.2040566800860688, 0.14246830833144486, 0.15626300795702264, 0.19626215536845848, 0.12803222984075546, 0.08309676879434846, 0.053748075079056434, 0.11338735552271828, 0.16214445407968014, 0.06379746337188408, 0.11900405530468561, 0.14623473747633398, 0.20055736473295838, 0.1296728363377042, 0.07835693875676952, 0.1920925173908472, 0.13768153003184125, 0.1906137733021751, 0.11917458599782549, 0.1007837287033908, 0.14304124633781612, 0.10081722182803787, 0.0874472755822353, 0.22928281396161765, 0.1360669283894822, 0.1371327563538216, 0.09466832052567042, 0.130536250944715, 0.08298291591927409, 0.23563559807371348, 0.22149664582684636, 0.15775374515214935, 0.2211504487786442, 0.10156403019209392, 0.1463178580161184, 0.21069205919047818, 0.3381039574742317, 0.21251633239444345, 0.09549301728839055, 0.14220713172107935, 0.1252726130769588, 0.0707508230698295, 0.18811061308952048, 0.27829415746964514, 0.15850545169087127, 0.1236727653304115, 0.19308880611788481, 0.07627223109011538, 0.1587274725898169, 0.13824827852658927, 0.15766640921356156, 0.1332075966638513, 0.2657383249606937, 0.13256274454761297, 0.15766113996505737, 0.1288721480523236, 0.1040851503785234, 0.12567251193104312, 0.1338190966635011, 0.08396524484851398, 0.25239332229830325, 0.07050060055917129, 0.11470974393887445, 0.1459293140214868, 0.10845554672414437, 0.13851445721229538, 0.07476751925423741, 0.09600601944839582, 0.196599283372052, 0.0895610531733837, 0.13893084658775479, 0.09664809593232349, 0.18514801893616095, 0.12183333004941233, 0.22244291380047798, 0.15473122999537736, 0.14923388982424513, 0.10754495378932916, 0.09776713588507846, 0.24731563695240766, 0.11147983561386354, 0.17390446679200977, 0.18337461253395304, 0.15517660765908659, 0.17370390880387276, 0.13875847536837682, 0.12273227868718095, 0.08763638965319842, 0.12770944013027474, 0.20320516952779144, 0.15046871965751052, 0.15382871904876083, 0.06644856330240145, 0.11838909689686261, 0.11045731196645647, 0.10733209099271335, 0.21375279495259747, 0.09373478780617006, 0.16513948008650914, 0.1252440403914079, 0.10752907182904892, 0.12079772233846597, 0.18947554141050205, 0.12147399698733352, 0.11129852151498199], [0.018312868705834262, 0.033644084905972704, 0.037679650195059367, 0.07452162346453406, 0.0968692559399642, 0.03885316749801859, 0.03791214279772248, 0.01243784401594894, 0.03258895128965378, 0.03177155726007186, 0.024871185050869826, 0.024996144165925216, 0.06187905244587455, 0.04188301507383585, 0.013153186246199766, 0.02052559684670996, 0.0411056858865777, 0.08431871494394727, 0.05738606443628669, 0.04580285356496461, 0.048788383792270906, 0.02936152544862125, 0.01134577092670952, 0.028920596960233524, 0.031600243601133116, 0.0573179612547392, 0.05861154320882633, 0.06776416848879308, 0.06359512422932312, 0.028664329656749032, 0.043178333653486334, 0.03692765050800517, 0.048036113221314736, 0.040940769540611655, 0.019398580661800224, 0.039970207362785004, 0.024971974271466024, 0.0786676982534118, 0.04317711282055825, 0.01413602632965194, 0.06554151783348061, 0.04593868514348287, 0.06751618726411834, 0.045863420236855745, 0.03834771297988482, 0.07358204966294579, 0.047475613610004075, 0.020955062864231877, 0.0917415572621394, 0.05792746858787723, 0.022831633359601256, 0.016169488699233625, 0.026924605626845732, 0.031156049662968144, 0.11124003285658546, 0.059369643349782564, 0.02291513796080835, 0.07259626232553273, 0.05109108620672487, 0.03252038797654677, 0.05323140670952853, 0.040919930033851415, 0.05406676442362368, 0.015969522573868744, 0.02607869086205028, 0.06516159759485163, 0.038380207915906794, 0.00595729825363378, 0.002435453848192992, 0.041019092095666565, 0.028044805185345467, 0.010739388035290176, 0.039667581804678775, 0.031286563753383234, 0.03868224717734847, 0.02583181358204456, 0.02657926204847172, 0.030876434393576346, 0.06248556892387569, 0.03650081540399697, 0.012765917817887384, 0.012934025398863014, 0.03521618004015181, 0.07834403280867264, 0.01573978519445518, 0.06035998747393023, 0.039518751509604044, 0.057842589158099145, 0.05015452923544217, 0.023744048266962636, 0.026282445651304442, 0.030159968737279996, 0.027511822554515675, 0.038591040938626975, 0.06487472783192061, 0.01480943907154142, 0.021468797895067837, 0.04009037591458764, 0.014849826748104533, 0.03353610241902061, 0.035213348746765405, 0.044238246700842865, 0.024283335442305543, 0.031091577438928653, 0.017121552846219856, 0.047187790187308565, 0.0989916424441617, 0.06555029744049534, 0.05623922734230291, 0.05858923424966633, 0.049358382893842645, 0.020734670979436487, 0.0026492308779779705, 0.033200065372511744, 0.020336274974397384, 0.013245910176920006, 0.006363958073052345, 0.035329713791725226, 0.04363075800938532, 0.042407865621498786, 0.031413749311468564, 0.012400770028762054, 0.02903227534261532, 0.13919298799009994, 0.039061696152202785, 0.03249625333410222, 0.03525413718307391, 0.0584671175602125, 0.02908065409428673, 0.047580297250533476, 0.08194846595870331, 0.011017543129128171, 0.008792566768534016, 0.05778896898846142, 0.01388103366480209, 0.027943789609707892, 0.043023584730690345, 0.027492437657201663, 0.00763348609325476, 0.032987625600071624, 0.021088016765133943, 0.008613577447249554, 0.057174945686711, 0.06075401965063065, 0.04329630173742771, 0.043122850693180226, 0.047975234847399406, 0.04113668910576962, 0.025631326097936835, 0.14867297461023554, 0.03181687279720791, 0.04951284237904474, 0.10842289222637191, 0.04100680584087968, 0.017554338119225577, 0.009121487546508433, 0.02794446310872445, 0.0674064236227423, 0.04297404637327418, 0.03717541279911529, 0.03180565152433701, 0.035237231058999896, 0.015912800226942636, 0.02496935263479827, 0.04349545335571747, 0.05162232664588373, 0.019175997585989535, 0.03853322021313943, 0.04752159336931072, 0.06150931818410754, 0.04263590162736364, 0.019901849555026274, 0.05212017415033188, 0.0779783543839585, 0.004632133277482353, 0.01991582234040834, 0.052243812242522836, 0.032829800475155935, 0.04110952650080435, 0.023278695698536467, 0.03807490320468787, 0.020433564968698192, 0.014632295842602616, 0.03766683701542206, 0.010315063245798228, 0.030822129592706915, 0.04208733203995507, 0.039708696785965, 0.09797094448003918, 0.02807180080708349, 0.02201025028625736, 0.06004008842865005, 0.0833086742204614, 0.02819496763549978, 0.05561076926824171, 0.05074611741292756, 0.035250942237325944, 0.015610514201398473, 0.03392807142517995, 0.08319684740854427, 0.015883476116869133, 0.05365234916098416, 0.01446908550860826, 0.0033269761388510233, 0.017970621738641057, 0.08127069217152894, 0.029667473972949665, 0.0433461889042519, 0.045836647259420715, 0.047756746571394615, 0.01199012858705828, 0.06141153280623257, 0.023546562770206947, 0.04891783290077001, 0.03797308796492871, 0.02342415478779003, 0.023721243924228474, 0.024563585247960873, 0.013828764203935862, 0.02934905180154601, 0.009681830379122403, 0.0775186755345203, 0.0650870191748254, 0.01969314649613807, 0.04862435060204007, 0.025338650884805247, 0.02126874271198176, 0.014706630281580146, 0.0400012365571456, 0.012921399611514062, 0.06613626013859175, 0.03855279806884937, 0.059602807596093044, 0.05462556080601644, 0.018589840074128006, 0.019880152867699508, 0.02684531642444199, 0.0387567588040838, 0.03423884576477576, 0.03622605749114882, 0.02549994555010926, 0.04459277435671538, 0.017831131372076925, 0.03429739379498642, 0.04578031454002485, 0.04738026989798527, 0.026259431651851628, 0.0804475910263136, 0.03858134848996997, 0.0519481591618387, 0.023141524543461856, 0.017953197966562584, 0.046469958979287185, 0.010784851074276958, 0.08718506738659926, 0.04436623377841897, 0.031534118243143894, 0.03388973949768115, 0.019846906507154927, 0.040757225287961774, 0.010483050227776403, 0.020988210890209302, 0.015467156317754416, 0.04801655020855833, 0.039362017341773026, 0.04175097215920687, 0.03697264321090188, 0.03956225249567069, 0.03409158882277552, 0.023882160094217397, 0.07854133276850916, 0.012582161125465063, 0.01856232494901633, 0.019645587817649357, 0.021689998720830772, 0.00472469625492522, 0.03963159877457656, 0.05549750268983189, 0.044324235641397536, 0.08461486897431314, 0.06674514777841978, 0.03127641488390509, 0.03463114131591283, 0.002889552442866261, 0.013397394577623345, 0.09619217977160588, 0.04553159116767347, 0.03929045575205237, 0.027215679656364955, 0.038981536781648174, 0.08419996389420703, 0.043189684802200645, 0.02442984467052156, 0.005174428470127168, 0.031088378782442305, 0.08870357574778609, 0.03883459896314889, 0.026569708752504084, 0.01854164685937576, 0.05253530187474098, 0.02975502884510206, 0.03726042581547517, 0.08514798333635554, 0.03337327150802594, 0.04912728923955001, 0.018343142764933873, 0.043815998069476336, 0.04515963046287652, 0.04483524513489101, 0.03755941113922745, 0.021452971595863346, 0.010496022969164187, 0.043505605935934, 0.006384954822351574, 0.03569784872524906, 0.025729326698638033, 0.062201560140238144, 0.021837198146386072, 0.078132372291293, 0.05244323474471457, 0.010924574289674638, 0.04152450950641651, 0.032770287652965635, 0.07723793591139838, 0.05789127775642555, 0.027146710017404985, 0.053138152143219486, 0.040981164638651535, 0.013155785618437221, 0.02421513021545252, 0.06944833163288422, 0.03192851036146749, 0.0490513786644442, 0.03921504241588991, 0.004469350142244366, 0.03715970895427745, 0.023334124853136018, 0.04815033345948905, 0.02315985744644422, 0.03841859179374296, 0.01386450974678155, 0.05421398425824009, 0.041858208787743933, 0.03287350555183366, 0.007752327128400793, 0.02920530521805631, 0.04953549643687438, 0.0008604792969890696, 0.05229819311352912, 0.08563967843656428, 0.02270385779411299, 0.0652853210340254, 0.14486283296719193, 0.10151694834348746, 0.1429203653242439, 0.16158827376784757, 0.1788541316636838, 0.1547404919983819, 0.14006418030476198, 0.15739500580821186, 0.11340116689098068, 0.09983117473893799, 0.17162307514809072, 0.07790375369950198, 0.18048967671347782, 0.11269558483036235, 0.06616288839722984, 0.1315993329626508, 0.18744984932709485, 0.18290432839421555, 0.14196719537721947, 0.1139429495378863, 0.11171120757353492, 0.07696518921875395, 0.12407923219143413, 0.14357973384903744, 0.14129503222648054, 0.10886174641200341, 0.10440819984069094, 0.12624392111320049, 0.2441925904713571, 0.17883274296764284, 0.1393922694842331, 0.1482952808146365, 0.19476695044431835, 0.10420714461361058, 0.1525670976843685, 0.1416723697911948, 0.10935635073110461, 0.2463320389506407, 0.13413210486760363, 0.08004969597095624, 0.12246747297467664, 0.16241388337220997, 0.16394851118093356, 0.12735129450447857, 0.16908510820940137, 0.20341044757515192, 0.16541066084755585, 0.06366523492033593, 0.2751689439173788, 0.11272550822468475, 0.09037455834913999, 0.09785836809896864, 0.0815978753962554, 0.14257669157814234, 0.1766723659238778, 0.10966995265334845, 0.15375358401797712, 0.16764424333814532, 0.11716184439137578, 0.1598302595084533, 0.1133133411349263, 0.0703760607575532, 0.15124660916626453, 0.1204382927971892, 0.10463737504323944, 0.16240891098277643, 0.11511943172081374, 0.05236948753008619, 0.05741872635553591, 0.22350981045747176, 0.070023985899752, 0.15010304865427315, 0.1284153710003011, 0.16277542803436518, 0.12980247469386086, 0.08140205973177217, 0.13639941054861993, 0.12824777921196073, 0.1773603368201293, 0.125801126123406, 0.09571664122631773, 0.10764449805719778, 0.1561739353928715, 0.20143596368143335, 0.09317015443230048, 0.08973233343567699, 0.16203151404624805, 0.15875310637056828, 0.10936204300378449, 0.09072879285668023, 0.09277043369365856, 0.07386330878944136, 0.09471872719586827, 0.14418278820812702, 0.09747888572746888, 0.09042952180607244, 0.0838690105592832, 0.12500799290137365, 0.07699772497289814, 0.10924961505224928, 0.13835305493557826, 0.1530152658233419, 0.10683578715543263, 0.13981873722514138, 0.1812213155790232, 0.1691350547480397, 0.20322599419159815, 0.15249414456775412, 0.14199336350429803, 0.12177668191725388, 0.11251795920543373, 0.10965063454932533, 0.12211547975311987, 0.15436210058396682, 0.16795397124951705, 0.24520792270777747, 0.13034496980253607, 0.19148564839269966, 0.10404836211819202, 0.16718426020815969, 0.08451093119219877, 0.1302550660329871, 0.15062517923070118, 0.17994569730944932, 0.13679300114745274, 0.23627921822480857, 0.1937038981122896, 0.2156924275914207, 0.10841025345143862, 0.10776349401567131, 0.26218771236017346, 0.11293997406028211, 0.16258560150163248, 0.1282658430864103, 0.08783259865595028, 0.10812452659592964, 0.17068566841771826, 0.1043801021296531, 0.1978724673972465, 0.09449683988350444, 0.13833470904501155, 0.159328730951529, 0.17405530088581145, 0.23211755091324449, 0.2027643338078633, 0.20962922950275242, 0.22007185587426648, 0.17752715677488595, 0.11230451753363013, 0.2345987138687633, 0.17783189745387062, 0.12170925037935376, 0.1756114955060184, 0.0767597478989046, 0.13683723314898089, 0.1067488371336367, 0.19509057136019692, 0.152035066857934, 0.09287892084103078, 0.13610344205517322, 0.0948328769300133, 0.19655188982142136, 0.0744446627504658, 0.11838319682283327, 0.21845568087883294, 0.12096902486518957, 0.13221083296230063, 0.09092145439353772, 0.13009774556849152, 0.25288123986683786, 0.10609070799546316, 0.15464181604329497, 0.1082104079250712, 0.10911412115092389, 0.17137607355834916, 0.11117925096186809], [0.019943988700106274, 0.07372748092166148, 0.05191058793570846, 0.018934641884698067, 0.02646077631652588, 0.04394279028929304, 0.02083295174088562, 0.01083890540030552, 0.051823582252836786, 0.02826938834914472, 0.06479911040514708, 0.03668264158477541, 0.014084544473007554, 0.03146188872051425, 0.06862394657218829, 0.05032244385802187, 0.00755794751967187, 0.06430555251426995, 0.05658106798364315, 0.012708719568763627, 0.0167126999804168, 0.04331822849053424, 0.035818258475046605, 0.019170279338140972, 0.01794028274161974, 0.003511189484015631, 0.012170771042292472, 0.027022519025194924, 0.032386218808824196, 0.022854960916447453, 0.044187903113197535, 0.03628824204497505, 0.00971020175711601, 0.03932857987820171, 0.060116062086308375, 0.07227160240290686, 0.014513007663481403, 0.031175872427411377, 0.0040509407335775904, 0.04005666014563758, 0.08542208073777147, 0.011697080444719177, 0.03890331441652961, 0.04537372893537395, 0.04551050304144155, 0.033755722470232286, 0.05248637207841966, 0.03313935398182366, 0.031056002590048593, 0.050792772526619956, 0.034442316682543606, 0.04955322263413109, 0.038355353390215896, 0.055828055265010335, 0.018118004845746327, 0.03838606346107554, 0.011607576507230988, 0.030864292857586406, 0.02149378415197134, 0.045707899480476044, 0.02947163604403613, 0.06154962051368784, 0.06149130254925694, 0.03840183409920428, 0.02892001994041493, 0.046414646712946706, 0.014471207123278873, 0.021755376365035772, 0.016927564720390365, 0.07953949170769192, 0.01787497560144402, 0.02770874030829873, 0.020712682999146637, 0.00843091913338867, 0.03659071917354595, 0.05418964552518446, 0.035672300291480497, 0.048492352216271684, 0.0253447253635386, 0.04235945161781274, 0.03409908080357127, 0.06525010612676851, 0.047609719695174135, 0.02206362554716179, 0.09641116528655402, 0.06237498149857856, 0.024006304702197667, 0.0304149280054844, 0.053671303612645715, 0.034342831786489114, 0.02353025778575102, 0.04622105749149341, 0.147550298133865, 0.047774190752534196, 0.029805530139128678, 0.04601925269525964, 0.008044319565669866, 0.032015137549024075, 0.057935773220378906, 0.02259578810480889, 0.02502745352103375, 0.008083198827080196, 0.010196654511673842, 0.010301118290954037, 0.050088838033843786, 0.030928130545362365, 0.04644922708394006, 0.011393341665097978, 0.02921195115050068, 0.019174069857399445, 0.010562941497482825, 0.030606018044636585, 0.10756998643046245, 0.09953100568964146, 0.071566228143638, 0.051773075392702594, 0.04417867450683843, 0.023394951276713982, 0.03481496016320307, 0.045274622534634545, 0.024337020549864974, 0.02219498568592826, 0.050311077866354026, 0.021653518451785203, 0.0673405580164399, 0.042212754997308366, 0.039406382929882966, 0.04326519832829945, 0.023800601775292307, 0.07554247727966867, 0.10488372354302555, 0.037822806771146134, 0.07730320037808269, 0.016678000865795184, 0.09066179176443256, 0.03292073211923707, 0.06646454916335642, 0.010885229330597213, 0.01742820084473351, 0.08849607867887244, 0.023891438795544673, 0.1157866299035959, 0.11997558598523028, 0.04657953708374407, 0.03913796666893177, 0.04621066742402036, 0.020746925692947116, 0.02965886320453137, 0.020712232144433074, 0.02773132386209909, 0.014695452609885251, 0.03393486578715965, 0.03474016652035061, 0.06610387281398289, 0.05709463788662106, 0.06635653699049726, 0.030132151186990086, 0.0677059989538975, 0.03528257999278139, 0.03375270192918833, 0.021510706974368077, 0.04400722355057951, 0.06663483494776301, 0.08132597475196235, 0.052755114884348586, 0.012459780045901425, 0.04794508138729725, 0.03926240256987512, 0.010479305165063124, 0.06270015350310132, 0.05899630967178382, 0.05165630216652062, 0.01760576338710962, 0.012545820936793461, 0.04640911029127892, 0.06450347587815486, 0.03199051679985132, 0.06428492823033594, 0.09572090115398169, 0.03995365746959578, 0.04668342662625946, 0.09922582714352757, 0.03232172988646198, 0.0504384749365272, 0.03451379292528145, 0.07771655436954461, 0.011402526670281077, 0.030318506323965266, 0.020878334071312565, 0.09231086616637185, 0.04567501862766221, 0.04418165051902179, 0.09908395819365978, 0.023018606334517244, 0.03892246553732548, 0.025832301544141956, 0.048427020956296474, 0.020181848885840736, 0.03269398002885282, 0.03963171751820482, 0.02356111628614599, 0.07390850558294915, 0.048200651071965694, 0.002261859244754305, 0.08873301674611866, 0.0481885874614818, 0.06336807156912982, 0.026094667446159292, 0.04503533185925335, 0.03866671402647626, 0.02289566029503476, 0.05632593616610393, 0.02721093547734199, 0.016683863832440693, 0.033997655191342346, 0.009993076910177479, 0.05005148574127816, 0.021741238451795653, 0.006459523501689546, 0.07185118316556327, 0.01723290653899312, 0.06157040064863395, 0.02780676688416861, 0.025243114214390516, 0.03860406934109051, 0.05412654812971596, 0.025778846502362285, 0.016382286557927728, 0.019356549128133338, 0.04245083226123825, 0.040658374928170815, 0.028336255854810588, 0.014498579384962795, 0.029052582358417567, 0.0025621825216148864, 0.0645195582183078, 0.09465290611842647, 0.05338827446394134, 0.031059665088832844, 0.07659224516828544, 0.04081993676663842, 0.03716175357112661, 0.11583529252675362, 0.042795032932190225, 0.02169635521568125, 0.06927207155968063, 0.09126218181336299, 0.014132580909063108, 0.024187891540350392, 0.013648228432430187, 0.07572923132102005, 0.07362631877185777, 0.02464529941789806, 0.04605792972142808, 0.03381977352546528, 0.0458551972405985, 0.09561937535181642, 0.025233150881831534, 0.016305060526065063, 0.023850173529353924, 0.049844196473713964, 0.04668429864977952, 0.03812095717876218, 0.0385684388311347, 0.020884705409116577, 0.04536014763289131, 0.051761909780907445, 0.039022792770992965, 0.05484618275659159, 0.058285072445869446, 0.05101181741338223, 0.0327188382652821, 0.012434301188477548, 0.010912541292782407, 0.025324646558146924, 0.018562675613793544, 0.02104916904499987, 0.07569379376946017, 0.017718751660140697, 0.02692247937375214, 0.04215440363623202, 0.042066978639923036, 0.039441096887458116, 0.04171136373770423, 0.07560567857581191, 0.031446927023353055, 0.019640659957076423, 0.007910392523626797, 0.11713146828697063, 0.013695580237254035, 0.12605618743691593, 0.07443877751938999, 0.020122475216339808, 0.06959058649954386, 0.017184871030622162, 0.08150385270710103, 0.0360012906457996, 0.03143716407066677, 0.041118918379652314, 0.04871387216553558, 0.041410471094422974, 0.03802500861638691, 0.039310374995693564, 0.04577632549626287, 0.10184592756559141, 0.06539212350617163, 0.04580738066579215, 0.062198164814617485, 0.014563120257662376, 0.03430958357057534, 0.03984433540608734, 0.023093976997188292, 0.014128026905382285, 0.021984000522934366, 0.08535374377970584, 0.04069887021614704, 0.04146022467466537, 0.09599472396075726, 0.10930378441116773, 0.07681536444579251, 0.06516999870655127, 0.027223726392548997, 0.0265185803436907, 0.0391398851206759, 0.0654079312516842, 0.03689261371619068, 0.01941630500368774, 0.036430764084798284, 0.041339473536936566, 0.01879234434454702, 0.07415728090563789, 0.01001728020128212, 0.04701724094047677, 0.09128673205850646, 0.07996618951437995, 0.01138035871917964, 0.035446798719931394, 0.03919820679584518, 0.011629028285824461, 0.08183689147699624, 0.07355844194535166, 0.01599327315489063, 0.01019227955112001, 0.008522169900970766, 0.022436384060711134, 0.05246588509180583, 0.07385231016087346, 0.02939507980045164, 0.056093020539265126, 0.02283478377648862, 0.06447434658184648, 0.009899121014314005, 0.16230593057116494, 0.23222317337058485, 0.1823940424947068, 0.12047744108713232, 0.15054617018904537, 0.2539736812468618, 0.08609860771684907, 0.11294241572613828, 0.12820771808037534, 0.21101441845530644, 0.17610549868550152, 0.12101125306799076, 0.07664557590032928, 0.17674094036919996, 0.14944136462872848, 0.1396863380796276, 0.2878661110298708, 0.08778021787293255, 0.14397648599697277, 0.07515756238717586, 0.18727666174527258, 0.17216378910234198, 0.11836431658593938, 0.08093892989563756, 0.10935796119156294, 0.1956708714715205, 0.13743852119660005, 0.08475316077237949, 0.21702956990338862, 0.09928456813213415, 0.09610120730940253, 0.08109951580991037, 0.11080635886173695, 0.05910402127483394, 0.10409404130768962, 0.2789825142826885, 0.15847500879317522, 0.14024805481312796, 0.16244913538685068, 0.17972901987377554, 0.2108147065155208, 0.1158334148931317, 0.1387750104186125, 0.10537282112636603, 0.23882043577032164, 0.2481404598802328, 0.1126356638269499, 0.11573644587770104, 0.09857490425929427, 0.17266193346586078, 0.11084588564699516, 0.22038719442207366, 0.2600397588685155, 0.12164276879047975, 0.14497114199912176, 0.24011990666622296, 0.11384616605937481, 0.15156849345657974, 0.12601352878846228, 0.14432338066399097, 0.20825956627959386, 0.20321351126767695, 0.1468484045471996, 0.11965207639150321, 0.2388759038876742, 0.09430955149582587, 0.19105781510006636, 0.13501478562830016, 0.1315548486309126, 0.21582896792097017, 0.1570664273458533, 0.11107687168987468, 0.10776631417684257, 0.09270587426726706, 0.1070910414273385, 0.13596958830021322, 0.14408013434149325, 0.13006895023863763, 0.1442480378318578, 0.15235894010402262, 0.1738501267391257, 0.15198151348158717, 0.1429101830581203, 0.11208863419597037, 0.15818810934433714, 0.22157599625643343, 0.08507420643582009, 0.11147805445943959, 0.12764104380039498, 0.2551612659590319, 0.0892200437374413, 0.13400739437201992, 0.25323818321339786, 0.15088404034031555, 0.13267215195810422, 0.18745615758234635, 0.19012161064893007, 0.12064899594406597, 0.11704819931765087, 0.08185914106434211, 0.15545875736279413, 0.13034453935688362, 0.09798073340789415, 0.0953710156318266, 0.06480956726591103, 0.13461582188028842, 0.09717763314256445, 0.07277647062437609, 0.24482870008796453, 0.13418355054454878, 0.09796917816856876, 0.10765275073936209, 0.30756648047827184, 0.20202533283736557, 0.21533554361667484, 0.2058904676232487, 0.09686365272500552, 0.11806063717813231, 0.12511299195466563, 0.15136919711949304, 0.12216305884066969, 0.060171422592247836, 0.14118512015556917, 0.14310912316432223, 0.1374587372993119, 0.14649539458332583, 0.17768468504073098, 0.1964705652790144, 0.18338319176109508, 0.18618585309013724, 0.16090208402602002, 0.12191939691547304, 0.12737038254272193, 0.09081992859137245, 0.20307550148572773, 0.14508111344184726, 0.1920154973049648, 0.07887786705396138, 0.1336271475884132, 0.20984770293580368, 0.1479169784579426, 0.15922126796795055, 0.2033283660421148, 0.13977768161566928, 0.13963291828986257, 0.11808287934400141, 0.11519067047629505, 0.11642731114989147, 0.11738839981262572, 0.11956935661146417, 0.0781396304955706, 0.1325730752432719, 0.13247052527731284, 0.24646725825732574, 0.14755342999706045, 0.17094650364015251, 0.1648287131683901, 0.23449625296052545, 0.13625904073705897, 0.1744502125075087, 0.09521881598629989, 0.23645003093406558, 0.12868613615864888, 0.22486025205580518, 0.11212363388040103, 0.09137479530181736, 0.08960534454672597, 0.10150710004381835, 0.0923993598553352, 0.19265914714196697, 0.13372131128562614, 0.16021893708966672, 0.10903041431447491, 0.0989690440474078, 0.08455247661913745, 0.11744863993953913], [0.07206409049103968, 0.07165301489294507, 0.03381951377377845, 0.01575579517520964, 0.04736809496534988, 0.05290573746606242, 0.043289422028465196, 0.021630979426845443, 0.06007977848639712, 0.06325549518805929, 0.07005777588346973, 0.03327817270474043, 0.03765097360883374, 0.018142434491892345, 0.015231342604238307, 0.01553304882691009, 0.004353691529104253, 0.03308688785182312, 0.06538619374623522, 0.033161551618832164, 0.017690522217890248, 0.05156883635208942, 0.027841885312227532, 0.050185372892883606, 0.034805007962859236, 0.10220462980214506, 0.0179730021773139, 0.015663382946513593, 0.028166205702291336, 0.04334006989665795, 0.02688784519705223, 0.02763376855000388, 0.03627362544648349, 0.04234609667037148, 0.05463477085868362, 0.06038684950908646, 0.023633985911146738, 0.06806014440371655, 0.02169627172406763, 0.06812361287302338, 0.032998334791045636, 0.019582457025535405, 0.06519618167658336, 0.020738814018841367, 0.024738169922784436, 0.03125139708572533, 0.08684985412401147, 0.038935360353207216, 0.02067062734568026, 0.09144017851212993, 0.05017918338126037, 0.018623151372594293, 0.06460776246967725, 0.015874707642069552, 0.04910675030259881, 0.026099608294316567, 0.061560285175801255, 0.12413178366841748, 0.04817872802959755, 0.029397365615295712, 0.004997910036763642, 0.044032014993717894, 0.03737829742021859, 0.004526886068560998, 0.0774690110119991, 0.041169414107571356, 0.07451812794897705, 0.03185461842804216, 0.02655721655173693, 0.06134779716376215, 0.015353878607129445, 0.052604047014028765, 0.06207976257428527, 0.060411414597183466, 0.04259118351910729, 0.02449380852340255, 0.03471461066510528, 0.014359891465574037, 0.041553230621502735, 0.11939834352233447, 0.02829414082953008, 0.06966480126720853, 0.05874045426025987, 0.007595138395117829, 0.023163659097917844, 0.029867877965443768, 0.03882299177348614, 0.0126271473345696, 0.034088323372998275, 0.03680398644064553, 0.08698762641870417, 0.0343680648074951, 0.05498918348166626, 0.027360708299966063, 0.04090747679583728, 0.045273813593667, 0.08199490956030786, 0.05370093756937422, 0.019664165629365016, 0.03868343832436949, 0.03688250566483475, 0.023636093610548414, 0.017304050670645665, 0.028236835896677803, 0.019475029293971602, 0.01768409707437968, 0.025654173114162404, 0.009399725204275455, 0.015508554242842365, 0.030394602435990237, 0.1120603880553972, 0.03918097041605506, 0.006627734983339906, 0.07283331913640723, 0.018473632735549472, 0.04712160545750521, 0.02805468873702921, 0.03548337546817493, 0.020130345692450646, 0.02117101670592092, 0.08024371563806199, 0.019998720235889778, 0.03006194772751769, 0.0476904208335327, 0.06458618823671713, 0.07264914034749381, 0.03996740575530566, 0.011748067845473997, 0.05112418599310331, 0.03986147159594111, 0.031599853973602876, 0.03535015996021684, 0.09832576528424397, 0.07294124225154519, 0.03643018892034888, 0.027469842971186154, 0.0507074440974975, 0.05381768482038751, 0.018724760666373186, 0.04011754965176806, 0.06906202892423607, 0.019645749234769028, 0.06035277008777484, 0.007222174399430514, 0.021375784526753705, 0.053034377633593976, 0.01918993697472615, 0.030453642139036674, 0.036726083199027926, 0.026282757353328634, 0.013160205107851652, 0.0447050019283779, 0.025695839140098542, 0.08587076838011853, 0.01719197152851848, 0.02651691607752582, 0.03570788998331409, 0.011871488859469537, 0.02730061845795717, 0.04807953257113695, 0.025307356372650247, 0.026548012065177318, 0.03783019485126715, 0.019564233589335345, 0.04438239033333957, 0.0256862654350698, 0.041570110770408064, 0.0285455544872093, 0.02123291553289164, 0.037895589193794876, 0.01571107150084572, 0.03441464570641983, 0.05008266707591247, 0.04827161523280665, 0.06915427788044326, 0.03747880276932847, 0.062424215575447306, 0.050834473804570735, 0.025177749557769857, 0.08822898715152405, 0.03854242284432985, 0.05209978364291601, 0.010028954184235772, 0.037914718050160445, 0.020083475355932023, 0.0538143674202729, 0.03500640086713247, 0.03436177510593552, 0.03989233751781285, 0.009639299751142971, 0.012390775154926814, 0.007407252578559564, 0.044407604800653644, 0.011729023408406647, 0.03752808137505781, 0.07867376902140677, 0.05020873941248283, 0.08577184009482153, 0.024945674413174856, 0.04297692590625957, 0.016738042468205094, 0.030871994495100807, 0.04561247042147443, 0.008884901999408612, 0.048940987908281386, 0.05955946246103849, 0.06392247072653845, 0.0408158252685098, 0.03988379910879303, 0.02776359615381807, 0.017067890003090724, 0.03293996487627737, 0.05858475167769939, 0.03882699194946326, 0.055326437650364824, 0.09489909876720048, 0.058313129338785075, 0.010611015968606807, 0.020861982702626847, 0.03036199246707838, 0.008068003353400854, 0.021562829861068167, 0.05046973419666756, 0.01695807255600812, 0.015546874110441422, 0.04370554052002262, 0.03519679885357618, 0.06399817721103318, 0.011153979558002902, 0.01743477812851779, 0.03125206501863431, 0.04712099318567198, 0.10596959691611119, 0.06493050022982061, 0.022216394791030325, 0.06954561977181584, 0.021288992211339064, 0.011074620779254474, 0.020497853511187714, 0.01702089350146707, 0.03632365733210463, 0.017068244378606323, 0.04485878976993263, 0.02344925236684503, 0.03427696618018672, 0.051063623031950556, 0.057922321793739684, 0.056446583403158, 0.06072524658520706, 0.034617652781889774, 0.059739025091403164, 0.023884553520474583, 0.06042810178769287, 0.05654503300320357, 0.050102905443054624, 0.04319643834605813, 0.04684954896220006, 0.031317433385993354, 0.0829641915333923, 0.053928784327581525, 0.05138899912708439, 0.031632248719688505, 0.04013608850073069, 0.010037197589554125, 0.0386904516199138, 0.05825079635542352, 0.013832952699885936, 0.06900695414515212, 0.03253370952734258, 0.06078962418541778, 0.07258348254254088, 0.03473710887192283, 0.015685625112382695, 0.02745621899521211, 0.02113350114086643, 0.04255161591572687, 0.028131315484642982, 0.028507278220786247, 0.032627401960780844, 0.04532081380602904, 0.01866027174401097, 0.015549945674138144, 0.039687352618784644, 0.03033644588867901, 0.038915700861252844, 0.008971126571850618, 0.025622949106036685, 0.014043980536371237, 0.02978995988087263, 0.06758135525160469, 0.033178468875121325, 0.070528861542698, 0.032041669328464195, 0.018765627028187737, 0.024834762298269197, 0.03940999347832985, 0.03981026711699087, 0.07105611293809488, 0.05280646408209577, 0.05553570474148728, 0.023266930802492425, 0.02224130312242778, 0.060510198163683526, 0.025717233402247075, 0.0424601165286731, 0.022489456896437332, 0.029907790667493828, 0.07927791433758102, 0.06914461511769332, 0.09140763533650897, 0.05249867317616008, 0.025704561230668332, 0.03579806834750343, 0.01950709007360274, 0.015501258003496332, 0.04489551865844987, 0.015053085226099938, 0.014501208443107316, 0.0434715450683143, 0.04885640162683558, 0.05196150297706481, 0.056397627631668, 0.03298164017905947, 0.04195717418042477, 0.05425410105090123, 0.08306156130856834, 0.04880346423306037, 0.055209890779224224, 0.033442079729866236, 0.053982319150236435, 0.03549370616383385, 0.007065414720273111, 0.011009172631020192, 0.010405491157143842, 0.12126611400162801, 0.021466844191309065, 0.03449121679295786, 0.044293432802078314, 0.004581427892844658, 0.05072769730759319, 0.03161339074722491, 0.05056858455645852, 0.017662906902842224, 0.028917535601067357, 0.028419695518095978, 0.028061279008397833, 0.011996964694844792, 0.013854243989044335, 0.02107371372403577, 0.05127481228555553, 0.050773469265550375, 0.027785734419012442, 0.20993052661651745, 0.1297675195382908, 0.15629693894879892, 0.16523959580808878, 0.16821982339024544, 0.23423626378644258, 0.12105851303203963, 0.1027673706994392, 0.14084852649830282, 0.18037700385320932, 0.13868083187844604, 0.08240264549385756, 0.07635673944605514, 0.06833274266682565, 0.10477843505213968, 0.11892261944012716, 0.16528019128600135, 0.1574503700248897, 0.22471808624686673, 0.2401534517412074, 0.1067849129321985, 0.22946777200559154, 0.07221816034871154, 0.20852092100540176, 0.09753469523275271, 0.21164205274544656, 0.0786454560875427, 0.10058115207357332, 0.24817657278617844, 0.17560585518367589, 0.11653164227027446, 0.09756270388606936, 0.11226910224650055, 0.12674200610490516, 0.1615885557839647, 0.1720985394786112, 0.14173364150337875, 0.16408340394264087, 0.14480147219728678, 0.19330410315888003, 0.12477981217671186, 0.13806217757519335, 0.10043271511676721, 0.21147248684428632, 0.09091752843232825, 0.25520721974316984, 0.18803090642904863, 0.08265358788776211, 0.0947226383141242, 0.22436249360907823, 0.13088660401990637, 0.1031813258305192, 0.11156336433487013, 0.08355644764378667, 0.10609718694468029, 0.102644359722035, 0.1820907712681219, 0.18614340224303305, 0.1158842965378426, 0.20654894557083026, 0.10505633224966004, 0.11244665365666151, 0.14733029587659985, 0.18698311265325174, 0.1712796388892457, 0.11774797778343782, 0.21152549103135243, 0.13197270745877177, 0.14544890698743984, 0.15651110792532563, 0.18274351983563974, 0.12569351471029222, 0.30305196647532284, 0.14746284345164895, 0.1663058393751271, 0.1428286507143639, 0.15160571958404034, 0.21454068861203268, 0.14122996071819216, 0.15117108821868896, 0.17435799323720858, 0.13983574724989012, 0.21443332952912897, 0.1092686437186785, 0.17061820719391108, 0.12399159197229892, 0.17251860990654677, 0.1453847112134099, 0.13557728903833777, 0.14899380505084991, 0.1451914559584111, 0.11257140868110582, 0.09066231126780622, 0.13965025485958904, 0.15659033961128443, 0.10519368152017705, 0.23997500975383446, 0.10850486985873431, 0.11823657070635818, 0.10226444690488279, 0.12884587602457032, 0.07700334303081036, 0.09856545671937056, 0.13936690287664533, 0.08617329003755003, 0.1355080318171531, 0.082919328706339, 0.11382269934983924, 0.13607574510388076, 0.12556319357827306, 0.21890965261263773, 0.13517396146198735, 0.08417245247983374, 0.1474013936240226, 0.15121787320822477, 0.1739878990338184, 0.12705311441095546, 0.17223488684976473, 0.0848692623549141, 0.16301570576615632, 0.14019911759532988, 0.11275650031166151, 0.1959440263453871, 0.2156523961457424, 0.16803013044409454, 0.14992612064816058, 0.1432229092461057, 0.13232363940915093, 0.17249309486942366, 0.08746228922973387, 0.10418118428788148, 0.16445490822661668, 0.16431765543529764, 0.2266625576885417, 0.18232922331662849, 0.32206736330408603, 0.15226580057060346, 0.08616507446276955, 0.1634425891097635, 0.13594350923085585, 0.1859361946117133, 0.14793170266784728, 0.21509974845685065, 0.13138431793777272, 0.14936576946638525, 0.1697021149448119, 0.06409073786926456, 0.11060776756494306, 0.17725698533467948, 0.24084189761197194, 0.1968438210315071, 0.20938299974659458, 0.09850511269178241, 0.1934774243272841, 0.10202068107901141, 0.14779385615838692, 0.21427166007924825, 0.12660274951485917, 0.1999306061770767, 0.21308400115231052, 0.10291559243341908, 0.10726973574492149, 0.10993590869475156, 0.24625481106340885, 0.191815028374549, 0.1777489550295286, 0.10445611289469525, 0.1561810154817067, 0.15122395881917328, 0.0868762968457304, 0.10750695582828484, 0.1406146163935773, 0.161599064595066, 0.13378860923694447, 0.1959114905912429, 0.2103923205868341], [0.07254345109686255, 0.02187794576457236, 0.07934873749036342, 0.05342529279005248, 0.01758095339027932, 0.03290690961875953, 0.09080337869818322, 0.04734058726171497, 0.022255322292039637, 0.040716692892601714, 0.07906226106570102, 0.04553561731881928, 0.03952184255467728, 0.014061678903090069, 0.045980438371771015, 0.026739849818113726, 0.015212174785119714, 0.027618337444437202, 0.007195736316134571, 0.04964019492035732, 0.05517606368812267, 0.014272178887040354, 0.03697598658618517, 0.03533720206178259, 0.08269711484899744, 0.06066383757570293, 0.04104911567992531, 0.01947320175531786, 0.044435205272748135, 0.022194805715116672, 0.03208768990589306, 0.057911824114853516, 0.052210853464202955, 0.06349874151055701, 0.03626933954365086, 0.02621046845888486, 0.05062587093561888, 0.027740532059397083, 0.03156889899400994, 0.05726924297050573, 0.027220835727348458, 0.04596240047249012, 0.0160409301679465, 0.04563494265312329, 0.01850687724072486, 0.04342618500231765, 0.07881190496846102, 0.017518050808575936, 0.021332348478608765, 0.09805710782529786, 0.011060955985158216, 0.026075861424033064, 0.023435418734152336, 0.06170925647893455, 0.042095183962373994, 0.04802883275260683, 0.019967288426414598, 0.02116977731930092, 0.07384597964119166, 0.04149838219746016, 0.1177348120836541, 0.028825613189837895, 0.009526259527774528, 0.03044678840524284, 0.03756124424398877, 0.011335360450175358, 0.05449131000204943, 0.04375312702904921, 0.02756565980234882, 0.05091478531539906, 0.0467700872104615, 0.021683768391085323, 0.02716946055443259, 0.042944379019900225, 0.04695189112680964, 0.023286258183361497, 0.08166633851942606, 0.03614571258367505, 0.03578361131076235, 0.0938808053615503, 0.030443122195720207, 0.023471132735721767, 0.015196135118458187, 0.08062071923632175, 0.01972307545656804, 0.06246064018341713, 0.08163109392626211, 0.023548640783701558, 0.006299792912614066, 0.04369282381958328, 0.03500780352624133, 0.05222491345193703, 0.04263194226950873, 0.021880775202589575, 0.011573688188946107, 0.06671183276921511, 0.04784172248037066, 0.027676141471602023, 0.06691897360724397, 0.0843745689780917, 0.025878283158817794, 0.003907015570803196, 0.039613382759853266, 0.0945690656953957, 0.027830793915200047, 0.03194635901309084, 0.01569721003761515, 0.023072154144756496, 0.02474829467246309, 0.03883412769937422, 0.01106653229726362, 0.03002429486514302, 0.05661893977958243, 0.03449505369644612, 0.07093394800904207, 0.03952166443923488, 0.020208354690112174, 0.03510529575578403, 0.024273398084915243, 0.05338100883818697, 0.018251923538628034, 0.036259717599023134, 0.014362140173034277, 0.06767688450054266, 0.011313118284306256, 0.0297510360906017, 0.04597368111717515, 0.08435070893028751, 0.03132485486275982, 0.029656471633643378, 0.005136787203809945, 0.011449417415860808, 0.06851183032267727, 0.08177584240911528, 0.05718323547625914, 0.013249925195850665, 0.018374487372057047, 0.02779879065201385, 0.018070351543428842, 0.04013367281004321, 0.00830086981295608, 0.06123755483713467, 0.045358210627455264, 0.014114934492681641, 0.007563906037830748, 0.058402595241204835, 0.037571593493339606, 0.012415985911502503, 0.014176555014273617, 0.0618624209164409, 0.01646653330681147, 0.031851757448748685, 0.037361714130383916, 0.02195127552113263, 0.03614774235757068, 0.03034715322428383, 0.03371203594724648, 0.05132799458806403, 0.013312260034581413, 0.02593930625153007, 0.0036155141106064548, 0.08632331519038416, 0.03177818092808593, 0.0334664333058754, 0.023839286222937517, 0.03936806955607608, 0.050331594538874924, 0.027926822258450557, 0.035111180986859836, 0.09801942156627774, 0.0237358011509059, 0.03263647100538947, 0.02106461499352008, 0.03083333416725509, 0.045640560711035505, 0.0490755021746736, 0.03801689323154278, 0.058285150371375494, 0.053199564863462, 0.05779295061074663, 0.02052076732070418, 0.07827936206012964, 0.14475630508968607, 0.05691071513865609, 0.04262249101884663, 0.05306762584950775, 0.012512842677097069, 0.018706008449953515, 0.014898895697115222, 0.016947220501606353, 0.0371262566477526, 0.040099793768604286, 0.020660994268837385, 0.02297485672897892, 0.005089258675070596, 0.03841224272036925, 0.039691530910204165, 0.04193885797576513, 0.029817098366038408, 0.06586922056158073, 0.050346389252808876, 0.03329110833874438, 0.016778480239736382, 0.00699333130796731, 0.0105747435009107, 0.045715669766650535, 0.03114456863841042, 0.12988575850613415, 0.03203991043847054, 0.01825366387492977, 0.007272721613844624, 0.01151472826677491, 0.028854453048552386, 0.049279715240118094, 0.01256035960977897, 0.011146790930069983, 0.04157177318120375, 0.05622317468805704, 0.057673654082464054, 0.03632752763223834, 0.03501973355014343, 0.04730675645987503, 0.038278670981526375, 0.020455024168768432, 0.04882358385657426, 0.07337384013226256, 0.01817244879930513, 0.022356055851560086, 0.06361191903124563, 0.04669517482398078, 0.03369906320585869, 0.01352390849206131, 0.006280523048189934, 0.053876110396231525, 0.03805623076914344, 0.07960434057167731, 0.11356604241882451, 0.033904860756592825, 0.03787320230912883, 0.040367623732890934, 0.1491620350861922, 0.017857399689091835, 0.03458100924035534, 0.02493277959729312, 0.024183267960324883, 0.03594634574255906, 0.07003502905718051, 0.035941852038376965, 0.021299771906342357, 0.045386222991510294, 0.10864343625144102, 0.038598076498601586, 0.015746906101412605, 0.04119314799027052, 0.04187862898106687, 0.03744303867279086, 0.04211443898384459, 0.04468635546800215, 0.0761153113853652, 0.023410376816173084, 0.026132446473638993, 0.03550336892658379, 0.006677481142105535, 0.058189832634525374, 0.06040489854058251, 0.0046992387342470465, 0.04989592787751462, 0.0688232651737053, 0.04586399169056676, 0.030097875096544158, 0.02883964163629571, 0.07118142457329668, 0.0651142856804654, 0.042116071708733216, 0.05809578397020232, 0.06334569581667893, 0.07284216553671286, 0.019149155959894415, 0.06110079186328221, 0.020140852648182772, 0.02862193447072059, 0.033203805796802044, 0.03378014655027073, 0.0482704315072624, 0.03353082574903965, 0.012348916170594748, 0.021947173299849965, 0.03371357590367552, 0.05732018769776914, 0.05056280322605744, 0.06960191909456626, 0.042617893413989805, 0.020466490350372624, 0.1050814613699913, 0.06825242002378218, 0.06678867473965511, 0.01246457060915418, 0.006604482105103671, 0.03171746582665946, 0.019211834041925613, 0.02229806072136853, 0.016665287876094226, 0.16455935809062794, 0.0922757328953594, 0.058552249320200644, 0.03460698811977636, 0.015022783336462453, 0.044071768134017475, 0.047257195838028565, 0.05670016042131465, 0.029546539153670892, 0.0185569313907763, 0.030882525570632424, 0.04643411695724353, 0.023339835679507814, 0.011415389944886556, 0.06567778356838971, 0.020251983696653042, 0.07556448937975802, 0.040793167499941774, 0.05970662292384077, 0.04104330837435555, 0.05094899461255409, 0.05320999203831889, 0.10125459913979284, 0.06608456955291331, 0.021035767713328823, 0.035337127847014926, 0.02670660902367672, 0.04806165423360653, 0.042568191784084775, 0.03884796875354368, 0.06211393847479485, 0.023125989537220448, 0.022946274766582064, 0.012956077389389975, 0.033585651908651926, 0.01909253936901223, 0.057182422824553214, 0.05445557559141889, 0.03648023193818517, 0.021403726386779454, 0.035212153889006004, 0.049297296718577854, 0.032520551249035634, 0.04479770730540622, 0.002890418900278746, 0.03876226553984452, 0.02592970100522507, 0.02261110788822407, 0.026267279863532167, 0.03142762005154509, 0.13131632236763835, 0.20387166267028078, 0.15757689136080444, 0.14218850381439552, 0.09160102417808957, 0.18597339105326682, 0.29606865369714797, 0.21875521168112755, 0.12037066830089316, 0.18262002646224573, 0.25420318299438804, 0.1377045811386779, 0.14466191874817014, 0.0945091743778903, 0.15625485917553306, 0.102126296114875, 0.11595810312428512, 0.1651509536895901, 0.1170323470432777, 0.12070341763319448, 0.11227545503061265, 0.08401254934142344, 0.1330285906442441, 0.1261918223462999, 0.15632546710548922, 0.11374629524652846, 0.11032453432562761, 0.062166412026272155, 0.15867773385252804, 0.07674889027839527, 0.1269214425701648, 0.21782522642752156, 0.11713213621987961, 0.11355872484273277, 0.14743625972187147, 0.13204468094045296, 0.136176127998624, 0.15586790337692946, 0.12158589801401831, 0.21858999476535246, 0.08754717608098872, 0.1830277475528419, 0.09816063000471331, 0.15908460889477283, 0.15042741171782836, 0.26459328015334904, 0.21051660063676536, 0.17269320756895468, 0.09870384499663487, 0.19290125055704266, 0.08439914890914224, 0.11683425298542716, 0.13474323379341513, 0.14722933410666883, 0.12274842039914802, 0.15262951230397448, 0.10186792482272722, 0.17167970101581886, 0.13613780349260196, 0.18443572043906897, 0.22849239700008184, 0.14745977096026763, 0.13842228247085586, 0.1339785841992125, 0.18361184746026993, 0.0985202970332466, 0.1215046996367164, 0.1415201256168075, 0.0961019643000327, 0.17397972056642175, 0.1389116546488367, 0.1303364647901617, 0.08976460943813436, 0.20547504303976893, 0.21458831964991987, 0.1251206806045957, 0.1793304123566486, 0.09747009869897738, 0.16997187078231946, 0.19294129684567451, 0.11055910494178534, 0.17689573753159493, 0.22549490706296638, 0.14743030769750476, 0.13665234931977466, 0.196202679653652, 0.17482799536082894, 0.1464704138925299, 0.12019751782645471, 0.12322136884904467, 0.16446859342977405, 0.12100804699002765, 0.13163145311409608, 0.07092176194419153, 0.10583551309537143, 0.14554433233570307, 0.14868950966047123, 0.22405490308301523, 0.12468961154809222, 0.18969398515764624, 0.12070456054061651, 0.1059863249247428, 0.12505969090852886, 0.3022456675535068, 0.0812311060144566, 0.1156910412828438, 0.08411725153564475, 0.11520947649842128, 0.08207191480323672, 0.18628531572176144, 0.1526297943200916, 0.11095864756498486, 0.19186544988770038, 0.10091224641655572, 0.11182238871697336, 0.11471841222373769, 0.12579524831380695, 0.29922435467597097, 0.09423945564776659, 0.09187694726279005, 0.12327840289799497, 0.15667715604649857, 0.09278562545659952, 0.08998888646601699, 0.13889743509935215, 0.0941921140474733, 0.28312803246080875, 0.20732466800836846, 0.1475072980974801, 0.12109009141568094, 0.10173884307732806, 0.12366930692223832, 0.21859517495613545, 0.19262396934209391, 0.0939997864770703, 0.09637422859668732, 0.1646161323878914, 0.1301209896337241, 0.12678513972787187, 0.187296002113726, 0.16755748627474532, 0.1406097033759579, 0.15378171141492203, 0.11013331255526282, 0.114322402223479, 0.18745756766293198, 0.14597007277188823, 0.11869482463225722, 0.1976324271527119, 0.16742504260037094, 0.13624090264784172, 0.10663807159289718, 0.19713778572622687, 0.11846429872093722, 0.1858429066487588, 0.1893194974400103, 0.13849186623701826, 0.13322294427780434, 0.2029536705231294, 0.13305732660228387, 0.05679155590769369, 0.14943340880563483, 0.11459979476057924, 0.16077214881079271, 0.11910549204912968, 0.11211583390831947, 0.09399674367159605, 0.11051475419662893, 0.08671414499985985, 0.16231914079980925, 0.0840337821864523, 0.08060783555265516, 0.070834990037838, 0.09018914017360657, 0.1006203077849932, 0.14743312785867602], [0.015143111450015567, 0.04322602406318765, 0.0497908286342863, 0.011284993670415133, 0.058055529880221, 0.04350055562099442, 0.05339638242730871, 0.03845102735795081, 0.05093527230201289, 0.027366528593120165, 0.08468454179819673, 0.021204817821853794, 0.06885169685119763, 0.08572738544899039, 0.01878683946415549, 0.02535303370677866, 0.04723080877738539, 0.011401385618228232, 0.034413614121149294, 0.04326173620938789, 0.055564711583429016, 0.010078191044158302, 0.03361335999215953, 0.021423294965643436, 0.05388624813349452, 0.010032696463895263, 0.031422588290297426, 0.042327004921389744, 0.06409119800082408, 0.04293685735319741, 0.044489497086033225, 0.007496453163184924, 0.08221016207244247, 0.0378545076091541, 0.029945196765766013, 0.04372339659312274, 0.015681849436077755, 0.07016678995569237, 0.014162369789119111, 0.02573222664068453, 0.007279955698322738, 0.018569046951597556, 0.07843507948564366, 0.011270379854977364, 0.05602988232567441, 0.08214372501242906, 0.07811937728547491, 0.022146783194330055, 0.005142505451658508, 0.06481283271568827, 0.04563262715237215, 0.04420929180923849, 0.07298702534171753, 0.08171796973329037, 0.06576546831638552, 0.021063943349872716, 0.02850824672350427, 0.003144875595353369, 0.07918496034108102, 0.007750744034638046, 0.07189778261817992, 0.014818326289969264, 0.058208690606988966, 0.06801663970691152, 0.030951164953876287, 0.07453523445292376, 0.05486741189088207, 0.024285999752464704, 0.056950382931972854, 0.04031844902783632, 0.010727924636739772, 0.013506170234904857, 0.015354098468378652, 0.07365195997408591, 0.02935108157544164, 0.042869154931395315, 0.04387362212582957, 0.011766481457016198, 0.03767939786484931, 0.015009237285994459, 0.009665315737947822, 0.02417394473013701, 0.0639666136703454, 0.020545158004097175, 0.048078252366394736, 0.020680162087955978, 0.050495824398240075, 0.03823866922175512, 0.030493031626974698, 0.006650850100413663, 0.05278858203382697, 0.021354724231059663, 0.03950491045543458, 0.05850118584930897, 0.03761850093724206, 0.08322367604705505, 0.02549005457694875, 0.021647518187819514, 0.056296977563761175, 0.106555515085347, 0.01241132336872397, 0.021292587916832417, 0.002416668930891319, 0.03609894985856954, 0.02474628901836695, 0.03081751157878898, 0.01799281752028037, 0.04085339649464004, 0.022553494964085985, 0.048489609980606474, 0.01007240414764965, 0.06956388402613811, 0.05285847008053679, 0.03368765268533025, 0.09088214283110574, 0.027578738299780525, 0.025039014326466713, 0.012277597634238191, 0.07178202242357656, 0.04535229571047239, 0.02241134028736269, 0.02178887134505203, 0.02458806127833668, 0.012498606429289794, 0.055857744882814586, 0.04756362490297761, 0.020704988783109002, 0.03602774449973367, 0.042801634335774, 0.014233691108529456, 0.01212850851516123, 0.05488952789164614, 0.002746382183431706, 0.050204731815028936, 0.061899554275441915, 0.042885222428594716, 0.03392734412045684, 0.012823900888179196, 0.028407312784111127, 0.040218244248535484, 0.0059615581812977325, 0.04781133153301198, 0.03205073837307282, 0.027485741629789118, 0.07628198291058652, 0.025464136924711056, 0.024175486541935243, 0.04117934404348489, 0.004092163326276932, 0.015104655212780926, 0.011237513845117064, 0.04497001544223167, 0.018848779109248426, 0.021794430031150114, 0.02961435846373206, 0.02892716867791023, 0.0639156429679133, 0.0350859813624993, 0.04146053266595118, 0.08075239849858917, 0.02958565590233775, 0.011776326045946917, 0.023735994109301828, 0.0303014350720332, 0.017313446260232013, 0.07668353675398976, 0.011798081177403219, 0.10897487940383144, 0.03745243055163883, 0.063669205410406, 0.016097249899758026, 0.021598256280412897, 0.007820984137651976, 0.03321993266581558, 0.034409346772008575, 0.04735557122330647, 0.06928102928213775, 0.06655783712631091, 0.03436668441281654, 0.025775601461646147, 0.05684964751708321, 0.040279927852679975, 0.031944010115694255, 0.06384081963915378, 0.03544744809914846, 0.043867247077287175, 0.037936704175081104, 0.023262303511728533, 0.06915850070072338, 0.022009059139236342, 0.0062099002752802335, 0.023333696262852754, 0.02320803025213536, 0.026069512350659352, 0.04287358184228651, 0.07280837555299513, 0.01962588750757277, 0.03133170117507689, 0.06678230711258948, 0.0256326396993245, 0.04763320495840162, 0.023187725091702305, 0.012499091608333401, 0.0784336545621045, 0.026070625572174322, 0.020919085400237236, 0.08780706135439686, 0.023541432674392127, 0.08373818476684391, 0.11014925388735719, 0.024389659229200333, 0.03236979137000162, 0.0041929205417545745, 0.01768524554790929, 0.05787102083559148, 0.015423692439071601, 0.04074099822901189, 0.06479851668700576, 0.0181353840889642, 0.03372327206307091, 0.02221446149633266, 0.019536634972610045, 0.05450642383948434, 0.08018359425477684, 0.05696718144463375, 0.023977219934749883, 0.14230254222638905, 0.024598714808234945, 0.03720996348420158, 0.022517010984302033, 0.06327408598735929, 0.05685331372660585, 0.04985739928088151, 0.02083033567032544, 0.05374643122195266, 0.025045075817615725, 0.023423472011927515, 0.059698689365177415, 0.056807222645147704, 0.02467813203111291, 0.027920154061575886, 0.02408430813375162, 0.104381408309564, 0.04305418719013687, 0.05980864225421101, 0.06360755520290695, 0.028771204488293733, 0.09265182365197688, 0.029405609020614065, 0.08355961661436595, 0.02508971043425845, 0.05664796888595447, 0.06473711880971678, 0.02276234830787871, 0.04494508670177311, 0.06335012643830851, 0.012832924476242624, 0.0910026156634558, 0.12173999755759723, 0.042812773972400464, 0.023951918265083805, 0.06078643666114658, 0.021939588550594635, 0.0511616792937275, 0.02792283321468858, 0.034099752447218634, 0.023250818776432425, 0.03596423892304301, 0.04107978122192435, 0.03575894974346738, 0.03327620230265893, 0.022360338043654338, 0.01631792008993216, 0.018529061890149023, 0.07226737216114998, 0.09974599102861248, 0.00952859822064056, 0.08625808783108369, 0.0379598332074238, 0.028823386746807955, 0.020788879301107954, 0.041919584400602616, 0.019611137322499417, 0.038150591135490686, 0.029812010943714995, 0.027880896304850467, 0.08033845078898594, 0.06065525463782251, 0.05721196772356052, 0.029917612991994247, 0.06176493981911335, 0.016139652507263236, 0.08105170665658079, 0.03294234717031941, 0.10072486154967919, 0.01267772098799469, 0.028410748927854, 0.08414945332333446, 0.022491746422019787, 0.020281962752051186, 0.055103682025219314, 0.009195319180435035, 0.06787513440940529, 0.07206602007499896, 0.02499285459634848, 0.020710397184302565, 0.016289423474518117, 0.09673012551502325, 0.025448677988606505, 0.018660388632270042, 0.016178516925720032, 0.027821531912195496, 0.012531458523881156, 0.03161205488140695, 0.04765109442814719, 0.01868812454631552, 0.06477297196397558, 0.02948895220470149, 0.021574015881924424, 0.03873658351949416, 0.047075224938453175, 0.030579271042370237, 0.02378599816438509, 0.01550281651361729, 0.018804263236233965, 0.029013975836278405, 0.10824203083757311, 0.05896562186535448, 0.03541891623171978, 0.0018097913516612607, 0.018529991430114023, 0.02787415389320813, 0.05458303574414458, 0.030710215578437783, 0.005502197527675889, 0.10051415098132566, 0.012420396124070976, 0.04943718042341061, 0.024159446875273716, 0.06388954163412564, 0.06088985865062568, 0.027360867861716542, 0.07446541319950484, 0.05497047764947638, 0.020316801019362174, 0.022052242857171223, 0.07671531551750377, 0.03934696287615225, 0.04368877911474556, 0.1082091908028815, 0.003083840674662497, 0.0274175568119972, 0.12441733982996084, 0.1954717532498762, 0.07816979879862629, 0.0922692019958049, 0.07536581644671969, 0.11637729781796224, 0.08702759849256836, 0.10586158474325202, 0.15351165871834382, 0.13936078757978976, 0.1699229038786143, 0.05438253341708332, 0.1615638125804253, 0.1295308189583011, 0.08012394784600474, 0.12046976728015579, 0.08797003698418848, 0.1364415348507464, 0.11156219174154103, 0.13580383703811094, 0.13219907734310254, 0.12272422638488933, 0.3046473761787638, 0.09597403288353235, 0.15909312875010073, 0.17173463478684425, 0.10819313814863563, 0.1827298049465753, 0.1934971654554829, 0.14529479260090739, 0.20327562902821228, 0.13435075641609728, 0.22165239293826744, 0.25220677605830133, 0.18775540636852384, 0.15927606815239415, 0.06225436394743156, 0.13169026089599356, 0.17120298987720162, 0.09342910459963605, 0.14711504336446524, 0.1375360690872185, 0.16836086113471538, 0.15304285887395963, 0.14023686322616413, 0.11936544411582872, 0.12637870997423306, 0.1627895882120356, 0.11351818873663433, 0.12869453727034852, 0.1911316142650321, 0.13348478882107884, 0.12190124398330227, 0.23189161147456616, 0.2801516343606636, 0.19160727155394852, 0.11007541761500761, 0.08951742231147364, 0.14938641601474956, 0.14355512423207983, 0.26539064361713827, 0.1038804512063507, 0.15566845861030743, 0.15220938250422478, 0.0869293900905177, 0.26806567038875073, 0.1825972573715262, 0.12490937631810084, 0.2327243605395779, 0.18759856087854132, 0.06896963895997033, 0.13483082206221297, 0.08053568395553157, 0.13271749718114734, 0.0839817724772729, 0.12463616207242012, 0.1181280984019395, 0.12078334693796933, 0.10312903410522267, 0.19725528254639357, 0.10296907159499824, 0.15349813678767532, 0.15722729527624324, 0.10852559804334305, 0.08124557047267444, 0.12530829553725198, 0.1157542500004638, 0.09483127389103174, 0.21941036480711773, 0.20547433057799935, 0.12928622192703187, 0.1424853183561936, 0.12784326419932768, 0.11530355855938978, 0.1265255661564879, 0.2601319632958621, 0.09818979640840553, 0.08366229274543002, 0.17510509846033528, 0.14350306999403983, 0.14021266921190545, 0.14847664686385542, 0.06243009338504635, 0.10199175958405249, 0.09449056131416, 0.11053525973693468, 0.12671175616560504, 0.11171257312525995, 0.13081271579721943, 0.07541182960267179, 0.13374963164096698, 0.14657084131613374, 0.11416356777772307, 0.06554015970323235, 0.16900127520784736, 0.10232454602373764, 0.13463421229971573, 0.12708064808975905, 0.17663963721133769, 0.14135676407022402, 0.08410924376221374, 0.13824066409142688, 0.11919707307242788, 0.07521475970861502, 0.14508146967273206, 0.1387444487772882, 0.19544500624760985, 0.19680853933095932, 0.09851813738350756, 0.1651505084009841, 0.08940233747125603, 0.1420029520522803, 0.11027979766367935, 0.11569161273655482, 0.10367601178586483, 0.18130862183170393, 0.18189653637818992, 0.056831001056707464, 0.12277579080546275, 0.09145146657829173, 0.24925106903538108, 0.09763186462805606, 0.09934075613273308, 0.12296023676753975, 0.12381738764815964, 0.08182686506188475, 0.07324875114136375, 0.06625277732382528, 0.15462336625205353, 0.12754561845213175, 0.15193247236311436, 0.17658071068581194, 0.12255146182724275, 0.10832338506588712, 0.23348057933617383, 0.08129764697514474, 0.16868884587893263, 0.1767714277957566, 0.08573479208280332, 0.19353784999111667, 0.07171257966547273, 0.09771977202035487, 0.12689450260950252, 0.17990578460739926, 0.17867310700239614, 0.1929790573194623, 0.1529345498420298, 0.0998058303957805, 0.10863860487006605, 0.10511535525438376, 0.16031075560022146, 0.0776288473571185, 0.08488003091770224, 0.27687986148521304, 0.1259582833154127, 0.1634127547731623], [0.036031915369676426, 0.07038788317004219, 0.06327011549728923, 0.022304864360194188, 0.02790694939903915, 0.05869772139703855, 0.028540669300127774, 0.01234385657880921, 0.08383283828152344, 0.04513388164923526, 0.030367081744770985, 0.030454952029685955, 0.07410768317640759, 0.0035211516569688683, 0.04256123043887783, 0.05516789264220279, 0.056427320960210636, 0.03394298859348055, 0.050594426138559356, 0.04864569476922043, 0.06014969992975239, 0.020468885631999, 0.0161424708130653, 0.06612185505218804, 0.044618267129408196, 0.039012636480038054, 0.052941286339773796, 0.017283695415244438, 0.04469060055271257, 0.02370277372392593, 0.027225605881540105, 0.036571905729942955, 0.01309512246734812, 0.009900932782329619, 0.011790209773607785, 0.029984517605043948, 0.029198974698374514, 0.020844148893957026, 0.09592806425644085, 0.01929673944687238, 0.028290496884437744, 0.02310520754690515, 0.056383942428510636, 0.060605148537433706, 0.029959407038404606, 0.0906965094327461, 0.025455266404605936, 0.06374923119437881, 0.06597205996513367, 0.023748111525492277, 0.016359677028958686, 0.07356780042755418, 0.03660520218545571, 0.02341274797799997, 0.11986821205937304, 0.033716243924573064, 0.022945888849790208, 0.023727535481157247, 0.022757863880542573, 0.04342836691648699, 0.07997359614819288, 0.022857881267555058, 0.018455516910762526, 0.1231566906790249, 0.033225554434466176, 0.03415132057853043, 0.06212803185917437, 0.07517573758377694, 0.025893489764712285, 0.0379689727560617, 0.035816043164231814, 0.018704999129113276, 0.010572509636403993, 0.02374861804128159, 0.02578864099632483, 0.021509385951503646, 0.023141533820307814, 0.02707214644033229, 0.06533325635246001, 0.021276774605212267, 0.027969775910605676, 0.04894004909147043, 0.05286003230139613, 0.03775648103328422, 0.03424551396165043, 0.055443307355744764, 0.02358024699788075, 0.019156519920215942, 0.022950043021410238, 0.016801633391878568, 0.08723899925826117, 0.01890502648166148, 0.04079354970599525, 0.057115726012852974, 0.04881178370851558, 0.04406989421113394, 0.016214011993724853, 0.03220609585696366, 0.016389207085012458, 0.03115742263616994, 0.029693694050365593, 0.01840744986111531, 0.03949741105316207, 0.020456866550375707, 0.019950784917455167, 0.02284506623254856, 0.06505438694148324, 0.075439756619744, 0.0046142762766976375, 0.04769401282828767, 0.033476207390776835, 0.028712600797007326, 0.022958338377065957, 0.08402682084124535, 0.03392154423636384, 0.1403119834139943, 0.04509056620008778, 0.055830292840255424, 0.04744946403661743, 0.015966357314027846, 0.041969605154008605, 0.04788070378708653, 0.040129468543455005, 0.013832029653713107, 0.008863093989930348, 0.0913631658477243, 0.04448017571121454, 0.03592829300032463, 0.07003531107329763, 0.043271851682220586, 0.03468162220087834, 0.016887162200873718, 0.022369434918800835, 0.028224755587871186, 0.053285004614735954, 0.030602264632761944, 0.028523557230073493, 0.02283856872963952, 0.008820626444503432, 0.007043009281915147, 0.025746785722731147, 0.016350023543054704, 0.015720405863248743, 0.017380009485350456, 0.04496645684412215, 0.048867426230572164, 0.02437431161524728, 0.07982884024386294, 0.02531406167690875, 0.044236651083338074, 0.013808648291160353, 0.05238275341980625, 0.05799532686069142, 0.015423626573465299, 0.045599891018355265, 0.016685108785168268, 0.05406980722909793, 0.02918813563155709, 0.04084066124050878, 0.02187447065807646, 0.019312753138365224, 0.011344602971803397, 0.062459905457217246, 0.02390098281466635, 0.09657630798756145, 0.017344900334137492, 0.06806191071518697, 0.0360962150443811, 0.007881623168941587, 0.03380092297447845, 0.021369602436607238, 0.07235878249048255, 0.025804756733123213, 0.018101961468346417, 0.01827972624596441, 0.06064567722205538, 0.05627338839985896, 0.07384620970697142, 0.05326789811078925, 0.02289294032379985, 0.015916700212983415, 0.04833388884435408, 0.032496420317329466, 0.0638014635478612, 0.050303882744628936, 0.06702492260956205, 0.015454477652383503, 0.039731729339109734, 0.02547250649513444, 0.01768366291798884, 0.006946006869839039, 0.04140991448366549, 0.0891790326568298, 0.08637004080810584, 0.0662780474522151, 0.007510833665946848, 0.013632674872496864, 0.034649498338694684, 0.03753486831556074, 0.04043418695800938, 0.06596141756745055, 0.030126206584100146, 0.03979211418482009, 0.026321660734538455, 0.0441178183973534, 0.03282988582213875, 0.0503919534094166, 0.005307778492351645, 0.028763617883669212, 0.03184146014973521, 0.044023832815582864, 0.031603193638147786, 0.003542092745192349, 0.023587596115248743, 0.019985027611255646, 0.0520411576871993, 0.041191055133822374, 0.038745437341276556, 0.04307550538214855, 0.055229502031579614, 0.06894261736306362, 0.012578877121995902, 0.031836528578423895, 0.052123027708148584, 0.027569283338380046, 0.01258374004464713, 0.0869861569663044, 0.022899157665960956, 0.05040849959186744, 0.034774676387314685, 0.02857949846656993, 0.028335244678601157, 0.03362837735039648, 0.02081729799101595, 0.046430242946371436, 0.02343822405237006, 0.01380993684506393, 0.046377361213671975, 0.047534209879813716, 0.0223803092376329, 0.07032010282273404, 0.046720051614101976, 0.055092516413424164, 0.028487054696597625, 0.018844357764464803, 0.041038840645342134, 0.02649406720593106, 0.042727167237899266, 0.04120259553019423, 0.09263184503652155, 0.04079087055288255, 0.02763900254649343, 0.07772782759275287, 0.015524451046076138, 0.04015847538539674, 0.01172265299828723, 0.022404458723030984, 0.014699399907840416, 0.03997573636297602, 0.035814792645396665, 0.06860186025733128, 0.05457271989143919, 0.012459344034141395, 0.02958946683065733, 0.04195011635601986, 0.01025007708449266, 0.07336024398682639, 0.04206436628010124, 0.08242401192546822, 0.024816319928504527, 0.024789743620203808, 0.03858878480968997, 0.07375266941380687, 0.022150709155539516, 0.0565444504172774, 0.027317227722960524, 0.05517027493624482, 0.039566653431393206, 0.025463984784437343, 0.06976177028263919, 0.09580902376910672, 0.034612891904544085, 0.014438558191613993, 0.0699224007257726, 0.012175984629720915, 0.050014189109788276, 0.013256112852104707, 0.035368134776945226, 0.04586675619066227, 0.05947656085481867, 0.0655990639643278, 0.04115814088436309, 0.10591012862278149, 0.040156241520890035, 0.06056693906430155, 0.06846644799225032, 0.030060574754315894, 0.030535656878782902, 0.029732345101365354, 0.07222986401757225, 0.06655944758676924, 0.07212334356154315, 0.007642071350346669, 0.016436520854767878, 0.0734934966021683, 0.07070329593261704, 0.055115882933023386, 0.019513442857714836, 0.0369444861280499, 0.025702785642351955, 0.024011158348002937, 0.03080720500292955, 0.03839845732727554, 0.09122646966716275, 0.04561837049550377, 0.03608841878303792, 0.028580196085385978, 0.05159989894309547, 0.01671780595643213, 0.0594725272821961, 0.030877124590915628, 0.05053288354247343, 0.037610979270539246, 0.031002922332845628, 0.012517248251242563, 0.050970772936125286, 0.03867351952067111, 0.06328997536911629, 0.03196563629899174, 0.03292227949714288, 0.02070350448775571, 0.04021271153760608, 0.11629649277892895, 0.020356689601612743, 0.049011584706022404, 0.024771137977950275, 0.015397529878100613, 0.030328634784382302, 0.034786587857524864, 0.04215036635287106, 0.0453539098816691, 0.0061879586792201735, 0.06426830412237905, 0.03778028170927428, 0.03984606089943554, 0.03726087852555793, 0.04873680823948234, 0.07005802821367979, 0.07363212978816591, 0.024652188403706532, 0.04538952554867137, 0.04626783505955245, 0.14609574805945158, 0.1708258452708833, 0.17345606116577983, 0.09615296468837187, 0.14753774099517614, 0.1573746115900576, 0.1067849574610591, 0.16782948339823633, 0.1331126908189617, 0.10989203292410821, 0.11343132035108283, 0.14974889578297734, 0.1446500889142044, 0.13682951481314376, 0.2778366976417601, 0.11147222117870115, 0.1435410976409912, 0.1784963274258189, 0.10857158151338808, 0.10507320868782699, 0.14502217207336798, 0.1384247760870494, 0.11922206860617734, 0.14606575045036152, 0.1093740138458088, 0.2213873274740763, 0.17539664375362918, 0.13376451912336051, 0.0990681727125775, 0.09114536034758203, 0.11674086112179793, 0.196619336202275, 0.16749502712627873, 0.17360931466100737, 0.11004386891727336, 0.09169481680146419, 0.05827803317515645, 0.15285255736671388, 0.17277548206038773, 0.14697948266984895, 0.12541445234091952, 0.1693724826327525, 0.16960251872660592, 0.15542092267423868, 0.14436822122661397, 0.1463524272548966, 0.09619753807783127, 0.17068134911824018, 0.12452945607947186, 0.042254779109498486, 0.127181580173783, 0.20161021995591, 0.15000619838247076, 0.14331441605463624, 0.2100815685116686, 0.16151353949680924, 0.12124643224524334, 0.09663644421380013, 0.128847538435366, 0.11184929157025181, 0.13972467742860317, 0.15862076659686863, 0.13012391369557008, 0.29722150589805096, 0.14026975521119311, 0.13947936793556437, 0.14108061091974378, 0.1607631242950447, 0.11001699574990198, 0.08253541571320966, 0.22040153271518648, 0.2004401054000482, 0.11918966643861495, 0.17545089474879205, 0.11212239449378103, 0.1303026228561066, 0.1428989617852494, 0.11586753884330392, 0.20860441261902452, 0.16673560225171968, 0.13777748972643167, 0.22497506230138242, 0.14425453904550523, 0.10887911266763695, 0.13929954555351287, 0.20481557061430067, 0.07896761497249827, 0.08197173970984295, 0.10566956887487322, 0.06745585807948373, 0.17274695390369743, 0.20474534860113636, 0.24121355032548308, 0.1990524079883471, 0.11596736512728967, 0.174818109953776, 0.18523535487474874, 0.22226209694053978, 0.11830669624032453, 0.18879781215218827, 0.1658593484899029, 0.09070358952158131, 0.08898124287952669, 0.1732869999250397, 0.12590471509611234, 0.112315835285699, 0.1372596190776676, 0.21948411944322288, 0.08889967342838645, 0.16323325893608853, 0.10066761969937943, 0.11979227550909854, 0.1701139920623973, 0.1394488656660542, 0.10816305890330113, 0.19270452205091715, 0.13287193811265752, 0.10041738976724446, 0.18538264150265604, 0.19160097814165056, 0.1284210558515042, 0.11314203860820271, 0.2095198369352147, 0.19117520801955834, 0.12637887324672192, 0.16993342753266916, 0.17913515330292284, 0.14712486939970404, 0.28120756207499653, 0.13944899925263599, 0.11045921186450869, 0.20404574082931504, 0.1469356959569268, 0.10310079538612626, 0.1131659431848675, 0.11613433351158164, 0.20996724808355793, 0.17208964854944497, 0.10639358588377945, 0.09475506274611689, 0.15340946498326957, 0.13380134449107572, 0.10432633353048004, 0.10389628121629357, 0.16806176077807322, 0.381722766906023, 0.15808214549906552, 0.1650513129425235, 0.07590277513372712, 0.1830937690101564, 0.11748349119443446, 0.1993170430068858, 0.13821468892274424, 0.07191218028310686, 0.16681342385709286, 0.16039524169173092, 0.23949702212121338, 0.11264573477092199, 0.1440644304966554, 0.10640275140758604, 0.12473405135096982, 0.2521308691939339, 0.18372125487076119, 0.07746855088043958, 0.21104077954078093, 0.12549981416668743, 0.1254837540909648, 0.08391135750571266, 0.1943451285478659, 0.12751067813951522, 0.08268017903901637, 0.13128544902428985, 0.16440562962088734, 0.06609060321352445, 0.15380298136733472, 0.0834523094817996], [0.09505309441010468, 0.07504379114834592, 0.07455874569131993, 0.028466630792536307, 0.07209998817415908, 0.017528368516650517, 0.02219064783275826, 0.052529947279253975, 0.020608617196558043, 0.032890897782635875, 0.02440483800455695, 0.07884294900577515, 0.05581303048529662, 0.030549065631930716, 0.003444571757427184, 0.035596352608990856, 0.061634099183720537, 0.027652158969431184, 0.002041564302999177, 0.03069601643801434, 0.07133245162549429, 0.08170045504812151, 0.04202820513455663, 0.038753719709347934, 0.03832420916296542, 0.032016273034969345, 0.03483771070023067, 0.036633897325373255, 0.025006669675349258, 0.01739362418447854, 0.036138098148512654, 0.03767235488339793, 0.08494082765537314, 0.028499211075541098, 0.02945656488009263, 0.02341233608603943, 0.0358610841067275, 0.0062536568384530256, 0.04995791576220654, 0.09152931786957197, 0.06813715706812218, 0.04721539437014144, 0.006620975409532548, 0.03420204637222923, 0.041728466530912556, 0.02506578544853255, 0.024584395068814047, 0.040566062889411114, 0.029550305553129874, 0.008247101213783026, 0.046965813817223534, 0.06121334597992245, 0.04316746490076184, 0.050528530846349895, 0.058004466409329325, 0.03007410039572278, 0.03730505115527194, 0.02034395805821987, 0.020696042192867026, 0.01622527965082554, 0.04525692231254652, 0.015321513546950882, 0.04060494029545225, 0.024927493650466204, 0.047170312609523535, 0.037909393140580505, 0.0455447976855794, 0.016060984853538685, 0.03614455483329948, 0.0846139264467638, 0.026652740234567318, 0.029271755265654065, 0.047214574296958745, 0.028848115107393824, 0.01166652900792542, 0.01646624572458677, 0.1198325667064637, 0.07983465126017109, 0.02001158722123364, 0.045021179103059694, 0.03312631815788336, 0.04281351240933873, 0.02221000861027278, 0.003587462088034954, 0.07420456313411705, 0.04362231607956346, 0.008536808763892623, 0.024136379070114344, 0.06396171549567953, 0.022354859138431493, 0.05337396214599721, 0.054972448051557876, 0.03848619402560871, 0.034884477136074565, 0.05101032198581379, 0.014930970392015297, 0.020285645659896545, 0.017364181330776773, 0.01679340668488294, 0.05492887656146195, 0.0383446627529338, 0.03223522144253366, 0.06281325680902228, 0.012421339579304913, 0.03253839247918222, 0.08294874001876451, 0.028435644271667115, 0.03837203315924853, 0.002671367983566597, 0.02693954505957663, 0.07221711392048746, 0.0402493810543092, 0.008668829414091306, 0.007891222849139012, 0.01657562159380177, 0.04327343987824861, 0.05764281784649938, 0.02869285410270095, 0.018175244840676896, 0.033051212813006714, 0.06450345361372456, 0.010637308405421209, 0.06671163238934241, 0.031389985742862336, 0.031060546389198862, 0.035427944458206184, 0.016821986791910604, 0.011518385199451586, 0.043335390655556694, 0.04833571452763863, 0.03026594185939757, 0.01882352753455052, 0.08095448531094007, 0.07341146701946855, 0.02975311224872712, 0.055775336804799736, 0.05861366204044316, 0.0086260937678162, 0.052403463050723076, 0.0660119578242302, 0.038888653289177455, 0.07040536074782722, 0.040298058520420454, 0.030787669820711017, 0.02103344664647011, 0.021498760252143256, 0.035672188969329, 0.046442336242762394, 0.07173261023126543, 0.04954658783390187, 0.026912773937510792, 0.02631832849147031, 0.04968422283127438, 0.02410395463812165, 0.0439889221888734, 0.07345684934989549, 0.013101746135362191, 0.056654481231817044, 0.040932194024208, 0.05428758304333314, 0.12633143516723067, 0.04040266423544381, 0.03940076116123237, 0.03408505050174426, 0.024938123060564976, 0.051165801924071275, 0.020170221287116874, 0.033010361294145696, 0.005740962205891265, 0.03383904338988941, 0.060622017554123886, 0.06160090662888251, 0.009231223357346607, 0.028658490809903014, 0.04804400596185587, 0.02708669810090214, 0.07459116270183586, 0.06471330329077318, 0.011743833892978728, 0.044075233963667415, 0.018973187179653905, 0.04291576551622711, 0.05852191403391771, 0.023145127670431975, 0.046391280193347484, 0.05950292936176993, 0.041754976045922376, 0.06644332373980433, 0.025356905862281565, 0.061588241878780536, 0.03241288417484611, 0.008657257476443192, 0.05069581464340445, 0.06476926122559234, 0.04259754372469615, 0.05248349625617266, 0.07080634313751943, 0.044169920874992386, 0.019028581082238816, 0.09245441236998886, 0.043548231187742203, 0.029405907735053916, 0.07470135678886436, 0.04686110791226383, 0.032360822515329346, 0.04237853594531771, 0.03441926928644534, 0.028541901265271008, 0.01025829451464233, 0.01973070844542235, 0.029781315715808887, 0.05915200483286753, 0.042654433054849505, 0.03957702123443596, 0.08701003185706213, 0.06587828218471259, 0.0853589536563959, 0.038577808445552364, 0.013601775553979678, 0.05530828100745566, 0.07832265153410845, 0.03877280774759129, 0.011383932160242693, 0.043220209336141124, 0.015783532944624312, 0.06044090383511502, 0.010917137042270042, 0.043594548624241725, 0.013827981238137, 0.021718797761423048, 0.021260107823763974, 0.07756031001918018, 0.05393753795942757, 0.02190423820138676, 0.03024860157893272, 0.04508248792262748, 0.05511700357601512, 0.03391186663066037, 0.049829487106762826, 0.03267265441536438, 0.07151549492846243, 0.029656746228283737, 0.007169391001298209, 0.05965760778053664, 0.0642416016489733, 0.05328900850145146, 0.011993746556981932, 0.010889903005590895, 0.022808804897067603, 0.0231119907766697, 0.02069347807264421, 0.03554908522346523, 0.05542181104829069, 0.03406414791243151, 0.048517013783566654, 0.07328057443373837, 0.08513615350238979, 0.056907739126472734, 0.04068231661221944, 0.05408396740676835, 0.029327195552468766, 0.026416117580083665, 0.009585799252818106, 0.048436386859975755, 0.06489413499366492, 0.02577181650849525, 0.07274675503140315, 0.027317305648466572, 0.0386806923779659, 0.03871072709443979, 0.030971104606578592, 0.013021923514315858, 0.037586247199214995, 0.06347799106151797, 0.07205310670542531, 0.019441762524365913, 0.01654079074796755, 0.05467043476528488, 0.09487871939199977, 0.02494252399628749, 0.051609201764222234, 0.026970605795213487, 0.03415209241211414, 0.059071437281090766, 0.07105620199581608, 0.05434596037957817, 0.06164809979964048, 0.03952375358494464, 0.05539343874261249, 0.017639095094637014, 0.030272357726062182, 0.019793829960690346, 0.016204933672270272, 0.041455812606727704, 0.03953860024921596, 0.0638115344918333, 0.04815917614905629, 0.05759865634900052, 0.06447579376981594, 0.030274932978500146, 0.032060638623079285, 0.03665118565550074, 0.039485046872869134, 0.02636092405737145, 0.0705548218684271, 0.03132894038571976, 0.05370582461182494, 0.08444985243841074, 0.07133167979191057, 0.05422572874522302, 0.03246523156121839, 0.03738549254194368, 0.02634565251355525, 0.019994686663267203, 0.028189444201416336, 0.0607317663525464, 0.037904391065239906, 0.1307691220426932, 0.00818504468043102, 0.028319631746853702, 0.051187283388571814, 0.033129787698271684, 0.029361208180489484, 0.09564768828568049, 0.03833963470242452, 0.04600148196914233, 0.009792260098038241, 0.04458580559003167, 0.04171274784312118, 0.022152978272060864, 0.03139420114166569, 0.03454260680882726, 0.015546658887615195, 0.044147704684291966, 0.08895708597265184, 0.044672351141343825, 0.07331970788072795, 0.06951124349143356, 0.034061917758663185, 0.017530591248942073, 0.033341515008942224, 0.040796748362481594, 0.051102455909131095, 0.07273684735991992, 0.03313940222142264, 0.03255589232139755, 0.03398284563445486, 0.022891203698236495, 0.02663996972842142, 0.0650286344171036, 0.020545688639685977, 0.013712251657125307, 0.17402077617589384, 0.20345470926258713, 0.14051506470423192, 0.10227980936178938, 0.25057215127162635, 0.14060612622415647, 0.1069421146530658, 0.14887633791659027, 0.21435932256281376, 0.15645477891666815, 0.09335385082522407, 0.15282428154023364, 0.21397741336841136, 0.10816613881615922, 0.09112169325817376, 0.06798142479965463, 0.14640918670920655, 0.10405197637737729, 0.10405127133708447, 0.15449239203007892, 0.1713412519893609, 0.13788094511255622, 0.13509300799341872, 0.1775989224552177, 0.18580513133201748, 0.11145474360091612, 0.11773820369853638, 0.1086131863121409, 0.09171376383164898, 0.12471781315980479, 0.1579126389697194, 0.09653797606006265, 0.22381233953638002, 0.15260619402397424, 0.07248654321301728, 0.1427452778443694, 0.13541116670239717, 0.09806801739614457, 0.15301934763556346, 0.2084782623569481, 0.18504566192859784, 0.10797956289025024, 0.1700263741076924, 0.12632741272682324, 0.1586866841535084, 0.1213456351251807, 0.05776885307568591, 0.13747081946348771, 0.1321759817074053, 0.14907550066709518, 0.11865716805914417, 0.12657221755944192, 0.21468071703566238, 0.19160633644787595, 0.07357449459959753, 0.20868118037469685, 0.11557810867088847, 0.1037641269795131, 0.0681003910722211, 0.16529993241420016, 0.20068351499503478, 0.12388554649078287, 0.16303558048093691, 0.1242935644404497, 0.1802532433066517, 0.172358498966787, 0.10953142336802557, 0.13336202275240794, 0.2301422951859422, 0.26945571298711, 0.10076623628265224, 0.13955674425233155, 0.15563945547910407, 0.16592808620771393, 0.08914775855373591, 0.12026306430925615, 0.1962492716847919, 0.23311741679208353, 0.13233681995188817, 0.17623155988985673, 0.18646712705958635, 0.17827455885708332, 0.16041576949646696, 0.16315313667291775, 0.17214058956597, 0.1001084633753635, 0.19599826249759644, 0.14082749403314665, 0.266290542203933, 0.11626395702478476, 0.21257761894958094, 0.1339053935953416, 0.10776367955259047, 0.12957475410075858, 0.13643699290696532, 0.11357312992913648, 0.1752009690972045, 0.10115938159287907, 0.12455847405362874, 0.09982176430639811, 0.10797839029692113, 0.09741101632243954, 0.16245701699517667, 0.0908873972366564, 0.12420124869095162, 0.2628273842856288, 0.1195830047072377, 0.09815472993068397, 0.10175644682021812, 0.10433575880597346, 0.18647331657120958, 0.16799535340396687, 0.17013692442560568, 0.08760766111663543, 0.08366406647837721, 0.1445373715250753, 0.09802043088711798, 0.1758708612760529, 0.1878046552883461, 0.08417669014306739, 0.20910689112497494, 0.11562937623239122, 0.1462624195846729, 0.0814603925391566, 0.11851044546347111, 0.18769159651128575, 0.13525703747291118, 0.08407497880398296, 0.22534352377988398, 0.11368408842827193, 0.11934209614992142, 0.12425047534634359, 0.19954066694481298, 0.17973246343899518, 0.1165576174389571, 0.11472262020106427, 0.16159271181095392, 0.07671186453080736, 0.13305602042237297, 0.1931388714001514, 0.0960771097743418, 0.3342292341403663, 0.1830157989752479, 0.08680832354002632, 0.16294012544676661, 0.11699752547428943, 0.0870397845574189, 0.28387261438183486, 0.1499905835953541, 0.13736785389482975, 0.09340908887679689, 0.12183471044409089, 0.12465933192288503, 0.09783409986994229, 0.17633005772950128, 0.16719187464332208, 0.20201590756187215, 0.15522891422733665, 0.28927714156452566, 0.21600482723442838, 0.18213409784948453, 0.18343573581660166, 0.18104664370184764, 0.11037545307772234, 0.07811815274180844, 0.13172773935366422, 0.15880725346505642, 0.16973475459963083, 0.07435320047079585, 0.17107094696257263, 0.10595256462693214, 0.14583561045583338, 0.08612959238234907, 0.1381865021539852, 0.08252668063505553, 0.14821036427747458], [0.03058143254747847, 0.030637945237685926, 0.03354718639457133, 0.025500409392407164, 0.022640231618424878, 0.0448070286802249, 0.05313753987138625, 0.0728367998090107, 0.0057059931350522675, 0.03582166493288241, 0.012073675861756783, 0.029922216162958648, 0.06641012005275115, 0.03653710271464661, 0.05535431642783806, 0.015192430873867124, 0.050437183599569835, 0.05742142035160214, 0.07650347688468173, 0.03132710357022006, 0.006272481414271169, 0.016849004678078927, 0.03452243152423762, 0.06882860121550038, 0.019428706291364506, 0.01312782891545794, 0.04068891430506483, 0.08667700793012045, 0.04423661026521586, 0.017001491905830335, 0.037592477528960444, 0.04238086999976076, 0.009921342771122, 0.02080502101307502, 0.08438807606580667, 0.03197830847057048, 0.11669691855786368, 0.04102999053429812, 0.028221135762578342, 0.02781564853648888, 0.006790731022192631, 0.03863292033202015, 0.03442066452407744, 0.01028037340802257, 0.053478545596590266, 0.01549042264741729, 0.09814787990762852, 0.009810091123654274, 0.08109808346489444, 0.016868098282429855, 0.061445345054380596, 0.038089619993115775, 0.027363771514501423, 0.017610008471820038, 0.05974534076813143, 0.055426839098799974, 0.06621932872803882, 0.03316033449664246, 0.02987930889503332, 0.08274008519947529, 0.014657115116278874, 0.04512644532951526, 0.0613770006748382, 0.01598653630935587, 0.050926281182910316, 0.012750262212648522, 0.07207485905382782, 0.07314763352042064, 0.03179109800839797, 0.023253535036928952, 0.039020373369567096, 0.038096837379271165, 0.07322807490709238, 0.013951130440545967, 0.0386606395477429, 0.02376144791924162, 0.031780585486558266, 0.04486977726628538, 0.05007200983527582, 0.04647595553251449, 0.0649447123578284, 0.01354488715151092, 0.0363311010733014, 0.014956819395592902, 0.021289892065396998, 0.02956374028144637, 0.04322071770729963, 0.010416549157525878, 0.07443093301844783, 0.04666849461500533, 0.034274183126399294, 0.016984509711619467, 0.018923899297078606, 0.011665900965454057, 0.040177541159209795, 0.03747016045963392, 0.07157562373322435, 0.03323817465570755, 0.029590084668598138, 0.041335295245517045, 0.03424230046221055, 0.007829493788449327, 0.01727214017591905, 0.01971082074305741, 0.03817113378318027, 0.05056755297118798, 0.036638580277212895, 0.006741283577866852, 0.05060031508037355, 0.038211929640965536, 0.059176851937081665, 0.010641793760441942, 0.034271292461198755, 0.07211945470771752, 0.04177482107479591, 0.041090835511568, 0.08806709505734034, 0.04993428578018211, 0.008564694035158027, 0.02751957428699825, 0.0754693905764725, 0.013981461088405922, 0.04142200035857968, 0.030047290310903918, 0.07441860594553873, 0.04398272154503502, 0.021433564434119035, 0.075525496940827, 0.07898481795564294, 0.07420062232995406, 0.09232881129719317, 0.06271550853853114, 0.026744310125650372, 0.054189215079532005, 0.062027990352362394, 0.10337753483327106, 0.04747070430312306, 0.03546185318555217, 0.07894886832218617, 0.025855645799310878, 0.006207736914802808, 0.05969498604827095, 0.006199047293193871, 0.03775921213673428, 0.047278424972319044, 0.040569484190200455, 0.04687138294684701, 0.03727078248630278, 0.036928433473804034, 0.027429358815425076, 0.02630065609992016, 0.0748276554804761, 0.060951048726565205, 0.02538493492465932, 0.06772513152100146, 0.038517275170306675, 0.07151916113798507, 0.015582134474243503, 0.03276632087363396, 0.011985442852164852, 0.017898620426421985, 0.019396033239900135, 0.016832089277158957, 0.038933363975957036, 0.04218929941998795, 0.07240987935801968, 0.01306703032241785, 0.033653335776762106, 0.044810965773649514, 0.023924833585624583, 0.02033674067206448, 0.037575575115624815, 0.006546856193381245, 0.042394273186801, 0.08227823185734451, 0.03001541321282275, 0.031969209740054794, 0.04616642800101545, 0.020105598778172862, 0.02242885126179317, 0.025620882224757224, 0.009324843431386398, 0.04816641579964198, 0.07054817964672111, 0.08228635837440379, 0.05497650017787237, 0.03533945076924283, 0.04281813227862585, 0.0423974607110722, 0.010178752982028527, 0.0800337249529548, 0.020150687960267533, 0.011310421505186241, 0.023193511988210957, 0.011145001426484669, 0.04084518091985956, 0.029274449261720292, 0.015811665907676797, 0.013342360616661608, 0.013237512775958749, 0.011820737090602051, 0.027261488721705973, 0.03719077896676026, 0.023195612266135868, 0.04727990184619557, 0.025654854034655727, 0.06585141643881798, 0.040216993729700334, 0.06042024244379718, 0.015138241105887573, 0.027673460463120136, 0.05952844810963143, 0.009059613767021801, 0.05709796641895082, 0.019754913591896184, 0.04080468563188333, 0.004612510892911814, 0.029081915745337028, 0.036097762422286905, 0.06135327050287742, 0.07504900844651274, 0.038515104388352484, 0.07160479013691656, 0.03248161076044198, 0.057130817585857585, 0.04346262074250262, 0.04666290995373856, 0.00538466360012535, 0.0032328370252798777, 0.04280848806956783, 0.017968851716432255, 0.047762416579644196, 0.014778206714254338, 0.06539905516547151, 0.054452273034257814, 0.02216681376012275, 0.027098383216070943, 0.028191097335366067, 0.05447480463772081, 0.011231469052290777, 0.036552765741362236, 0.02023162473051343, 0.03340524322993588, 0.017835706712503452, 0.05549359899305273, 0.05047197177191265, 0.02726049795455765, 0.029109486531524453, 0.0291852338341414, 0.046644449030281976, 0.09026200423249975, 0.018431322896503843, 0.04762670745549258, 0.04456569338799454, 0.08297026230138727, 0.04569321608869359, 0.038838528635096736, 0.06960847968002781, 0.02035419598541921, 0.0362510270497296, 0.09145341842668131, 0.018659195629879832, 0.08327722942340188, 0.04786287739989348, 0.08383925043744966, 0.045891992922406644, 0.027763636971940286, 0.04437696894456167, 0.011717021025106078, 0.03821098340267781, 0.0172236816433724, 0.01169534474684042, 0.021514844447665382, 0.049502838228363544, 0.023752983724989463, 0.03861453733406961, 0.02210233040386811, 0.02465188783389749, 0.04894152225460857, 0.10557193934801035, 0.03394668448891025, 0.038788767633377574, 0.04876192622759845, 0.021887213333684485, 0.02689590306545142, 0.025117876793956384, 0.028615950905077625, 0.0039527411445305916, 0.02995629001816269, 0.031177070995909162, 0.04913526361633558, 0.07048297455185093, 0.05300493292452302, 0.08184789752704091, 0.020975818879378494, 0.03888795567036141, 0.07044761863653548, 0.017639831676206086, 0.04102774924831465, 0.037062046030769125, 0.04895178986771498, 0.06477793693193235, 0.012706997786153806, 0.0754462875192985, 0.03282695804955438, 0.10098436090629548, 0.032062957834568806, 0.029470148037944455, 0.007426367055813898, 0.029181419195083436, 0.07031346802250482, 0.07582005535368808, 0.05192931232159026, 0.02237270222394727, 0.07215452118543908, 0.07895428600022569, 0.07479213629267178, 0.029126667250238825, 0.03277221352618653, 0.02210740298323799, 0.09163362672552466, 0.03971327212639153, 0.055389097178704105, 0.035934898114646785, 0.07298776748939417, 0.013257767841423629, 0.014217444568203064, 0.037925115539110266, 0.010572261016932316, 0.06294912920566276, 0.06561922069522552, 0.06150663160951808, 0.03238795914512593, 0.048961311622406356, 0.045784444591845386, 0.046085934664006345, 0.05687484714144375, 0.03204550994269084, 0.02896418885939056, 0.05173232777451631, 0.05735620783525519, 0.03710679753567092, 0.04100105419638567, 0.028007584623992443, 0.03934130028937943, 0.022319364070426673, 0.07170453478465788, 0.057530323101673275, 0.024477195547660813, 0.059115261101396754, 0.033963479290832765, 0.016853169981914107, 0.12710292736301199, 0.16090242541395128, 0.10034677441581152, 0.15441614377778023, 0.12935902661411092, 0.09238470243872143, 0.18094700295478106, 0.2670272870454937, 0.2014249947387725, 0.1673748585744761, 0.1088524769875221, 0.10067084804177284, 0.10824500684975646, 0.09559358572005294, 0.17849825700977817, 0.06782481679692864, 0.10308362951036543, 0.16525077255209908, 0.2113257345627062, 0.1616177667165175, 0.15807220072019845, 0.11147340119350702, 0.0995394068013411, 0.1363164235954173, 0.11106062607723288, 0.15581665065838024, 0.18138985731638968, 0.21453314839163795, 0.10746114305220544, 0.10007003496866673, 0.15662762511055917, 0.13877226447220892, 0.1177884396747686, 0.14398769242689013, 0.16067942488007247, 0.10995766846463084, 0.24211266223574057, 0.1476211435510777, 0.1314976587309502, 0.13969411578727886, 0.11259987004450522, 0.0736958505876828, 0.11562325351405889, 0.09727486190968193, 0.12564926786581054, 0.13635749404784292, 0.2160315148648806, 0.1394829005585052, 0.26252161944285035, 0.07835065276594833, 0.16411445540143177, 0.1272621180396527, 0.14689250296214595, 0.11564503554836847, 0.18806133448379114, 0.11163703733473085, 0.2217503119027242, 0.1671362729393877, 0.10814028981258161, 0.16667998570483178, 0.1122649759054184, 0.19073817209573463, 0.20245889551006258, 0.06545280150021426, 0.19195703091099858, 0.12119353195885196, 0.1730930618941784, 0.15905720880255103, 0.11471324687590823, 0.1747206659638323, 0.12457273813197389, 0.20034043496707454, 0.181739735417068, 0.16430388117441908, 0.13660967582836747, 0.08005591516848654, 0.12428441375959665, 0.11374751979019493, 0.13589268695795909, 0.09154989762464538, 0.20681908732512966, 0.15217877633403987, 0.0975288990593981, 0.12631825462449342, 0.14318878529593349, 0.08372314143343829, 0.14378735708305612, 0.14497023657895625, 0.18046359764412045, 0.1569340578862466, 0.11091124659287743, 0.08644889399874955, 0.10476197421667166, 0.17037883488228545, 0.11330306981108151, 0.11563340609427541, 0.12920151319121942, 0.16726171073969454, 0.1727820426458493, 0.2083935239352286, 0.1565701828803867, 0.08868007935234345, 0.1376766467001289, 0.22018108516931534, 0.30303934996481985, 0.11897287025931291, 0.21392549271695316, 0.08802054013358429, 0.16425181209342554, 0.1411688671214506, 0.1118049408250954, 0.191636779345572, 0.11772769488743506, 0.25602088076993823, 0.14558966271579266, 0.21306111331796274, 0.14417051308555529, 0.18044967495370656, 0.20642837625928223, 0.10245811034110375, 0.25586030969861895, 0.09205256908899173, 0.10950794181553647, 0.12533131695818156, 0.14566798898158595, 0.1558257345459424, 0.12808265135390684, 0.123506353556877, 0.21846840129001066, 0.15069430286530405, 0.30365120619535446, 0.19150114443618804, 0.09455201114178635, 0.1642915021511726, 0.1530020555946976, 0.23541099450085312, 0.14078238629736006, 0.15995505906175822, 0.16430153598776087, 0.2583465341012925, 0.21942312974715605, 0.15445440891198814, 0.22809882124420255, 0.10590032485197298, 0.10619555861921981, 0.1509179564891383, 0.1159425254445523, 0.0984487243113108, 0.1354643638478592, 0.10479745629709214, 0.20912155596306548, 0.09582253085682169, 0.14101665263297036, 0.1892754583968781, 0.19331575487740338, 0.12961641827132553, 0.1600079593481496, 0.13829846255248412, 0.09390660983626731, 0.11762526366510428, 0.12533433007774875, 0.1387740159407258, 0.09723612180096097, 0.23660175560507923, 0.17959653167054057, 0.12578447232954204, 0.08637508741230704, 0.13826119189616293, 0.10486743340152316, 0.08524260716512799, 0.15820459986571223, 0.12806184153305367, 0.12637884356081486, 0.15234430495183915, 0.16184876760235056, 0.08909260213840753], [0.02596142039692495, 0.039087827171897516, 0.005156983361302991, 0.050262934746569954, 0.045442774644470774, 0.04734601236123126, 0.032576060184510425, 0.029867061602999456, 0.09490148106124252, 0.042297697509638965, 0.0425814873597119, 0.04430442400916945, 0.03293902234872803, 0.03795743607042823, 0.08235086585045792, 0.003136748382530641, 0.012886430540675065, 0.0618412400217494, 0.020117903586651664, 0.008653208133182488, 0.05412261474702973, 0.02437617069517728, 0.056926686156657524, 0.03067958343308419, 0.015508446631429251, 0.053779508743900806, 0.012183288290543715, 0.03436968268943019, 0.03366931421624031, 0.061393105279421434, 0.029577583190985024, 0.06193253902893048, 0.021564286325883586, 0.053516747648245655, 0.025984660751419142, 0.042120190628338605, 0.06191680549818557, 0.023794703556632157, 0.1024311406945344, 0.10431971357320435, 0.026945411736960523, 0.013330193105502985, 0.048126414039870724, 0.02141070071957074, 0.0582452450908022, 0.032296374411089346, 0.032655173126840964, 0.03870272674248554, 0.04341162035416346, 0.027213705543545075, 0.06507216137833893, 0.02691134901397163, 0.06192131775605958, 0.04700740006228443, 0.04682631231844425, 0.02795278443954885, 0.06410592221072875, 0.027415232034400105, 0.033398838495486416, 0.0790605170186609, 0.013886612759961281, 0.065954634337686, 0.02691392983251717, 0.01943938208569307, 0.017457764297432732, 0.11209676813450642, 0.009138966979662655, 0.019429849198786542, 0.050136773352278396, 0.036795269916183315, 0.010249444403598318, 0.03442470922891516, 0.026760216205730103, 0.03948202633182518, 0.020589937339536846, 0.025600686531106476, 0.05861329467734322, 0.021558833395829424, 0.0426448296639137, 0.034896399738499895, 0.062034992515691556, 0.06308391806669533, 0.036415171562111937, 0.011019602588930866, 0.03211621064110659, 0.024356793219340034, 0.0341710913926363, 0.04137056952458806, 0.05984167153656017, 0.016262227472907398, 0.01936653658049181, 0.019029592258448247, 0.01583099328854587, 0.0014695900449623878, 0.03548248489096295, 0.04114622570341453, 0.03010948043083772, 0.012580297407112084, 0.05219223668973427, 0.010291801554558333, 0.015680033029639162, 0.014081403332966147, 0.07502861422835849, 0.019901083287550136, 0.0241079715124215, 0.03485086897853762, 0.03090016085479874, 0.08118619865854271, 0.06994093215325847, 0.011636729923338862, 0.010289627061865758, 0.03438113031734247, 0.027019821318390314, 0.030354366899700835, 0.007834173029550584, 0.06488361876108684, 0.02453216085996246, 0.014243542191252345, 0.06938404680113308, 0.0794658187078312, 0.16271276108454913, 0.007922425520519027, 0.01974042501387885, 0.02082666575006442, 0.06397750839823857, 0.013185107873141533, 0.043407011617091484, 0.02350806571485009, 0.041167896415572613, 0.021209962760622147, 0.04319285377277993, 0.03859551237837877, 0.030873402720317245, 0.08287918593850918, 0.04466895210498478, 0.007417195965899737, 0.02964024828543188, 0.01740829087793827, 0.012597295371961081, 0.05559087228903081, 0.0144489807280479, 0.026755113940453157, 0.007595065571877058, 0.03415746927203145, 0.0096191977536364, 0.012523568566393806, 0.033357478605466895, 0.023475338857679162, 0.03408547352591995, 0.04606939219229389, 0.039414264538208954, 0.02926543773355661, 0.035183707368560135, 0.041316934511996806, 0.043334578003850766, 0.02650537011504639, 0.058412313665030524, 0.07704125935561024, 0.045875687937950715, 0.047954773835954256, 0.025887591546052136, 0.010633595811668783, 0.03529744892148301, 0.02341240287933033, 0.04594531994371209, 0.02375730859057512, 0.018575002686702646, 0.03352248029841576, 0.01613608648767695, 0.01601149659109069, 0.024400680122198537, 0.036169531813357025, 0.03700078545080032, 0.04858026331930887, 0.06064703906304203, 0.03876838083670009, 0.02953713614260778, 0.014999104187154444, 0.05751457101723645, 0.06801865092711523, 0.007492795302823652, 0.06162385383504443, 0.04669111527618952, 0.036508351913653314, 0.034189047655672766, 0.04695018789789174, 0.03638156340457499, 0.004863738085987279, 0.029831419960828498, 0.018272560810146388, 0.032128322491189465, 0.026970188337145373, 0.05506150577275548, 0.06019779480993748, 0.01769863945810357, 0.03474828932667151, 0.04120995392440818, 0.061534625419881195, 0.056065765165840276, 0.03511046110361349, 0.009957863858289784, 0.04225344324368052, 0.031553273074678145, 0.039999151122174226, 0.029994083888595924, 0.016144192595675122, 0.044765453567379154, 0.010761668236227706, 0.027219607472943608, 0.014905787465977482, 0.030991009007266257, 0.07229740687762387, 0.04196002773824148, 0.04812393897736911, 0.08473711553961039, 0.02919242895586649, 0.020008952596981544, 0.032182258073589765, 0.007258016885316465, 0.059358718935982324, 0.057101888669421896, 0.018648902041604742, 0.04673899493354838, 0.12121011153794825, 0.03329382088850252, 0.039112993399612606, 0.01848780219006585, 0.0455198763665976, 0.10323766226065345, 0.045756729086861014, 0.0422901869751513, 0.04105206571693998, 0.05315413058269769, 0.0644635186472442, 0.03970011755882297, 0.06405106265447102, 0.032609839036013, 0.012310024849284673, 0.03130758508632425, 0.0018583716428111074, 0.046725283755222335, 0.00629222950010444, 0.04170351181528531, 0.018600807161419652, 0.07936340232845396, 0.0577121752576204, 0.0917142016987782, 0.029944120651634876, 0.028503612011263613, 0.0246923645681818, 0.008051399654505076, 0.022062562420614995, 0.032718934744480066, 0.015330193891713861, 0.022651039143966045, 0.031624515540897846, 0.021013349287386518, 0.04897555714705959, 0.02948105760879116, 0.046410973081947304, 0.03256846059230156, 0.03001948574819835, 0.06151807552669197, 0.07074609558912925, 0.02811314770951867, 0.05520280326891225, 0.00676346034197195, 0.03638699963630643, 0.02450425239658216, 0.056454505829606205, 0.02794278771034442, 0.04185984522337094, 0.0381815943546826, 0.02147138427972095, 0.11398262475267984, 0.031892334372969344, 0.0441929571388755, 0.06665981563855894, 0.015769695601193234, 0.04089359121280722, 0.05401956383138895, 0.11477417720016092, 0.025605252594687045, 0.09074722780496813, 0.05783127882750705, 0.009118870548263658, 0.03852844820357859, 0.02700557764910627, 0.03262005098804366, 0.011022710332326824, 0.01897251368063735, 0.08891958525055088, 0.022566814659512602, 0.027730479669116903, 0.022436812650994398, 0.06258352499571629, 0.0065568570971663576, 0.05203810003877152, 0.01630070968531072, 0.0679527259489987, 0.06845838084700517, 0.023684693151153624, 0.06374282645992935, 0.029730385831499007, 0.02775718028715346, 0.030558208891307004, 0.012489882483350812, 0.00785461734267301, 0.021159190582693554, 0.008996433807624271, 0.10630708857206628, 0.03327167891256977, 0.03200978295353707, 0.042405821004649624, 0.053052037037559785, 0.03544473183865193, 0.04632252763258293, 0.023395359457936138, 0.06962422063224949, 0.03575541340978816, 0.06651017640251666, 0.029198726078902837, 0.02941031980299158, 0.023619406420039013, 0.03938674199162051, 0.03468956318101846, 0.040141702847904526, 0.056492273724870756, 0.0474369440053124, 0.020160562235105317, 0.02525173797039315, 0.0395942539034877, 0.0661850266624242, 0.022324770616251044, 0.0249220945261186, 0.07456949941115454, 0.06550757199875079, 0.027124094922328368, 0.010346666676923633, 0.04299451109545771, 0.06245088094146922, 0.03625219593232032, 0.02719222778978292, 0.029929973461548798, 0.07221797481179237, 0.01011468059004983, 0.018782787337841, 0.062337332346942276, 0.028177050335216336, 0.014446601217059651, 0.06460160264396109, 0.03686433788971044, 0.13035596843110397, 0.12151172035373747, 0.20613053755369037, 0.2513113006716594, 0.23641773266717792, 0.1309597649378702, 0.10943739325739443, 0.10100482191774063, 0.2119934299844317, 0.12125245106290095, 0.11932007662835531, 0.09897223528241739, 0.134170577803161, 0.1253189824637957, 0.16047463665017858, 0.07990211990545504, 0.12272600011783652, 0.24054570647422224, 0.11484523041872308, 0.12217366413096897, 0.19381943566258997, 0.09986455654143356, 0.1546545809833333, 0.1559735555201769, 0.07706502292421646, 0.1726255237008445, 0.11048599597415887, 0.12335733772488311, 0.10603559610899538, 0.15091402310645208, 0.18700623797485605, 0.11923618425498717, 0.09619295160518959, 0.08393636788241565, 0.10953919365420006, 0.15687783277826384, 0.14051881997147575, 0.17459197755670175, 0.1267852881574072, 0.1893834408838302, 0.11107388083473779, 0.12135428856709041, 0.09311790723586455, 0.15631573012797162, 0.15022958483314142, 0.20106738345930353, 0.16777224896941334, 0.22364078467944637, 0.11371661676093936, 0.11862461004056968, 0.2306337156915106, 0.13981777243316174, 0.15512652753386647, 0.16554185771383345, 0.12968900031410158, 0.07633540270035155, 0.21380326099460945, 0.08421443577390164, 0.08776579794357531, 0.1731894668773748, 0.08749907006858848, 0.12077882725861855, 0.1322363776853308, 0.1297925744438544, 0.14462052175076678, 0.25466082093771547, 0.14107644004980102, 0.07397420049528591, 0.1596795886871405, 0.13256972073577344, 0.20203198248054832, 0.17679471638984978, 0.1328456067130901, 0.11029057364794426, 0.08793658838840201, 0.12902369460789487, 0.11743744093109854, 0.08937869264627807, 0.08611725046648644, 0.14267882594140247, 0.1639183354564011, 0.21919842227362096, 0.1144291007949505, 0.15021508326753974, 0.09884750252240337, 0.11391673688194714, 0.16099011758342385, 0.12414544660714455, 0.08482076300424524, 0.08929371673730202, 0.11109327315352857, 0.1428383876918815, 0.0769536042935215, 0.1045273219642695, 0.12097106577130035, 0.18164520064601675, 0.12097872473532334, 0.116985049971845, 0.2244957536458969, 0.11736189771909267, 0.10198224525083788, 0.10349448246415704, 0.14465376996668056, 0.18021566094830632, 0.16040885268012062, 0.1975058316020295, 0.11766586656449363, 0.18242181366076693, 0.11268351008766331, 0.12050593213643879, 0.057543874718248844, 0.08771392924245447, 0.07117326094885357, 0.08035393941099755, 0.13429439772153273, 0.1956982715637423, 0.12955550279002637, 0.15049775247462094, 0.1314462278969586, 0.1671804752550088, 0.277918660431169, 0.1462647202424705, 0.13918139564339072, 0.18959029228426516, 0.20526096312096342, 0.09961184041458182, 0.16782313061412424, 0.08965570668806322, 0.04761566058732569, 0.13177860615542158, 0.12178790319012478, 0.10674681849195622, 0.09004650681163184, 0.1902963567408733, 0.14707155351061374, 0.14274673245381564, 0.1774597549228929, 0.11421931791119277, 0.1824467646656558, 0.18201982195023447, 0.1756305983872153, 0.10834720800630748, 0.13209902099333704, 0.17892481380840763, 0.1381160129676573, 0.06932812597369775, 0.1203530868224334, 0.16638670378597453, 0.1129166928876657, 0.14201507874531671, 0.1259941142052412, 0.09249659604392946, 0.1842253067297861, 0.1392716556438245, 0.10034571314463392, 0.08453207497950643, 0.15169431717367843, 0.1695922770886682, 0.12744909472530708, 0.13515419064788148, 0.13249324983917177, 0.1549443748081103, 0.04426160208822694, 0.11397445370675996, 0.14096519211307168, 0.14026182907400653, 0.0813613306672778, 0.21710056375013664, 0.09480117980274372, 0.06952806055778638, 0.11455404877779074, 0.12216858784086071, 0.09413736581336707, 0.12580701877595857, 0.2541939803631976, 0.17916314711328596], [0.015513273374381242, 0.0035245312119513983, 0.08384399276110344, 0.030196146581147332, 0.010742013382696314, 0.04929091053782031, 0.03534171060891822, 0.033388886295142584, 0.05531169488676824, 0.04895758604106959, 0.013444234300550306, 0.05926196143263951, 0.03430516037042253, 0.08611808909336105, 0.05193212506128475, 0.03503111067402642, 0.02759847015113337, 0.04200471616059076, 0.010428405894344905, 0.0984550325665623, 0.0651328764797654, 0.05407346230640542, 0.040837028427631594, 0.04092639785085339, 0.014709667520946823, 0.024244712221843656, 0.03204078988346737, 0.05657881927618291, 0.03727170274942182, 0.023754926296533085, 0.02708404677832732, 0.055185425881063566, 0.062427518132608384, 0.0210506459188764, 0.01919056594488211, 0.03649370562925469, 0.036324521934147924, 0.02844079106580466, 0.021226735298114363, 0.01588345014170045, 0.07786556278006174, 0.05497629608726129, 0.03736435617611278, 0.05466411908855662, 0.03466134672635235, 0.008954875393101247, 0.029867751800338738, 0.042296677056583576, 0.024824830506986473, 0.020023702782054897, 0.04189124549156986, 0.017465584678575397, 0.03179385879775509, 0.03818650366156362, 0.010803096774907317, 0.10020498710218817, 0.027409103749960195, 0.014052248989173677, 0.04361302067991346, 0.02006409045861801, 0.05391485050495248, 0.03480191320704762, 0.02845048722520005, 0.01372263986922917, 0.06344592286041006, 0.05802938772831112, 0.019157776005158667, 0.040085941582219675, 0.023718408920103684, 0.03275767114246264, 0.04470997431781143, 0.016495419549755752, 0.023485138917749282, 0.03385594209248666, 0.037566060782410204, 0.017815733663155697, 0.03335118519316893, 0.011128460810141405, 0.029212674744485412, 0.05583737663982902, 0.04998183518182486, 0.04207301972201094, 0.00350349665950489, 0.041840571648208424, 0.022191597781784367, 0.011909335607924731, 0.02393108617980033, 0.02878826460801065, 0.04440999080543406, 0.021164422723813914, 0.03311547166958917, 0.03665945689135697, 0.040372811345150694, 0.038106511274236254, 0.058405259551364, 0.04151372610067483, 0.06031438249920029, 0.06388407942722552, 0.03208006062777713, 0.035709652584046125, 0.05822168190206867, 0.04860243127041031, 0.03416793355427217, 0.016911799648369197, 0.005096927379781846, 0.03573837369913235, 0.03959087342082057, 0.04979016070137732, 0.02195377841417212, 0.013392580822255695, 0.049940479002543725, 0.019288792900624685, 0.02025485024205409, 0.1035172886622604, 0.03800241764110979, 0.023522968040197156, 0.03513189061777666, 0.03042284672119422, 0.10380720123066567, 0.01337824716756586, 0.10492230780073442, 0.031017948967928533, 0.010752848738775356, 0.027771230998041574, 0.06713640061207116, 0.09329052336397581, 0.015563080760330195, 0.04776709211000707, 0.04500249182456173, 0.094496980891563, 0.03080114722251892, 0.00778379511757521, 0.10324793358449824, 0.08494793743011542, 0.0365900438191602, 0.044434310984797776, 0.019241916997998487, 0.02100984078424517, 0.048350019424105994, 0.05718597400118597, 0.05256902877590619, 0.017725011675793212, 0.06030349890352227, 0.019731550783035345, 0.0577666860044701, 0.06398701530997641, 0.04959498699463438, 0.0710281562351156, 0.08161050674971193, 0.015204410065052798, 0.058361005285405554, 0.07410346777760424, 0.0264711515410454, 0.043602801306406036, 0.04105081519810483, 0.014604263069486478, 0.017549783187860157, 0.026475387348909862, 0.053745826371596195, 0.05419913388323039, 0.059702786020352505, 0.11243893532082438, 0.0199250379591831, 0.011119324972241884, 0.03609969571698457, 0.045161712187109515, 0.055178308684844524, 0.0720015422848519, 0.032469966463395394, 0.029540082468884066, 0.042700071426224895, 0.04233194391417783, 0.04957144978106953, 0.024334873887710273, 0.053575573983835056, 0.03045950325031299, 0.10887403637752868, 0.03145885704725515, 0.07641245247214101, 0.0315215462615015, 0.06365635883412324, 0.04726408667920623, 0.01153642402641708, 0.06813342406530865, 0.017301983789366204, 0.021389991088653915, 0.02308205068402458, 0.046176250325515866, 0.010985967528540641, 0.08414410243858583, 0.05530143840587698, 0.006513246180475107, 0.07862865386414342, 0.03091195729211904, 0.040580638669780456, 0.015344661132985493, 0.04548861710645724, 0.0411107770196395, 0.04146573141042609, 0.02963958220789209, 0.03307962593680713, 0.015484376926906407, 0.028423320909496397, 0.02402158366749063, 0.04957406214089133, 0.02410853554465575, 0.07238371865241788, 0.03464086716121528, 0.055125041035353206, 0.06396070617483929, 0.014939013417460956, 0.03768409565964248, 0.041816392476903275, 0.031211046516546048, 0.05308639105351176, 0.03263344675360713, 0.03858350813970901, 0.10483230755198747, 0.036314009412308224, 0.04146125625993591, 0.055557286395924166, 0.025786830155993812, 0.04190802173980046, 0.028155670916021336, 0.010301163747499231, 0.02172083310142625, 0.04682420832978096, 0.04328475391957909, 0.04239432513713837, 0.08839254165650345, 0.03752957309188787, 0.03563871810911223, 0.05136546191351954, 0.04916312012937851, 0.09382852105773054, 0.05532923554710578, 0.0403180334251374, 0.01238287499290891, 0.0427656253305031, 0.012970023271918762, 0.010823580978467362, 0.0932277154061012, 0.059131258094566874, 0.09354283130960539, 0.04060573810420465, 0.057865183844114654, 0.018488831919967197, 0.07981422735610977, 0.03829716530162841, 0.03342073556268588, 0.025457127339905128, 0.024460102031298447, 0.032965157079161145, 0.021012874312873464, 0.036673097565653734, 0.03633190630353056, 0.03099537283560494, 0.04250343197782058, 0.1182295499893371, 0.03781639090448152, 0.02501846982340794, 0.020769271759490948, 0.014955300775909564, 0.03398723543796223, 0.026315259710827377, 0.03450669057201594, 0.04639777398551814, 0.03694584796903655, 0.028424671618267894, 0.06600081076612696, 0.05072099571407307, 0.10144710482563823, 0.030454536426987033, 0.03468275026534684, 0.030873701434757095, 0.02559997963544447, 0.02703293321246747, 0.04592258053889964, 0.02737669972702861, 0.04082533218024764, 0.02070188846118981, 0.11356097355019301, 0.013721162995352643, 0.028334669514151756, 0.0027462836169434013, 0.009807396199903451, 0.0342728101531975, 0.056323694880120456, 0.06735917850164697, 0.027538400718185585, 0.002788967776723439, 0.03207247958926018, 0.07242567226057872, 0.019441857148194686, 0.03522547172906343, 0.02499169499060372, 0.06904689653310925, 0.01788086268788902, 0.014911171747371554, 0.03754668330657296, 0.05209974282479379, 0.04024361456686165, 0.06668908594292589, 0.04506417171796784, 0.08084006098215468, 0.05561414975090884, 0.07716546519077383, 0.041792866395553574, 0.013204592032707296, 0.018839307449525222, 0.04965157204424031, 0.061981617254787125, 0.0048789581433084095, 0.03971706079028081, 0.03923650903743692, 0.013729306210734649, 0.0077160347154858755, 0.01405780118147959, 0.02559916698373854, 0.029679912368010264, 0.04696402153058443, 0.11072845562011935, 0.03598633637011517, 0.08107415662379935, 0.09056322713149711, 0.022475849618786015, 0.0528116813802626, 0.004498803664318984, 0.04900741383607965, 0.020667699573095888, 0.015533027490164386, 0.037286478909663856, 0.06511238578241318, 0.013207865831645904, 0.06808781166910194, 0.03122726244328078, 0.030948797502787784, 0.050988870207220316, 0.017761670060281176, 0.06645157642196864, 0.042583639587974176, 0.06144142280390952, 0.020209328758937772, 0.0556265733030159, 0.09262558131013066, 0.06742453944752924, 0.03184136738127563, 0.03932520681701135, 0.053297743579605594, 0.01607106507435674, 0.022489692528324667, 0.02836685089278035, 0.1610206495388411, 0.08214494213461876, 0.17675888550002128, 0.12076182465534657, 0.14283046155469492, 0.11269787806668319, 0.05159755004569888, 0.1444787863874808, 0.14975060272263363, 0.12129567374358885, 0.1382663127151318, 0.13336865755263716, 0.06962303319596685, 0.23174625443061814, 0.0623648808686994, 0.12684525368968025, 0.14314134721644223, 0.274855371681042, 0.10531186853768304, 0.3083446668460965, 0.11392872998840176, 0.10688092457712628, 0.1414846212719567, 0.1762626855634153, 0.12795258255209774, 0.09162488422589377, 0.07312808535061777, 0.2458980309893377, 0.10521933756535873, 0.17932646413100883, 0.09683609678177163, 0.1349874449078925, 0.20740933221532032, 0.09383966069435701, 0.10312884856830351, 0.10745341729489155, 0.08523089607479051, 0.06555647953064181, 0.11255965306190774, 0.16471908311359584, 0.12656055099796504, 0.20732710225274786, 0.1270288907107897, 0.14424512861296535, 0.143595764238853, 0.09341766810393892, 0.15001327847130597, 0.12848146667238325, 0.08192614215658978, 0.10538093280047178, 0.14177690871292725, 0.13407662190729752, 0.09958950919099152, 0.23973351489985362, 0.1437849525245838, 0.16866527526872233, 0.12940615299157798, 0.1587282889522612, 0.12247720253071748, 0.1411307355738245, 0.17972038127481937, 0.13633263210067526, 0.07749860786134377, 0.0958990833896678, 0.12340456058154814, 0.12764635757775977, 0.11516381957335398, 0.26033925998490304, 0.1403119388851337, 0.15767590870382264, 0.15914252609945834, 0.175653456535656, 0.08003733921214007, 0.09798191342270002, 0.13137278496287763, 0.11790065982495435, 0.0849880430905614, 0.1338866024161689, 0.11336900963215157, 0.20560086675686762, 0.12786618171958253, 0.15555970428977162, 0.18068452016450465, 0.1167979248566553, 0.13349903805647045, 0.09340480668470263, 0.09740258552483283, 0.12229322412167676, 0.12201697449199855, 0.09996041233534925, 0.14893057406879961, 0.12758649594616145, 0.1199401039048098, 0.16148608003277332, 0.17814932885812595, 0.19509444537106901, 0.15454600477823988, 0.13949571002740413, 0.14832008338999003, 0.10713631243561395, 0.13596393313491717, 0.14874701126245782, 0.14655724517069757, 0.157674498623237, 0.10519666495383717, 0.1857833715621382, 0.12738026794977486, 0.08864853807608597, 0.09286815227824263, 0.18064931267872453, 0.1918096700683236, 0.1837419014191255, 0.18566094688139856, 0.14442410494666547, 0.17017202801071107, 0.0764676979451906, 0.11519489329657517, 0.10751765759778209, 0.18822318204911426, 0.059444385042297654, 0.1934260973939672, 0.07118659734260291, 0.07914529996924102, 0.09930145941325463, 0.10224790443317033, 0.2730852604145184, 0.2237883978523314, 0.17576322017703205, 0.19712611916474998, 0.1658437930746004, 0.17799727764213458, 0.12605065101524815, 0.20345696539152414, 0.1415119768353179, 0.1476136627024971, 0.1310046945582144, 0.12072604571585543, 0.14287775120465085, 0.10514925656025298, 0.21276173094520345, 0.06917309132404625, 0.11768793061492033, 0.30405843746848404, 0.19340209633810446, 0.1481566476286389, 0.22474814322777092, 0.1361819464364089, 0.12551269785035402, 0.21485681383637711, 0.14099118212470785, 0.14006389828864485, 0.1289742230437696, 0.1379692755290307, 0.11950511630857363, 0.1433035361696966, 0.15585852263029665, 0.1919798890594393, 0.11587767658056691, 0.11285771441180259, 0.16613437357591465, 0.13528703508200124, 0.14470851077931002, 0.15791235695360228, 0.10585563271888532, 0.0945786022930406, 0.17797300941310823, 0.0884006978594698, 0.23735022637993097, 0.2106329397065565, 0.1707094319863245, 0.13872445531887934, 0.18851174390874803, 0.1765751445782371, 0.08468226340482943, 0.09400838796864264, 0.05040080352046061], [0.01896726113045588, 0.009973940632335143, 0.06275685358559713, 0.04056628553371411, 0.02953944422188215, 0.04154985384957399, 0.01245628453034442, 0.03182443899277132, 0.009348860257887281, 0.06109635010943748, 0.05608680876321159, 0.03380533504241612, 0.006023482519594836, 0.01664811457885662, 0.045746023606625386, 0.04254061357642058, 0.0845385019783862, 0.04740090902487282, 0.09877387405140325, 0.03886225138558075, 0.05980541762255598, 0.06341253363643773, 0.03928120117052458, 0.0229809033771744, 0.03386086624232121, 0.046509033054462634, 0.035896269328077324, 0.030913834925740957, 0.02640218004671624, 0.028131996405136306, 0.017137687136710156, 0.033478259429102764, 0.07108165766112506, 0.029320822359295562, 0.013363315156311728, 0.036547095733112656, 0.022214031050680205, 0.026900897719315253, 0.036126279446762055, 0.041239368947572075, 0.07442394940881059, 0.06985675034229644, 0.0367944758181693, 0.03936498593247961, 0.009369561539642746, 0.028839702863479033, 0.027433240247773938, 0.07535852855653502, 0.02030174098763382, 0.01945232885191217, 0.021637384161294904, 0.02378531909926096, 0.07727800446446054, 0.020594863344740588, 0.02892816501116613, 0.09874072231468745, 0.004335534422352794, 0.02707591098442208, 0.017488062476331834, 0.01206163915412617, 0.030247668328229338, 0.06374615870299749, 0.03515527940180618, 0.01652159324294189, 0.03383405986824073, 0.04749274237838108, 0.053192937484709546, 0.028354277055768762, 0.08191975226509385, 0.12123861000873148, 0.014204097042238573, 0.014707762056787033, 0.037579742274829186, 0.060426149939303286, 0.01973428559722379, 0.03115570085356012, 0.028569874666573014, 0.016367252501368057, 0.034379542121314444, 0.04926799672830384, 0.05119141344039235, 0.008215403158828849, 0.04194043132883962, 0.03422728681471199, 0.031689190000179224, 0.029890203622926492, 0.0785587435530033, 0.02105387055053143, 0.1019862231623847, 0.04702223930507898, 0.046519534444087185, 0.039514391392003745, 0.05290486544254236, 0.055499402587884106, 0.023609485760971438, 0.10163287181057967, 0.04832633007026743, 0.03820225945673883, 0.04314207602874376, 0.022855074093968142, 0.06659462538664229, 0.0446985823509749, 0.06193236091348808, 0.007656846582904109, 0.03244843675929587, 0.041185088266502135, 0.02811871196172433, 0.04708194508566521, 0.04729679683805443, 0.009722568720462732, 0.04893583740340546, 0.07582355086924508, 0.055872606390039437, 0.028697438719973434, 0.012658490086323582, 0.055617348407395184, 0.041016991817741655, 0.03464842964604031, 0.017612049377930816, 0.09073755019926466, 0.01946227919688681, 0.0293478587991558, 0.03228006200515665, 0.03659634094219655, 0.0892822357127443, 0.016688765717844944, 0.03911592117219698, 0.08060468884650618, 0.054335484965122305, 0.015383011614176212, 0.029837787587894127, 0.037319619514164515, 0.05100948706967756, 0.010132763018191326, 0.03225707398087252, 0.024754358018981293, 0.024324994046764914, 0.04782331350725144, 0.0539457869308535, 0.009341551030956907, 0.025601109555282164, 0.04569612901832443, 0.0627328673726879, 0.07194493126007728, 0.04185473553661723, 0.048805045007611625, 0.01980276170797879, 0.033100535947596654, 0.031412339230882935, 0.033517567280796356, 0.02050559596682433, 0.01695698345429264, 0.01592517368408153, 0.03260821002186276, 0.036057894249097444, 0.0336343256640248, 0.018854645786632318, 0.04499787937675137, 0.04337583028245717, 0.025585357470845338, 0.020444320543901995, 0.037627065321430564, 0.0447123269259464, 0.054389799042837694, 0.01746827496390324, 0.053199958201730624, 0.008524646818841575, 0.0771605818590615, 0.056722992594586685, 0.029452277121890802, 0.016709493902453687, 0.021495600558409933, 0.01953807473910274, 0.11128812402603216, 0.0654202583245933, 0.07995252657565288, 0.018464031199982855, 0.050124561312259175, 0.05843318656843621, 0.018493971292627975, 0.05554248797125183, 0.06789667153498158, 0.02904155775468098, 0.04238717083353549, 0.08006042742636055, 0.04084555199369788, 0.04840024426812306, 0.03898560746165458, 0.040453612673445605, 0.04275758416042663, 0.006664248649030924, 0.006481222044385504, 0.0761366481310688, 0.04188482591416687, 0.07102334711817093, 0.05211964722548146, 0.10857871355256066, 0.023964980064192787, 0.07850314184906892, 0.028363078927213792, 0.056603299017297104, 0.052153760043438524, 0.028288179528317414, 0.07414404841256328, 0.03780906590691302, 0.016213381168199703, 0.01795673801098019, 0.053810630706720985, 0.035261580924270675, 0.07729986813501455, 0.009523056232865201, 0.037376011605374515, 0.024462059445795603, 0.0315698600752512, 0.036558305873768404, 0.031684544155723415, 0.022844038358016405, 0.0050302481940889265, 0.034725297591648996, 0.04730222935904749, 0.06814386608311906, 0.0869764422532171, 0.04129389824811369, 0.11405942961573601, 0.06376436358550563, 0.04710925983090419, 0.0217447246905067, 0.11133580701425672, 0.013601791324617807, 0.02401825327979168, 0.016900882656045724, 0.025180476950481534, 0.054194128097151406, 0.026442584421602078, 0.015266549162333831, 0.048511150816921145, 0.050826751757995225, 0.021790914106532, 0.056311861335416324, 0.03624504905019421, 0.017260957865801174, 0.016795993069536053, 0.014990947984188097, 0.036097899719607085, 0.03410073208215181, 0.059216935333097354, 0.017277199767704587, 0.020083338058611844, 0.03907187099684961, 0.056438508836436085, 0.028507389542937744, 0.048126540204975754, 0.03620154435338918, 0.02388847391557647, 0.02009260562772397, 0.03699121545650996, 0.043675487249856815, 0.0090308648213977, 0.011264900022069924, 0.005348242239051615, 0.041789608367253095, 0.011415034641686361, 0.029577787281596102, 0.07196208971436135, 0.015978554511093535, 0.014167839417495998, 0.023851422192819882, 0.005089961396151921, 0.13903600891353562, 0.07226625151815824, 0.02115882878570119, 0.044209028346813284, 0.006800949004173162, 0.04742168173834216, 0.027980666927760467, 0.029286136232258286, 0.0771605150657706, 0.010873251067096135, 0.07139546738471836, 0.06510095670819283, 0.034494426581659354, 0.014443171567108948, 0.03710802579007577, 0.024075469154922757, 0.03721542198036332, 0.08354616147698835, 0.017860943444247823, 0.014607747452828335, 0.036164503762847744, 0.038919971921131946, 0.019400129895075224, 0.029476048111973796, 0.020655268599512056, 0.05555214702326339, 0.009098403043026337, 0.03308609746454749, 0.04835570798604749, 0.023775212903274223, 0.023356394849542994, 0.024711233672860544, 0.05829691712278873, 0.05378540139645338, 0.03608694561989978, 0.03549820357875433, 0.019056695491599385, 0.035680582659551874, 0.052155344528728165, 0.029250043735373765, 0.04678965393395629, 0.025625967791711446, 0.015944469523674343, 0.07316422794247046, 0.022633426124230027, 0.05585405269812327, 0.0342566535982769, 0.04362416402727831, 0.002561515284469351, 0.06010777229676023, 0.05825090025609825, 0.10218495546723716, 0.05604145611869171, 0.00444811358647712, 0.03610552157624625, 0.06422588296118192, 0.04989959779777564, 0.059991778325638734, 0.02253383176139323, 0.043485976129886694, 0.04575898150505964, 0.021552642028837, 0.0331341441051336, 0.009733308525028406, 0.04345906956586987, 0.010996594155585626, 0.038645907916361466, 0.015038095698400866, 0.022309614105324727, 0.0164316245354712, 0.03509964430122636, 0.04731275672384072, 0.011062764970120043, 0.03913707609171979, 0.03201066610927228, 0.08947632959461771, 0.06302968191448599, 0.07215072138933465, 0.03540845194947906, 0.03912178784958087, 0.029657063496415503, 0.03447822549787816, 0.06986855791183189, 0.03963702387409285, 0.19674600596772507, 0.14579814684111625, 0.11704252188792452, 0.07633148416061886, 0.1235781934519764, 0.17513960832729936, 0.09548025976982899, 0.10551854924415238, 0.1959156317752786, 0.15509857825236395, 0.12094183257431723, 0.16309741622535512, 0.11554139462532476, 0.13869079150026664, 0.11207831834326498, 0.10814825305715203, 0.2886804845184088, 0.11571629656828009, 0.19744473800528795, 0.23193961358629167, 0.23293511563679203, 0.1417415082687512, 0.18361937283771113, 0.09403399206348695, 0.33299017406534404, 0.2070254785940051, 0.12998505786526948, 0.13309232628671452, 0.12834648485295475, 0.15925533254630864, 0.13045730127487332, 0.16741604777052999, 0.1289589941734448, 0.18765165412332863, 0.09548567002639174, 0.09551359704346396, 0.07836896897060797, 0.21378032863140106, 0.14195975905749947, 0.08657441343530081, 0.11914064758457243, 0.18902107985923067, 0.0790546763164457, 0.09727869139169343, 0.15618949080817401, 0.1606262574205175, 0.12502479512477294, 0.2788414171664044, 0.2798437321325764, 0.16367615782655776, 0.0724051815632265, 0.1471626150305383, 0.1297356517170556, 0.07845622327295132, 0.16964088776148856, 0.20285864593461156, 0.1537442032713443, 0.09419290072401054, 0.07829384878277779, 0.09569997258950025, 0.08322956127813086, 0.0985590742493514, 0.1269112157751806, 0.19525004405295476, 0.19368863955605775, 0.15047369204694405, 0.17365130537655205, 0.10767436207970604, 0.21971332433167845, 0.176263234752696, 0.12740045436657965, 0.10924472429906018, 0.11389994208002463, 0.14535242778947577, 0.23456338763935491, 0.1333524045185186, 0.11898560551344417, 0.10695169577957131, 0.12150668859248981, 0.08817795707727782, 0.127880816871766, 0.16186350665520877, 0.22074026375776157, 0.10077342027216218, 0.07763134097331204, 0.1252961391583085, 0.1820523280184716, 0.16574997076531872, 0.24840919155394658, 0.1721069702762179, 0.20104350114706904, 0.18035503628198057, 0.19204904237994924, 0.29726161155849695, 0.1782695864676498, 0.2781970251817256, 0.1705031594610773, 0.15870822127908468, 0.1550692188902758, 0.12981314677745104, 0.1786324818385765, 0.13606259424705058, 0.15057781536597759, 0.2074271734454669, 0.16247652063611895, 0.11967973623541184, 0.08421042075497098, 0.13351796282222494, 0.13933634123532102, 0.1778450483107008, 0.16197347809793428, 0.11121520801680163, 0.13210619013989344, 0.1376079980400391, 0.07020803110208362, 0.11669919695123099, 0.10978813967085443, 0.15985638310667127, 0.14618669083574787, 0.30060326505918056, 0.11188201286131516, 0.22719953121850267, 0.13313090312294662, 0.15408291947096586, 0.21019225241616368, 0.16522457473911345, 0.19256864965427667, 0.14000905357534066, 0.12644118396565318, 0.21509059035452083, 0.19550169148715213, 0.1520212777541019, 0.15657986048609018, 0.13237186416517943, 0.1445033514755778, 0.13710076978895813, 0.07616158429300413, 0.17113287176471204, 0.14066656673094258, 0.18333180545596406, 0.1265234881429933, 0.08804293815046549, 0.09608657215721905, 0.2803734177723527, 0.15457934205187485, 0.11618405740591697, 0.15415015805047005, 0.2587485109688714, 0.1239935215562582, 0.17896882316563278, 0.14192838105373085, 0.1493030579877086, 0.11781970635638572, 0.11270054237684235, 0.09639410331146792, 0.15561444510240108, 0.15808487660251558, 0.14111884636804461, 0.17435641988413408, 0.13520790729671717, 0.2775095886318013, 0.10621883979183622, 0.1162960845977068, 0.13822783977957442, 0.17746481637004763, 0.145112773461733, 0.15707940008724108, 0.18516689917305484, 0.11797256651334465, 0.12875359738245606, 0.05067658559710253, 0.12371329401503317, 0.0831723416922614, 0.2265526307746768, 0.20002355275209993, 0.15177381603280082], [0.037236120479064994, 0.016840199095895514, 0.03650382852356415, 0.091687862877734, 0.021954928743070923, 0.02011935448535951, 0.0638810514647048, 0.01273672451134189, 0.05693145816621836, 0.051602214443846606, 0.028005202329950407, 0.026829375092347618, 0.06118761571997311, 0.02445905931381276, 0.05442379682790488, 0.052871958614559844, 0.08258092420874164, 0.03495894794468768, 0.03254821109294426, 0.01942219209013274, 0.010889471632253844, 0.02956921176519245, 0.031705509827588685, 0.0701321242377162, 0.034379820426693186, 0.030180656103766523, 0.09350706721306778, 0.03602523975132499, 0.03937947636586614, 0.017030825292749796, 0.031412131429533474, 0.02167009803088149, 0.023083356863935478, 0.03121613393886946, 0.04287099916837178, 0.04819441703148186, 0.016793527283880394, 0.054099177723401226, 0.02179754705139203, 0.04659552294469904, 0.006884200347485603, 0.06361107298289426, 0.0323006566031836, 0.042558402856229804, 0.09797882608836517, 0.028901065488753375, 0.01279124639040674, 0.07937626374769025, 0.06574426515726373, 0.07550390044343658, 0.0434528429468628, 0.03137584040814545, 0.02118668158800574, 0.015364424525614595, 0.08580164474551566, 0.047313702962128446, 0.017279515268455725, 0.023504492273787037, 0.07153470913181081, 0.023706989122729283, 0.012779006519849645, 0.04117286138352938, 0.08710340887773782, 0.028324926970526576, 0.024766911446931772, 0.03909008330083452, 0.025251250008295756, 0.002370386050642992, 0.021662470608134754, 0.04182398464763537, 0.07388747311779298, 0.039471955387853086, 0.03304985097202007, 0.04767997881572228, 0.04603818859322928, 0.06257276385440491, 0.09414087617187761, 0.027211020824324805, 0.04507133715378586, 0.007620190981469932, 0.04423200894962065, 0.05816790217068046, 0.07509472474339418, 0.08145692670950666, 0.09468065502005629, 0.04977421194780618, 0.07806135618011467, 0.03796020428126212, 0.033135995763586834, 0.03108624881861033, 0.09119060909142718, 0.050536208364064805, 0.01792296658095438, 0.06463801240897737, 0.04771304520545527, 0.055295452984864824, 0.039479573533753864, 0.03513981675496325, 0.02810388385114493, 0.045078743787598796, 0.03563931182725355, 0.033794670380302705, 0.03357325062097516, 0.01620918803382665, 0.030572539762943052, 0.018317757603654172, 0.012224095280544134, 0.039592253815499134, 0.13155282998923212, 0.027520464864210226, 0.020367582474136725, 0.014056713935133303, 0.02497871668310836, 0.00984742857326637, 0.02009095249377424, 0.06735990580637008, 0.026823150328709744, 0.0828104185347911, 0.03978641820140183, 0.01601615542313084, 0.07909987310995348, 0.05645306606311351, 0.03018482882907847, 0.03408887627301738, 0.013529502430174034, 0.07086152181727812, 0.02161282092856709, 0.03302028009784408, 0.0301241805209429, 0.03351815357746091, 0.03957469089073129, 0.10557456655078568, 0.047595422220183536, 0.026493876102904323, 0.02418731637590099, 0.025542067996866535, 0.04366694513009861, 0.03414037390029989, 0.05332566688593943, 0.015483087445318233, 0.08456838826532476, 0.02667563734576106, 0.018402301211608574, 0.04526904900558293, 0.039573915346409194, 0.03556617317372002, 0.09529585833661258, 0.02896871967095649, 0.04778257331054192, 0.07182694462244399, 0.04351925032096915, 0.09150902013061568, 0.11611656649620272, 0.040165915415855125, 0.021582624794973526, 0.031814839312573895, 0.014423443426494487, 0.007413652210743749, 0.055749929379089735, 0.02365066382481018, 0.01929384878167184, 0.022972543083596975, 0.021302697823557537, 0.023154937007348053, 0.04303868001443334, 0.054836056151543744, 0.025429558409086894, 0.08668548325658776, 0.07247921079397202, 0.020083939198229928, 0.01901398860354675, 0.09697693414636888, 0.08267321769380942, 0.006961131375646801, 0.04542418755590916, 0.06982299004448578, 0.03810988062468823, 0.03978295608249027, 0.010400942719570594, 0.007391841418211698, 0.09012493697809987, 0.046485243510687724, 0.03835961331787985, 0.010103132772201207, 0.031281561678042635, 0.027886540337931365, 0.1484608688042499, 0.07042454526526853, 0.041751083481358364, 0.030179670902725775, 0.08033103673369624, 0.06244443909963593, 0.05738663217925932, 0.026468696887604892, 0.04193062755803112, 0.013510593435057672, 0.05018581447075121, 0.029139760590624064, 0.014749564452358754, 0.04204988697892986, 0.02482587136910297, 0.02678599841601681, 0.07179483189247549, 0.05763493994891178, 0.023955313590704463, 0.05748787225456908, 0.03750461095478386, 0.030115315566945355, 0.06164838923723437, 0.048050065597635694, 0.05221336192335002, 0.05651261599268764, 0.026230946168652736, 0.09437422966584563, 0.031672836776124313, 0.05635202265693806, 0.0352333125192672, 0.04620037383574527, 0.06314129350357689, 0.010050269593193661, 0.05264014136628248, 0.05231304719927721, 0.015846288952161558, 0.020184670902381185, 0.08833613101160154, 0.04620343890564982, 0.03209468093700707, 0.04298514519177843, 0.03442257184360642, 0.02292380067956401, 0.11686518570058979, 0.03424533213546965, 0.022196690770215355, 0.04484449600568041, 0.02926524477516068, 0.06929023191332817, 0.016132924938574433, 0.00918417676075478, 0.08933937366236933, 0.007345863514274242, 0.018248264750582166, 0.05023008729040157, 0.034744816075544804, 0.02215719552623341, 0.06579107241122983, 0.02689476757950615, 0.07246811568620615, 0.021766477038909215, 0.009900885470415233, 0.06626040660194121, 0.0505883739242563, 0.03650860053312499, 0.04114741685043555, 0.014045008410903392, 0.045948592814966105, 0.06722450096276589, 0.018940939007734414, 0.12477743730414659, 0.01991668137634406, 0.07737216816167347, 0.027376983598514926, 0.03258933349570725, 0.05157301093277056, 0.0479408659884939, 0.025897990890371148, 0.04197402835416142, 0.036942011065548286, 0.04145271785091609, 0.0895793322706595, 0.03029770392458886, 0.045079912670189515, 0.07038427633233368, 0.07231694762594998, 0.035355533109395765, 0.0675412941200193, 0.010209721876890399, 0.05747453215008136, 0.052241767625673674, 0.020076191176485736, 0.035833876972901635, 0.05621937118121423, 0.03423014408326708, 0.0798016479529906, 0.021288537645887118, 0.09181422836263664, 0.07523974782088771, 0.03615658133639954, 0.00987991608781158, 0.055811186248320155, 0.03900326686562039, 0.039339352151728235, 0.009692864259704947, 0.03621556723373942, 0.0238811192321009, 0.044603372225537896, 0.008455605748167727, 0.011324992647132603, 0.035327635778230615, 0.02943492385384161, 0.038865049282321706, 0.05690899335604627, 0.014576902867702302, 0.07996604108484462, 0.03957983397413045, 0.02479695172951324, 0.05374404150643386, 0.037290427135303617, 0.07118302761227824, 0.011816456753876992, 0.046959780156612396, 0.03684884555696044, 0.04708577456767671, 0.028188778123876546, 0.011259583461651346, 0.06363166015944444, 0.01798189310648013, 0.017146858226624317, 0.038326788126141764, 0.017894072916533332, 0.10354817684856243, 0.02255192717711907, 0.007933320248412201, 0.05535482108825818, 0.039321551739703864, 0.019956235992140137, 0.03270021035859827, 0.03856760020426009, 0.02173709170165239, 0.022829499685030896, 0.004991808191334712, 0.04213608001009561, 0.036481545539572835, 0.050332730024820194, 0.015534325320913922, 0.053703308731201105, 0.002802885364872054, 0.02474883644026704, 0.006543245181092061, 0.07492604199796915, 0.05465559181175195, 0.06211716681718826, 0.04073385505762417, 0.06409633366274647, 0.026132348139071837, 0.01908658363390714, 0.025611022792872973, 0.0563963437161874, 0.03238489407522138, 0.036938040575478226, 0.043477497092681006, 0.04683151106291916, 0.038093360417406075, 0.15835440979572013, 0.11839786166092381, 0.1928987420978956, 0.13872332725441083, 0.2261348016327247, 0.13661665201652795, 0.11030459281755611, 0.05520711143617518, 0.12224632038851269, 0.09412716128281318, 0.2922359062358737, 0.2164425904629752, 0.10449167661136016, 0.11626340783550404, 0.22310649772407487, 0.1981959250406362, 0.12898363347630948, 0.08875329964212142, 0.11284005871857516, 0.10331175828468986, 0.07788375281961635, 0.14570793136954308, 0.0914028262195643, 0.1188320477376692, 0.18430299474857748, 0.21691088564693928, 0.24590549699496478, 0.19674879644298926, 0.12129968134104274, 0.1368022186215967, 0.09239954539225437, 0.06481364165665582, 0.1581334724323824, 0.09404205178725533, 0.19300265761557966, 0.12211634064442478, 0.05714103695936501, 0.1737064024200663, 0.0929497588367667, 0.09514598161331378, 0.1363913805107586, 0.16451123723527417, 0.1389862404903397, 0.054226556239882484, 0.1628565596183762, 0.15409694606205449, 0.07323573387111537, 0.23120654979720712, 0.151816712168511, 0.1665741702890955, 0.11869711786857806, 0.12813691719202325, 0.20231187605531886, 0.14010802638949826, 0.19613392709288746, 0.08390743896597996, 0.08346664777491242, 0.15253067307639867, 0.14604839903768152, 0.17647345550358295, 0.10862327952054329, 0.1192895372514613, 0.1827826607041061, 0.08651826996356249, 0.14641522779129446, 0.12077761013642885, 0.14533218200085685, 0.08451547313597985, 0.14249977539293468, 0.1717822509817779, 0.1512354621081613, 0.10890112476772629, 0.09839114107307978, 0.24345529644051567, 0.10867551187402569, 0.1488497096579522, 0.1699291230761446, 0.10337228784919716, 0.08984278727439232, 0.1369430188788101, 0.1908404697314836, 0.15186192380497232, 0.1043326492072083, 0.13463810115354136, 0.28394184191711247, 0.08203556441003457, 0.26110515638720244, 0.11867896493640728, 0.09440325506147929, 0.14094340265728533, 0.21027605573181063, 0.10684878958272748, 0.14606738317525014, 0.11383520453819074, 0.1848759624408558, 0.11536666337633505, 0.1351939994492568, 0.3141147462883964, 0.12820077157812193, 0.127137184899766, 0.24703670816961676, 0.1040093474148307, 0.15896954631898552, 0.13237317034509033, 0.14602353709051386, 0.09097089627175592, 0.12736233766190708, 0.09915789094520733, 0.23520193150034174, 0.1666881493292749, 0.1327002645120956, 0.12228394727571867, 0.061080059967935085, 0.14633630780735984, 0.19105563318589702, 0.08171044435584918, 0.13405585661530495, 0.13392857828876004, 0.10305269679520279, 0.10996791752404533, 0.1791952078929171, 0.12944238464115188, 0.1175727641384583, 0.128882909193635, 0.17933725495822728, 0.14080368593567982, 0.1415269830613397, 0.13320433121407405, 0.11773315709433518, 0.17635019961744547, 0.23201675241580233, 0.1639350040932186, 0.07132947561331093, 0.1102231717959512, 0.11747006574296393, 0.11404837903683074, 0.09942154632881284, 0.13137550122337416, 0.14272618980612606, 0.07252946903463453, 0.21635256794979796, 0.14664547168649733, 0.11476699321065098, 0.16264715522993356, 0.16429484181571752, 0.11458362336270511, 0.19217373803257942, 0.10526805213885382, 0.07632335764355958, 0.09961409654351883, 0.12722300685709342, 0.18861699529225007, 0.13820630265399814, 0.14817221788689494, 0.09578406534274109, 0.12316578198806383, 0.10318435379303992, 0.14925092953490093, 0.1381968625355512, 0.06481848045950755, 0.10722576349508017, 0.07489365467336029, 0.13877538149245083, 0.15568618109682575, 0.13761289621470496, 0.15514919272391126, 0.10480874436325394, 0.16979636769974604, 0.18940793175715953, 0.13208144693635404, 0.10982197418343276, 0.1899122804752551, 0.14133049204247072, 0.09662613578257151, 0.13870040973415598, 0.09975839231628925], [0.008410432146774838, 0.05296925788570661, 0.05471171301905997, 0.12223057943629101, 0.04571244884573389, 0.025715595111250877, 0.026320638426113874, 0.08275656829937361, 0.03619440860347822, 0.060639242801698856, 0.018976734645548277, 0.0923856820736546, 0.05079727365227882, 0.05288812630169559, 0.04547190394077916, 0.10142314087715931, 0.009281003840442281, 0.0563207411323674, 0.05718152482586447, 0.01566495073348051, 0.03699813598359469, 0.02318964910955401, 0.029289407248143107, 0.023069087219482753, 0.008731249599804869, 0.037391010409919545, 0.030625323161075357, 0.01114893851990928, 0.07768764771753922, 0.007059150530039915, 0.038336877623805776, 0.03774149336095434, 0.019136214759782888, 0.03720197426446248, 0.10012501326855272, 0.0437107912148349, 0.05035525420680642, 0.08503945166012272, 0.02293725025083404, 0.042144518229179084, 0.049826882168417796, 0.06842803442850709, 0.06310205615591258, 0.025171380075335037, 0.04966213280567899, 0.023352159041678533, 0.06999127203016542, 0.025013161612150725, 0.05706876290787477, 0.008524454788130242, 0.00986567427389673, 0.03402148555323947, 0.009649784442444798, 0.009546590663376264, 0.01729161598632345, 0.053496872933465056, 0.04051467287354171, 0.03562235375284217, 0.05065911544079427, 0.07361181720625609, 0.07262757353601046, 0.02767585017863894, 0.09078219780349173, 0.03308522173028905, 0.04685877756855916, 0.03439906060521025, 0.06368788526742719, 0.025704670697450638, 0.02552896909037372, 0.050285496035940014, 0.005975593121547718, 0.0554128013754962, 0.05264061263005715, 0.011705842425726587, 0.05887775529117789, 0.045235789657454006, 0.08417925797402859, 0.07684480544412509, 0.03499491613183636, 0.051776222098851576, 0.0659323031140957, 0.10721696904511191, 0.051015906647080556, 0.035944698174716905, 0.0596893086185446, 0.06277728491113521, 0.05644789329380728, 0.017781225651560817, 0.010218342849839246, 0.07905829799710773, 0.0779188415617682, 0.07586721883853897, 0.02669766985491151, 0.027776847200584598, 0.019611860916484147, 0.10481362769496627, 0.06620924294111319, 0.11744190866011195, 0.029172292634029873, 0.0690563366515562, 0.02643989042553585, 0.026963017335219774, 0.04631341405911371, 0.02177161270083161, 0.037381644506240264, 0.03599779884098098, 0.023567849420942366, 0.02565451079135528, 0.0388083937286865, 0.044035770260961726, 0.018815616240317468, 0.022552442969754338, 0.036545670809573494, 0.05162437868420966, 0.05881152603251394, 0.0378594651556341, 0.05017520918045193, 0.017182776318804827, 0.021431358400150202, 0.06275979991187342, 0.07063978293444961, 0.03346981749928091, 0.007518959719163831, 0.062394180858973414, 0.08513764521921985, 0.015525016005994985, 0.027140075217175763, 0.011875729305756977, 0.040644971741130576, 0.02024215951678343, 0.005862451316716033, 0.017145320125564467, 0.02912664869654691, 0.06712228496326134, 0.04137955322221387, 0.055684093458694406, 0.029853025735064875, 0.03864425663778093, 0.07103346259100363, 0.14145143242785707, 0.062487928953487426, 0.021713242786063347, 0.13461978494888172, 0.05560745557886548, 0.0356281016865978, 0.04673548086429946, 0.007298823875316884, 0.06702393555315211, 0.034885211862274446, 0.055298403021879494, 0.05090648810437415, 0.04834976338315755, 0.04409184322867077, 0.03459390405623708, 0.026704156225605402, 0.06224792581633665, 0.021943165702396072, 0.02792044720990816, 0.06831556936958805, 0.036046925306436606, 0.01777916248101974, 0.011221195873076795, 0.03399606699531432, 0.0501509372406872, 0.035214450836065225, 0.06839648573077284, 0.03213542855519336, 0.045766703551635146, 0.03984934861364309, 0.0188383166823769, 0.05528864749066997, 0.021062327323306818, 0.051345579777262174, 0.034681047036428936, 0.0479022668878315, 0.041709415600053035, 0.03858855474391021, 0.045970489882165566, 0.045244246430229396, 0.05436079220089596, 0.02971250007249182, 0.0033426470508857165, 0.03500287937640678, 0.09556873861583881, 0.032739418020355515, 0.04779684852110222, 0.03004319551109802, 0.06279842127696611, 0.12585775199113414, 0.07081478877807967, 0.036830006138188764, 0.06185733720485587, 0.050916054387926124, 0.04812937149836216, 0.057066714580287226, 0.07304557337192819, 0.07787639071466401, 0.06560301218996756, 0.03387924181879498, 0.024484470450261142, 0.02012372759054415, 0.006642936023126822, 0.06458591364207678, 0.02394961946265539, 0.014372915229614591, 0.038963224287726916, 0.022283277139649726, 0.01699142281722743, 0.03594925125071313, 0.06434831506339833, 0.030288549532997422, 0.024417730965069495, 0.05289829372486565, 0.0603141153260367, 0.007477792787540238, 0.06415519339498132, 0.040472381588188, 0.03911930907634087, 0.08788536535575986, 0.019068000256083906, 0.040674568590475246, 0.01795303283870453, 0.03330925384943839, 0.037483400374185294, 0.06724468737957068, 0.02860118587705074, 0.029649627176695503, 0.05154883176146541, 0.039142371315392666, 0.034100097545888275, 0.028449669007386547, 0.027941511216340587, 0.07589375803945586, 0.0612282297515776, 0.04517286295595113, 0.0067304505409993, 0.043112865096190944, 0.02813950508425478, 0.05420968351245392, 0.04474469198612496, 0.024743583890085574, 0.01714427740807878, 0.1392463780939579, 0.016906159326026682, 0.06141047895653173, 0.03709682678163517, 0.018486121225578245, 0.03487625042907894, 0.011339445045450702, 0.0378401433408726, 0.01691325054707704, 0.011566495850274805, 0.009885758645395981, 0.05223238687904086, 0.038037049962440506, 0.06249276775633916, 0.0411732324573677, 0.08451145069557242, 0.010168987246288452, 0.015109403102542274, 0.015751613173051737, 0.013693324108317029, 0.08291346573969349, 0.01080432224625838, 0.04016899903945159, 0.012131069852330256, 0.05618410432361998, 0.05362376163247973, 0.04197243273665663, 0.028726592136081308, 0.05922023417952005, 0.045995355540071614, 0.042402859835419804, 0.028246032961760648, 0.025842791801551357, 0.05988664568576496, 0.04438861695234664, 0.03628018603194505, 0.024645779958518688, 0.003601187181629939, 0.06570931742317043, 0.02684904757188633, 0.058244951942469925, 0.025152234520646743, 0.028708192439808045, 0.03888115759764332, 0.036543455498758703, 0.05114394567499403, 0.007690900492889341, 0.07267683729878627, 0.03162190318107605, 0.05249117377388757, 0.014069727494643303, 0.019287414361315314, 0.012698812824964989, 0.025560545618645847, 0.11162733004312031, 0.01974983730178792, 0.025920574444171507, 0.015562898934149416, 0.03830522131465841, 0.008270908383565256, 0.0005176331035272597, 0.04184286117379088, 0.03814329582382925, 0.027219767034694087, 0.028619001132028643, 0.020115046318096574, 0.04410032226587646, 0.022685994299536105, 0.009147634336841293, 0.030002689090906642, 0.017437924834666774, 0.03948792640585452, 0.053719843781436794, 0.08648802002426237, 0.01907678357383702, 0.024690017526154406, 0.0476450718997512, 0.04001377885288093, 0.07795494704623707, 0.0256215297486051, 0.029240011754154693, 0.04493188018386718, 0.03844557999400422, 0.020002020937681664, 0.055343032072414644, 0.021166790174902417, 0.11296548909740523, 0.047816860533203, 0.03785344262723811, 0.008660749281261815, 0.012046886185999028, 0.05851132358657196, 0.1107240398414433, 0.045579326106235385, 0.012245903290022397, 0.029653931633220054, 0.050716238547465764, 0.02064736843749415, 0.006476351236415212, 0.005623347105938592, 0.06499844384961762, 0.016278539878840093, 0.026439654793648515, 0.04608459508745, 0.014749872443644563, 0.038385176594601944, 0.01691980000032345, 0.03477858379483223, 0.029981437692185864, 0.06191871281771455, 0.17677116062259302, 0.2397305314661935, 0.13335038587683812, 0.27225818135775626, 0.13848601811332628, 0.0939937231305521, 0.07276706019183621, 0.22984157694736496, 0.2749852178385481, 0.11744799427106045, 0.1278041084879078, 0.1337930918089114, 0.20109744044020772, 0.21259685541735962, 0.17555225727846846, 0.1821138520608656, 0.07228689806652255, 0.14605405420297757, 0.22133488731924444, 0.13458502275170758, 0.1708005231921561, 0.09055225076735951, 0.13144048367394134, 0.10945054411422461, 0.11281367536867037, 0.06972610266529955, 0.14992249896749854, 0.1240345549013, 0.16634980420349166, 0.14888855366734788, 0.14909507852280512, 0.14436105208005756, 0.12197576303151436, 0.2388302024337463, 0.16777713230112568, 0.11530136180226691, 0.1323765842244029, 0.20459611754631624, 0.16913331812247634, 0.23770764470100403, 0.17703582532703876, 0.16027180769015104, 0.2202267272514291, 0.11761899251723662, 0.12342801244813018, 0.12910706747788936, 0.17186911194585264, 0.15098828240297735, 0.24008830601815134, 0.13813400262733921, 0.0676417957583908, 0.1646029666881077, 0.08324936919962056, 0.12178664896055125, 0.15394130285130814, 0.24163768772268668, 0.19667695654788986, 0.15530681004747748, 0.11913425027159974, 0.17433903878554702, 0.26385730714537203, 0.13223136076703668, 0.16950327873928472, 0.142651351634413, 0.17426961829187348, 0.15748021920444444, 0.18138185696443543, 0.13811120385071263, 0.11271272844169289, 0.12675325706368312, 0.22673405619570985, 0.27621614397503436, 0.146226633223705, 0.13738286012085155, 0.10214989641099237, 0.1663733896566555, 0.2210091141751036, 0.1383166154846549, 0.11499016443849541, 0.1434208548744209, 0.13773606304312125, 0.14782136015128344, 0.13039200712228194, 0.10994690732331946, 0.1613604641170241, 0.1452582047204487, 0.1351594302104786, 0.1360173083958216, 0.10548887075856328, 0.25556285690981895, 0.22777954931370914, 0.29106022557243705, 0.15052484086481854, 0.07508503971621394, 0.11935106871533208, 0.1688794294022955, 0.24940145784057677, 0.28537694772239774, 0.1265660280478187, 0.18611803563544527, 0.1285377808380872, 0.11407369369408116, 0.1409760126261972, 0.12461268051993102, 0.189604185288772, 0.07363815602730028, 0.1390503768925555, 0.07226116780657321, 0.13452912418870255, 0.09224787267157808, 0.09531568852253258, 0.06528084588353522, 0.07369694896624424, 0.18979886546730995, 0.1534192168037407, 0.15174160682363436, 0.2209137036697939, 0.08153655173373409, 0.09786695474758744, 0.18344063399126753, 0.1885995251359418, 0.2057958289515227, 0.09727213822770864, 0.11009857262251899, 0.19478038331726566, 0.0653768797928933, 0.09808891627471894, 0.10545309181907214, 0.14786247513256967, 0.09492635785136372, 0.05097538167319726, 0.1424306072294712, 0.16884845215827227, 0.11231245109229349, 0.08627177303424105, 0.14816613227594644, 0.07796408288413659, 0.18034011911367998, 0.1361111010191962, 0.2831816452089697, 0.16705693735275418, 0.1422564103268087, 0.23313521349336952, 0.11803838016930968, 0.20873376895906404, 0.11824609246104956, 0.09847534514847212, 0.12800287047866732, 0.18888353020884097, 0.07357200840488076, 0.17005744040943682, 0.18402636662358418, 0.14370371703989804, 0.07273356706718914, 0.14025801443494856, 0.12942282162839547, 0.19347438152180985, 0.10608851123834029, 0.15190723934210837, 0.15870887436904013, 0.13307720131706446, 0.09537926089251414, 0.1791516289813444, 0.10450526533531956, 0.1116213780187536, 0.10741184960352257, 0.15199030051007867, 0.13049329543719068, 0.18517843214794993, 0.07217367601697333, 0.1274534288677387, 0.14189260953571647, 0.2139949132106267, 0.0868027500109747, 0.15945845836540684, 0.1349282660521567], [0.05376880326366518, 0.06513998625450768, 0.0353803579491796, 0.028733854051097296, 0.04844461727770977, 0.039365998964058235, 0.013558687387558166, 0.03900984600477386, 0.07928984065074474, 0.055370068512274884, 0.06220553434104659, 0.04398654731630813, 0.032685285768820904, 0.051681820914382115, 0.06532152299769223, 0.06325747672235593, 0.06712480826536193, 0.010628498184814816, 0.03009457253938308, 0.026142803144466598, 0.01766509623848833, 0.05117193948535714, 0.03451415657764301, 0.029336706174944993, 0.01283590883758734, 0.032537535298615694, 0.03089865615038434, 0.043009513610741124, 0.015431499832629925, 0.048396106794825755, 0.07618825708050281, 0.043349736370146275, 0.01904055563500151, 0.0982491162721999, 0.021421734600153286, 0.07337319446378388, 0.009090621624636697, 0.025414396332053002, 0.027050759599660523, 0.019852198020089418, 0.0323470000148518, 0.05994564271531999, 0.023066274479788262, 0.022428430092986673, 0.07122774943127297, 0.015198948785837274, 0.014735745662619593, 0.08126245433231816, 0.01800062120310031, 0.07236516496050172, 0.041121434260276146, 0.0019507720435285592, 0.022120650319266133, 0.04327320981246885, 0.011962467815465061, 0.02900484556448646, 0.038866793329361826, 0.007583302995044505, 0.03000185974087799, 0.025613932011765428, 0.02654995463672094, 0.04556705098366365, 0.02545330899010878, 0.027559230948099867, 0.02400127108558081, 0.03409173725231085, 0.007432638667523861, 0.029840297902410384, 0.034555215897853486, 0.029669503746845294, 0.053401544064399786, 0.06045821442967281, 0.051004741035285406, 0.013032497263338882, 0.03029798037459841, 0.049494325794512406, 0.04712525682407431, 0.1276320341276005, 0.10465399172971956, 0.11021770216757432, 0.008207485370803624, 0.0585738383961143, 0.04025366324640345, 0.01631544131669216, 0.07883039186708629, 0.026158440196013544, 0.03172677235852461, 0.03792780211369973, 0.05236145749222487, 0.01808084922231501, 0.05144723174453247, 0.02272025369165931, 0.07284741994226351, 0.05502831321791746, 0.05554049901547842, 0.03721744433278218, 0.0279310617770534, 0.012462283866625512, 0.023540261936432216, 0.07181942666647956, 0.06157978881674353, 0.015993714732758235, 0.06788029975723475, 0.010658671126293484, 0.022671004771837033, 0.046552333660656586, 0.022840893507236615, 0.032901009544730186, 0.04472408625588287, 0.042081851279363036, 0.10092080337926745, 0.017557030259922612, 0.10748479529866017, 0.030375731475942302, 0.07026089428109117, 0.040620287909405306, 0.019100142671959475, 0.05073506683402229, 0.04957517907314468, 0.025518940819893032, 0.03320122312288731, 0.00317415819154121, 0.007038980347715551, 0.026136164633498993, 0.0628968671662733, 0.06037552433554083, 0.043570054040174, 0.030188979289960116, 0.032627138498355635, 0.02789983591355849, 0.006559527437275392, 0.035206268657930195, 0.039907469908939674, 0.003963912786275614, 0.042084259548573755, 0.07197342973086052, 0.03388719764188863, 0.052912387109245174, 0.05721866189560387, 0.037079052344779484, 0.026747976335173007, 0.022404130322684068, 0.0384282768209232, 0.030763271715841256, 0.03437340827076696, 0.05329803672793787, 0.06727501153363846, 0.04407486288982909, 0.04391214330098592, 0.07105019059963524, 0.012545272675197339, 0.05315047179465182, 0.024369853163079824, 0.05243278530542739, 0.028304553161433432, 0.04200666429824196, 0.04735515933134593, 0.052760565959033556, 0.02970959456433775, 0.027984099360764958, 0.12290656464756466, 0.04709174143499695, 0.01018963008391438, 0.0170005920517724, 0.0659300915140193, 0.08610343167674728, 0.03264615974330809, 0.029386500573309604, 0.019715171583811752, 0.031246918224496767, 0.02612346834212076, 0.02208938734838739, 0.05478716717334464, 0.038048775895731524, 0.017734106695570517, 0.03400887275347486, 0.007051220218272647, 0.06927245747647248, 0.0481508306984324, 0.08343636814970523, 0.015820135668036528, 0.025906560840667225, 0.01857663541159127, 0.07084343567839824, 0.04153695161221549, 0.06489240578957833, 0.07187978553702123, 0.02941324572020676, 0.013632133104692912, 0.023273298429558054, 0.03547959051502403, 0.0217728984716814, 0.025385333829035517, 0.013773599439446116, 0.05722018700907938, 0.07508134382078424, 0.019369594228919595, 0.06494230779935606, 0.009141087666648673, 0.04292019613785669, 0.018110394121322315, 0.024546248678234406, 0.08547796445782296, 0.07399921829346567, 0.018486800290702377, 0.008940624302340439, 0.03284910002548713, 0.0353791408269899, 0.06125917730969377, 0.004282522349967621, 0.0295416242806823, 0.07595428760396317, 0.008245111330325017, 0.003406489145163505, 0.006029615442457725, 0.0548476188123459, 0.017078038872568868, 0.008360046813322697, 0.011464033086667769, 0.010368056300649187, 0.03394365652638953, 0.01775678672856884, 0.01912697873194702, 0.04704239974671509, 0.028891955626022536, 0.05519223879673518, 0.060072947017033584, 0.056897961330832914, 0.021622825079248287, 0.1388736566877924, 0.024731911762501113, 0.03651151346275583, 0.034645757914404385, 0.08439961646217853, 0.012671533331740648, 0.04859636050241534, 0.03335654349939432, 0.03160641084832605, 0.041198754915967584, 0.0400807799451286, 0.05420831796072889, 0.02299025443790015, 0.021535698797379155, 0.009426852557226084, 0.041275240655522794, 0.023954766256792936, 0.10030082063167356, 0.029261253876029514, 0.017380684839736205, 0.03508133922878187, 0.030779849439568352, 0.0346935596462572, 0.024068606144282967, 0.04086619854206219, 0.032089385713334195, 0.012190074303362053, 0.030274174132500775, 0.04532050952548161, 0.10523458870011382, 0.05638654365611728, 0.026575976189633366, 0.04233916872180998, 0.06352708413032815, 0.030965369660407305, 0.08232466061599553, 0.04306293711124454, 0.05076540583104361, 0.03462865141045768, 0.028527462782221846, 0.02735357811616268, 0.07358402377576567, 0.04724695420009084, 0.04487056765356101, 0.04177522554527968, 0.02852963727491442, 0.05093765088531654, 0.038803881470812485, 0.03754306904738769, 0.04183877936156932, 0.013136278266756563, 0.039927726829773746, 0.04374548290797975, 0.025230297324014828, 0.006545861715494539, 0.10232427885057405, 0.0425244755751919, 0.07752905075903982, 0.03343546348332893, 0.05803643442050088, 0.025425727071706206, 0.07696725238929503, 0.006413968621927779, 0.028290383706917055, 0.06316398837952875, 0.04118726275919471, 0.07419855173793621, 0.020052392355864868, 0.016087173389678355, 0.07124234747607261, 0.050029529302264564, 0.08081945896265097, 0.04676457305322401, 0.022327433071041014, 0.04311013770347927, 0.041168389943777584, 0.0361269993300084, 0.028490622571553104, 0.0322701135155512, 0.01664876766881207, 0.028962164651602507, 0.028577533630596008, 0.025035765575012192, 0.07702257207711227, 0.050545284830150194, 0.008733782178751426, 0.08126685526804067, 0.0484464912005933, 0.026284605301043484, 0.04344459026469849, 0.03638074704213068, 0.053323896863730624, 0.03194841476215515, 0.06378531441441737, 0.044941791566088796, 0.04055489356687758, 0.06204365337907802, 0.041044477256946266, 0.04978436081728432, 0.03584650832635816, 0.05521189086721279, 0.05525844208023045, 0.03798560799623374, 0.02361928953177994, 0.04626976093277335, 0.006279669578361791, 0.05941750074271113, 0.04446261649718508, 0.03231260518077761, 0.05407698750786949, 0.028133610576333012, 0.04380417194624897, 0.02809211338899331, 0.042033110730699264, 0.041147183073917404, 0.029580392219941132, 0.032019968930399045, 0.0462170313403476, 0.04847303782298695, 0.01387103879096685, 0.03155261256324593, 0.03478547092527151, 0.027113497053505853, 0.14111810422036797, 0.12336593179497868, 0.123401005694177, 0.22985870571574196, 0.09325560531578958, 0.09902454927214421, 0.08999431156553328, 0.10270080747432075, 0.19807412376394495, 0.19909677357645705, 0.15961466560838744, 0.11430423444835469, 0.10045097194961272, 0.15178650675807148, 0.10901831730734557, 0.17818164196796715, 0.1369428407633677, 0.10230718718958087, 0.09392704858328216, 0.15041673963423818, 0.13047805172391236, 0.16685673559550196, 0.06502406278741546, 0.12883134477306157, 0.08597259846283123, 0.09375885565532371, 0.16080668836366385, 0.12574417371070012, 0.09828447218751535, 0.08586277544964105, 0.16805910388939083, 0.11243420784012415, 0.12504746031481773, 0.21441906545078382, 0.12491656030761078, 0.3069627581862733, 0.09439742920221761, 0.12285862190765329, 0.07751277546049096, 0.12350215300102718, 0.11556932164239697, 0.11174444094649516, 0.20162029832135886, 0.13139632588718086, 0.1068964354635682, 0.07794098724843934, 0.16393985773902386, 0.16415370017057285, 0.1155013038078323, 0.22637504967860878, 0.11090711283031851, 0.1607129699550569, 0.0993673547054641, 0.22115087922429666, 0.11588649329496548, 0.12766505969921127, 0.15602829633280635, 0.14099750522291288, 0.08945513385697268, 0.15300748811569065, 0.12588720041094348, 0.18181616178480908, 0.05791571667941753, 0.12100851454306394, 0.1402217976283282, 0.09115533481235616, 0.08975611926871352, 0.08521179319359362, 0.1025019415828865, 0.08516842208337039, 0.17932391114300117, 0.1204286894062534, 0.09487543167779222, 0.12497284478740767, 0.11784099857322872, 0.08774491390795447, 0.14912663464201614, 0.17055586678907275, 0.1853298896458, 0.26626614038832486, 0.10288673031027429, 0.1439194890554063, 0.1748302366468124, 0.1824971119640395, 0.15445639786776155, 0.10678429694962688, 0.09893530601402745, 0.08567005454096943, 0.19897194433724508, 0.09786752620129846, 0.11566336659598164, 0.0923502074147109, 0.17801798356231302, 0.08467614810797386, 0.15974446723703295, 0.09262837178539485, 0.16632451181067154, 0.17107802705140784, 0.15811119315912947, 0.2150955330580473, 0.1361036646994762, 0.08691090319189243, 0.1475357817253098, 0.07330739565077238, 0.1081246453395579, 0.12108020600862801, 0.12612252059625462, 0.056036075548036024, 0.22572840156499296, 0.1602780565735884, 0.28599019919056445, 0.16609551472356543, 0.2501628716709092, 0.17106956656789407, 0.16435663303127512, 0.0893029490543995, 0.1355762203456834, 0.10687199654057622, 0.1083167502656579, 0.16117722785566002, 0.12790797947673127, 0.14304289390565827, 0.11315072173601948, 0.14674787322292104, 0.1341218187008053, 0.11017157026799396, 0.13585002830950543, 0.14781479956582189, 0.12982938496861607, 0.1608210414997302, 0.11191926125320606, 0.08281257818453014, 0.12930107972351834, 0.08989657813799568, 0.1490560860838741, 0.18650598591193557, 0.24873548420146108, 0.09782819979591295, 0.11608613101998344, 0.21226389828370884, 0.18171830219216645, 0.10303154558641836, 0.09616607843781821, 0.1195731564075686, 0.0837919236801099, 0.1575065654469654, 0.15362229809397832, 0.09838081037742086, 0.17654366267379373, 0.22477290127426386, 0.06960330691072159, 0.18907194666098803, 0.10061283435788937, 0.13817021943395957, 0.17383509082719684, 0.22445165523095056, 0.1260000217007473, 0.08417879784246907, 0.08451755114947446, 0.18788715242408216, 0.3116931184194982, 0.10552659412496723, 0.16094009683001786, 0.11172504862770438, 0.1312452246202156, 0.30831958225462586, 0.13633920752909034, 0.09655643327278085, 0.1778140413807705, 0.1058960500813555, 0.13377188122831285, 0.12252032873220742, 0.13287407549796626, 0.10428379362565465, 0.07086880228598602, 0.10068937946925871], [0.08611717625171877, 0.02576266026153462, 0.050074124956154265, 0.012224705697008176, 0.030255915444286074, 0.018190015434811357, 0.03158094405080192, 0.0542847814358538, 0.0898909526586067, 0.06281684138230048, 0.021557742438744754, 0.052577455862774514, 0.06864306429633871, 0.009799318850127747, 0.0742508731491398, 0.012221264914842322, 0.04735512593470048, 0.054439868035842665, 0.05112485021527391, 0.0723014515824616, 0.049163431831402704, 0.031468994784518145, 0.029179409830248915, 0.07031090761302039, 0.007701228405494476, 0.039382303948514163, 0.04584589441947173, 0.03310677369881887, 0.057338871265528724, 0.014073489255679306, 0.019118585041724145, 0.016589475635555573, 0.004590791013470152, 0.06454935544752516, 0.007681653796680621, 0.02699595755984774, 0.044034070742782205, 0.04819669542484917, 0.014927783795428695, 0.04520672344369814, 0.006746626577296411, 0.07701994487433694, 0.07378413647529669, 0.04940932762110606, 0.04498603469983209, 0.013278749283927027, 0.03460462437942624, 0.0011586321397771826, 0.050326674099778756, 0.03657183151517529, 0.0359510954876896, 0.06592197983991355, 0.030489391392620746, 0.042378324433229864, 0.035877782429452054, 0.03169175783114042, 0.017156151770905126, 0.0219191460928414, 0.07029204221908003, 0.010526700571062975, 0.025258292989747133, 0.04697519456385635, 0.013194116618251428, 0.09073795838048682, 0.04368399597296957, 0.09824925728025846, 0.015355799841927364, 0.01866173006419558, 0.029108560702297837, 0.02809720823279349, 0.053333466858020984, 0.05292798705340829, 0.10047227158793248, 0.05112691338581499, 0.02914766260801116, 0.011085838341386989, 0.02699065677006729, 0.044321263339952566, 0.01796393498807447, 0.03222906161681749, 0.010506373146199621, 0.0306513410032494, 0.01669530218350701, 0.043325260339770466, 0.020342711250123102, 0.051388616921030916, 0.03580239506845828, 0.022852921865705866, 0.001524592464647867, 0.0847452568996232, 0.007775065141686355, 0.024434219631075393, 0.016809422231744975, 0.0274783535496681, 0.028568256784637924, 0.011269890965195373, 0.03878179515595548, 0.030063111044000834, 0.0559439898643177, 0.006614800277020549, 0.031370600845548324, 0.04524080657574814, 0.061756887516821735, 0.039690521589363925, 0.062388236256083474, 0.06216683133970946, 0.022014686473994516, 0.024184999019780662, 0.005271774125503725, 0.07631910513737239, 0.02070227808872005, 0.056966127594932914, 0.046901573514332995, 0.058828725304920226, 0.024352479485969525, 0.0386472066747956, 0.03216548924683593, 0.04764494573464617, 0.047914241440594196, 0.023992931201064494, 0.029720756465394516, 0.08931531323469244, 0.031134902164922096, 0.022109625715529546, 0.03088481509621488, 0.03329871535243001, 0.10149590845685452, 0.006510710354632465, 0.020990450320823584, 0.058303399782744236, 0.03498868580209091, 0.01958412685780786, 0.022944530719541945, 0.07505514600779861, 0.028689911487163045, 0.028007128203171305, 0.051399289004621096, 0.05070951840025373, 0.038055076729506254, 0.04616245008946862, 0.0766866686171852, 0.0361494196113199, 0.06415102994651534, 0.04788704543898348, 0.08424180618021637, 0.041081796152866445, 0.013076632785669062, 0.016859994029800873, 0.08366281967028044, 0.03914443448593374, 0.022494349504995625, 0.08823095384286717, 0.013914956307417015, 0.031028494886413682, 0.03431493074458558, 0.062351447995752096, 0.06939374667126685, 0.0991565921867732, 0.027645986156130675, 0.08180669348803349, 0.04013478974229656, 0.028437700020731427, 0.026169401717197616, 0.0483158249699045, 0.047382819175254554, 0.023040423620841466, 0.035411030912655406, 0.012114026430936065, 0.01897788682981627, 0.01558122348797042, 0.034805074756150134, 0.047867578905425034, 0.06045019923476502, 0.08667340851388872, 0.023802312425686978, 0.009066948969120858, 0.049156362874782644, 0.012131175608374178, 0.05721493260352872, 0.050169639362138696, 0.024034543421294075, 0.08396149700274691, 0.057661594182718545, 0.08614976395620033, 0.031080291228136048, 0.015060682035255013, 0.015322723247663816, 0.04647589987143874, 0.06972895251237787, 0.032820998603710905, 0.06410864589270204, 0.032438707203255035, 0.031913095954223536, 0.041696368643897586, 0.026483619622013066, 0.05878638206922915, 0.021045935136498883, 0.07301708232262172, 0.0824100521276705, 0.05227071880653966, 0.05873078778677154, 0.02530755675252294, 0.07107772427843884, 0.06733300295309164, 0.02580689782917034, 0.056213467396446504, 0.014765101313969353, 0.04399498182465322, 0.04432112975337077, 0.0103852500069479, 0.031034489584271796, 0.04003841444500722, 0.02744229630479822, 0.01747230111504905, 0.07358948598266579, 0.013692643187823705, 0.007548921148554655, 0.07272163333254866, 0.0012844266348110978, 0.0443634173279861, 0.04092373725143261, 0.08444864273769781, 0.06676019853330217, 0.10024294053437188, 0.04918499122140929, 0.022782375162933022, 0.030248020848375745, 0.028112793334003072, 0.06613461999222636, 0.05628462080494501, 0.06237887035240419, 0.022831659334769938, 0.07029172309557907, 0.016055199812399223, 0.15204703027848154, 0.026104779208253603, 0.08814922854071483, 0.046064657290116884, 0.045968445265316404, 0.039532718728878535, 0.015517755018663593, 0.055053820833563805, 0.0358369383320678, 0.07628243562066928, 0.028371691551001277, 0.04095811353181489, 0.06588131756871007, 0.06486302416305989, 0.05741053675592411, 0.03799863639869727, 0.06623197492444888, 0.03904422228515614, 0.024692572369531263, 0.08218059490900487, 0.03928415862901602, 0.040727873347350396, 0.01635117758269189, 0.04365334527392406, 0.019967525913671125, 0.029443733146763407, 0.01366831929772161, 0.01669096247496782, 0.0025603524318285054, 0.02456829974107677, 0.055279548760154285, 0.02406353727565147, 0.0607800356374355, 0.07191771670477465, 0.022005032988090534, 0.029232221058919095, 0.03573685229639523, 0.021842298556293827, 0.01077402128430549, 0.011598979654081631, 0.03477760787063744, 0.022966023316257633, 0.02952240451122634, 0.03465488633082714, 0.02131916793587152, 0.05642218158754986, 0.02219123412942281, 0.030740923793928232, 0.04529528392595239, 0.0382895768416347, 0.01657688510022126, 0.06829713442130014, 0.034889353046310134, 0.03742367975064553, 0.03255559546232689, 0.056943176678032614, 0.0178829258584301, 0.018614269720274024, 0.04986434578313492, 0.05435742285044398, 0.06248012898140587, 0.004450690694284276, 0.006057754899302381, 0.12391218959237449, 0.01944490180903813, 0.05384692172810901, 0.028776596191164572, 0.07728619777481072, 0.06388018315192312, 0.06714904680848122, 0.018776215620164294, 0.056228766770800576, 0.007751592866043211, 0.04837689259147737, 0.00880137420608662, 0.012465154122764943, 0.012335898900346365, 0.017413881105312612, 0.06424773921025917, 0.030045299499761313, 0.032020670259953476, 0.02223814713943284, 0.04083998588612303, 0.014600034683098784, 0.035704706169781275, 0.050082125308108516, 0.02778707585093798, 0.01406518647854682, 0.07597824413096532, 0.007809339840605389, 0.10270684855640866, 0.037334429071052, 0.04694522292993497, 0.06123833780293353, 0.013871699302399065, 0.02856641440303065, 0.023096158911357634, 0.08600897854194045, 0.0027092940490547335, 0.06282078218646348, 0.058788912792806514, 0.05356304653105326, 0.02443551282340195, 0.03235745687561575, 0.018458726699464023, 0.03005019581905799, 0.0075275523977325065, 0.03410605699173175, 0.06089196263928898, 0.03338413283927366, 0.01790152778994525, 0.05174731915758457, 0.018966520838148426, 0.06767108832718804, 0.047890908317640424, 0.030444656586041674, 0.09536713419947773, 0.06912685552379116, 0.18152513599488884, 0.12828925042413175, 0.15167718840530142, 0.15673988236812875, 0.08541189847164787, 0.18294009991222993, 0.09790455937036313, 0.12597520428244025, 0.18016694637481123, 0.12142001316533424, 0.07929269791929983, 0.15073653106810525, 0.1481041926308535, 0.12395895231748, 0.18037139321677387, 0.13735185319092125, 0.10729742527473718, 0.15310240880353376, 0.15153788728639483, 0.14028335135662928, 0.1401809201342985, 0.20162394968792796, 0.13803630630718544, 0.2318576953257434, 0.2459671546239406, 0.11292500494164415, 0.23861422261688858, 0.16211064183153212, 0.0947867301874794, 0.12445158252376132, 0.08195815098588355, 0.16592768544796854, 0.13084729987895116, 0.14411780575755984, 0.09764173519215547, 0.12452243536245078, 0.16324719646945596, 0.2750697039300576, 0.17563837609486654, 0.15135825786273926, 0.08021995206945576, 0.15987867722287774, 0.1411017621285282, 0.10445585314300843, 0.1635358325438574, 0.0872890793834813, 0.07328317195060663, 0.1267813250888139, 0.19526917662005872, 0.08421197926509194, 0.19570598989957944, 0.14187818218488246, 0.18028410180704668, 0.07745662456727587, 0.1103809078631457, 0.22143584908917546, 0.1209022018883843, 0.15700407209806144, 0.1938679424347356, 0.16487226239405572, 0.12371047385386191, 0.14092832221649587, 0.10100918574607931, 0.1560226411675103, 0.21386312262620777, 0.21245142415864393, 0.11650526634184644, 0.22965022159041837, 0.14295914996182546, 0.14325430209282786, 0.16232761612627655, 0.13298177596880123, 0.28355176909826696, 0.08676179830217734, 0.1321818001451902, 0.11696140514686704, 0.1581549650290981, 0.19542608148185536, 0.17705681326333433, 0.12790245789801702, 0.12278330876142718, 0.11975602901657112, 0.11321381913148798, 0.1337437389884144, 0.16765519743785262, 0.10475864939508028, 0.15424329758388922, 0.09636205737479031, 0.10128514593816362, 0.1708377938484773, 0.16346897988114506, 0.1581464006449096, 0.1246132593951188, 0.08605007868027315, 0.1593687030253932, 0.12618665699847043, 0.12024569063214585, 0.11864037325722165, 0.18260692013427615, 0.13115866051521152, 0.07414928055368364, 0.0882186416129116, 0.20224557258188725, 0.14797802752582356, 0.27252191095612943, 0.1603038387838751, 0.10699378297431394, 0.13648897293023765, 0.06983021114137955, 0.1881866090116091, 0.19684560218593106, 0.12086634131264873, 0.09123245137743652, 0.1312090820283629, 0.1299685673438944, 0.18296549620572478, 0.11298261786578223, 0.15037373959785327, 0.11770827288273722, 0.0693336252879817, 0.0886682495183777, 0.1851758049451746, 0.08730033776373602, 0.22147522744489834, 0.07636394569999538, 0.1202898558403831, 0.33455779775977135, 0.1997901769937016, 0.156023413001094, 0.2027100679697469, 0.06382648876751773, 0.12298983361688443, 0.09037958268891089, 0.12896423373604193, 0.18866291939048097, 0.09676036061136983, 0.10521887001232244, 0.12004426433122717, 0.0913795895758085, 0.08936108890338801, 0.1441934157628566, 0.06630477219005115, 0.18200585473095998, 0.2201259881258011, 0.20845742285018787, 0.1350802430533804, 0.18067049357341602, 0.11460943525889888, 0.18316575733479112, 0.1140371651854366, 0.10756141462479718, 0.1775213680230081, 0.10856496897758916, 0.16418552346294746, 0.11075634552980773, 0.10829247461515479, 0.1388967374805361, 0.11921175275347196, 0.2222127144341357, 0.12080760774551891, 0.18897389410994947, 0.0802569258667063, 0.21304146124748513, 0.13764719828031957, 0.1370701933046803, 0.13701549702091143, 0.12016228065476753, 0.07769598203594796, 0.09011922986246645, 0.10621657624142244, 0.0984200625680387, 0.20150523574557155, 0.16102346970001236, 0.15850874682655558, 0.3323920030379668, 0.2768825035309419], [0.04302749955968466, 0.03483000720734708, 0.038981124889687635, 0.011978910097241169, 0.018038329726550728, 0.036827345538767986, 0.015548739684163593, 0.017424341676814947, 0.0055444966983486665, 0.05521586506802123, 0.014940456894692034, 0.07075125351548195, 0.028485783768701367, 0.04469722793146502, 0.0479364168131724, 0.024552653412683867, 0.030995113083918113, 0.021472627377079334, 0.031104732006497215, 0.049369021580787376, 0.015072920978127513, 0.06673384486930445, 0.04372330382466316, 0.016900539412745275, 0.05534776326385327, 0.017819860004237853, 0.03291371882369276, 0.04868239026109222, 0.04533934894425329, 0.03780148115765769, 0.0617457181942882, 0.025414494666620158, 0.033080809662351385, 0.009818629532674095, 0.0440269461250864, 0.0727824894420337, 0.10137245219084434, 0.040861048037186265, 0.06160468044981826, 0.04725684331788216, 0.06380419465131126, 0.05816826582304202, 0.03566611820133403, 0.019572942692320794, 0.018073911996907555, 0.02174155571992742, 0.014990640920586884, 0.04489725899475161, 0.03180504667398054, 0.04691170383011922, 0.0017329716456515598, 0.03299149961094372, 0.003099990735790925, 0.032639669661875814, 0.007900615655671572, 0.04123537248233333, 0.04483996890485287, 0.02841509605786996, 0.02226123720902251, 0.043145801610080525, 0.07605885621160269, 0.040258698718389496, 0.07322906938497908, 0.031729952461319044, 0.021271492369123735, 0.012534767574834405, 0.02415036113234237, 0.07396522050839849, 0.030584291671402752, 0.056298973941011354, 0.027811338513856754, 0.018666683899937198, 0.013609887228085427, 0.025790681902435608, 0.05612200511677656, 0.041826214801403694, 0.06531829465529881, 0.11440498841693625, 0.053804834533366375, 0.04886358561634552, 0.025291927122452762, 0.04105969870579429, 0.05092994368169457, 0.14571933075785637, 0.03529584588250145, 0.0795315061986912, 0.03361480718012899, 0.06231236649909988, 0.03886637030518614, 0.03832143724139314, 0.04839067056309432, 0.006737381736456882, 0.06676115590380505, 0.0598237820668146, 0.05183259563636966, 0.04390225047245622, 0.015162505624175537, 0.015286350590031361, 0.06821600283728912, 0.05869892367627472, 0.014437593399634352, 0.03736287930223625, 0.013521291493816534, 0.04076960060046986, 0.04289310774765909, 0.025728386026457883, 0.04622130611096509, 0.034409198342473246, 0.023892002827778924, 0.0266825337530463, 0.04783332136867102, 0.07677348505239934, 0.037400947767309844, 0.09348860257887281, 0.03798857287620194, 0.032009341375669464, 0.019720811906154267, 0.04202088384772651, 0.034417161587043665, 0.03256426003645174, 0.033716095495037735, 0.05069403719971888, 0.04477738730201963, 0.08496825001202524, 0.08478046438540332, 0.011649451262201183, 0.02423204561637249, 0.034561928623588756, 0.030507455267070327, 0.023883531212050002, 0.00918831330636749, 0.024017872929107398, 0.008111585975711932, 0.036859810788882896, 0.07714277031482197, 0.04339617626101244, 0.023893585457699373, 0.03476847203273792, 0.047328301006928086, 0.06582423156942241, 0.01897221867693588, 0.045514005978475325, 0.03790283255511895, 0.015173185129242484, 0.020953020102751907, 0.01799275072698947, 0.06688633395242505, 0.05956848326604813, 0.040294904392794706, 0.022872154622746166, 0.019144402504025493, 0.012689823561231606, 0.04067709560331423, 0.024238029182015453, 0.03821375532425009, 0.0549324945313856, 0.011352170095051406, 0.005001500639991718, 0.041767644506762736, 0.04434494527231436, 0.04897530852758791, 0.032209617347689345, 0.023087240151653532, 0.020127364114159718, 0.037399982975330204, 0.03842915997665841, 0.06472907392890193, 0.06700343001284637, 0.03731510354555212, 0.04162839162745513, 0.048410656600026414, 0.06753572801244445, 0.03667599565233104, 0.11933592890272848, 0.042304421367589384, 0.0435291097528534, 0.08791017535259016, 0.06880624772747979, 0.047056990370037965, 0.02343663029023446, 0.016650255674903747, 0.048002211915445514, 0.038928039066377096, 0.02396334362856578, 0.05811183662444819, 0.042562822345644236, 0.03196315010427497, 0.027475078823044896, 0.0165840913541615, 0.053206912125460804, 0.005776719808636699, 0.05313177709467709, 0.013829177951265592, 0.011120764738734579, 0.0589474244043231, 0.017523887800052762, 0.01791321104974486, 0.02088803579681553, 0.10541998461121693, 0.029047977332083974, 0.016938513253990095, 0.025023085981956683, 0.04169212726992555, 0.005728251535401796, 0.07034422262222506, 0.00815518436866114, 0.036753223539562896, 0.04071911229402758, 0.037099376058904454, 0.03410757468373049, 0.04897339749732055, 0.04885515110800043, 0.0193762104754569, 0.016836885406519286, 0.03663406801933888, 0.023854194114392158, 0.026774471007229295, 0.028481180597736966, 0.03215831267880276, 0.022293216352409218, 0.016109077878354583, 0.05198118473344948, 0.12555721186799929, 0.06929858107469045, 0.05037302493292373, 0.023921427127788775, 0.007335798136409721, 0.011677628754114266, 0.05605787613603752, 0.010802915876411134, 0.057755212401389144, 0.024623023855383508, 0.0665271641628351, 0.0274046323102084, 0.025755966089491267, 0.036786204582313076, 0.020295790818636306, 0.019540544235496782, 0.02500109614629764, 0.049320043544867076, 0.03296540198789444, 0.07742625588434748, 0.026694139087339863, 0.04089553563972004, 0.05141020970768295, 0.10384182241978124, 0.04104102627024986, 0.059201272306381725, 0.017576676764292642, 0.029368677896854933, 0.05680869951902423, 0.07187531780800782, 0.013644172595377313, 0.024133163715305272, 0.020094943392905407, 0.02108405555190984, 0.04959736928867642, 0.032839912237250246, 0.03837522068351973, 0.026040917400678154, 0.015509532950090943, 0.028061668635928072, 0.04934247124765534, 0.013448583285935456, 0.07291787202120759, 0.03023007942829281, 0.06340958731016144, 0.014572968557331478, 0.02465262256009737, 0.05001528377761133, 0.029158188117435202, 0.05561858037253842, 0.05657515306666028, 0.012843433287343942, 0.043736699590226635, 0.08841062037390657, 0.038956014323048294, 0.04256828084180597, 0.07598576950840652, 0.029925767339591403, 0.09441444664844312, 0.025289357436122373, 0.05301953468006104, 0.04038492690597195, 0.02729905809246702, 0.03145567323372234, 0.051825289192493074, 0.022015469439793378, 0.030440890186582692, 0.024338228395208716, 0.02583331828645896, 0.0460808101342991, 0.04504309101321269, 0.04531000813585706, 0.014222186891856836, 0.020566363018588163, 0.03861011042317841, 0.011499858410388697, 0.054555279421037994, 0.023358446887868922, 0.07745741124381311, 0.01892615357064642, 0.03184976478223689, 0.019455744586593937, 0.03174531120748725, 0.0370957358245505, 0.0076405272193369456, 0.05788061309431214, 0.03467406342679169, 0.033985487680183724, 0.032650445646140724, 0.04236274675349705, 0.09221713291481137, 0.04569110467855353, 0.020430791191756725, 0.02351536473724991, 0.02917505527875619, 0.02207721056038281, 0.046003181487321854, 0.016244909456872847, 0.1081086669000797, 0.018978025982505642, 0.02603348850243492, 0.06761818804079667, 0.04818208624783438, 0.026485881317057647, 0.05173221274162643, 0.022736397258995567, 0.06496590809547342, 0.027707897970685735, 0.06819673668360338, 0.003736607332029962, 0.04212380859826226, 0.0558819982688874, 0.03519109915941954, 0.03872503941238392, 0.02389487679465674, 0.024371725230594166, 0.028717812529066578, 0.030649628497485537, 0.023465802260034252, 0.05355335037165787, 0.06491280000773259, 0.04839092289330438, 0.04582144436426461, 0.0388083491998259, 0.05240495847829152, 0.04677559023548383, 0.050876683453680016, 0.027566082826524507, 0.01847312436439097, 0.06896904524182901, 0.1719113698345609, 0.1579168692114763, 0.13854460325092077, 0.1467998235602863, 0.095663466345286, 0.11691102816257626, 0.19176773872459307, 0.15263277775375172, 0.09751383346156217, 0.16947768948739395, 0.16897292516659945, 0.1655755512183532, 0.241300722991582, 0.11228988980292343, 0.10046608949778602, 0.10337914529372938, 0.12410841343807988, 0.10400280909379944, 0.1620318109053187, 0.10959104751236737, 0.12810553918825462, 0.10002270821132697, 0.21684147999621928, 0.09497335806372575, 0.133936905185692, 0.1113079022616148, 0.15364643273642287, 0.07536673670983873, 0.16757890465669334, 0.11947075487114489, 0.16921062022447586, 0.10270464437780902, 0.17169191676657647, 0.13387563347350806, 0.13617629127111286, 0.19123275415040553, 0.19464382814476267, 0.1654602659982629, 0.1407380058662966, 0.10184728569583967, 0.2833795017795637, 0.08513670269167051, 0.12052156918798573, 0.17037415935192257, 0.11972402760875411, 0.09924520461936481, 0.16666824492858723, 0.11631135799689218, 0.16985060385195538, 0.11280375285423361, 0.0677137469756417, 0.15530232747551054, 0.1550456482800655, 0.09334332717116922, 0.19674244365887716, 0.14809260028414428, 0.12419800550560467, 0.169574613973964, 0.12260174233233556, 0.0935484271030873, 0.20263951941160485, 0.09450123339775018, 0.14199242839822546, 0.14081486267969012, 0.08061861895839684, 0.17428698454750702, 0.13729822559980676, 0.10377662474638782, 0.10263787335134111, 0.20645343116484582, 0.10124605702003464, 0.12118468555854633, 0.06485978097771294, 0.13989489641971886, 0.19048686604946852, 0.15931574336718768, 0.14335155312437564, 0.15102212433703244, 0.1681526144966483, 0.1894484381773509, 0.11854656579089351, 0.10854473803192377, 0.14657124207587913, 0.19696629024110734, 0.09877416348899715, 0.11056775838369504, 0.20196314086206257, 0.11954158544540405, 0.19369539309991524, 0.09870835725450888, 0.19631550094345585, 0.07355419686064124, 0.17077775410143659, 0.22385409276466817, 0.1265380045515485, 0.1953059426159598, 0.15736242552520707, 0.08168642103555612, 0.10207352941506542, 0.21858371619600803, 0.1288019260391593, 0.11579472673474811, 0.10794366520713083, 0.16760501341195777, 0.3306962252827361, 0.13116786314640194, 0.13764182513114065, 0.15599157486576587, 0.11952591128647327, 0.15523255075095221, 0.11654434783849865, 0.16151128336787224, 0.0853082501271274, 0.17657533753663301, 0.07605374281411059, 0.10651935765054077, 0.11991638486506417, 0.15465244359802455, 0.12202818834339269, 0.0836534686095547, 0.12101997330319136, 0.06402531755156815, 0.15993442735634744, 0.23268210265086964, 0.16296767396852374, 0.15759590518428013, 0.07393605410470627, 0.1493016627500765, 0.12660030042752624, 0.13983408483909443, 0.08232384425355121, 0.242589685076382, 0.07522232219344005, 0.0888655791641213, 0.15690100262872875, 0.18866429978515953, 0.1435861163190566, 0.13226820097770542, 0.15858777071116492, 0.23147724074078724, 0.051989199928357266, 0.15413296991027892, 0.24799706210615113, 0.09145739633822814, 0.13709551538340747, 0.0892461153853219, 0.12868901569163427, 0.17012874595820904, 0.15719851478934288, 0.1540559795103036, 0.17654217837844044, 0.12022119233733974, 0.07696274013142101, 0.14240837248507887, 0.12029749996145256, 0.07814159718691371, 0.10563452466158196, 0.08158514014212415, 0.1031278318259865, 0.1662105179275386, 0.1231124957848806, 0.15599445439875126, 0.10138371057109907, 0.1809785739169456, 0.13839785096934065, 0.20493107847869396, 0.17414425470633432, 0.14864156692055985, 0.20898752409266308, 0.15187473327387124, 0.11200644876225851, 0.1411142450524494, 0.18254269467433915, 0.14930277597159147, 0.09722163507831283, 0.17697682458674535], [0.021225627642706968, 0.046598936824011616, 0.050418054743204266, 0.0926216553489212, 0.037936796943540685, 0.021079975595057476, 0.03516395510814618, 0.06782377036870457, 0.029357143066590652, 0.04366183915408328, 0.03852165384159889, 0.06723676124238409, 0.059298760825186037, 0.02878499544749502, 0.06632967866607942, 0.026030380759038962, 0.09293478971812874, 0.03015601309016347, 0.03863242680381518, 0.03300291755294893, 0.0601498965988867, 0.03131780445983168, 0.10165043102460913, 0.06701875536236912, 0.03225426495191641, 0.038303711044136435, 0.05361102637834847, 0.030613261405960657, 0.05214990087551996, 0.07277054828591645, 0.06259771485929377, 0.05446640723675955, 0.04202151838399004, 0.026270383896189742, 0.01511361107986886, 0.11353453824995086, 0.0034417328106428613, 0.02115763763868017, 0.03285730446805246, 0.027300414367346093, 0.06650539697147906, 0.01919586673466256, 0.008008751210581977, 0.0512849759979872, 0.03858784228214063, 0.047152478800853714, 0.062137516506481916, 0.0204373258020496, 0.010447141412441852, 0.03212887910194695, 0.04481809039134532, 0.025432187467231415, 0.019921933926525526, 0.04589957025018521, 0.030054479866521433, 0.0630553305381909, 0.053529898505075835, 0.0253713499114383, 0.017136150891019497, 0.012452664705051575, 0.04153304049395956, 0.06608084397157654, 0.07401665876386687, 0.03040281244466314, 0.044679008206003346, 0.005625258600048255, 0.01946890100953169, 0.0272328882056172, 0.0036055120472155977, 0.016485268824908417, 0.03786758425121661, 0.07363362150499597, 0.03721096909430344, 0.040444936967105605, 0.054305865851347335, 0.012690364401350962, 0.06538025656482205, 0.09245589666534215, 0.05116137501318008, 0.07257206088979729, 0.06715551091474481, 0.03831238303973805, 0.0027617564683168894, 0.0465723159868503, 0.07940802024677396, 0.0495943190617254, 0.1152446617197711, 0.0539533568371553, 0.02762837684713304, 0.02804742311127484, 0.0466125960520003, 0.05102565846755169, 0.01701058507023845, 0.05001856407034211, 0.0137345179427939, 0.020024300210934598, 0.0370747107808711, 0.0415458017232595, 0.02968513894302305, 0.027172438421985134, 0.014681145858048694, 0.03367980076291133, 0.03896834881743416, 0.042337138947914355, 0.08882005582563579, 0.023850015822972637, 0.020502896404650528, 0.008393977805098984, 0.005121557405800559, 0.05571020221395884, 0.020016524358652532, 0.02687866483029211, 0.08617602114100009, 0.03161356144119054, 0.055007102637318894, 0.035117192383040674, 0.05911687527259346, 0.05256154792732559, 0.060969732294324785, 0.029807385508320294, 0.023522298251918983, 0.045703138603130355, 0.035184200896765105, 0.02617277106764959, 0.05805288041301537, 0.011559182912606047, 0.09455648629227653, 0.14282433141488582, 0.044541952083818614, 0.019797004497377202, 0.013428064758045366, 0.08126055443426594, 0.018221907375846058, 0.0340068281366257, 0.04102055783732794, 0.020443173925741576, 0.04767327722220216, 0.05429176875622943, 0.05788061680505052, 0.03628864280472044, 0.04278681364667136, 0.06073145465052221, 0.06838739442173392, 0.03350495819177013, 0.04236156673869118, 0.013853904456482269, 0.08312439895235002, 0.06745808452251367, 0.09151708727586083, 0.07870188157539815, 0.008874639024725184, 0.05201032145123463, 0.00752362550883845, 0.05682956500095315, 0.056388395314570516, 0.04188563485513441, 0.048271377745550126, 0.038594517900492065, 0.030176834043231793, 0.045734546292806044, 0.09250677831005305, 0.01479456828747061, 0.04035170466522686, 0.042677187302615494, 0.049596975950407796, 0.015185794218268711, 0.013363784564717207, 0.02308249968336895, 0.005493401222338434, 0.05785801098681986, 0.0226762127931579, 0.017284036803175695, 0.03070083483180497, 0.030593282790505327, 0.03700074092193972, 0.03745162903214805, 0.022671835977234878, 0.026615705210133456, 0.03324958146549761, 0.009630134227336384, 0.007318877633224474, 0.00747009717997571, 0.03916173765901476, 0.034869248265749775, 0.04120562720345333, 0.032771527039585635, 0.043787366012111306, 0.03166730035445653, 0.01637623063288629, 0.07910584739875048, 0.02182750013162149, 0.019748568229260854, 0.05217398356762715, 0.05439618893433362, 0.03388884892046917, 0.042311983852414414, 0.026195072605332825, 0.029239690775284544, 0.05720581531932112, 0.05218859274464194, 0.0245213292146218, 0.0219569696491817, 0.043804016095236875, 0.029154803924029693, 0.07308153784833848, 0.028002465660392772, 0.09033326525241137, 0.06648483205935918, 0.01891156851343112, 0.06227363381185569, 0.06122009210230317, 0.0036330067632661667, 0.052379810804268345, 0.05624800323857926, 0.012476154606702039, 0.009790654276002897, 0.04216650435409974, 0.06712261150823906, 0.02519980804208899, 0.02276654886372853, 0.03942210903915111, 0.04730991800897755, 0.042669546892284416, 0.02955514250061242, 0.0484178739861818, 0.07566127285826951, 0.0352222693618387, 0.055089247252908535, 0.020731372133013792, 0.025856970532913692, 0.02425285172648728, 0.012992291412956547, 0.019153057801304385, 0.054914931606617756, 0.010165449984924635, 0.024601915320090484, 0.03631872205005493, 0.044776069989893585, 0.06784172292100266, 0.01798625507944962, 0.009116408473346382, 0.03276441726484336, 0.016304555865644943, 0.06466520469984971, 0.09833878255449235, 0.0476561818504706, 0.026202082190138754, 0.004399001036290429, 0.05504355693119578, 0.059264080264256336, 0.07059548413963057, 0.026137615532206837, 0.03335081411933061, 0.08408167297602631, 0.06318942178040743, 0.022192510623426642, 0.025950534945877735, 0.060320412449073046, 0.10161383572267368, 0.023987595159269404, 0.1351061143213883, 0.051947932806797326, 0.08192846507881768, 0.048726907989475876, 0.02398927983449539, 0.015927865824778564, 0.03387008371646516, 0.07495715282857418, 0.0255731491415645, 0.018446692774887197, 0.020239801342540886, 0.0238624839039403, 0.026782664317579474, 0.06887480732984841, 0.015129444800550118, 0.04678442550357431, 0.0656695308862254, 0.035128220697515644, 0.04109885070647579, 0.008719223096704809, 0.023370041089947335, 0.04803348230780102, 0.06740980039467104, 0.04145226143009495, 0.030086729893810116, 0.018754357515717857, 0.02357526533160126, 0.06327821232844144, 0.027131084098073188, 0.016543670280952938, 0.06391405477188528, 0.05946530247456394, 0.044517784044728614, 0.05750555021222681, 0.03877202107105404, 0.03786401452089194, 0.026881130615947768, 0.024186795017158147, 0.06474049558164552, 0.011907202861038968, 0.03093113067734521, 0.05640497118292842, 0.08534163935109973, 0.05938594833423849, 0.026214446370431688, 0.0446585026656976, 0.014387716437340714, 0.026493054174352437, 0.03356908717250917, 0.02688890275749145, 0.011343153000780148, 0.027517182716110256, 0.011183097722096136, 0.05882516299607232, 0.053686269020545296, 0.0348038873198675, 0.030544763030775357, 0.03853111993521452, 0.051343835730222054, 0.09066067112144083, 0.027783984805864748, 0.03294400215963833, 0.08025684423046187, 0.010569612477411283, 0.0724934229219798, 0.02307141385244904, 0.007486326094294782, 0.05730725948524196, 0.024982948780234437, 0.02036454709013924, 0.03120944347756449, 0.007712370361332432, 0.07681531249545515, 0.016201050384552218, 0.009983018026105128, 0.08626292663393542, 0.025152112066280097, 0.02905106095568044, 0.01585090325534111, 0.05633309789118357, 0.06741538134519942, 0.06962738960282877, 0.04394693147332873, 0.00792362223364762, 0.04158473479037639, 0.029492683352145832, 0.039956459077075124, 0.03514760188409127, 0.07385652555967681, 0.04538732137007173, 0.03879284573486075, 0.020431384909898043, 0.13672751403646544, 0.13816575170494616, 0.16136340302182361, 0.16849898966029286, 0.17116285453084856, 0.1368680174346082, 0.1320703444071114, 0.1279219170100987, 0.12943457724759355, 0.12975180085049942, 0.12012185587082058, 0.17322841478744522, 0.1279319656896405, 0.13208788877818733, 0.14240182674257085, 0.1563744488521479, 0.22850176290376112, 0.2125254162820056, 0.210852422460448, 0.13402243028394878, 0.20736892969580367, 0.051367810810916126, 0.18711393844569102, 0.10444281360832974, 0.10832721454789862, 0.1266924900119193, 0.09323924095951952, 0.11301952486974187, 0.19331628922373056, 0.13149428938049823, 0.2569522167323157, 0.22426721669035032, 0.121108934545191, 0.13885560765629634, 0.21724428806919605, 0.1317871260107495, 0.11056136107072234, 0.2812374260975048, 0.14336186897708103, 0.14684147288789973, 0.10953323420835659, 0.14207495521986857, 0.07180851709563285, 0.09888453569146805, 0.17716540431138128, 0.1790850583347492, 0.15797772532096133, 0.1278867688961327, 0.13800529937725514, 0.18461515690432861, 0.10161362049984746, 0.1204150116245728, 0.13762206915998831, 0.18629797676112503, 0.11955826892517507, 0.08597776381066069, 0.09016367708682083, 0.09337222640169784, 0.08845997319440357, 0.10526540267164819, 0.13527208822779357, 0.1655043347273022, 0.16482662031194195, 0.17311724106548354, 0.13471305806888267, 0.13701031683012843, 0.1207360795524437, 0.2379308975650929, 0.1896968053188175, 0.09763358641066588, 0.12288412952329963, 0.1480371766956523, 0.1669308019336313, 0.19889149552909657, 0.22587028535781428, 0.1562517273123376, 0.1573054285836406, 0.18288718478288502, 0.21438952797325328, 0.14138340717181563, 0.12748258042847738, 0.27599765569902956, 0.21921982581261545, 0.0880960536596831, 0.21429339016322047, 0.14208144159056246, 0.22062062955228612, 0.172066003724467, 0.06795512308599427, 0.11886212698300369, 0.12989527283934876, 0.13894251314923167, 0.07548864930868149, 0.12972514290595427, 0.09197737468639389, 0.17469158861786127, 0.06504205244709738, 0.18092611891916022, 0.07464861235348508, 0.11908520173165016, 0.1384904858423397, 0.13930705608800054, 0.13936253904830664, 0.13007129542529583, 0.18228536238893867, 0.08625913425930776, 0.18531261244788766, 0.13978378206957132, 0.1094995481253136, 0.09234694196493365, 0.2064045681618154, 0.21726196602685377, 0.20965901931049302, 0.09666337675298564, 0.18090661527821794, 0.17049679183401167, 0.1327387077617459, 0.17188221827382222, 0.15881897939834744, 0.10404098517028615, 0.10546393459662795, 0.12310471065575257, 0.14530086336890236, 0.1327766611939296, 0.13758306187810376, 0.15445084660314023, 0.23278503853362054, 0.22467186528956518, 0.1235710465698503, 0.08315927989315242, 0.12831583415390924, 0.179514019691851, 0.20831812173128128, 0.14819138013990596, 0.10880736925173551, 0.06606326991459355, 0.09790411408175714, 0.20457048376556486, 0.10535259760217741, 0.1392872555879876, 0.13034235744271427, 0.12354937585769221, 0.24481258064042777, 0.26589634304400533, 0.147535202850122, 0.11949143110541627, 0.14900419511832297, 0.266885002492927, 0.1401882228674367, 0.17875647987239063, 0.07657002526684664, 0.13627796550281346, 0.13055133138550445, 0.13206004339735955, 0.11282692270469852, 0.1655029394896701, 0.15597190795233473, 0.1504164724610746, 0.14010723971296102, 0.1634488083072938, 0.1275521345087327, 0.08321307817823254, 0.13789583259494975, 0.14492216025246307, 0.10681732252123766, 0.14380743959918618, 0.09904984166496433, 0.1988410740159452, 0.1479154941625893, 0.1119883700448554, 0.09241541993105784, 0.17777783941710368, 0.15926291729556397, 0.16200046258745715, 0.13769248413154855, 0.10328592412406579], [0.03532040354912169, 0.04699042343418114, 0.05972668688627891, 0.027054143793066032, 0.10015902589657344, 0.06162096316984389, 0.018655052590474952, 0.05790975352283567, 0.04168494699115399, 0.06679636338958517, 0.004494719996728236, 0.011066977585869608, 0.022465489237220027, 0.05181227934372146, 0.02460805102600716, 0.037165924441069365, 0.03790769733313937, 0.1164247581618838, 0.014273586184572196, 0.027627374947769567, 0.049948820742429234, 0.04151834968070034, 0.05506173212779686, 0.06008351148921065, 0.0647746269532945, 0.0821382479625754, 0.01926922061102232, 0.04738419585919473, 0.00936433960305294, 0.07382073177723214, 0.029927960385975894, 0.07240019433083944, 0.022738228508387692, 0.04964186104189139, 0.025621824752306566, 0.028012592265440617, 0.010504553956707241, 0.11895372284925543, 0.05394048799644224, 0.06516426190501079, 0.04435613314853981, 0.024832456074364018, 0.023617764418304432, 0.03200551189365797, 0.03976692940341309, 0.039416182989953086, 0.061690546936006285, 0.035444331078906544, 0.06109069494414143, 0.04866480507189408, 0.06655068282270804, 0.029918093532614876, 0.05217309299041517, 0.02963476381410146, 0.010989654147124384, 0.036573315810528584, 0.0319107359246118, 0.013831581582053332, 0.04123250408156309, 0.047921399454935454, 0.01751803411025321, 0.0315104363107821, 0.021168027706153225, 0.016349184916180093, 0.043738718231907114, 0.02760393235803349, 0.02702599042095244, 0.012595056869031396, 0.074552578444127, 0.027671337920764927, 0.040995614253915846, 0.024441164277959615, 0.0466701384721091, 0.1337931808666326, 0.03840033125015907, 0.11474152270238847, 0.05549549146962818, 0.04886715534667019, 0.02552273690525908, 0.030369835112651344, 0.032282121464959346, 0.06362896616337821, 0.02458358427247731, 0.019750544197449926, 0.03430695265706163, 0.024597844640084077, 0.06731299465172924, 0.07466911789379083, 0.04385319822176825, 0.0781048608769197, 0.043187836854485795, 0.04689414090535138, 0.030452048376901075, 0.03541640406183433, 0.05932782332820352, 0.036176619323669, 0.052553313798853196, 0.015885799039097037, 0.020967536511307117, 0.04062517124111764, 0.07962828225572594, 0.03283126250607893, 0.0687658303650096, 0.053296815895009786, 0.04508954574703239, 0.018634046100487467, 0.015032446099212393, 0.006354132037813542, 0.022409173216146883, 0.07047440274618566, 0.051379102587816305, 0.02329336610273458, 0.033023478754330426, 0.03090631140366895, 0.03763859087484889, 0.009303698716394138, 0.056511057482566684, 0.0866962963482365, 0.0403181670117192, 0.027113910800835583, 0.059527895209612325, 0.027247562320553698, 0.013793587331747403, 0.05551180016482249, 0.011229855808778666, 0.018924923460872378, 0.006824219972259016, 0.01964153940207325, 0.00749688128962589, 0.016777016353444196, 0.015898730962362606, 0.039216660297825, 0.05663976444338914, 0.029272447318362538, 0.029303799346962478, 0.03303366102045402, 0.009861891176115023, 0.039062475407263264, 0.07369881175691262, 0.03469004557700828, 0.012908781245641876, 0.0616132596769603, 0.04853886261116713, 0.03512961964588612, 0.09626264669350348, 0.03589138599636499, 0.017787663782655727, 0.015293769283744041, 0.043989979749312624, 0.02818266468239017, 0.07309916385565884, 0.04502776937442832, 0.08627792543848045, 0.004199486229481408, 0.027985542837996036, 0.05242755316430703, 0.029048802971374243, 0.035191956339986064, 0.04319426014262717, 0.0876471062656492, 0.018115416605724022, 0.041568837987142615, 0.07891005399869755, 0.024316997405549046, 0.004531966533249943, 0.05614909721771255, 0.06064145069103688, 0.013059874163445784, 0.01340191054623574, 0.044925334441359155, 0.04149818552832585, 0.028358388553897385, 0.037055919601698406, 0.025916104859788902, 0.05504270717210602, 0.06436916199163534, 0.02918145815783646, 0.062367018254008144, 0.038063960237195715, 0.02933793071861146, 0.020856483388342895, 0.06316201426670887, 0.02780115624773316, 0.1267605449538678, 0.026049119987874292, 0.03747709954041056, 0.030434741493081674, 0.026209922980342526, 0.02740009036642732, 0.03137587751552928, 0.023655899676668923, 0.01732348380755866, 0.001692164539690566, 0.06480050564277917, 0.053074082534294575, 0.03338112343044486, 0.018894805252784863, 0.009854406616796041, 0.008025845654628938, 0.018328145815758035, 0.05433735888800584, 0.0740170743665658, 0.04836502193938941, 0.017206519478349946, 0.024519360667909496, 0.058228105190210044, 0.040840587025741115, 0.137333269813098, 0.027929493990086485, 0.04676464726799168, 0.04145707796851639, 0.011477523476060014, 0.06910399737535045, 0.09004479987197556, 0.06445170365623198, 0.05980585920042358, 0.04177351489488501, 0.019939654557674658, 0.03746996750123799, 0.034194220424978994, 0.033711323485476896, 0.043902810793952085, 0.02859325788449496, 0.013034500134381233, 0.021977308206260204, 0.03286254403064959, 0.09949331943062134, 0.022286037929006852, 0.05039298128394876, 0.01614389202586608, 0.03715475511853583, 0.033963661117013544, 0.02129351003532065, 0.014948931293474743, 0.0038062196244936786, 0.026161575769947376, 0.05937583657214418, 0.05450339216622524, 0.07407335142488591, 0.1024609527667053, 0.07383424628642388, 0.0528767937066732, 0.031017997207527515, 0.018008768129220698, 0.02297614249982871, 0.029633160775119904, 0.017836723454820458, 0.05504453285539057, 0.030838434577162843, 0.07599575139465742, 0.018555782917246688, 0.06550583537318744, 0.12344030983513221, 0.029205229147919454, 0.03108427656115964, 0.07076885725837201, 0.06415558673324995, 0.05659777372784447, 0.041098594665527344, 0.03220355400117114, 0.017277826882491354, 0.016733047814341262, 0.027671406569425017, 0.07947058329591528, 0.05740937158407178, 0.05883804667973891, 0.037772247960674576, 0.056138577274396084, 0.058686218108050525, 0.041191860364051536, 0.02572803721704986, 0.02266455179778859, 0.052696474085678346, 0.02023602010012837, 0.07362064876360819, 0.043800390703836456, 0.020812104812648613, 0.035413131190580316, 0.005705531148123555, 0.035304339762660675, 0.0503969554847572, 0.041153127676807344, 0.024161500768968835, 0.03573611757019535, 0.0687646132428199, 0.05557051888899878, 0.026200946704193484, 0.028011428948957473, 0.11910651621292345, 0.02721049946558196, 0.019446909318503458, 0.04954679934598971, 0.01702555233350722, 0.06992329872446135, 0.031662339097238146, 0.029592413156933617, 0.04847143107326701, 0.02478063561284216, 0.0169051592820324, 0.05055427594925277, 0.049642050289548934, 0.02400305966148153, 0.0844652668456547, 0.04098680496099405, 0.08373609191039577, 0.07496808466385119, 0.005437801837615552, 0.021249745586828794, 0.03252760165196378, 0.08204642203054391, 0.039556393239763565, 0.04579124266456347, 0.022011413602740504, 0.04207418860460166, 0.021150340471649542, 0.05915013462072238, 0.027122528990730643, 0.02362360326515045, 0.023553190148959402, 0.04981836973456666, 0.018900955801655073, 0.05842054037202615, 0.02667938890226651, 0.035309813101775944, 0.04931060342642013, 0.012652239347517025, 0.04598246443492826, 0.02033278316957876, 0.013883863102819305, 0.06199489056598395, 0.03501496154058259, 0.0810985584394075, 0.015531520002696197, 0.011020880010619294, 0.06598221996682696, 0.053632021736120805, 0.02934879947133595, 0.05765360125224106, 0.014137348280200968, 0.030556054807675537, 0.027229474326304626, 0.07506244874093682, 0.08577438566135243, 0.018092294994858094, 0.04808038233022671, 0.06429984539863653, 0.053288886047084816, 0.030283779378805775, 0.04512037085078191, 0.03348603713675402, 0.08371856980375014, 0.045743589362245984, 0.14062068716157228, 0.13296721503138542, 0.1216917579586152, 0.178294017969165, 0.15277489903382957, 0.16231403482379392, 0.13854441029252484, 0.16979087580693886, 0.1037462857493665, 0.16399338142946362, 0.09701821240014397, 0.11067445695516653, 0.11339716671500355, 0.11067982268286869, 0.0938919153122697, 0.14543188211973757, 0.12794771406333894, 0.24184309935662895, 0.12406221474520862, 0.13305821717949584, 0.074945241358364, 0.1126305504294578, 0.09832951313001104, 0.17050430236849934, 0.15281038853572682, 0.2524451835779473, 0.13168794539524242, 0.11641028628218919, 0.1707031682599336, 0.15535516839008778, 0.10485178150702268, 0.44291394122410566, 0.27664851921144873, 0.07267263674293645, 0.08945638808654621, 0.06022353620210197, 0.15980302268872038, 0.19373297545826063, 0.12181897691334598, 0.20608911087037995, 0.23499294271459803, 0.1052649796474725, 0.17699297372018918, 0.10192471396294422, 0.13341818848857656, 0.1510201205383055, 0.13469560275552794, 0.12430502320057712, 0.11933621091884561, 0.08696132470504381, 0.27670634735841304, 0.14492754824459553, 0.17351645714370534, 0.08588813463575207, 0.09835353645030409, 0.13567557907663286, 0.07788405710016377, 0.29505983751732856, 0.08671911738929339, 0.1463589136255905, 0.149085104058031, 0.15236193838063627, 0.11300432568532415, 0.14039728586794809, 0.13390776846790686, 0.16826662322273478, 0.1533670735079795, 0.10905938033829443, 0.11282856285106391, 0.07894925423897803, 0.12346995863481425, 0.13182608876377344, 0.12332115802564658, 0.22109168552560732, 0.12033967621391639, 0.26170205092057586, 0.13595271186204627, 0.17353110713884234, 0.14369682990945876, 0.15753938321722671, 0.1454322531935759, 0.2069020297494717, 0.06966702771023847, 0.1709679962368682, 0.16096294013550505, 0.08624924143077806, 0.16592100611887872, 0.19559457869036123, 0.24948131293058395, 0.18973487749462947, 0.14539833704475313, 0.13777946383925155, 0.20590045693097636, 0.15444462740560994, 0.14720738137839362, 0.13331810245290399, 0.11243518747505732, 0.1081930565123912, 0.12972627097042277, 0.14354713872307912, 0.21395180927356705, 0.13122947624651715, 0.16482056438690051, 0.1829086773796007, 0.09177296495181508, 0.08789094630628824, 0.11089929059380665, 0.11184661983861588, 0.24256707925815135, 0.14467633125605062, 0.18155402038246393, 0.1357807414024137, 0.14571247331332415, 0.14502594218356535, 0.1741770131047815, 0.12123551525291987, 0.13136027235304937, 0.18367829936323687, 0.09035846858751029, 0.14752309100003913, 0.14206570805981755, 0.17344620544463396, 0.17051449947757646, 0.12726753571769223, 0.13580420811194927, 0.12994553108001128, 0.10306510550435632, 0.11867042281664908, 0.18833854148397222, 0.18763220985420048, 0.0561015478160698, 0.08749512184294872, 0.15603697946062312, 0.18078825756674632, 0.10575350577710196, 0.15158936264924705, 0.15722644922789186, 0.12930860510095954, 0.15413564164191484, 0.1330176365445368, 0.09431659447727725, 0.14560358540620655, 0.1260354815167375, 0.11749275319743901, 0.24247334600659087, 0.2846629125997424, 0.07721340050920844, 0.12341722162091173, 0.13717470254050568, 0.07655848487047479, 0.17850726668257266, 0.18466580106178299, 0.17832294688560069, 0.12334887724136934, 0.09221770436852239, 0.15607401262968779, 0.08116498807794414, 0.11609354507527314, 0.12683654087595642, 0.23967706714756787, 0.07996348809683695, 0.09895128445350565, 0.21594180405372754, 0.14251490036258474, 0.1562085491605103, 0.14179954421706498, 0.21197465364821255, 0.09093713597394526, 0.13612563227070495, 0.09739291534060612, 0.15807089454028755, 0.11888697408721782, 0.12576758104842156, 0.14859825518215075, 0.14637019427027553, 0.12457193661248311], [0.013387023063842207, 0.011515572459757095, 0.051885399443563074, 0.04668467343435623, 0.03754169236344751, 0.024409081233898178, 0.08641970533062704, 0.028758445114362985, 0.018706281189224683, 0.07407263896311633, 0.05121926253195852, 0.07868415908887982, 0.012488648662838386, 0.05346476020349655, 0.03877162031130865, 0.0209471348716761, 0.07344113066210411, 0.02914151020377176, 0.02245589883386856, 0.014937274008843815, 0.029978435704833828, 0.029960917308926582, 0.04859041218878701, 0.06612992219743319, 0.03680096961033996, 0.044942652457393706, 0.07075105313560925, 0.05883442499907687, 0.08887245887308381, 0.02321134950761916, 0.04675184522056952, 0.028320815472397953, 0.016303964002872817, 0.05316391208907589, 0.0943629044923, 0.030578306250390597, 0.04181994365353603, 0.08841642396873794, 0.02672710343176732, 0.014420220650208648, 0.0446602504234761, 0.028021177058690228, 0.026458868996996898, 0.02917268040619092, 0.037854284964851104, 0.010301894762960728, 0.023723284830339253, 0.0281248272585799, 0.06996310752583668, 0.04607040151313413, 0.047358550946228206, 0.00896980925972457, 0.04139082273468375, 0.026040423872473184, 0.02783493880997412, 0.06162468132970389, 0.02703682392166229, 0.06792023472371511, 0.0587002113024937, 0.04148159110627603, 0.045615027120220475, 0.007206939035313553, 0.04549808691081125, 0.09604360922821797, 0.041500337756588124, 0.03924066506442614, 0.03188060472893994, 0.030439044094237033, 0.014905123243806884, 0.01794025862182025, 0.07661961557460018, 0.024305303013534285, 0.03993571976025123, 0.06357282269163989, 0.036303682427387685, 0.038810768601251766, 0.03430337550526019, 0.029186914798629005, 0.030493061312881764, 0.09626292870962061, 0.0427542927354807, 0.05222771505941637, 0.04144131104112603, 0.01486358245529118, 0.029942775508970954, 0.041250868525821716, 0.05826015483762603, 0.05548478598939255, 0.028361973127175588, 0.07120754075003788, 0.04566212752251886, 0.022281711208052002, 0.04935832352202851, 0.052777594537474215, 0.010313950024283258, 0.033002420314005576, 0.0512312185310293, 0.06681327693513595, 0.0191466363685322, 0.030288057860161643, 0.013845886478520697, 0.03221901293727569, 0.0671199471980799, 0.00921420776649029, 0.061784911013091914, 0.022208867558219936, 0.030479385386570357, 0.009367470538563794, 0.06351830452331342, 0.04176382986770477, 0.07784743211232126, 0.05804852400615346, 0.016840444004628807, 0.015022645111457678, 0.011104657351097558, 0.05646106641506776, 0.03706722622155212, 0.04598343664838467, 0.0036051732104169787, 0.01599854054802563, 0.016949463642959017, 0.037590848514810205, 0.09245027860742994, 0.027913003468711395, 0.015266796854120912, 0.016506551764905453, 0.024418337670795154, 0.057404421459068544, 0.03588428364309948, 0.021658411060343497, 0.02753888682491379, 0.02316033798706485, 0.02648574587510666, 0.013926217470725533, 0.08918282503145747, 0.04835880645259749, 0.04217027817503549, 0.05971636732283514, 0.06358650047332048, 0.027136993448948488, 0.018854022382583935, 0.02374745101406006, 0.04132971058425028, 0.014339242134155938, 0.04198219197860453, 0.04168516221398022, 0.016877302768989466, 0.015997512673493475, 0.027793128065241035, 0.005732597737733158, 0.045772061857860535, 0.01340600070761866, 0.07457181491190568, 0.059389176676631905, 0.012703921584034106, 0.024877446921891533, 0.03332234904519282, 0.031699220126029104, 0.02166979746107245, 0.0144808949335129, 0.01136585993663175, 0.08783012730418704, 0.02347585093957605, 0.018947078424389474, 0.00920462014619261, 0.016990877338685095, 0.04460789561562706, 0.014847270977043081, 0.06529686885187402, 0.03383169612789061, 0.06424316758057103, 0.05957007517281454, 0.061932123426231556, 0.044802601769333705, 0.047802800545468926, 0.03504674772557337, 0.05529356792976614, 0.0777627233765088, 0.04465330763196107, 0.03605130026699044, 0.05417242398834787, 0.015472302184207365, 0.027496708717080764, 0.048298529218300246, 0.01668265413172776, 0.030397862319659907, 0.004446714638106641, 0.10130790760740638, 0.04774103159434162, 0.04656742894439958, 0.013847946866007987, 0.04990647379599977, 0.05763256507634651, 0.021750075575255323, 0.06307843359536491, 0.03340470888360869, 0.040969516630866565, 0.016612994295428507, 0.0381406723317923, 0.06753264809958637, 0.027760523662436754, 0.009144443101831712, 0.048344705646741204, 0.03901187577866949, 0.08874556646333076, 0.033716496254783124, 0.06437611591536552, 0.0187088007805869, 0.05428609132650308, 0.013040443809586577, 0.008360118245036574, 0.06678766541881487, 0.013716552402911475, 0.02684116410819115, 0.02439318999677198, 0.016103506204672158, 0.05024126032367349, 0.031148394409683533, 0.024703326089365873, 0.011788229166995734, 0.00809503608252271, 0.011550995168363443, 0.01564630241773557, 0.038373105562641285, 0.0735594290017616, 0.029335151375562418, 0.07630312669789419, 0.06422839142032899, 0.05113275779876858, 0.024075125911622308, 0.02016028949583415, 0.07675712811760604, 0.06077228761569131, 0.07532756615546532, 0.024231743191194255, 0.06739070493495092, 0.02690165285457624, 0.05193208795390092, 0.041730128941708244, 0.06505525525426492, 0.04616876947693527, 0.031124398919928353, 0.036464791555772536, 0.014096913291723467, 0.03476751095149666, 0.029022653397987597, 0.0752912973985076, 0.01498580582847353, 0.0951007625553757, 0.05769466428318992, 0.05333504763257224, 0.0636674762063194, 0.015319580252253218, 0.06858821216155775, 0.032070932211354375, 0.0638140132650733, 0.03725599148310721, 0.041996044164989144, 0.05459348518343177, 0.029365314112510532, 0.03713699923537206, 0.09623127611121163, 0.04446228995220736, 0.002421921712993935, 0.03141179004160222, 0.03846765888738446, 0.06794229877414182, 0.015196598033071496, 0.05276297793898266, 0.041357526279171, 0.018147195369238034, 0.024847235945344437, 0.04755238136567641, 0.012063928679708624, 0.033032944847946055, 0.062563449901063, 0.034664085251279175, 0.013510769695130875, 0.015820269254618324, 0.0591601350606652, 0.09281465827370994, 0.05480893807543907, 0.062077187321847305, 0.03518238263495732, 0.08538034235243686, 0.08169749387889169, 0.028424044503481127, 0.0606550134398276, 0.027342831817804836, 0.02242882899736287, 0.07615637441631407, 0.043743894711951725, 0.03670234560559038, 0.07052305052638985, 0.02945464086224092, 0.011254692708462244, 0.024777598373475485, 0.031910019752103835, 0.040773326181806624, 0.036127663552179, 0.013484706396411639, 0.053823035705136135, 0.03171592587023042, 0.04096178716281429, 0.048237064547720365, 0.0547863137035165, 0.028137089393567294, 0.03240145510062575, 0.0757475029968191, 0.06456046539824456, 0.03895962858223356, 0.017198303903569467, 0.002252868589494028, 0.0554946454212768, 0.030498482701659668, 0.019567766212276183, 0.052019301438122056, 0.06628391041886061, 0.07246720284456387, 0.04832481237826869, 0.04341380968980957, 0.021634204058500472, 0.048093948789755814, 0.024535474549338687, 0.03849317392450757, 0.0562074040499283, 0.03568748834368307, 0.040274569546454586, 0.03074460670177359, 0.027425282569311094, 0.03097176697338, 0.018480696126061957, 0.024712552840355784, 0.0503430866956478, 0.04712553884019144, 0.018980669883603696, 0.03870998123602476, 0.0529875852225814, 0.03545530002156738, 0.029785006045131013, 0.017043905645550694, 0.0742522461223416, 0.017997877112065908, 0.057068057867581956, 0.031431883689947426, 0.08362833206774667, 0.0779982290987391, 0.044253694504732266, 0.06769959421944804, 0.06278769724303856, 0.06909545525559224, 0.06683282510493882, 0.1511979688075371, 0.18550807930296287, 0.13736785389482975, 0.2165976251126267, 0.13319992285687476, 0.1440871847444214, 0.11620339777437039, 0.15226274292217568, 0.09286827844334766, 0.2158196020172909, 0.11143069801619276, 0.12292962317587808, 0.07345084537519142, 0.12033493389026262, 0.051678815216291696, 0.14489649678580463, 0.11017759650712833, 0.09207081107888371, 0.13736628054175526, 0.09788984258193523, 0.1763566563022323, 0.11579563215491362, 0.13293806347064674, 0.1573188614565879, 0.21283081005094573, 0.13680089759873226, 0.13336717325728387, 0.10410428294562735, 0.2251089902711101, 0.18067322467686608, 0.14303900505183265, 0.09808976232307032, 0.12431306808139198, 0.11311241207295097, 0.17961388308322057, 0.15611343551427126, 0.15278134087566286, 0.20917822635965422, 0.1391224839608185, 0.09721020600409247, 0.12481537589337677, 0.12436532269930467, 0.13294285774463788, 0.2118077001068741, 0.1060519233578816, 0.1235982685466297, 0.11614189599640667, 0.1188914047088474, 0.22298209893051535, 0.11882246661116369, 0.19610327639384195, 0.15704598859883845, 0.0819349662924651, 0.12044163988321088, 0.12406214795191772, 0.3089558699866757, 0.14300039852969348, 0.135585957323201, 0.27482865436468273, 0.13861733372323215, 0.13710299623198807, 0.10728787383413874, 0.19019624101929367, 0.21785412565805018, 0.15151088795391843, 0.15838155755773187, 0.146747398248408, 0.15793601662153378, 0.10629928859998472, 0.09145961535978131, 0.18925956159364432, 0.09176494233543053, 0.15622092818375677, 0.2219077362678945, 0.12522590230219066, 0.2358120956341736, 0.18252774782013148, 0.16293102671625093, 0.10747547392384149, 0.14085109432926401, 0.15147352823987603, 0.1016221329336986, 0.1499228403554298, 0.06414246556232683, 0.20532974536763504, 0.2665295731276274, 0.13401965465163812, 0.10515058500459418, 0.17586651229066774, 0.1395455823512748, 0.1381961500737816, 0.099971002782695, 0.15397162700537592, 0.1406238932395354, 0.06282087124418467, 0.09343150173663162, 0.1637517975177616, 0.19503655785229057, 0.09958640701370314, 0.11860287995659746, 0.11147826968226582, 0.08246784316725098, 0.17986536724492908, 0.1252147404011339, 0.17288324190303683, 0.1344171044183895, 0.12119427410652861, 0.19851065502734855, 0.22112531965831295, 0.09996166656492278, 0.1357956585707143, 0.1612474795547314, 0.17887804366182536, 0.11751328100217506, 0.1359743528882973, 0.1391047317883931, 0.1253462934982963, 0.144847544725053, 0.11255261008045636, 0.1908719219500199, 0.08548623940441757, 0.12663907022215426, 0.1347243832424283, 0.1428049019887112, 0.1151011600450147, 0.18158179154852405, 0.09373992346809246, 0.10327188269002363, 0.15407254424644634, 0.11913052469026297, 0.11472447557025589, 0.08889739503501914, 0.1759559559286572, 0.11960643430938944, 0.2295557313482277, 0.2737371332477778, 0.1037714297126513, 0.12852102314354852, 0.2023116237251088, 0.1681801927043125, 0.14195106108672917, 0.1521365184453316, 0.13561905710957944, 0.10660457104677334, 0.1094321982236579, 0.12679665785981342, 0.1553814552607946, 0.1304865864221938, 0.13205386872868985, 0.14583001466235146, 0.12224836871610023, 0.08003966955584474, 0.13449654390569776, 0.1261032247566618, 0.08493279761751182, 0.07550193375209346, 0.13592241739388555, 0.12701109400950372, 0.10415421464131214, 0.12664761976338923, 0.12040019835694693, 0.23375545599265024, 0.10632335644913837, 0.08248878657468595, 0.08943125154473819, 0.13736533059272915, 0.19840285065583885, 0.14163701387587935, 0.1631129567977041, 0.12072297322447412, 0.15855091565754265, 0.12439504571375437, 0.16915251006139442, 0.13391550164669752, 0.13325611827895045, 0.17298926512012258], [0.06800273185945116, 0.024703326089365873, 0.026713807856140193, 0.061092958494555205, 0.04788268903212156, 0.013466036743920995, 0.01710189892037306, 0.015874312448431738, 0.015825607151782606, 0.08406466295127757, 0.0033787840766308364, 0.037361023933044635, 0.021682746082660742, 0.022683903298457153, 0.019003795205208007, 0.0573632879240904, 0.07488060029572807, 0.05172786746697966, 0.06402174782124348, 0.06438347059884109, 0.01601464144187048, 0.017132920693256892, 0.0336685423826566, 0.06957791061722673, 0.04165870836004615, 0.038038152051740326, 0.026457095264049713, 0.015891170332906768, 0.0027287772809359012, 0.007067582255331217, 0.04040661246108357, 0.04501960203924682, 0.03719161388289649, 0.01763227290211944, 0.027489734384289477, 0.10596011226880364, 0.03490674527711235, 0.022362252784660086, 0.015405866051878547, 0.024822548402880784, 0.03703683156345505, 0.025182219142152462, 0.018611585001053754, 0.010951847289106809, 0.02941254439065233, 0.012285123011679389, 0.0838168449990917, 0.022194486591615714, 0.041768928422243334, 0.01971288576896768, 0.0461862693191506, 0.033075221290346235, 0.042337528575444594, 0.08127858862280846, 0.029906619929533917, 0.03644264957983978, 0.0783664605114609, 0.0372289698862005, 0.116009430057602, 0.07107659621397033, 0.03371708997292444, 0.07693430103245191, 0.0085935821334715, 0.041158396925311536, 0.02869662977900589, 0.03250730020226911, 0.05506444096681662, 0.052368827018653974, 0.017541749439260457, 0.04651830990042072, 0.011612871730903862, 0.035685117181856185, 0.14092015859205276, 0.039140545632108115, 0.054155087418621406, 0.0764004593656864, 0.053275456884875894, 0.10334324761060998, 0.02604401030112058, 0.07155012353905477, 0.032032303424784914, 0.04278391927073244, 0.0530391310894629, 0.02394477323832689, 0.09178296910249628, 0.03878057061228901, 0.0350919556512963, 0.024006839048524853, 0.07992457729415037, 0.042028546522487886, 0.030081199038249906, 0.00490161452034954, 0.036662874481407925, 0.01354536954750074, 0.033056734391720966, 0.07776730242767371, 0.03835352028545458, 0.013285977802297566, 0.03213350639271084, 0.07362957680015825, 0.024436026760668028, 0.03757986472919583, 0.011083833614975447, 0.021445646598294843, 0.08247803285485134, 0.04869066149694845, 0.04946679211570881, 0.10393300268333405, 0.031195891860988922, 0.02753301458142232, 0.019828876029350795, 0.03876592432789039, 0.0590144403395243, 0.018088244723912794, 0.04363424981420394, 0.02229343899671221, 0.032451375664095394, 0.051242551126051694, 0.024060455507424194, 0.04230589824146591, 0.011220230153412558, 0.025086396744882222, 0.08033371588680893, 0.007836037675588159, 0.044713859460898675, 0.02820272678945912, 0.02595183741505025, 0.04081235943885986, 0.0433761790918652, 0.05454388745420147, 0.029952108016004786, 0.025416086573386565, 0.07710089834290557, 0.007380679980997229, 0.03541683450748678, 0.08772080895141698, 0.043711807957151905, 0.03755148500204086, 0.05772104763309471, 0.02151135264284676, 0.03077608304010937, 0.053364889390650205, 0.05210476345382631, 0.09577088480000384, 0.06769580926629715, 0.041922693999367766, 0.018188891081081238, 0.012293480522203026, 0.0411034074932104, 0.025678706660983153, 0.04297035418858286, 0.018697427367442288, 0.01731545005895896, 0.05030886626627762, 0.04696176911238581, 0.05149266973603517, 0.032103694320539944, 0.026789493931573816, 0.0761462737864349, 0.050671186472754925, 0.019437406117503997, 0.026715397907537408, 0.0944707533926703, 0.07215187913971022, 0.022903933386260178, 0.009455668296141084, 0.030330150621011853, 0.029988899987074547, 0.04679268931795377, 0.030586098800995387, 0.06283251554123126, 0.03564431390259415, 0.08318728854646906, 0.026686648961913306, 0.09052988243638538, 0.06561874572071247, 0.07767195871565491, 0.051128883787896484, 0.043102950003230944, 0.031912350095808506, 0.017857395978353452, 0.03583950987376738, 0.09535430988762528, 0.04161723343713675, 0.018201214443251956, 0.020429540672921576, 0.036468750913627446, 0.04550725614535622, 0.052907741264789365, 0.04831948746868875, 0.018914809843408875, 0.08503179269609973, 0.025482211931375787, 0.033834894784376957, 0.03226830638595857, 0.10705013424740173, 0.057701989280758426, 0.020842607082158793, 0.016900621048989706, 0.028122875410190318, 0.03362044379173312, 0.010133511659660144, 0.08399717204156332, 0.03624636636232026, 0.012480618624977069, 0.02831606201652903, 0.05418431319412775, 0.021344170891097747, 0.005907519162065, 0.06695706062600948, 0.016375950472138356, 0.055733531626174226, 0.08817459514830261, 0.020174722412775736, 0.017231681995326653, 0.055051319795893505, 0.0058474552952247905, 0.034608646819833666, 0.02505913951608818, 0.05920431140111759, 0.01923823780089151, 0.01602703530807048, 0.04395529176690616, 0.03865974897053093, 0.07760981869068928, 0.014589366310246987, 0.046196525800041854, 0.013791048259008676, 0.04940626626193989, 0.017027129397320095, 0.04029676718346309, 0.04029868563520722, 0.04823622963158414, 0.04388105473481119, 0.07525770779466256, 0.08627042974694632, 0.04339090330176987, 0.07067728365655057, 0.053012859061709605, 0.04022100503789261, 0.08842177485348657, 0.014401865482795984, 0.1092255100957118, 0.06188932005898096, 0.015474661286134506, 0.026152965001529083, 0.031128464033827186, 0.026052218454424292, 0.08382765066926368, 0.062131271333782934, 0.01780567199602956, 0.015712160602561198, 0.0330851660692133, 0.039988419666769914, 0.02547332100220956, 0.07134067462175153, 0.06055504985852167, 0.08073325108853169, 0.03480245126411319, 0.018138799823645968, 0.07529424372478388, 0.03253519753343426, 0.05135106424859259, 0.033356020285282284, 0.04718279182270635, 0.10592889753752388, 0.07122584953322075, 0.03200170467607677, 0.037790308124385774, 0.04568743104755413, 0.02282028963236371, 0.08115718810586259, 0.002512981609470444, 0.07554008756414987, 0.028542264917632565, 0.03579065429221373, 0.012815694590244675, 0.08882622307282872, 0.027100592960778158, 0.021949472102278378, 0.012446914915926754, 0.06077024299884215, 0.04021050735900644, 0.08749997548875399, 0.030550731753464788, 0.09336160626844503, 0.01708519132080255, 0.014934348091628635, 0.038445828613475896, 0.05853371047123801, 0.03980653411417734, 0.01984222912142286, 0.03529616500600241, 0.03297591822047252, 0.06827544144471176, 0.06860531124402769, 0.04340281477198005, 0.04244647214363795, 0.04678817334934138, 0.018497457531339023, 0.03666172415250912, 0.06044054389349185, 0.03705410133989062, 0.04568702286633197, 0.04311103199142963, 0.039325856196228415, 0.010553022693784442, 0.016492827598995063, 0.035295422858325765, 0.02279957443533931, 0.060436131825554185, 0.04026997194159776, 0.01185233310025069, 0.02993554327986203, 0.06042653585609514, 0.0036124181951890932, 0.00948822538703098, 0.011117718222521944, 0.0702385333715938, 0.06125672451162245, 0.0793545856140554, 0.07093172156601213, 0.01146991553468979, 0.01634630167245632, 0.06697459015413187, 0.04076828699908219, 0.029203293997852597, 0.017265993337787222, 0.024454851336486172, 0.01594987050339114, 0.04699480952695012, 0.0408540458738571, 0.025731015084602404, 0.06998356853728183, 0.05312212175340392, 0.021033199882367626, 0.06162559788208455, 0.09601300305803306, 0.049831665310193785, 0.010915572038356913, 0.01898995786177693, 0.04279459135432262, 0.08944786080974154, 0.03186296387866605, 0.027739086726796813, 0.02825293307978427, 0.02748936887655873, 0.05426596799225081, 0.041354676432092674, 0.0010873394626287336, 0.05635830122628249, 0.04092614552064333, 0.14410268078790978, 0.15459100861335173, 0.09519459228613414, 0.12955738784512505, 0.11964127072133124, 0.10207916231593117, 0.2596381085459143, 0.1278220981475897, 0.09674490167526528, 0.1313012419268489, 0.13765098323347047, 0.1267675359849818, 0.1580953854136169, 0.09302937643951736, 0.0875045545399189, 0.19587131071602926, 0.15117622388061136, 0.11513828969327733, 0.1398746357881464, 0.24688940669875592, 0.142410910630133, 0.14272307278588414, 0.12596989050507545, 0.13277191144879907, 0.11298419864033349, 0.12129144350183196, 0.12797202682122588, 0.07679997230297886, 0.06312472876743414, 0.07340025316807441, 0.09202428584103473, 0.14778511365875602, 0.11991555365966633, 0.12279668226256035, 0.12718462297925726, 0.2862278645625338, 0.11191856363439001, 0.09730522317113355, 0.08180160977644846, 0.11920620148885064, 0.1687390002189204, 0.10120296792592853, 0.1437362824799493, 0.12825322657590732, 0.0907164286763873, 0.04807000710570719, 0.13602937571704388, 0.17796405911212787, 0.0857220494071953, 0.12772655405569822, 0.13987378973979503, 0.10227769424091093, 0.18295837158802897, 0.18084688723320141, 0.12944504152983427, 0.1671234634704888, 0.20969293545931578, 0.12683817360084504, 0.2523080643732101, 0.12133682583225891, 0.1358470894047059, 0.19042743486352265, 0.10220858544926159, 0.14407544396817684, 0.2684297680389136, 0.07662148578674532, 0.20168581511825323, 0.130117115622852, 0.08275995991425589, 0.13597303186543286, 0.09641569238738157, 0.17676473362371325, 0.28137923567555845, 0.20677172346040606, 0.12193595423013903, 0.12638114421861246, 0.28429792437236756, 0.20368097524624318, 0.14408292481675744, 0.17600668914383277, 0.06914942423463799, 0.11707544355886057, 0.1908461397397332, 0.09302533173467964, 0.15973953937646002, 0.14394577592611313, 0.11854876254801638, 0.08212393935536966, 0.11753650280297734, 0.2753971691709012, 0.1334320369642228, 0.0793890435306821, 0.12373369565466419, 0.07387818885035813, 0.10786174694658257, 0.18869158113375306, 0.09981962692108937, 0.3093710570828989, 0.14098753075813875, 0.15617301512975246, 0.16550408239709213, 0.18221784179331735, 0.15644251863704994, 0.12686431204201654, 0.17715850233798847, 0.1594625401776284, 0.09180273991660215, 0.18869306542910635, 0.09099129048991017, 0.2483330768882297, 0.1285921357339248, 0.1346989572630264, 0.14549750281730667, 0.15217574837151915, 0.10794185436679982, 0.08252517407527193, 0.15426795172970742, 0.1113476739556063, 0.09594544535502791, 0.2634323533857241, 0.1107387121010106, 0.2067389799049124, 0.1873083069222048, 0.08125099557219073, 0.10050868135294877, 0.16152024851180613, 0.12838970753364265, 0.1327445261995308, 0.14099360152613372, 0.0862924566899892, 0.13194895873311907, 0.1316255159326829, 0.14090815064264461, 0.06666979010333307, 0.11804602429037914, 0.26561079430393875, 0.06604138397960924, 0.15668693755287677, 0.17492141691036522, 0.17153605091152713, 0.07862767422921024, 0.09202376633766107, 0.14371759520145133, 0.2728513354668394, 0.13748860132182017, 0.15451571031007916, 0.1391561032505706, 0.18808057095156983, 0.14391487289685756, 0.17490571306552738, 0.07585379338706844, 0.1298537422553636, 0.1937627504230477, 0.1240580364537891, 0.2112263609888032, 0.08517788446624763, 0.12583631876623258, 0.11205193499336019, 0.17107651307014748, 0.2426708908751607, 0.12101083746529184, 0.197177505469881, 0.20718336309073493, 0.17013680568197742, 0.13517859246348962, 0.07989413439645432, 0.18670608376851305, 0.14007611403940246, 0.09737805012264289, 0.0798626673349645, 0.12489365763030946, 0.10288540928740986, 0.16594563057878986, 0.1210076165443752, 0.17351276124827564, 0.2162879565730691], [0.01931224291183753, 0.030914233830117155, 0.025439781493332703, 0.04843571892706677, 0.02003699279157445, 0.04374608404759783, 0.020163141198281664, 0.03135452221613377, 0.08539828748325817, 0.06165143204270862, 0.0024357187021450954, 0.095943345077103, 0.03816055446804967, 0.060526722081704065, 0.022678784334857482, 0.05487817674293183, 0.060888700900250115, 0.021322297943697777, 0.0287975488754455, 0.02926863824541215, 0.03942221293982584, 0.03025517700734781, 0.026657749731384683, 0.03633673026342876, 0.06782308017136529, 0.01685043145698728, 0.04263229850039352, 0.03320788389828522, 0.07826514251064509, 0.04516644337854814, 0.04047161346534267, 0.053512190861511044, 0.012529934338090243, 0.025811205996433273, 0.04455203044926748, 0.020192667543597054, 0.056645909426151775, 0.03523742772813421, 0.02346783017856069, 0.01916660570714157, 0.03740103682503104, 0.01655372452660231, 0.05646745259582531, 0.04567749369016383, 0.047193805294227786, 0.061801724368706346, 0.002935464713118563, 0.045665107245440595, 0.03101173904724419, 0.0685712911945302, 0.008011679910850944, 0.0326153494825121, 0.053442224889295176, 0.014576913999917451, 0.027018639448215254, 0.055458673523389734, 0.07876360599766485, 0.011950092502956977, 0.00838208303321153, 0.07810691662598401, 0.018626709970703814, 0.06821674498496577, 0.01763270891387947, 0.013937939693278167, 0.06594039252377115, 0.06669609181699343, 0.05475536243466195, 0.07703550028963946, 0.024854635157680605, 0.02563616304541938, 0.051755456806859, 0.06450136817875318, 0.04114385083084926, 0.05480345731484704, 0.0946714672318194, 0.07295690156752244, 0.02328113179828506, 0.027545571720111184, 0.08436558156972751, 0.0199784206415643, 0.05152205136255361, 0.038400717166950926, 0.050978276049136184, 0.026814886514330283, 0.02009796393394936, 0.10145889013074338, 0.01812602931750007, 0.04361306891951244, 0.06545749187353067, 0.01692641253612237, 0.07986708311364055, 0.07674725755350664, 0.0536680752702523, 0.06452425601310097, 0.16326914919773117, 0.021051273033663165, 0.037020307645434514, 0.011745320971385809, 0.03287182087660767, 0.03501306906400714, 0.04913006487186067, 0.015612742499797605, 0.034226559509988874, 0.06950076436623931, 0.022409475641325116, 0.01056890279869549, 0.03457744693150744, 0.037227296343189664, 0.05191140800889116, 0.018249595050292555, 0.04600754902639892, 0.058211948635289446, 0.08635698643047363, 0.03312441454909276, 0.033036136082955636, 0.03689155986648984, 0.056552016612840816, 0.11074300171458162, 0.039739039493724704, 0.028698806127067655, 0.017438880349800456, 0.05052793712820858, 0.029438428646244574, 0.03905209276126698, 0.02114471499226056, 0.007241451685331413, 0.018018035698332824, 0.04975389936589636, 0.031326179596362635, 0.015646391475456767, 0.027069997922808398, 0.07600804136018269, 0.03781669889576733, 0.03798197518335655, 0.019761802577704657, 0.023079508828232065, 0.03638782713096589, 0.021982636826578528, 0.04269089848094154, 0.04965719752362929, 0.04994544025976211, 0.055958788288990036, 0.013323307830432896, 0.029945499190944247, 0.023546169431938324, 0.039819966987124644, 0.05599789947154932, 0.05442798625153955, 0.03000660020916257, 0.029886043885198887, 0.018179946346208453, 0.012503185480454704, 0.057347628608113155, 0.03287645929958671, 0.04290972814487759, 0.03734665966476314, 0.031076009036041796, 0.023461041382688563, 0.054509481487912126, 0.014371371562447166, 0.013036902837484377, 0.016490790403622668, 0.029330969373404514, 0.005291926681820769, 0.018855352682294324, 0.04933984775561839, 0.03828887551208027, 0.019181151801603846, 0.03308420869871043, 0.031011436622065958, 0.04643186824978329, 0.028423857111192774, 0.008551734281354584, 0.05615386922727339, 0.011351539269526256, 0.04034558565763291, 0.04307914190576412, 0.03240440884837881, 0.026938767659885343, 0.03629021244705655, 0.009632871824578615, 0.03408391501579899, 0.017023457621689886, 0.015210092133202124, 0.02849566732038511, 0.10286713019013405, 0.02874137386243092, 0.03317493625218049, 0.01739705661748303, 0.10160663689021021, 0.05821266480779741, 0.013405689005594468, 0.02606249719974585, 0.09827834204770625, 0.021929040776740294, 0.03410814613744151, 0.00994259602521197, 0.04023974426672794, 0.0394366068940144, 0.01893221135105705, 0.05136664563906379, 0.007878255673858803, 0.006448940011978266, 0.0026389776439827983, 0.055823602378950454, 0.046303250346682034, 0.026439610264787916, 0.13877364486688748, 0.03342842421261594, 0.056063275260385126, 0.05962653405731544, 0.03793650750594679, 0.017080033394449856, 0.03090906477154931, 0.025280566696892492, 0.03943841402360704, 0.008403305673709838, 0.05313038556778338, 0.04819379362743348, 0.028661145843216218, 0.04399897457915358, 0.027639076761261094, 0.03184809123922605, 0.06865799630759284, 0.01991521377931349, 0.09754271784913726, 0.03839847217022907, 0.05256114345684182, 0.04738193973025773, 0.046714151540072635, 0.0339697355957469, 0.022114707571745384, 0.08220940508181229, 0.02920625702245161, 0.049236418344662525, 0.038691809750162065, 0.07596725292387418, 0.04689993707870599, 0.05251662943919655, 0.013763525712420233, 0.010713740339269862, 0.04596650454914197, 0.09094423832721077, 0.02361272338021081, 0.023442689926014282, 0.03241078018618282, 0.02938665456895251, 0.01717041955998866, 0.052763927888008766, 0.029729304151260294, 0.08874970022588968, 0.1075693778693676, 0.05088913669169415, 0.020286990802560467, 0.056759450599201955, 0.021931647570454516, 0.08614294361905195, 0.020633497697417624, 0.038939030273468234, 0.06581631285371259, 0.0010951040667350753, 0.0351694173150463, 0.019544980423233937, 0.02765645785984816, 0.08906716873752885, 0.016599487207713537, 0.011581079052120913, 0.024325589620275423, 0.07128517681849189, 0.07469072181265801, 0.08361284344573505, 0.055339280515909195, 0.05254832285572775, 0.013295398439368, 0.05931196363235358, 0.037462538602994755, 0.06277314372709952, 0.02032451007835334, 0.04263363436621148, 0.06674856907920912, 0.03872130640957039, 0.021916680307185743, 0.03074387197557371, 0.05442826455691829, 0.08590997604187578, 0.0570489475649083, 0.06314798025414348, 0.01734085934003815, 0.07817871941369958, 0.03536929994879756, 0.020303479468566366, 0.06737557996530086, 0.04482399417611305, 0.028172179991088342, 0.07128390774596483, 0.03765562687476631, 0.029622900583490264, 0.04450193919183221, 0.014375515529536642, 0.06244565622182563, 0.004795812092197593, 0.048493617578060366, 0.04437372575921472, 0.04708315849711653, 0.06594697537366301, 0.037655916312360205, 0.023362614047073293, 0.006759808975402848, 0.05862025231181178, 0.03244105610065162, 0.008517535188730108, 0.027719809440895915, 0.064911070803646, 0.018875455607485492, 0.006544835232489277, 0.027909044110856485, 0.03661885770270601, 0.023475112502637785, 0.030094357316556852, 0.05846519910846837, 0.028258378588361666, 0.046818901973892935, 0.07635762260179035, 0.049890365480678156, 0.04468637773243245, 0.04874909820500761, 0.03727553223143332, 0.017897818906931207, 0.1078866608440876, 0.01510062627858133, 0.02246056879812386, 0.04263423179509118, 0.09654985784436576, 0.03717651117767673, 0.018860486488847528, 0.06591374942217954, 0.032061328820418566, 0.025725645646161865, 0.026062161377922166, 0.023245135780598503, 0.005747398481616983, 0.06468407009379007, 0.057714475915418006, 0.027986268287349958, 0.002603519915282959, 0.06580413421033882, 0.042511064966674894, 0.04058962978888303, 0.01924488187796669, 0.007751323373668129, 0.01965669962373795, 0.02420876258838689, 0.12841737479902804, 0.09566005246597342, 0.12400936640915461, 0.13789188436931, 0.06514496606541798, 0.14428345311898738, 0.13860458362614736, 0.18909674923634157, 0.1484759640879929, 0.1801584116765298, 0.12359434258542024, 0.2298605759278871, 0.09251823707018048, 0.17431282612960786, 0.11707965153618716, 0.19056715158512816, 0.05662985306116752, 0.22183847904670984, 0.10380869294749573, 0.09934091198374517, 0.1627683182596229, 0.19908779358956963, 0.07452644742443226, 0.08053818499320187, 0.10788383326143958, 0.11564924352569506, 0.10550969542236999, 0.10521056537982076, 0.22481597552541643, 0.20228337758453563, 0.15958343603415415, 0.216447236307431, 0.12148711815825664, 0.10694212207454257, 0.14753705821931362, 0.11995365552138537, 0.11804045818280429, 0.08159659890225157, 0.1421034982195124, 0.10586524353129789, 0.14872848725644872, 0.07019819764536805, 0.23173813533503562, 0.13863536791177467, 0.168059638235718, 0.18482215673429891, 0.10450179950566962, 0.14405711292056367, 0.2322747526341118, 0.17959662072826177, 0.09649572559283115, 0.088887643214548, 0.15955667418893427, 0.11896540425368585, 0.10370643241913058, 0.19995770941022784, 0.13990154606290162, 0.1297127193538472, 0.11253349235630594, 0.18787290318869054, 0.23979722085641697, 0.1680245198076591, 0.11059737749747, 0.08974022988695651, 0.09562347942846827, 0.1108169493090827, 0.17023411608533934, 0.15037782141007483, 0.06853606144431978, 0.19103284925222397, 0.18322701420402154, 0.21284735994413495, 0.12870139471488073, 0.13171018013963476, 0.2603400615043938, 0.22932590305572376, 0.11651000866550021, 0.10105128778377548, 0.1269893639255315, 0.12152231080108322, 0.14746190834557638, 0.12053493526764214, 0.16944876057095826, 0.35513648414053023, 0.11353238602168858, 0.13893638300942257, 0.12316366686718538, 0.09589920213329606, 0.19138501316774637, 0.12147525863838382, 0.1765074607101269, 0.17114131740527228, 0.23062203428708017, 0.1610952799092047, 0.20791749557247385, 0.1157998178678099, 0.08571749262046069, 0.09134646752499975, 0.162333672051318, 0.19158978655468673, 0.1905473807710223, 0.1470070460345596, 0.13867817498976365, 0.22216505371034145, 0.12458532495656982, 0.09550767470500432, 0.10377828715718351, 0.10720794452936389, 0.16701739572454244, 0.1737377210520208, 0.13993659027619287, 0.22797356155933812, 0.21239600057015195, 0.10670626012142748, 0.16798904514871538, 0.11940044380025938, 0.13720593211473897, 0.24753235891694203, 0.08253042848082259, 0.1729912986047566, 0.14314036758150905, 0.14320610702270642, 0.06405225009075366, 0.15845290763536468, 0.10152646267670207, 0.09291053633205593, 0.10441738020745106, 0.07665180251933634, 0.24206326488638297, 0.06153259935672395, 0.11604459301452152, 0.139882116636727, 0.08611344324890524, 0.1876201425329782, 0.18112348567228764, 0.11232632925384678, 0.14974196412367746, 0.17640777543419972, 0.1884858577977866, 0.1350745136733167, 0.11615735493251123, 0.11683498771162704, 0.16740436636609957, 0.13275160628836602, 0.0763560418272391, 0.14464431500528008, 0.25177561794407666, 0.1472788947285153, 0.08031498407945037, 0.18006331287324429, 0.1221105147851631, 0.11721774295438081, 0.1698550715809688, 0.13869175629224628, 0.09148324534180574, 0.16914459876716137, 0.19214798550819978, 0.08633080346044153, 0.16091646684799343, 0.14019847934832796, 0.12112250842619687, 0.08671735849929973, 0.12352056568488479, 0.14149689639452845, 0.0802780177036766, 0.09537860780255869, 0.11197511528735049, 0.11047578402212821, 0.12638261367101222, 0.19057326688198373, 0.09058574389200658, 0.1280479336855933, 0.11222175322473049, 0.056501739818486385, 0.10780755532323383, 0.11548756665433757], [0.04450022111996077, 0.03922678319213446, 0.05696174150216393, 0.04447969331522472, 0.027315665502101183, 0.05797980855277274, 0.04353894692030735, 0.024724579343455844, 0.009075429861695739, 0.010803393633977976, 0.03904703502485063, 0.030417577472690027, 0.054450874085887335, 0.013438907535601174, 0.024426534691883717, 0.04203360054816585, 0.041381965202162974, 0.055177540561999194, 0.02412524314422626, 0.04712793597718701, 0.015846105270611588, 0.01153605666331714, 0.018994080492120702, 0.07564234809251502, 0.05209438080783002, 0.02737912283919286, 0.03311894120997749, 0.013927799172961386, 0.03778810023504775, 0.020442773165996186, 0.013893912710045697, 0.010538835613260744, 0.08065238667768426, 0.008360499523405451, 0.020034167064295616, 0.02782866395136807, 0.04238802059262525, 0.014672818033432122, 0.060739206383004785, 0.05598072617431171, 0.021424107617349364, 0.017311075098405126, 0.033028584730345756, 0.029518025839934126, 0.03976164160121698, 0.04330173054768238, 0.07243703454150818, 0.046830572246108204, 0.031187991698971018, 0.028432966973923612, 0.03983796406828333, 0.0038298113395285327, 0.1046722411410883, 0.014085915590840159, 0.015170056049100822, 0.020684093615273014, 0.05129842000314966, 0.010451091493450804, 0.030266511457739398, 0.029395224519248586, 0.04100073507288471, 0.00644144292891724, 0.04418401797011029, 0.0069723744491057005, 0.0679924976429902, 0.02634918513649609, 0.043688901569112204, 0.12925484392326325, 0.07590780689497478, 0.050215667361044325, 0.018344799609621987, 0.06498875882243738, 0.034683948833844624, 0.016633386658213567, 0.030797195286140777, 0.08660509382025339, 0.10265712466207333, 0.06285693219979294, 0.055951351969270036, 0.048444431740790606, 0.04797332010639366, 0.060974734369665384, 0.0035389492859394522, 0.029933940240880474, 0.042038791871163994, 0.018314492153876927, 0.03574991409550421, 0.09033700567670166, 0.06555037907673977, 0.06841938840807416, 0.0029252562399051385, 0.02072205075819511, 0.019486141100060195, 0.07581563957501203, 0.02517994445952354, 0.04288214251573663, 0.05194059667701367, 0.06579453824087977, 0.09557128418236971, 0.03398863067559432, 0.030520704458467662, 0.037718906096415594, 0.022439783097070176, 0.01897779591672588, 0.045483399808290415, 0.09954660563380457, 0.050531492015579715, 0.015420054987771437, 0.019360460246389266, 0.05773616889200639, 0.0179594802466454, 0.027572563631110825, 0.028794567297154572, 0.035479323341860436, 0.03323059732792899, 0.02862348555936478, 0.03583776211598888, 0.013978332935948856, 0.05883159741642885, 0.04472638691368047, 0.05759251878771465, 0.02476201883837348, 0.061662764637731016, 0.06946835477720015, 0.04535382453468628, 0.048383427201770246, 0.013842762036802014, 0.017309561117144767, 0.04801724411663599, 0.02604988625535043, 0.0764674085075967, 0.026605389357428066, 0.0390455804154044, 0.055450272411690094, 0.053303287422750145, 0.0625484436750412, 0.06584947943338193, 0.023577966749144252, 0.04318640822020825, 0.0025359510800626595, 0.018362848641118035, 0.024153962403943297, 0.04660252139728982, 0.016956256149569526, 0.0594854295195546, 0.06983783299801871, 0.018617839450598694, 0.010233160755888093, 0.022161817250889726, 0.04066316920216195, 0.014304821324913064, 0.058674970860010944, 0.021231364444247447, 0.025185655285895336, 0.04630636736692395, 0.04442211749847047, 0.02322711457964033, 0.07982085473486222, 0.026059036936203483, 0.07213687291368842, 0.03108404464001069, 0.029912262107245624, 0.030479613596980926, 0.033349493096466176, 0.10711607406847179, 0.046465335399261676, 0.025525499549985398, 0.007475399825125351, 0.02986308369145263, 0.025593936697987374, 0.0341178645612672, 0.08240554729127325, 0.022425231436500326, 0.060076149384258315, 0.03946920573071111, 0.025334904894407373, 0.049458554276498035, 0.04701958612713497, 0.015463683994312305, 0.0161673253387562, 0.030971134292485658, 0.04103363447939046, 0.04121589481655974, 0.007599229484185344, 0.012067209900123999, 0.07951848150696605, 0.01986951603612397, 0.009845585263974499, 0.035083432085230015, 0.05758083367254585, 0.026646233454812318, 0.04363218664366286, 0.04304676200263202, 0.04743501071061473, 0.032419118215329945, 0.048479386896360666, 0.01071924707503058, 0.010349789263273124, 0.017283610068261623, 0.05746548908064142, 0.062258263933472335, 0.02285874586959835, 0.017259879896300845, 0.06161632845760323, 0.014717257836309727, 0.0059599894666462205, 0.03672453582112212, 0.024184449830499943, 0.024510627445124555, 0.04684355983044952, 0.023170451604528353, 0.020979459113732446, 0.06271754944464192, 0.03249066125135869, 0.08584307885030285, 0.025062909626285546, 0.026764546637423337, 0.058286263592890464, 0.031700426116003655, 0.02921330371464137, 0.03719955115229823, 0.06989508226979524, 0.05996940628392622, 0.019695801529451273, 0.047622903948649764, 0.013212432822911069, 0.023822400507924613, 0.04263438764610328, 0.07583851256640628, 0.06753704903530888, 0.009595048268238315, 0.00848616924486123, 0.037197840501903556, 0.04450453299796209, 0.037020251984358765, 0.033720834107953124, 0.003362838801876933, 0.01974610800971277, 0.10377500686445273, 0.02099217952491017, 0.04917840095004067, 0.0149576830699516, 0.03493213043839205, 0.010665660302038305, 0.04159914729825687, 0.01465546940380591, 0.06917292805155739, 0.04255399449903052, 0.03937933535780758, 0.09529643721180037, 0.0470055038749706, 0.043189020580030046, 0.06555348867550492, 0.018590791878523305, 0.04002734902314842, 0.08812268191832118, 0.028762038964487147, 0.02773999956843909, 0.055584515794180334, 0.027626445407804567, 0.07860356927267276, 0.059257055836496875, 0.04578366162604652, 0.04579133543302305, 0.07720165973296389, 0.01972100857528858, 0.03409547767660115, 0.020933258565491997, 0.06242000759812072, 0.11367734972736798, 0.07109575846698135, 0.03289661603048444, 0.02912696225394029, 0.06403382256394252, 0.1001740172796417, 0.032632359507260844, 0.04012593963125255, 0.017709788371575996, 0.01918638765346259, 0.06484468569396995, 0.1162152127653826, 0.0640903519524727, 0.044583404742297716, 0.009767891679075547, 0.04196464389679022, 0.04533338578767143, 0.014682889905088814, 0.07085237113642506, 0.09166380245005712, 0.00775258456087613, 0.01125106824474642, 0.02118284653988667, 0.047811795375309885, 0.03728903189767152, 0.046376307363971137, 0.055526368523715064, 0.04693233553553, 0.005115224103064975, 0.04098287157830782, 0.042527176992734894, 0.01237264541487093, 0.04370454604213592, 0.057257854714407586, 0.07987372533534653, 0.04057241938426159, 0.030412041051022243, 0.06594563950784504, 0.04036352336697746, 0.055110201792558655, 0.01462060052290326, 0.08070035168202594, 0.03359424226800911, 0.057796973051154055, 0.05631477426504716, 0.014631188187195221, 0.031156398472376168, 0.04204787946946453, 0.015823204448679462, 0.06807194455177523, 0.017927896296896506, 0.02993112193507841, 0.026760221771837678, 0.03451089854934253, 0.061797857779311016, 0.04126623840420507, 0.040907250440795906, 0.003651552337942121, 0.044966189670958556, 0.052784537328989245, 0.019321074469189625, 0.04769046907313168, 0.03433013735048007, 0.008590471607021755, 0.0873199304623995, 0.017510440084151924, 0.030044956256460864, 0.057944515720009804, 0.006949436519789742, 0.026395304048492108, 0.05780599014542531, 0.062111340957926586, 0.03505325636069756, 0.020090536891075317, 0.0305328905233182, 0.028451696925912984, 0.03360903698194306, 0.04047414047818165, 0.04194872482912615, 0.04746739061374683, 0.018713188728725072, 0.02865756869141478, 0.0218436325667426, 0.12616084510227665, 0.12372478246106766, 0.14480347599601373, 0.07690817001275718, 0.11508032053825445, 0.19518084620358422, 0.11294194817310199, 0.11074963651481085, 0.06346960479277186, 0.11930506298085675, 0.1136669448169414, 0.12088427160051651, 0.16616719134617597, 0.1457417881465517, 0.10014658008003607, 0.10613730744807981, 0.07600540673593059, 0.12452136666979641, 0.1364358203136362, 0.1540755870519206, 0.048263930293614976, 0.131242701318115, 0.16657428903272375, 0.15859572653425857, 0.17157523630885407, 0.07370506806182675, 0.11284950625849888, 0.1526557101169601, 0.13367510517127812, 0.08787286758888513, 0.0788397726137191, 0.08345266571268439, 0.2796295186271891, 0.09780447333469056, 0.10225462829112075, 0.15831571421585977, 0.19648181623779237, 0.08730197791010141, 0.1521210075588897, 0.19632105220807716, 0.11810478012193926, 0.08818385715130717, 0.2449948521098122, 0.08556271030101925, 0.11402498654206283, 0.18334226973820478, 0.1487472784356214, 0.11472976708319038, 0.14340575959067792, 0.1537512833601795, 0.19213428546208888, 0.22747219627490267, 0.2898368099704385, 0.20186255016596988, 0.12466111307730898, 0.09871672868030146, 0.14759264508029446, 0.11558979749679565, 0.08521625350113027, 0.1270565134473145, 0.11274384669377469, 0.06972139002755284, 0.18375114857917652, 0.10470015331520699, 0.16595184977632016, 0.12941669148858637, 0.14791448484174907, 0.21610887633869424, 0.21160401025554165, 0.2036216776468791, 0.13802918168948963, 0.15531531505985186, 0.11026088031940162, 0.19952928239945322, 0.1744659460382536, 0.19876145641319454, 0.18412265286315233, 0.18708641960984096, 0.10121588871697895, 0.13002602441702038, 0.09363856835989282, 0.1585690982756205, 0.10881416732445359, 0.09510533418506384, 0.1877912224153988, 0.13528069714084268, 0.1366354283527471, 0.15336279873736203, 0.21000674518290907, 0.10980359118548222, 0.14547219558153301, 0.1410706661408767, 0.14152460818877444, 0.18444134591845796, 0.13654206617502496, 0.07568859131424688, 0.14320264861453325, 0.15300045255571604, 0.15111573884496465, 0.11253407865297049, 0.15290884184651077, 0.17183385993121192, 0.16214084724197164, 0.22441747190896422, 0.2457257339847274, 0.18734997109277174, 0.17119778000051156, 0.12250056533957832, 0.096495317411609, 0.1039388804929331, 0.0822451691783499, 0.08690515154739842, 0.15932230395264924, 0.22463480243459344, 0.15880041086347774, 0.16638446249999106, 0.1520424141199328, 0.10627876821672544, 0.15670797001803294, 0.14572333835531026, 0.15134825371205807, 0.1814571997965686, 0.12590159807587042, 0.16307623533066362, 0.1723070236039348, 0.17241625289898366, 0.12034738712827675, 0.15223164693452418, 0.08710757974768057, 0.19394191971514374, 0.13596345816040412, 0.09275142729165964, 0.1252171301166527, 0.2105172537267208, 0.2027699741302058, 0.10834172353497706, 0.15638428973034024, 0.16625209304038435, 0.1191119932627771, 0.09382586416904815, 0.16254254209343344, 0.1262710985611193, 0.13094495167024434, 0.10951244665193371, 0.11161086920765229, 0.1368306577205658, 0.19435443507973105, 0.2039892930770293, 0.09859876430709846, 0.17290491261519492, 0.13588743255240843, 0.21881072432734072, 0.11258264479693025, 0.15360188903287053, 0.14165613160002977, 0.10995559045113623, 0.11550180104677565, 0.2953031432116404, 0.15496074658585712, 0.18336321314563975, 0.11259618157055229, 0.06612759927520528, 0.10586057542241178, 0.1082401532039512, 0.2040665951790288, 0.12314860126934946, 0.12086874587112106, 0.10978870370308869, 0.20933568041073158, 0.09782906810869463, 0.12568754784297198, 0.26642303040716797, 0.11149815181852318, 0.1281245975405909, 0.148081200895831, 0.15810779412277043], [0.016566046033403836, 0.07968598423758522, 0.011343330188537948, 0.05109485260618385, 0.0310684168653097, 0.025934090808732435, 0.06401542472303845, 0.01559003834699979, 0.08720008845557459, 0.02958809014671715, 0.04488655351451598, 0.03596517773985397, 0.020273288901080377, 0.024519143589714076, 0.026906955499725882, 0.033676023231237195, 0.01694627611868782, 0.02264943796035368, 0.01755893386871321, 0.0495949164906051, 0.04955936390615534, 0.04434384318301454, 0.010117483125213766, 0.021159734205866698, 0.013351702400541399, 0.016789740475360304, 0.02852286332199583, 0.034789203928085044, 0.02383502258453518, 0.042279496337869205, 0.019002108674612828, 0.02909899256337667, 0.012720295217150124, 0.014157201658235863, 0.06352918440825306, 0.025176614071824588, 0.03562685116776265, 0.012162398688815301, 0.07884597696829587, 0.05599170253844932, 0.006062968950573122, 0.04573867634462658, 0.02038769467617385, 0.05702399284928106, 0.010110346447618213, 0.03387057353393175, 0.016540278666070662, 0.07005047315033153, 0.09153218255960383, 0.013907384545746027, 0.023500358511228114, 0.029593791696242988, 0.05419399822130799, 0.03479251390672289, 0.12962882698047906, 0.051458308298606426, 0.04295114369597286, 0.018556929535407107, 0.08834433916490525, 0.017379055825585965, 0.03946463039028458, 0.04648980400816072, 0.06178685915074311, 0.043910959575441666, 0.08896883417037316, 0.10846944715012796, 0.0305871804812341, 0.020164768357062712, 0.03586080209061038, 0.03832222391793039, 0.09066894606803544, 0.0558348347840365, 0.012023470499116229, 0.020909355844196398, 0.03234658441215288, 0.06848637465736829, 0.07419222863973118, 0.17725079582305625, 0.11935712464037351, 0.05905158483074047, 0.04835338877455797, 0.040825565956765786, 0.016538593990844674, 0.02373829291173024, 0.07562631770269945, 0.002757400989139569, 0.019635242279036902, 0.026131385202461388, 0.027350887830834836, 0.04019412073830608, 0.03449733580055181, 0.03788148838793859, 0.03565793973393738, 0.06808043472119607, 0.015299237056751736, 0.006900875014252961, 0.008211312069761334, 0.03515058531775139, 0.047580868704244494, 0.02549398795963498, 0.03667358738312032, 0.0428448347520316, 0.054883520206203684, 0.06067401984182652, 0.07343712306465022, 0.04265916795702651, 0.016112291377794463, 0.03096542346611386, 0.08550735350581817, 0.05564170940488111, 0.06692747119814157, 0.017843998357420787, 0.051238135347375646, 0.013364725236897357, 0.027092048985650763, 0.07796318488544784, 0.03586901766539086, 0.031837137139518745, 0.0033160331713588675, 0.03304394718725234, 0.015153399472183082, 0.016642062364553567, 0.0019965954879808123, 0.06865118339192122, 0.027486322360346094, 0.04496359957556706, 0.04131830377446022, 0.035608379112090915, 0.004440096536200144, 0.02470502189680701, 0.013901516012992943, 0.032264595647575334, 0.024660674862388987, 0.061884670503786765, 0.05638156755594537, 0.02147289640561212, 0.018025499848590698, 0.02235980184195796, 0.04058338461618405, 0.06625947149586864, 0.10694931348552927, 0.04969668349076528, 0.01610424278624123, 0.034293924254598096, 0.06040284650225658, 0.053246056704665534, 0.04627511552826036, 0.04342512744187843, 0.017825923350756057, 0.04763854842167348, 0.0383062640321441, 0.07157649204600602, 0.05250936752418056, 0.07055226888041943, 0.05068230384495109, 0.05038699215219822, 0.040031605240073986, 0.027717594130081125, 0.047215561353368685, 0.03462929707893636, 0.019689938562805764, 0.015017322984931525, 0.02385402527579572, 0.00369435129869089, 0.024303293648699764, 0.09127936995355412, 0.019489410260575823, 0.01946904943906702, 0.04103003506315872, 0.012605664942384465, 0.03154290527163539, 0.02634540018334519, 0.07005077743087895, 0.06339117462630384, 0.025011994584929198, 0.028189316180942114, 0.0038688960830768337, 0.016068526929302607, 0.05713493279472459, 0.026148363685933873, 0.0224315007289988, 0.014931793248251779, 0.023368515976471826, 0.056128216892830096, 0.02468856291670818, 0.017302406813541893, 0.059531683873501606, 0.013701564730581595, 0.014007695081090787, 0.009725490926939528, 0.0119769777302281, 0.03781658386287745, 0.012113729571865406, 0.05666786957590375, 0.03469239818514325, 0.06139943208836485, 0.0425134324177634, 0.03960932321206201, 0.02449875679303659, 0.011091559372289339, 0.00717461386557261, 0.05088507343316451, 0.03554038725269493, 0.015442590301972814, 0.03123745584161952, 0.02015357491472969, 0.011049122440454084, 0.012855105414928403, 0.01909275830257684, 0.028557677469507325, 0.04264456991222687, 0.03613996464991942, 0.02762252315733349, 0.03916326277249027, 0.09209677140461281, 0.05355610745027661, 0.020753319295181427, 0.04844686969590839, 0.06611563585465774, 0.017950283181562554, 0.0730762018065434, 0.008479212538077263, 0.04102981612959411, 0.025113516676356085, 0.053813669801456854, 0.0189365158075816, 0.01086634259991115, 0.010507625520403963, 0.03732972385478206, 0.04873098609095905, 0.024451138742733747, 0.03680297711980529, 0.0408505503583001, 0.036853554483968765, 0.05694454594049603, 0.04970381924067624, 0.015406123948196182, 0.055412793954019435, 0.027502742377691902, 0.01582228418556042, 0.08544007039745338, 0.03142093701171689, 0.022287477695499547, 0.03418836487981025, 0.08805222241790034, 0.051647392683662474, 0.020114380240556784, 0.0479753906984115, 0.07122846931451932, 0.04060478815517854, 0.027677271391439717, 0.09126165488851257, 0.0496172477141954, 0.1522582900361158, 0.2059880451997742, 0.011962767457589507, 0.06259711371967569, 0.07873603521147743, 0.03524303836456966, 0.03273000387707725, 0.09548524700221606, 0.06223436677828431, 0.019765320357691962, 0.056294394889846444, 0.13512392586562783, 0.050889121848740615, 0.061421956270351075, 0.04081153936567716, 0.0969985529081896, 0.08055107609834522, 0.06373941258061677, 0.04899891253444366, 0.03181356281857006, 0.06101098457293119, 0.048763751910883, 0.06445191887905821, 0.025397668323421385, 0.0015984469428076409, 0.06345561530906707, 0.12614564591785893, 0.1277838330133818, 0.046308849850902334, 0.07797070284141228, 0.012506616058090003, 0.11166978831170127, 0.033640311085036956, 0.03533581424562726, 0.010258344609610504, 0.003777517758862814, 0.05032674831454642, 0.06276320636970922, 0.044806134392274544, 0.01488485333538847, 0.03472996941127349, 0.043133418876095675, 0.03689245044370182, 0.018196069504483603, 0.024320505908690393, 0.0198887636361178, 0.029489345542970113, 0.02984109756653197, 0.1026792183984071, 0.041391594568267465, 0.016777585951786023, 0.0648950700997375, 0.02801081667712424, 0.01874423833214678, 0.0366284870688105, 0.055678067219560035, 0.035811820343951695, 0.05180919943086337, 0.015269920368154999, 0.016273344845103566, 0.03161568027280737, 0.017869945695565548, 0.04887513343419414, 0.030071397122810595, 0.03663522205897607, 0.02870129046641523, 0.038276581835816614, 0.010468995806149906, 0.1638737620669417, 0.08221776166465133, 0.038809733305242844, 0.028306631174928043, 0.05657937959767878, 0.02071436210826505, 0.027177457195648458, 0.0740430346922949, 0.043453948746901006, 0.04680989601183683, 0.06254372361581773, 0.040682004910195246, 0.04745874830405228, 0.02155654572561616, 0.04763825156260282, 0.01181056131827063, 0.03474904631730169, 0.08626374299637973, 0.102717928821221, 0.016798108190414496, 0.08151701098540798, 0.03341341427585576, 0.03323643060866743, 0.0625149802363012, 0.054119705528137274, 0.06741114368196577, 0.03516376957122702, 0.03600061158067547, 0.040736916416790336, 0.03119145752862096, 0.026026334198832046, 0.10945310452370904, 0.15802667738171294, 0.146001287503168, 0.14925067720469087, 0.2161176485242322, 0.18983808055054396, 0.12407641203026287, 0.07656970614334568, 0.20475466997595504, 0.1056874546338804, 0.14018077170476317, 0.07532174771768041, 0.12791296670911834, 0.03824738203547895, 0.12392563730827533, 0.16255351103609428, 0.16602652467554435, 0.11988492522505112, 0.13864701963029802, 0.11737805427401327, 0.16421684209490195, 0.12876293360022828, 0.08273322775494307, 0.056811827671481296, 0.10845927230548114, 0.10422673731227405, 0.23204967408673838, 0.10468462758581154, 0.09710172627819702, 0.11356062474078499, 0.20733633456984535, 0.09526558613288216, 0.06089426329708658, 0.14835040754405782, 0.11895705509232357, 0.19961694488301873, 0.12685733585385606, 0.10976337420288473, 0.18920759641332552, 0.14148625399684533, 0.18419180618366227, 0.21724072576034814, 0.19674946437589824, 0.11882994745974429, 0.12844787706853822, 0.1297608550521545, 0.15913933486444876, 0.19464878569124267, 0.16036316606914625, 0.16615853790426627, 0.12636869098059833, 0.18672722013434395, 0.20671048143412918, 0.18432620912790298, 0.18736168218310922, 0.18082379159750417, 0.12531363900052384, 0.11287629036814906, 0.1563843639451079, 0.17310584167717025, 0.12764994957251474, 0.13844833185430616, 0.19068072986556217, 0.07167361691244878, 0.2324144248268567, 0.3114420943893492, 0.11990900049568154, 0.10102506770635955, 0.1390963900485076, 0.16442569729406387, 0.2085254481062293, 0.16331746301148087, 0.16430057119578123, 0.102516702900175, 0.20254685485269874, 0.23076066747307777, 0.19592093070968986, 0.34885556960944086, 0.25222648750059307, 0.1199995499337092, 0.18389429402304813, 0.16474620118970051, 0.09042029691045173, 0.1249217998702079, 0.2518528903601691, 0.11872161616338417, 0.12492185924202204, 0.11172315615112893, 0.29001955641433597, 0.12301043563638814, 0.13993847533129156, 0.11441786467912607, 0.10076494494569488, 0.1319556380622089, 0.11557413075934164, 0.0858831028745044, 0.16010311752324924, 0.13756044121691957, 0.1731821641442366, 0.17326060915365815, 0.09845056483754888, 0.15606709581334144, 0.19932424183934927, 0.17584365414222702, 0.2628218033351004, 0.19015549711184576, 0.1370118308113888, 0.11948019498959184, 0.2565172588219866, 0.08052421777392738, 0.17510020028566942, 0.1537713361904025, 0.1460296820732765, 0.18388605618383735, 0.1551685034064576, 0.22166627109982073, 0.17980857810471207, 0.10242972319247201, 0.14081848436035216, 0.15968926629284397, 0.0853871923754923, 0.2089883404551074, 0.1943919135374017, 0.1489946065703407, 0.19494705484248698, 0.27679967985022813, 0.11156008404213935, 0.1307255431311205, 0.09389506201841868, 0.13984247110784054, 0.06904328969540074, 0.11336965530063026, 0.15563532913802192, 0.10684006192605011, 0.17574677418451756, 0.11844403808936477, 0.15776851389091462, 0.11787820985773578, 0.21110184345161542, 0.2098058903357014, 0.14641775109339505, 0.09965346005628817, 0.10430891532450914, 0.0872704885841813, 0.1429204543819651, 0.2853704761946574, 0.17309579299762845, 0.17605200468096882, 0.10963099732180126, 0.14211063768016174, 0.1171886210795492, 0.07021127428743057, 0.13588078290922567, 0.1331241792649962, 0.16498021519510075, 0.16701496148016304, 0.11325744257192127, 0.14903343573678285, 0.09153043109108694, 0.07459430940798484, 0.08181151744793169, 0.08724542625714093, 0.15839307568967342, 0.2106393370195292, 0.12915560393594205, 0.1508711269707419, 0.18242683057906106, 0.12143216954427771, 0.19426757411565632, 0.08394606775254942, 0.11428364727180451, 0.13148176192771643, 0.17071265290724114, 0.14018341375049204, 0.18539328390033916, 0.1012834909488447], [0.029905514129495714, 0.05224078428000212, 0.07125968404579908, 0.018784557360049803, 0.014195476996974321, 0.08955651122960262, 0.05086189616122283, 0.02440384909277782, 0.03726444083440583, 0.05996961779601406, 0.05385677744925488, 0.06003663002047688, 0.08062803681241348, 0.02008453848247882, 0.021290808617777657, 0.0500877507874975, 0.029169093977543525, 0.015901680999377277, 0.023762553719279822, 0.028099046903662384, 0.004403338889460429, 0.07816947225364856, 0.09349010913865641, 0.04289014657842927, 0.04406901105539873, 0.11892930619069375, 0.023427438791259192, 0.07995871608727612, 0.01520805679319892, 0.043246099157840945, 0.012020274625683669, 0.036854278077953495, 0.01850187331001507, 0.00814910896224319, 0.00898107877219445, 0.023355546945822425, 0.047484485985478386, 0.02083379222312942, 0.06076135206967592, 0.0421593648934504, 0.08210293657612056, 0.04905734553176444, 0.05245879016001709, 0.010042111534858122, 0.02333568892936455, 0.02828778619004879, 0.04485382109123748, 0.007405019641737454, 0.11371350716217421, 0.0303848060866585, 0.08202789060305804, 0.11013036622898653, 0.03833794631646015, 0.052245107290218584, 0.05988185883325059, 0.009056787112058373, 0.0391498892713571, 0.05928755439526867, 0.07790307834511623, 0.04692509588494431, 0.05879740296222735, 0.05425275034212973, 0.04000417917268351, 0.05408174096373841, 0.02336661607841961, 0.01847839175752597, 0.06456089584389701, 0.04721960976894479, 0.06103445870394353, 0.016592666870565154, 0.05499654929735698, 0.04645677843654994, 0.04619756480678916, 0.03692605489050038, 0.05648329373798333, 0.19610703166108578, 0.15926052758004516, 0.14871708786813542, 0.07420227731927298, 0.04271127414540388, 0.013172981180105126, 0.04858199994487222, 0.051914031500928104, 0.06294064645771869, 0.031304824296967126, 0.04702766440459527, 0.016714516386855394, 0.051018489320995286, 0.09610676599550061, 0.051308238616911694, 0.04437534364114981, 0.023391004906443413, 0.006066790547265555, 0.028588556378963403, 0.054289995023282245, 0.025080363084271085, 0.024532383504265454, 0.025926134985638782, 0.0276840917285881, 0.13627585780341178, 0.031496650917688385, 0.03051645566301886, 0.05062410462414846, 0.10123051644768566, 0.06366924251778983, 0.023761709526297636, 0.06328501782263629, 0.04123802937101573, 0.016638481502013747, 0.012634203303605318, 0.05602377816103399, 0.09629205058445223, 0.02733600776991807, 0.049383916484657675, 0.11029087792849168, 0.026772897654154804, 0.036036264355061576, 0.022072015526646283, 0.020170592360955197, 0.10247661208268255, 0.062119315334712155, 0.04229407953971531, 0.04038715334900189, 0.010137238168681506, 0.015515011855313787, 0.011746756099455524, 0.04263257309503388, 0.031416677084052935, 0.01709436983219348, 0.029349376491154544, 0.02330278581212042, 0.05518616802874021, 0.04650940783903934, 0.023469021325581707, 0.03804316154855769, 0.027625994553091004, 0.017303215754509438, 0.04521920265688095, 0.05514088217751123, 0.03528558569087181, 0.056247357570100576, 0.047757904321770184, 0.08588198965298943, 0.027031497156713158, 0.05861008488864172, 0.028179044857097324, 0.039308953782892786, 0.027015711675630882, 0.02897857910284074, 0.02681685877178097, 0.03331133928440977, 0.04973170915036462, 0.04209924351016525, 0.02176097401388688, 0.0711038701410871, 0.020693863989436068, 0.021834617327840533, 0.030171498001436703, 0.09468044721870683, 0.029125602268322837, 0.028605288098333403, 0.03662846109364182, 0.030831148542347364, 0.060164387032273225, 0.031803284073248506, 0.06795970955863595, 0.016652511803840753, 0.046960915642557666, 0.049353907743352465, 0.025253556232200935, 0.04705424071289599, 0.04072193245519884, 0.019250609402661212, 0.028294639923842624, 0.02073890864267014, 0.028912860070704482, 0.011903993072337471, 0.001942537219292717, 0.04555678337055724, 0.02565540879004402, 0.07285429222974926, 0.025180653210554738, 0.02614749908389058, 0.03991754085291177, 0.06415531956008635, 0.06827746008639224, 0.11082751749199815, 0.04092749994015321, 0.04997395728423726, 0.06484008437837474, 0.0752748514059931, 0.010179990513279336, 0.0461297213769285, 0.018860274976759683, 0.030848054666421376, 0.06929239156306721, 0.027330950033501722, 0.031998372433008626, 0.10125710759893991, 0.02216586010035826, 0.09657235976192169, 0.03654439431556966, 0.014425462068174966, 0.046756405718042515, 0.035531685571186244, 0.04389508132589981, 0.014640440913353814, 0.08425140214967541, 0.08257970708655193, 0.05289043067023158, 0.015191954043984879, 0.06419157347409055, 0.15279800951248035, 0.00569138998798735, 0.01903419728478184, 0.009315821698692162, 0.05597162373305764, 0.0590120060951449, 0.013737802873947658, 0.027089071118098218, 0.038056869016145356, 0.008052042539929971, 0.035991598197142594, 0.03281565514043905, 0.034437117938068695, 0.05157629493623972, 0.059920205603702925, 0.03675351297715679, 0.021589554598904215, 0.07238465375849046, 0.032287090143654495, 0.08056889506406151, 0.05808143083413597, 0.11813165328931063, 0.009271262224501697, 0.0029529443781939335, 0.03751138305233326, 0.04977151795173995, 0.02590145857539028, 0.030240252417570446, 0.011645045688055689, 0.02359393962251488, 0.03724511530890595, 0.06526340541313402, 0.12199883640278131, 0.0466441336175194, 0.05758486353443004, 0.008298918892251095, 0.05341316238627769, 0.027197639901714865, 0.01756189132720465, 0.28388220292981714, 0.126601547235623, 0.090455689933151, 0.05028195599152241, 0.0650385717744939, 0.04178278431936633, 0.05630205756460782, 0.0648057452053763, 0.06652273354120553, 0.07779698091326281, 0.04062358304508962, 0.0552498442993965, 0.056075773027259856, 0.07382501396932639, 0.029080776548653375, 0.021903406995988917, 0.03612544453062583, 0.08717454373254441, 0.16491958172991872, 0.1277161788311787, 0.005078341682747123, 0.026335772672609892, 0.061097088546375744, 0.08676318611833267, 0.11684922952554189, 0.03129383680061437, 0.010683641612558858, 0.014844848792563425, 0.07930719206342474, 0.04048581075039692, 0.04231357575918082, 0.059688221372198313, 0.04542695576674305, 0.03250855443184264, 0.023347579990513623, 0.027228426042711362, 0.08730404850211926, 0.02713410463911714, 0.03692665231938008, 0.01782645398634486, 0.04399642159114592, 0.02522543254599441, 0.040258672743220814, 0.013438125497486908, 0.022361584851751104, 0.03349208192958031, 0.020064589552930556, 0.03262611062382348, 0.09453686390770599, 0.04372215720650274, 0.017124480618804228, 0.0548376814549556, 0.04159797841566615, 0.025779876232263632, 0.04245402349624783, 0.016430066025350243, 0.03287576910224743, 0.06808386344346218, 0.03198115089617204, 0.021574065976892598, 0.024926024198066443, 0.057012571196537465, 0.016548176972719375, 0.06240421469556168, 0.014118378985585878, 0.04763934623042587, 0.016700486085028388, 0.026076700050907675, 0.05618352173769381, 0.021953552059130743, 0.03731493285158649, 0.04065471614012495, 0.056643326752237044, 0.07648600672837347, 0.019914772201445885, 0.029779588367091492, 0.07765690796077251, 0.09163817609078251, 0.060044177662348375, 0.02489093731128378, 0.04843319933570456, 0.05418104032287374, 0.0270841395467869, 0.021816959779243916, 0.019486643905111123, 0.04149171771132387, 0.05389940270106308, 0.05894437417737208, 0.06658091791905463, 0.028773525555152446, 0.02020471260038903, 0.022415787607314996, 0.013947924362582853, 0.05697147105820477, 0.04637614038074389, 0.05008417363569606, 0.07088642829330638, 0.01664604955294635, 0.021542756621784065, 0.02428606283501722, 0.05181312168133445, 0.14588153455406427, 0.0944124576926697, 0.17651406582444906, 0.12806642800569534, 0.1522101098089479, 0.13500524160917848, 0.15825313632376492, 0.0856090425804723, 0.11112139312899671, 0.25052581157069653, 0.15434105327585712, 0.11309117922792211, 0.17753959516994655, 0.1335255178855732, 0.12323170696618035, 0.15693364228354767, 0.18488495727069676, 0.07060899122734554, 0.1889904440031387, 0.1275298700784333, 0.11749055644031614, 0.15499086293857545, 0.3251628315774724, 0.11471477570012212, 0.1410907189710997, 0.23840824695071205, 0.1617447630269453, 0.1962945723789744, 0.10793392080813646, 0.119542127213208, 0.13826831651385874, 0.15644805505871773, 0.12706622073892504, 0.15200141788227484, 0.0835526997980196, 0.16610584541922435, 0.22749783005565405, 0.12093035897123627, 0.16204016748815775, 0.2148699646932073, 0.15668251435272396, 0.18360972491791472, 0.08163187318132259, 0.12350364471785724, 0.19548110431060195, 0.05225657718256116, 0.13106510537909344, 0.09424611271242611, 0.2678008424118161, 0.1521517027867958, 0.22218808997422457, 0.22249480476602912, 0.18811735179042444, 0.14011360734002665, 0.19628642359748483, 0.115753099671565, 0.10371495227445848, 0.2742725779535249, 0.18129701464204118, 0.08198436364182271, 0.12904469738714397, 0.13683947443496436, 0.10673669559764676, 0.1009275643446017, 0.12222891702549532, 0.12648645497392863, 0.10258932947181165, 0.14171182236168534, 0.16278691648039967, 0.14031060301931575, 0.1538232568418607, 0.18612398765981197, 0.13142084644641727, 0.1798275622422807, 0.11647362116491422, 0.43480553256813437, 0.2925343386596069, 0.35725231748074293, 0.21046070207376033, 0.15245883318129927, 0.16300365328788757, 0.1609811227535829, 0.17753935768269002, 0.13663842662936077, 0.12936437007738277, 0.2133746410254389, 0.09584610888850875, 0.0978102620865684, 0.21998224896378815, 0.17663931066635996, 0.19085942418314517, 0.13665407110238448, 0.19430255895713344, 0.20122546091442928, 0.14995381759945303, 0.08382530548260547, 0.1325934991473332, 0.10662420085282065, 0.3384474531048909, 0.19315481273224577, 0.13485574338119477, 0.1310494905919768, 0.21470007224706933, 0.2266978839179501, 0.16715773585019633, 0.144917173020076, 0.2249613919411786, 0.16452775744255632, 0.11377322778571397, 0.11722807365003973, 0.14843955432297662, 0.23482495016651228, 0.11465826857602224, 0.11562749859876931, 0.19987006176961586, 0.13963143399450928, 0.27511634049005806, 0.12460380443371832, 0.10360830565332435, 0.14230383356334642, 0.1943777088308707, 0.1762817142298445, 0.11767121744924225, 0.2711751207243651, 0.11730310478014871, 0.10373130178777501, 0.11637576899374835, 0.1323213684372604, 0.13430167076876387, 0.07034752517938614, 0.15322949417168275, 0.11623922866419889, 0.13717869529500604, 0.17487740755314007, 0.09582074228092097, 0.10345911170588806, 0.1142456493107602, 0.10925052789389156, 0.1727347678388469, 0.13845373468939215, 0.12507775478297845, 0.11868580753798597, 0.2663483703508973, 0.13024164800299332, 0.10668674163753167, 0.08531186438631266, 0.14749604713870212, 0.20636655535781756, 0.12996148725505918, 0.15331265924032778, 0.1570326744695194, 0.18580976233351976, 0.128626704972703, 0.1655298497644253, 0.12732405768474564, 0.11048441519960761, 0.08804773242445663, 0.05724442184146028, 0.18717755534453318, 0.12536434252979234, 0.1161671438603662, 0.1334662054432556, 0.15628139837644994, 0.12653221579967067, 0.1092748183873482, 0.15938059223117307, 0.0784815008228179, 0.1839909513364546, 0.10800768286571838, 0.09594393879524432, 0.15527086041402072, 0.14503112237434834, 0.14378553139977157, 0.12539248476969078, 0.16754478070652112, 0.20333347201813012], [0.09070763422641903, 0.025623759902373422, 0.04428007043316029, 0.09958251815987751, 0.03656512621091679, 0.017597794576431625, 0.015285358895198442, 0.05640476338157896, 0.046388066693907604, 0.018540585588198155, 0.02944814521470107, 0.030477548571070656, 0.07799344224622473, 0.05327121551090386, 0.03216290286218282, 0.03227495602914132, 0.08817311085294932, 0.03685557683638763, 0.03661181101051625, 0.016706803617125843, 0.030387691185751464, 0.040607474729768, 0.030371510511031374, 0.09203834211803041, 0.046051873796386644, 0.16669442789861932, 0.030357025643752422, 0.038031045987736434, 0.02214233587437775, 0.09041726152645424, 0.0733488668629434, 0.029550331528298557, 0.035981204418931156, 0.04057793725223746, 0.05246667918981984, 0.0050807981915568234, 0.04190932791971136, 0.05080147791886702, 0.021815417967445683, 0.043652317399391904, 0.03139416774502024, 0.019804214462055825, 0.009345311864308314, 0.040484241108060814, 0.02204856922617182, 0.0160920548660215, 0.0824906567868311, 0.03511456146952696, 0.008729235596547369, 0.01283860005059978, 0.04897174992947839, 0.02695282208151184, 0.06073788907087874, 0.04988674380001612, 0.026882965576078277, 0.04208321312034968, 0.10100187559146434, 0.037922588526271284, 0.028878294542664662, 0.09570355716277845, 0.03089285070018377, 0.08532567575457506, 0.0320922392711509, 0.06071904965210706, 0.08559217356378213, 0.03638888098066673, 0.015810122240509372, 0.011137457495351555, 0.05066113779321313, 0.041027571132872254, 0.027078475104644895, 0.06534296364407055, 0.007470569835277274, 0.10270470374962315, 0.07357985290582292, 0.11115740213426761, 0.16143898334121332, 0.1444748233188875, 0.1333041797624901, 0.04994842369342223, 0.11722284150891937, 0.04329373019572813, 0.04379361118481029, 0.2542439120588824, 0.3353958606021479, 0.1200036020600237, 0.09120904403971508, 0.07922334421891719, 0.240522833482828, 0.13385022233705968, 0.11590159600018524, 0.06319566324236803, 0.154074874590151, 0.09423548515769653, 0.2079136809334159, 0.07071976418956183, 0.08821353563689627, 0.054383398019126616, 0.06575443258043379, 0.09309183558798395, 0.028002563994959928, 0.06830283411545679, 0.050784074555849656, 0.11082759912824258, 0.058656083201640286, 0.03634760643763002, 0.02106909014401026, 0.08487626822898164, 0.03994868879090063, 0.036071861468371935, 0.021308959694579244, 0.07608323576278053, 0.04611276701325551, 0.01227900307640084, 0.030747642085771076, 0.040397818011115305, 0.030023832878214307, 0.032058319411589764, 0.0397448171133874, 0.09736597537994385, 0.011447341257735388, 0.02204368032835191, 0.022134580431156792, 0.015555756690446287, 0.09880219440674409, 0.03564871112757828, 0.016267270366370212, 0.07053965236991644, 0.0331887216452742, 0.05976711167022586, 0.07478134546545334, 0.0029259642951728893, 0.01684563347225776, 0.01916147561132675, 0.012827856535295723, 0.03324177407193929, 0.035052974344580434, 0.05673696723533794, 0.060002246318617836, 0.07198923747637309, 0.02837128336977912, 0.03931914718123153, 0.03164260539051611, 0.038097961733001284, 0.1626684400252998, 0.07734476806945167, 0.04282370209693909, 0.08296048821648583, 0.05388930207118392, 0.027201632656215224, 0.033665176742943004, 0.04929658054606989, 0.020139889711572323, 0.06239585069124587, 0.061322931505856104, 0.04744237281556707, 0.031123183653107844, 0.047831477131694555, 0.023707005821052007, 0.019378993529244326, 0.0699384904874023, 0.08734525996260345, 0.027322402347635943, 0.044024819871992804, 0.05545384585275315, 0.021699446260754485, 0.0119520128100703, 0.04664159547246527, 0.03603558157919906, 0.045786715563735925, 0.017335565971734468, 0.036663368009612896, 0.032793249702081084, 0.04927716596284881, 0.06025165617757011, 0.08833355575916357, 0.0622156683675712, 0.05688234654371627, 0.03520597550959792, 0.06576047366252169, 0.026545635337242857, 0.0533856509719044, 0.006929398996362579, 0.040253073239000514, 0.012209013912070077, 0.022662388437311165, 0.06641112195211463, 0.017534734288346954, 0.04653835901990533, 0.02814010251313448, 0.00988497104117414, 0.037325267257983796, 0.03195066346961539, 0.01735937035846291, 0.014777689066249877, 0.03360062473802827, 0.009793489280127687, 0.04676297372498084, 0.042885578659479506, 0.020307292252255138, 0.06726233565132134, 0.10447598018799908, 0.02697158357477747, 0.04823468596441671, 0.025525184137222823, 0.07881189012550749, 0.10914816346485168, 0.010058680909423856, 0.08903415058739483, 0.026769283394969534, 0.04159555901424028, 0.039756071782903746, 0.034220778179587796, 0.023083076703187544, 0.0088780658916221, 0.007553789173471159, 0.03854955859424081, 0.027677798316290136, 0.04584580165101215, 0.027524800862011034, 0.017056253127520904, 0.020907277830701787, 0.08636962520540692, 0.011568589634407545, 0.04494074142712634, 0.024861911915650126, 0.056886784586822614, 0.02990333963680314, 0.04683249440859072, 0.12437757555744611, 0.008348516621481394, 0.0384096192283323, 0.013438726637104992, 0.0751335390668828, 0.044075233963667415, 0.019059205806115642, 0.06064402965421323, 0.04462162163690664, 0.05996740248519927, 0.06838272631284781, 0.024868466935004108, 0.028588029454112984, 0.032123479977599345, 0.07827407054719515, 0.0377193699387135, 0.03976255815359764, 0.026710366146289743, 0.024400975125900004, 0.06007406766002532, 0.09223042477970012, 0.06828186102211475, 0.13387431245064363, 0.16459848411614075, 0.1269404563936405, 0.11549544826266356, 0.03208589390851557, 0.04590763368469197, 0.16260700504062697, 0.16255110647762194, 0.23117250006180257, 0.49572766351047903, 0.2708074904512614, 0.16246722894720733, 0.0675696664256975, 0.40741467266343534, 0.11218845305847935, 0.15323923114920035, 0.1983843563357368, 0.19236601365264505, 0.36572903918568045, 0.4408592905383557, 0.014088791413087165, 0.1804594713030383, 0.055584998190170154, 0.1134685316355899, 0.12620452791452408, 0.08081474632490426, 0.029275059678184334, 0.03243064747948665, 0.09659826071583666, 0.07600552547955886, 0.0752787476812955, 0.014481077687378274, 0.084030264406465, 0.03440533175307792, 0.051027543522650376, 0.030580208003812004, 0.04581217865052167, 0.05966736331174616, 0.061878314008936286, 0.03946081575122662, 0.054950001795077696, 0.016877189591468778, 0.013380327036429662, 0.07410394275211729, 0.0304327877893229, 0.07275505966390483, 0.09896125891827978, 0.04803235424333252, 0.06544529838720337, 0.11321825717459433, 0.06795101900934242, 0.020383444025355857, 0.05996614825562574, 0.06215807399712503, 0.07022686681011692, 0.013266051137179602, 0.004781031757374876, 0.03152021410642192, 0.03903930184605997, 0.040380384962190874, 0.07210853029391728, 0.031046443727973383, 0.059713732698583044, 0.04954830961651169, 0.011518706178321736, 0.08039364431169815, 0.0036124794223724166, 0.07178098341682926, 0.0470855556341121, 0.05555373150855303, 0.058998588065151125, 0.024375649336434435, 0.04954995347361546, 0.03417803789488971, 0.02073629442747915, 0.05427001269708853, 0.03504661042825319, 0.03254300492699258, 0.008736733143450692, 0.016584095064899884, 0.04923842214338947, 0.08376435289392248, 0.024367389232793357, 0.019372156493773218, 0.03218837337044533, 0.045602956088259816, 0.10538831716985442, 0.05047652855864726, 0.012535802870843327, 0.06150961133243982, 0.03127707168459892, 0.03200158964318689, 0.020965803596482147, 0.02001109554839786, 0.06078337159124203, 0.017035606579156592, 0.04903572305920534, 0.07173492573201656, 0.05533083858608734, 0.022075826454965863, 0.05206327739870176, 0.11289477726677433, 0.09680350907729007, 0.15755508706206456, 0.13151221966836601, 0.1303727409685962, 0.0915527920005843, 0.12629266537260264, 0.18665294599486515, 0.17218517779838294, 0.06998242562985979, 0.1268939088913612, 0.13886522589018568, 0.24999829300213605, 0.14212883514119312, 0.08974999655038118, 0.0859478404163383, 0.11745025782147422, 0.12441983344615437, 0.18692850542720407, 0.11915821422007866, 0.1095119642559439, 0.10592141668894328, 0.14138272439595312, 0.1779210739186965, 0.2176885525113903, 0.28254384349565953, 0.12795145448762923, 0.16675682767527178, 0.10992214927682653, 0.19566828879760578, 0.20040731731569394, 0.19268362317234278, 0.13290042174048722, 0.16672295605530962, 0.14128066424746066, 0.21644647931680083, 0.17139590374426916, 0.14778414886677638, 0.11335039656842127, 0.12412623240379617, 0.10150891088414937, 0.17192812752909958, 0.15989350533345714, 0.18130565324099734, 0.07550680224085227, 0.12139976737671532, 0.14473984425421804, 0.0974969199160114, 0.11476248837425373, 0.10631997967720963, 0.1892196637345478, 0.11292877505184151, 0.20579602190991864, 0.20869272819254547, 0.0834410882089287, 0.10581775350146927, 0.18668021250050515, 0.1462420105235651, 0.13659906311659142, 0.21296504972269759, 0.08464803555398248, 0.13984978868393227, 0.22880994714796543, 0.1579188581672497, 0.2045995314256288, 0.27189939748495817, 0.09849661510088481, 0.2423363900743425, 0.1208537099591922, 0.20574546681018546, 0.1774833700619638, 0.18355277250520885, 0.2087632767506875, 0.2733702154364437, 0.11195438710274175, 0.2372411306714639, 0.31538411567453295, 0.30847519577946514, 0.21687693981220946, 0.18491525173885748, 0.23808851488865912, 0.2708296658238396, 0.3150660014944151, 0.5736821726895869, 0.554684498347342, 0.5524202948436141, 0.2896145515842363, 0.1648633269360289, 0.6916920840740204, 0.29740538040641695, 0.3991361043881625, 0.2039640600560233, 0.3545080928597599, 0.7268371107056737, 0.45911760767921805, 0.17678903153864667, 0.17269454343477264, 0.11980464711086825, 0.14519264339469373, 0.16978516126982868, 0.20379073888761923, 0.28032859205268323, 0.1769720748416148, 0.30542965920176357, 0.1656105212168768, 0.15870813222136348, 0.08529900296707638, 0.19751157582504675, 0.17369561159284785, 0.09775362137588672, 0.14145137305604294, 0.14341735193738714, 0.16077121370472014, 0.18293104571057484, 0.11144203061121516, 0.12163153267465532, 0.27982796891592443, 0.16882526746485382, 0.16396283463109285, 0.2116544614546001, 0.1728944928618148, 0.2657751354854554, 0.0794017045700457, 0.1550598826725036, 0.16846115497173741, 0.18488964764401317, 0.11159784451592714, 0.18844195234123617, 0.1530268878559582, 0.14539149444317445, 0.11153143714182079, 0.06715116935083643, 0.16267366474494338, 0.07997944427188486, 0.15355900774011388, 0.15484129049582407, 0.13206324947532266, 0.16853395965881646, 0.2611361484741792, 0.08323442976688966, 0.19923779647797346, 0.09114966480410658, 0.22158556996146217, 0.24363198695937172, 0.3703704010695219, 0.2147807733854279, 0.17471446160925552, 0.15480632049730048, 0.11727681048796512, 0.16699090105248615, 0.10627691284753382, 0.14722583116963506, 0.15097661584150046, 0.08465467777568847, 0.1559283141978085, 0.18215467018308118, 0.13503685710020363, 0.18890523060690612, 0.08750161563511938, 0.15752744948258623, 0.14495920826448128, 0.1815096993232146, 0.10870155383599922, 0.07361633688560687, 0.12916284729726613, 0.1893376058433205, 0.07378309004707262, 0.12327524877036922, 0.12290168131585233, 0.10285876618581824, 0.09310005116276443, 0.11555749180843122, 0.14117100450675935, 0.13467170560033992, 0.16585017554461956, 0.18404481641482562], [0.014333377312141238, 0.060021364042768255, 0.0320166589517612, 0.02465421817760216, 0.14992962358519435, 0.03238581804907881, 0.05144415183167439, 0.07318342730286531, 0.027028914482798427, 0.021740843258157838, 0.05611090258753393, 0.08091962663456798, 0.0219368741454673, 0.02933000272605568, 0.010156754797208123, 0.04844612012675498, 0.0440678236191161, 0.007876322379161138, 0.025731473360792734, 0.016419970961578656, 0.015127833412407199, 0.04287291762011591, 0.056691217541811056, 0.04333000637416262, 0.05644968929118477, 0.056766085399431176, 0.03766784262552392, 0.0310244186402997, 0.02493786330887815, 0.010865308231586823, 0.028676690126303583, 0.0033896050535986433, 0.019381791425985284, 0.03365435994055588, 0.052821017598034814, 0.043722123809857294, 0.024185358961403836, 0.1255962043069303, 0.029545980687544215, 0.11548060530913062, 0.02577133782324381, 0.06693579067359678, 0.044172767011332326, 0.007052827431834885, 0.04996768613636959, 0.008349294948857278, 0.054552470392081887, 0.013532149114325875, 0.039162739558378235, 0.022124585557321552, 0.03984778268204536, 0.021351939321903046, 0.027250751700194087, 0.02564154361607507, 0.034460907481843606, 0.027168529159098398, 0.0425096029357519, 0.08128956498694606, 0.03133885176794138, 0.06697322460240684, 0.027230852865613997, 0.06275559193454683, 0.031763438164489344, 0.06852679944131523, 0.05024330494052265, 0.020094412757316604, 0.04581917710311245, 0.05745552574808244, 0.041366565637872554, 0.060649399092653766, 0.0332376106234733, 0.06817399727879092, 0.037560483542620204, 0.07656380606931634, 0.01102055346564157, 0.5142009363044053, 0.48974099569022655, 0.21261621062876657, 0.10539737879298627, 0.010413007257739082, 0.013833998200425413, 0.5927234853152186, 1.7151618213392794, 1.9270503264851868, 5.392348123714328, 1.6936383512802422, 0.41148873686324805, 0.3865840716753155, 2.173967845737934, 1.6789070167578757, 2.16489820741117, 2.1130989119410515, 1.8451345595531166, 2.6294045196846128, 1.8033257592469454, 0.25004463270306587, 0.04684909254137892, 0.05258060627966188, 0.3393524279817939, 0.429955538129434, 0.1536861970089376, 0.052072168327867985, 0.0965993590943981, 0.14049091521883383, 0.07336868220590986, 0.02513903356884839, 0.08752842200919986, 0.1170447409094777, 0.013627870393975172, 0.032499151420779526, 0.09626004917663522, 0.04338504033512436, 0.02676566356967669, 0.025390257978870068, 0.0006927524725597323, 0.058711280435090885, 0.09417436187504791, 0.10436548182042316, 0.07407899174722843, 0.05737057210353669, 0.02457846530887764, 0.03301592369098216, 0.05201596548431553, 0.03344877390190959, 0.05862209654878825, 0.08845721240504645, 0.04478776623727754, 0.07739507083897479, 0.041460840657236986, 0.028661887990892865, 0.032226727562374435, 0.026413386476633605, 0.02773964519292349, 0.023941016115713865, 0.0075825316253030906, 0.03527764099999331, 0.0267206448916113, 0.03233876959711779, 0.053238690888974816, 0.0055673293354630005, 0.024129089324560482, 0.07689607300562784, 0.06186439502926078, 0.05156150022230577, 0.05449156975373626, 0.021602015258395113, 0.04065733963216189, 0.05386914162954781, 0.04082067891431507, 0.014600004997191718, 0.04538689834589604, 0.043464242335176095, 0.026492992947169114, 0.04355734847194981, 0.10687066067475826, 0.03982509522757027, 0.04341440711868927, 0.03708989141159691, 0.040429622749798, 0.004724867876575445, 0.026035993250843603, 0.03525680149323307, 0.04304858768591657, 0.028321804384177085, 0.05692789956810884, 0.025117897203017492, 0.027117794088553637, 0.00456789390227641, 0.015420367617480224, 0.03418986401811708, 0.011732235980161931, 0.08833051295368932, 0.020559950862661935, 0.030760022964386735, 0.03703107991896104, 0.037777457837364636, 0.02642173749336507, 0.060658067377517, 0.03871219283610117, 0.020244985244062264, 0.026389745362394024, 0.00626554511654831, 0.02356231299927458, 0.05147376352397259, 0.03959456931625027, 0.004650119226425886, 0.050462717190384865, 0.038692566740792245, 0.023867506388342008, 0.04847269272431731, 0.06517581714433618, 0.020120428744121455, 0.045352555462159216, 0.03267124804551713, 0.04479147697566077, 0.05745455353462603, 0.012005663593299687, 0.020621745788957924, 0.053316093180910684, 0.03166254689858761, 0.0729224510723725, 0.052002521479153074, 0.02588860828836914, 0.02794857460685307, 0.05402347866038326, 0.06495914713013917, 0.03639662158093415, 0.00898154354217695, 0.03526272383169271, 0.04101652797544375, 0.03935399101465009, 0.04470493884582538, 0.021592495359072927, 0.01757848574925447, 0.09023052974953316, 0.063685317436466, 0.04260089452145621, 0.06190382162458263, 0.04477847083762754, 0.026455126717337407, 0.02028207221883349, 0.04532134815235622, 0.04982233280315995, 0.031125502864597365, 0.04579140222631395, 0.03754414887225721, 0.10254926834022626, 0.02937647786893649, 0.07951995838084258, 0.02037023936281912, 0.006289472421485698, 0.07749556505586952, 0.06858372216811404, 0.050792256733984686, 0.006762410203009495, 0.03493668722512666, 0.03297217779618222, 0.04394095347379334, 0.04624924054951407, 0.11007652341504581, 0.16360685607651249, 0.10941215281491168, 0.03895438901963644, 0.06919301798916422, 0.039080023489077576, 0.059970790389343165, 0.03764712186239194, 0.024784912238828838, 0.030306509506772272, 0.07173597216024064, 0.07575833093142137, 0.5837787652853876, 0.32259295228868723, 0.15596582234138623, 0.05398735462222248, 0.05132016864081379, 0.3132243175059557, 2.664997922256589, 4.995780978351831, 7.202003868296742, 14.505601935088634, 6.999525083228946, 3.0292162159457803, 3.641900564543903, 8.789873588830233, 7.5710186921060085, 7.740183239802718, 7.470083283260465, 6.696448121219873, 9.609404113143682, 7.482890971004963, 2.5715314876288176, 1.564218127168715, 0.3575585869839415, 0.24297530500916764, 0.39920910203363746, 0.31209631240926683, 0.04638102000171784, 0.03774563825572841, 0.04885756308794953, 0.13265414745546877, 0.08585598479839973, 0.058355257351649925, 0.024483179113303777, 0.04220321468892507, 0.058540545651339926, 0.051761783615802415, 0.0471907253813697, 0.02457130543916719, 0.05058668553829193, 0.014796433861192781, 0.006535149277624441, 0.025121446524281055, 0.01996385970414849, 0.07135191073757596, 0.03907455386070069, 0.030805286551185418, 0.06947731249965727, 0.049694219560478814, 0.05875800605281256, 0.03618484603066463, 0.053466990357264876, 0.031112281503737904, 0.11185875395312905, 0.04662621817260515, 0.054391773155657575, 0.037822086887899786, 0.06769143059500493, 0.01545472627185518, 0.04491331535973586, 0.02770090508420253, 0.046271200699266046, 0.03851969457173254, 0.014263722114264965, 0.011497863888507709, 0.040886017595767044, 0.028540348321257625, 0.013780050558125367, 0.06854904160718434, 0.02279316042404389, 0.07634032313944772, 0.02328033955564024, 0.049312870687572286, 0.050265035024494864, 0.05381385162763763, 0.019387988359085284, 0.04432339330378454, 0.06409685316612013, 0.024373615851800423, 0.005120616269778111, 0.06728854088578373, 0.054128633564687334, 0.05128398894157726, 0.028035094182996545, 0.07406353281112388, 0.014950205932109384, 0.019092864058620762, 0.02573947742348537, 0.024405748990830034, 0.014112336048128782, 0.04274165396054741, 0.011904607199539896, 0.043322859492036514, 0.010551167324592825, 0.03624439224950038, 0.03006671973707853, 0.05792462616227567, 0.07518294383771718, 0.056600464013172314, 0.0475602184451418, 0.012162234488641843, 0.08868829492712393, 0.1216905185719952, 0.16099632193800062, 0.11697509777150117, 0.1520787793560885, 0.18979387823492289, 0.10584346149698831, 0.1277618802851066, 0.16371566976886243, 0.09275759453885257, 0.12490425549913198, 0.18140896019758657, 0.18430510244797915, 0.12880633439635858, 0.12406703870510682, 0.1782420527888462, 0.22150601173052564, 0.14947520656278357, 0.133422210928984, 0.10044847833341919, 0.2630134258652106, 0.1854123274097219, 0.11497508399770595, 0.15410684631206095, 0.10321708250558004, 0.19471583131235093, 0.18225791776785627, 0.09956590147339739, 0.09265914122806862, 0.13396681373706087, 0.17591267387615517, 0.21030149655416608, 0.11321577840135433, 0.13956075184978545, 0.17957356962142512, 0.12489665590692312, 0.1303897361503914, 0.1065056056540925, 0.2912120393011719, 0.2249302959535271, 0.1782700020703487, 0.17641910060774535, 0.22539452416822314, 0.13103607256198302, 0.08049655050854199, 0.12399572573485784, 0.12328767974395305, 0.17364239960443228, 0.09463286070968024, 0.11497342900838703, 0.05995730927679688, 0.276088880491443, 0.08481800963636488, 0.19390046334592625, 0.08362408698303625, 0.10192965666647069, 0.16696326347300783, 0.23952868214109913, 0.15332874900195748, 0.13010723021579906, 0.10464753504493274, 0.20303336234064773, 0.23652041621971875, 0.11584336709347554, 0.15295426128432155, 0.2801137848291546, 0.2172919933218509, 0.09756378742167726, 0.1246639629243873, 0.08389422131585889, 0.20952890597982332, 0.14303884177934378, 0.13066859071841463, 0.16450319235445932, 0.15117545204702765, 0.2611146558774635, 0.8630630071274936, 0.9278209728654474, 0.31118652841541916, 0.1875619581551291, 0.22625698882620782, 0.20207999943522736, 1.650723097845912, 3.372163726016879, 5.214131511747837, 11.362232007086277, 5.666416492313147, 1.9902397482655942, 2.9324194975197315, 6.553137861192226, 6.057093003764749, 6.6052948124706745, 5.390165615826845, 4.379985071718693, 6.949638510122895, 4.945157244801521, 1.5925383637659252, 0.7361423957627267, 0.21020035666879267, 0.5186458071693778, 0.6132162013091147, 0.3885084902867675, 0.1395505398977548, 0.2259874704759568, 0.2086574910208583, 0.2532451890874654, 0.19062750303419307, 0.19213327614124864, 0.17526038544019684, 0.1442305973614566, 0.12270619219634682, 0.1513346575666219, 0.289314248948358, 0.15548030933132395, 0.1917086192406714, 0.2635980601189658, 0.19324634922668338, 0.17500088608358055, 0.18597238173242658, 0.31429146649315953, 0.15117536298930645, 0.11974958717473783, 0.11984288255916908, 0.12178229255368933, 0.1309111394220963, 0.1156163886480499, 0.2918347605736926, 0.12195316463476047, 0.1623175377608277, 0.14305361051810905, 0.1658006149227731, 0.08685346096171997, 0.11795389407780021, 0.09004389445181005, 0.20625287317670882, 0.14576466113794595, 0.16516906209290028, 0.09499199339188635, 0.22152980498503894, 0.17400199983967468, 0.09361552467453294, 0.19775525259319693, 0.15973058907547966, 0.28718452260363847, 0.13596797041827813, 0.15020757273305207, 0.12800537893781438, 0.1326534349936992, 0.10026488584117033, 0.16683852329151705, 0.08398016201681457, 0.2503999730106443, 0.23243413626914844, 0.14090497425058857, 0.10473144226125441, 0.13760882924543694, 0.17529143689898774, 0.15152325213421136, 0.12678764818701893, 0.18702382687479258, 0.1383988157613203, 0.07470937940524891, 0.09527319314656779, 0.12475235271267593, 0.11747791766538285, 0.09568571593263187, 0.06891220415127464, 0.06640553358010948, 0.11983503063675016, 0.07617648661835119, 0.13414837274467573, 0.2807817474240437, 0.14987807400757447, 0.27621424407698214, 0.12705888831987977, 0.190932807745412, 0.14459295838605613], [0.0628335025976412, 0.036765546901733615, 0.018528811415308155, 0.01015373240079498, 0.07589473025291227, 0.02760096191195771, 0.015412187294714386, 0.008454991620965302, 0.010175989409617614, 0.11903394901310094, 0.02043577842414379, 0.03670943682664074, 0.03363798816280905, 0.0120760182653612, 0.031858815273153596, 0.04619017672666814, 0.020626877740141936, 0.08722900995053351, 0.00290385432435869, 0.06531363396788947, 0.01777515673893504, 0.025710195986903273, 0.0611401442438364, 0.011445009058661526, 0.04719572374597192, 0.06611173215787858, 0.09350893742521293, 0.030105138866929337, 0.08524585035047494, 0.03567335043044295, 0.07456776278559119, 0.023312136872846168, 0.04198207694571465, 0.04330170828325208, 0.015927396416373085, 0.036953937378712, 0.03205323198926635, 0.038503445248352364, 0.038878129635122605, 0.040211405357695185, 0.04622113541699946, 0.03964259369240608, 0.04055370984133333, 0.04419901677465532, 0.035658700435305946, 0.02733436947892187, 0.053138508374104276, 0.011195560236956226, 0.024808685084281024, 0.02067116725811502, 0.029078357147227507, 0.060726411757059395, 0.050928585551446304, 0.06727439555106685, 0.10910286277066916, 0.05666306788043585, 0.01768337533576414, 0.03466859750915319, 0.02234266750747338, 0.15492776554310694, 0.046131469134707004, 0.06593621423235163, 0.011200752487638965, 0.018739232546067797, 0.06239047754206695, 0.024207623391703237, 0.04670405833167024, 0.08861326379701495, 0.06223978074558545, 0.11217187347938307, 0.11698370668455027, 0.0927133699588012, 0.28832199750468135, 0.2043125726049766, 1.3153705489821732, 9.088161382824183, 19.19994793832302, 37.427353262901306, 38.173720613121986, 43.15390057861805, 56.630394235253334, 66.99118807911873, 81.37859165668488, 93.42410489916801, 113.10353010892868, 90.62104851007462, 83.09592470526695, 82.52165392041206, 90.3557999432087, 95.8349159359932, 93.7833984196186, 99.14667382836342, 88.92373278737068, 97.42585256695747, 94.21790510416031, 79.61984843015671, 75.26938587427139, 56.55684158205986, 36.60118259489536, 13.967476710677147, 2.4310086155310273, 0.5260998790618032, 0.3537054156186059, 0.537868085084483, 0.2855248429113999, 0.187873333634343, 0.013304981421242701, 0.031930952027323656, 0.0057049230508710025, 0.041589287866372615, 0.02486083765688818, 0.11231838827370666, 0.06495753666968085, 0.04350848546891939, 0.11134667947771959, 0.021839701039425563, 0.04109303226869088, 0.031048467935761437, 0.01587627542903647, 0.02753314074652735, 0.046518295057467185, 0.0052989534287917195, 0.034312570714973845, 0.020274454072932713, 0.033758338540792465, 0.026576054115139414, 0.06677395052975044, 0.023082777988747694, 0.026932583714369684, 0.05547739790927153, 0.08950470932177268, 0.025349573443236295, 0.021079663893033285, 0.04072264491696842, 0.03901085161487572, 0.020897533431707416, 0.06181244840263389, 0.010269154918205459, 0.06092473216995131, 0.1047715033928398, 0.028541062638396397, 0.044947977366973646, 0.01395087532728212, 0.05343400189303793, 0.017440578012610786, 0.09622637793654576, 0.034064259234583005, 0.07898201263742521, 0.0131962252453377, 0.011760284523916198, 0.06640301769948564, 0.09592064277967438, 0.003582902054404258, 0.02379713965638075, 0.02511288214009255, 0.01881864976894576, 0.017195801010529976, 0.016423067572759464, 0.03069392729230458, 0.035847109465976246, 0.018603484459163155, 0.016787042768555693, 0.04754130852234084, 0.024041643919190392, 0.021070164402772207, 0.04574509592202958, 0.08838711655698717, 0.016301850737363566, 0.046780009724898264, 0.021876422506466042, 0.008445164658041904, 0.03628668353485409, 0.03872432323987596, 0.05308022751705721, 0.0477206076902803, 0.028080079464416485, 0.02330240731680533, 0.03261862977524288, 0.07902197728981264, 0.03945043310523033, 0.06038550993253011, 0.020423701826075558, 0.036809626762988046, 0.08489877014653757, 0.014611968417739263, 0.12444851745385677, 0.028722193055727985, 0.02790146678307792, 0.05865230195922777, 0.03361212060553953, 0.05171997101570014, 0.01975232535187388, 0.06584510818356648, 0.01141819526310428, 0.04492514519370161, 0.03685081966978032, 0.028763744048774242, 0.0696994224563241, 0.020716890976473223, 0.01543092745123431, 0.01676457053690683, 0.008141341459122486, 0.024612117995275185, 0.04478551010834053, 0.07474394864402711, 0.04301435983506963, 0.11522048254846595, 0.08186406892491505, 0.052421538057387806, 0.026381308998679742, 0.028501339184003882, 0.05312327208230272, 0.010710245751397451, 0.0622619672503788, 0.02132212910510134, 0.049702642936608754, 0.06527660822030157, 0.01808856013667537, 0.05029242027376313, 0.05162310590094421, 0.008728837619855767, 0.011319993354845792, 0.043871655434486456, 0.03368997931829654, 0.016457933670608327, 0.0951600749976933, 0.06920848434674554, 0.02790723698126385, 0.01580239833856467, 0.06398285928298719, 0.13959244155557826, 0.05751405522460118, 0.04962391220033169, 0.04328522518335376, 0.04906130488961935, 0.09518910781480372, 0.012663922607316636, 0.05219980659603607, 0.04585959446558263, 0.013005134278500918, 0.0468506250763312, 0.008684878357598791, 0.03837021860817913, 0.10006908501964062, 0.07052443834254518, 0.05988938421069179, 0.21273942198604345, 0.028108264377806336, 1.4023895608261228, 0.4521685524377972, 5.3945928532630205, 20.355500131845474, 35.883819088339806, 61.22905567288399, 61.3900226354599, 67.09618404507637, 84.05313894152641, 92.43226692080498, 109.03509601950645, 119.36550289392471, 137.67554998397827, 116.18489116430283, 110.9741623699665, 112.45486691594124, 117.72760838270187, 121.78032651543617, 121.72455310821533, 126.99401915073395, 117.87254020571709, 125.39412260055542, 124.80231195688248, 112.97749847173691, 106.05518192052841, 88.57798174023628, 64.80428382754326, 29.935110993683338, 8.052353113889694, 0.7453164097387344, 0.21034782141214237, 0.32224426162429154, 0.2553734905086458, 0.3447032830445096, 0.0516973614867311, 0.04999390621378552, 0.05609674612060189, 0.017289625175180845, 0.04262640213710256, 0.07555348332971334, 0.06138382843346335, 0.010401393574284157, 0.08584236638853326, 0.01217647259181831, 0.009452817521378165, 0.014321353592094965, 0.041096037966781296, 0.05982810507703107, 0.0024084468623186694, 0.05890583444852382, 0.05744033769587986, 0.06900083884829655, 0.010709421967476374, 0.0606412020715652, 0.06506292163976468, 0.04401057063660119, 0.02352197541767964, 0.025745718885445967, 0.02886033085815143, 0.016583041215199046, 0.006221943476703018, 0.018407843199383933, 0.04343955479271244, 0.03258674711105414, 0.024904151250666473, 0.04091891700227279, 0.034844197070924565, 0.04489974147872999, 0.0032901809208851773, 0.06668657748377882, 0.04762438082252629, 0.01700879463896854, 0.0264268657338107, 0.02587714210676495, 0.006402203262041439, 0.056912125219241716, 0.032670413129380904, 0.02783627282042289, 0.033003648568410426, 0.0741417848621495, 0.02056195280601969, 0.026827569818124175, 0.008973187887022505, 0.07947914025862701, 0.013090435804770095, 0.03433076817600522, 0.01509998895926401, 0.00991385079032625, 0.043589245979092084, 0.016416102516814135, 0.0042736272462207125, 0.06094783151638694, 0.033241770361200906, 0.07516329918871634, 0.051545993046602234, 0.028676189176621847, 0.019376019372430164, 0.02839318971382454, 0.007121980752344825, 0.015109618325368501, 0.055020609725033864, 0.03528819805069361, 0.016043327304942068, 0.0409941856196383, 0.19100310397334397, 0.13677474431460723, 0.12318512235651724, 0.16636507760267705, 0.1760337033192627, 0.10265243428875692, 0.1655511642456986, 0.18701621243963018, 0.09467203126405366, 0.2575326949590817, 0.12011975559289567, 0.17962127487407997, 0.0864372645446565, 0.12412280368153006, 0.14509886561427265, 0.11736447297153063, 0.14138593047391623, 0.227211628225632, 0.1095638626429718, 0.1550012975349091, 0.10153838898986578, 0.16204988962272182, 0.08467935418593697, 0.08792764550889842, 0.20788228808669373, 0.24010810651816428, 0.09735093204653822, 0.12337576525169425, 0.16404426307417452, 0.1167940953746438, 0.23390262387692928, 0.21079217491205782, 0.17590862174984068, 0.12723770138109103, 0.1011606803513132, 0.13438590453006327, 0.09253264957806095, 0.18866940576117486, 0.11936627532122657, 0.10790526648634113, 0.11908236672752537, 0.1198234902403783, 0.13736249558860436, 0.16223311104113236, 0.13826583774061874, 0.10926042072242126, 0.08575091895181686, 0.20017311035189778, 0.11519405466970056, 0.19408836029469967, 0.23080323706381023, 0.2118874216102995, 0.15899498714134097, 0.1707871348480694, 0.14993300777859986, 0.1722594816237688, 0.1685401491704397, 0.1118160730402451, 0.1195301563711837, 0.32361984718590975, 0.14933013153495267, 0.21834241430042312, 0.2915249881334603, 0.09430932885152288, 0.15699132200097665, 0.24405379401287064, 0.1387370569864288, 0.18368545366683975, 0.23631552408915013, 0.2389237575698644, 0.21734912384999916, 0.152478544623591, 0.76011584373191, 0.26786971371620893, 3.2349830120801926, 16.293331906199455, 32.04572103917599, 58.622076362371445, 58.77655327320099, 64.90570038557053, 84.0264567732811, 96.22934997081757, 115.82493647933006, 128.23285907506943, 151.29224091768265, 126.87333762645721, 115.88960140943527, 122.1700032055378, 130.69950431585312, 134.5211112499237, 133.70444387197495, 140.25778502225876, 128.81641656160355, 139.84649509191513, 136.0323205590248, 117.2249485552311, 110.59726059436798, 90.43222904205322, 62.955082654953, 24.788064882159233, 6.085569150745869, 0.5880032479763031, 0.33259199699386954, 0.7579708588309586, 0.6862823024857789, 0.49298213270958513, 0.13415527471806854, 0.2347673149779439, 0.19898555532563478, 0.12940414919285104, 0.09173690399620682, 0.22205494868103415, 0.12856768938945606, 0.1990400586510077, 0.2716176782269031, 0.07493060620618053, 0.12157478806329891, 0.10798417162732221, 0.1434004754992202, 0.11005378401023336, 0.14044825657038018, 0.14722329302458093, 0.15735834371298552, 0.15136890026042238, 0.09678341913968325, 0.11535384648595937, 0.21398710581706837, 0.08935440215282142, 0.11360657852492295, 0.12041218404192477, 0.19840758555801585, 0.1664829603396356, 0.0934100165613927, 0.12406109410221688, 0.12170970308943652, 0.1250803077709861, 0.17180450056912377, 0.13897764642024413, 0.1654491337831132, 0.18639879010152072, 0.0919770184555091, 0.19496010179864243, 0.08007621290744282, 0.1675929015618749, 0.16116453713038936, 0.21423663070891052, 0.20098312001209706, 0.183477800746914, 0.11322745980578475, 0.09405987075297162, 0.35934829094912857, 0.27107683068607, 0.1529423869214952, 0.10511528846109286, 0.12028991521219723, 0.13770069228485227, 0.15501185087487102, 0.10335639846744016, 0.10960723375319503, 0.09876136144157499, 0.09961188494344242, 0.11631138768279925, 0.16311040380969644, 0.1118135942670051, 0.07535851371358149, 0.14123257307801396, 0.25557936227414757, 0.12765368999680504, 0.10058639163617045, 0.12112742886529304, 0.0592462279018946, 0.11876128395670094, 0.15432696731295437, 0.13689016312127933, 0.07341172677115537, 0.2614800597075373], [0.056212528579635546, 0.024622561868454795, 0.059106540866196156, 0.05282685087877326, 0.0596986262826249, 0.05095170345157385, 0.041451430224697106, 0.06694092633551918, 0.04153928566665854, 0.05365819357393775, 0.0058762037770065945, 0.04845641000429168, 0.12475597439333797, 0.03911334591975901, 0.011536436086316826, 0.05134724960953463, 0.020357723042252474, 0.0834534152818378, 0.037898661685176194, 0.03319281830044929, 0.04530498008534778, 0.03095414282142883, 0.03323415221530013, 0.01322824798990041, 0.024878931217244826, 0.06365215827827342, 0.0378111068130238, 0.01315645633439999, 0.006800365490562399, 0.011950256703130435, 0.042489538973313756, 0.037104277944308706, 0.025379112776136026, 0.002455595040373737, 0.04032480181194842, 0.023742443372611888, 0.1050268838298507, 0.09086443518754095, 0.07066500111250207, 0.07895623784861527, 0.04803833224286791, 0.012283876203582622, 0.017656088421063032, 0.01558512532938039, 0.04288271025870927, 0.008260951544798445, 0.0095435729053861, 0.01740325169521384, 0.06342963271890767, 0.034391397930448875, 0.0601813896355452, 0.00490892467496451, 0.0338066449330654, 0.035728966977330856, 0.06052815071598161, 0.03127615884295665, 0.03137409265036695, 0.04608745235600509, 0.09641040087444708, 0.019186576901120134, 0.04242041533871088, 0.05177690116397571, 0.05986659656628035, 0.04872639961831737, 0.17939230747288093, 0.15517163526965305, 0.11498897700221278, 0.9159284422639757, 3.064757133834064, 13.86121541261673, 24.26446057856083, 37.52097263932228, 57.979211658239365, 56.61293417215347, 79.00158360600471, 89.15192574262619, 99.4149774312973, 103.04281756281853, 105.2212406694889, 112.71461337804794, 112.40454241633415, 109.38842386007309, 109.2711241543293, 107.4651038646698, 104.21890005469322, 114.335196018219, 111.86978951096535, 104.50604304671288, 109.92145925760269, 104.35207530856133, 109.37058001756668, 97.14712232351303, 109.46739882230759, 111.80023804306984, 120.36400571465492, 116.4712741971016, 119.1677539050579, 116.95853725075722, 121.31979122757912, 112.31061905622482, 87.57222890853882, 47.16333903372288, 39.39752474427223, 21.372962035238743, 11.197755932807922, 1.811612758319825, 0.3157005674438551, 0.15985835721949115, 0.29139811056666076, 0.10944623965770006, 0.023026246744848322, 0.03599409552407451, 0.07578562712296844, 0.016624877935100812, 0.08354751960723661, 0.08010848148842342, 0.027483262856549118, 0.012807997591153253, 0.04236853179463651, 0.09764926056959666, 0.042889111282420345, 0.011350693221174879, 0.025185204431181774, 0.024750710363150574, 0.020889841071038973, 0.09935424837749451, 0.022019931602699216, 0.05950289596512448, 0.06584396527614444, 0.04952879113261588, 0.06812942388933152, 0.019827593969239388, 0.006569552460859995, 0.015939179866109043, 0.027178694726899266, 0.004510329217737308, 0.021239166271698195, 0.04239815832988825, 0.04864055910729803, 0.03287030318460893, 0.016219698700297158, 0.03537374170264229, 0.02579133870312944, 0.034804766764864326, 0.022596919880015776, 0.007043220794002991, 0.06069631766877137, 0.039278885669773445, 0.024132605249178596, 0.06516967216157354, 0.05805263550428208, 0.039195516510517336, 0.04102506267372519, 0.05379091184295248, 0.03956225991714746, 0.033713330994942226, 0.0489732973073842, 0.013537776449084049, 0.02149194733647164, 0.039561888843309134, 0.03419031301746145, 0.051257850500405766, 0.02760502145974897, 0.031852618340053596, 0.06617684819502756, 0.07704951945925131, 0.024804002132441383, 0.02128994216036517, 0.04599062434863299, 0.05493598633620422, 0.029405571913230233, 0.07139621695387177, 0.050853272405220196, 0.06505102501250803, 0.02444494552037213, 0.05743285684729926, 0.009151310750894481, 0.015390086136903847, 0.047262476218747906, 0.026858945966523606, 0.027969777765974868, 0.03422957262955606, 0.032050048175733536, 0.06405204971088096, 0.035391015189816244, 0.021124779050296638, 0.0223223901775782, 0.021305646005203016, 0.0347333090758184, 0.054505143634742126, 0.05511593488336075, 0.015302459833037574, 0.03665350115625188, 0.05703287635697052, 0.053271041106199846, 0.03566321269317996, 0.03534754388965666, 0.03577626033802517, 0.027090813309769146, 0.08962328967754729, 0.07091512714396231, 0.06578054133569822, 0.03546305175404996, 0.011885663880093489, 0.1045995848835446, 0.030371948378160596, 0.036660922633018345, 0.02404063088761177, 0.046919143860577606, 0.02644809672347037, 0.05019752927182708, 0.010351265209465055, 0.08316538034705445, 0.07259972073370591, 0.022747650073142722, 0.01840610842918977, 0.07675256390939467, 0.12705197150353342, 0.04286713257897645, 0.0034810047145583667, 0.042439700046088547, 0.05895735062949825, 0.02608106573461555, 0.05758108600275591, 0.04748864201246761, 0.044223466829862446, 0.02642203249706654, 0.08773009321885183, 0.022546721011167392, 0.04111659545742441, 0.06373334923409857, 0.0029879971725677024, 0.14217475923942402, 0.06535480089951307, 0.06666341505479068, 0.06146672632894479, 0.021907138143433258, 0.09584860992617905, 0.06638480539550073, 0.06268013778026216, 0.16348695469787344, 0.08563282841350883, 0.16786472056992352, 2.991962539963424, 6.823002705350518, 25.770173482596874, 43.68253581225872, 59.18178632855415, 81.07783019542694, 86.6048464179039, 105.55953651666641, 111.34427011013031, 116.291034668684, 117.02495768666267, 118.05553078651428, 130.63282549381256, 126.18904754519463, 119.54243659973145, 119.07997861504555, 118.39555934071541, 112.56895959377289, 123.16776886582375, 121.23511657118797, 115.74894055724144, 123.8626679778099, 112.19951301813126, 119.95130226016045, 110.18885850906372, 115.46010285615921, 122.93843597173691, 131.51957631111145, 124.22723561525345, 127.61762648820877, 130.58584481477737, 137.79180854558945, 132.7262395620346, 118.38210046291351, 79.17562186717987, 68.18845063447952, 43.563404604792595, 25.93285795301199, 6.488030254840851, 0.9877187025267631, 0.1665745858917944, 0.12760122015606612, 0.12478408694732934, 0.1942323221010156, 0.0584039979003137, 0.0738566814106889, 0.058665181932155974, 0.04652344556234311, 0.09746274401550181, 0.07954639368108474, 0.06189569139678497, 0.01887695660116151, 0.07260297876200639, 0.017975725859287195, 0.036868360330117866, 0.02596308280772064, 0.039622173499083146, 0.07850489331758581, 0.1134373020613566, 0.02527543474570848, 0.08321759043610655, 0.03110706791630946, 0.040424750550300814, 0.08036837418330833, 0.022927294339751825, 0.06313655117992312, 0.061543037663795985, 0.06544142437633127, 0.008193732446670765, 0.05211298273934517, 0.04092653514817357, 0.036219979301677085, 0.044412057686713524, 0.0818942223850172, 0.007274420668181847, 0.0430940627848031, 0.0230694749916438, 0.02460825697198743, 0.020222939747327473, 0.013990884508530144, 0.049680838637868874, 0.026009040302596986, 0.008805289035080932, 0.01713120818749303, 0.06047991853847634, 0.026651484149624594, 0.15958569216309115, 0.017838111270975787, 0.08249560691183433, 0.02072226783639053, 0.0064822262629604666, 0.0064504618785576895, 0.044024879243806936, 0.02820916492055403, 0.014273250362748513, 0.031115027450141497, 0.03231438633520156, 0.012607527733052848, 0.040709764944040217, 0.025243386953661684, 0.041281897720182315, 0.07076706126099452, 0.11559712249436416, 0.04727282175736036, 0.0380910523381317, 0.022361336232279427, 0.0436773277760949, 0.052201639700797386, 0.009194013000524137, 0.1349835263681598, 0.1305408967891708, 0.1375278757768683, 0.1389095321064815, 0.09664966186392121, 0.15044678177218884, 0.1179285571561195, 0.14010030805366114, 0.07535523342085071, 0.144594709854573, 0.11935644928598776, 0.08403003434068523, 0.21541835245443508, 0.10064177069580182, 0.11880665886565112, 0.13326505373697728, 0.17424365796614438, 0.14784344646614045, 0.17307786270976067, 0.22285446437308565, 0.05792373929580208, 0.14493099180981517, 0.09504811459919438, 0.20985141367418692, 0.11995637920335867, 0.148284460301511, 0.1253853304660879, 0.11733367384294979, 0.23628226103028283, 0.10754390736110508, 0.11187709984369576, 0.16621805814793333, 0.1474711555056274, 0.1641415586345829, 0.1664472630363889, 0.07994601794052869, 0.20915817352943122, 0.19093994720606133, 0.11201002591405995, 0.21691560570616275, 0.14665301190689206, 0.33625007257796824, 0.17852537508588284, 0.11650384141830727, 0.25396940647624433, 0.19329080387251452, 0.11150641934364103, 0.15080047451192513, 0.13488844240782782, 0.09088393882848322, 0.13079221767839044, 0.19331358780618757, 0.2195241063600406, 0.1184813903819304, 0.12342839094344527, 0.18043354066321626, 0.36517239874228835, 0.21174301451537758, 0.14648895274149254, 0.17974971095100045, 0.1459209871245548, 0.2297639483003877, 0.15293883945560083, 0.18577069567982107, 0.23704428342171013, 0.25951185438316315, 0.16189999063499272, 1.9074493157677352, 5.687248399481177, 23.718108795583248, 43.04414726793766, 59.20053832232952, 84.53011974692345, 88.84844362735748, 113.42569962143898, 122.55116075277328, 133.53346824645996, 137.95527577400208, 139.38944041728973, 147.50139713287354, 142.68611311912537, 137.38374084234238, 135.87011486291885, 132.08589792251587, 128.7613195180893, 139.4706192612648, 139.41699653863907, 133.76475423574448, 137.31089115142822, 130.29505401849747, 133.24732840061188, 124.44153651595116, 136.01351916790009, 135.71178495883942, 144.10167396068573, 140.29990196228027, 149.29509848356247, 149.95405912399292, 158.76870453357697, 150.4536259174347, 128.02005529403687, 81.03812992572784, 67.96499222517014, 44.381219521164894, 25.88649094104767, 4.84530477784574, 0.6569772062357515, 0.28832128504291177, 0.525705887703225, 0.29475309303961694, 0.27829249505884945, 0.1546117293764837, 0.2571568120038137, 0.10565283344476484, 0.2290563698625192, 0.11888229855685495, 0.1472915557678789, 0.10643313493346795, 0.08111131595796905, 0.2583923691418022, 0.14322915812954307, 0.06865084200398996, 0.08626167240436189, 0.1433312479639426, 0.21946688677417114, 0.17819538654293865, 0.16252480476396158, 0.16288339567836374, 0.255937403999269, 0.15471454651560634, 0.2503045031335205, 0.12132249496062286, 0.10972680858685635, 0.19166354119079188, 0.18340827635256574, 0.1352080557262525, 0.1135698496364057, 0.12568251608172432, 0.13225188857177272, 0.17141847987659276, 0.09582547718309797, 0.1337184020667337, 0.13758702494669706, 0.13670124200871214, 0.0780577419209294, 0.0754375672840979, 0.09869842731859535, 0.10892806472838856, 0.07361158714047633, 0.08213245921069756, 0.10285826894687489, 0.22711191326379776, 0.1445558955310844, 0.19090024230536073, 0.08717265125596896, 0.1335893277428113, 0.07965384182170965, 0.19344656582688913, 0.06654997778241523, 0.1945429405895993, 0.12283620162634179, 0.11125241187983193, 0.1479061579448171, 0.1917306164978072, 0.10721287238993682, 0.12216938193887472, 0.08133912560879253, 0.08464273661957122, 0.15969661355484277, 0.16792648209957406, 0.14515733200823888, 0.08995071038953029, 0.1044566991913598, 0.1546067273011431, 0.15177009045146406, 0.182674232928548], [0.054930605765548535, 0.018830830267688725, 0.04569505661493167, 0.0831065428792499, 0.07255315096699633, 0.030039618359296583, 0.015269880477717379, 0.026545023065409623, 0.015646243045921437, 0.0417789399944013, 0.008867704582371516, 0.11035323317628354, 0.02213325755292317, 0.025959611411963124, 0.012398829312587623, 0.01181687328426051, 0.0613960998452967, 0.03553425340214744, 0.06332173928967677, 0.022001943798386492, 0.05728674281272106, 0.05781305910204537, 0.04733551097160671, 0.008130032056214986, 0.02462082338752225, 0.03192897420376539, 0.04594745361828245, 0.013356824147194857, 0.010402117168268887, 0.030299407153506763, 0.0712776291766204, 0.006600305205211043, 0.02485683377017267, 0.03381666392670013, 0.0167672775205574, 0.07082523821736686, 0.044895900864503346, 0.014843858953099698, 0.05689840290870052, 0.056177016813308, 0.007251780525621143, 0.033515248069306836, 0.06640043502557091, 0.04307717150368262, 0.0671718010562472, 0.024207241185649764, 0.03159052517730743, 0.032127428203239106, 0.02093914750730619, 0.01648207016842207, 0.07396160624921322, 0.05986562064208556, 0.016785680927569047, 0.04831125705095474, 0.05583616693911608, 0.03504832478938624, 0.09690731327282265, 0.09869605986750685, 0.0667132057424169, 0.09833232586970553, 0.025094629017985426, 0.18336730980081484, 0.04152615336352028, 0.9141414694022387, 9.289378635585308, 20.634731948375702, 36.15978688001633, 61.0308089107275, 66.47299468517303, 92.06426426768303, 105.35439312458038, 98.23341563344002, 92.44628816843033, 85.92911347746849, 89.99162748456001, 97.39717170596123, 91.17009624838829, 87.39594116806984, 87.3116160929203, 68.2955364882946, 89.03885900974274, 87.71755591034889, 88.56142222881317, 95.33746182918549, 98.2343427836895, 85.69985657930374, 88.18306893110275, 93.51957857608795, 97.14348211884499, 96.73149302601814, 104.55265894532204, 109.72915157675743, 92.94794484972954, 101.49215877056122, 92.13134586811066, 97.65640899538994, 107.69093334674835, 89.68071296811104, 79.58885729312897, 96.43023759126663, 108.87543618679047, 121.83640390634537, 113.00655171275139, 110.06813138723373, 107.01658353209496, 87.48544156551361, 57.92381443083286, 30.126179940998554, 6.979228472337127, 2.0980168087407947, 0.2855612972052768, 0.49905304913409054, 0.3715322777861729, 0.06367248570313677, 0.03104210401943419, 0.044396268494892865, 0.10499047406483442, 0.11821429143310525, 0.030024677071196493, 0.055385802043019794, 0.03009128111443715, 0.13183825998567045, 0.03723590896697715, 0.040796165776555426, 0.05099157533550169, 0.05483957764226943, 0.024669877493579406, 0.03824689963948913, 0.05801176172099076, 0.06270758982282132, 0.052110863907728344, 0.04656397424696479, 0.048151546870940365, 0.01988926829653792, 0.07956022731377743, 0.07270198868354782, 0.05033398796513211, 0.023258128931047395, 0.04888366071099881, 0.0513297720317496, 0.01599500421434641, 0.04017850966192782, 0.03656361594039481, 0.03591619970393367, 0.04717348900157958, 0.0377329141338123, 0.055489279693574645, 0.07311945417313837, 0.06418541364837438, 0.08538931491784751, 0.06992205933784135, 0.0720012305828277, 0.013895397933083586, 0.03093121045822045, 0.05543570405279752, 0.055263058238779195, 0.16316590161295608, 0.058026934930239804, 0.03599391369789373, 0.02719235395488795, 0.03622509269916918, 0.06165822269394994, 0.015266446189343696, 0.04199578441330232, 0.0053261137145454995, 0.06532841012813151, 0.045614258997375146, 0.02253776885481784, 0.03276320385339204, 0.021017698272771668, 0.006713966513416381, 0.03423209593165666, 0.0046667382321174955, 0.028198279469506815, 0.04786024277564138, 0.029715841592405923, 0.07646354933967814, 0.06045874506526161, 0.011481806595838862, 0.0646061371662654, 0.0748843110341113, 0.055733000990585424, 0.019758722664846573, 0.026356270791438874, 0.022657445733784698, 0.050407460585120134, 0.018055634755000938, 0.1238584952079691, 0.021350226816139184, 0.011466974774521077, 0.04071786177519243, 0.03906464247847907, 0.0341494466556469, 0.025996922886406537, 0.017423549434170127, 0.03883144112478476, 0.04878051702689845, 0.0499865626625251, 0.024539547084714286, 0.03342509939102456, 0.040473350090906024, 0.04934917655191384, 0.05327023958670907, 0.007459165344698704, 0.0305254764680285, 0.025475729271420278, 0.0024680081560291, 0.014377499846887076, 0.03301009041024372, 0.09393111555255018, 0.0176836276659742, 0.0306823256687494, 0.01792951974493917, 0.011315670344629325, 0.06664339191047475, 0.02972437814605655, 0.046981651248643175, 0.11635003131232224, 0.01980401222681394, 0.08221182448323816, 0.011293629486317514, 0.012605757710844046, 0.02246271546027856, 0.04355800156190526, 0.006961304388823919, 0.06048035269486718, 0.09998962326790206, 0.0629973020113539, 0.06349169110762887, 0.06037035527697299, 0.02589389794593444, 0.043659928123815916, 0.02943854924524203, 0.029420529899653047, 0.10014108076575212, 0.06650365292443894, 0.041292903770226985, 0.07902645986177959, 0.4625068180030212, 3.4992462443187833, 19.132784642279148, 36.73093423247337, 56.01488046348095, 83.48361030220985, 88.69821488857269, 111.74036845564842, 121.2332470715046, 111.69025674462318, 104.16574850678444, 104.77966636419296, 109.82286214828491, 118.5758900642395, 107.06726521253586, 109.58093672990799, 106.59464657306671, 89.27613347768784, 109.60269436240196, 112.83261984586716, 108.5968579351902, 117.72206827998161, 126.57314613461494, 107.00434818863869, 109.10558983683586, 119.53302830457687, 126.05262726545334, 124.51149836182594, 129.69193518161774, 133.79957556724548, 113.44646170735359, 124.59234282374382, 113.09982150793076, 120.08019134402275, 130.85462719202042, 116.84219509363174, 99.94840040802956, 107.20291033387184, 121.06591925024986, 131.64054661989212, 125.68156197667122, 127.76011884212494, 126.67007133364677, 114.31920647621155, 86.20365634560585, 52.40486517548561, 18.727236203849316, 8.042775727808475, 1.637333210092038, 0.3581617749296129, 0.11748631877708249, 0.1497620763257146, 0.08764745507505722, 0.041803148851613514, 0.04517398730968125, 0.048990437207976356, 0.09160673871519975, 0.03562118115951307, 0.053179831156739965, 0.040601248110760935, 0.07717804459389299, 0.02675197280041175, 0.05065796882263385, 0.03439750580582768, 0.07058974733809009, 0.06189844847540371, 0.04327611160988454, 0.03087887049332494, 0.005828051380376564, 0.025477903764112853, 0.07252154289744794, 0.0662742847634945, 0.05446301191113889, 0.14917235093889758, 0.05064286982815247, 0.0282469291050802, 0.034299238031962886, 0.05764755645941477, 0.01344350328508881, 0.048389093499281444, 0.02245229570689844, 0.07081354196998291, 0.03809839217865374, 0.054990786520647816, 0.03882325894664973, 0.04827580836717971, 0.023681012098677456, 0.04942165840475354, 0.036881945343338884, 0.06035607264493592, 0.001978809455067676, 0.02007382001465885, 0.06213429558556527, 0.020767245696333703, 0.030731530059711076, 0.07752607474685647, 0.058270188674214296, 0.01763882606610423, 0.006833545057816082, 0.008230630173784448, 0.027929048701480497, 0.036928778572473675, 0.010475000708538573, 0.10656594968168065, 0.024189446339732967, 0.029634246166097, 0.048627757059875876, 0.05541607424675021, 0.05731669589295052, 0.04941726860124618, 0.026530643954174593, 0.03316959278890863, 0.033681863933452405, 0.00782548062488786, 0.13700553739909083, 0.17127214319771156, 0.20142253080848604, 0.18368937220657244, 0.16646163101540878, 0.1280317548662424, 0.09892532412777655, 0.11885763698955998, 0.14464167295955122, 0.15286495123291388, 0.10252839914755896, 0.23772594606271014, 0.07547984001575969, 0.09193450823659077, 0.12485577841289341, 0.08662387757794932, 0.15094226924702525, 0.21156164846615866, 0.08753608839469962, 0.19824113667709753, 0.12137167708715424, 0.13171064027119428, 0.0995965967013035, 0.09502100394456647, 0.16291271051159129, 0.11301733553409576, 0.1688221504446119, 0.10405980603536591, 0.1483802864095196, 0.11774238941143267, 0.15418511320604011, 0.10252097767079249, 0.1066791197808925, 0.22993320249952376, 0.1503228727960959, 0.1570709396037273, 0.12765140418196097, 0.11853492891532369, 0.15705848636571318, 0.15686665603425354, 0.10393717355327681, 0.208672912849579, 0.12487597967265174, 0.15222369111143053, 0.10427496206830256, 0.07137874679756351, 0.14073822851059958, 0.23887059011030942, 0.156001994619146, 0.16341247275704518, 0.25801526906434447, 0.2077204256784171, 0.08543697564164177, 0.18573723966255784, 0.20119341497775167, 0.1295094599481672, 0.15893453179160133, 0.21534654224524274, 0.17870118987048045, 0.22453296493040398, 0.10982381470967084, 0.29883941751904786, 0.3707033285172656, 2.4479153333231807, 15.782328676432371, 34.17960673570633, 56.56154952943325, 88.16756576299667, 98.36117997765541, 124.43240940570831, 136.2141028046608, 128.15327614545822, 118.91710415482521, 115.27879938483238, 115.30653029680252, 120.1911985874176, 113.48830506205559, 110.06482556462288, 110.45336991548538, 95.16121968626976, 114.041418582201, 114.51904535293579, 112.86247864365578, 121.4007268846035, 124.39162239432335, 114.34081211686134, 115.38904666900635, 121.67818799614906, 123.02033677697182, 123.19548457860947, 130.62375158071518, 136.50133699178696, 121.61298349499702, 129.4489762187004, 120.61469346284866, 122.34025686979294, 134.1533213853836, 115.6766228377819, 102.18781024217606, 117.9028245806694, 131.0257852077484, 147.51519799232483, 144.1421341896057, 145.10287463665009, 144.3745905160904, 125.50792649388313, 90.65819531679153, 53.836195170879364, 16.471757031977177, 6.649627508595586, 0.9432488575112075, 0.488440515473485, 0.44435486546717584, 0.23230452759889886, 0.1884226268157363, 0.1908396533690393, 0.19500460097333416, 0.25867227755952626, 0.14776452648220584, 0.16432017873739824, 0.15956883056787774, 0.22137523046694696, 0.18700408574659377, 0.15026133391074836, 0.09057562841917388, 0.20770473667653278, 0.20670776517363265, 0.14182912622345611, 0.20092656835913658, 0.1698268551263027, 0.13034884381340817, 0.10302226131898351, 0.20909276063321158, 0.17015884746797383, 0.18153068725951016, 0.2578891930170357, 0.20355881773866713, 0.18498982273740694, 0.15003071894170716, 0.11268094225670211, 0.15441050345543772, 0.13004287116928026, 0.06497118476545438, 0.1993233512621373, 0.14279987022746354, 0.1911675787414424, 0.19769959151744843, 0.19058678881265223, 0.14695226069306955, 0.2356385815073736, 0.11809533258201554, 0.13440368638839573, 0.07823950872989371, 0.17472388688474894, 0.11226582195376977, 0.1322547681047581, 0.2139299752889201, 0.14486626168945804, 0.21271930978400633, 0.12795899470802397, 0.179097140498925, 0.13640735152876005, 0.12365631191642024, 0.11897161602973938, 0.12479919707402587, 0.18797223223373294, 0.1698570160078816, 0.07348882107180543, 0.1474792746012099, 0.16008247097488493, 0.19746317295357585, 0.21349972259486094, 0.10073490280774422, 0.10604370778310113, 0.089621805382194, 0.0883438864548225], [0.026342778546677437, 0.027253855732851662, 0.03342666903336067, 0.08157152915373445, 0.05165910748473834, 0.03332086846057791, 0.013108149942127056, 0.0166712473219377, 0.028777405132132117, 0.014325919655675534, 0.05111493883305229, 0.06552035920321941, 0.028575843389262445, 0.04109129193238914, 0.06846429576398805, 0.021440297568915412, 0.03713296937348787, 0.06418468634365126, 0.02098031443892978, 0.030641869343526196, 0.02506126205844339, 0.07655495966901071, 0.04382688537589274, 0.0795675152039621, 0.03741859232832212, 0.02842528574547032, 0.10197543233516626, 0.04598413055646233, 0.02270476135890931, 0.01442356866391492, 0.0462742435047403, 0.04900269006611779, 0.02874834262911463, 0.14391803444596007, 0.08291827485663816, 0.04722891259007156, 0.021322648608474992, 0.012253889726707712, 0.010016404467023676, 0.08474612521240488, 0.0396146815182874, 0.06356284822686575, 0.12570623512146994, 0.011707266421581153, 0.0195916206939728, 0.046070787429925986, 0.015170086662692484, 0.04423235404829029, 0.03555032832082361, 0.04348946051322855, 0.011675691748678219, 0.03754670557100326, 0.04531644255621359, 0.022323586890706792, 0.011165162795805372, 0.09501560853095725, 0.09222911859978922, 0.155835026234854, 0.06396834287443198, 0.2947258413769305, 0.5960506817791611, 12.893735077232122, 36.62567228078842, 66.63082301616669, 98.70045617222786, 103.84256064891815, 106.75771862268448, 96.27761498093605, 95.92406675219536, 79.20890808105469, 78.13964545726776, 82.6931843161583, 89.34534296393394, 76.5316553413868, 69.48584541678429, 60.170584470033646, 56.16957776248455, 66.39474168419838, 98.2183988392353, 99.5284241437912, 68.72314274311066, 57.687938287854195, 62.203323394060135, 54.23673167824745, 57.77578957378864, 70.50688862800598, 66.08401715755463, 69.79638755321503, 52.9122519493103, 47.28144809603691, 50.6641785800457, 55.21360985934734, 55.22332973778248, 60.47098495066166, 65.77772319316864, 74.7071224451065, 61.054018065333366, 64.56346794962883, 82.57011651992798, 88.54462713003159, 101.5538826584816, 87.0571893453598, 94.72433432936668, 92.880939245224, 88.13026696443558, 98.76453593373299, 106.87030658125877, 105.97899600863457, 97.4245074391365, 90.84354177117348, 63.926910907030106, 38.14210630953312, 9.757930543273687, 0.7577770098578185, 0.5928248330019414, 0.2570864564040676, 0.05187421527807601, 0.041647012112662196, 0.07690942424233072, 0.050544412806630135, 0.05380166556278709, 0.04710838409664575, 0.08515490757417865, 0.16560036863666028, 0.0581213064288022, 0.06610966156586073, 0.07924811710836366, 0.0713132151577156, 0.07305674269446172, 0.03520513688272331, 0.05482096086780075, 0.031991025171009824, 0.02478449107002234, 0.08390142014832236, 0.03163039706123527, 0.03916905894584488, 0.05423411501396913, 0.01399253857016447, 0.04758132141432725, 0.02410341472568689, 0.051552386648836546, 0.06963838080991991, 0.04469036677619442, 0.05343581273336895, 0.03339176582812797, 0.06954247306566685, 0.027125488304591272, 0.051275947771500796, 0.0679465958091896, 0.00468617786282266, 0.03505137501633726, 0.04882592904323246, 0.04773284570546821, 0.06766276885173284, 0.011258734630246181, 0.055911060771904886, 0.06862567577627487, 0.03346405843331013, 0.042742989826365374, 0.029581329181382898, 0.01171040106783039, 0.05075911612948403, 0.021216419445408974, 0.054784335879958235, 0.02627579786349088, 0.024019169832172338, 0.02175473069655709, 0.054951274578343146, 0.022280507073446643, 0.08684062180691399, 0.04668957903049886, 0.024161428409570362, 0.059730787252192385, 0.01423400652129203, 0.03998655687610153, 0.03866153012495488, 0.016025020377128385, 0.04065810775500722, 0.07978294583153911, 0.06370535542373545, 0.02172063828766113, 0.012814021047233837, 0.04213681102555711, 0.03264838618633803, 0.002036422843048058, 0.060753195866709575, 0.044660450803348795, 0.0572379762888886, 0.047493310121353716, 0.08523452517692931, 0.030492007463180926, 0.051364779137657024, 0.012486272862588521, 0.06300411492702551, 0.045203346671769395, 0.0341959236538969, 0.017112264868046623, 0.026461872839718126, 0.0035110663338855375, 0.0567497024894692, 0.033885420198203065, 0.022118394190329127, 0.007217403317554272, 0.0402685470180586, 0.04503675678279251, 0.030215260594559368, 0.06374008051352575, 0.017409973697795067, 0.016597143876424525, 0.07622036238899454, 0.03128804062725976, 0.026721398171503097, 0.021631120434904005, 0.0727919369819574, 0.0035903982097806875, 0.019464553879515734, 0.08603201480582356, 0.02631160092278151, 0.16416735568782315, 0.02009957253903849, 0.07954041939228773, 0.027755957598856185, 0.0612171198008582, 0.015408923700306332, 0.027621508270385675, 0.06529102072818205, 0.054441704851342365, 0.005984596300550038, 0.15338773489929736, 0.010728463621489936, 0.02095055431709625, 0.07922462071292102, 0.23711769666988403, 0.053991406748536974, 0.05146214891283307, 0.2316100406460464, 2.3614426609128714, 24.485492818057537, 52.97985792160034, 88.18692952394485, 116.86543464660645, 119.7097036242485, 119.45559605956078, 109.90033999085426, 112.18289270997047, 98.00916686654091, 99.55325961112976, 112.45816513895988, 112.57630839943886, 101.24058946967125, 80.40196046233177, 82.55543410778046, 81.7275421321392, 89.18509036302567, 126.03650853037834, 121.665960252285, 100.2674388885498, 87.25530311465263, 97.65881046652794, 78.13460692763329, 92.03306034207344, 97.2524830698967, 86.43318682909012, 94.9015948176384, 78.60588043928146, 79.40892934799194, 78.47810089588165, 78.40732589364052, 80.2265314757824, 94.66634184122086, 88.44754233956337, 97.53835693001747, 100.39321973919868, 94.90895122289658, 110.34226387739182, 115.40742248296738, 129.37194675207138, 106.5636782348156, 111.27012848854065, 108.73332381248474, 95.73922947049141, 107.04280972480774, 117.47451916337013, 123.74722257256508, 121.24713152647018, 118.27502220869064, 93.05288001894951, 62.43777461349964, 21.49982962757349, 3.256116765551269, 0.11772814017604105, 0.3563784237485379, 0.029851086874259636, 0.01073700574124814, 0.012886937984148972, 0.05578668053203728, 0.07740605462458916, 0.06927574519068003, 0.048987899062922224, 0.1402596471598372, 0.0815459992736578, 0.0330144765030127, 0.035366138399695046, 0.08343659079400823, 0.04551977246592287, 0.034148674822063185, 0.023442845777026378, 0.11024443432688713, 0.07543902931502089, 0.027270370374026243, 0.01887376536615193, 0.03586141065170523, 0.09099649294512346, 0.061830400954931974, 0.05429288939922117, 0.04501530871493742, 0.03417249034100678, 0.01719636875350261, 0.08458130905637518, 0.03927330471924506, 0.026986868106178008, 0.03401757814572193, 0.052754298521904275, 0.04441689277882688, 0.025395909433427732, 0.010839160513569368, 0.07064621735480614, 0.013617795739264693, 0.01067285635144799, 0.038504881304106675, 0.02057682730082888, 0.06276590036577545, 0.033703575463732705, 0.07716650419752114, 0.005919975646975217, 0.04280607980035711, 0.08005518786376342, 0.015403042179968907, 0.02650392478244612, 0.04349438095232472, 0.013103094988764497, 0.07085018922225572, 0.0550496833602665, 0.061200005875434726, 0.008750589968258282, 0.01684734226728324, 0.03309115520096384, 0.013687437021872029, 0.047882577709970064, 0.05197663536819164, 0.04362470208434388, 0.07257521501742303, 0.12395332683809102, 0.1904787914827466, 0.15290891606127843, 0.16937277949182317, 0.20023849356221035, 0.12095059733837843, 0.10045022980193608, 0.1740856547257863, 0.14342823182232678, 0.16375083272578195, 0.13386470905970782, 0.13020578742725775, 0.1868680797633715, 0.10783016114146449, 0.17134079185780138, 0.14207066560629755, 0.14885414770105854, 0.2682934800395742, 0.11648534709820524, 0.08739366283407435, 0.127796093293, 0.18342987284995615, 0.10565986900473945, 0.13992115360451862, 0.16286423342535272, 0.11179336332133971, 0.26990874961484224, 0.1214684234582819, 0.13357105606701225, 0.11750805628253147, 0.18857136805308983, 0.12570804596180096, 0.10564189418801107, 0.24880971381207928, 0.22302308032521978, 0.09423323645023629, 0.11290163471130654, 0.23061772983055562, 0.10991680581355467, 0.20523519575363025, 0.1552632311359048, 0.23055366764310747, 0.26254824770148844, 0.1766674083773978, 0.18220164813101292, 0.23057453683577478, 0.15327320666983724, 0.12488711188780144, 0.09005312676890753, 0.10061903129098937, 0.1864745485363528, 0.18786393804475665, 0.21125187602592632, 0.1037219655700028, 0.14635532163083553, 0.25029375683516264, 0.38547257194295526, 0.21435687347548082, 0.1545979848015122, 0.40135227609425783, 1.3342841528356075, 21.354833208024502, 52.98756390810013, 91.64416640996933, 128.62673074007034, 135.77490717172623, 135.02058684825897, 120.17033010721207, 120.88234350085258, 102.50000149011612, 99.21306386590004, 103.96058231592178, 109.63810086250305, 101.46348550915718, 89.72026124596596, 81.4136029779911, 80.0196173787117, 92.95898705720901, 119.68745201826096, 123.44851300120354, 94.95315805077553, 80.58545261621475, 87.58853003382683, 76.42315596342087, 80.45164659619331, 94.00105074048042, 89.6913143992424, 90.89318990707397, 73.07663753628731, 69.81853276491165, 73.07868182659149, 73.3278040587902, 78.70166569948196, 87.99117162823677, 88.2888476550579, 99.22244176268578, 85.59356108307838, 86.49361118674278, 106.6302278637886, 116.1429414153099, 128.875450193882, 113.26085686683655, 117.32252731919289, 117.7677570283413, 109.6739861369133, 120.1406081020832, 132.77282506227493, 138.46773147583008, 132.7375629544258, 129.11579489707947, 97.75967985391617, 59.76651415228844, 20.240130722522736, 2.419040445238352, 0.6323234166484326, 0.5027677060570568, 0.15684382757171988, 0.14435091434279457, 0.11784244576119818, 0.2305629593320191, 0.12273469066713005, 0.2779494447167963, 0.21585057926131412, 0.2768916467903182, 0.16443835833342746, 0.15753935353131965, 0.14105782698607072, 0.18811433867085725, 0.20313546701800078, 0.1315224019344896, 0.2809760713716969, 0.17027943162247539, 0.12449079760699533, 0.1557287061586976, 0.0911329071095679, 0.12214166272315197, 0.23742923542158678, 0.17752062587533146, 0.17862151289591566, 0.10131406001164578, 0.16841573553392664, 0.13556467252783477, 0.20048022590344772, 0.11101670577772893, 0.08776036542258225, 0.10743618462583981, 0.10595039755571634, 0.21627210429869592, 0.17090617533540353, 0.11369863452273421, 0.1549724576761946, 0.1658329725614749, 0.1690043180133216, 0.14833820663625374, 0.10887980286497623, 0.2253829169785604, 0.1508626516442746, 0.18316483707167208, 0.08368575203348882, 0.19171737658325583, 0.08212802116759121, 0.2723028586478904, 0.08867483978974633, 0.07347238250076771, 0.16832275927299634, 0.14528251747833565, 0.15575503755826503, 0.1405240743770264, 0.12088992676581256, 0.16657213680446148, 0.14887181081576273, 0.1468905436922796, 0.12809378356905654, 0.20929732621880248, 0.1771769076003693, 0.18013653316302225], [0.09589715380570851, 0.008901180081011262, 0.016373276885133237, 0.0051736037585214945, 0.03837346921500284, 0.05598607334832195, 0.04735376780445222, 0.02519980804208899, 0.032713298132875934, 0.009116786968661472, 0.04503377334913239, 0.01876067133707693, 0.0409632454829989, 0.015316174722102005, 0.010278149748046417, 0.04889313051535282, 0.05405379910371266, 0.11725921416655183, 0.04812574610696174, 0.07258525627548806, 0.024209259827330243, 0.03793001000303775, 0.02827184485795442, 0.03493339580018073, 0.006562763201145572, 0.0636329960252624, 0.04527907170995604, 0.07459156346158125, 0.04502584350120742, 0.04534612104180269, 0.07981877672136761, 0.08309382246807218, 0.02271350756927859, 0.039962748778634705, 0.06815179222030565, 0.05472904216730967, 0.03240718819142785, 0.10812523905769922, 0.06910813855938613, 0.03516774006129708, 0.06061228799808305, 0.020618014641513582, 0.025519950140733272, 0.049748066085157916, 0.07642730284715071, 0.05160131273441948, 0.07024767663097009, 0.029533922643167898, 0.03546210180502385, 0.029239234354463406, 0.07121225338778459, 0.04586042196024209, 0.020473533331824, 0.021549461926042568, 0.016159940969373565, 0.0820072292117402, 0.24486539186909795, 0.0665461334574502, 2.497287984006107, 15.989849790930748, 53.18990685045719, 89.51830208301544, 98.9044140279293, 89.0740679204464, 85.49858137965202, 84.97440710663795, 80.4873114824295, 71.01890355348587, 70.3718438744545, 66.42178863286972, 66.64234399795532, 49.699516743421555, 52.96838253736496, 49.62031379342079, 65.787123888731, 90.28374820947647, 68.22815090417862, 59.86500106751919, 42.02275067567825, 33.650386333465576, 38.25327314436436, 34.53755512833595, 30.316403433680534, 35.294060334563255, 25.717438012361526, 34.391411170363426, 34.04154494404793, 34.959678277373314, 33.42688612639904, 33.419104143977165, 34.195733070373535, 23.435791544616222, 31.967813819646835, 30.315214097499847, 27.103607431054115, 47.71322272717953, 19.060073643922806, 31.065972112119198, 53.679552376270294, 45.96719741821289, 62.75876618921757, 74.49723690748215, 94.50712278485298, 71.53927803039551, 89.38559800386429, 81.71169698238373, 76.35618835687637, 74.15606841444969, 80.71973741054535, 88.52475419640541, 104.662214666605, 101.96658611297607, 98.2505451142788, 59.52960446476936, 21.819411478936672, 2.987721492536366, 0.39285266655497253, 0.4419142089318484, 0.023081484796421137, 0.08964211054262705, 0.00933333267312264, 0.09077302485820837, 0.036228424942237325, 0.10991907678544521, 0.01893835076771211, 0.08531646570190787, 0.04396939628350083, 0.018072869279421866, 0.0649508424976375, 0.0660018646158278, 0.024041081742325332, 0.01443548477254808, 0.017170395440189168, 0.024617502276669256, 0.0017700172224976995, 0.026101625080627855, 0.011139163507323246, 0.008108029232971603, 0.028971936881134752, 0.029922158646513708, 0.026465301561984234, 0.029947985385661013, 0.030743287534278352, 0.03469095470791217, 0.018056963199342135, 0.024693067753105424, 0.009973263422580203, 0.0725975091336295, 0.05549998146307189, 0.1491909788455814, 0.0553197805857053, 0.07194600737420842, 0.04776625719387084, 0.0689980409515556, 0.092067337827757, 0.12720255326712504, 0.04363490661489777, 0.023354778822977096, 0.02699235443287762, 0.02759103383141337, 0.010560053615336074, 0.08608875941717997, 0.0038441190190496854, 0.07065597659675404, 0.025432610491407104, 0.015945066952554043, 0.02503251682355767, 0.03416926942009013, 0.03321958014566917, 0.017382449295837432, 0.03604547440772876, 0.020137518549745437, 0.011978513048234163, 0.017614283242437523, 0.02195342218328733, 0.015448189806193113, 0.0870111228141468, 0.0327245713560842, 0.015886184955888893, 0.02180186264013173, 0.01852078323281603, 0.09434952356969006, 0.051682670673471875, 0.030323183709697332, 0.04722470461274497, 0.06229774618986994, 0.05847977488883771, 0.052544189093168825, 0.02264397389808437, 0.07360654053627513, 0.016971421937341802, 0.055104728453443386, 0.041371397019247524, 0.15696032991399989, 0.03320258867461234, 0.04886423499556258, 0.010269850681652315, 0.021514534601010382, 0.00835797251056647, 0.0384928139828844, 0.1071787261753343, 0.01197240981127834, 0.00817962236396852, 0.11042516212910414, 0.10223154007690027, 0.11514351441292092, 0.06187962761032395, 0.06760487391147763, 0.019326527399243787, 0.04624778594006784, 0.017483292322140187, 0.07437993263010867, 0.042837977307499386, 0.06776738198823296, 0.054765678287367336, 0.040400998113909736, 0.027555369924812112, 0.02426454611850204, 0.04862187182880007, 0.0616472537512891, 0.04730622211354785, 0.0379636181605747, 0.05366061297536362, 0.07161558838561177, 0.042375789998914115, 0.028155051222711336, 0.08664454639074393, 0.049981389893218875, 0.06602637033211067, 0.01890370545879705, 0.09700555136078037, 0.024828910463838838, 0.19067480752710253, 0.41315126640256494, 6.885440004989505, 30.955683030188084, 76.12089738249779, 108.57408195734024, 109.5079654455185, 99.27592769265175, 100.14434829354286, 99.00655254721642, 98.37048947811127, 98.58808100223541, 92.19845026731491, 96.21798098087311, 91.14065542817116, 86.00538298487663, 80.89851781725883, 78.36727604269981, 86.97278827428818, 91.30767166614532, 74.739451110363, 70.96078187227249, 67.1949103474617, 55.72959557175636, 54.07875135540962, 44.66287560760975, 48.211961165070534, 43.80698673427105, 43.9404621720314, 51.54357299208641, 50.77476404607296, 48.397410213947296, 39.29666295647621, 42.8121355175972, 48.64437036216259, 36.48599177598953, 49.97308686375618, 47.58996494114399, 43.81958685815334, 62.67229422926903, 39.79941017925739, 53.64403948187828, 72.93852254748344, 75.10771214962006, 102.37558856606483, 103.1500706076622, 123.2350480556488, 94.11463424563408, 110.33919364213943, 115.21908178925514, 100.88221549987793, 96.12940773367882, 94.13755461573601, 98.88095408678055, 113.25056701898575, 113.86712193489075, 117.10231393575668, 87.02757373452187, 41.48939989507198, 10.713951643556356, 0.45563236344605684, 0.4068988800281659, 0.1376546494429931, 0.031187038039206527, 0.007646809035577462, 0.03722252062289044, 0.08316219653352164, 0.09575897332979366, 0.07562352722743526, 0.08803972465102561, 0.0185859901830554, 0.03028047867701389, 0.05174540070584044, 0.034144422315876, 0.036766923585673794, 0.014956221966713201, 0.03476421952655073, 0.025312028192274738, 0.07095083929016255, 0.03636143264884595, 0.036842470508418046, 0.024070107137958985, 0.07828604881069623, 0.04968101675331127, 0.10717088909586892, 0.08417098302743398, 0.03845527986413799, 0.03310607236926444, 0.013747736520599574, 0.020107723175897263, 0.054250037792371586, 0.06140214092738461, 0.0461817088216776, 0.11217374369152822, 0.022149994838400744, 0.007978943776834058, 0.03830556641332805, 0.04510670420131646, 0.058066573037649505, 0.029707880203204695, 0.011034705294150626, 0.055165387893794104, 0.03118893422652036, 0.022375468579411972, 0.06067467664252035, 0.07127917284378782, 0.06412728122086264, 0.022575314105779398, 0.04974927578587085, 0.08221703435992822, 0.09168832300929353, 0.037665408381144516, 0.02796980188577436, 0.03193897464370821, 0.013837874994351296, 0.035946156494901516, 0.0258706464592251, 0.0049595646578382, 0.028104956254537683, 0.03264032275183126, 0.1898983577848412, 0.15784127404913306, 0.10593989616609178, 0.10020572924986482, 0.14573062624549493, 0.2548525028396398, 0.14584300224669278, 0.09308842913014814, 0.0955629647069145, 0.10927662180620246, 0.20894180779578164, 0.16741117928177118, 0.130421559442766, 0.32135798886884004, 0.09492189754382707, 0.2812587405787781, 0.21683551312889904, 0.2269931696355343, 0.13550809118896723, 0.1835198953631334, 0.1740857437835075, 0.10498699339223094, 0.13622260128613561, 0.11351302338880487, 0.14855337009066716, 0.22471678006695583, 0.08712919108802453, 0.1581812370568514, 0.20941323484294116, 0.19501288334140554, 0.1607106247683987, 0.12657625484280288, 0.15060287027154118, 0.12223247191286646, 0.15263804700225592, 0.16858635528478771, 0.15176278771832585, 0.2059162053046748, 0.20294529909733683, 0.12401427200529724, 0.11573645329917781, 0.08926668029744178, 0.2122788451379165, 0.136604510480538, 0.15506544878007844, 0.1801222690846771, 0.17932312446646392, 0.1769989702734165, 0.15887996909441426, 0.1405116359819658, 0.18789286696119234, 0.1312604089616798, 0.11015943615348078, 0.15725591249065474, 0.22760708903660998, 0.12966587499249727, 0.4858739906921983, 0.286639429978095, 4.466713042929769, 28.582106195390224, 79.96930047869682, 121.01222053170204, 125.35067573189735, 109.93564009666443, 106.57274454832077, 102.71370202302933, 100.53744480013847, 93.44405382871628, 91.68110802769661, 85.01684322953224, 81.87655493617058, 64.1914527118206, 70.18289521336555, 65.25527402758598, 82.58898630738258, 102.93383181095123, 83.05526688694954, 77.17643514275551, 60.333477929234505, 46.80890165269375, 54.045636132359505, 47.529874965548515, 47.00367160141468, 54.62283656001091, 39.57838363945484, 51.06312297284603, 52.86038473248482, 53.774007707834244, 50.03369741141796, 48.25817048549652, 57.45476000010967, 40.84461249411106, 50.09225606918335, 46.812834441661835, 43.72600927948952, 69.51511144638062, 30.71660365909338, 43.825126960873604, 72.68190711736679, 63.0840515345335, 82.56900697946548, 94.38469335436821, 120.14656618237495, 95.25125205516815, 113.28573793172836, 110.89945837855339, 98.40801626443863, 96.12620830535889, 102.00466766953468, 109.412180185318, 130.70903420448303, 131.01379305124283, 128.49829763174057, 90.68460389971733, 38.56204457581043, 8.247780427336693, 0.42960070248227566, 0.6237098132260144, 0.11199800312169828, 0.26133753766771406, 0.12717804755084217, 0.21321322390576825, 0.15571043448289856, 0.2083840689738281, 0.1397573616122827, 0.19403900747420266, 0.11287801957223564, 0.12760475277900696, 0.192806315026246, 0.10036889783805236, 0.17991273110965267, 0.12313241502852179, 0.1697944974876009, 0.06836022439529188, 0.14623359456891194, 0.14393667719559744, 0.10315833409549668, 0.08880551715265028, 0.21746764483395964, 0.1530625851592049, 0.21345799905247986, 0.12023325965856202, 0.17867517017293721, 0.1672836040961556, 0.14000816299812868, 0.14168896421324462, 0.16449609742267057, 0.2045788403484039, 0.1670576646574773, 0.33283527300227433, 0.10953880031593144, 0.05815078824525699, 0.18612392828799784, 0.1633866163319908, 0.1787758499267511, 0.21946148393908516, 0.1449830608908087, 0.1764275462483056, 0.1869143155636266, 0.08645494250231422, 0.11408801714424044, 0.40337269892916083, 0.10780389653518796, 0.10880087545956485, 0.16058822977356613, 0.2829869947163388, 0.24631633510580286, 0.17701663338812068, 0.08143219834892079, 0.0693336920812726, 0.17493284598458558, 0.13329131092177704, 0.12723118532449007, 0.10616285217110999, 0.12012702864012681, 0.12340932516963221], [0.05441129906103015, 0.036543444366543554, 0.05883189798623789, 0.10448973218444735, 0.07811548843164928, 0.05825738662679214, 0.03626819663622882, 0.04895825397397857, 0.027214058063691482, 0.02152810662664706, 0.060964073418290354, 0.030329736873682123, 0.07836115415557288, 0.012294130829104688, 0.08905726848752238, 0.013401702744886279, 0.05206153335166164, 0.047455475432798266, 0.05505387278390117, 0.013030781974521233, 0.05432883161120117, 0.05424510622106027, 0.01205659069455578, 0.022785902219766285, 0.0162851115965168, 0.08432305650785565, 0.07622385790455155, 0.00043745494735958346, 0.05717584368539974, 0.12730755232041702, 0.08500224779709242, 0.05394501880800817, 0.021669255693268497, 0.07795443496434018, 0.11896651747520082, 0.06960695827729069, 0.0448145985865267, 0.0342472691409057, 0.030071877663431223, 0.030879334335622843, 0.057310951669933274, 0.056107158452505246, 0.046370039926841855, 0.03497864454402588, 0.07155958592193201, 0.03894304158166051, 0.010700575567170745, 0.013114371922711143, 0.03837501659290865, 0.025677919984445907, 0.05936375069722999, 0.06860085093649104, 0.10170051857130602, 0.02998986848979257, 0.015687966588302515, 0.08758868440054357, 11.512992717325687, 37.974235117435455, 74.23510417342186, 93.68326619267464, 94.17760446667671, 78.10721039772034, 82.1879330277443, 70.14970019459724, 66.85844600200653, 82.8312461078167, 64.80335667729378, 73.69434759020805, 55.23767776787281, 45.64958766102791, 43.71451489627361, 28.564201556146145, 27.921963818371296, 36.06579892337322, 22.124027833342552, 67.3606726527214, 97.54882916808128, 69.1546019911766, 36.76821783185005, 36.42479605972767, 45.94212256371975, 59.91472899913788, 45.433823838829994, 62.64856830239296, 48.918814435601234, 58.4610828012228, 35.29972203075886, 55.94591036438942, 61.11622452735901, 69.12877097725868, 59.969951435923576, 44.938683807849884, 42.52715460956097, 55.088987946510315, 57.2348278015852, 34.667359963059425, 61.84139281511307, 42.57119424641132, 34.783219546079636, 29.08275593072176, 24.2544025182724, 28.137594647705555, 30.083715319633484, 36.594529151916504, 34.25422713160515, 43.30893225967884, 48.75940918922424, 56.31695665419102, 66.11511468887329, 81.70527532696724, 61.27524979412556, 65.55158972740173, 74.4943642616272, 94.0788097679615, 96.77822291851044, 78.00481349229813, 38.42954568564892, 5.20371769554913, 0.46076048514805734, 0.3372292622225359, 0.05356846420909278, 0.11206351991859265, 0.08325322094606236, 0.08086312693194486, 0.13388287683483213, 0.017633241404837463, 0.03496083299978636, 0.07897376737673767, 0.06795706009143032, 0.03463593930064235, 0.02261916575662326, 0.012128025191486813, 0.024939885661297012, 0.05213075717620086, 0.059238487301627174, 0.004635309205696103, 0.0003020775574213985, 0.021247702825348824, 0.011442906925367424, 0.042208725135424174, 0.04578612184559461, 0.06295042054262012, 0.061911146622151136, 0.10903869668254629, 0.010727038697950775, 0.06817151108407415, 0.02292751883942401, 0.010321528279746417, 0.017955652620003093, 0.03522406535921618, 0.03745504291146062, 0.05830922564200591, 0.039292370493058115, 0.034866539426730014, 0.07086483179591596, 0.04893252000329085, 0.05919498631556053, 0.07434295883285813, 0.11107855636510067, 0.055811163983889855, 0.05105875083245337, 0.04679817007854581, 0.056991238161572255, 0.017258397456316743, 0.06690926631563343, 0.02799666577629978, 0.006943018333913642, 0.02891532585636014, 0.0509156387852272, 0.07098270711139776, 0.04649855021853, 0.058309986343374476, 0.055372881251969375, 0.03170449679601006, 0.09899019525619224, 0.06357300822855905, 0.07036927010631189, 0.0013356014278542716, 0.04073197742400225, 0.0679988949559629, 0.06776994239771739, 0.02453526118188165, 0.06093409436289221, 0.043790509007521905, 0.021883853260078467, 0.059041884960606694, 0.009572020353516564, 0.03703765534737613, 0.07016670089797117, 0.0378729648218723, 0.05052689812146127, 0.03637106201495044, 0.06023836802341975, 0.010160561087104725, 0.03253099697758444, 0.03663623509055469, 0.048429893067805097, 0.0908078093198128, 0.0547850965813268, 0.05605813959846273, 0.02503556890587788, 0.03406686788366642, 0.03747670249140356, 0.02780352926492924, 0.04946784225467127, 0.060295257353573106, 0.019838562911900226, 0.11127587116789073, 0.02671295624168124, 0.0760856774286367, 0.03565270388207864, 0.08282178081572056, 0.03412437690712977, 0.013894704025005922, 0.03866986073262524, 0.12742506398353726, 0.1206157031992916, 0.04645775436074473, 0.038800463880761527, 0.027973718570137862, 0.03990491692093201, 0.03474334291240666, 0.03355497152369935, 0.016529083368368447, 0.05883656980586238, 0.046077889783191495, 0.014218646847439231, 0.03453759731200989, 0.13437598943710327, 0.014121472813712899, 0.027253564439888578, 1.0903930524364114, 21.88334684818983, 58.82792271673679, 91.98161110281944, 112.78340488672256, 100.11983960866928, 91.31566643714905, 97.42763087153435, 95.87621212005615, 97.11258217692375, 121.14905878901482, 98.41465830802917, 96.3662414252758, 85.93351364135742, 57.09756016731262, 58.51211026310921, 30.6694158911705, 30.91864451766014, 21.90190315246582, 27.097913436591625, 69.94478479027748, 92.81001225113869, 61.068628281354904, 31.353909261524677, 25.28180468827486, 41.668750271201134, 53.304371908307076, 35.15163637697697, 64.39702928066254, 34.76493112742901, 51.83828517794609, 39.62648145854473, 51.14607252180576, 54.64947693049908, 59.881986156105995, 53.82468178868294, 38.42791177332401, 35.796454176306725, 44.530574306845665, 45.23650802671909, 35.57359613478184, 43.07389587163925, 29.906663820147514, 26.23178221285343, 27.539854422211647, 36.29723310470581, 41.91821068525314, 48.582255095243454, 49.770314544439316, 53.74047830700874, 71.44324958324432, 78.34381610155106, 82.27159693837166, 87.78029814362526, 115.26648044586182, 85.4330424964428, 83.1749452650547, 89.4466683268547, 103.45366671681404, 110.94928130507469, 99.76075887680054, 59.68786597251892, 16.206913143396378, 0.9885376179590821, 0.2451656648190692, 0.17576966201886535, 0.01697591749689309, 0.06515215747640468, 0.057055099969147705, 0.0519687426276505, 0.027837480665766634, 0.038044438042561524, 0.0785415034624748, 0.1094002190802712, 0.048019622699939646, 0.042524434757069685, 0.01315911693382077, 0.068852765543852, 0.021623376123898197, 0.04957787306921091, 0.01757713132974459, 0.0018782091342472995, 0.07404961754218675, 0.0384047730040038, 0.031102192006073892, 0.032982003831421025, 0.04613407778379042, 0.05458078332594596, 0.03374478321347851, 0.010710585283959517, 0.023760019284964073, 0.043267788423690945, 0.03294324516900815, 0.006221077019290533, 0.030100411386229098, 0.03667679717182182, 0.03179951396305114, 0.0963675937964581, 0.035200899219489656, 0.058036081900354475, 0.045590332156280056, 0.04749080537294503, 0.05765566442278214, 0.07124373529222794, 0.015641315185348503, 0.008833178944769315, 0.03021149976120796, 0.03226591295970138, 0.015424273169628577, 0.08861433991114609, 0.028539383529277984, 0.038426811079261824, 0.03202631800377276, 0.05325452089891769, 0.023603778645338025, 0.020310188483563252, 0.025881522633426357, 0.07769149204250425, 0.08800093259196728, 0.07424582654493861, 0.030476685824396554, 0.15705382567830384, 0.10674934179405682, 0.1727715486777015, 0.20392635895404965, 0.14963632682338357, 0.14643220813013613, 0.15918755962047726, 0.12923216389026493, 0.12593555875355378, 0.09889214270515367, 0.14839088427834213, 0.1380081195384264, 0.16720823157811537, 0.14953690872061998, 0.1935502587002702, 0.11918110947590321, 0.15266577363945544, 0.12819799594581127, 0.2947304426925257, 0.13885434600524604, 0.1293376527610235, 0.23386330489302054, 0.15927548927720636, 0.10530027619097382, 0.1900823213509284, 0.23343115230090916, 0.12482790334615856, 0.14779634977458045, 0.09353861591080204, 0.2294516228721477, 0.3274271241389215, 0.13381829514401034, 0.09560354534187354, 0.18877811555285007, 0.21058146434370428, 0.2677063224837184, 0.08172948044375516, 0.20890876738121733, 0.12089212352293544, 0.20909451210172847, 0.15854775410844013, 0.16802931408165023, 0.1469104629359208, 0.09695938235381618, 0.1578584621893242, 0.19901387568097562, 0.11780098939198069, 0.16255070571787655, 0.1397743567940779, 0.12446988388546742, 0.22678894543787464, 0.13428268663119525, 0.2144151765969582, 0.15720534254796803, 0.1675601876922883, 0.5013933673035353, 17.9429354891181, 55.49729883670807, 100.34502312541008, 120.76901838183403, 113.35777446627617, 96.19512140750885, 102.17081755399704, 90.03334924578667, 89.90939229726791, 104.86363425850868, 88.45184370875359, 89.96208027005196, 75.99808037281036, 59.251713976264, 57.99649693071842, 38.27062301337719, 39.05791416764259, 51.924829334020615, 28.21627512574196, 74.16431397199631, 115.52653089165688, 88.00649240612984, 52.68142573535442, 49.55857090651989, 65.1589871942997, 82.5778529047966, 65.82131445407867, 85.93645468354225, 67.66229286789894, 79.38603937625885, 48.52508716285229, 72.65039160847664, 87.72415235638618, 91.10910192131996, 84.0283490717411, 69.00339290499687, 59.36093911528587, 78.41378554701805, 76.64199382066727, 50.12773096561432, 79.98684033751488, 58.93398642539978, 55.024228021502495, 42.39465571939945, 41.53733432292938, 44.58629831671715, 47.59785331785679, 55.14869034290314, 51.626096963882446, 60.311834290623665, 67.4107463657856, 73.51174458861351, 89.56657469272614, 109.19098645448685, 84.62778970599174, 87.89795503020287, 95.82117587327957, 117.0840673148632, 125.62765806913376, 112.5022579729557, 60.571911334991455, 14.017231240868568, 0.6431624537799507, 0.5489978659898043, 0.19849744479870424, 0.21963306848192587, 0.2539064426673576, 0.17160478862933815, 0.16914964537136257, 0.1793624582933262, 0.10842870324268006, 0.21455490816151723, 0.17933443479705602, 0.09855393116595224, 0.10469576722243801, 0.2365780365653336, 0.17428811261197552, 0.1366331722238101, 0.14928941731341183, 0.08668112684972584, 0.16306062054354697, 0.13993172178743407, 0.1280356288771145, 0.14739162696059793, 0.13885764114093035, 0.1732328231446445, 0.2428785734809935, 0.14969761337852105, 0.18608070560730994, 0.13897559809265658, 0.11373151166480966, 0.11254658384132199, 0.058191242715111, 0.12662859109696, 0.1910787436645478, 0.2479254300124012, 0.15092126646777615, 0.14272501721279696, 0.150808074104134, 0.13945100305136293, 0.11948764615226537, 0.1457750066765584, 0.236263633123599, 0.16455263423267752, 0.11792865363531746, 0.15521635708864778, 0.10544145494350232, 0.13834290235536173, 0.2191557636251673, 0.15128549770452082, 0.08129475259920582, 0.12220116070238873, 0.1676438277354464, 0.11577861470868811, 0.0842320172523614, 0.09274474796256982, 0.1739283194183372, 0.17053052986739203, 0.2062242856482044, 0.10950951516861096], [0.019298171791888308, 0.03452945966273546, 0.02509082365577342, 0.028241333311598282, 0.03245863757911138, 0.05353763168386649, 0.0633654443663545, 0.008069058130786289, 0.02494475043931743, 0.03142150104395114, 0.02021723448706325, 0.034333859221078455, 0.011234378271183232, 0.018144095047318842, 0.05521147897525225, 0.05228994043136481, 0.042065635352628306, 0.022676457701891195, 0.051861049578292295, 0.04863797272264492, 0.07278261560713872, 0.01225507623530575, 0.029492527501133736, 0.004723296378870145, 0.034499027897254564, 0.012461966598493746, 0.009318118645751383, 0.0668832911469508, 0.018650271304068156, 0.053052749499329366, 0.015760717469675, 0.09871952657704242, 0.02579591775429435, 0.0070790168956591515, 0.021902557236899156, 0.016616504653939046, 0.08310357428854331, 0.056797400320647284, 0.05100668546219822, 0.11030056295567192, 0.023290453173103742, 0.028209524862177204, 0.0698716971965041, 0.023932158583193086, 0.039070646453183144, 0.048895564759732224, 0.04263148955942597, 0.060463316694949754, 0.039382545146509074, 0.029171721180318855, 0.09866535721812397, 0.02773225340206409, 0.05781916326668579, 1.0334151098504663, 14.282061830163002, 52.258345037698746, 84.76977288722992, 93.84918808937073, 79.77953106164932, 78.92013877630234, 76.41956135630608, 80.96093326807022, 68.32675561308861, 54.22847472131252, 46.382393538951874, 23.757554478943348, 28.115477934479713, 29.042586386203766, 20.57502005249262, 49.03430163860321, 49.6164608001709, 84.93053466081619, 60.03506474196911, 83.42241078615189, 69.20046553015709, 33.198180198669434, 25.185219570994377, 43.8813791424036, 79.71068635582924, 83.54946076869965, 53.48838463425636, 50.496341586112976, 67.72878929972649, 41.70272424817085, 67.25786536931992, 46.92898280918598, 43.04490342736244, 53.25927212834358, 42.96996384859085, 45.30122235417366, 52.168597653508186, 54.00911249220371, 74.24531802535057, 61.42017401754856, 72.03566819429398, 58.8148058205843, 77.51999750733376, 88.70306342840195, 87.34201446175575, 82.9089443385601, 66.05778336524963, 47.25288882851601, 35.5588985234499, 21.5500458329916, 25.03342531621456, 23.92416413873434, 24.225609563291073, 25.282501950860023, 35.95460548996925, 33.04798185825348, 38.86931508779526, 60.14253817498684, 73.96583542227745, 74.99801203608513, 74.86750423908234, 80.57308807969093, 85.1571772992611, 75.2463287115097, 33.71482327580452, 5.785652194172144, 0.8168772573117167, 0.34990006824955344, 0.11872249931911938, 0.06606206763535738, 0.011891832054971019, 0.007931802556413459, 0.043366456957301125, 0.06884461676236242, 0.07236879406264052, 0.02533596987632336, 0.07413728002575226, 0.06374924603733234, 0.0010074628039546951, 0.06166162173030898, 0.03859923053823877, 0.02573945701442426, 0.02379444380494533, 0.010749058219516883, 0.06609308940824121, 0.07198232808150351, 0.026063962941407226, 0.029608675467898138, 0.05070564438938163, 0.0580718200217234, 0.08387510359170847, 0.015477476808882784, 0.0858450158557389, 0.042244864016538486, 0.06147473039163742, 0.03479884813714307, 0.06457164956373163, 0.017982779972953722, 0.0130328033992555, 0.010051598037534859, 0.022836770876892842, 0.023028246832836885, 0.032744052732596174, 0.05888318039069418, 0.025124956882791594, 0.04701819831097964, 0.02824759703798918, 0.022856445211800747, 0.025073511205846444, 0.04065749919391237, 0.009058027426362969, 0.07109536512871273, 0.025600443477742374, 0.03217856588889845, 0.013394952911767177, 0.1005424490722362, 0.08069538671406917, 0.12076992890797555, 0.049482321555842645, 0.05010664586734492, 0.028734700099448673, 0.00463381377812766, 0.03014850997715257, 0.016835618189361412, 0.04355518511147238, 0.005923847338635824, 0.02498755195119884, 0.02837273983459454, 0.048805883634486236, 0.02140072625479661, 0.018439922532706987, 0.04537405176961329, 0.0631644188251812, 0.012131747989769792, 0.05438514577690512, 0.02971807731228182, 0.030323128048621584, 0.022310024141916074, 0.033398816231056117, 0.07158137537771836, 0.012119340208300855, 0.05098421323054936, 0.08018290405743755, 0.022098916524555534, 0.029416592806228437, 0.010089958723256132, 0.020539007455226965, 0.012228136274643475, 0.038101806057966314, 0.03232451665098779, 0.04591344470100012, 0.025531145438435487, 0.05145754759723786, 0.06345057612634264, 0.023512663319706917, 0.04308611067244783, 0.07227532056276686, 0.041982147449743934, 0.06507474405225366, 0.036436270820559, 0.032829629781190306, 0.037460059829754755, 0.021020403401053045, 0.03159265143040102, 0.1070249531767331, 0.007430456289512222, 0.0795242702588439, 0.012689354152826127, 0.11578179110074416, 0.06378104706527665, 0.11995952590950765, 0.02942475457530236, 0.16577996837440878, 0.05063855795015115, 0.15059930796269327, 3.1299827713519335, 28.278242200613022, 74.47280421853065, 100.99094286561012, 104.14596676826477, 95.17054438591003, 92.60342493653297, 96.46325021982193, 112.52086937427521, 103.64032790064812, 76.15875095129013, 65.88164001703262, 26.840912327170372, 32.03461043536663, 25.266381315886974, 22.24505513906479, 28.034523278474808, 16.916937343776226, 32.41603396832943, 27.54022680222988, 42.19054587185383, 31.152328178286552, 18.910194486379623, 19.724580086767673, 32.535233572125435, 32.02404700219631, 38.261058926582336, 22.7481272444129, 21.07596807181835, 25.367245003581047, 17.920856773853302, 15.829643737524748, 19.947810508310795, 11.484088618308306, 15.468773301690817, 18.074769414961338, 15.792735368013382, 20.556621439754963, 22.830314934253693, 36.151613518595695, 30.844217911362648, 33.445018753409386, 29.31226171553135, 31.766717210412025, 32.986178174614906, 60.12266904115677, 42.58091412484646, 25.00288065522909, 22.42002435028553, 22.059501595795155, 14.486734997481108, 23.073192201554775, 18.497481532394886, 19.79495421051979, 22.196089066565037, 53.5294072329998, 55.33727802336216, 54.52343389391899, 87.5681023299694, 107.29664370417595, 101.32169231772423, 84.87091585993767, 92.88299113512039, 94.99836042523384, 98.851498067379, 56.57527059316635, 16.988856084644794, 1.692333477549255, 0.20114008424570784, 0.24851616472005844, 0.038131354667712, 0.06818406080128625, 0.026219218379992526, 0.03601288299250882, 0.05629894425510429, 0.005464583628054243, 0.09233712335117161, 0.02174327750253724, 0.01764791737514315, 0.06991475660470314, 0.018731002128333785, 0.0583947025006637, 0.03336632129503414, 0.0682862990652211, 0.0599689461523667, 0.04069199050718453, 0.05229947702900972, 0.07154726627049968, 0.015092077665030956, 0.030090828404354397, 0.032994453358696774, 0.05905765930947382, 0.03419468797801528, 0.03396558699023444, 0.08331942051881924, 0.026797392238222528, 0.04465334102860652, 0.04688088614784647, 0.018576757865957916, 0.007017174657448777, 0.04960061618476175, 0.02623258260427974, 0.06613834557356313, 0.020300475625845138, 0.035014623863389716, 0.026347483762947377, 0.04978411219781265, 0.023789664373907726, 0.016135472360474523, 0.05155592298251577, 0.05632420325127896, 0.07144932504161261, 0.08386699191760272, 0.07177880150265992, 0.04031864940770902, 0.020473058357310947, 0.0758143630810082, 0.029067575596855022, 0.03460806794464588, 0.05298483185470104, 0.048578823552816175, 0.023006234732747544, 0.040447738574584946, 0.07094044180121273, 0.17751151230186224, 0.16283270699204877, 0.1950598761322908, 0.10554364125709981, 0.11137479203171097, 0.22884649049956352, 0.09978246758691967, 0.12239918054547161, 0.09567499189870432, 0.11530756615684368, 0.15606945584295318, 0.13476208434440196, 0.10761259312857874, 0.14482379599940032, 0.15518526110099629, 0.16103898058645427, 0.11626541163423099, 0.1065296215529088, 0.1578747745952569, 0.17036566918250173, 0.05548530178202782, 0.1412305247504264, 0.18356584914727136, 0.07782795073580928, 0.10932940334896557, 0.19000812142621726, 0.14081369008636102, 0.2573891042266041, 0.08768609128310345, 0.1472724083578214, 0.16051857179263607, 0.07990937068825588, 0.07970636361278594, 0.14081262139370665, 0.14143525360850617, 0.15504557406529784, 0.1949376444099471, 0.12408358859829605, 0.2220990025671199, 0.1202600215037819, 0.14091708610067144, 0.18362010014243424, 0.08694347605342045, 0.1099978483398445, 0.16898442845558748, 0.12856814952101558, 0.1536587969167158, 0.25417141907382756, 0.10492108325706795, 0.2920961152995005, 0.16525675426237285, 0.3476400801446289, 2.128970422782004, 24.03771534562111, 77.16609969735146, 114.03800636529922, 116.89092367887497, 99.59926754236221, 94.15053471922874, 101.03571206331253, 101.99854239821434, 89.90393579006195, 69.28123399615288, 61.20650768280029, 32.60264955461025, 38.40651132166386, 42.784237414598465, 28.898984491825104, 72.58912369608879, 66.675516217947, 112.87202373147011, 80.94442695379257, 115.12987017631531, 92.52912372350693, 47.68211379647255, 40.661656111478806, 66.71602964401245, 102.64163509011269, 112.41420149803162, 70.88021099567413, 73.23798447847366, 96.22836962342262, 57.77665592730045, 96.73238217830658, 68.94274055957794, 60.85219569504261, 74.43796008825302, 62.61332519352436, 65.48934906721115, 72.44888082146645, 80.35700887441635, 103.0240997672081, 86.46397277712822, 96.86659097671509, 76.17207303643227, 107.72146090865135, 120.78393638134003, 111.7122195661068, 100.01490443944931, 83.87158468365669, 65.68373143672943, 47.22286283969879, 34.12080109119415, 40.40717996656895, 37.83788323402405, 37.09905467927456, 39.01037111878395, 54.18622098863125, 49.06109780073166, 57.55620315670967, 83.68789494037628, 95.16026213765144, 97.92689368128777, 93.16428244113922, 101.68754428625107, 112.34778106212616, 110.47951251268387, 61.842247769236565, 14.748483002185822, 1.1756753199733794, 0.6074380769859999, 0.22004268947057426, 0.1839573765755631, 0.12062978174071759, 0.24331329390406609, 0.10307171804015525, 0.27031586214434355, 0.188001784554217, 0.21510691760340706, 0.1753337838454172, 0.1745626627234742, 0.1552885680575855, 0.14213291695341468, 0.13994037522934377, 0.11764274124288931, 0.10227986131212674, 0.15160782728344202, 0.1920869215973653, 0.15052142698550597, 0.1667374130920507, 0.040361129940720275, 0.1931514433817938, 0.18017939961282536, 0.16385923081543297, 0.1167432359943632, 0.1577452104538679, 0.14984892244683579, 0.11943141362280585, 0.1271428697509691, 0.2267944224877283, 0.14651685749413446, 0.14714749006088823, 0.08625441420008428, 0.05313775509421248, 0.14755653217434883, 0.10147520253667608, 0.21119238546816632, 0.08210567510104738, 0.20366865559481084, 0.07823783147614449, 0.09758231884916313, 0.1314857101533562, 0.15665078011807054, 0.09887977110338397, 0.3033071762183681, 0.1692963531240821, 0.20778876263648272, 0.1547960046445951, 0.1721250786795281, 0.20257524942280725, 0.18641516187926754, 0.15650368644855917, 0.12489986198488623, 0.10247860103845596, 0.16298124042805284], [0.07451430588844232, 0.025366396075696684, 0.018950128651340492, 0.018765246677503455, 0.022776436126150656, 0.025689373178465758, 0.017984160367632285, 0.04965541636920534, 0.024767189752310514, 0.024502281994500663, 0.04918935876048636, 0.03935828062822111, 0.04851419733313378, 0.051947621104773134, 0.027969232287432533, 0.02103807022649562, 0.06202391225087922, 0.03521651029586792, 0.0281579808506649, 0.038229325582506135, 0.0332290685037151, 0.016441615698568057, 0.047636882300139405, 0.035700286680366844, 0.06436726951505989, 0.1343274232931435, 0.030186571020749398, 0.013178823737689527, 0.07605461854836904, 0.027927612645726185, 0.007745645943941781, 0.03254901632317342, 0.06080676037527155, 0.06514836510177702, 0.0461439075297676, 0.032602191204205155, 0.016589681581535842, 0.06749179286998697, 0.04292976242140867, 0.016498280529049225, 0.0787086202763021, 0.06711696376441978, 0.07869618930271827, 0.05586158178630285, 0.056974083418026567, 0.12872989318566397, 0.04067893241881393, 0.02580834687250899, 0.15109095111256465, 0.07610376356751658, 0.16587043617619202, 1.7246627365238965, 21.562349572777748, 54.44159388542175, 86.44520938396454, 87.32935354113579, 77.31588765978813, 74.74237695336342, 71.27902239561081, 83.21508631110191, 68.8269455730915, 42.74717800319195, 21.95306170731783, 33.959408551454544, 38.98687317967415, 75.72821885347366, 59.17919106781483, 58.9220816642046, 68.00348415970802, 69.9017482995987, 87.6463021337986, 74.87456426024437, 72.40323007106781, 51.82845130562782, 64.91703137755394, 77.05608800053596, 75.85760191082954, 70.22717043757439, 70.480145663023, 63.90310138463974, 76.30374357104301, 81.97050869464874, 87.34168767929077, 90.367890894413, 84.22245785593987, 77.3605352640152, 92.62075200676918, 85.0509425997734, 87.55314633250237, 85.13494849205017, 78.15454825758934, 78.80260348320007, 75.19088208675385, 76.18217289447784, 70.3071941435337, 79.10943701863289, 94.64564815163612, 77.85419717431068, 93.87465432286263, 91.48753121495247, 88.68316769599915, 88.07903811335564, 83.7174041569233, 73.50773200392723, 65.75125381350517, 83.32949817180634, 74.2890764772892, 57.146330550312996, 27.160562574863434, 35.019996240735054, 25.320587307214737, 21.942399479448795, 28.061783015727997, 41.10830694437027, 75.5850501358509, 73.49349796772003, 71.18478745222092, 69.78882595896721, 78.5024955868721, 62.69747167825699, 39.4445776194334, 9.28067235276103, 1.9083072384819388, 0.39578744501341134, 0.0552765133761568, 0.09541128456476144, 0.09729566430905834, 0.17220680398168042, 0.04003518981335219, 0.03422347588639241, 0.06274258208577521, 0.05865969375008717, 0.03864321392029524, 0.06774688386940397, 0.07748274816549383, 0.02216660595877329, 0.029465027218975592, 0.032531854158150963, 0.03613713335653301, 0.0627829103905242, 0.04443264115252532, 0.031909010431263596, 0.04250720208801795, 0.0419264937954722, 0.00884342707649921, 0.00855555726957391, 0.04386466069263406, 0.024322010613104794, 0.08741072480916046, 0.06969172638491727, 0.03641431809228379, 0.11705288969096728, 0.04245753756549675, 0.03601808173698373, 0.05723201313230675, 0.06119121884694323, 0.03084655738348374, 0.026627672341419384, 0.04861337052716408, 0.045874997740611434, 0.0981301796855405, 0.04712090412795078, 0.018714170219027437, 0.026780293155752588, 0.038755523128202185, 0.00858135432281415, 0.0694055987696629, 0.029097782862663735, 0.018281063967151567, 0.044577860899153166, 0.014329327041195938, 0.024221395797212608, 0.062346616614377126, 0.02176321344450116, 0.07517914404161274, 0.05985413219605107, 0.028530538984341547, 0.043743675778387114, 0.03529105902998708, 0.01563474717841018, 0.04047409966005944, 0.05063761542260181, 0.050884899028460495, 0.0459475315437885, 0.04393368784803897, 0.001237177802977385, 0.04295106577046681, 0.0691504187125247, 0.08376059020520188, 0.030459195259027183, 0.05386711927712895, 0.03719007763720583, 0.022842626422061585, 0.013359001422941219, 0.05219668586505577, 0.029732161419815384, 0.012520697382569779, 0.010801696898852242, 0.06217721398570575, 0.048467185988556594, 0.038304479166981764, 0.12085457085049711, 0.04371778224594891, 0.018705615111684892, 0.05285613973683212, 0.03382015202078037, 0.022739480882592034, 0.019683227692439687, 0.04248054785421118, 0.05780877319921274, 0.022497731843031943, 0.030649604377686046, 0.0077146789044491015, 0.08409598158323206, 0.028457450425776187, 0.08158656506566331, 0.03534791867423337, 0.04752886641654186, 0.023351142299361527, 0.05257712931779679, 0.02716887611313723, 0.06118842837167904, 0.026720375863078516, 0.0322192763997009, 0.1754947705194354, 0.040156920586014166, 0.11134604123071767, 5.225351834669709, 39.68212567269802, 78.88054490089417, 102.49948471784592, 97.97821372747421, 94.68343332409859, 97.77876242995262, 96.48718893527985, 111.26282528042793, 90.05881547927856, 55.442087799310684, 36.52200624346733, 28.52453738451004, 25.488891676068306, 37.370610907673836, 37.36656412482262, 33.476849645376205, 24.31818589568138, 53.63139756023884, 61.90353088080883, 59.557912945747375, 63.129588291049004, 56.46894469857216, 62.25524760782719, 68.54689300060272, 62.04369775950909, 60.7453378289938, 64.7594766318798, 57.497519105672836, 61.0684534907341, 67.77610436081886, 73.42793628573418, 71.82908847928047, 65.80480054020882, 61.49443343281746, 64.24431547522545, 62.0357333868742, 55.207454189658165, 55.17213128507137, 58.000289127230644, 59.44804564118385, 63.417844623327255, 61.09909504652023, 62.090404853224754, 70.2349828183651, 82.0736275613308, 70.5285094678402, 81.59229978919029, 77.1642529964447, 59.423145577311516, 62.181618958711624, 51.683815866708755, 48.640000596642494, 39.814719557762146, 40.0591604411602, 40.22787518799305, 33.3940938860178, 21.487468890845776, 25.31291551887989, 31.262402571737766, 29.489850886166096, 39.76328931748867, 56.33036233484745, 99.06130000948906, 96.61195144057274, 87.20101162791252, 84.17078822851181, 91.37820348143578, 85.4930716753006, 63.62560227513313, 23.036959245800972, 5.116604520007968, 0.30030314053874463, 0.05693438222806435, 0.07264741856488399, 0.062053572182776406, 0.13273967255372554, 0.0643666461110115, 0.007977916829986498, 0.045176573694334365, 0.08329582022270188, 0.035220291538280435, 0.07890408713137731, 0.03411617988604121, 0.05222803047217894, 0.03263754340878222, 0.030705341523571406, 0.02615820827486459, 0.033277055772487074, 0.07265637628734112, 0.044701443330268376, 0.06724561506416649, 0.08345333364559337, 0.05015922703023534, 0.04277094281860627, 0.07359492592513561, 0.039406739160767756, 0.02405029365036171, 0.0382020887627732, 0.046963257118477486, 0.04319925108575262, 0.04039313134853728, 0.06516081091831438, 0.026548711539362557, 0.018491306982468814, 0.09798912709811702, 0.0327380932867527, 0.06629809286096133, 0.03413751292100642, 0.05402993534517009, 0.016974524114630185, 0.099788367660949, 0.01851536926551489, 0.007951662428240525, 0.059527746780076995, 0.02766014262306271, 0.03489222515781876, 0.010926266386377392, 0.039798325960873626, 0.050267881160834804, 0.09836251643719152, 0.07967866666149348, 0.06480645024566911, 0.045665682409889996, 0.0850875502510462, 0.1060432253871113, 0.16710621595848352, 0.1472152629867196, 0.045687954261666164, 0.0922444587922655, 0.28869042929727584, 0.10549292288487777, 0.09969660852220841, 0.13675645779585466, 0.08902009431039914, 0.22248079301789403, 0.11256316342041828, 0.13929632463259622, 0.07981306218425743, 0.09807998823816888, 0.08967630870756693, 0.18187094712629914, 0.17682458041235805, 0.17459193302784115, 0.19833412778098136, 0.143727361864876, 0.09367687802296132, 0.24551821465138346, 0.14879614143865183, 0.16188762645469978, 0.24115742911817506, 0.21130899171112105, 0.09885136169032194, 0.1425389014184475, 0.15869621332967654, 0.12967204966116697, 0.10029523225966841, 0.14979812985984609, 0.238630638923496, 0.17804698669351637, 0.10249518803902902, 0.0986668786208611, 0.16071357851615176, 0.1050991022202652, 0.19760621449677274, 0.1357152542914264, 0.16922869894187897, 0.18148544593714178, 0.13037398777669296, 0.0934917492850218, 0.16663444752339274, 0.10425887972814962, 0.18482367071555927, 0.3353758226148784, 0.24181629298254848, 0.31390154210384935, 3.3407470118254423, 35.84349565207958, 82.95372113585472, 115.79226583242416, 108.14399063587189, 95.51321759819984, 92.86689519882202, 88.9058281481266, 103.07722091674805, 87.09982305765152, 56.558904871344566, 30.717927888035774, 48.82091648876667, 55.064676851034164, 107.16324806213379, 84.53360795974731, 82.6686604321003, 93.29046607017517, 101.43638536334038, 125.71142837405205, 110.75444296002388, 108.04474756121635, 74.60873812437057, 93.74259620904922, 112.71238669753075, 107.81928285956383, 101.35924190282822, 105.1796405017376, 91.92030519247055, 113.78823816776276, 120.24812713265419, 122.83318921923637, 130.18527030944824, 117.99727231264114, 106.63257613778114, 124.87776070833206, 118.06564584374428, 118.89541491866112, 117.83230036497116, 112.78118580579758, 109.1809093952179, 102.9371452331543, 107.3394750058651, 101.7156931757927, 115.8692193031311, 129.30195450782776, 116.0254593193531, 117.65016093850136, 128.29412698745728, 125.5799250304699, 123.91407921910286, 115.96315786242485, 97.4616314470768, 87.82521933317184, 107.78760775923729, 101.25473231077194, 82.1977137029171, 45.01371078193188, 52.96856492757797, 44.15090247988701, 35.532159358263016, 41.951622292399406, 58.977699279785156, 101.1438162624836, 96.20012193918228, 92.84113258123398, 87.8301514685154, 105.35730376839638, 98.36694046854973, 69.4898883998394, 20.860838815569878, 3.7055678106844425, 0.5280933470930904, 0.23957015335327014, 0.24741998291574419, 0.19871388474712148, 0.2379645613837056, 0.10822324707987718, 0.11469259290606715, 0.24899927317164838, 0.1549333316506818, 0.07940165261970833, 0.30326600186526775, 0.17477193352533504, 0.13571374031016603, 0.0737476599169895, 0.20145781250903383, 0.13466127100400627, 0.12020247537293471, 0.12173912182333879, 0.14670680277049541, 0.14879511727485806, 0.18635899614309892, 0.1518257663701661, 0.13760464353254065, 0.2173664901056327, 0.09224010238540359, 0.17996165348449722, 0.15502430411288515, 0.21121650526765734, 0.2492887107655406, 0.1249032313353382, 0.151878904143814, 0.16855157824466005, 0.20914854045258835, 0.22113508632173762, 0.06734698501531966, 0.25537360925227404, 0.09216107850079425, 0.1526825610199012, 0.16820030490634963, 0.18505878309952095, 0.14059368782909587, 0.21166361955692992, 0.12328511933446862, 0.18897383473813534, 0.14089982374571264, 0.12696278019575402, 0.16507583350175992, 0.15590668801451102, 0.12914748484035954, 0.1738208267488517, 0.19283273548353463, 0.17894091841299087, 0.20756108657224104], [0.07384544529486448, 0.017177714871650096, 0.08827667756122537, 0.046728771849302575, 0.06166510240291245, 0.043058287556050345, 0.056454965961165726, 0.0363094118074514, 0.061150897963671014, 0.02918739348388044, 0.007880188040871872, 0.045313822774915025, 0.0630229951639194, 0.06364999862853438, 0.014834637768217362, 0.0807537863147445, 0.03533805182087235, 0.05463945009978488, 0.030784743903495837, 0.01846215542173013, 0.07052308021229692, 0.0837572208547499, 0.06376923207426444, 0.1378095505060628, 0.008567993809265317, 0.0550763524370268, 0.030038659133424517, 0.06591647310415283, 0.029829410595993977, 0.018468675189069472, 0.03149882541038096, 0.02735908670729259, 0.009602699810784543, 0.004151024450038676, 0.06505411976831965, 0.03655615364550613, 0.07079636125126854, 0.0640555378049612, 0.037997330218786374, 0.006400992633643909, 0.07980792652233504, 0.027755681148846634, 0.005296969575283583, 0.057244507188443094, 0.11547324320417829, 0.02015890353504801, 0.037731771226390265, 0.05168724230316002, 0.06080103470594622, 0.16092764359200373, 12.073083613067865, 64.55912858247757, 84.98384580016136, 84.59223881363869, 70.88531032204628, 74.7220404446125, 69.49447095394135, 42.9116103798151, 41.967820823192596, 35.16903944313526, 34.599119424819946, 37.0350357145071, 46.220134645700455, 66.63196295499802, 78.15235957503319, 138.03198605775833, 60.47807537019253, 47.29537434875965, 67.5401446223259, 35.82476645708084, 32.94421702623367, 37.0755073428154, 36.948058381676674, 28.84933825582266, 35.069860965013504, 40.9277368336916, 45.94167038798332, 53.69606249034405, 73.66895735263824, 78.07118073105812, 49.748644307255745, 37.81844347715378, 27.49156281352043, 29.531354159116745, 27.55749687552452, 33.04725989699364, 34.38241705298424, 37.177873849868774, 50.083197355270386, 47.74363249540329, 45.61161629855633, 44.90838423371315, 41.110051050782204, 45.66395848989487, 47.11390748620033, 34.58768963813782, 35.186047330498695, 44.14225034415722, 56.265306025743484, 56.50299087166786, 58.48939508199692, 48.84732127189636, 55.11801838874817, 51.70570269227028, 54.66581605374813, 60.4884298145771, 58.14796440303326, 54.24162961542606, 74.9913015961647, 76.59017980098724, 51.72862686216831, 56.827812641859055, 51.12246818840504, 38.65218713879585, 24.153624325990677, 35.62030702829361, 56.414334028959274, 68.40387627482414, 59.654176980257034, 67.00799077749252, 74.7161203622818, 69.09743785858154, 46.423925310373306, 18.364507667720318, 0.48758392862509936, 0.4935621953336522, 0.10562019378994592, 0.04639877217414323, 0.07584222330478951, 0.07660906223463826, 0.08588811237132177, 0.014325663614727091, 0.03458369952568319, 0.10075405763927847, 0.04657826058974024, 0.03974964849476237, 0.02805309497489361, 0.0331130522681633, 0.07102918039890938, 0.03242710743506905, 0.040420412697130814, 0.004699032788266777, 0.050061549263773486, 0.038365301879821345, 0.022647500954917632, 0.06317220395430923, 0.028954967674508225, 0.03227674089430366, 0.06273951701587066, 0.02104696486640023, 0.03959872905397788, 0.07642838638275862, 0.07460625056410208, 0.03725542002939619, 0.011014850988431135, 0.029171184978622478, 0.024753239231358748, 0.027653710058075376, 0.04074260126799345, 0.06121095626440365, 0.06397746386937797, 0.05880251635971945, 0.02193708009144757, 0.12355019222013652, 0.07763577159494162, 0.07275928248418495, 0.06168247608002275, 0.026466952840564772, 0.024849907676980365, 0.062049108164501376, 0.028793318633688614, 0.016780686273705214, 0.038438700285041705, 0.16053938161348924, 0.10794888992677443, 0.04321797547163442, 0.06354755998472683, 0.030519134816131555, 0.026920026575680822, 0.05708904951461591, 0.08762744677369483, 0.032028700297814794, 0.0462165229691891, 0.07104343705577776, 0.08491110464092344, 0.01717679089779267, 0.010388187056378229, 0.02556481667852495, 0.07353369874181226, 0.043238915168331005, 0.02094898281939095, 0.045064639271004125, 0.042816985660465434, 0.037523361315834336, 0.02941930350061739, 0.08511912121321075, 0.05814137039124034, 0.09230668045347556, 0.03409007484151516, 0.1630648656282574, 0.015125467816687888, 0.05264998224447481, 0.05148846918018535, 0.050181732658529654, 0.020668879587901756, 0.020355073575046845, 0.03160308231599629, 0.02526152689824812, 0.021450552194437478, 0.05473234472447075, 0.01392179612594191, 0.02043210479314439, 0.0829441609675996, 0.10951179356197827, 0.0808557054551784, 0.06660004306468181, 0.06462809731601737, 0.0816947034036275, 0.04181280790362507, 0.06954626544029452, 0.07219120554509573, 0.015715631998318713, 0.14349650940857828, 0.07289947418030351, 0.2130710580968298, 0.2773702429840341, 25.61197467148304, 87.56161987781525, 95.71772262454033, 97.95669168233871, 85.63654437661171, 99.8313818871975, 96.20147466659546, 68.55509296059608, 61.70045077800751, 51.5925257652998, 52.169239819049835, 26.71012904495001, 13.845733143389225, 40.538611114025116, 58.48501391708851, 134.88621085882187, 59.65450756251812, 51.11213654279709, 67.92463079094887, 42.96033896505833, 43.83051507174969, 43.345482498407364, 43.69413658976555, 32.151184380054474, 35.095577985048294, 42.44279533624649, 47.08049587905407, 57.97691658139229, 85.28084546327591, 85.94698771834373, 54.95047777891159, 38.89917388558388, 27.496382854878902, 27.89144955575466, 27.114649638533592, 30.956885665655136, 30.807532779872417, 36.051644682884216, 53.47556412220001, 49.40959610044956, 51.42432019114494, 50.59086911380291, 47.11360350251198, 49.35465104877949, 51.06893666088581, 36.32489562034607, 34.845388010144234, 45.246079713106155, 62.930592969059944, 67.02464908361435, 71.2386305630207, 54.60553988814354, 56.80078849196434, 55.3243663161993, 57.44993045926094, 63.027183786034584, 58.00740994513035, 55.106353014707565, 51.00269861519337, 47.26630210876465, 33.943631798028946, 37.44666762650013, 30.081969313323498, 30.825205631554127, 34.03477370738983, 54.854483529925346, 78.83497774600983, 97.20512241125107, 80.87503507733345, 78.92064794898033, 87.96606257557869, 87.34705299139023, 69.21887174248695, 34.92586009204388, 1.6457095043733716, 0.33709338982589543, 0.12633159843971953, 0.0935101397044491, 0.020377987384563312, 0.033915855674422346, 0.028918244352098554, 0.10250511797494255, 0.03672056904179044, 0.053847778908675537, 0.014914281346136704, 0.07602551893796772, 0.01868766255938681, 0.03435891412664205, 0.019655014948511962, 0.04177790840913076, 0.10306335403583944, 0.012823432407458313, 0.013109168539813254, 0.016218949131143745, 0.03216396042262204, 0.03235480369767174, 0.07941577568999492, 0.04022667504614219, 0.05056917456386145, 0.0325935934233712, 0.04262228321749717, 0.07280556281330064, 0.04448161547770724, 0.06704956933390349, 0.0827779941027984, 0.023274550803762395, 0.026548218011157587, 0.036728261402458884, 0.038236119944485836, 0.005524287089428981, 0.017912032890308183, 0.05896570350159891, 0.02547558269725414, 0.09000208927318454, 0.014258576247812016, 0.014104792116995668, 0.02680896046513226, 0.03114106941211503, 0.03534741401381325, 0.034423425313434564, 0.026233421231154352, 0.05652509520587046, 0.05715978732041549, 0.044957810823689215, 0.04631818606867455, 0.031567043624818325, 0.19258910324424505, 0.17332568066194654, 0.16791187663329765, 0.14578885515220463, 0.14852375839836895, 0.19106728490442038, 0.12939294276293367, 0.1325277003343217, 0.15350048197433352, 0.09537956517306156, 0.07846890657674521, 0.10182538491790183, 0.14231533685233444, 0.1429295085836202, 0.10987670757458545, 0.16066530923126265, 0.10479665477760136, 0.11909890177776106, 0.11401288953493349, 0.116536614659708, 0.19341444567544386, 0.24774170393357053, 0.17292970034759492, 0.3462083882186562, 0.08327789735631086, 0.18686653609620407, 0.16103167785331607, 0.1637043445953168, 0.08240260096499696, 0.16107598406961188, 0.21329604758648202, 0.15936809446429834, 0.13188468874432147, 0.181055816647131, 0.10398168757092208, 0.1349969592411071, 0.20995816419599578, 0.3067800117423758, 0.23941949737491086, 0.08271648490335792, 0.17490894882939756, 0.19547512260032818, 0.08907836774596944, 0.14136476442217827, 0.1914533946546726, 0.12495020928326994, 0.22857366217067465, 0.23707800661213696, 0.3756464476464316, 0.19997693103505298, 22.77332179248333, 93.34782779216766, 109.31651651859283, 106.60292252898216, 89.10469427704811, 95.54024934768677, 89.89618420600891, 57.5194401293993, 55.00942401587963, 45.92831790447235, 50.67456342279911, 52.841963320970535, 63.61441187560558, 88.9235807955265, 108.07332962751389, 154.63347762823105, 83.3676329255104, 68.43620494008064, 102.48101770877838, 56.0769235342741, 54.75567743182182, 59.27111953496933, 62.16301515698433, 51.705793887376785, 55.53748548030853, 62.568282410502434, 73.52506667375565, 78.13810274004936, 100.37022337317467, 103.23653876781464, 72.15669929981232, 60.55722512304783, 47.2641172260046, 48.63099507987499, 46.37536011636257, 54.013797640800476, 56.02094113826752, 57.63190649449825, 82.91402846574783, 75.06304174661636, 73.59972506761551, 72.85704731941223, 67.85077035427094, 73.81148010492325, 74.69278201460838, 59.39375415444374, 57.186076417565346, 67.15122789144516, 83.10789406299591, 80.71919783949852, 90.02979263663292, 73.41896876692772, 84.83831360936165, 78.78020748496056, 83.5026016831398, 91.09020173549652, 85.61630666255951, 80.18449813127518, 105.16828671097755, 105.190789103508, 71.54402017593384, 78.38126689195633, 67.27530643343925, 53.37807655334473, 39.06296029686928, 52.178819105029106, 78.5727310180664, 92.49619469046593, 79.45240661501884, 85.71544334292412, 99.1207592189312, 100.18800035119057, 76.08811274170876, 34.302682131528854, 0.930703355697915, 0.5193691933527589, 0.2086845348821953, 0.13157867157133296, 0.1359938713721931, 0.2206759640830569, 0.22472237586043775, 0.17335440177703276, 0.21272656798828393, 0.16929457196965814, 0.15542297100182623, 0.25127561821136624, 0.13581973384134471, 0.09826004068600014, 0.13332493021152914, 0.09366306665469892, 0.1497791160363704, 0.18559563788585365, 0.12638653221074492, 0.19792486302321777, 0.14291471015894786, 0.14574184751836583, 0.23993533453904092, 0.1554863652563654, 0.17610883835004643, 0.1536925943219103, 0.1390282015199773, 0.14230844972189516, 0.11064209189498797, 0.19770342099945992, 0.24227642454206944, 0.13777802407275885, 0.15377348841866478, 0.18258628842886537, 0.22576917515834793, 0.153537426085677, 0.18133223697077483, 0.19689590495545417, 0.15579726576106623, 0.1847605881630443, 0.10980873426888138, 0.16293742402922362, 0.13131425919709727, 0.1385224427212961, 0.11278659439994954, 0.17445200850488618, 0.1879911866853945, 0.13255328958621249, 0.1489610318094492, 0.21066206158138812, 0.1706831599585712, 0.1091795859974809], [0.019683823265950195, 0.06530888422275893, 0.039008699386613443, 0.010778147625387646, 0.07165829156292602, 0.036945384126738645, 0.03878867115417961, 0.04941319792123977, 0.03812483118963428, 0.06480272466433235, 0.04485829995246604, 0.06640059829805978, 0.05648481514072046, 0.03403466609597672, 0.02498072604794288, 0.007691704795433907, 0.059920513594988734, 0.05063255397544708, 0.09610639492166229, 0.02476038982422324, 0.1109919254668057, 0.024298074495163746, 0.047308444845839404, 0.025675528413557913, 0.04215883796859998, 0.03440152453549672, 0.06506903693662025, 0.04882366549281869, 0.08738987045944668, 0.019164141776855104, 0.023939984530443326, 0.03798922596615739, 0.07303979946300387, 0.0231622304636403, 0.036391793910297565, 0.03273233051004354, 0.05239099496975541, 0.031885818316368386, 0.11383070712327026, 0.053830690958420746, 0.03794403288338799, 0.10554053907981142, 0.031910272082313895, 0.05768599599832669, 0.0640855502570048, 0.09414400061359629, 0.06834688058006577, 0.043459811713546515, 2.249459344893694, 28.449894189834595, 74.59394171833992, 82.06741869449615, 80.70377066731453, 69.11419495940208, 69.06414404511452, 65.14340043067932, 34.90927778184414, 31.531158350408077, 30.28149090707302, 32.792833149433136, 36.45275115966797, 58.77497635781765, 64.7398316860199, 52.322136014699936, 49.929427206516266, 51.100866347551346, 45.511309280991554, 35.19172042608261, 28.23267124593258, 29.133386313915253, 25.830010771751404, 23.469581231474876, 18.20936769247055, 8.749734442681074, 5.773839578032494, 7.111781984567642, 5.116073498502374, 9.494512528181076, 21.072025783360004, 14.224683959037066, 10.781921446323395, 4.3204584158957005, 2.4366940604522824, 2.169464137405157, 1.7550392565317452, 1.5978754148818552, 1.9041038327850401, 2.8573894361034036, 4.713939176872373, 4.706186642870307, 6.347929872572422, 7.729580383747816, 7.679283432662487, 6.848987611010671, 6.601596185937524, 7.425562972202897, 3.355235871858895, 3.7379192747175694, 14.154527373611927, 38.67934428155422, 41.617772206664085, 27.053873799741268, 20.12097291648388, 21.278293915092945, 28.35112038999796, 29.146508909761906, 41.775881722569466, 38.650104850530624, 54.501227885484695, 49.29587580263615, 61.60921387374401, 45.51979422569275, 131.41839534044266, 81.02067366242409, 24.299762584269047, 19.61888875812292, 15.040153451263905, 31.368869058787823, 40.56450292468071, 52.56904676556587, 58.79616022109985, 61.331011801958084, 69.24050778150558, 80.65457090735435, 39.74430173635483, 12.113492544740438, 0.6657872116193175, 0.6932814081665128, 0.027524834258656483, 0.042295092571293935, 0.020904257289657835, 0.052763100393349305, 0.03065576976950979, 0.0746205665927846, 0.08377040881896392, 0.06621894281124696, 0.0344729265634669, 0.03645783392130397, 0.03043426466319943, 0.05224285487201996, 0.048988233029376715, 0.0545656360918656, 0.04774351778905839, 0.027032697580580134, 0.03861628138110973, 0.04385904634546023, 0.01685468767391285, 0.03801194310653955, 0.05861129087861627, 0.02487744321115315, 0.03456637779891025, 0.017044961350620724, 0.05149594260728918, 0.054589384817518294, 0.03906889498466626, 0.05493728138389997, 0.055189648701343685, 0.040526781012886204, 0.07388840822386555, 0.02349710419366602, 0.033507993575767614, 0.051131032305420376, 0.019638760059024207, 0.045700051268795505, 0.032579262551735155, 0.08634371683001518, 0.021600940999633167, 0.012918210231873672, 0.009746892610564828, 0.010086826860060683, 0.04492489657422993, 0.041421421483391896, 0.01572164153913036, 0.0637047245982103, 0.026352855056757107, 0.004336667125244276, 0.0317453223397024, 0.05714042839827016, 0.01570631990034599, 0.05023586862080265, 0.02224452589871362, 0.00870217225383385, 0.014065931409277255, 0.0188113377589616, 0.044498172792373225, 0.04701735968410503, 0.06078439204429742, 0.03659859336039517, 0.041160207765642554, 0.043359799892641604, 0.036379537341417745, 0.003763288468690007, 0.04110683250473812, 0.03127101947029587, 0.04823139825020917, 0.024257252662209794, 0.05934297798376065, 0.016593073196418118, 0.05218348676862661, 0.06299461543676443, 0.04176267953880597, 0.056493776573915966, 0.015295976245397469, 0.03246461186790839, 0.08013506521820091, 0.06635556477704085, 0.01867047256382648, 0.04855768347624689, 0.03235548276279587, 0.01847664956585504, 0.07032880079350434, 0.024718901913729496, 0.08189108310034499, 0.030258418337325566, 0.10496834322111681, 0.009537262794765411, 0.15896690427325666, 0.14554180903360248, 0.01821136145736091, 0.02208255773439305, 0.03684265975607559, 0.09887451669783331, 0.12124097745981999, 0.03160380219924264, 5.694605754688382, 49.09128338098526, 89.19123843312263, 91.93263933062553, 99.7395408153534, 91.37292176485062, 97.01524659991264, 81.85158267617226, 54.91245701909065, 39.05411817133427, 28.354513607919216, 18.708260022103786, 23.602650091052055, 40.798019394278526, 51.89284265041351, 54.30950157344341, 53.24975363910198, 56.203452944755554, 44.81119304895401, 34.57372918725014, 26.934459507465363, 24.805908724665642, 19.611211270093918, 17.43622127920389, 13.686227202415466, 6.070208000019193, 4.047376569360495, 4.006034312769771, 2.991122785024345, 5.450427057221532, 12.704577427357435, 7.761398451402783, 7.721903845667839, 3.9838330540806055, 1.9497993495315313, 1.7447515460662544, 1.3679841882549226, 1.09508401947096, 2.3542952444404364, 2.547951377928257, 2.8460983419790864, 3.1222413992509246, 4.272260377183557, 4.373139264062047, 4.777080863714218, 3.501919638365507, 2.4072755640372634, 4.189306553453207, 1.1906427168287337, 0.9226797299925238, 6.488462956622243, 27.037722766399384, 32.18598671257496, 20.87976559996605, 17.010638415813446, 18.057356849312782, 24.672180600464344, 29.83558863401413, 42.051625326275826, 40.349141880869865, 59.88634832203388, 52.41622656583786, 54.55527238547802, 35.34751586616039, 106.98117703199387, 65.50778567790985, 17.77051404118538, 15.589768309146166, 23.08856427669525, 45.34376487135887, 63.54077182710171, 80.2869862318039, 80.84696218371391, 74.31466430425644, 81.44895628094673, 96.14976704120636, 60.57577572762966, 25.294807590544224, 2.3989825090393424, 0.4272371402475983, 0.14647017640527338, 0.04612935401382856, 0.03421388733841013, 0.06835270643932745, 0.023689021727477666, 0.06125044594227802, 0.053435512163559906, 0.05065005381766241, 0.014806469553150237, 0.05271772177366074, 0.029411566611088347, 0.029151052367524244, 0.02381823149335105, 0.06116215263318736, 0.053700303033110686, 0.04465961959795095, 0.09765108625288121, 0.021880567401240114, 0.03316775226267055, 0.029918846812506672, 0.08433648195932619, 0.008602591806265991, 0.07010016735875979, 0.050305407858104445, 0.061209275299916044, 0.04923347572912462, 0.06858322492917068, 0.04502278214204125, 0.0688702505431138, 0.08670219642226584, 0.00937483449888532, 0.029126702502253465, 0.0627750510466285, 0.03614591667428613, 0.026640583855623845, 0.02346141802263446, 0.02615171262732474, 0.03528200111759361, 0.018973035039380193, 0.04081517588929273, 0.023725283062958624, 0.038829941986477934, 0.018190078517363872, 0.05919765062571969, 0.023610827192896977, 0.015850487652642187, 0.02806804553983966, 0.015147209032875253, 0.12634552113013342, 0.15999488270608708, 0.15999166178517044, 0.1067300014256034, 0.14602966723032296, 0.18415147787891328, 0.10615641775075346, 0.1765647841966711, 0.13688772887689993, 0.1703098151483573, 0.12878080451628193, 0.14310826227301732, 0.0922299423837103, 0.1143099638284184, 0.1901689448277466, 0.1763046020641923, 0.1701637011137791, 0.14726192923262715, 0.15365950937848538, 0.10466869367519394, 0.23308600910240784, 0.1432870456483215, 0.1723194174701348, 0.09525383793516085, 0.169842321483884, 0.2250007406109944, 0.20162749715382233, 0.17522875510621816, 0.18548922875197604, 0.11635027622105554, 0.1485914719523862, 0.1759007401415147, 0.12033547565806657, 0.224720906408038, 0.16486773529322818, 0.1393877572263591, 0.22148686432046816, 0.16741802188334987, 0.40032232354860753, 0.14023263298440725, 0.2568466536467895, 0.2625466149765998, 0.11064389531384222, 0.11423912583268248, 0.1282549335155636, 0.24347616563318297, 0.20934034109814093, 0.19263449299614877, 3.6174263153225183, 47.25999444723129, 101.5056100487709, 102.52198711037636, 99.70085129141808, 88.7906639277935, 89.46008920669556, 80.02236843109131, 45.10740615427494, 44.47096690535545, 43.43464091420174, 46.186023876070976, 50.95757603645325, 82.09834903478622, 96.12131416797638, 74.5264421403408, 73.12120154500008, 68.49811881780624, 68.86720061302185, 53.135182186961174, 43.953396677970886, 46.88417561352253, 41.57440893352032, 38.0631123483181, 27.24476795643568, 14.201137572526932, 11.585763562470675, 11.72752445563674, 8.627891130745411, 13.505531698465347, 26.784618347883224, 21.66691616177559, 19.628789126873016, 10.568265561014414, 7.6525751408189535, 5.464432630687952, 4.958212869241834, 4.06552012078464, 5.151426326483488, 8.298776540905237, 9.084050003439188, 9.62102198973298, 12.763346023857594, 14.907745756208897, 14.309066031128168, 13.327403906732798, 12.321451585739851, 14.290200043469667, 7.241151742637157, 8.140859864652157, 19.355310201644897, 49.34273108839989, 56.409249901771545, 40.86971394717693, 35.56770645081997, 38.34330931305885, 45.454551726579666, 45.99178969860077, 62.31218375265598, 63.31820257008076, 84.05635356903076, 75.0701929628849, 87.51228332519531, 69.35239657759666, 144.32680428028107, 99.86417412757874, 40.55143162608147, 31.611539237201214, 24.82886329293251, 43.02262522280216, 57.259461879730225, 73.55082169175148, 79.25495401024818, 81.35832354426384, 91.3282361626625, 105.59594616293907, 64.82196807861328, 22.040086537599564, 1.4828629489056766, 0.8042779646348208, 0.22382007271517068, 0.10198730669799261, 0.14406805217731744, 0.22912850661668926, 0.13006374036194757, 0.21261512709315866, 0.1374822633806616, 0.22536347270943224, 0.1358144942787476, 0.2291385701391846, 0.1369210661505349, 0.14186816319124773, 0.17676955758361146, 0.23506700905272737, 0.12400337727740407, 0.11221088076126762, 0.1860513462452218, 0.15443112031789497, 0.20899588067550212, 0.09905663231620565, 0.17438141541788355, 0.10282998569891788, 0.20794173411559314, 0.15513144055148587, 0.15765636053401977, 0.16774440358858556, 0.16870593011844903, 0.14275357505539432, 0.1193165811127983, 0.21995947987306863, 0.1275807071942836, 0.08713455681572668, 0.15340424026362598, 0.18220531434053555, 0.1212369475979358, 0.16176408855244517, 0.1085028809029609, 0.21567123185377568, 0.14690192823763937, 0.14934852195437998, 0.15248143899952993, 0.13755012536421418, 0.12815894413506612, 0.12833575339755043, 0.09295089432271197, 0.14314725471194834, 0.09511761672911234, 0.07584445716929622], [0.07409919300698675, 0.05674026979249902, 0.028370361251290888, 0.03168598392221611, 0.03504974229144864, 0.014645446699432796, 0.06271047677728347, 0.018279349606018513, 0.014549300540238619, 0.03712740326591302, 0.03101854268606985, 0.014685459591419203, 0.03987657430116087, 0.02488109272235306, 0.0309004131850088, 0.05479354222188704, 0.020266817373340018, 0.029458119679475203, 0.01534908155008452, 0.003821651193902653, 0.033349515360896476, 0.06227233505342156, 0.012533866793091875, 0.05088358542707283, 0.061306121860980056, 0.03487972368020564, 0.03995850740466267, 0.021509519538085442, 0.0716023484710604, 0.02427629802696174, 0.09405490578501485, 0.027582961120060645, 0.03677282737044152, 0.024933095010055695, 0.023446745763067156, 0.05694126564776525, 0.029297999462869484, 0.027226409256400075, 0.0385411055322038, 0.10486322542419657, 0.005950964023213601, 0.07534878415754065, 0.0026154172383030527, 0.10189706896198913, 0.024417029635515064, 0.15615070617059246, 2.545699761249125, 16.67433176189661, 50.0199231505394, 91.89606249332428, 87.59255781769753, 81.99212193489075, 63.80785569548607, 60.90875945985317, 33.268472626805305, 42.88115881383419, 37.07431420683861, 45.71975089609623, 52.031531408429146, 76.01872846484184, 73.9155413210392, 58.54440473020077, 47.35980749130249, 41.46275572478771, 33.089988604187965, 17.403288446366787, 17.558907195925713, 13.401299491524696, 9.062021635472775, 2.5934069138020277, 0.5971497728023678, 0.5347088514827192, 0.04837980181036983, 0.06367716123349965, 0.16156643978320062, 0.22233328374568373, 0.13195157109294087, 0.25721363082993776, 0.8069910190533847, 0.33974502410274, 0.16606663033599034, 0.07381862407783046, 0.08672057942021638, 0.027376261859899387, 0.11280455437372439, 0.07034783688141033, 0.12619585962966084, 0.02772104140603915, 0.18374832841800526, 0.17101880366681144, 0.08924274603486992, 0.048654036509105936, 0.09230485477019101, 0.09335942435427569, 0.0828896724851802, 0.06621907639782876, 0.07737442429061048, 0.16351805068552494, 0.7152289117220789, 0.5823842994868755, 0.5226668226532638, 0.3236876497976482, 0.6199551397003233, 1.0220357892103493, 2.3719897074624896, 6.999917887151241, 10.378804877400398, 12.266615778207779, 15.435779672116041, 27.92951211333275, 36.722445487976074, 55.04890389740467, 37.573216035962105, 33.52619379758835, 55.89459791779518, 62.644122540950775, 41.518247947096825, 38.3550088852644, 24.693620949983597, 27.854844219982624, 41.53883144259453, 62.613594979047775, 55.696214362978935, 67.52439826726913, 72.79653936624527, 79.04840469360352, 50.68961441516876, 9.133718088269234, 0.47235814563464373, 0.3918589308159426, 0.00881038202351192, 0.01962091697350843, 0.02834019480360439, 0.04891522796242498, 0.03583231846278068, 0.07437325330101885, 0.1034192657971289, 0.027935967373196036, 0.06279356763116084, 0.007584983495689812, 0.05187157694308553, 0.10777306772070006, 0.07062338889227249, 0.007711577191003016, 0.022328744817059487, 0.0746008032001555, 0.020042935539095197, 0.015797091982676648, 0.08789251965936273, 0.03158819112286437, 0.03296275623142719, 0.04074482400028501, 0.07461267756298184, 0.05333597902790643, 0.08326957045937888, 0.07166321200202219, 0.05395825872255955, 0.024619179530418478, 0.021273509155435022, 0.05241024628048763, 0.10449324254295789, 0.05406186624895781, 0.01007894617941929, 0.04083057174284477, 0.02950051857624203, 0.02597700549813453, 0.029676066187676042, 0.039840691460995004, 0.07420514200930484, 0.025400792765140068, 0.03638365255028475, 0.0384513167955447, 0.041267140113632195, 0.0033456399933129433, 0.06599168977118097, 0.057443900004727766, 0.08400718361372128, 0.012125641969760181, 0.02878190625779098, 0.06507862548460253, 0.03828498665825464, 0.04143526624829974, 0.05329765823262278, 0.07446596981026232, 0.02392467958998168, 0.06720775811118074, 0.046557473033317365, 0.017346293716400396, 0.04543707495031413, 0.04028631403343752, 0.026506969443289563, 0.06103677049395628, 0.02860334552678978, 0.05438434425741434, 0.0801328090892639, 0.026638908457243815, 0.034583569649839774, 0.112869841104839, 0.05383699179219548, 0.007415824848067132, 0.11642693265457638, 0.017384746242896654, 0.010549033650022466, 0.01866462258476531, 0.04821547176106833, 0.007552827628387604, 0.07982836526934989, 0.09517338170553558, 0.028756218671333045, 0.029875199252273887, 0.0459084463363979, 0.05316896611475386, 0.011627387211774476, 0.03028896142495796, 0.039809985100873746, 0.12205674618599005, 0.043529228496481664, 0.07120458700228482, 0.01819669847463956, 0.11431588616687804, 0.07019082811893895, 0.23750287131406367, 8.228236176073551, 34.97547782957554, 71.19067713618279, 107.88415297865868, 104.14456084370613, 102.3321644961834, 88.97960498929024, 85.50417467951775, 51.830298006534576, 59.167776480317116, 35.13027772307396, 22.604781836271286, 24.180357791483402, 43.52257199585438, 47.73205451667309, 55.92031493782997, 51.97140723466873, 43.914224579930305, 27.628860846161842, 13.178496547043324, 11.04454530403018, 7.295988500118256, 4.1359208431094885, 0.9648127597756684, 0.3605546965263784, 0.26271748705767095, 0.4027525306446478, 0.09970172934117727, 0.19451117666903883, 0.19780194852501154, 0.34219096472952515, 0.2133708115434274, 0.6886670307721943, 0.2706094260793179, 0.34098636999260634, 0.38212910760194063, 0.04994031201931648, 0.16367823584005237, 0.22174281621119007, 0.20171336364001036, 0.34755019121803343, 0.2703520789509639, 0.17859433544799685, 0.11119570437585935, 0.13859922531992197, 0.021902254811720923, 0.08815221197437495, 0.0498118091491051, 0.08849815669236705, 0.046489985834341496, 0.0999213382601738, 0.10927166425972246, 0.4269484744872898, 0.7479902787599713, 1.2230775388889015, 0.6458842952270061, 0.5959847790654749, 0.3523014800157398, 0.4585975402733311, 2.202672455459833, 4.383687498047948, 7.345753954723477, 13.20976221933961, 24.175834134221077, 36.47948272526264, 56.37691743671894, 42.72874519228935, 37.67359144985676, 48.06155003607273, 47.24553622305393, 25.048776492476463, 24.07074697315693, 28.849319256842136, 45.0010384619236, 62.116809636354446, 85.7602809369564, 83.09937492012978, 88.45831096172333, 88.21716830134392, 93.36991980671883, 75.4638822376728, 22.560531310737133, 1.7847853666171432, 0.2295774465892464, 0.07076568828779273, 0.03811129441601224, 0.09513202923699282, 0.0727003114297986, 0.02976910924189724, 0.04986482446838636, 0.08165603008819744, 0.039584312835359015, 0.06965671185753308, 0.0660353948478587, 0.018803068378474563, 0.12510404165368527, 0.06814460823079571, 0.04493607331824023, 0.03971067089878488, 0.11242815191508271, 0.05323851277353242, 0.024795257777441293, 0.0664429749303963, 0.03102954688074533, 0.014691731666971464, 0.049829164272523485, 0.029555151777458377, 0.1192388559866231, 0.054137517072376795, 0.12867173849372193, 0.041424197115702555, 0.01222413609866635, 0.11492466248455457, 0.012397053724271245, 0.04131912013690453, 0.015493248374696122, 0.0432069805538049, 0.038953550392761827, 0.02916433681093622, 0.04556430874799844, 0.023763947101542726, 0.05732085934141651, 0.02420241537038237, 0.02044936343736481, 0.0343767182494048, 0.042817067296709865, 0.06476033318904229, 0.07799806582625024, 0.005711082412744872, 0.06345298810629174, 0.1991854453808628, 0.12965112109668553, 0.06586570278159343, 0.17311805742792785, 0.17132482083979994, 0.0946012452186551, 0.12685849360423163, 0.1977466733660549, 0.09789114134036936, 0.148434997536242, 0.11365433572791517, 0.11017113240086474, 0.10218433206318878, 0.10916979706962593, 0.07288169974344783, 0.2483278076397255, 0.17920351994689554, 0.11204983471543528, 0.13079637370537966, 0.11627534899162129, 0.10592474893201143, 0.13305602042237297, 0.13759806810412556, 0.09915085538523272, 0.16485014639329165, 0.15119685558602214, 0.12739183061057702, 0.10460490608238615, 0.22069238038966432, 0.07562506347312592, 0.30120330629870296, 0.18129014235455543, 0.2007475623395294, 0.08901832799892873, 0.12923833855893463, 0.23753451649099588, 0.10115746685187332, 0.13003346073674038, 0.114730160421459, 0.23606111586559564, 0.1287188203423284, 0.17875878053018823, 0.10261183881084435, 0.27254346292465925, 0.1285898796049878, 0.3462788328761235, 5.473696058616042, 33.60824279487133, 77.37190425395966, 118.77977952361107, 108.37524622678757, 102.93152153491974, 81.67492255568504, 74.80011105537415, 43.23752649128437, 55.963571816682816, 53.06123435497284, 63.566374853253365, 70.87021753191948, 100.2894777059555, 104.28832232952118, 82.23532408475876, 66.86846226453781, 61.82857230305672, 49.282371327281, 28.525597527623177, 26.664941869676113, 19.690214730799198, 14.568429663777351, 4.931518351659179, 1.5200869389809668, 1.5334111615084112, 0.8432410738896579, 0.3277733805589378, 0.3247943997848779, 0.42685588414315134, 0.528135085478425, 0.43088096659630537, 1.1400364385917783, 0.7789169973693788, 0.5365196918137372, 0.4275821795454249, 0.3444975597085431, 0.2846951218089089, 0.3813329909462482, 0.35712235257960856, 0.39015294110868126, 0.20608465798432007, 0.3640348941553384, 0.4265678714727983, 0.44801205047406256, 0.18646577635081485, 0.25567480246536434, 0.26297703094314784, 0.26692255516536534, 0.24560906836995855, 0.2701896376674995, 0.38672876078635454, 0.8819546434096992, 0.8728341234382242, 1.248691608197987, 1.2975230254232883, 1.7423802358098328, 2.8962843865156174, 5.5692072585225105, 9.80172699317336, 15.197502057999372, 19.015192352235317, 24.160163775086403, 43.19229371845722, 62.92388632893562, 85.34453764557838, 57.99085043370724, 51.984588727355, 78.22669878602028, 86.96335718035698, 58.86649064719677, 55.98021112382412, 36.28639228641987, 40.26906877756119, 59.1030203551054, 81.84221997857094, 76.33066892623901, 88.2356733083725, 95.856703966856, 105.10526329278946, 77.05523684620857, 19.00270812213421, 0.9736253181472421, 0.431568106287159, 0.23679514444665983, 0.12312733873841353, 0.2672638540389016, 0.22495027456898242, 0.14919445209670812, 0.11267628899076954, 0.2880502230254933, 0.108754632237833, 0.1420478816726245, 0.1570217203698121, 0.14662731875432655, 0.25277618144173175, 0.19019762141397223, 0.1399113127263263, 0.11377299029845744, 0.32617473509162664, 0.0777232411201112, 0.12371141638141125, 0.15570872754324228, 0.116594865830848, 0.11450334524852224, 0.11258992526563816, 0.12582615134306252, 0.17630494345212355, 0.12698623206233606, 0.17457277077483013, 0.15898863435722888, 0.0841590270283632, 0.16101543966215104, 0.15908134344499558, 0.1472953852498904, 0.10652328361175023, 0.10515761314309202, 0.11436572880484164, 0.09458580112550408, 0.13640340330312029, 0.13540291402023286, 0.30548941693268716, 0.17691967921564355, 0.1743783280835487, 0.16200331243453547, 0.15568140166578814, 0.22281277051661164, 0.2408298896625638, 0.1505305850878358, 0.2183368630358018], [0.06284387040068395, 0.02746411359112244, 0.02481135310517857, 0.008105330598482396, 0.04079553866176866, 0.01370674028294161, 0.02807223681884352, 0.050010389313683845, 0.04057316153193824, 0.10231889085844159, 0.008193061730707996, 0.002451275972816802, 0.04513969266554341, 0.02595669291622471, 0.07089992795954458, 0.031019257003208622, 0.04214539396343753, 0.036069980124011636, 0.04341962812759448, 0.04525175325397868, 0.05305832302838098, 0.04177364105999004, 0.023509757811552845, 0.0689161301124841, 0.036717555922223255, 0.04310075324610807, 0.010755515831988305, 0.07639717907295562, 0.06566562718944624, 0.035817950483760796, 0.0705697167722974, 0.018642475042724982, 0.054543954247492366, 0.027069409770774655, 0.03179150618962012, 0.015371965673693921, 0.012217346375109628, 0.023323382265516557, 0.0909915725060273, 0.05964986718026921, 0.06115278672950808, 0.13498642074409872, 0.04484288925596047, 0.21672879229299724, 1.3364417245611548, 19.70517072826624, 61.64604909718037, 86.22146219015121, 80.1878647506237, 65.09670093655586, 56.67395509779453, 56.960212737321854, 40.54523415863514, 32.081948295235634, 30.785739049315453, 27.87645746022463, 56.62525691092014, 80.07345288991928, 62.083812206983566, 61.5589539706707, 49.75644148886204, 34.356510043144226, 22.10955820977688, 6.943642431870103, 1.233059959486127, 0.6288976629730314, 0.17660267825704068, 0.2770126168616116, 0.29809118423145264, 0.15146505291340873, 0.07206017195130698, 0.005518397219930193, 0.04496650508372113, 0.053844275971641764, 0.22833207825897262, 0.40055452671367675, 0.34011523704975843, 0.28033351991325617, 0.8292941597755998, 0.3266978601459414, 0.29633740021381527, 0.19242547452449799, 0.16110887605464086, 0.06036265549482778, 0.04988856577256229, 0.07474296900909394, 0.5779037461616099, 0.34400115197058767, 0.3999202873092145, 0.25871175981592387, 0.10000704147387296, 0.10754775910754688, 0.3303155332105234, 0.1702353628934361, 0.04870234661211725, 0.11535664438270032, 0.2339233594830148, 0.19853679346852005, 0.5202290159650147, 0.39890749321784824, 0.3227064711973071, 0.08630379670648836, 0.0515237583022099, 0.1830689812777564, 0.09024879400385544, 0.6536760146263987, 0.2777144213905558, 0.28388567618094385, 0.10887089709285647, 0.14330104255350307, 2.321700593456626, 8.504714090377092, 34.22661781311035, 47.452860698103905, 48.44275318086147, 47.83958114683628, 60.563232600688934, 64.28792953491211, 47.382347881793976, 31.740753203630447, 20.02313006669283, 31.478141695261, 35.04318259656429, 45.94218336045742, 51.493978053331375, 68.16864609718323, 74.63214486837387, 79.35164362192154, 43.6835465580225, 7.912898221984506, 0.1314247798291035, 0.19287575036287308, 0.10718190998886712, 0.0339467846788466, 0.10346429931814782, 0.028229575837031007, 0.08023463175049983, 0.04579509812174365, 0.02983470396429766, 0.03030930554814404, 0.009015507002914092, 0.07273389361216687, 0.020584645826602355, 0.03160359068715479, 0.00880539571880945, 0.016204156272578984, 0.009452494687138824, 0.048625886847730726, 0.022572885427507572, 0.06565265444805846, 0.018385421062703244, 0.023106524859031197, 0.020474824668781366, 0.029848209196643438, 0.03398719090910163, 0.014135287892713677, 0.030020111007615924, 0.08332572877407074, 0.04653404343116563, 0.026061346870847046, 0.05361682255170308, 0.05615387293801177, 0.0871362118050456, 0.06387216053553857, 0.025427881155337673, 0.07465095754014328, 0.038881320870132186, 0.030413799941015895, 0.02219282789155841, 0.031313373838202097, 0.023094381467672065, 0.09648802209994756, 0.03310783125925809, 0.0036363232356961817, 0.04116282012546435, 0.033546106569701806, 0.019336130790179595, 0.04902693231997546, 0.01875218116765609, 0.03565905295545235, 0.029175114650570322, 0.05228486414125655, 0.02637236611917615, 0.0531122994289035, 0.03528025707055349, 0.03359799382451456, 0.04488063117605634, 0.014583122992917197, 0.03810325695667416, 0.008324171394633595, 0.049852219090098515, 0.037888553633820266, 0.05772033146058675, 0.03901313742971979, 0.032750386963016354, 0.03016937174834311, 0.052667151830974035, 0.016839763084135484, 0.04698302051110659, 0.03725284477695823, 0.0704789743758738, 0.029786393861286342, 0.007594312291985261, 0.020309822975832503, 0.050495813266024925, 0.07287919128430076, 0.019673802416946273, 0.022518152036354877, 0.04720994329545647, 0.06802638410590589, 0.052106377625023015, 0.02796823224343825, 0.01706381004623836, 0.06563439019373618, 0.06685541608021595, 0.06707261301926337, 0.06883914713398553, 0.06017733750923071, 0.09066432248800993, 0.09303001468651928, 5.219064597040415, 38.37402306497097, 79.34446960687637, 109.5612233877182, 99.81854617595673, 87.61879920959473, 82.13545024394989, 85.90520516037941, 61.21271274983883, 42.95841246843338, 29.184738658368587, 15.662650298327208, 22.752542607486248, 56.48547761142254, 60.613226518034935, 61.27835802733898, 56.68845131993294, 35.2729182690382, 17.949047461152077, 3.8016986148431897, 0.15134972316445783, 0.31973823672160506, 0.28422409552149475, 0.26681764516979456, 0.33391254488378763, 0.06438615717343055, 0.02582583372713998, 0.02535193347284803, 0.08129917579935864, 0.11308535336866044, 0.1635438625817187, 0.47591505164746195, 0.2688022964866832, 0.26173066813498735, 0.7209496235009283, 0.3055690642213449, 0.5579213902819902, 0.3543285228079185, 0.10166706255404279, 0.3008228517137468, 0.24609714921098202, 0.07073068860336207, 0.25128526613116264, 0.4276190197560936, 0.6215015379711986, 0.4889161727624014, 0.4528219095664099, 0.28332155488897115, 0.5177762475796044, 0.24112426995998248, 0.23125573934521526, 0.1267528414609842, 0.21974716626573354, 0.32106454367749393, 0.46831459854729474, 0.6509944866411388, 0.4954964102944359, 0.15541670727543533, 0.08866954085533507, 0.09495782491285354, 0.019971912006440107, 0.40051946765743196, 0.30601640115492046, 0.4017837013816461, 0.24040450545726344, 0.5766274896450341, 0.9678328258451074, 6.237589018419385, 33.23536120355129, 51.57853111624718, 53.66045840084553, 50.26647672057152, 54.108389765024185, 47.60256506502628, 27.090716622769833, 22.149119786918163, 22.03719299286604, 50.94982825219631, 56.257657036185265, 71.37363731861115, 76.31052240729332, 85.90012103319168, 82.66002729535103, 95.50656795501709, 65.26921927928925, 17.529821656644344, 0.24874790775356814, 0.3082711645402014, 0.12841655843658373, 0.011428198486100882, 0.04979171179002151, 0.030117957612674218, 0.02908426093199523, 0.06394222669769078, 0.022369535108737182, 0.05842108956130687, 0.02148522162315203, 0.0357918788358802, 0.1273388264235109, 0.02372253526118584, 0.05269332366879098, 0.013945397349743871, 0.03555911906005349, 0.02152860201022122, 0.11495270082377829, 0.04774764041940216, 0.04640359984477982, 0.035026880432269536, 0.017489912279415876, 0.046614577586296946, 0.08115096890833229, 0.02439017316646641, 0.015802813941263594, 0.060677971778204665, 0.0259933679990354, 0.06427663101931103, 0.04485084136831574, 0.03814499534200877, 0.05071307699836325, 0.051896049262722954, 0.060138842309243046, 0.02981621706567239, 0.013618651064462028, 0.06198613322339952, 0.04126420863030944, 0.025267788769269828, 0.04745539008581545, 0.04322892957134172, 0.04133776659728028, 0.05696550048014615, 0.017422573509975336, 0.10549764294410124, 0.1873021767823957, 0.2575606887694448, 0.13433358311885968, 0.18607653473736718, 0.101925515482435, 0.1194135649711825, 0.13634181988891214, 0.2064194408012554, 0.17265506117837504, 0.22227394161745906, 0.18429815594572574, 0.19452952255960554, 0.12340245288214646, 0.10835164604941383, 0.15961450233589858, 0.10516335736610927, 0.14949481410440058, 0.1530478461063467, 0.1199536926287692, 0.1252019903040491, 0.22819564183009788, 0.10228636994725093, 0.20904561941279098, 0.08661169151309878, 0.13392415508860722, 0.11828731876448728, 0.11606495754676871, 0.21173670626012608, 0.1464618495083414, 0.09985318683902733, 0.1918358530383557, 0.12434768184903078, 0.16441468382254243, 0.08329334887093864, 0.22314903762890026, 0.15707163722254336, 0.11303424165816978, 0.13243888010038063, 0.26499778032302856, 0.16942618443863466, 0.1770371908787638, 0.18480336555512622, 0.16230570792686194, 0.384639585390687, 3.435868970118463, 35.78519158065319, 88.82800072431564, 117.59425833821297, 103.22282150387764, 87.19038739800453, 78.16343978047371, 74.4014060497284, 55.018877908587456, 42.83201985061169, 45.31219616532326, 38.13366316258907, 78.14707025885582, 102.86251723766327, 89.63861122727394, 87.68092587590218, 72.6110029220581, 55.32747834920883, 37.02986419200897, 12.678990550339222, 2.6537771243602037, 1.5659534465521574, 0.9309259406290948, 0.5847236083354801, 0.6716404412873089, 0.28463382041081786, 0.13589397829491645, 0.1505175232887268, 0.21041641070041806, 0.19659690849948674, 0.5394951102789491, 1.0797178815118968, 0.7897982478607446, 0.6596335012000054, 1.395610012114048, 0.8780269604176283, 0.852532465942204, 1.0315073747187853, 0.6352365540806204, 0.9060274204239249, 0.5753245751839131, 0.5351788981352001, 2.2341502038761973, 1.9389806175604463, 1.5786957065574825, 0.9021380916237831, 0.831433207495138, 0.7939537998754531, 0.985060507664457, 0.639618847053498, 0.4665366205153987, 0.5551433830987662, 0.592052168212831, 0.6197601032909006, 0.9282681613694876, 0.8221570146270096, 0.7815425971057266, 0.2574226789874956, 0.19144135701935738, 0.3704212827142328, 0.25015031453222036, 0.7109689840581268, 0.5264273146167397, 0.7539470528718084, 0.5624912981875241, 0.9599730663467199, 3.506836099550128, 15.115014184266329, 55.6855483353138, 76.05561688542366, 73.55230361223221, 70.13632491230965, 86.49006977677345, 89.87365901470184, 69.37647968530655, 45.17042197287083, 32.21617229282856, 43.86819005012512, 48.082236126065254, 63.711983039975166, 71.07018560171127, 86.87614426016808, 92.2425127029419, 106.48349493741989, 67.08831086754799, 14.94346858933568, 0.28303567960392684, 0.4094903409713879, 0.23758272640407085, 0.08558572430047207, 0.17796414816984907, 0.1267962867859751, 0.13709432794712484, 0.1365419919602573, 0.08633812103653327, 0.18806739040883258, 0.182471196167171, 0.13323844032129273, 0.28701623319648206, 0.10849797530681826, 0.2846078749280423, 0.08082340718829073, 0.09864143037702888, 0.24297788768308237, 0.20514493575319648, 0.1778151249163784, 0.1877330825664103, 0.06754276357241906, 0.11544708249857649, 0.11665508369333111, 0.1979939272860065, 0.1509829389397055, 0.12531639978988096, 0.20322955650044605, 0.10343127374653704, 0.11445923941209912, 0.1369237675680779, 0.16068892437033355, 0.16308232094161212, 0.11536163903656416, 0.1589273032732308, 0.14870957733364776, 0.12503623904194683, 0.22708627948304638, 0.11267299385508522, 0.12355675280559808, 0.1529906562063843, 0.1254057840560563, 0.13113785069435835, 0.07692373284953646, 0.1464595488505438, 0.09448811222682707], [0.1144366707012523, 0.1182331345626153, 0.0158599129281356, 0.03077008092077449, 0.1301816082559526, 0.02214357711636694, 0.024232821160694584, 0.03316289861686528, 0.06512716936413199, 0.00886849589733174, 0.010164466639253078, 0.05052887223428115, 0.015365441267931601, 0.011827848720713519, 0.009990570306399604, 0.03773809803533368, 0.0531500784563832, 0.03588182713428978, 0.05681752365489956, 0.016160916893568356, 0.02775152141111903, 0.014202060774550773, 0.035167732639820315, 0.04343118336691987, 0.02857063722331077, 0.009829178234213032, 0.04464683610422071, 0.07750654884148389, 0.027225281191931572, 0.040989506378537044, 0.09907376108458266, 0.09309018059866503, 0.013348395204957342, 0.01782134986569872, 0.031355086248368025, 0.011824933935713489, 0.07603502584970556, 0.06534997693961486, 0.03426790455705486, 0.06337058744975366, 0.016399324413214345, 0.2320438259630464, 0.22280497796600685, 18.34952127188444, 58.88766311109066, 82.47452884912491, 84.60120633244514, 64.03137490153313, 54.29286226630211, 55.84023803472519, 43.4782587736845, 27.73365542292595, 37.95211650431156, 44.66425493359566, 60.93949981033802, 75.28794407844543, 85.22659197449684, 52.182729095220566, 34.00303401052952, 34.778975173830986, 14.316178299486637, 5.104286530986428, 0.3720967849949375, 0.1612460397882387, 0.009183032925648149, 0.03440789587330073, 0.10359562977100722, 0.11230957898078486, 0.152216239948757, 0.10310877347365022, 0.09992882653023116, 0.19724391284398735, 0.04217643057927489, 0.11487347655929625, 0.061426880420185626, 0.07408389734337106, 0.09754313345183618, 0.13293450116179883, 0.3085715265478939, 0.14084230730077252, 0.1267567600007169, 0.07571091511636041, 0.07815569057129323, 0.05324069468770176, 0.09137411252595484, 0.0890021343366243, 0.14031584258191288, 0.46232656517531723, 0.02011802604101831, 0.3931202256353572, 0.3513940708944574, 0.13038611446972936, 0.04981020982086193, 0.13906747597502545, 0.31662967696320266, 0.03227419532777276, 0.029690667943214066, 0.10297752465703525, 0.08482529752654955, 0.06522518480778672, 0.016762271734478418, 0.15800285444129258, 0.17833847261499614, 0.19029358110856265, 0.22513830510433763, 0.3624077799031511, 0.1446384223527275, 0.22832970338640735, 0.09615069371648133, 0.22414541541365907, 0.03860644792439416, 0.09016426338348538, 0.09458643195102923, 6.840973366051912, 30.345908850431442, 37.05560781061649, 42.3263505846262, 42.29171924293041, 59.795821979641914, 67.97940865159035, 47.70844258368015, 23.052819594740868, 31.93649210035801, 35.80504931509495, 49.381994381546974, 47.165694907307625, 64.33419585227966, 69.6596708893776, 80.0179074704647, 70.89675530791283, 32.80574105679989, 3.156834030523896, 0.4366058937739581, 0.11791615586844273, 0.05189708084799349, 0.10786982151330449, 0.08988527522888035, 0.043273721894365735, 0.018698850435612258, 0.08703524261363782, 0.08355277401278727, 0.0589982615201734, 0.03898807510267943, 0.06568623663042672, 0.0748980333446525, 0.02201138577220263, 0.0346545857610181, 0.028022347796650138, 0.06636284524574876, 0.06764371049939655, 0.007736724401183892, 0.06870632496429607, 0.025276434789702762, 0.026962271476804744, 0.06530459460918792, 0.04711118570412509, 0.08724783081561327, 0.015042550439829938, 0.08025469942367636, 0.03896723559591919, 0.03557377276592888, 0.033873371430672705, 0.02955972155177733, 0.06720614765072241, 0.047568304144078866, 0.029645133472513407, 0.027601345973380376, 0.07214433149783872, 0.06017384941515047, 0.014478486664302181, 0.03133974605589174, 0.0686261359078344, 0.01156031097707455, 0.026668219579732977, 0.016726763678889256, 0.04682978556957096, 0.0276893591217231, 0.058114081621170044, 0.0027361062211639364, 0.033196989170392044, 0.05132531914568972, 0.013475340492732357, 0.030459093213721644, 0.07007904583588243, 0.025209225896105636, 0.020364278061606456, 0.043000782243325375, 0.05343557524611242, 0.03124677350569982, 0.05891937864362262, 0.033328742647427134, 0.013376603310462087, 0.022456156730186194, 0.009726906573632732, 0.06360744388075545, 0.018389115102763753, 0.044115925920777954, 0.04171023938397411, 0.059696897078538314, 0.03951551203499548, 0.04005883834906854, 0.053626236694981344, 0.021482189949892927, 0.07508638300350867, 0.06608698153286241, 0.025274364197684918, 0.022026414262654725, 0.05309101834427565, 0.05303564670612104, 0.072380727797281, 0.034927762899314985, 0.01744516077451408, 0.0567955820588395, 0.03853568785416428, 0.02109162916895002, 0.12001126102404669, 0.0732605141820386, 0.2300555381225422, 2.031544125638902, 35.70007234811783, 81.54484033584595, 99.9586370587349, 100.31036138534546, 83.14506366848946, 79.05502393841743, 79.3479198217392, 69.6693679690361, 40.786646604537964, 33.88174831867218, 30.781846158206463, 29.602682031691074, 43.43936786055565, 67.12300300598145, 53.49207043647766, 33.69848035275936, 35.80604866147041, 12.232179176062346, 1.527338137384504, 0.18347094330238178, 0.14725657092640176, 0.013611930917249992, 0.03059872644371353, 0.0269016843958525, 0.06332731281872839, 0.11951647116802633, 0.0701083532476332, 0.09636078830226324, 0.3346684074494988, 0.009367758120788494, 0.11649012652924284, 0.12567467900225893, 0.0981337419943884, 0.22062506759539247, 0.1810619467869401, 0.2603444253327325, 0.0782165837881621, 0.23712455411441624, 0.20511530921794474, 0.1216460119758267, 0.20613013679394498, 0.1507921624579467, 0.16567446466069669, 0.12891755264718086, 0.302618017885834, 0.12537504429928958, 0.3498130588559434, 0.5488308530766517, 0.18623759562615305, 0.017893648036988452, 0.08395281387493014, 0.21361263294238597, 0.13279433915158734, 0.07031950910459273, 0.07939179689856246, 0.022655492030025925, 0.052125380316283554, 0.13183732487959787, 0.1689561377861537, 0.20697244472103193, 0.22226646076887846, 0.10155906522413716, 0.1465886231744662, 0.3062451904406771, 0.24418865708867088, 0.13693402404896915, 0.2354712865781039, 0.08431231020949781, 0.1624406303744763, 0.32249795738607645, 4.842658219859004, 29.994999580085278, 42.03766107559204, 48.50688993930817, 46.17810130119324, 51.5676598995924, 42.72570915520191, 28.512332439422607, 13.574129417538643, 32.470131665468216, 54.01839539408684, 73.58258798718452, 74.63753297924995, 90.06629347801208, 84.75879907608032, 92.40607112646103, 86.1450406908989, 52.21575692296028, 8.907282538712025, 0.14350917044794187, 0.11205754562979564, 0.037243556798784994, 0.08963220287114382, 0.08424049257882871, 0.08046636736253276, 0.048307720717275515, 0.027633853896986693, 0.02282441968418425, 0.06191587781358976, 0.04013824443973135, 0.01992425684875343, 0.05756617996667046, 0.021630680712405592, 0.04063039225002285, 0.028926079576194752, 0.05313087909598835, 0.031045172800077125, 0.021739314433943946, 0.04282501569832675, 0.019889426002919208, 0.04505161829001736, 0.05165345603018068, 0.022608736726397183, 0.03905447505530901, 0.06687125351163559, 0.032948436492006294, 0.061260917645995505, 0.05980037101835478, 0.015778692286403384, 0.06599933389225043, 0.0634323712438345, 0.03342624600918498, 0.05524518361198716, 0.02297815000929404, 0.052040723530808464, 0.034669376764213666, 0.06521630130009726, 0.028567316112457775, 0.032378997711930424, 0.02771583152934909, 0.03481159081275109, 0.04021494911285117, 0.03287271516455803, 0.16963521775323898, 0.1413271523779258, 0.10040528533863835, 0.13328715489478782, 0.19473500840831548, 0.09220409338013269, 0.07866857398767024, 0.1892007389687933, 0.12672992394072935, 0.07600210417876951, 0.09910517619573511, 0.22887387574883178, 0.1040859444765374, 0.11192096819286235, 0.11471680918475613, 0.15713268629042432, 0.12028158831526525, 0.14630170888267457, 0.1377355435397476, 0.0861559683107771, 0.1608150004176423, 0.24387104756897315, 0.1211514521855861, 0.20374799118144438, 0.18588875653222203, 0.11192859004950151, 0.11360149481333792, 0.16163559310371056, 0.16859618132002652, 0.09897144860588014, 0.20254968985682353, 0.12953720142832026, 0.13005449320189655, 0.08456455136183649, 0.27060443884693086, 0.10928278905339539, 0.18644535244675353, 0.1804957474814728, 0.11207060742890462, 0.14326789823826402, 0.18192539107985795, 0.5235600715968758, 1.1832968797534704, 30.248932354152203, 90.43732836842537, 112.9475636780262, 108.80560353398323, 84.34045672416687, 75.85281416773796, 73.50115075707436, 57.122559025883675, 37.15266600251198, 49.67582881450653, 61.60325579345226, 77.95820519328117, 100.6948171555996, 110.88717743754387, 69.03705149888992, 52.464620769023895, 54.59737412631512, 26.439121887087822, 9.05355853959918, 1.0849974607117474, 0.5080830270890146, 0.08210715197492391, 0.16967360163107514, 0.14251067012082785, 0.5293528607580811, 0.6011804065201432, 0.5815280391834676, 0.3731562750181183, 0.8152016659732908, 0.43485086294822395, 0.3364776447415352, 0.3243616089457646, 0.3406895702937618, 0.49089939915575087, 0.5203564872499555, 0.4485789325553924, 0.5311238032300025, 0.7730070082470775, 0.9914150729309767, 0.32962771074380726, 0.5026419565547258, 0.5626957747153938, 0.33607691468205303, 1.3282750127837062, 1.2190565234050155, 0.25549781508743763, 1.3147770683281124, 1.590364167932421, 0.6804873165674508, 0.15349657827755436, 0.3799440764123574, 1.009301485028118, 0.33879198774229735, 0.21152869710931554, 0.2516184013802558, 0.22100797126768157, 0.09264720007195137, 0.2688493486493826, 0.33650670724455267, 0.831966366386041, 0.6697501614689827, 0.594259612262249, 1.1285445489920676, 0.5851370142772794, 0.7819634245242923, 0.2460431505460292, 0.37550187727902085, 0.19315010751597583, 0.34820265776943415, 0.49537897284608334, 11.197406351566315, 49.33606244623661, 62.45591104030609, 67.61794164776802, 64.44097772240639, 85.50556540489197, 94.18790191411972, 66.97096556425095, 32.92764611542225, 45.452621430158615, 46.26306094229221, 63.123827800154686, 67.62579202651978, 84.442268460989, 85.03071248531342, 100.99532783031464, 96.44336968660355, 50.75543828308582, 6.499858545139432, 0.42086244793608785, 0.3106277802726254, 0.1381867247982882, 0.23008252261206508, 0.20283927588025108, 0.16687404247932136, 0.11208725380129181, 0.15078258875291795, 0.11819258361356333, 0.2441210622782819, 0.0923141538805794, 0.18920428643468767, 0.13976269023260102, 0.1495322331902571, 0.15036174649139866, 0.13517402083380148, 0.125500526628457, 0.14555524190654978, 0.10920889340923168, 0.14948084688512608, 0.07760801527183503, 0.13786761614028364, 0.12449302405002527, 0.08893839127267711, 0.13782733236439526, 0.16527229483472183, 0.14837759983493015, 0.12412190568284132, 0.10089237170177512, 0.07990809419425204, 0.1256042640306987, 0.21073851763503626, 0.22448665491538122, 0.11057501658797264, 0.18188734858995304, 0.17765623109880835, 0.10889300567214377, 0.20636475936044008, 0.06971233582589775, 0.15377041592728347, 0.11931235087104142, 0.08497604256263003, 0.08690206421306357, 0.08796839683782309], [0.025189464358845726, 0.05307753352099098, 0.019699488148035016, 0.05065686673333403, 0.07174502636189573, 0.024726885567361023, 0.043511290787137114, 0.009880273246380966, 0.03336102236062288, 0.0185079088259954, 0.03598356444854289, 0.020834781134908553, 0.024677367619005963, 0.06482149357907474, 0.020079562382306904, 0.010638170224410715, 0.043383303709561005, 0.04535841471806634, 0.09242801417713054, 0.07388733210973442, 0.055968495580600575, 0.04953163726895582, 0.04400190977321472, 0.06646137277130038, 0.04209728795103729, 0.07545770175056532, 0.032042058955994435, 0.026623234298313037, 0.0290033538476564, 0.0024767747754594893, 0.0628485978813842, 0.03688362630782649, 0.04460141666640993, 0.02920792314398568, 0.04311151438741945, 0.053319043217925355, 0.030292820592876524, 0.015509828881477006, 0.0597127901710337, 0.22243537358008325, 0.029404323249764275, 11.762839760631323, 45.61676882207394, 86.83934703469276, 87.51152336597443, 74.35933470726013, 59.5942047983408, 70.51495179533958, 47.809752747416496, 24.557865634560585, 19.178862869739532, 43.63278888165951, 52.83837631344795, 54.619333148002625, 73.06319385766983, 67.82331302762032, 48.644837737083435, 31.078688129782677, 21.634458303451538, 3.5673400154337287, 0.3517024184111506, 0.1310934851062484, 0.04726839113573078, 0.0125792760263721, 0.12715765333268791, 0.047550377566949464, 0.07600352168083191, 0.10312985788914375, 0.05625853802484926, 0.025776126531127375, 0.1465806970372796, 0.014383602156158304, 0.1634064019890502, 0.12229129453771748, 0.15800913301063702, 0.41245964413974434, 0.1618084986694157, 0.07272376329638064, 0.3439574543153867, 0.06783004151657224, 0.35657191649079323, 0.16237449017353356, 0.24534441850846633, 0.1017458934802562, 0.04994673530745786, 0.12436041710316204, 0.06663088672212325, 0.10270834027323872, 0.10420576421893202, 0.24453996011288837, 0.2498564834240824, 0.12848133308580145, 0.24989183933939785, 0.1232760948187206, 0.39012414577882737, 0.10231794833089225, 0.01882448861579178, 0.1584715800709091, 0.13524691457860172, 0.2394102353719063, 0.15658659918699414, 0.040388774941675365, 0.04411615227581933, 0.1268019716371782, 0.06056948834157083, 0.12083897832781076, 0.08709186848136596, 0.09926263766828924, 0.09397062749485485, 0.0911042231018655, 0.06649447997915559, 0.02029081657383358, 0.21068217378342524, 0.03254343908338342, 0.32619135919958353, 7.885132161900401, 23.233739286661148, 49.108857437968254, 50.3408083319664, 53.010697066783905, 52.25526720285416, 122.25261837244034, 68.87369066476822, 26.161149702966213, 29.84210718423128, 35.9627940505743, 49.74755756556988, 52.44368389248848, 59.827071502804756, 63.883304446935654, 79.65207070112228, 54.69500228762627, 19.9869617074728, 0.42784893710631877, 0.42050767166074365, 0.09652658409322612, 0.12394096265779808, 0.09024709448567592, 0.038456085094367154, 0.0583294120588107, 0.0477547353511909, 0.026809979062818456, 0.1093641655461397, 0.07843858242267743, 0.02669647499715211, 0.04241206988808699, 0.022268927714321762, 0.08642665183288045, 0.006195060568643385, 0.0352527011273196, 0.04179957541055046, 0.023466193742933683, 0.02202091309300158, 0.06911985707120039, 0.03818624019913841, 0.04923691929434426, 0.02275326070957817, 0.08744589518755674, 0.030714117419847753, 0.025699753969092853, 0.039522276711068116, 0.03230100170185324, 0.09501113338046707, 0.05089960839541163, 0.04088188012246974, 0.0030046136271266732, 0.03257573735027108, 0.10503151483135298, 0.06439086981117725, 0.02104850111209089, 0.04551911937596742, 0.028499114596343134, 0.03045553276024293, 0.004940510480082594, 0.028674422865151428, 0.04508569028985221, 0.04878531130088959, 0.017081742189475335, 0.0129639729129849, 0.036810098026762716, 0.09821427243878134, 0.009842041508818511, 0.029738334233115893, 0.006952521071070805, 0.02568541753134923, 0.06929230250534602, 0.1036446560465265, 0.01247219710421632, 0.057844207040034235, 0.024161671462934464, 0.04771908628754318, 0.0026812278792931465, 0.05497673395439051, 0.046292934493976645, 0.004849717988690827, 0.053446859601535834, 0.04066532514116261, 0.0396758975693956, 0.03862190686049871, 0.03563485894119367, 0.017638991193962283, 0.03071265724429395, 0.03318465838674456, 0.053561892491416074, 0.01341063263680553, 0.08756560360779986, 0.03671842052426655, 0.0632497583865188, 0.010285856023983797, 0.05681522670784034, 0.12101194326533005, 0.03223612315196078, 0.01038907206748263, 0.18023351702140644, 0.005347187461666181, 0.340693281032145, 0.7686433580238372, 25.196238979697227, 69.34726685285568, 98.70363280177116, 101.96967154741287, 94.59920704364777, 91.23197212815285, 93.09633448719978, 59.52225185930729, 22.969594560563564, 18.660382591187954, 25.988350175321102, 20.260488130152225, 27.725582756102085, 56.28084719181061, 65.9041728079319, 48.65649551153183, 32.340775206685066, 15.152255985885859, 1.6231787321157753, 0.36879324819892645, 0.1809090346796438, 0.028776588769687805, 0.09132175400736742, 0.08434701303485781, 0.13500233239028603, 0.1416647108271718, 0.016616525063000154, 0.06347668488160707, 0.09320461977040395, 0.14340344408992678, 0.026146933196287137, 0.04578543906973209, 0.19662056816741824, 0.0903890302288346, 0.24707767472136766, 0.04488740327360574, 0.06321398686850443, 0.310754687525332, 0.1893606421072036, 0.3544448025058955, 0.05154143997060601, 0.21496607281733304, 0.22611589170992374, 0.3867347276536748, 0.33735222124960274, 0.057816747575998306, 0.2497283590491861, 0.5926050385460258, 0.7115533214528114, 1.165498634800315, 0.5889672681223601, 0.7178382435813546, 0.5379647423978895, 0.6467168068047613, 0.34028640598990023, 0.20284182886825874, 0.2558579051401466, 0.3558636404341087, 1.7690887651406229, 0.6422618427313864, 0.3242248162860051, 0.08450360619463027, 0.08008400545804761, 0.11094114772276953, 0.09679965733084828, 0.13063448161119595, 0.35266474646050483, 0.2824398240773007, 0.1727891227346845, 0.08186385370208882, 0.07677921443246305, 0.19334153708769009, 0.0881282554473728, 0.20149472693447024, 4.603864783421159, 22.630286067724228, 53.75443495810032, 55.49765981733799, 55.43311648070812, 40.32972492277622, 81.14452421665192, 36.57776065170765, 15.716765094548464, 30.544098615646362, 47.25889630615711, 76.16619855165482, 80.64103603363037, 80.90658858418465, 78.38113009929657, 87.95217052102089, 74.020506888628, 36.80192582309246, 2.179767759516835, 0.2586292033083737, 0.13308399938978255, 0.08793527478701435, 0.05299755968735553, 0.09178284293739125, 0.08168195330654271, 0.043083097552880645, 0.12178176562883891, 0.07835966243874282, 0.059841871916432865, 0.061917020721011795, 0.04568303753330838, 0.03258162258134689, 0.04142466095800046, 0.019000180946022738, 0.03897665344993584, 0.04885060174274258, 0.024572483598603867, 0.05485422763740644, 0.04291592507797759, 0.06080434097384568, 0.029239740870252717, 0.06688280875096098, 0.024433559119643178, 0.029408182417682838, 0.029444798128679395, 0.043494651836226694, 0.06795851470087655, 0.07589831482619047, 0.10864132113056257, 0.04267580319719855, 0.03806614957284182, 0.024741671004449017, 0.031024370400700718, 0.03623795411840547, 0.001699364299838635, 0.08312393139931373, 0.09212792676407844, 0.004600072497851215, 0.06490141546237282, 0.029389923729468137, 0.0374415914848214, 0.1706982552423142, 0.1580951182404533, 0.12379042542306706, 0.18530588858993724, 0.2666579349897802, 0.07630515276105143, 0.10690216484363191, 0.09216935344738886, 0.15116063877940178, 0.11069959349697456, 0.193366963067092, 0.10639089188771322, 0.10925409762421623, 0.17147624865174294, 0.07832936054910533, 0.26919735653791577, 0.23561995360068977, 0.09187993069645017, 0.12946004775585607, 0.19897066784324124, 0.14261614414863288, 0.11110850944533013, 0.12204551749164239, 0.16749024769524112, 0.10420465841889381, 0.14113480254309252, 0.09272457638871856, 0.08909361145924777, 0.0984944702940993, 0.1199772632389795, 0.15213767619570717, 0.1633871061494574, 0.14806392369791865, 0.13664630823768675, 0.18541955592809245, 0.11079420248279348, 0.12461832084227353, 0.21440719108795747, 0.17802693386329338, 0.45130430662538856, 0.3672761796042323, 21.585583426058292, 69.08980786800385, 118.86991068720818, 109.21837538480759, 94.3355467915535, 83.42992678284645, 90.81092432141304, 63.02194006741047, 36.78853154182434, 29.196219742298126, 58.41738134622574, 73.2803750038147, 74.1805087029934, 99.59371984004974, 92.1561661362648, 71.39262869954109, 49.8632575571537, 36.53508894145489, 5.899435663595796, 1.3795163319446146, 0.4253777634585276, 0.22102530783740804, 0.28436664724722505, 0.2557328680995852, 0.26740744477137923, 0.257221408537589, 0.17875481746159494, 0.27276367298327386, 0.17842110333731398, 0.4180390213150531, 0.16212689486565068, 0.3629599674604833, 0.32478261447977275, 0.5001245916355401, 0.8457500673830509, 0.495401356020011, 0.36054611729923636, 0.7495971175376326, 0.39428504125680774, 0.9861781226936728, 0.3886258683633059, 0.8424550504423678, 0.5508456355892122, 0.6562107754871249, 0.33844677032902837, 0.15072836744366214, 0.47770944598596543, 0.8339693932794034, 1.1921159690245986, 1.23998663155362, 0.6750601390376687, 1.123643049504608, 0.5292791803367436, 0.8571347314864397, 0.44052006967831403, 0.4222467611543834, 0.5965805158484727, 0.45190538687165827, 1.089927814900875, 0.590031270403415, 0.3125868126517162, 0.17907563305925578, 0.18543962360126898, 0.1838388852775097, 0.18493947543902323, 0.22433779493439943, 0.40334936580620706, 0.39581241086125374, 0.26178686355706304, 0.25162139965686947, 0.33577055612113327, 0.4944048001198098, 0.20463169610593468, 0.8770457224454731, 13.034090995788574, 39.28081400692463, 75.23100033402443, 73.9517305791378, 78.41963723301888, 75.32184585928917, 153.84929090738297, 84.63764637708664, 35.25416247546673, 42.97538235783577, 47.92865976691246, 60.075072795152664, 71.51864513754845, 79.82097923755646, 80.34147530794144, 102.9535223543644, 81.0255677998066, 35.01596845686436, 1.3047156832180917, 0.6148450670298189, 0.33607768651563674, 0.1840174014796503, 0.21184443641686812, 0.21726330189267173, 0.22926212288439274, 0.12851377978222445, 0.19811292324448004, 0.2431401508511044, 0.19053371041081846, 0.11704132703016512, 0.09264826876460575, 0.16220179240917787, 0.15551995486021042, 0.1138351674308069, 0.1577979771536775, 0.11587404005695134, 0.15312128904042765, 0.21862843801500276, 0.1864072505850345, 0.13611545000458136, 0.20290290762204677, 0.19450026709819213, 0.11068963387515396, 0.09307546381023712, 0.13346690306207165, 0.10803018478327431, 0.133520693925675, 0.1707449957029894, 0.1715065134339966, 0.13537523191189393, 0.05915973430091981, 0.16735082783270627, 0.18795314419548959, 0.2826082322280854, 0.09803430904867128, 0.2178425036254339, 0.2326917357277125, 0.09165462950477377, 0.1260955212637782, 0.09043928846949711, 0.10040148554253392], [0.014811302789894398, 0.02202598381700227, 0.02897471065807622, 0.041131679608952254, 0.008027739986573579, 0.07433214574120939, 0.046899851731723174, 0.028288676767260768, 0.07307677326025441, 0.03501516563119367, 0.04464463192562107, 0.02345495391637087, 0.03924580443708692, 0.08265154698165134, 0.05690215817594435, 0.06387216053553857, 0.05578173040703405, 0.012695111363427714, 0.013720716779062059, 0.024789908748061862, 0.031110845447983593, 0.020694695194833912, 0.04505791912379209, 0.11364300313289277, 0.01987996176467277, 0.008862878767104121, 0.024411522899754345, 0.058746569557115436, 0.015142480624490418, 0.0567551684071077, 0.07172833546064794, 0.014288591482909396, 0.07223740423796698, 0.03167832124745473, 0.07423204486258328, 0.12620486930245534, 0.09891733861877583, 0.09785578542505391, 0.1123353315051645, 4.942343970760703, 34.17533956468105, 79.92855906486511, 91.26490116119385, 78.56139242649078, 70.4925785958767, 56.530923172831535, 40.58165140450001, 26.17839887738228, 38.22935342788696, 116.72671169042587, 123.60389426350594, 67.34516188502312, 64.28036794066429, 72.65196472406387, 53.96141745150089, 37.39700049161911, 16.67906440794468, 2.6032011257484555, 0.21263608534354717, 0.2540642529493198, 0.022159212312544696, 0.09383347118273377, 0.09847742316196673, 0.020599104718712624, 0.023663185711484402, 0.09565255677443929, 0.06681656464934349, 0.027747716048907023, 0.13163698953576386, 0.11431653183535673, 0.1283904051524587, 0.1279959239764139, 0.15824854985112324, 0.023570472912979312, 0.059015657461714, 0.1639312636689283, 0.16009860526537523, 0.171000131231267, 0.205542444891762, 0.0899008232227061, 0.1236873707966879, 0.03751537580683362, 0.05763339257100597, 0.09245941444532946, 0.33635435916949064, 0.21190892904996872, 0.1648573303828016, 0.0802095174731221, 0.1248870525159873, 0.04214865941321477, 0.21870256372494623, 0.03139850188745186, 0.11400195027817972, 0.018934883082692977, 0.13290471135405824, 0.061202024517115206, 0.1332399543025531, 0.17395230563124642, 0.19464031036477536, 0.2065203431993723, 0.13219024578575045, 0.06509893806651235, 0.06096326447732281, 0.22789136128267273, 0.13800570013700053, 0.2568042027996853, 0.19742570933885872, 0.18553953152149916, 0.07261597376782447, 0.05765671456174459, 0.10246798832667992, 0.04982599159120582, 0.1179285126272589, 0.0229762556773494, 0.05352559775928967, 0.08849602672853507, 0.507732080295682, 4.421787103638053, 17.240459583699703, 34.919282644987106, 45.50422266125679, 38.91074426472187, 56.891364231705666, 75.13974443078041, 54.608366936445236, 34.91564244031906, 20.107590034604073, 31.780993044376373, 39.1237760335207, 46.33198544383049, 57.945503666996956, 71.73951208591461, 74.5155519247055, 52.00316973030567, 6.705833617597818, 0.0818460421578493, 0.15564882138278335, 0.11125951423309743, 0.10083532280987129, 0.006467916264227824, 0.0009952085542863642, 0.06139616292784922, 0.052653689272119664, 0.06691622023936361, 0.06608730065636337, 0.06964626983972266, 0.03502725521684624, 0.041151361365336925, 0.03864139936922584, 0.05103051953483373, 0.014823332076048246, 0.04120258439797908, 0.03480395782389678, 0.03834711555100512, 0.005053491795479204, 0.017474382839282043, 0.01981030378374271, 0.029800537340634037, 0.022785419823776465, 0.0449924283020664, 0.033051869613700546, 0.04201976320473477, 0.04860874694713857, 0.08408528723521158, 0.04174704248725902, 0.02109099648805568, 0.018506756641727407, 0.003774002530008147, 0.025053005665540695, 0.02124868617102038, 0.019736645626835525, 0.11114563909359276, 0.028386415760905948, 0.01775224107404938, 0.04272789825336076, 0.05084180251287762, 0.05168263356608804, 0.044535777415148914, 0.06589503987925127, 0.05344059958588332, 0.039785356930224225, 0.05556198419071734, 0.04524865849816706, 0.03985118913988117, 0.04519175061432179, 0.045783561436110176, 0.029026853953837417, 0.06291164332651533, 0.03978520478995051, 0.06243700277991593, 0.041536465505487286, 0.03585001497413032, 0.03991431622125674, 0.02740479558269726, 0.10624432514305227, 0.03872540306474548, 0.016849667044880334, 0.029505411184800323, 0.04381904458568897, 0.04160856515227351, 0.05794877193693537, 0.009778096209629439, 0.04624313638487365, 0.04640726976504084, 0.050173368654213846, 0.06729156142682768, 0.05908884064410813, 0.05393579391238745, 0.0640332511102315, 0.04974994000804145, 0.016488263390783686, 0.05194163568376098, 0.048608041906845756, 0.1280844325083308, 0.6138933962211013, 12.772639375180006, 54.79704961180687, 100.43982803821564, 103.0309621989727, 101.8493016064167, 97.91281163692474, 82.72409945726395, 71.07919871807098, 45.33334583044052, 41.62435345351696, 91.15805849432945, 69.88227814435959, 36.544691026210785, 54.39439281821251, 67.61476501822472, 58.23088355362415, 35.84553234279156, 12.203340623527765, 0.5963979475200176, 0.37063442752696574, 0.1757617952534929, 0.021944336440355983, 0.1022863551042974, 0.10912195080891252, 0.03935576845833566, 0.1330859586596489, 0.07887475745519623, 0.020098912027606275, 0.10194920483627357, 0.04968845307303127, 0.3778264916036278, 0.2058774948818609, 0.374107530224137, 0.5814065644517541, 0.12310734528000467, 0.6653853831812739, 0.39919304195791483, 1.222112865652889, 1.3681555353105068, 1.1813098238781095, 0.7977712887804955, 1.151564426254481, 1.2757469876669347, 1.0772307962179184, 0.8224638481624424, 1.5552683011628687, 1.212311766576022, 0.7209545513615012, 0.7855776837095618, 0.5212067510001361, 0.4628478497033939, 0.9685449313838035, 0.8436049637384713, 0.9661619842518121, 0.5687983066309243, 0.8538154314737767, 0.7281961315311491, 0.8166686841286719, 0.3742645093007013, 0.5955843161791563, 0.36082914273720235, 0.23935978417284787, 0.5342624348122627, 0.2388599922414869, 0.053728979619336314, 0.07777904320391826, 0.2713217691052705, 0.2630470599979162, 0.5793489154893905, 0.4604574217228219, 0.12479370518121868, 0.22121577261714265, 0.13790178461931646, 0.07926670790766366, 0.0183482932698098, 0.01978899115783861, 0.18387618561973795, 0.21529533405555412, 1.5094919200055301, 14.013325050473213, 37.6924080401659, 53.80431488156319, 45.387492924928665, 50.43069630861282, 33.03869515657425, 28.623199090361595, 21.710575819015503, 20.21534465253353, 47.38484814763069, 60.212781205773354, 71.64726063609123, 76.36544466018677, 89.24450397491455, 87.18771234154701, 72.57346853613853, 15.102472957223654, 0.09647721642977558, 0.36217106448020786, 0.22973485611146316, 0.05562237274716608, 0.03346523102663923, 0.026844613239518367, 0.07076546564348973, 0.029955866993987, 0.03847485400910955, 0.05216548226599116, 0.031957209212123416, 0.04159299118327908, 0.04161016819125507, 0.008233046792156529, 0.015706184458395, 0.03948183708416764, 0.02317022896022536, 0.04778531925694551, 0.014915821302565746, 0.015051116679387633, 0.014070591169002, 0.04552194324787706, 0.03319216521049384, 0.02558461532316869, 0.015494603721890599, 0.05533794093935285, 0.03834437331533991, 0.02132353918568697, 0.015172132207226241, 0.02998272902914323, 0.046733362032682635, 0.04934245640470181, 0.027972230564046185, 0.040092769340844825, 0.005631845624520793, 0.05119439687405247, 0.03313126086140983, 0.07319440366700292, 0.06480478783487342, 0.05782827312941663, 0.03736515027412679, 0.12274998633074574, 0.22457360493717715, 0.09539523191051558, 0.15441912721144035, 0.16521123092388734, 0.1503923675045371, 0.18974875565618277, 0.17111655935877934, 0.127136962255463, 0.11084307290730067, 0.1903908618260175, 0.12775929761119187, 0.09221224958309904, 0.16613187995972112, 0.15048979665152729, 0.1217834503040649, 0.15636689378879964, 0.07447839336236939, 0.30043081962503493, 0.11575941534829326, 0.06944807188119739, 0.19713647954631597, 0.12764865823555738, 0.20781458937563002, 0.15470743674086407, 0.09615871633286588, 0.1480884591001086, 0.10552187406574376, 0.13813820318318903, 0.1584282238036394, 0.13864454085705802, 0.1271434931550175, 0.1344513174262829, 0.12011491679004394, 0.16935928724706173, 0.2458398911403492, 0.20309696439653635, 0.2020077736233361, 0.41252329072449356, 10.271710474044085, 57.90091685950756, 115.60036092996597, 117.42929399013519, 98.9765265583992, 91.96761265397072, 75.28235077857971, 56.097712218761444, 38.189394772052765, 50.621195286512375, 130.0409084558487, 137.58169502019882, 90.1844747364521, 91.15270838141441, 105.59982195496559, 78.46483960747719, 57.48615391552448, 28.077181689441204, 4.862593850120902, 1.1895758053287864, 0.37300698459148407, 0.1673993791337125, 0.4248542821733281, 0.3327338956296444, 0.16602900344878435, 0.15321129671065137, 0.27657041558995843, 0.17537368170451373, 0.532178187277168, 0.4203384026186541, 0.4654432291863486, 0.5127403303049505, 0.3124436078360304, 0.3210432588821277, 0.1592149745556526, 0.3327178058680147, 0.2878298645373434, 0.7609754288569093, 0.9961887449026108, 0.877438704483211, 0.2537928940728307, 0.5605383811052889, 0.7898951426614076, 0.5591827444732189, 0.36394325376022607, 0.8708034886512905, 0.5889016028959304, 0.32403506396804005, 0.4022912710206583, 0.2459476509829983, 0.297011062502861, 0.5795318994205445, 0.30621689977124333, 0.39278872311115265, 0.18280980846611783, 0.35913280094973743, 0.24259244586573914, 0.3582303790608421, 0.3302849270403385, 0.46189490240067244, 0.29438587836921215, 0.2542541240109131, 0.37346848170273006, 0.31223640020471066, 0.4785128653747961, 0.2745260065421462, 0.6888270378112793, 0.49756821943446994, 0.6040495494380593, 0.24694146093679592, 0.4215950961224735, 0.3631181933451444, 0.2924023848026991, 0.21725311962654814, 0.1670396898407489, 0.19109593180473894, 0.26764131034724414, 1.2953574978746474, 7.697145799174905, 29.188644848763943, 57.82446876168251, 70.26372447609901, 58.96378442645073, 82.90061518549919, 102.37463101744652, 72.34655231237411, 48.06251518428326, 28.541262187063694, 40.54053761065006, 55.461193174123764, 67.22967088222504, 75.94158500432968, 90.00856697559357, 100.15015438199043, 77.64656111598015, 11.810024678707123, 0.12668310926528648, 0.3806716779945418, 0.3211188392015174, 0.18707312032347545, 0.2458910399582237, 0.09995142492698506, 0.14551733300322667, 0.16938263521296903, 0.14607563585741445, 0.15308934700442478, 0.17675701528787613, 0.12269978746189736, 0.12063643880537711, 0.12699092243565246, 0.136944325058721, 0.13333769515156746, 0.10621309556881897, 0.17743786156643182, 0.1589162155869417, 0.05481615546159446, 0.06457704497734085, 0.0870582417701371, 0.1692628228920512, 0.1573894842294976, 0.13409150938969105, 0.15988921571988612, 0.11775942170061171, 0.16348885459592566, 0.15411279833642766, 0.19526080519426614, 0.18505945103242993, 0.1573897068738006, 0.07793727651005611, 0.11298474040813744, 0.05360536750231404, 0.11958036266150884, 0.2948929136618972, 0.16006819205358624, 0.11995381879387423, 0.11927427869522944, 0.18282707082107663], [0.023703308070253115, 0.023748490020807367, 0.10919394655502401, 0.07998847620910965, 0.011841843770525884, 0.04364530410384759, 0.10160521938814782, 0.08203752367990091, 0.06591573837795295, 0.04187081787677016, 0.03085952455876395, 0.04287494368327316, 0.05668572193826549, 0.010526668102102121, 0.043280516256345436, 0.04069650276505854, 0.04586929062497802, 0.010592501239443664, 0.032817625542520545, 0.037722086199210025, 0.02875503123505041, 0.04817018590983935, 0.017626756889512762, 0.03538049895723816, 0.0467202891013585, 0.05488152011821512, 0.0402009336539777, 0.011737210224964656, 0.03100222471402958, 0.09777284300071187, 0.03513790943543427, 0.06656882833340205, 0.02358979472774081, 0.025319035921711475, 0.03951286256778985, 0.04966817759850528, 0.13816227845381945, 2.5300229899585247, 39.13307413458824, 81.6279798746109, 96.92599698901176, 97.27987959980965, 64.46524322032928, 55.09178839623928, 43.90366494655609, 39.28847819566727, 30.65769352018833, 31.914054304361343, 29.329843372106552, 33.981755152344704, 90.1800137758255, 73.30922305583954, 47.2069188952446, 26.39799289405346, 9.831860326230526, 1.5600960608571768, 0.1867778939777054, 0.23311740194913, 0.09951939107850194, 0.07918847069959156, 0.0603698431950761, 0.052896323322784156, 0.06851856160210446, 0.10098909580847248, 0.08857393739162944, 0.08011523503228091, 0.10563373798504472, 0.09082440374186262, 0.0811405417334754, 0.056852705165511, 0.027966438101429958, 0.281420944374986, 0.061109827511245385, 0.27912269113585353, 0.061683901003561914, 0.2982696262188256, 0.11097890819655731, 0.24475147220073268, 0.4706042428733781, 0.3465022490127012, 0.5233094037976116, 3.3953819051384926, 3.689961335621774, 3.296072334051132, 13.002638183534145, 5.615870179608464, 1.6392046096734703, 1.3598232949152589, 1.0488234017975628, 1.553773912601173, 2.016737745143473, 0.4543032660149038, 0.9886878286488354, 2.389148874208331, 1.6303008561953902, 0.47867744404356927, 0.39373110223095864, 0.5072218389250338, 0.8143937936984003, 5.497471857815981, 1.257099963258952, 1.5615107724443078, 0.6587641790974885, 0.2763982967007905, 0.19226880714995787, 0.10457142037921585, 0.10252596490317956, 0.19032856595003977, 0.8102635340765119, 0.05529575726541225, 0.06695317177218385, 0.09105651042773388, 0.1907380681950599, 0.028767122676072177, 0.02319472168892389, 0.03065849159611389, 0.05882768629817292, 0.12671292875893414, 0.1447554590413347, 1.6756687592715025, 19.745340272784233, 34.95347321033478, 44.22988884150982, 66.77707716822624, 57.87124045193195, 64.90969017148018, 58.71191494166851, 31.38145588338375, 25.100752003490925, 30.564019046723843, 46.169266775250435, 44.95275445282459, 57.25346960127354, 68.98215964436531, 70.72877392172813, 23.95443521440029, 1.0733557166531682, 0.45177764841355383, 0.10441682359669358, 0.04230016143992543, 0.09542259489535354, 0.052607757752412, 0.025668531816336326, 0.00965940917012631, 0.02285808906890452, 0.02132598641765071, 0.02087090146233095, 0.02686246374651091, 0.02489604699803749, 0.047524131514364854, 0.08815365916234441, 0.030312801063701045, 0.030840134095342364, 0.0604064273647964, 0.0529740632919129, 0.01829250973969465, 0.014819293865002692, 0.03698787579196505, 0.04475833637116011, 0.012961317879671697, 0.015250037304213038, 0.04156620336289052, 0.01576056904013967, 0.0431052395288134, 0.04574134436552413, 0.014083070382184815, 0.030614372772106435, 0.022012296758475713, 0.06638716542511247, 0.036905345259583555, 0.0192051973863272, 0.04178130373475142, 0.056149653828470036, 0.0529728684341535, 0.06233146195882, 0.031123333938012365, 0.020304503632360138, 0.10243177152005956, 0.06377353653078899, 0.03124627997749485, 0.03406687901588157, 0.0552405043708859, 0.05721409397665411, 0.0027083503618996474, 0.03566717576177325, 0.02315679423190886, 0.005753762397944229, 0.08919101092033088, 0.019630724455055315, 0.023937861988088116, 0.05811169190565124, 0.06777063259505667, 0.0339658393204445, 0.03713953738042619, 0.02588511648355052, 0.03330851541250013, 0.0801837352628354, 0.020075946267752443, 0.02013414734392427, 0.07355788533459418, 0.026606934879964683, 0.0503832554386463, 0.04761151569255162, 0.042058429098688066, 0.027666035275615286, 0.06278652464970946, 0.06490161584224552, 0.07314746282645501, 0.04547724369331263, 0.0472763321158709, 0.1082510627747979, 0.08185555649106391, 0.44515988789498806, 8.809607829898596, 60.56450553238392, 103.21282044053078, 111.93887740373611, 117.27258279919624, 83.43808114528656, 82.77760058641434, 73.18197548389435, 51.413388177752495, 28.421365320682526, 16.25824648886919, 17.027444913983345, 30.819502137601376, 72.86934345960617, 68.27715307474136, 53.33318576216698, 28.45705110579729, 7.030932297930121, 0.23213015258079395, 0.5798577319364995, 0.2677244902588427, 0.162333672051318, 0.20972158235963434, 0.05221013729169499, 0.09899929398670793, 0.10364130896050483, 0.05854497998370789, 0.1767337860655971, 0.352161867194809, 0.3002464404562488, 0.3385776258073747, 0.46978609927464277, 0.9471871086861938, 1.0303770541213453, 1.1062302463687956, 1.3737254426814616, 1.6840636963024735, 1.3440497475676239, 1.3992147124372423, 1.579050156287849, 1.7121953680180013, 1.8635554960928857, 4.2047071270644665, 6.091295443475246, 14.074962493032217, 14.718715399503708, 10.615987200289965, 21.82815670967102, 11.20156617835164, 5.892223175615072, 5.8619259763509035, 6.436790954321623, 9.70128508284688, 6.181469829753041, 5.098179783672094, 5.4230770748108625, 5.909877503290772, 3.009997559711337, 1.830523512326181, 0.428377702482976, 0.33757919969502836, 0.7517701853066683, 1.6315140598453581, 0.48708401795011014, 0.7865766144823283, 2.4353460827842355, 0.6525002152193338, 0.1249519459088333, 0.04247526376275346, 0.2560037816874683, 0.24306900857482105, 1.5255503333173692, 0.1198858158022631, 0.08869131546816789, 0.4481565020978451, 0.1529440493322909, 0.22399455163395032, 0.1296931118122302, 0.08602882357081398, 0.05883632860786747, 0.059361954699852504, 0.18187805690104142, 0.27205023157875985, 15.969121903181076, 38.27410362660885, 52.21775941550732, 68.80142614245415, 42.33152970671654, 39.14738416671753, 27.123776748776436, 20.538205727934837, 31.1793390288949, 49.96828772127628, 75.12839064002037, 71.00026175379753, 73.50947231054306, 77.31318980455399, 89.70296457409859, 43.23854863643646, 3.3218138152733445, 0.4228617047192529, 0.09398456502822228, 0.09749743199790828, 0.11785980459535494, 0.05463455192511901, 0.09986003686208278, 0.057276753504993394, 0.018782985862344503, 0.05469485142384656, 0.03183788670867216, 0.08352071323315613, 0.04963426516042091, 0.017137924623966683, 0.008339484684256604, 0.012834066455980064, 0.04273334561730735, 0.058446556358831, 0.054721093765692785, 0.04197341979306657, 0.005177957382329623, 0.026880987752520014, 0.02322370812180452, 0.024037330185819883, 0.027517310736584477, 0.034132321598008275, 0.05597914168902207, 0.04801924049388617, 0.03854581816995051, 0.04678444405726623, 0.0023725243636363302, 0.06065901732654311, 0.06861164176370949, 0.053128775107325055, 0.009332737099612132, 0.049036476339097135, 0.001918546020078793, 0.00272247435987083, 0.09847782392171212, 0.012334600141912233, 0.12400572988553904, 0.20299353869631886, 0.1848911913111806, 0.17977184179471806, 0.06138568380265497, 0.09752131431014277, 0.19664370833197609, 0.21857366751646623, 0.13986420119181275, 0.1263373129768297, 0.07415769650833681, 0.2478791942121461, 0.17464465519879013, 0.08100585677311756, 0.10626915740431286, 0.115949939499842, 0.10221029981039464, 0.13243574823718518, 0.12080405285814777, 0.11087531922385097, 0.20547626016195863, 0.14675441896542907, 0.1634076636401005, 0.13277992664370686, 0.1421127305366099, 0.10117878875462338, 0.14647621748736128, 0.16297352209221572, 0.12451237183995545, 0.2520891308085993, 0.14877674169838428, 0.16286010708427057, 0.17984927748329937, 0.13949441869044676, 0.28533066739328206, 0.14729528134921566, 0.4124094155849889, 7.960759028792381, 63.49020414054394, 111.71377748250961, 123.41740787029266, 119.61115211248398, 83.5585954785347, 75.67726358771324, 59.57056246697903, 51.162263453006744, 42.081047147512436, 45.79340614378452, 41.23714283108711, 44.75889265537262, 115.82928344607353, 97.78959944844246, 68.62659752368927, 42.438691556453705, 16.148694567382336, 3.6668732995167375, 0.995386156719178, 0.7515953946858644, 0.23020095453830436, 0.5494593631010503, 0.37736538040917367, 0.31172785093076527, 0.2169819685514085, 0.4098726954543963, 0.3659485367825255, 0.49829558352939785, 0.34527064010035247, 0.28818953898735344, 0.2677065005991608, 0.2885080093983561, 0.4699381208047271, 0.44958760030567646, 0.39622866665013134, 0.6163523392751813, 0.6166879087686539, 0.8632953290361911, 0.44138520606793463, 0.6378037319518626, 0.8285043959040195, 2.0270603662356734, 4.008904583752155, 11.651490535587072, 11.034385599195957, 12.315353862941265, 27.547723799943924, 13.692920543253422, 5.873952331021428, 5.734958639368415, 4.653492020443082, 4.937456957995892, 5.0762720592319965, 3.962592906318605, 3.3650547824800014, 6.058726441115141, 3.638527770526707, 2.243053363636136, 1.4712204923853278, 2.0710933534428477, 1.362311092671007, 10.484033580869436, 3.963114428333938, 4.734178790822625, 4.344071298837662, 0.843758083647117, 0.6142065825406462, 0.16770830552559346, 0.34187846118584275, 0.41347463498823345, 1.5717256930656731, 0.15467830002307892, 0.21726244100136682, 0.21494152257218957, 0.531385395443067, 0.264797875424847, 0.20957422151695937, 0.18862459488445893, 0.11934556940104812, 0.3067134856246412, 0.4983526992145926, 4.376577604562044, 32.70604960620403, 57.94100470840931, 66.7151328921318, 94.16381880640984, 82.76802510023117, 90.6104926764965, 77.68190681934357, 45.15268452465534, 35.330496579408646, 39.422455206513405, 61.80098578333855, 64.03518989682198, 73.43535348773003, 85.9884586930275, 101.39986172318459, 42.61682219803333, 2.2693173168227077, 0.577686564065516, 0.25639275612775236, 0.2917864022310823, 0.2142795713734813, 0.1576829145778902, 0.21068814065074548, 0.19608933886047453, 0.22080361348344013, 0.08361352622159757, 0.14660977438325062, 0.16294420725898817, 0.10067833631183021, 0.23052800417644903, 0.16634723637253046, 0.1489473317633383, 0.11119891045382246, 0.17574045108631253, 0.2117162971990183, 0.17555345955770463, 0.08939572493545711, 0.09009174071252346, 0.08390171700739302, 0.1271864486625418, 0.11077853574533947, 0.13611822563689202, 0.10032459904323332, 0.1841607250389643, 0.20969490957213566, 0.14907300705090165, 0.1122014332213439, 0.15558125625830144, 0.19035964709473774, 0.23670895141549408, 0.1620938247651793, 0.1101859901973512, 0.0966611057810951, 0.12813816400012001, 0.1609438966261223, 0.0923302213777788], [0.0428758194175316, 0.010309168737876462, 0.011264280328759924, 0.017840254222392105, 0.0661842325644102, 0.023330115400312934, 0.03503573054331355, 0.06312302182777785, 0.019962718652095646, 0.006073623871998279, 0.03802964332862757, 0.09301157231675461, 0.019764602329814807, 0.013097411065245979, 0.016570612096984405, 0.07526796427555382, 0.011613257647695718, 0.08612833073129877, 0.027355095808161423, 0.06808544421801344, 0.02229515706858365, 0.022290145716397092, 0.007636540030944161, 0.0646802331903018, 0.027824468961625826, 0.027626155970210675, 0.09419947615242563, 0.023986760243133176, 0.006718442127748858, 0.06161054341646377, 0.027480702447064687, 0.12052081219735555, 0.015815345104783773, 0.013258368053357117, 0.177285157260485, 0.13322192011401057, 20.188770778477192, 76.15565791726112, 93.98510679602623, 86.385917365551, 65.80957308411598, 60.27582362294197, 70.97807854413986, 50.96746690571308, 34.39834959805012, 41.65369167923927, 57.43890345096588, 88.35380136966705, 58.19601282477379, 49.27433855831623, 34.21338312327862, 31.56775988638401, 10.109731815755367, 0.7018751814030111, 0.3520576102891937, 0.07604133410495706, 0.03083736402913928, 0.12414962489856407, 0.01005909372906899, 0.05618741059151944, 0.05293477028317284, 0.08897776220692322, 0.05356323206797242, 0.11269934751908295, 0.04757842703838833, 0.10044108654255979, 0.07835553609766066, 0.3191337425960228, 0.05161398490599822, 0.42345907422713935, 0.9146223217248917, 1.3054262450896204, 3.1896269833669066, 2.6860623294487596, 1.4627583464607596, 0.6775341625325382, 3.104338659904897, 7.212957730516791, 3.7065583700314164, 5.427155205979943, 4.410602878779173, 15.850694607943296, 21.413730047643185, 13.082023523747921, 16.96436069905758, 10.446783229708672, 8.09287128970027, 9.223888199776411, 3.3337371004745364, 2.077678400091827, 2.6146249752491713, 1.5323130204342306, 2.500796620734036, 7.009902326390147, 2.6140526309609413, 4.539325721561909, 3.3727137465029955, 1.4384302706457675, 2.1642873901873827, 1.1835299734957516, 1.2344403541646898, 2.224074569530785, 0.3363281168276444, 0.21059694554423913, 0.5658539989963174, 0.357695824932307, 0.16494428040459752, 0.7602420088369399, 3.265394917689264, 0.6108410318847746, 0.4329083062475547, 0.225558063830249, 0.012561381918203551, 0.009568084187776549, 0.04373563831904903, 0.09068597093573771, 0.1139864839205984, 0.050941105582751334, 0.10641258486430161, 0.13676686270628124, 0.21246712800348178, 1.4526966051198542, 17.987427301704884, 39.209499433636665, 43.93365293741226, 51.213887482881546, 57.512114122509956, 70.76094299554825, 43.95871639251709, 24.930756725370884, 19.6484549716115, 40.47514691948891, 53.41670148074627, 54.99106340110302, 59.49252225458622, 74.45658668875694, 41.85425631701946, 7.229328202083707, 0.2552878763526678, 0.04922357176837977, 0.07814378652255982, 0.09979211550671607, 0.05356464957003482, 0.06614539597649127, 0.007281471998794586, 0.025457322153670248, 0.04146383151237387, 0.012223358698975062, 0.01863641540694516, 0.10972878269967623, 0.03872346605930943, 0.06467500847065821, 0.04574445396428928, 0.019736001813726034, 0.025310506789537612, 0.08922291584894992, 0.05521410617802758, 0.04273305617971346, 0.03985624687629752, 0.03449366588029079, 0.03272414833190851, 0.022082461255195085, 0.023727210791548714, 0.04399299657961819, 0.020440522603166755, 0.07448746240697801, 0.04716302843007725, 0.03237638906284701, 0.06321371969534084, 0.016365849842259195, 0.068089303385932, 0.028624261103686877, 0.011590352187340613, 0.0302144126908388, 0.05440753637230955, 0.08192411609343253, 0.03294115602329839, 0.049765280200517736, 0.01963670802069828, 0.034369307904853486, 0.02858387157175457, 0.017546339622640517, 0.09257402431103401, 0.04046303052746225, 0.013768471199000487, 0.029734744093730114, 0.009210033185809152, 0.016675279039191082, 0.07183403213275596, 0.028873683950223494, 0.057665746498969384, 0.018120962304237764, 0.0327679498877842, 0.03680363763123751, 0.011487993324408308, 0.018411424061923753, 0.015494633407797664, 0.05922121010371484, 0.024496626829204615, 0.07009392589679919, 0.030672219472762663, 0.014407590224436717, 0.04835744090087246, 0.041306789353257045, 0.04362028259492945, 0.05505324195837602, 0.03361239148944151, 0.12801461125491187, 0.019932758150389418, 0.049681079835863784, 0.19375032687094063, 1.293585249222815, 38.128571435809135, 99.12670969963074, 104.43067029118538, 102.22612738609314, 89.15247291326523, 87.00169712305069, 109.8029588162899, 69.28062602877617, 37.76494614779949, 23.249654732644558, 24.34260718524456, 50.462553799152374, 46.68754756450653, 53.54598194360733, 45.61315901577473, 33.18214125931263, 7.930490327998996, 0.3562001895625144, 0.3644131519831717, 0.08978251004009508, 0.2601879509165883, 0.2816339407581836, 0.11781936496845447, 0.2594094380037859, 0.057478510061628185, 0.4999127530027181, 0.19533487153239548, 0.4722084692912176, 0.046751618865528144, 0.2299277699785307, 0.49835056182928383, 1.2356229219585657, 1.741753863170743, 3.354468788020313, 4.808470029383898, 4.238018514588475, 8.299682792276144, 7.124606296420097, 6.49534011259675, 6.6420008428394794, 6.307030292227864, 17.037360481917858, 12.218797244131565, 11.054565366357565, 11.172485388815403, 12.609692718833685, 21.27082921564579, 17.724916487932205, 17.95909222215414, 14.49959160760045, 11.634435150772333, 10.841486100107431, 7.169789671897888, 11.474934909492731, 7.807539375498891, 3.400367475114763, 4.151727044954896, 1.0349697014316916, 3.8654124084860086, 3.4329982241615653, 1.790821342729032, 2.2382912691682577, 2.1269463188946247, 3.000794453546405, 2.109628510661423, 2.093041925691068, 1.0503917676396668, 0.3919130185386166, 0.40619858948048204, 0.2992943243589252, 0.16070185258286074, 0.5436140298843384, 1.0455553396604955, 0.49602832237724215, 0.28062966652214527, 0.511232583085075, 0.12170085668913089, 0.2920334186637774, 0.08572293998440728, 0.05209776871197391, 0.21012008597608656, 0.05478595005115494, 0.08720871963305399, 0.10854634107090533, 0.26879920915234834, 0.6466332112904638, 11.86407582834363, 39.07766170799732, 51.08301490545273, 54.7672326117754, 44.3449504673481, 35.42637303471565, 23.01495462656021, 22.289446257054806, 29.110285453498363, 62.10726834833622, 81.39949813485146, 79.72733706235886, 76.05485692620277, 85.8516888320446, 61.48165851831436, 15.632425770163536, 0.19121195917250589, 0.2093954975134693, 0.1557618801598437, 0.18777406396111473, 0.028610555491468403, 0.0674709162558429, 0.049735820648493245, 0.050931112564285286, 0.03912225169187877, 0.029221547119959723, 0.06184711783134844, 0.05714682942198124, 0.03879563621012494, 0.021916509613220114, 0.02112017959007062, 0.004753777311634622, 0.029063688598398585, 0.008483465971949045, 0.025398404904990457, 0.03376370055775624, 0.04745384641864803, 0.014748606154171284, 0.026908244981314056, 0.019073725925409235, 0.07034737674985081, 0.005873507925571175, 0.013457605018629692, 0.027815945395559538, 0.06603342815651558, 0.026123453499167226, 0.015785141549713444, 0.01968058008060325, 0.053538114079856314, 0.011302293132757768, 0.05059983268438373, 0.053479176422115415, 0.06294731836533174, 0.047135012355283834, 0.0829687483201269, 0.15425724996021017, 0.09199716776493005, 0.12478892575018108, 0.1135058245563414, 0.08672949261381291, 0.13117745169438422, 0.17690666194539517, 0.10430468508275226, 0.1158844969177153, 0.1180212662438862, 0.16654225793899968, 0.17428478779038414, 0.2249329083133489, 0.22176600090460852, 0.15705510217230767, 0.12866182340076193, 0.13736473687458783, 0.09442364185815677, 0.13065071980236098, 0.11679506016662344, 0.16719960782211274, 0.0704506465990562, 0.13434119755402207, 0.17514081060653552, 0.09394517925102264, 0.1191334190662019, 0.08796499780146405, 0.13703618809813634, 0.1442774714087136, 0.10113391108461656, 0.2002852488658391, 0.19698941556271166, 0.07844051942811348, 0.3948538232361898, 1.1791122355498374, 42.72707708179951, 112.43505477905273, 118.59710812568665, 106.30786076188087, 85.73765695095062, 76.46990865468979, 92.9070894420147, 62.5275219976902, 47.03577607870102, 59.46813516318798, 79.38602417707443, 114.4225837290287, 86.08089253306389, 70.93989059329033, 56.872771829366684, 50.8005228638649, 16.670064590871334, 1.7229825141839683, 0.7187223492655903, 0.2298401965526864, 0.38919482845813036, 0.7619574386626482, 0.19639415375422686, 0.27523410448338836, 0.18241915677208453, 0.4191846598405391, 0.2176776874694042, 0.36599760758690536, 0.24508955015335232, 0.1552382652880624, 0.3013828466646373, 0.8014660561457276, 0.5812838429119438, 1.0017734952270985, 2.5360444793477654, 3.826638339087367, 6.297696093097329, 5.704024024307728, 4.986249664798379, 5.7945845648646355, 7.021253742277622, 17.198021560907364, 13.065116330981255, 14.21594062820077, 13.930985368788242, 33.05624641478062, 39.79986235499382, 32.60537400841713, 32.66934737563133, 20.790759176015854, 19.731983989477158, 19.863895811140537, 12.693191338330507, 7.573310444131494, 5.022051343694329, 3.5249711014330387, 6.92191899754107, 12.687142062932253, 14.216995071619749, 15.105915572494268, 8.277609776705503, 5.643262909725308, 5.6977196875959635, 11.75682183355093, 5.929556647315621, 5.5158262979239225, 2.51716376747936, 0.781186306849122, 1.4590379898436368, 1.0334276966750622, 0.49839247833006084, 2.3721915716305375, 8.437128067016602, 1.0124616092070937, 0.9474758931901306, 1.1376002943143249, 0.16286059690173715, 0.1755367760779336, 0.2489904416142963, 0.25485550111625344, 0.6446786317974329, 0.2664060500683263, 0.20486320165218785, 0.33235759707167745, 0.34237127692904323, 3.1970370607450604, 27.039480172097683, 57.539005279541016, 63.13589595258236, 71.55083701014519, 84.64865058660507, 94.80102941393852, 58.09893563389778, 36.405173912644386, 26.903779953718185, 53.187148198485374, 72.04267501831055, 74.62760031223297, 75.24167776107788, 98.03159326314926, 69.53597992658615, 14.919738862663507, 0.2249042020412162, 0.2529287966899574, 0.2449914233875461, 0.29107405920512974, 0.14102475688559934, 0.14530675602145493, 0.2720491628861055, 0.21354252967284992, 0.15027001703856513, 0.12079079810064286, 0.22132225596578792, 0.1885988423600793, 0.11122967247501947, 0.15918246848741546, 0.13138415466528386, 0.11867381443153135, 0.20851820474490523, 0.13827940420014784, 0.18367035838309675, 0.1424245216185227, 0.2142998468480073, 0.09597250405931845, 0.10623376438161358, 0.09856015036348253, 0.1776367868296802, 0.14226018043700606, 0.1004676851152908, 0.12799264368368313, 0.16340739646693692, 0.11128740414278582, 0.12494367838371545, 0.15000487735960633, 0.16875063709449023, 0.08693088922882453, 0.09223786109942012, 0.13159115449525416, 0.14160127204377204, 0.14620047993957996], [0.051886134169762954, 0.04270410499884747, 0.05095809334306978, 0.07034630063571967, 0.0229892247079988, 0.04143827565712854, 0.008637490373075707, 0.029853888481738977, 0.05332817163434811, 0.005391295617300784, 0.02482224412233336, 0.01093450422558817, 0.03822457954811398, 0.08309728829772212, 0.04498484355281107, 0.06186621329106856, 0.013025662083236966, 0.0344121966190869, 0.030002197418070864, 0.03496456229186151, 0.026131138438358903, 0.03503823158098385, 0.037217151184449904, 0.015574824319628533, 0.0156392130520544, 0.03152098594000563, 0.036276991086197086, 0.049298640005872585, 0.0598572455055546, 0.05612669177935459, 0.03614589812059421, 0.15309905429603532, 0.05880957418412436, 0.09157806212897412, 4.417164176702499, 48.601189479231834, 99.14994925260544, 81.44906267523766, 85.74889674782753, 61.48593708872795, 67.81756773591042, 47.19476714730263, 21.558331288397312, 45.73585823178291, 52.3102730512619, 63.306658789515495, 60.32106399536133, 41.5009930729866, 52.39689700305462, 48.91194820404053, 15.20262798294425, 0.8483811293262988, 0.600821147672832, 0.09754314829478972, 0.03601119460654445, 0.07328347623115405, 0.06349970630253665, 0.28826310066506267, 0.03774033932131715, 0.21321804786566645, 0.0945936085190624, 0.14276350499130785, 0.131430865440052, 0.1504802971612662, 0.10953224715194665, 0.23720923316432163, 0.3518279897980392, 0.4894785722717643, 0.9039857424795628, 3.9231595722958446, 5.737041877582669, 4.14648000150919, 12.978017404675484, 7.35290564596653, 5.4451358411461115, 3.0307373218238354, 10.820258539170027, 10.82936380058527, 4.782672263681889, 8.591526132076979, 7.027322016656399, 6.793144857510924, 18.671719282865524, 14.909641854465008, 11.512577589601278, 15.128089282661676, 13.611701801419258, 20.70952333509922, 18.870579712092876, 30.839110985398293, 17.672228515148163, 8.834697883576155, 11.576954685151577, 4.799923337996006, 4.467666316777468, 2.93955503962934, 1.3923110766336322, 2.4853720609098673, 4.767567599192262, 4.0370463486760855, 5.845743594691157, 3.3888892410323024, 1.7964893323369324, 0.8598805591464043, 1.1979665863327682, 0.9433868376072496, 0.5767133412882686, 0.2472668481641449, 0.2312247472582385, 0.15050481772050261, 0.5096921813674271, 2.3846817389130592, 0.1501538115553558, 1.6864512744359672, 0.09773154248250648, 0.18141773238312453, 0.14471162779955193, 0.06294609382166527, 0.07278307573869824, 0.1482255189330317, 0.08201491786167026, 0.035162326093995944, 0.6412983569316566, 1.4054342661984265, 24.065197370946407, 58.56384068727493, 66.24063715338707, 53.677975460886955, 53.4320754557848, 66.19915097951889, 47.8943058103323, 29.752010218799114, 21.994756869971752, 42.25978195667267, 53.28437738120556, 51.76599785685539, 69.89639818668365, 65.46428561210632, 23.22897244244814, 0.8505974791478366, 0.3437060443684459, 0.10864771844353527, 0.09187365212710574, 0.06549570505740121, 0.002660001759977604, 0.03822051628958434, 0.025978443409258034, 0.018896445399150252, 0.022031195549061522, 0.04665164786274545, 0.014778875574847916, 0.02386256182944635, 0.02870198066375451, 0.033079202912631445, 0.01984584152523894, 0.05588318199443165, 0.013671363030880457, 0.06665210472419858, 0.057013179757632315, 0.029364247275225352, 0.04954112562700175, 0.02147300030628685, 0.041702302114572376, 0.062246122397482395, 0.028521462518256158, 0.03342841679113917, 0.029242811506264843, 0.03129417818854563, 0.021199606089794543, 0.022214172058738768, 0.004686348556788289, 0.023611925571458414, 0.031682892877142876, 0.06998380602453835, 0.0353201809048187, 0.03871612250804901, 0.04459962437977083, 0.058307014041929506, 0.03328812861582264, 0.015899042664386798, 0.02105208197463071, 0.03173174845869653, 0.05007365740311798, 0.04531381906417664, 0.04883920235442929, 0.03850661792967003, 0.029397951911960263, 0.02642241099238163, 0.1324979550554417, 0.020343670475995168, 0.08117175646475516, 0.046178153934306465, 0.056590975655126385, 0.027616220468189567, 0.0424363455385901, 0.045268228932400234, 0.020305713333073072, 0.04229784964991268, 0.0376084448362235, 0.049044695624616, 0.11813131190137938, 0.014781035224586958, 0.030117176502244547, 0.055997587769525126, 0.04636220655811485, 0.021159474454179872, 0.06421609403332695, 0.19943747873185202, 0.08035632912651636, 0.24528311711037531, 8.674090001732111, 69.84049558639526, 115.44437929987907, 93.97073596715927, 108.41205105185509, 89.68168571591377, 105.496756285429, 66.93511068820953, 28.44940021634102, 33.07160519063473, 24.13647774606943, 48.85259538888931, 46.246657222509384, 46.04220159351826, 59.13336552679539, 47.94437192380428, 11.379293091595173, 0.5877458117902279, 0.37766042863950133, 0.10531906737014651, 0.12104389272280969, 0.13811991666443646, 0.16744705470046028, 0.3784889919916168, 0.31555457215290517, 0.6862260773777962, 0.4075991705758497, 0.7923616853076965, 0.9174579195678234, 1.0368661559186876, 0.9859911014791578, 2.7003906480968, 3.5731888515874743, 2.979896762408316, 5.525557100772858, 6.048114085569978, 7.642302392050624, 8.537410385906696, 10.274869054555893, 10.718000326305628, 7.87256671115756, 6.724813124164939, 13.359652776271105, 13.905255049467087, 15.142399314790964, 14.720907881855965, 12.23799666389823, 13.887250665575266, 21.131323501467705, 22.74457063525915, 14.578434526920319, 15.48138577491045, 14.645664319396019, 20.505569279193878, 21.91404540091753, 12.312187682837248, 6.311543025076389, 1.62759029539302, 1.7941946117207408, 1.7073159548453987, 4.488717662170529, 2.6100227097049356, 4.548540227115154, 6.077709747478366, 11.188401784747839, 10.412142388522625, 13.657192960381508, 10.190785266458988, 5.726779103279114, 4.339664485305548, 4.186271941289306, 2.976653161458671, 1.3004736858420074, 0.7165675680153072, 0.5955824756529182, 0.19738826056709513, 0.7100123260170221, 0.23232233914313838, 0.48478336015250534, 0.7153953902889043, 0.19842309644445777, 0.19051085226237774, 0.12337844440480694, 0.09722373535623774, 0.1585289480863139, 0.1808821689337492, 0.17513655067887157, 0.0826280060573481, 0.387569495360367, 0.4985517729073763, 17.791783399879932, 58.373611494898796, 75.03651157021523, 53.12151812016964, 33.29327009618282, 31.026490330696106, 19.446668699383736, 22.233072482049465, 34.38225366175175, 69.39309239387512, 87.56913587450981, 71.83949992060661, 84.222571849823, 82.57962360978127, 40.368289053440094, 1.345689359586686, 0.521140432683751, 0.20120680332183838, 0.15319329220801592, 0.18432132579619065, 0.037531621419475414, 0.06781727657653391, 0.021683577288058586, 0.05926708967308514, 0.01158246965133003, 0.034903698760899715, 0.019726899372471962, 0.019256008527008817, 0.03494968594168313, 0.06273977676755749, 0.07677638684981503, 0.022249837820709217, 0.0246087505001924, 0.11611269990680739, 0.01848728454206139, 0.002735460320764105, 0.009807260757952463, 0.04531429774942808, 0.03169190626067575, 0.018030693026958033, 0.026961638795910403, 0.04190313469734974, 0.03755557794647757, 0.028049584616383072, 0.08502733238856308, 0.006798971644457197, 0.08408913156017661, 0.04554041901428718, 0.056503461601096205, 0.0032168507004826097, 0.0410494941752404, 0.014812034733040491, 0.1777873537503183, 0.12463919003494084, 0.21615805104374886, 0.15943433856591582, 0.11532964505022392, 0.10813297965796664, 0.10390946918050759, 0.1456251967465505, 0.1311128996894695, 0.10776803595945239, 0.08230476363678463, 0.19102616992313415, 0.18949802848510444, 0.1493921157089062, 0.1454351475695148, 0.17382109392201528, 0.13978407892864197, 0.12559684255393222, 0.11476449959445745, 0.16875209170393646, 0.1819807998253964, 0.10886483374633826, 0.16326110431691632, 0.07216695215902291, 0.16661151516018435, 0.13465013878885657, 0.12672729673795402, 0.17614661366678774, 0.11445362877566367, 0.1508473337162286, 0.1669393217889592, 0.29758115066215396, 0.26221929816529155, 0.39841322286520153, 9.192429687827826, 77.62548744678497, 133.61861407756805, 100.68436771631241, 107.61779487133026, 81.96808442473412, 85.26211246848106, 57.25295662879944, 26.96800220757723, 62.031682804226875, 75.14952510595322, 82.333974391222, 87.87933602929115, 61.88226342201233, 72.36819595098495, 70.0163121521473, 23.591127209365368, 2.3130959551781416, 0.7623618794605136, 0.17542978806886822, 0.5899463687092066, 0.3819799656048417, 0.2801069273846224, 0.6636936427094042, 0.20956068474333733, 0.4583539970917627, 0.31360800785478204, 0.6044761359225959, 0.3533371619414538, 0.7722121977712959, 0.6159395270515233, 2.4172809021547437, 3.048188122920692, 2.6787714706733823, 5.241861948743463, 8.807988166809082, 13.399889767169952, 15.003997441381216, 26.668939255177975, 19.87258594483137, 14.477687682956457, 14.165090806782246, 26.761587783694267, 22.443641982972622, 24.413418285548687, 22.246499061584473, 18.131031095981598, 24.60666261613369, 40.806671530008316, 32.99729637801647, 23.24935644865036, 24.963024593889713, 24.79056514799595, 37.265117168426514, 36.434097960591316, 45.706113427877426, 30.892855301499367, 24.94759362190962, 27.71181419491768, 11.604338865727186, 14.597357511520386, 7.526628999039531, 5.360139152035117, 3.248914727009833, 6.5593690518289804, 5.274676037952304, 8.032619822770357, 5.903063043951988, 2.674997798167169, 2.0922425435855985, 2.7752019837498665, 3.149187178350985, 2.0007258793339133, 1.900193605106324, 2.0357690239325166, 0.2803181722993031, 3.810898158699274, 6.606202963739634, 0.5992135964334011, 4.188283458352089, 0.42629835312254727, 0.3705000691115856, 0.2871481573674828, 0.38890322379302233, 0.39437107101548463, 0.5276499583851546, 0.2582284138770774, 0.23095500626368448, 0.7612991239875555, 4.4808397348970175, 36.509079337120056, 78.4187176823616, 83.70456844568253, 76.09983891248703, 77.57459297776222, 86.52546107769012, 61.05691730976105, 39.34832878410816, 28.606896065175533, 54.55128639936447, 72.99772337079048, 70.41089817881584, 91.27016767859459, 96.00868061184883, 41.5987466275692, 0.8472578739747405, 0.5822144960984588, 0.3127961576683447, 0.32089325599372387, 0.2646176819689572, 0.13758649060036987, 0.12493214540882036, 0.1659884673426859, 0.16555284149944782, 0.12395961282891221, 0.16360552021069452, 0.07514151715440676, 0.07817903111572377, 0.12307293189223856, 0.12724579079076648, 0.1458195800660178, 0.1305736106587574, 0.08467792184092104, 0.18989662115927786, 0.14318657369585708, 0.12595915904967114, 0.19049563823500648, 0.16835300921229646, 0.09971856125048362, 0.09581856036675163, 0.10773823873023503, 0.17064026382286102, 0.16055018728366122, 0.14429249247768894, 0.1591552613535896, 0.16853228240506724, 0.14674058533273637, 0.13885421241866425, 0.12006122982711531, 0.13907893473515287, 0.11822110434877686, 0.09933572437148541], [0.022618748298555147, 0.08838327223202214, 0.044284745963523164, 0.028343517769826576, 0.03620470219175331, 0.047603775092284195, 0.06884122514748015, 0.03848411230137572, 0.04723061210825108, 0.04592093297105748, 0.07875889335991815, 0.0175348567427136, 0.023963440107763745, 0.007646180065421504, 0.037097186723258346, 0.03529471781803295, 0.05324670237314422, 0.00999487383523956, 0.056433239587931894, 0.06523628733702935, 0.03982570378866512, 0.013472352420649258, 0.023200267387437634, 0.017517323503852822, 0.11282798397587612, 0.05195314639422577, 0.03360237991728354, 0.054636552013107575, 0.08457129748421721, 0.10875690320972353, 0.0291526554065058, 0.02293993497005431, 0.053478326663025655, 5.5767949763685465, 79.4437126815319, 93.35366427898407, 83.36993560194969, 78.49390804767609, 62.31114260852337, 41.74661949276924, 28.245202973484993, 44.72662478685379, 68.2445128262043, 73.742665797472, 82.76099547743797, 50.87093688547611, 61.474750488996506, 82.97611713409424, 36.25697046518326, 1.3168379827402532, 0.8021003846079111, 0.06394024516339414, 0.24684778705704957, 0.09195573366014287, 0.12135648532421328, 0.03452364864642732, 0.03985754563473165, 0.11239160856348462, 0.16498765151482075, 0.7084624248091131, 0.20427519804798067, 1.13585215061903, 0.3666574659291655, 1.6328032594174147, 0.89367012726143, 1.1372008407488465, 2.203781045973301, 2.1644685929641128, 7.401537811383605, 16.8972771987319, 9.725650325417519, 7.521864054724574, 13.823697175830603, 8.826099894940853, 9.82031274586916, 8.705420270562172, 6.548807518556714, 7.365674385800958, 12.04579347744584, 9.541792441159487, 14.224260281771421, 3.744618077762425, 5.057188058272004, 21.622023470699787, 19.869956485927105, 15.741603411734104, 8.96568825468421, 9.734220765531063, 13.907629922032356, 20.269793830811977, 9.470952842384577, 4.5777046121656895, 3.6013256292790174, 1.2763873720541596, 8.597754947841167, 34.4728560000658, 55.35196043550968, 64.37979340553284, 68.03156465291977, 72.96889051795006, 65.1170602440834, 65.37685990333557, 58.304272815585136, 52.3221892118454, 43.92638012766838, 36.80495046079159, 23.53487692773342, 13.61551109701395, 4.74868593737483, 1.6036749724298716, 0.4557246866170317, 0.3213858342496678, 0.21340144739951938, 1.646144106052816, 0.18495624797651544, 0.12595760053955019, 0.10656192724127322, 0.09075684603885747, 0.09623594422009774, 0.07605049220728688, 0.037103565482539125, 0.22448686271673068, 0.5369145737495273, 0.1589244237402454, 0.1926625016494654, 4.322528354823589, 38.2540825009346, 76.33488669991493, 58.16767014563084, 50.15414334833622, 62.90708743035793, 67.2864094376564, 38.278705179691315, 25.388117283582687, 24.730585366487503, 29.62554730474949, 44.430347084999084, 66.10040947794914, 68.57463911175728, 34.18494164943695, 3.0375558184459805, 0.18473486532457173, 0.015669457425246947, 0.02765621851722244, 0.040150779313989915, 0.0160048988982453, 0.08200820884667337, 0.05395363143179566, 0.020523778584902175, 0.045680506809731014, 0.06923324239323847, 0.04188051032542717, 0.02267694566398859, 0.02249544602818787, 0.029402657128230203, 0.03957798231567722, 0.052844131787423976, 0.046550804836442694, 0.05765797250205651, 0.03920722389011644, 0.017336482524115127, 0.07983996503753588, 0.033738727288437076, 0.08048806776059791, 0.03718914253113326, 0.04944513253576588, 0.040578252665000036, 0.03845863808237482, 0.020702651017927565, 0.035695755868800916, 0.06455245020333678, 0.02791991657431936, 0.05993218015646562, 0.051939361001132056, 0.0036407673087524017, 0.07062745586154051, 0.06582328904187307, 0.05084717195131816, 0.026073634981003124, 0.01985608130780747, 0.03345994322444312, 0.057595116304582916, 0.029844812015653588, 0.010931802808045177, 0.03584848986065481, 0.12607297481736168, 0.10196491610258818, 0.0182553170088795, 0.025173558278765995, 0.01737046546622878, 0.06381643266649917, 0.07649674560525455, 0.021618429709633347, 0.039728367410134524, 0.11585201311390847, 0.03205119850463234, 0.047244675806723535, 0.02913082698796643, 0.0484856432012748, 0.04677407625422347, 0.08674918921315111, 0.05090119659143966, 0.026628078667272348, 0.014293464610091178, 0.021703014135709964, 0.021154650494281668, 0.04518431058386341, 0.14774469629628584, 0.21102878643432632, 12.68893176689744, 100.18815994262695, 106.04290097951889, 97.8879913687706, 106.27868592739105, 86.93798214197159, 67.65894904732704, 35.49771420657635, 30.59600193053484, 37.87901982665062, 58.88182282447815, 68.4463731944561, 50.14745190739632, 74.37312796711922, 90.51872000098228, 34.00608904659748, 1.015768856741488, 0.48717803321778774, 0.16778707707999274, 0.06619829626288265, 0.06833171850303188, 0.09688858888694085, 0.026919733427348547, 0.11959763985942118, 0.2157197831547819, 0.821175598539412, 1.8362348433583975, 1.1112254345789552, 2.8900033235549927, 2.6687889313325286, 2.1691611036658287, 1.7602205160073936, 3.8535273587331176, 2.603430775925517, 0.43709897669032216, 2.2384114377200603, 4.321704749017954, 2.9704317077994347, 2.4791653314605355, 3.6072637606412172, 2.0093958266079426, 1.7139690415933728, 4.542437279596925, 5.107232797890902, 7.917883079499006, 13.119244426488876, 13.090343177318573, 14.346465524286032, 11.38020884245634, 14.788084477186203, 30.11611618101597, 26.10972136259079, 17.1956504881382, 12.119243536144495, 10.504944808781147, 18.25916212052107, 13.909521270543337, 3.953208834864199, 1.5242326352745295, 2.373350984416902, 1.8655128660611808, 13.55579350143671, 47.59145826101303, 69.93655443191528, 78.68153437972069, 80.33566921949387, 82.6710695028305, 79.6136623620987, 79.38362270593643, 76.00786104798317, 70.62665060162544, 62.6408015191555, 56.29211738705635, 41.63275480270386, 28.84623382240534, 14.867619909346104, 8.861479796469212, 2.334853825159371, 1.2267942144535482, 0.4729810747085139, 0.391772129223682, 0.4065158130833879, 0.029442777631629724, 0.1827039336785674, 0.06653872682363726, 0.0654761865735054, 0.05955014479695819, 0.04121905265492387, 0.14641757297795266, 0.40227871388196945, 0.09993657455197535, 0.29160095436964184, 0.5829040403477848, 33.04488122463226, 82.62215852737427, 66.20643898844719, 42.227004915475845, 46.921508610248566, 41.83248348534107, 9.137173052877188, 18.191404156386852, 37.67384223639965, 55.89895248413086, 69.16825845837593, 84.73302125930786, 80.60208052396774, 52.23841890692711, 5.437673991546035, 0.3291367058409378, 0.12020986716379412, 0.12795041548088193, 0.06710493355058134, 0.06253470652154647, 0.05563710437854752, 0.011144144245918142, 0.02490219569153851, 0.02135030103090685, 0.053945170948281884, 0.010554690670687705, 0.08117603865684941, 0.05915099551202729, 0.019239967004978098, 0.045627881117979996, 0.02691178317036247, 0.09867084168945439, 0.017613984527997673, 0.056579420415800996, 0.011532160388014745, 0.04254971230693627, 0.019953274822910316, 0.02878764491470065, 0.07931690677651204, 0.03305149482912384, 0.02415727238258114, 0.05766852213128004, 0.02445862330205273, 0.029752167865808588, 0.09516118821920827, 0.032493778271600604, 0.03977597247285303, 0.053567907598335296, 0.013588376077677822, 0.041012331130332313, 0.19255116465501487, 0.279799826676026, 0.16366904805181548, 0.10480224314960651, 0.11773343168897554, 0.15513765974901617, 0.19700644043041393, 0.17327426467090845, 0.12816071044653654, 0.13954668072983623, 0.17062702390830964, 0.08173611524398439, 0.06959921767702326, 0.14144390705041587, 0.13597062730696052, 0.16053647239459679, 0.16294824454234913, 0.13679602910997346, 0.1498507332871668, 0.20307757949922234, 0.12483884260291234, 0.10505997619475238, 0.11987015648628585, 0.11368880848749541, 0.1855301359319128, 0.11925021084607579, 0.13459703070111573, 0.1190624623268377, 0.14881197887007147, 0.19254791404819116, 0.14681570552056655, 0.1934984716353938, 0.24367843056097627, 13.415844161063433, 113.49812373518944, 118.43666553497314, 103.58226701617241, 101.07468277215958, 79.97651249170303, 50.206918716430664, 35.475356206297874, 59.606645330786705, 96.7043548822403, 100.32262712717056, 112.56935477256775, 73.52685257792473, 82.27088257670403, 105.70074453949928, 55.78276611864567, 3.741755881346762, 0.8925539371557534, 0.2337036986136809, 0.59572389931418, 0.26721662376075983, 0.36054448457434773, 0.1997993647819385, 0.23404361709253863, 0.20943495008395985, 0.40517270390409976, 1.1919978191144764, 0.6876639439724386, 2.7828835090622306, 2.466203751973808, 3.5448480723425746, 3.4564911760389805, 8.537279292941093, 8.003068808466196, 7.103765364736319, 15.891472119838, 33.788626715540886, 26.214092262089252, 21.788209453225136, 31.91348433494568, 27.29673206806183, 25.792939960956573, 26.33050661534071, 16.82379674166441, 18.45643613487482, 26.71310618519783, 23.126495741307735, 28.240232840180397, 19.38036795705557, 18.43091670423746, 41.92020557820797, 33.19342665374279, 31.383253186941147, 18.367995880544186, 16.791325584053993, 28.43491919338703, 39.171664863824844, 29.350675754249096, 20.37094060331583, 10.825999081134796, 3.782154838554561, 8.598390463739634, 43.493860736489296, 70.83330631256104, 87.22203969955444, 91.0933555662632, 102.0516711473465, 94.97247621417046, 95.11806160211563, 87.24453449249268, 80.19581392407417, 67.65941262245178, 57.61975094676018, 37.49770648777485, 24.83025971800089, 11.457632537931204, 6.752389669418335, 1.5090905665419996, 1.22267487924546, 0.850882938830182, 2.8246891032904387, 0.8362764038611203, 0.49795401748269796, 0.2543536014854908, 0.12312589897192083, 0.21009151329053566, 0.15636662661563605, 0.19500989990774542, 0.3918556059943512, 0.5073897424153984, 0.369596162927337, 0.7688611932098866, 7.174328528344631, 52.52366580069065, 97.56816253066063, 79.06507819890976, 76.6966424882412, 88.27703028917313, 87.83000707626343, 53.44640448689461, 32.6969338953495, 29.929361902177334, 41.10991045832634, 62.798322066664696, 86.10558360815048, 96.36588424444199, 55.68220071494579, 4.613869171589613, 0.45864577987231314, 0.28751679696142673, 0.2939047588733956, 0.18111529236193746, 0.1737680155201815, 0.2249954268336296, 0.09694975669845007, 0.13546234520617872, 0.09738074411870912, 0.1176718482747674, 0.122800919925794, 0.20723547670058906, 0.1267345400992781, 0.15098743635462597, 0.3034660255070776, 0.1847608108073473, 0.24807151436107233, 0.1004046322486829, 0.12752249313052744, 0.11388013415853493, 0.15241595188854262, 0.11222685920074582, 0.1172257358848583, 0.1147576050425414, 0.10754413742688484, 0.12288490135688335, 0.14823442470515147, 0.12969033617991954, 0.19533856742782518, 0.2051588287577033, 0.09944328383426182, 0.22925977769773453, 0.16406351438490674, 0.12693385127931833, 0.22609512641793117], [0.03224265776225366, 0.032544466957915574, 0.041337235961691476, 0.03851644396490883, 0.013128788141330006, 0.054429897281806916, 0.1488494870136492, 0.1150250899081584, 0.16342578688636422, 0.07598274896736257, 0.030405317193071824, 0.14989545510616153, 0.048553382730460726, 0.07418500012136064, 0.033209887697012164, 0.03064069303945871, 0.14183297054842114, 0.04462911732844077, 0.05814163014292717, 0.04062280379002914, 0.07624550635227934, 0.02914936027082149, 0.05733075216994621, 0.022915861554793082, 0.1036042015766725, 0.08173056397936307, 0.04841725058213342, 0.021386937150964513, 0.026904758742603008, 0.008632395529275527, 0.07909804742666893, 0.2758138405624777, 6.7689985781908035, 87.9446317255497, 103.77894446253777, 98.93456161022186, 81.04914173483849, 69.27625626325607, 49.180399999022484, 39.35864143073559, 81.74660950899124, 94.89087179303169, 69.59676146507263, 63.1449356675148, 67.42895498871803, 109.39132690429688, 85.15118882060051, 19.20591551810503, 1.1738099763169885, 0.22380690701538697, 0.7986430451273918, 0.1776689663529396, 0.07488523871870711, 0.11810026044258848, 0.06225476841791533, 0.029664889443665743, 0.09315374554716982, 0.4002898174803704, 0.7007570913992822, 1.6117305401712656, 0.6495019979774952, 1.5885885944589972, 4.976495588198304, 0.775447724154219, 2.295200815424323, 4.7083245031535625, 5.940434513613582, 5.5622004345059395, 7.045400021597743, 5.982488756999373, 6.28217582590878, 5.517190899699926, 6.018571620807052, 10.240989122539759, 7.957331137731671, 5.390246361494064, 9.801374562084675, 12.914430666714907, 8.719603009521961, 7.98729395493865, 11.408033799380064, 17.022383585572243, 17.750367522239685, 14.238014593720436, 20.244443491101265, 13.655348159372807, 12.355951834470034, 9.68788605183363, 2.596782320179045, 1.5737828076817095, 1.3560516410507262, 3.7902153935283422, 1.9865272287279367, 40.765759125351906, 70.34913629293442, 63.86094644665718, 56.82815842330456, 53.76421943306923, 56.69789761304855, 57.70497277379036, 61.893708407878876, 62.188865169882774, 62.503712475299835, 61.90370947122574, 63.16874139010906, 64.55399125814438, 65.25713592767715, 64.67984810471535, 57.3397021740675, 48.41050811111927, 36.39968700706959, 22.66341269016266, 9.928560387343168, 3.012459115125239, 0.9378543344791979, 0.5819284426979721, 0.11910536588402465, 0.48164339270442724, 0.3229752177139744, 0.08485939921229146, 0.034895987846539356, 0.17589643568499014, 0.21038173756096512, 0.0721635457011871, 0.38869194919243455, 0.34795243525877595, 0.09654756460804492, 10.794068444520235, 50.15564426779747, 51.324111968278885, 24.301320500671864, 51.32152050733566, 91.949502825737, 72.46704384684563, 41.37213058769703, 15.872868318110704, 33.435671254992485, 48.542133048176765, 54.23234671354294, 71.53190642595291, 47.8962779045105, 8.018356338143349, 0.4437542601954192, 0.06637184749706648, 0.14949300326406956, 0.042828852601815015, 0.02090405690978514, 0.03387349017430097, 0.05178851577511523, 0.10201043201959692, 0.0387815688009141, 0.0733274187950883, 0.010677171012503095, 0.20932986197294667, 0.029481655037670862, 0.10582363131106831, 0.09948292936314829, 0.13661028438946232, 0.10702237792429514, 0.08115186690702103, 0.04335968857049011, 0.034411205851938576, 0.0703787399106659, 0.14382517692865804, 0.10884691830142401, 0.0985810715064872, 0.2210056409239769, 0.05415918778453488, 0.01465307690523332, 0.014738328336534323, 0.024069337159744464, 0.0350258265825687, 0.029080956519464962, 0.02149325722712092, 0.008907046758395154, 0.03943113726563752, 0.025970700953621417, 0.038668305933242664, 0.02035657271335367, 0.03053316511795856, 0.02595048485090956, 0.059308698182576336, 0.037698148225899786, 0.013429869104584213, 0.05589767613855656, 0.031991863797884434, 0.05824397972901352, 0.14860907569527626, 0.0374504007777432, 0.024532491115678567, 0.03349120990606025, 0.06434397349948995, 0.04715162162028719, 0.07237828613142483, 0.11307261811452918, 0.1074391532165464, 0.03141938221233431, 0.012568564980028896, 0.01207877348861075, 0.04526629563770257, 0.012107346174161648, 0.13685884448932484, 0.054469257083837874, 0.045354974863585085, 0.01837923155108001, 0.040704644125071354, 0.13792686921078712, 0.5404337786603719, 15.403931681066751, 111.63102552294731, 116.5655167400837, 114.12714198231697, 112.72412806749344, 92.60913223028183, 81.48791939020157, 38.01116533577442, 38.57258901000023, 72.48484209179878, 61.60291761159897, 61.68278932571411, 71.44701138138771, 117.27081969380379, 78.10805395245552, 13.593938704580069, 0.6690915499348193, 0.08812474508886226, 0.6532744830474257, 0.1548666719463654, 0.08974016309366561, 0.029619104498124216, 0.2975941530894488, 0.23446714592864737, 0.9920351521577686, 1.2174664274789393, 2.863646512851119, 4.4913271721452475, 0.9373651701025665, 1.8331697140820324, 0.31573200481943786, 0.2794169675325975, 0.44206557737197727, 0.8789712691213936, 0.8222016622312367, 0.6636942957993597, 1.1735034990124404, 1.1469130008481443, 0.35737726546358317, 1.4435694948770106, 0.8696064341347665, 1.050622130278498, 1.3196498318575323, 2.293419661000371, 1.5620085457339883, 4.2341341730207205, 7.227166593074799, 8.11598639935255, 13.9312713034451, 20.16666356474161, 21.328964196145535, 16.881701834499836, 30.31806204468012, 27.943812645971775, 23.15577507019043, 17.192808240652084, 6.545289382338524, 3.5562788089737296, 0.9325999883003533, 2.272428637370467, 4.28905357606709, 54.3407928943634, 78.2965238392353, 70.1686079800129, 62.45940305292606, 60.48472121357918, 66.40991047024727, 69.40003082156181, 74.24900382757187, 76.87738358974457, 75.22457867860794, 75.64877271652222, 77.6405194401741, 76.32606357336044, 78.85126367211342, 79.92504805326462, 79.25401166081429, 70.95443621277809, 60.49037531018257, 40.52837446331978, 23.840116448700428, 9.095512088388205, 4.141866574063897, 1.2059956742450595, 0.21813298022607341, 0.21342780848499388, 0.10077057784656063, 0.05063905147835612, 0.06520050839753821, 0.0999050481186714, 0.2546128781978041, 0.05858934928255621, 0.3597496740985662, 0.18071341939503327, 0.29653798788785934, 6.977491490542889, 50.019379779696465, 60.12473613023758, 26.329695358872414, 48.40249814093113, 77.80074164271355, 35.29858209192753, 9.705309066921473, 15.584008768200874, 54.41969946026802, 75.38347095251083, 76.39091089367867, 81.69556304812431, 65.04057794809341, 16.136869601905346, 0.21424240461783484, 0.08734744187677279, 0.026703209987317678, 0.05294861504808068, 0.07075537243508734, 0.04200179952022154, 0.06738830779795535, 0.07039262549369596, 0.09042687233886681, 0.1441329752560705, 0.08382632222492248, 0.11521210370119661, 0.08745014027226716, 0.1398245111340657, 0.1008606374671217, 0.09298662131186575, 0.081129654427059, 0.12883103307103738, 0.060372796942829154, 0.07864725208492018, 0.061119479141780175, 0.048524476078455336, 0.05070542174507864, 0.036024167347932234, 0.06300658627878875, 0.020284202182665467, 0.020415426879480947, 0.013916346906626131, 0.05075440349173732, 0.05809595466416795, 0.04191704996628687, 0.007276754258782603, 0.09826030785916373, 0.022656189648841973, 0.09431025653611869, 0.14153388503473252, 0.09800652303965762, 0.15143793483730406, 0.09654753492213786, 0.099436604505172, 0.23553944542072713, 0.16909923870116472, 0.2550387819064781, 0.19063223793637007, 0.17585343564860523, 0.39545448787976056, 0.16572166525293142, 0.18314463581191376, 0.1197283023793716, 0.1282364095095545, 0.1868801619275473, 0.22780631115892902, 0.21836694970261306, 0.21599756903015077, 0.19737469410756603, 0.10811634070705622, 0.20489239774178714, 0.1578328135656193, 0.204076376685407, 0.1669701506034471, 0.20984224072890356, 0.21691204339731485, 0.11256846235482953, 0.12446826600353234, 0.24826576409395784, 0.7067461044061929, 19.86306745558977, 128.317548930645, 125.4704301059246, 119.23804253339767, 103.8287065923214, 83.6938226222992, 64.29749742150307, 52.167833894491196, 109.01491150259972, 124.63008239865303, 96.9448059797287, 89.26873907446861, 83.10344070196152, 126.26901805400848, 99.18502897024155, 26.767384372651577, 2.338447719812393, 0.32303408486768603, 1.2507847021333873, 0.4923086485359818, 0.25443672202527523, 0.25618810148444027, 0.39315757050644606, 0.11904822051292285, 0.4456945607671514, 0.7503409869968891, 2.2435245383530855, 5.060596475377679, 2.961803558282554, 5.600466281175613, 11.759071312844753, 4.513147501274943, 8.108677491545677, 10.363353006541729, 13.39406467974186, 13.470040652900934, 18.97151179611683, 16.18431955575943, 17.738576754927635, 17.675393745303154, 15.017499066889286, 23.393492214381695, 22.36570816487074, 16.079380586743355, 23.607922308146954, 28.009324930608273, 23.27268909662962, 22.490765154361725, 28.871149085462093, 34.29734721779823, 31.238032579421997, 25.417598001658916, 41.33873037993908, 33.77878524363041, 27.539687231183052, 20.395796969532967, 8.82786300033331, 7.593427989631891, 4.39029011875391, 6.936124535277486, 3.093468868173659, 54.764348566532135, 92.07745715975761, 86.00568696856499, 77.8777027130127, 71.23856216669083, 74.45762023329735, 71.20885536074638, 76.65330961346626, 78.77374023199081, 79.72789943218231, 83.17094027996063, 89.81946632266045, 92.40240812301636, 95.05351066589355, 96.43045037984848, 89.91829141974449, 77.5665146112442, 64.8297044634819, 40.360134690999985, 19.30485650897026, 5.1095592230558395, 2.6898436015471816, 1.6872384259477258, 0.4495244286954403, 1.043336377479136, 0.659530550474301, 0.1334294691332616, 0.1263335725525394, 0.2579507912741974, 0.2952376857865602, 0.14504623250104487, 0.5478367314208299, 0.5061178794130683, 0.29591811646241695, 17.45699666440487, 68.91224339604378, 67.90297195315361, 34.4872610270977, 72.48893827199936, 121.71253055334091, 102.50766947865486, 56.514819636940956, 20.377056375145912, 43.44691425561905, 65.3912079334259, 71.54034957289696, 94.29062560200691, 74.28490430116653, 15.926817823201418, 0.42691961978562176, 0.35524299717508256, 0.3073597775073722, 0.12764846527716145, 0.12797021598089486, 0.13465319643728435, 0.1283950955257751, 0.15210243902402, 0.19812841928796843, 0.21707809151848778, 0.15741955605335534, 0.3151239186991006, 0.17693888599751517, 0.3478337510023266, 0.23435381997842342, 0.33882556250318885, 0.2962670149281621, 0.284038974205032, 0.1880166126647964, 0.21612224983982742, 0.2196906739845872, 0.32430876803118736, 0.17233705089893192, 0.15873870870564133, 0.33734750119037926, 0.2063838770845905, 0.1434077782323584, 0.11078645446104929, 0.12749132292810827, 0.20793210103875026, 0.10245522338664159, 0.20280028344132006, 0.13976464950246736, 0.11484570539323613], [0.12676588841713965, 0.048832426546141505, 0.040758683608146384, 0.026889231157838367, 0.06616864004172385, 0.07364358854829334, 0.026265151755069382, 0.01923674608406145, 0.01702838362689363, 0.1648010459030047, 0.013204008519096533, 0.006421314492399688, 0.03301292170363013, 0.06185349659062922, 0.03082498315052362, 0.0507714060950093, 0.019789800098806154, 0.057863187466864474, 0.16288171842461452, 0.0074209730337315705, 0.049034661788027734, 0.13344760722247884, 0.0663402394275181, 0.042478933683014475, 0.07252226278069429, 0.02375246236624662, 0.035721782987820916, 0.051447636215016246, 0.13727618381381035, 0.1627631380688399, 0.03702598507516086, 20.808933600783348, 81.41687080264091, 87.17002049088478, 89.86472949385643, 81.58926755189896, 59.21645946800709, 53.62749516963959, 39.09767523407936, 74.05618697404861, 94.94681999087334, 64.33530539274216, 69.9297983944416, 100.46462550759315, 122.29162707924843, 38.28931041061878, 0.49245532660279423, 0.1884054980473593, 0.0879533015540801, 0.046323885762831196, 0.10721882441430353, 0.15605185210006312, 0.10883849492529407, 0.15337908145738766, 0.07048679661238566, 0.1186771912034601, 0.4753898485796526, 0.7780375820584595, 2.569433287717402, 2.0219862135127187, 1.7898975173011422, 2.371266558766365, 4.18034995906055, 1.249426631256938, 1.7247046530246735, 3.6075387708842754, 2.242859099060297, 0.3772771538933739, 0.8081881329417229, 1.700681154616177, 0.8820547442883253, 1.1199735151603818, 0.8209929708391428, 0.5788243655115366, 0.7685099495574832, 1.1374377342872322, 1.9724315288476646, 3.363394271582365, 8.465337753295898, 11.09957680106163, 10.193609464913607, 8.597497511655092, 3.9359449362382293, 9.567937888205051, 22.083873488008976, 17.40960370749235, 16.223316863179207, 9.340427946299314, 21.091923415660858, 2.746891127899289, 1.863824212923646, 8.581637162715197, 68.97003069519997, 62.7801476418972, 48.95875409245491, 49.04768072068691, 55.61243645846844, 62.975905537605286, 69.84127074480057, 84.77768406271935, 90.65828651189804, 93.64806488156319, 92.77496293187141, 87.99341350793839, 84.27915081381798, 78.70578467845917, 70.01707971096039, 67.16353923082352, 66.77495688199997, 66.5045177936554, 65.09274154901505, 61.32177069783211, 57.01426863670349, 48.01983967423439, 29.172214530408382, 11.136963944882154, 1.967931620310992, 0.2569990907795727, 0.1262642559595406, 0.16232120397035033, 0.03651783656096086, 0.03336272930027917, 0.06937637299415655, 0.053673552320105955, 0.15850711410166696, 0.13815218524541706, 0.2877786860335618, 0.4485195904271677, 1.53093725675717, 25.571425147354603, 68.35172787308693, 84.73694264888763, 97.67692789435387, 132.1024650335312, 92.19548642635345, 60.15305981040001, 22.687343806028366, 25.703105181455612, 39.05975706875324, 49.33306820690632, 64.97107207775116, 65.01779437065125, 21.79996982216835, 0.26201369357295334, 0.1188707136316225, 0.07587587970192544, 0.016743953674449585, 0.18543321144534275, 0.18501345271943137, 0.15091739245690405, 0.07441180045134388, 0.0491567265271442, 0.11038626616937108, 0.057419913791818544, 0.1367371916421689, 0.09755133418366313, 0.06628762857872061, 0.05694046041753609, 0.08111610281048343, 0.055676953998045065, 0.16150245181052014, 0.052134434517938644, 0.04443496778549161, 0.05713832440960687, 0.06905840724357404, 0.08216283531510271, 0.0935214945639018, 0.05882007928448729, 0.11361078650224954, 0.03041131374629913, 0.07834625925170258, 0.19548885233234614, 0.05990353325614706, 0.24507215421181172, 0.11746335672796704, 0.0947794051899109, 0.15477770328288898, 0.07147978278226219, 0.03810784714005422, 0.020826680593017954, 0.03561063153028954, 0.00681065212120302, 0.04114287861739285, 0.040670620364835486, 0.11827669863123447, 0.059755010952358134, 0.10355182821513154, 0.002708715637709247, 0.07106521909008734, 0.03799286248977296, 0.04717865063867066, 0.08578745488193817, 0.02578782463388052, 0.03957646091294009, 0.06593704543774948, 0.13046579144429415, 0.1432615306111984, 0.018867436701839324, 0.029167348075134214, 0.04054944249219261, 0.10384614914073609, 0.04260228975908831, 0.028516877900983673, 0.03132741156150587, 0.020133915422775317, 0.19654363713925704, 0.00843623291075346, 32.64656759798527, 98.08897018432617, 98.06029692292213, 107.4765944480896, 107.54894256591797, 93.1718136370182, 84.03934568166733, 36.1550485342741, 36.879510059952736, 85.72591558098793, 61.33575774729252, 63.40416915714741, 107.78848931193352, 125.42653486132622, 30.07387764751911, 0.8265538536943495, 0.32359906705096364, 0.10845495300600305, 0.050228680920554325, 0.21307199320290238, 0.1303822553018108, 0.38172953529283404, 0.16682393266819417, 0.7283411175012589, 0.5334889388177544, 2.0680159935727715, 2.80515696387738, 2.255615727044642, 0.9757276147138327, 0.13976885005831718, 1.3458680687472224, 0.7437544560525566, 0.5426020966842771, 1.6455996665172279, 2.7737274253740907, 2.1465076692402363, 1.423276208806783, 1.9463959196582437, 1.8224130850285292, 0.8265990950167179, 0.615841147955507, 0.8475023077335209, 0.47668504470493644, 0.9758834657259285, 0.5857265763916075, 1.0281170066446066, 2.0124416006729007, 3.4676822880283, 8.27954862266779, 13.039713744074106, 8.505655489861965, 3.2025705138221383, 9.81382554396987, 28.03994368761778, 21.78044456988573, 19.82832781970501, 11.947485152631998, 13.184083197265863, 1.1995198717340827, 1.822527435142547, 15.13145875185728, 83.6031822860241, 70.47338202595711, 58.429692685604095, 61.131845489144325, 67.30735391378403, 76.0359339416027, 81.17019563913345, 90.98471939563751, 97.075404971838, 99.05905053019524, 100.3731644153595, 98.00657540559769, 95.4726205766201, 89.08438816666603, 85.49467518925667, 78.0804294347763, 74.86468479037285, 76.82487040758133, 75.64905390143394, 76.4634869992733, 74.30475443601608, 68.5188277065754, 51.72560602426529, 25.986765660345554, 7.482563713565469, 1.6918961447663605, 0.11360101983882487, 0.36877377424389124, 0.18983123794896528, 0.08031073157326318, 0.10000489666708745, 0.017026327877829317, 0.08188388426788151, 0.08695303491549566, 0.22819706675363705, 0.5221983196679503, 0.5545846943277866, 21.114908382296562, 63.88233929872513, 82.22096845507622, 101.98917210102081, 135.25661498308182, 75.0948840379715, 22.3409790918231, 14.42806139588356, 42.37199753522873, 63.4641033411026, 72.11571469902992, 78.3456552028656, 81.03634402155876, 35.34270152449608, 0.41357342968694866, 0.10736074531450868, 0.07414230436552316, 0.039577462812303565, 0.16248950822046027, 0.13147812540410087, 0.11600900703342631, 0.041391687336727045, 0.024018477779463865, 0.09193982943543233, 0.06864493450848386, 0.07739076638245024, 0.046324973009177484, 0.02995169797941344, 0.01519478440968669, 0.029591060592792928, 0.1011049302178435, 0.04502175055677071, 0.07519423932535574, 0.06755244117812254, 0.029256288908072747, 0.15559834049781784, 0.021677883160009515, 0.08618905325420201, 0.06195382753503509, 0.1344844320556149, 0.05126007323269732, 0.04797647794475779, 0.21223525138339028, 0.05384483629313763, 0.18204661348136142, 0.24885026476113126, 0.13534508587326854, 0.2349186537321657, 0.21571638411842287, 0.14639982080552727, 0.12301888127694838, 0.15638339915312827, 0.1463872636668384, 0.09824361695791595, 0.0937134213745594, 0.16469141584821045, 0.18765355402138084, 0.15150003775488585, 0.12714468059130013, 0.14391555567272007, 0.25550021964590997, 0.2507560554658994, 0.16504317900398746, 0.21598504157736897, 0.1783844263991341, 0.2555307367583737, 0.26626248902175575, 0.2660371136153117, 0.14323718816740438, 0.07404953590594232, 0.14105494745308533, 0.2053540135966614, 0.06915320176631212, 0.19398184726014733, 0.17553428246174008, 0.18697325693210587, 0.31525815837085247, 0.1868925557937473, 38.08236971497536, 116.3561099767685, 110.17482966184616, 111.93502441048622, 101.26487016677856, 73.54139059782028, 69.67213422060013, 49.14049454033375, 105.89410856366158, 135.57006776332855, 87.83338129520416, 91.07057198882103, 116.40832677483559, 144.51889157295227, 49.378521367907524, 1.4650933211669326, 0.6201293366029859, 0.16845388192450628, 0.31136482197325677, 0.3112785250414163, 0.385499051772058, 0.33517550211399794, 0.24223768443334848, 0.18217684555565938, 0.2503830223577097, 0.7760482106823474, 1.536263027228415, 6.072790436446667, 8.023453764617443, 5.705546792596579, 12.576819732785225, 9.005324877798557, 7.580732395872474, 8.1670081615448, 8.934252541512251, 5.820658290758729, 2.034103525802493, 2.9681615671142936, 3.2058060402050614, 1.9244751334190369, 2.6339780492708087, 3.063756600022316, 2.461419333703816, 3.3300581853836775, 5.5383871123194695, 9.451482687145472, 14.563840460032225, 17.648367695510387, 29.586587995290756, 21.924658231437206, 17.025225833058357, 10.245708469301462, 16.295159608125687, 38.15708130598068, 30.874279998242855, 24.639585949480534, 15.682344641536474, 32.498101964592934, 7.263087490573525, 3.418675842694938, 13.91295438632369, 84.58248093724251, 82.01201766729355, 66.55783653259277, 67.97545686364174, 74.7745232284069, 81.26001521945, 88.07649984955788, 100.16109019517899, 100.69591909646988, 102.14029759168625, 103.229129165411, 98.26658025383949, 93.00298869609833, 88.18776547908783, 82.7638453245163, 80.27859628200531, 80.15716999769211, 86.15302786231041, 88.03952023386955, 92.02716305851936, 91.12941563129425, 81.90123841166496, 56.70388609170914, 21.490917205810547, 4.372862353920937, 0.9864680946338922, 0.43208600662183017, 0.4763228172669187, 0.4385151428868994, 0.18872292945161462, 0.2902783581521362, 0.1438067271374166, 0.12638849148061126, 0.15399300085846335, 0.3064393065869808, 1.212244676426053, 3.006911175325513, 37.45017483830452, 88.45467835664749, 97.60943591594696, 105.55148854851723, 149.19040650129318, 127.30916664004326, 85.78396886587143, 32.214572578668594, 34.81623977422714, 53.91732081770897, 70.26527479290962, 86.46669343113899, 93.15864354372025, 35.55073656141758, 0.557055986719206, 0.291979598114267, 0.14890062098857015, 0.0966264029557351, 0.2708283002721146, 0.20449515577638522, 0.30433683190494776, 0.17924528801813722, 0.1449322237749584, 0.247620674490463, 0.20449306291993707, 0.20162607223028317, 0.1076943778025452, 0.09951562838978134, 0.1467213488649577, 0.1427297224290669, 0.2135040270513855, 0.24648927035741508, 0.16604072938207537, 0.1577027892926708, 0.13514846126781777, 0.209004845819436, 0.22089532809332013, 0.21124874416273087, 0.1306037270114757, 0.2105564984958619, 0.13697436719667166, 0.1781737752025947, 0.3267593099735677, 0.08544228199752979, 0.2564103895565495, 0.2677819918608293, 0.18835476483218372], [0.24398697103606537, 0.2923860278679058, 0.12950623902725056, 0.12544358905870467, 0.11114681910839863, 0.0525253162777517, 0.0213964125214261, 0.07560943384305574, 0.12020464244415052, 0.06455385286244564, 0.02318151146027958, 0.07417718530632555, 0.12176365722552873, 0.05817431432660669, 0.06868478041724302, 0.04901520267594606, 0.07380027818726376, 0.05661031973431818, 0.07734070110018365, 0.07621652548550628, 0.06328322924673557, 0.04965085587173235, 0.040548310716985725, 0.11490071337902918, 0.054121701905387454, 0.0680854739039205, 0.12184087769128382, 0.04546794829366263, 0.09474836857407354, 0.1003701520676259, 31.42660316079855, 94.8227870464325, 96.80489748716354, 88.94666075706482, 93.03252071142197, 56.21542990207672, 32.6995025575161, 38.89906749129295, 83.14558804035187, 93.01586240530014, 51.55493438243866, 72.79667615890503, 121.74513280391693, 82.50289812684059, 7.5182803720235825, 0.807745634810999, 0.12043177674058825, 0.14234748668968678, 0.21173666173126549, 0.23774957604473457, 0.2300702771754004, 0.02400044359092135, 0.09437972155865282, 0.1258607057388872, 0.6196152954362333, 1.4105318114161491, 2.1149066649377346, 2.950540012679994, 5.224748617038131, 6.630450887605548, 1.9224043632857502, 2.038540025241673, 1.1251850542612374, 4.857930550351739, 10.79025724902749, 16.11227922141552, 19.793732576072216, 23.65557175129652, 21.763073801994324, 26.369230337440968, 24.033983945846558, 19.52752646058798, 18.441459238529205, 10.756633803248405, 5.10279986076057, 1.5293128439225256, 0.3221407765522599, 0.3247760538943112, 1.5483416290953755, 2.615629071369767, 7.503200406208634, 7.539111329242587, 4.768919851630926, 2.5658139819279313, 12.207216415554285, 13.888871278613806, 9.888324346393347, 7.203499563038349, 2.3097625840455294, 0.644267660100013, 6.419777842238545, 75.64700201153755, 61.14552095532417, 59.8554065823555, 69.48589861392975, 78.80006521940231, 84.30973917245865, 84.40777391195297, 84.6764574944973, 83.31010401248932, 84.03069734573364, 87.6981009542942, 87.5621822476387, 90.28284385800362, 91.97081208229065, 94.52942758798599, 97.60906353592873, 90.79938054084778, 87.87378832697868, 81.21304973959923, 73.8752406835556, 67.93599978089333, 60.89075222611427, 61.68652452528477, 62.329738810658455, 58.843608275055885, 43.53244386613369, 19.562741070985794, 2.7267574332654476, 0.2754325547721237, 0.24513865064363927, 0.14836786285741255, 0.1449752238113433, 0.05137528794875834, 0.01923787971463753, 0.2645860071061179, 0.029953588600619696, 0.23486909311031923, 0.22047651931643486, 0.18754810967948288, 4.332639137282968, 42.57977798581123, 75.7958172261715, 64.24849525094032, 45.85810147225857, 70.14001831412315, 65.62917396426201, 28.469487838447094, 27.91964214295149, 27.420348934829235, 47.82164990901947, 63.51348549127579, 76.93981423974037, 22.45999440550804, 0.16786559630418196, 0.0691798522893805, 0.06230444778339006, 0.14266294398112223, 0.18768077599816024, 0.08295884064864367, 0.015268228271452244, 0.07862518803449348, 0.08258387795649469, 0.03265323241066653, 0.07896498034824617, 0.07390110637061298, 0.04638205900846515, 0.008843578289088327, 0.04007117655419279, 0.09310966939665377, 0.09679704497102648, 0.039469832845497876, 0.12188401131425053, 0.08005886149476282, 0.04538837150903419, 0.024907151382649317, 0.03580691474780906, 0.03384739626199007, 0.07422417067573406, 0.06467854851507582, 0.11505263100843877, 0.04678733843320515, 0.08674831347889267, 0.08755152506637387, 0.1139321512891911, 0.18417736398987472, 0.22792472824221477, 0.17701814736938104, 0.19970583933172747, 0.0798228065832518, 0.11347432038746774, 0.08231464904383756, 0.026140645350096747, 0.08406872992054559, 0.01160344181698747, 0.04405995685374364, 0.019297826693218667, 0.12644614151213318, 0.14838485803920776, 0.040948365422082134, 0.13210577453719452, 0.018026043471763842, 0.031216983697959222, 0.04844374896492809, 0.022342361371556763, 0.04468639257538598, 0.04026118120236788, 0.06411375929019414, 0.1463263333425857, 0.09545363893266767, 0.03334823515615426, 0.03935153079510201, 0.11948484825552441, 0.009023821839946322, 0.06798691669246182, 0.10272090483340435, 50.297954231500626, 116.15290448069572, 111.13595768809319, 119.3998758494854, 118.17533075809479, 84.24544662237167, 46.742260828614235, 32.082377672195435, 31.51371728628874, 75.93330904841423, 50.53668022155762, 75.4412354528904, 135.55237591266632, 77.68864765763283, 3.6140525713562965, 0.7796520204283297, 0.25521755043882877, 0.2697141288081184, 0.20680868241470307, 0.24526822962798178, 0.27653707831632346, 0.20965453673852608, 0.47364517813548446, 0.7279356080107391, 1.7118093324825168, 0.5795763689093292, 2.339542298577726, 1.3513403688557446, 1.6537983203306794, 2.2823249688372016, 1.0756851104088128, 2.4241428589448333, 4.805269176140428, 9.648510664701462, 16.773301251232624, 24.68845322728157, 29.847913272678852, 33.53167310357094, 30.56491579860449, 35.24250470101833, 34.63802553713322, 29.495979957282543, 29.434335865080357, 18.256336972117424, 9.83869805932045, 2.8843499394133687, 0.7842136162798852, 0.11075450500356965, 0.09334841830423102, 1.5677441004663706, 6.156472396105528, 2.1884327195584774, 2.064923197031021, 2.2875587129965425, 7.358593940734863, 15.989144928753376, 12.098485250025988, 8.665587957948446, 0.6177566014230251, 0.2595535630825907, 9.945384934544563, 87.98062339425087, 66.32863283157349, 69.02299225330353, 76.10061407089233, 86.9027428328991, 89.7275872528553, 95.52156195044518, 93.77673357725143, 93.13059344887733, 89.88594755530357, 92.7579778432846, 92.17790856957436, 93.89184460043907, 93.57507839798927, 95.7766042649746, 100.13927176594734, 95.54887488484383, 96.31723165512085, 88.56415808200836, 83.74040052294731, 77.78751075267792, 74.06884029507637, 73.91560971736908, 75.31926199793816, 76.5440882742405, 67.52743810415268, 39.23291377723217, 10.734996814280748, 1.1176740447990596, 0.09956613153917715, 0.26215250487439334, 0.12120366227463819, 0.06707667256705463, 0.0813214476511348, 0.09140085952822119, 0.07020262084552087, 0.33517063362523913, 0.14931935555068776, 0.19228250719606876, 2.3837332148104906, 42.29953162372112, 80.16430601477623, 69.89932402968407, 51.58600531518459, 73.1372518837452, 40.753238797187805, 16.36892694979906, 44.90095943212509, 49.6112322807312, 69.4150248169899, 75.63088327646255, 89.4388635456562, 38.040974736213684, 0.1619649285566993, 0.08881827467121184, 0.0881043286062777, 0.032883977255551144, 0.05912346925470047, 0.10996965414960869, 0.05442095440230332, 0.022046864141884726, 0.055791207632864825, 0.02096628970321035, 0.02677413333003642, 0.14610555925173685, 0.07423860544804484, 0.01660068577621132, 0.05909347906708717, 0.07671188679523766, 0.041415142914047465, 0.0343130679539172, 0.17860905965790153, 0.12499046337325126, 0.015080884222697932, 0.017269609452341683, 0.027529162834980525, 0.08117727062199265, 0.015658969023206737, 0.07660906223463826, 0.05064029828645289, 0.022523989027831703, 0.025826826349657495, 0.03848903645121027, 0.0896636773541104, 0.09110233062529005, 0.3523307206341997, 0.29222717857919633, 0.22828165674582124, 0.17022749612806365, 0.30345308245159686, 0.12189296161523089, 0.1387344891554676, 0.1367426835349761, 0.17036699020536616, 0.09180630222545005, 0.139637163374573, 0.15527020732406527, 0.2853655186481774, 0.11522674627485685, 0.18885421537561342, 0.10950489901006222, 0.24671249353559688, 0.21852297883015126, 0.12908285862067714, 0.26965223369188607, 0.2696082094917074, 0.17873390374006703, 0.27723573613911867, 0.2768845221726224, 0.17621264996705577, 0.17372859263559803, 0.23728334403131157, 0.09242473388439976, 0.2385854718158953, 0.22263648075750098, 62.13947921991348, 135.96155315637589, 121.01602792739868, 117.76389643549919, 113.03283870220184, 71.8345145881176, 42.51400351524353, 50.992397367954254, 115.49373865127563, 127.11487546563148, 70.54228752851486, 94.26687687635422, 143.98392587900162, 103.26348692178726, 13.3225173689425, 1.2119703786447644, 0.41302130150143057, 0.4109107225667685, 0.36112781264819205, 0.41736188577488065, 0.31112478172872216, 0.2355262203491293, 0.4005133226746693, 0.30464838549960405, 1.0643251449801028, 3.1175101781263947, 5.470751216635108, 10.848875753581524, 17.103585228323936, 15.307618249207735, 4.366881474852562, 5.29201403260231, 2.8059708327054977, 6.001338120549917, 11.905916333198547, 19.962570816278458, 24.74661860615015, 29.746259227395058, 27.391381189227104, 33.68263520300388, 32.36170068383217, 26.471064873039722, 26.12647656351328, 15.341736618429422, 7.133877798914909, 2.4477215437218547, 0.8034966909326613, 1.7386794718913734, 3.99208621121943, 9.860966764390469, 14.710554387420416, 15.22101804614067, 15.851897243410349, 9.045537170022726, 18.499307334423065, 22.418092153966427, 18.773740008473396, 15.503476839512587, 5.596979018300772, 0.8723292255308479, 9.719487056136131, 87.11931601166725, 72.44757369160652, 75.52448138594627, 83.21437194943428, 93.48901301622391, 97.95743644237518, 100.46086370944977, 99.12917196750641, 96.6173167526722, 95.08978351950645, 101.18010431528091, 98.93938735127449, 99.04974102973938, 98.97681534290314, 103.45382630825043, 106.06859520077705, 99.7181099653244, 98.57568606734276, 92.79161363840103, 85.07175028324127, 80.66831856966019, 78.75730991363525, 82.7498696744442, 89.56001624464989, 95.06548002362251, 81.1016397178173, 39.01608221232891, 5.789317572489381, 0.6122853106353432, 0.440424065454863, 0.5900965793989599, 0.2887321973685175, 0.20588133920682594, 0.1746360314427875, 0.38147349434439093, 0.18253614893183112, 0.5226156441494823, 0.36667506967205554, 0.4016578331356868, 8.42223571613431, 61.56022310256958, 95.74686706066132, 77.77027487754822, 60.61220437288284, 98.80761042237282, 94.28073853254318, 41.7373213917017, 39.54474784433842, 40.03785118460655, 67.67240032553673, 81.0308039188385, 103.3294665813446, 42.37661808729172, 0.1821965421549976, 0.1830225673620589, 0.33403253532014787, 0.29042025678791106, 0.24252439092379063, 0.24079079332295805, 0.1344822798273526, 0.1605492373346351, 0.39080395305063576, 0.1070264152076561, 0.10713973373640329, 0.21897401165915653, 0.15563206368824467, 0.07913444234873168, 0.2482423122273758, 0.24224363645771518, 0.17638773744693026, 0.1721241881023161, 0.18822564597940072, 0.3011102112941444, 0.11815208461484872, 0.14230380387743935, 0.08669784743688069, 0.16534311056602746, 0.10246446312521584, 0.13582687330199406, 0.21919393970165402, 0.08145351283019409, 0.13403529912466183, 0.15253123710863292, 0.11414700304158032, 0.15212103724479675], [0.26979879301507026, 0.025467829109402373, 0.12166204978711903, 0.10498319359612651, 0.03458026338194031, 0.011510702115629101, 0.11223566849366762, 0.13490503682987764, 0.13322515587788075, 0.16589664883213118, 0.2057292583049275, 0.14723129337653518, 0.2577978791669011, 0.05319742005667649, 0.04551520454697311, 0.051976494360133074, 0.09701513990876265, 0.10877118955249898, 0.0299422782700276, 0.1821238116826862, 0.17559690488269553, 0.17832916608313099, 0.15804931288585067, 0.19053240423090756, 0.07493200144381262, 0.1836374812410213, 0.03184564957336988, 0.09935304609825835, 0.49081271630711854, 31.178398579359055, 100.47749921679497, 90.74347034096718, 78.54976505041122, 50.19415520131588, 40.64224295318127, 40.04435643553734, 57.481157183647156, 88.10674622654915, 73.09224709868431, 54.5982176810503, 93.954206854105, 120.72687104344368, 47.16751500964165, 0.4724572371924296, 0.4647717042826116, 0.3841313032899052, 0.27541450574062765, 0.15829739801120013, 0.12105003770557232, 0.025554918283887673, 0.8627418056130409, 1.5694950940087438, 0.3584221797063947, 1.8575756857171655, 5.906754545867443, 4.302545702084899, 9.175846427679062, 5.364968217909336, 0.7449337583966553, 1.5640345495194197, 10.789948515594006, 34.880091547966, 54.23858217895031, 60.552574172616005, 66.57087743282318, 75.31273394823074, 81.6393868625164, 83.53065177798271, 87.73130357265472, 85.26563867926598, 78.52841779589653, 90.31233787536621, 94.48821499943733, 92.65416741371155, 83.6586745083332, 60.79763442277908, 39.24330621957779, 12.44460392743349, 1.181559779215604, 0.0951067368441727, 0.2667063823901117, 0.49831244512461126, 1.0753728146664798, 1.453055685851723, 2.212533876299858, 5.058227777481079, 7.540002381429076, 5.300481878221035, 0.18037060654023662, 5.258514080196619, 49.407411217689514, 70.34669682383537, 70.04626214504242, 76.98025926947594, 82.35177263617516, 95.38362175226212, 101.8324913084507, 99.14435595273972, 98.66640239953995, 98.62907320261002, 94.91227984428406, 89.59162294864655, 85.10732397437096, 81.48161172866821, 82.61813834309578, 83.19536536931992, 83.20467486977577, 85.07321700453758, 85.05832180380821, 81.0906583070755, 80.91076076030731, 76.61069110035896, 81.85930386185646, 75.48448473215103, 73.75367000699043, 65.33760040998459, 64.30651053786278, 59.39524367451668, 42.95479126274586, 17.903522104024887, 2.604494718834758, 0.16475006035761908, 0.3578949283109978, 0.08785210971836932, 0.018863731529563665, 0.11553395830560476, 0.11195898841833696, 0.0545953813707456, 0.11267504960414954, 0.18051857594400644, 0.2253066241974011, 0.890568484319374, 14.75683780387044, 51.23518534004688, 50.72130851447582, 28.430805914103985, 52.008060067892075, 75.08626610040665, 32.8647480905056, 25.437814816832542, 41.72276437282562, 54.79701541364193, 59.647196754813194, 75.13506308197975, 38.918731436133385, 1.735859310720116, 0.179580946569331, 0.2999142254702747, 0.10601451911497861, 0.12304463380132802, 0.08606196788605303, 0.008714379655430093, 0.044013828664901666, 0.06045879330486059, 0.03821998194325715, 0.4640809429110959, 0.2309219361632131, 0.31601286318618804, 0.1323320108349435, 0.11180646222783253, 0.08798093171208166, 0.041786279834923334, 0.04528710545855574, 0.0450836568052182, 0.070361321704695, 0.07417793487547897, 0.030507856026815716, 0.03766721179999877, 0.1158844523888547, 0.07444022470735945, 0.08990931339212693, 0.074926650559064, 0.13431891828076914, 0.01858558756794082, 0.02344785341847455, 0.20474615012062714, 0.04969259796780534, 0.06248279329156503, 0.08257116496679373, 0.06917909529875033, 0.07969273035996594, 0.02513635812647408, 0.15362063568318263, 0.11558428333955817, 0.08455256567685865, 0.1713954287697561, 0.17938145727384835, 0.19025329733267426, 0.21894935751333833, 0.052460816223174334, 0.026200922584393993, 0.08687998531968333, 0.11943345452891663, 0.1417929242597893, 0.017254827725992072, 0.15439974231412634, 0.11764494542148896, 0.0735767581500113, 0.18811064277542755, 0.43709045683499426, 0.08541014700313099, 0.2836575993569568, 0.03444176749326289, 0.054426624410552904, 1.2287520593963563, 49.90016117691994, 115.55036321282387, 107.46191963553429, 109.7391602396965, 78.54355618357658, 76.70725151896477, 53.48671272397041, 25.912367552518845, 34.232442900538445, 59.42946083843708, 59.894669875502586, 101.48552432656288, 130.39114326238632, 39.340759590268135, 0.40832119120750576, 0.5018504115287215, 0.22295740025583655, 0.15132867585634813, 0.07148477001464926, 0.435272284084931, 1.0539237968623638, 2.2151201125234365, 4.67818689532578, 1.012959263753146, 1.140997668262571, 0.4585029906593263, 0.1856603828491643, 1.163449832238257, 0.9510397457052022, 1.6943554440513253, 4.1388200875371695, 18.414353393018246, 47.67316907644272, 68.83361041545868, 74.45691347122192, 80.39711952209473, 90.23649394512177, 92.48893707990646, 96.23721554875374, 100.417500436306, 98.32303002476692, 91.2929892539978, 103.87440294027328, 105.18322750926018, 103.35113301873207, 95.29918268322945, 75.05663529038429, 49.73062567412853, 16.208015084266663, 2.0308349886909127, 0.08597404565080069, 0.7498478447087109, 1.0877117025665939, 1.9017370347864926, 1.0139307053759694, 3.7121568946167827, 7.4147706013172865, 10.39232550188899, 3.7023016484454274, 0.15044934960315004, 6.385808140039444, 57.74542920291424, 76.40147432684898, 76.62491753697395, 83.29607516527176, 87.83985614776611, 103.89724731445312, 109.13423269987106, 105.61206489801407, 99.65951710939407, 102.07509309053421, 100.16268610954285, 96.69675529003143, 93.14956203103065, 89.60604697465897, 90.58644756674767, 86.79751127958298, 84.20446962118149, 84.93938818573952, 87.20049485564232, 88.87205556035042, 87.09691241383553, 84.126186221838, 86.01555123925209, 84.14298892021179, 79.26167204976082, 74.8534069955349, 79.58568066358566, 81.34263038635254, 72.12772205471992, 35.96777558326721, 7.769744703546166, 0.6537482107523829, 0.26534213684499264, 0.2310116618173197, 0.058954051783075556, 0.10687586312997155, 0.12388148694299161, 0.12203203266835772, 0.033810381646617316, 0.387095381738618, 0.2921751094982028, 0.5591923033352941, 12.951674368232489, 58.391181752085686, 56.19066663086414, 31.15709312260151, 59.17498089373112, 46.55239641666412, 14.175090920180082, 40.97385875880718, 68.47220420837402, 80.23793086409569, 77.36929759383202, 87.65079349279404, 57.63998486101627, 4.663219973444939, 0.05577214928052854, 0.1447254911181517, 0.12357171450275928, 0.019384331426408608, 0.03982872804044746, 0.03344259181176312, 0.01460451076127356, 0.0962420149880927, 0.06999469333095476, 0.35575867106672376, 0.3052173159085214, 0.24647022684803233, 0.11543031738256104, 0.1150352276454214, 0.1008286360593047, 0.034091811467078514, 0.043151838981430046, 0.08791781947365962, 0.020885918820567895, 0.0588043197785737, 0.040890952877816744, 0.012063671711075585, 0.060733514110324904, 0.10083117420435883, 0.06849614132079296, 0.058427909898455255, 0.11147259225253947, 0.04974264469638001, 0.012822539974877145, 0.023743235615256708, 0.23658858990529552, 0.18286555859958753, 0.10510984109714627, 0.1945197707391344, 0.12054666862240992, 0.09573493516654707, 0.23712685477221385, 0.18139720457838848, 0.25613855570554733, 0.32133032160345465, 0.24746860843151808, 0.20680893474491313, 0.394920616527088, 0.174518401036039, 0.14855006011202931, 0.0883054432051722, 0.24453814927255735, 0.18194617121480405, 0.18609902181196958, 0.3941944398684427, 0.3045189252588898, 0.13541554537368938, 0.27459024684503675, 0.629651031922549, 0.2733801008434966, 0.48682195076253265, 0.19183460623025894, 0.19376332929823548, 2.636499688960612, 68.51001217961311, 129.98421549797058, 114.27802428603172, 107.36917421221733, 67.43129566311836, 53.187114000320435, 51.37920141220093, 78.49233493208885, 119.18783962726593, 108.40620696544647, 75.9360221028328, 113.28271329402924, 138.95159751176834, 60.97090132534504, 1.7341414466500282, 0.936389691196382, 0.4923821211559698, 0.40158335119485855, 0.39076960645616055, 0.27073327568359673, 0.33020133152604103, 1.7716835509054363, 5.200954293832183, 1.5539079741574824, 6.038709590211511, 15.764462985098362, 16.522801592946053, 21.524161621928215, 16.234207078814507, 4.63151684962213, 2.2191951563581824, 12.300983034074306, 41.92196108400822, 66.90145209431648, 80.81974804401398, 89.1415522992611, 102.66511783003807, 104.5168648660183, 108.71604233980179, 114.49595019221306, 114.19854775071144, 103.61524924635887, 112.5929743051529, 117.08177983760834, 110.58125585317612, 103.70519801974297, 78.44780132174492, 48.427854180336, 13.224168196320534, 1.1889581009745598, 2.3942567501217127, 1.3246904988773167, 1.7117568477988243, 7.241185940802097, 5.56822738610208, 6.51532419025898, 9.327671080827713, 17.686415053904057, 11.310248896479607, 1.5446332655847073, 5.753229958936572, 55.10199844837189, 80.02286240458488, 83.31713363528252, 91.18403390049934, 90.30270159244537, 102.5044472515583, 107.0562382042408, 106.33502930402756, 101.9549435377121, 109.80607464909554, 107.04156339168549, 106.56211271882057, 100.21500170230865, 97.10583373904228, 96.468965113163, 93.36070150136948, 91.55537277460098, 92.28935658931732, 93.86461526155472, 94.5146843791008, 94.14085283875465, 91.28159746527672, 93.69648188352585, 92.47787207365036, 87.36462324857712, 79.5141912996769, 87.71463006734848, 97.85704582929611, 84.32129055261612, 34.9457748234272, 4.8651444632560015, 0.46911736484616995, 0.4778835241449997, 0.3137059713480994, 0.2827267680549994, 0.22220713348360732, 0.19239234505221248, 0.4559318348765373, 0.39811888709664345, 0.46281100949272513, 0.887139702681452, 2.0591691182926297, 24.461934082210064, 73.37337881326675, 68.3369542658329, 41.671641916036606, 76.56757861375809, 106.92502364516258, 47.05553121864796, 37.382348477840424, 58.417145758867264, 74.62435528635979, 79.46740821003914, 99.80150789022446, 62.66312152147293, 3.6987533513456583, 0.30900111130904406, 0.462464367155917, 0.3483934194082394, 0.22082615992985666, 0.13559950893977657, 0.21612229436868802, 0.1251986951683648, 0.17367799300700426, 0.18512529437430203, 0.6111894850619137, 0.37027893878985196, 0.460378160350956, 0.224465147475712, 0.3312324418220669, 0.2675652550533414, 0.12210237342515029, 0.14085260831052437, 0.29579337628092617, 0.15269609779352322, 0.1786994977737777, 0.25759206677321345, 0.1523774937959388, 0.19785291922744364, 0.3662172832991928, 0.2621056605130434, 0.14635833475040272, 0.19470840983558446, 0.07412668957840651, 0.11109753308119252, 0.24594113492639735], [0.033714433084242046, 0.0965854586684145, 0.07411643309751526, 0.1487142380210571, 0.11517855862621218, 0.10419100290164351, 0.18633389670867473, 0.05575094241066836, 0.28025648498442024, 0.22864291939185932, 0.13502804038580507, 0.08201203832868487, 0.03507227389491163, 0.006349355853672023, 0.06066250913136173, 0.24599060649052262, 0.13415172725217417, 0.22293859423371032, 0.17957492033019662, 0.15293101721908897, 0.06327924391371198, 0.12768549844622612, 0.10209945263341069, 0.1756067606038414, 0.06316900529782288, 0.47236188605893403, 0.24368830112507567, 0.04716947769338731, 51.786752343177795, 99.93912130594254, 87.51772463321686, 75.19848927855492, 72.17038616538048, 55.180399641394615, 31.93874917924404, 54.39256891608238, 77.16624408960342, 65.98034352064133, 57.95726403594017, 100.50769239664078, 92.33252987265587, 26.74235511571169, 0.07093384410836734, 0.1113983106915839, 0.38730564701836556, 0.27378118713386357, 0.13109973398968577, 0.6019904161803424, 0.08473702648188919, 1.3532250677235425, 2.3842058144509792, 0.7684888725634664, 0.24687866040039808, 3.3646847773343325, 4.694297080859542, 0.724311611847952, 1.9996795104816556, 2.008725400082767, 19.55797042697668, 51.965072974562645, 83.96547764539719, 83.21268483996391, 80.82050040364265, 73.16456481814384, 74.23062041401863, 74.2893348634243, 76.56754821538925, 69.7128376364708, 75.0338289141655, 67.7178306877613, 62.69277133047581, 56.4532895386219, 60.51659770309925, 59.05912511050701, 67.79235228896141, 83.69652807712555, 94.58539098501205, 94.0890996158123, 67.56824031472206, 30.18076591193676, 6.868579834699631, 0.09849121226579882, 1.8506747810170054, 0.7615935488138348, 0.5007489456329495, 3.969688550569117, 2.190956734120846, 2.247030562721193, 1.3782192952930927, 34.35856953263283, 52.77647003531456, 65.3814272582531, 83.40387538075447, 86.93973764777184, 103.89174520969391, 106.46239086985588, 101.8799963593483, 87.90680095553398, 82.95471668243408, 78.37664633989334, 76.77033573389053, 71.75037950277328, 73.66511955857277, 72.28885620832443, 76.2145471572876, 71.810332685709, 75.24688348174095, 76.9353836774826, 88.9392739534378, 86.3999006152153, 72.34614953398705, 67.80999094247818, 67.83927977085114, 71.43083944916725, 75.19747853279114, 79.81222450733185, 78.13181027770042, 71.8171115219593, 71.11790344119072, 61.110141053795815, 37.597321942448616, 15.670020952820778, 1.7619722220115364, 0.06131495341833215, 0.188131126051303, 0.034172245432273485, 0.0972708839981351, 0.16033661202527583, 0.05108796918648295, 0.11557554083992727, 0.06526056298753247, 0.19433334324276075, 0.3145883255638182, 9.479307644069195, 75.49896195530891, 75.12658953666687, 26.836637556552887, 43.190006241202354, 85.95489129424095, 42.54591040313244, 25.60394760221243, 40.47868452966213, 54.19287443161011, 73.02730098366737, 71.5920040011406, 66.01735353469849, 8.264114800840616, 0.23446637409506366, 0.25726442341692746, 0.13050586741883308, 0.08425633743172511, 0.020799195153813343, 0.1512260368326679, 0.2445631893351674, 0.4300239938311279, 0.4020960268098861, 0.23010843840893358, 0.3029638883890584, 0.24422613554634154, 0.25171995686832815, 0.2630320092430338, 0.10697251302190125, 0.017907455694512464, 0.16520045493962243, 0.10322539455955848, 0.19502150709740818, 0.21629698108881712, 0.20990610995795578, 0.18218849727418274, 0.29043459508102387, 0.18512688257033005, 0.06318293540971354, 0.13173434446798638, 0.025987634908233304, 0.10271262246533297, 0.004145879511270323, 0.015720613664598204, 0.047557160796714015, 0.04722917605249677, 0.033171136456076056, 0.04569289696519263, 0.10661862732376903, 0.04578950232826173, 0.026108243182534352, 0.15790440113050863, 0.08040878412430175, 0.14346842654049397, 0.04306236565753352, 0.04260612295183819, 0.051703959179576486, 0.12881262780865654, 0.26087630772963166, 0.06972413597395644, 0.21000515698688105, 0.1594666368328035, 0.08851653226884082, 0.03932372623239644, 0.15946360887028277, 0.09764477799762972, 0.12246753234649077, 0.06280023211729713, 0.6799609854351729, 0.38917422643862665, 3.1789474189281464, 80.15581727027893, 115.57540386915207, 103.90514329075813, 94.39601674675941, 100.79922035336494, 79.0971788764, 33.643181920051575, 23.21523427963257, 43.30717675387859, 59.89180862903595, 66.82194516062737, 111.66893988847733, 95.7202760875225, 19.94128055870533, 0.20571260451106355, 0.10896831881836988, 0.14104825328104198, 0.0314104653079994, 0.07001881313044578, 0.7737632270436734, 0.31431206851266325, 3.6830772925168276, 3.085047332569957, 2.9795949161052704, 1.7121837311424315, 1.645775525830686, 1.1309804557822645, 0.6078993959818035, 2.318716566078365, 4.202041095122695, 30.151967257261276, 63.23243357241154, 94.19871613383293, 90.80219238996506, 87.55865603685379, 84.83830600976944, 83.60755205154419, 83.5856120288372, 84.58394005894661, 79.16073426604271, 84.28735077381134, 80.48202976584435, 75.75801685452461, 72.81678467988968, 74.46623057126999, 70.88553830981255, 78.45686763525009, 94.40507546067238, 104.71052527427673, 107.85277426242828, 81.74773424863815, 39.639408364892006, 8.567843902856112, 0.36171413899865, 0.6023316853679717, 1.1950209131464362, 3.2550749089568853, 1.9045619457028806, 1.0727098700590432, 0.9937692841049284, 2.6560589019209146, 42.613599970936775, 62.86744795739651, 72.20390036702156, 85.94485983252525, 90.0747974216938, 105.26478633284569, 106.6042448580265, 97.50691741704941, 87.18911826610565, 82.85152181982994, 78.77237230539322, 77.12384596467018, 74.12465170025826, 77.51460179686546, 78.46541717648506, 82.85540521144867, 77.0259328186512, 79.17660221457481, 79.82670933008194, 90.13231873512268, 89.37559694051743, 81.30103781819344, 75.87511897087097, 74.78315636515617, 73.51112902164459, 80.04781946539879, 83.12395200133324, 80.24768114089966, 77.56580024957657, 78.50387871265411, 82.10695937275887, 69.25799444317818, 33.49301777780056, 5.5999034363776445, 0.501538353273645, 0.11992808853392489, 0.2730316179804504, 0.06397956414730288, 0.1725793769583106, 0.11692614571074955, 0.1514407995273359, 0.08080673112999648, 0.13011304865358397, 0.47028428816702217, 5.447481265291572, 72.7293361723423, 83.41870218515396, 26.12850945442915, 45.647930949926376, 55.59680409729481, 14.043624624609947, 38.331332355737686, 66.22549116611481, 82.87524774670601, 97.57785961031914, 85.96674665808678, 84.59701135754585, 15.203976910561323, 0.1843227952485904, 0.41825851891189814, 0.09465424198424444, 0.044158695891383104, 0.05013789399527013, 0.12847367412177846, 0.16337451932486147, 0.20636002445826307, 0.15320673992391676, 0.1737786876037717, 0.1635872188489884, 0.28376912930980325, 0.13559458107920364, 0.22402733971830457, 0.11319191835355014, 0.03774480333959218, 0.14402588334633037, 0.07826847475371324, 0.07928903913125396, 0.1425979466876015, 0.07460089967935346, 0.10725217653089203, 0.2761771366931498, 0.051741482166107744, 0.04706323554273695, 0.1176148364902474, 0.028812740638386458, 0.09841756895184517, 0.03408342519833241, 0.1447324821492657, 0.1604226417839527, 0.1522442782879807, 0.18914123356807977, 0.244625648483634, 0.15763558039907366, 0.205747737782076, 0.14862093521514907, 0.5116262182127684, 0.2841184433782473, 0.27655055571813136, 0.18326545745367184, 0.13778177934000269, 0.1165275381936226, 0.22058522910811007, 0.5137112375814468, 0.2641330298501998, 0.4119755857391283, 0.3338495217030868, 0.26771706878207624, 0.10835720473551191, 0.21758094109827653, 0.15080319077242166, 0.22849680535728112, 0.2296341466717422, 0.7186535373330116, 0.5656060623005033, 5.779663240537047, 103.41725707054138, 132.20607787370682, 109.86925765872002, 99.11020338535309, 85.20665064454079, 66.91605851054192, 40.57714484632015, 74.26786601543427, 113.83005112409592, 100.07781386375427, 77.61724188923836, 116.29906743764877, 110.12421637773514, 35.063834488391876, 0.5657872057054192, 0.21961705293506384, 0.868619674583897, 0.6688608904369175, 0.23705461411736906, 0.5846285540610552, 0.11085770805948414, 2.241977071389556, 8.230032529681921, 5.9589314460754395, 3.9145722705870867, 15.105722732841969, 15.512253418564796, 5.88905462063849, 2.4864744767546654, 1.6556204413063824, 24.315738826990128, 61.64066098630428, 104.10283908247948, 103.6751264333725, 103.60767245292664, 89.82196658849716, 94.88639563322067, 91.76361680030823, 93.08042094111443, 90.79743504524231, 97.82562911510468, 92.17701941728592, 83.72917592525482, 80.4550664126873, 81.20731964707375, 76.20750233530998, 85.01868233084679, 102.18876779079437, 115.98831251263618, 114.92931693792343, 86.22672110795975, 37.54434138536453, 7.626511389389634, 0.5063081067055464, 4.8592315055429935, 3.7018136121332645, 4.327098084613681, 6.420377260074019, 5.476802866905928, 3.9687982108443975, 2.3829409573227167, 40.269425958395004, 65.03743171691895, 76.73339411616325, 92.63686314225197, 89.94808182120323, 106.6600714623928, 109.28146719932556, 103.55149626731873, 91.47278800606728, 92.71453097462654, 88.1982909142971, 85.48631563782692, 80.96858605742455, 82.68851816654205, 82.35674276947975, 89.13081407546997, 85.50161361694336, 90.55240899324417, 90.66310465335846, 95.31985357403755, 95.50016149878502, 90.04164800047874, 84.03101652860641, 81.65729910135269, 81.4069077372551, 88.67316663265228, 93.44799041748047, 90.31736120581627, 83.59201088547707, 87.09780916571617, 95.55580571293831, 77.93705552816391, 33.405573070049286, 2.8123502153903246, 0.31458942394237965, 0.40639208222273737, 0.36233971011824906, 0.20434102654689923, 0.4360334307420999, 0.25892217352520674, 0.2703554928302765, 0.2963663142872974, 0.4379941552178934, 0.9807567636016756, 11.686628200113773, 90.2509331703186, 95.20795717835426, 39.54291254281998, 63.6919467151165, 114.17713209986687, 51.91460408270359, 33.41639868915081, 52.070274129509926, 77.10281789302826, 94.09642562270164, 92.44836285710335, 97.05186143517494, 16.1684725061059, 0.9277430770453066, 0.47642297751735896, 0.27679585036821663, 0.20463687629671767, 0.13953041285276413, 0.36796700034756213, 0.26507956499699503, 0.3302575566340238, 0.36111955996602774, 0.2643250086111948, 0.3886946802958846, 0.49688303901348263, 0.5716497567482293, 0.5514054524246603, 0.1739947564783506, 0.1719426884665154, 0.3010761021869257, 0.2369170793099329, 0.24593999201897532, 0.38352191098965704, 0.23917921964311972, 0.18760145525448024, 0.44280469708610326, 0.17571066127857193, 0.13468758756062016, 0.22178097744472325, 0.11750791527447291, 0.2900309854885563, 0.15220193134155124], [0.052538945819833316, 0.04090186244866345, 0.045380864685284905, 0.04275100873201154, 0.12517896888311952, 0.1179332697938662, 0.0453464290330885, 0.11388105442165397, 0.15315039607230574, 0.013422795509541174, 0.055945373969734646, 0.09177280910080299, 0.05637501810269896, 0.14800446282606572, 0.05486528934852686, 0.11860028986120597, 0.07666078250622377, 0.0487831405189354, 0.03507985864416696, 0.0764849825645797, 0.04174938396317884, 0.10816754147526808, 0.03341000781801995, 0.13714464555960149, 0.17250732926186174, 0.9597684117034078, 1.8581752222962677, 51.40411667525768, 101.23560413718224, 80.27251660823822, 79.69851180911064, 66.24721840023994, 36.12226389348507, 42.324006110429764, 91.11708149313927, 89.53021064400673, 50.66175431013107, 61.08461022377014, 90.89860081672668, 70.10810762643814, 8.637013491243124, 0.27576423541177064, 0.03302735276520252, 0.21803559560794383, 0.059521868970477954, 0.7747184601612389, 0.07710655350820161, 0.11455444953753613, 1.3015852449461818, 16.28622818738222, 2.3783902265131474, 1.3337558624334633, 0.49309292051475495, 0.7503780943807214, 1.0007360321469605, 5.716468831524253, 31.54477681964636, 68.36356043815613, 77.96281054615974, 79.8864421248436, 72.77280583977699, 64.39291790127754, 62.984918653964996, 70.52252098917961, 68.67674723267555, 78.32562267780304, 76.72204032540321, 76.46315261721611, 76.81193590164185, 75.78596815466881, 73.73224675655365, 74.27383169531822, 74.17816042900085, 80.15988305211067, 78.7690056860447, 71.81125983595848, 69.15153935551643, 72.34047263860703, 79.42603603005409, 96.26215741038322, 84.26927134394646, 49.192654341459274, 15.088546704500914, 2.258765045553446, 0.17455081804655492, 3.3310903050005436, 3.2392789190635085, 1.0484913946129382, 4.295100476592779, 51.14894896745682, 42.742063477635384, 56.809832006692886, 79.43305045366287, 82.18342646956444, 80.97202867269516, 74.81272637844086, 65.73561385273933, 65.6570416688919, 67.97972023487091, 68.40956836938858, 68.49384784698486, 72.45969504117966, 71.54569208621979, 70.99526882171631, 69.72841680049896, 69.9410305917263, 70.6539635360241, 72.99349799752235, 69.89363193511963, 69.45385873317719, 80.65647080540657, 78.30471619963646, 76.95417746901512, 64.95428457856178, 66.99283719062805, 67.4929891526699, 70.18976524472237, 75.77023699879646, 77.72521689534187, 75.6637667119503, 72.15777084231377, 55.43614111840725, 33.463523760437965, 11.838779635727406, 0.9235580172389746, 0.23319467436522245, 0.18969086813740432, 0.14630218385718763, 0.03901401687471662, 0.06404189713066444, 0.24736301566008478, 0.05486133370141033, 0.019601222229539417, 0.7438410201575607, 1.1109748855233192, 50.027594938874245, 101.03750556707382, 50.7757405936718, 35.729311779141426, 81.78298875689507, 46.825430765748024, 25.961358323693275, 26.186937019228935, 41.2272709608078, 57.96378828585148, 56.1546977609396, 64.6095822751522, 11.059360709041357, 0.7672704441938549, 0.04003888570878189, 0.009008340639411472, 0.08263364637969062, 0.11843892469187267, 0.13054190611001104, 0.16696033941116184, 0.1724978446145542, 0.12706283654551953, 0.3099535539513454, 0.39436741964891553, 0.38549076940398663, 0.3422319906530902, 0.09604137536371127, 0.0982219165598508, 0.07074025488691404, 0.11776888408348896, 0.0854666021768935, 0.280156770022586, 0.25287545111496, 0.1986700386623852, 0.08202622077078559, 0.057005698909051716, 0.05629705177852884, 0.028620411212614272, 0.0691229072981514, 0.15262246190104634, 0.04972424685547594, 0.06752488523488864, 0.08584091177908704, 0.05364089040085673, 0.04204075856250711, 0.07499938103137538, 0.03387579454283696, 0.03973649021645542, 0.04463249410036951, 0.13757399283349514, 0.0827595368900802, 0.05504006883711554, 0.03917397938494105, 0.07298478405573405, 0.1516636071028188, 0.07385020246147178, 0.08996923439553939, 0.033919091438292526, 0.05326658450940158, 0.010060800668725278, 0.17129137966549024, 0.10538264716160484, 0.07279086828930303, 0.02221012364316266, 0.2660545986145735, 0.13645968778291717, 0.702129352139309, 5.459153763949871, 74.8023909330368, 112.62893557548523, 100.36972180008888, 108.28378513455391, 91.77187755703926, 57.42971554398537, 32.63824984431267, 30.163885317742825, 70.52103146910667, 52.39997863769531, 66.47324547171593, 104.4388322532177, 70.56906849145889, 5.279873684048653, 0.3915340482490137, 0.11611819179961458, 0.11137180117657408, 0.09866105276159942, 0.18185580731369555, 0.06911431322805583, 0.3224246925674379, 1.1817608121782541, 4.309053802862763, 0.8110600663349032, 1.3958203070797026, 0.5146924161817878, 0.2558342454722151, 2.1306530199944973, 11.813827324658632, 45.89827671647072, 84.97069090604782, 87.66275525093079, 85.44484466314316, 77.95432180166245, 72.72971615195274, 73.37209448218346, 83.84481132030487, 81.85811072587967, 88.61790999770164, 89.19474184513092, 86.14728257060051, 88.83702144026756, 87.0363436639309, 88.15458565950394, 88.33123818039894, 89.33025777339935, 94.72118809819221, 90.89140400290489, 84.29129496216774, 78.6890883743763, 79.22300532460213, 86.32196679711342, 106.97221711277962, 92.88413867354393, 60.81241562962532, 20.601880811154842, 3.46815821249038, 0.3674122894881293, 1.7306779325008392, 2.4033451499417424, 1.6048599150963128, 10.748771075159311, 63.23216758668423, 50.22332243621349, 62.158561795949936, 81.17362305521965, 80.96603259444237, 77.927016466856, 75.2300351858139, 70.12064695358276, 68.97147461771965, 72.03762888908386, 72.10615441203117, 73.73021766543388, 77.226592451334, 75.2660420536995, 73.72828736901283, 75.01918449997902, 77.406155616045, 77.9975938796997, 77.88151010870934, 74.12842869758606, 74.02366831898689, 86.48630797863007, 82.82977938652039, 82.61631444096565, 74.68663394451141, 74.69479590654373, 72.89753794670105, 74.52169239521027, 76.07354432344437, 79.27448496222496, 77.92046561837196, 82.85119503736496, 83.69140595197678, 58.296228647232056, 21.6925210878253, 3.0710966186597943, 0.10444647239637561, 0.41701539186760783, 0.12970011768629774, 0.07792344287736341, 0.04138633274124004, 0.2095696350443177, 0.0975624960847199, 0.0824283980182372, 0.47497858002316207, 0.10493988927919418, 46.981507390737534, 109.20927867293358, 52.27321743965149, 41.867920383811, 48.74902434647083, 13.705567214637995, 33.30256059765816, 46.97253607213497, 69.96882990002632, 83.39135125279427, 64.27671253681183, 77.54634529352188, 21.189281791448593, 0.6063361361157149, 0.014189877492754022, 0.07162834590417333, 0.12196080133435316, 0.019331642652105074, 0.11464085037005134, 0.12557935755467042, 0.0540171184547944, 0.07784662317135371, 0.20745365327456966, 0.24757501756539568, 0.3369074669899419, 0.23389134323224425, 0.0400025872659171, 0.0896685903717298, 0.12342321075266227, 0.14084368769545108, 0.1135663318564184, 0.16313780390191823, 0.1977213067584671, 0.122807339503197, 0.011958268187299836, 0.04221294424496591, 0.056949637073557824, 0.028367936283757444, 0.03605465477448888, 0.04940789527609013, 0.05227874884440098, 0.25240914488676935, 0.1160976936807856, 0.17118308547651395, 0.16291220585117117, 0.23832284059608355, 0.29683508444577456, 0.09835999313509092, 0.13477047061314806, 0.18573305394966155, 0.28838077560067177, 0.11282467399723828, 0.23682238126639277, 0.22287108848104253, 0.25855296989902854, 0.12363680827547796, 0.17524796188808978, 0.2530485496390611, 0.12271228522877209, 0.09966621015337296, 0.32095152942929417, 0.16705227666534483, 0.32325827283784747, 0.19560143613489345, 0.2809586457442492, 0.2520030119922012, 1.2279354594647884, 7.347601130604744, 97.42344349622726, 128.6873146891594, 103.95522460341454, 105.16044393181801, 83.98334428668022, 50.98031781613827, 58.41234661638737, 121.06512129306793, 127.3754046857357, 71.47894486784935, 80.59923827648163, 110.00212132930756, 90.80149322748184, 11.875364072620869, 0.8260165387764573, 0.16061441274359822, 0.2967559121316299, 0.2659917832352221, 0.5909136543050408, 0.17122666438808665, 0.3983674175105989, 3.4439634857699275, 30.033672004938126, 5.947884963825345, 6.366771161556244, 3.455856372602284, 3.1378732854500413, 1.4341239142231643, 6.900092493742704, 40.19776940345764, 91.78715273737907, 100.15570968389511, 96.28336027264595, 88.82853269577026, 83.4075079858303, 79.66267973184586, 91.32007420063019, 89.14746478199959, 98.9443726837635, 98.89153271913528, 98.22178065776825, 96.5683525800705, 96.10844805836678, 92.50589936971664, 91.14168137311935, 93.2768552005291, 98.49363327026367, 95.22705495357513, 87.47801676392555, 79.95201900601387, 85.25574401021004, 92.16373533010483, 114.43589821457863, 92.96800777316093, 55.84732845425606, 14.578945599496365, 2.8566368389874697, 1.7407795717008412, 6.211695307865739, 7.442835420370102, 2.5877886777743697, 7.701226305216551, 62.169717997312546, 57.66922049224377, 65.86150869727135, 88.43797445297241, 90.23926019668579, 85.70211365818977, 82.9830251634121, 76.73083305358887, 73.85767042636871, 79.29352954030037, 81.13126292824745, 78.59131962060928, 80.3756582736969, 80.03169313073158, 80.63732743263245, 79.90223407745361, 81.69672578573227, 83.97748500108719, 86.54938459396362, 85.75910300016403, 79.13304895162582, 86.56849756836891, 85.30014082789421, 92.59839400649071, 84.32129815220833, 81.69177085161209, 79.08332481980324, 86.91104158759117, 92.402104139328, 89.07637819647789, 83.04102525115013, 91.21814846992493, 95.74901014566422, 71.26619428396225, 21.4512587338686, 1.9358374737203121, 0.3663456451613456, 0.4224562249146402, 0.32572576543316245, 0.19853006961056963, 0.18289674364496022, 0.5688119621481746, 0.2364036615472287, 0.32345805899240077, 1.2903739465400577, 2.0365636562928557, 61.29598528146744, 121.64921075105667, 64.94565144181252, 54.62551921606064, 114.56322178244591, 60.794814974069595, 33.482423946261406, 35.4304426163435, 56.93303279578686, 75.09893462061882, 71.64162933826447, 92.61186048388481, 25.665962174534798, 0.8288503554649651, 0.13899189565563574, 0.20697401807410643, 0.19580076215788722, 0.14233981288271025, 0.45418012887239456, 0.2384931783308275, 0.29060223139822483, 0.2242640551412478, 0.2743330778321251, 0.39039847324602306, 0.6808049557730556, 0.5560220265761018, 0.4630503966473043, 0.24287661421112716, 0.17365019215503708, 0.18104584218235686, 0.2931266912491992, 0.33875039778649807, 0.46999710670206696, 0.41733813704922795, 0.13986820878926665, 0.1105853175977245, 0.1953178911935538, 0.1641345230746083, 0.3185088839381933, 0.2237136784242466, 0.1301839979714714], [0.14699152030516416, 0.09837154095293954, 0.1833834292483516, 0.11712161256582476, 0.10892255799262784, 0.03691689678817056, 0.00404249741222884, 0.25754673639312387, 0.12751327565638348, 0.024555304735258687, 0.04700585639511701, 0.03636103188910056, 0.04875013721175492, 0.00801340262114536, 0.02360324615438003, 0.05228431124123745, 0.06910424228408374, 0.046446800261037424, 0.11967405880568549, 0.07287367712706327, 0.07360187984886579, 0.026770843760459684, 0.05641496420139447, 0.03701122746861074, 0.08322861132910475, 12.145939953625202, 73.45026388764381, 95.92656701803207, 89.76543322205544, 65.76051011681557, 46.797433868050575, 34.33591514825821, 42.44401127099991, 74.89231690764427, 80.25293245911598, 32.52503491938114, 73.49605143070221, 104.63959828019142, 78.5792438685894, 6.316402964293957, 0.6394514185376465, 0.1875846233451739, 0.09830082912230864, 0.15077546413522214, 0.06019477055815514, 0.09241719366400503, 0.00928093983020517, 1.0307937255129218, 10.922944229096174, 1.7503370088525116, 1.7950899386778474, 0.4639591713203117, 0.20743541128467768, 10.17256049439311, 36.9992758333683, 78.36523935198784, 82.61274263262749, 72.20396876335144, 60.4284006357193, 65.47113284468651, 61.291455924510956, 63.78298223018646, 66.47897556424141, 64.19040396809578, 67.00439617037773, 64.88650381565094, 64.65198799967766, 66.58524826169014, 67.52737730741501, 72.65616729855537, 77.30774849653244, 82.8799518942833, 81.6685388982296, 77.89132118225098, 74.11872401833534, 79.65427458286285, 75.25242358446121, 76.15014061331749, 70.58899462223053, 65.35443350672722, 71.32541790604591, 95.12092664837837, 95.98674818873405, 54.178461804986, 12.020125854760408, 4.259456489235163, 8.067813534289598, 20.89004784822464, 25.18258061259985, 39.712064266204834, 50.44976368546486, 50.3998913615942, 50.788017734885216, 53.581263050436974, 55.80440975725651, 57.254993319511414, 62.870594188570976, 62.473887875676155, 65.8502385020256, 66.93056613206863, 70.40604203939438, 66.53036400675774, 68.26962187886238, 66.1473597586155, 67.33517602086067, 65.74105516076088, 68.19890767335892, 57.31424354016781, 49.29560221731663, 71.94589421153069, 92.11678504943848, 75.00051990151405, 81.56444728374481, 77.28057995438576, 66.07331693172455, 69.82367008924484, 66.77371814846992, 63.67689952254295, 66.41718327999115, 73.65191906690598, 75.37414625287056, 75.9142416715622, 62.744220569729805, 40.82791619002819, 20.9375187009573, 4.512026086449623, 0.150004951574374, 0.0806607655249536, 0.07830789763829671, 0.07467138886568137, 0.02884551944589475, 0.07755314829410054, 0.1993414299795404, 0.16838901821756735, 0.07323361132876016, 0.22400673769880086, 30.80195277929306, 100.53916230797768, 70.60433059930801, 43.68840649724007, 70.67427724599838, 54.302069172263145, 30.137235447764397, 32.47322849929333, 43.3071843534708, 59.931577295064926, 64.57555890083313, 58.5307140648365, 13.32190465182066, 0.33069334574975073, 0.095564092771383, 0.04486291982175317, 0.11169618650455959, 0.0823181371379178, 0.018222430589958094, 0.02880699456000002, 0.1119846296205651, 0.22516950499266386, 0.303906089393422, 0.07531695344368927, 0.14902292692568153, 0.05211525742197409, 0.16740840364946052, 0.21050667070085183, 0.07429225530358963, 0.02573599118477432, 0.08559741312637925, 0.0260084836918395, 0.08443701328360476, 0.08271169805084355, 0.0313113811716903, 0.010311711521353573, 0.05251775750366505, 0.06214983615791425, 0.26061729819048196, 0.17426057893317193, 0.13975751004181802, 0.05461411317810416, 0.11967521655606106, 0.060448410658864304, 0.05394130806962494, 0.05103247880470008, 0.07163236834458075, 0.11643125195405446, 0.03535543291945942, 0.02833493854268454, 0.04604618894518353, 0.044557477813214064, 0.03847895437502302, 0.0494295029056957, 0.007071108848322183, 0.00860136169649195, 0.03695297629747074, 0.06075140358007047, 0.058148417083430104, 0.10843027659575455, 0.05139542983670253, 0.10198382602538913, 0.03531357579049654, 0.03563774960639421, 0.027583365590544418, 21.84060674160719, 99.0970028936863, 106.30450174212456, 110.7464861869812, 86.1348344385624, 70.26917338371277, 66.56864315271378, 31.719364151358604, 36.236550360918045, 68.68216574192047, 32.295762822031975, 72.84455358982086, 110.89956477284431, 76.99421972036362, 3.9755466487258673, 0.746893621981144, 0.2429332846077159, 0.11143901007017121, 0.13432101113721728, 0.08560581423807889, 0.37338271911721677, 0.2115741017041728, 0.4584586399141699, 0.4144739219918847, 1.8335071834735572, 0.40788109763525426, 0.5486568342894316, 1.0251136240549386, 19.592763260006905, 54.17723827064037, 89.0213343501091, 90.81638842821121, 78.6033345758915, 70.25420218706131, 74.69260722398758, 72.88423866033554, 73.26659694314003, 72.89079710841179, 73.92510160803795, 77.06092894077301, 75.79661518335342, 75.24072021245956, 76.26821547746658, 79.80376616120338, 81.90569937229156, 85.27052521705627, 90.52967101335526, 89.78213712573051, 87.67370626330376, 80.92355847358704, 87.571180164814, 82.5710816681385, 84.74050685763359, 75.02468660473824, 72.54962861537933, 76.98800325393677, 100.2834740281105, 103.43156710267067, 63.475263342261314, 19.020401872694492, 6.910165278241038, 13.283322472125292, 33.016052171587944, 32.13767230510712, 41.85062751173973, 59.9539390951395, 54.1162933409214, 56.32875122129917, 59.46100294589996, 63.65615263581276, 66.02922409772873, 72.47124642133713, 70.96883744001389, 72.31778785586357, 73.06476697325706, 75.62767624855042, 72.06250995397568, 73.23267236351967, 71.73236086964607, 68.72375071048737, 69.02591809630394, 73.68268221616745, 65.27894675731659, 63.50731462240219, 79.75920215249062, 89.67875987291336, 76.78982108831406, 80.30194982886314, 80.43352916836739, 73.27961504459381, 78.09098526835442, 75.2623638510704, 72.65877395868301, 72.48964503407478, 76.01778611540794, 76.67637437582016, 79.76486384868622, 83.25204312801361, 73.21765556931496, 38.5885139554739, 10.580347012728453, 0.8571169199422002, 0.13003086321987212, 0.11963929660851136, 0.22194393823156133, 0.073041098221438, 0.03677977016195655, 0.07552318886155263, 0.13115966983605176, 0.08000755682587624, 0.32232174184173346, 27.00178999453783, 110.46040713787079, 73.85529175400734, 54.24434646964073, 41.377845481038094, 15.74526071548462, 31.754504665732384, 48.90940614044666, 65.99700182676315, 85.16039952635765, 75.71532994508743, 72.16106906533241, 24.028331749141216, 0.3633772622561082, 0.13485280447639525, 0.0883721919672098, 0.17592509742826223, 0.08700652149855159, 0.005891430328119895, 0.036308606577222236, 0.12084288202458993, 0.26233148120809346, 0.19490757258608937, 0.06955033240956254, 0.03867113722662907, 0.12579754897160456, 0.0858077897282783, 0.11599000805290416, 0.07713560116826557, 0.035648588673211634, 0.08100806837319396, 0.11165973963215947, 0.045551061411970295, 0.042312158257118426, 0.031930848126648925, 0.03748095128685236, 0.10023324066423811, 0.012649212312680902, 0.21088377077830955, 0.18194536969531327, 0.2795192354824394, 0.1672471794881858, 0.18592206411994994, 0.2494226535782218, 0.22257837059441954, 0.12940518819959834, 0.23709400731604546, 0.30813849822152406, 0.24961641349364072, 0.17842334462329745, 0.1215145034075249, 0.2049664343940094, 0.14656831801403314, 0.21828139491844922, 0.09373505497933365, 0.1961291625048034, 0.13143687683623284, 0.18461720523191616, 0.25387491623405367, 0.18160460516810417, 0.1337621739367023, 0.20630304235965014, 0.16928821918554604, 0.14697523758513853, 0.26628795953001827, 23.21814302355051, 113.51680353283882, 119.7955410182476, 113.70416387915611, 85.5719630420208, 60.591050907969475, 48.03408890962601, 62.82815806567669, 105.45056596398354, 113.0314327776432, 48.64004239439964, 88.43700930476189, 119.05389681458473, 95.43355867266655, 10.04946704953909, 1.9498543278314173, 0.3759554185671732, 0.29632463527377695, 0.25058242259547114, 0.12684611458098516, 0.265283714979887, 0.16293133841827512, 3.9602306205779314, 27.301772497594357, 6.833573263138533, 4.723982512950897, 2.2126796934753656, 0.4717807250563055, 16.231058947741985, 48.61405558884144, 95.34869402647018, 101.50098949670792, 88.78489583730698, 76.18123054504395, 84.49387729167938, 83.31309825181961, 80.48891499638557, 85.54302379488945, 82.61070594191551, 88.98093491792679, 84.3647526204586, 85.10669320821762, 86.05332881212234, 86.11449792981148, 87.12574526667595, 91.49753227829933, 97.20623955130577, 95.91697633266449, 92.44534581899643, 84.38147932291031, 87.19072178006172, 83.70078384876251, 84.3840479850769, 77.05241739749908, 72.4713072180748, 84.6569873392582, 107.60816618800163, 103.03760424256325, 60.292497128248215, 16.397837698459625, 7.134091062471271, 12.44480911642313, 29.8322619125247, 32.45746314525604, 53.01862344145775, 64.51701164245605, 60.22359162569046, 61.57522089779377, 64.42386344075203, 69.66923117637634, 69.72171396017075, 73.89180779457092, 72.95927703380585, 72.57501125335693, 73.96610140800476, 76.27703860402107, 72.90852695703506, 75.35105869174004, 75.870171636343, 76.99697837233543, 77.2145015001297, 80.54008305072784, 75.76704517006874, 69.70299616456032, 84.26163375377655, 98.31093147397041, 80.91237187385559, 80.46249881386757, 81.09564363956451, 78.76389876008034, 85.8423413336277, 83.43257904052734, 76.40180110931396, 79.91152077913284, 86.35618016123772, 84.79423597455025, 83.53135854005814, 91.47416353225708, 89.70421090722084, 48.826331198215485, 9.20132976025343, 0.4988447728101164, 0.29402935062535107, 0.3135630633914843, 0.25432649825233966, 0.30561578983906657, 0.2770194743061438, 0.3807994461385533, 0.2957769896602258, 0.3582382755121216, 0.3962195827625692, 38.03908623754978, 120.19358485937119, 86.3061672449112, 66.90440073609352, 100.02789974212646, 70.54325267672539, 40.1854732632637, 39.89558681845665, 57.78273560106754, 81.13393038511276, 82.83104851841927, 89.07459989190102, 29.08125691115856, 0.5117985152173787, 0.2797283133259043, 0.16989301017019898, 0.3016846039099619, 0.24129284138325602, 0.298087740666233, 0.27416772732976824, 0.2661218965658918, 0.43080547533463687, 0.38014632649719715, 0.21406329469755292, 0.18515309522626922, 0.26685878983698785, 0.28014914074447006, 0.3017112915404141, 0.15833918092539534, 0.12168548681074753, 0.16922719980357215, 0.26086701604072005, 0.1977975995396264, 0.18065832235151902, 0.15598966012476012, 0.143477228411939, 0.27660449501127005, 0.16756174620240927, 0.5176821432542056, 0.32022695580963045], [0.03539769822964445, 0.035196101234760135, 0.11966475227382034, 0.07361606229096651, 0.04577332721964922, 0.11207172807189636, 0.022499936021631584, 0.12079407097189687, 0.11364904421498068, 0.07721623551333323, 0.07046228347462602, 0.05586863218923099, 0.05690317862899974, 0.07713026512647048, 0.10313736100215465, 0.08846719429129735, 0.06454846487031318, 0.01428710347681772, 0.006980650787227205, 0.06299783635768108, 0.07002461672527716, 0.09190319702611305, 0.09031750945723616, 0.36365607229527086, 35.257589891552925, 91.54424697160721, 94.99434784054756, 84.20698508620262, 70.49556523561478, 51.344178691506386, 40.18867649137974, 33.48866321146488, 74.18911144137383, 61.312035620212555, 50.59705138206482, 105.69065988063812, 96.12914174795151, 55.738156512379646, 3.555939677171409, 0.2294183598132804, 0.6347377120982856, 0.1338978682179004, 0.28376895119436085, 0.33963595808018, 0.084297971916385, 0.5458044935949147, 1.1637265048921108, 1.7235249350778759, 1.498253548052162, 0.6222533632535487, 2.5645593367516994, 19.762895330786705, 59.57913860678673, 81.42345204949379, 88.36381763219833, 70.64289852976799, 59.759917706251144, 69.02606248855591, 68.83411958813667, 65.62173396348953, 68.42431917786598, 67.31371477246284, 59.691205993294716, 64.22061994671822, 61.4497060328722, 67.72790014743805, 73.09401020407677, 72.16290056705475, 77.84787431359291, 82.08310425281525, 82.7484941482544, 81.77877098321915, 86.56427219510078, 90.20340532064438, 87.34332159161568, 87.51113578677177, 78.31695914268494, 81.90060764551163, 82.01779335737228, 86.91966712474823, 70.39843484759331, 72.93211609125137, 72.01799914240837, 88.51890251040459, 88.24687510728836, 48.47465246915817, 57.693983763456345, 71.80885836482048, 52.03015208244324, 41.2428767234087, 54.619770124554634, 52.30732820928097, 67.41522252559662, 72.88005128502846, 72.43941932916641, 73.54285731911659, 79.66411605477333, 77.62109488248825, 84.64740425348282, 79.2662926018238, 82.31299191713333, 70.30140325427055, 75.80250486731529, 58.36459077894688, 58.28496225178242, 67.02939882874489, 67.53708958625793, 64.78824108839035, 75.64887911081314, 72.86075592041016, 70.05291938781738, 59.40827317535877, 65.19151344895363, 83.61651957035065, 73.36580201983452, 75.56817904114723, 65.62998712062836, 68.35327818989754, 64.80189755558968, 70.23217856884003, 65.78307330608368, 72.08039939403534, 74.79945749044418, 69.53984051942825, 48.72631296515465, 29.294702857732773, 12.294931858778, 0.5358718265779316, 0.17357248929329216, 0.10357715029385872, 0.16376074781874195, 0.07679091810132377, 0.06081848630856257, 0.13324501574970782, 0.05315343296388164, 0.06647277958109044, 0.251440464053303, 20.62445729970932, 91.2054343521595, 85.07988184690475, 51.93636931478977, 73.3143375813961, 59.84656445682049, 36.21770337224007, 40.46983860433102, 39.55427773296833, 56.22622512280941, 60.38813419640064, 71.29193410277367, 30.809312984347343, 1.0576567403040826, 0.09921499178744853, 0.1587710515013896, 0.08837559842504561, 0.10674354562070221, 0.0679985387250781, 0.09364683588501066, 0.11861947437864728, 0.034012308897217736, 0.026351393025834113, 0.21272257523378357, 0.11637109346338548, 0.15751073631690815, 0.09164226532448083, 0.14994143857620656, 0.11109838655102067, 0.06509027720312588, 0.1370899789617397, 0.08404992389841937, 0.025522740615997463, 0.04571029290673323, 0.018423680630803574, 0.0643109182419721, 0.02948341021692613, 0.06469210755312815, 0.10804819670738652, 0.046520933392457664, 0.044036894614691846, 0.01962231963261729, 0.0459513387613697, 0.03494654294627253, 0.08707945977221243, 0.09007543572806753, 0.034618409772519954, 0.04697778094850946, 0.05799490012577735, 0.03762009655474685, 0.05128491291543469, 0.0337229195429245, 0.03857969350065105, 0.013343455284484662, 0.03655240579973906, 0.04410712776007131, 0.040750983826001175, 0.017028836336976383, 0.029164941661292687, 0.06710938643664122, 0.12902877089800313, 0.13661867065820843, 2.0671686390414834, 52.60745130479336, 107.6426151394844, 103.76548558473587, 103.23353692889214, 93.62588167190552, 74.83589753508568, 60.90862266719341, 20.114091485738754, 40.09338140487671, 69.03623074293137, 54.519903883337975, 98.18287074565887, 102.45665341615677, 56.8619804084301, 1.4742769533768296, 0.06940923529327847, 0.41648098616860807, 0.15979897056240588, 0.11264751592534594, 0.36851874261628836, 0.2248285771929659, 0.4744080168893561, 1.3002160121686757, 3.217082410119474, 0.3265727043617517, 2.399839125573635, 5.2381153497844934, 33.50007399916649, 81.82746157050133, 95.11085718870163, 94.20355707406998, 76.00543677806854, 69.42436471581459, 79.96537908911705, 78.1497985124588, 74.41471293568611, 78.97819206118584, 76.67484685778618, 71.57763317227364, 72.86995902657509, 73.36558163166046, 78.16893428564072, 84.23551395535469, 84.46192100644112, 88.71933415532112, 93.0055421590805, 91.89287826418877, 91.75331175327301, 93.31736102700233, 100.76160237193108, 95.50136983394623, 92.34049424529076, 85.79355955123901, 87.34901368618011, 88.59019428491592, 94.53714117407799, 78.87575715780258, 79.77459132671356, 80.05532026290894, 94.33185338973999, 95.81963315606117, 59.172028452157974, 70.453911870718, 83.78514692187309, 54.960532039403915, 43.82211372256279, 61.55810281634331, 60.56791014969349, 77.20891579985619, 80.64625695347786, 79.87223848700523, 80.0302492082119, 83.39768171310425, 83.78973707556725, 87.36523881554604, 85.12885361909866, 88.90733286738396, 78.99536713957787, 82.08720803260803, 60.74981778860092, 62.52132073044777, 75.09080305695534, 73.64485144615173, 75.27142256498337, 83.252894282341, 81.56019911170006, 76.58251941204071, 66.98753267526627, 70.9894323348999, 81.07389360666275, 72.7640663087368, 75.09135022759438, 69.5898762345314, 73.94723162055016, 73.0630874633789, 73.54959055781364, 71.92530691623688, 74.94289219379425, 74.52427625656128, 79.35311794281006, 77.87506565451622, 51.61432519555092, 20.6624286621809, 1.8728638091124594, 0.3157998964888975, 0.0661305827088654, 0.15565084002446383, 0.0727029015251901, 0.05277267780911643, 0.10516645212192088, 0.02593400546174962, 0.05165050599316601, 0.374247677391395, 18.26678641140461, 98.908950984478, 90.67362248897552, 58.7003293633461, 52.84205451607704, 19.513718001544476, 29.228599704802036, 58.39255727827549, 58.890744745731354, 80.09540051221848, 73.51466283202171, 84.24205720424652, 47.21825748682022, 1.082984518725425, 0.17606968263862655, 0.16277508664643392, 0.14688322611618787, 0.07417906293994747, 0.036180604656692594, 0.01500177406342118, 0.13147925346856937, 0.13150589657016098, 0.017914953241415787, 0.11307784283417277, 0.0710185083153192, 0.049644324972177856, 0.07017350639216602, 0.09040767297847196, 0.03449843788985163, 0.09493024670518935, 0.0384666978061432, 0.05720977467717603, 0.03080811042309506, 0.04715067167126108, 0.04771519743371755, 0.03227454413718078, 0.03207842419215012, 0.027899047381652053, 0.027253150692558847, 0.20518042525509372, 0.08334840880706906, 0.1722224781406112, 0.130365438235458, 0.18994156562257558, 0.20629965816624463, 0.20628852595109493, 0.21378402452683076, 0.29790279746521264, 0.2033198461867869, 0.22671792190521955, 0.11412500578444451, 0.18986331357154995, 0.19262033281847835, 0.17419920332031325, 0.12724813597742468, 0.12206466490169987, 0.10948123192065395, 0.11392740154406056, 0.2150224315118976, 0.1458673446904868, 0.21607494534691796, 0.16754500335082412, 2.0723308995366096, 61.548360139131546, 128.0443587899208, 116.59577071666718, 111.53329476714134, 91.9331257045269, 63.1684336066246, 52.45001435279846, 44.879722371697426, 104.07711446285248, 88.29010158777237, 66.34632468223572, 134.42813783884048, 109.88555118441582, 71.63297340273857, 6.148876128718257, 0.4531083785695955, 0.7165602059103549, 0.17277856939472258, 0.24898254516301677, 0.6045570003334433, 0.19572524121031165, 0.6131760065909475, 7.329729739576578, 9.745073933154345, 6.880294131115079, 2.9286140017211437, 3.3919927245005965, 32.326263785362244, 87.025977820158, 107.08535984158516, 107.13873937726021, 86.05649784207344, 76.86074048280716, 88.21817144751549, 88.56845945119858, 87.67301470041275, 88.49792003631592, 84.47426274418831, 80.32079681754112, 81.33132979273796, 78.99592950940132, 84.90539520978928, 92.42066994309425, 90.46897307038307, 95.09538441896439, 98.28510046005249, 98.7745749950409, 96.33249163627625, 99.87848415970802, 103.74088570475578, 94.99415025115013, 88.9954349398613, 83.55976581573486, 82.45286241173744, 88.72238159179688, 90.7254821062088, 78.85928124189377, 81.58909276127815, 77.7875867486, 99.80346098542213, 96.32069706916809, 56.62432216107845, 65.9961886703968, 89.77918088436127, 65.75082063674927, 53.82839418947697, 67.22527831792831, 65.16479328274727, 76.90937027335167, 81.92963048815727, 78.1941269338131, 80.24002835154533, 82.62466639280319, 83.38970974087715, 87.97263622283936, 85.56151360273361, 90.2810351550579, 78.88974040746689, 81.14360466599464, 71.26256927847862, 66.7456528544426, 72.58327960968018, 75.31280994415283, 77.86219954490662, 86.54123023152351, 86.21417418122292, 86.30560487508774, 74.70064759254456, 74.37744453549385, 83.37672963738441, 72.39127591252327, 77.77324631810188, 74.69489470124245, 78.3533687889576, 76.94452598690987, 79.003377109766, 76.94790780544281, 82.40767523646355, 81.64960831403732, 82.10121408104897, 91.95178270339966, 70.50202488899231, 24.930004365742207, 0.8801451092585921, 0.5705756018869579, 0.22703894530422986, 0.37304248893633485, 0.30853251926600933, 0.19302780157886446, 0.380551420385018, 0.21517798566492274, 0.20533931907266378, 0.8636925858445466, 28.28884933143854, 109.69083443284035, 101.44561126828194, 70.69093555212021, 103.7758818268776, 74.97576802968979, 48.36093217134476, 51.93468980491161, 51.19754076004028, 79.51300576329231, 78.48100394010544, 97.48428583145142, 54.310926496982574, 2.1748909587040544, 0.3516267490340397, 0.29041696165222675, 0.30077321687713265, 0.22071946877986193, 0.23757996561471373, 0.20833956979913637, 0.3520071442471817, 0.2480824090889655, 0.1266402131295763, 0.24322767974808812, 0.15394704707432538, 0.2571360318688676, 0.23078054218785837, 0.3150646953145042, 0.19560741784516722, 0.1465217853547074, 0.22785189386922866, 0.19150098116369918, 0.12755265401210636, 0.18569849955383688, 0.11562334999325685, 0.1788196960114874, 0.15477857901714742, 0.14729296584846452, 0.1399687846424058], [0.039042760254233144, 0.07454290083842352, 0.044884045055368915, 0.05929017046582885, 0.11227240480366163, 0.07520129714976065, 0.08437248354312032, 0.08555787149816751, 0.10334957813029177, 0.14038646535482258, 0.14303349831607193, 0.10518880560994148, 0.027966649613517802, 0.023058717561070807, 0.0750405850703828, 0.03589712650864385, 0.06085656219511293, 0.02451121930789668, 0.05399151435995009, 0.034113879228243604, 0.008831752165860962, 0.16618513647699729, 1.86241805087775, 49.08699721097946, 92.10904866456985, 87.02245160937309, 74.33210536837578, 76.46192908287048, 55.26391535997391, 40.39473943412304, 42.87122994661331, 98.03347796201706, 56.46166428923607, 39.015614837408066, 83.62283483147621, 95.80487474799156, 64.40099626779556, 3.5934220533818007, 0.23809541686205193, 0.2610395505325869, 0.0394094071816653, 0.19821535446681082, 0.14588174235541373, 0.20279284712160006, 0.22222598403459415, 0.5352431978099048, 0.6349887955002487, 2.0196574134752154, 3.071463773958385, 16.98694858700037, 54.37480106949806, 83.12747061252594, 72.89386734366417, 70.9111413359642, 61.86064638197422, 64.07231390476227, 62.65676066279411, 61.010882779955864, 55.420007184147835, 60.575391948223114, 62.53006786108017, 58.19000534713268, 61.09770432114601, 64.16841834783554, 70.7430611550808, 77.02508926391602, 82.70995661616325, 89.93077754974365, 93.88529375195503, 99.00169640779495, 98.31919983029366, 99.80001077055931, 98.28806430101395, 103.54628294706345, 99.12645131349564, 97.42817044258118, 95.19731014966965, 89.88026306033134, 89.9228435754776, 96.31904035806656, 91.185113042593, 87.58266314864159, 89.16540741920471, 72.33018279075623, 76.24459594488144, 87.7937950193882, 84.81925383210182, 72.68125355243683, 69.01530906558037, 65.94305232167244, 56.858967170119286, 64.09023374319077, 77.93672874569893, 75.89654982089996, 75.40305510163307, 79.80742916464806, 84.06077653169632, 84.30921480059624, 87.65238180756569, 87.08948001265526, 89.4845598936081, 86.75583511590958, 75.21431162953377, 56.29551440477371, 67.65245139598846, 79.16994497179985, 78.06030571460724, 83.82206574082375, 80.9868934750557, 76.82392805814743, 75.10376796126366, 66.99270039796829, 68.96715804934502, 65.6142407655716, 67.09021836519241, 72.23650261759758, 64.83805641531944, 64.63373377919197, 62.16751791536808, 62.94123239815235, 73.00486698746681, 74.595036059618, 64.65413108468056, 65.91859683394432, 67.96458944678307, 49.338828697800636, 30.404687896370888, 19.117697551846504, 2.1963626565411687, 0.2798876672750339, 0.09460406537982635, 0.014587240057153394, 0.10864739932003431, 0.06030900935002137, 0.07225543100503273, 0.11480530287371948, 0.27316063293255866, 0.058209596027154475, 18.122413158416748, 79.69046384096146, 85.14881774783134, 55.86710639297962, 63.450971245765686, 71.8484902381897, 34.57555688917637, 39.55093011260033, 44.35107573866844, 47.84520484507084, 66.71443372964859, 68.41903746128082, 44.95776258409023, 4.653063593432307, 0.18853090616175905, 0.11470355442725122, 0.06437285788706504, 0.013080863027425949, 0.05252988790743984, 0.12413899734383449, 0.09091170999454334, 0.06984534353250638, 0.05253624440229032, 0.037458419683389366, 0.04337698803283274, 0.08832415274810046, 0.1236244292522315, 0.25368489674292505, 0.12558112386614084, 0.07947715872433037, 0.0776573532493785, 0.11057417796109803, 0.04594750556861982, 0.04071137169376016, 0.024114045991154853, 0.11605988125666045, 0.011406325538700912, 0.026632036169758067, 0.045283884537639096, 0.031358963969978504, 0.04442119723535143, 0.07481584048946388, 0.02744401808740804, 0.10057545980089344, 0.015691925946157426, 0.06683689949568361, 0.070351406611735, 0.04407676278788131, 0.04393570648971945, 0.11351124223438092, 0.016734487580833957, 0.09381878408021294, 0.029278414185682777, 0.0539259790093638, 0.0368206365237711, 0.03458585175394546, 0.02975308812892763, 0.061553375780931674, 0.02539461995183956, 0.17239058943232521, 5.214889571070671, 71.96818381547928, 102.76129826903343, 100.87675139307976, 105.46656310558319, 108.32661643624306, 86.86566442251205, 52.63523541390896, 12.508769184350967, 34.91604141891003, 54.27778087556362, 37.86257050931454, 83.17821308970451, 107.85676404833794, 64.7687329351902, 1.5564520563930273, 0.14521174627589062, 0.12431660812580958, 0.06656148107140325, 0.12043421098496765, 0.16442056163214147, 0.397726587834768, 1.1752417869865894, 0.7233974640257657, 1.7857401841320097, 3.216767502017319, 6.415370078757405, 28.845470063388348, 79.50091481208801, 93.29813405871391, 80.1516754925251, 76.5149362385273, 68.81745368242264, 78.37210938334465, 77.18540266156197, 70.6842403113842, 66.38204276561737, 71.01676806807518, 72.5073216855526, 68.32162588834763, 74.2817884683609, 77.57784560322762, 78.30790802836418, 83.46793234348297, 85.62743246555328, 94.70003083348274, 99.73477587103844, 101.96571215987206, 102.7280880510807, 102.80162170529366, 101.81579500436783, 103.1408067047596, 101.60489112138748, 101.70739442110062, 96.9310051202774, 91.75880625844002, 93.30846190452576, 99.50267672538757, 99.03897240757942, 94.09792274236679, 93.46212565898895, 79.57268536090851, 80.53503692150116, 91.26140534877777, 89.68566030263901, 78.45452696084976, 67.07773223519325, 69.18549433350563, 65.74692964553833, 73.40032696723938, 84.04612451791763, 80.94115152955055, 78.75371530652046, 81.04230970144272, 88.10901090502739, 88.54759857058525, 93.65472212433815, 88.86197850108147, 91.36817961931229, 89.49453815817833, 79.82082724571228, 67.26041123270988, 77.64270052313805, 85.25851786136627, 85.30780881643295, 86.49934127926826, 82.93997347354889, 83.46385896205902, 83.80629658699036, 76.86201721429825, 73.71398493647575, 72.36770197749138, 68.96287187933922, 75.83291843533516, 68.22348475456238, 69.46326702833176, 65.76136127114296, 68.77083018422127, 74.54837456345558, 80.27247861027718, 76.49192467331886, 66.29349991679192, 70.56122571229935, 76.7053896188736, 57.9223895072937, 29.780362397432327, 5.2499873377382755, 0.3206813579890877, 0.218758566188626, 0.06803170530474745, 0.08662291278596967, 0.10185419509070925, 0.08175672468496487, 0.0956510279502254, 0.2752088417764753, 0.13191826350521296, 17.700109519064426, 87.82863155007362, 95.5852997303009, 62.76274457573891, 45.540757700800896, 26.65226384997368, 29.575954265892506, 56.678492054343224, 63.127232417464256, 71.66191264986992, 78.93201693892479, 78.00688058137894, 62.53573335707188, 7.898671785369515, 0.4927406081696972, 0.14573055203072727, 0.034101886121788993, 0.050520404329290614, 0.05037017879658379, 0.04596879407472443, 0.10386893307440914, 0.0559421307843877, 0.049741958209779114, 0.03071555904170964, 0.035962543115601875, 0.014178405745042255, 0.07346400365349837, 0.09577215387253091, 0.07185368420323357, 0.02629355003591627, 0.06163650374219287, 0.0650670776667539, 0.05791578718344681, 0.08332581041031517, 0.08727854830794968, 0.060304690050543286, 0.0355402610875899, 0.02244038609205745, 0.12249333682120778, 0.18485169421182945, 0.1287693457561545, 0.21349138085497543, 0.19139770389301702, 0.22326748439809307, 0.17436673573683947, 0.14186515007168055, 0.26686175842769444, 0.2036061222315766, 0.2673245023470372, 0.14030194957740605, 0.09653774599428289, 0.1870700775180012, 0.10461486570420675, 0.14698236220283434, 0.12710187351331115, 0.17012325406540185, 0.13653639616677538, 0.14989863149821758, 0.11674504683469422, 0.3476481547113508, 7.814029902219772, 83.43025356531143, 121.4809861779213, 105.72703912854195, 101.01798981428146, 97.49595880508423, 76.17856308817863, 56.09387442469597, 60.09879112243652, 135.6633147597313, 83.0862808227539, 52.91943736374378, 102.68487676978111, 113.77048552036285, 83.27576905488968, 5.478140395134687, 0.7504534372128546, 0.3175389562966302, 0.22735977574484423, 0.21152039989829063, 0.32109078601934016, 0.30765274772420526, 1.353788624983281, 7.488743606954813, 7.728995215147734, 6.940353708341718, 5.34025339409709, 30.945685766637325, 92.51244261860847, 110.95742046833038, 92.40162536501884, 83.07233557105064, 75.84594413638115, 89.43279907107353, 87.55053967237473, 82.29561164975166, 76.08113631606102, 79.2210142314434, 81.40363991260529, 77.93090745806694, 83.11334297060966, 83.75993147492409, 84.74156320095062, 88.18376809358597, 93.6493568122387, 100.22051900625229, 106.04856267571449, 104.30332392454147, 106.24201789498329, 105.33423900604248, 104.00522992014885, 105.597253292799, 106.84493914246559, 102.96605408191681, 96.74199566245079, 89.50899258255959, 93.1578303873539, 91.40278056263924, 94.09701079130173, 100.2513125538826, 90.2856557071209, 80.76837480068207, 82.5755350291729, 98.43892380595207, 95.31578779220581, 83.3765396475792, 78.66590961813927, 79.90643665194511, 65.95093309879303, 76.88138097524643, 83.234191685915, 83.29856783151627, 77.76633828878403, 80.91964468359947, 89.28140759468079, 90.24711817502975, 95.37977635860443, 91.63881629705429, 94.63541150093079, 90.88512673974037, 87.98664227128029, 68.86916130781174, 70.23002788424492, 88.54041695594788, 86.42926543951035, 89.80074092745781, 86.96854770183563, 86.37747421860695, 86.4934591948986, 76.44799143075943, 78.36042121052742, 77.20238775014877, 71.34854346513748, 77.25688442587852, 70.11364012956619, 73.59318181872368, 69.8841780424118, 72.93382599949837, 74.70673486590385, 79.14022296667099, 78.69316175580025, 78.94579499959946, 72.41098165512085, 82.17539370059967, 78.99889335036278, 45.41970759630203, 3.607396516017616, 0.8679212839342654, 0.37814528855960816, 0.15779211418703198, 0.41540279402397573, 0.3212177526438609, 0.325188806746155, 0.22383634059224278, 0.3709818416973576, 0.45838570164050907, 25.129558257758617, 98.11711147427559, 103.17312777042389, 73.12168791890144, 91.49443164467812, 91.99072301387787, 44.56300936639309, 48.45098353922367, 55.435544550418854, 68.901626765728, 83.09071898460388, 87.67410904169083, 77.71073207259178, 10.764327440410852, 0.5473293992690742, 0.31684849178418517, 0.14329773257486522, 0.16956103267148137, 0.15165967372013256, 0.20876406342722476, 0.31817183014936745, 0.147275154304225, 0.12350228658760898, 0.1528403119300492, 0.14479105244390666, 0.17206125397933647, 0.32491575577296317, 0.2699055435368791, 0.2992233750410378, 0.1423195967799984, 0.30685918405652046, 0.1461846276652068, 0.2091257565189153, 0.1777594193117693, 0.2234822470927611, 0.14531014021486044, 0.15276857593562454, 0.2623771084472537], [0.10488657339010388, 0.09382745236507617, 0.050453054427634925, 0.07454926104401238, 0.08772234519710764, 0.14551319181919098, 0.07887529180152342, 0.141042182513047, 0.08868306278600357, 0.13127550424542278, 0.297934502013959, 0.15576490812236443, 0.11719224276021123, 0.02412114463368198, 0.030256397840275895, 0.09464411166845821, 0.040654118711245246, 0.08688631583936512, 0.05190368967305403, 0.04078053985722363, 0.11294611904304475, 13.27822694554925, 65.59587255120277, 94.3787656724453, 85.46514317393303, 61.718397215008736, 51.69198162853718, 45.42209766805172, 33.337313532829285, 44.97856646776199, 121.8829970061779, 131.425721347332, 97.71149843931198, 116.6367781162262, 107.44278386235237, 73.72026219964027, 3.8209115713834763, 0.15353122173110023, 0.20449162315344438, 0.060360184143064544, 0.40397152304649353, 0.1524866934050806, 0.3461796522606164, 0.6957451603375375, 2.6494593685492873, 0.5743400123901665, 1.090294138994068, 6.204972993582487, 32.36399196088314, 56.44515037536621, 49.97045740485191, 48.00185903906822, 72.3798917233944, 60.57777442038059, 63.27966883778572, 59.522069469094276, 56.838402673602104, 52.016077637672424, 55.69385468959808, 60.07624693214893, 57.3392765969038, 68.01207929849625, 70.5134242773056, 76.15813538432121, 81.47040992975235, 88.58524695038795, 95.03356173634529, 98.38805213570595, 99.2272599041462, 100.12644365429878, 95.15719950199127, 96.88200294971466, 97.71883204579353, 100.5830043554306, 99.06331390142441, 98.61712664365768, 95.39640426635742, 83.20417329668999, 81.58187314867973, 85.80053597688675, 101.11798524856567, 94.3468625843525, 76.91399082541466, 77.69387617707253, 69.24834296107292, 70.96669435501099, 91.01015523076057, 78.18860203027725, 81.25914886593819, 66.4205650985241, 73.06939512491226, 87.86726787686348, 81.57440274953842, 77.5288662314415, 82.10468709468842, 90.45543819665909, 89.74492952227592, 83.76133739948273, 85.78235015273094, 86.62864834070206, 88.61604049801826, 91.10863834619522, 93.10678392648697, 91.73755019903183, 93.70161160826683, 85.24403303861618, 86.09109878540039, 79.20502468943596, 82.3188816010952, 81.09626680612564, 77.51547574996948, 72.25601077079773, 71.91377833485603, 70.70887058973312, 66.22887298464775, 68.09622198343277, 65.34036666154861, 64.25800994038582, 61.25164546072483, 65.81737786531448, 71.3410122692585, 83.17696675658226, 90.96808388829231, 72.66648754477501, 54.284335523843765, 62.92906165122986, 53.14999379217625, 29.34229340404272, 23.42648394405842, 4.491611681878567, 0.19280517211882398, 0.06224559176189359, 0.06609976131585427, 0.06474718975368887, 0.12660175503697246, 0.05877730931388214, 0.0741371835465543, 0.1852303379564546, 0.15381273318780586, 14.742660764604807, 69.74016577005386, 83.01394030451775, 64.32456716895103, 72.01185867190361, 61.633733958005905, 30.628682076931, 33.85244429111481, 35.274149402976036, 49.35888022184372, 72.18179315328598, 68.33516076207161, 58.246903494000435, 15.058369673788548, 0.35024481068830937, 0.03546511863532942, 0.048626254210830666, 0.1717346496297978, 0.20964183117030188, 0.05247407840215601, 0.1683547013089992, 0.06008148171531502, 0.04055071156471968, 0.01796250078768935, 0.04885830894636456, 0.062434598221443594, 0.11292848561424762, 0.1368011796148494, 0.08302892907522619, 0.032204912131419405, 0.23310306365601718, 0.0915378525678534, 0.20727792754769325, 0.08238329770392738, 0.028713242754747625, 0.04805103410035372, 0.03582688223104924, 0.024015084309212398, 0.0450954532425385, 0.05286751314997673, 0.07576210104161873, 0.045384182085399516, 0.0919507909566164, 0.11784123606048524, 0.044305310875643045, 0.09403365067555569, 0.07278571036295034, 0.14337363943923265, 0.10392244934337214, 0.08635529433377087, 0.08412360431975685, 0.06077311139961239, 0.030954981448303442, 0.12343150796368718, 0.0460671546170488, 0.027140284873894416, 0.044993719639023766, 0.7351752882823348, 24.74450971931219, 84.85815614461899, 103.25359225273132, 101.40135884284973, 88.2028278708458, 81.07937291264534, 60.94707280397415, 39.82672691345215, 30.59271700680256, 72.11643666028976, 131.01794242858887, 95.61217188835144, 114.85169470310211, 117.15162009000778, 75.77860414981842, 2.118770107626915, 0.09312396316090599, 0.10269444726873189, 0.11974627719609998, 0.24925041594542563, 0.06035045829776209, 0.9334684198256582, 2.3232057876884937, 1.2968453555367887, 0.6165368668735027, 3.8192812213674188, 14.403956439346075, 55.65491817891598, 75.94132661819458, 63.376331850886345, 61.251383274793625, 82.93429657816887, 73.80417689681053, 73.82265150547028, 67.58694291114807, 67.66290083527565, 64.6659104526043, 68.94658595323563, 69.9721585214138, 70.61474964022636, 79.74042356014252, 77.45021045207977, 82.61362418532372, 86.40368521213531, 92.13469728827477, 98.56291875243187, 100.42858824133873, 100.22242650389671, 103.2732068002224, 96.41188457608223, 94.19776618480682, 96.2249194085598, 100.67772567272186, 97.7449594438076, 98.63842070102692, 98.36763203144073, 85.11691465973854, 86.67140364646912, 91.09744414687157, 100.32409384846687, 99.83186826109886, 80.87547585368156, 83.74677658081055, 76.75800919532776, 77.23268732428551, 93.15861314535141, 83.35701629519463, 83.21437954902649, 71.31028711795807, 79.53085720539093, 93.85408222675323, 87.63938650488853, 79.87288445234299, 85.98138347268105, 92.73377314209938, 93.33829790353775, 86.49717539548874, 89.15748104453087, 88.77272129058838, 88.56860384345055, 91.01242750883102, 101.03415414690971, 98.0632683634758, 93.1929861009121, 87.91803315281868, 89.5504179596901, 84.2767645418644, 86.01408451795578, 85.25672435760498, 81.31828129291534, 77.60417819023132, 78.2865759730339, 74.86567273736, 71.71580895781517, 72.42650762200356, 71.102195084095, 69.8094816505909, 66.29346951842308, 67.5005279481411, 73.79603773355484, 77.20450043678284, 91.70585989952087, 97.70763024687767, 70.41057899594307, 58.824381306767464, 71.62016049027443, 61.17597632110119, 33.198199197649956, 9.914004318416119, 0.7206008734647185, 0.0375489542784635, 0.08589566001319326, 0.0665930965624284, 0.14476017910055816, 0.12110620344174094, 0.15978136681951582, 0.09765196198713966, 0.23916590551380068, 13.328179065138102, 77.94574946165085, 92.3388147354126, 70.92049643397331, 66.18266746401787, 18.457663469016552, 29.32063076645136, 56.55621461570263, 52.70558103919029, 76.79344609379768, 88.18332731723785, 75.8447813987732, 72.27119475603104, 22.742007672786713, 0.47834380413405597, 0.00931020271309535, 0.09743633097968996, 0.06472291410318576, 0.12923158501507714, 0.07802043415722437, 0.14923728886060417, 0.04588758456520736, 0.0447902746964246, 0.046424754764302634, 0.039435827638953924, 0.04992455251340289, 0.041918274509953335, 0.022815161391918082, 0.07392072133370675, 0.0615146839118097, 0.060641443269560114, 0.0371663808618905, 0.0626897114852909, 0.04647171786928084, 0.0317934580380097, 0.016637620610708836, 0.046976808735053055, 0.2809595363214612, 0.21854432299733162, 0.2033080015098676, 0.14250603911932558, 0.12046305084368214, 0.2204646449536085, 0.28762586298398674, 0.2508305967785418, 0.23537468863651156, 0.3378077218076214, 0.42066301801241934, 0.2146129886386916, 0.20042067597387359, 0.12682048080023378, 0.14076668245252222, 0.12207932973979041, 0.28666659258306026, 0.19684166880324483, 0.2114832925144583, 0.20751983800437301, 0.7210803602356464, 28.652098439633846, 103.42939361929893, 120.1583531498909, 106.63190737366676, 85.46727865934372, 66.31017342209816, 62.69598975777626, 51.18241377174854, 69.11880791187286, 152.2605049610138, 158.655364215374, 115.16838490962982, 141.10130935907364, 124.19309824705124, 94.56790432333946, 5.929334359243512, 0.39578403113409877, 0.315649151452817, 0.18596377281937748, 0.42819364985916764, 0.24248513131169602, 0.31970335578080267, 2.6948241842910647, 8.411600086838007, 7.264201305806637, 6.480891862884164, 13.062578067183495, 62.80323900282383, 90.88870614767075, 71.01253509521484, 63.668023198843, 88.48282724618912, 82.34845921397209, 87.08464667201042, 77.61880740523338, 81.99033603072166, 77.70513117313385, 77.41305604577065, 78.23146373033524, 79.71538290381432, 86.47266671061516, 86.78079217672348, 89.00895461440086, 90.61908021569252, 96.22451663017273, 101.27531960606575, 103.73137101531029, 105.19491568207741, 106.654402166605, 100.06570771336555, 100.08976802229881, 101.31289958953857, 104.16644006967545, 99.54589560627937, 98.71608093380928, 97.53850892186165, 81.51797577738762, 86.50456979870796, 92.06970557570457, 99.92044150829315, 97.91777417063713, 80.57864338159561, 83.83842766284943, 81.35315582156181, 86.96503669023514, 98.79368796944618, 90.84168747067451, 92.91202157735825, 72.55321562290192, 79.03781086206436, 92.12405025959015, 88.91297176480293, 80.5102850496769, 86.32436826825142, 92.86302700638771, 95.78957676887512, 88.6729234457016, 90.85003942251205, 92.18509778380394, 94.25731658935547, 94.74628195166588, 103.99689316749573, 92.9490315914154, 96.4265213906765, 91.85187086462975, 92.9591466486454, 86.42149865627289, 89.74917769432068, 89.35447007417679, 85.98861068487167, 81.26160353422165, 81.26853436231613, 78.37842464447021, 73.72398599982262, 74.07086938619614, 72.79821127653122, 71.80153995752335, 70.95914795994759, 72.43115097284317, 74.36105981469154, 79.76427868008614, 85.49756303429604, 87.11124524474144, 78.1463634967804, 71.3444472849369, 75.32902747392654, 76.60227075219154, 55.1643493026495, 9.027537535876036, 0.8294490014668554, 0.12456531665520743, 0.12544514756882563, 0.27015068975742906, 0.3599765931721777, 0.4534933454124257, 0.38018675870262086, 0.19910388335119933, 0.42307378083933145, 20.805707573890686, 87.21666678786278, 100.95394045114517, 78.47415670752525, 102.3384265601635, 85.33884555101395, 40.85372060537338, 43.287961184978485, 46.89985357224941, 68.83716702461243, 88.47949862480164, 82.90775880217552, 87.09392577409744, 27.16140802949667, 0.7627876347396523, 0.07670978651731275, 0.2099515442387201, 0.21211031824350357, 0.33895784290507436, 0.21490294573595747, 0.30097561539150774, 0.1911598604056053, 0.13993644184665754, 0.1024360759765841, 0.13808145857183263, 0.10857043860596605, 0.2148612221935764, 0.13335455674678087, 0.2962065447354689, 0.2509849634952843, 0.27762376063037664, 0.1605809121974744, 0.289411143749021, 0.23017349507426843, 0.15843600151129067, 0.12596899992786348, 0.25332516292110085], [0.08372110794880427, 0.09446763637242839, 0.027359493033145554, 0.08781728814938106, 0.05294908260111697, 0.10028676435467787, 0.12495515198679641, 0.09426124510355294, 0.15552381402812898, 0.1723435372696258, 0.22736756829544902, 0.18299311894224957, 0.05250339694612194, 0.11370942534995265, 0.05276620628137607, 0.01750278112012893, 0.07165587216150016, 0.08015475439606234, 0.012443568757589674, 0.08820075585390441, 29.827498868107796, 90.07200837135315, 89.80837851762772, 65.2931959927082, 59.73368011415005, 67.61308550834656, 54.63767096400261, 58.896756023168564, 59.00159999728203, 56.49305060505867, 64.97278198599815, 84.44131091237068, 94.43349793553352, 89.81606170535088, 63.25651288032532, 3.385360180400312, 0.034231999452458695, 0.35181418585125357, 0.10495565991732292, 0.1845021574990824, 0.18769219022942707, 0.2617770968936384, 0.2661983674624935, 2.001393218524754, 0.5810005206149071, 0.9773709671571851, 23.683424256742, 41.555026173591614, 69.42802771925926, 77.03434556722641, 89.51107487082481, 74.45050701498985, 64.67355564236641, 58.43519479036331, 51.78746670484543, 55.153576880693436, 50.091925486922264, 52.12095580995083, 62.000383883714676, 64.08182099461555, 71.70892372727394, 70.85301965475082, 71.92971467971802, 78.56443986296654, 83.17523404955864, 86.94205552339554, 92.2449217736721, 93.75885933637619, 95.19373834133148, 94.50723677873611, 89.91259172558784, 91.97987079620361, 91.70351922512054, 91.36102840304375, 93.72973009943962, 97.19049319624901, 98.79298880696297, 87.6079697906971, 83.413245677948, 83.45513463020325, 86.15587770938873, 93.36127907037735, 86.90013617277145, 74.85078513622284, 69.41447004675865, 59.858104437589645, 72.59644210338593, 71.6596631705761, 65.64026176929474, 79.02471676468849, 88.5863944888115, 86.45568922162056, 78.87032344937325, 77.77623295783997, 81.8526542186737, 88.86403039097786, 83.00468400120735, 84.39890518784523, 86.39863148331642, 84.6713961660862, 82.58606046438217, 87.08826407790184, 92.47625336050987, 88.98293361067772, 82.40447580814362, 86.73619017004967, 89.08960148692131, 88.72511744499207, 85.29605984687805, 86.64966121315956, 83.52822750806808, 78.79847690463066, 75.01126572489738, 64.0105976164341, 59.63303491473198, 69.81787160038948, 78.10661762952805, 72.24043160676956, 64.98029038310051, 59.692406728863716, 62.19709932804108, 66.17269679903984, 97.45183557271957, 113.32070365548134, 90.02777114510536, 52.61271022260189, 51.64932131767273, 55.092871338129044, 28.892262652516365, 29.29461546242237, 10.67902771756053, 0.1677949438453652, 0.18113311874913052, 0.1193203215370886, 0.10645682428730652, 0.15730519109638408, 0.0458923343103379, 0.027958194696111605, 0.22430883633205667, 0.38137903378810734, 15.082106050103903, 67.2767123579979, 82.54674017429352, 66.79881200194359, 72.67638981342316, 64.57504972815514, 31.24433074146509, 32.49397538602352, 35.244590789079666, 38.287881687283516, 70.82205131649971, 63.02169308066368, 67.06284463405609, 17.515348233282566, 0.4812866571592167, 0.039250034678843804, 0.022319237905321643, 0.028521015374280978, 0.09799679348361678, 0.21729508065618575, 0.14992220210842788, 0.10108965681865811, 0.05673505991580896, 0.017738461247063242, 0.030374826055776794, 0.02555373084760504, 0.036824406633968465, 0.10033084050519392, 0.15876471356023103, 0.09198327476042323, 0.12625845236470923, 0.2400672438670881, 0.11431524791987613, 0.1160776631149929, 0.068695363443112, 0.030183943817974068, 0.10637760744430125, 0.07566781117930077, 0.046018722059670836, 0.07106834353180602, 0.022248077075346373, 0.0639602608862333, 0.07367785350652412, 0.1219224842498079, 0.06353791206493042, 0.07082773183356039, 0.06091450537496712, 0.11185885785380378, 0.06127650645794347, 0.0313801893935306, 0.06308330208412372, 0.020814531635551248, 0.030895965865056496, 0.010644137091730954, 0.04119789031392429, 0.39192521944642067, 44.166584238409996, 107.37653061747551, 100.65724477171898, 83.37913870811462, 88.82476329803467, 88.82311418652534, 72.01025515794754, 34.96970973908901, 25.51913045346737, 40.25423437356949, 77.30026289820671, 94.04676988720894, 98.63021314144135, 99.84810099005699, 65.011235922575, 1.8367061368189752, 0.11443513445556164, 0.315548189682886, 0.14867180201690644, 0.05513362026249524, 0.16185651562409475, 0.13679994764970616, 1.4067900809459388, 2.9516543028876185, 1.581151681020856, 2.8167394548654556, 35.97864679992199, 61.08060523867607, 79.57795187830925, 86.73340111970901, 96.05665683746338, 85.62446862459183, 70.46905025839806, 66.50255709886551, 60.55820167064667, 64.59439069032669, 63.099053129553795, 62.663330510258675, 70.64726829528809, 73.75070616602898, 78.08615952730179, 78.3850970864296, 83.16985353827477, 84.72725316882133, 89.311942756176, 88.63809451460838, 91.71338349580765, 96.36939525604248, 97.8790694475174, 96.49681761860847, 94.49584499001503, 96.14547327160835, 94.9632503092289, 92.96128213405609, 97.48932436108589, 97.5615356862545, 98.75341013073921, 86.62631526589394, 84.86884877085686, 86.9265827536583, 94.66105252504349, 96.43302664160728, 87.07086101174355, 80.32021924853325, 77.41281285881996, 72.88152560591698, 74.81642737984657, 74.06848311424255, 66.83403611183167, 80.65517887473106, 91.0959242284298, 89.2158991098404, 80.25375321507454, 81.57032936811447, 85.25306135416031, 89.5475909113884, 84.5171320438385, 88.76560807228088, 90.1944226026535, 89.47860941290855, 85.23365959525108, 90.65794453024864, 90.67440524697304, 90.73925256729126, 85.15251114964485, 88.57403755187988, 90.71108847856522, 90.2958619594574, 86.94011762738228, 89.05137553811073, 89.99044954776764, 83.48297953605652, 79.69863340258598, 73.46705138683319, 63.987031280994415, 71.19145229458809, 80.43343797326088, 77.93179661035538, 71.26294925808907, 65.27514696121216, 74.65852305293083, 76.0767437517643, 85.24786323308945, 94.60021778941154, 104.6185702085495, 88.52764964103699, 51.80825158953667, 66.3625194132328, 60.90888865292072, 37.20303609967232, 17.243455722928047, 0.9513950860127807, 0.15505629067774862, 0.1048930746037513, 0.05748711155320052, 0.27782238903455436, 0.033090747019741684, 0.03692154634336475, 0.13406936370301992, 0.5077754810918123, 15.415014736354351, 76.76732629537582, 92.08751142024994, 74.96438384056091, 61.6193213313818, 20.40735974907875, 29.916887171566486, 49.38387908041477, 54.78512965142727, 59.122456312179565, 90.15521630644798, 70.41984289884567, 80.58397829532623, 26.75177101045847, 0.4894285515183583, 0.05187513183045667, 0.09179114756989293, 0.061875824103481136, 0.09102717333007604, 0.09941722702933475, 0.09445852279895917, 0.10899408618570305, 0.06427306128898636, 0.026966507284669206, 0.06069970186217688, 0.029229065075924154, 0.0357365257514175, 0.10586148826405406, 0.05676407046848908, 0.0415054771292489, 0.0473747742944397, 0.026513257289479952, 0.06568953176611103, 0.12415165838319808, 0.07098916379618458, 0.08630899916170165, 0.23228744335938245, 0.17090391920646653, 0.2927948028082028, 0.20668156736064702, 0.14612319268053398, 0.12091201308066957, 0.2276223327498883, 0.22812415816588327, 0.1609612925676629, 0.19806511409115046, 0.1991940542939119, 0.3580385784152895, 0.2366218826500699, 0.16700375505024567, 0.2329002198530361, 0.12408615642925724, 0.16142213658895344, 0.1631961070233956, 0.12059730535838753, 0.6118512433022261, 52.8377341479063, 126.65221989154816, 114.35719683766365, 86.85478940606117, 81.43181160092354, 82.08453297615051, 73.45767349004745, 75.81092521548271, 78.60809952020645, 78.19342017173767, 84.6731972694397, 100.20126923918724, 113.43289643526077, 106.82807564735413, 83.22775483131409, 5.226271860301495, 0.37314799265004694, 0.8777255890890956, 0.3291891311528161, 0.2241473746835254, 0.42948103859089315, 0.3380812774412334, 0.6562177813611925, 6.546204183250666, 5.704121394082904, 4.691009782254696, 35.392064675688744, 71.38546988368034, 90.21415114402771, 89.70637679100037, 98.37552800774574, 94.95618268847466, 86.37118935585022, 79.4672866165638, 74.82823714613914, 79.55819293856621, 73.8307298719883, 69.28344547748566, 80.1679690182209, 80.28349801898003, 86.87619745731354, 87.66435876488686, 90.06139174103737, 90.22711604833603, 92.50316351652145, 90.37172868847847, 92.0031027495861, 98.23942691087723, 97.92573094367981, 99.04578924179077, 95.37523180246353, 97.65837728977203, 95.35811752080917, 95.66182762384415, 101.32666245102882, 101.48412600159645, 99.62118476629257, 87.98660427331924, 80.29795244336128, 89.29636359214783, 97.13278949260712, 94.84171763062477, 86.17206484079361, 83.18676263093948, 78.6759714782238, 77.70887017250061, 84.50347557663918, 82.35565602779388, 73.32772806286812, 79.53135877847672, 96.17799192667007, 93.71532887220383, 81.37508064508438, 82.00662955641747, 84.92373302578926, 94.53236863017082, 89.3590222299099, 92.58542150259018, 93.5682387650013, 92.52923771739006, 87.99535140395164, 93.33629921078682, 91.51140913367271, 91.44148528575897, 87.50697880983353, 91.51492774486542, 94.49883162975311, 91.75395771861076, 89.89410951733589, 92.50185638666153, 92.3195269703865, 86.63361847400665, 82.29802832007408, 76.46327421069145, 68.35957825183868, 75.35091429948807, 84.31907907128334, 77.90535762906075, 74.99143078923225, 72.91870281100273, 73.99094447493553, 74.97823789715767, 85.25706633925438, 89.71201568841934, 84.23605352640152, 76.95502862334251, 64.69144508242607, 70.14925181865692, 74.15527805685997, 59.96856831014156, 18.195207752287388, 0.7794525311328471, 0.3028639656258747, 0.31438016798347235, 0.4951924562919885, 0.48094583326019347, 0.20707100193249062, 0.1536017851321958, 0.2499522501602769, 0.828424422070384, 22.23015993833542, 85.44851526618004, 101.52234435081482, 80.85086077451706, 101.57165050506592, 84.95347023010254, 40.33010870218277, 43.24098810553551, 46.00936375558376, 55.02887897193432, 92.99432516098022, 77.32148855924606, 94.53815951943398, 35.260865315794945, 0.529144584434107, 0.2957281860290095, 0.210787529067602, 0.10978835489368066, 0.21895683836191893, 0.21027540264185518, 0.18266243278048933, 0.14557964372215793, 0.21629024238791317, 0.1265401122509502, 0.13918970769736916, 0.13028316374402493, 0.1411276333965361, 0.32177103857975453, 0.22093081759521738, 0.14635385217843577, 0.14523090852890164, 0.24233431206084788, 0.3043878322932869, 0.2556073560845107, 0.23138620890676975, 0.17983510246267542], [0.022375956541509368, 0.02413943857391132, 0.06045552043360658, 0.12028420809656382, 0.08779446710832417, 0.080338703119196, 0.05862278674612753, 0.0667404277191963, 0.08817210895358585, 0.16182015038793907, 0.062485828675562516, 0.2159099659183994, 0.14172080234857276, 0.08512839805916883, 0.051205128329456784, 0.03523965417116415, 0.11047180611058138, 0.0715474592288956, 0.24728042946662754, 14.510660413652658, 86.75588831305504, 76.10104724764824, 71.10335022211075, 64.48584571480751, 43.79597492516041, 40.99193058907986, 48.57014514505863, 91.75033271312714, 126.53381064534187, 52.08691343665123, 54.98179189860821, 85.94751968979836, 88.601403683424, 52.551366314291954, 2.210131692700088, 0.12797391187632456, 0.1817733992356807, 0.08192367822630331, 0.06887871102662757, 0.05062009331595618, 0.21493134030606598, 0.3189646516693756, 4.1438704915344715, 3.7364387791603804, 1.115600187331438, 8.107510954141617, 42.694661021232605, 64.69865709543228, 84.39110040664673, 85.20180210471153, 86.33140549063683, 62.7153193205595, 55.814517214894295, 54.59386691451073, 52.202237248420715, 50.640939027071, 58.88388991355896, 59.0864722430706, 66.36308938264847, 70.1099619269371, 72.33223468065262, 80.1130011677742, 83.486817330122, 85.78868061304092, 86.03806123137474, 85.48188507556915, 92.16169863939285, 96.62595748901367, 94.2478246986866, 92.8659376502037, 95.99292665719986, 97.94832453131676, 97.88866773247719, 91.88986122608185, 87.96356990933418, 89.85418125987053, 92.0668177306652, 86.35360389947891, 76.53481677174568, 78.06283637881279, 87.97525808215141, 87.80824184417725, 82.57694855332375, 78.70686382055283, 74.78941082954407, 71.1666852235794, 69.80760455131531, 80.58110564947128, 68.36742103099823, 77.39451304078102, 84.96637433767319, 82.1067313849926, 79.12045642733574, 83.47889095544815, 80.76512977480888, 79.83922585844994, 83.67738470435143, 88.53274896740913, 85.03692895174026, 88.50820228457451, 91.13082155585289, 91.29270806908607, 86.00701689720154, 85.51155388355255, 86.40586629509926, 86.58586263656616, 87.59540006518364, 85.35337597131729, 82.75506779551506, 88.04716542363167, 89.2472930252552, 88.19688498973846, 82.06921219825745, 83.66659328341484, 70.03223329782486, 65.13760954141617, 73.81130531430244, 80.56435614824295, 70.34585326910019, 58.51103492081165, 83.33499267697334, 84.45115238428116, 69.7837646305561, 66.88815280795097, 109.33387398719788, 137.52957701683044, 65.97678691148758, 46.05603285133839, 57.37654499709606, 32.304441556334496, 29.466267451643944, 11.796424258500338, 0.3536727908067405, 0.10055260165245272, 0.005988025950500742, 0.1437405720935203, 0.06773518020054325, 0.2663034258875996, 0.17756775225279853, 0.06293347731116228, 0.3849407489178702, 16.8384962528944, 63.67967717349529, 80.31158611178398, 70.93622758984566, 79.46692943572998, 65.04831433296204, 26.391257755458355, 25.91993674635887, 39.45270538330078, 34.695778638124466, 52.77986705303192, 61.92959368228912, 72.41204559803009, 24.540665857493877, 0.6607587158214301, 0.07566860527731478, 0.0714074753341265, 0.1439861487597227, 0.04123641519981902, 0.09523377026198432, 0.06354190481943078, 0.05467971903271973, 0.04150902088440489, 0.06463816825998947, 0.06473926361650229, 0.06479568910435773, 0.08681657622219063, 0.0726619795022998, 0.11033018949092366, 0.1171485599479638, 0.05271070847811643, 0.31961560423951596, 0.19904186949133873, 0.168349877349101, 0.07068860140861943, 0.03748875125893392, 0.036404095008037984, 0.14509463537251577, 0.19179365452146158, 0.04895235018921085, 0.038875209284015, 0.057843761751428246, 0.018900911272794474, 0.16837056842632592, 0.09119512877077796, 0.03650853373983409, 0.022011780965840444, 0.03926890007278416, 0.07064727862598374, 0.04365823602711316, 0.06868558935821056, 0.06537296125316061, 0.07225755354738794, 0.20790113863768056, 24.610017836093903, 104.15780693292618, 84.16951909661293, 99.74559009075165, 96.87524691224098, 63.68270941078663, 72.81558394432068, 53.4120087325573, 75.3728087246418, 115.36743342876434, 43.674427047371864, 62.05969110131264, 95.72139322757721, 102.18579635024071, 53.3716244995594, 1.641145118046552, 0.12707184621831402, 0.13693429122213274, 0.0658025014854502, 0.03448182120337151, 0.04037908249301836, 0.1382921839831397, 0.48509699176065624, 1.6579902078956366, 2.4672244722023606, 0.6455024750903249, 14.070738069713116, 61.0281490534544, 76.49380937218666, 95.5806715786457, 88.24032425880432, 86.13669633865356, 70.22292226552963, 70.4045981168747, 68.19601982831955, 66.26917362213135, 58.52238491177559, 68.24252173304558, 67.59911745786667, 75.42754098773003, 78.20874854922295, 81.82046234607697, 87.25388959050179, 89.93875712156296, 96.19486302137375, 92.99796536564827, 92.31996774673462, 94.47402656078339, 94.67267230153084, 94.93783727288246, 95.66808208823204, 96.0384938120842, 99.72526878118515, 102.18360766768456, 96.4054249227047, 89.57549661397934, 93.86833906173706, 93.67976278066635, 85.43375685811043, 78.27092841267586, 80.06578490138054, 92.6404881477356, 92.90239289402962, 87.26192235946655, 86.23627379536629, 77.81071230769157, 77.41000100970268, 78.30181315541267, 85.75825944542885, 71.02934539318085, 75.64569488167763, 87.08270117640495, 83.85600551962852, 80.80230697989464, 83.13811764121056, 84.37931343913078, 80.69386839866638, 84.25270423293114, 89.7380518913269, 89.59448039531708, 92.4695049226284, 93.50237309932709, 92.82056048512459, 90.25987029075623, 85.81143379211426, 88.48623186349869, 88.89669343829155, 88.61493095755577, 86.21357381343842, 84.70065459609032, 87.20683291554451, 86.80311217904091, 90.27868688106537, 88.3416648209095, 89.13989558815956, 79.32867005467415, 74.119111597538, 75.57156085968018, 78.01594689488411, 77.561194896698, 67.66830414533615, 85.15779286623001, 86.45432129502296, 83.4104186296463, 70.2603730559349, 81.72232121229172, 117.99359411001205, 108.38049754500389, 56.07594318687916, 63.524580895900726, 62.15615272521973, 39.12359744310379, 17.18431569635868, 0.4114655521698296, 0.23984079976798967, 0.057004767513717525, 0.07397905414109118, 0.25558826804626733, 0.12454023206373677, 0.1408192710368894, 0.09397590416483581, 0.372605393640697, 16.188689321279526, 74.07635629177094, 90.98431661725044, 80.40714338421822, 69.37928393483162, 19.938406012952328, 19.971468038856983, 43.57842139899731, 58.316481560468674, 68.88437569141388, 72.81787902116776, 70.79838618636131, 85.25075107812881, 35.524913147091866, 0.46635565522592515, 0.0034895786075139767, 0.10399135775514878, 0.07571130103315227, 0.022459257052105386, 0.03785031818551943, 0.05742437409935519, 0.0591713118046755, 0.0410891545470804, 0.129204259137623, 0.022724537739122752, 0.028510751471912954, 0.1202949469734449, 0.04839257417188492, 0.05002677964512259, 0.06650650277151726, 0.021758419170510024, 0.14480307523626834, 0.10790379703394137, 0.06203618737345096, 0.09655477828346193, 0.19112546928226948, 0.14159649261273444, 0.316561785293743, 0.39674380619544536, 0.18558386742370203, 0.16821443539811298, 0.15152337087783962, 0.15084135200595483, 0.22270797926466912, 0.2052942558657378, 0.14829934778390452, 0.3160177613608539, 0.3052170487353578, 0.29479753284249455, 0.21447821462061256, 0.2648748509818688, 0.15721690520877019, 0.20923170552123338, 0.31444114283658564, 32.08708181977272, 121.99471101164818, 97.02595442533493, 96.01266279816628, 91.52026265859604, 61.229644641280174, 56.55739635229111, 66.69224292039871, 107.6684157550335, 134.67851400375366, 70.60907274484634, 74.85354378819466, 112.42581367492676, 109.25647974014282, 73.82897436618805, 4.127629213035107, 0.3175599442329258, 0.19981940276920795, 0.1916407869430259, 0.14136281999526545, 0.19274885795312002, 0.316346799954772, 0.5870456993579865, 6.365069327875972, 12.111031226813793, 8.216043580323458, 13.792068623006344, 80.9594589471817, 81.2036794424057, 99.43713784217834, 89.56753224134445, 95.27612552046776, 78.6502392590046, 80.17775729298592, 80.55392950773239, 78.4817411005497, 67.25272804498672, 79.36045154929161, 80.43164446949959, 86.15922912955284, 85.2810126543045, 87.92513117194176, 91.19379177689552, 93.75413998961449, 96.43289744853973, 95.01479834318161, 94.39363807439804, 96.26116186380386, 97.68188282847404, 100.04313692450523, 96.29845306277275, 98.81818905472755, 104.70189213752747, 106.10249698162079, 100.87925925850868, 94.09700319170952, 95.42618706822395, 95.85940182209015, 85.49064740538597, 77.62984961271286, 78.34586799144745, 92.94968515634537, 96.02337822318077, 86.50109678506851, 83.49545806646347, 76.96335017681122, 77.66627445816994, 85.58137893676758, 93.01957100629807, 80.77459886670113, 78.46937656402588, 87.81593263149261, 86.59193471074104, 83.53817537426949, 86.0809077322483, 86.39281779527664, 83.50640147924423, 85.8936233818531, 93.2542996108532, 92.42033556103706, 97.71697774529457, 98.89340221881866, 95.73955625295639, 92.47616216540337, 88.07744979858398, 89.63053286075592, 89.20706078410149, 89.16938200592995, 88.86545911431313, 85.94650894403458, 91.23644828796387, 91.7412132024765, 95.13428673148155, 89.97175455093384, 89.74416196346283, 79.45277899503708, 74.91769194602966, 80.04356369376183, 80.34351959824562, 76.59398719668388, 72.27975189685822, 87.7790442109108, 91.89714163541794, 87.9981480538845, 74.89629909396172, 85.33696845173836, 100.93905285000801, 88.20962950587273, 64.04725044965744, 67.04908937215805, 73.32997754216194, 64.06914487481117, 18.196233697235584, 0.6239971134345978, 0.4357757867546752, 0.23251647013239563, 0.1723911237786524, 0.8018066722434014, 0.27951282332651317, 0.21805229393066838, 0.16995741374557838, 0.6286399892996997, 22.549513801932335, 83.12541872262955, 100.97495332360268, 86.46287843585014, 117.02090710401535, 89.13364112377167, 37.57430657744408, 38.853842318058014, 51.634619906544685, 51.1777438223362, 74.52088683843613, 76.34477376937866, 93.35959196090698, 44.4265890866518, 0.6350976834073663, 0.14298934052931145, 0.35714334051590413, 0.36155799112748355, 0.11896295516635291, 0.14470668509602547, 0.24328786792466417, 0.11872629911522381, 0.11626858802628703, 0.2516751311486587, 0.1678191527025774, 0.1301444711862132, 0.2849441271973774, 0.1089078931545373, 0.2481349086156115, 0.14980749576352537, 0.1490388682577759, 0.2548945677699521, 0.3239557729102671, 0.2692957653198391, 0.15552621858660132], [0.07515174394939095, 0.11321335899992846, 0.027907888215850107, 0.0697998127725441, 0.13546630827477202, 0.02904847828176571, 0.02590318221336929, 0.040486148427589796, 0.1335663953796029, 0.03654653912235517, 0.1302001767908223, 0.03866469909553416, 0.09952253036317416, 0.29325840761885047, 0.13289889291627333, 0.07082293755956925, 0.06045533489668742, 0.06854988023405895, 1.8427791609428823, 68.36041420698166, 80.78410595655441, 81.8902949988842, 56.150837168097496, 51.27967715263367, 49.925688207149506, 32.27587468922138, 72.68201351165771, 113.46631184220314, 114.70249190926552, 86.2589205801487, 89.15091499686241, 105.0068561732769, 47.33607776463032, 0.774541829014197, 0.08373784337891266, 0.05738494379329495, 0.06162234356452245, 0.20381601643748581, 0.12676900543738157, 0.14836458256468177, 0.17999795934883878, 0.1233491963648703, 6.8254635483026505, 0.16479764686664566, 2.160492343828082, 33.98933954536915, 58.45416337251663, 92.93647706508636, 77.05548763275146, 91.14264652132988, 73.86319532990456, 68.11189234256744, 66.10189139842987, 58.757314905524254, 55.26145689189434, 55.7438600063324, 59.99700978398323, 66.23021811246872, 72.26228803396225, 77.802504748106, 83.66320386528969, 95.0623793900013, 89.99852791428566, 92.88603097200394, 89.65926691889763, 89.43640887737274, 84.7251632809639, 89.78740364313126, 88.1849992275238, 93.86732831597328, 90.43940305709839, 89.92405951023102, 86.96868449449539, 83.74594822525978, 85.5493238568306, 88.23916912078857, 85.74370622634888, 86.67889684438705, 84.16479215025902, 80.52075728774071, 82.0340944826603, 93.04136663675308, 85.33633008599281, 86.32391229271889, 79.40974250435829, 63.018736839294434, 36.54469482600689, 48.47094386816025, 42.341105192899704, 65.84025263786316, 82.56228134036064, 79.19220417737961, 73.25972691178322, 74.6925388276577, 76.62674903869629, 76.78332343697548, 77.4212484061718, 81.53736993670464, 84.46401089429855, 84.22162190079689, 79.28985133767128, 75.7924734055996, 80.63682585954666, 77.15800613164902, 80.62672600150108, 82.63246357440948, 85.19137546420097, 84.14507880806923, 85.67819014191628, 85.57498008012772, 85.9356415271759, 88.42764660716057, 90.13038843870163, 81.53481647372246, 82.20110312104225, 84.30777087807655, 75.86383357644081, 70.8696323633194, 77.84141466021538, 71.40335932374, 65.65873637795448, 74.88961905241013, 75.7309927046299, 71.29514873027802, 56.38879179954529, 91.33839681744576, 134.72927927970886, 84.65127244591713, 43.03866036236286, 58.93239051103592, 31.739218086004257, 26.876628510653973, 7.8562019392848015, 0.547912964830175, 0.3229192004073411, 0.04171603555732872, 0.12446788008674048, 0.20021538308355957, 0.2001387786003761, 0.14677099854452536, 0.2293837460456416, 0.36844559654127806, 18.42053946107626, 63.33193503320217, 75.36436557769775, 65.36169871687889, 67.09285542368889, 57.12113790214062, 44.4847297668457, 27.42736715823412, 28.474712558090687, 49.13167141377926, 53.884593173861504, 68.42417478561401, 66.3317334651947, 33.303210362792015, 0.9485068253707141, 0.006560049259860534, 0.0835949725296814, 0.04747730941744521, 0.11042230486054905, 0.09360817741253413, 0.04634283279301599, 0.058979054738301784, 0.03544040511769708, 0.13120347139192745, 0.04062140484165866, 0.023823960873414762, 0.14314108004327863, 0.1277578726876527, 0.08528190388460644, 0.12051523866830394, 0.2665294543839991, 0.318383906269446, 0.17611574032343924, 0.056512022274546325, 0.08531000901712105, 0.0649967665958684, 0.010691171628423035, 0.049822967339423485, 0.06837890425231308, 0.07649756196769886, 0.01631444498343626, 0.09016480515128933, 0.037487474764930084, 0.07326130828005262, 0.07906872517196462, 0.055446843689423986, 0.04755945774377324, 0.18980823137098923, 0.03219056270609144, 0.03524845604260918, 0.13076802366413176, 0.16762623883550987, 4.049007631838322, 87.04358607530594, 90.29578596353531, 101.36529117822647, 74.66602385044098, 68.77498716115952, 69.41781386733055, 32.974790185689926, 52.04825051128864, 121.70512095093727, 120.86765348911285, 87.53388896584511, 101.50108829140663, 116.34436100721359, 53.45631815493107, 0.26295363844837993, 0.13967582926852629, 0.08439480734523386, 0.17977372684981674, 0.15138709772145376, 0.1491686253575608, 0.019512366743583698, 0.37150466989260167, 0.7903707108926028, 7.623459678143263, 0.2783544495468959, 3.1853187270462513, 59.91836920380592, 70.6925542652607, 100.7615415751934, 82.77142211794853, 95.59622794389725, 81.9224564731121, 76.60764366388321, 72.5727541744709, 67.78448671102524, 66.9880798459053, 67.10566073656082, 67.58915439248085, 74.25063014030457, 79.9299193918705, 87.44310423731804, 87.16984570026398, 100.33392012119293, 94.75575864315033, 94.8693497478962, 94.16536152362823, 94.89082619547844, 89.81901034712791, 92.08032980561256, 87.82610848546028, 90.63673406839371, 93.67695853114128, 91.23111337423325, 89.69702929258347, 89.95523303747177, 90.46482369303703, 91.0327260196209, 89.07637059688568, 83.36633339524269, 83.11269700527191, 80.70380866527557, 83.69066119194031, 98.28410491347313, 92.4356259405613, 88.0666583776474, 83.37483733892441, 60.58753989636898, 42.58631743490696, 49.97120976448059, 47.32650987803936, 68.03371533751488, 84.30015608668327, 80.44857636094093, 73.37540030479431, 76.46338820457458, 76.58356815576553, 85.42599007487297, 82.30866774916649, 83.71382474899292, 86.2027595937252, 85.28593719005585, 82.49646127223969, 80.69009900093079, 80.11520504951477, 80.33397451043129, 81.01827219128609, 85.3724205493927, 86.45158544182777, 88.44995900988579, 87.30879664421082, 89.26962062716484, 87.09508091211319, 87.04069823026657, 89.74106892943382, 87.32274949550629, 85.88702693581581, 88.6491671204567, 83.70946258306503, 75.41563242673874, 77.89006724953651, 79.26865607500076, 70.15646383166313, 75.10197445750237, 76.89047008752823, 79.38564419746399, 67.51607671380043, 76.42108127474785, 100.05580544471741, 122.60436549782753, 56.46989084780216, 66.37193530797958, 58.286922946572304, 34.58813801407814, 11.445580534636974, 0.23345101217273623, 0.6629185436759144, 0.12725100066745654, 0.0747061287984252, 0.1413750951178372, 0.14112405624473467, 0.22114047431387007, 0.18886571866460145, 0.20048304606461897, 17.59945672005415, 77.30422988533974, 86.43596068024635, 78.02441284060478, 50.64847782254219, 23.248286806046963, 20.533068403601646, 41.773256063461304, 41.470123529434204, 67.80481562018394, 77.45714128017426, 74.03823673725128, 79.99186366796494, 46.778404489159584, 0.9139093849807978, 0.028350467982818373, 0.06812320469180122, 0.0456004810257582, 0.008721256581338821, 0.09123526411713101, 0.02422063880658243, 0.08164856408257037, 0.03846946230623871, 0.022214292657736223, 0.022044674806238618, 0.04524151161604095, 0.06886450632009655, 0.05180978201678954, 0.02568939915363444, 0.05328485247446224, 0.16621161630610004, 0.10462639867910184, 0.07280158490175381, 0.08172678644768894, 0.1544586688396521, 0.147413520317059, 0.17080697987694293, 0.18392585014225915, 0.21018904633820057, 0.13228433526819572, 0.12669165880652145, 0.13482602778822184, 0.131713445589412, 0.09785778180230409, 0.21857945626834407, 0.1632345057441853, 0.21940361126326025, 0.4246702295495197, 0.23931524046929553, 0.21903026645304635, 0.31266634119674563, 0.25891243654768914, 6.216797959059477, 104.73934292793274, 104.73302006721497, 111.79691702127457, 81.50853708386421, 68.02646532654762, 70.49237340688705, 51.24413765966892, 101.90515100955963, 120.52558824419975, 124.21748533844948, 108.33011224865913, 110.26269614696503, 126.88351348042488, 66.92478284239769, 1.0495548625476658, 0.39828005188610405, 0.1148792875756044, 0.29874834115616977, 0.2801711083156988, 0.47317150980234146, 0.23990094341570511, 0.3371945000253618, 0.42370739683974534, 21.569337397813797, 10.337852574884892, 1.899101638700813, 70.03993928432465, 75.75587376952171, 107.87972241640091, 86.43855974078178, 97.8307056427002, 85.05215093493462, 85.85789009928703, 85.97005248069763, 80.28121814131737, 79.26683977246284, 79.13545042276382, 79.22967776656151, 77.68912643194199, 81.3912145793438, 92.70918846130371, 91.93640112876892, 104.46986138820648, 98.38592424988747, 101.33321329951286, 97.66495853662491, 95.50359651446342, 89.47717308998108, 96.53299927711487, 87.980737388134, 95.00795871019363, 96.75401821732521, 92.82351672649384, 93.43580827116966, 94.07303407788277, 92.42956906557083, 96.64060190320015, 92.72779986262321, 87.47715801000595, 82.64383256435394, 81.73749759793282, 82.89871528744698, 100.62215745449066, 94.28834572434425, 88.9790578186512, 80.83765268325806, 71.331497579813, 52.38577499985695, 62.963221818208694, 56.84360459446907, 70.49957782030106, 89.36282962560654, 83.77174884080887, 76.30708739161491, 77.28508651256561, 79.19841304421425, 85.52654787898064, 86.14583104848862, 85.74804559350014, 89.8630727827549, 89.14581567049026, 85.5821692943573, 83.99985060095787, 85.10638162493706, 84.0636795759201, 84.57345262169838, 86.88390344381332, 87.92745664715767, 89.73242059350014, 89.47608634829521, 93.69294807314873, 89.36561867594719, 93.04573640227318, 93.79514738917351, 90.53496032953262, 89.25926238298416, 92.69762948155403, 86.05437755584717, 80.52723214030266, 74.78597581386566, 78.22957903146744, 79.16742950677872, 82.84392982721329, 80.50570249557495, 79.75211933255196, 72.69934058189392, 83.17578122019768, 91.55332088470459, 100.0755263864994, 65.05470559000969, 71.25990182161331, 72.2417463362217, 57.24150784313679, 10.492805410176516, 0.7586409884970635, 1.4169931272044778, 0.21336699690436944, 0.3115495276870206, 0.7358210755046457, 0.2674408711027354, 0.3769673517672345, 0.36482222378253937, 0.363342470373027, 24.5577060431242, 83.64912942051888, 97.56731137633324, 85.85628658533096, 94.2838391661644, 70.52273377776146, 59.168718829751015, 38.37674751877785, 40.179302394390106, 67.34119489789009, 73.90200644731522, 84.31220144033432, 90.02869069576263, 60.005331337451935, 1.1985443928278983, 0.16109719465021044, 0.14611584541853517, 0.06916946964338422, 0.17981187324039638, 0.18915097054559737, 0.18693904392421246, 0.247499214601703, 0.12117223974200897, 0.23891612829174846, 0.1574941270519048, 0.16997475031530485, 0.2581790758995339, 0.1901181967696175, 0.17351660557324067, 0.22784815344493836, 0.4212519567226991, 0.4466185049386695, 0.18443006527377293, 0.19278221006970853], [0.07910957298008725, 0.06954903365112841, 0.031839237417443655, 0.041076493507716805, 0.13820284424582496, 0.04654563948861323, 0.050475181560614146, 0.04247586490237154, 0.05979012566967867, 0.09382172298501246, 0.044000596171827056, 0.08813412583549507, 0.10832944099092856, 0.3602712554857135, 0.28350762615446, 0.05579649543506093, 0.06837991357315332, 0.15884336637100205, 27.122893296182156, 83.84725078940392, 69.05205309391022, 66.87267243862152, 66.13290533423424, 57.376332208514214, 45.19091047346592, 86.49703860282898, 57.25438915193081, 60.98443999886513, 79.04259860515594, 80.86964696645737, 98.09186562895775, 47.07367144525051, 1.978563687298447, 0.15587315778248012, 0.2727041527396068, 0.14567466831067577, 0.15295127785066143, 0.0662868122162763, 0.16226671548793092, 0.04597631574142724, 0.40092972689308226, 0.7000934926327318, 0.4191615048330277, 0.9558308136183769, 17.861070781946182, 79.06641572713852, 87.09292262792587, 85.71523055434227, 89.66418385505676, 78.41783612966537, 62.98958860337734, 61.474826484918594, 57.496591955423355, 49.9138518422842, 54.814486876130104, 56.14882327616215, 70.39072886109352, 81.08606815338135, 90.43503329157829, 93.68474051356316, 84.37648639082909, 92.49581471085548, 91.88995242118835, 87.29691088199615, 92.32841089367867, 89.38229978084564, 88.11195954680443, 87.1996209025383, 82.48049452900887, 85.56792005896568, 88.32664042711258, 89.36156809329987, 88.20674166083336, 90.58108225464821, 88.35056394338608, 83.42500224709511, 81.85123309493065, 78.05254653096199, 76.79981455206871, 76.29150062799454, 81.75835087895393, 85.56396827101707, 88.21354329586029, 74.81272637844086, 85.20406678318977, 30.937867686152458, 34.94565702974796, 35.80321781337261, 23.926271125674248, 59.60803225636482, 75.34341350197792, 80.99263116717339, 74.68399688601494, 75.93938112258911, 70.72832554578781, 85.73622062802315, 80.56874111294746, 78.44614461064339, 79.73865285515785, 87.99740329384804, 80.06227388978004, 78.94315034151077, 74.92211490869522, 80.12810915708542, 80.54727986454964, 83.09771060943604, 80.2933318912983, 82.15885698795319, 79.85833883285522, 83.69842797517776, 81.94384932518005, 86.25743865966797, 89.06707629561424, 89.79714632034302, 79.90034937858582, 79.07005593180656, 77.38390401005745, 76.48380070924759, 76.39104768633842, 77.14005589485168, 66.55781373381615, 60.69904111325741, 54.305317997932434, 68.16160887479782, 78.03327396512032, 72.50893279910088, 68.13820973038673, 140.95725148916245, 83.50184932351112, 44.222802221775055, 57.565562054514885, 26.827544644474983, 22.203760854899883, 3.4704732382670045, 0.7093954528681934, 0.8619861805345863, 1.351807506289333, 0.2728530572494492, 0.18585853627882898, 0.12389923169394024, 0.07291095520486124, 0.21309342642780393, 0.11421302449889481, 22.124006934463978, 62.94757045805454, 75.05085960030556, 68.32596525549889, 53.72393399477005, 73.0882953107357, 46.72621428966522, 49.26280997693539, 37.049607932567596, 33.61330792307854, 53.82725045084953, 60.164907574653625, 66.93941205739975, 44.78864125907421, 1.045260855462402, 0.02856200975656975, 0.03088941826717928, 0.0856316855060868, 0.0531041543581523, 0.04092782277439255, 0.09027901425724849, 0.058086347562493756, 0.0303318668375141, 0.003759358100978716, 0.03401695845241193, 0.016910534286580514, 0.06408585453755222, 0.02238115714135347, 0.020131857818341814, 0.12731987197184935, 0.2134471043245867, 0.2157290154718794, 0.23734799993690103, 0.047878677723929286, 0.09163382710539736, 0.03305159872979857, 0.04222477407893166, 0.022058948161429726, 0.046996123128337786, 0.09785843489225954, 0.049498478110763244, 0.0536339476093417, 0.11437244524131529, 0.04157578448939603, 0.03142431007290725, 0.06764529869542457, 0.20453500910662115, 0.04691767811891623, 0.15214906074106693, 0.17175326269352809, 0.17955878603970632, 39.56153154373169, 100.43377116322517, 84.42334547638893, 87.92035102844238, 84.21068608760834, 72.48994901776314, 42.057739198207855, 40.87869666516781, 36.04472905397415, 66.93769454956055, 84.82820615172386, 90.17395690083504, 108.98177728056908, 51.55339926481247, 1.217262544669211, 0.10418726247735322, 0.09629793581552804, 0.15667999105062336, 0.16651205252856016, 0.19407912797760218, 0.053671600471716374, 0.2606549102347344, 0.7862554723396897, 2.112031881697476, 1.2303668539971113, 0.5183470482006669, 27.038925401866436, 91.69303178787231, 93.48802506923676, 90.44742062687874, 95.69469586014748, 84.02270257472992, 70.9035949409008, 70.38454279303551, 68.66880565881729, 60.68836368620396, 63.78012478351593, 67.62876346707344, 79.71171990036964, 85.57332336902618, 90.1684395968914, 96.7618153989315, 90.20073026418686, 92.42374017834663, 95.90544775128365, 93.1240426003933, 93.95818144083023, 95.02934396266937, 94.40392032265663, 89.38093945384026, 89.1346062719822, 86.79325550794601, 88.43931958079338, 91.93232014775276, 92.4688209593296, 91.86324745416641, 92.63836786150932, 89.59802180528641, 83.67540881037712, 81.53105467557907, 76.71106651425362, 77.90329813957214, 83.98832961916924, 87.91701480746269, 92.53371387720108, 82.97560796141624, 84.43093746900558, 34.29878734052181, 44.69619981944561, 46.94624148309231, 28.931311257183552, 64.14282292127609, 78.52894216775894, 79.51718553900719, 75.4806849360466, 75.46869277954102, 74.67505976557732, 85.90265929698944, 85.52912414073944, 83.85390043258667, 81.95676863193512, 88.10904130339622, 83.3219213783741, 84.24923121929169, 79.53097119927406, 83.44252690672874, 88.08909237384796, 81.78398430347443, 85.48694640398026, 83.56659024953842, 86.32051527500153, 84.4457870721817, 82.48244002461433, 82.99043476581573, 86.10890462994576, 90.74090927839279, 88.87162998318672, 84.5952558517456, 80.57450920343399, 83.66684406995773, 79.07553523778915, 82.24922373890877, 73.88384342193604, 68.02086442708969, 58.37749868631363, 66.52200445532799, 80.90675577521324, 80.41196912527084, 60.68107947707176, 103.15736621618271, 108.63223403692245, 57.174266651272774, 68.0338217318058, 52.55214907228947, 28.710256218910217, 5.900836363434792, 0.8151194953825325, 1.4992860238999128, 0.652820288669318, 0.05771892138000112, 0.23454047011910006, 0.1759212531032972, 0.52179797552526, 0.2166468888754025, 0.14937014813767746, 23.16853668540716, 76.1394327878952, 86.42241820693016, 81.33386045694351, 45.959320440888405, 40.52811227738857, 18.392200581729412, 57.296962067484856, 54.961029812693596, 51.544469743967056, 78.31784069538116, 65.74704363942146, 79.06010046601295, 56.75142154097557, 1.1426068819127977, 0.04827804223168641, 0.06147719432192389, 0.09019932243973017, 0.034561160500743426, 0.038577177620027214, 0.157692740613129, 0.058460364016355015, 0.061348613526206464, 0.016971056429611053, 0.035010478968615644, 0.04035341531562153, 0.02145899041352095, 0.033677411047392525, 0.09435519357793964, 0.09485618036706, 0.0788897265738342, 0.02103195307427086, 0.11348925982019864, 0.3024189145071432, 0.12363314206595533, 0.16835056012496352, 0.08847628560033627, 0.37184380169492215, 0.30073869216721505, 0.14410624309675768, 0.11781116423662752, 0.1675603212788701, 0.16424542962340638, 0.1427867342135869, 0.19135287817334756, 0.2401299701887183, 0.396536331390962, 0.3556523658335209, 0.3606061718892306, 0.35341096110641956, 0.28771631594281644, 49.80273440480232, 118.192840218544, 97.52352252602577, 91.7180572450161, 89.92918163537979, 80.12516811490059, 70.18076732754707, 122.18426764011383, 82.9089367389679, 75.13663619756699, 99.7753956913948, 100.88580250740051, 119.54302176833153, 65.15284672379494, 2.7502674842253327, 0.33967051247600466, 0.41773022850975394, 0.2736725070280954, 0.45827411231584847, 0.31002367206383497, 0.2992114413063973, 0.45991482271347195, 0.6789156259037554, 2.7145524881780148, 3.2317284867167473, 1.0980134247802198, 28.393913693726063, 99.83895108103752, 98.90892818570137, 102.36471354961395, 97.96421527862549, 91.1657340824604, 77.70271450281143, 83.67697432637215, 77.56159007549286, 69.9241290986538, 72.43502676486969, 73.98355007171631, 81.85502529144287, 88.9890892803669, 94.69345718622208, 102.0286899805069, 94.37866687774658, 98.79171207547188, 99.392079859972, 95.07977485656738, 95.73226064443588, 98.15700933337212, 96.76692232489586, 92.92247861623764, 90.4362416267395, 89.23695757985115, 90.55332094430923, 93.94162952899933, 94.32128995656967, 95.30530795454979, 97.99041107296944, 93.36516246199608, 86.62275865674019, 84.63151350617409, 77.0728451013565, 77.6224248111248, 84.5564067363739, 89.97639790177345, 94.53802272677422, 84.6547682583332, 88.55401262640953, 42.63836324214935, 46.86493344604969, 46.942612677812576, 38.530456870794296, 69.86015573143959, 79.29703295230865, 82.30017140507698, 76.55804112553596, 80.9323588013649, 76.04245439171791, 89.9528543651104, 87.76424020528793, 85.57987421751022, 85.14668986201286, 93.7223432958126, 86.22139379382133, 87.03384339809418, 81.83490917086601, 85.5168280005455, 89.24877494573593, 84.71437186002731, 86.4107908308506, 83.11356335878372, 87.54294767975807, 86.75110816955566, 86.92212179303169, 90.14130145311356, 93.03424581885338, 91.25192865729332, 88.52389544248581, 85.06266877055168, 83.61392050981522, 86.65291383862495, 84.12008374929428, 80.16527116298676, 75.64288303256035, 73.88833478093147, 69.88518118858337, 73.6893318593502, 81.2647345662117, 88.52308988571167, 70.18599584698677, 94.38480734825134, 97.86514699459076, 63.90697717666626, 73.6815270781517, 67.2225196659565, 49.18005421757698, 3.913743202574551, 1.7336165998131037, 2.830637921579182, 3.3566938061267138, 0.39953389554284513, 1.3301690923981369, 0.14777898351894692, 0.25375091820023954, 0.4566287115449086, 0.28200578643009067, 29.589234553277493, 82.62695387005806, 99.92405891418457, 91.08482882380486, 77.13030561804771, 98.81220817565918, 63.26855443418026, 68.80355402827263, 51.679408103227615, 49.45975720882416, 74.47268262505531, 75.867078602314, 87.90611699223518, 68.81179198622704, 1.4720418420620263, 0.13137409114278853, 0.13896989839849994, 0.3468563425121829, 0.18161265004891902, 0.12696294346824288, 0.25361332402098924, 0.12189449786092155, 0.11089195817476138, 0.10239146547974087, 0.13603305676952004, 0.09973756765248254, 0.11218161787837744, 0.2187870052875951, 0.23615566547960043, 0.2273373628850095, 0.22380594222340733, 0.24511371448170394, 0.3587545728078112], [0.1576195945381187, 0.06866863870527595, 0.06251696177059785, 0.05682639603037387, 0.0535461515391944, 0.06532928586238995, 0.027522739546839148, 0.07807067013345659, 0.04077880323166028, 0.06263218019739725, 0.04094221301784273, 0.05358061687729787, 0.17516519757919014, 0.06654392927885056, 0.33834972709883004, 0.19024014647584409, 0.06337780112517066, 1.315181152895093, 57.07548715174198, 77.82654985785484, 52.214723378419876, 59.33447353541851, 44.91622321307659, 42.51332335174084, 54.45591911673546, 51.3182070851326, 30.114468969404697, 42.13290676474571, 78.23542311787605, 99.86804232001305, 62.94378586113453, 2.114480137825012, 0.15632371563697234, 0.048078745894599706, 0.025883997695927974, 0.1288945460692048, 0.12129061971791089, 0.14316619432065636, 0.09445890871575102, 0.17573559744050726, 0.463561350479722, 3.0975510366261005, 1.2386925634928048, 2.5647550262510777, 57.46956020593643, 81.0143356025219, 101.30330130457878, 69.01588663458824, 79.40714344382286, 74.28821012377739, 63.458567038178444, 67.56294339895248, 61.78548261523247, 65.17976447939873, 62.71922551095486, 77.81096309423447, 82.0353864133358, 85.37217736244202, 85.98342776298523, 93.60423803329468, 90.76582834124565, 85.93259409070015, 94.05197560787201, 91.22925907373428, 87.07598313689232, 90.7199040055275, 83.88391122221947, 81.81758970022202, 81.11084282398224, 80.9766036272049, 84.67685267329216, 88.0322702229023, 83.34268346428871, 80.73329508304596, 86.00199356675148, 82.87465497851372, 78.3829540014267, 84.77021366357803, 76.39968082308769, 75.73737636208534, 80.36419808864594, 85.61800137162209, 85.24339467287064, 88.41990262269974, 72.22327172756195, 33.700026869773865, 58.16194765269756, 74.21299695968628, 34.5054392516613, 27.46519412845373, 77.52695873379707, 69.26310896873474, 71.44938245415688, 71.39745444059372, 74.97747793793678, 73.2604792714119, 79.76772889494896, 77.08986058831215, 76.74850970506668, 79.52732339501381, 80.169937312603, 81.4189986884594, 77.48681008815765, 77.8130529820919, 76.71210005879402, 78.46498399972916, 79.21899273991585, 82.79787629842758, 82.37926796078682, 77.66779437661171, 78.70937928557396, 78.68278831243515, 79.39930826425552, 82.60745331645012, 86.35638535022736, 82.01452553272247, 78.04180070757866, 76.14571765065193, 71.66153267025948, 75.8407612144947, 76.77325397729874, 70.0908413529396, 58.5825926810503, 56.03753104805946, 66.58691257238388, 68.99020001292229, 57.41168551146984, 80.33436968922615, 124.35123816132545, 71.31629839539528, 47.89158135652542, 56.42081268131733, 23.536339849233627, 22.6839866861701, 0.6654835247900337, 0.9960044547915459, 0.4382159386295825, 0.10962834043311886, 0.09037556024850346, 0.3792181669268757, 0.3346443618647754, 0.07223521490232088, 0.18229756329674274, 0.41266447689849883, 24.37413789331913, 64.73067417740822, 76.40172511339188, 69.15122777223587, 42.24068038165569, 66.27890110015869, 33.61074686050415, 27.996713407337666, 43.39582599699497, 46.54555678367615, 54.04981970787048, 58.17749261856079, 67.70712286233902, 38.916364163160324, 0.8234292338602245, 0.12180167002952658, 0.08906718358048238, 0.13008952257223427, 0.03293522626336198, 0.20528922410449013, 0.06372324118274264, 0.05434316990431398, 0.02522928058169782, 0.07491603042581119, 0.011086318882007618, 0.10862512746825814, 0.1376204809639603, 0.12002695744740777, 0.03520315163768828, 0.1666001751436852, 0.08267507306300104, 0.1428130507702008, 0.0444699600484455, 0.06671633018413559, 0.05822918130434118, 0.01607907841389533, 0.058266114283469506, 0.04122937592910603, 0.12199447257444263, 0.03474519086012151, 0.028643599616771098, 0.06946344175958075, 0.033798826407291926, 0.05636374859022908, 0.022684940449835267, 0.07187038252595812, 0.16988140298053622, 0.10573874445981346, 0.12062476482242346, 2.2993756039068103, 73.32581296563148, 89.17623683810234, 71.03250682353973, 81.306661516428, 59.83087509870529, 61.70843794941902, 62.47878581285477, 42.793155536055565, 30.05656197667122, 42.52873532474041, 88.17168474197388, 107.08523064851761, 67.03851073980331, 1.6497150831855834, 0.10308735509170219, 0.03806015301961452, 0.014244646135921357, 0.09536533078062348, 0.17510486097307876, 0.2672942524077371, 0.045284871594049037, 0.3349075571168214, 1.249637994915247, 1.2410599552094936, 1.3509228662587702, 4.024800080806017, 73.70564058423042, 86.10132783651352, 105.65041244029999, 78.03587302565575, 84.06196966767311, 81.8885850906372, 76.1611296236515, 78.47038730978966, 71.78807348012924, 73.58447268605232, 71.52480080723763, 82.56788983941078, 86.46891251206398, 89.27454516291618, 87.98654347658157, 95.37577137351036, 95.03932222723961, 90.19332066178322, 95.80349162220955, 95.55230990052223, 91.65193319320679, 91.02769508957863, 91.26034140586853, 89.0148974955082, 86.04065269231796, 85.66954180598259, 82.94444963335991, 88.66778612136841, 86.10993817448616, 86.78296566009521, 85.6540310382843, 89.44435805082321, 88.07229727506638, 87.32796281576157, 81.31499826908112, 75.2253158390522, 78.37511882185936, 90.54816082119942, 89.69227954745293, 92.7000841498375, 74.51998248696327, 42.611354291439056, 61.01453058421612, 75.36137893795967, 41.88064970076084, 26.653639376163483, 82.09950417280197, 68.02353948354721, 71.76133051514626, 70.45882120728493, 75.517558157444, 79.03334990143776, 81.17122158408165, 82.1945370733738, 81.84974357485771, 80.52939042448997, 83.41639950871468, 81.2516176700592, 82.95511186122894, 78.91816288232803, 76.50333926081657, 82.02708005905151, 78.658986389637, 84.92178753018379, 84.3280465900898, 84.1291880607605, 81.42570152878761, 82.84003123641014, 81.01650148630142, 81.46231636404991, 86.16949617862701, 88.14102038741112, 83.71735855937004, 80.89658752083778, 78.46007466316223, 79.23467069864273, 81.51844695210457, 76.98567777872086, 71.12820088863373, 61.76537789404392, 72.68463537096977, 67.01195776462555, 69.94579553604126, 71.4540334045887, 97.90421649813652, 92.62783482670784, 57.63298563659191, 72.574213296175, 48.07600066065788, 26.781643107533455, 2.2737984638661146, 1.2105986522510648, 1.0060437535867095, 0.3249029611470178, 0.25904922920744866, 0.23999586410354823, 0.08502986311214045, 0.10916697690845467, 0.16419404331827536, 0.359290789347142, 25.32112307846546, 76.99512407183647, 86.36095270514488, 73.99042770266533, 42.47625634074211, 39.77674059569836, 13.996795937418938, 41.27955995500088, 60.6553852558136, 65.65402463078499, 77.15633422136307, 65.48077672719955, 79.6286715567112, 51.92982226610184, 0.528571349568665, 0.08907827126677148, 0.09169606360956095, 0.041290792360086925, 0.037672993130399846, 0.17282441927818581, 0.07262924336828291, 0.06428702850826085, 0.042213764318148606, 0.07000323545071296, 0.05860936871613376, 0.08643139415653422, 0.08250348109868355, 0.07257107383338735, 0.024323815887328237, 0.06285980431130156, 0.04127346692257561, 0.044021123976563103, 0.3036991786211729, 0.19513219100190327, 0.17143217992270365, 0.10707237641327083, 0.19534134306013584, 0.22113009908935055, 0.18773486372083426, 0.18028393853455782, 0.13878363417461514, 0.21197938855038956, 0.16620279959170148, 0.10428754889289849, 0.31920709647238255, 0.13442204712191597, 0.39154464611783624, 0.42729490902274847, 0.2720547735225409, 3.321935646235943, 88.7794241309166, 106.98129862546921, 82.48376235365868, 85.60174584388733, 61.93344287574291, 55.18253892660141, 78.0708159506321, 72.29631140828133, 44.76966127753258, 60.268505215644836, 100.07085263729095, 117.74629577994347, 80.31793177127838, 2.9667487554252148, 0.2061568689532578, 0.17009886709274724, 0.11636319701210596, 0.1814460675814189, 0.30442912539001554, 0.2528831991367042, 0.38028965005651116, 0.30581480416003615, 0.8308885898441076, 10.504566729068756, 4.917392609640956, 3.5973370308056474, 86.31633549928665, 84.78559523820877, 108.53206381201744, 86.09304428100586, 92.92054072022438, 91.48333624005318, 87.93883323669434, 84.50638622045517, 78.6268325150013, 81.43481343984604, 75.71811139583588, 89.55284222960472, 92.815081179142, 92.1397054195404, 93.7009884417057, 98.82247522473335, 98.47088009119034, 94.1393481194973, 102.08226710557938, 97.9306934773922, 94.15362015366554, 93.1670106947422, 94.18160945177078, 89.44716989994049, 87.41560131311417, 86.2271922826767, 84.06326159834862, 92.03913241624832, 91.3800273835659, 89.45362195372581, 90.95014125108719, 95.2794997394085, 90.82886695861816, 90.2901166677475, 80.94251945614815, 74.7596888244152, 80.0957652926445, 92.01134070754051, 90.81513449549675, 91.74411624670029, 80.16554474830627, 45.081153362989426, 61.377137526869774, 70.77343672513962, 39.48249578475952, 37.25536689162254, 83.67908701300621, 71.18771329522133, 76.0210919380188, 72.47994795441628, 81.66205644607544, 83.04960519075394, 84.66651722788811, 84.59899485111237, 84.21702414751053, 81.12072229385376, 85.87954133749008, 85.47887563705444, 86.5770623087883, 84.91918846964836, 78.78800466656685, 85.32556906342506, 82.66435146331787, 85.55406600236893, 85.54244622588158, 83.4790201485157, 84.02202621102333, 84.11415606737137, 84.19044837355614, 86.79757207632065, 91.24125123023987, 90.60597851872444, 83.83535742759705, 81.22340798377991, 80.61145842075348, 83.79460841417313, 83.83572220802307, 72.69358769059181, 68.38091790676117, 69.56267729401588, 83.6763359606266, 76.02592527866364, 72.99119532108307, 77.5798062980175, 86.25989332795143, 87.99961477518082, 61.533404141664505, 80.2896536886692, 66.2603048980236, 40.46370953321457, 0.8773466187994927, 4.078271761536598, 2.491411124356091, 1.1562295071780682, 0.3739903005771339, 1.287018726579845, 1.1685879877768457, 0.19110764289507642, 0.28377399779856205, 0.43707994802389294, 33.78887750208378, 86.49342879652977, 97.12417155504227, 87.37083971500397, 62.156863287091255, 89.54192161560059, 48.06180842220783, 41.913985311985016, 56.00933276116848, 65.47602698206902, 77.44446516036987, 75.5512623488903, 89.23235982656479, 62.98795849084854, 0.7150377344805747, 0.15073995979037136, 0.2972220105584711, 0.21966846892610192, 0.1825644841301255, 0.2535422262735665, 0.1926562824519351, 0.20020629919599742, 0.1360332200420089, 0.27093893964774907, 0.1265173134743236, 0.16489354718942195, 0.2934215316781774, 0.2427881650510244, 0.2554352965671569, 0.2253716066479683, 0.1491701987106353, 0.24695940606761724], [0.14157888886984438, 0.2076937083620578, 0.05272132118989248, 0.038885647591087036, 0.10368243878474459, 0.0989954941906035, 0.035045686454395764, 0.04145613173022866, 0.11824100132798776, 0.03037514332390856, 0.05166276627278421, 0.021234308915154543, 0.062128759163897485, 0.13780606241198257, 0.1452759568928741, 0.4462919005891308, 0.06769325627828948, 6.10356118530035, 68.0128164589405, 70.28825595974922, 71.4523158967495, 42.81296007335186, 54.72794272005558, 55.38384832441807, 29.30201556533575, 33.231496810913086, 49.31072160601616, 88.97809267044067, 95.52342385053635, 76.32788747549057, 5.780364777892828, 0.2785815467359498, 0.16789655870525166, 0.09433117025764659, 0.016600298004050273, 0.14242278499295935, 0.10672720352886245, 0.26894208742305636, 0.1686418679310009, 0.17964505328563973, 2.1445747604593635, 2.01396650634706, 1.2752323527820408, 23.293557576835155, 57.79087856411934, 79.45043832063675, 93.15884873270988, 57.334846034646034, 69.44590955972672, 64.06408354640007, 68.10340359807014, 64.75873187184334, 63.409002497792244, 70.52905663847923, 76.49091392755508, 79.8385038971901, 90.7195696234703, 88.48308563232422, 92.60873705148697, 90.35759344696999, 94.41965907812119, 91.76912650465965, 87.38552212715149, 90.05483329296112, 87.55269035696983, 86.68883711099625, 88.37152361869812, 82.28599816560745, 82.12916538119316, 77.74469465017319, 77.52419248223305, 79.8787285387516, 79.90753099322319, 80.4416911303997, 84.8784850537777, 86.48886904120445, 81.87369748950005, 79.44777086377144, 82.42729738354683, 71.49295851588249, 73.36640238761902, 78.61213490366936, 82.33848094940186, 80.87684378027916, 71.1182302236557, 58.93544554710388, 65.51264941692352, 59.81225989758968, 68.80720183253288, 22.110800743103027, 57.87330374121666, 72.43977651000023, 64.9269488453865, 69.88727107644081, 69.56105098128319, 76.88909456133842, 78.36096078157425, 80.90127646923065, 78.48548009991646, 77.06162810325623, 81.91239461302757, 76.86845406889915, 79.91902157664299, 74.74739268422127, 78.64884853363037, 77.68158003687859, 78.60235422849655, 78.52592512965202, 77.6909351348877, 78.31442847847939, 77.20542758703232, 78.79148527979851, 79.57529202103615, 82.79259458184242, 80.4345703125, 78.38712617754936, 78.31567481160164, 81.44660040736198, 75.67967265844345, 73.73988434672356, 73.34013819694519, 78.64567190408707, 81.15481406450272, 63.54391425848007, 58.83939430117607, 54.304333850741386, 56.828720793128014, 59.24100995063782, 91.34525164961815, 108.31422910094261, 59.59303066134453, 57.75010295212269, 45.41378751397133, 24.291081950068474, 20.66685162484646, 0.6681547814514488, 1.6158115211874247, 0.21351269533624873, 0.1189809745119419, 1.2069344613701105, 2.557600485160947, 0.11281688886811025, 0.10575139807770029, 0.3511192981386557, 0.9883862792048603, 37.59954862296581, 76.08491331338882, 86.43649265170097, 73.29042926430702, 45.164760276675224, 62.135459035634995, 35.829991176724434, 29.657332599163055, 35.53844042122364, 36.88662327826023, 53.00122417509556, 63.106899708509445, 71.4148423075676, 25.34862220287323, 0.7701585860922933, 0.07655280001927167, 0.10741998354205862, 0.02408601878414629, 0.01989035925362259, 0.13252660195576027, 0.06671117225778289, 0.02815893451042939, 0.03382979251910001, 0.058777795420610346, 0.006694131225231104, 0.1244346096063964, 0.05122312169987708, 0.1169379310158547, 0.009141096943494631, 0.0741905662289355, 0.08886964613338932, 0.047723179231979884, 0.06669136433629319, 0.08804444471024908, 0.05723818037949968, 0.04960999322065618, 0.029358547581068706, 0.07631306405528449, 0.11007425986463204, 0.054409677468356676, 0.00472022574285802, 0.032395284142694436, 0.052774084178963676, 0.04435465998540167, 0.06109590482083149, 0.04217299443553202, 0.18210567359346896, 0.3567369404481724, 9.584520198404789, 84.67760503292084, 84.64917495846748, 86.96246802806854, 58.00421431660652, 71.0711507499218, 36.286681070923805, 15.037443246692419, 27.379797510802746, 54.044306203722954, 99.38137963414192, 107.71451488137245, 84.00912210345268, 4.713110346347094, 0.4350615438306704, 0.1083430445578415, 0.14837961847661063, 0.028876726755697746, 0.15321147482609376, 0.08663791901199147, 0.18186806759331375, 0.1067820779280737, 0.2780543843982741, 1.3249568408355117, 1.434041743632406, 1.4873815001919866, 37.24457927048206, 71.03944525122643, 85.15656173229218, 91.47911846637726, 65.89788034558296, 78.07308822870255, 75.43084681034088, 79.96702060103416, 70.66192030906677, 71.46623075008392, 75.57131007313728, 80.6903649866581, 84.27982717752457, 94.75379034876823, 94.2663449048996, 95.40037885308266, 93.85870277881622, 94.06624764204025, 94.08042088150978, 92.71806478500366, 94.53765794634819, 93.99782091379166, 88.30147817730904, 89.86654579639435, 90.46494528651237, 86.53973311185837, 83.53221729397774, 81.79650843143463, 78.62573057413101, 83.71985882520676, 84.46784868836403, 87.17405587434769, 86.50355145335197, 89.40089598298073, 84.48762282729149, 84.70177173614502, 77.26949974894524, 74.62201461195946, 76.51311993598938, 83.30989882349968, 81.60187527537346, 73.99059489369392, 64.70292046666145, 69.16851684451103, 60.831163823604584, 71.20048820972443, 29.175336062908173, 61.42409920692444, 79.58656221628189, 65.41630938649178, 71.58968612551689, 70.1134805381298, 79.9825769662857, 82.92572423815727, 83.12725022435188, 82.6008340716362, 82.53732427954674, 81.11347988247871, 79.1532714664936, 80.60780301690102, 80.92951655387878, 79.2188711464405, 81.08957156538963, 81.48773699998856, 79.88296151161194, 81.24147221446037, 79.96949806809425, 81.61238551139832, 80.97658842802048, 81.47318378090858, 80.77359572052956, 83.58678996562958, 81.62984177470207, 83.05439293384552, 83.86791408061981, 82.71223649382591, 80.14282956719398, 76.94549113512039, 81.27275213599205, 83.85739624500275, 76.05198428034782, 64.11246255040169, 66.41878679394722, 59.15495976805687, 65.00337034463882, 78.74613851308823, 96.64626359939575, 79.91404384374619, 63.65954965353012, 69.57723051309586, 39.67889204621315, 24.118753597140312, 2.2005832800641656, 0.6456592166796327, 0.5322969902772456, 0.3247950825607404, 1.2704949569888413, 0.5966786574572325, 0.05812029710796196, 0.37555195740424097, 0.16181440616492182, 0.7043556764256209, 41.32100433111191, 88.49345907568932, 93.21856632828712, 79.10406410694122, 45.4830501973629, 32.625539526343346, 20.261808559298515, 39.57676872611046, 60.991108641028404, 54.91299659013748, 69.58698838949203, 70.77263876795769, 85.09787768125534, 36.95785045623779, 0.4387776553630829, 0.018915628061222378, 0.27389627939555794, 0.05431368808785919, 0.01915467197250109, 0.08824391916277818, 0.07001366262556985, 0.06841410431661643, 0.03758999133424368, 0.02473413449479267, 0.061244015232659876, 0.033816771538113244, 0.05672160848916974, 0.14458777819527313, 0.04136493291298393, 0.07004829865763895, 0.028042382073181216, 0.23352825490292162, 0.28211547585669905, 0.20618576818378642, 0.1996829514973797, 0.10890123608987778, 0.19114132155664265, 0.3247255878522992, 0.20833916903939098, 0.14540400705300272, 0.10259787159156986, 0.15157546964474022, 0.20399474044097587, 0.1998160927905701, 0.19923586689401418, 0.24425346142379567, 0.5922965425997972, 0.4779808345483616, 12.954448219388723, 106.45011752843857, 94.694255143404, 97.94889450073242, 65.24218752980232, 80.00678926706314, 85.76091930270195, 43.78565087914467, 46.74247741699219, 74.87268716096878, 111.08345970511436, 115.89136451482773, 96.29915982484818, 8.419099934399128, 0.480734261800535, 0.2036612044321373, 0.3045170253608376, 0.16417980892583728, 0.4269302176544443, 0.16632189945084974, 0.5635759024880826, 0.3932197921676561, 1.3873519864864647, 6.35601251386106, 10.394252948462963, 2.916440167464316, 42.20102570950985, 83.13312470912933, 90.79569473862648, 101.46754369139671, 75.02604693174362, 92.61261284351349, 84.77166518568993, 87.46303036808968, 78.01708683371544, 79.81627508997917, 80.49723654985428, 85.38749054074287, 85.56160479784012, 98.00492629408836, 99.21077638864517, 101.67036920785904, 95.51378756761551, 97.85420358181, 99.17038455605507, 95.82758992910385, 97.53782495856285, 97.80235916376114, 92.05079019069672, 92.77729600667953, 94.29889395833015, 89.18961971998215, 87.0200577378273, 83.21076214313507, 82.62022063136101, 84.77693170309067, 87.48605713248253, 89.53746065497398, 91.97703614830971, 92.98579081892967, 87.27067708969116, 85.60774192214012, 78.16730797290802, 73.36722314357758, 80.61012849211693, 85.0033463537693, 84.82742339372635, 75.26519849896431, 65.03712013363838, 66.73857003450394, 63.82373124361038, 69.82224896550179, 30.897954627871513, 66.85105919837952, 78.50693374872208, 67.73367583751678, 74.98475074768066, 73.00863638520241, 83.30586344003677, 87.16828778386116, 85.4826146364212, 86.16709470748901, 85.20247086882591, 83.75091835856438, 84.50627222657204, 85.37020906805992, 82.96350181102753, 83.53325843811035, 84.71971437335014, 84.49667394161224, 82.3235097527504, 79.22411486506462, 81.09277099370956, 82.47116982936859, 82.83357158303261, 83.64007830619812, 86.5203009545803, 85.34067705273628, 84.04474139213562, 85.47355592250824, 86.24321222305298, 81.78062528371811, 82.7845086157322, 80.95561355352402, 88.02016407251358, 82.90479496121407, 75.58880433440208, 66.29128843545914, 71.78127184510231, 65.60556963086128, 73.48699271678925, 78.75833585858345, 84.78826269507408, 78.3535435795784, 68.28738212585449, 75.73197305202484, 60.035148337483406, 31.553231365978718, 1.8515838822349906, 2.02202373649925, 0.7189692172687501, 0.2634892612695694, 2.552997269667685, 6.186959110200405, 0.25155487353913486, 0.5414306314196438, 0.5068108672276139, 0.8959826594218612, 52.7587553858757, 96.01055011153221, 106.86100468039513, 93.87971565127373, 61.79753176867962, 84.42824721336365, 49.675198048353195, 43.71820069849491, 53.78528170287609, 50.711311250925064, 74.43710133433342, 78.62175598740578, 95.33124536275864, 47.441377714276314, 0.6301279063336551, 0.11317185068037361, 0.35260766046121716, 0.10354211350204423, 0.3380083688534796, 0.16477456607390195, 0.16293372813379392, 0.15207110554911196, 0.12706148583674803, 0.1480202705715783, 0.17470080609200522, 0.14412979886401445, 0.1947824761737138, 0.4011770698707551, 0.21012786368373781, 0.1644493272760883, 0.44085629226174206], [0.2003988271462731, 0.24934060173109174, 0.1605853799264878, 0.019155822301399894, 0.01966173880646238, 0.07522847459767945, 0.07804301028954796, 0.03637663183326367, 0.10919338994426653, 0.007911391639936483, 0.05895084570511244, 0.068514190352289, 0.08974621901870705, 0.03927602097974159, 0.0790184001380112, 0.1805264427093789, 0.27329389296937734, 15.406908821314573, 74.5838950574398, 58.237050622701645, 74.33286532759666, 65.78884899616241, 45.19555762410164, 64.79605346918106, 88.87391746044159, 47.20051243901253, 77.25157991051674, 77.15454071760178, 79.67182964086533, 11.291658394038677, 0.18545494152931497, 0.08429587905993685, 0.06880267057567835, 0.06601606190088205, 0.200756854028441, 0.06461263095843606, 0.28116840636357665, 0.09217874161549844, 0.39239036792423576, 0.6690258847083896, 4.599805176258087, 1.4906245074234903, 6.642659157514572, 62.76465967297554, 48.99113595485687, 54.86743323504925, 62.66147240996361, 58.66771951317787, 66.1775453388691, 63.67012068629265, 63.288685753941536, 64.40538883209229, 72.58365198969841, 71.80745244026184, 77.04733327031136, 89.58621963858604, 91.19241625070572, 88.86849135160446, 86.66149377822876, 90.88590189814568, 95.58197110891342, 92.75401845574379, 87.67549216747284, 86.7902460694313, 84.98978868126869, 82.67417773604393, 81.04010581970215, 80.36642476916313, 79.29065689444542, 76.83790370821953, 70.52803069353104, 79.01884227991104, 81.88539326190948, 83.78809556365013, 81.91060870885849, 82.91501641273499, 82.05199912190437, 78.54752317070961, 77.59651020169258, 82.35700875520706, 81.19906648993492, 70.15723139047623, 79.82185319066048, 74.11161080002785, 71.01970911026001, 62.676614597439766, 63.75581368803978, 61.11300989985466, 64.20622631907463, 52.69019566476345, 56.17700636386871, 68.12941700220108, 61.415135487914085, 68.46102520823479, 69.54205960035324, 76.34159713983536, 73.48178699612617, 77.0756721496582, 71.39270469546318, 71.38407915830612, 70.67573636770248, 74.44712519645691, 72.05203011631966, 76.01830288767815, 69.8008181154728, 75.70616483688354, 76.43763318657875, 78.77327665686607, 74.48678746819496, 77.75718078017235, 75.44574961066246, 78.4206935763359, 74.81743052601814, 77.75637522339821, 80.4528397321701, 80.62936305999756, 75.53468003869057, 73.96997720003128, 75.02609252929688, 80.80957978963852, 74.47946146130562, 73.18849593400955, 75.7474610209465, 79.12688568234444, 67.07392483949661, 60.128634721040726, 48.22044610977173, 49.72514256834984, 62.31154918670654, 100.65577045083046, 93.89207258820534, 57.77932718396187, 62.57343113422394, 34.13832575082779, 25.090142972767353, 12.858505267649889, 0.2673053549369797, 0.9092316578608006, 0.18824525352101773, 0.020280352291592862, 0.06119005738582928, 0.2816569770220667, 0.029335093859117478, 0.03358693211339414, 0.030643644931842573, 2.2519192378968, 57.33887381851673, 81.6608177125454, 79.04477968811989, 61.67138993740082, 29.894314482808113, 59.02898892760277, 43.954202234745026, 25.954598486423492, 35.95858387649059, 36.542855724692345, 47.71839424967766, 57.0339971780777, 60.38017362356186, 14.24164054915309, 0.45412630832288414, 0.040683990155230276, 0.11457829474238679, 0.12609464552951977, 0.05758874867751729, 0.09975992114050314, 0.08533622909453698, 0.04255064370227046, 0.15247287461534142, 0.09484236157732084, 0.023292820624192245, 0.1489783832221292, 0.03785090819292236, 0.07130327037884854, 0.05834842588228639, 0.12037702850648202, 0.08622489156550728, 0.07996193700819276, 0.05100283742649481, 0.030740515612706076, 0.03400356639758684, 0.026452295423951, 0.06455750422901474, 0.033760668884497136, 0.12053440834279172, 0.03706229093950242, 0.07695291409618221, 0.038830587654956616, 0.10373208846431226, 0.02186689704103628, 0.025134046336461324, 0.11476560539449565, 0.04255287756677717, 22.624840959906578, 89.53222453594208, 69.36341598629951, 89.10420790314674, 73.8899838924408, 48.76702778041363, 42.563777044415474, 63.4434362500906, 52.91350968182087, 89.50623393058777, 90.09410798549652, 91.12307757139206, 11.468117125332355, 0.37341733288485557, 0.1484178242390044, 0.14747167500900105, 0.17259589716559276, 0.12467870197724551, 0.06938747552339919, 0.06781440446502529, 0.23528092569904402, 0.4103479371406138, 0.8211116550955921, 1.4770093630068004, 2.3334222519770265, 12.419003751128912, 81.83788061141968, 63.13988953828812, 68.2520592212677, 71.41033574938774, 68.79368215799332, 73.34407478570938, 74.69163447618484, 71.81638196110725, 75.13928085565567, 78.61116975545883, 77.10699006915092, 82.94751226902008, 93.1151282787323, 92.968410551548, 92.68530294299126, 91.59308195114136, 93.84353399276733, 94.79870393872261, 91.86972990632057, 91.78643837571144, 90.76025784015656, 88.40797886252403, 86.38992995023727, 82.77715981006622, 84.32608589529991, 86.42301097512245, 83.18782657384872, 77.15558186173439, 81.62638396024704, 83.31776440143585, 84.01662290096283, 86.41734927892685, 86.98183938860893, 83.80240559577942, 83.79685029387474, 80.7498773932457, 84.6904331445694, 82.36146211624146, 72.15096920728683, 81.84974357485771, 73.49559545516968, 68.73138830065727, 66.16180658340454, 66.8269456923008, 63.089071065187454, 64.5159325003624, 58.08164656162262, 59.68231067061424, 69.08137232065201, 68.56596797704697, 70.0622820854187, 69.49798196554184, 77.72514089941978, 77.4470642209053, 80.20399868488312, 75.44804468750954, 76.51149362325668, 74.50370416045189, 73.68168666958809, 73.89177739620209, 75.264240950346, 78.21706250309944, 77.8946042060852, 81.6212010383606, 77.58482962846756, 77.19668805599213, 80.7007384300232, 78.171746134758, 81.50361254811287, 76.45291596651077, 78.08944255113602, 79.96606305241585, 80.70101961493492, 81.47863268852234, 79.5425833761692, 79.05990287661552, 79.54587399959564, 80.557372123003, 79.01892587542534, 77.6860485970974, 79.31200414896011, 81.61703646183014, 68.56009349226952, 62.04417273402214, 52.97706127166748, 65.03551661968231, 83.43881830573082, 93.44540655612946, 73.12418058514595, 68.3861692249775, 60.35567633807659, 34.655979573726654, 18.210254944860935, 0.7486189075279981, 0.7099940394982696, 0.22112744220066816, 0.14845880563370883, 0.36659589735791087, 0.26265087188221514, 0.07504641092964448, 0.026646021942724474, 0.07524221175117418, 1.9580151024274528, 62.396968603134155, 91.3043050467968, 91.26739382743835, 70.94594746828079, 35.478555634617805, 25.867674350738525, 29.492797628045082, 36.36936083436012, 52.57530502974987, 54.76341761648655, 68.58049839735031, 64.06555786728859, 75.33572271466255, 23.502295576035976, 0.3666536067612469, 0.035156900994479656, 0.057455707574263215, 0.10590747915557586, 0.07061092081130482, 0.1175256897113286, 0.05390473874285817, 0.08696875360328704, 0.06275625244597904, 0.06149960718175862, 0.040391494912910275, 0.06796247034799308, 0.06822639290476218, 0.030235641825129278, 0.08395731128985062, 0.053369112210930325, 0.23325230955379084, 0.2933368377853185, 0.2866067457944155, 0.12867121899034828, 0.09794457597308792, 0.1711974831414409, 0.15811126737389714, 0.13407806167379022, 0.21058388374513015, 0.12739441328449175, 0.11534967561601661, 0.1625502752722241, 0.13433957967208698, 0.12042011760058813, 0.12551045656437054, 0.4391532117733732, 0.3980804735329002, 29.74508699029684, 111.03463992476463, 86.18395060300827, 101.58922076225281, 91.77300989627838, 68.72199520468712, 100.63056260347366, 134.06294703483582, 67.26988792419434, 102.1132430434227, 96.54268875718117, 103.23146983981133, 16.019936576485634, 0.5536431167274714, 0.3435860836179927, 0.26208134775515646, 0.32106721540912986, 0.30578948208130896, 0.23714172741165385, 0.5478496744763106, 1.1721996939741075, 0.9014289546757936, 2.9580662213265896, 14.509768411517143, 6.7892158683389425, 12.409509010612965, 95.46537056565285, 75.04451394081116, 84.4963775575161, 81.73241347074509, 79.66172978281975, 86.75340324640274, 85.88122844696045, 83.02425295114517, 84.05967459082603, 82.79363572597504, 80.98738744854927, 86.12217351794243, 95.18501400947571, 94.67840239405632, 94.90559980273247, 93.93857449293137, 94.44159150123596, 100.81054374575615, 96.01571783423424, 96.37176632881165, 96.03834941983223, 93.57238054275513, 89.92133885622025, 88.34986478090286, 86.99320837855339, 88.00610482692719, 84.32558432221413, 77.79593870043755, 83.81497532129288, 83.63205313682556, 87.1979033946991, 89.02891114354134, 91.6209876537323, 87.81252041459084, 89.0841069817543, 87.5884236395359, 88.19651260972023, 83.27032014727592, 73.47793400287628, 86.51013270020485, 79.00829404592514, 71.17948293685913, 66.06357425451279, 66.38860881328583, 63.56125272810459, 63.65646801888943, 58.28152723610401, 64.12968322634697, 72.59250551462173, 69.28859040141106, 71.6143012046814, 73.31532552838326, 81.2271697819233, 83.57192516326904, 84.04509857296944, 77.5452433526516, 78.68967354297638, 78.07130232453346, 76.42016172409058, 79.51889544725418, 80.6877127289772, 80.19662708044052, 80.5565893650055, 85.4365687072277, 83.23871344327927, 79.89850267767906, 80.02689778804779, 78.97091165184975, 81.0928925871849, 79.24748361110687, 83.1258974969387, 84.82456594705582, 84.15005654096603, 83.25179234147072, 82.00846865773201, 80.77602759003639, 84.43644717335701, 83.74179124832153, 82.01843932271004, 83.03724065423012, 80.17486184835434, 79.89280298352242, 68.06015431880951, 65.47519862651825, 61.29521392285824, 72.22439646720886, 82.61631444096565, 83.22108998894691, 74.33724269270897, 73.45792427659035, 69.97269809246063, 57.954326793551445, 20.51255140453577, 1.07986262999475, 1.7951049003750086, 0.3394482540898025, 0.16600788192590699, 0.35082172660622746, 0.7753232214599848, 0.1356180923175998, 0.12748026492772624, 0.2060865133535117, 2.9787603858858347, 75.20564049482346, 96.11695200204849, 96.24207928776741, 85.74856996536255, 46.755381524562836, 84.50172767043114, 65.81206575036049, 37.7586954832077, 54.41572867333889, 51.16513229906559, 68.36188852787018, 72.20757856965065, 88.51708620786667, 32.04548165202141, 0.4261989943915978, 0.15945011662552133, 0.29084304347634315, 0.24969612015411258, 0.3398905444191769, 0.17883629043353721, 0.15304597589420155, 0.18670559395104647, 0.3337658668169752, 0.18450781266437843, 0.12252787637407891, 0.14533385925460607, 0.1823183285887353, 0.13625105522805825, 0.23139701457694173, 0.2042975663789548], [0.1174621247628238, 0.16506796673638746, 0.31264553137589246, 0.06252010105527006, 0.09079147464944981, 0.020753708922711667, 0.09691686471342109, 0.06343349188682623, 0.10568319470621645, 0.05857576055859681, 0.022352061241690535, 0.08254073691205122, 0.01809720059100073, 0.007375148197752424, 0.22073334694141522, 0.10905601840931922, 0.2577956230379641, 15.921669099479914, 59.10041369497776, 58.30036662518978, 62.80795454978943, 45.814365819096565, 61.409295201301575, 31.803275048732758, 39.439520090818405, 61.356155052781105, 84.03421595692635, 86.85625612735748, 19.891041554510593, 0.7026989059522748, 0.08187189858290367, 0.29956416925415397, 0.03466764756012708, 0.133385029330384, 0.09534034266835079, 0.24066645390121266, 0.1695922770886682, 0.6243940733838826, 0.10748247237643227, 0.14007817720994353, 0.7149603136349469, 0.9733766096178442, 53.129265904426575, 64.34381693601608, 49.6382412314415, 38.552039712667465, 52.29113347828388, 58.64846974611282, 60.08467487990856, 57.17904679477215, 65.41528344154358, 76.05717480182648, 74.12059351801872, 81.15358293056488, 89.14566367864609, 88.27456042170525, 92.96139612793922, 91.80635690689087, 92.44529262185097, 87.55794167518616, 88.60185965895653, 89.82613116502762, 90.83278834819794, 82.14770078659058, 80.82910314202309, 80.99236518144608, 78.1792925298214, 87.8168597817421, 84.095149487257, 81.13111853599548, 77.84757032990456, 74.42710027098656, 82.15511038899422, 83.45423027873039, 80.64744248986244, 78.05197656154633, 78.82563784718513, 75.98269119858742, 77.29007184505463, 76.93797513842583, 72.76275157928467, 67.37287759780884, 73.18395137786865, 70.9422616660595, 64.74835082888603, 65.86277782917023, 68.63687977194786, 63.887438625097275, 72.43774741888046, 66.95054545998573, 62.41774968802929, 64.78011712431908, 64.09670859575272, 65.14213889837265, 73.13741147518158, 77.89662569761276, 72.8628458082676, 71.9177757203579, 72.30505093932152, 71.61874696612358, 70.81718757748604, 69.63320910930634, 72.01764196157455, 71.93875059485435, 72.72311970591545, 72.68147394061089, 75.70036634802818, 73.31392720341682, 74.74250614643097, 74.81584221124649, 77.19125434756279, 77.6818460226059, 78.49614232778549, 76.88623711466789, 79.87533912062645, 76.6356709599495, 81.10818296670914, 78.85343715548515, 75.8281534910202, 73.66955772042274, 76.0150882601738, 76.51881963014603, 76.36162966489792, 73.33247020840645, 74.75037172436714, 70.26046425104141, 63.66257809102535, 48.372301161289215, 49.73297394812107, 67.8986781835556, 97.78747916221619, 82.23633483052254, 58.09304974973202, 58.11480738222599, 28.32057572901249, 28.781128115952015, 5.155356265604496, 0.7311333739198744, 0.7103144691791385, 1.223001186735928, 0.15924868290312588, 0.47055567672941834, 0.19586819369578734, 0.26863569917622954, 0.13123668992193416, 0.2069167688023299, 5.296136811375618, 72.0875658094883, 83.44503477215767, 83.43583166599274, 54.098973870277405, 47.04456880688667, 47.104263603687286, 36.665129363536835, 29.45005752146244, 41.19495369493961, 32.24874794483185, 59.92319494485855, 57.510886788368225, 71.94000452756882, 19.580877497792244, 0.5211199494078755, 0.05567448264628183, 0.036847301889793016, 0.05312125344062224, 0.015984823803592008, 0.04531000813585706, 0.06620053012738936, 0.01652627433941234, 0.04278836102457717, 0.018042812298517674, 0.014039154721103841, 0.11241058527957648, 0.07390130675048567, 0.05699230314348824, 0.05408485056250356, 0.05436203158751596, 0.12027853808831424, 0.03352569750859402, 0.03987346470239572, 0.07047022445476614, 0.04903948574792594, 0.08278827284811996, 0.031896315995254554, 0.12722377869067714, 0.027183353558939416, 0.09325892271590419, 0.018204262814833783, 0.048424015258206055, 0.06298256295849569, 0.10047422343632206, 0.020634981992770918, 0.119090990483528, 25.586276650428772, 76.78941071033478, 74.3185704946518, 89.48824569582939, 63.7032625079155, 65.65243631601334, 34.722145423293114, 48.09070207178593, 68.7049113214016, 92.99217447638512, 99.50589895248413, 22.642511911690235, 0.5613831232767552, 0.09420064132427797, 0.3922578500350937, 0.01952772363438271, 0.127543926355429, 0.18515270930947736, 0.3129579755477607, 0.26140581525396556, 0.7378657220397145, 0.17193670675624162, 0.21118273754836991, 0.44667188019957393, 2.408593143336475, 67.32040241360664, 74.6607269346714, 67.85308063030243, 52.261647060513496, 62.95532584190369, 66.578948199749, 69.3361334502697, 66.10542520880699, 74.40462067723274, 82.40682408213615, 79.6608254313469, 88.38283181190491, 93.58332395553589, 89.6835932135582, 96.74947366118431, 93.12243908643723, 97.86994233727455, 91.59559741616249, 90.15867412090302, 91.79735898971558, 92.16303616762161, 85.67099332809448, 85.78697070479393, 85.98490208387375, 83.638945966959, 88.94241258502007, 89.64396134018898, 89.27059337496758, 86.10622197389603, 83.40512171387672, 84.13540452718735, 83.56883212924004, 83.19385305047035, 81.90870121121407, 81.77259251475334, 80.68909585475922, 83.32060664892197, 82.82873064279556, 75.74751421809196, 70.60170873999596, 75.39224848151207, 74.75559264421463, 69.12266090512276, 68.03346455097198, 68.88705834746361, 63.4868261218071, 75.31933039426804, 72.72356808185577, 67.67151117324829, 69.8590461909771, 67.43445709347725, 70.27874127030373, 74.0464898943901, 77.75973424315453, 74.73475456237793, 78.63787472248077, 75.96727922558784, 74.60311442613602, 74.3184868991375, 73.3555805683136, 74.02457267045975, 74.30197298526764, 74.28966164588928, 78.9414632320404, 76.65003418922424, 80.6271743774414, 75.9767635166645, 78.96797820925713, 76.07232838869095, 78.63975942134857, 81.3795568048954, 79.86252620816231, 78.78372609615326, 78.10730919241905, 80.08343875408173, 82.90262147784233, 80.17119124531746, 79.61833611130714, 79.60545480251312, 79.82215717434883, 79.21023800969124, 75.364411175251, 73.91880914568901, 82.88191258907318, 74.08495143055916, 60.23095563054085, 56.02585047483444, 66.71613603830338, 81.6835404932499, 86.99725896120071, 70.81471011042595, 70.89430063962936, 50.48282951116562, 32.36432634294033, 9.082105457782745, 0.948533364571631, 0.3617788542760536, 0.3754672931972891, 0.021937076380709186, 0.1656159685808234, 0.05633243366901297, 0.25989213085267693, 0.09882055514026433, 0.03823617931629997, 6.344015132635832, 83.45056727528572, 91.68469503521919, 95.1055146753788, 62.84798540174961, 51.47883586585522, 25.110887959599495, 39.80151526629925, 43.519421964883804, 60.3197530657053, 46.687182784080505, 80.15993624925613, 67.33548760414124, 87.39512801170349, 29.0299254655838, 0.37562753772363067, 0.027968798131041694, 0.037776927201775834, 0.06311861347057857, 0.04048204435093794, 0.02701104913285235, 0.04556031970423646, 0.0837534581660293, 0.0572994149842998, 0.0587181601440534, 0.06493133885669522, 0.08722676124307327, 0.068885212240275, 0.10829903520061634, 0.056358304937020876, 0.15093250258360058, 0.24630591535242274, 0.3084687836235389, 0.13333089707884938, 0.21015231002820656, 0.13913634727941826, 0.23600765154697, 0.12453264731448144, 0.3422843269072473, 0.37144580273889005, 0.2627282927278429, 0.2645182341802865, 0.2398434714996256, 0.2229868041467853, 0.26739865774288774, 0.3245710430201143, 0.4522095189895481, 37.105062156915665, 93.85762363672256, 88.32114592194557, 92.3373556137085, 67.62385413050652, 96.53955012559891, 51.15792788565159, 60.878311693668365, 83.66701886057854, 108.70124593377113, 114.00482654571533, 29.49593435972929, 0.7425878592766821, 0.15428983024321496, 0.5832720268517733, 0.09147410208242945, 0.3988535836106166, 0.31819635070860386, 1.096774097532034, 0.8283859491348267, 0.8712602953892201, 0.37198712525423616, 1.2699267687276006, 1.818504638504237, 1.8370887287892401, 79.44124281406403, 86.70542702078819, 80.66050618886948, 69.19571578502655, 75.65479919314384, 77.38832697272301, 80.25474116206169, 76.07951760292053, 84.31885868310928, 87.24289298057556, 86.03337228298187, 89.99083712697029, 96.0769933462143, 93.64624857902527, 98.38446512818336, 95.91744750738144, 100.09915351867676, 94.76454377174377, 93.5694471001625, 93.66115137934685, 97.69388258457184, 90.55684715509415, 90.08814990520477, 89.45508107542992, 84.72682759165764, 91.77466660737991, 92.16070309281349, 91.46662473678589, 88.04415598511696, 81.02929159998894, 84.2286667227745, 84.17391926050186, 86.61378353834152, 86.5527892112732, 84.4133672118187, 83.12902092933655, 86.75534874200821, 84.40006792545319, 76.84146031737328, 69.82644394040108, 79.58682060241699, 79.2735730111599, 69.61050912737846, 68.00077870488167, 71.63584604859352, 68.35507929325104, 76.50531515479088, 80.93803569674492, 73.24969545006752, 71.05253174901009, 72.8536731004715, 73.29048246145248, 79.85937997698784, 82.50859782099724, 79.31408643722534, 81.15888744592667, 79.90060016512871, 77.2367151081562, 77.90118545293808, 76.57172799110413, 75.94103783369064, 78.4781464934349, 76.69554814696312, 80.5783773958683, 78.54784995317459, 81.53307616710663, 78.42165872454643, 80.63834577798843, 79.18858677148819, 83.16747486591339, 84.55136820673943, 82.78624132275581, 82.24413201212883, 79.70459148287773, 83.34035038948059, 86.75743862986565, 81.26914232969284, 79.68281865119934, 81.97375372052193, 82.96659484505653, 83.68862450122833, 79.0801253914833, 74.88569766283035, 81.23375102877617, 71.64874255657196, 61.84089504182339, 60.22684805095196, 71.29148572683334, 78.77214431762695, 80.06314024329185, 73.25212731957436, 76.52495250105858, 63.80940601229668, 53.09254087507725, 8.263944759964943, 1.993272341787815, 5.0994322914630175, 3.5799059411510825, 0.27058564766775817, 1.3270340231247246, 0.8692790579516441, 0.5329129134770483, 0.28259549697395414, 0.4118559812195599, 13.127869963645935, 102.95599982142448, 95.18608555197716, 99.47736248373985, 74.99271512031555, 68.40777486562729, 69.08552929759026, 60.90502046048641, 41.42592430114746, 58.88079687952995, 46.57726228237152, 83.76373127102852, 72.48246341943741, 102.51083850860596, 34.59436967968941, 0.49491210258565843, 0.2338516086456366, 0.26245022483635694, 0.23183384269941598, 0.34873635100666434, 0.15753484127344564, 0.21041560918092728, 0.14056060288567096, 0.18676039413549006, 0.20149306452367455, 0.12451425689505413, 0.2478496715775691, 0.3157300455495715, 0.30277196899987757, 0.20143829402513802], [0.18541749275755137, 0.21586248331004754, 0.22067252051783726, 0.1405703101772815, 0.008859715362632414, 0.011925270446226932, 0.07210499024949968, 0.006831994433014188, 0.08061684522544965, 0.06387075045495294, 0.024477564766129944, 0.02826250492944382, 0.015024727763375267, 0.04993616712454241, 0.07983184594195336, 0.08662359556183219, 0.09198385363561101, 16.949254609644413, 60.260563641786575, 52.983334735035896, 59.043906927108765, 52.10202142596245, 31.540737636387348, 32.81866796314716, 48.23969207704067, 81.42300367355347, 96.45967081189156, 36.11556105315685, 1.32674167631194, 0.08453375965473242, 0.10907965581282042, 0.025133599192486145, 0.03925276207155548, 0.16861225623870268, 0.08100595325231552, 0.3527615818893537, 0.18072284467052668, 2.6164797507226467, 0.8589372597634792, 0.19131821987684816, 1.2808081973344088, 24.16326440870762, 57.88720339536667, 36.124935150146484, 49.65851314365864, 41.30284130573273, 55.40098540484905, 52.687387615442276, 62.44816705584526, 72.76264518499374, 73.84288921952248, 78.91611099243164, 82.71315604448318, 88.74062821269035, 88.99680286645889, 91.83295547962189, 90.17768070101738, 88.83840456604958, 87.6781140267849, 87.19188451766968, 90.07440984249115, 85.16705676913261, 84.150200933218, 87.31860011816025, 87.40697577595711, 89.87274706363678, 87.81404033303261, 82.6280178129673, 83.03667068481445, 84.23330247402191, 80.88018760085106, 78.01031559705734, 75.76385334134102, 77.56143048405647, 81.37421429157257, 79.72821101546288, 79.24637407064438, 79.58063453435898, 81.2822288274765, 75.34320071339607, 71.68531939387321, 69.88641232252121, 70.69544211030006, 67.53553166985512, 67.37303718924522, 67.73673087358475, 64.25410374999046, 58.638206496834755, 63.96788790822029, 57.63037897646427, 58.174863159656525, 68.78607496619225, 59.78190712630749, 66.25454440712929, 70.68819209933281, 72.98494845628738, 74.38731640577316, 74.88227784633636, 72.69961416721344, 72.99201607704163, 70.34919708967209, 72.8044581413269, 73.20548862218857, 74.4890521466732, 73.39118465781212, 72.93286085128784, 75.8338151872158, 76.31872236728668, 73.34482714533806, 76.38145700097084, 76.2976410984993, 72.94410824775696, 75.42060256004333, 75.9954509139061, 73.99096727371216, 82.72717729210854, 79.7114235162735, 74.73597049713135, 75.17173871397972, 75.93309625983238, 75.8630508184433, 71.93526238203049, 76.19902119040489, 78.21352869272232, 74.65685874223709, 74.09178346395493, 73.2611708343029, 64.3594340980053, 54.92830976843834, 57.33041167259216, 72.6110029220581, 89.82844144105911, 75.22092327475548, 59.00632694363594, 47.07696966826916, 27.949172258377075, 26.713446266949177, 1.255674446001649, 0.16374186758184806, 1.6592664644122124, 0.5003490170929581, 0.30152388440910727, 0.05413106038758997, 0.07648021797649562, 0.07058504212182015, 0.05179362546186894, 0.14103599300142378, 5.309741981327534, 74.76348102092743, 82.48096570372581, 87.4727426469326, 50.825757309794426, 52.013265788555145, 45.02612091600895, 37.645849138498306, 25.559809170663357, 39.36310239136219, 37.36106961965561, 55.26234984397888, 56.53645947575569, 66.57095342874527, 6.993555603548884, 0.03149014970404096, 0.09243954715202563, 0.06782169235520996, 0.06845402444014326, 0.11327607790008187, 0.020851791159657296, 0.032143024436663836, 0.017708927480271086, 0.09887069463729858, 0.04472748900298029, 0.11685877354466356, 0.1362631967640482, 0.0973639715812169, 0.06035031357896514, 0.054136118124006316, 0.1349986216519028, 0.044505965342978016, 0.08450432607787661, 0.06759125550161116, 0.0342281699704472, 0.016826016653794795, 0.049711485626176, 0.05063635006081313, 0.013649731281475397, 0.06472364140790887, 0.07501228697947226, 0.025498574432276655, 0.027297948581690434, 0.051022597108385526, 0.06391026981873438, 0.2365563064813614, 28.012628853321075, 76.37957990169525, 69.22469303011894, 77.89349466562271, 62.17498451471329, 47.838760390877724, 36.00142277777195, 54.24801327288151, 91.56691655516624, 105.1943989098072, 41.536118388175964, 1.2519254721701145, 0.09255526281776838, 0.1610953689669259, 0.10782147059217095, 0.13295695855049416, 0.08786481528659351, 0.11289773101452738, 0.1808200660161674, 0.2072158840019256, 3.747408790513873, 2.0401739375665784, 0.20915732748107985, 1.735459619667381, 33.54183375835419, 72.33711361885071, 49.01206523180008, 65.19488766789436, 55.69394588470459, 67.92868137359619, 63.66062879562378, 73.0160915851593, 78.96441400051117, 82.19084367156029, 83.13120201230049, 89.527018815279, 89.90596488118172, 92.37077102065086, 95.43725207448006, 92.07065552473068, 89.22115802764893, 90.07335349917412, 92.58723020553589, 92.59660050272942, 85.48594325780869, 86.59324184060097, 91.27502381801605, 92.40924015641212, 94.32266548275948, 91.6224467754364, 84.61100980639458, 86.715899258852, 86.4783588051796, 87.87018612027168, 82.59185135364532, 83.45750570297241, 80.56543529033661, 82.89388194680214, 81.54340401291847, 84.56662058830261, 84.02840226888657, 83.94175171852112, 79.99377876520157, 76.25705167651176, 71.61443039774895, 72.33894512057304, 68.99694845080376, 70.93469247221947, 71.67597189545631, 69.7545973956585, 66.6031377017498, 69.03161019086838, 68.57436552643776, 65.65862998366356, 68.51426795125008, 65.94341710209846, 70.72846993803978, 73.18721920251846, 72.57697194814682, 76.03682309389114, 76.65144771337509, 75.7108461856842, 77.37945064902306, 74.9924111366272, 75.84117919206619, 76.6669736802578, 76.35590717196465, 76.27730458974838, 78.58357563614845, 80.51681309938431, 80.0813564658165, 77.98229590058327, 78.91215920448303, 79.55150529742241, 76.30182847380638, 78.72644796967506, 75.8721475303173, 75.86320281028748, 81.44124269485474, 82.72409945726395, 78.76705259084702, 77.5859847664833, 78.44937443733215, 79.66989934444427, 77.0555180311203, 79.78232771158218, 79.41595897078514, 77.3149985074997, 73.02008137106895, 78.55278208851814, 75.3443406522274, 66.26494064927101, 63.00778202712536, 70.01658573746681, 79.26883846521378, 86.23719334602356, 69.26806390285492, 65.87848618626595, 46.42652437090874, 31.123508624732494, 1.9256030791439116, 1.0613257996737957, 0.9066850820090622, 0.37041792820673436, 0.07306397121283226, 0.16783804778242484, 0.10445571955642663, 0.11198342734132893, 0.011195834831596585, 0.5103436682838947, 8.35709011182189, 82.69493982195854, 93.36365014314651, 94.74661633372307, 61.87646113336086, 46.57380446791649, 15.969028808176517, 33.86273793876171, 40.36069706082344, 54.08559858798981, 50.11027470231056, 76.41934096813202, 61.763527393341064, 82.5051400065422, 9.939771685749292, 0.3451408236287534, 0.1562219820334576, 0.05660608207108453, 0.10107704030815512, 0.035598612448666245, 0.1198185326938983, 0.014601488364860415, 0.026007754531747196, 0.04169024592556525, 0.092038831935497, 0.011613325368671212, 0.025265293297707103, 0.044029584460076876, 0.0330094744276721, 0.279754318180494, 0.2492263406747952, 0.25561557908076793, 0.2588301768992096, 0.28949693602044135, 0.14730032795341685, 0.2347632183227688, 0.15368546970421448, 0.23681674094405025, 0.12918788735987619, 0.1262866094475612, 0.19507347227772698, 0.19877742743119597, 0.4311768163461238, 0.13426922407234088, 0.3585445450153202, 0.4158548510167748, 40.95796421170235, 93.93400713801384, 79.9669674038887, 88.34798768162727, 74.36063423752785, 50.7977794110775, 48.90622191131115, 74.00911509990692, 101.05951398611069, 119.34033304452896, 53.093217238783836, 2.0310931373387575, 0.2931809570873156, 0.223252804717049, 0.28387020982336253, 0.29871975362766534, 0.31794909678865224, 1.098562020342797, 0.7851528783794492, 0.26712388498708606, 6.038017552345991, 2.4748036405071616, 0.9082872897852212, 2.4624011060222983, 35.4030878841877, 83.51686611771584, 57.38319844007492, 82.55968227982521, 68.28229799866676, 79.9757069349289, 72.67281800508499, 81.62478804588318, 84.26955252885818, 90.9425188601017, 91.21950879693031, 91.95843234658241, 93.25626030564308, 96.75762802362442, 97.44931250810623, 96.1058109998703, 91.29270806908607, 95.80865174531937, 96.44706308841705, 95.68624511361122, 88.86392399668694, 90.50374880433083, 93.95775586366653, 96.54633656144142, 98.20607990026474, 96.06881618499756, 86.32130563259125, 89.02998268604279, 88.49966794252396, 88.11269670724869, 82.63481944799423, 82.9259142279625, 81.70132353901863, 86.97841197252274, 84.69548687338829, 88.40972676873207, 84.64928135275841, 89.89181444048882, 81.77164256572723, 78.37668433785439, 71.50536864995956, 73.44961032271385, 69.23216342926025, 72.7058458328247, 76.45522624254227, 73.80910143256187, 63.46916846930981, 68.8763277232647, 68.25487107038498, 66.167171895504, 72.65465497970581, 68.25666457414627, 72.19556361436844, 77.43694916367531, 76.62886172533035, 80.56845992803574, 81.1415983736515, 79.97396662831306, 79.68317583203316, 75.57108208537102, 79.287548661232, 79.9089977145195, 79.36049714684486, 80.05195364356041, 78.28469127416611, 83.43355178833008, 80.10647311806679, 78.65139439702034, 80.85978269577026, 79.61651220917702, 74.11642894148827, 83.4022718667984, 79.251199811697, 78.86374980211258, 84.6280024945736, 85.66855385899544, 79.95579600334167, 81.74140378832817, 81.22205525636673, 80.48962935805321, 76.98343589901924, 82.8662422299385, 84.43893224000931, 81.62438526749611, 78.34294974803925, 80.55472746491432, 72.7348230779171, 66.58201843500137, 66.47732645273209, 71.34868785738945, 74.97983381152153, 80.3712809085846, 73.1915433704853, 71.48424938321114, 63.47313545644283, 48.572634011507034, 1.4722917973995209, 2.2358539374545217, 8.526409026235342, 0.7111228758003563, 0.5843807361088693, 0.4694920900510624, 0.2769607852678746, 0.15301755163818598, 0.13960777432657778, 1.3847127906046808, 23.226198591291904, 98.65807324647903, 95.66030770540237, 102.61604726314545, 69.6290597319603, 72.75706708431244, 62.993012219667435, 54.72146786749363, 41.175232753157616, 60.385402143001556, 52.13541403412819, 77.42804244160652, 71.95192828774452, 95.68149536848068, 12.158032804727554, 0.4568034131079912, 0.32671970897354186, 0.19254647428169847, 0.24609189480543137, 0.255106792319566, 0.23241028364282101, 0.12583156902110204, 0.11815003628726117, 0.14776679745409638, 0.1450563850812614, 0.11817926948424429, 0.1123592806106899, 0.33296164590865374, 0.14576397836208344], [0.10198709147516638, 0.17454047250794247, 0.30521268490701914, 0.24259615660412237, 0.0860692112473771, 0.06784360055462457, 0.02172260868974263, 0.10583599549136125, 0.09775743601494469, 0.06174096473841928, 0.05234631025814451, 0.005722542564399191, 0.04308375435357448, 0.044818932728958316, 0.0272214461438125, 0.03535327698045876, 0.40835538937244564, 27.09140818566084, 63.3766358345747, 54.71820384263992, 64.24257516860962, 45.75760446488857, 47.37423911690712, 38.101258501410484, 64.240333288908, 96.0592482984066, 61.65921539068222, 3.722987500950694, 0.14739838050445542, 0.10752179136034101, 0.1477135409368202, 0.06923769527929835, 0.20378826011437923, 0.11047155378037132, 0.2293493103934452, 0.015862903783272486, 0.14265408273786306, 2.882445054128766, 2.4536299891769886, 1.2776599475182593, 8.2128432020545, 56.948304176330566, 54.926873445510864, 51.65492221713066, 41.481382325291634, 53.69954310357571, 50.87654158473015, 62.81199753284454, 67.90205240249634, 78.01850035786629, 74.9996155500412, 80.56921988725662, 92.49186292290688, 85.04265144467354, 88.14655289053917, 85.98698437213898, 86.64671257138252, 86.51821106672287, 88.02209436893463, 89.24122095108032, 81.73160791397095, 81.56165823340416, 90.02868309617043, 91.71185597777367, 90.61821386218071, 87.63878613710403, 81.31788611412048, 83.93819510936737, 83.1251223385334, 84.00779977440834, 80.74978619813919, 75.16873687505722, 74.51797619462013, 77.19832196831703, 81.32059916853905, 83.23226898908615, 81.92232728004456, 82.39419355988503, 79.16447326540947, 74.30248215794563, 71.52597114443779, 65.94834923744202, 69.2196772992611, 63.928111642599106, 66.2452121078968, 65.47916561365128, 66.41689449548721, 76.72982230782509, 72.20195487141609, 72.28832423686981, 65.38483947515488, 62.351956218481064, 66.18259906768799, 66.04398250579834, 70.24646580219269, 71.16568207740784, 75.01221567392349, 74.52161639928818, 69.0828238427639, 73.57004106044769, 75.93117356300354, 73.1761845946312, 72.32747733592987, 75.58415338397026, 77.46916383504868, 75.57658419013023, 74.2965316772461, 72.67961204051971, 75.16737654805183, 77.00690343976021, 75.97337409853935, 76.76400527358055, 75.89422434568405, 74.3040020763874, 72.36106753349304, 72.95065149664879, 76.85050383210182, 81.62413448095322, 75.56276053190231, 66.93821132183075, 74.30732309818268, 73.44524815678596, 70.77936440706253, 72.74095594882965, 76.27016857266426, 74.50807392597198, 69.82669472694397, 71.69855788350105, 65.09366109967232, 58.67001459002495, 62.833094000816345, 71.75071388483047, 82.35514685511589, 68.41723635792732, 56.43115192651749, 41.53239458799362, 28.51587764918804, 13.461639303714037, 0.16691348020685837, 0.18182474101195112, 0.17228946438990533, 0.04612719436408952, 0.025250867802242283, 0.1407769092475064, 0.10083659930387512, 0.12621462112292647, 0.536488521611318, 0.9275080834049731, 8.63105921074748, 70.47676384449005, 80.73976993560791, 80.54037183523178, 43.80441427230835, 64.5177412033081, 45.61851292848587, 33.618707433342934, 51.21829904615879, 35.61882510781288, 31.93524196743965, 46.48072086274624, 59.71531189978123, 40.552955344319344, 0.6217035208828747, 0.023807015786587726, 0.08090600080322474, 0.08599048422183841, 0.10437156743137166, 0.13884741434594616, 0.04386455679195933, 0.014484835737675894, 0.086657986685168, 0.019526283867890015, 0.03235860349377617, 0.044993111077928916, 0.07716889391303994, 0.12026912765577435, 0.055561624249094166, 0.04865081558818929, 0.09719241672428325, 0.12059838889399543, 0.09823709347983822, 0.04439613861904945, 0.022213212832866702, 0.06124850522610359, 0.027848265926877502, 0.0895734247751534, 0.035209482157370076, 0.09106994330068119, 0.0840621990209911, 0.013948974501545308, 0.04683915147325024, 0.013515914633899229, 0.8571498119272292, 38.78626674413681, 77.23117500543594, 72.42330059409142, 86.80326417088509, 67.05978199839592, 28.02058182656765, 26.10416606068611, 78.84943217039108, 104.89416942000389, 74.60959687829018, 3.286944036372006, 0.12257049791514874, 0.047841952546150424, 0.06743616148014553, 0.12301871058298275, 0.17941394849913195, 0.14611290651373565, 0.1346423165523447, 0.2354430255945772, 0.1673672441393137, 5.285328291356564, 2.8018316673114896, 1.244119384791702, 14.288840666413307, 67.9978908598423, 66.70493423938751, 65.28271615505219, 53.6557200551033, 65.07157668471336, 62.27027200162411, 74.85430374741554, 75.1086013019085, 81.89575150609016, 83.49193945527077, 86.81766539812088, 99.29336115717888, 91.80249631404877, 92.77449175715446, 91.6027258336544, 90.28300344944, 89.92566302418709, 89.29327055811882, 91.53342515230179, 85.29240444302559, 88.01644027233124, 92.73950323462486, 93.36300417780876, 91.77751645445824, 88.9033430814743, 87.37828731536865, 87.73890316486359, 86.43304243683815, 85.58042898774147, 88.64690244197845, 82.25617736577988, 82.47342690825462, 84.59785491228104, 81.827013194561, 83.05003836750984, 83.4034726023674, 84.0593934059143, 78.10990065336227, 76.86092287302017, 74.69180926680565, 67.8189280629158, 71.06019213795662, 66.40201449394226, 69.20907586812973, 71.46746188402176, 72.7721218764782, 79.26171004772186, 75.458904504776, 72.05620989203453, 65.92889428138733, 64.53484788537025, 68.78393948078156, 71.420678794384, 75.37129640579224, 74.24699753522873, 76.40722721815109, 77.04035684466362, 73.21755677461624, 78.85162085294724, 76.7994649708271, 77.19513013958931, 74.80394124984741, 80.2062177658081, 79.3878784775734, 77.93148502707481, 79.24410939216614, 76.6765795648098, 77.8408370912075, 77.5554496049881, 77.28077754378319, 79.84458357095718, 79.39110830426216, 77.74424627423286, 77.16084077954292, 75.54034933447838, 74.92254808545113, 83.16262632608414, 80.97021237015724, 74.40696895122528, 76.50514796376228, 77.49175742268562, 75.99060997366905, 75.75982555747032, 75.50275415182114, 79.92831587791443, 71.73459514975548, 73.65103751420975, 75.39848014712334, 67.2165235877037, 70.31983986496925, 72.17196688055992, 76.32479444146156, 79.52588707208633, 70.80440506339073, 60.39448365569115, 39.743450582027435, 18.482603430747986, 0.12356208884739317, 0.1453314398531802, 0.00972041370914667, 0.04275086030247621, 0.02887552818719996, 0.12163549574324861, 0.08742299251025543, 0.16087499563582242, 0.7351637107785791, 0.4127956589218229, 9.38579086214304, 79.70186322927475, 88.37911561131477, 90.04376068711281, 50.78934006392956, 43.92590895295143, 22.46461495757103, 37.430438697338104, 60.9562873095274, 50.96275135874748, 46.86941720545292, 64.46084305644035, 67.77967616915703, 52.534928396344185, 0.6934277003165334, 0.025043101704795845, 0.04518923844443634, 0.07457706931745633, 0.08140684658428654, 0.05083703050331678, 0.05081479946966283, 0.03968276614614297, 0.04662470790208317, 0.026159028348047286, 0.025968908666982315, 0.046850369035382755, 0.007035130456642946, 0.06059202736651059, 0.3341411263681948, 0.31751933391205966, 0.29011419508606195, 0.32577344099991024, 0.3212734137196094, 0.1282113991328515, 0.1544463195023127, 0.24078344606095925, 0.14881322567816824, 0.2340942167211324, 0.1549538446124643, 0.18533504015067592, 0.1259159660548903, 0.1258972639334388, 0.16931459511397406, 0.2215457463171333, 1.5029087732546031, 53.88941511511803, 93.22451680898666, 82.16657817363739, 95.00900745391846, 70.87788552045822, 75.09698152542114, 56.075965985655785, 88.621124625206, 114.79227349162102, 91.86007082462311, 7.469767900183797, 0.32359704840928316, 0.26136713451705873, 0.3838895709486678, 0.18190998409409076, 0.4012568952748552, 0.3570033417781815, 0.3142194781685248, 0.6638659397140145, 0.3654460434336215, 8.501242976635695, 5.276332749053836, 1.696803462691605, 13.665311224758625, 75.00280737876892, 77.5557991862297, 77.45539337396622, 64.95964229106903, 77.12569266557693, 74.2673796415329, 84.00780737400055, 81.85948625206947, 87.24461048841476, 87.29554295539856, 90.32541677355766, 100.49774453043938, 93.14064770936966, 94.87409189343452, 92.27655127644539, 90.44450238347054, 94.06199187040329, 91.92852035164833, 96.04772731661797, 88.71214494109154, 88.94151583313942, 94.86704707145691, 98.16478371620178, 96.30035296082497, 97.53647983074188, 90.42668133974075, 90.29403805732727, 87.90635257959366, 89.08794477581978, 92.81011864542961, 84.07897755503654, 81.29232108592987, 83.23619037866592, 82.21830859780312, 85.1007579267025, 85.94314992427826, 86.34067699313164, 81.88925385475159, 81.17351666092873, 76.60347148776054, 68.32166388630867, 72.65744403004646, 66.58832609653473, 73.2785815000534, 73.26832965016365, 74.35425817966461, 80.44689685106277, 76.4530223608017, 74.4001217186451, 68.02757486701012, 67.50110551714897, 72.61352598667145, 75.927624553442, 79.99469071626663, 77.61494681239128, 81.51649385690689, 80.65256461501122, 77.79784619808197, 84.46546241641045, 80.86333930492401, 79.84038099646568, 77.96250656247139, 83.10417026281357, 82.33300924301147, 81.213368922472, 82.21823260188103, 78.47384512424469, 80.27411252260208, 82.16110646724701, 79.64961603283882, 81.47910386323929, 79.12202194333076, 79.61583584547043, 78.97033408284187, 78.68292510509491, 81.01649388670921, 87.88189709186554, 82.09064304828644, 76.92736610770226, 80.52661657333374, 77.99060225486755, 76.69503897428513, 78.28173503279686, 78.74766603112221, 81.33869379758835, 76.67570561170578, 74.65640276670456, 73.19984212517738, 65.63849866390228, 72.24576652050018, 69.93824914097786, 73.6814358830452, 74.05824646353722, 71.568513661623, 69.85577836632729, 61.16797015070915, 23.891601786017418, 0.26087900914717466, 0.679234511917457, 0.23312412580708042, 0.23320101230638102, 0.1654890167992562, 0.2725026448024437, 0.18264888116391376, 0.35283077973872423, 1.175443532411009, 2.6492128567770123, 25.159259364008904, 93.31606149673462, 92.1197260916233, 99.88676011562347, 61.783757507801056, 101.33699789643288, 65.58450356125832, 54.214404076337814, 62.660955637693405, 48.01751419901848, 46.10366329550743, 66.80691316723824, 76.04508385062218, 62.94123999774456, 0.7482687919400632, 0.12606556818354875, 0.15170302998740226, 0.2213528918218799, 0.2484868498868309, 0.1683807952213101, 0.17136983951786533, 0.16759958089096472, 0.20234598516253754, 0.1199625241861213, 0.07928846767754294, 0.1123639041907154, 0.20169755589449778, 0.29135586752090603], [0.1337846610113047, 0.20898664835840464, 0.17166631267173216, 0.2762153424555436, 0.1992598085780628, 0.12683763925451785, 0.030368449151865207, 0.09089546438190155, 0.03538010561896954, 0.06370555580360815, 0.020110021978325676, 0.160783548199106, 0.007473446121366578, 0.016739215061534196, 0.1552605297183618, 0.19816227606497705, 6.960627045482397, 40.36256656050682, 62.161749824881554, 57.255175709724426, 47.865780740976334, 47.56960943341255, 53.581247851252556, 57.88218766450882, 85.11760622262955, 82.45760455727577, 9.92244366556406, 0.3851368243340403, 0.06505863944767043, 0.0477609990775818, 0.07479065199731849, 0.22130569122964516, 0.1622345656505786, 0.26634243316948414, 0.24494484619935974, 0.38792899169493467, 0.16915383108425885, 1.7509635002352297, 0.060963694922975264, 2.2582561103627086, 46.19323208928108, 51.331418976187706, 44.89681385457516, 57.31838911771774, 53.31627666950226, 52.739300429821014, 63.21572586894035, 67.44574248790741, 77.909005433321, 78.46132099628448, 94.66245844960213, 81.21321693062782, 87.6270903646946, 89.61420893669128, 88.57900768518448, 88.9901152253151, 81.56985819339752, 81.49156719446182, 85.71862757205963, 82.11214229464531, 84.37308177351952, 89.43841516971588, 85.90968132019043, 88.01175132393837, 85.82332715392113, 83.75709682703018, 84.57254067063332, 82.16946601867676, 82.80582547187805, 80.31559109687805, 81.75783410668373, 79.72207054495811, 78.14622670412064, 77.76764541864395, 78.66874426603317, 83.08594644069672, 79.53953593969345, 80.16520276665688, 79.96503710746765, 76.3351146876812, 75.1615172624588, 70.32112419605255, 69.57011729478836, 67.27481245994568, 63.88899654150009, 74.29052039980888, 77.80717089772224, 71.57524690032005, 68.97448405623436, 67.83997133374214, 65.18276631832123, 64.96414124965668, 67.4923887848854, 65.16739994287491, 67.85649284720421, 73.46453592181206, 73.2549923658371, 71.99637070298195, 70.62041133642197, 71.35064095258713, 71.2772136926651, 70.95772683620453, 70.40840551257133, 71.4307102560997, 72.43973851203918, 73.66160094738007, 73.7555319070816, 73.67489263415337, 73.03713485598564, 72.16065868735313, 74.09415453672409, 73.25273528695107, 75.88898062705994, 77.39038646221161, 78.06038931012154, 75.04401236772537, 73.38160157203674, 71.24949797987938, 80.50220668315887, 75.97011387348175, 68.44312816858292, 69.84234228730202, 70.35602912306786, 72.9127599298954, 75.74205011129379, 74.73521813750267, 73.58691975474358, 65.33927232027054, 68.12260776758194, 61.1490585654974, 63.83423388004303, 73.4949266910553, 68.81505981087685, 70.46253740787506, 64.11185458302498, 52.085442915558815, 36.158593744039536, 27.12119858711958, 3.6028089746832848, 0.1127692949376069, 0.19349047128343955, 0.17944707797141746, 0.011000910672009923, 0.027031964709749445, 0.06656214900431223, 0.13405305129708722, 0.3922381979646161, 1.3917979854159057, 0.7761987182311714, 23.223850317299366, 79.65253427624702, 76.55912026762962, 62.48664379119873, 39.11256283521652, 43.24266001582146, 53.420375883579254, 63.21458213031292, 39.71121311187744, 34.944467693567276, 31.429671496152878, 50.63360922038555, 63.8878870010376, 11.542993057519197, 0.2939110225997865, 0.28730510675814, 0.08901547073037364, 0.044471158616943285, 0.08684782063937746, 0.12857643188908696, 0.0820590830699075, 0.07695929656620137, 0.10240706542390399, 0.01821439127525082, 0.05858726013684645, 0.08565049894968979, 0.03218545301933773, 0.12337859283434227, 0.09462632238864899, 0.050267766127944924, 0.18445684196194634, 0.039717109029879794, 0.008564325744373491, 0.053296147962100804, 0.041527340799802914, 0.07532425617682748, 0.01983715654205298, 0.03458533225057181, 0.0875763276417274, 0.02646618100698106, 0.04935891352943145, 0.07485910769901238, 0.138982321950607, 9.076540656387806, 51.242355555295944, 74.92042019963264, 75.84081441164017, 51.15294635295868, 47.76254788041115, 40.24546064436436, 60.46483688056469, 96.4973571896553, 94.93861243128777, 11.625348888337612, 0.6245953438337892, 0.06617952734814025, 0.25162454636301845, 0.22423708549467847, 0.1329093868844211, 0.23944571003085002, 0.17599141574464738, 0.21586031623883173, 0.5840362014714628, 0.21353812131565064, 2.3620470659807324, 0.07216540849185549, 3.7153263995423913, 58.848316222429276, 67.38285586237907, 63.9528863132, 69.74489271640778, 64.67521235346794, 64.72495168447495, 73.74932304024696, 74.35495734214783, 84.48751643300056, 85.30886515974998, 98.89287024736404, 88.98424834012985, 91.93165138363838, 94.46128964424133, 93.50288987159729, 92.554050385952, 88.12075987458229, 86.93786814808846, 90.25355502963066, 86.57710790634155, 90.38736864924431, 88.98889169096947, 86.44707128405571, 89.07877206802368, 86.59535452723503, 87.500009983778, 87.98209011554718, 86.83630719780922, 87.71159783005714, 87.0266541838646, 87.2262878715992, 84.86892476677895, 84.82749179005623, 82.46089518070221, 84.74469423294067, 83.27657461166382, 82.63375550508499, 81.39813780784607, 79.56447020173073, 79.92618799209595, 80.04161819815636, 76.53081938624382, 71.70484274625778, 71.01196512579918, 68.39940771460533, 73.8703465461731, 80.17849445343018, 73.92209216952324, 71.4457194507122, 72.42789074778557, 70.34565567970276, 69.1173867881298, 69.76886942982674, 69.66560617089272, 72.58094653487206, 78.06263878941536, 77.13713765144348, 73.79006445407867, 73.36778551340103, 75.29773235321045, 76.00618153810501, 75.88120624423027, 76.11990183591843, 77.22657725214958, 76.61991700530052, 74.79670643806458, 74.22015577554703, 77.06816375255585, 77.37556725740433, 75.81800803542137, 77.52030149102211, 76.14849910140038, 78.42114955186844, 79.8260709643364, 80.87041452527046, 77.93330132961273, 76.71912208199501, 72.35744252800941, 77.69030436873436, 78.91337513923645, 77.54685446619987, 73.91358062624931, 73.95342528820038, 74.79660004377365, 79.92165863513947, 76.2201252579689, 74.92996528744698, 73.0581097304821, 70.3916484117508, 69.73022550344467, 68.89150410890579, 80.61642855405807, 72.86424413323402, 68.93617451190948, 75.75839683413506, 69.43546772003174, 54.65595178306103, 37.126261219382286, 6.311759613454342, 0.15338457335019484, 0.05157543404493481, 0.14568939252058044, 0.05311865963449236, 0.03276942305092234, 0.10801258104038425, 0.09783015164430253, 1.145218766760081, 1.7098945914767683, 0.5005303386133164, 28.397206217050552, 89.76075187325478, 84.67095538973808, 73.69724303483963, 46.21493652462959, 28.538245148956776, 35.65144635736942, 73.5042741894722, 43.50504353642464, 29.60700999945402, 51.728543266654015, 61.51484213769436, 77.64839261770248, 15.218747667968273, 0.43676308065187186, 0.19251750083640218, 0.1554756931727752, 0.04417707517859526, 0.007575089739475516, 0.1005907851504162, 0.06186989805428311, 0.033479120320407674, 0.10662457934813574, 0.06786525642382912, 0.019870052237820346, 0.10127696004929021, 0.04333003606006969, 0.27070201642345637, 0.4476580460323021, 0.15308630419895053, 0.44486504746600986, 0.3223606897518039, 0.2509160031331703, 0.0957414586446248, 0.12499429285526276, 0.14917487424099818, 0.0900379943777807, 0.21595590485958382, 0.2734646463068202, 0.09781110071344301, 0.10430379450554028, 0.2957467100350186, 0.35394385282415897, 12.19938788563013, 67.74151861667633, 86.44554376602173, 86.1341580748558, 70.91564029455185, 73.30071151256561, 85.87254211306572, 86.12838998436928, 101.41638323664665, 116.19786366820335, 22.411786392331123, 1.0925350687466562, 0.36555003316607326, 0.3077791800023988, 0.48894606647081673, 0.3730372939025983, 0.41361038864124566, 0.39128952543251216, 0.5990966933313757, 1.3313640095293522, 0.4172933113295585, 5.081067876890302, 0.1861194011871703, 3.2261643977835774, 62.67620801925659, 71.41246363520622, 73.37387278676033, 84.25721079111099, 72.98455327749252, 75.65213933587074, 81.46870002150536, 85.35494148731232, 91.1811612546444, 90.88942050933838, 100.68408653140068, 91.54833555221558, 97.26449802517891, 98.01184192299843, 97.60049879550934, 96.53935253620148, 89.63731169700623, 89.17845591902733, 91.63741037249565, 89.45402473211288, 92.58678182959557, 96.29987418651581, 89.08077076077461, 92.71395340561867, 90.95625132322311, 92.27370902895927, 90.69475695490837, 91.32081896066666, 93.5646365582943, 88.75255957245827, 88.7743704020977, 84.00256365537643, 84.82898131012917, 82.42088332772255, 84.99413564801216, 85.84135338664055, 84.52599316835403, 84.71198558807373, 85.43599113821983, 82.76713594794273, 81.3348788022995, 76.98133081197739, 72.87716343998909, 73.047044724226, 69.73416209220886, 76.87970906496048, 85.71289747953415, 79.45591002702713, 75.28159841895103, 77.9417672753334, 73.18104073405266, 72.44698852300644, 73.40572267770767, 72.07250341773033, 73.66268008947372, 81.7849950492382, 80.49994200468063, 75.78384786844254, 76.04614019393921, 78.98085191845894, 78.21053445339203, 76.83960601687431, 78.71442541480064, 80.3250677883625, 80.54756864905357, 78.36096838116646, 78.41418072581291, 79.11329001188278, 78.74000564217567, 77.06510111689568, 79.54825267195702, 76.98171079158783, 81.35561808943748, 82.05606490373611, 83.43767836689949, 80.48795744776726, 80.92625632882118, 75.27035862207413, 84.89869236946106, 79.77244064211845, 77.79048979282379, 75.00428929924965, 74.16655585169792, 76.14284500479698, 84.07687246799469, 79.3147324025631, 76.93204745650291, 76.71738937497139, 73.23460265994072, 68.50148543715477, 67.98637747764587, 78.03790211677551, 71.22699558734894, 67.5659528374672, 72.91752487421036, 72.46309205889702, 70.60857117176056, 55.34405305981636, 6.385087128728628, 0.15805735776666552, 0.4261118365684524, 0.3573341912124306, 0.30768721306230873, 0.1550815682276152, 0.21758529008366168, 0.334048357908614, 4.01290244422853, 2.87472125608474, 1.991109901573509, 46.412544921040535, 91.78325414657593, 89.96654883027077, 84.13186311721802, 54.37072768807411, 60.722706243395805, 76.59281685948372, 76.91558673977852, 52.88459323346615, 52.11481533944607, 46.46145969629288, 67.13772341609001, 91.38189688324928, 17.642200626432896, 0.648258039727807, 0.42816981207579374, 0.30828636372461915, 0.11342559097101912, 0.26126866636332124, 0.2258079597959295, 0.13792673562420532, 0.11662322329357266, 0.1786322591942735, 0.2185858684242703, 0.09708822661195882, 0.2616415807278827, 0.2871265757130459], [0.1800059003289789, 0.18097820284310728, 0.15270610194420442, 0.2737112174509093, 0.13389700732659549, 0.10626552830217406, 0.0522656647808617, 0.12177885640994646, 0.05788230890175328, 0.03432757694099564, 0.09412422979949042, 0.058161419510724954, 0.1167274579347577, 0.07610968590597622, 0.0784757046494633, 0.09267035507946275, 15.908952131867409, 57.44172289967537, 60.902166813611984, 56.529224663972855, 89.61605563759804, 107.29243353009224, 40.60133434832096, 55.340523049235344, 86.98259934782982, 23.727099113166332, 0.5387382977642119, 0.050834681605920196, 0.16906043922062963, 0.09730580204632133, 0.2940881880931556, 0.12685125024290755, 0.12873784900875762, 0.1358375750714913, 0.2190900093410164, 0.1580665455549024, 0.10665756039088592, 0.17946126783499494, 0.5554712936282158, 24.7003123909235, 72.61904329061508, 82.22373470664024, 70.48092842102051, 52.21134915947914, 63.082246631383896, 65.49502596259117, 72.25719630718231, 70.63545852899551, 78.9079262316227, 85.64975246787071, 87.81081050634384, 89.29738193750381, 80.03297746181488, 85.99687904119492, 88.3182580769062, 80.48152819275856, 82.74511232972145, 82.3238517343998, 83.75078916549683, 81.98697701096535, 87.80970096588135, 82.74689823389053, 85.34565478563309, 86.39936864376068, 84.67488437891006, 88.35586845874786, 83.81663203239441, 82.24363043904305, 83.42092126607895, 84.31646481156349, 80.96772730350494, 82.76400491595268, 78.00231322646141, 75.37425264716148, 76.0368762910366, 77.57493495941162, 80.86780786514282, 79.46318283677101, 78.95247504115105, 76.64565682411194, 75.53420126438141, 71.63922026753426, 70.16513496637344, 64.27083045244217, 68.65246653556824, 65.53342670202255, 68.69687095284462, 69.79633435606956, 67.36302852630615, 70.96901223063469, 74.54587429761887, 68.86657744646072, 70.8884109556675, 68.60498428344727, 69.85132500529289, 74.91278260946274, 74.95610788464546, 76.52619123458862, 77.59762734174728, 76.9704557955265, 77.34022155404091, 73.76655891537666, 71.90827623009682, 73.76028925180435, 72.43937373161316, 71.83444619178772, 71.06397673487663, 72.38068968057632, 72.79156923294067, 71.92633286118507, 75.19758492708206, 74.16350081562996, 74.4551807641983, 70.7808767259121, 75.45243725180626, 78.146021515131, 78.97227197885513, 76.66970193386078, 69.75041002035141, 73.07452484965324, 76.60758286714554, 72.02341765165329, 71.32527351379395, 70.27545064687729, 73.34935650229454, 76.54851883649826, 73.15241307020187, 73.03002923727036, 62.943113297224045, 65.24363905191422, 64.56105127930641, 66.08954966068268, 66.98579236865044, 61.72563202679157, 64.82239365577698, 62.67380654811859, 44.542266279459, 31.44538175314665, 16.16137258708477, 0.2920803223969415, 0.08356950944289565, 0.17167391226394102, 0.17711222200887278, 0.5179696809500456, 0.23888005991466343, 0.21312496770406142, 0.30300316284410655, 0.38291602162644267, 0.9767973760608584, 1.4701541746035218, 37.737747207283974, 78.84677991271019, 82.94728428125381, 49.278510734438896, 36.915858909487724, 46.38324849307537, 30.771385319530964, 61.92683883011341, 86.51815786957741, 51.5818939357996, 44.98441435396671, 72.40045621991158, 31.363615840673447, 0.04163874087680597, 0.027071085169154685, 0.05363713142287452, 0.019386429848964326, 0.1430246073869057, 0.08995193493319675, 0.08301596375531517, 0.03694851227919571, 0.03486633162538055, 0.010453242794028483, 0.06470731415902264, 0.09513419630820863, 0.057495527507853694, 0.09339364478364587, 0.05909443643759005, 0.0948899332433939, 0.09403958785696886, 0.03192791293258779, 0.04124611506995279, 0.04058088357851375, 0.09090028092032298, 0.019833766782539897, 0.034546425158623606, 0.06947208035853691, 0.09725390365929343, 0.060053758788853884, 0.03461692176642828, 0.05885238497285172, 0.05388169505749829, 22.569109350442886, 68.50223019719124, 75.7656392455101, 68.57104450464249, 99.96321961283684, 99.13648277521133, 38.461391776800156, 68.271863758564, 96.91167935729027, 31.675468906760216, 0.6361533142626286, 0.28559264552313834, 0.3398426907369867, 0.07349055769736879, 0.3308105457108468, 0.22988074750173837, 0.15227118856273592, 0.07373372238362208, 0.2521279006032273, 0.3985377255594358, 0.2918412914732471, 0.1387826248537749, 1.1819980619475245, 34.301583990454674, 82.12889939546585, 90.32141178846359, 84.67254370450974, 68.23736160993576, 73.84458392858505, 74.43501904606819, 75.56124061346054, 79.30576488375664, 84.75425451993942, 90.0749646127224, 90.42690172791481, 92.32304558157921, 84.0116223692894, 90.58520123362541, 91.89275667071342, 84.98703002929688, 89.94796022772789, 85.60648798942566, 86.8201656639576, 85.61062216758728, 91.34506165981293, 86.02286204695702, 88.78281354904175, 90.36773890256882, 87.1471457183361, 88.90204355120659, 88.4479071199894, 86.5021151304245, 88.94830226898193, 86.97543293237686, 85.75968816876411, 84.19911190867424, 85.54351776838303, 83.4960812330246, 81.80910095572472, 81.339590549469, 83.94266366958618, 78.88309076428413, 81.2998902797699, 78.42076197266579, 76.4022570848465, 75.54554745554924, 75.43141677975655, 68.8024976849556, 69.43897113204002, 67.51277849078178, 69.84086036682129, 69.85172778367996, 68.89603346586227, 74.76513013243675, 75.74859336018562, 73.45686793327332, 73.65878909826279, 69.88397285342216, 73.99586901068687, 78.64779219031334, 77.30022490024567, 78.22974622249603, 78.22738274931908, 79.29793730378151, 81.50039792060852, 76.69922634959221, 75.71879535913467, 77.89192155003548, 76.87036156654358, 76.37220069766045, 74.94926065206528, 74.69532787799835, 76.57114282250404, 74.59157064557076, 75.93786120414734, 76.59135773777962, 78.55585992336273, 73.76245513558388, 75.27584552764893, 81.33781984448433, 79.418064057827, 76.77581503987312, 72.66241416335106, 74.41329181194305, 79.357700496912, 77.55338251590729, 75.05944713950157, 73.06090638041496, 73.32322910428047, 79.7513821721077, 77.41782858967781, 75.1135866343975, 70.12348160147667, 70.01467823982239, 71.18885323405266, 65.7577134668827, 73.82101759314537, 69.05791237950325, 66.18625447154045, 71.54079034924507, 64.0436102449894, 45.88652014732361, 22.81734623014927, 0.4998061212245375, 0.2340797003125772, 0.12763121776515618, 0.07864663610234857, 0.48499217082280666, 0.28198604530189186, 0.4804753710050136, 0.15196184656815603, 0.9803027473390102, 1.882228881586343, 1.5228180424310267, 46.32703050971031, 90.66117435693741, 88.64397659897804, 57.509591057896614, 37.23062641918659, 25.588944107294083, 22.08329401910305, 66.17775812745094, 91.68311432003975, 56.91260889172554, 54.80061002075672, 81.61351785063744, 38.18324290215969, 0.08205468955566175, 0.0332730221998645, 0.13106415543006733, 0.02525120733480435, 0.019055457960348576, 0.019578224928409327, 0.06552717211889103, 0.08051680371863768, 0.04177907729172148, 0.011144420695927693, 0.026551980699878186, 0.029918117652414367, 0.061330816824920475, 0.41922966367565095, 0.3883522830437869, 0.22305128193693236, 0.34589713148307055, 0.16256679547950625, 0.17997308255871758, 0.11312634218484163, 0.1960268203401938, 0.1530093137989752, 0.11588123146793805, 0.18004233977990225, 0.2624013915192336, 0.16479800309753045, 0.17159812414320186, 0.24173826357582584, 0.22145152324810624, 30.436894968152046, 85.13598963618279, 84.53456550836563, 84.12371635437012, 107.1717520058155, 140.6821310520172, 64.32544872164726, 76.16643413901329, 108.48688423633575, 48.96583691239357, 1.137123538646847, 0.36405911785550416, 0.7246884447522461, 0.1376861016615294, 0.9141309605911374, 0.4117085016332567, 0.3120581363327801, 0.4348415118874982, 0.8791416662279516, 1.1306080757640302, 0.7397739321459085, 0.6078204908408225, 1.213041446171701, 36.36592581868172, 89.79741230607033, 95.38030833005905, 91.39692887663841, 73.73807564377785, 81.96509018540382, 80.08201763033867, 83.89204278588295, 86.02886572480202, 91.51419058442116, 94.92763862013817, 98.82035493850708, 94.41273584961891, 92.75330409407616, 94.41254585981369, 97.38695025444031, 87.81736135482788, 88.13386157155037, 88.55761483311653, 89.73875105381012, 88.6089576780796, 94.06617924571037, 89.49601247906685, 90.6884416937828, 92.63373970985413, 88.10244485735893, 92.0959697663784, 92.66309693455696, 90.76319888234138, 91.04798600077629, 89.79137063026428, 87.3110993206501, 89.78265389800072, 86.12333625555038, 83.72753441333771, 84.35700863599777, 83.23228418827057, 85.34732669591904, 83.19997072219849, 86.5647965669632, 84.63979706168175, 82.13551104068756, 78.04242387413979, 77.92370304465294, 69.20152947306633, 73.80024030804634, 70.52699714899063, 73.53255987167358, 73.08490589261055, 71.69024392962456, 77.1512120962143, 78.33529695868492, 76.57631814479828, 76.49026796221733, 73.5770782828331, 75.31670853495598, 81.69837489724159, 81.24745309352875, 82.58345380425453, 84.51214671134949, 81.74133539199829, 83.86556580662727, 78.46016585826874, 75.89742377400398, 80.31045377254486, 79.73933681845665, 80.03888234496117, 78.61690744757652, 80.07640913128853, 79.57728311419487, 75.82836627960205, 78.47252279520035, 78.04661124944687, 77.83066883683205, 74.14298951625824, 80.0268141925335, 82.61029556393623, 82.11163312196732, 80.3781433403492, 74.57020819187164, 78.67998406291008, 79.54032629728317, 79.28881019353867, 76.73903301358223, 74.97838228940964, 76.4429073035717, 83.8872018456459, 78.98825392127037, 78.34289655089378, 72.86374256014824, 72.27928832173347, 74.96851041913033, 66.73354670405388, 70.08438929915428, 69.51375871896744, 67.4640043079853, 72.17059135437012, 69.84397619962692, 62.69109942018986, 33.03112976253033, 0.435826163738966, 0.39313913555815816, 0.1545154134510085, 0.79832314979285, 1.708164734300226, 0.7069038553163409, 1.0278240661136806, 1.235739290714264, 1.5575575595721602, 2.156236572191119, 6.017149547114968, 70.67742347717285, 93.33627641201019, 94.29422780871391, 72.86487489938736, 56.587194353342056, 66.50397822260857, 46.97506673634052, 79.96857851743698, 103.18509712815285, 67.92064100503922, 63.66257429122925, 93.21057915687561, 44.191176518797874, 0.20523795654298738, 0.2058132248930633, 0.2316487510688603, 0.11096889662439935, 0.24680159578565508, 0.24248913890914991, 0.1283526446786709, 0.14564021781552583, 0.11038729775464162, 0.19278641062555835, 0.0874315197870601, 0.21523605129914358, 0.20554045593598858], [0.07063371958793141, 0.12695075740339234, 0.23341378604527563, 0.11638833355391398, 0.17132851673522964, 0.07631955784745514, 0.03569513246475253, 0.026550060392764863, 0.09733069367939606, 0.06819776084739715, 0.03178972132445779, 0.03755071316845715, 0.0606556999264285, 0.03623684460762888, 0.08685079665156081, 0.11738011744455434, 18.73048882931471, 50.00936731696129, 40.74741370975971, 48.15282493829727, 31.64274126291275, 28.042535148561, 38.474622666835785, 77.54843518137932, 51.929795667529106, 0.32550968171563, 0.26488500356208533, 0.12775664072250947, 0.07083929449436255, 0.004161061533523025, 0.1495265928679146, 0.12484844599384815, 0.023738103664072696, 0.19086130923824385, 0.281566078774631, 0.33956076367758214, 0.16244940256001428, 0.34991164575330913, 12.383962981402874, 63.465710654854774, 81.40145123004913, 79.53308388590813, 76.93630322813988, 82.05294147133827, 71.21634855866432, 65.31502962112427, 73.51470082998276, 82.06203058362007, 82.15115860104561, 86.19569957256317, 84.35286685824394, 89.52022477984428, 82.84133076667786, 74.99116480350494, 84.81204181909561, 85.48753157258034, 82.98247799277306, 80.17773449420929, 83.98093521595001, 81.0248002409935, 86.62598088383675, 84.70935612916946, 80.21649241447449, 86.46281763911247, 84.71846044063568, 81.02293834090233, 82.83933967351913, 84.7072434425354, 86.2296013534069, 80.5446808040142, 79.3937985599041, 77.07184955477715, 80.55731132626534, 72.12215915322304, 69.98745650053024, 73.90015214681625, 71.82759135961533, 76.21333122253418, 77.72882670164108, 76.28738164901733, 73.43545988202095, 69.27852854132652, 68.73290821909904, 65.47411188483238, 63.43883089721203, 66.6313473880291, 70.31741559505463, 71.94237560033798, 75.78163638710976, 69.42742735147476, 68.88921663165092, 68.4836719930172, 68.19205284118652, 67.58316591382027, 72.17779576778412, 66.97551012039185, 70.5351135134697, 71.42947152256966, 72.1909050643444, 73.29797565937042, 74.70858916640282, 73.42884823679924, 70.67649632692337, 69.05257746577263, 71.23514235019684, 71.08565837144852, 73.19905176758766, 71.69418051838875, 70.61097264289856, 66.42515525221825, 69.35543641448021, 70.60630649328232, 71.31144985556602, 71.85940325260162, 67.36680552363396, 73.8253265619278, 77.69158110022545, 75.32275781035423, 75.86248084902763, 71.86834797263145, 72.15281590819359, 74.13064017891884, 68.60836610198021, 68.88220980763435, 68.55041921138763, 72.68024280667305, 77.03401878476143, 74.13988128304482, 72.94910877943039, 64.13462296128273, 59.42474149167538, 52.22499422729015, 74.43981438875198, 69.39985603094101, 60.125359296798706, 60.46178184449673, 59.091138392686844, 35.06691612303257, 29.984139762818813, 6.0553213488310575, 0.3089484485099092, 0.19034875236684456, 0.19120970304356888, 0.0954390483093448, 0.05777914295322262, 0.1029805229336489, 0.12253501583472826, 0.5755404511000961, 1.2629181635566056, 1.0056070145219564, 4.19869489967823, 23.01180649548769, 77.35820218920708, 69.92596060037613, 27.488340586423874, 31.581688039004803, 43.50376680493355, 23.907173350453377, 18.45665082335472, 47.89459079504013, 56.53093837201595, 55.05626030266285, 40.62968082726002, 0.36517186439596117, 0.09030703775351867, 0.0835887978610117, 0.04632721058442257, 0.0734925911820028, 0.0325769062328618, 0.022164822948980145, 0.04140742828894872, 0.036445889054448344, 0.04780135706823785, 0.009303459373768419, 0.06595897590159439, 0.05100274094729684, 0.044213677902007475, 0.046117171659716405, 0.0669439320336096, 0.16435888916021213, 0.06923948385519907, 0.04940257407724857, 0.05210711977269966, 0.02902675561927026, 0.06928592003532685, 0.028141896655142773, 0.10671971525880508, 0.09795446138014086, 0.11591873961151578, 0.054674112107022665, 0.08085365712759085, 0.15399899741169065, 27.085263915359974, 61.17889456450939, 52.29006953537464, 66.72125056385994, 58.461789563298225, 26.44145116209984, 37.787338346242905, 93.23528543114662, 59.47248212993145, 1.606922848150134, 0.33710205811075866, 0.08136183532769792, 0.11270810486166738, 0.056673751096241176, 0.37382456415798515, 0.33087971387431026, 0.04908102746412624, 0.1659615125390701, 0.3136709122918546, 0.9664001839701086, 0.14527610532240942, 0.5048374074976891, 18.08503646403551, 73.92598316073418, 90.41545674204826, 88.61905753612518, 84.33235555887222, 88.64404499530792, 76.39135926961899, 69.97399002313614, 79.69528198242188, 87.64694809913635, 86.46458834409714, 90.1202429831028, 89.31191235780716, 90.87064191699028, 89.31916236877441, 79.07103627920151, 87.53088712692261, 91.40095666050911, 85.39533331990242, 85.52805259823799, 87.01840102672577, 86.45281657576561, 89.29586201906204, 88.68283331394196, 82.995465695858, 87.99443185329437, 84.69811633229256, 83.97484794259071, 85.77578410506248, 87.71577760577202, 87.76434659957886, 81.06816351413727, 80.71877986192703, 81.45264968276024, 84.593196362257, 78.96122977137566, 75.74825897812843, 76.83514505624771, 76.24118372797966, 79.2941527068615, 79.31654870510101, 80.15214666724205, 78.87584075331688, 73.44717085361481, 70.87387293577194, 72.29227602481842, 65.07214665412903, 69.72954913973808, 73.89173179864883, 75.03373771905899, 78.80283147096634, 72.82782688736916, 72.04407334327698, 67.8279259800911, 67.83572316169739, 69.00618955492973, 73.65957945585251, 71.01827278733253, 74.97109428048134, 74.04446080327034, 73.28453958034515, 76.58829510211945, 75.77294245362282, 74.10415560007095, 73.13554957509041, 73.43887209892273, 74.8224538564682, 74.61838200688362, 76.77082970738411, 74.88935306668282, 73.31906452775002, 72.38442108035088, 71.68113201856613, 70.07607534527779, 73.5351437330246, 73.02670821547508, 68.48678782582283, 72.68520534038544, 78.37777107954025, 77.24834248423576, 78.35896208882332, 75.98443910479546, 73.95385846495628, 76.08458653092384, 73.65508049726486, 74.89796340465546, 74.08255755901337, 72.24116876721382, 79.95022550225258, 75.94802185893059, 75.26259943842888, 71.53976440429688, 68.61695364117622, 53.168848380446434, 76.2490265071392, 77.72082433104515, 68.47323775291443, 62.95618079602718, 72.14584708213806, 55.19151024520397, 41.86176851391792, 9.491364397108555, 0.24881345423636958, 0.2774345426587388, 0.15157830464886501, 0.1827059077913873, 0.04306772767449729, 0.19624253298388794, 0.48723039915785193, 1.5177552890963852, 0.13545388472266495, 1.292669854592532, 1.9310373812913895, 36.46780975162983, 85.31445845961571, 77.97335118055344, 36.84807054698467, 36.085747852921486, 34.31788511574268, 37.14465223252773, 37.394887804985046, 55.85620857775211, 65.11730343103409, 64.07223790884018, 48.07309001684189, 0.449399451026693, 0.03395884828933049, 0.02316886526386952, 0.027289951940474566, 0.07215591642307118, 0.02388784494542051, 0.05259058074443601, 0.07481333203031681, 0.02610969964734977, 0.03781088787945919, 0.0662186682166066, 0.006145371926322696, 0.029885262774769217, 0.28851489652879536, 0.27092528413049877, 0.3498269518604502, 0.3417983982944861, 0.29631558107212186, 0.24981893075164407, 0.23247105069458485, 0.14752846414921805, 0.21391876885900274, 0.2615228370996192, 0.1531948655610904, 0.23835712781874463, 0.3976033616345376, 0.13763475988525897, 0.22664643824100494, 0.19523116381606087, 38.522842079401016, 77.44644105434418, 63.46256822347641, 71.24094843864441, 46.545640379190445, 41.88658118247986, 60.25321863591671, 102.48822972178459, 79.90886092185974, 2.1740298299118876, 0.7064853433985263, 0.18308970204088837, 0.2628117991844192, 0.41951292660087347, 0.7346654031425714, 0.6708823819644749, 0.6382171378936619, 0.4342954989988357, 0.8684910752344877, 1.3960492447949946, 0.3601233899826184, 0.7063052686862648, 18.52414660155773, 81.9675600528717, 91.57328501343727, 91.3684456050396, 84.98980388045311, 98.5514585673809, 83.46455812454224, 77.40154266357422, 84.29798260331154, 94.46516543626785, 92.15442582964897, 94.9038214981556, 94.49455305933952, 98.22864308953285, 89.40553173422813, 85.14841496944427, 90.86446344852448, 96.13963678479195, 88.67753639817238, 86.74396455287933, 90.18276482820511, 86.82033285498619, 91.86513215303421, 93.41505378484726, 86.7340698838234, 92.05373123288155, 88.54050055146217, 87.55208238959312, 86.66465520858765, 91.71974435448647, 94.81220841407776, 85.86157590150833, 84.02961060404778, 83.0618405342102, 86.54777348041534, 79.64083090424538, 75.27319326996803, 78.77541214227676, 75.96661046147346, 80.89566797018051, 83.23242858052254, 81.81717932224274, 79.81425359845161, 76.70368731021881, 74.8694421350956, 73.22530075907707, 67.33092024922371, 70.24730175733566, 75.21776184439659, 78.57944905757904, 82.1043299138546, 78.06657537817955, 77.22451016306877, 72.05253928899765, 72.5838951766491, 71.91799610853195, 77.50283762812614, 74.19047176837921, 79.16992977261543, 76.97449877858162, 76.7156870663166, 78.92038196325302, 78.86431977152824, 77.8356085717678, 78.1866717338562, 74.66860011219978, 78.90288010239601, 79.38346311450005, 80.66366001963615, 76.2656544148922, 78.07168990373611, 73.35141599178314, 73.99530664086342, 73.81366118788719, 73.71210783720016, 74.29580211639404, 71.10825955867767, 75.64073234796524, 82.09886580705643, 79.7427186369896, 80.24498328566551, 77.740758061409, 80.87741374969482, 79.81006622314453, 73.55499386787415, 75.7940237224102, 74.59585681557655, 75.60464948415756, 83.85350525379181, 80.29998913407326, 79.05497074127197, 74.49766248464584, 70.90426370501518, 56.124493181705475, 76.65675222873688, 71.40880823135376, 69.97880056500435, 65.77925071120262, 71.72485247254372, 65.29397875070572, 61.71661891043186, 10.88614510372281, 0.32612124108709395, 0.40342470863834023, 0.14051917620236054, 0.19165301753673702, 0.1373265459551476, 0.6060470547527075, 1.1588711966760457, 2.7070573903620243, 1.0670051886700094, 2.163204923272133, 8.306758962571621, 70.97003817558289, 86.97901993989944, 84.4897735118866, 45.8347175270319, 52.77955926954746, 62.20572866499424, 38.286319971084595, 26.44016493111849, 70.77293515205383, 75.23188948631287, 73.77950862050056, 56.42616279423237, 0.7480872923042625, 0.13883781095501035, 0.17741240590112284, 0.08344395289896056, 0.26383231161162257, 0.10065741516882554, 0.19913174357498065, 0.1446144955116324, 0.17637678334722295, 0.1494941907003522, 0.10095273799379356, 0.128133429097943, 0.20928393787471578], [0.07667590005439706, 0.08098485399386846, 0.17191816790727898, 0.15861491847317666, 0.07043708756100386, 0.1417508296435699, 0.11082477154559456, 0.11060565244406462, 0.02146174192603212, 0.022535132375196554, 0.06482582030002959, 0.09484433569014072, 0.043995957748848014, 0.08467936160741374, 0.030725952819921076, 0.021477961563505232, 15.513934828341007, 60.75501590967178, 53.66439498960972, 50.61600476503372, 41.01801998913288, 50.03783918917179, 53.97794656455517, 70.12180969119072, 6.403437294065952, 0.44071679818443954, 0.14564446290023625, 0.19982373691163957, 0.071625718701398, 0.6780517660081387, 0.09447585194720887, 0.10089074639836326, 0.09665680874604732, 0.11162933384184726, 1.1477613053284585, 2.076819408684969, 0.3722876950632781, 12.934629432857037, 52.396593019366264, 65.61975806951523, 91.52866020798683, 84.00349840521812, 82.74499073624611, 69.63138520717621, 63.97426396608353, 70.31217947602272, 82.38078027963638, 77.72641763091087, 86.86917543411255, 86.53603971004486, 88.43962356448174, 85.11280328035355, 90.44134855270386, 79.81213331222534, 82.35834628343582, 82.2985602915287, 80.02436712384224, 83.66539254784584, 86.84625506401062, 81.87454864382744, 87.5623570382595, 77.24499106407166, 77.91215926408768, 84.95826557278633, 80.75035616755486, 86.1841481924057, 84.5820401608944, 82.979346960783, 78.12386110424995, 76.12288847565651, 78.95730838179588, 80.36583960056305, 77.70634710788727, 77.15938925743103, 74.70335304737091, 74.98218968510628, 73.95197376608849, 75.16413912177086, 77.137920409441, 78.8367560505867, 81.46803885698318, 73.01776349544525, 67.44552969932556, 67.41364941000938, 65.9219178557396, 73.45252856612206, 70.65897926688194, 73.88996869325638, 74.10955131053925, 72.76392951607704, 71.21988996863365, 65.75498521327972, 71.41564026474953, 68.03286418318748, 73.15342381596565, 75.17560690641403, 71.01999789476395, 75.10262042284012, 73.49963083863258, 76.51606857776642, 74.26347345113754, 70.12352719902992, 69.63079243898392, 68.07895570993423, 68.79834830760956, 68.9270094037056, 71.0674649477005, 72.73742973804474, 74.28534507751465, 71.71564936637878, 67.55621775984764, 68.32826033234596, 70.3834180533886, 68.06124106049538, 69.42234322428703, 66.18522092700005, 73.56374099850655, 76.88331887125969, 76.05044916272163, 76.70098945498466, 72.59603172540665, 70.37702679634094, 75.20328462123871, 66.08654782176018, 68.80612269043922, 69.69415783882141, 74.85899269580841, 73.49118769168854, 74.21840786933899, 68.73223945498466, 66.91232711076736, 56.32083624601364, 61.75231799483299, 75.95376715064049, 66.14062651991844, 54.90755908191204, 62.000623270869255, 50.258998721838, 29.14004545658827, 21.437997445464134, 0.5630403093528003, 0.019912029965780675, 0.2119083353318274, 0.40316940983757377, 0.11226991860894486, 0.08436912161414512, 0.0859290492371656, 0.5458905233535916, 2.2822347236797214, 0.7730304007418454, 0.9910220908932388, 8.151801377534866, 32.20997482538223, 88.93685728311539, 45.17384558916092, 15.84012072533369, 23.235519491136074, 28.951189890503883, 27.462437376379967, 40.500271171331406, 49.81261387467384, 58.577314764261246, 38.97305712103844, 0.15031513961730525, 0.046348421165021136, 0.060370767168933526, 0.08262139352154918, 0.17287524155108258, 0.11556857207324356, 0.006978902101764106, 0.0955160016019363, 0.057587219853303395, 0.07093351756338961, 0.0342634924891172, 0.0336751363647636, 0.027109010770800523, 0.0905898331257049, 0.06989365734625608, 0.03951454724301584, 0.050895307649625465, 0.05096377448353451, 0.1193836861057207, 0.10620698769344017, 0.09618231662898324, 0.042432467816979624, 0.010102449068654096, 0.035738110236707143, 0.07138023851439357, 0.04590790456859395, 0.035297708673169836, 0.010528139409871073, 0.06387368935975246, 20.762386098504066, 74.19136852025986, 66.21852993965149, 75.19099608063698, 34.50299598276615, 27.471980564296246, 63.22250850498676, 83.22960153222084, 7.878430271521211, 0.5856269504874945, 0.21339715778594837, 0.5489751859568059, 0.35629272053483874, 0.8073595399037004, 0.11856324184918776, 0.07548923560534604, 0.1395341829629615, 0.33997476333752275, 1.8890732643194497, 2.9193315748125315, 0.5031623505055904, 19.314251504838467, 66.36374294757843, 74.32920232415199, 94.91914227604866, 89.41709831357002, 89.57826286554337, 78.69004592299461, 69.85130980610847, 78.27173396945, 81.85052633285522, 81.76701441407204, 87.94050514698029, 90.07249474525452, 90.21555706858635, 87.72096052765846, 91.04111596941948, 86.17573544383049, 87.309131026268, 85.4589495062828, 88.41911986470222, 88.03817510604858, 89.2854505777359, 86.42141506075859, 91.14770025014877, 80.01367449760437, 83.26418727636337, 87.61300072073936, 85.95048353075981, 86.35528340935707, 84.18590381741524, 82.7659048140049, 80.30308216810226, 79.06444743275642, 82.69110962748528, 84.50532227754593, 81.74737706780434, 81.35925829410553, 82.85308733582497, 81.15995898842812, 81.81503623723984, 79.74451214075089, 80.19738703966141, 82.30504274368286, 81.23227670788765, 77.38533273339272, 71.27168118953705, 70.2274364233017, 70.12260764837265, 74.48028221726418, 75.15372008085251, 77.31647282838821, 73.97290304303169, 75.0861369073391, 70.27861207723618, 67.73212552070618, 72.60571360588074, 66.8708485364914, 75.84662809967995, 78.57363536953926, 74.49250996112823, 77.40297138690948, 77.13276788592339, 78.25023472309113, 77.96381369233131, 74.47877749800682, 74.8260560631752, 73.8660603761673, 70.4175478219986, 71.85716897249222, 73.77729713916779, 73.11191484332085, 76.34505495429039, 73.66526395082474, 73.79081681370735, 70.12397557497025, 72.87621349096298, 72.2338655591011, 73.67060646414757, 71.16344019770622, 72.29899406433105, 79.2278690636158, 77.19848155975342, 77.00726822018623, 75.81621453166008, 72.25677073001862, 79.67759773135185, 72.81993851065636, 72.59304508566856, 74.04301688075066, 75.12925699353218, 74.82789516448975, 77.08758071064949, 71.94113686680794, 75.49540534615517, 63.3879554271698, 63.2795624434948, 77.96952098608017, 76.82490840554237, 63.13857860863209, 67.2938722372055, 67.9927459359169, 46.860951259732246, 27.560683004558086, 1.2384076975286007, 0.16358349326765165, 0.270648225559853, 0.5216336937155575, 0.0816822872729972, 0.21344875189242885, 0.28515195823274553, 0.8128353429492563, 1.1933162296190858, 1.2343776575289667, 1.5191038604825735, 4.85450123436749, 40.345129296183586, 97.75657162070274, 52.15593673288822, 23.062856756150723, 19.093977324664593, 27.622982561588287, 34.235554933547974, 44.58106219768524, 55.59162117540836, 65.49349084496498, 44.15077708661556, 0.21462492237333208, 0.014376741000887705, 0.047505095426458865, 0.06157219293527305, 0.07140838817576878, 0.03381505717698019, 0.058915686458931305, 0.04974948358722031, 0.03082542843912961, 0.04389675857964903, 0.050889017948065884, 0.026736155778053217, 0.01575846876221476, 0.13999480433994904, 0.3150111122522503, 0.3457299107685685, 0.30705496261361986, 0.15127875900361687, 0.28980908333323896, 0.19168867031112313, 0.17452321015298367, 0.09959341288777068, 0.19197570334654301, 0.17152033222373575, 0.18844100239221007, 0.1831723772920668, 0.1496831266558729, 0.30922179634217173, 0.13488335127476603, 29.241667203605175, 90.2357567846775, 74.07574832439423, 72.40918055176735, 57.29963332414627, 72.0991399884224, 74.48410481214523, 96.23124226927757, 13.855175636708736, 1.360521032474935, 0.23834700492443517, 1.3522411580197513, 0.6547179305925965, 1.3126896740868688, 0.31226727354805917, 0.3769385564373806, 0.6542107171844691, 0.6143227138090879, 2.8530438942834735, 4.45175894536078, 0.8681262354366481, 16.974135674536228, 68.50792229175568, 83.00726026296616, 103.88392522931099, 97.65621140599251, 96.45789250731468, 83.30514907836914, 78.01846235990524, 85.13112589716911, 91.6709853708744, 86.74970224499702, 95.18287852406502, 95.10974764823914, 94.977917522192, 91.08827143907547, 95.87733685970306, 89.68123733997345, 94.8742362856865, 89.62685465812683, 88.50722953677177, 90.7837937772274, 93.66534635424614, 88.05128440260887, 93.41966673731804, 83.4272289276123, 85.28397649526596, 92.00656056404114, 88.5975430905819, 90.79582393169403, 88.01801338791847, 88.09141784906387, 83.5104900598526, 81.93807363510132, 85.61506032943726, 86.08216926455498, 83.69519054889679, 82.60531783103943, 82.47329011559486, 80.37862211465836, 82.57326275110245, 79.64607462286949, 82.19579100608826, 84.26049381494522, 89.12124618887901, 81.74184456467628, 74.75686177611351, 73.29464703798294, 72.35639378428459, 79.51738312840462, 80.09244427084923, 81.35861992835999, 78.79935085773468, 80.7510781288147, 76.64867386221886, 70.65526306629181, 74.44337859749794, 70.21891728043556, 78.88201162219048, 81.63076132535934, 78.8201205432415, 80.81521108746529, 80.41591331362724, 79.80303660035133, 80.62540367245674, 75.43767124414444, 76.05009958148003, 73.83200660347939, 73.26447665691376, 71.9925557076931, 78.93162935972214, 76.90291061997414, 80.89976415038109, 75.88673874735832, 75.2571277320385, 74.14599895477295, 75.72341591119766, 73.32853361964226, 74.48152095079422, 71.11053943634033, 73.08571144938469, 82.11490854620934, 80.22330164909363, 79.17562186717987, 78.92048075795174, 76.78395420312881, 82.75069802999496, 72.69353449344635, 72.69620954990387, 77.55153581500053, 79.62720483541489, 77.12061613798141, 79.06019926071167, 74.08352270722389, 75.30941292643547, 65.00933602452278, 65.05013063549995, 74.07514035701752, 71.15757331252098, 61.77340306341648, 68.95293921232224, 71.1575049161911, 63.61739091575146, 38.548638895154, 0.8956934593152255, 0.22052366053685546, 0.4074249736731872, 0.41147083626128733, 0.135301343689207, 0.25424937426578254, 0.5167839664500207, 1.350992212537676, 5.004340494051576, 1.7866154434159398, 2.32779570389539, 16.224599294364452, 68.84479701519012, 99.97820600867271, 62.345329374074936, 29.535239450633526, 35.211490765213966, 45.051868334412575, 39.859241768717766, 54.705060347914696, 68.62110301852226, 75.71513995528221, 54.61994491517544, 0.4361786838853732, 0.1347739587072283, 0.18993398087332025, 0.15752228413475677, 0.3778321319259703, 0.21177566901315004, 0.16225856670644134, 0.14171278715366498, 0.14351105550304055, 0.18761200859444216, 0.12027197008137591, 0.11122302283183672, 0.2094189345370978], [0.015512107274844311, 0.18800003308570012, 0.015846242567931768, 0.1337497800705023, 0.21281629364239052, 0.1436706617823802, 0.1319599276757799, 0.07572232192615047, 0.09346558857942, 0.04092418996151537, 0.03748980881937314, 0.004379085039545316, 0.0637757036020048, 0.0204174956161296, 0.14272912871092558, 0.03703379989019595, 15.250959489494562, 56.100448071956635, 46.44986651837826, 41.32283203303814, 52.26140387356281, 55.79271778464317, 81.03074312210083, 34.61913675069809, 0.5475566745735705, 0.18525113293435425, 0.6774465297348797, 0.2294664064538665, 0.8792754902970046, 0.052111105105723254, 0.008348118644789793, 0.05845825631695334, 0.023530597318313085, 0.12262972129974514, 1.151738385669887, 0.11064407342928462, 5.665753902867436, 56.18689723312855, 68.45110774040222, 65.23684501647949, 66.39465048909187, 67.26114839315414, 63.31903472542763, 74.27528321743011, 63.26355770230293, 72.7550607919693, 76.97960570454597, 86.71070873737335, 87.31215566396713, 86.06883957982063, 86.65239706635475, 85.95926865935326, 81.28757894039154, 89.15144696831703, 79.82934638857841, 82.76643678545952, 86.76695331931114, 83.231281042099, 81.0254842042923, 85.43352127075195, 80.72673663496971, 75.56564837694168, 80.24332657456398, 80.37581026554108, 83.62426355481148, 79.65410739183426, 78.59045326709747, 79.31608512997627, 82.72219955921173, 83.33116248250008, 80.07855981588364, 83.03683027625084, 81.60240724682808, 77.34470531344414, 74.96381387114525, 71.16188988089561, 73.19863379001617, 74.6903045475483, 75.83582907915115, 73.71083110570908, 72.57456287741661, 70.87102308869362, 68.89130651950836, 66.68124631047249, 66.48499444127083, 65.54613322019577, 71.31967261433601, 68.34491103887558, 72.22191140055656, 73.83713632822037, 69.17119950056076, 72.01070353388786, 65.98472088575363, 68.18925619125366, 76.14102870225906, 69.53452840447426, 69.57976877689362, 70.76599672436714, 70.63921272754669, 72.14537590742111, 74.64456260204315, 70.79855337738991, 71.51068836450577, 72.74126753211021, 67.91223585605621, 69.16305273771286, 67.36056625843048, 70.16179874539375, 71.55807182192802, 71.0356530547142, 73.03021162748337, 68.56180340051651, 66.54787346720695, 67.48013064265251, 71.98486492037773, 70.89623853564262, 68.59072744846344, 75.1902437210083, 77.75151148438454, 75.09041547775269, 77.65145525336266, 69.56254050135612, 66.35539099574089, 71.48937910795212, 65.00042170286179, 69.39995482563972, 71.38032495975494, 70.9981794655323, 74.10363882780075, 72.77312502264977, 67.83625513315201, 65.6074695289135, 59.41298492252827, 69.84144553542137, 71.18307754397392, 63.70529919862747, 55.969548895955086, 63.961185067892075, 33.23208197951317, 27.589817941188812, 7.9676884319633245, 0.3504537994740531, 0.1914558734279126, 0.38922884850762784, 0.5980639206245542, 0.7712963281664997, 0.5831022234633565, 0.47046572843100876, 0.11686575715430081, 1.0598198929801583, 0.7137799425981939, 1.4853323413990438, 1.269597967620939, 59.86748993396759, 71.62592098116875, 28.101105205714703, 34.984760731458664, 34.70742121338844, 52.24827937781811, 64.68991756439209, 51.73000618815422, 50.24693436920643, 9.239265974611044, 0.11563068983377889, 0.0716382684186101, 0.05592844929196872, 0.04578344269248191, 0.10287210257956758, 0.04216087516397238, 0.027464185950520914, 0.047919599746819586, 0.04293040808988735, 0.06851644648122601, 0.10887887518038042, 0.05586092498560902, 0.03156548511469737, 0.037829716166015714, 0.056173866396420635, 0.07972076127771288, 0.011274227890680777, 0.10633120095008053, 0.06343973334878683, 0.08229696366470307, 0.06559448491316289, 0.06591513723833486, 0.008939769904827699, 0.10799874740769155, 0.07577873999252915, 0.08695384385646321, 0.021957524404569995, 0.05796260556962807, 0.026822432300832588, 20.93015279620886, 66.83465927839279, 64.53785732388496, 64.78909224271774, 33.760816007852554, 51.95287562906742, 94.852714240551, 39.26221780478954, 0.4044346231967211, 0.10752485643024556, 0.7320714485831559, 0.33585293451324105, 0.9091017523314804, 0.16408223134931177, 0.04539737004961353, 0.080994115996873, 0.2014093502657488, 0.09208367991959676, 1.0397247900255024, 0.3862523316638544, 9.29926285520196, 69.2000475525856, 80.15232145786285, 78.4757450222969, 75.69462865591049, 74.42952454090118, 71.33952274918556, 78.54465052485466, 73.18833634257317, 79.25061464309692, 81.19285002350807, 88.86199370026588, 91.81469365954399, 91.57891631126404, 90.63779041171074, 89.24172252416611, 86.43637105822563, 92.10017994046211, 86.11268162727356, 86.17842569947243, 91.7698484659195, 89.64333817362785, 85.02393364906311, 89.06598195433617, 82.12870940566063, 79.65742081403732, 84.15068730711937, 83.58784630894661, 84.21279117465019, 84.19094234704971, 76.4635705947876, 80.44321864843369, 83.60428422689438, 86.47559255361557, 84.22395497560501, 85.14647707343102, 84.04673248529434, 80.67241474986076, 81.07998088002205, 78.46531078219414, 75.63359633088112, 78.11021223664284, 77.94880449771881, 75.15900939702988, 75.65929815173149, 76.55323058366776, 71.63311779499054, 72.47429385781288, 74.7170703113079, 70.73077261447906, 74.03994664549828, 71.19818553328514, 74.94410052895546, 76.28775402903557, 71.34765431284904, 74.93359789252281, 65.16967222094536, 68.02606254816055, 77.51530855894089, 70.90975061058998, 71.63106590509415, 74.58640292286873, 73.16287770867348, 73.88598650693893, 75.81955075263977, 74.49439465999603, 73.575619161129, 77.22250387072563, 73.65902468562126, 71.79244324564934, 71.6167102754116, 72.3114649951458, 72.73869886994362, 74.58605334162712, 76.49276062846184, 73.34614187479019, 70.39236277341843, 72.6499280333519, 73.24452012777328, 74.64163675904274, 69.1853803396225, 73.81556108593941, 78.01802158355713, 77.42396906018257, 77.61782705783844, 73.28479036688805, 69.30413156747818, 77.4284528195858, 70.2690289914608, 72.82478705048561, 71.28624200820923, 75.2170778810978, 74.522155970335, 75.0963507592678, 68.17143514752388, 72.22428247332573, 63.557414934039116, 71.85119569301605, 76.80279359221458, 74.7991307079792, 62.867611348629, 71.5913200378418, 58.51043835282326, 37.867635637521744, 11.407601572573185, 0.39948152960278094, 0.07011189329205081, 0.2918810705887154, 0.35263247787952423, 1.2061159615404904, 0.6959440559148788, 1.4649698277935386, 0.6406507885549217, 0.38175387773662806, 0.958721567876637, 0.4693785711424425, 8.357662931084633, 71.57960906624794, 78.79897087812424, 33.93729753792286, 29.071056358516216, 26.000270135700703, 49.82196517288685, 58.69527943432331, 55.972489938139915, 61.21575638651848, 11.723373178392649, 0.01231089965585852, 0.09793121731490828, 0.05931199702899903, 0.050295837863814086, 0.04462220793357119, 0.0776832245173864, 0.040488155937055126, 0.026881277190113906, 0.018068963727273513, 0.04030351701658219, 0.02136325707397191, 0.0720755937800277, 0.07192751305410638, 0.10214852343779057, 0.34693691006395966, 0.2639860549243167, 0.28747084317728877, 0.2776262245606631, 0.26209473609924316, 0.41544061386957765, 0.22103608382167295, 0.19429080333793536, 0.21982053498504683, 0.24720079702092335, 0.25248048012144864, 0.22368259727954865, 0.1607356796739623, 0.2601804997539148, 0.34103609388694167, 29.362413324415684, 80.67213356494904, 63.08272920548916, 60.06711222231388, 79.21224430203438, 75.73201104998589, 103.24368238449097, 54.65211398899555, 1.3605736359022558, 1.076153910253197, 1.7589577962644398, 1.1596573982387781, 3.021759591065347, 1.387447218876332, 0.29629236669279635, 0.4355559032410383, 0.3639248781837523, 0.33103939436841756, 2.585547510534525, 0.5391260550823063, 8.102965448051691, 78.48490253090858, 87.65036791563034, 84.76835176348686, 86.32080405950546, 88.52631211280823, 80.69095775485039, 86.5497037768364, 77.8313983976841, 87.54347205162048, 86.0841603577137, 94.20487940311432, 96.3578362762928, 94.23915356397629, 94.81975480914116, 94.2440477013588, 88.54082733392715, 96.27164170145988, 89.39886689186096, 91.3934026658535, 96.45091608166695, 92.49893814325333, 85.18075883388519, 90.58226779103279, 84.70812499523163, 78.26965928077698, 87.97686919569969, 87.88476973772049, 88.15775468945503, 90.36623418331146, 81.99580773711205, 84.17288571596146, 86.58485189080238, 90.26961296796799, 88.28547343611717, 88.22364315390587, 87.34343558549881, 84.01435822248459, 80.85798159241676, 80.52227720618248, 76.88355445861816, 79.92219060659409, 81.84070006012917, 78.26447635889053, 79.84947770833969, 82.21702426671982, 76.5708464384079, 75.03774270415306, 77.62677177786827, 71.01977750658989, 76.85561075806618, 77.2472633421421, 78.23380440473557, 80.89253693819046, 75.62544956803322, 79.8817227780819, 68.20067837834358, 73.50327104330063, 83.58804389834404, 74.51931372284889, 76.5746158361435, 79.370908588171, 78.56925040483475, 79.17308360338211, 79.33004558086395, 79.07389372587204, 75.71090698242188, 79.2579634487629, 74.90892201662064, 71.43920660018921, 73.55000093579292, 76.33797213435173, 74.22009497880936, 77.71422028541565, 79.00136321783066, 76.40795677900314, 71.21086925268173, 76.30738377571106, 74.44679081439972, 77.04189956188202, 70.87425291538239, 78.30432862043381, 81.45302206277847, 79.64255601167679, 79.56722125411034, 75.15128821134567, 71.58645629882812, 79.015202075243, 69.66201916337013, 75.60153365135193, 75.93236669898033, 78.57702478766441, 76.98117882013321, 79.22065705060959, 70.23888900876045, 74.8594182729721, 63.39637577533722, 71.0401064157486, 70.70226654410362, 73.58482986688614, 62.61920727789402, 71.43290653824806, 66.95350930094719, 59.492218270897865, 10.306792091578245, 0.49613911018241197, 0.4143148649018258, 0.5382005078718066, 0.6020632653962821, 2.2809594171121716, 3.4781944239512086, 3.4360038628801703, 2.32655459549278, 1.2942874990403652, 2.6041028648614883, 4.262197092175484, 33.00449699163437, 82.63509303331375, 84.41553309559822, 50.5762854963541, 51.442806199193, 47.772662937641144, 71.42849117517471, 86.22798264026642, 69.36857610940933, 73.73582616448402, 16.068454273045063, 0.2842304186196998, 0.22397491440642625, 0.14436583151109517, 0.12973013013834134, 0.20514015632215887, 0.17429206083761528, 0.23923606815515086, 0.11815077101346105, 0.1556660985806957, 0.1455363616696559, 0.1858181189163588, 0.09281920763896778, 0.19239886110881343], [0.05729751879698597, 0.09553216557833366, 0.10618371394230053, 0.14421223662793636, 0.12360971246380359, 0.09649680912843905, 0.20976299419999123, 0.16914250591071323, 0.028369426145218313, 0.07823400941560976, 0.034660515520954505, 0.10213958055828698, 0.013169620178814512, 0.048897813467192464, 0.01953115421201801, 0.08648831688333303, 30.240133926272392, 56.84553109109402, 45.348510816693306, 41.575856655836105, 43.66259828209877, 71.6665256023407, 82.6604376733303, 3.1606547255069017, 0.808911103522405, 0.2876443276181817, 0.6748981133569032, 0.29225327249150723, 0.10133960473467596, 0.5515534069854766, 0.004049673516419716, 0.2512078155996278, 0.27728646935429424, 0.2927251299843192, 0.2326220035320148, 1.460826862603426, 33.913404420018196, 61.346739158034325, 75.38331136107445, 76.03310689330101, 67.84651458263397, 59.03911918401718, 55.590336844325066, 63.2522115111351, 74.06851351261139, 74.07089978456497, 79.83219623565674, 87.33566120266914, 90.68707376718521, 82.47967377305031, 86.2390324473381, 80.83652034401894, 85.0517025589943, 86.59622088074684, 86.08223766088486, 82.05630049109459, 86.11917167901993, 83.9414781332016, 80.27854308485985, 77.38670065999031, 72.55015298724174, 79.53200474381447, 80.8843445777893, 76.87353819608688, 74.11085084080696, 78.59606936573982, 77.69411936402321, 81.77627071738243, 82.78703168034554, 79.80235263705254, 78.21319431066513, 80.88278666138649, 76.36994361877441, 78.04531931877136, 73.92397686839104, 72.3190189898014, 71.70225888490677, 72.51327976584435, 71.72221541404724, 72.05980449914932, 73.90424832701683, 73.28577071428299, 66.13359689712524, 70.60528814792633, 70.17662554979324, 66.51880502700806, 73.65285381674767, 69.68476474285126, 72.82816126942635, 73.42065587639809, 71.09823569655418, 67.54367083311081, 64.09688338637352, 69.74772736430168, 68.64132553339005, 67.25054696202278, 67.89199814200401, 68.1182000041008, 67.80051425099373, 71.20545834302902, 72.43687346577644, 70.39153441786766, 67.7248527109623, 71.61626189947128, 69.32310774922371, 69.76461365818977, 72.1712601184845, 71.17009744048119, 71.48579210042953, 69.10256758332253, 66.74397334456444, 69.82348769903183, 70.60935392975807, 65.93234449625015, 67.47758477926254, 68.4495422244072, 65.90915814042091, 64.61359485983849, 72.04664960503578, 74.94720116257668, 74.9528780579567, 77.23897978663445, 70.41830778121948, 64.71049726009369, 69.87153232097626, 66.92124143242836, 68.05761605501175, 73.5414969921112, 72.8403890132904, 71.26532033085823, 65.54716676473618, 62.1318606287241, 61.16415895521641, 66.3072095811367, 72.89049312472343, 69.44073423743248, 60.87797351181507, 65.82895964384079, 52.53389485180378, 26.16419903934002, 25.221781209111214, 0.38255996885709465, 0.08626081151305698, 0.1491296774474904, 0.3947161103133112, 0.5253157555125654, 0.5121915566269308, 0.2575795986922458, 0.3539179963991046, 0.23502400901634246, 0.25554145337082446, 0.67325618583709, 3.4015477867797017, 21.717290058732033, 74.44320380687714, 44.35802936553955, 27.695216685533524, 44.626804143190384, 37.098777294158936, 44.774950593709946, 49.660131856799126, 42.106463983654976, 0.6054010894149542, 0.10759754237369634, 0.017794096347643062, 0.03665336756967008, 0.013119169907440664, 0.07666922072530724, 0.012707792811852414, 0.07598329815664329, 0.031108492839848623, 0.0476537030772306, 0.02615797635371564, 0.05383048686780967, 0.02668335939233657, 0.03189450144418515, 0.03157732979161665, 0.06045506030204706, 0.02200600520154694, 0.051848633447661996, 0.09798931263503619, 0.02626487344969064, 0.10440191384986974, 0.08100827617454343, 0.029259131333674304, 0.022687838536512572, 0.025752819383342285, 0.032610681373625994, 0.13685776095371693, 0.022349263344949577, 0.0436288581113331, 0.03199992352165282, 39.6356313675642, 69.11057755351067, 58.36436279118061, 38.95230643451214, 32.47240014374256, 80.32392024993896, 90.01518622040749, 5.4042514599859715, 1.4042511046864092, 0.46630373457446694, 0.6047766166739166, 1.3112044287845492, 0.04841750291234348, 0.49613311362918466, 0.16948088072240353, 0.5674635095056146, 0.8580064284615219, 0.30677858681883663, 0.24523717816919088, 2.308850632980466, 45.739582031965256, 70.0499327480793, 85.18105521798134, 85.692697763443, 80.58505743741989, 71.34868025779724, 66.27631723880768, 73.3937457203865, 81.60175368189812, 79.39648121595383, 87.13680267333984, 92.05870136618614, 90.95251232385635, 87.2089684009552, 89.76142063736916, 85.02825021743774, 88.73859912157059, 87.63092055916786, 89.11602526903152, 85.03340274095535, 92.55492433905602, 88.68540957570076, 85.61306923627853, 77.04781204462051, 74.73489135503769, 84.00320962071419, 84.91525188088417, 83.63273710012436, 76.25830560922623, 81.44994422793388, 80.64647734165192, 83.8504958152771, 86.15380302071571, 83.71456950902939, 82.99473613500595, 83.29005628824234, 80.07122620940208, 81.8880607187748, 79.76240158081055, 78.12297195196152, 77.03084215521812, 76.43153071403503, 74.62758511304855, 74.84298035502434, 77.86901637911797, 76.34956911206245, 71.71747326850891, 72.9921604692936, 75.55046439170837, 73.3548054099083, 77.0015001296997, 74.54999327659607, 76.00305810570717, 74.12268340587616, 73.24628323316574, 67.9178823530674, 64.07021641731262, 67.85784557461739, 69.30711060762405, 68.88645797967911, 70.00358283519745, 68.97155821323395, 70.57958632707596, 72.3265577852726, 72.78099060058594, 75.66755130887032, 71.25596523284912, 72.14992806315422, 73.73440504074097, 70.58703392744064, 73.25908094644547, 72.45239943265915, 73.07792946696281, 72.36001878976822, 66.9617472589016, 71.74512818455696, 74.88797754049301, 70.6193245947361, 72.56687209010124, 70.6952141225338, 71.13716840744019, 65.21251112222672, 71.8828783929348, 78.00334677100182, 75.82452848553658, 80.19070699810982, 72.61332839727402, 68.7483049929142, 74.04785022139549, 71.17571353912354, 69.04202923178673, 73.84156689047813, 74.30638074874878, 73.01984578371048, 70.34763157367706, 66.35957077145576, 67.06366539001465, 67.47680202126503, 73.41452300548553, 77.7213867008686, 67.51463279128075, 68.89582827687263, 70.81498369574547, 43.42922620475292, 30.265147984027863, 1.2939882650971413, 0.12098482518922538, 0.12250473620952107, 0.3750243200920522, 1.1913361796177924, 0.1542162982514128, 0.38719328586012125, 0.31855721259489655, 0.3765603876672685, 0.49014386313501745, 0.8389459387399256, 6.656999588012695, 32.13750511407852, 85.03765851259232, 50.54576933383942, 38.32081452012062, 30.470587760210037, 34.19180408120155, 55.40931835770607, 55.46460539102554, 51.51710361242294, 0.47209162556100637, 0.05363091222534422, 0.06129542751295958, 0.07080702591338195, 0.05667365090630483, 0.07606794009916484, 0.010802116212289548, 0.026707200886448845, 0.029924481568741612, 0.044137615186627954, 0.0319931106059812, 0.01900617193314247, 0.02842322257492924, 0.055197508045239374, 0.12215827940963209, 0.22843097685836256, 0.31369941076263785, 0.38639179605524987, 0.27039464854169637, 0.23037252423819155, 0.5264141934458166, 0.2996165945660323, 0.10135703036212362, 0.1407987580751069, 0.20621408853912726, 0.2538560063112527, 0.18504828913137317, 0.19105253100860864, 0.1846066370490007, 0.19839957036310807, 47.95442618429661, 81.34728133678436, 62.317476868629456, 59.81291726231575, 65.68809360265732, 88.43023806810379, 104.4755382835865, 7.41108812391758, 3.3942604903131723, 1.6879703616723418, 2.7456493070349097, 3.395991772413254, 0.23590545781189576, 0.890191710786894, 0.48635671322699636, 0.546693408396095, 1.4165642252191901, 0.5747347755823284, 0.7398699957411736, 1.9678226136602461, 53.612254187464714, 79.50119599699974, 88.60061332583427, 88.78634735941887, 90.03994569182396, 82.74201929569244, 76.49053394794464, 80.05638420581818, 88.22276920080185, 82.97474920749664, 90.09498193860054, 96.03911697864532, 95.45685902237892, 90.63478097319603, 93.05294841527939, 86.84811696410179, 89.16678294539452, 92.95685157179832, 92.19953700900078, 88.44793751835823, 98.32341760396957, 89.98750850558281, 86.87812015414238, 79.11686182022095, 75.21807342767715, 84.40933182835579, 85.27291148900986, 85.73627382516861, 80.76748564839363, 84.7650383412838, 82.73804470896721, 86.853436678648, 89.69871640205383, 87.07032144069672, 87.13640749454498, 87.1523742377758, 83.0699872970581, 83.96208062767982, 82.22278475761414, 78.64485114812851, 77.08593919873238, 78.2650539278984, 75.5140395462513, 78.34463685750961, 81.08938157558441, 80.18246904015541, 75.54796412587166, 78.34807187318802, 78.60838830471039, 76.14491209387779, 81.91297978162766, 74.94298338890076, 80.56039676070213, 78.78903821110725, 76.86728373169899, 70.30597820878029, 67.68842026591301, 73.68968904018402, 74.41037356853485, 72.60177701711655, 74.27364930510521, 73.38417023420334, 73.0447344481945, 77.21622660756111, 75.0099889934063, 76.14359736442566, 74.50668320059776, 76.56073898077011, 75.6928351521492, 74.97170224785805, 77.99447044730186, 78.2851092517376, 77.08203300833702, 74.59254339337349, 69.96327459812164, 73.51082503795624, 77.63945549726486, 69.446502327919, 72.70494908094406, 71.5817141532898, 73.54864820837975, 67.62595921754837, 75.10242283344269, 79.13001671433449, 78.69327574968338, 84.13549572229385, 74.95523393154144, 70.58191940188408, 76.04671776294708, 73.28064098954201, 73.0515968799591, 80.37258043885231, 78.1379583477974, 76.14138588309288, 73.17615419626236, 70.35903096199036, 66.84368759393692, 69.28020045161247, 70.15333279967308, 71.08422204852104, 68.58843997120857, 69.84049558639526, 74.2250195145607, 58.98927345871925, 43.3572618663311, 1.071200044825673, 0.23200467025162652, 0.22646584402536973, 0.6905405083671212, 3.325939681380987, 3.08161374181509, 1.0672065778635442, 0.41018914722371846, 0.7170966302510351, 0.6077687186188996, 1.7456307238899171, 14.235211294144392, 53.24009835720062, 89.05167192220688, 66.29600018262863, 50.15730857849121, 61.04567751288414, 57.452977895736694, 64.59787890315056, 65.87005823850632, 61.89023919403553, 1.314961239695549, 0.21245700510917231, 0.13286479865200818, 0.16907983896089718, 0.1737467455677688, 0.2490750019205734, 0.17261261033127084, 0.19733202061615884, 0.15906988468486816, 0.1490980471135117, 0.16485621716128662, 0.17196740198414773, 0.10282905801432207, 0.13056218158453703], [0.05131979756697547, 0.11940602475078776, 0.14195163996191695, 0.06437440155423246, 0.011193203918082872, 0.09313866510638036, 0.11757948799640872, 0.21351992385461926, 0.05298640520777553, 0.0647285915329121, 0.02779357149847783, 0.016049440746428445, 0.024320075463037938, 0.12856277637183666, 0.09292906033806503, 3.021229044534266, 56.59298524260521, 51.27528838813305, 59.44149099290371, 60.20258255302906, 51.91343754529953, 87.71945580840111, 33.534055575728416, 0.734050014289096, 0.6928458565380424, 0.5934408155735582, 0.6172803207300603, 1.2847213936038315, 0.19154090870870277, 0.15205612900899723, 0.14852798864012584, 0.8307322638574988, 0.00815753697679611, 0.15495305793592706, 0.22948000259930268, 16.689188964664936, 48.29148709774017, 60.303489938378334, 90.52469328045845, 77.38585710525513, 79.57154542207718, 64.10449057817459, 67.7479250729084, 70.01635015010834, 69.09383565187454, 77.94258043169975, 85.27915075421333, 83.79099860787392, 84.87419128417969, 84.71838444471359, 83.44123497605324, 82.82460406422615, 82.56054863333702, 84.84176382422447, 83.02870631217957, 88.41420292854309, 81.76816195249557, 73.7382960319519, 73.12762320041656, 69.24067497253418, 80.68863227963448, 84.02837947010994, 81.91674157977104, 77.06318601965904, 72.84379363059998, 74.8157586157322, 82.2949580848217, 81.55262991786003, 80.53741559386253, 80.18696039915085, 78.35399955511093, 77.98710644245148, 80.3495916724205, 77.6676195859909, 73.32716569304466, 71.63318619132042, 68.69653657078743, 69.79991376399994, 69.01423752307892, 71.29615187644958, 70.74053809046745, 70.02666279673576, 66.95537120103836, 72.225202023983, 71.38505190610886, 69.84548091888428, 69.67895865440369, 69.2634965479374, 67.92201653122902, 74.6591766178608, 68.38670119643211, 67.44064316153526, 63.60989771783352, 61.59449726343155, 66.56458497047424, 66.76715970039368, 68.48554909229279, 66.14875808358192, 66.2118498980999, 68.11985671520233, 66.21667563915253, 70.95789402723312, 67.90747091174126, 68.76775994896889, 67.18807071447372, 66.30122110247612, 67.70178034901619, 69.21789139509201, 72.91965276002884, 71.0296493768692, 65.30448898673058, 61.74531117081642, 62.60226398706436, 68.6335663497448, 69.1162620484829, 70.89411824941635, 69.40560132265091, 63.01988437771797, 69.82677072286606, 72.47262194752693, 75.27215212583542, 74.48554873466492, 75.00637158751488, 67.75515988469124, 65.28833225369453, 67.5450387597084, 66.53275027871132, 67.52334952354431, 73.25515195727348, 67.88452014327049, 69.56662148237228, 67.60097935795784, 58.99799019098282, 60.43567344546318, 70.47210529446602, 72.54294857382774, 62.98136584460735, 59.595523327589035, 66.41037404537201, 30.628858767449856, 25.27160033583641, 11.464073192328215, 0.17227518546860665, 0.5059942079242319, 0.22012251487467438, 0.19179724651621655, 0.17093286296585575, 0.16274715220788494, 0.25813270651269704, 0.3245274937944487, 0.24961418705061078, 0.2777755446732044, 3.7181551102548838, 14.048594757914543, 37.93393827974796, 48.40468682348728, 40.195569321513176, 32.4648005515337, 39.39993001520634, 30.150369442999363, 49.96246263384819, 30.006710551679134, 0.14487451437162235, 0.20523984159808606, 0.10763499114545994, 0.045733629740425386, 0.07061213051201776, 0.025820816808845848, 0.0597227497928543, 0.060898226365679875, 0.03167620612657629, 0.05998398948577233, 0.015500235695071751, 0.07841026206733659, 0.0226715873577632, 0.03648364952823613, 0.08618422187282704, 0.09287146225688048, 0.07520897095673718, 0.040831588485161774, 0.07318007279536687, 0.030140767521515954, 0.0057685589672473725, 0.010796380338433664, 0.09471044482779689, 0.05593658694124315, 0.08600480025052093, 0.0456284117535688, 0.1330575640895404, 0.07185061913332902, 0.1353863938129507, 4.571455847471952, 66.40313163399696, 64.01106879115105, 75.14722242951393, 36.73096843063831, 48.25254298746586, 101.8286307156086, 44.64856177568436, 0.7491439918521792, 0.08686929839313962, 0.8768826280720532, 0.5974528065416962, 1.8634341401048005, 0.380786681198515, 0.03791552699112799, 0.07172813508077525, 3.04552280344069, 0.04560650355415419, 0.16183439962333068, 0.12020494672469795, 22.057390809059143, 58.845853954553604, 72.8807732462883, 95.92299520969391, 82.40529656410217, 89.07238081097603, 71.98025196790695, 78.2055415213108, 77.34574645757675, 76.05440855026245, 84.41833734512329, 89.90122273564339, 87.85785958170891, 88.59327211976051, 88.8614009320736, 87.36093744635582, 87.73112118244171, 84.85811814665794, 88.36699426174164, 85.86778476834297, 92.22672075033188, 84.10554572939873, 74.96734008193016, 76.51315033435822, 73.87603104114532, 83.29451724886894, 85.67926168441772, 82.03368410468102, 81.98011457920074, 81.97212740778923, 78.77408981323242, 85.91915041208267, 81.78968399763107, 83.89983236789703, 83.45364511013031, 82.3317477107048, 82.53776505589485, 82.2887796163559, 80.90495467185974, 77.23809823393822, 73.3109025657177, 74.35954749584198, 72.40968972444534, 70.93989819288254, 74.64576333761215, 73.3332833647728, 71.98462933301926, 71.20314046740532, 77.49205380678177, 72.30189710855484, 74.66437473893166, 72.81675428152084, 72.42947906255722, 74.38508972525597, 76.20744153857231, 69.95410189032555, 69.28780004382133, 62.89756894111633, 62.61777475476265, 68.84444743394852, 68.57590824365616, 70.0679437816143, 67.99375668168068, 69.29357573390007, 69.87586408853531, 67.81922444701195, 72.0675864815712, 68.40231835842133, 69.80473950505257, 71.62100404500961, 69.99650001525879, 69.81689125299454, 71.12522944808006, 72.47433945536613, 73.13869580626488, 69.99773114919662, 64.10830557346344, 64.89361703395844, 69.25412625074387, 72.90911212563515, 72.41602778434753, 74.02209520339966, 68.31632897257805, 67.82713562250137, 74.43843886256218, 74.23417702317238, 75.3656879067421, 76.03156417608261, 70.01809805631638, 71.86470776796341, 70.59665501117706, 70.17683073878288, 69.8492731153965, 72.44717091321945, 73.06961551308632, 72.08205610513687, 72.22924500703812, 66.10957458615303, 65.68071439862251, 70.58949619531631, 74.13063257932663, 74.1035932302475, 64.06694859266281, 77.59451150894165, 55.61075694859028, 29.471446573734283, 16.268808022141457, 0.30672283668536693, 0.9506390453316271, 0.05905344391067047, 0.34625077969394624, 0.35166670626495034, 0.6634698109701276, 0.25908609910402447, 0.2853354765102267, 0.1562716910848394, 0.5576562357600778, 3.98165007121861, 27.579545192420483, 40.51425822079182, 65.66629037261009, 51.62422366440296, 33.62364336848259, 41.476537585258484, 39.893781915307045, 56.834013909101486, 37.704639583826065, 0.0862106349086389, 0.13035725976806134, 0.09933566499967128, 0.02623307427711552, 0.07066557998768985, 0.03176667021762114, 0.06915467864018865, 0.024021197750698775, 0.045307191685424186, 0.056719664062256925, 0.04460114207176957, 0.08714329189388081, 0.06522604569909163, 0.032358525568270124, 0.152664229972288, 0.1821800516336225, 0.24021309072850272, 0.15056160686071962, 0.3683894011192024, 0.21055449469713494, 0.19207283563446254, 0.22994144033873454, 0.27714278956409544, 0.22739011474186555, 0.11940681884880178, 0.22970885125687346, 0.23835546540794894, 0.2070681075565517, 0.6837409513536841, 6.206961236894131, 84.26205173134804, 69.08296823501587, 82.06807985901833, 85.5969201028347, 68.68857219815254, 105.6286396086216, 62.81381383538246, 1.8150892155244946, 0.776906133396551, 2.1246462548151612, 2.349935690872371, 7.361523108556867, 1.0529518802650273, 0.3072078450350091, 0.38196723035071045, 5.367750618606806, 0.27442836959380656, 0.3726259956602007, 0.4180872312281281, 21.489260494709015, 73.80291536450386, 80.97311541438103, 96.1522825062275, 88.63334476947784, 94.82728600502014, 77.33876243233681, 86.13628596067429, 85.65268591046333, 81.79237425327301, 89.32007431983948, 93.57048064470291, 91.06729656457901, 92.00021490454674, 93.44665288925171, 93.58491227030754, 90.71101248264313, 89.27237167954445, 91.42038881778717, 90.98234072327614, 95.43932676315308, 89.95360672473907, 76.59540832042694, 78.52923855185509, 73.48211377859116, 86.26722693443298, 88.38972464203835, 87.90610939264297, 83.55598121881485, 82.31839522719383, 82.27612629532814, 88.62060785293579, 87.36988976597786, 88.50317135453224, 88.09934422373772, 86.60534799098969, 84.13372501730919, 86.46548509597778, 84.61984053254128, 80.30109867453575, 76.30625143647194, 76.06495678424835, 75.54949164390564, 74.09774914383888, 77.45345547795296, 76.28716126084328, 76.7498168349266, 76.92520782351494, 78.50042849779129, 77.7254144847393, 76.78561091423035, 75.10854810476303, 74.99002486467361, 75.30161574482918, 78.7178984284401, 73.12764599919319, 70.15118971467018, 66.56815677881241, 66.43974646925926, 71.52070462703705, 73.52215602993965, 75.29526248574257, 72.18102559447289, 74.00625005364418, 74.05318513512611, 71.46540239453316, 75.40412664413452, 71.78901582956314, 73.78542110323906, 74.5965787768364, 72.8499037027359, 74.00942668318748, 75.52316665649414, 78.54954466223717, 75.63938722014427, 71.8893912434578, 63.24966184794903, 68.35995823144913, 71.65107563138008, 76.59030139446259, 73.20552662014961, 75.8313225209713, 71.71494260430336, 69.72572654485703, 78.6314682662487, 76.79823383688927, 77.11132183670998, 79.38392668962479, 70.79003423452377, 74.55000847578049, 70.9093402326107, 72.23441272974014, 72.97453701496124, 76.85345247387886, 75.20890831947327, 74.53992381691933, 74.63344439864159, 69.412372559309, 66.25220373272896, 73.13619554042816, 68.7688846886158, 72.6770281791687, 65.39595007896423, 76.23226940631866, 62.305857092142105, 52.67779693007469, 16.618090979754925, 0.2796261938055977, 2.1928927302360535, 0.2876527881016955, 1.3344535999931395, 0.7957806112244725, 1.9152692961506546, 0.22168280615005642, 0.6351062923204154, 0.2533519989810884, 1.9552834052592516, 5.687681101262569, 42.630243077874184, 54.270504266023636, 78.14231291413307, 58.418802469968796, 49.4653695076704, 55.483900755643845, 46.181528717279434, 67.72286161780357, 44.851664677262306, 0.1658274361398071, 0.2930990536697209, 0.3075524984160438, 0.1822080899728462, 0.18536214338382706, 0.19579231651732698, 0.12707453279290348, 0.13820545660564676, 0.29770405031740665, 0.16222496225964278, 0.12642257090192288, 0.20626520767109469, 0.15774320665514097, 0.17977639858145267], [0.06130208828835748, 0.03752941724087577, 0.09169137323624454, 0.13523363013518974, 0.04643369764380623, 0.04106612199393567, 0.1960804034024477, 0.2108973075519316, 0.14784705330384895, 0.09550880276947282, 0.012161252070654882, 0.13843645749147981, 0.0714794488158077, 0.15235430910252035, 0.08434899456915446, 16.71183194965124, 67.86656230688095, 42.69823282957077, 47.60699562728405, 42.67610661685467, 58.394886553287506, 69.96274262666702, 1.7975615873001516, 1.5238868538290262, 0.13905382045777515, 0.23470740881748497, 0.6704284250736237, 1.5491803153418005, 0.9104958618991077, 0.09412152838194743, 0.2767438703449443, 0.10275917738908902, 0.1525554311228916, 0.3943556937156245, 1.5478070452809334, 35.07464110851288, 50.64220815896988, 67.56061032414436, 68.5667735338211, 86.98728069663048, 76.70128583908081, 72.25766748189926, 81.29191070795059, 65.16112267971039, 74.89572152495384, 77.21825569868088, 82.78067082166672, 85.26494711637497, 83.39514344930649, 80.68529605865479, 78.98799553513527, 82.71314084529877, 80.75362399220467, 84.34874027967453, 81.12557083368301, 78.19495528936386, 72.27185592055321, 73.5416641831398, 77.34980463981628, 82.58551329374313, 75.06413608789444, 78.06376352906227, 77.77570098638535, 78.86553570628166, 76.30024015903473, 76.94312766194344, 78.76690819859505, 83.48996356129646, 78.14311847090721, 81.41649082303047, 77.04377666115761, 76.97420999407768, 71.90278932452202, 74.54289525747299, 68.29735279083252, 72.13883265852928, 65.79118207097054, 64.66106191277504, 66.4415779709816, 68.62638473510742, 69.37777921557426, 62.36696921288967, 66.71662241220474, 75.82254499197006, 64.31683078408241, 69.88312929868698, 66.98891580104828, 69.64751914143562, 74.9129194021225, 72.6629613339901, 71.01441219449043, 70.97616344690323, 68.59149500727654, 62.10128366947174, 68.6276462674141, 68.6605753004551, 68.13205406069756, 68.79058912396431, 64.26478117704391, 64.68362510204315, 64.6303291618824, 69.06200096011162, 63.184548541903496, 65.48697039484978, 67.15014114975929, 66.82310029864311, 65.50507262349129, 69.53438401222229, 68.96411821246147, 72.60790228843689, 69.99871149659157, 67.76278987526894, 61.56257137656212, 62.14263305068016, 64.85491991043091, 65.9439566731453, 68.39189931750298, 65.99371120333672, 64.60015118122101, 72.57864385843277, 72.15172916650772, 73.02601665258408, 72.13218301534653, 70.95072761178017, 67.2199510037899, 62.98021450638771, 66.3207596540451, 67.58600816130638, 67.18838229775429, 72.39020437002182, 68.73679161071777, 71.23632788658142, 64.90055546164513, 59.12035122513771, 62.28734448552132, 70.04871681332588, 69.85125660896301, 57.59195923805237, 64.07694965600967, 49.65280584990978, 20.219809412956238, 25.82354921847582, 2.4493267200887203, 0.04876057922956534, 0.28999435307923704, 0.44197280891239643, 0.2616501896409318, 0.16126543952850625, 0.13349200249649584, 0.07874519331380725, 0.033780899830162525, 0.11678254013531841, 0.45071124157402664, 19.248410537838936, 18.677308782935143, 50.86472421884537, 72.86622002720833, 27.291856929659843, 30.054755173623562, 39.7892115265131, 52.46019020676613, 33.36181461811066, 0.028578125493368134, 0.10170312350965105, 0.03862481607939117, 0.03225272499548737, 0.07599746575579047, 0.05852925016370136, 0.03505870372464415, 0.07294756534975022, 0.0809694173221942, 0.09092929889447987, 0.04736190916446503, 0.12776250368915498, 0.09769538504770026, 0.02535406714741839, 0.06906762471771799, 0.05082042123831343, 0.04737726048915647, 0.06139608500234317, 0.023859346474637277, 0.04265553143341094, 0.07192527176812291, 0.004508300835368573, 0.10729340283432975, 0.05343735640053637, 0.06322683344478719, 0.09704135256470181, 0.08655040495796129, 0.3083122201496735, 0.2243487341911532, 20.857200510799885, 75.1785859465599, 56.78748920559883, 58.34024168550968, 30.06172589957714, 62.00531981885433, 83.54263633489609, 0.8052144362591207, 0.7941361307166517, 0.15778264438267797, 0.09254608245100826, 0.19690062501467764, 2.0299275498837233, 1.115014306269586, 0.37222458282485604, 0.1573450889554806, 0.10608002849039622, 0.1375937191187404, 0.2481525272014551, 2.770820581354201, 44.227776154875755, 60.57508796453476, 74.51899453997612, 70.91505512595177, 90.29064103960991, 79.99044254422188, 77.66166150569916, 82.92235761880875, 71.12938642501831, 81.10750660300255, 81.27672672271729, 86.71722158789635, 87.53150269389153, 84.59935963153839, 83.50635588169098, 85.6486277282238, 86.68349459767342, 84.28126350045204, 87.62813150882721, 84.03410196304321, 78.26763018965721, 76.22862160205841, 78.55446919798851, 83.73397126793861, 86.93107411265373, 77.50558868050575, 81.39377564191818, 79.91662010550499, 82.11762920022011, 81.52534738183022, 82.8554356098175, 81.7107318341732, 82.67111510038376, 81.02850884199142, 84.773960262537, 78.90187695622444, 79.05888453125954, 74.92962330579758, 77.50590026378632, 72.3397658765316, 74.05254676938057, 71.84164300560951, 71.72326415777206, 70.85323244333267, 73.98301050066948, 68.40423345565796, 64.85528469085693, 70.58853104710579, 78.85773092508316, 68.73154029250145, 73.9869774878025, 70.1482030749321, 71.07634127140045, 75.88429927825928, 75.5960239470005, 70.74060648679733, 71.35914489626884, 69.19390708208084, 64.91037413477898, 69.55157428979874, 73.1615249812603, 70.38574352860451, 70.83029687404633, 69.03783425688744, 69.10195201635361, 66.07200220227242, 68.88350173830986, 66.98984295129776, 70.07352948188782, 70.03693744540215, 71.08945056796074, 67.44074955582619, 71.92471414804459, 71.2257644534111, 74.44817394018173, 71.24034807085991, 70.43622761964798, 63.54263752698898, 66.28677427768707, 65.84298089146614, 71.98000878095627, 69.20823231339455, 72.4210587143898, 68.9517080783844, 68.96287187933922, 71.35517030954361, 76.4080859720707, 71.2138482928276, 74.86053541302681, 70.96270456910133, 71.00187286734581, 70.43463170528412, 72.66342490911484, 68.47997859120369, 74.94427531957626, 72.19370171427727, 74.6008725464344, 69.9111033976078, 66.28743544220924, 62.73705795407295, 69.20512408018112, 75.88630557060242, 66.87657102942467, 68.52000564336777, 69.12480399012566, 37.4334367364645, 29.702814258635044, 4.815045101568103, 0.7308086100965738, 0.10825526333064772, 0.26265853084623814, 0.10043957256129943, 0.12093130149878561, 0.1414762795320712, 0.2739151893183589, 0.03190530711435713, 0.2559260046109557, 0.08921377258957364, 25.391007028520107, 24.47421882301569, 56.45161382853985, 83.20442408323288, 35.01032195985317, 36.06693886220455, 48.13761055469513, 60.89674070477486, 40.361172035336494, 0.08702530525624752, 0.1200194914417807, 0.08899032676708885, 0.1527589577017352, 0.12129703929531388, 0.04262356713297777, 0.05428224700153805, 0.02178492497478146, 0.13565059838583693, 0.013789550976071041, 0.050705269604804926, 0.18801054189680144, 0.07887247906182893, 0.005047555541750626, 0.1120924117276445, 0.10096297963173129, 0.1561765922815539, 0.19761314615607262, 0.22481431311462075, 0.15039125428302214, 0.28638107352890074, 0.2541536669014022, 0.47666904400102794, 0.2119837375357747, 0.15741853188956156, 0.3601668501505628, 0.22827822802355513, 0.46490395499859005, 0.49063083075452596, 25.74625376611948, 89.81144115328789, 62.76790849864483, 68.17309185862541, 63.948220163583755, 71.00716978311539, 105.57302579283714, 10.657360330224037, 2.766518499702215, 0.49521682842168957, 0.8250927133485675, 2.001879117451608, 3.9884151332080364, 3.6913582356646657, 1.1717542866244912, 0.8154216385446489, 0.6296881393063813, 0.18552281835582107, 0.8266552607528865, 2.107303272932768, 56.118440106511116, 74.16341722011566, 83.37839394807816, 74.9538280069828, 93.40697541832924, 84.91091251373291, 85.75085744261742, 89.56728905439377, 81.16986885666847, 85.18409505486488, 85.98234102129936, 92.01617404818535, 94.06331419944763, 89.39318999648094, 89.31552976369858, 89.99823153018951, 91.37401610612869, 89.27349641919136, 92.25965738296509, 86.01319536566734, 81.22702538967133, 76.5367242693901, 77.98450738191605, 85.68551614880562, 90.16743645071983, 79.26346555352211, 84.7786796092987, 81.5838186442852, 85.49257770180702, 84.48579132556915, 86.02564349770546, 85.04505291581154, 88.37324872612953, 86.5883781015873, 88.83667185902596, 83.55324536561966, 84.90889862179756, 76.92409828305244, 80.85159793496132, 75.58294504880905, 77.95207992196083, 75.39000660181046, 73.50881114602089, 72.9550288617611, 77.2768485546112, 73.0295504629612, 68.31107005476952, 72.17625305056572, 83.56583788990974, 71.68817684054375, 78.43739748001099, 74.70698565244675, 72.72265613079071, 80.65536886453629, 79.06034365296364, 72.65223830938339, 75.73353096842766, 71.66999101638794, 67.09978625178337, 74.87762689590454, 76.13604336977005, 75.68646669387817, 74.2418298125267, 71.81129023432732, 69.77024495601654, 70.32523557543755, 74.1514478623867, 70.48541978001595, 72.12390705943108, 73.72282326221466, 74.79856073856354, 69.72001165151596, 76.63003966212273, 75.04812374711037, 79.28115740418434, 75.76554045081139, 73.29828724265099, 64.39161077141762, 67.75278881192207, 68.74951332807541, 71.95384338498116, 73.36713194847107, 73.32096442580223, 71.18341952562332, 74.66905608773232, 76.03758305311203, 80.5281288921833, 76.41504719853401, 77.5225281715393, 72.53566056489944, 73.7586097419262, 70.79875856637955, 75.05340546369553, 74.14362788200378, 77.62348115444183, 74.68481004238129, 76.56659826636314, 73.77493366599083, 67.36618235707283, 64.78514805436134, 68.79176706075668, 70.68193763494492, 66.91225871443748, 66.06415182352066, 70.01505821943283, 54.17844280600548, 46.83078467845917, 3.665284034796059, 0.9081833891104907, 0.414789542555809, 0.6343239499256015, 0.43455305392853916, 0.5370688810944557, 0.2983951976057142, 0.6336167722474784, 0.14193657436408103, 0.34270705422386527, 0.9468928619753569, 34.319386035203934, 35.75901098549366, 68.46179276704788, 92.28457644581795, 38.004838675260544, 44.02744710445404, 59.98827785253525, 66.0055285692215, 49.13915701210499, 0.3075307683320716, 0.3204565169289708, 0.21288120187819004, 0.34655954281333834, 0.25242585805244744, 0.15172339451964945, 0.24128383171046153, 0.15036931639770046, 0.3303917369339615, 0.20407180505571887, 0.14374311023857445, 0.3782265982590616, 0.22986753727309406, 0.07207450282294303], [0.027795994610642083, 0.0625906050845515, 0.08471130364341661, 0.16942446265602484, 0.08021281260880642, 0.06878782020066865, 0.17069405468646437, 0.1420774488360621, 0.15040614176541567, 0.10735407340689562, 0.047946109261829406, 0.027060977117798757, 0.0403724996431265, 0.02232614173408365, 0.12406603680574335, 39.65507872402668, 53.637990206480026, 49.16479803621769, 34.72418591380119, 31.71557955443859, 78.65663051605225, 27.33745828270912, 1.2301852949894965, 0.9783310687635094, 0.17200311413034797, 0.10234931149170734, 0.15247296367306262, 0.603998489677906, 0.7461869192775339, 0.4159738024463877, 0.30515536142047495, 0.036150929881841876, 0.27677147823851556, 0.23998434597160667, 12.081130631268024, 43.10042604804039, 51.94621458649635, 69.8507322371006, 58.02216835319996, 68.98083731532097, 67.63640105724335, 66.71050474047661, 58.29424515366554, 66.28776982426643, 70.26931777596474, 78.64400759339333, 80.11430069804192, 80.5017963051796, 76.81525692343712, 81.62947699427605, 84.76196050643921, 80.67344069480896, 81.87636494636536, 82.7153979241848, 74.77800384163857, 77.82537952065468, 82.2553338110447, 81.33398965001106, 81.57314881682396, 76.17357015609741, 79.6068987250328, 77.38080337643623, 76.49544328451157, 74.42823261022568, 76.61259859800339, 74.13124814629555, 76.20393812656403, 77.71396189928055, 78.51738318800926, 77.61275812983513, 74.2403706908226, 68.46245393157005, 71.3436721265316, 70.51983833312988, 69.84416618943214, 67.90991798043251, 66.16227775812149, 64.89415660500526, 63.61177481710911, 69.71431195735931, 59.25280071794987, 63.787374794483185, 71.6976535320282, 64.72489848732948, 64.85590785741806, 63.932192623615265, 61.73177629709244, 58.17220330238342, 68.17398101091385, 67.88288623094559, 65.41086807847023, 68.78358989953995, 72.11069136857986, 67.14748129248619, 68.34336832165718, 71.46845743060112, 71.53040170669556, 71.20617270469666, 68.8152801990509, 66.73677653074265, 65.97910478711128, 68.55504736304283, 69.58325698971748, 66.27303421497345, 68.7753139436245, 64.37351614236832, 64.28577125072479, 69.43618208169937, 65.6354208290577, 68.43727648258209, 68.319201618433, 68.18204417824745, 69.29448768496513, 62.06796705722809, 62.906540259718895, 63.89386788010597, 60.805481001734734, 69.50308129191399, 72.62448459863663, 64.11571517586708, 70.87799191474915, 68.00404652953148, 73.21004077792168, 71.87280133366585, 70.77931120991707, 64.56959322094917, 63.5092943161726, 68.19061651825905, 66.42504885792732, 71.20942533016205, 73.97963628172874, 72.03746169805527, 69.03807744383812, 62.0850395411253, 59.799397587776184, 64.92834717035294, 69.18541073799133, 57.83284351229668, 59.230237528681755, 59.56526555120945, 32.53729686141014, 25.854097679257393, 18.9783039316535, 0.5498812592122704, 0.06055314624973107, 0.06810491817304865, 0.12548911239719018, 0.9762040141504258, 0.309048400959, 0.08483795114443637, 0.08335286911460571, 0.4477073246380314, 0.13487440097378567, 6.193435387685895, 10.575446225702763, 18.219363056123257, 75.05138397216797, 25.526114478707314, 32.09003046154976, 32.465758100152016, 46.60162657499313, 36.82558335363865, 0.04604325375112239, 0.052241493031033315, 0.08008845092263073, 0.04670852234994527, 0.01227749373356346, 0.03029831248568371, 0.029967002919875085, 0.09341901139123365, 0.17306370253209025, 0.0815992483694572, 0.10702177678467706, 0.04933932454150636, 0.10936191683867946, 0.044390910188667476, 0.011719185313268099, 0.06649411632679403, 0.07655030640307814, 0.019552231206034776, 0.03174216821207665, 0.004742497594634187, 0.1529880883754231, 0.08523511889507063, 0.05450990080134943, 0.03227927903935779, 0.03249220120778773, 0.025711748930916656, 0.08751400207984261, 0.06475622911239043, 0.07743479058262892, 47.1667854487896, 63.647823482751846, 61.97258457541466, 40.30604459345341, 29.151788726449013, 92.81575754284859, 34.69168245792389, 0.6053972302470356, 0.0843571953009814, 0.12035816311254166, 0.08832077597617172, 0.1643825339851901, 0.48193283029831946, 1.1816139263100922, 0.5013415950816125, 0.18744011234957725, 0.031783810118213296, 0.37866027967538685, 0.11701791227096692, 15.211750343441963, 55.560356453061104, 63.155358508229256, 79.48354214429855, 65.35568743944168, 76.19830682873726, 70.308478474617, 73.38067442178726, 65.36036878824234, 71.64668306708336, 72.0108251273632, 85.15296712517738, 86.21829316020012, 85.38243681192398, 80.4303677380085, 87.53436014056206, 86.66251212358475, 84.8168295621872, 85.63654437661171, 86.9147577881813, 74.46277275681496, 82.45596304535866, 84.94293719530106, 85.27306348085403, 84.9370627105236, 80.79375743865967, 81.62424847483635, 80.29255673289299, 78.78308773040771, 77.54934713244438, 78.6043681204319, 78.99660587310791, 80.52150204777718, 80.86460083723068, 80.86374208331108, 79.80027034878731, 74.42111939191818, 72.66435965895653, 74.83315408229828, 75.00053510069847, 74.10614669322968, 72.5312452018261, 71.27915158867836, 72.17405676841736, 69.18554753065109, 71.48090556263924, 62.878756150603294, 65.2995416522026, 70.87748274207115, 69.02385100722313, 68.50257977843285, 63.77228960394859, 66.55504748225212, 60.61028927564621, 69.74504470825195, 70.392165184021, 66.49100571870804, 69.05688643455505, 73.82889077067375, 70.07142439484596, 69.60547059774399, 73.44355344772339, 72.77377858757973, 71.24296993017197, 72.86754235625267, 70.3029915690422, 71.09926924109459, 70.90148225426674, 72.45193585753441, 72.24495336413383, 71.95728600025177, 70.34631684422493, 69.95021089911461, 69.30022537708282, 69.59115296602249, 70.31486213207245, 71.60870790481567, 71.59925401210785, 71.25348016619682, 67.8730371594429, 64.2881727218628, 66.93625062704086, 66.97628527879715, 69.45778772234917, 74.31047692894936, 66.29441946744919, 71.56990438699722, 69.15070340037346, 72.27084517478943, 72.50977635383606, 75.28428867459297, 69.07066449522972, 68.2020691037178, 71.65549099445343, 69.09413203597069, 72.81486198306084, 74.73508894443512, 74.02018770575523, 72.2649934887886, 69.70911383628845, 63.23156721889973, 65.34640833735466, 69.64872747659683, 70.1020735502243, 62.33631245791912, 69.23581883311272, 60.620206743478775, 31.93681128323078, 24.470922499895096, 0.9942165319807827, 0.17800618341425434, 0.08217226801207289, 0.025035424187080935, 0.9242898935917765, 0.7257219299208373, 0.028894157949252985, 0.08449556873529218, 0.20617000496713445, 0.6678987701889127, 8.145105186849833, 11.360586695373058, 19.532633386552334, 88.33563834428787, 27.973437756299973, 28.908094502985477, 42.13110186159611, 53.568263947963715, 45.783899053931236, 0.17250339587917551, 0.053826616567675956, 0.14720175589900464, 0.008926036462071352, 0.042347295238869265, 0.040600435459055007, 0.04584221707773395, 0.09276725730160251, 0.04091813032573555, 0.08020573994144797, 0.022193308432179037, 0.054358023990062065, 0.033935856554307975, 0.03297371404187288, 0.10981812985846773, 0.2428306604269892, 0.08111199873383157, 0.2536313730524853, 0.20300158357713372, 0.2027600590372458, 0.24135258427122608, 0.21554851031396538, 0.23576658713864163, 0.1641423156252131, 0.14420413237530738, 0.1923355262260884, 0.16469543828861788, 0.14012861356604844, 0.25645102956332266, 55.76484628021717, 74.30532440543175, 67.11699172854424, 49.415789768099785, 46.88591592013836, 98.83645847439766, 55.288473442196846, 4.81701054610312, 1.2246729782782495, 0.4509364388650283, 0.5010566697455943, 0.7004505547229201, 1.0902699152939022, 4.587682401761413, 0.6341834762133658, 0.7099772372748703, 0.19091242837021127, 0.9465203632134944, 0.29607500648126006, 15.981986112892628, 68.69722053408623, 71.10683083534241, 84.30473864078522, 73.2845775783062, 90.03893494606018, 79.24600169062614, 81.12734913825989, 76.53058379888535, 80.5005195736885, 77.3267474770546, 87.96652615070343, 88.4052886068821, 90.17131984233856, 83.49640801548958, 89.774659126997, 91.24923840165138, 90.46525686979294, 89.0588991343975, 89.69120040535927, 75.23068115115166, 82.11949110031128, 87.60815978050232, 88.7917810678482, 89.05478775501251, 82.44089305400848, 84.6420769393444, 82.03951299190521, 82.49366462230682, 78.41386914253235, 83.40749278664589, 82.90325984358788, 83.79267051815987, 85.36998867988586, 84.22783836722374, 82.34279751777649, 78.25233221054077, 76.75120756030083, 77.20029026269913, 79.78738903999329, 77.65559703111649, 75.69579139351845, 74.56523045897484, 73.79023164510727, 70.70193976163864, 75.66403269767761, 64.73660185933113, 69.1928431391716, 77.85263165831566, 75.35479009151459, 73.53623047471046, 70.21858289837837, 70.8102111518383, 63.91497194766998, 73.02358478307724, 74.16454195976257, 70.51886558532715, 74.33276653289795, 79.15667608380318, 72.40761503577232, 75.6059642136097, 76.83506906032562, 78.50201681256294, 77.40070670843124, 76.10611617565155, 73.47707524895668, 74.51656267046928, 75.65112859010696, 75.00606760382652, 74.20654490590096, 73.04017469286919, 73.01963299512863, 70.17506763339043, 74.08413827419281, 74.83099579811096, 76.24880611896515, 73.60874578356743, 75.15101462602615, 74.4656454026699, 69.4175174832344, 64.99001026153564, 70.51467821002007, 66.45656436681747, 72.29055091738701, 77.33477264642715, 70.85988968610764, 73.21626484394073, 72.39576727151871, 74.65105265378952, 77.11196780204773, 77.1300320327282, 71.3850899040699, 69.7269044816494, 73.03917154669762, 71.5992084145546, 77.52059027552605, 78.86149272322655, 77.97677859663963, 76.10346391797066, 71.27220556139946, 64.06875729560852, 67.36154660582542, 68.57811972498894, 67.1028944849968, 61.81510962545872, 68.42010140419006, 70.37420734763145, 54.2247661203146, 32.13759630918503, 1.1118267523124814, 0.4483195667853579, 0.21159995812922716, 0.16695809812517837, 1.237874657381326, 0.9782849962357432, 0.19854894984746352, 0.15157535090111196, 0.645392993465066, 1.3570256950333714, 12.287268619984388, 16.4043752476573, 29.32951658964157, 99.9223718047142, 37.518198788166046, 47.89961412549019, 47.17845842242241, 62.28520140051842, 52.84602910280228, 0.2358786217519082, 0.18089457764290273, 0.22248536464758217, 0.1514720736304298, 0.10012349928729236, 0.11767097996198572, 0.1249492444912903, 0.2232504595303908, 0.2526373998261988, 0.20577623625285923, 0.20384824048960581, 0.15446916280779988, 0.38319313956890255, 0.19079505029367283], [0.05417469124950003, 0.07749721262371168, 0.07136078682378866, 0.07658586269826628, 0.16362833383027464, 0.12020965936244465, 0.20259867160348222, 0.11392216198146343, 0.20525927102426067, 0.22294272057479247, 0.027845779732160736, 0.06895341561175883, 0.15266072703525424, 0.18312134721782058, 4.258956341072917, 58.610224798321724, 58.87192815542221, 47.61652551591396, 42.04981282353401, 47.999776750802994, 59.04980421066284, 2.3518070904538035, 0.7435809716116637, 0.3619595227064565, 0.16995416313875467, 0.2583826915360987, 0.35004288714844733, 0.01927461602463154, 0.44531455147080123, 1.070198561064899, 0.7083850039634854, 0.45858522062189877, 0.8487492939457297, 0.9941316896583885, 29.134847335517406, 52.79756270349026, 54.94830049574375, 61.41701638698578, 50.28070315718651, 41.276128739118576, 57.5676329433918, 65.48079952597618, 54.87199679017067, 62.21424400806427, 75.0582692027092, 79.21018481254578, 79.10920903086662, 78.9610929787159, 77.67938375473022, 81.88201144337654, 83.3442185819149, 78.82240802049637, 88.14931154251099, 77.5320428609848, 77.37733036279678, 85.25543242692947, 81.00669801235199, 82.71221369504929, 78.5163040459156, 76.47389084100723, 74.2472331225872, 73.79177436232567, 74.09861549735069, 72.38936081528664, 76.8010912835598, 73.10652673244476, 72.37311288714409, 74.53290939331055, 75.41582241654396, 70.8826656639576, 68.96836638450623, 71.17507517337799, 66.61250039935112, 67.19546511769295, 69.23715636134148, 68.60005214810371, 69.78602930903435, 61.91540144383907, 65.18409624695778, 61.25690437853336, 57.35733322799206, 56.73651114106178, 60.11279717087746, 61.40652894973755, 56.79831102490425, 53.81069473922253, 61.02885581552982, 60.55238038301468, 63.420116901397705, 64.46741670370102, 60.30722513794899, 61.35249584913254, 67.78121888637543, 73.69303286075592, 67.61888399720192, 67.45059862732887, 67.91930347681046, 67.69926488399506, 67.88437575101852, 63.01128163933754, 66.70643135905266, 64.92101356387138, 69.78851437568665, 68.72425228357315, 70.11833667755127, 70.40301740169525, 67.34345957636833, 66.42058029770851, 66.305400878191, 65.1457031071186, 68.23320463299751, 67.04709067940712, 69.10759851336479, 63.89717370271683, 62.30420038104057, 58.586730659008026, 66.76123201847076, 62.83732317388058, 69.93584766983986, 64.28458571434021, 66.95755988359451, 71.3102263212204, 71.37004271149635, 71.37730792164803, 68.76829192042351, 69.24912571907043, 59.10873904824257, 64.01160836219788, 67.1191044151783, 69.61930945515633, 70.34121751785278, 71.63844510912895, 68.39926332235336, 64.88095611333847, 61.15654796361923, 59.00238275527954, 67.53195226192474, 66.07140183448792, 54.94547724723816, 57.94679559767246, 54.97348554432392, 23.50601177662611, 29.2584965005517, 8.604828268289566, 0.1745219188160263, 0.2679868246195838, 0.09645011319662444, 1.5056384517811239, 0.4234676534542814, 0.0698072936211247, 0.12721108796540648, 0.0547731220285641, 0.51532341982238, 1.208558042999357, 0.3462503937771544, 4.006705451756716, 50.01939117908478, 44.138203561306, 37.705410942435265, 37.237010076642036, 38.99606108665466, 42.332050278782845, 0.7173821493051946, 0.15387194172944874, 0.06416085598175414, 0.021666916072717868, 0.02886254802433541, 0.013247809147287626, 0.058502158062765375, 0.0051377960608078865, 0.020125970731896814, 0.1553263730602339, 0.04293963669624645, 0.1074603118468076, 0.06248571735341102, 0.039160386950243264, 0.03228526817110833, 0.02949573357909685, 0.05322797427652404, 0.11376261507393792, 0.07268603992997669, 0.037222958490019664, 0.014234094651328633, 0.03724573500221595, 0.0299438497677329, 0.08739302458707243, 0.14653916645329446, 0.07710198187851347, 0.10911458128248341, 0.236863050959073, 5.509208953008056, 69.61946904659271, 67.51758903265, 70.10570615530014, 29.833337254822254, 48.85402791202068, 73.47569972276688, 5.432223184034228, 0.8454515459015965, 0.29686934198252857, 0.17023822758346796, 0.046225810947362334, 0.16415456106187776, 0.04827879922231659, 0.5202718230430037, 1.0664815292693675, 0.6510878191329539, 0.7346283551305532, 1.0755149507895112, 1.1451900308020413, 38.36748741567135, 65.70116490125656, 64.51405540108681, 71.59459546208382, 65.73851689696312, 54.757136553525925, 64.07518655061722, 72.51532405614853, 61.75378851592541, 69.68210488557816, 79.54241618514061, 84.66713279485703, 81.78725212812424, 82.17429175972939, 81.40341192483902, 83.27830731868744, 84.107666015625, 85.35899206995964, 89.9030314385891, 78.65259513258934, 78.48684042692184, 86.07699394226074, 83.65525469183922, 84.2319193482399, 79.89202782511711, 81.95841014385223, 77.31838792562485, 78.55698466300964, 77.43406891822815, 76.21445596218109, 78.82876127958298, 77.11959019303322, 76.69777482748032, 77.9752054810524, 76.7262353003025, 72.38571301102638, 72.90104135870934, 71.97596579790115, 70.40875509381294, 71.91035851836205, 72.50316470861435, 73.41418862342834, 72.869883030653, 68.8544636964798, 70.4518523812294, 64.05044987797737, 57.92331285774708, 59.063270688056946, 61.57956786453724, 65.0356838107109, 61.58693186938763, 58.02859380841255, 66.8136616051197, 67.80150979757309, 67.30920061469078, 66.16625994443893, 63.12388859689236, 63.90342056751251, 66.98504000902176, 74.77445483207703, 68.78206238150597, 67.19717502593994, 68.62555637955666, 69.4873121380806, 72.1205860376358, 68.18870142102242, 67.72242844104767, 68.81108522415161, 69.78417500853539, 71.80429100990295, 72.57518604397774, 71.23689025640488, 71.82015895843506, 67.91480451822281, 68.99727523326874, 69.52312901616096, 68.89623865485191, 70.07718488574028, 71.51691243052483, 69.29457128047943, 65.63483566045761, 61.518182158470154, 70.5295430123806, 65.53170919418335, 70.72761878371239, 68.34011569619179, 64.5929391682148, 71.06949403882027, 70.42546659708023, 72.6330341398716, 71.1606815457344, 77.10926994681358, 65.20900771021843, 67.1274183690548, 69.93705600500107, 70.85889413952827, 72.82019689679146, 73.45535561442375, 72.72392526268959, 68.4376260638237, 67.4892121553421, 60.252819657325745, 67.45338767766953, 71.23389601707458, 64.52501401305199, 62.70813390612602, 72.92517006397247, 45.81436201930046, 29.774788096547127, 12.766691744327545, 0.16670835058903322, 0.27483393845614046, 0.09715995518490672, 0.9888966393191367, 0.24560520920204, 0.3815404063789174, 0.039577266143169254, 0.2219261712161824, 1.013012460898608, 1.409606442321092, 0.2639147196896374, 3.0250191036611795, 59.546498358249664, 45.9366774559021, 28.69185570627451, 54.06160667538643, 46.52826011180878, 52.32259958982468, 1.0285693011246622, 0.05956397100817412, 0.06099378158978652, 0.019424364727456123, 0.02477703063050285, 0.06087171313993167, 0.044449881243053824, 0.03553553360688966, 0.031163530511548743, 0.07079674716806039, 0.04716837931482587, 0.030269424387370236, 0.0560581470199395, 0.03475244535366073, 0.18706627772189677, 0.11411864557885565, 0.13228052062913775, 0.2963048644596711, 0.2512150292750448, 0.22372307401383296, 0.4482504876796156, 0.22699279856169596, 0.23945145425386727, 0.2750306372763589, 0.40636539459228516, 0.14469858084339648, 0.3245138382771984, 0.4846069071209058, 6.741447206586599, 78.94275516271591, 75.74512794613838, 64.38287124037743, 63.47444258630276, 68.70779916644096, 83.00239652395248, 12.736027389764786, 2.3480334179475904, 0.6710728467442095, 0.317131903138943, 0.2826120617100969, 0.7135441771242768, 0.2464687277097255, 1.0100162029266357, 2.6502599380910397, 1.317238979972899, 1.3518478791229427, 1.6512889112345874, 1.7078334395773709, 41.999093145132065, 76.82525798678398, 71.45999908447266, 83.62501591444016, 76.80986881256104, 67.8683178126812, 77.44155451655388, 83.23970139026642, 74.36646312475204, 78.00328597426414, 86.93176567554474, 89.55706760287285, 87.60065898299217, 86.7460848391056, 85.56294992566109, 89.52534690499306, 89.08437296748161, 89.71042737364769, 98.1322118639946, 82.67250582575798, 79.1687062382698, 90.33215761184692, 87.87742093205452, 89.90035638213158, 84.5137046277523, 85.54086551070213, 78.98856550455093, 80.95650270581245, 80.42838424444199, 78.31955820322037, 82.82914102077484, 80.33392131328583, 81.04095697402954, 82.06192418932915, 81.01223811507225, 76.5521514415741, 75.81534817814827, 77.2369734942913, 75.4806849360466, 73.93005654215813, 76.89315274357796, 76.78227469325066, 76.66995272040367, 68.88818308711052, 72.19500124454498, 70.2324977517128, 62.64036074280739, 63.292971923947334, 65.01934468746185, 69.15470078587532, 63.35370406508446, 61.77803121507168, 70.34154430031776, 69.29436609148979, 68.67689922451973, 69.07625779509544, 65.69212138652802, 68.3322349190712, 73.36425170302391, 81.61634489893913, 74.60331201553345, 73.37553709745407, 75.11491656303406, 74.16960328817368, 75.08522495627403, 70.78967705368996, 72.3365968465805, 72.23209485411644, 76.37606889009476, 77.8158800303936, 76.6072940826416, 77.19193831086159, 72.97488659620285, 69.60913360118866, 71.37810587882996, 73.10292452573776, 73.6711460351944, 73.07693392038345, 75.78053444623947, 71.62472024559975, 66.14010974764824, 63.21238584816456, 71.45728603005409, 65.57001873850822, 74.93988275527954, 71.15612179040909, 72.83278942108154, 72.48298779129982, 75.10477110743523, 76.21578589081764, 73.2888713479042, 77.81293898820877, 64.84068587422371, 69.45435270667076, 72.74711921811104, 74.17012006044388, 76.64481326937675, 77.38417759537697, 73.21912229061127, 75.01014858484268, 68.10505270957947, 61.206997856497765, 68.66408631205559, 68.10501471161842, 64.44308280944824, 61.03755734860897, 74.83799502253532, 61.259237453341484, 53.165899738669395, 13.408065028488636, 0.328088496462442, 0.8435659564565867, 0.15738198853796348, 2.901784353889525, 0.6236912892200053, 0.40938507474493235, 0.1529108901740983, 0.4494173516286537, 1.6656923945993185, 2.2306679282337427, 0.7731433259323239, 5.941336015239358, 68.37856203317642, 60.19471317529678, 56.03676348924637, 49.55941066145897, 51.804588586091995, 62.08798438310623, 1.115951668471098, 0.2368810257758014, 0.20915346831316128, 0.1720245770411566, 0.18836991948774084, 0.16721826541470364, 0.13502446323400363, 0.10829536156961694, 0.178710006584879, 0.22939033631701022, 0.10020333211286925, 0.09724668998387642, 0.09058642666786909, 0.13784588605631143], [0.10467077168868855, 0.011171933037985582, 0.02087330045469571, 0.05128948083438445, 0.0723867688793689, 0.16117405146360397, 0.16816008050227538, 0.17311577161308378, 0.1166392388404347, 0.11988689191639423, 0.10732716313214041, 0.04856484891206492, 0.11793032346758991, 0.11909297201782465, 16.039087548851967, 66.7339038848877, 34.47984382510185, 33.649892359972, 41.74009904265404, 58.195974826812744, 22.108150385320187, 3.1055201590061188, 0.2869190712226555, 0.37638571579009295, 0.06431318179238588, 0.18507855391362682, 0.18571706808870658, 0.207934015779756, 0.14637138170655817, 0.3606773290084675, 0.32886659377254546, 0.5761945503763855, 0.40399001736659557, 2.863160613924265, 52.90663205087185, 52.89437770843506, 45.96099995076656, 41.57316640019417, 48.149439319968224, 41.05546697974205, 46.62022277712822, 48.61575409770012, 51.713313683867455, 63.819042295217514, 74.80811342597008, 74.1904565691948, 77.13352784514427, 76.35610476136208, 82.91450724005699, 81.68047785758972, 79.70249399542809, 82.37636491656303, 76.8147325515747, 71.30353108048439, 82.99686402082443, 80.30241340398788, 82.0130056142807, 77.54620090126991, 75.25946080684662, 74.04371604323387, 76.2510783970356, 74.41806435585022, 71.97633817791939, 71.95121392607689, 69.64940384030342, 68.9795833826065, 72.8423573076725, 69.77753296494484, 68.62472802400589, 70.75401216745377, 70.37631243467331, 66.95340290665627, 67.05437108874321, 68.45094054937363, 71.89636006951332, 69.24085736274719, 67.41131633520126, 67.06529170274734, 56.53111696243286, 52.1104683727026, 56.475924924016, 56.81882992386818, 62.699800953269005, 64.71939638257027, 57.954026609659195, 60.80372929573059, 62.38613538444042, 61.64931692183018, 64.35219928622246, 62.309364303946495, 64.42831680178642, 60.766970068216324, 58.5123610496521, 59.22587536275387, 64.21429708600044, 60.93807868659496, 64.2623645067215, 66.18978828191757, 66.42900824546814, 61.593919694423676, 62.45778053998947, 63.07432785630226, 62.65319645404816, 64.86030042171478, 64.2542253434658, 66.76386907696724, 65.74952110648155, 65.14685064554214, 65.9072658419609, 68.13225165009499, 68.32557007670403, 67.58532419800758, 68.4507429599762, 65.70071652531624, 61.46772466599941, 61.22720517218113, 65.41032090783119, 66.1929801106453, 63.34792457520962, 61.83763861656189, 60.49969241023064, 66.0146252810955, 64.3686144053936, 69.44638833403587, 70.33945441246033, 71.78517803549767, 66.82018965482712, 61.02953217923641, 66.666419506073, 68.73502850532532, 73.09191271662712, 71.54050916433334, 70.32764464616776, 66.51809066534042, 59.231240674853325, 60.20207718014717, 61.347491517663, 69.43099156022072, 59.01579223573208, 57.444986924529076, 61.70577049255371, 42.38321453332901, 21.222229823470116, 27.337262593209743, 2.1842643432319164, 0.1934436269220896, 0.06552404025569558, 0.0752775973523967, 0.10811756525072269, 0.23406215594150126, 0.1021303037123289, 0.0998332527524326, 0.18031445564702153, 0.16211763286264613, 1.0423605423420668, 0.8234529825858772, 23.28922390937805, 45.46722024679184, 22.119654268026352, 35.150906816124916, 34.29676964879036, 46.16746187210083, 0.5855151533614844, 0.050113451361539774, 0.0963847670936957, 0.05113784151035361, 0.05830616799357813, 0.07643588207429275, 0.033464307052781805, 0.021131469511601608, 0.057173505920218304, 0.21448976243846118, 0.08215824142098427, 0.019656399053928908, 0.07378807727945969, 0.07072255466482602, 0.033122937675216235, 0.060899339587194845, 0.014203673090378288, 0.06573356338776648, 0.055421985452994704, 0.004513539006438805, 0.054617374917143025, 0.02638311983901076, 0.010333014870411716, 0.026772315068228636, 0.053304192842915654, 0.131180509342812, 0.19961946818511933, 0.34032354305963963, 21.602095440030098, 73.09328064322472, 54.79058235883713, 49.46273244917393, 29.738866724073887, 73.77137705683708, 25.92412032186985, 3.650867845863104, 0.16731060342863202, 0.7109380513429642, 0.36156713438685983, 0.06275470877881162, 0.13066205981886014, 0.22020122705725953, 0.14248294348362833, 0.3555605770088732, 0.278288695262745, 0.5857123271562159, 0.6246559030842036, 4.927983116358519, 64.729975014925, 57.88433834910393, 64.32452157139778, 58.896053060889244, 65.40598154067993, 51.955425292253494, 58.000642508268356, 56.08871050179005, 61.982589438557625, 69.80916246771812, 76.85727506875992, 79.28583115339279, 85.53681492805481, 80.64099803566933, 85.59335589408875, 86.1226598918438, 84.82920169830322, 86.25091820955276, 80.86368888616562, 76.41548797488213, 84.51199471950531, 82.06296533346176, 84.92899954319, 78.67781057953835, 80.17914801836014, 78.77066999673843, 81.47090390324593, 79.63723629713058, 76.69782042503357, 72.75516718626022, 75.9214536845684, 73.24310660362244, 75.8117687702179, 72.72391766309738, 71.48557931184769, 73.00355985760689, 72.2865991294384, 70.37599325180054, 71.3508765399456, 70.50333961844444, 72.43128776550293, 71.75034910440445, 71.66555285453796, 70.16299948096275, 62.33171470463276, 57.55972936749458, 59.90978166460991, 62.42969624698162, 67.72720098495483, 64.4319874048233, 60.36893002688885, 66.98700070381165, 63.188861310482025, 66.1741255223751, 68.64901632070541, 64.06931206583977, 67.49048128724098, 63.36304396390915, 58.740535005927086, 58.594763427972794, 64.75307017564774, 62.91551157832146, 64.4507583975792, 67.52898842096329, 67.86887258291245, 63.654815107584, 62.90786258876324, 66.09258949756622, 62.731221467256546, 65.8360044658184, 66.77697837352753, 68.36082458496094, 66.85103639960289, 69.36549067497253, 68.30914735794067, 69.63691011071205, 69.53676268458366, 69.79106023907661, 69.88306850194931, 69.52720239758492, 66.20204642415047, 64.52215656638145, 67.75167927145958, 70.7899734377861, 63.98552656173706, 65.67679300904274, 64.42316427826881, 66.93444192409515, 66.1055240035057, 68.84175717830658, 72.30684444308281, 74.2314563691616, 70.14720752835274, 68.45303043723106, 68.83555591106415, 70.34605085849762, 73.63320887088776, 74.01765704154968, 72.64723777770996, 69.85632553696632, 66.0234560072422, 65.41289716959, 59.071048870682716, 70.27127087116241, 69.61113229393959, 65.093904286623, 64.31869268417358, 67.8756134212017, 33.001320362091064, 32.20938205718994, 4.5536975003778934, 0.06142722922959365, 0.04516323358984664, 0.0580890601122519, 0.008631213659100467, 0.19301356718642637, 0.07331601940677501, 0.1364151737652719, 0.20761413528816774, 0.15498329303227365, 1.053361902013421, 0.9069643076509237, 25.61050985008478, 54.31574463844299, 20.53163208067417, 35.961939096450806, 41.569005623459816, 58.33604671061039, 1.1809619050472975, 0.037137578110559843, 0.027491376386024058, 0.12450746624381281, 0.024300273107655812, 0.02452218825055752, 0.03758561266295146, 0.025999561221397016, 0.035378758620936424, 0.05603556717687752, 0.04265369461791124, 0.08563487674109638, 0.027363370754756033, 0.08380493352888152, 0.14621858834289014, 0.16641987778712064, 0.18308429920580238, 0.13538198545575142, 0.13292094954522327, 0.28900379373226315, 0.43819103215355426, 0.29834081302396953, 0.17985511076403782, 0.21395802847109735, 0.20960801892215386, 0.30232320714276284, 0.235576790291816, 0.44405426597222686, 24.342269003391266, 89.35779109597206, 47.96092003583908, 47.20705948770046, 62.79149763286114, 84.95915472507477, 32.14414335787296, 3.6394648952409625, 0.41177829320076853, 0.9715432673692703, 0.6223339308053255, 0.4140592395560816, 0.34303983324207366, 0.37214499490801245, 0.31127701106015593, 0.4884217242943123, 0.7614582404494286, 0.7345124613493681, 1.8106338358484209, 4.8929504211992025, 78.04898232221603, 68.54711338877678, 72.5242155790329, 68.80075737833977, 78.61008301377296, 63.45648095011711, 74.98348161578178, 68.96078199148178, 71.01087838411331, 78.49694788455963, 85.08173614740372, 86.00579336285591, 89.6254563331604, 82.77135372161865, 91.75438329577446, 89.54237759113312, 88.95584866404533, 88.49034324288368, 86.21643885970116, 82.22359031438828, 92.57618799805641, 89.5823286473751, 91.69522047042847, 85.8132652938366, 83.88689786195755, 82.34617173671722, 84.43976059556007, 82.38848626613617, 80.82489296793938, 75.95799252390862, 78.03762093186378, 75.7277324795723, 80.70398345589638, 76.54392868280411, 75.2976943552494, 75.83074495196342, 74.56832349300385, 73.06330785155296, 73.64218398928642, 72.82233998179436, 75.567806661129, 76.91686347126961, 74.4433405995369, 73.067457228899, 65.24606332182884, 60.001919120550156, 62.47508481144905, 62.82300554215908, 69.74442154169083, 69.73524883389473, 64.5984336733818, 69.5824970304966, 67.02388912439346, 69.05124753713608, 70.8434745669365, 66.76054805517197, 69.34620290994644, 68.1392128765583, 63.8802570104599, 65.24476379156113, 69.65991407632828, 67.1292194724083, 71.29502713680267, 73.028015345335, 73.63909855484962, 68.67951348423958, 68.85287538170815, 70.42282193899155, 67.71264016628265, 69.45551544427872, 69.33127731084824, 72.660993039608, 71.51138752698898, 71.15327194333076, 71.6297435760498, 73.93552824854851, 74.06024515628815, 72.46941491961479, 72.71907672286034, 70.36985278129578, 71.4272828400135, 64.22570407390594, 70.05500167608261, 73.25535714626312, 65.80328062176704, 70.12023657560349, 65.86910828948021, 70.52935302257538, 68.5912898182869, 73.89680072665215, 76.97526633739471, 76.70852065086365, 73.3364599943161, 69.78516295552254, 72.55797296762466, 74.18727234005928, 78.33344265818596, 77.96886742115021, 77.42245674133301, 73.56998786330223, 70.32121539115906, 63.938469886779785, 60.32100699841976, 69.06727507710457, 67.087292522192, 65.74635207653046, 64.67280328273773, 74.37699615955353, 49.68190848827362, 51.000810116529465, 3.324106754735112, 0.34771622449625283, 0.11776598970755003, 0.12874783831648529, 0.2605233126087114, 0.5866391805466264, 0.13763412163825706, 0.37327323749195784, 0.3875437279930338, 0.28050982451532036, 1.1644338606856763, 1.302869813516736, 35.04672400653362, 60.16726724803448, 35.64103111624718, 46.84259444475174, 44.5414949208498, 70.31535610556602, 1.6071692411787808, 0.09826493143918924, 0.15592834388371557, 0.2548088051844388, 0.21704846498323604, 0.14983258035499603, 0.16065258882008493, 0.1428580842912197, 0.19055466866120696, 0.2045577485114336, 0.32310381706338376, 0.226329407596495, 0.09867015149211511, 0.16407004528446123], [0.09567186003550887, 0.020967675663996488, 0.017428020873921923, 0.0873629972920753, 0.04698543249105569, 0.11780672619352117, 0.13246745278593153, 0.22337871749186888, 0.0967925030272454, 0.15939662262098864, 0.17753491963958368, 0.06017692561727017, 0.028507794013421517, 0.0633765097882133, 32.3530637472868, 56.992226019501686, 29.06749214977026, 44.149853736162186, 27.905852682888508, 55.228387266397476, 1.7041539307683706, 3.56829518917948, 0.4089185904012993, 0.07231849871459417, 0.14636979351053014, 0.059886489834752865, 0.2544583333656192, 0.7257861702237278, 0.817988341441378, 0.29370853502769023, 0.4399978055153042, 0.6170063198078424, 0.5746999836992472, 22.54601988941431, 48.01278345286846, 41.64553351700306, 44.27455544471741, 37.187669724226, 40.11466786265373, 40.24775192141533, 43.02652761340141, 43.571019396185875, 50.69967247545719, 53.99526983499527, 64.14159178733826, 66.91745683550835, 73.42216819524765, 76.57103642821312, 81.99547335505486, 82.36627265810966, 79.52078774571419, 81.82659521698952, 76.19543418288231, 74.56310257315636, 73.81141930818558, 74.46111604571342, 74.1141414642334, 75.86652383208275, 77.1336342394352, 75.6921435892582, 74.42067101597786, 66.96990922093391, 69.66510459780693, 70.96289455890656, 70.13892397284508, 72.05399081110954, 69.15653988718987, 67.6096048951149, 69.3755829334259, 69.41212937235832, 67.7352337539196, 68.6750677227974, 70.63437938690186, 71.3166631758213, 73.55251640081406, 70.57219192385674, 70.00681266188622, 57.43926823139191, 53.87630581855774, 55.83280183374882, 60.472816452383995, 64.72797632217407, 63.14387932419777, 52.856402546167374, 64.4555613398552, 62.567108273506165, 60.13451300561428, 64.03230205178261, 64.65515702962875, 63.88782620429993, 65.2800714969635, 65.26838332414627, 59.23844888806343, 56.91893935203552, 55.58432176709175, 55.44109985232353, 55.32544545829296, 61.031078696250916, 63.31773139536381, 62.41349771618843, 62.47337110340595, 61.59044288098812, 59.4279333204031, 60.00283107161522, 60.87321616709232, 61.785900592803955, 64.08603116869926, 62.714437767863274, 61.91299997270107, 63.92827123403549, 64.62608858942986, 68.24548557400703, 65.85166722536087, 70.3825668990612, 65.03449827432632, 60.60362063348293, 64.81961220502853, 66.65968626737595, 63.05551126599312, 57.352735474705696, 64.9477869272232, 66.74319058656693, 72.3543418943882, 66.81680023670197, 65.87597072124481, 71.7585338652134, 69.824658036232, 64.40927222371101, 63.996644765138626, 66.26057848334312, 67.69715219736099, 71.52772665023804, 66.65722399950027, 70.0277191400528, 58.385744243860245, 56.506406888365746, 60.49088828265667, 64.51254308223724, 68.55706125497818, 54.064680710434914, 58.734633922576904, 55.09068265557289, 31.69011142104864, 24.04039040207863, 20.547728016972542, 0.4153322899946943, 0.2075238901306875, 0.1508722550352104, 0.14170524693327025, 0.17100660275900736, 0.015252696048264625, 0.05914011562708765, 0.07399059453746304, 0.15382812533061951, 0.1776637861621566, 0.11292872310150415, 5.789165580645204, 61.312438398599625, 29.274259954690933, 57.96162620186806, 33.35776403546333, 48.50076086819172, 3.140900772996247, 0.08091601979685947, 0.060158075066283345, 0.04183379955065902, 0.06469124666182324, 0.05042763958044816, 0.12466454179957509, 0.003024803522748698, 0.02624817698233528, 0.034155480316258036, 0.048731898932601325, 0.073755430203164, 0.03717871535627637, 0.010973787029797677, 0.05789541894046124, 0.05208025402680505, 0.05455156497191638, 0.058718119325931184, 0.06560201029060408, 0.1000353173003532, 0.05664602074830327, 0.12849622056819499, 0.009465264265600126, 0.02866605886083562, 0.08161107078194618, 0.05597704883257393, 0.058826439490076154, 0.05806760091218166, 39.36160907149315, 70.11577561497688, 44.4698041677475, 34.43705052137375, 27.011414878070354, 72.96575948596, 1.631690631620586, 4.340394996106625, 0.620264585595578, 0.04447949664609041, 0.12876643653726205, 0.10040745240985416, 0.44801772048231214, 0.9980555134825408, 2.200826467014849, 0.23981978214578703, 0.8246956346556544, 0.6623416277579963, 0.7362893410027027, 30.96484813839197, 62.41414748132229, 54.821125119924545, 63.418015614151955, 54.09525766968727, 57.12159767746925, 52.657331228256226, 50.600349605083466, 52.61626683175564, 59.00908179581165, 59.48332294821739, 67.18598082661629, 69.1784419119358, 75.04835173487663, 79.68747720122337, 84.51527014374733, 81.90537258982658, 82.98897564411163, 83.64070147275925, 75.98309397697449, 81.27016827464104, 80.21702438592911, 79.55392956733704, 81.48041859269142, 81.88417732715607, 80.50986707210541, 80.33888384699821, 76.71101331710815, 74.74895060062408, 75.30929133296013, 75.47372370958328, 73.89722630381584, 74.93550539016724, 70.75864031910896, 72.17381358146667, 71.52667790651321, 70.1615783572197, 71.27538979053497, 72.10912585258484, 74.00226026773453, 75.59299170970917, 75.51583305001259, 72.47680932283401, 70.29529318213463, 60.65612621605396, 59.53796021640301, 64.09332677721977, 66.66348606348038, 67.89588913321495, 66.74844950437546, 54.20423202216625, 66.13445565104485, 67.26568534970284, 65.66958099603653, 67.19405919313431, 70.67050784826279, 67.00843155384064, 67.40439310669899, 69.13122564554214, 62.47931398451328, 57.62648418545723, 57.032648250460625, 55.88710471987724, 54.94120627641678, 59.405890703201294, 62.34703168272972, 64.72289979457855, 64.55316290259361, 63.101393803954124, 62.8141064196825, 64.30221676826477, 63.49542126059532, 62.24369242787361, 64.37711834907532, 66.8284960091114, 63.898784816265106, 65.99415197968483, 67.07126498222351, 69.2254301905632, 69.9008971452713, 70.00789940357208, 70.34367218613625, 67.44322702288628, 66.84545829892159, 69.93989065289497, 64.7485788166523, 60.658417493104935, 67.86239013075829, 67.03059956431389, 73.11657339334488, 66.17990121245384, 64.15778651833534, 73.71041312813759, 72.23674580454826, 67.31104731559753, 68.86894091963768, 68.01543071866035, 68.08853879570961, 73.3397126197815, 71.55108779668808, 71.98301061987877, 65.61534270644188, 62.70967662334442, 64.71103683114052, 60.90315096080303, 72.59092479944229, 67.03784197568893, 60.115479826927185, 67.45595633983612, 59.79390308260918, 31.134999208152294, 28.6493131890893, 1.2338278745301068, 0.6684886885341257, 0.10959532228298485, 0.12911239609820768, 0.10380429943324998, 0.13853246171493083, 0.058100147798541, 0.09151361402473412, 0.13481529633281752, 0.06362389729474671, 0.021668533954652958, 6.0392192378640175, 67.24255979061127, 30.898344106972218, 52.68296465277672, 40.370648726820946, 58.64179350435734, 5.08865131996572, 0.2480971926706843, 0.17291868687607348, 0.03429147516726516, 0.10368594914325513, 0.01901173989608651, 0.03773856187763158, 0.08811960942693986, 0.05234782423940487, 0.06759363037417643, 0.020168145128991455, 0.0416362992109498, 0.0283634091829299, 0.057476031288388185, 0.16216208750847727, 0.1821732535609044, 0.10271444072714075, 0.1652180586825125, 0.2528793696546927, 0.15331766131566837, 0.39972634927835315, 0.3910618938971311, 0.18709091702476144, 0.2950993791455403, 0.22380959358997643, 0.2069412003038451, 0.0999462595791556, 0.13207645970396698, 45.91598376631737, 81.57707020640373, 36.65983624756336, 66.83442369103432, 44.518749341368675, 80.48741027712822, 3.6898069689050317, 5.788346249610186, 0.7127599942032248, 0.34590600756928325, 0.2879017044324428, 0.24724439077544957, 0.6822625931818038, 1.5578588121570647, 3.4766913671046495, 0.5009949230588973, 1.5211365139111876, 2.08665375597775, 1.5677249827422202, 36.45300954580307, 84.51178193092346, 66.73251315951347, 71.53739333152771, 65.5048294365406, 72.93217688798904, 61.71931676566601, 69.70105826854706, 69.07115086913109, 71.76725819706917, 67.54968211054802, 74.2949053645134, 75.3182664513588, 82.5191992521286, 83.63661289215088, 87.62710556387901, 86.43751099705696, 85.41417270898819, 86.45028591156006, 81.33682429790497, 85.0966389477253, 86.03163957595825, 83.72313424944878, 81.48775979876518, 82.63714492321014, 85.07447093725204, 85.17509713768959, 81.16519510746002, 75.86274683475494, 75.76411932706833, 78.50991278886795, 75.38214102387428, 77.52544641494751, 74.97348055243492, 75.13323917984962, 75.71963891386986, 76.16898000240326, 73.83000791072845, 75.26152789592743, 76.58777832984924, 77.10930794477463, 78.63787472248077, 74.35404539108276, 75.94430565834045, 64.06770095229149, 60.13706646859646, 63.49504508078098, 69.10369992256165, 70.34353539347649, 71.14691108465195, 56.4518266171217, 70.23393407464027, 71.22291460633278, 67.29628130793571, 69.52668562531471, 73.74862387776375, 69.16627496480942, 70.7692189514637, 72.38523423671722, 64.79644864797592, 62.006463557481766, 62.458563297986984, 62.15293049812317, 61.536250188946724, 66.90480351448059, 68.57329398393631, 70.17411768436432, 67.24428489804268, 68.08571174740791, 67.2761119902134, 65.5630499124527, 68.43926757574081, 66.04797229170799, 68.75680893659592, 70.17331972718239, 66.80258139967918, 72.74131312966347, 71.93108260631561, 72.80100792646408, 72.00840085744858, 76.159837692976, 72.50238955020905, 67.7297392487526, 69.23077270388603, 73.99922803044319, 67.33598917722702, 64.87420007586479, 71.21096044778824, 70.146743953228, 75.77852815389633, 68.11155036091805, 70.92710047960281, 77.9520571231842, 75.48473551869392, 70.68245440721512, 71.49988934397697, 70.75705960392952, 71.67812258005142, 76.91653668880463, 74.0965636074543, 75.91478884220123, 69.61046352982521, 64.67188373208046, 61.70195169746876, 63.03562693297863, 71.60005956888199, 67.00395539402962, 62.71200969815254, 66.32805526256561, 72.85368829965591, 51.08143799006939, 41.88298277556896, 1.2623771675862372, 0.9868339437525719, 0.2966697042575106, 0.15236955281579867, 0.2341846696799621, 0.30128559563308954, 0.27564697607886046, 0.24813416646793485, 0.27564439340494573, 0.23252550949109718, 0.33205821469891816, 8.441461734473705, 75.41854307055473, 42.97535955905914, 79.20175686478615, 42.81031161546707, 70.86662292480469, 5.258919233456254, 0.56380003108643, 0.2678935514995828, 0.13740697992034256, 0.195838522631675, 0.13795545673929155, 0.20788476685993373, 0.099708252819255, 0.21127161715412512, 0.17005469446303323, 0.1659701214521192, 0.14535823138430715, 0.1485088115441613, 0.11108277176390402], [0.0689283013343811, 0.02311005006049527, 0.07645709265489131, 0.049854801764013246, 0.04033870965940878, 0.09278364392230287, 0.09588093045749702, 0.1785669947275892, 0.11462920607300475, 0.19591296004364267, 0.12748639506753534, 0.05537580531381536, 0.13529971096431836, 0.9551175206433982, 54.469104409217834, 46.84567607939243, 42.69038625061512, 38.12694892287254, 34.96615692973137, 42.03360289335251, 0.6614180991891772, 5.429264567792416, 1.2406379403546453, 0.16577553033130243, 0.10065690308692865, 0.12505128979682922, 0.41017697600182146, 0.9452421474270523, 1.851794058457017, 0.4174187046010047, 2.0478352764621377, 0.16730399831430987, 6.185113359242678, 35.86823992431164, 40.9913682192564, 40.988396778702736, 34.27731089293957, 35.73485568165779, 35.950524508953094, 47.62220241129398, 38.61773818731308, 43.30003313720226, 48.11762362718582, 50.11515364050865, 57.96627715229988, 61.84820964932442, 65.59672370553017, 68.99864315986633, 69.89930883049965, 77.90288016200066, 81.81673094630241, 71.54346540570259, 66.35663732886314, 76.5594394505024, 76.59544631838799, 76.07071727514267, 80.95140337944031, 80.47686964273453, 72.90742501616478, 73.21550488471985, 70.67131340503693, 72.00324073433876, 71.6672171652317, 69.7863256931305, 69.2301419377327, 66.36416092514992, 66.25213533639908, 69.33709099888802, 65.24246871471405, 68.4494586288929, 69.02706563472748, 73.03196713328362, 72.70079210400581, 73.1036464869976, 70.76020583510399, 70.83883881568909, 58.64343881607056, 60.26391886174679, 62.33041897416115, 66.38685330748558, 59.208688884973526, 61.61090858280659, 51.99475318193436, 57.007326409220695, 63.01589459180832, 63.958510011434555, 62.56033703684807, 61.51508152484894, 68.87394145131111, 62.521685510873795, 62.69109942018986, 64.09157127141953, 64.56943362951279, 61.30901478230953, 59.27714981138706, 54.84137803316116, 51.793732568621635, 51.88155345618725, 55.93494035303593, 57.86509618163109, 58.69731232523918, 60.71776270866394, 60.29542677104473, 57.34835051000118, 59.87081095576286, 59.813890010118484, 60.80960378050804, 63.64180460572243, 59.67760272324085, 60.13762503862381, 62.293260768055916, 63.71762953698635, 66.46123811602592, 67.74205818772316, 65.56029126048088, 62.91851721704006, 60.991906598210335, 65.9381277859211, 63.83769169449806, 60.33078767359257, 62.11389519274235, 62.591453567147255, 71.15401670336723, 70.05599722266197, 60.63537172973156, 66.66485399007797, 74.09765034914017, 68.15723150968552, 65.61010658740997, 66.54524400830269, 68.42902332544327, 69.32877704501152, 68.80629748106003, 61.36882357299328, 64.96228694915771, 58.95545147359371, 62.98611558973789, 62.769895792007446, 68.77898454666138, 62.44501322507858, 49.69101279973984, 55.888898223638535, 46.95195257663727, 23.890967220067978, 25.282025076448917, 6.491470020264387, 0.20428723568329588, 0.19700636621564627, 0.09474993450567126, 0.9468426927924156, 0.4272907826816663, 0.06600143417017534, 0.016296533249260392, 0.07723490794887766, 0.07350707048317418, 0.047127416473813355, 0.5161450069863349, 50.14172941446304, 35.109040662646294, 30.03692463040352, 35.42780555784702, 43.11614580452442, 7.370913354679942, 0.27251686435192823, 0.11688517915899865, 0.15432956482982263, 0.12480880046496168, 0.03729079078766517, 0.012742488215735648, 0.039272432695725, 0.017961866251425818, 0.05160948006960098, 0.11421810821047984, 0.14290641294792295, 0.04786563076777384, 0.0909108342602849, 0.04002114095783327, 0.04732405592221767, 0.059991010202793404, 0.04634530414477922, 0.0269320493680425, 0.06900123218656518, 0.04211150750052184, 0.03011500943102874, 0.038959424491622485, 0.07703058727202006, 0.010338262782170204, 0.17824445734731853, 0.05950263250269927, 1.5114161605015397, 62.32776291668415, 55.11977769434452, 54.41583126783371, 30.911309011280537, 46.47636629641056, 53.64488683640957, 0.5636167502962053, 8.082051370292902, 1.060259125661105, 0.04822008420887869, 0.11251021118368953, 0.20518689678283408, 0.6874830380547792, 0.8623496547807008, 2.499365760013461, 0.3526878420962021, 2.8461807500571012, 0.008420973426837008, 9.657223597168922, 53.94608527421951, 53.04940178990364, 58.21803264319897, 53.7601650506258, 56.0945887863636, 53.16409483551979, 58.83555270731449, 45.74254587292671, 54.43381570279598, 58.09852905571461, 60.73911376297474, 65.32922565937042, 69.89534184336662, 73.01418408751488, 73.49695578217506, 71.86542972922325, 80.34424915909767, 83.48489463329315, 74.50888708233833, 72.28744268417358, 82.16335594654083, 80.31381279230118, 82.20799595117569, 84.49282854795456, 82.31180638074875, 78.22663798928261, 75.47824546694756, 75.05942434072495, 77.96686112880707, 76.36107489466667, 74.6554984152317, 70.21762534976006, 70.62657460570335, 71.76346600055695, 72.58906289935112, 69.99450132250786, 70.32674789428711, 71.44606903195381, 78.44912365078926, 77.4132764339447, 74.359220713377, 73.36280018091202, 66.45182982087135, 62.894852086901665, 64.32202890515327, 64.61896777153015, 68.69408950209618, 65.59264272451401, 64.69223544001579, 56.405210718512535, 61.566272377967834, 63.8627627491951, 65.99435716867447, 68.88405650854111, 65.37698909640312, 71.907227486372, 69.384246468544, 68.23134273290634, 65.1360896229744, 67.44391858577728, 62.30961889028549, 60.36949999630451, 55.68510755896568, 56.47487238049507, 51.83875635266304, 55.013645589351654, 58.19632060825825, 61.98577746748924, 62.66484662890434, 63.569650277495384, 62.48375974595547, 64.62633937597275, 62.25103743374348, 63.04711751639843, 64.8272953927517, 64.41358119249344, 63.96348774433136, 63.883692026138306, 65.21092280745506, 69.25476461648941, 69.87802237272263, 70.32448321580887, 67.72602304816246, 66.65241345763206, 67.02205002307892, 67.32992470264435, 63.477889001369476, 64.24958199262619, 63.444891571998596, 70.66439017653465, 69.95884403586388, 60.38833558559418, 65.13344496488571, 75.19183963537216, 68.92853692173958, 69.60059925913811, 69.6160264313221, 69.36359077692032, 71.29691943526268, 74.40391391515732, 65.87487637996674, 67.08332553505898, 61.198011338710785, 65.92410653829575, 65.87558314204216, 67.3851129412651, 70.61921820044518, 59.49405737221241, 58.61058197915554, 67.9923203587532, 42.970739006996155, 32.42358036339283, 13.12722209841013, 0.23061412299284711, 0.5883797840215266, 0.13797617750242352, 1.0801991494372487, 0.609207950765267, 0.09755677412613295, 0.03458605584455654, 0.07161922490922734, 0.14508124702842906, 0.2253093256149441, 0.4782767139840871, 58.05328108370304, 38.38131487369537, 27.865506447851658, 42.660660445690155, 53.940632566809654, 10.143638346344233, 0.29239692259579897, 0.13068698113784194, 0.038229670681175776, 0.2542095654644072, 0.14196179254213348, 0.03917665482731536, 0.05609095736872405, 0.04090232258022297, 0.04123657105083112, 0.06969793816097081, 0.08265336524345912, 0.08877526721335016, 0.07132412472856231, 0.09019941149745136, 0.15450106031494215, 0.19178225513314828, 0.1200442123808898, 0.11218296116567217, 0.2586108277318999, 0.244521094718948, 0.3557410673238337, 0.20022099371999502, 0.30154982989188284, 0.23491762956837192, 0.38223867828492075, 0.31518017349299043, 1.9955662311986089, 73.48351210355759, 63.007006868720055, 57.42287591099739, 57.18858428299427, 56.48577019572258, 66.10154941678047, 1.1742925504222512, 11.420042105019093, 1.2295475229620934, 0.33973392157349735, 0.43001784884836525, 0.32128597085829824, 0.8763375354465097, 2.2185589279979467, 4.27550682798028, 0.7645242603030056, 5.089881978929043, 0.4443493142025545, 10.469733998179436, 75.43834000825882, 67.24022671580315, 71.50778532028198, 67.0126873254776, 71.47208243608475, 63.93481448292732, 75.79875826835632, 67.96661093831062, 67.55783647298813, 68.38865429162979, 70.29049023985863, 74.71235856413841, 79.30420696735382, 83.31559091806412, 81.53084188699722, 80.4793319106102, 88.27638432383537, 93.02170649170876, 82.08520174026489, 75.19383072853088, 86.53683766722679, 84.02833387255669, 84.60331901907921, 86.1091098189354, 83.50632548332214, 80.6581275165081, 80.21518528461456, 79.73538503050804, 80.50519332289696, 80.43702498078346, 76.43998146057129, 72.84573912620544, 73.87130409479141, 73.80146384239197, 74.86019343137741, 72.75839701294899, 73.57237413525581, 75.45931488275528, 81.03996142745018, 78.64886373281479, 76.94543793797493, 78.87387245893478, 76.30375877022743, 65.44765010476112, 67.35402300953865, 68.24825942516327, 72.01278582215309, 67.37674579024315, 66.94651007652283, 58.175136744976044, 61.47506587207317, 65.14504954218864, 68.15434366464615, 72.10311457514763, 66.16341009736061, 74.57001820206642, 70.16191273927689, 69.573415517807, 70.99238857626915, 69.86658498644829, 65.3229483962059, 64.1453155875206, 61.66538245975971, 60.68397872149944, 57.55656033754349, 62.729636952281, 62.79543802142143, 66.18383020162582, 67.56103590130806, 66.04944661259651, 63.917829394340515, 71.03480190038681, 65.26587545871735, 69.59421560168266, 68.62020626664162, 67.28064894676208, 64.89965870976448, 70.03743141889572, 69.16975557804108, 73.5222016274929, 74.84302595257759, 75.02828121185303, 68.6293637752533, 67.27174982428551, 68.68886098265648, 71.45923912525177, 64.88210365176201, 66.05815574526787, 66.65777876973152, 75.99791318178177, 72.53818362951279, 62.45761714875698, 70.33064648509026, 80.55403590202332, 72.43616670370102, 74.2864242196083, 72.6993177831173, 71.9150322675705, 75.1572234928608, 76.78440257906914, 68.3639708161354, 71.92954748868942, 67.99082323908806, 67.46609419584274, 64.53727215528488, 69.03546318411827, 69.60057646036148, 60.28035297989845, 58.57976943254471, 70.77644616365433, 59.92797128856182, 50.880766957998276, 15.29074715450406, 0.38310197414830327, 0.8708192221820354, 0.2067513737711124, 1.3897783937864006, 0.4197592899436131, 0.1020357986271847, 0.1466851617442444, 0.16207513748668134, 0.1809685697662644, 0.4599461710313335, 1.3783704559318721, 65.52749902009964, 44.30241174995899, 40.15544727444649, 46.820422634482384, 63.47623988986015, 12.387177608907223, 0.7218206080142409, 0.26236003905069083, 0.3421950020128861, 0.3740982088493183, 0.29733241244684905, 0.16125755792018026, 0.21591897559119388, 0.11080321215558797, 0.17618027748540044, 0.19669111672556028, 0.2660883218050003, 0.1665258119464852, 0.17641037295106798], [0.08188420339138247, 0.06962200161069632, 0.03311021726403851, 0.015965785860316828, 0.020313014210842084, 0.021954103103780653, 0.07883098558522761, 0.21958022756734863, 0.21457893890328705, 0.14161546190734953, 0.14001332834595814, 0.1083368476247415, 0.07524577406002209, 3.9203054504469037, 64.29036900401115, 35.854807645082474, 44.67478036880493, 30.219185650348663, 55.368744134902954, 9.800155777484179, 1.715673606377095, 1.8059780169278383, 0.9508181107230484, 0.16188354464247823, 0.057400450968998484, 0.17527592601254582, 0.9366630984004587, 0.11449784593423828, 0.41883991740178317, 0.7046394143253565, 0.6014062569011003, 0.274278485449031, 16.675906777381897, 43.40248703956604, 36.629920452833176, 38.25507804751396, 36.06467418372631, 33.82973670959473, 38.78870241343975, 38.95019754767418, 37.78717115521431, 43.44220630824566, 48.88890244066715, 49.36403274536133, 55.671405494213104, 63.22111397981644, 65.1468962430954, 64.88616183400154, 66.4727135002613, 70.12329921126366, 67.55494862794876, 59.65826936066151, 79.21815678477287, 80.144212692976, 81.39974132180214, 79.96941447257996, 77.59344756603241, 76.53563752770424, 76.25252231955528, 71.54734119772911, 70.8119286596775, 72.55939409136772, 68.85896265506744, 70.3508386015892, 68.12638476490974, 67.08711013197899, 67.72047534584999, 67.28605225682259, 67.17588096857071, 70.63487336039543, 73.0392475426197, 73.87867569923401, 72.03632935881615, 72.65957191586494, 63.883220851421356, 57.965008020401, 67.25739419460297, 69.34203073382378, 62.589489072561264, 62.870806977152824, 61.02232776582241, 52.34921336174011, 52.34321728348732, 57.70141236484051, 59.43893373012543, 65.02991572022438, 64.50117409229279, 60.875549241900444, 66.1835490167141, 65.0907352566719, 63.78568008542061, 63.12955029308796, 60.87869167327881, 60.4888553917408, 60.20559959113598, 56.349205523729324, 56.52258642017841, 55.17105594277382, 53.83268415927887, 53.493616953492165, 56.99625380337238, 58.54900248348713, 59.89268638193607, 60.54791942238808, 60.34977525472641, 58.643507212400436, 59.87835355103016, 61.46187677979469, 60.49500726163387, 58.00214722752571, 60.30255898833275, 60.35941533744335, 60.899620950222015, 64.26719784736633, 62.706173211336136, 67.09796994924545, 62.53542557358742, 60.366767942905426, 63.98180276155472, 62.87624828517437, 61.57210126519203, 60.12039676308632, 65.81297010183334, 70.15200287103653, 67.76761561632156, 60.63161373138428, 68.29000398516655, 72.44375109672546, 67.5070407986641, 62.76216320693493, 69.11145150661469, 69.47388365864754, 69.72760364413261, 67.94533967971802, 62.653967812657356, 53.41660648584366, 55.68501636385918, 65.78200176358223, 62.312879115343094, 64.00686621665955, 52.43522174656391, 46.824420019984245, 54.894263595342636, 36.25797361135483, 21.325451284646988, 25.630434080958366, 3.018791237846017, 0.011906223226105794, 0.2104900317499414, 0.33914388448465616, 0.973212921526283, 0.22261019388679415, 0.08196469672839157, 0.11158730601891875, 0.07284505249117501, 0.415736879222095, 0.20266547973733395, 30.68702034652233, 48.18388067185879, 29.773477166891098, 23.069787584245205, 49.410686641931534, 12.432588022202253, 0.5788585043046623, 0.24386202305322513, 0.06377099096425809, 0.211187056847848, 0.1226508873514831, 0.08320236156578176, 0.03458093502558768, 0.0923909735865891, 0.019513129300321452, 0.07634006338776089, 0.06935088022146374, 0.06391386181348935, 0.05576696537900716, 0.004889261936114053, 0.060527018940774724, 0.13486154697602615, 0.034618101781234145, 0.05584554026427213, 0.07391043516690843, 0.012044237646477995, 0.04793562642589677, 0.11990069586317986, 0.04424550490512047, 0.05926995065237861, 0.06526333861984313, 0.1096492244687397, 6.149163963273168, 71.35244205594063, 47.127681747078896, 53.838725835084915, 25.537418872117996, 68.83317723870277, 12.58812127634883, 3.1814203737303615, 4.215801106765866, 1.4033231232315302, 0.08730076078791171, 0.0519284848269308, 0.6646536849439144, 1.9512259354814887, 0.3384477202780545, 0.5478988343384117, 1.4121016021817923, 0.9015630162321031, 0.6024757807608694, 34.06511887907982, 59.16445925831795, 53.676603734493256, 60.248617082834244, 59.321675822138786, 52.98912562429905, 54.92988668382168, 47.8302488476038, 46.992355808615685, 54.01128597557545, 57.58374787867069, 60.21763354539871, 64.90815505385399, 70.10085761547089, 72.03061446547508, 73.16249772906303, 76.63342148065567, 76.42597541213036, 70.82775101065636, 67.25952968001366, 85.60598641633987, 83.02859991788864, 83.85983571410179, 83.00401523709297, 80.93482866883278, 80.34250125288963, 79.18294787406921, 74.58856120705605, 74.2655861377716, 76.80054411292076, 74.12095069885254, 73.8139271736145, 71.56802728772163, 71.3019047677517, 71.91301077604294, 72.88079604506493, 73.86728391051292, 74.60250645875931, 75.88499084115028, 75.10175406932831, 76.33642181754112, 73.2317528128624, 62.06142380833626, 60.16961172223091, 69.44125100970268, 70.7263496518135, 67.0364436507225, 65.98218262195587, 62.95743852853775, 54.15306776762009, 56.036622896790504, 61.2950087338686, 64.26315486431122, 68.36989089846611, 68.93711686134338, 68.82360935211182, 68.49982872605324, 67.76813238859177, 70.24670138955116, 67.04975813627243, 64.5562407374382, 62.43084378540516, 60.07621273398399, 55.47023668885231, 58.748723566532135, 57.801764979958534, 54.45571772754192, 56.02106653153896, 58.25910463929176, 61.355227902531624, 63.9778433740139, 65.36610648036003, 64.71188798546791, 62.70476348698139, 61.537013947963715, 61.098711267113686, 61.99605591595173, 61.08897238969803, 61.38086512684822, 63.03914554417133, 66.26963719725609, 69.07359033823013, 66.70600578188896, 68.26364859938622, 68.08130398392677, 64.44634303450584, 64.98438656330109, 64.44984644651413, 64.29191932082176, 61.875735372304916, 65.43239772319794, 68.81642773747444, 68.11471939086914, 60.36422587931156, 69.88054543733597, 71.82564586400986, 68.4851311147213, 67.48486518859863, 71.26722022891045, 71.48928791284561, 68.37043046951294, 74.11446064710617, 65.57547524571419, 58.6467370390892, 59.99323658645153, 70.31391978263855, 63.201047256588936, 65.22590920329094, 62.99348719418049, 53.47783260047436, 59.8876478523016, 64.7432591021061, 33.71373653411865, 35.90574011206627, 6.681053722277284, 0.0712291595118586, 0.22223054082132876, 0.15501088608289137, 0.8610546961426735, 0.2000653653522022, 0.18397750362055376, 0.12507564708357677, 0.10129414818948135, 0.369379396433942, 0.12615526415174827, 35.40092960000038, 50.2295009046793, 26.31129864603281, 33.17198060452938, 58.84914457798004, 16.37311242520809, 0.6574846571311355, 0.2167538768844679, 0.16317084431648254, 0.2942882414208725, 0.05463179484650027, 0.1360565234790556, 0.04052528187457938, 0.12820348783861846, 0.04657174453313928, 0.05405889394751284, 0.046209758293116465, 0.02487832822225755, 0.015198499786492903, 0.124113653000677, 0.29026989766862243, 0.22854969080071896, 0.2707997424295172, 0.2937373600434512, 0.14980613021180034, 0.15505648363614455, 0.36332661809865385, 0.3941012261202559, 0.22842385224066675, 0.28242233907803893, 0.3265157074201852, 0.37909974984358996, 6.863571228459477, 85.48150509595871, 48.90761263668537, 63.41338366270065, 46.729140132665634, 77.91544988751411, 19.99303948134184, 5.890061566606164, 9.736094065010548, 1.8577428767457604, 0.16478713805554435, 0.8830767113249749, 1.3163824821822345, 3.461657236330211, 0.883394469274208, 0.6692645594011992, 2.1113080205395818, 1.757401186041534, 0.6954477075487375, 48.30929294228554, 78.33424061536789, 66.09461098909378, 72.36781597137451, 69.31236192584038, 66.85950994491577, 64.67829778790474, 67.22583308815956, 63.156456649303436, 66.13175019621849, 67.37065851688385, 66.51657834649086, 68.14259469509125, 76.25505298376083, 77.73154735565186, 77.5781799852848, 82.67565205693245, 83.53797018527985, 78.84847462177277, 68.78982916474342, 89.02953431010246, 87.51500397920609, 89.14165869355202, 88.57535228133202, 82.4969856441021, 81.00049674510956, 82.44860664010048, 79.29885685443878, 76.5474396944046, 79.3349701166153, 75.3687809407711, 78.18639054894447, 75.59690549969673, 73.08488309383392, 73.83998617529869, 76.07716172933578, 74.01327967643738, 77.80774086713791, 77.75162547826767, 79.01607602834702, 79.11516711115837, 78.65900918841362, 70.04852682352066, 62.958643063902855, 71.46446004509926, 77.07732126116753, 70.38700506091118, 67.64326348900795, 66.09837278723717, 59.6097307652235, 57.2465767711401, 64.31397333741188, 66.24571368098259, 71.17575153708458, 71.01058959960938, 70.50077095627785, 72.06140801310539, 70.38971051573753, 71.53981760144234, 70.22200271487236, 65.25927901268005, 66.35760247707367, 67.84239560365677, 60.20392768085003, 64.11623954772949, 61.95927768945694, 59.263398349285126, 60.911404117941856, 61.61372423171997, 65.6917642056942, 65.91262355446815, 68.60190644860268, 68.71118858456612, 66.86707153916359, 64.32940810918808, 66.40870973467827, 66.87666222453117, 65.10034114122391, 65.74610128998756, 66.29941239953041, 68.17654207348824, 71.04478016495705, 69.9207092821598, 73.56384739279747, 68.69885444641113, 67.37449631094933, 68.17597970366478, 65.39350301027298, 66.53455898165703, 63.954368233680725, 68.05417343974113, 73.71586963534355, 70.43520927429199, 64.55241814255714, 72.17628344893456, 75.44207900762558, 71.7215770483017, 73.32964316010475, 75.71651548147202, 75.99507853388786, 73.53502213954926, 78.25183063745499, 69.42999601364136, 65.81580474972725, 63.126468658447266, 66.34497195482254, 64.88476350903511, 68.64349141716957, 65.08440479636192, 55.109362453222275, 61.71824522316456, 71.51559010148048, 52.7031871676445, 53.21454472839832, 6.725517511367798, 0.2132027002517134, 0.7764707005117089, 0.24723852780880406, 1.480865206103772, 0.29638935055118054, 0.34336139098741114, 0.2030159960850142, 0.15137351641897112, 0.38845458067953587, 0.41780076222494245, 41.98000676929951, 60.25857634842396, 47.11899921298027, 29.4921687617898, 68.66935282945633, 17.794205769896507, 0.9336967638228089, 0.35537809773813933, 0.2897028374718502, 0.37629125523380935, 0.17057983815902844, 0.2527738659409806, 0.14108687464613467, 0.2541258215205744, 0.1584137073950842, 0.0782921863719821, 0.26234053540974855, 0.12225989426951855, 0.11245049056014977], [0.022656245309917722, 0.062076727190287784, 0.0977273567696102, 0.04941115701512899, 0.038677464035572484, 0.0816723721800372, 0.10618645246722735, 0.06836134503828362, 0.09015256713610142, 0.1527254719985649, 0.02163983695936622, 0.10316194093320519, 0.16750415554270148, 19.1062031686306, 60.08293077349663, 36.825982332229614, 50.84000274538994, 37.31245882809162, 71.34783670306206, 3.009311221539974, 1.3768947101198137, 0.5394683929625899, 0.1763971775653772, 0.2934527612524107, 0.11191252997377887, 0.8840320631861687, 0.5656703026033938, 0.26044120138976723, 0.14000332419527695, 0.5397818167693913, 0.29677743441425264, 3.70414977427572, 42.61882469058037, 39.884905591607094, 42.865469455718994, 40.54201193153858, 43.15340280532837, 39.48002591729164, 41.79029814898968, 43.290096670389175, 46.83425009250641, 49.295093044638634, 53.77161003649235, 58.915090039372444, 63.41853238642216, 66.96189165115356, 65.03655776381493, 70.89509099721909, 76.49022996425629, 65.87237611413002, 62.464566975831985, 80.24953544139862, 80.62472730875015, 79.24091756343842, 76.76905140280724, 75.13619542121887, 76.20779871940613, 74.97325256466866, 72.80461013317108, 71.8533007800579, 72.59070441126823, 71.91042691469193, 69.55556407570839, 67.79819637537003, 64.60650444030762, 66.15498214960098, 69.3422283232212, 70.43732956051826, 70.90688556432724, 71.77582293748856, 72.61471912264824, 72.36982986330986, 71.10764399170876, 58.06041330099106, 59.70401130616665, 67.15789273381233, 68.58843997120857, 68.52538615465164, 67.64761045575142, 60.709422156214714, 53.26811045408249, 51.474013924598694, 55.0507315993309, 60.514097437262535, 61.56522363424301, 61.60984084010124, 65.88790208101273, 65.39131432771683, 60.63145034015179, 60.48495680093765, 61.39398202300072, 58.420740365982056, 59.21324864029884, 54.89336684346199, 53.034278601408005, 52.45281860232353, 56.40041157603264, 57.59235821664333, 57.68915802240372, 53.71504247188568, 55.479880571365356, 54.595459029078484, 56.07933260500431, 60.66136233508587, 64.08387288451195, 61.24444104731083, 61.3180772960186, 61.11645631492138, 61.12394951283932, 58.1992806494236, 59.64903965592384, 62.68705643713474, 59.87142652273178, 61.01753242313862, 64.18642178177834, 61.82393275201321, 62.075597047805786, 59.115973860025406, 62.69006967544556, 64.18383032083511, 61.77379824221134, 61.33497878909111, 62.35423229634762, 66.48613438010216, 68.79481449723244, 65.3003092110157, 69.32674795389175, 70.29909297823906, 69.18749302625656, 65.76703816652298, 63.98806482553482, 70.4998742043972, 66.55266121029854, 71.10316023230553, 58.16325858235359, 55.86089752614498, 53.008800968527794, 61.89633406698704, 68.48977446556091, 60.851960107684135, 59.14936266839504, 43.8147497177124, 47.50321939587593, 47.96746328473091, 27.669987939298153, 24.81965448707342, 20.500583946704865, 0.44244629913009703, 0.45055432186927646, 0.06684155276161619, 0.1664768747286871, 0.15646819694666192, 0.09812992735533044, 0.19934450247092173, 0.04397375640110113, 0.07759203683235683, 0.031425593988387845, 9.35794310644269, 58.481392711400986, 23.638693057000637, 28.285123631358147, 48.99590089917183, 15.704727340489626, 0.7109385263174772, 0.1541452153469436, 0.056553563990746625, 0.08534388805855997, 0.058195847741444595, 0.08831758474116214, 0.04415986106323544, 0.0910745000874158, 0.06431946778320707, 0.037184344546403736, 0.05160949120181613, 0.03522955725202337, 0.10153026989428326, 0.0462846892332891, 0.08339652224094607, 0.07057381342747249, 0.05816827324451879, 0.04307881165004801, 0.14570769388228655, 0.05687899945769459, 0.11829940835013986, 0.0377341980492929, 0.1084124502085615, 0.04890426644124091, 0.07165771268773824, 0.2627423935336992, 24.471733756363392, 66.82966634631157, 50.72760097682476, 48.27339626848698, 36.48165620863438, 84.60358500480652, 3.890108233317733, 0.8203696261625737, 0.47946753446012735, 0.5361107387579978, 0.05570711859036237, 0.32156193105038255, 1.3880648044869304, 0.8745432598516345, 0.42831619328353554, 0.16319126822054386, 1.2170706549659371, 0.11444067829870619, 12.133514620363712, 63.19583773612976, 52.400058433413506, 65.37273332476616, 60.64948417246342, 64.34042751789093, 55.780148059129715, 56.52520067989826, 52.225184217095375, 53.71452949941158, 54.740105867385864, 61.136184856295586, 67.04511478543282, 69.02626007795334, 70.23559838533401, 68.05831521749496, 75.09527921676636, 79.83063831925392, 69.93386417627335, 66.4038535952568, 78.72415289282799, 80.05766853690147, 82.39735499024391, 80.8707869052887, 79.01347696781158, 79.7178603708744, 78.79346877336502, 73.8908426463604, 75.96836596727371, 75.99656045436859, 74.57203209400177, 72.69241735339165, 73.404970318079, 70.01713290810585, 69.37834918498993, 74.65046748518944, 76.32420927286148, 76.85800462961197, 77.47738659381866, 74.62425649166107, 76.16271033883095, 72.11530432105064, 62.2541456669569, 62.870841175317764, 69.5295886695385, 67.52841085195541, 68.93342345952988, 69.44580316543579, 64.211515635252, 57.061237916350365, 56.30405254662037, 58.833360224962234, 63.844478130340576, 66.43753498792648, 65.30311346054077, 68.34155961871147, 69.21328604221344, 67.25929409265518, 63.255319744348526, 65.56700929999352, 63.048417046666145, 60.65158165991306, 57.2748738527298, 53.98660629987717, 54.625314027071, 57.22392238676548, 60.59176906943321, 59.092760905623436, 54.62824746966362, 54.09083850681782, 56.80357754230499, 55.358051508665085, 62.90975868701935, 67.86071062088013, 66.35821804404259, 66.24627605080605, 62.867926731705666, 62.372923493385315, 61.24436505138874, 63.08103829622269, 62.24742002785206, 62.32161484658718, 63.284749165177345, 64.49384808540344, 63.15935589373112, 66.95407927036285, 64.5104531943798, 65.57964742183685, 65.10952904820442, 65.63284456729889, 64.77826282382011, 64.16372939944267, 66.17047011852264, 68.37603896856308, 64.78201702237129, 67.74490043520927, 70.42121082544327, 70.18558546900749, 68.34016129374504, 66.55549585819244, 70.50495833158493, 69.97812420129776, 72.60003671050072, 64.9868032336235, 60.81473730504513, 56.35486721992493, 62.53919877111912, 71.74589574337006, 64.77200835943222, 65.67930847406387, 58.89315381646156, 53.987693041563034, 62.37831920385361, 51.784856244921684, 33.48368547856808, 30.626005120575428, 1.2998413760215044, 0.36545949114952236, 0.12583351344801486, 0.08572751903557219, 0.17780828231479973, 0.07309678898309357, 0.10940868698526174, 0.04313564160838723, 0.15415009867865592, 0.18373177852481604, 10.744467806071043, 68.04264485836029, 26.975054629147053, 30.84824949502945, 58.93342785537243, 19.21161901205778, 0.4122545145219192, 0.29935814905911684, 0.1283133850665763, 0.11145976051921025, 0.014600452141166897, 0.09657900940510444, 0.0973874753981363, 0.025908362404152285, 0.0541887957660947, 0.05628560043987818, 0.04325559864810202, 0.025750041895662434, 0.040175533649744466, 0.14790577202802524, 0.10470911845914088, 0.16218317934544757, 0.11371254979167134, 0.0981326584587805, 0.272557326243259, 0.16871774510946125, 0.36029049195349216, 0.1893059755093418, 0.3541711875004694, 0.14633967715781182, 0.272989078075625, 0.3724257048452273, 28.333384841680527, 81.20166555047035, 49.61261160671711, 70.65886527299881, 55.86162328720093, 94.67749044299126, 4.421150637790561, 3.810555702075362, 1.9887813390232623, 0.8253131608944386, 0.8785910520236939, 0.4934965301072225, 2.212428906932473, 2.2425857512280345, 1.1977840773761272, 0.5814073956571519, 4.155130237340927, 0.5507229140494019, 21.51838593184948, 85.60967981815338, 65.57768672704697, 76.45925402641296, 69.49910670518875, 77.70546555519104, 67.5588396191597, 70.27121007442474, 69.22924518585205, 73.240507543087, 66.39592722058296, 70.20175740122795, 73.51726189255714, 76.22001126408577, 76.34044200181961, 73.59266504645348, 78.65422904491425, 85.23344680666924, 74.19910490512848, 70.43663039803505, 84.09507349133492, 88.08115839958191, 86.8908266723156, 85.74490696191788, 79.42450851202011, 82.23900988698006, 81.8944975733757, 79.09045323729515, 77.39739328622818, 78.52980092167854, 79.11683902144432, 76.32147341966629, 75.79449489712715, 72.83845871686935, 71.91930323839188, 78.4855104982853, 79.24248307943344, 78.77656728029251, 78.95137310028076, 77.68645897507668, 78.12490224838257, 76.63225874304771, 64.07210871577263, 65.32588183879852, 71.46643593907356, 74.88631322979927, 73.76506939530373, 75.69530501961708, 67.05931842327118, 59.60600696504116, 57.0001295953989, 62.65644147992134, 65.05671948194504, 69.00497362017632, 68.39247688651085, 72.49252527952194, 73.29262554645538, 67.29280829429626, 65.02895817160606, 67.36297532916069, 64.78175863623619, 64.34877187013626, 59.76917400956154, 58.414736688137054, 59.036782309412956, 62.42460452020168, 68.28222960233688, 63.05719457566738, 59.00274373590946, 61.74991272389889, 61.14489018917084, 61.31760232150555, 67.79128074645996, 70.49357414245605, 68.97393688559532, 70.29439643025398, 65.77236548066139, 65.78649312257767, 65.51693558692932, 66.0291101038456, 66.75069898366928, 67.58880481123924, 65.12583017349243, 68.02445143461227, 66.29499703645706, 70.1739276945591, 65.09306833148003, 66.39712035655975, 68.23556810617447, 66.36015594005585, 67.16048419475555, 65.5641670525074, 68.43544498085976, 73.51037666201591, 66.53775081038475, 71.74086481332779, 74.45888176560402, 73.09195831418037, 72.9913929104805, 70.95964193344116, 76.85214534401894, 72.08184331655502, 77.93558120727539, 67.77703151106834, 64.8049221932888, 66.25854179263115, 65.17323642969131, 69.31142717599869, 67.2153152525425, 68.19456070661545, 61.68113261461258, 54.89052079617977, 64.21170562505722, 63.34457315504551, 51.334626004099846, 37.641851752996445, 1.1533167259767652, 0.6462412979453802, 0.1468197873327881, 0.17449932784074917, 0.3105650836369023, 0.15503166621783748, 0.2398534756503068, 0.18738029524683952, 0.30576279445085675, 0.4181387065909803, 14.155149590224028, 76.84191629290581, 34.403802305459976, 36.77816189825535, 67.02208802103996, 21.32711559534073, 1.0004201740957797, 0.5964223493356258, 0.33729733200743794, 0.14573120512068272, 0.14461422833846882, 0.3202733548823744, 0.2000470194616355, 0.21626824513077736, 0.2304758905665949, 0.2709818060975522, 0.28117927140556276, 0.12873777479398996, 0.16250400978606194], [0.01134815878685913, 0.08115701741189696, 0.0318611604598118, 0.012833328019041801, 0.05468987532367464, 0.013787947009404888, 0.047651354179834016, 0.015880908285907935, 0.1241980203485582, 0.17730523977661505, 0.14408429036848247, 0.0382169836666435, 0.04418291588081047, 29.27090473473072, 57.52953238785267, 36.05438433587551, 44.17313888669014, 34.46377828717232, 58.28485205769539, 0.47937491443008184, 0.31394954421557486, 0.489656004938297, 0.36374323011841625, 0.15345530002377927, 0.05999971559504047, 0.19919556827517226, 0.14405093825189397, 0.0939690689847339, 0.09496541708358563, 0.08294752289657481, 0.2899004565551877, 30.469470620155334, 46.33160166442394, 42.54484266042709, 45.061044842004776, 48.191750049591064, 47.48315267264843, 43.71354594826698, 48.429009318351746, 48.68142977356911, 50.93820467591286, 54.71538819372654, 57.85522811114788, 61.288317292928696, 61.92121513187885, 64.27990436553955, 70.03976449370384, 75.04467353224754, 69.05549570918083, 64.39444541931152, 66.63407564163208, 72.68441498279572, 74.26728844642639, 79.23797652125359, 73.12494054436684, 75.25191441178322, 75.01418396830559, 75.90652048587799, 72.61626943945885, 71.1515924334526, 69.66792404651642, 71.10840395092964, 68.18649753928185, 68.35061073303223, 66.73232316970825, 69.79020148515701, 69.2767122387886, 69.380644261837, 71.75739392638206, 68.44121307134628, 67.75876969099045, 67.04642191529274, 59.058897122740746, 61.03791072964668, 67.14952558279037, 65.83458334207535, 69.09339487552643, 70.52186742424965, 65.00843927264214, 55.52697144448757, 52.76564061641693, 56.87041215598583, 52.02972270548344, 56.75157733261585, 58.55462998151779, 55.68552553653717, 63.18603806197643, 64.84688714146614, 67.13168933987617, 61.266871243715286, 60.763128474354744, 56.55114568769932, 51.21417246758938, 54.15846727788448, 55.424183160066605, 52.14306302368641, 53.152805641293526, 55.869458466768265, 58.0295779556036, 60.86783945560455, 56.56360901892185, 52.69716449081898, 54.40339833498001, 55.40867619216442, 58.68022844195366, 62.775314301252365, 63.88303846120834, 61.78260616958141, 64.29518714547157, 61.872543543577194, 57.792573273181915, 60.195564329624176, 60.044013261795044, 58.44267278909683, 62.25586697459221, 58.98738496005535, 60.31077794730663, 60.644320249557495, 59.739501401782036, 63.23138862848282, 63.399803191423416, 60.193007066845894, 59.46776658296585, 63.076733127236366, 66.7280749976635, 67.64568015933037, 61.384246945381165, 67.86438882350922, 70.81881389021873, 66.81899651885033, 64.965790361166, 64.29927572607994, 70.73319688439369, 65.50352230668068, 64.64333966374397, 52.34235852956772, 52.15588353574276, 50.08515805006027, 70.13722166419029, 63.70400346815586, 59.70042809844017, 48.86922709643841, 39.48444128036499, 44.92634207010269, 43.77142444252968, 21.998902447521687, 30.149016715586185, 9.76487372070551, 0.06477366958279163, 0.848163531627506, 0.05616688278678339, 0.1971637163660489, 0.06752833622158505, 0.13039245241088793, 0.07301728270249441, 0.1533142474363558, 0.09503947600023821, 1.9419860187917948, 46.666234508156776, 43.5927390307188, 27.654530368745327, 41.612661480903625, 25.341809168457985, 0.2551177464192733, 0.09940485542756505, 0.06710811736411415, 0.06084509972424712, 0.09208489704178646, 0.02235260672023287, 0.04880577231233474, 0.014243631248973543, 0.038868823103257455, 0.03374469044501893, 0.07448039716109633, 0.08404222782701254, 0.03877813636790961, 0.02921921492088586, 0.029600639863929246, 0.03508773283101618, 0.03139172236842569, 0.12029312871163711, 0.020907904945488553, 0.06588427131646313, 0.03672012375318445, 0.02797330296743894, 0.0907110481057316, 0.07123873321688734, 0.0860751410073135, 0.03980590699939057, 35.58395817875862, 66.30588725209236, 48.99868234992027, 37.03114092350006, 41.21720910072327, 68.47830668091774, 0.18679937173146755, 0.3665505372919142, 0.9787029144354165, 0.061838089604862034, 0.16589650040259585, 0.12075591715984046, 0.2467478346079588, 0.13499777560355142, 0.10938826308120042, 0.7817185157909989, 0.1485155354021117, 1.2059357087127864, 47.38546371459961, 61.39845438301563, 58.92094172537327, 67.42409884929657, 66.33726596832275, 65.31398847699165, 58.16689498722553, 60.85082396864891, 55.91479003429413, 57.90220499038696, 60.63944511115551, 60.14255717396736, 66.46408796310425, 68.37340950965881, 68.01319643855095, 74.50190305709839, 77.53280282020569, 69.78972271084785, 69.80749055743217, 69.69118639826775, 77.48956114053726, 77.3883193731308, 81.43672853708267, 77.1130545437336, 78.23174491524696, 77.49126344919205, 77.6295456290245, 74.87097725272179, 75.29147788882256, 72.3521076142788, 75.7977095246315, 73.45689073204994, 73.22165295481682, 71.92368060350418, 74.39357846975327, 71.74808442592621, 75.96108555793762, 75.01169130206108, 72.16872945427895, 74.20802682638168, 69.05621007084846, 61.69763892889023, 67.03183069825172, 69.73271057009697, 69.08185109496117, 72.10807710886002, 72.78467640280724, 65.23414716124535, 58.924095556139946, 59.362227246165276, 59.88958194851875, 54.98037837445736, 58.246610909700394, 59.672647789120674, 58.71417582035065, 65.66910222172737, 68.03860947489738, 69.97885376214981, 66.43695741891861, 63.18332500755787, 60.652843192219734, 55.92517867684364, 58.093330934643745, 56.850554421544075, 54.66127909719944, 54.109856486320496, 56.885516345500946, 58.67759518325329, 60.617033913731575, 57.378733679652214, 56.46087773144245, 57.73434139788151, 58.252519592642784, 59.2114133387804, 65.30940592288971, 67.68313094973564, 64.71442624926567, 66.06953233480453, 64.83632370829582, 61.65806025266647, 59.26151365041733, 61.715224385261536, 62.67031453549862, 62.55703881382942, 61.53166763484478, 64.19680282473564, 65.32585144042969, 63.02061013877392, 64.93845462799072, 66.76202237606049, 64.60208907723427, 64.23401802778244, 64.69689399003983, 65.74362382292747, 67.97649800777435, 59.220247864723206, 66.33180186152458, 71.8379420042038, 66.0007256269455, 66.0824516415596, 66.49692580103874, 70.59850171208382, 65.39498493075371, 69.83693137764931, 58.50339353084564, 56.4046635478735, 53.60123857855797, 67.79902473092079, 72.12215155363083, 65.18271312117577, 61.046984642744064, 52.005624398589134, 51.296293660998344, 64.24348711967468, 41.81926019489765, 38.59935477375984, 16.332025229930878, 0.15499288158025593, 0.97963742678985, 0.014316688266262645, 0.09709018588182516, 0.012284686072234763, 0.07882746038376354, 0.03212912772141863, 0.3218238794943318, 0.13408935716142878, 1.691104480996728, 54.14711728692055, 43.5962500423193, 26.351057812571526, 49.83440190553665, 31.60867229104042, 0.09510958669125102, 0.09633051609853283, 0.043748611060436815, 0.06952037190785632, 0.04861032030021306, 0.05290933317155577, 0.02430080930935219, 0.02601801843411522, 0.028179965120216366, 0.038069077345426194, 0.062262991414172575, 0.014387451119546313, 0.07918325340142474, 0.23226606950629503, 0.24745821836404502, 0.09820755600230768, 0.16773854062194005, 0.18004063284024596, 0.10800650285091251, 0.1453948489506729, 0.2088942806585692, 0.22478188126115128, 0.4350438213441521, 0.2768089418532327, 0.2819720335537568, 0.30580298916902393, 42.10521385073662, 75.27586072683334, 47.9157442599535, 67.4471028149128, 47.53254622220993, 77.38328084349632, 0.37791308539453894, 0.6158811645582318, 2.1467102458700538, 1.0182383679784834, 0.3862127900356427, 0.45731297170277685, 0.5478825664613396, 0.3208669839659706, 0.310854758718051, 1.9251817767508328, 0.6503241788595915, 2.095284992828965, 68.52171555161476, 76.16269513964653, 72.11056217551231, 79.7505234181881, 78.30350026488304, 76.9400118291378, 66.6970382630825, 73.13054904341698, 70.25482535362244, 70.50015538930893, 70.96059188246727, 71.86198711395264, 73.9737617969513, 74.7179214656353, 76.07368111610413, 79.76574540138245, 84.43131744861603, 76.68345719575882, 75.71801260113716, 74.02365311980247, 82.35897704958916, 82.42371797561646, 86.70587539672852, 82.97487080097198, 81.98148250579834, 81.68398886919022, 82.97598034143448, 79.56437900662422, 76.761474609375, 74.35453936457634, 78.37674513459206, 75.16964122653008, 75.33957570791245, 76.15488275885582, 75.62187775969505, 75.07390156388283, 75.80272525548935, 79.15903955698013, 75.51792293787003, 74.71576318144798, 72.63013109564781, 65.19127026200294, 68.04868653416634, 72.79123485088348, 73.49379435181618, 74.19506192207336, 75.77993407845497, 72.33054757118225, 62.83291541039944, 59.495193511247635, 61.94442808628082, 60.241895243525505, 63.14974620938301, 66.16703510284424, 61.81714251637459, 69.7929373383522, 70.01324951648712, 74.4860427081585, 67.64043644070625, 64.98350501060486, 63.84165868163109, 58.11959132552147, 60.58039627969265, 60.90211361646652, 58.744179010391235, 60.40075711905956, 62.055496126413345, 65.63895463943481, 66.46195247769356, 61.61424100399017, 60.88189870119095, 60.236089155077934, 63.503142446279526, 65.72573438286781, 71.68728768825531, 71.29235967993736, 66.02417796850204, 68.7113405764103, 66.82864800095558, 66.10047787427902, 65.45338779687881, 66.66602432727814, 64.15871366858482, 65.6615786254406, 62.63595297932625, 67.2382128238678, 66.39477208256721, 66.0263742506504, 65.91873362660408, 69.17401134967804, 66.07193380594254, 66.19335249066353, 66.65240585803986, 70.0873151421547, 70.56269243359566, 65.06561860442162, 70.89815363287926, 75.7888787984848, 69.84706923365593, 71.37441247701645, 68.94108384847641, 71.71425864100456, 71.57403856515884, 73.65422934293747, 63.04356850683689, 63.687105774879456, 61.02945618331432, 66.95212617516518, 69.85694870352745, 68.06385532021523, 62.492126896977425, 55.994467958807945, 53.95794443786144, 71.13475933670998, 54.17275831103325, 53.53024698793888, 17.801472879946232, 0.34508192678913474, 2.040792116895318, 0.12329673394560814, 0.2920082747004926, 0.11664575489703566, 0.27259277121629566, 0.23804018623195589, 0.503874693531543, 0.2855090796947479, 3.063101372681558, 59.4438848644495, 58.1549446284771, 41.630626916885376, 54.00887310504913, 36.1190302670002, 0.5143787548877299, 0.3298337012529373, 0.2547388948732987, 0.13266924273921177, 0.13942783320089802, 0.20597216323949397, 0.17907793371705338, 0.10157634242204949, 0.24126318516209722, 0.2205942090949975, 0.2002544645802118, 0.1464883441803977, 0.19933841685997322], [0.026090565224876627, 0.08053517929511145, 0.1108271761040669, 0.0814194259874057, 0.05168146839423571, 0.11073781410232186, 0.044950775263714604, 0.1336579764029011, 0.01592666725628078, 0.15765419346280396, 0.23770987114403397, 0.06671504626865499, 0.07102066796505824, 39.650366976857185, 44.11301091313362, 44.664372727274895, 30.361267626285553, 42.84540273249149, 42.19726391136646, 0.8171772630885243, 0.8940515911672264, 0.41598689393140376, 0.18477503035683185, 0.18295932153705508, 0.024697370354260784, 0.08941454580053687, 0.02216067434346769, 0.376775580807589, 0.18797303375322372, 0.2161415753653273, 7.827477855607867, 53.466364815831184, 41.42239049077034, 45.900108218193054, 47.99239754676819, 50.96983037889004, 52.25150540471077, 56.115316674113274, 51.339436545968056, 51.14380404353142, 52.98561841249466, 50.2179229259491, 50.723326206207275, 63.596602231264114, 57.92210832238197, 57.24113546311855, 67.01031625270844, 63.75195309519768, 66.71253383159637, 62.346313521265984, 70.72378098964691, 75.00101387500763, 75.33753901720047, 76.03477880358696, 74.87420707941055, 72.9847052693367, 75.02982392907143, 73.5980911552906, 70.79252690076828, 68.63738134503365, 69.45516586303711, 70.05443930625916, 71.01518735289574, 68.37681412696838, 72.53851801156998, 65.42787596583366, 69.12488758563995, 71.39240831136703, 66.84250205755234, 73.03382903337479, 65.25379970669746, 55.07975824177265, 66.33556365966797, 70.63828557729721, 64.21542942523956, 69.38241496682167, 68.64039078354836, 65.54186224937439, 56.01528324186802, 58.83789338171482, 57.286714017391205, 54.29203391075134, 52.47298792004585, 52.10185043513775, 55.70568345487118, 51.30346767604351, 57.397402077913284, 62.82313093543053, 65.84035143256187, 58.916161581873894, 58.39691944420338, 59.94209133088589, 56.074689254164696, 58.33736903965473, 54.3282725661993, 50.80667093396187, 54.8437263071537, 54.851626083254814, 58.950618132948875, 56.13706290721893, 60.40962964296341, 54.400924667716026, 54.52230155467987, 58.645323514938354, 56.2441411614418, 56.71213544905186, 57.61650212109089, 62.3936627805233, 67.87600859999657, 64.87192779779434, 60.979515463113785, 59.69748705625534, 59.67536084353924, 61.215855181217194, 59.45004053413868, 59.70282956957817, 58.63525405526161, 59.67981040477753, 60.03240488469601, 61.56919822096825, 62.48009294271469, 60.83772987127304, 63.78973066806793, 63.45073185861111, 60.645152404904366, 64.04060080647469, 63.53363960981369, 61.234721168875694, 73.34384679794312, 68.99035960435867, 69.4124485552311, 67.26686328649521, 67.87207961082458, 65.23746058344841, 63.28977629542351, 56.978634148836136, 49.776238426566124, 45.591557174921036, 52.072124630212784, 72.74174630641937, 54.336145743727684, 54.9338498711586, 35.53062804043293, 40.217076167464256, 43.37524250149727, 34.71515379846096, 23.845559656620026, 27.397039085626602, 1.5304584824480116, 0.3428377612726763, 0.25736574141774327, 0.11401623662095517, 0.2806350990431383, 0.04143285426835064, 0.06549078461830504, 0.15818013867828995, 0.04974378760380205, 0.14075317536480725, 29.748831689357758, 51.46567717194557, 19.69949573278427, 36.15440636873245, 32.7512139827013, 0.007291166766663082, 0.051633885595947504, 0.02385314212006051, 0.11899897159310058, 0.03442817134782672, 0.022988679229456466, 0.044708501154673286, 0.04499524104176089, 0.0913544901413843, 0.03467365153483115, 0.03761270476388745, 0.021544903283938766, 0.050831950502470136, 0.0726088194642216, 0.040794718588585965, 0.0473116546345409, 0.12080964865162969, 0.026296988035028335, 0.053833707788726315, 0.059669092515832745, 0.0349928937794175, 0.05249646899756044, 0.025022273330250755, 0.04845169736654498, 0.08911223194445483, 0.07102759962435812, 47.77916058897972, 50.4980742931366, 48.28611418604851, 37.42751285433769, 45.74968568980694, 51.02240435779095, 0.6676174071617424, 0.3327076236018911, 0.4539097793167457, 0.25500309944618493, 0.17129529820522293, 0.11278977079200558, 0.32548614079132676, 0.08323899397510104, 0.4361150076147169, 0.7911011623218656, 0.3488382924115285, 13.908427879214287, 71.40960618853569, 55.925927236676216, 64.09903407096863, 66.11639142036438, 66.84381678700447, 63.77079248428345, 67.9816809296608, 62.293997928500175, 59.14037235081196, 59.6448028832674, 55.18780544400215, 58.94352771341801, 66.07667595148087, 62.13438369333744, 61.67629927396774, 70.77193960547447, 64.13927391171455, 69.31571334600449, 69.2165994644165, 75.10883688926697, 79.03232395648956, 77.71719172596931, 79.70554903149605, 79.22462403774261, 76.5651847422123, 76.51036888360977, 76.93587005138397, 73.55744853615761, 71.7239785194397, 73.44317346811295, 75.0701017677784, 74.27165061235428, 70.15033096075058, 75.98386153578758, 71.24004408717155, 72.81847178936005, 72.87372842431068, 72.49934211373329, 76.29161462187767, 65.91026768088341, 60.6325750797987, 72.19108745455742, 74.37059730291367, 67.13995009660721, 72.3606875538826, 68.84146079421043, 65.26511549949646, 55.53534999489784, 61.56899303197861, 60.00685125589371, 58.05519238114357, 54.91539806127548, 58.37888181209564, 57.61086702346802, 56.708670035004616, 62.75228373706341, 65.83592846989632, 69.5187820494175, 65.66050708293915, 62.08436697721481, 61.7970035970211, 59.44315530359745, 60.319312289357185, 55.735128074884415, 52.13291756808758, 56.18932530283928, 56.266274973750114, 58.290817737579346, 56.590382382273674, 59.6532916277647, 54.63178128004074, 57.06362798810005, 60.95616191625595, 59.28826421499252, 59.4323942810297, 60.41464917361736, 63.655856251716614, 69.34434100985527, 67.51131176948547, 64.17783424258232, 60.38067139685154, 62.96273924410343, 62.51913584768772, 62.175341695547104, 61.4278420060873, 60.97128130495548, 62.72850081324577, 66.33148267865181, 65.11193051934242, 63.15294183790684, 64.13722202181816, 66.96669459342957, 65.48232704401016, 62.06222556531429, 62.01324239373207, 61.98023356497288, 58.41136246919632, 70.23377448320389, 70.3795650601387, 68.97794187068939, 69.35925900936127, 68.32731798291206, 66.19879379868507, 64.79758858680725, 63.25741723179817, 54.181209057569504, 51.72210641205311, 52.89367474615574, 75.18344208598137, 63.219088688492775, 63.86277794837952, 54.30086463689804, 49.137044325470924, 53.2145219296217, 58.253480941057205, 37.54813738167286, 35.827392116189, 3.2687216391786933, 0.23735828610369936, 0.4033474065363407, 0.14612669561756775, 0.2555600961204618, 0.08234771914430894, 0.10016600950621068, 0.034833365425583906, 0.0667270616395399, 0.08426961445366032, 35.20948447287083, 55.77813796699047, 22.581021711230278, 45.42467013001442, 38.83748419582844, 0.09248689617379569, 0.037289046740625054, 0.05226893765211571, 0.09761006775079295, 0.01787158955266932, 0.03130785597022623, 0.025929650910256896, 0.028232019358256366, 0.023171520297182724, 0.07496005462598987, 0.04194178203761112, 0.0754027086077258, 0.02973231912619667, 0.14603309595258906, 0.21323572582332417, 0.28907242754939944, 0.2592036552960053, 0.10756268369732425, 0.21629966766340658, 0.16824366117361933, 0.1911138027207926, 0.11974266293691471, 0.23947683570440859, 0.3442692750832066, 0.3863462578738108, 0.1288834583829157, 56.62900730967522, 59.628193974494934, 56.56891353428364, 46.94282166659832, 55.43598912656307, 64.50889527797699, 1.8618501001037657, 1.8448818731121719, 0.8297154621686786, 0.49808997893705964, 0.4485083691542968, 0.2265068847918883, 0.5177171726245433, 0.35075822845101357, 0.8733094541821629, 2.2523205913603306, 0.4571522818878293, 21.467709951102734, 92.23612144589424, 67.52692893147469, 75.86867451667786, 73.77524524927139, 77.3312084376812, 74.44397136569023, 77.34640002250671, 72.80909389257431, 69.80470910668373, 71.17069020867348, 67.21705555915833, 68.4904432296753, 77.31274902820587, 72.83801794052124, 70.11283457279205, 77.41836056113243, 68.51029336452484, 74.75665658712387, 73.18329021334648, 78.83671805262566, 82.92841449379921, 82.7701985836029, 83.27798053622246, 82.07077771425247, 79.26275879144669, 80.13570874929428, 80.68088829517365, 75.29150068759918, 74.26664248108864, 76.31725564599037, 76.83241680264473, 76.61873906850815, 72.43622750043869, 79.21744242310524, 72.20108091831207, 75.33148974180222, 74.78330075740814, 72.61461272835732, 77.69623965024948, 70.42722970247269, 60.28137132525444, 71.51267945766449, 77.05614119768143, 69.2894035577774, 76.84646084904671, 74.34390753507614, 71.38548508286476, 60.70210374891758, 64.20068621635437, 63.05307559669018, 61.03679358959198, 60.37190146744251, 59.61911626160145, 62.05043859779835, 59.075164049863815, 64.41710740327835, 69.03344929218292, 71.117113083601, 66.0472959280014, 63.4386371076107, 64.968191832304, 61.646508872509, 63.08564364910126, 59.79419566690922, 56.871324107050896, 60.55503264069557, 62.49218389391899, 66.11655861139297, 60.42203977704048, 64.74676251411438, 61.243475899100304, 61.66098229587078, 64.2633144557476, 61.81373029947281, 63.63425061106682, 65.33115595579147, 69.25667211413383, 71.46032586693764, 71.77779123187065, 66.88449740409851, 64.85788375139236, 65.45360058546066, 67.73659408092499, 64.42405343055725, 65.15443503856659, 65.38741573691368, 63.89641374349594, 68.37222397327423, 67.83523678779602, 66.39597281813622, 66.59271106123924, 71.14108219742775, 68.34643855690956, 64.03913408517838, 67.67421662807465, 65.19222781062126, 63.68321858346462, 76.19896039366722, 73.86596918106079, 74.18520525097847, 74.91022154688835, 74.26750123500824, 69.23995301127434, 70.83476543426514, 66.5606939792633, 58.808980733156204, 61.55956573784351, 57.09297001361847, 72.85107403993607, 63.34429197013378, 65.93794539570808, 55.980868488550186, 55.142325684428215, 54.03821513056755, 67.48016104102135, 47.66205087304115, 45.743294432759285, 3.359794202260673, 0.319779232959263, 0.6005680456291884, 0.1603184887790121, 0.37737660168204457, 0.16433902928838506, 0.1386351155815646, 0.24210782343288884, 0.12192379042971879, 0.22891672735568136, 43.11566323041916, 66.15935951471329, 29.389581866562366, 48.1988138705492, 46.17522485554218, 0.23360569059150293, 0.11715708722476847, 0.13827889953972772, 0.3277536988025531, 0.16539078613277525, 0.11791628945502453, 0.15260430896887556, 0.20008592284284532, 0.16264387493720278, 0.08985214575659484, 0.16259801021078601, 0.21689941204385832, 0.19828367658192292], [0.06694728654110804, 0.008529475417162757, 0.006083945754653541, 0.09044941878528334, 0.04496718043810688, 0.07918219213024713, 0.06959019316127524, 0.12577198940562084, 0.07903177363914438, 0.09731384692713618, 0.18568131141364574, 0.11048303480492905, 0.5906894069630653, 53.50730001926422, 42.232408225536346, 40.62585063278675, 24.252234734594822, 55.68133816123009, 25.30528362840414, 0.7697944587562233, 0.303655955940485, 0.16379319451516494, 0.28818864841014147, 0.10055206730612554, 0.10931210388662294, 0.13089555432088673, 0.05934191671258304, 0.8037642203271389, 1.159034469164908, 0.1556507361237891, 16.823057681322098, 55.283172726631165, 45.39669223129749, 48.94143842160702, 52.76445508003235, 54.24900121986866, 57.00384959578514, 50.622061640024185, 52.182702496647835, 50.397493690252304, 50.96297934651375, 55.45569866895676, 61.66962683200836, 63.2524698972702, 61.25684358179569, 56.45896263420582, 64.28658440709114, 64.55571636557579, 65.1065044105053, 61.671044155955315, 75.34221276640892, 70.99719151854515, 75.99015399813652, 75.82882985472679, 76.17413252592087, 70.7693101465702, 72.12133839726448, 71.59049168229103, 71.59654095768929, 69.04173284769058, 71.21440306305885, 69.45740014314651, 66.95075824856758, 71.00190326571465, 68.0406005680561, 69.93220746517181, 66.99007093906403, 64.62807208299637, 70.93150824308395, 61.506778970360756, 57.956865057349205, 68.5512475669384, 70.59664741158485, 67.97390654683113, 67.91554167866707, 64.63855192065239, 62.02275328338146, 55.88710471987724, 59.035589173436165, 60.052289217710495, 56.35772846639156, 52.88422845304012, 50.537972152233124, 53.09506393969059, 57.25193068385124, 58.3486620336771, 60.2059605717659, 62.92074389755726, 65.68883836269379, 62.730655297636986, 60.34266583621502, 60.06662204861641, 58.205261528491974, 56.18044897913933, 49.55114610493183, 50.32502017915249, 53.94332282245159, 51.724222898483276, 57.8620183467865, 58.52991230785847, 58.8414765894413, 59.89975780248642, 51.15332253277302, 56.130504459142685, 58.88086527585983, 58.686938881874084, 57.550332471728325, 53.81505310535431, 58.49780023097992, 63.44721704721451, 64.17904257774353, 61.596020981669426, 60.32773643732071, 59.841613322496414, 60.97740277647972, 59.130508080124855, 58.14227610826492, 59.8795884847641, 58.77118416130543, 60.674540027976036, 59.50268290936947, 63.66410180926323, 63.085959032177925, 63.02535608410835, 61.01506635546684, 62.54777491092682, 64.30401787161827, 58.0436410009861, 66.00943475961685, 71.5043731033802, 67.74787187576294, 67.83835262060165, 65.75870141386986, 68.28338474035263, 61.74306929111481, 58.63147705793381, 50.776732340455055, 50.38881875574589, 34.493678882718086, 66.31306126713753, 61.86587490141392, 47.5924614071846, 45.098750218749046, 31.73297882080078, 40.56582525372505, 44.26570191979408, 28.346450440585613, 31.65696009993553, 10.312379691749811, 0.2902322559384629, 0.7968720432836562, 0.11422431256505661, 0.2783493435708806, 0.09488336523645557, 0.046182217192836106, 0.10270480765029788, 0.10147096487344243, 0.05672793529811315, 14.777493495494127, 52.603469118475914, 29.478848576545715, 38.10057453811169, 36.50653727352619, 0.06198822979058605, 0.050056038817274384, 0.038222071088966914, 0.10439870035042986, 0.04044307046569884, 0.05296143935993314, 0.0542984146886738, 0.036741987423738465, 0.06430595327401534, 0.04179171235591639, 0.07472917248378508, 0.07502802051021717, 0.06746893472154625, 0.03450309857726097, 0.012078499821654987, 0.05224153013841715, 0.1086972642224282, 0.05534145129786339, 0.054469097522087395, 0.016981320331979077, 0.057669683592393994, 0.02808520213875454, 0.06223804040928371, 0.07837807512260042, 0.041535949712852016, 1.333105859812349, 60.48741526901722, 50.816846787929535, 46.7291135340929, 21.016499362885952, 60.15385776758194, 31.39238979667425, 0.5574704613536596, 0.2690693212207407, 0.25423334387596697, 0.1072113064583391, 0.1586407155264169, 0.14655222825240344, 0.14343317452585325, 0.15687621489632875, 1.3739260006695986, 1.5606989222578704, 0.17846223316155374, 25.86016785353422, 70.42210757732391, 60.01971736550331, 65.90381562709808, 63.84545847773552, 64.86533895134926, 67.13018462061882, 59.266449585556984, 62.55288943648338, 58.890976533293724, 60.28846174478531, 63.58366772532463, 66.2982040643692, 66.95559158921242, 69.09129738807678, 64.23279449343681, 71.73685222864151, 67.47058555483818, 69.22891080379486, 65.70005536079407, 77.67325088381767, 73.42156022787094, 78.11822980642319, 77.25256785750389, 79.80889588594437, 73.6112080514431, 75.90937033295631, 76.40443056821823, 73.96518185734749, 72.9319716989994, 74.32542532682419, 72.22720071673393, 72.33163431286812, 75.10180726647377, 72.12715208530426, 71.29156172275543, 71.13459974527359, 68.307194262743, 72.79092326760292, 63.87045353651047, 64.27426546812057, 74.84468266367912, 72.0988892018795, 71.4039520919323, 73.23540061712265, 66.60534158349037, 64.81338813900948, 55.986047610640526, 61.119017377495766, 60.864453837275505, 57.266297712922096, 56.14668399095535, 51.2860532104969, 55.273680835962296, 60.52308015525341, 62.24030300974846, 65.45933827757835, 66.6344328224659, 66.14246562123299, 66.11791133880615, 63.96424010396004, 63.786037266254425, 61.62940599024296, 57.296867072582245, 52.01320119202137, 51.71169117093086, 54.33675371110439, 52.68092796206474, 58.6815469712019, 58.27085740864277, 60.23493781685829, 61.47096589207649, 55.46004183590412, 57.4344614893198, 63.715634644031525, 64.4623401761055, 62.720080465078354, 58.95942606031895, 60.53289122879505, 64.23199653625488, 67.68351092934608, 62.91899599134922, 62.89295978844166, 60.556613355875015, 63.26620616018772, 64.21334713697433, 62.87077657878399, 60.17088085412979, 63.85694906115532, 64.4883231818676, 64.2339800298214, 63.50299045443535, 67.40764573216438, 65.90989530086517, 63.82388323545456, 61.738300547003746, 61.78491644561291, 58.36595870554447, 64.99965414404869, 69.44338649511337, 68.03789511322975, 66.88858598470688, 66.11905887722969, 69.00571838021278, 63.66202712059021, 64.25652801990509, 57.965072616934776, 54.610449224710464, 41.114348620176315, 63.83303314447403, 72.38065928220749, 57.66305722296238, 62.65856936573982, 47.58092902600765, 47.94671639800072, 57.62352034449577, 49.00679111480713, 41.12711973488331, 15.072069838643074, 0.3182657860452309, 1.303726548794657, 0.10889069017139263, 0.10632829915266484, 0.07629359752172604, 0.11915566865354776, 0.01655204912822228, 0.10269155289279297, 0.08740098041016608, 19.148270711302757, 55.52045099437237, 32.21484616398811, 52.78376184403896, 42.83861629664898, 0.41195056051947176, 0.07039063653792255, 0.04248110075423028, 0.1117085135774687, 0.08329345277161337, 0.09122241754084826, 0.05961769507848658, 0.017810403187468182, 0.04847815493121743, 0.07409546000417322, 0.034772130820783786, 0.04081925028003752, 0.0211733451942564, 0.19744000310311094, 0.14424625667743385, 0.1942555364803411, 0.2221915335394442, 0.20035094377817586, 0.17808624630561098, 0.11972671418334357, 0.22440485539846122, 0.10878009532461874, 0.18435567239066586, 0.35045252298004925, 0.277500890661031, 1.7676176503300667, 75.68578273057938, 56.520899310708046, 55.21578714251518, 38.21873679757118, 70.1723925769329, 41.94366551935673, 1.5141313523054123, 0.36245358525775373, 0.474279981572181, 0.41500930732581764, 0.2762222592718899, 0.4360654321499169, 0.3153730428311974, 0.30493966361973435, 1.167083268519491, 3.0695873871445656, 0.29824765864759684, 37.88173288106918, 85.96414759755135, 69.45621460676193, 77.49608159065247, 74.37012612819672, 75.14953270554543, 74.99054163694382, 67.66509711742401, 74.60692942142487, 71.67670905590057, 74.05125483870506, 71.84107303619385, 74.14473742246628, 78.66989180445671, 76.23208701610565, 69.18479517102242, 77.29233652353287, 70.58386489748955, 76.62150532007217, 73.37346240878105, 81.71498760581017, 79.29048970341682, 84.1912691295147, 82.65927493572235, 84.91856530308723, 78.39628368616104, 78.31604719161987, 79.67021092772484, 77.48475819826126, 74.41605046391487, 78.64659145474434, 75.16996040940285, 73.36456328630447, 75.9074704349041, 74.90373909473419, 75.82151904702187, 75.05143716931343, 71.06425032019615, 77.24740013480186, 68.83202970027924, 64.51845556497574, 74.70588371157646, 74.91061672568321, 76.31752163171768, 74.43615898489952, 70.78270062804222, 67.65815109014511, 61.49547077715397, 64.94377434253693, 65.71333944797516, 61.49663731455803, 58.78354489803314, 55.366126075387, 58.996717259287834, 64.03243124485016, 65.30797719955444, 67.16796979308128, 68.73593285679817, 68.63080769777298, 69.40248548984528, 67.13637828826904, 65.54706797003746, 66.27878710627556, 62.440358474850655, 57.565999031066895, 56.91125616431236, 60.59668980538845, 56.981943771243095, 65.50368949770927, 64.11503881216049, 65.52246809005737, 68.00400093197823, 58.14770221710205, 65.531405210495, 65.9142042696476, 65.35517066717148, 64.82895970344543, 62.210732996463776, 65.91824725270271, 68.17111596465111, 70.9607894718647, 67.0728000998497, 65.94443544745445, 64.17308449745178, 65.73422312736511, 66.6367506980896, 65.99669024348259, 62.933799996972084, 66.07532322406769, 66.11509948968887, 66.01903304457664, 67.97031953930855, 70.60855597257614, 68.17919433116913, 66.50039881467819, 65.85099086165428, 67.6258984208107, 63.11842069029808, 70.27633979916573, 74.71925899386406, 72.93072536587715, 72.70096689462662, 70.99083065986633, 71.64396241307259, 69.70162063837051, 70.1540395617485, 61.49030305445194, 60.44502094388008, 51.33209154009819, 66.61210522055626, 70.24714976549149, 58.04349660873413, 60.051286071538925, 52.18238331377506, 53.66980969905853, 65.2206502854824, 59.18867535889149, 50.254879742860794, 17.919205762445927, 0.5998688831459731, 1.979013963136822, 0.24250190384918824, 0.36696937575470656, 0.15235129598295316, 0.19794794381596148, 0.1460936403600499, 0.24405045434832573, 0.32740385038778186, 23.916579745709896, 65.12438625097275, 42.98248037695885, 50.862159356474876, 50.270006731152534, 0.5296460387762636, 0.12745687243295833, 0.19524765433743596, 0.17407689738320187, 0.20388205273775384, 0.13833102799253538, 0.16546696017030627, 0.08994075076770969, 0.16705472575267777, 0.09390416817041114, 0.17943076556548476, 0.12084134577889927, 0.1555292317061685], [0.031512005953118205, 0.053274918827810325, 0.04194041648588609, 0.05866360115760472, 0.06408221801393665, 0.026074564520968124, 0.025052693963516504, 0.03437140076130163, 0.052396416358533315, 0.027512865272001363, 0.18433357123285532, 0.18588560982607305, 3.586557009257376, 56.22317008674145, 36.04792468249798, 47.87928141653538, 37.34839729964733, 68.41893866658211, 15.014242641627789, 0.3366562054725364, 0.5669616395607591, 0.02567219617048977, 0.1044838989037089, 0.09744087292347103, 0.09506320988293737, 0.19760716444579884, 0.058590373446349986, 0.7957724772859365, 1.1856281734071672, 0.18496720207622275, 33.19971151649952, 56.1363485455513, 47.942331433296204, 52.18928374350071, 58.41475188732147, 53.84023055434227, 62.20740057528019, 58.87087941169739, 55.76788231730461, 41.837947592139244, 41.107136607170105, 51.397463232278824, 52.49355621635914, 56.00516818463802, 61.079647690057755, 59.044146314263344, 68.52147996425629, 68.2852390408516, 64.53490868210793, 62.89391353726387, 73.52458789944649, 72.61899769306183, 73.95902618765831, 73.99658337235451, 71.09443590044975, 73.72463196516037, 75.26357218623161, 70.5167604982853, 69.17021155357361, 69.41856622695923, 72.66498282551765, 68.08068841695786, 73.09077277779579, 69.88154858350754, 68.22854608297348, 69.71113532781601, 69.3207898736, 73.0216620862484, 61.6978745162487, 61.42493516206741, 75.70383936166763, 71.06370314955711, 65.84745705127716, 71.67985528707504, 69.97159615159035, 64.44095492362976, 56.168209835886955, 54.276481345295906, 60.010168477892876, 56.21114753186703, 55.088782757520676, 53.71238261461258, 49.200903698801994, 50.725940465927124, 55.6265527009964, 60.69462575018406, 62.97598533332348, 64.0733702480793, 67.27485045790672, 64.15342435240746, 62.532267943024635, 59.065611362457275, 54.120822697877884, 49.04859647154808, 46.57130420207977, 49.05181869864464, 50.77635616064072, 51.32526710629463, 52.20216125249863, 54.25439693033695, 57.24064528942108, 59.12017643451691, 62.66471743583679, 51.235797107219696, 57.25559748709202, 60.48906058073044, 61.86330623924732, 58.135219886898994, 52.78665728867054, 54.53771352767944, 64.94281679391861, 64.88819092512131, 64.11330610513687, 62.52410978078842, 60.73046162724495, 60.86675651371479, 59.2276156693697, 58.61670345067978, 58.95826332271099, 57.95183412730694, 58.52703586220741, 61.44795812666416, 64.08007308840752, 62.973169684410095, 59.09293569624424, 62.719901874661446, 60.02815671265125, 59.846146479249, 61.7762491106987, 67.37386554479599, 68.39361682534218, 68.73163148760796, 67.31149569153786, 65.47947719693184, 60.90963341295719, 60.56915648281574, 57.65666216611862, 51.64122395217419, 33.81258063018322, 42.058141976594925, 70.92783764004707, 45.6201658397913, 44.746224135160446, 37.31953404843807, 33.36213760077953, 45.63129164278507, 41.277010291814804, 30.68504825234413, 20.489129461348057, 0.6685576192103326, 0.8537996385712177, 0.2937848278088495, 0.09472031539189629, 0.08278134861029685, 0.08477958122966811, 0.071436092548538, 0.07568334433017299, 0.011645636623143218, 6.430253405123949, 51.736716628074646, 41.069252640008926, 24.999719224870205, 44.83942933380604, 0.5987997155170888, 0.04137401680054609, 0.0847538880771026, 0.044104073822381906, 0.048536602771491744, 0.04205129705951549, 0.012270164097571978, 0.026272465620422736, 0.017945581676030997, 0.041460632855887525, 0.03057836933294311, 0.12600291607668623, 0.03661950337118469, 0.02958820332423784, 0.07653134452993982, 0.022412008220271673, 0.140347903361544, 0.0226155496420688, 0.0033509737158965436, 0.03372655235580169, 0.01825032421038486, 0.035692141609615646, 0.022450546093750745, 0.15458296373253688, 0.15199634159216657, 5.082155093550682, 66.49139329791069, 44.00363378226757, 46.54501721262932, 31.175786219537258, 77.14700192213058, 16.94509193301201, 0.18132362805772573, 0.48014766827691346, 0.08354596851859242, 0.09464083137572743, 0.2107692277058959, 0.08859684006893076, 0.22371740400558338, 0.11634330003289506, 0.7745145179796964, 2.0779111376032233, 0.33885714830830693, 43.664197996258736, 68.76233384013176, 62.332543060183525, 63.73017266392708, 67.59109988808632, 64.72578004002571, 67.81951323151588, 68.86419877409935, 66.15112155675888, 54.12008933722973, 53.91190230846405, 55.98930403590202, 58.94501343369484, 64.2675930261612, 65.83105713129044, 64.98358100652695, 75.64065635204315, 71.76741778850555, 68.83433997631073, 72.34307169914246, 75.72194159030914, 75.1291885972023, 77.68792569637299, 76.00030705332756, 73.74790951609612, 77.40369334816933, 77.12021335959435, 72.85362750291824, 73.08286920189857, 75.64902350306511, 76.39516666531563, 70.98953872919083, 74.44236025214195, 70.38151055574417, 70.96920982003212, 71.74639731645584, 73.14568743109703, 74.40817728638649, 62.10397012531757, 69.22099962830544, 78.3002096414566, 74.08460184931755, 71.25393614172935, 73.864776045084, 71.37457966804504, 67.08961799740791, 58.2160909473896, 58.410404920578, 61.484945341944695, 56.7015416175127, 55.816713497042656, 57.432295605540276, 53.115829825401306, 52.09688030183315, 56.58321976661682, 63.44452679157257, 64.7554412484169, 65.05439400672913, 69.8874382674694, 66.91003203392029, 66.49960085749626, 64.13620367646217, 57.961409613490105, 51.23730942606926, 48.51606644690037, 49.81518633663654, 52.880405858159065, 52.55889371037483, 54.8980937898159, 53.91035579144955, 58.44633959233761, 59.489706605672836, 62.73335315287113, 54.787557721138, 57.88459673523903, 63.05470570921898, 65.51107630133629, 62.63290174305439, 58.27213793992996, 55.556275472044945, 63.4207134693861, 65.24294748902321, 64.17965054512024, 64.71165239810944, 62.336548045277596, 63.12670424580574, 62.767175137996674, 62.70178824663162, 63.38158696889877, 61.29074916243553, 61.9276861846447, 62.86976583302021, 65.37695109844208, 64.86542254686356, 64.92262467741966, 64.87255856394768, 57.69313640892506, 59.35263656079769, 61.37876383960247, 65.31346410512924, 67.59307578206062, 67.59201943874359, 67.45466440916061, 66.08207166194916, 60.59062913060188, 60.379037484526634, 63.31802777945995, 54.94557224214077, 41.154463067650795, 45.227187126874924, 75.95272600650787, 58.66738513112068, 58.57092350721359, 55.272822082042694, 44.9442695081234, 51.25359155237675, 55.7711311429739, 45.31774766743183, 25.54879356175661, 1.4349287585355341, 0.7126436848193407, 0.2748698287177831, 0.08854857078404166, 0.044191461711307056, 0.09836986369919032, 0.054916375083848834, 0.051582235828391276, 0.0573887844075216, 7.438666094094515, 58.56691852211952, 37.42302909493446, 33.08004453778267, 54.541916102170944, 0.9687535639386624, 0.015813374702702276, 0.14787941094255075, 0.03297628558357246, 0.023376538592856377, 0.012947795021318598, 0.04959153229719959, 0.03787235626077745, 0.028945497870154213, 0.07379740607575513, 0.08840366645017639, 0.048412300457130186, 0.010760505847429158, 0.11312153306789696, 0.24156176601536572, 0.2216699521522969, 0.21140698489034548, 0.13725409749895334, 0.1705218170536682, 0.18735111400019377, 0.0950521815684624, 0.2665674523450434, 0.07207384231151082, 0.42761002492625266, 0.3815594350453466, 5.8599253837019205, 80.47507613897324, 46.90943285822868, 64.98827755451202, 56.47380843758583, 84.84585240483284, 23.65935254842043, 0.7770112808793783, 0.868945091497153, 0.16440260165836662, 0.35556464397814125, 0.44121169194113463, 0.4310514230746776, 0.5458664777688682, 0.6787649996113032, 2.72645297460258, 4.9769216403365135, 1.1046738736331463, 59.0621193498373, 81.58445701003075, 74.56740394234657, 75.39159491658211, 74.27572399377823, 72.72458642721176, 77.58165299892426, 80.43150767683983, 78.75965818762779, 67.45116099715233, 65.45855551958084, 72.75584354996681, 72.87754341959953, 75.67116871476173, 78.6334365606308, 71.59778729081154, 78.6577020585537, 75.5853845179081, 75.1032891869545, 78.16375136375427, 81.90249994397163, 82.63766929507256, 85.7379837334156, 82.05403581261635, 77.61726468801498, 79.66252774000168, 81.15767911076546, 75.20489573478699, 75.55281266570091, 78.11560794711113, 78.92640084028244, 74.23461779952049, 80.51808223128319, 75.27021422982216, 75.5350524187088, 75.70035874843597, 75.65014064311981, 79.3159331381321, 69.40875515341759, 68.76096591353416, 83.29278454184532, 77.74205759167671, 72.14213088154793, 78.94687414169312, 75.34012287855148, 70.65875887870789, 62.38580480217934, 61.64752721786499, 66.8514695763588, 63.31545151770115, 59.582326635718346, 59.980910047888756, 54.54964108765125, 56.70247636735439, 63.41380164027214, 67.45702788233757, 68.00792992115021, 68.24354007840157, 73.33876267075539, 71.13619565963745, 71.25514447689056, 65.10218784213066, 60.875078067183495, 53.31818036735058, 52.307404205203056, 53.36447708308697, 56.2056378275156, 56.39385312795639, 59.03375767171383, 60.45619994401932, 63.76344367861748, 65.86783155798912, 68.49548935890198, 58.94749850034714, 64.10910353064537, 66.06503337621689, 67.65258818864822, 65.55133894085884, 60.84027573466301, 59.156722873449326, 70.68555504083633, 68.60701337456703, 69.72465500235558, 67.36467763781548, 65.82041010260582, 68.86634185910225, 65.80223187804222, 65.82212001085281, 66.71001836657524, 62.42010556161404, 64.56279918551445, 64.75085109472275, 69.74740818142891, 68.03832828998566, 66.25721946358681, 65.99381759762764, 61.97161182761192, 64.1396614909172, 66.33577644824982, 72.20035895705223, 71.02900341153145, 74.26633089780807, 75.09272575378418, 71.77194714546204, 68.36980730295181, 64.96941536664963, 69.18175533413887, 63.66824358701706, 49.62213009595871, 51.93105719983578, 72.90088176727295, 58.936897069215775, 55.18970154225826, 57.48651869595051, 49.60229896008968, 56.696491688489914, 62.34395384788513, 53.55513945221901, 32.44957096874714, 2.1489891735836864, 1.3388374960049987, 0.5904081033077091, 0.15249506483087316, 0.16468190151499584, 0.158411139564123, 0.19278468884294853, 0.13311000424437225, 0.22760870691854507, 13.856775350868702, 67.60975688695908, 54.1312151402235, 35.39105013012886, 60.98220951855183, 1.2408588035032153, 0.17600312683498487, 0.15373869653558359, 0.11729008750990033, 0.10095529098180123, 0.11073553570895456, 0.19717787654371932, 0.10442393337143585, 0.1276739506283775, 0.18970395962242037, 0.1666060381103307, 0.17650711932219565, 0.1728720948449336], [0.02952371069113724, 0.021920151702943258, 0.052303555130492896, 0.011743438699340913, 0.0038093851162557257, 0.03797262041189242, 0.05378901194490027, 0.04708632375695743, 0.0659920608450193, 0.10764751859824173, 0.12106749301892705, 0.462613538838923, 12.598667610436678, 62.62528695166111, 34.30355228483677, 41.44116148352623, 24.836189299821854, 67.88869991898537, 4.719051327556372, 0.012870265636593103, 0.11785460956161842, 0.10253956104861572, 0.1313780838972889, 0.10465690094861202, 0.08513864711858332, 0.023063855078362394, 0.2608212403720245, 0.7390738790854812, 0.46654092497192323, 1.7754031950607896, 56.21186949312687, 54.9347960203886, 62.00324513018131, 59.40918892621994, 63.127281814813614, 68.69285836815834, 60.36916561424732, 47.917397171258926, 38.3948877453804, 37.93035127222538, 41.02442644536495, 43.70506100356579, 50.46790771186352, 52.60641396045685, 51.27403825521469, 59.60991695523262, 68.52236911654472, 68.59812185168266, 63.8232296705246, 67.05168843269348, 74.79344621300697, 73.14026892185211, 71.69629320502281, 70.35437241196632, 71.51353821158409, 74.41740319132805, 71.94111406803131, 69.1353902220726, 70.64699470996857, 71.73417717218399, 67.36447244882584, 70.86900159716606, 65.2879598736763, 66.47652089595795, 66.53782680630684, 71.24587297439575, 74.94717836380005, 58.77051159739494, 64.93060424923897, 75.45944407582283, 69.01438191533089, 72.04566925764084, 69.84856635332108, 68.13450112938881, 63.303527757525444, 58.37068185210228, 56.87355078756809, 58.98959644138813, 53.02794434130192, 55.17855294048786, 54.09901186823845, 57.11411587893963, 49.19502541422844, 49.61687117815018, 49.55839991569519, 61.93199895322323, 61.71102561056614, 61.09582722187042, 62.946552112698555, 61.857633143663406, 63.62530969083309, 58.57081711292267, 50.704828798770905, 48.17623928189278, 46.416884288191795, 50.32033123075962, 49.8055462539196, 48.17046359181404, 50.33162422478199, 52.985075041651726, 57.27486625313759, 58.355475068092346, 57.962747141718864, 60.40777914226055, 50.65633960068226, 53.43832232058048, 62.513667941093445, 61.70218348503113, 60.730423629283905, 54.69835750758648, 56.23936101794243, 60.479333102703094, 64.77631732821465, 61.25758074223995, 60.97041875123978, 58.52700166404247, 60.96801348030567, 57.582053169608116, 60.765100568532944, 57.95315645635128, 59.48960021138191, 59.79453764855862, 62.02880255877972, 62.750532031059265, 62.464479580521584, 61.586483493447304, 60.68237900733948, 62.35773950815201, 59.5388987660408, 62.10084289312363, 70.3721934556961, 65.76609581708908, 66.1913537979126, 65.00696495175362, 62.526667043566704, 57.715714797377586, 62.79179781675339, 47.451325580477715, 42.534552812576294, 30.82335703074932, 60.37687540054321, 53.24075572192669, 38.20701062679291, 41.475963816046715, 33.77498924732208, 43.066319078207016, 48.44192862510681, 38.55032600462437, 24.48762070387602, 3.440122604370117, 0.2904976479476318, 0.8086383494082838, 0.33358662331011146, 0.07124482624931261, 0.04771003579662647, 0.06580876521184109, 0.07129528486984782, 0.12615103390999138, 1.4934716233983636, 28.17455716431141, 54.53345015645027, 41.73087693750858, 40.22187910974026, 1.1516150110401213, 0.14985267771407962, 0.11830032119178213, 0.025815684857661836, 0.01369836978483363, 0.08612917677965015, 0.06969011592445895, 0.024944717042671982, 0.009727191372803645, 0.01211830769534572, 0.07449441633070819, 0.09057963601662777, 0.03445980910328217, 0.041739149746717885, 0.017245819908566773, 0.014568516598956194, 0.001878120076526102, 0.09068171100807376, 0.1557405063067563, 0.010466655257914681, 0.05635953690216411, 0.08246154975495301, 0.0751040164323058, 0.10102034764713608, 0.5910275294445455, 16.581345051527023, 71.42836198210716, 45.94627574086189, 51.12282536923885, 30.27419339865446, 74.08426746726036, 6.217651488259435, 0.07877929499954917, 0.12006731543806382, 0.0805804503033869, 0.04363468768133316, 0.14858278882456943, 0.33425722795072943, 0.18186405999585986, 0.2129939044243656, 2.639994313940406, 1.2877329695038497, 2.742316173389554, 67.94872149825096, 64.2992377281189, 70.52313655614853, 69.69092801213264, 69.75439980626106, 72.74729400873184, 67.35634848475456, 56.28693446516991, 49.576103165745735, 50.83223216235638, 52.465487122535706, 56.96801371872425, 61.84032127261162, 63.410906195640564, 60.56043215095997, 67.20495700836182, 71.07331663370132, 74.90007609128952, 66.72058179974556, 71.95423096418381, 77.14974537491798, 77.27462947368622, 75.91537401080132, 74.6104708313942, 75.6090572476387, 73.75393599271774, 74.20779123902321, 75.04034176468849, 72.30130434036255, 74.42554995417595, 71.68576017022133, 73.20944041013718, 66.7787566781044, 71.30515739321709, 71.23040780425072, 75.9626966714859, 74.00399297475815, 62.60994717478752, 70.68582862615585, 77.86400064826012, 70.10316789150238, 74.96924757957458, 73.37601587176323, 71.21117323637009, 63.18476513028145, 58.58434818685055, 59.882715716958046, 62.055796310305595, 55.598122626543045, 55.026834681630135, 55.944329649209976, 59.2319056391716, 51.97410508990288, 50.53353779017925, 51.448494493961334, 61.43544539809227, 64.10001441836357, 64.57162231206894, 67.97091230750084, 67.13267728686333, 67.3336561024189, 62.79543802142143, 54.175197780132294, 49.016442596912384, 47.6762431114912, 53.32025125622749, 51.73775017261505, 49.78704124689102, 51.08646512031555, 55.220145508646965, 60.46843148767948, 59.6459998190403, 56.07912741601467, 63.605649545788765, 56.20485506951809, 56.09168194234371, 66.38488501310349, 65.85977599024773, 64.58922296762466, 59.2132980376482, 56.08365297317505, 58.813510090112686, 63.603677451610565, 63.368416875600815, 64.31967303156853, 60.07938556373119, 62.72870980203152, 61.97453387081623, 62.93611027300358, 60.54167255759239, 60.117683708667755, 60.882917046546936, 63.976612240076065, 64.32287245988846, 61.78923301398754, 65.24329707026482, 59.77633662521839, 61.249737963080406, 59.185646921396255, 62.678449898958206, 68.69937121868134, 65.38157925009727, 65.7160297036171, 62.55861572921276, 62.006429359316826, 58.922089263796806, 64.46734070777893, 52.22333751618862, 48.91906142234802, 36.81637264788151, 63.82721945643425, 68.78604456782341, 53.65921966731548, 58.92829433083534, 52.161856815218925, 49.25982713699341, 54.959658086299896, 56.4389681071043, 31.34154662489891, 4.796658838167787, 0.11369461950380355, 0.9320857690181583, 0.095354636432603, 0.10808503691805527, 0.10690719660487957, 0.14404845947865397, 0.056090942525770515, 0.12596561573445797, 1.8625865480862558, 32.97307647764683, 50.88801696896553, 39.919327944517136, 50.99490903317928, 1.2915516458451748, 0.19829329481581226, 0.10169501925702207, 0.01942765615240205, 0.12607488955836743, 0.030764819093747064, 0.025909976575348992, 0.05504714521521237, 0.04853309983445797, 0.021379790268838406, 0.015468426317966077, 0.0715181369741913, 0.023269995872396976, 0.2302412234712392, 0.13257080427138135, 0.10503289522603154, 0.05246038577752188, 0.16960896056843922, 0.30473171384073794, 0.22947378340177238, 0.17439000948797911, 0.18112850259058177, 0.3822274273261428, 0.32374316244386137, 0.8549130382016301, 20.269193463027477, 85.1858201622963, 48.06134104728699, 58.85983720421791, 34.709043726325035, 86.46449714899063, 8.341149967163801, 0.16084017406683415, 0.2973113948246464, 0.3471689351135865, 0.4091768281068653, 0.3310836263699457, 0.9142779058311135, 0.42413540824782103, 1.0961601929739118, 6.060875225812197, 2.066201353445649, 5.062111644074321, 86.31658628582954, 73.83421808481216, 81.31825089454651, 76.83099567890167, 77.31083393096924, 81.8024817109108, 77.27076128125191, 66.96910366415977, 65.29923006892204, 62.587809562683105, 64.00254964828491, 68.97918060421944, 70.59345558285713, 75.63236519694328, 71.13849833607674, 77.56326198577881, 73.82339626550674, 79.06735047698021, 73.72262567281723, 77.99153700470924, 83.43487411737442, 82.25509062409401, 80.41456058621407, 80.07064864039421, 78.31913262605667, 77.69383057951927, 79.57417488098145, 78.44921484589577, 76.22685089707375, 78.09340193867683, 74.00922149419785, 77.60420098900795, 70.18140569329262, 73.91531333327293, 73.24306100606918, 76.00398525595665, 78.1815268099308, 67.09833472967148, 69.64928984642029, 80.33205941319466, 71.00686579942703, 78.01951870322227, 74.40959841012955, 72.62778282165527, 65.4877607524395, 64.69459131360054, 61.42854876816273, 66.95662513375282, 60.37702739238739, 60.48300750553608, 59.83613781630993, 63.93133386969566, 53.9964135736227, 55.02287909388542, 54.57811675965786, 68.38971063494682, 68.76149028539658, 66.47400543093681, 70.96574440598488, 67.59505167603493, 70.35942614078522, 66.27520009875298, 57.77631014585495, 52.97937534749508, 50.82889974117279, 55.673901960253716, 54.31227162480354, 53.54041904211044, 56.655564084649086, 58.820995688438416, 67.0911455154419, 65.31828224658966, 63.01381230354309, 68.66947442293167, 57.49804347753525, 61.169060692191124, 70.48361107707024, 68.84320110082626, 65.83249345421791, 59.925471022725105, 60.31063735485077, 65.53789526224136, 67.74373009800911, 65.2942143380642, 67.66616106033325, 62.88834683597088, 66.22558996081352, 64.84620317816734, 67.97734156250954, 62.50432804226875, 63.34114953875542, 65.76038092374802, 69.19896841049194, 67.51720145344734, 65.61769858002663, 66.88037842512131, 62.792352586984634, 66.6066487133503, 64.12210643291473, 68.76093551516533, 73.5776786506176, 72.707639336586, 72.89305418729782, 71.56972959637642, 66.57783105969429, 65.10577484965324, 70.83496302366257, 59.28340047597885, 54.345459043979645, 44.57083314657211, 68.62372487783432, 65.0811217725277, 52.136869356036186, 55.49401581287384, 54.2228814214468, 54.72054451704025, 64.07018601894379, 62.74777717888355, 38.57708036899567, 5.920430012047291, 0.6123851740267128, 1.5159819717518985, 0.533803787548095, 0.17345270665828139, 0.283622985589318, 0.42955436278134584, 0.15497165615670383, 0.3099314676364884, 6.499516563490033, 40.313811376690865, 67.16132014989853, 57.181505262851715, 55.281561613082886, 2.1330927265807986, 0.29141283477656543, 0.332441667560488, 0.1474221737589687, 0.2454883061000146, 0.147753334895242, 0.19327039481140673, 0.13171530095860362, 0.16633254184853286, 0.08853042527334765, 0.13691870612092316, 0.204944615252316, 0.1236923951364588], [0.019124405334878247, 0.02345057338970946, 0.05865698120032903, 0.05735437844123226, 0.06232667510630563, 0.06810860664700158, 0.09540199287584983, 0.1213657992775552, 0.0801541458349675, 0.026983402276528068, 0.10972136122290976, 0.20652721548685804, 24.803397059440613, 56.502770483493805, 42.32288897037506, 35.10317377746105, 46.4106260240078, 53.37228186428547, 0.9027614956721663, 0.04391352369566448, 0.08269350801128894, 0.14377975749084726, 0.17410447559086606, 0.227467832446564, 1.56599702546373, 0.29854805034119636, 0.2662960340967402, 1.7427342105656862, 0.7247130840551108, 10.584847871214151, 67.36252695322037, 59.95946779847145, 67.29159235954285, 73.74300017952919, 74.63167369365692, 58.92939627170563, 43.927455469965935, 44.26352083683014, 48.039188235998154, 54.01736944913864, 60.34825533628464, 59.28787283599377, 63.98504018783569, 55.09122982621193, 54.726198613643646, 61.25253841280937, 58.183085918426514, 76.08608365058899, 61.375636607408524, 67.74559959769249, 68.53748470544815, 75.20806476473808, 70.69902151823044, 71.46408766508102, 68.1416067481041, 71.96262091398239, 71.37083306908607, 72.05410480499268, 68.37866842746735, 69.37667727470398, 70.04079803824425, 69.1395092010498, 64.63217586278915, 72.08823457360268, 70.52438288927078, 74.17699009180069, 61.81190639734268, 69.83878567814827, 74.683708101511, 68.3142314851284, 76.12732663750648, 74.69392195343971, 69.00695711374283, 62.228345051407814, 52.73895464837551, 56.990801095962524, 56.76343269646168, 55.27315266430378, 51.83677285909653, 52.02486276626587, 51.67753480374813, 56.64603799581528, 53.879372254014015, 50.01912519335747, 48.49340446293354, 57.18763053417206, 61.44330337643623, 61.65666192770004, 65.66810667514801, 63.83195400238037, 60.273118168115616, 60.57362124323845, 48.93089398741722, 46.683770567178726, 46.90291240811348, 49.37538653612137, 50.63311904668808, 48.141072168946266, 48.722494170069695, 49.539632722735405, 52.08520732820034, 57.77912959456444, 60.72470873594284, 59.3434714525938, 56.28762222826481, 50.15062853693962, 56.75327204167843, 63.07533860206604, 62.874580174684525, 63.041144236922264, 60.041573792696, 54.72332216799259, 57.62975201010704, 65.046057254076, 59.433230236172676, 61.49216115474701, 59.457446336746216, 61.14935874938965, 56.90096251666546, 58.22887346148491, 56.603210493922234, 57.22558289766312, 57.413019239902496, 62.19021029770374, 61.12361513078213, 64.8838971555233, 58.44844847917557, 64.75603401660919, 60.671408995985985, 59.01780232787132, 68.3214282989502, 64.70623388886452, 63.935004472732544, 61.1653520911932, 60.69183669984341, 58.25506165623665, 58.99582430720329, 51.02870061993599, 46.08351297676563, 38.300280421972275, 40.492192804813385, 55.874063819646835, 42.48128727078438, 41.97763189673424, 41.54048055410385, 41.53987258672714, 49.93620604276657, 44.756384789943695, 29.278515726327896, 5.7344090938568115, 0.1208613911876455, 0.44250466162338853, 0.1839095080504194, 0.1129578598192893, 0.12701262283371761, 0.08407914967392571, 0.04444664918992203, 0.03310668464109767, 0.006027960453138803, 13.09720940887928, 53.3204260468483, 28.48478201776743, 42.02676706016064, 4.396050134673715, 0.26276079879608005, 0.15771746897371486, 0.013541797034122283, 0.22513091331347823, 0.07456654566340148, 0.20225210348144174, 0.04491151194088161, 0.031051484766067006, 0.03907276528479997, 0.04235965199768543, 0.02400407083769096, 0.06667654364719056, 0.040010305601754226, 0.035274160327389836, 0.05614679284917656, 0.053157073198235594, 0.07269612571690232, 0.017167365622299258, 0.057474561835988425, 0.097463055717526, 0.05180843501875643, 0.04674680603784509, 0.13206170580815524, 0.15119256597245112, 30.498069785535336, 66.16910979151726, 56.24915689229965, 31.2541551142931, 44.964864403009415, 61.779547333717346, 1.765112872235477, 0.0495571151986951, 0.13202917005401105, 0.09326153507572599, 0.013125800069246907, 0.18608950747875497, 2.1478337980806828, 0.43438642693217844, 0.7686563604511321, 3.3245066832751036, 1.5209269314073026, 12.626133486628532, 78.52915495634079, 67.41952389478683, 73.31249848008156, 76.35534480214119, 78.69177863001823, 66.55308678746223, 52.47917398810387, 58.77366162836552, 59.134915843605995, 65.9178900718689, 68.72547581791878, 68.4142193198204, 70.64373448491096, 64.59021851420403, 61.23170033097267, 68.81912559270859, 63.661696538329124, 76.51887282729149, 68.3806823194027, 73.78962367773056, 71.3329567015171, 78.41645300388336, 71.53122246265411, 74.62190821766853, 72.70246401429176, 74.67961952090263, 74.94328737258911, 77.28223666548729, 71.82320639491081, 71.74400344491005, 71.46805465221405, 70.09690582752228, 68.83735701441765, 74.65482205152512, 73.9057606458664, 73.310476988554, 63.8908888399601, 74.97057750821114, 74.60585787892342, 72.65757322311401, 77.59283199906349, 75.74927732348442, 71.30323469638824, 63.10381427407265, 57.173024117946625, 59.275797083973885, 60.68047150969505, 57.45359346270561, 54.504830092191696, 53.9851775765419, 55.45742757618427, 58.25109086930752, 54.32386480271816, 51.41119949519634, 50.53938947618008, 57.5236427038908, 63.697756603360176, 66.79343909025192, 69.50286850333214, 69.47013705968857, 63.62005077302456, 64.95276466012001, 52.62724444270134, 47.03254625201225, 48.249795734882355, 50.91646984219551, 51.842738538980484, 51.02818004786968, 49.34837758541107, 51.03742495179176, 53.06141294538975, 57.03145131468773, 61.193440183997154, 61.86758480966091, 61.798360124230385, 55.13675898313522, 58.43435503542423, 65.99622666835785, 64.22121271491051, 65.58721661567688, 64.19370219111443, 57.77416706085205, 58.46457481384277, 66.97649046778679, 62.08765000104904, 63.30038532614708, 63.2426056265831, 61.670136004686356, 62.81406082212925, 62.56995432078838, 59.680528566241264, 60.29830701649189, 60.0516090542078, 63.834066689014435, 65.68801000714302, 66.71516329050064, 61.40624016523361, 66.54829144477844, 61.92979887127876, 57.772677540779114, 66.7504633963108, 64.48690965771675, 64.26317766308784, 61.35058835148811, 62.06887900829315, 61.08568176627159, 59.69415843486786, 58.65646831691265, 52.134236097335815, 45.73803931474686, 46.02076694369316, 68.7291844189167, 60.571348965168, 56.85490898787975, 58.628182634711266, 52.887925654649734, 50.994225069880486, 59.49340000748634, 41.209662705659866, 8.083399347960949, 0.40880747605115175, 0.39491506526246667, 0.2214885564171709, 0.05205340312386397, 0.053820764733245596, 0.013000738908885978, 0.08909564494388178, 0.07516744779422879, 0.08815744411549531, 15.085341576486826, 55.33619128167629, 26.594440452754498, 56.29724331200123, 6.66844267398119, 0.3644580964464694, 0.23110024456400424, 0.04128192740608938, 0.22235951124457642, 0.038420306154876016, 0.08222893840866163, 0.015763016272103414, 0.02577775183453923, 0.06823497955338098, 0.02416359548078617, 0.014723898202646524, 0.05270029614621308, 0.121594774100231, 0.17520796012831852, 0.21936098230071366, 0.1015265443129465, 0.11871761598740704, 0.1218617765698582, 0.1318113793968223, 0.27843166259117424, 0.15641232806956396, 0.135154650779441, 0.2747961779823527, 0.5251819314435124, 38.083209469914436, 77.78831630945206, 55.18413104116917, 47.6822429895401, 59.76052567362785, 74.28437232971191, 3.352407398633659, 0.20460549829294905, 0.35148977825883776, 0.26075993897393346, 0.3949184197699651, 1.059359167702496, 3.819509921595454, 1.340499788057059, 1.053332097362727, 5.383951524272561, 4.608958410099149, 19.666910581290722, 92.7162104845047, 77.27165803313255, 84.95255827903748, 82.25425466895103, 87.1112908422947, 78.06531384587288, 62.09389306604862, 66.96838170289993, 66.47563934326172, 72.05089017748833, 74.78992760181427, 77.20780625939369, 79.5157416164875, 75.99891632795334, 70.85618108510971, 75.14881834387779, 69.34886276721954, 83.47879216074944, 71.17725625634193, 78.36995109915733, 75.33624708652496, 84.56831529736519, 77.68067568540573, 81.58367425203323, 76.11959785223007, 77.91478872299194, 77.08009511232376, 80.72292923927307, 75.00029191374779, 73.91695484519005, 74.44037675857544, 76.04249998927116, 70.95202714204788, 78.61480236053467, 74.87732291221619, 79.67049211263657, 68.61123874783516, 76.78957030177116, 78.99780660867691, 74.13365721702576, 80.2555239200592, 80.74518844485283, 73.9802822470665, 69.2144487798214, 56.830924674868584, 61.63802772760391, 63.64470385015011, 62.468442767858505, 59.02939170598984, 59.60669472813606, 57.99563817679882, 62.343269884586334, 58.35062272846699, 54.76159751415253, 54.72648359835148, 62.947623655200005, 68.8774448633194, 68.45171570777893, 75.10343357920647, 72.9113844037056, 65.06048887968063, 66.0464371740818, 52.79221639037132, 51.39356084167957, 50.5551016330719, 54.67360183596611, 57.414356768131256, 53.04539680480957, 53.82604971528053, 54.531782045960426, 58.45291703939438, 65.82589700818062, 68.21521639823914, 66.77628681063652, 65.01162350177765, 56.395692229270935, 63.342160284519196, 68.74198973178864, 66.45271897315979, 71.15650177001953, 64.48498696088791, 59.00059685111046, 64.31557685136795, 70.28006359934807, 65.42349100112915, 67.46985599398613, 66.08612224459648, 66.66811421513557, 64.53825250267982, 63.27357776463032, 61.80270329117775, 63.25151614844799, 62.625385746359825, 65.93355283141136, 69.5295050740242, 71.08706429600716, 65.02863138914108, 70.72071835398674, 67.10417121648788, 64.40893784165382, 74.83862578868866, 71.53445228934288, 73.79601493477821, 69.68984887003899, 69.67249900102615, 66.28764823079109, 66.75101816654205, 64.82311561703682, 56.531189158558846, 51.2879379093647, 52.57874384522438, 65.9046059846878, 56.874926313757896, 52.0715394616127, 55.53220376372337, 56.772673800587654, 56.40125513076782, 63.354825004935265, 46.47466018795967, 11.258563119918108, 0.9963815845549107, 0.4926306218840182, 0.39691028476227075, 0.19662101345602423, 0.12983220512978733, 0.2505709935212508, 0.21749201696366072, 0.324524495517835, 1.2801595008932054, 20.713516920804977, 66.57263293862343, 39.970040023326874, 60.667962580919266, 7.728681256994605, 0.7401286787353456, 0.3378887346480042, 0.1719249808229506, 0.3311961062718183, 0.1199737009301316, 0.20672980695962906, 0.1167522901960183, 0.10355103411711752, 0.12310498525039293, 0.15488399367313832, 0.11106257792562246, 0.22505223081680015], [0.04411817091749981, 0.045793027529725805, 0.07111535116564482, 0.04781649688084144, 0.09407886973349378, 0.0169848121367977, 0.0494931977300439, 0.05021856544772163, 0.019410879904171452, 0.029279781592777, 0.0678177441295702, 0.6938062550034374, 55.766411796212196, 38.96420359611511, 30.272162407636642, 48.421257734298706, 50.01788645982742, 37.81668037176132, 0.5841972178313881, 0.09912381152389571, 0.08127321547362953, 0.25500960065983236, 0.09836366676609032, 0.06820650334702805, 1.035698668565601, 0.31954726728145033, 0.0766039191512391, 0.7534590165596455, 1.331584753934294, 26.29292283207178, 67.90272116661072, 70.6422221660614, 78.15678253769875, 73.34396079182625, 55.50180919468403, 48.604696691036224, 59.34086099267006, 65.71561172604561, 74.06248703598976, 67.88554608821869, 69.60176199674606, 65.13539806008339, 59.67111647129059, 57.86153957247734, 49.42099168896675, 62.253727689385414, 65.16325816512108, 63.35531137883663, 73.19066181778908, 65.37720948457718, 72.42967665195465, 69.91196975111961, 70.49931183457375, 71.66255101561546, 68.70113432407379, 75.35553485155106, 71.14593833684921, 71.72350734472275, 68.562912940979, 69.92932721972466, 62.58940547704697, 67.84360393881798, 69.99677360057831, 73.2294349372387, 73.71972262859344, 64.07304346561432, 70.50917610526085, 76.86311155557632, 67.43549063801765, 72.65137195587158, 71.56522303819656, 72.16862305998802, 59.88425463438034, 53.128289356827736, 58.88511344790459, 60.06111994385719, 58.96072179079056, 51.936053931713104, 54.215904995799065, 50.24541065096855, 53.62668201327324, 55.366635248064995, 52.58036255836487, 48.5759474337101, 49.015029072761536, 55.82568481564522, 61.05598635971546, 65.28609037399292, 65.73080331087112, 60.56472972035408, 59.94674228131771, 62.10347235202789, 48.49366284906864, 46.24252684414387, 47.75039233267307, 50.792030319571495, 50.65698176622391, 48.10262203216553, 47.566858381032944, 47.1827407926321, 47.62942582368851, 51.58480457961559, 56.10347270965576, 59.86139126121998, 58.419239446520805, 58.47655937075615, 49.20637160539627, 59.14661541581154, 63.534604758024216, 61.0845760256052, 62.62814059853554, 64.75866347551346, 56.32074125111103, 58.94160121679306, 61.210094690322876, 60.54384604096413, 60.33289276063442, 58.74933533370495, 57.17920258641243, 59.618838876485825, 57.83662810921669, 57.54398301243782, 59.455747827887535, 59.08772997558117, 61.23072378337383, 61.2324982881546, 61.7891950160265, 63.80123645067215, 58.62480081617832, 58.506174981594086, 60.27899645268917, 60.41592210531235, 60.06381019949913, 64.53807771205902, 61.06186844408512, 56.691802740097046, 57.47025556862354, 56.87667042016983, 53.797015473246574, 45.00168442726135, 47.95471116900444, 46.30088411271572, 49.09404583275318, 44.015196561813354, 41.44289419054985, 41.48656524717808, 44.90025646984577, 50.53815074265003, 36.27872809767723, 10.82661084830761, 0.4578954091994092, 0.5184920341707766, 0.802049384219572, 0.12779086857335642, 0.027655281555780675, 0.1409697488998063, 0.03748508504941128, 0.09601456898963079, 0.0763843250751961, 1.8448582431301475, 48.50407809019089, 27.291457951068878, 30.01468252390623, 18.022237233817577, 0.38167298363987356, 0.4374204750638455, 0.07461161629180424, 0.28642254474107176, 0.09151278281933628, 0.20828260254347697, 0.04549934485112317, 0.07465788919944316, 0.017222282695001923, 0.027309963952575345, 0.09747160525876097, 0.009200061504088808, 0.05969776910205837, 0.045121369039407, 0.06408636661944911, 0.07365799363469705, 0.020452422941161785, 0.0526220552274026, 0.03880946613207925, 0.05584560705756303, 0.06696446725982241, 0.08648484363220632, 0.05728673168050591, 1.6499029356054962, 62.061412408947945, 53.47921572625637, 38.01094874739647, 34.920703768730164, 58.15173760056496, 41.597302705049515, 1.3092016987502575, 0.13480873574735597, 0.07973927786224522, 0.111366019846173, 0.20618180511519313, 0.15011459647212178, 1.6922060656361282, 0.3407755703665316, 0.31855923123657703, 0.9204567898996174, 2.385345040820539, 30.61212256550789, 79.30154711008072, 74.2669540643692, 77.52288535237312, 78.21086883544922, 63.98595213890076, 58.75510722398758, 65.10123789310455, 69.42128688097, 76.67866185307503, 73.44815880060196, 73.33159625530243, 73.31863135099411, 66.34846776723862, 65.27874916791916, 58.90300288796425, 66.40139892697334, 69.6315447986126, 68.57986003160477, 75.16600102186203, 71.06769293546677, 74.07696425914764, 72.01079472899437, 74.5265181362629, 74.71425846219063, 73.37698861956596, 73.55284318327904, 74.27478164434433, 74.58469301462173, 71.44119769334793, 72.72519439458847, 67.02140405774117, 72.50580936670303, 72.69647553563118, 76.81302264332771, 73.35185676813126, 65.8910559117794, 74.22332480549812, 75.1473668217659, 70.19308626651764, 75.73924586176872, 73.15387219190598, 72.18401223421097, 60.704509019851685, 59.01887767016888, 61.6739472001791, 59.42838169634342, 59.70425829291344, 55.65852798521519, 56.633757054805756, 54.07977730035782, 56.66431121528149, 59.12210673093796, 52.86134988069534, 48.81480261683464, 51.82117089629173, 57.31281101703644, 62.78919115662575, 66.1997589468956, 68.43660771846771, 64.59365352988243, 65.5582469701767, 64.49717670679092, 49.40952390432358, 47.17624694108963, 47.63145491480827, 53.61984618008137, 53.81489351391792, 49.09617751836777, 49.89642597734928, 51.53210900723934, 51.00425273180008, 53.271648064255714, 59.2416825145483, 62.34521917998791, 61.882233023643494, 63.469073474407196, 55.35587802529335, 59.69655990600586, 67.04396724700928, 63.40046055614948, 64.23679947853088, 65.66034749150276, 60.65492928028107, 57.9163022339344, 62.444466054439545, 63.64995896816254, 64.38791736960411, 62.95792110264301, 61.07813537120819, 62.242932468652725, 61.51775278151035, 57.742484360933304, 62.04766094684601, 60.74663355946541, 62.84410201013088, 63.38947534561157, 64.33437824249268, 65.1257161796093, 62.56795562803745, 56.56495414674282, 60.085579231381416, 61.2722023576498, 59.633623883128166, 65.12095123529434, 61.76461413502693, 56.82449921965599, 60.68881966173649, 60.83485722541809, 59.801191091537476, 49.48321335017681, 51.2222546339035, 58.35673280060291, 66.08532428741455, 60.41739262640476, 58.41985501348972, 54.645521342754364, 47.116457149386406, 57.54254288971424, 49.34159874916077, 15.824099835008383, 1.1911762319505215, 0.29251706146169454, 0.9226022497750819, 0.027019912231480703, 0.046102848209557123, 0.10841504030395299, 0.24974744708742946, 0.14033634070074186, 0.18653215403901413, 1.4867987064644694, 52.42398954927921, 27.5823912397027, 42.05519713461399, 25.742149986326694, 0.6103710446041077, 0.293421798851341, 0.0694415632460732, 0.2591569593641907, 0.09550477290758863, 0.21006599825341254, 0.03045995039428817, 0.039523111627204344, 0.01707479197648354, 0.07893206609878689, 0.04181031799816992, 0.021731753804488108, 0.1642580609768629, 0.19110277440631762, 0.1402579402201809, 0.11715946209733374, 0.22398631379473954, 0.16936816333327442, 0.1140981177741196, 0.2523375127930194, 0.18518042110372335, 0.22477444494143128, 0.15107432700460777, 1.4672394935041666, 78.01935911178589, 56.66362725198269, 39.97440218925476, 69.72417622804642, 66.02307602763176, 53.794066831469536, 2.009702897630632, 0.19538318534614518, 0.1942851481726393, 0.3237383533269167, 0.38347162306308746, 0.31441433646250516, 2.8068260243162513, 0.9488656092435122, 0.6973132293205708, 1.9878012291155756, 3.92629511654377, 39.27247725427151, 93.76599535346031, 78.61826777458191, 86.9501642882824, 84.29107457399368, 73.8579212129116, 67.13442519307137, 69.60852563381195, 74.80587154626846, 83.13280552625656, 81.3492040336132, 78.50563421845436, 80.75822934508324, 75.51791533827782, 77.55558639764786, 68.02204996347427, 74.72523227334023, 75.5832490324974, 76.55300259590149, 79.53053802251816, 75.69053247570992, 78.10968786478043, 78.46058383584023, 78.55459839105606, 81.27386167645454, 73.65315780043602, 79.94460180401802, 77.93998137116432, 79.4227834045887, 74.84687134623528, 77.16274827718735, 69.78208512067795, 74.25431594252586, 73.65041434764862, 79.44239795207977, 78.06017652153969, 70.9311206638813, 77.00682744383812, 80.30726194381714, 71.67629107832909, 77.12499350309372, 78.08192655444145, 77.65512585639954, 65.3536431491375, 57.64391005039215, 65.1989458501339, 64.06098291277885, 64.72595483064651, 60.05294278264046, 60.14412268996239, 55.94049945473671, 60.65842889249325, 62.829149812459946, 56.49068333208561, 54.26801159977913, 55.59901177883148, 62.5646498054266, 68.32730278372765, 69.77987363934517, 70.61737149953842, 65.82435429096222, 68.10658782720566, 67.68870145082474, 51.93590193986893, 49.55187566578388, 51.05165898799896, 56.431391313672066, 56.69282868504524, 52.68836796283722, 52.55825154483318, 54.643317461013794, 54.888757690787315, 58.90772983431816, 65.91770768165588, 67.2307500243187, 67.10729464888573, 66.28207013010979, 57.64932096004486, 65.62580734491348, 68.54544147849083, 64.38417837023735, 68.30337926745415, 70.02602443099022, 62.54066549241543, 63.339888006448746, 66.87888890504837, 68.34358870983124, 67.56279900670052, 65.6922809779644, 64.47287321090698, 66.25528156757355, 62.80251704156399, 61.5909406542778, 66.28281489014626, 63.83824646472931, 68.83905932307243, 68.46477180719376, 70.23839503526688, 70.33552542328835, 67.78967723250389, 62.42766335606575, 68.11285749077797, 69.2259469628334, 68.79604563117027, 74.16892692446709, 70.1356865465641, 66.7666657269001, 64.85599145293236, 62.252116575837135, 62.83188946545124, 53.8256773352623, 55.05485437810421, 63.17973040044308, 61.83214031159878, 57.83692829310894, 52.752660512924194, 55.3885068744421, 50.9032541513443, 61.46189197897911, 54.585666954517365, 17.90677472949028, 1.8649317347444594, 0.616232348838821, 2.2519095009192824, 0.22807401866884902, 0.12794412206858397, 0.569829773157835, 0.2286587716662325, 0.4244485648814589, 0.3723235853249207, 3.296513822861016, 64.63193267583847, 36.28439359366894, 47.26938374340534, 28.18895649164915, 0.6239646370522678, 0.40698170370887965, 0.25681910512503237, 0.25955118821002543, 0.2800814568763599, 0.38516556029208004, 0.20714776968816295, 0.17237058113096282, 0.10012288330472074, 0.11650631277007051, 0.14396478974958882, 0.09812597170821391], [0.06491576859843917, 0.025260441507271025, 0.0743835097819101, 0.045399088121484965, 0.11889592438819818, 0.13874009979190305, 0.09085198194952682, 0.16318555368343368, 0.06566553813172504, 0.06569090473931283, 0.12021627189824358, 20.61548788100481, 59.202024042606354, 26.67956918478012, 37.417139410972595, 33.11975620687008, 55.3929640352726, 18.397904075682163, 0.5738883116282523, 0.0246406647056574, 0.036989256186643615, 0.06648889160715044, 0.06186195707414299, 0.18863473262172192, 0.14572265557944775, 0.12644954054849222, 0.13984297576826066, 0.5829242267645895, 2.25114312954247, 28.010006994009018, 70.62316238880157, 79.3324926495552, 69.05696243047714, 52.77317941188812, 56.50924153625965, 68.6905100941658, 70.50302803516388, 65.99537551403046, 68.03097948431969, 66.95685312151909, 70.36683574318886, 69.0811975300312, 61.87055245041847, 52.459449246525764, 54.83651049435139, 54.901783391833305, 66.47658929228783, 64.06579345464706, 62.005338817834854, 66.48753270506859, 71.66428372263908, 69.3483915925026, 70.06094455718994, 70.90592041611671, 69.37882795929909, 68.22430551052094, 74.38632845878601, 68.84367227554321, 70.0362154841423, 65.53180798888206, 71.47381514310837, 68.73496010899544, 74.2215085029602, 73.60816821455956, 59.668927788734436, 68.65643352270126, 74.21377211809158, 70.11364012956619, 73.4287266433239, 72.85070925951004, 71.01890355348587, 62.34268471598625, 56.09718404710293, 65.1387494802475, 60.039692893624306, 56.64593540132046, 53.63512896001339, 51.37782968580723, 49.476776495575905, 52.25475423038006, 51.77654609084129, 55.386701971292496, 54.35569949448109, 49.87390838563442, 47.81859867274761, 50.500688552856445, 60.12995705008507, 63.46200205385685, 67.33378529548645, 64.42334666848183, 65.53386747837067, 55.273825228214264, 46.62604406476021, 44.74540717899799, 46.60760745406151, 50.83473242819309, 49.862231612205505, 49.58552286028862, 46.88294067978859, 47.70070239901543, 48.18655572831631, 48.69869604706764, 51.30818322300911, 52.49125733971596, 58.149651512503624, 59.267034754157066, 60.782260447740555, 53.783491998910904, 55.01458413898945, 64.21765610575676, 62.61555187404156, 60.946457237005234, 63.226308301091194, 55.62257431447506, 53.82865257561207, 63.27321298420429, 58.808038383722305, 61.77026443183422, 58.658505007624626, 57.96893700957298, 58.76943625509739, 59.27358940243721, 58.02330069243908, 58.28384891152382, 60.24181544780731, 61.86777099967003, 60.894886404275894, 59.48876045644283, 59.16488103568554, 61.87542378902435, 58.737909346818924, 55.74075557291508, 59.95482064783573, 59.17714677751064, 59.36794213950634, 55.76686017215252, 62.1185727417469, 63.13931576907635, 58.56043606996536, 49.614006131887436, 48.4263114631176, 43.35684768855572, 52.293512150645256, 49.60261054337025, 42.358257472515106, 41.48613967001438, 39.2241096496582, 47.74363249540329, 39.70033809542656, 13.94538564607501, 0.9973521949723363, 0.35164251225069165, 0.10599746456136927, 0.019636741417343728, 0.03684574709041044, 0.09234616270987317, 0.052174510492477566, 0.08406734952586703, 0.09928098355885595, 0.015616302953276318, 26.664018519222736, 47.96658933162689, 21.443007476627827, 43.754184767603874, 0.13809818658046424, 0.14929789263987914, 0.0474375191697618, 0.03245636660722084, 0.12624653347302228, 0.09529300848953426, 0.02582917524705408, 0.016703504770703148, 0.04951784445438534, 0.07835102383978665, 0.11675974135869183, 0.10138086072402075, 0.04358869307907298, 0.014771404930797871, 0.051597427591332234, 0.037648146026185714, 0.09780733802472241, 0.12658312713028863, 0.1366980210877955, 0.06120288169768173, 0.16676646075211465, 0.08771280859946273, 0.1410887745441869, 27.518571764230728, 70.04016727209091, 37.95413799583912, 32.775209695100784, 33.64353530108929, 60.9457428753376, 24.652790240943432, 1.3559898943640292, 0.06661093037109822, 0.14172403811244294, 0.03534794093866367, 0.19395646580960602, 0.09904525519232266, 0.11831084484583698, 0.1289631353574805, 0.465314065804705, 0.5929444672074169, 2.986226510256529, 34.448993280529976, 80.59558287262917, 83.0494911968708, 77.77628615498543, 62.42577105760574, 62.52001740038395, 72.84780621528625, 70.23116782307625, 69.36980724334717, 70.02988502383232, 73.22689667344093, 76.75995469093323, 75.62066942453384, 69.59765061736107, 61.30645751953125, 62.01045334339142, 59.657049626111984, 69.35938060283661, 70.56766256690025, 65.37436723709106, 70.1771879196167, 75.10794013738632, 71.73956528306007, 72.87562072277069, 74.64012444019318, 73.99249479174614, 72.83680960536003, 75.13899967074394, 71.92838475108147, 71.6974787414074, 67.14541420340538, 75.50946459174156, 70.1958829164505, 76.73577278852463, 74.10773500800133, 63.496169820427895, 72.83767595887184, 75.09050667285919, 72.56447821855545, 73.50305825471878, 74.9275030195713, 73.37506592273712, 61.332212537527084, 60.87282098829746, 67.33205258846283, 61.048280373215675, 60.009199529886246, 54.82995584607124, 54.535802230238914, 53.980370834469795, 57.08907522261143, 55.56614734232426, 58.8850412517786, 55.934142395853996, 50.95235511660576, 50.769227743148804, 48.596679121255875, 58.12037408351898, 64.59021851420403, 70.11177822947502, 66.8464994430542, 66.77389293909073, 56.77418991923332, 47.54762001335621, 48.32536607980728, 49.23458889126778, 50.5828857421875, 52.1981942653656, 51.935651153326035, 49.81156513094902, 49.55117650330067, 51.438143849372864, 52.876640260219574, 54.08898800611496, 56.71333998441696, 60.26225455105305, 63.27627182006836, 64.90200698375702, 57.69342139363289, 56.59071296453476, 66.34238049387932, 66.01537764072418, 63.12929190695286, 64.2089393734932, 60.332235395908356, 57.49170921742916, 67.376958578825, 63.375438898801804, 63.78586247563362, 61.60385616123676, 59.7605636715889, 61.417468562722206, 62.3670794069767, 58.5701597481966, 61.628091260790825, 62.641223296523094, 63.58601599931717, 64.87271815538406, 64.10370782017708, 61.83133475482464, 64.49090704321861, 59.99932385981083, 55.88165581226349, 61.900722831487656, 61.548059955239296, 59.89486746490002, 59.24034118652344, 63.18751238286495, 64.81192901730537, 61.52351327240467, 54.083968475461006, 51.300283446908, 49.451523050665855, 64.23654869198799, 64.97399792075157, 57.63549730181694, 57.21814289689064, 44.98130612075329, 51.351303309202194, 50.77681593596935, 17.48259589076042, 2.2868785494938493, 0.2761808771174401, 0.01613829066627659, 0.049438137793913484, 0.11813388715381734, 0.11384170575183816, 0.08301360372570343, 0.10454162314999849, 0.19525369541952386, 0.0931134691927582, 29.895372726023197, 48.12345631420612, 25.36890361458063, 55.41926622390747, 0.2183896445785649, 0.12401590473018587, 0.017166762627311982, 0.04025277266919147, 0.05052234875620343, 0.033472845461801626, 0.060391755105229095, 0.021649496011377778, 0.022480254265246913, 0.03690015022584703, 0.06808091711718589, 0.030053038244659547, 0.14818432973697782, 0.20376225525978953, 0.19872515054885298, 0.2634817804209888, 0.2728419844061136, 0.3656795230926946, 0.3325507929548621, 0.30540522770024836, 0.2749579958617687, 0.19667842600028962, 0.2643131936201826, 35.002152398228645, 82.75031805038452, 41.000898107886314, 52.319947332143784, 48.914406672120094, 66.40911251306534, 35.386798158288, 4.308944558724761, 0.11390145606128499, 0.45473668025806546, 0.18978348816744983, 0.3691574645927176, 0.30965256853960454, 0.7578991376794875, 0.40848018892575055, 0.7816817646380514, 2.832636614330113, 4.205586779862642, 41.877754256129265, 89.99322339892387, 86.1624513566494, 87.91570007801056, 69.40577611327171, 71.04104116559029, 75.70374816656113, 71.95325061678886, 73.89428526163101, 74.62407410144806, 81.07476755976677, 81.91465929150581, 83.88229250907898, 78.16256582736969, 73.56098234653473, 73.32354068756104, 71.39122277498245, 75.41538923978806, 75.94032347202301, 71.97633817791939, 74.19932529330254, 79.94075641036034, 79.82960477471352, 76.05390697717667, 77.92409062385559, 76.99528366327286, 76.23697355389595, 80.73562815785408, 75.35441011190414, 74.13697823882103, 69.47683990001678, 75.79673677682877, 71.27770006656647, 80.46284079551697, 79.27921950817108, 65.16337975859642, 73.98127019405365, 76.99286699295044, 74.71855983138084, 78.21691051125526, 77.90212020277977, 77.81777232885361, 67.85814195871353, 61.957902163267136, 70.06520792841911, 64.43397089838982, 61.54971286654472, 58.7166228890419, 57.73791700601578, 56.77580863237381, 61.858035922050476, 60.38796320557594, 63.277966529130936, 62.9995022714138, 55.34356288611889, 54.49998155236244, 52.98242658376694, 65.56042045354843, 70.2530774474144, 72.59662449359894, 70.79992890357971, 71.16509690880775, 60.533803179860115, 52.29589082300663, 49.00947377085686, 51.82902127504349, 54.96891438961029, 56.523049995303154, 55.762311816215515, 54.418810307979584, 53.9585942029953, 57.06169009208679, 55.881652012467384, 58.90431381762028, 61.812844946980476, 64.53511387109756, 66.79122760891914, 69.27703142166138, 59.50345806777477, 62.412198185920715, 68.78648534417152, 67.18960583209991, 66.89479485154152, 70.13338387012482, 62.60955959558487, 61.60849191248417, 69.31005924940109, 67.29655489325523, 67.4072277545929, 64.41102772951126, 65.20501032471657, 64.57768678665161, 63.81093353033066, 62.342927902936935, 65.83435535430908, 68.45127493143082, 70.58198779821396, 69.9012391269207, 69.19699251651764, 64.34933423995972, 69.81078118085861, 66.65866032242775, 65.8300843834877, 72.47626975178719, 70.6182986497879, 69.54832166433334, 66.65245905518532, 67.58950397372246, 69.61749315261841, 63.1296680867672, 55.314000472426414, 55.44965699315071, 55.33561371266842, 62.696259543299675, 62.62420400977135, 55.12019947171211, 55.84238111972809, 47.03184328973293, 54.82901729643345, 52.83588744699955, 20.500067174434662, 2.921394626609981, 0.7430397381540388, 0.3745873138541356, 0.1803573517827317, 0.19845769536914304, 0.21806934848427773, 0.2125903542037122, 0.3672996611567214, 0.22490613162517548, 0.509405059274286, 38.29456552863121, 62.413201332092285, 31.692809276282787, 60.28740920126438, 0.25681518658529967, 0.16685063514159992, 0.13283581036375836, 0.1194395252969116, 0.25327540934085846, 0.14616035943618044, 0.16340772301191464, 0.063971615745686, 0.15299519815016538, 0.2714327350258827, 0.23950012429850176, 0.15241216693539172], [0.15380885917693377, 0.03999859080067836, 0.06676307806628756, 0.04447087660082616, 0.019658176497614477, 0.45682811178267, 0.3050773171707988, 2.200774932280183, 1.103962599299848, 2.4546628212556243, 9.092637542635202, 58.900658413767815, 39.6515829116106, 36.15344122052193, 29.971858821809292, 45.68570852279663, 49.30088773369789, 4.090111926198006, 0.31817524402868, 0.2300535491667688, 0.061541865070466883, 0.024537903227610514, 0.04966617751051672, 0.029444594038068317, 0.1263997721252963, 0.2566103241406381, 0.2889837260590866, 0.5861813051160425, 0.8836305909790099, 36.488773226737976, 70.16625210642815, 63.86416867375374, 49.588992074131966, 67.60213449597359, 78.4494124352932, 74.03663322329521, 71.86792239546776, 66.68349578976631, 71.57234385609627, 67.43145525455475, 70.31621485948563, 66.26811727881432, 58.848282024264336, 52.591480761766434, 53.01388129591942, 53.00921894609928, 62.19302594661713, 66.1664043366909, 63.39912302792072, 65.28628036379814, 64.14939656853676, 70.35257890820503, 68.53704392910004, 69.59739223122597, 69.31661769747734, 71.2252476811409, 69.8008181154728, 70.62268361449242, 67.98881694674492, 69.93726119399071, 71.35453194379807, 69.16551500558853, 71.20373323559761, 60.61821945011616, 66.06093719601631, 75.84628611803055, 72.1281324326992, 67.83365607261658, 69.69570055603981, 70.1263390481472, 56.459578201174736, 57.86977373063564, 64.73701223731041, 62.16211840510368, 58.13639782369137, 54.647744223475456, 50.473094433546066, 51.228360906243324, 49.94451239705086, 52.121742367744446, 49.78601910173893, 51.37064807116985, 48.383749946951866, 48.37206557393074, 48.34659554064274, 48.462838903069496, 50.82982309162617, 54.31356355547905, 58.90431761741638, 58.458153158426285, 52.936760634183884, 47.854841127991676, 47.89866417646408, 46.72496035695076, 45.76784871518612, 47.64652110636234, 49.564046412706375, 51.33753664791584, 46.344509571790695, 48.44382852315903, 45.107607543468475, 47.30554260313511, 49.009754955768585, 51.53412289917469, 52.97948554158211, 56.9314406812191, 58.419813215732574, 61.0186343640089, 53.368463069200516, 53.76279450953007, 60.29892258346081, 62.684939950704575, 63.29571917653084, 63.30459550023079, 54.40999858081341, 55.50359509885311, 60.95938794314861, 58.59165899455547, 58.24202075600624, 56.721068769693375, 57.19510853290558, 61.83951571583748, 56.870621144771576, 58.714422807097435, 61.49014726281166, 60.98557993769646, 59.29421089589596, 60.97036935389042, 57.26660169661045, 58.61797638237476, 55.76614961028099, 54.79747138917446, 58.49496178328991, 55.01009277999401, 54.08519960939884, 59.6427433937788, 62.12797723710537, 62.389353811740875, 64.29693505167961, 51.385459676384926, 44.4162954390049, 44.477776139974594, 42.10174463689327, 53.260488063097, 43.40616524219513, 39.86816368997097, 37.7834777534008, 44.32809077203274, 44.26891274750233, 15.106004867702723, 1.5649571875110269, 0.5735856341198087, 0.23155109927756712, 0.03172934018948581, 0.07738013140624389, 0.05633687171211932, 0.09316331925219856, 0.0537517561315326, 0.04174743211478926, 0.06389641392161138, 8.343827873468399, 61.73725560307503, 23.304879069328308, 37.84805528819561, 20.327260047197342, 0.24910825013648719, 0.17896425153594464, 0.008916192800825229, 0.1417515124194324, 0.03665994299808517, 0.13897947210352868, 0.06982098624575883, 0.17709737905533984, 1.3971832464449108, 2.233535824343562, 1.542507754638791, 0.06613012999878265, 0.10496599803445861, 0.041536558273946866, 0.02957271284685703, 0.2125792219885625, 0.22985802293987945, 0.6076719425618649, 1.9725563284009695, 2.155251712538302, 2.3279120726510882, 12.720212638378143, 69.24934610724449, 51.80202752351761, 47.668483927845955, 31.419191658496857, 49.24762599170208, 51.15743771195412, 9.456143137067556, 2.4187564104795456, 0.1742377207847312, 0.25716224452480674, 0.014246448627091013, 0.05462206529045943, 0.057478717862977646, 0.08066329624853097, 0.8323725883383304, 0.4553545033559203, 0.7167158194351941, 1.3240669760853052, 45.43474718928337, 82.74299964308739, 74.2816972732544, 60.72897210717201, 68.98392274975777, 80.14028370380402, 78.5524933040142, 73.15160751342773, 69.20814111828804, 75.25896683335304, 75.91185539960861, 76.2677139043808, 70.24105489253998, 65.11241689324379, 60.117691308259964, 59.327128529548645, 58.43495160341263, 66.25878497958183, 69.5296722650528, 68.94007310271263, 68.09763550758362, 67.2491866350174, 71.34181022644043, 72.54949182271957, 72.93883413076401, 73.84077653288841, 74.40737932920456, 71.04402780532837, 73.12570050358772, 74.56925064325333, 73.57101380825043, 75.21246492862701, 73.0118054151535, 71.2814162671566, 63.57920676469803, 70.93434289097786, 76.53596431016922, 73.10392007231712, 70.49655318260193, 72.0715382695198, 68.72748970985413, 59.89859126508236, 61.22715577483177, 67.22649425268173, 65.2395960688591, 60.62656380236149, 54.46354150772095, 53.15556429326534, 54.622927755117416, 52.8969007730484, 55.823864713311195, 54.48370322585106, 52.302779853343964, 52.29841008782387, 50.87568663060665, 50.91748058795929, 51.22410513460636, 51.866981238126755, 53.83839525282383, 56.48991957306862, 56.766947507858276, 55.000619888305664, 50.51680348813534, 49.30457353591919, 48.304094821214676, 47.36374408006668, 49.49911169707775, 51.04503974318504, 53.41923214495182, 51.217162907123566, 50.34168988466263, 50.45423224568367, 50.49960941076279, 52.404568791389465, 56.2132678180933, 58.72904822230339, 60.00962510704994, 64.84760150313377, 64.61367085576057, 57.636462450027466, 54.78935122489929, 58.55145335197449, 64.24070566892624, 63.70889000594616, 64.5860767364502, 61.315216049551964, 57.64052823185921, 64.95838835835457, 62.070870101451874, 61.466140151023865, 61.02019988000393, 60.16353204846382, 60.47894172370434, 59.279843866825104, 61.02307632565498, 62.66022987663746, 62.84439459443092, 63.0830217897892, 63.57182756066322, 60.992738753557205, 62.34799303114414, 57.60658845305443, 57.380029410123825, 61.10722281038761, 57.74542920291424, 57.8962317109108, 62.568806782364845, 62.86200664937496, 64.78746592998505, 66.15987628698349, 55.78610993921757, 48.034696877002716, 49.32784728705883, 51.04721702635288, 67.37274080514908, 60.112041011452675, 55.837927758693695, 44.29422318935394, 47.86602012813091, 50.02951383590698, 18.533845581114292, 1.96653270162642, 0.6489163544028997, 0.4744092340115458, 0.1801047840854153, 0.06062619584554341, 0.026231050069327466, 0.04438767813553568, 0.15188853722065687, 0.03845479746814817, 0.073146446084138, 9.195854254066944, 68.2832707464695, 25.110914558172226, 46.38268992304802, 28.881729617714882, 0.213028562720865, 0.25736312905792147, 0.026953330452670343, 0.11911350724403746, 0.07269734283909202, 0.039565710903843865, 0.015389716918434715, 0.30367198633030057, 0.9941078815609217, 1.7282299138605595, 0.7890186365693808, 0.13265527551993728, 0.2757666993420571, 0.14862681302474812, 0.15363172336947173, 0.3786284860689193, 0.505454340018332, 2.4009771645069122, 5.22747497074306, 7.467653313651681, 8.042614236474037, 14.804814979434013, 87.25923970341682, 57.845447435975075, 51.941464841365814, 42.780300825834274, 62.85179279744625, 63.63124877214432, 15.644489172846079, 7.209756402298808, 0.343292371253483, 0.46957719954662025, 0.17767073266441002, 0.2661872352473438, 0.2870238327886909, 0.4819719266379252, 1.292507650796324, 0.9648307494353503, 2.4018359184265137, 1.799493902362883, 57.37964943051338, 87.63747900724411, 81.78715333342552, 71.40177860856056, 73.4680925309658, 86.01088508963585, 79.77571606636047, 75.85635557770729, 72.17365399003029, 80.90426310896873, 83.05657401680946, 82.79007151722908, 77.65021651983261, 73.12257707118988, 71.98726639151573, 69.97919574379921, 69.17194426059723, 74.2255362868309, 74.25067573785782, 74.6843084692955, 71.78517043590546, 72.0903168618679, 75.65881937742233, 76.12984970211983, 77.64963135123253, 77.70104259252548, 76.18477955460548, 75.08103758096695, 75.38986220955849, 75.88884383440018, 74.24638956785202, 79.12289589643478, 72.58812814950943, 74.78760972619057, 65.46490877866745, 71.69620960950851, 81.13904491066933, 77.17045426368713, 72.62250870466232, 76.37695044279099, 75.20372539758682, 65.90512275695801, 63.120388984680176, 69.79189619421959, 70.36993637681007, 64.73381280899048, 58.08773763477802, 55.467960610985756, 58.87686029076576, 57.96525500714779, 59.6363977342844, 58.951062709093094, 58.701628893613815, 56.73066325485706, 54.33098562061787, 55.48263542354107, 54.874907433986664, 55.624637603759766, 58.721068650484085, 64.45896595716476, 62.16914422810078, 59.02365021407604, 54.01301868259907, 51.88414491713047, 50.48162877559662, 50.80257475376129, 53.23395788669586, 53.86507362127304, 56.05933427810669, 52.389776185154915, 56.66239611804485, 52.29504346847534, 55.01708060503006, 56.27007856965065, 60.02729795873165, 62.20691800117493, 63.627122193574905, 68.2852466404438, 65.78910738229752, 59.266449585556984, 58.39013680815697, 64.2020009458065, 65.98130866885185, 67.13931933045387, 67.47307062149048, 63.64998936653137, 60.630318000912666, 68.03246140480042, 64.7023656964302, 65.14730662107468, 61.06877267360687, 62.270028814673424, 64.14921417832375, 61.04940511286259, 65.12223556637764, 65.28859823942184, 67.4065513908863, 66.34295806288719, 69.46631446480751, 65.28295174241066, 67.52381309866905, 65.88483184576035, 63.707385286688805, 70.08571922779083, 68.88539403676987, 63.18942368030548, 67.09614604711533, 65.35362794995308, 65.3548514842987, 67.6089209318161, 59.95500683784485, 50.69143071770668, 54.595177844166756, 55.83333760499954, 63.40641863644123, 57.39147059619427, 53.10479901731014, 46.27742797136307, 50.8470893651247, 52.61410094797611, 19.20586422085762, 2.5886215455830097, 1.9640711462125182, 1.1206864519044757, 0.5002104432787746, 0.21057203906821087, 0.1654505735496059, 0.17274024488870054, 0.22541563084814698, 0.20782227802556008, 0.2381088348920457, 13.574112318456173, 80.45720189809799, 37.61016145348549, 54.07951131463051, 29.71251893788576, 0.4559125687228516, 0.36893143609631807, 0.09955392320989631, 0.21628071321174502, 0.1907642066362314, 0.15603752864990383, 0.16851438180310652, 0.6843014212790877, 1.7684112139977515, 2.605442055501044, 1.7338740359991789], [17.06394575536251, 5.098301852121949, 1.9379196432419121, 0.05698826957086567, 0.8187786990310997, 1.7424244084395468, 4.448896748945117, 8.152098711580038, 3.8160722935572267, 1.559347144793719, 30.937480106949806, 48.074089363217354, 29.979011937975883, 25.76385822147131, 25.254685543477535, 63.2088178396225, 21.767705753445625, 0.3009107516845688, 1.0343991382978857, 0.3896094812080264, 0.03766225796425715, 0.11890077803400345, 0.04274862272723112, 0.1583111722720787, 0.03258855052990839, 0.595712618669495, 3.7039348483085632, 8.528901692479849, 4.680988769978285, 36.94537952542305, 50.24814650416374, 53.48260514438152, 73.37171450257301, 86.23321875929832, 84.58128020167351, 80.10423123836517, 82.39407196640968, 74.57422077655792, 70.86084723472595, 72.45993822813034, 73.03464978933334, 66.58331796526909, 63.02043914794922, 52.09458902478218, 53.793071284890175, 49.891858622431755, 61.69081449508667, 67.56579324603081, 63.13183017075062, 72.43697986006737, 68.32154229283333, 68.2286524772644, 69.97316926717758, 72.4870915710926, 71.5297557413578, 70.40727317333221, 69.87952709197998, 70.01251995563507, 70.41778340935707, 68.97401288151741, 74.46688413619995, 71.65696531534195, 62.28917598724365, 62.96721540391445, 69.89593461155891, 70.04240155220032, 70.68722695112228, 69.64976102113724, 65.31150341033936, 58.793785348534584, 59.848988726735115, 67.49754130840302, 61.795289888978004, 61.2991277128458, 52.19851724803448, 50.5253454297781, 55.012634843587875, 50.82397520542145, 47.5351756811142, 52.73998439311981, 50.58857403695583, 48.22433330118656, 47.133571431040764, 48.61537031829357, 47.479383274912834, 50.24924084544182, 51.50218941271305, 50.9566792845726, 51.53814688324928, 50.166830867528915, 47.1876235306263, 48.621571585536, 45.864127948880196, 46.567310616374016, 46.36513106524944, 48.83092135190964, 50.01848682761192, 49.8736310005188, 48.44311036169529, 45.27556233108044, 44.55714628100395, 48.051932752132416, 46.83163583278656, 51.09913744032383, 54.53634940087795, 56.59994266927242, 59.551540687680244, 60.52762471139431, 61.6203510761261, 58.5867952555418, 53.16721446812153, 55.539571568369865, 61.687132492661476, 62.50120460987091, 62.47868321835995, 54.92967389523983, 57.722231447696686, 60.1159206032753, 57.47466333210468, 60.10296329855919, 57.4666153639555, 56.141121089458466, 60.18202565610409, 57.18957222998142, 58.864985927939415, 59.76361110806465, 61.45637847483158, 61.63549326360226, 54.107986986637115, 55.12441724538803, 51.202241107821465, 50.58186359703541, 54.7514558583498, 53.896900713443756, 58.41199703514576, 64.08067345619202, 59.745520278811455, 62.471076026558876, 54.66238483786583, 53.94261606037617, 54.04390722513199, 49.47450041770935, 33.914654552936554, 48.963671028614044, 48.14721643924713, 35.44718071818352, 34.151640236377716, 35.91778166592121, 45.71918472647667, 15.849257335066795, 1.4525877172127366, 0.18628473684657365, 0.36588209972251207, 1.0010375222191215, 0.09223455112078227, 0.024149884302460123, 0.07556537995696999, 0.051743330113822594, 0.07875904921093024, 0.16162440151674673, 3.3796217758208513, 43.97103153169155, 68.75908881425858, 20.34126229584217, 52.16735891997814, 13.801054190844297, 0.17199840891407803, 0.10620534012559801, 0.05237424840743188, 0.06466985054430552, 0.08734320421353914, 2.4783388758078218, 10.670841056853533, 15.523238629102707, 19.21550240367651, 19.335439167916775, 15.977610647678375, 4.850270636379719, 1.4764177822507918, 0.17239717970369384, 0.7568440411705524, 2.915428471751511, 3.860216187313199, 6.883526332676411, 6.78460244089365, 7.983289919793606, 42.058339565992355, 63.477254435420036, 39.91031102836132, 35.274593979120255, 21.18966367095709, 64.52455803751945, 29.138968214392662, 0.16277329064905643, 1.5624350728467107, 0.48599317960906774, 0.016943723130680155, 0.15876085439231247, 0.031606659467797726, 0.1589974807575345, 0.18171349307522178, 0.6809408578556031, 4.04412679374218, 8.222521282732487, 4.0563915856182575, 55.41662536561489, 65.38150325417519, 62.09940277040005, 77.7878375351429, 88.89138132333755, 85.05934774875641, 83.46472531557083, 83.99254739284515, 77.92241871356964, 72.8957824409008, 77.5136898458004, 76.19728848338127, 70.72903230786324, 69.10793289542198, 59.07451428472996, 61.728782057762146, 57.23315589129925, 66.35536059737206, 71.13523051142693, 67.86286130547523, 74.48643028736115, 72.62981951236725, 72.01278582215309, 73.18722680211067, 75.98237201571465, 72.63699352741241, 73.33943143486977, 73.16909417510033, 71.70670464634895, 74.40636858344078, 71.8954785168171, 76.07710853219032, 72.67597183585167, 62.657748609781265, 67.58890360593796, 73.53693723678589, 74.4622103869915, 74.57723021507263, 73.17572861909866, 65.61644464731216, 59.687938168644905, 66.3006891310215, 68.48694741725922, 63.813821375370026, 61.44945524632931, 54.011738151311874, 52.566485702991486, 56.892701759934425, 52.69596755504608, 51.25195764005184, 56.03469640016556, 55.229656398296356, 52.99235165119171, 51.68544597923756, 52.23902307450771, 50.63747361302376, 53.32987613976002, 53.71722735464573, 54.23087999224663, 53.85413780808449, 54.021161645650864, 51.668791472911835, 51.60646341741085, 49.67092327773571, 48.60970862209797, 48.45587007701397, 51.34640917181969, 50.846637189388275, 50.69989666342735, 49.808833077549934, 48.85142885148525, 49.627434611320496, 53.00862617790699, 49.7871096432209, 52.86109149456024, 58.57411913573742, 59.54184740781784, 63.86269435286522, 63.42527702450752, 64.46267455816269, 63.09809558093548, 55.812571719288826, 56.35992094874382, 63.44348564743996, 66.48152142763138, 64.40588280558586, 57.235257178545, 59.354072883725166, 65.11618629097939, 61.334116235375404, 61.7868809401989, 61.6960734128952, 57.10573352873325, 60.83040006458759, 60.08625939488411, 61.264032796025276, 64.2278091609478, 64.49999615550041, 64.25170227885246, 59.68889191746712, 59.0952155739069, 54.73997287452221, 52.07264140248299, 56.92244656383991, 59.383844286203384, 62.04726956784725, 65.22631198167801, 60.402106046676636, 64.010339230299, 57.423685267567635, 57.24750392138958, 59.222561940550804, 53.3620186150074, 43.59016276896, 59.30924668908119, 60.79388402402401, 54.22155909240246, 42.674012929201126, 42.48441070318222, 52.34992012381554, 18.147284723818302, 2.15836517047137, 0.4403806943446398, 0.6568347732536495, 0.8665371488314122, 0.19616160920122638, 0.050421049309079535, 0.05722138186683878, 0.09265661792596802, 0.05427340802270919, 0.059770826119347475, 4.482140215113759, 52.981241047382355, 70.30897244811058, 26.847305484116077, 63.48766967654228, 19.797395579516888, 0.21201116731390357, 0.0558248974266462, 0.026486089118407108, 0.010501468477741582, 0.05931168903771322, 3.5679843183606863, 13.170402031391859, 16.708575524389744, 22.18540783971548, 23.292193450033665, 25.046162232756615, 8.16416211426258, 3.1634677620604634, 0.6323435436934233, 2.569084418937564, 7.160070268437266, 15.31932732090354, 22.41409096866846, 23.244281820952892, 8.311632201075554, 54.22867991030216, 78.67097094655037, 47.580005675554276, 35.32937563955784, 40.0611325353384, 78.51257264614105, 36.694661378860474, 1.2366502918303013, 3.0871835304424167, 0.9458372904919088, 0.10664503293810412, 0.34658848657272756, 0.26094301196280867, 0.47980040253605694, 0.4961817985167727, 1.979166311211884, 8.437854778021574, 16.672545857727528, 8.445048741996288, 66.70961558818817, 73.20497184991837, 71.9195768237114, 84.84380811452866, 92.22020030021667, 90.98449140787125, 86.11531868577003, 88.9074544608593, 82.16160044074059, 74.0946789085865, 79.96369957923889, 82.36606746912003, 75.11503055691719, 79.4646343588829, 69.01229202747345, 70.19164234399796, 65.76396033167839, 75.28524622321129, 76.33297920227051, 73.53088796138763, 77.0705272257328, 77.32781901955605, 77.71232798695564, 79.91061642765999, 80.37465512752533, 76.72104477882385, 75.93008682131767, 76.91939413547516, 74.99048843979836, 74.02223959565163, 73.2110895216465, 78.94207879900932, 76.42435669898987, 66.43121972680092, 69.60886001586914, 74.97506886720657, 77.68547102808952, 78.11405763030052, 77.08080187439919, 72.12278231978416, 62.838231325149536, 67.35416740179062, 74.81923162937164, 66.05412036180496, 63.64619717001915, 58.04967887699604, 55.5901924520731, 60.21390214562416, 56.90057873725891, 55.21644830703735, 60.42463883757591, 61.37951619923115, 55.27853697538376, 56.609411761164665, 56.90946266055107, 54.320881962776184, 57.472942024469376, 59.7888645529747, 57.29191213846207, 57.03886091709137, 55.90799979865551, 52.8841220587492, 53.74643638730049, 51.73406057059765, 51.408516839146614, 52.663171514868736, 54.16691802442074, 55.31127981841564, 54.44899968802929, 53.782207667827606, 51.40411667525768, 51.772351115942, 57.282443046569824, 52.197305113077164, 58.552179113030434, 62.76343613862991, 63.07202138006687, 69.28690329194069, 68.28605979681015, 66.59762799739838, 62.73968741297722, 56.32274754345417, 58.793804347515106, 66.79139479994774, 68.76081392168999, 67.62682557106018, 60.20198218524456, 65.1119077205658, 67.8082962334156, 63.580791279673576, 65.46658828854561, 63.591981679201126, 61.36555194854736, 64.58853140473366, 62.17063754796982, 64.33038085699081, 68.13476711511612, 70.47924891114235, 67.25552469491959, 63.24480950832367, 65.80919310450554, 60.111106261610985, 62.26778693497181, 68.09216380119324, 68.29369738698006, 68.53964298963547, 69.94119018316269, 64.2712864279747, 66.10613957047462, 61.62462204694748, 62.43924893438816, 60.13492338359356, 53.81945326924324, 49.42599222064018, 56.367497742176056, 60.58568559587002, 52.144989520311356, 42.63650894165039, 41.63763754069805, 52.81779281795025, 19.427599422633648, 3.258417542092502, 0.7378732622601092, 2.16662616468966, 1.527141141705215, 0.362199058290571, 0.19153526838636026, 0.20647139113862067, 0.3190438833553344, 0.3411273780511692, 0.3536877821898088, 6.827594758942723, 63.1723739951849, 81.43317192792892, 31.248438321053982, 72.2731326520443, 21.93915255367756, 0.3568359726341441, 0.26135772408451885, 0.11479060834972188, 0.15580305451294407, 0.23348506190814078, 6.151932114735246, 19.005974046885967, 28.856761157512665, 34.33028765022755, 33.36446687579155], [30.28342880308628, 25.084245689213276, 15.020803939551115, 4.701286805793643, 3.4261854272335768, 0.4505550937028602, 5.07708141580224, 8.2782063446939, 4.853293849155307, 2.420680532231927, 20.657924003899097, 42.56546415388584, 40.578888952732086, 19.282787293195724, 57.76108056306839, 56.80486187338829, 2.1110983192920685, 0.08542239243979566, 0.2277950750431046, 0.23943439970025793, 0.044576940636034124, 0.12918625463498756, 0.12613507773494348, 0.11422506213421002, 0.14560977491782978, 0.5507416755426675, 5.995653150603175, 5.500168763101101, 14.695740882307291, 38.19749213755131, 42.42271341383457, 77.71729812026024, 81.32737800478935, 83.08906987309456, 81.31008893251419, 77.73033142089844, 78.4314090013504, 77.71985918283463, 76.05195388197899, 70.8665469288826, 73.10522720217705, 66.81195929646492, 61.531432047486305, 55.00348873436451, 55.62141537666321, 56.87232345342636, 57.22673803567886, 68.97465124726295, 66.147450953722, 69.74570587277412, 70.45170798897743, 72.5200206041336, 67.74873062968254, 70.61771348118782, 70.24892047047615, 67.90508463978767, 65.47934800386429, 70.80769568681717, 72.43523195385933, 71.78656116127968, 68.17619249224663, 62.671374678611755, 63.465144485235214, 70.44405519962311, 70.6152056157589, 72.55133092403412, 69.38496842980385, 60.723853781819344, 56.1136219650507, 61.28478728234768, 67.42035984992981, 65.64799055457115, 63.78441855311394, 54.39612552523613, 51.51165470480919, 50.63675545156002, 52.51742273569107, 50.70712007582188, 49.374174401164055, 50.12004777789116, 49.007079899311066, 48.17775160074234, 45.66229037940502, 46.38383366167545, 47.63617046177387, 48.411454260349274, 50.35414181649685, 53.89242835342884, 54.440336152911186, 54.67044420540333, 52.197631895542145, 47.88688860833645, 46.54183678328991, 44.43728171288967, 44.97422710061073, 47.70663008093834, 45.597344264388084, 47.490258291363716, 48.79987321794033, 47.60768339037895, 46.54021807014942, 46.86290055513382, 48.850744888186455, 46.31735622882843, 51.9959881156683, 58.04742179811001, 54.84153002500534, 58.009541630744934, 57.72067353129387, 62.12462201714516, 58.156924322247505, 55.24034142494202, 57.8028517216444, 61.04874774813652, 64.60312262177467, 59.1465850174427, 54.29047219455242, 58.644354566931725, 60.04550278186798, 59.3691960722208, 58.74251089990139, 58.682154938578606, 55.686866864562035, 57.18713276088238, 55.08205711841583, 61.56561881303787, 59.82107922434807, 59.749764651060104, 57.962807938456535, 54.01772662997246, 53.11150565743446, 47.85128831863403, 48.0065593868494, 60.33999837934971, 59.89560082554817, 62.95740433037281, 61.27179957926273, 57.552904933691025, 52.661917582154274, 55.56535318493843, 56.594774946570396, 56.678157672286034, 36.52277760207653, 37.852200865745544, 48.21186617016792, 33.47689524292946, 33.508038371801376, 35.60922682285309, 45.111012160778046, 17.94629640877247, 3.001209581270814, 0.09357901843031868, 0.6644202943425626, 1.9655302679166198, 0.13450601371005177, 0.2898259152425453, 0.12218730480526574, 0.08559517184039578, 0.19918403530027717, 0.28634064132347703, 2.119405148550868, 26.179555915296078, 72.89781913161278, 40.21156266331673, 22.5960898026824, 58.75275515019894, 1.2226704857312143, 0.02652823197422549, 0.03311089632916264, 0.10186089668422937, 5.111900847405195, 17.620359398424625, 19.408456049859524, 10.397135093808174, 9.7697745077312, 10.366018563508987, 43.60606871545315, 31.53966799378395, 17.52456843852997, 6.833003768697381, 7.1163669135421515, 4.294365216046572, 4.635826768353581, 5.852617900818586, 11.516509428620338, 5.057452144101262, 36.60192355513573, 58.61304044723511, 56.57885380089283, 24.63779054582119, 44.45998929440975, 66.04541882872581, 3.332156385295093, 0.08434871255303733, 0.3674765001051128, 0.1645764274871908, 0.07350802043220028, 0.18888217950006947, 0.19183914817404002, 0.1888381552998908, 0.04658332574763335, 0.9086371678858995, 10.645465068519115, 15.150440633296967, 15.660103484988213, 47.53767214715481, 54.927405416965485, 83.95231515169144, 85.57185664772987, 87.86838501691818, 82.02005043625832, 81.85483530163765, 81.9125086069107, 79.9387577176094, 79.80456411838531, 74.39653471112251, 76.64024591445923, 72.59826600551605, 67.30511963367462, 60.213803350925446, 63.03718864917755, 63.81853312253952, 64.07649368047714, 71.39116957783699, 70.05178704857826, 71.57735198736191, 72.31691390275955, 73.86190339922905, 71.64145454764366, 72.86115869879723, 74.07471477985382, 71.71260192990303, 70.94442754983902, 73.41177955269814, 74.02784809470177, 75.16210243105888, 69.46164071559906, 66.45333454012871, 68.16863849759102, 72.0469231903553, 73.30915465950966, 74.97506886720657, 69.74339559674263, 63.148556873202324, 60.47238327562809, 66.19644552469254, 70.18438473343849, 68.48028257489204, 64.50542986392975, 56.31043620407581, 54.97187443077564, 52.837905138731, 52.090150862932205, 53.89863722026348, 52.00603857636452, 53.97386938333511, 53.13605614006519, 52.215589731931686, 50.19506335258484, 48.898371532559395, 51.37048847973347, 52.725700959563255, 52.93866813182831, 54.04421880841255, 56.12787500023842, 58.91122184693813, 55.13790652155876, 50.26449702680111, 49.62562970817089, 46.69367663562298, 48.2711885869503, 51.68571576476097, 49.564251601696014, 49.33333799242973, 49.92142863571644, 50.89786224067211, 52.5012394040823, 49.36724737286568, 52.913008108735085, 48.96969370543957, 53.42989817261696, 62.84626789391041, 60.57175554335117, 63.55106547474861, 59.75964032113552, 64.1336578130722, 62.23605863749981, 57.208062037825584, 59.56271968781948, 63.81904989480972, 66.5737272799015, 64.99933496117592, 58.33464838564396, 60.04170298576355, 63.845815658569336, 63.13848361372948, 62.32165664434433, 60.01230776309967, 59.33662422001362, 59.988232254981995, 59.85067203640938, 64.5823985338211, 64.55598995089531, 62.16678075492382, 62.91000947356224, 60.172583162784576, 59.30546589195728, 51.935008987784386, 52.677242159843445, 65.0013792514801, 62.20088392496109, 64.25946146249771, 63.615810200572014, 59.60962817072868, 56.19618773460388, 59.54647555947304, 60.49895144999027, 60.121688693761826, 46.17016352713108, 51.40096664428711, 60.13138197362423, 52.79405549168587, 39.97868835926056, 39.33613523840904, 49.65252846479416, 19.5866721868515, 2.8740358678624034, 0.753014381043613, 1.1120835947804153, 3.2831152668222785, 0.16552202752791345, 0.19508809258695692, 0.1158692235185299, 0.03917779402399901, 0.2998081280384213, 0.2553504245588556, 2.3219725163653493, 38.02330568432808, 75.56318610906601, 47.6018963009119, 30.509946048259735, 70.36894842982292, 2.6333135599270463, 0.09209317198838107, 0.04959315017913468, 0.07231266543385573, 5.898230653256178, 25.447059720754623, 30.335278920829296, 29.148435406386852, 32.67016053199768, 28.879383243620396, 55.05790941417217, 46.404261365532875, 30.11178821325302, 13.042248208075762, 23.322010450065136, 8.438999466598034, 16.462337337434292, 16.163116693496704, 29.520891420543194, 1.952467281371355, 71.35999605059624, 71.73113733530045, 60.66314823925495, 31.991915926337242, 77.41029739379883, 76.33997082710266, 6.4217703603208065, 0.17108613130403683, 0.49746194388717413, 1.3970476412214339, 0.17284107307204977, 0.4335735971108079, 0.2851022343384102, 0.5634569213725626, 0.34983606543391943, 0.8563909213989973, 15.680060014128685, 17.319892421364784, 17.852686531841755, 57.48355485498905, 67.17820644378662, 92.05492436885834, 90.18821373581886, 91.09128847718239, 86.08777776360512, 86.3897855579853, 86.1064575612545, 85.23536190390587, 83.26094225049019, 80.4007901251316, 80.62929466366768, 79.10134345293045, 73.6636832356453, 71.17433801293373, 70.37410095334053, 70.36722332239151, 73.11885327100754, 79.41691651940346, 77.01690450310707, 77.31793195009232, 76.41912817955017, 78.56350511312485, 73.91050279140472, 77.40098789334297, 76.87855392694473, 74.93754208087921, 71.23079538345337, 73.92247974872589, 78.94699573516846, 75.31517341732979, 72.58305922150612, 68.34768489003181, 69.38134342432022, 76.3614472746849, 75.89405715465546, 78.38220164179802, 76.1420926451683, 69.1020356118679, 60.12302242219448, 68.63118007779121, 74.20035123825073, 72.63959258794785, 69.54247757792473, 61.141063794493675, 57.670444026589394, 56.61670736968517, 56.01632438600063, 57.17330150306225, 55.149176716804504, 57.92876556515694, 57.51779101788998, 56.268915832042694, 55.973664075136185, 54.47646081447601, 55.42553588747978, 56.20012812316418, 59.09438721835613, 58.22583742439747, 61.03426672518253, 62.223705500364304, 58.89308921992779, 54.27042827010155, 52.183105275034904, 50.0423913449049, 51.98459632694721, 55.2061964571476, 50.343042612075806, 52.61876329779625, 55.977376475930214, 53.75069595873356, 55.82530863583088, 52.306347861886024, 57.54561312496662, 53.32202576100826, 58.215277791023254, 66.87553748488426, 61.99395842850208, 66.63089141249657, 62.511327266693115, 66.36438891291618, 62.314851209521294, 56.913444846868515, 60.84812991321087, 69.75581333041191, 68.3755373954773, 66.78747341036797, 60.68956442177296, 64.78473007678986, 66.31765142083168, 66.30030155181885, 66.20814889669418, 63.07299792766571, 60.852663069963455, 64.35742780566216, 62.716170474886894, 70.94592466950417, 69.05084475874901, 68.16407114267349, 66.81899651885033, 65.31787186861038, 64.32252287864685, 60.22799178957939, 58.97922299802303, 74.70476657152176, 66.64147764444351, 70.2937200665474, 63.94712582230568, 62.63501822948456, 57.389110922813416, 61.194796711206436, 63.64436946809292, 61.683325096964836, 50.00723943114281, 50.168666169047356, 57.30030968785286, 52.7918554097414, 40.48096060752869, 40.85758879780769, 51.44064411520958, 20.39234295487404, 4.863729039207101, 1.4168531284667552, 2.742493813857436, 4.47807633318007, 0.38034418306779116, 0.8075823623221368, 0.21457168069900945, 0.15084157465025783, 0.44294422084931284, 0.5206772731617093, 3.8453547097742558, 44.13217328488827, 79.23065811395645, 53.48374128341675, 34.438642635941505, 79.85103562474251, 3.6631302628666162, 0.1595161677687429, 0.16116993996547535, 0.15145552373724058, 9.767169747501612, 37.80154578387737, 42.389932572841644, 41.882591396570206, 43.59440714120865, 36.73520900309086], [6.333237010985613, 16.480074785649776, 18.999865874648094, 20.401969738304615, 6.818597316741943, 6.736163590103388, 7.953241132199764, 5.000321259722114, 2.6687547331675887, 4.091881206259131, 12.167099118232727, 44.70250368118286, 26.210997328162193, 29.10662814974785, 58.76850910484791, 23.34374338388443, 0.45330976776313037, 0.04792858715518378, 0.038510376907652244, 0.0723382992146071, 0.03435724429436959, 0.06243634968996048, 0.07185856011346914, 0.07772176424623467, 0.13267675327369943, 2.4662987468764186, 6.724173333495855, 2.7546989964321256, 29.56499755382538, 59.400738179683685, 71.04970470070839, 76.9541622698307, 81.08831003308296, 79.92094427347183, 78.10566008090973, 78.35133969783783, 77.4868556857109, 72.54889905452728, 76.36042132973671, 73.25072899460793, 70.89034885168076, 66.2887653708458, 63.95616173744202, 57.59588822722435, 58.39465856552124, 64.3548971414566, 58.96501176059246, 62.51982361078262, 66.66465640068054, 67.15506568551064, 66.58416152000427, 67.70744204521179, 71.55930295586586, 66.6150538623333, 70.71621179580688, 67.88757517933846, 71.10137432813644, 72.66032427549362, 72.21655368804932, 68.69272157549858, 63.8322351872921, 66.07208579778671, 68.10494631528854, 70.15185847878456, 68.57264801859856, 68.95421594381332, 58.16031374037266, 59.45899285376072, 68.51798415184021, 66.73307552933693, 66.98511600494385, 66.72438159584999, 56.4308213442564, 52.19036668539047, 54.934891015291214, 52.17110551893711, 52.499084919691086, 49.791392013430595, 48.48049655556679, 49.10299055278301, 47.54810258746147, 45.21674908697605, 45.852876752614975, 45.61052955687046, 46.849335283041, 49.86866846680641, 49.29527923464775, 48.29335279762745, 49.07826907932758, 48.35394434630871, 47.46268317103386, 48.155142813920975, 45.35653978586197, 44.03356097638607, 42.73876525461674, 47.55493462085724, 45.288295447826385, 48.09596098959446, 47.383187636733055, 47.69010856747627, 46.843259409070015, 45.6693921983242, 50.39574198424816, 49.27509091794491, 45.701337084174156, 51.022411957383156, 59.7094602137804, 60.03917992115021, 59.38398487865925, 61.14582493901253, 62.312666326761246, 57.96506501734257, 60.89621253311634, 57.03843154013157, 59.62971769273281, 62.58062034845352, 57.42684289813042, 54.95192550122738, 61.761247515678406, 61.64827577769756, 56.57238654792309, 57.3489660769701, 56.45335413515568, 58.43222714960575, 55.41084587574005, 57.63981766998768, 61.35189928114414, 59.6152138710022, 58.43779765069485, 52.6793472468853, 52.726240530610085, 52.81282648444176, 44.469811767339706, 57.645912542939186, 59.1910046339035, 64.65065807104111, 60.11894904077053, 57.31620043516159, 56.184735149145126, 54.91016574203968, 57.12039314210415, 56.44003964960575, 44.25781734287739, 36.01150743663311, 46.0101655125618, 32.17738017439842, 30.511308275163174, 37.12226763367653, 43.85322645306587, 18.957317657768726, 2.0784119982272387, 0.8904561528470367, 1.0440468206070364, 1.8398206634446979, 0.25122497405391186, 0.06822659328463487, 0.14231781562557444, 0.12593217456014827, 0.0593663148174528, 0.13369863125262782, 0.9370082861278206, 24.87637024372816, 38.72019588947296, 41.378533244132996, 22.681754305958748, 55.29617182910442, 8.130471222102642, 0.46042761707212776, 0.11970844250754453, 2.7709357626736164, 17.511008866131306, 21.970930248498917, 18.212057948112488, 32.28011146187782, 35.10867968201637, 21.396323181688786, 24.39110018312931, 32.594875171780586, 31.213687285780907, 31.726087890565395, 14.213972333818674, 2.4363090936094522, 2.940911566838622, 3.6596836103126407, 12.663375288248062, 8.330089710652828, 38.51234324276447, 53.50722022354603, 44.90374468266964, 26.44845798611641, 59.09402243793011, 29.76592317223549, 0.2847454394213855, 0.009509837655059528, 0.17013315431540832, 0.14074708975385875, 0.04626110749086365, 0.05672276995028369, 0.11563140229554847, 0.09092178093851544, 0.3884296742035076, 1.3357281940989196, 9.572792127728462, 3.5366495372727513, 29.25754465162754, 63.76214414834976, 78.20860415697098, 81.57776176929474, 83.9864145219326, 83.46784114837646, 79.96886730194092, 80.77996417880058, 78.53315234184265, 79.92968380451202, 78.74626770615578, 79.77026715874672, 74.38444375991821, 71.84204578399658, 67.82297864556313, 65.92394694685936, 63.54128859937191, 69.48270678520203, 66.99739694595337, 65.53545579314232, 70.42901560664177, 71.2298758327961, 69.593645632267, 70.18940806388855, 72.94960275292397, 69.46258306503296, 73.40037256479263, 71.03370755910873, 73.87267202138901, 72.71726042032242, 73.47962111234665, 71.59961879253387, 67.26748645305634, 69.93439614772797, 72.79074087738991, 71.81325852870941, 71.60664081573486, 69.87514212727547, 61.26615308225155, 66.1528542637825, 71.44619062542915, 69.35140863060951, 71.19902148842812, 69.31205034255981, 57.68086686730385, 56.77092209458351, 58.6222093552351, 54.17504578828812, 54.80119898915291, 51.79192006587982, 53.14374312758446, 51.064627692103386, 50.99066466093063, 50.031839311122894, 51.29494473338127, 49.19046565890312, 49.03383046388626, 51.24400466680527, 52.742260470986366, 49.37724843621254, 53.984751999378204, 51.87209576368332, 50.727528780698776, 51.24373108148575, 49.936038851737976, 45.41989378631115, 45.82668095827103, 48.97566318511963, 46.51211857795715, 49.68697361648083, 50.26856280863285, 47.960916236042976, 49.12387803196907, 47.70909994840622, 53.11028212308884, 52.27486275136471, 50.84688037633896, 53.40650662779808, 62.80709579586983, 64.10674005746841, 63.333686739206314, 62.69275613129139, 64.65797647833824, 61.596036180853844, 63.747689723968506, 60.65644919872284, 60.42636774480343, 65.0122618675232, 61.71578295528889, 59.38899680972099, 64.48498696088791, 64.12965282797813, 58.767768144607544, 59.41455043852329, 59.37263108789921, 57.93508842587471, 59.314710795879364, 61.178305596113205, 63.457495495676994, 61.954539343714714, 61.6513954102993, 58.909181356430054, 59.705098047852516, 56.35062664747238, 51.25676058232784, 59.36399035155773, 59.07622039318085, 65.92081591486931, 61.459023132920265, 58.84707748889923, 58.305291160941124, 58.65916237235069, 58.38611662387848, 60.713092759251595, 54.87822845578194, 50.3829138725996, 60.02361215651035, 51.22031293809414, 35.15032924711704, 42.5975838303566, 39.38436605036259, 17.25836992263794, 2.5463281525298953, 0.7172220235224813, 1.153694330714643, 1.4529294613748789, 0.35593150241766125, 0.06522551877424121, 0.08107581161311828, 0.09915140457451344, 0.12028927696519531, 0.019584215915529057, 1.0328184231184423, 32.4626574665308, 46.45888723433018, 53.91292825341225, 31.287802308797836, 68.36507275700569, 12.295374535024166, 0.4034036019584164, 0.1378547918284312, 3.115894552320242, 25.446085073053837, 39.51122984290123, 33.99089366197586, 36.67915441095829, 39.0069817006588, 30.747657492756844, 35.3584972769022, 42.598480582237244, 48.40742267668247, 67.83931776881218, 37.75162786245346, 14.370261747390032, 26.243869364261627, 29.00000587105751, 35.359584018588066, 10.701343920081854, 69.72814321517944, 68.00482168793678, 39.7843249887228, 42.87449777126312, 76.21783018112183, 34.76780757308006, 1.6132106794975698, 0.2104061096906662, 0.2831405895994976, 0.36920282465871423, 0.240614325448405, 0.15081266057677567, 0.3261015296448022, 0.15614609001204371, 0.8915310201700777, 6.3958334270864725, 15.80207146704197, 6.2559781316667795, 36.81989885866642, 72.72767946124077, 87.85471335053444, 86.62006080150604, 88.53856265544891, 85.7300041615963, 87.29149237275124, 85.66923022270203, 83.45617577433586, 82.88645714521408, 80.81502109766006, 81.16287723183632, 79.51851546764374, 75.49005523324013, 76.24942168593407, 73.41737285256386, 69.23572763800621, 73.84133890271187, 72.51832589507103, 72.88564458489418, 75.02059042453766, 76.81758999824524, 73.26917320489883, 75.83915770053864, 77.93890222907066, 73.79295229911804, 76.23197302222252, 75.16489908099174, 74.70233470201492, 76.65251165628433, 76.02029398083687, 75.43675929307938, 68.18169459700584, 73.38763564825058, 74.80430603027344, 75.6407019495964, 73.09572771191597, 75.23978546261787, 66.20321676135063, 64.90354210138321, 73.69294926524162, 73.48110303282738, 74.10312205553055, 71.8120501935482, 62.13470287621021, 58.941536620259285, 63.039164543151855, 58.72128903865814, 57.32178993523121, 56.15502454340458, 55.782720521092415, 55.00470466911793, 53.84670540690422, 53.44732403755188, 55.04954606294632, 54.30213376879692, 53.67742829024792, 55.37374086678028, 56.94175332784653, 53.769489750266075, 56.99501886963844, 55.9244529157877, 54.454535990953445, 54.17598433792591, 52.22269915044308, 48.88948380947113, 48.858325481414795, 52.757797837257385, 49.634224846959114, 53.88161413371563, 54.058388248085976, 52.669824957847595, 52.07674898207188, 51.96197234094143, 59.56425480544567, 56.60664550960064, 54.41542848944664, 59.70206581056118, 68.68273571133614, 68.38915586471558, 67.2823816537857, 65.14453276991844, 64.66910228133202, 64.46325212717056, 64.68822285532951, 62.947452664375305, 64.55686390399933, 68.04953008890152, 64.50208604335785, 61.86410419642925, 68.82164865732193, 68.08231472969055, 61.11111760139465, 61.07460156083107, 61.7527511715889, 63.472158908843994, 62.18737564980984, 67.49638617038727, 70.31864672899246, 66.57584756612778, 68.42310324311256, 64.89972710609436, 65.27926594018936, 63.88927772641182, 58.72919261455536, 66.58604621887207, 67.77850583195686, 69.05823916196823, 64.23959612846375, 64.84452366828918, 61.941532641649246, 62.031150832772255, 62.00108304619789, 67.23596334457397, 55.817382261157036, 52.265066877007484, 58.80199670791626, 51.40148341655731, 33.01596097648144, 42.58975625038147, 51.39802560210228, 23.693976290524006, 5.084769353270531, 4.05957723967731, 4.670258145779371, 3.731778091751039, 1.0646058549173176, 0.3344680572627112, 0.2706576359923929, 0.4027894599130377, 0.21741015807492658, 0.38082108716480434, 1.2468678248114884, 42.16813467442989, 51.059695556759834, 53.03781621158123, 36.017549112439156, 79.367815554142, 15.78567249700427, 0.5931212170980871, 0.3099564928561449, 5.122971553355455, 37.23571054637432, 50.319932252168655, 50.932497382164, 62.02668607234955, 70.66258147358894, 61.38356298208237], [18.568296432495117, 11.685611754655838, 13.217651546001434, 27.034344747662544, 5.4421568010002375, 28.360524885356426, 24.39348265528679, 17.66107801347971, 20.101814344525337, 15.064010471105576, 32.98546001315117, 46.207040548324585, 37.67428681254387, 33.95538456737995, 56.649594604969025, 11.486719027161598, 0.14696848404128104, 0.06336904378258623, 0.06967412264202721, 0.06164814061776269, 0.04911760050163139, 0.01571966928167967, 0.018558078008936718, 0.12808070692699403, 0.029509635860449634, 0.7683164568152279, 3.4863701602444053, 10.518164299428463, 57.17033386230469, 72.57222980260849, 79.88209515810013, 74.72831010818481, 81.46105483174324, 77.82726421952248, 73.70624855160713, 71.72434329986572, 69.77965325117111, 73.14761012792587, 73.59249025583267, 75.82708954811096, 70.92730566859245, 68.15319612622261, 63.46239723265171, 62.4305360019207, 62.39731438457966, 68.31715732812881, 63.79758104681969, 57.000209391117096, 65.72269454598427, 64.03432354331017, 65.70578545331955, 66.41078442335129, 65.95154106616974, 68.66910964250565, 69.08358380198479, 68.54024335741997, 67.19975888729095, 69.71259444952011, 68.34679573774338, 65.14922931790352, 65.68814679980278, 66.71653121709824, 67.58657053112984, 68.20735841989517, 69.6338626742363, 59.19020287692547, 62.37167716026306, 70.84839910268784, 66.4579626917839, 67.39013627171516, 66.4718547463417, 59.01368334889412, 49.40535172820091, 53.95939216017723, 52.39805594086647, 55.49847677350044, 50.75346998870373, 50.18329918384552, 47.99255333840847, 46.61529444158077, 46.19941055774689, 47.69589565694332, 45.715441927313805, 46.04427248239517, 46.55914105474949, 47.15803451836109, 48.025710359215736, 49.76204238831997, 50.33210679888725, 50.069468691945076, 49.26722154021263, 45.18401004374027, 45.60972400009632, 43.35849680006504, 41.57526008784771, 43.639860302209854, 43.59908849000931, 46.23157203197479, 46.21654003858566, 46.06134116649628, 45.216091722249985, 45.91762527823448, 47.19699762761593, 48.979064002633095, 48.778275176882744, 46.553855538368225, 50.43996021151543, 57.56932385265827, 59.99623082578182, 60.161168575286865, 59.03002627193928, 60.61580277979374, 57.28387176990509, 60.29198795557022, 58.32796074450016, 60.58646075427532, 59.41928118467331, 57.82074116170406, 57.728447914123535, 58.20353262126446, 61.34133964776993, 57.17318370938301, 56.266035586595535, 55.70463091135025, 57.76777200400829, 56.89896382391453, 55.18185116350651, 59.95306894183159, 57.10544854402542, 51.49034544825554, 51.25825010240078, 52.75271750986576, 47.67087399959564, 49.848476350307465, 61.94513864815235, 58.199637830257416, 57.369317784905434, 55.585526302456856, 54.25493270158768, 52.47305251657963, 52.65767700970173, 51.97263456881046, 54.25369776785374, 33.25983569025993, 41.49726927280426, 25.97451701760292, 29.23620119690895, 33.100175857543945, 17.452431209385395, 2.73373338393867, 0.24923221848439425, 0.12785136845195666, 0.12463487073546275, 0.19467482023173943, 0.2615972002968192, 0.10676713107386604, 0.07917185401311144, 0.093615331716137, 0.1399417853099294, 0.05979710927931592, 0.9968182048760355, 30.41171371936798, 34.52561616897583, 33.11647318303585, 23.91704522073269, 55.21142117679119, 16.996265687048435, 0.7371856772806495, 0.132107347890269, 12.218743097037077, 13.374326638877392, 19.20917384326458, 43.67149740457535, 54.5788349211216, 36.257886216044426, 32.88900598883629, 30.48360586166382, 25.316968001425266, 26.551289968192577, 40.47911770641804, 15.357983596622944, 12.515527121722698, 19.808684773743153, 14.412684570997953, 23.386546187102795, 14.392840135842562, 54.80561435222626, 57.951412349939346, 35.73663018643856, 26.467669755220413, 65.86550608277321, 14.61440909653902, 0.1142466883175075, 0.11936690614675172, 0.045023405546089634, 0.063698728044983, 0.17058593861293048, 0.04236711058183573, 0.134480647102464, 0.09626758197555318, 0.14885089709423482, 1.283218574244529, 5.508172558620572, 8.754222001880407, 57.64517158269882, 79.80818912386894, 84.24653336405754, 81.5415421128273, 84.0725938975811, 79.19825345277786, 77.55106464028358, 75.05834519863129, 73.15102234482765, 77.14483603835106, 77.19430938363075, 79.3239963054657, 75.50687313079834, 74.27390769124031, 68.08632731437683, 68.67231667041779, 67.14450225234032, 71.14273130893707, 72.07639440894127, 63.08283559978008, 70.034931153059, 68.40354189276695, 68.28778490424156, 70.59704259037971, 71.24279513955116, 67.86565035581589, 71.48729681968689, 72.74387419223785, 68.5308350622654, 72.13842228055, 69.48928043246269, 66.99238881468773, 68.62694710493088, 71.01748242974281, 71.32177770137787, 69.940946996212, 70.31085714697838, 61.96938134729862, 69.08829554915428, 72.20700100064278, 68.19535866379738, 71.28454729914665, 68.92164409160614, 61.082486137747765, 52.551864087581635, 56.80575482547283, 56.3251756131649, 57.858697324991226, 51.56587779521942, 54.16117273271084, 49.73387449979782, 49.70607899129391, 49.64512266218662, 49.305633679032326, 47.796974033117294, 50.21909326314926, 48.94547000527382, 48.75399827957153, 52.10490547120571, 51.23044319450855, 53.0245815217495, 54.692806005477905, 52.36697360873222, 47.77418665587902, 48.81351448595524, 45.154538825154305, 44.31025832891464, 47.66142010688782, 45.29127448797226, 47.03011438250542, 46.69121436774731, 47.97006994485855, 48.26411336660385, 48.91634836792946, 49.89182822406292, 50.95720365643501, 52.74873152375221, 49.121970534324646, 52.75303669273853, 59.54600818455219, 62.57677495479584, 62.74324782192707, 62.40544594824314, 64.72694277763367, 60.05497567355633, 61.643184050917625, 63.15412737429142, 62.660131081938744, 63.09666685760021, 60.681056678295135, 60.1222700625658, 61.37434087693691, 64.45294708013535, 58.96426320075989, 57.072188928723335, 59.023137241601944, 61.02059505879879, 60.140398889780045, 56.944169998168945, 64.40670356154442, 61.854038536548615, 56.32196478545666, 56.90121330320835, 56.77512466907501, 51.0213328152895, 52.56587773561478, 62.45245322585106, 59.79449205100536, 59.24115814268589, 57.2510377317667, 58.165774047374725, 55.16889005899429, 56.320710852742195, 57.854665741324425, 61.82098411023617, 46.94035179913044, 57.45860159397125, 39.97767761349678, 31.020686142146587, 32.45647519826889, 8.494302649050951, 4.021946908906102, 0.051582499290816486, 0.1434523070929572, 0.19902548287063837, 0.07718954046140425, 0.23437902331352234, 0.17002135718939826, 0.08667979840538464, 0.1299766864394769, 0.09708703175419942, 0.06984018560615368, 1.1119891935959458, 33.69446776807308, 40.93070827424526, 41.7500165104866, 28.037160336971283, 67.19647586345673, 23.97246714681387, 0.7941018138080835, 0.25549015612341464, 14.78207889944315, 26.55636079609394, 36.805341839790344, 50.65663978457451, 68.58876675367355, 57.775474190711975, 47.25849352777004, 70.32672509551048, 43.5989098995924, 61.304052248597145, 93.40181529521942, 49.288378804922104, 58.89495871961117, 60.43588623404503, 49.101330041885376, 46.61013811826706, 38.35733436048031, 73.82283389568329, 67.0894356071949, 52.868432700634, 47.67101839184761, 77.42331549525261, 20.95936942845583, 0.19767121179029346, 0.20354407868580893, 0.12259345996426418, 0.1560355693800375, 0.2495953068137169, 0.16796173411421478, 0.4238994646584615, 0.3787060553440824, 0.4966798092937097, 4.611269636079669, 7.777199428528547, 13.991009797900915, 67.34238043427467, 87.37723097205162, 87.63713702559471, 84.97512146830559, 88.37709411978722, 82.49454617500305, 81.33777424693108, 79.16370570659637, 78.49105820059776, 79.70931842923164, 80.08508786559105, 83.02269503474236, 80.57517796754837, 78.2048499584198, 73.03190633654594, 75.74280247092247, 71.99309527873993, 75.6891417503357, 75.22285357117653, 70.8821488916874, 76.17455810308456, 72.59176835417747, 73.11644420027733, 73.24312180280685, 73.38166236877441, 74.7595976293087, 75.92192485928535, 74.84962239861488, 69.86169084906578, 73.76428663730621, 71.47057771682739, 70.08352294564247, 71.18265956640244, 75.16362234950066, 71.78343012928963, 72.37695828080177, 78.5377348959446, 67.70715326070786, 69.9358780682087, 77.04129159450531, 71.18832886219025, 72.13572442531586, 73.20827767252922, 65.05399882793427, 55.36164231598377, 58.216805309057236, 57.07812421023846, 62.55183309316635, 53.61687853932381, 57.02431529760361, 54.03471551835537, 52.29994140565395, 52.227285504341125, 55.59494599699974, 51.83451198041439, 55.64941227436066, 53.53407338261604, 54.05796267092228, 57.36644133925438, 53.70715789496899, 55.98893545567989, 54.94812950491905, 54.480192214250565, 49.91632930934429, 52.81135216355324, 48.35244342684746, 46.43116012215614, 48.09044748544693, 46.34866274893284, 52.53173656761646, 49.79153260588646, 51.31613239645958, 51.343175545334816, 53.02439533174038, 54.92959029972553, 54.07771401107311, 56.77764393389225, 52.76853606104851, 57.41975627839565, 64.74398866295815, 66.47877037525177, 64.59015011787415, 63.824384808540344, 65.34244135022163, 61.73717200756073, 62.20729038119316, 67.95268088579178, 66.9755557179451, 64.20713067054749, 64.51495975255966, 64.41417396068573, 62.4797547608614, 68.53815346956253, 61.35238565504551, 58.92646282911301, 61.306290328502655, 64.63474452495575, 64.288689494133, 60.83828464150429, 68.52347105741501, 67.51388803124428, 63.28647427260876, 66.66029423475266, 65.17371520400047, 58.37823584675789, 58.95371116697788, 66.4481820166111, 64.65498983860016, 62.8195895254612, 60.669102519750595, 61.63569085299969, 59.75134156644344, 61.78661495447159, 64.50961723923683, 66.65397897362709, 49.62468735873699, 56.43097333610058, 42.105210050940514, 30.909821391105652, 45.682744681835175, 35.10791592299938, 6.188948778435588, 0.35937943146564066, 0.2490812656469643, 0.5024785653222352, 0.37570617569144815, 0.9010661928914487, 0.45639912073966116, 0.3007397905457765, 0.24934339220635593, 0.3737824398558587, 0.28057635063305497, 1.2178677809424698, 47.08208039402962, 47.12710037827492, 42.33318641781807, 38.455688282847404, 77.16950431466103, 32.03215576708317, 0.9551070118322968, 0.5807597085367888, 23.33393421024084, 39.06120479106903, 53.24387915432453, 79.1087606549263, 101.05238556861877, 83.96811470389366, 81.83367043733597], [3.7345184572041035, 26.354042552411556, 54.611315578222275, 22.911448180675507, 44.48586590588093, 43.99055488407612, 42.68862694501877, 29.607234187424183, 26.14889156073332, 28.92628602683544, 50.434522703289986, 47.54964530467987, 43.261617198586464, 46.28281608223915, 47.32562452554703, 1.1163905449211597, 0.08496804963215254, 0.1208923981175758, 0.02110418074153131, 0.022413492515624966, 0.07007886772044003, 0.060964281219639815, 0.0944561033975333, 0.2529645978938788, 1.96540238102898, 2.8757543256506324, 3.638519933447242, 29.567790403962135, 52.0600450783968, 58.07831034064293, 80.18259823322296, 76.8788655102253, 77.4603483080864, 72.79796048998833, 69.99057233333588, 66.44172996282578, 65.90420320630074, 70.93451768159866, 72.07872748374939, 74.5866385102272, 69.7523707151413, 69.73837226629257, 68.1149397790432, 65.16626760363579, 67.38749921321869, 68.51647943258286, 66.98922738432884, 60.92348366975784, 57.645251378417015, 68.23302984237671, 64.36416104435921, 67.69001618027687, 67.48714506626129, 66.87524110078812, 67.2014231979847, 66.35585457086563, 66.97788119316101, 67.1320541203022, 63.399134427309036, 64.56840768456459, 68.8596922159195, 67.36334010958672, 68.76459091901779, 66.38690650463104, 58.514200150966644, 62.117983773350716, 66.81748420000076, 61.717960238456726, 68.46445262432098, 64.36410784721375, 63.26813265681267, 49.38305452466011, 53.62296961247921, 56.105927377939224, 55.973998457193375, 52.44222477078438, 50.89400924742222, 46.564274579286575, 44.1976323723793, 45.84818780422211, 45.44023409485817, 48.14458318054676, 45.04035495221615, 45.06411127746105, 43.47059078514576, 45.23941107094288, 46.51531420648098, 50.51218293607235, 51.24807804822922, 50.27403071522713, 48.36363382637501, 46.491918861866, 43.30955922603607, 40.48477180302143, 41.608014330267906, 43.21596644818783, 44.570354372262955, 43.556716963648796, 44.75133866071701, 45.33319763839245, 45.21857678890228, 48.00823129713535, 46.75960309803486, 48.86069655418396, 49.129934906959534, 50.233631283044815, 43.90873767435551, 50.478744730353355, 57.073959633708, 60.31689181923866, 59.10330913960934, 61.77716106176376, 60.02118028700352, 59.95245337486267, 61.69207602739334, 57.13610529899597, 59.172758013010025, 61.43541119992733, 55.20166330039501, 56.630857810378075, 58.633661940693855, 56.792972311377525, 55.48734337091446, 57.69493371248245, 53.3208554238081, 58.00387613475323, 55.78655831515789, 60.10126858949661, 53.12831595540047, 51.65661692619324, 48.188448026776314, 51.94588020443916, 47.80580475926399, 52.42120049893856, 58.70172008872032, 55.784316435456276, 59.95597578585148, 52.77866631746292, 51.859856620430946, 49.06123839318752, 54.157395735383034, 52.73179203271866, 55.436779484152794, 32.31728866696358, 35.378252416849136, 22.64877587556839, 25.148599036037922, 12.420757357031107, 3.6601234367117286, 0.76315977727063, 0.03889729188813362, 0.1761062556761317, 0.16282390512060374, 0.07907829145551659, 0.11555965145817026, 0.11862717787153088, 0.05013916677853558, 0.020255785348126665, 0.06108768182457425, 0.03827551314316224, 0.7250057870987803, 34.1451957821846, 28.986830078065395, 58.12626376748085, 26.863697804510593, 54.19163189828396, 19.97353322803974, 0.9949488833080977, 1.4755675778724253, 13.742858413606882, 5.921250768005848, 30.33278625458479, 30.792517885565758, 19.006479419767857, 1.1993446061387658, 3.0109959561377764, 24.148321710526943, 25.485768243670464, 53.704703226685524, 16.657152883708477, 32.939064502716064, 41.21285833418369, 40.7945653796196, 37.18599021434784, 37.38166071474552, 36.139666959643364, 63.41140776872635, 64.13076996803284, 43.086598590016365, 41.52117379009724, 59.61653620004654, 2.2564105968922377, 0.09467267693253234, 0.10949508039630018, 0.06885983821121044, 0.02998348601977341, 0.10261799121508375, 0.06655459394096397, 0.18739819584880024, 0.4622279485920444, 1.2146161054261029, 5.123715838417411, 5.024960562586784, 27.065911553800106, 62.71124213933945, 74.4394040107727, 84.8589389026165, 76.54261395335197, 80.97332820296288, 73.01727712154388, 73.61899763345718, 68.62759307026863, 69.00276973843575, 73.70671972632408, 76.21165171265602, 77.40388333797455, 74.60400357842445, 73.87269482016563, 73.89622315764427, 69.69539657235146, 70.43268620967865, 74.81731653213501, 70.89804723858833, 69.31697487831116, 62.142044082283974, 71.85396954417229, 68.68918776512146, 72.56360426545143, 68.87584894895554, 69.657793790102, 67.97459810972214, 70.35725265741348, 70.82992449402809, 70.72586327791214, 68.02288591861725, 66.58549904823303, 70.8367109298706, 72.3207288980484, 70.75374618172646, 67.96357870101929, 60.09249106049538, 66.77543565630913, 68.18842023611069, 66.32923319935799, 72.05185532569885, 68.86480674147606, 65.16260460019112, 52.13229060173035, 57.61663131415844, 61.23035900294781, 56.83562882244587, 55.45626483857632, 52.539070174098015, 48.94765108823776, 48.02572935819626, 49.011434465646744, 47.82387278974056, 51.05042405426502, 47.8506575524807, 48.88091906905174, 47.556336745619774, 48.20638306438923, 49.58426512777805, 53.38810421526432, 56.34725242853165, 55.745349526405334, 50.20825244486332, 49.2104297876358, 45.40641590952873, 42.79925040900707, 45.67820392549038, 43.788975700736046, 44.59879584610462, 45.793991312384605, 46.42934001982212, 47.01887458562851, 45.55865854024887, 49.33267302811146, 50.14553301036358, 51.51814855635166, 51.273544281721115, 53.09233948588371, 49.71896030008793, 51.38941526412964, 58.725674003362656, 64.84437927603722, 62.88556918501854, 63.453912287950516, 62.62562893331051, 62.73906424641609, 61.4955847710371, 61.65823504328728, 62.19700053334236, 63.7231582403183, 57.340747117996216, 59.349912106990814, 59.7175195813179, 58.46506878733635, 58.41310277581215, 59.63203936815262, 58.044796139001846, 59.59710404276848, 59.86370533704758, 64.02927741408348, 56.934761703014374, 58.74758742749691, 55.00251218676567, 57.368941605091095, 50.62037453055382, 54.46626976132393, 61.005574464797974, 58.223329558968544, 62.23822832107544, 56.13145440816879, 55.843665450811386, 53.33375573158264, 57.59119547903538, 57.43688575923443, 64.90329131484032, 46.82090900838375, 51.14189274609089, 31.388012431561947, 25.916885510087013, 7.75299615226686, 4.348447239026427, 0.9020302724093199, 0.02888176964916056, 0.17075777548598126, 0.05742130902945064, 0.10405338645796292, 0.1326334266923368, 0.05850274807016831, 0.08313953876495361, 0.015610696027579252, 0.1811772320070304, 0.04172158682195004, 1.2031851313076913, 39.93140749633312, 32.61651501059532, 50.93449987471104, 34.196994602680206, 67.07617431879044, 27.45544385164976, 0.7562355394475162, 2.8853419236838818, 23.299291469156742, 17.68973607569933, 39.364230930805206, 47.94294700026512, 41.86915531754494, 23.06438997387886, 28.436868488788605, 55.418574661016464, 100.7346086204052, 112.6401449739933, 92.84620150923729, 102.48062252998352, 66.78577870130539, 77.9554009437561, 80.58664575219154, 56.243662387132645, 60.18467031419277, 72.78428122401237, 69.49639365077019, 60.24499207735062, 59.949516132473946, 70.00257968902588, 3.9845212921500206, 0.21420626202598214, 0.22086311888415366, 0.3271059226244688, 0.2165543579030782, 0.235031237534713, 0.15333836723584682, 0.4758235299959779, 0.6546242418698967, 3.1172261433675885, 7.310587791725993, 6.952999429777265, 31.586673371493816, 75.3546305000782, 83.53807657957077, 92.59387984871864, 81.53729394078255, 86.30549848079681, 78.04105594754219, 78.36412981152534, 73.9148573577404, 74.32100996375084, 78.31753671169281, 80.25828257203102, 82.73390293121338, 79.74039316177368, 78.16954225301743, 80.48314690589905, 73.94290745258331, 77.81686037778854, 78.49561035633087, 75.90480297803879, 71.02294653654099, 68.13070893287659, 75.26392936706543, 72.3758715391159, 76.54009088873863, 72.96245366334915, 72.85092204809189, 70.8878181874752, 74.07522395253181, 72.58041456341743, 72.67191365361214, 70.07740527391434, 69.39174726605415, 73.5024730861187, 74.78083088994026, 74.70872595906258, 70.72169110178947, 64.41662102937698, 69.24278005957603, 71.66423812508583, 69.95984718203545, 74.4026979804039, 70.07002606987953, 69.98624056577682, 55.87876796722412, 59.67268578708172, 65.89321419596672, 60.55931121110916, 57.97170326113701, 56.082619428634644, 51.817511692643166, 50.20886801183224, 53.69594469666481, 51.13216146826744, 55.84132857620716, 52.40973271429539, 51.93397544324398, 50.12922428548336, 50.88523171842098, 49.37900014221668, 55.73164366185665, 57.98543192446232, 58.439579755067825, 54.60187688469887, 51.39199152588844, 48.52983310818672, 44.800196439027786, 47.519284933805466, 47.731279358267784, 49.280824810266495, 49.009496569633484, 50.15185207128525, 50.19310645759106, 49.8677147179842, 54.58648011088371, 54.98678483068943, 56.42941541969776, 55.79219341278076, 57.4640467017889, 53.24341557919979, 57.50996343791485, 62.610232159495354, 66.0286009311676, 62.33314722776413, 64.09194365143776, 63.205789402127266, 67.01847061514854, 66.94799959659576, 64.87239897251129, 66.19833782315254, 68.1898945569992, 60.91342180967331, 61.20060659945011, 62.96132571995258, 60.90820848941803, 59.065440371632576, 63.169558346271515, 60.52426569163799, 64.56086128950119, 64.04869437217712, 66.5984183549881, 62.670078948140144, 63.60469959676266, 62.16818667948246, 67.46438428759575, 58.6371273547411, 59.73850965499878, 66.76373988389969, 62.460596188902855, 65.69466724991798, 59.729093760252, 59.7891191393137, 56.33784793317318, 63.45272295176983, 65.65179035067558, 73.19190815091133, 50.520899668335915, 56.46673321723938, 35.5777683109045, 30.20988754928112, 36.405242308974266, 8.492075018584728, 1.676409956999123, 0.08785308193182573, 0.23030161944916472, 0.1497840290539898, 0.24872782523743808, 0.24395795306190848, 0.3943728224840015, 0.37254611088428646, 0.17711030726786703, 0.28489084099419415, 0.23559954453958198, 1.0281191440299153, 49.709772393107414, 40.994476452469826, 75.6003101170063, 41.66724935173988, 77.46825948357582, 36.92074544727802, 0.7674493314698339, 3.8853577757254243, 36.79288990795612, 37.13891074061394, 73.6340980231762, 69.04965922236443, 46.81376539170742, 27.96371977776289, 46.19025304913521], [9.237860050052404, 77.22734481096268, 32.331674695014954, 49.046396389603615, 26.76259282976389, 14.469825904816389, 13.302793577313423, 17.576154470443726, 21.861357428133488, 29.60455533117056, 57.76204191148281, 51.40709951519966, 27.639232389628887, 47.13849976658821, 40.151062309741974, 0.9743092814460397, 0.10808065082528628, 0.057339079066878185, 0.021369780552049633, 0.16634921048535034, 0.06450334229157306, 0.08872842285200022, 0.04390498899738304, 0.07282517035491765, 0.17610604787478223, 1.7595053231343627, 3.6844183830544353, 35.87242729961872, 30.02402052283287, 27.410600557923317, 59.51845206320286, 78.95065873861313, 77.73611471056938, 70.76976612210274, 68.50546762347221, 59.76690173149109, 65.18144398927689, 65.22009551525116, 67.8837601840496, 70.8030067384243, 68.9956185221672, 70.5746465921402, 66.33579164743423, 68.56606677174568, 63.65158148109913, 67.76389941573143, 67.57918372750282, 69.8536504805088, 55.98863527178764, 57.626138404011726, 63.205265030264854, 64.32475715875626, 62.51635059714317, 66.3048005104065, 63.42797867953777, 65.32437711954117, 65.80747559666634, 64.18806329369545, 66.53787240386009, 69.321299046278, 67.18776673078537, 69.31430742144585, 66.87499031424522, 56.956466138362885, 62.75068022310734, 69.33446913957596, 65.11786580085754, 66.76213636994362, 67.67939195036888, 62.99156069755554, 55.010738745331764, 51.33820541203022, 57.07373544573784, 58.3622957020998, 56.83043070137501, 50.023183375597, 50.38848057389259, 47.065235897898674, 47.67373524606228, 44.236086308956146, 47.73844197392464, 44.65944059193134, 44.06924866139889, 42.724185436964035, 45.02514436841011, 45.98281837999821, 47.78098829090595, 49.015971422195435, 50.068446546792984, 50.129098892211914, 50.848077312111855, 45.69735109806061, 42.642695009708405, 40.229748487472534, 39.17519107460976, 41.7789975553751, 40.80726429820061, 44.11320470273495, 42.8327152132988, 45.3027118742466, 46.336860582232475, 45.47471344470978, 47.79728561639786, 48.21932137012482, 50.65232701599598, 49.629475101828575, 50.9571048617363, 44.287330359220505, 50.89681349694729, 57.013166695833206, 60.63354782760143, 59.67512145638466, 61.76256984472275, 60.77971078455448, 57.69624084234238, 57.24504165351391, 54.79480393230915, 59.06670190393925, 58.25213201344013, 58.819779753685, 58.360585793852806, 57.64657370746136, 55.4805189371109, 53.96702975034714, 57.56792172789574, 54.52452443540096, 56.576448529958725, 53.1827100366354, 46.70781567692757, 50.35600371658802, 45.74462056159973, 44.37164023518562, 49.35685493052006, 49.628813937306404, 48.16868908703327, 55.201306119561195, 52.463883608579636, 52.684796154499054, 48.6690766364336, 48.23674723505974, 48.71903255581856, 50.30194401741028, 48.61103855073452, 27.52050206065178, 22.05157522112131, 25.23247193545103, 19.397780522704124, 3.9963757060468197, 1.5954167093150318, 0.2832241851137951, 0.09774419610039331, 0.015371399786090478, 0.13751476944889873, 0.04985077561286744, 0.1968801417388022, 0.06001731933793053, 0.1483484185882844, 0.07262277184054255, 0.13343874597921968, 0.13427850091829896, 1.1858725477941334, 32.736459374427795, 25.61507150530815, 45.22799268364906, 25.396036058664322, 45.57499386370182, 24.671158455312252, 0.29318763641640544, 1.5857920632697642, 12.197324596345425, 4.799650702625513, 11.452306173741817, 3.8244586810469627, 1.9458297500386834, 0.4838690342148766, 0.801496395142749, 13.50064231082797, 56.83228500187397, 66.17895126342773, 45.97516559064388, 50.11530563235283, 27.738076485693455, 34.6381813287735, 39.15663667023182, 39.887231066823006, 42.31217734515667, 69.69171836972237, 62.37332247197628, 27.494475357234478, 50.505240708589554, 51.04423798620701, 1.3079636776819825, 0.07377799891401082, 0.13183266419218853, 0.058114322819164954, 0.15510971046751365, 0.0380620158102829, 0.060480382380774245, 0.02496650649845833, 0.3015718568349257, 0.36678202799521387, 2.015439164824784, 4.217549962922931, 40.26766285300255, 49.0300040692091, 52.699090987443924, 76.6023999452591, 79.28407564759254, 76.6699831187725, 70.05222782492638, 68.89672502875328, 63.49321737885475, 66.16797745227814, 68.9451952278614, 74.72061932086945, 73.54296371340752, 72.40721985697746, 73.11199843883514, 73.71408373117447, 70.99298134446144, 69.05498653650284, 71.63012355566025, 71.75726473331451, 73.80795389413834, 65.86553648114204, 61.84722550213337, 66.1931625008583, 67.74013549089432, 66.84969127178192, 69.49462294578552, 65.59595614671707, 69.68031138181686, 69.29374292492867, 68.50341573357582, 69.39116209745407, 72.65865236520767, 67.04303249716759, 71.30378946661949, 69.82844263315201, 60.106991082429886, 65.25633797049522, 70.63542053103447, 67.63895452022552, 69.2870020866394, 69.88481640815735, 64.98531371355057, 56.25549495220184, 55.33312104642391, 60.830392464995384, 61.53569921851158, 57.13482476770878, 52.225142419338226, 50.921249985694885, 49.63828302919865, 47.80621513724327, 46.365989819169044, 48.74358683824539, 47.6769232749939, 47.15497188270092, 45.27332805097103, 48.530273884534836, 47.38463535904884, 49.48805049061775, 51.36574253439903, 53.50236788392067, 54.69872988760471, 50.89599274098873, 48.04124392569065, 44.896665662527084, 43.69866594672203, 43.40621463954449, 44.55093741416931, 43.15828554332256, 44.38981465995312, 46.22014984488487, 48.23140472173691, 49.43462535738945, 47.123144790530205, 49.29030530154705, 52.67916485667229, 52.33634725213051, 54.49570298194885, 53.6935356259346, 48.61031658947468, 54.4260261207819, 58.99805098772049, 62.08973228931427, 62.83704958856106, 61.5538964420557, 62.945317178964615, 61.40725091099739, 62.1502972394228, 58.31409528851509, 59.52931948006153, 60.893704667687416, 60.470285788178444, 58.28339293599129, 61.12698554992676, 58.221752643585205, 56.78112454712391, 60.877889916300774, 59.55127850174904, 59.244505763053894, 56.052342653274536, 52.05482415854931, 58.49665269255638, 54.282507821917534, 49.466281458735466, 51.24474182724953, 51.85968942940235, 52.61408194899559, 56.3841712474823, 53.73619593679905, 55.35642899572849, 52.8513640165329, 51.82755075395107, 51.699577420949936, 54.845649003982544, 52.76932641863823, 42.79139243066311, 37.18658298254013, 28.695600405335426, 19.13134641945362, 1.915422237943858, 1.9084302568808198, 0.3486751683522016, 0.09841624050750397, 0.07727490228717215, 0.06141338817542419, 0.05968846628093161, 0.18502259597880766, 0.10540657400269993, 0.15003395470557734, 0.07071776039083488, 0.08919970146962442, 0.021413019931060262, 1.9482433330267668, 40.20840123295784, 31.235836297273636, 48.24721947312355, 29.632907509803772, 57.403481751680374, 31.46936796605587, 0.3595896373735741, 3.1259725615382195, 20.19548501819372, 14.075174331665039, 29.311287067830563, 18.077733255922794, 9.76516155526042, 1.2155095324851573, 5.955199571326375, 41.186936125159264, 146.14166289567947, 84.2020757496357, 130.3851243853569, 63.59220206737518, 19.81603927910328, 30.92603512108326, 58.11706446111202, 56.91619589924812, 52.011772468686104, 81.89452797174454, 69.66143399477005, 41.021265015006065, 60.39696492254734, 64.5244288444519, 2.7417633030563593, 0.1961595460306853, 0.3337873297277838, 0.12775897106621414, 0.3770231019007042, 0.17808948206948116, 0.17580613115569577, 0.12630556389922276, 1.5063363080844283, 0.6800596613902599, 4.182761879637837, 6.704115634784102, 46.21130771934986, 59.156190901994705, 63.490827307105064, 88.29940348863602, 84.60068956017494, 82.91712909936905, 78.35235804319382, 74.20347467064857, 68.35284501314163, 72.61515229940414, 73.25968891382217, 79.18924793601036, 79.85792845487595, 75.50902381539345, 77.23479241132736, 76.20953902602196, 75.28254076838493, 73.52067410945892, 76.1613880097866, 75.84779843688011, 77.66202628612518, 67.8036680817604, 68.48598226904869, 69.7227855026722, 71.35769337415695, 70.01634255051613, 73.41614931821823, 68.38989302515984, 70.90541884303093, 72.13566362857819, 70.82794100046158, 72.72802144289017, 74.42925855517387, 69.50485199689865, 74.42355886101723, 74.42491918802261, 62.97489479184151, 69.47563916444778, 76.0111440718174, 70.7747134566307, 72.56684929132462, 73.2483047246933, 70.23605436086655, 60.04725068807602, 58.06437648832798, 63.51172238588333, 63.76206815242767, 61.17545194923878, 56.65244825184345, 53.38977612555027, 52.59282968938351, 52.6841501891613, 50.62652640044689, 52.81191073358059, 51.11658230423927, 52.76229299604893, 50.15917427837849, 52.15560235083103, 49.62678484618664, 53.09248387813568, 52.9873663187027, 53.88436898589134, 57.84646958112717, 53.35435822606087, 51.812811344861984, 46.56775139272213, 45.19571341574192, 44.477673545479774, 48.217064291238785, 46.19177296757698, 48.71454879641533, 47.36103482544422, 52.979945316910744, 51.8431793153286, 50.95105938613415, 53.870324939489365, 55.77194809913635, 57.49798268079758, 58.3781598508358, 57.14782766997814, 50.89878939092159, 57.51516155898571, 63.72353442013264, 65.25724992156029, 64.47421833872795, 64.52594876289368, 66.78449437022209, 63.40848572552204, 64.38577428460121, 61.873402297496796, 63.88853296637535, 64.36070322990417, 64.56266239285469, 61.997211053967476, 63.24128329753876, 59.50095400214195, 56.53795659542084, 62.67470709979534, 63.1989573687315, 61.770678609609604, 62.250057086348534, 56.659208089113235, 62.23898448050022, 59.33572746813297, 59.93437014520168, 58.32145929336548, 55.328964069485664, 56.815387308597565, 61.13033317029476, 60.73835760354996, 56.444417014718056, 56.30628302693367, 55.91649994254112, 61.68047904968262, 66.97498574852943, 66.44602373242378, 51.39430560171604, 42.66836643218994, 30.81205263733864, 32.63616755604744, 22.745758071541786, 2.680839509703219, 0.4611519235186279, 0.1877100908313878, 0.19351701048435643, 0.20413169637322426, 0.22533580544404685, 0.28141019807662815, 0.15388930798508227, 0.2547654340742156, 0.28595395269803703, 0.1975848406436853, 0.5080023407936096, 1.8277367181144655, 48.669517412781715, 38.962448090314865, 64.32336643338203, 37.63758458197117, 71.16585686802864, 45.03931000828743, 0.29754472605418414, 6.202181093394756, 36.35537378489971, 39.85836021602154, 57.31259822845459, 20.949450060725212, 6.081825401633978, 0.8999335567932576, 12.21462981775403], [22.01089460402727, 67.05038890242577, 54.15451169013977, 36.58239260315895, 9.747971277683973, 1.1816661735065281, 1.9395213760435581, 11.922597438097, 11.99537018314004, 30.64825102686882, 64.2805427312851, 45.874862372875214, 38.09342712163925, 49.86426070332527, 40.773537307977676, 0.6185153732076287, 0.07161882414948195, 0.13726582343224436, 0.04398101460537873, 0.08440081131993793, 0.08133787880069576, 0.052712296674144454, 0.058669189529609866, 0.13363792357267812, 0.10237903450615704, 0.3307324420893565, 7.489647958427668, 24.487911388278008, 15.579217225313187, 20.462939366698265, 33.860872238874435, 61.64089657366276, 66.09598651528358, 71.15366712212563, 68.83562430739403, 64.98552650213242, 60.2381182461977, 61.162312254309654, 63.393328338861465, 66.81865453720093, 65.5026027560234, 70.70641592144966, 68.74465718865395, 69.76621717214584, 64.11565437912941, 64.34199303388596, 68.54107171297073, 65.8919906616211, 68.72648656368256, 56.6210163384676, 55.087677016854286, 59.25726927816868, 66.09321266412735, 64.00868251919746, 63.644555658102036, 65.67954406142235, 64.95374500751495, 64.64041382074356, 66.8386110663414, 65.0852483510971, 67.28783056139946, 68.16359996795654, 60.43516807258129, 61.14615932106972, 68.28388631343842, 64.36244353652, 66.82931676506996, 67.41493374109268, 67.14599937200546, 54.90239895880222, 48.506707549095154, 59.65910151600838, 56.45441047847271, 56.98119901120663, 51.07079476118088, 49.029228910803795, 48.28647896647453, 45.80459274351597, 44.63647462427616, 44.59417909383774, 44.72931884229183, 44.436726942658424, 43.0605623871088, 41.3706486672163, 43.380273431539536, 44.37768571078777, 46.44471399486065, 48.465950936079025, 50.31527370214462, 51.59700192511082, 50.105920135974884, 46.72410540282726, 44.272169172763824, 38.032212406396866, 41.95062294602394, 41.14898756146431, 40.7940524071455, 41.142774894833565, 43.59555467963219, 44.07492555677891, 43.9664451777935, 46.663943231105804, 45.75194276869297, 48.03495906293392, 52.81990170478821, 52.71549090743065, 51.817716881632805, 48.540305346250534, 44.78153184056282, 52.21335165202618, 54.20503377914429, 60.50987966358662, 57.34268121421337, 57.49006770551205, 58.064680472016335, 57.60226808488369, 57.24455527961254, 56.26050308346748, 58.220544308423996, 56.63845360279083, 56.494581922888756, 57.6201119273901, 57.77939938008785, 56.449140161275864, 59.07763011753559, 55.15506640076637, 55.69441705942154, 47.580613642930984, 53.65242563188076, 56.226700097322464, 47.989445105195045, 40.972764417529106, 44.91565704345703, 46.909546852111816, 48.72598238289356, 47.6097808778286, 45.844798386096954, 44.8417092114687, 42.953932508826256, 47.23474860191345, 44.717273488640785, 40.90863525867462, 31.10915869474411, 12.32768040150404, 20.36469753831625, 24.28029052913189, 13.183557875454426, 2.061799527145922, 0.5172120372299105, 0.057702549602254294, 0.09597259311703965, 0.07896845359937288, 0.13347376050660387, 0.12913225597003475, 0.07841954633477144, 0.11448730001575314, 0.02474442993843695, 0.1625541047542356, 0.1294456797768362, 0.20238484401488677, 1.6111445403657854, 38.36660586297512, 22.777972742915154, 34.692837595939636, 53.56634885072708, 41.132355853915215, 15.080667827278376, 0.12820641190046445, 3.549346080981195, 11.431178357452154, 2.602545660920441, 1.4019821514375508, 0.7054832065477967, 0.08334638274391182, 0.5345622624736279, 1.007122895680368, 7.024533916264772, 71.93530797958374, 59.6935922652483, 71.597840487957, 19.041849821805954, 8.777024578303099, 13.681256119161844, 21.98502939194441, 36.76990494132042, 40.93000911176205, 71.16375178098679, 61.72954201698303, 37.452914491295815, 58.15116003155708, 48.157483488321304, 0.35526867548469454, 0.10078502746182494, 0.07544309628428891, 0.07191363489255309, 0.02911696552473586, 0.042697099124779925, 0.09265332279028371, 0.06005785915476736, 0.04615811965777539, 0.08844582043820992, 0.8291975024621934, 8.037246074527502, 30.065005123615265, 25.359721407294273, 30.472945533692837, 60.70652671158314, 76.88690587878227, 70.52210301160812, 74.66223925352097, 66.33023634552956, 64.96557757258415, 62.28824503719807, 64.03936207294464, 69.4744536280632, 70.31886711716652, 73.11397433280945, 73.89756068587303, 73.60703587532043, 71.98250144720078, 69.72334027290344, 66.26434788107872, 71.79859891533852, 71.78890943527222, 73.22922974824905, 65.05988091230392, 62.620575204491615, 65.35525426268578, 66.77255541086197, 69.37910914421082, 64.46547120809555, 67.81627580523491, 68.12093585729599, 66.70693293213844, 69.60974916815758, 65.9822890162468, 68.3007650077343, 68.10287922620773, 62.93696902692318, 66.11199885606766, 71.15577220916748, 66.95170819759369, 69.28933516144753, 69.06522318720818, 68.88448968529701, 57.54716344177723, 53.476115092635155, 63.97805616259575, 58.467002883553505, 60.35478338599205, 55.527985990047455, 52.50979654490948, 49.02664124965668, 48.13075952231884, 46.85761883854866, 47.95406140387058, 48.67511831223965, 48.90658289194107, 45.880163088440895, 44.90239955484867, 44.87503342330456, 46.74120828509331, 46.275547072291374, 49.94852878153324, 54.49835903942585, 53.881807923316956, 51.846443340182304, 49.13982577621937, 45.277842208743095, 40.572326704859734, 43.11923883855343, 44.9528494477272, 43.72469834983349, 44.351653307676315, 46.26148782670498, 46.44551955163479, 46.82646431028843, 48.785152807831764, 48.84129859507084, 50.521021261811256, 55.65745264291763, 54.758166298270226, 55.75403206050396, 52.46720463037491, 47.44937628507614, 54.6510424464941, 56.59556910395622, 62.32300937175751, 62.36618645489216, 61.09861247241497, 58.15543480217457, 60.11957600712776, 61.51515372097492, 58.702442049980164, 59.662384539842606, 58.08032803237438, 60.22627428174019, 58.89919549226761, 60.405012890696526, 60.66421218216419, 61.1086705327034, 57.58080303668976, 57.840097323060036, 52.488004714250565, 59.56969991326332, 60.45161359012127, 57.243487536907196, 48.32280121743679, 50.69492273032665, 50.44900372624397, 52.5495196133852, 51.16983264684677, 50.91426596045494, 46.93129688501358, 47.50094331800938, 49.43627446889877, 48.83565589785576, 44.81638737022877, 40.1644641906023, 21.371027939021587, 20.559991858899593, 26.553448252379894, 16.87326818704605, 2.456435663625598, 1.0601674555800855, 0.08544933240045793, 0.05082995041448157, 0.14172350376611575, 0.17293599375989288, 0.15236271021422, 0.04673217830713838, 0.06786777230445296, 0.09357620569062419, 0.15631651680450886, 0.10648410563590005, 0.2117942672339268, 2.608635784126818, 47.19346761703491, 27.6088435202837, 42.53294549882412, 55.11335223913193, 48.51830832660198, 28.90817239880562, 0.0935189489973709, 5.784131325781345, 22.984892539680004, 16.809585504233837, 3.484131130389869, 2.347896625287831, 0.7600488129537553, 0.6279462890233845, 1.8978298944421113, 45.55282965302467, 139.68155354261398, 117.4693514406681, 129.5790660381317, 13.438937421888113, 3.7307150987908244, 10.907576903700829, 47.78938204050064, 58.253822922706604, 53.697612807154655, 83.98100361227989, 65.56627973914146, 51.86322323977947, 66.33288860321045, 61.3612125813961, 1.003808998502791, 0.2739423222374171, 0.4491712851449847, 0.11789404728915542, 0.2758850570535287, 0.3951922128908336, 0.25014796934556216, 0.2499605028424412, 0.4502970044268295, 0.34257702995091677, 1.3082112581469119, 10.541673637926579, 34.41530428826809, 33.71190883219242, 40.94498410820961, 74.3665923178196, 85.03937602043152, 81.2338650226593, 83.60220193862915, 71.53490826487541, 71.8578377366066, 67.6698924601078, 69.3452225625515, 74.20839160680771, 74.16322723031044, 77.30792328715324, 78.09953480958939, 77.01511099934578, 77.416453063488, 72.53075882792473, 71.15386471152306, 75.97677871584892, 74.01324167847633, 75.67022636532784, 67.9639282822609, 66.51265695691109, 69.33859571814537, 72.41365671157837, 71.28395453095436, 66.36493608355522, 71.0467104613781, 72.77552649378777, 72.36372739076614, 72.36860632896423, 71.02497562766075, 68.86331722140312, 74.76192310452461, 67.43172883987427, 67.65721634030342, 75.87253510951996, 69.45667818188667, 72.50867441296577, 74.55628573894501, 72.88817524909973, 61.208369582891464, 54.8955175280571, 66.8193992972374, 60.5052325129509, 63.2807631790638, 57.763983607292175, 55.19301116466522, 52.018171325325966, 50.65874107182026, 48.79431411623955, 50.180954709649086, 51.46858021616936, 51.27569116652012, 48.74922953546047, 48.55066359043121, 46.23088426887989, 48.56150820851326, 48.37608575820923, 53.2098063826561, 57.053246945142746, 56.95128321647644, 54.45123016834259, 51.649944484233856, 48.35374295711517, 42.026311084628105, 45.722190365195274, 47.02526584267616, 46.345246732234955, 47.693729773163795, 48.17933991551399, 48.345881178975105, 48.473470732569695, 52.80547387897968, 52.04586423933506, 53.517464473843575, 59.74563427269459, 59.38688412308693, 59.32967819273472, 55.82989878952503, 50.45171678066254, 58.18182818591595, 58.65164257586002, 64.69282060861588, 63.45834285020828, 62.30976328253746, 61.729853600263596, 62.44107663631439, 63.83231118321419, 61.52610093355179, 63.937405943870544, 60.78217305243015, 63.35129879415035, 61.5229395031929, 60.208890214562416, 63.12746040523052, 63.773421943187714, 62.12050683796406, 63.71283419430256, 56.96118928492069, 61.85178905725479, 63.329237177968025, 60.0079607963562, 57.28196807205677, 59.41300772130489, 56.74275800585747, 58.624975606799126, 54.89412300288677, 56.431220322847366, 55.00345453619957, 52.58289322257042, 58.06496925652027, 56.322546154260635, 60.839929953217506, 59.83100809156895, 39.26850646734238, 26.176764965057373, 34.43194359540939, 33.76647010445595, 7.569437501952052, 2.0806023431941867, 0.10543182928813621, 0.23599175474373624, 0.1797354914015159, 0.2020054284366779, 0.2679417614126578, 0.3109632310224697, 0.1540489142644219, 0.17614171549212188, 0.3187486866954714, 0.3046374017139897, 0.6104333256371319, 2.7520191902294755, 56.58274859189987, 38.13489809632301, 49.83293138444424, 69.04161125421524, 62.71190330386162, 44.69528786838055, 0.2124161721440032, 11.415227763354778, 43.784636333584785, 45.380907878279686, 34.10035818815231, 2.8211222821846604, 0.6946365104522556, 0.7017155305948108, 3.7727396562695503], [39.926771745085716, 74.46911081671715, 84.50782254338264, 12.063774112612009, 1.591335847042501, 2.239496042020619, 0.7603827200364321, 7.944618444889784, 13.434624653309584, 32.3755319416523, 70.05203783512115, 31.435810066759586, 29.773285277187824, 39.78779040277004, 37.12137848138809, 0.6694633362349123, 0.3080494108144194, 0.27072264812886715, 0.07522050393163227, 0.09009370740386657, 0.15191286482149735, 0.09598456395906396, 0.06794417640776373, 0.071744477172615, 0.13270376744912937, 0.20901324693113565, 9.887408595532179, 32.96457253396511, 18.802475966513157, 19.050030782818794, 23.693393021821976, 33.35782863199711, 39.899151027202606, 50.41948691010475, 63.72802197933197, 69.1241580247879, 62.54424870014191, 59.423548355698586, 60.95426581799984, 63.818426728248596, 64.58826541900635, 67.99206957221031, 69.3570551276207, 67.6205787062645, 66.31743863224983, 62.92511746287346, 65.18938556313515, 69.73054468631744, 68.09483125805855, 67.99269273877144, 64.83297228813171, 60.097780376672745, 59.47980813682079, 62.71494314074516, 64.47370156645775, 66.35134801268578, 60.13082720339298, 64.95675444602966, 66.03715047240257, 66.08179807662964, 65.81246092915535, 62.36059695482254, 59.949823915958405, 65.29595464468002, 66.0820184648037, 65.3096567094326, 64.93381127715111, 66.64405390620232, 58.826877772808075, 48.90011563897133, 59.054694548249245, 59.796920120716095, 57.57272467017174, 55.29050253331661, 53.456899523735046, 50.54342105984688, 48.440473303198814, 46.863265335559845, 47.48656868934631, 45.83869591355324, 48.17105256021023, 46.05641283094883, 43.59049715101719, 40.47287844121456, 42.917135283350945, 43.757957965135574, 44.39033903181553, 45.73041692376137, 50.86593635380268, 50.904356092214584, 45.59575214982033, 43.92440803349018, 42.23400413990021, 40.7801603525877, 39.08139690756798, 41.77995890378952, 44.04144175350666, 45.23221045732498, 46.266096979379654, 45.94460763037205, 47.654147297143936, 44.19916369020939, 43.248359709978104, 45.43247111141682, 49.88029204308987, 53.1119654327631, 54.63682360947132, 53.965175449848175, 47.750403732061386, 48.13896708190441, 53.75625506043434, 53.71264100074768, 59.656483456492424, 58.98272641003132, 60.542823895812035, 54.40920442342758, 58.24989013373852, 56.577554270625114, 57.49650456011295, 57.60178551077843, 59.39935505390167, 55.415804609656334, 55.87181434035301, 57.95892454683781, 53.82222332060337, 52.108921855688095, 51.364826783537865, 52.666161954402924, 53.04324612021446, 51.705904081463814, 48.96106816828251, 39.38607595860958, 42.52569168806076, 44.67748962342739, 45.64076453447342, 43.467919528484344, 41.32892310619354, 40.790856778621674, 38.746900856494904, 38.841075003147125, 35.186279118061066, 25.14083795249462, 4.488236038014293, 10.829826425760984, 18.762078434228897, 13.413180503994226, 4.551079915836453, 0.5032207723706961, 0.11604188417550176, 0.08616157894721255, 0.09970849772798829, 0.02476828627550276, 0.0965968357922975, 0.11592345224926248, 0.024083868411253206, 0.027905556016776245, 0.11754152714274824, 0.12737977813230827, 0.02086603853967972, 0.2589405491016805, 2.2488893754780293, 38.47154103219509, 24.599378407001495, 41.97175741195679, 44.050071090459824, 39.10975098609924, 6.970794349908829, 0.03307528808363713, 3.583237174898386, 10.06918229162693, 11.185501590371132, 7.656715018674731, 2.267251177690923, 0.09766408868017606, 0.09218565101036802, 1.2272769073024392, 32.38228797912598, 50.744206085801125, 57.71837845444679, 43.176239579916, 4.9202619306743145, 4.255688041448593, 4.918855056166649, 15.476971361786127, 34.166953414678574, 45.69247215986252, 76.47084340453148, 44.551617577672005, 29.423707835376263, 48.36291566491127, 45.0991415977478, 0.7976276683621109, 0.04609357136359904, 0.06995283620199189, 0.13732935127336532, 0.12086646747775376, 0.07715050349361263, 0.08703502739081159, 0.02979060369398212, 0.021237314613244962, 0.2269863715628162, 0.030013273972144816, 10.157849583774805, 32.07935683429241, 21.100047379732132, 28.060694374144077, 45.401563569903374, 57.162700071930885, 57.364241257309914, 64.93403166532516, 66.61259159445763, 70.57295188307762, 65.4274807870388, 61.298709735274315, 66.55646100640297, 71.15795329213142, 71.1575885117054, 71.50890246033669, 74.38841074705124, 72.43273168802261, 69.69967514276505, 64.44875210523605, 67.05391511321068, 70.65891847014427, 71.6652412712574, 70.06239607930183, 69.6451860666275, 67.95260488986969, 63.92955556511879, 64.30470943450928, 65.17448276281357, 68.26176390051842, 63.7201564013958, 68.86876612901688, 67.97487169504166, 68.63345995545387, 69.08774837851524, 62.545764818787575, 64.04023602604866, 69.44087103009224, 66.46030336618423, 69.07979160547256, 67.37110689282417, 69.00352209806442, 57.28326380252838, 53.44831958413124, 63.48478563129902, 62.98619918525219, 60.38075879216194, 58.53638336062431, 54.02223698794842, 52.84411020576954, 52.08941750228405, 49.0498124063015, 49.337969943881035, 48.13982963562012, 51.822793409228325, 47.826388254761696, 44.704540371894836, 42.85035386681557, 45.40354706346989, 45.18912456929684, 46.31876975297928, 49.70354452729225, 51.75641857087612, 51.54031276702881, 45.191282853484154, 45.0093562155962, 44.44728657603264, 41.75908662378788, 40.90534083545208, 46.2550737708807, 46.121932715177536, 47.07513056695461, 50.435199066996574, 48.13428193330765, 49.48418229818344, 47.35065758228302, 46.3001811504364, 49.91769343614578, 51.680111065506935, 54.637796357274055, 56.59270025789738, 57.64345407485962, 53.13433863222599, 50.83085283637047, 56.29263415932655, 54.99734826385975, 63.14145505428314, 61.788036078214645, 62.19459146261215, 58.62240694463253, 59.14140969514847, 59.17439192533493, 61.48265786468983, 59.957609698176384, 60.531401708722115, 57.60337382555008, 57.70992770791054, 59.11585986614227, 58.342996537685394, 53.39664235711098, 56.6399697214365, 56.83937542140484, 55.48510529100895, 55.090891644358635, 52.97066621482372, 50.63349902629852, 46.0327173024416, 48.40390406548977, 49.7743309289217, 46.82604253292084, 46.017692908644676, 45.43598212301731, 43.440059423446655, 41.53395250439644, 38.69108185172081, 28.175968788564205, 6.89431537874043, 11.763203591108322, 22.52141810953617, 15.10885376483202, 1.81557024596259, 1.197791676968336, 0.17624761996557936, 0.05335537876817398, 0.030058799165999517, 0.009729080138640711, 0.04719915617897641, 0.04791361061506905, 0.04489126986300107, 0.05609441577689722, 0.05366978592064697, 0.0371807006013114, 0.04897103746770881, 0.2605940244393423, 3.533486919477582, 50.652923583984375, 29.957936368882656, 44.26519274711609, 54.241443425416946, 47.70978771150112, 15.977255366742611, 0.06992165115661919, 6.775254467502236, 20.58669302612543, 24.160705246031284, 16.65902428328991, 4.417450111359358, 0.21549581782892346, 0.3350334253627807, 1.2063685292378068, 59.62862715125084, 140.54810464382172, 169.19154524803162, 80.39271175861359, 3.6682975105941296, 5.976359685882926, 3.780280826613307, 39.2665571719408, 50.50221607089043, 60.24358615279198, 91.35005459189415, 48.25391471385956, 44.54274885356426, 55.69602817296982, 55.48406034708023, 1.4105091313831508, 0.3816664527403191, 1.1812481959350407, 0.17125790880527347, 0.5421088950242847, 0.2903911645989865, 0.36509482946712524, 0.2158113196492195, 0.19527077965904027, 0.39132010191679, 0.5544563918374479, 11.787176504731178, 40.90858966112137, 39.91784982383251, 49.02737461030483, 63.912152498960495, 66.71802833676338, 70.60512855648994, 71.78322494029999, 74.39398124814034, 75.5219355225563, 70.48817083239555, 66.77595242857933, 72.5822764635086, 78.81352409720421, 76.71686500310898, 78.8941177725792, 76.08068034052849, 77.22974628210068, 73.32718849182129, 71.4471785724163, 72.43876576423645, 76.76186978816986, 76.30928367376328, 75.61709761619568, 73.90441551804543, 70.03104776144028, 68.18009108304977, 67.64540657401085, 69.44648712873459, 71.3124530017376, 65.89718118309975, 73.26601177453995, 69.36358317732811, 72.10389733314514, 71.47520586848259, 68.0927261710167, 66.160659044981, 72.37299889326096, 70.39563819766045, 71.7472256720066, 70.31304582953453, 72.49995768070221, 64.43191140890121, 55.49074798822403, 66.21289864182472, 65.92259421944618, 62.23154067993164, 59.98356610536575, 57.394263446331024, 56.17851108312607, 52.510651499032974, 51.229356452822685, 53.07943157851696, 50.746865943074226, 53.22508916258812, 52.99271643161774, 48.37961956858635, 45.89117869734764, 46.944181993603706, 46.89624756574631, 48.23104374110699, 50.55417828261852, 55.63072867691517, 55.35212382674217, 47.54234969615936, 47.21627779304981, 46.828295812010765, 45.22485785186291, 43.53158891201019, 49.01802331209183, 48.62035945057869, 48.65485019981861, 51.642105504870415, 49.53644089400768, 52.159797325730324, 49.11371357738972, 47.575426921248436, 54.28047113120556, 55.722771137952805, 59.17063392698765, 60.80858163535595, 59.74766716361046, 54.478752091526985, 54.29042659699917, 59.03850361704826, 58.20596069097519, 63.542382940649986, 63.893457502126694, 64.74432304501534, 60.67932017147541, 62.90820077061653, 61.068955063819885, 61.461561396718025, 61.20634809136391, 62.328496277332306, 60.126833617687225, 61.296437457203865, 64.8491670191288, 59.81867775321007, 60.075999945402145, 57.80994214117527, 60.62587983906269, 61.81623816490173, 59.54749770462513, 56.90814033150673, 54.33405205607414, 54.312385618686676, 56.58044591546059, 55.60055449604988, 55.35042531788349, 53.579686135053635, 51.574062556028366, 49.38975736498833, 49.438402354717255, 52.70432710647583, 45.941020622849464, 29.396613389253616, 19.158904440701008, 30.646077543497086, 26.63674358278513, 12.82570542767644, 2.067723171785474, 0.38912527437787503, 0.18091771780746058, 0.2619849279290065, 0.09196583429002203, 0.23072353040333837, 0.22327541053527966, 0.150354235956911, 0.1491803809767589, 0.21730572305386886, 0.1358151770546101, 0.1804580315365456, 0.6016169080976397, 4.653044594451785, 64.7027836740017, 42.137762904167175, 59.08240266144276, 57.43519864976406, 59.82439644634724, 42.30303503572941, 0.21105053136125207, 10.911983717232943, 45.904979556798935, 47.952169105410576, 38.746593073010445, 4.757835371419787, 0.3798351885052398, 0.40426633378956467, 2.078935895115137], [41.87508299946785, 69.63293552398682, 48.694539070129395, 10.998435728251934, 1.3200788525864482, 0.3233353077666834, 1.1112432461231947, 5.535386223345995, 16.93631250411272, 50.73888257145882, 47.05612778663635, 39.62887153029442, 73.02253603935242, 46.62705101072788, 31.845323592424393, 0.7830034999642521, 0.035779677928076126, 0.11296670621959493, 0.35726787289604545, 0.2545004873536527, 0.11304532934445888, 0.04970976755430456, 0.02488271060428815, 0.0421031063888222, 0.18645549018401653, 0.0826603636960499, 4.296911079436541, 38.876036927103996, 41.0555087774992, 38.35082910954952, 32.90627986192703, 31.24895129352808, 27.711061835289, 32.74633124470711, 53.84528808295727, 67.56832391023636, 71.09640419483185, 64.2535337805748, 58.45548190176487, 56.868649050593376, 59.777909740805626, 64.20280650258064, 67.19509273767471, 68.00353735685349, 65.63547402620316, 63.855033963918686, 59.61476169526577, 64.93871301412582, 66.87007337808609, 68.54650542140007, 63.63048881292343, 67.23537057638168, 64.74216476082802, 57.662977427244186, 59.51168082654476, 59.01165425777435, 62.38108545541763, 63.33340175449848, 62.17856012284756, 66.79228395223618, 65.31271934509277, 61.69618360698223, 65.58913171291351, 64.36590135097504, 62.934932336211205, 63.562601655721664, 65.57338535785675, 59.108803644776344, 49.233129769563675, 58.588417768478394, 62.05561392009258, 61.25319577753544, 58.83243687450886, 51.82316578924656, 51.465654373168945, 48.340075090527534, 49.73000630736351, 49.51411709189415, 47.45758764445782, 52.64395594596863, 51.046764850616455, 46.87633663415909, 43.326513916254044, 41.23492754995823, 44.311246275901794, 41.2032600492239, 41.84767127037048, 43.64063926041126, 45.069043412804604, 44.951694309711456, 43.8556507229805, 41.2299308180809, 42.311983555555344, 39.925236627459526, 39.42212462425232, 41.24038025736809, 46.163479685783386, 50.683511942625046, 53.04535120725632, 46.7633268982172, 46.310440599918365, 44.409094825387, 45.382853373885155, 46.48053087294102, 51.81748889386654, 50.0847552716732, 52.80002877116203, 55.30231989920139, 56.12504415214062, 47.68526382744312, 49.82882380485535, 54.452966675162315, 54.62749511003494, 56.41995392739773, 58.70520830154419, 56.230465695261955, 55.813814252614975, 56.421736031770706, 60.71847327053547, 58.08208353817463, 59.310268834233284, 56.54535099864006, 54.3013434112072, 55.63711993396282, 53.06892894208431, 46.69884815812111, 55.43568894267082, 52.63240456581116, 48.059391751885414, 49.00505840778351, 45.50070784986019, 44.595026448369026, 36.72600209712982, 37.34001114964485, 39.32834945619106, 39.045781418681145, 35.28118282556534, 33.48939657211304, 34.093267768621445, 29.022388570010662, 14.146158322691917, 3.21670931763947, 3.4369115391746163, 5.423477003350854, 6.160529628396034, 4.268158497288823, 0.43373200111091137, 0.08547361547243781, 0.052603987642214634, 0.051528689873521216, 0.023822289185773116, 0.13540285464841872, 0.017206658631039318, 0.12678919185418636, 0.049100601609097794, 0.09899528638925403, 0.06865979230497032, 0.06843707378720865, 0.09067866078112274, 0.0569673706922913, 1.1170114553533494, 29.43679053336382, 24.81535691767931, 45.12706249952316, 37.698198929429054, 40.194908156991005, 3.50802234839648, 0.1744311096263118, 2.9403140489012003, 16.26428436487913, 15.879571158438921, 25.629223845899105, 9.74981227889657, 0.5535965692251921, 0.14805780840106308, 1.1741974367760122, 57.718663439154625, 52.28742867708206, 64.69560205936432, 8.393321167677641, 5.0522027257829905, 0.5463790346402675, 4.6443763095885515, 9.277604017406702, 31.02000977844, 62.69488401710987, 59.6742133051157, 43.74749332666397, 60.265450179576874, 52.352534383535385, 39.20879267156124, 1.2291522254236042, 0.36562596971634775, 0.05406620410212781, 0.24354583845706657, 0.3511216433253139, 0.1451639668084681, 0.040618072598590516, 0.03858217227389105, 0.034574652745504864, 0.06228255442692898, 0.034347010077908635, 6.560994414612651, 42.40785241127014, 41.67228028178215, 41.09775871038437, 48.69173862040043, 43.97300362586975, 43.321885764598846, 49.86873686313629, 63.1880671530962, 72.60591879487038, 71.42529174685478, 68.74156415462494, 62.24249169230461, 61.921792700886726, 66.9294261932373, 68.77244889736176, 75.10557666420937, 72.51911625266075, 70.55301055312157, 67.14325591921806, 63.27906087040901, 65.84849819540977, 69.45274159312248, 70.51989912986755, 68.02011206746101, 68.48587587475777, 69.301578104496, 61.8403934687376, 62.887974455952644, 64.2724035680294, 66.17037132382393, 64.6515928208828, 65.18318429589272, 69.48348954319954, 69.04326796531677, 65.19275978207588, 69.93550568819046, 67.16170772910118, 65.0940790772438, 66.59577369689941, 68.72595459222794, 59.08559828996658, 54.02208499610424, 66.82020485401154, 65.31914860010147, 62.87451557815075, 59.25089322030544, 54.9335040897131, 54.15109187364578, 52.27383300662041, 53.44829298555851, 50.3034183382988, 50.36342851817608, 56.549333184957504, 53.8046682626009, 49.85947296023369, 45.389199033379555, 44.96153578162193, 46.016997545957565, 41.744453608989716, 44.8565474152565, 43.987344056367874, 47.32769541442394, 47.00421877205372, 43.51613514125347, 41.561227440834045, 43.21017175912857, 43.67709830403328, 41.640787571668625, 44.13730300962925, 47.743001729249954, 53.79050262272358, 56.83869145810604, 50.53521350026131, 47.058308869600296, 48.70017796754837, 47.56286099553108, 47.8350555896759, 55.23189067840576, 53.6997064948082, 56.185487508773804, 58.58913592994213, 60.62175706028938, 51.496919095516205, 51.67209729552269, 57.96126142144203, 56.69988490641117, 58.41390073299408, 60.64564637839794, 60.546057522296906, 58.94659034907818, 59.220247864723206, 61.724955663084984, 61.393130868673325, 59.01530206203461, 58.650495037436485, 56.28527395427227, 57.086688950657845, 55.26702739298344, 51.22407853603363, 57.243536934256554, 55.396391451358795, 52.042455822229385, 52.86579184234142, 50.656928569078445, 51.60921826958656, 42.86549985408783, 43.99306274950504, 42.109773606061935, 43.59324440360069, 42.14523330330849, 41.52084320783615, 36.66735224425793, 30.28528120368719, 12.150691598653793, 2.458531726151705, 4.697771044448018, 4.007288245484233, 3.4238321660086513, 1.6318521229550242, 0.20630875689676031, 0.0576161895878613, 0.13117227150360122, 0.04828558987355791, 0.058132535123149864, 0.084253353998065, 0.06198352828505449, 0.07418758279527538, 0.1028046190913301, 0.1050283903896343, 0.048104208981385455, 0.02592807013570564, 0.03288516469183378, 0.10248432299704291, 4.107391973957419, 42.96121671795845, 31.393199153244495, 46.42500825226307, 42.600000500679016, 49.70433108508587, 12.294303942471743, 0.372891565784812, 5.9652248583734035, 28.53366259485483, 27.381347827613354, 41.813697293400764, 17.902064882218838, 0.6474798533599824, 0.20132127217948437, 1.440583448857069, 74.05178681015968, 115.70873111486435, 154.44029599428177, 19.259686432778835, 3.4702348010614514, 3.603893341496587, 6.831517573446035, 39.24693502485752, 46.15918591618538, 80.80957978963852, 67.44609966874123, 55.48018075525761, 87.33061507344246, 66.08487591147423, 46.84040196239948, 1.7556663416326046, 0.6948550581000745, 0.5174323066603392, 1.0586519306525588, 0.856044664978981, 0.33922685659490526, 0.32320471946150064, 0.14281955198384821, 0.21328659262508154, 0.42709384637419134, 0.17595660901861265, 7.113704206421971, 42.829823568463326, 58.73198926448822, 69.50390964746475, 67.80239894986153, 60.97579166293144, 57.001056745648384, 61.52116119861603, 73.63207653164864, 78.18374589085579, 76.82366207242012, 72.60686114430428, 68.325205296278, 68.56716871261597, 70.83278954029083, 72.65330985188484, 78.01935911178589, 77.05598920583725, 74.0445975959301, 72.14238166809082, 68.15270215272903, 71.0899369418621, 73.80410850048065, 75.7902543246746, 69.93182748556137, 73.19584473967552, 71.06941804289818, 64.42972272634506, 66.76227316260338, 69.92117285728455, 68.19120168685913, 67.68192261457443, 66.93976163864136, 73.71272340416908, 72.5971108675003, 67.42662951350212, 71.04658126831055, 67.60353282094002, 67.31746897101402, 70.18341958522797, 73.32258313894272, 64.10428538918495, 56.20525024831295, 66.38401865959167, 67.94371336698532, 66.03539496660233, 62.690719440579414, 59.58411633968353, 58.46020124852657, 54.56146985292435, 55.67130669951439, 53.74604880809784, 52.65652947127819, 56.81846894323826, 58.45450535416603, 54.32519473135471, 48.166838586330414, 46.29000909626484, 49.0836837887764, 44.56400491297245, 45.32223902642727, 46.75613388419151, 48.54592904448509, 48.21746326982975, 45.673362985253334, 43.65193225443363, 46.39340914785862, 45.771241933107376, 42.909957468509674, 48.010883554816246, 52.20037914812565, 55.077565759420395, 58.41055691242218, 52.51340255141258, 51.218929812312126, 50.87989680469036, 50.73132857680321, 51.12276077270508, 59.393089190125465, 57.087863087654114, 58.74653488397598, 62.032693549990654, 61.81424707174301, 53.94140012562275, 55.69663234055042, 60.0569249689579, 60.28929390013218, 60.79324945807457, 63.545992746949196, 61.79142169654369, 60.88538311421871, 63.36002692580223, 64.80201914906502, 64.76180970668793, 62.85486303269863, 61.980883330106735, 59.467530995607376, 61.56971499323845, 59.7037149220705, 55.396201461553574, 63.08359935879707, 59.35443006455898, 53.11633139848709, 57.9752142727375, 55.56848421692848, 58.02961975336075, 51.41524627804756, 53.78159590065479, 51.464924812316895, 52.79354251921177, 50.94313681125641, 52.665322199463844, 49.257277473807335, 42.546259984374046, 22.231769151985645, 8.283735048025846, 11.497871428728104, 11.346592996269464, 8.397836275398731, 6.998569909483194, 0.6468175607733428, 0.21666527929482982, 0.20492058451054618, 0.1708973734639585, 0.17421429860405624, 0.13281841442221776, 0.10007510383729823, 0.2707487717270851, 0.2271525384276174, 0.17475904984166846, 0.20213324110955, 0.1502488658297807, 0.2171877512591891, 0.36808987031690776, 6.531357429921627, 61.95952467620373, 40.17185479402542, 65.19612640142441, 51.186247766017914, 66.392180621624, 33.28282065689564, 0.44229000282939523, 9.557639490813017, 53.493077382445335, 44.88779693841934, 65.11085137724876, 18.665392622351646, 0.9077823325060308, 0.2752987603889778, 1.8501913757063448], [50.340941324830055, 70.56176528334618, 18.35978452116251, 4.991195099428296, 1.4476773119531572, 5.230049332603812, 1.3593224342912436, 8.874661289155483, 21.13540258258581, 56.93882368505001, 36.70215077698231, 67.3970215022564, 93.9690412580967, 42.129376754164696, 31.010550186038017, 3.59009200707078, 0.06587136536836624, 0.2021223315387033, 0.03383726223546546, 0.012520582349679898, 0.10259445029078051, 0.044264388852752745, 0.06369567781803198, 0.0397262485785177, 0.1430727876140736, 0.019657528973766603, 4.234071476384997, 26.692518889904022, 64.57439616322517, 66.00900918245316, 47.82757759094238, 34.71348188817501, 27.102824673056602, 30.343315489590168, 47.3321183770895, 69.21706303954124, 75.70742636919022, 67.08390310406685, 60.04872500896454, 54.4852801412344, 57.382677868008614, 62.754100039601326, 64.14775505661964, 68.21339249610901, 63.60758364200592, 63.99943381547928, 59.70912203192711, 59.880375042557716, 64.55934137105942, 65.52473276853561, 63.52213762700558, 63.467272371053696, 62.587004005908966, 65.86607605218887, 64.02330413460732, 58.10178168118, 60.75705640017986, 58.634999468922615, 65.36124274134636, 64.91503268480301, 61.213746294379234, 62.424657717347145, 64.58109140396118, 63.721919506788254, 65.044856518507, 64.19339820742607, 63.12515012919903, 48.16080451011658, 59.35361310839653, 61.29791937768459, 63.56328941881657, 58.11115577816963, 55.18817402422428, 54.80335347354412, 51.93487599492073, 48.578972071409225, 49.646703377366066, 45.958317294716835, 56.08175687491894, 55.13895146548748, 52.6319295912981, 46.76876820623875, 41.44007854163647, 44.03368256986141, 43.12788337469101, 40.37471070885658, 43.24362516403198, 40.27217321097851, 42.45820350944996, 41.229949817061424, 42.346208319067955, 38.26311841607094, 42.9829553514719, 42.66830563545227, 41.53740651905537, 39.76343750953674, 46.49618603289127, 52.92947642505169, 58.54046814143658, 52.45382934808731, 46.85557834804058, 43.71209442615509, 43.50114494562149, 43.925680965185165, 47.001110538840294, 53.27049292623997, 52.93642245233059, 53.14096927642822, 56.42703674733639, 55.89282341301441, 46.603781059384346, 54.28649760782719, 53.3670799434185, 53.465000689029694, 54.99277710914612, 55.83583407104015, 56.962906792759895, 53.55773851275444, 56.96647100150585, 59.1026745736599, 55.81095680594444, 57.70110458135605, 53.13205115497112, 53.63193333148956, 50.33893123269081, 42.57430627942085, 50.14879323542118, 53.21558967232704, 49.80127528309822, 48.70172828435898, 42.34930895268917, 38.67424115538597, 35.99915809929371, 34.48242388665676, 34.18025650084019, 31.99173353612423, 33.402715623378754, 33.41239370405674, 20.287343189120293, 8.583827745169401, 0.9372970112599432, 0.5341317574493587, 0.18452296731993556, 0.08962434352724813, 0.19194830325432122, 0.1751239935401827, 0.1115955512796063, 0.0520796009368496, 0.03747727023437619, 0.08926553739001974, 0.043475704806041904, 0.07090245126164518, 0.0516234398673987, 0.050147593865403906, 0.054191946182982065, 0.07696606495301239, 0.03195009943738114, 0.005729305385102634, 0.10585119467577897, 0.05786160298157483, 2.2431702073663473, 22.419779263436794, 23.591602183878422, 41.944854855537415, 45.19086107611656, 35.97439102828503, 2.3698231112211943, 0.11561346458620392, 1.31771894171834, 17.154415100812912, 18.260942324995995, 45.780638828873634, 28.61244186758995, 0.04714272698038258, 0.26108235761057585, 4.197143157944083, 68.95920887589455, 73.14238160848618, 51.31375752389431, 4.9295776057988405, 1.8330309027805924, 5.002061566337943, 3.6594468355178833, 9.873221106827259, 32.83031053841114, 74.18946862220764, 47.184826880693436, 66.89693033695221, 96.18429198861122, 49.639772549271584, 38.29435653984547, 5.8328076638281345, 0.44570759288035333, 0.20403591479407623, 0.2275984949665144, 0.021563002410402987, 0.07814205731847323, 0.04212485873722471, 0.03171754004142713, 0.05213318028836511, 0.1021103622042574, 0.10836987319635227, 3.071236261166632, 33.533101826906204, 68.16834211349487, 70.1319931447506, 58.05647291243076, 44.540100395679474, 38.96754741668701, 42.479809150099754, 57.27441027760506, 73.16442802548409, 75.70267662405968, 69.35670554637909, 65.57210102677345, 59.68821935355663, 60.911119133234024, 68.40294912457466, 68.97721230983734, 71.14956334233284, 67.89299368858337, 68.60774293541908, 62.75028124451637, 64.86294507980347, 67.51391842961311, 68.75004529953003, 67.20555737614632, 69.99563366174698, 65.92897787690163, 68.02626013755798, 64.9074786901474, 61.4124870300293, 61.45533733069897, 62.23144568502903, 68.3745950460434, 66.76856562495232, 64.00387957692146, 67.08331033587456, 67.3755906522274, 67.28922128677368, 67.84342914819717, 67.65382692217827, 64.73448917269707, 52.11610347032547, 64.8303048312664, 65.0740085542202, 65.24063721299171, 60.41801579296589, 57.37267680466175, 57.36816264688969, 54.36560936272144, 51.288515478372574, 50.84207743406296, 50.50612226128578, 60.079009383916855, 58.35666820406914, 54.43012610077858, 47.79927670955658, 41.621545404195786, 47.917799949645996, 44.090599715709686, 42.173537984490395, 43.738723397254944, 41.760522946715355, 44.19889010488987, 43.035156950354576, 43.65980923175812, 40.16396641731262, 43.5488323867321, 44.569282829761505, 42.84401200711727, 42.70971201360226, 49.78580631315708, 54.00672622025013, 59.244764149188995, 56.55162826180458, 49.64886926114559, 45.77073276042938, 46.788515746593475, 47.56563104689121, 49.95776228606701, 56.05127491056919, 55.79850107431412, 58.692718371748924, 59.27043177187443, 61.14026963710785, 52.394826114177704, 55.09704351425171, 58.894149363040924, 55.837798565626144, 58.6550547927618, 58.408056646585464, 59.641014486551285, 55.68818159401417, 57.83391125500202, 62.201446294784546, 59.627190828323364, 58.67904670536518, 56.13742768764496, 54.5624615997076, 53.47139194607735, 48.3461357653141, 50.634779557585716, 55.01945547759533, 53.567868769168854, 52.56387524306774, 49.41480942070484, 44.10812817513943, 39.83947142958641, 41.51316002011299, 41.6658928245306, 40.3890473395586, 37.13145174086094, 34.192157462239265, 21.102619841694832, 8.474634904414415, 0.827108861412853, 0.6835619453340769, 0.23881783825345337, 0.16871358908247203, 0.20401134970597923, 0.0051222360070823925, 0.02484310960426228, 0.061065072295605205, 0.022549043933395296, 0.035582637719926424, 0.07332471737754531, 0.06598452062462457, 0.012475261246436276, 0.04075539960467722, 0.05064609074906912, 0.0542117021541344, 0.03114889535936527, 0.013721640752919484, 0.025920114312611986, 0.07501469895942137, 4.940036544576287, 40.80516681075096, 33.3405015617609, 47.78355695307255, 55.68716324865818, 48.146661669015884, 4.448141539469361, 0.7609097636304796, 3.218097905628383, 27.742615342140198, 30.277067944407463, 65.43229892849922, 40.34280762076378, 0.12514695263234898, 0.08581091416999698, 3.5453641321510077, 94.45640310645103, 111.14601954817772, 85.63883945345879, 6.990223182365298, 1.5489297662861645, 8.62421102821827, 10.644713658839464, 34.119448363780975, 48.267571181058884, 88.82046952843666, 55.93036159873009, 78.48687842488289, 111.85478031635284, 57.44273364543915, 47.64747105538845, 6.681913901120424, 0.5565892055165023, 0.48735389253124595, 0.5359483568463475, 0.15847882343223318, 0.18795985321048647, 0.1667134862509556, 0.1470258372137323, 0.11020456615369767, 0.21333837968995795, 0.3398897428996861, 3.5350977955386043, 35.32708056271076, 69.12074580788612, 77.5406152009964, 73.67648854851723, 59.98115323483944, 52.582254856824875, 57.50413455069065, 67.89701387286186, 80.93783810734749, 82.39804655313492, 75.68480238318443, 72.29264080524445, 64.72532406449318, 67.99966916441917, 74.83253851532936, 71.82544827461243, 74.84256997704506, 73.21691080927849, 73.83258417248726, 67.35498815774918, 68.41358855366707, 71.58007264137268, 72.22047507762909, 70.0174368917942, 71.24501422047615, 70.43131828308105, 72.978276014328, 68.55555653572083, 62.557848170399666, 65.39563089609146, 63.73690590262413, 72.52296164631844, 69.87939029932022, 67.27646917104721, 69.38206538558006, 69.87271785736084, 70.4106093943119, 70.64329370856285, 70.7842281460762, 69.37383502721786, 53.79668869078159, 65.72027787566185, 66.89583599567413, 67.4465936422348, 63.76909777522087, 60.98634369671345, 61.124223098158836, 57.51915894448757, 56.10283434391022, 53.73437963426113, 51.72912083566189, 61.31825968623161, 59.55608144402504, 57.725480273365974, 52.752379328012466, 44.1509822756052, 50.630037412047386, 48.1243796646595, 41.015888303518295, 45.318291038274765, 41.702667251229286, 44.44775775074959, 46.62577427923679, 45.08162833750248, 41.082346737384796, 45.334960743784904, 46.67982257902622, 45.84131017327309, 44.48018901050091, 50.95184974372387, 56.04060508310795, 61.85331657528877, 59.31034862995148, 53.07825364172459, 49.076923951506615, 51.51387758553028, 49.81024660170078, 53.07412326335907, 58.31069827079773, 60.18825352191925, 62.284240052103996, 62.853810489177704, 63.778749257326126, 54.210828468203545, 59.535300359129906, 58.94801527261734, 59.65216688811779, 60.83663173019886, 62.250649854540825, 61.388878896832466, 59.13400389254093, 62.69212156534195, 65.86517170071602, 63.20951320230961, 60.92485159635544, 59.69833441078663, 59.71563868224621, 59.190267473459244, 50.56606024503708, 56.12508215010166, 58.55330005288124, 56.84727519750595, 56.71307399868965, 55.146440863609314, 50.313662588596344, 47.339573577046394, 52.26034373044968, 52.2731414437294, 47.87596799433231, 48.047654181718826, 47.433652728796005, 30.935359820723534, 11.848638206720352, 1.9454999989829957, 1.2017676886171103, 0.3869145055068657, 0.326845963136293, 1.1650528712198138, 0.4156126140151173, 0.13375466340221465, 0.16102084249723703, 0.08054575489950366, 0.1332095856196247, 0.10894803592236713, 0.2863202174194157, 0.13472318096319214, 0.12759511970216408, 0.19427637598710135, 0.15705044148489833, 0.08060737542109564, 0.2272755271405913, 0.18300181691301987, 0.2414461987791583, 11.118032410740852, 64.07400861382484, 41.410766914486885, 63.16613852977753, 58.72275196015835, 64.8674288392067, 25.458973981440067, 0.9553231252357364, 5.592928910627961, 50.23766286671162, 46.37249507009983, 82.62992531061172, 46.62737399339676, 0.5191897123586386, 1.144123119302094, 7.503223679959774], [42.77546748518944, 55.920197144150734, 11.3539551012218, 1.9704012502916157, 4.702724078670144, 8.636246882379055, 4.759237971156836, 3.812470561824739, 23.638485968112946, 53.8074155151844, 38.19718815386295, 73.01131144165993, 87.70232632756233, 39.28145997226238, 38.05287949740887, 11.699357517063618, 0.1581530354451388, 0.05296428549627308, 0.05794336168037262, 0.0348937873786781, 0.047927644627634436, 0.031071313096617814, 0.040460510936100036, 0.030540992920577992, 0.03418488791794516, 0.03682510054204613, 3.521409505046904, 23.531844690442085, 63.85698705911636, 73.34353521466255, 64.43897143006325, 41.34321413934231, 31.476350091397762, 31.87854900956154, 42.90889352560043, 63.83123204112053, 79.7447857260704, 76.80146366357803, 71.88475549221039, 56.91649988293648, 50.844965279102325, 55.68808659911156, 58.92257943749428, 63.91820937395096, 64.74936917424202, 60.981453359127045, 60.89669890701771, 57.1864677965641, 57.29006543755531, 61.38892449438572, 64.9512979388237, 64.40897583961487, 63.28519754111767, 62.604870647192, 63.46343457698822, 60.94854712486267, 60.17760269343853, 61.65556378662586, 65.32513707876205, 59.82182778418064, 60.930817276239395, 65.96499234437943, 60.358260199427605, 66.70263156294823, 65.41868045926094, 64.72780153155327, 51.58300347626209, 58.4452186524868, 65.60251459479332, 64.90563198924065, 60.71405030786991, 55.823659524321556, 57.81894385814667, 53.08939464390278, 47.789556831121445, 46.432885229587555, 46.602511927485466, 52.059718295931816, 64.92743521928787, 58.036751970648766, 50.0310717523098, 41.59364350140095, 41.859412640333176, 46.86092086136341, 44.47912506759167, 42.50460661947727, 40.83625294268131, 41.43191657960415, 43.22967231273651, 41.55699446797371, 40.1633470505476, 37.50065892934799, 40.941541492938995, 41.79985083639622, 41.47884026169777, 39.71601605415344, 43.422960340976715, 56.94603189826012, 60.90417690575123, 57.37137347459793, 50.36161981523037, 42.352717369794846, 44.763330817222595, 43.344882130622864, 46.87361977994442, 49.22690570354462, 55.61202608048916, 53.474648371338844, 54.57556709647179, 57.38836616277695, 57.686171382665634, 47.54510074853897, 59.29663136601448, 52.96434335410595, 54.30085323750973, 54.78414170444012, 58.43832582235336, 54.313259571790695, 52.24360562860966, 55.49925193190575, 55.640406757593155, 55.039799585938454, 54.98540550470352, 44.625424817204475, 48.14987629652023, 44.25102710723877, 46.72715663909912, 50.5210592597723, 47.367118299007416, 46.77459329366684, 41.80454358458519, 32.81554073095322, 31.364026218652725, 32.99141049385071, 34.10336762666702, 33.39513123035431, 28.066703751683235, 13.520400300621986, 5.18638065084815, 0.7502592320088297, 0.12621261732419953, 0.06782919546822086, 0.14580338640371338, 0.0428417585499119, 0.04262254667992238, 0.20608982333214954, 0.19858439482050017, 0.11646418104646727, 0.03609742103435565, 0.029090866046317387, 0.12688838731264696, 0.15508357202634215, 0.033717438782332465, 0.03032349170098314, 0.0729087510262616, 0.10008698562160134, 0.07184614398283884, 0.07389836784568615, 0.09351877830340527, 0.07634888010215946, 1.1820665770210326, 22.2616583481431, 24.61525395512581, 32.165300622582436, 50.03073737025261, 41.32411636412144, 9.671167898923159, 0.4860301979351789, 0.09015078598167747, 9.669631831347942, 25.554455257952213, 50.608298778533936, 51.543079018592834, 0.3042443306185305, 0.37942044669762254, 6.373378057032824, 72.20500990748405, 83.49769234657288, 24.300997518002987, 4.535120772197843, 6.627170238643885, 10.087085980921984, 5.43384569697082, 10.025762021541595, 31.958713307976723, 68.4234756231308, 44.438421651721, 84.8204317688942, 96.64177983999252, 42.58242264389992, 44.65299993753433, 16.29893660545349, 0.7061137352138758, 0.06443166566896252, 0.20552645903080702, 0.06434841896407306, 0.06784508484997787, 0.09483816102147102, 0.0767155530047603, 0.04311622331442777, 0.04351902025518939, 0.18761625367915258, 4.51846151612699, 29.09461509436369, 72.27946311235428, 81.65944218635559, 71.44013375043869, 47.975997626781464, 40.22695563733578, 44.641459956765175, 57.93119363486767, 70.2625085413456, 79.354607462883, 72.02665507793427, 68.5172089934349, 58.928586915135384, 55.40001265704632, 63.14121566712856, 65.42403817176819, 69.11576047539711, 68.74689146876335, 66.03823721408844, 64.91258561611176, 61.52136258780956, 62.95176163315773, 65.2593246102333, 66.07330173254013, 68.97805586457253, 68.29625084996223, 66.55763134360313, 64.27278354763985, 62.422085255384445, 63.14824528992176, 63.186098858714104, 65.78580915927887, 62.538005635142326, 63.976809829473495, 68.32638323307037, 63.46241243183613, 67.7685883641243, 67.90146723389626, 65.88467985391617, 53.34696002304554, 62.45632901787758, 68.02071243524551, 64.90777507424355, 61.56793288886547, 61.000326946377754, 59.93118591606617, 56.137811467051506, 49.659143909811974, 49.44436423480511, 48.58694784343243, 56.283005475997925, 67.2966156899929, 61.20032921433449, 53.16653810441494, 43.90875667333603, 44.16958227753639, 48.23635585606098, 44.22075413167477, 41.01045459508896, 41.54526449739933, 42.766461968421936, 43.51452402770519, 40.880733355879784, 41.44013173878193, 38.255047649145126, 41.74010284245014, 42.788705974817276, 44.983506202697754, 42.1864914894104, 45.32879367470741, 56.8091556429863, 62.22101144492626, 59.122585505247116, 52.87021480500698, 43.53308603167534, 47.84317575395107, 46.370971351861954, 49.71221186220646, 50.446123480796814, 58.028749600052834, 56.998073905706406, 58.848984986543655, 60.101390182971954, 62.600303292274475, 53.300442919135094, 60.61830684542656, 56.2604308873415, 56.676075384020805, 57.046616300940514, 58.77027980983257, 56.81787997484207, 55.111934915184975, 56.9947262853384, 57.906373366713524, 57.20732867717743, 57.93085925281048, 48.78830663859844, 51.75712153315544, 46.94258227944374, 49.79810245335102, 55.53729169070721, 50.81839710474014, 50.33383950591087, 44.694831892848015, 38.471039459109306, 37.296830266714096, 41.76254823803902, 39.064947590231895, 35.36335341632366, 29.065985530614853, 15.025468189269304, 4.528063600882888, 0.5424924963153899, 0.13345265382668003, 0.1299878186546266, 0.1776857240474783, 0.07594343740493059, 0.053633810312021524, 0.038417333853431046, 0.018981013126904145, 0.018914453612524085, 0.08922508292016573, 0.10109573500812985, 0.03770629329665098, 0.14416555553907529, 0.014043489791220054, 0.07571938302135095, 0.06533849591505714, 0.05012122906919103, 0.02847532319719903, 0.07166598021285608, 0.08935178237152286, 0.02020650303165894, 7.315934579819441, 37.92096197605133, 33.74633498489857, 38.889096826314926, 51.13275803625584, 53.68989162147045, 18.65198314189911, 0.624835443450138, 1.1728552775457501, 22.29635238647461, 38.63984540104866, 63.71616281569004, 66.23029410839081, 0.6638644554186612, 0.512905977666378, 9.558029919862747, 87.99769207835197, 104.82714861631393, 31.11575324088335, 4.040582058951259, 10.01565931364894, 18.141406439244747, 13.740433193743229, 36.87718838453293, 42.218831554055214, 90.98481059074402, 53.578021824359894, 87.433642745018, 101.33265852928162, 52.42338538169861, 56.08718678355217, 16.22949343174696, 0.926537235500291, 0.09463749913265929, 0.33009214675985277, 0.10346723822294734, 0.15572217525914311, 0.15077259944519028, 0.1732982657267712, 0.10817782022058964, 0.1684940469567664, 0.3101796715054661, 5.14783694408834, 36.864090487360954, 71.43428966403008, 76.30248963832855, 78.40025827288628, 63.08236822485924, 53.338509276509285, 61.404621452093124, 69.28273871541023, 80.90391352772713, 86.24810636043549, 81.10027179121971, 76.40532732009888, 66.82614773511887, 63.05812932550907, 68.62079903483391, 70.43802872300148, 71.28996580839157, 75.48342078924179, 70.56631743907928, 71.38398796319962, 65.06365031003952, 65.34319370985031, 68.15394848585129, 70.36213159561157, 70.69351181387901, 69.49642404913902, 70.18432393670082, 67.51529395580292, 64.47993323206902, 63.23153682053089, 66.42679676413536, 70.15334039926529, 65.43935894966125, 66.23748332262039, 72.76547223329544, 66.07906982302666, 72.8570245206356, 72.04600363969803, 70.23328810930252, 57.602993845939636, 63.38442921638489, 73.31171572208405, 66.1736011505127, 65.95049232244492, 62.86534667015076, 62.9257520288229, 59.3138862401247, 53.98648090660572, 49.97278667986393, 52.38430067896843, 55.884292870759964, 70.16019523143768, 63.81608605384827, 57.59744614362717, 47.30735890567303, 46.67871683835983, 51.45783819258213, 47.22729340195656, 43.678595423698425, 40.748325660824776, 45.36656364798546, 46.359731554985046, 43.141642436385155, 42.47792825102806, 37.49088205397129, 42.512061819434166, 44.20879237353802, 46.79439403116703, 44.27678592503071, 49.43090535700321, 62.18402802944183, 64.8700051009655, 62.311978563666344, 55.82671836018562, 47.04141117632389, 52.12112300097942, 50.04600115120411, 54.209935516119, 56.704330667853355, 62.364506945014, 61.02013908326626, 60.52112326025963, 61.649693101644516, 64.26196932792664, 55.435194969177246, 65.48220545053482, 57.15115249156952, 59.28902417421341, 59.85209695994854, 62.795688807964325, 59.579317197203636, 59.67956721782684, 59.58902947604656, 59.91720646619797, 60.65579563379288, 61.49882599711418, 53.3649330586195, 55.60645937919617, 49.9955740571022, 52.54047989845276, 59.401441141963005, 55.5890829116106, 56.3861433416605, 54.02486264705658, 45.198753252625465, 46.276337429881096, 48.716551288962364, 49.88628812134266, 48.62601354718208, 41.069070249795914, 20.0105432420969, 5.5304707121104, 0.8343742496799678, 0.22885656886501238, 0.36501803202554584, 0.19859916355926543, 0.5471141764428467, 0.1536436125752516, 0.3868761513149366, 0.29347656934987754, 0.18785283551551402, 0.2818075439427048, 0.26695978129282594, 0.23991939320694655, 0.3434221283532679, 0.13790129480184987, 0.24651607673149556, 0.1319823702215217, 0.198923007119447, 0.12733153853332624, 0.18974964623339474, 0.16587432503001764, 0.19012487609870732, 17.222391553223133, 60.92431582510471, 42.54618778824806, 52.37985111773014, 60.44207990169525, 67.2573333978653, 32.99156628549099, 0.9403107245452702, 2.2648622933775187, 44.11731608211994, 57.989064529538155, 72.2255440056324, 78.26670303940773, 0.8197805390227586, 1.214241231791675, 15.993811078369617], [55.34569837152958, 50.369831174612045, 5.067060878500342, 0.3880014253081754, 8.07998713105917, 8.984908573329449, 6.891519678756595, 8.666176926344633, 34.90632154047489, 58.800218403339386, 44.148447811603546, 56.74564205110073, 79.16380450129509, 54.51900713145733, 36.76207356154919, 28.098707534372807, 0.5969615047797561, 0.06030179938534275, 0.1156598117086105, 0.050608779274625704, 0.10964552857331, 0.08851982740452513, 0.05532854163902812, 0.025156091833196115, 0.026179661908827256, 0.20203659863909706, 0.9699492529034615, 11.425355169922113, 44.70369681715965, 70.47316163778305, 76.92975237965584, 53.58572021126747, 40.728885903954506, 39.217053428292274, 42.847823202610016, 49.88957114517689, 58.39960590004921, 66.52461871504784, 74.4558647274971, 65.6948572397232, 53.249696642160416, 54.07110616564751, 59.69317048788071, 59.91083420813084, 64.07217711210251, 59.89329434931278, 60.20935758948326, 58.00856128334999, 59.219408109784126, 57.58165419101715, 63.611334040760994, 63.504289984703064, 66.81461155414581, 64.18720453977585, 61.95616565644741, 61.38211525976658, 57.10564613342285, 59.00724649429321, 60.2923983335495, 61.354190558195114, 63.13287131488323, 61.67135573923588, 66.50266349315643, 59.52908769249916, 64.32810857892036, 51.571163311600685, 56.08853191137314, 63.81291702389717, 61.86687044799328, 61.45928151905537, 54.31853748857975, 59.53553594648838, 52.30480894446373, 48.06629218161106, 45.12723349034786, 47.057081535458565, 47.01370306313038, 60.06431557238102, 60.99925920367241, 55.434104427695274, 47.805420979857445, 42.02015921473503, 42.74494372308254, 44.068389907479286, 42.14035056531429, 37.81924143433571, 39.36639681458473, 39.65461514890194, 38.61661344766617, 38.41735973954201, 38.41769032180309, 38.98487068712711, 39.601866379380226, 44.264212399721146, 42.79280215501785, 40.295313969254494, 42.53182455897331, 47.10795700550079, 57.49472625553608, 60.45062944293022, 55.232331454753876, 45.766704976558685, 41.44176185131073, 41.679796278476715, 44.401210248470306, 48.122950941324234, 51.716820895671844, 57.04013004899025, 58.70469152927399, 55.325080677866936, 59.17609803378582, 50.34117691218853, 52.25114442408085, 60.10096840560436, 52.7924557775259, 56.52793653309345, 53.21343518793583, 56.33438251912594, 46.76228955388069, 53.1106811016798, 56.335811242461205, 52.22065486013889, 50.1946871727705, 44.490486457943916, 48.228083699941635, 42.9951298981905, 42.47409425675869, 47.51510515809059, 45.31055085361004, 36.26007869839668, 33.879213854670525, 30.89245442301035, 32.06637293100357, 29.47085950523615, 30.622684098780155, 21.4072684943676, 8.762697447091341, 4.116854416206479, 1.8100751470774412, 0.2823587815510109, 0.20908498292556033, 0.7580709003377706, 0.6942153268028051, 0.5155471921898425, 0.7704636384733021, 0.11787806142820045, 0.4344432457583025, 0.12106882146326825, 0.1493889541598037, 0.02005240534344921, 0.03723074732988607, 0.07681071117985994, 0.004054669097968144, 0.07160605178796686, 0.09872435053694062, 0.016940852874540724, 0.04514459455094766, 0.033980140506173484, 0.08474298592773266, 0.05716978404961992, 4.823964172974229, 22.54031829535961, 24.653751589357853, 28.40533208101988, 49.22765426337719, 48.73155668377876, 24.668050222098827, 0.6443500681780279, 0.26970747916493565, 5.235372371971607, 28.89471162110567, 47.16801658272743, 68.38088750839233, 1.898524782154709, 0.34189743048045784, 2.9801753349602222, 72.19867944717407, 74.5802852511406, 7.449016263708472, 0.8934388146735728, 11.929344926029444, 10.474026817828417, 4.8945985827594995, 12.318128664046526, 42.525300309062004, 73.64843845367432, 47.0107202231884, 68.51250484585762, 90.95208674669266, 57.8374108672142, 42.41643615067005, 39.02304343879223, 0.9678427409380674, 0.07843804065487348, 0.06893540368764661, 0.06206221820320934, 0.09041043376782909, 0.01773316973412875, 0.037270596949383616, 0.07103447191184387, 0.06408849658328108, 0.06548564153490588, 1.2843658751808107, 19.675007946789265, 56.59590728580952, 75.77222809195518, 82.9013067483902, 60.36221578717232, 47.77681231498718, 46.37054577469826, 54.76552650332451, 62.986263781785965, 70.56456193327904, 73.99184122681618, 75.14454737305641, 65.80848634243011, 56.44730105996132, 58.14323365688324, 65.74568331241608, 65.9076002240181, 68.94631236791611, 66.95559918880463, 63.243312388658524, 63.2088216394186, 62.99170508980751, 61.94281317293644, 67.59583443403244, 67.19563230872154, 70.58170661330223, 66.81117653846741, 66.7935074865818, 62.23734676837921, 60.23411326110363, 61.15568161010742, 64.56140086054802, 64.80408623814583, 66.89689233899117, 65.45904189348221, 70.04894480109215, 64.37035471200943, 67.51014903187752, 54.09755274653435, 59.816823452711105, 66.22577235102654, 65.55382400751114, 64.86612930893898, 59.7338093072176, 62.40483038127422, 53.16682688891888, 50.46693496406078, 49.002098366618156, 50.26888579130173, 51.588099002838135, 60.393735095858574, 65.05654469132423, 57.6985777169466, 49.07726593315601, 41.343863904476166, 45.00830367207527, 45.02870477735996, 43.14082928001881, 39.201660454273224, 39.36652600765228, 41.135486885905266, 38.17096196115017, 38.23653884232044, 39.291453436017036, 39.084258154034615, 39.03850480914116, 44.62280295789242, 46.26679614186287, 41.85915045440197, 45.98843827843666, 49.39447671175003, 58.18656273186207, 60.24870827794075, 59.11525569856167, 50.03243587911129, 44.9878341704607, 46.59511372447014, 45.13427071273327, 49.92297135293484, 52.51952402293682, 58.621768578886986, 61.41728617250919, 60.175163224339485, 60.60473017394543, 56.778506487607956, 54.862816482782364, 63.15411597490311, 56.52074731886387, 57.529118210077286, 56.649150028824806, 58.69779109954834, 50.5621312558651, 54.641345366835594, 59.38143901526928, 55.849555134773254, 52.70868927240372, 51.594300270080566, 51.90634332597256, 46.096052303910255, 45.00691294670105, 50.58440946042538, 51.16320960223675, 40.82460656762123, 39.44290190935135, 38.137934133410454, 36.9148975610733, 36.48927479982376, 35.44908441603184, 22.103440538048744, 9.863332137465477, 3.3930918155238032, 1.538186555262655, 0.4129051702329889, 0.2598659775685519, 0.18916501197963953, 0.5694579274859279, 0.742682913551107, 0.08777436974924058, 0.16902117960853502, 0.5812457855790854, 0.04160001190030016, 0.15155658940784633, 0.0346692802850157, 0.024003046673897188, 0.04217672372760717, 0.05994658524286933, 0.07008046333794482, 0.06092492512834724, 0.028348104242468253, 0.028024563107464928, 0.056907178804976866, 0.05794883501948789, 0.11556253841263242, 12.602111175656319, 42.007608488202095, 33.39505523443222, 38.38470809161663, 51.98403015732765, 57.26637750864029, 31.037929616868496, 0.4636305186431855, 0.11563624851987697, 14.588326346129179, 43.81090812385082, 58.202122896909714, 81.09765753149986, 3.5255470080301166, 0.5971719778608531, 14.596517756581306, 98.8141992688179, 99.12971153855324, 6.639033677056432, 0.3552178532117978, 18.50562259554863, 19.264821857213974, 19.129541516304016, 35.36287844181061, 55.907703414559364, 95.66585540771484, 57.64732226729393, 70.37729278206825, 99.77686241269112, 62.56595313549042, 55.66733591258526, 42.11698181927204, 0.943206287920475, 0.09947446145815775, 0.16564042976824567, 0.10976655059494078, 0.21904041903326288, 0.1897639993694611, 0.11915245515410788, 0.14114039833657444, 0.15938878554152325, 0.2169656116166152, 1.9228231720626354, 24.87408086657524, 63.90684798359871, 77.92679607868195, 81.69350355863571, 69.59166213870049, 60.86244374513626, 61.52541697025299, 67.86114379763603, 74.01082500815392, 80.1422443985939, 83.98905918002129, 89.55794915556908, 74.4081848859787, 65.26055574417114, 64.12025973200798, 70.84985822439194, 70.60176193714142, 74.77909058332443, 69.0089862048626, 69.10346433520317, 68.68818461894989, 68.11546415090561, 66.9218721985817, 71.07419818639755, 71.34643077850342, 74.27823945879936, 71.9131551682949, 69.32405009865761, 64.20624911785126, 63.29572677612305, 64.6107830107212, 66.74898907542229, 67.16564431786537, 70.57748883962631, 66.2496730685234, 73.9960590004921, 65.2502278983593, 71.01397901773453, 57.78678618371487, 62.9821752011776, 70.95030203461647, 68.01090896129608, 69.37362223863602, 59.814961552619934, 65.2538301050663, 58.811606392264366, 54.2011845856905, 50.00082157552242, 52.55719140172005, 51.48615047335625, 63.36647517979145, 70.59683740139008, 61.05976715683937, 52.572762966156006, 44.03725437819958, 45.85005350410938, 48.65077681839466, 44.47567105293274, 38.716536685824394, 40.68058669567108, 40.8186636865139, 38.80534932017326, 38.463371470570564, 40.2935204654932, 39.21409718692303, 40.39097003638744, 47.170007675886154, 47.13300906121731, 45.97275651991367, 46.576604917645454, 49.40931111574173, 60.78824892640114, 67.2890692949295, 61.9620705395937, 51.38826012611389, 47.05912582576275, 47.28528209030628, 50.21255001425743, 53.91556151211262, 56.81332401931286, 64.09178406000137, 63.626795411109924, 63.542185351252556, 62.899389043450356, 58.70080813765526, 58.78227956593037, 66.45613878965378, 58.27897757291794, 61.112276539206505, 59.747997745871544, 59.92595359683037, 50.76737344264984, 60.54764963686466, 63.23516942560673, 58.1549446284771, 58.169718235731125, 53.9334699511528, 54.059752374887466, 52.061561197042465, 49.7946522384882, 56.590416580438614, 55.47598958015442, 48.439770340919495, 47.409341633319855, 44.13149692118168, 45.335082337260246, 49.09933514893055, 48.79714876413345, 27.72362396121025, 11.811890378594398, 3.486412432976067, 1.5444096713326871, 0.8168583770748228, 0.22399097448214889, 1.3856582273729146, 1.056775781325996, 2.035476202145219, 1.8210134538821876, 0.6949482718482614, 0.8114653977099806, 0.294419156271033, 0.2274976222543046, 0.137370451411698, 0.10737941775005311, 0.30496489664074033, 0.13651425048010424, 0.19536049047019333, 0.30690555344335735, 0.09930973435984924, 0.10856997847440653, 0.18146987567888573, 0.2317177559598349, 0.2447621145984158, 23.031757324934006, 60.84312938153744, 45.023373663425446, 50.00392980873585, 65.81655710935593, 70.60898914933205, 38.22757892310619, 0.5813402461353689, 0.48859422910027206, 31.61102246493101, 66.09228551387787, 65.93651667237282, 97.85468995571136, 4.216937245801091, 1.2563396478071809, 20.498131178319454], [65.02308368682861, 34.603242203593254, 1.914287405088544, 0.33473956456873566, 9.807382989674807, 6.024394808337092, 8.996865581721067, 11.550051178783178, 37.77990214526653, 51.10575668513775, 56.64049789309502, 37.84009851515293, 89.19804006814957, 77.63306424021721, 39.11536328494549, 40.80241575837135, 0.7174008514266461, 0.05401399401307572, 0.09591967798769474, 0.05184816960536409, 0.05265334417345002, 0.09037705196533352, 0.022680587753711734, 0.025781130461837165, 0.034724573997664265, 0.0549652492190944, 0.7290561916306615, 5.1227611396461725, 50.2825840562582, 71.23935252428055, 78.49826261401176, 66.33358776569366, 56.3567329198122, 51.30602113902569, 48.48824813961983, 43.850194215774536, 34.212558567523956, 33.14654476940632, 46.98335029184818, 70.33123925328255, 64.85634103417397, 52.738563269376755, 56.2347062677145, 63.98146837949753, 61.20050400495529, 59.760639667510986, 57.73357763886452, 59.13162522017956, 54.599483013153076, 55.5424328148365, 59.94686387479305, 61.54649443924427, 63.69995668530464, 63.47818158566952, 62.696259543299675, 60.40359936654568, 53.10709789395332, 57.37114168703556, 59.56007122993469, 62.14504212141037, 61.64294846355915, 61.28793731331825, 62.905244529247284, 62.808072343468666, 58.17357502877712, 53.38879957795143, 61.680467650294304, 64.54944670200348, 63.28293286263943, 58.74675527215004, 59.51638497412205, 53.88123415410519, 49.75928373634815, 47.96156220138073, 45.157601460814476, 50.62141187489033, 55.651065185666084, 58.86353820562363, 58.95047374069691, 55.90579591691494, 44.92029659450054, 40.26251032948494, 46.365381851792336, 46.5084707736969, 40.08323974907398, 37.88017876446247, 39.25054483115673, 38.69033709168434, 38.16995121538639, 37.5736416131258, 36.75346702337265, 39.73020829260349, 35.42239844799042, 40.87532624602318, 44.193836376070976, 40.39148300886154, 40.118965432047844, 48.18274073302746, 52.06843122839928, 54.62432228028774, 58.28200601041317, 55.381203666329384, 44.676585271954536, 44.939276576042175, 45.97326569259167, 44.504249319434166, 47.34747335314751, 51.327679976820946, 57.823264226317406, 58.70004057884216, 59.17669840157032, 58.08074600994587, 49.15351264178753, 56.51328071951866, 57.08791248500347, 53.2770361751318, 53.65364156663418, 55.98526485264301, 50.91544769704342, 45.730500519275665, 51.245486587285995, 47.20088481903076, 43.05848769843578, 47.32458338141441, 46.0212267190218, 40.867555662989616, 38.45889911055565, 41.375231221318245, 36.98450602591038, 30.807848162949085, 32.1078173071146, 35.17229966819286, 30.803518295288086, 29.403703808784485, 17.046719379723072, 6.392719494178891, 4.269306510686874, 2.358933133073151, 1.1652622162364423, 1.1155683640390635, 3.807082213461399, 6.802856186404824, 8.698437195271254, 2.682101991958916, 0.8800814033020288, 1.6990237310528755, 1.305577524472028, 1.4578421227633953, 0.015797778469277546, 0.17606948968023062, 0.01807551503588911, 0.09266323046176694, 0.06614528465433978, 0.17856196296634153, 0.04875611892202869, 0.07059918745653704, 0.04692282120231539, 0.1680478232447058, 0.05482766246132087, 0.15399047755636275, 7.240300588309765, 30.78416023403406, 25.35273738205433, 22.649843618273735, 36.27630762755871, 32.35068127512932, 16.18546899408102, 0.4916085657896474, 0.05768511655332986, 4.404208771884441, 34.52617473900318, 43.87336537241936, 70.24020373821259, 4.1080626379698515, 0.4068927944172174, 5.701496684923768, 78.9249037206173, 58.269440084695816, 2.372240494005382, 0.9097120945807546, 15.19150123000145, 8.223007656633854, 9.264521319419146, 16.976407952606678, 45.989205837249756, 73.17360833287239, 56.9990960508585, 43.0262616276741, 116.90804556012154, 79.83829870820045, 45.09037546813488, 54.32788498699665, 1.2929588765837252, 0.24528280540835112, 0.1442453364143148, 0.04742220866319258, 0.06209745908563491, 0.09418683737749234, 0.14884766133036464, 0.027309472279739566, 0.040620024446980096, 0.09009138448163867, 1.43243727972731, 7.913929391652346, 59.16952818632126, 75.81483140587807, 82.79287576675415, 70.51374346017838, 60.765092968940735, 56.03137917816639, 56.93917706608772, 53.97667743265629, 52.824263870716095, 48.90353925526142, 58.626107946038246, 73.25503036379814, 62.5383248180151, 55.84328547120094, 60.12896530330181, 67.44477733969688, 66.2998303771019, 66.76798805594444, 63.77115726470947, 64.35856774449348, 57.024699077010155, 58.24876919388771, 63.48726689815521, 64.8211321234703, 66.63495719432831, 65.52239209413528, 63.66995349526405, 63.91915172338486, 56.02417476475239, 60.01899540424347, 62.364202961325645, 66.92840784788132, 62.67420172691345, 64.83199194073677, 65.5121098458767, 67.57682025432587, 60.6147388368845, 58.234253972768784, 64.42542135715485, 67.6755541563034, 63.99046629667282, 64.42141637206078, 63.40371698141098, 55.8188109844923, 53.61527122557163, 50.30119925737381, 48.85313116014004, 55.61002358794212, 58.03822249174118, 63.58207181096077, 60.2341740578413, 56.07767969369888, 47.17177838087082, 43.32006946206093, 49.016427397727966, 47.49895602464676, 41.760496348142624, 38.61211068928242, 39.25712987780571, 39.54351291060448, 38.55513654649258, 37.60422997176647, 38.93951632082462, 39.87105533480644, 37.54213370382786, 42.64516107738018, 47.31536887586117, 42.224132269620895, 42.33714580535889, 49.29367192089558, 53.66835817694664, 55.90718284249306, 58.34516242146492, 55.99206268787384, 47.7974946051836, 47.235462963581085, 49.325905591249466, 47.25609965622425, 50.19879475235939, 55.24165615439415, 58.708970099687576, 61.339390352368355, 62.509491965174675, 61.1867905408144, 53.82314667105675, 58.26181769371033, 59.86109487712383, 54.84065227210522, 54.533195570111275, 57.27654956281185, 55.78627333045006, 46.97202309966087, 51.46034225821495, 52.38649696111679, 49.37766641378403, 49.98809985816479, 48.43888118863106, 43.11309836804867, 42.24988728761673, 45.39040356874466, 41.666778177022934, 36.46047614514828, 39.07542362809181, 38.05017024278641, 35.12514799833298, 32.20429793000221, 17.93588686734438, 6.791742732748389, 4.202439598739147, 3.6236282950267196, 1.4468338759616017, 1.1404860019683838, 2.390332273207605, 5.792001178488135, 7.856506397947669, 2.9387575574219227, 1.6382426675409079, 1.5815955447033048, 1.1775086028501391, 1.7435132875107229, 0.17501048947451636, 0.09726842006784864, 0.060609371357713826, 0.1379658913356252, 0.08703766201506369, 0.24005492421565577, 0.08826288103591651, 0.052670146396849304, 0.009792982764338376, 0.1147426210809499, 0.04229772719554603, 0.12655344122322276, 19.10420637577772, 48.907513841986656, 37.34369695186615, 33.09999726712704, 43.31315763294697, 44.441666677594185, 22.424154728651047, 0.3846641950076446, 0.09301684898673557, 10.889643765985966, 49.87977147102356, 52.16468766331673, 83.87080952525139, 6.640329407528043, 0.45095163804944605, 13.753264155238867, 106.87661424279213, 74.83323007822037, 1.5832344442605972, 0.7220107759349048, 23.05646549910307, 10.397087596356869, 21.746920868754387, 34.39411282539368, 54.20023463666439, 87.05982640385628, 69.77416634559631, 52.955755814909935, 101.51988208293915, 81.96986272931099, 53.88499975204468, 60.225559920072556, 1.0104752657935023, 0.40409762877970934, 0.202463140594773, 0.18922474002465606, 0.18124147230992094, 0.2332408062648028, 0.17684941267361864, 0.08893321108189411, 0.10137599965673871, 0.2731327578658238, 1.390160748269409, 18.58814276754856, 65.38480147719383, 83.74051451683044, 81.74363806843758, 76.21083855628967, 68.29774796962738, 66.66561394929886, 67.52978637814522, 73.12523692846298, 65.29922246932983, 57.15309418737888, 70.59040054678917, 84.65200200676918, 67.94337898492813, 64.36731487512589, 65.93430519104004, 74.42270770668983, 70.49260139465332, 71.123625934124, 69.60544019937515, 68.11229512095451, 64.07908514142036, 66.359943151474, 67.19255447387695, 68.07982206344604, 70.15714019536972, 69.3251596391201, 69.8908580839634, 68.34096685051918, 58.98760914802551, 62.68789619207382, 64.14045944809914, 69.44606155157089, 65.14463916420937, 66.85128718614578, 70.28365820646286, 70.63963070511818, 65.19384652376175, 58.84398825466633, 68.37840244174004, 69.52372178435326, 69.37634289264679, 64.17502239346504, 65.34668192267418, 60.36789648234844, 55.296225026249886, 54.17511038482189, 51.72203801572323, 56.40888512134552, 60.79941652715206, 64.60559248924255, 62.81798981130123, 59.527332186698914, 49.3573223054409, 46.191700771450996, 51.79201126098633, 49.439644888043404, 41.722243800759315, 38.82382772862911, 39.73132163286209, 40.424157455563545, 38.423051834106445, 37.76828996837139, 38.46237972378731, 41.089600548148155, 37.772735729813576, 43.07255834341049, 48.7981329113245, 45.19239619374275, 44.378115087747574, 49.71553288400173, 56.49908468127251, 59.00428265333176, 63.400015980005264, 62.63358190655708, 48.446040004491806, 49.27566848695278, 52.24588930606842, 51.523863449692726, 53.29298011958599, 59.038100838661194, 62.817959412932396, 65.07314220070839, 66.2206806242466, 62.789643332362175, 54.63484771549702, 62.55066655576229, 61.941943019628525, 59.1495830565691, 58.02478641271591, 62.97839820384979, 58.15150961279869, 48.92829492688179, 58.94434466958046, 55.51941744983196, 52.879915684461594, 55.06679713726044, 53.792797699570656, 47.88318760693073, 48.363383039832115, 51.95392057299614, 50.29276750981808, 44.08204637467861, 46.71665400266647, 48.82324576377869, 49.6628525108099, 40.88485613465309, 24.60866890847683, 8.19489011541009, 4.895071182399988, 4.886594312265515, 2.7507293969392776, 5.140922265127301, 5.871808771044016, 8.141763266175985, 10.865933988243341, 4.578570490702987, 3.5399126121774316, 4.52411038801074, 3.4297940460965037, 2.934147217310965, 0.2868117269827053, 0.2822614414617419, 0.15442289732163772, 0.2339007388218306, 0.1941096896189265, 0.39707812888082117, 0.21207344834692776, 0.16893210704438388, 0.2157471832470037, 0.2898270433070138, 0.14379222557181492, 0.5850814422592521, 31.538395062088966, 65.68864837288857, 47.77656152844429, 45.77905811369419, 54.531626254320145, 62.629827708005905, 29.152725376188755, 0.4695071408059448, 0.2780379680916667, 22.912413328886032, 69.7607758641243, 60.26688650250435, 97.1443484723568, 7.665492072701454, 1.3010588544420898, 24.435436204075813], [57.3785474896431, 23.417385332286358, 0.5292925983667374, 0.6905704317614436, 7.985306661576033, 4.232995184138417, 5.188546059653163, 2.771249720826745, 26.79687839001417, 49.95814606547356, 51.43113322556019, 36.95906259119511, 52.88042485713959, 56.53939671814442, 42.413369715213776, 49.43190850317478, 3.014686508104205, 0.34683280158787966, 0.12104692810680717, 0.16915893706027418, 0.06407118227798492, 0.0706602587888483, 0.06305111513938755, 0.03402169335458893, 0.02192342457419727, 0.23193608096335083, 0.8246076456271112, 5.218959152698517, 66.27575486898422, 77.20054104924202, 74.51324164867401, 74.17300030589104, 57.99786865711212, 56.71373136341572, 52.682379484176636, 53.447525426745415, 29.457634314894676, 22.65294425189495, 19.71738327294588, 50.8912505954504, 75.2252322435379, 63.73986974358559, 58.862421065568924, 59.99776214361191, 65.53854122757912, 60.40347017347813, 55.89863710105419, 56.95911459624767, 54.33623693883419, 53.79122458398342, 56.339858025312424, 58.79239462316036, 60.80589517951012, 65.57851508259773, 63.280075415968895, 60.31550869345665, 54.11452643573284, 57.75081351399422, 57.89094619452953, 60.97092792391777, 57.50409655272961, 61.628159657120705, 61.14746645092964, 61.16673521697521, 56.28583252429962, 62.97881618142128, 62.826242968440056, 60.51262691617012, 59.6669252961874, 63.63680027425289, 52.96007998287678, 50.981902331113815, 49.303163811564445, 45.08591450750828, 51.7553698271513, 56.55118368566036, 58.837038427591324, 60.59097111225128, 56.99993960559368, 50.00467076897621, 43.43747176229954, 43.49042572081089, 49.92558941245079, 47.278320863842964, 41.240190267562866, 37.950585186481476, 39.84372340142727, 40.89934095740318, 37.607148215174675, 36.03598192334175, 40.13433940708637, 36.8185081332922, 35.625645741820335, 43.03141415119171, 47.58707329630852, 41.48206628859043, 41.410371735692024, 43.43673460185528, 50.6076680123806, 56.4092954993248, 55.488506108522415, 54.57873612642288, 51.953324005007744, 44.56986799836159, 46.69564113020897, 48.15465644001961, 43.969834595918655, 49.91683088243008, 54.735397920012474, 55.92376135289669, 56.46642163395882, 56.779388040304184, 53.05098630487919, 51.2454029917717, 57.90551081299782, 52.71706782281399, 51.57956466078758, 50.72074614465237, 55.21296389400959, 45.486029237508774, 43.86906020343304, 44.358272552490234, 42.84773960709572, 43.447066247463226, 43.64758148789406, 37.83700928092003, 36.95624694228172, 35.26881068944931, 29.872412458062172, 30.64704079180956, 31.20761901140213, 33.71191643178463, 30.930959656834602, 18.63277517259121, 5.8610619977116585, 4.6012187004089355, 3.6384472623467445, 3.0644336761906743, 5.525542376562953, 14.051320161670446, 15.475886519998312, 23.145118542015553, 16.415979824960232, 17.115195505321026, 15.813187770545483, 11.429416202008724, 9.559621084481478, 4.6037213411182165, 0.6638265762012452, 0.1715158496517688, 0.039011500994092785, 0.05211597359448206, 0.07269472305779345, 0.020625521465262864, 0.03854169182886835, 0.03212442992662545, 0.027545100456336513, 0.06368110203766264, 0.11316534204524942, 0.5733128206338733, 20.4176913946867, 38.10878209769726, 34.65579338371754, 19.779965914785862, 25.53427454084158, 10.334684494882822, 9.42427234724164, 0.5983397620730102, 0.1133727426349651, 5.583716779947281, 31.185422502458096, 46.60298690199852, 80.48260733485222, 5.087777841836214, 0.36911400442477316, 9.64810598641634, 86.5551982820034, 39.72058340907097, 0.8354126627091318, 1.464599585160613, 9.883510004729033, 5.143725089728832, 6.0832322761416435, 9.40328512340784, 38.724345266819, 69.60043206810951, 55.36844775080681, 33.8415502756834, 79.1698157787323, 68.76402094960213, 47.47585706412792, 65.06098285317421, 4.91693283431232, 0.6298401311505586, 0.21218998037511483, 0.09927020757459104, 0.12846957746660337, 0.04227089484629687, 0.056600386087666266, 0.09485474802204408, 0.024001009478524793, 0.20407189411344007, 1.1604705546051264, 10.532575976103544, 75.63518464565277, 75.50419807434082, 78.73973205685616, 73.04375410079956, 66.10854864120483, 62.43770241737366, 60.26855081319809, 63.70767407119274, 44.5311214774847, 34.344726875424385, 41.76208846271038, 63.13982114195824, 74.20734286308289, 59.83931064605713, 60.89020125567913, 63.96170184016228, 68.04490953683853, 66.89180061221123, 61.24010547995567, 66.76977396011353, 58.58682945370674, 57.3066895455122, 59.25878159701824, 62.334754541516304, 63.57880398631096, 68.35898548364639, 64.37777951359749, 65.08717104792595, 56.45564541220665, 60.40994882583618, 59.429137855768204, 64.06311839818954, 59.04787391424179, 66.58825770020485, 64.49422046542168, 62.935737892985344, 59.386975318193436, 66.4455297589302, 65.02506718039513, 64.77980554103851, 64.87082585692406, 66.40665784478188, 55.12289732694626, 55.81080101430416, 52.09474861621857, 52.3025518655777, 54.991960152983665, 59.29850846529007, 62.618679106235504, 62.17290222644806, 58.90483058989048, 51.67965888977051, 43.58522303402424, 46.339330449700356, 53.15145671367645, 52.376305907964706, 41.59398928284645, 38.104621320962906, 40.348172932863235, 41.003101989626884, 37.15687237679958, 38.14410500228405, 40.141338631510735, 35.99558249115944, 36.161576583981514, 44.08672392368317, 50.79185552895069, 45.436483696103096, 43.679435178637505, 43.22085298597813, 50.83244875073433, 60.013238713145256, 56.92137122154236, 56.2934435158968, 54.04038481414318, 49.310949593782425, 49.45101387798786, 51.67080536484718, 46.59210428595543, 52.204182744026184, 57.1653713285923, 56.74061492085457, 57.5899263471365, 60.42856402695179, 57.27661035954952, 54.761707708239555, 60.27221381664276, 56.01477026939392, 55.2198339253664, 53.50734941661358, 59.49311502277851, 50.33605478703976, 45.667773485183716, 48.18427585065365, 48.83173830807209, 47.65112265944481, 44.475975036621094, 42.30254866182804, 42.57943220436573, 39.19718809425831, 38.24324168264866, 38.242561519145966, 35.35425290465355, 37.812789380550385, 30.749551691114902, 18.13279040157795, 7.185204969719052, 4.332908922806382, 4.128279453143477, 6.044081076979637, 7.435357421636581, 13.718676511198282, 14.384947959333658, 23.83304502815008, 17.775955349206924, 14.231313653290272, 14.672034904360771, 12.536784131079912, 13.385885618627071, 4.822505051270127, 2.6275205332785845, 0.2062644061516039, 0.05999420885927975, 0.07490034142392687, 0.17368866509059444, 0.04660489998059347, 0.04173110857664142, 0.019279666339571122, 0.057738881441764534, 0.08162158701452427, 0.02739509571256349, 0.7304032193496823, 32.74628184735775, 54.97137665748596, 47.4807284027338, 29.677766002714634, 32.726743295788765, 19.394402503967285, 14.744430519640446, 0.5953215365298092, 0.08001927533769049, 11.739738900214434, 49.65413577854633, 53.84035214781761, 90.53153291344643, 7.182050663977861, 0.5366980447433889, 13.01282923668623, 97.2193868458271, 57.84159064292908, 0.4897014540620148, 1.9697656156495214, 19.82187196612358, 7.9738303273916245, 23.100193552672863, 19.54432535916567, 42.73451708257198, 84.09846290946007, 64.15848568081856, 49.37727503478527, 70.70488080382347, 67.11727291345596, 57.770800441503525, 78.80941271781921, 3.5975191835314035, 0.6736831285525113, 0.20541488454909995, 0.3175795666174963, 0.14865684031974524, 0.19530073273926973, 0.11620238845353015, 0.20035266556078568, 0.14513910486130044, 0.39516505028586835, 1.2254689168184996, 18.15866131335497, 78.36587011814117, 85.93362763524055, 84.19331341981888, 79.56365704536438, 68.82639080286026, 64.60516691207886, 67.85429656505585, 75.23901790380478, 66.32394388318062, 47.7754557877779, 51.42717383801937, 73.84867250919342, 86.12633049488068, 64.47026655077934, 69.39473390579224, 69.03310731053352, 75.31357750296593, 73.47655087709427, 69.81452018022537, 68.94093185663223, 63.9672115445137, 63.058836087584496, 63.948280960321426, 64.73642706871033, 66.2902320921421, 72.81650349497795, 69.55066233873367, 66.18965908885002, 59.338987693190575, 65.45618444681168, 64.4063387811184, 67.5932277739048, 61.13261304795742, 68.76250103116035, 65.25684714317322, 65.29154688119888, 61.93465881049633, 67.63683423399925, 68.49796682596207, 66.37822017073631, 66.16392686963081, 69.35897022485733, 59.18786600232124, 58.83784398436546, 55.407813638448715, 54.4562952965498, 58.410363122820854, 62.12041564285755, 64.75502327084541, 66.27776876091957, 60.72995625436306, 54.45073999464512, 47.17877000570297, 49.54484984278679, 55.253819301724434, 52.63191059231758, 42.41910740733147, 38.36189031600952, 41.09663397073746, 41.93428382277489, 36.66667588055134, 36.9143807888031, 40.51290549337864, 37.9243627935648, 37.037163600325584, 46.01302295923233, 51.17399342358112, 46.23277276754379, 45.91981016099453, 44.78875145316124, 52.00806386768818, 63.339124247431755, 60.20924359560013, 60.115153044462204, 58.074962720274925, 50.60230650007725, 52.146224454045296, 55.52336543798447, 49.83483508229256, 56.544275656342506, 61.22554086148739, 59.50861059129238, 63.116554990410805, 63.53048577904701, 57.04493299126625, 56.04630097746849, 62.812624499201775, 57.57860295474529, 57.217238545417786, 58.58532093465328, 63.52480128407478, 51.89391039311886, 51.455261930823326, 51.80449739098549, 52.18791961669922, 50.83556838333607, 49.079485014081, 46.905473470687866, 48.00643399357796, 45.97673110663891, 49.29769970476627, 44.78750891983509, 47.31777414679527, 48.226677775382996, 37.63101853430271, 24.203924126923084, 9.03459470719099, 5.494024017825723, 5.4830848798155785, 8.763477355241776, 11.927099246531725, 19.834916666150093, 19.427399933338165, 28.02675649523735, 21.524254716932774, 27.69343078136444, 19.152515083551407, 17.115450091660023, 19.224903099238873, 5.967477187514305, 3.7363418843597174, 1.154983292799443, 0.1111417353968136, 0.36274334939662367, 0.24313782050739974, 0.13497416046448052, 0.1014682263485156, 0.2408398492843844, 0.22079018061049283, 0.10968635411700234, 0.2192132652271539, 1.287574446760118, 43.582802563905716, 68.46830561757088, 57.632218077778816, 41.26067876815796, 48.50834146142006, 44.49625834822655, 18.791036680340767, 0.7668744341935962, 0.178958551841788, 20.83643652498722, 71.9861264526844, 64.74827483296394, 106.98151901364326, 9.01336619630456, 1.4447384071536362, 27.69667960703373], [39.59487855434418, 21.98923196643591, 0.24058640585280955, 2.15203114785254, 5.40583455003798, 1.992922998033464, 11.718228254467249, 5.106602031737566, 9.59762854501605, 50.05087248980999, 49.561131969094276, 55.408721789717674, 54.952753856778145, 26.621268913149834, 48.21688190102577, 47.82269485294819, 7.601214246824384, 0.9675323450937867, 0.14656101528089494, 0.3835594339761883, 0.07525306195020676, 0.154560714145191, 0.03462905217020307, 0.1371907626162283, 0.11709478392731398, 0.07727934775175527, 0.2097061011590995, 8.112125806510448, 68.0006343126297, 76.51646375656128, 62.474058866500854, 66.9584034383297, 58.30199673771858, 59.48622599244118, 48.76149147748947, 50.50980046391487, 30.978056229650974, 21.288179084658623, 11.214006710797548, 23.63078188151121, 51.23849876224995, 66.01850867271423, 69.40861076116562, 61.38708919286728, 64.71875801682472, 63.50511074066162, 59.79585237801075, 59.04552564024925, 54.27284874022007, 52.65117935836315, 52.760963067412376, 58.51154029369354, 60.16678087413311, 60.21175526082516, 64.8300388455391, 56.698858961462975, 56.214540749788284, 56.538374572992325, 57.94103130698204, 61.12999498844147, 61.07962109148502, 62.794222086668015, 59.91027943789959, 58.972691148519516, 58.18703390657902, 62.10377633571625, 61.874534636735916, 59.174061343073845, 61.98835372924805, 56.517924070358276, 56.164539232850075, 52.092981711030006, 49.099707528948784, 55.02314127981663, 55.75968995690346, 55.894514322280884, 58.27944874763489, 53.922230154275894, 53.98334987461567, 50.239984542131424, 43.258900344371796, 46.94375641644001, 53.25588271021843, 56.461284309625626, 46.056006252765656, 40.998789221048355, 42.1154011040926, 38.06366331875324, 38.122453764081, 37.28187806904316, 39.456026405096054, 37.824135571718216, 41.09338894486427, 50.62143847346306, 51.0810200124979, 45.47925040125847, 44.84399288892746, 48.01294304430485, 45.071908459067345, 55.18792703747749, 56.25684767961502, 53.949535489082336, 54.61183235049248, 50.312127470970154, 47.596177607774734, 49.69140037894249, 48.21187376976013, 47.76946350932121, 53.9755716919899, 55.51975183188915, 52.77800515294075, 53.045256212353706, 56.87689080834389, 50.20110122859478, 54.586765095591545, 53.29834163188934, 57.524778842926025, 49.726932272315025, 53.30771192908287, 43.01093325018883, 41.80053859949112, 44.44591484963894, 43.08787152171135, 40.49622818827629, 37.47346758842468, 35.98272018134594, 35.09522080421448, 29.64703895151615, 31.592965833842754, 33.494712486863136, 36.32967196404934, 33.54203134775162, 19.58972342312336, 8.096347153186798, 4.693898102268577, 2.1452594362199306, 2.3744246643036604, 3.6149277118965983, 14.739685524255037, 21.451254934072495, 33.612354174256325, 43.52910004556179, 43.373969569802284, 36.32567077875137, 22.53988701850176, 28.770847767591476, 24.409658387303352, 20.873140655457973, 6.7911547143012285, 0.5418987188022584, 0.09918132796883583, 0.10723659142968245, 0.11065141326980665, 0.06608702606172301, 0.08009179058717564, 0.06414561226847582, 0.07558318407973275, 0.030146428252919577, 0.2417400002013892, 0.403242526226677, 17.29848627001047, 47.20819182693958, 39.34808939695358, 19.709164313971996, 20.233032703399658, 10.989460609853268, 3.6415908811613917, 0.34189766796771437, 0.3351463208673522, 8.962632268667221, 43.094942942261696, 57.07033082842827, 70.6733500957489, 3.4073709743097425, 0.45268520596437156, 4.936291370540857, 74.95289325714111, 32.38932520151138, 0.3499083506176248, 3.749596285633743, 7.7933020144701, 4.284336604177952, 14.251492470502853, 4.429117385298014, 19.019098542630672, 73.18122312426567, 54.03132230043411, 53.32930997014046, 68.69803369045258, 33.664491176605225, 52.94611193239689, 66.1902366578579, 11.260715704411268, 1.147330622188747, 0.16633274964988232, 0.07051649736240506, 0.17127246974268928, 0.03697125539474655, 0.018110546261596028, 0.055735824862495065, 0.19836020685033873, 0.07598736512591131, 0.31626421376131475, 9.268605150282383, 76.15749701857567, 78.52945894002914, 72.70305678248405, 74.4108447432518, 63.8855767250061, 63.84915187954903, 59.79444645345211, 64.67488557100296, 48.283488526940346, 34.505374655127525, 26.374878734350204, 41.87868520617485, 66.41042724251747, 65.34391567111015, 65.14257207512856, 66.49724498391151, 68.16147208213806, 67.35827878117561, 64.6625742316246, 67.4957250058651, 59.875435307621956, 56.72348544001579, 55.88744670152664, 60.85901252925396, 64.07955631613731, 62.10097208619118, 65.33618688583374, 59.26803410053253, 62.06671692430973, 60.6739966571331, 63.52640479803085, 63.30067791044712, 63.7554869055748, 67.3106749355793, 61.72202602028847, 62.52337262034416, 60.49783430993557, 66.47576093673706, 63.24395835399628, 61.23436018824577, 64.18011412024498, 59.249506294727325, 57.745786383748055, 53.20692993700504, 52.99608305096626, 57.441589906811714, 58.16448971629143, 60.14055848121643, 60.8161736279726, 57.96939678490162, 56.16591855883598, 51.853218376636505, 44.209031760692596, 49.726727083325386, 54.498150050640106, 59.54717472195625, 50.18866069614887, 42.5549653172493, 42.30383299291134, 39.67769891023636, 38.81860300898552, 38.901734948158264, 39.737465903162956, 40.53364098072052, 43.15267704427242, 53.37756738066673, 53.01903001964092, 49.554227739572525, 45.42244344949722, 51.754157692193985, 45.72991915047169, 55.889403596520424, 57.41906091570854, 56.65598206222057, 56.90744876861572, 54.21957179903984, 50.87432250380516, 52.04721696674824, 51.83078818023205, 49.548911824822426, 56.76676131784916, 57.978577092289925, 56.01267658174038, 55.051814541220665, 58.71701046824455, 54.787056148052216, 55.836290046572685, 56.786223873496056, 57.86202974617481, 55.64036875963211, 57.39840902388096, 48.995604515075684, 44.27953697741032, 48.96195352077484, 48.01717981696129, 45.4924850910902, 42.62757562100887, 40.599613040685654, 40.487321466207504, 37.69701339304447, 37.56796471774578, 39.31528955698013, 39.210384786129, 31.92874811589718, 20.07017534226179, 8.306649718433619, 5.4462292324751616, 2.4971751775592566, 2.641442036256194, 5.521652810275555, 15.728409569710493, 26.75349611788988, 38.67940127849579, 43.43734636902809, 41.31359092891216, 41.10050216317177, 21.912109404802322, 33.02731096744537, 31.478639468550682, 25.462975166738033, 9.753842912614346, 2.5580540858209133, 0.027371877622499596, 0.19487741170451045, 0.04818586749024689, 0.07363578857621178, 0.08322866327944212, 0.04026991628052201, 0.05393345243646763, 0.07859416626160964, 0.3178058622870594, 1.3488358282484114, 31.823752149939537, 58.75750109553337, 52.26579263806343, 28.40098701417446, 33.29910658299923, 8.731348179280758, 6.979976557195187, 0.5670439882669598, 0.7095102779567242, 20.16629498451948, 60.66455036401749, 65.7365258038044, 79.52274844050407, 4.063161397352815, 0.7130854111164808, 12.442509289830923, 76.56995728611946, 54.001911878585815, 0.1694076752755791, 5.670382529497147, 17.11493331938982, 6.095266230404377, 38.86968746781349, 11.065865959972143, 25.609286315739155, 90.68760573863983, 61.78247697651386, 65.25762990117073, 86.10519602894783, 30.8832798153162, 65.41510105133057, 81.46619975566864, 9.278317429125309, 1.5976874437183142, 0.28179279004689306, 0.6117873592302203, 0.16229163680691272, 0.3404319263063371, 0.21588627656456083, 0.26580482139252126, 0.2957248908933252, 0.3990703501040116, 0.38233043742366135, 14.441112745553255, 84.42238792777061, 84.3605424463749, 81.38980105519295, 81.2137109041214, 70.24316757917404, 68.92542868852615, 64.84801188111305, 70.50096094608307, 67.80489161610603, 52.71398238837719, 38.1583846360445, 52.13952161371708, 77.1028558909893, 74.577716588974, 73.35487380623817, 70.89683890342712, 74.67077359557152, 72.72109061479568, 68.33769902586937, 72.21466898918152, 65.42356699705124, 60.6811136752367, 59.73059467971325, 65.03262877464294, 68.83253887295723, 66.40981927514076, 69.42640900611877, 61.67699843645096, 64.61674869060516, 62.06602916121483, 66.40332162380219, 68.79599243402481, 67.13528394699097, 71.93275451660156, 66.30511209368706, 66.68521329760551, 61.977212727069855, 67.14539140462875, 65.85475265979767, 63.59311401844025, 67.74154901504517, 63.632609099149704, 59.92184981703758, 58.530596271157265, 55.58046497404575, 61.37341372668743, 61.484732553362846, 63.37545409798622, 64.34835389256477, 61.711382791399956, 59.979716911911964, 52.97439381480217, 48.05742345750332, 53.29589456319809, 57.93162681162357, 60.62038533389568, 48.62881779670715, 41.35446533560753, 42.53403224050999, 39.94255609810352, 37.75205343961716, 38.67543429136276, 39.16410706937313, 38.740520998835564, 42.20071792602539, 56.82050563395023, 56.41514338552952, 51.29199989140034, 49.52138990163803, 48.336062505841255, 47.599152848124504, 59.05709221959114, 61.297740787267685, 61.780387088656425, 60.65442390739918, 57.67109379172325, 54.5635711401701, 54.32922251522541, 54.8270870000124, 53.68425652384758, 61.237027645111084, 61.82208985090256, 58.21409225463867, 57.55102403461933, 61.20175413787365, 54.26189012825489, 58.578325510025024, 59.493916779756546, 61.5808179974556, 57.63634465634823, 61.78034529089928, 51.172272115945816, 47.06291422247887, 51.22196584939957, 55.173993185162544, 47.95499615371227, 47.02096067368984, 45.72437904775143, 47.844805866479874, 44.48927812278271, 45.58102414011955, 49.53582152724266, 49.93949666619301, 36.369714215397835, 24.482042603194714, 10.457789339125156, 6.466917637735605, 4.349875012412667, 3.279565069824457, 8.765031471848488, 23.450130075216293, 33.371887877583504, 43.76374885439873, 49.940461814403534, 53.002284318208694, 46.08809553086758, 31.086025536060333, 50.29616452753544, 42.43985429406166, 31.248012743890285, 13.524193447083235, 4.391564000397921, 0.22559018398169428, 0.27658980048727244, 0.2584850782295689, 0.21600956213660538, 0.14506374718621373, 0.1811647936119698, 0.1931775372941047, 0.1851156316115521, 0.6235696957446635, 2.509666057303548, 49.44146119058132, 68.34276795387268, 65.29865249991417, 39.032223746180534, 50.41534513235092, 30.31351938843727, 9.041696526110172, 0.560862016864121, 1.005951133556664, 29.5762924477458, 77.72692680358887, 72.55908250808716, 96.61844909191132, 6.212903643026948, 1.1983431223779917, 17.177707850933075], [35.62856398522854, 33.735030591487885, 0.4425276385154575, 1.059248261153698, 2.914516283199191, 0.7597162714228034, 8.67007551714778, 5.643094293773174, 1.3640261068940163, 43.555197045207024, 48.19653019309044, 45.52976109087467, 78.49879458546638, 64.0791155397892, 50.244392305612564, 47.515340745449066, 12.727873027324677, 0.4315845522796735, 0.281133406679146, 0.16811681329272687, 0.10501556607778184, 0.008824619199003791, 0.014743892588739982, 0.03059439972275868, 0.06865510935313068, 0.21641286002704874, 0.42178464063908905, 11.524413954466581, 82.61082753539085, 68.05967554450035, 50.324381813406944, 49.40775319933891, 48.66950981318951, 53.1761933863163, 47.97909066081047, 47.00451895594597, 32.77020536363125, 18.08031901717186, 10.101234521716833, 10.54660577327013, 21.402756236493587, 50.60562752187252, 66.68539568781853, 67.83266052603722, 64.78549763560295, 66.23735412955284, 64.05410528182983, 59.12972152233124, 57.83056743443012, 50.90818628668785, 52.977133467793465, 54.11057084798813, 57.20964655280113, 59.88974153995514, 60.180049762129784, 61.067119762301445, 61.49538338184357, 57.05016531050205, 57.53986023366451, 55.95628760755062, 57.450150847435, 57.28552848100662, 59.69364546239376, 59.84979808330536, 57.69489571452141, 62.5360943377018, 60.4310566931963, 62.773908376693726, 59.183237850666046, 57.27630637586117, 50.945431888103485, 49.68513071537018, 54.10149313509464, 54.18794609606266, 60.5046321451664, 59.07930962741375, 55.07561266422272, 54.09919045865536, 51.14489458501339, 48.06102566421032, 47.71343931555748, 49.08935308456421, 54.783993512392044, 54.10539552569389, 55.20064875483513, 49.277549386024475, 50.853412225842476, 42.39919267594814, 41.28428690135479, 41.68097801506519, 45.846565291285515, 47.13391721248627, 51.04575790464878, 53.52395072579384, 53.78064975142479, 49.201135486364365, 43.139465153217316, 48.961862325668335, 49.651848301291466, 44.42436620593071, 50.352390110492706, 50.923754051327705, 52.46161513030529, 51.10840134322643, 49.07359533011913, 48.66797849535942, 52.06672891974449, 46.78743280470371, 49.587320163846016, 53.5016193240881, 53.82414981722832, 53.097442612051964, 52.81729504466057, 53.56260225176811, 52.00789287686348, 53.32139499485493, 52.9299172013998, 51.9865608215332, 48.06534603238106, 45.43214812874794, 41.69587701559067, 45.45519769191742, 42.150317430496216, 40.7950783520937, 36.9912164658308, 30.248590372502804, 28.90049871057272, 29.187653101980686, 36.066520884633064, 34.908073246479034, 32.256016954779625, 24.171568863093853, 12.353581711649895, 4.733953177928925, 2.7223456325009465, 1.4378093602135777, 0.8354599820449948, 7.886532386764884, 28.085355050861835, 39.448996782302856, 43.55639398097992, 55.94741128385067, 63.769135773181915, 57.28882670402527, 50.60761101543903, 24.921150840818882, 21.411448270082474, 21.838397160172462, 13.635111395269632, 3.040339881554246, 0.39736557751893997, 0.111615359201096, 0.09123915297095664, 0.04571651581500191, 0.025484471771051176, 0.06407736436813138, 0.016384362716053147, 0.05450224554806482, 0.4585990245686844, 6.123017091304064, 37.60790437459946, 42.701409459114075, 48.914133086800575, 21.074659042060375, 22.648095712065697, 0.7795585098210722, 3.8148860447108746, 1.235330575145781, 6.58666156232357, 35.24219311773777, 31.83119025081396, 70.12915089726448, 57.72649861872196, 1.0404395079240203, 0.18247073603561148, 0.770924185635522, 64.5230533182621, 33.46395693719387, 0.5160265602171421, 1.5111998096108437, 3.255838192999363, 2.7586108865216374, 19.805960319936275, 6.6993834637105465, 3.2183769531548023, 72.55661264061928, 54.915109276771545, 50.69903030991554, 73.95444363355637, 66.5920802950859, 50.46329475939274, 69.63449344038963, 20.10249450802803, 0.6186402321327478, 0.37241089157760143, 0.12496208364609629, 0.17294874385697767, 0.05674970991094597, 0.117987713747425, 0.06902005305164494, 0.08653960670926608, 0.20342646312201396, 0.3137687570415437, 13.763454258441925, 86.62170991301537, 74.74431484937668, 66.44330307841301, 64.97989520430565, 60.74329733848572, 61.44968703389168, 56.37106575071812, 62.6871058344841, 50.34414455294609, 36.46907888352871, 22.03488651663065, 22.817564718425274, 43.903847336769104, 61.519067510962486, 67.10562273859978, 66.3416813313961, 66.55919685959816, 69.26042631268501, 67.9926547408104, 65.96348762512207, 62.402113527059555, 56.34597189724445, 55.62907576560974, 58.552076518535614, 60.43011054396629, 65.50330191850662, 63.10654252767563, 64.27950918674469, 63.15180949866772, 60.43044492602348, 62.39330179989338, 63.4942889213562, 59.31882597506046, 62.688937336206436, 64.80005085468292, 62.08033159375191, 62.79011830687523, 64.13722202181816, 62.4686099588871, 63.88367682695389, 60.89169077575207, 59.494197964668274, 52.17342719435692, 53.91879513859749, 56.661658957600594, 58.170516192913055, 60.74976459145546, 61.93731486797333, 55.913612097501755, 53.80688354372978, 52.04488769173622, 50.81151567399502, 50.34557327628136, 50.33538222312927, 55.538412630558014, 55.49117736518383, 55.88844984769821, 53.66674326360226, 51.915481835603714, 44.78778250515461, 40.35550653934479, 43.8973268866539, 51.022343561053276, 47.90097065269947, 52.58559487760067, 56.34392760694027, 54.663623571395874, 51.543542593717575, 45.957314148545265, 51.348654851317406, 50.38992069661617, 47.99008347094059, 50.08839167654514, 51.16056114435196, 52.97310568392277, 53.39382290840149, 51.305014193058014, 52.17706359922886, 54.94669318199158, 51.864784955978394, 51.68236054480076, 56.63841940462589, 57.13049300014973, 56.00895658135414, 54.98213768005371, 57.619405165314674, 56.26568600535393, 55.047972947359085, 55.30627928674221, 55.138860270380974, 50.967983677983284, 49.836658984422684, 42.67454110085964, 48.68981972336769, 45.96931390464306, 46.254974976181984, 42.70774371922016, 36.50766961276531, 33.44688065350056, 37.14346669614315, 39.04412850737572, 38.04488092660904, 33.312052488327026, 26.132328249514103, 13.916196562349796, 4.6506250742822886, 3.624498685821891, 1.8384548742324114, 2.3926178505644202, 9.941355250775814, 31.486829929053783, 40.34580945968628, 45.89158147573471, 58.616889640688896, 66.14294439554214, 58.057768642902374, 53.48255194723606, 38.10116350650787, 26.118884570896626, 28.558712750673294, 20.4933263361454, 6.064844587817788, 0.9754922054708004, 0.09451449557673186, 0.0219387554898276, 0.04253793442330789, 0.02197920624894323, 0.052520113822538406, 0.011416244342399295, 0.04599303261784371, 0.37128350988496095, 9.036927781999111, 57.47504711151123, 52.96288803219795, 63.69684085249901, 28.91283094882965, 40.7325679063797, 19.8929338529706, 7.451686095446348, 1.1131318635307252, 9.584440402686596, 60.854308381676674, 43.30708935856819, 80.42386248707771, 62.50628873705864, 0.8428403141442686, 0.6160203914623708, 7.415538160130382, 71.68996274471283, 56.315797716379166, 0.2677604102063924, 1.771522534545511, 13.993683904409409, 4.5352342911064625, 42.20795653760433, 11.22551154345274, 10.260346233844757, 96.2540790438652, 66.10195219516754, 56.63195975124836, 110.97258925437927, 90.44686585664749, 57.51113757491112, 85.95594763755798, 19.544268362224102, 0.9995485958643258, 0.3594567335676402, 0.37088690616656095, 0.360604984452948, 0.1981429653824307, 0.1344414913910441, 0.24668804719112813, 0.22414734499761835, 0.5809704784769565, 0.5963222484569997, 19.450443796813488, 94.08211559057236, 83.70593637228012, 78.8039182126522, 73.12430217862129, 69.60981756448746, 67.9230272769928, 64.72976222634315, 71.77838400006294, 68.21948736906052, 57.488711178302765, 35.09905859827995, 32.106088399887085, 55.79055570065975, 71.42548173666, 73.25992450118065, 73.06269988417625, 71.61417201161385, 71.35978326201439, 71.81143462657928, 70.92446342110634, 65.94944357872009, 59.93427515029907, 60.05864627659321, 61.322291269898415, 61.759651601314545, 68.70074674487114, 66.40952289104462, 67.26926475763321, 66.83185502886772, 64.22753557562828, 65.59342548251152, 63.73252473771572, 63.58539283275604, 65.59945195913315, 66.45544722676277, 65.1332625746727, 64.48648408055305, 67.77758628129959, 63.83038088679314, 66.64374232292175, 62.09046944975853, 61.39255329966545, 58.1417403370142, 55.41370712220669, 57.485906928777695, 61.77245311439037, 64.47759255766869, 64.31572884321213, 60.92568755149841, 57.32894495129585, 57.56615102291107, 52.96645224094391, 52.54229240119457, 52.034814432263374, 58.383901342749596, 59.25919957458973, 60.6041070073843, 54.21083226799965, 54.65331852436066, 43.253352642059326, 40.979273468256, 44.574891328811646, 49.798938408493996, 50.60482956469059, 54.734653159976006, 58.75617876648903, 59.26650658249855, 54.47489149868488, 47.219891399145126, 53.46511848270893, 49.449585154652596, 50.516328513622284, 54.906601533293724, 54.03734877705574, 59.74157229065895, 58.13315659761429, 55.36033518612385, 55.231301710009575, 58.55192832648754, 54.447426572442055, 56.855889335274696, 59.84317883849144, 60.749760791659355, 58.55751782655716, 59.04381953179836, 60.363602712750435, 60.580289885401726, 59.05904911458492, 57.9792420566082, 61.405016630887985, 55.77583149075508, 52.32931762933731, 46.970343589782715, 55.258785635232925, 50.91575548052788, 50.19066318869591, 46.972574070096016, 43.55336174368858, 41.947830095887184, 44.27289493381977, 50.08742652833462, 46.15966089069843, 39.46254685521126, 31.075498200953007, 17.231560461223125, 6.0834878124296665, 4.998193373903632, 3.074860079213977, 7.559269247576594, 16.923754177987576, 36.99359513819218, 46.05856731534004, 55.34347169101238, 62.75667630136013, 69.16294634342194, 66.72701105475426, 64.16429936885834, 42.13827967643738, 32.878883332014084, 35.70316918194294, 29.410754330456257, 10.797177627682686, 1.9196198252029717, 0.19424857513513416, 0.12747202708851546, 0.1033721245767083, 0.17945960542419925, 0.13165628537535667, 0.09358050272567198, 0.11315103343804367, 0.9293697460088879, 11.011517476290464, 72.83316180109978, 64.1859582066536, 77.41005420684814, 39.41765986382961, 51.94026790559292, 33.635757118463516, 14.607669208198786, 3.0065178964287043, 10.220832154154778, 72.96670943498611, 53.792641907930374, 93.6375318467617, 82.23966345191002, 1.9376930803991854, 0.5577147169969976, 5.896272333338857], [36.01100206375122, 51.13431595265865, 1.9631175161339343, 0.8762274601031095, 3.8397642597556114, 1.2116906186565757, 4.784040190279484, 1.596138789318502, 0.6187251338269562, 25.105663239955902, 47.685719802975655, 37.09109030663967, 86.40381440520287, 67.4244712293148, 50.76440580189228, 48.50161202251911, 23.136320114135742, 0.9020796697586775, 0.10098775994265452, 0.05716668187233154, 0.07833955023670569, 0.04599727028107736, 0.027654652585624717, 0.07561094040283933, 0.02005265767365927, 0.06835652107838541, 0.24967771489173174, 25.563219487667084, 80.83299413323402, 57.93434366583824, 42.33020357787609, 38.41820329427719, 34.76550489664078, 40.80417886376381, 42.2303107380867, 49.98852923512459, 41.83304585516453, 30.876354686915874, 9.52369686216116, 9.88436970859766, 13.4264275431633, 31.46436743438244, 56.32025107741356, 62.9946993291378, 62.76166923344135, 64.48387742042542, 65.25221139192581, 59.36251983046532, 59.53558914363384, 52.640995904803276, 51.286501586437225, 52.56515197455883, 55.59947915375233, 57.58639253675938, 58.939769715070724, 59.415359795093536, 60.6212554872036, 57.927021458745, 58.26555669307709, 56.437512785196304, 54.979337230324745, 57.84497246146202, 60.22980809211731, 54.6839714795351, 61.72322675585747, 57.341997250914574, 60.607352033257484, 61.032192036509514, 61.02185279130936, 52.94632472097874, 51.44419692456722, 57.270222902297974, 49.982411563396454, 55.98197802901268, 58.73915188014507, 58.33369463682175, 51.5953604131937, 46.589364632964134, 45.05769722163677, 51.34232819080353, 53.57715927064419, 47.883704379200935, 53.198638781905174, 49.35990996658802, 53.64709451794624, 47.68177941441536, 53.37984345853329, 48.80382880568504, 43.6880949139595, 47.07929514348507, 52.21145935356617, 46.63309268653393, 49.8419065028429, 47.19364620745182, 50.087038949131966, 48.825658634305, 47.06480652093887, 44.397342056035995, 42.55900830030441, 47.49416448175907, 44.601003527641296, 50.508801117539406, 50.04120200872421, 50.12043535709381, 48.62227074801922, 50.506699830293655, 48.628734201192856, 49.89777870476246, 50.406438410282135, 51.66225582361221, 55.14058157801628, 54.61307108402252, 53.33768092095852, 52.32352294027805, 52.155579552054405, 50.54617591202259, 50.89415743947029, 51.235865503549576, 46.578930392861366, 44.98923249542713, 41.07108794152737, 43.185169100761414, 40.06862573325634, 35.40008224546909, 33.609705716371536, 30.059107840061188, 28.90306357294321, 31.67259056121111, 30.86311049759388, 30.7488202303648, 28.99428717792034, 26.62424225360155, 10.463441535830498, 4.39382535405457, 2.358399499207735, 1.3260178151540458, 1.5991522651165724, 9.197228830307722, 31.33238721638918, 56.58431030809879, 57.24852606654167, 64.49826344847679, 61.939936727285385, 61.63424693048, 35.03167301416397, 19.802641198039055, 17.50932365655899, 10.385338626801968, 13.320827409625053, 14.482598919421434, 2.543058665469289, 1.0277421330101788, 0.11805893765995279, 0.18393895647022873, 0.013112580563756637, 0.04256559426721651, 0.09241912324796431, 0.06114011826866772, 0.042106115797651, 9.765737224370241, 41.459096521139145, 46.374634355306625, 46.44624151289463, 23.160948492586613, 22.308188751339912, 35.592089742422104, 9.272147510200739, 1.8537389603443444, 21.230230294167995, 30.613536089658737, 38.78949657082558, 80.01848503947258, 19.439471885561943, 0.5078924435656518, 0.26951282867230475, 1.7940332391299307, 47.62285217642784, 45.34698709845543, 1.4536376483738422, 1.1217359080910683, 2.7731040213257074, 2.7701280685141683, 20.12066513299942, 2.5412836857140064, 0.7157491275575012, 47.48884096741676, 60.96277356147766, 41.99150115251541, 94.37131807208061, 76.90709039568901, 48.905359357595444, 69.03528079390526, 37.731067165732384, 1.1984530789777637, 0.3233931359136477, 0.10460297649842687, 0.0475718812958803, 0.1261942565906793, 0.08395888464292511, 0.012501170549512608, 0.055835272651165724, 0.07399701411486603, 0.21968636952806264, 28.00512995570898, 86.43479034304619, 66.96665659546852, 59.376161098480225, 52.240311205387115, 53.59169729053974, 55.730078145861626, 56.06548994779587, 60.254552364349365, 55.01751758158207, 42.9842434823513, 25.702909491956234, 18.676900304853916, 30.470175482332706, 49.91738945245743, 63.038039803504944, 63.40501271188259, 64.21347633004189, 69.87494453787804, 68.85457769036293, 64.68211278319359, 63.757044821977615, 58.383908942341805, 52.98860885202885, 54.29132714867592, 59.94843319058418, 61.748487800359726, 62.09285192191601, 61.880450919270515, 62.30204589664936, 62.23926566541195, 62.959346026182175, 59.11709859967232, 60.26182897388935, 60.5870421230793, 61.92422077059746, 60.00007621943951, 64.97944682836533, 59.13895882666111, 64.75884586572647, 62.38634057343006, 65.88116124272346, 57.62915924191475, 54.09955523908138, 59.291953817009926, 54.712504148483276, 57.33871802687645, 59.46325242519379, 60.48091001808643, 54.51657526195049, 48.88292916119099, 46.31679005920887, 53.316497057676315, 54.29317764937878, 48.755415603518486, 55.020025447010994, 51.86279386281967, 54.9119820445776, 48.45606006681919, 51.96565434336662, 49.47450801730156, 45.87687626481056, 48.455908074975014, 54.3834076076746, 47.26147636771202, 50.717812702059746, 49.70498465001583, 51.77546314895153, 50.00888094305992, 48.97253595292568, 49.20505307614803, 45.458005741238594, 49.81321424245834, 47.874254286289215, 50.36993756890297, 53.1301474571228, 53.88829417526722, 51.185598000884056, 54.16093334555626, 52.81240850687027, 54.111870378255844, 54.220981523394585, 52.243613228201866, 58.0622486025095, 55.91001369059086, 55.98249480128288, 53.90744894742966, 56.732183173298836, 54.422883689403534, 56.61845147609711, 53.055226877331734, 48.74569572508335, 47.00755499303341, 44.94040511548519, 46.46557107567787, 46.08868449926376, 39.906549230217934, 38.33578571677208, 36.07578098773956, 37.597595527768135, 36.78477354347706, 32.89782531559467, 33.566904813051224, 29.36446711421013, 23.796597383916378, 9.86889123916626, 4.66032262891531, 2.717388798482716, 1.307051251642406, 3.183515486307442, 14.696092363446951, 36.038258001208305, 54.72839489579201, 59.59749922156334, 64.93317291140556, 67.42392405867577, 66.3235867023468, 46.41754925251007, 24.519483894109726, 20.49893483519554, 12.429430391639471, 19.815522506833076, 18.59305400401354, 2.053062845952809, 0.9317434311378747, 0.3449018520768732, 0.12834511930122972, 0.16544135607546195, 0.06942292049643584, 0.058804119398701005, 0.03900076582795009, 0.21110358007717878, 16.957008093595505, 55.0665083527565, 58.528263196349144, 60.43439671397209, 32.769893780350685, 33.19235511124134, 60.873748138546944, 12.569692265242338, 2.6017355918884277, 35.720940828323364, 39.20531965792179, 39.71317760646343, 89.14393097162247, 18.88295754790306, 0.7324129552580416, 0.6657953455578536, 3.162328298203647, 70.40186986327171, 82.50476762652397, 2.1843230025842786, 1.2223363411612809, 11.934219114482403, 3.7877970607951283, 45.8114779740572, 3.5297225089743733, 0.2790374035248533, 68.57822611927986, 77.74164721369743, 45.9220140427351, 111.65531381964684, 90.33072128891945, 56.94642327725887, 84.47178527712822, 37.35624007880688, 1.3815917330794036, 0.28784034366253763, 0.1856176054570824, 0.1808996984618716, 0.30143865616992116, 0.2921969286398962, 0.13366927189053968, 0.10164698003791273, 0.3078139421995729, 0.31029975099954754, 41.25785931944847, 93.55509147047997, 78.59154760837555, 70.3523737192154, 62.85702891647816, 63.887294232845306, 64.21114325523376, 61.7795093357563, 69.18845817446709, 66.38400346040726, 66.45328134298325, 48.24631132185459, 32.2222101688385, 45.51167406141758, 63.22513036429882, 68.96873116493225, 70.13940274715424, 70.32525837421417, 74.26045641303062, 71.92342981696129, 67.99367308616638, 68.69012251496315, 60.7618897408247, 59.34849478304386, 60.67832462489605, 64.63065594434738, 64.343740940094, 66.57308131456375, 64.51414659619331, 65.86948826909065, 66.58371314406395, 64.85897049307823, 62.74209648370743, 61.36424861848354, 65.10030314326286, 64.85203966498375, 60.192433297634125, 67.67814561724663, 61.46945737302303, 64.14525479078293, 65.5388756096363, 69.0774205327034, 60.05183704197407, 57.26856619119644, 62.03444145619869, 56.63643591105938, 62.3870587348938, 63.02063673734665, 63.27832750976086, 56.47310167551041, 51.263330429792404, 47.73034080862999, 54.50889967381954, 58.75163421034813, 51.55491538345814, 60.18316179513931, 54.27593797445297, 60.044701024889946, 51.92045196890831, 57.96832524240017, 52.912829518318176, 46.18866093456745, 50.392272770404816, 58.82187344133854, 51.17454059422016, 55.12435644865036, 52.15158596634865, 55.0280924141407, 54.511912912130356, 51.81055426597595, 51.615514531731606, 46.93934865295887, 46.60136438906193, 48.30646209418774, 55.495227947831154, 57.07555174827576, 59.3271741271019, 54.994095638394356, 58.45641665160656, 55.32195724546909, 55.90302586555481, 58.0010224878788, 58.0851461738348, 59.60163339972496, 59.694952592253685, 58.78861762583256, 56.01583041250706, 59.58439752459526, 56.50427520275116, 58.12907561659813, 57.72201485931873, 54.109993278980255, 52.71079055964947, 47.65371032059193, 53.19168895483017, 50.30935361981392, 47.305793389678, 43.11488427221775, 42.96883910894394, 43.74788850545883, 47.57838696241379, 41.70694962143898, 39.152430295944214, 33.93607780337334, 27.863152474164963, 11.977365799248219, 7.191380588337779, 3.1946287024766207, 1.9309903588145971, 5.778813986107707, 19.226979687809944, 41.65909878909588, 59.96829852461815, 68.35651561617851, 67.9796214401722, 68.03349494934082, 69.9872513115406, 55.68350784480572, 37.090391144156456, 47.790130600333214, 19.66160986572504, 22.844374179840088, 28.993810303509235, 6.981617119163275, 2.8662602975964546, 0.44670150673482567, 0.2991736214607954, 0.1796251637279056, 0.1890736387576908, 0.09517121463431977, 0.20715651218779385, 0.40534847415983677, 22.716180458664894, 73.06260868906975, 68.25481787323952, 74.45007383823395, 46.32404766976833, 39.21229988336563, 73.39044749736786, 23.63229800015688, 12.810510993003845, 52.657578215003014, 57.98837296664715, 63.82556274533272, 106.82030886411667, 30.5944687128067, 0.8531213749665767, 0.8277252595871687, 2.715624743141234], [40.52216939628124, 61.87789365649223, 3.8865074515342712, 0.4147451918106526, 1.218688536901027, 1.4968490484170616, 6.719840141013265, 3.303012424148619, 1.0710342787206173, 13.270194176584482, 49.58334557712078, 40.10611832141876, 37.127598747611046, 35.90505614876747, 44.79743018746376, 48.413589745759964, 34.18691374361515, 1.1989164166152477, 0.1309454266447574, 0.08966156223323196, 0.02755073150183307, 0.01669655270234216, 0.009613427555450471, 0.07317147130379453, 0.04299271880881861, 0.05369272570533212, 1.1043512471951544, 42.73474507033825, 68.48596706986427, 49.74013276398182, 38.80297064781189, 34.83774282038212, 29.73873183131218, 33.83565679192543, 34.29987408220768, 45.6056772172451, 43.447818607091904, 39.36963424086571, 22.543954700231552, 16.684600710868835, 16.561316326260567, 20.52907671779394, 38.96128535270691, 55.865651071071625, 62.8713009506464, 56.27608984708786, 64.97868686914444, 61.53692275285721, 57.421052008867264, 51.74580194056034, 50.465916618704796, 48.69835026562214, 54.93900619447231, 57.36940898001194, 60.173164531588554, 58.7335129827261, 58.405742570757866, 58.52965772151947, 58.78510661423206, 55.55565230548382, 59.57652434706688, 52.83075012266636, 58.61163452267647, 55.99405758082867, 58.74489337205887, 58.32501210272312, 58.28773990273476, 60.79744443297386, 59.18909713625908, 52.25122042000294, 56.77187964320183, 50.67053563892841, 56.2297323346138, 49.86512325704098, 55.54677598178387, 52.16428108513355, 48.515241891145706, 47.47221305966377, 48.010024800896645, 50.94785615801811, 44.895901903510094, 46.44365385174751, 49.71100352704525, 46.82666189968586, 49.634354040026665, 50.94998024404049, 48.263756185770035, 45.190598890185356, 48.69876064360142, 46.629737466573715, 44.47305679321289, 46.07754349708557, 47.370256930589676, 45.18792763352394, 49.863542541861534, 46.08103550970554, 44.12690296769142, 49.21734161674976, 45.864496529102325, 42.4785590171814, 50.3390946239233, 45.46505056321621, 49.59228649735451, 47.476202845573425, 50.44451616704464, 49.17577564716339, 49.49879251420498, 52.573272138834, 54.457579627633095, 48.013866394758224, 55.52456997334957, 52.91500300168991, 54.16271165013313, 51.46204076707363, 52.49919891357422, 48.283617720007896, 52.87918992340565, 46.17917284369469, 42.23457030951977, 43.76705087721348, 39.40149933099747, 40.04078082740307, 36.321658194065094, 32.74497851729393, 30.80175518989563, 29.559024274349213, 31.02589376270771, 23.57956252992153, 24.761893786489964, 31.965199559926987, 30.356270894408226, 23.52853886783123, 7.272151904180646, 3.0972793512046337, 1.7893954692408442, 0.444951641256921, 1.150328661315143, 15.16383871436119, 40.572516694664955, 49.05362740159035, 64.01637330651283, 62.26690158247948, 62.60429307818413, 52.66818344593048, 51.580020636320114, 46.112448424100876, 57.54234530031681, 25.511329472064972, 28.872942589223385, 42.911606580019, 5.907043805345893, 5.897532915696502, 1.5819873986765742, 0.07308834334253334, 0.07798622857080773, 0.14374824590049684, 0.06173515743284952, 0.2639747742796317, 0.08410295034991577, 11.372771691530943, 35.31822703778744, 49.62532192468643, 39.817592203617096, 29.76881291717291, 25.091928876936436, 43.923940658569336, 19.631838463246822, 7.653828598558903, 21.44209172576666, 19.083738774061203, 57.40692436695099, 45.73647379875183, 1.3345393328927457, 0.06505505487439223, 0.4372148704715073, 0.8501290355343372, 52.393686175346375, 64.5481775701046, 3.6098896572366357, 0.8170399360824376, 1.6359617211855948, 2.2185993008315563, 18.991711512207985, 3.0226722545921803, 1.3633758667856455, 28.918785229325294, 60.57777442038059, 43.292205557227135, 46.26102425158024, 42.357406318187714, 51.49737507104874, 67.48408243060112, 49.38577137887478, 1.3454242050647736, 0.08209118837839924, 0.035861006181221455, 0.20723399240523577, 0.030921384422981646, 0.05214406017330475, 0.03083242874708958, 0.03383718430995941, 0.04055374694871716, 1.2305522128008306, 46.38243533670902, 76.47210493683815, 60.91116093099117, 53.875564858317375, 46.484148278832436, 46.47423081099987, 49.28686648607254, 49.73767809569836, 59.38859403133392, 58.7924250215292, 51.12527623772621, 36.26181900501251, 23.92749086022377, 27.956686355173588, 36.33574403822422, 52.56931655108929, 63.88667106628418, 62.715133130550385, 59.92351032793522, 66.6067323088646, 65.37442803382874, 61.79020956158638, 56.897288113832474, 54.90321211516857, 50.038914531469345, 59.38775807619095, 60.63607469201088, 63.54304790496826, 62.936801835894585, 61.61871716380119, 60.77336512506008, 62.908770740032196, 58.66891644895077, 61.95172369480133, 57.28733338415623, 60.17250336706638, 60.48594854772091, 63.06480176746845, 60.905408039689064, 60.62583804130554, 63.58034670352936, 61.089629754424095, 56.33597083389759, 56.54283553361893, 54.547026827931404, 55.76776832342148, 52.20077432692051, 59.48820948600769, 51.88933923840523, 51.541372910141945, 48.41744653880596, 53.23569819331169, 53.44179153442383, 47.42184296250343, 49.503470063209534, 53.00564333796501, 48.74270148575306, 49.78819638490677, 50.72237245738506, 51.074617356061935, 48.50662015378475, 52.12486959993839, 48.73865470290184, 47.025414034724236, 49.229975938797, 49.35636855661869, 47.5371477752924, 52.028993144631386, 47.54994548857212, 45.161013677716255, 50.20954817533493, 50.1096211373806, 44.74655471742153, 51.58247150480747, 47.00524091720581, 50.15589125454426, 49.60687771439552, 54.10791479051113, 49.967850744724274, 53.80547381937504, 53.34750719368458, 56.664558202028275, 50.7506163418293, 54.90193158388138, 56.2666055560112, 56.15467116236687, 53.59686121344566, 54.79443535208702, 52.6302956789732, 57.91634023189545, 48.52417901158333, 47.57688224315643, 44.805341362953186, 46.608435809612274, 42.254960015416145, 41.92738339304924, 39.44847621023655, 37.883290797472, 36.20309695601463, 38.4677754342556, 29.000127464532852, 29.71762776374817, 32.77248524129391, 28.68024542927742, 24.17197734117508, 9.945947304368019, 2.824663929641247, 2.1901813382282853, 0.36652931186836213, 3.10524586122483, 17.297846004366875, 44.71284292638302, 54.04163874685764, 65.76228842139244, 64.04802560806274, 66.37377440929413, 58.520279824733734, 57.25999005138874, 49.024513363838196, 61.31992019712925, 23.201887495815754, 27.375347949564457, 40.029047057032585, 7.365571791306138, 6.917912112548947, 1.1411736463196576, 0.2897544909501448, 0.014543278939527227, 0.2235059512895532, 0.03962797338317614, 0.24318586714798585, 0.2922437433153391, 19.564150795340538, 54.24514062702656, 60.00949211418629, 54.87804226577282, 41.62684611976147, 30.26854120194912, 59.25681330263615, 28.945066519081593, 15.890007298439741, 34.39292348921299, 30.33484384417534, 75.04127651453018, 48.65442082285881, 0.7302134670317173, 0.14105582318734378, 0.4375367844477296, 1.115170216653496, 70.6454747915268, 108.04892733693123, 9.983380995690823, 0.721032862784341, 8.869008142501116, 6.790406154468656, 38.113186061382294, 5.313440132886171, 1.9884214270859957, 59.068860188126564, 74.22687381505966, 50.691624507308006, 57.78834030032158, 54.15271058678627, 57.48986251652241, 83.64947140216827, 56.94065138697624, 1.0694611631333828, 0.15888599533354864, 0.272579857846722, 0.2583142358344048, 0.08507897844538093, 0.09734318402479403, 0.14107669238001108, 0.1211077174230013, 0.18058035231661052, 2.278716587461531, 60.76771482825279, 82.36572548747063, 75.23904830217361, 68.6429138481617, 62.71800197660923, 60.70218354463577, 60.216881185770035, 56.36763073503971, 66.04937061667442, 67.61588215827942, 64.51457217335701, 59.34292808175087, 49.66593414545059, 49.07866045832634, 51.98265843093395, 60.4561011493206, 70.58008790016174, 69.77466031908989, 66.67459666728973, 71.41088292002678, 69.83800292015076, 65.61513751745224, 58.21555137634277, 59.538910165429115, 55.047011598944664, 63.13851401209831, 66.51331812143326, 68.76555606722832, 63.567089214921, 65.45831233263016, 64.16439056396484, 66.62384659051895, 62.88271553814411, 67.11776688694954, 59.75231051445007, 63.69872935116291, 61.85148887336254, 65.91500222682953, 64.28273141384125, 62.699063792824745, 66.28949493169785, 65.01059755682945, 59.62255507707596, 61.28409571945667, 56.75985708832741, 60.73113039135933, 55.41948281228542, 61.80371783673763, 56.033852845430374, 50.765773728489876, 51.08432963490486, 52.86880128085613, 57.51857377588749, 49.44706209003925, 50.736359506845474, 56.73571698367596, 51.421371549367905, 54.503431767225266, 55.024520605802536, 55.791904628276825, 49.27679322659969, 53.38656909763813, 50.8345690369606, 49.82052505016327, 51.262042298913, 52.08888553082943, 47.92438119649887, 54.651088044047356, 48.5834102332592, 48.45345340669155, 54.82041075825691, 52.85563498735428, 49.77761395275593, 51.4021597802639, 48.98007854819298, 55.50014108419418, 54.965008199214935, 59.84395779669285, 53.39601919054985, 55.88460445404053, 59.32855725288391, 60.52993878722191, 53.738772198557854, 60.50578348338604, 58.14780481159687, 59.90869112312794, 56.82257652282715, 60.26447743177414, 55.6200360506773, 61.752602979540825, 51.607265174388885, 50.385258346796036, 48.29645723104477, 49.5866210013628, 48.4577851742506, 49.35175180435181, 44.836176708340645, 44.12750333547592, 43.02063412964344, 50.641774982213974, 36.91191092133522, 34.609948843717575, 37.180541306734085, 31.253370456397533, 29.73626386374235, 11.465815398842096, 3.8754737935960293, 3.6286276392638683, 0.3930972784291953, 7.203131932765245, 27.386101372539997, 49.675540030002594, 61.7012183368206, 68.01432877779007, 68.49991232156754, 68.17797839641571, 64.04085159301758, 68.32626163959503, 61.13346800208092, 72.03476384282112, 44.38438855111599, 40.55126063525677, 52.85490922629833, 14.573115762323141, 12.439614795148373, 1.3374926056712866, 0.23917297075968236, 0.1696340600028634, 0.20486970286583528, 0.10179597360547632, 0.2938767947489396, 0.6556960812304169, 25.97848780453205, 68.20593729615211, 70.51635771989822, 68.25756132602692, 54.1463915258646, 36.690819784998894, 67.85379499197006, 37.38862194120884, 36.057636961340904, 55.54656699299812, 57.4848809838295, 112.98772752285004, 70.48260793089867, 2.7760334266349673, 0.5293975083623081, 1.025337337050587, 5.600748416036367], [62.95726753771305, 68.4763839840889, 11.986845340579748, 2.207410088740289, 5.252987751737237, 5.196140427142382, 17.45250530540943, 1.7068038135766983, 3.321462096646428, 21.017599403858185, 54.822926223278046, 34.89342123270035, 53.12426157295704, 41.88849627971649, 41.97472505271435, 51.52596853673458, 37.90034428238869, 2.4222130374982953, 0.48172835377044976, 0.18889380153268576, 0.16997390426695347, 0.09423987125046551, 0.015631995665899012, 0.06745293401763774, 0.3606209554709494, 0.2818448294419795, 13.712398298084736, 64.71678972244263, 68.85302737355232, 49.36321198940277, 38.97439084947109, 35.07828131318092, 29.941616244614124, 32.1170774102211, 33.58179621398449, 44.234429597854614, 50.64595855772495, 47.0638033747673, 39.190394058823586, 34.14890058338642, 32.36860491335392, 23.5977141559124, 34.63729977607727, 47.68896482884884, 58.43322269618511, 61.5223353356123, 65.86530849337578, 60.7782706618309, 55.15915498137474, 52.86206044256687, 44.9380112439394, 47.390426248312, 54.59917902946472, 57.100615203380585, 58.32731477916241, 56.43595866858959, 56.32117062807083, 55.59035964310169, 57.4468108266592, 53.75449575483799, 56.57519839704037, 57.37481229007244, 56.891672015190125, 54.294488579034805, 59.81705904006958, 54.55995753407478, 55.25934800505638, 61.76502451300621, 52.68024779856205, 56.311956122517586, 54.96405445039272, 52.25997895002365, 50.03980368375778, 51.81952178478241, 49.79481942951679, 47.247854098677635, 48.425673097372055, 47.83399164676666, 52.62800820171833, 43.22046920657158, 47.49228358268738, 48.04117172956467, 47.32338264584541, 47.07402102649212, 51.684914007782936, 47.68409349024296, 50.16555413603783, 47.05827847123146, 51.7751819640398, 45.690481066703796, 48.629383966326714, 47.718888223171234, 48.35842050611973, 44.56251919269562, 46.85190014541149, 48.53175200521946, 46.130360662937164, 41.65383227169514, 46.47363044321537, 41.49849280714989, 42.72385485470295, 48.152570351958275, 43.43488410115242, 46.88936233520508, 47.86659009754658, 44.38102573156357, 50.27371533215046, 48.43620613217354, 54.83493357896805, 53.13823342323303, 48.338061198592186, 57.2088485956192, 49.92612138390541, 47.53452971577644, 51.004925295710564, 49.59539473056793, 49.739049822092056, 43.306336998939514, 41.37268915772438, 39.28012624382973, 38.43939855694771, 36.89421907067299, 34.00698199868202, 29.9937741458416, 31.938540190458298, 32.027865797281265, 22.956422567367554, 15.984710566699505, 28.576072119176388, 34.14206475019455, 29.596792347729206, 11.469068974256516, 2.31801122892648, 2.052992549724877, 1.071028697770089, 0.31012561346869916, 2.7398795541375875, 19.41521968692541, 30.355830118060112, 32.17822752892971, 56.86317354440689, 60.780064165592194, 58.82037632167339, 56.62918210029602, 57.36612215638161, 61.94230780005455, 57.49998137354851, 57.094440534710884, 58.0108867585659, 53.73600214719772, 40.50248645246029, 17.562021128833294, 3.988400883972645, 0.20161168940830976, 0.05363904987461865, 0.1305299872183241, 0.8230249118059874, 0.14574849716154858, 0.1738874419243075, 22.745585180819035, 44.27664153277874, 48.53788487613201, 47.0458759367466, 29.42469198256731, 28.43550056219101, 27.204554714262486, 23.36500894278288, 15.551871042698622, 8.715255092829466, 14.214816838502884, 21.772749982774258, 5.134722897782922, 0.47245144844055176, 0.030057487419981044, 0.05041036980401259, 1.8124437262304127, 58.23396138846874, 76.68159529566765, 2.8997127525508404, 1.491380666848272, 1.539384440984577, 2.692727646790445, 17.135150134563446, 4.736522315070033, 3.9651656057685614, 39.2208456248045, 63.532830253243446, 39.85135719180107, 53.07824224233627, 49.42934364080429, 51.69516205787659, 67.99031406641006, 54.11906339228153, 2.5021823588758707, 0.39605497440788895, 0.10460318429977633, 0.08115885793813504, 0.0253047328806133, 0.07443011665600352, 0.030195786639524158, 0.14814187888987362, 0.1669891198980622, 11.651727072894573, 67.22395598888397, 76.50475278496742, 61.815151423215866, 52.86054812371731, 45.447320714592934, 43.4930095821619, 44.68428745865822, 48.25716353952885, 55.465103164315224, 61.242062374949455, 58.83734621107578, 50.564479529857635, 44.528260231018066, 43.29029805958271, 36.53124734759331, 44.73339982330799, 58.551210165023804, 62.27392740547657, 66.4119091629982, 69.36415314674377, 65.78057304024696, 62.927849516272545, 59.29384231567383, 50.317488983273506, 50.688132494688034, 58.4597946703434, 59.629121124744415, 61.2719401717186, 59.498168751597404, 59.38167080283165, 59.50395964086056, 59.47305969893932, 58.187254294753075, 60.09060636162758, 60.960451886057854, 59.613420367240906, 58.29956106841564, 63.62363778054714, 58.17730262875557, 60.285748690366745, 64.8671780526638, 55.00697314739227, 58.80761660635471, 57.57700704038143, 54.750980883836746, 51.79475091397762, 54.05762068927288, 52.06488601863384, 50.68780571222305, 52.01209545135498, 50.923590660095215, 54.14434723556042, 47.79664725065231, 47.904439866542816, 49.453324154019356, 49.370830580592155, 48.61182890832424, 50.91555409133434, 50.301856622099876, 51.87987394630909, 51.16242304444313, 54.21932101249695, 49.801442474126816, 50.35536155104637, 50.65779872238636, 50.75372077524662, 48.46177116036415, 48.04880551993847, 50.03232568502426, 49.58998002111912, 45.08975230157375, 49.46048676967621, 44.156301990151405, 44.53947722911835, 49.826859310269356, 45.45918367803097, 47.58727088570595, 48.538838624954224, 49.31473799049854, 53.531683310866356, 51.588801965117455, 54.95150372385979, 57.886633425951004, 52.04991862177849, 58.46651270985603, 54.42588172852993, 53.08600142598152, 52.05754101276398, 53.95345687866211, 50.930836871266365, 46.31955251097679, 47.72244103252888, 44.64038461446762, 42.12103620171547, 42.152699902653694, 40.55104784667492, 37.672284319996834, 37.59401232004166, 36.63310848176479, 24.256095327436924, 21.798079423606396, 29.724834077060223, 32.87059597671032, 31.557251550257206, 16.70817654579878, 4.3567692674696445, 2.2960821306332946, 2.095115426927805, 0.3845605318201706, 3.362308479845524, 27.7932533249259, 37.5603461265564, 43.22174973785877, 66.01038470864296, 59.538336396217346, 66.76000088453293, 61.36054381728172, 66.1386126279831, 62.42509089410305, 67.87341713905334, 59.69725526869297, 60.49871206283569, 55.28364770114422, 35.11559911072254, 18.377622663974762, 5.052491035312414, 0.08597881023888476, 0.0867000367725268, 0.2503543457714841, 1.578242580872029, 0.20471812662435696, 0.1101387821836397, 33.11665557324886, 56.317279636859894, 61.25288039445877, 58.01399879157543, 40.863360688090324, 38.40927757322788, 34.50530245900154, 40.96790827810764, 20.63843484967947, 27.03777026385069, 37.71158941090107, 39.92365971207619, 5.113926138728857, 0.34283891902305186, 0.061696595439570956, 0.10806985257659107, 0.32324975298251957, 86.60813704133034, 112.29106530547142, 42.412168979644775, 4.678177870810032, 8.214959688484669, 10.775702130049467, 39.07578840851784, 7.106466069817543, 18.78068793565035, 74.72035333514214, 81.13863453269005, 47.01803483068943, 75.65309688448906, 60.72149030864239, 60.03489375114441, 80.19977331161499, 72.82809287309647, 2.2018925473093987, 0.542551155667752, 0.19539930479368195, 0.2544422139180824, 0.14330417441669852, 0.16448627138743177, 0.1971387505182065, 0.5530469049699605, 0.4676373739494011, 20.027051456272602, 77.6356329023838, 79.5014999806881, 77.32715785503387, 64.91636261343956, 62.57891424000263, 56.77054591476917, 59.66909117996693, 56.816090270876884, 64.1599828004837, 69.29602280259132, 69.00627315044403, 62.936957627534866, 59.94470939040184, 59.75949212908745, 53.46755415201187, 57.05807648599148, 67.5906591117382, 68.39729502797127, 72.53180757164955, 74.4478015601635, 68.71052742004395, 68.36603790521622, 63.46336618065834, 55.35686977207661, 57.89038002490997, 64.01290029287338, 64.77005526423454, 65.2319584786892, 64.53029572963715, 60.36178261041641, 60.77042028307915, 63.76896098256111, 61.317841708660126, 66.02334201335907, 64.0575022995472, 63.93147826194763, 59.98384349048138, 67.73407101631165, 61.394768580794334, 60.88015079498291, 67.76480376720428, 57.84940682351589, 61.66258580982685, 61.546129658818245, 56.965505853295326, 55.20444855093956, 56.96843549609184, 53.48251394927502, 51.933808252215385, 53.56148511171341, 52.40451939404011, 57.80038945376873, 48.822850584983826, 52.6597099006176, 52.96285383403301, 52.080195397138596, 52.384528666734695, 54.80065941810608, 51.957655772566795, 54.74791444838047, 52.89547584950924, 56.26711092889309, 51.624603644013405, 51.588106602430344, 54.1641403734684, 52.74593487381935, 49.43017199635506, 50.67735627293587, 54.135942086577415, 51.072926446795464, 48.797030970454216, 51.104354560375214, 46.24323360621929, 49.60115522146225, 51.26146852970123, 47.520390674471855, 51.084177643060684, 52.78298668563366, 51.40491463243961, 59.470152854919434, 54.75204102694988, 59.99249942600727, 61.81327052414417, 54.895874708890915, 62.838512510061264, 57.294568195939064, 55.9736792743206, 55.73141187429428, 56.301932260394096, 55.05189813673496, 52.59806580841541, 52.998298332095146, 49.025448113679886, 47.77747727930546, 47.122776210308075, 46.37650765478611, 42.90591448545456, 45.71090877056122, 46.38407684862614, 36.961984634399414, 28.242332227528095, 36.39971360564232, 36.86034768819809, 33.43236543238163, 21.60727646201849, 6.907639838755131, 2.8184628998860717, 3.3402269147336483, 0.7858899200800806, 8.372967559844255, 36.797651052474976, 40.26311069726944, 54.931334406137466, 71.48098155856133, 61.666799783706665, 68.35931226611137, 62.00004570186138, 63.383475467562675, 61.87586076557636, 62.737069353461266, 64.28485929965973, 72.00146242976189, 61.818092465400696, 51.5056624263525, 27.34692357480526, 7.628889586776495, 0.1890768003067933, 0.21815065818373114, 0.3110743156867102, 0.9990707715041935, 0.8415045076981187, 0.2663529716664925, 44.28290359675884, 70.95593333244324, 69.95531782507896, 70.15365958213806, 49.87458094954491, 44.32053677737713, 48.54131229221821, 63.04017148911953, 36.87976084649563, 50.236830711364746, 67.04718187451363, 57.9785542935133, 6.803219066932797, 0.7778063882142305, 0.1446579408366233, 0.3035714995348826, 5.106393992900848], [49.88166756927967, 85.57409852743149, 25.442688055336475, 7.516753803938627, 4.9392723105847836, 10.226419754326344, 21.001262180507183, 0.3557313303463161, 6.641313079744577, 20.826414562761784, 47.09560386836529, 44.29853975772858, 39.92649435997009, 31.874164044857025, 42.100296914577484, 54.44286681711674, 32.38086685538292, 5.975686646997929, 0.9056891198270023, 0.20788647379959002, 0.1695239104446955, 0.07464827096555382, 0.09649109459132887, 0.13199238921515644, 0.18239560100482777, 0.9788733709137887, 34.92220848798752, 83.75640526413918, 72.84504756331444, 50.427740067243576, 40.41446037590504, 39.32285115122795, 35.559761077165604, 34.94651958346367, 37.01683089137077, 44.219826981425285, 53.469735234975815, 47.5741083920002, 47.82600827515125, 43.06703343987465, 41.0899843275547, 28.767509646713734, 29.879187494516373, 43.165413960814476, 50.24172104895115, 58.73939886689186, 66.67487025260925, 56.6639768332243, 53.114902675151825, 46.537056639790535, 41.561561822891235, 45.278537571430206, 51.87073923647404, 54.5958162099123, 55.606972351670265, 55.13263240456581, 56.27618104219437, 55.272521898150444, 55.18469721078873, 56.665116772055626, 55.964977741241455, 54.55617293715477, 56.07051707804203, 50.50419196486473, 57.82881572842598, 58.304082825779915, 61.46281532943249, 54.87194359302521, 53.44906434416771, 55.72366788983345, 52.43891894817352, 50.265359580516815, 48.60040292143822, 49.94811460375786, 46.82608053088188, 48.891896679997444, 47.147497683763504, 49.243583008646965, 50.801909789443016, 48.09931240975857, 46.883563846349716, 42.90532931685448, 46.151137948036194, 46.63880378007889, 47.517081052064896, 49.02797497808933, 48.14913533627987, 48.945800587534904, 51.7033202201128, 51.03922225534916, 48.863333612680435, 48.982176035642624, 46.86204560101032, 44.23929713666439, 43.882325291633606, 43.15653383731842, 45.12071684002876, 47.0173204690218, 44.79451574385166, 47.409007251262665, 41.640248000621796, 42.09607154130936, 41.791609078645706, 44.08953197300434, 42.55303502082825, 46.51907980442047, 46.088342517614365, 52.50591315329075, 50.762163922190666, 56.89121223986149, 49.63822603225708, 53.920782431960106, 48.769786432385445, 48.42866353690624, 51.03636860847473, 49.53487917780876, 45.07008075714111, 37.691948264837265, 39.98487062752247, 39.78859595954418, 35.596850886940956, 37.52352610230446, 33.650564923882484, 37.21346653997898, 30.589411184191704, 21.45815536379814, 12.746585123240948, 13.293732963502407, 26.144706085324287, 27.85260993987322, 20.506610423326492, 6.137214079499245, 1.2142918165773153, 0.6570899533107877, 1.0342074860818684, 0.11966248872340657, 0.5115176271647215, 17.79817085713148, 35.12815743684769, 48.216927498579025, 57.0406050235033, 58.66279877722263, 55.003321543335915, 57.753727957606316, 59.23032872378826, 63.046657741069794, 55.38727194070816, 60.89828722178936, 63.860984444618225, 37.650127708911896, 39.30407635867596, 21.87654711306095, 3.7490714387968183, 0.5340781447011977, 0.07741145003819838, 0.15438636881299317, 3.4990674164146185, 0.013505729584721848, 0.6550981476902962, 27.751548662781715, 43.93816329538822, 53.14333654940128, 50.04177197813988, 25.967857874929905, 21.174688674509525, 23.07894129306078, 15.048953779041767, 9.068479388952255, 8.027726635336876, 4.482383877038956, 1.2463427404873073, 0.17036192875821143, 0.19379838835448027, 0.15960795659339055, 0.20338809408713132, 2.2838878724724054, 63.06289806962013, 86.99980482459068, 2.819194598123431, 4.8960078321397305, 3.002122244797647, 9.255357161164284, 27.795462906360626, 5.66582134924829, 16.093227043747902, 39.344996362924576, 70.61943858861923, 42.80711978673935, 46.585884019732475, 43.41107837855816, 44.90229316055775, 68.84435623884201, 59.75350745022297, 5.671175736933947, 0.25319095293525606, 0.09162046102574095, 0.04324656300013885, 0.03947781093302183, 0.11236400066991337, 0.11913559355889447, 0.1038855423394125, 1.0425705998204648, 42.123228684067726, 87.31660142540932, 79.83904346823692, 64.48499456048012, 51.456204280257225, 49.66423563659191, 45.735516250133514, 44.837704226374626, 48.82062770426273, 56.147269159555435, 62.383574321866035, 63.179301023483276, 60.395828783512115, 55.50688572227955, 54.96636092662811, 39.47865419089794, 42.704084515571594, 53.98860119283199, 59.46822255849838, 63.0350037664175, 70.63507094979286, 62.376654893159866, 60.40135748684406, 52.89201803505421, 47.662541046738625, 52.32640698552132, 55.73484688997269, 57.94152148067951, 60.08608840405941, 57.36675292253494, 59.338626712560654, 58.90376664698124, 58.50904002785683, 60.08013792335987, 58.22247080504894, 57.94509708881378, 59.89533104002476, 57.20740847289562, 58.22587922215462, 59.90838333964348, 64.73415479063988, 56.65485352277756, 57.5581144541502, 59.44836102426052, 54.390555024147034, 52.131808027625084, 54.76545810699463, 51.011555939912796, 50.466722175478935, 52.4921502918005, 48.61322343349457, 52.313415482640266, 52.65154413878918, 51.61549933254719, 50.20056925714016, 45.61068154871464, 46.492637023329735, 47.25856572389603, 50.99964737892151, 50.13924814760685, 48.735341280698776, 49.282591715455055, 55.09753368794918, 50.67855700850487, 49.47131618857384, 50.7834579795599, 48.91219899058342, 48.240801617503166, 47.71831825375557, 44.239677116274834, 45.96260726451874, 49.480952471494675, 47.154565304517746, 49.07246679067612, 44.0323830395937, 43.477377220988274, 44.50267620384693, 47.12827071547508, 45.433960631489754, 48.7640867382288, 48.25958400964737, 55.95717675983906, 53.9966681599617, 57.98637807369232, 54.42716225981712, 56.56026899814606, 52.22129322588444, 51.657832860946655, 56.01178362965584, 52.339440286159515, 49.24830235540867, 43.70835542678833, 47.421930357813835, 43.80071707069874, 43.9950842410326, 42.57872924208641, 41.08053423464298, 42.79091365635395, 39.15865816175938, 25.665893778204918, 21.495847441256046, 19.714316837489605, 26.403375305235386, 30.45803513377905, 26.470732390880585, 8.847935423254967, 1.6263161762617528, 2.985055698081851, 1.8280861806124449, 0.4096821416169405, 3.3540270617231727, 28.311321325600147, 37.841242253780365, 48.018395751714706, 63.425467014312744, 60.529156029224396, 62.700066938996315, 61.31124146282673, 66.12345144152641, 66.02968767285347, 62.73458808660507, 64.15469348430634, 70.13689488172531, 41.737602576613426, 48.63566882908344, 32.94134058058262, 3.8023650040850043, 0.7834825711324811, 0.030568825313821435, 0.26092831743881106, 3.307115016505122, 0.08745385843212716, 1.3288448634557426, 39.88678269088268, 57.595379054546356, 63.56276884675026, 61.17589272558689, 33.64897660911083, 29.599055126309395, 32.50992693006992, 21.8075143173337, 18.184708915650845, 17.71165519952774, 12.866684328764677, 4.652837980538607, 0.062247784808278084, 0.11154660664033145, 0.10196014409302734, 0.2462496457155794, 0.6501842988654971, 75.30162334442139, 114.12885189056396, 63.28941151499748, 20.66957987844944, 5.020755138248205, 30.328376591205597, 54.46897141635418, 21.041076444089413, 30.856865532696247, 60.64682811498642, 86.71138510107994, 55.41387431323528, 54.27303873002529, 51.35762996971607, 58.49900096654892, 77.07185715436935, 78.42220589518547, 7.754164589568973, 0.9641887026373297, 0.2813385659828782, 0.1815171356429346, 0.13402274198597297, 0.2178548974916339, 0.24138388806022704, 0.24860382720362395, 1.972382131498307, 51.57575726509094, 91.01261749863625, 82.9771126806736, 77.49187141656876, 66.29002690315247, 66.7118726670742, 60.969696789979935, 56.280752196908, 55.74055418372154, 63.78374218940735, 67.9711402952671, 68.76050993800163, 69.5456314086914, 62.52873033285141, 63.911476135253906, 53.445424139499664, 52.98547402024269, 63.288917541503906, 66.36521726846695, 70.37078753113747, 76.5746158361435, 65.08093938231468, 64.21527743339539, 59.20860908925533, 52.716216668486595, 58.028373420238495, 64.35379520058632, 63.72163072228432, 63.96534964442253, 62.021632343530655, 62.98099346458912, 59.50218513607979, 63.36015231907368, 63.588824048638344, 63.20763610303402, 59.93923768401146, 62.33770698308945, 59.17825631797314, 63.1245231628418, 62.236396819353104, 67.89202094078064, 58.59003268182278, 58.94277535378933, 61.76128551363945, 58.836730644106865, 54.207123667001724, 56.13629914820194, 55.33601649105549, 52.34759844839573, 54.437847286462784, 52.11953468620777, 56.269774585962296, 55.91884061694145, 52.6659681648016, 53.611604422330856, 48.487955555319786, 50.32933294773102, 51.10851153731346, 53.81038315594196, 55.01766197383404, 52.989961579442024, 54.4400929659605, 56.66450500488281, 54.95736300945282, 54.152885377407074, 54.79726240038872, 51.8511550873518, 51.487092822790146, 48.605160266160965, 46.99647478759289, 51.59363150596619, 52.604559659957886, 49.546149373054504, 51.27012066543102, 47.347849532961845, 48.92927147448063, 45.46511135995388, 49.26120646297932, 50.158942490816116, 53.14387992024422, 52.43106856942177, 58.96620489656925, 56.927002519369125, 62.864453718066216, 57.28413015604019, 59.301616698503494, 55.720198675990105, 54.92469996213913, 59.54329892992973, 56.381868571043015, 53.749715611338615, 47.04486899077892, 52.21962511539459, 48.813605681061745, 48.5672041028738, 48.26154090464115, 47.17098042368889, 49.46697682142258, 47.501475289464, 37.78899885714054, 30.30645176768303, 29.395788833498955, 33.9541382342577, 37.109393924474716, 32.04127907752991, 10.271627828478813, 2.7171988086774945, 4.16849079541862, 2.8038066113367677, 0.8253064518794417, 5.0068151112645864, 33.17266836762428, 50.84929324686527, 59.47684809565544, 63.76128539443016, 60.75805574655533, 61.74719586968422, 62.4048075824976, 68.07143211364746, 65.61335161328316, 66.74331977963448, 66.87584906816483, 75.93595370650291, 51.60094991326332, 49.957416504621506, 45.6794236600399, 9.792733825743198, 1.116331648081541, 0.25480488664470613, 0.3663206199416891, 5.124695710837841, 0.1151321447105147, 1.215600015129894, 54.969244971871376, 68.56811866164207, 73.77915903925896, 70.80118283629417, 43.09847675263882, 36.67159281671047, 59.70254838466644, 36.64249397814274, 32.75290109217167, 31.226745285093784, 17.734358981251717, 5.226039122790098, 0.2818650158587843, 0.25283549388404936, 0.3497464139945805, 0.28459050867240876, 3.313494874164462], [34.54502932727337, 74.82075154781342, 37.23229072988033, 33.9090346544981, 12.087637782096863, 13.55776084586978, 22.090158350765705, 1.7743954178877175, 9.027024563401937, 15.842523146420717, 38.07328820228577, 47.11604677140713, 39.257570654153824, 28.426827527582645, 51.01318225264549, 63.96074429154396, 42.050553783774376, 10.434936415404081, 0.541837268974632, 0.1410485798260197, 0.104184345836984, 0.11895670628291555, 0.08570438629249111, 0.18673542828764766, 0.4117713466985151, 1.9516638619825244, 22.81966220587492, 72.50156119465828, 68.45987766981125, 49.89597000181675, 46.79434843361378, 44.1728463023901, 40.952139124274254, 43.33672396838665, 44.40156742930412, 48.38664159178734, 55.270842388272285, 53.64195339381695, 53.60067620873451, 47.59256400167942, 42.93880932033062, 35.841109380126, 30.713848806917667, 40.43996460735798, 47.238001227378845, 58.13142009079456, 63.17095287144184, 54.3072596937418, 48.81071023643017, 40.90700514614582, 37.891380563378334, 47.45055042207241, 45.37428483366966, 51.3555096834898, 52.823192328214645, 56.3755077123642, 55.371301397681236, 54.29453417658806, 57.58661292493343, 56.82439662516117, 56.72626309096813, 55.87322786450386, 56.121225357055664, 55.833656787872314, 48.68659749627113, 59.628847539424896, 55.13731375336647, 56.16242654621601, 55.79272538423538, 54.746580719947815, 54.19978626072407, 52.803186401724815, 48.15461844205856, 46.563750207424164, 42.64510028064251, 44.17555175721645, 45.47249436378479, 47.04599753022194, 48.99725742638111, 49.72583033144474, 48.87286730110645, 44.79802295565605, 43.25416959822178, 44.339425563812256, 43.28783579170704, 46.08123689889908, 43.944159373641014, 47.283594980835915, 50.73254071176052, 50.83853982388973, 44.97523404657841, 44.98150371015072, 44.5102795958519, 41.559323742985725, 42.97108478844166, 39.603545889258385, 40.93618758022785, 44.771355986595154, 47.541228756308556, 45.79521104693413, 41.8178428709507, 43.20313073694706, 42.94274590909481, 46.935700848698616, 44.840223491191864, 47.09901608526707, 46.02258704602718, 47.93522581458092, 51.15881323814392, 51.45491994917393, 50.33106565475464, 52.25253514945507, 49.29066628217697, 44.98944528400898, 48.425080329179764, 46.95443384349346, 40.09506091475487, 39.93651442229748, 40.073630064725876, 37.82294623553753, 37.36660212278366, 36.791134402155876, 35.700402930378914, 39.90030616521835, 32.67663538455963, 28.12826994806528, 25.985154546797276, 17.632047571241856, 24.087720662355423, 23.170934356749058, 14.555763993412256, 3.336616870947182, 0.34150907944422215, 2.403080826625228, 1.4682668633759022, 0.45977506146300584, 1.8372479639947414, 10.40582712739706, 43.01903061568737, 61.23296946287155, 54.05993476510048, 56.32964037358761, 56.18815876543522, 60.06401538848877, 58.54476571083069, 63.44860777258873, 57.434275299310684, 61.30717188119888, 58.55181433260441, 52.372076734900475, 31.681031808257103, 21.09460797160864, 11.765177585184574, 2.4716550344601274, 0.653538272017613, 0.9799208678305149, 2.4979377491399646, 0.1360743647092022, 3.9592139376327395, 38.03274817764759, 48.834553956985474, 56.59022659063339, 47.67881937325001, 22.393383979797363, 28.645486794412136, 16.42066117376089, 5.846632746979594, 2.190862214192748, 4.139629444107413, 0.16867884172825143, 0.2558722731191665, 0.2409833064302802, 0.38189182814676315, 0.12345431416179053, 0.09780126725672744, 1.1998351360671222, 58.70228245854378, 101.94884866476059, 19.855961836874485, 10.801605340093374, 11.235654149204493, 10.664939973503351, 38.98054651916027, 20.01692119985819, 31.195121482014656, 35.88147461414337, 64.41098213195801, 46.0358939319849, 42.79682233929634, 44.7886298596859, 52.86169946193695, 69.82667192816734, 65.42238146066666, 26.206257082521915, 0.15575451805489138, 0.1285295726847835, 0.10115918121300638, 0.033760231017367914, 0.03803308318310883, 0.1541729865130037, 0.5519032257143408, 1.2490555574186146, 41.05464242398739, 74.60556149482727, 77.35019221901894, 60.41017301380634, 56.3578462600708, 55.73885567486286, 50.49871265888214, 52.07082889974117, 53.09187211096287, 58.118291795253754, 65.81066742539406, 63.210675939917564, 63.66391941905022, 58.300556614995, 58.74563433229923, 47.323546037077904, 44.03497830033302, 52.04674579203129, 58.227737322449684, 63.97804096341133, 69.17394295334816, 62.307384610176086, 56.67416408658028, 49.702894762158394, 45.422394052147865, 52.32526324689388, 53.97714100778103, 57.85729140043259, 58.046338856220245, 59.50565055012703, 60.57476118206978, 55.777567997574806, 58.85712414979935, 59.63822543621063, 60.55405609309673, 57.89792262017727, 58.923802971839905, 59.016423001885414, 53.162168338894844, 62.313832864165306, 58.563251718878746, 59.47543457150459, 58.90245571732521, 58.523479253053665, 55.64543768763542, 54.18375492095947, 50.744574666023254, 49.15135055780411, 46.02040596306324, 48.134202137589455, 47.74575278162956, 48.510309755802155, 53.74553583562374, 50.16993150115013, 51.782644763588905, 46.91238150000572, 45.07258102297783, 45.89477710425854, 46.214423552155495, 46.609233766794205, 47.37149566411972, 48.53657014667988, 52.875063344836235, 50.937311723828316, 46.523757353425026, 47.010621428489685, 45.89505448937416, 43.41959372162819, 45.05062960088253, 42.37030282616615, 44.02676314115524, 47.005905881524086, 49.256103336811066, 44.85407754778862, 43.32940176129341, 43.243438974022865, 44.95830595493317, 48.15257415175438, 48.46614092588425, 49.42814290523529, 52.28624314069748, 51.075791493058205, 54.176930487155914, 53.6485156416893, 55.62340646982193, 54.927268624305725, 53.242458030581474, 48.03261838853359, 51.168396323919296, 48.77547472715378, 45.72393447160721, 44.14239093661308, 45.010245367884636, 42.43188992142677, 45.83527609705925, 43.33383992314339, 44.33382086455822, 43.03974710404873, 41.735672280192375, 33.844012543559074, 37.08958938717842, 26.62238035351038, 28.7205308675766, 31.711055897176266, 21.285146847367287, 4.8062647227197886, 0.5673725518863648, 3.807866396382451, 1.9535708846524358, 0.8160375617444515, 0.8930129406508058, 19.51894272118807, 53.78943108022213, 63.358199223876, 61.91700875759125, 61.556111723184586, 62.29149006307125, 64.94265720248222, 65.14024659991264, 65.33791199326515, 62.65711024403572, 64.75673317909241, 65.8795577287674, 54.5364747941494, 38.95224183797836, 32.74119012057781, 12.903206069022417, 2.601472456008196, 0.15435505018103868, 0.16875494155101478, 2.5962218502536416, 0.3418264217907563, 6.242732992395759, 52.69285172224045, 58.62936817109585, 69.28337708115578, 57.32164554297924, 31.038159504532814, 34.3894162774086, 26.979937367141247, 18.119101636111736, 15.107577983289957, 12.170033510774374, 1.8078528600744903, 0.3925086068920791, 0.469948451500386, 0.5478678422514349, 0.38533785729669034, 0.05080144452222157, 1.5713624563068151, 52.71055117249489, 112.95422852039337, 80.13831540942192, 56.68364077806473, 21.14701095968485, 16.872337237000465, 63.13536778092384, 48.94265055656433, 57.73997649550438, 61.9292327016592, 79.61586624383926, 60.2275700122118, 51.05423524975777, 51.61352723836899, 65.70696339011192, 79.98672634363174, 78.36283788084984, 27.624635472893715, 0.4430196527391672, 0.2586842706659809, 0.13162171613657847, 0.1184628886403516, 0.1962118229130283, 0.2511806529946625, 0.9933760052081198, 1.9071401073597372, 62.13363513350487, 78.8345293700695, 85.02831861376762, 68.61902832984924, 73.88627529144287, 64.77726727724075, 61.87615714967251, 59.88934636116028, 59.24250327050686, 63.68489809334278, 70.09673863649368, 67.3964211344719, 70.12815535068512, 65.03411069512367, 66.40477314591408, 63.36180903017521, 56.12998388707638, 63.8751956820488, 66.74952864646912, 68.420390188694, 69.50864419341087, 65.14607548713684, 58.607447147369385, 55.14531992375851, 52.694006860256195, 60.9396518021822, 56.14130347967148, 61.18466645479202, 62.368876710534096, 64.68025848269463, 63.577933833003044, 59.98610816895962, 63.3026310056448, 63.435373082756996, 62.9414451867342, 62.623843029141426, 64.1105854511261, 62.376172319054604, 54.24147002398968, 65.5254927277565, 60.65939784049988, 61.416172832250595, 61.470916494727135, 59.97507356107235, 61.373561918735504, 57.022350803017616, 52.40507036447525, 51.991990730166435, 49.464119374752045, 51.032941192388535, 49.268760457634926, 51.24393627047539, 57.717162519693375, 54.57900211215019, 56.17801710963249, 50.9943238645792, 49.53372023999691, 47.33054146170616, 48.27175095677376, 51.56082026660442, 50.00042639672756, 52.57030829787254, 56.71140968799591, 55.86482651531696, 49.84598748385906, 50.685191452503204, 50.60549072921276, 44.95291404426098, 47.628369480371475, 44.604491740465164, 45.969234108924866, 50.9144901484251, 51.6925135999918, 47.94150307774544, 45.877317041158676, 48.58413599431515, 49.52304281294346, 52.723557874560356, 52.32091628015041, 53.749312832951546, 54.6621910482645, 54.588041827082634, 57.61755846440792, 56.450865268707275, 57.22297623753548, 59.09403383731842, 57.268904373049736, 49.98576678335667, 55.206287652254105, 53.250912576913834, 52.52475634217262, 49.57333691418171, 50.52352912724018, 46.3653514534235, 50.21471589803696, 47.64819301664829, 48.08955833315849, 49.89194601774216, 48.114135414361954, 40.64373627305031, 42.35732652246952, 34.23268608748913, 35.64071573317051, 34.16321061551571, 26.21027536690235, 9.292862098664045, 3.839759984984994, 5.7088507153093815, 4.042285792529583, 2.080488824285567, 3.934808559715748, 26.934753991663456, 59.090237841010094, 62.369682267308235, 61.579134687781334, 59.03834402561188, 63.46434272825718, 62.762451991438866, 64.20759424567223, 66.81020379066467, 62.22805246710777, 66.5890708565712, 68.90079841017723, 64.42282989621162, 52.283408492803574, 43.04670073091984, 29.682553745806217, 9.690911639481783, 1.3688830775208771, 1.5090341633185744, 6.7356050200760365, 0.6216353026684374, 7.646990865468979, 65.79298317432404, 67.64196395874023, 76.85732826590538, 65.40597394108772, 42.36610025167465, 46.75456456840038, 51.259420439600945, 23.58528882265091, 19.187682196497917, 13.94541984423995, 1.6620101546868682, 0.37289367348421365, 0.4614083800697699, 1.135131495539099, 0.7897080620750785, 0.42385315464343876, 1.7338413815014064], [8.879358787089586, 53.240090757608414, 42.83575505018234, 50.15161268413067, 35.148471146821976, 24.581380672752857, 20.161393247544765, 4.49463726952672, 6.06323204934597, 16.09184581786394, 33.36898483335972, 39.27484072744846, 36.2053844332695, 22.551888674497604, 47.38498114049435, 69.27103534340858, 58.10373097658157, 44.27532680332661, 1.4341816236265004, 0.2474688904476352, 0.20814080780837685, 0.08885996852768585, 0.10693577671190724, 0.14582906471332535, 0.6875288730952889, 4.184053335338831, 28.466151617467403, 73.58498185873032, 62.532746717333794, 51.96723885834217, 50.51956593990326, 49.95215758681297, 52.18548774719238, 52.3212506622076, 51.17143616080284, 49.80855569243431, 57.5137784332037, 57.09058374166489, 52.533393278717995, 45.98147705197334, 45.37667490541935, 39.61631320416927, 33.32012705504894, 38.66447567939758, 47.04232692718506, 61.001159101724625, 65.04937067627907, 56.30246803164482, 47.333364710211754, 38.011381924152374, 38.1560667604208, 45.76617680490017, 49.51426908373833, 53.762072548270226, 50.39735309779644, 54.47629362344742, 53.07364448904991, 53.026603013277054, 53.76782923936844, 56.864644065499306, 54.68567378818989, 54.208863973617554, 56.46093852818012, 52.50336728990078, 50.93655176460743, 54.96088922023773, 53.22228491306305, 58.36948871612549, 55.253237932920456, 54.939557164907455, 53.686798587441444, 50.17066866159439, 48.3497379720211, 46.4824877679348, 43.9117319136858, 46.71741396188736, 45.53054004907608, 45.2767288684845, 46.918430775403976, 44.83936473727226, 44.42531995475292, 44.329846277832985, 42.714742943644524, 45.634973645210266, 44.78962920606136, 44.26646947860718, 46.07939399778843, 46.288101598620415, 49.2752581089735, 49.377655014395714, 45.86014576256275, 44.74004186689854, 41.92759998142719, 41.98297820985317, 40.027861520648, 41.038063913583755, 40.8695163577795, 43.07467482984066, 44.00070793926716, 44.50938664376736, 42.40154094994068, 42.64919266104698, 41.460365653038025, 37.82770358026028, 42.062808126211166, 45.77688083052635, 50.14686293900013, 45.836651623249054, 49.499286487698555, 53.23097884654999, 50.05075849592686, 51.178720369935036, 49.48760971426964, 43.73587355017662, 42.65062898397446, 41.14142596721649, 36.185047924518585, 37.4177435785532, 37.98203989863396, 40.67756965756416, 40.65797410905361, 43.72080355882645, 42.6459514349699, 43.65668959915638, 48.10285001993179, 45.2813608199358, 45.057047456502914, 34.091820046305656, 31.571886464953423, 27.971184477210045, 17.43008080869913, 9.109467789530754, 4.34221082367003, 5.757872359827161, 3.9557449612766504, 3.4065205324441195, 5.990435080602765, 19.98614475131035, 42.907840982079506, 53.001573756337166, 50.91935768723488, 54.55138139426708, 54.626005589962006, 58.28090026974678, 56.16135120391846, 61.412133648991585, 59.245440512895584, 60.45305751264095, 59.11829933524132, 60.43882727622986, 51.031774654984474, 45.66102124750614, 30.099410377442837, 17.185588628053665, 3.153919824399054, 0.34901673439890146, 3.027238422073424, 0.21408264990895987, 9.788319412618876, 45.84079720079899, 50.25071136653423, 60.40402494370937, 39.67558242380619, 20.992610044777393, 20.38155533373356, 16.06956761330366, 4.1899757925421, 1.7038463847711682, 0.9056518936995417, 0.4299654235364869, 0.08412865834543481, 1.4812394860200584, 5.919225001707673, 3.1051278300583363, 0.10253508589812554, 0.7991861191112548, 23.985889926552773, 97.41638347506523, 51.657996252179146, 32.0017383992672, 9.79913268238306, 24.950350373983383, 41.69382892549038, 28.885719403624535, 35.51384054124355, 51.98272682726383, 68.15597757697105, 45.594859197735786, 39.12384442985058, 33.13994452357292, 52.576080188155174, 73.95623713731766, 73.8206148147583, 56.01362653076649, 2.164253666996956, 0.300525042694062, 0.056735052494332194, 0.2261301557882689, 0.08073218981735408, 0.21614960540318862, 1.1056608706712723, 2.585110296495259, 43.83148781955242, 78.04705202579498, 74.65062707662582, 60.98314806818962, 62.25017488002777, 57.53302060067654, 58.48344840109348, 56.875302493572235, 57.546164095401764, 56.83201141655445, 63.25990229845047, 63.50685104727745, 62.17002958059311, 57.12424233555794, 57.481772750616074, 53.10409605503082, 47.639723271131516, 52.03176699578762, 56.20365813374519, 67.31357797980309, 66.76861882209778, 63.804945051670074, 53.846785202622414, 45.71649447083473, 45.45959785580635, 50.864541828632355, 55.12461103498936, 57.77487762272358, 56.18936710059643, 56.61149024963379, 56.1552981287241, 55.56117720901966, 54.80065181851387, 59.401201754808426, 55.9070460498333, 57.65361852943897, 61.034525111317635, 53.670189678668976, 57.09834672510624, 59.58678379654884, 56.13914519548416, 60.02644680440426, 59.22758907079697, 59.72852759063244, 55.44425368309021, 52.324579283595085, 51.31924822926521, 47.144822627305984, 45.22156722843647, 48.129364997148514, 48.91014710068703, 48.59957076609135, 49.075252041220665, 47.5218839943409, 47.84563422203064, 44.31350715458393, 44.277538284659386, 47.3116260766983, 46.93879388272762, 45.71378521621227, 49.5246235281229, 50.75089752674103, 50.604935958981514, 49.767939671874046, 48.72193560004234, 47.35114015638828, 44.18858125805855, 43.72295804321766, 42.70836688578129, 44.170938804745674, 45.18045723438263, 46.053528785705566, 46.09544813632965, 45.19254058599472, 45.17673343420029, 45.33660605549812, 42.52062276005745, 40.43837629258633, 42.46449217200279, 46.4707387983799, 51.277883648872375, 51.72688275575638, 51.826061233878136, 55.89775934815407, 55.365966483950615, 55.45607104897499, 53.8064731657505, 46.943452432751656, 46.77479088306427, 44.971365854144096, 43.25032040476799, 42.19702452421188, 42.95884944498539, 45.48110470175743, 46.94746881723404, 48.954247534275055, 49.25894558429718, 48.01285944879055, 49.36900667846203, 47.464077696204185, 47.360282465815544, 40.23317590355873, 35.518635883927345, 33.38357225060463, 21.474555283784866, 10.129060428589582, 2.91575335431844, 5.505021577700973, 3.1916282884776592, 3.6772788036614656, 6.414021151140332, 24.897992983460426, 50.69305703043938, 60.80049566924572, 57.071303576231, 57.80318610370159, 58.882658779621124, 65.33686324954033, 63.11288058757782, 65.93599990010262, 63.427800089120865, 66.90285041928291, 64.17268171906471, 68.94300654530525, 58.71297508478165, 50.764417201280594, 33.61306093633175, 17.08702191710472, 2.8373217629268765, 0.7582125614862889, 1.1416305718012154, 0.186795289919246, 13.230105377733707, 60.34715339541435, 58.44309076666832, 71.2231881916523, 48.5523696988821, 29.95366159826517, 34.89030160009861, 23.399074114859104, 11.825231462717056, 6.619354533031583, 6.0068839229643345, 1.0099130147136748, 0.077204865810927, 4.694471871480346, 14.372579623013735, 7.213023276999593, 0.8634382369928062, 1.094506687950343, 13.528508115559816, 107.66016259789467, 68.75307753682137, 87.50450134277344, 63.148841857910156, 36.73887960612774, 45.24272829294205, 58.98892767727375, 60.210793912410736, 71.79055854678154, 77.90259897708893, 57.56539486348629, 50.03963649272919, 39.45466227829456, 64.5366869866848, 81.97289496660233, 85.6892703473568, 69.20770794153214, 1.8384237634018064, 0.6101454910822213, 0.3139104478759691, 0.29814126435667276, 0.20077384921023622, 0.433064810349606, 4.790640436112881, 9.661695007234812, 56.668836772441864, 84.06070813536644, 79.68022719025612, 70.60623809695244, 69.91340607404709, 63.56040917336941, 63.272050246596336, 62.03287594020367, 61.03678598999977, 59.85007546842098, 66.93824172019958, 68.63409072160721, 66.11281961202621, 63.65266442298889, 64.80223193764687, 63.67947578430176, 56.45243838429451, 62.37360365688801, 62.386557161808014, 71.58144056797028, 69.37739923596382, 69.20988142490387, 59.60237056016922, 51.64023220539093, 52.84231670200825, 57.76379741728306, 61.82511068880558, 62.28989414870739, 58.75235237181187, 58.73016156256199, 59.83120568096638, 60.55195860564709, 61.55977852642536, 62.5427021831274, 59.8066172003746, 58.563054129481316, 64.80896517634392, 57.933412715792656, 61.00647881627083, 60.99947199225426, 57.24108226597309, 62.56708547472954, 61.80118337273598, 60.386652275919914, 58.198178708553314, 55.472068190574646, 54.38454754650593, 50.294910594820976, 47.896996065974236, 51.3350135833025, 50.89320749044418, 48.87627571821213, 53.94434116780758, 50.16284868121147, 51.62539020180702, 46.94186791777611, 47.02899344265461, 50.2987027913332, 50.74358291924, 48.25411230325699, 52.97207213938236, 52.54772990942001, 53.67684692144394, 53.69400680065155, 51.41658000648022, 51.031535267829895, 47.20333568751812, 44.472718611359596, 44.22983564436436, 47.72521488368511, 47.45342306792736, 48.18997174501419, 49.21781279146671, 47.902638763189316, 47.068176940083504, 49.453194960951805, 45.951698049902916, 43.18748697638512, 44.88843150436878, 50.23718789219856, 54.61130037903786, 54.9891597032547, 56.8107895553112, 58.10252644121647, 57.56510987877846, 57.004864141345024, 56.80846408009529, 48.11958432197571, 54.55968774855137, 52.180130034685135, 49.69649210572243, 47.55624555051327, 50.58904521167278, 50.11071927845478, 50.618664622306824, 57.12176486849785, 54.328120574355125, 52.87233889102936, 58.09862405061722, 57.20904998481274, 55.768057107925415, 46.760758236050606, 40.694524347782135, 37.29439079761505, 26.08474340289831, 16.508388966321945, 8.858938682824373, 6.5097080916166306, 6.764608388766646, 6.557224066928029, 17.28935156017542, 38.18011187016964, 58.80815617740154, 56.69569373130798, 58.625553175807, 56.4118679612875, 59.828040450811386, 65.18246233463287, 63.66966091096401, 66.56247988343239, 66.16561397910118, 67.76511535048485, 63.21101412177086, 67.5752167403698, 67.10731744766235, 64.63773116469383, 50.53463593125343, 32.76991277933121, 5.456227920949459, 2.3010914493352175, 5.71154429577291, 0.36107031104620546, 17.01463770121336, 72.63763949275017, 64.94806811213493, 82.82491564750671, 55.54914325475693, 42.26912945508957, 35.23763336241245, 48.950611129403114, 16.338633075356483, 5.726165436208248, 5.9667139034718275, 1.6256865975447, 0.14283534488640726, 3.4188784193247557, 19.772033840417862, 14.61304971948266, 1.7773554590530694, 0.9735909418668598], [1.7846237565390766, 40.6657674908638, 44.91737835109234, 29.655786082148552, 48.461174592375755, 50.34089952707291, 28.21614783257246, 7.228896925225854, 4.727106895297766, 8.954992778599262, 26.62812564522028, 27.035005912184715, 33.35600093007088, 27.28478740900755, 45.33236928284168, 70.66448897123337, 64.90918099880219, 45.1910624653101, 4.254136299714446, 0.34829910728149116, 0.05140458793903235, 0.08770833344897255, 0.02180169936764287, 0.057540193665772676, 2.8520037000998855, 5.999859049916267, 50.41167072951794, 72.43939653038979, 62.688371166586876, 56.773486956954, 55.8864663541317, 56.80427670478821, 53.97706501185894, 53.91202010214329, 52.129220366477966, 51.26808777451515, 56.040456891059875, 59.19202297925949, 54.52803924679756, 49.79236476123333, 47.00187809765339, 42.291069477796555, 37.545827105641365, 38.93804579973221, 47.33948238193989, 56.40502072870731, 60.98752163350582, 52.13656537234783, 42.918096631765366, 39.84307363629341, 39.32427227497101, 48.05154137313366, 48.831837102770805, 51.528237015008926, 49.99832510948181, 51.70105554163456, 49.56092678010464, 48.02349127829075, 51.490497440099716, 56.53982229530811, 54.200280234217644, 57.219845205545425, 55.397934168577194, 50.57063139975071, 48.37432645261288, 52.651893720030785, 51.03048652410507, 59.333534985780716, 55.17813116312027, 56.18949629366398, 54.50616382062435, 49.06557776033878, 44.32449996471405, 44.37503345310688, 43.57729285955429, 44.27602976560593, 44.985675886273384, 46.39151304960251, 45.852207988500595, 45.47437146306038, 40.711931213736534, 42.25932978093624, 43.314183577895164, 42.9505430907011, 40.81991381943226, 42.47124440968037, 43.941408321261406, 43.766328915953636, 43.93201142549515, 42.848826348781586, 45.16264759004116, 43.135851547122, 42.586906403303146, 40.986192896962166, 40.395765379071236, 42.3136592656374, 40.863121300935745, 41.66239321231842, 41.61879815161228, 40.54882116615772, 44.08293552696705, 43.94345261156559, 41.57777935266495, 41.392964869737625, 40.243374556303024, 41.0090334713459, 46.58503286540508, 51.326350048184395, 48.911629021167755, 49.37374122440815, 53.00476558506489, 48.84670950472355, 49.5842195302248, 44.36526037752628, 42.40168534219265, 37.617042884230614, 38.774369582533836, 37.526919320225716, 39.792809933423996, 40.78422233462334, 43.134286031126976, 45.31716249883175, 48.16978342831135, 50.756718814373016, 50.79017981886864, 39.09522816538811, 44.4667187333107, 48.88261757791042, 42.912754118442535, 31.281276158988476, 22.26481407880783, 16.804016903042793, 12.927499115467072, 12.501926701515913, 9.444156680256128, 14.38904033973813, 16.87730737030506, 40.513475462794304, 52.596986666321754, 53.065467327833176, 53.30116108059883, 52.21220411360264, 50.57205252349377, 53.384190425276756, 56.10572598874569, 59.02004040777683, 59.62591029703617, 55.31962037086487, 56.750293001532555, 63.73805724084377, 64.03772056102753, 63.26385788619518, 55.02364285290241, 35.128970593214035, 14.797590617090464, 1.8278040457516909, 0.6899840163532645, 0.25000031164381653, 17.314179427921772, 50.96712492406368, 52.39360257983208, 53.504643961787224, 36.15481294691563, 21.009454540908337, 18.41567002236843, 13.137213662266731, 3.6092954641208053, 1.7647530790418386, 2.7683010790497065, 0.8768234343733639, 3.0829581571742892, 8.529061283916235, 9.751962963491678, 13.632101956754923, 5.040048127993941, 0.21951255854219198, 5.557267824187875, 63.94767299294472, 69.24480155110359, 43.553810119628906, 44.16922129690647, 16.919912584125996, 52.95652337372303, 31.310335099697113, 27.30907190591097, 39.06553275883198, 62.19674974679947, 35.27356043457985, 30.938183069229126, 36.31084017455578, 49.848168566823006, 77.37191945314407, 71.43063426017761, 62.40019463002682, 7.46267463080585, 0.37159633997362107, 0.09664998098742217, 0.1502076321048662, 0.016232571251748595, 0.3759179846383631, 4.061590181663632, 8.566087447106838, 61.487320214509964, 77.76315405964851, 74.65183541178703, 63.23827005922794, 66.45120665431023, 60.105524361133575, 60.69855093955994, 59.1509585827589, 58.151805996894836, 56.32089324295521, 67.17822164297104, 66.44187435507774, 63.82701426744461, 57.48157896101475, 61.067556738853455, 52.462546080350876, 50.23937277495861, 48.06979939341545, 54.114769622683525, 63.5635744035244, 61.60432353615761, 59.51016090810299, 47.212816178798676, 46.10782407224178, 47.716574147343636, 52.96446494758129, 55.38059949874878, 55.71386061608791, 56.22641511261463, 52.35044829547405, 54.26348224282265, 50.197658613324165, 54.077672213315964, 56.25325307250023, 59.593551233410835, 57.514291405677795, 57.60278485715389, 53.55116106569767, 54.107831194996834, 57.1068012714386, 54.64334025979042, 59.52856332063675, 60.14158442616463, 57.76974409818649, 57.879208624362946, 50.902383998036385, 46.544078662991524, 47.075244560837746, 46.5953379124403, 48.06856065988541, 48.94581958651543, 47.758953273296356, 48.27046662569046, 48.88238199055195, 45.179560482501984, 45.121370404958725, 48.50698873400688, 46.644066497683525, 45.37544757127762, 44.52237814664841, 46.821976751089096, 46.34833216667175, 45.256627947092056, 45.45581325888634, 48.60523246228695, 45.803870782256126, 44.130763560533524, 41.64319284260273, 42.18894235789776, 46.1470265686512, 44.79117572307587, 43.66623468697071, 44.891323149204254, 41.68919317424297, 44.28904786705971, 46.92449904978275, 44.09153826534748, 43.48786845803261, 42.794922441244125, 43.56826454401016, 43.550147116184235, 52.720324248075485, 53.21587845683098, 51.58988490700722, 55.22735372185707, 51.59093365073204, 51.550864800810814, 47.269436940550804, 45.377632454037666, 43.55203561484814, 42.96287342905998, 43.818712905049324, 45.72432205080986, 44.955414310097694, 49.63788025081158, 50.006019696593285, 50.0088657438755, 52.03823804855347, 51.75050228834152, 40.01694470643997, 45.37732847034931, 47.26788282394409, 44.8526868224144, 33.009227737784386, 24.556568004190922, 19.269807189702988, 13.5751211643219, 13.687413688749075, 10.341965854167938, 14.310208819806576, 17.564612589776516, 44.71671871840954, 58.79647560417652, 56.488107070326805, 59.982665553689, 53.941723108291626, 56.80064409971237, 58.111064583063126, 61.90165378153324, 64.19354259967804, 64.21099126338959, 61.762421652674675, 64.45849478244781, 71.7831489443779, 73.09125915169716, 72.31113821268082, 68.23375180363655, 42.5368706882, 19.713923558592796, 2.7758465241640806, 0.32756320433691144, 0.27353479410521686, 26.67618166655302, 61.31058029830456, 63.65501269698143, 60.066188871860504, 48.1886076182127, 27.829058803617954, 30.4246786236763, 18.274733684957027, 7.601164849475026, 2.091715084388852, 3.6344826500862837, 2.70726899150759, 4.684709245339036, 18.855916298925877, 20.174189060926437, 23.230669051408768, 7.774181915447116, 0.8611783676315099, 3.139956286177039, 67.68237099051476, 81.801106184721, 60.55530622601509, 78.0783623456955, 65.35894766449928, 59.86784711480141, 45.90632848441601, 45.3690867125988, 56.20960481464863, 72.05845177173615, 41.56185440719128, 50.85944250226021, 43.73859040439129, 62.47456043958664, 85.31403288245201, 82.89765134453773, 78.54122310876846, 8.69295883923769, 0.7496880751568824, 0.15363181242719293, 0.2133874356513843, 0.06760773118003272, 0.4466964304447174, 7.628667773678899, 27.46973678469658, 73.56388539075851, 83.42498704791069, 78.89012798666954, 71.534893065691, 67.7260610461235, 63.266954720020294, 60.620704516768456, 63.14520925283432, 58.61930251121521, 59.55686040222645, 65.60047030448914, 71.2794479727745, 65.72355329990387, 67.64628812670708, 68.06308016180992, 64.03165608644485, 60.105429366230965, 58.15827324986458, 62.914747819304466, 68.16489189863205, 66.30068153142929, 61.38193666934967, 53.257577419281006, 50.69586507976055, 52.84123755991459, 60.22840976715088, 57.6148834079504, 58.43215115368366, 58.38624581694603, 57.018045634031296, 57.543618232011795, 55.36266826093197, 55.84113858640194, 60.272286012768745, 62.7234660834074, 59.863910526037216, 60.60034140944481, 56.29144862294197, 57.28496991097927, 61.911651045084, 57.27287515997887, 65.23194327950478, 62.32147045433521, 62.482471615076065, 61.17577113211155, 53.516563922166824, 48.64243246614933, 52.00137622654438, 48.99428218603134, 51.55944474041462, 51.99558913707733, 52.301905900239944, 49.287178069353104, 52.27167472243309, 46.07641115784645, 48.90831559896469, 51.945291236042976, 49.688763320446014, 48.259321823716164, 49.02550131082535, 49.85507279634476, 50.1795943826437, 49.71314661204815, 52.8300965577364, 52.84878395497799, 50.43454930186272, 47.406795769929886, 44.87106263637543, 46.42554022371769, 47.84241959452629, 47.00996786355972, 46.331457272171974, 46.955182403326035, 45.530551448464394, 48.50673034787178, 49.96923387050629, 47.085363417863846, 47.40607000887394, 46.79594814777374, 45.93511573970318, 46.816402450203896, 53.72005060315132, 55.983079969882965, 52.604745849967, 59.89256098866463, 56.28728784620762, 55.7242226600647, 52.20077432692051, 48.81732188165188, 47.72861570119858, 48.68440501391888, 47.55575157701969, 49.30771976709366, 50.41871555149555, 56.39269798994064, 53.46264861524105, 57.222246676683426, 56.201705038547516, 61.47861868143082, 47.28601545095444, 51.930171847343445, 54.05653014779091, 49.743396788835526, 35.142072290182114, 25.603637918829918, 21.84684030711651, 15.891524367034435, 15.378892924636602, 15.655310992151499, 19.845415502786636, 29.106985330581665, 55.45471832156181, 61.782666966319084, 58.514200150966644, 58.91108885407448, 53.45898561179638, 58.321052715182304, 57.067583575844765, 63.07575657963753, 65.64105212688446, 64.74766686558723, 62.76581101119518, 65.15532419085503, 71.60768195986748, 71.8481482565403, 68.30295369029045, 67.16428399085999, 51.07787758111954, 24.01414331048727, 5.447402419522405, 2.8283388074487448, 0.4780071065761149, 33.00804600119591, 72.97727286815643, 69.38179939985275, 69.86310437321663, 57.90037728846073, 35.570248514413834, 36.51174299418926, 44.3631324917078, 17.846848145127296, 5.324826221913099, 4.521871358156204, 3.0138866510242224, 7.00544991530478, 27.21365712583065, 36.19199775159359, 44.89074558019638, 16.752860248088837, 1.4698555343784392], [0.31566547870170325, 14.57826828584075, 61.38621523976326, 27.32849646359682, 12.692701164633036, 20.365833677351475, 29.243751391768456, 11.761978156864643, 4.396748822182417, 7.212029630318284, 17.5262688472867, 22.880018167197704, 40.23697569966316, 24.383409395813942, 46.053946763277054, 69.51229199767113, 67.67170876264572, 53.22593651711941, 7.112124916166067, 0.5237679916899651, 0.10873959632590413, 0.10446256215800531, 0.08770251501118764, 0.46011633065063506, 2.8823177609592676, 8.982141371816397, 59.90437835454941, 64.03063014149666, 57.65755891799927, 64.50841650366783, 60.20140841603279, 61.14187695086002, 53.86250115931034, 54.02611277997494, 54.839303344488144, 51.44673138856888, 56.0700649023056, 62.39428594708443, 58.17541033029556, 51.02835103869438, 51.01139634847641, 47.14923419058323, 42.03839063644409, 44.143249690532684, 46.541130021214485, 53.69206130504608, 56.11088611185551, 50.93182861804962, 44.60854612290859, 44.237697422504425, 44.84699472784996, 48.33509735763073, 49.21133793890476, 52.254169061779976, 50.027697533369064, 48.24636451900005, 44.91508707404137, 49.15711484849453, 47.845691218972206, 53.30779552459717, 54.456568881869316, 54.79826934635639, 55.16739673912525, 53.584059700369835, 50.2707476913929, 49.41978335380554, 47.89397522807121, 52.15475879609585, 55.81797502934933, 54.0644147247076, 54.58517678081989, 46.296187564730644, 47.323204055428505, 42.46494434773922, 42.123878449201584, 44.95171330869198, 45.26862770318985, 44.49799865484238, 45.39197288453579, 42.74870552122593, 43.437923938035965, 41.92492492496967, 42.75735005736351, 41.86842195689678, 42.232913598418236, 44.416215643286705, 43.69775019586086, 45.769817009568214, 41.07862673699856, 40.39552599191666, 44.76278364658356, 42.29936443269253, 41.13281562924385, 40.56421793997288, 41.23786859214306, 42.993241399526596, 42.29953162372112, 41.98615483939648, 40.93277916312218, 41.100798547267914, 40.57416580617428, 42.978585585951805, 43.06651286780834, 40.64901798963547, 39.391285479068756, 41.964921578764915, 42.86678038537502, 47.76936091482639, 53.26890841126442, 49.31948773562908, 48.283701315522194, 43.5827911645174, 46.01921662688255, 41.079652681946754, 39.783641025424004, 39.1242890059948, 40.62999241054058, 42.778191938996315, 42.56299428641796, 44.61716406047344, 45.89447312057018, 47.88816154003143, 50.7531052082777, 53.35690788924694, 45.44725611805916, 35.850221291184425, 49.04424570500851, 42.04616501927376, 25.97730416804552, 29.102174788713455, 24.560789577662945, 19.5281021296978, 15.322331059724092, 17.20373075455427, 17.099688537418842, 28.09820406138897, 37.3028377443552, 48.16224463284016, 59.26861546933651, 54.25132289528847, 52.128969579935074, 49.18731942772865, 49.25694689154625, 50.83518460392952, 52.79111444950104, 55.59159077703953, 56.16281792521477, 58.39071437716484, 60.35159915685654, 61.12152524292469, 66.02600187063217, 69.11924108862877, 71.01957991719246, 48.56449484825134, 27.091763466596603, 9.385587573051453, 0.12309908517636359, 0.1789164572255686, 28.904327005147934, 52.659979686141014, 52.147201001644135, 38.662366792559624, 35.73729135096073, 20.093297101557255, 35.110070407390594, 19.055732376873493, 11.273295879364014, 11.62018496543169, 5.049446923658252, 0.6119773490354419, 1.09021398704499, 6.223712163046002, 7.296844404190779, 11.33663373067975, 1.0862354817800224, 0.10905236704275012, 1.2678713165223598, 34.33002166450024, 54.87539000809193, 59.5731957256794, 56.827949434518814, 37.770797833800316, 45.61418116092682, 22.308380641043186, 18.207260705530643, 24.188496954739094, 44.30729068815708, 29.339397959411144, 34.75200802087784, 39.013923928141594, 50.19802339375019, 78.9485764503479, 71.82504549622536, 62.54275918006897, 13.338325470685959, 0.5172871425747871, 0.07500332183553837, 0.05386981327319518, 0.06330040996544994, 0.5081509484443814, 3.6920752096921206, 21.0446672514081, 68.13033655285835, 75.29747396707535, 69.95399549603462, 69.03765186667442, 67.47530490159988, 66.44119799137115, 62.0042634755373, 59.81571011245251, 59.06425483524799, 55.406673699617386, 61.18469685316086, 68.4841887652874, 67.2298912703991, 57.869063168764114, 58.776842057704926, 58.576551005244255, 52.032568752765656, 53.54987673461437, 53.44759002327919, 61.18721231818199, 57.7875005453825, 52.9498927295208, 48.167397156357765, 46.568853333592415, 50.15700079500675, 53.102408945560455, 55.48694059252739, 52.26803831756115, 54.54443916678429, 49.048900455236435, 49.79033567011356, 49.98978316783905, 51.71750105917454, 55.67479871213436, 57.196700647473335, 58.568335846066475, 59.87918570637703, 57.875435426831245, 56.401908695697784, 51.09383672475815, 51.547745168209076, 56.13175459206104, 57.871989011764526, 57.48876817524433, 57.44830034673214, 46.84277303516865, 51.696814969182014, 44.44679640233517, 47.93535500764847, 47.8267378360033, 49.263459742069244, 47.279479801654816, 49.87367659807205, 45.355369448661804, 46.83177262544632, 44.13962088525295, 46.08227424323559, 43.53212848305702, 44.67213951051235, 47.29738064110279, 47.5633055716753, 46.58606640994549, 43.95856440067291, 42.358941435813904, 47.90796987712383, 43.987868428230286, 44.36003565788269, 44.31289538741112, 44.66885648667812, 46.675589606165886, 43.02088871598244, 43.944512754678726, 41.712656915187836, 42.377370446920395, 40.51781103014946, 45.38557402789593, 44.8665826767683, 44.20537255704403, 42.249480709433556, 42.88652032613754, 46.3622660189867, 52.763816714286804, 56.44828900694847, 53.18329520523548, 50.73079660534859, 46.59550130367279, 47.04625591635704, 46.95322170853615, 44.07639607787132, 44.26981709897518, 46.81518271565437, 48.060824275016785, 47.36095502972603, 48.28334413468838, 48.14989149570465, 50.09387098252773, 53.580218106508255, 53.75412717461586, 52.36114092171192, 45.2305993437767, 54.77120719850063, 47.78149366378784, 30.87139405310154, 33.06496314704418, 29.05425366014242, 24.24641914665699, 17.566843070089817, 19.734641946852207, 18.828115090727806, 32.58439153432846, 41.1151959747076, 54.34749573469162, 65.92416733503342, 59.87901471555233, 59.13182660937309, 50.166127905249596, 54.060386940836906, 54.18775610625744, 59.928206875920296, 58.983246982097626, 65.81918656826019, 65.17962768673897, 67.84219801425934, 66.42441809177399, 73.58635738492012, 76.41317009925842, 83.2008446753025, 61.71127639710903, 37.56090849637985, 11.427685394883156, 0.16149218048667535, 0.2860742399934679, 40.293505266308784, 62.27898873388767, 61.81699812412262, 47.62906864285469, 50.262296944856644, 23.495691530406475, 37.24839426577091, 32.408525571227074, 16.72356192022562, 14.874868020415306, 6.240075035020709, 1.9612356671132147, 6.857264041900635, 9.123584982007742, 13.869176935404539, 22.16029118746519, 7.28482517413795, 0.2269632907700725, 1.0374430124647915, 22.453662045300007, 90.33039450645447, 65.50916120409966, 51.059079989790916, 51.75318494439125, 51.93139158189297, 52.00142182409763, 44.75494086742401, 44.92606848478317, 54.93606135249138, 43.82567413151264, 60.423818081617355, 43.089041858911514, 61.189864575862885, 83.89695212244987, 81.69851928949356, 77.31522649526596, 14.3333182297647, 1.1161370272748172, 0.1317207483225502, 0.19273328769486398, 0.13926800427725539, 1.347107752226293, 4.653815953060985, 46.81971587240696, 76.26650556921959, 79.67976361513138, 72.25311532616615, 70.45919358730316, 67.235818952322, 65.2570067346096, 61.10841974616051, 60.69698162376881, 62.727763652801514, 58.00912745296955, 63.552475199103355, 72.45233103632927, 72.6907454431057, 60.834861025214195, 66.82039484381676, 65.08105337619781, 61.03710517287254, 61.439986154437065, 59.146775007247925, 63.45443286001682, 63.273068591952324, 55.35657338798046, 51.3493350148201, 52.0916023850441, 55.05803860723972, 56.733999475836754, 58.940309286117554, 57.08496004343033, 57.74810045957565, 53.149264231324196, 53.74505706131458, 54.71539959311485, 55.16244180500507, 57.363838478922844, 59.80054512619972, 60.71265198290348, 62.63863943517208, 59.941361770033836, 57.410515174269676, 56.744616106152534, 53.536965027451515, 58.85437689721584, 61.11122399568558, 58.63415211439133, 60.77777288854122, 49.33377116918564, 55.1568903028965, 46.89641855657101, 49.194155260920525, 50.12857832014561, 52.28981114923954, 49.285069182515144, 53.252698481082916, 48.119762912392616, 49.421132281422615, 47.709996700286865, 49.06639091670513, 47.126815393567085, 49.20708976686001, 51.901608780026436, 50.878426283597946, 51.18387669324875, 46.3985350728035, 46.32521040737629, 52.77097173035145, 47.155500054359436, 48.852519392967224, 47.11195059120655, 46.63179315626621, 49.74855691194534, 47.805952951312065, 47.261385172605515, 44.625056236982346, 44.62410248816013, 45.55612787604332, 49.12040501832962, 49.36810992658138, 47.636789828538895, 46.64062388241291, 45.35277418792248, 49.31291788816452, 52.961216121912, 57.98776499927044, 56.208822056651115, 55.1076677441597, 51.669057458639145, 53.705793768167496, 50.08378632366657, 50.224215388298035, 47.832277938723564, 49.436054080724716, 50.84649659693241, 49.09734785556793, 52.962975427508354, 51.809706911444664, 55.747443214058876, 60.09292423725128, 57.574822157621384, 57.66759417951107, 53.882320895791054, 56.90506249666214, 52.258611023426056, 37.81603440642357, 35.436244904994965, 28.29856351017952, 22.436165884137154, 16.336689479649067, 21.30292609333992, 26.24900858849287, 33.83587338030338, 43.27765613794327, 54.79907110333443, 65.13636320829391, 59.099851325154305, 59.55666281282902, 51.079557090997696, 53.362588584423065, 56.02740079164505, 59.795943573117256, 61.27693310379982, 65.33867955207825, 64.57944229245186, 67.75965124368668, 67.9330663383007, 72.2875414788723, 69.24080416560173, 72.63408288359642, 60.179441794753075, 42.36867271363735, 12.544983141124249, 0.1964941358892247, 0.5097151582594961, 46.73420146107674, 72.7940770983696, 66.9776152074337, 60.12848272919655, 54.81436148285866, 37.878791838884354, 52.48266980051994, 51.18168421089649, 27.27908581495285, 22.626159489154816, 10.536895394325256, 3.3278341172263026, 11.440062280744314, 30.30339863151312, 23.168327696621418, 53.46161887049675, 15.356553923338652, 0.33446229819674045], [0.06464609439717606, 1.4014904340729117, 32.4563118070364, 32.44015507400036, 5.166966067627072, 2.610473223030567, 13.507121913135052, 14.562274944037199, 2.496659830212593, 4.568798365071416, 12.856292836368084, 22.712914533913136, 34.13017138838768, 27.9965291172266, 39.29705433547497, 71.31292417645454, 68.28479066491127, 51.58327706158161, 17.444934211671352, 0.49804099719040096, 0.16236236348049715, 0.14537395007209852, 0.07012008660240099, 2.7686729840934277, 4.969281675294042, 12.89468502625823, 63.552209213376045, 58.556503280997276, 62.96529270708561, 66.08098492026329, 61.499198377132416, 58.85171324014664, 59.65057097375393, 56.49172827601433, 52.90337182581425, 50.64511500298977, 53.63574832677841, 61.083044707775116, 59.333542585372925, 55.17728380858898, 50.713746920228004, 54.5394766330719, 51.51627145707607, 48.921242505311966, 50.802156776189804, 51.63685418665409, 52.398249730467796, 52.359943985939026, 52.29442410171032, 46.45185001194477, 50.5840028822422, 47.70687706768513, 49.3098970502615, 48.0753280967474, 47.879057228565216, 47.83770024776459, 44.25924226641655, 46.36333756148815, 48.692490980029106, 50.31704440712929, 53.634798377752304, 56.84158310294151, 58.58241409063339, 55.27583912014961, 49.89809408783913, 43.138135224580765, 47.52110883593559, 48.721893802285194, 50.16176953911781, 58.714080825448036, 53.95481340587139, 47.930772453546524, 44.981568306684494, 42.265284061431885, 45.72695150971413, 45.56364007294178, 45.337867587804794, 44.222091659903526, 45.255727395415306, 44.990684017539024, 43.59965465962887, 41.8939033895731, 42.81664967536926, 44.345873817801476, 41.30086921155453, 43.190545812249184, 41.20744742453098, 44.230914786458015, 39.877849370241165, 39.635901153087616, 42.17524029314518, 41.37884862720966, 40.44549711048603, 43.47752921283245, 46.049934178590775, 43.253386840224266, 39.4095017015934, 40.098309740424156, 42.06816963851452, 42.00576938688755, 41.84469982981682, 42.15141177177429, 41.50632418692112, 40.272085815668106, 38.1572674959898, 36.684192940592766, 41.698704063892365, 49.54278275370598, 49.32168781757355, 51.22426852583885, 46.386425122618675, 41.66191443800926, 37.22959287464619, 37.906963527202606, 40.2413834631443, 43.04891601204872, 47.35528573393822, 48.96290726959705, 48.731575682759285, 47.04927295446396, 48.48384037613869, 48.87887857854366, 54.14429023861885, 53.89492481946945, 55.46072959899902, 53.60237471759319, 58.99142414331436, 52.66252554953098, 33.81459832191467, 24.67740722000599, 19.861401244997978, 19.339599944651127, 25.697052106261253, 27.96178188174963, 26.00610852241516, 38.63096907734871, 52.09424704313278, 56.70532241463661, 56.17002993822098, 58.56935419142246, 53.978843316435814, 50.938812643289566, 48.96297946572304, 52.25455664098263, 51.49960175156593, 53.85261408984661, 55.3616689145565, 55.50217017531395, 59.36090871691704, 62.25059285759926, 64.56242680549622, 68.78993555903435, 63.40787775814533, 55.41872285306454, 30.270243510603905, 13.516805693507195, 0.06691201968351379, 0.6276465801056474, 35.31592816114426, 54.80695188045502, 47.34102509915829, 31.80144354701042, 37.32632428407669, 34.76890571415424, 37.462501376867294, 19.020513966679573, 22.126284912228584, 26.86517972499132, 12.636910658329725, 4.893156085163355, 5.1073111686855555, 2.605224042199552, 6.772201806306839, 11.30908140912652, 0.5128125264309347, 0.13736099645029753, 0.17168244696222246, 7.737624552100897, 50.24872787296772, 28.62835541367531, 34.867932200431824, 23.925942443311214, 31.946128383278847, 31.024691127240658, 16.295560486614704, 16.75860743969679, 28.527345433831215, 23.005244247615337, 36.437646970152855, 40.082677379250526, 42.52215027809143, 81.20617210865021, 71.60800114274025, 64.49196338653564, 28.506079874932766, 0.3412467450834811, 0.08559224035707302, 0.20391905622091144, 0.11982081108726561, 3.363169371150434, 5.205843206495047, 27.471771575510502, 77.81847149133682, 64.0810914337635, 71.73243686556816, 70.40362536907196, 69.97465118765831, 64.23303008079529, 65.92577084898949, 60.989033952355385, 60.08022151887417, 54.51864615082741, 59.68797616660595, 66.3252966105938, 68.97791147232056, 60.624587908387184, 57.93800286948681, 59.56088438630104, 58.231350928545, 55.40353886783123, 56.15858115255833, 58.79752814769745, 54.943330362439156, 56.54172219336033, 53.27819511294365, 50.94252124428749, 52.68927991390228, 53.407076597213745, 50.215023681521416, 49.5920243114233, 51.59726031124592, 50.50020597875118, 45.71382321417332, 47.95796379446983, 52.51977480947971, 53.586324378848076, 57.92514815926552, 59.18983429670334, 62.296414598822594, 57.02635198831558, 51.88843868672848, 47.77422845363617, 51.323367208242416, 50.057788118720055, 54.33565177023411, 58.97253155708313, 57.38041698932648, 49.20876927673817, 47.84594960510731, 44.33888219296932, 48.11200372874737, 48.29011157155037, 47.58192837238312, 46.76274172961712, 46.84404216706753, 47.66757197678089, 48.805819898843765, 46.4412447810173, 46.362269818782806, 47.92119316756725, 46.02091133594513, 45.88393248617649, 45.17809376120567, 46.19420863687992, 43.002843484282494, 43.56732219457626, 45.36160111427307, 42.44327411055565, 44.574803933501244, 45.721555799245834, 48.36533613502979, 44.82074573636055, 43.714841678738594, 45.24496257305145, 47.19557270407677, 44.01197053492069, 44.60287682712078, 44.373570531606674, 43.55429649353027, 44.514075592160225, 42.72947855293751, 41.134381145238876, 43.44739682972431, 53.808198273181915, 54.083683490753174, 53.90054851770401, 48.57424892485142, 44.18652556836605, 42.7961003780365, 40.93972139060497, 45.828968435525894, 47.51626409590244, 52.53424823284149, 50.93619838356972, 52.69215635955334, 48.413247764110565, 50.11657476425171, 49.58313278853893, 54.11115221679211, 56.283374056220055, 58.39722342789173, 58.04104574024677, 61.54080994427204, 58.64465855062008, 39.29186761379242, 29.213846996426582, 22.004786431789398, 20.929033756256104, 25.757216177880764, 30.31375117599964, 31.879137977957726, 43.38643290102482, 58.608682081103325, 63.389015570282936, 65.20313322544098, 62.462963461875916, 59.47778284549713, 56.322709545493126, 53.97666983306408, 57.23870739340782, 56.084249541163445, 59.289518147706985, 60.221159756183624, 61.70285224914551, 65.46744704246521, 69.07992839813232, 73.226607888937, 74.57861334085464, 69.61573004722595, 64.20315608382225, 39.76891301572323, 19.474169723689556, 0.26117150438949466, 0.7973825221415609, 45.337738394737244, 67.38063678145409, 53.68019074201584, 41.85333676636219, 46.66184954345226, 39.77553226053715, 54.68505822122097, 47.466083988547325, 26.709104999899864, 23.87656409293413, 10.032048784196377, 3.1584724551066756, 5.793178640305996, 6.707651345059276, 12.744210250675678, 24.337688349187374, 1.6980079980567098, 0.23240884387632832, 0.3482969105243683, 2.919076276011765, 46.707352101802826, 67.27245658636093, 34.44991283118725, 21.757841482758522, 22.55802344530821, 49.40301105380058, 44.260568395256996, 38.850034922361374, 37.18135446310043, 42.02839717268944, 55.61584487557411, 46.717619150877, 51.73903830349445, 86.20628580451012, 80.5688627064228, 74.53100949525833, 31.381020806729794, 0.34320073085837066, 0.18679429544135928, 0.2856418944429606, 0.3033661324298009, 6.944682626053691, 4.114158460870385, 50.93385010957718, 83.36121127009392, 71.13053396344185, 73.38284030556679, 70.09739220142365, 69.94735345244408, 62.42934666574001, 66.45719513297081, 62.72021725773811, 60.87566323578358, 55.87496817111969, 63.48765067756176, 68.63947883248329, 69.226805716753, 65.49175053834915, 62.11159631609917, 67.28659942746162, 65.7481075823307, 63.024345338344574, 66.15875154733658, 62.21382603049278, 59.23563323915005, 58.66897724568844, 57.67993591725826, 53.92911158502102, 58.05574715137482, 54.03767555952072, 54.172146543860435, 55.468766167759895, 54.837031066417694, 56.03726126253605, 49.255844950675964, 52.13537223637104, 56.300267949700356, 57.46173642575741, 59.772069454193115, 64.19168069958687, 64.91498708724976, 56.76460683345795, 54.006498232483864, 49.58984702825546, 55.19130125641823, 52.776310443878174, 55.79485327005386, 61.309333965182304, 61.52642771601677, 50.735812336206436, 52.41882562637329, 46.87402255833149, 52.553004026412964, 52.872620075941086, 49.29541602730751, 49.8502242565155, 52.15939834713936, 51.71462081372738, 50.411541536450386, 48.429153710603714, 50.5126579105854, 50.25198809802532, 48.29208366572857, 48.48176948726177, 47.10898295044899, 50.2192984521389, 46.55180744826794, 45.951063483953476, 50.60748182237148, 44.46425646543503, 47.66339600086212, 49.23665978014469, 51.52422443032265, 47.39518739283085, 47.38812357187271, 47.91475631296635, 48.88488605618477, 46.897626891732216, 47.63732559978962, 46.96426011621952, 47.50711038708687, 45.62644690275192, 45.02582833170891, 41.02077104151249, 46.12780340015888, 55.155849158763885, 54.58113379776478, 58.33766542375088, 53.0523694306612, 48.526379093527794, 48.280015513300896, 46.19004786014557, 47.546339482069016, 50.169676914811134, 55.08463717997074, 54.20851819217205, 57.92025402188301, 51.37141562998295, 54.31762933731079, 54.65201899409294, 59.95989717543125, 58.87338727712631, 60.045677572488785, 60.22625148296356, 60.594113543629646, 57.78984121978283, 44.30342249572277, 34.63362157344818, 21.946307569742203, 21.389941424131393, 26.165561266243458, 35.15623793005943, 34.910516515374184, 44.71312791109085, 55.57465508580208, 62.43678666651249, 64.28330898284912, 63.08618322014809, 59.38198618590832, 54.44691739976406, 53.73471021652222, 60.06808876991272, 55.68892255425453, 59.14499290287495, 59.748651310801506, 63.291961178183556, 66.80818229913712, 67.03761398792267, 71.60831272602081, 73.88265028595924, 71.85687258839607, 67.91190147399902, 42.88260653614998, 24.69464309513569, 0.540510902646929, 1.0613208124414086, 53.15637364983559, 76.40755400061607, 63.380473628640175, 49.27398517727852, 55.88053487241268, 54.883654564619064, 50.68606160581112, 52.33555309474468, 42.53228813409805, 50.135763734579086, 35.26516668498516, 26.09906293451786, 23.725522197782993, 10.74565714225173, 41.55523516237736, 50.53696520626545, 1.281070620752871, 0.3732716047670692], [0.0435143929644255, 0.4162235796684399, 4.301191074773669, 13.424213211983442, 3.587538069114089, 4.530902523547411, 5.691875601187348, 11.213189754635096, 9.368843771517277, 7.827631272375584, 12.40901218727231, 15.999951548874378, 28.20918470621109, 39.560934975743294, 37.54239208996296, 63.45781467854977, 73.64410668611526, 58.31775449216366, 45.390297174453735, 0.4920998972374946, 0.18040700146229938, 0.04157679752097465, 0.2830968325724825, 5.611109985038638, 12.120471820235252, 27.03204207122326, 63.1287257373333, 69.55511569976807, 70.00059619545937, 67.47469693422318, 64.61155816912651, 62.55461074411869, 58.24228674173355, 56.953080520033836, 52.098563611507416, 53.36886204779148, 51.7569163441658, 58.81201297044754, 61.72726973891258, 56.401661708950996, 56.42454408109188, 54.906054362654686, 53.29443924129009, 53.23490783572197, 53.406305238604546, 57.210892885923386, 57.93633095920086, 56.082133054733276, 55.35022012889385, 51.825426667928696, 52.1718692779541, 48.485261499881744, 49.440735429525375, 48.34479823708534, 47.454490810632706, 45.063556507229805, 46.489164009690285, 44.606319442391396, 48.19323197007179, 51.62933439016342, 54.522407948970795, 52.41852164268494, 56.78169071674347, 50.807886868715286, 47.37480528652668, 54.33651812374592, 51.16930067539215, 44.125500842928886, 51.840295270085335, 54.220586344599724, 50.64927197992802, 46.96884647011757, 45.88759168982506, 42.09952935576439, 43.77446427941322, 43.95337387919426, 43.29355828464031, 43.48360888659954, 44.21720892190933, 44.400788471102715, 47.75363355875015, 47.05643177032471, 43.47280606627464, 43.16676668822765, 41.57313600182533, 44.279707968235016, 45.041513890028, 44.12737034261227, 39.77045573294163, 38.642927035689354, 40.974143743515015, 43.999871984124184, 44.698312506079674, 44.87057626247406, 44.27920639514923, 41.07939049601555, 44.074101001024246, 46.89011849462986, 46.547483280301094, 47.09122650325298, 44.82073433697224, 42.61384315788746, 41.557161659002304, 38.77766780555248, 38.83807696402073, 41.63944624364376, 39.92609158158302, 45.83195507526398, 52.849517315626144, 45.122270956635475, 43.59421335160732, 37.49988377094269, 40.28406277298927, 34.69761773943901, 42.771717086434364, 51.26439057290554, 53.154887929558754, 56.2766370177269, 53.29869881272316, 49.93088632822037, 50.24933584034443, 50.321870148181915, 50.060197189450264, 51.15702733397484, 55.20929329097271, 55.753025114536285, 55.782788917422295, 52.41098664700985, 53.702484145760536, 58.16335737705231, 38.49537715315819, 31.313276141881943, 37.01456241309643, 44.18861545622349, 42.048984467983246, 43.79857778549194, 54.468169659376144, 58.094068095088005, 58.09759810566902, 58.08483079075813, 54.59501065313816, 51.627202704548836, 50.90170003473759, 50.10642170906067, 53.19762043654919, 52.286129146814346, 56.36426791548729, 56.69586852192879, 61.076740846037865, 60.73861598968506, 67.79441937804222, 67.9502110183239, 71.95801556110382, 58.25777091085911, 38.876842483878136, 12.814919706434011, 0.15543045185040683, 1.656564453151077, 38.369242921471596, 58.034282103180885, 42.72757105529308, 28.67190297693014, 38.09030368924141, 42.115279510617256, 35.85468225181103, 41.33045442402363, 41.11303009092808, 32.44851462543011, 4.963734447956085, 3.457947210408747, 1.5959628112614155, 5.014114044606686, 25.271267853677273, 7.840836988762021, 0.18587633298011497, 0.2595099247992039, 0.07041753939120099, 1.3801913894712925, 19.91644699126482, 29.315337650477886, 16.03037841618061, 5.978986769914627, 16.044266670942307, 25.478292144834995, 17.168637737631798, 15.889367032796144, 16.729227416217327, 18.595691062510014, 41.22018814086914, 46.65621444582939, 42.27925591170788, 70.9244254231453, 77.7816590666771, 63.72582949697971, 55.29020234942436, 0.825268691405654, 0.10401513616670854, 0.15672362933401018, 0.6918990542180836, 7.672521220520139, 13.887856733053923, 34.74355347454548, 76.94090098142624, 74.22564268112183, 76.53237730264664, 68.76839071512222, 70.65811291337013, 67.89935454726219, 64.68620896339417, 61.17149256169796, 57.67554335296154, 55.72752468287945, 58.59366908669472, 63.37682582437992, 67.93982237577438, 60.5367898195982, 65.14773979783058, 63.221566155552864, 61.47864148020744, 61.38476371765137, 61.36485658586025, 61.3541791588068, 60.71934722363949, 59.18655127286911, 58.099186420440674, 53.93813990056515, 53.192695900797844, 50.31826414167881, 52.10647098720074, 50.70649690926075, 48.88257957994938, 47.954851761460304, 49.95135962963104, 48.076346442103386, 51.75664275884628, 55.942091569304466, 56.957530081272125, 59.43242847919464, 59.563323855400085, 55.56561917066574, 52.28258773684502, 56.87134310603142, 54.80351686477661, 47.444542944431305, 54.41331960260868, 57.7614339441061, 51.07353441417217, 48.2563541829586, 46.451880410313606, 43.69491554796696, 44.815862998366356, 46.250130236148834, 44.42562773823738, 46.76809944212437, 45.402714908123016, 47.90026769042015, 50.76475538313389, 51.40208378434181, 46.53388760983944, 46.02172449231148, 44.60196107625961, 48.69108505547047, 47.01337248086929, 46.665246561169624, 43.12316782772541, 42.776983603835106, 46.32755108177662, 50.458875596523285, 46.94275327026844, 46.8772903829813, 46.59047797322273, 45.078983679413795, 45.625987127423286, 48.293554186820984, 47.126017436385155, 47.3996027559042, 47.08537481725216, 43.92072223126888, 44.76013898849487, 43.50160852074623, 42.22948618233204, 44.40533682703972, 41.38015575706959, 45.74215069413185, 55.141356736421585, 47.57130794227123, 44.052062183618546, 43.22719484567642, 43.45379188656807, 42.025608122348785, 44.16686162352562, 53.78986805677414, 53.17686975002289, 57.0720711350441, 52.129759937524796, 52.05212250351906, 52.48513586819172, 49.689656272530556, 51.083037704229355, 52.66763247549534, 57.36066184937954, 60.117410123348236, 58.048508539795876, 57.199941873550415, 59.25997093319893, 63.171967417001724, 40.30884504318237, 32.749751061201096, 41.22171185910702, 49.35224197804928, 48.557491824030876, 49.2096546292305, 60.07258392870426, 65.15008807182312, 62.24918693304062, 62.08789698779583, 58.63225221633911, 54.76057916879654, 55.124060064554214, 55.089664310216904, 60.14459386467934, 57.87399150431156, 61.64577931165695, 62.290619909763336, 66.68927147984505, 66.11144408583641, 73.4170612692833, 73.59150230884552, 79.4547700881958, 65.86855351924896, 54.545408114790916, 19.093454852700233, 0.3279461228521541, 1.8433941341936588, 48.52100998163223, 66.97275146842003, 53.309361040592194, 38.083422258496284, 44.32768039405346, 61.303759664297104, 53.050271943211555, 61.465307995676994, 58.40028986334801, 47.09580525755882, 31.842393949627876, 18.539541475474834, 12.635901812463999, 8.84689997881651, 40.137421041727066, 15.532190948724747, 0.3373741591349244, 0.10918288855464198, 0.4046203085454181, 0.9045254322700202, 8.445442020893097, 33.37703660130501, 26.237622499465942, 13.564464636147022, 14.110268298536539, 42.00845964252949, 36.19159497320652, 33.31782437860966, 29.717126190662384, 40.13166055083275, 50.066330060362816, 54.97453048825264, 52.78257630765438, 76.36826410889626, 84.50219884514809, 75.72651654481888, 64.22707960009575, 0.7911962165962905, 0.2818280865903944, 0.1033930828270968, 1.0389578249305487, 15.243964064866304, 30.76799400150776, 54.420113638043404, 78.2987505197525, 76.38943657279015, 77.07957834005356, 69.03604075312614, 70.35621151328087, 68.12833786010742, 65.10186105966568, 62.04555965960026, 57.25590527057648, 58.38220663368702, 60.54180935025215, 65.4107540845871, 71.97210520505905, 64.03336599469185, 67.21166744828224, 70.40790393948555, 67.16822057962418, 67.56270781159401, 63.87175306677818, 66.18508413434029, 64.63811114430428, 61.471851244568825, 58.995216339826584, 56.10073305666447, 56.80246040225029, 52.76183322072029, 56.86559781432152, 53.24284180998802, 52.7373131364584, 50.28912350535393, 50.801848992705345, 49.2269778996706, 54.30287852883339, 58.468272015452385, 60.577820017933846, 59.759875908493996, 63.70563358068466, 58.202107697725296, 53.93885426223278, 57.806560322642326, 54.2345429956913, 50.08438289165497, 58.12601678073406, 61.97350412607193, 54.57522131502628, 48.81522439420223, 49.15201932191849, 46.54355429112911, 47.55678132176399, 50.016575530171394, 47.524969428777695, 50.31003378331661, 50.858994126319885, 48.713541850447655, 54.82617124915123, 54.67175133526325, 49.23214942216873, 50.084071308374405, 48.30532595515251, 50.81877328455448, 52.73067869246006, 50.513706654310226, 45.416948944330215, 44.241607412695885, 47.96293392777443, 52.027268037199974, 49.758299589157104, 50.86589455604553, 51.07994087040424, 48.830362781882286, 49.45667937397957, 51.69999919831753, 51.94773830473423, 51.8137650936842, 50.658703073859215, 47.21981160342693, 47.1164495497942, 45.28542660176754, 44.88763354718685, 47.08203099668026, 41.76955886185169, 48.515276089310646, 59.79673773050308, 52.99321800470352, 50.99553979933262, 47.74411126971245, 47.65750251710415, 45.22369511425495, 51.56523942947388, 56.58187463879585, 56.124990954995155, 59.47643771767616, 56.859164759516716, 54.30686831474304, 56.21204048395157, 55.72255074977875, 55.333459228277206, 55.95586583018303, 58.176835253834724, 60.61935178935528, 58.86921510100365, 57.35183112323284, 57.95947551727295, 61.68999753892422, 41.4599134773016, 34.338312819600105, 42.502550929784775, 49.524068757891655, 48.57360675930977, 48.2436590641737, 57.68565461039543, 61.10253766179085, 61.26986928284168, 61.90172217786312, 58.35160307586193, 56.61204881966114, 54.69996862113476, 56.54724329710007, 58.72152842581272, 57.63560749590397, 62.140493765473366, 62.77342960238457, 66.52153328061104, 65.83899110555649, 70.15706419944763, 71.50743573904037, 79.77516129612923, 66.40174850821495, 59.58869509398937, 29.50118947774172, 0.3979278285987675, 2.011235165409744, 56.52479790151119, 75.0485797226429, 61.31219141185284, 45.11259667575359, 57.98998408019543, 59.11638043820858, 43.87651540338993, 72.13084548711777, 69.15344685316086, 60.5182696133852, 44.06138688325882, 25.728269331157207, 30.667498894035816, 44.72389653325081, 90.57058721780777, 17.233456559479237, 0.46617848973255605, 0.6784179713577032], [0.0652330664161127, 0.06933243785169907, 0.25528446247335523, 3.0407260358333588, 7.665519621223211, 5.238022729754448, 3.3734777430072427, 3.285760162398219, 10.88180098682642, 8.586333710700274, 14.290867857635021, 16.73987254500389, 19.520225152373314, 28.487548269331455, 36.28259629011154, 49.588691890239716, 73.35315629839897, 60.36219298839569, 62.46194511651993, 4.494142821058631, 0.18582589662401006, 3.1961600203067064, 0.3464346838882193, 22.416634932160378, 45.306310281157494, 51.926698833703995, 75.82109346985817, 70.30233040452003, 72.81384363770485, 65.50903961062431, 68.42505633831024, 61.96366645395756, 60.87739214301109, 56.940936371684074, 53.88723403215408, 49.30695980787277, 52.02425479888916, 55.0482427328825, 61.57206706702709, 58.95513989031315, 57.06088453531265, 57.37132787704468, 59.66361567378044, 55.40953494608402, 60.765624940395355, 60.66949389874935, 58.092525377869606, 60.92916816473007, 61.86286926269531, 62.633676901459694, 56.69926553964615, 52.423476576805115, 46.87013156712055, 47.28608004748821, 49.30639363825321, 47.25224666297436, 48.2825917750597, 49.42271679639816, 50.78467011451721, 52.38099865615368, 51.916975155472755, 53.713089376688, 50.00267207622528, 54.793333411216736, 54.963446483016014, 45.31908139586449, 53.18685941398144, 45.52181951701641, 45.29025614261627, 46.763228103518486, 42.85274013876915, 43.433405980467796, 42.52119652926922, 43.87205444276333, 44.02670994400978, 44.460867047309875, 41.471024081110954, 42.12137058377266, 42.16308854520321, 40.2522736787796, 41.88829489052296, 46.23741611838341, 45.586351454257965, 42.383681908249855, 42.50723607838154, 42.073629945516586, 44.30982135236263, 44.10121634602547, 43.856486678123474, 43.571558967232704, 44.8616923391819, 44.278454035520554, 44.89648327231407, 44.012023732066154, 41.26523472368717, 43.60131897032261, 43.20527382194996, 43.03417660295963, 43.6043132096529, 41.30469560623169, 41.178713366389275, 43.40053014457226, 39.634639620780945, 41.27914197742939, 38.38448390364647, 41.96580693125725, 35.80727219581604, 37.950900569558144, 42.1951512247324, 37.39478521049023, 35.98438449203968, 39.31166835129261, 38.52296367287636, 43.32880899310112, 41.70306243002415, 52.94507838785648, 59.120347425341606, 59.26418110728264, 58.72761569917202, 53.61180581152439, 49.327319115400314, 51.05947516858578, 50.30749551951885, 50.99281534552574, 49.83535185456276, 53.08454230427742, 54.454467594623566, 53.81078213453293, 53.90992261469364, 57.92261749505997, 58.01626726984978, 43.876861184835434, 54.95589628815651, 62.140432968735695, 55.39141371846199, 57.926364094018936, 59.77783374488354, 58.644517958164215, 60.64485602080822, 58.82619380950928, 53.99314574897289, 49.126214906573296, 50.44478215277195, 48.39579530060291, 52.24593110382557, 52.43331044912338, 53.75960648059845, 55.92597283422947, 60.56921347975731, 61.09782211482525, 67.47361779212952, 66.95412486791611, 69.46205109357834, 61.21629595756531, 42.45975382626057, 6.797577319666743, 0.6061650265473872, 3.439172417856753, 51.85711316764355, 56.36612221598625, 39.80019673705101, 26.638140007853508, 43.953465074300766, 29.536295793950558, 28.730794116854668, 39.32764269411564, 42.507764250040054, 27.960792034864426, 8.470774311572313, 6.562977433204651, 4.402057137340307, 14.319785255938768, 20.325154960155487, 0.1097326196031645, 0.047068489948287606, 0.06890958436997607, 0.09527638438157737, 0.18873922701459378, 2.4005235638469458, 10.325648579746485, 8.036781549453735, 4.431069530546665, 9.214498903602362, 13.085044361650944, 18.914739042520523, 16.387939229607582, 14.048114083707333, 18.895593769848347, 34.53694336116314, 35.49872115254402, 41.80209271609783, 55.44920101761818, 78.76357197761536, 66.39898225665092, 66.44428342580795, 7.173369079828262, 0.723853261442855, 0.6170795846264809, 0.42986051354091614, 25.495364628732204, 49.65246006846428, 62.30663225054741, 86.37267887592316, 77.6250770688057, 79.2854967713356, 68.6895601451397, 75.22988319396973, 68.22665378451347, 64.55776825547218, 61.784897446632385, 57.30087585747242, 56.64497785270214, 56.2272434681654, 61.503621339797974, 67.26930275559425, 65.8196197450161, 63.18727299571037, 64.0058858692646, 66.27760156989098, 61.56244598329067, 64.23910215497017, 65.11632308363914, 62.55998745560646, 64.33755487203598, 61.96306988596916, 63.31733241677284, 56.96578323841095, 53.03817339241505, 48.98949824273586, 50.35372003912926, 50.9584803879261, 50.580814853310585, 51.80641248822212, 53.875325471162796, 54.937687665224075, 54.60246205329895, 59.52984385192394, 56.7339538782835, 52.640669122338295, 61.79527468979359, 54.89357203245163, 47.73292846977711, 51.276827305555344, 47.8284477442503, 46.734775230288506, 45.4914515465498, 41.3450076431036, 47.15910226106644, 43.31880412995815, 46.78920730948448, 45.6110767275095, 49.25965994596481, 43.98595713078976, 45.44453926384449, 45.97675010561943, 45.02061501145363, 43.99389870464802, 47.498515248298645, 46.550709307193756, 46.50828838348389, 45.92306658625603, 43.237898871302605, 46.68438233435154, 48.247952833771706, 45.8776780217886, 46.50259628891945, 47.38003000617027, 47.012859508395195, 47.89886936545372, 47.38565370440483, 43.62322859466076, 44.56276997923851, 44.68536280095577, 47.29173794388771, 44.89470116794109, 42.76069387793541, 43.924472630023956, 44.50149826705456, 43.07260774075985, 44.61139976978302, 42.5970708578825, 44.035126492381096, 36.46484211087227, 38.6240154504776, 43.022910207509995, 40.2118818461895, 39.95250776410103, 43.43275621533394, 42.04141907393932, 49.90670822560787, 46.60767965018749, 52.24383361637592, 59.47567015886307, 56.88496917486191, 57.231400385499, 54.71821144223213, 51.45784579217434, 51.96243591606617, 51.0802486538887, 52.359256222844124, 50.90480826795101, 53.00776742398739, 57.260586619377136, 58.40265333652496, 56.958001255989075, 61.97701893746853, 59.021833911538124, 49.74461272358894, 60.672111958265305, 66.5363296866417, 60.29807522892952, 61.86781659722328, 64.40083667635918, 65.2846160531044, 67.17288672924042, 62.86539226770401, 57.87335693836212, 53.852180913090706, 56.55302278697491, 53.26918959617615, 57.25791156291962, 57.27257877588272, 59.604270458221436, 60.48285931348801, 65.48835352063179, 66.69053301215172, 73.2961517572403, 71.31435289978981, 73.91976669430733, 65.82522824406624, 52.91834682226181, 9.136206954717636, 0.7687856128904969, 4.520620750263333, 63.64052027463913, 65.23298442363739, 50.66513612866402, 30.980244912207127, 54.93032746016979, 36.45755410194397, 24.62987557053566, 42.60147102177143, 59.80769254267216, 49.95584338903427, 19.812818951904774, 10.104519445449114, 16.8436411768198, 32.68826276063919, 37.708910554647446, 0.47214740538038313, 0.10010421086917631, 0.07191608397988603, 0.18245526967803016, 0.17082784906961024, 0.7071886619087309, 5.468110358342528, 22.72692058235407, 12.968672756105661, 14.649461265653372, 14.07799568027258, 31.173665933310986, 32.815096154809, 30.85074596107006, 39.754914566874504, 37.716859728097916, 41.38165667653084, 50.48656091094017, 62.69948177039623, 84.39715728163719, 74.61498498916626, 77.04120799899101, 7.781762033700943, 1.0897989780642092, 7.972875628620386, 0.42193449509795755, 30.499272421002388, 62.573575526475906, 68.15268695354462, 78.72966259717941, 74.82306182384491, 75.9813840687275, 70.20124822854996, 72.43128776550293, 69.27567109465599, 64.41048055887222, 64.5518709719181, 59.74383696913719, 58.67975726723671, 57.33844444155693, 63.791516572237015, 67.91482731699944, 70.25828316807747, 64.10040199756622, 66.56987428665161, 68.34802687168121, 65.9892426431179, 70.18744736909866, 69.03877660632133, 63.95367667078972, 65.87026342749596, 63.81278023123741, 66.60058423876762, 60.058638677001, 55.68954952061176, 51.03733755648136, 52.47644953429699, 53.85643668472767, 54.00002717971802, 54.00820054113865, 55.87021462619305, 56.5282329171896, 59.610460326075554, 58.3169337362051, 60.36785468459129, 57.37951643764973, 60.02422772347927, 55.655963122844696, 52.124014645814896, 54.452142119407654, 49.142044857144356, 50.55661015212536, 51.17634169757366, 43.565049916505814, 47.48357065021992, 47.702674493193626, 49.8744897544384, 47.52851463854313, 51.00523687899113, 46.215616688132286, 49.29929181933403, 47.798801735043526, 47.015998139977455, 47.19280645251274, 52.03357569873333, 50.97268022596836, 51.68508879840374, 50.26361167430878, 47.53565825521946, 49.49133351445198, 52.614651918411255, 49.89872865378857, 50.32008804380894, 50.38317605853081, 49.333186000585556, 51.945743411779404, 53.091682121157646, 47.404838874936104, 47.98681944608688, 47.85115912556648, 50.27233600616455, 48.19317117333412, 46.733342707157135, 46.366590186953545, 48.832616060972214, 46.524973288178444, 47.793759405612946, 44.89005021750927, 45.62065601348877, 36.80229440331459, 40.55716551840305, 48.06507244706154, 46.01663276553154, 44.38253425061703, 49.1267316788435, 45.48800513148308, 51.168833300471306, 48.29779855906963, 57.399993538856506, 61.56988598406315, 61.6103196144104, 62.472181767225266, 59.27713081240654, 55.644943714141846, 56.72979690134525, 56.11812852323055, 56.37618027627468, 53.696248680353165, 55.68782061338425, 57.34520807862282, 58.32421414554119, 56.91140815615654, 60.75599625706673, 59.95800867676735, 50.167465433478355, 61.274630427360535, 64.25719678401947, 59.03963975608349, 60.53535349667072, 62.40399442613125, 64.02524203062057, 67.1774160861969, 63.32824543118477, 57.45914876461029, 53.09741601347923, 57.30894662439823, 53.617752492427826, 58.38602162897587, 57.88001038134098, 60.77928140759468, 59.11873251199722, 67.42100581526756, 67.59470969438553, 72.7067805826664, 71.33520618081093, 75.86172848939896, 67.8514239192009, 64.30708810687065, 14.411393590271473, 0.8612677222117782, 5.010986337438226, 68.87177556753159, 71.53796330094337, 57.03023537993431, 40.10668069124222, 67.61010646820068, 40.02160705626011, 41.69821389019489, 59.45532225072384, 70.27532905340195, 54.88517448306084, 36.04284055531025, 38.06846626102924, 41.77208952605724, 64.19169589877129, 46.07350051403046, 0.27252407802734524, 0.2867563033942133, 0.2163130114786327], [0.08115185948554426, 0.07451772718923166, 0.08124142928863876, 0.5473797465674579, 4.461595192551613, 1.9760041683912277, 1.6445085313171148, 8.651143033057451, 11.268927063792944, 9.861300196498632, 12.063506226986647, 22.87406198680401, 28.70227474719286, 19.82560146600008, 38.04483912885189, 35.953431352972984, 63.58058229088783, 64.61919575929642, 67.15278580784798, 21.479472219944, 0.3968409087974578, 1.5430197771638632, 0.1994042008300312, 24.143528267741203, 70.10103240609169, 65.15597015619278, 74.35344502329826, 70.30227720737457, 70.70202335715294, 61.700370982289314, 65.48348218202591, 63.120928555727005, 60.551297441124916, 58.1936227530241, 58.04829575121403, 49.5977696031332, 52.432292103767395, 54.85397055745125, 60.95019243657589, 60.1142942905426, 62.00980357825756, 59.0539725869894, 61.263611018657684, 58.19502107799053, 61.059535369277, 63.13103601336479, 61.7837955057621, 59.78125736117363, 59.45626460015774, 62.75380365550518, 61.235416531562805, 59.405248537659645, 49.62564870715141, 46.260541677474976, 50.24062670767307, 52.67571844160557, 54.377863705158234, 53.05380195379257, 51.409580782055855, 51.57231844961643, 54.19819414615631, 45.66552400588989, 56.79300270974636, 58.52225951850414, 53.64228777587414, 49.52433094382286, 47.22399137914181, 46.93139187991619, 40.50283223390579, 37.38298684358597, 37.42583714425564, 41.7839714884758, 40.67958354949951, 42.93508931994438, 43.76868478953838, 43.038595765829086, 42.79668554663658, 42.31327548623085, 44.838243797421455, 44.4499958306551, 43.77880744636059, 44.204065427184105, 42.27735601365566, 43.75210627913475, 41.86812177300453, 43.60558234155178, 39.74532388150692, 41.12105146050453, 42.519513219594955, 41.02032646536827, 38.644161969423294, 40.48971153795719, 42.02740162611008, 43.10759626328945, 43.21234904229641, 42.23587363958359, 43.258197382092476, 43.1035228818655, 41.56559720635414, 40.398904010653496, 44.18880544602871, 42.47456543147564, 38.505218625068665, 39.53940913081169, 41.03889986872673, 39.89101566374302, 36.82121738791466, 35.05511395633221, 33.83455105125904, 36.69078938663006, 37.33795925974846, 40.29522277414799, 45.00621758401394, 50.691795498132706, 58.55562932789326, 54.55535598099232, 58.655734956264496, 58.30841079354286, 52.80247204005718, 54.1851494461298, 50.2373930811882, 51.550215035676956, 47.04511597752571, 48.55478256940842, 46.76755987107754, 46.89929120242596, 48.047893568873405, 55.14338202774525, 51.55271150171757, 57.697190791368484, 51.487666592001915, 53.856269493699074, 61.48626387119293, 54.596146792173386, 57.063715383410454, 57.27111965417862, 59.55135829746723, 59.01754394173622, 60.590021163225174, 56.20907284319401, 53.03750082850456, 47.75561325252056, 48.267358392477036, 51.61860376596451, 54.014276415109634, 54.82721619307995, 59.25671450793743, 57.16452017426491, 62.77700141072273, 60.25862194597721, 64.69290420413017, 63.63321326673031, 66.39677837491035, 58.219909742474556, 36.468733102083206, 2.020234032534063, 0.49758463574107736, 7.477469611912966, 63.06259788572788, 51.087213680148125, 36.55932404100895, 28.717663921415806, 43.57004664838314, 41.867969781160355, 47.83353567123413, 32.25332669913769, 39.73074406385422, 28.670310862362385, 29.404038190841675, 13.17926600575447, 5.795558737590909, 12.436982486397028, 0.5910771642811596, 0.05731670702516567, 0.04016119164589327, 0.1062456016370561, 0.05946561417658813, 0.046590546844527125, 0.1580206214566715, 1.9389535440132022, 5.733896596357226, 3.2774338591843843, 4.25059393979609, 13.520554192364216, 12.40271782502532, 13.947954308241606, 14.783765058964491, 29.653749391436577, 31.670502573251724, 22.18110267072916, 45.508995205163956, 42.756419107317924, 70.60607090592384, 67.39560037851334, 75.77118694782257, 26.44307367503643, 0.36891222931444645, 0.4661565221613273, 0.1962277345592156, 28.478345163166523, 76.78398460149765, 71.99113458395004, 77.7231878042221, 77.49083787202835, 73.3915950357914, 67.55494862794876, 69.56453919410706, 66.11232563853264, 63.59417036175728, 62.040042355656624, 60.99860183894634, 54.85698759555817, 55.661586821079254, 59.61029313504696, 65.084298402071, 66.49041295051575, 67.0077095925808, 63.46117749810219, 64.42940354347229, 64.30696651339531, 66.7616955935955, 66.33253902196884, 64.02639716863632, 62.40279369056225, 62.47218556702137, 63.15166890621185, 63.19858878850937, 60.09226307272911, 51.32353439927101, 48.40541258454323, 53.361893221735954, 55.891333892941475, 56.909413263201714, 58.127141520380974, 54.86848957836628, 58.5355170071125, 56.33084490895271, 53.45549739897251, 62.386344373226166, 57.301780208945274, 55.809775069355965, 54.05692532658577, 51.253735944628716, 49.83563303947449, 45.968128368258476, 38.72389309108257, 38.45017097890377, 45.715510323643684, 44.067531153559685, 44.834033623337746, 45.48177346587181, 45.33424258232117, 45.08562192320824, 45.68451538681984, 46.47111877799034, 47.65701234340668, 46.653216406702995, 47.97602042555809, 43.68499048054218, 45.69675453007221, 45.12435704469681, 47.31613263487816, 44.77570675313473, 46.020443961024284, 45.63807047903538, 42.97010064125061, 41.64253547787666, 43.666607066988945, 48.2863649725914, 46.966707184910774, 45.352755188941956, 44.69300799071789, 45.77389419078827, 45.563548877835274, 44.195018112659454, 43.2349768280983, 47.101064175367355, 44.4914136081934, 41.98203206062317, 42.578938230872154, 44.23548974096775, 42.23218023777008, 37.99722008407116, 36.27320699393749, 36.84384137392044, 41.97457306087017, 41.07708781957626, 44.53827269375324, 49.97363023459911, 54.4550945609808, 59.48576241731644, 56.74208924174309, 56.530364602804184, 58.98634001612663, 53.62643122673035, 56.22085981070995, 54.37654137611389, 55.23411735892296, 50.876967161893845, 51.219803765416145, 50.76924294233322, 49.537926614284515, 48.57443891465664, 58.0863469094038, 55.99756099283695, 61.158539056777954, 57.45655730366707, 57.547725811600685, 64.17929336428642, 58.80731262266636, 62.73278318345547, 63.15592087805271, 64.48481976985931, 65.57758033275604, 63.97978127002716, 60.70968434214592, 56.21959067881107, 51.6153397411108, 53.402326852083206, 55.23992344737053, 57.86744445562363, 61.168616116046906, 64.48469817638397, 63.60227532684803, 66.25683948397636, 64.69774514436722, 67.7049645781517, 69.07042130827904, 74.78385552763939, 65.63656836748123, 47.22897291183472, 2.263345462270081, 0.869573779636994, 11.54069323092699, 73.69125455617905, 60.64392887055874, 46.28785461187363, 34.14589874446392, 52.793333530426025, 44.59498465061188, 32.29811869561672, 26.860861256718636, 48.09955179691315, 38.30123417079449, 33.12801316380501, 21.615385226905346, 21.208765245974064, 31.35140899568796, 2.32842480763793, 0.06691494374535978, 0.0119599138997728, 0.08229876708355732, 0.19305312365759164, 0.1787701205466874, 0.18414843507343903, 0.6709286326076835, 7.7296198066324, 9.841999132186174, 13.040114622563124, 16.74552284181118, 38.79822090268135, 26.68373566120863, 34.253151789307594, 46.6196072101593, 42.471088618040085, 31.054382734000683, 53.2202710211277, 51.55807301402092, 75.05849719047546, 77.73271009325981, 82.9403230547905, 30.16325645148754, 1.060789197217673, 4.741789307445288, 0.2710710122482851, 30.14095924794674, 72.13874906301498, 68.00913825631142, 77.02369093894958, 74.9112018942833, 73.59024837613106, 65.2516870200634, 68.2141600549221, 67.23901838064194, 64.60555449128151, 64.22913148999214, 62.477170899510384, 55.55646926164627, 57.983919605612755, 61.31740853190422, 68.03694516420364, 68.94366770982742, 67.12336018681526, 66.16420045495033, 68.0956444144249, 65.35811930894852, 69.7327409684658, 68.53629916906357, 65.86811274290085, 64.05908301472664, 65.9033976495266, 66.88583493232727, 64.18972000479698, 62.02780321240425, 51.79838351905346, 52.12060242891312, 55.792881175875664, 56.46033436059952, 59.118477925658226, 59.904127568006516, 57.85333961248398, 58.955333679914474, 60.81710837781429, 55.50606496632099, 60.16665168106556, 61.335145980119705, 56.951245218515396, 57.442285269498825, 55.343011915683746, 52.237240970134735, 50.81828311085701, 42.503143697977066, 41.27998933196068, 46.56442657113075, 46.62874951958656, 47.765367329120636, 48.7192415446043, 49.03796844184399, 48.72794307768345, 48.90755943953991, 49.609263986349106, 49.28316168487072, 49.69004765152931, 50.86176797747612, 45.64036935567856, 48.40886279940605, 48.55781860649586, 51.27321369946003, 49.1142151504755, 49.38087724149227, 50.36913201212883, 46.72118715941906, 46.62030257284641, 46.45756110548973, 51.21037267148495, 48.62462282180786, 48.00556004047394, 48.634411096572876, 47.69615404307842, 48.2269361615181, 47.48339585959911, 46.06940433382988, 52.05205790698528, 49.967311173677444, 45.00946640968323, 45.83629444241524, 46.402589455246925, 43.50240267813206, 39.216814041137695, 41.64075717329979, 41.10205627977848, 47.650955468416214, 45.909885093569756, 49.971547946333885, 53.19624491035938, 58.94226998090744, 62.36788496375084, 60.16939513385296, 61.52930036187172, 64.23303008079529, 60.99787227809429, 64.76946249604225, 60.26116020977497, 58.75642195343971, 52.65296146273613, 53.24332818388939, 54.10356782376766, 50.80047346651554, 49.980363473296165, 60.1541655510664, 56.634296625852585, 61.099174842238426, 57.67680488526821, 56.16658352315426, 62.27400720119476, 57.700192630290985, 60.96145883202553, 60.36506563425064, 64.63441774249077, 65.15198037028313, 62.95115366578102, 59.37453858554363, 57.776750922203064, 52.37018063664436, 53.42699512839317, 57.31472231447697, 58.601257279515266, 61.95479013025761, 65.30618369579315, 61.99784941971302, 66.0825352370739, 66.44430622458458, 67.57272407412529, 70.20371809601784, 76.179558634758, 68.35923627018929, 55.74710503220558, 3.9034334057942033, 0.9653272165451199, 11.766460966318846, 77.0995956659317, 67.35868155956268, 53.8297925144434, 43.73049683868885, 58.79998281598091, 59.44538578391075, 63.86034607887268, 49.14316199719906, 55.47246336936951, 50.591534078121185, 58.90254691243172, 35.668967217206955, 45.365419909358025, 38.132257238030434, 1.202840656042099, 0.17133727407781407, 0.19090827234322205, 0.21669923997251317], [0.03165375244861934, 0.01618010883248644, 0.014299786780611612, 0.014668592430098215, 0.28446205775253475, 0.8460234152153134, 2.1734095131978393, 6.654466548934579, 5.553972451016307, 6.412237621843815, 11.411080285906792, 23.59300810843706, 52.24571071565151, 27.59339164942503, 36.87011316418648, 37.437643110752106, 49.09121498465538, 64.56691056489944, 63.67586597800255, 49.450288116931915, 1.068107842002064, 0.3712340828496963, 0.49515134131070226, 15.334457159042358, 63.14335115253925, 71.08223095536232, 75.10866969823837, 71.7757773399353, 73.36049750447273, 65.98953142762184, 65.57615160942078, 64.14484441280365, 62.03208178281784, 57.72895708680153, 55.95593802630901, 52.90738061070442, 52.00082525610924, 51.15730091929436, 55.94227395951748, 59.30130511522293, 59.59804639220238, 59.96914587914944, 61.33850499987602, 57.931379824876785, 63.85681986808777, 61.937364265322685, 61.56870424747467, 65.76771453022957, 58.99706684052944, 62.449911162257195, 62.8003853559494, 59.99138988554478, 51.358686313033104, 48.60399752855301, 50.99012888967991, 57.77434945106506, 54.92521293461323, 53.817845955491066, 53.53590868413448, 55.95417872071266, 46.064589992165565, 56.678302064538, 58.30766223371029, 52.04166166484356, 53.322078958153725, 51.72416590154171, 47.724291533231735, 44.37302716076374, 42.31476500630379, 37.909004017710686, 37.96331450343132, 44.329880475997925, 40.70304349064827, 39.61947463452816, 42.69140459597111, 43.872719407081604, 44.085967764258385, 44.413308799266815, 43.10136839747429, 41.50357313454151, 43.13402384519577, 42.188133001327515, 40.657008960843086, 42.636983916163445, 42.13784649968147, 45.72633974254131, 41.61816358566284, 42.51756012439728, 42.80959725379944, 42.503253892064095, 43.689649030566216, 48.39118994772434, 46.67610637843609, 45.36263845860958, 43.86157840490341, 42.10487946867943, 41.740251034498215, 40.85473135113716, 40.19028760492802, 43.968728855252266, 41.83147273957729, 43.698145374655724, 38.79432611167431, 38.762791603803635, 36.855062171816826, 40.07025204598904, 35.3813948482275, 32.87785738706589, 33.45185458660126, 34.190348759293556, 41.0393862426281, 45.5064607411623, 49.16601397097111, 52.89662718772888, 57.551069632172585, 61.55790142714977, 54.62558001279831, 53.29184018075466, 48.34295533597469, 48.21842461824417, 50.918738320469856, 51.441480070352554, 52.60956399142742, 50.35525515675545, 47.631884291768074, 46.95782706141472, 44.877792075276375, 53.733646273612976, 53.379429280757904, 56.33449651300907, 54.51724402606487, 56.11788533627987, 56.76577717065811, 55.78527398407459, 57.09447093307972, 59.98570919036865, 57.67180435359478, 57.77742348611355, 54.21729952096939, 51.30425803363323, 47.53170646727085, 48.431289196014404, 50.138602182269096, 53.7900048494339, 58.25653597712517, 62.85816125571728, 62.379003167152405, 62.22399428486824, 64.08193498849869, 61.27874940633774, 66.58960282802582, 65.4528634250164, 68.44385772943497, 63.6579005420208, 33.55263277888298, 1.0620451485738158, 0.10919057720457204, 15.16810493543744, 63.71420972049236, 57.09571346640587, 34.12695676088333, 32.95210920274258, 43.61800007522106, 40.79774960875511, 29.75896004587412, 44.81407329440117, 40.093104019761086, 35.57003952562809, 37.965222001075745, 28.698034174740314, 15.425941050052643, 0.4674621974118054, 0.07865974985179491, 0.01743169079418294, 0.07325865139137022, 0.039726589966448955, 0.05981613794574514, 0.0154390743773547, 0.0563884435541695, 0.1486136027961038, 2.1964958868920803, 0.5200549971777946, 7.82025539316237, 11.393357086926699, 17.530689910054207, 11.392635125666857, 21.301953345537186, 32.42662400007248, 49.61093969643116, 27.810451202094555, 45.186506509780884, 42.527572587132454, 55.332600474357605, 72.17877611517906, 72.28073224425316, 56.432497054338455, 1.853805456776172, 0.3354512545047328, 0.5688178399577737, 17.413946874439716, 70.12615665793419, 76.18322163820267, 80.19572272896767, 75.53334251046181, 76.5904913842678, 70.53182289004326, 68.21356728672981, 67.56542846560478, 66.73121362924576, 63.325171396136284, 58.5512063652277, 56.24468453228474, 54.26956571638584, 56.485937386751175, 62.05406740307808, 64.89914193749428, 66.12564772367477, 66.2997467815876, 64.4832694530487, 63.39330554008484, 64.73963409662247, 64.91357356309891, 66.82452142238617, 67.0926882326603, 61.909211575984955, 63.47547993063927, 63.49982522428036, 61.02021127939224, 54.20837000012398, 50.0155495852232, 53.34664084017277, 58.726506158709526, 57.40617960691452, 56.07258416712284, 58.10467332601547, 53.500220999121666, 53.47948171198368, 62.97413483262062, 56.41747646033764, 55.68112537264824, 57.35681265592575, 55.42746238410473, 51.4508655667305, 48.866111263632774, 45.97505919635296, 41.52811601758003, 37.668837904930115, 45.507828667759895, 43.22664387524128, 42.55765177309513, 45.827836096286774, 47.676535695791245, 47.08488464355469, 46.47551514208317, 44.98274624347687, 44.49403926730156, 44.646726474165916, 45.46612210571766, 45.26619203388691, 44.884635508060455, 42.73379512131214, 47.55287513136864, 45.874451994895935, 45.81779703497887, 44.288797080516815, 44.70265567302704, 48.387393951416016, 49.11259263753891, 50.1015617698431, 47.112847343087196, 46.83473266661167, 44.017959013581276, 44.256829395890236, 43.55101726949215, 42.64353856444359, 46.28923773765564, 45.06083965301514, 46.21608026325703, 41.81400887668133, 43.65329258143902, 40.23690350353718, 44.24442306160927, 37.970667108893394, 34.22312580049038, 36.44346825778484, 39.98501881957054, 45.60240939259529, 49.3892177939415, 51.186513751745224, 56.503036469221115, 57.94182926416397, 61.61026641726494, 56.99131406843662, 57.57928691804409, 53.83482724428177, 53.994775861501694, 56.49844631552696, 54.92117375135422, 54.64652828872204, 52.273677214980125, 48.82092408835888, 50.70274271070957, 46.407726779580116, 56.32360249757767, 56.76715649664402, 57.757611349225044, 56.960702911019325, 61.81184560060501, 58.568567633628845, 61.08477361500263, 60.60397781431675, 63.482433557510376, 61.52507498860359, 62.17428915202618, 58.07307042181492, 54.507812932133675, 51.21790386736393, 53.91261287033558, 52.93466694653034, 58.204182386398315, 62.042812407016754, 65.73803812265396, 69.08687442541122, 67.7617335319519, 68.47324535250664, 68.71166735887527, 70.45385867357254, 72.42105111479759, 70.40436252951622, 68.49500298500061, 41.75626717507839, 0.975421731127426, 0.11315305950120091, 19.02127582579851, 72.36641004681587, 65.1191957294941, 43.49445350468159, 40.04973314702511, 50.80653414130211, 43.79615731537342, 23.14079437404871, 43.60540375113487, 54.662654623389244, 38.65858979523182, 39.37775440514088, 34.79616545140743, 21.776367388665676, 1.1829857714474201, 0.14711752213770524, 0.012190553916298086, 0.05163359615835361, 0.11184970717295073, 0.21163236029678956, 0.09643105484428816, 0.14025360607774928, 0.1429058489156887, 1.13678143825382, 2.7839282155036926, 10.119880121201277, 66.8852649629116, 41.90125599503517, 26.213577389717102, 40.353781431913376, 46.324074268341064, 67.86013305187225, 41.40102043747902, 52.7691288292408, 53.457146510481834, 62.010149359703064, 79.22304332256317, 78.15314993262291, 64.63615044951439, 2.252616975456476, 1.1404768587090075, 1.0053654899820685, 20.447179712355137, 73.3819967508316, 76.35016947984695, 79.40011382102966, 74.82059195637703, 76.74859330058098, 69.84834596514702, 69.2029657959938, 68.85830149054527, 67.32678607106209, 63.15690502524376, 58.957499563694, 56.189253106713295, 58.12773808836937, 57.65892684459686, 61.52796283364296, 66.1854337155819, 69.6610540151596, 66.24790996313095, 67.30908662080765, 64.44835692644119, 68.68144378066063, 66.76617175340652, 69.23287779092789, 69.50684309005737, 62.618078738451004, 65.80964148044586, 66.22372806072235, 63.44245970249176, 56.092962473630905, 53.57896037399769, 55.76355054974556, 62.415112629532814, 60.21789193153381, 58.98032873868942, 59.93914648890495, 60.015279203653336, 55.482331439852715, 60.178868025541306, 60.64551338553429, 58.59337270259857, 61.41826651990414, 58.4074866771698, 57.15597823262215, 49.300332963466644, 50.610004886984825, 46.349996477365494, 42.17929467558861, 50.63522033393383, 47.620796486735344, 46.257144659757614, 48.90256270766258, 49.2726818472147, 49.87169690430164, 49.08121012151241, 46.96785472333431, 47.28909708559513, 48.59909579157829, 46.730599254369736, 46.97977848351002, 49.16511341929436, 45.57044930756092, 51.67247727513313, 46.2774583697319, 48.66625338792801, 48.741325959563255, 48.43891158699989, 49.262980967760086, 53.269436582922935, 51.27406485378742, 50.270538702607155, 50.42959436774254, 46.138336434960365, 49.858063235878944, 47.10575312376022, 45.59327848255634, 51.346450969576836, 47.62949042022228, 49.47905637323856, 44.86712224781513, 45.607960894703865, 41.437213495373726, 45.968333557248116, 40.346706211566925, 36.8643032759428, 39.802670404314995, 45.26561066508293, 50.1249685138464, 53.00416141748428, 54.25194226205349, 58.595390394330025, 60.4754763096571, 64.08188939094543, 61.2190356105566, 65.3111158311367, 58.9352897554636, 59.89079788327217, 60.77308014035225, 58.318841233849525, 56.75492115318775, 56.89930200576782, 51.937991827726364, 52.63684272766113, 47.38881893455982, 59.58401754498482, 58.498841375112534, 59.131005853414536, 56.453266739845276, 60.98495677113533, 58.99920612573624, 60.631731525063515, 60.342593640089035, 62.10893265902996, 59.63000647723675, 63.23438286781311, 56.537500619888306, 56.493628174066544, 52.397117391228676, 54.87939119338989, 54.16259765625, 59.30293522775173, 63.47288466989994, 68.62232655286789, 68.19568544626236, 67.30754390358925, 67.95498356223106, 69.49856713414192, 73.6913913488388, 74.75142806768417, 72.8925222158432, 74.91805672645569, 51.5999885648489, 2.7195563446730375, 0.3058783320011571, 19.99349545687437, 78.19988742470741, 73.98538157343864, 48.82125087082386, 45.288964211940765, 57.022031620144844, 57.9014640301466, 42.66602575778961, 58.47753591835499, 57.46280036866665, 49.967276975512505, 56.49105191230774, 60.71811988949776, 38.32528308033943, 0.6484809808898717, 0.19856204133247957, 0.10086176553159021, 0.12260555697139353, 0.17596129939192906], [0.10100544532178901, 0.06537474982906133, 0.03318905561172869, 0.04109259069082327, 0.13366885628784075, 0.17522143753012642, 15.962183475494385, 35.65790981054306, 13.332643825560808, 6.864282740280032, 7.369892159476876, 24.48418378829956, 53.10050904750824, 36.08787573873997, 32.91546016931534, 41.90176136791706, 38.85519504547119, 63.29421065747738, 64.00042176246643, 57.83616453409195, 2.908681221306324, 0.32871786737814546, 0.6913954624906182, 11.450298931449652, 63.441084176301956, 71.07358261942863, 73.46701338887215, 69.89325195550919, 69.90761518478394, 64.96816143393517, 64.30602416396141, 60.63668645918369, 61.74719586968422, 58.866023272275925, 58.42930130660534, 52.56295569241047, 53.23477864265442, 50.1166507601738, 54.00667302310467, 56.78016699850559, 56.88142016530037, 58.00869047641754, 60.03558151423931, 61.845181211829185, 61.02041266858578, 60.36087065935135, 58.37136581540108, 56.81846134364605, 59.91659849882126, 58.074955120682716, 60.57483337819576, 57.291714549064636, 53.112372010946274, 47.167906388640404, 53.775166645646095, 56.66042782366276, 55.983646139502525, 52.84563012421131, 51.86348542571068, 48.716509491205215, 56.56361661851406, 59.249076917767525, 52.3606925457716, 53.485470190644264, 49.30822513997555, 49.565573930740356, 46.533857211470604, 48.38752694427967, 44.70803238451481, 39.580796509981155, 35.92451490461826, 37.22624525427818, 43.82156655192375, 43.69187951087952, 41.619014739990234, 40.916098058223724, 44.05018508434296, 43.9223675429821, 43.38182754814625, 42.83309519290924, 40.717368721961975, 42.64964863657951, 43.93010012805462, 44.49119322001934, 41.623422503471375, 39.82796564698219, 44.5288871973753, 42.343677654862404, 39.21120174229145, 41.38855330646038, 44.110020473599434, 40.0456103682518, 41.978642642498016, 41.85653239488602, 40.59618942439556, 38.9050217717886, 39.73562300205231, 39.251217395067215, 40.03828816115856, 42.4909083545208, 43.43059793114662, 39.57558698952198, 42.18384303152561, 39.35117483139038, 37.672174125909805, 38.128510639071465, 35.30921012163162, 32.50924676656723, 34.20004963874817, 38.08734364807606, 44.24649775028229, 50.26854760944843, 52.91872300207615, 55.532967522740364, 56.82901717722416, 57.22336381673813, 53.888419568538666, 48.6000457406044, 47.47363418340683, 51.03101849555969, 51.76652982831001, 55.37636272609234, 52.031770795583725, 52.68911652266979, 48.083573654294014, 44.932999312877655, 44.48904253542423, 49.01581183075905, 54.044857174158096, 54.717098101973534, 57.87054508924484, 57.73281767964363, 55.59859000146389, 56.12053379416466, 52.00853884220123, 53.716896772384644, 51.79581865668297, 49.87558029592037, 47.36983895301819, 46.61741092801094, 47.244441881775856, 49.302107468247414, 53.565596491098404, 58.45226727426052, 62.36209787428379, 63.2181653380394, 63.97392958402634, 64.67276528477669, 66.30543887615204, 64.47566226124763, 65.06456226110458, 65.29074892401695, 64.83696207404137, 59.48326975107193, 27.093591168522835, 0.058255178737454116, 0.09048663006979041, 14.590194895863533, 63.67192558944225, 51.00159287452698, 31.64881143718958, 37.508019134402275, 40.13751223683357, 41.17995969951153, 29.59939330816269, 52.84426599740982, 35.07287800312042, 34.484243988990784, 63.28580550849438, 46.05051554739475, 5.98644339479506, 0.06001972760714125, 0.156440737482626, 0.07472532815882005, 0.0702525005908683, 0.027934358768106904, 0.08786249978584237, 0.061846193857491016, 0.06144465114630293, 0.038373046190827154, 0.29966002504806966, 0.04706459367298521, 13.681463208049536, 54.314623698592186, 28.068844936788082, 10.95717754215002, 20.213418155908585, 36.23030349612236, 61.151585429906845, 36.12897053360939, 40.08189842104912, 48.58431078493595, 45.040172562003136, 72.99839213490486, 69.93137151002884, 66.57341569662094, 3.459140108898282, 0.2723421627888456, 1.0950025613419712, 15.622947178781033, 71.19970545172691, 75.17415538430214, 77.66475453972816, 72.98535883426666, 73.09458017349243, 68.27841460704803, 67.79942750930786, 65.7046227157116, 65.74865475296974, 63.67035247385502, 62.52859354019165, 55.555143132805824, 55.87471358478069, 55.082703083753586, 57.50335179269314, 61.154689863324165, 63.68921846151352, 62.95912563800812, 65.16931504011154, 65.25055468082428, 66.83188542723656, 62.9037132114172, 61.71668730676174, 59.513854309916496, 63.04941639304161, 60.47854654490948, 63.34136612713337, 59.794115871191025, 55.89268662035465, 48.92819993197918, 55.212188735604286, 58.10637563467026, 56.12007021903992, 53.71088549494743, 49.86100807785988, 53.39172162115574, 59.87004719674587, 58.63268539309502, 57.3872946202755, 55.4739984869957, 49.62544731795788, 51.847207099199295, 49.43663164973259, 53.18814754486084, 47.659736797213554, 43.796256110072136, 38.19957062602043, 39.52725738286972, 46.66211552917957, 46.50608450174332, 45.78372806310654, 44.804482609033585, 46.203609332442284, 46.748367100954056, 44.13323722779751, 45.634681060910225, 44.750031530857086, 44.774916395545006, 46.48352511227131, 45.94267353415489, 42.76053808629513, 44.30804304778576, 47.374011129140854, 44.365723952651024, 43.82961831986904, 43.87384794652462, 44.610537216067314, 44.08827044069767, 44.881401881575584, 43.25453817844391, 42.92624719440937, 41.5269760787487, 43.32312449812889, 41.19556926190853, 43.04844103753567, 44.00078393518925, 45.11788219213486, 44.11420784890652, 43.71517226099968, 41.71246312558651, 41.43420785665512, 41.63158446550369, 38.09436947107315, 34.68007408082485, 38.15428465604782, 43.724420964717865, 49.889293760061264, 52.50542677938938, 55.980773493647575, 56.35444164276123, 57.88374938070774, 57.573572024703026, 58.00999380648136, 55.00460967421532, 51.3250695168972, 56.9944678992033, 57.097100391983986, 57.24009431898594, 54.77849140763283, 56.1681604385376, 51.398815959692, 47.58960776031017, 47.86568954586983, 54.41578947007656, 56.4786721765995, 57.896186113357544, 60.950633212924004, 60.686870366334915, 59.725848734378815, 60.907543525099754, 55.702655017375946, 57.087426111102104, 56.34668245911598, 54.41208466887474, 51.32856912910938, 49.996535405516624, 50.363895893096924, 53.41324366629124, 57.818221896886826, 62.9462481290102, 66.14936605095863, 67.6380729675293, 68.71288329362869, 69.6581357717514, 70.069570094347, 71.55932575464249, 69.99000236392021, 71.61128416657448, 68.92583906650543, 66.06251791119576, 34.563728123903275, 0.10935004989732988, 0.1657618599710986, 17.9129645973444, 73.09640407562256, 61.86693124473095, 38.25840666890144, 43.19499537348747, 45.01421995460987, 44.65724050998688, 25.80072194337845, 60.10124959051609, 47.00762718915939, 28.993612714111805, 71.61066100001335, 60.91284044086933, 8.034995645284653, 0.022148768439365085, 0.18212666152976453, 0.12264083125046454, 0.07573418886750005, 0.029494349473679904, 0.19561798602808267, 0.25859654881060123, 0.21718178439186886, 0.09714623287436552, 0.12012762235826813, 0.09638640724006109, 29.1699156537652, 79.32078167796135, 47.2917265444994, 27.781829237937927, 36.02013677358627, 45.896790996193886, 70.5908565223217, 52.09249533712864, 48.63195642828941, 57.79973588883877, 53.659846633672714, 77.74553820490837, 78.35598304867744, 70.55127784609795, 4.150942387059331, 0.5907140462659299, 1.0502339573577046, 18.88610377907753, 72.1344704926014, 73.59862312674522, 76.64649277925491, 73.74176144599915, 74.17127519845963, 67.59590283036232, 68.92813414335251, 65.5564458668232, 67.22575709223747, 63.69912452995777, 64.7468613088131, 55.94807244837284, 56.82502739131451, 56.43122412264347, 58.19654479622841, 63.65112170577049, 65.1577864587307, 63.81265103816986, 66.0724125802517, 67.57301285862923, 68.85957822203636, 63.682903200387955, 63.56738179922104, 62.755437567830086, 64.93558198213577, 62.053360641002655, 65.00136405229568, 61.02187559008598, 58.87439422309399, 51.97629377245903, 59.13040928542614, 63.27166646718979, 63.44933733344078, 56.522316634655, 55.694037079811096, 55.2882644534111, 59.62770000100136, 66.36919185519218, 58.9690737426281, 61.66057571768761, 55.49593850970268, 55.514789298176765, 53.586297780275345, 56.6897888481617, 51.70654624700546, 49.33361537754536, 40.93053348362446, 43.78678321838379, 46.41674369573593, 52.104153111577034, 49.14617903530598, 47.34008654952049, 51.10071815550327, 50.10865978896618, 50.15469811856747, 47.58647672832012, 47.27591559290886, 49.76651094853878, 50.341112315654755, 48.78766067326069, 45.72348989546299, 47.76165492832661, 52.66852542757988, 47.615488171577454, 45.604582875967026, 48.01949389278889, 48.21205995976925, 45.64174488186836, 49.255476370453835, 48.2724729180336, 46.0461001843214, 44.356859028339386, 46.19387425482273, 43.12065616250038, 44.328105971217155, 47.29486137628555, 48.491675555706024, 47.07657068967819, 48.151996582746506, 45.42876251041889, 43.193574249744415, 42.83491149544716, 41.42896793782711, 39.53567773103714, 41.399207934737206, 47.59573683142662, 52.80304580926895, 57.28432014584541, 59.60292913019657, 58.654207438230515, 60.90497866272926, 61.228797286748886, 60.56669421494007, 60.022225230932236, 57.624876871705055, 61.207127049565315, 59.93433214724064, 59.260894283652306, 56.1486104875803, 59.356945529580116, 54.01474379003048, 48.52872736752033, 49.665611162781715, 56.4489159733057, 59.891033470630646, 59.797091111540794, 61.62437506020069, 60.08806049823761, 60.166511088609695, 60.25163792073727, 55.296867191791534, 56.33638121187687, 56.88006363809109, 54.885790050029755, 52.54992999136448, 50.47482334077358, 53.28752361238003, 53.554124906659126, 58.94959598779678, 63.63064080476761, 68.41029793024063, 68.417297154665, 70.02781793475151, 70.03813818097115, 73.50371941924095, 71.9238629937172, 71.25779673457146, 71.80135756731033, 72.82894402742386, 71.06928884983063, 43.83478224277496, 0.4707645467715338, 0.3674273699289188, 20.222338177263737, 81.23524814844131, 66.70289754867554, 45.99829114973545, 46.80050790309906, 56.999540627002716, 56.25907815992832, 40.1594864577055, 65.60527324676514, 51.951720491051674, 49.626078084111214, 90.45643374323845, 78.28179582953453, 7.931663515046239, 0.19934666954213753, 0.18320580362342298, 0.22434079321101308, 0.16063036891864613, 0.13386665348662063], [0.02780852391879307, 0.06698964833049104, 0.0556025165860774, 0.05660176648234483, 0.07870918430853635, 0.3878041327698156, 13.526555970311165, 31.03062640875578, 17.10045039653778, 9.183414671570063, 13.009756151586771, 14.184811748564243, 34.396400302648544, 56.956405341625214, 30.884645842015743, 38.57342876493931, 34.55765224993229, 64.99436482787132, 65.44384270906448, 63.55572782456875, 5.4113195557147264, 0.243001606722828, 1.979353332426399, 6.951956385746598, 61.74043983221054, 68.32403495907784, 71.8821108341217, 69.86720815300941, 68.50775510072708, 67.4314096570015, 64.80506658554077, 64.18992519378662, 60.98717965185642, 60.444868952035904, 57.05540902912617, 53.395388424396515, 49.92224179208279, 49.20729875564575, 47.91787214577198, 54.441236704587936, 54.196765422821045, 56.58827729523182, 57.087281718850136, 57.70565673708916, 58.79535086452961, 60.45186057686806, 60.9726682305336, 52.90576569736004, 54.56148125231266, 60.24226002395153, 60.4717943072319, 57.34487749636173, 50.855752900242805, 49.36204545199871, 53.606296107172966, 54.513216242194176, 58.38556185364723, 52.196662947535515, 49.39242862164974, 56.15608088672161, 56.10164500772953, 54.10723842680454, 52.345512360334396, 47.50521428883076, 46.87327399849892, 45.95581702888012, 47.31590084731579, 47.22074255347252, 51.038317903876305, 38.198149502277374, 37.73709364235401, 31.904608011245728, 58.786067962646484, 46.6012541949749, 37.14132361114025, 41.149523332715034, 42.002763748168945, 42.45493948459625, 39.10134583711624, 42.049790024757385, 39.60752047598362, 40.19211530685425, 40.37004075944424, 43.937676921486855, 40.204358249902725, 44.26897354424, 40.00619128346443, 41.31763771176338, 40.610434859991074, 40.87502606213093, 42.28547237813473, 41.537292525172234, 41.43646493554115, 39.96392235159874, 41.148922964930534, 41.70485973358154, 42.256118953228, 38.219158574938774, 40.12869291007519, 42.86858528852463, 42.28274792432785, 41.99047900736332, 40.70428982377052, 40.51208473742008, 38.815255388617516, 37.745722979307175, 32.25161299109459, 34.18379031121731, 34.75865766406059, 42.39424914121628, 48.847530260682106, 51.03552885353565, 52.04076111316681, 50.89499719440937, 57.36836023628712, 53.78633804619312, 51.51565968990326, 52.67904706299305, 45.70265181362629, 47.86051042377949, 52.40532495081425, 55.498985946178436, 56.76634334027767, 52.85641774535179, 48.42255726456642, 45.606760159134865, 44.50799971818924, 50.05474828183651, 55.87541274726391, 54.5236960798502, 53.260233476758, 58.61794598400593, 56.107283905148506, 56.84672422707081, 50.300131514668465, 46.81188829243183, 46.35953016579151, 48.24999712407589, 47.294853776693344, 46.39444649219513, 46.28715164959431, 54.745053201913834, 58.32784295082092, 61.455223336815834, 63.414637595415115, 63.36141385138035, 60.54986111819744, 62.84373342990875, 63.82215812802315, 64.7417163848877, 65.59890478849411, 67.49333873391151, 59.64340075850487, 61.62032827734947, 20.470818243920803, 0.20800575177418068, 0.15172334999078885, 17.768040373921394, 69.09668549895287, 48.827832117676735, 35.96687123179436, 38.065012246370316, 39.86597500741482, 44.03150148689747, 35.395385697484016, 47.552084773778915, 35.44714272022247, 42.66161039471626, 75.85991978645325, 25.516839176416397, 0.15419410803588107, 0.17507826240034774, 0.136270321381744, 0.08881900939741172, 0.04789883074408863, 0.010621739074849756, 0.042971760558430105, 0.17582085536560044, 0.06428762964787893, 0.19395936018554494, 0.03680000481836032, 0.4868204070953652, 15.354066006839275, 51.68430984020233, 31.423470228910446, 13.51855169981718, 17.389204502105713, 22.775048799812794, 47.16611668467522, 63.017099127173424, 38.67296442389488, 45.51926985383034, 39.80162926018238, 76.01686656475067, 69.13769289851189, 70.83386868238449, 7.5982247572392225, 0.12986239569727331, 2.1544340439140797, 9.366460349410772, 69.07830968499184, 73.70586857199669, 76.44080981612206, 73.18207427859306, 72.29830250144005, 69.9836491048336, 70.04370868206024, 66.94848597049713, 64.60144311189651, 63.05411674082279, 62.69543118774891, 57.846355587244034, 55.22412769496441, 54.757831916213036, 54.14224214851856, 56.238559260964394, 59.6919621527195, 60.84512807428837, 62.138700261712074, 62.63683833181858, 63.41508977115154, 63.9838470518589, 65.24939954280853, 56.47616811096668, 58.64314243197441, 63.04180920124054, 62.52639725804329, 59.55191686749458, 54.74859081208706, 49.39194604754448, 54.61601212620735, 60.03773979842663, 59.03560817241669, 54.40228879451752, 55.13983681797981, 59.6463456004858, 55.872802287340164, 57.0995132625103, 54.30360808968544, 49.286562502384186, 51.050367057323456, 48.049694672226906, 48.00785891711712, 49.122954681515694, 54.372384399175644, 40.806112959980965, 41.40887461602688, 37.42210954427719, 59.920736476778984, 51.116738095879555, 41.372495368123055, 44.337700456380844, 46.05297401547432, 46.40001319348812, 42.58109271526337, 44.389263689517975, 43.682376220822334, 43.85260708630085, 45.692992731928825, 46.494479924440384, 44.16985586285591, 47.34687678515911, 43.84912267327309, 44.984767735004425, 43.74694235622883, 46.22707687318325, 43.820540606975555, 42.8068196028471, 45.612497851252556, 42.916192933917046, 43.642022386193275, 43.90578143298626, 43.70626553893089, 41.31479166448116, 42.175768464803696, 44.34952162206173, 46.163494884967804, 43.949623480439186, 43.93492206931114, 44.56031911075115, 43.28705683350563, 40.57131975889206, 36.738997399806976, 37.963113114237785, 38.30684646964073, 47.31450252234936, 52.692266553640366, 52.85547539591789, 54.06513288617134, 53.065379932522774, 59.22117501497269, 59.670094326138496, 54.26701605319977, 57.12533287703991, 52.98721432685852, 52.45640940964222, 55.72317011654377, 57.132582888007164, 58.42824496328831, 55.66270016133785, 51.624003276228905, 47.17166058719158, 47.31270141899586, 53.32383066415787, 58.21987934410572, 57.97672279179096, 57.04635411500931, 60.52743472158909, 59.5858908444643, 61.42605610191822, 52.30480134487152, 51.21395967900753, 48.954505920410156, 53.596374839544296, 50.01384347677231, 48.90508197247982, 49.84204709529877, 59.65821996331215, 61.47635020315647, 65.2582910656929, 66.46812334656715, 67.5952872633934, 65.16246780753136, 68.86467754840851, 68.82690757513046, 69.33886930346489, 67.59913265705109, 74.3584531545639, 61.41899228096008, 68.97196859121323, 23.684507198631763, 0.061108703157515265, 0.16302492324030027, 23.103847056627274, 76.88820540904999, 59.19456124305725, 39.99874368309975, 41.45248107612133, 41.393591836094856, 53.54977034032345, 30.702500715851784, 66.35487422347069, 34.913012981414795, 41.978923827409744, 84.73333284258842, 33.440413400530815, 0.18629843689268455, 0.25875032180920243, 0.05007878935430199, 0.12724531581625342, 0.07613880778080784, 0.13021168007981032, 0.08894256214261986, 0.2754104387713596, 0.1436837829533033, 0.3396058565704152, 0.14296229666797444, 0.6033766292966902, 14.12874385714531, 65.52205011248589, 53.738198429346085, 28.481546491384506, 42.70804390311241, 32.767819091677666, 51.75738371908665, 74.63296562433243, 46.41626872122288, 51.383966356515884, 47.31643661856651, 79.92875665426254, 77.6661604642868, 80.04750788211823, 8.790832087397575, 0.28158849163446575, 2.495383098721504, 13.89493765309453, 72.96297043561935, 71.66313618421555, 76.67801588773727, 72.35660657286644, 72.05785900354385, 72.03734010457993, 69.10290956497192, 66.76221996545792, 65.50715491175652, 64.27184119820595, 63.59310641884804, 58.15962977707386, 55.47198839485645, 55.12754067778587, 53.02333898842335, 57.97353856265545, 60.59303060173988, 61.811241433024406, 62.90139153599739, 63.80610018968582, 65.12418106198311, 64.93872061371803, 68.0226731300354, 57.703897431492805, 57.27111205458641, 64.14409205317497, 66.24664083123207, 62.65856556594372, 55.84566414356232, 53.459821566939354, 57.21530444920063, 62.138255685567856, 62.587072402238846, 58.44260059297085, 54.53370854258537, 59.540445283055305, 60.77723331749439, 60.847347155213356, 55.27639389038086, 55.70745415985584, 55.0163434445858, 53.45264755189419, 53.335936814546585, 55.83481952548027, 54.90476243197918, 48.72620277106762, 47.2724349796772, 42.03961417078972, 59.61491748690605, 53.29038865864277, 46.08035534620285, 50.81941545009613, 50.2462238073349, 49.889293760061264, 45.65651088953018, 48.1234373152256, 46.7309146374464, 45.800849944353104, 46.85900576412678, 49.018707275390625, 47.58505940437317, 52.98837326467037, 42.911355793476105, 50.26586875319481, 47.4511431902647, 46.34265527129173, 46.00394144654274, 47.19024918973446, 47.47280962765217, 46.82739146053791, 45.93962609767914, 48.25342074036598, 47.92160354554653, 44.63392876088619, 44.78285796940327, 46.191769167780876, 48.76662500202656, 47.40505926311016, 49.137808084487915, 45.97470581531525, 46.590394377708435, 44.08352069556713, 38.947313502430916, 42.68597088754177, 42.935203313827515, 50.62759034335613, 57.25871331989765, 56.6630382835865, 58.22261519730091, 55.42851872742176, 61.731164529919624, 60.33085986971855, 57.54146754741669, 60.548561587929726, 55.153816267848015, 54.79782857000828, 57.46271297335625, 58.427625596523285, 59.02157552540302, 56.82520218193531, 53.68279740214348, 48.750004693865776, 48.589691296219826, 53.48845303058624, 60.38746543228626, 57.11973957717419, 56.210699155926704, 61.733831986784935, 59.91865798830986, 62.126077339053154, 56.05190187692642, 52.05381341278553, 49.594649970531464, 53.30709256231785, 53.17343853414059, 50.1184556633234, 51.50708734989166, 60.96206679940224, 64.20900776982307, 67.43159964680672, 70.32496199011803, 67.15213224291801, 66.95357009768486, 67.21980661153793, 70.7125335931778, 71.15667656064034, 71.18626177310944, 77.036222666502, 63.00026223063469, 72.27018401026726, 29.95417647063732, 0.23784206248819828, 0.26580865087453276, 24.591334238648415, 85.69062307476997, 63.78365859389305, 50.05066730082035, 48.34585838019848, 55.54554104804993, 59.681299924850464, 42.592822685837746, 61.54117092490196, 52.2264913469553, 57.34971463680267, 93.64471346139908, 38.945725187659264, 0.27284047042485327, 0.38096111558843404, 0.12334894403466024, 0.17261841392610222, 0.14232513320166618, 0.27062958281021565], [0.03632618434494361, 0.03743658569874242, 0.047151206017588265, 0.14698899700306356, 0.146523863368202, 0.44829994440078735, 2.5046284776180983, 21.378591433167458, 19.80783361941576, 10.64019475132227, 10.342681165784597, 40.081176459789276, 36.69586591422558, 48.24379205703735, 31.59676942974329, 36.66697606444359, 41.17301747202873, 60.07462441921234, 59.8684398829937, 64.81618478894234, 13.07826742529869, 0.15170749771641567, 3.253958481363952, 6.184002393856645, 59.86642599105835, 68.54455232620239, 74.42292049527168, 70.04595056176186, 69.12796542048454, 63.364567682147026, 66.84757858514786, 62.35437668859959, 61.13366179168224, 60.78074432909489, 57.45343007147312, 54.2333422601223, 53.69532532989979, 50.4654910415411, 48.387857526540756, 49.92214299738407, 52.03321471810341, 51.80801220238209, 52.8211784362793, 54.47105370461941, 55.86472772061825, 58.9288567006588, 59.22372467815876, 58.415029272437096, 54.826501831412315, 59.87595587968826, 60.605345740914345, 55.56468442082405, 50.896528512239456, 50.030965358018875, 49.686388447880745, 54.83670048415661, 57.43375092744827, 58.37634354829788, 61.88420511782169, 56.61525584757328, 53.38710106909275, 54.43766489624977, 50.255882889032364, 44.9968358874321, 43.02662640810013, 42.04333037137985, 46.0099109262228, 46.02857552468777, 48.585386127233505, 43.906351402401924, 31.409034803509712, 35.94395086169243, 55.3095319122076, 48.02795223891735, 37.74507321417332, 40.79062879085541, 41.29562929272652, 46.1417106539011, 40.41132174432278, 40.16928233206272, 40.57440139353275, 41.594137474894524, 44.31388333439827, 43.45857962965965, 43.62146928906441, 46.491926461458206, 43.857242837548256, 46.4384975284338, 40.25941349565983, 45.99251925945282, 43.600502014160156, 41.83291666209698, 44.23912614583969, 43.624452129006386, 40.89396044611931, 43.206926733255386, 38.66171322762966, 41.45643286406994, 41.781832203269005, 41.370789259672165, 37.25257024168968, 40.47328121960163, 38.11496816575527, 44.2302992194891, 43.18449653685093, 33.25113035738468, 33.257411420345306, 32.99813613295555, 42.14211747050285, 48.299918845295906, 50.395092219114304, 49.26489606499672, 47.30012409389019, 49.46397118270397, 52.3436276614666, 54.90820124745369, 55.42672522366047, 54.16351340711117, 54.48309525847435, 44.088813811540604, 52.6017440110445, 55.514850094914436, 53.88577491044998, 56.09211891889572, 49.13542941212654, 46.04733131825924, 43.11814829707146, 50.304410085082054, 57.54506215453148, 55.1539758592844, 55.64913868904114, 58.19031313061714, 55.256691947579384, 55.60886465013027, 48.86636205017567, 47.39445023238659, 49.57782827317715, 46.46286562085152, 45.69762848317623, 44.72058691084385, 51.07536591589451, 53.68827670812607, 57.11980037391186, 61.50240160524845, 62.277430817484856, 61.69832669198513, 62.207088991999626, 60.71770951151848, 59.69171516597271, 62.052049711346626, 61.65863782167435, 62.37022943794727, 60.340990126132965, 67.61853441596031, 24.922988042235374, 0.07490242685889825, 0.4453867475967854, 21.403320506215096, 75.88531762361526, 43.5908467322588, 53.366669565439224, 42.11965687572956, 47.3465272039175, 27.187233343720436, 26.0396721214056, 49.53205592930317, 41.378628239035606, 55.30313305556774, 70.26895299553871, 2.652731230482459, 0.173618606349919, 0.0717829872155562, 0.021824845098308288, 0.021277186497172806, 0.08842628711136058, 0.060054619680158794, 0.049228121133637615, 0.06398297060513869, 0.04568215437757317, 0.10968364527798258, 0.07737193809589371, 0.4163330316077918, 3.46920576877892, 32.5127387791872, 29.69286449253559, 16.40804585069418, 17.178701497614384, 43.01095984876156, 41.39649488031864, 65.4041500389576, 35.43678067624569, 48.69646556675434, 47.00479254126549, 71.98662042617798, 66.98331490159035, 76.61988660693169, 14.21242106705904, 0.028132376755820587, 3.569461964070797, 11.98572725057602, 69.24813777208328, 73.59398737549782, 77.53288641571999, 71.94191202521324, 73.87964084744453, 69.43958669900894, 72.69919618964195, 66.72903254628181, 67.01966375112534, 62.715836092829704, 61.57519429922104, 58.47316235303879, 56.19272232055664, 55.28914600610733, 51.953016221523285, 54.56438049674034, 54.071721732616425, 55.32927565276623, 56.427652314305305, 57.71688133478165, 59.34161335229874, 63.489729166030884, 63.150813952088356, 62.21048600971699, 59.13420528173447, 63.33300277590752, 63.52897346019745, 57.91934587061405, 53.17677855491638, 52.259055599570274, 51.537770703434944, 57.395369186997414, 58.023733869194984, 62.10763692855835, 61.65024787187576, 56.86526723206043, 57.60633006691933, 56.27602905035019, 51.95642463862896, 45.68605050444603, 47.116130366921425, 46.038082614541054, 50.7279809564352, 51.38026535511017, 51.703282222151756, 49.988354444503784, 38.521622344851494, 37.522272169589996, 51.86108775436878, 52.32540383934975, 41.54250204563141, 45.768445283174515, 44.90704670548439, 47.709894105792046, 41.49224974215031, 42.32445828616619, 43.88520933687687, 44.961828365921974, 45.55116534233093, 43.676186352968216, 46.21508851647377, 48.213830664753914, 47.19948269426823, 48.241736367344856, 43.09549771249294, 48.107352778315544, 44.1436068713665, 43.69859755039215, 46.63810841739178, 44.675468131899834, 41.4165236055851, 45.174046978354454, 39.3243482708931, 42.497269213199615, 43.541255593299866, 45.84988251328468, 41.58549673855305, 43.03651727735996, 41.26750700175762, 46.79744906723499, 46.16265892982483, 34.45099197328091, 35.78019864857197, 39.326635748147964, 47.109613716602325, 51.047460213303566, 52.95719213783741, 52.24487856030464, 50.09394317865372, 51.840853840112686, 51.9639178365469, 57.10888735949993, 58.88199761509895, 58.69021050632, 57.45166316628456, 52.06238575279713, 56.37753680348396, 59.27799716591835, 57.38401539623737, 59.000824838876724, 51.68037325143814, 48.587726801633835, 46.888005807995796, 53.024855107069016, 59.981149435043335, 58.816614523530006, 57.82579869031906, 60.510658621788025, 60.03211610019207, 59.425984025001526, 51.63340777158737, 48.574298322200775, 52.25953437387943, 50.95981411635876, 48.992431685328484, 49.41539078950882, 55.04068873822689, 59.735428020358086, 62.21429340541363, 66.10370010137558, 64.05363410711288, 65.73570504784584, 65.10321378707886, 65.46075940132141, 63.61514903604984, 67.32612490653992, 67.39718869328499, 70.61071425676346, 66.89227938652039, 72.33251586556435, 28.447834700345993, 0.05120738074765541, 0.3436013124883175, 26.87521878629923, 83.0272775888443, 53.840089961886406, 58.4087710082531, 39.62303884327412, 46.15201950073242, 38.46157796680927, 26.30710557103157, 63.561571910977364, 34.21881303191185, 63.16572815179825, 79.5869117975235, 3.79915417637676, 0.13993954402394593, 0.03611691725382116, 0.09044091377290897, 0.04985354382370133, 0.04821517490199767, 0.03323305383673869, 0.09738877415657043, 0.10485425285878591, 0.11161334798089229, 0.21847656491445377, 0.21070592250907794, 0.40305835485924035, 1.7157480586320162, 36.23261757194996, 44.2977038025856, 29.293093644082546, 45.450554341077805, 63.92912998795509, 46.96484908461571, 72.9701216518879, 49.0582175552845, 51.32965587079525, 53.882708474993706, 74.66162368655205, 72.73460268974304, 81.22998163104057, 17.182938270270824, 0.2894245320931077, 4.08315259963274, 16.485117115080357, 73.6041784286499, 73.46801653504372, 79.43975329399109, 72.78885617852211, 74.90466624498367, 67.32917994260788, 74.6273647248745, 67.03088074922562, 67.17556938529015, 64.06254082918167, 62.8006399422884, 59.458791464567184, 59.53690767288208, 56.89079426229, 53.98502558469772, 55.186084136366844, 58.01974408328533, 56.98233135044575, 59.148405119776726, 60.932618379592896, 61.82051293551922, 66.29848524928093, 64.90472763776779, 62.34859719872475, 60.41155233979225, 65.03549382090569, 66.63655310869217, 59.46170210838318, 54.11791205406189, 56.39036111533642, 54.84804667532444, 60.47733820974827, 62.70081169903278, 64.843680113554, 62.60010950267315, 61.21864803135395, 58.18418025970459, 62.53889478743076, 55.719058737158775, 49.53857257962227, 48.878726586699486, 47.139575108885765, 53.61442007124424, 58.13478671014309, 55.775637701153755, 50.57872876524925, 42.91086181998253, 42.34991692006588, 59.95099425315857, 54.285114482045174, 44.86488036811352, 47.51799680292606, 48.40232715010643, 51.622057780623436, 46.00016824901104, 44.614112824201584, 44.9541337788105, 49.415918961167336, 51.462272554636, 47.580940425395966, 50.340340957045555, 51.37033648788929, 49.38661113381386, 50.834177657961845, 46.34557731449604, 49.9658140540123, 49.87999565899372, 45.37318669259548, 50.70338487625122, 47.863071486353874, 43.69322843849659, 49.38591197133064, 42.62274608016014, 45.06109803915024, 47.53520607948303, 49.48805809020996, 45.86093991994858, 44.81820747256279, 44.43534001708031, 49.311591759324074, 48.32519508898258, 41.27208575606346, 39.64141845703125, 44.84473004937172, 51.40048027038574, 53.27837370336056, 56.083915159106255, 57.88271963596344, 52.83302620053291, 54.15350094437599, 56.63069061934948, 60.49695275723934, 61.552372723817825, 61.684677824378014, 59.54654015600681, 47.53934025764465, 56.87575466930866, 60.37133529782295, 58.46667230129242, 62.51062050461769, 54.090785309672356, 52.174092158675194, 48.80168952047825, 56.84940308332443, 63.09407539665699, 61.278608813881874, 58.17703664302826, 61.454049199819565, 61.14610232412815, 60.07912717759609, 53.53707902133465, 50.197263434529305, 54.234444200992584, 51.46610274910927, 49.59029920399189, 48.83969888091087, 56.723641231656075, 59.722265526652336, 64.16131272912025, 69.71548989415169, 66.15625888109207, 67.28935807943344, 68.39490875601768, 67.18911945819855, 66.05101212859154, 70.0742894411087, 70.50490513443947, 72.61152729392052, 67.24100187420845, 72.64783054590225, 30.839025489985943, 0.17787566932383925, 0.5544626258779317, 27.892063222825527, 91.26036420464516, 56.334200128912926, 74.42618072032928, 54.95433837175369, 63.730469048023224, 40.175441801548004, 34.20048661530018, 67.57941171526909, 52.797851487994194, 75.54832130670547, 95.18228575587273, 5.198121070861816, 0.2842438069637865, 0.16446507564978674, 0.2516177186043933, 0.192908835306298, 0.1742346482933499, 0.20409108605235815], [0.03693492355523631, 0.04577770218020305, 0.06539833528222516, 0.06036152000888251, 0.07994233688805252, 0.0419512147345813, 0.15739108726847917, 6.457053842023015, 6.551237963140011, 6.394098345190287, 4.489394975826144, 17.047315947711468, 15.722658578306437, 47.93230377137661, 41.01780340075493, 30.58108013123274, 38.89904849231243, 55.22188201546669, 58.73707719147205, 60.66787898540497, 17.704847864806652, 0.20818195247557014, 4.1445316560566425, 7.693129414692521, 51.01064018905163, 67.82386019825935, 74.6400636434555, 67.22217008471489, 69.24898132681847, 68.98863449692726, 69.98686373233795, 65.49715384840965, 65.6770969927311, 63.72318483889103, 62.05826237797737, 60.6332628428936, 53.54052923619747, 50.36350451409817, 49.889886528253555, 48.627199083566666, 50.72931468486786, 49.65656764805317, 49.488525465130806, 48.36027480661869, 52.03058525919914, 55.24908095598221, 61.639547646045685, 57.92976871132851, 58.15251275897026, 61.301008611917496, 58.482034876942635, 55.703289583325386, 49.71725419163704, 48.463454470038414, 51.57392576336861, 54.939994141459465, 58.84003646671772, 57.66488492488861, 55.05825899541378, 57.474416345357895, 56.61070369184017, 51.95750758051872, 51.66804291307926, 44.57804895937443, 41.81900180876255, 42.49710202217102, 47.36934117972851, 47.60782018303871, 48.52926693856716, 46.12179972231388, 38.48370797932148, 33.35776403546333, 45.94118021428585, 45.3163493424654, 36.86835005879402, 41.86094015836716, 40.61237655580044, 41.822676211595535, 40.62353655695915, 40.23270092904568, 40.97959265112877, 40.14103464782238, 42.013490572571754, 38.51843051612377, 42.78243251144886, 43.78316581249237, 41.95326380431652, 46.98829382658005, 43.11162404716015, 42.999165281653404, 41.945747807621956, 40.97189426422119, 39.488811045885086, 42.021842524409294, 39.4895938038826, 42.16740131378174, 39.59014020860195, 39.3921822309494, 38.511024713516235, 40.46890765428543, 39.590759575366974, 44.42685887217522, 40.0155083835125, 46.04577340185642, 45.571661442518234, 31.26827135682106, 32.27754279971123, 35.59230633080006, 43.74543383717537, 48.4275121986866, 47.616973891854286, 45.78766085207462, 45.76442889869213, 46.56813137233257, 51.268030777573586, 51.09648518264294, 59.875442907214165, 55.484193339943886, 58.42897452414036, 53.37949387729168, 54.39329847693443, 57.49104805290699, 56.98894299566746, 56.65613405406475, 52.49571830034256, 45.333984196186066, 43.419004753232, 47.45210453867912, 58.57848510146141, 55.40387324988842, 56.328701823949814, 55.91628335416317, 58.48377138376236, 55.732813999056816, 48.222167417407036, 45.34949876368046, 45.3759453445673, 47.02762931585312, 47.069028094410896, 45.622719302773476, 50.73156416416168, 54.74388666450977, 58.64242427051067, 60.2432631701231, 64.72271740436554, 60.78313820064068, 59.38779227435589, 60.99028408527374, 60.80181419849396, 61.25262200832367, 67.82848075032234, 65.92498809099197, 69.29856106638908, 71.19287341833115, 34.83587332069874, 0.18039339047390968, 0.3719567268854007, 28.70635762810707, 72.70367234945297, 42.880623042583466, 47.15088710188866, 41.111817955970764, 44.72931504249573, 32.66808584332466, 30.156202130019665, 39.348442777991295, 46.258542984724045, 75.36688104271889, 27.78558723628521, 0.1691350547480397, 0.08232484615291469, 0.06913741628522985, 0.21266526659019291, 0.05870629320270382, 0.055932208269950934, 0.03282570010924246, 0.10996906785294414, 0.07381619725492783, 0.033361404566676356, 0.0294585185838514, 0.0837005653011147, 0.0656536192400381, 0.15435423381859437, 10.746586192399263, 11.630840543657541, 13.85361772030592, 18.002265505492687, 24.930808022618294, 20.04401184618473, 69.13140043616295, 45.422059670090675, 39.166493341326714, 46.973543018102646, 65.19421130418777, 65.02154096961021, 70.05715996026993, 20.322476103901863, 0.11362630481016822, 5.356900300830603, 14.632458128035069, 62.581995874643326, 72.01595485210419, 77.46021151542664, 73.87375876307487, 74.16641145944595, 70.68341955542564, 72.86615923047066, 69.42530706524849, 70.26252374053001, 68.41011554002762, 65.7213494181633, 62.314972802996635, 58.32914248108864, 54.54378940165043, 52.88988634943962, 53.072386756539345, 51.95207767188549, 53.839892372488976, 53.254275396466255, 52.48298138380051, 55.1762692630291, 59.68855373561382, 62.68789239227772, 62.2867327183485, 61.21048986911774, 66.46392077207565, 61.35019317269325, 56.663528457283974, 53.256574273109436, 49.60072964429855, 53.96092347800732, 57.00023978948593, 60.665226727724075, 59.219081327319145, 57.13302366435528, 59.61834490299225, 57.94493369758129, 56.517528891563416, 53.14351134002209, 48.387770131230354, 44.61294628679752, 44.493142515420914, 49.86894205212593, 52.36165389418602, 52.7634671330452, 51.51836134493351, 44.568272083997726, 37.61829301714897, 46.375363916158676, 48.13352197408676, 39.51201640069485, 44.75086368620396, 43.4780877828598, 44.31303218007088, 42.884567230939865, 43.47696304321289, 44.750571101903915, 41.849206387996674, 43.94222907721996, 42.17644102871418, 43.746664971113205, 45.66029168665409, 46.070361882448196, 49.52324040234089, 48.644571751356125, 45.05828998982906, 43.63747403025627, 43.878818079829216, 43.41048941016197, 44.78479966521263, 43.677136301994324, 42.08700142800808, 42.30210788547993, 42.53320388495922, 41.043638214468956, 41.742352321743965, 43.16601812839508, 46.41126058995724, 42.55897790193558, 47.868972569704056, 47.30936139822006, 34.68432605266571, 37.995646968483925, 39.51855964958668, 47.43995659053326, 52.121339589357376, 49.17551726102829, 49.90589886903763, 48.39820817112923, 49.009352177381516, 51.34203180670738, 53.37100513279438, 60.53732939064503, 58.20479415357113, 59.9456175416708, 57.03152351081371, 56.93897947669029, 59.472048953175545, 59.839177653193474, 57.833527475595474, 54.812377989292145, 47.92330205440521, 47.737017050385475, 51.61292307078838, 61.893210634589195, 58.88498045504093, 58.73116470873356, 58.74900855123997, 62.28814244270325, 57.47014157474041, 51.67873173952103, 48.36423419415951, 47.96257294714451, 49.449687749147415, 49.95303153991699, 50.14526702463627, 55.878900960087776, 59.739638194441795, 62.909146919846535, 64.41588386893272, 66.30166947841644, 64.21551302075386, 66.32632255554199, 68.78992795944214, 67.51432120800018, 66.8838058412075, 73.77038910984993, 71.55585274100304, 73.09567451477051, 77.38976329565048, 40.96995636820793, 0.5839853791985661, 0.2947605145163834, 34.864546582102776, 82.7514199912548, 49.61907505989075, 58.390512987971306, 33.99549521505833, 49.66396205127239, 43.417009860277176, 31.342262886464596, 42.65241488814354, 37.71087884902954, 88.87568816542625, 27.646277211606503, 0.25520938681438565, 0.1296658898354508, 0.026907246792688966, 0.20051261322805658, 0.06042659893864766, 0.02268534492031904, 0.0893464166438207, 0.2699743554694578, 0.17768069228623062, 0.1350880356039852, 0.15833698416827247, 0.30042322003282607, 0.09453850405407138, 0.28836329060140997, 7.65793570317328, 18.445625714957714, 19.148027524352074, 38.922409638762474, 44.823492988944054, 24.990029744803905, 67.11879283189774, 61.73228166997433, 44.2608267813921, 54.90444324910641, 70.0701704621315, 69.23738434910774, 78.81569758057594, 22.769227512180805, 0.19404547900194302, 4.989156033843756, 19.026399850845337, 68.88613879680634, 74.34389233589172, 77.60530292987823, 72.05392241477966, 75.32531887292862, 72.93124973773956, 72.48969063162804, 71.08681350946426, 68.94794628024101, 69.28625732660294, 66.25500038266182, 64.81955140829086, 59.728747978806496, 54.26568232476711, 55.30312925577164, 54.36674550175667, 52.377274855971336, 55.68969011306763, 55.55621847510338, 52.89709836244583, 58.67265164852142, 60.805636793375015, 64.8794361948967, 64.51604649424553, 64.01054441928864, 67.07644790410995, 63.56835834681988, 59.4193609803915, 55.4740022867918, 52.62779541313648, 56.706431955099106, 60.79318106174469, 66.23553782701492, 59.772567227482796, 59.38358969986439, 63.76073822379112, 62.807342782616615, 58.47881264984608, 56.930243745446205, 50.09119212627411, 48.99321064352989, 48.289138823747635, 55.65618351101875, 54.31251481175423, 58.28195281326771, 52.946100533008575, 46.1048374325037, 43.24310839176178, 54.95684623718262, 53.23802746832371, 44.284518510103226, 47.079230546951294, 46.014098301529884, 47.75888107717037, 45.1859213411808, 46.52091510593891, 48.07329140603542, 44.660420939326286, 47.09431953728199, 43.74614059925079, 48.65581154823303, 50.2866118401289, 47.08526462316513, 51.43822744488716, 51.139624267816544, 47.771720588207245, 47.6313941180706, 45.639115422964096, 45.97926937043667, 46.91608250141144, 44.734501764178276, 45.541639253497124, 45.26315979659557, 46.23072847723961, 45.20100653171539, 45.383358746767044, 45.47855883836746, 50.063028037548065, 46.587924510240555, 51.56484045088291, 52.36855812370777, 38.67235645651817, 43.13168317079544, 43.99380750954151, 51.77328206598759, 56.26543901860714, 52.11535111069679, 50.413194447755814, 51.90997213125229, 51.894609555602074, 53.385235369205475, 54.80870358645916, 62.686980441212654, 58.84875699877739, 61.66955083608627, 56.5308927744627, 58.768026530742645, 62.41288974881172, 61.92153051495552, 61.219491586089134, 54.46938939392567, 50.951587557792664, 48.80039379000664, 52.35979959368706, 64.40273657441139, 60.37663221359253, 60.80813705921173, 60.13620391488075, 62.982182800769806, 60.45861281454563, 52.713651806116104, 51.342377588152885, 47.3243173956871, 53.23298893868923, 50.86438983678818, 52.35328674316406, 56.976996436715126, 62.90423758327961, 65.76540425419807, 67.89528116583824, 69.61541846394539, 66.44097000360489, 67.12388455867767, 71.40373930335045, 70.36144763231277, 72.03057646751404, 75.62024384737015, 74.46317553520203, 73.5577829182148, 78.40172499418259, 37.966646924614906, 0.5006228992715478, 0.5261008883826435, 39.280605018138885, 86.536336094141, 57.66779936850071, 63.38496878743172, 54.49263274669647, 58.318301662802696, 50.79050660133362, 37.73161433637142, 60.28028458356857, 53.82951132953167, 102.46404021978378, 32.15233951807022, 0.2531677682418376, 0.30833270342554897, 0.16192221053643152, 0.36982521938625723, 0.14187349181156605, 0.16244293103227392, 0.1313467652653344], [0.07567421591375023, 0.05797186757263262, 0.022141482404549606, 0.10504977908567525, 0.03835146453639027, 0.07688525249250233, 0.08958143254858442, 0.28936907881870866, 5.291496310383081, 6.788230296224356, 6.805858500301838, 32.25357748568058, 22.312837801873684, 27.190010994672775, 48.10789234936237, 32.520330771803856, 30.108163207769394, 47.85745158791542, 63.48715290427208, 59.05781038105488, 14.55094300210476, 0.5616514245048165, 5.4723333567380905, 13.827105592936277, 35.69296672940254, 62.85385608673096, 75.7933397591114, 66.78953289985657, 69.73080307245255, 64.83953073620796, 68.04810136556625, 61.9746782630682, 68.63681897521019, 62.45340317487717, 66.87716379761696, 59.84198570251465, 60.314167365431786, 50.42117401957512, 50.45275032520294, 49.08567488193512, 49.48498025536537, 47.63970047235489, 48.21932137012482, 47.83224754035473, 48.564574643969536, 53.46884228289127, 59.25263732671738, 60.40688619017601, 54.50264900922775, 57.64049023389816, 58.15115623176098, 54.15483467280865, 49.183329641819, 45.96905171871185, 49.69668969511986, 54.49029587209225, 54.109461307525635, 56.985295191407204, 58.66207681596279, 57.14682072401047, 55.35468488931656, 55.544819086790085, 48.94121803343296, 44.65627156198025, 41.921797692775726, 41.40336111187935, 42.47728228569031, 47.31978043913841, 50.62469109892845, 45.00760830938816, 39.782227501273155, 32.462866455316544, 33.90496127307415, 40.071125999093056, 39.418340027332306, 41.09095327556133, 43.46275180578232, 46.72659046947956, 42.53802962601185, 41.26246087253094, 40.63486374914646, 42.21022121608257, 42.14133471250534, 40.88454835116863, 40.99036507308483, 42.656313478946686, 45.95402352511883, 46.392675787210464, 45.6666449457407, 42.5527386367321, 42.1163434535265, 42.771143317222595, 42.334615141153336, 42.39839091897011, 39.78867195546627, 41.84998534619808, 40.22212989628315, 41.58067859709263, 40.16602210700512, 43.840314745903015, 42.18056760728359, 43.85936312377453, 37.11909860372543, 42.30749599635601, 39.80591543018818, 29.18122574687004, 36.23018190264702, 39.74938586354256, 40.026843175292015, 47.80585415661335, 44.577763974666595, 43.36697414517403, 42.71231487393379, 44.60489071905613, 46.96989521384239, 49.11424554884434, 53.16428862512112, 56.30188666284084, 57.69940987229347, 54.67063419520855, 59.865650832653046, 51.74124978482723, 54.17249992489815, 55.70855990052223, 53.657661750912666, 45.50948157906532, 44.392478317022324, 49.37298506498337, 54.52096402645111, 54.498758018016815, 55.64932867884636, 55.35930924117565, 56.15828096866608, 55.44639676809311, 46.91550873219967, 44.58799682557583, 46.25588692724705, 47.24984139204025, 45.868277326226234, 45.19171603024006, 50.84470309317112, 54.63982544839382, 58.42461995780468, 59.8119331151247, 59.30400297045708, 59.26787070930004, 63.25860656797886, 62.77557648718357, 64.21826407313347, 63.178871646523476, 63.429327607154846, 64.68659654259682, 63.20648096501827, 68.16287040710449, 44.10787358880043, 3.128922628238797, 1.056353054009378, 37.43312135338783, 68.25144365429878, 44.472084045410156, 49.197396486997604, 32.701687440276146, 44.931901171803474, 30.455466471612453, 41.56411148607731, 45.906624868512154, 60.473109036684036, 63.03811959922314, 1.4342415891587734, 0.08977352263173088, 0.09875863033812493, 0.01083900744561106, 0.02968966047774302, 0.05095659420476295, 0.03688462820718996, 0.03244559062295593, 0.035877437330782413, 0.04426797342603095, 0.039796878772904165, 0.027012694845325314, 0.015279867930075852, 0.04143526624829974, 0.09020760480780154, 0.3582875244319439, 5.943580269813538, 7.012873291969299, 24.791178815066814, 38.22210721671581, 15.576302781701088, 41.40007048845291, 56.322477757930756, 35.75746826827526, 43.539823070168495, 52.09618493914604, 73.35210755467415, 64.48554173111916, 16.125436015427113, 0.3670725639676675, 5.8836503606289625, 17.147121392190456, 49.40239928662777, 67.9328003525734, 79.87346962094307, 71.03905007243156, 71.41061693429947, 69.7977402806282, 73.4040355682373, 67.7751924097538, 72.29941204190254, 67.1491152048111, 69.86587062478065, 64.45587292313576, 64.72729235887527, 54.33363787829876, 56.07615977525711, 51.50130786001682, 53.04200738668442, 50.359643921256065, 50.302601382136345, 50.36180220544338, 51.66467249393463, 56.4903299510479, 63.91217529773712, 63.94391879439354, 60.03469616174698, 59.37773421406746, 59.34587672352791, 56.98161318898201, 51.845774576067924, 48.52231711149216, 52.23185285925865, 57.08931460976601, 57.41858214139938, 58.89485992491245, 62.34711527824402, 59.55223225057125, 60.1668568700552, 55.81656150519848, 50.90202681720257, 45.854085087776184, 44.842685759067535, 44.5657642185688, 47.95974589884281, 51.91222161054611, 53.89023207128048, 50.3448361158371, 43.693901002407074, 36.77629239857197, 37.778025045990944, 43.713933527469635, 42.354662865400314, 43.11910964548588, 47.28147469460964, 48.59414845705032, 47.00089015066624, 45.265158489346504, 43.80898542702198, 43.311269134283066, 43.672876730561256, 43.671976178884506, 45.07261902093887, 44.74158838391304, 48.23192909359932, 48.775318935513496, 46.38745106756687, 43.87949824333191, 45.591994151473045, 44.20307368040085, 42.53403224050999, 43.43984663486481, 43.12662564218044, 43.51959675550461, 41.484452560544014, 42.79794327914715, 42.14446194469929, 46.492010056972504, 44.821555092930794, 46.02938488125801, 38.82104627788067, 47.05219879746437, 41.799900233745575, 33.25966089963913, 41.72275297343731, 44.17182415723801, 46.09329745173454, 51.10345400869846, 47.89221592247486, 45.69989316165447, 44.735649302601814, 46.83800429105759, 50.42973875999451, 50.051803439855576, 55.08770741522312, 57.67540656030178, 61.385174095630646, 58.69326554238796, 62.73184463381767, 55.395217314362526, 56.54496341943741, 58.29733058810234, 57.93697312474251, 48.51466812193394, 47.94000215828419, 52.46058538556099, 56.05710759758949, 59.6751556545496, 57.586305141448975, 59.377669617533684, 61.452369689941406, 58.20746921002865, 48.03732253611088, 47.42569215595722, 50.7671644538641, 49.6826646476984, 50.2199862152338, 49.46629285812378, 55.27624949812889, 57.92295567691326, 63.9292211830616, 64.15000453591347, 64.19106513261795, 64.82660382986069, 67.90234118700027, 67.87494465708733, 69.07422870397568, 69.06294330954552, 70.6626346707344, 70.6952977180481, 71.5991248190403, 73.28731343150139, 51.875770166516304, 5.394549630582333, 1.3944560615345836, 44.13877733051777, 75.36630347371101, 52.52990886569023, 55.04415415227413, 34.42873276770115, 58.747462034225464, 38.66535723209381, 42.006107568740845, 47.05303095281124, 64.63688760995865, 69.93949547410011, 0.7851016998756677, 0.16479077457915992, 0.03288014777353965, 0.07827623761841096, 0.051135748653905466, 0.03162577348120976, 0.02840060376911424, 0.06727331943693571, 0.16467955632833764, 0.11754613587982021, 0.10342286521336064, 0.19326868787175044, 0.08635786958620884, 0.16832988389069214, 0.16233481495874003, 0.2008778983145021, 8.271915782243013, 10.196122080087662, 49.03169497847557, 56.492644026875496, 37.96196937561035, 38.69916781783104, 68.07775497436523, 47.02158384025097, 45.73738195002079, 62.260897904634476, 75.48403635621071, 72.64774695038795, 18.045482486486435, 0.5861941887997091, 5.681540630757809, 17.877409905195236, 60.74106685817242, 72.55231887102127, 79.92694035172462, 74.9996991455555, 72.91765406727791, 70.3149077296257, 73.15941229462624, 67.90512263774872, 72.93743580579758, 67.4712011218071, 70.97152009606361, 66.42723754048347, 64.81305375695229, 55.42807415127754, 57.17792205512524, 52.93616406619549, 55.075893849134445, 52.724226638674736, 52.56172075867653, 52.83631682395935, 52.80125230550766, 57.98217169940472, 63.11302877962589, 65.39332821965218, 60.35854138433933, 61.02922059595585, 62.75432422757149, 60.194903165102005, 53.141923025250435, 50.953791439533234, 53.965886011719704, 59.299412816762924, 58.82660038769245, 62.393966764211655, 65.98267659544945, 63.01191620528698, 61.54555208981037, 61.65461003780365, 55.50870202481747, 48.20837415754795, 47.81612120568752, 47.31723837554455, 50.126028656959534, 55.378931388258934, 57.50258803367615, 55.3653547167778, 45.46248950064182, 42.77796395123005, 47.887450978159904, 46.07806406915188, 46.752448081970215, 47.20331288874149, 50.895369574427605, 51.20486676692963, 50.34016616642475, 46.41001045703888, 46.963363364338875, 46.69581972062588, 44.929028525948524, 45.19806928932667, 47.56806671619415, 48.1893789768219, 53.52078549563885, 50.84032952785492, 49.284161031246185, 47.78018653392792, 49.05936509370804, 48.18775646388531, 44.6515978127718, 47.3059643805027, 45.86170367896557, 46.123612225055695, 44.379008039832115, 45.92375434935093, 45.912731140851974, 49.01749514043331, 48.1130600720644, 49.39015254378319, 40.402513816952705, 48.98364655673504, 46.91531494259834, 37.895453944802284, 45.275364741683006, 47.92193412780762, 49.488662257790565, 56.09748803079128, 51.03959463536739, 50.302734375, 47.88085073232651, 50.778807029128075, 51.13286443054676, 50.97707279026508, 56.4854434132576, 58.8533965498209, 61.81086525321007, 58.28887604176998, 62.77773097157478, 55.04241764545441, 59.168779626488686, 59.19986955821514, 58.8297314196825, 49.61608462035656, 50.38628809154034, 55.2730006724596, 59.05518852174282, 59.52850632369518, 57.45382145047188, 61.08124740421772, 62.25116662681103, 60.94595946371555, 51.36491417884827, 49.16200898587704, 52.38397389650345, 53.787607178092, 51.253804340958595, 50.1340614259243, 55.75330249965191, 60.22845916450024, 66.02120652794838, 66.52340278029442, 65.48745676875114, 67.4628035724163, 69.53724145889282, 72.11067616939545, 71.7731174826622, 72.77346700429916, 71.14741265773773, 73.7718178331852, 72.00212359428406, 77.5364126265049, 50.927903428673744, 4.92759601213038, 1.3664431334473193, 47.77220696210861, 78.74445900321007, 61.6447077691555, 63.41722145676613, 45.240942388772964, 59.77230504155159, 43.633917421102524, 53.397831693291664, 68.15983057022095, 72.33921110630035, 87.9617840051651, 1.8091443157754838, 0.15867644251557067, 0.14119769213721156, 0.13942864956334233, 0.08044172063819133, 0.13898983248509467, 0.09844085754593834, 0.1363306283019483], [0.05527167457330506, 0.06541291848407127, 0.03146122078760527, 0.08293788239825517, 0.008419139394391095, 0.10766790539491922, 0.045474575672415085, 0.12584488315042108, 1.005311580374837, 4.682158632203937, 12.543885000050068, 37.35751301050186, 32.30963967740536, 22.573714703321457, 32.84625828266144, 40.2678794413805, 24.939127676188946, 43.933759331703186, 65.05082219839096, 67.48362645506859, 13.842709455639124, 0.9927343740127981, 6.606671288609505, 20.422106757760048, 20.71253277361393, 56.676778346300125, 68.62877860665321, 66.96276560425758, 66.54151260852814, 67.82182350754738, 60.88444836437702, 62.50748947262764, 64.06193286180496, 63.7494832277298, 62.99202807247639, 64.89928632974625, 62.19941720366478, 55.91601736843586, 50.04883199930191, 49.42853428423405, 47.71329492330551, 46.74141347408295, 48.96280847489834, 48.52968871593475, 47.373266369104385, 56.999077051877975, 58.591222018003464, 59.075232446193695, 54.91486229002476, 56.139156594872475, 56.24557368457317, 52.18889616429806, 49.826369136571884, 48.82778652012348, 51.36893056333065, 54.53892186284065, 58.64957548677921, 56.8853073567152, 58.59361968934536, 57.94926166534424, 56.835951805114746, 51.94274537265301, 46.659911647439, 42.77513690292835, 40.59311918914318, 43.8170599937439, 43.86802665889263, 46.1623777449131, 50.48186436295509, 52.581859678030014, 37.82706141471863, 26.915439628064632, 31.73606615513563, 42.43918173015118, 40.071296989917755, 41.76480531692505, 39.86764311790466, 42.67774812877178, 43.77039469778538, 41.60504288971424, 39.34832498431206, 39.80209283530712, 39.8007021099329, 41.052666530013084, 42.98224098980427, 42.63448365032673, 41.99713245034218, 43.943327218294144, 45.73863208293915, 42.94877998530865, 42.710962146520615, 44.170140847563744, 41.196181029081345, 42.00619116425514, 40.56756176054478, 40.04111520946026, 41.48616626858711, 42.657651007175446, 43.68212543427944, 42.741257920861244, 43.167530447244644, 44.098461493849754, 39.239829406142235, 44.103359431028366, 33.784526735544205, 29.04096007347107, 38.32856610417366, 40.982966870069504, 44.28477689623833, 46.627430990338326, 42.51609720289707, 40.48841580748558, 38.928686901926994, 40.360693261027336, 47.15423472225666, 46.89280495047569, 49.00802984833717, 52.27361261844635, 55.70721097290516, 54.58984673023224, 56.796015948057175, 55.94128981232643, 56.142792999744415, 56.430068984627724, 54.263265654444695, 47.16728322207928, 41.00818991661072, 51.24287232756615, 54.309949949383736, 54.880876913666725, 56.240618750452995, 56.87551908195019, 56.98444023728371, 49.518616050481796, 45.18168456852436, 44.53503146767616, 44.59731772542, 44.51572850346565, 43.93499806523323, 48.479379415512085, 52.40809500217438, 55.3347397595644, 57.00693883001804, 58.5228218883276, 63.70015427470207, 63.18690061569214, 62.82536901533604, 63.13199356198311, 62.99071714282036, 60.972561836242676, 63.77416670322418, 63.65680620074272, 66.5945653617382, 60.448778942227364, 50.48450902104378, 11.758113764226437, 2.4324494507163763, 37.724672108888626, 61.78898222744465, 34.47378695011139, 41.512126475572586, 33.83556179702282, 34.958735927939415, 32.92266458272934, 46.91408760845661, 54.29077237844467, 68.53712752461433, 15.581086724996567, 0.3294199984520674, 0.1802874414715916, 0.06454822738305666, 0.10789755557198077, 0.027063214693043847, 0.05745516580645926, 0.05191870703129098, 0.019724157136806753, 0.017990309061133303, 0.0296724018335226, 0.029552233281719964, 0.07350582367507741, 0.050434612057870254, 0.07779301784466952, 0.08090378920314834, 0.1508048828691244, 0.8538781874813139, 2.8355415584519506, 33.885430321097374, 47.83511258661747, 23.151528798043728, 28.22746552526951, 45.492325499653816, 34.47875328361988, 35.986052602529526, 50.00953070819378, 70.25053918361664, 72.45988503098488, 16.75612047314644, 1.0822738381102681, 6.713200947269797, 21.48353610187769, 28.96288376301527, 67.24716514348984, 70.27300357818604, 71.72739833593369, 67.6933827996254, 71.12640738487244, 64.1485758125782, 64.5196259021759, 68.44862267374992, 67.70854398608208, 66.98234215378761, 67.63030618429184, 66.5020403265953, 60.46477608382702, 52.40329585969448, 51.81387908756733, 50.35699546337128, 51.95329360663891, 53.83150242269039, 53.20165582001209, 50.6159857660532, 61.12381272017956, 61.62611536681652, 61.93117059767246, 56.14517167210579, 60.507649183273315, 57.604331374168396, 53.98880638182163, 52.78368204832077, 51.80085338652134, 53.46604943275452, 56.23596020042896, 62.284787222743034, 59.23920124769211, 60.34909889101982, 59.2778679728508, 59.75199893116951, 53.896984308958054, 48.33106957376003, 46.13471902906895, 45.337027832865715, 44.48124535381794, 46.64125844836235, 48.92570726573467, 55.324727296829224, 57.46637597680092, 43.31671804189682, 32.246069088578224, 34.609340876340866, 44.61165435612202, 42.73563802242279, 44.937065094709396, 44.296446070075035, 45.384988859295845, 48.559444919228554, 43.50292704999447, 42.11789757013321, 41.250309124588966, 43.05552385747433, 44.03842851519585, 46.135034412145615, 45.09876161813736, 45.428249537944794, 46.09955571591854, 48.030125722289085, 44.95617426931858, 45.03288835287094, 46.121195554733276, 44.11300331354141, 46.390000730752945, 40.68689435720444, 42.52883791923523, 42.84726843237877, 43.964252695441246, 44.937099292874336, 45.37861280143261, 44.7364966571331, 45.1455295085907, 40.58883681893349, 48.84896658360958, 37.18644618988037, 33.19322146475315, 42.92113646864891, 45.64395636320114, 50.62485449016094, 49.268897250294685, 46.61242559552193, 41.632264629006386, 43.32206815481186, 44.634145349264145, 49.28759604692459, 49.498522728681564, 52.55323201417923, 54.17647451162338, 57.305355817079544, 56.35391727089882, 60.530691146850586, 57.120776921510696, 58.59046585857868, 56.46290302276611, 57.421507984399796, 49.82748627662659, 46.30311079323292, 53.98859739303589, 58.594721630215645, 57.67947234213352, 58.26617605984211, 60.2595566958189, 60.138916969299316, 54.342252016067505, 48.226290196180344, 47.83396124839783, 48.3493047952652, 49.5286513119936, 49.37067098915577, 51.96752764284611, 56.8811009824276, 59.12962272763252, 62.23454251885414, 65.06361991167068, 68.32675561308861, 67.11548700928688, 67.45193615555763, 67.90138363838196, 69.36239004135132, 67.63844534754753, 68.76006156206131, 68.41829270124435, 75.16730815172195, 66.54965177178383, 57.75458291172981, 14.976168684661388, 2.8681656578555703, 40.895989537239075, 68.50848466157913, 40.99028907716274, 48.73269662261009, 37.01545536518097, 49.79677252471447, 39.103602916002274, 44.0790331363678, 58.63536424934864, 74.28017735481262, 13.23793675750494, 0.23183108191005886, 0.27265226177405566, 0.11817854960099794, 0.1867878981283866, 0.054454822311527096, 0.05691705679055303, 0.09156808024272323, 0.08917054990888573, 0.15618566132616252, 0.17703180288663134, 0.18849608459277079, 0.1847810417530127, 0.1795697698253207, 0.15512611193116754, 0.28807213122490793, 0.4576780489878729, 2.2036121925339103, 5.806374382227659, 64.43677514791489, 56.245626881718636, 55.234706327319145, 31.83670185506344, 48.708260133862495, 55.08998729288578, 37.242257595062256, 62.08648346364498, 74.21428889036179, 82.58744359016418, 19.014058113098145, 1.4703463017940521, 7.400743179023266, 21.057379469275475, 38.627081885933876, 74.7870397567749, 72.62456819415092, 72.96282604336739, 68.30936014652252, 74.21438008546829, 66.30417734384537, 65.26083692908287, 67.69188567996025, 70.64019307494164, 69.28714647889137, 70.3556415438652, 69.0243373811245, 61.154720261693, 52.56656549870968, 53.93905185163021, 52.082973048090935, 51.70448295772076, 54.298406168818474, 53.34753759205341, 52.08181791007519, 63.64430867135525, 62.38572120666504, 63.908816277980804, 58.77595290541649, 61.15854285657406, 60.040730237960815, 58.84145379066467, 54.350938349962234, 53.208047077059746, 58.29529009759426, 56.47563233971596, 65.04585966467857, 61.93216234445572, 63.428666442632675, 63.53426277637482, 63.9197900891304, 60.09181089699268, 49.95162181556225, 47.67655849456787, 47.81856067478657, 48.32198426127434, 51.79233804345131, 52.070684507489204, 58.482327461242676, 58.66871885955334, 46.402684450149536, 38.01384799182415, 42.558290138840675, 48.93862657248974, 45.02578653395176, 50.63998147845268, 46.826350316405296, 49.89314295351505, 51.46277412772179, 47.747797071933746, 44.68061305582523, 44.844331070780754, 46.60230673849583, 45.973014906048775, 50.228022783994675, 48.278658986091614, 47.56569944322109, 48.4897680580616, 51.337874829769135, 46.78068436682224, 46.108150854706764, 49.73350591957569, 46.017324328422546, 48.87079641222954, 42.99560867249966, 43.12259405851364, 46.03618271648884, 46.971346735954285, 48.063989505171776, 48.82991060614586, 47.64684408903122, 49.841898903250694, 44.38400097191334, 52.24420979619026, 42.904341369867325, 40.22819437086582, 46.35245494544506, 48.33721004426479, 53.07460203766823, 54.16064836084843, 49.50615651905537, 43.6839759349823, 44.65763948857784, 45.822881162166595, 50.03851555287838, 49.75893035531044, 52.80088372528553, 56.179810613393784, 59.96639482676983, 56.72890394926071, 61.889566630125046, 58.89840513467789, 61.1662108451128, 60.28928630053997, 56.809315234422684, 51.68709509074688, 46.08534447848797, 57.393518686294556, 59.07039910554886, 59.7007966786623, 61.25346176326275, 62.19629377126694, 60.941004529595375, 55.697126314044, 50.01454643905163, 51.52752265334129, 49.43156272172928, 50.257984176278114, 51.911864429712296, 54.72114108502865, 59.98470604419708, 62.05771900713444, 63.33376653492451, 68.01305204629898, 70.86849242448807, 69.4842267036438, 69.86915364861488, 69.26558643579483, 71.48209869861603, 69.62433278560638, 72.3231303691864, 72.28789865970612, 75.73421493172646, 67.15593203902245, 62.71663784980774, 15.144323911517859, 3.3343996899202466, 43.51164758205414, 76.6466523706913, 47.465278431773186, 59.37989629805088, 41.972631365060806, 49.976768866181374, 47.55814164876938, 63.72234508395195, 72.03255236148834, 85.05592793226242, 23.171774111688137, 0.5776470818091184, 0.567630403675139, 0.313240674440749, 0.39527577871922404, 0.10746102430857718, 0.2054376239539124, 0.15711955027654767, 0.19754477951209992], [0.046485967104672454, 0.04799267902853899, 0.006839077304903185, 0.042780631556524895, 0.03428376054216642, 0.06738065625540912, 0.04102129256352782, 0.09067987790331244, 0.05923754477407783, 1.4157982100732625, 17.088690027594566, 52.13431969285011, 36.95745907723904, 28.010706156492233, 30.43554414063692, 40.91768637299538, 29.027759581804276, 38.811011016368866, 61.20227850973606, 65.96493154764175, 19.06571254134178, 0.9406266419682652, 7.339658606797457, 19.141013100743294, 19.750884175300598, 53.46102990210056, 65.1045361161232, 59.66136999428272, 57.80726708471775, 56.19579255580902, 54.54534351825714, 59.087057411670685, 58.51217105984688, 62.17210806906223, 60.79946592450142, 63.744095116853714, 61.07315003871918, 56.77045091986656, 50.04890039563179, 48.32869090139866, 46.35792665183544, 48.436529114842415, 48.688767179846764, 49.846770241856575, 46.976696848869324, 53.13841201364994, 59.496436044573784, 57.8500109910965, 52.77137450873852, 56.334678903222084, 55.998970717191696, 51.374516263604164, 48.220829889178276, 50.06119653582573, 53.32869440317154, 54.804755598306656, 56.75886534154415, 58.07601146399975, 56.117246970534325, 55.895578265190125, 56.73739269375801, 51.8417201936245, 46.310113817453384, 43.88383761048317, 43.39769549667835, 44.00395296514034, 42.88151599466801, 44.58629071712494, 52.35994018614292, 53.348293751478195, 47.38759160041809, 31.13892439752817, 24.57423895597458, 38.991748318076134, 38.75706911087036, 38.69332753121853, 44.89688225090504, 40.437217354774475, 41.843453496694565, 38.82729314267635, 38.41501526534557, 38.02545256912708, 38.02746266126633, 39.25114519894123, 41.01394660770893, 42.89533965289593, 44.88357916474342, 43.93942482769489, 44.64745603501797, 45.71670725941658, 43.53780157864094, 43.11161644756794, 42.03645274043083, 45.13506107032299, 42.00068525969982, 41.295910477638245, 42.20902808010578, 44.26574371755123, 44.11176078021526, 45.827896893024445, 42.002136781811714, 40.193243846297264, 38.75511221587658, 44.39395643770695, 28.468486592173576, 31.01797878742218, 37.93464884161949, 46.2862852960825, 46.765344589948654, 42.89245940744877, 40.3080964833498, 39.39967542886734, 42.969572469592094, 42.209898233413696, 44.60676781833172, 45.476503148674965, 46.52174346148968, 47.96830303966999, 49.379490315914154, 53.24440732598305, 56.83416590094566, 54.826938807964325, 53.58354292809963, 52.30342201888561, 54.39489059150219, 47.257133200764656, 44.48016621172428, 50.90643838047981, 56.24524310231209, 55.796639174222946, 56.55415892601013, 57.619807943701744, 54.84240397810936, 50.08831948041916, 43.405861258506775, 44.692259430885315, 44.04652588069439, 45.831164717674255, 45.79259678721428, 47.954517379403114, 54.97524105012417, 56.25327207148075, 57.015473172068596, 61.635603457689285, 60.48956595361233, 62.526249065995216, 64.43869024515152, 61.769702062010765, 60.94132751226425, 62.51869887113571, 61.285247057676315, 59.70141984522343, 63.2050484418869, 55.93823857605457, 49.709533005952835, 21.81958056986332, 2.596991783939302, 36.51532620191574, 56.59288264811039, 35.956303998827934, 38.43148358166218, 31.113108582794666, 35.16944222152233, 44.30724889039993, 48.91815707087517, 57.1206933259964, 41.29859313368797, 0.05570784960582387, 0.04029983967484441, 0.09062606477527879, 0.057980687997769564, 0.023386876709992066, 0.049564325163373724, 0.023483226032112725, 0.034431518433848396, 0.045825964043615386, 0.02960989259008784, 0.022617748254560865, 0.051530741911847144, 0.05827516106364783, 0.030907461732567754, 0.15490308171138167, 0.03802694191108458, 0.04901044179860037, 0.033180224054376595, 1.1226701829582453, 25.01467902213335, 68.25844287872314, 34.71355028450489, 30.47674722969532, 45.97138859331608, 37.605107724666595, 35.59453681111336, 49.189017936587334, 65.23538589477539, 72.70310238003731, 21.51971586048603, 1.1235379613935947, 8.502198625355959, 20.31479861587286, 25.61855971813202, 65.73422312736511, 70.04393666982651, 66.11680939793587, 61.82562746107578, 65.03623858094215, 59.52829733490944, 63.79682868719101, 63.53326342999935, 66.35973796248436, 63.26169200241566, 68.07294443249702, 65.5204389989376, 61.50766432285309, 53.534958735108376, 52.311355993151665, 50.60558572411537, 51.16406835615635, 50.16387842595577, 51.79373636841774, 50.48756405711174, 55.21071821451187, 61.06976442039013, 61.94423049688339, 56.43625885248184, 59.06078182160854, 56.35330930352211, 52.36253924667835, 50.63051238656044, 50.54388463497162, 57.96541079878807, 57.59116888046265, 59.330867528915405, 59.35523562133312, 58.64633806049824, 58.60398553311825, 60.20695611834526, 52.729911133646965, 49.969617649912834, 47.399127781391144, 46.51457704603672, 45.80345280468464, 45.30919812619686, 46.655899062752724, 56.73037447035313, 57.382104098796844, 51.896805837750435, 35.045842453837395, 28.12634915113449, 43.30361634492874, 42.845493927598, 41.55952513217926, 48.41105528175831, 46.056846007704735, 46.52170926332474, 42.45917245745659, 40.24067670106888, 41.14861138164997, 40.010310262441635, 41.149010360240936, 44.45374622941017, 46.15155592560768, 47.50654421746731, 47.77016647160053, 48.302935883402824, 48.132906407117844, 44.89788539707661, 42.82116383314133, 43.020295947790146, 46.51540160179138, 45.13141326606274, 43.72399918735027, 43.194919377565384, 44.79871831834316, 43.41681607067585, 47.98611268401146, 44.52497340738773, 44.868873953819275, 41.32935248315334, 47.36112222075462, 30.874872766435146, 35.88327191770077, 43.65513928234577, 50.44222868978977, 50.51079601049423, 45.89926466345787, 42.94069401919842, 44.02565740048885, 45.72160139679909, 43.70606414973736, 48.23691062629223, 47.2299000620842, 50.1888582855463, 51.38377636671066, 53.56763698160648, 55.50279714167118, 59.724845588207245, 56.242632642388344, 56.3171162456274, 56.65766157209873, 58.12477044761181, 49.024357572197914, 48.26190568506718, 54.949470832943916, 59.172682017087936, 58.658383414149284, 58.6753761023283, 60.362375378608704, 58.05146858096123, 52.99190327525139, 48.02579015493393, 49.35133382678032, 48.9583171159029, 50.06188429892063, 49.97101977467537, 52.278487756848335, 59.689465686678886, 62.93307803571224, 62.6812731474638, 64.26975890994072, 65.39037957787514, 67.3141023516655, 67.56521567702293, 66.7074953019619, 66.11907407641411, 66.44625931978226, 65.16832709312439, 67.1781076490879, 66.31648868322372, 62.62809120118618, 59.815580919384956, 26.195771545171738, 3.170337793417275, 39.91377264261246, 65.86144030094147, 43.20018209517002, 44.135163724422455, 38.43277171254158, 43.22924293577671, 44.61081080138683, 48.5702059417963, 66.57630354166031, 37.50472091138363, 0.2166431484511122, 0.08120418089674786, 0.13292719842866063, 0.06184823847434018, 0.08699300698935986, 0.05144730967003852, 0.06699462071992457, 0.038203710355446674, 0.043681409588316455, 0.1449160449556075, 0.24114583677146584, 0.11568395377253182, 0.1924502177280374, 0.08865079420502298, 0.23626171838259324, 0.13606974855065346, 0.16989814583212137, 0.17644789593759924, 1.0252054128795862, 55.16129046678543, 76.38849422335625, 52.85255715250969, 39.448240622878075, 47.177219688892365, 60.045001208782196, 38.31813186407089, 55.79899504780769, 73.14826369285583, 79.97177794575691, 24.328479543328285, 1.6832664515823126, 9.690864142030478, 19.95735939592123, 31.299608275294304, 70.05076110363007, 70.59978604316711, 65.80930709838867, 62.531040608882904, 64.77059483528137, 59.781698137521744, 65.13105109333992, 63.23766589164734, 67.4687160551548, 63.91497954726219, 69.0862512588501, 64.9111644923687, 62.28429704904556, 54.789472818374634, 52.34403803944588, 50.82477316260338, 53.24948385357857, 51.5093482285738, 54.58191655576229, 51.943805515766144, 57.35446818172932, 61.76899150013924, 63.58888864517212, 60.4189695417881, 61.13989345729351, 60.4434934258461, 54.84639756381512, 51.531246453523636, 52.636493146419525, 58.353818356990814, 59.4273329526186, 62.248772755265236, 61.4767149835825, 61.1127857118845, 60.00210151076317, 62.495197132229805, 56.45738571882248, 52.19774968922138, 49.40852455794811, 50.679909735918045, 49.97518055140972, 50.1917727291584, 49.12078879773617, 61.12001292407513, 60.165583938360214, 53.38029183447361, 41.423260644078255, 35.67119389772415, 46.01140044629574, 44.60101492702961, 44.501608461141586, 52.445823177695274, 47.40991160273552, 50.43673798441887, 44.750510305166245, 43.346238657832146, 43.59856031835079, 42.807826548814774, 43.797559440135956, 47.254636734724045, 48.26490372419357, 52.39699199795723, 52.562925294041634, 52.018410712480545, 52.34677009284496, 49.69331927597523, 47.76684544980526, 45.7752051204443, 50.20372308790684, 46.41899697482586, 44.31274339556694, 46.60774804651737, 45.675996243953705, 46.43048755824566, 50.04690930247307, 48.36883194744587, 48.689831122756004, 43.2378950715065, 50.419790893793106, 37.267579436302185, 41.38319939374924, 47.752888798713684, 54.5428204536438, 53.93225781619549, 49.39807511866093, 46.74392893910408, 47.21358373761177, 49.98778447508812, 45.025904327631, 48.254974856972694, 49.11760076880455, 51.43034666776657, 53.956052139401436, 54.8585569113493, 55.821565836668015, 59.249050319194794, 59.380242079496384, 56.561458334326744, 57.464559674263, 59.064908400177956, 52.701690047979355, 50.13201713562012, 56.27541348338127, 60.85530012845993, 61.66029453277588, 61.26883573830128, 62.03623875975609, 61.09484687447548, 54.67074438929558, 50.024859085679054, 51.704764142632484, 52.47576557099819, 51.56813867390156, 52.51425750553608, 55.152452141046524, 61.79058574140072, 64.33560937643051, 64.61828380823135, 67.39484041929245, 66.91408261656761, 70.09888172149658, 71.73155531287193, 67.72080212831497, 68.2235911488533, 70.85604429244995, 67.5683619081974, 70.23659393191338, 72.3801577091217, 68.84963035583496, 62.99946807324886, 27.448152042925358, 3.613529624417424, 43.4570749104023, 70.38097098469734, 51.24843902885914, 51.80097497999668, 41.597895473241806, 51.75570800900459, 63.8270066678524, 72.00812727212906, 76.73602357506752, 60.01143001019955, 0.2972080581821501, 0.09695611690403894, 0.21478651760844514, 0.14477702585281804, 0.1657704243552871, 0.2085141823044978, 0.16562459233682603, 0.16066734271589667, 0.07734231156064197], [0.04246104792400729, 0.04090218157216441, 0.0067534877325670095, 0.01175511175460997, 0.06752541215973906, 0.06475317146396264, 0.09261516155675054, 0.04425955376063939, 0.072788485995261, 0.2147100170259364, 8.039133623242378, 56.88903495669365, 47.458932772278786, 28.176069483160973, 34.25990402698517, 32.68324322998524, 35.4248683154583, 32.289956733584404, 56.87125951051712, 63.86536180973053, 23.133627958595753, 0.8284798159729689, 8.21610912680626, 18.204543851315975, 22.051022350788116, 62.963309213519096, 66.88314467668533, 67.28754937648773, 61.289491429924965, 65.03862485289574, 63.87104630470276, 66.69227331876755, 64.17136698961258, 65.1106309890747, 62.02456958591938, 62.97886937856674, 63.33954982459545, 57.66329661011696, 48.48934628069401, 50.2012874186039, 47.372023835778236, 48.32893788814545, 47.42368966341019, 47.48009003698826, 47.44140811264515, 48.11848618090153, 56.075426414608955, 55.83272963762283, 53.40041175484657, 56.0030896961689, 52.33142651617527, 50.35338185727596, 49.18359562754631, 50.999909564852715, 53.26344810426235, 57.60056957602501, 57.23484680056572, 56.10854543745518, 54.33611914515495, 58.31345312297344, 58.21368187665939, 47.75737635791302, 45.5715474486351, 44.355092123150826, 44.4277898222208, 43.96685175597668, 44.29816737771034, 44.02438826858997, 48.81242774426937, 49.62648466229439, 49.19868841767311, 33.43097850680351, 19.015087857842445, 38.241900354623795, 40.1378808170557, 38.59603375196457, 41.894629150629044, 44.51752580702305, 44.80037122964859, 38.35522547364235, 38.27391743659973, 38.06051708757877, 36.902962401509285, 38.06565061211586, 44.63312700390816, 38.85370932519436, 43.438961282372475, 43.3557191491127, 44.12425071001053, 44.62898902595043, 42.538025826215744, 41.26073196530342, 41.83434158563614, 43.18771116435528, 45.63802868127823, 41.78986877202988, 43.12378339469433, 44.3308912217617, 45.107941925525665, 42.379198148846626, 42.967558577656746, 39.70895603299141, 42.9013167321682, 42.12031044065952, 26.468329019844532, 32.46777579188347, 40.80368109047413, 50.74920281767845, 47.68526002764702, 42.43472836911678, 39.058377742767334, 41.25786691904068, 41.42753541469574, 43.403091207146645, 43.64212118089199, 45.731708854436874, 43.85125435888767, 46.57099261879921, 48.52018162608147, 50.71008011698723, 52.89270579814911, 53.27305778861046, 51.54200367629528, 55.321402475237846, 52.69602835178375, 44.02229078114033, 45.04465252161026, 54.7105548530817, 55.669889375567436, 54.25110250711441, 52.48130187392235, 57.26654089987278, 54.3058043718338, 46.05212666094303, 42.46442757546902, 45.243009477853775, 42.19710811972618, 47.40451589226723, 46.349586099386215, 51.5668011456728, 56.39207102358341, 60.352598503232, 57.157425954937935, 61.23066298663616, 63.387153670191765, 64.37505885958672, 60.97925707697868, 63.51210616528988, 59.2424538731575, 60.27360074222088, 59.28128778934479, 61.4687430113554, 58.42813476920128, 58.92324060201645, 57.35970810055733, 26.994876265525818, 2.93894374743104, 40.24305157363415, 56.14664599299431, 30.529121719300747, 41.35904788970947, 26.49353116750717, 41.69674336910248, 44.0652284771204, 44.68674972653389, 57.87527583539486, 4.945525350049138, 0.21124592400155962, 0.033171514951391146, 0.012918428237753687, 0.08762837445829064, 0.032531249307794496, 0.07766336464555934, 0.050104330366593786, 0.038645184322376736, 0.05478236918861512, 0.04818845016416162, 0.042454721115063876, 0.041136774452752434, 0.08289287856314331, 0.06817343324655667, 0.04541386057098862, 0.13226266455603763, 0.04181528667686507, 0.0990014684794005, 0.18318658199859783, 9.260091707110405, 74.61610972881317, 50.656438395380974, 22.16563370078802, 46.99471928179264, 34.26276907324791, 35.68756341934204, 46.301625072956085, 58.47946621477604, 73.53135913610458, 26.068548671901226, 1.201216836925596, 8.816458862274885, 18.487558364868164, 27.79297214001417, 70.45097842812538, 67.42513239383698, 70.7378402352333, 65.04899829626083, 70.4017786681652, 68.65044504404068, 71.20657548308372, 67.06527650356293, 67.97151267528534, 65.44108405709267, 67.47671082615852, 66.56582370400429, 60.686543583869934, 52.05774240195751, 52.664748430252075, 49.575905576348305, 51.02111242711544, 49.467960968613625, 50.49579441547394, 49.21457536518574, 51.487237215042114, 57.84493066370487, 59.75935533642769, 57.83223934471607, 59.88249532878399, 55.37459582090378, 51.344015300273895, 51.207310035824776, 53.235306814312935, 57.204247042536736, 59.90495592355728, 58.95935006439686, 58.685669749975204, 58.973899483680725, 59.90502052009106, 58.480670750141144, 52.836149632930756, 48.771880120038986, 47.755058482289314, 47.37819090485573, 46.468952894210815, 45.26494190096855, 45.518091917037964, 51.863071247935295, 52.23959684371948, 53.14380392432213, 41.22522287070751, 23.947485387325287, 39.29413989186287, 43.129619881510735, 42.87178851664066, 47.85313881933689, 47.71046407520771, 46.823348477482796, 41.18703491985798, 41.444767490029335, 40.890734419226646, 41.23069457709789, 40.79395741224289, 46.163494884967804, 41.31381131708622, 44.2252416908741, 46.948289573192596, 47.44516611099243, 46.77685797214508, 44.850061163306236, 44.35187369585037, 44.12078909575939, 44.68064725399017, 44.90092523396015, 43.270022347569466, 45.17238266766071, 46.428314074873924, 48.01197409629822, 43.46670359373093, 46.414121836423874, 41.50289297103882, 46.99879266321659, 43.22746083140373, 27.940843105316162, 37.9954531788826, 46.617851704359055, 53.60514856874943, 45.46526335179806, 45.65551154315472, 42.076149210333824, 45.09653493762016, 44.34414491057396, 46.20110146701336, 46.19817942380905, 48.08568634092808, 46.55718415975571, 50.760609805583954, 51.95634104311466, 55.22016070783138, 56.15932211279869, 56.78726501762867, 55.714650973677635, 58.08712586760521, 55.095504596829414, 47.367065101861954, 49.11093592643738, 57.72582985460758, 58.20047378540039, 58.07460933923721, 56.799420565366745, 61.35276183485985, 58.2139440625906, 50.86522959172726, 46.440936997532845, 47.671398371458054, 46.7312566190958, 51.60047873854637, 49.78561632335186, 55.22503964602947, 60.73815241456032, 65.4221610724926, 64.41676542162895, 68.11244711279869, 68.80247488617897, 65.53354069590569, 65.91800406575203, 68.3211775124073, 63.75723481178284, 63.86562779545784, 64.38453555107117, 66.48497924208641, 64.06159088015556, 69.03803944587708, 65.07653161883354, 31.80239539593458, 3.323495937511325, 46.62083454430103, 63.11255380511284, 39.609496369957924, 46.04782909154892, 31.742352917790413, 53.15165810286999, 41.18740729987621, 47.950736582279205, 62.75201015174389, 2.4746300373226404, 0.07315267270314507, 0.07814185693860054, 0.017489465135440696, 0.03303028795926366, 0.03427686599025037, 0.0399449112592265, 0.02773392880044412, 0.029007929188082926, 0.013008052774239331, 0.20805697480682284, 0.1466250923112966, 0.11562507919734344, 0.21329722017981112, 0.20047681202413514, 0.23971015209099278, 0.18169262388255447, 0.17557867773575708, 0.22086892247898504, 0.3155848814640194, 26.628693714737892, 93.83088827133179, 62.453384175896645, 44.860829785466194, 45.78783184289932, 47.88148529827595, 45.80909550189972, 48.81947636604309, 66.76034286618233, 79.16855424642563, 28.257966488599777, 2.062987913377583, 10.830449592322111, 18.805665895342827, 33.907495737075806, 73.01301375031471, 66.5999610722065, 70.53810775279999, 66.37496754527092, 71.77023723721504, 67.76909753680229, 72.91347429156303, 70.32582074403763, 70.86756527423859, 66.80898025631905, 68.1178580224514, 68.84782925248146, 62.50746287405491, 53.63701365888119, 54.78306636214256, 51.94574721157551, 52.57792688906193, 51.63306578993797, 52.38099865615368, 51.703426614403725, 52.16734752058983, 62.09165118634701, 61.757044941186905, 58.77589970827103, 61.583466455340385, 56.96512587368488, 54.171238392591476, 54.67715844511986, 54.26871456205845, 60.86343929171562, 63.11426751315594, 60.953403264284134, 59.903021827340126, 61.97983838617802, 61.72463648021221, 61.49703249335289, 54.79640744626522, 50.46748213469982, 48.764899894595146, 49.5061869174242, 51.06470748782158, 46.78666144609451, 48.43516118824482, 55.247002467513084, 55.99628046154976, 56.3329765945673, 44.263175055384636, 30.14770768582821, 44.26953971385956, 46.17185443639755, 45.997291803359985, 51.54779456555843, 51.20280347764492, 48.905393555760384, 42.461296543478966, 45.36257766187191, 43.787303790450096, 42.34268590807915, 43.34574468433857, 49.99146267771721, 43.15970666706562, 46.97771519422531, 48.9057507365942, 51.27208516001701, 50.49168683588505, 48.122772350907326, 45.774388164281845, 44.797829166054726, 47.558669820427895, 48.7898987531662, 46.638723984360695, 46.55137047171593, 51.028233245015144, 50.21468549966812, 48.01578529179096, 49.55279901623726, 46.47007383406162, 47.676759883761406, 46.070772260427475, 35.889625176787376, 41.063153967261314, 49.69415903091431, 58.72195020318031, 52.58449673652649, 49.23163264989853, 44.933736473321915, 49.73787948489189, 48.076224848628044, 48.60451050102711, 48.23913350701332, 51.54781736433506, 48.37334230542183, 51.55511677265167, 55.963032245635986, 57.58759327232838, 60.30316315591335, 56.935620456933975, 55.73867708444595, 58.91953960061073, 55.88359370827675, 50.283366814255714, 52.10441529750824, 59.75168734788895, 60.79681746661663, 58.547634556889534, 56.785425916314125, 64.14492800831795, 60.631689727306366, 54.175182580947876, 49.91947554051876, 50.36029368638992, 48.51927727460861, 54.31700997054577, 51.924057975411415, 58.984850496053696, 62.896926775574684, 68.01509633660316, 65.98054870963097, 71.51175230741501, 71.40835225582123, 72.14906930923462, 66.004928201437, 72.21541374921799, 67.34537467360497, 70.35802021622658, 68.72519463300705, 72.0981976389885, 66.33214384317398, 76.07791408896446, 70.3359206020832, 34.57762397825718, 3.9178500697016716, 50.449930876493454, 69.62935611605644, 47.28524409234524, 51.7594888061285, 40.03755480051041, 65.62491059303284, 63.230305686593056, 61.94264978170395, 81.73066556453705, 9.856004230678082, 0.4364391480339691, 0.4335626430111006, 0.08011994767002761, 0.23434715549228713, 0.15806857903953642, 0.2663095708703622, 0.179010606079828, 0.14216854004189372, 0.18901655275840312], [0.03821797814453021, 0.049937220974243246, 0.05268427688861266, 0.05032281864259858, 0.017289289353357162, 0.03855380738968961, 0.048488864122191444, 0.05298408228554763, 0.010244689092360204, 0.09705883014248684, 0.3728407731978223, 42.48444490134716, 48.30024562776089, 45.67097671329975, 33.082210421562195, 33.787992149591446, 35.06272874772549, 24.982405453920364, 51.89602307975292, 65.68316146731377, 32.1813927590847, 0.500299382256344, 6.653248239308596, 17.078730762004852, 31.232437379658222, 70.46067550778389, 66.4482732117176, 69.22933638095856, 64.35173571109772, 67.40700736641884, 65.62819361686707, 62.71603748202324, 62.73318216204643, 62.81537935137749, 61.22979283332825, 62.084591165184975, 60.28045177459717, 54.836225509643555, 47.543672025203705, 46.85536175966263, 45.97278691828251, 48.69487725198269, 46.39533944427967, 46.81491672992706, 48.28410029411316, 47.23561115562916, 50.953620448708534, 54.196431040763855, 52.89053611457348, 52.29519926011562, 51.23355142772198, 47.91749216616154, 49.22549977898598, 51.594478860497475, 56.07979238033295, 56.76779866218567, 54.006448835134506, 58.78852263092995, 56.74341157078743, 56.978846937417984, 54.88425113260746, 49.81166772544384, 45.76358914375305, 48.374968618154526, 44.30030286312103, 44.598241075873375, 46.37046977877617, 45.618379935622215, 46.70376129448414, 49.185503125190735, 52.59735904633999, 41.06471948325634, 19.392831288278103, 31.163854859769344, 40.8495332300663, 34.42305587232113, 43.63733343780041, 42.65600189566612, 40.34787654876709, 38.097306713461876, 37.4704809486866, 38.80585089325905, 38.636813163757324, 40.628552287817, 41.17449939250946, 42.990437150001526, 49.41416725516319, 45.8294852077961, 45.62089920043945, 44.02104824781418, 43.24548326432705, 43.2077930867672, 44.658619835972786, 41.09395891427994, 43.73992793262005, 42.713732197880745, 43.228285387158394, 42.87316404283047, 43.48029926419258, 44.0177234262228, 44.89164613187313, 35.73184624314308, 44.18901063501835, 32.829242795705795, 21.327934451401234, 34.068759083747864, 46.9951106607914, 49.698034822940826, 45.3413026034832, 44.20798301696777, 40.19870035350323, 41.64448097348213, 40.90322054922581, 45.36551110446453, 43.56361739337444, 43.7486332654953, 43.40377897024155, 46.88940413296223, 46.890912652015686, 48.81912678480148, 50.35033442080021, 50.51902636885643, 53.953289687633514, 50.70026904344559, 44.06730316579342, 41.95252284407616, 47.438565865159035, 53.288568556308746, 51.84705130755901, 54.13200929760933, 54.559015184640884, 54.36361446976662, 52.469207122921944, 46.77869327366352, 43.427831679582596, 44.79482352733612, 43.20166401565075, 46.97602428495884, 45.84128737449646, 54.58439402282238, 59.36549887061119, 59.5405250787735, 61.88371114432812, 62.069232389330864, 60.161632150411606, 62.88833923637867, 60.6413222104311, 61.639916226267815, 58.7190243601799, 56.73741169273853, 57.601534724235535, 58.09779189527035, 61.54213987290859, 61.40120543539524, 60.67197136580944, 29.362732507288456, 3.6772548174485564, 47.35019400715828, 48.225306048989296, 33.584836050868034, 48.440336510539055, 30.951850935816765, 49.50070761144161, 36.84352599084377, 51.65035866200924, 37.83067502081394, 0.02887765072955517, 0.08260823524324223, 0.09711522594443522, 0.04680619269493036, 0.06114349504059646, 0.027667170761560556, 0.031212916728691198, 0.027337933643138967, 0.09945187048288062, 0.06249683472560719, 0.03534319119353313, 0.035099187880405225, 0.039600870150025, 0.025940245068341028, 0.03649546822998673, 0.03594860929297283, 0.028779113927157596, 0.029229636529635172, 0.1658669183962047, 0.19783617637585849, 0.930992733919993, 43.04787106812, 59.385801181197166, 30.13025902211666, 36.088362112641335, 41.63294479250908, 32.62262888252735, 38.20175550878048, 56.4520014077425, 73.42048868536949, 35.095106810331345, 1.54745580162853, 7.5226363632828, 17.827125303447247, 39.253748059272766, 75.30053660273552, 67.15857669711113, 71.82080492377281, 68.45911771059036, 72.07106709480286, 68.31186041235924, 67.40127727389336, 68.02355468273163, 67.86633431911469, 65.83481132984161, 66.1417892575264, 63.31770479679108, 57.40612640976906, 50.888244956731796, 51.3451324403286, 49.613610953092575, 49.50587533414364, 48.781535401940346, 48.593095913529396, 49.80564124882221, 50.174479857087135, 52.275356724858284, 57.36759267747402, 56.0631150752306, 53.50740261375904, 55.23610085248947, 49.67586301267147, 50.16552373766899, 54.64390642940998, 59.49223347008228, 58.939701318740845, 55.370366647839546, 59.96674820780754, 59.479697942733765, 57.57279306650162, 57.59589582681656, 52.83882088959217, 48.797030970454216, 49.67712454497814, 48.38454030454159, 48.20354841649532, 48.80940690636635, 49.80859749019146, 49.52090732753277, 54.590143114328384, 57.13963530957699, 48.83529871702194, 22.766945734620094, 34.26357463002205, 44.82515349984169, 39.3926078081131, 46.175981014966965, 47.30220638215542, 42.8628171980381, 39.91463519632816, 41.08985513448715, 42.4161359667778, 41.45264446735382, 42.19606697559357, 42.32449248433113, 46.08826272189617, 51.688223630189896, 47.07747504115105, 45.20307742059231, 44.651373624801636, 44.0046863257885, 44.44875709712505, 47.10781641304493, 44.51495714485645, 43.89095842838287, 43.704175651073456, 45.010108575224876, 42.5972418487072, 43.9606086909771, 46.2266930937767, 48.00084449350834, 40.25909811258316, 47.85709820687771, 33.53179469704628, 24.697561338543892, 38.614234775304794, 50.33205360174179, 52.8111469745636, 47.427177876234055, 46.09218031167984, 43.9823093265295, 42.71361440420151, 44.45713944733143, 47.85019397735596, 46.462478041648865, 48.206679448485374, 47.634053975343704, 51.31517104804516, 50.511407777667046, 51.195682659745216, 52.91149578988552, 54.29074577987194, 56.24939627945423, 52.48879887163639, 48.029886335134506, 46.29042707383633, 50.7241203635931, 56.980750635266304, 55.83300702273846, 57.768596559762955, 57.24896304309368, 57.97959543764591, 55.88099084794521, 51.16798974573612, 46.74762234091759, 48.131888061761856, 46.89824625849724, 51.317466124892235, 49.92200240492821, 57.24351793527603, 63.563836589455605, 64.3409138917923, 65.88854804635048, 64.63063314557076, 62.97299489378929, 68.31825166940689, 65.38748413324356, 63.28766740858555, 61.413402780890465, 62.12261572480202, 61.44806072115898, 61.8449380248785, 67.06219866871834, 66.27019956707954, 66.1375030875206, 31.32097452878952, 4.410336893051863, 51.07489854097366, 55.99396638572216, 40.24402812123299, 52.590709403157234, 37.74804085493088, 53.09580869972706, 39.971293956041336, 62.160302102565765, 38.50734271109104, 0.09271419374272227, 0.06263361254241318, 0.06088896807341371, 0.01356845126792905, 0.15769906371133402, 0.027840788789035287, 0.039616585127078, 0.05144726143043954, 0.07752188903396018, 0.02550932258600369, 0.10528042374062352, 0.14258047653129324, 0.19623233587481081, 0.16877699817996472, 0.19723634293768555, 0.07565488296677358, 0.21238675341010094, 0.10477430871105753, 0.31008814985398203, 0.377786920289509, 3.1339687574654818, 73.6289530992508, 62.37509697675705, 63.53453256189823, 43.733080700039864, 50.68385012447834, 51.9833841919899, 37.88311220705509, 65.76382353901863, 78.60855549573898, 40.64348928630352, 2.700886996462941, 8.684206958860159, 19.47762943804264, 45.93415819108486, 77.21176564693451, 70.18984884023666, 72.72584795951843, 69.47788864374161, 70.88965728878975, 71.15975439548492, 70.16832679510117, 69.98883962631226, 68.67725640535355, 67.07791462540627, 67.26233392953873, 67.52793207764626, 60.51163896918297, 52.633491307497025, 51.06407672166824, 51.317956298589706, 51.93152077496052, 50.63401959836483, 51.734812930226326, 54.20111618936062, 51.11516498029232, 55.73714196681976, 57.938804626464844, 60.77582739293575, 57.12517328560352, 58.07987205684185, 51.70523151755333, 53.795446157455444, 55.957104563713074, 60.8013354241848, 62.68288426101208, 55.57788111269474, 62.63178840279579, 62.32030771672726, 60.25038778781891, 62.24743142724037, 55.43796122074127, 52.38585099577904, 51.812872141599655, 50.54459899663925, 50.25922290980816, 51.67875833809376, 53.12944069504738, 53.59548568725586, 56.81740500032902, 60.303850919008255, 50.31196027994156, 31.84509940445423, 38.56143660843372, 44.070833176374435, 40.77580578625202, 48.23978707194328, 48.41499947011471, 44.13881532847881, 42.34769023954868, 44.27131041884422, 44.941187873482704, 44.11103501915932, 44.646031111478806, 44.65037427842617, 47.723554372787476, 55.817948430776596, 52.51968361437321, 48.797844126820564, 47.81911924481392, 46.482955142855644, 47.297992408275604, 49.85163398087025, 46.60315789282322, 46.78370900452137, 46.07845924794674, 47.27026529610157, 46.60030044615269, 45.67415714263916, 47.772792130708694, 50.97749076783657, 41.879616156220436, 46.999404430389404, 39.80968102812767, 31.854956075549126, 43.53344701230526, 53.07125821709633, 56.9414721429348, 51.70762158930302, 51.672325283288956, 45.05625709891319, 46.92062705755234, 46.63845419883728, 51.16543248295784, 48.74658487737179, 51.23508274555206, 49.261008873581886, 53.97078774869442, 52.50537358224392, 55.088687762618065, 56.156692653894424, 55.96837095916271, 59.37633588910103, 56.185772493481636, 50.393671095371246, 48.767916932702065, 53.20143923163414, 59.204786494374275, 57.70357824862003, 58.88758711516857, 58.49310368299484, 58.57446871697903, 58.71647469699383, 56.14427492022514, 49.32311274111271, 50.42148180305958, 49.85167197883129, 53.605969324707985, 51.90144918859005, 59.118280336260796, 67.87673056125641, 69.84107315540314, 68.67929309606552, 67.47957587242126, 66.11804813146591, 72.92564883828163, 68.42114254832268, 68.69456827640533, 64.9795152246952, 65.00254958868027, 66.52139648795128, 67.05986559391022, 69.73533242940903, 72.95250579714775, 69.00542199611664, 35.498424768447876, 4.570440826937556, 54.80879858136177, 60.45869641005993, 49.475541561841965, 57.73680366575718, 50.02874247729778, 64.23650309443474, 54.9308480322361, 71.26262247562408, 54.73383620381355, 0.23827593686291948, 0.19534696853952482, 0.1893701564404182, 0.10666367568774149, 0.21749575738795102, 0.13071515306364745, 0.12844999961089343, 0.13979512208607048, 0.18282699660630897, 0.1449934212723747], [0.10166476931772195, 0.05868612162885256, 0.08726989486603998, 0.008418354573223041, 0.025860516143438872, 0.04497231238929089, 0.07383835036307573, 0.03070035614655353, 0.010108595906785922, 0.06021444118232466, 0.5322486022487283, 7.269471623003483, 61.21863663196564, 53.03894095122814, 42.23363555967808, 41.530844271183014, 37.88387596607208, 23.942165672779083, 45.90124815702438, 64.15223881602287, 34.77492079138756, 0.586157200159505, 5.809600409120321, 14.293292127549648, 47.92101837694645, 66.90499350428581, 67.59752914309502, 68.7061956524849, 67.952870875597, 66.82672530412674, 65.00388711690903, 64.40812468528748, 63.59334200620651, 61.594356670975685, 58.28892923891544, 58.4102301299572, 58.141797333955765, 50.22863835096359, 47.33888581395149, 49.140904918313026, 48.407270684838295, 46.25053681433201, 46.823143288493156, 46.7437769472599, 44.7322066873312, 45.28734929859638, 47.16925151646137, 48.328189328312874, 51.510013192892075, 49.47535537183285, 47.6585778594017, 47.525201216340065, 48.609131053090096, 53.66286367177963, 55.72261154651642, 56.48435667157173, 57.25390277802944, 56.39201782643795, 57.83381626009941, 54.985519498586655, 52.42753855884075, 46.147015169262886, 47.8828152269125, 49.87458094954491, 49.38260234892368, 47.17783145606518, 46.882518902421, 46.15352042019367, 46.750312596559525, 51.141356974840164, 52.13839687407017, 43.26043926179409, 19.51443426311016, 27.603352814912796, 46.47459179162979, 38.50678414106369, 38.265052512288094, 45.2123299241066, 42.591998130083084, 40.33847965300083, 40.33045828342438, 37.4059946089983, 39.647323340177536, 36.25614210963249, 40.51266610622406, 43.02624262869358, 39.56312745809555, 42.137272730469704, 45.100197941064835, 43.647843673825264, 44.30206596851349, 44.46592457592487, 42.279681488871574, 43.67405466735363, 42.46492154896259, 44.365716353058815, 41.37067146599293, 43.023708164691925, 49.48526903986931, 45.251995995640755, 42.14278623461723, 44.77468840777874, 41.44868887960911, 21.996559873223305, 18.211824260652065, 43.979182094335556, 52.46523633599281, 51.19173847138882, 43.61582659184933, 40.757817551493645, 40.10607652366161, 41.097583919763565, 43.99518683552742, 46.41426622867584, 45.093810483813286, 44.976457580924034, 43.236998319625854, 44.59938481450081, 44.343240559101105, 46.70496582984924, 48.2645845413208, 49.0888287127018, 47.820623964071274, 43.90548884868622, 42.83137008547783, 42.46404379606247, 48.32387275993824, 53.594452142715454, 56.23382091522217, 54.76255126297474, 54.97380092740059, 54.62699353694916, 48.991462737321854, 42.87563771009445, 43.280775770545006, 45.32415792346001, 44.83676567673683, 45.82625538110733, 46.67788848280907, 57.37618401646614, 60.616194158792496, 60.99138982594013, 60.631921514868736, 59.34561833739281, 59.71913069486618, 60.7518544793129, 60.04745967686176, 59.52898129820824, 54.50101509690285, 56.19023345410824, 55.192422196269035, 60.61202958226204, 62.76140324771404, 63.687903732061386, 68.34359630942345, 28.751588501036167, 3.625045856460929, 55.64789615571499, 41.9379848241806, 37.71472804248333, 44.55957815051079, 37.25887790322304, 54.63708579540253, 24.553805552423, 50.616711527109146, 22.037487477064133, 0.16463787731481716, 0.05065302611910738, 0.029538403359765653, 0.021239739580778405, 0.08110284805297852, 0.038773264168412425, 0.051871640025638044, 0.018318920920137316, 0.05093908323033247, 0.0747741837403737, 0.06349091185256839, 0.08326988216140307, 0.024839777361194137, 0.059164792037336156, 0.04313636520237196, 0.11147922705276869, 0.010802623655763455, 0.027460571691335645, 0.025068258655664977, 0.11296602344373241, 0.2194067876553163, 6.715409103780985, 73.16593274474144, 48.18438224494457, 35.81463240087032, 50.69591447710991, 35.62085039913654, 33.7832348048687, 51.988757103681564, 69.13399949669838, 40.63823416829109, 1.2483685067854822, 5.35658111795783, 14.277787059545517, 57.181376069784164, 69.97029662132263, 71.09193563461304, 72.80826553702354, 70.69515332579613, 70.45894280076027, 69.78789880871773, 65.59593334794044, 68.51058214902878, 63.21918748319149, 62.71311543881893, 59.95661415159702, 59.403455033898354, 53.12511272728443, 50.754283145070076, 51.85812771320343, 51.00794233381748, 48.966034501791, 50.339467003941536, 49.675669223070145, 49.735652804374695, 46.83088347315788, 48.14687825739384, 51.42332464456558, 53.10790725052357, 53.034346997737885, 51.11093580722809, 51.414281129837036, 50.58290474116802, 57.42136739194393, 58.602363020181656, 58.475810810923576, 60.20177699625492, 59.37317445874214, 59.33743737637997, 57.20896638929844, 54.50707957148552, 51.96762263774872, 49.99352216720581, 52.54760451614857, 51.76798515021801, 50.129718258976936, 49.723820239305496, 49.73189480602741, 50.134509801864624, 55.05383223295212, 54.134114384651184, 50.06050877273083, 26.35882269591093, 29.91946343332529, 49.076547771692276, 43.22082258760929, 41.05548217892647, 46.11986182630062, 47.24218100309372, 42.96017177402973, 43.391893208026886, 40.38234069943428, 42.82193899154663, 39.63456742465496, 43.11139605939388, 44.85256142914295, 42.737013548612595, 42.124129235744476, 47.00281664729118, 45.441602021455765, 47.3203694075346, 46.08621843159199, 44.45800580084324, 45.06036847829819, 45.98425090312958, 43.34940768778324, 43.88838976621628, 45.4067312926054, 51.79886609315872, 44.75422650575638, 44.357071816921234, 46.96126587688923, 45.47571659088135, 22.44698580354452, 22.86594182252884, 48.917879685759544, 55.940146073699, 53.812313452363014, 46.473763436079025, 44.63001497089863, 44.106239676475525, 42.269357442855835, 49.40198130905628, 49.80810731649399, 48.40087182819843, 48.176520466804504, 48.756255358457565, 48.65864999592304, 47.93582618236542, 48.82318116724491, 51.567648500204086, 50.28056636452675, 51.126469373703, 45.70813871920109, 46.039686128497124, 45.67872829735279, 52.46189631521702, 56.6731533408165, 60.03665305674076, 56.9154929369688, 59.91186015307903, 57.43215121328831, 52.34599493443966, 46.367319747805595, 46.50595910847187, 48.429556488990784, 47.35522873699665, 49.91352505981922, 50.66202029585838, 61.092194616794586, 63.58962580561638, 64.324019998312, 61.84214137494564, 65.05001664161682, 63.97832974791527, 65.14702543616295, 63.353658467531204, 64.06747296452522, 58.15368689596653, 58.054048642516136, 59.34711925685406, 66.74698278307915, 68.82104828953743, 70.76924175024033, 73.99070888757706, 30.66799856722355, 4.875902161002159, 61.941369250416756, 46.36630520224571, 41.72404870390892, 50.06415277719498, 48.08876797556877, 53.62133949995041, 27.89095178246498, 62.22835645079613, 24.613183066248894, 0.17595413024537265, 0.08981477119959891, 0.07099982103682123, 0.03580447308195289, 0.044349320232868195, 0.015229928812914295, 0.07398696543532424, 0.03179761777573731, 0.08882633439498022, 0.05077942871139385, 0.21197978931013495, 0.16310131992213428, 0.15691333712311462, 0.1759620415396057, 0.20851072389632463, 0.2406958577921614, 0.1664249986060895, 0.21189692110056058, 0.1566634263144806, 0.32830449112225324, 0.7305920217186213, 16.891921386122704, 87.03753679990768, 69.90376219153404, 55.69620296359062, 57.87855505943298, 55.87336465716362, 33.56579527258873, 60.30790150165558, 75.47269776463509, 45.66818006336689, 2.018515574745834, 7.824455592781305, 18.19956611841917, 62.35660336911678, 70.33328354358673, 70.87965622544289, 71.96998491883278, 74.47125390172005, 70.9718468785286, 73.02974805235863, 67.61427864432335, 71.52398765087128, 65.54612562060356, 64.63285222649574, 61.586947068572044, 63.960987478494644, 55.40920056402683, 51.02263234555721, 55.23746497929096, 53.175650015473366, 50.3568434715271, 50.89206375181675, 50.407243967056274, 50.55270396173, 48.94063666462898, 51.368960961699486, 53.315467312932014, 55.85435047745705, 55.64640283584595, 53.41642029583454, 54.94491867721081, 53.94168131053448, 58.95037494599819, 61.03738255798817, 59.7005382925272, 62.19010770320892, 61.61251209676266, 61.81707791984081, 59.39241662621498, 57.38294765353203, 53.20501483976841, 53.861243426799774, 54.26668167114258, 55.001607835292816, 51.916177198290825, 52.68244028091431, 51.54215566813946, 53.0133531242609, 57.12140388786793, 59.10702534019947, 50.54977431893349, 32.17925727367401, 35.46137295663357, 47.71137982606888, 47.689956575632095, 43.641798198223114, 52.6041416823864, 48.251399248838425, 47.276546359062195, 46.196826696395874, 42.75222033262253, 46.30174286663532, 43.92307050526142, 47.66793295741081, 51.03541485965252, 47.161287143826485, 45.430282428860664, 49.33409035205841, 49.89397510886192, 51.24223776161671, 49.85661171376705, 47.57284305989742, 48.60497027635574, 49.48964640498161, 50.26676170527935, 46.39021351933479, 47.40067809820175, 56.30269981920719, 51.47575423121452, 48.98598723113537, 46.07138782739639, 45.79591780900955, 31.66978631168604, 28.986706584692, 49.97941352427006, 57.57915772497654, 57.51192033290863, 50.16469158232212, 46.58972181379795, 47.53787733614445, 45.434724390506744, 53.27962003648281, 53.59877251088619, 50.26358887553215, 51.54623664915562, 51.75303295254707, 52.45381034910679, 52.92139045894146, 53.172511383891106, 53.83377470076084, 52.11597427725792, 55.490641593933105, 47.612615525722504, 49.26789030432701, 48.34588497877121, 54.480158016085625, 58.92151549458504, 61.555708944797516, 60.46944223344326, 62.35246159136295, 59.534168019890785, 55.884080082178116, 49.813636019825935, 50.15268422663212, 52.88818784058094, 50.85383020341396, 52.71172910928726, 52.12721407413483, 64.75889906287193, 68.05129319429398, 65.94925358891487, 65.95472529530525, 64.93435084819794, 65.35821810364723, 65.59535577893257, 67.17126041650772, 66.82612493634224, 60.454406440258026, 62.72002726793289, 62.59862378239632, 70.91778337955475, 72.65176713466644, 73.7516713142395, 78.99424999952316, 35.73372334241867, 5.1592824049293995, 65.84867298603058, 54.4838248193264, 51.286645978689194, 55.077026188373566, 61.65802985429764, 67.3086230456829, 35.89575044810772, 71.10635966062546, 35.40903456509113, 0.32497248554136604, 0.24682185641722754, 0.1310737885069102, 0.1781294689862989, 0.1267788017867133, 0.13974320143461227, 0.2179995272308588, 0.11325593601213768, 0.14256030495744199, 0.19868363480782136], [0.051312576470081694, 0.09362794822664, 0.05504673703399021, 0.10712771836551838, 0.08916958511690609, 0.04867388153797947, 0.019981357690994628, 0.07204243462183513, 0.0401376581430668, 0.05043775505328085, 0.0621584339387482, 0.3996064478997141, 45.067656487226486, 50.366133973002434, 51.19540147483349, 55.46110577881336, 53.489843755960464, 19.159100130200386, 39.7171825915575, 64.2473629117012, 41.49900197982788, 1.6601278306916356, 3.3909304440021515, 8.602682333439589, 60.65946623682976, 66.70314833521843, 70.64174339175224, 65.84755584597588, 68.97744029760361, 63.013018146157265, 65.3337474167347, 61.22247062623501, 62.30802297592163, 55.23238085210323, 58.30960012972355, 54.988931715488434, 51.629877761006355, 46.02627284824848, 48.11936013400555, 48.44876065850258, 47.98589989542961, 47.171603590250015, 46.49296760559082, 45.30112735927105, 44.19057235121727, 45.30358962714672, 45.318823009729385, 45.69379448890686, 48.99667605757713, 45.20398557186127, 48.16489689052105, 45.3469642996788, 49.56927493214607, 55.12880600988865, 57.45449401438236, 53.064505979418755, 49.574902430176735, 56.13815724849701, 58.29817794263363, 55.79118646681309, 51.46758086979389, 46.03815481066704, 46.42432048916817, 52.42624282836914, 51.26985467970371, 49.72817100584507, 48.21921497583389, 48.65220554172993, 46.48168221116066, 51.93005785346031, 48.02712768316269, 48.73320199549198, 24.52899858355522, 19.969486445188522, 51.99342705309391, 37.927440628409386, 41.039067059755325, 36.27327159047127, 39.608253836631775, 39.7253293544054, 41.12081587314606, 37.05811567604542, 38.5958057641983, 36.245939657092094, 36.314343586564064, 36.602197140455246, 38.91787268221378, 34.2735680937767, 36.343636214733124, 36.85901015996933, 42.515276446938515, 41.64524853229523, 43.53389918804169, 39.324561059474945, 41.50972880423069, 39.486717358231544, 35.24563193321228, 44.578740522265434, 44.04382802546024, 40.660721361637115, 53.94498333334923, 43.16566474735737, 39.991197288036346, 13.238546624779701, 28.528090193867683, 57.49110125005245, 52.9436344653368, 53.49140167236328, 40.609416514635086, 42.69711568951607, 41.92620545625687, 42.58936487138271, 45.376663506031036, 46.98950216174126, 46.51352070271969, 45.73013573884964, 45.40291249752045, 43.11093248426914, 45.98609760403633, 46.33603982627392, 45.126952305436134, 45.813172683119774, 43.09521272778511, 42.00784407556057, 42.05512873828411, 42.76959300041199, 49.05586168169975, 54.650187492370605, 54.26167733967304, 54.94375593960285, 55.64280442893505, 53.8179637491703, 45.1206636428833, 40.12532629072666, 43.09736721217632, 44.791422709822655, 44.211817011237144, 46.68806813657284, 48.68455320596695, 56.17964342236519, 60.36050587892532, 59.31484378874302, 60.84739275276661, 60.83701930940151, 64.62761610746384, 58.40062044560909, 60.901292860507965, 57.68949620425701, 57.10222251713276, 53.326555117964745, 58.73000957071781, 61.18411548435688, 67.51220092177391, 64.00747418403625, 71.97983399033546, 20.207518972456455, 3.4194377018138766, 61.5474633872509, 33.89893479645252, 56.83530583977699, 31.42198070883751, 43.2124288380146, 51.264196783304214, 31.349750384688377, 54.30188678205013, 14.342932663857937, 0.2844660950358957, 0.1396112921065651, 0.09807601032662205, 0.04402648228278849, 0.03053225598705467, 0.04390888898342382, 0.044123981933807954, 0.06881760258693248, 0.06294629420153797, 0.01446238391508814, 0.046821391879348084, 0.04580067536153365, 0.03483441185380798, 0.07506276044296101, 0.027567541146709118, 0.06895026148413308, 0.035576136506279, 0.0342484639986651, 0.012599846504599554, 0.08117432429571636, 0.05748946045059711, 0.4366372717777267, 46.86212919652462, 55.2164901047945, 45.60972020030022, 69.28740486502647, 52.9861655831337, 25.45953255146742, 51.023852080106735, 68.58333304524422, 48.92208606004715, 2.171341711655259, 3.017780492082238, 12.159784510731697, 69.18063059449196, 67.88505211472511, 74.81537863612175, 69.68601107597351, 72.86305859684944, 68.75913441181183, 69.32333573698997, 64.05786707997322, 64.5097616314888, 58.36830697953701, 63.72106075286865, 58.57645221054554, 54.44113411009312, 50.71707174181938, 51.371035650372505, 50.18034674227238, 50.55112324655056, 49.36789333820343, 51.010260209441185, 48.484592735767365, 47.84615479409695, 48.09221439063549, 48.5630015283823, 49.73279915750027, 50.17809346318245, 46.0263754427433, 50.609343722462654, 47.5536122918129, 52.022962868213654, 57.448604330420494, 61.91309116780758, 55.97109541296959, 49.70145083963871, 60.39011389017105, 61.64829097688198, 57.579024732112885, 53.42252276837826, 49.82634633779526, 48.367285430431366, 53.825502544641495, 53.348001167178154, 53.15873712301254, 52.77315281331539, 50.84841549396515, 48.73910687863827, 54.22867611050606, 52.74471893906593, 55.81864759325981, 29.614801481366158, 24.500657804310322, 53.96753892302513, 39.84510272741318, 44.005970656871796, 38.45475733280182, 43.42759229242802, 42.922838777303696, 42.29440189898014, 39.580522924661636, 40.93070067465305, 38.56342390179634, 40.31085133552551, 39.0358829498291, 40.738719776272774, 36.37359380722046, 38.68779882788658, 39.048749059438705, 41.90205775201321, 42.09758386015892, 46.88091158866882, 41.65917858481407, 44.00025196373463, 42.84298226237297, 39.63515259325504, 45.34744307398796, 42.51866586506367, 43.44925872981548, 54.92681264877319, 44.747595861554146, 37.66541808843613, 16.97931669652462, 35.537646263837814, 61.32093854248524, 56.95435345172882, 56.68297201395035, 43.78042995929718, 46.11851669847965, 46.396578177809715, 45.78753545880318, 45.93740701675415, 50.311751291155815, 50.10252311825752, 49.80751074850559, 48.76362696290016, 48.57555225491524, 49.59004081785679, 48.75163100659847, 46.626036465168, 47.404892072081566, 46.676429361104965, 44.699452444911, 45.36484234035015, 45.34902758896351, 52.05653786659241, 58.45892831683159, 57.169311717152596, 56.238088086247444, 59.129314944148064, 55.58071196079254, 48.351960852742195, 45.251919999718666, 46.94066718220711, 48.02355207502842, 48.98778073489666, 48.23895491659641, 51.76363818347454, 58.80538232624531, 66.52556106448174, 63.62186327576637, 63.939670622348785, 62.8038165718317, 69.4831171631813, 62.80738078057766, 64.65162321925163, 60.01328431069851, 60.923270881175995, 57.19526432454586, 64.90709871053696, 64.96908858418465, 71.18905082345009, 68.40362548828125, 73.80628198385239, 18.816445916891098, 4.732928657904267, 66.1475345492363, 39.14974384009838, 63.43173287808895, 38.70243564248085, 51.86386160552502, 59.11385737359524, 36.95561617612839, 63.01425687968731, 15.381284896284342, 0.43234267097432166, 0.15778886358020827, 0.1488856296055019, 0.09306018298957497, 0.08838261172058992, 0.05225684064498637, 0.04231397280818783, 0.08372409880394116, 0.0673626888601575, 0.021315676131052896, 0.15369534026831388, 0.12609759927727282, 0.13870891474653035, 0.21329506795154884, 0.14119656407274306, 0.17154940956970677, 0.2008577564265579, 0.21364415937568992, 0.11081617005402222, 0.22389565303456038, 0.13063465972663835, 0.9398907283321023, 62.86150127649307, 64.00069534778595, 63.08418832719326, 74.9055477976799, 76.17507487535477, 27.50800833106041, 53.64385329186916, 74.13958489894867, 53.70920218527317, 3.3736506337299943, 3.5431493259966373, 18.063235133886337, 71.0548648238182, 71.68257594108582, 75.01519471406937, 69.43742081522942, 73.34980487823486, 69.89028811454773, 70.36765649914742, 66.2551599740982, 67.10370004177094, 60.79342804849148, 65.80023318529129, 60.206059366464615, 58.186783120036125, 51.52069441974163, 54.44232724606991, 53.06775480508804, 54.05900001525879, 52.47025586664677, 51.61146394908428, 49.70140904188156, 47.87751071155071, 52.4965238571167, 48.78184698522091, 49.896840155124664, 54.5850133895874, 48.85349214076996, 54.72354635596275, 49.729307144880295, 54.59115765988827, 59.56920213997364, 61.801627948880196, 57.20895119011402, 52.43138775229454, 60.592027455568314, 64.42472979426384, 59.953699707984924, 55.639361813664436, 50.835283398628235, 49.95018549263477, 57.43903264403343, 57.62185223400593, 54.68866042792797, 56.98148399591446, 52.527511194348335, 52.57369391620159, 58.7580406665802, 56.00803703069687, 57.87591800093651, 35.0972954928875, 34.32352401316166, 50.04721328616142, 40.025110468268394, 46.66004844009876, 40.6688529253006, 46.45587399601936, 45.4320303350687, 46.62324361503124, 44.42833699285984, 44.839642122387886, 41.407164707779884, 44.57088254392147, 43.23349870741367, 44.138097167015076, 41.80474117398262, 42.70219601690769, 43.45646694302559, 46.488058269023895, 45.90859316289425, 50.69907210767269, 44.614500403404236, 46.64375491440296, 43.757418394088745, 45.35482607781887, 50.33087566494942, 45.22619158029556, 42.521253526210785, 55.14357201755047, 45.996691435575485, 39.63731847703457, 25.54354414343834, 37.110233679413795, 60.44535532593727, 58.592019975185394, 60.674274042248726, 47.88232505321503, 50.202469155192375, 51.161081716418266, 47.860217839479446, 50.39718970656395, 54.620929062366486, 55.879508927464485, 52.70362414419651, 52.110285982489586, 50.0897292047739, 52.376013323664665, 53.55087608098984, 50.975898653268814, 49.98187959194183, 48.9508543163538, 47.72850550711155, 49.260518699884415, 45.91879181563854, 54.65226598083973, 60.0260516256094, 60.52717253565788, 60.962245389819145, 60.358328595757484, 59.57666493952274, 51.824491918087006, 47.01551176607609, 49.895726814866066, 51.46875120699406, 51.2943709641695, 54.30219456553459, 56.16803504526615, 62.752599120140076, 69.08144071698189, 65.29274001717567, 66.76634654402733, 65.6211107969284, 71.6755311191082, 62.8463438898325, 67.17093363404274, 61.78764849901199, 65.26584506034851, 61.18662714958191, 69.14093792438507, 68.5717436671257, 77.61653512716293, 72.76408910751343, 81.28953963518143, 25.200713239610195, 5.79265664331615, 71.81258976459503, 49.215156733989716, 68.21719989180565, 42.45409972965717, 67.49181881546974, 61.824369728565216, 46.1650376021862, 75.29498130083084, 23.21985673159361, 0.5747759796213359, 0.39262390695512295, 0.2970177121460438, 0.2709211577894166, 0.23374760407023132, 0.19561862427508458, 0.1594614566420205, 0.22829473338788375, 0.13747764722211286, 0.13945309590781108], [0.057341591236763634, 0.009316100004070904, 0.02201079947553808, 0.050023573567159474, 0.0864324851136189, 0.03695319523103535, 0.044247048572287895, 0.03654549640486948, 0.05392064296756871, 0.0843413059192244, 0.14960644795792177, 0.5866922589484602, 26.681066304445267, 60.39536900818348, 34.43231597542763, 39.639115780591965, 53.7912891805172, 21.735859662294388, 20.764244198799133, 60.66114954650402, 53.49187284708023, 5.85189831443131, 1.2189829023554921, 12.442335449159145, 69.24382880330086, 71.16722479462624, 73.30923065543175, 68.40294152498245, 68.55089798569679, 66.1247281730175, 62.285550981760025, 61.05531379580498, 59.11272123456001, 58.16768914461136, 59.056822434067726, 54.36355747282505, 47.35243208706379, 49.76101264357567, 46.89293794333935, 46.6729411482811, 45.06554760038853, 44.405625611543655, 45.407799035310745, 47.366046756505966, 45.82634657621384, 44.515276327729225, 44.995289370417595, 42.962960824370384, 45.922112837433815, 44.65865023434162, 43.35937075316906, 44.4755494594574, 50.930141508579254, 52.63541400432587, 56.80317476391792, 57.53705598413944, 50.20074024796486, 54.688896015286446, 58.3234503865242, 55.203680992126465, 51.53180122375488, 50.04615694284439, 48.89759257435799, 50.07847800850868, 52.43494436144829, 50.743126943707466, 47.53814332187176, 50.131097584962845, 46.70824125409126, 50.191081166267395, 51.45698703825474, 54.69179905951023, 33.073265701532364, 14.842631500214338, 44.80027623474598, 45.09632594883442, 37.69757576286793, 37.98074036836624, 38.41458968818188, 36.81455634534359, 35.38135685026646, 35.87905414402485, 37.185610234737396, 37.08611637353897, 36.3029707968235, 37.36199676990509, 35.315874963998795, 34.58629131317139, 38.49343925714493, 39.58521567285061, 42.28147119283676, 43.4166868776083, 46.20085448026657, 39.33555766940117, 39.22966115176678, 53.159348890185356, 42.37525016069412, 46.52949124574661, 49.77237023413181, 60.29122419655323, 44.959814473986626, 48.21595095098019, 35.86620323359966, 14.097202699631453, 50.26271492242813, 50.812807604670525, 53.32129620015621, 44.392029941082, 41.67196869850159, 41.33650749921799, 44.075050950050354, 44.51490014791489, 46.274312138557434, 45.43410122394562, 47.89114437997341, 45.25758549571037, 46.82397544384003, 45.495076552033424, 47.963291108608246, 44.200459420681, 44.71769906580448, 41.61321245133877, 44.33941036462784, 41.68331488966942, 42.74034596979618, 43.751912489533424, 49.68329921364784, 51.26357741653919, 56.56106695532799, 52.72584155201912, 54.52852562069893, 48.80308784544468, 44.54398758709431, 38.35313938558102, 42.20485210418701, 42.7686620503664, 41.77243150770664, 43.749298229813576, 43.538014367222786, 46.802913174033165, 61.4366689324379, 59.18934792280197, 60.29537737369537, 59.84567530453205, 65.82080528140068, 59.955535009503365, 59.697893634438515, 56.563251838088036, 56.675775200128555, 53.58312115073204, 63.40274803340435, 64.51669245958328, 69.20209184288979, 63.60656149685383, 68.10191407799721, 5.446981117129326, 8.379114679992199, 53.84968064725399, 39.69156056642532, 47.0249542593956, 24.952700547873974, 57.075361758470535, 65.29609903693199, 42.44955897331238, 48.30097138881683, 7.012541759759188, 0.3021862363675609, 0.12442827908671461, 0.07366430931142531, 0.008401835293625481, 0.03458217441220768, 0.0249025519224233, 0.030470227284240536, 0.02502513802028261, 0.04252140308381058, 0.08010296733118594, 0.06137085198133718, 0.03170670839608647, 0.05081210176285822, 0.09753594946232624, 0.010071209289890248, 0.03207725159882102, 0.03271983274316881, 0.06409458219422959, 0.013481348178174812, 0.13022110535530373, 0.03954382867959794, 0.9447709133382887, 29.367782436311245, 69.19288113713264, 35.88929459452629, 56.14757314324379, 53.91745001077652, 24.578251540660858, 28.725622594356537, 65.74534893035889, 60.299177169799805, 9.107915572822094, 0.9802146395668387, 19.516007378697395, 74.69918087124825, 72.57058829069138, 74.3632560968399, 71.17993131279945, 72.01458692550659, 68.89793336391449, 66.05353519320488, 64.4256341457367, 63.19934494793415, 60.81867769360542, 61.516829431056976, 56.76801145076752, 50.80499142408371, 52.4329836666584, 48.42241287231445, 48.40833082795143, 49.38410706818104, 46.63042522966862, 47.73085758090019, 49.64783191680908, 47.07794241607189, 47.591401264071465, 47.568043917417526, 44.066459611058235, 47.97462210059166, 46.36932983994484, 46.64639197289944, 48.096701949834824, 56.02582387626171, 56.51780627667904, 58.43816623091698, 60.82182392477989, 55.24004124104977, 58.69855485856533, 60.552281588315964, 55.7421462982893, 52.864446714520454, 51.84682331979275, 52.082631066441536, 52.65549972653389, 54.58311349153519, 54.43975478410721, 50.09119972586632, 51.16799354553223, 49.53443840146065, 51.782146990299225, 55.96933610737324, 57.87995718419552, 39.897346124053, 18.656028024852276, 44.48636367917061, 47.242074608802795, 39.702880159020424, 41.95905849337578, 42.470290660858154, 42.51868486404419, 37.694725915789604, 38.234619945287704, 40.5130460858345, 39.457683116197586, 40.87212301790714, 40.945375487208366, 36.27265602350235, 37.536608800292015, 43.14993359148502, 42.71428696811199, 43.801195845007896, 44.66278061270714, 46.959582567214966, 44.335249587893486, 40.88422156870365, 55.40139578282833, 44.149424359202385, 49.44552317261696, 50.24553604424, 60.13708546757698, 43.914121985435486, 50.86152099072933, 35.40974512696266, 19.458320774137974, 53.42711292207241, 50.930175706744194, 54.98947888612747, 45.888841822743416, 45.96481874585152, 44.48407240211964, 46.92519061267376, 46.778260096907616, 49.65512752532959, 48.398291766643524, 50.33889323472977, 48.543675765395164, 50.478607937693596, 49.71872851252556, 52.27917172014713, 49.706565365195274, 48.38838949799538, 45.84294408559799, 49.039089381694794, 44.49134521186352, 46.20669476687908, 47.42157697677612, 53.41968812048435, 55.82778990268707, 60.543751046061516, 55.20908810198307, 57.475282698869705, 51.74352206289768, 47.74743989109993, 42.22838044166565, 44.70921412110329, 43.41176234185696, 47.04548455774784, 47.106319293379784, 46.10411927103996, 48.858215287327766, 63.11023972928524, 62.441122233867645, 63.17401930689812, 63.309607431292534, 68.51952686905861, 62.19408608973026, 64.22115191817284, 59.76780608296394, 58.95043954253197, 57.59212262928486, 67.2290401160717, 68.7368144094944, 73.35235074162483, 69.38391968607903, 69.37150955200195, 3.984360988251865, 11.2778290361166, 60.63456617295742, 44.3828534334898, 56.72524854540825, 30.745478309690952, 65.31125262379646, 80.6783652305603, 48.8302905857563, 59.33015316724777, 8.74432923272252, 0.2868898899760097, 0.23602249450050294, 0.15668963897041976, 0.014517859453917481, 0.06907133545610122, 0.044346451832097955, 0.028950631676707417, 0.09137685105088167, 0.12462111131753772, 0.017363468869007193, 0.14505739440210164, 0.08358822640730068, 0.1796980426297523, 0.19784140109550208, 0.1431629733997397, 0.12531264452263713, 0.11967422207817435, 0.11615059396717697, 0.1175340537156444, 0.3983682784019038, 0.41668938123621047, 0.9415241063106805, 41.08116500079632, 83.34288865327835, 43.38988311588764, 56.60264432430267, 67.23584935069084, 35.35345874726772, 29.4834653288126, 75.17493054270744, 63.37164670228958, 10.15384554862976, 0.7988793449476361, 24.888352900743484, 78.13222825527191, 75.33319965004921, 76.90227225422859, 73.80917742848396, 73.26497063040733, 73.99689495563507, 67.4833756685257, 66.3644877076149, 65.44525623321533, 62.97882378101349, 63.62988844513893, 60.555822998285294, 52.38768629729748, 54.447358176112175, 51.40545800328255, 51.681019216775894, 50.765275955200195, 49.40101236104965, 49.50548395514488, 53.028472512960434, 49.73098665475845, 50.38217671215534, 50.553862899541855, 46.021610498428345, 50.53892210125923, 49.93308261036873, 49.18171472847462, 50.30912943184376, 56.31919473409653, 57.816352397203445, 59.31943014264107, 62.42648921906948, 54.47470910847187, 60.30142284929752, 64.57135632634163, 58.64745520055294, 55.50722770392895, 57.31814593076706, 52.82276675105095, 55.69914400577545, 58.59342969954014, 58.14193792641163, 54.65879783034325, 53.54863420128822, 52.1308808773756, 56.615784019231796, 58.43970134854317, 60.97341299057007, 42.02458597719669, 27.90487613528967, 48.49155396223068, 43.62654201686382, 44.7033928334713, 46.25825800001621, 45.89025154709816, 47.49722711741924, 41.3673048466444, 42.233521565794945, 45.840177834033966, 44.381443709135056, 44.45143215358257, 44.170167446136475, 42.38954499363899, 37.8373246639967, 45.106004029512405, 45.51342576742172, 46.44806921482086, 49.515648409724236, 51.21053606271744, 47.46737211942673, 43.564639538526535, 59.63162899017334, 48.80810737609863, 50.608374774456024, 51.32629685103893, 60.48933416604996, 48.81609834730625, 55.2694820612669, 43.528203293681145, 25.75496479868889, 55.58262325823307, 57.35897094011307, 55.769618824124336, 50.513919442892075, 47.82708361744881, 47.47824713587761, 50.28372399508953, 50.010419860482216, 51.40744149684906, 52.628270387649536, 52.85466983914375, 51.56273916363716, 53.568925112485886, 52.579321414232254, 58.14553253352642, 51.46557457745075, 51.37084946036339, 49.04500186443329, 52.256646528840065, 45.23498050868511, 49.153945818543434, 50.5611053109169, 55.728455632925034, 59.5688221603632, 63.74342255294323, 58.80926191806793, 61.52723327279091, 57.465437427163124, 51.70094154775143, 44.35886912047863, 49.45488587021828, 46.90088331699371, 49.415079206228256, 48.82043391466141, 51.369895711541176, 53.18763077259064, 67.48033583164215, 65.9957554936409, 65.12902960181236, 65.22101506590843, 73.46502229571342, 65.57752713561058, 68.0932505428791, 62.15446561574936, 65.63574761152267, 60.209456384181976, 70.96909582614899, 70.42167440056801, 77.40790352225304, 70.06916731595993, 83.04056167602539, 8.030132856220007, 11.970432121306658, 68.1531885266304, 54.30004008114338, 56.69705405831337, 37.799060717225075, 78.84046465158463, 78.970265686512, 56.597294211387634, 73.86158421635628, 14.424745123833418, 0.7250995945651084, 0.3500844771042466, 0.2486127329757437, 0.3219885175349191, 0.18481357750715688, 0.19355537951923907, 0.10394946351880208, 0.2286206401186064, 0.279501483310014, 0.1943464792566374], [0.13799029315123335, 0.03631608000432607, 0.0929661825648509, 0.058393793369759806, 0.048633159894961864, 0.05902792887354735, 0.033817138901213184, 0.10894252176512964, 0.023278703120013233, 0.14429532748181373, 0.07128469442250207, 0.3832498990232125, 10.127314422279596, 62.99567207694054, 38.91717351973057, 49.145662263035774, 57.72458352148533, 34.90957036614418, 16.966560781002045, 47.95323684811592, 67.00241267681122, 18.692791052162647, 0.43592136644292623, 27.803446277976036, 71.55490279197693, 71.94965600967407, 73.31786379218102, 66.45777270197868, 63.805469423532486, 59.58611503243446, 60.57048261165619, 57.08606958389282, 57.88332000374794, 55.34491181373596, 53.59129451215267, 50.79350084066391, 48.235690891742706, 46.59639045596123, 47.68440127372742, 44.74945776164532, 44.14522558450699, 44.429473131895065, 45.853374525904655, 45.831609293818474, 46.53976209461689, 47.00332202017307, 46.807723715901375, 43.93625199794769, 44.05355550348759, 44.39243271946907, 44.74778585135937, 44.12523865699768, 53.569654673337936, 54.318963065743446, 54.98557649552822, 56.16508640348911, 58.882521986961365, 54.45191033184528, 59.92537222802639, 56.34643167257309, 53.13332788646221, 45.523195043206215, 48.89656662940979, 51.993902027606964, 52.64141768217087, 51.691575050354004, 49.39904786646366, 50.44029079377651, 48.82058210670948, 48.857124745845795, 52.38276556134224, 50.73363125324249, 49.15582291781902, 16.55505806207657, 28.709568455815315, 42.1050276607275, 38.79748374223709, 35.470184683799744, 35.97201995551586, 35.18844120204449, 36.47963471710682, 36.26705512404442, 36.61237299442291, 38.234920129179955, 36.07575058937073, 31.50526273995638, 33.975770473480225, 42.03698851168156, 42.25956916809082, 45.1239200681448, 44.34292897582054, 42.87261687219143, 43.716600984334946, 47.9476473480463, 53.152315467596054, 53.114541694521904, 49.10003051161766, 48.39837536215782, 45.303764417767525, 36.447697430849075, 32.77281202375889, 39.7814105451107, 16.994413286447525, 26.697895601391792, 51.96148596704006, 50.70101760327816, 48.247584253549576, 44.83492657542229, 42.69236594438553, 42.138663455843925, 44.78421829640865, 47.91517049074173, 49.73923601210117, 46.38848461210728, 47.46645636856556, 43.773856312036514, 47.10148595273495, 44.064331725239754, 45.08035160601139, 45.88084325194359, 43.26461523771286, 42.92286917567253, 42.55323641002178, 42.70712435245514, 41.68231174349785, 45.16114667057991, 49.66560736298561, 50.74677474796772, 52.08866134285927, 51.4252245426178, 48.17732982337475, 42.37316407263279, 43.41772802174091, 43.30180004239082, 41.49152398109436, 41.76564887166023, 43.92349608242512, 44.268654361367226, 45.89461371302605, 44.296316877007484, 48.198730275034904, 55.09868122637272, 59.97827298939228, 58.99201311171055, 62.474632635712624, 57.222759649157524, 57.90350832045078, 53.44530254602432, 53.95289830863476, 57.543880417943, 64.77841481566429, 64.9448610842228, 69.52695161104202, 67.4072277545929, 46.80280297994614, 0.11982473704847507, 15.641440786421299, 52.49263286590576, 52.5159066170454, 30.844643488526344, 23.55695754289627, 57.91565626859665, 57.94448532164097, 50.542535707354546, 55.109301656484604, 3.9541383599862456, 0.2772883395664394, 0.0919869780773297, 0.08472197572700679, 0.08789985949988477, 0.14962302753701806, 0.04928547059535049, 0.0536509019730147, 0.023104975625756197, 0.11495321290567517, 0.07252992174471729, 0.02188680700783152, 0.06221393916348461, 0.0903404715063516, 0.09482186345849186, 0.05847026426636148, 0.06191295004100539, 0.03555274772224948, 0.05765461428381968, 0.022899096438777633, 0.1812573245842941, 0.13974189525470138, 0.35683291498571634, 9.237403124570847, 72.37364485859871, 42.57157422602177, 60.1124931871891, 64.94288519024849, 32.017720341682434, 21.660635098814964, 59.18754681944847, 73.3922865986824, 24.068624787032604, 0.2294347612769343, 35.12120001018047, 75.6063137948513, 75.63605859875679, 74.37011852860451, 69.12797302007675, 67.2008228302002, 64.01759684085846, 63.91858175396919, 59.90962587296963, 61.25185824930668, 59.63936157524586, 55.77118054032326, 54.43953439593315, 52.19354711472988, 49.6744304895401, 50.161229968070984, 48.92880029976368, 47.879972979426384, 47.58874900639057, 49.7095900028944, 50.19257448613644, 49.24587808549404, 49.52286422252655, 50.385797917842865, 45.647433176636696, 48.144845366477966, 45.911651998758316, 47.22586467862129, 46.88525475561619, 55.768950060009956, 57.16746121644974, 56.41826681792736, 57.60646305978298, 62.362105473876, 59.46615926921368, 62.00474604964256, 58.25592041015625, 54.235644936561584, 48.05283710360527, 51.86469756066799, 55.286972522735596, 54.365320578217506, 54.346032813191414, 52.71854214370251, 53.55331934988499, 52.57629297673702, 51.429647505283356, 57.763117253780365, 53.79087880253792, 55.50842083990574, 23.812279142439365, 31.499017775058746, 44.338266626000404, 41.63069151341915, 37.04442881047726, 39.395195469260216, 36.913955211639404, 41.085329577326775, 39.21087495982647, 42.42053233087063, 41.35020196437836, 39.66794863343239, 30.976650305092335, 36.029776856303215, 44.66647021472454, 41.79209165275097, 41.4151518791914, 43.19999970495701, 43.1438235193491, 41.83395780622959, 48.25281657278538, 53.10912698507309, 50.77723391354084, 49.859529957175255, 49.36768814921379, 45.736872777342796, 37.963078916072845, 36.59439615905285, 36.33263200521469, 19.33268241584301, 33.628355115652084, 53.28992888331413, 50.93220479786396, 51.79308280348778, 47.10653208196163, 45.91424725949764, 44.60660442709923, 47.25612625479698, 51.24500401318073, 51.03178225457668, 50.08824348449707, 50.17706751823425, 46.40270344913006, 51.28086268901825, 48.87500658631325, 48.482347056269646, 49.59645487368107, 46.26426547765732, 45.41286036372185, 46.00191995501518, 46.70044407248497, 44.46121282875538, 47.27111265063286, 53.02879549562931, 52.40018382668495, 54.59159083664417, 55.065072029829025, 52.67443411052227, 44.973018765449524, 46.279517859220505, 46.00018344819546, 45.12852542102337, 45.576069205999374, 46.04804947972298, 47.42178976535797, 48.721361830830574, 47.5078247487545, 49.63437303900719, 56.04180581867695, 60.225130543112755, 61.97548381984234, 64.15505066514015, 60.8436993509531, 60.06420537829399, 53.55371832847595, 57.07611411809921, 60.32216973602772, 70.73756664991379, 66.57334730029106, 73.10893580317497, 69.64177384972572, 46.068104803562164, 0.0774927152087912, 19.25481129437685, 58.40644933283329, 58.9534679800272, 42.52299763262272, 29.237723015248775, 62.83711038529873, 71.82496950030327, 54.54378180205822, 67.52413228154182, 5.436683669686317, 0.47657119925133884, 0.1301025546854362, 0.06590212738956325, 0.0381183856370626, 0.07597361312946305, 0.07442745976732112, 0.11034694718546234, 0.017745314980857074, 0.1079152557940688, 0.052480635276879184, 0.23725953593384475, 0.20257409167243168, 0.2402180334320292, 0.15909832378383726, 0.19400295394007117, 0.16092908335849643, 0.17126132268458605, 0.11505223767017014, 0.14908296667272225, 0.3070598904741928, 0.35033069201745093, 0.6045693496707827, 18.043356500566006, 83.27478110790253, 46.906491816043854, 66.05931848287582, 74.59065109491348, 53.14855746924877, 26.003074385225773, 62.53397025167942, 76.22014805674553, 23.691105544567108, 0.336926436284557, 37.72946745157242, 76.29012510180473, 75.65848499536514, 77.3208349943161, 71.62566259503365, 67.06403017044067, 63.53745460510254, 66.18221908807755, 60.69983147084713, 63.232251182198524, 62.13908404111862, 57.77997314929962, 55.99608667194843, 53.254678174853325, 52.44168519973755, 54.792999029159546, 51.66270039975643, 50.02734035253525, 49.73955899477005, 50.81940785050392, 52.556127458810806, 52.21394822001457, 51.56811207532883, 53.10053564608097, 47.1330888569355, 50.36882422864437, 50.76580412685871, 49.29644577205181, 49.02210809290409, 58.065273240208626, 58.439055383205414, 60.85210829973221, 59.406559467315674, 64.88246083259583, 60.03280386328697, 64.93033066391945, 62.58022136986256, 57.56010174751282, 51.87475562095642, 53.22013422846794, 58.60657699406147, 57.935882583260536, 58.28483685851097, 55.61869852244854, 58.15258875489235, 56.04421488940716, 55.86961045861244, 60.38382142782211, 57.695142701268196, 55.730325132608414, 30.123417489230633, 39.195314794778824, 45.987780913710594, 38.67072254419327, 40.29080741107464, 44.82297241687775, 40.82001641392708, 43.21530528366566, 43.48476022481918, 45.65622590482235, 45.91715410351753, 42.768380865454674, 36.37256406247616, 42.5398725271225, 50.865579172968864, 45.65417021512985, 46.5008407831192, 43.72630186378956, 45.02843879163265, 45.02808541059494, 50.13945713639259, 55.0930917263031, 54.637203589081764, 51.286030411720276, 52.330966740846634, 52.413296923041344, 43.23938079178333, 38.882758766412735, 41.75006590783596, 27.895509637892246, 36.630083844065666, 55.793850123882294, 55.383407548069954, 54.64802160859108, 51.983836367726326, 50.142185389995575, 47.19693683087826, 49.747983142733574, 52.75278590619564, 54.39036123454571, 51.34219519793987, 53.45762528479099, 49.1233878582716, 55.91205418109894, 51.915637627243996, 51.37261636555195, 54.32249307632446, 51.05483181774616, 48.700816333293915, 50.98374143242836, 50.681281462311745, 47.90523402392864, 49.939983040094376, 56.706963926553726, 54.64509956538677, 57.21302457153797, 58.27283330261707, 56.674506068229675, 47.97440931200981, 50.15792414546013, 50.08457288146019, 48.264117166399956, 48.33615370094776, 50.30126005411148, 49.9490949511528, 51.42596170306206, 50.61188958585262, 55.29900647699833, 60.96972718834877, 66.37470915913582, 65.10667160153389, 66.78457036614418, 62.49367721378803, 65.41087567806244, 56.83467507362366, 60.15050634741783, 61.352245062589645, 71.77213713526726, 69.62985768914223, 78.63424971699715, 75.8742906153202, 59.110338762402534, 0.40174148802179843, 19.570194371044636, 64.4721132516861, 63.63628730177879, 38.76931205391884, 35.52717782557011, 69.44533199071884, 77.21061810851097, 66.81634426116943, 76.22299030423164, 6.985608329996467, 0.5810823943465948, 0.3470110654598102, 0.2896249119658023, 0.12427592359017581, 0.27873591345269233, 0.1348460212466307, 0.23272885795449838, 0.10865853895666078, 0.30399808601941913, 0.16982436151010916], [0.14443379739532247, 0.03636362940596882, 0.04465499230718706, 0.045423979754559696, 0.2958786045201123, 0.10308768163667992, 0.05127361000631936, 0.01962876704055816, 0.10485822334885597, 0.2505756838945672, 0.3637232515029609, 0.5855015572160482, 4.7359618451446295, 65.08906334638596, 46.189246103167534, 31.163098700344563, 52.03104883432388, 35.83875350654125, 21.249740347266197, 37.40410231053829, 69.51106086373329, 33.600134029984474, 0.609765452099964, 41.42507314682007, 69.7292147576809, 68.73862311244011, 67.76405140757561, 67.37245962023735, 64.4930425286293, 59.0646044164896, 61.132240667939186, 57.01881319284439, 60.56901589035988, 55.183314085006714, 53.400157168507576, 51.06910765171051, 48.73998083174229, 44.34966221451759, 48.79458010196686, 47.4400781840086, 42.57841765880585, 40.1285333186388, 43.80881063640118, 45.0193876773119, 45.0295939296484, 44.7473868727684, 45.0398001819849, 45.50686351954937, 45.19039750099182, 47.11054466664791, 44.4112379103899, 43.512734323740005, 49.45468448102474, 51.547460183501244, 55.21379604935646, 55.12011967599392, 57.99557738006115, 55.543086379766464, 57.365331798791885, 54.59094487130642, 50.3298345208168, 45.52507594227791, 49.39786992967129, 52.905480712652206, 54.60580587387085, 51.628684625029564, 51.90323509275913, 46.71988382935524, 51.48023419082165, 50.48758305609226, 53.75859573483467, 48.907092064619064, 53.89671832323074, 23.754767328500748, 28.640547059476376, 33.39029788970947, 32.541313245892525, 40.0980019569397, 33.790032640099525, 32.887786254286766, 29.306073747575283, 34.61641609668732, 35.665425807237625, 35.964845940470695, 38.07106152176857, 16.227338947355747, 44.582977294921875, 71.36250391602516, 56.66516616940498, 36.73242375254631, 40.34811973571777, 36.525578051805496, 37.86909095942974, 41.57875970005989, 51.40021428465843, 46.60602293908596, 43.81053574383259, 38.51078152656555, 36.531938910484314, 39.975606724619865, 37.37704776227474, 21.067823208868504, 21.283626928925514, 35.28644174337387, 49.883145689964294, 48.905849531292915, 46.89264915883541, 42.66891360282898, 40.765405744314194, 41.23558111488819, 43.25265347957611, 48.38427051901817, 45.53927578032017, 47.65343673527241, 42.96595126390457, 44.095417857170105, 42.97493778169155, 43.97923529148102, 45.48806972801685, 44.318785071372986, 45.84790661931038, 41.798855289816856, 41.53765730559826, 42.87187971174717, 40.157160982489586, 43.49033832550049, 46.521021500229836, 48.96188512444496, 51.1376977711916, 49.59256388247013, 42.13470786809921, 38.8783548027277, 39.15161333978176, 42.710422575473785, 42.978695780038834, 41.397277638316154, 47.17604175209999, 46.21503911912441, 44.668206721544266, 46.17096148431301, 46.860985457897186, 46.01388171315193, 52.35658496618271, 53.67952197790146, 53.94254766404629, 57.71057367324829, 51.15020290017128, 51.07002340257168, 55.63541762530804, 63.38035963475704, 63.15569669008255, 66.33779793977737, 64.50258761644363, 66.50148555636406, 21.33682407438755, 0.5907426634803414, 23.757364489138126, 52.20124930143356, 43.76797042787075, 18.876828476786613, 22.54697173833847, 50.875287652015686, 45.71785859763622, 43.360970467329025, 58.20008620619774, 4.085851879790425, 0.3823093307437375, 0.05511119255970698, 0.27406884357333183, 0.03631234329077415, 0.1416462758788839, 0.07409800557070412, 0.08408414432778955, 0.11017683209502138, 0.23389558831695467, 0.10309505858458579, 0.05964772979496047, 0.10274861662765034, 0.03504053966025822, 0.11507289906148799, 0.3982542548328638, 0.2052807339350693, 0.057889663585228845, 0.0842348077276256, 0.11862196057336405, 0.12939049367560074, 0.26959256501868367, 0.974354047793895, 7.238833392038941, 75.4184290766716, 48.77158373594284, 32.76518203318119, 57.020393908023834, 37.91306599974632, 25.066650733351707, 43.9548671990633, 77.80383467674255, 38.11368763446808, 1.2589848996140063, 43.81959065794945, 71.04030400514603, 70.68383753299713, 69.1621407866478, 69.62231129407883, 64.42080840468407, 62.26643420755863, 63.764264434576035, 61.70997306704521, 64.02426928281784, 56.716018840670586, 54.514280185103416, 53.13321389257908, 51.88873887062073, 49.018270298838615, 51.701496317982674, 51.508280485868454, 45.366191267967224, 41.54716059565544, 47.88854531943798, 49.03286911547184, 47.78289578855038, 47.90672354400158, 47.10021682083607, 48.02476420998573, 48.6761062592268, 51.21647894382477, 47.558738216757774, 46.06314606964588, 52.546616569161415, 53.683462366461754, 57.01074242591858, 56.476289704442024, 60.43408893048763, 56.44458420574665, 61.39702945947647, 57.052661776542664, 53.174259290099144, 48.04544270038605, 47.84103266894817, 55.116281881928444, 55.9226556122303, 52.92763352394104, 54.99240852892399, 48.96813578903675, 54.43502403795719, 53.98379445075989, 57.180194333195686, 50.270162522792816, 57.89591632783413, 31.434805020689964, 34.44684259593487, 39.92133803665638, 37.48989410698414, 43.77043269574642, 36.699464321136475, 35.14268025755882, 30.87811019271612, 35.59541076421738, 36.63549855351448, 37.814924865961075, 40.879756808280945, 17.40931872278452, 56.18398658931255, 76.13095924258232, 59.15890395641327, 36.94003701210022, 41.403813287615776, 36.605875343084335, 36.09235569834709, 42.649074867367744, 49.15553033351898, 47.61589094996452, 43.23834724724293, 39.19145420193672, 38.064807057380676, 39.60185877978802, 37.64761604368687, 25.437421537935734, 26.258179396390915, 38.50886642932892, 51.31570681929588, 49.63621214032173, 46.4223749935627, 45.065596997737885, 43.547798842191696, 45.59012085199356, 43.8240098208189, 49.01956982910633, 48.19497607648373, 50.70932015776634, 46.1610060185194, 45.6802824139595, 46.69615410268307, 46.657399982213974, 46.72582671046257, 45.887211710214615, 46.77303537726402, 46.78660064935684, 46.60771004855633, 45.62267370522022, 46.18160091340542, 45.43363004922867, 47.979360446333885, 51.7648009210825, 53.23745749890804, 51.372236385941505, 43.593065813183784, 40.029054656624794, 43.180377557873726, 44.04062479734421, 46.17254599928856, 46.204802468419075, 49.567261040210724, 52.04739935696125, 49.76094804704189, 50.32714046537876, 52.03022427856922, 48.887986689805984, 52.99360178411007, 54.44221705198288, 54.487628415226936, 61.48903012275696, 54.32229928672314, 55.47047607600689, 60.41398040950298, 68.10369998216629, 65.39169430732727, 68.88134345412254, 68.05685609579086, 69.25151959061623, 21.139743849635124, 0.586887770332396, 30.622032433748245, 57.26557955145836, 52.8204944729805, 26.766183637082577, 28.960681781172752, 61.08818203210831, 59.5187446475029, 48.12570199370384, 69.50584754347801, 5.548559641465545, 0.15654635993996635, 0.09791549120564014, 0.14850164239760488, 0.13191284582717344, 0.1617253929725848, 0.14621836569858715, 0.11125498713226989, 0.38938992423936725, 0.1265756759676151, 0.07465791888535023, 0.17438059905543923, 0.22321195690892637, 0.21277302643284202, 0.13580511353211477, 0.6090630241669714, 0.27137410535942763, 0.15095628099516034, 0.24513602344086394, 0.22660113754682243, 0.29414242424536496, 0.5998444813303649, 1.538605245295912, 10.190548729151487, 90.50462275743484, 61.91368393599987, 43.63828718662262, 67.92137056589127, 48.85115526616573, 29.399520233273506, 49.12713445723057, 86.09549134969711, 38.777086436748505, 1.4699031505733728, 47.63677462935448, 72.86375775933266, 73.62937107682228, 69.99631002545357, 75.25949880480766, 68.26847434043884, 61.990211829543114, 66.49346798658371, 63.21873530745506, 67.28010177612305, 62.56874978542328, 59.58358436822891, 57.387070432305336, 58.121749609708786, 51.72185182571411, 53.86742949485779, 54.273118525743484, 46.16599515080452, 41.7893747985363, 47.8005800396204, 51.68448843061924, 48.675631284713745, 49.38456304371357, 48.37429225444794, 50.9017950296402, 50.6844998896122, 56.947472020983696, 53.68450731039047, 49.77382555603981, 58.00200663506985, 53.94284784793854, 59.45641279220581, 59.23232361674309, 63.805743008852005, 57.8197418153286, 64.49190258979797, 61.40656694769859, 57.48851738870144, 52.04661279916763, 50.26013106107712, 58.064783066511154, 58.181972578167915, 56.10265575349331, 56.65501311421394, 50.942962020635605, 54.70265507698059, 57.79182471334934, 61.52485080063343, 54.385934472084045, 57.86339767277241, 34.8305232077837, 41.88751593232155, 40.79467177391052, 40.62543645501137, 41.071825101971626, 39.457648918032646, 38.42543050646782, 34.35102693736553, 35.857209116220474, 39.06139478087425, 37.90350951254368, 43.387329652905464, 16.080102548003197, 65.0192154943943, 81.57004818320274, 59.721912145614624, 37.51998849213123, 43.5318510979414, 36.92924179136753, 38.062842562794685, 43.12556929886341, 51.99951812624931, 47.92804040014744, 45.05118817090988, 40.42567737400532, 38.35025534033775, 38.64347040653229, 37.57660545408726, 28.214798904955387, 32.40851417183876, 43.48753787577152, 53.56268584728241, 52.22934119403362, 48.983068987727165, 47.85861812531948, 45.9817848354578, 47.4267902970314, 46.39628179371357, 53.110160529613495, 52.48798191547394, 54.34727534651756, 49.91824060678482, 48.23186829686165, 50.27359373867512, 47.26314067840576, 50.438337698578835, 47.82554090023041, 51.42275467514992, 51.45651586353779, 51.968724578619, 51.60093851387501, 50.432182028889656, 49.81116235256195, 50.84164805710316, 52.43290387094021, 56.73647314310074, 55.27923233807087, 49.15596351027489, 41.45189970731735, 43.487754464149475, 48.2759003341198, 49.31045942008495, 48.41399632394314, 53.55329655110836, 55.4873813688755, 54.70241189002991, 53.486971110105515, 55.116832852363586, 51.85595043003559, 59.031242206692696, 59.21808198094368, 54.8962926864624, 62.89791092276573, 56.58818989992142, 57.22574628889561, 61.786793544888496, 72.54585921764374, 69.17684599757195, 70.67100942134857, 68.32363978028297, 74.64379504323006, 30.074001140892506, 0.5081738659646362, 30.652858279645443, 64.99527677893639, 54.569673612713814, 24.33872949331999, 36.282212510704994, 62.113351821899414, 58.17601069808006, 54.71301332116127, 81.38720959424973, 6.217995844781399, 0.6627998000476509, 0.19552830490283668, 0.25200514937750995, 0.30573687865398824, 0.26432955055497587, 0.3335948759922758, 0.3666566050378606, 0.4435640625888482, 0.5772432347293943, 0.19169178733136505], [0.25950567971449345, 0.19110394699964672, 0.054529389599338174, 0.10681933374144137, 0.13028760178713128, 0.18477552017429844, 0.05608267500065267, 0.045125243050279096, 0.07926527556264773, 0.24270722642540932, 0.14064412418520078, 0.1832430000649765, 3.740385342389345, 57.23056063055992, 46.079363599419594, 40.54063260555267, 31.33950613439083, 28.154349848628044, 25.48576634377241, 25.776513442397118, 54.61107239127159, 47.310470938682556, 2.099403734318912, 33.97782236337662, 67.9509025812149, 58.892842233181, 67.32265189290047, 61.24391287565231, 57.3282115906477, 58.82939703762531, 60.41985869407654, 59.27671663463116, 61.33169576525688, 47.25771076977253, 45.77021598815918, 44.84168641269207, 44.13891792297363, 44.5610448718071, 51.37264296412468, 49.0204893797636, 47.055823802948, 44.89022500813007, 47.27258317172527, 44.691066294908524, 43.50383140146732, 48.02647411823273, 45.09771287441254, 47.04156316816807, 44.2622023075819, 43.36011551320553, 41.83331184089184, 41.53032749891281, 45.68966031074524, 56.2221859395504, 60.42092643678188, 58.29131931066513, 63.60732905566692, 54.5632291585207, 54.462724551558495, 54.74799804389477, 46.282451301813126, 46.38420604169369, 50.39584077894688, 53.332539796829224, 50.40464110672474, 50.447214022278786, 50.74334733188152, 46.57290771603584, 48.69298875331879, 46.851869747042656, 50.72020657360554, 46.896692141890526, 56.26136563718319, 36.17230340838432, 25.483906343579292, 40.41157253086567, 33.132443726062775, 34.80801321566105, 34.59091566503048, 33.533155024051666, 30.304112993180752, 34.65450905263424, 35.15022665262222, 37.95431658625603, 44.96172197163105, 28.404146544635296, 93.76664131879807, 90.21640062332153, 59.148405119776726, 39.99043732881546, 40.05305036902428, 35.65509036183357, 35.2530225366354, 38.9602480083704, 44.541996493935585, 41.04635886847973, 39.19519700109959, 39.452408999204636, 39.35884281992912, 35.947104692459106, 26.348483450710773, 32.702466398477554, 27.973010279238224, 35.58116152882576, 46.29994176328182, 44.177216067910194, 44.34544824063778, 41.47197782993317, 41.739513874053955, 45.29667019844055, 44.23123776912689, 47.43003532290459, 45.564141646027565, 45.69295473396778, 43.5560368001461, 43.703316897153854, 40.35996749997139, 39.6927423030138, 41.11636631190777, 42.98471465706825, 44.2152938246727, 41.49462081491947, 40.632868856191635, 39.55206245183945, 41.91812328994274, 41.61762401461601, 44.444478526711464, 46.61237619817257, 47.11098924279213, 43.88880014419556, 39.17752794921398, 38.36059458553791, 40.43179124593735, 42.40830458700657, 41.7058514803648, 44.85385715961456, 48.40170778334141, 46.051074117422104, 45.96394099295139, 47.47101232409477, 48.771861121058464, 48.05448241531849, 43.247424960136414, 45.03374330699444, 51.46520979702473, 52.05197811126709, 52.19481244683266, 53.88876534998417, 57.64170616865158, 64.17545557022095, 64.51311305165291, 68.9816352725029, 64.49617356061935, 62.77377538383007, 6.8945675902068615, 1.1313535482622683, 32.81172573566437, 51.07326842844486, 32.95028530061245, 25.286275148391724, 33.44002582132816, 47.861236184835434, 49.224922209978104, 27.98160921782255, 62.958411276340485, 5.7669643219560385, 0.597939892904833, 0.1990798080805689, 0.48417705518659204, 0.06946347144548781, 0.0706800444459077, 0.26664822769816965, 0.14100060740020126, 0.04807512792467605, 0.5596078466624022, 0.48287615936715156, 0.0689633826550562, 0.16757143865106627, 0.07979534711921588, 0.18580578442197293, 0.15830314223421738, 0.38394876464735717, 0.1451603599707596, 0.04297145627788268, 0.11721454429789446, 0.23260730900801718, 0.15431838808581233, 0.3759437520056963, 3.850129866041243, 68.87617573142052, 47.85348080098629, 42.42841310799122, 38.19594942033291, 32.43051499128342, 29.305980652570724, 31.915350034832954, 61.30942516028881, 53.067215234041214, 2.74020419921726, 34.54547390341759, 71.02920100092888, 62.03393988311291, 70.45144960284233, 64.33622494339943, 61.17792561650276, 59.85498480498791, 64.26787421107292, 62.76450768113136, 66.00695729255676, 51.62822484970093, 47.70820699632168, 49.80166666209698, 49.12496097385883, 48.22379373013973, 53.39549481868744, 52.139783799648285, 50.86966395378113, 47.58896939456463, 48.68487238883972, 49.52178508043289, 46.14542305469513, 49.41056124866009, 48.5812671482563, 48.326175436377525, 48.869318291544914, 46.35260693728924, 46.23137824237347, 45.481416285037994, 46.669080555438995, 55.33919312059879, 62.963514402508736, 60.33791609108448, 64.63957786560059, 57.291953936219215, 57.48171955347061, 56.375325322151184, 49.32985357940197, 50.44836536049843, 53.58358472585678, 56.459551602602005, 54.23713445663452, 53.913768008351326, 52.668255642056465, 50.40962643921375, 51.169714853167534, 51.4231688529253, 54.45256769657135, 50.6860464066267, 55.46896755695343, 43.25959570705891, 31.36461328715086, 43.88715483248234, 36.887501031160355, 40.13566553592682, 39.91905435919762, 37.22216047346592, 31.478523574769497, 37.75708816945553, 34.6575640887022, 40.36378249526024, 45.49720823764801, 31.33442010730505, 94.23971593379974, 82.59369045495987, 55.79905964434147, 37.95357942581177, 38.013741597533226, 36.134221851825714, 34.65162880718708, 40.45683570206165, 45.407430455088615, 41.49430923163891, 37.003265619277954, 38.31845484673977, 38.5809675604105, 35.801701694726944, 27.049977108836174, 36.34244687855244, 32.0624515414238, 38.305983915925026, 49.94591072201729, 45.58763958513737, 44.17389504611492, 43.324826806783676, 47.25096993148327, 48.61446596682072, 47.67397083342075, 51.39526315033436, 49.79037366807461, 49.4378437846899, 48.72992277145386, 48.22969861328602, 42.60720491409302, 39.77228723466396, 42.406533882021904, 43.016142770648, 47.32090897858143, 45.95975361764431, 43.3182417601347, 42.66139380633831, 46.36330336332321, 43.65406394004822, 45.38447968661785, 47.76929251849651, 49.10248517990112, 45.331119149923325, 42.82715231180191, 38.06027390062809, 41.05127580463886, 44.17348846793175, 45.15037044882774, 47.589353173971176, 52.32745572924614, 51.02058045566082, 48.864439353346825, 50.65381273627281, 54.99792203307152, 50.75203366577625, 48.92924107611179, 50.42058885097504, 53.79921555519104, 57.7287632972002, 56.63416363298893, 54.872388169169426, 60.414531379938126, 67.73784041404724, 68.58346223831177, 71.1301539838314, 67.58641093969345, 68.22766453027725, 5.324685629457235, 1.467174778226763, 40.47144591808319, 55.280170887708664, 41.45766779780388, 27.536257915198803, 41.07339061796665, 58.70337300002575, 53.402326852083206, 30.220663771033287, 77.59787812829018, 11.466374918818474, 0.3485593042569235, 0.2921574463834986, 0.3304661001311615, 0.36334819975309074, 0.10351362245273776, 0.3110335866222158, 0.12681357882684097, 0.058220268110744655, 0.571748788934201, 0.4917786957230419, 0.239042115281336, 0.21043912041932344, 0.12966286187293008, 0.27974374999757856, 0.18629165366292, 0.3729887871304527, 0.22942569223232567, 0.20915226603392512, 0.2755805687047541, 0.38340667029842734, 0.2945462119532749, 0.44559095695149153, 5.657322630286217, 80.23687452077866, 58.47273297607899, 52.98785649240017, 45.40235012769699, 38.21305990219116, 34.99552935361862, 38.399743884801865, 68.69790449738503, 55.024562403559685, 3.0512840067967772, 38.15226696431637, 71.53989359736443, 64.67083498835564, 70.92029124498367, 71.4987114071846, 65.87821260094643, 58.95754516124725, 65.61272084712982, 65.7898673415184, 70.49693316221237, 55.36031998693943, 52.57110245525837, 54.45165954530239, 54.913102984428406, 51.38562686741352, 55.57854227721691, 55.94732008874416, 52.99623504281044, 45.46673387289047, 48.5547711700201, 50.782777816057205, 48.820946887135506, 51.88389033079147, 49.844505563378334, 48.50538142025471, 52.57905922830105, 51.08379386365414, 52.17724218964577, 47.00714461505413, 47.30651155114174, 56.9690016657114, 62.697186693549156, 60.936836153268814, 68.28225240111351, 60.30391551554203, 59.33239504694939, 60.026196017861366, 51.379345804452896, 53.97908270359039, 53.394077494740486, 55.86763076484203, 54.48036700487137, 56.593315824866295, 55.38932003080845, 52.61934466660023, 54.38347600400448, 57.81789131462574, 62.40411601960659, 53.42549420893192, 58.21436204016209, 45.125785768032074, 40.39639614522457, 48.83626766502857, 42.83109650015831, 45.8312027156353, 46.0315203666687, 41.26896612346172, 32.522447258234024, 36.80401191115379, 36.25294268131256, 41.936005130410194, 50.336807146668434, 26.56783238053322, 90.07931157946587, 77.28548929095268, 60.017277896404266, 41.06346555054188, 39.94463458657265, 37.50426113605499, 34.68374468386173, 41.39549933373928, 46.21422976255417, 43.18210266530514, 37.914449125528336, 37.658950835466385, 41.87916778028011, 39.861924424767494, 31.79930616170168, 40.019399374723434, 38.73579405248165, 40.39714090526104, 50.82414239645004, 47.06547528505325, 46.14710256457329, 45.56449882686138, 50.96315033733845, 52.859206795692444, 50.11683315038681, 55.16017712652683, 52.6455632597208, 52.36896850168705, 52.247367426753044, 50.92474199831486, 45.332559272646904, 41.029643565416336, 45.785605162382126, 45.85763409733772, 48.25127385556698, 49.90804195404053, 49.429982006549835, 48.39645266532898, 51.93000465631485, 45.62219113111496, 46.3849052041769, 50.312127470970154, 52.72833801805973, 49.66941095888615, 48.9510253071785, 37.834657207131386, 40.846896171569824, 46.484619453549385, 46.99574902653694, 49.04738813638687, 59.05996486544609, 56.83097027242184, 53.15536290407181, 53.790035247802734, 61.60521648824215, 56.93602703511715, 52.3695232719183, 54.08419646322727, 54.43315453827381, 57.33842544257641, 59.15660507977009, 55.41727513074875, 59.20302338898182, 69.39003735780716, 69.73856985569, 72.16442808508873, 69.02661725878716, 76.38777986168861, 10.054279491305351, 1.002153712324798, 42.71939769387245, 61.81984797120094, 40.89012265205383, 31.01611688733101, 50.99238596856594, 60.75557067990303, 66.02061375975609, 38.681301176548004, 86.30064994096756, 10.800090171396732, 0.9480330976657569, 0.3782015136675909, 0.6441758119035512, 0.4936223092954606, 0.1770211011171341, 0.3974862804170698, 0.4464068741071969, 0.16824498219648376, 0.7371306989807636, 0.5873196409083903], [0.08232395557570271, 0.07271639376995154, 0.06063034074031748, 0.16563428478548303, 0.19560746237402782, 0.17702496028505266, 0.1504145428771153, 0.10502184464712627, 0.020289410203986336, 0.053608555026585236, 0.03698849548527505, 0.09918592186295427, 2.2903795866295695, 58.433378487825394, 52.98224799335003, 44.90075424313545, 25.143549107015133, 30.608450062572956, 18.56355808675289, 32.29057230055332, 47.25388437509537, 61.06371134519577, 5.3617725893855095, 27.66140230000019, 78.43926697969437, 64.36002686619759, 68.06508645415306, 57.04863019287586, 63.61304014921188, 61.710182055830956, 59.09768924117088, 55.28118923306465, 54.5256719738245, 46.411044001579285, 47.92253449559212, 44.3498370051384, 44.74184297025204, 43.87727916240692, 48.25449988245964, 45.81872798502445, 48.05015064775944, 47.83937595784664, 46.128920540213585, 43.864656239748, 45.00255078077316, 41.61974810063839, 44.686187356710434, 43.91167871654034, 42.07960322499275, 38.87759104371071, 41.867540404200554, 43.66604469716549, 48.27001824975014, 51.273358091712, 58.74906934797764, 53.83887402713299, 54.2225356400013, 53.369466215372086, 59.66839961707592, 54.88487049937248, 51.7357362806797, 50.87030991911888, 56.84148050844669, 53.51720608770847, 53.3143425732851, 50.17878882586956, 51.45299345254898, 47.06992484629154, 46.968979462981224, 42.86016494035721, 48.14102277159691, 46.83609299361706, 53.528141900897026, 40.93290455639362, 23.417410030961037, 35.8609215170145, 38.9823704212904, 34.64337185025215, 32.13579140603542, 34.628351256251335, 32.937555983662605, 37.39054083824158, 38.90904575586319, 40.430879294872284, 37.96658992767334, 38.62623453140259, 53.19006644189358, 43.42416487634182, 42.72695168852806, 46.74728415906429, 43.76084581017494, 40.06163410842419, 39.35473904013634, 37.92572312057018, 42.246205285191536, 42.04246401786804, 37.24882364273071, 37.360628843307495, 32.52437375485897, 33.484703823924065, 33.96779090166092, 35.872602090239525, 26.717158667743206, 38.50286275148392, 48.832471668720245, 45.11694744229317, 41.94891683757305, 40.44644705951214, 40.90153343975544, 44.033298790454865, 44.04582291841507, 46.48392029106617, 47.98904612660408, 44.17892977595329, 44.99659650027752, 45.28741009533405, 42.21486836671829, 43.92432063817978, 44.745296984910965, 45.54855868220329, 46.21500872075558, 44.01494197547436, 41.27294830977917, 39.89873684942722, 41.362745091319084, 45.460312217473984, 45.32461389899254, 42.96463653445244, 41.303019896149635, 39.20020893216133, 40.528336465358734, 44.88745115697384, 40.63241668045521, 42.16129504144192, 41.73995845019817, 44.11216355860233, 42.24013701081276, 42.12595693767071, 42.16769389808178, 45.9994500875473, 43.41786481440067, 45.6527528911829, 46.775619238615036, 48.89601565897465, 50.000471994280815, 51.05173498392105, 52.298596277832985, 56.7091716080904, 60.66342182457447, 63.54601174592972, 64.7928312420845, 70.22745162248611, 62.951096668839455, 48.8517290353775, 0.5461527686566114, 3.779571452178061, 43.16366225481033, 45.82359932363033, 19.95361279696226, 30.522156693041325, 31.035296358168125, 41.7717969417572, 50.37755236029625, 43.37066374719143, 64.44777175784111, 11.21260553598404, 0.5260202614590526, 0.33582206116989255, 0.3505826066248119, 0.054878403097973205, 0.10260685157845728, 0.07435588704538532, 0.07327131243073381, 0.05376988679927308, 0.2252224349649623, 0.08708616136573255, 0.05874782749742735, 0.09173897458822466, 0.07829329959349707, 0.12085457827197388, 0.05544176739931572, 0.22566324099898338, 0.1783792907372117, 0.04345057197497226, 0.025631786229496356, 0.03365994831256103, 0.0369972491171211, 0.1489222323289141, 3.2658216822892427, 71.53767451643944, 53.12879852950573, 48.60083609819412, 35.54812990128994, 35.675981640815735, 24.03257042169571, 36.36249840259552, 51.723827719688416, 68.342524766922, 7.395904138684273, 28.43824591487646, 83.17771151661873, 66.05060935020447, 70.67487761378288, 61.05939097702503, 65.74314504861832, 64.72238302230835, 65.01080274581909, 58.97455304861069, 57.46351473033428, 49.99939285218716, 50.79171873629093, 47.01621852815151, 48.692464381456375, 47.86999471485615, 52.98847585916519, 50.271002277731895, 52.48067110776901, 48.74880775809288, 50.034643560647964, 48.026181533932686, 45.53704530000687, 44.32264566421509, 47.05129064619541, 45.56752726435661, 45.55478274822235, 42.19716511666775, 44.13405038416386, 47.239407151937485, 51.569833382964134, 53.58967959880829, 60.44301465153694, 56.920022293925285, 57.61133819818497, 55.826695561409, 63.53826016187668, 57.916055247187614, 54.46337431669235, 53.0136913061142, 58.00283119082451, 57.31745436787605, 54.66338038444519, 54.98106233775616, 54.71633054316044, 48.565946370363235, 50.199733301997185, 47.294621989130974, 50.35808980464935, 49.30533729493618, 56.16031385958195, 45.61666622757912, 34.45104897022247, 43.89753207564354, 45.85259176790714, 40.568374916911125, 35.51604822278023, 40.03872513771057, 35.12429304420948, 39.02452535927296, 41.76778055727482, 41.21314711868763, 38.085515946149826, 39.37844976782799, 49.091990143060684, 44.484817162156105, 42.86774933338165, 45.22100105881691, 42.2737842053175, 38.20219628512859, 36.30493529140949, 37.09388315677643, 38.31740990281105, 39.80603702366352, 38.467349857091904, 38.528233990073204, 34.12632219493389, 36.34522072970867, 36.71196565032005, 38.52174013853073, 31.498504802584648, 40.628734678030014, 49.06589314341545, 44.47935305535793, 44.52104061841965, 40.71632757782936, 43.468322306871414, 46.54578097164631, 46.539853289723396, 48.488039150834084, 50.39859563112259, 48.13367396593094, 46.641091257333755, 47.764466777443886, 45.17766438424587, 46.112258434295654, 48.003508150577545, 47.77138240635395, 48.97405207157135, 46.962789595127106, 44.27801325917244, 44.16972666978836, 46.29479303956032, 47.43781350553036, 48.93086738884449, 45.78471601009369, 42.741824090480804, 42.584786117076874, 43.646369352936745, 46.94968789815903, 43.390726670622826, 45.95094569027424, 45.864591524004936, 46.547886058688164, 46.00269891321659, 45.69704331457615, 47.18785531818867, 49.64837908744812, 47.531847059726715, 48.34573298692703, 48.977057710289955, 51.65216736495495, 52.75850459933281, 52.550860941410065, 52.6480483263731, 57.729724645614624, 65.87875217199326, 66.41211435198784, 68.12846705317497, 72.78621912002563, 66.91817119717598, 53.0183232575655, 0.17449076345656067, 5.5684928968548775, 54.51534792780876, 51.724203899502754, 22.1431902050972, 28.81070762872696, 33.833620101213455, 56.38925917446613, 58.49937714636326, 47.40879066288471, 77.56936445832253, 16.400398761034012, 0.030531332013197243, 0.3904794860864058, 0.09447703196201473, 0.10240712479571812, 0.04070993934874423, 0.05127978467498906, 0.04372014598629903, 0.05935172419412993, 0.11343271558871493, 0.13080832228297368, 0.12789989006705582, 0.26861583930440247, 0.20856359449680895, 0.3067258349619806, 0.27240005030762404, 0.45079097792040557, 0.37677023734431714, 0.13488624565070495, 0.14136176614556462, 0.15427106874994934, 0.17248957708943635, 0.43843318009749055, 4.176872195675969, 86.08067214488983, 67.66281723976135, 56.19841441512108, 37.51418240368366, 42.00659014284611, 26.444551795721054, 46.35824963450432, 61.56005211174488, 71.32546350359917, 6.982322931289673, 30.44919490814209, 84.1733492910862, 67.1531429886818, 72.01499730348587, 63.38203154504299, 70.20059466362, 68.10086533427238, 68.75405788421631, 62.068221643567085, 62.556886821985245, 53.05666320025921, 51.61924593150616, 51.81420587003231, 52.3979115486145, 49.08542029559612, 54.630979523062706, 52.81168654561043, 54.172891303896904, 52.951218858361244, 53.50560910999775, 51.51210308074951, 47.85962127149105, 46.223839446902275, 49.73312593996525, 48.32455292344093, 47.0239245146513, 46.54820904135704, 48.48300062119961, 48.922124058008194, 53.730705231428146, 54.99862879514694, 63.45340311527252, 56.74468070268631, 59.32247377932072, 57.90579579770565, 63.87263461947441, 60.25730721652508, 54.075684919953346, 53.96110586822033, 60.49763672053814, 59.44154419004917, 58.240155056118965, 57.45609752833843, 57.39649772644043, 52.360783740878105, 53.60994391143322, 51.51160150766373, 55.560390651226044, 54.882997199893, 59.9132926762104, 50.563913360238075, 40.960886254906654, 50.986849665641785, 50.95205493271351, 42.00846344232559, 39.86168123781681, 45.12630634009838, 38.211433589458466, 41.549866050481796, 41.15391969680786, 44.54624466598034, 40.33009730279446, 43.638412579894066, 45.97152158617973, 44.161944687366486, 41.84976115822792, 46.98262833058834, 43.99076767265797, 38.93502876162529, 38.00389252603054, 39.376793056726456, 41.722441390156746, 42.43085637688637, 38.84494699537754, 39.22954335808754, 35.19260957837105, 39.42921124398708, 40.21404393017292, 42.875649109482765, 36.86343312263489, 44.34437669813633, 52.83684119582176, 47.4898137152195, 48.651544377207756, 43.532405868172646, 46.25934474170208, 51.27517819404602, 49.09432701766491, 52.76430308818817, 53.84278021752834, 51.63109369575977, 50.008497163653374, 48.05986672639847, 47.60484114289284, 46.63917995989323, 50.78132629394531, 48.990075811743736, 50.70491619408131, 48.35210904479027, 46.70998156070709, 47.502486035227776, 50.09287543594837, 52.787664234638214, 51.062404811382294, 50.14409288764, 45.41495405137539, 45.966832637786865, 47.75305978953838, 47.243222147226334, 44.38784636557102, 49.05866213142872, 48.43545377254486, 49.3113599717617, 50.22706523537636, 49.56242009997368, 49.283002093434334, 52.76396110653877, 50.8397101610899, 53.063727021217346, 52.24124975502491, 53.90152886509895, 55.58399498462677, 55.22912062704563, 56.63502238690853, 58.94468665122986, 67.81837329268456, 67.6742622256279, 70.99580839276314, 73.90338197350502, 67.95679986476898, 61.711280196905136, 1.3301927223801613, 4.4010991137474775, 58.98753695189953, 58.64148572087288, 27.813853919506073, 40.26722587645054, 44.34204362332821, 60.576448291540146, 69.53184574842453, 55.75573816895485, 90.50317883491516, 23.716028407216072, 0.7766309450380504, 0.6293980486225337, 0.5094395542982966, 0.26531081821303815, 0.17997734248638153, 0.13038405129918829, 0.1912986271781847, 0.16307985701132566, 0.3583899111254141, 0.17914494965225458], [0.03241864324081689, 0.036113495953031816, 0.060748123287339695, 0.12570280639920384, 0.04117200420296285, 0.07969277488882653, 0.12553132575703785, 0.07077961097820662, 0.06039440086169634, 0.0555356565018883, 0.2294665400404483, 0.07027100975392386, 1.3473569951020181, 48.330378010869026, 53.63871976733208, 41.71491399407387, 23.229124434292316, 27.73418929427862, 19.594039991497993, 27.84881964325905, 44.634137749671936, 71.10059157013893, 14.210249483585358, 22.201342284679413, 75.38701996207237, 65.17290204763412, 69.64688837528229, 60.58373250067234, 64.14457082748413, 55.4228076338768, 57.52849884331226, 51.21772147715092, 50.729603469371796, 48.48610885441303, 49.26941402256489, 46.63914956152439, 48.47204960882664, 45.35602681338787, 47.7848032861948, 45.83914428949356, 45.85098825395107, 44.22537848353386, 44.81227979063988, 43.266043961048126, 41.926779225468636, 42.91882239282131, 43.78869071602821, 43.395905792713165, 45.17145551741123, 42.0991987735033, 46.7958265542984, 43.547814041376114, 46.543113514781, 45.7190365344286, 53.0648859590292, 54.47966784238815, 58.481221720576286, 60.70338428020477, 59.27651144564152, 53.03935892879963, 51.97054088115692, 48.083341866731644, 51.27343788743019, 50.89798763394356, 50.162115320563316, 50.35740204155445, 51.42974629998207, 49.387758672237396, 50.09604066610336, 47.698034942150116, 48.59484001994133, 45.404265224933624, 48.854347094893456, 40.66194109618664, 28.452829532325268, 40.117042735219, 37.974276915192604, 39.249553084373474, 35.625550746917725, 30.66583838313818, 32.982112392783165, 32.653863206505775, 35.66307373344898, 38.39235708117485, 37.529396787285805, 35.67154347896576, 45.066702738404274, 46.65534049272537, 54.219651594758034, 59.376856461167336, 55.18598914146423, 41.47647678852081, 37.58247993886471, 38.23939248919487, 34.279127195477486, 32.40288287401199, 32.82088704407215, 36.35796904563904, 34.10209469497204, 36.8597549200058, 32.53102719783783, 33.05227942764759, 25.239917635917664, 38.463466465473175, 46.33803851902485, 45.14127753674984, 44.13424037396908, 40.53582206368446, 44.12460409104824, 47.29879416525364, 47.00799956917763, 45.34307710826397, 48.30101698637009, 46.30689539015293, 46.356205344200134, 42.003295719623566, 47.005503103137016, 46.63951814174652, 47.24277377128601, 45.89245542883873, 45.44243037700653, 43.8092590123415, 40.32856598496437, 43.290062472224236, 41.91881485283375, 41.94122605025768, 42.213489040732384, 41.7195725440979, 43.44681166112423, 41.70351840555668, 42.243632823228836, 41.816999316215515, 42.4617563188076, 44.895027950406075, 43.74114386737347, 43.83261635899544, 41.61386601626873, 43.72901871800423, 44.406438767910004, 42.73572541773319, 43.9421720802784, 42.613660767674446, 47.247158735990524, 47.09043234586716, 47.93244056403637, 51.21246635913849, 55.269204676151276, 54.7870409488678, 61.185859590768814, 62.03747369349003, 64.68561619520187, 60.61367489397526, 65.07482171058655, 27.281475886702538, 0.10564491472905502, 9.11439137533307, 50.99311172962189, 33.554179295897484, 18.069647289812565, 32.6065519452095, 29.016979560256004, 43.47528353333473, 40.05558103322983, 37.70542614161968, 59.425828233361244, 9.530168864876032, 0.33241254568565637, 0.19160488183842972, 0.19338691199664026, 0.056749134746496566, 0.05170578486286104, 0.035110490789520554, 0.03706036135554314, 0.04374334923340939, 0.09140197274973616, 0.10376823847764172, 0.05091686332889367, 0.034541385975899175, 0.0927369405690115, 0.09128184872679412, 0.04031099415442441, 0.0827012411900796, 0.013980515777802793, 0.022368152858689427, 0.04465984595299233, 0.02348140591493575, 0.2969418646534905, 0.08986134096630849, 0.7755372568499297, 57.92785741388798, 57.20088042318821, 54.36698488891125, 29.906080551445484, 32.90287904441357, 27.153816036880016, 33.81196886301041, 50.25375500321388, 75.87478458881378, 17.793713696300983, 22.728478498756886, 77.20931097865105, 68.9999882876873, 73.06880995631218, 64.27906841039658, 68.64276185631752, 60.46281918883324, 59.93930608034134, 53.89604955911636, 54.84096385538578, 52.55061395466328, 53.0092341452837, 49.10983398556709, 52.851052433252335, 51.920653358101845, 52.12545096874237, 52.54165783524513, 50.752755627036095, 48.573705554008484, 47.97624081373215, 45.11317424476147, 45.30213050544262, 44.947852715849876, 46.48290194571018, 48.14377762377262, 48.65087181329727, 44.46583718061447, 47.80911058187485, 49.48093347251415, 51.04359582066536, 48.63483287394047, 55.191958621144295, 56.56623847782612, 60.28376519680023, 60.69222807884216, 63.345511704683304, 58.084918186068535, 55.7644435018301, 55.106463208794594, 52.797251120209694, 52.8247844427824, 51.74502678215504, 49.836788177490234, 50.132264122366905, 49.580149948596954, 52.20341518521309, 51.09895505011082, 51.06050871312618, 50.25961048901081, 56.15486495196819, 45.88802486658096, 34.2246001213789, 48.42732220888138, 43.889708295464516, 42.17164568603039, 39.45472687482834, 36.8747641146183, 34.248238652944565, 33.89250174164772, 37.41781197488308, 38.2644597440958, 36.43339119851589, 37.12063372135162, 41.66010193526745, 45.33570550382137, 52.001509219408035, 57.683769911527634, 52.55153350532055, 42.113417610526085, 36.72695204615593, 35.57162024080753, 30.87280187755823, 32.77665361762047, 31.52258411049843, 38.163506761193275, 38.57667379081249, 42.36568607389927, 37.34660379588604, 37.244039699435234, 26.98518678545952, 41.266386061906815, 45.22484265267849, 44.28551405668259, 44.699479043483734, 39.80095289647579, 45.510503724217415, 48.73548187315464, 51.951781287789345, 47.65419289469719, 52.84625329077244, 48.873691856861115, 50.09750358760357, 45.91958597302437, 47.48811520636082, 48.380789905786514, 46.49204805493355, 47.850604355335236, 46.18411637842655, 45.69120302796364, 45.15804223716259, 45.81741325557232, 46.153873801231384, 45.703290179371834, 44.75530564785004, 45.80975666642189, 47.51499116420746, 46.05254463851452, 45.9509114921093, 45.21696947515011, 43.28529752790928, 45.73259800672531, 45.56937016546726, 44.25581865012646, 43.03495556116104, 45.12316770851612, 47.71300233900547, 45.458442717790604, 48.691537231206894, 47.22325801849365, 49.54053707420826, 48.011096343398094, 51.20281867682934, 53.64082105457783, 58.43412324786186, 58.69828127324581, 65.5405855178833, 66.97459056973457, 71.57495051622391, 65.43172135949135, 69.60132881999016, 28.313582204282284, 0.12361538989352994, 11.794761847704649, 58.496219515800476, 36.63704127073288, 19.560197107493877, 31.660725697875023, 32.06979274749756, 51.04593649506569, 45.43025963008404, 38.684132024645805, 72.39841192960739, 17.872187085449696, 0.1958469979581423, 0.3064360411372036, 0.11442110044299625, 0.05783470012829639, 0.06547868018969893, 0.05739312597142998, 0.06203827651916072, 0.03951142651203554, 0.17858266888651997, 0.11657863506115973, 0.17759381647920236, 0.10249819373711944, 0.14039709290955216, 0.22767196758650243, 0.1131214588531293, 0.2993067924398929, 0.1855256236740388, 0.324358640355058, 0.15474849235033616, 0.1266843412304297, 0.637026020558551, 0.1578968163812533, 2.7937117405235767, 69.78871196508408, 66.79514139890671, 63.2535832375288, 33.40091072022915, 43.944554552435875, 27.632582746446133, 41.77871257066727, 55.65359205007553, 80.38915514945984, 16.988516002893448, 25.725472681224346, 83.11347216367722, 71.71665251255035, 76.89948320388794, 66.73564419150352, 74.21792909502983, 64.33610334992409, 65.39642125368118, 56.248301938176155, 56.16065204143524, 55.965939089655876, 55.38563422858715, 51.54811754822731, 54.630945324897766, 52.528084963560104, 53.72203789651394, 54.647117257118225, 54.38008278608322, 50.61169199645519, 50.33212959766388, 47.04198494553566, 44.90072764456272, 47.45832480490208, 47.42120459675789, 48.970035687088966, 50.95824480056763, 45.049520060420036, 50.61202637851238, 51.59186840057373, 52.31795243918896, 53.29226195812225, 58.78982976078987, 58.75081725418568, 60.6726249307394, 63.43556687235832, 64.57524731755257, 61.91647678613663, 59.42907325923443, 58.029505759477615, 57.92374223470688, 59.3088249117136, 55.964806750416756, 52.00826905667782, 53.11164624989033, 50.86930297315121, 54.8219458758831, 55.02186454832554, 56.72267608344555, 56.33622542023659, 61.44342117011547, 53.900510519742966, 41.78643375635147, 53.3097942173481, 52.83016875386238, 47.95363962650299, 44.29846756160259, 38.66788789629936, 38.3370054513216, 37.05558501183987, 41.01968429982662, 42.005609795451164, 39.305729269981384, 38.51450152695179, 45.44542081654072, 49.70894403755665, 54.6223159879446, 62.54640318453312, 57.0149639993906, 43.653478771448135, 37.4582190066576, 38.48155349493027, 32.410258278250694, 34.19832833111286, 34.75585721433163, 42.91699469089508, 41.766199842095375, 47.24547542631626, 43.2878053933382, 40.29580794274807, 33.57300728559494, 44.408825039863586, 49.87919010221958, 47.122981399297714, 47.906658947467804, 43.211703076958656, 49.77110110223293, 53.10357168316841, 55.19969880580902, 50.76634369790554, 57.494224682450294, 51.010096818208694, 52.34747685492039, 46.868376061320305, 52.053783014416695, 52.59073220193386, 52.16796688735485, 50.96475385129452, 48.87735866010189, 47.60041058063507, 48.262623846530914, 52.70782291889191, 52.215692326426506, 50.09428136050701, 51.29937529563904, 50.1483828574419, 51.28961741924286, 49.57264915108681, 50.29120959341526, 48.94885562360287, 45.39202608168125, 50.86833402514458, 48.11866097152233, 48.256810158491135, 47.58107341825962, 48.567481487989426, 49.24501933157444, 48.03100347518921, 50.68640358746052, 47.64745205640793, 54.4245707988739, 52.104172110557556, 53.54933336377144, 53.67119662463665, 59.432595670223236, 59.97968651354313, 67.1262176334858, 68.06609719991684, 71.02565199136734, 68.7430764734745, 72.77534410357475, 37.969485372304916, 0.3578723967075348, 11.58824672922492, 66.46905049681664, 41.428595557808876, 24.646986052393913, 41.57025195658207, 44.78714033961296, 61.53782330453396, 52.96959467232227, 48.69588419795036, 78.81301492452621, 19.827987737953663, 0.5403277999721467, 0.4734445904614404, 0.37046785990241915, 0.17301984160440043, 0.13560143852373585, 0.35901833209209144, 0.11718913316144608, 0.1410111310542561, 0.2908074203878641, 0.2846191852586344], [0.028051501212758012, 0.0931172986747697, 0.05278371354506817, 0.0289426016388461, 0.07689399499213323, 0.11384232915588655, 0.09615959948860109, 0.10409566661110148, 0.06320505883195437, 0.0885345070855692, 0.15086651081219316, 0.07773651072056964, 0.3433262725593522, 40.58162100613117, 56.02116532623768, 32.525449097156525, 36.317003443837166, 35.98101407289505, 19.93159867823124, 27.186845764517784, 34.56972040235996, 77.16486096382141, 23.555642813444138, 17.61461790651083, 73.20995718240738, 66.00825682282448, 69.30043056607246, 59.73083786666393, 58.672841638326645, 55.63784569501877, 54.978607669472694, 48.578542694449425, 48.642770648002625, 46.71859189867973, 48.39757360517979, 48.24644051492214, 46.42770230770111, 47.67041802406311, 48.41239280998707, 48.08418162167072, 48.210942819714546, 46.33991941809654, 47.84673996269703, 45.743336230516434, 46.74844689667225, 42.48857527971268, 46.213051825761795, 46.080161556601524, 48.98632161319256, 42.01076991856098, 44.95582848787308, 46.022777035832405, 45.18562875688076, 44.69160966575146, 53.35746645927429, 53.652634620666504, 56.24492771923542, 56.77774652838707, 57.081905007362366, 52.196301966905594, 50.20707830786705, 49.236044213175774, 51.528886780142784, 52.89037652313709, 54.02295894920826, 52.41895101964474, 52.29385793209076, 49.71191167831421, 53.02747316658497, 45.97609654068947, 45.64892649650574, 46.66148476302624, 49.942563101649284, 42.243613824248314, 25.416423864662647, 37.02030770480633, 32.53225453197956, 32.95344293117523, 33.5806030780077, 32.29434549808502, 26.767067089676857, 31.161660477519035, 35.22972218692303, 37.814419493079185, 38.98759514093399, 43.242982998490334, 41.35754317045212, 49.90059435367584, 53.37703540921211, 49.17362876236439, 45.2200511097908, 32.83115029335022, 38.85441228747368, 36.78848974406719, 30.86555566638708, 32.8580604493618, 36.80915303528309, 42.82291553914547, 36.241995468735695, 33.44078578054905, 31.90713107585907, 39.49701100587845, 25.861364789307117, 42.38369330763817, 47.58679211139679, 47.62434169650078, 43.28285425901413, 43.36608499288559, 45.43523356318474, 47.944330126047134, 48.15572418272495, 47.52433106303215, 46.97886273264885, 46.9422060996294, 48.80165912210941, 47.79960349202156, 49.60335150361061, 48.46240572631359, 48.122213780879974, 45.22518843412399, 45.71758881211281, 44.25155907869339, 39.961653873324394, 40.001821517944336, 41.04519233107567, 40.688383877277374, 41.14122837781906, 38.696667551994324, 42.73051209747791, 42.70660378038883, 43.7615791708231, 41.093442142009735, 42.88027726113796, 44.89263787865639, 44.40227419137955, 45.14941670000553, 43.55849526822567, 44.33033265173435, 45.1300111413002, 45.10521747171879, 46.2560161203146, 46.11779473721981, 46.69061399996281, 45.19742712378502, 49.96335558593273, 53.28011780977249, 58.17615509033203, 56.45403049886227, 60.063350424170494, 58.70954766869545, 60.52974499762058, 58.24074402451515, 57.01360747218132, 12.363005205988884, 0.3556924418080598, 17.106630764901638, 50.684283301234245, 28.060143403708935, 22.69997052848339, 26.129584796726704, 29.60533618927002, 25.09890530258417, 29.91759393364191, 30.961447320878506, 60.66488474607468, 16.37258045375347, 0.6053971708752215, 0.07086023048032075, 0.15424559824168682, 0.12705971952527761, 0.030870452683302574, 0.03325822748593055, 0.06407183536794037, 0.09577064731274731, 0.0921853467298206, 0.06170259199279826, 0.04484219905862119, 0.05019425640057307, 0.09149339792202227, 0.08289077086374164, 0.049664474281598814, 0.055851729775895365, 0.08614478414529003, 0.06626099289860576, 0.14983535598730668, 0.05574674556555692, 0.11747912736609578, 0.09060368160135113, 0.6467726756818593, 48.389639630913734, 59.09946374595165, 35.514931082725525, 35.92176005244255, 39.021557718515396, 24.82257843017578, 30.909359715878963, 39.9576298892498, 82.11509853601456, 29.409597292542458, 18.743417635560036, 75.3161309659481, 69.38659474253654, 74.95040819048882, 61.38823293149471, 62.64145888388157, 59.31936554610729, 56.59654565155506, 52.15097039937973, 53.79983112215996, 50.34499950706959, 52.353864312171936, 52.73759052157402, 50.21482229232788, 49.67113986611366, 52.245551124215126, 51.11385405063629, 50.72405196726322, 48.851269260048866, 50.383157059550285, 46.002729311585426, 48.9922720938921, 45.420095175504684, 49.89020951092243, 49.31333586573601, 51.502690985798836, 46.87478631734848, 48.24328288435936, 49.47186715900898, 46.633218079805374, 46.55878387391567, 55.52379101514816, 56.850159242749214, 60.35727225244045, 61.29187390208244, 59.80020694434643, 57.242689579725266, 53.51929597556591, 52.15367965400219, 55.68146355450153, 51.86919651925564, 53.1235396116972, 52.00345851480961, 55.3789047896862, 52.42724597454071, 56.59157171845436, 50.10587453842163, 51.41255982220173, 48.78576077520847, 54.518558755517006, 49.25833001732826, 34.55359026789665, 42.62783020734787, 39.03250873088837, 38.172801062464714, 36.88724264502525, 38.02905097603798, 31.68131109327078, 34.09491688013077, 37.367084696888924, 40.23052744567394, 37.50031694769859, 41.444459706544876, 38.299740850925446, 43.06789979338646, 43.846968188881874, 42.72049583494663, 39.22525718808174, 29.156504273414612, 33.0369358509779, 36.87318719923496, 32.26403072476387, 33.96910183131695, 36.718938276171684, 43.70024286210537, 38.37874621152878, 36.97534091770649, 35.75395725667477, 41.21019847691059, 28.603491447865963, 42.436761260032654, 46.331046894192696, 46.16140119731426, 42.973284870386124, 43.2508409768343, 49.4487340003252, 50.043314695358276, 52.25811704993248, 51.93820461630821, 51.467250287532806, 50.48631012439728, 49.56840097904205, 49.08474013209343, 48.672534450888634, 48.240132853388786, 49.070072919130325, 46.276979595422745, 47.75909386575222, 46.368296295404434, 45.22349372506142, 43.90477828681469, 46.308673694729805, 44.800777807831764, 43.991451635956764, 41.66555464267731, 44.58720646798611, 44.95883412659168, 45.473991483449936, 43.771120458841324, 44.81773629784584, 45.72337210178375, 46.24620504677296, 45.238970294594765, 45.3868393599987, 46.25548414885998, 49.53234851360321, 48.74748542904854, 48.961193561553955, 48.60758453607559, 50.64995974302292, 48.12691032886505, 52.47935637831688, 56.47264949977398, 62.51270279288292, 60.267346277832985, 67.84203082323074, 67.24555402994156, 69.28027644753456, 63.86177480220795, 67.954580783844, 13.398495241999626, 0.46003128052689135, 23.359869718551636, 59.74385216832161, 33.044041469693184, 26.043236330151558, 26.891698502004147, 34.710483849048615, 35.25163181126118, 39.59852635860443, 46.02974586188793, 71.79928287863731, 22.228108048439026, 0.2654478483600542, 0.38092282076831907, 0.14985561661887914, 0.14411976502742618, 0.0720742208068259, 0.021722361925640143, 0.08698866542545147, 0.12924534443300217, 0.16956597537500784, 0.11668484381516464, 0.07393349369522184, 0.17659172415733337, 0.14361589128384367, 0.21308021619915962, 0.32066912739537656, 0.1998785074101761, 0.14854908047709614, 0.24864978098776191, 0.2250627989997156, 0.1940108058624901, 0.2915834990562871, 0.19941098405979574, 1.214542246889323, 59.72823120653629, 72.84680306911469, 45.5250683426857, 49.171003103256226, 55.370313450694084, 24.905495680868626, 36.36240340769291, 47.99567297101021, 88.64122554659843, 29.336388520896435, 21.973023936152458, 78.63358095288277, 70.70440962910652, 77.01715528964996, 66.44832640886307, 65.09571298956871, 63.17054249346256, 59.979777708649635, 55.6270656734705, 56.53052419424057, 55.573442950844765, 56.50114417076111, 57.72351197898388, 52.23946005105972, 54.07527074217796, 53.676105961203575, 53.038389980793, 51.76374077796936, 50.79256609082222, 54.37563702464104, 47.810204923152924, 49.7789590805769, 47.66709320247173, 51.30256712436676, 52.444219663739204, 52.46202550828457, 48.763364776968956, 51.70278824865818, 53.38115058839321, 49.84119974076748, 49.79521080851555, 58.40696610510349, 56.93113289773464, 62.1634179353714, 64.40252378582954, 63.66172693669796, 59.52070154249668, 58.714061826467514, 57.56010174751282, 59.46761839091778, 56.52055352926254, 55.39546050131321, 53.815110102295876, 53.7400983273983, 53.213431388139725, 58.30561414361, 54.77393165230751, 55.468458384275436, 57.32690826058388, 61.94613419473171, 57.888939902186394, 42.00875602662563, 48.43388445675373, 44.6080369502306, 42.904443964362144, 42.94610492885113, 43.16189154982567, 35.19515544176102, 36.62048935890198, 38.68488438427448, 41.364967972040176, 42.053232640028, 46.52875408530235, 43.40778775513172, 46.27271242439747, 47.344726100564, 43.86717550456524, 42.4883396923542, 33.87360915541649, 37.52386048436165, 39.86588381230831, 35.06071865558624, 37.12825991213322, 39.66452121734619, 48.021576181054115, 42.6453472673893, 42.59816899895668, 40.31413435935974, 46.14643760025501, 35.374213233590126, 45.06204418838024, 48.83353941142559, 48.90485018491745, 44.09353315830231, 47.12463431060314, 53.42920660972595, 55.64133770763874, 58.917381316423416, 55.903827622532845, 55.57944282889366, 53.99411469697952, 52.90818236768246, 53.47685605287552, 51.62012368440628, 50.07173337042332, 51.383631974458694, 48.52786101400852, 50.95370024442673, 49.287634044885635, 47.811398059129715, 48.74304726719856, 54.274311661720276, 49.121472761034966, 48.85026231408119, 45.35731114447117, 48.2612407207489, 47.30479024350643, 48.48149210214615, 45.31845062971115, 45.099255591630936, 48.476411774754524, 47.12170086801052, 46.845489889383316, 47.80150718986988, 47.6153551787138, 52.330563962459564, 53.01933400332928, 53.12715321779251, 52.394818514585495, 52.565661147236824, 50.91784916818142, 57.72166147828102, 60.263246297836304, 65.18684729933739, 64.38667863607407, 68.07004898786545, 67.5145111978054, 70.81433773040771, 67.92266249656677, 71.39127597212791, 17.42798902094364, 0.7584111008327454, 22.629066333174706, 67.1400260925293, 39.45058509707451, 29.651492312550545, 35.36420837044716, 45.83696700632572, 37.246836349368095, 43.58616918325424, 43.73900078237057, 83.5426439344883, 29.949213936924934, 0.6226981175132096, 0.6752878299448639, 0.3471006278414279, 0.456293142051436, 0.1764645942603238, 0.1128460255858954, 0.20408845884958282, 0.14763396786293015, 0.25690644106362015, 0.17260127031477168], [0.008959476708696457, 0.03950525926484261, 0.030346129060490057, 0.0340118524763966, 0.13784518843749538, 0.09338486517663114, 0.06550995429279283, 0.06718461052514613, 0.060279156459728256, 0.03222798550268635, 0.01915497810841771, 0.06124958876171149, 0.18425855494569987, 35.85172601044178, 50.30485846102238, 38.8310207426548, 45.30463457107544, 43.33390071988106, 20.921010486781597, 30.44689603149891, 35.35513445734978, 64.4577044248581, 40.42242094874382, 11.5387724339962, 63.070018887519836, 68.84532898664474, 70.31280264258385, 62.15335227549076, 59.62077297270298, 51.18935979902744, 49.25625532865524, 47.51374863088131, 48.46135698258877, 47.29021802544594, 51.059585362672806, 52.01959624886513, 53.32513399422169, 52.22759708762169, 48.71870197355747, 48.855323642492294, 47.60340102016926, 48.47814068198204, 45.8715033531189, 43.86047646403313, 44.8890470713377, 42.65056058764458, 43.4648796916008, 44.075104147195816, 44.63451012969017, 44.372859969735146, 42.79763549566269, 44.77857939898968, 47.15801551938057, 45.09628415107727, 51.803893223404884, 56.23071268200874, 56.38411045074463, 56.94817878305912, 55.34064844250679, 52.85583637654781, 47.89398282766342, 47.900735065340996, 46.75967149436474, 48.20685803890228, 46.63462780416012, 49.683823585510254, 53.407171592116356, 52.89706416428089, 51.949706599116325, 47.19305343925953, 46.54391527175903, 45.930369794368744, 47.00767278671265, 42.00983516871929, 23.05993851274252, 39.870295375585556, 34.609416872262955, 38.30460079014301, 34.48495075106621, 32.387482300400734, 30.253685899078846, 28.543236181139946, 29.94465798139572, 35.786301121115685, 39.45183902978897, 38.463090285658836, 40.63278526067734, 38.25031690299511, 32.850457057356834, 20.300891362130642, 21.345189325511456, 23.259969279170036, 38.15961956977844, 34.81663875281811, 33.41114357113838, 33.43767374753952, 40.73509857058525, 41.18136562407017, 39.0811613202095, 37.66832493245602, 36.82839520275593, 38.047407791018486, 26.116712987422943, 44.12360094487667, 47.17946536839008, 46.13575257360935, 43.36005851626396, 42.307568192481995, 47.315057292580605, 45.32845549285412, 48.119496926665306, 45.96001960337162, 49.24108274281025, 46.452495977282524, 43.85649427771568, 45.08965730667114, 48.132754415273666, 46.65198527276516, 47.656632363796234, 46.77377253770828, 42.695363983511925, 41.67065776884556, 42.610487937927246, 42.73151904344559, 42.77069114148617, 40.585876777768135, 42.109910398721695, 41.93949714303017, 43.5967668145895, 45.36790877580643, 45.1090856641531, 40.64509280025959, 43.75668503344059, 43.05470310151577, 44.76275324821472, 44.525463581085205, 42.892979979515076, 43.519592955708504, 46.93994902074337, 46.56265206634998, 46.982141956686974, 47.54058659076691, 47.71037667989731, 45.405089780688286, 48.077493980526924, 53.80683034658432, 56.72530934214592, 54.92336243391037, 59.21943850815296, 60.54060101509094, 62.31263592839241, 56.64740592241287, 55.65484598278999, 5.508830398321152, 0.24063639692030847, 36.781821101903915, 49.279958456754684, 31.582411900162697, 19.76182758808136, 24.233862720429897, 28.25957950204611, 36.96403652429581, 38.572155833244324, 44.54565569758415, 58.771438747644424, 11.475086901336908, 0.2503968559904024, 0.09796228361665271, 0.15752410981804132, 0.11046412488212809, 0.03964792973420117, 0.036275176535127684, 0.0662460683088284, 0.08122809289488941, 0.07195959609816782, 0.05681328970240429, 0.0733859816682525, 0.027492519293446094, 0.038755808855057694, 0.04452594766917173, 0.032198403496295214, 0.05655743800161872, 0.07018218209850602, 0.01434255953427055, 0.044373603304848075, 0.024945500008470844, 0.02215168879047269, 0.04445087201020215, 0.4663887253263965, 44.593472331762314, 55.48152968287468, 40.23953676223755, 42.33459614217281, 44.40265417098999, 22.731670327484608, 34.34384532272816, 39.0327101200819, 69.96035635471344, 47.7054825425148, 13.61605541780591, 63.652033656835556, 73.34457635879517, 73.4517154097557, 67.75464311242104, 62.778821513056755, 55.87268449366093, 53.04500162601471, 51.68449603021145, 51.39532774686813, 51.64902113378048, 55.36946229636669, 54.927663803100586, 57.26705387234688, 53.56701381504536, 51.690298318862915, 52.37059101462364, 51.39299847185612, 51.87201216816902, 49.963667169213295, 48.497154861688614, 48.80914472043514, 47.10658147931099, 45.38569562137127, 47.54937171936035, 48.20795238018036, 45.1047994941473, 43.811151310801506, 46.501425951719284, 50.593608766794205, 47.556963711977005, 52.43415020406246, 57.29496717453003, 58.08363765478134, 60.08038491010666, 55.479116812348366, 53.47967930138111, 49.30675081908703, 47.344608306884766, 48.82616400718689, 50.649442970752716, 48.7837240844965, 53.63473758101463, 55.93883514404297, 55.58227747678757, 53.72304484248161, 52.521670907735825, 49.62269626557827, 49.7579538077116, 51.663551554083824, 48.0592055618763, 28.781187012791634, 41.56724251806736, 37.93600536882877, 40.71069248020649, 36.42536602914333, 32.45877407491207, 30.88474653661251, 29.663915745913982, 32.55915708839893, 35.8431650698185, 36.90634801983833, 36.840999126434326, 42.77486331760883, 41.24619394540787, 36.772978976368904, 27.539611235260963, 28.36978878825903, 29.024098478257656, 36.93625621497631, 34.315434247255325, 34.23507235944271, 35.18310248851776, 44.13660004734993, 45.83971805870533, 43.687581941485405, 40.78982703387737, 39.91900496184826, 39.598435163497925, 29.958434142172337, 46.26393489539623, 49.7945686429739, 47.5764224678278, 46.330119743943214, 46.21772177517414, 52.7605564892292, 49.91445980966091, 50.41968069970608, 51.38647802174091, 51.92609466612339, 47.781265676021576, 45.15472501516342, 47.16461956501007, 50.25255426764488, 46.319427117705345, 51.50836408138275, 48.37360829114914, 47.12409853935242, 44.537208750844, 45.90041980147362, 45.44201999902725, 45.829105228185654, 43.35517957806587, 43.1922747194767, 43.90879847109318, 44.81291435658932, 46.43473573029041, 44.67885375022888, 45.37507139146328, 45.179321095347404, 46.53562031686306, 49.203407764434814, 47.643564864993095, 48.67668382823467, 47.962056174874306, 51.49673670530319, 49.90066654980183, 51.214700639247894, 48.96036520600319, 51.58372163772583, 49.3901639431715, 52.80211865901947, 58.02768565714359, 61.677697598934174, 59.11940887570381, 66.13026067614555, 65.8202201128006, 69.72308948636055, 62.45594523847103, 62.30181410908699, 5.068923253566027, 0.45514818630181253, 44.939474165439606, 56.13269314169884, 35.79851746559143, 27.02115185558796, 28.87673668563366, 32.75625631213188, 34.60481531918049, 35.43943293392658, 50.44984348118305, 67.43290677666664, 19.731594510376453, 0.3127546270843595, 0.17405705235432833, 0.06010487792082131, 0.2256885333918035, 0.04958879006153438, 0.052335330183268525, 0.023942275911394972, 0.0863133258826565, 0.07507124319090508, 0.029405657260213047, 0.2886654337635264, 0.11351891604135744, 0.138843288004864, 0.14433798613026738, 0.39465243404265493, 0.26259711070451885, 0.07967893383465707, 0.09718099507153966, 0.1764026694581844, 0.12053803002345376, 0.12313110142713413, 0.15470290964003652, 0.8884602505713701, 53.96890304982662, 67.0770026743412, 50.3437265753746, 57.824445962905884, 61.08025185763836, 25.344294235110283, 38.520087227225304, 45.34880340099335, 75.08544534444809, 48.19345235824585, 15.508438423275948, 69.51400190591812, 73.74885186553001, 76.57330870628357, 69.33230325579643, 66.3209268450737, 58.823241367936134, 56.444261223077774, 54.29449997842312, 55.03072947263718, 54.07517194747925, 56.705839186906815, 55.58027118444443, 58.74609790742397, 55.733155980706215, 52.49673664569855, 53.639669716358185, 53.99839706718922, 54.568936452269554, 53.609031960368156, 50.88329002261162, 53.888719752430916, 51.08174957334995, 47.75665819644928, 48.5520239174366, 51.37438327074051, 46.579203978180885, 47.153527960181236, 48.18469002842903, 53.94008159637451, 50.87252140045166, 56.42843507230282, 61.068784072995186, 62.194671258330345, 62.43125796318054, 57.755597457289696, 57.621377259492874, 51.57107591629028, 50.578352585434914, 52.56482519209385, 53.53473074734211, 49.54141862690449, 55.63287936151028, 58.470536693930626, 59.06484380364418, 56.72461777925491, 53.24558526277542, 54.70886014401913, 55.44780269265175, 57.23501779139042, 52.51949742436409, 36.209298223257065, 45.79651437699795, 42.15670108795166, 46.81175909936428, 43.177949488162994, 38.876808285713196, 35.43731264770031, 34.707447811961174, 35.9880892932415, 41.81524761021137, 41.998450979590416, 41.817671880126, 47.697700560092926, 48.19224402308464, 44.888845682144165, 33.03193151950836, 37.096383422613144, 37.31935165822506, 46.98085002601147, 41.45413778722286, 40.37247642874718, 42.075902223587036, 48.980891704559326, 51.12589180469513, 49.39733415842056, 46.92443065345287, 46.714735105633736, 43.94847594201565, 35.38133405148983, 50.00969409942627, 53.740204721689224, 51.47866107523441, 49.267757311463356, 48.37161339819431, 53.96346554160118, 52.011772468686104, 55.0561349093914, 56.15997567772865, 58.83250527083874, 54.32747080922127, 49.64445769786835, 50.29447741806507, 52.69265033304691, 50.11342853307724, 53.70409145951271, 53.637473434209824, 50.15271842479706, 47.08441346883774, 51.438170447945595, 50.760731399059296, 50.759591460227966, 47.226810827851295, 47.8447450697422, 47.48839259147644, 48.79623681306839, 49.707671105861664, 48.81353348493576, 46.61605820059776, 47.69414775073528, 47.77221076190472, 51.11397944390774, 50.847571939229965, 50.82440838217735, 50.24804390966892, 56.024197563529015, 54.383506402373314, 53.66827838122845, 51.89665764570236, 55.27508296072483, 51.25853128731251, 54.511559531092644, 60.047942250967026, 65.69890022277832, 62.141135931015015, 69.32752311229706, 71.43146261572838, 73.85925114154816, 67.45633631944656, 70.70637032389641, 8.16256145015359, 0.33488360058981925, 43.918879330158234, 64.25786554813385, 44.92199130356312, 26.612282395362854, 33.54024164378643, 40.390251874923706, 53.18936347961426, 51.55956253409386, 52.55503311753273, 79.25096422433853, 22.826946415007114, 0.36240947199985385, 0.2269260201137513, 0.21922234911471605, 0.26883878046646714, 0.09742453825310804, 0.2168405448901467, 0.11934385503991507, 0.1438003743533045, 0.27827334764879197, 0.09997046843636781], [0.06657445381279103, 0.07397257519187406, 0.0489906041912036, 0.03745536203496158, 0.09205456546624191, 0.11050834946217947, 0.0037475363842531806, 0.170137518143747, 0.02140814031008631, 0.033806856445153244, 0.07943093776702881, 0.1567456711200066, 0.9951357264071703, 41.937129870057106, 52.874360382556915, 31.967202052474022, 38.372681736946106, 47.03858032822609, 23.514726608991623, 28.726806230843067, 29.49592676013708, 56.17153465747833, 58.30326586961746, 15.771944783627987, 43.13240893185139, 73.952756524086, 66.00505739450455, 66.64552062749863, 56.93674519658089, 56.671169847249985, 51.73747658729553, 50.713602527976036, 47.81718894839287, 55.4339524358511, 56.67954459786415, 56.10624276101589, 54.3698613345623, 53.77265878021717, 51.52805082499981, 51.61012262105942, 49.528776705265045, 49.565554931759834, 47.51410201191902, 45.965305119752884, 43.66607889533043, 44.089501574635506, 44.53786991536617, 44.68670412898064, 44.03098851442337, 45.58686442673206, 42.90316343307495, 43.99776689708233, 43.66108596324921, 45.5844933539629, 46.15618787705898, 50.94308741390705, 55.72544999420643, 56.41448222100735, 53.69515813887119, 50.24302437901497, 49.28076781332493, 49.73981358110905, 46.475059166550636, 48.04092474281788, 48.63840468227863, 45.965255722403526, 45.51947124302387, 49.55524608492851, 48.632986173033714, 46.39086328446865, 41.580655798316, 46.85063861310482, 45.643728375434875, 46.23695254325867, 23.867955654859543, 34.490745440125465, 35.5035050958395, 35.043801963329315, 36.43011197447777, 29.646100401878357, 27.203832753002644, 31.75672374665737, 34.75732393562794, 29.89150643348694, 31.05958465486765, 20.909732691943645, 18.874970376491547, 8.340733889490366, 2.7300767926499248, 6.041924217715859, 9.752686824649572, 15.723406188189983, 25.53580015897751, 22.862789891660213, 25.201758183538914, 28.65832630544901, 41.07867993414402, 42.8792817145586, 38.94496902823448, 35.52186191082001, 31.698400676250458, 35.62495797872543, 26.206863150000572, 45.42380377650261, 47.32086718082428, 47.2718346118927, 43.148649260401726, 43.95731806755066, 48.437771648168564, 47.9329801350832, 47.777139097452164, 47.304759845137596, 45.45783095061779, 43.01894322037697, 42.532717511057854, 43.63664947450161, 46.138199642300606, 46.128244176506996, 45.02541035413742, 43.94898511469364, 41.20495095849037, 43.110381513834, 43.03213611245155, 43.01175780594349, 43.71312417089939, 42.14879371225834, 40.251958295702934, 41.321251317858696, 44.57503952085972, 42.40479737520218, 42.408437579870224, 41.30555436015129, 41.60395234823227, 43.29094022512436, 44.486291483044624, 43.498283699154854, 46.462785825133324, 45.575187653303146, 46.62261664867401, 47.41138972342014, 51.14555574953556, 47.409341633319855, 48.919053822755814, 46.494445726275444, 51.9893878698349, 54.52138960361481, 57.369739562273026, 54.55985113978386, 59.32258017361164, 58.89539569616318, 59.81248028576374, 50.97388856112957, 42.113307416439056, 1.409779095556587, 2.945038857869804, 53.14080588519573, 43.77884164452553, 31.984164342284203, 18.84464420378208, 25.271721929311752, 28.32720447331667, 33.95756945014, 43.24757695198059, 30.84149155765772, 57.25275903940201, 24.310318417847157, 0.23930119903525338, 0.13647482759552076, 0.05446162038424518, 0.06675307391560636, 0.07306785264518112, 0.08220866293413565, 0.030188430100679398, 0.07191563869128004, 0.051734368680627085, 0.10580792746623047, 0.06431152680306695, 0.029798323885188438, 0.057819983339868486, 0.026151306301471777, 0.07533712501754053, 0.08670575873111375, 0.053989399239071645, 0.042192958208033815, 0.08077464066445827, 0.016598214424448088, 0.06719421391608194, 0.261773326783441, 1.360125734936446, 53.508538752794266, 59.214365780353546, 36.30602203309536, 47.2049506008625, 50.76874136924744, 22.55058914422989, 39.940276220440865, 37.84032270312309, 56.967553943395615, 66.1538802087307, 18.92984703183174, 41.655751168727875, 76.01934403181076, 68.37939038872719, 71.34592920541763, 61.46678611636162, 59.57775928080082, 54.86189313232899, 54.192160069942474, 51.6443207859993, 60.47222748398781, 61.45715743303299, 62.670800909399986, 59.452833384275436, 57.66019977629185, 55.947939455509186, 55.950424522161484, 52.145152911543846, 52.3308489471674, 49.0764831751585, 50.34243084490299, 46.58523045480251, 47.27198660373688, 48.30609351396561, 48.68068881332874, 46.8452201038599, 46.90072372555733, 46.793558076024055, 47.11097024381161, 48.19977141916752, 47.77804344892502, 48.735177889466286, 52.7610694617033, 55.66441006958485, 55.334838554263115, 53.66236589848995, 53.19383203983307, 53.27647380530834, 52.31887958943844, 49.94713805615902, 51.00786253809929, 50.138936564326286, 48.11152495443821, 49.94327366352081, 52.79453806579113, 50.96064627170563, 51.17841258645058, 47.308799028396606, 51.883016377687454, 48.349734172225, 50.55548541247845, 30.538284927606583, 37.17685550451279, 37.76420898735523, 37.37697176635265, 38.44771631062031, 36.377895176410675, 34.438737630844116, 34.44367356598377, 35.28940178453922, 31.19063012301922, 36.30642481148243, 32.06994853913784, 26.266240663826466, 21.71144787222147, 14.96265945956111, 22.85037025809288, 25.444147177040577, 29.96411293745041, 39.49477672576904, 31.05794694274664, 32.87955969572067, 33.67181718349457, 44.492397755384445, 46.07805646955967, 46.530368998646736, 41.25049911439419, 37.853796780109406, 40.56433953344822, 31.632061935961246, 48.327839747071266, 51.8221740424633, 51.338467597961426, 48.349293395876884, 48.65816742181778, 53.347188010811806, 52.816090509295464, 50.49170583486557, 49.939226880669594, 47.24587440490723, 45.401179790496826, 44.75772611796856, 48.04295003414154, 50.461147874593735, 49.71280463039875, 48.993993401527405, 46.24527409672737, 44.9401581287384, 48.58770780265331, 46.207701712846756, 45.278640165925026, 45.667917877435684, 44.52818803489208, 42.7674613147974, 42.51208461821079, 46.49373136460781, 45.67098431289196, 45.65937593579292, 46.14074170589447, 45.02722665667534, 47.01837681233883, 47.270671874284744, 47.37141586840153, 49.62955489754677, 51.76851712167263, 51.80157154798508, 49.9490911513567, 53.108481019735336, 51.82170286774635, 53.90306398272514, 50.14847785234451, 55.994699746370316, 58.56815345585346, 62.11302123963833, 60.86237534880638, 65.80923870205879, 63.665693923830986, 65.58310523629189, 58.14421020448208, 46.31929412484169, 1.1040361016057432, 5.097051719203591, 61.236495673656464, 47.90227398276329, 38.29895429313183, 21.68001215904951, 23.931085467338562, 33.67028586566448, 30.924813486635685, 35.8995046466589, 39.11403335630894, 68.03541004657745, 34.64643068611622, 0.13464071351336315, 0.13140487542841583, 0.03942533367080614, 0.029997380879649427, 0.07959005422890186, 0.04828271776204929, 0.022136270672490355, 0.07797528931405395, 0.040885627968236804, 0.04428525433468167, 0.22501067054690793, 0.2706685900921002, 0.13306853303220123, 0.17662903934251517, 0.1934528147103265, 0.1910988410236314, 0.17851568263722584, 0.37656964967027307, 0.22011251072399318, 0.18577266979264095, 0.1864110355381854, 0.34750070481095463, 2.197063243947923, 63.26291933655739, 66.7568090558052, 44.58392724394798, 50.05200482904911, 67.11428627371788, 32.81309366226196, 37.85435155034065, 43.18246744573116, 66.80162385106087, 67.69473552703857, 20.761263258755207, 48.36179092526436, 79.00483623147011, 72.78596833348274, 75.37645652890205, 62.5002508610487, 63.56358580291271, 57.62619540095329, 56.96867488324642, 53.598191142082214, 60.90522184967995, 63.56130212545395, 64.02472525835037, 60.51656350493431, 58.24564576148987, 59.70382131636143, 58.553569838404655, 55.67395895719528, 54.964981600642204, 53.9044851064682, 54.62580420076847, 50.60738302767277, 50.46906664967537, 50.97606584429741, 50.75664281845093, 49.40207630395889, 50.20640194416046, 49.94210712611675, 49.59181152284145, 49.90144930779934, 50.51226273179054, 51.793732568621635, 55.09587697684765, 59.14142869412899, 57.79002360999584, 57.84793630242348, 57.102347910404205, 56.58333756029606, 55.796167999506, 52.12722547352314, 53.809835985302925, 52.38545581698418, 49.139650985598564, 51.61477357149124, 56.172883585095406, 55.38972660899162, 54.74540278315544, 49.38223756849766, 55.39209768176079, 53.601485565304756, 55.58301083743572, 35.9708534181118, 42.88090422749519, 42.17649422585964, 44.05015088617802, 45.0192166864872, 40.21567024290562, 36.944885551929474, 39.915288761258125, 38.76916006207466, 34.693711549043655, 36.834927052259445, 30.81158336251974, 29.160606153309345, 19.975619316101074, 10.54370652884245, 30.30870694667101, 34.528382420539856, 38.76455470919609, 43.963830918073654, 32.45422571897507, 32.11127892136574, 34.74947355687618, 48.240816816687584, 51.880641505122185, 50.14094665646553, 46.182060688734055, 42.605092227458954, 44.477966129779816, 36.26748830080032, 53.59284482896328, 55.901745334267616, 55.6441343575716, 51.71696908771992, 53.99004131555557, 58.15968297421932, 55.96260666847229, 54.12466049194336, 54.13286045193672, 50.437129363417625, 46.44729405641556, 45.918313041329384, 49.43945489823818, 52.31223374605179, 53.14589761197567, 52.166940942406654, 50.70872358977795, 46.43913969397545, 49.90139991044998, 49.266385585069656, 48.56844663619995, 49.95826005935669, 47.33630195260048, 46.35796844959259, 47.40608140826225, 49.213819205760956, 48.76406393945217, 47.25180968642235, 45.47899201512337, 45.930362194776535, 47.344980686903, 51.69706955552101, 49.92098405957222, 53.84067513048649, 54.016085118055344, 54.3593966960907, 52.59566433727741, 56.553972736001015, 52.83402934670448, 56.281728744506836, 52.21655488014221, 57.56414473056793, 60.97324199974537, 66.24313741922379, 62.9302129894495, 69.7461998462677, 67.54414960741997, 71.21697932481766, 63.31061817705631, 57.697551771998405, 1.88986575929448, 3.82629896979779, 65.05456119775772, 55.932519882917404, 44.8905061930418, 24.705159030854702, 35.17814755439758, 43.875189274549484, 53.239741176366806, 63.173973709344864, 42.64473170042038, 78.63588362932205, 39.9756371229887, 0.368938620085828, 0.23819406313123181, 0.1514875251450576, 0.27502128621563315, 0.14827534672804177, 0.22448454721597955, 0.18054869229672477, 0.20581041957484558, 0.19501735107041895, 0.1944935432402417], [0.05359585687983781, 0.0591124186757952, 0.011313981030980358, 0.00456476435829245, 0.02425752354611177, 0.004889172878392856, 0.04327851616835687, 0.026708121149567887, 0.06830249272752553, 0.06423626560717821, 0.0027326114013703773, 0.23776395886670798, 0.9050312207546085, 46.277082189917564, 51.59422807395458, 32.340775206685066, 37.03228086233139, 47.971711456775665, 29.53594621270895, 15.913428291678429, 21.25392012298107, 47.78475008904934, 68.02467182278633, 27.41444405168295, 26.5378462895751, 67.1311953663826, 67.42351368069649, 69.41747948527336, 59.28900897502899, 56.46312341094017, 49.96965564787388, 50.69776877760887, 55.11364482343197, 61.81453965604305, 59.67178523540497, 58.24503019452095, 55.97464062273502, 53.80610838532448, 52.35876984894276, 51.87822863459587, 49.543200731277466, 49.51007790863514, 47.16043218970299, 46.71946585178375, 45.321061089634895, 45.04292741417885, 44.41163308918476, 45.585785284638405, 44.03019815683365, 44.62701313197613, 43.714670687913895, 42.880193665623665, 45.3267265856266, 47.897391244769096, 48.19038212299347, 50.860365852713585, 51.981210708618164, 53.678446635603905, 49.51136603951454, 49.955888986587524, 49.72530975937843, 49.23899665474892, 50.90905264019966, 54.72899526357651, 52.080408185720444, 53.65939065814018, 48.883578926324844, 47.79918171465397, 45.61899550259113, 48.16990502178669, 44.208902567625046, 46.6880339384079, 44.261347353458405, 47.24446848034859, 24.19582486152649, 33.039325922727585, 33.09050537645817, 31.978320255875587, 32.36529529094696, 27.458335496485233, 22.604576647281647, 11.584223695099354, 14.086917601525784, 8.187578357756138, 2.4189195642247796, 1.3499156828038394, 0.7142078946344554, 1.1770943063311279, 0.632914878660813, 0.5303690687287599, 2.497825180180371, 2.766531561501324, 1.123360083438456, 1.5209006890654564, 5.736170774325728, 23.884532265365124, 37.76485115289688, 36.70753128826618, 36.300512328743935, 31.348306462168694, 30.43795321136713, 35.64435973763466, 27.355837896466255, 48.11139576137066, 48.46771024167538, 48.23610506951809, 42.07537405192852, 42.328277081251144, 46.00839100778103, 44.273996874690056, 45.55373400449753, 45.84617391228676, 45.46682506799698, 46.91364303231239, 48.81404645740986, 47.925224751234055, 49.27090734243393, 46.020941734313965, 46.85034982860088, 44.658456444740295, 47.69968785345554, 46.40502892434597, 46.56794898211956, 43.149568811059, 42.69297391176224, 42.72346347570419, 41.78789287805557, 43.475158140063286, 44.11374807357788, 42.881857976317406, 42.770953327417374, 43.72952029109001, 41.67814336717129, 42.90756359696388, 43.49974662065506, 44.08819064497948, 44.955216720700264, 48.97226236760616, 50.029833018779755, 48.536585345864296, 50.27737073600292, 47.050093710422516, 49.04116027057171, 47.34970383346081, 50.70200175046921, 55.50425246357918, 58.08052562177181, 53.93193103373051, 63.33745613694191, 62.61689320206642, 59.94042322039604, 50.83483502268791, 31.531800515949726, 0.28912016248796135, 11.652317941188812, 59.29769530892372, 39.82091322541237, 29.66705247759819, 20.711381435394287, 41.86945930123329, 26.770887784659863, 83.32427725195885, 77.01454862952232, 43.10816243290901, 56.808046102523804, 25.646856799721718, 0.14543499913997948, 0.10388937924290076, 0.03787864596233703, 0.049325023355777375, 0.09776013743248768, 0.03145745809888467, 0.028649863343161996, 0.042424263374414295, 0.06076820951420814, 0.04373806885269005, 0.022638450464000925, 0.018248244341521058, 0.07909441090305336, 0.035361845075385645, 0.10994226147886366, 0.030456584754574578, 0.06986638341913931, 0.05612217581074219, 0.015633372349839192, 0.047416215820703655, 0.10519691728404723, 0.1398589913151227, 1.6863136505708098, 53.11935603618622, 58.83815936744213, 39.17545326054096, 42.027485221624374, 55.571573451161385, 30.878809355199337, 25.550364777445793, 30.95488127321005, 52.23247982561588, 71.91437110304832, 32.64583803713322, 26.325458586215973, 69.21720743179321, 70.56420475244522, 72.72404685616493, 63.02083432674408, 61.137085407972336, 52.78506137430668, 55.3282231092453, 59.63280312716961, 66.13523840904236, 63.372851237654686, 63.6212021112442, 59.151885733008385, 58.71166035532951, 56.768763810396194, 58.44031311571598, 53.83128583431244, 53.15386198461056, 52.20493510365486, 49.706846550107, 49.14210945367813, 50.55615037679672, 46.463051810860634, 49.0790556371212, 47.08671234548092, 48.41675117611885, 46.46063894033432, 44.90159399807453, 47.80779965221882, 50.30047729611397, 48.83225508034229, 52.59364664554596, 55.52841916680336, 54.42558914422989, 53.09510953724384, 51.01923532783985, 50.974922105669975, 52.60487504303455, 53.223774433135986, 57.08233058452606, 52.49876953661442, 55.49410700798035, 51.95504531264305, 54.15364533662796, 52.12526477873325, 51.01474016904831, 48.455455899238586, 49.72988851368427, 50.298930779099464, 52.123285084962845, 29.058859013020992, 37.0257718116045, 37.72532947361469, 38.47277596592903, 40.10090120136738, 35.72638973593712, 33.25979009270668, 19.358156248927116, 22.215012051165104, 14.683387745171785, 9.905741661787033, 4.500937331467867, 4.484590133652091, 2.068565539084375, 0.8088843862060457, 2.630937024950981, 6.441835183650255, 9.344222042709589, 8.217189218848944, 5.920651825144887, 12.369944583624601, 30.548990853130817, 44.40076567232609, 45.98735153675079, 44.14923056960106, 38.186092749238014, 36.21735379099846, 40.29043883085251, 30.56249152868986, 50.507395192980766, 50.41185311973095, 53.02383676171303, 46.408102959394455, 44.15311396121979, 49.30804654955864, 48.184401243925095, 48.51466432213783, 47.82621346414089, 49.37887854874134, 51.57642222940922, 51.128726452589035, 51.080423444509506, 51.848818212747574, 49.539374336600304, 48.29449653625488, 48.08611951768398, 50.095254108309746, 47.91896268725395, 48.13387915492058, 46.22328847646713, 46.81259125471115, 44.361711367964745, 45.5309884250164, 45.624433010816574, 46.85935914516449, 45.78706048429012, 44.856980592012405, 45.96078336238861, 45.82410849630833, 46.959521770477295, 47.11579978466034, 47.186035215854645, 49.26449328660965, 52.33476273715496, 51.99580192565918, 52.305568903684616, 53.462713211774826, 50.44706963002682, 52.1928783506155, 51.19410194456577, 54.39338967204094, 60.17681993544102, 61.50539964437485, 56.94032080471516, 66.35047405958176, 68.87715607881546, 65.6457106769085, 59.79587137699127, 35.695387199521065, 0.29510314925573766, 16.239859275519848, 67.64083161950111, 45.42151249945164, 34.907662868499756, 21.58264998346567, 36.45489424467087, 31.186554841697216, 100.70380747318268, 84.00496512651443, 48.80801618099213, 67.01588675379753, 35.33073216676712, 0.16533975605852902, 0.09069708830793388, 0.029723311308771372, 0.012944897862325888, 0.07982498849742115, 0.03447577641054522, 0.04495559180213604, 0.06920282918144949, 0.005530037806238397, 0.020174729834252503, 0.11934348396607675, 0.2212923622573726, 0.17476728768087924, 0.10930008109426126, 0.2256252578808926, 0.13432757172267884, 0.21002259745728225, 0.13681392971193418, 0.16195986710954458, 0.28400881332345307, 0.13971171953016892, 0.4696664056973532, 2.6880242116749287, 64.467743486166, 66.87533989548683, 41.93564034998417, 47.70427420735359, 66.25443041324615, 42.08833135664463, 21.22516706585884, 30.565926544368267, 62.55202308297157, 75.26173308491707, 34.45083998143673, 32.96889290213585, 72.2964558005333, 73.47132235765457, 76.26465886831284, 66.32370829582214, 63.00810120999813, 53.930274322628975, 57.41260506212711, 61.504932269454, 68.8742758333683, 66.87324240803719, 66.0717362165451, 61.32020518183708, 61.24164819717407, 58.35052013397217, 59.804576709866524, 55.64616724848747, 55.572037026286125, 55.00208280980587, 53.38327847421169, 53.162734508514404, 53.14373552799225, 48.62499140202999, 52.79021389782429, 49.89797629415989, 50.57995989918709, 47.791734114289284, 47.80377186834812, 50.797399431467056, 52.67947643995285, 51.13399676978588, 56.09375663101673, 58.432778120040894, 56.95328190922737, 53.4002635627985, 54.286600202322006, 56.302418634295464, 55.437767431139946, 55.231035724282265, 60.33258497714996, 56.807643324136734, 60.4214546084404, 55.41019231081009, 55.95758713781834, 53.28772880136967, 54.00141030550003, 50.966433361172676, 53.43077592551708, 54.86951932311058, 54.13383699953556, 35.749359503388405, 42.435921505093575, 42.91040204465389, 46.51946738362312, 45.52723042666912, 44.853002205491066, 39.74443092942238, 22.807784043252468, 20.722340047359467, 11.448490228503942, 6.116828173398972, 1.5846275445073843, 1.8353687273338437, 1.5315922466106713, 0.5946735525503755, 1.1470822105184197, 6.971720550209284, 8.620857708156109, 4.742250507697463, 2.628533891402185, 9.025403950363398, 27.963894568383694, 43.39269116520882, 46.684644520282745, 51.57639563083649, 43.69763620197773, 40.62066771090031, 46.262479573488235, 36.046970933675766, 53.48131321370602, 53.8228502869606, 57.78898246586323, 49.50364105403423, 48.41703616082668, 54.54122453927994, 51.7626578360796, 53.407403379678726, 52.782846093177795, 50.77167861163616, 52.61008456349373, 53.20233978331089, 51.7240747064352, 55.86805634200573, 53.567021414637566, 51.860643178224564, 51.01152554154396, 56.02115772664547, 52.05439478158951, 53.13178896903992, 48.97064745426178, 48.106410428881645, 47.974413111805916, 47.935472801327705, 49.34571772813797, 49.56374242901802, 50.296916887164116, 47.91511349380016, 50.055420845746994, 47.58153319358826, 51.18588678538799, 50.37697099149227, 48.98268520832062, 53.71370114386082, 56.10166400671005, 55.505012422800064, 54.96352627873421, 57.78374634683132, 52.237309366464615, 56.66314847767353, 54.69693638384342, 56.76402926445007, 62.36265264451504, 63.9772430062294, 57.20175817608833, 70.69149032235146, 72.68771320581436, 72.80315101146698, 65.81346407532692, 46.678564846515656, 0.23345979920122772, 14.975185487419367, 70.2117432653904, 52.678408697247505, 39.422987177968025, 28.189936839044094, 56.37256667017937, 43.5123885422945, 102.47848704457283, 96.02441176772118, 56.87722139060497, 74.17081162333488, 46.55283719301224, 0.27918948442675173, 0.19612895470345393, 0.14863968186546117, 0.11489751472254284, 0.13637508294777945, 0.08377637568628415, 0.10077479324536398, 0.179719535226468, 0.07888898442615755, 0.12428992791683413], [0.04181290809356142, 0.016161716557689942, 0.05286412524583284, 0.0508356760838069, 0.05933398686465807, 0.023784200311638415, 0.0560649191174889, 0.06824231197242625, 0.06733318106853403, 0.13122064468916506, 0.07504301189328544, 0.09160815621726215, 0.7312372152227908, 47.38634526729584, 56.7354092001915, 41.67156212031841, 38.18024106323719, 44.4222117215395, 23.541847653687, 28.757886663079262, 23.895781561732292, 37.615370973944664, 65.23003578186035, 43.567143604159355, 15.929377935826778, 55.32775953412056, 67.3146191239357, 68.715550750494, 61.30623713135719, 58.18832203745842, 48.63146245479584, 55.24490498006344, 61.663094982504845, 62.10113547742367, 61.77594892680645, 59.31175835430622, 54.35120053589344, 54.53217342495918, 52.26230062544346, 53.733045905828476, 52.307385206222534, 50.74989818036556, 47.63745479285717, 49.89173702895641, 45.39475053548813, 44.52369287610054, 44.09051612019539, 45.28895661234856, 45.54233841598034, 45.644275546073914, 45.39339400827885, 43.628825694322586, 44.003664180636406, 45.35589002072811, 48.39068457484245, 48.203274831175804, 47.59935423731804, 50.46977341175079, 48.93120177090168, 50.30713453888893, 48.398455157876015, 51.809836104512215, 51.42326384782791, 54.39089700579643, 51.14668048918247, 50.00250108540058, 51.12625278532505, 51.016598269343376, 49.22514259815216, 45.25698132812977, 44.55133259296417, 47.07331046462059, 44.252900406718254, 48.065125644207, 24.19200986623764, 29.593900702893734, 29.873373806476593, 24.875754676759243, 27.47869100421667, 28.406226933002472, 12.547674346715212, 1.1001591221429408, 1.2132631405256689, 0.9432544384617358, 2.6639389665797353, 1.405563815496862, 4.1650130320340395, 6.939159147441387, 5.019212421029806, 1.2072467571124434, 3.1391825526952744, 2.456864803098142, 2.0137710543349385, 0.9974089544266462, 1.3269063737243414, 11.983546167612076, 36.44892856478691, 35.19940361380577, 37.32376702129841, 30.125784762203693, 29.02841504663229, 32.643041387200356, 29.5007885992527, 47.47647263109684, 45.19096367061138, 48.04774917662144, 46.000103652477264, 41.53067708015442, 44.04613070189953, 44.43750970065594, 48.2842218875885, 48.7869007140398, 50.035468116402626, 49.49520170688629, 49.46817755699158, 45.91993175446987, 45.24087779223919, 44.029578790068626, 46.38000346720219, 44.90846022963524, 44.15311396121979, 42.65454277396202, 43.3389088511467, 42.01743096113205, 44.22722138464451, 42.66178138554096, 42.759823724627495, 41.98104411363602, 41.3829980045557, 43.234460055828094, 43.650279343128204, 43.64918500185013, 43.8616544008255, 42.827095314860344, 43.39537762105465, 45.38571462035179, 46.97193570435047, 47.226818427443504, 49.2593065649271, 51.0490333288908, 51.503606736660004, 50.9323263913393, 49.354537054896355, 47.501859068870544, 54.233235865831375, 56.992499604821205, 57.19267666339874, 55.72814404964447, 59.47286210954189, 66.40449956059456, 58.29090893268585, 50.94319760799408, 20.46424649655819, 0.25077045313082635, 28.70933286845684, 61.138533130288124, 36.40710420906544, 21.746350899338722, 30.737420842051506, 33.90298157930374, 30.04836581647396, 44.980059787631035, 50.27630679309368, 30.938853733241558, 51.88232861459255, 31.577738150954247, 0.6725077447481453, 0.05765993548266124, 0.045231819167383946, 0.10968889968353324, 0.03895403649949003, 0.13307783956406638, 0.022707835705659818, 0.03197419697244186, 0.019065059495915193, 0.02881645137676969, 0.038184959994396195, 0.07601429024362005, 0.0062675183016835945, 0.026647374506865162, 0.030556800666090567, 0.039728564079268835, 0.07100816277670674, 0.003959713621952687, 0.03877451097650919, 0.04920327402942348, 0.0852509266405832, 0.21627238631481305, 2.7336191525682807, 57.99821823835373, 63.16690608859062, 43.43047633767128, 40.03897972404957, 51.60973884165287, 27.34244741499424, 34.3322179466486, 29.21974617987871, 42.321597039699554, 69.18557032942772, 50.59810392558575, 17.763993591070175, 55.48472911119461, 71.35328561067581, 70.95140397548676, 64.34101268649101, 60.638935938477516, 53.94598267972469, 60.79793840646744, 65.27473658323288, 66.71823352575302, 63.88312965631485, 64.2000250518322, 59.186821058392525, 57.330901846289635, 54.710334464907646, 56.727904602885246, 54.01852458715439, 53.98332327604294, 51.274304240942, 51.94530263543129, 46.75070017576218, 46.79066263139248, 47.054208889603615, 46.00237973034382, 48.53450685739517, 47.47582286596298, 47.69041635096073, 45.650640204548836, 44.720719903707504, 49.31129537522793, 50.13223372399807, 49.54801507294178, 50.68460628390312, 51.690298318862915, 53.372639045119286, 52.20178507268429, 51.261023953557014, 54.64810520410538, 54.76579628884792, 56.940936371684074, 55.158326625823975, 54.06023494899273, 53.770929872989655, 54.68864522874355, 52.330016791820526, 48.53251576423645, 48.26604746282101, 52.1626053750515, 48.43877099454403, 52.16366931796074, 30.198539458215237, 33.09528551995754, 34.80005644261837, 29.54545520246029, 36.665026769042015, 36.154588758945465, 22.33494121581316, 4.895789818838239, 5.824985783547163, 5.834845779463649, 4.836952351033688, 3.3306481037288904, 2.246512365527451, 2.0833612326532602, 2.524537746794522, 1.1552844266407192, 0.8812194422353059, 1.5146685484796762, 1.7013773485086858, 1.8166474881581962, 2.5077279238030314, 16.337118856608868, 39.902073070406914, 36.65647342801094, 43.78966346383095, 35.80305062234402, 34.75018411874771, 36.568470150232315, 34.741345793008804, 53.41102458536625, 47.746945917606354, 53.1412048637867, 46.764881014823914, 44.96324948966503, 47.870378494262695, 48.720712065696716, 51.01398780941963, 53.18149410188198, 54.073564633727074, 51.8803945183754, 51.29101574420929, 50.47274485230446, 49.066067934036255, 48.558871150016785, 49.82126601040363, 49.42136786878109, 46.633313074707985, 46.59463495016098, 45.78020565211773, 44.92255747318268, 48.47397230565548, 46.99212782084942, 47.35445357859135, 43.19803141057491, 44.008850902318954, 46.581046879291534, 45.04735417664051, 45.569088980555534, 45.970803424715996, 47.154778093099594, 47.024540081620216, 48.111597150564194, 49.096793085336685, 51.24771326780319, 54.891630336642265, 54.171983152627945, 54.69044253230095, 52.8184349834919, 51.98575906455517, 51.347024738788605, 57.99066424369812, 61.21344991028309, 61.3043562322855, 60.363310128450394, 61.35175108909607, 69.33343559503555, 62.955101653933525, 60.40856570005417, 23.59018675982952, 0.3163200826384127, 36.532265692949295, 65.79845488071442, 40.39528660476208, 27.38804306834936, 34.33027245104313, 37.30527341365814, 35.51931984722614, 58.475913405418396, 61.9309464097023, 39.44204695522785, 62.22562439739704, 47.278784438967705, 1.3467630394734442, 0.05673029532772489, 0.06586077492102049, 0.03670378908282146, 0.031237607981893234, 0.13909695408074185, 0.05896388152905274, 0.022010144530213438, 0.04167145845713094, 0.017427011553081684, 0.16808046289952472, 0.13719028764171526, 0.16884759126696736, 0.18857831455534324, 0.17770304577425122, 0.1638637133873999, 0.3417364734923467, 0.14742128318175673, 0.18605150951771066, 0.276981238857843, 0.2754281315719709, 0.5267119430936873, 4.317282261326909, 72.21804320812225, 71.73200368881226, 53.25772561132908, 49.0203981846571, 59.57913480699062, 31.330316327512264, 37.306956723332405, 30.52062727510929, 52.12141938507557, 75.38039311766624, 52.553133219480515, 22.33693040907383, 61.715592965483665, 72.54353374242783, 75.72720050811768, 65.90050980448723, 63.01790468394756, 54.45519335567951, 62.32284978032112, 67.28157609701157, 70.8103783428669, 66.81971088051796, 67.58299872279167, 61.31023831665516, 60.13566434383392, 57.92965851724148, 58.886587768793106, 58.20052698254585, 58.531128242611885, 54.433439522981644, 56.02849133312702, 50.83682231605053, 49.24531191587448, 49.69653770327568, 51.27863980829716, 51.39192312955856, 49.696617498993874, 49.327174723148346, 49.59892474114895, 48.76977503299713, 51.63124568760395, 53.14531624317169, 52.98718012869358, 53.45746569335461, 55.503298714756966, 55.72418846189976, 54.42921034991741, 52.86312058568001, 57.336673736572266, 58.11414621770382, 58.18889580667019, 57.01765425503254, 56.19582675397396, 57.247826904058456, 57.98088736832142, 56.58107288181782, 50.69065935909748, 52.196336165070534, 54.69162426888943, 53.42702932655811, 56.073556914925575, 35.79520024359226, 38.53808306157589, 39.58124488592148, 35.69135561585426, 44.63665321469307, 41.68557196855545, 17.2127590700984, 1.4253658591769636, 3.1371242506429553, 5.052690049633384, 3.4876081813126802, 9.25237337127328, 12.743759974837303, 11.793561112135649, 8.082039970904589, 4.443371845409274, 4.891523597761989, 3.1460768077522516, 3.180804569274187, 1.4631766802631319, 1.7842058977112174, 16.410639211535454, 44.16183449327946, 41.530065312981606, 49.96571145951748, 40.59314578771591, 43.51812623441219, 40.99028527736664, 39.81130354106426, 54.97811749577522, 49.24921050667763, 55.733919739723206, 50.252607464790344, 47.7810300886631, 49.643598943948746, 52.95770511031151, 51.965099573135376, 54.694436118006706, 54.441175907850266, 56.281572952866554, 52.6875776052475, 52.567754834890366, 50.248670876026154, 51.01762421429157, 52.54848226904869, 53.82374703884125, 50.267605260014534, 51.08695529401302, 49.20496568083763, 48.42818856239319, 50.95715805888176, 49.74790334701538, 50.81349156796932, 45.65771922469139, 46.74549825489521, 48.9244419336319, 47.70774342119694, 49.59878794848919, 47.9778291285038, 49.263417944312096, 50.07560156285763, 51.678336560726166, 52.51932643353939, 53.419760316610336, 56.82108320295811, 57.459384351968765, 57.02660657465458, 56.97104215621948, 56.344850957393646, 52.93595887720585, 60.78311540186405, 64.0200287103653, 65.74080437421799, 65.00835567712784, 65.70364996790886, 73.43947246670723, 67.69390717148781, 64.75093469023705, 31.962254717946053, 0.2652898896485567, 35.15480160713196, 72.48608082532883, 49.54744130373001, 31.10882431268692, 41.066182404756546, 44.004811719059944, 47.01571695506573, 59.85852621495724, 61.36211313307285, 44.702739268541336, 67.76254668831825, 57.062062472105026, 1.8507263157516718, 0.23437750933226198, 0.17724576406180859, 0.11749492026865482, 0.11278783378656954, 0.25323411624412984, 0.1340246418840252, 0.09069282095879316, 0.25243785115890205, 0.10817911897902377], [0.05977799526590388, 0.019009003226528876, 0.029460932419169694, 0.018582377779239323, 0.025986729488067795, 0.04604395136993844, 0.04811825783690438, 0.05488028815307189, 0.02546040021115914, 0.09697199144284241, 0.13137284433469176, 0.05142365371284541, 2.6920766942203045, 48.73802773654461, 48.68798442184925, 28.704763613641262, 28.266745917499065, 45.84066420793533, 26.38333898037672, 32.3938013613224, 23.631405048072338, 23.176993131637573, 54.29982349276543, 57.391717582941055, 10.458021126687527, 37.88758456707001, 69.78295147418976, 67.00409218668938, 65.72395607829094, 55.7311724871397, 52.006019577383995, 61.19487650692463, 60.87228521704674, 62.001216039061546, 59.38347190618515, 61.78013630211353, 56.59126773476601, 54.88444872200489, 52.32470087707043, 51.18036188185215, 49.176653400063515, 49.40927691757679, 47.81312696635723, 48.083026483654976, 44.469560980796814, 46.15709602832794, 44.40024130046368, 45.526873245835304, 43.962064012885094, 45.152866914868355, 44.56759192049503, 46.95450223982334, 43.10064263641834, 43.34561549127102, 46.1730931699276, 47.50913567841053, 49.698752984404564, 47.17259533703327, 47.41877272725105, 49.4733414798975, 49.07090127468109, 52.64714017510414, 51.68954595923424, 52.18274049460888, 52.517016157507896, 54.19217146933079, 48.98843429982662, 51.69700875878334, 46.1249915510416, 43.987112268805504, 43.47828157246113, 48.02761025726795, 42.11953528225422, 47.17357188463211, 28.347162902355194, 29.67751331627369, 30.714162290096283, 25.131391659379005, 29.672115705907345, 23.814456425607204, 5.203003333881497, 6.695765582844615, 8.531496953219175, 8.572946079075336, 15.572717674076557, 24.69885516911745, 9.835331439971924, 2.9469059826806188, 3.473691903054714, 1.9069830095395446, 0.7422676670830697, 1.0963742877356708, 1.5498598851263523, 1.356017799116671, 1.4832073054276407, 14.105232618749142, 33.89241814613342, 45.59839300811291, 34.50165085494518, 33.97184148430824, 29.078458361327648, 31.271011009812355, 28.180857226252556, 48.9063511043787, 49.335861057043076, 47.902285382151604, 43.30086909234524, 43.84918347001076, 43.94861653447151, 46.41295149922371, 50.84328576922417, 47.63857573270798, 50.02377614378929, 50.56729897856712, 50.74132964015007, 47.602052092552185, 48.20191070437431, 47.13321805000305, 46.810227781534195, 47.59138226509094, 43.41142416000366, 43.247690945863724, 43.52020092308521, 39.96749795973301, 41.88742853701115, 42.84964330494404, 43.06479915976524, 44.40620698034763, 42.127283066511154, 42.18639649450779, 42.50121720135212, 41.913726925849915, 44.27447184920311, 46.2189757078886, 43.234881833195686, 48.7892109900713, 45.79126685857773, 51.10132232308388, 51.541030928492546, 51.63877688348293, 51.312879770994186, 50.35341985523701, 50.28031937777996, 50.53524769842625, 53.18770296871662, 57.101352363824844, 56.08315519988537, 57.30972558259964, 59.88542877137661, 65.6004399061203, 62.43870936334133, 55.186308324337006, 13.43682473525405, 1.8283888581208885, 54.20603692531586, 54.95921730995178, 33.56342799961567, 18.345280699431896, 21.689935326576233, 21.127029731869698, 33.69229428470135, 25.73018442839384, 38.94422426819801, 29.721260368824005, 42.84461997449398, 47.54192411899567, 1.968992950860411, 0.09271875052945688, 0.03310810214316007, 0.007745869515929371, 0.05150929013325367, 0.11141387352836318, 0.01902151583635714, 0.055151754640974104, 0.10163211481994949, 0.009922650806402089, 0.0801417742331978, 0.009131299666478299, 0.018004326375375967, 0.06348615468596108, 0.042884855065494776, 0.017824570786615368, 0.1027064181107562, 0.0361952546518296, 0.023386527900584042, 0.11988220896455459, 0.11652189787128009, 0.3065319563029334, 4.1805242747068405, 59.34531435370445, 58.197046369314194, 34.34504225850105, 35.4892672598362, 51.673001646995544, 29.333987049758434, 35.52192270755768, 30.397059805691242, 29.428392983973026, 55.312096774578094, 64.8607487976551, 11.711521614342928, 35.25746829807758, 72.76060089468956, 71.36818081140518, 68.30340966582298, 59.48822468519211, 55.927443355321884, 65.51718637347221, 63.79276290535927, 65.76519906520844, 61.86413459479809, 65.86273983120918, 59.24848414957523, 57.76980869472027, 54.17247332632542, 55.5441465228796, 50.616814121603966, 52.050955966115, 51.90774165093899, 52.084466367959976, 47.427348867058754, 49.17820371687412, 46.670676469802856, 47.62772351503372, 46.34278066456318, 47.4324481934309, 46.40175350010395, 50.43378174304962, 46.85107558965683, 47.00880132615566, 47.12919406592846, 50.274938866496086, 50.828002989292145, 52.30846054852009, 51.350170969963074, 52.29554884135723, 52.85320311784744, 55.171986892819405, 55.4836043715477, 56.243593990802765, 55.814441218972206, 57.08351232111454, 53.25356103479862, 54.57147851586342, 50.91646984219551, 48.887789100408554, 46.8446159362793, 50.94451613724232, 48.82997140288353, 53.437680155038834, 35.36024898290634, 33.48691910505295, 34.75743792951107, 32.660216465592384, 36.01719953119755, 29.877095706760883, 12.59912358596921, 13.684741482138634, 9.738315995782614, 9.102050587534904, 6.505402447655797, 18.74753851443529, 14.055211152881384, 6.843132600188255, 7.306452663615346, 2.7864408306777477, 1.0110131744295359, 1.40483912313357, 1.655324650928378, 1.9106952915899456, 3.2547775749117136, 17.392953000962734, 36.199737936258316, 47.195451110601425, 39.57506641745567, 42.85679452121258, 34.012233316898346, 37.24387630820274, 34.397137463092804, 55.11101916432381, 49.94388923048973, 51.326608434319496, 48.14297966659069, 47.78794951736927, 47.90159001946449, 48.36313225328922, 52.34674349427223, 49.8317838460207, 53.6407108604908, 53.832250982522964, 52.123646065592766, 50.906989350914955, 51.7606021463871, 50.44546231627464, 49.927504509687424, 50.275410041213036, 46.92598097026348, 44.862965270876884, 45.76541684567928, 45.05765162408352, 44.71967115998268, 45.95304697751999, 46.30879148840904, 45.26893928647041, 45.074480921030045, 44.063294380903244, 45.73589622974396, 45.41467286646366, 47.92531594634056, 50.01702770590782, 46.754446774721146, 51.945496425032616, 49.39155846834183, 52.492249086499214, 52.88481742143631, 53.0866701900959, 55.3524924069643, 52.46491715312004, 53.851812332868576, 55.647945553064346, 56.180258989334106, 61.51174530386925, 57.951530143618584, 61.291490122675896, 61.831452548503876, 70.9169702231884, 66.42112746834755, 64.79783177375793, 13.067283164709806, 2.8397695440799, 60.77326253056526, 57.10118517279625, 34.899660497903824, 23.078054040670395, 15.907895788550377, 11.332259215414524, 32.23232142627239, 41.14020623266697, 51.27871200442314, 34.25260081887245, 51.84628374874592, 58.827451542019844, 4.509980846196413, 0.1623538733110763, 0.08072236378211528, 0.02458350449160207, 0.045031784393358976, 0.1259633744484745, 0.07911674954812042, 0.11591053887968883, 0.09420332789886743, 0.0022832481727164122, 0.24439835833618417, 0.14812044566497207, 0.1418180830660276, 0.14564513083314523, 0.15449687460204586, 0.17718351271469146, 0.20164716406725347, 0.15710436593508348, 0.2120497589930892, 0.2895651542348787, 0.4386295226868242, 0.5806757567916065, 6.075920993462205, 69.28736686706543, 63.70848722755909, 40.922006741166115, 39.29772689938545, 62.32905484735966, 34.864736571908, 39.584208726882935, 29.78327114135027, 37.09002636373043, 64.64021623134613, 66.34088337421417, 15.06881246343255, 42.98618517816067, 75.38508966565132, 75.79739794135094, 72.7596053481102, 62.50158078968525, 58.58175292611122, 67.54138335585594, 67.06713080406189, 66.1415308713913, 62.79894903302193, 69.79907020926476, 61.99670188128948, 60.85772819817066, 57.33460284769535, 58.5869662463665, 55.72211377322674, 55.49761421978474, 55.40595933794975, 56.20379112660885, 49.9742192029953, 51.97381250560284, 49.23759452998638, 49.89171043038368, 49.43579949438572, 50.10695368051529, 49.16379489004612, 53.73527258634567, 48.90649929642677, 48.40687930583954, 50.83105802536011, 52.21775941550732, 54.34586942195892, 54.310120940208435, 55.215600952506065, 56.3225157558918, 56.7481879144907, 57.099182680249214, 56.864290684461594, 58.2278361171484, 58.57744015753269, 59.153857827186584, 56.80179923772812, 58.91219459474087, 54.313251972198486, 52.11863033473492, 48.36033560335636, 55.04084452986717, 51.087179481983185, 54.54766899347305, 41.312648579478264, 38.26256364583969, 38.96654427051544, 37.17213995754719, 44.14601594209671, 33.67653653025627, 9.673052597790956, 13.848628588020802, 14.201657194644213, 11.211688835173845, 27.669963240623474, 47.98535272479057, 24.081532694399357, 11.406899560242891, 11.157580688595772, 6.372680319473147, 3.1802566861733794, 3.631471311673522, 6.487664049491286, 4.738124404102564, 9.658538326621056, 19.06246181577444, 43.85819658637047, 49.96420294046402, 45.385855212807655, 46.32842503488064, 39.43200409412384, 43.4681361168623, 37.87635616958141, 56.73878341913223, 53.07951137423515, 55.25615997612476, 49.04057130217552, 49.97326545417309, 49.66878779232502, 52.10913844406605, 55.71533113718033, 54.34002913534641, 55.68881995975971, 57.58285112679005, 54.858142733573914, 54.680407270789146, 53.98698627948761, 52.41053827106953, 51.649727895855904, 56.63551636040211, 50.282485261559486, 48.66559982299805, 49.311610758304596, 46.73142001032829, 48.131029307842255, 49.41876880824566, 49.36351217329502, 50.48061802983284, 48.57692018151283, 47.67463579773903, 48.27404223382473, 48.320825323462486, 50.10422542691231, 53.71136046946049, 47.027762308716774, 57.13186852633953, 51.237168833613396, 56.53197191655636, 55.833288207650185, 56.718557104468346, 58.501740619540215, 56.131705194711685, 55.68027801811695, 57.274281084537506, 60.19772261381149, 65.8113893866539, 63.56437236070633, 63.6148564517498, 64.51711043715477, 72.62446939945221, 69.7801624238491, 70.85080817341805, 18.19904364645481, 1.9110182742588222, 63.08475449681282, 66.90383836627007, 47.86535136401653, 25.435166358947754, 27.400481700897217, 29.18703753501177, 50.62608562409878, 40.230702236294746, 52.13390551507473, 42.38270156085491, 53.31261746585369, 73.04918020963669, 5.884040789678693, 0.20041346229845658, 0.12001873445115052, 0.14390068303328007, 0.21193748689256608, 0.36401476711034775, 0.18607246776809916, 0.19456260750303045, 0.43981704802718014, 0.11890825888258405], [0.06755156544386409, 0.03953390987589955, 0.07285643703653477, 0.07358354880125262, 0.07095779321389273, 0.025680179824121296, 0.055236147964023985, 0.05486681817274075, 0.08097559941234067, 0.04134164802962914, 0.031013134284876287, 0.1873488281853497, 4.735957570374012, 55.080970376729965, 56.20539844036102, 49.98441405594349, 26.790905110538006, 49.80152226984501, 30.658371783792973, 28.656652495265007, 24.847168810665607, 16.56940419226885, 37.680552676320076, 76.04883804917336, 13.37618948891759, 14.34486486017704, 70.09025618433952, 66.25262930989265, 66.67085006833076, 58.6217799782753, 55.18205635249615, 65.56165158748627, 63.47574971616268, 59.80822451412678, 60.736127123236656, 62.49044358730316, 56.88009783625603, 55.543945133686066, 50.88656924664974, 50.558046475052834, 51.8854596465826, 51.57198786735535, 47.678105011582375, 46.70203618705273, 45.92091590166092, 43.64531680941582, 44.860058426856995, 46.675289422273636, 43.39326113462448, 47.07473158836365, 44.83559913933277, 45.942882522940636, 44.6694378554821, 44.070969969034195, 45.62980592250824, 46.41452081501484, 47.0861841738224, 47.48509056866169, 46.42347693443298, 51.032899394631386, 50.14422208070755, 52.73350574076176, 51.861475333571434, 52.036889120936394, 51.47058270871639, 52.02507555484772, 50.1804493367672, 49.760940447449684, 48.191442266106606, 47.93091684579849, 46.13285332918167, 48.12104344367981, 43.49708676338196, 47.96077184379101, 29.737268909811974, 27.080023996531963, 32.03529819846153, 28.48331529647112, 27.85158209502697, 20.467464923858643, 23.29027835279703, 26.211949177086353, 15.522119589149952, 16.226485893130302, 44.56355653703213, 22.54297625273466, 4.15581657551229, 5.336224185302854, 3.0237143486738205, 1.1262183613143861, 0.5287349782884121, 0.48654955287929624, 0.4669722612015903, 0.6039620947558433, 1.6656175861135125, 14.254567455500364, 22.40058459341526, 28.412154614925385, 33.09952229261398, 35.33453196287155, 28.144679367542267, 32.47128680348396, 30.138795264065266, 48.460528627038, 47.91958585381508, 45.979162976145744, 47.54853196442127, 45.96892632544041, 44.085808172822, 46.4840304851532, 47.219374626874924, 50.22488795220852, 50.261852368712425, 49.04347434639931, 49.28688548505306, 48.96896794438362, 47.459970116615295, 49.21872854232788, 46.413544267416, 43.033165857195854, 42.69073203206062, 41.174639984965324, 41.68872579932213, 41.15130163729191, 43.37137430906296, 43.04704651236534, 40.001836717128754, 41.31810888648033, 40.392121374607086, 43.01520422101021, 43.91709342598915, 44.66400794684887, 44.29608888924122, 44.64414641261101, 47.37162485718727, 48.54873709380627, 51.037041172385216, 51.12727113068104, 49.14734557271004, 52.70956702530384, 50.96815846860409, 52.143120020627975, 50.80823265016079, 50.86875960230827, 54.55163978040218, 55.592787712812424, 57.934313267469406, 58.47180962562561, 60.76685227453709, 67.91803434491158, 61.670333594083786, 56.58627100288868, 6.0657380148768425, 9.328831918537617, 61.997784823179245, 45.87386682629585, 27.483349554240704, 15.984640270471573, 39.307469576597214, 45.9788665920496, 36.85288868844509, 38.31543780863285, 35.24922274053097, 45.59542536735535, 45.57171083986759, 55.339785888791084, 13.757312837988138, 0.10049543401692063, 0.05348363672965206, 0.11484768692753278, 0.04728934196464252, 0.015000123712525237, 0.04741660915897228, 0.06567874093889259, 0.05473067118145991, 0.0392178551555844, 0.07074749082676135, 0.025279930305259768, 0.02559746746555902, 0.04925234112306498, 0.03740983498573769, 0.03364437805430498, 0.008437063188466709, 0.037230569214443676, 0.05635226014419459, 0.06785939345718361, 0.14608969213441014, 0.30179675726685673, 7.0648611523211, 66.95887461304665, 61.95126011967659, 49.77611303329468, 30.705658346414566, 53.565896674990654, 31.50173842906952, 31.480989642441273, 25.933460220694542, 22.62091387063265, 39.567599818110466, 81.07731342315674, 18.132393322885036, 13.741613030433655, 68.06946381926537, 68.82722675800323, 69.7350512444973, 62.55364179611206, 60.72523310780525, 68.55020642280579, 66.38831242918968, 61.967496648430824, 63.990435898303986, 67.49501824378967, 59.58562105894089, 58.79636541008949, 53.33508186042309, 54.940894693136215, 54.044230207800865, 54.25663881003857, 52.202442437410355, 49.98872682452202, 46.39422990381718, 47.08685293793678, 47.97977842390537, 49.1212447732687, 46.647205129265785, 47.41419777274132, 46.60461701452732, 48.15457284450531, 46.5931948274374, 46.274870708584785, 48.00560563802719, 48.32599304616451, 49.80167806148529, 50.46669937670231, 50.156609416007996, 55.37284791469574, 54.155511036515236, 55.93256168067455, 53.3842284232378, 55.54081790149212, 54.53850768506527, 54.88216504454613, 54.56326335668564, 53.70355188846588, 52.7024120092392, 51.63711257278919, 50.93987658619881, 52.53508418798447, 47.18237221240997, 51.586358696222305, 34.38872091472149, 32.09217354655266, 35.68441718816757, 34.05417926609516, 33.48771706223488, 26.304776296019554, 26.32329650223255, 21.101474203169346, 13.478631041944027, 9.8182038590312, 38.81050184369087, 40.06924510002136, 17.582532428205013, 6.3572403229773045, 3.941938877105713, 3.0733190244063735, 1.7268233955837786, 0.26782099914271384, 0.8503874216694385, 1.6937834559939802, 4.6723314095288515, 19.274556934833527, 28.62446442246437, 30.92647209763527, 36.47763982415199, 40.44555030763149, 34.299440905451775, 34.94106687605381, 35.472783744335175, 50.15919707715511, 50.441913306713104, 50.50671882927418, 50.57591691613197, 48.151308819651604, 48.45238946378231, 49.39870968461037, 50.87950922548771, 51.834891960024834, 52.959168031811714, 52.122718915343285, 52.01774574816227, 51.54398716986179, 50.79555653035641, 50.91038256883621, 49.16881822049618, 45.049235075712204, 45.135235860943794, 44.38166789710522, 45.827262327075005, 44.70003001391888, 46.995399445295334, 46.73344150185585, 45.23053474724293, 44.072334095835686, 45.28375469148159, 47.291715145111084, 47.637245804071426, 47.57182851433754, 46.421003267169, 47.8473137319088, 49.58939865231514, 53.45232076942921, 53.922230154275894, 55.2375827729702, 52.406943663954735, 56.98510520160198, 54.481727331876755, 55.856064185500145, 53.556765764951706, 53.68115209043026, 57.34471410512924, 59.07512605190277, 60.8448126912117, 61.51818975806236, 62.8286824375391, 70.71686536073685, 64.6350485086441, 58.81250314414501, 6.308559235185385, 13.759654462337494, 66.74683839082718, 47.41487793624401, 32.98894822597504, 19.45643037557602, 24.83838178217411, 28.847858235239983, 40.40477089583874, 39.54913280904293, 45.067656487226486, 44.39111419022083, 54.27374929189682, 70.99452406167984, 27.21345953643322, 0.3340457158628851, 0.04713686772447545, 0.09746162337251008, 0.020938388661306817, 0.00644951888716605, 0.05951852930593304, 0.045744851013296284, 0.06816524735768326, 0.05769211129518226, 0.21549059310927987, 0.15853763121413067, 0.15483231050893664, 0.18714081903453916, 0.1473120242008008, 0.10080954802106135, 0.15171767998253927, 0.09914093287079595, 0.1758484187303111, 0.20369421516079456, 0.3422473679529503, 0.5872072500642389, 8.81522012874484, 79.00988236069679, 71.82677060365677, 62.37340606749058, 36.2246759980917, 64.51930671930313, 43.793098479509354, 38.16614381968975, 29.769006706774235, 30.825391821563244, 48.38170565664768, 87.6037672162056, 18.91950398683548, 18.39933469891548, 74.37128126621246, 71.53915643692017, 73.18531930446625, 65.98444730043411, 60.170679464936256, 72.98293456435204, 70.84069311618805, 62.81686507165432, 66.28578633069992, 70.30008092522621, 63.02370697259903, 63.24925146996975, 57.07017123699188, 58.98574724793434, 57.49038688838482, 57.10987150669098, 54.441947266459465, 52.467166632413864, 51.3264412432909, 49.1419992595911, 53.16491179168224, 53.17344233393669, 50.03293365240097, 50.95647029578686, 49.16603296995163, 51.54148310422897, 48.80652666091919, 48.263421803712845, 51.38134829699993, 50.349490866065025, 52.73739293217659, 54.20011304318905, 51.58679187297821, 57.95304246246815, 56.691046580672264, 59.77729417383671, 56.56951390206814, 57.013303488492966, 59.13010910153389, 58.846085742115974, 57.26556055247784, 58.78665313124657, 56.09692186117172, 56.34501814842224, 54.76610407233238, 54.91066351532936, 50.75766496360302, 57.00482614338398, 37.5985948741436, 37.799053117632866, 42.79871083796024, 40.505552887916565, 40.23354448378086, 33.38216632604599, 35.43328866362572, 36.190485432744026, 24.180139303207397, 23.304668180644512, 63.25243949890137, 58.22720915079117, 39.270915538072586, 14.146963879466057, 4.80398484505713, 4.130661925300956, 2.9380572075024247, 2.3195347096771, 2.4455278739333153, 4.882319066673517, 6.068765502423048, 19.445296972990036, 31.872811317443848, 30.119841881096363, 40.5620064586401, 48.46488319337368, 40.20905859768391, 44.483521431684494, 39.47781443595886, 54.55094821751118, 53.069521710276604, 52.64774814248085, 55.57763412594795, 52.84846857190132, 51.22504748404026, 53.74745853245258, 52.00943559408188, 55.51985822618008, 56.16178818047047, 55.76707676053047, 52.80854411423206, 54.93339389562607, 51.65905259549618, 53.143184557557106, 53.90785552561283, 49.594402983784676, 49.99403893947601, 47.83071242272854, 49.95597258210182, 48.654458820819855, 50.839090794324875, 48.357105776667595, 46.58287838101387, 46.82250492274761, 48.36675725877285, 50.05063310265541, 49.104176089167595, 51.25489488244057, 49.209384843707085, 48.015496507287025, 52.005764991045, 54.904424250125885, 55.48279121518135, 58.386318013072014, 55.07814332842827, 59.93877790868282, 56.36954963207245, 58.64332102239132, 57.03298643231392, 55.807058215141296, 58.95246863365173, 63.72586369514465, 64.32085856795311, 65.93679785728455, 66.0203629732132, 75.72373509407043, 67.6600281894207, 67.92343765497208, 8.2786575704813, 11.688721887767315, 71.11957535147667, 55.39490573108196, 42.17662341892719, 22.371622547507286, 49.457971304655075, 58.505274429917336, 51.28892585635185, 54.056431353092194, 46.972083896398544, 61.978755444288254, 57.26649530231953, 82.09299132227898, 24.914972372353077, 0.4309599014231935, 0.3290778090013191, 0.36539495398756117, 0.14752982970094308, 0.23274430946912616, 0.08228123755543493, 0.14368497038958594, 0.21350895491195843, 0.08102349020191468], [0.03139295433356892, 0.05293438436638098, 0.08611713914433494, 0.08474331989418715, 0.0338364124763757, 0.06241971073905006, 0.035104271591990255, 0.02547982778196456, 0.028907557425554842, 0.0457449586247094, 0.11602640297496691, 0.2589782205177471, 6.56952828168869, 56.307479962706566, 55.56423984467983, 31.735847666859627, 35.44530741870403, 48.55823278427124, 35.17771817743778, 30.888457037508488, 24.68314491212368, 19.824412129819393, 28.999059721827507, 68.70495691895485, 39.46501672267914, 5.9070134069770575, 50.16331225633621, 72.80521050095558, 65.02385884523392, 59.77446712553501, 56.65233425796032, 62.40195393562317, 63.600177839398384, 63.08812491595745, 58.348802626132965, 61.56453587114811, 57.479131892323494, 52.94945575296879, 49.11603145301342, 48.794629499316216, 48.112566098570824, 50.00635787844658, 46.89858824014664, 46.80162124335766, 46.45393230021, 46.16895519196987, 44.836374297738075, 47.27841965854168, 43.81267502903938, 43.88428218662739, 45.24060420691967, 45.828660652041435, 44.875743985176086, 47.0326754450798, 46.088239923119545, 44.674423187971115, 47.3082784563303, 44.996756091713905, 48.413057774305344, 48.79274480044842, 51.88046671450138, 51.22537046670914, 51.96767583489418, 52.45678558945656, 53.48015807569027, 49.111714884638786, 49.86011512577534, 49.429689422249794, 47.471399903297424, 46.6634226590395, 45.467448234558105, 47.604829743504524, 42.75439001619816, 48.703791573643684, 32.53432162106037, 26.954611726105213, 32.62402720749378, 28.014868833124638, 28.275842629373074, 28.221410550177097, 27.288558706641197, 17.308747619390488, 20.02691276371479, 48.1888660043478, 51.87325470149517, 37.4834268540144, 13.884854894131422, 7.158830109983683, 8.448513206094503, 5.6869676895439625, 2.631968194618821, 1.7479411186650395, 2.909624995663762, 4.144448060542345, 8.271461706608534, 11.467034183442593, 22.210847474634647, 32.15473338961601, 42.12298169732094, 36.282299906015396, 28.950291238725185, 28.852330595254898, 30.57165663689375, 46.6411292552948, 51.546381041407585, 48.06273937225342, 47.84391291439533, 46.15602448582649, 43.941450119018555, 45.68255469202995, 47.353363037109375, 47.354229390621185, 47.152293026447296, 49.7783625125885, 48.512703627347946, 50.05114607512951, 48.265352100133896, 48.98109309375286, 44.84871223568916, 45.51963843405247, 41.323120817542076, 42.25333370268345, 42.27623887360096, 43.392998948693275, 42.63816565275192, 43.870070949196815, 41.544838920235634, 43.231879994273186, 42.64497108757496, 43.90106588602066, 44.069203063845634, 45.89067332446575, 44.33768145740032, 49.52392056584358, 51.81026168167591, 54.57579888403416, 55.07744416594505, 56.279866844415665, 54.42905455827713, 52.96100713312626, 50.580583065748215, 53.389042764902115, 51.25472389161587, 53.408706709742546, 53.408319130539894, 56.204946264624596, 55.557183623313904, 60.0075314193964, 64.41606625914574, 68.86514112353325, 63.1356717646122, 49.98924359679222, 3.23439784348011, 21.97193719446659, 65.55234968662262, 41.564434468746185, 21.458679735660553, 28.407739251852036, 78.54381456971169, 49.64168384671211, 26.580392606556416, 33.309597820043564, 26.828393898904324, 41.56700313091278, 48.44833508133888, 50.05202762782574, 57.05480106174946, 2.856303406879306, 0.13337198237422854, 0.04902653156023007, 0.06591982761165127, 0.04163750520092435, 0.017551974378875457, 0.02332715052034473, 0.034271121767233126, 0.09160161789623089, 0.04148206608078908, 0.07083615520969033, 0.02310941923497012, 0.024672070539963897, 0.038673552917316556, 0.05632128661090974, 0.03537242810125463, 0.03924665419617668, 0.05065365323389415, 0.047345054990728386, 0.05035589616454672, 0.27893949940335006, 10.125749856233597, 64.89377662539482, 62.95681916177273, 27.98994217067957, 38.12897801399231, 50.21556705236435, 28.027011081576347, 27.549699693918228, 23.954363018274307, 24.30831402540207, 35.886589139699936, 70.61034187674522, 47.697749957442284, 6.714829159900546, 46.9372283667326, 77.07228273153305, 67.92532995343208, 65.21674409508705, 59.89019371569157, 67.9656533896923, 65.80822795629501, 64.50945764780045, 62.82804787158966, 65.75827583670616, 62.387108132243156, 57.127027586102486, 51.92270904779434, 52.271241545677185, 52.05577790737152, 52.07338236272335, 48.80952849984169, 50.1723937690258, 48.89026656746864, 49.63128760457039, 47.653828114271164, 50.66824436187744, 46.96254260838032, 47.80248373746872, 47.167735397815704, 46.06132596731186, 47.39278592169285, 49.27741639316082, 48.046392649412155, 47.66448274254799, 46.78722381591797, 48.91831286251545, 49.59212310612202, 50.868991389870644, 54.14277411997318, 53.47717523574829, 55.52370361983776, 54.28799472749233, 54.84324753284454, 53.45069445669651, 53.088011518120766, 53.84361997246742, 51.27847261726856, 48.87050002813339, 51.499586552381516, 52.254940420389175, 47.607994973659515, 52.89095029234886, 35.9100528806448, 30.880961939692497, 36.42450347542763, 32.57872983813286, 37.01581634581089, 33.733898252248764, 24.731504917144775, 18.479062020778656, 14.535421784967184, 34.659008011221886, 55.10767534375191, 42.30486273765564, 18.429856561124325, 10.318564809858799, 7.818254800513387, 5.256364345550537, 6.3596550934016705, 4.089980833232403, 7.384561272338033, 10.306665748357773, 7.605392597615719, 13.246810231357813, 25.792854465544224, 32.69121900200844, 45.08717603981495, 42.09529638290405, 33.67224656045437, 34.8836899548769, 35.7245734333992, 52.427850142121315, 53.22287768125534, 53.957518860697746, 49.269376024603844, 49.840724766254425, 49.165687188506126, 49.76484663784504, 49.658535942435265, 50.80573618412018, 50.810493528842926, 53.12694042921066, 52.98055708408356, 54.405647814273834, 49.82563577592373, 51.15125544369221, 47.034142166376114, 48.2852478325367, 45.83541288971901, 46.356197744607925, 46.42245098948479, 45.84567233920097, 46.21781297028065, 45.327767729759216, 44.56562742590904, 44.64247830212116, 46.48520842194557, 46.102671548724174, 45.214590802788734, 48.35799492895603, 47.184621691703796, 52.640361338853836, 55.74679344892502, 58.22001613676548, 58.61731141805649, 57.628315687179565, 56.62152551114559, 55.10035313665867, 54.91081930696964, 55.70421293377876, 55.17845034599304, 55.22576920688152, 56.18460975587368, 59.75793421268463, 58.98898847401142, 61.216406151652336, 65.60503005981445, 71.3073992729187, 68.0129836499691, 50.190685987472534, 4.192155925557017, 26.977575793862343, 73.33313137292862, 42.84945331513882, 28.143227845430374, 31.47010512650013, 87.94848471879959, 61.04005381464958, 37.05222599208355, 33.38015243411064, 33.59444573521614, 49.64632339775562, 52.284875214099884, 60.2681328356266, 68.48174929618835, 8.176341410726309, 0.6001650891266763, 0.08030604862142354, 0.13432441017357633, 0.03649425481853541, 0.04404359991895035, 0.055637397526879795, 0.07877903524786234, 0.03607553881010972, 0.13548501039622352, 0.18620532704517245, 0.1881884495378472, 0.16009004088118672, 0.1449517867877148, 0.14101448556175455, 0.21771881729364395, 0.11198519365279935, 0.16953511687461287, 0.35134244710206985, 0.3561797953443602, 0.5820925463922322, 14.736545942723751, 77.81637400388718, 70.25664925575256, 44.94723714888096, 47.9896654933691, 65.21916076540947, 47.696473225951195, 42.65243008732796, 30.947538167238235, 30.56454721838236, 41.7370630055666, 79.42991942167282, 46.03817380964756, 8.007389176636934, 56.33507028222084, 79.40810099244118, 70.40873989462852, 66.01386532187462, 62.93126553297043, 69.06040504574776, 67.44274064898491, 65.5873154103756, 63.67897421121597, 67.93680533766747, 64.5878018438816, 59.83889266848564, 56.69955052435398, 55.76017253100872, 55.33494494855404, 55.98797030746937, 50.70408783853054, 55.234877318143845, 53.21883089840412, 51.83590270578861, 49.68346260488033, 54.086609333753586, 51.31145864725113, 50.71118205785751, 49.701420441269875, 49.16588477790356, 48.1110043823719, 52.314487025141716, 51.48113094270229, 48.932862281799316, 51.741508170962334, 50.77384449541569, 54.12079609930515, 55.532401353120804, 58.24676290154457, 58.08931455016136, 58.24604474008083, 56.77934244275093, 57.78626561164856, 55.089922696352005, 56.08254723250866, 60.09130172431469, 55.31795606017113, 51.03362135589123, 54.531291872262955, 54.1640567779541, 51.42636068165302, 54.63529609143734, 42.58649982511997, 37.94823311269283, 38.738833889365196, 41.20920293033123, 38.82569722831249, 37.99963675439358, 37.42118239402771, 22.27085765451193, 26.191831156611443, 53.27119968831539, 60.206864923238754, 54.80287089943886, 43.5282526910305, 34.89994168281555, 19.046466574072838, 15.971257388591766, 14.814370516687632, 12.934694979339838, 17.282523326575756, 25.276511572301388, 18.217955231666565, 18.09407237917185, 31.318747848272324, 38.96785520017147, 51.42012521624565, 48.22934903204441, 38.16549025475979, 40.03002740442753, 40.41729502379894, 56.02072075009346, 54.67633008956909, 55.97211375832558, 51.12188681960106, 53.89766447246075, 50.390737652778625, 53.588665053248405, 53.30782972276211, 54.25462871789932, 51.094923466444016, 57.12771914899349, 55.31015507876873, 57.7830395847559, 52.9354041069746, 56.54236435890198, 50.56838572025299, 51.31433129310608, 46.31489396095276, 50.02350255846977, 48.345554396510124, 48.91498804092407, 49.90681082010269, 48.535358011722565, 46.357596069574356, 49.224074855446815, 49.47524517774582, 48.870287239551544, 47.5256571918726, 52.09572896361351, 49.58740375936031, 56.26460686326027, 57.2505247592926, 61.07075996696949, 59.95836205780506, 61.057643070816994, 59.12461459636688, 59.61038812994957, 55.97910538315773, 59.22833003103733, 56.870586946606636, 61.22765734791756, 57.79405519366264, 64.45894315838814, 62.50870160758495, 65.95731675624847, 67.70823240280151, 78.43761786818504, 69.73645716905594, 58.972603753209114, 6.010099500417709, 26.817513182759285, 76.25259071588516, 52.080032005906105, 35.81628531217575, 35.96835695207119, 86.2441697716713, 50.967512503266335, 34.13658544421196, 47.58211836218834, 36.82939074933529, 59.09379445016384, 62.58863791823387, 67.23426103591919, 75.61896711587906, 8.603435643017292, 0.7557039242237806, 0.1580678517348133, 0.23215385677758604, 0.09942528675310314, 0.10658036218956113, 0.16873819869942963, 0.1964924586354755, 0.19196238921722397], [0.014109937055764021, 0.03455670390394516, 0.011143422507302603, 0.12770344357704744, 0.09251082301489078, 0.04852917758398689, 0.08076764963334426, 0.012845654164266307, 0.06867137723020278, 0.10194510818109848, 0.06672056784736924, 0.21763673576060683, 10.711271837353706, 56.6572891920805, 52.69058704376221, 47.867232263088226, 27.9488492757082, 47.94857829809189, 38.934500589966774, 33.78702700138092, 29.753228053450584, 17.47925017029047, 37.31867529451847, 53.923430889844894, 69.34928074479103, 13.082925025373697, 19.174920581281185, 77.27990359067917, 63.38801622390747, 70.02690598368645, 58.97742189466953, 65.64518630504608, 62.723143100738525, 64.8625499010086, 58.99943791329861, 61.35325960814953, 57.212291210889816, 52.386303171515465, 49.32519882917404, 49.11191627383232, 48.060755878686905, 47.70526595413685, 44.05443325638771, 49.482248201966286, 45.54428771138191, 45.600072517991066, 43.80611278116703, 47.27502644062042, 44.276398345828056, 44.936711713671684, 44.175012186169624, 45.33385880291462, 45.47431066632271, 46.316683664917946, 46.56579069793224, 46.228649988770485, 45.60981139540672, 46.04887783527374, 44.30404946208, 47.086313366889954, 47.84087687730789, 49.477547854185104, 48.465331569314, 50.55043168365955, 51.380880922079086, 47.98301205039024, 50.35030782222748, 46.702214777469635, 48.04312862455845, 45.624493807554245, 48.12485083937645, 49.24298644065857, 46.31086617708206, 46.546172350645065, 29.777069874107838, 30.531614385545254, 33.518275022506714, 27.58194476366043, 24.379947781562805, 48.710608407855034, 29.888476096093655, 19.589411839842796, 48.366821855306625, 56.7715148627758, 55.527256429195404, 40.337548702955246, 31.372932940721512, 19.92078445851803, 7.645397800952196, 4.719738140702248, 3.6624251632019877, 3.4044330194592476, 2.746421378105879, 11.784124318510294, 19.335902743041515, 19.003834761679173, 19.91346415132284, 33.91145892441273, 44.87402647733688, 30.22939570248127, 28.243204280734062, 31.49785503745079, 33.87066811323166, 43.35707947611809, 52.332973033189774, 49.606923311948776, 49.78537313640118, 45.91291733086109, 44.8458281904459, 46.099833101034164, 46.58923923969269, 46.37034818530083, 47.060793936252594, 47.98450157046318, 47.77658432722092, 48.27605992555618, 46.57858461141586, 43.718614876270294, 42.09969274699688, 44.419388473033905, 43.303525149822235, 42.3266925662756, 44.03853490948677, 43.06884594261646, 42.16062627732754, 42.645807042717934, 43.02800193428993, 44.12072829902172, 43.84044013917446, 43.84171687066555, 43.59691500663757, 45.13316497206688, 44.577737376093864, 50.04546917974949, 55.69379769265652, 58.26377458870411, 58.38204324245453, 60.38903474807739, 58.19878287613392, 57.74482883512974, 54.01458419859409, 54.430285692214966, 52.87470996379852, 51.92315362393856, 52.8662022203207, 55.15738807618618, 56.22169576585293, 59.60083544254303, 63.50643686950207, 67.22052857279778, 65.5837208032608, 37.05746591091156, 2.0659581664949656, 41.28589801490307, 63.78374978899956, 34.48949530720711, 18.98155275732279, 39.523343592882156, 55.42653523385525, 21.110929995775223, 20.47446794807911, 45.42295262217522, 31.228994764387608, 28.437324464321136, 35.881159231066704, 51.16609364748001, 65.1853121817112, 25.784675404429436, 0.2080433489754796, 0.0994738528970629, 0.03724193149537314, 0.046002231538295746, 0.08996429169201292, 0.06806613353546709, 0.05154178878001403, 0.11312483562505804, 0.050237690593348816, 0.0624429176968988, 0.053455754241440445, 0.03285416889411863, 0.032105338177643716, 0.06235601962544024, 0.08818231348413974, 0.051761943177552894, 0.048344765018555336, 0.03840991237666458, 0.09856401695287786, 0.3659052250441164, 17.572176083922386, 64.47129249572754, 65.39424777030945, 50.1852522790432, 33.82826238870621, 51.2569809705019, 33.21088671684265, 27.479962036013603, 32.1998255699873, 23.227982595562935, 42.035468593239784, 60.968154072761536, 72.82427787780762, 19.914075918495655, 14.529307913035154, 78.42877954244614, 64.98326942324638, 74.16024059057236, 62.01103091239929, 71.3122022151947, 64.39946874976158, 67.13779181241989, 61.33649870753288, 66.29092365503311, 59.69700068235397, 56.78698383271694, 51.426774859428406, 52.88037545979023, 48.795066475868225, 50.58584578335285, 47.1735604852438, 52.2578776627779, 45.31576797366142, 49.17651280760765, 45.39399817585945, 49.28778223693371, 46.94136634469032, 48.1886950135231, 46.111916452646255, 49.881310388445854, 47.168206572532654, 50.59817612171173, 48.1428162753582, 50.225047543644905, 47.16320224106312, 50.919878259301186, 45.929598435759544, 50.69145731627941, 50.40214844048023, 52.31427043676376, 50.67080922424793, 54.54550690948963, 53.302365615963936, 51.66629880666733, 51.62592597305775, 49.7744183242321, 48.18952336907387, 50.67117020487785, 50.381089970469475, 51.98005937039852, 47.780501917004585, 51.75339013338089, 34.46762368083, 36.50050699710846, 37.05368511378765, 35.53522199392319, 29.599524401128292, 53.345128521323204, 33.75134311616421, 14.842551704496145, 39.52864810824394, 56.23789809644222, 56.59810736775398, 48.592499345541, 34.17391464114189, 18.478896729648113, 10.273021403700113, 8.721417412161827, 7.595664169639349, 6.972409738227725, 9.720020927488804, 24.461897984147072, 32.37711265683174, 24.388558119535446, 26.765712462365627, 36.7986124008894, 45.54843708872795, 35.82579240202904, 33.619300201535225, 36.82906396687031, 37.11750268936157, 45.47136202454567, 53.79168815910816, 51.01364962756634, 51.16458512842655, 48.61116774380207, 49.839550629258156, 48.60333636403084, 49.60617855191231, 51.9165001809597, 50.75769916176796, 50.58839924633503, 49.99146267771721, 51.38084292411804, 49.923252537846565, 46.06852278113365, 47.22044236958027, 44.642892479896545, 46.76702789962292, 45.854696854949, 47.99933597445488, 44.83570173382759, 47.190682366490364, 44.185560420155525, 45.45341178774834, 46.658729910850525, 44.67794939875603, 45.97536318004131, 47.3775639384985, 47.08323933184147, 45.53035765886307, 52.52870433032513, 59.96972344815731, 59.32847745716572, 61.95837713778019, 62.13253699243069, 61.65864162147045, 60.89518278837204, 57.45448641479015, 55.81013225018978, 56.34751461446285, 54.64768722653389, 58.13553526997566, 56.81773938238621, 61.11333668231964, 61.79490230977535, 68.04577589035034, 68.41314017772675, 71.11907377839088, 34.45732623338699, 3.595310552045703, 50.01501761376858, 67.17420905828476, 32.74505831301212, 23.989243246614933, 33.80909621715546, 67.8837601840496, 33.12384858727455, 29.333122596144676, 48.4665285050869, 28.44570681452751, 38.00268419086933, 44.732529670000076, 66.41111880540848, 71.66306018829346, 41.40831224620342, 0.5301917251199484, 0.17187708261189982, 0.07181756387581117, 0.10232634202111512, 0.05947874276898801, 0.0425840329262428, 0.030175164210959338, 0.04941565071931109, 0.10565684104221873, 0.12482247082516551, 0.24580996774602681, 0.22435658611357212, 0.18067374418023974, 0.22369266080204397, 0.3970147791551426, 0.12995569850318134, 0.1778678470873274, 0.25642389664426446, 0.14432685391511768, 0.41816343495156616, 21.460389643907547, 79.08277004957199, 67.22653985023499, 59.125990122556686, 38.610385581851006, 65.1514407992363, 52.68978908658028, 44.59936581552029, 37.508395314216614, 26.305737644433975, 50.46216242015362, 65.16369894146919, 79.55665782094002, 16.99781410396099, 22.669285275042057, 85.07044315338135, 69.05804917216301, 78.59975516796112, 65.03458186984062, 72.97857239842415, 65.93309685587883, 67.80965656042099, 62.681964710354805, 69.81623768806458, 62.518470883369446, 59.14530448615551, 54.61366005241871, 55.644677728414536, 51.922085881233215, 52.986651957035065, 49.69165496528149, 55.245965123176575, 50.640171468257904, 51.811139434576035, 50.577471032738686, 53.94184850156307, 50.40056772530079, 50.585256814956665, 47.98697903752327, 50.83603575825691, 51.20390921831131, 52.720024064183235, 51.346287578344345, 53.02208125591278, 48.837650790810585, 54.91763234138489, 49.6690309792757, 52.891193479299545, 53.776333183050156, 55.91179199516773, 54.09608602523804, 58.53852264583111, 57.43875905871391, 53.75880092382431, 56.30655661225319, 52.751581370830536, 53.36938261985779, 53.53805556893349, 54.65989597141743, 58.445667028427124, 51.507330536842346, 54.52279932796955, 38.890939727425575, 38.920293152332306, 41.589946299791336, 39.72369164228439, 34.76894751191139, 53.762885704636574, 34.287152364850044, 26.082862503826618, 54.99193735420704, 59.03063803911209, 57.69049175083637, 48.81916098296642, 44.553384482860565, 35.43415881693363, 32.199301198124886, 25.42503420263529, 23.232910931110382, 23.224089704453945, 27.416171059012413, 38.04589547216892, 42.00652174651623, 29.92304854094982, 29.23198152333498, 42.20900148153305, 50.398523434996605, 40.808978006243706, 36.34542591869831, 41.424734964966774, 41.36381283402443, 51.33248671889305, 56.01669676601887, 54.5296161621809, 52.56938494741917, 51.055675372481346, 51.85737535357475, 51.59639775753021, 52.248165383934975, 54.105714708566666, 52.13315695524216, 53.8360545784235, 51.65242575109005, 53.60061541199684, 52.506277933716774, 49.67405430972576, 50.02306938171387, 49.59781140089035, 50.17102584242821, 47.389628291130066, 50.83566337823868, 48.92534248530865, 50.96428267657757, 48.096333369612694, 47.66631804406643, 50.18106110394001, 47.72895388305187, 49.827056899666786, 49.72429521381855, 49.29345913231373, 46.688752099871635, 54.30741548538208, 59.925463423132896, 64.03059214353561, 63.314083591103554, 68.06418970227242, 63.69924232363701, 64.41057935357094, 59.27517391741276, 59.915059581398964, 58.66241879761219, 60.251018553972244, 62.32796810567379, 59.69961114227772, 63.23410548269749, 64.5259639620781, 68.50384131073952, 74.3406169116497, 73.27738836407661, 47.55814164876938, 3.757001138292253, 51.033480763435364, 73.41293469071388, 46.31626948714256, 32.06733427941799, 47.94595643877983, 63.31261307001114, 24.009233973920345, 28.65679118782282, 66.43913850188255, 40.51820620894432, 39.5093185454607, 49.088817313313484, 68.07587027549744, 84.24553021788597, 46.43480412662029, 0.485790038947016, 0.31274070439394563, 0.1195260374515783, 0.19993149675428867, 0.18920318805612624, 0.132449863885995, 0.1537527231266722, 0.2346701084752567], [0.025846231656032614, 0.08487303246511146, 0.033510932480567135, 0.06392880866769701, 0.03742209155461751, 0.09103524047532119, 0.09191690449370071, 0.028221002175996546, 0.04930603921820875, 0.08050578282563947, 0.051813310928991996, 0.22640464652795345, 19.838169291615486, 62.34986253082752, 48.0404307693243, 29.954417757689953, 27.507311068475246, 52.1367971599102, 29.007922746241093, 33.67284692823887, 23.60097248107195, 20.07869828492403, 27.913870252668858, 57.734732776880264, 63.272787407040596, 51.62170059978962, 6.1072830855846405, 46.847237795591354, 71.26722022891045, 60.84706597030163, 67.60678544640541, 64.21504184603691, 66.93001136183739, 65.08372083306313, 61.88597582280636, 60.999882370233536, 57.45615452528, 51.50799170136452, 48.38526226580143, 49.84526552259922, 48.93299147486687, 48.98731715977192, 46.52580924332142, 45.41713893413544, 45.36649905145168, 44.71249334514141, 43.72989647090435, 44.44282941520214, 45.04435993731022, 47.11589477956295, 44.54459175467491, 44.87754128873348, 45.72486162185669, 45.96243627369404, 45.78762665390968, 46.351687386631966, 47.92116656899452, 47.43748292326927, 45.928834676742554, 46.188664734363556, 47.57079876959324, 47.32121676206589, 47.63678602874279, 47.31887228786945, 48.925616070628166, 48.79986181855202, 45.84377624094486, 46.19713068008423, 47.71876662969589, 46.77324056625366, 48.456808626651764, 44.292433485388756, 47.23558455705643, 45.289435386657715, 32.38456405699253, 32.394394129514694, 35.79830087721348, 27.228563725948334, 29.475022181868553, 38.00026372075081, 19.96833510696888, 40.96230357885361, 53.16016584634781, 51.0903637111187, 41.72193221747875, 42.819077745079994, 38.67087073624134, 30.258236154913902, 23.221300654113293, 11.975298710167408, 8.707667849957943, 6.162850353866816, 8.603530637919903, 10.880621150135994, 20.725552774965763, 28.196563683450222, 21.048717834055424, 29.251457378268242, 39.721814543008804, 33.45809765160084, 34.9434607475996, 34.03969444334507, 32.40767441689968, 41.54644623398781, 52.06003747880459, 48.06508384644985, 49.90206867456436, 45.13716235756874, 44.666815996170044, 45.81995911896229, 45.534514635801315, 46.01092167198658, 46.09353683888912, 44.29479315876961, 47.24290296435356, 44.07491035759449, 44.696306213736534, 40.51145777106285, 44.795537889003754, 42.888633012771606, 46.09944932162762, 44.33386646211147, 44.55732487142086, 41.64704963564873, 42.386581152677536, 40.21110288798809, 43.4315212816, 42.229945957660675, 41.30224473774433, 42.484619691967964, 44.17814701795578, 44.409543201327324, 45.24952992796898, 52.41976037621498, 60.53906209766865, 56.7902060598135, 59.4084669649601, 60.715391635894775, 62.38545902073383, 56.44713766872883, 58.933150470256805, 54.85734477639198, 55.08074998855591, 49.92479905486107, 54.01738464832306, 52.11058236658573, 57.77650013566017, 58.09401109814644, 69.26168024539948, 63.1580525636673, 70.97962886095047, 18.39319232851267, 9.553026538342237, 62.10447169840336, 52.49117374420166, 26.224393509328365, 18.637504018843174, 38.798027113080025, 17.07863386720419, 17.258888594806194, 38.25625218451023, 41.598879620432854, 34.14451941847801, 32.534659802913666, 28.946723230183125, 47.07874797284603, 58.79747115075588, 50.76998010277748, 4.2869337648153305, 0.48120988940354437, 0.06719552009599283, 0.15930391353322193, 0.025210580315615516, 0.10498919757083058, 0.04715440096333623, 0.033582620235392824, 0.05907442813622765, 0.04321329623053316, 0.09048121981322765, 0.09638853720389307, 0.03215680982975755, 0.10337793559301645, 0.07172645040554926, 0.004573458618324366, 0.023689264780841768, 0.045371168525889516, 0.08570723613956943, 0.1828689279500395, 27.78046891093254, 72.04671800136566, 54.97479647397995, 35.75257033109665, 32.33256384730339, 57.353712022304535, 33.28505113720894, 25.917107798159122, 21.40176258981228, 27.26410511881113, 31.542593836784363, 61.38867750763893, 63.411840945482254, 61.32414937019348, 8.337710201740265, 36.94371901452541, 77.44495153427124, 63.08163106441498, 70.05640000104904, 65.32725736498833, 67.52236157655716, 66.27143830060959, 65.80099314451218, 64.47497069835663, 59.5552758872509, 53.43202605843544, 51.52909576892853, 50.97260423004627, 52.28569597005844, 51.25458709895611, 50.39169140160084, 47.846074998378754, 49.10557821393013, 48.85338954627514, 47.47844472527504, 47.05589979887009, 47.12834671139717, 48.15047666430473, 47.892717495560646, 47.6395370811224, 48.183698281645775, 47.32121676206589, 48.44707354903221, 50.32677188515663, 50.01204997301102, 50.43371334671974, 50.23119181394577, 49.32405889034271, 49.99569185078144, 50.38465037941933, 51.690932884812355, 51.94245658814907, 51.8685657531023, 51.95319101214409, 50.871548652648926, 47.63343080878258, 52.02941492199898, 51.90553016960621, 50.68455308675766, 49.917978420853615, 51.98846451938152, 49.504268020391464, 36.72635167837143, 37.448301538825035, 37.90446326136589, 34.449069276452065, 32.217867001891136, 42.900575771927834, 18.08708645403385, 31.249640956521034, 55.79031251370907, 53.50867174565792, 44.936198741197586, 46.74718536436558, 41.72132425010204, 37.5594075769186, 26.30325447767973, 16.04328252375126, 12.695853095501661, 12.70637758076191, 14.374058693647385, 21.70793116092682, 35.397289395332336, 38.620477840304375, 26.79346427321434, 33.82178753614426, 44.84547480940819, 39.931316301226616, 40.85320383310318, 39.32266876101494, 36.697089448571205, 43.69029879570007, 54.46302093565464, 50.65387733280659, 52.69330769777298, 48.58990028500557, 49.741303101181984, 48.221365660429, 48.44688355922699, 48.48681561648846, 48.51156748831272, 48.182394951581955, 52.25847043097019, 46.26079626381397, 47.41377219557762, 44.49105262756348, 47.5843146443367, 46.39909744262695, 48.134639114141464, 46.249598264694214, 47.135425731539726, 44.016097113490105, 45.487856939435005, 42.86793552339077, 45.32199203968048, 45.36250166594982, 44.97579261660576, 44.87132482230663, 45.596040934324265, 45.764345303177834, 49.32097725570202, 55.73844149708748, 63.696487471461296, 60.595888048410416, 62.70910665392876, 61.649434715509415, 66.34599789977074, 59.81802798807621, 64.1404290497303, 56.39219641685486, 59.47978153824806, 53.72128553688526, 58.15276734530926, 55.57560123503208, 61.8426239490509, 58.715159967541695, 72.83274382352829, 63.779949992895126, 73.2544831931591, 16.284579075872898, 13.813381679356098, 67.36319571733475, 54.16710801422596, 25.529880076646805, 19.669281654059887, 38.4129823744297, 19.13154400885105, 24.358304142951965, 40.76119177043438, 48.494540601968765, 28.796503990888596, 41.1801914870739, 32.29570962488651, 58.64099554717541, 62.871570736169815, 66.20646178722382, 9.18480634689331, 0.6428811501245946, 0.08713707269635051, 0.23964171123225242, 0.0709934534097556, 0.13550089235650375, 0.015296552337531466, 0.08578962937463075, 0.16786990076070651, 0.21272359939757735, 0.1777411624789238, 0.21573395817540586, 0.09950261111953296, 0.17182020441396162, 0.19854865298839286, 0.10946442969725467, 0.17085241415770724, 0.22098052664659917, 0.18380041234195232, 0.3760733309900388, 31.585161052644253, 84.12863329052925, 62.57504224777222, 39.63152378797531, 35.59206314384937, 72.89324417710304, 37.99249313771725, 43.19906495511532, 28.38532615453005, 28.450895436108112, 41.38583265244961, 67.20333069562912, 71.4468365907669, 60.18869809806347, 8.417836502194405, 53.361695632338524, 77.24689856171608, 66.64539143443108, 72.46249929070473, 69.0010218322277, 68.56043547391891, 70.35903096199036, 69.14460852742195, 65.48209145665169, 63.87257382273674, 56.93360656499863, 52.89239801466465, 55.32536566257477, 56.91179193556309, 54.741735979914665, 53.49834010004997, 51.310014724731445, 53.061488941311836, 53.145464435219765, 48.883339539170265, 52.21558593213558, 50.20202837884426, 51.00560925900936, 49.75614130496979, 47.941457480192184, 49.7498070448637, 49.74863290786743, 49.21400539577007, 51.90673470497131, 52.369599267840385, 53.19330766797066, 51.968340799212456, 52.91711948812008, 54.11892279982567, 52.55211487412453, 53.75285804271698, 53.79873298108578, 55.267677158117294, 56.5513850748539, 52.07337476313114, 52.89391793310642, 54.910864904522896, 56.133684888482094, 54.086677730083466, 51.83692865073681, 53.55825528502464, 53.58500584959984, 40.09213887155056, 40.44464595615864, 39.58946384489536, 37.455479353666306, 36.94530352950096, 47.26980932056904, 25.54187223315239, 45.99885731935501, 61.563186943531036, 53.71449910104275, 47.753147184848785, 47.1166205406189, 41.713667660951614, 40.42854242026806, 41.15574739873409, 37.8612519800663, 30.96646685153246, 28.866424039006233, 31.176890060305595, 36.41462780535221, 46.28443859517574, 46.25084079802036, 32.21503995358944, 38.145609721541405, 53.04608456790447, 44.00270663201809, 43.13538797199726, 41.054760217666626, 42.07378573715687, 47.530973106622696, 54.874367862939835, 53.967918902635574, 51.36480398476124, 50.0026872754097, 51.56398169696331, 50.36880902945995, 50.76515436172485, 50.819951221346855, 51.09501466155052, 48.85411910712719, 56.423244550824165, 49.05048497021198, 50.70844240486622, 46.80493846535683, 50.14315813779831, 47.95765981078148, 51.94336473941803, 49.386839121580124, 50.99283054471016, 45.48367336392403, 48.0108417570591, 45.26493050158024, 48.38622361421585, 48.493871837854385, 46.35815843939781, 47.61035464704037, 49.064757004380226, 49.54692453145981, 50.65402552485466, 58.19283239543438, 65.58124333620071, 62.92055770754814, 67.2453260421753, 64.64409962296486, 69.2478109896183, 62.892169430851936, 65.88358551263809, 60.213598161935806, 62.654070407152176, 56.03401243686676, 61.824035346508026, 58.25106807053089, 63.85681226849556, 62.04377755522728, 75.72523981332779, 67.17186838388443, 78.99781420826912, 22.738948836922646, 11.600187588483095, 74.66417714953423, 58.61287705600262, 37.96382747590542, 27.640089243650436, 50.03780499100685, 21.51672162115574, 23.624616712331772, 51.16040155291557, 60.023030787706375, 41.45412638783455, 44.54877533018589, 40.24499326944351, 62.625378146767616, 73.41409742832184, 76.77529826760292, 14.208361934870481, 1.1644027498550713, 0.22746293427189812, 0.40404247236438096, 0.1687891100300476, 0.38072549854405224, 0.16969280841294676, 0.24226834997534752], [0.015282301246770658, 0.016964777860266622, 0.018422354041831568, 0.023055865858623292, 0.08654745121020824, 0.017529136639495846, 0.012213833233545301, 0.020164024354016874, 0.03640292241470888, 0.0511829269817099, 0.05869383996468969, 0.10395065095508471, 28.462156131863594, 68.24132099747658, 46.5725277364254, 39.20203663408756, 30.82377500832081, 47.98715382814407, 36.26496523618698, 26.213470995426178, 19.57408346235752, 20.312948115170002, 20.574681870639324, 42.49352641403675, 62.177632972598076, 66.35216116905212, 32.250906229019165, 6.5219871327281, 59.553934559226036, 70.77262356877327, 68.17767441272736, 66.74046233296394, 66.34770780801773, 60.95879137516022, 64.38179969787598, 57.38519713282585, 52.879607900977135, 49.69516217708588, 50.74790708720684, 48.37287873029709, 48.37856322526932, 46.7162474244833, 47.56989821791649, 44.056203961372375, 44.710224866867065, 44.041719138622284, 46.28951892256737, 44.425460547208786, 45.29157467186451, 45.82557141780853, 45.53948476910591, 45.20090013742447, 48.54554906487465, 47.51606650650501, 46.42655476927757, 46.193714663386345, 47.23263971507549, 46.687045991420746, 47.062329053878784, 48.029327765107155, 48.99237468838692, 48.219260573387146, 47.03402437269688, 47.56633400917053, 47.80065983533859, 46.67188860476017, 48.121632412075996, 44.810786470770836, 47.083269730210304, 47.920140624046326, 49.232297614216805, 49.37528394162655, 51.7608605325222, 43.54418143630028, 31.489257998764515, 36.11837290227413, 35.45049034059048, 20.356220193207264, 28.312185779213905, 29.770154245197773, 53.5791427642107, 53.72068136930466, 51.64953790605068, 40.17608016729355, 40.60858815908432, 40.3472837805748, 37.879445403814316, 39.398512691259384, 40.98477177321911, 27.572697959840298, 14.667499847710133, 13.044972661882639, 12.64548109844327, 18.291023410856724, 26.738452725112438, 33.769931718707085, 25.201571993529797, 30.991959683597088, 37.43646137416363, 28.518490009009838, 24.285558946430683, 39.90178428590298, 37.01977953314781, 35.00221699476242, 50.26171937584877, 49.41480562090874, 50.28055876493454, 47.32503555715084, 45.716771855950356, 45.501878187060356, 46.945090144872665, 46.18350841104984, 46.866654753685, 47.12762475013733, 46.36760853230953, 45.75185537338257, 44.18384671211243, 43.45284953713417, 45.348381623625755, 44.23905394971371, 42.14098893105984, 43.35666909813881, 42.96943187713623, 42.54825107753277, 42.7042631059885, 40.81031173467636, 42.88816183805466, 40.34086972475052, 42.62110456824303, 41.79182566702366, 44.53850448131561, 43.85260708630085, 45.12549698352814, 53.35486359894276, 59.3575306981802, 59.39094230532646, 59.59871135652065, 56.60329028964043, 62.84387782216072, 58.10983344912529, 62.50868260860443, 58.42743560671806, 56.647261530160904, 51.77604451775551, 55.26181407272816, 51.04668125510216, 60.186216831207275, 59.689644277095795, 68.73711079359055, 56.91551573574543, 52.09192156791687, 6.482843533158302, 25.247456431388855, 63.89262914657593, 53.99286836385727, 20.26157107204199, 14.234695471823215, 46.368683874607086, 71.98934108018875, 41.48172050714493, 38.23428936302662, 45.242450907826424, 33.049410581588745, 32.23512947559357, 29.933395385742188, 32.49607667326927, 55.33966049551964, 57.797725796699524, 12.236049268394709, 0.4788016201928258, 0.07960275237564929, 0.07259848876856267, 0.09520582840195857, 0.051176611304981634, 0.025305758899776265, 0.02700265915336786, 0.06712236659950577, 0.0542025180766359, 0.035324088312336244, 0.044486673214123584, 0.04494153552514035, 0.05985459232761059, 0.04631251977116335, 0.023680505582888145, 0.01789496349374531, 0.06764853445929475, 0.08848135446896777, 0.09778345571248792, 35.36282144486904, 76.49946346879005, 50.125515684485435, 53.46338577568531, 38.75285513699055, 54.58986192941666, 40.67293390631676, 22.93342810124159, 17.113143615424633, 22.552299052476883, 25.797022841870785, 43.04372929036617, 65.67514389753342, 70.49597561359406, 43.568686321377754, 6.37176931835711, 45.924274921417236, 74.1577859222889, 71.92825555801392, 67.82066076993942, 67.44701161980629, 65.58304443955421, 65.44168442487717, 58.08122478425503, 54.56724934279919, 52.70210802555084, 53.40476632118225, 51.03240542113781, 51.94861225783825, 49.7014432400465, 51.83470577001572, 45.77484034001827, 46.63103699684143, 46.160390451550484, 49.42913845181465, 46.78071476519108, 48.303528651595116, 47.716042175889015, 48.701143115758896, 47.91571006178856, 50.21033093333244, 49.96425233781338, 48.07210586965084, 49.240873754024506, 50.57421460747719, 49.24063436686993, 52.734592482447624, 52.09260553121567, 51.340215504169464, 51.45063757896423, 52.50145599246025, 50.87321676313877, 50.541661754250526, 49.75149415433407, 51.94495305418968, 49.33478191494942, 51.8141982704401, 51.396023109555244, 53.292459547519684, 54.3210643529892, 56.51714511215687, 47.6325948536396, 37.611882761120796, 41.3992041349411, 42.12210774421692, 25.826488360762596, 30.60467306524515, 34.435538202524185, 43.950189650058746, 49.16370749473572, 55.057088658213615, 42.96631224453449, 44.08210717141628, 44.7136826813221, 40.43284758925438, 39.39491808414459, 41.08140058815479, 30.25407537817955, 20.26180475950241, 19.354842826724052, 21.043679304420948, 27.727925330400467, 36.344152987003326, 41.133283004164696, 27.826497741043568, 34.59026589989662, 43.34120012819767, 32.73367412388325, 31.994986161589622, 44.986998215317726, 42.65860855579376, 39.45584021508694, 53.353199288249016, 52.75085560977459, 53.097769394516945, 51.69057570397854, 49.02931250631809, 49.34252589941025, 48.23741599917412, 48.30262050032616, 49.35132622718811, 48.754693642258644, 48.6742177605629, 49.997074976563454, 47.80575916171074, 46.38737127184868, 49.46937069296837, 48.019414097070694, 45.93494474887848, 47.53812052309513, 45.96333682537079, 46.34268946945667, 43.96213620901108, 46.361240074038506, 44.53911244869232, 44.12235841155052, 45.837989151477814, 44.88027714192867, 47.34268181025982, 47.71424487233162, 48.95946845412254, 57.05043129622936, 61.81753769516945, 60.16938753426075, 62.00311593711376, 56.659310683608055, 64.03127610683441, 63.95318269729614, 63.62440153956413, 61.68000787496567, 59.323894903063774, 55.999491289258, 56.80620700120926, 55.0446405261755, 63.39245818555355, 64.46343451738358, 70.25135233998299, 63.63105498254299, 52.32459828257561, 6.56969927251339, 31.503799818456173, 76.4726673066616, 55.299527049064636, 24.036930687725544, 14.195449277758598, 47.674153223633766, 55.29527507722378, 34.2040204256773, 35.81295669078827, 55.2396384626627, 22.761373333632946, 35.1590383797884, 30.093184411525726, 35.73470748960972, 66.16483122110367, 68.47595080733299, 28.988663479685783, 0.6945489963982254, 0.13663167308550328, 0.11392795815481804, 0.05577165946306195, 0.10133135205251165, 0.03154576996166725, 0.08109832095215097, 0.1778752834070474, 0.2045910560991615, 0.13296114426339045, 0.13396022346569225, 0.17335754848318174, 0.1705897829378955, 0.13574456912465394, 0.07958465139381588, 0.2127961814403534, 0.1174265387817286, 0.1280032267095521, 0.28165849100332707, 43.43601644039154, 88.1127879023552, 59.26693595945835, 53.447464630007744, 43.02172467112541, 66.21444895863533, 50.821991711854935, 32.537042275071144, 28.12574688345194, 26.626417636871338, 34.59352232515812, 54.455075562000275, 72.52326563000679, 76.38740748167038, 39.227077290415764, 9.257690235972404, 65.74128314852715, 78.08514878153801, 76.25626891851425, 68.78730610013008, 70.79286128282547, 64.34130907058716, 69.59872975945473, 61.74073241651058, 59.714289754629135, 54.90104243159294, 58.27132098376751, 53.93076829612255, 55.43093919754028, 52.6943526417017, 54.09941844642162, 47.45953693985939, 48.34192559123039, 47.168138176202774, 54.82563927769661, 50.17735630273819, 51.25461749732494, 49.950067698955536, 51.71471580862999, 50.59355556964874, 54.8511017113924, 54.21449527144432, 51.02800905704498, 50.42994774878025, 55.800248980522156, 51.68804503977299, 54.19347859919071, 54.44168508052826, 53.73961955308914, 54.58440542221069, 54.80789802968502, 53.84966544806957, 52.90310204029083, 54.434632658958435, 55.540711507201195, 52.52708561718464, 54.32162672281265, 55.22801108658314, 56.441544368863106, 56.03282310068607, 55.874930173158646, 50.585857182741165, 42.48813070356846, 42.59569153189659, 43.64367909729481, 28.64727459847927, 35.29662139713764, 40.71022890508175, 56.378722339868546, 55.96652425825596, 59.657102823257446, 44.854286536574364, 47.462945356965065, 44.21286195516586, 40.50962246954441, 43.72202329337597, 51.871818378567696, 41.25952363014221, 35.55229067802429, 37.26719945669174, 33.90164405107498, 41.043816804885864, 47.796236872673035, 51.85082830488682, 35.532372146844864, 38.10132309794426, 47.589824348688126, 37.766827046871185, 35.044409930706024, 45.477935671806335, 44.70915712416172, 43.337730914354324, 53.694842755794525, 52.5063007324934, 54.976274594664574, 53.21043714880943, 50.317891761660576, 52.791866809129715, 52.54012651741505, 52.030440866947174, 52.217698618769646, 51.912027820944786, 52.24344223737717, 52.99874670803547, 47.95001082122326, 47.564475908875465, 51.64725422859192, 49.97646488249302, 47.87237338721752, 49.906556233763695, 48.568845614790916, 49.15191292762756, 46.49755395948887, 48.48389357328415, 48.91420528292656, 46.3885074108839, 49.57029327750206, 46.51822105050087, 50.706132128834724, 49.97002802789211, 52.28807844221592, 57.956401482224464, 65.9045983850956, 62.53255292773247, 64.51577290892601, 61.407847478985786, 66.68868631124496, 64.7698424756527, 67.32845798134804, 63.879763036966324, 62.306818440556526, 58.28933581709862, 61.93374685943127, 56.226133927702904, 67.19142973423004, 64.39813882112503, 74.81665536761284, 64.5263059437275, 63.93857628107071, 9.842586200684309, 29.511315934360027, 77.36178159713745, 62.73034751415253, 31.73339679837227, 22.22599346190691, 58.14398601651192, 78.18025007843971, 52.94018805027008, 47.67204813659191, 67.84488067030907, 38.96252788603306, 44.49138700962067, 42.31142118573189, 45.03519482910633, 73.3959724009037, 76.06300368905067, 40.08454687893391, 0.8660179423168302, 0.2219158850493841, 0.30892440292518586, 0.15670446708099917, 0.26098469097632915, 0.10960973479086533, 0.13067219755612314], [0.022697916901961435, 0.027815403627755586, 0.039492575961048715, 0.015331436061387649, 0.06608469571801834, 0.06197514943778515, 0.04285109476768412, 0.026745957693492528, 0.035751847390201874, 0.08394396005314775, 0.16393742349464446, 0.08408823356148787, 36.64089426398277, 57.89286129176617, 56.762307956814766, 20.619120486080647, 26.934512704610825, 50.416891649365425, 40.291894152760506, 24.27950967103243, 39.54305313527584, 24.95824635028839, 15.190808717161417, 26.490886509418488, 56.19143418967724, 61.532537788152695, 67.87939801812172, 17.594347894191742, 2.277594222687185, 37.99540378153324, 51.70596867799759, 69.10629138350487, 62.040239945054054, 66.53759121894836, 56.75584830343723, 55.42638324201107, 51.99458219110966, 54.526747316122055, 51.56789928674698, 55.582300275564194, 49.46660064160824, 49.01246041059494, 45.876519083976746, 47.78448790311813, 44.19692561030388, 45.47213338315487, 44.0043443441391, 45.76785631477833, 44.839820712804794, 47.10539594292641, 47.381549924612045, 46.378114968538284, 47.85664603114128, 48.879893124103546, 46.990683898329735, 48.336636275053024, 47.902509570121765, 48.156050965189934, 46.392763182520866, 48.92905108630657, 46.58990800380707, 49.252071753144264, 46.925426200032234, 49.34331625699997, 45.984608083963394, 47.271796613931656, 45.4051847755909, 46.10482983291149, 46.981260403990746, 50.08931502699852, 48.238476142287254, 50.399184599518776, 52.614617720246315, 43.34094174206257, 32.05316483974457, 47.35936291515827, 26.78800206631422, 24.790380857884884, 23.39014459401369, 36.37286424636841, 53.18325720727444, 49.76883262395859, 46.738822013139725, 42.426171228289604, 39.99094270169735, 40.912248864769936, 40.17728090286255, 41.41870468854904, 43.3354776352644, 31.575342379510403, 24.704792350530624, 23.712994270026684, 21.7226629704237, 22.123634554445744, 31.0182086750865, 33.93065169453621, 37.96390727162361, 42.098522409796715, 26.189277693629265, 10.271975509822369, 16.3882964104414, 34.15126025676727, 37.569435238838196, 32.07301117479801, 47.51603990793228, 51.87612734735012, 51.60570725798607, 52.73566782474518, 50.59455871582031, 47.46938221156597, 44.73335422575474, 46.388302221894264, 43.591857478022575, 44.26490776240826, 46.562146693468094, 44.93004687130451, 45.51560305058956, 45.06694212555885, 46.87084212899208, 44.44850251078606, 44.50064331293106, 42.4057587236166, 44.75384272634983, 43.24514128267765, 43.01874943077564, 43.015929982066154, 42.36535929143429, 42.222631350159645, 45.06975017488003, 43.205760195851326, 44.275923371315, 44.51509773731232, 48.73061053454876, 52.74753078818321, 58.14708665013313, 59.70085367560387, 58.06626878678799, 58.0288901925087, 57.76697404682636, 62.169322818517685, 62.11408518254757, 61.57668001949787, 59.86431710422039, 54.40455727279186, 55.71666106581688, 52.54615679383278, 58.992909863591194, 60.49325555562973, 68.20257067680359, 58.31242337822914, 37.295500338077545, 2.8895475855097175, 44.13367420434952, 45.20452134311199, 51.737058609724045, 19.032086245715618, 7.953391224145889, 26.13171648234129, 79.18366223573685, 54.00113292038441, 37.571441531181335, 35.33466875553131, 32.973904833197594, 34.89524133503437, 39.814924746751785, 25.5802121758461, 35.673101395368576, 64.62391510605812, 41.19718037545681, 1.0821276647038758, 0.09882848127745092, 0.09732069695019163, 0.07765107468003407, 0.11049365493818186, 0.026879462639044505, 0.08732000467716716, 0.04101988619368058, 0.04496276465943083, 0.0658669495896902, 0.01876227994216606, 0.07840131176635623, 0.07534179312642664, 0.01390426103171194, 0.04145445447647944, 0.039487618414568715, 0.04257474123733118, 0.13846265530446544, 0.022567415799130686, 48.027750849723816, 60.77561840415001, 60.91541290283203, 26.263263523578644, 28.11642788350582, 58.06613199412823, 43.5393100976944, 34.218482449650764, 45.1842038333416, 32.960339561104774, 19.529914632439613, 30.904302187263966, 61.383312195539474, 63.57649751007557, 72.16112986207008, 26.09537523239851, 1.4071305189281702, 23.218659795820713, 49.983365312218666, 71.31517365574837, 65.49750342965126, 68.81406426429749, 58.61848175525665, 56.31027661263943, 55.18670730292797, 58.067784905433655, 55.38253739476204, 58.62907558679581, 51.30856700241566, 51.69726714491844, 49.02927830815315, 49.85935516655445, 46.96654759347439, 48.69214899837971, 47.672154530882835, 50.00366382300854, 49.17619362473488, 50.339740589261055, 48.352135643363, 48.422868847846985, 49.83680337667465, 52.283066511154175, 51.325510293245316, 51.08360007405281, 50.556769743561745, 51.3949553668499, 50.36117143929005, 52.24691905081272, 48.30103978514671, 51.658706814050674, 50.508630126714706, 50.64710609614849, 48.59101362526417, 51.56260997056961, 48.6434356123209, 51.65564797818661, 52.27319844067097, 55.62920115888119, 52.51289337873459, 53.799185156822205, 54.404378682374954, 46.96879327297211, 37.21529424190521, 49.05276104807854, 31.5099972859025, 25.386272482573986, 24.636764600872993, 38.59642133116722, 52.66947537660599, 48.69283676147461, 47.460475489497185, 42.090907618403435, 41.22767373919487, 41.90821722149849, 40.78359156847, 47.47227005660534, 51.94693274796009, 40.12406475841999, 30.876003205776215, 27.36924357712269, 26.91883284598589, 29.758870750665665, 36.31876274943352, 41.48933529853821, 38.033120557665825, 43.61368730664253, 36.96340575814247, 9.4832774810493, 14.008682649582624, 35.48261001706123, 42.09976874291897, 37.738503366708755, 48.29583406448364, 57.452198937535286, 53.62996503710747, 54.7814666479826, 52.174848318099976, 49.5150176435709, 49.75909374654293, 50.461113676428795, 46.72290466725826, 47.85653963685036, 48.91952499747276, 49.09756064414978, 48.61295744776726, 48.27769763767719, 48.98371495306492, 49.35182400047779, 47.04345926642418, 45.623635053634644, 48.47180262207985, 49.0125098079443, 47.538226917386055, 45.003006756305695, 45.74174791574478, 45.828231275081635, 47.389499098062515, 48.467862233519554, 46.49696499109268, 47.441411912441254, 50.331715419888496, 56.41629472374916, 59.79927979409695, 61.382567435503006, 59.00927558541298, 60.86374707520008, 58.12799647450447, 64.84953179955482, 63.04532781243324, 63.32780085504055, 63.3224393427372, 59.178727492690086, 57.28458613157272, 57.13920213282108, 62.99767076969147, 64.06913727521896, 69.36908528208733, 64.26207572221756, 33.925879150629044, 4.460063399747014, 51.24990954995155, 43.3333383500576, 52.650419399142265, 22.588797993957996, 8.664919193834066, 32.22470663487911, 66.77046552300453, 42.423564568161964, 36.30146987736225, 46.63690388202667, 30.367879271507263, 35.82902602851391, 44.87595297396183, 28.601031079888344, 48.118999153375626, 67.02043130993843, 64.40383091568947, 3.054427388124168, 0.3006915806327015, 0.060903102275915444, 0.05931839805271011, 0.030140620947349817, 0.09124465228524059, 0.018111084318661597, 0.14943084097467363, 0.15818790154298767, 0.15280973544577137, 0.10567178047494963, 0.2801200485555455, 0.23632244090549648, 0.18204251682618633, 0.12911675992654637, 0.13302387058502063, 0.08645339141367003, 0.29505879851058125, 0.24892053130315617, 56.52756795287132, 71.22297540307045, 70.05326896905899, 28.933148458600044, 34.82285901904106, 70.10257512331009, 58.80415119230747, 30.031494721770287, 50.645608976483345, 32.355206832289696, 27.67639249563217, 37.50178746879101, 69.2088782787323, 70.97957566380501, 79.66924577951431, 20.663325414061546, 3.909176797606051, 42.540617287158966, 55.75107201933861, 74.63557228446007, 67.76589050889015, 71.5070329606533, 63.014021292328835, 59.65141072869301, 57.159158661961555, 61.144346818327904, 56.65358059108257, 61.500680297613144, 55.35425931215286, 55.54269500076771, 50.58670073747635, 53.41083459556103, 47.96008788049221, 52.030406668782234, 49.264231100678444, 54.62429568171501, 51.47773392498493, 53.06564211845398, 52.22599357366562, 50.59885248541832, 52.64335557818413, 53.78740578889847, 53.23971077799797, 52.51898065209389, 52.8268401324749, 54.8885753005743, 52.486059218645096, 54.99308869242668, 51.45512893795967, 56.07972018420696, 52.650624588131905, 52.640961706638336, 50.30037470161915, 54.85559307038784, 51.531732827425, 56.243362203240395, 53.61289635300636, 60.009131133556366, 54.48477856814861, 55.52121855318546, 55.969317108392715, 48.5508231818676, 39.96844790875912, 51.62987396121025, 35.90480916202068, 31.803822219371796, 30.109240449965, 42.507490664720535, 54.373721927404404, 47.73797079920769, 50.420664846897125, 44.7406954318285, 46.07818566262722, 45.18898777663708, 41.57809093594551, 44.013748839497566, 47.08119124174118, 38.88421788811684, 34.35025177896023, 40.83548158407211, 38.27625811100006, 43.09235908091068, 47.40043871104717, 50.342974215745926, 46.16697169840336, 50.992963537573814, 44.68612276017666, 16.3803643360734, 23.67653712630272, 41.54906429350376, 45.834105759859085, 40.107235461473465, 49.10809367895126, 55.962310284376144, 54.319707825779915, 55.23909509181976, 54.33061704039574, 51.536862552165985, 51.83401420712471, 53.51766586303711, 50.91985926032066, 49.87407937645912, 53.26183699071407, 51.08670070767403, 50.30990459024906, 52.01512768864632, 52.20984444022179, 51.73183389008045, 49.81705583631992, 47.73190252482891, 51.19539387524128, 51.148500591516495, 50.92591993510723, 48.1549946218729, 49.79119062423706, 46.98791764676571, 52.196560353040695, 50.696005672216415, 49.70026530325413, 49.84736680984497, 53.324077650904655, 57.409888207912445, 63.14099907875061, 63.97317722439766, 63.46300520002842, 62.906943038105965, 63.11001554131508, 70.70682629942894, 66.39072149991989, 66.79861441254616, 65.79482227563858, 61.47684797644615, 64.20038983225822, 58.20634447038174, 65.35843089222908, 65.01742959022522, 75.22826448082924, 66.65256544947624, 45.88920280337334, 4.616154748946428, 54.12822850048542, 54.527184292674065, 61.436581537127495, 28.135700449347496, 14.884661994874477, 35.50310991704464, 86.18179231882095, 59.32965159416199, 46.35732628405094, 50.554505065083504, 42.88385666906834, 47.463074550032616, 54.936015754938126, 32.76286795735359, 58.833497017621994, 75.5793808400631, 75.14006361365318, 4.086483595892787, 0.6644277751911432, 0.2576512307859957, 0.1301961246645078, 0.19428735977271572, 0.2750684868078679, 0.15240289008943364], [0.04373216877866071, 0.068137639464112, 0.03655885135231074, 0.011174531482538441, 0.0562911071756389, 0.0455831073486479, 0.029110731484252028, 0.06010641787725035, 0.03271191773819737, 0.052141113847028464, 0.15827317431103438, 0.4165532119804993, 49.97848637402058, 58.0497320741415, 43.0663038790226, 41.169358268380165, 44.612843692302704, 43.66320624947548, 42.92045630514622, 20.12361567467451, 43.85474257171154, 42.278070375323296, 13.002260103821754, 22.92960360646248, 54.807765036821365, 64.35642465949059, 59.08195808529854, 61.84920519590378, 2.67007848713547, 0.18743223074125126, 23.528500869870186, 65.95190584659576, 62.6151566952467, 61.90923437476158, 57.445731684565544, 57.527446299791336, 59.26598981022835, 59.95591878890991, 56.59033678472042, 54.84176941215992, 53.76363426446915, 47.241808623075485, 48.06468486785889, 48.546119034290314, 45.4635838419199, 45.36396838724613, 45.704012140631676, 43.67567718029022, 46.30665220320225, 50.93392230570316, 48.698749244213104, 47.702313512563705, 47.498788833618164, 52.32235260307789, 48.98736655712128, 49.777104780077934, 48.30177694559097, 49.36764255166054, 48.67214307188988, 48.800709173083305, 48.53433586657047, 46.11869528889656, 46.50774121284485, 48.653831854462624, 46.728642359375954, 45.361141338944435, 50.44813357293606, 49.08545069396496, 49.53250430524349, 48.075848668813705, 50.6440244615078, 52.81034901738167, 50.61754748225212, 30.91648243367672, 27.909209802746773, 23.04843842983246, 19.966418109834194, 15.728632807731628, 15.822778455913067, 39.432976841926575, 52.53566935658455, 56.35859861969948, 55.099114403128624, 39.644826874136925, 38.01745779812336, 38.19130226969719, 37.28673420846462, 38.08529555797577, 40.1436223089695, 39.53137256205082, 35.62111258506775, 33.253250643610954, 36.4576680958271, 38.503478318452835, 40.41241228580475, 36.93043872714043, 37.23677068948746, 41.88031531870365, 26.39085877686739, 7.396882586181164, 7.273842338472605, 25.102902688086033, 30.370719619095325, 23.885427117347717, 37.54944071173668, 54.028993025422096, 52.397090792655945, 54.017715230584145, 50.180122554302216, 51.31577141582966, 47.132363095879555, 49.289716333150864, 45.58831214904785, 47.83101260662079, 45.72274513542652, 47.00030118227005, 45.67854970693588, 46.15810677409172, 46.75918132066727, 47.53005735576153, 44.77827921509743, 45.678431913256645, 45.63897863030434, 43.83908361196518, 43.740311712026596, 42.58095592260361, 40.17788127064705, 44.16406877338886, 42.73266278207302, 45.49956411123276, 44.92280825972557, 47.17911958694458, 50.32920755445957, 53.480583652853966, 56.09036721289158, 60.43613322079182, 54.79098133742809, 60.209368988871574, 53.010526075959206, 56.97106495499611, 65.1070287823677, 65.35862848162651, 62.6391676068306, 58.70889410376549, 53.750228583812714, 56.25199154019356, 55.467660427093506, 70.86254194378853, 59.74927827715874, 63.11009533703327, 11.671344470232725, 9.618738312274218, 53.30328516662121, 32.23142847418785, 63.06368462741375, 15.742964688688517, 5.350356576964259, 28.511578179895878, 55.70867009460926, 76.67974099516869, 42.53915436565876, 33.05232882499695, 29.619790613651276, 29.4697879627347, 31.649818383157253, 28.107545860111713, 31.578737497329712, 56.664763391017914, 66.09334945678711, 9.838672410696745, 0.515655130147934, 0.07197226455900818, 0.260916116531007, 0.1194530694920104, 0.06460390330175869, 0.024096271554299165, 0.08087546142633073, 0.050568536316859536, 0.055799000183469616, 0.054826716223033145, 0.07797745638526976, 0.05412045880802907, 0.006869205717521254, 0.03078540255955886, 0.08884494745871052, 0.09149888239335269, 0.1544706619461067, 1.370591085869819, 64.25797954201698, 63.30215983092785, 50.51423862576485, 39.879726469516754, 42.60465145111084, 51.55613511800766, 41.72864645719528, 21.492564417421818, 41.49248532950878, 54.352412670850754, 24.460417963564396, 26.20120145380497, 60.932318195700645, 68.84609654545784, 63.39007571339607, 67.54599630832672, 6.2125117890536785, 0.28080294316168875, 21.714632101356983, 69.69575375318527, 70.4052896797657, 65.73729336261749, 61.3115606456995, 60.983330458402634, 60.31342640519142, 59.566162303090096, 57.443949580192566, 56.67883023619652, 52.999301478266716, 49.01283659040928, 50.3544458001852, 48.90957713127136, 48.90547335147858, 46.97085656225681, 49.151776134967804, 46.803521141409874, 49.42997820675373, 51.7526263743639, 49.23986680805683, 49.31265190243721, 50.71474626660347, 52.40636229515076, 52.863401770591736, 51.29969447851181, 52.74153470993042, 52.10158444941044, 53.0784360319376, 52.27512113749981, 52.73400731384754, 50.92607192695141, 50.72268404066563, 50.890908613801, 50.60417219996452, 51.51470974087715, 54.37487706542015, 53.11675317585468, 52.56653890013695, 52.31415644288063, 52.55524590611458, 57.1999304741621, 51.19318999350071, 30.602463483810425, 32.65623427927494, 25.48129018396139, 22.697246074676514, 13.134794142097235, 16.449940502643585, 42.523833587765694, 52.61223524808884, 49.13388669490814, 43.4922344237566, 38.03463287651539, 41.79410174489021, 42.009443789720535, 40.628134310245514, 42.381451427936554, 42.60792687535286, 43.09055417776108, 36.37704402208328, 36.99578382074833, 38.612528666853905, 41.256438195705414, 43.470879569649696, 43.60661968588829, 39.56746302545071, 45.768076702952385, 34.44042854011059, 6.3598227594047785, 4.931474179029465, 31.742009036242962, 31.551789343357086, 27.15445440262556, 38.41488227248192, 57.18967482447624, 52.29109548032284, 56.019345223903656, 51.31942681968212, 53.89747828245163, 48.69538262486458, 53.2490848749876, 50.206105560064316, 51.322706043720245, 47.50038854777813, 49.585690051317215, 46.69613890349865, 47.347085773944855, 47.8803301602602, 51.79788574576378, 46.08303800225258, 51.209726706147194, 48.85280437767506, 49.61799591779709, 46.92570358514786, 47.84558102488518, 46.3139022141695, 48.258311077952385, 45.815042182803154, 48.97673472762108, 46.76843002438545, 48.11992630362511, 50.341575890779495, 57.202772721648216, 58.03639858961105, 60.33052168786526, 58.09710033237934, 61.91814489662647, 54.49758768081665, 59.35724951326847, 64.46531921625137, 64.75000753998756, 64.67427000403404, 62.0485994964838, 56.39867126941681, 63.22297967970371, 58.77179592847824, 72.51213982701302, 61.740941405296326, 67.50403136014938, 8.808143958449364, 14.644744768738747, 58.47558282315731, 33.74185882508755, 66.4604477584362, 15.45760665088892, 7.12060178630054, 34.69543285667896, 66.0713030397892, 62.75535397231579, 33.44954811036587, 41.55206613242626, 34.48911152780056, 26.834009997546673, 39.49415735900402, 33.36527623236179, 40.50543509423733, 64.09458830952644, 76.29576399922371, 15.308491252362728, 1.184139484539628, 0.23394590592943132, 0.17363405786454678, 0.08004549541510642, 0.10777271148981526, 0.025461576515226625, 0.241722559730988, 0.24299834127305076, 0.16328086028806865, 0.12034628132823855, 0.18368499353528023, 0.08338453655596823, 0.11270728849922307, 0.19632664800155908, 0.2027198494761251, 0.20639293128624558, 0.23061915475409478, 1.2900178343988955, 72.11300924420357, 74.81093287467957, 58.70918668806553, 55.85591599345207, 62.857781276106834, 56.822238340973854, 58.771396949887276, 24.944331496953964, 53.03606070578098, 49.755024164915085, 22.591222263872623, 38.69149602949619, 66.84491112828255, 75.46227112412453, 67.82643646001816, 74.5102246105671, 3.8499332265928388, 0.2637984399916604, 29.510231092572212, 72.93188810348511, 72.90758460760117, 67.78240442276001, 63.512470945715904, 63.798591792583466, 62.26952724158764, 64.91849809885025, 60.41906073689461, 62.17686541378498, 56.958730816841125, 51.53917282819748, 53.98084580898285, 51.74785763025284, 50.34871190786362, 50.44334962964058, 53.2437651604414, 48.83137732744217, 52.1084126830101, 56.368303298950195, 52.853548899292946, 51.28582902252674, 51.17470018565655, 56.339018270373344, 56.20116546750069, 54.03720058500767, 53.9960677921772, 55.91198578476906, 56.21600367128849, 54.740466848015785, 55.84608592092991, 53.25763441622257, 53.598251938819885, 52.47296132147312, 52.813339456915855, 53.761601373553276, 56.84333100914955, 56.920383274555206, 56.09438739717007, 52.73417070508003, 55.76791651546955, 58.08227352797985, 52.53287270665169, 38.013688400387764, 46.30151107907295, 41.272287145256996, 34.640100225806236, 24.58520896732807, 23.901796638965607, 44.39689747989178, 53.74072529375553, 52.47363768517971, 46.0165111720562, 40.28421476483345, 44.44686859846115, 41.311242654919624, 41.696697771549225, 41.84800185263157, 42.93521851301193, 40.96726231276989, 38.31364430487156, 39.175840839743614, 45.300257205963135, 48.3707470446825, 50.77126443386078, 47.83966854214668, 45.75483821332455, 48.263824582099915, 41.75485745072365, 15.166829153895378, 15.50654897466302, 34.28483448922634, 41.45696483552456, 35.97793623805046, 44.022511169314384, 57.83632032573223, 52.89212442934513, 55.62740385532379, 53.547091484069824, 55.56604474782944, 49.174673706293106, 55.553573817014694, 53.03338564932346, 53.80182981491089, 51.01124435663223, 53.27533766627312, 47.97759734094143, 48.90843719244003, 52.13135205209255, 53.724161982536316, 49.439834877848625, 54.05891261994839, 51.35201767086983, 52.752713710069656, 49.08160910010338, 50.3390072286129, 46.86197340488434, 50.4397664219141, 48.152741342782974, 51.696909964084625, 49.64559763669968, 51.23208090662956, 54.81737472116947, 59.94059041142464, 61.505217254161835, 65.72450324892998, 60.918262749910355, 64.45885196328163, 56.42794489860535, 60.69590628147125, 68.59725549817085, 68.26190829277039, 67.33880862593651, 63.77146124839783, 60.00618629157543, 65.7230593264103, 61.922700852155685, 74.43457826972008, 65.1652492582798, 75.23514211177826, 17.50535286962986, 11.699086781591177, 67.80462563037872, 39.219515696167946, 71.17454320192337, 25.992357060313225, 12.06909952685237, 35.59770204126835, 66.00555896759033, 84.7173660993576, 51.585629135370255, 48.09026509523392, 42.1019422262907, 36.27865210175514, 49.05543990433216, 38.20937789976597, 48.45685802400112, 72.12207555770874, 88.66538465023041, 18.60370673239231, 1.4463210222311318, 0.3118473367067054, 0.31381195003632456, 0.27611438068561256, 0.16585580102400854, 0.10796424496220425], [0.14250817650463432, 0.032464081232319586, 0.05201090774789918, 0.06382257022778504, 0.08916522128856741, 0.03311521933937911, 0.026813932854565792, 0.07367788319243118, 0.1414454952464439, 0.04835427193029318, 0.3236964368261397, 2.2066926397383213, 61.50549463927746, 50.252375677227974, 50.42420245707035, 38.987291157245636, 37.134947553277016, 41.020071879029274, 43.91865134239197, 48.56323331594467, 96.80248081684113, 58.05758625268936, 6.814114982262254, 8.993376418948174, 36.00414343178272, 66.62094354629517, 57.01131619513035, 60.593528375029564, 26.847989447414875, 0.026368100625404622, 4.675321374088526, 65.1611302793026, 64.06918287277222, 65.88220998644829, 63.96040230989456, 64.28478330373764, 61.4359887689352, 58.40306371450424, 55.15108421444893, 56.55863128602505, 51.97064347565174, 49.746577218174934, 47.19700522720814, 48.84586974978447, 43.757657781243324, 47.90962278842926, 44.99570354819298, 44.4416818767786, 45.26889368891716, 47.48897776007652, 47.08265036344528, 50.173020735383034, 51.17242410778999, 50.51131658256054, 50.059889405965805, 52.82787747681141, 50.43211743235588, 50.69979406893253, 48.42166431248188, 51.73064835369587, 46.693194061517715, 51.143534258008, 48.84295150637627, 51.498454213142395, 49.25602734088898, 52.77419775724411, 47.80190996825695, 51.457971185445786, 47.44412496685982, 50.90624459087849, 48.66789869964123, 55.952153429389, 32.306816428899765, 2.566306055523455, 6.151759698987007, 2.960012904368341, 2.89457471575588, 4.5359743013978004, 12.344551496207714, 40.85712142288685, 49.983912482857704, 69.33600425720215, 91.6256234049797, 51.82090491056442, 29.186047688126564, 38.35510767996311, 35.551127940416336, 40.0952585041523, 36.821901351213455, 40.1741498708725, 34.86540913581848, 43.05278040468693, 42.276330068707466, 43.82101558148861, 47.072516307234764, 59.3914020806551, 42.53929115831852, 31.20115175843239, 39.8141647875309, 6.203021323308349, 0.8748920692596585, 7.874093279242516, 8.0131259188056, 11.759951915591955, 14.17780777439475, 39.72518876194954, 52.46202930808067, 53.649917766451836, 51.68729268014431, 49.83813710510731, 46.63351446390152, 49.2737989872694, 48.58621068298817, 48.32866430282593, 47.48109698295593, 45.113155245780945, 45.63910782337189, 46.47047661244869, 46.58064790070057, 46.80771231651306, 42.878848537802696, 46.40865013003349, 46.35928697884083, 46.31419099867344, 42.943289279937744, 46.776854172348976, 43.09236668050289, 44.821273908019066, 43.38688887655735, 45.25737650692463, 42.128886580467224, 46.48958578705788, 51.504799872636795, 54.349274039268494, 56.115069687366486, 59.67282637953758, 57.3102917522192, 59.153044670820236, 57.42134839296341, 55.45994684100151, 60.10901257395744, 67.20735847949982, 61.633304581046104, 62.18360245227814, 53.795985728502274, 62.74487033486366, 59.16878342628479, 65.97482621669769, 59.733163341879845, 52.11302563548088, 2.146027944982052, 35.539618358016014, 47.81160704791546, 58.23312543332577, 59.18024741113186, 5.162409162148833, 10.384739208966494, 19.7912760078907, 45.85337832570076, 65.63410609960556, 51.94768890738487, 34.88658159971237, 29.639659747481346, 23.259893283247948, 37.49407008290291, 20.675019286572933, 30.41217729449272, 49.539799913764, 65.91320872306824, 17.6955858618021, 0.5263297073543072, 0.18316940870136023, 0.10152227696380578, 0.10446249536471441, 0.12894879706436768, 0.031627428470528685, 0.11354578178725205, 0.034935945077450015, 0.05148099204234313, 0.05353779866709374, 0.08858422355842777, 0.03810143127338961, 0.040531096601625904, 0.09670192390331067, 0.10866944110603072, 0.17256279737921432, 0.10740765646914952, 2.954738549888134, 72.20711499452591, 58.50282356142998, 56.785030737519264, 36.69471077620983, 45.19567161798477, 48.47934141755104, 42.81422160565853, 35.630053505301476, 88.71393844485283, 55.916458144783974, 18.92251342535019, 15.193311832845211, 36.69959731400013, 68.24354007840157, 62.06654593348503, 65.07408455014229, 37.27911941707134, 0.13007859815843403, 2.9021078115329146, 66.76667332649231, 71.05086743831635, 67.61026605963707, 63.43106031417847, 67.75708258152008, 62.18616731464863, 57.78227962553501, 54.78864446282387, 56.32392168045044, 52.01567105948925, 53.56059215962887, 47.56554365158081, 48.22559483349323, 47.96502381563187, 52.25709110498428, 49.24531951546669, 50.4978197067976, 47.70613230764866, 48.24440382421017, 47.703582644462585, 50.351858139038086, 52.9985187202692, 53.27916406095028, 52.68082156777382, 56.05946347117424, 53.68778273463249, 55.44744931161404, 51.79205685853958, 54.431691616773605, 52.94384725391865, 55.425984263420105, 49.48724113404751, 54.28756155073643, 52.03676752746105, 57.456572502851486, 52.64066532254219, 54.259982630610466, 51.369876712560654, 53.650799319148064, 51.13138630986214, 58.811279609799385, 25.69853402674198, 6.075147734954953, 5.70043321698904, 3.9089571218937635, 5.068245939910412, 6.089827297255397, 16.109653562307358, 44.434386268258095, 49.10516403615475, 66.39213502407074, 72.36689642071724, 48.770952969789505, 39.36673879623413, 42.469390109181404, 38.9890618622303, 39.45576421916485, 39.75245609879494, 42.92881965637207, 41.94925881922245, 47.39307090640068, 46.802818179130554, 49.09212313592434, 48.92283461987972, 50.95833979547024, 41.800200417637825, 37.978772073984146, 46.477415040135384, 8.833873327821493, 4.300605431199074, 11.486041713505983, 16.85499306768179, 16.578149423003197, 16.185907870531082, 41.463880464434624, 53.71509946882725, 53.35123859345913, 51.455071941018105, 51.22433692216873, 47.65151023864746, 50.62239222228527, 52.95360893011093, 51.31239339709282, 51.60886108875275, 49.27258685231209, 48.24690029025078, 47.62279897928238, 49.9616152793169, 50.279946997761726, 48.93689006567001, 50.26808023452759, 50.72205327451229, 51.091545447707176, 48.490964993834496, 51.71908937394619, 51.16047754883766, 48.969100937247276, 45.838908702135086, 47.56932444870472, 46.8681176751852, 45.476932525634766, 52.400863990187645, 58.594429045915604, 56.342430487275124, 56.76138460636139, 60.102093145251274, 63.51033166050911, 62.1829716861248, 58.72049108147621, 55.10860249400139, 64.2968362569809, 62.94840641319752, 63.29237535595894, 59.04696196317673, 65.24821400642395, 66.8350924551487, 66.08535468578339, 63.66023361682892, 48.30319806933403, 4.612688384950161, 42.94931575655937, 53.78039516508579, 62.909105122089386, 54.2670464515686, 4.1157562751322985, 17.110238671302795, 27.727330662310123, 53.59910689294338, 60.23799665272236, 31.462857015430927, 39.046510979533195, 34.38712500035763, 26.47650808095932, 39.1031127423048, 19.79615304619074, 32.737359926104546, 56.9361562281847, 73.73676091432571, 21.938179805874825, 1.0057569877244532, 0.4951889830408618, 0.030698844020662364, 0.09226855632732622, 0.09251791052520275, 0.005766224912804319, 0.29963888868223876, 0.1415522606112063, 0.12575014057802036, 0.16504957631696016, 0.22993955528363585, 0.21079723635921255, 0.11759792294469662, 0.203650472976733, 0.17661067860899493, 0.34308139351196587, 0.4011870740214363, 3.300291057676077, 83.9983382821083, 65.53236275911331, 65.82560062408447, 52.6826948672533, 52.44963817298412, 53.00427161157131, 55.816325917840004, 60.532416254282, 111.02182701230049, 63.91211450099945, 14.026028718799353, 23.336375579237938, 50.83047665655613, 75.31431466341019, 69.37736123800278, 72.72413045167923, 35.58420516550541, 0.09156835483736359, 6.7421891167759895, 71.78951740264893, 73.92466843128204, 71.37280136346817, 66.32465824484825, 72.39309221506119, 66.20856687426567, 64.09913286566734, 59.167347103357315, 59.17394354939461, 56.76382787525654, 56.800860688090324, 51.27723008394241, 53.145088255405426, 50.38125716149807, 55.94247154891491, 52.19831585884094, 53.583862110972404, 49.624991342425346, 50.80066345632076, 52.493218034505844, 54.37720254063606, 55.69046147167683, 55.81756845116615, 56.87622204422951, 57.47667722404003, 55.70805832743645, 55.96076376736164, 53.38622331619263, 57.70735904574394, 55.82571141421795, 56.385702565312386, 54.04796540737152, 54.9904478341341, 53.90410512685776, 61.42409920692444, 55.80195128917694, 57.08380490541458, 54.48973350226879, 56.38375326991081, 53.322911113500595, 59.34305727481842, 40.568785294890404, 31.012408286333084, 14.102262128144503, 4.07805897295475, 5.154685126617551, 12.118671666830778, 24.367583245038986, 51.56413748860359, 59.02174651622772, 77.49143064022064, 75.18010586500168, 51.14304028451443, 40.75154788792133, 45.09233616292477, 41.066748574376106, 37.66227945685387, 34.082616940140724, 34.8273503780365, 36.43032856285572, 47.548448368906975, 49.56452898681164, 48.420140594244, 52.39122770726681, 53.16279910504818, 46.888742968440056, 40.83737388253212, 58.08796942234039, 17.528632320463657, 9.20824633911252, 9.233253747224808, 18.471926003694534, 24.336014539003372, 27.32684165239334, 51.68082922697067, 56.383301094174385, 54.581080600619316, 48.88601079583168, 51.83350123465061, 47.714282870292664, 53.38806241750717, 55.047843754291534, 53.422503769397736, 53.61701153218746, 52.129725739359856, 49.0383256226778, 49.7131884098053, 51.833710223436356, 51.15593299269676, 48.955550864338875, 51.42458617687225, 51.48952089250088, 54.44640442728996, 49.55388955771923, 54.28601883351803, 53.37697081267834, 51.97958439588547, 47.97428771853447, 50.86711049079895, 50.916937217116356, 50.5628228187561, 55.710243210196495, 62.5482726842165, 59.19724389910698, 62.809983640909195, 64.45566773414612, 65.77532932162285, 63.1829222291708, 58.910845667123795, 60.61136841773987, 70.658690482378, 66.64003372192383, 69.58643361926079, 59.73966099321842, 68.02132800221443, 69.0454414486885, 71.38168528676033, 65.73383554816246, 61.05573557317257, 5.845133727416396, 40.701667964458466, 65.93815058469772, 68.58087077736855, 67.95917093753815, 12.186757363379002, 21.260706558823586, 25.013240799307823, 55.27306526899338, 70.93167543411255, 60.257098227739334, 48.83052617311478, 39.25286650657654, 31.15962378680706, 53.5110542178154, 26.95519119501114, 44.51901912689209, 66.37947410345078, 88.27174857258797, 29.418667405843735, 1.1946119600906968, 0.5131666199304163, 0.14851022162474692, 0.19476429355563596, 0.2533884532749653, 0.12258487331564538], [0.04914706376439426, 0.04658368939999491, 0.09788174575078301, 0.10772890251246281, 0.054435196216218174, 0.077803489548387, 0.01735830352117773, 0.04193085762381088, 0.09809366601984948, 0.12117116362787783, 0.1995702786371112, 1.1999575607478619, 51.89571529626846, 61.24506041407585, 41.22153326869011, 32.843245044350624, 37.92141415178776, 39.496030658483505, 41.38288401067257, 42.16370411217213, 81.64651528000832, 51.9761797785759, 18.027463853359222, 5.714922314509749, 10.640366692095995, 55.284742042422295, 60.134353414177895, 58.86522151529789, 49.32192720472813, 8.299059625715017, 0.1480659274966456, 35.9356065094471, 73.47665727138519, 59.90834154188633, 68.28675135970116, 58.150586262345314, 60.91851353645325, 52.18005783855915, 55.17980307340622, 53.952955305576324, 50.39362169802189, 48.91251057386398, 47.16073617339134, 46.61635458469391, 45.56182377040386, 46.70389048755169, 48.03686276078224, 44.086226150393486, 49.284427016973495, 50.12006677687168, 48.182068169116974, 47.56700277328491, 53.73420104384422, 50.30162863433361, 51.07700362801552, 50.23008607327938, 52.61527508497238, 50.61393387615681, 49.43074196577072, 53.44196252524853, 54.264071211218834, 51.52942255139351, 51.01429179310799, 51.043884605169296, 53.485899567604065, 50.81522427499294, 54.04624029994011, 48.215468376874924, 50.532846227288246, 47.558894008398056, 52.792828157544136, 37.13016740977764, 1.4521180861629546, 2.1556069934740663, 1.5553159173578024, 0.5181526055093855, 0.6214492314029485, 2.045523812994361, 11.721982453018427, 26.708704121410847, 47.13697984814644, 56.54873661696911, 72.66920819878578, 50.02657659351826, 30.163159556686878, 33.281361535191536, 33.9541382342577, 33.53351600468159, 28.64850763231516, 27.165350317955017, 29.563802517950535, 34.84769068658352, 42.22161680459976, 37.910102158784866, 30.048859789967537, 73.18788036704063, 82.73900985717773, 41.656419932842255, 23.143917806446552, 13.142754714936018, 1.770347566343844, 0.7674559217412025, 3.0607020389288664, 6.935315653681755, 4.9380729999393225, 13.07186096906662, 36.53089016675949, 51.30945235490799, 51.64908193051815, 50.03743261098862, 49.98713091015816, 52.20754936337471, 48.499392941594124, 48.477741703391075, 48.17191131412983, 46.33463390171528, 44.85336318612099, 45.14119394123554, 51.03876627981663, 45.21641090512276, 49.0607026219368, 48.170269802212715, 48.65445502102375, 45.38970820605755, 46.45234778523445, 46.3534314930439, 44.37572501599789, 42.159911915659904, 42.600471675395966, 43.05553525686264, 43.784609735012054, 43.55360493063927, 51.83376342058182, 50.79166553914547, 55.7488339394331, 52.498218566179276, 56.1847997456789, 57.149906158447266, 58.96419480443001, 57.39614054560661, 57.087684497237206, 56.476890072226524, 63.915496319532394, 59.90183249115944, 61.30906417965889, 57.7170143276453, 69.11571487784386, 61.66386254131794, 65.81116139888763, 18.98672427982092, 3.7497630016878247, 53.925866559147835, 40.67437402904034, 59.01052571833134, 27.64562364667654, 1.4668805315159261, 12.684838436543941, 22.601265124976635, 40.49182802438736, 42.11873732507229, 42.822816744446754, 44.93131600320339, 28.193580843508244, 32.42845930159092, 41.80096037685871, 41.396738067269325, 34.58841919898987, 41.899200305342674, 60.293371081352234, 21.835220530629158, 0.5171257699839771, 0.10468870197655633, 0.14903883857186884, 0.09589333174517378, 0.06325377340544946, 0.019673987953865435, 0.25416871765628457, 0.048317324108211324, 0.036469864135142416, 0.05145679802808445, 0.018408180876576807, 0.06195684436534066, 0.06458222516812384, 0.04947092958900612, 0.15087914216564968, 0.18296680238563567, 0.17707452090689912, 3.004320664331317, 65.07999703288078, 66.87125131487846, 47.18956142663956, 31.760403849184513, 49.03392545878887, 46.02373078465462, 47.15647280216217, 47.45169796049595, 89.1320452094078, 44.30775806307793, 13.769272696226835, 10.151494424790144, 13.268175534904003, 58.80566731095314, 69.17713478207588, 61.29614867269993, 59.08203408122063, 14.297276213765144, 0.03946061166061554, 29.774818494915962, 81.10380560159683, 63.22866037487984, 68.77564072608948, 61.37591399252415, 66.71284541487694, 59.212975054979324, 56.54987655580044, 51.80284067988396, 53.15452314913273, 53.60642150044441, 47.06693060696125, 47.57003501057625, 48.888442665338516, 50.15880189836025, 50.215890035033226, 50.86146019399166, 51.5322457998991, 47.547669410705566, 48.263429403305054, 49.269224032759666, 53.27149987220764, 53.22297267615795, 51.98928527534008, 50.06077095866203, 53.01316313445568, 54.876066371798515, 56.891896203160286, 57.267977222800255, 59.89096127450466, 57.791003957390785, 53.52984040975571, 51.3223260641098, 51.57483771443367, 53.72219368815422, 59.63927038013935, 55.99328242242336, 53.16719926893711, 51.39825738966465, 58.71423281729221, 31.386724300682545, 1.6744695673696697, 1.547495936974883, 2.2098956303671002, 2.417368534952402, 1.6049159620888531, 3.248029612004757, 16.474369391798973, 33.74733053147793, 46.32121302187443, 56.09022282063961, 69.1815197467804, 50.364386066794395, 35.241759940981865, 41.57513089478016, 39.02531571686268, 43.536308258771896, 39.71879370510578, 40.64351208508015, 40.8237212151289, 41.232856661081314, 48.5452526807785, 42.16586999595165, 42.98829026520252, 60.74880704283714, 66.03996992111206, 46.56365901231766, 38.4128949791193, 15.184641648083925, 2.3206494748592377, 7.945300033316016, 5.574458576738834, 9.679858032613993, 9.912969823926687, 17.083638198673725, 37.28107251226902, 54.451860934495926, 53.11128906905651, 50.29408223927021, 51.44850589334965, 53.163456469774246, 52.62191332876682, 52.625671327114105, 53.037189245224, 51.65904879570007, 49.427648931741714, 47.325700521469116, 50.03998227417469, 50.424145460128784, 53.06913033127785, 51.24544098973274, 51.96285389363766, 51.7901873588562, 48.772248700261116, 48.79711456596851, 52.70477548241615, 48.74506875872612, 46.22715286910534, 46.555869430303574, 50.88847674429417, 43.512434139847755, 54.60789196193218, 53.76116059720516, 56.49107091128826, 53.052852004766464, 61.7784757912159, 59.90641124546528, 66.34192451834679, 64.60266664624214, 56.441046595573425, 56.35829083621502, 64.48623329401016, 61.17523916065693, 66.82448342442513, 60.06286785006523, 75.5700333416462, 63.36584821343422, 66.52436792850494, 11.268448289483786, 6.202784786000848, 63.82774382829666, 46.20984859764576, 63.73844861984253, 26.59267734736204, 1.3651217543520033, 21.500483192503452, 22.619743533432484, 48.56765627861023, 47.721890062093735, 28.461392372846603, 46.34898193180561, 30.20381547510624, 39.419806748628616, 47.75931045413017, 36.214579939842224, 35.103424564003944, 51.06134086847305, 72.44340151548386, 28.619826771318913, 1.2677957955747843, 0.1730192924151197, 0.09126220407779329, 0.17454203101806343, 0.08014011924387887, 0.04754267407406587, 0.2674550609663129, 0.26512059092056006, 0.14403308217879385, 0.18021445866907015, 0.1712287572445348, 0.24394229374593124, 0.11971337036811747, 0.27229386381804943, 0.3114853170700371, 0.31110216106753796, 0.26521932624746114, 4.580055261030793, 78.6735700070858, 78.57968464493752, 59.6254201233387, 43.5032994300127, 53.42546381056309, 56.16582736372948, 56.54385007917881, 45.60091607272625, 97.7527642250061, 57.96896740794182, 24.69551894813776, 13.208526335656643, 22.583573274314404, 65.94704210758209, 74.43014770746231, 66.82931676506996, 63.49029153585434, 11.543938256800175, 0.21586104354355484, 45.07352717220783, 83.3345215022564, 64.56766292452812, 73.69367122650146, 64.09723296761513, 67.4425658583641, 60.39659634232521, 61.21366649866104, 56.44991531968117, 55.78710928559303, 56.753963604569435, 49.37886714935303, 50.07212854921818, 53.36461007595062, 52.02304266393185, 52.1443397551775, 51.00288860499859, 53.985618352890015, 50.27446389198303, 52.752626314759254, 51.8043377995491, 58.92763316631317, 56.69254370033741, 56.50612190365791, 55.130261331796646, 58.08142997324467, 57.966847121715546, 58.08476239442825, 58.65997552871704, 60.603803023695946, 59.63669031858444, 56.70813046395779, 54.79715220630169, 55.93830697238445, 58.547334372997284, 61.214905232191086, 58.15243296325207, 56.41455441713333, 55.656810477375984, 55.46370103955269, 52.280357256531715, 22.03498151153326, 2.8602250339463353, 3.789089941419661, 2.3370569944381714, 4.979453729465604, 2.3333232197910547, 24.251531772315502, 49.78609889745712, 54.257691353559494, 70.91299563646317, 79.13249418139458, 54.17202115058899, 35.10266460478306, 39.30112011730671, 40.562561228871346, 37.42361806333065, 33.53434436023235, 32.223817482590675, 35.73711276054382, 37.60403238236904, 51.200105622410774, 47.421200796961784, 43.171809017658234, 66.24629124999046, 76.27785176038742, 48.636964559555054, 46.75845555961132, 23.250011913478374, 0.9863029816187918, 9.111811313778162, 8.090204782783985, 13.438217360526323, 13.514407072216272, 33.86416666209698, 51.206219494342804, 53.343627601861954, 53.8497718423605, 49.08907949924469, 52.14941248297691, 54.66673940420151, 53.121806904673576, 54.76235747337341, 54.53639879822731, 54.389810264110565, 50.10098040103912, 47.891129180788994, 55.42213886976242, 51.79983504116535, 52.54448488354683, 52.63987876474857, 53.42490144073963, 53.45161020755768, 50.11748671531677, 51.04223169386387, 53.45050446689129, 49.70097206532955, 47.684880048036575, 48.39678704738617, 53.06935451924801, 48.57276700437069, 57.85220727324486, 56.39032691717148, 60.38602910935879, 56.00484900176525, 62.90687844157219, 62.628824561834335, 68.8358598947525, 66.49490430951118, 58.809683695435524, 57.3866980522871, 68.47162663936615, 65.05101218819618, 70.31423896551132, 62.05127835273743, 79.95311334729195, 67.04392164945602, 72.42531448602676, 25.472907833755016, 5.5544977728277445, 64.22325700521469, 53.53106774389744, 71.60784155130386, 38.85093167424202, 7.1017818711698055, 20.67090790718794, 29.993658252060413, 47.5903145223856, 51.584762781858444, 45.306903049349785, 64.03346478939056, 39.31596592068672, 41.83743841946125, 61.74685388803482, 52.48046211898327, 47.18615300953388, 60.72524830698967, 84.82604786753654, 36.08878768980503, 1.3935698778368533, 0.2980894624488428, 0.41475204925518483, 0.28786058945115656, 0.3614463424310088, 0.09509570852969773], [0.14573945780284703, 0.03175456578901503, 0.06958144324016757, 0.032211190700763837, 0.010963186377921375, 0.09057574716280214, 0.09919196294504218, 0.12830133258830756, 0.15023518062662333, 0.14855236076982692, 0.1048671588068828, 2.4822904262691736, 58.868329748511314, 55.942999720573425, 34.47102829813957, 38.364903554320335, 41.727354526519775, 45.584842935204506, 34.68118742108345, 13.93542068079114, 39.308035746216774, 37.03390337526798, 26.4754631370306, 9.586176909506321, 6.079342234879732, 31.290878243744373, 68.7435932457447, 55.11459477245808, 57.70673207938671, 38.553650826215744, 0.5305993126239628, 1.5342973452061415, 52.15657889842987, 69.24121454358101, 61.865958496928215, 56.95135921239853, 59.177329167723656, 57.92717345058918, 55.295529663562775, 51.802582293748856, 50.604628175497055, 48.22277918457985, 45.157179683446884, 46.579770147800446, 46.97646506130695, 49.71399776637554, 52.18470498919487, 49.67380352318287, 47.69228205084801, 45.69851003587246, 46.25526376068592, 48.26351299881935, 50.609130933880806, 51.4477801322937, 48.12596037983894, 48.642960637807846, 49.43804517388344, 51.3087759912014, 53.32665391266346, 55.61212107539177, 55.64018256962299, 52.80444413423538, 53.614914044737816, 49.35899041593075, 49.540362283587456, 52.89322257041931, 53.566386848688126, 51.250536516308784, 49.027659595012665, 50.03811277449131, 44.7463571280241, 6.866227285936475, 2.160530579276383, 1.573253448586911, 1.4978703623637557, 0.2899652312044054, 0.557536898413673, 2.5132297910749912, 6.73558839596808, 21.65564976632595, 59.74666401743889, 34.11258973181248, 19.037003181874752, 32.00314052402973, 26.87048614025116, 21.19552105665207, 20.528016574680805, 18.29399675130844, 18.352887891232967, 16.765274181962013, 22.92903933674097, 27.391358390450478, 22.927171736955643, 16.82316977530718, 20.898012220859528, 39.71117131412029, 55.906966254115105, 73.2294349372387, 25.171177424490452, 17.485734522342682, 6.2744323164224625, 1.291559364181012, 0.9751303936354816, 2.463283846154809, 3.865311713889241, 5.09503735229373, 10.810452215373516, 41.255435049533844, 56.02732099592686, 53.37672762572765, 52.509177178144455, 47.703214064240456, 50.49789950251579, 48.90425741672516, 48.57592083513737, 47.18190483748913, 46.110844910144806, 47.93661653995514, 50.9442425519228, 51.14577613770962, 52.11374379694462, 53.813267201185226, 48.0917090177536, 47.67239771783352, 46.93378195166588, 48.82778652012348, 47.00653664767742, 44.86616849899292, 46.50096997618675, 43.39462526142597, 42.84696824848652, 44.73172791302204, 48.30962352454662, 51.17130696773529, 52.467098236083984, 55.60001112520695, 58.90915475785732, 57.74168640375137, 61.41762435436249, 58.76307159662247, 58.23920510709286, 52.84009002149105, 58.98637801408768, 58.69277536869049, 60.87742634117603, 58.24029944837093, 64.98398378491402, 57.96959437429905, 49.33013096451759, 0.3729214594932273, 22.876811139285564, 57.91324719786644, 39.36836510896683, 56.53465457260609, 15.382506530731916, 0.2264818298863247, 23.050589114427567, 53.382963091135025, 35.197013542056084, 18.764700293540955, 20.602416582405567, 40.21413132548332, 27.290796786546707, 27.467738091945648, 39.483502730727196, 30.239818543195724, 25.48907596617937, 39.771379083395004, 54.21177461743355, 22.471095509827137, 1.3010942400433123, 0.24363173462916166, 0.03422733876504935, 0.04606690970831551, 0.11091947701061144, 0.03766107794945128, 0.18206196109531447, 0.012856300272687804, 0.13140471215592697, 0.025710552217788063, 0.03332769621920306, 0.12913648621179163, 0.1155893893155735, 0.10662486136425287, 0.20008865394629538, 0.29837420966941863, 0.2870784548576921, 5.405677333474159, 70.76738744974136, 61.58868357539177, 39.39985401928425, 38.28480385243893, 47.13920272886753, 49.32154342532158, 39.1714558750391, 20.16420889645815, 45.51556505262852, 34.44921746850014, 16.665204651653767, 7.7926593739539385, 9.37775619328022, 35.32624460756779, 75.46904996037483, 60.37458032369614, 59.12174955010414, 43.47848296165466, 0.9219242830295116, 0.11176132480613887, 44.41488951444626, 71.48947790265083, 64.09399554133415, 63.049059212207794, 72.43930533528328, 65.56018486618996, 60.70817582309246, 54.81301635503769, 56.522844806313515, 52.832676619291306, 46.87933087348938, 46.29481203854084, 49.4189739972353, 48.67023557424545, 53.329393565654755, 54.59717273712158, 52.66258254647255, 46.86055228114128, 51.17506876587868, 52.11288124322891, 52.935852482914925, 52.882009372115135, 53.35277371108532, 52.41084985435009, 51.396623477339745, 56.42846167087555, 60.99777348339558, 58.68677169084549, 57.56000675261021, 57.87116065621376, 57.43930242955685, 52.72730067372322, 51.33690968155861, 50.33525303006172, 52.68069237470627, 57.26842939853668, 53.30798551440239, 58.04819315671921, 44.73476015031338, 7.142963586375117, 2.8976188274100423, 2.7879650238901377, 3.362464508973062, 0.8031649806071073, 2.1573157142847776, 5.89700854383409, 7.792551079764962, 27.44124211370945, 60.42533040046692, 29.62631296366453, 35.97168177366257, 41.998314186930656, 34.726177006959915, 28.119551315903664, 27.10633758455515, 26.270201951265335, 25.791980512440205, 23.948382139205933, 30.588425137102604, 34.37945321202278, 32.864641696214676, 21.98534097522497, 26.5756618604064, 38.872039541602135, 41.96326106786728, 66.09669327735901, 32.54306495189667, 22.044144719839096, 11.850787941366434, 2.3669276665896177, 0.9067418414633721, 3.498776969499886, 6.955655962228775, 6.613461999222636, 14.654934871941805, 45.82477726042271, 56.263607516884804, 54.738065376877785, 50.925091579556465, 51.701188534498215, 53.66640888154507, 52.11408957839012, 55.89597724378109, 50.9788016974926, 50.51537476480007, 49.260142520070076, 49.22840662300587, 54.220605343580246, 51.92838974297047, 55.050013437867165, 55.11972449719906, 51.9310761988163, 49.205311462283134, 50.84367334842682, 54.741477593779564, 53.37735079228878, 49.48205441236496, 48.02127219736576, 51.00657820701599, 44.880527928471565, 50.535597279667854, 52.312256544828415, 54.263068065047264, 56.46929427981377, 64.15622860193253, 63.21940407156944, 68.46183836460114, 63.375621289014816, 63.97936329245567, 59.81464236974716, 65.09076565504074, 65.6668071448803, 65.624188631773, 65.84118738770485, 67.24065229296684, 59.511889815330505, 37.81403571367264, 0.13504733622539788, 33.67708370089531, 58.87789003551006, 48.118072003126144, 63.41948613524437, 14.567059837281704, 1.972991048824042, 24.91898685693741, 42.1858037263155, 41.89495973289013, 27.984732650220394, 20.25091264396906, 46.776253804564476, 31.560304686427116, 34.09146286547184, 46.27490110695362, 32.210362404584885, 28.23937028646469, 49.80216443538666, 70.05435571074486, 30.673304982483387, 1.5167566551826894, 0.41522663785144687, 0.03940355163649656, 0.19825084396870807, 0.04636891186237335, 0.17065546300727874, 0.26172526529990137, 0.12375777834677137, 0.19070815964369103, 0.2722894406178966, 0.24187838105717674, 0.21039824292529374, 0.15557831735350192, 0.23620659165317193, 0.18049978476483375, 0.38363750791177154, 0.40274976985529065, 5.7701286021620035, 83.53773459792137, 72.41386190056801, 51.77933134138584, 51.22523367404938, 55.64266763627529, 59.609559774398804, 47.65020690858364, 17.707815505564213, 55.84374524652958, 44.063613563776016, 36.08312979340553, 17.332437448203564, 12.592067364603281, 40.807442888617516, 78.25845748186111, 65.92901587486267, 69.0023897588253, 46.24921068549156, 0.4966783249983564, 2.273569763638079, 63.80192041397095, 71.36835560202599, 65.53777366876602, 63.06199751794338, 70.3414835035801, 64.63698640465736, 61.63936525583267, 58.817024901509285, 61.31534144282341, 55.23579686880112, 49.057286605238914, 47.834174036979675, 53.46000395715237, 50.729466676712036, 55.51554165780544, 57.286748215556145, 53.783279210329056, 49.08271864056587, 54.19352039694786, 54.03643682599068, 58.592707738280296, 58.90807181596756, 56.579381972551346, 58.17571811378002, 56.3166830688715, 59.5705396682024, 61.36091619729996, 59.280736818909645, 62.69575037062168, 59.51834186911583, 60.25320343673229, 57.20363907516003, 58.236389458179474, 58.7655870616436, 59.33209486305714, 57.43495546281338, 57.28321060538292, 53.502656668424606, 51.91381372511387, 33.101596981287, 3.79875757265836, 2.931988458149135, 3.743387656286359, 1.066646701656282, 2.4522774992510676, 9.85910676419735, 9.652929827570915, 42.946633100509644, 74.62927222251892, 44.20085459947586, 47.141820788383484, 47.890365421772, 33.24649080634117, 31.23589899390936, 35.807199999690056, 30.582155473530293, 30.62545035034418, 28.028056025505066, 37.45328687131405, 37.60297603905201, 35.688201785087585, 21.598086655139923, 22.26310607045889, 56.807472333312035, 64.27546620368958, 68.42447876930237, 49.44442503154278, 29.4588540494442, 17.676039710640907, 2.330489521846175, 1.0274394555017352, 5.324749751016498, 9.14529986679554, 9.69942033290863, 37.49436266720295, 54.8348043859005, 58.78348030149937, 53.62217925488949, 52.963009625673294, 53.34637485444546, 57.386067286133766, 52.676915377378464, 58.31913761794567, 53.04721310734749, 53.00757743418217, 53.129197508096695, 53.480283468961716, 57.91361577808857, 54.784012511372566, 57.350128814578056, 56.629486083984375, 52.65674985945225, 51.44030213356018, 53.732289746403694, 58.0511000007391, 52.88530379533768, 50.34773916006088, 49.492769837379456, 53.3202550560236, 47.542634680867195, 52.516054809093475, 56.97824276983738, 57.06589266657829, 58.81062604486942, 68.17311465740204, 64.7208859026432, 68.37920799851418, 64.34156745672226, 63.05208384990692, 56.133684888482094, 65.54512247443199, 64.49305012822151, 67.9748184978962, 64.63748037815094, 74.14122641086578, 59.249403700232506, 57.43552163243294, 1.332283797673881, 27.857099398970604, 68.1256552040577, 52.411309629678726, 69.74018096923828, 24.67625018209219, 4.660813752561808, 36.046017184853554, 66.4052215218544, 42.199786975979805, 28.72195389121771, 22.43679855018854, 58.727912083268166, 40.56763395667076, 35.788033828139305, 56.9585370272398, 42.161420434713364, 40.522617772221565, 60.35522036254406, 81.85906827449799, 41.91140525043011, 1.5960515127517283, 0.554576797876507, 0.14303228119388223, 0.3535629529505968, 0.1669445910374634, 0.22613469773204997], [0.059275795065332204, 0.04139704193221405, 0.08555045744287781, 0.1112325223220978, 0.13813517522066832, 0.026730545141617768, 0.007419926605507499, 0.14468872512225062, 0.05922100601310376, 0.10954732759273611, 0.20382707443786785, 2.6068589044734836, 58.19025993347168, 57.452833503484726, 39.929781183600426, 31.881896629929543, 42.83487729728222, 31.39047469943762, 30.307263024151325, 30.231263302266598, 38.125501200556755, 37.024137899279594, 14.354978017508984, 6.794769270345569, 13.492665588855743, 35.288478434085846, 56.71450272202492, 63.71124587953091, 59.94788222014904, 49.79595176875591, 7.602460579946637, 0.23642162152100354, 3.735694969072938, 41.775744929909706, 61.55556075274944, 61.44613042473793, 63.09047318994999, 57.53554746508598, 53.973090425133705, 49.894362688064575, 46.949927285313606, 48.22412811219692, 46.87836192548275, 45.43591372668743, 46.77257940173149, 51.12089887261391, 50.89230313897133, 51.09219901263714, 49.589866027235985, 47.149899154901505, 47.260689809918404, 52.14114412665367, 48.632454201579094, 52.68714442849159, 50.67992873489857, 53.21558587253094, 50.07661230862141, 55.9885136783123, 56.24054275453091, 56.423244550824165, 52.06332050263882, 52.48294338583946, 49.11538168787956, 49.76055666804314, 44.677269235253334, 40.05549743771553, 39.60307851433754, 42.7692624181509, 50.130402222275734, 51.50098867714405, 20.696056857705116, 2.1624164655804634, 0.5970312072895467, 0.8414420485496521, 0.8857270097360015, 1.1124991974793375, 0.2505887456936762, 1.1134182731620967, 1.9416353688575327, 23.476396165788174, 34.831807538867, 18.49811229854822, 11.69943731278181, 16.397564113140106, 14.263582471758127, 9.380415100604296, 8.766539990901947, 9.928601235151291, 9.009211119264364, 5.505687491968274, 4.637222243472934, 2.776772012002766, 1.0633306670933962, 4.041767120361328, 11.651622578501701, 10.219488926231861, 20.911824479699135, 35.43561413884163, 27.619788832962513, 6.456815879791975, 4.127792604267597, 1.6937630320899189, 0.3542550205020234, 0.8847996813710779, 0.8248397300485522, 0.9568901255261153, 5.41967673227191, 14.766921512782574, 42.74406976997852, 49.89909343421459, 51.3953847438097, 50.36969058215618, 49.77471470832825, 47.94659100472927, 49.69742685556412, 47.60383039712906, 45.571034476161, 49.18042279779911, 48.917913883924484, 47.78758853673935, 53.09727922081947, 53.74490886926651, 47.73941092193127, 50.08537843823433, 46.615769416093826, 47.813955321908, 46.58100888133049, 47.1344605833292, 47.63145871460438, 46.28361403942108, 45.7282130420208, 43.58470246195793, 44.7362344712019, 48.90573173761368, 51.775124967098236, 53.178032487630844, 54.87169660627842, 59.372414499521255, 59.98768508434296, 59.82051685452461, 58.07361759245396, 59.01920825242996, 60.31643584370613, 63.182242065668106, 63.42861704528332, 63.32463562488556, 61.599235609173775, 63.94055977463722, 6.957134557887912, 0.280002195504494, 45.02092659473419, 41.27650871872902, 57.57746301591396, 49.62746500968933, 8.204378206282854, 3.3209422370418906, 25.20858071744442, 48.59735168516636, 70.87930664420128, 49.97804559767246, 12.762237433344126, 26.362451501190662, 31.74724705517292, 30.92824660241604, 36.388785392045975, 38.94473344087601, 29.159652404487133, 39.18255887925625, 52.57552541792393, 15.780970249325037, 0.49706679477822036, 0.08932506505516358, 0.07578697041026317, 0.10084503010148183, 0.012229407202539733, 0.07365688041318208, 0.14846165548078716, 0.05447965086204931, 0.06690324007649906, 0.0995431249612011, 0.03857357820379548, 0.07266767177497968, 0.09044463935424574, 0.10693971009459347, 0.18167709815315902, 0.11535078883753158, 0.4839124350110069, 2.967800348997116, 67.65551403164864, 64.95349422097206, 42.593936026096344, 30.310264863073826, 43.5326262563467, 40.137052461504936, 34.74524438381195, 28.514485023915768, 46.39302156865597, 33.07091362774372, 13.412972465157509, 7.923017553985119, 15.725510325282812, 40.540556609630585, 59.77779194712639, 69.36991363763809, 63.05040813982487, 53.668757155537605, 9.405066277831793, 0.2977932267822325, 2.4770191591233015, 35.402236729860306, 64.69765394926071, 71.90013706684113, 72.97765284776688, 62.1150541305542, 58.66533324122429, 53.4775248169899, 52.25467063486576, 54.06472630798817, 51.83621808886528, 45.45824892818928, 46.641862615942955, 50.263387486338615, 49.55615043640137, 53.829868510365486, 54.01679188013077, 50.01758627593517, 53.68807531893253, 57.15800732374191, 54.70607869327068, 58.75074505805969, 55.940537452697754, 57.31717698276043, 55.11134974658489, 61.67756460607052, 60.34057594835758, 58.88867385685444, 53.26407127082348, 56.219412088394165, 54.09759074449539, 56.69966071844101, 51.986914202570915, 44.52748887240887, 46.8880096077919, 39.874452352523804, 50.57684026658535, 50.49385651946068, 19.841600507497787, 3.490522624924779, 1.4297033264301717, 1.3803639239631593, 0.70375946466811, 0.3624146670335904, 1.8386382143944502, 2.3613034933805466, 5.309706358239055, 21.302263028919697, 38.294766917824745, 27.87824146449566, 30.01815363764763, 27.65951380133629, 22.673151567578316, 11.314253881573677, 10.719773881137371, 10.762684978544712, 6.830458855256438, 2.9580942448228598, 3.082183711230755, 2.5920822098851204, 2.3867193795740604, 6.196751184761524, 18.01866352558136, 17.46950939297676, 23.787669762969017, 38.10016795992851, 28.439431451261044, 14.093254711478949, 7.591213658452034, 4.746906207874417, 0.4960022878367454, 1.3588694273494184, 2.523433668538928, 4.359221085906029, 8.397183660417795, 19.354801028966904, 45.444508865475655, 52.60669894516468, 55.034844651818275, 54.60300162434578, 51.232890263199806, 50.473873391747475, 54.311519265174866, 50.316903814673424, 52.302274480462074, 52.1385944634676, 50.8597768843174, 49.860438108444214, 55.244224816560745, 54.38178889453411, 53.53166051208973, 50.526413172483444, 49.037546664476395, 45.77218048274517, 50.3174851834774, 51.94523423910141, 51.894909739494324, 51.147702634334564, 53.37546229362488, 46.547604873776436, 45.287866070866585, 50.17376929521561, 52.626074105501175, 55.97504340112209, 62.679133862257004, 59.51421529054642, 63.70813764631748, 61.82660020887852, 61.98395736515522, 64.71722289919853, 64.65477705001831, 63.93341615796089, 65.29068052768707, 63.33309017121792, 71.56736612319946, 55.7039887458086, 0.6653847894631326, 2.209035214036703, 50.405093282461166, 47.410774156451225, 66.35055005550385, 53.50069597363472, 10.015452224761248, 4.203051840886474, 21.97776798158884, 49.23539064824581, 67.94821232557297, 50.73830500245094, 13.279849458485842, 37.208298817276955, 35.80579027533531, 33.2533760368824, 41.702845841646194, 32.73127645254135, 32.22189478576183, 52.15407483279705, 74.19692382216454, 20.818594582378864, 0.7154474593698978, 0.10127230678335764, 0.15280752384569496, 0.03211337192624342, 0.22558156022569165, 0.0486634283879539, 0.22834454633994028, 0.29857571760658175, 0.17920099664479494, 0.18857423274312168, 0.09535730816423893, 0.2505528851179406, 0.13978067989228293, 0.31401417043525726, 0.2189072480541654, 0.28853074880316854, 0.6129261699970812, 5.108267292380333, 85.48259183764458, 71.57161429524422, 58.39336283504963, 42.13202141225338, 55.336818248033524, 46.127746403217316, 41.84387907385826, 38.07912088930607, 53.31110514700413, 44.8893016576767, 21.75033688545227, 15.253403708338737, 20.37749145179987, 42.523860186338425, 67.45511278510094, 73.18573728203773, 67.36636474728584, 62.06015467643738, 10.895736739039421, 0.31991148367524147, 6.333622690290213, 48.18078003823757, 64.14786145091057, 70.0934936106205, 70.06333082914352, 62.09805004298687, 57.15340577065945, 53.15834954380989, 51.77618891000748, 56.997051760554314, 51.18575759232044, 48.21676790714264, 50.04420764744282, 55.921185091137886, 50.87323196232319, 55.3956238925457, 53.818161338567734, 53.19002464413643, 54.02669034898281, 61.132506653666496, 53.37039716541767, 64.1803041100502, 60.50457514822483, 63.11222322285175, 59.42877687513828, 67.81148046255112, 62.21868596971035, 64.51573491096497, 57.99144700169563, 61.8264140188694, 51.39574572443962, 59.107895493507385, 51.600797921419144, 52.129056975245476, 50.39231076836586, 54.26135055720806, 50.768087804317474, 57.85536490380764, 37.71942839026451, 9.644149448722601, 2.148910565301776, 4.071163292974234, 2.0921822218224406, 1.1480331094935536, 4.353149011731148, 8.710694387555122, 9.890932906419039, 42.57026709616184, 43.389525935053825, 27.74277113378048, 45.454620122909546, 33.8363141566515, 32.056428864598274, 18.413040563464165, 17.909719571471214, 18.133337572216988, 12.260474357753992, 9.435651786625385, 7.70411747507751, 5.21583192050457, 4.082324244081974, 6.379188420251012, 12.971438057720661, 39.81376960873604, 41.054931208491325, 42.782428711652756, 39.123035073280334, 26.725605614483356, 24.60414905101061, 5.815702881664038, 0.442467019893229, 1.3079551281407475, 3.8372606690973043, 8.828503265976906, 12.65978068113327, 35.94616234302521, 51.27580136060715, 51.401228830218315, 54.886116832494736, 54.89430919289589, 53.091321140527725, 51.08494520187378, 56.73456944525242, 53.21706019341946, 53.52890565991402, 55.40358826518059, 52.49072536826134, 54.49073664844036, 60.78240863978863, 60.592027455568314, 55.58375559747219, 54.27487023174763, 51.406020373106, 51.71269431710243, 55.997838377952576, 53.43562826514244, 53.738137632608414, 54.73658345639706, 52.9743330180645, 48.98585803806782, 48.4833388030529, 52.16405689716339, 56.18950389325619, 58.208058178424835, 62.841711938381195, 62.13779591023922, 62.75148577988148, 63.67523521184921, 60.42339250445366, 61.846294552087784, 59.970061630010605, 64.40903663635254, 64.62176442146301, 69.23246741294861, 70.79157695174217, 76.61450609564781, 9.817947372794151, 1.759207514114678, 56.54389567673206, 58.1431120634079, 71.26481875777245, 59.83654819428921, 13.954258169978857, 7.552229650318623, 36.63366325199604, 63.681797459721565, 72.9458637535572, 60.013307109475136, 14.367298856377602, 38.885639011859894, 48.015891686081886, 37.56209783256054, 54.82331000268459, 47.16358222067356, 44.720651507377625, 61.324092373251915, 86.03641211986542, 30.514815486967564, 0.9138023375999182, 0.33399106410797685, 0.222345796355512, 0.21573190984781832, 0.3022037510527298, 0.14146704721497372], [0.25193583278451115, 0.05917069582210388, 0.06849429337307811, 0.012107941747672157, 0.09661489966674708, 0.09471972167375498, 0.07245798537041992, 0.0009172596242024156, 0.1318533849553205, 0.1101092595490627, 0.4381491453386843, 0.9587255457881838, 50.50084434449673, 54.032576233148575, 44.594475477933884, 41.926247254014015, 32.843332439661026, 25.686292983591557, 22.460161596536636, 29.962431527674198, 39.48729872703552, 33.91513332724571, 12.746435981243849, 2.0159488124772906, 7.881243070587516, 45.383917316794395, 59.78494316339493, 48.933873027563095, 46.71471990644932, 55.56931637227535, 21.614313684403896, 0.6309668300673366, 0.348245405475609, 12.1206846088171, 52.14276663959026, 66.03009805083275, 66.71943426132202, 60.986472889781, 55.06398908793926, 51.88716575503349, 49.8275812715292, 49.7986876219511, 48.28468546271324, 49.574868232011795, 54.75431330502033, 55.87122917175293, 54.23172354698181, 51.73157550394535, 49.03248533606529, 46.55745394527912, 48.76505948603153, 53.17615918815136, 54.1158639639616, 54.15388472378254, 52.99244284629822, 54.87608537077904, 51.75062768161297, 60.79012982547283, 57.469244822859764, 55.88752269744873, 54.21812787652016, 54.38252605497837, 50.115457624197006, 52.011035308241844, 47.7270083874464, 47.191085144877434, 38.183573484420776, 24.228786192834377, 42.770535349845886, 38.007540330290794, 3.156965598464012, 0.5792882374953479, 0.36178586015012115, 0.15519294975092635, 0.1043761613254901, 0.9344814217183739, 1.2767158169299364, 1.1537059675902128, 1.262988222297281, 21.86397548764944, 28.25893733650446, 8.311909586191177, 9.844244811683893, 10.423542726784945, 6.289596352726221, 0.39463364286348224, 0.4147638048743829, 0.22422095120418817, 0.47610299312509596, 0.7327725703362375, 0.06242466828553006, 0.11081979915616103, 0.2503690402954817, 0.09804869187064469, 2.5319402245804667, 2.9547582613304257, 5.465164091438055, 23.994543962180614, 29.27232015877962, 5.558886062353849, 5.5705728102475405, 3.7832361180335283, 2.145524234510958, 0.07038435054710135, 0.7994410616811365, 1.3933186163194478, 3.088423451408744, 5.432688659057021, 27.581350095570087, 49.83480468392372, 55.62108859419823, 51.59328192472458, 49.704688265919685, 47.12964244186878, 46.8452163040638, 45.52510254085064, 50.088889449834824, 51.378384456038475, 50.61631254851818, 50.83743788301945, 54.2173071205616, 54.877635687589645, 53.00801821053028, 46.95608675479889, 46.97657525539398, 45.380907878279686, 45.89828431606293, 47.3127394169569, 50.61562858521938, 48.42511832714081, 48.567093908786774, 43.166246116161346, 45.41797488927841, 49.17409613728523, 50.21357975900173, 52.990827932953835, 56.865122839808464, 56.6152710467577, 59.81748081743717, 61.66636660695076, 60.78679360449314, 58.06965820491314, 62.34977513551712, 59.606474339962006, 58.921428099274635, 60.20683832466602, 67.4693164229393, 10.906856842339039, 0.4343623813474551, 8.857189826667309, 51.04807958006859, 54.59406070411205, 59.07842427492142, 46.754522770643234, 16.089223958551884, 5.752502772957087, 6.1023215018212795, 39.203795939683914, 85.40417924523354, 72.36897870898247, 16.323796771466732, 19.696490094065666, 32.87008300423622, 35.39041556417942, 39.93016876280308, 37.63619385659695, 34.182783365249634, 43.86006988584995, 56.065315157175064, 13.610450718551874, 0.3335321496706456, 0.007145773543015821, 0.1524401904316619, 0.11735479536582716, 0.1340386239462532, 0.060440343513619155, 0.13841502426657826, 0.007758389547234401, 0.055453968307119794, 0.034833053723559715, 0.03177713821060024, 0.10388598020654172, 0.09358380528283305, 0.09356152600958012, 0.1691247388953343, 0.059391811300884, 0.315825812285766, 1.9768899958580732, 62.46604509651661, 57.74499222636223, 49.99611742794514, 38.79520006477833, 36.27847731113434, 37.07766182720661, 29.396362602710724, 32.62676306068897, 48.84822562336922, 35.37910357117653, 16.058696396648884, 4.827998131513596, 8.016137257218361, 46.71789273619652, 64.19816315174103, 52.722930908203125, 51.41598343849182, 59.4708938151598, 29.02105674147606, 0.7910334784537554, 0.3316153900232166, 11.14311771467328, 52.96134911477566, 68.639395236969, 68.291075527668, 59.125765934586525, 55.48321679234505, 53.399701192975044, 52.537105679512024, 55.28072185814381, 51.971316039562225, 53.120613768696785, 58.18112522363663, 58.74199032783508, 53.22535514831543, 54.4725052267313, 50.482293739914894, 49.54012669622898, 53.294785022735596, 53.86400207877159, 57.653329744935036, 57.21432030200958, 57.13348723948002, 56.84213787317276, 56.17618940770626, 63.464563116431236, 59.03343848884106, 61.74537196755409, 55.85108645260334, 60.71196421980858, 53.65664720535278, 56.994532495737076, 51.570004373788834, 52.79329553246498, 44.11810263991356, 34.447921738028526, 43.11219781637192, 37.631322517991066, 5.897805551066995, 1.1516006430611014, 1.2738026794977486, 0.4324044770328328, 0.7009939849376678, 1.6086740791797638, 3.3202193258330226, 2.762399520725012, 0.3481060895137489, 22.822745740413666, 38.39876353740692, 18.89100171625614, 12.048560678958893, 11.99465012177825, 3.8157861214131117, 0.20139044034294784, 0.31546266458462924, 1.3460848946124315, 1.3203679933212698, 0.41110213729552925, 0.05715516374038998, 0.11615247160079889, 0.12828046339564025, 0.11346334402333014, 4.568327190354466, 10.323871225118637, 16.116443797945976, 35.084379985928535, 32.61653780937195, 7.979877702891827, 9.772716499865055, 5.4254386480897665, 3.9781765826046467, 0.40700954908970743, 2.921649687923491, 4.956619329750538, 5.834638215601444, 7.149366242811084, 33.62559266388416, 52.95191802084446, 57.4077033251524, 52.928898856043816, 50.27046650648117, 49.624630361795425, 50.88436916470528, 47.742154374718666, 54.32594709098339, 53.27770113945007, 53.43196526169777, 55.481567680835724, 56.39378473162651, 57.37162046134472, 58.69995318353176, 50.491531044244766, 49.40624088048935, 44.53443489968777, 48.63939642906189, 47.758489698171616, 51.68825402855873, 51.56570300459862, 51.09940342605114, 45.57760052382946, 48.115662932395935, 53.09460036456585, 53.92061144113541, 56.122384294867516, 59.65128533542156, 54.9812713265419, 61.69552244246006, 62.6330803334713, 64.0423259139061, 58.527818620204926, 62.537146881222725, 57.27159842848778, 56.2082938849926, 61.78563080728054, 60.37991523742676, 2.5384416757151484, 0.30020927370060235, 12.520407009869814, 67.74152621626854, 60.03221869468689, 60.32294489443302, 54.20105159282684, 21.543909162282944, 7.994438521564007, 6.890429612249136, 42.13280037045479, 77.68361672759056, 65.92697158455849, 14.335328321903944, 27.95450147241354, 34.87679712474346, 32.331401109695435, 45.40091000497341, 34.25629802048206, 38.89988824725151, 55.20735539495945, 68.6072413623333, 18.132248930633068, 0.6031544599682093, 0.10944645488052629, 0.1784778034198098, 0.08118115947581828, 0.05901839227590244, 0.05614334928395692, 0.3849063429515809, 0.13600380130810663, 0.13999358721775934, 0.10822139171068557, 0.24859340745024383, 0.26052138302475214, 0.20397119951667264, 0.1957052922807634, 0.265934489434585, 0.31892240862362087, 0.5073443823494017, 4.4306316040456295, 79.4642923772335, 68.69858086109161, 61.29633866250515, 55.55276446044445, 46.976647451519966, 44.74324889481068, 32.421372681856155, 42.71750919520855, 59.325000643730164, 42.65005141496658, 21.648768335580826, 8.51390104740858, 14.918707218021154, 51.7901835590601, 70.25506854057312, 59.45736274123192, 59.653945192694664, 65.26624023914337, 27.86441020667553, 1.307022396940738, 1.3898714887909591, 13.236439637839794, 54.666617810726166, 68.64587768912315, 74.02145683765411, 64.33644533157349, 60.15221245586872, 57.52579718828201, 56.33195824921131, 56.940826177597046, 53.86953838169575, 56.46290682256222, 63.07932458817959, 60.43278560042381, 56.161898374557495, 56.49469971656799, 53.438934087753296, 50.921379178762436, 53.73686470091343, 56.41148038208485, 60.28800576925278, 58.785904571413994, 58.55982430279255, 61.58662408590317, 62.41894282400608, 68.99283707141876, 63.52339155972004, 67.06711560487747, 61.32671803236008, 63.04166480898857, 55.75848162174225, 59.532803893089294, 48.12955878674984, 51.39184333384037, 42.79557980597019, 41.16232104599476, 43.15965726971626, 46.77157625555992, 18.2521153986454, 2.9321482870727777, 2.587557602673769, 2.308871056884527, 2.1840349305421114, 3.399237748235464, 10.142416711896658, 15.964191667735577, 14.58280049264431, 29.789747893810272, 38.08016963303089, 37.84286476671696, 32.560042440891266, 21.822567209601402, 9.410900864750147, 1.0120617994107306, 0.489317110623233, 1.5652202046476305, 1.602945055346936, 0.5008545087184757, 0.16069391160272062, 0.258505413075909, 0.18363997485721484, 0.2038950106361881, 4.388510389253497, 28.322724513709545, 37.06527069211006, 39.29377131164074, 29.163780882954597, 28.134028539061546, 28.935500532388687, 9.252059888094664, 4.999230243265629, 0.7369760947767645, 4.721015822142363, 7.012863792479038, 7.175038140267134, 19.015085957944393, 44.71551798284054, 48.449186235666275, 59.77095991373062, 53.00132676959038, 51.91466487944126, 52.31597274541855, 53.69098216295242, 52.271678522229195, 56.20358593761921, 55.68530894815922, 54.973401948809624, 56.105285212397575, 62.128049433231354, 63.292937725782394, 60.659644827246666, 51.83329224586487, 50.64847022294998, 50.54127037525177, 53.69716063141823, 54.37205761671066, 57.02033311128616, 57.12801173329353, 53.63192193210125, 48.12204658985138, 49.42729935050011, 55.01352779567242, 56.07059687376022, 58.06369252502918, 63.403823375701904, 59.19929958879948, 62.99327440559864, 64.75376933813095, 61.92789517343044, 59.841666519641876, 64.94801491498947, 60.506174862384796, 58.26421536505222, 62.79246658086777, 77.03146532177925, 13.849358148872852, 0.533134073484689, 12.239888962358236, 66.69980451464653, 63.032613694667816, 67.66298443078995, 59.95003290474415, 21.493658758699894, 11.895395647734404, 11.65437363088131, 50.25158911943436, 88.75663295388222, 82.14281424880028, 18.8494186475873, 27.952326089143753, 49.30956646800041, 41.991109773516655, 57.034772336483, 48.69230858981609, 53.81616644561291, 68.77284407615662, 84.36736688017845, 24.96737726032734, 0.875585472676903, 0.2570858033141121, 0.2709963225061074, 0.16212328802794218, 0.15425863035488874, 0.24002105259569362], [0.13566587178502232, 0.013063882688584272, 0.15009593887953088, 0.051503568174666725, 0.0716567256313283, 0.10901624671532772, 0.03206456829502713, 0.10499735377379693, 0.0918204549816437, 0.10683577973395586, 0.4987158766016364, 1.5009242109954357, 40.04909858107567, 56.18536591529846, 26.557939611375332, 32.5950575619936, 37.553734481334686, 23.261384703218937, 25.815117470920086, 17.97437310218811, 40.05350634455681, 37.519646510481834, 27.765663005411625, 5.893850913271308, 3.688799310475588, 26.427720598876476, 62.40768402814865, 55.22517263889313, 50.15609264373779, 59.410461857914925, 39.02051657438278, 1.6207608743570745, 0.08958146223449148, 6.8780954740941525, 45.4985685646534, 68.2185298204422, 64.00881171226501, 57.74732530117035, 53.406613022089005, 50.352663695812225, 49.305873066186905, 47.95160673558712, 52.030159682035446, 54.61195394396782, 62.372760102152824, 60.96391350030899, 57.034285962581635, 54.10174012184143, 53.83237637579441, 47.23343767225742, 45.37694089114666, 48.977924063801765, 51.96555934846401, 50.413110852241516, 51.81286074221134, 53.87247182428837, 50.83617255091667, 52.708240896463394, 54.60242785513401, 55.09817585349083, 53.356182128190994, 54.234881177544594, 48.90432961285114, 53.490573316812515, 50.614876225590706, 46.027192398905754, 33.33588480949402, 33.510386645793915, 39.546092972159386, 20.86294960230589, 1.5511265234090388, 0.5314081942196935, 0.3505545831285417, 0.7459572691004723, 0.007994022362254327, 1.2821604497730732, 3.7721281265839934, 3.1446787202730775, 3.052307339385152, 15.73290092870593, 13.284308519214392, 2.8092581313103437, 5.353634376078844, 1.8993286765180528, 0.1613131002523005, 0.12723434687359259, 0.03657241410110146, 0.26359072769992054, 0.24366035184357315, 0.4904704377986491, 0.0689224828965962, 0.059400572354206815, 0.19012092787306756, 0.16293067048536614, 0.19527266471413895, 2.596313995309174, 1.70640436001122, 7.650922704488039, 16.684961691498756, 7.212751116603613, 7.121359370648861, 2.978476113639772, 1.825831951573491, 0.7909654977265745, 0.6007121410220861, 1.1286643613129854, 0.6538097199518234, 5.935182245448232, 15.52150497213006, 45.5127228051424, 52.97062061727047, 49.29779849946499, 48.38348016142845, 45.21535836160183, 46.10960237681866, 49.27014738321304, 49.54996436834335, 50.18726237118244, 48.21169897913933, 50.96911981701851, 52.466163486242294, 56.198444813489914, 52.314194440841675, 49.3993404507637, 48.007710725069046, 46.90926946699619, 47.67909295856953, 45.2590674161911, 48.28242838382721, 50.25213249027729, 45.25495223701, 43.91638286411762, 44.456337690353394, 45.53493641316891, 50.42472302913666, 53.24274301528931, 52.48165525496006, 55.27664467692375, 54.48124475777149, 58.40006947517395, 57.754696905612946, 59.93843212723732, 57.565185874700546, 58.25003072619438, 56.51742249727249, 58.29236425459385, 9.140336383134127, 0.08222562100854702, 0.6355213606730103, 20.470054484903812, 49.516016989946365, 41.27240113914013, 54.296536669135094, 43.961190059781075, 39.83230501413345, 6.395412599667907, 3.6647086031734943, 30.111265741288662, 70.19731163978577, 89.55785036087036, 31.881410256028175, 18.22753831744194, 30.627384446561337, 32.44942657649517, 31.07217527925968, 25.659462623298168, 28.142541982233524, 45.24776682257652, 47.50040374696255, 10.90333728119731, 0.5731348239351064, 0.07684456053539179, 0.04437287228938658, 0.1482613498228602, 0.1319104412687011, 0.05624168385111261, 0.15834624617127702, 0.049326010412187316, 0.17262270353967324, 0.037111703131813556, 0.16429487150162458, 0.086903385235928, 0.017455689994676504, 0.10105099092470482, 0.14039338217116892, 0.14735472737811506, 0.4782168671954423, 3.0375764798372984, 51.33415102958679, 67.00206309556961, 31.252487003803253, 33.651989847421646, 49.14359137415886, 34.25079211592674, 30.49405910074711, 25.07771573960781, 54.53029252588749, 38.286456763744354, 31.737834960222244, 11.857118401676416, 3.9197870157659054, 28.12260065227747, 70.93829467892647, 59.44747947156429, 54.55254793167114, 66.74820631742477, 42.58709639310837, 2.4475016305223107, 0.16511411347892135, 6.355194132775068, 45.84664888679981, 71.89382940530777, 68.42426598072052, 59.972789883613586, 55.525079146027565, 52.00104184448719, 52.828071266412735, 49.30382877588272, 55.54698497056961, 57.8227474540472, 65.18526658415794, 64.05883222818375, 60.353115275502205, 55.82665756344795, 55.69883622229099, 48.69388930499554, 49.803843945264816, 50.900985673069954, 53.48110042512417, 51.503591537475586, 55.9757349640131, 58.167282566428185, 56.92388288676739, 55.87578892707825, 58.63247640430927, 59.655670300126076, 56.920261681079865, 56.68982304632664, 53.279631435871124, 54.383164420723915, 52.60412648320198, 47.37698256969452, 29.50686827301979, 42.192369773983955, 44.06798332929611, 21.19977492839098, 1.4353321306407452, 1.038940844591707, 0.6990248593501747, 0.6736355123575777, 0.6960620277095586, 1.5999233862385154, 6.900275833904743, 5.3979684971272945, 2.923231115564704, 18.017381094396114, 18.92571285367012, 3.177076019346714, 4.849534425884485, 1.5764680760912597, 0.24399740563239902, 0.17750213155522943, 0.27393142750952393, 0.7922294642776251, 0.28450014477130026, 0.3068770846584812, 0.03511725546559319, 0.042200817551929504, 0.23823577183065936, 0.1478717668214813, 0.13530861673643813, 2.6527516543865204, 0.8088918670546263, 9.804411549121141, 20.528155267238617, 6.512123811990023, 9.83937632292509, 5.404458548873663, 2.7758721727877855, 0.6928153987973928, 1.5077987546101213, 2.7628203481435776, 2.8312838869169354, 6.82253485545516, 20.779739767313004, 50.78488290309906, 54.38156470656395, 49.42254200577736, 48.758159056305885, 49.19354349374771, 48.521853536367416, 52.24804759025574, 52.69629053771496, 51.53107926249504, 52.87922792136669, 53.526770174503326, 52.64355316758156, 58.5493216663599, 55.458305329084396, 50.98316006362438, 49.95308093726635, 48.177618607878685, 51.195295080542564, 49.72334526479244, 51.26009300351143, 51.331665962934494, 46.691639944911, 46.69538274407387, 45.84548994898796, 49.65958468616009, 53.65827351808548, 56.919361129403114, 54.72626321017742, 56.9649700820446, 56.39396332204342, 59.34077359735966, 60.0931142270565, 62.89274699985981, 59.13407988846302, 60.66909112036228, 56.0280429571867, 46.059821248054504, 2.0695425616577268, 0.22366057033650577, 1.5966585301794112, 27.42813851684332, 56.133635491132736, 43.44588831067085, 58.63546684384346, 51.01959250867367, 47.6572897285223, 7.141681630164385, 5.426826998591423, 35.98661497235298, 66.79164558649063, 91.96277931332588, 28.764296919107437, 23.75482812523842, 36.79883658885956, 28.71094588190317, 35.11319763958454, 27.041093185544014, 35.084892958402634, 57.11258836090565, 58.884182497859, 13.419031240046024, 0.907966741360724, 0.09652636144892313, 0.009565969994582701, 0.09646202466683462, 0.13722396630328149, 0.09276403638068587, 0.3223351004999131, 0.2039507162407972, 0.2598050027154386, 0.12102810724172741, 0.3399272362003103, 0.27610161574557424, 0.15512673533521593, 0.4218802886316553, 0.48799341602716595, 0.3319899964844808, 0.7713833672460169, 6.00953190587461, 75.3943307697773, 77.47593507170677, 42.74368219077587, 45.12132100760937, 55.035376623272896, 37.54229709506035, 38.829155042767525, 24.74533997476101, 58.14438499510288, 44.68723230063915, 40.66973067820072, 11.669939495623112, 10.000198893249035, 35.15810742974281, 74.51784700155258, 63.674216866493225, 58.567093312740326, 71.22743636369705, 46.38492040336132, 2.3547987174242735, 0.40010609140153974, 8.51151667535305, 48.714639991521835, 76.38877540826797, 74.43163722753525, 65.75988695025444, 60.35790301859379, 55.50140641629696, 57.73311026394367, 53.23249876499176, 57.87108086049557, 57.039894461631775, 67.37571984529495, 64.02968019247055, 61.663634553551674, 57.33349710702896, 59.47387285530567, 50.08318215608597, 52.67425552010536, 53.23020748794079, 60.56477151811123, 53.954148441553116, 59.595815911889076, 61.26955009996891, 63.15224647521973, 58.71812000870705, 63.41264270246029, 61.00977323949337, 60.589971765875816, 57.97340176999569, 58.431733176112175, 55.107998326420784, 55.99029578268528, 48.8809684664011, 45.58416657149792, 44.194083362817764, 50.59844970703125, 35.15596054494381, 5.766014372929931, 1.6100160009227693, 3.210516362451017, 2.4701488902792335, 0.6684192235115916, 3.4547033719718456, 16.4405208081007, 18.109896630048752, 15.614109802991152, 34.386247247457504, 38.13565045595169, 24.80056621134281, 12.386256158351898, 4.870341159403324, 0.21379270765464753, 0.3003013593843207, 0.5241840693634003, 0.4961643135175109, 0.23050560615956783, 0.48590958409477025, 0.23033133504213765, 0.18750223011011258, 0.4756912199081853, 0.4563419456826523, 0.4513334285002202, 9.393562395125628, 25.95796700567007, 30.775245912373066, 27.22188178449869, 25.081236250698566, 33.09842795133591, 12.433165591210127, 5.495971888303757, 1.9010476092807949, 2.2121384600177407, 5.1218705624341965, 5.774482693523169, 10.361225120723248, 38.43041583895683, 54.60149310529232, 51.948642656207085, 55.134969279170036, 49.88963954150677, 52.09761746227741, 50.00142574310303, 56.10549420118332, 56.408007368445396, 54.36055563390255, 53.935179859399796, 55.76915144920349, 56.7026549577713, 63.97944688796997, 56.14398993551731, 54.53226462006569, 53.52284878492355, 51.888324692845345, 53.364097103476524, 52.93353080749512, 53.090530782938, 58.25318455696106, 50.28613306581974, 51.26456916332245, 48.77202831208706, 52.43157394230366, 56.93302899599075, 61.906810104846954, 58.33864577114582, 57.780524119734764, 60.55409789085388, 61.54310882091522, 61.76778316497803, 66.11747056245804, 63.24159488081932, 63.2268250733614, 55.24878457188606, 61.45412899553776, 12.302888631820679, 0.3325908095575869, 1.220554355531931, 27.06579376012087, 61.534665673971176, 50.08102387189865, 64.4330969452858, 56.833181753754616, 49.02036018669605, 12.059682682156563, 9.077128674834967, 38.725678995251656, 72.31827422976494, 100.5738240480423, 34.50337216258049, 25.2538837864995, 48.75221237540245, 38.436712101101875, 46.30600243806839, 31.939668729901314, 46.826597303152084, 67.16367602348328, 78.02104622125626, 20.945654064416885, 0.9214959153905511, 0.24045051861321554, 0.1811017852742225, 0.23356485762633383, 0.29764144273940474, 0.1832556165754795], [0.05420516383310314, 0.05256099873804487, 0.018519347177061718, 0.08727927561267279, 0.007587709033032297, 0.05079631257103756, 0.2301451747189276, 0.04829012439586222, 0.04663882726163138, 0.1258950523333624, 0.48799305979628116, 1.5418844693340361, 35.0810057669878, 45.048285126686096, 41.4228692650795, 42.871317341923714, 27.5578635558486, 20.96149541437626, 37.89190113544464, 24.983513094484806, 17.333868071436882, 35.55645525455475, 29.670595787465572, 15.12548927217722, 1.6275241551920772, 10.623933523893356, 58.99246908724308, 64.9836266040802, 58.28812748193741, 59.54934060573578, 45.459464862942696, 3.671541349031031, 0.07386491924989969, 3.4031171025708318, 35.962771251797676, 66.0395747423172, 65.4296162724495, 61.08030125498772, 55.7400032132864, 52.2142294049263, 53.51879060268402, 49.160755053162575, 53.82683627307415, 59.22399066388607, 62.25542239844799, 63.29983815550804, 58.7097642570734, 58.44013452529907, 51.678670942783356, 49.485052451491356, 46.48897401988506, 49.604358449578285, 52.028632164001465, 52.03726910054684, 51.63599543273449, 53.18766877055168, 50.454133450984955, 54.66818332672119, 56.017072945833206, 54.89848896861076, 51.66178844869137, 56.323309913277626, 54.732156693935394, 47.31876589357853, 47.28592425584793, 35.62243111431599, 23.928273618221283, 44.83668968081474, 26.939549334347248, 4.676942937076092, 0.7903393625747412, 0.14705343026435003, 0.09472589634242468, 0.3871513099875301, 0.5614535976201296, 0.5417368118651211, 1.9891037279739976, 3.00859899725765, 1.2540021794848144, 4.5168323535472155, 3.5697906464338303, 1.572762206196785, 0.5535996565595269, 0.06081502047891263, 0.07231924828374758, 0.046649395444546826, 0.007495159043173771, 0.7006006466690451, 0.9499023598618805, 0.08292726226500235, 0.11217095321626402, 0.057465956633677706, 0.1447553699836135, 0.20179122977424413, 0.07034663460217416, 0.5164213827811182, 1.0833690105937421, 0.8205114654265344, 4.318654462695122, 2.079378333874047, 1.468008121009916, 0.47146177967078984, 0.39123134105466306, 0.17881999287055805, 0.5593955924268812, 0.7161811168771237, 1.5051055303774774, 5.081926630809903, 9.029092602431774, 32.330097779631615, 54.31840069591999, 48.74117776751518, 51.46557837724686, 47.25949287414551, 52.473436295986176, 47.02040210366249, 49.554151743650436, 49.371970519423485, 51.231320947408676, 48.96285027265549, 51.71907037496567, 53.531398326158524, 52.307316809892654, 50.67047484219074, 48.923248797655106, 48.5757802426815, 51.84577077627182, 48.562344163656235, 51.00891128182411, 46.8501066416502, 46.62131331861019, 46.74940064549446, 45.93585290014744, 48.53055126965046, 49.848613142967224, 52.724105045199394, 51.9239591807127, 53.97397577762604, 58.68302509188652, 56.82376205921173, 61.316272392868996, 64.16569009423256, 64.35738980770111, 59.863644540309906, 47.288732305169106, 5.632446790114045, 0.16590110171819106, 0.8172543870750815, 1.2730731186456978, 44.80108559131622, 27.92789150029421, 45.19439108669758, 57.343995943665504, 56.310018226504326, 45.30077397823334, 2.804513848386705, 6.963219456374645, 30.330234691500664, 67.9414714872837, 77.65204802155495, 34.30731028318405, 25.50969745963812, 25.386813953518867, 34.15931962430477, 37.36562937498093, 29.627397805452347, 30.119100920856, 50.69692142307758, 43.198445588350296, 6.504876650869846, 0.3722106304485351, 0.06417503842385486, 0.02130057713657152, 0.03149635776935611, 0.08689143665833399, 0.01861099684902001, 0.06124733634351287, 0.01638986388570629, 0.07690046651987359, 0.030855513250571676, 0.03695360712299589, 0.02764837958238786, 0.05674491563695483, 0.06271258447668515, 0.03602796343329828, 0.2268546403502114, 0.5698895605746657, 2.400311012752354, 51.65518820285797, 53.53701442480087, 44.65235777199268, 42.77927488088608, 32.392783015966415, 29.873890578746796, 37.362840324640274, 26.873655170202255, 28.12292743474245, 39.97586891055107, 28.981153182685375, 20.521756410598755, 4.007736621424556, 9.77609546855092, 62.99609765410423, 68.86534631252289, 60.99277675151825, 64.23027902841568, 51.55146896839142, 5.0989568419754505, 0.07104612363036722, 3.562990198843181, 36.274631917476654, 66.6144534945488, 67.36283093690872, 62.403416857123375, 58.07994045317173, 53.80926601588726, 55.48157908022404, 50.49681656062603, 55.547649934887886, 63.02722938358784, 64.4666263461113, 67.18198344111443, 61.69396832585335, 58.83421517908573, 55.804166570305824, 51.84158720076084, 49.757433235645294, 52.01532907783985, 54.26980510354042, 54.985724687576294, 56.23021490871906, 56.18653625249863, 54.06935065984726, 58.51504750549793, 58.39447617530823, 56.03800602257252, 53.135767355561256, 58.025759160518646, 58.06493505835533, 50.23244954645634, 51.639996618032455, 38.381881043314934, 31.763544380664825, 50.24061530828476, 28.074924610555172, 3.2526238029822707, 0.9395740984473377, 1.6274683456867933, 0.9601202490739524, 0.8878198068123311, 0.5242950946558267, 0.4274336312664673, 4.066866673529148, 8.075301982462406, 3.4977446123957634, 6.27784738317132, 2.800094448029995, 0.9056870418135077, 0.21549376950133592, 0.29030154284555465, 0.12956332502653822, 0.025085725101234857, 0.004908189021080034, 0.6100922939367592, 0.35135524172801524, 0.23897373379440978, 0.13570035196607932, 0.09496083803242072, 0.06539400856127031, 0.13105333491694182, 0.13847362424712628, 0.6990682007744908, 1.134934974834323, 1.3479605689644814, 8.045111652463675, 6.229094574227929, 4.1535647213459015, 0.9441350412089378, 1.1595802148804069, 0.5951657448895276, 0.4043801792431623, 1.137649454176426, 3.2472772523760796, 8.866835609078407, 12.096686996519566, 39.51230138540268, 55.03533102571964, 51.983311995863914, 52.20400035381317, 50.756194442510605, 54.41824793815613, 51.7141268402338, 52.291787043213844, 53.03866736590862, 51.49333208799362, 53.142850175499916, 54.22935627400875, 56.625906676054, 53.58972139656544, 53.78928668797016, 50.091078132390976, 50.442437678575516, 53.74028831720352, 52.1373101323843, 50.8926223218441, 51.04223549365997, 48.24438862502575, 50.45032225549221, 48.224549889564514, 49.8864933103323, 52.31023125350475, 55.63889443874359, 56.07007250189781, 56.86511904001236, 61.542029678821564, 59.0219859033823, 64.0475544333458, 67.14840844273567, 67.0196333527565, 60.35569913685322, 40.495890006423, 4.007072607055306, 0.17503869108622894, 1.7596367723308504, 2.646950790658593, 48.91412928700447, 29.62922740727663, 51.87654912471771, 59.35664154589176, 63.59455794095993, 44.118828400969505, 2.872435678727925, 13.468878865242004, 35.83243444561958, 64.66726318001747, 79.0717202425003, 36.530988961458206, 27.51033190637827, 34.037091583013535, 30.31421285122633, 42.03407406806946, 24.978905841708183, 37.01218754053116, 60.298413410782814, 53.866844326257706, 8.264610674232244, 0.4228479304583743, 0.040981981001095846, 0.05430177290691063, 0.0017748008281159855, 0.04720122306025587, 0.027710823887900915, 0.13012033654376864, 0.12274250548216514, 0.13221219851402566, 0.14998369646491483, 0.1067439909093082, 0.13170741935027763, 0.29917115753050894, 0.24575681512942538, 0.17222859343746677, 0.2838496374897659, 0.7517753506544977, 4.37050030566752, 68.48385438323021, 66.72838658094406, 57.578682750463486, 60.35092659294605, 38.91477584838867, 30.390757843852043, 53.73180337250233, 32.27037638425827, 29.398969262838364, 46.405804082751274, 39.760694056749344, 24.07407559454441, 6.337298043072224, 15.893043335527182, 72.35140085220337, 73.01115944981575, 67.48866498470306, 71.92040517926216, 56.14933244884014, 5.4244606755673885, 0.2980971214128658, 5.244534155353904, 42.61337958276272, 70.72323381900787, 69.0952567756176, 63.66998389363289, 62.663520500063896, 55.10319918394089, 60.27200862765312, 54.11540798842907, 59.03277352452278, 65.53958237171173, 66.68824553489685, 68.57986763119698, 63.63154515624046, 60.87286278605461, 57.096712812781334, 53.03140975534916, 51.186042577028275, 56.129030138254166, 56.789104118943214, 58.77844177186489, 57.610323652625084, 61.42617769539356, 56.26869544386864, 64.58748266100883, 62.24846877157688, 60.69124773144722, 57.348901480436325, 63.2712484896183, 61.31523124873638, 52.93244406580925, 52.48813770711422, 44.49622794985771, 51.21732249855995, 49.91480939090252, 39.449836537241936, 14.268444310873747, 1.4544020011089742, 1.6879179957322776, 1.5794629091396928, 1.6055759391747415, 1.0014123958535492, 1.3384007569402456, 7.528022099286318, 20.53529128432274, 11.336324997246265, 15.36367379128933, 11.84981994330883, 2.8096924955025315, 2.174765090458095, 0.585862003499642, 0.22077683679526672, 0.1785029622260481, 0.10700486323912628, 1.349590562749654, 0.8318808116018772, 0.33742542669642717, 0.19820782908936962, 0.17455598339438438, 0.1598456219653599, 0.2086865683668293, 0.23888222698587924, 2.1273600216954947, 5.78452080488205, 14.928310252726078, 18.754691630601883, 19.37430538237095, 21.148054003715515, 4.390700971707702, 1.8419674295000732, 0.9127439162693918, 2.9810727993026376, 4.156620232388377, 5.928851310163736, 10.953513588756323, 23.52221980690956, 55.310124680399895, 54.83467519283295, 53.34216848015785, 51.69511266052723, 52.63206258416176, 56.24015897512436, 54.162096083164215, 54.82487551867962, 55.89747816324234, 53.88236649334431, 54.86075319349766, 56.64370112121105, 59.16114203631878, 57.3133809864521, 56.907657757401466, 53.014470264315605, 56.57290332019329, 56.50761142373085, 54.42607171833515, 56.18718221783638, 53.13836261630058, 52.39716678857803, 52.95790649950504, 51.75680235028267, 55.49649327993393, 57.108495980501175, 58.98203864693642, 59.561849534511566, 57.12688319385052, 66.31987810134888, 60.60047060251236, 66.63662910461426, 71.28711596131325, 68.7935833632946, 61.79566226899624, 49.49650123715401, 8.199447970837355, 0.2791749086463824, 2.1382286259904504, 2.6010504411533475, 50.12437954545021, 37.996273934841156, 56.506714671850204, 66.78881853818893, 67.13358923792839, 55.8652026951313, 7.644131518900394, 10.92155635356903, 38.683976233005524, 68.68800222873688, 90.75161710381508, 37.592621594667435, 33.14274497330189, 44.65097464621067, 42.23757594823837, 56.210554763674736, 39.376929849386215, 50.055276453495026, 69.71997365355492, 75.31708851456642, 13.208735324442387, 0.5644901690538973, 0.1779001601971686, 0.18536249961471185, 0.13975077134091407, 0.20475498167797923, 0.11852496187202632], [0.15851906267926097, 0.038535635903826915, 0.03088619178015506, 0.0930070823233109, 0.055194123851833865, 0.026055194466607645, 0.06283439317485318, 0.08408530949964188, 0.07332938548643142, 0.018575748545117676, 0.37773173418827355, 0.6456257309764624, 32.967844158411026, 52.07434371113777, 32.944931387901306, 39.62273485958576, 47.11451545357704, 22.753217071294785, 33.87976102530956, 36.485497802495956, 25.713452026247978, 38.539109006524086, 40.14835685491562, 15.181429870426655, 6.707102274522185, 7.800779538229108, 42.282177954912186, 55.81981033086777, 60.74818007647991, 56.90513089299202, 52.34183795750141, 6.62698594853282, 0.07596008377731778, 1.6310235299170017, 24.692821092903614, 65.11493995785713, 67.93944239616394, 62.01312080025673, 59.261992424726486, 54.32105675339699, 50.438406094908714, 49.034237042069435, 57.45063342154026, 59.6530332416296, 64.73610028624535, 60.83576537668705, 60.17230197787285, 57.101679146289825, 56.62293143570423, 52.28323370218277, 47.69691780209541, 48.123779296875, 52.83512368798256, 55.262403041124344, 52.52300463616848, 53.17155383527279, 53.114070519804955, 56.08408235013485, 54.779809936881065, 52.85117022693157, 51.600661128759384, 50.46645238995552, 45.956816375255585, 49.618866071105, 41.20383761823177, 28.92071172595024, 49.935738667845726, 43.77149663865566, 15.546891409903765, 0.5866600200533867, 0.20132162841036916, 1.0747738718055189, 0.541433421894908, 0.27304607501719147, 0.03648607635113876, 0.3437635162845254, 0.5604502733331174, 0.8282270701602101, 0.7570711383596063, 0.9702761541120708, 0.11221001244848594, 0.34665590326767415, 0.14738045021658763, 0.022785121109336615, 0.03899892159097362, 0.06857062326162122, 0.04373257324914448, 0.46655778656713665, 0.2884379803435877, 0.03128628173726611, 0.08850162994349375, 0.0737206828489434, 0.021190820916672237, 0.08961484403698705, 0.039706321913399734, 0.15415596164530143, 0.14553251734469086, 0.7176193397026509, 1.6327973222360015, 0.6914939603302628, 0.2972085034707561, 0.032089074011310004, 0.03378186091140378, 0.17807808268116787, 0.7225536718033254, 1.4371898747049272, 1.828441817779094, 4.120773430913687, 9.147171266376972, 19.576245546340942, 50.38544453680515, 53.3536172658205, 49.74321819841862, 47.579583898186684, 41.67003080248833, 46.24669902026653, 46.47953152656555, 51.839060336351395, 50.64509600400925, 49.56915333867073, 49.822725132107735, 53.21360617876053, 51.39625869691372, 51.78430147469044, 47.71756209433079, 47.29225091636181, 45.948464423418045, 49.23790231347084, 48.04250165820122, 50.024061128497124, 45.99580228328705, 46.64263777434826, 44.0224389731884, 44.44020375609398, 47.79561370611191, 49.38031107187271, 50.206911116838455, 53.567465990781784, 55.71914613246918, 60.60361683368683, 58.873296082019806, 58.51072333753109, 58.79833370447159, 49.67840127646923, 14.855436813086271, 1.2171983043663204, 0.15317289798986167, 0.1546543583390303, 4.016528399661183, 38.09908501803875, 69.97899815440178, 60.541778951883316, 50.075153186917305, 56.11348517239094, 19.303102903068066, 1.5333688887767494, 15.280441157519817, 31.146808974444866, 69.522475451231, 66.91100478172302, 33.33754152059555, 25.72722628712654, 25.762224309146404, 34.6994112432003, 35.41376531124115, 25.603060349822044, 29.177885726094246, 47.23553515970707, 22.312999293208122, 2.3849933221936226, 0.01456410638638772, 0.023489925770263653, 0.08103438492980786, 0.010166329429921461, 0.03678639011923224, 0.028026168001815677, 0.03692989550472703, 0.02609402177768061, 0.0240841578488471, 0.027274203566776123, 0.08026428055018187, 0.028118053305661306, 0.04161492906860076, 0.07666851568501443, 0.12071508419467136, 0.07162270558183081, 0.40607132599689066, 1.0087559767998755, 46.952549144625664, 64.2009750008583, 38.31668794155121, 37.43611939251423, 51.06031492352486, 28.161337673664093, 37.476427629590034, 34.30457063019276, 34.2005056142807, 44.857778549194336, 43.219994232058525, 17.68615286797285, 9.470489267259836, 12.141522690653801, 44.369018375873566, 63.66033621132374, 67.93045207858086, 61.138464733958244, 56.94886274635792, 8.684038817882538, 0.20702170848380774, 2.1903941268101335, 27.025308832526207, 66.74872308969498, 72.69316971302032, 63.54061983525753, 60.502633452415466, 56.37582689523697, 52.841492146253586, 51.99140556156635, 59.908174350857735, 64.20507878065109, 65.45837312936783, 61.66955463588238, 60.71087747812271, 58.61591309309006, 59.36224244534969, 54.809942319989204, 50.56098751723766, 49.45184983313084, 53.981347382068634, 57.721099108457565, 56.2962781637907, 55.540384724736214, 55.72089783847332, 59.17481750249863, 57.67161436378956, 55.20673602819443, 54.21504624187946, 50.74555121362209, 46.80771991610527, 52.7125346660614, 39.613664746284485, 40.289519280195236, 57.35889874398708, 45.82541182637215, 16.30719356238842, 0.3445226146141067, 0.5859180504921824, 0.8656529244035482, 0.9828025382012129, 0.8073365036398172, 0.06502941367216408, 0.47490169352386147, 0.31447468791157007, 1.1330621503293514, 0.8736185438465327, 0.6445091252680868, 1.0336316982284188, 0.33307905367109925, 0.2710188244236633, 0.17281266365898773, 0.04844430186494719, 0.07512197640608065, 0.1472047096467577, 0.14013009786140174, 1.2342006107792258, 0.011414727578085149, 0.05011613422539085, 0.10697943725972436, 0.06115851239883341, 0.05450066106277518, 0.04281439927581232, 0.18845260958187282, 0.21230061975074932, 0.3391554916743189, 0.5709923920221627, 0.6468345411121845, 0.45268529502209276, 0.09365467296447605, 0.010519595434743678, 0.1540467917220667, 1.2409215001389384, 2.7610954781994224, 6.29112197086215, 9.134738333523273, 10.956969503313303, 25.3013052418828, 56.25100739300251, 53.249943628907204, 51.39176733791828, 50.1860274374485, 41.49237513542175, 48.79331856966019, 50.34127190709114, 50.84371514618397, 52.12549276649952, 50.774186477065086, 52.27499194443226, 55.66805027425289, 53.39838266372681, 54.07627008855343, 50.465616434812546, 49.350703060626984, 48.65474000573158, 52.891030088067055, 51.76007777452469, 53.458879217505455, 50.6282477080822, 49.328109472990036, 45.90907193720341, 47.20642112195492, 49.393777549266815, 53.4203264862299, 53.3920294046402, 54.579176902770996, 58.29218186438084, 64.51544612646103, 62.489159256219864, 60.99878042936325, 60.834355652332306, 50.0164957344532, 15.593762844800949, 0.8085972047410905, 0.1478589721955359, 0.31369160336907953, 4.422712828963995, 42.77708999812603, 68.68968173861504, 64.69114869832993, 53.26318971812725, 62.62022942304611, 18.267088495194912, 2.828960311599076, 18.13962433487177, 32.15948313474655, 67.75699898600578, 72.40704506635666, 39.75284747779369, 29.332356937229633, 33.310251384973526, 26.489151902496815, 39.035662561655045, 31.177954003214836, 37.876819744706154, 61.475658640265465, 32.762237191200256, 3.665138455107808, 0.10890627527260222, 0.03961100046581123, 0.10881957015953958, 0.04015231927041896, 0.016678670654073358, 0.05136834144650493, 0.21605560497846454, 0.08724808314582333, 0.14029469137312844, 0.1495458887075074, 0.16189771966310218, 0.13222778361523524, 0.19778752117417753, 0.27260642673354596, 0.4064976453082636, 0.41642392985522747, 0.6468914786819369, 2.661488098092377, 65.98116427659988, 73.98943215608597, 50.02673238515854, 50.99044427275658, 60.731992945075035, 30.958078801631927, 47.580286860466, 46.58432610332966, 38.766572400927544, 46.698148995637894, 52.86863029003143, 23.467056266963482, 13.586151022464037, 12.30029622092843, 50.465563237667084, 67.287268191576, 72.68370062112808, 67.98864975571632, 62.05804578959942, 9.412320088595152, 0.39928702753968537, 3.8393631437793374, 32.2463084757328, 69.95837286114693, 76.02716401219368, 68.80715623497963, 64.92738962173462, 59.38066765666008, 55.60051269829273, 55.472417771816254, 63.7960459291935, 63.522555604577065, 68.95372956991196, 65.7524773478508, 65.56027606129646, 61.68494760990143, 59.752473905682564, 59.573974683880806, 53.92941176891327, 54.47929546236992, 56.081247702240944, 62.189929112792015, 58.48396137356758, 62.827827483415604, 60.17641715705395, 64.540805965662, 61.89072176814079, 60.54571554064751, 54.315129071474075, 57.50940106809139, 49.615051075816154, 55.83883211016655, 47.776086553931236, 51.34690314531326, 55.72711430490017, 50.23783765733242, 27.245972491800785, 3.6890983069315553, 0.5785193725023419, 2.8110300237312913, 2.0827651396393776, 0.9331335034221411, 0.1239018292108085, 0.8514642482623458, 0.9859364794101566, 5.157226715236902, 5.496308645233512, 4.424392813816667, 2.639555912464857, 1.2985524139367044, 0.4082011117134243, 0.4835892148548737, 0.10744969171355478, 0.22902088036062196, 0.21673849958460778, 1.3823906402103603, 1.7641725414432585, 0.07389278689515777, 0.20204646920319647, 0.1956414824235253, 0.17704002588288859, 0.23700342077063397, 0.10066045797429979, 0.39158436586149037, 0.9991259872913361, 2.7398277819156647, 4.52352236956358, 3.5480230394750834, 2.405646163970232, 0.1592385451658629, 0.10644581823726185, 0.3380601410754025, 2.276437897235155, 4.872765904292464, 9.69502966850996, 13.778500501066446, 16.402038373053074, 46.701306626200676, 60.6426939368248, 52.76336833834648, 53.162700310349464, 51.15500204265118, 46.09701365232468, 51.30898877978325, 53.08130867779255, 55.11103816330433, 57.51835338771343, 54.72669258713722, 55.55334582924843, 60.940430760383606, 57.63540230691433, 55.94894640147686, 53.30366514623165, 55.102709010243416, 54.444550126791, 56.94564051926136, 55.72275593876839, 57.04976253211498, 54.273787289857864, 52.409611120820045, 49.51380170881748, 51.92533850669861, 52.21145175397396, 55.89960224926472, 56.2873562425375, 58.81588876247406, 63.848703503608704, 67.92015463113785, 65.59578135609627, 65.09096324443817, 66.34633228182793, 56.07419528067112, 19.63916826993227, 2.163416761904955, 0.2705338457599282, 0.6359914073254913, 6.335356347262859, 49.664813205599785, 79.9114827811718, 70.8349022269249, 57.385235130786896, 66.70414388179779, 27.315972335636616, 4.108028914779425, 20.70506427437067, 35.83068273961544, 68.76512289047241, 77.18933165073395, 38.380364924669266, 36.8375451117754, 44.56629619002342, 43.06136414408684, 53.74332815408707, 37.209526151418686, 48.53296414017677, 70.05872547626495, 54.36007305979729, 6.447445107623935, 0.280431691207923, 0.07323686935706064, 0.26606748229824007, 0.1499169328599237, 0.15112428838619962, 0.11617616837611422], [0.11472774102003314, 0.04994532522687223, 0.18272048357175663, 0.0582032172678737, 0.019084130835835822, 0.09917835195665248, 0.07181464723544195, 0.013800053293380188, 0.19107196043478325, 0.03742255539691541, 0.3461917641106993, 0.4029708111193031, 31.728546358644962, 56.487111523747444, 30.236611515283585, 39.62514393031597, 37.07403302192688, 26.84560127556324, 35.90506374835968, 33.30678217113018, 25.80174218863249, 41.24652832746506, 52.37135097384453, 17.432923056185246, 2.8890258260071278, 19.921118840575218, 60.34191347658634, 57.69757077097893, 55.79950802028179, 60.89424043893814, 44.732905849814415, 12.219212371855974, 0.2668200497282669, 0.795327426167205, 17.122990787029266, 58.69323134422302, 71.09822049736977, 63.07155780494213, 61.21773228049278, 54.608313739299774, 49.86929163336754, 49.71416495740414, 57.768433168530464, 60.521309450268745, 61.100690960884094, 60.37429913878441, 61.643328443169594, 61.86500854790211, 57.92842738330364, 50.61888501048088, 45.850509479641914, 46.59707821905613, 54.29060898721218, 54.94658678770065, 55.72861522436142, 53.788165748119354, 53.281991109251976, 54.60496611893177, 54.84669774770737, 53.42362090945244, 48.83506312966347, 44.98696781694889, 53.95195595920086, 47.82171070575714, 40.70425182580948, 62.908470556139946, 59.19488422572613, 22.2664175927639, 7.238736497238278, 0.5835719138849527, 0.2730624913237989, 0.23538896755781025, 0.1086996984668076, 0.07530188784585334, 0.06241628201678395, 0.08108157810056582, 0.07736398969427682, 0.08903712659957819, 0.2304742726846598, 0.2814039937220514, 0.14236609975341707, 0.2087540295906365, 0.1437972573330626, 0.06903580884682015, 0.01726208964100806, 0.01723531480820384, 0.05382357747294009, 0.22103197232354432, 0.7057141629047692, 0.21013243531342596, 0.07370599574642256, 0.08669808492413722, 0.11061449884437025, 0.13740188878728077, 0.05631147912936285, 0.08888929820386693, 0.14186978107318282, 0.2230368397431448, 0.1727786287665367, 0.11577154946280643, 0.044826677039964125, 0.02501757553545758, 0.09822219115449116, 0.04446663151611574, 0.46204282727558166, 2.0367455715313554, 2.1030959486961365, 5.252100974321365, 9.905788209289312, 11.645151525735855, 42.7632587403059, 52.56524316966534, 48.58004741370678, 48.568526431918144, 42.49058537185192, 40.79712264239788, 53.99707093834877, 46.50672286748886, 48.690955862402916, 53.052285835146904, 50.704433619976044, 52.681022956967354, 52.87595249712467, 50.52247658371925, 47.92058899998665, 48.36142614483833, 47.5351794809103, 48.97198498249054, 48.679275289177895, 46.60534277558327, 46.151806712150574, 46.30342237651348, 44.87451285123825, 44.08994995057583, 47.17948816716671, 51.43921919167042, 48.47277916967869, 55.58557190001011, 52.766655161976814, 57.618360221385956, 54.23753723502159, 59.09926615655422, 50.53916908800602, 36.384848803281784, 10.626035761088133, 0.21113377064466476, 0.4568000289145857, 1.826153271831572, 5.163798937574029, 52.66824424266815, 43.51708509027958, 43.334618881344795, 55.83114892244339, 52.885919362306595, 12.142224702984095, 2.7700967201963067, 18.91782257705927, 36.089589446783066, 62.86892607808113, 58.4988147765398, 33.028428107500076, 26.32894489914179, 20.01633983105421, 33.67536239326, 33.24972443282604, 24.35081474483013, 34.785225838422775, 53.865453600883484, 17.441276907920837, 1.3980632554739714, 0.02102201757224975, 0.08061852990067564, 0.1727038944954984, 0.03777362093387637, 0.13033521798206493, 0.05667983670718968, 0.09278267170884646, 0.03196497949829791, 0.0559570479526883, 0.015141464809858007, 0.03619352173700463, 0.030430906444962602, 0.09529364673653618, 0.058702259630081244, 0.21133484813617542, 0.056175254212575965, 0.4458206961862743, 0.6521230260841548, 43.36947061121464, 65.02649590373039, 36.93484649062157, 41.358424723148346, 41.10365979373455, 34.15219500660896, 37.636923417449, 31.445816829800606, 28.759967051446438, 50.29082581400871, 57.60044418275356, 23.986921571195126, 4.691680921241641, 19.445219077169895, 68.32522809505463, 59.58797313272953, 59.64304357767105, 63.490964099764824, 48.68403643369675, 16.40925418585539, 0.5222789465915412, 0.823150483192876, 17.779240272939205, 59.17525827884674, 71.68661132454872, 65.79022452235222, 62.56835080683231, 57.32434339821339, 51.70705921947956, 54.45021942257881, 62.2520861774683, 62.30322763323784, 63.98754045367241, 60.62997221946716, 61.49217255413532, 64.5725266635418, 60.57733744382858, 53.756593242287636, 47.94465310871601, 49.98787187039852, 57.79785878956318, 59.46908511221409, 60.62643460929394, 56.99908845126629, 57.14214317500591, 56.975905895233154, 56.05337239801884, 55.31625755131245, 50.347484573721886, 48.732837215065956, 57.42549017071724, 53.45244616270065, 52.51169644296169, 77.8809705376625, 52.569460943341255, 31.156445257365704, 8.748627752065659, 0.7193804858252406, 0.24160798697266728, 0.452895411872305, 0.6524922593962401, 0.23463274876121432, 0.04502572104684077, 0.040300273831235245, 0.0533236816409044, 0.03306002952740528, 0.2793870441382751, 0.20711983524961397, 0.09500009764451534, 0.250215504784137, 0.01654157371376641, 0.18008824903517962, 0.15301721025025472, 0.07118034103768878, 0.07502372347516939, 0.3124564024619758, 1.0017001116648316, 0.07380181443295442, 0.047937340787029825, 0.024895009846659377, 0.036298379782238044, 0.09734332503285259, 0.01671908059506677, 0.02815938350977376, 0.08246880053775385, 0.17520847963169217, 0.14687997550936416, 0.057880023086909205, 0.06898749503307045, 0.11338226438965648, 0.13048617081949487, 0.07290540394023992, 0.44368099537678063, 2.415820355527103, 5.0719626154750586, 9.924683645367622, 14.29088020697236, 16.334312707185745, 53.31642486155033, 53.8258521258831, 53.83928440511227, 50.58060586452484, 48.4327445179224, 42.55928188562393, 53.68801072239876, 48.48480172455311, 48.28012190759182, 56.20594181120396, 53.56577508151531, 55.80662503838539, 54.954212978482246, 54.87247936427593, 49.95593078434467, 50.03638006746769, 48.83607767522335, 51.822956800460815, 51.98740057647228, 50.72581887245178, 50.002409890294075, 49.84808497130871, 47.520166486501694, 49.09081980586052, 50.059813410043716, 54.06319119036198, 50.63015520572662, 57.210790291428566, 56.534430384635925, 60.512159541249275, 60.52192501723766, 61.33630111813545, 55.851314440369606, 40.55661454796791, 11.85363968834281, 0.43135344749316573, 0.24329747131559998, 0.8931190380826592, 7.63036010786891, 59.48391951620579, 43.36509704589844, 47.44082294404507, 61.10891751945019, 58.835127130150795, 12.21377581357956, 4.093224909156561, 21.023487187922, 34.51798997819424, 58.50916542112827, 59.91152957081795, 36.94828636944294, 25.143997482955456, 30.05808189511299, 23.83247885853052, 39.89530183374882, 27.602993734180927, 37.12591543793678, 66.07243537902832, 27.624238394200802, 1.6289157117716968, 0.18260012206155807, 0.09270333612221293, 0.21635863871779293, 0.06802924879593775, 0.06961457271245308, 0.05128216325829271, 0.29095629521179944, 0.16595014283666387, 0.39740936423186213, 0.08076247686403804, 0.09646820675698109, 0.22485527966637164, 0.1830924628302455, 0.1912945305230096, 0.33837632567156106, 0.20722527959151193, 0.5536709621082991, 1.7967288382351398, 61.06392793357372, 78.3279101550579, 47.30936899781227, 55.431463569402695, 47.31420233845711, 40.420376658439636, 50.87280638515949, 40.11127844452858, 38.1922560185194, 50.40432572364807, 67.30593279004097, 26.53392869979143, 7.9788099601864815, 24.310498908162117, 72.15364426374435, 67.71538361907005, 68.52135077118874, 71.44416153430939, 55.63832826912403, 16.621083319187164, 0.8118634263519198, 1.986274067312479, 22.62047879397869, 63.40250484645367, 72.98072308301926, 69.81543213129044, 66.94909393787384, 59.20254461467266, 55.20283363759518, 56.0448494553566, 64.66635122895241, 67.32171714305878, 68.48869532346725, 64.42873477935791, 64.19924229383469, 67.8874459862709, 63.337965309619904, 58.0213475972414, 49.81836296617985, 52.60819226503372, 60.36624737083912, 63.64871643483639, 62.676648795604706, 59.12853218615055, 58.9335760474205, 60.800499469041824, 58.87752145528793, 56.57722368836403, 53.90390373766422, 51.90798103809357, 53.0485962331295, 63.80176082253456, 52.29358434677124, 69.96524289250374, 51.82006515562534, 42.154440209269524, 13.4974305331707, 1.4055804396048188, 0.6515734212007374, 2.578144557774067, 1.0649961652234197, 0.473463351954706, 0.22798185877036303, 0.11522184067871422, 0.23393095907522365, 0.5623308755457401, 1.8825295404531062, 0.3753961360780522, 0.2142748364713043, 0.35415643360465765, 0.17033262876793742, 0.24568680091761053, 0.30125124903861433, 0.3355656046187505, 0.2917557366890833, 0.46107669943012297, 2.0122950710356236, 0.47127452096901834, 0.2221159532200545, 0.12010763632133603, 0.15736065921373665, 0.2005652166553773, 0.11262427186011337, 0.17075393116101623, 0.1944632042432204, 0.24155974737368524, 0.26283637911546975, 0.40663883148226887, 0.14165476604830474, 0.2688321011373773, 0.19891772302798927, 0.18027783808065578, 1.6105510597117245, 3.309493688866496, 8.497900106012821, 14.802405908703804, 17.744177654385567, 30.214485302567482, 60.208856016397476, 50.626275613904, 55.73224402964115, 50.379855036735535, 51.71200655400753, 48.61619487404823, 57.67588533461094, 52.12323948740959, 53.69382821023464, 60.23313291370869, 58.47560562193394, 57.85647064447403, 58.44509705901146, 56.83394931256771, 54.530630707740784, 52.93870232999325, 52.03780487179756, 53.607899621129036, 55.06221458315849, 53.488840609788895, 52.274345979094505, 51.79742597043514, 51.315931007266045, 49.3118691444397, 52.53327548503876, 58.5590947419405, 54.147071689367294, 59.79711011052132, 57.33788587152958, 65.56660652160645, 61.21572978794575, 64.0035679936409, 59.02011640369892, 44.43946659564972, 16.044145077466965, 1.0267125070095062, 0.7713051151949912, 3.9778072899207473, 7.724853912368417, 62.512030228972435, 50.29569715261459, 51.448220908641815, 64.67314526438713, 64.72458690404892, 17.588285319507122, 6.650941288098693, 25.0551525503397, 43.03999789059162, 65.40623232722282, 70.58384969830513, 37.49210938811302, 35.349199175834656, 34.81931380927563, 44.021671414375305, 50.778130665421486, 35.12932777404785, 48.22681076824665, 79.7265163064003, 43.29640053212643, 2.800271138548851, 0.3863651677966118, 0.25484217214398086, 0.4727780231041834, 0.17335691023617983, 0.23385753098409623, 0.14831951935775578], [0.12414005119353533, 0.09374035391374491, 0.07419360161293298, 0.08122173268930055, 0.08213435910874978, 0.1178652593807783, 0.08239589195000008, 0.00781826973252464, 0.03321704571135342, 0.03803661951678805, 0.33165858301799744, 0.38656156975775957, 24.863751120865345, 52.96334780752659, 25.68722203373909, 27.13630847632885, 35.50876781344414, 25.88593427091837, 42.18513876199722, 35.080941170454025, 28.58578059822321, 39.04169663786888, 56.79825022816658, 37.37620420753956, 5.324014965444803, 6.628425121307373, 51.083972454071045, 65.79145565629005, 56.34577430784702, 56.61679856479168, 55.24471119046211, 18.591617681086063, 0.605741289909929, 0.5967132118530571, 10.647666100412607, 54.79378938674927, 71.17265850305557, 62.62286268174648, 62.9525063931942, 55.60989059507847, 49.53295648097992, 51.73777297139168, 61.484610959887505, 58.86340521275997, 65.01814395189285, 59.669896736741066, 61.49053484201431, 60.59995383024216, 60.248009115457535, 53.668551966547966, 47.87056468427181, 52.12978273630142, 57.08748310804367, 55.71272827684879, 57.52058006823063, 51.83213710784912, 57.51953512430191, 55.7646144926548, 57.270618081092834, 52.02183052897453, 43.25671926140785, 52.243218049407005, 61.81212678551674, 66.5935318171978, 79.29520145058632, 58.81931617856026, 30.18157336860895, 5.951723232865334, 3.939360952936113, 0.19974174443632364, 0.049252322569373064, 0.36661462916526943, 0.18012137850746512, 0.060674001288134605, 0.13726037606829777, 0.04018898878712207, 0.30088682484347373, 0.14857305184705183, 0.9521726192906499, 0.4892086680047214, 0.32788544485811144, 0.13502955436706543, 0.09110483166296035, 0.03218142686819192, 0.05270516463497188, 0.07578597593237646, 0.045934788868180476, 0.06831231134128757, 0.7243748428300023, 0.12963473447598517, 0.015065144198160851, 0.03698504078784026, 0.035478759309626184, 0.0487068514485145, 0.054519222176168114, 0.10498126401216723, 0.10348627431085333, 0.14728187816217542, 0.1709540735464543, 0.626251520588994, 0.41283327096607536, 0.1606465774239041, 0.04778340822667815, 0.08721306119696237, 0.23739393887808546, 0.5773784837219864, 1.8792776274494827, 4.8325977846980095, 7.019666377454996, 11.473560333251953, 35.78133098781109, 55.6034879386425, 50.23200877010822, 45.76865427196026, 53.847651556134224, 49.55303840339184, 39.96929906308651, 47.70313046872616, 47.355034947395325, 49.97915133833885, 52.327725514769554, 54.73834276199341, 51.10587827861309, 53.656529411673546, 50.02033732831478, 47.4299631267786, 46.690997779369354, 47.981427535414696, 45.61853192746639, 47.66745038330555, 48.71114417910576, 46.57538138329983, 45.334550365805626, 43.9972273260355, 46.19733966886997, 48.166565001010895, 50.60387961566448, 52.924825474619865, 55.631127655506134, 59.28411103785038, 59.00012947618961, 58.41528385877609, 55.74064917862415, 34.87042486667633, 6.79965153336525, 0.20310693886131048, 0.1926480297697708, 0.2944232529262081, 21.808876544237137, 63.48329231142998, 42.87928931415081, 53.898538425564766, 40.99315032362938, 39.2686128616333, 5.826433980837464, 6.26603476703167, 34.058769419789314, 32.17115990817547, 57.96778567135334, 41.89957648515701, 31.69133685529232, 28.83011508733034, 17.87845104932785, 23.99066437035799, 32.03022547066212, 20.612926818430424, 33.241262286901474, 45.890445336699486, 17.239217050373554, 0.6589298264589161, 0.05625502024486195, 0.030038315890124068, 0.09112189363804646, 0.0612121177255176, 0.09590848640073091, 0.032875175384106115, 0.09180555265629664, 0.039540166180813685, 0.08285148898721673, 0.05498039645317476, 0.07937213740660809, 0.12945035530719906, 0.06042406450433191, 0.08918205319787376, 0.03806613472988829, 0.08929727904614992, 0.39355096814688295, 0.24466510105412453, 35.48618942499161, 66.42011672258377, 33.27399753034115, 26.257991306483746, 40.456448122859, 36.91976509988308, 40.4105693846941, 33.62528868019581, 34.53447349369526, 47.96960636973381, 64.08154740929604, 41.05240814387798, 10.147595833986998, 7.041638698428869, 52.94284410774708, 65.69243296980858, 64.18433949351311, 61.11108720302582, 61.14805921912193, 21.160306446254253, 0.8207859413232654, 0.46911623678170145, 12.206535302102566, 54.83513876795769, 74.20301869511604, 64.73784819245338, 65.28868943452835, 58.72386150062084, 54.02163282036781, 57.17658452689648, 62.88004048168659, 62.149575278162956, 66.02095574140549, 60.429460778832436, 62.48516567051411, 63.21574106812477, 62.963719591498375, 53.89895260334015, 50.46777471899986, 54.65407468378544, 57.69296921789646, 57.580784037709236, 60.6427813321352, 57.4327477812767, 61.687140092253685, 54.69473250210285, 59.53039862215519, 52.77187988162041, 46.202093213796616, 54.98576268553734, 64.28411453962326, 69.9790133535862, 78.38075771927834, 52.1582318097353, 34.09742094576359, 12.031044568866491, 3.579276599921286, 0.5090596934314817, 0.2535689139040187, 0.21057729347376153, 0.12530321924714372, 0.1840303890639916, 0.07386468918411992, 0.18328858277527615, 0.4432771779829636, 0.9942789911292493, 1.1799702770076692, 0.8106911298818886, 0.1042215497000143, 0.13577913836343214, 0.024346122991119046, 0.030022990540601313, 0.0556812176364474, 0.09889135602861643, 0.06358228507451713, 0.051203636612626724, 1.745184960309416, 0.22903064702404663, 0.048362494926550426, 0.033585789205972105, 0.06101296981796622, 0.08135592041071504, 0.0955359208455775, 0.07286261170520447, 0.10976321835187264, 0.10082205320941284, 0.08910932272556238, 0.22776734840590507, 0.39894498651847243, 0.2823060593800619, 0.05339677576557733, 0.07121044254745357, 0.28480579087045044, 0.9037415462080389, 4.040217278525233, 7.850063843652606, 10.319914687424898, 16.7377370595932, 38.89342099428177, 57.505346685647964, 52.31120020151138, 51.20929352939129, 52.08000160753727, 55.39932869374752, 39.419255778193474, 49.378908947110176, 50.758622512221336, 51.55673548579216, 53.635125160217285, 56.090184822678566, 52.71384559571743, 55.71918413043022, 51.12375631928444, 49.55817952752113, 50.39295293390751, 50.640300661325455, 48.59221816062927, 51.414425522089005, 51.221038699150085, 48.00002373754978, 48.49890656769276, 47.7131163328886, 48.89572687447071, 51.58364564180374, 54.228098541498184, 55.6278370320797, 58.080784007906914, 62.183925434947014, 61.410891115665436, 62.16569781303406, 59.59467977285385, 38.18921618163586, 6.792911170050502, 0.23403462226269767, 0.30605006497353315, 0.9653066738974303, 28.17651405930519, 67.79880434274673, 49.059517085552216, 61.961872950196266, 47.651540637016296, 40.439497232437134, 3.7430715607479215, 9.916420988738537, 36.489457190036774, 30.82248877733946, 60.292470529675484, 44.823021814227104, 33.51754926145077, 28.087277747690678, 25.195625312626362, 21.90451931208372, 39.095182567834854, 21.231508925557137, 40.7879613339901, 59.84797418117523, 27.014570608735085, 1.4342018100433052, 0.09713896724861115, 0.01810480946005555, 0.19103537255432457, 0.03103449515037937, 0.05823604245961178, 0.03180411527864635, 0.18968258576933295, 0.20585385005688295, 0.1731769839534536, 0.1952935042208992, 0.23403787286952138, 0.2945644984720275, 0.23102715786080807, 0.20758303930051625, 0.16531015920918435, 0.2319322366383858, 0.7016566931270063, 0.762024053838104, 52.58557207882404, 79.65145513415337, 42.301180735230446, 38.94806206226349, 45.79290457069874, 36.15791738033295, 59.96708258986473, 45.781539380550385, 43.263608291745186, 49.55076992511749, 72.86860629916191, 44.587711840867996, 13.320748563855886, 9.316299241036177, 62.01175667345524, 74.01447281241417, 71.4554089307785, 66.86068028211594, 65.53332790732384, 24.433747194707394, 1.1823577363975346, 1.1329270200803876, 16.746478490531445, 61.26047618687153, 76.4079187810421, 67.65189662575722, 67.8255321085453, 61.127069145441055, 57.882594242691994, 59.26679536700249, 67.27440968155861, 64.1333082318306, 68.82083550095558, 62.44493342936039, 65.24032562971115, 68.02718728780746, 65.64872771501541, 56.46929807960987, 53.05703938007355, 56.87225125730038, 59.35153841972351, 61.39815799891949, 64.57685843110085, 60.279007852077484, 66.58720895648003, 60.89006066322327, 61.678419560194016, 55.308950543403625, 48.43485340476036, 57.167939990758896, 67.17067524790764, 66.27596005797386, 65.43012544512749, 57.567541748285294, 40.89224673807621, 29.14632461965084, 7.461008420214057, 0.9298306494019926, 0.21427838393719867, 1.1101784720085561, 0.6642715085763484, 0.24340218835277483, 0.16994243720546365, 0.24759324471233413, 0.96897151786834, 3.5984950186684728, 2.876232387498021, 1.3463854347355664, 0.3856921289116144, 0.23558246030006558, 0.24133950762916356, 0.1119746254698839, 0.1573182677384466, 0.22409416269510984, 0.16386843344662338, 0.5335907021071762, 2.431167019531131, 0.29145858075935394, 0.11626167863141745, 0.09915262169670314, 0.18249181302962825, 0.18073816259857267, 0.17201086215209216, 0.23242246970767155, 0.2563676715362817, 0.25550850201398134, 0.21416142146335915, 1.2035521678626537, 0.889377782586962, 0.5104269075673074, 0.18172979063820094, 0.14940065040718764, 0.3721459151711315, 2.4067934649065137, 5.116097722202539, 10.411551520228386, 14.859407600015402, 22.9089992120862, 52.04364895820618, 56.82136818766594, 56.09249509871006, 53.15700821578503, 56.0619143396616, 58.74943792819977, 48.22830408811569, 49.89231459796429, 51.94107346236706, 54.87413987517357, 57.9190418869257, 58.650236651301384, 55.508204251527786, 58.327364176511765, 54.719123393297195, 49.95430827140808, 52.35347293317318, 54.05014269053936, 53.04536260664463, 55.70521987974644, 54.90027867257595, 52.09564156830311, 52.41736650466919, 50.06307743489742, 51.78820766508579, 52.94070482254028, 56.5022499114275, 58.15352350473404, 63.519872948527336, 65.675128698349, 65.48239544034004, 66.40465155243874, 63.344276770949364, 42.82332591712475, 10.353010911494493, 0.9520411700941622, 1.0377430776134133, 0.9182096854783595, 26.593718491494656, 75.05602732300758, 50.67480280995369, 69.46223348379135, 50.711740627884865, 50.694641545414925, 8.67989894002676, 11.886924002319574, 41.71250492334366, 37.32363402843475, 63.19041542708874, 50.11514984071255, 36.61216780543327, 42.678504288196564, 28.917113319039345, 33.08256760239601, 47.721023708581924, 29.771168790757656, 51.48954749107361, 71.46751508116722, 42.74526670575142, 1.6821488365530968, 0.14657798077678308, 0.16520055884029716, 0.3742380888434127, 0.12568432692205533, 0.2029794082045555, 0.36696355731692165], [0.10318045751773752, 0.09055487797013484, 0.08060672233114019, 0.027833040767291095, 0.09255797907826491, 0.03947348421206698, 0.23364453460089862, 0.05412592843640596, 0.12708223628578708, 0.00528146239958005, 0.28368425730150193, 0.09383265482028946, 22.831724658608437, 52.699588760733604, 35.056759268045425, 36.389644145965576, 33.47453936934471, 26.80898644030094, 42.37567573785782, 40.48977613449097, 25.14318622648716, 44.261244758963585, 68.31073567271233, 58.50276276469231, 10.905521214008331, 4.972549499943852, 40.24933263659477, 62.89050132036209, 54.63794454932213, 57.00637266039848, 59.8238492757082, 25.430152527987957, 1.7078086221590638, 0.37394954182673246, 4.307532934471965, 39.09352965652943, 68.27942535281181, 66.47812440991402, 62.77009718120098, 57.51654088497162, 51.645407527685165, 56.30265802145004, 58.778453171253204, 64.27769288420677, 60.7431111484766, 60.568692907691, 58.350098356604576, 62.90995627641678, 56.74241602420807, 53.59937287867069, 49.38520520925522, 55.49443759024143, 55.097864270210266, 58.21633033454418, 55.210763812065125, 55.182630121707916, 54.50949624180794, 54.56240460276604, 54.704459980130196, 47.200972214341164, 46.7237064242363, 52.32228420674801, 51.34949080646038, 57.71883063018322, 47.49207079410553, 30.307377018034458, 6.933579621836543, 6.5219838079065084, 2.649347987025976, 0.11764528680942021, 0.15286582696717232, 0.26038325449917465, 0.04879118911048863, 0.0315306858101394, 0.07269275636645034, 0.3571329504484311, 3.411268377676606, 4.462219309061766, 2.301197131164372, 1.4695064281113446, 0.2826828329125419, 0.138712135667447, 0.05291227207635529, 0.026683750875236, 0.023886150993348565, 0.026884249491558876, 0.026219676656182855, 0.07091708641382866, 0.6996672623790801, 0.5141333711799234, 0.004379457504910533, 0.08624032823718153, 0.049858920683618635, 0.03731865101144649, 0.02811348909744993, 0.05297365511069074, 0.043017903590225615, 0.21724795427871868, 0.7086492085363716, 1.4203574904240668, 2.9468836588785052, 2.6967497309669852, 0.7714154873974621, 0.031637529100407846, 0.1911398075753823, 0.4894377541495487, 0.4887059371685609, 2.5977355940267444, 5.6390684098005295, 12.236842475831509, 27.268467284739017, 52.10881546139717, 44.791886284947395, 47.36243695020676, 45.584018379449844, 56.584922075271606, 47.8159274160862, 39.101786613464355, 48.19339916110039, 46.923290714621544, 50.99284954369068, 50.82859955728054, 55.5729565769434, 51.66469529271126, 51.587688624858856, 48.31103324890137, 46.15075796842575, 45.39193868637085, 47.15318217873573, 45.756156742572784, 45.25894582271576, 44.66595344245434, 47.27695673704147, 47.685282826423645, 47.472300454974174, 48.60237121582031, 54.00915428996086, 51.497253477573395, 55.57451829314232, 54.06739376485348, 57.341697067022324, 57.03229866921902, 59.453585743904114, 28.83608266711235, 2.0020211348310113, 0.30151156475767493, 0.15298832586267963, 0.9904229699168354, 44.83653008937836, 57.052448987960815, 51.32804475724697, 40.0286328792572, 31.34982068091631, 35.704502910375595, 0.7596871792338789, 16.793383173644543, 20.563861951231956, 36.8048744648695, 57.99165599048138, 34.67628188431263, 30.40212493389845, 29.735976979136467, 20.079741328954697, 25.124485529959202, 39.65483173727989, 35.227028131484985, 42.92717434465885, 59.73949380218983, 19.422538094222546, 0.9477080369833857, 0.17895176861202344, 0.026796162128448486, 0.10766685896669514, 0.06150890258140862, 0.008864252667990513, 0.004495314178711851, 0.06634646604652517, 0.07986507189343683, 0.03229477137210779, 0.08738621909287758, 0.12342434623860754, 0.0362980569479987, 0.041915279944078065, 0.033213984352187254, 0.026212069642497227, 0.024699607929505873, 0.29573459818493575, 0.11680455965688452, 30.679743736982346, 70.1540395617485, 37.00327321887016, 36.674818843603134, 39.27763357758522, 32.56532795727253, 41.91035270690918, 33.69049698114395, 26.30342546850443, 47.1933688223362, 70.84787473082542, 61.07913091778755, 18.573148772120476, 4.213407235220075, 43.31739820539951, 66.87570467591286, 59.95415948331356, 62.67933525145054, 64.97665777802467, 30.388170182704926, 2.921389639377594, 0.6895154539961368, 3.8437587954103947, 38.49588252604008, 72.61174768209457, 67.53452092409134, 67.47606486082077, 60.02023033797741, 55.65962612628937, 58.61099995672703, 62.32469268143177, 65.02336487174034, 63.89613255858421, 62.319148778915405, 61.0407567769289, 62.63254076242447, 59.07128445804119, 53.69007021188736, 53.346732035279274, 55.711143761873245, 59.30720239877701, 58.13314139842987, 57.09690660238266, 58.620070070028305, 56.736932918429375, 55.45890189707279, 56.815550699830055, 49.29433688521385, 53.18081013858318, 52.333702594041824, 57.01353907585144, 57.75938205420971, 45.973744466900826, 33.20836745202541, 21.507364623248577, 7.1277064550668, 2.292985296808183, 0.663418632466346, 0.3190700663253665, 0.3299278946360573, 0.07765308590023778, 0.08247871563071385, 0.11622710197116248, 0.7995968533214182, 1.4432891411706805, 4.629303943365812, 2.2508239466696978, 1.3362680026330054, 0.3396348003298044, 0.08005172945559025, 0.005971823939034948, 0.04078081816260237, 0.08731244219234213, 0.012724832522508223, 0.021872476136195473, 0.026598732292768545, 1.824628128670156, 0.2931181120220572, 0.0021392731468949933, 0.0435743028356228, 0.1578988943947479, 0.025860876085062046, 0.0297885943291476, 0.05282249076117296, 0.031888044759398326, 0.16788046894362196, 0.6593187712132931, 0.8430161140859127, 2.5902217347174883, 2.6663133641704917, 0.7596386724617332, 0.0943062044098042, 0.1774427597410977, 0.45859160309191793, 1.0106749925762415, 5.458165816962719, 10.105537790805101, 14.995616991072893, 31.259091049432755, 55.16852907836437, 47.213853523135185, 53.337616324424744, 45.83653762936592, 54.9760428071022, 55.61255045235157, 40.259960666298866, 45.920285135507584, 49.8857257515192, 52.980367094278336, 52.463625222444534, 58.95393155515194, 55.446290373802185, 51.89084395766258, 52.09661051630974, 47.915132492780685, 46.53826877474785, 49.24280785024166, 47.6482006162405, 46.86316654086113, 48.18056344985962, 50.81057332456112, 50.32703407108784, 50.043383091688156, 52.84188732504845, 56.257220059633255, 53.42965118587017, 58.28870505094528, 58.52257490158081, 61.731096133589745, 60.23217536509037, 62.51252040266991, 30.43129976838827, 1.5158815146423876, 0.3117424267111346, 0.14390580385224894, 2.749715088866651, 52.00354591012001, 62.81932733952999, 52.462321892380714, 43.200090900063515, 34.39157456159592, 35.84112837910652, 0.5986563919577748, 22.76836685836315, 23.75551588833332, 38.61524552106857, 60.76016843318939, 40.338886231184006, 27.01489169150591, 29.03928816318512, 21.430956423282623, 24.403111338615417, 48.565414398908615, 37.28567026555538, 47.11351990699768, 71.00438833236694, 29.752578288316727, 0.8186372159980237, 0.08861935682944022, 0.049337669552187435, 0.14858114125672728, 0.03771568888623733, 0.08650584641145542, 0.010173081118409755, 0.17026454414008185, 0.21054107666714117, 0.18162590480642393, 0.18073232931783423, 0.21624354645609856, 0.08716536336578429, 0.3298890951555222, 0.15238289663102478, 0.298353637335822, 0.08059052124735899, 0.49649667693302035, 0.21958623896352947, 45.601778626441956, 80.57733625173569, 51.601785868406296, 53.41856338083744, 48.755354806780815, 34.78848606348038, 60.86040325462818, 48.445584028959274, 36.16234414279461, 52.37539775669575, 77.6488333940506, 66.26932561397552, 19.731330424547195, 7.571144085377455, 50.10073721408844, 74.20447781682014, 67.52252116799355, 66.8729916214943, 69.67758312821388, 30.84287278354168, 3.2121386379003525, 1.4878937602043152, 7.903545023873448, 43.389989510178566, 72.72793024778366, 69.86324116587639, 69.86286118626595, 63.009750321507454, 58.873828053474426, 61.373930498957634, 64.24256756901741, 69.06131699681282, 67.0034310221672, 65.30112236738205, 63.59922409057617, 66.36395573616028, 62.18676008284092, 57.27867364883423, 56.83461807668209, 59.94753263890743, 61.7049915343523, 61.66855528950691, 60.05119867622852, 61.20636709034443, 61.30142278969288, 58.762725815176964, 61.82525888085365, 51.48813396692276, 53.43375876545906, 54.22203026711941, 59.87067796289921, 60.74109725654125, 58.801890313625336, 44.68458004295826, 32.754371613264084, 11.899463329464197, 4.8383796494454145, 0.9782518073916435, 0.4054330789949745, 0.6963620334863663, 0.15498581633437425, 0.21980036341119558, 0.17484142823377624, 1.6956761106848717, 7.326292349025607, 10.259524527937174, 5.373013811185956, 2.317762579768896, 0.7727824640460312, 0.22695634426781908, 0.09100922077777795, 0.13162639166694134, 0.15088368410943076, 0.09137134431512095, 0.1397485300549306, 0.17786533862818033, 2.450311817228794, 0.5857093585655093, 0.16438407765235752, 0.20835090981563553, 0.2176589853479527, 0.10292206396115944, 0.11762593159801327, 0.14303999952971935, 0.12109916788176633, 0.29666617163456976, 0.7420826645102352, 1.000595677178353, 4.270491572096944, 4.823690112680197, 1.1539645912125707, 0.2019258850486949, 0.32098884461447597, 1.3107556966133416, 1.5885777887888253, 9.58768542855978, 15.932709407061338, 20.284352749586105, 40.89440122246742, 59.66738507151604, 48.679765462875366, 56.87514670193195, 50.45287571847439, 56.07910841703415, 56.68144069612026, 44.72113788127899, 49.93916608393192, 51.420763581991196, 55.850953459739685, 56.61430209875107, 62.79741391539574, 58.32875110208988, 53.82879696786404, 53.823393657803535, 52.76743791997433, 50.12773856520653, 53.51540498435497, 50.68670377135277, 51.089607551693916, 51.281725242733955, 52.787314653396606, 54.46865223348141, 52.38251477479935, 55.2621940523386, 59.747397378087044, 55.884190276265144, 60.36814346909523, 60.63982129096985, 64.44003537297249, 63.59089873731136, 66.4833377301693, 34.98240105807781, 3.9445377001538873, 0.7892230537254363, 0.46027699077967554, 1.996779078617692, 53.737297877669334, 66.25332087278366, 59.74919468164444, 48.92527408897877, 38.55164833366871, 46.63550555706024, 1.5244109882041812, 26.790082454681396, 26.97169940918684, 41.17769882082939, 63.86540740728378, 45.73283739387989, 34.94758352637291, 45.09295932948589, 28.933106660842896, 34.31071110069752, 55.78462041914463, 46.73129081726074, 60.77935740351677, 80.1060551404953, 42.368847504258156, 1.5313912136480212, 0.3386946179671213, 0.19782327784923837, 0.4155769315548241, 0.08972134965006262, 0.19123155187116936, 0.2668157155858353], [0.047162037662928924, 0.051718920876737684, 0.04846789102884941, 0.08580917754443362, 0.03469620911346283, 0.046422264858847484, 0.04368923182482831, 0.10066941569675691, 0.04485559111344628, 0.024449969860143028, 0.24451129836961627, 0.2716364397201687, 19.145740047097206, 50.349954441189766, 44.84174720942974, 27.82268464565277, 36.824979186058044, 38.17219689488411, 35.7256867736578, 45.862429440021515, 28.23874332010746, 54.348863661289215, 62.59600192308426, 65.70504829287529, 28.70253313332796, 1.742145479656756, 19.62797027081251, 67.41736561059952, 59.91008564829826, 60.123531594872475, 58.24846900999546, 32.16343492269516, 2.9537031054496765, 0.23077696503605694, 0.7368348492309451, 30.62065500766039, 62.64006435871124, 66.11749336123466, 64.83534336090088, 64.28290620446205, 52.968808114528656, 58.08653689920902, 60.12238405644894, 63.88375282287598, 61.042664274573326, 60.92939615249634, 58.30514296889305, 60.96103325486183, 60.56914508342743, 57.47903689742088, 50.25707982480526, 57.001391127705574, 57.40121707320213, 57.31238164007664, 58.10363218188286, 56.854567006230354, 53.69900353252888, 56.27720318734646, 51.365666538476944, 45.26736617088318, 47.27540262043476, 54.69462230801582, 43.866495341062546, 41.18560999631882, 25.818227604031563, 13.067591898143291, 7.657336285337806, 4.952734988182783, 1.1536279530264437, 0.1619720977032557, 0.09072210610611364, 0.17059957928722724, 0.1476208318490535, 0.028804820067307446, 1.7643079091794789, 4.6901429537683725, 8.970132116228342, 4.868689673021436, 3.4400884062051773, 2.6884671254083514, 0.36814624385442585, 0.035322711628396064, 0.0885124207707122, 0.055319888197118416, 0.032989521787385456, 0.0182557159132557, 0.047082063829293475, 0.05810295682749711, 1.8642761511728168, 0.6229831022210419, 0.07931099928100593, 0.013165808322810335, 0.008848937522998312, 0.08070018840953708, 0.0627848993462976, 0.06325443391688168, 0.05280857178149745, 0.1291949674487114, 0.5415949132293463, 3.0236882250756025, 5.601032450795174, 10.227082818746567, 7.468219483271241, 1.7891311459243298, 0.2628033980727196, 0.4716644750442356, 0.3285803325707093, 2.3136060778051615, 5.110756633803248, 10.116857383400202, 20.25222547352314, 41.61965690553188, 47.36366428434849, 40.95793381333351, 44.6137822419405, 45.17453335225582, 54.85381096601486, 41.90541297197342, 37.702599093317986, 43.93184423446655, 47.89463259279728, 52.999540865421295, 51.1135196685791, 51.43915079534054, 50.62154106795788, 49.011461064219475, 47.204327434301376, 45.73160246014595, 44.48079697787762, 45.674719512462616, 46.09233610332012, 46.473334059119225, 46.88606411218643, 48.91859784722328, 53.16613532602787, 52.19580039381981, 54.014242216944695, 54.19695161283016, 57.25266024470329, 60.306320786476135, 62.60734811425209, 58.74575212597847, 58.23616527020931, 20.269142165780067, 0.5989913083612919, 0.3144644165877253, 2.0046220952644944, 14.43056546151638, 59.135945588350296, 52.115943878889084, 54.109134525060654, 47.889115288853645, 61.67224869132042, 19.743607565760612, 1.2505361717194319, 20.116722844541073, 22.1323436871171, 59.4243311136961, 63.047208711504936, 35.57679936289787, 31.11359115689993, 33.33572521805763, 20.573638826608658, 25.411320738494396, 32.1097020059824, 23.495366647839546, 37.33237735927105, 59.51052188873291, 20.06381258368492, 0.3527731297072023, 0.1457818047492765, 0.08143146362272091, 0.09794685436645523, 0.07489133917260915, 0.04245446507411543, 0.02600750776764471, 0.07995021107490174, 0.030469338562397752, 0.010445030002301792, 0.04824853072932456, 0.050911523576360196, 0.0421686602931004, 0.011753821345337201, 0.043105922304675914, 0.15219174907542765, 0.07762662091408856, 0.250463827396743, 0.20231456262990832, 24.48547951877117, 65.49375683069229, 48.27689588069916, 29.808334596455097, 40.10843239724636, 47.082464173436165, 39.96093571186066, 36.30642481148243, 27.858153842389584, 49.60438884794712, 64.1748096048832, 62.95635178685188, 39.53311666846275, 2.5501830456778407, 19.18065447360277, 67.17361629009247, 70.03980249166489, 63.16539756953716, 64.91933405399323, 36.08802393078804, 5.3369727451354265, 0.40310288371983916, 0.7123053248506039, 31.12231358885765, 64.90958377718925, 68.44042271375656, 67.71845385432243, 66.51666954159737, 57.7572275698185, 60.77839985489845, 66.52960404753685, 65.56789845228195, 64.04073759913445, 62.381096854805946, 63.342555463314056, 63.91338363289833, 64.89826798439026, 58.78502681851387, 54.69276800751686, 58.806864246726036, 60.39244316518307, 56.8726996332407, 61.95461913943291, 58.58698144555092, 59.25570756196976, 58.0590757727623, 54.495516791939735, 46.46056294441223, 52.03438125550747, 56.580426916480064, 49.78525534272194, 44.738480150699615, 38.88862565159798, 21.857443638145924, 10.813897680491209, 8.23214141651988, 1.8349806731566787, 0.12693046708591282, 0.8776491181924939, 0.03180766274454072, 0.1499529418651946, 0.03373071951500606, 2.466637878678739, 7.436775220558047, 14.747666995972395, 11.57660510390997, 5.458669289946556, 2.3321842309087515, 0.20893463864922523, 0.04438819763890933, 0.0620909541612491, 0.10861070011742413, 0.02636805053043645, 0.036398139272932895, 0.024389603568124585, 0.01834908551245462, 1.6809424012899399, 0.23331202275585383, 0.0668647003476508, 0.015151871575653786, 0.09665796649642289, 0.06390465918229893, 0.06814538006437942, 0.05808075919048861, 0.020354181142465677, 0.09139991700067185, 0.5728914588689804, 2.6541335927322507, 8.393678348511457, 12.163961436599493, 9.138540029525757, 3.172589410096407, 0.2659472543746233, 0.4348805785411969, 0.3811710840091109, 3.4181210724636912, 8.404002394527197, 15.48297693952918, 24.248535633087158, 48.361049965023994, 48.44109646975994, 46.96774832904339, 45.05025342106819, 49.08247925341129, 51.14451080560684, 52.299933806061745, 36.784127578139305, 46.05722978711128, 47.13436558842659, 57.25620545446873, 53.41640889644623, 56.04668855667114, 52.99277722835541, 53.41357044875622, 48.99791479110718, 50.158110335469246, 46.67278155684471, 49.59662206470966, 47.51757502555847, 50.07720127701759, 48.12807306647301, 53.46913866698742, 54.816021993756294, 57.333371713757515, 56.67403869330883, 59.369952231645584, 60.780561938881874, 63.57885338366032, 62.73877166211605, 61.21652014553547, 58.61610688269138, 21.132816821336746, 0.2998285519424826, 0.437887612497434, 3.9026019629091024, 22.63563048094511, 65.29441192746162, 56.0175821185112, 59.18461337685585, 54.42819580435753, 61.29052497446537, 20.031717605888844, 1.3600350148044527, 26.567359305918217, 24.269789792597294, 63.52877587080002, 66.72600790858269, 37.707554027438164, 22.752384915947914, 36.602770909667015, 24.630523435771465, 26.44376713782549, 39.18653726577759, 22.48410601168871, 46.2880028039217, 68.52677688002586, 26.82410202920437, 0.37329947983380407, 0.11388796381652355, 0.15380881464807317, 0.07373120650299825, 0.1170173408172559, 0.07968959107529372, 0.07906980870757252, 0.1582694932585582, 0.1517895792494528, 0.22547313245013356, 0.31950499454978853, 0.13465156371239573, 0.3446601494215429, 0.14960726432036608, 0.29530397441703826, 0.18639265996171162, 0.2734477847116068, 0.5972289748024195, 0.3548579115886241, 36.99755072593689, 80.2078364789486, 63.22741024196148, 39.157765209674835, 48.2616700977087, 47.49704472720623, 55.50090864300728, 55.953057780861855, 37.767700999975204, 62.77887091040611, 67.26954594254494, 72.52083376049995, 40.13123877346516, 4.369480535387993, 26.512321159243584, 77.10812240839005, 71.52201935648918, 68.4478323161602, 72.13703915476799, 39.86971400678158, 7.321747317910194, 0.7510489365085959, 1.8506851117126644, 36.63107939064503, 69.49016958475113, 71.55617952346802, 71.66375175118446, 68.60775053501129, 59.15526755154133, 62.5953483581543, 67.35776960849762, 67.47015237808228, 66.44413903355598, 65.86977705359459, 65.91379389166832, 67.96105563640594, 66.83616399765015, 59.89599980413914, 57.1093737334013, 64.13021519780159, 62.79390290379524, 60.30038170516491, 66.3966415822506, 62.956138998270035, 61.68727308511734, 61.32941968739033, 57.54886955022812, 51.6522129625082, 52.352800369262695, 59.52470652759075, 54.86776381731033, 52.72062063217163, 46.97619907557964, 34.6020832657814, 14.512969739735126, 10.382718667387962, 1.8309157225303352, 0.37599092291202396, 0.7216589979361743, 0.36885544017422944, 0.3175397281302139, 0.14426093635847792, 3.1519626919180155, 14.414280485361814, 23.42562709003687, 12.809960972517729, 7.009054496884346, 4.070722041651607, 0.5589428823441267, 0.16771596448961645, 0.20816739153815433, 0.14937302767066285, 0.15630060515832156, 0.13178530032746494, 0.1267910620663315, 0.15709879982750863, 2.9031708044931293, 0.8167556044645607, 0.1910094716004096, 0.10258960406645201, 0.2615445078117773, 0.13057702453806996, 0.183242539933417, 0.12657557206694037, 0.16187189292395487, 0.19537193438736722, 0.45996205299161375, 2.324505317956209, 7.243649158626795, 16.36121716350317, 14.368176609277725, 3.2349623506888747, 0.28020705794915557, 0.6769011996220797, 0.6464382936246693, 5.9864642936736345, 13.407307919114828, 20.39292812347412, 32.41054706275463, 52.67752714455128, 52.09353648126125, 52.53441542387009, 49.47842940688133, 52.090021669864655, 54.39996711909771, 50.2981024235487, 41.056097745895386, 48.18312831223011, 52.86996401846409, 58.74499596655369, 56.43968626856804, 58.40205296874046, 56.75432078540325, 54.95664864778519, 51.60446472465992, 52.877533212304115, 51.47596322000027, 52.413547709584236, 50.81382215023041, 52.590496614575386, 52.36865691840649, 54.77553516626358, 59.101576432585716, 57.657000347971916, 59.35906581580639, 60.212876200675964, 63.819901049137115, 66.27132430672646, 68.19272920489311, 63.35946075618267, 63.653747364878654, 26.97241187095642, 1.2560246209613979, 1.732053339947015, 4.830458974465728, 17.100657485425472, 71.41974404454231, 60.735439360141754, 65.42513251304626, 57.74442605674267, 72.26491749286652, 27.021835818886757, 3.0991175025701523, 27.36175987869501, 28.295183591544628, 64.65222358703613, 65.38036331534386, 42.79322013258934, 37.348803877830505, 55.23652642965317, 29.55019924789667, 35.19789129495621, 44.89546872675419, 32.13522143661976, 56.23593360185623, 81.82042434811592, 38.84124979376793, 0.7372230815235525, 0.4117738106288016, 0.24058224982582033, 0.2632093528518453, 0.21561393805313855, 0.14407798211323097, 0.24613789311842993], [0.09707454883027822, 0.009793672033993062, 0.006386325012499583, 0.09079484399990179, 0.06412553717382252, 0.1077912503387779, 0.0600829474569764, 0.08371958654606715, 0.03815155963820871, 0.053933500676066615, 0.10874424217035994, 0.4299818695290014, 16.113003082573414, 48.96285027265549, 36.23279996216297, 32.7055936306715, 38.96063178777695, 26.844964809715748, 43.07964116334915, 38.68332266807556, 39.1511307656765, 36.12634867429733, 42.8921440243721, 43.94146911799908, 39.54033628106117, 8.620258290320635, 8.22225434705615, 52.67925605177879, 47.982533276081085, 61.22427932918072, 55.39406217634678, 43.95813122391701, 5.247629089280963, 0.14075684157432988, 0.09621451099519618, 9.73765293136239, 43.86996455490589, 69.26364853978157, 64.57395538687706, 64.70349803566933, 57.882818430662155, 60.316139459609985, 57.97114849090576, 64.60625365376472, 61.17771662771702, 60.83418846130371, 58.226126208901405, 61.59658335149288, 56.52176186442375, 53.534023985266685, 50.52495785057545, 53.150635957717896, 56.27441793680191, 56.61906324326992, 56.12637788057327, 55.31680092215538, 53.139745742082596, 54.119306579232216, 51.32012598216534, 48.926395028829575, 55.30789040029049, 46.62076234817505, 40.327095463871956, 32.50515438616276, 13.358691427856684, 13.88309558853507, 8.238599169999361, 1.9191867671906948, 0.1226299958943855, 0.23178031900897622, 0.02964419465570245, 0.10943402390694246, 0.0395192710129777, 0.22819040226750076, 2.245949045754969, 2.9149135993793607, 3.452506852336228, 0.5934416467789561, 1.26738102408126, 1.307076544035226, 0.06746017737896182, 0.29314753075595945, 0.07427880758768879, 0.03564854785508942, 0.012349565549811814, 0.044637188184424303, 0.10383112065028399, 0.047478289052378386, 0.7508609653450549, 0.03696666892210487, 0.0938238603703212, 0.039766524932929315, 0.16838287323480472, 0.07593859860207886, 0.08910405347705819, 0.015704262295912486, 0.07089274397003464, 0.02019817056861939, 0.6084535724949092, 1.4410320622846484, 3.6094628926366568, 7.296625440940261, 9.036049079149961, 5.070747630670667, 0.5589869362302125, 0.2884524373803288, 0.29434657422825694, 4.4712253008037806, 8.1935915350914, 11.532934047281742, 16.646982729434967, 38.20217348635197, 44.57895331084728, 42.64531686902046, 41.25570483505726, 45.210639014840126, 45.79364933073521, 52.143883779644966, 38.8086361438036, 41.11981652677059, 43.880774974823, 50.090717151761055, 54.347260147333145, 54.012467712163925, 52.95369632542133, 50.45805104076862, 46.33614242076874, 45.688311383128166, 44.766948223114014, 44.66507948935032, 43.13200235366821, 46.02520130574703, 48.70317220687866, 54.84699033200741, 54.38522391021252, 58.200150802731514, 58.286375775933266, 55.27407981455326, 60.6383203715086, 56.45975299179554, 58.82538445293903, 60.04726588726044, 50.704931393265724, 6.882883217185736, 0.24905671540182084, 0.3959456708980724, 11.169818881899118, 46.37738920748234, 53.33838768303394, 51.937710642814636, 52.199159413576126, 54.538203701376915, 52.307582795619965, 7.926581762731075, 1.116550611332059, 24.606503024697304, 24.06782492995262, 70.50769418478012, 59.44722108542919, 24.782946556806564, 28.463801443576813, 25.872954167425632, 13.847477249801159, 39.87197108566761, 37.74406246840954, 29.08354438841343, 44.600220769643784, 52.47522220015526, 10.700695104897022, 0.06340245527098887, 0.1028392773878295, 0.08478485789964907, 0.09775853439350612, 0.05559425648243632, 0.029404436427284963, 0.04655186981835868, 0.02096434898703592, 0.017278171981160995, 0.02074215739412466, 0.06616075101192109, 0.05489760616910644, 0.05923183023696765, 0.03478354505205061, 0.010989304410031764, 0.03175606492732186, 0.06486922851763666, 0.12235698202857748, 0.33442002546507865, 21.41963493078947, 65.15505820512772, 43.09545211493969, 33.42202618718147, 34.48609068989754, 25.60624647885561, 49.799880757927895, 32.260200530290604, 44.560406506061554, 41.586705073714256, 45.27428179979324, 41.39069639146328, 47.41686522960663, 11.301245279610157, 11.169665940105915, 59.75836358964443, 55.65486118197441, 66.25987932085991, 61.416875794529915, 53.12588028609753, 8.076545465737581, 0.4959612025413662, 0.3354667208623141, 8.34868211299181, 45.836936607956886, 70.5123071372509, 69.1214069724083, 66.62884712219238, 61.552277728915215, 61.95154510438442, 60.23443624377251, 66.4195467531681, 63.801935613155365, 62.12422303855419, 59.82363648712635, 65.04933267831802, 58.957693353295326, 56.94639287889004, 52.595607340335846, 55.57357594370842, 59.890999272465706, 58.675547093153, 57.7933332324028, 59.69209514558315, 56.7457028478384, 55.608385875821114, 52.95126065611839, 49.82171058654785, 57.89732985198498, 47.55517020821571, 48.0354568362236, 39.040929079055786, 24.003095403313637, 19.62014839053154, 11.643977388739586, 4.11768039688468, 0.6398932635784149, 0.8716254914179444, 0.5950762121938169, 0.12198278374853544, 0.14054148516152054, 0.46050432545598596, 4.449275303632021, 11.921715885400772, 12.769523542374372, 7.191856512799859, 5.189646575599909, 2.8703417535871267, 0.08721856793272309, 0.28491387725807726, 0.02721865937928669, 0.03166876238537952, 0.025533332918712404, 0.013416003002930665, 0.0742634228663519, 0.0019474722694212687, 0.3718872618628666, 0.04752039851155132, 0.055281062741414644, 0.02355907352466602, 0.13608560082502663, 0.06639254599576816, 0.025810395200096536, 0.030743643765163142, 0.16106872586533427, 0.012915949464513687, 0.2438870185869746, 3.225816716440022, 8.002859819680452, 15.79536197707057, 20.803108513355255, 9.595025684684515, 4.755805805325508, 1.0408800467848778, 0.751429331721738, 5.477160047739744, 13.095922227948904, 13.544347565621138, 23.653293773531914, 43.20828706026077, 47.067097797989845, 48.11811380088329, 43.23857523500919, 50.31075954437256, 44.88103710114956, 53.678317442536354, 45.30970349907875, 42.20384895801544, 45.205038115382195, 51.496292129158974, 55.36520652472973, 55.8713735640049, 55.2423857152462, 52.5088731944561, 49.140338748693466, 46.51019588112831, 47.60901711881161, 47.498207464814186, 45.134551897645, 48.595238998532295, 51.94721393287182, 58.20594169199467, 59.347442239522934, 61.37542761862278, 61.193664371967316, 60.72453774511814, 60.62587223947048, 59.9150063842535, 59.3637053668499, 63.58262278139591, 49.73363131284714, 5.242723552510142, 0.09285779189667664, 0.8945439616218209, 20.536932796239853, 53.140695691108704, 56.704938635230064, 57.60409578680992, 56.185384914278984, 58.84167417883873, 53.517620265483856, 8.481081258505583, 2.4253701930865645, 33.95321488380432, 20.746339559555054, 74.70345944166183, 56.67074427008629, 29.13137622177601, 21.453092135488987, 33.977966755628586, 16.666179299354553, 36.26038268208504, 39.68565948307514, 29.598008282482624, 52.24598050117493, 61.49566076695919, 12.692930102348328, 0.2051908746943809, 0.05814357828057837, 0.09717724722577259, 0.15374981390777975, 0.0315623124333797, 0.037946289012324996, 0.05637481401208788, 0.19952839182224125, 0.16524017468327656, 0.13812100020004436, 0.18252227077027783, 0.1262722266255878, 0.2797229401767254, 0.14990146650234237, 0.18918448593467474, 0.13953306974144652, 0.19936329365009442, 0.36475691478699446, 0.4794627847149968, 29.160266071558, 79.72932815551758, 57.00688183307648, 46.85243211686611, 52.69408665597439, 34.17616792023182, 66.48452326655388, 50.851474329829216, 45.56627333164215, 48.16064491868019, 51.580408215522766, 48.702685832977295, 49.542832151055336, 14.081557039171457, 11.573490221053362, 63.85211572051048, 59.61037293076515, 73.24188306927681, 63.07559698820114, 57.36762687563896, 7.892619660124183, 0.6228841887786984, 0.3859906207071617, 11.95699604228139, 53.74845027923584, 71.6422601044178, 72.67646580934525, 69.55978184938431, 63.59468713402748, 65.02410963177681, 62.17254124581814, 72.02087938785553, 66.96147367358208, 64.62118685245514, 63.12836475670338, 67.83614113926888, 61.78674414753914, 58.13510589301586, 56.66692167520523, 60.1534777879715, 61.53686575591564, 59.819506108760834, 61.69423051178455, 61.38587325811386, 59.9173204600811, 58.72218199074268, 56.46996684372425, 53.01978997886181, 60.301715433597565, 55.52617348730564, 53.04425306618214, 48.969340324401855, 36.439945846796036, 22.3052629083395, 14.003999400883913, 5.634818812832236, 0.22658130736090243, 0.4502400668570772, 0.6685911642853171, 0.2158118539955467, 0.15832625271286815, 0.6224969064351171, 9.37636261805892, 23.16310677677393, 18.82308606058359, 10.025315545499325, 5.237726820632815, 3.7702505523338914, 0.34830730059184134, 0.36330322560388595, 0.15590551542118192, 0.22579209267860278, 0.10664715548045933, 0.05882899247808382, 0.2791841409634799, 0.1507020805729553, 1.4675534516572952, 0.22132280515506864, 0.19919046229915693, 0.1751078147208318, 0.31508342712186277, 0.18686966795939952, 0.12207304374896921, 0.1750764367170632, 0.17896956531330943, 0.1569774586823769, 0.4840036004316062, 3.4920632047578692, 7.314541954547167, 14.044491928070784, 30.85938859730959, 17.49219797551632, 4.339379500597715, 0.6386847503017634, 1.0827197204343975, 7.1655709482729435, 16.196459904313087, 20.916771814227104, 31.030725203454494, 47.67076000571251, 49.37272667884827, 50.3975772857666, 49.03641052544117, 52.97468639910221, 49.738574847579, 50.73404163122177, 44.76549670100212, 44.801910147070885, 46.75915852189064, 54.97033551335335, 59.75966311991215, 60.56815333664417, 57.644609212875366, 53.69556091725826, 52.446586936712265, 50.176254361867905, 49.90402936935425, 50.31806655228138, 47.567492946982384, 52.1633805334568, 54.71485622227192, 61.608583107590675, 61.46168678998947, 63.01850125193596, 64.52839583158493, 61.92299723625183, 66.41707688570023, 63.23687933385372, 64.53091129660606, 65.87101578712463, 57.234235033392906, 11.507738549262285, 0.653881678590551, 0.4246842412976548, 19.56132374703884, 57.06724539399147, 62.6931095123291, 63.00504617393017, 62.077276557683945, 66.21163710951805, 63.483546897768974, 12.49275779351592, 3.3118298510089517, 32.71388478577137, 29.47934255003929, 79.34896856546402, 60.572504103183746, 34.4074273109436, 32.75311008095741, 47.33936458826065, 17.33998004347086, 51.275086998939514, 47.414022982120514, 40.244275107979774, 62.94283211231232, 76.38508960604668, 21.38028234243393, 0.3935879864729941, 0.19678884273162112, 0.2406915681785904, 0.1902296970365569, 0.14024026226252317, 0.28828022943343967, 0.2494737133383751], [0.07214136290713213, 0.11492199075291865, 0.06034220932633616, 0.06554923616931774, 0.04241396607540082, 0.03132519625069108, 0.13516757899196818, 0.06626340487855487, 0.053932799346512184, 0.11773225909564644, 0.1732034786255099, 0.42970359383616596, 9.169823750853539, 47.60864473879337, 45.16358993947506, 36.39193542301655, 51.580244824290276, 53.64319212734699, 26.397576816380024, 54.73325103521347, 21.457551196217537, 30.013802871108055, 33.0152428150177, 27.43938021361828, 21.031554155051708, 4.8425033781677485, 9.713037852197886, 52.975469157099724, 53.43497470021248, 50.82119755446911, 60.07878139615059, 57.978470697999, 29.15420539677143, 3.8154303655028343, 0.04481385643885005, 2.300999304279685, 26.560266986489296, 64.21127244830132, 66.63240373134613, 65.79225361347198, 61.58397562801838, 63.540863022208214, 62.54581041634083, 63.39599959552288, 60.644411444664, 59.835868030786514, 58.465175181627274, 60.86995594203472, 59.58348177373409, 54.68544580042362, 53.427948877215385, 55.73171965777874, 57.08540461957455, 57.004985734820366, 57.13025741279125, 59.82039526104927, 55.718861147761345, 56.98079623281956, 45.874288603663445, 47.191172540187836, 44.72049191594124, 36.68191686272621, 26.07108883559704, 17.098240815103054, 21.757374107837677, 14.88683832809329, 7.314887261018157, 1.9759300723671913, 1.6581899346783757, 0.38788683770690113, 0.7574648328591138, 0.11530434523592703, 0.17193541541928425, 0.2518696035258472, 1.6537759965285659, 1.7781802522949874, 2.8530593309551477, 1.3770762691274285, 0.1656934487982653, 0.1485925554879941, 0.03121306886896491, 0.047277738485718146, 0.08797244154266082, 0.0372470968432026, 0.018483451349311508, 0.08732437592698261, 0.008360545907635242, 0.0455290827085264, 0.8826415752992034, 0.02784393735055346, 0.07644826851901598, 0.042363867396488786, 0.02915688935900107, 0.04752690343593713, 0.0664331266307272, 0.03456800310232211, 0.07086115816491656, 0.11053363443352282, 0.10535926950979047, 0.18951358390040696, 0.7432301435619593, 1.438402603380382, 4.635520884767175, 8.64206437021494, 6.7965038772672415, 1.141026879195124, 2.1372402040287852, 3.498230748809874, 10.871204305440187, 10.08899062871933, 17.906797528266907, 35.01170888543129, 44.77863259613514, 45.68538933992386, 41.920680552721024, 43.72868813574314, 42.56261810660362, 47.846093997359276, 47.126378417015076, 35.26755675673485, 44.28971283137798, 48.35724636912346, 54.07739482820034, 52.130763083696365, 54.309744760394096, 49.75141055881977, 49.003143310546875, 45.15986993908882, 46.549079194664955, 44.362611919641495, 48.32045294344425, 45.134620293974876, 51.97187080979347, 52.252633944153786, 57.32851557433605, 55.405370369553566, 56.65913589298725, 57.89976932108402, 58.99579390883446, 62.02231630682945, 62.84179553389549, 61.7318294942379, 29.381188116967678, 0.18424393463646993, 1.637487339321524, 25.93047358095646, 54.30386647582054, 55.263588577508926, 59.92765210568905, 51.03986822068691, 54.2333422601223, 48.90089079737663, 44.17759224772453, 2.5766125274822116, 6.250053299590945, 27.901330925524235, 41.54637783765793, 76.33067652583122, 42.97893516719341, 15.376286264508963, 24.15204931050539, 24.660919904708862, 23.38945873081684, 33.74407410621643, 29.883538261055946, 30.45366156846285, 47.422659918665886, 48.94919380545616, 5.391303179785609, 0.15241581830196083, 0.05574561007961165, 0.15367225947557017, 0.03292073954071384, 0.02672476566658588, 0.04498760805290658, 0.012801829416275723, 0.07962216695887037, 0.0415606075694086, 0.058143700734945014, 0.03315388152259402, 0.046668453796883114, 0.04777805363119114, 0.035544858692446724, 0.09549406371661462, 0.028690334511338733, 0.08796305337455124, 0.24107111734338105, 0.5104869324713945, 12.757890466600657, 61.011749133467674, 54.49450224637985, 40.805109813809395, 50.497960299253464, 25.906852148473263, 32.75642350316048, 44.70319524407387, 28.36529742926359, 40.59671759605408, 42.295503839850426, 27.35359411686659, 26.076592840254307, 8.3807229436934, 8.052316065877676, 58.16289000213146, 58.12601298093796, 61.561522632837296, 65.05263850092888, 63.0609829723835, 38.59714329242706, 7.240645894780755, 0.14525505801429972, 2.4293298181146383, 26.06669247150421, 64.3772779405117, 69.78063359856606, 68.91494885087013, 64.7478112578392, 67.31151089072227, 67.63691022992134, 65.83201467990875, 60.45708529651165, 59.06011305749416, 61.53839327394962, 64.43235978484154, 60.60474917292595, 57.66833133995533, 57.16586150228977, 58.26986946165562, 58.12775328755379, 60.79633869230747, 60.58088645339012, 60.6635358184576, 57.44394198060036, 59.490280374884605, 47.153406366705894, 52.8780347853899, 46.752216294407845, 44.89707224071026, 33.474250584840775, 25.258722826838493, 23.91695212572813, 17.048315294086933, 7.690528454259038, 3.07027087546885, 2.370653604157269, 1.3198120356537402, 3.2683466468006372, 0.7718030072283, 0.18843365513021126, 1.5868115960620344, 4.463938241824508, 4.8631177470088005, 3.537999652326107, 1.476686974056065, 0.8098330290522426, 1.345472177490592, 0.09110178143600933, 0.027439136611064896, 0.04608745235600509, 0.1013342612714041, 0.018826466439350042, 0.045300133861019276, 0.039321210351772606, 0.088956032122951, 0.3861957206390798, 0.008684950716997264, 0.07096876215655357, 0.0678251359204296, 0.06974959906074218, 0.03854763643175829, 0.05298759635479655, 0.00952440879700589, 0.03948094279621728, 0.087230360659305, 0.35107325529679656, 0.9319544385652989, 2.3519336711615324, 4.788124971091747, 12.115540634840727, 24.870552755892277, 17.98117283731699, 2.8888220619410276, 2.457651598379016, 3.488870901055634, 13.499649614095688, 16.78743839263916, 28.112042918801308, 36.62650063633919, 46.539089530706406, 46.886451691389084, 45.522450283169746, 47.82349281013012, 47.65276417136192, 47.20782324671745, 52.92197182774544, 38.37253734469414, 43.18952366709709, 51.26477815210819, 55.64532369375229, 53.947844579815865, 57.545480132102966, 52.36256964504719, 50.22183671593666, 48.302688896656036, 49.77080851793289, 46.23699054121971, 50.104685202240944, 45.92444211244583, 54.540673568844795, 54.881503880023956, 61.373390927910805, 60.149488002061844, 59.85303170979023, 59.52618084847927, 62.37500198185444, 66.12229630351067, 63.79995971918106, 60.32774783670902, 24.873098619282246, 0.17358170676743612, 4.616267317906022, 38.146536871790886, 60.19005462527275, 58.827641531825066, 64.94160085916519, 56.0786372423172, 60.20993135869503, 54.46540720760822, 47.89894916117191, 1.9713586801663041, 11.156415101140738, 37.86795102059841, 38.62190656363964, 86.65296703577042, 42.609731778502464, 22.35504023730755, 20.96032127737999, 31.244600526988506, 22.348415292799473, 38.843947649002075, 33.07936817407608, 31.06785111129284, 57.308547645807266, 57.573743015527725, 6.876689074561, 0.1547732058679685, 0.1535431554657407, 0.001163198319318326, 0.008926931677706307, 0.06566201293026097, 0.06226102472282946, 0.03815643925918266, 0.21153181412955746, 0.22290926455752924, 0.28404737531673163, 0.2462129242485389, 0.1267367962282151, 0.1513421829440631, 0.2744647645158693, 0.15847177302930504, 0.11595396194024943, 0.35701198037713766, 0.46842470357660204, 0.6040423060767353, 21.35151408612728, 77.7860440313816, 64.85150009393692, 49.02105934917927, 68.69182482361794, 62.671169489622116, 40.63158072531223, 71.17926254868507, 28.258236274123192, 41.616434678435326, 41.612232103943825, 35.014380142092705, 30.42356338351965, 11.484350804239511, 13.1671142578125, 67.5596983730793, 61.439788565039635, 64.60050836205482, 71.76322281360626, 68.66613820195198, 39.56330984830856, 7.290288805961609, 0.2466321931569837, 3.7542111380025744, 33.53564769029617, 69.82845783233643, 71.8431781232357, 72.61602625250816, 67.26399824023247, 70.22548332810402, 69.32468846440315, 68.3528982102871, 62.05311745405197, 64.11050945520401, 64.02126744389534, 66.74058392643929, 62.597567439079285, 60.164443999528885, 59.94616851210594, 60.43168745934963, 63.31731341779232, 61.34975999593735, 63.62110711634159, 67.32426300644875, 62.992567643523216, 61.95220626890659, 52.24419839680195, 56.3790263235569, 49.972114115953445, 48.858754858374596, 44.39079500734806, 32.95553281903267, 26.706583835184574, 21.15047637373209, 10.599653776735067, 3.3813867811113596, 2.590430248528719, 0.4843919217819348, 2.413410097360611, 1.2663189810700715, 0.2564821107080206, 2.8314800513908267, 10.581906829029322, 13.842197433114052, 10.368133150041103, 6.191771551966667, 1.2382508371956646, 1.4797640964388847, 0.12552239029901102, 0.15403407131088898, 0.2455068301060237, 0.13566463981987908, 0.08791112530161627, 0.15312062110751867, 0.22961685463087633, 0.3265752276638523, 1.7075448925606906, 0.36720962380059063, 0.31873221101704985, 0.2229184820316732, 0.14386406546691433, 0.10712512084865011, 0.2521307207643986, 0.1127877076214645, 0.14963163645006716, 0.17552227451233193, 0.49902389757335186, 1.049111948814243, 5.204949304461479, 10.860161148011684, 19.364209324121475, 40.05232460796833, 22.433756813406944, 1.9506724714301527, 4.686628142371774, 5.89317929930985, 17.35206339508295, 20.081658326089382, 32.026794254779816, 41.67981907725334, 49.03419144451618, 48.606790378689766, 47.15629801154137, 51.46530479192734, 49.921744018793106, 52.294412702322006, 49.01746854186058, 41.50903344154358, 46.836442574858665, 52.50307850539684, 60.07197976112366, 56.78530812263489, 60.810952708125114, 54.8056523501873, 54.61599312722683, 51.981476694345474, 53.453270718455315, 49.42829869687557, 54.067701548337936, 49.802343025803566, 57.34689898788929, 56.90668500959873, 64.71781566739082, 61.70432277023792, 63.186862617731094, 62.81252570450306, 64.0841692686081, 68.00938904285431, 65.28612837195396, 66.4071974158287, 37.85351559519768, 0.7493516150861979, 2.5368015887215734, 32.320115715265274, 60.9669229388237, 63.71267840266228, 69.98496383428574, 61.099516823887825, 63.45901921391487, 59.357963874936104, 53.60822260379791, 5.658829249441624, 10.675126276910305, 37.71043427288532, 42.90812596678734, 83.09230729937553, 49.14430193603039, 22.33605645596981, 31.085548661649227, 42.11610406637192, 27.989972569048405, 50.936289578676224, 40.37006355822086, 44.69946764409542, 65.98991140723228, 75.01801416277885, 10.809350274503231, 0.25180197902955115, 0.3219760791398585, 0.20729995449073613, 0.12106483613024466, 0.13540990505134687, 0.18301415140740573, 0.12073093646904454], [0.02446856065944303, 0.008721674039406935, 0.02474213299137773, 0.02217403300164733, 0.06471239787060767, 0.03655601634818595, 0.06243126597837545, 0.03609662322560325, 0.03571495151845738, 0.08036485640332103, 0.060474059282569215, 0.28632698580622673, 1.3831890723668039, 32.65284486114979, 51.3050027936697, 27.923882715404034, 61.39805160462856, 184.83314752578735, 36.326624527573586, 44.36876378953457, 29.660777114331722, 40.17720490694046, 53.134882003068924, 38.7523003667593, 35.05012482404709, 10.205744113773108, 1.6706096869893372, 16.572953201830387, 52.6172661781311, 61.83930292725563, 42.85590156912804, 53.80647696554661, 54.70765940845013, 20.981104262173176, 0.15094811737071723, 0.3800677479011938, 7.394067887216806, 47.46228039264679, 63.6568745970726, 64.68278914690018, 62.27030999958515, 64.46938499808311, 60.35241611301899, 67.32091158628464, 56.87868811190128, 54.30955857038498, 62.554253563284874, 60.72309382259846, 57.39255353808403, 54.54704962670803, 51.863945201039314, 54.60826434195042, 54.67743203043938, 55.190347507596016, 54.077296033501625, 54.01396103203297, 51.54311701655388, 54.7912473231554, 41.64424538612366, 39.07302215695381, 32.67145246267319, 21.06681816279888, 21.474315896630287, 22.32597179710865, 18.287449702620506, 10.288196839392185, 4.016826683655381, 3.9751182217150927, 4.338050996884704, 0.4847984405932948, 0.6032684538513422, 0.8875177230220288, 0.3587997250724584, 1.9165365281514823, 1.9149267207831144, 1.6471498645842075, 1.845845952630043, 0.20732796314405277, 0.028546547109726816, 0.026045921331387945, 0.07773702280246653, 0.1295718745677732, 0.16232481080805883, 0.03278254051110707, 0.08286636904813349, 0.040583277004770935, 0.040976908421725966, 0.12734078569337726, 0.30190582328941673, 0.030103187018539757, 0.12683429958997294, 0.18745740439044312, 0.1336481503676623, 0.17215923231560737, 0.07490504664019682, 0.20557698444463313, 0.05131112186063547, 0.09735079845995642, 0.046252160900621675, 0.13790343218715861, 0.05629162296827417, 0.7077312609180808, 3.322114236652851, 3.2358063803985715, 10.088834837079048, 14.93985878303647, 4.481393555179238, 6.788486782461405, 18.478813134133816, 14.774701595306396, 22.61999811977148, 34.69248801469803, 39.26863566040993, 42.565004378557205, 46.39407031238079, 41.27124980092049, 46.24456733465195, 46.562268286943436, 50.741265043616295, 45.17452195286751, 50.34537948668003, 48.780137076973915, 55.94559498131275, 50.277321338653564, 52.71449916064739, 50.483882054686546, 48.88829067349434, 45.07603123784065, 46.47469058632851, 45.546081215143204, 45.73017753660679, 45.11381261050701, 54.89026241004467, 59.37337204813957, 58.195306062698364, 58.69675375521183, 63.04679453372955, 57.79552951455116, 62.84202352166176, 57.55882881581783, 66.30970984697342, 46.76544338464737, 3.436252037063241, 1.1353751574642956, 33.26395846903324, 52.89512626826763, 44.87941078841686, 51.82418033480644, 52.22542740404606, 55.23887850344181, 48.36413539946079, 55.083406046032906, 26.840477250516415, 0.599436656339094, 14.891526326537132, 31.040716767311096, 39.56804059445858, 70.8535972237587, 26.906616501510143, 7.890994772315025, 23.57804261147976, 24.120942279696465, 27.71733719855547, 29.403994493186474, 17.866464592516422, 23.938153088092804, 53.54854680597782, 31.526946276426315, 2.1938424417749047, 0.1715058900299482, 0.06604612630326301, 0.07192257777205668, 0.0895745973684825, 0.06237811336177401, 0.10999894671840593, 0.09738921944517642, 0.18466412380803376, 0.02598470528027974, 0.027803558950836305, 0.08223788128816523, 0.045470523546100594, 0.0257733100806945, 0.04667074332246557, 0.06789492748794146, 0.04248071854817681, 0.024157713960448746, 0.15303858410334215, 0.305881894310005, 3.8588774716481566, 47.17596955597401, 61.61706045269966, 31.956650018692017, 67.39100262522697, 173.05168211460114, 53.178735449910164, 38.91292914748192, 31.441650353372097, 51.41417853534222, 64.02920141816139, 45.26740796864033, 31.58922303467989, 20.338009670376778, 1.9305822369642556, 16.300124041736126, 53.23773868381977, 65.13571724295616, 46.63235552608967, 58.32343898713589, 60.76048381626606, 29.18896023184061, 1.4750772854313254, 0.347993461182341, 5.559652671217918, 46.1703535169363, 65.92414453625679, 69.4151996076107, 64.68533501029015, 67.88699761033058, 62.81420141458511, 69.10350233316422, 58.297607973217964, 58.13517048954964, 65.92606723308563, 62.712800055742264, 59.73548501729965, 55.90043060481548, 53.71138706803322, 55.941035225987434, 57.14695371687412, 58.592912927269936, 57.716527953743935, 56.92163720726967, 55.029939115047455, 58.86270225048065, 45.60943901538849, 45.04990004003048, 38.19085009396076, 25.288986302912235, 24.008762799203396, 25.845206156373024, 19.869405515491962, 11.011082399636507, 7.865580786019564, 3.6869915574789047, 3.5337215568870306, 3.718163422308862, 3.8662322144955397, 0.7031196739990264, 5.8955123741179705, 4.830520246177912, 0.7007090596016496, 0.9084180265199393, 2.2591381380334496, 0.6517046922817826, 0.31296127068344504, 0.21844094182597473, 0.06072413707443047, 0.09420215530553833, 0.07880645760451443, 0.030198482490959577, 0.03562821671948768, 0.05760903157352004, 0.036990599473938346, 0.10694832642911933, 0.12525276804808527, 0.019763617128774058, 0.0962387421168387, 0.06709774213959463, 0.10194267393671907, 0.007046245509627624, 0.14238018571631983, 0.08083758963039145, 0.100573344680015, 0.0758167973253876, 0.09281492544687353, 0.2139451596303843, 0.34609335532877594, 1.4556366973556578, 1.2159842695109546, 5.342993047088385, 20.017200484871864, 23.61575558781624, 10.008919425308704, 12.275971826165915, 23.234457448124886, 24.04021181166172, 29.241289123892784, 40.20257234573364, 40.27041010558605, 43.72173830866814, 48.61171491444111, 45.539625361561775, 48.707325384020805, 48.42940829694271, 50.346694216132164, 52.797638699412346, 51.48783378303051, 52.55036696791649, 55.36120913922787, 53.76417763531208, 54.19027917087078, 54.912175834178925, 50.46022452414036, 47.813772931694984, 49.18044179677963, 47.72053733468056, 48.49767543375492, 46.26011610031128, 57.49750390648842, 61.93316929042339, 60.690350979566574, 60.3459070622921, 64.2320117354393, 61.55088700354099, 64.90789666771889, 59.25295650959015, 66.72887295484543, 44.278834015131, 2.449775096029043, 3.323737462051213, 44.558924585580826, 58.683199882507324, 49.674966260790825, 57.333664298057556, 56.54333710670471, 61.95220246911049, 50.56914567947388, 60.663649812340736, 21.93536225706339, 0.38637371733784676, 23.901505954563618, 35.22722192108631, 37.87199020385742, 72.75936976075172, 28.585425317287445, 15.249022543430328, 21.957687959074974, 34.41617824137211, 24.03182376176119, 44.33635152876377, 19.399382136762142, 27.135839201509953, 64.13475215435028, 38.564902022480965, 2.300829025916755, 0.1292322826338932, 0.12745687243295833, 0.098355636728229, 0.09764630682184361, 0.148510028666351, 0.08261787574156187, 0.055704977494315244, 0.3235391905764118, 0.1658551479340531, 0.12118359460146166, 0.14367468422278762, 0.2077657709014602, 0.12133168274885975, 0.20232665963703766, 0.20204633561661467, 0.26478270592633635, 0.2893203345593065, 0.36470689403358847, 0.6750032608397305, 7.696061432361603, 68.60935404896736, 71.49861261248589, 43.21550287306309, 70.5466876924038, 202.93979912996292, 48.68269510567188, 62.99271583557129, 36.52970843017101, 53.37156370282173, 63.0395483225584, 44.954813942313194, 42.90856294333935, 17.876138873398304, 4.355628853663802, 25.45098301023245, 60.848597288131714, 72.24923953413963, 51.108454540371895, 64.95068237185478, 66.15217790007591, 26.968940757215023, 1.4177901344373822, 0.46180338074918836, 11.051193047314882, 56.81549370288849, 70.33106446266174, 73.58234480023384, 66.66910976171494, 69.42862048745155, 65.9935288131237, 71.99356645345688, 60.49355573952198, 57.76797719299793, 68.43221515417099, 66.20017692446709, 62.448273450136185, 60.85281506180763, 56.79261893033981, 60.90241760015488, 60.445625111460686, 60.26057884097099, 59.63301591575146, 58.81324790418148, 57.133912816643715, 61.461568996310234, 47.55220636725426, 48.23871552944183, 44.41025756299496, 32.51092627644539, 29.02818325906992, 29.943548440933228, 23.747551515698433, 14.72237080335617, 9.313409496098757, 4.001361038535833, 4.048162652179599, 3.359454832971096, 2.6754490239545703, 0.7553398562595248, 7.570423549041152, 12.015198469161987, 7.819375740364194, 5.729772392660379, 4.9945564940571785, 0.4853511624969542, 0.3551763226278126, 0.22667447658022866, 0.1579650494386442, 0.325844093458727, 0.19710611086338758, 0.09769770796992816, 0.10803457829752006, 0.11889078872627579, 0.13120360497850925, 0.49499008746352047, 1.2011894071474671, 0.14135379547951743, 0.3144455363508314, 0.4072692117188126, 0.25284410279709846, 0.3166297957068309, 0.32731087412685156, 0.4163674375740811, 0.24707253905944526, 0.13600696285720915, 0.21866435796255246, 0.32096883631311357, 0.3728751791641116, 2.144327536225319, 9.024940375238657, 17.021030858159065, 31.12649906426668, 24.36342816799879, 8.228523060679436, 11.734802965074778, 24.16782796382904, 19.813242629170418, 30.064524449408054, 45.16129866242409, 45.24422541260719, 47.896103113889694, 52.476753517985344, 47.963701486587524, 49.91037882864475, 52.639297395944595, 50.82014121115208, 46.54957316815853, 52.82367870211601, 54.374238699674606, 58.39303985238075, 55.17787657678127, 55.70645101368427, 57.23905697464943, 53.47957290709019, 51.40523761510849, 50.922150537371635, 51.912111416459084, 51.42191492021084, 49.34292487800121, 61.116786897182465, 65.48744916915894, 63.32104101777077, 63.35293270647526, 68.9013759791851, 62.62844078242779, 68.34728971123695, 62.06444464623928, 68.59280213713646, 49.777834340929985, 5.844737598672509, 1.7931102449074388, 41.903805658221245, 62.07202523946762, 56.09776921570301, 61.08349308371544, 63.29883120954037, 64.84833866357803, 58.69150623679161, 64.20967653393745, 36.59363999962807, 0.587292033014819, 20.19338373094797, 43.4898329526186, 42.25023306906223, 79.2367833852768, 34.10052917897701, 11.023429837077856, 33.03006961941719, 38.96867215633392, 33.63186992704868, 47.91949465870857, 25.373915545642376, 40.56775934994221, 72.39708960056305, 54.57399398088455, 4.126627966761589, 0.31060982029885054, 0.2987045841291547, 0.16900455550057814, 0.1880728971445933, 0.30700042960233986, 0.1292006522999145, 0.17609674134291708], [0.0705933319113683, 0.04784043485415168, 0.05753953315434046, 0.05856130723259412, 0.05279637087369338, 0.012946452661708463, 0.03093225503107533, 0.07844017804018222, 0.08148238979629241, 0.04444094949576538, 0.09087556740269065, 0.39898262824863195, 0.9651075408328325, 25.443698801100254, 45.61787076294422, 41.16684280335903, 31.595642790198326, 28.26989594846964, 20.6050593405962, 41.10443115234375, 41.59721910953522, 27.975145764648914, 55.72677992284298, 39.17048692703247, 33.92057843506336, 26.705153211951256, 2.861376847140491, 12.088396791368723, 39.77093830704689, 64.5183415710926, 94.81926843523979, 54.67810459434986, 43.89315851032734, 47.35071457922459, 26.97887722402811, 7.701332224532962, 1.6042942204512656, 14.260917864739895, 50.06901651620865, 64.1448900103569, 64.299496114254, 63.08373995125294, 67.00712442398071, 64.24471065402031, 54.04579572379589, 55.11385001242161, 60.553584918379784, 58.41993860900402, 57.43223860859871, 51.51891991496086, 53.296886309981346, 53.99925582110882, 56.1223690956831, 56.86351552605629, 54.03890289366245, 56.05336859822273, 57.863473668694496, 49.07293036580086, 32.978646978735924, 27.19615336507559, 22.098981477320194, 21.091045662760735, 25.358944348990917, 20.080184005200863, 18.018730022013187, 8.209243845194578, 5.038380017504096, 5.48067438416183, 3.303249911405146, 4.712562700733542, 3.7575209978967905, 4.257295830175281, 5.5132172629237175, 0.8358556951861829, 0.6062436348292977, 0.49161025788635015, 0.10981470855767839, 0.13268473878270015, 0.03675487852888182, 0.0783763978688512, 0.05395685606345069, 0.06470932537922636, 0.06950069757294841, 0.06159286916954443, 0.21181147021707147, 0.06424478546250612, 0.0821658039058093, 0.04592826167936437, 0.07952545027364977, 0.0832292421546299, 0.17294003104325384, 0.24129857076331973, 0.6362270540557802, 0.5350118258502334, 0.6567198294214904, 0.33225521037820727, 0.14860336115816608, 0.17995921924011782, 0.019700968732649926, 0.06613887249841355, 0.16981299180770293, 0.4068144829943776, 0.20571483095409349, 1.6358720697462559, 1.4520062296651304, 16.97058856487274, 20.976550206542015, 8.835732378065586, 12.819245774298906, 19.81784038245678, 27.451465465128422, 38.46502058207989, 39.231374859809875, 40.1602616161108, 41.994343400001526, 47.14930638670921, 45.43917015194893, 46.65309101343155, 45.68076118826866, 55.25410048663616, 53.14030431210995, 50.72036996483803, 50.07450342178345, 51.66247621178627, 51.11736126244068, 47.19086475670338, 50.058122500777245, 47.844995856285095, 47.257775366306305, 48.282656371593475, 45.84824860095978, 45.045788660645485, 54.505232870578766, 52.044203728437424, 57.77245715260506, 52.25212097167969, 56.35351449251175, 56.362558007240295, 62.32855327427387, 50.669661685824394, 52.39179387688637, 15.517704226076603, 2.758147311396897, 29.966869689524174, 53.55153724551201, 48.014022186398506, 54.31186504662037, 56.85783103108406, 61.12484246492386, 50.6263630092144, 60.92330887913704, 35.53108021616936, 1.6065350314602256, 2.0161974616348743, 34.73914951086044, 29.430353678762913, 35.62204733490944, 37.600528970360756, 8.256741296499968, 11.135256886482239, 29.768930710852146, 24.290973655879498, 31.48452155292034, 31.82237472385168, 22.74931088089943, 37.41184629499912, 53.928302228450775, 15.189977511763573, 0.4061563464347273, 0.20156806596787646, 0.17458338348660618, 0.19800734531600028, 0.1136343867983669, 0.04339384220656939, 0.08450256718788296, 0.0782473012804985, 0.058080239687114954, 0.01780135826265905, 0.052371053461683914, 0.06278558954363689, 0.0935201883839909, 0.08165770734194666, 0.044799421666539274, 0.06293508035014383, 0.09307084765168838, 0.10622744128340855, 0.05516026336408686, 0.5470843124203384, 1.4129518065601587, 41.77573353052139, 61.20253309607506, 41.041973903775215, 35.73042131960392, 42.04374834895134, 27.08386179059744, 46.26468725502491, 34.8276923596859, 38.35058972239494, 57.47082933783531, 48.00399832427502, 31.208941340446472, 38.02862159907818, 6.329137030988932, 11.469747237861156, 44.5414075255394, 65.34882500767708, 94.52160000801086, 59.71200227737427, 47.426870092749596, 55.51831170916557, 39.27113592624664, 14.844664391130209, 3.5276110097765923, 13.81199760362506, 47.58197396993637, 68.2920254766941, 66.23228520154953, 65.72865262627602, 70.4984150826931, 65.48706918954849, 54.516267478466034, 58.69466386735439, 61.12875625491142, 61.69285498559475, 60.67624233663082, 55.97639612853527, 59.12993811070919, 57.767988592386246, 58.433044105768204, 58.151676803827286, 57.85359799861908, 58.26225467026234, 61.15624777972698, 52.104255706071854, 40.17108343541622, 34.31900605559349, 24.284506402909756, 25.033077634871006, 27.09091991186142, 21.765707060694695, 21.74694936722517, 10.08416298776865, 8.703314233571291, 10.721549335867167, 5.873385211452842, 11.696436423808336, 6.893878877162933, 7.764732772484422, 14.823449179530144, 3.012764761224389, 1.1627389141358435, 1.1915575177408755, 0.2636432717554271, 0.14552267646649852, 0.021788017875223886, 0.04040247127704788, 0.030445263291767333, 0.08503391523845494, 0.06163693418784533, 0.029799524309055414, 0.11221884400583804, 0.03574493057385553, 0.027201747689105105, 0.0433833705028519, 0.04064451903104782, 0.1323458889964968, 0.17368902132147923, 0.25271862046793103, 0.2693571854615584, 0.3812072117580101, 0.29017092485446483, 0.12098239094484597, 0.22920435410924256, 0.20834457187447697, 0.004961281338182744, 0.05894831498153508, 0.14528575324220583, 0.35154920944478363, 1.1775502818636596, 0.4873919201781973, 4.652803782373667, 20.73188703507185, 25.826520659029484, 13.7535928376019, 19.15389820933342, 22.883905358612537, 33.63725423812866, 39.62861314415932, 39.72409062087536, 42.76362732052803, 42.21928372979164, 48.99897113442421, 48.23751859366894, 46.88291788101196, 45.08788280189037, 53.361790627241135, 53.07249695062637, 53.533062636852264, 51.81397408246994, 53.69828537106514, 56.657783165574074, 50.07009945809841, 51.91051170229912, 50.11005811393261, 50.971346497535706, 50.41650027036667, 49.54776048660278, 48.21584835648537, 58.02850641310215, 53.70487421751022, 61.06876127421856, 53.45409907400608, 57.453065291047096, 55.470069497823715, 63.03977631032467, 50.73512077331543, 50.444170385599136, 12.265521436929703, 4.974425649270415, 40.873418748378754, 56.16521939635277, 56.53770200908184, 62.055290937423706, 62.394369542598724, 67.80279412865639, 52.26351276040077, 67.35624969005585, 29.840332679450512, 1.4301787759177387, 5.807465873658657, 39.97011601924896, 32.846984043717384, 36.49112910032272, 37.62816868722439, 13.992415722459555, 13.35302023217082, 29.375965297222137, 32.15580113232136, 24.89583659917116, 41.33083440363407, 19.036079831421375, 44.576194658875465, 65.64859852194786, 17.420444525778294, 0.8150617266073823, 0.10012398910475895, 0.23432180372765288, 0.11882074482855387, 0.13696765818167478, 0.05822284336318262, 0.06945193104911596, 0.02501484257663833, 0.1625764137133956, 0.2005799111793749, 0.14850904903141782, 0.20000491000246257, 0.1735175258363597, 0.19293414254207164, 0.1578118107863702, 0.24238758342107758, 0.41170137701556087, 0.26411768223624676, 0.11878207893460058, 0.8934838185086846, 3.114965739659965, 64.00354519486427, 69.91757065057755, 56.25503897666931, 42.76980198919773, 39.80148866772652, 24.071539230644703, 62.82171741127968, 51.54792755842209, 36.437339186668396, 62.87365682423115, 51.40347070991993, 39.60435524582863, 38.20827975869179, 6.739725898951292, 16.815404891967773, 50.140274092555046, 70.2427875995636, 93.67400228977203, 62.7275774627924, 58.98106969892979, 63.813015818595886, 37.34693057835102, 11.313799805939198, 3.001611172221601, 19.682398550212383, 55.780953615903854, 69.65066537261009, 68.68031144142151, 71.27801164984703, 71.12204521894455, 69.6191194653511, 53.76834601163864, 60.46334736049175, 66.0453200340271, 65.50254195928574, 62.59887836873531, 60.374090149998665, 61.35714299976826, 61.820828318595886, 61.37630917131901, 64.97288838028908, 59.9661136418581, 63.5197551548481, 64.45542454719543, 55.93686304986477, 43.45855303108692, 39.069784730672836, 31.612768471240997, 28.777966685593128, 31.282193809747696, 24.637870341539383, 23.741849921643734, 14.141500722616911, 13.202675599604845, 10.155711248517036, 4.589566625654697, 10.00338027253747, 8.552095647901297, 13.158334828913212, 28.35422482341528, 11.2903493642807, 4.995736330747604, 2.5231562834233046, 0.5173058446962386, 0.2879407414002344, 0.12064013470080681, 0.20782987761776894, 0.10676435544155538, 0.2370082595734857, 0.2811047004070133, 0.16210541711188853, 0.42313579469919205, 0.13475927902618423, 0.37749786861240864, 0.19888189213816077, 0.4883739002980292, 0.2526482648681849, 0.5089634517207742, 0.5957737716380507, 0.7768895092885941, 1.0389594873413444, 0.9841209487058222, 0.9458588424604386, 0.4742926574544981, 0.4327721073059365, 0.0917613874480594, 0.23065394663717598, 0.4225693875923753, 0.7849403272848576, 1.5364980208687484, 9.739896710962057, 13.251711018383503, 30.53728748112917, 31.610534191131592, 12.838797625154257, 17.361348196864128, 24.41029105335474, 34.45554032921791, 45.17842434346676, 46.295074224472046, 47.70420581102371, 47.13519774377346, 53.36977779865265, 51.294811740517616, 50.06441876292229, 46.88754603266716, 50.422678738832474, 56.86562441289425, 56.45829766988754, 53.368531465530396, 56.55525706708431, 58.009826615452766, 52.1618340164423, 55.56316830217838, 54.7846394777298, 53.720217794179916, 54.09016214311123, 51.004951894283295, 51.349057629704475, 61.48171931505203, 56.2921591848135, 62.660321071743965, 55.9356015175581, 59.87168110907078, 57.66846813261509, 65.22301375865936, 53.27529586851597, 59.52514350414276, 22.550404854118824, 3.242696598172188, 37.078376188874245, 63.18294122815132, 57.704205214977264, 64.3872258067131, 64.96963575482368, 72.22754269838333, 59.59066338837147, 71.4719608426094, 43.90922784805298, 4.331211838871241, 3.133188374340534, 50.26254013180733, 41.00773014128208, 39.37970370054245, 47.76092916727066, 15.39265863597393, 13.821583539247513, 46.03763423860073, 33.05681638419628, 38.58613908290863, 48.38113568723202, 29.146742597222328, 56.46332859992981, 77.81626760959625, 30.631030350923538, 1.0682283667847514, 0.37170950265135616, 0.3953083441592753, 0.29985702072735876, 0.2126259179203771, 0.25783273042179644, 0.1719853768008761, 0.14575281646102667], [0.09556138393236324, 0.04622831198503263, 0.08827868878142908, 0.014025999225850683, 0.03993500358774327, 0.10418356658192351, 0.03126576506474521, 0.03545565625245217, 0.045020273682894185, 0.09925981008564122, 0.06265221076318994, 0.29399865539744496, 0.5558890337124467, 12.44627583771944, 54.565714225173, 36.30840450525284, 37.539082467556, 27.281113006174564, 33.3940064907074, 33.69656145572662, 51.678670942783356, 22.037078998982906, 43.22088338434696, 36.31489835679531, 26.11407782882452, 40.702644512057304, 6.316742096096277, 4.735518218949437, 35.702025443315506, 60.61011828482151, 65.06806567311287, 47.35759600996971, 34.871070832014084, 53.616019785404205, 58.35631862282753, 59.81327824294567, 34.329831674695015, 9.657631125301123, 14.555249121040106, 47.25885070860386, 68.24774265289307, 65.29334038496017, 59.234155118465424, 55.03546021878719, 53.061606734991074, 57.94536307454109, 60.75182408094406, 60.60085818171501, 57.40206442773342, 55.51630541682243, 53.92023526132107, 57.70160235464573, 54.720571115612984, 55.292622819542885, 54.71771366894245, 50.542980283498764, 48.27020063996315, 38.47674295306206, 29.547790177166462, 31.684350930154324, 26.040110997855663, 28.030960969626904, 22.12251741439104, 26.985811851918697, 12.899242881685495, 7.870729034766555, 7.964722691103816, 7.537597585469484, 11.2794372998178, 8.40230293571949, 13.90346059575677, 11.003739293664694, 3.2175253238528967, 1.6564484406262636, 0.840276520466432, 0.30636455747298896, 0.09110780025366694, 0.056690790806896985, 0.037135915699764155, 0.07998498069355264, 0.014913258110027527, 0.0621438062080415, 0.0744083865720313, 0.2154400380095467, 0.3252241626614705, 0.31030417419970036, 0.3042727994034067, 0.04914840334095061, 0.3106621268671006, 0.17228919721674174, 0.09471601093537174, 0.8581111603416502, 1.0856621875427663, 0.9645677916705608, 1.2408971576951444, 1.0217842902056873, 0.05492131407663692, 0.038123402555356734, 0.06361267602187581, 0.018353469749854412, 0.004248428549544769, 0.10628572956193238, 0.06633447294007055, 0.49626794701907784, 2.30202192440629, 3.619376323185861, 16.315583512187004, 20.17302632331848, 13.59412869438529, 17.658138871192932, 24.28353175520897, 35.93069717288017, 28.382628299295902, 29.063988737761974, 37.12956324219704, 36.54440604150295, 45.445299223065376, 45.32635420560837, 41.3401211053133, 44.94664438068867, 52.914406433701515, 49.76638935506344, 51.78296774625778, 48.27412202954292, 47.77757607400417, 48.48379857838154, 49.99614402651787, 47.184655889868736, 48.930039033293724, 45.49131475389004, 46.42101466655731, 45.32139167189598, 54.76654104888439, 54.86406281590462, 60.124705731868744, 55.126324743032455, 54.56510245800018, 49.22657512128353, 53.05849850177765, 43.726263865828514, 31.89447395503521, 2.106974353082478, 23.909840807318687, 51.00686319172382, 50.154979303479195, 37.16764099895954, 34.4531312584877, 42.272701263427734, 44.48719963431358, 60.63757561147213, 45.83332300186157, 4.822324085980654, 5.281481947749853, 40.67113280296326, 54.61911275982857, 33.572076335549355, 34.034245535731316, 24.036393016576767, 5.3258151188492775, 24.021239429712296, 28.07629443705082, 24.73852314054966, 45.13727255165577, 31.885586231946945, 24.39098048955202, 47.721255496144295, 51.1033970117569, 5.39018508978188, 0.1722139582852833, 0.07840179416234605, 0.08098971506115049, 0.023202618140203413, 0.11317922020680271, 0.10868026904063299, 0.011425522116041975, 0.05116059946885798, 0.022391988786694128, 0.06116793767432682, 0.05739451378758531, 0.05430378412711434, 0.02314274537638994, 0.03855840870528482, 0.027823353884741664, 0.04746353886730503, 0.050088930802303366, 0.09358398339827545, 0.04126028266909998, 0.4705436836229637, 0.22590742242755368, 23.31577118486166, 71.15263357758522, 38.007806316018105, 40.56484870612621, 29.77153167128563, 18.325679451227188, 39.810946360230446, 41.163141801953316, 30.72164598852396, 50.598358511924744, 36.67923800647259, 28.888576850295067, 38.2321272790432, 13.435742743313313, 4.155475543811917, 29.19182527810335, 64.80435222387314, 68.24908778071404, 50.82550272345543, 44.435055032372475, 56.87323160469532, 60.34695200622082, 65.18990233540535, 44.29714523255825, 14.245648384094238, 13.661721367388964, 42.55091853439808, 67.30581119656563, 68.47980380058289, 57.86296829581261, 55.17986387014389, 55.49202471971512, 60.57362504303455, 61.744190230965614, 64.41124051809311, 59.95905742049217, 58.310531079769135, 56.03925235569477, 61.88396953046322, 58.77264708280563, 59.29176762700081, 58.158733025193214, 55.32913126051426, 53.16368445754051, 43.585006445646286, 34.87967737019062, 34.73295584321022, 28.591548688709736, 29.718773402273655, 24.831810034811497, 32.13547222316265, 12.753590047359467, 12.549608442932367, 12.316834833472967, 10.207691509276628, 12.461619414389133, 13.048732560127974, 16.376416347920895, 13.097919970750809, 7.41459533572197, 0.9817694092635065, 1.7173062125220895, 0.536207277327776, 0.2634587441571057, 0.041600119511713274, 0.032539739477215335, 0.034325803208048455, 0.03325600846437737, 0.06304193477262743, 0.14038947847438976, 0.11529471958056092, 0.10863905015867203, 0.09834757700446062, 0.25447017804253846, 0.0728233446716331, 0.3762971924152225, 0.055274465048569255, 0.316274247597903, 0.3504870180040598, 1.014713344629854, 1.1994254705496132, 0.7552553701680154, 0.4662835184717551, 0.35244625818450004, 0.16976726066786796, 0.0735645869281143, 0.08388302230741829, 0.056322214295505546, 0.11086740050814115, 0.7691243290901184, 0.9966342709958553, 1.454950359184295, 10.458768736571074, 19.135579392313957, 21.252780184149742, 17.163458615541458, 20.592164732515812, 23.326406814157963, 38.84315729141235, 29.87541999667883, 30.69123052060604, 42.10729233920574, 38.500263690948486, 45.21954573690891, 45.46251229941845, 40.04853241145611, 45.7361926138401, 54.31376874446869, 51.741295382380486, 55.626917481422424, 52.154652401804924, 50.18795393407345, 49.14365977048874, 53.08215223252773, 50.16736663877964, 51.17483697831631, 48.505438417196274, 50.18983103334904, 48.954676911234856, 59.254092648625374, 60.08804149925709, 62.88005568087101, 55.238323733210564, 54.158091098070145, 50.21843209862709, 53.451667204499245, 40.85670344531536, 30.85998136550188, 4.105043699964881, 32.21770741045475, 54.539199247956276, 57.71153882145882, 38.17103035748005, 39.4362560659647, 47.32043780386448, 51.715920343995094, 67.32287988066673, 43.193437457084656, 1.9335032114759088, 13.299612198024988, 44.697962924838066, 61.33073441684246, 41.966164112091064, 31.806786060333252, 25.211386866867542, 12.039298675954342, 20.23640312254429, 39.83201242983341, 24.412257447838783, 39.05901990830898, 38.31174060702324, 22.641858346760273, 57.74266675114632, 58.61793078482151, 8.745858650654554, 0.21930377755779773, 0.09037763826199807, 0.20727739320136607, 0.07129779332899489, 0.11571591065148823, 0.11300910511636175, 0.015748876503494103, 0.03181991931342054, 0.2336204593302682, 0.3018715063808486, 0.2554385917028412, 0.19052762479986995, 0.09593287337338552, 0.2127724772435613, 0.17253895959584042, 0.1523704285500571, 0.16061910311691463, 0.28007382759824395, 0.17146593279903755, 0.8092899550683796, 0.8272318204399198, 42.15669348835945, 83.3517573773861, 51.069677621126175, 51.72070048749447, 38.41414511203766, 38.07987704873085, 51.57144449651241, 67.84882485866547, 28.589652590453625, 52.82011069357395, 43.98770123720169, 34.57289323210716, 50.3898561000824, 13.580457028001547, 7.079827599227428, 43.56559708714485, 71.6626650094986, 74.90335151553154, 55.50570398569107, 48.74818459153175, 66.12656727433205, 72.16845586895943, 72.82163321971893, 40.281475111842155, 13.626388013362885, 19.54369269311428, 54.350869953632355, 73.04155021905899, 69.41206857562065, 61.37475125491619, 55.46172894537449, 56.56778499484062, 62.080320194363594, 64.0728534758091, 67.42104381322861, 63.632001131772995, 63.440696597099304, 58.87990012764931, 65.29505789279938, 60.5425389111042, 61.95621885359287, 60.26064343750477, 59.20496888458729, 56.214035376906395, 49.424441903829575, 39.20771732926369, 38.054224625229836, 34.30806644260883, 35.60240998864174, 28.40703248977661, 39.21892672777176, 20.715673305094242, 18.094676546752453, 15.039142705500126, 11.981918904930353, 16.18085604161024, 13.398428745567799, 24.97187241911888, 23.58842745423317, 17.958647646009922, 8.401677869260311, 2.7525965217500925, 0.5849553365260363, 0.3072861861437559, 0.0716157590795774, 0.21907007525442168, 0.19865243491949514, 0.1174166014243383, 0.18072798033244908, 0.4617173509905115, 0.47681052703410387, 0.8007915923371911, 0.5518812581431121, 0.8943030308000743, 0.12174412389867939, 1.0290287202224135, 0.4101683967746794, 0.8292825822718441, 1.2660899246111512, 2.052675266750157, 1.6809008410200477, 1.6196000366471708, 1.2410787167027593, 0.8982443693093956, 0.4962784855160862, 0.14795850904192775, 0.15552825207123533, 0.14748249552212656, 0.2040942179155536, 1.252377291675657, 1.2416556919924915, 8.683760482817888, 18.18127389997244, 27.8136620298028, 25.75177486985922, 19.458451867103577, 27.62587420642376, 33.25876034796238, 43.40874530375004, 34.0299441665411, 40.3059495985508, 45.935480520129204, 41.54383197426796, 47.87614278495312, 48.67592766880989, 41.936195120215416, 47.95225650072098, 58.462895303964615, 54.140452444553375, 57.6508104801178, 54.97614160180092, 52.57308214902878, 52.446260154247284, 55.76447390019894, 52.215494737029076, 52.06355608999729, 50.311287716031075, 51.60409614443779, 52.11937129497528, 59.573982283473015, 63.009666725993156, 63.891253620386124, 57.902892753481865, 56.58489167690277, 52.32663497328758, 54.87633615732193, 45.32730035483837, 38.621568381786346, 4.607790447771549, 29.560198411345482, 63.845815658569336, 60.28550550341606, 45.59746205806732, 46.107406094670296, 53.19510877132416, 54.894537180662155, 71.27013847231865, 56.1633574962616, 7.668719524517655, 8.699357695877552, 48.93685586750507, 68.67816835641861, 42.416576743125916, 37.19803936779499, 32.61593744158745, 9.905785359442234, 30.08771650493145, 48.93657848238945, 27.35066257417202, 61.68955296278, 41.951071321964264, 34.04925473034382, 65.01470133662224, 77.44497433304787, 15.954726375639439, 0.4070153081556782, 0.17816187115386128, 0.3064756718231365, 0.19319233571877703, 0.2903730561956763, 0.20697899046353996, 0.09718602683278732, 0.10649099276633933], [0.07257693680003285, 0.11088194660260342, 0.02884070847358089, 0.062019325778237544, 0.08297446285723709, 0.0509331015200587, 0.05650453771522734, 0.026752876365208067, 0.06091908442613203, 0.028668175837083254, 0.1448031939798966, 0.29184708022512496, 0.21797882131068036, 11.373080424964428, 60.13816460967064, 49.29524503648281, 31.61728072911501, 47.96899080276489, 60.14505743980408, 34.0388622879982, 52.676907777786255, 25.102870389819145, 35.63541881740093, 34.14070822298527, 14.825532417744398, 51.04106515645981, 43.30335795879364, 3.7241941737011075, 2.7481094375252724, 26.064921766519547, 55.16321696341038, 74.83498558402061, 66.75719663500786, 52.63392448425293, 44.961186200380325, 44.674020409584045, 62.06408366560936, 37.59723834693432, 9.508383683860302, 11.68284835293889, 36.51107423007488, 55.252200588583946, 62.32186183333397, 54.96952995657921, 55.364302173256874, 56.15012660622597, 60.96730671823025, 59.161130636930466, 62.23265781998634, 59.24447536468506, 58.97967517375946, 59.63299311697483, 58.3316845446825, 57.477649971842766, 54.99511018395424, 55.654633194208145, 48.1481321901083, 36.17707975208759, 38.50788988173008, 34.087283089756966, 26.379552483558655, 28.71696475893259, 24.30854581296444, 7.864885423332453, 8.77792228013277, 18.520103618502617, 17.661811374127865, 15.432649590075016, 14.648294728249311, 19.23442728817463, 18.089955300092697, 6.658357540145516, 1.205912078730762, 1.7043873807415366, 0.4954359994735569, 0.46581703412812203, 0.13287545589264482, 0.10583738330751657, 0.053392289482872, 0.08989300098619424, 0.07818286801921204, 0.18696108571020886, 0.6154306512326002, 0.42321208748035133, 0.9456275298725814, 0.8880441728979349, 0.8001757285092026, 0.24519543978385627, 0.6581953971181065, 0.18775988894049078, 0.7655557862017304, 3.360935328528285, 4.280757671222091, 2.472043801099062, 2.307036705315113, 1.5043352404609323, 0.4121033241972327, 0.17335435724817216, 0.12278457041247748, 0.10801036201883107, 0.059421192927402444, 0.21225371601758525, 0.036761988303624094, 0.6004681822378188, 0.3599250881234184, 3.1254327530041337, 12.94105488806963, 22.099298760294914, 17.670089229941368, 18.1530699133873, 12.985947579145432, 20.475710481405258, 34.74636532366276, 13.007425926625729, 17.818617559969425, 31.03748694062233, 31.752557270228863, 37.65715353190899, 40.83147659897804, 43.17750111222267, 53.45469944179058, 50.761639550328255, 51.1664280295372, 49.87005539238453, 49.52228285372257, 45.58526091277599, 47.54383161664009, 50.52359752357006, 50.153204798698425, 50.70603333413601, 48.69151063263416, 49.929658994078636, 51.15398369729519, 52.55992345511913, 55.28992496430874, 55.191358253359795, 47.346314415335655, 55.02648510038853, 45.18944375216961, 34.25063632428646, 16.854219809174538, 15.54943822324276, 53.04208718240261, 50.18338277935982, 53.887929394841194, 45.00873684883118, 47.68022149801254, 50.11441268026829, 39.79631334543228, 51.65790505707264, 3.27989992685616, 2.2511504916474223, 44.378483667969704, 70.86369708180428, 57.39878140389919, 21.11433271318674, 17.942141331732273, 12.943953182548285, 7.226147772744298, 30.29814351350069, 22.090627625584602, 38.18271853029728, 36.50505155324936, 20.927097760140896, 34.24583338201046, 53.60455200076103, 34.41203646361828, 2.7139616198837757, 0.12225747486809269, 0.0647892769484315, 0.13592992792837322, 0.13334611110622063, 0.015393256035167724, 0.1296711145550944, 0.020632727719203103, 0.08668377631693147, 0.016743931410019286, 0.06498305170680396, 0.030369512278412003, 0.06628043716773391, 0.06995426854700781, 0.1335613487754017, 0.05085118697024882, 0.0326686431071721, 0.05348745507944841, 0.0384344960184535, 0.23973459843546152, 0.2594682457856834, 0.3282325027976185, 15.563280880451202, 74.76110234856606, 54.97968301177025, 31.795681156218052, 43.77786509692669, 42.147178798913956, 41.435978561639786, 45.51364615559578, 28.856476172804832, 46.62779577076435, 31.379527486860752, 26.860868856310844, 49.60095763206482, 45.444379672408104, 9.250614065676928, 2.299713073298335, 21.39456007629633, 61.92652344703674, 83.45293074846268, 67.78576344251633, 60.415070950984955, 54.668426513671875, 50.61110682785511, 66.48551121354103, 48.08338366448879, 13.323686756193638, 11.86053916811943, 32.56347745656967, 53.681292682886124, 62.612075060606, 54.81338493525982, 54.78945381939411, 56.13677032291889, 62.240891978144646, 63.781371116638184, 65.54432451725006, 63.36430549621582, 62.78387524187565, 63.0718769878149, 61.652478352189064, 59.53188054263592, 60.09218707680702, 59.40071918070316, 54.035851657390594, 38.27213153243065, 43.72535191476345, 34.39479298889637, 28.21383945643902, 31.833758912980556, 28.732616119086742, 8.816091232001781, 11.189883705228567, 23.193444348871708, 19.04138244688511, 15.090057123452425, 15.878891944885254, 19.59732871502638, 21.030378118157387, 10.944192688912153, 6.897144326940179, 1.4104283857159317, 0.9352181071881205, 0.7257937698159367, 0.02402018286375096, 0.03490280818368774, 0.03260342316934839, 0.08485263082548045, 0.03498998084978666, 0.22049263876397163, 0.48170887981541455, 0.332041917135939, 0.8614519529510289, 0.45723513525445014, 0.3161696344614029, 0.05922924756305292, 0.36762205010745674, 0.24733157828450203, 0.43905227968934923, 2.095640036277473, 2.1219405625015497, 1.688135415315628, 1.768206381238997, 1.0584297613240778, 0.5025758757255971, 0.1794404283282347, 0.06435176605009474, 0.04662041086703539, 0.06768176041077822, 0.08346945309313014, 0.08255965425632894, 0.32532227458432317, 2.1332435309886932, 5.396718364208937, 18.235042914748192, 24.827565662562847, 20.856885127723217, 22.640642412006855, 19.361583665013313, 23.27185694128275, 37.526824325323105, 18.184819109737873, 20.527777187526226, 35.41540302336216, 35.25348611176014, 38.360571786761284, 40.4193165153265, 46.57297991216183, 53.955295979976654, 54.54630866646767, 53.15856233239174, 50.44697463512421, 52.99374237656593, 48.027116283774376, 49.01197023689747, 53.49966622889042, 51.79393395781517, 54.49246935546398, 51.87170818448067, 53.548216223716736, 53.6016109585762, 55.495322942733765, 58.38737815618515, 57.85151571035385, 50.059194043278694, 52.48349815607071, 42.63602256774902, 40.2963475137949, 19.955742582678795, 21.98825541883707, 59.450336918234825, 55.22539682686329, 60.41929632425308, 49.911769554018974, 52.771226316690445, 54.31483268737793, 44.38840493559837, 46.59790277481079, 1.5950171370059252, 5.647822190076113, 55.14357201755047, 75.5950815975666, 79.22120422124863, 26.30648050457239, 18.900803290307522, 17.0693376660347, 10.496268924325705, 24.11618873476982, 37.012005150318146, 26.107487082481384, 41.92202568054199, 21.225984022021294, 32.21665866672993, 68.72441947460175, 39.390658512711525, 3.662687111645937, 0.11339282515109517, 0.09724266012199223, 0.040061877443804406, 0.03447350914939307, 0.05520049518963788, 0.13513850164599717, 0.06895650294609368, 0.0738980709866155, 0.21694092778488994, 0.35085488576442003, 0.13068282511085272, 0.31655017810408026, 0.18598336551804096, 0.4548202460864559, 0.13798309431876987, 0.10031752637587488, 0.2297911257483065, 0.14230123604647815, 0.5757202883251011, 0.4366169369313866, 0.4583618638571352, 21.956160441040993, 90.22406101226807, 66.19856581091881, 48.202400878071785, 60.73771923780441, 71.4311434328556, 47.725963443517685, 74.52177599072456, 31.042831353843212, 49.63658832013607, 37.46103085577488, 28.55350323021412, 57.73898854851723, 55.01895010471344, 7.779632722958922, 4.526040209457278, 34.383811578154564, 68.4214997291565, 85.1495549082756, 75.33706024289131, 65.90627789497375, 58.76660920679569, 59.72707226872444, 73.01272496581078, 47.04671569168568, 12.63508390635252, 16.123661510646343, 41.27564996480942, 58.72492164373398, 67.66738459467888, 54.206823483109474, 56.868322268128395, 58.304041028022766, 65.4236201941967, 65.47581419348717, 66.22785463929176, 67.52616137266159, 64.47249323129654, 66.29799887537956, 62.847730815410614, 63.53920251131058, 61.610665395855904, 63.84153708815575, 56.11196905374527, 43.4352944791317, 45.65013863146305, 40.55807746946812, 33.48398946225643, 34.001343101263046, 40.66172830760479, 16.820405423641205, 14.891814161092043, 27.203990444540977, 23.74350283294916, 19.709453098475933, 18.761810548603535, 26.01668905466795, 31.420510187745094, 19.040711782872677, 14.4330476783216, 6.986513156443834, 0.8788738399744034, 1.2790200370363891, 0.21089859888888896, 0.18731275980826467, 0.3831684705801308, 0.16521506040589884, 0.1562734425533563, 0.6059753929730505, 1.2153803394176066, 0.7971003279089928, 1.5677272388711572, 1.1169314221478999, 2.3560061026364565, 1.2445633672177792, 1.0810026875697076, 1.4960860018618405, 2.4532621214166284, 5.391133138909936, 4.616813538596034, 4.73125864751637, 3.082212684676051, 2.2940475773066282, 1.2685930402949452, 0.3658483171602711, 0.6530644849408418, 0.19338036625413224, 0.25404201820492744, 0.43182658147998154, 0.20065028162207454, 0.9123784827534109, 3.57662386726588, 16.234417967498302, 24.62740570306778, 33.69259066879749, 27.953144945204258, 26.074575148522854, 24.495516680181026, 32.4037454277277, 41.82313218712807, 22.63844233006239, 28.290705531835556, 42.41146221756935, 37.38348841667175, 42.2242234647274, 40.45770585536957, 47.65805348753929, 56.49914547801018, 56.261738017201424, 57.706906870007515, 53.351937755942345, 53.82090099155903, 49.819122925400734, 51.45194470882416, 56.03229492902756, 56.19993053376675, 57.34905727207661, 52.1390276402235, 55.03082826733589, 56.62990786135197, 58.561382219195366, 61.34610839188099, 62.09002107381821, 48.95186886191368, 53.86570058763027, 47.64726206660271, 43.75848613679409, 24.542368166148663, 19.528263621032238, 62.96234406530857, 60.96309274435043, 63.098357766866684, 55.679689049720764, 54.96681310236454, 56.37630946934223, 51.91208861768246, 61.593395322561264, 6.900435900315642, 4.899381101131439, 56.49373456835747, 78.88641938567162, 70.24815291166306, 27.772213853895664, 22.33578097075224, 21.219963245093822, 10.565776694566011, 41.395210549235344, 36.10414646565914, 41.70666083693504, 54.91092570126057, 28.063521422445774, 45.39359539747238, 74.39234733581543, 60.95664829015732, 7.037224285304546, 0.21648516005370766, 0.38641207152977586, 0.23333295132033527, 0.17546057235449553, 0.19249246077379212, 0.3006120817735791, 0.16226054081926122, 0.17552049335790798], [0.09768554416950792, 0.026555240583547857, 0.04530372214503586, 0.03203428495908156, 0.06120285572251305, 0.055195329841808416, 0.028504908914328553, 0.0071685885541228345, 0.02842903915734496, 0.05521622872038279, 0.07622981735039502, 0.09018450175062753, 0.034752504725474864, 1.5052120434120297, 46.572231352329254, 51.75877824425697, 37.220294773578644, 42.116092666983604, 70.02261221408844, 28.379970341920853, 47.41754539310932, 36.73415645956993, 21.428254768252373, 34.21003930270672, 9.47929909452796, 24.310884587466717, 75.99095955491066, 40.90093307197094, 4.361445866525173, 0.8991022920235991, 17.82813034951687, 47.361578196287155, 62.967466190457344, 62.76149444282055, 68.409074395895, 53.73786024749279, 43.83125223219395, 54.19530630111694, 41.11585333943367, 7.297049593180418, 8.551791664212942, 33.12053896486759, 42.4924510717392, 57.619275972247124, 55.25379650294781, 55.66382870078087, 54.74006026983261, 61.48247927427292, 58.24599914252758, 57.19788998365402, 54.41537149250507, 60.07223814725876, 56.02494612336159, 52.45148867368698, 53.53056617081165, 55.21558955311775, 45.20805515348911, 41.63826830685139, 44.55885238945484, 30.696215853095055, 30.628231801092625, 16.66031051427126, 2.744942307472229, 3.7080303160473704, 21.291851587593555, 26.134188249707222, 21.13849561661482, 13.26447643339634, 18.790432512760162, 20.552063584327698, 16.010066606104374, 7.903871331363916, 2.3338122060522437, 1.6638708673417568, 1.1403298540972173, 0.21449963300256059, 0.008080623574642232, 0.0655606429791078, 0.18097452179063112, 0.011305071548122214, 0.08151383459335193, 0.019804257135547232, 0.5747889226768166, 1.3002200494520366, 1.180136043112725, 1.3291999069042504, 0.9395111643243581, 0.6819511286448687, 0.6662963249254972, 0.46023121511098, 0.5698181362822652, 3.9294646214693785, 6.375768128782511, 5.8771370351314545, 3.3064552769064903, 2.4201013008132577, 0.17468260863097385, 0.20622191077563912, 0.2292562896036543, 0.19941341830417514, 0.14157375320792198, 0.12396661870297976, 0.13294766686158255, 0.371930722030811, 0.686407636385411, 3.115062634460628, 11.143395099788904, 18.250154703855515, 19.011307060718536, 15.115784592926502, 15.030095390975475, 8.34106732159853, 16.9732978194952, 28.781865276396275, 9.425420835614204, 11.751453671604395, 27.5814051926136, 34.3510003387928, 34.12986360490322, 49.04520705342293, 48.833543211221695, 50.632583275437355, 55.10868988931179, 48.782967925071716, 47.508136332035065, 47.24967420101166, 46.985246390104294, 48.84081982076168, 49.398322105407715, 47.17288412153721, 50.84267780184746, 52.106847167015076, 56.89332112669945, 58.1485989689827, 55.516871586441994, 55.628608390688896, 47.78048291802406, 44.951143339276314, 24.7036999091506, 24.8291102796793, 16.68864369392395, 36.746182814240456, 52.54799969494343, 49.11419615149498, 42.252455949783325, 57.81325176358223, 48.73385936021805, 51.82167246937752, 56.03639490902424, 6.672610100358725, 0.6375482550356537, 19.247485287487507, 62.533331885933876, 43.43397594988346, 23.376915603876114, 15.175708327442408, 21.536605954170227, 8.014149013906717, 15.84960026666522, 31.672216281294823, 21.67410157620907, 42.527435794472694, 37.17421844601631, 40.89947395026684, 39.34024661779404, 56.26834586262703, 19.07557111233473, 0.6243472290225327, 0.14047604257939383, 0.09662234340794384, 0.12371949836960994, 0.050106441776733845, 0.08059234693064354, 0.09876562879071571, 0.05370980994484853, 0.08672176685649902, 0.13235338468803093, 0.10612131416564807, 0.05427184951258823, 0.026028466018033214, 0.08575511208618991, 0.033724381573847495, 0.0425884375727037, 0.016370981793443207, 0.034457875808584504, 0.02010379350394942, 0.06349123097606935, 0.08110750131891109, 0.023947129557200242, 2.39147933665663, 55.86405135691166, 67.71084666252136, 34.299980476498604, 50.8295077085495, 70.6398206949234, 27.510398402810097, 50.992587357759476, 31.962661296129227, 34.3687529861927, 35.21618731319904, 15.904149189591408, 36.790336444973946, 72.96829774975777, 49.21454876661301, 8.979315273463726, 1.5028408518992364, 16.691449843347073, 56.09848737716675, 69.12624791264534, 64.55361127853394, 73.46827492117882, 61.16582706570625, 52.792140394449234, 57.61834882199764, 50.8417696505785, 10.419580489397049, 10.498750191181898, 35.091462805867195, 41.45397059619427, 55.60531184077263, 54.93721269071102, 55.916074365377426, 55.966178476810455, 62.83274061977863, 62.20087632536888, 57.73919373750687, 57.250482961535454, 58.94308693706989, 57.23370686173439, 56.479625925421715, 57.25011818110943, 58.99696804583073, 44.48398120701313, 45.665835589170456, 45.48140108585358, 31.534587666392326, 35.956262201070786, 18.35623361170292, 3.9658061088994145, 7.1176103968173265, 28.504018485546112, 27.295012660324574, 22.552264854311943, 16.55823089182377, 20.773601196706295, 19.903187602758408, 21.364912167191505, 11.652840413153172, 5.215811021625996, 1.294010707642883, 0.5310774932149798, 0.09158098619082011, 0.056120595036190934, 0.034506753654568456, 0.12976199795957655, 0.24128190212650225, 0.036258296386222355, 0.022770317118556704, 0.3078695142176002, 0.9423787635751069, 0.5046314466744661, 2.075646696612239, 1.2215389776974916, 0.420807974296622, 0.8173609001096338, 0.31070294498931617, 0.20508157118456438, 4.2223514802753925, 5.576309077441692, 3.996432228013873, 2.3796367971226573, 2.035231115296483, 0.4435080155963078, 0.12095208163373172, 0.19270164251793176, 0.06603552101296373, 0.22154179809149355, 0.08319292144733481, 0.23750588443363085, 0.2709875354776159, 0.6943173869512975, 4.240170624107122, 16.885321140289307, 22.382178381085396, 27.41235226392746, 20.13592891395092, 22.05970298498869, 15.51605511456728, 26.377407498657703, 35.02276249229908, 15.320721846073866, 11.474186349660158, 31.118869073688984, 36.98909617960453, 35.48560045659542, 47.75979682803154, 53.851356357336044, 50.47293484210968, 55.90099677443504, 51.156339570879936, 52.04971723258495, 48.63485187292099, 47.83884018659592, 50.381663739681244, 52.347518652677536, 52.182672098279, 53.88533413410187, 54.78725753724575, 61.087501868605614, 61.630568727850914, 58.755730390548706, 57.634155973792076, 48.714176416397095, 45.79823948442936, 26.87087181955576, 22.645468153059483, 23.035291135311127, 42.11945168673992, 57.16242268681526, 52.96994045376778, 49.81171332299709, 60.52282936871052, 50.863572880625725, 51.831943318247795, 55.65071560442448, 5.432598888874054, 1.1709939711727202, 26.759794279932976, 71.12476587295532, 64.27288234233856, 37.03718639910221, 16.8171850964427, 19.288817569613457, 15.343495924025774, 12.899311278015375, 34.27713990211487, 26.263974085450172, 28.778914734721184, 51.397455632686615, 30.784576311707497, 43.11356194317341, 65.6072947382927, 24.807687029242516, 0.7565659435931593, 0.27117126155644655, 0.19114322145469487, 0.126651567989029, 0.09097172747715376, 0.05019352167437319, 0.06526320503326133, 0.06852914462797344, 0.0500858026498463, 0.23231926665175706, 0.26220018044114113, 0.14281456475146115, 0.13427283091004938, 0.20930099242832512, 0.12974371144082397, 0.12805551843484864, 0.10477164440089837, 0.18041703529888764, 0.2119583560852334, 0.3934421989833936, 0.1457233977271244, 0.16191619914025068, 4.808197868987918, 74.35559570789337, 78.03923964500427, 53.571258187294006, 54.73671644926071, 85.6962239742279, 34.578950107097626, 71.19390696287155, 46.55865468084812, 34.63237524032593, 43.010674864053726, 19.775818437337875, 35.21695487201214, 78.52464839816093, 53.85203272104263, 8.917415644973516, 2.006069105118513, 22.381800301373005, 58.75979237258434, 71.22796833515167, 72.90702983736992, 79.80389535427094, 67.2811809182167, 58.43296431005001, 61.76350079476833, 49.361338689923286, 9.692422058433294, 14.796946551650763, 42.701040878891945, 49.74956765770912, 59.648218899965286, 56.400571167469025, 56.399267837405205, 54.598126485943794, 66.93829491734505, 63.26148301362991, 63.83048728108406, 59.90468613803387, 63.875081688165665, 61.979887783527374, 57.66552709043026, 57.52807326614857, 57.82606467604637, 47.095858454704285, 48.60008753836155, 47.751038298010826, 35.88179759681225, 41.95318400859833, 31.777369938790798, 7.8823773097246885, 9.552011042833328, 32.85014547407627, 32.95249678194523, 28.007164746522903, 20.94505749642849, 26.46559126675129, 29.133783392608166, 34.46818605065346, 17.749168686568737, 10.497403163462877, 2.4477882776409388, 3.2882103184238076, 0.6251647195313126, 0.10328310396289453, 0.20930091821355745, 0.36575920006725937, 0.5956609058193862, 0.1859280013013631, 0.36246946721803397, 1.1673785839229822, 1.878714901395142, 1.3352878927253187, 3.7077374942600727, 2.6143582770600915, 1.5558053785935044, 1.4390925038605928, 2.3492693016305566, 2.9953265469521284, 6.561915865167975, 8.565260041505098, 6.563774440437555, 6.075259353965521, 3.509029056876898, 0.7086202350910753, 0.5296003818511963, 0.5400435870978981, 0.5505903961602598, 0.3972757776500657, 0.2607382682617754, 0.48847115132957697, 1.3123779720626771, 1.4092428493313491, 13.60394736751914, 21.569325998425484, 29.145057387650013, 32.72517777979374, 25.1740500703454, 24.398211501538754, 17.352990545332432, 28.96753281354904, 39.539146944880486, 17.890279814600945, 18.136445805430412, 39.51774649322033, 39.75095517933369, 36.44037142395973, 51.71984553337097, 53.742967173457146, 53.33941362798214, 59.61475409567356, 55.11364482343197, 55.97723588347435, 53.415667936205864, 52.44321271777153, 54.162422865629196, 55.2728296816349, 55.05026042461395, 55.33621788024902, 57.01372146606445, 61.47916965186596, 65.50451785326004, 61.27461902797222, 58.83807957172394, 50.645050406455994, 51.572124660015106, 34.392482712864876, 31.535539515316486, 21.514643132686615, 46.56427837908268, 62.212078124284744, 57.738574370741844, 53.66774640977383, 66.7176103591919, 57.9385956376791, 54.8398657143116, 62.66540139913559, 11.250415407121181, 1.243492062203586, 24.802251420915127, 73.41982752084732, 54.65530201792717, 32.7776225656271, 21.698973141610622, 27.67524115741253, 14.850592073053122, 20.12865800410509, 47.55586177110672, 27.818261682987213, 54.03132990002632, 59.47216674685478, 46.74561604857445, 53.935411646962166, 76.87867552042007, 43.710255324840546, 1.8373439088463783, 0.44609244097955525, 0.33137190621346235, 0.19682595011545345, 0.21881433116504923, 0.19789618643699214, 0.25465829763561487, 0.17287663678871468, 0.19836350198602304], [0.004343234204498003, 0.024620355834485963, 0.056226206361316144, 0.05429298216768075, 0.13888599118217826, 0.024649835795571562, 0.051146157275070436, 0.057346964385942556, 0.14418167498661205, 0.0440051232726546, 0.08613145517301746, 0.07375820583547466, 0.3582727408502251, 0.03886733880790416, 27.518738955259323, 66.89252257347107, 43.20164121687412, 31.079869866371155, 77.82966569066048, 45.63383750617504, 35.92510387301445, 48.865579292178154, 17.87062916904688, 32.768522053956985, 17.732185497879982, 10.618122685700655, 62.798158675432205, 89.39369916915894, 31.793224588036537, 2.457720944657922, 1.691992802079767, 30.63239447772503, 68.28928962349892, 63.89254555106163, 58.31464625895023, 60.497632920742035, 46.337521746754646, 41.20718143880367, 62.236260026693344, 33.29854801297188, 4.2976235412061214, 23.576866574585438, 35.632435977458954, 47.78237521648407, 51.57578766345978, 52.73896984755993, 48.93110677599907, 52.799891978502274, 59.114875718951225, 62.0066649466753, 59.245474711060524, 60.40525607764721, 56.447092071175575, 62.65892654657364, 60.151042118668556, 56.029703468084335, 51.33649170398712, 51.84740088880062, 38.74800659716129, 30.403502359986305, 8.927551601082087, 1.7947529442608356, 2.728542862460017, 20.07147677242756, 35.41695713996887, 18.024745099246502, 9.034391418099403, 15.817799773067236, 18.948597125709057, 13.23900070041418, 14.556975178420544, 6.214183224365115, 1.0450866585597396, 1.021131556481123, 0.10111733150552027, 0.12924482492962852, 0.04344896151451394, 0.008160839533957187, 0.03977774249506183, 0.21322486078133807, 0.14193180977599695, 0.3275939589366317, 0.7791918294969946, 0.9405660827178508, 1.6789084416814148, 2.0485928608104587, 1.1311361286789179, 0.4252735659247264, 0.9028585092164576, 0.5166556045878679, 1.261495971120894, 1.709212171845138, 2.8580204397439957, 3.747523734346032, 3.7299791257828474, 0.654089004965499, 1.312450880650431, 0.35308239748701453, 0.44419153360649943, 0.31477605924010277, 0.32865986111573875, 0.0413295287580695, 0.08175869137630798, 0.09121859548031352, 0.6160598143469542, 3.03529588971287, 7.940227780491114, 17.34063930809498, 22.088013365864754, 13.284231573343277, 11.128241512924433, 11.918590553104877, 4.322143150493503, 17.455826327204704, 25.466535575687885, 9.819595534354448, 7.7504892367869616, 25.282332859933376, 37.25210666656494, 43.864333257079124, 49.41179998219013, 49.79154780507088, 46.915770918130875, 50.32392583787441, 49.205775037407875, 48.51132430136204, 47.54531733691692, 50.608572363853455, 52.06480622291565, 55.58377459645271, 53.8163336366415, 59.66227054595947, 54.6115093678236, 54.26840677857399, 56.69396102428436, 54.73501794040203, 42.14936748147011, 32.519506216049194, 9.80708945542574, 6.41971324570477, 35.57565562427044, 51.21878542006016, 37.129665836691856, 44.9250615388155, 45.63226439058781, 53.03640268743038, 40.82342863082886, 41.167496368288994, 32.97124497592449, 1.485387438442558, 6.178420018404722, 49.1778427362442, 35.875782519578934, 11.918752044439316, 20.429214276373386, 19.064411111176014, 20.892755202949047, 7.221917174756527, 25.670744217932224, 23.453272506594658, 30.40357645601034, 53.897938057780266, 34.684364050626755, 32.45128847658634, 43.12031798064709, 59.75116677582264, 11.112589202821255, 0.3965486213564873, 0.06488702521892264, 0.08223820783314295, 0.06125230502220802, 0.0418613814690616, 0.03263018872530665, 0.04109604538825806, 0.035327910372870974, 0.044419564510462806, 0.019033649950870313, 0.02182077256293269, 0.10936832157312892, 0.04988976063032169, 0.029483538237400353, 0.023386969478451647, 0.11132094921777025, 0.026486829410714563, 0.08405471075093374, 0.015732653155282605, 0.032937456417130306, 0.11088344574091025, 0.30074566835537553, 0.06724559279973619, 34.117183685302734, 79.47430863976479, 44.343491345644, 34.0933133661747, 93.7177911400795, 34.68561038374901, 47.101303562521935, 42.273670211434364, 23.134030736982822, 40.49972780048847, 15.356515925377607, 26.11673578619957, 77.9450199007988, 89.72232073545456, 40.45338548719883, 3.624356430955231, 1.3753591175191104, 27.276080176234245, 75.74752941727638, 69.91124778985977, 65.96234008669853, 63.82582873106003, 53.378760516643524, 48.31192620098591, 70.5602377653122, 40.741413831710815, 6.673306887969375, 24.671718925237656, 44.19058375060558, 48.495836332440376, 53.65608483552933, 53.199573531746864, 51.90909817814827, 53.77679295837879, 63.7968210875988, 65.89712038636208, 65.45537889003754, 61.617706418037415, 59.823013320565224, 63.98149877786636, 62.825642600655556, 55.331631526350975, 54.47977423667908, 50.90946301817894, 40.062154680490494, 34.96838741004467, 9.726482480764389, 1.6593833081424236, 10.20049849525094, 26.16146508604288, 35.291719660162926, 22.77067333459854, 13.581529520452023, 20.57743102312088, 20.66215317696333, 18.204175271093845, 17.22071584314108, 9.116367269307375, 2.959512756206095, 0.44071653101127595, 0.10699914128053933, 0.16637331544188783, 0.032892114904825576, 0.01598552698851563, 0.11018428325769491, 0.11664799618301913, 0.23356009303824976, 0.1888438846799545, 0.9060826362110674, 0.9241433639544994, 2.2362075559794903, 2.256974629126489, 0.6195314624346793, 1.2095323344692588, 0.5437837145291269, 1.0800940613262355, 1.873785259667784, 4.771868968382478, 5.896054320037365, 5.886885887011886, 4.092035572975874, 2.8474598564207554, 0.7069603772833943, 0.309561284375377, 0.4320815537357703, 0.35589976818300784, 0.18635534477652982, 0.14826850412646309, 0.11256906349444762, 0.26765775633975863, 0.34818351035937667, 2.600159151479602, 14.762151818722486, 21.014082692563534, 30.149282701313496, 21.156379356980324, 18.909672014415264, 14.488781187683344, 9.317769762128592, 26.01760670542717, 28.685264959931374, 14.880923945456743, 8.480121809989214, 27.368975691497326, 38.791837245225906, 45.520793572068214, 48.7994172424078, 53.20213459432125, 47.73567192256451, 52.28895239531994, 52.155055180191994, 50.9885785728693, 50.897402465343475, 52.47048385441303, 55.61713680624962, 58.28248858451843, 56.71428993344307, 62.172100469470024, 56.87339499592781, 55.70042073726654, 59.03083182871342, 55.5022119730711, 43.71423751115799, 32.777079194784164, 9.66208828613162, 10.227687936276197, 43.7276241928339, 55.00506944954395, 42.51095607876778, 50.199056938290596, 50.27922883629799, 59.707309529185295, 53.019683584570885, 47.01920136809349, 29.391544461250305, 1.297092461027205, 10.855001024901867, 55.76410911977291, 45.67842051386833, 20.509312078356743, 23.121719397604465, 13.183048702776432, 17.569679617881775, 12.145730964839458, 20.245737321674824, 36.169594153761864, 23.059117756783962, 54.01518076658249, 37.49782048165798, 24.636627808213234, 54.027792289853096, 68.07279244065285, 14.698022659868002, 0.34839600208215415, 0.11633434231043793, 0.13133048254530877, 0.045980827999301255, 0.05076083791209385, 0.03152684890665114, 0.01689058350166306, 0.042097744371858425, 0.043827620102092624, 0.12204307582578622, 0.09792466415092349, 0.19703910977113992, 0.13507697760360315, 0.28454066603444517, 0.11519636274897493, 0.24053555389400572, 0.1597272790968418, 0.23533623054390773, 0.13902897335356101, 0.22145958297187462, 0.2012250156258233, 0.3580696595599875, 0.18600270588649437, 44.998196214437485, 89.98618617653847, 58.64700302481651, 42.85802185535431, 96.68093293905258, 51.874588429927826, 53.29687111079693, 72.69797265529633, 24.60536878556013, 44.18962240219116, 24.613973423838615, 21.802487187087536, 70.14047428965569, 98.85267600417137, 42.53381945192814, 4.569043451920152, 3.1633426062762737, 37.002228274941444, 83.86677414178848, 72.11557030677795, 72.16366812586784, 71.81217938661575, 59.9595095962286, 55.83469793200493, 73.46635982394218, 40.60948111116886, 7.288025077432394, 30.483037792146206, 47.3667611181736, 53.63474138081074, 55.13376094400883, 60.10998532176018, 55.40388464927673, 60.73505938053131, 67.80190497636795, 70.49991220235825, 67.69297242164612, 66.12958431243896, 61.14480659365654, 66.92224457859993, 64.05687913298607, 57.32445739209652, 60.35897836089134, 54.21678274869919, 43.08672018349171, 44.806678891181946, 20.806074254214764, 4.13668935187161, 12.12224442511797, 30.26129689067602, 40.75698919594288, 28.068468756973743, 17.977720722556114, 27.1182157471776, 30.46369682997465, 26.650924421846867, 28.146930746734142, 13.789095282554626, 5.58527042157948, 1.8091671145521104, 1.6161588463000953, 0.2492279140278697, 0.22636035515461117, 0.13141767005436122, 0.23671770875807852, 0.7649417035281658, 1.3264183374121785, 0.5896976008079946, 1.2375153391622007, 1.7587011912837625, 3.3155144657939672, 4.6701902244240046, 2.7038684114813805, 1.4580355561338365, 1.789820808917284, 2.305990098975599, 3.6129484931007028, 5.674279220402241, 7.506660120561719, 6.82914650067687, 5.431827055290341, 3.8252198277041316, 2.215758003294468, 1.9440411147661507, 1.9192141969688237, 1.3598691299557686, 0.9941410704050213, 0.8295760571490973, 0.34342922328505665, 0.18767083121929318, 1.5069604245945811, 5.87990946136415, 19.587479643523693, 27.03470192849636, 37.07016862928867, 25.604658164083958, 20.036246962845325, 16.460013762116432, 10.462749972939491, 30.19191451370716, 37.244058698415756, 16.777000352740288, 14.082807172089815, 32.24357642233372, 41.84864401817322, 47.10834838449955, 53.25331024825573, 53.022514432668686, 52.862132638692856, 55.71123115718365, 54.761038944125175, 53.82920354604721, 54.34735894203186, 56.146060824394226, 57.750418335199356, 59.66165117919445, 58.553664833307266, 63.21820333600044, 60.54952293634415, 57.11393728852272, 63.55544663965702, 58.70095252990723, 46.669183149933815, 41.025380194187164, 13.737805634737015, 9.966893680393696, 41.703875586390495, 59.876677840948105, 46.68934866786003, 55.7358006387949, 54.90537039935589, 64.86099198460579, 50.55519662797451, 49.430677369236946, 39.71353478729725, 2.8204164700582623, 9.747255966067314, 60.463829934597015, 48.542064651846886, 17.807626649737358, 28.87044422328472, 25.39210706949234, 29.406869038939476, 11.327618714421988, 34.94600661098957, 37.775486782193184, 35.041537284851074, 74.0512016415596, 47.13936232030392, 43.96970920264721, 59.45468008518219, 85.45313581824303, 26.872574128210545, 0.48258479218930006, 0.36837794235907495, 0.26933818648103625, 0.12983870634343475, 0.14252261869842187, 0.12109265924664214, 0.17196158354636282, 0.1457587833283469, 0.1440412606461905], [0.08770994390943088, 0.021554955674218945, 0.04785179713508114, 0.07629249172168784, 0.06032508797943592, 0.0422498178522801, 0.02232537546660751, 0.0523473529756302, 0.053552047902485356, 0.06533013191074133, 0.0700278599106241, 0.05114378611324355, 0.21969101537251845, 0.15711229207227007, 9.339143615216017, 54.14160758256912, 55.83283603191376, 31.64044428616762, 55.19280977547169, 72.62434020638466, 26.5062053874135, 47.42122359573841, 20.25207158178091, 30.53086392581463, 26.078887917101383, 14.12219300866127, 22.41377178579569, 73.45391929149628, 59.73268076777458, 12.976247649639845, 1.9551379443146288, 10.840599797666073, 38.457747772336006, 64.67313766479492, 58.54590944945812, 60.87183304131031, 66.1411052942276, 46.770413517951965, 37.90933080017567, 50.91480553150177, 15.041966903954744, 6.678131679072976, 35.522975251078606, 34.460081085562706, 46.18499793112278, 49.9143648147583, 51.47155165672302, 49.657806381583214, 46.64038069546223, 50.24681277573109, 48.93264949321747, 54.62565220892429, 58.76580365002155, 57.05892004072666, 51.11538536846638, 52.726198732852936, 49.93911288678646, 43.47173452377319, 22.50941075384617, 4.67469060793519, 2.659649709239602, 7.283715633675456, 20.43056510388851, 28.85751161724329, 29.139602780342102, 9.485710300505161, 9.862056355923414, 21.916748955845833, 14.630235247313976, 16.025013104081154, 11.033113617449999, 5.69414977915585, 1.0379968327470124, 0.8638783602509648, 0.06302475405391306, 0.02235289244708838, 0.026915842718153726, 0.08806860161712393, 0.24131241923896596, 0.5233522702474147, 0.26734409504570067, 0.11787771261879243, 0.3085005475440994, 1.2391155282966793, 2.398486160673201, 4.302274491637945, 2.520055412314832, 1.1688605044037104, 0.6828556582331657, 1.4520097919739783, 1.5383368846960366, 1.4870937843807042, 3.998271329328418, 1.8620892497710884, 1.4186424762010574, 2.1218503173440695, 2.5551196932792664, 1.2953903898596764, 0.16330766666214913, 0.5422317353077233, 0.29482309240847826, 0.16907206125324592, 0.7077459257561713, 0.9668549126945436, 0.3664471412776038, 1.5149848815053701, 3.7083264626562595, 14.330153949558735, 17.476079240441322, 23.99760089814663, 10.294843632727861, 14.5109748467803, 9.136230703443289, 6.045451378449798, 16.07502032071352, 18.918042965233326, 15.845457538962364, 8.587604742497206, 24.068957269191742, 44.50943984091282, 49.21389140188694, 47.83715307712555, 52.933785393834114, 49.084196761250496, 46.58513925969601, 49.02257166802883, 51.244396045804024, 52.696108147501945, 49.49098393321037, 56.07567340135574, 56.53987169265747, 54.88556206226349, 58.82463589310646, 64.06544387340546, 56.95898540318012, 50.04080303013325, 29.5114204287529, 8.322576563805342, 5.9879272151738405, 25.816897675395012, 55.53510680794716, 53.49830590188503, 50.93926481902599, 56.53675965964794, 57.40787051618099, 61.83406300842762, 37.56925664842129, 24.24956727772951, 3.368540620431304, 1.354307890869677, 33.61277595162392, 59.11440834403038, 21.457718387246132, 31.975611001253128, 23.705176189541817, 20.349251367151737, 10.810482613742352, 10.166765805333853, 33.156283646821976, 19.034358523786068, 42.359963580965996, 30.869030579924583, 23.566094152629375, 31.007922627031803, 50.490261912345886, 41.08896978199482, 2.714950516819954, 0.04984237821190618, 0.0973812339361757, 0.014169773639878258, 0.03631897066952661, 0.03895684923918452, 0.0008533481275208032, 0.02725421938521322, 0.05244889733148739, 0.0467049971484812, 0.08326974857482128, 0.06546579650603235, 0.042991809677914716, 0.12897425272967666, 0.04768393817357719, 0.09916394687024876, 0.09542719621094875, 0.045582654638565145, 0.10880845278734341, 0.024055805952230003, 0.024202409804274794, 0.10735119387391023, 0.32927112362813205, 0.2910265023820102, 11.319728437811136, 63.0676744133234, 69.60900440812111, 25.987844802439213, 69.03838142752647, 68.59204977750778, 36.22873418033123, 47.31416054069996, 26.055467873811722, 40.486515909433365, 21.59934438765049, 22.524351552128792, 41.68751746416092, 96.31732285022736, 68.18432405591011, 24.656023867428303, 3.017767430283129, 5.7799107022583485, 34.16958287358284, 69.28029164671898, 65.18408864736557, 68.57363596558571, 67.63632506132126, 52.99850732088089, 47.59281098842621, 57.31731757521629, 20.51851138472557, 8.384160809218884, 31.59711141139269, 36.62813074886799, 52.547456324100494, 58.17808918654919, 53.934982270002365, 53.92020106315613, 46.77711635828018, 51.36215552687645, 49.96899828314781, 55.66279135644436, 57.86118619143963, 56.080605536699295, 48.064065501093864, 56.3380341231823, 50.06198309361935, 44.40408669412136, 26.325393989682198, 5.4406345076859, 3.834586562588811, 16.03241130709648, 28.09555370360613, 30.94337359070778, 33.90091069042683, 13.87824609875679, 16.101673990488052, 26.323889270424843, 20.726951099932194, 24.370104409754276, 15.70419441908598, 7.9849086329340935, 1.065257757436484, 0.47187349351588637, 0.039593196343048476, 0.04234903186443262, 0.06839797002612613, 0.11026600113837048, 0.19572777935536578, 0.48371790326200426, 0.19450451218290254, 0.6811474717687815, 1.7366940784268081, 2.7586797578260303, 3.2461330387741327, 3.0733738839626312, 1.4713420858606696, 0.3799528634408489, 1.1815239186398685, 1.120029087178409, 1.8808658234775066, 4.603162771090865, 5.90325303375721, 6.046020872890949, 3.8068471010774374, 2.8307837387546897, 1.7638305597938597, 1.4370358642190695, 0.694508267333731, 0.5029495025519282, 0.3641657793195918, 0.6758833886124194, 0.06621139516937546, 0.3199580905493349, 0.6315283686853945, 2.003093627281487, 10.895194318145514, 18.370625339448452, 23.361543528735638, 28.108782693743706, 15.561960451304913, 19.221678972244263, 8.404191434383392, 13.382341358810663, 24.086804911494255, 24.709502197802067, 24.872680641710758, 14.081662483513355, 25.98960030823946, 47.06108272075653, 52.86969043314457, 49.72316287457943, 54.12119887769222, 53.39049428701401, 51.39395222067833, 51.94949001073837, 53.04862663149834, 53.77556562423706, 54.51236508786678, 56.269542798399925, 59.438014179468155, 59.24772419035435, 63.1309600174427, 66.04751631617546, 58.582330495119095, 49.85192656517029, 28.70086122304201, 7.608497980982065, 8.114045653492212, 35.16177423298359, 56.989026591181755, 57.4372923374176, 53.837901279330254, 61.1283952742815, 61.15669995546341, 66.83468207716942, 38.09647835791111, 17.053967490792274, 1.7976217903196812, 2.966101602651179, 41.601737067103386, 59.492552652955055, 29.74577285349369, 31.92072294652462, 23.14630027860403, 11.916034240275621, 13.89988973736763, 10.329065546393394, 31.234333477914333, 26.422281190752983, 33.70425224304199, 37.43226259946823, 24.889572635293007, 31.637360751628876, 59.66226674616337, 45.14804117381573, 3.8260536454617977, 0.05672887040418573, 0.11080054784542881, 0.06634883349761367, 0.019563283640309237, 0.012245725174580002, 0.04343437831266783, 0.1034512894693762, 0.062106004916131496, 0.13468957651639357, 0.18629092635819688, 0.1540892870980315, 0.16054904437623918, 0.3663048567250371, 0.14057137886993587, 0.21018109051510692, 0.17528184835100546, 0.24169950862415135, 0.3067952406127006, 0.22103829542174935, 0.2639579423703253, 0.42465577251277864, 0.5893885111436248, 0.44806031975895166, 18.244325816631317, 79.75313767790794, 77.22032278776169, 41.87017746269703, 66.8451315164566, 83.95936757326126, 36.52116648852825, 66.73504382371902, 29.631171002984047, 45.62345266342163, 30.259997360408306, 24.434410259127617, 28.088759668171406, 90.6199237704277, 68.08125078678131, 22.9697959497571, 3.5002847760915756, 14.667067620903254, 45.854206681251526, 74.47842791676521, 66.10306933522224, 72.02663987874985, 73.92006307840347, 56.66019983589649, 52.56079740822315, 61.125009655952454, 19.430228881537914, 10.85210558027029, 40.45879639685154, 48.05476740002632, 57.366198152303696, 57.861372381448746, 56.098787561059, 57.09046594798565, 51.93852759897709, 55.92272400856018, 53.78202527761459, 55.61032757163048, 62.23206505179405, 57.993042916059494, 52.40642309188843, 60.27794010937214, 52.73633658885956, 47.99360208213329, 37.20886878669262, 9.919153992086649, 5.395296290516853, 19.531307257711887, 35.48191085457802, 35.84473438560963, 39.31372784078121, 16.343361921608448, 18.17310243844986, 33.34019377827644, 26.39596190303564, 32.20362536609173, 21.494166031479836, 15.357300583273172, 2.2545427596196532, 2.8424042277038097, 0.26426581491250545, 0.11415979766752571, 0.2051299888989888, 0.19567624462069944, 0.6769700115546584, 1.7243688460439444, 2.2160102147608995, 2.2284455224871635, 2.139145564287901, 3.500606333836913, 4.683699449524283, 7.194098392501473, 6.395028345286846, 4.030884029343724, 4.084855383262038, 5.894293114542961, 5.015371302142739, 5.8822050131857395, 7.408670503646135, 6.567467842251062, 4.101298050954938, 4.153311559930444, 7.372874524444342, 5.3885735012590885, 4.009167244657874, 1.980831571854651, 1.2476621009409428, 2.017758940346539, 1.187928356230259, 1.95448141079396, 2.281606332398951, 4.2064350843429565, 16.504530273377895, 26.696677766740322, 29.812122993171215, 35.63039168715477, 21.323380395770073, 22.125374861061573, 13.87957127764821, 14.785553812980652, 28.775012344121933, 33.43835771083832, 28.71059440076351, 16.074209064245224, 31.388413310050964, 48.246151730418205, 53.03120456635952, 53.48719909787178, 56.843213215470314, 54.798383340239525, 53.11552584171295, 52.571037858724594, 56.838858649134636, 58.867163211107254, 56.30839191377163, 59.800966903567314, 62.153390273451805, 60.77505983412266, 63.55777591466904, 68.99146154522896, 59.20466110110283, 51.15543521940708, 36.31726562976837, 12.211273647844791, 7.499672770500183, 30.802169367671013, 62.85162940621376, 63.868728429079056, 59.48406770825386, 68.24789464473724, 65.94585657119751, 70.55472046136856, 45.57921163737774, 31.071597710251808, 5.785183869302273, 2.4737349478527904, 37.64860779047012, 67.4001145362854, 28.718216791749, 41.612840071320534, 36.05207026004791, 27.38024588674307, 21.168958581984043, 14.915142059326172, 46.7760144174099, 29.614419601857662, 51.24308131635189, 47.944588512182236, 31.670439876616, 44.42145176231861, 66.71348378062248, 68.9108070731163, 8.881196938455105, 0.17495073174359277, 0.2416316614835523, 0.14529415435390547, 0.15150368912145495, 0.18546423321822658, 0.17578931408934295, 0.18535957555286586, 0.14126316440524533, 0.2469795331126079], [0.10129350994247943, 0.045182332760305144, 0.027681744686560705, 0.14991025353083387, 0.08746178456931375, 0.00987315697784652, 0.04083826039277483, 0.10632317091221921, 0.09040678240125999, 0.0013982363725517644, 0.12976777186850086, 0.12603870243765414, 0.07520344195654616, 0.6619004951789975, 0.9086157940328121, 20.76981659978628, 73.23804527521133, 38.54153707623482, 37.28813633322716, 42.636581137776375, 29.817336313426495, 35.94474121928215, 19.437906369566917, 24.810020104050636, 30.341254100203514, 21.87913477420807, 23.51767335087061, 22.3208686709404, 68.20202350616455, 64.28419813513756, 10.607667546719313, 0.9083968307822943, 8.294117990881205, 44.10354562103748, 56.745189875364304, 49.548550844192505, 53.40018376708031, 60.367151722311974, 44.96611453592777, 47.21531644463539, 40.39017207920551, 7.741238158196211, 1.4725190727040172, 7.067400841042399, 26.15685023367405, 50.05179964005947, 45.80817595124245, 48.082167729735374, 57.09322080016136, 58.57558585703373, 58.92712779343128, 64.48166593909264, 56.99131786823273, 56.41875319182873, 51.02979876101017, 39.87490072846413, 34.56060089170933, 20.92546384781599, 2.7742059621959925, 3.0953314807265997, 9.730078987777233, 23.662067502737045, 22.912113144993782, 25.899410247802734, 15.746765434741974, 9.340502042323351, 17.020196802914143, 17.606074064970016, 15.560818612575531, 12.6702681183815, 9.04368381947279, 2.6775037636980414, 0.07608277563122101, 0.6182217202149332, 0.07900929398601875, 0.08519480543327518, 0.28372988454066217, 0.29710112954489887, 0.5702598032075912, 0.8463545318227261, 0.5278620938770473, 1.1121669528074563, 1.7060565599240363, 2.7066612616181374, 4.325192011892796, 3.649816489778459, 3.7573105841875076, 5.84817498922348, 2.640394954942167, 2.76353542227298, 1.578190689906478, 2.530380883254111, 1.5385510982014239, 1.407398998271674, 4.553399216383696, 4.390206998214126, 4.533369541168213, 2.2482973197475076, 2.107973461970687, 3.1391196185722947, 0.9531922708265483, 2.6375073473900557, 1.5048888232558966, 1.238769271876663, 0.040365352761000395, 3.199452068656683, 5.792413456365466, 9.521946106106043, 17.12750304490328, 20.641765370965004, 18.562953919172287, 8.857471011579037, 10.236191879957914, 1.8278273195028305, 2.773176454938948, 5.4953358974307775, 9.486536756157875, 18.859543204307556, 11.531780809164047, 16.047619991004467, 43.43907527625561, 50.390437468886375, 44.4927017390728, 51.9990773499012, 53.755590096116066, 50.34635603427887, 54.412749633193016, 56.4368212223053, 57.17291012406349, 58.55179913341999, 61.33755125105381, 59.39915746450424, 57.67028823494911, 53.720886558294296, 54.05178800225258, 23.409527353942394, 6.646393407136202, 3.721097814850509, 23.83833434432745, 49.810402393341064, 50.945390090346336, 48.97042706608772, 52.179161086678505, 53.129695281386375, 53.90283979475498, 52.031204625964165, 33.80971558392048, 4.382601706311107, 0.47034544113557786, 22.556777112185955, 61.449797227978706, 46.791730374097824, 49.504287019371986, 33.28076496720314, 16.425095535814762, 10.21998954936862, 2.3318201629444957, 17.757604233920574, 25.45551236718893, 24.30022045969963, 35.2510504424572, 24.411134608089924, 27.666739113628864, 41.01527273654938, 55.05790561437607, 23.028214015066624, 1.1841031489893794, 0.1405280374456197, 0.20105107105337083, 0.027226435231568757, 0.05276422845781781, 0.028997071567573585, 0.07534994190791622, 0.09842059691436589, 0.0661444386059884, 0.16135463083628565, 0.06058298058633227, 0.07139345616451465, 0.03148315125145018, 0.06919295119587332, 0.08992840143037029, 0.03086798133153934, 0.12225677724927664, 0.07163601228967309, 0.02562773781392025, 0.029646016628248617, 0.1394622540101409, 0.04652625088056084, 0.012260780567885377, 0.364883792353794, 1.0006881784647703, 24.253420270979404, 92.9408772289753, 32.19181939959526, 41.92291863262653, 51.53376951813698, 30.467310436069965, 49.06848080456257, 23.35593692958355, 37.558355033397675, 30.40178295224905, 20.141909793019295, 26.20606329292059, 39.02066856622696, 76.45373672246933, 74.83018264174461, 18.4357101470232, 2.0297126239165664, 6.774778068065643, 44.78853866457939, 60.63584290444851, 55.93970149755478, 58.914964646101, 62.128110229969025, 47.90130503475666, 52.945834547281265, 48.66912603378296, 13.284503258764744, 3.202267955057323, 7.449950063601136, 23.86703610420227, 50.57531274855137, 49.93169568479061, 52.09931217133999, 62.369458079338074, 62.62671187520027, 62.82230257987976, 64.50970083475113, 56.652106270194054, 54.34925504028797, 52.97688268125057, 45.244688987731934, 35.34908518195152, 22.182675786316395, 3.2254554983228445, 6.780463512986898, 20.281007029116154, 27.400722987949848, 25.317209288477898, 30.58510221540928, 21.31615698337555, 12.50084850937128, 17.86787811666727, 20.788198113441467, 21.345662400126457, 20.225657299160957, 11.813248805701733, 3.077235189266503, 1.137125319801271, 0.9853369428310543, 0.05383034957048949, 0.09299260302213952, 0.1662675742409192, 0.23626216367119923, 0.6577900657430291, 0.862120360834524, 0.3535480803111568, 0.7782567234244198, 1.0706198634579778, 2.110079498961568, 2.510560196824372, 4.592726156115532, 4.540843740105629, 4.6497340220957994, 2.652747854590416, 3.5200802888721228, 4.315656898543239, 2.632985827513039, 5.18375214189291, 7.179489126428962, 2.668334855698049, 4.193957978859544, 4.437052784487605, 1.2949500884860754, 0.628698292421177, 2.5212219497188926, 0.4337846935959533, 0.8413973415736109, 0.6792794563807547, 0.8563959680031985, 0.08474021771689877, 1.8186143576167524, 11.586446575820446, 15.782567113637924, 24.803064577281475, 26.842304952442646, 21.043635606765747, 15.656446181237698, 12.529014497995377, 2.5594376865774393, 10.849580615758896, 10.492380782961845, 18.454614132642746, 24.085837863385677, 17.36862290650606, 17.254458032548428, 43.74776691198349, 52.88018546998501, 45.995885878801346, 52.550089582800865, 55.38899324834347, 52.2500728815794, 58.025937750935555, 59.3939745426178, 60.286820232868195, 63.578868582844734, 63.339048251509666, 60.16779541969299, 58.55715684592724, 54.517323821783066, 51.63954824209213, 19.390072636306286, 5.0248650927096605, 7.292331196367741, 31.046600751578808, 52.30525352060795, 53.29663172364235, 52.991223111748695, 56.38209655880928, 56.908436715602875, 58.36618669331074, 56.02310322225094, 27.918773889541626, 1.9172189477831125, 2.0839274022728205, 33.956133127212524, 64.27249476313591, 55.97554877400398, 56.910864785313606, 28.818455412983894, 15.174777377396822, 4.994176989421248, 6.436786204576492, 14.28599176928401, 29.73906811326742, 24.75416500121355, 31.772240214049816, 30.046570412814617, 22.234776690602303, 43.452477157115936, 66.54273614287376, 32.14455373585224, 1.2048709345981479, 0.08318938882439397, 0.20952037128154188, 0.05930168117629364, 0.1151057836250402, 0.06834713291027583, 0.049132090935017914, 0.025249424325011205, 0.03299235308077186, 0.2180253539700061, 0.13330502581084147, 0.1971938178758137, 0.21055174875073135, 0.3082186501706019, 0.17060428450349718, 0.36613024421967566, 0.16116904938826337, 0.3181235905503854, 0.2767503121867776, 0.12856951507274061, 0.25671282957773656, 0.26768218784127384, 0.1615872941329144, 0.9548137744423002, 1.3918868056498468, 40.9521809220314, 100.6626708805561, 50.04366047680378, 45.4732771217823, 59.420280531048775, 35.929652228951454, 57.80630573630333, 28.770726174116135, 36.7349848151207, 35.71610368788242, 32.17731937766075, 28.4620763361454, 30.466107800602913, 82.06267654895782, 76.14738196134567, 17.39749375730753, 2.5178517680615187, 12.345424499362707, 52.2996412217617, 66.1204344034195, 61.11703388392925, 64.64402362704277, 71.22093111276627, 54.29944731295109, 57.86453381180763, 52.503363490104675, 13.308455273509026, 4.203265104442835, 10.857400596141815, 34.22632522881031, 60.40604643523693, 56.649423614144325, 55.152007564902306, 62.30296924710274, 60.83967536687851, 62.72857680916786, 65.74113115668297, 59.75766822695732, 58.977106511592865, 61.129744201898575, 54.29203771054745, 43.63926373422146, 33.41474957764149, 5.72462746873498, 9.226203225553036, 26.719277054071426, 34.99057061970234, 28.2448647916317, 33.07015746831894, 25.853248424828053, 15.544566884636879, 24.89750850945711, 25.83573516458273, 28.335885107517242, 27.928641960024834, 19.589387141168118, 8.224752712994814, 1.2229792191646993, 3.061289582401514, 0.21062600804725662, 0.27475984243210405, 0.4917489504441619, 0.8822715701535344, 1.377095386851579, 1.7902577854692936, 2.7947170240804553, 2.6672813622280955, 4.677957482635975, 6.020951718091965, 8.534269854426384, 5.921184746548533, 6.3921139016747475, 11.503053400665522, 7.402298720553517, 6.633315458893776, 7.8899826016277075, 5.860100649297237, 7.793804537504911, 11.961751487106085, 8.125914316624403, 12.502468172460794, 10.167436469346285, 5.001153415068984, 4.470390770584345, 5.946389744058251, 4.414705708622932, 3.3720376202836633, 1.4307793811894953, 2.303691222332418, 0.299037778750062, 4.971148325130343, 18.94564848393202, 24.574056565761566, 31.117197163403034, 36.890141889452934, 27.979158349335194, 20.687929093837738, 16.983447074890137, 6.077048107981682, 11.039199940860271, 11.329542361199856, 20.77060505747795, 27.48603980988264, 20.11558100581169, 21.03302277624607, 48.73195566236973, 54.980032593011856, 48.00954222679138, 55.537907257676125, 59.623976200819016, 55.51246762275696, 59.19418886303902, 61.74946054816246, 61.79589405655861, 66.34678825736046, 64.92798238992691, 62.426261231303215, 61.669714227318764, 56.65869511663914, 54.90412026643753, 29.026581645011902, 8.529055584222078, 6.402834551408887, 28.719286434352398, 57.31882989406586, 59.81340363621712, 56.52082711458206, 63.45714591443539, 60.034582167863846, 63.421446830034256, 62.11299084126949, 41.16472251713276, 5.3223074320703745, 1.806543474085629, 27.75072030723095, 71.37124344706535, 60.81427372992039, 55.667753890156746, 39.77675959467888, 24.438196755945683, 18.39452225714922, 9.045635964721441, 24.06159706413746, 42.92998619377613, 31.916292384266853, 47.30380989611149, 38.803920596838, 34.59478385746479, 55.78466221690178, 77.53385916352272, 47.93580338358879, 2.296392763964832, 0.27516086935065687, 0.36687268875539303, 0.18168036360293627, 0.29848612553905696, 0.1313043589470908, 0.1921964922803454, 0.2473945717792958, 0.1931640598922968, 0.4162361368071288], [0.1627254072809592, 0.06306108218268491, 0.02983853530167835, 0.023703834995103534, 0.06869753051432781, 0.0597023889713455, 0.011397811249480583, 0.01975568913621828, 0.03346737583342474, 0.059294500897522084, 0.010290538048138842, 0.17780636757379398, 0.10337001687730663, 0.11697215886670165, 0.09893302762066014, 12.805098183453083, 70.2505011856556, 53.48907619714737, 45.316645726561546, 46.93030133843422, 48.07519130408764, 36.94116175174713, 38.68331886827946, 8.991119340062141, 28.54403793811798, 31.21572397649288, 29.88635390996933, 34.85782854259014, 60.72785496711731, 66.69691666960716, 65.0039555132389, 11.316338069736958, 2.8203229000791907, 21.56393028795719, 61.048990935087204, 54.81734812259674, 42.25060164928436, 56.86986118555069, 57.657805904746056, 46.155348122119904, 50.13853758573532, 23.31005059182644, 9.41604483872652, 5.961811691522598, 3.478418136946857, 10.073501709848642, 25.357243940234184, 25.04015665501356, 28.622235842049122, 30.35179663449526, 36.50339104235172, 34.096235409379005, 29.830514006316662, 17.71074704825878, 12.181772980839014, 6.38257403858006, 2.76560393627733, 1.5261303959414363, 0.6414328934624791, 9.582435060292482, 16.687423959374428, 19.24145881086588, 16.470341607928276, 12.43616933003068, 3.298010230064392, 11.719264648854733, 13.525894805788994, 14.349479712545872, 11.796854585409164, 8.711916022002697, 3.8293359568342566, 3.1974904239177704, 0.3447995544411242, 0.494863239582628, 0.07367651764070615, 0.0880451720149722, 1.1837323126383126, 2.860006308183074, 3.9497617073357105, 2.6632811268791556, 4.300843868404627, 4.699607295915484, 3.978290339000523, 2.4274486815556884, 5.890716081485152, 7.510394845157862, 5.905243651941419, 7.896069400012493, 5.487382924184203, 5.490106903016567, 4.552862495183945, 3.629030417650938, 4.853910841047764, 7.25660408847034, 11.251122169196606, 11.521619204431772, 5.613163774833083, 4.614690877497196, 2.728940178640187, 1.850681786891073, 0.4143146571004763, 0.9250781731680036, 0.5829712492413819, 0.9306660701986402, 1.0198168270289898, 0.7972351019270718, 6.393455704674125, 4.042914658784866, 15.893455613404512, 16.911368742585182, 18.96471206098795, 16.02627843618393, 7.459068624302745, 7.321121776476502, 3.419112106785178, 0.807945717824623, 5.013661393895745, 16.930006742477417, 27.253997661173344, 16.204665564000607, 12.912489920854568, 40.80749988555908, 54.93737228214741, 46.624068170785904, 47.07821600139141, 51.47199243307114, 49.155883714556694, 53.52392412722111, 52.99951046705246, 50.37188686430454, 53.619055822491646, 55.03098025918007, 61.14349186420441, 57.281869277358055, 18.981695249676704, 4.645126294344664, 3.3323990972712636, 18.240336030721664, 42.649975419044495, 52.674928084015846, 51.460722237825394, 49.102109000086784, 39.937574565410614, 48.33665907382965, 54.11676071584225, 49.22027125954628, 23.474408872425556, 0.5966343067120761, 14.181925803422928, 57.84358933568001, 54.764348566532135, 45.601315051317215, 46.745562851428986, 19.58975952118635, 14.452368691563606, 5.511334463953972, 3.9704373478889465, 21.69883444905281, 21.073065027594566, 24.081762582063675, 29.56671506166458, 21.964179910719395, 36.98335088789463, 39.93545047938824, 63.310200199484825, 17.211493737995625, 0.2743522252421826, 0.05666755787387956, 0.14769691682886332, 0.04277252730389591, 0.1470459345728159, 0.04689091627369635, 0.062135416228557006, 0.10746069034212269, 0.05114533720188774, 0.04390570516989101, 0.10416818186058663, 0.04550457699224353, 0.04930650306050666, 0.02395228006207617, 0.07493227603845298, 0.06705165476887487, 0.04800493930815719, 0.06816315450123511, 0.05022564182581846, 0.05097840963571798, 0.03288199943199288, 0.1655155560001731, 0.05440392211312428, 0.18049469363177195, 0.18114028789568692, 16.969285234808922, 81.29433497786522, 58.35052393376827, 34.50896926224232, 58.17062258720398, 34.539683014154434, 48.68420362472534, 36.570632234215736, 19.2565705999732, 35.687799006700516, 20.231657177209854, 31.75127863883972, 36.12102895975113, 67.00829476118088, 68.5697677731514, 67.64458581805229, 16.581417247653008, 3.4146463964134455, 21.540177762508392, 62.7071687579155, 60.105060786008835, 50.30275717377663, 63.81487771868706, 58.29920768737793, 51.146159917116165, 55.27378723025322, 30.408508591353893, 17.565269954502583, 11.893911827355623, 6.7935077380388975, 12.743942365050316, 23.400274850428104, 23.323176987469196, 27.517179138958454, 28.115369640290737, 35.54609701037407, 31.97870023548603, 31.524542905390263, 21.39277797192335, 15.441870745271444, 8.080109674483538, 3.5141811054199934, 1.5594923682510853, 1.0628948779776692, 14.509750362485647, 20.427128188312054, 21.96183543652296, 18.607027754187584, 15.935290418565273, 8.204076122492552, 12.457356993108988, 17.526209950447083, 20.85568629205227, 17.805608958005905, 13.669803533703089, 8.037938587367535, 3.51939395070076, 0.815627183765173, 0.5006870802026242, 0.06035022823198233, 0.1370685754227452, 0.17017904872773215, 0.6886698212474585, 0.7148748182225972, 0.7526302454061806, 0.9552984859328717, 1.0921043856069446, 2.142965071834624, 3.308911370113492, 7.268936801701784, 7.803529165685177, 5.319934459403157, 8.414695970714092, 5.974376192316413, 6.5112940315157175, 6.108272457495332, 3.8718138774856925, 5.311422441154718, 4.105503475293517, 6.7578765749931335, 8.132657054811716, 4.801282240077853, 2.758096014149487, 1.4971330831758678, 3.0377766815945506, 0.8438992104493082, 2.8346284199506044, 1.3130996958352625, 1.1893955525010824, 1.1024508741684258, 2.1979010989889503, 11.957014091312885, 12.15820474550128, 22.72900477051735, 21.78466234356165, 21.864117980003357, 17.081998586654663, 12.838725429028273, 6.306758131831884, 4.640267780050635, 6.461978852748871, 7.770857093855739, 20.12640092521906, 34.31852348148823, 23.21035724133253, 17.66966175287962, 44.15261618793011, 59.190860241651535, 52.07885026931763, 47.38349162042141, 54.69238802790642, 50.18084451556206, 55.047896951437, 54.5215567946434, 53.04418466985226, 56.44580014050007, 56.383240297436714, 63.288598358631134, 55.3747022151947, 16.268616132438183, 6.174569400027394, 6.031839558854699, 22.435027845203876, 48.757395297288895, 54.512752667069435, 56.972451880574226, 53.370495960116386, 43.304535895586014, 53.37677322328091, 58.746443688869476, 55.81951014697552, 23.6390483379364, 0.5913044395856559, 18.960625380277634, 64.71803605556488, 59.575585797429085, 49.37806159257889, 43.929556757211685, 20.15078231692314, 7.409657025709748, 4.577853754162788, 7.416738420724869, 19.83898814767599, 31.95693500339985, 20.64979624003172, 30.78498288989067, 25.817707031965256, 29.571614898741245, 50.97886249423027, 70.51735326647758, 19.13559079170227, 0.5465333419851959, 0.22112022852525115, 0.13249039999209344, 0.07854939249227755, 0.11831970608909614, 0.06811795028625056, 0.06859130691736937, 0.14919770270353183, 0.0872651525423862, 0.028379261457303073, 0.2175497412099503, 0.1808733819052577, 0.09896312913042493, 0.10855405198526569, 0.2544507337734103, 0.20805278909392655, 0.12027871620375663, 0.21326037996914238, 0.11787771261879243, 0.15547670249361545, 0.16219345066929236, 0.3076868271455169, 0.300409208284691, 0.39416831627022475, 0.43665662698913366, 27.370535507798195, 95.55380702018738, 74.15372774004936, 55.702525824308395, 69.3852724134922, 58.965349942445755, 52.194588258862495, 58.74718464910984, 16.181526705622673, 41.0173474252224, 39.88823801279068, 45.485611259937286, 38.567930459976196, 75.65386444330215, 73.24825912714005, 73.58748212456703, 19.71031565219164, 6.009044107049704, 29.97730202972889, 70.36065727472305, 66.6486668586731, 56.65538929402828, 68.68246972560883, 67.50568807125092, 58.29290762543678, 61.187797486782074, 29.999979212880135, 18.166752979159355, 14.423630833625793, 8.831280916929245, 15.461874771863222, 35.973539873957634, 33.85399080812931, 39.70412649214268, 39.84665684401989, 47.67145536839962, 44.27315331995487, 41.36736184358597, 27.70028181374073, 18.620997704565525, 9.266808796674013, 4.4848014973104, 2.207480384968221, 1.5533878770656884, 21.26778557896614, 27.531610764563084, 26.496134027838707, 24.39493417739868, 17.952750362455845, 9.519459139555693, 17.928458265960217, 22.69619733095169, 27.619386054575443, 25.045911446213722, 22.62382071465254, 18.56844462454319, 8.884969186037779, 0.4858970863278955, 1.9415515358559787, 0.15240704611642286, 0.28101142728701234, 2.245450560003519, 4.157229624688625, 5.55426218546927, 4.054689276963472, 7.635751543566585, 8.229917585849762, 7.440587365999818, 4.483220307156444, 10.53323334082961, 13.154771570116282, 8.618866614997387, 11.109192185103893, 10.22759199142456, 12.937343437224627, 12.675472889095545, 10.079414192587137, 10.840304363518953, 13.382484801113605, 13.759751357138157, 15.59905406087637, 10.546240992844105, 6.179924262687564, 6.9227435532957315, 5.416323887184262, 0.9980926802381873, 3.134586699306965, 0.8302466024179012, 1.1601389036513865, 2.263578912243247, 3.422318184748292, 18.97592145949602, 19.03002105653286, 29.09030232578516, 29.49444103986025, 29.126630276441574, 25.550159588456154, 16.022235453128815, 13.80942514166236, 5.557812144979835, 5.882442025467753, 8.483257591724396, 22.823661491274834, 33.45144420862198, 25.083518028259277, 16.20953880250454, 49.00327630341053, 59.83340576291084, 53.004043623805046, 52.062340155243874, 59.15745623409748, 52.93536230921745, 58.70174288749695, 57.1926386654377, 57.852290868759155, 56.36443890631199, 56.666986271739006, 63.86984556913376, 65.23823574185371, 23.623598366975784, 8.826697412878275, 4.681686507537961, 21.92361518740654, 51.159983575344086, 61.77115738391876, 61.739877462387085, 58.76105010509491, 48.152330964803696, 59.15898755192757, 62.448436841368675, 62.17804715037346, 27.595755122601986, 1.4238681457936764, 17.38541230559349, 67.65201821923256, 65.92555046081543, 56.19871839880943, 51.94064788520336, 28.9975531026721, 22.092732712626457, 14.13142841309309, 8.91114978119731, 34.04447838664055, 39.42226521670818, 32.77828373014927, 46.762901321053505, 32.24932171404362, 48.43823902308941, 57.449675872921944, 84.62670296430588, 34.28579203784466, 0.6240140344016254, 0.46190508466679603, 0.1964942249469459, 0.19036534678889439, 0.3002161014592275, 0.18810443842085078, 0.21312084136297926, 0.23107691144105047, 0.22673307656077668, 0.16566569247515872], [0.043270337700960226, 0.027138353434565943, 0.10749549706815742, 0.02690277720830636, 0.06851042024209164, 0.04467483733606059, 0.039060686831362545, 0.01735490634018788, 0.1256355975056067, 0.1028341417259071, 0.11791271972469985, 0.02789284673781367, 0.10638294348609634, 0.05083123061922379, 0.08486783743137494, 3.4512590942904353, 58.05808402597904, 58.282446786761284, 42.688554748892784, 39.152525290846825, 57.09756016731262, 28.111826330423355, 38.39902572333813, 15.988991037011147, 27.082518562674522, 35.8327080309391, 25.825251527130604, 36.40959307551384, 47.59251080453396, 34.486071690917015, 62.66176499426365, 36.494389325380325, 3.2886425452306867, 5.8570698369294405, 41.84144340455532, 68.15784707665443, 62.88125641644001, 61.554120630025864, 60.21606042981148, 44.1832235455513, 51.35564647614956, 41.20010621845722, 17.214624769985676, 6.4118291437625885, 5.935323787853122, 2.6238907780498266, 1.2527408846653998, 1.8906594417057931, 9.13004843518138, 4.131519729271531, 6.471562413498759, 3.488126853480935, 3.064994621090591, 1.5977850509807467, 1.4510706486180425, 1.415690272115171, 9.985467083752155, 4.446563674136996, 1.8032326642423868, 11.514900214970112, 16.12998817116022, 14.036821089684963, 9.478797521442175, 2.7895433641970158, 2.6688613649457693, 8.505955673754215, 12.842639219015837, 6.890406338497996, 7.44356450624764, 3.7295856093987823, 3.0032966192811728, 1.4755921578034759, 0.7939392537809908, 0.4474931408185512, 0.1254473443259485, 0.31317824497818947, 0.5752034566830844, 0.5171298666391522, 1.0640299483202398, 6.083324896171689, 4.608777444809675, 6.220128955319524, 7.265184978023171, 7.863979646936059, 9.045414626598358, 11.443584691733122, 10.069879554212093, 13.64365428686142, 8.341069221496582, 9.56241488456726, 8.137240558862686, 3.7085770117118955, 8.406202476471663, 14.067612737417221, 16.442008428275585, 11.07162930071354, 7.548670191317797, 7.60132254101336, 2.7783833630383015, 0.7866656722035259, 0.45526802830863744, 0.0454710319172591, 0.7463803526479751, 0.24432133825030178, 1.2934296950697899, 0.8023573458194733, 4.0291589219123125, 1.1711077275685966, 11.40966771170497, 15.687188431620598, 11.777345482259989, 20.632592663168907, 14.877764414995909, 3.4435618948191404, 9.142190683633089, 2.8436272870749235, 22.033267803490162, 28.37998554110527, 8.318329341709614, 23.624647110700607, 16.74812190234661, 12.504628356546164, 26.4636267721653, 46.62395037710667, 52.58144170045853, 49.970047026872635, 46.833216547966, 53.70614714920521, 56.370868161320686, 55.246025919914246, 51.773787438869476, 44.68545779585838, 25.970850214362144, 4.55791337415576, 0.48961646331008524, 14.552299529314041, 19.35657173395157, 50.8776169270277, 47.4754922837019, 46.45480625331402, 46.75863794982433, 48.14934432506561, 47.87590719759464, 46.79321989417076, 49.75817419588566, 49.83081869781017, 14.389701504260302, 1.5830439794808626, 19.946355186402798, 56.33559465408325, 34.99098479747772, 51.32246285676956, 44.3881693482399, 7.816415699198842, 14.86041359603405, 4.825617084279656, 5.529590109363198, 22.003591395914555, 17.079272232949734, 24.463066421449184, 27.227799966931343, 22.807462960481644, 40.33019609749317, 46.65660582482815, 60.181706473231316, 2.401985772885382, 0.23449441243428737, 0.04979340759746265, 0.163423664344009, 0.02947449145722203, 0.05877323121239897, 0.060203817338333465, 0.02714984744670801, 0.11940665557631291, 0.058524318592390046, 0.12858391273766756, 0.048211256362264976, 0.05280746969219763, 0.02913359334343113, 0.021270583238219842, 0.13516986480681226, 0.013440600559988525, 0.03425215618335642, 0.10632685938617215, 0.07402138624456711, 0.04450963897397742, 0.06438673604861833, 0.1652711964561604, 0.024657513313286472, 0.14395721984328702, 0.14898944122251123, 4.730652580037713, 66.19158938527107, 75.13043493032455, 34.13058176636696, 45.42618244886398, 45.538329631090164, 33.46266880631447, 45.199026837944984, 21.879731342196465, 37.23967373371124, 30.50834633409977, 19.939992427825928, 36.74523286521435, 56.95311091840267, 40.49351893365383, 64.61333647370338, 40.04752926528454, 5.2548515517264605, 6.462537422776222, 48.53836365044117, 74.77050304412842, 69.1823785007, 65.63883304595947, 66.14193364977837, 52.125686556100845, 54.79310542345047, 46.27460092306137, 22.662622332572937, 11.921317856758833, 13.69007259607315, 6.4836300909519196, 5.311650903895497, 4.062661249190569, 16.211892776191235, 7.6693108677864075, 11.086244266480207, 7.020850013941526, 7.0868610218167305, 4.1576894000172615, 3.959152903407812, 3.7378382915630937, 19.531537145376205, 8.961169347167015, 4.833357743918896, 16.093299239873886, 22.497023418545723, 16.585692018270493, 14.321506563574076, 8.739784676581621, 4.159623496234417, 9.853007141500711, 16.29441674798727, 14.035997483879328, 11.093981601297855, 7.5792765989899635, 4.818945117294788, 5.153480591252446, 0.8436861843802035, 1.751627039629966, 0.20310021500336006, 0.08205072648706846, 0.3126599290408194, 1.0374601115472615, 3.5069873789325356, 4.4881282187998295, 6.877489881590009, 8.630098812282085, 8.453298099339008, 6.582769621163607, 8.986100759357214, 13.41549837961793, 9.04226079583168, 14.82440672814846, 9.961437173187733, 10.242173708975315, 11.941802557557821, 6.862518209964037, 3.4951134910807014, 10.495875645428896, 14.572741482406855, 13.306671269237995, 8.554859049618244, 7.468732455745339, 4.2022215854376554, 1.4995963010005653, 0.3909080912126228, 1.0512166796252131, 1.6692384355701506, 2.155319871380925, 1.6137891984544694, 1.0159228672273457, 8.46829779446125, 10.91553557664156, 19.94548123329878, 19.260104410350323, 13.623255081474781, 21.196940280497074, 17.27987676858902, 4.49557201936841, 8.821773827075958, 7.167714033275843, 25.458242520689964, 25.665255412459373, 13.090766854584217, 31.65254283696413, 26.84592805802822, 21.818341836333275, 28.864845223724842, 46.41850680112839, 56.94390781223774, 53.787394389510155, 51.80138535797596, 56.55617281794548, 58.95940326154232, 57.61687070131302, 50.70167116820812, 43.09310384094715, 20.389075130224228, 2.3436771892011166, 2.059487351216376, 19.355454593896866, 25.88332761079073, 54.40063588321209, 53.512285351753235, 51.80615410208702, 52.26003594696522, 52.63955198228359, 53.25969010591507, 52.12193235754967, 55.746044889092445, 52.44943678379059, 18.10546986758709, 2.3675446584820747, 27.6486748829484, 64.8741164803505, 44.048520773649216, 56.364666894078255, 50.09867772459984, 7.703887112438679, 12.390933707356453, 8.723051324486732, 7.675805669277906, 24.572065472602844, 25.192332789301872, 18.961115553975105, 33.90389733016491, 23.001330457627773, 43.150868341326714, 56.27404935657978, 65.64113572239876, 3.722639582119882, 0.4017929040128365, 0.1358252702630125, 0.1274731254670769, 0.0924018831574358, 0.07311686407774687, 0.08201132586691529, 0.11319082739646547, 0.09862021979643032, 0.041391160411876626, 0.05810789210954681, 0.17524848139146343, 0.09961393327102996, 0.19015926722204313, 0.16442243184428662, 0.2438880575937219, 0.12235826594405808, 0.17690804234007373, 0.1892825384857133, 0.37167479982599616, 0.27170765621121973, 0.1282357712625526, 0.22384438547305763, 0.3509546007262543, 0.2781337348278612, 0.5122185114305466, 7.407986065372825, 80.40638342499733, 83.49212184548378, 54.3584543466568, 56.08164668083191, 75.32990902662277, 36.309954822063446, 63.41339126229286, 24.88237202167511, 41.294899731874466, 44.40290115773678, 36.30127988755703, 42.83070132136345, 57.73299627006054, 45.75861521065235, 70.97242444753647, 44.164387956261635, 7.430023932829499, 10.116880182176828, 55.54150566458702, 77.09144130349159, 72.85246476531029, 72.6229190826416, 68.75494703650475, 56.14832170307636, 63.15669223666191, 50.89773304760456, 22.29559812694788, 8.854306731373072, 12.01406043022871, 4.403971284627914, 4.005353199318051, 3.9636625489220023, 17.13820707052946, 9.619291182607412, 11.694296188652515, 6.841938039287925, 6.451929342001677, 3.55700362008065, 3.9771556248888373, 5.23662487976253, 18.808226957917213, 7.824936741963029, 5.488300574943423, 18.630045019090176, 28.36473125964403, 22.09470860660076, 15.925954319536686, 9.26906967535615, 10.749759022146463, 15.29055431485176, 24.711875170469284, 19.499654956161976, 15.718700140714645, 13.944090865552425, 8.810063805431128, 7.850437648594379, 2.552330167964101, 2.44792222045362, 1.803715475834906, 0.5779424565844238, 1.047260498162359, 1.1343494500033557, 5.9153074119240046, 9.613104164600372, 10.78080240637064, 11.701668743044138, 14.537079446017742, 15.761065967381, 16.33815050125122, 17.625082544982433, 18.986824974417686, 20.19659835845232, 16.522110030055046, 17.35546611249447, 17.25027445703745, 11.868520639836788, 15.879020188003778, 20.953458845615387, 21.16542287170887, 17.43531882762909, 13.157299384474754, 13.662702664732933, 4.991094404831529, 1.1680019879713655, 0.8194166491739452, 1.167104879859835, 2.2298797080293298, 3.1859345315024257, 3.032135646790266, 1.668391318526119, 13.669531848281622, 15.567080676555634, 26.56405158340931, 26.661565750837326, 20.38067378103733, 30.668511539697647, 22.736230082809925, 9.460994526743889, 12.767418455332518, 5.983254890888929, 28.94430845975876, 34.53122466802597, 12.546784244477749, 30.280732847750187, 22.1005716919899, 16.53913501650095, 34.424879774451256, 53.50396379828453, 61.5047612786293, 54.148272424936295, 52.05717623233795, 56.916059106588364, 60.49481347203255, 54.812567979097366, 52.87805758416653, 48.73365417122841, 31.247754357755184, 7.5055277813225985, 3.1256201304495335, 20.01106571406126, 25.298159010708332, 54.654207676649094, 57.600132599473, 57.680908665061, 57.44684122502804, 57.430870682001114, 58.858237490057945, 56.074818447232246, 60.30599020421505, 58.078899309039116, 19.269898384809494, 2.5107938842847943, 27.10318185389042, 73.19756984710693, 51.78841285407543, 60.16553834080696, 53.617528304457664, 16.319768987596035, 25.102752596139908, 13.680097181349993, 10.244853515177965, 37.53763474524021, 29.863726124167442, 34.124988466501236, 45.1040281355381, 30.80807615071535, 58.951191902160645, 61.31442189216614, 87.46976360678673, 8.187158480286598, 0.6685880769509822, 0.31407419533934444, 0.26396506698802114, 0.2683054731460288, 0.18304552941117436, 0.17260809807339683, 0.1819651256664656, 0.24879035860067233, 0.20751612726598978, 0.3253523167222738], [0.03983669128501788, 0.029454692812578287, 0.09641593729611486, 0.08738080141483806, 0.045331196452025324, 0.030618764430982992, 0.013650253567902837, 0.02623282009153627, 0.12291258346522227, 0.06402569604688324, 0.019462624295556452, 0.10302073249476962, 0.12458438985049725, 0.08047551804338582, 0.4562858393182978, 0.5701209919061512, 28.170033507049084, 70.62413513660431, 47.21267178654671, 35.56177116930485, 52.786585092544556, 38.048889711499214, 32.411356419324875, 31.282740980386734, 12.778699100017548, 37.86278709769249, 34.80655029416084, 19.43797666579485, 27.270773760974407, 38.75831924378872, 63.07762607932091, 61.813255324959755, 7.912061791867018, 2.77168289758265, 21.29421506077051, 56.716197431087494, 54.70837377011776, 53.1804833561182, 59.66825522482395, 43.60417261719704, 44.75120946764946, 54.0127032995224, 57.54347383975983, 24.67984478920698, 6.574978139251471, 1.268234672024846, 0.5943874991498888, 1.0213103843852878, 19.12030801177025, 29.722934179008007, 18.956842683255672, 3.90967670828104, 5.475748898461461, 4.6450550481677055, 8.229310568422079, 2.28279828093946, 7.089358437806368, 3.148918580263853, 3.9253209438174963, 9.289616122841835, 11.135958898812532, 3.8148784451186657, 1.4315078733488917, 5.592708047479391, 4.561746418476105, 9.894954040646553, 11.00584153085947, 3.537519690580666, 6.338390959426761, 6.203661113977432, 3.7284133723005652, 2.8343883203342557, 1.268783148843795, 0.08232358450186439, 0.7288656674791127, 0.6460879999212921, 0.5899412033613771, 2.700364999473095, 9.228091724216938, 14.349861592054367, 13.460699804127216, 14.363723248243332, 6.936702104285359, 11.651777420192957, 14.654079917818308, 13.28420877456665, 10.980157759040594, 15.033553205430508, 8.161907885223627, 15.609504450112581, 13.07280806824565, 7.917240913957357, 13.783338591456413, 14.203245509415865, 21.844588927924633, 10.133511889725924, 14.174785036593676, 8.56135480105877, 1.1025793547742069, 0.9110921924002469, 0.5786065303254873, 0.5019883322529495, 0.25197377137374133, 0.9258248331025243, 2.43128742557019, 0.346300236415118, 0.3715925698634237, 0.7635275856591761, 3.936053942888975, 11.106811612844467, 8.691205233335495, 13.101693168282509, 20.27939021587372, 6.110929939895868, 6.126995952799916, 8.411293253302574, 15.67990517243743, 24.106641747057438, 6.14095545373857, 4.495400553569198, 17.854202650487423, 26.790475733578205, 13.391125537455082, 11.53848459944129, 21.985855847597122, 38.474083095788956, 47.27716572582722, 39.73403848707676, 45.80349080264568, 33.95905517041683, 22.719592675566673, 8.199196234345436, 4.582819612696767, 2.372362087480724, 6.934777507558465, 25.191434137523174, 27.944549806416035, 52.70210042595863, 55.10993242263794, 50.49127645790577, 50.37075832486153, 54.72101949155331, 57.87532903254032, 56.039522141218185, 55.45091852545738, 42.44054205715656, 12.864665687084198, 3.077770248055458, 38.67018297314644, 35.41451387107372, 19.662730805575848, 27.085987776517868, 13.402220942080021, 10.941713321954012, 13.725029770284891, 7.48389839194715, 8.790807388722897, 26.004670299589634, 19.194924607872963, 32.46303744614124, 24.874111264944077, 26.906361915171146, 31.226559095084667, 59.78853017091751, 32.939794063568115, 0.3531051072059199, 0.14808785053901374, 0.04822637391043827, 0.13018263241974637, 0.011284782158327289, 0.08147553977323696, 0.023651658302696887, 0.1353519581607543, 0.11015850846888497, 0.0037821002888449584, 0.07264313637278974, 0.002547005369706312, 0.02587994371424429, 0.0523591048840899, 0.08582847338402644, 0.03755416415515356, 0.08019359098398127, 0.05851635905855801, 0.07607196996104904, 0.04208961414406076, 0.04099076802958734, 0.006042690229151049, 0.07220902451081201, 0.08089608571026474, 0.022755763602617662, 0.4383611324010417, 0.38899741717614233, 34.21553760766983, 84.73831057548523, 47.86553755402565, 37.979011461138725, 55.08027881383896, 29.60843302309513, 45.90465657413006, 29.142452627420425, 27.554894015192986, 41.58232010900974, 22.722104340791702, 25.75731497257948, 36.92387267947197, 43.33838827908039, 73.08710217475891, 70.84934905171394, 15.07281269878149, 3.2908423896878958, 22.79559049755335, 63.70023027062416, 60.40598563849926, 59.883950650691986, 65.80008879303932, 49.395278468728065, 51.200098022818565, 58.48927728831768, 58.190092742443085, 24.95268724858761, 7.331127114593983, 3.4373330790549517, 3.328794753178954, 3.8387862872332335, 28.59306860715151, 39.14288520812988, 23.67783285677433, 8.270966783165932, 9.45370651781559, 6.168068423867226, 8.287862576544285, 3.160534081980586, 10.87163083255291, 6.407786160707474, 9.4371004588902, 13.399053812026978, 14.373917151242495, 12.355531007051468, 6.5682088024914265, 4.906737981364131, 3.6315940925851464, 8.933747168630362, 16.469532251358032, 8.808292150497437, 6.8402528297156096, 5.813322309404612, 5.0675999745726585, 3.69874503929168, 2.060794956050813, 0.3367706743301824, 0.832148875342682, 0.7446103601250798, 2.088954532518983, 2.3178335884585977, 4.291808903217316, 11.04346426203847, 9.499831292778254, 10.614850111305714, 11.639854609966278, 12.594761420041323, 12.438469156622887, 15.121762622147799, 14.194376785308123, 17.833837643265724, 9.049439560621977, 14.215108472853899, 14.541215524077415, 7.025344697758555, 13.099568132311106, 19.892156794667244, 23.420221880078316, 14.365638345479965, 13.806580994278193, 13.23411226272583, 5.11927530169487, 0.8992358786053956, 1.0966234118677676, 1.162215017247945, 1.7034123768098652, 2.326644603163004, 1.6244509513489902, 1.3165306742303073, 4.082881389185786, 7.601770916953683, 9.518152009695768, 17.260911986231804, 10.013918057084084, 14.522551875561476, 19.898650646209717, 8.096038419753313, 6.290061352774501, 11.047950871288776, 20.49871064722538, 32.57192440330982, 7.015535049140453, 9.521903358399868, 26.267405301332474, 35.379855930805206, 25.259330794215202, 14.996208809316158, 22.583318687975407, 35.780555829405785, 46.12479396164417, 36.42913542687893, 41.93094380199909, 26.604984886944294, 21.37121982872486, 5.389445079490542, 10.01499054953456, 7.472410183399916, 9.286230504512787, 29.512146189808846, 32.66293331980705, 56.74766734242439, 54.91722196340561, 54.545655101537704, 52.67475329339504, 57.065406292676926, 58.497298657894135, 59.380964040756226, 60.75645223259926, 44.772017151117325, 12.910451330244541, 3.926381324417889, 43.287661001086235, 40.50142630934715, 22.21721403300762, 31.72035589814186, 20.662972033023834, 9.238058589398861, 13.938555512577295, 13.687620777636766, 14.240280222147703, 33.96957680583, 20.129750445485115, 30.80990955233574, 31.018949635326862, 23.504704646766186, 39.162473157048225, 67.17970356345177, 35.88333651423454, 0.5019387567881495, 0.1126641474547796, 0.060106607124907896, 0.07844092760933563, 0.023560010486107785, 0.07127066040993668, 0.0678103968675714, 0.08667359405080788, 0.050493289963924326, 0.056278216070495546, 0.13568905647844076, 0.11954407164012082, 0.1831880514509976, 0.17048110283212736, 0.3088405105518177, 0.2215343914576806, 0.18979132524691522, 0.23552858037874103, 0.1914298685733229, 0.25083594024181366, 0.09039323820616119, 0.14235162787372246, 0.20380656147608534, 0.3140168421668932, 0.1403860200662166, 0.5864873668178916, 0.9809709771070629, 47.56761074066162, 94.01803582906723, 62.48219043016434, 49.68770697712898, 76.71754896640778, 44.84176620841026, 53.14135305583477, 45.74185810983181, 23.707779049873352, 50.71098826825619, 44.48066018521786, 28.888525553047657, 32.92341314256191, 46.32409326732159, 77.4483485519886, 71.37600839138031, 14.348212480545044, 4.900735728442669, 28.519242368638515, 68.35313379764557, 65.57408452033997, 66.08574226498604, 72.3124985396862, 56.28568813204765, 57.66739659011364, 64.88059893250465, 64.0940411388874, 27.9097892716527, 9.542661644518375, 4.741034572944045, 2.8557493491098285, 3.3655026834458113, 33.04368048906326, 39.23838548362255, 28.179173916578293, 7.205827413126826, 9.5080597512424, 7.977026905864477, 11.375098116695881, 6.36129280552268, 14.563599172979593, 6.2898466642946005, 12.578769978135824, 18.735648952424526, 20.48452790826559, 9.904106799513102, 5.98219427280128, 12.696833442896605, 14.840423818677664, 13.120796643197536, 22.703848220407963, 15.805640425533056, 8.88031443580985, 8.59707098454237, 6.306456523016095, 6.755985226482153, 4.517303053289652, 0.2179041167255491, 2.0526553178206086, 1.600968805141747, 3.0874191178008914, 7.252536406740546, 15.283613037317991, 20.708301700651646, 20.468430072069168, 21.521984338760376, 13.385240603238344, 19.00343958288431, 21.181136928498745, 17.553942762315273, 18.286872133612633, 22.137083932757378, 16.06609459966421, 22.42690198123455, 17.497316300868988, 15.477580279111862, 26.206625662744045, 22.83116988837719, 30.5473455414176, 13.76506632193923, 21.28718163818121, 19.92089845240116, 8.342059068381786, 2.281297123990953, 2.48305038549006, 4.261103225871921, 4.100559940561652, 4.113296857103705, 4.288178673014045, 2.652839762158692, 9.473845437169075, 8.079994730651379, 15.9682422503829, 21.697373427450657, 17.520134076476097, 20.39538849145174, 29.474005736410618, 12.957170773297548, 13.937781304121017, 12.12494608014822, 20.455385372042656, 33.9679466933012, 11.870344541966915, 8.221216052770615, 24.36633501201868, 31.504521779716015, 19.458641856908798, 14.767656773328781, 29.219174310564995, 45.32511547207832, 55.10505348443985, 43.529267236590385, 51.84792906045914, 37.09716618061066, 28.58630497008562, 11.472801323980093, 9.617623072117567, 4.050494777038693, 11.83018259704113, 29.62006989866495, 34.92747500538826, 60.58126263320446, 60.7975622266531, 58.29582966864109, 57.953521236777306, 60.52138924598694, 67.39272773265839, 62.21754603087902, 67.15724676847458, 47.97982022166252, 17.973476350307465, 3.7401150818914175, 43.04050326347351, 44.13752719759941, 29.314273707568645, 35.6709773093462, 21.024323143064976, 20.25538120418787, 24.697204157710075, 18.28990437090397, 17.972389608621597, 45.76788291335106, 32.2755441069603, 46.838148683309555, 42.508528009057045, 36.7065167427063, 49.91928555071354, 72.12249353528023, 59.19519580900669, 0.6364308774936944, 0.27024357696063817, 0.134185227798298, 0.2603404474211857, 0.1766679872525856, 0.11731279722880572, 0.15570160292554647, 0.3466465522069484, 0.1927871973020956, 0.16647684504278004, 0.26746536197606474], [0.07174028403824195, 0.03743497894902248, 0.05862080892256927, 0.13356235809624195, 0.03220601050998084, 0.07525049411924556, 0.013947561637905892, 0.1171637665538583, 0.08793258079094812, 0.055367029417539015, 0.1018053840380162, 0.025554652966093272, 0.1198483225016389, 0.10357890918385237, 0.2215682779205963, 0.14830887696007267, 6.144120683893561, 59.34979051351547, 59.89808589220047, 42.37294368445873, 54.15105387568474, 60.613819286227226, 25.064427852630615, 41.61976709961891, 11.520894393324852, 30.15093181282282, 41.3307736068964, 29.362088441848755, 22.813069559633732, 41.782569363713264, 52.00502023100853, 58.87391544878483, 33.003885224461555, 5.280696339905262, 8.598189074546099, 35.72610855102539, 54.19016517698765, 64.53736335039139, 62.29433611035347, 58.39697264134884, 49.848115369677544, 51.88309997320175, 53.26669692993164, 48.914760053157806, 30.708101615309715, 9.447547998279333, 4.9007623270154, 2.078303466551006, 2.0226324163377285, 2.3637109016999602, 3.9200651133432984, 1.0200887499377131, 3.3544462267309427, 1.7914158920757473, 5.238053128123283, 2.4056580383330584, 4.641347397118807, 8.291596826165915, 8.145550712943077, 5.706732803955674, 4.427070245146751, 1.7718263994902372, 5.623349603265524, 10.157957877963781, 3.482006094418466, 6.124423015862703, 8.111894018948078, 4.909556480124593, 6.878363359719515, 7.150107678025961, 6.0212851502001286, 0.7674784830305725, 2.2120914375409484, 3.035876783542335, 1.6528907627798617, 0.5646931612864137, 1.269178802613169, 3.830023482441902, 14.434681590646505, 23.03674265742302, 28.039896190166473, 23.70126809924841, 12.607988510280848, 9.418780691921711, 18.33904143422842, 17.895903512835503, 6.327765304595232, 7.00726336799562, 7.176060760393739, 19.980192370712757, 18.66134773939848, 18.719442822039127, 20.911341905593872, 22.548552453517914, 11.164906695485115, 14.88794406875968, 19.677377119660378, 12.462997790426016, 10.27179691940546, 3.9714701799675822, 6.284297062084079, 5.398203609511256, 5.838141152635217, 1.06054802890867, 2.2400142392143607, 4.469466945156455, 5.426750527694821, 2.6106644002720714, 1.2176552298478782, 1.7774614971131086, 8.051853440701962, 8.185437172651291, 18.3313924446702, 10.347109828144312, 7.7562084048986435, 9.905172642320395, 19.26849815994501, 11.13198621198535, 6.726821791380644, 11.090012714266777, 6.664163628593087, 17.11807195097208, 23.972094766795635, 23.715618029236794, 6.634521894156933, 4.27386911585927, 5.776638127863407, 5.567809883505106, 12.233215570449829, 4.627858120948076, 9.11753760650754, 4.4968796242028475, 3.881282969377935, 12.108523361384869, 5.340494681149721, 34.19762156903744, 46.24672941863537, 52.81480997800827, 47.748849615454674, 51.338380202651024, 48.37441764771938, 56.378361359238625, 49.696841686964035, 57.482924088835716, 53.3782247453928, 42.960688546299934, 8.45791770145297, 5.906701823696494, 36.51201277971268, 51.558798775076866, 45.30541352927685, 22.898069098591805, 24.5213058963418, 18.106890991330147, 10.443485006690025, 3.2943887868896127, 19.757117740809917, 20.800688043236732, 21.343447118997574, 33.04368048906326, 25.652301907539368, 34.09968942403793, 38.26691061258316, 62.10361294448376, 6.410227054730058, 0.25997970427852124, 0.056942271257867105, 0.056834214556147344, 0.08918098450521939, 0.08774214569712058, 0.057902090848074295, 0.017932703558471985, 0.04330642092099879, 0.026590974994178396, 0.055199448761413805, 0.01901483650726732, 0.04691352580266539, 0.0583010397531325, 0.06508610633318312, 0.037534148432314396, 0.024952544845291413, 0.10003323928685859, 0.06885070979478769, 0.07172669531428255, 0.05287946172757074, 0.03783189436944667, 0.08339707143022679, 0.026404091076983605, 0.1690682614571415, 0.03465850059001241, 0.4642478667665273, 0.1974625198636204, 8.793689534068108, 69.56738144159317, 70.96280336380005, 38.99973928928375, 57.328929752111435, 40.94301201403141, 31.116338409483433, 39.02949549257755, 22.613186985254288, 45.83192087709904, 37.674138620495796, 22.841307744383812, 30.988971143960953, 52.07232981920242, 64.85751137137413, 64.1971904039383, 47.399849742650986, 11.447083353996277, 9.095138758420944, 36.12463876605034, 60.32994031906128, 69.50836300849915, 68.2795013487339, 58.16065192222595, 55.04053294658661, 56.61941662430763, 56.337885931134224, 48.952571824193, 30.43424841016531, 9.246528334915638, 8.20916024968028, 1.6012925002723932, 0.7606082141865045, 3.297840189188719, 4.725890960544348, 4.74660649895668, 6.229851683601737, 4.569752113893628, 5.291639752686024, 1.4829930919222534, 8.656257558614016, 16.386314816772938, 11.981774512678385, 7.014027005061507, 8.994488809257746, 6.187180448323488, 7.913041189312935, 11.821909490972757, 6.287954840809107, 11.652436684817076, 13.758910652250051, 6.4616055227816105, 5.974904838949442, 7.514646342024207, 6.222016029059887, 4.0695754531770945, 3.2810199167579412, 3.1990711390972137, 0.9983406169340014, 1.2026628968305886, 4.459649221971631, 2.2952497377991676, 8.048976995050907, 19.354563541710377, 21.376712433993816, 18.633149452507496, 14.8238624073565, 16.980262845754623, 22.333151511847973, 17.8811090067029, 9.709459394216537, 13.618336245417595, 7.369307465851307, 21.730830632150173, 24.067287258803844, 16.01399939507246, 26.303182281553745, 22.091163396835327, 22.99673840403557, 13.583496864885092, 22.633551992475986, 14.878343883901834, 3.086216957308352, 1.389839902985841, 1.0785762802697718, 1.6243462194688618, 1.9710361724719405, 2.385703409090638, 2.9137418372556567, 7.741088066250086, 7.270519891753793, 10.162935610860586, 5.0200265273451805, 10.636257212609053, 10.381625276058912, 11.137783750891685, 22.202005349099636, 10.932857897132635, 7.895061504095793, 8.128940854221582, 20.94239953905344, 21.385415866971016, 11.694112848490477, 7.409661300480366, 10.328597221523523, 20.12179557234049, 32.19336971640587, 36.76658011972904, 13.759280182421207, 5.712703708559275, 5.674165701493621, 6.424757475033402, 18.634296990931034, 7.895953981205821, 14.152368139475584, 6.2487860675901175, 8.058771919459105, 18.66673205047846, 10.004345420747995, 37.602269276976585, 53.39413829147816, 58.03463168442249, 51.987309381365776, 53.919444903731346, 53.291843980550766, 58.06299336254597, 55.082813277840614, 61.806970462203026, 59.76427227258682, 44.76757898926735, 11.130923219025135, 8.320786859840155, 44.671387150883675, 50.21804451942444, 47.39327609539032, 27.174293138086796, 24.401179142296314, 13.036122936755419, 10.368855111300945, 9.58159340545535, 24.017268642783165, 20.418700240552425, 19.7031644359231, 33.43395374715328, 28.861073926091194, 30.085394829511642, 49.8296407610178, 66.6870068013668, 8.211913201957941, 0.44920631451532245, 0.13185521063860506, 0.16689756856067106, 0.055603796790819615, 0.02935225231340155, 0.08044222529861145, 0.07762056498904712, 0.069517299416475, 0.014284267545008333, 0.026133565261261538, 0.06756919145118445, 0.1559076231205836, 0.2857722749467939, 0.14965155569370836, 0.227417366404552, 0.1401307064224966, 0.2381652529584244, 0.14616905740695074, 0.2900744753424078, 0.21869968419196084, 0.21615123812807724, 0.21348747715819627, 0.1332553761312738, 0.3218449268024415, 0.21642881620209664, 0.627704052021727, 0.442446744418703, 13.10549771413207, 85.64859732985497, 81.13474354147911, 58.59853282570839, 73.64385589957237, 78.37388008832932, 35.66815406084061, 61.0950368642807, 18.193087466061115, 47.15184085071087, 51.63491629064083, 38.07892709970474, 26.325973458588123, 47.012654319405556, 67.40083649754524, 72.60590359568596, 42.38899402320385, 11.062885019928217, 13.246362805366516, 47.76768520474434, 66.53928592801094, 78.20859655737877, 73.41503977775574, 67.96258315443993, 59.027313217520714, 63.08521427214146, 58.164037540555, 55.637002140283585, 38.52395921945572, 16.916677057743073, 9.957914762198925, 4.3062172550708055, 3.914707163348794, 5.05903665907681, 5.951865250244737, 4.70363175496459, 8.434567004442215, 3.933915845118463, 10.444986876100302, 5.647342465817928, 12.855825461447239, 16.502550579607487, 15.581687092781067, 9.45126324892044, 10.69630729034543, 6.552073918282986, 15.187871474772692, 22.327263727784157, 12.949482835829258, 15.160958468914032, 20.22281125187874, 13.306397683918476, 7.977720368653536, 9.214169271290302, 8.225484173744917, 6.48044491186738, 5.261037144809961, 6.868021264672279, 4.013038286939263, 9.364650696516037, 12.00651403516531, 13.65035142749548, 32.855928763747215, 31.81826714426279, 37.72913306951523, 34.58371885120869, 25.873659029603004, 23.116052001714706, 30.664324164390564, 28.15690141171217, 12.036459278315306, 14.537837505340576, 14.31980425491929, 32.30742819607258, 26.718549393117428, 25.5141831189394, 34.96385045349598, 27.597907707095146, 18.880335688591003, 21.860791258513927, 29.571290016174316, 27.64399353414774, 21.36565502732992, 14.709071516990662, 13.700666427612305, 9.578748308122158, 9.741380531340837, 3.1313582975417376, 2.7210653387010098, 10.508732255548239, 13.602076917886734, 10.201595686376095, 7.504989635199308, 10.372963640838861, 15.745576098561287, 14.38678516075015, 29.595325626432896, 19.9563467502594, 15.650243014097214, 14.91023177281022, 29.205367751419544, 18.822808675467968, 12.498225700110197, 15.622207168489695, 9.546697027981281, 21.483978778123856, 28.460432924330235, 28.813027404248714, 9.53673966228962, 6.2889746110886335, 10.608002878725529, 11.763679515570402, 21.19537476450205, 8.377963341772556, 12.923528328537941, 6.542755868285894, 7.745522428303957, 21.569498889148235, 9.773292168974876, 38.64795796573162, 55.79255439341068, 62.99543268978596, 56.25032342970371, 59.343600645661354, 59.416062757372856, 62.0425084233284, 61.41648441553116, 63.48428785800934, 65.20000979304314, 49.64380033314228, 11.99043994769454, 7.78153452090919, 44.159953594207764, 57.94490709900856, 54.54133853316307, 30.256541445851326, 36.090034022927284, 25.891348980367184, 20.01825872808695, 11.39724712818861, 29.928402453660965, 36.51750348508358, 31.889899000525475, 48.70309621095657, 40.241094678640366, 45.893146991729736, 52.65658646821976, 89.21060979366302, 18.59038844704628, 0.580833270214498, 0.2824733988381922, 0.3722045448375866, 0.19842417998006567, 0.2543723926646635, 0.18298874027095735, 0.15940806653816253, 0.15115905058337376, 0.10224039389868267, 0.15225769631797448, 0.1622052359743975], [0.09477881889324635, 0.08223486074712127, 0.020985502051189542, 0.025164420585497282, 0.0968397110409569, 0.026894947550317738, 0.015016447250673082, 0.01831073132052552, 0.010926443574135192, 0.014187682591000339, 0.05234595031652134, 0.21390474226791412, 0.07207713002571836, 0.1186164389946498, 0.031906668955343775, 0.16754895157646388, 0.6182065210305154, 35.16088888049126, 62.44917020201683, 42.12705887854099, 43.37488152086735, 86.97705164551735, 48.44137005507946, 37.86470219492912, 28.142559081315994, 12.461255583912134, 46.52637921273708, 42.92898304760456, 16.260087490081787, 21.151887997984886, 42.92508065700531, 67.23783284425735, 63.99541363120079, 23.251668624579906, 2.736172853037715, 26.17420770227909, 66.2547267973423, 60.46774372458458, 61.20380602777004, 54.938994795084, 53.90554144978523, 55.03248117864132, 60.57267889380455, 47.105935513973236, 20.42227014899254, 14.17800821363926, 7.807670468464494, 5.1927814073860645, 3.5108204232528806, 2.665228759869933, 1.805555170867592, 7.51574020832777, 5.701592629775405, 2.3654371965676546, 3.0389493936672807, 6.138844192028046, 12.459938954561949, 2.020625649020076, 0.9291459736414254, 6.700774189084768, 9.881676603108644, 15.27310375124216, 7.881339015439153, 6.278243036940694, 3.6862969072535634, 3.249143664725125, 5.0104819145053625, 2.6386760221794248, 6.601938167586923, 5.302124815061688, 5.66833158954978, 2.9915471747517586, 3.6053819116204977, 1.8077128613367677, 3.620008989237249, 3.4611485386267304, 1.838400133419782, 0.851911852369085, 4.528447855263948, 15.717697944492102, 25.671981051564217, 25.486746691167355, 31.732346154749393, 29.161806888878345, 27.10802659392357, 23.634942658245564, 8.338633552193642, 5.1480174344033, 7.271168231964111, 12.663370538502932, 22.757590636610985, 27.87623707205057, 19.364870488643646, 15.333716198801994, 9.09648198634386, 23.101601377129555, 26.718914173543453, 27.346089519560337, 22.485741823911667, 9.833773523569107, 8.654015678912401, 11.951900515705347, 8.39861998334527, 4.108255002647638, 3.4861234109848738, 3.4211421478539705, 9.547257497906685, 7.9820264875888824, 2.9459567461162806, 1.2335920496843755, 5.540173491463065, 5.625991886481643, 14.581557959318161, 11.076588034629822, 7.941587157547474, 10.057748705148697, 14.770299531519413, 12.06180676817894, 12.260469608008862, 23.46405442804098, 16.311168149113655, 12.774799559265375, 10.799259915947914, 17.56717935204506, 26.886046305298805, 14.19378211721778, 4.385167518630624, 1.3987843855284154, 4.86628582701087, 4.38296458683908, 4.424689672887325, 1.8812966253608465, 1.4704555459320545, 2.4442235939204693, 7.907279273495078, 41.30586214363575, 49.89164963364601, 55.820296704769135, 54.381697699427605, 51.66643179953098, 52.678237706422806, 54.538279697299004, 54.486598670482635, 59.52545128762722, 54.77986693382263, 36.14308297634125, 10.316643062978983, 19.589590430259705, 57.37895026803017, 59.340215027332306, 53.819286078214645, 62.43339344859123, 17.293069660663605, 11.718800123780966, 5.36398739553988, 5.1521763112396, 16.004319414496422, 31.10906559973955, 35.7203708589077, 41.54672361910343, 32.40961231291294, 27.713677994906902, 58.5873082280159, 28.400415144860744, 0.40334859397262335, 0.0937050573702436, 0.057708011809154414, 0.0374714035569923, 0.1282940892269835, 0.1547122755437158, 0.05035027439589612, 0.039024607322062366, 0.03963720198953524, 0.031970575291779824, 0.12181678757769987, 0.07688846599194221, 0.019339136488270015, 0.060628900973824784, 0.04510843340540305, 0.017996897477132734, 0.12575034837936983, 0.0047368183095386485, 0.08919959014747292, 0.055457044509239495, 0.03246767693781294, 0.07905372636741959, 0.020730845208163373, 0.12071587829268537, 0.06805917961173691, 0.035428486226010136, 0.019715761591214687, 0.028946753955096938, 0.1979746314464137, 40.528070479631424, 79.01609122753143, 42.08887852728367, 45.35595841705799, 81.15232899785042, 39.15812999010086, 40.10994851589203, 30.48999521881342, 33.39538961648941, 51.08911357820034, 28.691331334412098, 25.195532217621803, 25.213757939636707, 43.851812928915024, 75.39892092347145, 74.2275121808052, 38.798034712672234, 4.4744508527219296, 25.443011038005352, 67.54356443881989, 69.62903693318367, 66.10751509666443, 58.1635245680809, 59.870400577783585, 60.106261521577835, 62.548637464642525, 52.06046685576439, 24.802899286150932, 15.170271769165993, 6.602092059329152, 7.455827398225665, 3.5202515171840787, 2.0835659466683865, 2.6075176941230893, 8.730192091315985, 12.342394161969423, 6.231076642870903, 5.548466546460986, 8.511149995028973, 21.356602013111115, 7.166359405964613, 4.743475466966629, 10.707530938088894, 17.094408720731735, 15.51133481785655, 7.671768385916948, 10.049290359020233, 8.409961424767971, 6.1293779499828815, 9.67140918597579, 5.37912673316896, 8.424257207661867, 5.166122037917376, 6.2192892003804445, 5.9854682721197605, 6.8931835144758224, 10.30492639169097, 2.689926247112453, 4.435956543311477, 4.254815513268113, 4.466823237016797, 14.148404952138662, 24.851481579244137, 34.831378161907196, 31.390001624822617, 23.384653888642788, 19.99027892947197, 26.922326758503914, 24.46106392890215, 9.617605023086071, 9.113238137215376, 12.01839029788971, 22.00974516570568, 30.090668946504593, 29.761528708040714, 22.228459529578686, 22.427777834236622, 13.478465750813484, 21.43936727195978, 30.355438739061356, 18.516868092119694, 15.86311424151063, 4.44372427649796, 9.563855957239866, 6.2984745763242245, 7.95481757260859, 6.377822393551469, 3.2985457638278604, 10.145918224006891, 11.90697267651558, 15.242711082100868, 7.639093464240432, 5.342667689546943, 11.243247091770172, 7.411572597920895, 18.204122073948383, 11.377333346754313, 8.412441741675138, 9.682894069701433, 14.692051280289888, 12.202110439538956, 22.61980812996626, 26.66832558810711, 12.193237915635109, 13.935466278344393, 17.055726796388626, 25.94129540026188, 42.67214722931385, 25.17694551497698, 9.891947451978922, 3.555246451869607, 8.793614488095045, 5.93858496285975, 3.052020217292011, 2.370167230255902, 5.006812261417508, 3.9575626887381077, 10.365590136498213, 42.512137815356255, 55.25967478752136, 57.00404338538647, 57.659322023391724, 55.086423084139824, 57.160701379179955, 58.26310582458973, 57.60682784020901, 65.87387323379517, 61.74089960753918, 39.776919186115265, 12.325385324656963, 28.341271318495274, 57.19662845134735, 58.62654872238636, 55.68968631327152, 65.53249955177307, 14.859707783907652, 10.622377507388592, 7.588395159691572, 12.80312703922391, 17.3403163254261, 34.90798965096474, 38.337951600551605, 43.31349201500416, 34.5903342962265, 30.16633428633213, 68.16743016242981, 31.697198040783405, 0.6531945685856044, 0.07480616288376041, 0.09922306635417044, 0.06403418621630408, 0.06305861083092168, 0.05763164852396585, 0.09531266798148863, 0.03268625427153893, 0.02269707270897925, 0.02984585844387766, 0.028925760452693794, 0.08876087696989998, 0.1988124122726731, 0.17988479667110369, 0.17396588693372905, 0.1105953217484057, 0.22092985280323774, 0.14100966160185635, 0.15527718351222575, 0.22326344711473212, 0.1592378772329539, 0.15335528820287436, 0.13429552578600124, 0.3331943537341431, 0.23303466732613742, 0.14588313759304583, 0.21413400652818382, 0.2530560008017346, 0.9574545139912516, 58.54011096060276, 85.27948513627052, 58.77230890095234, 57.018421813845634, 110.67501202225685, 62.369682267308235, 59.09768544137478, 38.99843975901604, 23.999781981110573, 60.69821275770664, 50.46647518873215, 26.054185442626476, 24.375669211149216, 53.99991698563099, 86.62541091442108, 75.30169934034348, 35.69219537079334, 5.635330360382795, 33.43838430941105, 74.10319045186043, 72.91795805096626, 71.4951927959919, 65.88832765817642, 64.84269976615906, 65.87022542953491, 65.10146588087082, 57.798060178756714, 26.943776607513428, 22.389536686241627, 18.558751344680786, 13.761469814926386, 9.298692885786295, 8.494850769639015, 5.341983726248145, 18.455622978508472, 15.493071097880602, 8.153532184660435, 7.1523334085941315, 14.06085954979062, 22.79613956809044, 7.0235122460871935, 6.073474874719977, 15.085427071899176, 17.014297619462013, 25.589941553771496, 15.801871977746487, 13.496692422777414, 12.654710803180933, 8.780801575630903, 17.332669235765934, 13.425839524716139, 8.411848973482847, 8.57247680425644, 8.719653356820345, 11.252408400177956, 11.70511705800891, 16.76570925861597, 13.612357266247272, 13.053452856838703, 7.924934551119804, 2.874791077338159, 13.388135097920895, 25.15215564519167, 37.6004833728075, 36.86570160090923, 41.968607380986214, 40.08537523448467, 38.823170363903046, 41.34810067713261, 24.368780180811882, 23.671308606863022, 24.482276290655136, 29.532169215381145, 36.09002262353897, 41.81331351399422, 27.033512592315674, 21.971228532493114, 17.69092921167612, 34.113908261060715, 37.63451434671879, 30.15119969844818, 31.936530098319054, 23.92487470060587, 22.446235343813896, 14.143817648291588, 12.988235056400299, 8.678808398544788, 5.427299598231912, 11.370717901736498, 14.024125970900059, 18.742222599685192, 7.736908290535212, 4.424702497199178, 12.464969884604216, 10.571445040404797, 24.097195453941822, 19.805025570094585, 16.549481861293316, 17.437674701213837, 20.58561958372593, 14.102590810507536, 19.15422309190035, 29.741049706935883, 22.64623001217842, 16.970419473946095, 15.058100838214159, 22.625942900776863, 35.811204984784126, 17.99199465662241, 8.262803871184587, 2.6836330723017454, 8.69752049446106, 7.762270979583263, 8.162835985422134, 3.7543120700865984, 4.496246483176947, 4.356032581999898, 11.418725475668907, 49.13825646042824, 61.70115374028683, 66.48878663778305, 62.47904799878597, 59.969050884246826, 61.639505848288536, 62.83093571662903, 62.68185831606388, 70.0495907664299, 65.9749174118042, 44.58439461886883, 15.476930513978004, 25.68379271775484, 65.64426675438881, 71.44480749964714, 59.8687856644392, 74.486643075943, 23.66024550050497, 18.897153586149216, 13.044403642416, 9.518040865659714, 28.57628110796213, 49.96468551456928, 46.39397531747818, 63.55203442275524, 47.254192158579826, 41.02092303335667, 75.02670809626579, 54.04711805284023, 1.352323922328651, 0.2721824822947383, 0.23901585809653625, 0.12654799385927618, 0.312078352435492, 0.3049268096219748, 0.23032551660435274, 0.13086540828226134, 0.1725642816745676, 0.118935050413711, 0.1420937167131342, 0.18526453612139449], [0.011052104018745013, 0.08745935774641111, 0.020068901430931874, 0.0753419563989155, 0.12375162594253197, 0.2016819262644276, 0.02525465275539318, 0.05675373977283016, 0.031651711542508565, 0.02809064208122436, 0.06841115799034014, 0.050498407072154805, 0.07085506513249129, 0.1614324821275659, 0.24438792373985052, 0.37521902995649725, 0.18047134566586465, 11.575605757534504, 69.57252636551857, 57.39834062755108, 37.61991932988167, 55.96005320549011, 67.51728504896164, 39.049452021718025, 45.52408039569855, 11.126400511711836, 33.191165775060654, 42.57206819951534, 26.897023916244507, 39.70059648156166, 68.5290339589119, 51.73918269574642, 37.77745507657528, 20.41625887155533, 11.472132559865713, 18.08309856802225, 60.800123289227486, 59.39494349062443, 62.33469754457474, 47.96151280403137, 36.63830280303955, 46.642531380057335, 61.89854174852371, 49.138742834329605, 34.595825001597404, 13.01914544776082, 12.795756384730339, 0.2555418392876163, 0.9890347381588072, 2.61125051882118, 4.9700558837503195, 8.602763079106808, 8.496206346899271, 9.645558223128319, 4.66318910010159, 4.5647140592336655, 3.9724474400281906, 3.5779792070388794, 1.6783464280888438, 5.730545176193118, 4.712976878508925, 13.082334157079458, 12.482397649437189, 2.454238194040954, 5.090111866593361, 6.291273012757301, 5.636265110224485, 2.5268546724691987, 7.551578460261226, 2.3362274514511228, 1.5762080275453627, 5.474674506112933, 5.765682840719819, 2.2463691607117653, 5.67979272454977, 2.8549395175650716, 0.6232560344506055, 0.2996613015420735, 4.2803947906941175, 17.126032523810863, 29.172060638666153, 35.66861383616924, 36.75054877996445, 42.54461087286472, 40.79934172332287, 31.573750264942646, 22.20107439905405, 27.278618440032005, 14.8764069378376, 6.097133830189705, 15.962766744196415, 16.412311121821404, 11.205436270684004, 5.816584434360266, 18.279249742627144, 35.28607316315174, 37.765789702534676, 34.33130979537964, 28.110333010554314, 18.70000496506691, 19.808986857533455, 5.893620075657964, 4.091214342042804, 2.607267857529223, 5.870485967025161, 2.6473262580111623, 11.224267110228539, 14.115983191877604, 10.7512266933918, 2.370529160834849, 1.4465159992687404, 4.7665967512875795, 11.371739096939564, 11.19991421699524, 9.66525636613369, 10.499908179044724, 5.700791822746396, 15.645963493734598, 15.624294206500053, 9.201764836907387, 15.099905245006084, 15.469622556120157, 16.660631597042084, 11.337605528533459, 9.367980267852545, 17.457524836063385, 20.71640856564045, 4.871584167703986, 4.0877304039895535, 3.242947622202337, 2.357903625816107, 3.0315153300762177, 6.472964538261294, 10.768412221223116, 9.682148359715939, 35.357646122574806, 63.512094765901566, 48.45388278365135, 54.916591197252274, 47.54345163702965, 56.00067302584648, 52.03982636332512, 62.24135935306549, 53.182896226644516, 60.134911984205246, 28.51340778172016, 12.133950646966696, 29.697547741234303, 77.5047679245472, 41.57587565481663, 60.019094198942184, 14.91772212088108, 17.418111450970173, 12.722788900136948, 1.965323535259813, 8.786800503730774, 35.9568777680397, 23.496806770563126, 36.00320488214493, 55.03626957535744, 24.745292477309704, 44.815331026911736, 48.9162153750658, 6.007212130352855, 0.5475490749813616, 0.10665226145647466, 0.23213245323859155, 0.19963092694524676, 0.1375193113926798, 0.0673142859886866, 0.08260832430096343, 0.06802892967243679, 0.09808668241021223, 0.05740681488532573, 0.15019618818769231, 0.07549027461209334, 0.037203451138339005, 0.043832659284817055, 0.05832743423525244, 0.12409714021487162, 0.10550217004492879, 0.0888906118052546, 0.03754986712010577, 0.09374926710734144, 0.057463051125523634, 0.1131833613908384, 0.06327739596599713, 0.0749737027217634, 0.023873100326454733, 0.18544728256529197, 0.14781848061829805, 0.37284270278178155, 0.10610248587909155, 14.659978151321411, 81.86213850975037, 64.08150181174278, 39.32292714715004, 60.252614468336105, 49.86965261399746, 39.498637318611145, 34.46543499827385, 25.68345833569765, 46.023985370993614, 37.10420720279217, 25.26461061090231, 40.01023806631565, 69.52008157968521, 61.06072090566158, 45.95453269779682, 25.499713495373726, 12.762942295521498, 22.31357306241989, 67.87362232804298, 69.09866139292717, 66.4264851808548, 57.99713909626007, 47.863398268818855, 54.24359790980816, 65.58023259043694, 52.522237077355385, 38.06222699582577, 19.61793500930071, 11.187839414924383, 3.3683627424761653, 1.8141187238506973, 3.027723371051252, 4.808332761749625, 3.690489982254803, 4.1192820109426975, 1.552706288639456, 9.366879276931286, 13.090795353055, 9.960346631705761, 3.1634361762553453, 3.465163023211062, 8.951203431934118, 13.511094599962234, 16.384219229221344, 13.150868229568005, 4.836795134469867, 8.025938831269741, 9.476184211671352, 7.245774669572711, 4.954850049689412, 13.144050445407629, 6.667696014046669, 4.688113862648606, 8.24218237772584, 7.067241249606013, 9.428518619388342, 6.591932354494929, 5.574404429644346, 2.695680088363588, 0.3241791593609378, 8.159972839057446, 23.116948753595352, 34.74931016564369, 43.03627409040928, 40.08109286427498, 40.53692780435085, 39.207922518253326, 33.030278608202934, 25.02439320087433, 31.070695258677006, 23.111815229058266, 12.032495141029358, 24.75497055798769, 25.900626182556152, 20.84286767989397, 12.790150735527277, 15.616494175046682, 37.91130669414997, 41.26715362071991, 33.06816637516022, 25.06410676985979, 15.361912585794926, 13.690654914826155, 10.163739267736673, 6.873060744255781, 4.862107001245022, 7.55017776042223, 6.597215496003628, 14.057178497314453, 14.431847892701626, 15.845220051705837, 3.53160388302058, 9.00501899421215, 7.338929520919919, 15.864333026111126, 13.401795364916325, 8.544867485761642, 9.633689559996128, 7.077504973858595, 14.8878756724298, 16.960971280932426, 14.147114921361208, 20.019822344183922, 15.839104279875755, 18.42258185148239, 15.793193243443966, 18.155045807361603, 29.309772849082947, 31.775559335947037, 11.7433762550354, 6.250810883939266, 1.3439414533786476, 1.221974529325962, 3.957096738740802, 9.855566304177046, 10.838091932237148, 8.656105566769838, 39.56953011453152, 66.69104978442192, 51.969153955578804, 56.86683654785156, 53.5950943082571, 58.37039306759834, 58.203984797000885, 64.10519734025002, 59.91151437163353, 65.04465892910957, 33.58613558113575, 15.766809359192848, 39.95307393372059, 72.27125555276871, 53.10624673962593, 73.2675164937973, 20.93948509544134, 17.149572260677814, 13.07320799678564, 8.130574766546488, 11.73488276079297, 29.271638095378876, 29.91123877465725, 34.226921796798706, 58.76176066696644, 25.431752242147923, 54.515359327197075, 58.39111715555191, 9.751219153404236, 0.6251007167156786, 0.15036982105812058, 0.24191024887841195, 0.1478167885215953, 0.018930485857708845, 0.10970282237394713, 0.07796512931236066, 0.0886238097155001, 0.11272193849436007, 0.02624800443300046, 0.0729696145572234, 0.06335372585454024, 0.1141005742829293, 0.2232711506076157, 0.26677424437366426, 0.15716640948085114, 0.3749721619533375, 0.28617389558348805, 0.11410717939725146, 0.2299456557375379, 0.2094413770828396, 0.20288500702008605, 0.12057307423674501, 0.182092166505754, 0.09739917164552025, 0.4013490106444806, 0.3358522814232856, 0.8826127799693495, 0.21260395034914836, 22.603149823844433, 97.00356602668762, 74.48551073670387, 50.75370937585831, 67.54771381616592, 80.68829029798508, 63.444906771183014, 61.892386078834534, 18.225666917860508, 47.315650060772896, 51.110658422112465, 37.61227793991566, 45.93776039779186, 81.88474729657173, 64.81678515672684, 47.19980947673321, 27.90755119174719, 17.92966280132532, 25.388250276446342, 72.71348342299461, 73.74061390757561, 73.85922834277153, 58.691920414566994, 46.38994373381138, 56.140752509236336, 68.56974497437477, 59.26604300737381, 45.650340020656586, 20.073986537754536, 24.297575801610947, 6.761784665286541, 9.81314443051815, 9.920167587697506, 10.844147857278585, 20.78303039073944, 19.911227971315384, 16.697858199477196, 11.230864506214857, 12.85948846489191, 8.895087093114853, 10.452815406024456, 5.864022513851523, 10.893850140273571, 10.833520777523518, 23.381266370415688, 21.013697013258934, 6.888639433309436, 12.13401809334755, 14.217941220849752, 10.700182132422924, 12.121527213603258, 16.06582671403885, 9.24674492329359, 5.969729516655207, 16.33356984704733, 14.708368554711342, 12.252662926912308, 13.878457937389612, 7.0709265768527985, 5.6876906007528305, 0.35934021638240665, 12.850263509899378, 29.531798735260963, 39.2758172750473, 50.13295188546181, 43.790860399603844, 45.5625419318676, 52.839432656764984, 50.0859560072422, 44.319488033652306, 51.75495944917202, 35.75154438614845, 21.188451535999775, 31.276921592652798, 33.121211528778076, 22.059220410883427, 18.070857524871826, 31.136617921292782, 51.955151706933975, 44.65953938663006, 38.99841696023941, 34.547822177410126, 24.272347055375576, 22.669764049351215, 10.530859418213367, 6.9356186874210835, 5.56490208953619, 10.305054634809494, 6.523610120639205, 17.081346921622753, 29.687903858721256, 19.192243851721287, 3.5335420165210962, 6.904856013134122, 8.939411714673042, 19.88960523158312, 19.284637793898582, 18.66217229515314, 16.342375874519348, 12.392162941396236, 20.911207012832165, 22.057394608855247, 12.598054893314838, 22.676029913127422, 20.52081786096096, 20.715922191739082, 14.427696615457535, 14.034855645149946, 25.36224827170372, 28.332835771143436, 9.646132942289114, 7.3185141663998365, 5.540394829586148, 7.831793949007988, 7.506143348291516, 15.915362387895584, 19.963269978761673, 17.214366383850574, 43.43891568481922, 72.72978454828262, 57.01713368296623, 63.34478594362736, 55.758504420518875, 64.63734358549118, 61.45291306078434, 68.65587115287781, 62.119416296482086, 72.2709971666336, 33.738598600029945, 15.2861712500453, 36.36118367314339, 85.93298926949501, 48.28432448208332, 69.64559644460678, 21.167208775877953, 24.314028918743134, 21.61280896514654, 9.006946440786123, 12.532350718975067, 56.96734495460987, 36.24836012721062, 47.71908201277256, 74.6993936598301, 37.74002328515053, 60.16911394894123, 73.52572023868561, 21.345472410321236, 1.0524633689783514, 0.37166975322179496, 0.3142986504826695, 0.43308737163897604, 0.2601800544653088, 0.31221277022268623, 0.10212289707851596, 0.2578058943618089, 0.2459232194814831, 0.10637368148309179, 0.43276904965750873, 0.2469160794862546], [0.045500580527004786, 0.015263326386047993, 0.07899483694927767, 0.03709160577272996, 0.14963623776566237, 0.0761674546811264, 0.07081744566676207, 0.06678122357698157, 0.07223561566206627, 0.13021070044487715, 0.10346916780690663, 0.03650235536042601, 0.03176906735461671, 0.11959119059611112, 0.0430891275027534, 0.2308814594289288, 0.05224109969276469, 1.9540204480290413, 54.161666706204414, 70.32294049859047, 36.386942490935326, 56.60842381417751, 75.4121670126915, 37.26103998720646, 53.20342652499676, 30.485234074294567, 14.399580974131823, 34.572767838835716, 24.62551910430193, 26.086960583925247, 44.47630561888218, 47.733620032668114, 73.61376911401749, 48.64856533706188, 21.09220650047064, 26.22341886162758, 67.85445615649223, 56.57309330999851, 59.846382066607475, 46.94408319890499, 14.116712752729654, 33.73340427875519, 56.25181294977665, 63.39445307850838, 63.55361893773079, 19.56979539245367, 5.7088592648506165, 5.837553609162569, 2.6956406654790044, 1.27913486212492, 3.1443393509835005, 4.496378526091576, 12.867906913161278, 11.578641794621944, 5.956536624580622, 1.3482577842660248, 8.926890436559916, 5.911177508533001, 3.950866973027587, 2.5258598383516073, 4.978241119533777, 15.194179136306047, 9.735452849417925, 5.179110690951347, 6.037709293887019, 5.597251653671265, 3.041663635522127, 6.22470248490572, 8.376536518335342, 3.443545983172953, 2.801829529926181, 4.564998093992472, 4.35797855257988, 2.0374112483114004, 5.589685784652829, 1.8259718315675855, 0.48338880529627204, 1.8480410473421216, 13.393478561192751, 24.691491164267063, 33.8424926251173, 39.190325662493706, 43.025079891085625, 55.37990793585777, 49.6160352230072, 39.15232390165329, 30.372152142226696, 43.331943824887276, 23.628665395081043, 9.3833770416677, 6.511388076469302, 6.60711538977921, 7.042223392054439, 8.188599552959204, 31.337820924818516, 48.191689252853394, 44.87724110484123, 36.39120206236839, 26.011916510760784, 24.279344379901886, 11.136822402477264, 1.129423133097589, 0.9963700664229691, 2.359543237835169, 3.567610988393426, 1.6541184531524777, 7.582674091681838, 9.939958825707436, 22.182580791413784, 7.061594752594829, 1.5675062569789588, 2.6522009214386344, 8.922871202230453, 11.486421693116426, 14.299624487757683, 12.883517425507307, 12.354441415518522, 9.791510291397572, 24.673398435115814, 20.840935483574867, 16.667005755007267, 19.644161202013493, 23.02929885685444, 23.04028406739235, 18.80416687577963, 9.36425456777215, 14.366207364946604, 20.25173719972372, 19.218618236482143, 3.9600924029946327, 2.745551224797964, 4.93181711062789, 8.35484728217125, 6.564081273972988, 15.854349061846733, 32.54624158143997, 52.31974594295025, 54.586670100688934, 53.152171075344086, 49.97467137873173, 47.69194766879082, 48.88238199055195, 57.599665224552155, 57.38586209714413, 51.87204636633396, 15.408863816410303, 24.488498456776142, 62.23180666565895, 71.13793596625328, 45.24138696491718, 31.33679687976837, 22.28580415248871, 21.462796814739704, 9.251926895231009, 5.474883494898677, 22.97053501009941, 33.01264375448227, 19.423993416130543, 78.54105591773987, 29.12031691521406, 37.29681886732578, 53.89639154076576, 35.269346460700035, 0.29358091531321406, 0.011604975279624341, 0.12388453716994263, 0.07930947045679204, 0.1081456258543767, 0.06987597938859835, 0.06458237359765917, 0.0961280582123436, 0.07912807472166605, 0.04932056304824073, 0.016557689450564794, 0.009793448462005472, 0.18925629614386708, 0.04052013136970345, 0.03056140754779335, 0.06736248848028481, 0.10845209573744796, 0.10208797903032973, 0.04348948648839723, 0.03152310477162246, 0.09160385918221436, 0.04456104012206197, 0.049549775358173065, 0.06771274507627822, 0.009786910140974214, 0.012211864686832996, 0.1602163098868914, 0.08622077264590189, 0.23433008609572425, 0.16437264857813716, 2.3457913007587194, 63.49911846220493, 84.3274538218975, 41.37354031205177, 70.0411856174469, 79.89809229969978, 46.08889728784561, 41.223835945129395, 32.81018301844597, 36.26355551183224, 41.157043129205704, 26.181733198463917, 33.409285470843315, 49.79753628373146, 55.94179518520832, 74.57583948969841, 47.17527039349079, 26.363399550318718, 35.40619231760502, 77.81671598553658, 59.22027066349983, 63.46466951072216, 54.77731727063656, 22.695473469793797, 40.72281762957573, 65.34851342439651, 63.93197223544121, 66.55191645026207, 25.85915520787239, 8.866891656070948, 3.6721913516521454, 2.6240629563108087, 1.3771620020270348, 1.9836137350648642, 2.2424632078036666, 5.142782740294933, 21.103868074715137, 17.93434415012598, 12.797920368611813, 16.459208205342293, 8.23189252987504, 9.11244397982955, 8.114572875201702, 9.588253498077393, 19.565209038555622, 11.460698023438454, 5.820052223280072, 8.682623393833637, 9.747867733240128, 4.654059140011668, 7.510541137307882, 9.619403276592493, 8.678338173776865, 6.9792526960372925, 8.613284714519978, 6.013188734650612, 10.263558961451054, 9.471646305173635, 3.6259839311242104, 1.080727914813906, 0.8197750768158585, 5.912326471880078, 23.11910893768072, 40.629354044795036, 45.1884064078331, 48.303692042827606, 51.41869269311428, 47.79598608613014, 41.39652147889137, 37.56089709699154, 48.1579964607954, 32.53692828118801, 14.2778155580163, 15.076496601104736, 16.733530685305595, 11.629320625215769, 12.351064346730709, 36.740015745162964, 49.444010853767395, 47.78656259179115, 40.178736224770546, 32.825196012854576, 25.242370404303074, 21.319901682436466, 5.46929731965065, 1.2793571501970291, 4.03118041343987, 7.824952891096473, 7.559044109657407, 12.363544777035713, 14.204792976379395, 24.24791246652603, 7.598900645971298, 7.040916737169027, 8.407310117036104, 12.29554457589984, 13.423304110765457, 16.21739488095045, 7.112664487212896, 9.57131590694189, 14.750871174037457, 22.764006592333317, 20.36111243069172, 17.341938838362694, 19.060630314052105, 21.37514691799879, 20.926447995007038, 21.980300545692444, 16.97134282439947, 24.458538964390755, 28.62128969281912, 26.780835650861263, 11.447381637990475, 3.5061093885451555, 2.4768545804545283, 5.2398965042084455, 6.131009962409735, 16.192973591387272, 37.69696779549122, 58.216573521494865, 57.58494481444359, 56.297190114855766, 58.05448181927204, 53.68623621761799, 56.61688596010208, 62.16258578002453, 62.16155603528023, 54.18503165245056, 20.086332075297832, 31.44728545099497, 62.05959990620613, 67.34756335616112, 55.913201719522476, 39.06396344304085, 27.184254303574562, 18.717398531734943, 11.059721689671278, 9.601535685360432, 18.381293267011642, 37.72789813578129, 21.692277900874615, 70.41345924139023, 39.0497750043869, 38.97673152387142, 64.4284687936306, 42.38910801708698, 1.090777781791985, 0.021727300918428227, 0.14347746589919552, 0.06755405906005763, 0.04635803939891048, 0.02222027993411757, 0.025507201899017673, 0.13583708525402471, 0.12071126213413663, 0.011350831446179654, 0.01631130198802566, 0.04670582464314066, 0.047753236212884076, 0.15703953191405162, 0.0729643007798586, 0.18034604145213962, 0.2111060736933723, 0.3215234284289181, 0.1565988446236588, 0.2250339591410011, 0.26161394314840436, 0.14640433306340128, 0.15761025832034647, 0.15107888379134238, 0.159470243670512, 0.09553636613418348, 0.4915494017768651, 0.13630830449983478, 0.4229326540371403, 0.37076914217323065, 4.513811990618706, 80.86460083723068, 91.0358190536499, 52.4643661826849, 69.28723007440567, 84.7717335820198, 55.84242671728134, 79.91494819521904, 43.90007793903351, 28.706619814038277, 47.7909779548645, 34.10603888332844, 33.40896248817444, 51.26173831522465, 59.02367301285267, 86.197439879179, 59.055199921131134, 31.015305630862713, 34.3016903847456, 81.76056236028671, 66.71571806073189, 75.68004503846169, 58.349395394325256, 18.072827719151974, 38.68982791900635, 69.84251707792282, 69.38509002327919, 75.35936504602432, 29.756330586969852, 13.971935771405697, 15.143494606018066, 11.63301307708025, 4.565766602754593, 8.789342567324638, 11.158859319984913, 26.717202365398407, 29.02530301362276, 16.73981934785843, 7.008043276146054, 19.265082143247128, 12.959772683680058, 12.452185470610857, 8.46689946949482, 10.378718432039022, 24.528428614139557, 17.75077410042286, 10.690374858677387, 14.236580170691013, 16.743630543351173, 8.267031144350767, 10.149191748350859, 11.725675854831934, 12.840916011482477, 10.053522381931543, 16.351257897913456, 9.286819472908974, 15.699843652546406, 13.861467149108648, 5.874881856143475, 1.0272571840323508, 6.06761178933084, 24.721412658691406, 33.44724543392658, 41.40209197998047, 54.789560213685036, 51.23341463506222, 56.78093455731869, 56.44067041575909, 51.478311493992805, 51.94117985665798, 58.62259693443775, 43.472790867090225, 28.23292963206768, 23.35090409964323, 23.6080913990736, 21.688290014863014, 30.22150542587042, 51.38416774570942, 54.576646238565445, 46.520592123270035, 41.76046974956989, 30.85512712597847, 31.36442329734564, 25.58618925511837, 4.843450002372265, 0.7434669777285308, 5.203871112316847, 8.241785299032927, 14.921243581920862, 14.582393914461136, 22.898162193596363, 32.79292434453964, 8.22241298854351, 5.3933849930763245, 8.913101926445961, 16.54013816267252, 18.22470936924219, 24.44641761481762, 18.861659690737724, 19.437030516564846, 14.889658726751804, 33.827445432543755, 26.10105212777853, 22.659447602927685, 24.850888811051846, 29.352246969938278, 28.38746163994074, 24.72724724560976, 14.450641684234142, 20.7872823625803, 30.49320414662361, 32.9167976975441, 13.154733572155237, 10.942218694835901, 15.809048842638731, 17.390961907804012, 12.538469340652227, 21.356792002916336, 40.234988406300545, 63.90737995505333, 61.6845790296793, 63.8029083609581, 60.302916169166565, 56.62929229438305, 59.841005355119705, 64.9178597331047, 66.59735441207886, 56.4750699698925, 21.45504903048277, 28.571337573230267, 68.95527988672256, 75.6743985414505, 50.76170414686203, 38.42414237558842, 32.819355726242065, 26.439750753343105, 18.38362444192171, 9.895180128514767, 32.18118757009506, 53.42439226806164, 27.243588119745255, 101.89726263284683, 47.95409180223942, 53.26731629669666, 73.37672263383865, 66.07536122202873, 3.3907601656392217, 0.25045082496944815, 0.28232986747752875, 0.20356343389721587, 0.1761181597248651, 0.1347220380557701, 0.17285745969275013, 0.19377615361008793, 0.2164930713479407, 0.10693219213862903, 0.12137152123614214, 0.10598544919048436, 0.187144796946086], [0.08148967026500031, 0.06266202195547521, 0.02916212150012143, 0.1033560125506483, 0.09546837056404911, 0.09713007631944492, 0.06287485506618395, 0.014650322609668365, 0.09070681786397472, 0.054942550632404163, 0.007764064657749259, 0.07127167715225369, 0.0606840722321067, 0.08261544149718247, 0.05565992913034279, 0.12661207088967785, 0.3383949090493843, 0.7337797537911683, 27.700131721794605, 84.07494977116585, 48.55011261999607, 31.919981986284256, 46.71575725078583, 33.14731612801552, 40.2641936391592, 59.400969967246056, 9.059536568820477, 43.18199247121811, 24.94887415319681, 22.078111097216606, 38.80530372262001, 40.97632862627506, 53.21976184844971, 57.36608415842056, 12.255235388875008, 11.127907130867243, 50.18446572124958, 66.9343051314354, 51.418388709425926, 69.3372505903244, 32.43174232542515, 26.67744889855385, 55.73728635907173, 54.74530778825283, 56.28746263682842, 30.794318988919258, 10.732095669955015, 4.89953214302659, 1.3411737768910825, 1.4832102740183473, 2.5651613669469953, 0.855121195781976, 7.51527045853436, 4.320857394486666, 2.9802033584564924, 9.361843597143888, 11.264420505613089, 0.5465506191831082, 0.32911675691138953, 2.7657858515158296, 16.510490253567696, 12.329676244407892, 9.605002999305725, 8.559141419827938, 1.3369518471881747, 4.483085414394736, 3.375135879032314, 3.8662469387054443, 3.8195759430527687, 5.225657718256116, 6.604736717417836, 3.4343728004023433, 4.206100702285767, 4.680468197911978, 3.9216037932783365, 3.2477747881785035, 0.7353621313814074, 2.781220623292029, 15.950544700026512, 29.112747721374035, 41.02404646575451, 50.3733915835619, 52.11602367460728, 53.89794185757637, 48.775900304317474, 37.6288640499115, 36.19545176625252, 45.62875717878342, 32.43711903691292, 16.599903255701065, 8.362145740538836, 9.344575423747301, 8.838200345635414, 20.164790265262127, 41.37782648205757, 51.48837335407734, 38.6788123100996, 31.476849764585495, 27.399288564920425, 18.984660990536213, 5.912022963166237, 2.0000571152195334, 2.8394719725474715, 2.860443047247827, 1.8015118315815926, 8.512517921626568, 6.47891596890986, 3.7642642110586166, 23.264880515635014, 16.9195744022727, 5.080203423276544, 3.0829714564606547, 6.640835255384445, 11.263481006026268, 10.596763081848621, 18.2097951695323, 12.057354357093573, 11.319652441889048, 24.586200714111328, 21.6941075026989, 21.354407630860806, 20.23460391908884, 24.05809175223112, 23.213326781988144, 22.932797335088253, 20.87455987930298, 12.724929135292768, 16.587745808064938, 26.30332287400961, 9.914912469685078, 2.1680539380759, 1.7303075711242855, 11.475968454033136, 5.35893271677196, 9.564916100353003, 39.3048021197319, 49.62161712348461, 50.47705382108688, 55.50384968519211, 50.063655003905296, 46.96917325258255, 60.95178075134754, 57.63570249080658, 54.39414203166962, 49.187733605504036, 21.670379675924778, 49.88506458699703, 68.84094402194023, 60.22217810153961, 35.084619373083115, 35.388644859194756, 25.299371145665646, 10.629723463207483, 12.297710459679365, 10.371179636567831, 30.900099612772465, 13.928923029452562, 52.38632217049599, 58.86235646903515, 27.890338115394115, 43.707451075315475, 48.052533119916916, 8.46984051167965, 0.5065040930639952, 0.11908056330867112, 0.15348842949606478, 0.008475217928207712, 0.0030515558592014713, 0.018303150282008573, 0.12068796611856669, 0.051018945741816424, 0.054534143055207096, 0.019014439458260313, 0.05519941165402997, 0.09916341252392158, 0.07640360607183538, 0.05039418727392331, 0.06371033523464575, 0.008227984417317202, 0.078557481901953, 0.018272831694048364, 0.025277703862229828, 0.025026633447851054, 0.020059483576915227, 0.019022797896468546, 0.08839508722303435, 0.03985917464888189, 0.02042467032879358, 0.018526779786043335, 0.10463615792104974, 0.019549702337826602, 0.06688410008791834, 0.24954706721473485, 0.3026822581887245, 31.41512967646122, 95.67457213997841, 52.35309295356274, 32.63414606451988, 44.370200112462044, 37.8525048494339, 45.91157600283623, 42.273772805929184, 21.727032735943794, 54.299128130078316, 28.59629463404417, 27.526268251240253, 48.70987884700298, 51.76882490515709, 53.05050753057003, 56.87195487320423, 18.935280740261078, 13.543400466442108, 54.81771670281887, 70.05149826407433, 63.549146577715874, 76.40687003731728, 33.51908057928085, 33.196303099393845, 59.34417821466923, 59.23582702875137, 63.100998625159264, 33.503208830952644, 8.56942081823945, 6.488296240568161, 3.9482828741893172, 0.5948076141066849, 0.4341400635894388, 4.565920019522309, 18.439690433442593, 14.78304784744978, 10.018482562154531, 15.611404348164797, 11.136756855994463, 3.69247252587229, 3.31999727524817, 4.66979599557817, 21.66929103434086, 15.218013357371092, 13.172811102122068, 7.254941677674651, 3.6961903888732195, 8.196930605918169, 3.2443243358284235, 8.250023256987333, 6.054937094449997, 11.325715016573668, 11.243683118373156, 6.176564292982221, 5.004441663622856, 10.171485152095556, 7.97741923481226, 3.369154050014913, 1.4355760300531983, 2.6536588557064533, 18.457091599702835, 32.9781112074852, 43.2468967884779, 50.65206862986088, 51.14182434976101, 51.812940537929535, 53.48610855638981, 46.00397564470768, 43.256259486079216, 54.1233229637146, 39.19445984065533, 23.415846414864063, 14.903672374784946, 12.4580960534513, 14.84544524922967, 27.94440731406212, 48.8964906334877, 55.562355145812035, 44.673180654644966, 40.573124662041664, 29.79920368641615, 28.427786976099014, 17.583020702004433, 1.96925216820091, 0.7510087417904288, 3.829317195340991, 2.9083710629493, 7.7615627925843, 9.963991586118937, 8.140367791056633, 27.052063196897507, 11.941300984472036, 6.323130978271365, 9.206873662769794, 12.885118089616299, 13.226012997329235, 13.195141553878784, 7.17640939168632, 15.893530659377575, 15.053161103278399, 24.07120294868946, 20.94384156167507, 22.12444581091404, 20.41795738041401, 22.667867951095104, 22.669781148433685, 21.06902964413166, 22.626529969274998, 22.32397310435772, 30.117356814444065, 39.10978138446808, 24.26943641155958, 6.052119545638561, 1.7982942354865372, 3.1133591383695602, 1.8458647141233087, 11.359986327588558, 44.14639592170715, 57.037629783153534, 55.61641104519367, 60.913942381739616, 56.57724268734455, 53.457636684179306, 65.01996785402298, 62.559432685375214, 60.481024011969566, 52.65811398625374, 23.708227425813675, 53.13362047076225, 64.50673699378967, 67.40229561924934, 38.13243202865124, 37.72489629685879, 30.40871188044548, 9.3950604647398, 14.989215284585953, 14.485924690961838, 30.5984129011631, 21.43751297146082, 47.030327171087265, 64.46257576346397, 35.70189245045185, 47.56162606179714, 65.06573259830475, 13.559640794992447, 0.5361854878719896, 0.2000317015335895, 0.15481991664273664, 0.009594729144737357, 0.030141927127260715, 0.05669169251632411, 0.10468428619788028, 0.06062117521651089, 0.047194146682159044, 0.0235706083549303, 0.039712645011604764, 0.03713266138220206, 0.03890941858117003, 0.1953485864214599, 0.11321999380015768, 0.15601806953782216, 0.31542698212433606, 0.26413534535095096, 0.18140373547794297, 0.11978120266576298, 0.11844002307043411, 0.1235833513783291, 0.2356885132030584, 0.21333935932489112, 0.11037373871658929, 0.15728408441646025, 0.22010333777870983, 0.1473034152877517, 0.24566676293034106, 0.5200318421702832, 0.9181451483163983, 46.8036275357008, 105.99142894148827, 63.50008741021156, 44.026386961340904, 52.26457290351391, 39.08101312816143, 61.63597583770752, 77.08505764603615, 17.213729918003082, 54.27537180483341, 37.17598535120487, 28.74776780605316, 46.641520634293556, 53.25943551957607, 59.757079258561134, 68.06868106126785, 19.205199256539345, 13.502621054649353, 66.152253895998, 76.55501648783684, 69.74321320652962, 89.56360325217247, 33.298434019088745, 34.88598123192787, 65.57153865695, 64.34732034802437, 68.04079815745354, 39.03458721935749, 16.701418608427048, 14.211936593055725, 6.598752988502383, 2.168564535677433, 2.8712826780974865, 5.940490085631609, 14.437148608267307, 10.550416968762875, 6.147175244987011, 15.408790670335293, 18.34058605134487, 6.8606102373450994, 5.579284317791462, 6.8810042180120945, 26.879126876592636, 20.233714766800404, 18.8950389996171, 16.338857263326645, 7.331308554857969, 12.494206465780735, 7.10264727473259, 13.671320602297783, 6.818528920412064, 13.610381372272968, 10.68972984328866, 14.862855914980173, 9.838769305497408, 17.338627316057682, 10.919315423816442, 6.2393383495509624, 1.1595654906705022, 5.285036182031035, 31.831081956624985, 39.55589644610882, 48.24733346700668, 58.5242810100317, 51.943995505571365, 51.43160060048103, 59.64292958378792, 53.33495646715164, 50.368938222527504, 59.00781266391277, 49.58475150167942, 35.70025473833084, 28.410277515649796, 25.68308785557747, 28.347430787980556, 40.48452101647854, 59.29271377623081, 56.180711165070534, 39.73452106118202, 35.79279117286205, 31.954522132873535, 34.54209968447685, 24.73524771630764, 2.873828304000199, 2.4989242712035775, 5.924794552847743, 5.4333882965147495, 23.545489758253098, 12.832655254751444, 12.10519663989544, 37.30561159551144, 22.20256581902504, 8.050536811351776, 7.948822444304824, 13.584641553461552, 15.200143866240978, 18.89601554721594, 27.849306017160416, 20.046460814774036, 16.154339164495468, 33.42347390949726, 26.953739672899246, 27.568020410835743, 26.7434798553586, 30.879419222474098, 29.176686890423298, 28.140491992235184, 26.033506952226162, 20.232705920934677, 22.10673686116934, 31.984696313738823, 17.948164008557796, 3.2755997451022267, 3.6698202788829803, 26.631638556718826, 11.641617715358734, 14.292203485965729, 48.95184986293316, 59.42067191004753, 59.27866593003273, 64.2646823823452, 60.899062380194664, 55.82180142402649, 69.96419414877892, 68.51710259914398, 65.1945760846138, 57.27853685617447, 26.223920434713364, 54.14627753198147, 77.24612340331078, 71.51759639382362, 40.52041009068489, 44.960380643606186, 36.13795705139637, 16.320542246103287, 22.66489651054144, 14.919040650129318, 48.90201933681965, 24.702064096927643, 68.95346358418465, 77.80071124434471, 43.94110053777695, 57.004795745015144, 78.54154989123344, 26.967713423073292, 0.8591910148970783, 0.30003635329194367, 0.358681931393221, 0.14279992959927768, 0.118901364330668, 0.13176708802348003, 0.20243915438186377, 0.1003031806612853, 0.23704027582425624, 0.1303570222808048, 0.17347847402561456, 0.19463159755105153, 0.270083510549739], [0.05655363078403752, 0.026444244977028575, 0.06580272412975319, 0.04064883090904914, 0.017942390441021416, 0.06748294646968134, 0.04544328672636766, 0.031006421559141017, 0.15335445699747652, 0.03556415453203954, 0.06967968874960206, 0.037797299155499786, 0.023563461472804192, 0.03396644788153935, 0.08022566660656594, 0.20808946603210643, 0.1338977791601792, 0.5381608474999666, 7.202976616099477, 87.57577791810036, 57.732323706150055, 51.605034694075584, 52.72398345172405, 38.67911249399185, 24.266447871923447, 53.488377034664154, 30.948556512594223, 38.56097683310509, 44.23975691199303, 28.577972017228603, 24.689811654388905, 24.377004839479923, 56.91979430615902, 67.13767781853676, 24.532929472625256, 13.940354716032743, 28.043103218078613, 55.40950834751129, 52.17061534523964, 50.61814785003662, 36.8110491335392, 30.771624706685543, 65.69351971149445, 48.546806797385216, 57.94521488249302, 28.3304475992918, 7.72850314155221, 3.009450389072299, 2.110896217636764, 0.6181116448715329, 1.421320263762027, 5.176429459825158, 5.114082880318165, 5.318183703348041, 13.086209949105978, 26.154743246734142, 13.927060179412365, 5.839563701301813, 2.950438605621457, 8.748266771435738, 19.79467872530222, 13.2472063601017, 6.5490136574953794, 13.581824004650116, 7.225292343646288, 0.411998443887569, 3.0352298682555556, 4.5623439364135265, 3.403705833479762, 2.8108884813264012, 11.828911565244198, 6.012429725378752, 7.944112122058868, 6.565479123964906, 4.608212225139141, 3.6425056820735335, 0.7908785180188715, 2.1561966743320227, 12.748940046876669, 28.857986591756344, 44.96911257505417, 51.54212526977062, 54.360327646136284, 52.323180958628654, 49.3074955791235, 38.84067602455616, 35.81168755888939, 48.36884334683418, 37.50545807182789, 23.00581991672516, 12.023431677371264, 12.316304761916399, 9.485686551779509, 21.82884257286787, 35.98561942577362, 40.677888840436935, 34.41023916006088, 27.47266262769699, 17.622587978839874, 14.103613905608654, 1.1779309739358723, 1.15337930386886, 1.7531145410612226, 2.5002439878880978, 3.6766542121767998, 8.30364502966404, 11.927380431443453, 3.765944908373058, 15.161581635475159, 22.44371797889471, 8.71780950576067, 4.814805714413524, 2.91838803794235, 7.232074029743671, 19.11872159689665, 30.236189737915993, 9.254109878093004, 19.785629510879517, 21.907027177512646, 26.666385792195797, 20.36001428961754, 21.265036426484585, 23.0816600471735, 26.369509622454643, 26.82013314217329, 20.853564105927944, 18.007083646953106, 14.314022865146399, 24.125918112695217, 21.455166824162006, 12.873740550130606, 3.9000002900138497, 2.5577071169391274, 6.3747607078403234, 7.16382684186101, 40.11624097824097, 55.4433873295784, 56.4921348541975, 51.90262332558632, 44.153395146131516, 54.17498119175434, 62.185855731368065, 52.234368324279785, 61.347229331731796, 42.1835732460022, 32.0688010007143, 62.21666067838669, 71.99661388993263, 46.71481490135193, 45.618121549487114, 50.9406403452158, 14.547978211194277, 21.030494011938572, 5.965023944154382, 11.511345505714417, 20.480699613690376, 27.97643579542637, 64.55269932746887, 33.86571317911148, 31.82865008711815, 47.880565747618675, 34.70680184662342, 0.4963593202410266, 0.4686437558848411, 0.03365303149621468, 0.055969059612834826, 0.004308420520828804, 0.08575122323236428, 0.065218661329709, 0.10963872307911515, 0.10289188081515022, 0.04163413213973399, 0.09749108663527295, 0.023326736773015, 0.07870108005590737, 0.053291672811610624, 0.10092157521285117, 0.021676393298548646, 0.1949130793218501, 0.07131664387998171, 0.058217986006638967, 0.06509466329589486, 0.04871345285209827, 0.06552774357260205, 0.07965288445120677, 0.04184282406640705, 0.009036789942911128, 0.05879282020032406, 0.026363167198724113, 0.2068079699529335, 0.12643769587157294, 0.16871768573764712, 0.1218864975089673, 0.12127602167311125, 8.386106304824352, 98.55857938528061, 64.0452441573143, 41.343229338526726, 49.198365435004234, 33.70088942348957, 34.89919692277908, 38.61331522464752, 20.756285525858402, 55.52269667387009, 36.3825461268425, 32.02775180339813, 36.70852683484554, 25.346481017768383, 57.9421142488718, 73.7737101316452, 34.749321565032005, 16.833396926522255, 30.261154398322105, 62.21391722559929, 56.14905506372452, 62.029874101281166, 31.988325119018555, 33.35537016391754, 74.11960557103157, 57.32991389930248, 64.76501673460007, 37.674841582775116, 12.643634397536516, 3.303014086559415, 3.0043330136686563, 0.6502849934622645, 5.14010863378644, 17.903761491179466, 16.231839805841446, 12.955855093896389, 19.467214196920395, 25.648302622139454, 14.725359342992306, 7.600839491933584, 4.839393720030785, 11.989472899585962, 21.058365516364574, 11.7094830237329, 10.141528509557247, 12.940710056573153, 11.344254221767187, 4.196833949536085, 3.3969975309446454, 8.509489484131336, 9.615412540733814, 9.274088256061077, 12.463337872177362, 11.804774310439825, 8.176313862204552, 11.033540144562721, 7.100934041664004, 3.6284010764211416, 2.7824914176017046, 2.82525313552469, 24.975672215223312, 44.88900527358055, 45.45052394270897, 51.1724317073822, 58.94229657948017, 51.22819371521473, 52.67087750136852, 48.065927401185036, 47.82044157385826, 55.116411074995995, 49.22146059572697, 29.61491357535124, 22.690144255757332, 20.65512925386429, 22.334300950169563, 34.341930225491524, 52.482080832123756, 51.456975638866425, 39.524483531713486, 33.543342277407646, 33.49740274250507, 25.25863543152809, 10.412206035107374, 1.6300570755265653, 2.228992930613458, 3.9792191516608, 2.6277850940823555, 7.648108480498195, 12.685418855398893, 6.086177593097091, 29.867717809975147, 22.795594297349453, 9.327049814164639, 5.152614712715149, 8.026574347168207, 12.325946744531393, 20.961567610502243, 33.39253216981888, 14.18028999119997, 19.107419103384018, 23.650618717074394, 22.150029838085175, 19.885792136192322, 22.028358466923237, 21.463467478752136, 24.002894014120102, 25.938365757465363, 20.428912192583084, 21.098668053746223, 21.384541913866997, 35.63045248389244, 33.56986105442047, 32.179508060216904, 11.021938417106867, 1.8678278918378055, 0.9601106308400631, 7.484286921098828, 44.06346537172794, 57.961546406149864, 57.97960303723812, 58.96292567253113, 48.719545528292656, 57.135960906744, 67.51078739762306, 56.596420258283615, 66.83494806289673, 45.95092289149761, 32.136213183403015, 61.13601766526699, 74.78727534413338, 55.88136322796345, 42.79033228754997, 51.868455559015274, 20.18021933734417, 14.597989227622747, 12.14574996381998, 19.39354185014963, 23.250872567296028, 34.077874794602394, 59.128148406744, 48.08931514620781, 31.397785507142544, 58.88668276369572, 45.37705108523369, 1.3506647176109254, 0.29971221287269145, 0.005989000483168638, 0.027740500518120825, 0.03660621150629595, 0.11090175452409312, 0.0352532540273387, 0.10665013149264269, 0.05023710058594588, 0.0038588951792917214, 0.05235337921476457, 0.05637700334773399, 0.1307478075614199, 0.030092882298049517, 0.21733497851528227, 0.17644978099269792, 0.2550088881980628, 0.18125309434253722, 0.2209312777267769, 0.23540740250609815, 0.09597677140845917, 0.14123034663498402, 0.25713754585012794, 0.10838835267350078, 0.2645195403601974, 0.11321586745907553, 0.19817530817817897, 0.33239090465940535, 0.28411075472831726, 0.29224317928310484, 0.35866806807462126, 0.6867680232971907, 13.718148339539766, 112.1945808827877, 77.71674335002899, 63.29518720507622, 66.21070995926857, 46.87622644007206, 39.72331926226616, 80.63203051686287, 36.73982195556164, 62.73742273449898, 53.06746982038021, 36.30800552666187, 34.57710340619087, 26.55642919242382, 68.29720079898834, 81.89028739929199, 35.98373092710972, 19.19385876506567, 39.069818928837776, 64.82011377811432, 60.49354054033756, 74.51403200626373, 37.464564666152, 41.02606415748596, 82.26037234067917, 62.70938403904438, 75.42779937386513, 41.093647330999374, 14.482748061418533, 9.10098284482956, 7.869387231767178, 0.5033903382718563, 4.149363096803427, 11.136560216546059, 10.851003639400005, 10.986103489995003, 21.654031053185463, 38.88381130993366, 27.674764283001423, 12.839367594569921, 7.814857307821512, 15.381621178239584, 30.619682259857655, 18.285597302019596, 12.134441770613194, 21.534949243068695, 20.706998370587826, 8.707332517951727, 7.142292447388172, 11.759872119873762, 10.99303051829338, 9.997959863394499, 20.00664085149765, 19.49814833700657, 12.99589354544878, 19.056469537317753, 13.879557978361845, 7.24080691114068, 2.268799119628966, 4.53637233003974, 29.36279710382223, 46.07081025838852, 48.366829454898834, 57.569962218403816, 58.576414212584496, 57.167913392186165, 56.69170394539833, 55.148002579808235, 52.633491307497025, 57.28034555912018, 54.69864249229431, 40.25112234055996, 36.01168602705002, 31.292124576866627, 35.479969158768654, 44.46952298283577, 55.55422358214855, 51.788116469979286, 34.9907112121582, 32.32915163040161, 32.949285954236984, 31.955540478229523, 16.460437439382076, 2.0493967551738024, 3.854432897642255, 6.23994916677475, 5.923369154334068, 23.135594353079796, 20.03657754510641, 7.9654323030263186, 31.758047975599766, 29.09313127398491, 14.163275454193354, 9.87306721508503, 11.036944761872292, 16.82111408561468, 32.40011662244797, 41.60812832415104, 13.259295411407948, 26.730112172663212, 29.843055233359337, 34.55104820430279, 25.898804180324078, 26.743656545877457, 29.019666016101837, 32.70819649100304, 33.91728401184082, 27.438861541450024, 25.987827703356743, 21.07886351644993, 31.01386170834303, 27.256279438734055, 26.443575248122215, 9.717014338821173, 7.745770364999771, 12.52899169921875, 10.573267992585897, 50.03489814698696, 61.682766526937485, 65.20433396100998, 63.37963007390499, 54.15443189442158, 59.85868580639362, 72.91688650846481, 60.80351270735264, 71.3490754365921, 49.66929316520691, 36.88023962080479, 68.91661316156387, 81.65588557720184, 58.43341648578644, 52.96248145401478, 62.768763452768326, 20.63749060034752, 29.247714579105377, 13.14626857638359, 20.789180360734463, 34.655295610427856, 41.204696372151375, 80.86745828390121, 53.52833189070225, 42.782497107982635, 67.66041576862335, 66.01280897855759, 3.1241762079298496, 0.7068927527870983, 0.2719080657698214, 0.14668262359919026, 0.1526476800790988, 0.242751473269891, 0.18250471155624837, 0.26237339770887047, 0.2154396817786619, 0.10685811837902293, 0.19128185464069247, 0.18153855402488261, 0.25249072175938636, 0.21139416057849303], [0.11470315366750583, 0.04071988783834968, 0.042231527622789145, 0.061631171411136165, 0.017404511490894947, 0.03871627835906111, 0.107747805013787, 0.024514518154319376, 0.05790977578726597, 0.1677232820657082, 0.042673999778344296, 0.05813591189507861, 0.0954068019927945, 0.04555881314445287, 0.07562708953628317, 0.049823542503872886, 0.024582959013059735, 0.12302962757530622, 0.36911296541802585, 68.28418269753456, 72.51335576176643, 51.55122198164463, 111.0004797577858, 56.92666433751583, 41.99057400226593, 56.409094110131264, 54.52108941972256, 34.55642491579056, 55.852598771452904, 29.843999482691288, 25.45293990522623, 50.67658491432667, 75.01961767673492, 62.19726651906967, 49.306446835398674, 28.02360076457262, 21.090095713734627, 37.22435675561428, 44.53272879123688, 55.063578709959984, 32.01506048440933, 32.4805773049593, 60.42515940964222, 49.3611790984869, 52.931076139211655, 21.183545999228954, 1.4711287035606802, 3.5377132426947355, 3.6494296230375767, 0.49471237580291927, 3.7964826822280884, 6.402181936427951, 11.5226498991251, 15.984051302075386, 21.808074787259102, 21.349526792764664, 9.332283083349466, 3.9482479635626078, 3.6150274565443397, 9.355269949883223, 23.816781900823116, 15.61098637059331, 10.00587198883295, 5.374682396650314, 4.592433571815491, 4.84567953273654, 1.0119189508259296, 1.8303406471386552, 1.2072180211544037, 7.919793901965022, 13.149581998586655, 6.175984349101782, 8.819367606192827, 5.5791389755904675, 3.494461588561535, 4.421879248693585, 0.305269414675422, 0.4227809590520337, 8.043178506195545, 27.290715090930462, 46.1269636452198, 58.059246763587, 58.60993221402168, 48.61552990972996, 45.734273716807365, 37.93065905570984, 36.1101159453392, 44.217664897441864, 40.454092249274254, 27.1834734454751, 20.472218468785286, 15.611500293016434, 15.877386275678873, 20.2822894603014, 25.62306247651577, 30.746825337409973, 26.696189492940903, 19.855093583464622, 10.203695073723793, 2.5919169187545776, 2.5751180201768875, 1.5462765586562455, 4.46156669408083, 3.122519259341061, 4.839737126603723, 6.548660276457667, 8.793358001857996, 5.508511690422893, 17.027203626930714, 16.3370618596673, 18.06997027248144, 18.776909038424492, 16.416152715682983, 20.116510055959225, 18.44497784972191, 5.264401389285922, 10.969672221690416, 20.466874055564404, 19.635244980454445, 20.29654059559107, 25.124489329755306, 19.99564804136753, 21.693415939807892, 26.232426278293133, 25.7475133985281, 28.05569764226675, 25.54977770894766, 21.91166862845421, 20.771116130053997, 24.748714193701744, 6.6393927577883005, 7.568959202617407, 3.450942523777485, 0.204206163471099, 4.120354978367686, 38.08483958244324, 51.340200304985046, 55.632689371705055, 36.20903983712196, 55.74258327484131, 55.81404983997345, 53.16432662308216, 57.11072266101837, 59.50647130608559, 49.99542586505413, 58.47486466169357, 60.60665287077427, 61.402615159749985, 49.40709203481674, 58.88023070991039, 26.995919309556484, 15.694306399673223, 19.037527553737164, 9.33959199115634, 17.44410775601864, 30.865534767508507, 35.82048028707504, 66.17460429668427, 33.924963399767876, 46.49151608347893, 49.55263942480087, 21.794845797121525, 0.666732945246622, 0.16036723303841427, 0.0780788114934694, 0.06411606736946851, 0.09472181453020312, 0.05245087144430727, 0.04416613963257987, 0.033058066546800546, 0.02670969635801157, 0.08109666596283205, 0.05593099114776123, 0.026281232239853125, 0.040641643208800815, 0.04526433265709784, 0.10410259827040136, 0.0455472764588194, 0.03671898826723918, 0.01157894630523515, 0.06211251355125569, 0.014477863260253798, 0.12184506340418011, 0.07174278507591225, 0.03156903258059174, 0.0987847094074823, 0.03804298714385368, 0.026355814370617736, 0.048909817705862224, 0.07203477565781213, 0.08705145111889578, 0.03592537635995541, 0.043294984425301664, 0.1406481020967476, 0.5636316526215523, 72.01795354485512, 84.88818973302841, 55.47597438097, 124.55624476075172, 56.586464792490005, 43.25189732015133, 50.11277116835117, 45.18430642783642, 53.76030944287777, 58.68881978094578, 33.1959231197834, 35.83715759217739, 45.291168093681335, 73.57674390077591, 65.59222474694252, 48.93099658191204, 30.1503998413682, 23.38290598243475, 42.72406004369259, 45.911264419555664, 65.92283740639687, 32.39736557006836, 35.483974143862724, 68.09622958302498, 55.633050352334976, 59.03066463768482, 29.680047780275345, 5.310775525867939, 3.5912708938121796, 2.0416000485420227, 2.6946612680330873, 18.90435989946127, 16.916620060801506, 17.382552959024906, 19.999269247055054, 25.52737221121788, 23.179937973618507, 9.906068444252014, 6.637720847502351, 4.034789744764566, 9.585064519196749, 23.003456443548203, 15.825948435813189, 10.647919736802578, 7.04846978187561, 10.018042735755444, 10.191684868186712, 2.662605713121593, 5.954910311847925, 8.095956724137068, 12.468276657164097, 21.040772460401058, 12.832750249654055, 9.41694539040327, 10.355378184467554, 6.540331598371267, 3.9992450270801783, 3.160810279659927, 1.118544435594231, 19.04814798384905, 44.36957314610481, 49.823754876852036, 54.44959245622158, 57.771374210715294, 49.20541025698185, 52.58773036301136, 51.09160244464874, 45.45426294207573, 51.21311232447624, 48.180783838033676, 33.838825821876526, 28.0397479981184, 22.152900584042072, 24.833242557942867, 32.544478476047516, 44.937399476766586, 41.0646016895771, 29.68508441001177, 29.32104304432869, 23.497372940182686, 16.20201140642166, 4.53783287666738, 0.9493230690713972, 1.6680442309007049, 5.798073727637529, 3.822366180829704, 11.961331609636545, 16.545946151018143, 6.091679697856307, 29.247294701635838, 23.103349283337593, 14.671063106507063, 14.670322146266699, 20.81362444907427, 26.664789877831936, 24.873311407864094, 9.573650881648064, 16.599027402698994, 20.992260463535786, 18.657053969800472, 20.486891381442547, 23.248949870467186, 20.28152760118246, 20.80704130232334, 26.159658282995224, 22.961561791598797, 26.120077706873417, 24.355224408209324, 23.480416350066662, 29.506587088108063, 39.19266253709793, 16.514176055788994, 25.947593562304974, 11.946375612169504, 2.228291630744934, 2.4300384800881147, 38.230478167533875, 61.07417978346348, 59.51142244040966, 45.78242473304272, 58.693816512823105, 61.22791953384876, 59.0718050301075, 66.52883648872375, 62.41595238447189, 53.771967217326164, 58.64089675247669, 64.17819902300835, 65.71169793605804, 56.317279636859894, 53.74019332230091, 39.07090567052364, 14.901828523725271, 10.589455123990774, 20.93329142779112, 19.684167355298996, 36.05871990323067, 36.38630032539368, 66.37887373566628, 46.915257945656776, 48.394647762179375, 60.92691868543625, 25.433051772415638, 0.6073565001133829, 0.14700237050419673, 0.05838324374053627, 0.04718109230452683, 0.04394174015033059, 0.017405826947651803, 0.05015534559788648, 0.02224541090981802, 0.01721547534543788, 0.02760835184744792, 0.007023549242148874, 0.021291188968461938, 0.10726909749791957, 0.028873466872028075, 0.2663844684138894, 0.1442353322636336, 0.2114091964904219, 0.13540637242840603, 0.11537419617525302, 0.11666621590848081, 0.16731858893763274, 0.15145979850785807, 0.16352128644939512, 0.30251200951170176, 0.14990930358180776, 0.10857077257242054, 0.20709565607830882, 0.1218790834536776, 0.10837683454155922, 0.1796889290562831, 0.16371053410694003, 0.29144673608243465, 1.4823922491632402, 91.76990926265717, 93.91710564494133, 61.075566709041595, 125.2445550262928, 73.61550942063332, 61.327770575881004, 87.35496416687965, 66.50235950946808, 55.290589928627014, 64.53221842646599, 43.19266989827156, 38.321829065680504, 60.05010813474655, 89.7012546658516, 76.09444320201874, 55.799253433942795, 38.38158845901489, 28.70686300098896, 48.355760648846626, 53.809706792235374, 75.99901512265205, 35.106118619441986, 43.40836152434349, 75.33579871058464, 62.432701885700226, 65.09309872984886, 35.11014640331268, 6.924281045794487, 10.613231398165226, 6.61635079421103, 1.9735718239098787, 11.455573048442602, 10.783806145191193, 19.87409446388483, 25.732792988419533, 33.99734191596508, 33.9500230550766, 15.30893012881279, 8.157508671283722, 7.84437982365489, 15.53943905979395, 34.71166178584099, 21.979107409715652, 15.093954764306545, 11.933098174631596, 12.598696108907461, 16.802683174610138, 6.940517574548721, 7.319837920367718, 7.311475044116378, 15.452012401074171, 24.473443664610386, 15.043806955218315, 12.84369746223092, 18.427035212516785, 13.149061426520348, 9.210939444601536, 3.976139179430902, 0.936688925139606, 19.51290674507618, 52.14815855026245, 57.78938144445419, 63.240405544638634, 63.05992662906647, 51.40793927013874, 54.34680417180061, 55.149640291929245, 48.314684852957726, 52.72167697548866, 51.521625369787216, 43.35801422595978, 42.14563988149166, 35.71928791701794, 37.42557875812054, 43.27145867049694, 51.28080189228058, 45.24340085685253, 32.464333176612854, 30.689482614398003, 19.8017805442214, 16.194795593619347, 6.823791163042188, 1.2787780375219882, 5.173123637214303, 6.18465025909245, 8.569847345352173, 20.76981659978628, 25.018634609878063, 10.961420014500618, 23.831977285444736, 21.539537496864796, 26.21463943272829, 26.562932543456554, 23.165418952703476, 29.035649858415127, 26.108843609690666, 10.727871246635914, 20.74620846658945, 28.850083015859127, 26.361252665519714, 27.81800139695406, 31.826888881623745, 26.74970392137766, 26.07130542397499, 34.95361000299454, 31.53438627719879, 37.24367871880531, 32.42006175220013, 30.45573055744171, 29.743014201521873, 37.13822677731514, 12.12417472153902, 18.77598188817501, 9.270228613168001, 5.715227723121643, 8.858520705252886, 45.232195258140564, 65.50720050930977, 68.25339674949646, 44.030684530735016, 61.61854237318039, 68.14085438847542, 62.83147148787975, 67.37741455435753, 67.10487797856331, 59.30280603468418, 64.25758436322212, 70.8494858443737, 70.12191608548164, 59.94000144302845, 63.63597571849823, 41.618167385458946, 21.968939155340195, 28.681278973817825, 15.405763182789087, 29.362103641033173, 49.965931847691536, 49.40013840794563, 83.18399637937546, 52.305283918976784, 56.407148614525795, 73.75068336725235, 38.9340104162693, 1.0285631264559925, 0.1463456588680856, 0.16896900662686676, 0.1146511068509426, 0.25480467884335667, 0.1845731068169698, 0.187389527563937, 0.12746034568408504, 0.20368306810269132, 0.15237275889376178, 0.08673908858327195, 0.11537122016306967, 0.24879150150809437, 0.10446157510159537], [0.046633765814476646, 0.04685164924012497, 0.08346917849848978, 0.08535925051546656, 0.04585782444337383, 0.09167099386104383, 0.0747963368485216, 0.10482400291948579, 0.07082588388584554, 0.05756395352364052, 0.09051305052707903, 0.14709717244841158, 0.07685604898142628, 0.01902584255731199, 0.08743201702600345, 0.05665042168402579, 0.035118019877700135, 0.2843303116969764, 0.2753854135517031, 18.086634278297424, 91.18518143892288, 45.00139184296131, 43.395639806985855, 50.62882907688618, 49.32603478431702, 64.5148229598999, 52.775204703211784, 11.931730248034, 19.055692479014397, 39.96635802090168, 29.46134101599455, 58.75168740749359, 68.30489918589592, 59.435217529535294, 71.37843266129494, 61.99713505804539, 20.730853490531445, 33.36933821439743, 58.68973173201084, 69.75633770227432, 63.36182802915573, 42.95070268213749, 48.654983192682266, 57.06790275871754, 40.060585364699364, 16.418187506496906, 13.028156664222479, 5.313870459794998, 0.7921602367423475, 4.255983950570226, 7.445083949714899, 14.734935779124498, 22.6071947067976, 22.17413954436779, 24.577573277056217, 24.22504149377346, 14.50768992304802, 8.342682234942913, 5.5078937485814095, 14.863147549331188, 20.358458273112774, 15.403200220316648, 11.5881222859025, 4.637626921758056, 1.5526789776049554, 3.430638313293457, 5.826692366972566, 1.9237148179672658, 10.018957536667585, 13.183219693601131, 13.61854998394847, 10.796219129115343, 11.737607214599848, 6.4727716986089945, 3.1735343718901277, 3.5800888063386083, 1.7420299421064556, 0.11025086132576689, 3.0298220459371805, 11.845986898988485, 32.336416840553284, 47.85800635814667, 53.13493140041828, 41.73050455749035, 38.35350036621094, 35.69107063114643, 35.34802883863449, 37.17236414551735, 37.11144961416721, 25.137488432228565, 22.502421028912067, 18.630696684122086, 17.005615085363388, 16.29402156919241, 21.625521183013916, 25.255010426044464, 20.10471548885107, 10.425568968057632, 2.6021419325843453, 2.075134674087167, 3.6131634190678596, 3.221265273168683, 2.477631876245141, 3.406341467052698, 6.861784374341369, 7.320414539426565, 10.285760220140219, 9.46101637557149, 24.879102297127247, 29.66970093548298, 41.2930454313755, 10.340372789651155, 3.1388279842212796, 3.822420327924192, 2.6754008140414953, 3.771585705690086, 13.416269738227129, 20.830856524407864, 22.722997292876244, 20.81868387758732, 22.32938401401043, 23.921175599098206, 19.24360379576683, 26.773762330412865, 26.279051676392555, 28.085740730166435, 29.486841447651386, 25.095768570899963, 18.649224489927292, 28.034785464406013, 36.45687393844128, 8.315608687698841, 10.398877300322056, 1.5403886558488011, 0.4103132936870679, 26.228483989834785, 58.117854818701744, 43.383324667811394, 38.89826953411102, 76.01394832134247, 62.37438261508942, 51.392139717936516, 53.81632223725319, 59.17210444808006, 61.15951560437679, 63.35990913212299, 57.55013108253479, 41.87042064964771, 52.63324812054634, 56.35850362479687, 15.392138063907623, 24.282199926674366, 20.747804380953312, 11.406797915697098, 31.07027728110552, 23.31232286989689, 62.040266543626785, 60.073058903217316, 38.830260783433914, 57.413129433989525, 58.620130866765976, 5.57729939930141, 0.2483157700044103, 0.2280294304364361, 0.11669199069729075, 0.1366863545263186, 0.07536825811257586, 0.00802033428044524, 0.1091806472686585, 0.03682498921989463, 0.01892814067105064, 0.029951588512631133, 0.11299703779513948, 0.042880276014329866, 0.02544096150813857, 0.004746006561617833, 0.053642890488845296, 0.04369805224996526, 0.028307308384682983, 0.06589878772501834, 0.0020270323557269876, 0.043551377893891186, 0.04958305697073229, 0.0473166121810209, 0.0947634044860024, 0.314093817723915, 0.027506955921126064, 0.03053092568734428, 0.09376615838846192, 0.0799766909040045, 0.09956268797395751, 0.06702012833557092, 0.024247083383670542, 0.20998212072299793, 0.12234400928718969, 23.500783257186413, 101.6498351097107, 54.0841318666935, 48.63343454897404, 50.629581436514854, 52.200675532221794, 73.1407780945301, 71.3885249197483, 35.97513198852539, 29.82972364872694, 37.31525167822838, 36.47179193794727, 57.52696372568607, 73.17777290940285, 64.97855007648468, 63.64103704690933, 63.985898941755295, 25.909280218183994, 33.587237522006035, 63.83701533079147, 74.00825634598732, 55.70742376148701, 43.10767985880375, 56.364237517118454, 67.98504754900932, 44.38238225877285, 20.45302949845791, 9.135560989379883, 1.535429684445262, 2.841181643307209, 18.67240894585848, 17.319016568362713, 20.956542380154133, 25.824926644563675, 23.342742137610912, 26.291220523416996, 22.15128757059574, 17.580759823322296, 10.271481536328793, 4.179345387965441, 11.237597744911909, 18.534926623106003, 15.90705318376422, 13.196142800152302, 6.888621859252453, 4.149896018207073, 11.64645865559578, 9.305199086666107, 6.951944986358285, 15.432338006794453, 16.681606471538544, 19.108070768415928, 13.613335713744164, 9.995399750769138, 10.144284311681986, 6.3315684255212545, 4.48856994509697, 3.7404910242184997, 0.6593510101083666, 7.8399240877479315, 32.30462774634361, 47.46500484645367, 52.23757915198803, 61.49730607867241, 52.082346081733704, 50.43896846473217, 48.34840804338455, 43.10648672282696, 49.0599350631237, 45.636987537145615, 34.079797491431236, 32.79507502913475, 28.09937059879303, 28.98414932191372, 28.6267177015543, 32.659650295972824, 33.144458681344986, 29.716738611459732, 24.134534150362015, 7.853092281147838, 4.866543738171458, 3.3042371459305286, 0.3341985389124602, 1.8273237277753651, 3.6341007705777884, 3.5452330391854048, 14.797113742679358, 16.204357780516148, 9.432703144848347, 33.348899111151695, 30.37148527801037, 46.11840270459652, 20.402421914041042, 8.734228424727917, 8.124829474836588, 3.889412870630622, 5.966592784970999, 12.768948823213577, 19.184106588363647, 20.658317282795906, 19.7097684815526, 20.393420197069645, 21.94842405617237, 19.712266847491264, 25.133107267320156, 25.618692710995674, 25.807417184114456, 26.132630333304405, 21.250355914235115, 18.826521076261997, 37.29566752910614, 47.49053567647934, 17.06607934087515, 27.85074044018984, 5.7944083493202925, 0.440497063100338, 24.176928475499153, 61.80134676396847, 48.50141063332558, 46.083087399601936, 72.99709260463715, 69.53518956899643, 60.49491226673126, 59.96123090386391, 64.08613756299019, 65.90384602546692, 64.41602826118469, 61.94776430726051, 48.22433330118656, 59.686710834503174, 59.49697181582451, 25.2288431301713, 12.384991776198149, 24.029574282467365, 15.969441086053848, 30.64140759408474, 30.82928281277418, 51.257003769278526, 72.38194361329079, 43.003975823521614, 64.12194684147835, 70.13424262404442, 7.815699437633157, 0.3227577090729028, 0.20637571346014738, 0.1224947023729328, 0.16016391426092014, 0.037637637215084396, 0.020566860257531516, 0.03357461988343857, 0.11545811823452823, 0.08535481247236021, 0.08235017565311864, 0.09041412966325879, 0.05157526335096918, 0.0217751564559876, 0.05244421066890936, 0.130686788179446, 0.24138136475812644, 0.15329484769608825, 0.17864538036519662, 0.1305408522603102, 0.11039421457098797, 0.2254422739497386, 0.1148209250823129, 0.21634277160046622, 0.5899230949580669, 0.16257383103948087, 0.20749525807332247, 0.22093930776463822, 0.17441680101910606, 0.27974829194135964, 0.228510950691998, 0.26380850351415575, 0.5183414078783244, 0.5221800925210118, 35.28945878148079, 116.14680200815201, 63.60591933131218, 55.81226773560047, 59.52058754861355, 67.0355848968029, 82.71817177534103, 71.62842124700546, 22.404703572392464, 28.791132979094982, 52.85099923610687, 38.373384699225426, 67.71776989102364, 81.84054806828499, 73.074661642313, 79.21195551753044, 77.51087799668312, 28.45946967601776, 39.05073255300522, 66.79585576057434, 88.65976855158806, 67.89093419909477, 53.201066851615906, 63.55146825313568, 74.27428007125854, 51.88325956463814, 26.870565935969353, 23.632558286190033, 9.520238097757101, 4.217122485861182, 10.996114052832127, 11.208376362919807, 26.036476492881775, 37.68535181879997, 33.33772391080856, 36.19927816092968, 34.00572806596756, 20.689570605754852, 13.857788946479559, 9.756957795470953, 22.81086377799511, 27.633456699550152, 19.956401847302914, 17.97385822981596, 9.774609748274088, 5.999966869130731, 15.111140292137861, 16.856267899274826, 8.32512242719531, 18.495450541377068, 22.2124357894063, 23.333721421658993, 19.312691688537598, 17.380495369434357, 15.929523278027773, 11.115563493221998, 7.638461273163557, 4.902165876701474, 0.611677699489519, 5.5606672167778015, 26.39760911464691, 47.98369221389294, 56.160887628793716, 65.67151889204979, 53.6395101249218, 53.96199122071266, 51.620169281959534, 47.394583225250244, 52.49488614499569, 46.73667132854462, 44.31401252746582, 42.8936867415905, 40.070833414793015, 39.209362640976906, 40.9051850438118, 42.188467383384705, 43.30316796898842, 35.25249056518078, 22.751801647245884, 5.286186570301652, 7.219005580991507, 10.023878272622824, 6.23595985583961, 3.6445038998499513, 4.53877997584641, 7.81782922334969, 24.448370710015297, 24.03616312891245, 14.607815500348806, 36.78293064236641, 42.044911086559296, 51.3074004650116, 15.860444884747267, 6.037012031301856, 7.622421383857727, 6.022080732509494, 15.296570342034101, 24.519039317965508, 28.667565509676933, 29.399037659168243, 28.04553508758545, 28.59036885201931, 30.086711458861828, 25.519504733383656, 35.27838237583637, 34.537376537919044, 33.6283703148365, 36.527994722127914, 32.55926348268986, 25.19159372895956, 35.0174655765295, 53.773958310484886, 12.058073468506336, 20.56957684457302, 3.597193113528192, 0.7810425676871091, 32.56346605718136, 69.24908772110939, 54.85674440860748, 44.069925025105476, 75.38882106542587, 70.16299188137054, 61.8222114443779, 63.15073035657406, 71.76199167966843, 70.51819682121277, 72.81836539506912, 67.29311987757683, 52.139749601483345, 64.92405340075493, 69.87307503819466, 23.931319154798985, 35.77780477702618, 32.64135807752609, 15.33346826210618, 50.247557535767555, 37.914209738373756, 79.72726106643677, 79.18738603591919, 51.4877387881279, 70.36485224962234, 90.36750331521034, 11.456217113882303, 0.6399255024734885, 0.38002621731720865, 0.25217703077942133, 0.37961518624797463, 0.1463687841896899, 0.19851476652547717, 0.15449363883817568, 0.27720661426428705, 0.14975282916566357, 0.15375264891190454, 0.23026471986668184, 0.07837725133867934, 0.1982955657877028, 0.1943528765696101], [0.042235694781993516, 0.09693128464277834, 0.03609004779718816, 0.008326693769049598, 0.045285283486009575, 0.042109622445423156, 0.1270246010972187, 0.056016223097685724, 0.06740152544807643, 0.03631518942711409, 0.02336555851798039, 0.0040538504163123434, 0.06515934888739139, 0.0509434804553166, 0.04479851995711215, 0.08973776595667005, 0.05434246486402117, 0.13163287803763524, 0.06230436614714563, 1.4112722966820002, 54.53020893037319, 80.9692320227623, 42.65584610402584, 44.364523217082024, 47.42719687521458, 43.40594485402107, 36.9157525151968, 18.867262490093708, 30.85715241730213, 47.03998625278473, 24.354249760508537, 33.47853295505047, 68.71891736984253, 57.15798072516918, 67.08050608634949, 60.69855093955994, 49.91783782839775, 30.20054765045643, 56.540004685521126, 69.15816619992256, 94.62392091751099, 61.29649065434933, 43.728570342063904, 53.01393449306488, 51.11735366284847, 20.988213680684566, 2.151245065033436, 2.8611210733652115, 2.936904444359243, 6.991629581898451, 23.34091443568468, 23.436177223920822, 22.118301540613174, 21.578717194497585, 22.65619307756424, 18.697833381593227, 15.589554570615292, 8.751928824931383, 4.496614588424563, 9.268197622150183, 22.683112733066082, 16.82011093944311, 13.547430150210857, 7.432032600045204, 4.685301063582301, 0.29969683557283133, 6.68947359547019, 5.663702487945557, 15.4279625415802, 15.40190638974309, 22.047222554683685, 13.231562599539757, 11.164376623928547, 11.304354462772608, 4.7040582820773125, 2.156916023232043, 3.161582825705409, 0.778548417147249, 4.2344695050269365, 11.245938297361135, 30.85043627768755, 46.84040196239948, 46.45199440419674, 34.61761683225632, 34.20731484889984, 31.199390552937984, 34.53068509697914, 38.877777233719826, 33.62231723964214, 29.67727392911911, 27.516242489218712, 18.93063358962536, 19.476096220314503, 17.506086230278015, 22.91128098964691, 23.108137026429176, 18.307919204235077, 6.866707485169172, 1.4734693779610097, 1.2730724061839283, 1.3398068002425134, 3.2108901673927903, 2.3569957120344043, 3.151839436031878, 4.875420061871409, 10.926631931215525, 13.354300763458014, 8.746156934648752, 23.66731882095337, 30.326254405081272, 17.983466014266014, 4.034400740638375, 3.78237783908844, 5.464539974927902, 10.798376463353634, 10.415155626833439, 14.552909396588802, 19.20884896069765, 22.91844930499792, 20.921859741210938, 23.585663102567196, 20.665288008749485, 21.624111458659172, 21.031424961984158, 27.10784040391445, 28.645933270454407, 31.039884611964226, 31.93211853504181, 35.066182762384415, 15.194441322237253, 31.046982631087303, 37.60193109512329, 11.920414455235004, 8.725902121514082, 0.25841196184046566, 4.4543128833174706, 60.30026011168957, 25.39199497550726, 27.400675490498543, 79.46765139698982, 72.50473022460938, 54.15385812520981, 55.88520102202892, 59.69534397125244, 54.72548045217991, 58.61166872084141, 57.60837435722351, 35.917424485087395, 63.15662004053593, 43.01102064549923, 14.090365916490555, 28.110486902296543, 8.374342136085033, 20.828441753983498, 29.084140956401825, 34.65277634561062, 75.84236472845078, 44.75589081645012, 40.65818689763546, 52.42840111255646, 21.51847902685404, 0.4602633055765182, 0.19662089471239597, 0.19767864811001346, 0.07206230933661573, 0.041307490682811476, 0.04665024891437497, 0.014402479609998409, 0.1439398535876535, 0.07814659184077755, 0.0378514314070344, 0.04271498117304873, 0.08709481480764225, 0.035578322131186724, 0.11422665033023804, 0.039414335042238235, 0.021579114436462987, 0.062463519716402516, 0.02326678793906467, 0.08897713138139807, 0.018228788940177765, 0.06431027257349342, 0.09819037528359331, 0.08721589620108716, 0.1274509946233593, 0.09088883700314909, 0.09466380826779641, 0.06091903618653305, 0.02082729657558957, 0.03355625543917995, 0.1426184448064305, 0.14380125008756295, 0.04810578975593671, 0.13366416591452435, 0.04410039276990574, 1.98100873734802, 68.05192396044731, 88.2507736980915, 46.96377374231815, 41.18912100791931, 44.967026486992836, 50.64706049859524, 44.86746422946453, 24.39625460654497, 38.135388270020485, 39.05288703739643, 32.01656520366669, 43.187923952937126, 72.72698789834976, 64.41289722919464, 66.80131986737251, 62.741648107767105, 50.723607391119, 33.49734574556351, 60.43402053415775, 74.701719135046, 78.35077732801437, 60.549237951636314, 53.06178532540798, 61.02097883820534, 54.7983605414629, 25.269780233502388, 2.9296361468732357, 0.7907603681087494, 13.172364626079798, 14.917079955339432, 28.910298384726048, 27.67764452844858, 20.606856644153595, 20.83663411438465, 20.3812038525939, 19.471553564071655, 17.64403022825718, 10.341960154473782, 4.039529040455818, 6.90241226926446, 17.546939738094807, 18.031890615820885, 12.214286886155605, 8.313653692603111, 5.035384828224778, 3.8945649191737175, 12.676044758409262, 11.647354457527399, 18.353474959731102, 16.927305087447166, 27.376202903687954, 16.77271608263254, 11.595966964960098, 13.515745550394058, 6.463321130722761, 2.3670217115432024, 1.8517710221931338, 1.2080670380964875, 3.2472150307148695, 23.491715043783188, 41.38536527752876, 52.11778677999973, 54.114005863666534, 45.22162422537804, 45.29718317091465, 43.19649249315262, 40.56590884923935, 45.770641565322876, 42.357999086380005, 36.28085598349571, 36.1884069442749, 26.593007929623127, 28.647447489202023, 26.578821390867233, 28.68776522576809, 31.369439028203487, 23.439646437764168, 14.382285252213478, 1.618240897078067, 2.043351042084396, 2.351312404498458, 2.025443078018725, 3.0161803029477596, 4.132680566981435, 3.828855757601559, 17.446505427360535, 19.513003639876842, 9.241755791008472, 28.128648027777672, 29.97723363339901, 23.921690471470356, 12.04488342627883, 9.56197315827012, 11.390209905803204, 14.739498384296894, 11.677464041858912, 14.014473538845778, 17.897959202528, 22.241905108094215, 20.150808915495872, 22.012938894331455, 17.978613674640656, 20.570310205221176, 20.850871950387955, 27.7786336094141, 26.744642592966557, 30.639819279313087, 24.91202563047409, 18.875781632959843, 10.722248498350382, 36.85768403112888, 40.25154031813145, 19.25848189741373, 26.345700100064278, 0.7772874785587192, 2.58165224455297, 64.86092358827591, 31.405538991093636, 25.646007545292377, 76.7870244383812, 72.45086431503296, 58.78608696162701, 59.81834717094898, 66.1195832490921, 59.776287227869034, 66.56988188624382, 61.93157717585564, 44.78741392493248, 64.68077525496483, 55.74392840266228, 17.812349796295166, 17.880369946360588, 10.944404527544975, 12.48504800722003, 33.55374991893768, 36.17938242852688, 73.13437163829803, 57.38469935953617, 41.000434532761574, 63.566367253661156, 28.370771035552025, 0.6198923836927861, 0.12112693162634969, 0.14220745826605707, 0.05253689749224577, 0.03639150447270367, 0.019185686323908158, 0.10192478075623512, 0.06312070632702671, 0.07809199203620665, 0.0201202858806937, 0.03738515115401242, 0.010020930640166625, 0.10615165316266939, 0.050352274483884685, 0.07010077591985464, 0.1244458308792673, 0.18951469712192193, 0.11960661242483184, 0.18509338202420622, 0.17509742465335876, 0.12736495002172887, 0.2168057084782049, 0.18367270356975496, 0.2421425559441559, 0.24634480389067903, 0.11534630626556464, 0.15657168201869354, 0.1300967510906048, 0.12908444681670517, 0.18822438432835042, 0.2650842850562185, 0.3418683976633474, 0.46676288649905473, 0.17699867341434583, 3.8304017996415496, 88.82901147007942, 97.63262987136841, 61.940932273864746, 59.680562764406204, 61.4473045617342, 56.47914335131645, 51.879706755280495, 24.935018196702003, 48.65163937211037, 64.04396742582321, 33.081602454185486, 44.79447014629841, 77.53871530294418, 75.32223343849182, 79.14292082190514, 74.91762354969978, 58.34920920431614, 40.1552876830101, 64.47203725576401, 87.70463660359383, 100.54939895868301, 72.43488237261772, 57.65587940812111, 65.6403985619545, 61.18943139910698, 34.87662613391876, 9.143621306866407, 6.809923807159066, 7.494235262274742, 11.339713465422392, 37.17745967209339, 39.60427165031433, 32.907104417681694, 34.69357095658779, 32.90945269167423, 26.199179962277412, 19.03553646057844, 12.541753314435482, 9.09568877890706, 16.959932036697865, 30.506446436047554, 24.562425389885902, 18.230287469923496, 12.28934045881033, 8.820602539926767, 5.406553186476231, 17.076154500246048, 12.184069957584143, 24.29191030561924, 24.955358505249023, 36.73253774642944, 22.956048287451267, 17.445804364979267, 19.805745631456375, 10.605947189033031, 6.135965371504426, 6.7888985853642225, 2.5454520620405674, 5.7573408633470535, 27.454288713634014, 47.38546371459961, 59.320543482899666, 62.042177841067314, 46.527101173996925, 47.35726162791252, 46.26064047217369, 44.628973826766014, 49.42211262881756, 46.12462297081947, 44.46001209318638, 43.80059167742729, 39.99836750328541, 36.79510898888111, 38.13233703374863, 40.169054344296455, 41.665330454707146, 27.56028402596712, 15.111241936683655, 1.9362435769289732, 6.780230300500989, 6.904203398153186, 8.99718951433897, 5.14723657630384, 4.826607881113887, 10.897594839334488, 25.757060386240482, 29.0579641610384, 13.04482351988554, 33.30150805413723, 39.860339909791946, 22.928872145712376, 9.21976637095213, 8.87442760169506, 12.680693808943033, 22.750120237469673, 19.622705653309822, 25.56857530027628, 29.37680695205927, 31.622609943151474, 28.348604924976826, 31.924613937735558, 24.790853932499886, 27.68663104623556, 26.982044354081154, 34.92507353425026, 35.4285579174757, 39.483065754175186, 40.808753818273544, 44.26456198096275, 23.899866342544556, 39.204483702778816, 49.98512841761112, 15.459212064743042, 17.451781444251537, 0.30690362385939807, 6.203360930085182, 76.12334445118904, 32.60873682796955, 32.91987933218479, 81.69418752193451, 76.60413265228271, 64.6894995868206, 68.71798262000084, 67.75160327553749, 65.42650803923607, 69.29601520299911, 66.70381709933281, 44.59304675459862, 74.17297750711441, 58.88134025037289, 20.46388551592827, 41.89181350171566, 15.361683648079634, 36.734357848763466, 41.08840361237526, 55.059634521603584, 92.03529462218285, 66.15844756364822, 52.10906244814396, 77.26104140281677, 42.086971029639244, 0.7714971236418933, 0.3551518020685762, 0.31144170847255737, 0.1861865507089533, 0.18314096960239112, 0.10937103041214868, 0.2533500693971291, 0.21341701765777543, 0.2179621675168164, 0.17700422467896715, 0.13186101423343644, 0.11064792517572641, 0.23013401281787083, 0.2775120228761807, 0.16534162627067417], [0.10298133187461644, 0.044603854621527717, 0.023736953335173894, 0.04815217398572713, 0.10260595357976854, 0.06316916114883497, 0.09025712832226418, 0.04817102824745234, 0.1060024592152331, 0.026058604635181837, 0.233028388756793, 0.0500602839019848, 0.10506712307687849, 0.0990487210219726, 0.09036899224156514, 0.15476039639906958, 0.038913979078643024, 0.10505821730475873, 0.6731870176736265, 0.2771161316195503, 16.079143099486828, 82.74787098169327, 55.41454307734966, 47.06481792032719, 72.54114747047424, 55.27357064187527, 34.2321465164423, 64.5791383087635, 24.67117365449667, 42.71271385252476, 33.19239690899849, 20.656958855688572, 60.252177491784096, 66.09515815973282, 62.181808948516846, 68.96060720086098, 75.37931397557259, 59.880527034401894, 51.55812241137028, 58.18699590861797, 70.43397054076195, 55.712051913142204, 41.41650840640068, 55.33449277281761, 42.737974897027016, 11.840507593005896, 0.25168596650473773, 1.8654240458272398, 6.368515742942691, 27.077485732734203, 23.29772785305977, 21.234833747148514, 27.053491920232773, 22.70828068256378, 23.624867498874664, 21.440691500902176, 23.113641031086445, 10.961067583411932, 4.872566889971495, 7.189804147928953, 18.82808469235897, 19.380312860012054, 16.036154106259346, 8.530526105314493, 7.250630808994174, 3.990456098690629, 7.493045451119542, 13.110215160995722, 17.6943851262331, 17.449085488915443, 22.166921831667423, 15.755582861602306, 12.75277404114604, 13.094325363636017, 5.9136146027594805, 3.97673764731735, 6.04968530125916, 1.666070711798966, 9.314204603433609, 20.61890009790659, 35.8374197781086, 43.86098563671112, 37.7255042642355, 28.919379897415638, 28.149113729596138, 27.670708000659943, 32.746190652251244, 36.580971479415894, 38.269076496362686, 29.985967464745045, 25.22344931960106, 22.671891935169697, 18.358414694666862, 14.851168692111969, 20.513584949076176, 24.71635513007641, 21.393422037363052, 6.357141528278589, 1.2269449001178145, 1.1910549947060645, 3.815424428321421, 0.4458406154299155, 3.6103933677077293, 3.1928259367123246, 3.520822199061513, 9.000705275684595, 14.0914336591959, 12.176781948655844, 25.006650052964687, 31.135747767984867, 25.940753929316998, 20.9576728194952, 14.626200813800097, 7.776318825781345, 3.050810219720006, 5.699287578463554, 12.030259910970926, 17.38034527748823, 19.722068421542645, 19.055534787476063, 21.605710946023464, 20.18386334180832, 18.960900865495205, 25.593406967818737, 28.055348061025143, 28.363256938755512, 27.736890949308872, 22.40735962986946, 44.272564351558685, 51.894104182720184, 24.783607721328735, 38.69784168899059, 40.52270896732807, 17.13259667158127, 4.684450384229422, 0.37756317760795355, 22.317408956587315, 48.96912753582001, 40.8518473058939, 47.93450005352497, 52.088554948568344, 59.427595138549805, 58.85374993085861, 57.48561814427376, 59.37555693089962, 59.925968796014786, 50.81427052617073, 40.3681218624115, 72.4241441488266, 27.643904238939285, 21.751157641410828, 12.71106842905283, 7.60488105006516, 32.84030020236969, 30.83573866635561, 44.773962646722794, 65.49459278583527, 37.006662636995316, 47.66070954501629, 60.11391431093216, 5.319570153951645, 0.10973207783536054, 0.2398568598437123, 0.1504308998119086, 0.09614427413907833, 0.0877745849720668, 0.11306407599477097, 0.10271783234202303, 0.025856640277197585, 0.053621783808921464, 0.05821602673677262, 0.04867494651989546, 0.07256147044245154, 0.05972390383249149, 0.006975512342251022, 0.0885446448228322, 0.03991685065557249, 0.002760418051366287, 0.04792321029526647, 0.03607218801334966, 0.00971759818639839, 0.058249070862075314, 0.03788522881222889, 0.0536991044646129, 0.09469730139244348, 0.03917733389243949, 0.04675407908507623, 0.04088483387022279, 0.05478392027725931, 0.08800073963357136, 0.050655579107115045, 0.13831624441081658, 0.05516238961718045, 0.3017996664857492, 0.46686628251336515, 0.26555792370345443, 22.181609943509102, 94.02731493115425, 63.0205075442791, 50.0019197165966, 65.41111886501312, 57.08666995167732, 35.58399997651577, 44.37124885618687, 35.661181434988976, 36.95010267198086, 36.66290268301964, 33.19273129105568, 67.10700586438179, 69.11439254879951, 68.57934325933456, 71.4351712167263, 74.16649505496025, 63.47266048192978, 55.66624157130718, 67.20810323953629, 71.11636832356453, 57.15583384037018, 47.27259837090969, 63.82523596286774, 46.85486778616905, 15.023869425058365, 0.4681330395396799, 11.510303411632776, 20.08502684533596, 31.92208707332611, 20.648044534027576, 9.212653152644634, 19.777078069746494, 21.627413481473923, 25.353683531284332, 21.186437644064426, 26.693497337400913, 13.406857643276453, 6.923586633056402, 7.305850870907307, 12.661346197128296, 17.71833334118128, 12.745037656277418, 8.35851788520813, 7.331221159547567, 6.3854519091546535, 13.72502027079463, 17.04568013548851, 22.1761192381382, 17.360875122249126, 24.359383285045624, 18.87316357344389, 14.593628961592913, 18.024771697819233, 9.188714437186718, 3.640209180302918, 3.9513661712408066, 1.3408550689928234, 1.670142193324864, 21.52094129472971, 38.19004073739052, 49.026417061686516, 49.553027004003525, 42.95265957713127, 40.36719091236591, 38.28543081879616, 40.48982173204422, 43.67695011198521, 45.54391533136368, 34.49954196810722, 35.935963690280914, 30.176884420216084, 29.9549725279212, 23.69141712784767, 29.83824849128723, 29.735804088413715, 23.168437890708447, 10.047357212752104, 1.1111431452445686, 1.4285522256977856, 5.130844255909324, 3.104412518441677, 3.427221109159291, 3.382805767469108, 5.728375017642975, 15.906953439116478, 20.928501784801483, 10.362154170870781, 26.971978694200516, 33.63678686320782, 22.38818395882845, 20.800467655062675, 17.16132503002882, 9.587657880038023, 7.432312835007906, 7.730288570746779, 11.516988202929497, 16.28306295722723, 20.534833408892155, 17.90897861123085, 18.96236188709736, 16.129492297768593, 18.00245739519596, 21.90101020038128, 30.441961996257305, 26.303858645260334, 27.04450160264969, 25.200061574578285, 49.1873574256897, 50.83781026303768, 27.25561447441578, 39.405116736888885, 40.611088424921036, 22.0117324590683, 18.10944065451622, 0.1702222862513736, 17.771384194493294, 52.961596101522446, 39.12461198866367, 48.58747981488705, 57.45534896850586, 66.38452783226967, 61.555484756827354, 63.75987946987152, 65.1467214524746, 65.12309432029724, 55.07913127541542, 43.4665098041296, 71.86543732881546, 40.79944431781769, 23.24340406805277, 13.924392722547054, 10.172761883586645, 16.010473184287548, 22.38760259002447, 41.43420025706291, 73.71181145310402, 45.272731482982635, 48.73275741934776, 73.90414953231812, 7.615370862185955, 0.30869356531184167, 0.1598974980879575, 0.1368797433678992, 0.03394149316591211, 0.015132399475987768, 0.053655087685910985, 0.06441795820137486, 0.0006594342164589762, 0.0287470438706805, 0.05357171110517811, 0.05323069424775895, 0.09174932754831389, 0.05376994246034883, 0.0748409992957022, 0.02862036482838448, 0.173657821433153, 0.14635394123615697, 0.15833250159630552, 0.3151286387583241, 0.17972998466575518, 0.1589930575573817, 0.22559607663424686, 0.17224858689587563, 0.17703824472846463, 0.1341492187930271, 0.3016786073567346, 0.19857934821629897, 0.21819392539327964, 0.24871134955901653, 0.16037006804253906, 0.4363057395676151, 0.11552945346920751, 0.3735628828871995, 0.9358187124598771, 0.379105182364583, 32.763016149401665, 111.85258403420448, 71.67559951543808, 65.81998452544212, 88.51450234651566, 71.39207392930984, 56.06979891657829, 82.37315028905869, 37.73096077144146, 62.18937814235687, 45.164916068315506, 30.552313774824142, 70.5640983581543, 77.31426894664764, 74.75107848644257, 84.82263565063477, 84.91003096103668, 72.72434324026108, 60.59440992772579, 68.9634570479393, 82.36692622303963, 64.27298873662949, 54.238715171813965, 70.25389820337296, 56.88834339380264, 21.746635884046555, 0.5036961031146348, 7.389060230925679, 15.045544411987066, 40.17061226069927, 32.83868528902531, 33.60651768743992, 42.68789738416672, 35.475682988762856, 30.13234131038189, 26.916060894727707, 29.330291748046875, 16.032029427587986, 10.765805561095476, 15.198240168392658, 28.806658945977688, 26.87387365847826, 22.317494451999664, 14.706503804773092, 13.471172042191029, 7.753496775403619, 15.547362584620714, 19.549508281052113, 30.569490753114223, 26.09421819448471, 32.58765555918217, 25.227015428245068, 18.336911648511887, 21.89524780958891, 13.332909811288118, 11.211446598172188, 13.603855222463608, 2.246307651512325, 15.938997119665146, 38.620401844382286, 45.250787660479546, 57.774847224354744, 55.26414714753628, 46.6690007597208, 44.03912007808685, 45.49518294632435, 44.79878671467304, 49.788861349225044, 49.46796476840973, 42.73621179163456, 42.901168540120125, 41.30267411470413, 38.78385007381439, 36.4594653993845, 39.38270553946495, 40.57133115828037, 29.449356459081173, 12.51993678510189, 2.8109053429216146, 6.402505869045854, 12.253431435674429, 15.195207931101322, 5.212600193917751, 3.2187353214249015, 10.601968802511692, 23.157346285879612, 34.145241379737854, 15.411203540861607, 35.07591404020786, 40.21730035543442, 34.235513135790825, 28.30403331667185, 20.219874009490013, 10.823446568101645, 10.268389452248812, 12.446127645671368, 22.524262256920338, 26.85958832502365, 29.73333042114973, 26.011530831456184, 27.041623257100582, 24.283742643892765, 25.659006647765636, 31.41298659145832, 37.680921256542206, 34.476860985159874, 35.26405714452267, 27.015993632376194, 51.41971863806248, 61.05966076254845, 35.066011771559715, 47.67774783074856, 52.145031318068504, 20.912170261144638, 12.042271066457033, 0.5332578637171537, 33.572900891304016, 58.09885583817959, 51.21079444885254, 57.71228738129139, 60.76266869902611, 69.98573139309883, 65.70561826229095, 66.77083790302277, 70.5714699625969, 68.3891710639, 60.586711540818214, 47.98868514597416, 85.02777144312859, 39.41482901573181, 29.59343522787094, 23.01046136766672, 15.234859753400087, 47.26479358971119, 43.507255017757416, 66.04956060647964, 79.0947014093399, 57.45571754872799, 58.88293996453285, 91.60074234008789, 10.151016600430012, 0.3465925535419956, 0.43037410941906273, 0.5062231456395239, 0.18157015467295423, 0.1692182049737312, 0.1763022123486735, 0.14989846822572872, 0.12073481047991663, 0.1567353997961618, 0.1929929354810156, 0.20988844684325159, 0.3069277585018426, 0.22199783299583942, 0.1593881769804284, 0.11685584206134081], [0.03974070190452039, 0.0032059541172202444, 0.02882865970605053, 0.058688685749075375, 0.0284200888563646, 0.023862686139182188, 0.07375855464488268, 0.14241484401281923, 0.03627229329140391, 0.07949406484840438, 0.14592680556233972, 0.06391709757735953, 0.08361599015188403, 0.08011289726709947, 0.080992876610253, 0.07266166037879884, 0.04435676026332658, 0.15617022465448827, 0.14841323776636273, 0.17813834507251158, 0.855478614103049, 46.58668577671051, 72.72596195340157, 40.59393234550953, 56.73557639122009, 86.56309425830841, 41.91548243165016, 62.485636845231056, 33.48108261823654, 38.03812488913536, 42.53900237381458, 19.135459698736668, 45.60857646167278, 69.61012914776802, 71.83946952223778, 61.31051950156689, 63.068818151950836, 68.4417374432087, 70.88340282440186, 63.083386570215225, 56.66194014251232, 60.349334478378296, 61.45847216248512, 64.34789031744003, 37.96870641410351, 1.8272066465578973, 1.3047779048793018, 4.742990043014288, 22.51366462558508, 23.44456907361746, 41.064176112413406, 52.10617460310459, 18.722323067486286, 17.020723074674606, 19.855403266847134, 22.994796708226204, 26.63518186658621, 12.577227260917425, 6.051955204457045, 4.8903765343129635, 12.195418048650026, 16.9698666036129, 14.023057278245687, 8.837755769491196, 8.496759217232466, 4.181609116494656, 12.574001234024763, 20.879322923719883, 20.363443605601788, 21.43057644367218, 26.014131791889668, 17.51257438212633, 15.796367973089218, 14.45803513750434, 9.12222370505333, 5.465619117021561, 6.384106781333685, 2.8419209411367774, 6.7025558184832335, 21.360806487500668, 35.52440017461777, 45.75773745775223, 38.853663727641106, 26.956492625176907, 24.3664813041687, 26.321643590927124, 32.46071957051754, 35.74959509074688, 35.60343973338604, 28.38868897408247, 28.26781366020441, 19.0960843116045, 20.402431413531303, 16.563732996582985, 20.868613198399544, 24.003764167428017, 25.97978923469782, 11.484659537672997, 4.188578417524695, 4.893464343622327, 4.558284804224968, 0.5497061123605818, 1.3504448044113815, 2.219976489432156, 6.431177705526352, 11.111644953489304, 22.879742681980133, 13.8828856498003, 19.140792712569237, 29.571778289973736, 28.07255733758211, 23.006587475538254, 19.710817225277424, 21.360455006361008, 16.342107988893986, 9.936691951006651, 13.070559538900852, 17.547618001699448, 19.072516076266766, 19.36010554432869, 20.054801367223263, 18.431142792105675, 17.396737597882748, 24.825850054621696, 27.353369928896427, 31.320178471505642, 29.982942827045918, 27.156295403838158, 15.864530615508556, 23.822164312005043, 21.67745679616928, 24.35956757515669, 34.41498130559921, 47.98218369483948, 25.827535204589367, 2.259429059922695, 0.7921119674574584, 44.317025765776634, 55.12864261865616, 48.8538683205843, 53.008751571178436, 53.22543874382973, 59.9250378459692, 57.378802075982094, 61.643013060092926, 58.60398553311825, 49.65521112084389, 50.83474762737751, 54.28105250000954, 23.38992230594158, 24.101658314466476, 6.5033624321222305, 8.61703796312213, 84.8916095495224, 88.42748701572418, 59.45617340505123, 58.40484581887722, 33.0769857019186, 63.08609202504158, 47.08177641034126, 0.6816003599669784, 0.1353074293001555, 0.05095414140669163, 0.15687597740907222, 0.13238700397778302, 0.11610498899244703, 0.08193326677428558, 0.10913366932072677, 0.015885656175669283, 0.06611092321691103, 0.022893485802342184, 0.07784196990542114, 0.02109686131007038, 0.09043399695656262, 0.05638278838887345, 0.043744744471041486, 0.03904651552147698, 0.05158459214726463, 0.025834424086497165, 0.0215962636139011, 0.06642909676884301, 0.0829256146971602, 0.10860618043807335, 0.12151364993769675, 0.12335747873294167, 0.12003522497252561, 0.1708827234688215, 0.05074428430816624, 0.044968872534809634, 0.12891783466329798, 0.010654609723133035, 0.251553597045131, 0.0663601141422987, 0.14713943033711985, 0.06073651609767694, 0.04607676171872299, 1.4773948048241436, 61.95055715739727, 87.88670003414154, 47.65107326209545, 62.019120678305626, 76.65210127830505, 43.62272322177887, 42.544029504060745, 38.95615182816982, 43.21861110627651, 37.2395483404398, 29.91525325924158, 55.34157559275627, 77.67857819795609, 79.11529630422592, 67.81708896160126, 69.3349327147007, 74.8576095700264, 72.94087842106819, 67.39284172654152, 62.724678218364716, 61.722014620900154, 67.71333932876587, 69.79804426431656, 41.27474181354046, 2.129080379381776, 3.6441764049232006, 20.334800742566586, 26.646478660404682, 30.82387950271368, 25.685109347105026, 44.624797850847244, 25.438698269426823, 22.304660640656948, 21.382716111838818, 23.414100408554077, 25.98374292254448, 16.521929539740086, 5.567483576014638, 6.212665205821395, 9.469781555235386, 15.133048966526985, 13.61080789938569, 9.801197871565819, 9.021415114402771, 6.252907896414399, 19.15845226496458, 23.19805160164833, 23.433990441262722, 18.498589172959328, 27.38175630569458, 19.911873936653137, 17.310552522540092, 17.211894616484642, 13.127319943159819, 5.4259316716343164, 5.507763605564833, 3.3445356460288167, 6.869936361908913, 31.68942365795374, 44.257657751441, 47.82923050224781, 43.13024304807186, 37.51137815415859, 36.079614982008934, 37.171820774674416, 37.7161605656147, 42.84153833985329, 42.57628597319126, 33.221153765916824, 37.380231991410255, 29.440181851387024, 30.534008257091045, 25.796304680407047, 27.741500101983547, 34.18914422392845, 27.712367065250874, 14.22575930133462, 2.5265369145199656, 0.8036620414350182, 4.6350079122930765, 5.080877412110567, 1.5340207912959158, 3.1415370013564825, 8.815469965338707, 15.035574696958065, 27.780736796557903, 12.189190182834864, 23.45140490680933, 34.46322351694107, 26.735585778951645, 20.062159672379494, 19.53097477555275, 21.98094081133604, 17.304374054074287, 9.687854703515768, 15.621747393161058, 17.0530042424798, 17.454813681542873, 16.51377707719803, 15.664435252547264, 13.469575177878141, 15.984241291880608, 24.77402463555336, 27.066244035959244, 29.827276580035686, 29.4296146184206, 26.900312639772892, 24.06123798340559, 28.786867707967758, 18.06082796305418, 25.815947726368904, 41.70273184776306, 45.542061030864716, 34.016443490982056, 11.69117845594883, 0.4937812773277983, 40.12856371700764, 59.9820613861084, 56.376681849360466, 60.070022866129875, 62.08366401493549, 69.33699980378151, 66.45913302898407, 67.27080747485161, 64.57922950387001, 53.309687823057175, 51.45250707864761, 62.255521193146706, 36.12933911383152, 29.67712003737688, 14.949361123144627, 14.20206282287836, 76.67569801211357, 74.5753987133503, 60.67936956882477, 65.01994505524635, 39.40222889184952, 68.27488079667091, 55.52185691893101, 1.3785699452273548, 0.0993201244273223, 0.0773574216873385, 0.11323575701680966, 0.03513438052323181, 0.04528081204625778, 0.1383451436413452, 0.08834022766677663, 0.0214314251934411, 0.04017381928861141, 0.04074202981428243, 0.07674097156268544, 0.01644403881073231, 0.05169067473616451, 0.04083221188921016, 0.02337028599868063, 0.12438936086255126, 0.09546540939481929, 0.13619806588394567, 0.10646889160852879, 0.20667611999670044, 0.23414281255099922, 0.1661091999267228, 0.17878546816064045, 0.23772603512043133, 0.18307009449927136, 0.19263848575064912, 0.20731114607769996, 0.1833974855253473, 0.20595295645762235, 0.10193600202910602, 0.2728374127764255, 0.21670349990017712, 0.22766049398342147, 0.2229106004233472, 0.24431799858575687, 2.4927170667797327, 83.32565277814865, 96.2387278676033, 55.92764474451542, 80.39644315838814, 95.97002148628235, 64.62670415639877, 85.03990039229393, 43.78976985812187, 57.20440283417702, 58.23124073445797, 26.353073604404926, 60.52111566066742, 81.32693722844124, 90.12018218636513, 77.31210306286812, 78.4409236907959, 78.7803366780281, 82.92859688401222, 70.17429247498512, 72.12618693709373, 69.19883921742439, 73.66698145866394, 78.0826561152935, 51.891387328505516, 4.058311432600021, 2.3413557512685657, 14.882688950747252, 28.810586035251617, 39.30647403001785, 53.889198526740074, 71.82449832558632, 26.329739056527615, 22.86639779806137, 25.653523541986942, 31.02045815438032, 36.04156382381916, 18.684121817350388, 10.10157935321331, 11.783921029418707, 18.946642130613327, 24.559195563197136, 22.419480979442596, 15.82979192957282, 12.652062345296144, 7.223189156502485, 21.053021103143692, 31.69826578348875, 31.530592180788517, 28.25159803032875, 36.05895169079304, 28.516937792301178, 22.75723345577717, 22.87678264081478, 18.700077161192894, 12.101993411779404, 18.66728112101555, 6.16857142187655, 12.59750297293067, 48.94367650151253, 56.771465465426445, 60.016582533717155, 53.46275120973587, 41.47553823888302, 42.385578006505966, 42.03233756124973, 46.791483387351036, 45.302400290966034, 45.86630903184414, 39.66970793902874, 45.3211522847414, 40.149561390280724, 39.90151830017567, 37.26537935435772, 39.32376690208912, 41.77302047610283, 31.580377109348774, 20.41379850357771, 15.855681840330362, 14.87710515037179, 11.964510139077902, 7.1921775955706835, 1.391171256545931, 3.996335808187723, 14.027399495244026, 25.62777992337942, 41.061440259218216, 17.94043142348528, 30.806603729724884, 40.31906269490719, 36.04114204645157, 30.71723062545061, 25.055355839431286, 26.568497344851494, 23.03633227944374, 16.362362802028656, 23.71626779437065, 29.840497970581055, 29.408079273998737, 29.105053134262562, 26.98799293488264, 24.39815830439329, 22.67390202730894, 30.709560737013817, 35.33969968557358, 41.60439312458038, 38.77498134970665, 33.27019013464451, 20.24160124361515, 27.279475294053555, 26.832856759428978, 30.576009303331375, 46.87988184392452, 56.68830692768097, 38.02193395793438, 6.947801308706403, 1.1539027257822454, 56.52547426521778, 69.34812560677528, 57.27025710046291, 67.02847927808762, 67.99988195300102, 69.63479742407799, 67.89993211627007, 68.55089038610458, 68.23608487844467, 57.527978271245956, 57.90185160934925, 64.22785475850105, 35.226161777973175, 34.59926761686802, 15.33066876232624, 18.946720026433468, 105.66495805978775, 100.76126798987389, 78.22202503681183, 75.75681611895561, 46.63389824330807, 77.31898829340935, 72.13214501738548, 1.7581372777931392, 0.14003934804350138, 0.22525581676745787, 0.2421331751975231, 0.23140963108744472, 0.21848340751603246, 0.29258044087328017, 0.24475512356730178, 0.10707017223467119, 0.09433233542949893, 0.17875178949907422, 0.1911886705784127, 0.07001892445259728, 0.2827381674433127, 0.14387052215170115, 0.1172503009729553], [0.1269611029420048, 0.01349517438939074, 0.055149472536868416, 0.05695438310794998, 0.10481454795808531, 0.0348800205392763, 0.06292270874837413, 0.06356538637191989, 0.06252347040572204, 0.08807916237856261, 0.038534303748747334, 0.050140821767854504, 0.11787959767389111, 0.038204367156140506, 0.20066741039045155, 0.11120082519482821, 0.12586980446940288, 0.01815660023567034, 0.09872642855043523, 0.2321080514229834, 0.2664078905945644, 5.086035160347819, 64.05860424041748, 58.91200080513954, 39.18328084051609, 73.75902011990547, 61.86197631061077, 48.270797207951546, 59.883616268634796, 28.413623236119747, 52.76340253651142, 21.87639322131872, 39.4549510627985, 58.59959676861763, 66.13683432340622, 60.105060786008835, 58.79457950592041, 70.55737271904945, 65.98697796463966, 64.23774182796478, 65.50809726119041, 67.5076487660408, 72.56478980183601, 51.3771191239357, 9.51215498149395, 1.121678554918617, 4.125590622425079, 18.346498534083366, 29.2656572163105, 36.875649467110634, 60.62724016606808, 16.239139214158058, 11.267657931894064, 22.82856322824955, 26.733579486608505, 27.829503379762173, 30.144648849964142, 15.879912190139294, 7.271386245265603, 5.751977926120162, 13.758722562342882, 15.236089937388897, 12.099562492221594, 8.356791827827692, 10.513709038496017, 10.261736959218979, 16.210608445107937, 33.09709422290325, 21.79307509213686, 21.54439363628626, 25.504590533673763, 16.996634267270565, 18.149663396179676, 16.812978722155094, 8.810929208993912, 3.1728095607832074, 3.543734257109463, 2.2520158952102065, 1.390886390581727, 7.315765013918281, 13.463218118995428, 33.12979146838188, 33.94545570015907, 26.030594408512115, 21.35274711996317, 25.249206237494946, 31.256176605820656, 33.90066750347614, 32.67070010304451, 25.045339576900005, 30.635248124599457, 21.75657045096159, 20.027155950665474, 16.964527890086174, 16.899929456412792, 24.36756804585457, 23.306326791644096, 12.771853767335415, 6.745869219303131, 12.20138467848301, 4.602070329710841, 1.604676099959761, 0.5583408521488309, 2.126215808093548, 11.234157979488373, 12.037813905626535, 33.77143643796444, 20.499993078410625, 17.448365427553654, 29.413125403225422, 27.029627300798893, 28.657746836543083, 21.224228516221046, 17.65701223164797, 13.583759050816298, 15.660915691405535, 14.084075354039669, 14.422042518854141, 16.075168512761593, 22.237136363983154, 14.898957777768373, 15.740572717040777, 16.305622346699238, 20.497867092490196, 27.31011874973774, 31.253645941615105, 27.609854266047478, 35.53055204451084, 27.762248888611794, 27.99742966890335, 35.33804677426815, 26.053727567195892, 27.292542792856693, 34.76374179124832, 20.28286322951317, 9.924435708671808, 1.1095367814414203, 11.502662971615791, 60.325958132743835, 52.70200923085213, 59.34893935918808, 47.32842117547989, 57.820870354771614, 59.270712956786156, 60.60669846832752, 62.06897020339966, 54.134209379553795, 59.21707883477211, 47.43130065500736, 25.71871094405651, 25.370936505496502, 4.7946397215127945, 30.98003212362528, 74.89826738834381, 76.66921555995941, 77.44609147310257, 47.04513877630234, 34.46518421173096, 68.08065801858902, 23.770996257662773, 0.8862819580826908, 0.07633834902662784, 0.1904891518643126, 0.06466694874688983, 0.024793500742816832, 0.011935435086343205, 0.02319227631232934, 0.05713899234251585, 0.029838828450010624, 0.0808232142298948, 0.016999977924569976, 0.1358745785546489, 0.05813315110572148, 0.001561522892643552, 0.0899516603385564, 0.03964902811276261, 0.13309333560755476, 0.07578712626127526, 0.009682655090728076, 0.05152824829565361, 0.0365546767716296, 0.0753655492735561, 0.02591227908851579, 0.09279384845285676, 0.01759542341460474, 0.1053207743098028, 0.05721039808122441, 0.05390417099988554, 0.05888220817723777, 0.15144960139878094, 0.11109039362054318, 0.20433946803677827, 0.07708785880822688, 0.09638832198106684, 0.09904386737616733, 0.24627170234452933, 0.22416906023863703, 11.499891970306635, 84.34124708175659, 68.93686607480049, 50.20165599882603, 76.41944736242294, 58.50077927112579, 39.22814883291721, 45.717011243104935, 41.82061292231083, 46.73161759972572, 30.090587250888348, 51.800454407930374, 64.868895560503, 74.71451684832573, 67.78026133775711, 65.56380987167358, 74.61623132228851, 72.9172132909298, 68.66240680217743, 72.24846437573433, 72.26856529712677, 73.74599441885948, 60.739334151148796, 7.44558029808104, 2.7171050012111664, 18.004336394369602, 24.809510931372643, 33.872963190078735, 36.682657822966576, 74.44438934326172, 33.50499853491783, 17.161055244505405, 24.336932189762592, 25.574571378529072, 27.976500391960144, 30.740559473633766, 20.225769393146038, 7.956516081467271, 6.740883886814117, 6.9458686374127865, 12.509588990360498, 15.344244483858347, 8.458669111132622, 9.91815559566021, 12.780718691647053, 23.9215137809515, 32.49539650976658, 22.633844576776028, 21.982523426413536, 24.74269911646843, 23.196334093809128, 21.86873473227024, 21.033961325883865, 12.23881172016263, 5.476946784183383, 5.785000529140234, 2.827487178146839, 6.208256492391229, 27.83821251243353, 37.24928341805935, 47.96363689005375, 44.66887928545475, 33.3746313303709, 32.72384785115719, 34.601406902074814, 40.057602524757385, 40.9043300896883, 38.75378988683224, 34.666030034422874, 39.424400702118874, 31.91254958510399, 30.682264901697636, 25.735084265470505, 27.70292267203331, 32.67085589468479, 30.05591221153736, 17.27666974067688, 11.858551874756813, 5.697882603853941, 6.0666195675730705, 5.252756914123893, 0.48382907698396593, 2.166889775544405, 11.989740785211325, 19.41398285329342, 40.45347288250923, 17.534666396677494, 20.061287619173527, 33.227035850286484, 25.912770330905914, 25.022647194564342, 21.99905823916197, 18.440389595925808, 15.379443895071745, 18.61626885831356, 16.38946484774351, 12.787825260311365, 15.292709749192, 15.298881568014622, 7.812070157378912, 12.300959285348654, 15.440730806440115, 22.775263488292694, 25.483049489557743, 30.256096869707108, 26.246732510626316, 31.941325441002846, 22.817405126988888, 24.16835993528366, 29.422079622745514, 24.338719993829727, 31.190747916698456, 39.328539445996284, 22.38402508199215, 24.37118735164404, 7.032919116318226, 8.163580745458603, 60.007664412260056, 62.48342156410217, 68.8116703927517, 55.54453030228615, 64.07390981912613, 67.5233419239521, 65.77027559280396, 67.5820791721344, 58.5801912099123, 59.2853269726038, 56.21973127126694, 35.35700775682926, 31.82667799293995, 16.291975378990173, 37.168218567967415, 87.10888937115669, 74.74721029400826, 81.17081880569458, 57.732084318995476, 38.709085285663605, 77.08137944340706, 29.57110572606325, 1.2062826775945723, 0.16584429773502052, 0.1863317147945054, 0.03298744006315246, 0.1252686500083655, 0.028876838077849243, 0.060167129267938435, 0.04555362553219311, 0.055826426250860095, 0.06191730273712892, 0.04196879992377944, 0.10449306442751549, 0.03318012757517863, 0.025192586945195217, 0.027328771830070764, 0.0665211453451775, 0.17235153762158006, 0.1974614363280125, 0.0959076923027169, 0.21947582223219797, 0.17578689468791708, 0.22267726919380948, 0.30807963106781244, 0.2394537252257578, 0.1028616531402804, 0.16573443019296974, 0.12582011026097462, 0.1286421564873308, 0.15662802587030455, 0.2948070323327556, 0.23899110005004331, 0.32531559525523335, 0.36027276946697384, 0.24799523642286658, 0.2522155037149787, 0.5378531233873218, 0.23016760242171586, 18.429721668362617, 109.88513320684433, 76.3866475224495, 63.81072074174881, 84.86688047647476, 80.61093404889107, 72.23021775484085, 76.00587755441666, 44.33665931224823, 71.57216146588326, 29.28152896463871, 57.428393214941025, 67.1650743484497, 83.65656942129135, 77.8529204428196, 76.60730928182602, 79.58126530051231, 80.36580920219421, 70.60971111059189, 80.64651533961296, 78.41662779450417, 85.16051352024078, 71.44470110535622, 16.597461886703968, 2.2926366655156016, 11.60032058134675, 25.750602632761, 48.27572174370289, 50.44495314359665, 77.03034818172455, 22.58961495012045, 14.568826742470264, 29.947773814201355, 37.587708458304405, 37.304916232824326, 43.074807822704315, 22.991905063390732, 13.821376450359821, 13.22038359940052, 20.461550541222095, 21.57869439572096, 18.818104527890682, 13.180048763751984, 15.669942107051611, 15.106549188494682, 24.497332982718945, 46.86051428318024, 30.347899943590164, 30.319249480962753, 34.60515730082989, 27.381771504878998, 27.207537554204464, 31.434067860245705, 18.707306273281574, 9.12515714764595, 12.638397328555584, 7.7737468387931585, 5.442378139123321, 27.235597148537636, 37.61236913502216, 56.86268337070942, 53.71241681277752, 38.25223580002785, 39.419084787368774, 39.27931308746338, 46.49965524673462, 45.15491120517254, 46.607854440808296, 40.08551962673664, 45.02295948565006, 40.835158601403236, 38.30884136259556, 36.13348849117756, 38.7358358502388, 39.67498205602169, 29.14243172854185, 24.12515625357628, 27.18219481408596, 20.09457193315029, 13.36609248071909, 7.344028372317553, 0.4508194763911888, 2.5728659285232425, 14.299733731895685, 25.87613459676504, 50.42278133332729, 25.051918923854828, 32.09771364927292, 39.990270137786865, 35.45196086168289, 39.21084836125374, 25.579503513872623, 22.294023111462593, 18.222545385360718, 24.46626204997301, 22.174587920308113, 24.113200195133686, 25.224802047014236, 34.47159066796303, 21.456527151167393, 21.24647632241249, 22.130802869796753, 29.184514470398426, 36.643861904740334, 40.81443831324577, 33.471643924713135, 44.83358144760132, 35.64680680632591, 35.649200677871704, 43.62135909497738, 32.58218005299568, 35.30049338936806, 50.17310053110123, 22.96444583684206, 23.29357087612152, 5.588976172730327, 17.66146559268236, 72.14668303728104, 69.1207230091095, 70.28258666396141, 57.38530732691288, 67.23269551992416, 71.5263207256794, 67.86337047815323, 72.30956509709358, 62.74179250001907, 65.3040862083435, 57.30107344686985, 35.61286702752113, 36.79315209388733, 10.556669533252716, 42.978182807564735, 87.38157793879509, 82.25757569074631, 87.40312278270721, 67.21621200442314, 46.95090763270855, 86.19292572140694, 38.09954859316349, 1.261377464979887, 0.4253098421031609, 0.319032424595207, 0.15602653002133593, 0.18753678450593725, 0.12786457868060097, 0.09619141535949893, 0.15991551743354648, 0.13705711666261777, 0.33163370622787625, 0.15041672479128465, 0.2068965823855251, 0.19948813773225993, 0.20791518007172272, 0.17163342068670318, 0.16466275410493836], [0.05777972924988717, 0.07431271631503478, 0.09993162442697212, 0.039771263545844704, 0.1165088806010317, 0.01731960608594818, 0.05290533670631703, 0.05761245287430938, 0.14003090240294114, 0.07586209801957011, 0.14328323100926355, 0.05370944258174859, 0.05286194704240188, 0.11336792609654367, 0.04048514281748794, 0.17221388407051563, 0.04074928801856004, 0.029547221929533407, 0.029542353440774605, 0.06666276938631199, 0.24697472399566323, 0.6223274592775851, 28.084095418453217, 63.734010457992554, 36.541886776685715, 55.01274883747101, 90.09270966053009, 46.20545223355293, 64.61569234728813, 30.66786367446184, 45.516173020005226, 33.72230127453804, 27.14405246078968, 59.34617690742016, 47.880075573921204, 69.41589877009392, 65.38836568593979, 65.47756969928741, 74.4373369216919, 67.14381828904152, 63.5779832303524, 63.94664704799652, 71.9162406027317, 19.063221774995327, 0.35147900227457285, 0.48430037044454366, 13.88508478179574, 35.38881964981556, 35.62165215611458, 29.65579178184271, 12.595804464071989, 12.019044812768698, 31.669421531260014, 30.085987597703934, 30.654967166483402, 26.071598008275032, 27.4168037250638, 22.653951197862625, 8.051045034080744, 3.8169500464573503, 11.80792624130845, 18.179271407425404, 13.784200195223093, 10.776930414140224, 13.417165540158749, 13.524000607430935, 14.002458583563566, 39.778754487633705, 27.431385442614555, 16.165947541594505, 31.91160723567009, 16.670940443873405, 22.758987061679363, 19.225043691694736, 10.02333015203476, 2.4444233207032084, 3.693157914094627, 1.5999423852190375, 0.26132815692108124, 0.8181267965119332, 3.579161656089127, 21.798368208110332, 28.652429021894932, 32.26537965238094, 22.711419314146042, 22.65709362924099, 27.35569730401039, 34.25808012485504, 28.425909876823425, 21.74822609871626, 28.82582701742649, 21.23873233795166, 20.249231234192848, 15.054840613156557, 17.95052368193865, 25.82594309002161, 18.567359782755375, 11.190208587795496, 10.922976527363062, 13.000745885074139, 5.509944688528776, 1.0384101793169975, 0.6980477774050087, 2.635814775712788, 8.442851509898901, 12.280491683632135, 39.6212263405323, 26.066171899437904, 15.932156536728144, 24.827100187540054, 25.038135163486004, 30.431210473179817, 21.20268937200308, 29.31520275771618, 20.01912698149681, 14.140962101519108, 15.121230650693178, 14.55016404390335, 15.840512104332447, 15.871391147375107, 7.7155007142573595, 9.972058553248644, 15.663499552756548, 25.51281899213791, 35.02094618976116, 36.324215456843376, 36.00174956023693, 40.12234345078468, 37.500867918133736, 38.213010504841805, 23.814927600324154, 25.27827087789774, 27.56983481347561, 38.85039210319519, 18.09981007128954, 13.813557419925928, 5.183863760903478, 2.642244268208742, 27.9178524389863, 39.876606836915016, 58.43111380934715, 59.97179053723812, 55.684457793831825, 59.180699586868286, 61.444872692227364, 60.060340985655785, 57.39714749157429, 67.90516823530197, 41.72374092042446, 25.59914655983448, 34.995240569114685, 11.17772150784731, 50.223204642534256, 59.27118793129921, 73.82814601063728, 76.63629412651062, 44.75125886499882, 37.53377415239811, 55.91745749115944, 6.523107597604394, 0.010854904248844832, 0.19545419403584674, 0.1344508572947234, 0.07134093437343836, 0.03349555146996863, 0.06477267510490492, 0.025469107458775397, 0.05234816562733613, 0.06087121590098832, 0.04643375701562036, 0.09141966555034742, 0.08166318439180031, 0.04190105297311675, 0.0691267590445932, 0.09941720476490445, 0.2011089734151028, 0.04289256226911675, 0.06146646657725796, 0.12070317272446118, 0.00669242335789022, 0.05205652014410589, 0.055431395885534585, 0.0573662750684889, 0.05430303455796093, 0.08265464915893972, 0.08884912575013004, 0.05927805490500759, 0.038178993127075955, 0.02346878383832518, 0.16600485396338627, 0.04017856532300357, 0.1456445371150039, 0.08022135472856462, 0.04104741616174579, 0.028982499497942626, 0.1492145939846523, 0.2579143666662276, 1.7315218434669077, 54.13986727595329, 77.91633144021034, 44.48014721274376, 56.68011076748371, 82.78024524450302, 46.01889364421368, 44.88655440509319, 36.723346039652824, 46.636459305882454, 34.41661901772022, 41.903144493699074, 64.57937389612198, 56.475244760513306, 76.34443178772926, 70.2577055990696, 72.29169085621834, 83.18224087357521, 71.50636419653893, 70.83033487200737, 67.52896562218666, 77.76899814605713, 24.907298684120178, 0.4167977051110938, 8.166116159409285, 23.64392727613449, 37.405109256505966, 39.13501963019371, 35.53393006324768, 22.076093405485153, 15.677645243704319, 28.08372113853693, 28.324960693717003, 27.188707664608955, 24.459663704037666, 25.604859553277493, 23.133040890097618, 11.193059384822845, 5.1254110224545, 10.62063055112958, 9.973644968122244, 14.204488042742014, 11.222490705549717, 14.900989718735218, 15.102143324911594, 21.442414708435535, 45.31178578734398, 24.244937226176262, 17.531235180795193, 32.824139669537544, 23.531251922249794, 25.349023081362247, 24.888170510530472, 15.17959551885724, 4.857749585062265, 5.479236636310816, 4.791207080706954, 0.355778619996272, 5.626786993816495, 14.192701075226068, 33.71420010924339, 37.45133377611637, 35.44509083032608, 28.150329664349556, 33.34297902882099, 32.501730769872665, 43.3259629458189, 35.057469829916954, 33.87793332338333, 37.508319318294525, 32.714017778635025, 29.318713769316673, 26.911864019930363, 27.333947271108627, 32.32374832034111, 27.110260874032974, 19.266545064747334, 16.05250082910061, 13.328414652496576, 5.490648373961449, 1.5502064977772534, 0.9182951808907092, 2.2016180120408535, 10.013459231704473, 22.1835820376873, 43.24591264128685, 23.523794822394848, 18.889580592513084, 29.208525381982327, 28.305676728487015, 27.70082898437977, 21.428855136036873, 26.25761892646551, 20.56521087884903, 18.05035002529621, 16.39754891395569, 15.631017945706844, 12.902344465255737, 8.999902568757534, 4.46050607599318, 9.221849609166384, 17.883291989564896, 25.007712095975876, 30.074523612856865, 33.31077195703983, 29.514433667063713, 34.12579782307148, 31.146886870265007, 35.16419090330601, 26.998379677534103, 24.012148417532444, 27.653113044798374, 41.05545558035374, 21.175030656158924, 20.106972567737103, 20.330296084284782, 5.629854379221797, 20.688784047961235, 50.03598868846893, 60.239383578300476, 65.40436282753944, 63.691752925515175, 67.44014158844948, 66.15869835019112, 66.08875170350075, 61.942448392510414, 68.51698100566864, 50.20271994173527, 34.13937449455261, 36.53533212840557, 18.67471542209387, 73.72668385505676, 74.40350353717804, 73.75217288732529, 85.52524834871292, 48.1140898168087, 41.31503105163574, 70.50525471568108, 9.292588513344526, 0.14255139918532223, 0.26296580967027694, 0.08282638213131577, 0.04828736731724348, 0.029406447647488676, 0.013855895267624874, 0.024471371543768328, 0.17233844613656402, 0.06168467283714563, 0.034346000757068396, 0.02678157892660238, 0.014447527973970864, 0.09560701859300025, 0.11841634113807231, 0.07940410170704126, 0.08888945405487902, 0.2738197788130492, 0.14429445174755529, 0.24545548832975328, 0.09465965966228396, 0.20681399619206786, 0.10079975909320638, 0.1500660748570226, 0.16356352949514985, 0.30121277610305697, 0.12441760700312443, 0.1976380674750544, 0.25445322738960385, 0.24079517199425027, 0.23255883192177862, 0.07819796330295503, 0.47825851652305573, 0.18797781318426132, 0.3222381166415289, 0.11521780339535326, 0.25749935768544674, 0.3345889085903764, 2.8337181312963367, 77.59693577885628, 90.3369377553463, 53.583493530750275, 74.06086072325706, 98.55823740363121, 69.79912340641022, 86.74937546253204, 42.13172122836113, 64.586251527071, 41.02324850857258, 42.99723118543625, 70.73103860020638, 63.8902048766613, 84.04490858316422, 78.2635036110878, 79.78617310523987, 81.94512605667114, 78.9688141644001, 76.99596002697945, 74.42443281412125, 86.76748529076576, 33.32562156021595, 0.526858294615522, 5.609901649877429, 22.589269168674946, 52.11455695331097, 48.45748879015446, 40.09034916758537, 19.996723383665085, 17.54147183150053, 44.37361992895603, 41.4391665905714, 40.77182739973068, 34.52840521931648, 35.80254524946213, 30.396622829139233, 14.42028321325779, 10.248519368469715, 21.502688974142075, 29.180026911199093, 22.173404283821583, 16.699666902422905, 19.751110263168812, 18.995980583131313, 20.90260997414589, 53.94545070827007, 38.85949641466141, 22.726633697748184, 47.72952005267143, 27.00545869767666, 30.17051786184311, 36.89770348370075, 21.9985718652606, 6.596530107781291, 10.137431379407644, 8.807041067630053, 0.45261431601829827, 3.4607704589143395, 10.408657975494862, 36.49590544402599, 50.2509393543005, 45.280946642160416, 34.21434827148914, 41.81769087910652, 41.0344123095274, 49.521059319376945, 42.32046090066433, 40.30382551252842, 48.269072100520134, 39.6519210934639, 42.08246447145939, 36.937160566449165, 40.41832856833935, 40.528731644153595, 28.202664256095886, 25.863825157284737, 29.206595085561275, 17.50228263437748, 9.141689110547304, 4.845254430547357, 0.749651858350262, 2.4596749898046255, 11.782200671732426, 26.13031055778265, 51.2357173115015, 34.37460847198963, 32.68125593662262, 39.28520277142525, 37.295910716056824, 39.283040687441826, 28.90971891582012, 34.00506690144539, 25.90409729629755, 21.646437160670757, 24.163716584444046, 24.198085740208626, 26.15848794579506, 27.323089353740215, 15.794030148535967, 15.612287800759077, 21.693864315748215, 32.92318515479565, 43.44031020998955, 45.735569447278976, 47.01134338974953, 49.07794989645481, 46.88368164002895, 47.56801351904869, 31.135194897651672, 29.108372256159782, 34.57236886024475, 52.46777839958668, 28.363870605826378, 18.079072684049606, 17.732626274228096, 8.503009881824255, 44.3156274408102, 60.78561566770077, 70.23662433028221, 69.72811281681061, 66.61206722259521, 68.62832263112068, 70.06431877613068, 70.60863956809044, 64.33430224657059, 72.98723593354225, 51.34559981524944, 34.52132239937782, 45.23096792399883, 14.462621491402388, 64.39672529697418, 68.274956792593, 85.16141027212143, 90.74311316013336, 65.9040816128254, 49.46797996759415, 82.83705979585648, 12.052805051207542, 0.4648324119625613, 0.4230017034569755, 0.32041759870480746, 0.16291705949697644, 0.07456924708094448, 0.1674732525134459, 0.19443230121396482, 0.23201008792966604, 0.14529130450682715, 0.17346567939966917, 0.11715005166479386, 0.1753892222768627, 0.15744312666356564, 0.2655015204800293, 0.21493482840014622, 0.3304040268994868], [0.05794389231596142, 0.12215247581480071, 0.06721471945638768, 0.03506939065118786, 0.011247041165916016, 0.07308024651138112, 0.040462551842210814, 0.06722761056153104, 0.048602301394566894, 0.053659952463931404, 0.20131496392423287, 0.0404022671864368, 0.051297555401106365, 0.0492324404331157, 0.06116341428423766, 0.15575230645481497, 0.1843123309663497, 0.06594353922992013, 0.021412151618278585, 0.19126290018903092, 0.17028456728439778, 0.7098605122882873, 14.43960327655077, 62.666674330830574, 59.467204213142395, 68.5321193933487, 86.1611670255661, 73.92517000436783, 54.41524229943752, 57.03164130449295, 38.78878980875015, 41.81311972439289, 22.589918933808804, 56.277818754315376, 59.61237922310829, 74.11699131131172, 63.35767865180969, 68.96822959184647, 68.49181115627289, 61.9633586704731, 66.88775762915611, 68.57492789626122, 46.3923604041338, 13.505547847598791, 0.4518590174848214, 11.487099956721067, 39.72903415560722, 33.38251210749149, 31.86219848692417, 30.06509441882372, 33.73036824166775, 34.49419945478439, 32.36865811049938, 29.43903811275959, 29.139306396245956, 28.76351036131382, 28.02775204181671, 24.948887452483177, 10.616533420979977, 5.284316120669246, 7.2826179675757885, 15.931607466191053, 15.404604244977236, 12.427700534462929, 11.681470926851034, 21.124825850129128, 19.76861782371998, 22.38296303898096, 24.890087507665157, 17.522653341293335, 26.081984750926495, 20.86644161492586, 27.955035343766212, 23.684643991291523, 10.144203566014767, 2.8118571918457747, 2.6905223401263356, 0.36977546580601484, 0.4544283327413723, 1.0081762704066932, 1.4040710893459618, 10.81668483093381, 19.700251892209053, 24.211119040846825, 25.153139792382717, 21.253990419209003, 21.823315769433975, 31.932046338915825, 23.221249356865883, 19.018365181982517, 27.743538692593575, 24.297936782240868, 18.62668599933386, 15.748291052877903, 19.3479385972023, 22.81530573964119, 12.066983040422201, 4.730587033554912, 2.4824683042243123, 11.859748810529709, 3.912982768379152, 1.0148578556254506, 0.7274654426146299, 1.0967197129502892, 7.421890944242477, 15.829232409596443, 39.942472502589226, 32.48652398586273, 17.25839462131262, 24.80160165578127, 17.668782100081444, 29.676787555217743, 27.84552711993456, 26.79303679615259, 22.621491439640522, 18.03189441561699, 17.05721441656351, 11.829683873802423, 15.675618052482605, 7.789391074329615, 6.318518025800586, 9.123787321150303, 16.555344946682453, 26.92202277481556, 34.65225577354431, 33.85165773332119, 38.40610474348068, 34.643512442708015, 35.256115570664406, 27.872859053313732, 25.69025617092848, 32.3663554340601, 23.255939595401287, 34.69296678900719, 41.54707320034504, 18.21416113525629, 24.906616620719433, 7.609658818691969, 3.082514056004584, 38.38299058377743, 32.15390503406525, 35.48200584948063, 44.00017976760864, 58.40771846473217, 67.01597794890404, 57.81977981328964, 61.136519238352776, 76.62508472800255, 42.98265516757965, 29.462308064103127, 43.52297477424145, 25.400804802775383, 20.451507680118084, 55.98271518945694, 70.29755786061287, 68.28368112444878, 50.85941210389137, 47.335800379514694, 47.684306278824806, 2.869468512944877, 0.06371636889525689, 0.32827421149704605, 0.04900482374068815, 0.028723167124553584, 0.04005075265013147, 0.05083923468191642, 0.0929076864849776, 0.025209090454154648, 0.04745182035549078, 0.06342719847452827, 0.09668229409726337, 0.12562093266751617, 0.010028478282038122, 0.04615971527528018, 0.058592792847775854, 0.10375594851211645, 0.10992882118443958, 0.018427435898047406, 0.01819662797061028, 0.06734877359122038, 0.07213390432298183, 0.05813007490360178, 0.04042400840262417, 0.04987381187675055, 0.06005343595461454, 0.058103168339584954, 0.26166820898652077, 0.04311691351176705, 0.1406828939798288, 0.11227440118091181, 0.10036099396529607, 0.1595017107320018, 0.3827472572447732, 0.015921930498734582, 0.12979033315787092, 0.07536405755672604, 0.5720194056630135, 0.36008628259878606, 29.90691840648651, 82.91011467576027, 65.94594776630402, 76.4074020087719, 85.99547311663628, 70.34399896860123, 47.66076274216175, 47.08626016974449, 42.22212217748165, 37.99066923558712, 37.5018672645092, 65.01999825239182, 69.63471382856369, 78.33830639719963, 71.34944021701813, 76.39023452997208, 76.23697355389595, 66.00307390093803, 71.70244887471199, 68.99118795990944, 60.72437435388565, 18.46754863858223, 1.8207547115162015, 19.34944711625576, 45.095660984516144, 44.09299358725548, 37.453043684363365, 28.921849764883518, 31.859407536685467, 31.20138354599476, 30.025017969310284, 28.641362115740776, 28.043458499014378, 28.40681780129671, 27.16946169734001, 25.099287182092667, 16.25771451741457, 6.436851276084781, 10.537677202373743, 9.33041738346219, 13.827518820762634, 13.773019295185804, 13.764850683510303, 21.912094205617905, 24.186065085232258, 31.277637854218483, 34.058290645480156, 16.371657103300095, 29.391536861658096, 29.05614785850048, 33.31481494009495, 31.71349346637726, 15.956858061254025, 3.581460057757795, 3.5549351060763, 2.2319266106933355, 0.6255252845585346, 0.7536212797276676, 8.086765017360449, 19.99406162649393, 35.07500968873501, 36.18551529943943, 33.239092603325844, 29.36475209891796, 31.155132427811623, 40.755150094628334, 31.432190760970116, 29.971319250762463, 38.33762861788273, 34.4449806958437, 29.73170030862093, 26.67086385190487, 26.39432419091463, 27.233712449669838, 20.148008465766907, 14.082586783915758, 18.42440765351057, 14.834028761833906, 6.706273918971419, 1.9543979340232909, 0.6257073185406625, 0.6647106225136667, 6.644335342571139, 25.137022957205772, 46.2060260027647, 33.49413491785526, 19.386565424501896, 29.75216221064329, 22.833552360534668, 29.097508639097214, 22.319998517632484, 26.48748379200697, 24.022799246013165, 18.252290189266205, 17.91544396430254, 15.498812589794397, 10.664975121617317, 6.155692962929606, 4.78675989434123, 10.54024776443839, 19.21045247465372, 24.766654931008816, 34.81049448251724, 27.331992276012897, 33.82138095796108, 30.15066772699356, 31.827076971530914, 28.782845623791218, 27.008107155561447, 26.921297013759613, 21.87584225088358, 36.55854128301144, 38.42131532728672, 19.252464920282364, 44.88611362874508, 26.593262515962124, 4.56268971785903, 43.758379742503166, 43.02040234208107, 42.6787056773901, 47.4532824754715, 61.63135148584843, 71.65355309844017, 64.04249310493469, 63.49678538739681, 73.02027136087418, 52.531026005744934, 34.16065335273743, 40.80393187701702, 24.413701370358467, 36.84481792151928, 57.84429229795933, 79.86374974250793, 67.23851680755615, 54.72061671316624, 50.097758173942566, 60.24477168917656, 3.9754751650616527, 0.13351787376450375, 0.4964985471451655, 0.03935744571208488, 0.1198272529290989, 0.030543603425030597, 0.0462951349618379, 0.03780652776185889, 0.06931062613148242, 0.09975201726774685, 0.10174581926548854, 0.020977726198907476, 0.09573713192366995, 0.02169533290725667, 0.02868179424694972, 0.07326348277274519, 0.038660550490021706, 0.17610757669899613, 0.27574473177082837, 0.15928329667076468, 0.24753222533036023, 0.13971731532365084, 0.16606388438958675, 0.08831284241750836, 0.16331067978171632, 0.16092243371531367, 0.18873201333917677, 0.3667552216211334, 0.08358671984751709, 0.22421933332225308, 0.21762273885542527, 0.19502493581967428, 0.38553791062440723, 0.5693932715803385, 0.3287851653294638, 0.14145413384540007, 0.44665822468232363, 0.5062048591207713, 1.097033314872533, 42.71447695791721, 103.55368494987488, 72.55093574523926, 87.23933637142181, 98.02915379405022, 91.52269452810287, 78.70151370763779, 68.52137356996536, 60.25596968829632, 51.013999208807945, 35.87359383702278, 67.62557923793793, 71.34025990962982, 88.93286749720573, 72.66877502202988, 82.18552395701408, 77.75801673531532, 70.72333261370659, 78.32682341337204, 75.98154366016388, 68.42969208955765, 25.26792973279953, 1.726730775553733, 21.14694446325302, 49.96125429868698, 51.20265528559685, 43.77333953976631, 42.67643719911575, 46.13230235874653, 49.26056049764156, 42.01019234955311, 40.31997084617615, 39.68804955482483, 37.828018963336945, 39.12562653422356, 33.83167080581188, 15.643338784575462, 12.112494148314, 17.098174318671227, 26.390459798276424, 24.512874148786068, 19.505195058882236, 18.34907289594412, 26.145794726908207, 31.018632352352142, 28.34447454661131, 35.107668936252594, 25.28458423912525, 40.35033501684666, 35.81560134887695, 38.156587332487106, 39.5759441703558, 22.255170196294785, 7.4103989358991385, 7.840058030560613, 3.441900433972478, 0.9660051832906902, 7.236028192564845, 10.03756893798709, 23.611249029636383, 42.789006158709526, 39.536103308200836, 42.505997344851494, 39.13001909852028, 38.664221093058586, 44.453347250819206, 39.65213768184185, 38.173838406801224, 47.850467562675476, 43.462748005986214, 39.78956490755081, 36.84266723692417, 39.41416785120964, 32.59290687739849, 23.189688250422478, 17.391129098832607, 26.96640059351921, 15.708416942507029, 8.120245970785618, 2.3825455410405993, 0.8257828513160348, 0.5508975859265774, 8.043452091515064, 33.20804066956043, 50.45333929359913, 42.32074588537216, 34.0866257250309, 41.88662298023701, 32.10725113749504, 39.180370196700096, 34.07980889081955, 31.24311100691557, 30.120759531855583, 23.30580811947584, 26.47580511868, 18.732725009322166, 27.438057884573936, 15.652252156287432, 15.437697619199753, 14.018684662878513, 22.795199118554592, 34.540446773171425, 43.31085115671158, 40.57693585753441, 48.86674202978611, 41.93937934935093, 43.188539519906044, 33.271687254309654, 34.40567560493946, 36.78098514676094, 29.19977255165577, 47.640460431575775, 55.71449518203735, 23.66690844297409, 35.03956899046898, 20.531654879450798, 12.584337629377842, 63.81545528769493, 50.979364067316055, 50.348890498280525, 54.214369878172874, 71.21346071362495, 75.00650838017464, 67.67319068312645, 68.02626013755798, 82.19167202711105, 53.490402325987816, 37.91042894124985, 56.54129661619663, 33.71063970029354, 30.270940773189068, 67.9669301211834, 90.78855872154236, 73.34738060832024, 63.86455625295639, 57.1732597053051, 76.75269708037376, 3.6648705694824457, 0.27102063526399434, 0.4822885268367827, 0.16055682208389044, 0.3711034945445135, 0.13372197921853513, 0.1895912125473842, 0.18792810413287953, 0.13407302991254255, 0.17033645824994892, 0.2327258448349312, 0.17560846754349768, 0.26276976394001395, 0.0965346438169945, 0.1558816627948545, 0.17380386125296354, 0.2101948350900784], [0.046423251915257424, 0.07520396145991981, 0.09797449194593355, 0.03181489126291126, 0.03963365081290249, 0.02101369624142535, 0.09837223857175559, 0.11501426197355613, 0.11203912552446127, 0.05786965157312807, 0.0662510258553084, 0.036320551444077864, 0.10788586674607359, 0.208274275646545, 0.11938097726670094, 0.1070166782301385, 0.043022000245400704, 0.0886311792419292, 0.04830243291507941, 0.0830444399616681, 0.09623146906960756, 0.23675701289903373, 4.060292551293969, 61.65969416499138, 68.83555591106415, 54.44064013659954, 75.42010858654976, 94.63475033640862, 56.315007358789444, 62.36986465752125, 43.72750259935856, 50.514656603336334, 24.421281963586807, 62.16899983584881, 70.60240790247917, 73.33213582634926, 69.75315347313881, 61.35963946580887, 66.22641831636429, 73.13276052474976, 70.17233937978745, 62.768626660108566, 52.9646435379982, 9.960511922836304, 1.4777621976099908, 27.061762176454067, 33.14502865076065, 30.448377951979637, 33.983609452843666, 42.09356747567654, 27.63496521860361, 23.77897582948208, 28.42678762972355, 28.736178427934647, 27.003224417567253, 24.819050319492817, 25.36169160157442, 28.735519163310528, 13.672097660601139, 5.151651464402676, 8.37078457698226, 13.722771741449833, 14.44170456379652, 13.51795133203268, 18.76968752592802, 18.63683145493269, 29.57943867892027, 18.29032614827156, 10.505264941602945, 18.17354891449213, 29.37869355082512, 27.497216910123825, 32.3366866260767, 31.506461575627327, 12.794024627655745, 2.9547257255762815, 2.046413915231824, 1.022082099225372, 1.6717573441565037, 4.916953258216381, 6.340491296723485, 7.920513488352299, 18.048250637948513, 18.299335464835167, 28.48638743162155, 24.737749882042408, 18.506646640598774, 29.534126110374928, 20.12439463287592, 18.716644272208214, 25.749772377312183, 23.71676366776228, 16.29075564444065, 16.407627873122692, 18.69371060281992, 19.21690072864294, 6.089010816067457, 4.252132857218385, 2.8840131824836135, 3.169398056343198, 0.5276171257719398, 0.21822643146151677, 0.26424634095747024, 0.8778316271491349, 6.498784627765417, 26.0041269287467, 44.445432275533676, 28.741038367152214, 16.04246936738491, 27.634678333997726, 19.62956428527832, 19.593356028199196, 29.626651145517826, 21.462642922997475, 25.28849422931671, 22.46584229171276, 17.06781964749098, 15.887885112315416, 15.954610481858253, 7.088450761511922, 5.50561529584229, 9.259206354618073, 20.23662731051445, 24.224974997341633, 23.188139833509922, 26.835613511502743, 25.232027359306812, 25.477064810693264, 30.37166576832533, 29.4649014249444, 34.365435764193535, 32.983088940382004, 30.115265026688576, 22.159428633749485, 45.916340947151184, 37.51216471195221, 14.982796479016542, 6.251486297696829, 2.9842370795086026, 15.042831357568502, 32.02973149716854, 24.78494144976139, 24.679975882172585, 28.472938053309917, 48.548357114195824, 66.11601904034615, 63.54678690433502, 71.6777653992176, 31.603848449885845, 31.107393689453602, 42.35073767602444, 33.97603265941143, 33.81268322467804, 56.22196935117245, 63.97250846028328, 76.8488547205925, 49.89199921488762, 55.386914759874344, 27.657691799104214, 0.3544150572270155, 0.07820714366971515, 0.13965883408673108, 0.0699870492098853, 0.09628502244595438, 0.04273343467502855, 0.05737259445595555, 0.026164718765357975, 0.020722930203191936, 0.02563378631748492, 0.025050593685591593, 0.02274918446346419, 0.1363060186849907, 0.05975504434900358, 0.0725094236258883, 0.10904919065069407, 0.03933958963898476, 0.04283103822672274, 0.042777280759764835, 0.030391791551664937, 0.07586762701976113, 0.04662768391426653, 0.03815679177932907, 0.08100265811663121, 0.06815489439759403, 0.10420119258924387, 0.045384193217614666, 0.1996705131023191, 0.1134361072035972, 0.18817188480170444, 0.12141700004576705, 0.15299279359169304, 0.08271344209788367, 0.13929904089309275, 0.13089610351016745, 0.0797460981993936, 0.058283532489440404, 0.46534013003110886, 0.09169085373287089, 7.980683259665966, 84.46512043476105, 75.33638387918472, 69.43647086620331, 83.13503220677376, 87.0640441775322, 50.80437205731869, 47.273118942976, 40.02870127558708, 44.486952647566795, 36.16642512381077, 68.98362636566162, 78.36337745189667, 80.88662445545197, 80.70171117782593, 66.39975741505623, 68.3310341835022, 77.14354410767555, 74.05256196856499, 66.61825329065323, 64.89114716649055, 11.696902848780155, 5.379147632047534, 44.77643631398678, 40.03253906965256, 35.274491384625435, 31.667751520872116, 41.74183554947376, 25.897293761372566, 24.790787436068058, 27.311372682452202, 25.760915279388428, 25.156960487365723, 20.37313688546419, 23.323473371565342, 27.220086380839348, 17.44286522269249, 9.803302958607674, 11.12064952030778, 13.18209495395422, 8.732444420456886, 13.766583390533924, 21.00521206855774, 20.55408887565136, 29.87475123256445, 21.0950031504035, 19.567808099091053, 18.573008179664612, 34.48855295777321, 34.26950991153717, 37.748090252280235, 36.70889921486378, 21.041847802698612, 4.1105481795966625, 3.6355591798201203, 0.8430282259359956, 0.5960556690115482, 4.066148512065411, 3.8531499914824963, 11.780850794166327, 22.716841623187065, 27.117712274193764, 36.99506185948849, 33.051306679844856, 27.855625078082085, 37.05110885202885, 29.2709294334054, 29.538119696080685, 38.436214327812195, 32.06474281847477, 28.287293314933777, 25.93443486839533, 24.774062633514404, 25.476722829043865, 10.225510653108358, 7.9654318280518055, 7.738041579723358, 7.121383119374514, 2.0947879320010543, 0.5965978524181992, 0.5174696515314281, 1.3321855966933072, 6.164694204926491, 26.896463446319103, 51.65833443403244, 34.67185892164707, 17.444770820438862, 39.956337958574295, 25.221439227461815, 25.183743350207806, 23.538019359111786, 23.76568604260683, 24.309640154242516, 22.594423592090607, 20.49654856324196, 14.90244884043932, 9.659771360456944, 7.976019009947777, 11.072813887149096, 13.293985649943352, 20.883166417479515, 24.629263803362846, 20.996666327118874, 23.09694852679968, 23.46824560314417, 21.65678970515728, 29.532684087753296, 24.871715493500233, 28.679992742836475, 31.749162152409554, 25.324949473142624, 24.929451495409012, 46.69846437871456, 35.445292219519615, 19.06985241919756, 17.52799965441227, 12.802821155637503, 21.392371393740177, 38.550846576690674, 32.827700078487396, 33.00051860511303, 30.712304189801216, 51.56283795833588, 69.16470944881439, 68.96595731377602, 68.25914204120636, 42.830636724829674, 32.05357141792774, 34.08877640962601, 28.775323927402496, 30.654471293091774, 56.108294650912285, 70.26167258620262, 80.56785196065903, 56.87187887728214, 59.2981930822134, 36.38406604528427, 0.6787501566577703, 0.07219591076136567, 0.2812446397729218, 0.05305749553372152, 0.07640983269084245, 0.0484916397545021, 0.025271803788200486, 0.06957722784136422, 0.05590445194684435, 0.00537094407263794, 0.0564844737527892, 0.03170881238474976, 0.09430503923795186, 0.026507913826208096, 0.039066850367817096, 0.08545221193344332, 0.05779916980827693, 0.09251763593056239, 0.22837959055323154, 0.14702965185279027, 0.15059302939334884, 0.21572160883806646, 0.08641573484055698, 0.31583079951815307, 0.19041377934627235, 0.2172865014290437, 0.1617559842998162, 0.28495528909843415, 0.24244138912763447, 0.21959958277875558, 0.20878257259028032, 0.19576349150156602, 0.15447524841874838, 0.2566199720604345, 0.28248637157958, 0.1905528429779224, 0.34512396203354, 0.6498181528877467, 0.23987949534785002, 14.45627773180604, 105.484748929739, 81.27141460776329, 75.0557005405426, 90.50520792603493, 105.24418383836746, 78.46825182437897, 77.73727744817734, 58.733357191085815, 62.765522226691246, 35.070727318525314, 78.29405397176743, 80.93869686126709, 88.23793038725853, 84.79523152112961, 75.27917414903641, 75.03500685095787, 82.93274626135826, 79.52856972813606, 71.53519704937935, 72.27683365345001, 14.502357859164476, 6.010626722127199, 38.80430817604065, 44.35951128602028, 43.611734211444855, 41.994658783078194, 57.92465798556805, 36.54477082192898, 32.77506150305271, 39.53094318509102, 39.79603596031666, 35.713155046105385, 33.15267764031887, 32.90919050574303, 37.00900711119175, 19.67046909034252, 12.684561051428318, 17.635345794260502, 25.452086851000786, 25.58658253401518, 19.63609043508768, 25.432500801980495, 24.121276661753654, 40.81413812935352, 23.366908840835094, 15.146552491933107, 26.73367638140917, 47.062123864889145, 42.88762986660004, 42.11792416870594, 44.93313990533352, 30.02763032913208, 6.725280024111271, 7.817480592057109, 3.0631700064986944, 2.5931364158168435, 15.235310979187489, 18.44353772699833, 18.571132980287075, 29.967135675251484, 32.3129341006279, 43.19754883646965, 42.166557759046555, 39.7643418610096, 46.779126450419426, 39.06359106302261, 38.575362861156464, 45.82028590142727, 42.557499781250954, 41.678637340664864, 37.06396736204624, 37.635464295744896, 26.98082271963358, 15.666810125112534, 12.600574158132076, 10.935702044516802, 5.234034368768334, 1.2564084003679454, 0.3049045451916754, 1.2973086931742728, 1.6556838504038751, 9.371277540922165, 34.926046282052994, 58.58929932117462, 39.05977986752987, 31.119630932807922, 54.363587871193886, 36.52456730604172, 31.12005650997162, 39.21439737081528, 29.444401524960995, 32.96692080795765, 28.78178548067808, 24.94958471506834, 24.003376588225365, 24.57374308258295, 16.985504664480686, 15.038085412234068, 13.587055373936892, 31.278426311910152, 32.214443385601044, 29.413701072335243, 33.13387244939804, 33.62373076379299, 33.58855985105038, 38.05301249027252, 35.71260027587414, 40.85111394524574, 41.32910929620266, 36.11027553677559, 32.30978026986122, 62.039905562996864, 50.49707114696503, 20.22217858582735, 13.872262369841337, 13.620353937149048, 33.65909166634083, 48.99396300315857, 37.459089159965515, 43.267731070518494, 41.217053309082985, 60.26563256978989, 72.51642599701881, 72.1755538880825, 75.04664942622185, 44.06794533133507, 38.43504399061203, 54.57728460431099, 44.19420875608921, 45.379912331700325, 72.45078071951866, 81.37205600738525, 89.99991863965988, 59.31753784418106, 68.50547522306442, 45.27273528277874, 0.482632527127862, 0.15969110681908205, 0.32589981390628964, 0.14101699402090162, 0.3048108861548826, 0.1705805357778445, 0.14197841665009037, 0.10836144982022233, 0.16318522713845596, 0.12454753479687497, 0.21360708167776465, 0.08365044806851074, 0.1912328283651732, 0.1822805087431334, 0.09136445718468167, 0.29164714564103633, 0.12176952019217424], [0.02717209888942307, 0.03988482698332518, 0.10568090889137238, 0.08220315619837493, 0.09447300952160731, 0.04821198737772647, 0.03924586751963943, 0.03215094315237366, 0.09226086767739616, 0.048874049898586236, 0.12248229366377927, 0.070894480595598, 0.1374110468896106, 0.18352307175518945, 0.02484104086761363, 0.1484739306033589, 0.1394108380191028, 0.03994602077000309, 0.059963057210552506, 0.012012200058961753, 0.12888466066215187, 0.2821864845464006, 0.59706243686378, 46.22822441160679, 84.2435771226883, 52.93761558830738, 63.36208641529083, 104.8793426156044, 68.00518646836281, 65.26843652129173, 52.97274850308895, 48.74585151672363, 27.907625287771225, 59.0900744497776, 89.39816012978554, 66.98744148015976, 74.52268794178963, 68.63313317298889, 79.83658879995346, 75.21055743098259, 67.69834533333778, 65.37065103650093, 43.83782587945461, 8.953093830496073, 8.190987724810839, 22.140410654246807, 36.694988161325455, 38.413540944457054, 39.4887388497591, 35.28798446059227, 36.04772329330444, 30.329334139823914, 29.297224022448063, 25.278654657304287, 26.143501549959183, 28.438283912837505, 22.070952281355858, 29.739809073507786, 23.412449397146702, 5.6196714006364346, 7.267694743350148, 11.690146811306477, 18.96033089607954, 16.628036946058273, 18.995826691389084, 21.478258185088634, 30.392000377178192, 28.044484443962574, 23.124174065887928, 15.511846840381622, 31.1155803501606, 39.22317869961262, 37.741178423166275, 43.418278992176056, 21.194060035049915, 2.125470098108053, 2.155744261108339, 1.2333856732584536, 0.4608966247178614, 2.690002480521798, 3.461267282254994, 5.1062624249607325, 10.30551915988326, 19.345033653080463, 26.391860023140907, 23.89228954911232, 20.61473172158003, 26.63442950695753, 21.451340429484844, 22.56526205688715, 27.307903468608856, 26.687058582901955, 18.101609274744987, 17.77169767767191, 21.416878178715706, 8.231486901640892, 1.8641783064231277, 0.6250295892823488, 0.3108398267067969, 0.14064379764022306, 0.1870971213793382, 0.9811464801896363, 0.1279944842099212, 1.1489999201148748, 8.02460890263319, 30.976916290819645, 47.718873023986816, 31.164799109101295, 17.376026809215546, 24.883698150515556, 17.864255011081696, 17.1109701320529, 23.768758177757263, 21.920812837779522, 28.109825737774372, 21.21476322412491, 18.287552297115326, 20.216798074543476, 9.44288469851017, 7.434352375566959, 4.699473353102803, 14.785187132656574, 30.331864804029465, 29.748248420655727, 35.68060979247093, 36.0566072165966, 41.17225371301174, 46.03869818150997, 47.09714278578758, 48.81280392408371, 36.058932691812515, 30.21023143082857, 27.86866407841444, 31.215760074555874, 40.05843847990036, 49.29460287094116, 47.048402801156044, 21.552705690264702, 11.301975790411234, 2.708782497793436, 13.435291517525911, 20.186534598469734, 28.71929783374071, 16.056401319801807, 19.568374268710613, 41.47944822907448, 58.64275865256786, 76.75946071743965, 34.06908206641674, 34.47784513235092, 41.50456868112087, 33.69837015867233, 48.59200157225132, 61.67507193982601, 80.75213447213173, 46.79855480790138, 45.42311981320381, 60.6464709341526, 8.545107822865248, 0.052270744781708345, 0.37624369841068983, 0.04494829277973622, 0.26132616796530783, 0.08428525150520727, 0.10860100766876712, 0.07752628254820593, 0.03692809950734954, 0.06114925410656724, 0.07187010793131776, 0.06809771934058517, 0.01961854210094316, 0.019639689598989207, 0.024109055048029404, 0.03905553632648662, 0.04214570566546172, 0.11118181137135252, 0.00215534829749231, 0.037949042380205356, 0.08512689149938524, 0.03338711627293378, 0.03696390071127098, 0.06793950087740086, 0.024771342068561353, 0.06228766040294431, 0.09006370979477651, 0.08407278204686008, 0.05117084852827247, 0.07691168037126772, 0.03993522623204626, 0.14100543136009946, 0.11087136357673444, 0.1454342866782099, 0.05620439835183788, 0.0336846544087166, 0.03877358329191338, 0.027130922680953518, 0.07600408571306616, 0.22994181141257286, 0.9834390634205192, 62.197148725390434, 89.93387818336487, 61.03982962667942, 76.21134772896767, 103.79475921392441, 59.30100493133068, 52.081377133727074, 40.217125564813614, 43.59784595668316, 36.76998473703861, 70.3744201362133, 89.43763241171837, 77.08334773778915, 80.32667130231857, 75.4318955540657, 80.87891086935997, 77.21609741449356, 73.35154518485069, 71.89739361405373, 49.23657238483429, 11.699824891984463, 22.056275568902493, 32.97966152429581, 33.75806115567684, 39.326662346720695, 38.237329199910164, 38.38438890874386, 34.28742974996567, 29.37348783016205, 30.41382260620594, 25.2521263808012, 23.040958531200886, 26.023418493568897, 21.539062522351742, 28.97799175232649, 23.206194564700127, 12.196650132536888, 10.33122668042779, 13.783689122647047, 12.675098609179258, 14.37567075714469, 20.731014981865883, 21.154846139252186, 30.55258736014366, 29.83292307704687, 27.7100320905447, 19.763873778283596, 34.7235931456089, 41.647365018725395, 44.18609619140625, 46.7398289591074, 30.109812319278717, 2.5128220254555345, 2.629195055924356, 1.1541214515455067, 1.16107341600582, 2.8809659834951162, 5.105247879400849, 4.259579507634044, 14.96567839756608, 24.836901761591434, 36.20240539312363, 28.153458796441555, 31.207037642598152, 33.27972762286663, 31.018772944808006, 31.884849071502686, 43.09999667108059, 34.79195147752762, 29.508475586771965, 24.23014461994171, 27.885039299726486, 17.375160455703735, 6.922618160024285, 2.3965083668008447, 3.92842513974756, 0.9799776272848248, 0.5306222301442176, 1.2639487395063043, 0.42131106136366725, 0.9505721926689148, 9.240696597844362, 30.147054120898247, 52.340375036001205, 35.921026691794395, 16.494033336639404, 43.150765746831894, 26.327242590487003, 25.046532712876797, 24.46591056883335, 25.39403546601534, 23.318007364869118, 22.354215681552887, 18.7033411860466, 14.116140883415937, 10.45511333271861, 12.127844374626875, 11.427467856556177, 19.38495621085167, 27.581602782011032, 23.917391002178192, 24.979971684515476, 28.681563958525658, 30.226606652140617, 37.99793064594269, 37.89732724428177, 36.186761632561684, 30.78572954982519, 27.4678672850132, 24.220645129680634, 30.54968621581793, 43.490387722849846, 47.39249713718891, 32.47433423995972, 19.474526904523373, 24.67976689338684, 4.2332796938717365, 12.760070599615574, 19.551275186240673, 35.19344173371792, 22.235757037997246, 24.284240417182446, 41.44723355770111, 59.10616658627987, 75.96622288227081, 41.24250814318657, 31.637717932462692, 30.146047174930573, 27.785497941076756, 46.52024254202843, 61.86804458498955, 80.53381338715553, 65.82214280962944, 47.28531628847122, 74.84866484999657, 13.189976681023836, 0.3969885961851105, 0.4206077428534627, 0.14729865069966763, 0.22583142650546506, 0.10788254934595898, 0.04557262822345365, 0.0193040384692722, 0.04759697701956611, 0.07469553092960268, 0.02988475996971829, 0.06748020052327774, 0.023362936881312635, 0.06786141952034086, 0.039953234445420094, 0.0352917195414193, 0.17275726975640282, 0.04866135408519767, 0.1497111501521431, 0.08751285917242058, 0.11378870156477205, 0.2544512087479234, 0.14452880714088678, 0.16562414704822004, 0.08311940429848619, 0.15731378516647965, 0.14796955219935626, 0.18849482294172049, 0.1853566663339734, 0.213784811203368, 0.2843592851422727, 0.2939765393966809, 0.13018389407079667, 0.28056403098162264, 0.335466216201894, 0.15891339542577043, 0.20983349822927266, 0.09205907772411592, 0.20640959992306307, 0.21783684846013784, 1.5983406524173915, 77.5180672109127, 107.19765901565552, 68.07287603616714, 83.38242933154106, 119.506726115942, 89.25547018647194, 85.39079636335373, 70.07740527391434, 63.049583584070206, 36.89743369817734, 75.13988882303238, 98.66400092840195, 82.95439749956131, 84.0260311961174, 80.04883021116257, 87.73545295000076, 81.12968221306801, 75.5184169113636, 76.48468226194382, 61.73985466361046, 13.832732141017914, 18.590580336749554, 31.263379119336605, 50.80203518271446, 49.70903903245926, 52.81970411539078, 46.06511816382408, 45.147619396448135, 37.68028289079666, 38.65418963134289, 35.07098190486431, 34.84589338302612, 37.45400883257389, 31.45250827074051, 41.28436289727688, 32.73570701479912, 11.780530661344528, 15.440452471375465, 19.60056234151125, 29.297765493392944, 25.975693054497242, 25.64317859709263, 28.388419188559055, 44.49661172926426, 35.78604653477669, 33.470530584454536, 23.46554394811392, 48.75968277454376, 53.121248334646225, 48.999035730957985, 53.77435348927975, 36.957637667655945, 8.416479025036097, 5.340658547356725, 3.748330478556454, 1.2447527633048594, 9.219173602759838, 10.427340622991323, 10.920373667031527, 22.88758736103773, 32.62578271329403, 39.064491614699364, 36.929872557520866, 42.92669557034969, 42.46749401092529, 39.92243617773056, 40.83818703889847, 52.19420447945595, 47.23484739661217, 40.243195965886116, 35.63039928674698, 34.05901260674, 18.547471649944782, 8.060340285301208, 3.0789567343890667, 3.167666061781347, 0.5494288459885865, 0.16844413010403514, 1.7333572637289762, 0.22180773928994313, 3.9118919894099236, 12.07265518605709, 36.57811023294926, 50.797570422291756, 43.04380148649216, 28.401872366666794, 55.659101754426956, 35.057557225227356, 29.38611075282097, 35.48097610473633, 32.312535122036934, 35.70321097970009, 30.435747429728508, 26.929571069777012, 31.482173278927803, 16.135769560933113, 17.915823943912983, 9.749162513762712, 22.283512875437737, 42.50233434140682, 39.61907185614109, 45.27860216796398, 45.489889830350876, 52.09052324295044, 55.48921287059784, 53.0474790930748, 55.83405576646328, 41.93421922624111, 36.125337928533554, 34.79876451194286, 41.953704580664635, 52.069320380687714, 62.02551573514938, 59.241420328617096, 30.810677111148834, 27.845977395772934, 6.031157970428467, 21.454480960965157, 29.669562242925167, 45.54010413587093, 29.903891868889332, 35.31041085720062, 48.644898533821106, 69.94033142924309, 85.37942737340927, 45.12021526694298, 39.350312277674675, 52.1729826182127, 44.813222140073776, 68.09237658977509, 74.63478192687035, 91.18378311395645, 63.089842423796654, 54.39032703638077, 83.7310454249382, 11.648510545492172, 0.5753568140789866, 0.5337795044761151, 0.4027037270134315, 0.2968650672119111, 0.2554064418654889, 0.18069204554194584, 0.11811362652224489, 0.2719675563275814, 0.19506179087329656, 0.12166709639132023, 0.2058452263008803, 0.21112767019076273, 0.06883818976348266, 0.11965315250563435, 0.13265119370771572, 0.1997657009633258, 0.14657716441433877], [0.06226209341548383, 0.0416301690711407, 0.031202036843751557, 0.021669778907380532, 0.13043233542703092, 0.09302429272793233, 0.03446805065323133, 0.04677003154938575, 0.07120636815670878, 0.03696774132549763, 0.09767851603101008, 0.11977033762377687, 0.05258832090476062, 0.01584295299835503, 0.15161866263952106, 0.05704702911316417, 0.022127075462776702, 0.07275644748006016, 0.036606586290872656, 0.11002012019162066, 0.05299427197314799, 0.3757375240093097, 0.12348441567155533, 13.853716515004635, 89.5120020210743, 70.64426645636559, 57.69606985151768, 88.28630179166794, 91.70287325978279, 54.76190149784088, 49.283758252859116, 48.70770536363125, 34.071821719408035, 43.39803747832775, 95.35730436444283, 70.61724990606308, 77.39066004753113, 62.54452608525753, 73.84184047579765, 58.99930492043495, 46.01798549294472, 32.204651311039925, 19.100531972944736, 4.360711080953479, 19.434146471321583, 41.03447690606117, 46.36610001325607, 33.88697683811188, 32.91372746229172, 36.14154785871506, 35.498329773545265, 30.774979926645756, 31.32861401885748, 26.53511803597212, 34.450706988573074, 27.67063770443201, 32.78381623327732, 23.681868240237236, 24.27679091691971, 9.12982614710927, 5.042196912690997, 13.062485922127962, 14.137823469936848, 19.486669152975082, 24.135561995208263, 19.817107021808624, 28.323264084756374, 28.987865522503853, 29.966793693602085, 18.850417993962765, 40.01351349055767, 39.99409273266792, 41.87218755483627, 48.05596433579922, 30.22015079855919, 3.6033005733042955, 2.225579763762653, 1.6462185583077371, 1.167820191476494, 4.302971754223108, 9.14452375844121, 10.305296871811152, 20.59469159692526, 17.908942513167858, 20.6374317035079, 22.52245355397463, 16.659421361982822, 25.604912750422955, 11.551483701914549, 24.379714094102383, 28.906088210642338, 27.64310248196125, 18.29866860061884, 20.218374989926815, 20.918650813400745, 6.832304606214166, 2.408074946142733, 0.6320925790350884, 0.2775195334106684, 1.1308840359561145, 0.8964984223712236, 0.5481527675874531, 1.4280897192656994, 0.36293209239374846, 6.703792652115226, 23.007963001728058, 38.50171521306038, 36.05898968875408, 18.57756033539772, 21.250241920351982, 24.4132586941123, 16.286705061793327, 19.174183420836926, 26.394043006002903, 29.858936481177807, 24.974689967930317, 22.126944176852703, 15.043645463883877, 7.971342410892248, 6.796776512637734, 11.436007898300886, 25.646340027451515, 39.45847727358341, 46.53860695660114, 45.405526757240295, 43.56999725103378, 50.15816353261471, 43.54918956756592, 56.77580863237381, 60.222960859537125, 55.602891370654106, 48.689994513988495, 43.65446671843529, 26.846602521836758, 40.01717269420624, 50.31484052538872, 49.20903526246548, 40.82349322736263, 34.00926947593689, 12.386950571089983, 0.7763323048129678, 7.976920511573553, 9.874091260135174, 15.059624556452036, 18.695671297609806, 22.069829441607, 35.02214692533016, 65.27014642953873, 34.92273285984993, 37.90555000305176, 42.90956608951092, 36.01794049143791, 46.89961038529873, 77.70321607589722, 58.12195099890232, 33.59343118965626, 71.17334246635437, 23.804519958794117, 0.5219661758746952, 0.08149111745296977, 0.1137362614099402, 0.17521311063319445, 0.01702302717603743, 0.04087012821401004, 0.08368371112737805, 0.0619981560157612, 0.01700294280453818, 0.06667574954917654, 0.06467062237788923, 0.04866310926445294, 0.03695722509291954, 0.04504225238633808, 0.046604799790657125, 0.05053764441981912, 0.11545750225195661, 0.21242902614176273, 0.04855950544879306, 0.03670782636618242, 0.04745912679936737, 0.034526387171354145, 0.0842492796073202, 0.032607159882900305, 0.031785186802153476, 0.03570855791622307, 0.03241740385419689, 0.0740627090272028, 0.12820178089896217, 0.07297272415598854, 0.11692214553477243, 0.053549773219856434, 0.03461895525106229, 0.07168674550484866, 0.045604458937305026, 0.041557327276677825, 0.040602958761155605, 0.12005628712358885, 0.07796065416187048, 0.7695038930978626, 0.2148773119552061, 22.48021502047777, 103.68170768022537, 72.17464953660965, 66.04591280221939, 98.84699150919914, 77.08335533738136, 46.903850957751274, 37.86760523915291, 41.32111452519894, 35.866849198937416, 57.62543544173241, 96.11458092927933, 79.31322768330574, 80.64636334776878, 75.31915560364723, 80.89192137122154, 67.81844168901443, 51.96713626384735, 35.805440694093704, 23.3080006018281, 10.726600214838982, 33.26982915401459, 39.116294234991074, 42.492071092128754, 26.865913085639477, 32.86986641585827, 34.4781681150198, 37.23793722689152, 30.467971600592136, 27.986681945621967, 27.27911051362753, 29.406405463814735, 23.686842173337936, 26.9282316416502, 21.924681030213833, 24.568921141326427, 14.219818320125341, 14.623938985168934, 16.22716225683689, 16.99809718877077, 13.179553840309381, 25.584494546055794, 21.981615275144577, 29.125412441790104, 28.123351112008095, 32.61300019919872, 23.536510840058327, 42.6751908659935, 41.031991839408875, 47.73722603917122, 51.76686801016331, 38.30146595835686, 7.849168516695499, 1.9958721147850156, 2.1870301198214293, 2.9037600103765726, 6.627033445984125, 9.547728672623634, 3.8001922331750393, 14.623075481504202, 26.206310279667377, 31.030493415892124, 21.2575888261199, 25.368605330586433, 32.267199754714966, 20.44332291930914, 32.24230349063873, 42.76363492012024, 36.31535053253174, 26.031196676194668, 24.105946384370327, 29.00875110179186, 11.725111585110426, 3.7483444903045893, 0.5018014891538769, 0.3150667733279988, 0.7659837976098061, 0.6193849327974021, 0.6985009030904621, 1.5694991312921047, 0.3778640442760661, 5.86852147243917, 30.136044211685658, 44.58015784621239, 39.05523531138897, 19.154253490269184, 34.12790670990944, 32.584190145134926, 23.990867659449577, 27.352364882826805, 27.80820932239294, 29.58796352148056, 25.47782476991415, 19.856062531471252, 12.234232015907764, 11.498784329742193, 13.277829866856337, 17.542326785624027, 23.69939099997282, 33.65425452589989, 31.433355398476124, 35.3731606900692, 34.70834456384182, 41.19722597301006, 40.334178283810616, 47.060372158885, 48.51541668176651, 43.34956347942352, 42.86751374602318, 42.80426613986492, 28.646222054958344, 46.741884648799896, 43.54902997612953, 31.995016559958458, 36.19019664824009, 45.604864060878754, 17.5125040858984, 0.4142800433328375, 7.982428316026926, 12.482954319566488, 17.20595933496952, 27.48419690877199, 30.040868818759918, 38.48782315850258, 71.35746538639069, 38.487975150346756, 32.85313591361046, 28.628822788596153, 35.35876706242561, 44.17300969362259, 77.50870451331139, 74.0817292034626, 34.786304980516434, 71.70000940561295, 35.48270881175995, 0.7267623615916818, 0.11409978760639206, 0.17086957261199132, 0.08084179760771804, 0.01845216982474085, 0.06836349726654589, 0.07462016583303921, 0.07663735290407203, 0.02716092400078196, 0.0915147272462491, 0.07708316101343371, 0.03496105935482774, 0.021451225693454035, 0.12044477174640633, 0.05239295795036014, 0.09016208146931604, 0.11010334463207982, 0.029679480066988617, 0.18977186613483354, 0.17760481510777026, 0.07235369877889752, 0.11437128749093972, 0.24233478703536093, 0.19093485607299954, 0.17733623186359182, 0.19403750833589584, 0.11227927709114738, 0.1432206531171687, 0.23146158142481, 0.182662284350954, 0.2223737901658751, 0.13813910860335454, 0.15139466762775555, 0.19541776942787692, 0.19196522422134876, 0.44241958181373775, 0.22944313270272687, 0.273303214344196, 0.22470670170150697, 0.9095869981683791, 0.7313023461028934, 26.78378239274025, 120.68299859762192, 87.83033385872841, 74.2172983288765, 106.73450946807861, 108.20517495274544, 76.75605610013008, 69.43865194916725, 65.4423987865448, 44.16938088834286, 57.82590128481388, 107.01642394065857, 83.04403468966484, 91.38125091791153, 75.63586860895157, 83.88695865869522, 73.58564302325249, 62.182682901620865, 41.688372418284416, 36.71559065580368, 7.507540248334408, 31.381501480937004, 46.19519278407097, 61.77931174635887, 43.44028361141682, 44.1815060377121, 46.62266604602337, 45.52029199898243, 38.54049973189831, 40.234243646264076, 35.2373331785202, 44.633237197995186, 33.604465797543526, 43.65613482892513, 33.797252252697945, 37.185986414551735, 15.143995229154825, 14.25910821184516, 21.087042577564716, 27.01372515410185, 27.821470610797405, 33.47764380276203, 27.84346003085375, 39.009098187088966, 38.29098232090473, 40.37980243563652, 25.620640106499195, 54.39533896744251, 49.64513786137104, 49.898375272750854, 55.50551779568195, 42.30897791683674, 13.106724098324776, 3.7439676001667976, 4.361269176006317, 2.737317541614175, 11.9650449603796, 21.448853462934494, 24.442034550011158, 34.87146981060505, 34.04198192059994, 33.59658882021904, 32.30184629559517, 35.19953280687332, 42.192077189683914, 27.040910795331, 40.21119028329849, 52.95979879796505, 48.83024878799915, 37.786506190896034, 33.963972106575966, 33.5389307141304, 16.714708395302296, 4.821358462795615, 0.7476922322530299, 0.3252184035954997, 1.4313836675137281, 1.6055087302811444, 0.6772874132730067, 2.7945583825930953, 0.22682044218527153, 4.975568912923336, 33.70942756533623, 49.148424714803696, 47.39652492105961, 29.631664976477623, 43.04376728832722, 44.43242557346821, 21.01454246789217, 29.601851776242256, 41.191302090883255, 41.09849967062473, 33.69125314056873, 31.092621982097626, 23.71385682374239, 18.312554955482483, 14.752868916839361, 17.934199757874012, 35.843883231282234, 49.184458181262016, 55.316470339894295, 53.72358441352844, 52.85203278064728, 56.36070750653744, 49.48122225701809, 62.1573306620121, 64.46214258670807, 61.199546456336975, 60.343289002776146, 58.01781378686428, 33.88636887073517, 53.06731402873993, 60.84587283432484, 62.966824024915695, 49.65550370514393, 58.82899805903435, 20.808641016483307, 1.2288409983739257, 10.406689681112766, 19.4065485522151, 24.508599378168583, 33.94064515829086, 40.22266186773777, 52.00162321329117, 81.23673766851425, 40.82763120532036, 47.58531779050827, 50.7658801227808, 52.518224492669106, 56.49601824581623, 92.51064151525497, 77.14935019612312, 42.89964482188225, 84.36453983187675, 41.99918434023857, 0.5700124008581042, 0.22137868887512013, 0.37586621241644025, 0.22379142581485212, 0.16838186391396448, 0.22715078695910051, 0.21790625411085784, 0.13279548205900937, 0.06924346918822266, 0.24634386878460646, 0.15895787975750864, 0.20290532702347264, 0.08436305826762691, 0.2095720692886971, 0.12174710733233951, 0.10922561399638653, 0.28244875953532755, 0.2559679507976398], [0.0346320764219854, 0.017509419631096534, 0.045360793301369995, 0.11549354836461134, 0.04373478484922089, 0.00967019164818339, 0.031103885958145838, 0.0864089812966995, 0.0486343473312445, 0.025930419033102226, 0.05231211209320463, 0.005015488732169615, 0.0087666537547193, 0.08920068110455759, 0.042726636602310464, 0.03626984420407098, 0.04947352710587438, 0.023481218522647396, 0.08886385738151148, 0.03090819274802925, 0.09712915605632588, 0.061729943845421076, 0.5432333971839398, 0.625378992408514, 53.04227717220783, 85.35714536905289, 58.983144387602806, 79.50986713171005, 101.2735641002655, 68.58518734574318, 41.1396324634552, 45.42492851614952, 44.50083330273628, 35.28762727975845, 92.40911096334457, 72.87415400147438, 78.05089741945267, 78.49550396203995, 63.98358106613159, 34.71350848674774, 26.38874039053917, 18.08422140777111, 8.340917229652405, 5.30235375277698, 42.2677843272686, 43.23530741035938, 35.53457222878933, 46.136235147714615, 33.47529552876949, 35.375885143876076, 35.97173497080803, 41.1378313601017, 44.962447732687, 40.04813723266125, 44.95642125606537, 41.37159861624241, 34.31937463581562, 37.39865720272064, 29.8750514164567, 26.671230532228947, 6.358696119859815, 11.507792696356773, 12.176870293915272, 17.412212267518044, 23.10558546334505, 21.130082868039608, 24.40341342240572, 31.25153135508299, 33.19558493793011, 29.50311977416277, 30.031580217182636, 30.843321159482002, 38.5976030677557, 50.25132693350315, 35.63286155462265, 14.112345837056637, 1.6063559660688043, 2.1819578669965267, 1.861127307638526, 6.065274914726615, 6.988701364025474, 9.113515522331, 8.413093406707048, 11.26904010772705, 21.118029914796352, 22.79934659600258, 17.28902667760849, 15.161894168704748, 1.5592109458521008, 26.390461698174477, 33.25678825378418, 29.97288666665554, 22.386019974946976, 24.671352244913578, 17.157985009253025, 3.351932899095118, 1.1779969953931868, 0.2895837079267949, 1.1075169523246586, 1.2881944072432816, 0.9335576556622982, 1.319807404652238, 0.26534047443419695, 0.5850564467255026, 4.412738364189863, 11.388093419373035, 32.04815290868282, 37.851532101631165, 20.650400407612324, 21.784291863441467, 29.141654670238495, 21.64846245199442, 18.285887986421585, 25.592631809413433, 21.675862781703472, 22.315678149461746, 21.08976323157549, 12.089276444166899, 10.268978420644999, 10.908166822046041, 24.92980297654867, 41.39571592211723, 50.007744804024696, 51.75769530236721, 47.23380245268345, 46.51208817958832, 48.46129238605499, 53.7433547526598, 61.17655768990517, 57.90731571614742, 61.9974884390831, 56.6810455173254, 43.05225983262062, 20.458033829927444, 35.80446794629097, 49.98315632343292, 30.074147433042526, 31.50631908327341, 42.16544821858406, 31.049367003142834, 1.987652680836618, 1.7520046443678439, 5.28190609999001, 10.016670059412718, 16.31037589162588, 34.032444432377815, 35.31722389161587, 52.1577188372612, 34.08665992319584, 40.63700683414936, 39.90147650241852, 30.782535821199417, 64.7454097867012, 79.86851468682289, 36.27224184572697, 57.32685126364231, 50.06024278700352, 1.39453288866207, 0.1276364127988927, 0.025678341153252404, 0.12504841026384383, 0.06519163231132552, 0.035291073872940615, 0.04257081156538334, 0.027866112723131664, 0.05134573562827427, 0.04431810179085005, 0.08187252940842882, 0.015002288000687258, 0.0943457534594927, 0.060353026128723286, 0.08482902310788631, 0.04831029596971348, 0.09974496686481871, 0.14930751087376848, 0.11364933365257457, 0.10627807059790939, 0.017958847565751057, 0.07024281556368805, 0.07135084946639836, 0.08514977191225626, 0.07933583154226653, 0.058329679231974296, 0.06169737840536982, 0.088538136187708, 0.030339596305566374, 0.03403350834560115, 0.09757660431205295, 0.08474696383927949, 0.1401663591968827, 0.06936163394129835, 0.025010243116412312, 0.08353221652214415, 0.023414007773681078, 0.045704801013926044, 0.030794540252827574, 0.027988192305201665, 0.18149896786781028, 0.4191191727295518, 1.096456814557314, 68.93222272396088, 86.95970177650452, 63.89248475432396, 87.43828609585762, 93.25853258371353, 58.16324718296528, 39.3938085436821, 36.29301153123379, 39.564692974090576, 50.98406441509724, 96.73979178071022, 77.47003018856049, 85.52160054445267, 86.11585825681686, 65.90864136815071, 35.06676033139229, 33.233278915286064, 22.10435438901186, 10.67983042448759, 9.501041527837515, 46.16316810250282, 38.193836733698845, 36.560562774538994, 39.79160539805889, 33.91583628952503, 34.20967072248459, 32.132363989949226, 35.70492848753929, 37.38088175654411, 31.221883445978165, 39.54058326780796, 32.71963767707348, 28.51093601435423, 26.31179641932249, 25.629590526223183, 24.96767744421959, 14.656372144818306, 18.528212383389473, 18.40976893901825, 13.16887641325593, 18.830318972468376, 24.186481162905693, 24.242967031896114, 31.034496501088142, 35.90231649577618, 29.92287565022707, 37.47633643448353, 32.14848272502422, 42.229508981108665, 55.47486864030361, 43.53474274277687, 15.052178855985403, 3.684709779918194, 2.846381664276123, 1.2807276891544461, 1.3899036683142185, 9.676001239567995, 14.311240464448929, 20.977999828755856, 17.427177764475346, 29.248081259429455, 24.1374371945858, 24.880688712000847, 27.341408170759678, 3.833724008873105, 33.090862557291985, 40.945751667022705, 40.48672869801521, 28.04641854017973, 31.155033633112907, 25.265342071652412, 6.2742385268211365, 1.800821574870497, 0.2433388979989104, 0.19331158400746062, 3.8503174809738994, 1.9251853390596807, 0.7896919129416347, 0.56805633706972, 0.902257013367489, 3.8708819774910808, 17.815357334911823, 40.329033359885216, 42.365708872675896, 23.856218084692955, 30.374266728758812, 31.634488105773926, 25.74494283646345, 24.095800928771496, 26.184983924031258, 23.9121662825346, 21.491316184401512, 16.795005686581135, 10.03925509750843, 13.578257896006107, 17.33865201473236, 27.270667366683483, 30.585527792572975, 38.80321003496647, 42.850969433784485, 42.96489492058754, 45.51609322428703, 51.07437416911125, 49.02870453894138, 57.03360579907894, 51.9489998370409, 54.92792218923569, 48.51349398493767, 40.12789875268936, 19.384895414114, 39.514794051647186, 51.12600199878216, 35.58712720870972, 35.19004471600056, 51.095189452171326, 46.394537687301636, 3.6604478443041444, 1.0821091406978667, 6.1587869469076395, 12.330285161733627, 18.35024893283844, 35.99312402307987, 42.62072078883648, 59.20637860894203, 41.183284521102905, 30.694996118545532, 30.49948900938034, 34.959131106734276, 59.406810253858566, 85.29298961162567, 45.086450278759, 54.15377452969551, 63.824506402015686, 3.6890538968145847, 0.14297035639174283, 0.0784755710628815, 0.061941073727211915, 0.04509422869887203, 0.03663259485620074, 0.05938075701124035, 0.10945221394649707, 0.08364909735973924, 0.04477875285374466, 0.04094825781066902, 0.06311773031484336, 0.06794897810323164, 0.03424521710257977, 0.0066111206160712754, 0.015245582562783966, 0.05048782404628582, 0.07078841284965165, 0.05971543963823933, 0.18390760815236717, 0.11282644773018546, 0.13020793965552002, 0.3144984069513157, 0.1726728875655681, 0.1475425946409814, 0.1849703339394182, 0.1889552068314515, 0.1283136967686005, 0.21064552653115243, 0.17324423737591133, 0.12353130456176586, 0.11374941226677038, 0.18686836177948862, 0.30746715143322945, 0.21773615386337042, 0.1458592849667184, 0.180737865739502, 0.23611210141098127, 0.1887505076592788, 0.20147648494457826, 0.4091979644726962, 0.43021555698942393, 1.3057286851108074, 87.74838745594025, 102.59539157152176, 76.01686656475067, 100.93075409531593, 112.7839520573616, 88.78344431519508, 55.895407274365425, 65.65511137247086, 56.32588617503643, 48.7044033408165, 106.20238602161407, 86.64907604455948, 88.95577266812325, 92.40142777562141, 77.78254821896553, 46.409569680690765, 40.48236273229122, 29.491688087582588, 14.523710813373327, 7.17566130682826, 47.93817065656185, 51.070475578308105, 49.910793006420135, 63.179643005132675, 42.46519893407822, 47.0794927328825, 46.380379647016525, 50.43430611491203, 52.920520305633545, 49.66713488101959, 58.24894778430462, 52.69451603293419, 44.619747921824455, 50.49539543688297, 41.34826026856899, 38.2388187199831, 13.520396500825882, 21.2692504003644, 22.15317416936159, 27.87734091281891, 33.41233670711517, 30.59548705816269, 34.5708679407835, 41.82172246277332, 45.13207443058491, 39.23116207122803, 39.43594068288803, 38.47080007195473, 47.445204108953476, 57.23755605518818, 50.392519757151604, 21.485907174646854, 6.360835405066609, 5.15886252745986, 5.004927087575197, 18.827524222433567, 18.128120452165604, 28.03813688457012, 24.699379540979862, 19.778786078095436, 34.292221292853355, 32.63173699378967, 35.406788885593414, 37.000214383006096, 8.717447575181723, 41.869265511631966, 53.16447101533413, 50.00326864421368, 41.039504036307335, 40.01933477818966, 28.340724147856236, 9.057389684021473, 2.7745994785800576, 1.083306788932532, 1.6379688447341323, 5.418074643239379, 4.777750577777624, 2.8243813198059797, 0.864042048342526, 0.4615827847737819, 4.823240786790848, 24.91412501782179, 48.54133129119873, 51.067868918180466, 29.639574252068996, 38.85064668953419, 47.30096384882927, 26.919328719377518, 30.398982502520084, 37.535100281238556, 30.81827100366354, 34.48181971907616, 28.784496635198593, 20.31335849314928, 20.031250230968, 17.320724576711655, 35.36710001528263, 49.96622443199158, 60.679194778203964, 56.96974642574787, 56.25010684132576, 51.4750474691391, 54.470639526844025, 57.10270509123802, 67.17581257224083, 61.92028038203716, 69.10618498921394, 63.96023511886597, 51.316436380147934, 24.06410302966833, 45.730576515197754, 66.50484457612038, 40.08870005607605, 42.781965136528015, 56.839295625686646, 46.35845102369785, 3.5298866126686335, 3.2708481000736356, 8.54319367557764, 14.716574214398861, 26.143364757299423, 46.23662956058979, 49.0045378357172, 69.38071265816689, 40.65584622323513, 49.44740027189255, 48.87530297040939, 47.984497770667076, 76.8617208302021, 99.00477424263954, 50.525900200009346, 65.69231137633324, 71.86114355921745, 2.2133560571819544, 0.20115096413064748, 0.3021444089245051, 0.193431856459938, 0.18809127272106707, 0.2573169081006199, 0.1788856729399413, 0.2052669893600978, 0.12590714934049174, 0.12857877707574517, 0.12543768156319857, 0.09837111050728709, 0.14595301821827888, 0.16670723736751825, 0.14542348100803792, 0.09139960529864766, 0.22129846271127462, 0.19678582961205393, 0.23839622415835038], [0.04020455904537812, 0.07132192054996267, 0.04058011545566842, 0.0457585918775294, 0.05579178650805261, 0.03318709263112396, 0.05880628275917843, 0.08303777547553182, 0.131309182906989, 0.03437926010519732, 0.030666176535305567, 0.09145298055955209, 0.04295496204576921, 0.0333783700625645, 0.03255939154769294, 0.03697245767398272, 0.019579774161684327, 0.041747780924197286, 0.08727475593332201, 0.015468484762095613, 0.050888305486296304, 0.057502047275193036, 0.37413890822790563, 0.172168078715913, 18.57498027384281, 101.05657294392586, 59.565124958753586, 57.61840961873531, 92.2765588760376, 77.48433262109756, 37.364728823304176, 44.062523022294044, 43.76665949821472, 38.58607068657875, 84.95390340685844, 77.8235176205635, 62.2488297522068, 40.97585365176201, 29.17761404067278, 21.515733674168587, 25.32916534692049, 9.234931357204914, 2.3393686953932047, 26.46549817174673, 36.95886120200157, 40.58560699224472, 41.317709907889366, 33.314830139279366, 37.80121140182018, 33.85498255491257, 45.81119678914547, 48.72591018676758, 54.57802176475525, 55.53027726709843, 43.6861190199852, 51.319499015808105, 40.492527186870575, 39.82713729143143, 36.99372433125973, 39.25026744604111, 24.417292177677155, 8.892394937574863, 8.509004060178995, 9.084175396710634, 25.823230035603046, 24.932284243404865, 26.410902701318264, 27.070653699338436, 34.26909573376179, 32.963736578822136, 28.09323012828827, 25.146782733500004, 31.199217662215233, 50.47326922416687, 29.818531349301338, 7.8678264655172825, 0.5031733936630189, 0.23193459666799754, 2.8745443280786276, 2.4482874758541584, 0.9285337314940989, 5.476399613544345, 3.4744141018018126, 10.978458300232887, 23.255164436995983, 22.947084568440914, 17.405414432287216, 2.700992440804839, 1.6751027083955705, 27.833895944058895, 34.00882109999657, 28.98266550153494, 21.68717287480831, 30.7418742030859, 14.804236460477114, 4.639774756506085, 2.6665313774719834, 1.1613819119520485, 3.784162080846727, 3.6999600240960717, 3.3543227333575487, 0.3621041524456814, 0.5267720273695886, 0.8007352484855801, 2.842408027499914, 12.12588082998991, 28.532000184059143, 34.654395058751106, 15.209991037845612, 23.45784366130829, 25.19389070570469, 26.824159026145935, 29.252268634736538, 27.157011665403843, 20.769324526190758, 24.32930789887905, 15.763987060636282, 10.87461557239294, 13.30965980887413, 21.018663346767426, 41.09002232551575, 56.06392063200474, 55.043359994888306, 45.11211410164833, 47.26693667471409, 46.88367024064064, 50.40687918663025, 59.59584631025791, 52.371434569358826, 62.88511700928211, 60.67300871014595, 56.72367163002491, 58.713651448488235, 34.10800337791443, 40.71492165327072, 51.57362177968025, 29.57022987306118, 36.35165758430958, 20.799318216741085, 21.496379412710667, 6.631128201261163, 0.233598061313387, 2.1633386285975575, 4.023065948858857, 11.186504736542702, 21.28237869590521, 44.5285452157259, 38.78639593720436, 28.64167559891939, 45.88243156671524, 34.54637065529823, 42.62591131031513, 77.25561529397964, 62.97932915389538, 42.12045483291149, 66.10060706734657, 17.45366234332323, 0.31547771533951163, 0.17296118225203827, 0.20170223142486066, 0.1555775455199182, 0.025573086059011985, 0.11339951932313852, 0.09714507512398995, 0.04286093564587645, 0.009429340607312042, 0.07784183631883934, 0.030406825608224608, 0.027646860035019927, 0.007763136045468855, 0.06465253623900935, 0.029973012460686732, 0.04872025463555474, 0.09910519103868864, 0.22321627620840445, 0.05042686032538768, 0.017345273263345007, 0.0756594620179385, 0.12353839207207784, 0.05319721225532703, 0.03692422920721583, 0.05261612546746619, 0.03687659074785188, 0.03476378165942151, 0.044686867549899034, 0.062168868535081856, 0.11861027916893363, 0.012373638037388446, 0.028236379475856666, 0.036967900887248106, 0.018586680380394682, 0.015414070494443877, 0.03962809954828117, 0.020706981449620798, 0.057344793603988364, 0.030566081222787034, 0.06543490089825355, 0.11671967280562967, 0.5274762958288193, 0.45689140213653445, 28.674348145723343, 110.35753905773163, 66.26895323395729, 74.56619560718536, 98.81306692957878, 67.13485836982727, 38.94478663802147, 34.2464679479599, 38.58588069677353, 49.67486746609211, 94.47538688778877, 82.66551420092583, 70.67204296588898, 49.46132272481918, 35.559358298778534, 27.224570140242577, 33.667569011449814, 8.76866027712822, 3.7421809835359454, 24.299677088856697, 32.5039878487587, 38.75586837530136, 43.87183405458927, 30.27323205024004, 32.371937334537506, 36.28731943666935, 38.65358166396618, 38.96137274801731, 44.84614737331867, 42.00112223625183, 37.43111126124859, 45.661709010601044, 33.34342360496521, 32.75491878390312, 25.351002775132656, 29.357870668172836, 23.201864697039127, 18.4345094114542, 13.61250450834632, 10.946201831102371, 17.766908034682274, 27.694093845784664, 28.169486336410046, 26.854080520570278, 29.885751642286777, 32.53875598311424, 29.34279877692461, 29.56089947372675, 33.502171486616135, 52.2300935536623, 43.95860239863396, 13.096559643745422, 1.479617329314351, 0.8014651655685157, 3.143486534245312, 5.562820751219988, 4.185699122026563, 12.468044869601727, 11.33053220808506, 20.262072645127773, 26.16742316633463, 24.40259836614132, 25.266366116702557, 9.964407663792372, 1.2662220862694085, 33.25850576162338, 42.204829305410385, 40.41076697409153, 28.707267679274082, 36.18287444114685, 19.46235615760088, 5.610673483461142, 1.2858715443871915, 0.4571716074133292, 3.189219692721963, 5.2420291397720575, 6.356980986893177, 1.0249917930923402, 0.14172161871101707, 0.4744621936697513, 2.1566932601854205, 15.325932316482067, 36.338791474699974, 43.40690240263939, 21.369380727410316, 25.484894290566444, 26.844060458242893, 28.66602849215269, 27.408352978527546, 28.09409838169813, 27.892295010387897, 20.449552685022354, 13.234325051307678, 11.660461854189634, 18.869470171630383, 25.506486631929874, 32.865344658493996, 45.385520830750465, 47.62467607855797, 46.01697854697704, 48.06930921971798, 53.2051782310009, 54.140118062496185, 56.49820692837238, 53.951841965317726, 58.549580052495, 57.7754969894886, 51.85367815196514, 53.73069383203983, 33.8872542232275, 42.100692093372345, 56.227995827794075, 37.585531175136566, 47.00382739305496, 27.974898777902126, 24.717757254838943, 10.172161515802145, 0.16260105301626027, 3.7571901781484485, 5.285665523260832, 11.72722427174449, 22.56180614233017, 46.44640110433102, 46.4005071669817, 35.96374399960041, 28.458848409354687, 30.043120197951794, 39.67085547745228, 76.40162631869316, 70.74290156364441, 42.180244624614716, 74.0638017654419, 24.69171915203333, 0.5769141961354762, 0.15823952533537522, 0.17465097829699516, 0.06570482742972672, 0.130860970239155, 0.03246340958867222, 0.1293735727085732, 0.03713407517352607, 0.012583338357217144, 0.043126810051035136, 0.13841526175383478, 0.010308408036507899, 0.04445820071850903, 0.08368373339180835, 0.0558052898850292, 0.04152910340053495, 0.06915293459314853, 0.1070018723839894, 0.021267614647513255, 0.1536225207382813, 0.19959600147558376, 0.18910348793724552, 0.15897624049102888, 0.09359903415315785, 0.10714012707467191, 0.3304799337638542, 0.13384352816501632, 0.23094995965948328, 0.19099896278930828, 0.18913431675173342, 0.09235446734237485, 0.13913606526330113, 0.1615097397007048, 0.10397244783234783, 0.19279375788755715, 0.2554473787313327, 0.19325952976942062, 0.2886123850475997, 0.12341799345449544, 0.26287048822268844, 0.2627174276858568, 0.8829939470160753, 0.5122591811232269, 36.65697120130062, 129.56838101148605, 77.87664636969566, 76.54728770256042, 109.3463297188282, 96.2393206357956, 55.49857936799526, 61.521989554166794, 58.8955856859684, 49.96391795575619, 101.61315187811852, 88.77341285347939, 78.60607042908669, 63.77206161618233, 43.634202405810356, 36.79335728287697, 41.51778057217598, 17.315431460738182, 4.30225501768291, 34.02790367603302, 45.86546167731285, 46.60702608525753, 53.62472511827946, 44.03361037373543, 45.215947329998016, 44.732468873262405, 56.94726683199406, 59.32120464742184, 64.39107120037079, 65.43204054236412, 52.222619354724884, 61.55265770852566, 52.40482337772846, 51.43883541226387, 47.1202227473259, 51.30178816616535, 34.074299186468124, 18.49871076643467, 16.488658525049686, 17.945152670145035, 38.27527396380901, 34.02997076511383, 37.369341775774956, 35.989890396595, 40.76598331332207, 41.2136372923851, 36.47559933364391, 31.54951136559248, 37.45008364319801, 55.94724029302597, 54.650685265660286, 18.365567810833454, 2.1643788227811456, 2.6962842559441924, 6.261507784947753, 9.126763511449099, 2.533480329439044, 14.335701651871204, 27.513510435819626, 27.430465891957283, 34.169742465019226, 30.828745141625404, 38.440226912498474, 19.828909188508987, 3.9605182176455855, 40.679165571928024, 53.21711719036102, 49.479177966713905, 42.42794953286648, 41.41496568918228, 26.172763779759407, 10.087493509054184, 2.6766556967049837, 3.87129093054682, 7.365737082436681, 9.209615215659142, 16.06622189283371, 1.426094826310873, 0.4716669983463362, 2.7041605208069086, 4.547229772433639, 25.345306880772114, 42.728258818387985, 48.47592160105705, 22.737645506858826, 38.50686773657799, 39.09339666366577, 37.35158912837505, 43.162807300686836, 40.27123846113682, 33.778120279312134, 33.74920383095741, 23.576925471425056, 20.036222264170647, 20.668622329831123, 29.540779553353786, 48.007357344031334, 65.55188611149788, 59.98687952756882, 51.62695571780205, 50.94743438065052, 52.04445071518421, 52.20937326550484, 62.81617730855942, 56.31558112800121, 65.18593534827232, 65.77982068061829, 61.316382586956024, 65.13323977589607, 40.38813538849354, 52.93434776365757, 60.64457103610039, 39.88382264971733, 51.73169709742069, 31.789468489587307, 32.66679771244526, 11.119585577398539, 0.9741869161371142, 6.363476263359189, 7.3561725206673145, 16.66985560208559, 29.615835025906563, 58.94091345369816, 55.70845730602741, 36.69246129691601, 52.201712876558304, 48.39884273707867, 55.48261642456055, 89.09519478678703, 80.47265946865082, 53.30068230628967, 88.71106579899788, 25.419336408376694, 0.5248514679260552, 0.34646071842871606, 0.39880492840893567, 0.16976951679680496, 0.24694480060134083, 0.14019744034158066, 0.2450018431409262, 0.2223577004042454, 0.10343741130782291, 0.13268384820548818, 0.15227252442855388, 0.07371975516434759, 0.20932484505465254, 0.18776101700495929, 0.1790066430112347, 0.19982173311291263, 0.12759660399751738, 0.3477452276274562, 0.15919021650915965], [0.06265310876187868, 0.03137223357043695, 0.026542753948888276, 0.09900187666062266, 0.01078935869372799, 0.0987611165328417, 0.04818228662770707, 0.06117356686445419, 0.03505483713524882, 0.06553329483722337, 0.033278250630246475, 0.13145025033736601, 0.07358384566032328, 0.08184740770957433, 0.024686766919330694, 0.07283251761691645, 0.03736381811904721, 0.0042721313548099715, 0.051668840751517564, 0.06502550255390815, 0.06629839714150876, 0.07589999950141646, 0.09529867107630707, 0.127374924486503, 1.3123271497897804, 56.87898449599743, 80.18099471926689, 42.447309494018555, 81.53641998767853, 99.38677534461021, 49.470594227313995, 34.287745133042336, 44.11371007561684, 41.25440530478954, 74.76573050022125, 50.129064694046974, 30.605662912130356, 24.505489245057106, 22.565792128443718, 15.28601260855794, 6.50648538954556, 0.15914123476250097, 23.373822569847107, 67.75648221373558, 63.622832223773, 44.27114702761173, 41.10958747565746, 31.38047743588686, 43.99849645793438, 47.86114498972893, 50.985382944345474, 54.450572803616524, 53.8086998462677, 48.332923874258995, 47.58797004818916, 44.654793441295624, 54.93737228214741, 45.79303376376629, 48.245482966303825, 40.02765633165836, 45.05816079676151, 19.541836492717266, 15.910824481397867, 10.351109113544226, 19.17717956006527, 27.48931523412466, 29.865626022219658, 31.419412046670914, 42.07917384803295, 32.67759293317795, 38.97075064480305, 20.98691415041685, 28.771710321307182, 42.28239834308624, 23.945397399365902, 6.118129603564739, 0.44099329272285104, 0.9726461581885815, 3.033971660770476, 7.4811867624521255, 1.999141601845622, 0.8540516125503927, 0.6328746839426458, 11.912232544273138, 25.524737052619457, 31.061338260769844, 13.81497759371996, 7.869294136762619, 0.20002528937766328, 20.03616526722908, 37.287824749946594, 30.61548538506031, 34.62023489177227, 37.84413769841194, 17.962329648435116, 7.335957605391741, 6.780122006312013, 3.8436379143968225, 3.2145472336560488, 9.026075564324856, 1.962841080967337, 1.0876856977120042, 0.10481845907634124, 0.6099803780671209, 2.602174705825746, 10.788976717740297, 34.21682573854923, 32.84240148961544, 20.789330452680588, 24.468933306634426, 21.242173053324223, 27.11976796388626, 30.03314383327961, 25.144635848701, 23.34687441587448, 26.694139502942562, 15.904649812728167, 15.24827778339386, 19.221304692327976, 40.46215921640396, 53.0517652630806, 52.956561371684074, 48.5666873306036, 50.47451555728912, 51.92177049815655, 55.340884029865265, 58.475012853741646, 56.56938090920448, 58.611691519618034, 61.23668186366558, 56.72939032316208, 62.6503200083971, 66.10642075538635, 46.30445212125778, 40.675821751356125, 53.83267655968666, 52.78786942362785, 43.556021600961685, 34.81179021298885, 56.85292549431324, 16.60940084606409, 0.18491825001547113, 0.7822541089262813, 1.8900675047188997, 7.854467332363129, 12.202862799167633, 41.91777750849724, 30.053489841520786, 32.76246897876263, 44.442540630698204, 37.55926698446274, 54.317503944039345, 77.79415279626846, 58.70708540081978, 60.252990648150444, 42.44662173092365, 0.2576987579232082, 0.08593727223342285, 0.0846595388429705, 0.09173257727525197, 0.05358055008400697, 0.022495848643302452, 0.07669529237318784, 0.027609676581050735, 0.04960061618476175, 0.08293779334053397, 0.10827973193954676, 0.04022468609036878, 0.04918946266116109, 0.039423493144568056, 0.01570409345731605, 0.031342280490207486, 0.08330037700943649, 0.013222333072917536, 0.021620229417749215, 0.05977863722364418, 0.031197027346934192, 0.027174095266673248, 0.019352946001163218, 0.2015062005375512, 0.06556168940733187, 0.11205097020138055, 0.060495704019558616, 0.08715627205674537, 0.09015489005832933, 0.05270182868116535, 0.020117022286285646, 0.005304972246449324, 0.059263104340061545, 0.05367300684156362, 0.0552617075300077, 0.047890540954540484, 0.06688181427307427, 0.023258763467310928, 0.08422087761573493, 0.06071146490285173, 0.036757056732312776, 0.006435766890717787, 0.14552724809618667, 0.09417775348993018, 2.450057943351567, 80.57867377996445, 80.91990306973457, 48.061519637703896, 99.11850973963737, 89.9725753068924, 47.139138132333755, 33.41877356171608, 33.189220279455185, 50.83009287714958, 86.26652017235756, 56.01350113749504, 39.146643206477165, 32.85098522901535, 28.10179866850376, 18.645086511969566, 5.6591275334358215, 0.18670752353500575, 29.26847666501999, 68.6779935657978, 48.3336990326643, 28.1438510119915, 42.93993405997753, 31.461048312485218, 39.853694066405296, 40.816737189888954, 43.16527336835861, 47.364724427461624, 46.34927071630955, 44.21310894191265, 41.89472034573555, 42.37447500228882, 51.38066813349724, 43.155473694205284, 40.62496908009052, 30.64128790050745, 32.76590019464493, 20.706014223396778, 22.438865639269352, 14.511525817215443, 11.850571352988482, 20.739366933703423, 27.84117065370083, 32.56046801805496, 37.19391658902168, 33.646791726350784, 34.915011674165726, 22.370611801743507, 30.34826472401619, 46.13968916237354, 35.15076622366905, 7.47665835544467, 0.7127838616725057, 2.6241106912493706, 3.365544006228447, 6.568062985315919, 2.9987905360758305, 1.7050991300493479, 6.318262489512563, 20.726105645298958, 31.751367934048176, 30.81226732581854, 25.002350583672523, 7.207761984318495, 0.6850673770532012, 25.26286270469427, 46.94037839770317, 41.72143444418907, 42.38790348172188, 44.337597861886024, 18.956004828214645, 7.959115616977215, 5.910368151962757, 2.3550172057002783, 4.777051415294409, 12.63634068891406, 7.221954697743058, 0.5797099554911256, 0.659680167445913, 1.031507255975157, 4.025858324021101, 14.938974380493164, 39.58853669464588, 41.29643104970455, 23.2303973659873, 24.595457017421722, 23.39931160211563, 29.476317912340164, 31.683742962777615, 28.61290354281664, 22.569143548607826, 17.13034339249134, 11.117634382098913, 17.769801579415798, 27.994747012853622, 36.80539883673191, 43.9190237224102, 46.98612034320831, 48.470434695482254, 53.779479414224625, 56.167240887880325, 62.8797022998333, 59.08530570566654, 58.06920602917671, 58.16756755113602, 63.37871052324772, 55.37284031510353, 61.59491904079914, 60.30527584254742, 44.97236520051956, 39.235782623291016, 56.14138327538967, 57.78073310852051, 51.86189331114292, 42.21197672188282, 61.101789101958275, 20.210306122899055, 0.13596010365290567, 1.5163943683728576, 1.5069625619798899, 7.493494777008891, 16.288357973098755, 44.13341201841831, 43.45577917993069, 33.049676567316055, 30.41146483272314, 36.677106320858, 55.46593151986599, 82.06491082906723, 66.16300731897354, 62.07522466778755, 59.56489697098732, 2.5434329453855753, 0.06388955647707917, 0.04156825540121645, 0.14393176417797804, 0.05407581862527877, 0.06019090396875981, 0.07999564535566606, 0.01913900523504708, 0.09430765159777366, 0.015330268106481526, 0.05005990169593133, 0.045719595727859996, 0.04561559857393149, 0.03214885771740228, 0.019028185888601, 0.06266723183216527, 0.03902290409314446, 0.049874090182129294, 0.033273534281761386, 0.06836626547737978, 0.2329412754625082, 0.0773388308880385, 0.11809180738055147, 0.24293668364407495, 0.12913801503600553, 0.1997679570922628, 0.1503847085405141, 0.22507688496261835, 0.17883603810332716, 0.17084046558011323, 0.07686633514822461, 0.1283196933218278, 0.20439355575945228, 0.24633656605146825, 0.28476176667027175, 0.11792997465818189, 0.18770909635350108, 0.20026581943966448, 0.10644146183039993, 0.37014624278526753, 0.2585528511554003, 0.19533507933374494, 0.21182447264436632, 0.1912769564660266, 2.0579443965107203, 91.80685088038445, 95.10239124298096, 58.41920904815197, 99.25527200102806, 119.40413162112236, 67.55516141653061, 50.126218646764755, 55.03791868686676, 52.19980537891388, 95.88535442948341, 68.91564041376114, 50.028993263840675, 44.95705582201481, 39.17391434311867, 25.87474387139082, 11.06623264029622, 0.2428651406080462, 32.83570624887943, 80.68727195262909, 69.91295769810677, 52.5849375128746, 54.30714949965477, 44.24803286790848, 54.8937164247036, 57.2187926620245, 60.31631425023079, 66.36884987354279, 62.59645789861679, 58.07671442627907, 54.61407043039799, 53.95205095410347, 64.50896367430687, 57.391915172338486, 55.45733258128166, 52.32802949845791, 56.69100858271122, 26.621398106217384, 24.308878295123577, 17.519383616745472, 28.93547773361206, 41.07462175190449, 37.91341558098793, 40.83535239100456, 51.408851221203804, 43.662024512887, 45.9536549448967, 29.13476563990116, 33.72018478810787, 51.767251789569855, 50.437471345067024, 13.649371080100536, 0.4165450780419633, 3.7597415037453175, 5.007649641484022, 12.65372570604086, 5.520413126796484, 3.9179234532639384, 10.26251781731844, 27.83017784357071, 40.854640156030655, 38.4194952249527, 37.804703414440155, 11.972019486129284, 0.828563233371824, 29.435888081789017, 54.61750164628029, 49.294743463397026, 53.23809206485748, 49.63012106716633, 22.717662379145622, 12.28865934535861, 10.17596036195755, 10.757788941264153, 8.479983117431402, 19.3716474249959, 6.8951047863811255, 1.6132979560643435, 0.4280949739040807, 2.0718248141929507, 6.9565066415816545, 23.761238381266594, 46.12565651535988, 52.7380046993494, 28.520397506654263, 39.874718338251114, 31.302372626960278, 40.79888194799423, 44.82700400054455, 35.308028385043144, 35.34645952284336, 38.13831031322479, 25.026397593319416, 21.996888555586338, 28.331481143832207, 48.94813746213913, 58.833557814359665, 57.00566969811916, 52.31023885309696, 59.500159844756126, 53.89235995709896, 59.70542103052139, 57.91247583925724, 59.55802693963051, 59.61467809975147, 64.49311092495918, 58.22441250085831, 67.9594749212265, 69.36279281973839, 51.04207970201969, 45.64955346286297, 67.62095108628273, 64.38483193516731, 55.88851064443588, 43.22852097451687, 68.888601064682, 21.213883571326733, 0.42322791006881744, 2.243547812104225, 3.217674703337252, 11.864566002041101, 20.15325218439102, 52.4799719452858, 48.09255637228489, 40.58742709457874, 52.23135508596897, 56.21087394654751, 66.3091778755188, 95.98359435796738, 76.0133783519268, 72.38102406263351, 66.88511297106743, 1.5132809104397893, 0.16598677524598315, 0.14402448810869828, 0.19071083137532696, 0.17100023513194174, 0.10643368412274867, 0.26088761806022376, 0.0698542344616726, 0.2201081914245151, 0.31393683864735067, 0.16951832949416712, 0.22221615799935535, 0.21736494643846527, 0.1572385017061606, 0.12669125804677606, 0.14174130046740174, 0.20822103397222236, 0.11958095637965016, 0.14056974614504725, 0.13277100602863356], [0.08730311339604668, 0.0499357255466748, 0.08030633805901743, 0.07977835935889743, 0.0756293605081737, 0.04056684956594836, 0.02911115636379691, 0.004132740714339889, 0.07559375968412496, 0.010404743443359621, 0.017303525601164438, 0.013613114642794244, 0.036899055558023974, 0.052732104595634155, 0.05568951484747231, 0.12487768661230803, 0.08412249851971865, 0.06504778924863786, 0.0405510381096974, 0.12619866494787857, 0.06014223021338694, 0.05733887497626711, 0.06654270473518409, 0.24018975760554895, 0.20399151952005923, 9.848647825419903, 98.14943253993988, 59.347803220152855, 62.921207472682, 96.23912304639816, 71.97640657424927, 37.08727531135082, 52.443824484944344, 42.14594766497612, 62.796057388186455, 37.24762290716171, 34.51825216412544, 27.653835006058216, 12.220191769301891, 5.403738487511873, 0.19023138913325965, 2.894049631431699, 44.85808253288269, 43.638944551348686, 55.327197164297104, 69.09789383411407, 51.59516282379627, 26.922140568494797, 37.66172468662262, 54.904466047883034, 59.07214321196079, 56.3777381926775, 56.44208773970604, 54.996170327067375, 56.78932070732117, 45.62896616756916, 42.92825348675251, 41.5507248044014, 48.39251987636089, 44.59539882838726, 46.93446211516857, 39.95288394391537, 21.542664729058743, 13.08321475982666, 23.93960651010275, 63.48308712244034, 41.462869718670845, 27.46212389320135, 30.891798958182335, 30.72813604027033, 34.377587512135506, 26.12097255885601, 25.558188557624817, 44.41102892160416, 31.568692736327648, 16.139056384563446, 2.0730279246345162, 2.225712281651795, 1.95245873183012, 7.739161569625139, 8.903208207339048, 4.93558413349092, 3.9057377446442842, 17.691852562129498, 33.90445590019226, 34.662522822618484, 19.61068119853735, 7.694263178855181, 0.7434207864571363, 10.462799370288849, 37.36112281680107, 32.543741315603256, 39.285810738801956, 47.5621922314167, 15.83391185849905, 14.036254920065403, 16.795511059463024, 10.752630718052387, 10.89863408356905, 8.427699822932482, 1.542920507490635, 0.14045143296243623, 0.10248747712466866, 0.02726116217672825, 1.8340437859296799, 8.232713285833597, 29.348840452730656, 28.612392470240593, 19.392664097249508, 18.706597611308098, 17.669469863176346, 27.755477651953697, 31.976652145385742, 25.45823112130165, 58.66330794990063, 61.88557304441929, 25.197494812309742, 21.173812821507454, 31.902445927262306, 51.13990545272827, 49.223953261971474, 52.258174046874046, 54.19958487153053, 58.215330988168716, 58.45647744834423, 56.211633905768394, 61.73314422369003, 60.5042065680027, 61.759119629859924, 63.434753715991974, 60.321044996380806, 64.49428886175156, 68.59636634588242, 56.0263292491436, 44.66670200228691, 53.04832644760609, 52.965840473771095, 45.869246274232864, 32.092017754912376, 46.68209485709667, 25.16820028424263, 0.2141139833838679, 0.12904288654681295, 0.6016177986748517, 1.9650263199582696, 8.93611254170537, 26.53186921030283, 26.275588162243366, 37.64016464352608, 40.560547336936, 35.487507954239845, 64.77720648050308, 75.5197848379612, 54.68675673007965, 76.99055671691895, 10.51307637244463, 0.4480946366675198, 0.06877721491036937, 0.054099140616017394, 0.052804022416239604, 0.16540123557206243, 0.02343085823667934, 0.05099930851429235, 0.07822792380466126, 0.06370007133227773, 0.0692469795467332, 0.07378162801614963, 0.04544724608422257, 0.0235935370074003, 0.02437712249957258, 0.03175909288984258, 0.03226709668524563, 0.008250949249486439, 0.14821129938354716, 0.049632009031483904, 0.05088115118269343, 0.08972289331723005, 0.026304732346034143, 0.07025915765552782, 0.16447730624349788, 0.04024012276204303, 0.05940439070400316, 0.02953833100036718, 0.04841956979362294, 0.03296624432550743, 0.09240566068910994, 0.025269208126701415, 0.024565299609093927, 0.03382063070603181, 0.023684387015237007, 0.040054507917375304, 0.042027054805657826, 0.09550028291414492, 0.04693040595157072, 0.08828058125800453, 0.10124342239578255, 0.025358007951581385, 0.07293033268069848, 0.1771910084062256, 0.27954963385127485, 0.2154910977697, 17.5219788774848, 112.58203849196434, 61.76587946712971, 78.44213962554932, 102.14689403772354, 63.824848383665085, 30.28852242976427, 35.47254055738449, 51.602789014577866, 75.27529075741768, 43.578839376568794, 43.165147975087166, 33.226952254772186, 12.828354835510254, 7.4521643947809935, 0.15132101689232513, 3.3327957009896636, 49.05235067009926, 46.50295726954937, 57.76396840810776, 59.75345805287361, 47.51551553606987, 28.843811452388763, 35.26761755347252, 52.173826172947884, 52.60302074253559, 50.55781848728657, 52.19975598156452, 51.427348628640175, 55.293128192424774, 45.590451434254646, 43.50341722369194, 46.49845831096172, 50.21964803338051, 40.74005350470543, 38.2449933886528, 32.50883638858795, 24.53372363001108, 19.3338755518198, 22.22215946763754, 59.01074230670929, 41.44836209714413, 30.279330722987652, 30.922531709074974, 29.276716522872448, 33.876793384552, 24.93501629680395, 28.198514878749847, 49.102409183979034, 40.57256609201431, 18.5016518086195, 1.3396580144762993, 1.580702355131507, 2.992107169702649, 8.467820920050144, 8.281211983412504, 5.310891419649124, 3.175126248970628, 20.951045975089073, 37.36371427774429, 38.12754929065704, 27.941042594611645, 8.38889915496111, 0.8631682733539492, 13.310090135782957, 45.02343446016312, 41.77715465426445, 47.07878977060318, 52.451997846364975, 19.429493620991707, 18.025491759181023, 19.302135854959488, 9.790112916380167, 10.740116089582443, 11.332613546401262, 3.8723429990932345, 0.43557988945394754, 0.09528429567581043, 0.01022669015583233, 5.203962782397866, 10.72300560772419, 35.667656287550926, 38.2379599660635, 15.80635478720069, 16.124050989747047, 20.470774546265602, 28.515742756426334, 32.04939544200897, 32.111191526055336, 54.54746000468731, 52.26748734712601, 27.149178385734558, 29.06138777732849, 33.80867823958397, 44.73185330629349, 43.834379464387894, 50.24859867990017, 60.50038017332554, 64.54644486308098, 66.8311558663845, 58.80416639149189, 63.29407386481762, 62.81239651143551, 64.52004387974739, 64.8573137819767, 62.17189908027649, 66.34350523352623, 67.57859855890274, 54.58645351231098, 43.851170763373375, 52.963446602225304, 58.38225223124027, 53.428393453359604, 38.69751490652561, 56.854764595627785, 33.00847537815571, 0.15838212158996612, 0.34796650637872517, 1.3243200187571347, 2.038758513517678, 11.311289090663195, 28.570866398513317, 41.82684078812599, 30.188327506184578, 29.63173907250166, 39.848917722702026, 67.00993627309799, 84.46813747286797, 64.98757839202881, 83.48678693175316, 20.537236779928207, 0.6957818521186709, 0.0685328702093102, 0.13484700088156387, 0.07888144420576282, 0.04370975220808759, 0.04925697583530564, 0.08438348217168823, 0.021199897382757626, 0.07168436321080662, 0.05581671153777279, 0.08564708507037722, 0.04018019804789219, 0.07529575770604424, 0.04439860254933592, 0.08083155596978031, 0.09931810578564182, 0.047236675454769284, 0.07560089172329754, 0.03715245817147661, 0.03247368833399378, 0.14592541032470763, 0.19984720362117514, 0.1408781678765081, 0.26591851841658354, 0.18346344761084765, 0.1336425545741804, 0.11817091290140525, 0.23019010433927178, 0.16775129071902484, 0.2040262075024657, 0.13171777973184362, 0.16928489436395466, 0.1738529617432505, 0.17250957054784521, 0.2574161480879411, 0.18627152661792934, 0.29979337414260954, 0.15061317128129303, 0.23428901564329863, 0.1589320827042684, 0.21406212210422382, 0.16888388228835538, 0.2818546851631254, 0.4409609053982422, 0.4610444308491424, 20.400556214153767, 128.6155441403389, 72.92479768395424, 83.64016190171242, 118.45253348350525, 90.0007089972496, 49.764113277196884, 61.74376845359802, 55.355737432837486, 86.60296931862831, 57.71021269261837, 55.8467660844326, 43.61225478351116, 18.589012920856476, 10.078260004520416, 0.486248834640719, 3.8899973267689347, 55.248898565769196, 54.55965735018253, 65.20159810781479, 81.96302309632301, 63.16094420850277, 35.12232095003128, 48.565851375460625, 72.20195487141609, 70.54710566997528, 64.51223149895668, 64.72081750631332, 63.13252933323383, 64.35681983828545, 52.78870537877083, 49.585956037044525, 51.29798077046871, 61.83513455092907, 50.80381728708744, 57.97025553882122, 47.19874173402786, 29.030381441116333, 20.50196137279272, 29.760852344334126, 78.74279469251633, 50.213066786527634, 35.58678522706032, 38.53775627911091, 38.491763547062874, 44.272803738713264, 37.270478680729866, 30.82645956426859, 54.88480590283871, 52.027499824762344, 30.79281996935606, 3.549576443620026, 5.796526735648513, 3.600667789578438, 10.079123508185148, 17.342499308288097, 17.93068304657936, 12.774430979043245, 25.703829042613506, 47.81948782503605, 40.261408388614655, 45.97133919596672, 12.958941478282213, 1.3063433021306992, 18.22920072823763, 48.08060601353645, 48.26013498008251, 54.07646007835865, 53.26421946287155, 22.948089614510536, 27.186021208763123, 25.358815155923367, 14.576041605323553, 10.908976178616285, 15.902029853314161, 8.720333520323038, 1.035406559240073, 0.1990024614497088, 0.12963715387741104, 7.0325020886957645, 17.422631308436394, 40.94329699873924, 52.12053403258324, 24.05659843236208, 35.536798909306526, 27.606360353529453, 40.923500061035156, 39.483434334397316, 36.385312378406525, 75.84053322672844, 74.73910912871361, 32.5575003772974, 26.480070389807224, 38.637440130114555, 57.30828545987606, 54.01851698756218, 56.60795643925667, 59.36261482536793, 60.16840718686581, 60.112470388412476, 54.767521396279335, 63.27805772423744, 63.91868814826012, 62.61828012764454, 64.24983277916908, 62.05455757677555, 68.18455964326859, 72.2213414311409, 60.408295914530754, 52.243259847164154, 62.78635270893574, 62.54214361310005, 58.54173347353935, 42.601885199546814, 57.62166224420071, 34.933516681194305, 0.6487673905212432, 1.442343348171562, 2.2427569795399904, 3.8875756692141294, 13.417302332818508, 36.89059406518936, 42.87697523832321, 43.334782272577286, 47.325381338596344, 53.057191371917725, 77.23077982664108, 96.10791608691216, 66.53560772538185, 97.71233439445496, 22.30685882270336, 0.5770455859601498, 0.14536773087456822, 0.2633327868534252, 0.16174780583241954, 0.36629348702263087, 0.2919439156539738, 0.1374073064653203, 0.129534381267149, 0.17931222973857075, 0.15297293371986598, 0.18876549904234707, 0.23118375102058053, 0.25443019112572074, 0.10873513601836748, 0.18820645404048264, 0.13545421126764268, 0.18385746865533292, 0.29400485975202173, 0.15007432753918692, 0.20988114411011338], [0.06848592194728553, 0.1584673795150593, 0.09211073120241053, 0.09785001893760636, 0.08335136997629888, 0.068529285636032, 0.041663858864922076, 0.08532811742043123, 0.03451368160312995, 0.06101113300246652, 0.13073651207378134, 0.10577847162494436, 0.011843213032989297, 0.04707529544248246, 0.057755338566494174, 0.08537235684343614, 0.09058826719410717, 0.09281616483349353, 0.06649112547165714, 0.09521350963041186, 0.0263391791304457, 0.07340855780057609, 0.0885707164707128, 0.05832308153912891, 0.13883717270800844, 0.9216103842481971, 50.37461891770363, 76.82504519820213, 45.411674827337265, 93.65890190005302, 73.33974301815033, 52.519193440675735, 44.91406872868538, 42.50339828431606, 56.16697870194912, 46.741918846964836, 25.549789108335972, 12.545763999223709, 5.3028311021626, 2.7790243411436677, 0.4873012297321111, 10.785279516130686, 70.03116935491562, 60.83521820604801, 39.05252605676651, 51.043215841054916, 57.65551842749119, 27.037587873637676, 36.09178572893143, 49.38728369772434, 53.85035701096058, 57.780660912394524, 58.60699117183685, 57.245193645358086, 56.33046492934227, 51.06097608804703, 52.85826824605465, 46.784142181277275, 51.23466856777668, 48.61503593623638, 46.77921764552593, 47.551647797226906, 34.71706509590149, 18.135537654161453, 16.07965987175703, 22.87061557173729, 26.919986084103584, 29.12183303385973, 28.56680441647768, 25.007966682314873, 23.341613598167896, 29.866334684193134, 25.752088353037834, 45.21438181400299, 36.91237449645996, 11.076082661747932, 3.449035263620317, 2.0688633481040597, 0.3098582028178498, 3.220168319530785, 19.347444623708725, 17.664444632828236, 19.237581118941307, 29.491351805627346, 44.16203208267689, 35.422045066952705, 28.55879444628954, 4.0761832986027, 2.625784738920629, 4.696137607097626, 15.141103584319353, 37.827376797795296, 40.12574806809425, 55.59202775359154, 15.898810476064682, 15.34127589315176, 26.383221186697483, 18.32163266837597, 12.836302109062672, 0.734631858067587, 1.434477532748133, 1.0359787847846746, 0.15160702576395124, 0.06306109702563845, 1.2259226362220943, 9.896628800779581, 28.149284720420837, 33.50203089416027, 30.31507920473814, 28.766033425927162, 24.39931534230709, 25.531844571232796, 23.090504072606564, 25.080504789948463, 59.201974645256996, 60.92899717390537, 19.701281636953354, 23.428442738950253, 41.42585210502148, 55.606064200401306, 52.419034615159035, 55.49996629357338, 58.842783719301224, 51.19650341570377, 54.53732594847679, 64.46374610066414, 65.76639980077744, 69.3327896296978, 68.00821110606194, 63.04718591272831, 63.38800482451916, 63.04934419691563, 54.411959275603294, 58.46984513103962, 48.25842127203941, 58.5915981978178, 55.14819636940956, 60.63498415052891, 45.671193301677704, 43.40358518064022, 27.492292374372482, 0.9498641244135797, 0.08904488204279914, 0.053447527534444816, 0.7689280458725989, 4.479582952335477, 14.343894012272358, 19.23799529671669, 30.973821356892586, 37.73156113922596, 40.6050543487072, 75.76659679412842, 65.24037882685661, 60.39800226688385, 46.96011833846569, 0.8189606142695993, 0.06768286621081643, 0.03561675795936026, 0.02370318747125566, 0.03346487108501606, 0.06729051499860361, 0.017179369860969018, 0.03351591600221582, 0.0853588645986747, 0.07402244009426795, 0.04311140306526795, 0.01679690776654752, 0.02648885918461019, 0.038462742159026675, 0.07714987266808748, 0.09098226597416215, 0.12231089465785772, 0.03400803041586187, 0.015439314647665014, 0.1418014886439778, 0.04921771993394941, 0.03157339640893042, 0.12865219032391906, 0.04966811080521438, 0.044362838452798314, 0.008209830557461828, 0.061259414796950296, 0.08655668352730572, 0.10216394526651129, 0.03846241190331057, 0.0744010838388931, 0.09800489773624577, 0.07490723597584292, 0.07223082138807513, 0.05614393186988309, 0.050985482303076424, 0.11311869806377217, 0.09607147687347606, 0.02178424776502652, 0.07149565732106566, 0.06920582003658637, 0.04353141412138939, 0.12883376417448744, 0.09179292872431688, 0.05699475594155956, 0.010252641204715474, 1.939147689845413, 74.08843964338303, 76.17226302623749, 58.89900170266628, 101.67791560292244, 71.62106484174728, 46.012050211429596, 28.063848204910755, 49.4801165163517, 75.9519812464714, 50.55548161268234, 27.117780670523643, 13.253010548651218, 7.628236496821046, 3.1799508025869727, 0.356275265221484, 13.357477393001318, 87.07276850938797, 67.70584613084793, 39.84899751842022, 53.0379644036293, 53.35896737873554, 27.05539181828499, 34.60751697421074, 44.91919845342636, 55.2035403996706, 57.5416499376297, 59.46499653160572, 59.28823001682758, 56.11460231244564, 56.01015731692314, 56.713659167289734, 52.147371992468834, 53.0924990773201, 50.82432098686695, 46.01644657552242, 39.76866602897644, 31.8398404866457, 19.87630594521761, 18.884768150746822, 29.90989364683628, 27.84379441291094, 27.03466773033142, 25.802247561514378, 26.84032715857029, 25.63743520528078, 28.440104015171528, 26.884152106940746, 46.69822119176388, 48.08685667812824, 20.473016425967216, 2.278039511293173, 2.6130454475060105, 0.5723615060560405, 3.8495446974411607, 21.366838663816452, 21.071271523833275, 19.456857852637768, 31.169987730681896, 51.05550438165665, 44.245354011654854, 40.838339030742645, 14.081845823675394, 2.245340128429234, 2.7596330316737294, 21.549219377338886, 46.34788379073143, 45.78066162765026, 58.676348850131035, 20.74260625988245, 19.0012850984931, 32.521273121237755, 20.978419706225395, 13.607021402567625, 2.102753729559481, 1.5495129162445664, 0.2788747544400394, 0.2922331454465166, 0.024251220856967848, 2.133734179660678, 12.397117875516415, 33.19581672549248, 43.83831985294819, 26.319038830697536, 30.352524295449257, 26.238893531262875, 27.06630103290081, 26.598392240703106, 27.211913019418716, 64.27610456943512, 65.72173699736595, 24.56331644207239, 26.977442800998688, 37.67892636358738, 53.23711171746254, 52.28425584733486, 59.59564872086048, 63.59037056565285, 57.264504209160805, 58.936802074313164, 65.03959760069847, 66.52702778577805, 69.03631433844566, 69.7810135781765, 64.27853643894196, 65.11417999863625, 66.77265420556068, 57.27066367864609, 55.55084936320782, 49.39212463796139, 59.81817618012428, 62.11223088204861, 66.9675001502037, 51.654899418354034, 54.619591534137726, 34.249842166900635, 1.0686214081943035, 0.2950393839273602, 0.2355030208127573, 1.4048311673104763, 6.399890659376979, 18.141651526093483, 30.704997181892395, 24.55861609429121, 34.02033448219299, 44.81181621551514, 81.0505248606205, 75.20769238471985, 66.86299815773964, 68.53659555315971, 2.0606327522546053, 0.17010113806463778, 0.09879733333946206, 0.024883120640879497, 0.08548577185138129, 0.025028961936186533, 0.02159372732421616, 0.04001012377557345, 0.07293082249816507, 0.09349613537779078, 0.0217276385956211, 0.05250400550721679, 0.01112666481276392, 0.043681212919182144, 0.057374401585548185, 0.09340217206045054, 0.08071077885688283, 0.093718646094203, 0.06108886926085688, 0.07371271218289621, 0.07065353493089788, 0.13350154651561752, 0.38106940977741033, 0.2650751417968422, 0.18333679268835112, 0.16557976661715657, 0.154722279694397, 0.35728351736906916, 0.17407942068530247, 0.19716555689228699, 0.1889406458940357, 0.16998681763652712, 0.166609555890318, 0.10582017290289514, 0.11709894737577997, 0.15076519281137735, 0.2559331292286515, 0.23436253279214725, 0.18179284350480884, 0.1637311212834902, 0.1979307408328168, 0.15817415696801618, 0.23838242021156475, 0.3272666718112305, 0.10601072674035095, 0.0980385541333817, 1.7659357655793428, 83.13055604696274, 92.50330030918121, 66.23505905270576, 111.09941884875298, 89.74271804094315, 70.6411050260067, 55.823830515146255, 51.36347405612469, 79.45081830024719, 66.35032206773758, 40.495635420084, 22.26608321070671, 10.921449959278107, 6.246665306389332, 0.40590024611447006, 16.126817241311073, 83.79083141684532, 77.34866470098495, 48.36480796337128, 66.2570370733738, 71.61563113331795, 34.92221988737583, 47.13460497558117, 59.79247435927391, 65.42995825409889, 65.47511503100395, 66.40256926417351, 62.587285190820694, 58.34499143064022, 55.15570096671581, 60.109776332974434, 53.06705944240093, 60.020234137773514, 56.40035457909107, 56.837194338440895, 54.01999890804291, 42.885311990976334, 23.42474363744259, 18.689359836280346, 29.839399829506874, 34.928877130150795, 38.79210323095322, 36.009007170796394, 34.00861591100693, 31.871276199817657, 40.63842795789242, 34.856631606817245, 49.606630727648735, 49.02607128024101, 35.503045320510864, 6.433065254241228, 4.786570379510522, 0.5448155966587365, 2.8326256899163127, 40.15336498618126, 35.709416046738625, 34.12047430872917, 32.71329961717129, 62.045951038599014, 49.35384929180145, 54.12541665136814, 26.527165062725544, 2.571614133194089, 8.719774950295687, 23.744285590946674, 52.74138651788235, 49.365548864006996, 55.77788718044758, 27.65411999076605, 24.087441377341747, 36.71068511903286, 26.04707222431898, 21.966047510504723, 0.8743777906056494, 3.1360800191760063, 2.3300494579598308, 0.7370386726688594, 0.14263546967413276, 3.5263366531580687, 15.542342104017735, 40.404691100120544, 55.26890829205513, 40.17034247517586, 45.22451967000961, 32.40705505013466, 36.42309755086899, 31.207218132913113, 35.65729804337025, 72.68137514591217, 70.11329054832458, 23.44409789890051, 31.726969443261623, 47.90369130671024, 64.5815397799015, 56.63707047700882, 59.42391313612461, 61.827284172177315, 53.600885197520256, 56.88056901097298, 63.74323256313801, 66.21684283018112, 68.65704908967018, 67.78027653694153, 62.49591149389744, 64.97769892215729, 67.13527634739876, 59.999817833304405, 62.20635183155537, 55.8535373210907, 69.44106861948967, 66.6840809583664, 70.4870916903019, 51.968587785959244, 57.255722880363464, 34.420916587114334, 1.0116277914494276, 0.4925829463172704, 0.4807232186431065, 2.32279849704355, 7.825869116932154, 22.629556506872177, 33.08909945189953, 34.51685383915901, 50.388241186738014, 55.50232596695423, 93.59708681702614, 82.8706119954586, 71.04218870401382, 72.85403788089752, 1.3043208606541157, 0.2302416687598452, 0.17302997934166342, 0.11561366496607661, 0.16372586687793955, 0.14632750593591481, 0.2925265015801415, 0.10846645629499108, 0.25294185848906636, 0.2609289705287665, 0.09061396034667268, 0.1772089535370469, 0.13691913656657562, 0.13095595029881224, 0.2451326244045049, 0.3367155772866681, 0.20921301824273542, 0.14927301584975794, 0.20124336151639, 0.24113857856718823, 0.11857036646688357], [0.06227896243217401, 0.08266461620223708, 0.05070044193416834, 0.06833501363871619, 0.03035778077901341, 0.031644735354348086, 0.02103278056893032, 0.04708152206148952, 0.006359595636240556, 0.02781753173621837, 0.06755796275683679, 0.06907904637046158, 0.043943729106104, 0.08950476869358681, 0.09912088004057296, 0.045905433216830716, 0.022613436376559548, 0.02913821692345664, 0.05084112344775349, 0.062139694709912874, 0.028633471156354062, 0.08864000337780453, 0.08194202411687002, 0.03230713555240072, 0.14339568122522905, 0.12329412900726311, 7.77144986204803, 94.81209442019463, 51.701446920633316, 74.78348314762115, 92.17746019363403, 57.272848561406136, 40.18488809466362, 43.010948449373245, 48.82681757211685, 33.81866030395031, 17.19214517623186, 11.204696260392666, 1.9703525654040277, 1.4488235441967845, 1.1029735836200416, 8.092283271253109, 38.30832079052925, 29.236803464591503, 44.86204572021961, 56.42337754368782, 58.494213223457336, 41.51920549571514, 43.98639030754566, 50.31012877821922, 50.624599903821945, 50.68322695791721, 55.26521869003773, 57.4886579811573, 58.647732585668564, 59.17674019932747, 58.04057456552982, 57.03535370528698, 51.0549496114254, 52.433519437909126, 45.63279636204243, 48.663300946354866, 45.166698172688484, 37.85913549363613, 24.556894786655903, 21.261223331093788, 34.44664120674133, 37.674643993377686, 33.139458149671555, 28.453598991036415, 27.14706189930439, 24.731411822140217, 40.7901082187891, 49.72693607211113, 24.550585225224495, 4.01462422683835, 1.0896738222800195, 0.6352892168797553, 0.5255036079324782, 3.133634850382805, 6.493362793698907, 16.608638986945152, 37.5181569904089, 40.92236392199993, 52.2902937233448, 44.033120200037956, 33.931316658854485, 21.441487558186054, 1.849772329442203, 0.7095950609073043, 6.6264193039387465, 29.30962275713682, 55.04844792187214, 55.66661775112152, 22.051286436617374, 9.65419040992856, 26.46169077605009, 28.04064854979515, 14.831207413226366, 4.969200454652309, 0.8056295046117157, 2.2431937186047435, 2.650081110186875, 1.2560343579389155, 0.5126388045027852, 4.475653013214469, 25.53529668599367, 34.96763505041599, 26.488456539809704, 14.538477770984173, 26.11444640904665, 25.697103403508663, 26.751905903220177, 35.12206256389618, 24.94864236563444, 18.747813999652863, 20.86375705897808, 34.92381580173969, 56.78968548774719, 53.77672076225281, 56.02518931031227, 56.518368646502495, 62.552315667271614, 56.95464223623276, 69.3935027718544, 72.19641476869583, 69.85482841730118, 67.71058827638626, 67.96216517686844, 65.7517857849598, 68.69120165705681, 62.280379459261894, 60.08250139653683, 61.856079027056694, 55.96359081566334, 52.56867438554764, 52.778875306248665, 53.42716611921787, 47.39132679998875, 39.91102539002895, 30.690795443952084, 4.220735616981983, 0.08723369290237315, 0.2650658501079306, 0.10642551307682879, 5.368099249899387, 10.317705105990171, 15.302263386547565, 25.63604637980461, 37.23390944302082, 52.613219395279884, 76.23259618878365, 52.44698591530323, 55.26540867984295, 22.873898595571518, 0.8131951955147088, 0.33815525472164154, 0.10180844168644398, 0.1363745634444058, 0.08095697150565684, 0.10016649932367727, 0.06865792951430194, 0.09177624524454586, 0.025699284560687374, 0.13535958743887022, 0.04680095684307162, 0.16508387838257477, 0.04096716031199321, 0.05081120747490786, 0.0031585232272846042, 0.004905230634904001, 0.04573458711092826, 0.08122523562633432, 0.05545988693484105, 0.09343804747913964, 0.03380844464118127, 0.015278988485079026, 0.1385071247932501, 0.033561906893737614, 0.04472786749829538, 0.04878356725384947, 0.03652497231087182, 0.02679077228094684, 0.03772048687096685, 0.007283493887371151, 0.1473097235430032, 0.11164045121404342, 0.06511049330583774, 0.08055384430917911, 0.031095631420612335, 0.029719466983806342, 0.025977495315601118, 0.06829887846834026, 0.06447037609177642, 0.07505458197556436, 0.032180584530578926, 0.04060767139890231, 0.06944781955098733, 0.0988567051535938, 0.10690904455259442, 0.11274332719040103, 0.36966144223697484, 22.063215896487236, 111.88096851110458, 56.01139985024929, 91.60166189074516, 89.4047337770462, 66.08744457364082, 35.58545529842377, 39.40259367227554, 72.1899551153183, 39.68758977949619, 21.095130443572998, 13.00230285152793, 2.130441893823445, 1.8166377511806786, 1.1426207749173045, 13.196328990161419, 52.01508209109306, 40.448966324329376, 50.34194067120552, 60.90719774365425, 61.093497946858406, 38.45341980457306, 43.54912117123604, 50.42014807462692, 51.18798427283764, 53.0092379450798, 55.56543678045273, 60.33249378204346, 63.055294677615166, 60.561184510588646, 62.52381719648838, 59.53245811164379, 56.63490079343319, 55.69344811141491, 49.558928087353706, 48.92313100397587, 42.11018778383732, 36.99949622154236, 25.963281020522118, 25.031354427337646, 27.748237140476704, 32.91870139539242, 27.536326311528683, 30.885943472385406, 29.27284263074398, 30.203175209462643, 36.75107315182686, 52.3924208432436, 38.42959128320217, 9.62296748533845, 1.6428024228662252, 2.00161574408412, 0.42908867995720357, 2.7283740090206265, 10.365376397967339, 18.578172102570534, 44.93669271469116, 46.54924638569355, 56.90298020839691, 56.56625747680664, 44.0558847784996, 36.16785004734993, 0.9636395727284253, 1.429132882039994, 8.05991755798459, 36.20691195130348, 62.717663794755936, 61.46736368536949, 29.101259037852287, 16.333018876612186, 36.972867250442505, 32.27750480175018, 18.17606057971716, 3.024770929478109, 0.7366320944856852, 1.1208816664293408, 1.0843904432840645, 0.5054306506644934, 0.8219216647557914, 6.782892057672143, 30.809485875070095, 45.13711296021938, 24.279085993766785, 22.88615483790636, 27.935213707387447, 26.069977395236492, 26.85103878378868, 30.04158318042755, 26.911231353878975, 27.88976814597845, 23.40451542288065, 34.17598553001881, 52.08873733878136, 54.029676988720894, 58.45950968563557, 60.51434442400932, 65.91306433081627, 59.83717896044254, 68.70170429348946, 71.2406824529171, 68.8741010427475, 65.96701383590698, 67.25952208042145, 66.05162769556046, 70.27197763323784, 64.47588264942169, 60.299606546759605, 62.706385999917984, 57.990291863679886, 57.6459239423275, 61.35185368359089, 62.586145251989365, 52.3391705006361, 41.893918588757515, 35.6999621540308, 4.548515053465962, 0.04998323041945696, 0.18054180516628549, 0.7635860668960959, 5.337056340649724, 15.375159624963999, 21.57291680574417, 25.556472949683666, 39.837434738874435, 59.6125578135252, 85.20240247249603, 62.56543256342411, 72.26886928081512, 32.51531884074211, 0.6640396022703499, 0.4440265690209344, 0.04533364553935826, 0.09898846605210565, 0.05733490819693543, 0.1321709351032041, 0.03347524630953558, 0.0732061815506313, 0.03228785084502306, 0.054219442754401825, 0.12211340916110203, 0.06986020132899284, 0.1604836611659266, 0.04586125316563994, 0.032560567851760425, 0.09620554585126229, 0.0752711777749937, 0.04076983066624962, 0.037794497548020445, 0.04797786576091312, 0.0556811953720171, 0.11170407553436235, 0.22779059247113764, 0.20196101831970736, 0.12325146293733269, 0.10308004493708722, 0.1467479919665493, 0.1358088687993586, 0.1639456464909017, 0.10463766448083334, 0.2341572250588797, 0.13264988752780482, 0.14313774037873372, 0.15867901034653187, 0.1620834050117992, 0.24551401409553364, 0.16730708564864472, 0.2150639472529292, 0.15111410612007603, 0.1917756351758726, 0.25100069702602923, 0.10853065949049778, 0.18304024531971663, 0.18428234820021316, 0.1722263966803439, 0.327447637100704, 0.6913388217799366, 25.563702061772346, 132.9003918170929, 69.83552545309067, 106.60410806536674, 110.92560857534409, 78.54617044329643, 52.81588912010193, 56.534206196665764, 66.24984785914421, 48.78429785370827, 23.667109832167625, 17.424647100269794, 4.3489165138453245, 2.6291746320202947, 1.5055295638740063, 14.662434719502926, 51.502432599663734, 42.49368980526924, 56.123182252049446, 69.55424174666405, 72.52109974622726, 50.81730656325817, 56.009199768304825, 61.80165074765682, 58.405552580952644, 58.295499086380005, 59.786793664097786, 60.16807280480862, 64.68801006674767, 60.63274227082729, 62.54902504384518, 60.24069830775261, 58.432702124118805, 58.11835639178753, 54.626339972019196, 58.12994956970215, 54.62540902197361, 49.81212370097637, 32.85864561796188, 29.73520752042532, 43.11603561043739, 47.26833879947662, 40.22947110235691, 39.1344952583313, 36.5455611795187, 34.047810807824135, 48.078960701823235, 55.1447119563818, 47.97427251935005, 23.43892067670822, 2.853648061864078, 5.92615345492959, 0.8516822021920234, 12.504393719136715, 18.084926269948483, 24.50108528137207, 52.39917688071728, 49.86304856836796, 57.52249136567116, 63.900471925735474, 51.96205213665962, 48.95250342786312, 2.5254114624112844, 4.128029616549611, 12.817594762891531, 40.63826836645603, 63.74537564814091, 60.55915541946888, 37.6296392083168, 22.53721196204424, 49.6238362044096, 43.523084968328476, 25.74559450149536, 10.252220369875431, 2.2437169030308723, 8.378199879080057, 7.855528425425291, 1.7597689339891076, 3.653561663813889, 8.060706965625286, 35.87936192750931, 55.87801940739155, 33.776148185133934, 27.251924872398376, 36.4376849681139, 34.49253514409065, 33.43060612678528, 47.881173714995384, 29.106308966875076, 27.96575076878071, 26.40768237411976, 45.424476340413094, 59.71819594502449, 62.28216536343098, 58.39796058833599, 58.44671577215195, 63.40225026011467, 59.36952665448189, 69.8276674747467, 73.3112445473671, 68.9835199713707, 67.95953571796417, 68.29634204506874, 67.8030677139759, 70.78013196587563, 65.77771559357643, 65.09448185563087, 66.11415714025497, 62.09792844951153, 63.58745992183685, 64.3052490055561, 63.753298223018646, 58.958438113331795, 46.9257377833128, 41.679788678884506, 4.787663295865059, 0.11176203726790845, 0.4663705872371793, 1.017540511675179, 6.814293572679162, 18.83596356958151, 26.328120343387127, 37.42804102599621, 57.55779527127743, 70.787822753191, 99.85314711928368, 67.85529971122742, 79.86213102936745, 37.724371924996376, 0.6758915819227695, 0.6382394023239613, 0.22317878290778026, 0.18488816334865987, 0.21049095201306045, 0.18655164283700287, 0.17696631577564403, 0.18360447051236406, 0.14755342999706045, 0.2676051529124379, 0.2122132244403474, 0.21917458449024707, 0.2005474199540913, 0.12003225638181902, 0.12819244468118995, 0.2276897049159743, 0.11013751311111264, 0.16041949507780373, 0.12169641864602454, 0.21893129363888875, 0.16139253973960876], [0.11162652852362953, 0.06094322649005335, 0.07274705931195058, 0.09647371349274181, 0.09845601220149547, 0.049865403343574144, 0.03176694852299988, 0.023645277688046917, 0.007123387586034369, 0.051674247297341935, 0.05342306634702254, 0.05242982784693595, 0.04756333175464533, 0.09288333661970682, 0.07623543540830724, 0.12230126158101484, 0.11291902323137037, 0.08253871827037074, 0.07542547027696855, 0.0036894695904265973, 0.07471855977200903, 0.049706201534718275, 0.011488882973935688, 0.0654515101632569, 0.13388780469540507, 0.09168695003609173, 0.4486396402353421, 27.790982946753502, 71.43478363752365, 66.01095467805862, 102.13157325983047, 58.80719102919102, 35.294504910707474, 40.51642030477524, 28.47212489694357, 16.71002134680748, 10.712590366601944, 1.0830759513191879, 0.15645001432858407, 0.03950849502871279, 0.41567109525203705, 20.24796400219202, 52.3099272698164, 38.08791361749172, 37.99122400581837, 55.10565385222435, 59.11226525902748, 43.77789929509163, 47.76937611401081, 51.738696321845055, 54.02883343398571, 57.88985185325146, 59.97033901512623, 60.55963419377804, 61.85549385845661, 68.00711676478386, 63.50938931107521, 65.25955259799957, 58.72486084699631, 55.79286977648735, 49.26536723971367, 44.56743612885475, 45.53049445152283, 36.65271542966366, 31.785917580127716, 33.05240482091904, 31.729091629385948, 31.388464607298374, 35.74962168931961, 28.275417052209377, 32.36748397350311, 23.285015635192394, 28.62375196069479, 42.95842386782169, 14.86132649704814, 4.943309593945742, 1.2209673458710313, 0.07642014854354784, 0.027544089280127082, 1.9805970531888306, 2.059866380877793, 9.40150111913681, 23.302684687078, 33.62098351120949, 55.73711536824703, 50.26003606617451, 35.93862734735012, 30.5674996599555, 1.3762267772108316, 1.5939758741296828, 6.684548584744334, 16.01118754595518, 52.861076295375824, 58.750695660710335, 18.766964972019196, 9.569277316331863, 27.968604415655136, 30.810008347034454, 23.16124487668276, 10.171791035681963, 3.3086325600743294, 0.48430897935759276, 1.0460603563115, 0.3705653781071305, 0.6947298429440707, 3.714126138947904, 16.75822366029024, 37.97368414700031, 34.36364606022835, 16.75370380282402, 27.899142242968082, 26.966024413704872, 31.236898340284824, 35.44410288333893, 33.70304770767689, 15.782621260732412, 25.89388534426689, 43.92118200659752, 55.977007895708084, 53.53226087987423, 55.87432600557804, 60.20186059176922, 65.64067214727402, 70.52342534065247, 74.60581988096237, 71.42877995967865, 71.53922483325005, 71.35369598865509, 70.70323929190636, 66.78169772028923, 68.32614004611969, 63.302380219101906, 63.713533356785774, 62.356287986040115, 59.355854988098145, 58.45346041023731, 58.229162245988846, 55.852830559015274, 49.893237948417664, 50.07096581161022, 46.15427277982235, 8.125828821212053, 0.03543923252436798, 0.2965603116899729, 0.028539624727272894, 3.171729468740523, 7.992096897214651, 11.385885737836361, 25.66967837512493, 34.261496141552925, 63.32274712622166, 67.27405250072479, 53.92258733510971, 47.7528166025877, 4.3657410610467196, 0.4468236642424017, 0.21188310231082141, 0.11786332979681902, 0.10644908368703909, 0.14510625740513206, 0.06005199618812185, 0.14130188967101276, 0.020495111275522504, 0.05401511094532907, 0.09460791712626815, 0.01601796811883105, 0.06038869745680131, 0.018751875031739473, 0.05958327055850532, 0.035411008648225106, 0.02478587703080848, 0.09934408837580122, 0.11510558324516751, 0.085513810190605, 0.04060695893713273, 0.0454722490394488, 0.03933010499167722, 0.08432203976553865, 0.10143241030164063, 0.11667362996377051, 0.13396513648331165, 0.04756912421726156, 0.011155417469126405, 0.024472091427014675, 0.0739609234733507, 0.04986813073628582, 0.02590721949673025, 0.07374806809821166, 0.0238777777121868, 0.12278067413717508, 0.08051608383539133, 0.019976659896201454, 0.042401828250149265, 0.0667344979592599, 0.032671274020685814, 0.0696612463798374, 0.04070630282512866, 0.01651124028285267, 0.010241359632345848, 0.02870367832656484, 0.19694534683367237, 0.08991525799501687, 2.0022937702015042, 58.43130759894848, 78.84133860468864, 75.0478957593441, 106.13727271556854, 64.09856289625168, 36.90663680434227, 32.707398533821106, 50.86548797786236, 26.868723034858704, 11.043304670602083, 2.217200738377869, 0.17118476273026317, 0.4359919298440218, 0.18735886202193797, 24.164417646825314, 57.44084894657135, 38.911367431283, 47.881295308470726, 68.88214901089668, 67.58153200149536, 44.20181594789028, 43.79473239183426, 51.37251757085323, 57.55652993917465, 59.663497880101204, 63.550107926130295, 65.00856086611748, 65.41948601603508, 71.40690073370934, 67.00542211532593, 66.66019544005394, 61.251254081726074, 57.63354800641537, 52.06629954278469, 46.1322757601738, 41.25372514128685, 33.08923624455929, 28.261654190719128, 31.05059053748846, 32.91303209960461, 31.660195626318455, 32.19229817390442, 27.9622720554471, 26.658149734139442, 27.477381974458694, 29.33971144258976, 46.01550042629242, 25.107234455645084, 6.0315787978470325, 1.7407562979497015, 0.630422153044492, 0.0727911651483737, 0.41857951262500137, 1.2064755172468722, 12.76879208162427, 33.82141135632992, 42.838981077075005, 59.913551062345505, 61.57150849699974, 43.988210409879684, 46.850376427173615, 3.177160802297294, 2.846886799670756, 6.9224523939192295, 21.752424873411655, 58.95467631518841, 65.83056315779686, 25.736773274838924, 14.489993322640657, 36.54173858463764, 38.60737234354019, 22.976521588861942, 9.557446651160717, 3.434306778945029, 4.128516465425491, 3.1895248638466, 1.9421390793286264, 0.5025922623462975, 5.11770598590374, 23.790996484458447, 47.1235703676939, 22.30589747428894, 12.823680136352777, 28.216429017484188, 28.884533867239952, 31.30626931786537, 31.940371692180634, 33.42511922121048, 18.99851694703102, 29.83831688761711, 43.38819220662117, 53.92589695751667, 55.19185222685337, 57.14210897684097, 64.17203575372696, 66.37841776013374, 71.530781686306, 72.86442652344704, 71.45526453852654, 71.36129558086395, 73.00283029675484, 69.01759654283524, 67.33971297740936, 69.09163936972618, 65.92369616031647, 64.96989414095879, 61.472193226218224, 60.93889184296131, 64.85475271940231, 64.75959062576294, 61.10702522099018, 53.02442193031311, 55.16978681087494, 46.50482676923275, 8.242213726043701, 0.0316814271354815, 0.8645327563863248, 0.2337320931837894, 3.3131125196814537, 11.7041234113276, 13.541169036179781, 32.85901039838791, 43.551511242985725, 68.33522915840149, 80.76733365654945, 60.97375117242336, 66.49756416678429, 9.54948227852583, 0.4488182900240645, 0.3016891161678359, 0.014277528844104381, 0.152773741283454, 0.08871553916833363, 0.0852586078690365, 0.03245224026613869, 0.04465528916625772, 0.22534445888595656, 0.04361042687378358, 0.06954026146559045, 0.05189834249904379, 0.054078349348856136, 0.0518019783339696, 0.04474675515666604, 0.01931248410983244, 0.040701467733015306, 0.07646021709661, 0.03894721987308003, 0.047983198091969825, 0.09989823520299979, 0.13351885339943692, 0.2412595337955281, 0.1616722551989369, 0.27887220145203173, 0.3016201558057219, 0.345619271392934, 0.0979851714510005, 0.13189436635002494, 0.14959633990656585, 0.16274982393952087, 0.12595979729667306, 0.128610021492932, 0.16662205365719274, 0.19329537550220266, 0.15929319692077115, 0.1910591361229308, 0.2108153744484298, 0.24866224906872958, 0.14590761362342164, 0.10420816135592759, 0.17292929958784953, 0.08342451605130918, 0.17615293676499277, 0.2570973808178678, 0.30226241040509194, 0.17171996994875371, 1.9376068725250661, 69.99133229255676, 94.52843964099884, 88.97658795118332, 124.85199809074402, 83.95036205649376, 49.8615438491106, 53.83586458861828, 42.86418132483959, 32.48585902154446, 15.755417570471764, 3.0541008431464434, 0.6859097443521023, 0.8015666319988668, 0.8352961158379912, 26.425921395421028, 72.59477019309998, 51.223242580890656, 52.10703335702419, 72.36729919910431, 76.32461205124855, 53.94488073885441, 57.69809514284134, 60.19004322588444, 65.785923153162, 63.85520115494728, 67.87296116352081, 65.56083843111992, 66.65897950530052, 69.18713584542274, 69.04145926237106, 69.35091465711594, 63.32601875066757, 61.29605747759342, 56.80963061749935, 50.40405593812466, 52.175980657339096, 43.47781039774418, 40.618273839354515, 41.2563394010067, 42.377746626734734, 39.910375624895096, 45.09932018816471, 39.075640216469765, 41.51201628148556, 31.27105090767145, 36.979186311364174, 47.22599387168884, 42.99559347331524, 13.275008518248796, 2.2465080907568336, 1.743854556698352, 0.08984175568912178, 3.3067027386277914, 2.433192548342049, 18.496324494481087, 35.37681609392166, 42.34051242470741, 57.08600498735905, 64.63888630270958, 48.35797592997551, 57.82947689294815, 5.4681559558957815, 4.523393651470542, 10.476153753697872, 27.115527391433716, 59.39156927168369, 65.00117406249046, 32.892133221030235, 22.42500778287649, 41.534636467695236, 40.06755419075489, 32.617400363087654, 12.507997825741768, 9.430949538946152, 7.331350352615118, 3.598564602434635, 2.613424239680171, 3.743199328891933, 5.228884695097804, 34.08703230321407, 54.68711011111736, 43.51688750088215, 27.634634636342525, 37.36884020268917, 39.24318082630634, 41.782732754945755, 43.44722963869572, 40.729364678263664, 22.07357034087181, 34.92855794727802, 53.48026067018509, 63.10809664428234, 60.17347991466522, 59.57312352955341, 63.10476802289486, 67.01985374093056, 73.12690883874893, 73.44948872923851, 72.33617126941681, 71.6641317307949, 72.63700872659683, 67.86932855844498, 66.28658428788185, 70.9812019765377, 67.03458175063133, 68.37413907051086, 64.61003065109253, 66.70477464795113, 69.7573484480381, 70.80363750457764, 68.12589079141617, 58.82433570921421, 62.89589323103428, 56.17487467825413, 10.392787177115679, 0.22425017697969452, 1.0544500686228275, 0.535053564235568, 3.885480319149792, 12.885610163211823, 21.074505150318146, 50.28946168720722, 58.08980092406273, 83.76230254769325, 94.95078697800636, 65.82076728343964, 80.94409257173538, 8.041545543819666, 0.593799896305427, 0.4126083408482373, 0.11764496026444249, 0.21975357842165977, 0.21844820003025234, 0.17551419994561002, 0.21866125578526407, 0.15760386100737378, 0.3055509855039418, 0.217447295144666, 0.15062826656503603, 0.09999001660617068, 0.11341569072101265, 0.23624055233085528, 0.13464527030009776, 0.10941434957203455, 0.1541003747843206, 0.28856536257080734, 0.14060237095691264, 0.23850037716329098, 0.21453678491525352], [0.029320653520699125, 0.024210959345509764, 0.030193821803550236, 0.03538021323038265, 0.09286061947932467, 0.08835459564579651, 0.0453060599102173, 0.0958107752376236, 0.034641074962564744, 0.03458326536929235, 0.0618592556566, 0.02761532989097759, 0.0517325504188193, 0.06378829784807749, 0.06892249773954973, 0.08372800992219709, 0.030699293020006735, 0.04839965054998174, 0.0238951291248668, 0.016945192583079915, 0.0922833028016612, 0.06233228574274108, 0.23859860782977194, 0.04930574978061486, 0.05373076077376027, 0.13916162482928485, 0.9654398448765278, 12.878548242151737, 72.4750842154026, 68.814847022295, 99.21803399920464, 77.95313626527786, 42.53152057528496, 28.837004117667675, 22.422045841813087, 7.99999762326479, 7.076324662193656, 0.796590264653787, 0.2535791852278635, 1.9865009863860905, 1.8442720058374107, 17.20681618899107, 31.425552517175674, 39.26308415830135, 54.06961664557457, 64.09672379493713, 74.26988750696182, 47.70263269543648, 51.15620277822018, 52.388651445508, 53.768220618367195, 54.44271482527256, 65.71777760982513, 66.71470731496811, 69.96901988983154, 68.82481008768082, 72.74593368172646, 66.77400693297386, 64.97692376375198, 54.734318777918816, 54.26350884139538, 53.024672716856, 49.057776778936386, 41.52514077723026, 36.90953604876995, 36.61817908287048, 27.4485320225358, 29.129812605679035, 33.85291546583176, 27.160211093723774, 36.641452834010124, 24.138605631887913, 30.2174586430192, 45.48142768442631, 18.07688780128956, 4.082739371806383, 0.9026080789044499, 0.20740489417221397, 0.5925456073600799, 3.035606285557151, 0.7650377077516168, 3.7925090454518795, 8.175983279943466, 17.25373037159443, 32.094039246439934, 47.431407049298286, 32.922318801283836, 31.10290803015232, 3.799448423087597, 0.9513500821776688, 4.373639887198806, 13.647835962474346, 48.68006184697151, 53.29330690205097, 20.794441178441048, 11.221244372427464, 30.21230421960354, 32.477925047278404, 26.773386150598526, 17.420985996723175, 9.365078173577785, 1.4103791071102023, 0.26635947288013995, 0.1740215628524311, 0.2442090809927322, 0.14992980170063674, 4.969495413824916, 37.92709484696388, 30.090148374438286, 26.625838167965412, 25.38279376924038, 28.725563697516918, 32.888318225741386, 35.994917526841164, 28.199299536645412, 21.25768382102251, 30.284314155578613, 46.89210958778858, 56.3780801743269, 54.09360855817795, 59.74837392568588, 63.11270959675312, 66.73640415072441, 68.8443486392498, 75.24517357349396, 74.14859801530838, 71.01110637187958, 69.18251529335976, 69.90191549062729, 64.33772966265678, 70.65291479229927, 65.71621969342232, 64.2567028105259, 64.87118303775787, 63.21009837090969, 59.802570417523384, 56.26030169427395, 55.29477350413799, 50.58831565082073, 54.5323596149683, 50.35334765911102, 5.865844516083598, 0.1399804512038827, 0.3401737776584923, 0.1586944321752526, 0.8145082625560462, 3.7892595073208213, 3.9287576219066978, 29.948149994015694, 32.67388053238392, 80.7511693239212, 49.69898097217083, 54.050446674227715, 35.02210132777691, 1.275507837999612, 0.04424838443810586, 0.0762966403272003, 0.059270837518852204, 0.015261253010976361, 0.125929799687583, 0.019096496871497948, 0.03236118245695252, 0.05199383835133631, 0.03621620548074134, 0.051401136952335946, 0.05990239777020179, 0.1215069557656534, 0.06686282271402888, 0.04438815682078712, 0.10555333370575681, 0.02590926411357941, 0.032264721812680364, 0.040462436809320934, 0.05182645436434541, 0.03395455867575947, 0.058936744899256155, 0.018118607840733603, 0.023116460361052305, 0.11203398986253887, 0.11236170001211576, 0.02391632671788102, 0.07695118489209563, 0.07005821375059895, 0.035945466297562234, 0.03330424806335941, 0.04527499360847287, 0.02831384670571424, 0.07050834858091548, 0.02926182161900215, 0.045535524550359696, 0.05268816574243829, 0.02475803721608827, 0.17119798780186102, 0.05845263825904112, 0.04883326146227773, 0.02563626509072492, 0.05560027158935554, 0.04478270479012281, 0.09252412230125628, 0.14458086137892678, 0.14540428906911984, 0.33010945364367217, 1.2532613379880786, 20.0512732565403, 88.72848406434059, 77.0170184969902, 109.98962000012398, 77.39281833171844, 43.64171840250492, 28.15995454788208, 33.29758666455746, 14.546446893364191, 8.282507713884115, 1.8393075722269714, 1.1351825552992523, 3.887372617609799, 4.423397742211819, 23.9152118191123, 40.99926799535751, 49.277507588267326, 64.13310304284096, 72.38385871052742, 75.70880189538002, 49.89315815269947, 53.87237682938576, 57.78691917657852, 56.62304922938347, 58.21406565606594, 70.0456465780735, 68.59638154506683, 72.54909664392471, 72.85314112901688, 73.59169229865074, 69.43155393004417, 66.60234734416008, 57.551267221570015, 59.43293385207653, 54.56875406205654, 48.79541225731373, 40.635346323251724, 32.78169974684715, 31.213170513510704, 24.844645746052265, 28.69564790278673, 30.490979366004467, 22.380667962133884, 36.58333495259285, 24.411966763436794, 26.46310430020094, 46.372274681925774, 28.031589835882187, 5.181960063055158, 0.5571921856608242, 0.20525371975963935, 0.3958627878455445, 1.8712849938310683, 2.940588346682489, 3.1693966314196587, 14.155221786350012, 26.836225278675556, 39.94540974497795, 58.49403463304043, 43.531436920166016, 44.43841025233269, 5.831477260217071, 3.9916492346674204, 6.170890247449279, 17.10177082568407, 56.44002445042133, 61.18731111288071, 26.46684519946575, 16.930341124534607, 38.88050548732281, 41.201762929558754, 27.5547344237566, 18.027490451931953, 12.586901541799307, 1.4067175285890698, 0.7924051454756409, 1.0015915799885988, 0.47584362735506147, 0.08799992327112705, 14.793646428734064, 43.93198482692242, 22.663169503211975, 24.190926924347878, 22.228356935083866, 28.275192864239216, 30.751766972243786, 31.984061747789383, 27.03410156071186, 21.1957186460495, 31.69258128851652, 45.03887303173542, 56.703403517603874, 57.556385546922684, 62.15150557458401, 64.90573078393936, 67.74575158953667, 69.66663971543312, 73.35599094629288, 73.68637561798096, 69.56164374947548, 69.90478053689003, 70.73650270700455, 66.64270877838135, 71.16366058588028, 66.96189165115356, 69.03759106993675, 66.24689161777496, 65.1911410689354, 65.44559061527252, 63.2780235260725, 62.65830717980862, 56.705694794654846, 60.906369388103485, 55.4258930683136, 6.356757748872042, 0.06694611394777894, 0.37573776149656624, 0.13992943597259, 1.3698720932006836, 3.4244800312444568, 10.395401436835527, 47.58928097784519, 45.523487627506256, 89.44925978779793, 64.70406040549278, 65.85544422268867, 52.62330025434494, 1.6363231767900288, 0.10785904552903958, 0.07415898784529418, 0.0849872044636868, 0.027851366248796694, 0.03767116002563853, 0.03246853782911785, 0.05243795436399523, 0.06504932549432851, 0.1388095796573907, 0.057285406946903095, 0.06285606388701126, 0.07629531930433586, 0.04642149302526377, 0.03453020552115049, 0.03767867056012619, 0.05694263491022866, 0.08136429183650762, 0.0763809186173603, 0.049738436719053425, 0.009901752855512314, 0.008967047542682849, 0.1548402663320303, 0.21621825406327844, 0.21542522474192083, 0.1596233932650648, 0.18294474575668573, 0.20654507155995816, 0.20529900561086833, 0.17364768369589, 0.10514501889701933, 0.15103858517250046, 0.1788823926472105, 0.10141784194274805, 0.2290902563254349, 0.12405816261889413, 0.11376088586985134, 0.1770371018210426, 0.2300183119950816, 0.11607300242758356, 0.22957756533287466, 0.08956515725003555, 0.2914850605884567, 0.19157092116074637, 0.33399219217244536, 0.22405307739973068, 0.25159759155940264, 0.5224404379259795, 1.850813354831189, 29.393235370516777, 113.68768036365509, 90.58277696371078, 125.08852019906044, 102.51596823334694, 63.85400041937828, 43.947119414806366, 40.08547022938728, 17.307373993098736, 12.329972628504038, 2.2718289820477366, 2.209624657407403, 5.0672822166234255, 9.485355969518423, 29.84714761376381, 43.82989950478077, 53.41354385018349, 69.09459561109543, 80.47800198197365, 87.72729858756065, 56.87443993985653, 66.78619667887688, 62.2261031717062, 61.368219405412674, 59.35460865497589, 70.62239482998848, 68.98038133978844, 73.07219177484512, 70.16528695821762, 73.99756371974945, 69.45612341165543, 66.80374413728714, 55.93713663518429, 60.550343692302704, 57.70361244678497, 59.05097834765911, 50.850205197930336, 47.17656992375851, 46.40532150864601, 35.917397886514664, 38.39928790926933, 42.171102315187454, 34.12095308303833, 49.402756467461586, 31.066365391016006, 37.91169807314873, 51.22386574745178, 45.73156826198101, 7.027736669406295, 0.6770048034377396, 0.1978096817038022, 1.988551332615316, 4.034756971523166, 2.0760820107534528, 5.911302901804447, 23.343173414468765, 35.77004939317703, 43.11146445572376, 61.18139863014221, 47.77313031256199, 56.02645844221115, 8.862355649471283, 6.443671435117722, 8.014108166098595, 22.538973167538643, 57.13319465517998, 62.07105249166489, 32.75062121450901, 25.787850134074688, 47.67488278448582, 44.488856345415115, 34.91221122443676, 20.09107232093811, 14.099882505834103, 6.720844237133861, 0.9887163271196187, 0.7464854407589883, 0.8987600728869438, 0.2218250758596696, 25.626744478940964, 52.27076657116413, 42.40676186978817, 40.75502470135689, 32.310186848044395, 36.05608284473419, 38.883659318089485, 42.93751738965511, 34.51366201043129, 26.84067104011774, 40.735402554273605, 51.969951912760735, 63.40362958610058, 59.688907116651535, 63.679285794496536, 64.65573459863663, 68.02312150597572, 70.25612488389015, 73.5046997666359, 73.31993848085403, 71.62810206413269, 71.58992171287537, 70.99855184555054, 64.29664626717567, 74.23800721764565, 66.60206615924835, 67.55456104874611, 68.98457631468773, 71.4060115814209, 71.13362699747086, 70.46458169817924, 68.53466525673866, 62.77853652834892, 65.05457639694214, 61.284414902329445, 7.648719772696495, 0.40826674725394696, 1.1906022252514958, 0.3370647132396698, 2.3615896655246615, 3.708357810974121, 18.276481591165066, 62.45359696447849, 54.97597061097622, 106.93626344203949, 70.36259517073631, 73.22784662246704, 61.540384367108345, 1.1570168961770833, 0.1737876230617985, 0.18419612548314035, 0.12586199707584456, 0.1630952046252787, 0.26560898346360773, 0.14364554750500247, 0.21323679451597854, 0.12005735581624322, 0.20468740171054378, 0.15600083686877042, 0.1212072691123467, 0.23197719594463706, 0.11559608348761685, 0.1351389172486961, 0.15774480969412252, 0.16478556470246986, 0.18353865685639903, 0.21977082593366504, 0.08291259742691182, 0.14012715895660222, 0.11544826251338236], [0.0556360022892477, 0.05875076640222687, 0.08004595554666594, 0.07830749687855132, 0.06585335344425403, 0.03275021255831234, 0.07183651090599597, 0.07424307317705825, 0.03361456598213408, 0.0375433325098129, 0.04329835377575364, 0.06739176620612852, 0.046877268177922815, 0.04298132684198208, 0.10789743682835251, 0.06829434394603595, 0.031000725575722754, 0.03002253968588775, 0.03011679986229865, 0.062385816854657605, 0.08689150345162489, 0.051873487973352894, 0.08275649408460595, 0.14286771736806259, 0.09712413171655498, 0.03052922802453395, 0.015619590667483862, 4.521815786138177, 72.79441148042679, 78.72265577316284, 93.8269592821598, 97.34634563326836, 54.87423487007618, 28.604652285575867, 13.428441435098648, 6.5050984639674425, 2.1627774462103844, 0.24005609680898488, 0.31496299139689654, 0.48738806101027876, 0.36570226249750704, 28.119716607034206, 50.068936720490456, 47.09446392953396, 60.68063870072365, 65.39379179477692, 64.33590576052666, 53.39984178543091, 48.97852823138237, 56.183568611741066, 64.10135954618454, 62.017558962106705, 67.08341673016548, 72.47376188635826, 75.22092327475548, 75.86781576275826, 74.68253776431084, 70.68889126181602, 64.30963397026062, 59.04264159500599, 52.72526018321514, 48.918172270059586, 43.544257432222366, 43.168552592396736, 36.37563809752464, 38.50242577493191, 34.34909664094448, 31.311311647295952, 30.215587243437767, 31.493162289261818, 25.25961197912693, 32.239620834589005, 44.23785321414471, 42.52821855247021, 17.949326746165752, 3.0196127062663436, 0.6159009947441518, 0.23250548634678125, 0.7095116435084492, 0.32323508814442903, 0.9558249358087778, 0.17624868865823373, 3.605868285521865, 5.624056840315461, 12.226933557540178, 31.357190385460854, 31.547525972127914, 21.5975109860301, 1.555415780749172, 4.480673493817449, 5.604950990527868, 17.607402093708515, 50.412176102399826, 56.41797423362732, 24.129090942442417, 14.728607218712568, 36.90240763127804, 35.65766282379627, 25.43971661478281, 24.8672716319561, 7.874901685863733, 2.732801246456802, 0.29374026926234365, 0.39909056620672345, 0.3612424893071875, 0.7935545837972313, 2.5419683614745736, 32.91659630835056, 14.153895657509565, 15.444970428943634, 29.295825697481632, 24.97676845639944, 33.43351677060127, 31.047533601522446, 30.50784096121788, 28.552008010447025, 36.00192055106163, 43.75302202999592, 50.978721901774406, 56.29167661070824, 58.655708357691765, 67.3400017619133, 66.55061691999435, 75.42474433779716, 74.52749088406563, 73.77282857894897, 71.76236405968666, 73.2977020740509, 70.65151646733284, 70.17013549804688, 68.54355677962303, 65.44927641749382, 66.38450503349304, 63.690115213394165, 63.66362303495407, 61.96561574935913, 53.27352896332741, 52.002839148044586, 45.701971650123596, 51.270234659314156, 38.07335279881954, 3.1903308955952525, 0.06797664536861703, 0.14986337948357686, 0.1345380744896829, 0.25863689195830375, 1.187213638331741, 12.379914298653603, 24.370529986917973, 45.38037210702896, 80.77874064445496, 42.988130673766136, 68.5526990890503, 15.529823675751686, 0.896731634857133, 0.12286283730645664, 0.17195325664943084, 0.058683739334810525, 0.13635633629746735, 0.035886216937797144, 0.039907644313643686, 0.10444296203786507, 0.038359379541361704, 0.11121089613880031, 0.0461514106427785, 0.10348914642236196, 0.045832676769350655, 0.02320176652574446, 0.04237766392179765, 0.0763718198868446, 0.02223931787739275, 0.04500476650719065, 0.03169281168084126, 0.025814671826083213, 0.13129281112924218, 0.09600674675311893, 0.040542963542975485, 0.07480339467292652, 0.05302977631799877, 0.13754513813182712, 0.017928471461345907, 0.03572039517166559, 0.0650001507892739, 0.05483890970936045, 0.004782542027896852, 0.031080630760698114, 0.08899335472960956, 0.0654676889826078, 0.025745969360286836, 0.04684576029831078, 0.09592270595021546, 0.013968001312605338, 0.0795478186046239, 0.07627068742294796, 0.06100623853853904, 0.08595427483669482, 0.07971401515533216, 0.050199440302094445, 0.054512130955117755, 0.046681456224177964, 0.06505408266093582, 0.2437727723736316, 0.26469103584531695, 11.027546916157007, 95.19012093544006, 82.97459721565247, 99.75485399365425, 97.86510899662971, 60.30016511678696, 30.174311958253384, 18.468528985977173, 10.29676727950573, 4.765245448797941, 1.0036942921578884, 0.17935117764864117, 0.7667307544033974, 1.5839681611396372, 25.316261239349842, 53.43102291226387, 55.587027221918106, 65.23901090025902, 68.57780814170837, 69.97191533446312, 57.525911182165146, 50.52941121160984, 60.71217700839043, 66.99532225728035, 68.12722072005272, 69.6377232670784, 74.15111348032951, 77.54534974694252, 78.64780738949776, 75.76025113463402, 72.42907628417015, 67.43242800235748, 62.183712646365166, 56.358294636011124, 53.21731857955456, 46.275205090641975, 41.92422576248646, 34.77369345724583, 33.91921430826187, 29.688399732112885, 29.731533117592335, 31.243851967155933, 28.810538537800312, 22.873596511781216, 19.37992338091135, 40.30555821955204, 47.2594852745533, 28.033107854425907, 4.324888028204441, 0.4603285255143419, 0.18538133532274514, 0.5016528815031052, 4.566830545663834, 1.2584608839824796, 0.9086105693131685, 2.5692729838192463, 7.218978982418776, 14.157630857080221, 39.362334832549095, 40.17130762338638, 31.3004632294178, 2.5673320004716516, 3.0258108861744404, 5.71333447471261, 23.573974929749966, 57.57888413965702, 61.58606171607971, 31.78223367780447, 21.750475578010082, 45.17679043114185, 41.769441068172455, 30.513584353029728, 31.109709665179253, 12.46067801490426, 2.207240522839129, 0.9227459889370948, 0.3882314614020288, 0.1894030484254472, 0.4579277371522039, 6.870290692895651, 44.82290022075176, 14.358766414225101, 16.39444638043642, 21.77755292505026, 27.848585955798626, 31.86478804796934, 30.218423791229725, 28.64144191145897, 25.51509127020836, 35.189527943730354, 45.7541960477829, 54.832186326384544, 59.94177594780922, 62.07236722111702, 68.19818571209908, 68.15955698490143, 74.08406227827072, 74.64319467544556, 72.76047170162201, 72.13140785694122, 71.77641570568085, 71.82066813111305, 66.96420192718506, 70.15084013342857, 67.47148230671883, 70.0043959915638, 64.01860758662224, 68.69836047291756, 67.1919997036457, 61.753169149160385, 58.76062832772732, 50.8248795568943, 57.956925854086876, 41.457827389240265, 3.3841038728132844, 0.2930087788263336, 0.386128660175018, 0.2631798747461289, 0.8331400284077972, 0.823089211480692, 17.446649819612503, 45.84301248192787, 48.32390695810318, 98.56284275650978, 49.9470354616642, 77.78365015983582, 23.736629001796246, 0.8750183531083167, 0.18250723485834897, 0.18876224843552336, 0.22021191398380324, 0.1036624972766731, 0.1116844976786524, 0.011555410019354895, 0.11354236790793948, 0.07241108905873261, 0.0556464702822268, 0.08407635919866152, 0.08214783651055768, 0.04965175758115947, 0.030881195270922035, 0.0062593263828603085, 0.05485603105626069, 0.05718647866160609, 0.03742790999240242, 0.03380826652573887, 0.028482599955168553, 0.0926214549690485, 0.0044259442438487895, 0.145874424779322, 0.2688124490668997, 0.13329785666428506, 0.2891315321903676, 0.11242158390814438, 0.08376300218515098, 0.2302231002249755, 0.19313406228320673, 0.26118976122234017, 0.14127560280030593, 0.09419644076842815, 0.09268409965443425, 0.14652095414930955, 0.09708345460239798, 0.21502168936422095, 0.14146934787277132, 0.1322256017010659, 0.1333323962171562, 0.10315763647668064, 0.23918248509289697, 0.2902095462195575, 0.15182533592451364, 0.1849933256744407, 0.1513490403885953, 0.13202557805925608, 0.2918555703945458, 0.2820355910807848, 13.186011593788862, 115.17009481787682, 99.35396030545235, 118.48114594817162, 118.0816125869751, 80.84096610546112, 48.21319229900837, 29.274083264172077, 12.28639181703329, 7.1960206143558025, 2.2831898974254727, 0.39419066975824535, 1.103567776735872, 2.5416698399931192, 37.704312801361084, 66.22887298464775, 61.64767540991306, 74.39622312784195, 78.87483760714531, 77.68297836184502, 66.00267872214317, 58.58551852405071, 65.54782032966614, 75.24286329746246, 71.22608363628387, 70.69354981184006, 75.7794401049614, 76.30052134394646, 77.57078558206558, 75.67774996161461, 71.15728452801704, 65.78465402126312, 61.16988904774189, 57.261186987161636, 54.01405602693558, 48.62596035003662, 50.612269565463066, 47.39124320447445, 49.727137461304665, 44.197624772787094, 41.68869540095329, 40.384506583213806, 40.093943774700165, 33.92491400241852, 36.766086146235466, 56.763113513588905, 53.34180749952793, 40.94558447599411, 5.143034001812339, 0.3294081537751481, 0.501624858006835, 2.476050923578441, 6.730904672294855, 3.7936912570148706, 0.322033105767332, 4.14223562926054, 16.593177616596222, 21.924424543976784, 45.492127910256386, 47.011521980166435, 43.21383096277714, 5.0511364080011845, 11.51777571067214, 10.496278423815966, 24.220656529068947, 61.50710575282574, 62.579997181892395, 35.60727372765541, 28.97159669548273, 51.64782799780369, 44.363178089261055, 38.11228930950165, 31.74904815852642, 14.32980626821518, 2.7846689382568, 3.2242773240432143, 1.1096986290067434, 0.6421409023460001, 0.5846255854703486, 18.21699198335409, 51.42879255115986, 22.772406041622162, 24.751949720084667, 36.29271134734154, 33.133215084671974, 41.5921463817358, 37.89815180003643, 37.720743119716644, 35.72842262685299, 44.7207996994257, 51.285198256373405, 62.50723868608475, 62.518349289894104, 64.53691497445107, 69.30264204740524, 68.60147327184677, 73.68056952953339, 74.96800124645233, 75.57207763195038, 73.41583773493767, 71.94274038076401, 70.4507428407669, 69.13817167282104, 69.34286668896675, 65.1611302793026, 70.35656109452248, 66.82415664196014, 70.15824973583221, 73.12490254640579, 67.6409912109375, 66.31359323859215, 57.88032576441765, 67.00808197259903, 45.75010746717453, 4.6899045165628195, 1.153195013757795, 0.7854237325955182, 0.5393599800299853, 1.3585665123537183, 0.8453574415761977, 27.3403974249959, 56.0699737071991, 63.59811834990978, 116.30799695849419, 56.746459007263184, 96.9661608338356, 22.89837308228016, 0.9369929681997746, 0.2691321959719062, 0.2600683463970199, 0.2515764255076647, 0.2157651135348715, 0.19370205758605152, 0.14754909585462883, 0.27981134480796754, 0.14695558551466092, 0.25201420357916504, 0.20793677656911314, 0.28546054323669523, 0.11148930541821755, 0.07139892579289153, 0.10055023420136422, 0.1480891418759711, 0.12258148912223987, 0.10872882034163922, 0.12827396218199283, 0.19743891956750304, 0.18347621255088598, 0.09329674998298287], [0.05932554122409783, 0.08840553666232154, 0.10087231145007536, 0.1057770689658355, 0.10993228701408952, 0.04981202437193133, 0.043388513586251065, 0.10196144285146147, 0.009631625016481848, 0.02395773113676114, 0.0481446115009021, 0.07170525466790423, 0.08337817635037936, 0.04469698673347011, 0.027415308104536962, 0.03173361867084168, 0.047580341779394075, 0.05773442113422789, 0.1202958523936104, 0.035063613031525165, 0.012313453571550781, 0.06076817982830107, 0.082894763618242, 0.13949671934824437, 0.08915282742236741, 0.2300779361394234, 0.10791778651764616, 3.8709736475721, 60.93422569334507, 88.33269730210304, 76.33177846670151, 101.15210741758347, 65.64901649951935, 42.06377327442169, 10.100036635994911, 7.090980000793934, 0.6995872885454446, 0.23731148627121001, 0.2360116591444239, 0.489547859178856, 0.24819808022584766, 37.802362740039825, 82.29583963751793, 67.63989686965942, 72.91949316859245, 68.56801986694336, 70.51682129502296, 63.80738452076912, 60.02077370882034, 60.023194178938866, 62.50161498785019, 66.76994875073433, 74.86573353409767, 75.115387737751, 75.73549926280975, 79.77266862988472, 78.2761949300766, 75.25145083665848, 69.6241807937622, 62.56031423807144, 60.15518769621849, 57.1057715266943, 45.02002604305744, 40.64881660044193, 35.009140223264694, 36.04809947311878, 35.1052750647068, 30.38369782269001, 25.204501636326313, 28.785877861082554, 28.782731629908085, 47.69363857805729, 33.38821180164814, 35.58022677898407, 22.131536230444908, 3.155515263788402, 0.5201038008090109, 0.4404246888589114, 0.3895474970340729, 0.3650494694011286, 0.3399634826928377, 0.3002944722538814, 2.601886633783579, 4.766653273254633, 7.260350687429309, 13.644029516726732, 26.11475609242916, 14.72427450120449, 2.051082202233374, 5.574219189584255, 11.193784195929766, 38.97293172776699, 42.320996671915054, 55.353275164961815, 47.335534393787384, 32.213862016797066, 46.539621502161026, 34.1667216271162, 31.46506279706955, 18.062608167529106, 6.71908350661397, 4.4059196300804615, 0.21612628712318838, 0.26187078561633825, 0.4310021741548553, 0.3583291737595573, 4.189811451360583, 23.904010020196438, 14.520095307379961, 14.707322660833597, 28.762454017996788, 24.87578507512808, 35.60897223651409, 27.474100850522518, 33.31327222287655, 32.69202075898647, 35.19302375614643, 41.15541681647301, 53.55472907423973, 56.777142360806465, 65.92523887753487, 66.91438660025597, 71.78732112050056, 76.6042086482048, 72.74979427456856, 73.8321889936924, 69.78248789906502, 72.52295404672623, 69.91231173276901, 78.19434732198715, 69.9641789495945, 71.71086922287941, 67.03446015715599, 63.918566554784775, 64.54537332057953, 62.437124848365784, 51.433093920350075, 53.73279511928558, 47.78252340853214, 63.01581859588623, 32.69377626478672, 0.859740738524124, 0.191807146766223, 0.15275155106792226, 0.03944508222048171, 0.13357745337998495, 0.5307368177454919, 38.850061520934105, 26.20134774595499, 78.2523550093174, 56.68454892933369, 46.831442043185234, 63.93850788474083, 1.3528720429167151, 0.11732179948012345, 0.04543905277387239, 0.05828560679219663, 0.011837798138003564, 0.0858597994374577, 0.030835564321023412, 0.0849993088922929, 0.04648347348847892, 0.12764361163135618, 0.08785829180851579, 0.02023669545451412, 0.10271485632983968, 0.09901674187858589, 0.04718338554084767, 0.02815329047734849, 0.03403531918593217, 0.05665243661496788, 0.030921419674996287, 0.056961010486702435, 0.0782091474684421, 0.023068595546646975, 0.03527964850945864, 0.1435748059884645, 0.0150346799637191, 0.13541391264880076, 0.12471870373701677, 0.024640991250635125, 0.13479650515364483, 0.025426103711652104, 0.012231119708303595, 0.06384268242982216, 0.05231755945715122, 0.020425395778147504, 0.01556650113343494, 0.055468050559284166, 0.023231140730786137, 0.017902770887303632, 0.013327148444659542, 0.06542762042954564, 0.051159170834580436, 0.042094438103958964, 0.07468164534657262, 0.0479365058708936, 0.070041782601038, 0.07382667638012208, 0.17533191363327205, 0.10973051190376282, 0.06404882136848755, 0.1464652782306075, 3.050374430604279, 80.85267707705498, 96.41433924436569, 93.78146052360535, 103.16405385732651, 71.8552614748478, 47.8985083848238, 14.987912904471159, 9.40416382625699, 2.226633969694376, 0.18916119734058157, 0.261963524390012, 0.7035829522646964, 0.11544386157765985, 39.360294342041016, 84.07084599137306, 72.00146242976189, 79.96129050850868, 80.14852166175842, 78.63793551921844, 69.59549233317375, 63.24053853750229, 64.14604514837265, 66.54022067785263, 69.38728630542755, 72.92899265885353, 77.6567217707634, 78.45717921853065, 80.1551941037178, 76.34483456611633, 76.89930841326714, 68.99504095315933, 63.587501719594, 64.58062022924423, 60.72898730635643, 46.785137727856636, 43.024582117795944, 35.60643397271633, 32.291484251618385, 27.972609400749207, 30.93147072941065, 23.209333196282387, 30.63163071870804, 26.932590007781982, 36.87563046813011, 38.127146512269974, 41.63735255599022, 31.353477984666824, 3.7194273294880986, 0.9031684894580394, 0.29001955641433597, 0.5521835794206709, 4.468238186091185, 1.4247115817852318, 0.12387198745273054, 0.9517240058630705, 6.16969283670187, 8.117558564990759, 14.539794400334358, 32.218303978443146, 17.347756326198578, 0.6218495755456388, 4.563942700624466, 11.428984925150871, 44.88651640713215, 52.252375558018684, 59.61464770138264, 50.8900460600853, 37.38817736506462, 48.62635172903538, 40.18754035234451, 37.403015568852425, 19.691586457192898, 8.9281633682549, 3.5845262557268143, 1.4390681614167988, 0.41933769069146365, 0.4384047706844285, 0.40997015428729355, 7.977943606674671, 39.137991070747375, 17.511155158281326, 11.12179420888424, 25.426160842180252, 25.954260304570198, 33.92453022301197, 27.41580057889223, 34.540910348296165, 32.95407749712467, 38.78057084977627, 45.726324543356895, 56.83349333703518, 61.339853927493095, 68.37780967354774, 69.05138432979584, 70.757295191288, 75.29886469244957, 72.3250986635685, 72.05415800213814, 69.56126376986504, 72.3683251440525, 69.90950748324394, 76.83082088828087, 70.06162852048874, 71.72625079751015, 70.51654770970345, 68.30682188272476, 68.34187880158424, 67.37059772014618, 59.02839615941048, 65.44666975736618, 61.09504446387291, 64.66605484485626, 35.26792533695698, 1.1457573878578842, 0.2778846997534856, 0.05107220225909259, 0.23138335905969143, 0.41846525156870484, 0.42241059767547995, 44.293847009539604, 40.97328118979931, 74.84153643250465, 77.33158841729164, 52.80139669775963, 78.14974531531334, 2.890269309282303, 0.22771976189687848, 0.032718348447815515, 0.07007921652984805, 0.028952854408998974, 0.12373120945994742, 0.029342047782847658, 0.050423906577634625, 0.06822891620686278, 0.0768725766101852, 0.0243697919358965, 0.0601400482992176, 0.06875486142234877, 0.0392755088978447, 0.013598378372989828, 0.047219817570294254, 0.0337458259309642, 0.029889209145039786, 0.09108808138989843, 0.08499049217789434, 0.06417948388843797, 0.051672985646291636, 0.09214750461978838, 0.28993504063691944, 0.17124352598330006, 0.27965243614744395, 0.15795041428646073, 0.18123918649507686, 0.150190859567374, 0.14778837910853326, 0.21726512757595628, 0.12137640456785448, 0.11495508311782032, 0.12176343458122574, 0.15648817556211725, 0.15255048841936514, 0.1346652934444137, 0.1111542628495954, 0.12925803515827283, 0.1788545769522898, 0.2102800039574504, 0.27578866691328585, 0.1541405843454413, 0.20119483990129083, 0.268070746678859, 0.20399058441398665, 0.3494985366705805, 0.17378407559590414, 0.4773107642540708, 0.13400614756392315, 4.642019961029291, 100.28677985072136, 110.24783134460449, 105.22399932146072, 116.20923265814781, 89.04433831572533, 68.19107249379158, 24.44255892187357, 13.512329533696175, 4.863274963572621, 0.7714533666148782, 0.2799985441379249, 1.365242872852832, 0.4354323504958302, 47.140114679932594, 97.8597740828991, 79.46097895503044, 88.71799662709236, 82.88859263062477, 86.64521545171738, 76.78680405020714, 71.98187828063965, 70.20599037408829, 67.5175130367279, 71.29767939448357, 76.79170578718185, 77.88850173354149, 78.59609216451645, 81.61888316273689, 78.09972479939461, 76.51522502303123, 69.28784564137459, 63.11349615454674, 65.04972785711288, 61.38075493276119, 50.09964667260647, 50.67740187048912, 46.45641356706619, 44.241409823298454, 42.076947167515755, 41.4367651194334, 33.73222254216671, 36.832894161343575, 40.30546322464943, 53.529160246253014, 48.32668460905552, 39.851455986499786, 45.228817239403725, 6.471156310290098, 1.081529671791941, 0.7675893895793706, 0.4993592295795679, 5.970007376745343, 2.7904657647013664, 0.3108253696700558, 2.664711275137961, 6.460738694295287, 12.117512729018927, 19.3795358017087, 40.97093291580677, 32.258787006139755, 5.5125560984015465, 15.017135236412287, 14.677575957030058, 45.89641101658344, 55.586502850055695, 63.112618401646614, 53.119686618447304, 40.86237274110317, 51.64498955011368, 38.502680361270905, 47.26013123989105, 19.54955767840147, 14.272378999739885, 3.742142510600388, 4.937843587249517, 0.6661325180903077, 0.6173792341724038, 0.43495182471815497, 15.421930365264416, 44.894161596894264, 25.69594256579876, 25.494112595915794, 37.4084796756506, 31.083627864718437, 41.00592143833637, 34.43473644554615, 40.65238460898399, 43.63542214035988, 45.70872388780117, 50.885345712304115, 60.89971974492073, 63.41365344822407, 69.4608123600483, 68.58894154429436, 72.59020283818245, 75.80700382590294, 75.15152379870415, 73.08139488101006, 70.93242779374123, 72.8884944319725, 70.81745356321335, 77.07039043307304, 70.12336760759354, 71.87563598155975, 69.23796951770782, 69.10673215985298, 73.82743164896965, 70.14687314629555, 65.88387429714203, 68.49257871508598, 61.55872978270054, 74.92885574698448, 38.61425377428532, 1.3840446202084422, 0.5035821092315018, 0.3677993343444541, 0.27627040981315076, 0.5008865694981068, 1.1156527907587588, 66.10437646508217, 47.475097104907036, 101.46065846085548, 83.21839973330498, 65.35494267940521, 88.26668724417686, 1.7324911477044225, 0.17188907571835443, 0.06805459313909523, 0.15304677741369233, 0.2468504142598249, 0.19663382292492315, 0.1768488041125238, 0.19412831752561033, 0.14436829544138163, 0.18155091820517555, 0.18858548370189965, 0.09341363824205473, 0.18399561202386394, 0.16164576052688062, 0.17368189670378342, 0.19848117692163214, 0.1348141088965349, 0.12170663801953197, 0.1310591385117732, 0.2513996756169945, 0.21743352088378742, 0.15087448147824034, 0.1755610591499135], [0.03703417467477266, 0.03859436576021835, 0.09753479913342744, 0.061468411004170775, 0.06308008858468384, 0.01131546347096446, 0.019306864196551032, 0.04996011994080618, 0.07667891317396425, 0.05313982939696871, 0.02028961058385903, 0.07041892720735632, 0.06057852027879562, 0.07618543691933155, 0.026608085208863486, 0.061656727266381495, 0.02286442515469389, 0.040757147362455726, 0.06934963341336697, 0.16547083418117836, 0.010164256982534425, 0.11228807154111564, 0.05677371096680872, 0.05289909524435643, 0.053759185029775836, 0.10066759743494913, 0.14868559112073854, 0.24185188638512045, 43.82094718515873, 95.6467804312706, 64.03650462627411, 100.44664487242699, 79.54500764608383, 45.43622151017189, 9.758034087717533, 1.5643775998614728, 0.5296948424074799, 0.07235123484861106, 0.4334202397149056, 0.33590182720217854, 0.15145316370762885, 20.959494821727276, 80.64393147826195, 61.45957790315151, 59.450268521904945, 64.2506991326809, 64.29989129304886, 63.21598045527935, 54.63633343577385, 64.09207284450531, 67.92947933077812, 71.75805509090424, 78.74600172042847, 79.75113898515701, 80.22118896245956, 77.56583824753761, 81.78491145372391, 79.57123383879662, 73.22976171970367, 69.55310180783272, 59.824077263474464, 57.17160679399967, 48.8786543905735, 37.262578904628754, 29.486341774463654, 36.62699081003666, 41.29702761769295, 33.32893878221512, 30.482070744037628, 21.240358650684357, 26.31642647087574, 26.02722778916359, 13.315141964703798, 30.08109536021948, 28.602003827691078, 5.74327259324491, 0.37797171506099403, 0.21133521921001375, 0.27416701486799866, 0.1760412286967039, 0.10862550596357323, 0.52096783882007, 1.4095594198442996, 1.0285589704290032, 2.148729362525046, 4.878495521843433, 12.647044714540243, 19.299217611551285, 1.1467358353547752, 3.4006453352048993, 10.417988374829292, 37.46526762843132, 47.19686083495617, 47.05395810306072, 36.52416452765465, 24.452485889196396, 33.62884148955345, 32.33626864850521, 36.63348466157913, 21.579722240567207, 2.508380776271224, 0.8681458281353116, 1.2260059942491353, 0.13848045200575143, 0.24814788135699928, 0.21930594462901354, 4.425744116306305, 17.971452958881855, 9.215253163129091, 14.534447137266397, 18.84254101663828, 26.295113414525986, 29.388438127934933, 25.485348366200924, 32.469968274235725, 32.08491213619709, 31.397990696132183, 43.462200835347176, 51.225412264466286, 64.62583780288696, 69.00194898247719, 67.60136693716049, 74.52688291668892, 71.78530722856522, 75.17518892884254, 70.68815410137177, 75.28160601854324, 72.33486413955688, 75.20975947380066, 70.78794434666634, 74.54527392983437, 69.29649397730827, 68.8590082526207, 64.09315958619118, 68.19933325052261, 56.57175198197365, 50.34026496112347, 38.49061980843544, 35.61297342181206, 56.316398084163666, 16.793079189956188, 0.17291421914706007, 0.1439237192971632, 0.23187528422567993, 0.2983314619632438, 0.8066099707502872, 19.078713543713093, 40.84967382252216, 35.6936164945364, 91.97657257318497, 43.701815977692604, 79.96274203062057, 24.68163639307022, 0.4897906305268407, 0.12667258561123163, 0.19949667243054137, 0.0710507323674392, 0.046245136472862214, 0.0449557773390552, 0.05694398561900016, 0.08935852107242681, 0.03323048229503911, 0.03345895616803318, 0.06819513364462182, 0.028613253198273014, 0.06031414872268215, 0.04778698908921797, 0.05091312661534175, 0.08507464430294931, 0.009858187859208556, 0.004974834346285206, 0.029213645102572627, 0.01382386231853161, 0.05724040682252962, 0.03292832428996917, 0.15447217592736706, 0.05313836365530733, 0.07773555335006677, 0.10632818040903658, 0.010256004989059875, 0.08842279159580357, 0.009728180284582777, 0.08195408401661552, 0.048467015294590965, 0.08926866183173843, 0.04259128741978202, 0.08756955183343962, 0.040206859703175724, 0.024139687193382997, 0.03120428926195018, 0.05306808598106727, 0.0105380266722932, 0.03510489870677702, 0.08001439942745492, 0.1358533086022362, 0.06032422337739263, 0.12161668972112238, 0.03499666760035325, 0.011007109460479114, 0.07833500087144785, 0.03865268001391087, 0.02120779754477553, 0.10329428070690483, 0.5524368595797569, 65.18864080309868, 103.04798528552055, 76.629249304533, 107.36526802182198, 83.35923537611961, 64.64062660932541, 17.873180732131004, 1.9539728318341076, 0.40723323239944875, 0.13721718307351694, 0.47562638588715345, 0.46092589502222836, 0.18847787228878587, 25.79128134995699, 81.41690120100975, 64.57823395729065, 67.19812497496605, 74.38616886734962, 78.40218856930733, 67.3476393520832, 61.22652120888233, 69.79477643966675, 75.51731497049332, 73.8965879380703, 83.53414759039879, 78.52721706032753, 83.64811107516289, 78.84497120976448, 84.81534004211426, 79.20399114489555, 74.92582350969315, 66.89773589372635, 62.777654975652695, 57.549500316381454, 48.45825634896755, 39.518403857946396, 32.992976009845734, 39.0426579862833, 37.85158149898052, 31.526106521487236, 28.660490289330482, 23.079503662884235, 23.55110965669155, 30.952529199421406, 19.92264825850725, 37.99516439437866, 32.59359464049339, 8.76457929611206, 0.2253878299961798, 0.22308773623080924, 0.42852405400481075, 1.2163777858950198, 0.6729928124696016, 0.18415069120237604, 1.520421914756298, 1.7486544116400182, 2.8568417904898524, 6.28047114238143, 14.81851514428854, 20.74847884476185, 0.15543416258879006, 3.4097456093877554, 15.436493083834648, 43.270588517189026, 54.166948422789574, 49.82236795127392, 40.45688509941101, 25.66181279718876, 41.414532512426376, 38.1727896630764, 44.55390125513077, 26.457030326128006, 2.4182303762063384, 3.347583319991827, 0.8014557254500687, 0.5295771081000566, 0.3825512115145102, 0.10041307046776637, 9.343178048729897, 32.4764621257782, 12.495411951094866, 7.7824977692216635, 21.71244151890278, 29.452952966094017, 28.709498159587383, 27.441939376294613, 36.430366560816765, 36.23229838907719, 34.73407678306103, 48.05897757411003, 52.285965755581856, 67.44724720716476, 70.3514389693737, 68.84231954813004, 73.00067201256752, 71.66572004556656, 72.91861921548843, 70.37160068750381, 74.0039549767971, 72.84734264016151, 75.15030026435852, 72.32582062482834, 71.76537349820137, 72.66797706484795, 69.47269052267075, 67.82249987125397, 70.21640181541443, 61.72009192407131, 57.0472052693367, 48.86659003794193, 44.58691008388996, 63.38468760251999, 17.750204131007195, 0.3287119301967323, 0.10586215619696304, 0.3393881698139012, 0.29938299616333097, 0.6097846291959286, 11.051034405827522, 59.62356962263584, 38.61375220119953, 98.54231625795364, 53.578075021505356, 76.7713312804699, 39.293725714087486, 0.7896886474918574, 0.18562467070296407, 0.08710725320270285, 0.07190795004134998, 0.025452776499150787, 0.0444817342213355, 0.03535677620675415, 0.032469291109009646, 0.06770585794583894, 0.08092028714600019, 0.02221534465206787, 0.06364445478538983, 0.0362677587690996, 0.0448797331773676, 0.04939487800584175, 0.040666523709660396, 0.04143989353906363, 0.020442775021365378, 0.02118939970387146, 0.06064293498639017, 0.16086136980447918, 0.08143964209011756, 0.13176787470001727, 0.2638101065531373, 0.11150106103741564, 0.17271008400712162, 0.10625052949762903, 0.17766568606020883, 0.27483874757308513, 0.11549985661986284, 0.14778401528019458, 0.17707553022773936, 0.1672310006688349, 0.09989096215576865, 0.09047966872458346, 0.18441718159010634, 0.1882018378819339, 0.10419454294606112, 0.09503842215053737, 0.2701023907866329, 0.11714165055309422, 0.3833655850030482, 0.19218835834180936, 0.12905695766676217, 0.1544877907144837, 0.19175256922608241, 0.22767499554902315, 0.12371822929708287, 0.11299342353595421, 0.20506551110884175, 0.28519829793367535, 73.39137464761734, 119.38217639923096, 86.85587614774704, 125.34058347344398, 100.33752232789993, 77.34569326043129, 24.995963126420975, 3.019040124490857, 1.6708184382878244, 0.31766120286192745, 1.4873766317032278, 1.611072225496173, 0.795879999641329, 27.558752708137035, 100.0441400706768, 71.61048620939255, 78.4641632437706, 80.157929956913, 84.02584880590439, 77.4120756983757, 67.92489677667618, 75.51517188549042, 82.14512452483177, 77.51865237951279, 84.60174590349197, 80.09476214647293, 84.53707337379456, 77.3493866622448, 83.67043107748032, 79.85053405165672, 75.48920407891273, 66.89608678221703, 63.72031979262829, 56.63457781076431, 50.986849665641785, 43.67305152118206, 40.50116412341595, 45.66228657960892, 50.33139243721962, 42.266287207603455, 37.615465968847275, 27.69177597016096, 33.56924928724766, 30.68846996873617, 20.693602189421654, 39.16812725365162, 42.166626155376434, 15.358032993972301, 0.40442265977617353, 0.4423094470985234, 0.6164133735001087, 0.4987510247156024, 0.4831858427496627, 0.5226211063563824, 1.6555022913962603, 1.871535424143076, 1.222462565638125, 6.210647989064455, 21.296403743326664, 27.75022253394127, 3.405093946494162, 7.2519840113818645, 19.914746582508087, 47.96655513346195, 59.2851559817791, 55.74488215148449, 52.56037563085556, 29.222594127058983, 38.645320907235146, 35.44865503907204, 47.53602683544159, 27.357817590236664, 2.5793215446174145, 3.7183676613494754, 3.5282208770513535, 0.7759447256103158, 0.5540680408012122, 0.41854106937535107, 13.632081057876348, 34.407890886068344, 16.399893388152122, 26.236718147993088, 29.093262366950512, 36.12347982823849, 37.608785927295685, 31.32091373205185, 39.0880161523819, 42.50807583332062, 40.810015350580215, 55.29446192085743, 58.26496012508869, 72.69573077559471, 72.70354315638542, 71.23282447457314, 75.77861934900284, 74.67968791723251, 75.36822617053986, 71.25506848096848, 75.85906863212585, 73.72193410992622, 75.27454599738121, 72.86924466490746, 74.83365565538406, 73.86381849646568, 70.34887030720711, 71.697828322649, 72.33456775546074, 68.80167692899704, 62.639080211520195, 49.15813319385052, 47.349263057112694, 70.37530928850174, 20.134790875017643, 0.6330520869232714, 0.21355642267735675, 0.7416121428832412, 0.8076564583461732, 0.973027681466192, 32.29526124894619, 66.51438966393471, 53.501737117767334, 118.85353356599808, 61.13265484571457, 100.25606229901314, 34.25186365842819, 0.7598907058127224, 0.2623908530222252, 0.2466175431618467, 0.1302607954130508, 0.23618719191290438, 0.1986179398954846, 0.12728202244034037, 0.20185342174954712, 0.2439601646619849, 0.1578153730952181, 0.1593382452847436, 0.15478862769668922, 0.1463202032027766, 0.12521658092737198, 0.10565348653472029, 0.1834136198158376, 0.07939956718473695, 0.11930352673516609, 0.10307705408195034, 0.2188528041006066, 0.23347829352132976, 0.12390237097861245, 0.2612642728490755], [0.07313886875635944, 0.029740974423475564, 0.05747645060182549, 0.01156985221314244, 0.052738887825398706, 0.037126724200788885, 0.018493201314413454, 0.04159446063567884, 0.04846292235015426, 0.08976736280601472, 0.06213890061189886, 0.0605383552465355, 0.06826459124567918, 0.056661516791791655, 0.03237094540963881, 0.023552082493552007, 0.03322354321426246, 0.05437748310214374, 0.04812857740034815, 0.03488038790237624, 0.11880156773258932, 0.11570491944439709, 0.035012994849239476, 0.025313473524875008, 0.1468643607222475, 0.17661998514086008, 0.15617816563462839, 1.0393254552036524, 17.59301796555519, 105.2865819633007, 64.86302107572556, 73.04788827896118, 94.48883056640625, 53.694850355386734, 40.05913384258747, 2.0251459814608097, 0.44571130361873657, 0.23898727056803182, 0.8976779028307647, 0.46549702004995197, 0.0836583148338832, 13.132438268512487, 68.86227607727051, 67.83323809504509, 57.61714808642864, 67.63175010681152, 70.41573151946068, 66.219821870327, 55.0865712761879, 54.5015774667263, 65.46142816543579, 71.73657864332199, 78.18516701459885, 87.29741245508194, 85.45245185494423, 76.05340540409088, 76.40262946486473, 80.64365029335022, 78.21798965334892, 67.42037504911423, 68.81881400942802, 58.39943490922451, 48.67753878235817, 38.22545863687992, 27.406825460493565, 29.28624451160431, 33.66109035909176, 34.68258574604988, 26.196658797562122, 25.0442623347044, 21.67861383408308, 11.628997642546892, 13.277750071138144, 26.175769418478012, 24.921770207583904, 6.404337370768189, 0.6874922406859696, 0.5362877261359245, 0.10848144767805934, 0.3860865655587986, 0.2814275643322617, 0.3032868116861209, 0.3867061994969845, 0.9760671621188521, 2.997966930270195, 1.3919610204175115, 2.2527122078463435, 8.538880906999111, 0.7599515025503933, 1.647612014785409, 5.071911793202162, 29.540496468544006, 36.00561015307903, 18.492807783186436, 14.050571601837873, 15.620880089700222, 26.596862822771072, 24.849256798624992, 24.973732419312, 8.912891987711191, 8.513917196542025, 0.7020408287644386, 0.7298178726341575, 0.12708572437986732, 0.10244326738757081, 0.35577799659222364, 5.6242273561656475, 17.328759245574474, 6.63391487672925, 19.1339872777462, 25.235667563974857, 26.559676118195057, 35.356950759887695, 25.31332589685917, 36.216681227087975, 30.17461024224758, 26.50323584675789, 37.84817688167095, 50.476240664720535, 62.488353699445724, 67.55706891417503, 68.96313786506653, 75.10160967707634, 75.9451188147068, 70.5187363922596, 71.92147672176361, 72.93998926877975, 70.88512033224106, 76.59565910696983, 74.62546482682228, 74.9238096177578, 70.7671594619751, 64.49966937303543, 63.125412315130234, 66.32451385259628, 55.375313982367516, 46.71408534049988, 42.26504847407341, 31.272367537021637, 30.850725062191486, 3.972060098312795, 0.19109529355773702, 0.17065308813471347, 0.08655284662381746, 0.5985413293819875, 4.875770593062043, 56.039993315935135, 24.20476008206606, 80.5445896089077, 64.14525479078293, 55.507508888840675, 73.99958521127701, 2.41123020183295, 0.3346051467815414, 0.05901662967517041, 0.14077364379772916, 0.032428469276055694, 0.14914983417838812, 0.14389787771506235, 0.08645837122458033, 0.07890609093010426, 0.17835502250818536, 0.0786356745811645, 0.1706552255200222, 0.01991937908314867, 0.08135303345625289, 0.052818664989899844, 0.0720572033606004, 0.0461744506174, 0.017308442329522222, 0.029593903018394485, 0.07270411122590303, 0.10287250333931297, 0.038834532169857994, 0.04933899428579025, 0.043305578583385795, 0.030613088856625836, 0.024907793340389617, 0.021106299573148135, 0.0852263615524862, 0.01892079340905184, 0.03287968393124174, 0.030532576965924818, 0.033356803251081146, 0.03379971327376552, 0.03164494686643593, 0.02840966724761529, 0.08271833285107277, 0.05038325172790792, 0.06038193649146706, 0.02446299826260656, 0.05153458252607379, 0.047467706026509404, 0.05360796130844392, 0.03289922467956785, 0.08677835561684333, 0.08689160735229962, 0.16447613365016878, 0.07789613926433958, 0.11442965740570799, 0.09945245677954517, 0.2872863452648744, 0.2426394386566244, 1.2403973657637835, 33.02633821964264, 114.47203427553177, 74.7814616560936, 96.29546642303467, 92.85714492201805, 68.76121670007706, 44.82291541993618, 0.5425078142434359, 0.2899063640506938, 0.2771397022297606, 0.3976620506728068, 0.5544631008524448, 0.23162981146015227, 15.789023917168379, 79.05468955636024, 73.85822519659996, 66.18228748440742, 65.42882591485977, 75.15037626028061, 77.48404383659363, 63.224457800388336, 62.39891029894352, 71.11550956964493, 74.03990864753723, 79.6277368068695, 88.01647067070007, 85.57519286870956, 78.28162863850594, 79.36472252011299, 80.68173184990883, 77.84540444612503, 70.2921849489212, 68.82872387766838, 61.331433579325676, 53.57289969921112, 41.54725939035416, 32.083080634474754, 32.01188385486603, 36.169708147645, 32.32782170176506, 26.61739692091942, 23.97277683019638, 24.95146371424198, 24.253486767411232, 17.0420703291893, 30.821728818118572, 29.882079139351845, 6.957176830619574, 0.3622110513970256, 0.9120063995942473, 0.1171772662200965, 0.5757922469638288, 1.1318560712970793, 0.3754918137565255, 0.3967438358813524, 0.8583558315876871, 3.4632370015606284, 0.6003029504790902, 2.4869888741523027, 10.590291079133749, 1.4652305888012052, 0.8349462377373129, 5.047380784526467, 30.50542239099741, 36.925875172019005, 22.662757225334644, 18.736034631729126, 18.030621483922005, 31.409747265279293, 29.14822641760111, 28.423905484378338, 11.768149975687265, 8.622190486639738, 1.1563369701616466, 0.9760219801682979, 0.10729904315667227, 0.1472651056246832, 0.42804438911844045, 9.384246245026588, 31.19967743754387, 7.975332196801901, 10.339305996894836, 27.387212812900543, 24.067826829850674, 32.56623990833759, 27.05383960157633, 38.86333420872688, 33.55149284005165, 36.5926368534565, 43.93023692071438, 55.252139791846275, 67.44242146611214, 67.97908186912537, 69.38633635640144, 73.78137052059174, 75.78431904315948, 66.7694091796875, 72.28328570723534, 71.98794275522232, 69.12231892347336, 75.3043819963932, 73.14588502049446, 76.50029942393303, 71.939138174057, 67.21151545643806, 69.37074199318886, 69.76936340332031, 61.68665751814842, 56.07844725251198, 46.014759466052055, 32.777774557471275, 34.418465718626976, 4.751753797754645, 0.17010719398967922, 0.2111262155813165, 0.2542132168309763, 0.40134408278390765, 0.5474179226439446, 67.14419066905975, 39.04029831290245, 64.76673424243927, 84.31122109293938, 57.1671724319458, 91.98052436113358, 6.00184396840632, 0.31089388474356383, 0.04995113253244199, 0.17204295261763036, 0.02358201330935117, 0.053552196332020685, 0.11084454235970043, 0.07199167172075249, 0.06003346476063598, 0.19170985120581463, 0.03300672477053013, 0.13713747641304508, 0.04614908029907383, 0.0859465565008577, 0.012688334627455333, 0.04852751888392959, 0.04050805662700441, 0.08700079211848788, 0.02686413728952175, 0.038860997156007215, 0.0306584006830235, 0.02307439543073997, 0.0444099833839573, 0.04317995895689819, 0.11611505251494236, 0.14399193751160055, 0.1674583798740059, 0.3262888774042949, 0.11948052895604633, 0.18758330232230946, 0.14226792845875025, 0.18329354032175615, 0.1631551404716447, 0.17175262444652617, 0.14821119548287243, 0.2599971299059689, 0.1504097189172171, 0.2705616020830348, 0.10964238186716102, 0.1778100337833166, 0.12862271221820265, 0.16265940066659823, 0.1726622154819779, 0.213812522997614, 0.17272479337407276, 0.2369311504298821, 0.12575408880366012, 0.20457446167711169, 0.27929000090807676, 0.5419835611246526, 0.3152330144075677, 1.3667213497683406, 34.54763598740101, 132.99125254154205, 90.0170861184597, 103.41189175844193, 113.49691540002823, 80.22270128130913, 64.13735121488571, 2.488212171010673, 0.6257433572318405, 0.33762877515982836, 2.2856018180027604, 1.4517909474670887, 0.385748264961876, 18.054613396525383, 85.32224804162979, 86.19395926594734, 74.21496525406837, 82.21946373581886, 89.39518868923187, 86.86086148023605, 70.74019610881805, 65.38985520601273, 75.84089040756226, 76.91769182682037, 81.78535982966423, 88.83497714996338, 90.18309161067009, 80.80122783780098, 78.49329248070717, 81.3610365986824, 80.73522537946701, 67.6060862839222, 72.45907187461853, 60.63719563186169, 57.72893808782101, 47.1820530295372, 38.29417034983635, 37.39317029714584, 44.634008556604385, 43.08504067361355, 34.00484271347523, 33.64831544458866, 28.48942916840315, 21.422279588878155, 21.475486233830452, 38.71383123099804, 32.58372277021408, 12.627727501094341, 1.3627458130940795, 2.701495438814163, 0.6505018193274736, 0.5173715099226683, 0.7643740496132523, 0.22113087092293426, 0.5366422946099192, 1.1758727906271815, 4.202469997107983, 0.8915143960621208, 4.34158100746572, 13.678446169942617, 3.4962092572823167, 2.556212372146547, 6.8340567871928215, 36.21348559856415, 41.3116530328989, 26.814703233540058, 26.004626601934433, 17.77331069111824, 30.93660995364189, 26.101964078843594, 35.559453293681145, 17.908125557005405, 15.864918194711208, 2.234390778467059, 0.8936662087216973, 0.22414801293052733, 0.1938943035202101, 0.644687240710482, 12.11452228948474, 35.22788688540459, 11.91043809056282, 30.119040124118328, 35.03138802945614, 35.15874959528446, 42.51727893948555, 32.59932093322277, 46.44721046090126, 39.90375638008118, 42.3007133603096, 48.49435441195965, 57.32294127345085, 69.5891846716404, 70.13634771108627, 72.1876372396946, 78.38049933314323, 78.4948579967022, 70.67272692918777, 71.98367178440094, 76.3525253534317, 69.61215823888779, 76.7509263753891, 74.171252399683, 78.00818011164665, 73.4234069287777, 70.12009978294373, 70.04690051078796, 77.20199257135391, 64.860999584198, 61.395163759589195, 54.761217534542084, 44.35998626053333, 39.19672071933746, 5.6202256958931684, 0.24400488648097962, 0.6740556273143739, 0.41306289145722985, 1.6122484998777509, 12.089618425816298, 82.30698823928833, 41.28543823957443, 98.17923054099083, 89.5385093986988, 71.07127234339714, 100.69442957639694, 3.8603033451363444, 0.5907925951760262, 0.1310881119570695, 0.22172442579176277, 0.11188245072844438, 0.13810301054036245, 0.2790103596635163, 0.12419810198480263, 0.16800755431177095, 0.3153237048536539, 0.1457018160726875, 0.4043943394208327, 0.1494532241486013, 0.16729855095036328, 0.19074217969318852, 0.20872223598416895, 0.07895876115071587, 0.2536786923883483, 0.12596609070897102, 0.158510513138026, 0.21498391404747963, 0.11246917783864774, 0.16600507660768926, 0.20007547340355814], [0.030605708197981585, 0.007844014835427515, 0.0409911316819489, 0.0652345284470357, 0.05737368541304022, 0.059911633798037656, 0.08419283927651122, 0.04149848609813489, 0.027696259239746723, 0.1545164524577558, 0.1500582229346037, 0.03581814715289511, 0.08575252199079841, 0.02752812382823322, 0.06059380481019616, 0.04071611772815231, 0.028163222268631216, 0.009968941340048332, 0.03670937003334984, 0.05430876393802464, 0.013731139315495966, 0.09591438647476025, 0.11510561293107457, 0.019864562200382352, 0.03320535317470785, 0.07911060456535779, 0.05122264672536403, 0.1790450417320244, 0.9167867212090641, 78.5376589000225, 84.28968384861946, 67.81889766454697, 106.0134905576706, 65.8350621163845, 57.93129622936249, 17.667668759822845, 0.31244601239450276, 0.6857809075154364, 0.07583831960801035, 0.493997479788959, 0.37818088196218014, 2.1266420977190137, 38.22701655328274, 78.90884578227997, 57.19317823648453, 69.83303278684616, 73.19811701774597, 60.70591874420643, 58.534000888466835, 59.44531738758087, 64.83430221676826, 73.49120289087296, 77.01860681176186, 83.60052242875099, 82.19764530658722, 78.23286205530167, 75.0677838921547, 77.71393910050392, 81.33326008915901, 70.28207749128342, 62.4498275667429, 62.470544055104256, 50.51035903394222, 35.25461845099926, 21.5514175593853, 27.13680624961853, 34.01693366467953, 27.924220897257328, 29.178503192961216, 33.75645004212856, 15.71250457316637, 14.339196514338255, 12.754589393734932, 23.65728735923767, 22.735365629196167, 7.6004899106919765, 0.3371588175650686, 0.20590462780091912, 0.707222088240087, 0.42869356053415686, 0.6997085851617157, 0.7417915051337332, 0.20975860068574548, 0.9651058190502226, 1.4696520077995956, 2.852807594463229, 2.3962046205997467, 1.223904825747013, 0.2731117996154353, 1.2414338788948953, 1.5099400584585965, 8.8227104768157, 17.24025249481201, 13.93416864797473, 6.55785720795393, 10.109520927071571, 16.741799041628838, 12.918783333152533, 9.351242166012526, 3.6555335205048323, 2.3112409422174096, 0.8343922393396497, 0.8379627414979041, 0.0891553952533286, 0.2734408975811675, 0.38741100230254233, 6.710741054266691, 13.810263946652412, 15.090925376862288, 36.85642629861832, 13.740432243794203, 27.331714890897274, 24.33184616267681, 26.232306584715843, 32.98029609024525, 31.343085542321205, 18.439116664230824, 28.10970414429903, 46.76565237343311, 59.29561302065849, 67.4803814291954, 66.97613328695297, 73.80447328090668, 70.62905207276344, 68.57830971479416, 67.54429399967194, 71.8003848195076, 71.84478923678398, 76.85260131955147, 72.32679337263107, 70.69104954600334, 67.77336090803146, 60.71360193192959, 62.2026090323925, 59.35539901256561, 44.95863273739815, 50.957530438899994, 42.15020723640919, 36.780388578772545, 12.07073723897338, 0.6513447209727019, 0.22325035562971607, 0.01653173840168165, 0.6586655031424016, 2.324197059497237, 44.58336107432842, 24.605592973530293, 53.48712310194969, 99.57406729459763, 51.36874817311764, 76.56129375100136, 25.80452933907509, 0.4035103227943182, 0.13468053715769202, 0.22511253773700446, 0.23226767254527658, 0.06503260490717366, 0.15094673697603866, 0.06857298329123296, 0.18501104816095904, 0.009615978688088944, 0.098791900818469, 0.051097657924401574, 0.054765537279308774, 0.04708715125161689, 0.06488093218649738, 0.06014428967318963, 0.051592414383776486, 0.028509326548373792, 0.01395217223034706, 0.06426123887649737, 0.009051382421603194, 0.13494595885276794, 0.04035186051623896, 0.08314404360135086, 0.02515099142328836, 0.011465366169431945, 0.03444514426519163, 0.05584482409176417, 0.05778545862995088, 0.04807356199307833, 0.026387222060293425, 0.05836785159772262, 0.008648762668599375, 0.03274439040978905, 0.14893149433191866, 0.026338726420362946, 0.054779196507297456, 0.011326133699185448, 0.02494332737114746, 0.013001135957892984, 0.059328962524887174, 0.05844355808221735, 0.029683587854378857, 0.0629551628662739, 0.08106674256850965, 0.020491558243520558, 0.05257092125248164, 0.007049178384477273, 0.11375050322385505, 0.0444811813213164, 0.09115500084590167, 0.024692401675565634, 0.6025619292631745, 5.049909073859453, 102.89120569825172, 91.44747376441956, 83.00049662590027, 109.69535619020462, 71.32704421877861, 74.70996469259262, 12.877424452453852, 0.44836222543381155, 0.197036438039504, 0.5459279869683087, 0.5836360948160291, 0.11974165361607447, 3.138732514344156, 43.6490748077631, 79.6152126789093, 62.000125497579575, 82.64273822307587, 81.46922439336777, 67.04489439725876, 65.07729157805443, 64.3548059463501, 71.37578040361404, 76.84929549694061, 79.14146929979324, 85.04335060715675, 82.29296699166298, 78.32071334123611, 77.01832562685013, 79.1152735054493, 80.82382142543793, 70.92656090855598, 64.38631385564804, 62.792181596159935, 55.40491059422493, 41.376226767897606, 29.3987849727273, 32.761044055223465, 39.37390901148319, 30.106559693813324, 29.221780970692635, 31.11679818481207, 17.559746950864792, 17.673130966722965, 15.878476817160845, 28.64711120724678, 29.71070073544979, 6.565467249602079, 0.12616608466487378, 0.3173983935266733, 0.9663247817661613, 2.417741152457893, 1.1663673631846905, 0.4528334573842585, 0.8727450063452125, 2.203037473373115, 4.812849294394255, 3.8731267070397735, 5.025465460494161, 0.8860197721514851, 0.9409428562503308, 1.8547641928307712, 3.3166470425203443, 10.050178561359644, 18.24197754263878, 15.20561272278428, 7.818105183541775, 12.629635948687792, 15.437688119709492, 12.677660621702671, 10.079687777906656, 5.675131324678659, 4.722941843792796, 2.3359883017838, 0.479574641212821, 0.2846904908074066, 0.534362654434517, 0.45399619499221444, 13.474944289773703, 26.68043363839388, 16.846141442656517, 36.05347238481045, 15.65048810094595, 26.55907765030861, 27.418093755841255, 24.532180912792683, 37.25899949669838, 38.67231845855713, 26.83522593230009, 37.976670786738396, 51.64949230849743, 64.25762996077538, 69.52055275440216, 67.4544820189476, 73.38451221585274, 68.39172452688217, 67.48196974396706, 68.8058491051197, 72.56547376513481, 73.93362835049629, 75.90374663472176, 71.50593861937523, 71.93619713187218, 71.64580911397934, 64.19078394770622, 64.59462627768517, 65.26415035128593, 55.39568088948727, 59.006459936499596, 38.116993457078934, 33.09054717421532, 13.611280974000692, 0.5910356633830816, 0.0711684518319089, 0.08301959285745397, 0.16345686803106219, 3.8581113377586007, 47.29407861828804, 50.48219494521618, 40.04971034824848, 99.87916052341461, 62.35813468694687, 76.47302448749542, 46.98481321334839, 0.593722831690684, 0.1225531761883758, 0.03546927837305702, 0.055871296499390155, 0.09141062619164586, 0.03276942305092234, 0.04318779603636358, 0.06933209646376781, 0.02624079817906022, 0.023729223867121618, 0.03261135672801174, 0.023634796707483474, 0.08467491614283063, 0.011320268877170747, 0.07807573158061132, 0.05742791043303441, 0.0799308113346342, 0.017201305890921503, 0.014243942023313139, 0.027191359477001242, 0.030105973783065565, 0.04991612171579618, 0.04248363518854603, 0.03704610469867475, 0.09102001902647316, 0.12267022029845975, 0.2905133517924696, 0.11474720013211481, 0.18208529421826825, 0.11490412725834176, 0.15454152220627293, 0.1399876203504391, 0.17286378279095516, 0.27247284015174955, 0.27346948510967195, 0.2697009185794741, 0.0905850091658067, 0.08908379284548573, 0.17203750525368378, 0.09542499945382588, 0.22102760849520564, 0.11048666390706785, 0.09401433999300934, 0.2421627868898213, 0.18150769552448764, 0.18072659993777052, 0.2882947458419949, 0.2531699649989605, 0.2863539702957496, 0.17600749066332355, 0.3050277417059988, 0.7475235569290817, 3.0608642427250743, 111.30930438637733, 111.86595931649208, 92.58520111441612, 132.21556216478348, 84.5346263051033, 85.2256952226162, 30.273779220879078, 1.5500961849465966, 0.615700496127829, 1.8017298448830843, 1.1843569041229784, 0.737378754420206, 3.9616042468696833, 51.832988262176514, 91.49279773235321, 68.59486922621727, 89.47641313076019, 92.05432400107384, 75.0558677315712, 73.89738589525223, 71.46488562226295, 79.63413566350937, 83.41586753726006, 83.05522128939629, 84.10853996872902, 86.0471199452877, 78.13430294394493, 77.60899633169174, 75.43178915977478, 83.39928522706032, 69.8739717900753, 67.05165043473244, 64.50060412287712, 57.883460596203804, 42.53891117870808, 33.747885301709175, 37.5491139292717, 46.130387261509895, 33.582700565457344, 40.37461191415787, 40.99671833217144, 20.591516867280006, 17.220936231315136, 22.085250914096832, 36.985566169023514, 34.42229211330414, 8.080725241452456, 0.5470092664472759, 0.6063854740932584, 1.838781894184649, 2.7929517813026905, 2.2899288358166814, 2.123472117818892, 0.8181503077503294, 4.3556583020836115, 6.60421472042799, 7.316641341894865, 5.7952105812728405, 0.9853058913722634, 1.4801551192067564, 2.436597878113389, 5.891129784286022, 15.272382739931345, 18.774946443736553, 19.25161376595497, 16.24694399535656, 13.51831041276455, 20.378792881965637, 16.785451099276543, 17.47724387794733, 5.857830746099353, 4.692071825265884, 3.740301034413278, 3.6904918821528554, 0.4177432012511417, 0.5527380527928472, 0.3568932367488742, 15.955674424767494, 32.832286432385445, 17.17577375471592, 49.38924819231033, 23.096994124352932, 39.56434719264507, 33.49204882979393, 30.500076077878475, 39.516705349087715, 38.99298705160618, 29.725941717624664, 37.813055366277695, 54.676136299967766, 65.66870704293251, 73.26962158083916, 72.43723064661026, 78.05669590830803, 73.61873924732208, 68.80080297589302, 71.9104877114296, 73.56675803661346, 74.96818363666534, 77.40471929311752, 75.20573168992996, 72.21581652760506, 73.86547520756721, 68.185775578022, 68.12268376350403, 69.02900353074074, 60.91265805065632, 67.15420693159103, 54.100098609924316, 43.311044946312904, 20.442789047956467, 1.0238159936852753, 0.5084590881597251, 0.12018141322187148, 1.6059962916187942, 7.962623303756118, 65.08810579776764, 42.772078067064285, 68.916544765234, 120.4806898534298, 71.53803169727325, 96.01204723119736, 44.9543883651495, 0.8059450658038259, 0.27698551362846047, 0.28846383676864207, 0.3506077505880967, 0.1623122685123235, 0.30061006313189864, 0.09682290881755762, 0.26411023107357323, 0.14690526790218428, 0.2021630309172906, 0.16336248168954626, 0.1456711208447814, 0.17122897988883778, 0.22412583755794913, 0.13562373263994232, 0.12127055946621113, 0.15158707683440298, 0.11420002207159996, 0.13436781096970662, 0.22632244625128806, 0.1596290632733144, 0.11269299473497085, 0.23580084467539564, 0.19111334258923307], [0.01904249635117594, 0.014599140395148424, 0.042769707142724656, 0.017182520277856383, 0.061107255969545804, 0.056988380893017165, 0.07039039162918925, 0.12006243210635148, 0.0895189140283037, 0.04429388551216107, 0.05020142925786786, 0.10982115782098845, 0.07197476559667848, 0.0362162129022181, 0.004025276339234551, 0.035400574051891454, 0.05722891466575675, 0.0317180558340624, 0.07973544095875695, 0.05671059130690992, 0.11640029697446153, 0.3042243520030752, 0.07402371658827178, 0.07576555202831514, 0.044345130809233524, 0.040591689248685725, 0.023638364582438953, 0.08544550291844644, 0.560082346200943, 48.83846394717693, 107.97063633799553, 71.27360388636589, 100.22709265351295, 89.06940177083015, 50.52948720753193, 60.61213217675686, 3.8733511324971914, 0.8686745341401547, 0.22698138433042914, 0.44565157557372004, 0.17470672843046486, 0.1756912170094438, 16.10893540084362, 44.33992713689804, 68.43434303998947, 65.34435644745827, 62.7089736610651, 63.386211320757866, 56.660211235284805, 54.98643144965172, 62.096237540245056, 71.82595744729042, 75.58909311890602, 78.45135793089867, 80.1366662979126, 79.81694385409355, 73.6275851726532, 74.07818779349327, 77.37438932061195, 73.74679997563362, 60.76875977218151, 63.806282579898834, 54.060968309640884, 33.1573323905468, 18.922844007611275, 16.8834725394845, 29.72160805016756, 30.412640869617462, 26.10888920724392, 27.31770694255829, 22.93325711041689, 22.548725344240665, 15.05374912172556, 24.127985201776028, 26.554118916392326, 4.626272181048989, 0.3151712677208707, 0.38294639030937105, 0.5993727722670883, 2.1311809541657567, 0.6085641228128225, 0.11391668493160978, 0.23740306729450822, 0.9613359463401139, 2.7552587538957596, 4.077517502009869, 4.393398826941848, 3.545110495761037, 1.1652296804822981, 1.670995366293937, 2.056708512827754, 2.7285430999472737, 10.082811210304499, 5.160744376480579, 4.055490558966994, 8.554902747273445, 5.691324155777693, 2.0725448755547404, 0.39201187260914594, 1.0369296837598085, 0.08724691055249423, 1.8352573458105326, 0.2649071195628494, 0.6471718323882669, 1.2973832641728222, 0.8819112426135689, 11.632279716432095, 11.196649242192507, 10.030029192566872, 7.638383852317929, 10.105984266847372, 25.71765650063753, 23.343277908861637, 34.11536358296871, 35.71534752845764, 25.139502324163914, 15.420515891164541, 20.180599316954613, 40.53599305450916, 58.226331397891045, 62.10824489593506, 63.0012159794569, 70.88799297809601, 66.24018877744675, 66.00696489214897, 68.90288069844246, 70.27299597859383, 70.16870677471161, 72.26088970899582, 67.29084759950638, 72.20190927386284, 61.95808835327625, 57.13024981319904, 59.96271662414074, 53.676406145095825, 46.30263201892376, 44.26767021417618, 46.13781586289406, 25.017582066357136, 3.9743015030398965, 0.24813737254589796, 0.04040305386297405, 0.49142154457513243, 2.8025486413389444, 34.72915604710579, 25.26545226573944, 41.60327598452568, 100.26864722371101, 58.065881207585335, 52.511476054787636, 53.03717024624348, 1.6381432791240513, 0.3773498546797782, 0.030825960930087604, 0.18684774491703138, 0.024309572218044195, 0.2150063862791285, 0.013014542855671607, 0.1035739887447562, 0.0602347945823567, 0.045756005492876284, 0.07752277218969539, 0.030131934108794667, 0.040846026968210936, 0.12172525850473903, 0.04628676353604533, 0.0322634082112927, 0.039826085994718596, 0.07969948390382342, 0.025825612938206177, 0.013671912220161175, 0.07496790654840879, 0.06741211589542218, 0.024274522438645363, 0.02015128353377804, 0.025962676481867675, 0.04002270688943099, 0.019800379413936753, 0.03674527513794601, 0.02737503917160211, 0.05832791663124226, 0.056873726498452015, 0.04341255174949765, 0.022603584366152063, 0.0925991682743188, 0.05028828280046582, 0.044287948330747895, 0.045185238268459216, 0.07052543282043189, 0.031709996110294014, 0.05102808900119271, 0.03318084003694821, 0.03749914132640697, 0.03248848675866611, 0.05402405382483266, 0.05915854315389879, 0.04602174260071479, 0.06918488405062817, 0.07612862551468424, 0.044630601623794064, 0.04950687180098612, 0.05425872834166512, 0.04334828176070005, 0.11097794340457767, 0.6105093215592206, 67.66698181629181, 110.48706650733948, 87.76185393333435, 114.90739971399307, 88.38545367121696, 71.16035476326942, 61.363640651106834, 1.3972118636593223, 0.9934100252576172, 0.19039764505578205, 0.9620465675834566, 0.18427783594233915, 0.12828865670599043, 19.00983653962612, 61.768630519509315, 85.55580630898476, 70.38167014718056, 76.40304744243622, 76.77423432469368, 67.43268638849258, 63.13099421560764, 68.9342974126339, 78.0600093305111, 77.73208692669868, 83.85784462094307, 84.79089215397835, 83.28646928071976, 75.41324615478516, 74.94261860847473, 77.34874829649925, 73.22201013565063, 64.21658456325531, 66.93214684724808, 61.20009362697601, 42.10361793637276, 29.457514621317387, 22.88689959794283, 34.969850331544876, 31.886969357728958, 25.315206795930862, 28.108252622187138, 24.279868751764297, 25.757757648825645, 20.84358774125576, 30.79561661928892, 31.641166247427464, 5.97950829192996, 0.17353416478727013, 0.9940155583899468, 1.2292234716005623, 0.34776761080138385, 0.7069846009835601, 0.8508569339755923, 0.08367439717403613, 1.0968986595980823, 2.436984982341528, 2.339159706607461, 4.057120671495795, 10.490926411002874, 2.8200303157791495, 1.5397279663011432, 0.8535673760343343, 2.1618847316130996, 7.918490096926689, 5.46616343781352, 4.348821993917227, 11.054001096636057, 4.991833940148354, 0.9567922214046121, 1.274067002814263, 0.7848950859624892, 0.8849919866770506, 1.069148511160165, 0.2219084487296641, 0.4697878804290667, 0.875988369807601, 0.37120332824997604, 13.455580528825521, 19.342187605798244, 10.424318835139275, 9.280265774577856, 15.030027944594622, 21.179723404347897, 23.524108305573463, 36.63123518228531, 35.58611646294594, 35.17640344798565, 24.129123240709305, 31.31897773593664, 48.85912723839283, 63.12845975160599, 61.42691105604172, 62.61729218065739, 70.92290550470352, 65.86733758449554, 69.25702169537544, 66.8693970143795, 72.80733838677406, 70.05545005202293, 72.69798025488853, 69.04107168316841, 74.76639166474342, 65.24258270859718, 64.05093625187874, 67.84419670701027, 60.16388922929764, 54.58177216351032, 49.66745026409626, 39.69150356948376, 23.69962088763714, 3.1169922184199095, 0.06552871578605846, 0.13144858792657033, 0.5469491821713746, 5.386278899386525, 41.190899312496185, 51.676964834332466, 36.009934321045876, 80.32606333494186, 86.2603797018528, 58.56843464076519, 79.8255617916584, 5.924251656979322, 0.3181626572040841, 0.08899900989490561, 0.1661075820447877, 0.07667959594982676, 0.15495872794417664, 0.02844131984602427, 0.06995121089858003, 0.05053840512118768, 0.0136179933360836, 0.003437207797105657, 0.009560728576616384, 0.040972214337671176, 0.07514112381613813, 0.018361253023613244, 0.0762974789540749, 0.09930042040650733, 0.10164119870751165, 0.00736979963221529, 0.01698316085821716, 0.017483691226516385, 0.0272809367015725, 0.02887126825953601, 0.025456713592575397, 0.017610327595320996, 0.1138205842289608, 0.08884822032996453, 0.134432882477995, 0.08421146718319505, 0.1579142568516545, 0.11299032878014259, 0.21862443041754887, 0.14436264027608559, 0.2314776266575791, 0.14300529670435935, 0.14099361636908725, 0.1770669361576438, 0.1748808956472203, 0.13384253368712962, 0.14688974217278883, 0.12650598830077797, 0.19412107416428626, 0.07911168067948893, 0.14134466706309468, 0.1807062205625698, 0.21013342979131266, 0.3908829769352451, 0.15452173654921353, 0.2566397428745404, 0.13414256914984435, 0.20384086354169995, 0.20681702415458858, 0.3212162386626005, 0.8058470429386944, 70.54114758968353, 131.8355369567871, 99.2023104429245, 120.51795825362206, 111.61164656281471, 74.31877568364143, 90.08690357208252, 6.871427306905389, 1.3480653008446097, 0.5033326288685203, 2.2038394678384066, 0.4017614963231608, 0.511592198163271, 19.922562763094902, 65.64387157559395, 81.36913776397705, 82.51847729086876, 83.38431403040886, 88.23172152042389, 76.28273829817772, 72.2498095035553, 73.60830500721931, 82.98353433609009, 84.220861941576, 87.83998534083366, 87.67787083983421, 86.03060603141785, 78.89699041843414, 74.02875244617462, 80.14193281531334, 76.33909687399864, 61.7284020781517, 68.95169287919998, 64.21815767884254, 42.243047654628754, 32.3684149235487, 25.691513903439045, 41.51314102113247, 35.598135218024254, 32.930043786764145, 37.11440585553646, 29.111609682440758, 32.16257616877556, 25.465249344706535, 36.09017841517925, 41.55868537724018, 7.600024435669184, 0.4985396016854793, 1.047359174117446, 2.7057751966640353, 5.169300567358732, 0.8359800197649747, 0.8888328087050468, 0.307047808310017, 1.7414547479711473, 3.695021476596594, 8.29825596883893, 10.87220935150981, 16.615243032574654, 5.974128730595112, 3.434410085901618, 3.8800964830443263, 5.379145257174969, 13.833828382194042, 18.476419262588024, 12.592706680297852, 14.862530082464218, 9.141434524208307, 2.0101377367973328, 3.928673076443374, 1.906275178771466, 1.3131886348128319, 2.2370057506486773, 0.8517947711516172, 1.228314726613462, 2.6400040509179235, 0.460780166904442, 17.923001758754253, 25.682424791157246, 12.867800518870354, 8.457072246819735, 22.475417777895927, 33.86251375079155, 27.798994816839695, 43.66463877260685, 42.201287895441055, 34.882185235619545, 27.515077851712704, 30.59242632240057, 49.06341567635536, 68.39969649910927, 67.0371276140213, 66.60561516880989, 78.73099252581596, 69.04974281787872, 72.04350337386131, 70.52359253168106, 74.24373731017113, 73.79478380084038, 78.11120018362999, 68.78084644675255, 78.83912712335587, 69.43210110068321, 67.30154022574425, 72.37484559416771, 67.40412712097168, 58.79648320376873, 60.25734521448612, 54.2413180321455, 33.32657910883427, 5.076170889660716, 0.3627515723928809, 0.28336608374956995, 2.2529979050159454, 7.897894252091646, 57.65310935676098, 41.339421942830086, 57.86843620240688, 113.01815629005432, 83.53078097105026, 68.35198625922203, 87.904072701931, 3.7424681056290865, 0.33946942014154047, 0.13214568723924458, 0.2761670731706545, 0.14630393532570451, 0.26407787343487144, 0.16136313584866002, 0.22374323074473068, 0.18373945233179256, 0.21313759905751795, 0.10653571458533406, 0.16858078917721286, 0.09529755043331534, 0.20584895188221708, 0.19446039892500266, 0.12846565892687067, 0.19327671790961176, 0.1970708736917004, 0.13710393133806065, 0.1544096870929934, 0.09888938191579655, 0.27750136563554406, 0.18952303886180744, 0.19230404432164505, 0.161369206616655], [0.05718765125493519, 0.06062547596229706, 0.04866912437137216, 0.053629598623956554, 0.06099883932620287, 0.04862807989411522, 0.0514878828835208, 0.0776860372570809, 0.042132710659643635, 0.06257018118049018, 0.11661728611215949, 0.03483949927613139, 0.03889542909746524, 0.03456557999015786, 0.0819675020466093, 0.03622705196903553, 0.07787337759509683, 0.03991019359091297, 0.11117438989458606, 0.05194571007450577, 0.030132217980280984, 0.1578833389794454, 0.09351700457045808, 0.03256418953242246, 0.04473165616218466, 0.06542296716361307, 0.06239767637453042, 0.259270211099647, 0.4126031161285937, 9.088463466614485, 120.60601472854614, 91.52680590748787, 78.53220239281654, 100.00273749232292, 82.04835891723633, 50.42573757469654, 56.39491707086563, 1.428663250990212, 0.7953996222931892, 0.09863853600108996, 0.11886476902873255, 0.06140569952549413, 0.5661738943308592, 24.19170018285513, 43.86729709804058, 66.4410687983036, 66.15272507071495, 62.205227091908455, 59.712215065956116, 65.67730218172073, 63.24767455458641, 66.26951560378075, 67.26972073316574, 77.0029516518116, 73.10789465904236, 75.04167169332504, 70.93066468834877, 69.88281771540642, 69.52768117189407, 68.57889488339424, 61.564858853816986, 54.91795912384987, 49.16526161134243, 33.94097954034805, 13.9191803522408, 12.751845940947533, 27.60308302938938, 34.36605893075466, 29.260645285248756, 25.248427279293537, 27.793933488428593, 18.71571522206068, 9.289830811321735, 21.93797841668129, 18.623501770198345, 1.2667079851962626, 0.3313670674106106, 0.478995053563267, 0.09230707379174419, 0.9714163898024708, 1.9961770484223962, 0.10868075143662281, 0.05286622923449613, 0.10109487411682494, 0.32759945082943887, 0.4229481203947216, 0.4662752361036837, 3.6804079357534647, 1.4587711729109287, 0.4405839537503198, 2.1652724873274565, 0.6118359847459942, 0.651211371878162, 2.2275900933891535, 1.5201872773468494, 2.230060435831547, 0.2302653284277767, 0.22605487232794985, 0.7731420791242272, 1.0540889692492783, 0.2208714309381321, 0.024975041196739767, 0.5742729222401977, 0.5990397557616234, 1.2424276443198323, 0.98953987355344, 10.804509334266186, 14.820400793105364, 3.9147591730579734, 0.9646267478819937, 9.226481560617685, 17.389426790177822, 17.60422546416521, 23.83458584547043, 40.22050358355045, 23.881961703300476, 11.119474433362484, 20.062505453824997, 32.84068018198013, 50.38546733558178, 54.090922102332115, 60.17879202961922, 66.76019847393036, 58.99474136531353, 60.636336877942085, 64.50783893465996, 69.4867193698883, 64.48341384530067, 63.016825541853905, 63.14653918147087, 63.12742240726948, 58.081547766923904, 51.108652129769325, 55.39320342242718, 51.73700541257858, 48.210676833987236, 50.08969500660896, 37.04391963779926, 11.481743194162846, 1.143929804675281, 0.18112249119440094, 0.6263360066805035, 4.539895690977573, 31.037758626043797, 25.42134840041399, 37.127796337008476, 79.22925218939781, 85.4480592906475, 37.57402919232845, 74.89828258752823, 15.364490747451782, 0.15430041326908395, 0.22000587894581258, 0.20753025775775313, 0.05224914086284116, 0.11399250273825601, 0.2756340627092868, 0.019011908734682947, 0.09313018235843629, 0.022562148405995686, 0.02143750523828203, 0.0546474133443553, 0.04723203332105186, 0.05192652184632607, 0.04281450317648705, 0.01983531972655328, 0.0068420908883126685, 0.08011788449948654, 0.05232594943663571, 0.12336970932665281, 0.061075595949660055, 0.011182853741047438, 0.05132030593813397, 0.012206745723233325, 0.08548946774681099, 0.037354266678448766, 0.04842213020310737, 0.02285805381688988, 0.09989807935198769, 0.07288477223482914, 0.02166093807318248, 0.0321512214577524, 0.017004421533783898, 0.11223952766158618, 0.1250089131644927, 0.00934561150643276, 0.06163645921333227, 0.051379584983806126, 0.03524278232362121, 0.0238851472386159, 0.046228694191086106, 0.04394067145767622, 0.042659780228859745, 0.05984917464957107, 0.0681338099821005, 0.005120790210639825, 0.07992050290340558, 0.08298396976897493, 0.07942855547298677, 0.01118799033065443, 0.08941357358708046, 0.17187426245072857, 0.18829309236025438, 0.15878332662396133, 0.9071339922957122, 23.92707098275423, 124.93458285927773, 91.5378025174141, 103.44518557190895, 109.70162585377693, 73.59118312597275, 77.54736363887787, 40.66721901297569, 0.7182119297794998, 1.3758612843230367, 0.04101646860362962, 0.3075443347916007, 0.17057804216165096, 1.5476998197846115, 21.403753682971, 52.4880351126194, 92.22690314054489, 76.50607511401176, 73.206377774477, 70.71727573871613, 73.27431812882423, 74.86904695630074, 75.93973070383072, 78.41500908136368, 79.28081542253494, 78.96097138524055, 79.93063375353813, 75.25237798690796, 72.72168338298798, 72.66160100698471, 69.17590364813805, 61.24756067991257, 60.52333854138851, 54.81174722313881, 42.625063955783844, 25.508741810917854, 20.64075082540512, 33.01814965903759, 33.978574723005295, 33.376580625772476, 27.063700072467327, 25.67164856940508, 22.897658720612526, 17.857533171772957, 30.978856086730957, 23.705808855593204, 1.3214381108991802, 0.11350595814292319, 0.5137728061527014, 0.3637084679212421, 1.2501200940459967, 1.6800391185097396, 0.5884235410485417, 0.5051732144784182, 0.1579526110435836, 0.20967727614333853, 0.597114684060216, 0.11425862205214798, 1.6187523258849978, 1.0353436251170933, 3.535068822093308, 2.721266965381801, 0.8548492728732526, 1.2425826047547162, 1.56176500255242, 2.2158059757202864, 1.9385638274252415, 0.18532467976910993, 0.05671607577824034, 0.31671926903072745, 0.9373763320036232, 0.1956675318069756, 0.12207314022816718, 0.7862854551058263, 1.1210099095478654, 0.9983138996176422, 0.9892655757721514, 11.570106502622366, 17.770139761269093, 4.601587755605578, 4.0969054866582155, 17.07143135368824, 22.906951121985912, 21.858556978404522, 20.92634730041027, 38.703244999051094, 37.91389435529709, 20.7412763312459, 29.346021004021168, 42.71674923598766, 55.88567599654198, 60.438857674598694, 66.22836381196976, 67.89091140031815, 62.97139897942543, 64.64949533343315, 65.90823099017143, 72.50394746661186, 68.40972796082497, 64.88443672657013, 64.2443534731865, 66.24190628528595, 65.87685987353325, 58.55033241212368, 61.97948880493641, 64.30838003754616, 56.077330112457275, 40.205232203006744, 35.52316144108772, 9.186399411410093, 1.3212092919275165, 0.2523894334444776, 0.9357774490490556, 9.837465025484562, 39.835702031850815, 49.50867958366871, 36.11875668168068, 60.036098286509514, 103.97902652621269, 51.19216024875641, 77.30318874120712, 33.42538520693779, 0.5585206893738359, 0.29015569598414004, 0.05788430898974184, 0.08124387095449492, 0.14329210709547624, 0.22327949234750122, 0.04285673509002663, 0.0354458227957366, 0.03722036839462817, 0.017361793470627163, 0.0395711694000056, 0.06563576316693798, 0.014601210059481673, 0.05372657877160236, 0.027999660342175048, 0.0752377811295446, 0.06191368847794365, 0.018216087082691956, 0.08593634454882704, 0.016535840622964315, 0.02536406016588444, 0.059759853465948254, 0.02579575448180549, 0.009025183680932969, 0.02625158529554028, 0.15164961019763723, 0.16932936385273933, 0.2881239331327379, 0.2268819959135726, 0.16680065891705453, 0.11922562349354848, 0.17721621174132451, 0.16704302950529382, 0.27395707613322884, 0.13033832015935332, 0.12174503674032167, 0.1292525729513727, 0.23817835928639397, 0.15024117717985064, 0.15692561224568635, 0.13528654526453465, 0.20079255133168772, 0.17036215140251443, 0.21960431768093258, 0.08709505229489878, 0.2525544574018568, 0.24219187907874584, 0.47141707269474864, 0.14680452877655625, 0.15405045793158934, 0.24234183743828908, 0.2716138487448916, 0.4946720920270309, 1.3856661831960082, 16.358393914997578, 149.55524772405624, 113.04893463850021, 105.24356067180634, 122.49630689620972, 109.87814158201218, 75.30513435602188, 82.74259686470032, 2.1894396655261517, 1.5903190453536808, 0.21683408820535988, 0.8213072852231562, 0.2342985596624203, 2.031357460655272, 27.542795464396477, 51.30177676677704, 81.80815860629082, 85.61296284198761, 81.3879619538784, 75.1358762383461, 81.96864679455757, 80.68043991923332, 82.30100736021996, 81.85341417789459, 85.81144139170647, 82.20058634877205, 79.27842915058136, 75.53063705563545, 73.00532296299934, 72.15210154652596, 74.62165743112564, 66.20162084698677, 60.83234176039696, 58.048371747136116, 43.72730500996113, 24.90113541483879, 22.089457288384438, 40.872313007712364, 42.823185324668884, 35.84423281252384, 32.87485174834728, 32.20353417098522, 26.946810744702816, 16.930571012198925, 33.676403537392616, 32.77422554790974, 4.159270590171218, 0.7496492459904402, 0.9408787940628827, 0.4672363173449412, 2.2018122766166925, 4.302459256723523, 0.5433764238841832, 0.6187324365600944, 0.5334949947427958, 0.9083464834839106, 1.3344129896722734, 0.5841881933156401, 9.47444960474968, 1.4478289475664496, 6.799908019602299, 4.16318248026073, 0.981870578834787, 3.684226730838418, 9.7704185731709, 2.6947584003210068, 10.584758576005697, 0.3386391350068152, 0.5399887275416404, 1.1052996525540948, 1.9065146846696734, 0.32993181317579, 0.4126823181286454, 1.8318894202820957, 3.990199137479067, 2.712461412884295, 1.6502355365082622, 14.42448578774929, 28.139874525368214, 7.434087339788675, 4.99527988024056, 25.426628217101097, 28.792206421494484, 24.64606650173664, 24.331857562065125, 47.708187997341156, 39.652380868792534, 19.991304874420166, 32.56112918257713, 44.84693393111229, 68.54459032416344, 66.70554980635643, 74.26972791552544, 76.47332847118378, 66.76159679889679, 65.74256747961044, 69.02312904596329, 75.40715888142586, 71.3381016254425, 66.53967350721359, 66.2864550948143, 71.82214245200157, 68.03211942315102, 60.363028943538666, 66.37044578790665, 63.5111828148365, 67.64653891324997, 63.548341020941734, 45.77566869556904, 15.288441628217697, 1.612372468225658, 0.22677064407616854, 2.304821186698973, 14.11024359986186, 56.00679449737072, 41.71635791659355, 54.09881807863712, 91.12481787800789, 109.26209583878517, 59.598490968346596, 101.12133666872978, 30.63857864588499, 0.5388994328677654, 0.702374973334372, 0.3479743137722835, 0.30690130835864693, 0.3861916536698118, 0.44691913411952555, 0.15503508009715006, 0.11845338172861375, 0.18228092434583232, 0.12199885124573484, 0.11995925131486729, 0.2144926568144001, 0.09498736981186084, 0.13339601311599836, 0.10735350937466137, 0.14991893665865064, 0.1680027600377798, 0.1787458820035681, 0.1525592160760425, 0.08323416259372607, 0.19124219426885247, 0.27921765635255724, 0.08963664833572693, 0.19225004565669224, 0.19184183474862948], [0.05280754019622691, 0.08402279097936116, 0.06604581460123882, 0.08783370445598848, 0.0553174131346168, 0.021990347740938887, 0.019281883505755104, 0.03933170060918201, 0.16506124287843704, 0.0121770060104609, 0.19768075580941513, 0.026929555751848966, 0.059203958880971186, 0.018455576282576658, 0.031160517391981557, 0.06153862188511994, 0.05400725902291015, 0.012375844999041874, 0.05050093408499379, 0.06590200122445822, 0.02307601516804425, 0.10403824664535932, 0.08150117355398834, 0.09753882157383487, 0.03685909461637493, 0.040047669026535004, 0.014577185811504023, 0.07050725020235404, 0.21079989324789494, 0.7127736497204751, 51.73404537141323, 108.02241235971451, 59.75381143391132, 79.63548839092255, 103.86903002858162, 63.113279566168785, 54.10302825272083, 56.74921005964279, 2.77992133051157, 0.2612179925199598, 0.1541497721336782, 0.1484146626899019, 0.13232779543614015, 6.262998729944229, 49.372795075178146, 49.69632491469383, 57.65078008174896, 70.42719930410385, 68.24436843395233, 65.56275352835655, 64.57456335425377, 68.30378204584122, 64.27856683731079, 62.356022000312805, 72.4276551604271, 71.08802944421768, 70.65776333212852, 60.58562479913235, 57.99515940248966, 62.24058039486408, 67.26340547204018, 55.602401196956635, 47.501764073967934, 29.782874062657356, 12.196802124381065, 13.0420458689332, 19.054136462509632, 34.73677843809128, 26.757651194930077, 25.22739540785551, 26.01801138371229, 20.82645446062088, 14.193287193775177, 21.664440594613552, 8.958543688058853, 0.5032208911143243, 0.3207250853301957, 0.348220617743209, 0.05194781035243068, 0.24786199122900143, 0.2787475800141692, 0.047061202058102936, 0.1177871780237183, 0.23633217788301408, 0.522556034848094, 0.35741591651458293, 0.45643616875167936, 0.4408356308704242, 0.08014679115149193, 0.09018909564474598, 0.6630336656235158, 0.6041089806240052, 0.729365162551403, 1.0228262655436993, 0.8662502642255276, 0.07661555602680892, 0.30708880454767495, 0.3881777299102396, 0.034768616751534864, 0.05187428578210529, 0.08244333002949134, 0.18030013219686225, 0.10898487613303587, 0.46586892509367317, 0.6495159503538162, 0.2632645092671737, 6.43226919695735, 18.608169592916965, 10.83382286131382, 6.817125845700502, 7.1851360984146595, 13.199735507369041, 23.646020963788033, 34.40053828060627, 31.47585041821003, 14.101122189313173, 6.407064674422145, 13.502999134361744, 26.964618489146233, 36.064206808805466, 48.333284854888916, 57.270086109638214, 55.60814268887043, 52.49943070113659, 50.28828375041485, 54.95444476604462, 59.09420482814312, 59.73292015492916, 56.18953809142113, 60.755479484796524, 59.60368908941746, 56.79152078926563, 62.36449934542179, 54.92444157600403, 50.08425369858742, 58.07225726544857, 51.326752826571465, 18.979867547750473, 3.6990350112318993, 0.8012306469026953, 2.708298973739147, 6.51519974693656, 22.855904661118984, 21.526226811110973, 37.48856037855148, 73.30788552761078, 90.21630182862282, 39.84952189028263, 67.591343075037, 52.768216878175735, 0.8760994544718415, 0.25805121869780123, 0.06707974505843595, 0.10703792591812089, 0.08308307616971433, 0.06346132984617725, 0.046107750094961375, 0.05950462887994945, 0.14009863079991192, 0.019495256528898608, 0.11372476554242894, 0.1456799969309941, 0.02830832512699999, 0.09888687345664948, 0.060847389249829575, 0.04715846422186587, 0.040638474238221534, 0.03686478317831643, 0.09244403714546934, 0.04362680236226879, 0.07607572522829287, 0.04701661011495162, 0.03526759232045151, 0.027757555071730167, 0.05854193717823364, 0.044325886919978075, 0.045332391309784725, 0.10496081042219885, 0.07383628719253466, 0.016640077119518537, 0.0185389602847863, 0.02207438854384236, 0.03338842616358306, 0.04908340975816827, 0.0908847626124043, 0.08380618033697829, 0.12100992462364957, 0.022933493128221016, 0.08574176084948704, 0.11179333363543265, 0.025954596349038184, 0.03614261782786343, 0.04557719614240341, 0.04374714902951382, 0.04638684215024114, 0.06368951799231581, 0.05166932685824577, 0.09342448101961054, 0.059413207418401726, 0.07773387609631754, 0.03554603870725259, 0.0019340428752911976, 0.09420382513781078, 0.061148730892455205, 0.3667079616570845, 1.5895329625345767, 91.67479276657104, 112.1870344877243, 79.98596638441086, 105.39825037121773, 107.57372483611107, 66.78619667887688, 83.52413132786751, 30.77412497252226, 0.884507215814665, 0.7041690114419907, 0.06061750900698826, 0.20814656687434763, 0.08744822553126141, 8.049234431236982, 40.35784341394901, 50.86550697684288, 73.50726842880249, 82.88875222206116, 79.02293846011162, 78.14626470208168, 74.59293857216835, 77.45410904288292, 73.7117050588131, 70.51287710666656, 78.07963147759438, 75.14818757772446, 74.09603163599968, 66.55697017908096, 68.66388112306595, 67.30260416865349, 68.72641056776047, 58.48713420331478, 53.40066634118557, 40.22069737315178, 21.143328957259655, 21.42456516623497, 27.145473584532738, 35.860108360648155, 29.239666610956192, 27.514031007885933, 26.965007968246937, 28.7772998213768, 22.24128384143114, 29.78347823023796, 16.80212650448084, 0.7017151149921119, 0.05726571034756489, 0.24039598560193554, 0.016536219118279405, 1.058173393830657, 0.5834563763346523, 0.1096731067809742, 0.4231958492891863, 0.11760860987124033, 0.46252370928414166, 0.6398853671271354, 0.5835750605911016, 0.09891624766169116, 0.1814198846113868, 0.3247220255434513, 1.5860459371469915, 0.7026197039522231, 1.1280427384190261, 0.5915511294733733, 0.5426035809796304, 0.03310838415927719, 0.07491589683922939, 0.009809480707190232, 0.11476965009933338, 0.1569587565609254, 0.07295930612599477, 0.3123709961073473, 0.10536511763348244, 0.9705972368828952, 0.9650310699362308, 0.5817490804474801, 7.930835159495473, 20.819155052304268, 16.125291623175144, 11.945293620228767, 13.573864381760359, 18.860989026725292, 22.91540376842022, 27.39460911601782, 37.61076562106609, 26.635540947318077, 12.80516467988491, 22.749377377331257, 37.0249130576849, 44.36818242073059, 51.573059409856796, 61.57609485089779, 61.943451538681984, 58.21843162178993, 56.056655421853065, 61.690518110990524, 63.13002526760101, 64.88130569458008, 60.68885385990143, 62.43658907711506, 66.5301664173603, 58.90446960926056, 65.96432358026505, 67.04921096563339, 54.96398225426674, 45.46956852078438, 45.03626637160778, 15.422060508280993, 4.095401242375374, 2.4221676774322987, 4.133059596642852, 17.326906844973564, 36.919556111097336, 45.9395918995142, 40.3330497443676, 55.15019126236439, 92.66511082649231, 68.3833421766758, 60.17865523695946, 73.15467774868011, 2.417257153429091, 0.3463383234338835, 0.0402169788867468, 0.13241419626865536, 0.022650771970802452, 0.10670450865291059, 0.08662435997393914, 0.03941561153624207, 0.09985822602175176, 0.06838457426056266, 0.06952445372007787, 0.042102987645193934, 0.034136366302846, 0.05711176294425968, 0.03379890804353636, 0.03891366737661883, 0.021676254145859275, 0.04801775990927126, 0.08647477268823422, 0.07081642892444506, 0.08409115762333386, 0.04065509834617842, 0.05041625874582678, 0.03472344593319576, 0.006913043453096179, 0.044306906493147835, 0.13095704867737368, 0.2818609488895163, 0.13931998430052772, 0.1634567344444804, 0.18413105397485197, 0.08740170029341243, 0.14350743382237852, 0.27644819871056825, 0.21866452123504132, 0.10498911593458615, 0.3649940458126366, 0.12342392321443185, 0.20157539838692173, 0.20322336698882282, 0.10325292823836207, 0.1227342824859079, 0.20413273537997156, 0.20250539848348126, 0.11792728066211566, 0.24297953525092453, 0.13801582303131, 0.1868889489560388, 0.19854345795465633, 0.2923761721467599, 0.09285146137699485, 0.16349326295312494, 0.18147775728721172, 0.2994220925029367, 0.3303183236857876, 1.0749849979765713, 81.06339856982231, 140.19726186990738, 82.91101142764091, 106.01597562432289, 122.1665757894516, 89.90675523877144, 82.88401007652283, 79.88860800862312, 4.635429214686155, 1.1398381367325783, 0.14701356209116057, 0.7883730868343264, 0.4716099420329556, 8.996149320155382, 63.53819936513901, 57.342597618699074, 69.4508644938469, 87.21589922904968, 85.11125296354294, 81.79549008607864, 78.23646426200867, 82.54010573029518, 80.47373861074448, 75.73166146874428, 85.05707547068596, 77.35002502799034, 77.7242061495781, 68.81691411137581, 67.53969624638557, 69.58270221948624, 77.29328647255898, 64.28788393735886, 59.99609403312206, 43.38505357503891, 23.24659399688244, 24.768868312239647, 31.613425835967064, 46.313708424568176, 28.012733347713947, 31.110938899219036, 31.676289662718773, 29.08346649259329, 20.311483293771744, 33.2071553170681, 25.924889780580997, 0.9336782991886139, 0.46645272814203054, 0.512128088157624, 0.08723240898689255, 0.9224101819563657, 0.6280380778480321, 0.13514826830942184, 0.4123581777093932, 0.5614106717985123, 1.2667215219698846, 0.8106124622281641, 4.175846250727773, 0.747965817572549, 0.244045392901171, 0.8643774990923703, 8.104449268430471, 0.6983637541998178, 1.8046205397695303, 1.399434506893158, 0.5676409718580544, 0.1821287692291662, 0.38059440557844937, 0.9504137886688113, 0.2391861513024196, 0.5302879074588418, 0.24182375898817554, 0.43298940814565867, 0.2435100669390522, 2.1348819555714726, 1.4971747621893883, 0.3830002702306956, 8.452827874571085, 30.15170317143202, 17.93119601905346, 9.949569460004568, 19.91788901388645, 16.503365635871887, 25.525548309087753, 47.894662991166115, 49.79869142174721, 24.7647113353014, 15.760010574012995, 29.102258384227753, 46.81895971298218, 56.85639090836048, 61.26991108059883, 73.81479352712631, 68.47641438245773, 64.81524243950844, 59.34632129967213, 65.58020979166031, 67.72695779800415, 66.2585873901844, 61.78596518933773, 67.25612506270409, 72.34187096357346, 61.41301520168781, 67.00409978628159, 70.86521700024605, 65.90023621916771, 65.44843286275864, 58.06807368993759, 25.118614844977856, 4.437931487336755, 2.3887259094044566, 5.90771209448576, 25.042759515345097, 54.73457336425781, 37.09260642528534, 54.4367491453886, 86.32502943277359, 105.12019649147987, 64.16354700922966, 83.80030050873756, 75.94375848770142, 1.3117355690337718, 0.5418619082774967, 0.27742162928916514, 0.2885464526480064, 0.23112017865059897, 0.16573221859289333, 0.17581564548891038, 0.1463938390952535, 0.28049088490661234, 0.08988600253360346, 0.27539719885680825, 0.23642738058697432, 0.13975940993987024, 0.2831604197854176, 0.3489063325105235, 0.14893835177645087, 0.15811916382517666, 0.17077575030270964, 0.1852074798080139, 0.11668166742310859, 0.17276552243856713, 0.18659044231753796, 0.12765428371494636, 0.1450984796974808, 0.122540871379897, 0.15313178300857544], [0.049451670856797136, 0.028937376919202507, 0.05543424573261291, 0.05391994534875266, 0.104289248411078, 0.0487086659995839, 0.01815881554648513, 0.01677358948654728, 0.041044291720027104, 0.0617761944886297, 0.2039158798288554, 0.21577277249889448, 0.1358381094178185, 0.11759528089896776, 0.061493658868130296, 0.07747413925244473, 0.03957795262977015, 0.12638132233405486, 0.026772120254463516, 0.030567747344321106, 0.04310539166908711, 0.05175380181754008, 0.032587099631200545, 0.11139294496388175, 0.0030223623207348282, 0.0311047134528053, 0.1529662247048691, 0.0226458700853982, 0.048985824760166, 0.777304993243888, 4.141013994812965, 92.32538625597954, 87.82822117209435, 76.31773442029953, 99.55628424882889, 90.43042033910751, 53.69611568748951, 49.02898192405701, 62.42708958685398, 5.870081288740039, 0.12051383600919507, 0.3004892711760476, 0.3053448465652764, 0.46082615037448704, 14.175696987658739, 57.04279750585556, 58.678852915763855, 56.955960765480995, 73.7376880645752, 70.29080182313919, 74.7668020427227, 68.9164687693119, 70.3799070417881, 62.28717729449272, 63.20254437625408, 61.67664125561714, 61.1614914983511, 56.91419720649719, 57.07788482308388, 51.733277812600136, 54.240463078022, 49.403535425662994, 41.175479739904404, 30.037802383303642, 16.24386616051197, 14.750379100441933, 9.733066577464342, 27.936967313289642, 30.29804851859808, 26.98203295469284, 31.189068406820297, 15.728756301105022, 14.859027620404959, 15.602718014270067, 1.7379807843826711, 0.1271683254162781, 0.41172720375470817, 0.2793479181127623, 0.043507587470230646, 0.21728195948526263, 0.08354712626896799, 0.040172182852984406, 0.06726671432261355, 0.1132604482700117, 0.22219110309379175, 0.2594050148036331, 0.21034658944699913, 0.08098440870526247, 0.29713636671658605, 0.34415875445120037, 0.2257827267749235, 0.10681721119908616, 0.041821476188488305, 0.23288810800295323, 0.12263423355761915, 0.06856703126686625, 0.5741866549942642, 0.16913915140321478, 0.16812233487144113, 0.09398771173437126, 0.08853024715790525, 0.0183861390905804, 0.07662330404855311, 0.04834810839383863, 0.19760477473028004, 0.7052010123152286, 11.665796767920256, 28.02920736372471, 16.41593422740698, 7.492101676762104, 11.84541692957282, 15.941011011600494, 24.143537767231464, 21.16871729493141, 15.417608097195625, 3.672426464036107, 7.516528191044927, 11.035838071256876, 30.951463356614113, 36.03330686688423, 55.30295066535473, 62.620970383286476, 52.49028079211712, 54.89306665956974, 55.203388407826424, 60.87094768881798, 56.55118748545647, 57.814475297927856, 56.327820271253586, 57.40998700261116, 62.36723139882088, 64.78050470352173, 61.812457367777824, 50.81202104687691, 62.082645669579506, 52.94302649796009, 27.006220556795597, 7.7909005433321, 4.35856182128191, 2.0595652470365167, 6.224450273439288, 13.208698276430368, 16.61317404359579, 40.53990304470062, 71.05470523238182, 99.26982522010803, 48.00716355443001, 51.57061614096165, 81.47398173809052, 9.523709211498499, 0.15087154257344082, 0.09258372418116778, 0.05081409071863163, 0.0241891290716012, 0.10216984534054063, 0.0506422872422263, 0.12426198605680838, 0.09667660924606025, 0.17808430187869817, 0.10601702757412568, 0.04736665519885719, 0.10614268059725873, 0.010325143466616282, 0.093418269243557, 0.05612078428384848, 0.08049934098380618, 0.028326971587375738, 0.03928332371287979, 0.030826836664346047, 0.04363404201285448, 0.013094995374558493, 0.05638300732243806, 0.0202756081125699, 0.08974848999059759, 0.08331450750119984, 0.1559197052847594, 0.06779622926842421, 0.0757338697439991, 0.04335284225817304, 0.0966152039472945, 0.07610768210724927, 0.04345637556980364, 0.10434567389893346, 0.049671543238218874, 0.009754152670211624, 0.005007499048588215, 0.21000926848500967, 0.118754099967191, 0.0780369172571227, 0.034081002086168155, 0.018633769650477916, 0.03061228919250425, 0.00823393180326093, 0.06682904015178792, 0.003446318355599942, 0.010938471004919847, 0.02403342463367153, 0.01237970787769882, 0.11107278987765312, 0.05099107438581996, 0.025806465528148692, 0.03727788483956829, 0.06708364133373834, 0.20842223020736128, 0.0822551065357402, 1.244905823841691, 16.85694806277752, 114.78227242827415, 83.20123225450516, 89.6637810766697, 111.98443695902824, 94.68694433569908, 62.68095016479492, 85.02716347575188, 43.11834588646889, 1.1310964683070779, 0.535237438743934, 0.11764191745896824, 0.1634113150066696, 1.0562794329598546, 16.622310653328896, 42.834341526031494, 51.66339196264744, 71.81265816092491, 86.57576277852058, 81.1452765762806, 83.63727405667305, 75.18059223890305, 75.98201483488083, 70.0652839243412, 70.75108632445335, 66.50831758975983, 69.46531131863594, 62.85862863063812, 65.89949145913124, 62.45073951780796, 63.90798792243004, 55.90115636587143, 48.054600208997726, 33.11772331595421, 17.47163537889719, 20.025846920907497, 19.70006190240383, 38.16140167415142, 27.677602730691433, 27.49715991318226, 31.66763562709093, 23.406457118690014, 19.507729522883892, 30.57144194841385, 12.240006756037474, 0.3826449596090242, 0.19936016178689897, 0.2500429406063631, 0.12440049307770096, 0.8726118947379291, 0.5352064466569573, 0.0954787754744757, 0.0487335205252748, 0.1323997986037284, 0.09561865546857007, 0.5157764861360192, 0.2389806802966632, 0.2977562975138426, 0.5596243520267308, 0.0938273558858782, 0.5274685774929821, 0.1553943834733218, 0.03176877791702282, 0.15267500595655292, 0.10113051204825751, 0.15897111967206, 0.3427264391211793, 0.10823093572980724, 0.11087128936196677, 0.10895677100052126, 0.09046840292285196, 0.07013961250777356, 0.10598061780910939, 0.02001085249503376, 0.6515250925440341, 3.669942347332835, 15.31206401064992, 41.53816647827625, 20.60747791081667, 13.702760115265846, 17.16125663369894, 19.441443979740143, 24.117186181247234, 28.224511183798313, 31.300425231456757, 12.644287012517452, 13.628069423139095, 22.488293386995792, 40.82142613828182, 47.709704115986824, 61.85155346989632, 69.79843944311142, 61.41072392463684, 64.35450196266174, 62.36696921288967, 66.4639587700367, 62.52267725765705, 61.91046930849552, 56.594843342900276, 59.928309470415115, 63.417707830667496, 70.1855094730854, 68.48047256469727, 46.443004086613655, 49.42614421248436, 48.45136731863022, 20.86212694644928, 11.456636991351843, 7.983505558222532, 8.457333482801914, 24.436009973287582, 38.8006641715765, 40.53494431078434, 42.138131484389305, 51.79226964712143, 85.76906606554985, 82.03040108084679, 45.55861674249172, 89.29555803537369, 19.097355343401432, 0.12236676353495568, 0.10775838061817922, 0.07246664623380639, 0.06785663266782649, 0.11390563435270451, 0.03980535038863309, 0.06786883357563056, 0.2070087951142341, 0.028450375903048553, 0.0975708155601751, 0.020826315085287206, 0.053348113142419606, 0.008598561016697204, 0.036474350417847745, 0.06778318231226876, 0.04307408416934777, 0.004195556557533564, 0.07783470427966677, 0.08669663031469099, 0.019220888243580703, 0.08098180376691744, 0.05027413375501055, 0.03628555547038559, 0.12179198500234634, 0.04175207795924507, 0.0753520496073179, 0.165596182923764, 0.2099320405977778, 0.1358464066288434, 0.17650336405495182, 0.1430766616249457, 0.14854927343549207, 0.176536122453399, 0.17673359310720116, 0.10164425635593943, 0.25691059709060937, 0.46902352769393474, 0.320412878645584, 0.13537362887291238, 0.1798512219102122, 0.2370632378733717, 0.14976872596889734, 0.13566124078352004, 0.2142851077951491, 0.11739850044250488, 0.1560521638020873, 0.13033293216722086, 0.19020032283151522, 0.22515020915307105, 0.2788442966993898, 0.1298527477774769, 0.19873988960171118, 0.19064101012190804, 0.2776028320658952, 0.17349671601550654, 0.9717413317412138, 7.335257017984986, 133.19174498319626, 114.84821408987045, 102.86485031247139, 119.71968188881874, 115.97415447235107, 76.50629550218582, 77.87389531731606, 93.33436131477356, 10.63588673248887, 1.4669209043495357, 0.390935224131681, 0.372170020127669, 0.7517498207744211, 21.07568308711052, 71.33507698774338, 74.11392867565155, 69.89088088274002, 85.30067279934883, 84.56488788127899, 92.4115352332592, 82.52039238810539, 83.20639997720718, 75.96892833709717, 74.97568443417549, 72.05556392669678, 71.2718103826046, 66.40142172574997, 69.42276120185852, 64.80061322450638, 67.47517570853233, 61.37779489159584, 56.860502287745476, 44.770155251026154, 25.611345805227757, 27.15829599648714, 20.159936025738716, 46.20799049735069, 37.22183749079704, 31.476137302815914, 35.15525758266449, 19.018570370972157, 18.01400877535343, 30.990644954144955, 19.51491303741932, 0.3572775505017489, 0.630017890362069, 0.6436995905824006, 0.40752145287115127, 0.9673842717893422, 0.26961770898196846, 0.3269666066626087, 0.1838376236264594, 0.2228621530230157, 0.33625467389356345, 2.0604297006502748, 0.9727631800342351, 0.19213525025406852, 1.3723473041318357, 0.4089845821727067, 0.35680186352692544, 0.5445535888429731, 0.10330365403206088, 0.6021961395163089, 0.4306368890684098, 0.2643023879500106, 0.9303290757816285, 0.2388701299787499, 0.32035804877523333, 0.40585939830634743, 0.2234176654019393, 0.1535524323116988, 0.23580626235343516, 0.08117571953334846, 1.2350748013705015, 5.6848787516355515, 16.086258217692375, 43.152053877711296, 19.341724030673504, 7.985680941492319, 17.19897150993347, 21.379843465983868, 31.28618359565735, 35.93664765357971, 31.255192458629608, 12.968861795961857, 26.266048774123192, 31.8829757720232, 57.413327023386955, 54.0987154841423, 74.82924029231071, 84.04955193400383, 67.94556766748428, 66.6852816939354, 62.521582916378975, 71.9123800098896, 61.93076781928539, 66.54059305787086, 61.5762734413147, 64.7781640291214, 66.98245614767075, 72.2593241930008, 73.07518601417542, 57.85183109343052, 68.6850155889988, 65.0705735385418, 32.91980713605881, 10.546907857060432, 7.197332018986344, 11.73138314858079, 35.240688398480415, 50.44032499194145, 39.38336670398712, 62.85568378865719, 87.69734099507332, 113.47486898303032, 76.30382716655731, 66.32318392395973, 110.94155251979828, 13.043617084622383, 0.2395627912483178, 0.3151498344959691, 0.1133805129211396, 0.1460508184391074, 0.1935594019596465, 0.14638368651503697, 0.2416421109228395, 0.2186842475202866, 0.15591553441481665, 0.2416787136462517, 0.11144149626488797, 0.2972409501671791, 0.11986017460003495, 0.21492109866812825, 0.11030309367924929, 0.18301109375897795, 0.10348179916036315, 0.1283287475234829, 0.14866009092656896, 0.1347383504617028, 0.15332707174820825, 0.16143236338393763, 0.08982162122265436, 0.19575891987187788, 0.21052466036053374, 0.2391266607446596], [0.07597456307848915, 0.11165920528583229, 0.029326611111173406, 0.16688314120983705, 0.034027730725938454, 0.08111837378237396, 0.058290360248065554, 0.04620431092916988, 0.05401206071837805, 0.03236467055103276, 0.041244716121582314, 0.12176695236121304, 0.12654627207666636, 0.06471831278759055, 0.022177469145390205, 0.08511817126418464, 0.017503662420494948, 0.06507943442557007, 0.07125284886569716, 0.021008458534197416, 0.019176626556145493, 0.10752409943961538, 0.046419511490967125, 0.07585306608234532, 0.10813537679496221, 0.059646278896252625, 0.1088966941460967, 0.047556633871863596, 0.22908929153345525, 0.024791689902485814, 1.7106877989135683, 19.965922236442566, 91.64008542895317, 72.69506201148033, 75.88565960526466, 107.56060034036636, 75.45665502548218, 44.38838593661785, 36.87475271522999, 54.29768040776253, 6.736723585054278, 0.40953492920380086, 0.08696272736415267, 0.08388233953155577, 2.6504677394405007, 23.816078938543797, 49.78008382022381, 57.00798757374287, 46.80330075323582, 56.462116464972496, 69.84682604670525, 81.52701169252396, 78.48263025283813, 76.1019591987133, 69.8142921924591, 65.28603717684746, 55.114309787750244, 59.025838896632195, 62.40222752094269, 57.73051120340824, 55.133441761136055, 54.128087908029556, 37.875037640333176, 35.84196053445339, 27.333652786910534, 21.29835493862629, 9.138216096907854, 21.362801380455494, 39.829553961753845, 31.501793526113033, 32.89954662322998, 28.59059114009142, 23.499599620699883, 18.684961572289467, 1.7133657052181661, 0.5083581560757011, 0.12917541927890852, 0.35528770415112376, 0.05916812799114268, 0.22860843921080232, 0.15793423546710983, 0.046627821211586706, 0.21392466151155531, 0.04703582060756162, 0.22479583363747224, 0.1752596432925202, 0.06427084968890995, 0.07341841352172196, 0.14594929263694212, 0.44296152773313224, 0.29940425127279013, 0.16274918569251895, 0.28422332368791103, 0.2194935892475769, 0.1321651611942798, 0.04529643425485119, 0.08817106252536178, 0.1371202734299004, 0.028000597303616814, 0.07690650018048473, 0.20652776467613876, 0.1877393017639406, 0.0251181606654427, 0.19517340988386422, 0.6381413200870156, 1.2726632156409323, 10.608946178108454, 26.85694746673107, 15.479454528540373, 3.792034783400595, 6.590702645480633, 15.171965528279543, 15.31898533925414, 13.484920654445887, 6.471694931387901, 12.05068001523614, 15.508726257830858, 13.051031436771154, 21.776924058794975, 36.809236630797386, 46.54741108417511, 49.36924986541271, 54.08950477838516, 52.094326838850975, 55.34069404006004, 51.63598783314228, 51.31267458200455, 55.01228146255016, 59.909641072154045, 61.12952381372452, 66.4194555580616, 62.09231235086918, 62.010502740740776, 61.61671847105026, 36.13038405776024, 20.355030857026577, 9.41146893426776, 8.4190115891397, 3.091029399074614, 5.077517442405224, 9.910785891115665, 12.38320492208004, 40.53828813135624, 80.03429219126701, 102.60686695575714, 60.819270461797714, 55.39813555777073, 83.84821593761444, 18.794222809374332, 0.41272177069913596, 0.22074339562095702, 0.19291716220322996, 0.08606521849287674, 0.3236149193253368, 0.21644306543748826, 0.2855587739031762, 0.1080974233627785, 0.10609499018755741, 0.06016383784299251, 0.046866952325217426, 0.07264053143444471, 0.07478618426830508, 0.07253949544974603, 0.07652363361557946, 0.09059769246960059, 0.15305538632674143, 0.09581971069565043, 0.12160156475147232, 0.022522302497236524, 0.11031230373191647, 0.006287356836764957, 0.1313793455483392, 0.05100708622194361, 0.09276350203435868, 0.04147866333369166, 0.014688019073219039, 0.08830350619973615, 0.13512428209651262, 0.09599545868695714, 0.0667209982930217, 0.062148863944457844, 0.12632442929316312, 0.024850100635376293, 0.10170707173529081, 0.032657629635650665, 0.03244052546506282, 0.12062773341313004, 0.030704987148055807, 0.040032325123320334, 0.05238575911789667, 0.01904422741063172, 0.047583473642589524, 0.07226219939184375, 0.038629242990282364, 0.059546211414271966, 0.05130052399181295, 0.04632443124137353, 0.09881021702312864, 0.040317109451279975, 0.054211935930652544, 0.04373446572571993, 0.13037357217399403, 0.03011128199432278, 0.0079098386959231, 0.15909127338090912, 0.16121574532007799, 2.3752610944211483, 56.93142928183079, 109.51704695820808, 85.75619995594025, 103.71206805109978, 115.76264262199402, 78.9815890789032, 58.432626128196716, 86.39907225966454, 51.2580981105566, 3.7581425020471215, 0.22698905813740566, 0.07648404745850712, 0.10744618135504425, 2.652734317816794, 29.28454030305147, 41.38269782066345, 47.47833453118801, 56.6416872292757, 70.58521002531052, 81.8650871515274, 84.08831745386124, 83.91424119472504, 82.07873448729515, 77.75587365031242, 71.7358110845089, 64.96112421154976, 66.04106426239014, 69.26431730389595, 68.18756148219109, 68.47731873393059, 67.37355396151543, 50.97059413790703, 43.87349456548691, 31.99386902153492, 23.621772564947605, 14.430836196988821, 28.919180408120155, 34.952029287815094, 24.02994856238365, 24.327193312346935, 23.12864262610674, 22.65223938971758, 31.485843881964684, 8.163044974207878, 0.46814176719635725, 0.5499382561538368, 0.43770433170720935, 0.13558607606682926, 0.3410865005571395, 0.1319904744741507, 0.052910620797774754, 0.43037298135459423, 0.0901784012967255, 0.08600177228800021, 0.1190102967666462, 0.05866223560587969, 0.028946507190994453, 0.19148365943692625, 1.1436280771158636, 0.606133381370455, 0.3806675219675526, 0.07857061049435288, 0.126557374605909, 0.08130771049764007, 0.07150417717639357, 0.10350337339332327, 0.150272436439991, 0.019041756058868486, 0.2838067413540557, 0.15668156440369785, 0.0914056612236891, 0.07093716892995872, 0.18672076344955713, 1.5356291737407446, 2.6611976511776447, 11.215274892747402, 38.485908061265945, 21.533467322587967, 11.075211558490992, 17.873834297060966, 22.948551289737225, 15.054962206631899, 25.692526549100876, 19.58682417869568, 16.5991622954607, 24.799386374652386, 28.538868315517902, 45.52291385829449, 48.83549630641937, 66.16556078195572, 66.80030152201653, 67.55726650357246, 63.50266367197037, 66.77608162164688, 58.80360022187233, 56.23896203935146, 57.823271825909615, 62.15373985469341, 65.9346091747284, 69.30478513240814, 64.99779984354973, 58.39084357023239, 53.634148612618446, 33.03597450256348, 19.091516956686974, 17.242458276450634, 17.69814882427454, 13.044966012239456, 23.18758886307478, 32.39692859351635, 32.0804587751627, 45.286030769348145, 59.81693744659424, 85.63115626573563, 95.20952269434929, 47.86595173180103, 76.69864118099213, 41.82758554816246, 0.6337399093899876, 0.12650554301217198, 0.14007765770656988, 0.0415013396559516, 0.062429366080323234, 0.09561129336361773, 0.17016494792187586, 0.1200478414830286, 0.12400131410686299, 0.07541471655713394, 0.04058775957673788, 0.033348468932672404, 0.040696142823435366, 0.033854632201837376, 0.1312943547964096, 0.08063087181653827, 0.026117688867088873, 0.030834193203190807, 0.061203078366816044, 0.02133263049472589, 0.13273453689180315, 0.10918015745119192, 0.08761065197177231, 0.03425567767408211, 0.08800490308203734, 0.11997288456768729, 0.11549975271918811, 0.19685692735947669, 0.19833711121464148, 0.1803954684874043, 0.18158437422243878, 0.20823464496061206, 0.2581758698215708, 0.25610652461182326, 0.16107920499052852, 0.14096192666329443, 0.12058714535669424, 0.2228429017122835, 0.11946565631660633, 0.2551540522836149, 0.18456394871464, 0.18718010833254084, 0.17240299814147875, 0.09315294402767904, 0.09241426960215904, 0.14435423916438594, 0.2880502230254933, 0.13339813565835357, 0.17616996163269505, 0.11290557551546954, 0.16686136659700423, 0.20402789959916845, 0.24230738694313914, 0.3596905991435051, 0.16632583283353597, 0.30012927018105984, 0.13345473184017465, 1.9357007998041809, 39.84677843749523, 132.00672537088394, 97.72782996296883, 105.14055579900742, 127.41462618112564, 96.63118600845337, 66.10124543309212, 68.31951320171356, 91.07906073331833, 17.140914425253868, 0.8487538655754179, 0.22972961654886603, 0.1950911947642453, 3.273628600873053, 36.95445343852043, 72.36705601215363, 75.61022758483887, 64.56712335348129, 71.89607128500938, 81.62101104855537, 90.36685734987259, 93.66943493485451, 87.89997652173042, 83.34488734602928, 78.49814862012863, 75.75558498501778, 70.92873439192772, 72.88537859916687, 67.31039375066757, 70.88051497936249, 64.54982668161392, 54.49015147984028, 54.50419172644615, 45.69267734885216, 34.724470898509026, 18.906493484973907, 32.1924539655447, 42.89369434118271, 29.405075535178185, 30.29984962195158, 25.290016047656536, 23.34875151515007, 40.04626393318176, 16.113903634250164, 0.5743477307260036, 0.49379656556993723, 0.6026887474581599, 0.29781198827549815, 0.5680033180397004, 0.27444490464404225, 0.1712185749784112, 0.32106409838888794, 0.21428779436973855, 0.24767222406808287, 1.0073945811018348, 0.48791715293191373, 0.10687563306419179, 0.27399664744734764, 2.3444252740591764, 0.5344260635320097, 0.9325634152628481, 0.5239697964861989, 0.43276121257804334, 0.371045132051222, 0.34002104366663843, 0.1734025523182936, 0.2728880272479728, 0.07192743141786195, 0.37275147798936814, 0.2412944147363305, 0.2161047054687515, 0.2290563253336586, 0.5057545832823962, 1.4319317881017923, 5.510524632409215, 14.534193500876427, 47.50711798667908, 18.835864774882793, 6.891511604189873, 13.304969910532236, 28.672662936151028, 32.96743758022785, 28.739676140248775, 18.9382141828537, 26.470990777015686, 33.72125633060932, 30.248751863837242, 46.64649456739426, 55.32476909458637, 62.03468844294548, 61.289723217487335, 67.38758280873299, 63.028684705495834, 71.20443999767303, 60.44458396732807, 64.18379992246628, 66.40837535262108, 73.95636633038521, 71.88701257109642, 78.67619946599007, 73.57454001903534, 69.89332795143127, 76.79004147648811, 57.9764112085104, 34.032041653990746, 23.40364906936884, 19.804896377027035, 16.47865366190672, 28.00181843340397, 33.682259023189545, 28.40250503271818, 61.49520859122276, 98.14191654324532, 118.0971385538578, 94.28388476371765, 74.45669308304787, 108.76575127243996, 31.55563283711672, 0.3047834266908467, 0.33833405293989927, 0.3823140211170539, 0.13003812142414972, 0.2398850762983784, 0.27070813172031194, 0.4502090153982863, 0.33077186497393996, 0.3275866265175864, 0.19496736000292003, 0.11251956224441528, 0.13916757685365155, 0.20233228511642665, 0.12955811514984816, 0.19130247150314972, 0.26680182258132845, 0.1686474637244828, 0.1665319420862943, 0.22622287971898913, 0.13341440353542566, 0.1781875197775662, 0.1402053961646743, 0.23893135716207325, 0.1823720897664316, 0.2252248246804811, 0.2025152393616736, 0.10388108203187585], [0.021986696374369785, 0.1410396146820858, 0.03465276378847193, 0.04807185505342204, 0.03622845091740601, 0.05578810174483806, 0.26087746548000723, 0.07378578404313885, 0.07427467382512987, 0.02542334477766417, 0.09977453402825631, 0.08607027994003147, 0.06014135818986688, 0.0668114067229908, 0.10487620558706112, 0.050714516764855944, 0.06420155536034144, 0.0369340181350708, 0.047785055794520304, 0.11579425176023506, 0.006885049642733065, 0.2034979616291821, 0.13020701939240098, 0.11996804576483555, 0.05850290763191879, 0.05894460795389023, 0.15164017007919028, 0.030821966320218053, 0.044185402075527236, 0.04322576802223921, 0.11535923447809182, 0.784853941295296, 59.59484316408634, 84.61817622184753, 73.80499005317688, 81.71174257993698, 126.13158702850342, 72.62405142188072, 42.94761724770069, 28.124800734221935, 38.60274039208889, 5.967581206932664, 1.4839670271612704, 1.070669973269105, 0.9890087333042175, 5.927869537845254, 26.41978282481432, 49.73763629794121, 56.88370384275913, 52.428784891963005, 52.81846158206463, 53.77126045525074, 66.58929884433746, 71.43134862184525, 76.05516850948334, 65.91407507658005, 61.70521952211857, 56.672036200761795, 64.49903100728989, 63.69490295648575, 57.9830988496542, 58.209232315421104, 45.08040480315685, 33.81338618695736, 23.26010227203369, 26.554719284176826, 24.665147177875042, 17.44747817516327, 34.51793298125267, 49.35926020145416, 75.25137484073639, 44.82144869863987, 39.63175177574158, 16.38740535825491, 6.168153919279575, 0.33132197451777756, 0.10322904592612758, 0.4584749968489632, 0.0515176281624008, 0.19406003993935883, 0.8558292640373111, 0.09874524941551499, 0.06474996538599953, 0.14323062758194283, 0.20934964763000607, 0.5742722097784281, 0.3675015550106764, 0.6656451942399144, 0.5040029366500676, 0.51225520321168, 0.6681660027243197, 0.15313470707042143, 0.1830087782582268, 0.06913875215104781, 0.03931675375497434, 0.09757458567037247, 0.2815513248788193, 0.19006801274372265, 0.12955012964084744, 0.23626131762284786, 0.11752338905353099, 0.13873055577278137, 0.13511812227079645, 0.07876006595324725, 0.34131564607378095, 0.3809481725329533, 8.168495781719685, 28.838512636721134, 20.097524374723434, 15.140736903995275, 13.012401759624481, 12.721213884651661, 21.51339679956436, 10.648974180221558, 14.192661177366972, 17.985662296414375, 10.539892483502626, 12.477134931832552, 10.977447554469109, 30.70772923529148, 30.80854542553425, 35.86101271212101, 44.12950202822685, 50.28374299407005, 44.55331228673458, 50.62712296843529, 52.802627831697464, 57.79967129230499, 51.186882331967354, 59.15573492646217, 58.893017023801804, 60.78068733215332, 51.41815312206745, 31.249069087207317, 20.77411226928234, 15.582122169435024, 9.761108122766018, 1.851088721305132, 5.461776573210955, 9.125217944383621, 16.523850336670876, 48.203259631991386, 87.45840981602669, 100.8431687951088, 51.661245077848434, 49.26877185702324, 78.00613582134247, 29.818537048995495, 0.08393257550778799, 0.11159567744471133, 0.06108949637564365, 0.18922750081401318, 0.4393625567900017, 0.2477270836243406, 0.23806397948646918, 0.02706033887079684, 0.11709193408023566, 0.04983636681572534, 0.05205973364354577, 0.08607524490798824, 0.03259577904827893, 0.018963596776302438, 0.03927471479983069, 0.044772785986424424, 0.1664425726630725, 0.06942804873688146, 0.06375609606038779, 0.05034831141529139, 0.03176435100613162, 0.1178229643846862, 0.11136999775771983, 0.03082209062995389, 0.03732176061021164, 0.06014668309944682, 0.07457510262611322, 0.04737136041512713, 0.03152002114802599, 0.05699858913430944, 0.06944640204892494, 0.024481114087393507, 0.08762641518842429, 0.08108577123493887, 0.12517313560238108, 0.06799349212087691, 0.1492709229933098, 0.04709914806880988, 0.014744865729880985, 0.04830776153539773, 0.03667543162009679, 0.02432732995657716, 0.04782549542142078, 0.004784474858752219, 0.013900837875553407, 0.11291837756289169, 0.03465360983682331, 0.2247689085197635, 0.15537379629677162, 0.06625774971325882, 0.07424808267387562, 0.06278639106312767, 0.07011999754467979, 0.16728586022509262, 0.046014335966901854, 0.029471433808794245, 0.09444311581319198, 0.12699172395514324, 0.7725748408120126, 2.32969940174371, 92.49388441443443, 99.52384158968925, 86.85160517692566, 110.59748858213425, 116.2354664504528, 68.53678554296494, 51.64438918232918, 74.76631566882133, 54.33758206665516, 8.633825462311506, 1.1800254927948117, 1.0913198464550078, 1.6612949618138373, 5.846128324046731, 26.16702038794756, 44.03715938329697, 40.48022724688053, 44.87393908202648, 61.132540851831436, 65.99847614765167, 74.55415025353432, 79.44573417305946, 82.53616914153099, 73.69182452559471, 73.59779477119446, 68.25382992625237, 75.95117568969727, 71.05006948113441, 70.93477606773376, 72.57032230496407, 55.78446462750435, 40.30520863831043, 32.08330862224102, 31.110013648867607, 32.208595499396324, 24.16816234588623, 31.319196224212646, 29.668600894510746, 44.114926010370255, 33.30320656299591, 27.47243084013462, 29.330599531531334, 6.292835678905249, 0.4560118680819869, 0.8071845711674541, 0.5476310080848634, 0.08143741564708762, 0.040741963020991534, 0.3031945478869602, 0.11769580480176955, 0.05832086622831412, 0.08883449801942334, 0.2837862877640873, 0.633292542770505, 0.4773949534865096, 0.4147203447064385, 0.7403384987264872, 0.4163600754691288, 3.60908932518214, 0.2500972361303866, 0.3182439075317234, 0.25607565126847476, 0.020760017177963164, 0.11806472641183063, 0.2541404269868508, 0.2064257490565069, 0.06603473433642648, 0.2018840130767785, 0.27845704404171556, 0.1414941207622178, 0.13820058811688796, 0.01821843226935016, 0.5488520488142967, 1.1176315345801413, 11.46214859560132, 37.42754325270653, 36.67981177568436, 33.393592312932014, 28.73631902039051, 28.632366098463535, 29.031739868223667, 23.19023922085762, 20.26348616927862, 24.42355614155531, 28.616184666752815, 25.453842356801033, 28.824645280838013, 50.60248129069805, 40.824283584952354, 47.96899080276489, 52.45809271931648, 57.97647960484028, 54.40114505589008, 54.77091461420059, 59.459726214408875, 65.90471997857094, 61.35555848479271, 63.300757706165314, 57.32243210077286, 51.79048754274845, 45.02308487892151, 26.792157143354416, 27.206433713436127, 32.030814439058304, 21.665394343435764, 17.44268473237753, 22.88913007825613, 26.140252724289894, 33.61891262233257, 46.360749900341034, 62.33810216188431, 88.47170144319534, 87.09389537572861, 57.246496975421906, 75.9768471121788, 58.10850352048874, 0.3655953932320699, 0.20298896706663072, 0.03859089621983003, 0.0883424466883298, 0.08259291731519625, 0.05212412237597164, 0.029822957621945534, 0.05142497473570984, 0.15418214461533353, 0.03909802428097464, 0.10112603689776734, 0.044441814097808674, 0.08663339933264069, 0.08399127938901074, 0.07749542404781096, 0.03894488952937536, 0.11173494145623408, 0.023716989562672097, 0.06295909624896012, 0.026342628261772916, 0.01138929324952187, 0.050909731289721094, 0.01802132526790956, 0.0872195846750401, 0.0427468564157607, 0.06949173985049129, 0.04321611639170442, 0.06520647526485845, 0.11206393552129157, 0.16721862164558843, 0.15967758488841355, 0.353000137838535, 0.18999223946593702, 0.3762736218050122, 0.406230115913786, 0.2444657898740843, 0.26782934088259935, 0.34068170352838933, 0.2745231566950679, 0.17507958342321217, 0.21775987290311605, 0.16771830967627466, 0.15998875256627798, 0.1740705149131827, 0.11345214501488954, 0.17000056221149862, 0.1435899903299287, 0.424712264793925, 0.355542438919656, 0.22534955001901835, 0.24357022542972118, 0.20937670633429661, 0.2640763594536111, 0.19562662462703884, 0.18894449021900073, 0.0840211211470887, 0.19401493220357224, 0.13806921313516796, 0.3287119895685464, 0.5454705271404237, 95.44742032885551, 118.94623339176178, 99.9052195250988, 105.2519354224205, 143.40384900569916, 91.68760567903519, 65.2857255935669, 55.83477392792702, 77.0604957640171, 29.083958566188812, 1.3952989038079977, 2.2900824900716543, 1.895907197613269, 5.918757626786828, 39.694752395153046, 73.9459776878357, 74.99277591705322, 69.68083575367928, 73.29336270689964, 70.75004518032074, 80.73305189609528, 80.75586587190628, 89.51957121491432, 75.76772913336754, 79.53139677643776, 74.83495518565178, 82.66870602965355, 76.71470671892166, 75.90804040431976, 71.61930173635483, 52.48516246676445, 42.60801047086716, 39.005872160196304, 46.08616903424263, 41.63211643695831, 29.032541625201702, 44.05933879315853, 48.926756009459496, 82.0652224123478, 53.68905566632748, 48.19042772054672, 40.44998846948147, 20.09439904242754, 0.9150904684793204, 0.9627374180126935, 0.5510971345938742, 0.13076266535790637, 0.2824395865900442, 1.2210711278021336, 0.19710753578692675, 0.1971090052393265, 0.456169203389436, 0.36212211241945624, 0.7009708299301565, 0.6869667407590896, 0.8681669645011425, 1.2402744661085308, 1.8890860886313021, 3.3327275421470404, 0.16418904124293476, 0.3971660288516432, 0.37745820824056864, 0.12920025154016912, 0.30392125889193267, 0.41454979917034507, 0.3131156077142805, 0.28848212328739464, 0.39128459757193923, 0.32367541920393705, 0.26139450492337346, 0.591624453663826, 0.10610351004288532, 1.190741511527449, 1.5269548329524696, 11.91315969452262, 38.70190367102623, 38.841116800904274, 30.945602171123028, 24.8271818831563, 33.86497601866722, 45.32030873000622, 26.518710516393185, 27.259446568787098, 35.17137631773949, 31.255908720195293, 27.509444653987885, 27.031977474689484, 47.266754284501076, 42.41952158510685, 49.54486884176731, 58.750300481915474, 63.312267288565636, 59.19737309217453, 61.14525876939297, 68.68756905198097, 74.4642698764801, 71.39369264245033, 74.28519308567047, 66.93140208721161, 70.74724093079567, 71.35771617293358, 48.62915597856045, 39.08787935972214, 37.23162576556206, 25.555340610444546, 20.544872470200062, 22.46652625501156, 23.31920240074396, 33.13521757721901, 70.21154567599297, 98.4391137957573, 110.10858401656151, 84.61558476090431, 74.91833791136742, 104.3010288476944, 51.67358681559563, 0.11197158266440965, 0.3405768529046327, 0.21198424219619483, 0.2142670439206995, 0.38366942026186734, 0.34778560046106577, 0.47135033877566457, 0.16296912857796997, 0.35609222191851586, 0.11448663208284415, 0.11703632495482452, 0.14123720407951623, 0.16699698666343465, 0.138469215889927, 0.13560606952523813, 0.12165131091023795, 0.28198465006425977, 0.14095426769927144, 0.12931222678162158, 0.10821795556694269, 0.14016799192177132, 0.18200794758740813, 0.12806219776393846, 0.1890146083314903, 0.1336970875854604, 0.17922339466167614, 0.15959082782501355, 0.1936496768030338], [0.061689032954745926, 0.034622094535734504, 0.020372473227325827, 0.07592952955747023, 0.03844404374831356, 0.028163407805550378, 0.22083828662289307, 0.023080208302417304, 0.11347093619406223, 0.013874800552002853, 0.039098016859497875, 0.10816296242410317, 0.016157241407199763, 0.04031420765386429, 0.045899703836767, 0.08613423822680488, 0.06135293653642293, 0.02316485024493886, 0.049297148289042525, 0.045713706786045805, 0.011947256571147591, 0.15847920934902504, 0.05025791782827582, 0.1889983404544182, 0.08582517082686536, 0.09128587858867832, 0.06472696622950025, 0.03553274684236385, 0.04775145134772174, 0.03655754146166146, 0.054260398173937574, 1.21088138082996, 0.7859915646258742, 80.80687433481216, 81.387619972229, 64.46207419037819, 83.7848049402237, 127.14629977941513, 73.76441583037376, 48.718310594558716, 25.845449343323708, 29.84690822660923, 6.988889453932643, 4.436972988769412, 5.119900843128562, 4.557684911414981, 5.681714471429586, 20.77969416975975, 40.88266745209694, 59.267308339476585, 50.693467408418655, 44.52547878026962, 39.67630438506603, 43.91352541744709, 55.26932626962662, 54.199767261743546, 60.120632350444794, 61.24237395823002, 62.5422690063715, 61.46324470639229, 57.27747671306133, 52.87070877850056, 51.36986531317234, 31.33073430508375, 21.02243084460497, 17.373746931552887, 27.555650174617767, 33.42870622873306, 37.47977524995804, 43.94326262176037, 66.00457862019539, 54.6785643696785, 43.73860940337181, 17.26984530687332, 5.39198761805892, 0.2334603780764155, 0.2510183007689193, 0.1312363930628635, 0.26451081270352006, 0.11304731830023229, 0.13104604702675715, 0.03538721168297343, 0.12902868184028193, 0.17948293854715303, 0.13856073754141107, 0.04054815486597363, 0.04321734464610927, 0.2137015719199553, 0.32232767902314663, 2.3688579630106688, 2.168582584708929, 0.07913333654869348, 0.06889326454256661, 0.06119253986980766, 0.158877816866152, 0.20588479761499912, 0.10977372716297396, 0.08159002347383648, 0.07296936222701333, 0.05218995829636697, 0.03021493219421245, 0.057480424802633934, 0.1378955357358791, 0.12307884680922143, 0.3188524686265737, 0.47514114005025476, 4.865070842206478, 20.31879600137472, 15.550908744335175, 16.053866855800152, 23.420381471514702, 21.670731157064438, 40.03410078585148, 20.761958621442318, 8.459054790437222, 12.47607383877039, 7.218096479773521, 10.144372656941414, 5.065271649509668, 14.032885450869799, 24.770266637206078, 30.98389081656933, 34.706847444176674, 39.01702456176281, 48.81175518035889, 50.02493508160114, 47.03938968479633, 47.02552802860737, 49.45100247859955, 47.25795775651932, 33.934611082077026, 23.791828639805317, 26.1460892111063, 18.81058283150196, 13.227615561336279, 8.516492508351803, 5.34014604985714, 7.6138851419091225, 8.536585830152035, 22.0040587708354, 61.721638441085815, 97.39507421851158, 103.48691493272781, 48.64455655217171, 49.20649319887161, 73.50283786654472, 33.33719953894615, 0.19159610965289176, 0.12826979131205007, 0.0917228328762576, 0.21157475479412824, 0.24992479069624096, 0.20206837740261108, 0.10237283757305704, 0.03963815564929973, 0.024185345973819494, 0.05786897621874232, 0.1068070883047767, 0.1295331641449593, 0.030179808200045954, 0.05219223297899589, 0.05827834487718064, 0.04079776881553698, 0.022518170590046793, 0.147582744830288, 0.035503673207131214, 0.129040882748086, 0.07329956599278376, 0.08015102881472558, 0.06808227524743415, 0.12296353932470083, 0.02992379137140233, 0.06929616167326458, 0.07742303496343084, 0.03279730553913396, 0.07651336971321143, 0.01583403423865093, 0.038722976241842844, 0.0771666229411494, 0.08375198129215278, 0.07005333784036338, 0.03918815069482662, 0.09304378894739784, 0.07221240870421752, 0.08896856699720956, 0.01204831760333036, 0.11655062640784308, 0.0499791040783748, 0.039793138348613866, 0.07490978896385059, 0.033710759453242645, 0.08711749484064057, 0.025987395565607585, 0.1209432574978564, 0.06176804570714012, 0.061421232676366344, 0.04649836839234922, 0.09445343908737414, 0.1053743351076264, 0.08559013265767135, 0.055898125137900934, 0.14572985441191122, 0.09501299617113546, 0.025614687147026416, 0.04178497736575082, 0.16349939309293404, 0.051376393748796545, 1.6901865927502513, 15.758575201034546, 106.99972003698349, 87.47095674276352, 87.2766275703907, 120.68750515580177, 112.39559009671211, 65.18920317292213, 46.79813303053379, 59.20333497226238, 52.67704077064991, 14.944643676280975, 12.083516903221607, 8.75344019383192, 6.9925866555422544, 8.956744484603405, 20.362104177474976, 41.37419007718563, 58.23001720011234, 40.78057453036308, 38.94739709794521, 42.489415034651756, 56.73233896493912, 65.34686431288719, 63.013291731476784, 68.2015523314476, 74.21372652053833, 74.24824386835098, 74.13414359092712, 66.63656070828438, 66.19160458445549, 66.91152915358543, 55.6063149869442, 36.64740331470966, 28.289939872920513, 35.11380560696125, 34.38854232430458, 38.00880566239357, 37.631732895970345, 69.68576788902283, 57.59426191449165, 50.37206545472145, 33.0742422491312, 6.6825147438794374, 0.03475664219877217, 0.36880446947179735, 0.10810672247316688, 0.20674611936556175, 0.26104584394488484, 0.10729367742897011, 0.1807023910805583, 0.07368894119281322, 0.07810146926203743, 0.10653923978679813, 0.04746559090563096, 0.007815911558282096, 0.043777725513791665, 0.256254686973989, 0.810266324551776, 2.4279652163386345, 0.5776851391419768, 0.04427994797879364, 0.06017897023411933, 0.13943672413006425, 0.18485133798094466, 0.08545601915102452, 0.09008023742353544, 0.06636977690504864, 0.043131340862601064, 0.07534211967140436, 0.05097695131553337, 0.19746870937524363, 0.15193435741821304, 0.19068221416091546, 0.353280016570352, 7.914186352863908, 28.24918705970049, 33.9222427457571, 43.29722888767719, 35.06847403943539, 35.087921395897865, 53.55159804224968, 31.035689637064934, 22.94725365936756, 30.155934244394302, 24.485534615814686, 24.718505814671516, 16.309007965028286, 27.715351805090904, 35.775239914655685, 40.081689432263374, 54.35165651142597, 56.281899735331535, 57.0335678011179, 62.30755940079689, 55.89720457792282, 49.936715215444565, 47.53039933741093, 43.31457115709782, 31.038402691483498, 26.94754220545292, 30.373607464134693, 33.38184714317322, 28.127006515860558, 21.57512068748474, 22.123397067189217, 21.83963969349861, 27.114927023649216, 39.24078315496445, 46.90179146826267, 69.35967698693275, 96.72840759158134, 88.1726498901844, 53.531519919633865, 69.71039816737175, 64.71241235733032, 2.647156692110002, 0.1692274076049216, 0.12568164034746587, 0.24524648470105603, 0.25326038827188313, 0.06368169575580396, 0.12556599889649078, 0.11695448090904392, 0.0864757077943068, 0.10358946994529106, 0.037875480702496134, 0.022313135596050415, 0.04394279771076981, 0.03901718955603428, 0.032702087992220186, 0.03548715671058744, 0.038203710355446674, 0.033038878318620846, 0.058779583996511064, 0.019192399049643427, 0.040343938089790754, 0.03963531693443656, 0.04870640615990851, 0.034910997783299536, 0.06286396775976755, 0.024589775639469735, 0.05097887718875427, 0.05012532201362774, 0.15180590649833903, 0.08924883164581843, 0.2232740746694617, 0.28902754245791584, 0.22810904803918675, 0.11805715650552884, 0.2150139561854303, 0.3697662038030103, 0.20282919751480222, 0.27235768851824105, 0.08559608468203805, 0.2216189369210042, 0.2685587533051148, 0.17579476145328954, 0.12113938486436382, 0.2060216199606657, 0.16541922523174435, 0.1756836916320026, 0.21383797866292298, 0.2467921408242546, 0.14195487572578713, 0.24225187429692596, 0.26539343409240246, 0.2060133227496408, 0.22087122313678265, 0.10535984096350148, 0.23197425703983754, 0.15667976840632036, 0.12084863366908394, 0.19736886082682759, 0.2775938669219613, 0.16325487027643248, 1.6084540472365916, 5.219699637964368, 128.1823217868805, 107.16157615184784, 91.83015882968903, 110.08916705846786, 148.15648198127747, 93.97121474146843, 73.0664312839508, 48.6663293838501, 63.91874134540558, 34.991395175457, 14.35571612790227, 12.042585499584675, 10.005383715033531, 10.14322416856885, 31.956642419099808, 70.24724096059799, 95.31066566705704, 69.10449787974358, 55.607333332300186, 52.29626700282097, 65.97186997532845, 71.9489948451519, 71.08783945441246, 72.22007229924202, 74.69681739807129, 74.83984172344208, 74.49214518070221, 65.12954637408257, 64.10421699285507, 68.1205178797245, 47.97755554318428, 36.623206213116646, 36.99825368821621, 47.513212859630585, 47.09847651422024, 56.77960082888603, 49.9951446801424, 73.987577855587, 59.07862186431885, 58.23546230792999, 42.092845514416695, 16.656368225812912, 0.6113984144758433, 1.4527993183583021, 0.16899443260626867, 0.7769558869767934, 0.3699469019193202, 0.39082048810087144, 0.15231298631988466, 0.25330993405077606, 0.5213765543885529, 0.43926126847509295, 0.1301033265190199, 0.14008436672156677, 0.2589079539757222, 0.49307873065117747, 5.681266570463777, 4.674620786681771, 0.39494866970926523, 0.12096841630409472, 0.19319352315505967, 0.16067611490143463, 0.36198258865624666, 0.2379281070898287, 0.19172420434188098, 0.28323944367002696, 0.1250685818376951, 0.27287840901408345, 0.12297707609832287, 0.5100111267529428, 0.287386208656244, 0.4620559187605977, 0.6748492503538728, 10.13456728309393, 35.528051778674126, 40.992546156048775, 49.084694534540176, 45.03152422606945, 37.35520653426647, 70.65883487462997, 46.45604878664017, 27.970969788730145, 42.22511261701584, 24.617488235235214, 20.19570730626583, 14.181085098534822, 27.97432880848646, 37.1501999348402, 36.939869821071625, 47.93087884783745, 49.423731341958046, 59.423985332250595, 61.459099128842354, 63.03658448159695, 58.35693418979645, 62.64618583023548, 59.20733615756035, 52.818149998784065, 51.41743876039982, 50.47992646694183, 45.87533354759216, 34.398201406002045, 29.109799079596996, 20.346160233020782, 17.075561732053757, 23.31693012267351, 42.74112492799759, 78.41196164488792, 101.70303225517273, 113.13970416784286, 75.61582088470459, 70.17500683665276, 94.66743618249893, 59.27814155817032, 0.6778003263752908, 0.19034955388633534, 0.36542846937663853, 0.3663130203494802, 0.38681200006976724, 0.17566632537636906, 0.21889547759201378, 0.19317008613143116, 0.18019556358922273, 0.17716470669256523, 0.13590132555691525, 0.17531744175357744, 0.1205399670288898, 0.14072463236516342, 0.25710649439133704, 0.11234154328121804, 0.15193594561424106, 0.17290385876549408, 0.17508167627966031, 0.20048059697728604, 0.11423605334130116, 0.1502484650700353, 0.1489537736051716, 0.12726023298455402, 0.28857883997261524, 0.1323867219616659, 0.13954614638350904, 0.19333102827658877, 0.29439614969305694], [0.039774120814399794, 0.08502130614942871, 0.21845798153663054, 0.010760864861367736, 0.09634918111260049, 0.0858323548163753, 0.049753676721593365, 0.03351064304297324, 0.11056438903324306, 0.08554744432331063, 0.030285543834907003, 0.03592302746255882, 0.0002364050399705775, 0.021261705296637956, 0.08030857192352414, 0.08484595149639063, 0.06518422567751259, 0.008219716892199358, 0.028685898323601577, 0.11742804534151219, 0.09458147440454923, 0.2748580137267709, 0.00044580228234281094, 0.2764498017495498, 0.18434608384268358, 0.1618253899505362, 0.22023302066372707, 0.07946576675749384, 0.0335624635044951, 0.2194573130691424, 0.1753612729953602, 0.31776462856214494, 1.445635634008795, 7.614672649651766, 106.58499509096146, 90.67322731018066, 77.01866760849953, 90.49989581108093, 130.83029329776764, 83.09152454137802, 63.662521094083786, 35.56741006672382, 21.993316747248173, 8.60089072957635, 5.143962576985359, 5.449792491272092, 5.240782806649804, 2.1858562203124166, 12.22086813300848, 25.150901712477207, 45.05349084734917, 46.11575044691563, 39.31394062936306, 47.9339262843132, 42.22344450652599, 43.89146380126476, 40.82713343203068, 41.97327733039856, 43.05034093558788, 42.03754708170891, 37.8570494055748, 32.55056954920292, 26.607737839221954, 11.073075123131275, 11.265611741691828, 20.329319536685944, 29.172917492687702, 35.50714910030365, 46.833406537771225, 58.4674284607172, 29.71208956092596, 18.191052675247192, 38.464674800634384, 9.695566389709711, 2.6676005451008677, 0.1975070487242192, 0.2674022497376427, 0.1755904036690481, 0.2787056041415781, 1.2709660129621625, 0.2279298342182301, 0.2551307191606611, 0.06996136347879656, 0.1087024221487809, 0.12188243796117604, 0.05748110757849645, 0.08561470516724512, 0.14337732049170882, 0.1317320586531423, 0.21225760487141088, 3.58736636582762, 1.0919228265993297, 0.2066673181252554, 0.08902774585294537, 0.03834032118902542, 0.03236755008401815, 0.06947242174646817, 0.14190080284606665, 0.0672524057154078, 0.0639873938052915, 0.07475628313841298, 0.16080187924671918, 0.019645593383756932, 0.11440844682510942, 0.19948387780459598, 2.238074205815792, 0.29677879996597767, 21.58782910555601, 15.466598868370056, 13.839465379714966, 34.2577039450407, 38.26416335999966, 25.589607171714306, 15.567586049437523, 16.725900694727898, 5.095102898776531, 5.393977761268616, 7.794643817469478, 12.033959962427616, 17.44228385388851, 13.945185206830502, 22.720468528568745, 30.58523140847683, 37.03804135322571, 41.07355020940304, 38.47092166543007, 31.715171076357365, 33.37189547717571, 31.93083420395851, 30.81297028809786, 32.424955889582634, 19.699832014739513, 16.223282665014267, 12.471163552254438, 6.401606742292643, 5.980169931426644, 6.562054557725787, 10.660373568534851, 27.808433510363102, 64.13015440106392, 106.544990837574, 89.33740898966789, 43.41566853225231, 49.50538896024227, 64.08381208777428, 39.45861026644707, 1.5113236592151225, 0.05567586675169878, 0.23453334550140426, 0.04388347042549867, 0.07281936676008627, 0.2240289279143326, 0.06024983049428556, 0.03840878060145769, 0.11131162784295157, 0.04136999436013866, 0.09119462411035784, 0.04476765403524041, 0.0484589295956539, 0.07385919729131274, 0.02943911327747628, 0.027214533038204536, 0.04030645592138171, 0.014444998178078094, 0.0475279275997309, 0.045568286659545265, 0.08107437184662558, 0.3155579266604036, 0.05942978699749801, 0.05628681756206788, 0.07676555891521275, 0.01962667975021759, 0.10315741383237764, 0.04474846580706071, 0.05640206938551273, 0.04697983298683539, 0.06532704457640648, 0.061211512875161134, 0.05108165350975469, 0.06049332172551658, 0.10055582999484614, 0.05296659357554745, 0.006509239046863513, 0.04625588277122006, 0.14321237074909732, 0.04983778431778774, 0.04201574447506573, 0.04810699203517288, 0.03385023868759163, 0.051600685619632713, 0.08472313347738236, 0.0676728249527514, 0.029802658027620055, 0.04187262871710118, 0.034884855631389655, 0.048565134638920426, 0.03531945731083397, 0.05068489394034259, 0.03070084781938931, 0.05502088060893584, 0.024878823605831712, 0.025945291672542226, 0.16871403437107801, 0.11699417838826776, 0.13256612874101847, 0.14502543752314523, 0.06181081567774527, 0.5890757404267788, 1.624350850470364, 33.68287459015846, 111.99196055531502, 78.70232686400414, 89.12438482046127, 124.65396791696548, 109.99007597565651, 74.22122731804848, 49.04257379472256, 56.3400062173605, 50.79839497804642, 37.64903336763382, 22.736847549676895, 18.4485724568367, 15.979683436453342, 10.644286181777716, 16.879249066114426, 23.84251791983843, 38.605248257517815, 38.788698613643646, 28.06709513068199, 37.89636589586735, 44.86628629267216, 47.86417342722416, 52.44366869330406, 56.663745045661926, 61.10154591500759, 60.77679254114628, 58.52665588259697, 45.96975088119507, 41.151522025465965, 23.436215221881866, 27.127515748143196, 34.336238130927086, 34.16930548846722, 35.036840736866, 43.92078682780266, 52.2136290371418, 34.713143706321716, 27.253946363925934, 44.17810522019863, 22.97807950526476, 6.293686833232641, 0.11852231982629746, 0.1624031222308986, 0.21883077715756372, 0.12530013191280887, 0.3853044903371483, 0.18667503230972216, 0.19332863856106997, 0.03210622504411731, 0.1100495240825694, 0.07100146118318662, 0.13995860237628222, 0.11234829682507552, 0.23660951846977696, 0.09668747428804636, 0.2872285171179101, 3.054476547986269, 1.2529453611932695, 0.13665994891198352, 0.09510995776508935, 0.04550173085590359, 0.027170599751116242, 0.1042399846483022, 0.08634884507046081, 0.07119089437765069, 0.07487100432626903, 0.10445350795635022, 0.33758175268303603, 0.14042093069292605, 0.06921898573637009, 1.3278231932781637, 3.746829559095204, 2.523965877480805, 36.2175589799881, 23.177604898810387, 28.28906212002039, 49.48088027536869, 44.48020800948143, 43.62007476389408, 30.419788286089897, 28.310196585953236, 25.339818075299263, 15.411025900393724, 14.470936395227909, 17.875540405511856, 22.09922656416893, 31.06836598366499, 44.56523224711418, 46.906279027462006, 52.23321318626404, 55.44473245739937, 46.16821803152561, 28.85422859340906, 30.930376388132572, 25.15667550265789, 26.63305778056383, 34.83049660921097, 33.71185563504696, 32.06258453428745, 28.084308207035065, 20.54818209260702, 20.861026905477047, 24.36760224401951, 31.13943737000227, 37.152084633708, 48.86165030300617, 80.47930151224136, 95.63810929656029, 74.7636254131794, 51.55094839632511, 66.8913446366787, 68.683130890131, 5.464681517332792, 0.09957234331523068, 0.18751079449430108, 0.11240497464314103, 0.06217046044184826, 0.06848991470178589, 0.04948923837218899, 0.05485524066898506, 0.06227108824532479, 0.09211182958097197, 0.06133836446679197, 0.06976559234317392, 0.055668705026619136, 0.025298539658251684, 0.036882750573568046, 0.07698838875512592, 0.0760903900663834, 0.032551354088354856, 0.07389404854620807, 0.07890475506428629, 0.014639080000051763, 0.22668114106636494, 0.12075239937985316, 0.04434500835486688, 0.07124512310838327, 0.04208712423860561, 0.024635469671920873, 0.09917069299262948, 0.008481028944515856, 0.06648371883784421, 0.1887178680044599, 0.21116633608471602, 0.3113064297940582, 0.08983016334241256, 0.25226596975699067, 0.334525647922419, 0.2277502344804816, 0.19085219566477463, 0.3085401188582182, 0.18355654261540622, 0.1492300009704195, 0.12043797367368825, 0.09132982115261257, 0.10481594319571741, 0.29470271605532616, 0.22602293029194698, 0.14444605767494068, 0.15381019504275173, 0.14526385988574475, 0.29549690312705934, 0.18502822145819664, 0.24600677046692, 0.08010759833268821, 0.30533478304278105, 0.19859607622493058, 0.2765822899527848, 0.32303720188792795, 0.10948719136649743, 0.20852515124715865, 0.2725746331270784, 0.23300035041756928, 0.6690564611926675, 1.5019570430740714, 17.52917569130659, 147.83225297927856, 105.50731971859932, 106.8031793832779, 116.8635955452919, 155.2290576696396, 103.9991806447506, 90.91478794813156, 63.22966732084751, 56.10815025866032, 59.875116124749184, 34.80581313371658, 19.013199359178543, 13.945257402956486, 14.223434776067734, 21.145834922790527, 41.9517020881176, 70.64586237072945, 72.36622765660286, 54.62561421096325, 58.831114545464516, 53.769660741090775, 54.55024525523186, 56.93528987467289, 56.854525208473206, 60.331137254834175, 57.26548835635185, 52.436965852975845, 42.98344932496548, 33.68591822683811, 20.21367274224758, 20.721179209649563, 33.79825159907341, 47.051841616630554, 50.32590173184872, 48.71354565024376, 62.974746599793434, 39.99174825847149, 30.465399138629436, 56.53362102806568, 26.08994722366333, 17.722712606191635, 0.2186331877601333, 0.8169674430973828, 0.38312201213557273, 1.743552591651678, 3.8566415291279554, 0.4404873261228204, 0.40850090968888253, 0.2934720570920035, 0.2527928352355957, 0.20991028082789853, 0.1495732442708686, 0.32370828150305897, 0.3310599667020142, 0.18214537849416956, 0.47291840775869787, 6.179762771353126, 2.0088341692462564, 0.19160939409630373, 0.16467220906633884, 0.10045946211903356, 0.12177485623396933, 0.13256494130473584, 0.2251383347902447, 0.09370948799187317, 0.1376905248616822, 0.2504468767438084, 0.39176806225441396, 0.29200503893662244, 0.35655078012496233, 2.3332676477730274, 4.591032397001982, 2.1639591827988625, 45.333760008215904, 34.18683394789696, 34.19065274298191, 62.07908906042576, 59.74765196442604, 43.14997538924217, 35.218281000852585, 47.17122361063957, 22.670218124985695, 11.103301551192999, 19.848863817751408, 32.61798933148384, 39.264904260635376, 34.778089821338654, 41.26210369169712, 39.792790934443474, 50.384236201643944, 49.388735219836235, 49.817743599414825, 36.17093548178673, 47.38496974110603, 46.90391555428505, 48.085762336850166, 51.5757192671299, 45.06040267646313, 36.61632478237152, 28.14565971493721, 17.448699809610844, 14.748292062431574, 19.289455935359, 37.791943699121475, 58.81687670946121, 85.35903006792068, 113.62701281905174, 102.80959367752075, 66.9295097887516, 66.98283612728119, 82.26416453719139, 63.48687171936035, 1.8813159805722535, 0.1775038830237463, 0.29514343303162605, 0.21987092681229115, 0.2031964567140676, 0.28629531094338745, 0.13907736138207838, 0.22955556807573885, 0.1529887117794715, 0.22540472127730027, 0.16149019153090194, 0.1624271529726684, 0.32717069727368653, 0.13709542632568628, 0.1637993098120205, 0.15447382349520922, 0.21097205666592345, 0.12318054330535233, 0.22426190291298553, 0.2960829029325396, 0.19559209991712123, 0.4875890049152076, 0.22897859278600663, 0.17793133039958775, 0.19585090165492147, 0.19548183161532506, 0.17572192708030343, 0.11777297331718728, 0.1380984389106743, 0.19599934603320435], [0.015555332738586003, 0.02808310371619882, 0.04137128569709603, 0.07661962299607694, 0.014893978968757438, 0.031025637617858592, 0.1534129530773498, 0.01955158182681771, 0.012067080024280585, 0.01017025353576173, 0.16924386844038963, 0.09501557142357342, 0.08483639263431542, 0.054680479734088294, 0.1544125666259788, 0.05070934028481133, 0.053547168281511404, 0.033906560274772346, 0.1390816509956494, 0.10477180767338723, 0.17530001612612978, 0.08316721345181577, 0.031377061241073534, 0.0462965747283306, 0.1399245229549706, 0.2024779687053524, 0.18226904998300597, 0.056458888211636804, 0.03979840017564129, 0.03535272408043966, 0.3921319224173203, 0.09991405036998913, 0.06545787779032253, 0.5949749832507223, 15.564431268721819, 120.03166794776917, 85.0325059890747, 63.42403069138527, 83.82633671164513, 130.1980224251747, 98.46228495240211, 76.31473258137703, 41.30747325718403, 17.068570107221603, 6.389068840071559, 2.8592836344614625, 6.0294456873089075, 2.137518539093435, 3.70469409506768, 4.927662508562207, 2.916704728268087, 19.92896541953087, 40.64167678356171, 48.67194168269634, 41.95683181285858, 38.256692960858345, 31.980410143733025, 23.586835339665413, 29.878064654767513, 32.1220513433218, 33.87565344572067, 32.88222335278988, 23.019227497279644, 19.094045720994473, 17.65754610300064, 12.652826104313135, 22.89683036506176, 33.362730368971825, 36.60448841750622, 34.92984987795353, 38.127575889229774, 32.39421933889389, 15.866186376661062, 21.205505020916462, 9.506183601915836, 0.3383011609548703, 0.29898057400714606, 0.8708655915688723, 0.748313736403361, 0.8720924507360905, 0.09412905375938863, 0.127380327321589, 0.15419988194480538, 0.04883501293079462, 0.05603608296951279, 0.22219528880668804, 0.0073748680370044895, 0.07290581954293884, 0.10899511034949683, 0.26854619616642594, 1.1247497401200235, 1.4118201797828078, 0.1813585832132958, 0.05514069664059207, 0.02187351514294278, 0.06564035706105642, 0.10760150544228964, 0.06346551555907354, 0.007176193712439272, 0.0994665056350641, 0.050279736969969235, 0.06970549322431907, 0.051711736887227744, 0.12109729024814442, 0.133575004292652, 1.096719119232148, 0.4596690827747807, 7.568555474281311, 19.518247358500957, 25.398068949580193, 29.038847386837006, 34.8304358124733, 32.56551794707775, 25.800858736038208, 4.254948981106281, 3.550059017725289, 11.853840127587318, 3.0850399704650044, 5.204594498500228, 11.369580812752247, 13.299024179577827, 22.115696780383587, 26.92826583981514, 24.85031694173813, 19.283167272806168, 26.393093056976795, 32.752836495637894, 34.56006892025471, 26.831429935991764, 18.218772187829018, 11.782779190689325, 8.113628625869751, 8.397523742169142, 5.780408950522542, 6.45134037360549, 8.93051354214549, 22.34500877559185, 52.246398478746414, 84.50121849775314, 105.524373203516, 72.81705066561699, 32.03856222331524, 54.10885713994503, 70.96749231219292, 40.5396294593811, 1.3342957897111773, 0.11552921598195098, 0.18770848779240623, 0.10787240418721922, 0.05579911150562111, 0.17658642522292212, 0.09273568633943796, 0.1391950956895016, 0.05205270179430954, 0.09809845287236385, 0.09366423182655126, 0.11900178433279507, 0.031045261857798323, 0.08309181124786846, 0.034437299764249474, 0.006837645423729555, 0.15629563276888803, 0.0705896805447992, 0.01879042960354127, 0.17187521239975467, 0.0607918766036164, 0.041477846971247345, 0.052222846570657566, 0.03308394523628522, 0.06688746943837032, 0.04055733894347213, 0.06296554551227018, 0.05232546332990751, 0.04069676622748375, 0.03380657442903612, 0.06342787382891402, 0.04050370022014249, 0.04801141454663593, 0.049987252859864384, 0.05923144803091418, 0.036034520308021456, 0.018758949554467108, 0.08536434164852835, 0.09276551325456239, 0.0701445403683465, 0.054049049358582124, 0.10617411797284149, 0.1224141199782025, 0.09795918143936433, 0.07292196125490591, 0.06287108495598659, 0.16319986229063943, 0.11926889070309699, 0.11323272163281217, 0.025120229402091354, 0.0383464105107123, 0.11634391601546668, 0.0706043750687968, 0.026487968607398216, 0.15806727285962552, 0.03574963950086385, 0.08474312693579122, 0.0058373996580485255, 0.1343119569355622, 0.1185877327225171, 0.038230691134231165, 0.17925270949490368, 0.052804894439759664, 1.0016454895958304, 1.7963748634792864, 49.89231839776039, 115.38841590285301, 84.55895259976387, 88.27193096280098, 124.15325358510017, 115.13455912470818, 85.75249895453453, 61.464529037475586, 48.055337369441986, 44.37609739601612, 32.77228385210037, 25.778593830764294, 21.68061252683401, 18.319766968488693, 18.922889605164528, 16.249947734177113, 14.119042977690697, 27.08356160670519, 37.622738778591156, 35.90711943805218, 24.302882216870785, 26.371827498078346, 25.94687920063734, 25.773682594299316, 36.40352100133896, 44.91769753396511, 52.059133127331734, 47.173822671175, 39.560832381248474, 27.701093070209026, 25.6786135956645, 30.134659186005592, 44.51562590897083, 54.18325714766979, 43.04680332541466, 47.706253901124, 43.94961588084698, 37.308484241366386, 23.957482650876045, 25.038916021585464, 16.043031737208366, 0.11157195098348893, 0.4376474831951782, 0.35628663492389023, 0.18251467117806897, 0.46944361296482384, 0.1518844999372959, 0.04783835684065707, 0.25748065556399524, 0.3044646297348663, 0.05597730116278399, 0.18163012020522729, 0.09088156395591795, 0.23544351541204378, 0.0589182320254622, 0.6752466852776706, 1.2519065919332206, 1.919043562375009, 0.25590926175937057, 0.06715914001688361, 0.03488298170850612, 0.07319235533941537, 0.1866390381474048, 0.05897560375160538, 0.09533609758364037, 0.017205038893735036, 0.0284058359102346, 0.12266678415471688, 0.03200735984137282, 0.1040169173211325, 0.32256412727292627, 2.9694026755169034, 0.7837501598987728, 16.307153664529324, 32.714283764362335, 26.134488433599472, 32.90764778852463, 41.82103469967842, 34.263031259179115, 33.36144223809242, 26.669446527957916, 10.492870956659317, 11.607468947768211, 12.444090005010366, 20.927464440464973, 30.229921974241734, 25.54863967001438, 29.79372628033161, 32.96949706971645, 30.725345090031624, 18.080385513603687, 18.808183260262012, 23.293677270412445, 26.355841755867004, 32.384841442108154, 36.54777266085148, 29.11908768117428, 24.607867151498795, 24.5186460390687, 23.212836608290672, 25.45893218368292, 27.87901472300291, 31.918222680687904, 45.99019758403301, 55.90012662112713, 83.29313412308693, 90.97145810723305, 63.36022451519966, 55.50905540585518, 73.02678421139717, 66.57883420586586, 6.820833021774888, 0.052687716743093915, 0.08751878893235698, 0.23188467981526628, 0.030401103649637662, 0.16900406568311155, 0.06290955047006719, 0.08436038653599098, 0.024387937446590513, 0.033231335764867254, 0.06407564258552156, 0.05871296511031687, 0.01988295633054804, 0.025003209411806893, 0.06561843401868828, 0.050641693524084985, 0.13255656987894326, 0.14801911282120273, 0.0990533668664284, 0.18277385883266106, 0.10076444028527476, 0.08006643882254139, 0.013742874525632942, 0.09216611026204191, 0.016739901548135094, 0.04441917859367095, 0.014188164059305564, 0.07246710636536591, 0.050998978258576244, 0.012519737229013117, 0.06631871714489534, 0.11395769601222128, 0.11429897262132727, 0.17439079616451636, 0.18349562713410705, 0.1408825465478003, 0.16007951722713187, 0.23049781360896304, 0.15998318645870313, 0.10870359474211, 0.14302233641501516, 0.2520730113610625, 0.22099582973169163, 0.23871557030361146, 0.16345591808203608, 0.4483778995927423, 0.26621778204571456, 0.2072362633771263, 0.2688956289784983, 0.20958416629582644, 0.16856906324392185, 0.34808967320714146, 0.3067634766921401, 0.29518169816583395, 0.21933331503532827, 0.1950821405625902, 0.2797805011505261, 0.1846660385490395, 0.16424952627858147, 0.19411142624448985, 0.19112239679088816, 0.585211644647643, 0.1747075596358627, 0.6156059761997312, 0.5543056468013674, 26.686845794320107, 152.3805633187294, 103.3331523835659, 93.14551904797554, 112.65725925564766, 150.6207713484764, 122.7998574078083, 106.87565669417381, 69.03928577899933, 43.18693980574608, 36.87507949769497, 29.459528513252735, 18.730760514736176, 13.946423940360546, 15.358650460839272, 13.461186178028584, 19.021640606224537, 40.93140363693237, 67.99594536423683, 72.89066791534424, 60.213468968868256, 48.66357073187828, 40.859306305646896, 36.37715041637421, 38.10551047325134, 40.18496789038181, 44.58847559988499, 44.428735971450806, 37.7452290058136, 27.574075385928154, 26.375266313552856, 23.789615258574486, 34.54057216644287, 57.16955870389938, 53.163490667939186, 49.30231645703316, 47.60888792574406, 44.29539732635021, 25.838775001466274, 42.13187702000141, 27.078144997358322, 0.4672092734836042, 1.7475201725028455, 2.7986025530844927, 1.2560474197380245, 2.529457532800734, 1.915957652963698, 0.4216903285123408, 0.9079262497834861, 0.4069099825574085, 0.1355856456211768, 0.3954957512905821, 0.18861730699427426, 0.44984655047301203, 0.4141212534159422, 1.1313121067360044, 3.1024670228362083, 2.1015893295407295, 0.4551746364450082, 0.2679856965551153, 0.15672851266572252, 0.1956473899190314, 0.3130172286182642, 0.1500032446347177, 0.14994685625424609, 0.19014522578800097, 0.35111291566863656, 0.20462424494326115, 0.10369527051807381, 0.23277699365280569, 0.29759934812318534, 4.62536402978003, 1.2975528300739825, 13.800935447216034, 52.14060075581074, 48.65116819739342, 46.586157605051994, 58.42213489115238, 63.110509514808655, 57.50869810581207, 21.951454393565655, 5.287640942260623, 18.926096633076668, 25.27923222631216, 31.038934662938118, 37.667937353253365, 39.613664746284485, 36.45209759473801, 36.270174756646156, 34.22368437051773, 25.612915121018887, 32.145165503025055, 45.98124906420708, 53.0481668561697, 49.34775061905384, 46.488100066781044, 34.19074773788452, 24.247072711586952, 20.089457407593727, 17.562135122716427, 20.274429582059383, 27.39590484648943, 47.44013138115406, 76.11625403165817, 97.63712882995605, 116.17745116353035, 88.3054755628109, 56.47081799805164, 78.34883943200111, 90.71823209524155, 67.48968333005905, 2.3530907090753317, 0.157729699567426, 0.3710894234245643, 0.29498390096705407, 0.11126077588414773, 0.2553367690416053, 0.29404808243270963, 0.2519580675289035, 0.269775697379373, 0.08798372960882261, 0.29741470178123564, 0.2207121957326308, 0.1566785215982236, 0.1216582277265843, 0.1617710350546986, 0.18967908283229917, 0.22965204727370292, 0.17318974889349192, 0.25277906097471714, 0.266846677986905, 0.14111688709817827, 0.16522922058356926, 0.17094098206143826, 0.18677779007703066, 0.13104763522278517, 0.14101190288783982, 0.14799592812778428, 0.19599560560891405, 0.1693847429123707, 0.41259254794567823, 0.16856895934324712], [0.05053986344137229, 0.0419661764317425, 0.08001217298442498, 0.09460120811127126, 0.0412818123731995, 0.07667242680327035, 0.06751577166141942, 0.007734709470241796, 0.02602476826723432, 0.040058560043689795, 0.06878120024339296, 0.06441144956625067, 0.06364821005263366, 0.021685974425054155, 0.0627803648239933, 0.14040829933946952, 0.029380375999608077, 0.027260078641120344, 0.1356467540608719, 0.16430107585620135, 0.23601756663993, 0.19762175506912172, 0.13583083637058735, 0.04975084913894534, 0.14023059949977323, 0.14860772498650476, 0.13952585606602952, 0.03588862520700786, 0.058087412544409744, 0.14341856905957684, 0.1450409335666336, 0.07538298232248053, 0.21961723105050623, 0.10948891314910725, 0.6233827932737768, 25.217656530439854, 122.9114194214344, 87.25309923291206, 77.3758028447628, 93.26893642544746, 131.49951338768005, 112.23646983504295, 75.60487747192383, 38.13118189573288, 16.889804899692535, 6.035698251798749, 5.018392140045762, 4.667162736877799, 1.6899168072268367, 0.6380566558800638, 1.1121920077130198, 3.482411722652614, 4.293810920789838, 15.783067736774683, 34.12448689341545, 45.18918916583061, 48.248629197478294, 45.499039739370346, 33.88497814536095, 28.578498288989067, 21.05870559811592, 20.09278792887926, 22.920225709676743, 21.535859294235706, 21.890346072614193, 12.685542348772287, 7.888308791443706, 8.28409317880869, 15.326326545327902, 25.31898759305477, 36.22809201478958, 32.82896541059017, 38.37809644639492, 36.692244708538055, 5.175411114469171, 0.22381973132723942, 0.5261672660708427, 0.2980374527396634, 0.4188210371648893, 0.18861769291106611, 0.15269836876541376, 0.05351681073079817, 0.12197171090519987, 0.06967018183786422, 0.020255451381672174, 0.08028878626646474, 0.11671836662571877, 0.21454217290738598, 0.22903008299181238, 0.2524155570426956, 1.2207240401767194, 1.063317961525172, 0.14999975654063746, 0.05628861727018375, 0.05035385154769756, 0.10806235688505694, 0.128034500812646, 0.16159278602572158, 0.037470709648914635, 0.02582521403382998, 0.016961616311164107, 0.052563432982424274, 0.07238850550493225, 0.22171814722241834, 0.005772332788183121, 0.8164338686037809, 0.2618364983936772, 1.019713282585144, 7.941421866416931, 23.788927495479584, 39.04813729226589, 45.73525786399841, 20.28580617159605, 7.987850625067949, 9.282641597092152, 14.04068548232317, 10.911190509796143, 2.6387871662154794, 6.130381096154451, 13.133119381964207, 10.772729739546776, 13.073180448263884, 20.66655144095421, 24.286136515438557, 31.255876421928406, 28.886112682521343, 20.41234128177166, 18.013338111341, 13.693674802780151, 11.151337623596191, 5.731707438826561, 4.554380038753152, 5.7005049381405115, 15.843363851308823, 21.662189215421677, 42.94314868748188, 75.63480466604233, 95.60242921113968, 98.81657034158707, 66.12478137016296, 39.39624801278114, 56.58661298453808, 63.88233169913292, 31.577943339943886, 1.1086206743493676, 0.09952368069207296, 0.27501104457769543, 0.09912145891576074, 0.047783656846149825, 0.14064209070056677, 0.08649272524053231, 0.032521872271900065, 0.16632375482004136, 0.07636908136191778, 0.1073626006837003, 0.06671526891295798, 0.1300007023382932, 0.06966373257455416, 0.06172575071104802, 0.058835805393755436, 0.04789886042999569, 0.016445333858428057, 0.1442980585852638, 0.08134248011629097, 0.07372720632702112, 0.08651318625197746, 0.09422621573321521, 0.10534970322623849, 0.04712737565569114, 0.0616347262985073, 0.12273019325220957, 0.023179153286037035, 0.09690397360827774, 0.04242360286298208, 0.0900379498489201, 0.035055568150710315, 0.04450560169061646, 0.04067376707098447, 0.08773470195592381, 0.08216152913519181, 0.06655723598669283, 0.11137805006001145, 0.015884273925621528, 0.05107966084324289, 0.016542981938982848, 0.03632177598774433, 0.1286613632692024, 0.04719357151770964, 0.11527008769917302, 0.12384608649881557, 0.04370045309769921, 0.06765710626496002, 0.12684178043855354, 0.026496597929508425, 0.08503847944666632, 0.14264275756431744, 0.08076589074335061, 0.13700823881663382, 0.03818722725554835, 0.04965277432347648, 0.058815422307816334, 0.16287288686726242, 0.07327809566049837, 0.11220724423765205, 0.06991600341279991, 0.0982873368775472, 0.13793558202451095, 0.01882415836007567, 0.06656542187556624, 0.5863675544969738, 2.334512793458998, 59.52616944909096, 114.76305305957794, 80.38657128810883, 86.4480896294117, 123.0579623579979, 119.93772178888321, 98.5946774482727, 65.87069660425186, 48.332760483026505, 37.42741785943508, 26.37570519000292, 20.782297030091286, 21.100866235792637, 16.89034067094326, 19.311787337064743, 20.075248070061207, 17.847843691706657, 20.671987049281597, 32.5208855420351, 41.03252001106739, 35.82539722323418, 29.441236294806004, 21.74307357519865, 18.370585441589355, 21.739313676953316, 20.156601704657078, 25.940178260207176, 30.191439539194107, 30.89359626173973, 32.33521610498428, 22.85966645926237, 21.164765506982803, 24.305015802383423, 42.070525512099266, 38.52697625756264, 41.61705024540424, 39.807807728648186, 33.230440467596054, 46.05593405663967, 16.81363418698311, 0.099616538209375, 0.2735157951246947, 0.9611621650401503, 0.9083236253354698, 1.0868334746919572, 0.38772104191593826, 0.04707097243226599, 0.1282724185148254, 0.06320095475530252, 0.0389240759977838, 0.07021558616543189, 0.1107972304453142, 0.12105918096494861, 0.07320440781768411, 0.23154235677793622, 2.8960734978318214, 1.7004592227749527, 0.41987482749391347, 0.11431996055762284, 0.0298862182899029, 0.05824989464599639, 0.10927427661954425, 0.12741370912408456, 0.06145968705823179, 0.09370054511236958, 0.12224886595504358, 0.05369215054088272, 0.029407757538137957, 0.1813865770236589, 0.23506411467678845, 1.326808885205537, 0.6029020703863353, 3.6978497123345733, 22.460237592458725, 38.4370768815279, 43.669650703668594, 47.379638627171516, 42.90211848914623, 32.281467989087105, 17.260235622525215, 13.876402247697115, 13.09558404609561, 12.303418703377247, 13.22954585775733, 18.893399387598038, 26.384180635213852, 25.253619700670242, 18.93720343708992, 13.029409646987915, 13.989724516868591, 21.300366930663586, 23.904059417545795, 33.854397386312485, 33.92037324607372, 28.81762705743313, 20.215646736323833, 18.515439368784428, 23.703338988125324, 35.67050613462925, 34.608672112226486, 36.994871869683266, 55.64650543034077, 71.42600610852242, 90.34278184175491, 88.63649100065231, 59.46544870734215, 57.10590451955795, 75.39492353796959, 55.297870337963104, 6.462435778230429, 0.16143926535733044, 0.16917664470383897, 0.03054985972994473, 0.08452271649730392, 0.033123041575890966, 0.05752564386057202, 0.04795350476342719, 0.00965129100222839, 0.026602070101944264, 0.14748167915968224, 0.058123080161749385, 0.04826128082640935, 0.027541638337424956, 0.08418666460784152, 0.05288687207212206, 0.021426619787234813, 0.013053693928668508, 0.05107897064590361, 0.07459404965629801, 0.09544677406665869, 0.05807314104458783, 0.05804418986372184, 0.05598116775217932, 0.06418427816242911, 0.04044709661684465, 0.033095556136686355, 0.03889972984325141, 0.041023993981070817, 0.02915104865678586, 0.07147724463720806, 0.02726543323660735, 0.1625428389525041, 0.15109115891391411, 0.20550407585687935, 0.2091302687767893, 0.14015294116688892, 0.1995764533057809, 0.3259861405240372, 0.08465976890875027, 0.2315860692760907, 0.11831917916424572, 0.1824026959366165, 0.15729264880064875, 0.1667559816269204, 0.20895844674669206, 0.1500979278353043, 0.3041284071514383, 0.21586684713838622, 0.1638741182978265, 0.2618090092437342, 0.30881438695359975, 0.2745120838517323, 0.3652280004462227, 0.31669638119637966, 0.11168116543558426, 0.2642522781388834, 0.22828032088000327, 0.19433236360782757, 0.22812392067862675, 0.14517227886244655, 0.22082480922108516, 0.18568355269962922, 0.11712030638591386, 0.3425601089838892, 0.5100243666674942, 0.6966895284131169, 35.641544088721275, 153.4432902932167, 103.31169873476028, 103.95388707518578, 124.52021509408951, 150.6600308418274, 138.77408623695374, 110.84805473685265, 82.99900710582733, 55.59946395456791, 25.738076604902744, 14.799634907394648, 12.764349170029163, 10.712333880364895, 14.989300779998302, 12.886698804795742, 13.063126187771559, 18.59576515853405, 39.80188764631748, 56.647896096110344, 71.2720687687397, 71.25678598880768, 65.22134944796562, 52.668924406170845, 40.48080861568451, 28.996599353849888, 28.506533950567245, 29.79872491210699, 33.05797912180424, 29.692697301506996, 14.318963550031185, 11.358081679791212, 10.041919704526663, 23.521475046873093, 38.67850832641125, 42.0806747674942, 39.68240685760975, 44.97535564005375, 52.896938771009445, 14.124847166240215, 0.449890693416819, 2.481483444571495, 2.1413461212068796, 1.8819283414632082, 1.0314282914623618, 0.8491285610944033, 0.1723709818907082, 0.1594973320607096, 0.17145972844446078, 0.16318825510097668, 0.12308718112763017, 0.3078009991440922, 0.28943474404513836, 0.26824316242709756, 0.4574756801594049, 4.303034450858831, 2.745894156396389, 0.3672065067803487, 0.26164719136431813, 0.21951831760816276, 0.22820808022515848, 0.18147719325497746, 0.2220456866780296, 0.0999682791007217, 0.14872534055029973, 0.20810603076824918, 0.19662512495415285, 0.15370752633316442, 0.4400210495805368, 1.131462436169386, 2.775782165117562, 0.6459135061595589, 3.0863546999171376, 17.657069228589535, 43.297943249344826, 61.54555968940258, 64.34694036841393, 48.695944994688034, 31.104439347982407, 21.84954386204481, 26.190729215741158, 20.614490434527397, 14.168170541524887, 27.591871730983257, 31.3754104077816, 32.88763806223869, 32.98536501824856, 33.24322298169136, 32.869418039917946, 40.543368458747864, 43.208838030695915, 36.72843396663666, 36.714032739400864, 30.842720791697502, 23.538207449018955, 12.763848546892405, 11.666703019291162, 17.69704308360815, 28.236972615122795, 42.01122209429741, 59.696616902947426, 84.44343119859695, 103.41385245323181, 104.20021265745163, 85.85081487894058, 62.70867347717285, 78.67206528782845, 87.70896837115288, 50.128266736865044, 2.3957201465964317, 0.19469261693302542, 0.2795194135978818, 0.09663901204476133, 0.23496952053392306, 0.15953837282722816, 0.20245757448719814, 0.1360183474025689, 0.41170502838212997, 0.20072942425031215, 0.38146105594933033, 0.16818066767882556, 0.20509006135398522, 0.10191840570769273, 0.18933526065666229, 0.11070494438172318, 0.08422871469520032, 0.10625376526149921, 0.19196182518498972, 0.2246261341497302, 0.3355542052304372, 0.18896319234045222, 0.15142932592425495, 0.16556428541662171, 0.25730538996867836, 0.19719791453098878, 0.18544159771408886, 0.11088355706306174, 0.10336345629184507, 0.19105689483694732, 0.1261325692757964, 0.14848279184661806], [0.027886046809726395, 0.05483514702063985, 0.09766238916199654, 0.0363829326670384, 0.058537595614325255, 0.03713706973940134, 0.048465453073731624, 0.057617321363068186, 0.03495636898151133, 0.0153185440285597, 0.10404684813693166, 0.04827878809010144, 0.03667075237899553, 0.02820537811203394, 0.04279902939742897, 0.06581027919310145, 0.043327405146555975, 0.04338764898420777, 0.08921690445276909, 0.0694463872059714, 0.13210846111178398, 0.010207331233687, 0.07738269181572832, 0.07399504742352292, 0.03550172506948002, 0.06556620166520588, 0.19427196762990206, 0.3247943997848779, 0.1580806463607587, 0.19293405348435044, 0.060736178420484066, 0.11197308180271648, 0.20123022550251335, 0.30066477425862104, 0.10138814119272865, 0.8476510341279209, 18.483682572841644, 104.46282416582108, 91.9679394364357, 82.32412531971931, 80.65008714795113, 102.79458448290825, 121.40824288129807, 96.95926040410995, 54.73146893084049, 25.96006829291582, 14.030085951089859, 5.644643185660243, 3.437327854335308, 4.042912758886814, 2.6134691247716546, 1.3540497422218323, 2.0343999098986387, 7.304980717599392, 9.641128610819578, 14.905781261622906, 33.769597336649895, 41.92771777510643, 50.453894063830376, 45.767715722322464, 44.87647354602814, 34.52921837568283, 27.933695688843727, 23.123801685869694, 20.670619122684002, 18.217387162148952, 17.074524387717247, 15.317734256386757, 7.787720588967204, 13.482446037232876, 29.449856132268906, 42.61822052299976, 32.618266716599464, 12.9593594558537, 6.044835336506367, 0.22177219041623175, 0.3673358779633418, 1.0421300609596074, 0.6923346652183682, 0.09402606592630036, 0.14940087305149063, 0.02090695870720083, 0.1612185061094351, 0.03779319878958631, 0.0068084233589615906, 0.04604269714036491, 0.03781861734751146, 0.07436303392751142, 0.20489717717282474, 0.10132362629519776, 0.32128597085829824, 1.0532574076205492, 0.3706285497173667, 0.058150209370069206, 0.05605635102256201, 0.08987050649011508, 0.07262683138833381, 0.10345504473662004, 0.04981187965313438, 0.018213971961813513, 0.048907361197052523, 0.04464846511837095, 0.05185003981750924, 0.38755684916395694, 0.42449344997294247, 0.6270104111172259, 0.4584077879553661, 1.5205788938328624, 9.035941734910011, 14.287483189255, 29.904083758592606, 25.669421888887882, 26.860956251621246, 24.444958493113518, 15.683709718286991, 7.18813176266849, 4.061508486047387, 5.421897238120437, 1.8158853915520012, 8.466301001608372, 20.695257000625134, 35.00290475785732, 35.92939764261246, 28.93388941884041, 28.083084672689438, 24.0696070343256, 18.190076127648354, 7.6227685902267694, 5.799755612388253, 8.15839022397995, 9.26052488386631, 14.968381002545357, 26.43418215215206, 41.97215639054775, 66.34842216968536, 80.51154658198357, 88.02632734179497, 66.09449699521065, 43.601375967264175, 46.93498648703098, 69.36547547578812, 62.92218402028084, 20.29004294425249, 0.5417662009131163, 0.07273342605913058, 0.040483944248990156, 0.19675060728332028, 0.1808919059112668, 0.07400429458357394, 0.16467909619677812, 0.09148700803052634, 0.059486765385372564, 0.04784880256920587, 0.15052579081384465, 0.0772076340217609, 0.031249831154127605, 0.0702857413853053, 0.09341737866634503, 0.09829874368733726, 0.049944427228183486, 0.05499372913618572, 0.02812913171510445, 0.0702037860173732, 0.03195923527528066, 0.02766932113445364, 0.05378756846766919, 0.034916415461339056, 0.04352500938693993, 0.05983488830679562, 0.054815353942103684, 0.039502479921793565, 0.060468919909908436, 0.061164646249380894, 0.044956730998819694, 0.058745237402035855, 0.037266029030433856, 0.035523755723261274, 0.03590608794183936, 0.055049575748853385, 0.05447455230751075, 0.06235001565073617, 0.09648838575230911, 0.12085944676073268, 0.03985214279964566, 0.05680528192897327, 0.02668752655154094, 0.08096125369775109, 0.03540704186889343, 0.0327423643466318, 0.06756887974916026, 0.09642574848840013, 0.13178696273826063, 0.013139290458639152, 0.12626382551388815, 0.1528048817999661, 0.035645905809360556, 0.04409307148307562, 0.10928131217951886, 0.16948778269579634, 0.11694946399074979, 0.038461320946225896, 0.028818701939599123, 0.14087671326706186, 0.12523384328233078, 0.12163807099568658, 0.18573985202237964, 0.043206208720221184, 0.041690858197398484, 0.03430712706176564, 0.06924070097738877, 0.12731997587252408, 3.8653703732416034, 53.401331305503845, 108.82844030857086, 88.24032425880432, 85.91065406799316, 113.6496140062809, 119.98270377516747, 102.01132491230965, 76.23153984546661, 67.4776303768158, 44.63509909808636, 35.52409619092941, 22.180401608347893, 19.630295746028423, 19.267466515302658, 18.88166181743145, 17.097399160265923, 20.893361270427704, 23.407408967614174, 28.972725234925747, 36.33210763335228, 44.14397545158863, 39.06823441386223, 34.74190056324005, 26.90491609275341, 30.508952401578426, 23.577326349914074, 19.37711913138628, 21.65555477142334, 22.294743172824383, 20.203880667686462, 22.36330859363079, 21.93700186908245, 18.38063210248947, 37.32171893119812, 50.10530076920986, 49.268407076597214, 47.837039083242416, 33.6542659252882, 9.375973138958216, 0.12399735845974647, 0.30866975721437484, 0.6256536464206874, 1.2747363606467843, 0.8816681744065136, 0.5509498924948275, 0.025581427798897494, 0.028384718098095618, 0.01730612126266351, 0.10377911836258136, 0.04765755853441078, 0.04526305987383239, 0.0696091030840762, 0.11714095293427818, 0.2260707988170907, 2.1516452310606837, 0.5463733349461108, 0.02394059680227656, 0.03716689665452577, 0.1162005405058153, 0.1376271602930501, 0.06528230791445822, 0.05228990332398098, 0.06248227378819138, 0.1392992486944422, 0.06138433309388347, 0.03180067542416509, 0.12255075678694993, 0.19862813700456172, 0.1866133598377928, 1.010361984372139, 0.35396481107454747, 1.7409785860218108, 10.470463559031487, 25.79447127878666, 40.05475267767906, 47.87697874009609, 34.46038506925106, 22.20430612564087, 17.64735884964466, 11.959253121167421, 14.25283094868064, 7.4514775816351175, 12.877333257347345, 24.457594715058804, 24.78187881410122, 22.43009950965643, 18.7832622975111, 24.77854449301958, 36.66827939450741, 35.270949974656105, 37.32736922800541, 25.723396092653275, 21.627597771584988, 22.407697811722755, 23.3970545232296, 29.601249508559704, 36.233240738511086, 37.96136140823364, 45.55556930601597, 63.30831550061703, 85.30063480138779, 82.57111206650734, 68.7995034456253, 61.41423113644123, 69.66028645634651, 79.35390830039978, 42.6388344168663, 3.304424285888672, 0.04999252952984534, 0.026719494562712498, 0.11544140506885014, 0.1785751583520323, 0.1361007703235373, 0.11090948770288378, 0.1944859288050793, 0.21466627484187484, 0.09375393521622755, 0.06967166613321751, 0.03940237162169069, 0.018173903408751357, 0.03856567433103919, 0.052902954412274994, 0.026474218466319144, 0.01786237393389456, 0.036597001453628764, 0.04688763969170395, 0.07758603285765275, 0.0194038313566125, 0.08436621239525266, 0.0707741265068762, 0.047988337464630604, 0.03903384706063662, 0.027158552838955075, 0.024885725579224527, 0.05248331814073026, 0.03713216043252032, 0.03199865073838737, 0.0452547366876388, 0.06066430141800083, 0.07623173209140077, 0.14630443998612463, 0.16810489440103993, 0.13215735380072147, 0.1328215908142738, 0.15519700187724084, 0.15395454276585951, 0.2515498863067478, 0.11732643790310249, 0.11603711216594093, 0.14672231365693733, 0.1658340560970828, 0.11110921448562294, 0.256089722388424, 0.1282585403532721, 0.15814944345038384, 0.2478073097881861, 0.2785827044863254, 0.2695294824661687, 0.3146928199566901, 0.20273329719202593, 0.17239060427527875, 0.24665006407303736, 0.21100742742419243, 0.3086899733170867, 0.15753175393911079, 0.15191331011010334, 0.27943115739617497, 0.23603557114256546, 0.1973000043653883, 0.294743207632564, 0.1463599526323378, 0.31809310312382877, 0.13508583884686232, 0.4722197202499956, 0.20292195113142952, 0.9804040950257331, 28.544890992343426, 132.8354761004448, 107.9058726131916, 101.74058184027672, 109.64636161923409, 132.5566926598549, 147.53108114004135, 118.6895951628685, 89.42300319671631, 74.03721079230309, 50.8891075104475, 23.149159625172615, 15.649803187698126, 10.105698332190514, 9.774522352963686, 8.511384632438421, 12.421385273337364, 15.910868179053068, 27.012625113129616, 38.855909407138824, 54.64732624590397, 61.67396999895573, 69.5959635078907, 70.94434395432472, 63.43650542199612, 42.35416129231453, 35.3068770468235, 26.862677559256554, 26.327423080801964, 22.541659623384476, 24.36882197856903, 22.75449190288782, 7.537754802033305, 23.559499606490135, 47.73821018636227, 53.752561658620834, 40.816471204161644, 22.834965884685516, 9.494442231953144, 0.5415052024181932, 1.284382261801511, 1.933897677809, 2.926894356496632, 1.2560245022177696, 0.9277791751082987, 0.16164234664756805, 0.2854824811220169, 0.15623597893863916, 0.25223675882443786, 0.13759288791334257, 0.1173792862391565, 0.1378638608730398, 0.418514886405319, 0.4487037321086973, 3.442371846176684, 3.0626748455688357, 0.25552049512043595, 0.3753865178441629, 0.22763849672628567, 0.24684331932803616, 0.1314733608160168, 0.18324068456422538, 0.20545144274365157, 0.16771737457020208, 0.21237354318145663, 0.11568177185836248, 0.2698062144918367, 0.6100496649742126, 1.369920065626502, 1.5860896348021924, 0.9026610979344696, 1.9523251452483237, 13.43939434736967, 24.501013085246086, 40.21416932344437, 45.80386698246002, 49.97125916182995, 56.8052114546299, 42.4511206895113, 38.05881477892399, 36.12989008426666, 46.39609560370445, 52.72437483072281, 59.80477809906006, 52.72037364542484, 49.276143461465836, 49.3490007519722, 42.96534709632397, 45.094923824071884, 33.976009860634804, 29.99741245061159, 19.484320878982544, 16.74058310687542, 18.506722636520863, 22.19312522560358, 36.76533758640289, 45.72443224489689, 61.014150604605675, 78.67303803563118, 91.88341677188873, 102.77591988444328, 82.92518466711044, 69.28086161613464, 69.73095506429672, 88.84763807058334, 85.33257588744164, 35.93804217875004, 0.8890134771354496, 0.08941718784626573, 0.09601338155334815, 0.30527164111845195, 0.34340146696195006, 0.2887996140634641, 0.33920346410013735, 0.3268831892637536, 0.31848050421103835, 0.27404369961004704, 0.29109163326211274, 0.151787412178237, 0.13243617868283764, 0.12965756293851882, 0.32112314365804195, 0.12005265802145004, 0.08035228442167863, 0.15467672667000443, 0.1439557652338408, 0.10297636690665968, 0.17062518338207155, 0.13017161894822493, 0.27019524830393493, 0.0793382286792621, 0.17902835825225338, 0.1557899036561139, 0.10476593728526495, 0.10067881870782003, 0.11526014292030595, 0.1886161047150381, 0.08228410966694355, 0.28078519098926336, 0.12044016300933436], [0.07537484838394448, 0.07905842416221276, 0.1424372271867469, 0.09883473758236505, 0.014609443260269472, 0.07180793822044507, 0.03992548554379027, 0.01934693646035157, 0.08760206532315351, 0.022805179505667184, 0.03246787360694725, 0.06681573344394565, 0.02872845492674969, 0.07270410380442627, 0.10915505059529096, 0.06123624865722377, 0.07160563618526794, 0.07312643036129884, 0.07190058793639764, 0.08132101720548235, 0.044291837184573524, 0.14587430603569373, 0.0449027063586982, 0.14272483909735456, 0.07926629230496474, 0.05491136558703147, 0.08586598894908093, 0.13842771499184892, 0.36436238908208907, 0.1860184097313322, 0.12291069841012359, 0.08302445392473601, 0.11185718060005456, 0.12451965973014012, 0.14332770049804822, 0.14089179370785132, 1.5144797461107373, 16.328153237700462, 92.90766701102257, 94.6589170396328, 76.82061463594437, 73.33736434578896, 79.55449193716049, 120.78516751527786, 114.87164363265038, 85.21176517009735, 64.18155804276466, 36.758015379309654, 28.261266611516476, 25.08729312568903, 5.935532301664352, 4.231140408664942, 2.199291349388659, 3.807349386624992, 4.385224040597677, 3.246270543895662, 9.457647856324911, 15.993816778063774, 25.064925625920296, 29.052230268716812, 24.07026629894972, 31.32452543824911, 37.15741194784641, 35.55802837014198, 32.21115656197071, 41.671109944581985, 32.7270282804966, 27.582520432770252, 30.136296898126602, 26.15580338984728, 19.45950821042061, 24.151239953935146, 23.01557209342718, 15.846641175448895, 12.083923481404781, 0.8079002983868122, 1.0720685357227921, 0.3878088528290391, 0.6673779606353492, 0.9399895230308175, 0.6765293539501727, 0.14489983645034954, 0.11557671343325637, 0.023561034649901558, 0.13972596876556054, 0.026797219688887708, 0.033386318464181386, 0.03904543940734584, 0.31462777813430876, 0.12872536608483642, 1.267988160252571, 1.64698694832623, 0.1717133796773851, 0.05346067096979823, 0.022104861127445474, 0.11847219517221674, 0.07874468865338713, 0.03070562168431934, 0.05032548666349612, 0.12310944555792958, 0.10564594631432556, 0.14991120347985998, 0.037344269949244335, 0.030587417968490627, 0.4685364116448909, 0.3975115728098899, 0.355552354012616, 2.071023532189429, 8.915245961397886, 30.819980911910534, 37.886760011315346, 23.742328695952892, 33.50424997508526, 31.90676249563694, 18.573980927467346, 9.670126754790545, 9.32374969124794, 15.37250641733408, 14.824412427842617, 30.871409252285957, 40.86374066770077, 32.39226244390011, 21.713811345398426, 20.626182407140732, 22.479379065334797, 15.141652654856443, 8.503700494766235, 17.26040281355381, 19.397592432796955, 22.032771930098534, 33.77546802163124, 44.591656029224396, 62.564030438661575, 83.57757925987244, 78.8084551692009, 69.72247391939163, 47.50946246087551, 40.61772666871548, 58.285509422421455, 73.15086275339127, 47.1451760083437, 11.473221201449633, 0.0991451927984599, 0.11322950813337229, 0.26481826964300126, 0.30956576694734395, 0.209394903795328, 0.015320558959501795, 0.17947366170119494, 0.12907944474136457, 0.12756372685544193, 0.05374571876018308, 0.06398973157047294, 0.0952962516748812, 0.11182017711689696, 0.15194998704828322, 0.07305551072931848, 0.027324346774548758, 0.03138554769975599, 0.0948723146575503, 0.04337482096161693, 0.03458457154920325, 0.014746166343684308, 0.02033862387179397, 0.09580687154084444, 0.07979241563589312, 0.049000775325112045, 0.09817393671255559, 0.02247631531645311, 0.01767109650245402, 0.23560200846986845, 0.27417675184551626, 0.11771679273806512, 0.10336294420994818, 0.05983653958537616, 0.053238987748045474, 0.11594810639508069, 0.055712747780489735, 0.07406182587146759, 0.009153325681836577, 0.019745549543586094, 0.026095487519341987, 0.05646987570798956, 0.03970244048105087, 0.06321977562038228, 0.09200179134495556, 0.025697772434796207, 0.11318037053570151, 0.10041171233751811, 0.10731177841080353, 0.07221580774057657, 0.03403310016437899, 0.05787817142845597, 0.015690799737058114, 0.030596780161431525, 0.06531587525387295, 0.04987177839211654, 0.02390286415902665, 0.14309393882285804, 0.12160095619037747, 0.039694410443189554, 0.018710344447754323, 0.05825564257975202, 0.1206689968239516, 0.21882697736145929, 0.23778980044880882, 0.11042327707400545, 0.06960853905184194, 0.08786894162767567, 0.1127692949376069, 0.136827822716441, 0.35060187277849764, 4.5432718098163605, 47.30224438011646, 110.33001333475113, 96.92564740777016, 80.63775300979614, 98.11914816498756, 113.08507069945335, 114.78288039565086, 93.27870950102806, 75.47530442476273, 63.600907400250435, 52.12002485990524, 49.85626593232155, 37.608675733208656, 21.07971277087927, 20.14874942600727, 20.890874303877354, 19.221374988555908, 16.041287630796432, 17.219596803188324, 23.377909250557423, 28.40951945632696, 39.27638344466686, 48.647702783346176, 41.7255724221468, 46.61326915025711, 41.23631827533245, 32.183547243475914, 24.87882301211357, 27.005937471985817, 35.31465522944927, 30.483626760542393, 29.685578383505344, 31.333369463682175, 38.678128346800804, 47.04994931817055, 37.4383232742548, 18.7907649949193, 9.528039079159498, 0.5089869035873562, 0.5542105331551284, 0.171367434959393, 1.0840057139284909, 0.25919952895492315, 0.15677241812227294, 0.10858467299840413, 0.1437880250159651, 0.05388945050071925, 0.08175478767952882, 0.06381519327987917, 0.011260071423748741, 0.18662238435354084, 0.12935648846905679, 0.06619487496209331, 3.0395364621654153, 0.5001973221078515, 0.12292178609641269, 0.032254754769383, 0.05995982886815909, 0.2037686822586693, 0.045556341792689636, 0.07882385354605503, 0.07222996049677022, 0.05974457635602448, 0.12743799219606444, 0.11845709246699698, 0.048416723657283, 0.361419387627393, 0.8843755291309208, 0.5614344798959792, 0.20615606743376702, 2.5292169582098722, 9.15922136977315, 20.76281927525997, 34.24231097102165, 30.50232745707035, 37.45767183601856, 38.41025032103062, 24.59292445331812, 10.7183195091784, 11.4913728274405, 19.8311909660697, 25.85690762847662, 35.64500950276852, 43.59013617038727, 38.230702355504036, 38.77985268831253, 38.61362300813198, 39.4651535153389, 36.123194843530655, 33.41180473566055, 36.63332127034664, 35.81205613911152, 35.283838883042336, 44.02729131281376, 47.30649635195732, 54.37021091580391, 78.00651580095291, 87.0207417011261, 84.99796584248543, 68.90201434493065, 56.89849264919758, 58.90637710690498, 71.7923292517662, 64.43150863051414, 27.440206669270992, 0.3139734116848558, 0.05198064296564553, 0.07914401605376042, 0.21313486795406789, 0.14809899759711698, 0.19672760070534423, 0.11744086223188788, 0.2460869966307655, 0.18491142225684598, 0.1122811992536299, 0.12849994614953175, 0.06797069334425032, 0.11572701318073086, 0.10276026092469692, 0.02257875952636823, 0.031267813392332755, 0.039184120832942426, 0.05232494753727224, 0.06657918129349127, 0.02812985716445837, 0.04156396578764543, 0.058591876295395195, 0.0386960511241341, 0.05209060327615589, 0.11474833561806008, 0.13684673263924196, 0.12584681273438036, 0.01746159377944423, 0.0972684274893254, 0.06305449933279306, 0.054704751673853025, 0.07386342011159286, 0.09808895338210277, 0.004856651039517601, 0.1856900835991837, 0.20370058278786018, 0.21006176801165566, 0.15103030280442908, 0.24429905897704884, 0.10313166872947477, 0.09756987303262576, 0.11383595410734415, 0.152044759306591, 0.1958345595630817, 0.09218634862918407, 0.17848124698502943, 0.14018048968864605, 0.14712905511260033, 0.21027636743383482, 0.22190607385709882, 0.1665822003269568, 0.19837522791931406, 0.21245822223136202, 0.2055164400371723, 0.18714133853791282, 0.25002486188896, 0.24617612856673077, 0.20194690267089754, 0.1437196138431318, 0.09047508225194179, 0.14523200690746307, 0.28813031560275704, 0.298245016601868, 0.22386593744158745, 0.2206329195178114, 0.15351968875620514, 0.20284510916098952, 0.20931090752128512, 0.3278636554023251, 0.29312778962776065, 1.5644442150369287, 24.64222300797701, 124.37526047229767, 118.40366050601006, 98.63004595041275, 99.04334977269173, 111.2892110645771, 147.16661989688873, 139.5449736714363, 112.34211176633835, 105.46586394309998, 80.17181441187859, 66.31673946976662, 58.015723899006844, 30.97566805779934, 16.663808226585388, 13.748008087277412, 12.053136583417654, 9.216281957924366, 11.627926100045443, 19.6713088452816, 30.126860104501247, 43.10451082885265, 53.63895535469055, 46.88685066998005, 54.525770768523216, 57.32048660516739, 54.72836069762707, 46.213462203741074, 49.124558195471764, 46.96864128112793, 38.26435714960098, 59.6850161254406, 34.066084027290344, 36.85655929148197, 47.81276598572731, 41.16679720580578, 29.112455137073994, 16.075470596551895, 1.953072042670101, 1.638153016101569, 1.6099290805868804, 2.0068008033558726, 1.308750829193741, 0.7827615598216653, 0.2243527863174677, 0.44221902382560074, 0.14587357873097062, 0.1746783487033099, 0.12465076753869653, 0.08122819679556414, 0.46204683487303555, 0.6954933051019907, 0.17862454085843638, 5.931801376864314, 2.729540071450174, 0.165913243254181, 0.2783475327305496, 0.09912561494274996, 0.2948272187495604, 0.21075485972687602, 0.1668821764178574, 0.17688401159830391, 0.23261584370629862, 0.3822572319768369, 0.4058390931459144, 0.24239116057287902, 0.6921889667864889, 1.3273730361834168, 0.7390067889355123, 0.8804056327790022, 3.711340888403356, 15.085943844169378, 39.39899906516075, 53.18188928067684, 33.719706013798714, 51.64825737476349, 66.21603727340698, 55.48179566860199, 42.64764614403248, 43.89219716191292, 56.624633744359016, 56.17543324828148, 60.23452743887901, 54.7098632901907, 44.81865204870701, 41.81373529136181, 36.0415980219841, 33.982271924614906, 30.86202945560217, 26.720407493412495, 36.688532307744026, 38.449300825595856, 46.152958050370216, 62.59894296526909, 67.28150770068169, 79.50091481208801, 103.73734429478645, 102.33883693814278, 93.17182123661041, 67.04366326332092, 63.73678430914879, 78.55820059776306, 90.19902035593987, 64.76516872644424, 17.239251248538494, 0.17339562065899372, 0.2866637130500749, 0.2752277220133692, 0.2828259189845994, 0.2952880330849439, 0.41079364134930074, 0.4759263026062399, 0.39556860050652176, 0.26325631595682353, 0.35746157343965024, 0.24428409727988765, 0.16146071342518553, 0.25232937885448337, 0.2104907887405716, 0.1275538859772496, 0.12960904132341966, 0.12883756397059187, 0.2701662451727316, 0.14274570829002187, 0.21582972491160035, 0.34116430731955916, 0.1304354821331799, 0.15850018244236708, 0.16012863256037235, 0.14405141322640702, 0.21644251624820754, 0.304189560119994, 0.09185393326333724, 0.26618373231031, 0.30171230086125433, 0.17753410327713937, 0.25178327690809965, 0.17173899861518294, 0.06881750610773452], [0.12172534014098346, 0.051092381254420616, 0.11552419164218009, 0.010621759483910864, 0.06674502161331475, 0.04987714783055708, 0.0690213889174629, 0.07058344650431536, 0.07782975415466353, 0.034424252808094025, 0.04280309636669699, 0.03343370459333528, 0.08555059845093638, 0.06334505014820024, 0.03506832195853349, 0.12049511904479004, 0.12087274604709819, 0.11404575925553218, 0.06630193718592636, 0.10042495225206949, 0.18113429134245962, 0.1264355584862642, 0.07697840686887503, 0.0796479640121106, 0.10181964069488458, 0.1295402887626551, 0.15392182889627293, 0.0984462900669314, 0.06669777649221942, 0.29172038077376783, 0.2684355864766985, 0.36940727150067687, 0.06446793442592025, 0.07451239114743657, 0.08025253235246055, 0.21636790072079748, 0.22970701073063537, 0.5962073639966547, 9.552838448435068, 64.58695828914642, 107.09108993411064, 82.20006957650185, 76.08830273151398, 79.05657425522804, 88.21532160043716, 113.75847816467285, 105.09601458907127, 91.08758747577667, 71.14951014518738, 53.46081331372261, 43.201162442564964, 19.86267987638712, 17.201502174139023, 17.882391437888145, 17.951488830149174, 4.595290068536997, 2.5932311732321978, 4.822355909273028, 7.431861134245992, 13.233149964362383, 10.504743419587612, 10.396963153034449, 19.51887432485819, 18.847123570740223, 23.334306590259075, 38.83252926170826, 40.01280292868614, 44.3416940420866, 49.63216535747051, 28.502230681478977, 21.540059968829155, 26.264181174337864, 32.2344721108675, 17.300931438803673, 6.338894432410598, 2.1446198830381036, 0.3393873682944104, 0.10682899650419131, 0.5068004177883267, 0.8969599788542837, 0.3245884389616549, 0.17522189766168594, 0.27632476470898837, 0.12588160461746156, 0.06875684295664541, 0.06991882357397117, 0.13097291579470038, 0.4640694544650614, 0.10408071233541705, 0.1389790713437833, 1.598503093700856, 0.2726280380738899, 0.16909226251300424, 0.21597295941319317, 0.13504798931535333, 0.14743633393663913, 0.21079981903312728, 0.025993479321186896, 0.05282096564769745, 0.011035885308956495, 0.09492111828876659, 0.16374697355786338, 0.4358549293829128, 1.0892482451163232, 0.7587861525826156, 0.41716705716680735, 1.0539665445685387, 2.1889920020475984, 11.388443000614643, 24.995396956801414, 29.531872831285, 27.37777791917324, 24.863179251551628, 29.303032010793686, 25.452808812260628, 11.265687737613916, 17.579295001924038, 19.355644583702087, 22.330617047846317, 35.67794233560562, 50.17422907054424, 46.065292954444885, 26.151160039007664, 26.290335170924664, 25.82244537770748, 27.67614170908928, 27.19528131186962, 35.66570699214935, 43.16616632044315, 54.32259187102318, 60.40973603725433, 66.91139236092567, 75.02708807587624, 63.84410575032234, 52.26820170879364, 39.727012664079666, 56.17130666971207, 58.91682654619217, 58.644346967339516, 29.633177295327187, 4.632978346198797, 0.26944846962578595, 0.3906671010190621, 0.40421147423330694, 0.2120904583716765, 0.48725560249295086, 0.3893178468570113, 0.27495606627780944, 0.08186734921764582, 0.18201818922534585, 0.16526047984370962, 0.0767290526709985, 0.09695492204627953, 0.11724705036613159, 0.0468417712545488, 0.03418623120523989, 0.0420547703106422, 0.05923763383179903, 0.014112631051830249, 0.09976308268960565, 0.038740041927667335, 0.09321369623648934, 0.02884558623918565, 0.07443584603606723, 0.1333338805125095, 0.144662304664962, 0.11957138267462142, 0.028839673177571967, 0.031190867521218024, 0.039961049260455184, 0.18933938699774444, 0.017397047340637073, 0.09924705256707966, 0.12551864987472072, 0.10241096169920638, 0.11367141996743158, 0.05622176089673303, 0.020360470844025258, 0.09962367767002434, 0.09465481343795545, 0.06214064465893898, 0.08448373147984967, 0.09135491316555999, 0.09725957366754301, 0.11510753509355709, 0.06803929005400278, 0.10339212545659393, 0.04803639523743186, 0.021341762621887028, 0.011813256242021453, 0.039381398528348655, 0.08909922209568322, 0.1391622333903797, 0.10303156785084866, 0.10901915593422018, 0.0893589440966025, 0.11476564992335625, 0.18269122811034322, 0.050189558605779894, 0.1437430508667603, 0.037878007715335116, 0.07468534866347909, 0.034903732157545164, 0.03305718339106534, 0.044350949247018434, 0.14697523758513853, 0.11906692263437435, 0.12963298300746828, 0.059408524466562085, 0.04980798708857037, 0.043983600990031846, 0.0848419958492741, 0.7345718331634998, 2.7732510259374976, 35.20482212305069, 94.34425592422485, 107.50578448176384, 86.28355085849762, 89.67293098568916, 121.23269230127335, 120.36234900355339, 112.53919959068298, 97.48629212379456, 81.87891080975533, 80.50322502851486, 77.71133244037628, 61.27973735332489, 35.09856082499027, 34.63969744741917, 36.736576929688454, 33.85945871472359, 20.45324418693781, 17.037903852760792, 19.134979024529457, 24.54064305871725, 32.31511518359184, 31.854038424789906, 29.938240125775337, 39.578463435173035, 38.53194259107113, 38.98201324045658, 43.95271651446819, 37.33347550034523, 32.75166995823383, 40.897885635495186, 32.006590738892555, 31.03829249739647, 37.17302531003952, 37.423580065369606, 26.35513499379158, 14.179827366024256, 1.61771759390831, 0.3178552002646029, 0.661760080838576, 1.0881707654334605, 0.8127854706253856, 0.5387765332125127, 0.1786246002302505, 0.17787575838156044, 0.03306369573692791, 0.03654312153230421, 0.05805854299978819, 0.1256141345947981, 0.07174650323577225, 0.19102097488939762, 0.06462821605964564, 1.3601767946965992, 0.11956620990531519, 0.10237871538265608, 0.11495342070702463, 0.05435571962152608, 0.1378362678224221, 0.05337944290658925, 0.0316354362439597, 0.06518191759823821, 0.053174220520304516, 0.09961787407519296, 0.032626485408400185, 0.07542435705545358, 0.2847137348726392, 0.7847064023371786, 0.47936770075466484, 0.34216184285469353, 2.1898151328787208, 9.47707336395979, 29.453201852738857, 44.438683837652206, 28.668553456664085, 34.61487337946892, 43.343647196888924, 37.039530873298645, 27.4753300845623, 31.501861922442913, 34.61888216435909, 41.39655187726021, 57.33338691294193, 54.66739296913147, 46.27827152609825, 36.230846866965294, 36.35142579674721, 38.222863376140594, 44.26517374813557, 39.25457261502743, 51.80369183421135, 53.53604547679424, 55.0313488394022, 60.92225253582001, 71.7996172606945, 81.99241831898689, 75.57349115610123, 72.14085415005684, 60.3565426915884, 53.683754950761795, 65.84480479359627, 71.85147687792778, 47.56305478513241, 13.268035892397165, 0.7540639559738338, 0.12577675399370492, 0.21689991670427844, 0.23127705382648855, 0.2563162852311507, 0.4300608637277037, 0.6058598554227501, 0.38485949859023094, 0.2071000199066475, 0.10973488315357827, 0.11565824577701278, 0.11838281832751818, 0.06692729308269918, 0.02534577921323944, 0.06952383773750626, 0.04992683832824696, 0.036260303895687684, 0.06182428936881479, 0.08125620544888079, 0.03168728268065024, 0.013229349151515635, 0.05817573553940747, 0.0012821655195693893, 0.06604908747249283, 0.06438759693992324, 0.048161988888750784, 0.0300652651276323, 0.04154506699705962, 0.11415181215852499, 0.023627373375347815, 0.05974101775791496, 0.055821145870140754, 0.11119723320007324, 0.09192514233291149, 0.062010765104787424, 0.1086356288578827, 0.15328055393183604, 0.2158695930847898, 0.1833959567011334, 0.21416013012640178, 0.10197291645454243, 0.21425855375127867, 0.15984191122697666, 0.25551779370289296, 0.08975639386335388, 0.21323436027159914, 0.15618534962413833, 0.12768575077643618, 0.2295714055071585, 0.18619498150656, 0.2567525493213907, 0.3695095394505188, 0.3879419347504154, 0.18862843920942396, 0.19276151899248362, 0.25097320787608624, 0.25765313068404794, 0.15060781297506765, 0.31190035573672503, 0.2182056661695242, 0.1880112840444781, 0.3729260608088225, 0.1920142356539145, 0.14295239641796798, 0.2290235520922579, 0.23348139569861814, 0.2802539319964126, 0.10713029361795634, 0.17829134623752907, 0.12832436885219067, 0.42350603733211756, 0.5735256092157215, 0.7296369667164981, 14.778257254511118, 90.56386917829514, 132.81091421842575, 103.90303060412407, 98.80495816469193, 119.28253814578056, 129.2779701948166, 142.77328044176102, 127.9068973660469, 110.10717809200287, 104.62787970900536, 92.11770460009575, 74.40263718366623, 46.22292369604111, 45.73832809925079, 44.05141621828079, 42.61882849037647, 21.829627230763435, 16.019535697996616, 18.646587431430817, 22.933741584420204, 31.696295589208603, 28.908846862614155, 27.15008083730936, 37.61475920677185, 37.47547768056393, 40.7842793315649, 51.984778717160225, 49.546673744916916, 58.34007069468498, 69.32873904705048, 48.94894681870937, 36.07227377593517, 45.53540378808975, 54.21738691627979, 37.90029488503933, 17.69765105098486, 2.9804482078179717, 0.4353291622828692, 1.0581617569550872, 2.0093877520412207, 3.32090400159359, 1.3070527953095734, 0.21295133483363315, 0.3988607379142195, 0.20606837526429445, 0.2473813615506515, 0.20951424114173278, 0.36676448362413794, 0.6675493670627475, 0.7383826130535454, 0.3596715407911688, 4.429714428260922, 0.45181223249528557, 0.2786784415366128, 0.3448364243377, 0.3550577868008986, 0.4113669355865568, 0.24930518644396216, 0.2625516912667081, 0.20948097808286548, 0.2836024429416284, 0.22415089246351272, 0.24805732449749485, 0.346384514705278, 1.14808191312477, 1.9475770625285804, 1.1686785891652107, 1.0431262012571096, 4.623765265569091, 17.183884419500828, 35.55520512163639, 47.124755904078484, 45.283587500452995, 40.52894443273544, 47.03765697777271, 55.34944497048855, 45.28554819524288, 44.39546875655651, 49.91726025938988, 50.96664234995842, 67.23672330379486, 70.00835537910461, 62.18354545533657, 47.556036561727524, 52.16327793896198, 47.94307239353657, 50.227114632725716, 45.585409104824066, 61.65326490998268, 68.17984029650688, 80.14411389827728, 85.76444551348686, 95.27986451983452, 97.03578069806099, 79.91845920681953, 71.71690329909325, 63.534517362713814, 75.93642488121986, 83.44881936907768, 79.61463510990143, 41.7397266626358, 6.429582266137004, 0.2827217214507982, 0.20547796710161492, 0.5060459207743406, 0.3019802161725238, 0.5438565637450665, 0.5459237715695053, 0.6802020943723619, 0.6719935848377645, 0.38043134089093655, 0.3766992286546156, 0.44787926541175693, 0.2932690648594871, 0.21122848353115842, 0.12071716962964274, 0.11005358363036066, 0.174104000616353, 0.10010789934312925, 0.13194837985793129, 0.18887977494159713, 0.1495699046063237, 0.09225179121131077, 0.1171464151411783, 0.22670716076390818, 0.1705439478973858, 0.225928068975918, 0.19227122655138373, 0.2201836826861836, 0.10028466407675296, 0.15959314332576469, 0.43334602494724095, 0.18188405345426872, 0.25311748031526804, 0.14366568939294666, 0.11155243992106989, 0.1447373061091639], [0.06877553023514338, 0.031477852317038924, 0.08258938469225541, 0.06966342829400674, 0.07456814870238304, 0.11934323163586669, 0.11176738815265708, 0.09502873712335713, 0.02160460349841742, 0.07782609536661766, 0.06331204684101976, 0.06944558568648063, 0.012994822136533912, 0.12153699790360406, 0.14872363361064345, 0.07402909715892747, 0.033730485738487914, 0.11974468157859519, 0.19308738119434565, 0.17559849307872355, 0.2533445181325078, 0.16561163443839177, 0.05530110443942249, 0.10771848275908269, 0.06932958058314398, 0.045459313405444846, 0.06380012768204324, 0.055312930562649854, 0.13474188308464363, 0.21305422618752345, 0.3672725282376632, 0.39850539760664105, 0.5554547882638872, 0.15577313111862168, 0.17724307748721913, 0.07752080549835227, 0.08577114989748225, 0.1988859145785682, 0.34453529049642384, 2.582449964247644, 46.83282896876335, 93.25898855924606, 91.75723314285278, 70.92792123556137, 58.28476086258888, 62.92228661477566, 90.5929908156395, 110.59340000152588, 112.91065245866776, 107.88171350955963, 76.50708585977554, 51.670087203383446, 46.73293612897396, 42.22239576280117, 36.898949816823006, 26.49494469165802, 25.146919526159763, 29.70648866146803, 30.526750646531582, 28.600485809147358, 27.69928626716137, 31.49979293346405, 35.561091005802155, 33.91757279634476, 45.19911043345928, 55.54283559322357, 64.4773417711258, 54.757736921310425, 50.705634355545044, 45.48249542713165, 46.60426743328571, 33.097337409853935, 17.13469795882702, 16.862089186906815, 9.224111437797546, 4.328714897856116, 2.9657733952626586, 1.9852921762503684, 0.29737919743638486, 0.22921769792446867, 0.15167001925874501, 0.07852252674638294, 0.2797613834263757, 0.16758087876951322, 0.15599065460264683, 0.1575154415331781, 0.24150741111952811, 0.647669427562505, 0.46618276450317353, 0.13950471970019862, 2.110573947429657, 0.07851841524825431, 0.18158928724005818, 0.1468599375220947, 0.2318229479715228, 0.1131051464471966, 0.14013619831530377, 0.038291458185995, 0.2038437282317318, 0.17002536478685215, 0.47258548031095415, 1.326681354548782, 2.3259129049256444, 2.0559397665783763, 3.812245661392808, 1.778179183602333, 4.209631662815809, 5.562281655147672, 16.857252046465874, 18.85814107954502, 13.229989483952522, 20.86936555802822, 35.201687291264534, 58.85035291314125, 61.231719329953194, 58.29842492938042, 64.15780171751976, 62.13737793266773, 56.17160305380821, 57.64913856983185, 63.96015152335167, 59.890577495098114, 45.440230295062065, 35.73039852082729, 49.22220155596733, 64.30749848484993, 70.25286465883255, 74.93738248944283, 70.19893795251846, 72.43169814348221, 72.95401811599731, 56.76317051053047, 54.1171482950449, 47.72484250366688, 48.72266136109829, 62.183446660637856, 48.75276334583759, 40.75557567179203, 15.708587933331728, 0.5128722544759512, 0.12308140721870586, 1.2457385729067028, 1.376921427436173, 1.1287405947223306, 0.8476827386766672, 0.3295698529109359, 0.5056886211968958, 0.2286193339386955, 0.10102735352120362, 0.26223191467579454, 0.13573158154031262, 0.07528716363594867, 0.0875319101032801, 0.16193614806979895, 0.12974084675079212, 0.11001899954862893, 0.02980704597575823, 0.11352992951287888, 0.16076594445621595, 0.22689161414746195, 0.08455131886876188, 0.04544224029814359, 0.04693638395110611, 0.05933671425736975, 0.0983444599842187, 0.075621946452884, 0.11485356473713182, 0.06694188370602205, 0.06090795221098233, 0.04859403758018743, 0.07085533230565488, 0.05051352833106648, 0.025146842817775905, 0.12386534523102455, 0.06452036715927534, 0.1326086834887974, 0.09337744369986467, 0.08773588197072968, 0.025001984868140426, 0.11885954430908896, 0.16842530923895538, 0.04234436746628489, 0.07254032665514387, 0.10790435364469886, 0.043933383567491546, 0.04842640497372486, 0.04911400479613803, 0.07689559803111479, 0.016820530327095184, 0.03442442350205965, 0.009728895529406145, 0.16299277340294793, 0.1201755650981795, 0.19831144774798304, 0.1584506663493812, 0.14560886949766427, 0.1372406497830525, 0.1282371219713241, 0.06906585840624757, 0.1261392337619327, 0.08528681690222584, 0.07794759978423826, 0.11379831237718463, 0.018846702951123007, 0.09071975349797867, 0.10859646572498605, 0.2278180667781271, 0.17925031977938488, 0.1415337811340578, 0.04166592574620154, 0.22489660244900733, 0.08170061832061037, 0.1355942990630865, 0.40001875546295196, 1.3454358419403434, 19.595155231654644, 87.54675507545471, 112.40223973989487, 101.7258158326149, 88.53928461670876, 93.39372172951698, 108.91382932662964, 118.17099899053574, 110.54610013961792, 94.91168707609177, 85.68992391228676, 72.65391021966934, 64.67650428414345, 59.34467598795891, 54.51661325991154, 49.93463292717934, 43.167154267430305, 40.004359781742096, 44.50430631637573, 44.203062281012535, 43.02563086152077, 43.59528869390488, 43.13721187412739, 43.63449119031429, 38.51945646107197, 45.55589608848095, 51.92264445126057, 56.737704277038574, 56.704904437065125, 56.50911994278431, 48.3509387075901, 44.095786437392235, 41.829785630106926, 44.98262085020542, 34.110059067606926, 14.489405304193497, 3.973352503962815, 1.7089780094102025, 1.144567932933569, 0.4446300835115835, 0.916700572706759, 0.1662574810325168, 0.16711856529582292, 0.2684430673252791, 0.1051818962150719, 0.12005333337583579, 0.10158989403862506, 0.14624923904193565, 0.9878863685298711, 0.17227055446710438, 0.0844144965230953, 1.7915763147175312, 0.09152663129498251, 0.18612628831760958, 0.20170502190012485, 0.11369738771463744, 0.08814976288704202, 0.24993696191813797, 0.02503981584595749, 0.1272102864459157, 0.07602188983582892, 0.03299689502455294, 0.11005295280483551, 1.3275158847682178, 0.9346355509478599, 1.1826859437860548, 1.3739346689544618, 1.9519875571131706, 4.840640053153038, 14.888425692915916, 28.64859312772751, 32.50652231276035, 37.96737268567085, 37.556246146559715, 48.952685818076134, 55.15074983239174, 49.64481107890606, 47.27488584816456, 53.238608837127686, 56.08825072646141, 63.609369546175, 71.16458773612976, 66.6547541320324, 58.00597742199898, 62.40353465080261, 60.459448769688606, 61.80549994111061, 70.24502947926521, 74.34006974101067, 73.25333565473557, 74.3861536681652, 76.97689265012741, 70.97946926951408, 72.34579235315323, 59.931626692414284, 57.09716118872166, 67.33244776725769, 72.03702852129936, 55.604297295212746, 26.285952106118202, 3.3831107011064887, 0.2796458458760753, 0.569581420859322, 0.5581087083555758, 0.5248557426966727, 0.581485410220921, 0.730089379940182, 0.7636374235153198, 0.4912972199963406, 0.24808025686070323, 0.24932955857366323, 0.09170858364086598, 0.17102472600527108, 0.10757976793684065, 0.22437355160946026, 0.15534157224465162, 0.09019004559377208, 0.10394384546088986, 0.13617449527373537, 0.08316374762216583, 0.08383496082387865, 0.01524711973615922, 0.07135306848795153, 0.03645162214525044, 0.01426758313755272, 0.04614715071511455, 0.05638150076265447, 0.0228061053348938, 0.028992412735533435, 0.06458206931711175, 0.02774228352791397, 0.033503611193737015, 0.07656615867745131, 0.07097492198226973, 0.04172860011749435, 0.0477051598863909, 0.15725669916719198, 0.23982033133506775, 0.23036361846607178, 0.1769934338517487, 0.24405452131759375, 0.28181532165035605, 0.2624940709210932, 0.1962052474846132, 0.16962246765615419, 0.09930016807629727, 0.10983803425915539, 0.11602542334003374, 0.25929024908691645, 0.1082263641001191, 0.1644715917063877, 0.36836036830209196, 0.2867356420028955, 0.3990991454338655, 0.2816627064021304, 0.36102509940974414, 0.21482631156686693, 0.2849381306441501, 0.32162079820409417, 0.20342227740911767, 0.21636252757161856, 0.3266379242995754, 0.15144050266826525, 0.2039507607696578, 0.20192595926346257, 0.2731547551229596, 0.15735654771560803, 0.3788220084970817, 0.312071138760075, 0.6362271134275943, 0.287050906335935, 0.2539427485316992, 0.23101271566702053, 0.8716696640476584, 0.3581341670360416, 0.3991599124856293, 7.517973063513637, 71.21782287955284, 125.22519126534462, 121.22206047177315, 95.39705023169518, 89.52617526054382, 101.20763003826141, 120.9354418516159, 134.14246916770935, 135.64095675945282, 132.51372456550598, 98.57013076543808, 78.45034718513489, 69.24623027443886, 54.9314484000206, 51.69956982135773, 47.03187748789787, 42.361498698592186, 49.15360763669014, 47.71094664931297, 51.195363476872444, 51.051848977804184, 56.13626874983311, 59.94531735777855, 62.173354402184486, 71.42831638455391, 76.59975528717041, 82.93802797794342, 77.51084759831429, 69.54061567783356, 65.70792093873024, 67.41035878658295, 53.485736176371574, 41.372582763433456, 38.60963702201843, 22.02906522899866, 8.169870357960463, 5.451743686571717, 4.304430400952697, 1.8622280610725284, 0.9019137849099934, 0.34068333625327796, 0.21287547249812633, 0.36581025982741266, 0.36711305554490536, 0.3777171880938113, 0.33550293766893446, 0.28327963838819414, 1.0235579637810588, 1.0576527030207217, 0.30984775337856263, 4.206906734034419, 0.28209573472850025, 0.4857270751381293, 0.38670527923386544, 0.3301443939562887, 0.1643236371455714, 0.3863146126968786, 0.10823491364135407, 0.582425087923184, 0.3417612612247467, 0.45188689255155623, 1.3673151866532862, 2.6006668992340565, 3.5246960911899805, 8.044422939419746, 3.8442679680883884, 5.553656117990613, 11.011866107583046, 24.678955636918545, 35.10646440088749, 39.99838650226593, 62.792686969041824, 62.880196273326874, 84.30958718061447, 84.5624940097332, 86.51765629649162, 95.03736153244972, 103.63951474428177, 95.5997085571289, 87.40581303834915, 78.57479050755501, 73.74110028147697, 73.2949586212635, 76.19158118963242, 78.57533767819405, 82.71627947688103, 88.22129487991333, 92.01415255665779, 94.83190655708313, 97.51827120780945, 95.9389315545559, 75.69380789995193, 72.40141376852989, 69.94182854890823, 77.8616751730442, 95.939372330904, 85.01333981752396, 57.88874611258507, 19.380295760929585, 1.250526790972799, 0.5892562901135534, 0.9071026439778507, 0.7203459902666509, 0.5221005342900753, 0.7244780310429633, 0.7398813951294869, 0.9041636798065156, 0.6746301089879125, 0.46944144589360803, 0.5867943784687668, 0.36471568106207997, 0.3060120076406747, 0.2295252587646246, 0.2694879815680906, 0.2169234279426746, 0.1693978492403403, 0.18256010545883328, 0.16173766809515655, 0.2219901591888629, 0.3765357186784968, 0.13883577747037634, 0.2011179385590367, 0.11084821599069983, 0.11660901116556488, 0.3164656920125708, 0.15260729240253568, 0.13775117316981778, 0.14293265528976917, 0.07006078158156015, 0.1392555213533342, 0.19853568024700508, 0.25315627979580313, 0.20815784751903266, 0.18861089483834803, 0.13211138517362997, 0.3002055926481262], [0.1773579471046105, 0.08238262234954163, 0.040644637774676085, 0.11204437250853516, 0.14240584918297827, 0.061423102888511494, 0.01704390193481231, 0.022846318606752902, 0.013655424481839873, 0.008154541483236244, 0.053549120129900984, 0.014948056486900896, 0.17874987475806847, 0.18763188330922276, 0.09004039893625304, 0.11122428448288701, 0.05070935883850325, 0.09764882270246744, 0.09239775681635365, 0.1654658024199307, 0.18465759290847927, 0.06053238837921526, 0.1126886012207251, 0.21318563085515052, 0.0876520415476989, 0.21573732752585784, 0.15643721970263869, 0.07071812404319644, 0.06292676087468863, 0.05448428928502835, 0.1420746583607979, 0.3130194847472012, 0.19567165814805776, 0.09876637093839236, 0.12505897844675928, 0.13211922225309536, 0.05293085545417853, 0.5032709415536374, 0.7891622569877654, 0.9961615526117384, 0.8173398824874312, 18.6647105589509, 81.49934157729149, 104.42980393767357, 84.26813140511513, 68.94134983420372, 72.57236659526825, 68.97927179932594, 74.07008662819862, 83.32651153206825, 90.90162545442581, 95.12997776269913, 91.9941808283329, 88.4522008895874, 84.87687394022942, 76.88480839133263, 74.99823242425919, 81.71564877033234, 78.98639962077141, 81.77353486418724, 84.90667954087257, 80.89464202523232, 67.71856024861336, 57.89159595966339, 66.49077013134956, 75.60242280364037, 83.10914039611816, 73.03711205720901, 62.00724631547928, 46.212751641869545, 28.456068858504295, 20.34864339977503, 19.6970334649086, 10.171206817030907, 13.629595041275024, 16.17218490689993, 9.654484894126654, 4.853367945179343, 1.156356087885797, 0.2068959441385232, 1.2375128455460072, 0.36341674451250583, 0.6262816220987588, 0.0962486349453684, 0.16865348996361718, 0.4307304590474814, 0.36458880349528044, 0.2974069834453985, 0.8519149397034198, 0.17192435741890222, 0.5153912224341184, 0.05431917998066638, 0.10614480313961394, 0.07553940478828736, 0.1687014030176215, 0.265184564050287, 0.3967818635283038, 0.31361824949271977, 0.5224502936471254, 0.1368257001740858, 0.2835836517624557, 2.0638051070272923, 1.4501160685904324, 0.48098629515152425, 1.9637462636455894, 3.4803505707532167, 4.334620730951428, 9.333099089562893, 26.203177347779274, 19.353976473212242, 4.461200013756752, 2.5430657900869846, 10.607372112572193, 29.292086698114872, 47.736340686678886, 68.79236742854118, 70.50311163067818, 77.84298777580261, 81.23854637145996, 87.55560100078583, 93.84652823209763, 85.49423441290855, 64.91652220487595, 54.149644151329994, 49.65450815856457, 63.25640648603439, 72.14137852191925, 64.61936295032501, 65.50228357315063, 61.881522461771965, 61.03974223136902, 51.97153262794018, 67.13717624545097, 59.089227095246315, 45.75635813176632, 35.40413282811642, 20.847991704940796, 2.6519819581881166, 0.513311130926013, 0.7705255039036274, 1.1493737250566483, 3.2288356544449925, 2.8224028134718537, 3.0067240353673697, 1.5432165353558958, 0.6382671883329749, 0.06578752494533546, 0.2020992655889131, 0.19804469018708915, 0.24841055710567161, 0.19147230457747355, 0.10764535894850269, 0.1585379577591084, 0.32336517178919166, 0.4150763381039724, 0.09685727767646313, 0.09392899301019497, 0.06044708221452311, 0.0972388157970272, 0.11580781079828739, 0.2431988250464201, 0.008337620965903625, 0.07679531161556952, 0.12494903668994084, 0.06621837135753594, 0.03755542580620386, 0.0652677692414727, 0.12202699348563328, 0.0814180530142039, 0.11623712096479721, 0.08956198827945627, 0.12750686350045726, 0.09663202843512408, 0.10969853276037611, 0.10583531271549873, 0.20713518286356702, 0.029137604651623406, 0.03938218891562428, 0.05454433645354584, 0.08011765443370678, 0.05966584190900903, 0.04026141497888602, 0.07171047196607105, 0.03588523730286397, 0.034920397083624266, 0.03593475339584984, 0.05894794019695837, 0.041140310786431655, 0.10992583775077946, 0.0673876769724302, 0.051967373365187086, 0.08160906698321924, 0.07333098852541298, 0.19359929981874302, 0.19529381592292339, 0.15142594173084944, 0.24785559391602874, 0.115641554875765, 0.13556814577896148, 0.19845022936351597, 0.05254097930446733, 0.1720016446779482, 0.061711100715911016, 0.09250999180949293, 0.035179840779164806, 0.038606325470027514, 0.20813926414120942, 0.2465807623229921, 0.23859553533839062, 0.1360181692871265, 0.03482749132672325, 0.17479890317190439, 0.04945304011926055, 0.22300035576336086, 0.12147249042754993, 1.3350141886621714, 10.891825798898935, 53.58190141618252, 108.77004504203796, 106.04206502437592, 84.26592752337456, 76.88509717583656, 88.9341290295124, 100.13892218470573, 101.1673977971077, 97.83648893237114, 98.94364312291145, 91.64255529642105, 86.53909474611282, 81.99622571468353, 79.35798168182373, 71.5795786678791, 68.68622392416, 70.56758657097816, 79.93178129196167, 85.1583780348301, 96.1627471446991, 95.80150052905083, 89.12231773138046, 76.87249705195427, 72.90497034788132, 66.97716683149338, 68.87818962335587, 67.07407683134079, 73.83411929011345, 70.4490177333355, 62.985370829701424, 54.37024511396885, 38.533105328679085, 29.634718112647533, 19.303777366876602, 10.600656922906637, 5.389610370621085, 4.200568674132228, 0.48838699178304523, 0.23991450987523422, 1.013203163165599, 0.2449094012263231, 0.5639130750205368, 0.15474973915843293, 0.020551859597617295, 0.2556103840470314, 0.17193315929034725, 0.5007360619492829, 0.6432515115011483, 0.3721039096126333, 1.1460911761969328, 0.13297371624503285, 0.017153142362076323, 0.09242381362128071, 0.06968063869862817, 0.15123804478207603, 0.1554980911896564, 0.40182947705034167, 0.12245692705619149, 0.15559036983177066, 0.43855990923475474, 0.8771023037843406, 1.3426694716326892, 2.172816270031035, 2.894360264763236, 1.0110476100817323, 8.596872445195913, 13.988425936549902, 29.501257874071598, 29.296617954969406, 31.34001150727272, 34.18621838092804, 40.663396418094635, 64.94974762201309, 74.01662349700928, 73.31498354673386, 82.00406089425087, 88.01977649331093, 92.95531645417213, 89.760432690382, 83.30232962965965, 68.93407702445984, 60.162730291485786, 56.705641597509384, 65.22131145000458, 77.4188469350338, 84.48121637105942, 75.01557469367981, 74.16588708758354, 79.12766084074974, 78.71646210551262, 66.95325091481209, 69.28060322999954, 73.94118994474411, 71.71456262469292, 64.0255232155323, 35.99782437086105, 12.234837133437395, 2.2666170867159963, 0.636670442763716, 1.5304899495095015, 1.7440991685725749, 1.7942488775588572, 1.449309205636382, 1.2765534943901002, 0.8888548356480896, 0.4556873714318499, 0.30458966677542776, 0.35122302069794387, 0.2107559284195304, 0.15542089298833162, 0.10247431142488495, 0.21224673982942477, 0.20597964408807456, 0.1830054831225425, 0.1389265718171373, 0.04616674341377802, 0.06614225669181906, 0.08532360516255721, 0.1905111491214484, 0.14605053642299026, 0.11808634517365135, 0.08189065265469253, 0.03999169995950069, 0.05457873128762003, 0.08005293173482642, 0.05308147432515398, 0.06330492222332396, 0.04579395892506, 0.11284277497907169, 0.05804621963761747, 0.10613888822263107, 0.10781413075164892, 0.053185682991170324, 0.026836175020434894, 0.04280720415408723, 0.23812986735720187, 0.24468772171530873, 0.3039516572607681, 0.23873896279837936, 0.2191272799973376, 0.11436825210694224, 0.1919271520455368, 0.0649347527360078, 0.09771012410055846, 0.07503012078814209, 0.16131019103340805, 0.09731790647492744, 0.17243964539375156, 0.19394215720240027, 0.1600514492020011, 0.23817791399778798, 0.2179400366730988, 0.26421701128128916, 0.3110776108223945, 0.2660581312375143, 0.4466801031958312, 0.3377479640766978, 0.21517455694265664, 0.3914198465645313, 0.23697800963418558, 0.272409490426071, 0.16851258580572903, 0.17658838449278846, 0.1973891956731677, 0.3333600010955706, 0.21861346147488803, 0.3270643326686695, 0.27795223519206047, 0.39727548079099506, 0.20748357666889206, 0.21858698164578527, 0.2159096096875146, 0.5414521240163594, 0.6672074447851628, 0.8750608039554209, 3.039587759412825, 29.568846747279167, 103.36737334728241, 123.43738719820976, 98.79168927669525, 86.43304243683815, 85.3621307015419, 88.00213024020195, 102.51989722251892, 112.97749847173691, 124.20176938176155, 121.69584944844246, 123.79361808300018, 117.28732600808144, 113.00968274474144, 100.52684336900711, 91.33895918726921, 93.62721160054207, 96.3500314950943, 101.93149879574776, 113.73136281967163, 115.96422180533409, 109.88025426864624, 97.6971124112606, 98.24349269270897, 88.8682633638382, 81.94486767053604, 76.03417843580246, 81.51129573583603, 68.84967595338821, 52.316922694444656, 48.629566356539726, 44.84884902834892, 39.88943874835968, 28.065219931304455, 22.20398124307394, 14.225032590329647, 7.821940127760172, 1.0212386632338166, 0.38557771942578256, 1.5515211084857583, 0.3706219594459981, 0.40307818504516035, 0.2755070070270449, 0.2866825636010617, 0.5893859581556171, 0.4334167664637789, 0.47089121653698385, 1.3549229828640819, 0.7401014270726591, 1.8251367076300085, 0.20166138361673802, 0.34774979925714433, 0.41335164627525955, 0.2516491856658831, 0.4619661782635376, 0.8757772436365485, 0.5623676266986877, 0.5014808813575655, 0.32527403498534113, 0.5902503523975611, 1.5538940811529756, 2.1195792267099023, 2.0674336748197675, 1.9745969376526773, 4.234303263947368, 13.421303518116474, 22.9410694912076, 43.39708372950554, 38.37196737527847, 28.76531146466732, 31.963820233941078, 32.52093493938446, 60.83346650004387, 82.45090171694756, 98.65957796573639, 105.38732215762138, 107.69452035427094, 104.6878556907177, 94.73282307386398, 85.90801700949669, 82.85189419984818, 79.82883721590042, 88.77062380313873, 92.51531526446342, 107.44258627295494, 109.69873040914536, 91.45792320370674, 86.90835133194923, 88.05375427007675, 86.04990899562836, 80.56089073419571, 86.98894500732422, 95.44400811195374, 87.32544735074043, 68.62333729863167, 33.362369388341904, 8.556597456336021, 1.455906720366329, 1.5142764570191503, 1.4424902340397239, 2.101316931657493, 1.4049641601741314, 1.543406881392002, 1.0541482223197818, 0.9363435592968017, 0.3861210308969021, 0.41677742963656783, 0.4606879624770954, 0.3188262559706345, 0.35157764854375273, 0.3761529189068824, 0.24888815882150084, 0.3336701891385019, 0.356242373236455, 0.19972461566794664, 0.16998957842588425, 0.16420450760051608, 0.17057967488653958, 0.3086304827593267, 0.2866749343229458, 0.2821619639871642, 0.19169628474628553, 0.23840324487537146, 0.11345664242981002, 0.098063364130212, 0.1320109874359332, 0.21382053819252178, 0.2803094149567187, 0.16184069303562865, 0.2756287786178291, 0.19657379802083597, 0.23835881991544738, 0.09771200173418038, 0.19297350605484098, 0.19796676468104124], [0.08277919638203457, 0.05655209824908525, 0.14765461441129446, 0.13919353717938066, 0.014872174670017557, 0.06931336465640925, 0.09412748040631413, 0.09393605083459988, 0.08486514343530871, 0.046683315304107964, 0.028592393282451667, 0.07533565556514077, 0.14516182942315936, 0.04289227283152286, 0.19650712347356603, 0.011249044036958367, 0.01714167246973375, 0.09631736524170265, 0.003015479596797377, 0.08704158055479638, 0.07276806951267645, 0.17550907912664115, 0.17113067500758916, 0.32013371237553656, 0.10797269060276449, 0.04623033804818988, 0.046494598282151856, 0.027575328131206334, 0.1535247205174528, 0.08286022406537086, 0.050774938717950135, 0.1466886349953711, 0.15286713314708322, 0.047585688953404315, 0.33256085647735745, 0.18323170457733795, 0.13847154623363167, 0.14550194086041301, 0.42912071105092764, 0.5958564765751362, 0.4607553198002279, 1.3223113515414298, 2.845414853654802, 44.22204986214638, 85.74851676821709, 93.87790694832802, 94.92734983563423, 68.54830652475357, 61.136526837944984, 46.34746581315994, 43.67995575070381, 49.85077142715454, 68.6363933980465, 75.04876211285591, 76.83465868234634, 86.30352258682251, 88.53327333927155, 89.65061098337173, 98.38986843824387, 98.16220745444298, 99.43464517593384, 87.75034815073013, 68.55067759752274, 63.52639339864254, 58.17554712295532, 63.71777392923832, 73.78194808959961, 77.50890970230103, 74.75680097937584, 75.37483021616936, 54.526317939162254, 61.58170334994793, 52.344961389899254, 25.713982097804546, 28.568858206272125, 21.370484568178654, 20.5210667476058, 8.735982030630112, 5.215282374992967, 2.0019116532057524, 0.935794310644269, 1.534636951982975, 0.42894621728919446, 0.1893636997556314, 0.2237968731787987, 0.317725443164818, 0.44988505309447646, 0.538830264704302, 1.0135278082452714, 0.2523829025449231, 0.6060640944633633, 0.06767561542801559, 0.15919499594019726, 0.2892029861686751, 0.22488422342576087, 0.3448375524021685, 0.1471862746984698, 0.6290070258546621, 1.4735383680090308, 2.6342471223324537, 1.4531880849972367, 0.2569173654774204, 0.8369228441733867, 0.19668255234137177, 3.376023368909955, 8.303611781448126, 15.687745101749897, 31.442533805966377, 44.43804547190666, 46.394511088728905, 35.0575952231884, 17.036541625857353, 15.384123343974352, 25.731029883027077, 37.91550546884537, 48.03745932877064, 54.44202706217766, 58.590975031256676, 65.33196151256561, 70.60173153877258, 66.15461736917496, 57.708871364593506, 49.63234394788742, 42.06987954676151, 36.6002706438303, 32.26665258407593, 35.0998679548502, 35.41391730308533, 39.93211425840855, 39.71942827105522, 52.4193499982357, 59.571778401732445, 54.17215034365654, 41.17878936231136, 20.667944066226482, 5.19800802692771, 2.020261106081307, 1.1124026589095592, 1.0506488475948572, 1.111034257337451, 2.0495409099385142, 3.06538172531873, 3.418591534718871, 2.816513841971755, 1.2263694684952497, 0.7522373821120709, 0.5323243013117462, 0.17175351502373815, 0.20782563253305852, 0.18332640262087807, 0.16544977203011513, 0.20038266316987574, 0.21220463037025183, 0.11351227381965145, 0.11652782020973973, 0.053916538890916854, 0.06023411551723257, 0.17046591849066317, 0.18279662792338058, 0.22201570391189307, 0.20877452770946547, 0.1189372174849268, 0.03783411710173823, 0.08293935185065493, 0.12661720655160025, 0.0770733572426252, 0.2814880642108619, 0.11870027199620381, 0.015554610072285868, 0.08232865337049589, 0.04475048815947957, 0.03896245987561997, 0.11422774870879948, 0.07935610701679252, 0.18633777071954682, 0.07662786825676449, 0.14528070663800463, 0.030003347746969666, 0.06893765981658362, 0.055609203336643986, 0.10246025514788926, 0.07692270868574269, 0.04387513981782831, 0.11176818225067109, 0.059344673791201785, 0.07123894843971357, 0.052859761417494155, 0.03214578151528258, 0.06445029357564636, 0.032356688752770424, 0.08020268229302019, 0.01265709392100689, 0.04607879891409539, 0.09792040422325954, 0.10721578903030604, 0.23838169290684164, 0.15724727389169857, 0.1765959692420438, 0.166587024286855, 0.11344562153681181, 0.050396595543134026, 0.023906945971248206, 0.03180118008458521, 0.027130874441354536, 0.05278958393319044, 0.10158314791624434, 0.012099185332772322, 0.1800131140043959, 0.15622653882019222, 0.18536108953412622, 0.07569017208879814, 0.10003079019952565, 0.4094830679241568, 0.23209896753542125, 0.495022326358594, 0.32984655525069684, 1.4938361663371325, 5.864915465936065, 20.23396745324135, 79.9089141190052, 105.20229488611221, 89.95670735836029, 80.17664775252342, 67.40411192178726, 73.17806169390678, 81.0040457546711, 82.62392163276672, 84.09872889518738, 92.40867778658867, 92.31323450803757, 93.44612091779709, 92.61689141392708, 98.21804165840149, 100.02094611525536, 108.28259199857712, 110.77682375907898, 117.25410059094429, 114.85249266028404, 101.54505953192711, 97.00817137956619, 83.51125001907349, 73.35310310125351, 71.61961331963539, 70.03949850797653, 70.85207730531693, 67.44280904531479, 54.61284689605236, 48.718352392315865, 42.12933875620365, 28.628226220607758, 26.712089739739895, 19.58996281027794, 15.606850292533636, 7.6487059984356165, 2.4655960220843554, 1.2616818048991263, 1.0727793350815773, 0.8574626420158893, 0.4513939283788204, 0.14032105245860294, 0.09929086896590889, 0.26078716095071286, 0.3103225794620812, 0.20251252310117707, 0.6978001969400793, 0.6330177106428891, 0.2653852110961452, 0.1695874976576306, 0.0021472155185620068, 1.1924742185510695, 0.6511873262934387, 0.07572955786599778, 0.14942693727789447, 0.48348201904445887, 0.9205890703015029, 0.5546838452573866, 0.6671193370129913, 2.0124893356114626, 2.2128568589687347, 1.626107543706894, 2.3977530375123024, 5.128886885941029, 14.033984541893005, 22.73950170725584, 40.53526729345322, 45.87540954351425, 37.69430413842201, 25.532289147377014, 27.976939268410206, 49.32886943221092, 62.908573150634766, 78.08127298951149, 82.77750179171562, 84.12748575210571, 85.40145099163055, 80.91784358024597, 73.72497394680977, 64.49186459183693, 59.03953716158867, 62.311902567744255, 66.35118842124939, 77.90782749652863, 71.82651981711388, 72.49948650598526, 66.06835439801216, 59.59787920117378, 67.748092263937, 73.01192700862885, 75.28719171881676, 57.83288910984993, 36.39854706823826, 16.596952714025974, 6.650614030659199, 1.4929471327923238, 1.6060253838077188, 1.7817678535357118, 2.3391509195789695, 2.6619051257148385, 2.423408073373139, 1.8805386847816408, 1.041956339031458, 0.5399321462027729, 0.5101069528609514, 0.17156815622001886, 0.2793206664500758, 0.08440631063422188, 0.1165809431404341, 0.1987614860991016, 0.1824573625344783, 0.10242563395877369, 0.20417246996657923, 0.1537606047349982, 0.06808236430515535, 0.16663228045217693, 0.1764458921388723, 0.16052412305725738, 0.16232034307904541, 0.10259992734063417, 0.06428040112950839, 0.09406539975316264, 0.11783088310039602, 0.16350249527022243, 0.16753660223912448, 0.1519878811086528, 0.08740528486669064, 0.11559431717614643, 0.12541641161078587, 0.04572361816826742, 0.05211759518715553, 0.13338547461898997, 0.013603983443317702, 0.08153039932949468, 0.22234903211938217, 0.17608743481105193, 0.17934573028469458, 0.38312224962282926, 0.3053329128306359, 0.19139357755193487, 0.2747689560055733, 0.29003374627791345, 0.17516947234980762, 0.1884512885590084, 0.15490211691940203, 0.10536094676353969, 0.25649808172602206, 0.16526082123164088, 0.19506743119563907, 0.08757631279877387, 0.09704421725473367, 0.2512461697915569, 0.26302720012608916, 0.44755509530659765, 0.2503893751418218, 0.2137353247962892, 0.1707092983997427, 0.22807726927567273, 0.1443635011673905, 0.2089641909697093, 0.12563127820612863, 0.16555839276406914, 0.20497865014476702, 0.16227584390435368, 0.17290368065005168, 0.21828626340720803, 0.12936196551891044, 0.18792460119584575, 0.4033314058324322, 0.20908281585434452, 0.8619161217939109, 0.4629182646749541, 0.6487241084687412, 0.6069676741026342, 0.9121895022690296, 1.8573057814501226, 5.4738224018365145, 56.436004266142845, 106.16079345345497, 100.55712014436722, 99.31552156805992, 73.96426230669022, 76.19125440716743, 78.76096531748772, 78.08052822947502, 83.11819911003113, 98.30793723464012, 99.96486872434616, 109.36602786183357, 118.95719200372696, 126.93368598818779, 122.7628929913044, 124.04451861977577, 124.33725491166115, 130.2337709069252, 124.17820304632187, 105.45402377843857, 105.5465716123581, 94.12078231573105, 85.75575157999992, 84.83674809336662, 79.65057358145714, 74.31325078010559, 83.95840242505074, 70.5520986020565, 79.68951389193535, 70.66578850150108, 47.08231218159199, 42.8109385818243, 29.12526234984398, 24.808589480817318, 13.535840772092342, 3.5887262178584933, 2.130365422926843, 2.502201357856393, 2.3780081095173955, 0.37339325761422515, 0.2188011654652655, 0.4192263091681525, 0.2989798318594694, 0.3644915821496397, 0.7082810439169407, 1.000734488479793, 0.6356311985291541, 1.14743297919631, 0.3998485067859292, 0.23319382831687108, 1.9520646217279136, 1.3043811824172735, 0.8977198193315417, 0.4173501895274967, 0.8228089171461761, 2.0372013095766306, 2.250016964972019, 2.5024504819884896, 1.3001205422915518, 1.3731606979854405, 1.7624094360508025, 7.665431750938296, 13.966525811702013, 28.029197864234447, 44.12684977054596, 64.2556844651699, 59.74490091204643, 51.567329317331314, 33.74699994921684, 31.751177944242954, 49.19510520994663, 63.85118097066879, 76.92664414644241, 83.08111310005188, 78.75688433647156, 75.96807718276978, 68.14772441983223, 63.98661330342293, 63.442163318395615, 66.38752967119217, 74.84001651406288, 82.08140194416046, 90.5667570233345, 81.80451080203056, 83.0413444340229, 79.55408155918121, 74.40085887908936, 87.57012382149696, 91.42803400754929, 86.85450822114944, 63.03483657538891, 34.03887368738651, 12.199710868299007, 3.8966529071331024, 1.8322420888580382, 2.2458540508523583, 1.9171307212673128, 2.010660208761692, 2.4732288625091314, 2.1447699749842286, 1.6354226251132786, 0.7684943347703665, 0.7015197817236185, 0.4692195140523836, 0.21381826722063124, 0.39138737018220127, 0.27113370888400823, 0.19478185276966542, 0.41696581640280783, 0.34815970226190984, 0.23154652764787897, 0.3527024178765714, 0.33710042538587004, 0.1590919413138181, 0.25113140407484025, 0.304025961086154, 0.2660641277907416, 0.3007480432279408, 0.14738996454980224, 0.1374036550987512, 0.2454047996434383, 0.2348679502028972, 0.3633593616541475, 0.2899393154075369, 0.20092515827855095, 0.18122233974281698, 0.1802441297331825, 0.2853579487418756, 0.193009574431926, 0.2592866274062544, 0.24877477349946275, 0.17573262884980068, 0.11256980564212427], [0.0963686328032054, 0.12172312111943029, 0.11193293161340989, 0.014187017441145144, 0.040452729517710395, 0.07491342548746616, 0.025981207909353543, 0.014717375652253395, 0.10731432397733442, 0.019405998427828308, 0.05380409238568973, 0.040046373978839256, 0.08699688100023195, 0.04641883984731976, 0.04239120440615807, 0.0336535361566348, 0.0509566053369781, 0.0821780864498578, 0.025028987911355216, 0.021978219192533288, 0.05409305129433051, 0.04596173625031952, 0.12355779181234539, 0.08015738159883767, 0.11131456674775109, 0.12866823555668816, 0.0703043989778962, 0.06965242966543883, 0.0663502435781993, 0.06892774472362362, 0.16658510954584926, 0.03050217859708937, 0.0906095074606128, 0.06524078475194983, 0.0952049600891769, 0.1081916390103288, 0.141528467356693, 0.2876319782808423, 0.7619173626881093, 1.330362525768578, 1.680383593775332, 1.5051618148572743, 1.9828104344196618, 0.8524174033664167, 16.08674269169569, 48.15815605223179, 71.18071407079697, 63.28528493642807, 63.74121867120266, 55.46949952840805, 56.93501628935337, 54.594174697995186, 51.977198123931885, 58.284772261977196, 51.02717690169811, 47.45227552950382, 60.25485634803772, 77.41579949855804, 90.04527300596237, 88.73640283942223, 86.0268822312355, 79.05420318245888, 63.54337848722935, 47.26567894220352, 42.42304779589176, 33.39725151658058, 32.75503657758236, 36.359397768974304, 44.56947281956673, 56.87422715127468, 67.47940868139267, 68.97290334105492, 74.57911491394043, 75.04316121339798, 75.89850291609764, 59.779581651091576, 34.15525384247303, 13.062086943536997, 10.58182893320918, 5.760966343805194, 4.376240847632289, 1.7098231078125536, 0.2845178672578186, 0.3245630278252065, 0.5214938137214631, 0.22689980745781213, 0.276372826192528, 0.2707139204721898, 0.9175808192230761, 0.6309190951287746, 0.11126936253276654, 0.09016955489641987, 0.0832142804574687, 0.7137793488800526, 1.070472146384418, 1.3538736454211175, 1.2752375775016844, 2.2231234330683947, 5.270143356174231, 4.511069962754846, 0.8980579418130219, 1.2795979622751474, 2.3676501028239727, 9.165670573711395, 17.665576972067356, 26.655269488692284, 38.37961256504059, 54.73561830818653, 62.55636624991894, 69.13500264286995, 64.61048662662506, 37.626895755529404, 29.088465124368668, 27.940288335084915, 25.53074263036251, 27.169429399073124, 29.577358290553093, 30.839720852673054, 32.59912334382534, 35.17070755362511, 33.26986715197563, 29.919113852083683, 21.308863274753094, 18.008635863661766, 21.54841762036085, 20.12296210974455, 20.26409413665533, 21.558977253735065, 25.150833316147327, 34.18748751282692, 41.096451580524445, 33.800485879182816, 22.689006216824055, 8.415430281311274, 2.1321589266881347, 1.11146921524778, 0.613081130431965, 0.3491405543172732, 0.33096877159550786, 0.9128145687282085, 1.4508952642790973, 1.5973650547675788, 1.917098423000425, 1.0840130760334432, 0.9018322674091905, 0.6216123851481825, 0.47523848013952374, 0.294323627022095, 0.3845779277617112, 0.26212397671770304, 0.36691475368570536, 0.20399540837388486, 0.05432921752799302, 0.11746945718186907, 0.1588292358792387, 0.20997297746362165, 0.07619161900947802, 0.165449490013998, 0.4108346672728658, 0.29190891596954316, 0.3140175249427557, 0.2256023552035913, 0.1510359431267716, 0.1485167525243014, 0.023344012115558144, 0.09412860104930587, 0.16614198801107705, 0.22552235168404877, 0.19006161543074995, 0.03172534372424707, 0.21891219075769186, 0.08489209081744775, 0.06468674924690276, 0.04514256848779041, 0.06351902440655977, 0.07724800685537048, 0.02822910828399472, 0.07662076590349898, 0.13475216925144196, 0.11112183099612594, 0.06519019996630959, 0.07344855213887058, 0.12330526122241281, 0.023598123480041977, 0.03963370276323985, 0.11379540315829217, 0.04293679055990651, 0.06676469594822265, 0.043976417000521906, 0.06841981143224984, 0.040830901998560876, 0.07715317522524856, 0.033275163295911625, 0.044698975689243525, 0.022909595973032992, 0.0545005682943156, 0.04977674638212193, 0.07621990225743502, 0.08526311270543374, 0.07542160368757322, 0.038410331690101884, 0.03636931054643355, 0.0834448063687887, 0.09505653797532432, 0.07119352158042602, 0.07301796547835693, 0.12461035017622635, 0.061809654216631316, 0.189918321557343, 0.025708388857310638, 0.18329174432437867, 0.156893685052637, 0.22270155226578936, 0.3346021781908348, 0.5494577600620687, 0.9781707648653537, 0.8460366551298648, 1.6775463335216045, 2.737205922603607, 4.1115788742899895, 33.84886108338833, 70.41209131479263, 93.47335025668144, 76.78271546959877, 73.08336317539215, 61.95508271455765, 62.989702597260475, 67.42008626461029, 76.69406622648239, 74.80973213911057, 82.00246497988701, 93.51169779896736, 94.60080295801163, 98.76264363527298, 102.75979354977608, 104.00374040007591, 103.7378990650177, 101.66712418198586, 94.34670299291611, 87.04498440027237, 78.39885994791985, 69.02761280536652, 63.59252505004406, 63.527271151542664, 64.24138203263283, 70.08930623531342, 61.84111163020134, 69.6867786347866, 65.44495224952698, 49.58697058260441, 45.49532733857632, 36.47820599377155, 30.720781534910202, 13.05227966979146, 9.329733420163393, 4.369277246296406, 2.715991185978055, 0.685775326564908, 0.4562123666983098, 0.37060337606817484, 0.30538610997609794, 0.045731585123576224, 0.38202586001716554, 0.3137985320063308, 0.5951815971639007, 0.8077256265096366, 0.44008499302435666, 0.3326943836873397, 0.218755419482477, 0.5934212822467089, 1.8057157122530043, 2.8083400055766106, 0.2977137279231101, 1.3133002538233995, 2.0105982245877385, 3.803055854514241, 1.7179097863845527, 1.0978291346691549, 1.0281342244707048, 1.014182441867888, 3.1131515745073557, 11.88905568793416, 22.200137749314308, 40.863258093595505, 51.70907311141491, 63.34101274609566, 58.885531425476074, 41.029514372348785, 42.606251165270805, 45.49147054553032, 50.89491739869118, 59.58467110991478, 62.89643660187721, 64.6419869363308, 62.68549092113972, 59.65105354785919, 53.995395228266716, 48.42959828674793, 46.83580420911312, 49.488730654120445, 52.99334339797497, 49.940659403800964, 51.46706409752369, 53.56159530580044, 58.3593774586916, 57.362098172307014, 65.47164961695671, 55.9776196628809, 39.32630896568298, 20.851721204817295, 7.447844501584768, 2.7573959017172456, 1.3586505828425288, 1.5475930692628026, 1.677784533239901, 1.9362197094596922, 2.482213005423546, 2.343742260709405, 2.4106792313978076, 1.3566187606193125, 0.7684422063175589, 0.642193149542436, 0.41443396476097405, 0.3648592421086505, 0.2919440343976021, 0.16039340116549283, 0.2599772997200489, 0.18290288862772286, 0.1574212481500581, 0.10893785365624353, 0.21637596044456586, 0.33378744847141206, 0.2198603586293757, 0.3931204928085208, 0.30034348368644714, 0.308840629295446, 0.1033798725984525, 0.08670289404108189, 0.09313415284850635, 0.0790963701729197, 0.052716140999109484, 0.05438345739094075, 0.19619245285866782, 0.1866792922373861, 0.03714830214448739, 0.15644171711755916, 0.12144406617153436, 0.029016337721259333, 0.07383743752143346, 0.09665928751928732, 0.027676473582687322, 0.10837304216693155, 0.15529174444964156, 0.21282600093400106, 0.25955507706385106, 0.3968819644069299, 0.3847255260916427, 0.30153118714224547, 0.25143764389213175, 0.28302178659942, 0.18083021859638393, 0.121730312530417, 0.15101786440936849, 0.14884271862683818, 0.14734574739122763, 0.1610792792052962, 0.16721872554626316, 0.19095207389909774, 0.15183732903096825, 0.11429220423451625, 0.08268098055850714, 0.09840968734351918, 0.18454162491252646, 0.16304221528116614, 0.16179000434931368, 0.18102187081240118, 0.2106998665840365, 0.18799225537804887, 0.22806989232776687, 0.20211853174259886, 0.2430304465815425, 0.20698841573903337, 0.14846699894405901, 0.13883545092539862, 0.14177563221892342, 0.19324035267345607, 0.168922696611844, 0.42468133207876235, 0.35460219718515873, 0.34126990009099245, 0.5794157087802887, 1.0391780943609774, 1.328382238280028, 1.275264888536185, 1.97430067230016, 0.6458763394039124, 15.390759687870741, 56.915124356746674, 92.0578046143055, 91.07754081487656, 93.8444459438324, 85.97309231758118, 86.16877421736717, 85.38851648569107, 87.8279247879982, 89.67568203806877, 91.0413059592247, 95.28578460216522, 104.04587253928185, 117.17834785580635, 123.905278891325, 120.37575468420982, 117.14226499199867, 118.3704274892807, 116.07521384954453, 105.93685626983643, 99.89701956510544, 90.13458341360092, 80.223278850317, 73.3846566081047, 74.63312521576881, 72.91774526238441, 74.39256772398949, 74.28534507751465, 74.62902143597603, 81.52869880199432, 78.6714269220829, 70.42868122458458, 53.94453875720501, 34.337780848145485, 16.589562110602856, 9.053107313811779, 4.110315442085266, 1.7621111520566046, 0.4663020127918571, 0.480273655266501, 0.7655117323156446, 0.2905551198637113, 0.6274228077381849, 0.8148959605023265, 1.735775952693075, 1.5827396395616233, 1.162525056861341, 0.30090463638771325, 0.3193741984432563, 2.279140977188945, 5.072715925052762, 4.858078742399812, 2.484316430054605, 4.7391080763190985, 7.346091661602259, 7.97197412699461, 2.6608589943498373, 2.88085222709924, 4.56452501937747, 13.861373104155064, 28.58712762594223, 46.038648784160614, 58.04965227842331, 71.47783532738686, 76.3314288854599, 75.87180554866791, 77.31327340006828, 55.40535517036915, 49.840363785624504, 49.05439496040344, 49.45433869957924, 53.33057910203934, 53.56067955493927, 52.12186396121979, 51.62152200937271, 52.86390334367752, 53.5226321965456, 54.902459755539894, 57.87448927760124, 61.53495445847511, 65.54325297474861, 60.68124666810036, 64.1099014878273, 65.42637884616852, 72.41149842739105, 74.48016062378883, 70.63836917281151, 53.078322038054466, 30.24363163858652, 13.303692229092121, 4.116832567378879, 2.0342669170349836, 1.164861456491053, 1.9323711097240448, 1.540239870082587, 1.7531740316189826, 2.4158918391913176, 1.826265009585768, 2.0002359431236982, 1.4364742068573833, 0.6917573336977512, 0.7430798141285777, 0.6127465702593327, 0.351009014993906, 0.32896146993152797, 0.37817723059561104, 0.51985734840855, 0.33747900975868106, 0.311425321851857, 0.24501407373463735, 0.28750130091793835, 0.5200881266500801, 0.37746592657640576, 0.47169736702926457, 0.5235591810196638, 0.2848892973270267, 0.3416716691572219, 0.2786769869271666, 0.21861268964130431, 0.2414629267877899, 0.1251103202230297, 0.22427015559514984, 0.22003198770107701, 0.3095825097989291, 0.300482680904679, 0.2826905809342861, 0.3678872936870903, 0.19263173220679164, 0.1469949638703838, 0.19441763637587428, 0.18971164827235043, 0.22236972319660708], [0.104651371948421, 0.13448260637233034, 0.152567557815928, 0.22158209671033546, 0.1282309027737938, 0.12594078347319737, 0.10896133520873263, 0.19157902541337535, 0.14064307033549994, 0.056037374306470156, 0.09988002289901488, 0.07537803961895406, 0.04841513175051659, 0.020724453461298253, 0.04258630760887172, 0.08915099431760609, 0.1319686256465502, 0.034065532017848454, 0.06372136354912072, 0.08599811349995434, 0.028925107362738345, 0.049242997483816, 0.02598084982309956, 0.11457842832896858, 0.01214813275510096, 0.016940914101724047, 0.015172451330727199, 0.030643231184512842, 0.0631968655216042, 0.25552604638505727, 0.12051384343067184, 0.0667666329536587, 0.1350271943374537, 0.07150129022193141, 0.07547544650151394, 0.19337638834258541, 0.3658493858529255, 0.4641645384253934, 0.7790473778732121, 0.5012614431325346, 0.7749167620204389, 0.7362214790191501, 1.1812674324028194, 1.273495964705944, 1.7903350875712931, 0.8760989794973284, 6.3021143060177565, 17.591819129884243, 37.77686230838299, 53.97286243736744, 55.18689349293709, 55.87282508611679, 46.04950860142708, 50.88780038058758, 55.25232218205929, 44.065319672226906, 55.18101520836353, 60.119348019361496, 52.298630475997925, 49.2475575953722, 44.025288820266724, 43.383841440081596, 39.49291102588177, 34.834231808781624, 26.325563080608845, 18.533564396202564, 12.964399885386229, 9.673294834792614, 10.654842965304852, 15.346320122480392, 18.979377374053, 29.467270597815514, 37.55525819957256, 52.132005617022514, 70.2812947332859, 73.6223566532135, 34.65105503797531, 15.706520844250917, 16.07570618391037, 17.217427119612694, 12.212406937032938, 1.3616701145656407, 0.07311439272598363, 0.060055102076148614, 0.09436098975129426, 0.31757796357851475, 0.24332500499440357, 0.45424145995639265, 0.2069101488450542, 0.2576042083092034, 0.042837160945055075, 0.14234800619306043, 0.06939748709555715, 0.3132053482113406, 0.47115423367358744, 3.1521279830485582, 2.910573282279074, 6.90214485861361, 6.877799089998007, 4.329400761052966, 4.720232114195824, 4.144363040104508, 10.647980533540249, 25.3405799344182, 47.49788448214531, 61.29161171615124, 62.91910618543625, 61.60395875573158, 64.42491978406906, 63.47337104380131, 46.4703132212162, 29.894373379647732, 17.647531740367413, 11.666624173521996, 16.025444380939007, 16.39741212129593, 16.855359748005867, 15.491566378623247, 13.493058867752552, 11.768834888935089, 11.528584230691195, 6.530827358365059, 6.353022549301386, 10.399677157402039, 9.212672151625156, 12.76676869019866, 14.239777699112892, 18.0655188113451, 20.06973646581173, 18.402114249765873, 7.752386284992099, 4.286092109978199, 0.6377870484720916, 0.4289773281197995, 0.33886347140651196, 0.1629493132350035, 0.07632643755641766, 0.1415783545235172, 0.3645262256031856, 0.5082927283365279, 0.4080457950476557, 0.6740553304553032, 0.4027176497038454, 0.35804359533358365, 0.30745548487175256, 0.33660241460893303, 0.1825001696124673, 0.09861936632660218, 0.17606067296583205, 0.18437622988130897, 0.13139015121851116, 0.20151351811364293, 0.07692771818256006, 0.050164726344519295, 0.17447817663196474, 0.07750432239845395, 0.1975764098460786, 0.17448705271817744, 0.15342589613283053, 0.3006862965412438, 0.16129928146256134, 0.09156254382105544, 0.03434149963140953, 0.05241700724582188, 0.09033124661073089, 0.2246169315185398, 0.13449139340082183, 0.07287875341717154, 0.05974441308353562, 0.2285227953689173, 0.13364234677283093, 0.20061142276972532, 0.1013134366075974, 0.02560716362495441, 0.05550796697207261, 0.03110728499450488, 0.11785747425165027, 0.05642722077027429, 0.17215952917467803, 0.18473878386430442, 0.07416260952595621, 0.13118350761942565, 0.18444885645294562, 0.13897095224820077, 0.027324747534294147, 0.055545775685459375, 0.0389149587135762, 0.070947551575955, 0.05258011646219529, 0.05903260811464861, 0.036037548270542175, 0.04601701512001455, 0.03869805492286105, 0.021882396795263048, 0.04098914272617549, 0.018556734721641988, 0.042802847747225314, 0.017797541768231895, 0.03373614090378396, 0.09257536759832874, 0.07837645724066533, 0.016890384977159556, 0.02583121615316486, 0.03138721382129006, 0.08410315815126523, 0.060762535795220174, 0.08448370921541937, 0.07694365209317766, 0.03230724316381384, 0.10444877305417322, 0.03730436095793266, 0.19137950643198565, 0.3024281171383336, 0.4587486118543893, 0.7134314300492406, 0.702922559576109, 1.1299066571518779, 0.7763090310618281, 1.8050204683095217, 1.7164651514030993, 3.439013776369393, 3.2849757419899106, 25.116099379956722, 48.21851201355457, 68.04623946547508, 76.88523396849632, 78.74915555119514, 74.04158815741539, 66.17101728916168, 74.48331445455551, 68.82238581776619, 61.81748829782009, 69.83585223555565, 79.60932299494743, 89.12407323718071, 90.33847287297249, 89.09394085407257, 81.44545286893845, 78.92478972673416, 72.54256099462509, 68.52034762501717, 58.61881613731384, 49.487332329154015, 47.265492752194405, 46.92851923406124, 58.30867677927017, 64.01099279522896, 67.32753843069077, 67.21901625394821, 67.12000116705894, 73.16737666726112, 72.86686599254608, 49.58888567984104, 26.102349758148193, 24.845443703234196, 13.483685720711946, 8.54407712817192, 2.647391567006707, 0.42158981203101575, 0.20533453964162618, 0.11598954049986787, 0.31254456960596144, 0.16716674552299082, 0.7637656666338444, 0.6110628449823707, 0.2907478407723829, 0.10014388608396985, 0.282954637077637, 0.11190068529685959, 0.5011788569390774, 2.470034658908844, 5.7393440790474415, 6.157968090847135, 6.994118923321366, 9.326806627213955, 6.210914924740791, 3.450400815345347, 2.7520393766462803, 5.829341299831867, 18.208727426826954, 32.574337273836136, 45.76694056391716, 53.38815741240978, 64.46176260709763, 70.14298215508461, 74.89560753107071, 64.79032337665558, 51.761696487665176, 43.95869359374046, 37.786464393138885, 36.72209970653057, 38.50202299654484, 38.69985178112984, 36.53716363012791, 35.226009786129, 34.944612085819244, 35.624521002173424, 34.991296380758286, 32.88358747959137, 32.340121641755104, 39.02598828077316, 33.0503149330616, 40.05957841873169, 42.61442452669144, 43.50179851055145, 39.715339690446854, 25.23515459150076, 12.815228439867496, 4.457118082791567, 1.5447005932219326, 0.9004081750754267, 0.7116983667947352, 0.7705502619501203, 0.8544537972193211, 1.0190902347676456, 1.2435268540866673, 1.0740682971663773, 1.1170191736891866, 1.1617572605609894, 0.9193274786230177, 0.6160808319691569, 0.3568712098058313, 0.3938894171733409, 0.1967786901514046, 0.17297884536674246, 0.2161901563522406, 0.12465358769986778, 0.2414785118889995, 0.10391321702627465, 0.09328454165370204, 0.19683628081111237, 0.2188067909446545, 0.27233150554820895, 0.10881703201448545, 0.13022382161580026, 0.0801242224406451, 0.15666384191717952, 0.1354182616341859, 0.11923629557713866, 0.10913959165918641, 0.07854618641431443, 0.16340398258762434, 0.07152567719458602, 0.06807339173974469, 0.017234819424629677, 0.11455577056040056, 0.12519348529167473, 0.17386897729011253, 0.21188672399148345, 0.12907997908769175, 0.06319499530945905, 0.03434568534430582, 0.2894396719057113, 0.22149943630211055, 0.27311349171213806, 0.3673794271890074, 0.20824202190851793, 0.19947368069551885, 0.23887894669314846, 0.3083191072801128, 0.23666382883675396, 0.1649094736785628, 0.14127462316537276, 0.17034583899658173, 0.16062014212366194, 0.2036207722267136, 0.1404057166655548, 0.11996886212727986, 0.13134330685716122, 0.2423980922321789, 0.12563702242914587, 0.27864569798111916, 0.19855046382872388, 0.266731763840653, 0.15258836763678119, 0.22409800702007487, 0.14617771084886044, 0.18760105449473485, 0.136859824124258, 0.13380127027630806, 0.2137427165871486, 0.29297342291101813, 0.24628987011965364, 0.16858913091709837, 0.1751484101987444, 0.1651319398661144, 0.16933380189584568, 0.32462329021655023, 0.3750420722644776, 0.500546843977645, 0.6194867554586381, 0.45356521499343216, 0.6808321480639279, 0.5639895459171385, 1.1243633483536541, 1.380435407627374, 1.2234127521514893, 0.4513316473457962, 11.906614545732737, 36.00163176655769, 66.18237107992172, 91.97183042764664, 96.19863241910934, 91.05113223195076, 78.78930419683456, 82.72545978426933, 83.47158014774323, 71.40508443117142, 80.42346730828285, 87.30567321181297, 90.1569490134716, 94.68089506030083, 95.70354178547859, 90.15303522348404, 91.59194201231003, 89.66096922755241, 85.94174399971962, 77.96809986233711, 69.40323024988174, 70.85228249430656, 64.42871958017349, 77.89887517690659, 73.8225907087326, 73.71671319007874, 74.42657589912415, 83.15818816423416, 87.29073241353035, 98.09184283018112, 74.68013629317284, 49.020010605454445, 34.275224804878235, 27.854572534561157, 20.683851912617683, 4.13761792704463, 0.8218893664889038, 0.21416136209154502, 0.15082423808053136, 0.5512908054515719, 0.5052288458682597, 1.0128969233483076, 0.6509192625526339, 0.47527805145364255, 0.3912961750756949, 0.871549139264971, 0.20683017501141876, 0.5518994852900505, 3.9246973022818565, 8.186653107404709, 9.658483229577541, 12.176651805639267, 10.355238541960716, 6.738464841619134, 8.188894987106323, 10.88070759549737, 17.26649008691311, 39.881649166345596, 63.9541782438755, 70.84036633372307, 71.90906658768654, 71.37166902422905, 79.0186370909214, 74.82993185520172, 69.87384259700775, 63.1421884149313, 53.423145934939384, 52.32672616839409, 48.86323481798172, 46.438527926802635, 45.28254255652428, 43.995996192097664, 40.526227578520775, 41.244810819625854, 48.03127706050873, 48.787751868367195, 41.432402953505516, 51.20860196650028, 55.89198365807533, 48.24436962604523, 56.114948093891144, 53.09705123305321, 45.74447236955166, 34.518426954746246, 15.754279531538486, 6.544416379183531, 1.9632154796272516, 0.6389923556707799, 0.7266683166380972, 0.6210541713517159, 0.9411587321665138, 0.8314992883242667, 1.1525191250257194, 1.2350658955983818, 0.9542419051285833, 1.0635990276932716, 0.8923036849591881, 0.8567172882612795, 0.5641276447568089, 0.4936057742452249, 0.5114130140282214, 0.2488705699215643, 0.20399206870933995, 0.28988804784603417, 0.2669127588160336, 0.43408288853242993, 0.2723059162963182, 0.18641827889950946, 0.31433842959813774, 0.4148352885385975, 0.3971496719168499, 0.32324865460395813, 0.39000786608085036, 0.41191431402694434, 0.242186090326868, 0.26927103695925325, 0.2481532099773176, 0.14045216026715934, 0.20920982700772583, 0.33343148475978523, 0.34592922194860876, 0.218168618157506, 0.17915229691425338, 0.4737124464008957, 0.3311736637260765, 0.36851120239589363, 0.32828691706527025, 0.16920621186727658, 0.17103042569942772, 0.1389627589378506], [0.12313525003264658, 0.06189277475641575, 0.025524150696583092, 0.08325851245899685, 0.09246547779184766, 0.09053961199242622, 0.041923209792003036, 0.1267618066049181, 0.06413197901565582, 0.04347557493019849, 0.06542707866174169, 0.052241504163248464, 0.06981235506827943, 0.0764872164290864, 0.024311820925504435, 0.02249957608000841, 0.008097436930256663, 0.04280250635929406, 0.11462671245681122, 0.09971646097255871, 0.03119163193332497, 0.06083321422920562, 0.10541838899371214, 0.05666353172273375, 0.03567084939277265, 0.0686124581261538, 0.0742288981564343, 0.06179136769787874, 0.12209395004902035, 0.001671971165251307, 0.074178061040584, 0.0716999483120162, 0.05669091326126363, 0.022695608822687063, 0.053869579496677034, 0.028115593086113222, 0.11448019024101086, 0.32108541287016124, 0.26936828799080104, 0.6068158010020852, 0.5807866633404046, 0.868029281264171, 0.7562233088538051, 0.46148853201884776, 0.40835233172401786, 1.2259555282071233, 2.015860229730606, 1.1065996577963233, 2.0761485071852803, 14.669699929654598, 30.89753095060587, 46.009458750486374, 52.87723682820797, 43.78995604813099, 38.39287385344505, 39.68806095421314, 65.25516763329506, 56.77299678325653, 37.258163541555405, 32.76229038834572, 26.316166184842587, 18.340530954301357, 13.663581367582083, 18.666840344667435, 20.660167783498764, 14.730282928794622, 8.98802250623703, 7.449579108506441, 9.028104655444622, 7.4177843146026134, 9.316809363663197, 10.195946339517832, 19.792691431939602, 36.49701878428459, 58.29915069043636, 76.39433830976486, 39.872807040810585, 16.004796288907528, 14.04443683102727, 19.467018507421017, 18.64688191562891, 7.147348551079631, 1.3018129952251911, 0.7746975019108504, 0.42703931336291134, 0.21198574133450165, 0.6802783871535212, 0.285010653315112, 0.14888795994920656, 0.619076614966616, 0.19315089419251308, 0.4200211790157482, 0.0896541407564655, 0.1666652169660665, 0.059167222570977174, 0.5258493300061673, 2.3833126248791814, 2.4285957450047135, 2.4856931436806917, 2.8192696440964937, 6.342120934277773, 14.453806914389133, 28.357811830937862, 43.82749803364277, 62.15116359293461, 70.60353264212608, 76.54648214578629, 79.12137597799301, 68.24176177382469, 51.69368393719196, 39.59600709378719, 23.461322374641895, 16.271988451480865, 15.2560730651021, 9.643257446587086, 9.092951025813818, 7.907388042658567, 7.955785570666194, 6.209803959354758, 6.473625702783465, 18.44020150601864, 16.75511732697487, 12.569782510399818, 14.135850425809622, 23.356235213577747, 25.838811099529266, 24.203481450676918, 9.480191096663475, 5.639375243335962, 2.344009908847511, 0.6609500711783767, 0.3142408520216122, 0.261755307437852, 0.169282786664553, 0.10343738904339261, 0.20124193659285083, 0.24046605918556452, 0.3470663703046739, 0.38833456055726856, 0.22524680709466338, 0.2727871248498559, 0.18590080901049078, 0.3595864016097039, 0.2712306036846712, 0.44134144904091954, 0.3475497756153345, 0.3124699689215049, 0.1381965063046664, 0.16383065812988207, 0.09286604457884096, 0.09564031133777462, 0.15663387399399653, 0.05576208946877159, 0.14304801472462714, 0.054933978826738894, 0.18458027596352622, 0.2456683956552297, 0.22795359778683633, 0.18089741264702752, 0.1134175386687275, 0.07441860594553873, 0.025813894426391926, 0.20241430727764964, 0.19806618278380483, 0.14935408806195483, 0.12789619417162612, 0.06126790125563275, 0.033914304585778154, 0.2620348893105984, 0.15865186258452013, 0.189574217365589, 0.14229638240067288, 0.10871028891415335, 0.07366260979324579, 0.08423396167927422, 0.07524264219682664, 0.12405843721353449, 0.07981861344887875, 0.18361474183620885, 0.03730374126462266, 0.18224933854071423, 0.18740233703283593, 0.06756524322554469, 0.13003516767639667, 0.024820620674290694, 0.05214032717049122, 0.06318786327028647, 0.040109512192429975, 0.050050094214384444, 0.03809943489613943, 0.08344156318344176, 0.047912623558659106, 0.050662176799960434, 0.02657848093804205, 0.10837017005542293, 0.04856285624555312, 0.04344392604252789, 0.028215721795277204, 0.02610275685583474, 0.0790122922626324, 0.01060815591699793, 0.026579236073303036, 0.06293368511251174, 0.03225385305995587, 0.008179562064469792, 0.04142831974604633, 0.03222175146220252, 0.023562867754662875, 0.004755808013214846, 0.026188497176917735, 0.09682752497610636, 0.0887032863101922, 0.1155968478997238, 0.2942509559215978, 0.38741916592698544, 0.6246179644949734, 0.716205578064546, 0.8671272452920675, 0.6256811949424446, 0.5874052550643682, 0.8292188169434667, 0.802304504904896, 1.9653544086031616, 2.9562359070405364, 15.884265806525946, 35.491649731993675, 52.83785194158554, 66.37608468532562, 65.6329433619976, 67.57364362478256, 70.27128607034683, 67.33412727713585, 79.95887383818626, 78.27640011906624, 67.6347367465496, 65.11535033583641, 62.52247206866741, 62.258625626564026, 61.74308069050312, 54.23923574388027, 49.7531508654356, 41.63573004305363, 33.64249035716057, 28.38118437677622, 31.99674926698208, 38.20827975869179, 38.227742314338684, 39.5734629034996, 53.400894328951836, 61.09703555703163, 73.81489232182503, 97.44322523474693, 66.16536319255829, 35.60489505529404, 32.13626638054848, 34.40979078412056, 24.124096110463142, 5.252450555562973, 0.8530686527956277, 0.789363527437672, 0.17566887836437672, 0.1553243098896928, 0.15383133140858263, 0.17496260610641912, 0.37981155852321535, 0.6804826855659485, 0.5413206154480577, 0.50070138880983, 0.09060756303369999, 0.20302136923419312, 1.0033716657198966, 3.441612124443054, 5.30546436086297, 5.109131271019578, 5.440554711967707, 4.883407233282924, 9.4371004588902, 12.959822081029415, 24.949656911194324, 46.95579417049885, 68.22451069951057, 78.50311875343323, 82.8394004702568, 78.71294349431992, 74.99077722430229, 67.5063644349575, 57.78620481491089, 45.80896630883217, 35.41162222623825, 25.71069147437811, 23.529694005846977, 24.46607965976, 26.649584993720055, 27.163969092071056, 23.5628567263484, 26.91599629819393, 28.511994257569313, 23.69109984487295, 19.6603312343359, 26.700633354485035, 32.421733662486076, 33.3051710575819, 35.145442709326744, 23.57012763619423, 15.624728333204985, 7.762898420915008, 2.777449800632894, 1.2486859085038304, 0.7352929632179439, 0.480667557567358, 0.17376525473082438, 0.38455803820397705, 0.37595485453493893, 0.43712438782677054, 0.5966812104452401, 0.7653247704729438, 0.4760307673132047, 0.43451852921862155, 0.5677680275402963, 0.5711427214555442, 0.37042134208604693, 0.376042309217155, 0.2892432105727494, 0.1650985877495259, 0.07121560047380626, 0.136542986438144, 0.10345917849917896, 0.1415049858042039, 0.1827423769282177, 0.20725331793073565, 0.24629196297610179, 0.2714290836593136, 0.2479336381657049, 0.36141448945272714, 0.3324148611864075, 0.1732530986191705, 0.12403823595377617, 0.11557882855413482, 0.12826147925807163, 0.22413012717152014, 0.16698477091267705, 0.1611594163114205, 0.16329414473148063, 0.04411167341459077, 0.10194736431003548, 0.19350512127857655, 0.1854491824633442, 0.20077793102245778, 0.10218075491138734, 0.08349766954779625, 0.044012886137352325, 0.02849348540621577, 0.2051141217816621, 0.24853357550455257, 0.24930147570557892, 0.1929119523265399, 0.21987692336551845, 0.21209449565503746, 0.10064800473628566, 0.2193590230308473, 0.1881501398747787, 0.17706285434542224, 0.17418366274796426, 0.1855578922550194, 0.10235101100988686, 0.12168599889264442, 0.13539598236093298, 0.09862897713901475, 0.1636633780435659, 0.09363183708046563, 0.17198310582898557, 0.1659129315521568, 0.13170455466024578, 0.1902696245815605, 0.2122967308969237, 0.19962825521361083, 0.1655750020290725, 0.1161855120153632, 0.11964040983002633, 0.22191481635672972, 0.2692913421196863, 0.10523602104512975, 0.2483649001806043, 0.15449948696186766, 0.11350407308782451, 0.263577428413555, 0.19870468211593106, 0.14385845483047888, 0.19143691897625104, 0.39311176515184343, 0.3967976267449558, 0.6266152916941792, 0.5534697510302067, 0.7417754747439176, 0.6923483207356185, 0.33965780690778047, 0.3923879039939493, 1.323075348045677, 1.2238721712492406, 0.8617207885254174, 7.598650334402919, 23.882638067007065, 46.64208300411701, 67.12657481431961, 73.71946424245834, 72.77291223406792, 70.50975367426872, 72.62672647833824, 94.023667126894, 91.23704105615616, 71.24293953180313, 71.2145246565342, 75.48285081982613, 66.842380464077, 70.2471573650837, 69.55332219600677, 73.2196618616581, 64.44701179862022, 55.489509254693985, 56.98029085993767, 72.82773569226265, 67.74853304028511, 66.0008092224598, 61.102765649557114, 70.25723442435265, 79.45649519562721, 87.25328922271729, 113.49399715662003, 97.15175047516823, 64.82376158237457, 54.70608249306679, 53.73000226914883, 35.91023147106171, 18.897161185741425, 6.995166717097163, 3.154404298402369, 1.6048641898669302, 0.5280003708321601, 1.5204054093919694, 0.40022818953730166, 0.5820696288719773, 2.4398759147152305, 1.0177485505118966, 1.2737587443552911, 0.19416646391618997, 0.5404670268762857, 1.822713625151664, 3.040449363179505, 5.552729442715645, 4.028734769672155, 4.423561608418822, 6.593995168805122, 12.862620446830988, 23.9060790091753, 40.27785390615463, 66.86945021152496, 83.98500099778175, 88.65809664130211, 95.11445939540863, 95.0307422876358, 87.71510124206543, 76.2599091231823, 72.99545109272003, 62.431964725255966, 57.27520063519478, 46.737442687153816, 40.4711077362299, 42.56833679974079, 45.036441162228584, 42.212976068258286, 40.00190511345863, 46.53983049094677, 52.658634558320045, 52.32129625976086, 50.99705211818218, 48.51599805057049, 54.78613659739494, 48.930434212088585, 39.156564474105835, 18.121288418769836, 8.74545682221651, 3.1449499307200313, 1.117527277674526, 0.5814771575387567, 0.5682507203891873, 0.7053379237186164, 0.30155276879668236, 0.4769733839202672, 0.5786045710556209, 0.4869324713945389, 0.5588686082046479, 0.5787473008967936, 0.5163835035637021, 0.4200190713163465, 0.7527344429399818, 0.4743155452888459, 0.37402999063488096, 0.4078669671434909, 0.3686164686223492, 0.27678252139594406, 0.2583835821133107, 0.24767361930571496, 0.3402950445888564, 0.3652541834162548, 0.2766365261049941, 0.521375248208642, 0.27650682837702334, 0.24100208276649937, 0.36416895571164787, 0.3754354699049145, 0.46691012859810144, 0.319953637663275, 0.21782547875773162, 0.24341139098396525, 0.22625033918302506, 0.31709776434581727, 0.20112602796871215, 0.37276887393090874, 0.23051277530612424, 0.1979445299366489, 0.3335902449907735, 0.23969594738446176, 0.3022388991666958, 0.20361400383990258, 0.2994212316116318, 0.21338774735340849, 0.14356834930367768, 0.2278191057848744], [0.0835093657951802, 0.029012610284553375, 0.10412446194095537, 0.005436247965917573, 0.04700190074800048, 0.051802546076942235, 0.024370636128878687, 0.008252978095697472, 0.09130736376391724, 0.01945473897649208, 0.029260081282700412, 0.039423444904969074, 0.04072376184922177, 0.08085859240964055, 0.028771436409442686, 0.02476818237482803, 0.09568630965077318, 0.1617381875985302, 0.08599400200182572, 0.013253720353532117, 0.02295752572536003, 0.06181003642268479, 0.07287664571776986, 0.032819094994920306, 0.07652535539818928, 0.12264390374184586, 0.05849107779795304, 0.0120110831267084, 0.05685512827767525, 0.04595250022248365, 0.010691683710319921, 0.07736950385151431, 0.04040626736241393, 0.09567160770529881, 0.028428104051272385, 0.03015338403201895, 0.06030859745806083, 0.043162006404600106, 0.024310251283168327, 0.14736360346432775, 0.15530679520452395, 0.040323684879695065, 0.293391608283855, 0.2657928579719737, 0.34588546492159367, 0.2299436370958574, 0.34382244281005114, 0.3248113504378125, 0.6559738225769252, 0.8091978100128472, 2.3892265325412154, 4.178000735118985, 10.071811750531197, 17.621121257543564, 21.594837829470634, 29.58379704505205, 50.0643465667963, 62.164314687252045, 48.9334474503994, 40.586518943309784, 36.34799838066101, 24.2047106847167, 16.76538437604904, 12.766654696315527, 5.348328435793519, 1.9112044642679393, 6.565959323197603, 12.735646460205317, 11.713854689151049, 12.299813646823168, 13.091592360287905, 12.890921328216791, 16.03679247200489, 25.841273367404938, 41.65524199604988, 62.62710705399513, 30.811944343149662, 16.260539665818214, 15.012899413704872, 17.965855859220028, 22.553467489778996, 15.181602761149406, 8.33804838359356, 2.8952567791566253, 0.8292920817621052, 0.29536043701227754, 1.2696306221187115, 0.3132945246761665, 0.4414530977373943, 1.0732779395766556, 0.3442867600824684, 0.05253609226201661, 0.08508986575179733, 0.11355184513377026, 0.4066472622798756, 0.7971519220154732, 0.6404176948126405, 0.9626923548057675, 3.7740030884742737, 11.180832590907812, 17.557392977178097, 34.9684976041317, 50.453206300735474, 59.932629838585854, 60.430395528674126, 63.74520845711231, 64.76287364959717, 63.40942807495594, 50.980108827352524, 36.51515521109104, 22.393488474190235, 9.257394801825285, 4.920859923586249, 3.216125098988414, 2.0399435749277472, 2.0951125770807266, 2.065559425391257, 5.421020435169339, 6.224491596221924, 4.225302021950483, 7.285957038402557, 5.5276270397007465, 14.463816527277231, 21.57374896109104, 18.69066696614027, 12.994067743420601, 5.336415600031614, 1.6854855325073004, 0.8231251314282417, 0.22002189449267462, 0.08270283680758439, 0.07511631381930783, 0.07771403848892078, 0.0567738705285592, 0.13923530525062233, 0.14765320433070883, 0.16199952748138458, 0.2806145267095417, 0.35576110531110317, 0.4790101043181494, 0.39249064691830426, 0.1565565273631364, 0.2427094677113928, 0.21818427747348323, 0.006479335597759928, 0.01218652498209849, 0.06833424180513248, 0.09194460886646993, 0.06552430000738241, 0.12401621643221006, 0.1425638227374293, 0.13386608945438638, 0.1629999277065508, 0.2179725278983824, 0.19973715796368197, 0.13740206690272316, 0.11492013538372703, 0.07856015363358893, 0.01063027470081579, 0.02171481984987622, 0.035811842608381994, 0.11990361250354908, 0.04287782692699693, 0.0680272449972108, 0.1464064556057565, 0.09019166347570717, 0.04489023827773053, 0.14135084173176438, 0.04137586845899932, 0.10423147221445106, 0.11857119767228141, 0.06401483100489713, 0.04705865649157204, 0.08389930502744392, 0.040842653907020576, 0.13097701244987547, 0.11266210654866882, 0.020342657444416545, 0.08803671153145842, 0.12122361120418645, 0.07018532138317823, 0.07966015749843791, 0.043237861318630166, 0.0938658213999588, 0.10530084764468484, 0.044465904211392626, 0.06328255389234982, 0.04151274646574166, 0.01966477975656744, 0.12519268377218395, 0.058853349764831364, 0.018281598313478753, 0.04446453494892921, 0.09446059339097701, 0.0893749670649413, 0.046339960681507364, 0.0852795438549947, 0.08809444319922477, 0.06966693865251727, 0.08487000450259075, 0.056397460648440756, 0.1413342621526681, 0.03541422214766499, 0.0706006346445065, 0.10232242348138243, 0.08762274897890165, 0.049537485392647795, 0.030936746879888233, 0.10016315965913236, 0.09842996281804517, 0.09668098791735247, 0.021801515686092898, 0.12251022810232826, 0.03963663795730099, 0.11869829046190716, 0.1570668281055987, 0.2658134006196633, 0.053743084135930985, 0.6077184900641441, 0.5598477087914944, 0.33155863056890666, 0.41048514540307224, 0.6036779412534088, 0.23052638629451394, 1.0219601495191455, 2.943321350030601, 9.12473252043128, 17.23202593624592, 28.71032651513815, 36.40941068530083, 43.11229661107063, 52.365586683154106, 74.14103642106056, 72.40585193037987, 58.38246501982212, 54.44958105683327, 51.884578093886375, 38.45528930425644, 36.540249064564705, 40.173040330410004, 41.326840817928314, 34.795789271593094, 29.824438132345676, 30.48265401273966, 32.17199586331844, 30.705793239176273, 29.520222656428814, 35.46898394823074, 48.75076085329056, 53.88449437916279, 67.56216064095497, 93.1872408092022, 66.27897709608078, 37.372495606541634, 33.58217239379883, 38.04110772907734, 35.49510754644871, 16.140682697296143, 6.273728404194117, 1.322653095703572, 0.8372628665529191, 0.9264463372528553, 1.0389573499560356, 1.0647124866954982, 0.17114164395025, 0.8213859528768808, 0.2373299063765444, 0.169827448844444, 0.06819543050369248, 0.21386082196841016, 0.43626732600387186, 0.96277731587179, 1.0326982545666397, 1.0269889421761036, 1.9339191704057157, 9.416174031794071, 16.35677520185709, 31.491477079689503, 53.81853371858597, 68.22603061795235, 82.06186339259148, 86.17061331868172, 83.25867757201195, 84.5509122312069, 67.70035922527313, 59.4303347915411, 52.41928160190582, 36.134385243058205, 26.53491284698248, 23.477931283414364, 21.534153185784817, 20.611682385206223, 20.793686918914318, 19.023054130375385, 14.450164809823036, 14.554568007588387, 20.808948799967766, 26.43859751522541, 27.44493741542101, 30.126103945076466, 30.41043508797884, 26.39198161661625, 14.221654571592808, 4.189349301159382, 2.159585142508149, 0.9919282828923315, 0.4394966480322182, 0.31147382862400264, 0.19502843875670806, 0.008363486667803954, 0.22500747931189835, 0.20474380493396893, 0.21596132253762335, 0.4879056051140651, 0.5042293213773519, 0.5851833242923021, 0.4292238102061674, 0.3046252898639068, 0.3312480862950906, 0.26572906295768917, 0.12849535967689008, 0.1256684894906357, 0.22988920798525214, 0.14919753943104297, 0.09668373386375606, 0.17900198232382536, 0.18069045734591782, 0.24886193132260814, 0.17370606103213504, 0.200606539438013, 0.1877394353505224, 0.07304646394914016, 0.18798162782331929, 0.14135998499114066, 0.10219075164059177, 0.1082821810268797, 0.08001228430657648, 0.15531877346802503, 0.09595069976057857, 0.16993008786812425, 0.11616286166827194, 0.09606450810679235, 0.04662897525122389, 0.12351221652352251, 0.04286501745809801, 0.12435339638614096, 0.12428525980794802, 0.16331921447999775, 0.06971904484089464, 0.11426605837186798, 0.010451887446834007, 0.032837845355970785, 0.24923450429923832, 0.11106182835646905, 0.3412007022416219, 0.171736326883547, 0.17423806217266247, 0.14003991207573563, 0.2299877058248967, 0.18130633601685986, 0.31993306532967836, 0.15513139602262527, 0.1322464708937332, 0.12400907697156072, 0.13415846595307812, 0.19212926854379475, 0.14931010839063674, 0.09251899406081066, 0.16839961608638987, 0.26274218573234975, 0.2091903382097371, 0.08683218358783051, 0.12636843865038827, 0.18288935185410082, 0.18532772257458419, 0.11530706149642356, 0.14810190681600943, 0.21189280960243195, 0.09885635634418577, 0.30640291166491807, 0.21416551811853424, 0.2231305729947053, 0.07576156669529155, 0.17162506410386413, 0.20092831982765347, 0.19226055446779355, 0.18633778556250036, 0.12702995940344408, 0.20229023502906784, 0.14389293501153588, 0.33020367671269923, 0.2852104097837582, 0.3200929536251351, 0.1241892778489273, 0.3833607165142894, 0.4134776332648471, 0.2787638478912413, 0.2141471128561534, 0.44229694933164865, 0.2702564903302118, 0.5355240858625621, 0.9276721870992333, 3.3818149706348777, 7.442263076081872, 15.912946667522192, 26.240641437470913, 38.07243324816227, 50.26361547410488, 68.38576644659042, 80.2211357653141, 70.2618245780468, 68.86068016290665, 71.05541199445724, 57.708278596401215, 60.96574120223522, 62.79019430279732, 52.36822374165058, 49.584952890872955, 44.661268293857574, 51.318442672491074, 51.311850026249886, 67.12100431323051, 67.58003488183022, 72.05823138356209, 75.68754583597183, 76.12401321530342, 79.90526631474495, 102.271968126297, 92.92019873857498, 72.25794866681099, 67.77279853820801, 64.24771249294281, 55.57204842567444, 35.828782841563225, 16.726345270872116, 6.861771075055003, 3.8529424276202917, 3.1569211883470416, 4.052361901849508, 2.659877697005868, 1.7671216581948102, 2.1745506394654512, 0.9649003332015127, 0.2122654567938298, 0.23930094670504332, 0.34446178819052875, 1.6297146189026535, 2.4739888217300177, 1.9648311054334044, 2.307825400494039, 6.40345866791904, 18.241930045187473, 27.507670149207115, 49.35110963881016, 72.42991223931313, 89.03827384114265, 91.74419984221458, 95.13494029641151, 89.38771829009056, 86.6410356760025, 76.84505492448807, 72.13335335254669, 63.696624264121056, 50.286600440740585, 44.09947603940964, 43.93807590007782, 40.64599335193634, 35.417705699801445, 32.99695439636707, 35.16448348760605, 39.50795441865921, 39.43215988576412, 42.752277329564095, 44.50714856386185, 44.94969941675663, 46.20056189596653, 33.20074126124382, 19.06154416501522, 7.897787382826209, 1.8844933225773275, 1.1041612573899329, 0.66556480480358, 0.3501426614820957, 0.4812101268908009, 0.2711501548765227, 0.38441373500972986, 0.3406961011933163, 0.2550175861688331, 0.2617134799947962, 0.4753735807025805, 0.6678140466101468, 0.7704051572363824, 0.49244879570323974, 0.5050303658936173, 0.3311373578617349, 0.3979276504833251, 0.1277791426400654, 0.12336455140030012, 0.22925826371647418, 0.25444159051403403, 0.19339627790031955, 0.2923172456212342, 0.37292157823685557, 0.5073912267107517, 0.3580292273545638, 0.38460396230220795, 0.32026124303229153, 0.20173065568087623, 0.3250922978622839, 0.17329255118966103, 0.1380943867843598, 0.19228124554501846, 0.2742097032023594, 0.17509301629615948, 0.11172300030011684, 0.19450840103672817, 0.2512718184152618, 0.22547762986505404, 0.06645766203291714, 0.24293975613545626, 0.09596879332093522, 0.23477494425605983, 0.24368175538256764, 0.2124909806298092, 0.1615433144615963, 0.2143889936269261, 0.14824094076175243, 0.14561260992195457], [0.09758133179275319, 0.15243480243952945, 0.06748215237166733, 0.051320517450221814, 0.07804148146533407, 0.08321059940499254, 0.03959890716942027, 0.03869004714943003, 0.020329770050011575, 0.042650781688280404, 0.06930296716745943, 0.014726161753060296, 0.08174571121344343, 0.07227301990496926, 0.034370525027043186, 0.09940778691088781, 0.05632942426018417, 0.1290770698687993, 0.04482665848627221, 0.06213108579686377, 0.039787434943718836, 0.07578058051876724, 0.02290602624270832, 0.05687480261258315, 0.07158027699915692, 0.02831634588801535, 0.04943502077367157, 0.010966369263769593, 0.028268338210182264, 0.08063333574682474, 0.1388249421142973, 0.023877323146734852, 0.018977881263708696, 0.035488607609295286, 0.039997566636884585, 0.025925194313458633, 0.07331002285354771, 0.05806903696793597, 0.0019243183055550617, 0.051758284389507025, 0.07618766336236149, 0.009406358149135485, 0.14546882623108104, 0.04048831920954399, 0.15389760519610718, 0.08926272465032525, 0.20003180543426424, 0.15641106641851366, 0.060246012144489214, 0.22608574567129835, 0.329995815991424, 0.6271025561727583, 0.42389379465021193, 1.3081727852113545, 0.8792116062249988, 3.52125798817724, 7.794551672413945, 18.15983545035124, 34.49829563498497, 32.67806030809879, 36.24483771622181, 31.361847035586834, 32.55258724093437, 26.884666979312897, 17.796664237976074, 8.584050983190536, 5.675999103114009, 2.8031499590724707, 4.177353344857693, 5.851827068254352, 8.432143684476614, 15.056747160851955, 16.897881366312504, 22.647907622158527, 33.60815919935703, 34.85271401703358, 26.293052025139332, 22.101827524602413, 22.195443101227283, 22.207731641829014, 20.27766890823841, 22.007032111287117, 14.95927194133401, 8.690805304795504, 5.480163311585784, 3.459264077246189, 1.6185819287784398, 3.6749761272221804, 1.4541057357564569, 0.3089324774919078, 0.37284481048118323, 0.15090093162143603, 0.26404299249406904, 0.9135006694123149, 1.404382197652012, 0.24743252521147951, 0.7026281941216439, 5.442760493606329, 14.148386903107166, 24.459954388439655, 42.619311064481735, 52.22489543259144, 53.224348202347755, 56.64746291935444, 56.83998338878155, 50.35786181688309, 45.499252527952194, 45.41039429605007, 31.88682496547699, 27.094250433146954, 17.724515609443188, 12.762230783700943, 4.651554124429822, 1.9373638043180108, 3.9955972228199244, 0.31501054822001606, 2.0541645493358374, 0.7272354362066835, 4.890179419890046, 5.861875154078007, 5.007677190005779, 15.707592386752367, 17.519566006958485, 12.155819423496723, 4.898101519793272, 1.1234458163380623, 0.46539754257537425, 0.15337385673774406, 0.1566252947668545, 0.07793715034495108, 0.07412798091536388, 0.11747579512302764, 0.043162841320736334, 0.11832461910671555, 0.12429233247530647, 0.1417773836874403, 0.030522661872964818, 0.02800321894028457, 0.08165330640622415, 0.059003430578741245, 0.054925581425777636, 0.10206759965512902, 0.08558710469515063, 0.06015297651174478, 0.062342356686713174, 0.1065972979995422, 0.08152728230925277, 0.02646137374540558, 0.0953088681853842, 0.07021476980298758, 0.04184559227724094, 0.10602326161460951, 0.07843971048714593, 0.037972382924635895, 0.039093782907002605, 0.0626623336574994, 0.0158208054563147, 0.04688608860305976, 0.004329631565269665, 0.03498054815281648, 0.12147695815656334, 0.021317614991858136, 0.06767941522412002, 0.02730183186940849, 0.05979393288725987, 0.14336985448608175, 0.10012321727117524, 0.11107110520242713, 0.03773452830500901, 0.07382062045508064, 0.052127035305602476, 0.062099403512547724, 0.022804014333814848, 0.0679961490095593, 0.024131946593115572, 0.04177171518676914, 0.04535183557891287, 0.05419428023742512, 0.0837050775589887, 0.10044581402326003, 0.08612420439021662, 0.0629498045600485, 0.023710846435278654, 0.07904403391876258, 0.023832317456253804, 0.03321643715025857, 0.008875917374098208, 0.09363134726299904, 0.009818405960686505, 0.03672294020361733, 0.03109945719188545, 0.04640499137167353, 0.060464960552053526, 0.0762408234004397, 0.10595380401355214, 0.10466130188433453, 0.2072283223969862, 0.0665546533127781, 0.11597539516515099, 0.06924747678567655, 0.1251760745071806, 0.19829509081318974, 0.07178953295806423, 0.017504076167824678, 0.010867125565710012, 0.08419328456511721, 0.05748559386120178, 0.042382294923299924, 0.047715780019643717, 0.006546199856529711, 0.031946522285579704, 0.01225257334226626, 0.04832504615478683, 0.02667203421879094, 0.041842638529487886, 0.07970720966113731, 0.0827075939741917, 0.17468165868194774, 0.18116347258910537, 0.11535102632478811, 0.1860349447815679, 0.1685433107195422, 0.18017438269453123, 0.5747867259196937, 0.3514132183045149, 0.22929774597287178, 0.5589657404925674, 1.3783450447954237, 1.5779587836004794, 5.129012279212475, 6.7109638173133135, 14.406807236373425, 27.110787145793438, 42.76254817843437, 47.94831231236458, 50.24388313293457, 50.37148408591747, 48.33785220980644, 46.04637756943703, 34.85008455812931, 24.44026954472065, 18.614739440381527, 20.410031005740166, 28.733186088502407, 29.29961409419775, 30.653342753648758, 31.57371036708355, 31.047788187861443, 37.077468037605286, 46.122601479291916, 67.4650302529335, 81.02681413292885, 58.20556931197643, 43.52194882929325, 35.67358396947384, 36.08875349164009, 36.08816832304001, 37.14635454118252, 21.219408474862576, 9.527482409030199, 5.203348640352488, 2.3912952840328217, 1.6596447816118598, 2.7080526994541287, 1.1830905033275485, 0.630030061583966, 0.48270715749822557, 0.5981514940503985, 0.7804727763868868, 1.8504666234366596, 2.5250573689118028, 0.1824788996600546, 0.900605705101043, 3.9948429632931948, 12.5132567435503, 26.94452326744795, 42.321418449282646, 61.916955560445786, 69.7338505089283, 77.48406663537025, 79.00492742657661, 78.87248173356056, 72.663903683424, 69.52630564570427, 62.673373371362686, 47.137397825717926, 38.174355179071426, 24.47287179529667, 21.74923874437809, 23.23903240263462, 18.136360310018063, 13.44586730003357, 10.851054936647415, 4.555741790682077, 6.685948809608817, 16.590299271047115, 23.50807696580887, 24.872084073722363, 27.93229166418314, 24.270623847842216, 12.836268860846758, 5.4422627203166485, 1.6863561607897282, 0.7633511919993907, 0.39790764218196273, 0.27915365353692323, 0.08357543178135529, 0.08858558168867603, 0.18915272201411426, 0.2079619947471656, 0.21926938643446192, 0.4192734800744802, 0.34686230937950313, 0.2915547037264332, 0.48693769611418247, 0.3778142313240096, 0.2803684602258727, 0.2277087781112641, 0.22944743715925142, 0.021090887021273375, 0.05827772889460903, 0.057161112054018304, 0.08584391747717746, 0.06953659525606781, 0.061600427943631075, 0.08658552338602021, 0.09246961155440658, 0.09056512702954933, 0.06132656802947167, 0.14402181637706235, 0.16197720367927104, 0.08075799429207109, 0.16592801199294627, 0.04678375757066533, 0.03632048836152535, 0.05196816004172433, 0.017185702236020006, 0.05466120986966416, 0.057778152186074294, 0.06336649821605533, 0.12759482284309343, 0.14610775600885972, 0.16307458776282147, 0.12301156370085664, 0.07762106222799048, 0.07130360434530303, 0.0239012815291062, 0.09762076209881343, 0.02837576779711526, 0.020253614566172473, 0.05147972668055445, 0.07912654589745216, 0.18719637620961294, 0.2567282662494108, 0.15034242096589878, 0.15701808384619653, 0.1584240232477896, 0.22999033302767202, 0.07858293756726198, 0.18106605828506872, 0.15072159905685112, 0.15068613924086094, 0.1522315727197565, 0.12897627137135714, 0.19729280553292483, 0.14856739668175578, 0.15903739345958456, 0.1570673772948794, 0.1451868991716765, 0.21255615603877231, 0.08395777142141014, 0.18531243433244526, 0.1656316575827077, 0.20749356597661972, 0.1337423882796429, 0.16813634661957622, 0.2089443162549287, 0.20077232038602233, 0.126034130807966, 0.0955345256079454, 0.25012128171510994, 0.21214033069554716, 0.261077904724516, 0.11417100409744307, 0.11855427670525387, 0.07288354026968591, 0.12109634029911831, 0.2352020947728306, 0.25563181727193296, 0.1601593871600926, 0.14931113255443051, 0.12589067366207018, 0.27105296321678907, 0.3015731630148366, 0.28369779407512397, 0.20818392658839002, 0.2047100372146815, 0.265075052739121, 0.21950730413664132, 0.5410122976172715, 0.21864127716980875, 0.3154059051303193, 0.32700490148272365, 0.8895595790818334, 0.49530051299370825, 1.9165937625803053, 2.192999362014234, 6.276687020435929, 14.805023018270731, 29.596038088202477, 43.64806406199932, 44.17479179799557, 57.68876664340496, 58.2968670129776, 71.10258266329765, 73.22542995214462, 62.20203906297684, 49.8220981657505, 48.959126472473145, 51.43818564713001, 53.74851867556572, 51.935255974531174, 55.143929198384285, 61.793610379099846, 68.44230741262436, 73.69664266705513, 89.52530890703201, 91.2586010992527, 83.42281356453896, 72.32515946030617, 68.6471164226532, 76.13222077488899, 67.11643695831299, 57.39460162818432, 36.76794044673443, 18.06584369391203, 10.473413150757551, 6.88635528087616, 4.186612972989678, 5.055498098954558, 1.881252215243876, 0.7739787467289716, 0.6287194881588221, 0.5994829663541168, 1.050195365678519, 3.191082780249417, 4.501535324379802, 1.216060146689415, 1.8607024429365993, 6.599709587171674, 18.82808279246092, 35.20343139767647, 56.20654597878456, 78.05371686816216, 85.42792797088623, 99.60472404956818, 96.69785723090172, 93.01841586828232, 78.59767287969589, 80.7748344540596, 71.29481434822083, 63.33079509437084, 57.660009786486626, 49.728501588106155, 44.639446064829826, 40.7600974291563, 40.37227123975754, 40.87325535714626, 42.055672109127045, 39.31349605321884, 41.81883081793785, 38.75220537185669, 36.15837715566158, 37.996805906295776, 33.09459775686264, 19.501438960433006, 6.70636273920536, 1.9698405428789556, 0.6394776608794928, 0.45124481606762856, 0.3507846192223951, 0.2427650842582807, 0.1801394869107753, 0.32335282245185226, 0.2943401027005166, 0.23493256157962605, 0.24375283828703687, 0.3738332918146625, 0.4003150505013764, 0.28695273504126817, 0.4466120630968362, 0.26612836809363216, 0.27321899542585015, 0.2501732617383823, 0.35727265232708305, 0.22679786605294794, 0.208283745450899, 0.2584886405384168, 0.28303603583481163, 0.1659030164591968, 0.15666047256672755, 0.1946237456286326, 0.1767712496803142, 0.26619388489052653, 0.10425850123283453, 0.3142552200006321, 0.22196520818397403, 0.1551656238734722, 0.2694443432847038, 0.08821252631605603, 0.21683386556105688, 0.22924848221009597, 0.10245765763102099, 0.10588729273877107, 0.13879378675483167, 0.1296196540351957, 0.1314071612432599, 0.5183358862996101, 0.21184695971896872, 0.2243534690933302, 0.20387109863804653, 0.17646934400545433, 0.1707002441980876, 0.2609513240167871, 0.10520056865061633, 0.14231061679311097, 0.13214138278272003, 0.15401449345517904], [0.07206878086435609, 0.06419339173589833, 0.03171143958752509, 0.022251685768424068, 0.13135331100784242, 0.02071061982860556, 0.08083471751888283, 0.032366867308155634, 0.02489972990588285, 0.10894783554249443, 0.07809217757312581, 0.06868118842248805, 0.07382539246464148, 0.07101735798642039, 0.017802788752305787, 0.013377468840189977, 0.028712988569168374, 0.10536310641327873, 0.086251245229505, 0.043274605050100945, 0.07176162078394555, 0.0479587925656233, 0.023965944856172428, 0.028036448602506425, 0.03230291644285899, 0.017813221493270248, 0.06521964838611893, 0.06495650508441031, 0.05879610049305484, 0.07459908141754568, 0.06071726107620634, 0.07537611745647155, 0.037568116531474516, 0.025257363449782133, 0.05468786781420931, 0.009380856099596713, 0.09098334950977005, 0.0710331805748865, 0.03587823513953481, 0.03133898164378479, 0.0639331724960357, 0.08606519622844644, 0.02924469099525595, 0.020174123128526844, 0.04774080895003863, 0.039528447668999434, 0.04859456079429947, 0.019574170946725644, 0.06542267772601917, 0.18008447892498225, 0.2572397841140628, 0.4462821042397991, 0.21427719650091603, 0.1712480976129882, 0.06180900112667587, 0.221784925670363, 0.36653703020419925, 0.6056325207464397, 4.229113217443228, 8.310155980288982, 15.939113013446331, 20.07423922419548, 31.869602389633656, 32.849814891815186, 33.075461983680725, 20.75153388082981, 14.29438741877675, 16.22717935591936, 13.213909696787596, 12.323671616613865, 9.604249689728022, 10.629215240478516, 12.34516041353345, 14.053760580718517, 27.30534240603447, 30.180486626923084, 22.964571230113506, 28.248472698032856, 29.35167320072651, 27.74641703814268, 26.00793432444334, 18.480536341667175, 19.303290992975235, 18.994164280593395, 13.121704794466496, 6.833716230466962, 5.659063886851072, 6.047969218343496, 5.347854886204004, 5.838929610326886, 6.085357312113047, 4.680477697402239, 5.1757008489221334, 4.593861820176244, 3.7563606351614, 4.273630203679204, 8.237580824643373, 19.073768109083176, 34.71799984574318, 46.90790913999081, 54.12474408745766, 45.4530394077301, 47.754955887794495, 47.805557772517204, 45.34393586218357, 34.070286601781845, 32.50045783817768, 26.606168523430824, 28.144641369581223, 13.785271737724543, 13.893747366964817, 6.5978476870805025, 3.4459614660590887, 4.087057365104556, 7.771429913118482, 12.576014176011086, 6.886965148150921, 11.276669148355722, 8.55481630191207, 11.410437170416117, 15.229578986763954, 12.70330449566245, 3.778008073568344, 1.3057478028349578, 0.3276299679419026, 0.26662884280085564, 0.16273278422886506, 0.09182360168779269, 0.11302431172225624, 0.05823334846354555, 0.020004785437777173, 0.05045603415055666, 0.052899536822224036, 0.11248959432123229, 0.05841272184625268, 0.2580724738072604, 0.08359638261026703, 0.08635673410026357, 0.07597859294037335, 0.03105123614659533, 0.030661168893857393, 0.08085408015176654, 0.02777657260594424, 0.0867310214380268, 0.060150479184812866, 0.04893821598670911, 0.09610677341697738, 0.011811143904196797, 0.04729708256490994, 0.020252638641977683, 0.10984118096530437, 0.047887583496049047, 0.06997146410867572, 0.044717670389218256, 0.03426253882935271, 0.033031453131115995, 0.06492172062280588, 0.0680718629155308, 0.10519529940211214, 0.05756099977588747, 0.07515853460063227, 0.062245469307526946, 0.037050019527669065, 0.007309142511076061, 0.0302305247168988, 0.0544491560140159, 0.07652219384908676, 0.06255044005229138, 0.051633162001962774, 0.02270586530357832, 0.009785809907043586, 0.03550011089828331, 0.10574302665190771, 0.0693831562239211, 0.0160355737170903, 0.07151084166252986, 0.07841432161512785, 0.056299653006135486, 0.07086884681484662, 0.017817336702137254, 0.006499669516415452, 0.05694420826330315, 0.03898083545209374, 0.05316746326570865, 0.055966729269130155, 0.024340187665075064, 0.06415707845008001, 0.1440529865794815, 0.15885489934589714, 0.10527597085456364, 0.023448038955393713, 0.00478659044347296, 0.06872595477034338, 0.30531008436810225, 0.18679224711377174, 0.15575613593682647, 0.021300476946635172, 0.026691087005019654, 0.04917134312563576, 0.020904541161144152, 0.07680992450332269, 0.26488470670301467, 0.06276777799939737, 0.08106875378871337, 0.025728694017743692, 0.060424083058023825, 0.05939718445006292, 0.006509810964416829, 0.03292903675173875, 0.039410720783052966, 0.05016853356210049, 0.04334816672781017, 0.05867901927558705, 0.0737081553961616, 0.08840752561809495, 0.040906871945480816, 0.04563280897855293, 0.17866338486783206, 0.0845925674366299, 0.08873577753547579, 0.09054216498043388, 0.12087012626579963, 0.06686572451144457, 0.03783061787544284, 0.24598498101113364, 0.24422168266028166, 0.22317774390103295, 0.3650236426619813, 0.21984340797644109, 0.6431406643241644, 0.06709740817314014, 0.797333896625787, 1.611083981115371, 4.4779319409281015, 14.083456937223673, 23.09601567685604, 35.075306072831154, 39.52099911868572, 48.94643135368824, 49.5903941988945, 41.213846281170845, 23.159398175776005, 13.479391001164913, 10.673139933496714, 15.157628897577524, 19.3480658903718, 23.720814250409603, 27.453918233513832, 32.55462773144245, 36.6387739777565, 49.97381642460823, 46.93211004137993, 47.89664648473263, 42.10193082690239, 42.812295109033585, 44.477133974432945, 39.665467366576195, 42.97531396150589, 43.93215961754322, 30.642121955752373, 16.317652501165867, 9.593990240246058, 5.304588507860899, 7.408857643604279, 6.940262988209724, 7.279585255309939, 8.067248314619064, 7.066294150426984, 7.675970485433936, 6.152205700054765, 4.709223629906774, 5.669452529400587, 12.473594471812248, 23.705468773841858, 38.86868432164192, 56.79877080023289, 70.8789874613285, 68.71745824813843, 71.05169579386711, 69.58596244454384, 73.11652779579163, 62.57530063390732, 55.08222810924053, 51.87063284218311, 45.91552399098873, 34.83300067484379, 32.94428162276745, 23.337240032851696, 16.35512799024582, 13.226639963686466, 8.94526245072484, 7.167837526649237, 8.336411621421576, 11.923070512712002, 17.23907645791769, 15.617865901440382, 16.91791009157896, 20.02407431602478, 11.793332174420357, 5.034412555396557, 1.6055264230817556, 0.6646805803757161, 0.3155618452001363, 0.16159064864041284, 0.11306855114526115, 0.08392674964852631, 0.07165085524320602, 0.10864063093322329, 0.03246378437324893, 0.1857077021850273, 0.1698343359748833, 0.2851072809426114, 0.19992496585473418, 0.15772745828144252, 0.21989673870848492, 0.1379922078922391, 0.29400960949715227, 0.15332104550907388, 0.09764636619365774, 0.006935162236914039, 0.0680532498518005, 0.008183482459571678, 0.0600086065242067, 0.06377902842359617, 0.04227121768053621, 0.06404818312148564, 0.08446338921203278, 0.09178072039503604, 0.1492296892683953, 0.07858847398892976, 0.050709102797554806, 0.03394978295546025, 0.026043077050417196, 0.012096478349121753, 0.08074104363913648, 0.06818826877861284, 0.0378109954908723, 0.059005690418416634, 0.039157841383712366, 0.05765036548837088, 0.05591329463641159, 0.06033548175764736, 0.07823376450687647, 0.07443637296091765, 0.13813924218993634, 0.01140261665568687, 0.05865023507794831, 0.03619061622885056, 0.013094589976390125, 0.09089516752283089, 0.10046751442132518, 0.12872266466729343, 0.28730317717418075, 0.21029382274718955, 0.17661986639723182, 0.16992311167996377, 0.17262479639612138, 0.1445290891570039, 0.14977644430473447, 0.24801956402370706, 0.12090167496353388, 0.21586392307654023, 0.24391851533437148, 0.22457546030636877, 0.23535232030553743, 0.1818605125299655, 0.12298046029172838, 0.10017242166213691, 0.17864818568341434, 0.5081681662704796, 0.24534459662390873, 0.22972431761445478, 0.21254284190945327, 0.11859869424370117, 0.1725079823518172, 0.08789283136138692, 0.15700969757745042, 0.2593027171678841, 0.28071554785128683, 0.17761519033228979, 0.08454968614387326, 0.2221348334569484, 0.16661282134009525, 0.13743745250394568, 0.13635615818202496, 0.06672723233350553, 0.18369660072494298, 0.19756864698138088, 0.17210649530170485, 0.18528696382418275, 0.15042050974443555, 0.08513436492648907, 0.16572297143284231, 0.2778707176912576, 0.27882547583431005, 0.17805029667215422, 0.20532011229079217, 0.18286039325175807, 0.16599363269051537, 0.07971071259817109, 0.26576605159789324, 0.41119434172287583, 0.3809667855966836, 0.44989149493630975, 0.3005058359121904, 0.4087763058487326, 0.13216294959420338, 0.22742098808521405, 0.5631878483109176, 1.3372171204537153, 6.613673362880945, 13.949621468782425, 29.089627861976624, 36.41991712152958, 54.11966755986214, 62.07832910120487, 68.82560044527054, 64.08467844128609, 54.18061248958111, 56.698893159627914, 53.068879544734955, 52.74612486362457, 54.90738049149513, 57.33822025358677, 60.710888877511024, 61.81914500892162, 72.99969926476479, 71.67755261063576, 71.528889387846, 72.00743570923805, 70.6747180223465, 68.7317530810833, 70.78764036297798, 70.85260167717934, 63.679532781243324, 42.92714774608612, 22.65871424227953, 11.410725004971027, 7.157346764579415, 8.118862845003605, 7.368018859997392, 9.364739991724491, 7.565623931586742, 5.631661182269454, 7.899039890617132, 7.652785554528236, 6.981234764680266, 8.465014770627022, 14.634323827922344, 26.278101727366447, 44.42596212029457, 64.98972147703171, 85.52109137177467, 85.62756165862083, 96.35209858417511, 91.94682016968727, 92.98258379101753, 80.61275035142899, 77.35905334353447, 63.970266580581665, 63.234679251909256, 45.12204296886921, 57.2970000654459, 48.55762101709843, 42.39559046924114, 41.56357191503048, 45.40053382515907, 46.196021139621735, 48.40450443327427, 38.62066403031349, 39.0524310618639, 33.34517151117325, 30.14335121959448, 20.81925194710493, 6.791353728622198, 1.8915133271366358, 0.526462581474334, 0.4203655949095264, 0.37727103859651834, 0.2328820520779118, 0.19044388085603714, 0.13965610298328102, 0.17153704538941383, 0.093628170870943, 0.16816493414808065, 0.1642729336163029, 0.18234078597743064, 0.30483876122161746, 0.19011643045814708, 0.40598541498184204, 0.4621284711174667, 0.3255690832156688, 0.22930015053134412, 0.347159702796489, 0.31085386814083904, 0.10882069080253132, 0.22980353445746005, 0.13953342597233132, 0.24271101137856022, 0.11512132419738919, 0.10691922681871802, 0.1269694001530297, 0.28296897537074983, 0.19218038767576218, 0.27864875562954694, 0.18041149887721986, 0.18131656281184405, 0.08254369808128104, 0.1478179165860638, 0.12551726948004216, 0.22403872426366434, 0.13809174473863095, 0.14338901673909277, 0.11880012796609662, 0.12694191100308672, 0.06968909918214194, 0.10614078069920652, 0.1322300694300793, 0.12843698234064505, 0.19166002341080457, 0.20290906744776294, 0.09556585908285342, 0.18561000586487353, 0.08703458952368237, 0.20398369728354737, 0.29441615799441934, 0.19071397808147594, 0.1889613369712606], [0.06544489762745798, 0.023471268177672755, 0.014135367673588917, 0.010287595432600938, 0.12738706602249295, 0.035460984872770496, 0.007477314566131099, 0.025164390899590217, 0.08932868673582561, 0.03937145746021997, 0.030760423724132124, 0.03454366808000486, 0.04157569543167483, 0.0491648493334651, 0.03816979420662392, 0.020868960746156517, 0.031153626550803892, 0.012617286975000752, 0.031542508222628385, 0.03582319004635792, 0.052776514712604694, 0.049357533134752885, 0.04124723571294453, 0.030966724079917185, 0.0760226245620288, 0.06684093677904457, 0.06332974706310779, 0.05299451688188128, 0.05308340761985164, 0.013633567305078031, 0.0781122526677791, 0.029099207786202896, 0.05741646280512214, 0.0503362478048075, 0.046040296292630956, 0.1432860066415742, 0.060093682623119093, 0.023980592995940242, 0.04886369322775863, 0.024411743688688148, 0.02058839181700023, 0.03734607707883697, 0.013261071326269303, 0.07273799026734196, 0.13136824301909655, 0.04973621769750025, 0.05175515623704996, 0.044259453570703045, 0.1038098506978713, 0.03387087410374079, 0.12009596233838238, 0.06333480108878575, 0.10576684959232807, 0.19614912627730519, 0.21274774888297543, 0.13344324339414015, 0.09264664346119389, 0.11645991369732656, 0.07723269634880126, 0.7485144131351262, 1.6099898773245513, 3.9383464073762298, 8.46260379999876, 24.521976560354233, 33.98501917719841, 27.17372316867113, 12.199763115495443, 13.093053381890059, 20.76925802975893, 19.08528909087181, 18.84115979075432, 11.479630507528782, 9.654211308807135, 6.854012841358781, 12.492930684238672, 26.651302501559258, 24.60661891847849, 28.548998571932316, 29.308513216674328, 26.115147471427917, 24.78167362511158, 23.84128488600254, 18.84604822844267, 19.265260733664036, 19.713399186730385, 20.58282483369112, 16.747390441596508, 11.919747591018677, 12.015779837965965, 14.624709393829107, 13.302059266716242, 12.326809298247099, 17.78561633080244, 28.293775767087936, 32.403038665652275, 27.640207037329674, 34.229406863451004, 47.40675397217274, 51.39397881925106, 59.02921311557293, 49.2290335893631, 50.66363140940666, 50.839998945593834, 49.23144266009331, 46.41871199011803, 29.771183989942074, 31.093832217156887, 21.746989265084267, 11.790811009705067, 10.636378806084394, 10.339262299239635, 13.364204932004213, 9.518632683902979, 14.205158706754446, 17.80113659799099, 12.28641176596284, 5.622190665453672, 14.59785433486104, 17.565908320248127, 14.955756179988384, 6.227966509759426, 1.7028804053552449, 0.6350558262784034, 0.31898730201646686, 0.06922191721969284, 0.06206695310538635, 0.09541787483613007, 0.033684858499327675, 0.00834394499179325, 0.10307927310350351, 0.017263093395740725, 0.027911600809602533, 0.054573090965277515, 0.0733673018112313, 0.08454164126305841, 0.10310771220247261, 0.06038325380359311, 0.02545765612012474, 0.06870285913464613, 0.07339526593568735, 0.056083736271830276, 0.05023807279940229, 0.09078098068130203, 0.03983664675615728, 0.07355024863500148, 0.02275792881846428, 0.04125316547288094, 0.059211480547674, 0.09678137823357247, 0.004570889859678573, 0.03877308976370841, 0.10714698451920412, 0.06445370745495893, 0.010645159400155535, 0.015142412903514924, 0.03811807764577679, 0.08824973017908633, 0.05844779203471262, 0.07846043867175467, 0.04630067509424407, 0.04984391816833522, 0.03270452965807635, 0.02449479743518168, 0.08294237981317565, 0.10188956584897824, 0.03674573526950553, 0.08290597746963613, 0.03873211579048075, 0.005874602593394229, 0.05767596958321519, 0.062095251196296886, 0.026742501140688546, 0.05463475230499171, 0.022612723914789967, 0.04511585117143113, 0.1844519141013734, 0.1423841339419596, 0.05369328231608961, 0.09450766039662994, 0.06199036717589479, 0.05637138900056016, 0.1267892512260005, 0.06405521125998348, 0.05335697809641715, 0.02501667939213803, 0.08497553790220991, 0.11095026129623875, 0.054792748123873025, 0.06585697512491606, 0.07659640119527467, 0.027755100418289658, 0.04740868302178569, 0.09468823234783486, 0.12340519882855006, 0.203511216386687, 0.13572683179518208, 0.11313036462524906, 0.07335895264986902, 0.04009302538179327, 0.046674283366883174, 0.18342536059208214, 0.22413367463741452, 0.08937545688240789, 0.028165617550257593, 0.022842273901915178, 0.030270229617599398, 0.05880368153157178, 0.027246948193351272, 0.03335830981086474, 0.030737393026356585, 0.026803043692780193, 0.02265156050270889, 0.08118204263155349, 0.08747931409743614, 0.02861335153284017, 0.07515099438023753, 0.052827800827799365, 0.03330022933369037, 0.08711857095477171, 0.1066605735104531, 0.030957844282966107, 0.04136956391448621, 0.06636992533458397, 0.0759801737149246, 0.02538304430345306, 0.06827726712799631, 0.04739385491120629, 0.10981154700857587, 0.12856751127401367, 0.2753654052503407, 0.25880292523652315, 0.26530298113357276, 0.15472582716029137, 0.21620960062136874, 0.7801976474002004, 3.0037827556952834, 8.342150263488293, 16.368092894554138, 28.71286477893591, 43.50989207625389, 49.36032794415951, 37.25036256015301, 25.575395934283733, 26.83977998793125, 19.13107853382826, 14.11243038251996, 14.588119257241488, 24.32775378227234, 29.53807219862938, 33.188148736953735, 38.58879894018173, 38.71933713555336, 43.329945132136345, 51.9752412289381, 50.25611847639084, 46.72229290008545, 48.7912704795599, 43.37626464664936, 36.160163059830666, 38.74422959983349, 38.364740163087845, 32.60165020823479, 24.579680263996124, 19.76873181760311, 18.166994266211987, 19.749989323318005, 21.111241579055786, 21.961521953344345, 29.056750126183033, 36.67356111109257, 37.34277360141277, 34.58575174212456, 41.33787162601948, 53.1579315662384, 62.75977313518524, 70.34016877412796, 68.48306402564049, 65.98129346966743, 71.13891631364822, 75.45537829399109, 67.24133625626564, 51.40239916741848, 46.53864495456219, 39.90842252969742, 37.009535282850266, 30.174629241228104, 25.920597910881042, 18.14405109733343, 14.195371381938457, 15.095399636775255, 16.556657776236534, 20.223913192749023, 20.077645741403103, 22.158098705112934, 20.846705473959446, 18.60314056277275, 13.267852552235126, 6.671205125749111, 2.025028900243342, 0.7593697775155306, 0.25692000752314925, 0.09651339612901211, 0.04982501195627265, 0.05677275359630585, 0.07742679765215144, 0.07608552899910137, 0.025097373109019827, 0.10936294842395, 0.11925532424356788, 0.11322896636556834, 0.12034228857373819, 0.18530955479945987, 0.0609865716251079, 0.11183960654307157, 0.09456520652747713, 0.15240029257256538, 0.06466157559771091, 0.0645661873568315, 0.10828532031155191, 0.03331362138851546, 0.15421202348079532, 0.05544669154915027, 0.033523775346111506, 0.04788143480254803, 0.029433784657157958, 0.11033964445232414, 0.06791517327656038, 0.08509397724992596, 0.03090346341195982, 0.09426497810636647, 0.07292435097042471, 0.05381549919547979, 0.012962084147147834, 0.030496825856971554, 0.02832706435583532, 0.053593222255585715, 0.07325456957914867, 0.03166129637975246, 0.06500026953290217, 0.009646835333114723, 0.03194529403117485, 0.05408541459473781, 0.010147207995032659, 0.07222563377581537, 0.059899091502302326, 0.020117100211791694, 0.031138560952967964, 0.04762515636684839, 0.06824569616583176, 0.0227832434757147, 0.01148282055510208, 0.04257541288097855, 0.16737131110858172, 0.08772970730205998, 0.17989833344472572, 0.2981138345785439, 0.1797575777163729, 0.23315542959608138, 0.12767987296683714, 0.12226197970448993, 0.19410565233556554, 0.14027472760062665, 0.15552203287370503, 0.12526298000011593, 0.1771745624137111, 0.21764265809906647, 0.16126463800901547, 0.08709054745850153, 0.13270483614178374, 0.23168001032900065, 0.31111323391087353, 0.2503416402032599, 0.1723652525106445, 0.1633192293229513, 0.21602070919470862, 0.15925742540275678, 0.2902945369714871, 0.22535706055350602, 0.17055450123734772, 0.21144050027942285, 0.14888904348481447, 0.11947149701882154, 0.09819430866627954, 0.18675754428841174, 0.24314478185260668, 0.18685926304897293, 0.1714761892799288, 0.12767307489411905, 0.1727924178703688, 0.22075601213146, 0.1892627973575145, 0.13966310885734856, 0.16420369123807177, 0.0997292333340738, 0.3070380416465923, 0.3238812612835318, 0.1548206587904133, 0.08911336000892334, 0.10054798549390398, 0.1643435563892126, 0.2128444507252425, 0.17949350673006848, 0.15918750024866313, 0.22594640002353117, 0.20446397073101252, 0.4373952420428395, 0.4520620097173378, 0.48403616587165743, 0.3914523823186755, 0.26265983702614903, 0.2531208941945806, 1.0389283765107393, 3.130457033403218, 9.754307437688112, 19.947027750313282, 45.65300367772579, 58.37630175054073, 57.54282407462597, 48.481051325798035, 50.95605991780758, 58.94456505775452, 51.530824676156044, 50.73833540081978, 57.734288200736046, 52.25637674331665, 54.20182675123215, 59.811515137553215, 59.13710832595825, 65.46962812542915, 69.22357589006424, 73.28083857893944, 69.11053955554962, 73.37521031498909, 75.09045347571373, 71.96731746196747, 67.22942009568214, 55.335807502269745, 43.70207816362381, 27.683110535144806, 24.264840558171272, 26.629389077425003, 28.278536684811115, 25.09715549647808, 23.932554088532925, 32.822372764348984, 44.66157227754593, 47.21104547381401, 41.71161577105522, 46.98711208999157, 60.78515589237213, 74.64431941509247, 92.41658136248589, 94.670240432024, 95.71133136749268, 98.03048372268677, 101.54800057411194, 95.0037257373333, 80.4624456167221, 74.70827758312225, 63.420580476522446, 50.840230733156204, 52.3180740326643, 49.4796871393919, 48.828098103404045, 43.641695603728294, 51.15750230848789, 49.68522571027279, 41.146677285432816, 34.79664422571659, 39.053396210074425, 32.968383729457855, 23.987949416041374, 10.322869028896093, 2.919818186201155, 0.9955953236203641, 0.5334215518087149, 0.17589743016287684, 0.1279064654954709, 0.18249783926876262, 0.18733397038886324, 0.20530428970232606, 0.16424744826508686, 0.1265764923300594, 0.1600822334876284, 0.22689302422804758, 0.17208412697073072, 0.17709908599499613, 0.23064121138304472, 0.16061419009929523, 0.2075623779091984, 0.21826441457960755, 0.2017444299417548, 0.2022792215575464, 0.12239861651323736, 0.20407377916853875, 0.12867552344687283, 0.16223458049353212, 0.1314931019442156, 0.09241711944923736, 0.12268385355127975, 0.16533963731490076, 0.14265011966926977, 0.10195361319347285, 0.15486125426832587, 0.15179565001744777, 0.14311954291770235, 0.21208652498899028, 0.1239849571720697, 0.17110042506828904, 0.10534901302889921, 0.12109296352718957, 0.21442032710183412, 0.135278366797138, 0.1072534901322797, 0.09812514050281607, 0.34336667507886887, 0.17396882583852857, 0.1056119411077816, 0.12168887100415304, 0.13561616273364052, 0.1123244887276087, 0.13574197160778567, 0.14232020534109324, 0.0655666617967654, 0.14014066604431719, 0.08440664460067637, 0.289649105980061, 0.3580138203687966], [0.03194830715074204, 0.03136554310913198, 0.053128660074435174, 0.08545246426365338, 0.06568313445313834, 0.0844256732671056, 0.05213750700931996, 0.0636948095052503, 0.0750978417636361, 0.07041287870379165, 0.04373290721559897, 0.04676647666201461, 0.010398219965281896, 0.040136734169209376, 0.03463172761257738, 0.020565570775943343, 0.062359262810787186, 0.0022933068248676136, 0.015485945641557919, 0.049508278170833364, 0.09933801018632948, 0.018303189244761597, 0.032275913399644196, 0.053104287944734097, 0.028664864003076218, 0.07706033997237682, 0.04751968976052012, 0.07124049952835776, 0.11371513988706283, 0.0953730491164606, 0.1045359308773186, 0.009114188524108613, 0.022454791178461164, 0.0968519935850054, 0.08928795767133124, 0.0665928516536951, 0.12248289480339736, 0.07450580087606795, 0.06205128265719395, 0.02695966282772133, 0.03462806511379313, 0.07606468949234113, 0.057940649130614474, 0.027405623077356722, 0.026541661136434413, 0.07041206234134734, 0.06726920793880709, 0.08139152123476379, 0.08936474769143388, 0.04785714430909138, 0.030266060603025835, 0.04496145476878155, 0.09922791999997571, 0.14251446991693228, 0.10110383183928207, 0.17603355488972738, 0.03735082682396751, 0.10948869792628102, 0.0006586065478586534, 0.0684201528201811, 0.1931822721962817, 0.6054772040806711, 2.6501369196921587, 8.499607164412737, 16.960688196122646, 22.871964499354362, 17.729829624295235, 16.114557199180126, 29.18585579842329, 28.556396774947643, 19.31826788932085, 29.70981728285551, 19.997110962867737, 22.418143451213837, 18.601584546267986, 17.301746495068073, 24.836869463324547, 19.705567806959152, 26.338674277067184, 29.071529433131218, 28.888411559164524, 29.658111557364464, 27.81519904732704, 23.925300277769566, 33.20048287510872, 30.516489297151566, 29.990512020885944, 30.302055403590202, 29.13212478160858, 33.73522438108921, 33.04754488170147, 35.684238597750664, 39.36462990939617, 67.92312607169151, 77.00889453291893, 57.77214176952839, 67.66745299100876, 80.17359271645546, 71.81731671094894, 59.628684148192406, 41.980683133006096, 41.38381876051426, 40.797555819153786, 37.65217959880829, 36.279400661587715, 29.259303957223892, 23.99918731302023, 20.122424438595772, 13.951916545629501, 25.459355860948563, 21.172767877578735, 14.148382153362036, 12.00223546475172, 18.605036661028862, 12.236439697444439, 13.222263548523188, 11.93119827657938, 14.531157463788986, 6.885129846632481, 1.792935454286635, 0.4254868294810876, 0.20488622307311743, 0.09096332636545412, 0.023140338962548412, 0.037152858931222, 0.052309028469608165, 0.041270676447311416, 0.03949177815229632, 0.02450992054946255, 0.03053691667446401, 0.05132387195772026, 0.08375081612030044, 0.04966967673681211, 0.03507088236801792, 0.05227272631600499, 0.009135227483056951, 0.07162128807976842, 0.05028881714679301, 0.07278590332134627, 0.07959656286402605, 0.024293348869832698, 0.06359392937156372, 0.08450183246168308, 0.022161336710269097, 0.045633870249730535, 0.03891030544764362, 0.06100097300077323, 0.04901812302705366, 0.04709499204182066, 0.047049839777173474, 0.04373819501779508, 0.08078805869445205, 0.17921163904247805, 0.033499432902317494, 0.046262224423117004, 0.04983725739293732, 0.011413504889787873, 0.029328457203519065, 0.015033387699077139, 0.12273980406462215, 0.007038598141662078, 0.016492781214765273, 0.0609591492684558, 0.02154552668798715, 0.05199454339162912, 0.02656156924786046, 0.12938549160026014, 0.005586585748460493, 0.06321976819890551, 0.08185462138499133, 0.06779864124837331, 0.11069018306443468, 0.06282824819209054, 0.057247193763032556, 0.06939969869563356, 0.05626906538964249, 0.031566802426823415, 0.041106112621491775, 0.050963425674126484, 0.05947304678556975, 0.11092992644989863, 0.20415795355802402, 0.043168637494090945, 0.04797719040652737, 0.023682698629272636, 0.08177294803317636, 0.0964566960465163, 0.15571925119729713, 0.06342468259390444, 0.05490617055329494, 0.06093185307690874, 0.0545353379129665, 0.05095533997518942, 0.04430918117577676, 0.06381058454280719, 0.2067024217103608, 0.05813760399178136, 0.02784400414384436, 0.07162268331740052, 0.03424019647354726, 0.19867272523697466, 0.15814384765690193, 0.13692143722437322, 0.015489012566831661, 0.026050799096992705, 0.03540444806276355, 0.04718948228401132, 0.07067291240673512, 0.04750963365950156, 0.051818954962072894, 0.041984570561908185, 0.018430003729008604, 0.03941817565646488, 0.03103202750935452, 0.02393461694737198, 0.042693919021985494, 0.012602863334905123, 0.10409277223516256, 0.06110434675065335, 0.015972784312907606, 0.055316132929874584, 0.025715637784742285, 0.0424737497814931, 0.051105131351505406, 0.033099504362326115, 0.029209348067524843, 0.029291910141182598, 0.1799826859496534, 0.1258798679918982, 0.17763518379069865, 0.08560277885408141, 0.23855945211835206, 0.09512102318694815, 0.05270230736641679, 0.013488846652762732, 0.39422694593667984, 0.7017996010836214, 2.4023491283878684, 8.574151564389467, 20.012570433318615, 34.674818962812424, 36.62694901227951, 30.911065824329853, 30.692286863923073, 38.34280773997307, 31.598524935543537, 30.322606600821018, 24.47470899671316, 25.512773394584656, 22.195539996027946, 26.82084560394287, 35.70071831345558, 39.130513072013855, 47.46393330395222, 58.7745051831007, 60.982277914881706, 57.53664180636406, 55.06742410361767, 50.44186390936375, 42.9628886282444, 49.897303730249405, 50.81533066928387, 45.22893503308296, 45.19058749079704, 47.15101629495621, 54.88601043820381, 59.1453804820776, 58.176964446902275, 59.547391310334206, 84.5510034263134, 85.7763160765171, 71.87405526638031, 87.1478220820427, 100.53084075450897, 81.27369448542595, 78.09458747506142, 65.47994077205658, 62.048208117485046, 67.79473096132278, 66.42599880695343, 66.41552656888962, 50.249058455228806, 45.81349566578865, 33.71216721832752, 27.456992268562317, 23.99785738438368, 19.975885301828384, 20.252660550177097, 19.27919838577509, 28.831878192722797, 29.060380831360817, 24.480725973844528, 18.977295085787773, 21.752761155366898, 16.116219609975815, 8.210584223270416, 2.3937136167660356, 0.5869616288691759, 0.25054424651898444, 0.06910635740496218, 0.08542489347746596, 0.07169096090365201, 0.017154890119854826, 0.028495776787167415, 0.033883379292092286, 0.04896451398963109, 0.03338078946399037, 0.0170697101202677, 0.07446788455126807, 0.07938214897876605, 0.039641862676944584, 0.06756062706699595, 0.052850647844024934, 0.1371578112593852, 0.15471796039491892, 0.1310442658723332, 0.01658337703702273, 0.015864621855143923, 0.04266963595000561, 0.06832287210272625, 0.024807048648654018, 0.0518713839846896, 0.06710054745781235, 0.03326314050354995, 0.05491173666086979, 0.03897198534104973, 0.051145307515980676, 0.03583857847843319, 0.03672393097076565, 0.024951090235845186, 0.08192442779545672, 0.019359022335265763, 0.060115327360108495, 0.05822888444527052, 0.02713844063691795, 0.06806159901316278, 0.013553710359701654, 0.03833872557152063, 0.04165644852037076, 0.05268844775855541, 0.03988012176705524, 0.08344058354850858, 0.12258904418558814, 0.04022665278171189, 0.016449315480713267, 0.17031248687999323, 0.01370300449707429, 0.0850028489367105, 0.11366866659955122, 0.10928124538622797, 0.03663718875031918, 0.03395956817257684, 0.17370254325214773, 0.1356191758532077, 0.19081609760178253, 0.15694236994022503, 0.16000334318960086, 0.2570761553943157, 0.10646571521647274, 0.1483572946744971, 0.20040552131831646, 0.15314092626795173, 0.15252819430315867, 0.27052903664298356, 0.10999136939062737, 0.1006761024473235, 0.0990992909646593, 0.12098595325369388, 0.15195445477729663, 0.1428413117537275, 0.20375749067170545, 0.352155098807998, 0.24272454815218225, 0.14653753372840583, 0.1241140092315618, 0.13137648085830733, 0.2708749665180221, 0.14843038137769327, 0.15793281054357067, 0.15816139202797785, 0.13115083827869967, 0.17118002782808617, 0.18524659099057317, 0.16923940071137622, 0.13070829561911523, 0.14866111509036273, 0.22959663852816448, 0.14421691215829924, 0.1971137401415035, 0.1769490831065923, 0.12870154314441606, 0.18068698409479111, 0.09999940477428026, 0.28984518139623106, 0.14562823955202475, 0.10747303225798532, 0.17785183154046535, 0.15573715179925784, 0.1693843273096718, 0.1420120953116566, 0.2627759682945907, 0.2155176072847098, 0.12850671453634277, 0.39477070269640535, 0.20561772835208103, 0.15444778895471245, 0.16638373519526795, 0.22168314753798768, 0.15112295252038166, 0.28813491691835225, 0.11257150516030379, 0.22433203586842865, 0.28107700345572084, 1.1609785398468375, 5.5999647080898285, 14.213040433824062, 29.385987259447575, 37.643352672457695, 46.74035333096981, 41.88179723918438, 57.37421192228794, 67.02866926789284, 61.81840404868126, 71.40981897711754, 66.22382685542107, 63.92355188727379, 62.49110095202923, 54.648618176579475, 60.219480246305466, 62.46024660766125, 73.6125835776329, 81.24486163258553, 80.6378898024559, 74.93860602378845, 71.75928622484207, 72.0822536945343, 82.04314559698105, 74.6939979493618, 70.09893491864204, 68.15384969115257, 66.31639748811722, 66.37737661600113, 73.765988945961, 67.22726941108704, 69.13005530834198, 91.77352666854858, 96.2064827978611, 85.20483434200287, 96.88944295048714, 113.53027001023293, 102.27703705430031, 95.50823986530304, 79.1871352493763, 75.80453395843506, 86.43776938319206, 83.54557737708092, 91.61048501729965, 77.73172974586487, 73.87192726135254, 61.66274160146713, 55.887621492147446, 64.55310970544815, 57.87249058485031, 51.19925446808338, 46.327273696660995, 52.11233787238598, 37.28399835526943, 32.37626910209656, 29.42774511873722, 22.24909622222185, 11.052579972893, 3.8876780262216926, 0.9050214244052768, 0.3065091575263068, 0.22460484935436398, 0.10799119976582006, 0.23219783644890413, 0.17198021145304665, 0.09647177648730576, 0.15528908756095916, 0.23765704507241026, 0.11131230319733731, 0.19925997185055166, 0.11064745762269013, 0.3231597749982029, 0.1831506917369552, 0.11265115244896151, 0.14123650646070018, 0.0981635763309896, 0.4268261685501784, 0.2171927088056691, 0.22221390187041834, 0.08841855393256992, 0.18506519525544718, 0.16252885689027607, 0.1280913790105842, 0.09638569477829151, 0.10984608656144701, 0.13426796242129058, 0.19743549084523693, 0.15935371164232492, 0.1372539935982786, 0.13328092085430399, 0.1858679615543224, 0.17507294862298295, 0.19124777521938086, 0.15588903974276036, 0.08684701911988668, 0.13200306129874662, 0.1494192486279644, 0.18871209409553558, 0.17303744534729049, 0.08475143898976967, 0.1254280484863557, 0.13890553935198113, 0.12665002432186157, 0.17841276159742847, 0.2025334516656585, 0.19983819394838065, 0.13752452126936987, 0.0889363132591825, 0.20311732892878354, 0.1161756859801244, 0.16321261238772422, 0.2443585792207159, 0.15648467262508348, 0.1714971030014567, 0.19433450099313632], [0.13257500482723117, 0.0645117879321333, 0.03995618819317315, 0.09385470402776264, 0.03622335978434421, 0.030585577442252543, 0.030913784830772784, 0.026398775444249623, 0.03624765027780086, 0.06933030046639033, 0.04828889614145737, 0.09632745845010504, 0.07988951081642881, 0.09379329130752012, 0.07149919736548327, 0.04197635127638932, 0.0421816515881801, 0.01739917730446905, 0.06467344253906049, 0.06387233865098096, 0.04446760372957215, 0.037722672495874576, 0.05158602820301894, 0.05000165052479133, 0.005574609340328607, 0.034367723419563845, 0.008384556240343954, 0.06527242250740528, 0.07109743572073057, 0.08080157320364378, 0.07747384239337407, 0.10643884204910137, 0.04849432261835318, 0.06634560515522026, 0.05588252519373782, 0.054062237322796136, 0.024902340410335455, 0.027683670559781604, 0.035587365200626664, 0.028204982918396126, 0.04178863615379669, 0.05498979204276111, 0.022236119220906403, 0.0068589441343647195, 0.04439963784534484, 0.056855480797821656, 0.10543159922235645, 0.02659511061210651, 0.03583334262657445, 0.11218720625038259, 0.1113279105629772, 0.05766334565123543, 0.04111729307624046, 0.03590356463973876, 0.12775564624462277, 0.05678315479599405, 0.08173233771231025, 0.08966952547780238, 0.058884920726995915, 0.07739386113826185, 0.012714095500996336, 0.0336498847900657, 0.1528726250398904, 0.5176578008104116, 3.1755886366590858, 7.22970818169415, 18.772313185036182, 19.75612599402666, 25.495681911706924, 28.268358930945396, 26.974668949842453, 31.260987147688866, 45.036528557538986, 33.52653957903385, 26.6015612706542, 26.644274778664112, 33.06816257536411, 36.76537558436394, 23.22946261614561, 33.49522165954113, 28.302321508526802, 28.235901072621346, 22.033991664648056, 28.72384998947382, 28.55129934847355, 31.447256952524185, 39.25353527069092, 35.874764174222946, 50.45094162225723, 65.79734534025192, 74.83335927128792, 75.06114944815636, 55.29192365705967, 78.15017849206924, 126.22168779373169, 64.72075670957565, 49.10148583352566, 41.54083773493767, 44.19835053384304, 38.23363579809666, 26.85876376926899, 31.032106429338455, 36.915627121925354, 37.94481709599495, 32.23238222301006, 32.42128528654575, 31.831640526652336, 34.228833094239235, 30.71991328150034, 32.79184900224209, 18.14255017787218, 17.51204051077366, 26.741889640688896, 19.723939821124077, 13.051183428615332, 6.380873154848814, 5.005772542208433, 2.0527894981205463, 0.41852091264445335, 0.021864848713448737, 0.03752453761990182, 0.0671073752164375, 0.08340343905729242, 0.03334558568894863, 0.07605910112033598, 0.06176652430440299, 0.04763275966979563, 0.01670151210419135, 0.08533361673471518, 0.07068348058965057, 0.047281419538194314, 0.036453429274843074, 0.022899777359270956, 0.04059162987687159, 0.0681402963527944, 0.022258417047851253, 0.08837755769491196, 0.06476059294072911, 0.07296353636775166, 0.0996435152774211, 0.0734492126503028, 0.038450303763966076, 0.06615773047087714, 0.03223582258215174, 0.026065955607919022, 0.0630453041230794, 0.04063898260938004, 0.03449817442742642, 0.06380944163538516, 0.05973005994746927, 0.06010737153701484, 0.017096336523536593, 0.07620203134138137, 0.05261959129711613, 0.034307212408748455, 0.06763018114725128, 0.057996707255369984, 0.07043139528832398, 0.06402473867638037, 0.03281611527199857, 0.009372201730002416, 0.058519969607004896, 0.049582838037167676, 0.05060610012151301, 0.07206938942545094, 0.04860503620875534, 0.0693872306146659, 0.03027322603884386, 0.01308412476646481, 0.14095658320002258, 0.033449905677116476, 0.08716214244486764, 0.012034337396471528, 0.12031506659695879, 0.05672783881891519, 0.13857001438736916, 0.10069326832308434, 0.017262612855120096, 0.04619653322151862, 0.042480711126700044, 0.02824540399160469, 0.054151024160091765, 0.055410994245903566, 0.0799234195437748, 0.01720743046462303, 0.03900371586496476, 0.08287696691695601, 0.09565024127368815, 0.12032927872496657, 0.16932137834373862, 0.042728395492304116, 0.03070843256864464, 0.04457288479898125, 0.05679329624399543, 0.23008323507383466, 0.09307324478868395, 0.08787855986156501, 0.05963780356978532, 0.042893838763120584, 0.07839380865334533, 0.03173572265950497, 0.12674322322709486, 0.12666672264458612, 0.16103210829896852, 0.016518235024705064, 0.0751151486474555, 0.08800102164968848, 0.10156270916922949, 0.0774976504908409, 0.06102737119363155, 0.029409933886199724, 0.00722222403055639, 0.011056767489208141, 0.026288664848834742, 0.026494211924728006, 0.02313230335857952, 0.03272930996899959, 0.05627357022603974, 0.045901989651611075, 0.057199959774152376, 0.10432452269014902, 0.045987288394826464, 0.12195971779874526, 0.0687312833906617, 0.05485023859364446, 0.055805230513215065, 0.008977753022918478, 0.01885546214907663, 0.049320663238177076, 0.11420143215218559, 0.20471483148867264, 0.1748044989653863, 0.11705079683451913, 0.1013008868903853, 0.05128496115503367, 0.0267355843243422, 0.11485885625006631, 0.0871859431208577, 0.2576366253197193, 4.079317655414343, 10.101792141795158, 17.87006299942732, 23.10985643416643, 27.199535183608532, 40.734897181391716, 46.79784044623375, 40.731196179986, 45.30446358025074, 42.4512080848217, 44.21161562204361, 34.78561721742153, 35.08483216166496, 38.59024666249752, 38.19125287234783, 48.34585838019848, 53.916021287441254, 55.36413878202438, 55.92483289539814, 50.48474460840225, 63.60428921878338, 62.44676113128662, 58.1702122092247, 72.65175953507423, 66.7445433139801, 84.59356874227524, 99.28954616189003, 106.17141768336296, 94.55313831567764, 69.53828260302544, 98.003930747509, 136.87657445669174, 77.42320150136948, 74.53506007790565, 76.21004819869995, 79.92161303758621, 65.95355495810509, 53.30397292971611, 56.1223728954792, 54.68565098941326, 59.258466213941574, 57.49343432486057, 48.39419178664684, 41.93324267864227, 34.35240626335144, 31.803309246897697, 41.96703426539898, 34.86152574419975, 30.3656392917037, 31.982218846678734, 32.30870872735977, 22.735511921346188, 16.445215456187725, 10.495692305266857, 7.080754274502397, 2.568335859104991, 0.4990731761790812, 0.23576591920573264, 0.11518709332449362, 0.07750928736641072, 0.06188286337419413, 0.042354995021014474, 0.09339647236629389, 0.04020252927148249, 0.014313637111627031, 0.00801088395746774, 0.07294995506526902, 0.01826904117478989, 0.04922631400404498, 0.027267129044048488, 0.059619197927531786, 0.059658212630893104, 0.104325190623058, 0.06662222585873678, 0.01898347520182142, 0.059054278826806694, 0.05649019942211453, 0.1035608453094028, 0.051399207368376665, 0.008783010689512594, 0.09909142419928685, 0.031672621553298086, 0.10621747424011119, 0.04055745026562363, 0.04069201277161483, 0.09713815088616684, 0.022050296574889217, 0.056251888381666504, 0.03510986738547217, 0.10360352622228675, 0.07839637648430653, 0.03892174194334075, 0.028271262272028252, 0.008561642880522413, 0.035890269064111635, 0.06884027519845404, 0.1049662874720525, 0.04270920355338603, 0.03758045844733715, 0.10165092084207572, 0.08438803153694607, 0.024502526903233957, 0.10450931004015729, 0.12361467743176036, 0.12532661174191162, 0.04484410266741179, 0.1609634596388787, 0.019072729592153337, 0.017803315677156206, 0.024718341592233628, 0.036015881269122474, 0.03100263660599012, 0.12452814989956096, 0.23220862727612257, 0.19089359266217798, 0.23779116600053385, 0.2669817488640547, 0.21127163199707866, 0.14139097707811743, 0.17393916961736977, 0.09634980451664887, 0.12675603269599378, 0.10086031092214398, 0.13692694396013394, 0.3341695060953498, 0.1728953092242591, 0.25727531814482063, 0.19426082057179883, 0.10200119970249943, 0.20826430118177086, 0.13947853673016652, 0.23709666420472786, 0.12689233553828672, 0.10644860129104927, 0.20318835246143863, 0.17473463318310678, 0.22274081187788397, 0.0994464750692714, 0.15785017982125282, 0.11789034397224896, 0.2203014912083745, 0.15305842913221568, 0.13762376125669107, 0.21167202066862956, 0.17370111832860857, 0.18539491662522778, 0.185515352350194, 0.2063163268030621, 0.2777857566252351, 0.14389533957000822, 0.07789304450852796, 0.1472867318079807, 0.17570841999258846, 0.22660262184217572, 0.3279846551595256, 0.13288934889715165, 0.1482873546774499, 0.19015617988770828, 0.13383756129769608, 0.27206816186662763, 0.1320940931327641, 0.29050411947537214, 0.21315915102604777, 0.2610858605476096, 0.1002682997204829, 0.16604902659310028, 0.13053653296083212, 0.3203080577077344, 0.22924891265574843, 0.1746535164420493, 0.22323916404275224, 0.1886472452315502, 0.09966074052499607, 0.13702245836611837, 0.08631485470687039, 0.18641013011801988, 1.4650711161084473, 4.530452247709036, 11.776004154235125, 26.59849863499403, 38.10224264860153, 47.87675455212593, 61.57864071428776, 61.496504321694374, 69.18747022747993, 84.22826394438744, 79.7248899936676, 69.58840191364288, 70.61213538050652, 74.37837168574333, 80.2161580324173, 69.23454970121384, 75.3647455573082, 72.1991354227066, 75.18884539604187, 64.07351464033127, 80.97356379032135, 77.16539293527603, 78.1119753420353, 89.00390848517418, 79.20851290225983, 89.84165713191032, 100.30161425471306, 101.40426948666573, 98.1134332716465, 77.12250843644142, 112.84707427024841, 147.797811627388, 89.71873372793198, 80.05267560482025, 72.9191891849041, 77.74262756109238, 73.60308408737183, 64.74219515919685, 74.2824724316597, 76.59875974059105, 83.86929720640182, 82.39517390727997, 78.23543831706047, 76.356902718544, 72.43924453854561, 75.28935000300407, 73.79413783550262, 54.06258702278137, 51.36544615030289, 52.251186221838, 37.89168454706669, 24.851033203303814, 15.017059240490198, 7.417030055075884, 3.0057263514027, 0.9674451872706413, 0.3179846308194101, 0.22267584427027032, 0.17614400130696595, 0.2563284267671406, 0.1942083062021993, 0.11978457943769172, 0.18841435929061845, 0.11059578187996522, 0.11994702072115615, 0.11275918688625097, 0.17882368876598775, 0.07058019589749165, 0.1060572148708161, 0.14618268323829398, 0.2100823848741129, 0.08613051264546812, 0.20180141204036772, 0.16181384213268757, 0.19009591749636456, 0.09914868831401691, 0.2065576583845541, 0.19239323562942445, 0.1329177137813531, 0.10223180725006387, 0.21134793962119147, 0.04061133389768656, 0.1607202726881951, 0.10638045729137957, 0.19109579821815714, 0.11893455317476764, 0.11226791481021792, 0.13606842752778903, 0.097932783246506, 0.28681914845947176, 0.16404521302320063, 0.13210393401095644, 0.13025680265855044, 0.11563610009034164, 0.18535993178375065, 0.12064475085935555, 0.14219963602954522, 0.12938834144733846, 0.2009243270731531, 0.14913347724359483, 0.09683605225291103, 0.18338492838665843, 0.24056089081568643, 0.21117541997227818, 0.20887881430098787, 0.10449812587467022, 0.38833545113448054, 0.0894904971937649, 0.14772704802453518, 0.22337668400723487, 0.2578103472478688, 0.2704237407306209, 0.18958478554850444], [0.054662946495227516, 0.0012077986116310058, 0.03761760293855332, 0.03725893038790673, 0.09535570512525737, 0.1286823660484515, 0.03332339176267851, 0.015314016000047559, 0.056428582611260936, 0.06343309854855761, 0.03028750310477335, 0.08518868271494284, 0.04733154048153665, 0.11642440935247578, 0.050591119870659895, 0.06177193085022736, 0.06657181918853894, 0.05523156149138231, 0.032334450297639705, 0.03724686677742284, 0.052270010055508465, 0.020576363458530977, 0.015267761646100553, 0.009280553913413314, 0.04279663597117178, 0.1363966497592628, 0.08787092316197231, 0.021795886495965533, 0.08780237098108046, 0.010336018713132944, 0.0702277128584683, 0.031290879342122935, 0.05375425345846452, 0.04665320637286641, 0.031103581677598413, 0.0813477642077487, 0.040679811863810755, 0.046511281761922874, 0.05524483851331752, 0.06246439545066096, 0.0428580041625537, 0.019088837907474954, 0.08229225844843313, 0.0294557299639564, 0.029687910864595324, 0.04741643104352988, 0.029096233629388735, 0.07730846962658688, 0.019196562498109415, 0.014760707799723605, 0.03088960194872925, 0.058127599841100164, 0.0242995458029327, 0.07693630483117886, 0.04611055912391748, 0.013384750236582477, 0.0929993120371364, 0.004415659004735062, 0.1082461497571785, 0.04934888340358157, 0.1602419585105963, 0.10839823065907694, 0.043426567208371125, 0.04040639723825734, 0.08074842058704235, 0.17400243028532714, 1.3090533879585564, 4.384664995595813, 11.176943499594927, 20.252538956701756, 25.825019739568233, 37.375026270747185, 43.187958151102066, 45.56559696793556, 39.97466817498207, 40.93592159450054, 42.54595220088959, 42.644496113061905, 44.405086040496826, 49.98064085841179, 48.73817212879658, 36.210601553320885, 42.60329492390156, 46.02820694446564, 50.67593514919281, 58.91909882426262, 62.93498933315277, 59.505749344825745, 51.22292339801788, 47.80433803796768, 26.664778478443623, 40.00859275460243, 55.81008665263653, 32.8619210422039, 87.11676254868507, 44.35397118330002, 42.75235332548618, 51.20344564318657, 51.37983217835426, 50.24102568626404, 41.01099796593189, 43.53703022003174, 45.24837478995323, 45.65527215600014, 44.57358039915562, 45.77325962483883, 45.86141109466553, 41.14019863307476, 44.98047396540642, 26.165774054825306, 16.11518606543541, 16.526534892618656, 17.94394813477993, 8.253595065325499, 2.594379661604762, 0.8674436970613897, 0.3613388497615233, 0.03449928764894139, 0.13450513797579333, 0.09676873945863917, 0.09118916190345772, 0.05721314773836639, 0.021195763620198704, 0.06468714258517139, 0.04150529159232974, 0.020248133805580437, 0.007038050807750551, 0.04482154137804173, 0.06078871505451389, 0.049341595513396896, 0.0355470777139999, 0.10581652153632604, 0.05208548245718703, 0.02056112716672942, 0.026255694938299712, 0.01229677751325653, 0.03462387940089684, 0.012085346133972052, 0.03288159867224749, 0.0450866439496167, 0.0260727110071457, 0.018095395316777285, 0.12449238580302335, 0.07187199298641644, 0.011876541957462905, 0.0505648701073369, 0.05094186257338151, 0.024861622478056233, 0.022947942743485328, 0.010866019765671808, 0.04090985908987932, 0.04431949331774376, 0.0967035120993387, 0.032733050393289886, 0.09755962397321127, 0.041466028269496746, 0.10672827222151682, 0.021655991658917628, 0.004039670757265412, 0.06778462950023822, 0.026018170574388932, 0.08262234347057529, 0.03795893891947344, 0.10599704153719358, 0.03555622468411457, 0.061387746973196045, 0.05366302495531272, 0.02816086409438867, 0.06720533870975487, 0.07721327434410341, 0.050899485941044986, 0.044158213495393284, 0.018213920011476148, 0.06451983281294815, 0.17441219970351085, 0.05354399931093212, 0.029163158651499543, 0.05473918732604943, 0.05956196349870879, 0.024035003552853595, 0.08206256374251097, 0.04748152110551018, 0.0539004602615023, 0.05965883974567987, 0.1272912696003914, 0.08202700744732283, 0.0691228182404302, 0.09937935523339547, 0.12617071566637605, 0.12699326762231067, 0.05182473258173559, 0.05251383896393236, 0.04710063978563994, 0.0684539279609453, 0.030313823372125626, 0.08060547552304342, 0.1682212928426452, 0.04369013724499382, 0.015217689870041795, 0.09325429171440192, 0.16367456963052973, 0.11685855090036057, 0.042156259005423635, 0.027463864971650764, 0.03263837090344168, 0.0566046719904989, 0.043040212549385615, 0.011219724565307843, 0.03219209153030533, 0.02619518021674594, 0.04505433826125227, 0.08724391227588058, 0.012530429721664404, 0.03328571663587354, 0.08179348325938918, 0.09754654733114876, 0.019991489862150047, 0.07970965132699348, 0.03381708695087582, 0.08683243591804057, 0.07602823519846424, 0.035909835787606426, 0.07888856882345863, 0.1039227684668731, 0.07050016269204207, 0.019458128736005165, 0.0475887243374018, 0.026276410135324113, 0.04377319470222574, 0.13884965563192964, 0.061447697662515566, 0.05519404592632782, 0.07753869125735946, 0.04054520853969734, 0.08640245781862177, 0.06623896595556289, 0.051827690040227026, 0.12222264587762766, 0.06109987531090155, 0.2386715609463863, 0.7163280027452856, 1.8539959215559065, 6.5337232779711485, 12.967137638479471, 23.68612591177225, 35.044307336211205, 40.96548780798912, 54.53901685774326, 58.402543142437935, 56.97934851050377, 48.469192162156105, 47.548672556877136, 53.78200247883797, 56.69089458882809, 49.53984931111336, 60.609951093792915, 61.30879819393158, 59.38705511391163, 59.878649935126305, 67.11990237236023, 65.01147150993347, 80.05455270409584, 81.30302891135216, 76.27195447683334, 67.47658923268318, 66.40283524990082, 44.47993062436581, 60.85010960698128, 71.95689842104912, 51.31972700357437, 109.59808140993118, 63.11631180346012, 57.70956672728062, 57.98159033060074, 56.18720881640911, 61.8746904283762, 47.793219834566116, 54.96797204017639, 53.10515619814396, 58.36685165762901, 57.36036166548729, 57.86726586520672, 54.69626761972904, 55.40266111493111, 54.603168815374374, 48.45163710415363, 33.71448889374733, 29.956726133823395, 30.8089330047369, 17.84167282283306, 8.907694816589355, 3.511905502527952, 1.7088856268674135, 0.16589086008025333, 0.17078973236493766, 0.03234184950997587, 0.04223255920805968, 0.032509753000340424, 0.06612124649109319, 0.1320333854528144, 0.09108903133892454, 0.06719387252815068, 0.05903462675632909, 0.012544459095806815, 0.036327575871837325, 0.12823130353353918, 0.024530123664590064, 0.08094045871985145, 0.053632734197890386, 0.09037786090630107, 0.0802281305368524, 0.059808660807902925, 0.06387794186593965, 0.07349754130700603, 0.024074778957583476, 0.09305752610089257, 0.07115452172001824, 0.08372108568437397, 0.11007366614649072, 0.0008240654153723881, 0.052528088199323975, 0.028510463889688253, 0.06245626151212491, 0.03041263476916356, 0.02086010321363574, 0.036941354264854454, 0.03905218924046494, 0.057442694014753215, 0.15351870912127197, 0.07772072523948736, 0.04773667889821809, 0.022175723242980894, 0.04016273531306069, 0.03178877137543168, 0.04732146211608779, 0.019685018123709597, 0.030875031734467484, 0.04405953754030634, 0.06728789521730505, 0.028145561009296216, 0.07302373196580447, 0.09756330502568744, 0.05317007191479206, 0.027251607025391422, 0.03383192619367037, 0.015765675016155, 0.014296554727479815, 0.018733013348537497, 0.05026658982387744, 0.030180704343365505, 0.0525772814580705, 0.012998526381124975, 0.19628029345767573, 0.10641812870744616, 0.27862473973073065, 0.10132366340258159, 0.18492105533368886, 0.4493475006893277, 0.09475258397287689, 0.11031528716557659, 0.20511075243121013, 0.17799533321522176, 0.10617568390443921, 0.1745512633351609, 0.18218673096271232, 0.2628571295645088, 0.14280893927207217, 0.13989503000630066, 0.23113969713449478, 0.13430112157948315, 0.08797287198831327, 0.1578473299741745, 0.3160994272911921, 0.10799799783853814, 0.07077762944390997, 0.13331289257621393, 0.18312704691197723, 0.3482042608084157, 0.18502388731576502, 0.13808706920826808, 0.1310009541339241, 0.0959037737629842, 0.1642339857062325, 0.11881560174515471, 0.15622780047124252, 0.14911817415850237, 0.16957170475507155, 0.1730992365628481, 0.1636947857332416, 0.15541546046733856, 0.1596561071346514, 0.23847894393838942, 0.15845774643821642, 0.21675493073416874, 0.15745427372166887, 0.1365866544074379, 0.165067758935038, 0.1537331601139158, 0.1274146739160642, 0.26220282248687, 0.14255836053052917, 0.12371310105663724, 0.14824045094428584, 0.1305402140133083, 0.10908861353527755, 0.20457674749195576, 0.14573936874512583, 0.10482399549800903, 0.24459443375235423, 0.2064778923522681, 0.17760141607141122, 0.1346382050542161, 0.2693950349930674, 0.2521055768011138, 0.13281796913361177, 0.15519535430939868, 0.19629883230663836, 0.45517825812567025, 2.4131046887487173, 7.410737592726946, 17.65618197619915, 34.00195486843586, 46.71484149992466, 67.20131680369377, 73.0470523238182, 79.71380218863487, 80.02954244613647, 82.35590681433678, 85.75971096754074, 82.51595422625542, 85.10344058275223, 90.97388237714767, 98.3550775051117, 82.56067022681236, 89.03524160385132, 94.70754683017731, 93.01678195595741, 101.49584457278252, 105.37615835666656, 97.36254036426544, 82.963737398386, 76.27812534570694, 43.009679317474365, 59.796927720308304, 66.60005986690521, 56.08221285045147, 118.97144123911858, 66.06292828917503, 72.02413961291313, 77.76034221053123, 83.98612573742867, 87.85672724246979, 79.98387649655342, 88.1765864789486, 82.26507648825645, 89.87429738044739, 86.15069478750229, 89.89516586065292, 82.85855904221535, 75.67562207579613, 78.05347368121147, 55.300245210528374, 41.3742470741272, 32.539770528674126, 27.75662139058113, 11.847820300608873, 4.9156874511390924, 1.3032545428723097, 0.67467131302692, 0.0933157786494121, 0.18262287630932406, 0.1605094879050739, 0.18786674336297438, 0.17307614092715085, 0.06910419775522314, 0.20713179867016152, 0.22437709907535464, 0.1491004368290305, 0.0957662463770248, 0.12545074336230755, 0.16355598927475512, 0.2026462581125088, 0.08793796136160381, 0.21096898417454213, 0.11393784356187098, 0.16645878116833046, 0.1614834083011374, 0.10618142070597969, 0.14819065283518285, 0.2030619201832451, 0.08083373046247289, 0.18333220621570945, 0.1704338873969391, 0.22394260129658505, 0.2748919150326401, 0.1495388531475328, 0.08452636786387302, 0.1639705232810229, 0.1309848643722944, 0.08892958197975531, 0.15887058834778145, 0.07467393443221226, 0.1310316938906908, 0.09880250610876828, 0.18949528253870085, 0.0997775026189629, 0.18047937570372596, 0.12239515810506418, 0.2320513958693482, 0.15255189849995077, 0.07695128879277036, 0.1062602738966234, 0.07168644122430123, 0.1203184730547946, 0.10712276081903838, 0.16806232481030747, 0.11540754829184152, 0.17417080875020474, 0.1718886601156555, 0.21304966940078884, 0.19426470942562446, 0.1033857578295283, 0.11173998806043528, 0.19580022781156003, 0.2672371960943565, 0.11994389627943747, 0.24569454893935472, 0.09426442891708575], [0.0405696511734277, 0.1817128696711734, 0.06556124411872588, 0.025333544908789918, 0.04315654790843837, 0.05743862333474681, 0.03513132658554241, 0.018293502362212166, 0.024517638885299675, 0.015434505530720344, 0.08418479439569637, 0.04535686362942215, 0.0648738669406157, 0.053868547911406495, 0.018796951226249803, 0.07868267479352653, 0.0400198941497365, 0.10409782626084052, 0.1094608822313603, 0.05713645419746172, 0.06988752720644698, 0.08806765166809782, 0.036445547666517086, 0.04135705501539633, 0.03725341994140763, 0.06868970085633919, 0.07921427517430857, 0.022584115977224428, 0.013048741020611487, 0.03626361387432553, 0.02957021180918673, 0.03756368962058332, 0.0323463803215418, 0.06865778108476661, 0.06996946773142554, 0.017426391859771684, 0.07923475102870725, 0.01351012680970598, 0.009276392320316518, 0.06859396380605176, 0.060527204477693886, 0.043400413924246095, 0.0599570606573252, 0.08551904233172536, 0.04671900147513952, 0.0532089715852635, 0.047703716409159824, 0.02382876813499024, 0.07379897942882963, 0.05973930710752029, 0.027612044032139238, 0.04714722810604144, 0.036499620546237566, 0.05063130345661193, 0.08537007102859206, 0.06221569434273988, 0.09445752832107246, 0.057054172284551896, 0.043461166133056395, 0.039244516810867935, 0.03018550603883341, 0.14339185174321756, 0.10106619753059931, 0.050857461828854866, 0.05705309617042076, 0.052471629314823076, 0.11224599918932654, 0.19082317769061774, 1.0684434114955366, 2.40741188172251, 7.845248552039266, 12.566819619387388, 16.023160703480244, 33.06743301451206, 37.99079082906246, 44.791662096977234, 58.73391576111317, 57.351439744234085, 66.12431779503822, 55.68688966333866, 63.10765586793423, 63.46070632338524, 64.99390125274658, 59.360289350152016, 61.78258337080479, 84.97140526771545, 100.30822589993477, 94.25412476062775, 80.73768004775047, 78.0487847328186, 67.978595495224, 61.33646070957184, 55.437775030732155, 42.82174900174141, 48.65147978067398, 58.087414652109146, 75.04166409373283, 78.40644434094429, 58.20861674845219, 59.94254730641842, 60.28389818966389, 55.62916316092014, 67.49402269721031, 67.1918249130249, 57.85750798881054, 47.40122526884079, 37.43174582719803, 30.09205587208271, 20.06430845707655, 13.248137310147285, 6.989468447864056, 3.3622678695246577, 0.6274314760230482, 0.3514835442183539, 0.13426241115666926, 0.0516879325004993, 0.029410689021460712, 0.03064263004489476, 0.1070461118069943, 0.033226404193555936, 0.009283522504119901, 0.032906746346270666, 0.048845198907656595, 0.06774825684260577, 0.03125089613604359, 0.02209219823271269, 0.039955739193828776, 0.029299277812242508, 0.03577371848223265, 0.03578774136258289, 0.05907534097786993, 0.024535060802008957, 0.053120822994969785, 0.014148675309115788, 0.061062270688125864, 0.0794586272968445, 0.013130640727467835, 0.049177848050021566, 0.05113579689350445, 0.05797298450488597, 0.05975835803837981, 0.027254742599325255, 0.07612728964886628, 0.030464301235042512, 0.04379211204650346, 0.04834602295886725, 0.04643194246455096, 0.09533294345601462, 0.044958957441849634, 0.03347671947267372, 0.09616603390895762, 0.05350760809960775, 0.030615780997322872, 0.064892257360043, 0.045457098094630055, 0.02223133236839203, 0.010005429958255263, 0.045138059940654784, 0.051971366119687445, 0.09298283635871485, 0.052558853931259364, 0.001470840679758112, 0.0316306568129221, 0.04930038034217432, 0.02488095356966369, 0.0036962901594961295, 0.03401623856916558, 0.01914314827445196, 0.024222976571763866, 0.014670028485852527, 0.05387297482229769, 0.03353635845996905, 0.06214642598934006, 0.07205329224234447, 0.0601751927024452, 0.018364922943874262, 0.023715633287793025, 0.08606468414654955, 0.08627765826531686, 0.040971008347696625, 0.039639947935938835, 0.05210922747210134, 0.04575580882374197, 0.042357291968073696, 0.050291808001929894, 0.028230906136741396, 0.03131842415314168, 0.052352967322804034, 0.10832637592102401, 0.09986207034671679, 0.0186598227446666, 0.0055713522397127235, 0.008963085401774151, 0.037021480238763615, 0.09214637655531988, 0.07579115612315945, 0.09708718760521151, 0.00780037191361771, 0.017871201780508272, 0.0665954194846563, 0.06035141566826496, 0.07604609869304113, 0.04681739170337096, 0.021575602222583257, 0.029256860361783765, 0.030881414204486646, 0.018412782192172017, 0.03376413100340869, 0.027912020123039838, 0.03792906005401164, 0.04270931858627591, 0.05286657433316577, 0.0691902349353768, 0.10016052503488027, 0.02207646470196778, 0.032336654476239346, 0.03882104363583494, 0.01618310339836171, 0.05456477520056069, 0.05290776723995805, 0.05591685323452111, 0.03642003262939397, 0.014760353424208006, 0.043763851062976755, 0.023412694172293413, 0.11554267111932859, 0.014813724046689458, 0.04013266348920297, 0.05264302461000625, 0.028048178246535826, 0.026895279661403038, 0.08215335066779517, 0.058165735099464655, 0.0838081470283214, 0.04132433743507136, 0.044502373348223045, 0.12556850735563785, 0.14646993891801685, 0.0778745130810421, 0.06247688579605892, 0.03343922617204953, 0.16589160222792998, 0.5060316121671349, 1.0560953803360462, 4.490674082189798, 9.158018734306097, 19.151149056851864, 28.54031603783369, 37.155595645308495, 52.1888467669487, 57.02778071165085, 61.47190824151039, 68.21367368102074, 70.82076698541641, 81.94930583238602, 73.8697461783886, 84.73281607031822, 80.2128142118454, 86.24462574720383, 84.72400054335594, 93.17451909184456, 105.67862212657928, 120.6321269273758, 110.53117454051971, 93.66516396403313, 78.51265624165535, 62.858108058571815, 60.3615166246891, 55.152949914336205, 48.85400891304016, 62.81594552099705, 64.19855833053589, 74.64762523770332, 84.83829841017723, 77.06948608160019, 79.72285330295563, 80.17641976475716, 74.5324382185936, 83.92828524112701, 78.13377097249031, 73.67382869124413, 64.811260253191, 57.69378997385502, 49.503565058112144, 38.463405668735504, 25.982709378004074, 15.00800147652626, 10.909423604607582, 4.640411222353578, 1.9613924087025225, 0.6533736339770257, 0.1996655555558391, 0.05549075656745117, 0.013382675933826249, 0.14716254081577063, 0.04463125471374951, 0.007607046618431923, 0.07926543883513659, 0.03624940916779451, 0.05307675055519212, 0.0745190927409567, 0.04733057568955701, 0.08472023910144344, 0.06714238232234493, 0.04053046206536237, 0.04178835413767956, 0.047986571153160185, 0.049089666063082404, 0.03523386170854792, 0.059251511993352324, 0.08430094792856835, 0.057892428085324354, 0.044784597266698256, 0.050480035206419416, 0.07630432897713035, 0.03145852679153904, 0.06670511633274145, 0.0407840205298271, 0.047511407392448746, 0.04841865324124228, 0.08956463032518514, 0.04462405588128604, 0.08182716934243217, 0.04699985613115132, 0.06384463427821174, 0.04631513584172353, 0.04231991741107777, 0.01825873645429965, 0.017038154001056682, 0.02991240497067338, 0.03472496733593289, 0.07677437562961131, 0.046376685859286226, 0.010231926935375668, 0.03393950049940031, 0.040436179624521174, 0.0438446672342252, 0.017717966838972643, 0.004519217827692046, 0.03127635922282934, 0.04516312597843353, 0.008552906874683686, 0.011559771992324386, 0.020191569165035617, 0.04074712465808261, 0.009519949417153839, 0.04833173290535342, 0.033511700603412464, 0.06616425394895487, 0.04388341476442292, 0.05722023895941675, 0.08077777994913049, 0.15026667737402022, 0.2823348843958229, 0.18198578705778345, 0.09301247031544335, 0.17846863047452644, 0.16768506146036088, 0.1463753150892444, 0.12327125601586886, 0.18571907188743353, 0.1788462945842184, 0.1500242474139668, 0.12441489816410467, 0.22869006061227992, 0.2096396789420396, 0.1360790996113792, 0.16770293237641454, 0.1256173852016218, 0.09711935970699415, 0.20226402237312868, 0.21655603515682742, 0.1438958739163354, 0.14023665542481467, 0.16968761337921023, 0.08935296238632873, 0.21083395782625303, 0.16075175459263846, 0.09620205775718205, 0.14673399506136775, 0.16932111117057502, 0.07788254311890341, 0.0996387358463835, 0.10822799682500772, 0.15619961370248348, 0.13923365768278018, 0.1586746019893326, 0.17075879964977503, 0.19441834883764386, 0.32566191104706377, 0.09240269209840335, 0.2265253642690368, 0.14737573015736416, 0.1403520890744403, 0.14982863212935627, 0.21048972004791722, 0.14438009558944032, 0.17051598377292976, 0.12876665918156505, 0.10883143710088916, 0.19292289158329368, 0.25462855235673487, 0.10695571821997873, 0.14722865133080631, 0.08957965139416046, 0.14765434723813087, 0.19892380863893777, 0.10170911264140159, 0.16342112619895488, 0.1804053835803643, 0.09289734094636515, 0.20483874046476558, 0.23187476472230628, 0.20512523915385827, 0.2093364967731759, 0.23880128836026415, 0.10036832638434134, 0.19636620447272435, 0.23511639155913144, 0.4160828684689477, 1.970022339373827, 4.995756279677153, 12.664639670401812, 20.015150494873524, 30.426044650375843, 52.2843736410141, 63.28619688749313, 75.72684332728386, 87.66726180911064, 94.30009469389915, 107.51186415553093, 96.8766376376152, 105.15105843544006, 106.78289607167244, 105.97569018602371, 103.2475733757019, 101.14962235093117, 123.16077724099159, 127.321637570858, 118.28781992197037, 101.87522381544113, 92.7652658522129, 80.1949779689312, 80.61024248600006, 74.46730971336365, 62.99497291445732, 82.73286938667297, 80.84490269422531, 92.70168006420135, 99.45732235908508, 89.94169056415558, 110.41958972811699, 102.43393063545227, 90.74167683720589, 99.52826455235481, 98.09275478124619, 92.20445394515991, 77.61974215507507, 64.15845528244972, 48.93158175051212, 32.15014323592186, 21.115860231220722, 10.561570320278406, 5.940614053979516, 1.5043483022600412, 0.5392777500674129, 0.26728602941147983, 0.18298783485079184, 0.13810455420752987, 0.10647472488926724, 0.2373583009466529, 0.13954749709228054, 0.1513233472360298, 0.23218694172101095, 0.1596711578895338, 0.0776972807943821, 0.23903301655082032, 0.19626724650152028, 0.12695682817138731, 0.17469175189035013, 0.1702478012884967, 0.13985957019031048, 0.10496001632418483, 0.14189485082169995, 0.10041867368272506, 0.1270462866523303, 0.15328387875342742, 0.21877674880670384, 0.15889378788415343, 0.10261058458127081, 0.13115208508679643, 0.2758512448053807, 0.17839302046922967, 0.09024566956213675, 0.15516077022766694, 0.12386027636239305, 0.18234773247968405, 0.16590591083513573, 0.1476752312737517, 0.2866280305897817, 0.12634004408027977, 0.11194666134542786, 0.159894336538855, 0.1038071047514677, 0.14237892406526953, 0.1523751486092806, 0.09723997354740277, 0.19465264485916123, 0.14261314587201923, 0.21128956228494644, 0.1802508090622723, 0.15400754695292562, 0.1032171344559174, 0.09935185124049895, 0.15461463859537616, 0.13759977504378185, 0.1902840074035339, 0.08870398392900825, 0.19997385854367167, 0.16738800943130627, 0.11186431263922714, 0.12100937543436885, 0.22285718063358217, 0.10032419086201116, 0.18222558981506154, 0.1598372356966138, 0.18656583270058036, 0.1789079373702407], [0.026043637371913064, 0.04208381054922938, 0.05841395010065753, 0.05478622093505692, 0.04076591583725531, 0.043911338070756756, 0.01576041875523515, 0.03247644541261252, 0.0326048369606724, 0.040055543213384226, 0.03407294978387654, 0.01747638663800899, 0.043960349503322504, 0.060170698998263106, 0.02414057591522578, 0.04109545909159351, 0.0521844849572517, 0.029230924155854154, 0.10773474321467802, 0.04289730088203214, 0.07745985290966928, 0.03391233789443504, 0.07671266605029814, 0.07942340496811084, 0.07824969099601731, 0.1196066866395995, 0.03197523226845078, 0.012882700320915319, 0.030599880483350717, 0.009222773078363389, 0.018536466668592766, 0.042240971451974474, 0.02330232939129928, 0.0445610994938761, 0.06076950827264227, 0.07100628514308482, 0.04539886176644359, 0.03018473791598808, 0.04137860698392615, 0.02144219932233682, 0.028619615259231068, 0.05383181902288925, 0.01560533401061548, 0.061900092332507484, 0.0841091843903996, 0.04952938856149558, 0.00799769784862292, 0.015607456552970689, 0.022552313093910925, 0.06564840194187127, 0.07064850316965021, 0.06312564160907641, 0.026438599088578485, 0.047098450449993834, 0.04565814961097203, 0.024592170921096113, 0.07259082238306291, 0.002776708424789831, 0.09645517464377917, 0.03571453220502008, 0.047459961715503596, 0.024100854316202458, 0.024926944461185485, 0.052653615057352, 0.0934034633974079, 0.10810324180056341, 0.02703933609154774, 0.048513377259951085, 0.08182057907106355, 0.04697113501606509, 0.056110394216375425, 0.25621847016736865, 0.42653302021790296, 0.6957668310496956, 3.982996861450374, 7.345174010843039, 15.692002773284912, 16.281917318701744, 25.01961875706911, 44.003842771053314, 47.26649969816208, 54.87663634121418, 49.70278076827526, 65.10435372591019, 52.105859220027924, 48.96815478801727, 43.41739743947983, 95.80787658691406, 99.0942594408989, 100.11486947536469, 93.94942671060562, 91.40728712081909, 90.83691492676735, 95.19449830055237, 94.98764500021935, 93.1814195215702, 92.07935705780983, 100.6209947168827, 65.89237064123154, 46.57454922795296, 20.24129346013069, 18.39414607733488, 21.3666657730937, 21.970071494579315, 12.847872488200665, 9.143109284341335, 6.326469574123621, 2.0595628721639514, 0.3444341506110504, 0.3729741519782692, 0.03146190727420617, 0.06456710761995055, 0.13904970895964652, 0.015045303807710297, 0.017645099069341086, 0.03865212340315338, 0.04578663021675311, 0.0010081481309498486, 0.03990390388935339, 0.08307736163260415, 0.019240723995608278, 0.06070157207432203, 0.07429330915329047, 0.07939976014313288, 0.021247396689432207, 0.009325222854386084, 0.021684174716938287, 0.04037616956338752, 0.08882283145794645, 0.033858049791888334, 0.02457457459968282, 0.06282857473706827, 0.05358637594326865, 0.053451943313120864, 0.055706825442030095, 0.0454368819919182, 0.06658709258772433, 0.020335909466666635, 0.038324736087815836, 0.031822023302083835, 0.07940600902657025, 0.02883641700464068, 0.008811784682620782, 0.029825555138813797, 0.030580493730667513, 0.05371890125388745, 0.026830590359168127, 0.0574914976459695, 0.035279206931591034, 0.019699118929565884, 0.022679600697301794, 0.027352539109415375, 0.03341700627061073, 0.015732961146568414, 0.024490502255503088, 0.10220000622211955, 0.0348323041544063, 0.04224619617161807, 0.026651936859707348, 0.054810500296298414, 0.046787561077508144, 0.04867348077823408, 0.024128011355060153, 0.06230992483324371, 0.010742969825514592, 0.0405660888645798, 0.02891197505960008, 0.07873430600739084, 0.04778675160196144, 0.027631744342215825, 0.019438953495409805, 0.061901572917122394, 0.027181390578334685, 0.05085810749733355, 0.033328490317217074, 0.01908149064547615, 0.013153372710803524, 0.02225757471023826, 0.04704662256699521, 0.026281154314347077, 0.04686279258748982, 0.04216026660287753, 0.05588344545685686, 0.03028858292964287, 0.044552453473443165, 0.03369039863173384, 0.033335503612761386, 0.037946311276755296, 0.03267130741733126, 0.028984950440644752, 0.014575509485439397, 0.16009820450562984, 0.08971688934252597, 0.061493989123846404, 0.10851180893951096, 0.011908752094313968, 0.03574358357582241, 0.05276814328681212, 0.023933075135573745, 0.06768826904590242, 0.052673923928523436, 0.08339100066223182, 0.03657796907646116, 0.05053680208220612, 0.07251381714013405, 0.07640607742359862, 0.018348744124523364, 0.06577249645488337, 0.08315211816807278, 0.041494912657071836, 0.03066574423428392, 0.069780049379915, 0.008304267921630526, 0.02899829240050167, 0.020809249399462715, 0.08414651441853493, 0.045260633050929755, 0.016593989748798776, 0.019343093990755733, 0.04454894682567101, 0.043234818513155915, 0.04802319985174108, 0.04100698024558369, 0.013713164498767583, 0.07779663210385479, 0.05605548642051872, 0.0611242325976491, 0.05346009951608721, 0.02967644097225275, 0.06119601312093437, 0.02700352004467277, 0.03662341077870224, 0.06164707934658509, 0.030457280518021435, 0.04469351719308179, 0.03583406993129756, 0.026533193231443875, 0.05007789877709001, 0.016210240028158296, 0.0390816116851056, 0.16538809955818579, 0.006445137896662345, 0.0324393788469024, 0.09389744431246072, 0.2526595158269629, 0.2493320225039497, 0.9571222099475563, 2.691413867287338, 3.6945742880925536, 9.150645229965448, 14.906319882720709, 22.48024731874466, 35.56401684880257, 37.85741038620472, 48.90265770256519, 67.04980373382568, 71.5164564549923, 83.2561469078064, 78.47889125347137, 91.99836060404778, 77.48287349939346, 71.7108616232872, 61.849623173475266, 115.52558094263077, 119.91032525897026, 113.84143531322479, 99.31709468364716, 93.62737879157066, 89.19872403144836, 92.90526553988457, 95.76300099492073, 100.75114533305168, 107.99639135599136, 116.12388923764229, 91.36922836303711, 69.00028467178345, 38.15942957997322, 35.2987302839756, 40.22992707788944, 42.09510639309883, 28.586683049798012, 22.169547490775585, 16.306331008672714, 8.623862396925688, 3.5807428462430835, 2.432869803160429, 0.4754016932565719, 0.10057335952296853, 0.16351923812180758, 0.03171011485392228, 0.02857870436855592, 0.019640030986920465, 0.03014678633917356, 0.022959108355280478, 0.12457524659112096, 0.013880790611437988, 0.050113351171603426, 0.029643467350979336, 0.06873025180539116, 0.07842620339943096, 0.04136827257752884, 0.03469012721325271, 0.004073100335517665, 0.07166762778069824, 0.03179158411512617, 0.013509711207007058, 0.03219311198336072, 0.037657018401660025, 0.05465828951855656, 0.07638407274498604, 0.051271242555230856, 0.048889416066231206, 0.03531004687829409, 0.04065670138515998, 0.052661700756289065, 0.04545055235212203, 0.04032287593872752, 0.042478302857489325, 0.049685280391713604, 0.0799220243061427, 0.010654567049641628, 0.04174169902398717, 0.028586862426891457, 0.09970368861104362, 0.01156756825366756, 0.09308690030593425, 0.07592978188768029, 0.027626617957139388, 0.02434719353914261, 0.025933771685231477, 0.008098126199911349, 0.02338396563573042, 0.03489575407002121, 0.06905497852130793, 0.04297797233448364, 0.06705427455017343, 0.08962546417023987, 0.021202557982178405, 0.02327982561837416, 0.05302204684994649, 0.07743762558675371, 0.06745704551576637, 0.03378992434591055, 0.022929461410967633, 0.05109099714900367, 0.010152106169698527, 0.038693954556947574, 0.0520418887026608, 0.06336240898235701, 0.09173428421490826, 0.196810647030361, 0.015052525832288666, 0.1332726830150932, 0.11673465676722117, 0.14537737879436463, 0.17290611489443108, 0.20100388530408964, 0.14061099471291527, 0.16080550092738122, 0.16775034076999873, 0.13127093261573464, 0.1859222273924388, 0.10568518366198987, 0.20219289493979886, 0.11414746317313984, 0.12187155065475963, 0.15154993976466358, 0.2123424768797122, 0.1891610340680927, 0.14208760141627863, 0.19271906814537942, 0.1982294998015277, 0.23401412414386868, 0.131488322513178, 0.10683054017135873, 0.11140879723825492, 0.13948583946330473, 0.21716363145969808, 0.1909118049661629, 0.14621772745158523, 0.1508215960348025, 0.0795788700634148, 0.06719053286360577, 0.21737463888712227, 0.11421496892580763, 0.10225002697552554, 0.26867135195061564, 0.15531463228398934, 0.13580072001786903, 0.20866332430159673, 0.10793919005664065, 0.2364755459711887, 0.15181951748672873, 0.15766014548717067, 0.1658040881738998, 0.07833848154405132, 0.15231227385811508, 0.17375578492647037, 0.07368255872279406, 0.10980722770909779, 0.12892693339381367, 0.1695884476066567, 0.20642717398004606, 0.2042409108253196, 0.09870449066511355, 0.19561022316338494, 0.09896332208882086, 0.19371553498785943, 0.18129343749023974, 0.14221615623682737, 0.15706798585597426, 0.177406171860639, 0.22306370548903942, 0.18564506492111832, 0.12527259823400527, 0.20043922966578975, 0.233236605708953, 0.13884420826798305, 0.11083666075137444, 0.16186390741495416, 0.1780835894169286, 0.18902428593719378, 0.28234482917468995, 0.8169689867645502, 1.0944695211946964, 3.655868615023792, 7.496717954054475, 13.98684997111559, 26.019821986556053, 33.54850620031357, 44.784510880708694, 66.22880458831787, 75.34901440143585, 86.56256228685379, 82.5607082247734, 99.52140972018242, 83.430565148592, 77.47262924909592, 72.67876088619232, 132.23372519016266, 140.8890375494957, 127.13351726531982, 109.4024071097374, 103.06721985340118, 105.2503927052021, 110.79580754041672, 114.59403052926064, 113.5580313205719, 121.28486350178719, 133.82056564092636, 109.56803262233734, 78.65913838148117, 36.96045711636543, 29.54702451825142, 32.79806546866894, 30.437580831348896, 18.569312877953053, 14.020915143191814, 9.755854904651642, 3.7955593317747116, 1.274817818775773, 0.8425489172805101, 0.18636082182638347, 0.16502055834280327, 0.21054287266451865, 0.1482246580417268, 0.17054135038051754, 0.1170543665648438, 0.17575879697687924, 0.11136406057630666, 0.3032325458480045, 0.18596389156300575, 0.08023360016522929, 0.09480299064307474, 0.19717700080946088, 0.15123371063964441, 0.13721575814997777, 0.17238889733562246, 0.11885463871294633, 0.15816551836906, 0.16956777137238532, 0.14158274803776294, 0.10848659818293527, 0.22091880964580923, 0.15517583582550287, 0.16801202204078436, 0.12179692028439604, 0.17043572792317718, 0.09590580724761821, 0.15798128762980923, 0.12414801443810575, 0.16548882384086028, 0.16845728096086532, 0.15313723037252203, 0.19527169992215931, 0.16773451818153262, 0.149726438394282, 0.0890215192339383, 0.09848498564679176, 0.3072660294128582, 0.15146241086767986, 0.14972798206144944, 0.1588142296532169, 0.2117452706443146, 0.1601158527773805, 0.13533238030504435, 0.15975743997842073, 0.15997545327991247, 0.2370042965048924, 0.13397638744208962, 0.10938307546894066, 0.2665059134596959, 0.16182675550226122, 0.10132756709936075, 0.14830386004177853, 0.10968630216666497, 0.2618174400413409, 0.11924894177354872, 0.08220481118769385, 0.1399062661221251, 0.13726396806305274, 0.11512902769027278, 0.1342709903838113, 0.2170166713767685, 0.15492501959670335, 0.09683292781119235, 0.34680626238696277, 0.1541568522225134], [0.0856078254582826, 0.015334997442550957, 0.07141330861486495, 0.023160827804531436, 0.026258476136717945, 0.004495210278037121, 0.03350161852722522, 0.03681582740682643, 0.038120363460620865, 0.07727985241217539, 0.051130045249010436, 0.020357539360702503, 0.061110606766305864, 0.029255941954033915, 0.05449935488286428, 0.052602692594518885, 0.03232079849112779, 0.03299491720099468, 0.05481523148773704, 0.010221206612186506, 0.03654858373920433, 0.06440182391088456, 0.055436605762224644, 0.039343367170658894, 0.09220618623658083, 0.010657049533620011, 0.023453241410607006, 0.024641028358018957, 0.007704343106524902, 0.021740589072578587, 0.05801289349619765, 0.034596056284499355, 0.018645358286448754, 0.010597361379041104, 0.04476997324672993, 0.04337966347520705, 0.021998837910359725, 0.023626694310223684, 0.019546412768249866, 0.07032961715594865, 0.058549325258354656, 0.0435600721539231, 0.05201845538977068, 0.01553279185827705, 0.03616861897171475, 0.0080629029434931, 0.01538368047476979, 0.06751822074875236, 0.032152019266504794, 0.025117245968431234, 0.06286688440013677, 0.050473816008889116, 0.06029574346030131, 0.0527539831091417, 0.030356378119904548, 0.012141541556047741, 0.039512784642283805, 0.03481436273432337, 0.04786699631949887, 0.03527908818796277, 0.057149616186507046, 0.03538876277161762, 0.0859266817860771, 0.10307741031283513, 0.027348314433766063, 0.028365207035676576, 0.05307339604769368, 0.0639390799915418, 0.06496652407804504, 0.03938187350286171, 0.10716525619500317, 0.08340522763319314, 0.027679069244186394, 0.059738854397437535, 0.14361489680595696, 0.14663530426332727, 0.16980196349322796, 0.5315568612422794, 0.4941461468115449, 0.9447715664282441, 1.5394951100461185, 1.8845100654289126, 2.000559400767088, 2.9231411078944802, 2.0607576705515385, 0.28906450141221285, 0.8759836200624704, 2.982495347969234, 13.335138391703367, 56.022567451000214, 88.93406063318253, 95.08687287569046, 93.76774325966835, 94.38255786895752, 92.18511298298836, 70.9977538883686, 46.4395272731781, 21.056579612195492, 8.047528322786093, 2.593105542473495, 0.1700057424022816, 0.22039632283849642, 0.03679300265503116, 0.23143118305597454, 0.15798090171301737, 0.10097787453560159, 0.030124703735054936, 0.037509301328100264, 0.10566087832557969, 0.05902523116674274, 0.029266061137604993, 0.11704579475917853, 0.0788918268517591, 0.06116732911323197, 0.02785778953693807, 0.017779511290427763, 0.07043054181849584, 0.025596220657462254, 0.017780663474695757, 0.04228502533806022, 0.028966877289349213, 0.041688609489938244, 0.05451315511891153, 0.03975348539825063, 0.05046525904617738, 0.029398022415989544, 0.045245300279930234, 0.01490889520937344, 0.08041757857427001, 0.05111555481562391, 0.022280416160356253, 0.035549244785215706, 0.034025010754703544, 0.07994893458089791, 0.020886137754132506, 0.020045056226081215, 0.03681218717247248, 0.04524214986304287, 0.032029171561589465, 0.055587246897630394, 0.04147058505623136, 0.03405664479942061, 0.044737040443578735, 0.04430946319189388, 0.03791400187765248, 0.0622101133922115, 0.04399181285407394, 0.05080877694126684, 0.0438303029659437, 0.043377232941566035, 0.06001688518153969, 0.039905495796119794, 0.10325655734050088, 0.04563510592561215, 0.15057756303576753, 0.045014971037744544, 0.04960973346896935, 0.06686776541755535, 0.01395286706610932, 0.025067542483157013, 0.0336405448615551, 0.018596751324366778, 0.01728892013488803, 0.026326365950808395, 0.03701929090311751, 0.021950923000986222, 0.044173305068397895, 0.03613560453231912, 0.047626566447434016, 0.03630933388194535, 0.08520880233845674, 0.0389234785689041, 0.044556824723258615, 0.027469158339954447, 0.05263358820229769, 0.03786907225730829, 0.0033912250228240737, 0.04342674532381352, 0.04180493742751423, 0.019801835878752172, 0.06798679794883355, 0.08441139434580691, 0.07185094567830674, 0.023278890512301587, 0.09921502147335559, 0.025563850031176116, 0.05934672582952771, 0.058711154269985855, 0.0269766004930716, 0.02502263327187393, 0.05110486417834181, 0.03730591575731523, 0.02667871169251157, 0.039992059901123866, 0.06334382560453378, 0.036809912489843555, 0.04004271519079339, 0.013005316104681697, 0.08677604753756896, 0.007822553779988084, 0.13093200861476362, 0.06533109670272097, 0.056248641485581174, 0.045892304624430835, 0.032019657228374854, 0.06515838409541175, 0.043268374720355496, 0.0481763271818636, 0.04461093099962454, 0.041872120345942676, 0.027272802763036452, 0.015475937780138338, 0.04328626790083945, 0.047020806960063055, 0.013288027057569707, 0.11853649484692141, 0.03785601416893769, 0.04767639053170569, 0.06445346254622564, 0.06448462532716803, 0.03187929483829066, 0.052892671956215054, 0.06886710383696482, 0.06510780673124827, 0.039271289788302965, 0.1079486747039482, 0.025563848175806925, 0.04459954645426478, 0.018432964898238424, 0.0766598251357209, 0.02732259530603187, 0.01517651458925684, 0.05839581572217867, 0.025324084381281864, 0.04948751658957917, 0.029524734854931012, 0.024791266878310125, 0.05409584548033308, 0.07482213390176184, 0.06831542836152948, 0.04790746192156803, 0.03548251457687002, 0.07271961469086818, 0.04110811270948034, 0.009042913588928059, 0.07306344428798184, 0.022041804550099187, 0.009749734108481789, 0.1061994326300919, 0.12349069424089976, 0.38567330804653466, 0.5177478678524494, 0.7750717818271369, 1.6455043153837323, 2.0903146220371127, 4.2068046145141125, 5.868497248739004, 5.123218540102243, 6.3428576197475195, 7.741690333932638, 5.466080317273736, 0.7104734075255692, 1.9614894222468138, 6.591385658830404, 25.81433281302452, 69.26635399460793, 103.40757519006729, 112.29168087244034, 109.59032982587814, 115.99760681390762, 107.68765792250633, 96.09168335795403, 71.87924578785896, 36.969094052910805, 15.94713058322668, 5.231687994673848, 0.40638002974446863, 0.6715343438554555, 0.3286756540182978, 0.6110695539973676, 0.5225816834717989, 0.24536408542189747, 0.051788820055662654, 0.04736684444651473, 0.08592242927988991, 0.02052262640063418, 0.06925192225025967, 0.06267229327932, 0.07872050948208198, 0.029150529153412208, 0.03269192427978851, 0.0398816134838853, 0.03870006985380314, 0.02085666150378529, 0.06582012749277055, 0.0985934876371175, 0.03499455619021319, 0.016574651235714555, 0.07431889098370448, 0.06464866964961402, 0.010655140358721837, 0.06379853948601522, 0.0542575817235047, 0.03729120267962571, 0.07890037639299408, 0.046953134224168025, 0.020335245244496036, 0.0550491081958171, 0.032399792689830065, 0.02245324936666293, 0.018526674029999413, 0.042475501250009984, 0.00995714304735884, 0.06378193764248863, 0.047014198135002516, 0.0263953059038613, 0.017515414328954648, 0.02739912371907849, 0.08781247161095962, 0.10608578013489023, 0.02106548701704014, 0.035052310122409835, 0.019322619991726242, 0.02951049118564697, 0.011238652114116121, 0.08436889154836535, 0.006869618537166389, 0.07783416993333958, 0.06751654349500313, 0.007713537388553959, 0.04608537434251048, 0.024966120581666473, 0.017992995635722764, 0.047184598952298984, 0.015809673241165, 0.05698271830624435, 0.03407071220863145, 0.015657592339266557, 0.021145408900338225, 0.023550371843157336, 0.020715299069706816, 0.029072228862787597, 0.05435517043224536, 0.11901344347279519, 0.03918281465303153, 0.019793987667071633, 0.034657624855753966, 0.019985528560937382, 0.055281341046793386, 0.05176131606276613, 0.031874526539468206, 0.022994668361207005, 0.24032220127992332, 0.09529382485197857, 0.16591052699368447, 0.16906103293877095, 0.1560478296596557, 0.15824218222405761, 0.12078103885869496, 0.12360896289465018, 0.34483048715628684, 0.23211758059915155, 0.19288909417809919, 0.23243406205438077, 0.1138860268110875, 0.13210711040301248, 0.19524867850122973, 0.19979001372121274, 0.14634653460234404, 0.20544452592730522, 0.09722720860736445, 0.14562571624992415, 0.10147325810976326, 0.20261977828340605, 0.12289049715036526, 0.21358748897910118, 0.19013179291505367, 0.18224930885480717, 0.0808603067707736, 0.11490992343169637, 0.10962960950564593, 0.1866737409727648, 0.15348139393609017, 0.1321249664761126, 0.10016542320954613, 0.09287797831348144, 0.09619758260669187, 0.12212879388243891, 0.2029382041655481, 0.1379085233202204, 0.12811996653908864, 0.30492677993606776, 0.0815833812521305, 0.1411660321173258, 0.15250744385411963, 0.14448159170569852, 0.09711541890283115, 0.21197312482399866, 0.10099140388774686, 0.1187701229355298, 0.11815428137197159, 0.11081241478677839, 0.19739283219678327, 0.15341739112045616, 0.14640586188761517, 0.18443873355863616, 0.15971233224263415, 0.0827890372602269, 0.1815015060128644, 0.10538192727835849, 0.12043172479025088, 0.08519542883732356, 0.13147735357051715, 0.17528419353766367, 0.15425628516823053, 0.15192337363259867, 0.11816982936579734, 0.1548099867068231, 0.17910289956489578, 0.15549635456409305, 0.12108672948670574, 0.19268170843133703, 0.21417204901808873, 0.24350568826775998, 0.1984744382207282, 0.21188054932281375, 0.24220771651016548, 0.28056863229721785, 0.24932777741923928, 0.9463267517276108, 0.8677816414274275, 1.7218933976255357, 3.26954310759902, 2.6775123132392764, 4.091498851776123, 5.1943502482026815, 3.3442831970751286, 0.40609890420455486, 1.4237722009420395, 6.489467527717352, 30.5901787430048, 79.23682138323784, 127.92620033025742, 137.39658415317535, 139.11635667085648, 140.51025867462158, 125.35858690738678, 114.55647334456444, 80.65456330776215, 34.07621048390865, 12.532920688390732, 3.478969344869256, 0.28110882674809545, 0.35910207603592426, 0.2322485696640797, 0.3459380386630073, 0.2670510357711464, 0.14553906308719888, 0.04966628141119145, 0.09364221972646192, 0.1682984465151094, 0.1761082001030445, 0.19454179768217728, 0.18361144670052454, 0.22715385945048183, 0.2203498940798454, 0.20981478126486763, 0.19309978990349919, 0.17690810171188787, 0.2128155218088068, 0.1295803053653799, 0.31091012293472886, 0.12742637016344815, 0.11302958097076043, 0.1554918274632655, 0.235033716307953, 0.18182900093961507, 0.1685556600568816, 0.07985129763255827, 0.17003343935357407, 0.23576324747409672, 0.17711048538330942, 0.09224786525010131, 0.14820368494838476, 0.07322869831114076, 0.17595319513930008, 0.08828121208352968, 0.1676495125866495, 0.08743698199396022, 0.2239521750016138, 0.14308721496490762, 0.1443583209766075, 0.07644430545042269, 0.17463307769503444, 0.1711923474795185, 0.21725681552197784, 0.1742655216366984, 0.13770389836281538, 0.13896828051656485, 0.1953950003371574, 0.1524270692607388, 0.17284641653532162, 0.20926441939081997, 0.19063232699409127, 0.20913061016472057, 0.06383960993844084, 0.19969910063082352, 0.09983867785194889, 0.34703834680840373, 0.22243423067266122, 0.11368556530214846, 0.14547474856954068, 0.22698300221236423, 0.11695134162437171, 0.08754429654800333, 0.1530440611531958, 0.20486004010308534, 0.11876569973537698, 0.1400534636923112, 0.18719716288615018, 0.16735680954298005, 0.1447969302535057, 0.23674867115914822, 0.13919816818088293, 0.15400765085360035, 0.14958823565393686, 0.07591993358801119, 0.13545392925152555], [0.030433134743361734, 0.009301196751039242, 0.030131579733279068, 0.032947037543635815, 0.03639783870312385, 0.023505731660407037, 0.023582282337883953, 0.014081955305300653, 0.010282597067998722, 0.03268686654337216, 0.1676536092418246, 0.033207813394255936, 0.00465176725811034, 0.021156665425223764, 0.101966415240895, 0.011351979919709265, 0.03217688121367246, 0.03548402484739199, 0.013861911302228691, 0.008766227947489824, 0.041151016266667284, 0.04083251616975758, 0.0683880400902126, 0.03512340786983259, 0.019437430237303488, 0.04067762252816465, 0.04150540291448124, 0.03368567857251037, 0.013925448420195607, 0.028133111482020468, 0.022386027485481463, 0.11410503459046595, 0.016080553432402667, 0.017543654903420247, 0.03480591709376313, 0.0467626063618809, 0.02312561475264374, 0.04994990798877552, 0.030598865596402902, 0.04153145229793154, 0.037032256223028526, 0.0435017541894922, 0.0489831010781927, 0.06816302833613008, 0.041433321821386926, 0.04148439642449375, 0.06317299805232324, 0.043943387718172744, 0.017573676632309798, 0.011617147429205943, 0.03226379041734617, 0.04318659375712741, 0.026252039860992227, 0.05027237857575528, 0.09133877887506969, 0.09100848605157807, 0.05383273928600829, 0.034963578946189955, 0.0542402748396853, 0.019412191650189925, 0.061744734848616645, 0.00915185344638303, 0.06730537279509008, 0.05174892590730451, 0.04283174697775394, 0.02254750954307383, 0.003984292625318631, 0.012202221405459568, 0.0582732203474734, 0.03396959087694995, 0.009168632477667416, 0.11632334368187003, 0.038112856636871584, 0.04465900732611772, 0.008845882657624315, 0.008452179808955407, 0.047515964179183356, 0.021173617933527566, 0.11767129166400991, 0.03389257450180594, 0.03361794646480121, 0.06944845779798925, 0.02167755847040098, 0.07553628034656867, 0.047943099853000604, 0.05100029557070229, 0.17011121643008664, 0.024600516371720005, 0.22057770373066887, 0.03397419961402193, 1.2444385676644742, 3.27957718167454, 6.653974950313568, 7.2136293444782495, 4.677330516278744, 1.6594913648441434, 0.15479431254789233, 0.05050758001743816, 0.086335746163968, 0.043713255145121366, 0.029534627683460712, 0.04023054163553752, 0.07361860043602064, 0.029818645743944217, 0.03684378039906733, 0.09579157587722875, 0.012194698811072158, 0.033970811709878035, 0.06310710276011378, 0.0647610382293351, 0.02946077842352679, 0.10205153215792961, 0.025895122489600908, 0.01784940861398354, 0.027820129253086634, 0.0802653343998827, 0.02749230963672744, 0.03738450548553374, 0.026223931017739233, 0.022404126611945685, 0.05131015335791744, 0.016252375462499913, 0.0676552063669078, 0.038212204235605896, 0.037448400689754635, 0.0659177644411102, 0.03866281775117386, 0.05808746820548549, 0.018756068166112527, 0.024844686668075155, 0.06140376252005808, 0.04565865056065377, 0.010911643294093665, 0.01254660483027692, 0.022176732563821133, 0.09250188013538718, 0.024687935801921412, 0.03250288813433144, 0.01690493107162183, 0.001999535552386078, 0.12779989308910444, 0.030294590615085326, 0.04790509075974114, 0.027815527937491424, 0.009721427668409888, 0.0603314444742864, 0.038501645540236495, 0.03854845650494099, 0.045910494663985446, 0.024961947856354527, 0.057399463912588544, 0.010321820500394097, 0.08607566793216392, 0.06737443705787882, 0.03034042751096422, 0.011820506097137695, 0.014552793272741837, 0.004781544766956358, 0.04658157056837808, 0.03319363095215522, 0.01749472696246812, 0.04142073870752938, 0.03033123786735814, 0.03343510354170576, 0.008521040908817668, 0.0257974558553542, 0.03127248150121886, 0.027485459613671992, 0.035328359372215346, 0.024433674152533058, 0.05123467693920247, 0.03898138464137446, 0.014829067949904129, 0.013333234055608045, 0.004307584213165683, 0.05876550916582346, 0.07932990178233013, 0.05103196672280319, 0.068769726640312, 0.07973125524586067, 0.018115290440618992, 0.03680274334328715, 0.054397925559896976, 0.029493711226677988, 0.013088676914776443, 0.07358544127782807, 0.030389411112992093, 0.0075396122974780155, 0.02186449804867152, 0.012306834541959688, 0.006403740899258992, 0.045042100246064365, 0.01543688782476238, 0.007533757679993869, 0.005753773530159378, 0.03031427793757757, 0.03414987339056097, 0.026018528660642914, 0.04406907413795125, 0.053946733169141226, 0.048301798378815874, 0.0394652909017168, 0.06387047586031258, 0.022184423069120385, 0.028301781239861157, 0.06376757708494551, 0.01573699657456018, 0.05639734190481249, 0.06242940318770707, 0.030057186850172002, 0.02067728441033978, 0.056830793255358, 0.03687816410092637, 0.02326950791029958, 0.028457186963350978, 0.05815389413328376, 0.012931114324601367, 0.06887174968142062, 0.026616729373927228, 0.017001265550788958, 0.05741287081036717, 0.04641778228688054, 0.05082977229903918, 0.03717733867233619, 0.0054480550716107246, 0.03932983039703686, 0.04107558066607453, 0.043245446067885496, 0.008170716591848759, 0.03646492143161595, 0.03601836746383924, 0.005802367968499311, 0.010617961543175625, 0.012986659439775394, 0.07301982084754854, 0.020039180271851365, 0.04971592738002073, 0.05028450526879169, 0.0767997645016294, 0.02664817417098675, 0.04404364444781095, 0.052340161564643495, 0.015330831211031182, 0.046124585715006106, 0.05118667853821535, 0.03558860829798505, 0.0056718705764069455, 0.05509955568413716, 0.022472558193840086, 0.00973236692516366, 0.028109414706705138, 0.11375674468581565, 0.0860667547385674, 0.05757181286753621, 0.09856363103608601, 0.055861726505099796, 0.07024490099865943, 0.173747279914096, 0.049685395424603485, 0.08164208513335325, 0.07806938621797599, 0.03001769531692844, 0.04564320275676437, 0.03854320581012871, 0.14362219953909516, 0.323922376264818, 3.4605690697208047, 7.053033811971545, 13.08349784463644, 14.12240769714117, 10.507456474006176, 6.667993823066354, 1.0683658719062805, 0.015447685145772994, 0.1092899581999518, 0.11354345886502415, 0.043242299361736514, 0.0262239607036463, 0.05050122723332606, 0.0337042842147639, 0.025337250081065577, 0.015363325219368562, 0.015539840405836003, 0.05113708451972343, 0.03405741292226594, 0.06279190522036515, 0.025442275109526236, 0.0763695637579076, 0.04546000731352251, 0.06458943142206408, 0.04493150168855209, 0.09031520879943855, 0.014233990750653902, 0.04533794257440604, 0.043393734595156275, 0.0605409008130664, 0.06310929951723665, 0.010907434389082482, 0.053823610869585536, 0.028976783105463255, 0.02763673157460289, 0.056016946691670455, 0.06098246383771766, 0.02012729917623801, 0.013999742041050922, 0.04024118032248225, 0.06460142452851869, 0.019755292087211274, 0.04233094572555274, 0.0535763161315117, 0.01607737704034662, 0.025768011146283243, 0.05271412977890577, 0.04949378031597007, 0.01859553791291546, 0.0392415370879462, 0.05486307774845045, 0.01062776716935332, 0.008482865760015557, 0.042357922793598846, 0.021762990800198168, 0.04704251477960497, 0.07445114912115969, 0.02009682844800409, 0.09728992750751786, 0.05460597181809135, 0.031032155529828742, 0.008858359087753342, 0.041525563356117345, 0.04453090521565173, 0.10910632117884234, 0.025563170966051985, 0.021916266559856012, 0.011171843980264384, 0.024784160814306233, 0.02844377449946478, 0.010557490422797855, 0.015279623021342559, 0.06995927062234841, 0.02090543359372532, 0.007735185372439446, 0.01313392194788321, 0.0308345271696453, 0.006408509661923745, 0.04597051585733425, 0.017479711459600367, 0.03952666651457548, 0.04684150779212359, 0.023604710040672217, 0.014708519975101808, 0.015897411794867367, 0.052902921015629545, 0.10151838810998015, 0.11124681608635001, 0.16519077733391896, 0.18990591284818947, 0.19000819564098492, 0.10731483605923131, 0.12357126921415329, 0.170601494028233, 0.07458762265741825, 0.22383286734111607, 0.2610639820341021, 0.08052144956309348, 0.07980892842169851, 0.1025625379406847, 0.14583276060875505, 0.13144201249815524, 0.11597442295169458, 0.07739395761745982, 0.10584933930658735, 0.16192563925869763, 0.1371067069703713, 0.11461506815976463, 0.10642978784744628, 0.122025063901674, 0.07981456132256426, 0.09525283603579737, 0.1271350623574108, 0.12449283109162934, 0.09542328509269282, 0.16241812845692039, 0.09679981318186037, 0.1763167732860893, 0.15678540570661426, 0.13620550220366567, 0.1411136513343081, 0.1490303929313086, 0.16786794149084017, 0.10398004742455669, 0.18164462177082896, 0.12616305670235306, 0.11396729940315709, 0.11950349100516178, 0.10728326509706676, 0.10663624590961263, 0.20536815893137828, 0.09340370088466443, 0.17108135187299922, 0.15648290631361306, 0.11397620517527685, 0.09636226517613977, 0.0780441309325397, 0.14428582799155265, 0.12007241399260238, 0.1460244573536329, 0.12285505959880538, 0.14877074514515698, 0.12888776283944026, 0.17026761663146317, 0.2755072742002085, 0.15716565249022096, 0.18824390281224623, 0.12477544834837317, 0.17867711459985003, 0.1474961658823304, 0.18477348668966442, 0.22551595437107608, 0.07915511116152629, 0.1386338984593749, 0.1641407422721386, 0.14273502136347815, 0.13435284927254543, 0.21554105915129185, 0.11151182960020378, 0.17067116685211658, 0.201178468123544, 0.3125771350460127, 0.16865159006556496, 0.11097470764070749, 0.21244945004582405, 0.13832375494530424, 0.20650830556405708, 0.259830413851887, 0.09718801578856073, 0.17889975890284404, 0.1489965955261141, 0.08683577558258548, 0.13860979350283742, 0.201904971327167, 0.4202783480286598, 0.37550692388322204, 3.031460945494473, 6.725568333640695, 13.182220347225666, 13.748248424381018, 9.018465522676706, 4.738177601248026, 0.6533884175587445, 0.17331159469904378, 0.14630353456595913, 0.279654721962288, 0.10674520061002113, 0.10230318701360375, 0.12208030195324682, 0.08461200428428128, 0.055484151453129016, 0.1852599496487528, 0.08512177810189314, 0.12703957763733342, 0.21191620209719986, 0.23234154592501, 0.18744757835520431, 0.1881161198252812, 0.11740295332856476, 0.2135534689296037, 0.15552277502138168, 0.1509874957264401, 0.10873067571083084, 0.1221169566269964, 0.11552022115211003, 0.1604767591925338, 0.1866823053569533, 0.07659539929591119, 0.1665474529727362, 0.15926734049571678, 0.1661957788746804, 0.14067768410313874, 0.07861085716285743, 0.17232597805559635, 0.10250853185425512, 0.16968424402875826, 0.11307278138701804, 0.13260857958812267, 0.11497988569317386, 0.11922423567739315, 0.1156141993124038, 0.12175152311101556, 0.1454835059121251, 0.15923560626106337, 0.17419204901671037, 0.10502895442186855, 0.17630319198360667, 0.058015286922454834, 0.12753623770549893, 0.10910934914136305, 0.06830395475844853, 0.13141197036020458, 0.10505790560273454, 0.16385448107030243, 0.11454680541646667, 0.16305181867210194, 0.0995120067091193, 0.09065603269846179, 0.17590866627870128, 0.1735108910361305, 0.1923992915544659, 0.08677347228513099, 0.125131634704303, 0.1282166238524951, 0.12022514798445627, 0.09473077967413701, 0.10386214984464459, 0.11838419130071998, 0.1490303929313086, 0.15358397358795628, 0.06312147073913366, 0.10735386560554616, 0.11734531071851961, 0.057314061268698424, 0.08737330572330393, 0.0883538906055037, 0.17950643494259566, 0.11956490372540429, 0.14555420289980248, 0.07504267050535418, 0.12481274869060144, 0.16446135006844997], [0.037303655917639844, 0.07415726606268436, 0.03942336326872464, 0.027894525846932083, 0.0823739540646784, 0.06176063165185042, 0.017664480255916715, 0.02704062371776672, 0.07789006107486784, 0.039938146583153866, 0.03163908018905204, 0.08331565040862188, 0.033049550402211025, 0.049893382310983725, 0.045408773148665205, 0.07348203042056412, 0.007835113701730734, 0.031893195264274254, 0.04626502231985796, 0.015037941702757962, 0.04010287368146237, 0.013831962860422209, 0.0261872874762048, 0.0768332947336603, 0.046614748280262575, 0.04448630956176203, 0.015364108185167424, 0.06923491964698769, 0.0628746250004042, 0.09264542633900419, 0.05252467803074978, 0.019085099338553846, 0.043253201511106454, 0.02318877708603395, 0.05627451646432746, 0.041382035706192255, 0.024500942417944316, 0.028323618935246486, 0.019199981943529565, 0.03630341525422409, 0.056096415864885785, 0.06980225443840027, 0.01584398643899476, 0.03086383829213446, 0.048418382357340306, 0.05623231423669495, 0.08760377968428656, 0.02798533132590819, 0.031638994842069224, 0.07694636835367419, 0.02122939589753514, 0.03355585467943456, 0.018300120464118663, 0.03601757707656361, 0.03247778498916887, 0.040526254088035785, 0.024986242060549557, 0.02674741601367714, 0.05384988289733883, 0.043790301206172444, 0.02018909595790319, 0.03773136304516811, 0.033449215479777195, 0.028246949514141306, 0.011661216158245225, 0.05458063860714901, 0.11290552356513217, 0.03232873947126791, 0.05080540388007648, 0.04466037287784275, 0.023089961978257634, 0.06248079691431485, 0.047099886505748145, 0.07312777364859357, 0.013209337139414856, 0.08184427584637888, 0.01686402018094668, 0.015063723913044669, 0.02158653220249107, 0.04913294440484606, 0.05664932701620273, 0.014807560510234907, 0.05433674290543422, 0.051925575608038343, 0.059842354312422685, 0.0983719936630223, 0.15559185412712395, 0.061752583060297184, 0.06025010137818754, 0.035149553732480854, 0.06314829937764443, 0.2335426228819415, 0.21595974918454885, 0.18702966015553102, 0.09800955100217834, 0.18437807040754706, 0.056768827635096386, 0.0026808312941284385, 0.05058359820395708, 0.05549242268898524, 0.03309570827696007, 0.06293082784395665, 0.06766839433112182, 0.07025152837741189, 0.06704646715661511, 0.057203388496418484, 0.026911894492513966, 0.009597613316145726, 0.016486114873259794, 0.012339070653979434, 0.02397203046712093, 0.046020213776500896, 0.0621877821686212, 0.03851471847156063, 0.01266835230126162, 0.01119508990086615, 0.021888187402510084, 0.02156896000087727, 0.024760733067523688, 0.03263876053097192, 0.007129062232706929, 0.027038814732804894, 0.03172096505295485, 0.031478805976803415, 0.0558393730170792, 0.023636279147467576, 0.014548818144248798, 0.006099776228438714, 0.035608746475190856, 0.019732684413611423, 0.017502313567092642, 0.028546812427521218, 0.07735454957582988, 0.01611691124708159, 0.0398104823398171, 0.060488163799163885, 0.017852659220807254, 0.038675731120747514, 0.00769097377997241, 0.028388386162987445, 0.0447116404393455, 0.02254307892144425, 0.017188327583426144, 0.06662834857706912, 0.02863819678168511, 0.021138788943062536, 0.022453815254266374, 0.04488518796279095, 0.03610375897551421, 0.02303547164046904, 0.016941220237640664, 0.04075253862538375, 0.13837160862749442, 0.00980839438852854, 0.03498624042549636, 0.019324633067299146, 0.0402250348997768, 0.03319738250866067, 0.021544467272178736, 0.06229188322322443, 0.006169914286147105, 0.048062266505439766, 0.05505032902874518, 0.03634033339039888, 0.026767344534164295, 0.033953849924728274, 0.04706261956016533, 0.06573027567355894, 0.033046095704776235, 0.07687862511374988, 0.0508071924559772, 0.02367204324400518, 0.029089105300954543, 0.03129734344838653, 0.07316944524063729, 0.1202019039192237, 0.015251654258463532, 0.0257698572386289, 0.020750662406499032, 0.035266998602310196, 0.03879927644447889, 0.015887439185462426, 0.028104026714572683, 0.061573183702421375, 0.0521670222224202, 0.053471899664145894, 0.0414248947345186, 0.025357694394188002, 0.056013918729149736, 0.04963848798070103, 0.027830420985992532, 0.04015898004581686, 0.019474392902338877, 0.028546714092954062, 0.06374858552590013, 0.018095818340952974, 0.022764600726077333, 0.045907221792731434, 0.02211349601566326, 0.05822729995998088, 0.02889499101002002, 0.047319473160314374, 0.010170894565817434, 0.02919625287177041, 0.04719249911431689, 0.05862303907633759, 0.05644303222652525, 0.030051175453991164, 0.04729657419375144, 0.04866646748268977, 0.08535761779057793, 0.035619028931250796, 0.037045143617433496, 0.06290210672887042, 0.01747954262100393, 0.1140150120772887, 0.018570965403341688, 0.041025233367690817, 0.03676290485600475, 0.03367171506397426, 0.04342517197073903, 0.0621869843598688, 0.0796344866103027, 0.015330464775615837, 0.029355651349760592, 0.010697434427129338, 0.012049898377881618, 0.039319729767157696, 0.02365959000599105, 0.027164911189174745, 0.06711688954965211, 0.031482650301768444, 0.03898298768035602, 0.03598149385652505, 0.03822504710115027, 0.02997454870637739, 0.049646414117887616, 0.021358846861403435, 0.07402028044452891, 0.04536823333182838, 0.03764625726034865, 0.04369448623037897, 0.012529222804005258, 0.023733164671284612, 0.023394068120978773, 0.06193813853315078, 0.05477219063322991, 0.03607964659749996, 0.04555691695713904, 0.08504357800120488, 0.0561490638210671, 0.1210878427082207, 0.012425658878782997, 0.036246993477107026, 0.038900382933206856, 0.07310614004381932, 0.07549982605269179, 0.0255089440906886, 0.022745657406630926, 0.11181362395291217, 0.07601533667184412, 0.014537876104441239, 0.13873857096768916, 0.07202966226032004, 0.09884211453027092, 0.03493587457342073, 0.05023003905080259, 0.1533329050289467, 0.36152189306449145, 0.33720827428624034, 0.20264538237825036, 0.14919019216904417, 0.02405230115982704, 0.07215345249278471, 0.029312838705664035, 0.08356873760931194, 0.01300452293435228, 0.03858744152239524, 0.015136625079321675, 0.09641461627325043, 0.05602955578069668, 0.04105170206457842, 0.01487278694185079, 0.030054450180614367, 0.04295872102375142, 0.05140002744155936, 0.061311194440349936, 0.04226639372063801, 0.05322300930856727, 0.055905665358295664, 0.036595212877728045, 0.019591331256378908, 0.013713239641219843, 0.03348237463796977, 0.05327517486875877, 0.05055538174929097, 0.06236750807147473, 0.05859396915184334, 0.018222554899693932, 0.027206671838939656, 0.020376464126456995, 0.006914886298545753, 0.03063188003579853, 0.0637952666147612, 0.055986362785915844, 0.04677328957768623, 0.031004330558062065, 0.048387293791165575, 0.08600065164500847, 0.015141876701818546, 0.05339475712389685, 0.027983600266452413, 0.01797151046048384, 0.03165476176945958, 0.02366171440371545, 0.027302588860038668, 0.0988264700572472, 0.023720052777207457, 0.019866274706146214, 0.01987461087992415, 0.04255066596670076, 0.02739727577136364, 0.04355890327133238, 0.025212556283804588, 0.016016884583223145, 0.17309196351561695, 0.05339077179087326, 0.03517721728712786, 0.013378639578149887, 0.05701208508980926, 0.08740733319427818, 0.07921363692730665, 0.025153407113975845, 0.023431242298102006, 0.029339791653910652, 0.035504604602465406, 0.02087349712383002, 0.03786971421504859, 0.042982043014490046, 0.06317921724985354, 0.013915010113123572, 0.09633828638470732, 0.00785226658990723, 0.038478349524666555, 0.040930546456365846, 0.03362480390933342, 0.030360738237504847, 0.0105300810537301, 0.03118865963188, 0.0692322182294447, 0.06620938394917175, 0.06251472048461437, 0.09500204207142815, 0.19826607283903286, 0.062034335714997724, 0.1185766005073674, 0.20857922412687913, 0.14897088753059506, 0.0937543433974497, 0.16512374655576423, 0.19163612625561655, 0.1339995869784616, 0.15831770317163318, 0.11408034333726391, 0.10349341377150267, 0.16572657827055082, 0.11551111500011757, 0.19827757612802088, 0.10407555440906435, 0.18528245156630874, 0.1539740909356624, 0.07602137775393203, 0.2050502970814705, 0.15898559155175462, 0.09258153484552167, 0.20525210187770426, 0.15675989066949114, 0.18875453009968624, 0.19444386387476698, 0.16480071935802698, 0.2155800664331764, 0.1767802593531087, 0.19029435294214636, 0.1071568179759197, 0.1406052356469445, 0.1077810903370846, 0.18156917503802106, 0.14926394680514932, 0.11519484134623781, 0.2338374633109197, 0.07339847201365046, 0.11820242449175566, 0.16783723141998053, 0.1663467168691568, 0.13331836962606758, 0.1627115291194059, 0.20676767133409157, 0.18898262176662683, 0.16657559521263465, 0.08874967053998262, 0.15414649184094742, 0.19115347793558612, 0.11265990979154594, 0.09687594269053079, 0.1654134810087271, 0.12136907957028598, 0.17598642851226032, 0.21928004367509857, 0.15034280688269064, 0.11459275177912787, 0.12484169244999066, 0.17380881879944354, 0.08875682484358549, 0.07602932615554892, 0.11693440581439063, 0.1310516576631926, 0.1302063959883526, 0.1133099792059511, 0.14329808880575, 0.19698460644576699, 0.1414226074120961, 0.13552103424444795, 0.14776541705941781, 0.1756379901780747, 0.11725736621883698, 0.17169988743262365, 0.21379776910180226, 0.220441430574283, 0.18320215225685388, 0.13436353619908914, 0.11229846903006546, 0.1831317224423401, 0.23548044468043372, 0.17569647141499445, 0.14897773013217375, 0.26287134911399335, 0.12943333043949679, 0.1531591237289831, 0.37890355568379164, 0.2267427690094337, 0.1745086640585214, 0.12744336534524336, 0.14853005181066692, 0.32063766033388674, 0.44933259836398065, 0.32801790337543935, 0.3726219286909327, 0.37452176737133414, 0.17495801963377744, 0.16109358781250194, 0.15479435707675293, 0.17091637244448066, 0.2846007503103465, 0.09599903583875857, 0.10656456186552532, 0.22192145115695894, 0.21062817511847243, 0.22093810548540205, 0.18803915911121294, 0.08627518691355363, 0.13226054201368243, 0.10728517983807251, 0.10965855326503515, 0.2119023387786001, 0.17508137942058966, 0.15601415099808946, 0.12126754634664394, 0.09214671052177437, 0.15193441679002717, 0.11024216335499659, 0.11115832981886342, 0.13562920968979597, 0.09952624110155739, 0.14334321138449013, 0.06662371757556684, 0.1679248345317319, 0.09517629092442803, 0.13633557100547478, 0.13177476183045655, 0.10078876046463847, 0.13399798393948004, 0.0895632425090298, 0.07915367881651036, 0.12348377000307664, 0.16561875905608758, 0.0851269879785832, 0.12738809018628672, 0.11607899898081087, 0.23797426867531613, 0.15113610337721184, 0.06120140111306682, 0.11644741593045183, 0.11765163959353231, 0.062216826117946766, 0.16744110267609358, 0.10222486816928722, 0.13325855252332985, 0.1349852333078161, 0.12410679555614479, 0.0846944865770638, 0.12203704958665185, 0.19757876987569034, 0.12063021960784681, 0.1459172467002645, 0.24705869058379903, 0.17721803742460907, 0.16499342542374507, 0.33057540364097804, 0.15938442171318457, 0.11891116067999974, 0.0844554408104159, 0.14478664408670738, 0.1873115130001679, 0.1684000762179494, 0.17046639346517622, 0.07520405051764101, 0.10182456855545752, 0.13506724062608555, 0.174478518019896, 0.15510268975049257, 0.147267940628808, 0.20243088685674593, 0.08882524343789555, 0.1628187546157278, 0.08807782651274465, 0.2161189547041431, 0.1608192900312133, 0.17864909110357985], [0.013470038775267312, 0.007497868809878128, 0.03203148335160222, 0.0441687223064946, 0.016390858363592997, 0.07576566335046664, 0.010390035931777675, 0.04883518733549863, 0.06114588846685365, 0.036374694827827625, 0.013947556999482913, 0.013742019200435607, 0.016100392895168625, 0.013329627217899542, 0.01792922103049932, 0.05300343007547781, 0.11009415684384294, 0.04385106083645951, 0.039264024162548594, 0.07398025642032735, 0.00829011794849066, 0.017355407289869618, 0.06327262395643629, 0.020696921637863852, 0.03400290588615462, 0.023885484915808775, 0.051283703214721754, 0.07490789648727514, 0.057651849783724174, 0.0500095358438557, 0.04961769671353977, 0.029384515328274574, 0.011006770855601644, 0.037584699821309187, 0.021073606112622656, 0.0379226070799632, 0.052695153062813915, 0.02317175592907006, 0.038276904670055956, 0.0010795723073897534, 0.04939800615829881, 0.07047461796901189, 0.013962470457045129, 0.09505520953098312, 0.05726062663597986, 0.04035963451315183, 0.03563031699741259, 0.021458973715198226, 0.017446819474571384, 0.05802137624414172, 0.04724365906440653, 0.05214662800426595, 0.07103016745531932, 0.046347489769686945, 0.1679290202446282, 0.030130004524835385, 0.02855753275071038, 0.06823432646342553, 0.025610438351577614, 0.002112816741828283, 0.03087516532104928, 0.0805519666755572, 0.07870647546951659, 0.06801891067880206, 0.004914870669381344, 0.012428144145815168, 0.02624122120323591, 0.028160084839328192, 0.024832556264300365, 0.0279069160023937, 0.10220981741440482, 0.05946455661614891, 0.01422240304236766, 0.028531303396448493, 0.02982234349474311, 0.0366148760804208, 0.010166921292693587, 0.05867694126209244, 0.03337177979119588, 0.03671589722216595, 0.012272062140255002, 0.04209656806779094, 0.08630516967969015, 0.05638912261929363, 0.028871696849819273, 0.037832150410395116, 0.0262518023737357, 0.014684498510177946, 0.024108003053697757, 0.09004433974041604, 0.05213681681198068, 0.14900918235071003, 0.09015272298711352, 0.014032532908458961, 0.05177890125196427, 0.08793667744612321, 0.08704276799107902, 0.12520231684902683, 0.03930013706849422, 0.10225486577837728, 0.07190107775386423, 0.05750228476244956, 0.032468600911670364, 0.0511696907778969, 0.026326701772632077, 0.03266454274125863, 0.09006524604046717, 0.025865267743938603, 0.10306792566552758, 0.046007222481421195, 0.029615820494655054, 0.009463369933655486, 0.02096826381603023, 0.03844747618131805, 0.020712707118946128, 0.040401777368970215, 0.1273808319820091, 0.03828786619124003, 0.054168902497622184, 0.037629477301379666, 0.017027932772180066, 0.03574013629986439, 0.02073414776532445, 0.05540640035178512, 0.03919389862858225, 0.03238405544834677, 0.04504164753598161, 0.018433402765367646, 0.02670601159479702, 0.0369798086467199, 0.060848880966659635, 0.050553893743199296, 0.013693450273422059, 0.05966298464045394, 0.04402070837386418, 0.026456900450284593, 0.03655199019704014, 0.013002143423364032, 0.015302769679692574, 0.010554032014624681, 0.020717256484203972, 0.04987220512703061, 0.054026844300096855, 0.08604521761299111, 0.08060857027885504, 0.046267445432022214, 0.027385900502849836, 0.02784542721201433, 0.06430752662708983, 0.007467280265700538, 0.07006045503658243, 0.03956872031267267, 0.033568575090612285, 0.08340821848833002, 0.06120616199041251, 0.05841475533088669, 0.04507144105446059, 0.03806843909842428, 0.030963408535171766, 0.06574566039489582, 0.01658071643760195, 0.01783012761734426, 0.04983034799806774, 0.062143012110027485, 0.08098781516309828, 0.04355220538855065, 0.018747744979918934, 0.06042573062586598, 0.0597823071439052, 0.0621944652084494, 0.03537696633429732, 0.0221333169247373, 0.02029998580837855, 0.06854589490103535, 0.02647868990607094, 0.049545793735887855, 0.05823288462124765, 0.03282247176684905, 0.07693913241382688, 0.019232834965805523, 0.0418545871070819, 0.08684854052262381, 0.013461459548125276, 0.019015051730093546, 0.044944363107788377, 0.04155694135988597, 0.03557174299203325, 0.040796303073875606, 0.026084123383043334, 0.0805036083329469, 0.009026001898746472, 0.0245350292607327, 0.07105862881871872, 0.057396513875573874, 0.029786336344841402, 0.0030156022830851725, 0.08717768301721662, 0.04664500193030108, 0.0374510427354835, 0.03114607148745563, 0.04926177382003516, 0.02143403013178613, 0.015991992950148415, 0.07077305781422183, 0.026119126778212376, 0.040845006515155546, 0.05499418555700686, 0.020519579884421546, 0.0151384785931441, 0.04060308863699902, 0.010438617846375564, 0.07462635534466244, 0.014828141192992916, 0.03469322939054109, 0.05073244705272373, 0.017167903679364827, 0.02069686226604972, 0.02842696299921954, 0.035139879837515764, 0.05145584807905834, 0.012491226698330138, 0.03660564005258493, 0.07337024813750759, 0.061059598956489936, 0.023150899723987095, 0.04474402405321598, 0.03295927555882372, 0.030209013566491194, 0.07647708611330017, 0.01006525541015435, 0.09245807115803473, 0.0410823601851007, 0.002485325708221353, 0.05590401036897674, 0.02816967524267966, 0.008501293286826694, 0.025466407896601595, 0.027552123028726783, 0.043271781178191304, 0.05154437887540553, 0.014888515834172722, 0.015019160728115821, 0.013065756611467805, 0.07862482438213192, 0.04118321063288022, 0.019265736227680463, 0.024372986881644465, 0.013941797005827539, 0.06122695325757377, 0.015377360159618547, 0.06340930529404432, 0.07272320668562315, 0.02762217805866385, 0.017892126634251326, 0.06166703569761012, 0.05848897009855136, 0.07194138379418291, 0.015073331942403456, 0.06176075039547868, 0.004943235553582781, 0.03827884909696877, 0.02542120924772462, 0.04741608594486024, 0.022791581504861824, 0.17094901209929958, 0.027340642482158728, 0.026882370002567768, 0.06285149967879988, 0.04588073083141353, 0.11305165986414067, 0.13519472675397992, 0.007246838749779272, 0.09885092382319272, 0.08906938775908202, 0.06638853839831427, 0.03918302616511937, 0.09362866810988635, 0.04944783024257049, 0.030507586998282932, 0.05230191869486589, 0.04385666405141819, 0.03776970239414368, 0.02889963870984502, 0.048782275916892104, 0.09922437253408134, 0.04881799177383073, 0.042239286776748486, 0.03759738683584146, 0.016806052881293, 0.05934995046118274, 0.04028672592539806, 0.04429327695106622, 0.042177662544418126, 0.07057864480884746, 0.054385312760132365, 0.012500129687396111, 0.008838005687721306, 0.04158969233685639, 0.028514586520032026, 0.02861879147530999, 0.03868259227601811, 0.01824049075366929, 0.042777648122864775, 0.028119558010075707, 0.07322564066271298, 0.007313587511816877, 0.019163971082889475, 0.06238669258891605, 0.03879812982631847, 0.055293731202255, 0.0576830496720504, 0.037491378461709246, 0.020215241820551455, 0.013974634257465368, 0.05797911464469507, 0.044893422091263346, 0.05330329113348853, 0.03402896640182007, 0.018203670952061657, 0.0293079331095214, 0.025631324242567644, 0.0468339378858218, 0.050972505850950256, 0.04309547657612711, 0.05393571969761979, 0.017679877964837942, 0.07070383770042099, 0.05860596225829795, 0.03761578096600715, 0.06612898709136061, 0.026829312009795103, 0.024082710660877638, 0.019333201162226032, 0.011144247218908276, 0.04012138655525632, 0.012464414758142084, 0.07455043363734148, 0.04047914255352225, 0.029781555058434606, 0.06602048510103486, 0.014252220680646133, 0.03527364453475457, 0.01688694697804749, 0.005144552851561457, 0.05927359088673256, 0.049073772970587015, 0.06758875446394086, 0.01611575535207521, 0.021878500519960653, 0.07230096918647178, 0.04246037256962154, 0.01989506446989253, 0.1922572444891557, 0.1415530769736506, 0.1419154676841572, 0.1564220798900351, 0.10702846353524365, 0.1567460867227055, 0.06353616059641354, 0.1490403525531292, 0.14336844440549612, 0.10715247641201131, 0.15976641996530816, 0.12993913376703858, 0.09351483749924228, 0.13857360638212413, 0.0901028209773358, 0.12591363571118563, 0.26910779415629804, 0.10278187226504087, 0.12496704119257629, 0.11368793275323696, 0.15498017601203173, 0.1330125008826144, 0.22369246784364805, 0.08495705100358464, 0.17849877651315182, 0.11217577717616223, 0.13937276584329084, 0.23974371200893074, 0.1350000168895349, 0.11961348471231759, 0.14586882898584008, 0.17981740966206416, 0.08965438566519879, 0.2682493964675814, 0.06155571354611311, 0.1225902687292546, 0.1806302840122953, 0.17045040760422125, 0.10903120841248892, 0.11128194935736246, 0.1834798787604086, 0.16883203585166484, 0.13169125537388027, 0.21087496890686452, 0.17443517659557983, 0.1533463824307546, 0.13639181095641106, 0.1095117193472106, 0.09166298608761281, 0.2215561957564205, 0.17417404451407492, 0.12025500458548777, 0.20480149949435145, 0.05866648811206687, 0.24014303198782727, 0.1261973736109212, 0.07500249063014053, 0.214404504513368, 0.13861800165614113, 0.11128932630526833, 0.07700977002969012, 0.15370109933428466, 0.17652000300586224, 0.17284049419686198, 0.06979936748393811, 0.06571736230398528, 0.10270462953485548, 0.12282788957236335, 0.08599556051194668, 0.1094705969444476, 0.15211382356937975, 0.1070040394552052, 0.12735458964016289, 0.11330891051329672, 0.23700214427663013, 0.13879642880056053, 0.08380698927794583, 0.17299800761975348, 0.20613231870811433, 0.1422266650479287, 0.14138793427264318, 0.16597469308180735, 0.27380832005292177, 0.31589794903993607, 0.11904036859050393, 0.10826787241967395, 0.15785144147230312, 0.175542357028462, 0.29849405167624354, 0.20565878396155313, 0.2538952510803938, 0.1549458591034636, 0.15294768585590646, 0.15261686610756442, 0.13781007000943646, 0.1913751129177399, 0.20438226027181372, 0.36558598279953003, 0.18669900367967784, 0.20878947456367314, 0.28246443369425833, 0.1897757253027521, 0.08013171813217923, 0.17684185761027038, 0.19024842884391546, 0.10591027705231681, 0.23399617901304737, 0.18674807448405772, 0.1817302210838534, 0.11014595875167288, 0.13247724913526326, 0.1148371261660941, 0.11008337343810126, 0.10967915528453887, 0.12386200556647964, 0.09575691758072935, 0.18629088182933629, 0.083421280287439, 0.21654220152413473, 0.13072692352579907, 0.14695911813760176, 0.09907289277180098, 0.11103674376499839, 0.12621683272300288, 0.15020058170193806, 0.12362364999717101, 0.11292011418845505, 0.11077427581767552, 0.15300686471164227, 0.11900171753950417, 0.15573991258861497, 0.12113981531001627, 0.12236165013746358, 0.10252298146951944, 0.1587909707450308, 0.12044524672091939, 0.0969735425314866, 0.09893768830806948, 0.08003621114767157, 0.07985063712112606, 0.1590222684899345, 0.12595495849382132, 0.12493888410972431, 0.13192313199397177, 0.13830181705998257, 0.10679776692995802, 0.13801779714412987, 0.1350317956530489, 0.23631317890249193, 0.17382435937179253, 0.2034612253191881, 0.18527577223721892, 0.11722609211574309, 0.19599532359279692, 0.11189128228579648, 0.14040561276488006, 0.14729897724464536, 0.13822451495798305, 0.12661742919590324, 0.10663475419278257, 0.13328571512829512, 0.16411237738793716, 0.1403891370864585, 0.1401956591871567, 0.1258730996050872, 0.09926475278916769, 0.09551497001666576, 0.13014870142797008, 0.18146609072573483, 0.11840060018585064, 0.10981884232023731, 0.09048890846315771, 0.059710188943427056, 0.24707527016289532, 0.13848325732396916, 0.13865432236343622], [0.017357733922835905, 0.06513934800750576, 0.022990412144281436, 0.04822740549570881, 0.012708375397778582, 0.04248397657647729, 0.04623250883014407, 0.011285952896287199, 0.05461488130094949, 0.03987719399447087, 0.0934778488590382, 0.06686835913569666, 0.022804363143222872, 0.033276918475166894, 0.041172122946591116, 0.016163690670509823, 0.09483557834755629, 0.059089408387080766, 0.02987055340781808, 0.03878034796798602, 0.013321171372808749, 0.05363028139981907, 0.04008041258202866, 0.00990579941571923, 0.0586141184612643, 0.04899132407444995, 0.029005667493038345, 0.03580133379728068, 0.028134349013271276, 0.044203165380167775, 0.04915106394037139, 0.010100286635861266, 0.02731211618083762, 0.03543832710420247, 0.03133649915980641, 0.0641537610499654, 0.016565081241424195, 0.02483507585566258, 0.05088971185614355, 0.045369940271484666, 0.06947493020561524, 0.015487912332901033, 0.08340168758877553, 0.03901946052792482, 0.02503894196706824, 0.04026332600915339, 0.025259684516640846, 0.019217520748497918, 0.04213137108308729, 0.038649373746011406, 0.053565473353955895, 0.012114318651583744, 0.033483999941381626, 0.0895669161400292, 0.06571670179255307, 0.062318971613422036, 0.007374054921456263, 0.035025937904720195, 0.09642233460908756, 0.06837864450062625, 0.024390935723204166, 0.06621958105824888, 0.04313670659030322, 0.05598375413683243, 0.025966706343751866, 0.0066248359689780045, 0.025992998780566268, 0.0273651927273022, 0.05551819005631842, 0.08511097985319793, 0.05756720413046423, 0.027664504596032202, 0.006102011948314612, 0.016574987057538237, 0.015991434484021738, 0.040416776173515245, 0.019759286697080825, 0.07479625521227717, 0.02033164768363349, 0.05861906858626753, 0.06470075357356109, 0.06261966758756898, 0.04290002827474382, 0.037204389955149963, 0.06804717908380553, 0.014693301309307572, 0.11807273418526165, 0.0498646166670369, 0.029927708055765834, 0.014100368916842854, 0.01672062797297258, 0.035498337165336125, 0.07857776479795575, 0.06251351078390144, 0.039115071413107216, 0.0640855502570048, 0.06227780468179844, 0.02181056061090203, 0.06256999564357102, 0.025075461198866833, 0.03201097781129647, 0.11475966079160571, 0.02191824994952185, 0.0017939039412340207, 0.02558381194830872, 0.02574394329712959, 0.031067377858562395, 0.026223580352962017, 0.019535451247065794, 0.02585962927696528, 0.04755057052534539, 0.067643124202732, 0.054707757371943444, 0.013807423747493885, 0.07485192370950244, 0.0016804316487650794, 0.030981605996203143, 0.023911192911327817, 0.0017358628906549711, 0.028752630387316458, 0.027524732213350944, 0.03162748413160443, 0.02739578776527196, 0.03182596781698521, 0.028786539114662446, 0.035333684281795286, 0.06058240913262125, 0.07066014004522003, 0.044496016853372566, 0.027702597180905286, 0.026601092322380282, 0.05291930021485314, 0.02514367013645824, 0.02067591700324556, 0.05512911913683638, 0.037938277528155595, 0.004850543164138799, 0.012938035779370693, 0.09158177286735736, 0.022025468024367, 0.05537331169762183, 0.024791860596451443, 0.02796953842334915, 0.04573899546812754, 0.05672344530466944, 0.03177107486408204, 0.0659595696197357, 0.033119586878456175, 0.02282259585626889, 0.028061789234925527, 0.054559676646022126, 0.02997079714987194, 0.012782467711076606, 0.009298224449594272, 0.04968000743247103, 0.021053766649856698, 0.03852539426588919, 0.027042736983275972, 0.02643791445734678, 0.04251565143931657, 0.0018996416633854096, 0.08694710515555926, 0.04952937742928043, 0.06481508142314851, 0.11299624369712546, 0.08278265479020774, 0.024226041641668417, 0.04764611090649851, 0.03068410496780416, 0.012416633435350377, 0.016512318252352998, 0.06240065980819054, 0.017199378162331413, 0.06088769900088664, 0.022771239237044938, 0.023604351954418235, 0.018563762860139832, 0.09120247603277676, 0.038276604100246914, 0.01123947125961422, 0.02107698473992059, 0.03664187912363559, 0.046489778032992035, 0.03905588513589464, 0.03264736573328264, 0.022472077653219458, 0.06240311631700024, 0.04125063103856519, 0.003422426070756046, 0.05589723456068896, 0.02304374473169446, 0.03215678014385048, 0.04422949306899682, 0.1042536624299828, 0.08114580356050283, 0.05400628309871536, 0.06334909485303797, 0.0651750824181363, 0.023620892570761498, 0.07955181135912426, 0.04354901786427945, 0.05086725446744822, 0.07552466573542915, 0.027903431619051844, 0.03499873819237109, 0.05340446070476901, 0.017623302192077972, 0.012963234476046637, 0.0038505815018652356, 0.028104210396122653, 0.030733318635611795, 0.013841635827702703, 0.02829144497809466, 0.018414030855637975, 0.02019127416133415, 0.03307869454147294, 0.020929920756316278, 0.08913561701774597, 0.035892161540687084, 0.03421417306526564, 0.06672112445812672, 0.045822197644156404, 0.04607672832207754, 0.022890409600222483, 0.05921244533965364, 0.01272663686904707, 0.047044333041412756, 0.014409485484065954, 0.0397292802517768, 0.08944443208747543, 0.02641132516146172, 0.08130740621709265, 0.00971050510997884, 0.019122073135804385, 0.012135596953157801, 0.0866243673954159, 0.062252801726572216, 0.029598287255794276, 0.03790068032685667, 0.059282745278324, 0.020084325115021784, 0.035849873966071755, 0.058204304514219984, 0.01690414996119216, 0.04933932454150636, 0.05999989742122125, 0.07437809952534735, 0.015763222218083683, 0.10265119490213692, 0.021458292794704903, 0.044575612191692926, 0.11475277366116643, 0.07993934603291564, 0.04292013305530418, 0.029043431677564513, 0.06649946721154265, 0.03595615693484433, 0.06051249511074275, 0.0549832425895147, 0.050935472681885585, 0.04768938182678539, 0.023344034379988443, 0.1551879773614928, 0.013853628006472718, 0.03909524864866398, 0.03253379858506378, 0.012173379691375885, 0.038625239103566855, 0.1377699346630834, 0.09462041489314288, 0.08649446928757243, 0.10170959503739141, 0.018164893735956866, 0.021473796259670053, 0.021444982376124244, 0.04848168384341989, 0.023899073639768176, 0.05232839481323026, 0.01831883371778531, 0.0480270256230142, 0.0072761364208417945, 0.03292398643679917, 0.03965479460021015, 0.016417859551438596, 0.03897671282174997, 0.03253875613154378, 0.08878729000571184, 0.052452841846388765, 0.03024032663233811, 0.019804431540251244, 0.051430674429866485, 0.04150040454987902, 0.04619558327249251, 0.05517694684385788, 0.03857858770061284, 0.08099594910163432, 0.10002842274843715, 0.014564091543434188, 0.04838364613533486, 0.026526513902354054, 0.025150058172584977, 0.03151711563987192, 0.0362622928514611, 0.02809696703479858, 0.039595226116944104, 0.04902688036963809, 0.03988090102211572, 0.008522413882019464, 0.06178652147355024, 0.03909391278284602, 0.04691853901022114, 0.05828047484101262, 0.015706147351011168, 0.0324208771053236, 0.007674477692489745, 0.04000117347459309, 0.04547633827314712, 0.04586609567923006, 0.008580678968428401, 0.06903467336087488, 0.047001733764773235, 0.022846943866170477, 0.07254924727021717, 0.024695247811905574, 0.06056061225535814, 0.03630731895100325, 0.040224567346740514, 0.03810616246482823, 0.05040307078161277, 0.03707741961989086, 0.02924493033788167, 0.03666599892312661, 0.12975708494195715, 0.03043391028768383, 0.009488043560850201, 0.04359894955996424, 0.025114409108937252, 0.01829981803894043, 0.023609376294189133, 0.024265907959488686, 0.017182052724820096, 0.017761809212970547, 0.09223121145623736, 0.03960886308050249, 0.042506029494688846, 0.04751194173877593, 0.06205962439707946, 0.06546319898916408, 0.02361658996960614, 0.005421192572612199, 0.02074246538541047, 0.05885094520635903, 0.11615876501309685, 0.16959365748334676, 0.14987428905442357, 0.09295251220464706, 0.09208082265104167, 0.11452186183305457, 0.11562223677174188, 0.11236178906983696, 0.13034510338911787, 0.15582227613776922, 0.2472634639707394, 0.15449859638465568, 0.08142364138620906, 0.12297002569539472, 0.07709407058428042, 0.15088407002622262, 0.16512037720531225, 0.17644997395109385, 0.11138772024423815, 0.1189793121011462, 0.14451662107603624, 0.29972500749863684, 0.10238727234536782, 0.20256321178749204, 0.14971116499509662, 0.12108416165574454, 0.1888588909059763, 0.08406482622376643, 0.23566960328025743, 0.1410139215295203, 0.0692645758681465, 0.11460815876489505, 0.08270717837149277, 0.1806518656667322, 0.1885228612809442, 0.14160501246806234, 0.12320818088483065, 0.09994688298320398, 0.13462226372212172, 0.0988737671286799, 0.10100755302119069, 0.13186941534513608, 0.23407918080920354, 0.10315510575310327, 0.12353639569482766, 0.1344859757227823, 0.19096059375442564, 0.10771041561383754, 0.1216038283018861, 0.14191034686518833, 0.11229990137508139, 0.06867563715786673, 0.1174335743417032, 0.1677224360173568, 0.12947964045451954, 0.22616275091422722, 0.12880919908639044, 0.09860086458502337, 0.14270861574914306, 0.23166332684922963, 0.13060783850960433, 0.1502379117300734, 0.12330192897934467, 0.1623664007638581, 0.19227146403864026, 0.1683809733367525, 0.13177188229747117, 0.18366829521255568, 0.13526952039683238, 0.22097442619269714, 0.13395205984124914, 0.21932712552370504, 0.14669586351374164, 0.11476840329123661, 0.11700808623572811, 0.19642907922388986, 0.20017075032228604, 0.2306669342215173, 0.07052685032249428, 0.1442366384435445, 0.16752852767240256, 0.21336957957828417, 0.17251331097213551, 0.10196858231211081, 0.19310611300170422, 0.07188751129433513, 0.4067770193796605, 0.1372022065334022, 0.21438501571537927, 0.13124899473041296, 0.11768174852477387, 0.11516591242980212, 0.3346266393782571, 0.22811215021647513, 0.21633229247527197, 0.22736464423360303, 0.18989987176610157, 0.09021767575177364, 0.09078947085072286, 0.1515210108482279, 0.17733056185534224, 0.16941974259680137, 0.13011347909923643, 0.06489727427833714, 0.13894459116272628, 0.15492933889618143, 0.17408823739970103, 0.10042629553936422, 0.06996423559030518, 0.10370718198828399, 0.16023516043787822, 0.15207535063382238, 0.09277297183871269, 0.1164234297175426, 0.1406865898752585, 0.11960239702602848, 0.09704012059955858, 0.0728665896167513, 0.13618706725537777, 0.10028289034380578, 0.24611792934592813, 0.18406997522106394, 0.11463469054433517, 0.20902501739328727, 0.059983551618643105, 0.13127016078215092, 0.10920358705334365, 0.1283680516644381, 0.1445128658087924, 0.2150393376359716, 0.13385308702709153, 0.1786128297680989, 0.1883470464963466, 0.09670339335571043, 0.22589403408346698, 0.20829367538681254, 0.10151182010304183, 0.05909620274906047, 0.13864900858607143, 0.16140809515491128, 0.15899025223916396, 0.21689294051611796, 0.13975654524983838, 0.14240483986213803, 0.2568125742254779, 0.10060467815492302, 0.16701441229088232, 0.12671301781665534, 0.12803398130927235, 0.17795831488911062, 0.09889980166917667, 0.13897473720135167, 0.06364015775034204, 0.13692568230908364, 0.09128203426371329, 0.1798318963847123, 0.18281316297361627, 0.1003874812158756, 0.1587767363525927, 0.152473587077111, 0.08344838352059014, 0.11390073617803864, 0.18020691844867542, 0.14831381966359913, 0.1818305891356431, 0.14605846256017685, 0.18585365294711664, 0.12960593914613128, 0.12772403075359762, 0.10953094097203575, 0.09940110016032122, 0.13438980822684243, 0.12992613133974373, 0.12559393333503976, 0.16767701657954603, 0.1272103309747763], [0.016338935856765602, 0.014072008671064395, 0.04104394291061908, 0.04957122713676654, 0.08428114000707865, 0.03243078477680683, 0.056160244275815785, 0.04493521984841209, 0.004742573200928746, 0.020909131344524212, 0.02260145811305847, 0.036485631062532775, 0.012027413158648415, 0.025332819459435996, 0.02229209385404829, 0.001244836998921528, 0.022435640057665296, 0.0616107809037203, 0.042116516997339204, 0.032439178467029706, 0.02917442445323104, 0.02855792423360981, 0.016141008782142308, 0.07112495455658063, 0.029102588268870022, 0.013827894963469589, 0.016438077509519644, 0.04334207740612328, 0.05687769327778369, 0.043777139217127115, 0.041307305145892315, 0.042261836933903396, 0.013020282440265873, 0.05850838468177244, 0.07907006103778258, 0.04884541413048282, 0.049593933144933544, 0.04223677460686304, 0.03299237163446378, 0.025240357135771774, 0.023510054670623504, 0.03747653550817631, 0.02551152490923414, 0.06389772752299905, 0.059752224187832326, 0.08036799568799324, 0.03657603949250188, 0.0718414832954295, 0.02501860526535893, 0.02128879368683556, 0.016117746163217817, 0.032992367923725396, 0.1160444000561256, 0.007971470349730225, 0.0502611090632854, 0.03265626779466402, 0.053017998434370384, 0.03723670306499116, 0.0623548989824485, 0.022240264115680475, 0.02790502167044906, 0.026959942988469265, 0.018939000146929175, 0.030720056456630118, 0.07539528713095933, 0.0442313781240955, 0.014690981170133455, 0.027426215820014477, 0.10714549280237406, 0.02613084900076501, 0.027305616822559386, 0.018286051199538633, 0.03609544692153577, 0.07250505979754962, 0.04529575147898868, 0.06272310813074, 0.08173028196324594, 0.03427504772844259, 0.04996376017516013, 0.04338659142376855, 0.03277075520600192, 0.043352445209166035, 0.04315993210184388, 0.02374411134951515, 0.03291598608484492, 0.12016547188977711, 0.03312314918730408, 0.020373002007545438, 0.0409099963871995, 0.034260828178958036, 0.03991443867562339, 0.09052532564965077, 0.0571203013532795, 0.04097914228623267, 0.05156602732313331, 0.02082288821839029, 0.0698087111231871, 0.021105492487549782, 0.0372340164904017, 0.056661802518647164, 0.021228870828053914, 0.051141036456101574, 0.04593420999299269, 0.009553285763104213, 0.04304853944631759, 0.047649309562984854, 0.059756113041657954, 0.05639436589262914, 0.017485401876911055, 0.04887972732831258, 0.009162725909845904, 0.07858641823986545, 0.06030734693922568, 0.030337026619235985, 0.06728272244799882, 0.03787898735026829, 0.05548162072955165, 0.03577050127205439, 0.009984198968595592, 0.07186941031250171, 0.040499124879715964, 0.062033968351897784, 0.014207186231942615, 0.04800475748197641, 0.06663315769401379, 0.014703846300108125, 0.03711010380357038, 0.04952973366016522, 0.07714885592577048, 0.03939273483410943, 0.08369650575332344, 0.08643446664791554, 0.04408645152579993, 0.04508094054472167, 0.00975296059550601, 0.008755644921620842, 0.01736502737912815, 0.011638841333478922, 0.030975229092291556, 0.08449637767625973, 0.030243716391851194, 0.0024080011098703835, 0.029877126980863977, 0.03095981097430922, 0.09874889336060733, 0.06577837426448241, 0.02251814275950892, 0.015353805320046376, 0.019965735482401215, 0.027945683941652533, 0.03563845093594864, 0.036316157929832116, 0.04432496665685903, 0.015958883886924013, 0.04135725539526902, 0.05468116622068919, 0.015137896007217932, 0.046736185904592276, 0.03033218781638425, 0.014184818828653079, 0.026500438543735072, 0.029023056013102178, 0.05134743514645379, 0.04232733517710585, 0.044793157940148376, 0.05189582290768158, 0.021558710941462778, 0.00565483689570101, 0.020353511354187503, 0.015563577999273548, 0.09097675181692466, 0.06668059577350505, 0.0386341708508553, 0.00752450634536217, 0.04261142930772621, 0.05361945346521679, 0.01196864712255774, 0.028275854310777504, 0.09748871176270768, 0.05869763976079412, 0.04371445742435753, 0.03376745211426169, 0.0550973329518456, 0.13536573242163286, 0.022743349327356555, 0.021475818612088915, 0.01548945321701467, 0.06743944919435307, 0.04016030106868129, 0.036822202455368824, 0.03547603191691451, 0.029257734240673017, 0.02323124648683006, 0.024885905550036114, 0.062473375437548384, 0.06241890921955928, 0.04407690379593987, 0.014981395615905058, 0.03262232567067258, 0.03960978705435991, 0.01985771959880367, 0.05250807247648481, 0.06772251916117966, 0.059949639180558734, 0.028614884067792445, 0.04989380162442103, 0.05215251323534176, 0.02962675418530125, 0.01627237448701635, 0.03821033031272236, 0.027882204340130556, 0.029979784558236133, 0.026483285655558575, 0.052925471172784455, 0.0890268552757334, 0.00949422101257369, 0.011704548305715434, 0.030955317270127125, 0.06590728531591594, 0.05886213679332286, 0.025212804903276265, 0.05078156609670259, 0.026146289383177646, 0.037259245800669305, 0.01940639176609693, 0.04320060179452412, 0.044432874929043464, 0.04226613396895118, 0.07263642735779285, 0.015729287515569013, 0.07981591203133576, 0.03576921735657379, 0.03848424588795751, 0.017625795808271505, 0.024019809934543446, 0.05328408064087853, 0.050839661416830495, 0.011233346685912693, 0.008076548256212845, 0.041663294832687825, 0.06294249440543354, 0.02256800580653362, 0.04644176849978976, 0.03363284507940989, 0.006698785882690572, 0.052450570874498226, 0.024287239139084704, 0.06439888500608504, 0.05209623988776002, 0.037556216193479486, 0.014494025381281972, 0.1548871403792873, 0.01578995808813488, 0.01347965329841827, 0.03849829845421482, 0.027447934771771543, 0.012512146913650213, 0.041430256751482375, 0.031453584088012576, 0.04960076461429708, 0.035530709646991454, 0.07021492565399967, 0.02043078562564915, 0.05075045526609756, 0.042162259269389324, 0.05968011711956933, 0.04937347075610887, 0.08000947156688198, 0.06586364703252912, 0.05421274858235847, 0.09094999739318155, 0.06703472638037056, 0.021895662684983108, 0.04227853525662795, 0.022418620756070595, 0.03255193667428102, 0.044942630192963406, 0.030340351440827362, 0.05063614225946367, 0.06629844167036936, 0.03743164299521595, 0.057293347927043214, 0.009023516631714301, 0.05062131414888427, 0.0659510052355472, 0.05954471598670352, 0.024883198566385545, 0.032570794646744616, 0.022949755439185537, 0.04667905537644401, 0.06835284002590925, 0.05329041858203709, 0.057375102915102616, 0.06307953197392635, 0.08491878586937673, 0.04439045747858472, 0.03437289247813169, 0.04251841593941208, 0.055713011242914945, 0.03376764136191923, 0.057001361055881716, 0.011744762505259132, 0.03377819841261953, 0.026203564630122855, 0.0687599451339338, 0.032501696987310424, 0.044716475531458855, 0.08484864549245685, 0.009702378592919558, 0.022656866858596914, 0.08506580532412045, 0.09302550985012203, 0.03360057649842929, 0.042341855296399444, 0.07388307960354723, 0.09643442419474013, 0.021699112294299994, 0.06461502067395486, 0.020007093517051544, 0.05984681461995933, 0.020182615153316874, 0.03717545732797589, 0.038177868773345836, 0.03375869848241564, 0.029808775179844815, 0.040372674047830515, 0.043044698832090944, 0.049754433712223545, 0.04700613470049575, 0.04534993939159904, 0.06791086139855906, 0.023234691907418892, 0.021902809567109216, 0.06353853546897881, 0.03091621165367542, 0.03069006255827844, 0.01805084233637899, 0.0482661604473833, 0.019745627469092142, 0.07265488457051106, 0.06016141844156664, 0.06401115737389773, 0.026302442820451688, 0.024372806910832878, 0.05306223414663691, 0.021470308165589813, 0.07390141807263717, 0.0763570140406955, 0.08237214322434738, 0.007919385498098563, 0.01790786387573462, 0.057229211524827406, 0.09662223208579235, 0.11307302629575133, 0.19890892115654424, 0.18745540059171617, 0.13152364874258637, 0.13743927818723023, 0.10601429647067562, 0.1293783076107502, 0.09434967942070216, 0.07138817949453369, 0.09858635559794493, 0.10766874402179383, 0.12143665953772143, 0.09814528981223702, 0.1401290885405615, 0.08252319996245205, 0.08679516526171938, 0.21722082135966048, 0.13437034911476076, 0.13864632201148197, 0.12440464910469018, 0.11343088248395361, 0.08605873954365961, 0.20313778251875192, 0.12453813920728862, 0.15729106060462072, 0.10968712595058605, 0.14173043542541564, 0.18336086795898154, 0.08728780288947746, 0.13313240226125345, 0.13515405706129968, 0.10529931139899418, 0.18063892261125147, 0.1663620347972028, 0.181705700524617, 0.15583110769512132, 0.12384381552692503, 0.23628747090697289, 0.1076089491834864, 0.09790975440409966, 0.09871565998764709, 0.18258719384903088, 0.14472696057055146, 0.15252975281327963, 0.10613566730171442, 0.11657435286906548, 0.26580081379506737, 0.12188927314127795, 0.15089189226273447, 0.1500879682134837, 0.15394179266877472, 0.15387361898319796, 0.07122463241103105, 0.1411979296244681, 0.09444211391382851, 0.2212736156070605, 0.10967840571538545, 0.12347247451543808, 0.13276536570629105, 0.11660758624202572, 0.08848916928400286, 0.11360744683770463, 0.1421992649557069, 0.17870452953502536, 0.15727887453977019, 0.17665885883616284, 0.162913482345175, 0.25804382690694183, 0.15920646954327822, 0.16876303096069023, 0.12604492163518444, 0.14188861678121611, 0.08159113669535145, 0.16329837497323751, 0.25182997283991426, 0.13175182946724817, 0.0966809804958757, 0.09960760275134817, 0.20364554511616006, 0.11333694885252044, 0.1059095942764543, 0.055272802637773566, 0.1437537229503505, 0.11564257903955877, 0.1886716767330654, 0.1206294032454025, 0.10285310359904543, 0.14538293005898595, 0.24815868702717125, 0.14092777302721515, 0.24386018252698705, 0.16201500868191943, 0.1352807119837962, 0.10600507899653167, 0.14872121420921758, 0.13163411000277847, 0.1500837379717268, 0.0775866191543173, 0.09779878848348744, 0.1632358119240962, 0.1727060170378536, 0.1459606474963948, 0.1565735522308387, 0.17644176579779014, 0.14095336227910593, 0.14586810168111697, 0.1414627576014027, 0.10094991041114554, 0.10632653284119442, 0.054170190123841166, 0.18125707225408405, 0.19617887155618519, 0.12996601435588673, 0.12738063902361318, 0.1013119968411047, 0.1449175737798214, 0.16760539932874963, 0.24730996694415808, 0.1271582322078757, 0.1266388624208048, 0.1493347476935014, 0.16918103821808472, 0.1438844745280221, 0.1621354592498392, 0.13931467052316293, 0.18587559083243832, 0.09066357291885652, 0.21402816142654046, 0.23105176747776568, 0.11068840933148749, 0.19101453304756433, 0.21024288173066452, 0.09999642134062015, 0.1657504605827853, 0.11631736197159626, 0.12213549547595903, 0.07871673195040785, 0.11569638474611565, 0.18705352762481198, 0.13056540250545368, 0.13175982981920242, 0.16387971409130841, 0.12614389444934204, 0.22320410498650745, 0.1625844437512569, 0.11129617632832378, 0.0671395547396969, 0.1766711488016881, 0.17686541337752715, 0.13455437205266207, 0.07478564992197789, 0.18361947673838586, 0.11386425961973146, 0.12925007933517918, 0.1441889480338432, 0.1018708488845732, 0.15620022226357833, 0.1575353162479587, 0.16189132235012949, 0.09796819853363559, 0.11412381092668511, 0.088596610003151, 0.15766974887810647, 0.17205835960339755, 0.12839845003327355, 0.10438796147354878, 0.11233349840040319, 0.14317916706204414, 0.13873442978365347, 0.10763884289190173, 0.1819504756713286, 0.16190947528230026, 0.10625872280797921, 0.11549360031494871, 0.10820689014508389], [0.04938688507536426, 0.020506894725258462, 0.0593602292065043, 0.015930528279568534, 0.05413595856225584, 0.034884900160250254, 0.03312013235699851, 0.05033390632888768, 0.05064509627118241, 0.06500435134512372, 0.002178921690756397, 0.01843756064772606, 0.012215388032927876, 0.01909195492771687, 0.02310120366018964, 0.04568987642414868, 0.011081970824307064, 0.07410329708363861, 0.031825878759264015, 0.05482366599608213, 0.0331187630945351, 0.023443988684448414, 0.03612067252106499, 0.06484994009952061, 0.04461208503926173, 0.01549532917124452, 0.04708660577307455, 0.0468702994112391, 0.020021337186335586, 0.057023829576792195, 0.010576423537713708, 0.022659033929812722, 0.03329747967654839, 0.042765321049955674, 0.03766935660678428, 0.019700521588674746, 0.01136699542257702, 0.009233582459273748, 0.032450986036565155, 0.0528481319634011, 0.021785902754345443, 0.057259873356088065, 0.046780688790022396, 0.07866110056056641, 0.04003110057965387, 0.056475931633030996, 0.06383973610354587, 0.044332863108138554, 0.05572499692789279, 0.04788256286701653, 0.016473283139930572, 0.0030494734392050304, 0.05487546790391207, 0.043919520248891786, 0.09301255937316455, 0.0705187905987259, 0.04970738897100091, 0.037674640698242, 0.034910849353764206, 0.07668232705327682, 0.021218597648839932, 0.03864497281028889, 0.018326906429138035, 0.06390596536220983, 0.017697802686598152, 0.06665243869065307, 0.022641513678536285, 0.02384088555118069, 0.028827412897953764, 0.05038765266363043, 0.05016054063162301, 0.026625664831954055, 0.041352071493747644, 0.06435751027311198, 0.06778117851354182, 0.023649188806302845, 0.02970463701785775, 0.02513528015697375, 0.026530855466262437, 0.08707281755050644, 0.04593142322846688, 0.04832464910577983, 0.0114976004260825, 0.018203086510766298, 0.02134461246896535, 0.021814249084854964, 0.09546209199470468, 0.0385417920188047, 0.030177160588209517, 0.06718757911585271, 0.05911529078730382, 0.04128884422243573, 0.04620614774466958, 0.04084076514118351, 0.03970603247580584, 0.04947549008647911, 0.05443167843623087, 0.036474086955422536, 0.05392764142015949, 0.073688503325684, 0.10958832383039407, 0.016019073918869253, 0.043629377614706755, 0.06624277317314409, 0.03125121525954455, 0.02519369274523342, 0.0982739930623211, 0.05977826986054424, 0.012186393250885885, 0.03140951906971168, 0.07609168882481754, 0.028293949726503342, 0.06474874084233306, 0.08019027358386666, 0.028161326081317384, 0.0365521979983896, 0.10965874622343108, 0.08015804953174666, 0.04089239635504782, 0.0210487423100858, 0.05121945920109283, 0.005755768515882664, 0.025139059544017073, 0.047914204333210364, 0.08396856224862859, 0.08256809247541241, 0.023115486292226706, 0.007620482274433016, 0.027980230916000437, 0.0753132278623525, 0.009884740047709784, 0.06528059355332516, 0.029640916218340863, 0.07344968762481585, 0.040565984963905066, 0.03759918283321895, 0.05528814283024985, 0.036153660985291936, 0.03443186724325642, 0.06845164214610122, 0.018242915721202735, 0.02412846777588129, 0.055357285018544644, 0.04384427760669496, 0.10301282862201333, 0.029249828512547538, 0.05821512131660711, 0.04595900514686946, 0.0771206097851973, 0.033313881140202284, 0.04530515077931341, 0.03823328122962266, 0.05062915864982642, 0.034784283488988876, 0.10058613188448362, 0.0859427715477068, 0.05609986314084381, 0.024443526162940543, 0.019014983081433456, 0.017692700421321206, 0.05082088508061133, 0.05032607296016067, 0.059367613575886935, 0.03863023746816907, 0.02150317232008092, 0.04652621006243862, 0.07200157197075896, 0.06116641998232808, 0.03108151206106413, 0.06860373046947643, 0.07114554915460758, 0.05722882560803555, 0.08104260050458834, 0.021323468681657687, 0.03657383902464062, 0.0772235901968088, 0.0160960606081062, 0.023936034449434374, 0.007045017719065072, 0.025358718557981774, 0.006012139256199589, 0.02803756739012897, 0.03491340234177187, 0.09011577145429328, 0.028838014477514662, 0.01728116098092869, 0.009697342193248915, 0.06970737827941775, 0.10858300316613168, 0.04038847437186632, 0.049891753296833485, 0.06965666732867248, 0.010181310608459171, 0.027710627218766604, 0.02251468806207413, 0.015687280101701617, 0.038586873779422604, 0.025608660907892045, 0.07595151197165251, 0.051199591907789, 0.03113995619060006, 0.025634535886638332, 0.12089636860764585, 0.02194768538174685, 0.03334970089781564, 0.039874396097729914, 0.023811745122657157, 0.016031365739763714, 0.04973309325578157, 0.019469481740088668, 0.06849231926025823, 0.03460796404397115, 0.040934390781330876, 0.03580461780074984, 0.04759761897730641, 0.039028715109452605, 0.06508626218419522, 0.010186953713855473, 0.04574302161927335, 0.04762703028973192, 0.02040586987277493, 0.08711998103535734, 0.03378486289875582, 0.06451345034292899, 0.005434129134300747, 0.04989325243514031, 0.02868964060326107, 0.03730095078935847, 0.050130023519159295, 0.030461494061455596, 0.052245819751988165, 0.058653374362620525, 0.07178312822361477, 0.0062998346584208775, 0.1082150092406664, 0.06727532323566265, 0.07765670015942305, 0.018640413727553096, 0.04685434694692958, 0.03896549154887907, 0.040479198214598, 0.027105559784104116, 0.004055828703712905, 0.02500404432794312, 0.03568879823433235, 0.04254356732417364, 0.07205894740764052, 0.002208961973337864, 0.05348658676666673, 0.038947579814703204, 0.08244901488069445, 0.03707848831254523, 0.09885451581794769, 0.02098196571751032, 0.03180681298545096, 0.15367901301942766, 0.11479017790406942, 0.01062802135493257, 0.031057900632731616, 0.024649286606290843, 0.02134672387910541, 0.023216989829961676, 0.059187512888456695, 0.014126050009508617, 0.04543375383946113, 0.06401326507329941, 0.016710881718609016, 0.04691029746027198, 0.04441317461896688, 0.014201088561094366, 0.021781340401503257, 0.006164762853586581, 0.09653200177126564, 0.015201756887108786, 0.06859198227175511, 0.04517228408076335, 0.10076331222080626, 0.006405429749065661, 0.018134884994651657, 0.09419632202479988, 0.027559023146750405, 0.049959518801188096, 0.01974489088752307, 0.07457916217390448, 0.045970809005666524, 0.03547834370692726, 0.032977298615151085, 0.0032648071237417753, 0.03304824793303851, 0.03728580726601649, 0.027718304736481514, 0.018260304241266567, 0.050446857494534925, 0.034326823661103845, 0.033163607367896475, 0.06654006268945523, 0.013744372736255173, 0.02742638094787253, 0.049675261398078874, 0.039551628651679493, 0.07398151064990088, 0.10443291335832328, 0.10897420404944569, 0.019267311436124146, 0.020767698406416457, 0.004587728262777091, 0.04626827663742006, 0.022615718480665237, 0.018326229219383094, 0.011659826486720704, 0.012109208037145436, 0.0061932167955092154, 0.026371267740614712, 0.03328891900309827, 0.02583557812613435, 0.10207103579887189, 0.026214216304651927, 0.04949490466970019, 0.023804102856956888, 0.017682085854175966, 0.0343278738000663, 0.00497066162097326, 0.06617505961912684, 0.03598058101488277, 0.07642523967660964, 0.053787312426720746, 0.036607766305678524, 0.04380185644549783, 0.027698303856595885, 0.05475520287291147, 0.04467727158043999, 0.03770785180677194, 0.030054437193030026, 0.03910417297447566, 0.01488734324084362, 0.03400726600375492, 0.014218044780136552, 0.038141559198265895, 0.020191186958982144, 0.046282859839266166, 0.06118301069363952, 0.036022330532432534, 0.055526542928419076, 0.039057896356098354, 0.020589944761013612, 0.07902985147666186, 0.08323661910253577, 0.020490291026362684, 0.061978841622476466, 0.048405023699160665, 0.056264660743181594, 0.032189764897339046, 0.1547335454961285, 0.08579388188081793, 0.10896838561166078, 0.23843897186452523, 0.10168474793317728, 0.07301101897610351, 0.10889588520512916, 0.19780635688221082, 0.13362621248234063, 0.21706991305109113, 0.1724185683997348, 0.14031097409315407, 0.21526444586925209, 0.12881016387837008, 0.10970962044666521, 0.16782704915385693, 0.07837299141101539, 0.16668237542035058, 0.15383841149741784, 0.126428478397429, 0.08760851458646357, 0.17620977043407038, 0.14011066843522713, 0.19111945788608864, 0.20095410203794017, 0.09324413913418539, 0.2866835432359949, 0.1489339434192516, 0.07046647660899907, 0.15980455151293427, 0.1073561143130064, 0.13675218302523717, 0.1397203136002645, 0.13672257133293897, 0.19713245710590854, 0.132933447312098, 0.13209957018261775, 0.1917592337122187, 0.15676199836889282, 0.14148190501146019, 0.11401250361814164, 0.17112985864514485, 0.153701025119517, 0.17191107297549024, 0.06702642916934565, 0.16857114125741646, 0.06147678985144012, 0.16515628230990842, 0.08168241343810223, 0.14475440519163385, 0.1649376901332289, 0.138989312981721, 0.09922351164277643, 0.11111092142527923, 0.17045676038833335, 0.15375358401797712, 0.12299197842366993, 0.10263928343192674, 0.1428952658898197, 0.13702268101042137, 0.13533968303818256, 0.07618197108968161, 0.10810356092406437, 0.19865311769535765, 0.14847256505163386, 0.15594853030052036, 0.07516092431615107, 0.10023928174632601, 0.0816192344063893, 0.18176520592533052, 0.16808755783131346, 0.11071000582887791, 0.1627862040186301, 0.14007522346219048, 0.19497138244332746, 0.12154950309195556, 0.1408377059851773, 0.21995097486069426, 0.12129354377975687, 0.25566426396835595, 0.21521004644455388, 0.19392128800973296, 0.08051856260863133, 0.094741362700006, 0.09148889308562502, 0.10718045537942089, 0.18275632930453867, 0.07980960377608426, 0.19838256033835933, 0.1840320069459267, 0.2598157193278894, 0.18123930523870513, 0.14820858312305063, 0.1391856258851476, 0.1816241384949535, 0.15428693586727604, 0.15519842680078, 0.10097405989654362, 0.13204254355514422, 0.19643609994091094, 0.1462191078462638, 0.15632291411748156, 0.10490859291166998, 0.2647760265972465, 0.12732650677207857, 0.19919592450605705, 0.2449292759411037, 0.18603825476020575, 0.09269769579987042, 0.15276038262527436, 0.1626216253498569, 0.07608712461660616, 0.13406428741291165, 0.14891234692186117, 0.07578455843031406, 0.1417737768497318, 0.2060368933598511, 0.1272574721951969, 0.1445508934557438, 0.12805128819309175, 0.10544719916651957, 0.08790949999820441, 0.15573431679513305, 0.17124383768532425, 0.30725195829290897, 0.12904244125820696, 0.19802852621069178, 0.07847186032449827, 0.21620409388560802, 0.20041603012941778, 0.17760527523932979, 0.13678197283297777, 0.06717868076520972, 0.17406941653462127, 0.17302877706242725, 0.12543636054033414, 0.14359240973135456, 0.14636419771704823, 0.10375580008258112, 0.15997010981664062, 0.06490581639809534, 0.10529620180022903, 0.1075048629718367, 0.07501508487621322, 0.18419152416754514, 0.11262256492045708, 0.12423893494997174, 0.12703459040494636, 0.18540118035161868, 0.09367048813146539, 0.21157116279937327, 0.09501855485723354, 0.126946096715983, 0.13300346152391285, 0.157548971765209, 0.17340449674520642, 0.21502422750927508, 0.13580637518316507, 0.06527516845380887, 0.08915547688957304, 0.09179509579553269, 0.12288608879316598, 0.13223486370407045, 0.13042589358519763, 0.22515927819767967, 0.12014797204756178, 0.13737174274865538, 0.13154082203982398, 0.1226537446200382, 0.20631576277082786, 0.18958266300614923, 0.13265506771858782, 0.13415923778666183, 0.1350669882958755, 0.12506285245763138, 0.12479820259613916], [0.03741628424904775, 0.03706115545355715, 0.003565500314834935, 0.060484033747343346, 0.005118439457874047, 0.025104013475356624, 0.04055333505675662, 0.03954921667173039, 0.031268960010493174, 0.061256958288140595, 0.03311977241537534, 0.02560902270488441, 0.03297012204711791, 0.08664279492222704, 0.060875115887029096, 0.04878506268141791, 0.05048644736234564, 0.021630751216434874, 0.10157147393329069, 0.04804859614523593, 0.025803676908253692, 0.03573390225938056, 0.009029105931404047, 0.011446554581198143, 0.02371615464653587, 0.0586858915630728, 0.07693309875321575, 0.0416616398433689, 0.004172945637037628, 0.02021158674324397, 0.039774020624463446, 0.03527169639710337, 0.0057758552065934055, 0.07136886881198734, 0.04842698384891264, 0.06589673939743079, 0.04967969944118522, 0.018934430372610223, 0.013050561137788463, 0.015028742782305926, 0.03253162038163282, 0.040276680956594646, 0.025173168651235756, 0.06496297661215067, 0.03294807283964474, 0.03269153465225827, 0.03472983582469169, 0.06433800663216971, 0.04624164095730521, 0.0945305556524545, 0.016239029791904613, 0.052907373901689425, 0.02550319430156378, 0.025988462402892765, 0.007783898090565344, 0.022399926056095865, 0.05362811803934164, 0.0314069475280121, 0.06355442485073581, 0.057278004023828544, 0.0524421883164905, 0.01941862421517726, 0.06105417756771203, 0.07213060918729752, 0.05201611762458924, 0.07746447648969479, 0.03189627517713234, 0.050984658519155346, 0.01336347842880059, 0.07534983800724149, 0.05581547586189117, 0.03963232607929967, 0.04187642480246723, 0.04899614803434815, 0.04045196510560345, 0.03450597439950798, 0.060991202626610175, 0.016694367077434435, 0.03233663592254743, 0.014158956837491132, 0.02747322345385328, 0.031144713357207365, 0.04203009018965531, 0.03745977781363763, 0.0873904196487274, 0.08928707451559603, 0.051515635495889, 0.0936167492181994, 0.03612073931435589, 0.003839332398456463, 0.03320235860883258, 0.010348371761210728, 0.07254964802996255, 0.03991307683463674, 0.031598165587638505, 0.020016286871396005, 0.023999397162697278, 0.05040768322942313, 0.07881255805841647, 0.058035128240589984, 0.03983000453445129, 0.10617498628562316, 0.027382204607420135, 0.03982886904850602, 0.03476466481515672, 0.028908900712849572, 0.03527176319039427, 0.012455578562367009, 0.039545973486383446, 0.09747407661052421, 0.03508719106321223, 0.040834746323525906, 0.05045353311288636, 0.0061293675116758095, 0.09232088516000658, 0.02250945592095377, 0.0328893429832533, 0.006231142860997352, 0.031202530371956527, 0.03281406323367264, 0.07210392155684531, 0.009822574975260068, 0.038339768289006315, 0.06474592810263857, 0.017262475557799917, 0.04808324702025857, 0.02713158133701654, 0.0082105894034612, 0.014979264724388486, 0.07282660269993357, 0.012743730385409435, 0.024695433348824736, 0.031181175072561018, 0.07783187669701874, 0.028019236342515796, 0.025892294906952884, 0.060582357182283886, 0.038408724940381944, 0.01401044566591736, 0.027154213130415883, 0.018817119089362677, 0.11855007614940405, 0.06326664966763929, 0.07710734760621563, 0.02628861660923576, 0.07062297328957357, 0.07162338093621656, 0.010283669471391477, 0.037264489074004814, 0.061349704483291134, 0.026050077358377166, 0.06280328234424815, 0.06801085095503367, 0.04632810487237293, 0.03300135904282797, 0.06126177482656203, 0.058583760910551064, 0.003251353841733362, 0.037707339724875055, 0.05175310419872403, 0.019480721566651482, 0.04937709243677091, 0.028013531082251575, 0.04316536462283693, 0.023547917189716827, 0.01929098965774756, 0.008191135857487097, 0.023390134738292545, 0.06471890650573187, 0.010914765880443156, 0.06588262374862097, 0.09049131302163005, 0.015809483993507456, 0.004474435709198588, 0.015360369616246317, 0.0721685477765277, 0.0442957371706143, 0.03192263626260683, 0.04251603735610843, 0.05097781220683828, 0.018667815675144084, 0.07250364971696399, 0.021397189921117388, 0.024820733851811383, 0.022411952559195925, 0.04615916979673784, 0.06104366133513395, 0.0056905972815002315, 0.03086850825638976, 0.0233229740842944, 0.11631371060502715, 0.04133082380576525, 0.008330656837642891, 0.05921063449932262, 0.0712540140375495, 0.04302106885006651, 0.02233393428468844, 0.02371062564634485, 0.036939357887604274, 0.0318164980126312, 0.02896246522141155, 0.03678235283587128, 0.010615349183353828, 0.021410869558167178, 0.048032669656095095, 0.04879697415162809, 0.04862968664383516, 0.01821059333451558, 0.018262148478243034, 0.023907517424959224, 0.06759227966540493, 0.030055696988711134, 0.07208588736830279, 0.08524389108060859, 0.030065613937040325, 0.057941762352129444, 0.04409898268932011, 0.04005322029115632, 0.03236111195292324, 0.13857773272320628, 0.05144589958945289, 0.019226161202823278, 0.10545437573455274, 0.017259853921132162, 0.07494705962017179, 0.06258381443331018, 0.0462276774487691, 0.023638481470698025, 0.09911696892231703, 0.044220884155947715, 0.014942796515242662, 0.03723497757164296, 0.07891389832366258, 0.042696742893895134, 0.038575455837417394, 0.055971456749830395, 0.017473915286245756, 0.056309360297746025, 0.0259515387006104, 0.05325904428900685, 0.027053284757130314, 0.019560435648600105, 0.023227199926623143, 0.02161247954063583, 0.07025355444056913, 0.01697751496976707, 0.05218268895987421, 0.02771485931589268, 0.022764522800571285, 0.027455706913315225, 0.04950481976266019, 0.009005737556435633, 0.08038262341869995, 0.08853441060637124, 0.017520687288197223, 0.047544696426484734, 0.00736367366698687, 0.05307189690938685, 0.02772402855043765, 0.022490295523311943, 0.0941525649977848, 0.009291782607760979, 0.05085683100332972, 0.13435178057989106, 0.007215615205495851, 0.03641130868345499, 0.04710238383268006, 0.0021129057995494804, 0.03262585829361342, 0.025832128994807135, 0.048762011574581265, 0.06705026695271954, 0.06460975142545067, 0.03600215153710451, 0.07899076998000965, 0.03605877369409427, 0.01533017441033735, 0.07892575042205863, 0.02261255322082434, 0.06908305396791548, 0.04115837837161962, 0.02592177301266929, 0.03277183503087144, 0.002872167865461961, 0.052060245725442655, 0.018212552604381926, 0.024458055559080094, 0.045629944288521074, 0.028241977124707773, 0.00927509727262077, 0.026074967136082705, 0.04324518631619867, 0.06238687812583521, 0.04804197247722186, 0.058635047025745735, 0.0578355610196013, 0.09576819822541438, 0.022132392950879876, 0.030823756751487963, 0.05440857166831847, 0.04484648867219221, 0.043053467306890525, 0.04633763033780269, 0.033514787937747315, 0.004216959168843459, 0.057364749955013394, 0.05556248142966069, 0.060103508658357896, 0.03928515681764111, 0.07678103269427083, 0.01968463035154855, 0.030476040155917872, 0.062594434566563, 0.0549809419317171, 0.039736252729198895, 0.04286836825485807, 0.026734903403848875, 0.03983672468166333, 0.03300636482890695, 0.04082569954334758, 0.08931506090448238, 0.06375406999723054, 0.00858707999213948, 0.03119151690043509, 0.03235393167415168, 0.006791776058889809, 0.03980307941674255, 0.020265644780010916, 0.011307488166494295, 0.10739806049969047, 0.06329356736387126, 0.03258664692111779, 0.011876340649905615, 0.03630384569987655, 0.05453278492495883, 0.014479485780611867, 0.015708199389337096, 0.04164153506280854, 0.03325893994770013, 0.06744166821590625, 0.029324659262783825, 0.03725128997757565, 0.008726487794774584, 0.05960807313385885, 0.03559053788194433, 0.02741214841080364, 0.04177505114057567, 0.01999835658352822, 0.055314596684183925, 0.056208001478808, 0.0662150613788981, 0.05351010542653967, 0.13227385614300147, 0.10681361178285442, 0.08823986703646369, 0.1662318324088119, 0.0810797004669439, 0.11788420641096309, 0.13504163653124124, 0.17411308450391516, 0.0874177752120886, 0.13795860344544053, 0.185564705170691, 0.1569808428757824, 0.17420978634618223, 0.3256667498499155, 0.21511511091375723, 0.17202275135787204, 0.09982333023799583, 0.13882661936804652, 0.2929274394409731, 0.1415355919743888, 0.09366859565488994, 0.09536420271615498, 0.1312056533060968, 0.12609103869181126, 0.12529033556347713, 0.12152080424129963, 0.21506166143808514, 0.1716100430348888, 0.22683749673888087, 0.21686948864953592, 0.14370156481163576, 0.08189876432879828, 0.0658074145030696, 0.20138846623012796, 0.12959363433765247, 0.14510057255392894, 0.21123719634488225, 0.0708833483804483, 0.14676820806926116, 0.12231889500981197, 0.0941559714556206, 0.17320910410489887, 0.16478489676956087, 0.21807748242281377, 0.11243391840253025, 0.13886850618291646, 0.2254968514898792, 0.10844152013305575, 0.2907000167760998, 0.11433764593675733, 0.14894304214976728, 0.09643117358791642, 0.1340464610257186, 0.1645400474080816, 0.14166543813189492, 0.09923543795594014, 0.14206572290277109, 0.14624183240812272, 0.08335336635354906, 0.2052596866269596, 0.21052877185866237, 0.12640812870813534, 0.1201509554812219, 0.14062160742469132, 0.14013097359566018, 0.13122342032147571, 0.09126578122959472, 0.12848931859480217, 0.09820874343859032, 0.14805795683059841, 0.18553776521002874, 0.12583866395289078, 0.21012792305555195, 0.12899844674393535, 0.18426930124405771, 0.18977434490807354, 0.1705034266342409, 0.13112052896758541, 0.16477587225381285, 0.10588211254798807, 0.1674736978020519, 0.16065990639617667, 0.11261409701546654, 0.11644788348348811, 0.13757092034211382, 0.12529466970590875, 0.17381247016601264, 0.23226267046993598, 0.13978790841065347, 0.08586987780290656, 0.15348278917372227, 0.09354570342111401, 0.11791024837293662, 0.16349471756257117, 0.10734027688158676, 0.20411740260897204, 0.16431945143267512, 0.16635749285342172, 0.17845190246589482, 0.13966806640382856, 0.10489385385881178, 0.2547908155247569, 0.17993576737353578, 0.1100422881427221, 0.12067507501342334, 0.1109879178693518, 0.21687210100935772, 0.10554413849604316, 0.20746631431393325, 0.20087212440557778, 0.09736958221765235, 0.10546440214966424, 0.157851159456186, 0.08760734199313447, 0.07515379227697849, 0.16655361279845238, 0.24583104474004358, 0.1327134302118793, 0.1667237575748004, 0.1350567169720307, 0.21122594538610429, 0.08288916040328331, 0.21629073220537975, 0.18458377890056, 0.1297326385974884, 0.13802388275507838, 0.12091367549146526, 0.1364685787120834, 0.09298970122472383, 0.15785343042807654, 0.15534126054262742, 0.14064076967770234, 0.10070555828860961, 0.15549942705547437, 0.11563918742467649, 0.11881629194249399, 0.12785031460225582, 0.15878392034210265, 0.13608430948806927, 0.1678566460032016, 0.11279434242169373, 0.21482650452526286, 0.16130483272718266, 0.1863334811059758, 0.15902299579465762, 0.1814981218194589, 0.11436930595664307, 0.06459361713496037, 0.06658243190031499, 0.16305900266161188, 0.10161857062485069, 0.18050808197585866, 0.1544600195484236, 0.15456619119504467, 0.1578012277605012, 0.12950775300851092, 0.16255708818789572, 0.079965425102273, 0.11645836260868236, 0.13195854728110135, 0.09902268648147583, 0.09134887208347209, 0.1459845298086293, 0.1846440412919037, 0.18029363098321483, 0.08811213599983603, 0.07179857231676579, 0.13808089453959838, 0.14153817464830354, 0.10951563046546653, 0.1403771439800039, 0.13971197186037898, 0.10721863887738436, 0.10333311729482375, 0.19791125203482807, 0.21739794232416898], [0.045107249679858796, 0.08562853879993781, 0.014341583610075759, 0.15405835438286886, 0.02237421434983844, 0.02114002276357496, 0.043173353842576034, 0.06314387617749162, 0.10822185184224509, 0.02852581521437969, 0.06588234915398061, 0.04038282662804704, 0.031629035220248625, 0.0176117877708748, 0.017743878925102763, 0.029712427713093348, 0.025049486030184198, 0.014193735732987989, 0.038110860259621404, 0.04544390641967766, 0.08422335638897493, 0.020723893139802385, 0.022651727485936135, 0.02467742328008171, 0.028865915519418195, 0.09615945105906576, 0.043065482677775435, 0.05247839028015733, 0.04720790238934569, 0.039480746127082966, 0.03320909359899815, 0.06899303145473823, 0.051082224963465706, 0.024176095103030093, 0.04135791590670124, 0.10602065667626448, 0.012978652594028972, 0.020645225486077834, 0.01867008293629624, 0.022177986793394666, 0.008627699589851545, 0.07755124097457156, 0.05563741608057171, 0.03954989944759291, 0.014271350464696297, 0.057537254760973155, 0.03124365277471952, 0.047748241559020244, 0.03708866315719206, 0.059841170586878434, 0.03162831533700228, 0.02900340208725538, 0.051326439788681455, 0.11113662942079827, 0.06793485503294505, 0.0211507041240111, 0.02733509121753741, 0.04993080139684025, 0.012019057503493968, 0.04713588808954228, 0.015449515467480524, 0.05773434320872184, 0.04129896711674519, 0.03844650767860003, 0.016551548178540543, 0.04018028710561339, 0.08851130012772046, 0.08723099148483016, 0.0651440977526363, 0.033157870566355996, 0.09071216132724658, 0.03607641083362978, 0.0724738376447931, 0.05017626674089115, 0.011325873019814026, 0.059556308333412744, 0.06693507079035044, 0.02806679502100451, 0.04142165525991004, 0.07736772269709036, 0.04893783749139402, 0.03684408467961475, 0.06632818694924936, 0.02496667904779315, 0.06855031810118817, 0.04743350415083114, 0.008304947914439254, 0.027262692856311332, 0.0572473607462598, 0.02708738829824142, 0.02153399556846125, 0.04811357859580312, 0.04823365066840779, 0.02346997684071539, 0.026717800610640552, 0.032094870184664614, 0.017335003794869408, 0.06210243147506844, 0.024868717409844976, 0.02413825484836707, 0.008625218033557758, 0.06164221456856467, 0.018341023933317047, 0.043117677923874, 0.038703791724401526, 0.012049682227370795, 0.07105378259439021, 0.05356122084776871, 0.041770858006202616, 0.06734996102750301, 0.022367655619746074, 0.04831288235436659, 0.07656057030544616, 0.012110790667065885, 0.05776899779448286, 0.022640001552645117, 0.05060478280938696, 0.018255973809573334, 0.06797230380470864, 0.022516356038977392, 0.039187334332382306, 0.01809400193451438, 0.04253575250913855, 0.04503192540141754, 0.030319057368615177, 0.10237363167107105, 0.021654379343090113, 0.021634256008837838, 0.04105566142243333, 0.03859761265630368, 0.008476403509121155, 0.06263179428060539, 0.018632827122928575, 0.055127174709923565, 0.010353229117754381, 0.043289477689540945, 0.07208115988760255, 0.03431081182498019, 0.0456611441768473, 0.041729349686647765, 0.03815626114374027, 0.02833128903148463, 0.026610187342157587, 0.04527117525867652, 0.046285602074931376, 0.00889158411155222, 0.05580750890658237, 0.04881716056843288, 0.021994331218593288, 0.08571660946472548, 0.02954525152745191, 0.014166213186399546, 0.026547754168859683, 0.0028890607700304827, 0.021065609471406788, 0.024580157405580394, 0.008568509601900587, 0.0347152043832466, 0.049774586732382886, 0.023685093910899013, 0.01021054937154986, 0.10961633248371072, 0.05493033859238494, 0.08790524007054046, 0.08911190539947711, 0.03159350490022916, 0.03132419806206599, 0.03969490026065614, 0.026745022587419953, 0.014787747022637632, 0.018609488433867227, 0.048541686483076774, 0.05179131367185619, 0.021424729166028555, 0.017425161749997642, 0.03932561128749512, 0.01282128388993442, 0.09115304157603532, 0.04548750017420389, 0.0501627336780075, 0.011314716684864834, 0.08380246959859505, 0.05377456604037434, 0.058587479070411064, 0.08302306610858068, 0.044143021732452326, 0.04976995573088061, 0.07290679917787202, 0.034727201200439595, 0.029920234628662, 0.045553002128144726, 0.015481042828469072, 0.07866318599553779, 0.027031973986595403, 0.027801267569884658, 0.0351949360629078, 0.070843665744178, 0.04266033312887885, 0.023002277230261825, 0.12839343311497942, 0.03263860096922144, 0.040594891615910456, 0.02241426620457787, 0.03395692241610959, 0.025918784012901597, 0.030721807925147004, 0.13442529772873968, 0.08518544695107266, 0.028344378661131486, 0.017730154759192374, 0.06531929655466229, 0.08839548798277974, 0.07961194016388617, 0.028744665287376847, 0.01511723647126928, 0.006115396581662935, 0.044096578130847774, 0.026962017291225493, 0.03253226233937312, 0.04143893616856076, 0.02775059187115403, 0.010129325946763856, 0.02359050718951039, 0.01657961434830213, 0.06270739686442539, 0.049824125089799054, 0.023943057021824643, 0.03532938353600912, 0.037615625114995055, 0.04972617272869684, 0.06575182022061199, 0.06144146362203173, 0.0285071780308499, 0.0508090070070466, 0.025003933005791623, 0.00993551593637676, 0.03545307357853744, 0.03846674975648057, 0.05398362904088572, 0.02341464230994461, 0.07498223742004484, 0.029457453601935413, 0.04876077589869965, 0.029997950477991253, 0.08599642140325159, 0.01407604224368697, 0.01998703883145936, 0.009983695235860068, 0.023050288618833292, 0.017141529606305994, 0.07678544847294688, 0.03768584712815937, 0.0647277751704678, 0.03629537779488601, 0.057083342398982495, 0.03922796320694033, 0.04266043702955358, 0.013408743870968465, 0.07002829035627656, 0.0678749785583932, 0.04210601189697627, 0.012841115931223612, 0.05154313948878553, 0.022065592238504905, 0.016315192697220482, 0.07429183227941394, 0.021163083147257566, 0.024380367540288717, 0.02620484297949588, 0.02088842727971496, 0.034016932477243245, 0.03921678646293003, 0.03205569591955282, 0.016812188587209675, 0.13187553064199165, 0.01710428492515348, 0.029754342358501162, 0.017243723341380246, 0.012923161284561502, 0.07162603782489896, 0.03133628393698018, 0.03501565915939864, 0.05162733985343948, 0.010128978065040428, 0.046938053783378564, 0.053161641117185354, 0.03393958955712151, 0.00524557121025282, 0.032013875897973776, 0.007791229581926018, 0.03123358554148581, 0.06654057477135211, 0.055946450083865784, 0.02913295138569083, 0.04620774336217437, 0.027511304906511214, 0.020818168159166817, 0.04226900979119819, 0.021653338480973616, 0.042508415499469265, 0.03823846884188242, 0.08906189206754789, 0.03333472806843929, 0.05342069889593404, 0.054030573592172004, 0.03308940744318534, 0.03272211855801288, 0.043040223681600764, 0.028910633627674542, 0.1132278902514372, 0.05733512713050004, 0.04928803842631169, 0.043968932441202924, 0.04690578891313635, 0.026977350062225014, 0.04914504512271378, 0.01655980642681243, 0.023174885936896317, 0.013150544200470904, 0.018141035543521866, 0.02186005629482679, 0.004541416392385145, 0.03317649847303983, 0.07339656469412148, 0.02881750522647053, 0.0882643208024092, 0.006193709859871888, 0.015121000087674474, 0.03637108427938074, 0.022996254701865837, 0.004414776776684448, 0.08357595870620571, 0.0178410520311445, 0.010643348559824517, 0.11204119611647911, 0.08884621653123759, 0.01842831348767504, 0.05752313169068657, 0.059368095971876755, 0.047874328738544136, 0.046046548886806704, 0.03153671947075054, 0.01118099002269446, 0.041246334003517404, 0.05524047097424045, 0.014962467139412183, 0.09949137500370853, 0.04888506337010767, 0.026424553943797946, 0.0476680228166515, 0.009570477614033734, 0.024171621807909105, 0.07147687356336974, 0.15071736881509423, 0.10902949405135587, 0.2037880226271227, 0.0843013338453602, 0.15548544499324635, 0.11223719731788151, 0.12763351842295378, 0.1724615684361197, 0.06076270277844742, 0.12268055841559544, 0.15644608094589785, 0.15624124818714336, 0.20314437279012054, 0.13819200888974592, 0.14696619822643697, 0.11591603819397278, 0.1205177916563116, 0.1778574421769008, 0.15292128024157137, 0.15344906598329544, 0.1089490600861609, 0.13240586937172338, 0.15644845581846312, 0.07832068484276533, 0.2053469038219191, 0.08309080192702822, 0.1401647858438082, 0.159038937126752, 0.17080067162169144, 0.3480972134275362, 0.2165395297924988, 0.10822808588272892, 0.19587260205298662, 0.21557233325438574, 0.2802298270398751, 0.26221998094115406, 0.14775931660551578, 0.07857626565964893, 0.10344084003008902, 0.1021252571081277, 0.2356858117855154, 0.10734627343481407, 0.13656201510457322, 0.10958760394714773, 0.16160379949724302, 0.09465713636018336, 0.0824831314093899, 0.14664484828244895, 0.16478082980029285, 0.050670852506300434, 0.05762439774116501, 0.0932002485205885, 0.17136041424237192, 0.12942681438289583, 0.16924042487517, 0.09142693117610179, 0.22148815565742552, 0.11929465807043016, 0.11502566136186942, 0.1652541567455046, 0.1237989601213485, 0.1438980855164118, 0.08427438646322116, 0.16670042445184663, 0.10242477306746878, 0.12973032309673727, 0.1764031741186045, 0.1978829168365337, 0.11262283209362067, 0.13909595960285515, 0.06470096879638731, 0.1453901585773565, 0.08060653679422103, 0.10816048365086317, 0.12648290750803426, 0.14706034708069637, 0.11832150208647363, 0.09631985143641941, 0.18229328852612525, 0.10384110253653489, 0.09246967092622072, 0.21576149185420945, 0.18176679412135854, 0.17373631097143516, 0.15370069857453927, 0.1357151207048446, 0.11463146220194176, 0.0776411521655973, 0.1430817527580075, 0.10278013563947752, 0.1800563366850838, 0.18242700869450346, 0.12676899059442803, 0.14665574301034212, 0.08257604829850607, 0.17984161851927638, 0.1448657421860844, 0.22128648444777355, 0.10961625826894306, 0.07118045978131704, 0.12261289681191556, 0.0450159543834161, 0.17243823531316593, 0.11024346211343072, 0.09807379872654565, 0.14716596953803673, 0.13440281065413728, 0.10428220542962663, 0.12847002275520936, 0.11684658005833626, 0.12438685982488096, 0.11458997614681721, 0.1664713679929264, 0.22010399086866528, 0.11178514774655923, 0.10323898328351788, 0.17405191669240594, 0.2248887059977278, 0.08139063065755181, 0.18594907829537988, 0.10444382292916998, 0.14091876335442066, 0.18450061383191496, 0.13048146560322493, 0.17973516485653818, 0.08894312617485411, 0.141754035721533, 0.18659440538613126, 0.1366056830738671, 0.14832987973932177, 0.15737801062641665, 0.1958155754255131, 0.19157154456479475, 0.19691238063387573, 0.20620530151063576, 0.12593199644470587, 0.13143076153937727, 0.12748019071295857, 0.2403630194021389, 0.12353442900348455, 0.17746207042364404, 0.17933201539563015, 0.09939832452801056, 0.1101664271845948, 0.07935973611893132, 0.16425446898210794, 0.1857090528937988, 0.08359795596334152, 0.197299410647247, 0.10839034162927419, 0.09441733360290527, 0.11075355505454354, 0.12132815754739568, 0.07628621315234341, 0.1509114701184444, 0.12293715597479604, 0.08559370980947278, 0.2063238076516427, 0.18115999933797866, 0.08782090240856633, 0.09342640318209305, 0.09836468350840732, 0.17863393644802272, 0.11248131937463768, 0.1053359141224064, 0.10413965370389633, 0.11912462461623363, 0.1637375185964629, 0.057423691323492676, 0.1698016221052967, 0.11029668894479983, 0.1120603657909669, 0.07145566298277117, 0.1340835090377368, 0.09090153514989652], [0.037353736042859964, 0.01150487069025985, 0.02511229398805881, 0.030427756028075237, 0.11971452811849304, 0.019240916954004206, 0.025057480816030875, 0.05114199753734283, 0.04474543784453999, 0.015222273559629684, 0.03339277514896821, 0.012605266038008267, 0.05965932956314646, 0.05285797655233182, 0.043195135876885615, 0.020976178821001668, 0.01485289923948585, 0.04435652277607005, 0.051348425913602114, 0.009564630418026354, 0.027793679109890945, 0.049633994276518933, 0.03212070805602707, 0.05132781276188325, 0.04299760585126933, 0.04909352894173935, 0.08599694832810201, 0.03245101201173384, 0.03841486992314458, 0.0851108314236626, 0.034256846556672826, 0.047999848175095394, 0.032949976448435336, 0.041335477071697824, 0.02288630923430901, 0.05994196908432059, 0.06659449922153726, 0.00805959203717066, 0.03368718142155558, 0.019018571365450043, 0.03951124468585476, 0.02418131240119692, 0.006750274233127129, 0.014751196249562781, 0.017728494203765877, 0.03894631074217614, 0.0694215326802805, 0.027763371654145885, 0.015987311853677966, 0.048350961951655336, 0.032908512657741085, 0.017542677123856265, 0.1010057124949526, 0.04643501866667066, 0.09720232439576648, 0.06336986014503054, 0.061247926350915805, 0.047884622326819226, 0.050102170716854744, 0.04286219358618837, 0.09119650916545652, 0.012729966329061426, 0.031114864177652635, 0.10381685657193884, 0.015732608626422007, 0.04823188064619899, 0.044494914764072746, 0.009696514698589453, 0.0851975662226323, 0.03076294146012515, 0.06299985499936156, 0.042174285772489384, 0.023631930162082426, 0.04100204496353399, 0.03615634384914301, 0.030911476751498412, 0.0970406252599787, 0.018089959085045848, 0.034550941127236, 0.03409417149669025, 0.006968101997699705, 0.035870520514436066, 0.0703503453405574, 0.029865018841519486, 0.036787570134038106, 0.034571465221233666, 0.046007118580746464, 0.01778183792339405, 0.10854944324819371, 0.02491191782610258, 0.01346940423900378, 0.01260859178728424, 0.13906193955335766, 0.05220833758357912, 0.08674317039549351, 0.024345729652850423, 0.12312595834373496, 0.05467334769491572, 0.06956010649446398, 0.007338507903114078, 0.007600634926347993, 0.006467685734605766, 0.045936187816550955, 0.04949058165948372, 0.06984036372159608, 0.06292191465036012, 0.037407890558824874, 0.01834807433624519, 0.025242205083486624, 0.052430132127483375, 0.09127623066888191, 0.03602025994041469, 0.025597721651138272, 0.057728302126633935, 0.02613897180708591, 0.03117882617516443, 0.0407958169671474, 0.013950815027783392, 0.03851613597362302, 0.03779620448767673, 0.011656845836114371, 0.01133799136368907, 0.030939802672946826, 0.05817882287374232, 0.05290223081829026, 0.025668919588497374, 0.007959673912409926, 0.034879334052675404, 0.009479968994128285, 0.044675405079033226, 0.045070309279253706, 0.12337749445578083, 0.10659496023436077, 0.002313425984539208, 0.04204819488222711, 0.028161812188045587, 0.05001558063668199, 0.07339719551964663, 0.0024494106310157804, 0.04165136851952411, 0.031256451111403294, 0.03033022669114871, 0.029106914989824872, 0.01985024988243822, 0.03657977620605379, 0.06490335988928564, 0.05859329008671921, 0.01892010692245094, 0.07614566522534005, 0.05170913937035948, 0.027317938329360913, 0.0025517003814456984, 0.0431654611020349, 0.05903609620872885, 0.028196674575156067, 0.032672283341526054, 0.04127728156163357, 0.026830460483324714, 0.057322989305248484, 0.038112982801976614, 0.029514235320675652, 0.0240323021353106, 0.09275311938836239, 0.021582476365438197, 0.04297397215850651, 0.04831731668673456, 0.011958589166169986, 0.03418938533286564, 0.015967409308359493, 0.011876685748575255, 0.05576261268288363, 0.014678143870696658, 0.013427700177999213, 0.019451644220680464, 0.07209937219158746, 0.051034289645031095, 0.034754593871184625, 0.04626533031114377, 0.03812356211710721, 0.06706981512252241, 0.026618657102517318, 0.056787911962601356, 0.032097875882755034, 0.010609846158331493, 0.09182746085571125, 0.01957312266313238, 0.01877049551694654, 0.042363785760244355, 0.03210919734556228, 0.058880890865111724, 0.025815382432483602, 0.045469157994375564, 0.018922862145700492, 0.03609020364820026, 0.02080776324874023, 0.044207321407156996, 0.028203270412632264, 0.023644414941372816, 0.036745831748703495, 0.058399185072630644, 0.05925160105107352, 0.020711154174932744, 0.0359970641147811, 0.052932929756934755, 0.05288896121783182, 0.06438578609959222, 0.02454102024785243, 0.01626095468964195, 0.017579398590896744, 0.02616716785269091, 0.029284824486239813, 0.021873695113754366, 0.018702895140449982, 0.04515174885455053, 0.002779235669549962, 0.0662176737387199, 0.052406183021957986, 0.016385872986575123, 0.05540401805774309, 0.036424225763767026, 0.08265987387858331, 0.01713485584332375, 0.05869365813850891, 0.03492571457172744, 0.05231686183833517, 0.0552311867068056, 0.014131457483017584, 0.04446732913493179, 0.059562197275226936, 0.058961744143744, 0.08854840009007603, 0.013311271122802282, 0.022036077025404666, 0.01713144753011875, 0.1231358660152182, 0.026309725144528784, 0.025410108573851176, 0.044509086073958315, 0.04285623785108328, 0.027842380695801694, 0.029209073472884484, 0.03323665325297043, 0.03544856503140181, 0.00393499824895116, 0.04025636466394644, 0.0874316088447813, 0.0665895342535805, 0.010125188473466551, 0.012467118958738865, 0.05802462314022705, 0.08108049456495792, 0.02756976016826229, 0.012267092533875257, 0.037660461966879666, 0.04513739942922257, 0.04158869785896968, 0.019588140021369327, 0.0123892954979965, 0.11304371146252379, 0.04442674478923436, 0.019030091352760792, 0.008824226788419764, 0.09159115361399017, 0.025875939827528782, 0.04373926742118783, 0.08174025642802007, 0.022463632012659218, 0.09693798623629846, 0.012051884550601244, 0.022837349752080627, 0.007522453379351646, 0.011277228022663621, 0.011301190115773352, 0.04997071409889031, 0.006997466925895424, 0.04655363241909072, 0.030614818060712423, 0.05923967473790981, 0.04400543497467879, 0.018682985173654743, 0.058637674228521064, 0.054909936952753924, 0.0798801523342263, 0.027784441226685885, 0.011447527722339146, 0.08129937617923133, 0.062351915548788384, 0.02938764348073164, 0.025274911531596445, 0.04195483270450495, 0.033351352176396176, 0.05699395442206878, 0.06898275270941667, 0.05277731252135709, 0.02877008570067119, 0.02186029563745251, 0.017830565484473482, 0.018764170563372318, 0.026520675055508036, 0.021609429313684814, 0.06933171054697596, 0.029404653505480383, 0.046901172754587606, 0.0032397329687228194, 0.038876155522302724, 0.0018000978593590844, 0.007100046577761532, 0.10405860375612974, 0.037598837734549306, 0.023072397198120598, 0.01438541114112013, 0.025610865086491685, 0.03414574333874043, 0.07368266262346879, 0.023644394532311708, 0.031010024686111137, 0.024370923711103387, 0.0037719869033026043, 0.02225514232122805, 0.03412519698031247, 0.012579187896335497, 0.11722215131158009, 0.03461841348325834, 0.012091973512724508, 0.04056368059536908, 0.05951791332336143, 0.020082479022676125, 0.009108007361646742, 0.04909114293695893, 0.10232445696601644, 0.060889780725119635, 0.06645319430390373, 0.02164749035728164, 0.007916702634247486, 0.017033144504239317, 0.0103323988878401, 0.0993325405579526, 0.06277926644543186, 0.07721798698185012, 0.05833172755956184, 0.04719253622170072, 0.03883051344018895, 0.06098775163991377, 0.05053942928498145, 0.0347586719726678, 0.054747933536418714, 0.0300346348376479, 0.027795918540505227, 0.025942614374798723, 0.05603121819149237, 0.01918232810567133, 0.02890620300604496, 0.11984752840362489, 0.10247430400340818, 0.11002891464158893, 0.17255876009585336, 0.18216286349343136, 0.11485231792903505, 0.08929373900173232, 0.08324686816195026, 0.19061730592511594, 0.04610469986801036, 0.13503875699825585, 0.09337935101939365, 0.15374743903521448, 0.19658975419588387, 0.21798404603032395, 0.09999922665883787, 0.26375883899163455, 0.1311013221857138, 0.12951271055499092, 0.10933157784165815, 0.09424981602933258, 0.17974555492401123, 0.13793130725389346, 0.12650181743083522, 0.13311821239767596, 0.2099705283762887, 0.2139021150651388, 0.0914771226234734, 0.08824080956401303, 0.18454729492077604, 0.09619148215278983, 0.09318228112533689, 0.09028145592310466, 0.18005618825554848, 0.14514216250972822, 0.2515719726216048, 0.18528767628595233, 0.15638853481505066, 0.2514250570675358, 0.17386961553711444, 0.09910468637826853, 0.11081738717621192, 0.1503766339737922, 0.10380885621998459, 0.16537301911739632, 0.12869575439253822, 0.18631728744367138, 0.1166963174182456, 0.1589712532586418, 0.14193825161783025, 0.09220194115187041, 0.13727870711591095, 0.22141395573271438, 0.1954076168476604, 0.24788425565930083, 0.17759997630491853, 0.21758113405667245, 0.20255452865967527, 0.2615608350606635, 0.09825314613408409, 0.08422351223998703, 0.09864477004157379, 0.14555620669852942, 0.15163757256232202, 0.15801213128725067, 0.1261526221060194, 0.1949698684620671, 0.08876561929355375, 0.13065932871541008, 0.16877465299330652, 0.20565430138958618, 0.14690552023239434, 0.08410186681430787, 0.2936584845883772, 0.19032948621315882, 0.12499926524469629, 0.17659194680163637, 0.13770138990366831, 0.10524211407755502, 0.10026225121691823, 0.07508654627599753, 0.09933910114341415, 0.1804902555886656, 0.12548042926937342, 0.17219677014509216, 0.1234247544198297, 0.17153529392089695, 0.08648034621728584, 0.2251385574345477, 0.20808590372325853, 0.1136111056257505, 0.20000308431917801, 0.3196646453579888, 0.18376153864664957, 0.26866951142437756, 0.0733263352594804, 0.20602368313120678, 0.11168820099555887, 0.20203824620693922, 0.1413776184199378, 0.06022883884725161, 0.07907858089311048, 0.15985820878995582, 0.16468095156596974, 0.11481428286060691, 0.210331434791442, 0.1404566873679869, 0.19568476447602734, 0.13534260710002854, 0.189591568778269, 0.25142719445284456, 0.11790692355134524, 0.14153985190205276, 0.15769827703479677, 0.18081957619870082, 0.11739859692170285, 0.175867298967205, 0.12692904216237366, 0.10514069959754124, 0.1427452778443694, 0.1382414359250106, 0.11623286845861003, 0.1571750480798073, 0.17013551434502006, 0.11456234598881565, 0.17757425346644595, 0.09312993002822623, 0.06572952610440552, 0.10440048150485381, 0.10034966137027368, 0.13928306987509131, 0.24824121384881437, 0.4655310994712636, 0.10154238174436614, 0.11243437111261301, 0.10738429366028868, 0.16995474201394245, 0.24260003061499447, 0.19073438714258373, 0.10800158241181634, 0.11075666465330869, 0.11902855359949172, 0.09553539392072707, 0.13274940953124315, 0.10009073346736841, 0.21369222085922956, 0.14005623932462186, 0.07574692412163131, 0.1462707613245584, 0.13258560269605368, 0.06740269804140553, 0.11003936408087611, 0.09412088271346875, 0.21008023264585063, 0.1621820661239326, 0.11419792921515182, 0.14763874729396775, 0.10552182953688316, 0.15410234889714047, 0.09672256303019822, 0.23830155580071732, 0.15662801102735102, 0.2235767967067659, 0.16635724052321166, 0.10208178209722973, 0.08867008262313902, 0.11916013638256118, 0.10762253048596904, 0.11450796882854775, 0.07085565885063261, 0.1251140161184594, 0.10734447743743658, 0.12248715473106131, 0.12200812809169292, 0.24626083730254322, 0.06884457965497859], [0.06815417451434769, 0.012327608183113625, 0.030217115963750985, 0.07028442036244087, 0.014694508226966718, 0.05510285453055985, 0.036061682912986726, 0.07749816999421455, 0.019445343386905733, 0.017263160189031623, 0.019905410008504987, 0.029500650307454634, 0.024530058726668358, 0.07657756548724137, 0.021687180415028706, 0.01762048945238348, 0.017117741917900275, 0.06416334959794767, 0.06447375286370516, 0.03586393766454421, 0.0685925834113732, 0.021163148085179273, 0.05963920622889418, 0.018022789154201746, 0.05479336039570626, 0.012140889393776888, 0.018176170669903513, 0.012124465665692696, 0.03361144525115378, 0.04944671702105552, 0.05221763298322912, 0.07115881875506602, 0.018859601477743126, 0.034907246226794086, 0.021652382965839934, 0.03201128951332066, 0.03377580127562396, 0.0509858199802693, 0.041055138208321296, 0.05179406332899816, 0.05172161116206553, 0.05782850690593477, 0.02712024317588657, 0.08016424646484666, 0.033403269117116, 0.040179240677389316, 0.020385115712997504, 0.049846894180518575, 0.035796146185020916, 0.029723242660111282, 0.0483540233108215, 0.032991091429721564, 0.05625926161883399, 0.04134232709475327, 0.03426296556426678, 0.04377402590762358, 0.06052686308976263, 0.04581400062306784, 0.05786697242001537, 0.024397281085839495, 0.017079161370929796, 0.03514192816510331, 0.0033524791160743916, 0.06633305543800816, 0.053592339099850506, 0.033060200221370906, 0.057113740767817944, 0.06273620703723282, 0.014054714774829336, 0.0376760136714438, 0.06690356662147678, 0.024473707453580573, 0.01721977980196243, 0.031706611916888505, 0.08789405590505339, 0.04544337949482724, 0.06891806711792015, 0.0232251515990356, 0.009647250008129049, 0.06743041725712828, 0.01638801593799144, 0.04559979082841892, 0.03751609940081835, 0.044912814410054125, 0.053079407443874516, 0.03868160521960817, 0.012711188137473073, 0.03256688352848869, 0.02513523562811315, 0.009304589293606114, 0.026885817278525792, 0.050185740255983546, 0.01908829428430181, 0.009344764530396787, 0.03007620067364769, 0.025204943704011384, 0.01979975786525756, 0.04938544901960995, 0.049347651438438334, 0.00598247561356402, 0.029568378704425413, 0.0774221592291724, 0.026873655333474744, 0.0497795850969851, 0.04548047203570604, 0.09317465184722096, 0.039940072456374764, 0.034086876185028814, 0.025455975155637134, 0.06125192281615455, 0.0542326604045229, 0.020407124102348462, 0.040206677876994945, 0.03979213273851201, 0.045527283000410534, 0.023899177540442906, 0.02711071771045681, 0.06955641059903428, 0.03511970455292612, 0.07019408614723943, 0.034950439221574925, 0.011693130363710225, 0.02534762716095429, 0.027890238088730257, 0.012811659162252909, 0.019063293184444774, 0.03758819162612781, 0.08733907787245698, 0.04369918031443376, 0.07452469595591538, 0.024597269475634675, 0.017898933983815368, 0.04124107588722836, 0.07693407096667215, 0.05788083202787675, 0.028531019524962176, 0.04630128365533892, 0.019086787724518217, 0.014010118193255039, 0.030181229412846733, 0.08521786396158859, 0.011864249208883848, 0.03603866520279553, 0.06865246730740182, 0.05424094277259428, 0.051169301150366664, 0.06037586572347209, 0.06812175750383176, 0.018331507744733244, 0.08921472253859974, 0.060804114618804306, 0.06169358232000377, 0.04272358266462106, 0.02523621966247447, 0.022301418939605355, 0.07417194574372843, 0.06772813721909188, 0.018100757333741058, 0.06127338572696317, 0.006865888317406643, 0.0437274116120534, 0.0739561440423131, 0.027812874759547412, 0.08887593954568729, 0.01612062940694159, 0.023803138064977247, 0.06209091705386527, 0.05029332569392864, 0.06789612976717763, 0.026968112179019954, 0.016986481969070155, 0.054340787610271946, 0.021005506641813554, 0.014024332176632015, 0.037332484644139186, 0.052695334888994694, 0.03269136024755426, 0.027550690683710855, 0.05512651419849135, 0.01907923822727753, 0.01580067470058566, 0.05363629650673829, 0.01928758319991175, 0.11497822328237817, 0.019713139954546932, 0.01044299651766778, 0.01614960841834545, 0.030641754310636315, 0.02998676816787338, 0.07616680901264772, 0.014973103043303126, 0.02565555721957935, 0.053102863021194935, 0.007696878028582432, 0.09141021058894694, 0.042049946350743994, 0.12433375173714012, 0.014066240328247659, 0.060024002377758734, 0.03375791180587839, 0.03540662626619451, 0.025499459443381056, 0.017104672697314527, 0.05898544091905933, 0.060445772323873825, 0.027154890340170823, 0.04416751260578167, 0.07557107965112664, 0.01943410541571211, 0.06785688499803655, 0.012236072616360616, 0.0486057969101239, 0.07003369319136254, 0.08105623375740834, 0.018203218241978902, 0.05387416225858033, 0.024102572388073895, 0.03806056120083667, 0.08789961459115148, 0.01906108715047594, 0.04617896658601239, 0.008624807069281815, 0.03182419779477641, 0.038787988378317095, 0.04545757306914311, 0.037333171130740084, 0.07576777847134508, 0.022027603554306552, 0.05050913110608235, 0.006386524464687682, 0.010116368048329605, 0.03696524399856571, 0.04526980970695149, 0.03254294555517845, 0.059325504116714, 0.037856374110560864, 0.05043996665335726, 0.03919558701454662, 0.047513667232124135, 0.024434646365989465, 0.01683859791228315, 0.04133065311179962, 0.05100948335893918, 0.0450458332488779, 0.09762281042640097, 0.01254468823390198, 0.026962585034198128, 0.02698759355553193, 0.021144765087228734, 0.12561183393700048, 0.05068621496320702, 0.04222481118631549, 0.042431376859894954, 0.02294513556989841, 0.026758711501315702, 0.03083519510255428, 0.011841152645502007, 0.0535442924592644, 0.02586176295153564, 0.06773235261789523, 0.02052022555290023, 0.09795337784453295, 0.025192852262989618, 0.024938141614256892, 0.09001846847240813, 0.019184343036613427, 0.07587488522403874, 0.028950056512258016, 0.06576332350960001, 0.05808488553157076, 0.041808043315541, 0.04007247160188854, 0.073685801908141, 0.08664599357871339, 0.03625680095865391, 0.02080319532979047, 0.016937121727096383, 0.05922093550907448, 0.06575363848241977, 0.0466027700167615, 0.01858065228589112, 0.04620850406354293, 0.015824983747734223, 0.029790221487928648, 0.05929042279603891, 0.03631325984315481, 0.06133593022241257, 0.04814673404325731, 0.051998506460222416, 0.07743749200017191, 0.015048636050778441, 0.042137438140343875, 0.04196454741759226, 0.06578799249837175, 0.003801463617492118, 0.036724086821777746, 0.024146292307705153, 0.030550644551112782, 0.03351869534526486, 0.016059461595432367, 0.05413593629782554, 0.011576575143408263, 0.05613285902654752, 0.0265108119128854, 0.04392249626107514, 0.010855009077204159, 0.022407234355341643, 0.016790313784440514, 0.06491621388704516, 0.05068818536528852, 0.08645676818559878, 0.030719434907950927, 0.07023640340776183, 0.012627398737095064, 0.041029237254406326, 0.02000751468585804, 0.08033990539843217, 0.026248535068589263, 0.04156790659180842, 0.04892484248557594, 0.019527350705175195, 0.017042541949194856, 0.026127687451662496, 0.02518786131986417, 0.010153276907658437, 0.017709617677610368, 0.0343711855384754, 0.042526030374574475, 0.03731726319529116, 0.007913243298389716, 0.04426123843586538, 0.061837046887376346, 0.05029493986512534, 0.003644193479885871, 0.044778678638977, 0.056325264522456564, 0.024342022625205573, 0.02362289080338087, 0.03723118148627691, 0.015014208747743396, 0.12460013822419569, 0.018614557302498724, 0.04990573906979989, 0.05483468688908033, 0.06922806220245548, 0.0028429226085791015, 0.08331716438988224, 0.02705176706513157, 0.040898355800891295, 0.0392824368464062, 0.06620384752750397, 0.0380408571800217, 0.1511491948622279, 0.08497937480569817, 0.14443856198340654, 0.20112196099944413, 0.153549374663271, 0.13894384901504964, 0.10819721253938042, 0.16374019032809883, 0.14377787243574858, 0.05775594341685064, 0.1494496618397534, 0.046827269688947126, 0.1331762780318968, 0.10497280352865346, 0.10461922953254543, 0.1732918238849379, 0.09339754848042503, 0.21538547531235963, 0.21559689834248275, 0.09267296743928455, 0.2144163491902873, 0.12219665586599149, 0.1745202564052306, 0.12821052339859307, 0.11717594519723207, 0.10028614837210625, 0.12332049751421437, 0.14643127302406356, 0.25227253034245223, 0.15607910376274958, 0.0639022546238266, 0.11462756592663936, 0.06415609139367007, 0.12614065868547186, 0.13901252736104652, 0.21367895125877112, 0.23037319217110053, 0.12744519102852792, 0.2088321777409874, 0.16189121844945475, 0.12033671504468657, 0.1331788903917186, 0.16624361771391705, 0.18923876661574468, 0.09608849431970157, 0.1182619521568995, 0.13021561346249655, 0.11800603737356141, 0.11429290927480906, 0.10440663390909322, 0.1140263001434505, 0.10861308241146617, 0.21894649282330647, 0.09265635075280443, 0.10036299776402302, 0.16787537781056017, 0.10499817013624124, 0.184667389257811, 0.12993145996006206, 0.06019236228894442, 0.08860418733092956, 0.1117058566887863, 0.16197972698137164, 0.23282407550141215, 0.10526554367970675, 0.12459685793146491, 0.146179536532145, 0.12225487735122442, 0.18888433172833174, 0.13109173363773152, 0.09260309423552826, 0.1183574739843607, 0.14135673438431695, 0.21577073901426047, 0.3471992741106078, 0.11329141809255816, 0.2144539909204468, 0.07988831595866941, 0.1277306952397339, 0.14991721487604082, 0.11531088355695829, 0.16043712850660086, 0.13248156843474135, 0.2747613564133644, 0.07915131136542186, 0.26809678121935576, 0.12690330448094755, 0.08898985921405256, 0.163431991240941, 0.07171617908170447, 0.21149227250134572, 0.11678265145746991, 0.1029434749216307, 0.18103591224644333, 0.0975139373622369, 0.09689241094747558, 0.1523017353611067, 0.15100797900231555, 0.10998891288181767, 0.13495551771484315, 0.15126605343539268, 0.22964814357692376, 0.1876856741728261, 0.1530662810546346, 0.15014129894552752, 0.16992021730402485, 0.12937858962686732, 0.10945461108349264, 0.14097170816967264, 0.17827999137807637, 0.09005188738228753, 0.13121193187544122, 0.1854466591612436, 0.11542695545358583, 0.10955231482512318, 0.10561203758697957, 0.13784754846710712, 0.20914655149681494, 0.17607766814762726, 0.12695941084530205, 0.08557609122362919, 0.19166428333846852, 0.12937949504703283, 0.16228690190473571, 0.11940865937503986, 0.19443506200332195, 0.14844804449239746, 0.12418336293194443, 0.12343265829258598, 0.14713677344843745, 0.07491727723390795, 0.10224852041574195, 0.22482088854303584, 0.13321274716872722, 0.16016807028790936, 0.07484316636691801, 0.13339699275093153, 0.10430081849335693, 0.11925152444746345, 0.07732355748885311, 0.22810337803093717, 0.132238945516292, 0.18775978503981605, 0.14771676185773686, 0.11925591054023243, 0.0714335024531465, 0.11371696557034738, 0.12999905477045104, 0.11794311067205854, 0.10534618544625118, 0.14923350390745327, 0.10723562663770281, 0.09906549355946481, 0.06717168973409571, 0.1818232864025049, 0.14501687313895673, 0.11221998691326007, 0.12556031404528767, 0.12384696965455078, 0.12165517007815652, 0.09490821976214647, 0.11057166950195096, 0.09433686995180324, 0.18805646599503234, 0.11530568852322176, 0.14303670439403504, 0.08105676068225875, 0.13428146950900555, 0.24669468199135736, 0.19455937173916027, 0.26345607242546976, 0.15143575292313471, 0.1065155207470525, 0.08150650959578343, 0.15717890724772587, 0.12802596611436456], [0.06321748238406144, 0.05334744149877224, 0.05667768076818902, 0.05462905261083506, 0.01702674533589743, 0.025895430480886716, 0.04019165309728123, 0.04628941671398934, 0.031359090135083534, 0.050953295358340256, 0.05487639929924626, 0.06800238305004314, 0.015999694587662816, 0.05926698577241041, 0.019805813790299, 0.04662954299419653, 0.020742389315273613, 0.020031183630635496, 0.08932278666179627, 0.0704556932032574, 0.06374287841026671, 0.08102766107185744, 0.01836952240410028, 0.06012456338794436, 0.029063538313494064, 0.03501134728139732, 0.03563498139556032, 0.031965539819793776, 0.0946867183665745, 0.050964286565431394, 0.028325522544037085, 0.03388099328731187, 0.013486872539942851, 0.03743087116163224, 0.030965762998675928, 0.03637559282651637, 0.09108201804338023, 0.04871852172072977, 0.03385268406418618, 0.017867162641778123, 0.03954927975428291, 0.08952604606747627, 0.053408854219014756, 0.011124020911665866, 0.007900419914221857, 0.03179231884132605, 0.07788154121953994, 0.035797879099845886, 0.02680559853615705, 0.016835998540045694, 0.07943293414427899, 0.023637759732082486, 0.04807320947293192, 0.008368472044821829, 0.03453087716479786, 0.024623834651720244, 0.06835168969701044, 0.03110191555606434, 0.08017077736440115, 0.04820943438971881, 0.03099826350080548, 0.046501793403876945, 0.03928187652491033, 0.04673279428971, 0.044225303645362146, 0.05092866347695235, 0.02377759705268545, 0.01679312095802743, 0.029328228993108496, 0.002686748762243951, 0.02194899341702694, 0.023308865856961347, 0.012173645009170286, 0.015025834491098067, 0.03945841861423105, 0.03231516187952366, 0.06593806218006648, 0.03529695910401642, 0.05883912279387005, 0.0288006918708561, 0.00324666230881121, 0.04988129272533115, 0.03485604916932061, 0.013592671257356415, 0.05551702488446608, 0.0395068548823474, 0.06148164720798377, 0.008632275857962668, 0.05427530421002302, 0.04066179993969854, 0.017448710095777642, 0.03824285864538979, 0.0553036908240756, 0.023724103048152756, 0.012968978699063882, 0.03938553229090758, 0.03499582897347864, 0.020219731813995168, 0.050350348610663787, 0.09057306058821268, 0.05265330335532781, 0.047758512882865034, 0.05267172346066218, 0.04719929347629659, 0.02410363180388231, 0.039276236202567816, 0.015395401769637829, 0.05681504488165956, 0.05939372975262813, 0.0631446999614127, 0.0726679760555271, 0.029940042550151702, 0.08289633697131649, 0.07096398272551596, 0.02339516649954021, 0.07957479567267, 0.04169992353126872, 0.03553095826646313, 0.05436136736534536, 0.053553803081740625, 0.04199490125756711, 0.0397367833647877, 0.008048165746004088, 0.05163774476386607, 0.019062237479374744, 0.008940705010900274, 0.00999237929136143, 0.04850784825976007, 0.04008267613244243, 0.017821169894887134, 0.11156922730151564, 0.045101498035364784, 0.05757516366429627, 0.04664858650357928, 0.0274598072792287, 0.03988886055594776, 0.03453317782259546, 0.014617459382861853, 0.02948766457848251, 0.01866403628810076, 0.01855515394709073, 0.013096206002956023, 0.04099112797121052, 0.03687590797198936, 0.062280320562422276, 0.012876799319201382, 0.03874798661854584, 0.06222193580470048, 0.05173599027330056, 0.06606491006095894, 0.02308051258296473, 0.04098916870134417, 0.05720942215702962, 0.024740164444665425, 0.04631618969142437, 0.051267758171889, 0.05745409340306651, 0.10332530247978866, 0.029654905702045653, 0.020666052005253732, 0.04850601515499875, 0.02930455819296185, 0.04821577233087737, 0.024941575902630575, 0.031295940789277665, 0.004566522320601507, 0.03933803855034057, 0.047870150447124615, 0.031826383419684134, 0.058338136004749686, 0.04605060843459796, 0.030710358441865537, 0.01322560779954074, 0.04094276962860022, 0.05588015774264932, 0.10260491457302123, 0.016273309593088925, 0.0540488118713256, 0.029316083746380173, 0.017015507364703808, 0.0812957544985693, 0.031167526976787485, 0.04247215787472669, 0.07294162816833705, 0.027136416429129895, 0.10217178976745345, 0.06267489079618827, 0.0373616733122617, 0.011367973202141002, 0.02197861067543272, 0.05361240677302703, 0.02666101703653112, 0.042381641833344474, 0.031198886426864192, 0.037066751247039065, 0.03344438780914061, 0.04416405419760849, 0.03521647318848409, 0.01998749896301888, 0.06199494993779808, 0.0845950907387305, 0.02996887684275862, 0.05289672037179116, 0.025514077897241805, 0.05028000785387121, 0.020606620819307864, 0.04382526007248089, 0.05747832081397064, 0.04072453739354387, 0.04013480829598848, 0.03797322897298727, 0.06405287349480204, 0.05241389764705673, 0.06461942160967737, 0.028022691039950587, 0.006986068929109024, 0.08009324519662187, 0.03861558376229368, 0.06394759242539294, 0.045635269198101014, 0.0619726150034694, 0.029293815605342388, 0.016367122625524644, 0.042643427004804835, 0.027780071832239628, 0.038612340576946735, 0.07548768451670185, 0.073522425518604, 0.055895820769364946, 0.06907494229380973, 0.04018815016024746, 0.008522741354681784, 0.051158918504370376, 0.04424729348102119, 0.041186097587342374, 0.024726453266339377, 0.01333776115643559, 0.04964716368704103, 0.04760273608553689, 0.05217805795837194, 0.05656305977026932, 0.04360965504019987, 0.059009627511841245, 0.05677469802321866, 0.009403996264154557, 0.024960289156297222, 0.04102049846551381, 0.008012006455828669, 0.0247171745650121, 0.17339900485239923, 0.0024451486160614877, 0.02316598573088413, 0.10384578548837453, 0.041332931505166925, 0.037674577615689486, 0.02642741677846061, 0.027197228009754326, 0.05648616213875357, 0.02935080512543209, 0.013345336628844962, 0.05915216068387963, 0.0584399401122937, 0.012730609214486321, 0.04762870754348114, 0.05524620406504255, 0.02226296826847829, 0.027930802025366575, 0.05075816618045792, 0.02296159083925886, 0.05913916196732316, 0.048888518067542464, 0.046012959282961674, 0.017285743742831983, 0.02089768742735032, 0.02379827699769521, 0.023262240429176018, 0.022350168765115086, 0.044475529866758734, 0.03399459754291456, 0.03889538456860464, 0.02718325336900307, 0.025154577851935755, 0.028926587947353255, 0.025518855472910218, 0.017279064413742162, 0.030853696844133083, 0.010887280441238545, 0.020090086036361754, 0.05811224480567034, 0.023225415061460808, 0.01151911899796687, 0.05049710460298229, 0.06580765199032612, 0.022532972725457512, 0.11014886054908857, 0.03563095895515289, 0.022310693930194248, 0.06735231363563798, 0.03360502938448917, 0.05003075384593103, 0.050389879106660374, 0.017740242401487194, 0.07969268583110534, 0.020145042071817443, 0.011980884210061049, 0.018088461802108213, 0.03451357399171684, 0.027854937834490556, 0.018725079789874144, 0.060922004777239636, 0.016183786174224224, 0.1005757566599641, 0.07104715521563776, 0.03772495831071865, 0.04973415081622079, 0.03382258626515977, 0.02449425566737773, 0.030214097278076224, 0.055030227958923206, 0.03758010963792913, 0.021868561307201162, 0.010564725434960565, 0.024640716655994765, 0.02791563809296349, 0.043429988509160466, 0.04758931805554312, 0.02610417806863552, 0.016617306173429824, 0.05413778795627877, 0.043857584314537235, 0.054770368660683744, 0.02136625349521637, 0.023792764695826918, 0.046845526521792635, 0.07296938449144363, 0.008293845385196619, 0.009883405109576415, 0.05807897061458789, 0.04645887129299808, 0.011564900232770015, 0.036802683971473016, 0.008881906505848747, 0.00823260150355054, 0.04800107271876186, 0.031629699442419223, 0.04066620458615944, 0.035980914981337264, 0.04325459674873855, 0.022429003402066883, 0.0784571583790239, 0.033720997380441986, 0.0030311723094200715, 0.20167946233414114, 0.2262493595480919, 0.20282293378841132, 0.15304504078812897, 0.11271131836110726, 0.09667157748481259, 0.11866641521919519, 0.1879487358382903, 0.09562462975736707, 0.22099124325904995, 0.0954403322248254, 0.08577467509894632, 0.09012930822791532, 0.18068949255393818, 0.16030008351663128, 0.1256587079842575, 0.14001191826537251, 0.0755821747588925, 0.14939823100576177, 0.14146152563625947, 0.11517236169311218, 0.19153608474880457, 0.1187529496382922, 0.18310867133550346, 0.14777592587051913, 0.11302020764560439, 0.09526503694360144, 0.17407315695891157, 0.1889304190990515, 0.1041938379057683, 0.12074803555151448, 0.14801204757532105, 0.08264802178018726, 0.13176791922887787, 0.15911748603684828, 0.18537719413870946, 0.17679924349067733, 0.12682779837632552, 0.06568551674718037, 0.0945306224457454, 0.12843910488300025, 0.14817750197835267, 0.11250024414039217, 0.11578716424992308, 0.14303162810392678, 0.09222184555255808, 0.22565669525647536, 0.1311838490073569, 0.1036782085429877, 0.15858647937420756, 0.19553410849766806, 0.16607848985586315, 0.15684767189668491, 0.149555625685025, 0.14754793810425326, 0.13954534486401826, 0.15361248690169305, 0.14492385234916583, 0.17730817868141457, 0.1742836448829621, 0.08691472525242716, 0.1608594847493805, 0.1447378849843517, 0.14952929428545758, 0.1440609572455287, 0.1322334387805313, 0.0966424259240739, 0.1473394242930226, 0.09803278764593415, 0.09708559940918349, 0.12170845628133975, 0.12921387737151235, 0.13630521716549993, 0.21641867846483365, 0.23747538216412067, 0.11890691559528932, 0.2389133971882984, 0.1365315870498307, 0.19354126387042925, 0.1581155273015611, 0.1477805123431608, 0.17444092081859708, 0.0743344241345767, 0.09357115166494623, 0.0967653478437569, 0.10860661830520257, 0.1745466174907051, 0.1639483924373053, 0.1333865729975514, 0.19165741105098277, 0.13116859045112506, 0.1206778729101643, 0.1473622675985098, 0.19906419329345226, 0.09358734532725066, 0.07772692217258736, 0.1650418876670301, 0.12419659542501904, 0.16150611802004278, 0.10251753410557285, 0.11918364019948058, 0.22043850651243702, 0.14975269557908177, 0.17799825727706775, 0.15488730365177616, 0.1573796136653982, 0.09366239130031317, 0.1472560068941675, 0.13820251770084724, 0.12276112596737221, 0.15382898622192442, 0.11349428415996954, 0.1584472376271151, 0.1422761514550075, 0.05008829997677822, 0.20364444673759863, 0.09701766321086325, 0.1166716187435668, 0.18014392495388165, 0.19236939784605056, 0.2274041116470471, 0.1439530638162978, 0.31956576160155237, 0.14390777796506882, 0.14215314789908007, 0.07900153854279779, 0.1378806185675785, 0.1184429026034195, 0.12008185411104932, 0.10006592347053811, 0.200137160718441, 0.2983051602495834, 0.1813507016049698, 0.19396146788494661, 0.08991648253868334, 0.16859961004229262, 0.11574872842174955, 0.20734728866955265, 0.12546246929559857, 0.09922930039465427, 0.1282181081478484, 0.14552597160218284, 0.13281896361149848, 0.12214483169373125, 0.10659357241820544, 0.07379092712653801, 0.09057818882865831, 0.070565820496995, 0.14052711718250066, 0.15226588962832466, 0.06288261050940491, 0.14364829345140606, 0.11630132416030392, 0.1919501883094199, 0.12677138030994684, 0.12290461279917508, 0.18082796246744692, 0.10042735681054182, 0.13864549080608413, 0.13542269967729226, 0.09172869584290311, 0.16025024087866768, 0.16093800397356972, 0.1449320901883766, 0.1378217662568204, 0.17109147476730868, 0.0957712484523654, 0.11879966041306034, 0.09845661334111355, 0.13370223809033632, 0.09888227214105427, 0.182517847570125, 0.10083936751470901, 0.19388370565138757, 0.15094267000677064, 0.14655687409685925], [0.012959157302248059, 0.0741086331254337, 0.015155586024775403, 0.018700742912187707, 0.012039947105222382, 0.002152854913219926, 0.03980150977440644, 0.03092472965363413, 0.03707863674208056, 0.035976866565761156, 0.03396465559490025, 0.003250822278459964, 0.03782596832024865, 0.002960741103379405, 0.035025229153689, 0.028250437608221546, 0.04758961120387539, 0.021899197163293138, 0.05020706958021037, 0.04345969296991825, 0.024918842063925695, 0.02682060847291723, 0.04250935431628022, 0.053652679416700266, 0.05421436275355518, 0.03248537344916258, 0.06691093614790589, 0.03858989803120494, 0.04957770237524528, 0.0273076503071934, 0.011562001218408113, 0.07472768818843178, 0.015285749450413277, 0.041865852908813395, 0.03302336001070216, 0.05783401364169549, 0.02867370112653589, 0.05065586112323217, 0.03526333981426433, 0.04981914898962714, 0.10565587625023909, 0.006954123182367766, 0.1027724395680707, 0.05469365656608716, 0.05878461946849711, 0.04851611578487791, 0.021683376908185892, 0.031193657996482216, 0.05888571853574831, 0.02193759773945203, 0.05413209568359889, 0.05081023155071307, 0.028238260820216965, 0.02762980919214897, 0.0371682622062508, 0.016677392304700334, 0.007614110936629004, 0.05599586227617692, 0.0038210486627576756, 0.017434689070796594, 0.0380521229817532, 0.039342406089417636, 0.0733848758682143, 0.0312047493935097, 0.032365193765144795, 0.043929765597567894, 0.03476492827758193, 0.06808254242059775, 0.009279708792746533, 0.05038206800236367, 0.07549941787146963, 0.03556775023753289, 0.12131226816563867, 0.04899712395854294, 0.05640377632516902, 0.011450975925981766, 0.053619913596776314, 0.02919891347119119, 0.060846621126984246, 0.02559451557317516, 0.032770907346275635, 0.0481261097593233, 0.04062500796862878, 0.07823977590305731, 0.10831842009793036, 0.05835563213622663, 0.04287030526029412, 0.03603481345635373, 0.025706065935082734, 0.08346445843926631, 0.040107894310494885, 0.05369775746657979, 0.10818705253768712, 0.10817779053468257, 0.07269477500813082, 0.12692331278230995, 0.03305632249976043, 0.055328619564534165, 0.05484774497745093, 0.040570448982180096, 0.07538114921771921, 0.07501341504394077, 0.028492448254837655, 0.03819143894361332, 0.05485512563609518, 0.03604312922107056, 0.0387085340480553, 0.04253378581779543, 0.04762578348163515, 0.020765139852301218, 0.07837408236810006, 0.0211258941271808, 0.059949412825517356, 0.036442734926822595, 0.05895221867831424, 0.05711932171834633, 0.05934842905844562, 0.019671498048410285, 0.021485472097992897, 0.023660020451643504, 0.018619205002323724, 0.011421078506828053, 0.024214503100665752, 0.0328855357656721, 0.024357012152904645, 0.03698860680742655, 0.037543373327935115, 0.010709089856391074, 0.10655774152837694, 0.04606100592354778, 0.0242442595117609, 0.06877320731291547, 0.08683230233145878, 0.05130988618475385, 0.028125818025728222, 0.07638735303771682, 0.033394923666492105, 0.018721641790762078, 0.023488172446377575, 0.11275044438662007, 0.034160794093622826, 0.10803149838466197, 0.027576580505410675, 0.020451780983421486, 0.050881351562566124, 0.01311427729888237, 0.03630219442129601, 0.05022088465921115, 0.04794753789610695, 0.0029433927056743414, 0.016033432621043175, 0.02626766392495483, 0.036558020146912895, 0.019834911545331124, 0.012404768349369988, 0.036140543525107205, 0.07906983839347959, 0.05735736558563076, 0.017090189685404766, 0.027939251376665197, 0.0901335384696722, 0.04778301859914791, 0.05017156152462121, 0.02950796788354637, 0.03087331737333443, 0.04505934404733125, 0.030977622518548742, 0.09314615337643772, 0.06200682058988605, 0.048288692050846294, 0.05180603788176086, 0.017422501150576863, 0.03089391753746895, 0.07467175251804292, 0.04951103524945211, 0.045834958873456344, 0.08957656405982561, 0.01233682287420379, 0.03389701625565067, 0.06587561787455343, 0.022720307497365866, 0.025881188666971866, 0.024890727654565126, 0.05452969759062398, 0.013489225148077821, 0.025382381936651655, 0.027375408390071243, 0.012269845901755616, 0.06360859420965426, 0.0078008663695072755, 0.05526328088308219, 0.029082292385282926, 0.026999440087820403, 0.03425968156079762, 0.021474536551977508, 0.01755568511725869, 0.040218927024398, 0.039900044721434824, 0.004788309443028993, 0.07268365763593465, 0.001890179744350462, 0.045564865358755924, 0.06042857305146754, 0.051002959880861454, 0.05556498988880776, 0.055443641322199255, 0.04564210808894131, 0.009202546771120979, 0.01895657420391217, 0.023124230647226796, 0.02750760530034313, 0.01278187584830448, 0.03468680239166133, 0.03979006956797093, 0.03332849773869384, 0.012152601411798969, 0.03368348923686426, 0.009572731887601549, 0.048392871030955575, 0.040153239533538, 0.0292980402809917, 0.05166487768292427, 0.04577474472171161, 0.04596115366439335, 0.09104003474931233, 0.023967573870322667, 0.037638301437254995, 0.033900478374562226, 0.008285384901682846, 0.04333978045906406, 0.030777489409956615, 0.036056829267181456, 0.022828440269222483, 0.04553290105832275, 0.04078260673850309, 0.03334822031320073, 0.04146302628214471, 0.03815835028945003, 0.011000307677022647, 0.034408474748488516, 0.008360193387488835, 0.04716883944638539, 0.048452751216245815, 0.0364233017899096, 0.013305762531672372, 0.027720956059056334, 0.09785523623577319, 0.043289306995575316, 0.02550758781580953, 0.01875822781585157, 0.020804991327167954, 0.0071079782810556935, 0.02729985033511184, 0.05202815154916607, 0.05378409521654248, 0.04124958461034112, 0.022095727144915145, 0.06002639580401592, 0.03243653271056246, 0.030313962524814997, 0.057835279003484175, 0.06550540492753498, 0.06071675641578622, 0.05881625722395256, 0.019213156920159236, 0.03968849552620668, 0.0016407145722041605, 0.04147171683143824, 0.02853200101526454, 0.04303487279685214, 0.07891388348070905, 0.037457454891409725, 0.04031112403026782, 0.06922484128153883, 0.06685835498501547, 0.03233626855944749, 0.0714768141915556, 0.02753954362560762, 0.04028387236758135, 0.053818501182831824, 0.02159496485546697, 0.045215911231935024, 0.032030180882429704, 0.024816145523800515, 0.022338379749271553, 0.029952987461001612, 0.07343767967540771, 0.025808328318817075, 0.02510553673346294, 0.07467371920938604, 0.06536487926496193, 0.038076606433605775, 0.028977564215892926, 0.008909232383302879, 0.031552215514238924, 0.076394306961447, 0.04615487647242844, 0.04732213375973515, 0.04598613435518928, 0.03931601902877446, 0.00937415728913038, 0.009996827538998332, 0.01613399919733638, 0.05654635031532962, 0.05346077858121134, 0.01847257517511025, 0.0493357733648736, 0.01234117835338111, 0.023204523604363203, 0.029327299453143496, 0.019744172859645914, 0.07296737327123992, 0.043287689113640226, 0.03295540525869001, 0.062060915734036826, 0.04646118308301084, 0.026776190934469923, 0.027285994437988847, 0.05612994609691668, 0.015339672972913831, 0.046879368455847725, 0.029977539561514277, 0.0511442833521869, 0.056937094777822495, 0.07666787001653574, 0.031842885073274374, 0.07606370985740796, 0.03969197619881015, 0.0395054596447153, 0.056120134904631414, 0.02059836442640517, 0.07252394003444351, 0.023132082569645718, 0.05161296816368122, 0.04451421802514233, 0.01707304792944342, 0.040120288176694885, 0.039132270685513504, 0.07481905398890376, 0.024761315653449856, 0.024119192785292398, 0.0037075306818223908, 0.031276318404707126, 0.04320388950873166, 0.05893914574699011, 0.026800407213158906, 0.08027321600820869, 0.0526716529566329, 0.06276088344748132, 0.08658234699396417, 0.030366128085006494, 0.05974191204586532, 0.2719089563470334, 0.11076179289375432, 0.10738776691141538, 0.12048498872900382, 0.08428139975876547, 0.08822608535410836, 0.07569769004476257, 0.1995670874021016, 0.07116100809071213, 0.08473566093016416, 0.09407479534274898, 0.12934465863509104, 0.15703657816629857, 0.11158695720951073, 0.1877347004483454, 0.12206628278363496, 0.09665757315815426, 0.08693618816323578, 0.10048329990240745, 0.15763047442305833, 0.1783977702143602, 0.2079081890406087, 0.10829084931174293, 0.17109099979279563, 0.100009423767915, 0.18276032205903903, 0.17725116689689457, 0.1190999778918922, 0.26789693569298834, 0.09200256317853928, 0.12289514299482107, 0.149003527185414, 0.16190264752367511, 0.1649049762636423, 0.10883954877499491, 0.15134130720980465, 0.17893781623570248, 0.16493026865646243, 0.13064335769740865, 0.12105688772862777, 0.19951654714532197, 0.10692140873288736, 0.2037689642747864, 0.12984894798137248, 0.1262896225671284, 0.12705566739896312, 0.11768708456656896, 0.13299562444444746, 0.1202316046692431, 0.08790937383309938, 0.11282392442808487, 0.08369047951418906, 0.084699533181265, 0.12733998417388648, 0.14302462222985923, 0.1431412878446281, 0.06829307487350889, 0.14661960041848943, 0.08231867890572175, 0.15020932420156896, 0.15036759461509064, 0.11824669360066764, 0.08914358026231639, 0.1429597139940597, 0.10422450344776735, 0.08138158387737349, 0.10227114849840291, 0.1540960554848425, 0.10926214250503108, 0.21366042725276202, 0.15325055632274598, 0.1501375436782837, 0.14949332980904728, 0.22043053584638983, 0.16465013759443536, 0.1358817477012053, 0.1018638133245986, 0.10578368150163442, 0.1411489478778094, 0.1495121803600341, 0.07697897832258604, 0.16611273254966363, 0.1491958918632008, 0.15651864814572036, 0.14412645919946954, 0.1528787997085601, 0.1514562065131031, 0.14076494582695886, 0.19443439407041296, 0.18628807651111856, 0.1296767548774369, 0.11876949953148142, 0.18964951566886157, 0.16073164239060134, 0.2034845732850954, 0.17804471572162583, 0.16564455610932782, 0.20045404293341562, 0.13700378593057394, 0.1671747607178986, 0.10811305299284868, 0.12771997862728313, 0.14039244706509635, 0.1944418007042259, 0.16141916799824685, 0.15599841746734455, 0.15767714066896588, 0.14493626105831936, 0.14707704540342093, 0.07171144417952746, 0.16553675173781812, 0.17731321044266224, 0.09753370817634277, 0.16875826637260616, 0.171498809941113, 0.09885691295494325, 0.1282221602741629, 0.0697525379655417, 0.12383672059513628, 0.22494289762107655, 0.17570935509866104, 0.166817772842478, 0.18725718779023737, 0.18863921519368887, 0.11761517045670189, 0.07651518055354245, 0.1679870265070349, 0.17197436332935467, 0.11836928897537291, 0.18876652320614085, 0.07581809608382173, 0.08475468959659338, 0.1191097816627007, 0.17601489729713649, 0.1167644168890547, 0.23031960910884663, 0.11465587886050344, 0.09026961124618538, 0.13486637093592435, 0.26848112465813756, 0.082239922194276, 0.1791185440379195, 0.13259666069643572, 0.21132997964741662, 0.18293438537511975, 0.06404226820450276, 0.1966753980377689, 0.13762460730504245, 0.11785664304625243, 0.05334287357982248, 0.14576047542504966, 0.12681524123763666, 0.10468390028108843, 0.12494863593019545, 0.10156851276406087, 0.13935738854343072, 0.25512813648674637, 0.2135114188422449, 0.13619022880448028, 0.08934680256061256, 0.22547065367689356, 0.13930619519669563, 0.13133116532117128, 0.11592835784540512, 0.10085415109642781, 0.09575859483447857, 0.206818567821756, 0.12874737818492576, 0.20689033350208774, 0.11429627120378427, 0.18225773965241387, 0.21732488530687988, 0.12703558488283306, 0.28346793609671295, 0.13147027348168194, 0.18964440969284624], [0.039011649423628114, 0.040046681970125064, 0.03731554883415811, 0.03067321580601856, 0.02625551125674974, 0.019484042677504476, 0.008202765311580151, 0.08311948593473062, 0.05027969615184702, 0.011752101418096572, 0.005828607991134049, 0.025714624753163662, 0.016901121998671442, 0.06879685213789344, 0.033460796694271266, 0.06589765966054983, 0.012023899089399492, 0.03893722685461398, 0.039386986900353804, 0.0149008262087591, 0.04027782386401668, 0.018983139379997738, 0.037843063691980205, 0.062379872251767665, 0.0491487595718354, 0.04528497920546215, 0.0725442600378301, 0.06347992064547725, 0.04481673597183544, 0.04231987288221717, 0.026201738946838304, 0.05078440110082738, 0.04483363467443269, 0.034759332484100014, 0.03900453964888584, 0.03966470598243177, 0.030299707723315805, 0.0635275145759806, 0.03857758209051099, 0.047460993300774135, 0.012166100150352577, 0.14736473152879626, 0.03509340655000415, 0.020429520263860468, 0.05066555728262756, 0.043459377557155676, 0.07565623367554508, 0.0355518348806072, 0.04569603253912646, 0.021598146813630592, 0.02656192176800687, 0.023288506890821736, 0.006957640498512774, 0.016537306364625692, 0.037638965659425594, 0.031091751843632665, 0.027513794811966363, 0.07708748773438856, 0.017136249225586653, 0.009045983297255589, 0.01793030085536884, 0.07289349989150651, 0.03543084254488349, 0.04083351435838267, 0.012576840854308102, 0.017793556435208302, 0.0622458774887491, 0.023416230505972635, 0.0394237937143771, 0.031895262145553716, 0.03509800415486097, 0.11570797709282488, 0.03704781163833104, 0.014603829840780236, 0.0428115048998734, 0.07776601851219311, 0.009364051093143644, 0.008400710939895362, 0.02932609717390733, 0.05010247499740217, 0.07523157677496783, 0.06936840974958614, 0.07883000595029444, 0.02560000375524396, 0.036787328936043195, 0.03647893317975104, 0.11801224914961495, 0.05729607531975489, 0.026073258341057226, 0.009922038534568856, 0.021001356180931907, 0.01971395260625286, 0.03020782613020856, 0.01992081513890298, 0.02225834468845278, 0.01108460544855916, 0.017371357898809947, 0.03732240627869032, 0.012197569994896185, 0.05312284534738865, 0.014971393320593052, 0.06615968974074349, 0.03649118974863086, 0.034461341638234444, 0.06519815578940324, 0.014081163990340428, 0.11674861656501889, 0.009665551369835157, 0.012527059443527833, 0.05776083045930136, 0.030110768057056703, 0.031777175317984074, 0.017423740537196863, 0.0901710095058661, 0.02727186023548711, 0.029740779609710444, 0.009630868025851669, 0.03723931542481296, 0.020722136105177924, 0.043356898095225915, 0.09228875016560778, 0.04762915283208713, 0.0898956875607837, 0.060038440860807896, 0.03136493083729874, 0.035193841395084746, 0.04724155878648162, 0.006992511698626913, 0.039885138685349375, 0.0194880873823422, 0.007294800507224863, 0.03205783330486156, 0.04335372170316987, 0.04482985343202017, 0.023309917851292994, 0.019517595173965674, 0.06023883557645604, 0.04738504190754611, 0.026121614828298334, 0.03839292090560775, 0.002141690924872819, 0.015177845816651825, 0.014529860909533454, 0.03813093906501308, 0.05669160345860291, 0.05070890983915888, 0.015120571497391211, 0.018892845982918516, 0.06245353783015162, 0.027351162425475195, 0.013139932416379452, 0.04198062604700681, 0.050652525169425644, 0.01698229811154306, 0.008371360854653176, 0.020061259165231604, 0.09412425948539749, 0.039974385654204525, 0.02278962409036467, 0.07322692457819358, 0.06884253874886781, 0.06013725411321502, 0.03818005439825356, 0.04291195087716915, 0.028106080608267803, 0.03367018623976037, 0.09380199669976719, 0.06009495169564616, 0.02882917735405499, 0.013926338997407584, 0.06608351570321247, 0.051401066448306665, 0.05770590782049112, 0.055683117534499615, 0.03540487108693924, 0.11010177127900533, 0.045461172485374846, 0.06756260117981583, 0.03487381247396115, 0.05886742459551897, 0.051468245655996725, 0.03109896551904967, 0.04822536087885965, 0.07288186301593669, 0.06281604728428647, 0.023830252430343535, 0.033726689653121866, 0.04347227237303741, 0.024979009831440635, 0.030163211922626942, 0.0332623983558733, 0.04203552642138675, 0.017629938847676385, 0.04464149635168724, 0.0250947013773839, 0.029571514278359246, 0.028797884697269183, 0.03928153513697907, 0.040984515435411595, 0.014255784844863228, 0.06712642614729702, 0.1317766765714623, 0.027840534603456035, 0.05258511482679751, 0.0675499252974987, 0.04193816406768747, 0.029683446846320294, 0.02443025470711291, 0.03810168360359967, 0.03938676054531243, 0.046439983634627424, 0.056899260089267045, 0.027374473283998668, 0.03174920006131288, 0.034271626427653246, 0.03816320764599368, 0.011072397119278321, 0.01778700327122351, 0.04348092210420873, 0.04165259306319058, 0.024881751378416084, 0.04932156123686582, 0.07194505742518231, 0.02590406351373531, 0.047405209770658985, 0.056299456337001175, 0.012724177577183582, 0.024707135162316263, 0.032224489987129346, 0.040507778321625665, 0.05636707712255884, 0.014946034134482034, 0.010690498129406478, 0.04848867858527228, 0.030517698760377243, 0.019485393386275973, 0.05933514461503364, 0.03777981786697637, 0.01185774428449804, 0.0303659277051338, 0.019389014378248248, 0.047214540900313295, 0.030729533682460897, 0.05088897712994367, 0.049375700909877196, 0.024890002205211204, 0.06407508597476408, 0.049202839873032644, 0.020053969419677742, 0.04052652497193776, 0.01827167023293441, 0.03270631823397707, 0.04710247289040126, 0.06379518497851677, 0.04415485898789484, 0.05924560078710783, 0.051880731334676966, 0.009893292371998541, 0.08545844597392716, 0.03256922500440851, 0.04889259987976402, 0.050718513230094686, 0.0711237225914374, 0.06312185665592551, 0.06860122943180613, 0.0290547661279561, 0.025984673739003483, 0.034033330230158754, 0.027492177905514836, 0.015801578265381977, 0.03982523252489045, 0.03160428459523246, 0.055884710818645544, 0.01029463934173691, 0.00922242519663996, 0.01520755677120178, 0.013062865946267266, 0.052212471346138045, 0.04194561894109938, 0.030245189554989338, 0.05117648142913822, 0.05013282141590025, 0.09002242411952466, 0.014256201375246746, 0.035646959659061395, 0.07772568278596736, 0.03327773112687282, 0.04375114178401418, 0.03182324413501192, 0.06898705716594122, 0.04075760007253848, 0.02705105460336199, 0.029494100854208227, 0.07820437545888126, 0.06860115521703847, 0.03472163880360313, 0.07782170185237192, 0.06690259440802038, 0.04067112873599399, 0.024201960804930422, 0.02806488955684472, 0.046350911070476286, 0.0376815241179429, 0.041963586336351, 0.05235948337940499, 0.08163088612491265, 0.030561034618585836, 0.042611488679540344, 0.04664448984840419, 0.0356510303390678, 0.03725896378455218, 0.04640645711333491, 0.13785906659904867, 0.08973746909759939, 0.015976153663359582, 0.006041610868123826, 0.052741318359039724, 0.05069692044344265, 0.061636095560970716, 0.06706668325932696, 0.04164714198850561, 0.03171346565068234, 0.04369764035800472, 0.03236116761399899, 0.05070262755907606, 0.013151626808394212, 0.03875884794979356, 0.026148987089982256, 0.05033653724240139, 0.069003970711492, 0.05697394612070639, 0.04298354215279687, 0.08699334095581435, 0.05244481180852745, 0.020080770227650646, 0.02386344684055075, 0.04993958100385498, 0.07318843679968268, 0.016447257876279764, 0.062459259788738564, 0.023464013684133533, 0.04988973836589139, 0.05086896140710451, 0.09742202979396097, 0.050618649838725105, 0.04553894956188742, 0.03593867564632092, 0.07668508042115718, 0.012554471595649375, 0.048454127900185995, 0.0679838887299411, 0.066652631649049, 0.159113077679649, 0.21353687450755388, 0.20764333137776703, 0.1580650167306885, 0.1245128468144685, 0.15775821288116276, 0.17106285755289719, 0.10331440775189549, 0.15821121982298791, 0.12050740158883855, 0.11422233103075996, 0.10813798173330724, 0.09116197703406215, 0.16255566326435655, 0.0926437861926388, 0.19027729838853702, 0.1332347295829095, 0.12351828729151748, 0.11753329672501422, 0.06954513737582602, 0.10060540545964614, 0.16862205258803442, 0.17597954138182104, 0.13459627371048555, 0.15460187365533784, 0.1726727094501257, 0.16850902349688113, 0.20450624346267432, 0.09518098129774444, 0.1535508144297637, 0.14082612848142162, 0.11489355165394954, 0.15871723095187917, 0.24246648856205866, 0.14643344009527937, 0.15032981929834932, 0.08175719965947792, 0.19995181675767526, 0.14010324695846066, 0.11969830477028154, 0.10094173936522566, 0.23904548463178799, 0.10415992175694555, 0.13122288597514853, 0.12412415439030156, 0.17401526944013312, 0.14268547558458522, 0.08110122274956666, 0.09893984795780852, 0.16404881986090913, 0.1025528900208883, 0.07005619510891847, 0.08030872777453624, 0.10829014427145012, 0.19238006992964074, 0.11415032044169493, 0.09319929115008563, 0.18805339350365102, 0.19412819878198206, 0.07533316194894724, 0.13265496381791309, 0.1637838879832998, 0.11912609406863339, 0.10171292728045955, 0.13031195907387882, 0.1368133063078858, 0.23178349540103227, 0.04872498582699336, 0.17112761735916138, 0.11821867010439746, 0.1450253781513311, 0.29477874166332185, 0.08512363347108476, 0.05604231329925824, 0.11922275880351663, 0.17926811648067087, 0.15547331830020994, 0.15268876537447795, 0.14219898293958977, 0.15981909760739654, 0.23337810358498245, 0.16292212094413117, 0.14012220141012222, 0.17293588985921815, 0.10856888751732185, 0.130687233468052, 0.2225266132154502, 0.14722407970111817, 0.17578070517629385, 0.18834487942513078, 0.10897507236222737, 0.09757196588907391, 0.12054806386004202, 0.07621375727467239, 0.1507184375077486, 0.19761840056162328, 0.13120332296239212, 0.12879650836111978, 0.1174845673085656, 0.1060382901050616, 0.15380537108285353, 0.1571407460141927, 0.10232830129098147, 0.08376163663342595, 0.18309338309336454, 0.10072758523165248, 0.17198435263708234, 0.1572768113692291, 0.19103010330582038, 0.24968213809188455, 0.1291453474550508, 0.1316727462108247, 0.11322219797875732, 0.16264236095594242, 0.16434397199191153, 0.09255989381927066, 0.09940522650140338, 0.14866203535348177, 0.22975734318606555, 0.18822120793629438, 0.1426742839976214, 0.10482207333552651, 0.1760181924328208, 0.21288734686095268, 0.086811447981745, 0.2060478029306978, 0.30490671226289123, 0.15493015525862575, 0.14212788519216701, 0.1468935122829862, 0.09970670915208757, 0.13871041388483718, 0.11885723622981459, 0.1592006065766327, 0.14308176760096103, 0.2207254950189963, 0.3498008579481393, 0.2167015554732643, 0.09961541756638326, 0.1485762430820614, 0.09998852488934062, 0.08579691726481542, 0.21775194676592946, 0.09955212721251883, 0.1361829409142956, 0.10230652667814866, 0.081006732507376, 0.14829332154477015, 0.14277337555540726, 0.14520509663270786, 0.16507197433384135, 0.140398146759253, 0.16636031301459298, 0.12847285775933415, 0.11292369876173325, 0.21495603898074478, 0.18679445871384814, 0.09262746636522934, 0.14415534358704463, 0.15428996382979676, 0.35133244295138866, 0.1452410759520717, 0.10071476091980003, 0.1087160554016009, 0.10622704052366316, 0.202797107049264, 0.16307391982991248, 0.20151564065599814, 0.12584230047650635, 0.07475747799617238, 0.14862434909446165, 0.14929483499145135, 0.1384284274536185, 0.14797922980505973, 0.18649503181222826, 0.164364009979181], [0.01598145259777084, 0.05283367863739841, 0.05062906217062846, 0.07538721998571418, 0.005639489745590254, 0.050273298838874325, 0.022532551556651015, 0.019180209274054505, 0.012092582073819358, 0.04996576397388708, 0.027775375892815646, 0.023079301026882604, 0.09123464813455939, 0.01767281828506384, 0.01035559749652748, 0.04856127176026348, 0.07566353640868329, 0.054567569386563264, 0.09937561480910517, 0.025481646043772344, 0.07833967640181072, 0.002836084413502249, 0.056305055841221474, 0.04855407663853839, 0.11927001876756549, 0.03911755760782398, 0.01889011859020684, 0.046345448863576166, 0.023184400270110928, 0.05229061578575056, 0.01859370109741576, 0.10332188860047609, 0.07939806062495336, 0.048380050429841504, 0.0135512436463614, 0.06549613550305367, 0.05314605601597577, 0.041304240075987764, 0.025165183142235037, 0.06373897471348755, 0.013211160967330215, 0.017157099864562042, 0.03046979683858808, 0.048556410692981444, 0.038603549837716855, 0.0709104812995065, 0.01435341715477989, 0.06430930778151378, 0.08969356364104897, 0.04654422569728922, 0.08422165687079541, 0.06931447787792422, 0.008098684666038025, 0.014872795291012153, 0.02908470807597041, 0.010307638058293378, 0.03315305773867294, 0.039724077796563506, 0.01969896307855379, 0.03206154033250641, 0.0502419208351057, 0.12092501550796442, 0.11054090005927719, 0.03865229038638063, 0.05578255790169351, 0.021826678203069605, 0.05713553764508106, 0.01631564911804162, 0.0487403371516848, 0.03729663891135715, 0.032724259654060006, 0.04177108065050561, 0.024977746325021144, 0.07271088703419082, 0.03438918633037247, 0.0416507080080919, 0.04267256743332837, 0.05564226972637698, 0.01907659989228705, 0.08204600642784499, 0.07687553777941503, 0.051829330186592415, 0.06015248298353981, 0.028401401577866636, 0.020694557897513732, 0.01377153812427423, 0.05984731556964107, 0.022781302759540267, 0.022206572466529906, 0.024860794983396772, 0.023223405696626287, 0.06862251422717236, 0.021475740686582867, 0.11195861734449863, 0.034110083142877556, 0.0859560930985026, 0.021104128791193943, 0.08095841127214953, 0.02785933877021307, 0.04555626386718359, 0.03502780440612696, 0.024671332103025634, 0.01603603199328063, 0.11175906867720187, 0.03830663510598242, 0.05503832479007542, 0.07766403999994509, 0.016466423840029165, 0.05642182906740345, 0.03607049962738529, 0.018315705565328244, 0.018719741892709862, 0.04402195518196095, 0.07267100401804782, 0.022260487639869098, 0.06802357878768817, 0.026976492881658487, 0.01713499499601312, 0.04555890220217407, 0.04852006401051767, 0.04498272101045586, 0.0360143932630308, 0.01631382343475707, 0.019357749552000314, 0.020630469734896906, 0.03124800176010467, 0.07113297717296518, 0.07837417884729803, 0.041648904589237645, 0.05376496636017691, 0.027974705626547802, 0.04431830588146113, 0.03125258081126958, 0.02122709895047592, 0.03466595175268594, 0.033935637620743364, 0.03587738538044505, 0.08186691877199337, 0.03466961054073181, 0.0154367727918725, 0.037761895000585355, 0.033203531202161685, 0.04357777608674951, 0.02695899489481235, 0.04977012642484624, 0.0415582401183201, 0.09167576587060466, 0.01172252497781301, 0.03893315988534596, 0.006663550566372578, 0.027146209067723248, 0.08280772453872487, 0.027774913905886933, 0.042098627527593635, 0.01424344385668519, 0.01146906763096922, 0.03407661599339917, 0.10344190872274339, 0.08527898724423721, 0.06497986047179438, 0.09925803635269403, 0.06130216992460191, 0.025161448284052312, 0.09121317038079724, 0.017574763878656086, 0.018946115487779025, 0.04516524852078874, 0.050660996785154566, 0.06906679351232015, 0.08005024516023695, 0.011443820694694296, 0.04758341056003701, 0.04311426775529981, 0.03878119030559901, 0.014229881107894471, 0.009348849125672132, 0.00581502761633601, 0.02867294413590571, 0.026137532040593214, 0.0039829808793001575, 0.04213387212075759, 0.034617712153703906, 0.07629520798218437, 0.0278458539469284, 0.032256391205010004, 0.03299765943665989, 0.03167556045809761, 0.006494027338703745, 0.059741986260632984, 0.04366031404060777, 0.036548806383507326, 0.0781756617652718, 0.04818206769414246, 0.02701202691241633, 0.028255738398001995, 0.014881253919156734, 0.05045383739343379, 0.057210939849028364, 0.03571826149709523, 0.019979424396296963, 0.0394336865429068, 0.09503696011961438, 0.001514730713552126, 0.01056631548635778, 0.053970968001522124, 0.0217680299829226, 0.007190003689174773, 0.027634521829895675, 0.0284520030618296, 0.03644443073426373, 0.014369940145115834, 0.013100191335979616, 0.012019050082017202, 0.029637732404808048, 0.0295534207180026, 0.09223555302014574, 0.07849759800592437, 0.06373784664901905, 0.06892695804708637, 0.04951973693096079, 0.01625938504730584, 0.020429709511518013, 0.03135848528472707, 0.06228150799870491, 0.05117154614708852, 0.042383812615298666, 0.006097511286498047, 0.04491576073633041, 0.043437651183921844, 0.011934271769860061, 0.050935955077875406, 0.03892784610798117, 0.0311725698702503, 0.03644697259005625, 0.055184290395118296, 0.06282264497713186, 0.052643224989878945, 0.04889162766630761, 0.03310025393147953, 0.04963098486769013, 0.018304113218619023, 0.05028092440625187, 0.08180963981430978, 0.031239882664522156, 0.08946588757680729, 0.059989128858433105, 0.056026884049060754, 0.03752945805899799, 0.03200956773071084, 0.06439572345698252, 0.01243833105036174, 0.015623451690771617, 0.0307296876781038, 0.09632203335058875, 0.05360111128538847, 0.06861914487672038, 0.04336865742516238, 0.0032994461707858136, 0.10157241646084003, 0.025236540641344618, 0.02510725851607276, 0.022664110219920985, 0.05194118668441661, 0.03898891001881566, 0.05049237341154367, 0.023855682120483834, 0.027591853904596064, 0.03849019420158584, 0.03460717365669552, 0.022456718907051254, 0.014218996584531851, 0.06327324736048467, 0.04342507178080268, 0.0635538311325945, 0.029086355643812567, 0.08542533134459518, 0.06152600537461694, 0.0663613090000581, 0.01203510273626307, 0.025672444789961446, 0.07624839330674149, 0.02623056210723007, 0.0400526711018756, 0.04948212859744672, 0.043670782033586875, 0.028639347110583913, 0.016597795111010782, 0.022858441589050926, 0.03937071160180494, 0.01415245933458209, 0.041935165791073814, 0.015596838275087066, 0.07675112414290197, 0.019722819415619597, 0.02780351813271409, 0.007214600318548037, 0.023641438929189462, 0.012573248859553132, 0.0218717395546264, 0.04305202754039783, 0.027128191577503458, 0.0018221270056528738, 0.08413427640334703, 0.02259885317471344, 0.013079681157250889, 0.03760106046684086, 0.024384838980040513, 0.028065939695807174, 0.022103566079749726, 0.02931933806394227, 0.09141734262811951, 0.013437621764751384, 0.0365368392522214, 0.05995316067128442, 0.015478748664463637, 0.0567708388553001, 0.03455261838098522, 0.07708250792347826, 0.03689849152578972, 0.03242685510485899, 0.05006616913306061, 0.012973304492334137, 0.025312785182904918, 0.05496513418620452, 0.031560111965518445, 0.08176973453373648, 0.016091765428427607, 0.022747562870790716, 0.03388950201042462, 0.017937418051587883, 0.07584395993035287, 0.021613101089315023, 0.01296623275266029, 0.05497597325302195, 0.02203353331424296, 0.03862484576529823, 0.05539424026210327, 0.039132144520408474, 0.02942030354461167, 0.03535119896696415, 0.03164127323543653, 0.04229967533319723, 0.014454166484938469, 0.052037591667613015, 0.018570598040241748, 0.042057475438923575, 0.03508044123009313, 0.03689629476866685, 0.03598804702050984, 0.055266765266424045, 0.0731543054280337, 0.0028721933767883456, 0.06193665794853587, 0.13777769752778113, 0.1997007185127586, 0.0968969009409193, 0.11060726290452294, 0.13885544438380748, 0.16538483410840854, 0.0886411833926104, 0.1036707054299768, 0.14429232920520008, 0.10954110097372904, 0.10688511771149933, 0.23312167671974748, 0.1739539680420421, 0.12126425121095963, 0.16410393174737692, 0.14173818344715983, 0.17863979941466823, 0.4080871178302914, 0.1572999218478799, 0.262147844186984, 0.1675073616206646, 0.09622042591217905, 0.24998861539643258, 0.2033235866110772, 0.27262845367658883, 0.12758942000800744, 0.08735743860597722, 0.16049455589381978, 0.14531775465002283, 0.12067698233295232, 0.14170506881782785, 0.13566812791395932, 0.133154058130458, 0.0910412370285485, 0.14349987875903025, 0.10704112457460724, 0.09419696769327857, 0.05826267442898825, 0.30369698186405003, 0.16318908630637452, 0.14084163936786354, 0.26267732202541083, 0.13474256586050615, 0.10430149384774268, 0.10154642644920386, 0.06916048965649679, 0.16713486285880208, 0.14268750906921923, 0.13489467644831166, 0.21820863476023078, 0.1618362549925223, 0.04998980584787205, 0.12220924269058742, 0.16718356258934364, 0.12655482161790133, 0.07965989032527432, 0.12117795427911915, 0.15496156294830143, 0.15050279907882214, 0.1390556461410597, 0.25870549608953297, 0.17034100019373, 0.1675776281626895, 0.18105750874383375, 0.1518711561220698, 0.17203481867909431, 0.09710453901789151, 0.17058853612979874, 0.09145445001195185, 0.17126970895333216, 0.06448156025726348, 0.12790076580131426, 0.16747902642237023, 0.16614688618574291, 0.09794767072889954, 0.15751593135064468, 0.19558666739612818, 0.13234198529971763, 0.18720369378570467, 0.14393439138075337, 0.17002627020701766, 0.19370797992451116, 0.16885668999748304, 0.1609663391718641, 0.11770272903959267, 0.15393673122162, 0.1684830928570591, 0.11522213753778487, 0.17412216839147732, 0.1329832008923404, 0.2325387642486021, 0.20294795598601922, 0.13831045565893874, 0.11000677637639455, 0.17645024112425745, 0.12058100779540837, 0.17397336778230965, 0.08462934827548452, 0.10817437665537, 0.0931794906500727, 0.19725731603102759, 0.12396178732160479, 0.11322607941110618, 0.16238155541941524, 0.16108845215057954, 0.16816350922454149, 0.14152600342640653, 0.18246085062855855, 0.11883515733643435, 0.12675543897785246, 0.2397834465955384, 0.0720225005352404, 0.13690188905457035, 0.09656784008257091, 0.1378114355611615, 0.1924324210267514, 0.12591728707775474, 0.15884210471995175, 0.13947862578788772, 0.15620451187714934, 0.08997470402391627, 0.08784374571405351, 0.16673726466251537, 0.11303280931315385, 0.10958686179947108, 0.2353378335828893, 0.14972525095799938, 0.13199163222452626, 0.17438606126233935, 0.13789240387268364, 0.19233563012676314, 0.10072848323034123, 0.11128401252790354, 0.23324812384089455, 0.08354042467544787, 0.11535421755979769, 0.16904375574085861, 0.09161289854091592, 0.12790762324584648, 0.0844255396805238, 0.10838588874321431, 0.11789947238867171, 0.11448076169472188, 0.1750487249228172, 0.08762672689044848, 0.16935330553678796, 0.10173417496844195, 0.1035852100176271, 0.23438877513399348, 0.1271479163551703, 0.08570604128181003, 0.1325429292046465, 0.05055360801634379, 0.2293808665126562, 0.170353171415627, 0.06981020284001715, 0.19879584753653035, 0.17772001127013937, 0.10366056769271381, 0.12676747661316767, 0.14743918378371745, 0.09724979958264157, 0.22665225667878985, 0.13965913094580173, 0.08457093383185565, 0.13732995983446017, 0.16274991299724206, 0.10441435224493034, 0.1614449205226265, 0.06861900386866182, 0.08250907689216547, 0.11951992215472274, 0.1617987616918981, 0.2058431037585251, 0.09091982909012586], [0.014264881720009726, 0.040245213895104825, 0.0181187636917457, 0.047384611461893655, 0.029379210827755742, 0.021491541010618676, 0.07785379231791012, 0.0952232391864527, 0.045453576603904366, 0.10373437427915633, 0.021181377087486908, 0.08895419159671292, 0.008810136187094031, 0.051329000198165886, 0.011637598236120539, 0.017988444415095728, 0.012564552744152024, 0.025274497784266714, 0.026788967006723396, 0.07551572285592556, 0.05014679234591313, 0.06785910401958972, 0.06974097530473955, 0.08143780898535624, 0.02229570996860275, 0.02661986309249187, 0.10561816772678867, 0.025334802849101834, 0.04080312341102399, 0.02260168817883823, 0.008910388278309256, 0.010521700351091567, 0.060274462375673465, 0.03645597113063559, 0.02392135291302111, 0.015561470299871871, 0.011786721679527545, 0.050788238004315645, 0.05009057837014552, 0.024198919854825363, 0.07239827958983369, 0.06672407820587978, 0.035024939716095105, 0.05449745127407368, 0.014401886819541687, 0.01512095463112928, 0.01094430428565829, 0.029066972601867747, 0.05773439886979759, 0.042699522236944176, 0.047651491477154195, 0.035468146597850136, 0.05362061121559236, 0.03149803131236695, 0.02309234427229967, 0.039449898758903146, 0.02524097311834339, 0.01657319848163752, 0.07741564317257144, 0.0247221321114921, 0.01311478195930249, 0.023101092338038143, 0.01682804271695204, 0.06217509515408892, 0.021753281653218437, 0.13872936833649874, 0.024340269301319495, 0.04344798930105753, 0.04443090452696197, 0.009192289362545125, 0.031037738335726317, 0.07814697033609264, 0.055012750381138176, 0.05643445299938321, 0.030532066739397123, 0.03866420556732919, 0.026596784155117348, 0.057894446727004834, 0.02275924984132871, 0.0043137435750395525, 0.007582687476315186, 0.053653113573091105, 0.04639783706807066, 0.05149109638296068, 0.025587053278286476, 0.046196789262467064, 0.019136188784614205, 0.01557977815537015, 0.02829837663739454, 0.025456023395236116, 0.03565232167602517, 0.061623790752491914, 0.08254876694991253, 0.06933786295121536, 0.0060215241774130845, 0.027984186563116964, 0.00586275745263265, 0.029877678025513887, 0.10210665888735093, 0.031840729134273715, 0.08073723642155528, 0.0254863920781645, 0.008364300247194478, 0.02934105330496095, 0.017033933036145754, 0.014845270889054518, 0.021090326699777506, 0.03364300879184157, 0.017348171350022312, 0.06711678564897738, 0.0720767886377871, 0.019282358480268158, 0.013058832373644691, 0.04348663664131891, 0.03715927479788661, 0.0054903305863263085, 0.02127416224539047, 0.037856099515920505, 0.07968073725351132, 0.01686844894720707, 0.027273620980849955, 0.04279146691260394, 0.023600977037858684, 0.06766242746380158, 0.01395849069012911, 0.0563344634429086, 0.03015104441146832, 0.026239068974973634, 0.02735407164436765, 0.060784236193285324, 0.016463097163068596, 0.04537147280643694, 0.0330312972801039, 0.01991693556192331, 0.03039457089471398, 0.0030428163745455095, 0.02876048045436619, 0.010217144281341461, 0.02088389275741065, 0.04609095529303886, 0.0865971454186365, 0.02257783926324919, 0.027981878483842593, 0.0131382616564224, 0.02381537422479596, 0.024725970870349556, 0.053636793745681643, 0.016450716284452938, 0.015260723303072155, 0.09120309943682514, 0.05656468136294279, 0.2033157495316118, 0.024879300435713958, 0.04067656867846381, 0.012953162604389945, 0.016080733403214253, 0.06827202014392242, 0.024866268322512042, 0.03283976380771492, 0.016121223125082906, 0.09347845742013305, 0.024126094758685213, 0.019733545304916333, 0.015156823556026211, 0.07966096643940546, 0.015114719662960852, 0.03392820872250013, 0.028158151544630527, 0.03654222353361547, 0.03945451862819027, 0.06518686030176468, 0.04359126462077256, 0.05749300791649148, 0.025732621834322345, 0.009073113433260005, 0.047969817169359885, 0.00672637151183153, 0.0299345766325132, 0.06611536868149415, 0.11438114321208559, 0.05890758962777909, 0.03714824277267326, 0.041922968594008125, 0.05080436858406756, 0.06185508107591886, 0.06660961676971056, 0.013497128093149513, 0.02488092202838743, 0.03448876770562492, 0.05461255095724482, 0.04125359220779501, 0.024680614515091293, 0.06993302828050219, 0.04490829844144173, 0.03955856402171776, 0.06634336386923678, 0.038396264280891046, 0.036852830889984034, 0.04752332257339731, 0.020782411484105978, 0.03117708212812431, 0.01823870959924534, 0.03796170713030733, 0.01991610992263304, 0.031566494435537606, 0.024246697466878686, 0.05210520132095553, 0.012326364158070646, 0.056988128562807105, 0.06489193081506528, 0.04335783691203687, 0.03594227506255265, 0.003690681378429872, 0.015112642577150837, 0.051377221243456006, 0.04814785468624905, 0.11148994366521947, 0.026053003275592346, 0.04096548676898237, 0.035668099735630676, 0.022017803494236432, 0.03293514091637917, 0.05634266046399716, 0.06248679346754216, 0.011293888310319744, 0.05023233228712343, 0.027008206707250793, 0.0717718550004065, 0.029010808721068315, 0.02940017464425182, 0.030736233420611825, 0.13343718746909872, 0.045794612015015446, 0.03057984620681964, 0.06311499178991653, 0.03982682072091848, 0.042443726197234355, 0.022706928430125117, 0.03211877847206779, 0.036218602617736906, 0.05988789620460011, 0.09383006472489797, 0.03929110513126943, 0.062063542936812155, 0.033653643768047914, 0.01796048214600887, 0.04662587307393551, 0.056271844732691534, 0.013137097412254661, 0.05781356005172711, 0.04566394578432664, 0.035805497245746665, 0.021211486018728465, 0.031367387346108444, 0.02449897201586282, 0.01740792351483833, 0.08425005886238068, 0.01223726005264325, 0.009751176658028271, 0.072300167666981, 0.054167128764675, 0.04740838616271503, 0.059941850340692326, 0.03789639442402404, 0.0108237052882032, 0.027905053211725317, 0.06752863308065571, 0.04255473664670717, 0.06910295836860314, 0.051395248010521755, 0.03822473168838769, 0.04452986620890442, 0.0347282179427566, 0.0330511274660239, 0.029594773186545353, 0.035159643230144866, 0.02261992089188425, 0.01885088309791172, 0.04387149958347436, 0.04937350044201594, 0.03475302422884852, 0.07727047166554257, 0.07035242335405201, 0.044462252844823524, 0.06570657147676684, 0.0324845051363809, 0.029226909136923496, 0.03103242826909991, 0.02522836217394797, 0.016428427734354045, 0.025738943077158183, 0.028501890228653792, 0.030148758596624248, 0.04539098386885598, 0.05366170393244829, 0.04016190410766285, 0.009522427262709243, 0.0302447553985985, 0.08493275308865122, 0.039175708589027636, 0.051277632446726784, 0.048567246049060486, 0.07666857505682856, 0.00749214499592199, 0.022729291194991674, 0.015351081638073083, 0.02431539436656749, 0.033130592928500846, 0.011746259788196767, 0.04600962332915515, 0.025666611509223003, 0.016177624493138865, 0.03621164127252996, 0.07445299706887454, 0.05213751443079673, 0.02169360926927766, 0.029307619552128017, 0.04809154794202186, 0.07524157350417227, 0.08123096500639804, 0.015229220061883098, 0.036486606986727566, 0.04167507271631621, 0.03998891690571327, 0.07314609727472998, 0.027066882757935673, 0.030012335155333858, 0.058320806856499985, 0.03504613174300175, 0.05738533342082519, 0.04114143885090016, 0.039986341653275304, 0.0353201586403884, 0.04954437623382546, 0.01655705491430126, 0.023875822153058834, 0.02138405390724074, 0.007938048656797037, 0.022195763085619546, 0.07439496854203753, 0.031880055539659224, 0.015397538227261975, 0.027791944339696784, 0.021758187249361072, 0.022032579654478468, 0.04062739768414758, 0.07335119720664807, 0.03249303983466234, 0.045239953105919994, 0.02441247099341126, 0.013281710453156848, 0.034128213810618035, 0.0955728575354442, 0.13094395719235763, 0.0981116111506708, 0.24238311569206417, 0.101180421479512, 0.20306051010265946, 0.1514370591030456, 0.17037217039614916, 0.1642315069329925, 0.20387917320476845, 0.14719905448146164, 0.15604123938828707, 0.0742239851388149, 0.16166452202014625, 0.12062765177688561, 0.0899714459956158, 0.12893572042230517, 0.1468863431364298, 0.15783680632011965, 0.11677066577249207, 0.14773320785025135, 0.14965971931815147, 0.12035260442644358, 0.1548104319954291, 0.22171649965457618, 0.20078789064427838, 0.26007849897723645, 0.08088433751254342, 0.23662749328650534, 0.1480000841547735, 0.11733997467672452, 0.07980128430062905, 0.13887497771065682, 0.09123504147282802, 0.08425727995927446, 0.12609192926902324, 0.17046774417394772, 0.18672741309273988, 0.14015341614140198, 0.09880842102575116, 0.1988036697730422, 0.17275934776989743, 0.08447416519629769, 0.20614385168300942, 0.11481142559205182, 0.1006338074512314, 0.09828730719164014, 0.11678930852212943, 0.12802326469682157, 0.07213100252556615, 0.12711576651781797, 0.13458297442412004, 0.12380713858874515, 0.09138577166595496, 0.14731779810972512, 0.1704115339089185, 0.11787812822149135, 0.14954251935705543, 0.11709715137840249, 0.06552219230798073, 0.14306411932921037, 0.0953780734562315, 0.15772080863825977, 0.11727937089744955, 0.2180093977949582, 0.2814749727258459, 0.13124580349540338, 0.1505578070646152, 0.13623549981275573, 0.10410908464109525, 0.18501922662835568, 0.24527038185624406, 0.1711464233812876, 0.12029646095470525, 0.12613245053216815, 0.12511039443779737, 0.07757616229355335, 0.12134153847000562, 0.08616426552180201, 0.17814449005527422, 0.17437676957342774, 0.31036182423122227, 0.08818507427349687, 0.13868751120753586, 0.20037969457916915, 0.10197361407335848, 0.09888293265248649, 0.08997777651529759, 0.10029809694970027, 0.19620026025222614, 0.120588392164791, 0.13409936131210998, 0.12134803968365304, 0.14455650409217924, 0.12053637503413484, 0.13149587757652625, 0.16651073150569573, 0.1329246602836065, 0.13657599716680124, 0.13911884743720293, 0.13242460117908195, 0.1086056609346997, 0.1651845729793422, 0.12983202701434493, 0.20537832635454834, 0.1292236737208441, 0.120458256569691, 0.13036110409302637, 0.18764334206935018, 0.17335760785499588, 0.17861284461105242, 0.11703198339091614, 0.11881190584972501, 0.13303902524057776, 0.1911572035169229, 0.12907349271699786, 0.16395070793805644, 0.1871253378340043, 0.11956537869991735, 0.10641436601872556, 0.10454704824951477, 0.22330099978717044, 0.1519070760696195, 0.220278054184746, 0.12458388519007713, 0.20574793074047193, 0.2174296765588224, 0.09289948575315066, 0.14815700385952368, 0.14141067367745563, 0.108211335609667, 0.10428935231175274, 0.10765087310574017, 0.2169684911496006, 0.16712408687453717, 0.1267273264238611, 0.12420643630321138, 0.1140909263631329, 0.11878380813868716, 0.13404107303358614, 0.16759953636210412, 0.14599491987610236, 0.20286787825170904, 0.13722110161324963, 0.13659615389769897, 0.03756195670575835, 0.13001321494812146, 0.05516654193343129, 0.1287116957246326, 0.12891494028735906, 0.18430615629768, 0.33759235055185854, 0.13558536360505968, 0.16089654760435224, 0.12160379861597903, 0.13560933497501537, 0.1476452633505687, 0.13108809711411595, 0.06311143690254539, 0.06318730665952899, 0.14136489800876006, 0.10405743116280064, 0.053966437189956196, 0.1721873300266452, 0.14746285829460248, 0.18856681126635522, 0.15188592486083508, 0.06384350621374324, 0.18177385936724022, 0.07834361720597371, 0.17808630567742512, 0.11411608516937122, 0.15159958944423124, 0.08021425979677588, 0.0743951540789567, 0.07917855560663156], [0.013633438356919214, 0.04383129744383041, 0.033289783605141565, 0.023424297651217785, 0.03622855481808074, 0.027924263704335317, 0.020906357567582745, 0.02825070478138514, 0.04200551025860477, 0.017035218806995545, 0.07454008809872903, 0.030465379204542842, 0.05441004112071823, 0.035668797354446724, 0.02828126642270945, 0.026366707243141718, 0.06469614483648911, 0.012539642557385378, 0.03964090530644171, 0.02885531765059568, 0.0532757648761617, 0.02847319879947463, 0.01990676813875325, 0.028741448077198584, 0.010954192475765012, 0.02900418319768505, 0.07850707523175515, 0.04073038180649746, 0.03560362194548361, 0.08342027096659876, 0.06421947822673246, 0.029376127204159275, 0.033875412336783484, 0.01889692593977088, 0.03267176012741402, 0.03827571723377332, 0.050534223119029775, 0.01531364399852464, 0.05415856066974811, 0.044576988875633106, 0.03478582344541792, 0.05075464468973223, 0.015481092923437245, 0.015720715709903743, 0.02330288971279515, 0.08070983632933348, 0.030247788927226793, 0.014695847803523066, 0.007715027250014828, 0.04032436765555758, 0.05967689990939107, 0.06904986512381583, 0.03257382632000372, 0.018355800093559083, 0.013722335588681744, 0.026215513207716867, 0.03620049792516511, 0.05586303639574908, 0.010173590417252854, 0.03945971737266518, 0.0244777076295577, 0.04205748286040034, 0.02962228645628784, 0.03961154965509195, 0.02029930674325442, 0.026517285295994952, 0.028485668735811487, 0.07104501783032902, 0.06622886532568373, 0.06191690197738353, 0.026646272417565342, 0.027199261494388338, 0.03279002135968767, 0.06057336606318131, 0.04673981871746946, 0.05600391457846854, 0.09253466821974143, 0.03134141217742581, 0.09147144519374706, 0.04818235713173635, 0.03694762541272212, 0.0819870427949354, 0.00473975257591519, 0.11203173373360187, 0.03944325653719716, 0.03957499146054033, 0.0036748228421856766, 0.047091819360502996, 0.004403932143759448, 0.04531474674877245, 0.060956570305279456, 0.034739962429739535, 0.10872983708395623, 0.029183992592152208, 0.054215817363001406, 0.012739339654217474, 0.09757020699908026, 0.04925530971377157, 0.04537921711744275, 0.04779573529958725, 0.016094364800665062, 0.009485967402724782, 0.04849402575928252, 0.009684434389782837, 0.016584636832703836, 0.011308359262329759, 0.008890388326108223, 0.01692994515906321, 0.017336065066047013, 0.013390229141805321, 0.05358657261240296, 0.04094895542948507, 0.012865365606558044, 0.07425851727020927, 0.0772671468439512, 0.0395458510320168, 0.011902695241587935, 0.04271253208571579, 0.06266321681323461, 0.03894870045769494, 0.15204694122076035, 0.03902650722011458, 0.07332586770644411, 0.00844370912091108, 0.04113100796530489, 0.058231916118529625, 0.02372170962189557, 0.05953504209173843, 0.0508922017615987, 0.014987560080044204, 0.02451889682561159, 0.08962540479842573, 0.040164078600355424, 0.0066448554025555495, 0.013888559969927883, 0.07772845099680126, 0.06302641646470875, 0.020141427812632173, 0.06095352007832844, 0.03338679343869444, 0.04365432861959562, 0.08018057371373288, 0.0266240172641119, 0.04514211948844604, 0.022545314641320147, 0.03420611705223564, 0.10344990907469764, 0.025119279453065246, 0.009223911347362446, 0.02900655621488113, 0.01630872859095689, 0.007791609004925704, 0.08668835536809638, 0.03082234110479476, 0.053113030444364995, 0.022956865213927813, 0.026580573794490192, 0.03934086242225021, 0.03419573069550097, 0.049434913162258454, 0.006596052699023858, 0.046055833154241554, 0.018044879179797135, 0.029191072680987418, 0.029603396942547988, 0.013135580647940515, 0.02819415498379385, 0.027922319277422503, 0.06414989446057007, 0.05263292769086547, 0.024050852116488386, 0.06539509951835498, 0.05744413378124591, 0.0782376756251324, 0.026321406548959203, 0.056626780569786206, 0.04036454753077123, 0.032076164352474734, 0.033276825706707314, 0.02144586182112107, 0.03430964665312786, 0.023974516661837697, 0.037168829949223436, 0.02984623879456194, 0.020070719692739658, 0.03484631590254139, 0.09775735437870026, 0.02425817663606722, 0.026814944030775223, 0.014442311603488633, 0.06953209784114733, 0.04639261605916545, 0.0488344637415139, 0.038684017199557275, 0.058041187876369804, 0.019771244551520795, 0.05067331272584852, 0.010229288600385189, 0.0358666836109478, 0.0070663034421158955, 0.041865337116178125, 0.024713213351788, 0.02812000886478927, 0.02214506697782781, 0.01222794053319376, 0.05100339032651391, 0.05384912590670865, 0.04077303303347435, 0.025797151574806776, 0.041178605606546625, 0.0868981382518541, 0.019648675151984207, 0.04771274092490785, 0.021626344714604784, 0.0744829946779646, 0.06429889544961043, 0.0549480759218568, 0.05133557933731936, 0.009665934503573226, 0.011458941953605972, 0.06100975260778796, 0.05238384437689092, 0.011661942535283742, 0.03524859705066774, 0.009712837309052702, 0.08250562590546906, 0.06099873542552814, 0.02528219200030435, 0.005172259543542168, 0.016822886645968538, 0.060330060368869454, 0.04851051256991923, 0.07151288256864063, 0.05819658617838286, 0.048799879659782164, 0.06758902905858122, 0.03610074956668541, 0.09959012517356314, 0.034135568494093604, 0.044036582912667654, 0.06362840213114396, 0.013851436815457419, 0.045170469529693946, 0.039200025057652965, 0.15887291869148612, 0.02214094620285323, 0.00659355351672275, 0.07075864530634135, 0.052602280702558346, 0.0407544311019592, 0.05563986887864303, 0.031207027786877006, 0.03728836767550092, 0.04690417474193964, 0.09286551023251377, 0.08442861959338188, 0.025452501904510427, 0.032903488317970186, 0.04685236170189455, 0.016918876026466023, 0.08693510462762788, 0.015389663112728158, 0.027753252470574807, 0.003940419173886767, 0.048503462166991085, 0.06900550695718266, 0.06057517690351233, 0.04495942499488592, 0.09876317970338278, 0.04063256303197704, 0.06009667347825598, 0.014572027885151329, 0.12086774397175759, 0.05358797156077344, 0.0189427572695422, 0.03269974280556198, 0.04430743712873664, 0.008368808794330107, 0.03650547609140631, 0.026220802865282167, 0.019216426080674864, 0.02653658670169534, 0.07086031953804195, 0.024251519571407698, 0.04230414306221064, 0.028184670336486306, 0.01094639157599886, 0.01445408206564025, 0.045778477724525146, 0.038373083298210986, 0.03382000359124504, 0.038159118412295356, 0.011673522822093219, 0.01234117185958894, 0.07326136023038998, 0.026527478694333695, 0.06316967323073186, 0.024187861854443327, 0.05074020620668307, 0.0750058377161622, 0.01549893229821464, 0.07546711960458197, 0.07171724035288207, 0.024681523645995185, 0.08031177058001049, 0.009273494233639212, 0.06233144711586647, 0.015302846677514026, 0.07725447838311084, 0.10302573457011022, 0.04787241770827677, 0.054041672410676256, 0.05365392251405865, 0.02571617213106947, 0.018977007384819444, 0.03596389011363499, 0.07203263827250339, 0.028636961105803493, 0.05072808693512343, 0.014851920532237273, 0.05028567415138241, 0.03799587932007853, 0.034132028449676, 0.026325783364882227, 0.03454190547927283, 0.02027702190389391, 0.01935533571668202, 0.015172653565969085, 0.029236915142973885, 0.04963798332028091, 0.0397262263140874, 0.021886281938350294, 0.049324218125548214, 0.032906219421420246, 0.023379865269816946, 0.040510657854611054, 0.036193929918226786, 0.05259507073787972, 0.0697799603221938, 0.07983735267771408, 0.00221811659685045, 0.031256302681867965, 0.04361543265986256, 0.03582441830076277, 0.029669976865989156, 0.002467935796630627, 0.040200195217039436, 0.04037333084852435, 0.017057915538316593, 0.03284311089373659, 0.051860682215192355, 0.06274571394897066, 0.17744277458405122, 0.0826257944572717, 0.16091486380901188, 0.0910708264564164, 0.13614866853458807, 0.10396525642136112, 0.11408042497350834, 0.13884471292840317, 0.12104022651328705, 0.09768239004188217, 0.1551008492242545, 0.2583987219259143, 0.14733445190358907, 0.10530521147302352, 0.10833882915903814, 0.16020651353755966, 0.15712761000031605, 0.11102466160082258, 0.16137238300871104, 0.12322367692831904, 0.10018473389209248, 0.0732123116904404, 0.09664002878707834, 0.1538473172695376, 0.08743432510527782, 0.09976875269785523, 0.2541915461188182, 0.11195177474291995, 0.10319060267647728, 0.14903312403475866, 0.11879331505042501, 0.247106677852571, 0.12722216080874205, 0.17550235526869074, 0.09763983529410325, 0.07404013289487921, 0.13581090228399262, 0.12781829835148528, 0.18053981621051207, 0.1238955877488479, 0.17603365879040211, 0.13835047226166353, 0.10382484950241633, 0.17042046936694533, 0.11890129011590034, 0.18769655405776575, 0.12203038510051556, 0.11966789155849256, 0.076513288076967, 0.22362870251527056, 0.17729094601236284, 0.18782604398438707, 0.10168686305405572, 0.09352784734801389, 0.11691732899635099, 0.1624142099171877, 0.21483190736034885, 0.1471881300676614, 0.13889022142393515, 0.22425816248869523, 0.08407733141211793, 0.18582910270197317, 0.09227536924299784, 0.14836131711490452, 0.14327163866255432, 0.13570873823482543, 0.13554953271523118, 0.1743148299283348, 0.39019886520691216, 0.09249419148545712, 0.10687859423342161, 0.14358632412040606, 0.10597833941574208, 0.14942649198928848, 0.19337842182721943, 0.21023442124715075, 0.16708898328943178, 0.09956494410289451, 0.1943011934054084, 0.18936515436507761, 0.10603398564853705, 0.16888162615941837, 0.18264693673700094, 0.29306541953701526, 0.10959620543872006, 0.1316339467302896, 0.14363106078235433, 0.13087410625303164, 0.13005477521801367, 0.14600251946831122, 0.36551559751387686, 0.14933704835129902, 0.19237898639403284, 0.09757930572959594, 0.13637472671689466, 0.1089066092390567, 0.2839761885115877, 0.12838322116294876, 0.1250276598148048, 0.13118788629071787, 0.1382969634141773, 0.12991970434086397, 0.16021625051507726, 0.11148498611873947, 0.10387260670540854, 0.18251731322379783, 0.13584363099653274, 0.08751797256991267, 0.20780396182090044, 0.16175012133317068, 0.18190691160270944, 0.12882646144134924, 0.19944644387578592, 0.17622548912186176, 0.18658903223695233, 0.15396223141578957, 0.11774281985708512, 0.14924663992132992, 0.14408139599254355, 0.08007042415556498, 0.1927286566933617, 0.09520439605694264, 0.10998584039043635, 0.1861871444270946, 0.09580305690178648, 0.1692676023230888, 0.1840792372240685, 0.15623703278834, 0.27284406241960824, 0.08486264981911518, 0.14752558461623266, 0.14745040505658835, 0.16220499848714098, 0.11766218551201746, 0.16108880838146433, 0.1822176339919679, 0.14528667350532487, 0.12518417875980958, 0.14778499491512775, 0.12463267397833988, 0.10944549008854665, 0.1546840145601891, 0.12024285562802106, 0.16066522017354146, 0.18146068789064884, 0.1168215177312959, 0.13393254135735333, 0.20669771649409086, 0.07878745120251551, 0.18245074257720262, 0.11872758303070441, 0.07966087738168426, 0.17734865541569889, 0.09231840638676658, 0.13823171379044652, 0.16245020407950506, 0.157441493938677, 0.09601745594409294, 0.15813745034392923, 0.08569516139687039, 0.10508570645470172, 0.21484777447767556, 0.16832308581797406, 0.09367057718918659, 0.08616968319984153, 0.08037326493649743, 0.1294089137809351, 0.18182125291787088, 0.14565360615961254, 0.14337215514387935, 0.11645710095763206, 0.13263255095807835, 0.1481661619618535, 0.1791182323358953, 0.12310641017393209, 0.1379809420905076], [0.06169750457047485, 0.04259858644218184, 0.06161000164865982, 0.09390845778398216, 0.04022878645628225, 0.07198727820650674, 0.05254929877992254, 0.0289599753159564, 0.039331823063548654, 0.021626613743137568, 0.07488178031053394, 0.03941373390262015, 0.038439045383711345, 0.06085082910431083, 0.03695715087815188, 0.018400167537038215, 0.04547026750515215, 0.023893791403679643, 0.02075744378089439, 0.06337109953165054, 0.057172166343661956, 0.029835791210643947, 0.03348651953274384, 0.016247560779447667, 0.02091759924951475, 0.019504295887600165, 0.029276978129928466, 0.007476308956029243, 0.07021875513601117, 0.020375020649225917, 0.021797222361783497, 0.0049634850529400865, 0.027959504586760886, 0.11019018333172426, 0.08492057444527745, 0.018200492704636417, 0.08420430545811541, 0.0466771332139615, 0.02968033353681676, 0.07915550449979492, 0.02294833422638476, 0.03729995631147176, 0.003382819736543752, 0.06443250429583713, 0.05501106941665057, 0.036245984156266786, 0.017120482298196293, 0.056023247525445186, 0.008257561785285361, 0.04047871581860818, 0.08956402176409028, 0.045758220803691074, 0.023656873745494522, 0.04831955426197965, 0.019316358120704535, 0.02580382348241983, 0.035685978073161095, 0.012846521549363388, 0.039038722970872186, 0.02502191338862758, 0.0036276616765462677, 0.023823829142202158, 0.041041182121261954, 0.031277487287297845, 0.056167532166000456, 0.004552515210889396, 0.06631409356486984, 0.022204308916116133, 0.06275752151850611, 0.026815348501258995, 0.0446645660122158, 0.03734850761247799, 0.017060841455531772, 0.02616431243950501, 0.022081808165239636, 0.020836732983298134, 0.0881478407245595, 0.06661742416326888, 0.04072648553119507, 0.05367003825085703, 0.04105120853637345, 0.053768443322042, 0.01699905209534336, 0.03222222643671557, 0.01772908235579962, 0.048508430845686235, 0.08244649900007062, 0.08103199521428905, 0.06184634599776473, 0.03128853044472635, 0.03031868258403847, 0.010068820502056042, 0.0457888232631376, 0.015474100964638637, 0.07033472313196398, 0.005942026709817583, 0.03379399873665534, 0.005201459807722131, 0.005664586860802956, 0.0315257950569503, 0.0006489957934263657, 0.05356776659027673, 0.013073421141598374, 0.004428312622621888, 0.01274794114578981, 0.07395837048534304, 0.018090367266268004, 0.01630195834877668, 0.03850236542348284, 0.033682750799926, 0.06446616069297306, 0.034669744127313606, 0.01342810372079839, 0.04564756287436467, 0.05583838596066926, 0.02570216038293438, 0.07828611560398713, 0.037210245500318706, 0.02777457622869406, 0.031103882247407455, 0.03709300101036206, 0.02929119953478221, 0.08124111758661456, 0.05703778937458992, 0.014315519383671926, 0.029171502246754244, 0.02121272169461008, 0.06322240282315761, 0.034025793720502406, 0.04609383482602425, 0.05129092431161553, 0.014759193818463245, 0.054977735853753984, 0.047783612317289226, 0.0515608953719493, 0.04755657078931108, 0.0536098240991123, 0.017610398099350277, 0.03136733539577108, 0.0733387291256804, 0.07751800760161132, 0.052465558546828106, 0.010780311913549667, 0.02661950686160708, 0.0181115704253898, 0.0344294144451851, 0.08725365667487495, 0.06188369086885359, 0.051345913743716665, 0.010702926319936523, 0.0628159953339491, 0.02367679298913572, 0.020177139958832413, 0.02863908179278951, 0.07216465150122531, 0.024579513592470903, 0.03644639000413008, 0.012913246191601502, 0.02160773721698206, 0.0334199563076254, 0.0170284782507224, 0.019047928872168995, 0.08954357559559867, 0.020257622163626365, 0.053489388374146074, 0.06305407630861737, 0.02120096793078119, 0.09851102018728852, 0.034513143546064384, 0.08337737483088858, 0.027930356736760587, 0.02151215787307592, 0.020970848345314153, 0.05456047074403614, 0.020108875360165257, 0.005676456585206324, 0.087409277621191, 0.008711419413884869, 0.045084721787134185, 0.07032347217318602, 0.03386730437341612, 0.028894766510347836, 0.05914147004659753, 0.047323777616838925, 0.029968630078656133, 0.01845514398155501, 0.06392155788489617, 0.02748903676547343, 0.02276469906064449, 0.024812267802190036, 0.0441519905871246, 0.026414731619297527, 0.03861258548568003, 0.05123558978084475, 0.05533904302865267, 0.019284859517938457, 0.05482269007188734, 0.030157731162034906, 0.03085812375502428, 0.020299963543948252, 0.0498919054371072, 0.010990080882038455, 0.05258325945760589, 0.016440829022030812, 0.02545485636801459, 0.009605481009202776, 0.054558778647333384, 0.06680057136691175, 0.01962631053174846, 0.06991771777393296, 0.02402050198725192, 0.021566509058175143, 0.040902107357396744, 0.061463865349651314, 0.023508095400757156, 0.05607805142062716, 0.043736617953982204, 0.009866780073934933, 0.05377141933422536, 0.07882480349508114, 0.11072411405621096, 0.02347175613977015, 0.0038194375065359054, 0.03650907179689966, 0.07925369805889204, 0.008708976820344105, 0.09043657220900059, 0.07062426462653093, 0.0053472273521038005, 0.06786719342926517, 0.006427524413084029, 0.028219935338711366, 0.025916455524566118, 0.02989114058436826, 0.04003068868769333, 0.02307709499291377, 0.00906976170881535, 0.02263514048536308, 0.04163851452176459, 0.0945339621102903, 0.055973408598219976, 0.03307090941234492, 0.07350736734224483, 0.0709600344998762, 0.06207099781022407, 0.020954821666236967, 0.023784131662978325, 0.008509737999702338, 0.013938739357399754, 0.03131215300527401, 0.02484949021891225, 0.01617552978132153, 0.05148827622178942, 0.06999432225711644, 0.010360645028413273, 0.02702203291846672, 0.01577269573317608, 0.029924349837529007, 0.08188510139007121, 0.04069780894496944, 0.11384193581761792, 0.026769216601678636, 0.032443538584630005, 0.046280195529107004, 0.08577805187087506, 0.002993335069731984, 0.06338440623949282, 0.03087719509494491, 0.017588567825441714, 0.029947137481940445, 0.027285931355436333, 0.03645826436695643, 0.025562631053617224, 0.019878896782756783, 0.037190975635894574, 0.023745632752252277, 0.03394937106349971, 0.014503378297376912, 0.013377252689679153, 0.019627340261649806, 0.029087270340824034, 0.05833612478454597, 0.048320170244551264, 0.0796628143871203, 0.011175205909239594, 0.026886336781899445, 0.027167295338585973, 0.11503478977829218, 0.07196373728220351, 0.07389392238110304, 0.07670370090636425, 0.06875789680634625, 0.09976778048439883, 0.07753544065053575, 0.01772942930983845, 0.049824540692497976, 0.033781486126827076, 0.005176252298042527, 0.033118681458290666, 0.021850671837455593, 0.09550359289278276, 0.0020681371324826614, 0.04911284333502408, 0.023264810115506407, 0.040664078333065845, 0.024129998455464374, 0.030155896201904397, 0.02556081279180944, 0.05052630069258157, 0.05001968842407223, 0.03980496076110285, 0.030349661683430895, 0.027083558816229925, 0.05854509130585939, 0.10176455849432386, 0.006115925361882546, 0.046718489393242635, 0.01793910272681387, 0.0063827399753790814, 0.06786711179302074, 0.05460508866235614, 0.028300783051236067, 0.09723206967464648, 0.06518179143313318, 0.013065632301731966, 0.05304660451656673, 0.028719161382468883, 0.03344553813803941, 0.02834062895999523, 0.04523830924881622, 0.10801428798004054, 0.018459600578353275, 0.03262632955738809, 0.01207582994538825, 0.07802196298143826, 0.027936410806432832, 0.016561190532229375, 0.022627969483437482, 0.08173383685061708, 0.03041805244720308, 0.067789371823892, 0.06531977152917534, 0.07983849558513612, 0.055452855085604824, 0.06202556352945976, 0.011951819851674372, 0.044645451998803765, 0.06824392985436134, 0.048752831207821146, 0.021601236003334634, 0.04235648302710615, 0.009882229733193526, 0.19467220787191764, 0.14121611224254593, 0.16328482335666195, 0.23680980928475037, 0.09634315487346612, 0.20695452927611768, 0.07832039540517144, 0.19857027917169034, 0.11963837634539232, 0.2101285316166468, 0.23302867077291012, 0.12463252554880455, 0.15813758393051103, 0.13070094835711643, 0.10414569478598423, 0.13370124361244962, 0.13687310856767, 0.1465041667688638, 0.19542655645636842, 0.17853831814136356, 0.17927392007550225, 0.14872548897983506, 0.14272908418206498, 0.11304776358883828, 0.07427772405208088, 0.11167036718688905, 0.12286659999517724, 0.09681902738520876, 0.19898571859812364, 0.1377284189220518, 0.20983143505873159, 0.154325675975997, 0.10542558782617562, 0.23975469579454511, 0.11326553940307349, 0.07076386260450818, 0.12718598853098229, 0.1272671201149933, 0.11581744387513027, 0.10315724313841201, 0.068793274986092, 0.07828924004570581, 0.07766883427393623, 0.171014781226404, 0.24427259399089962, 0.10559294954873621, 0.07160548775573261, 0.1412718920619227, 0.15013320953585207, 0.13076018658466637, 0.316545101813972, 0.12627138057723641, 0.08187494138837792, 0.19939342484576628, 0.17261311499169096, 0.17199679103214294, 0.19457118673017249, 0.1396246804506518, 0.09649973319028504, 0.12462627666536719, 0.14998231607023627, 0.14793723908951506, 0.11500808730488643, 0.23360638821031898, 0.1212034396303352, 0.14196663134498522, 0.2304031007224694, 0.13456787914037704, 0.17188787343911827, 0.16706542752217501, 0.08142200123984367, 0.18201581435278058, 0.04938164922350552, 0.09754861050168984, 0.20169501774944365, 0.12782910402165726, 0.1958064321661368, 0.19516472675604746, 0.09734206338180229, 0.16243822581600398, 0.09985697179217823, 0.17696063092444092, 0.13112018757965416, 0.1461555651621893, 0.20143698784522712, 0.12487914122175425, 0.14879584457958117, 0.15424657787662, 0.20674319530371577, 0.1479210751131177, 0.20513858296908438, 0.10670365518308245, 0.0910214068426285, 0.12173731098300777, 0.12980332074221224, 0.10171140587772243, 0.19883424625732005, 0.0897582492325455, 0.09936138783814386, 0.1350255764555186, 0.14727944391779602, 0.1309771163505502, 0.16015906061511487, 0.07381619725492783, 0.17148699495010078, 0.25472571433056146, 0.11891811460372992, 0.15049766341689974, 0.08329645104822703, 0.12989113165531307, 0.119583249615971, 0.27769203821662813, 0.18143169960239902, 0.17613905860343948, 0.13635774637805298, 0.12253595094080083, 0.2467561763478443, 0.11736024272977374, 0.09059955526026897, 0.1523036797880195, 0.1329371877363883, 0.08501117583364248, 0.10296268912497908, 0.13161413138732314, 0.24704320938326418, 0.12144231470301747, 0.1858014502795413, 0.1797605463070795, 0.1773929616319947, 0.10000459238654003, 0.1846230830415152, 0.10748163374955766, 0.18850607390049845, 0.1597738711279817, 0.13572659430792555, 0.08889315737178549, 0.08495005255099386, 0.18712183489697054, 0.25315625010989606, 0.1167766771686729, 0.16632276034215465, 0.10227447331999429, 0.10065175258205272, 0.15712661552242935, 0.12035201070830226, 0.15825801965547726, 0.22491855517728254, 0.24516833655070513, 0.1505117939086631, 0.12433258656528778, 0.09800509811611846, 0.14271155465394258, 0.11509185351314954, 0.09820584164117463, 0.16660357418004423, 0.0710356370836962, 0.11298002034891397, 0.08585658593801782, 0.14997182210208848, 0.13186567492084578, 0.056066603792714886, 0.0895709460019134, 0.2110621682368219, 0.17416702379705384, 0.1615290652262047, 0.13402053038589656, 0.204208642244339, 0.15560781030217186, 0.1434423919999972, 0.22706867574015632, 0.06443950274842791, 0.1681764968088828, 0.096399884641869, 0.17484608892118558, 0.06792923697503284, 0.10836566521902569], [0.031268948878278024, 0.047949411818990484, 0.05560050907661207, 0.056950141733977944, 0.055513481129310094, 0.0470749317901209, 0.027513616696523968, 0.031387184135382995, 0.052714456323883496, 0.015619818877894431, 0.040816901382640935, 0.06539278401760384, 0.033083689195336774, 0.013289445487316698, 0.0043768618434114615, 0.04911760792310815, 0.06639322877163067, 0.005999474506097613, 0.022649478778475896, 0.07590345790958963, 0.027277925437374506, 0.04032357355754357, 0.06670214774203487, 0.05501520317920949, 0.03776458899665158, 0.007145331501305918, 0.026482942412258126, 0.04212137806462124, 0.05975398307782598, 0.06413433904526755, 0.04025745191029273, 0.058093910047318786, 0.01732939501380315, 0.014773184229852632, 0.019320490027894266, 0.04867446783464402, 0.04299355743569322, 0.023404005478369072, 0.02065358577965526, 0.020254466180631425, 0.028835632183472626, 0.034963259822689, 0.030701953619427513, 0.015215786261251196, 0.02950124031485757, 0.04715191476861946, 0.04246074735419825, 0.05310460335749667, 0.045012618429609574, 0.04276802246749867, 0.02580389398644911, 0.04908108683594037, 0.03321559852338396, 0.023589269658259582, 0.012941329987370409, 0.07971577404532582, 0.028700492657662835, 0.03633875632658601, 0.024986158568935934, 0.03282945908722468, 0.04882245579210576, 0.05003266858693678, 0.05834556490299292, 0.12615918269148096, 0.04934491291351151, 0.01695889819529839, 0.017652511269261595, 0.06838256304035895, 0.016607543220743537, 0.11595923118875362, 0.1166653327527456, 0.029725393033004366, 0.04728564235847443, 0.03782448773563374, 0.029664477551705204, 0.09719336667330936, 0.040750089538050815, 0.045156502310419455, 0.044868151962873526, 0.014545465492119547, 0.04991562447685283, 0.03603503981139511, 0.022592183122469578, 0.055054878394003026, 0.03888931380060967, 0.026362495555076748, 0.02174201399611775, 0.07179264255682938, 0.024075756737147458, 0.09752602694788948, 0.029606677235278767, 0.008791021245997399, 0.022957707551540807, 0.0503065247903578, 0.021260553112369962, 0.052726308422279544, 0.04743916302686557, 0.053033160511404276, 0.0923052332655061, 0.028339484197204, 0.0288289101808914, 0.05744323578255717, 0.027765137965616304, 0.009164164748654002, 0.017742285162967164, 0.025208732367900666, 0.027765748382080346, 0.045908153188065626, 0.03691497833642643, 0.04074154370755423, 0.0407705653924495, 0.007951712523208698, 0.0131894531477883, 0.08670800001709722, 0.010057415547635173, 0.104168233810924, 0.0499103849142557, 0.016041202907217667, 0.022452063785749488, 0.0672377334558405, 0.0619385541358497, 0.012482103848014958, 0.014726347289979458, 0.06051260272215586, 0.05014001282688696, 0.1004060720151756, 0.024539086953154765, 0.04469510538910981, 0.052757753219339065, 0.022307819963316433, 0.06795341614633799, 0.013573258529504528, 0.02407905372820096, 0.08197181392461061, 0.011369201456545852, 0.058769702300196514, 0.040307309391209856, 0.005550999303522985, 0.024277557822642848, 0.078764459467493, 0.03282745528849773, 0.04492722320719622, 0.018608419741212856, 0.03897112444974482, 0.0449608016788261, 0.0039022027431201423, 0.05870544715435244, 0.01857770224887645, 0.06586738745681942, 0.04254840241628699, 0.027050748467445374, 0.042804981421795674, 0.037341342176659964, 0.07194250443717465, 0.05436902261862997, 0.0409762145136483, 0.015212837151921121, 0.029477768039214425, 0.005078529538877774, 0.012108246028219583, 0.014487473144981777, 0.04422312544193119, 0.02138399453542661, 0.03611501364503056, 0.040569346892880276, 0.021317076934792567, 0.030038683253224008, 0.03921030009223614, 0.04476768743188586, 0.026292950751667377, 0.003576112794689834, 0.02290641587023856, 0.04425911218277179, 0.03088364621362416, 0.02978191685542697, 0.04756865295348689, 0.013741688017034903, 0.03603952609410044, 0.0516953242913587, 0.006186350074131042, 0.01393264725265908, 0.02578852781880414, 0.05204649001825601, 0.027943793320446275, 0.030558127255062573, 0.0048313280331058195, 0.015129445728234714, 0.0276236938952934, 0.045044601283734664, 0.02235846041003242, 0.016605697128397878, 0.05319179457728751, 0.05683992167178076, 0.033883241994772106, 0.02524173010897357, 0.0252530107536586, 0.02145553386071697, 0.053552367025986314, 0.02412140809610719, 0.1185642734344583, 0.059000744004151784, 0.0080009113480628, 0.008554464457120048, 0.07205468747997656, 0.05312431479978841, 0.02088291683321586, 0.007186876928244601, 0.034211976308142766, 0.0539043342723744, 0.0065613790957286255, 0.040489922248525545, 0.06564606417668983, 0.04885283560724929, 0.04471545878914185, 0.06945906308828853, 0.06784040189813823, 0.022822874161647633, 0.026610116838128306, 0.042668812166084535, 0.02931238414021209, 0.06026287373970263, 0.07964763004565611, 0.04342370622907765, 0.054222114486037754, 0.06896767969010398, 0.05720863919123076, 0.01253345397344674, 0.016941591311478987, 0.0282791531572002, 0.013365264221647521, 0.037424956244649366, 0.03311999505967833, 0.03668018878670409, 0.015074943330546375, 0.02093855193379568, 0.021745490957982838, 0.04693432078056503, 0.03739755986316595, 0.03754728073545266, 0.08588813463575207, 0.10759791344753467, 0.05535040902032051, 0.021696197509299964, 0.06616101076360792, 0.08162456302670762, 0.13709938939427957, 0.07983859206433408, 0.044769435189664364, 0.07059195151668973, 0.004336981146479957, 0.04010436539829243, 0.037668447475880384, 0.023752725828671828, 0.02671496375114657, 0.043428151693660766, 0.03063985626795329, 0.007783132750773802, 0.004842329444727511, 0.09099420713027939, 0.033364996561431326, 0.021868756120966282, 0.02433456218568608, 0.04987896238162648, 0.13831519056111574, 0.026068324914376717, 0.09569717469275929, 0.07241520055686124, 0.04094131872989237, 0.036913297371938825, 0.07050816304399632, 0.05133748294610996, 0.0908292573876679, 0.015102305387699744, 0.016578404647589196, 0.07800536113791168, 0.024008779764699284, 0.07583987069665454, 0.00930028112634318, 0.026094886379723903, 0.05125898969708942, 0.025550754835421685, 0.030981058662291616, 0.04092000424861908, 0.0297544889326673, 0.03165321068081539, 0.01906863479234744, 0.08299297944176942, 0.04552844446152449, 0.04456359311006963, 0.03757257683901116, 0.043273284027236514, 0.01947301807376789, 0.05798365658847615, 0.03701626294059679, 0.03257501004554797, 0.05287745050736703, 0.023403667801176198, 0.009942930919351056, 0.03552016001776792, 0.028860197271569632, 0.039750390642439015, 0.09762859917827882, 0.05429186894616578, 0.006995810545049608, 0.047047887928783894, 0.029886856536904816, 0.03587136656278744, 0.05556447409617249, 0.024044640340434853, 0.006471825527114561, 0.05983145587379113, 0.044430626221583225, 0.046185003957361914, 0.04333607714215759, 0.09299308541812934, 0.01489978349127341, 0.027737595009966753, 0.019207256846129894, 0.06076497746107634, 0.09627763065509498, 0.03953817351430189, 0.006223981599760009, 0.02598338425741531, 0.019101936813967768, 0.025941391686501447, 0.03009212716278853, 0.03738873572729062, 0.06830661164713092, 0.038069663642090745, 0.018589159153634682, 0.017818487031036057, 0.02490085425961297, 0.04698848642874509, 0.03584372898330912, 0.11974778375588357, 0.026603639744280372, 0.015249203315761406, 0.0485704743914539, 0.024884035337890964, 0.0031255287331077852, 0.06043719309673179, 0.016097157131298445, 0.04103347862837836, 0.025506392958050128, 0.018463487576809712, 0.034586957553983666, 0.034990938220289536, 0.016098990236059763, 0.010111907740792958, 0.019365889056643937, 0.02894286510127131, 0.07738917818642221, 0.11019692945410497, 0.11864421758218668, 0.14862164767691866, 0.17381534969899803, 0.10204055579379201, 0.12203010308439843, 0.09828509559156373, 0.1441699787392281, 0.14427046553464606, 0.18642290990101174, 0.10020480156526901, 0.12001270821201615, 0.10943162676994689, 0.09024207014590502, 0.14035674976184964, 0.12736471253447235, 0.10412500370875932, 0.1246780637302436, 0.10768754262244329, 0.16995753248920664, 0.14182440616423264, 0.16161223029484972, 0.13768454315140843, 0.1787703431909904, 0.14929381082765758, 0.05804124353744555, 0.08388222078792751, 0.20385998126585037, 0.177168654918205, 0.17750875151250511, 0.12486909254221246, 0.12303802868700586, 0.1788435337948613, 0.09570722337230109, 0.208747721335385, 0.19052421092055738, 0.12208378262585029, 0.1102122622251045, 0.16516302101081237, 0.10506608407013118, 0.14936288993339986, 0.12119503851863556, 0.13102094759233296, 0.09278422279749066, 0.11316471864120103, 0.15492132370127365, 0.1526738630491309, 0.10966944057145156, 0.13027421344304457, 0.06388752299244516, 0.12911509751575068, 0.08838196605211124, 0.13537214457755908, 0.05845436004165094, 0.12624901224626228, 0.11993684587650932, 0.3239145688712597, 0.10347534989705309, 0.0914763285254594, 0.11723123519914225, 0.11681736170430668, 0.15688440820667893, 0.1632316707400605, 0.21882638364331797, 0.21859854430658743, 0.13684928562724963, 0.1431985668023117, 0.13124461605912074, 0.22481763793621212, 0.21400824218289927, 0.1812205882743001, 0.13234749203547835, 0.235921117127873, 0.12265568162547424, 0.11068452789913863, 0.16393654776038602, 0.11711335246218368, 0.11838434715173207, 0.16182794293854386, 0.17796831903979182, 0.15000894432887435, 0.0929732403892558, 0.17488750076154247, 0.11067363317124546, 0.12129057518905029, 0.08471288441796787, 0.13368709827773273, 0.2576488262275234, 0.2513175643980503, 0.2567375579383224, 0.12467913242289796, 0.09642360368161462, 0.1836600573733449, 0.23631901218323037, 0.1343782158801332, 0.17954063310753554, 0.16280719195492566, 0.26130265672691166, 0.22840713907498866, 0.11143237526994199, 0.1994444994488731, 0.08796499780146405, 0.08540452894521877, 0.08632276600110345, 0.12644729926250875, 0.10009264820837416, 0.2854210906662047, 0.1545277627883479, 0.12813611567253247, 0.10653888355591334, 0.2238602822762914, 0.15850640163989738, 0.06487199672847055, 0.1500085584120825, 0.16720996820367873, 0.17030730668921024, 0.2632591361179948, 0.08586490541347302, 0.07717598884482868, 0.10714256874052808, 0.12481506419135258, 0.18055259599350393, 0.07345381396589801, 0.11392979868105613, 0.10412221323349513, 0.209163932595402, 0.08494648282066919, 0.16356442007236183, 0.19275423110229895, 0.14888003381201997, 0.11779124499298632, 0.12672486249357462, 0.17697315837722272, 0.23505373945226893, 0.07681514922296628, 0.13021585094975308, 0.112109874462476, 0.11719742295099422, 0.22323174256598577, 0.2059445108170621, 0.14604891854105517, 0.1299669494619593, 0.12763489881763235, 0.19324876862810925, 0.0829800141218584, 0.08475336857372895, 0.13895916694309562, 0.14171853137668222, 0.1452269751462154, 0.1470372366020456, 0.14413057069759816, 0.08791250569629483, 0.16198974597500637, 0.18457790109096095, 0.10022446105722338, 0.10363910478190519, 0.10647079150658101, 0.20331482926849276, 0.14344219904160127, 0.13834953715559095, 0.0952866037550848, 0.16335284861270338, 0.0725481785775628, 0.0882831119815819, 0.10586331394733861, 0.13550160481827334, 0.1941221725428477, 0.12072329234797508, 0.13063437771052122, 0.10663283945177682, 0.12079040476237424, 0.08216762216761708, 0.0916768865135964, 0.0741112900141161, 0.1743731924216263, 0.12967849150300026], [0.031235670976457186, 0.03819470810412895, 0.05201764273806475, 0.0685901491669938, 0.04818637957214378, 0.051518945474526845, 0.028579064310179092, 0.027459894481580704, 0.030881312159181107, 0.04377318357001059, 0.045075367015670054, 0.03199396036507096, 0.03718394378665835, 0.025577609449101146, 0.1123079982062336, 0.041015236638486385, 0.05125604337081313, 0.028262979903956875, 0.04769023529661354, 0.0458954995701788, 0.005979101160846767, 0.03086516859184485, 0.07131721533369273, 0.023387698638543952, 0.006442712001444306, 0.04650862858397886, 0.030636511037300806, 0.03862877914798446, 0.07886968858656473, 0.025498622671875637, 0.03068975271162344, 0.01755832530761836, 0.03686407071654685, 0.028445156749512535, 0.02910654577135574, 0.0037373559734987793, 0.051178522335249, 0.04065943619934842, 0.04605767739121802, 0.02860120999685023, 0.023542070921394043, 0.004992422782379435, 0.0477206744835712, 0.028816072881454602, 0.02239023360743886, 0.04218616013531573, 0.1115967238729354, 0.09346775565063581, 0.05464585112349596, 0.026704171068558935, 0.017663630496826954, 0.040543134236941114, 0.07741010675090365, 0.016928173281485215, 0.04125058279896621, 0.028774325219274033, 0.043021896344725974, 0.024566036190663, 0.02164259960409254, 0.055317969745374285, 0.03032937878742814, 0.09590768488124013, 0.03739238338312134, 0.028021459074807353, 0.03156871345709078, 0.03209237656847108, 0.030348283144121524, 0.02485654433257878, 0.058997645537601784, 0.042794550536200404, 0.021027349903306458, 0.01972744856175268, 0.028249630522623193, 0.03235822499846108, 0.03904477518517524, 0.039171689859358594, 0.12065252114553005, 0.03586940358218271, 0.04775943685672246, 0.034789422861649655, 0.022388886609405745, 0.019461678057268728, 0.06458344971179031, 0.04712791371275671, 0.020283432204450946, 0.02904263572418131, 0.006477509450633079, 0.019510173697199207, 0.03088891360675916, 0.044220839627087116, 0.026700807284214534, 0.03233079522033222, 0.033701349020702764, 0.010104657885676716, 0.021379387653723825, 0.02691892077564262, 0.060611664594034664, 0.03762720632948913, 0.022857371041027363, 0.06460128352046013, 0.07774197292746976, 0.010160492438444635, 0.025911240081768483, 0.05855730334587861, 0.022629518716712482, 0.03929491234885063, 0.03424041540711187, 0.03464297486061696, 0.05060876443167217, 0.02401049598120153, 0.06838612534920685, 0.05712510675948579, 0.02110437555529643, 0.03474341341643594, 0.03527998247591313, 0.02737638060352765, 0.0717919300950598, 0.045040333934593946, 0.04726570456114132, 0.038739630035706796, 0.014733134230482392, 0.010747159249149263, 0.05931157400482334, 0.04410515364725143, 0.04910706571536139, 0.03337602116516791, 0.029621054491144605, 0.08210204599890858, 0.04941299011989031, 0.027057568804593757, 0.04577412502840161, 0.025553094455972314, 0.027515802321431693, 0.01892920565296663, 0.022790262337366585, 0.028608388420252595, 0.0938376494741533, 0.06528270125272684, 0.036648539899033494, 0.034572151707834564, 0.013225734892330365, 0.03262835190980695, 0.023783716060279403, 0.03456038495642133, 0.053513085149461403, 0.007468741832781234, 0.03321165400848258, 0.03377355998964049, 0.053522532689385116, 0.024111593193083536, 0.021374359603214543, 0.03236463715438731, 0.054475743454531766, 0.03505329346808139, 0.0720236285997089, 0.05753136952989735, 0.058560880497680046, 0.03707996518642176, 0.03059258702705847, 0.12357509127468802, 0.03838805983832572, 0.061410022535710596, 0.05670165213814471, 0.03677934342704248, 0.09267539426218718, 0.010643421846907586, 0.011126484841952333, 0.008204420300899073, 0.0683878842392005, 0.024286825391754974, 0.02455892456055153, 0.06549834710313007, 0.04456554124772083, 0.008562914736103266, 0.005865011726200464, 0.03861984740069602, 0.034560804269858636, 0.04450005042599514, 0.0788759597344324, 0.030865580483805388, 0.012727025568892714, 0.02084254585497547, 0.023168689003796317, 0.061426639222190715, 0.016130921139847487, 0.019526593714545015, 0.01868157138233073, 0.015067479180288501, 0.032230824217549525, 0.018498008575988933, 0.027827439407701604, 0.04472776359762065, 0.01782969160558423, 0.05453297417261638, 0.014214122529665474, 0.07430474564898759, 0.018405592636554502, 0.04727214640297461, 0.06118820201663766, 0.032595960874459706, 0.03800557547947392, 0.05012446112232283, 0.03482711283140816, 0.014129250521364156, 0.026033559006464202, 0.050153286138083786, 0.0389941013418138, 0.02104511691868538, 0.014936716470401734, 0.03842244354018476, 0.035121277906000614, 0.020213017232890707, 0.01761842442647321, 0.024125387863023207, 0.059599215601338074, 0.04389586429169867, 0.033441011037211865, 0.005266235848466749, 0.04034210498502944, 0.04158005183853675, 0.10368773771915585, 0.040717130759730935, 0.04807903904293198, 0.05243865198281128, 0.03205238223017659, 0.06344121764414012, 0.07328611085540615, 0.02629504360811552, 0.05162880930583924, 0.04414419803651981, 0.03066872766794404, 0.04252514350810088, 0.03133432466711383, 0.03453866971540265, 0.0069013068514323095, 0.020123629255976994, 0.02919487433246104, 0.04604440779075958, 0.04689948807936162, 0.05746098424424417, 0.012732061040878762, 0.05983385672152508, 0.010984619602822931, 0.03652202969533391, 0.04458114490262233, 0.07230865041492507, 0.01758203507051803, 0.03346291181514971, 0.009533322918287013, 0.05340975592844188, 0.08692957562743686, 0.08311711848364212, 0.030691847423440777, 0.04195558598439675, 0.022354907378030475, 0.02679678553249687, 0.016805069535621442, 0.07155596424126998, 0.004413758642840548, 0.012094498670194298, 0.06604962924029678, 0.0274519720551325, 0.013858308175258571, 0.11536644073203206, 0.02477909565641312, 0.05453382764244452, 0.042953010197379626, 0.06749774489435367, 0.0638175978383515, 0.04342939479101915, 0.026572092901915312, 0.04987755972251762, 0.007366016070591286, 0.012202105444885092, 0.027081972475571092, 0.05624845223792363, 0.024412226084677968, 0.06367198104271665, 0.045858061930630356, 0.020918337686453015, 0.03484227119770367, 0.03654033847851679, 0.051127451442880556, 0.04336008190875873, 0.038492476305691525, 0.05151635908987373, 0.019484990771161392, 0.03407190706639085, 0.017998997755057644, 0.026674114087654743, 0.02427245370199671, 0.017017958307405934, 0.06214681932760868, 0.07962350282468833, 0.071578844654141, 0.034825984766939655, 0.023875877814134583, 0.022129331591713708, 0.028757745640177745, 0.012903649294457864, 0.032974912610370666, 0.039853018533904105, 0.026949350685754325, 0.04944015272485558, 0.05913683162361849, 0.013132027615938568, 0.04315898957429454, 0.03500374026771169, 0.0540618031664053, 0.032573295684414916, 0.011874833162437426, 0.04489777478738688, 0.07918688250356354, 0.04412509886606131, 0.034195793778053485, 0.03805942942562979, 0.02680847992451163, 0.013314747156982776, 0.05384106989367865, 0.01868957915576175, 0.08405197222600691, 0.028417378161975648, 0.08531878862413578, 0.08551773615181446, 0.06543401774251834, 0.05529770911380183, 0.008665518507768866, 0.0075608957013173494, 0.019166060228599235, 0.037584825986414216, 0.032792273777886294, 0.03641454815806355, 0.04264195384166669, 0.05400042384280823, 0.037201373124844395, 0.061961742540006526, 0.03477199352346361, 0.0855246974970214, 0.052373372673173435, 0.034997190814465284, 0.06665823486400768, 0.005667465466103749, 0.019311511896376032, 0.02614163611724507, 0.02245491363282781, 0.02043956337729469, 0.0492503447458148, 0.10719287893152796, 0.03595847243559547, 0.10021145862992853, 0.08476401839288883, 0.03661687245767098, 0.13476768013788387, 0.14611170423449948, 0.25008847878780216, 0.14506402920233086, 0.237850270641502, 0.23253098654095083, 0.08228448816225864, 0.11936649796552956, 0.1665935106575489, 0.1305616769241169, 0.1414542822749354, 0.18789779482176527, 0.2005129397730343, 0.1271471445215866, 0.13082607445539907, 0.14327995071653277, 0.09264759341022, 0.17705443839076906, 0.19063226762227714, 0.22504034161102027, 0.14764603518415242, 0.11976425943430513, 0.1428349589696154, 0.156095520069357, 0.12773433176334947, 0.14219582139048725, 0.10151825452339835, 0.09971288382075727, 0.12631966470507905, 0.09068573344848119, 0.11456096559413709, 0.1357170651317574, 0.1885746928746812, 0.10832976753590629, 0.16970668657450005, 0.20511075243121013, 0.15180877118837088, 0.1332391973119229, 0.21490824467036873, 0.08610546516138129, 0.20871094049653038, 0.039704396040178835, 0.11808061579358764, 0.11547701331437565, 0.15881853410974145, 0.09880353769403882, 0.13960344018414617, 0.2045124478172511, 0.1647211314411834, 0.2220814285101369, 0.15478246787097305, 0.10666507834685035, 0.26285588275641203, 0.13836184196406975, 0.1666006352752447, 0.10408787406049669, 0.1191853397176601, 0.1940995964105241, 0.062168616204871796, 0.11740733942133375, 0.10622058383887634, 0.2178113185800612, 0.10921001405222341, 0.10082082866574638, 0.11948513027164154, 0.13684128527529538, 0.17750683677149937, 0.16896675049792975, 0.2202573631075211, 0.12082107030437328, 0.12063541464158334, 0.060373817395884544, 0.12377984239719808, 0.14614554616855457, 0.17959273187443614, 0.15765837917570025, 0.24402459792327136, 0.16947268741205335, 0.12319097048020922, 0.09559743746649474, 0.13442888972349465, 0.14497357624350116, 0.1070349127985537, 0.19276509614428505, 0.1794951839838177, 0.09684399323305115, 0.10800374948303215, 0.15891627495875582, 0.1963466266170144, 0.18625387834617868, 0.11292542796581984, 0.15870701899984851, 0.13684486242709681, 0.10204714606516063, 0.1455470931250602, 0.22528608154971153, 0.13032332877628505, 0.20996622391976416, 0.09349358238978311, 0.14578817237634212, 0.14794682763749734, 0.11956841408391483, 0.11607110995100811, 0.14710710238432512, 0.07021923011052422, 0.12515712005551904, 0.21884311165194958, 0.15569637820590287, 0.1284101908095181, 0.1740964307100512, 0.11096810252638534, 0.1024575685732998, 0.08012715392396785, 0.08507932725478895, 0.1208849617978558, 0.06266504991799593, 0.1657098502619192, 0.15540014253929257, 0.20824637089390308, 0.11040361016057432, 0.10644068257533945, 0.1260836172150448, 0.14535037946188822, 0.14015154592925683, 0.13245137786725536, 0.11902881335117854, 0.06432645139284432, 0.23271750309504569, 0.13919331453507766, 0.13728817692026496, 0.1633401875733398, 0.23287566960789263, 0.17520821245852858, 0.08932487209676765, 0.12306229691603221, 0.15115427115233615, 0.14780614612391219, 0.1820246162242256, 0.16845713253133, 0.1388885293272324, 0.1405649073421955, 0.05277354983263649, 0.1312611807952635, 0.05346210331481416, 0.1777719912934117, 0.044807696613133885, 0.21562640613410622, 0.15861892607063055, 0.17603356973268092, 0.11469018834759481, 0.2545039012329653, 0.11194596372661181, 0.14973249431932345, 0.09643075056374073, 0.14258402399718761, 0.2009482984431088, 0.09935997775755823, 0.18575126625364646, 0.13117362221237272, 0.12617886444786564, 0.11283934625680558, 0.1510461699217558, 0.13812005025101826, 0.13280115206725895, 0.1979150518309325, 0.12489178741816431, 0.09861642742180265, 0.08211898180888966, 0.20303216006141156, 0.08541398390661925, 0.16947087657172233, 0.29160059813875705, 0.15774679864989594, 0.17284030123846605, 0.23508832353400066, 0.1453064294764772], [0.06042425746272784, 0.012727174926112639, 0.0751757004763931, 0.031001141178421676, 0.06668757938314229, 0.039621186442673206, 0.05807636938698124, 0.05084219956188463, 0.008371533403987996, 0.003359695342624036, 0.040480960815330036, 0.04276289793779142, 0.01135873810198973, 0.041302874524262734, 0.009679782051534858, 0.03348095342516899, 0.021168025850784034, 0.040020703090704046, 0.015638597069482785, 0.007868105876696063, 0.07175674487370998, 0.0025913526360454853, 0.026831380746443756, 0.04826510288694408, 0.04045943853270728, 0.0440533925575437, 0.025125489373749588, 0.05866694082214963, 0.043761075430666097, 0.06252569684875198, 0.04216294575599022, 0.01678948443441186, 0.03875001268170308, 0.009981801831600023, 0.010750499841378769, 0.060503218264784664, 0.008142110509652412, 0.03418512911594007, 0.05807946785353124, 0.05655709661368746, 0.016979880565486383, 0.015822751738596708, 0.031908620803733356, 0.05088640929898247, 0.038109116212581284, 0.06486152502475306, 0.12873302504885942, 0.0405126393889077, 0.00241114016262145, 0.041838230172288604, 0.011833895368908998, 0.07179891370469704, 0.03586528095183894, 0.05872740730410442, 0.042621841639629565, 0.012151910286775092, 0.01928693938680226, 0.031202834652503952, 0.0434831856546225, 0.09674677188741043, 0.07864049111958593, 0.046962017731857486, 0.02885988556954544, 0.04452841902093496, 0.07575650524813682, 0.03863907273625955, 0.030553743017662782, 0.034064511564793065, 0.05179136562219355, 0.026483033325348515, 0.02490315120667219, 0.015063459522934863, 0.03442467583226971, 0.11403278651414439, 0.068996757036075, 0.05285948311211541, 0.03013683784956811, 0.037835490074940026, 0.06598702166229486, 0.058924800032400526, 0.04060522602230776, 0.049545886504347436, 0.02338331254577497, 0.10356696060625836, 0.06258306486415677, 0.020940999165759422, 0.01889694634883199, 0.014964739038987318, 0.012958379902556771, 0.008324981263285736, 0.01769556140061468, 0.05780491032055579, 0.05235883028944954, 0.012898799359390978, 0.0563133938703686, 0.07787358539644629, 0.04656178491131868, 0.024806896508380305, 0.014172860046528513, 0.05150939032319002, 0.07995303865754977, 0.01678618929872755, 0.028411834318831097, 0.05267737491521984, 0.018597712405608036, 0.06824548094300553, 0.10195981754804961, 0.050099109357688576, 0.018338253867113963, 0.03335936366056558, 0.019053836367675103, 0.054585451434832066, 0.08409239700995386, 0.01943246526934672, 0.03426249801123049, 0.06612604818656109, 0.05205860928981565, 0.05467961142130662, 0.03786857872910332, 0.03221726889023557, 0.04771466308739036, 0.04738589908811264, 0.01705093378404854, 0.022450026590377092, 0.019923436775570735, 0.08228787977714092, 0.03439049622102175, 0.036711989814648405, 0.024865036357368808, 0.012923379290441517, 0.015748846817587037, 0.06970977541641332, 0.050037540786433965, 0.052751018229173496, 0.02666556269105058, 0.04026067654194776, 0.050771402384270914, 0.013993192587804515, 0.023680908198002726, 0.044518255308503285, 0.021518876164918765, 0.031067264681041706, 0.04635297053027898, 0.022674158899462782, 0.06506922247353941, 0.06655720630078577, 0.06701431731926277, 0.05748813571699429, 0.04481321077037137, 0.024394457213929854, 0.017500248541182373, 0.051828194700647146, 0.0434348495764425, 0.06179720840009395, 0.018195878401456866, 0.03608672668633517, 0.05053836801380385, 0.0540351786185056, 0.0352501555607887, 0.04886534821707755, 0.042400611127959564, 0.03821143240202218, 0.1342161456705071, 0.013964195950393332, 0.04234993728459813, 0.023247733297466766, 0.015145092056627618, 0.06198589573614299, 0.04446689497854095, 0.022610000232816674, 0.03939454567444045, 0.024201472842833027, 0.05662473224219866, 0.09598900942364708, 0.030678271687065717, 0.03834543087577913, 0.06026618000760209, 0.03105526415311033, 0.03700702320202254, 0.027760568191297352, 0.02290023934619967, 0.02435113063256722, 0.02095314997859532, 0.02424242084089201, 0.0380019500880735, 0.0533700250525726, 0.030230602642404847, 0.09452710466575809, 0.038536578431376256, 0.038098971053841524, 0.08269787926110439, 0.026814955162990373, 0.030402814300032333, 0.02785430144285783, 0.03939125424949452, 0.028225638743606396, 0.11626823179540224, 0.02378810957452515, 0.04585600247082766, 0.03415682731429115, 0.050462832223274745, 0.03175993522745557, 0.03456004356849007, 0.07344649638980627, 0.07156259162002243, 0.09898867385345511, 0.024146650393959135, 0.015175646276475163, 0.03816645825281739, 0.06194840985699557, 0.0395310229214374, 0.041314834234071895, 0.04443496036401484, 0.04532205690338742, 0.06797986628953367, 0.05220502760494128, 0.014719179071107646, 0.06257395129068755, 0.05828529509017244, 0.03108967939624563, 0.053851014672545716, 0.027293645980535075, 0.09285623338655569, 0.028581951264641248, 0.08243219781434163, 0.06461818964453414, 0.03050417682970874, 0.01706372098851716, 0.02244047514977865, 0.06010891520418227, 0.04679264849983156, 0.02694318343856139, 0.02896694222727092, 0.027562041832425166, 0.08259273177827708, 0.0072847490446292795, 0.06624206813285127, 0.0673936735256575, 0.0387121854146244, 0.03694201477628667, 0.016953397025645245, 0.04625469162419904, 0.0884290924295783, 0.06858640132122673, 0.032645443570800126, 0.030297169578261673, 0.013184128238208359, 0.05830007496115286, 0.0326533066254342, 0.07066004356602207, 0.011292964336462319, 0.0072776759134285385, 0.05537552700843662, 0.041442984584136866, 0.05246574408374727, 0.062316619005287066, 0.019097398580925073, 0.010379343439126387, 0.04190378407656681, 0.07764818030409515, 0.033973049285123125, 0.024343827899429016, 0.07118252295185812, 0.05837137308844831, 0.019140127733408008, 0.03959107751143165, 0.023251245511346497, 0.012886622571386397, 0.06714805975207128, 0.07480907952412963, 0.04209687976981513, 0.02112144309649011, 0.026139725086977705, 0.03150475888105575, 0.057572439982322976, 0.08161246601957828, 0.023464015539502725, 0.03469539275101852, 0.050750447844620794, 0.004459337642401806, 0.04591046868881676, 0.028998463094467297, 0.05536737080547027, 0.040061176114249974, 0.03997465282736812, 0.05315690992574673, 0.017018754260789137, 0.06242408198886551, 0.050662956055020913, 0.024845399129844736, 0.05205015993851703, 0.1114478861563839, 0.07120332535123453, 0.02436641701933695, 0.026698217188823037, 0.09430181089555845, 0.03358774476510007, 0.05273239774396643, 0.03410063931369223, 0.04495332825172227, 0.023904294648673385, 0.044325679118628614, 0.05248658730124589, 0.04612153548805509, 0.019693408103194088, 0.025912065721058752, 0.020960003712389152, 0.0661379522352945, 0.04815970307390671, 0.042338159400969744, 0.02762048039585352, 0.009844206724665128, 0.01906420788145624, 0.061211423817439936, 0.04739572512335144, 0.033844832141767256, 0.01716643793770345, 0.049912603935808875, 0.015401055079564685, 0.060396449189283885, 0.02261692818137817, 0.05646853613143321, 0.007566880194644909, 0.05131375648488756, 0.039573859685333446, 0.08048106188653037, 0.006279293866100488, 0.02383844017458614, 0.039815183845348656, 0.12112253811210394, 0.013304039821377955, 0.08131285358103923, 0.05865654704393819, 0.07789913011947647, 0.012296647637413116, 0.025566232325218152, 0.008473289271933027, 0.09159849345451221, 0.013736401142523391, 0.024690303253009915, 0.04572826401272323, 0.034669651358854026, 0.03375872074684594, 0.06302584501099773, 0.03936862245609518, 0.024990403653646354, 0.06221349016414024, 0.03728447140019853, 0.026742417649074923, 0.08226666177506559, 0.03785156128287781, 0.04690052337537054, 0.3224956715712324, 0.13416429923381656, 0.11271370807662606, 0.1619513620971702, 0.11055462979129516, 0.08802501528407447, 0.12352598336292431, 0.08780889445915818, 0.09268412191886455, 0.12589168298291042, 0.09342168312286958, 0.21153635607333854, 0.14527991996146739, 0.12665518966969103, 0.1300560071831569, 0.09946972655598074, 0.09764414717210457, 0.10200148914009333, 0.11378915427485481, 0.11323078462737612, 0.21681081445422024, 0.12574565800605342, 0.11466094030765817, 0.14191567548550665, 0.14367855823365971, 0.15388807601993904, 0.105556346825324, 0.10562937415670604, 0.11575107360840775, 0.23964604537468404, 0.1416137846536003, 0.0943628376990091, 0.13407222839305177, 0.08909760421374813, 0.10182916244957596, 0.2011259537539445, 0.09233725693775341, 0.10337255502236076, 0.1291170419426635, 0.13413811626378447, 0.15599684411427006, 0.10295033236616291, 0.1301259026513435, 0.14152015530271456, 0.13673888373887166, 0.15948333515552804, 0.2023883766378276, 0.11642612371360883, 0.11069691434386186, 0.18861447199014947, 0.19081241654930636, 0.1731068509980105, 0.1064696189132519, 0.20956191670848057, 0.08695321303093806, 0.10804948062286712, 0.11591315866098739, 0.09124417731072754, 0.12723305553663522, 0.11831480049295351, 0.09759834181750193, 0.14866589452140033, 0.15899706515483558, 0.13783304690150544, 0.20281013916246593, 0.0892918836325407, 0.21059127553598955, 0.08897803680156358, 0.24799229751806706, 0.1272651311592199, 0.1006217252870556, 0.13756686821579933, 0.10339085638406686, 0.2143883256940171, 0.128049373452086, 0.15852712240302935, 0.1545153689221479, 0.12400097271893173, 0.1779087245813571, 0.17606748588150367, 0.16835655667819083, 0.1544182960060425, 0.1248597860103473, 0.24648848368087783, 0.20265541621483862, 0.11372709588613361, 0.17494198924396187, 0.12270089326193556, 0.08337645456776954, 0.07726795578491874, 0.13204282557126135, 0.15802142297616228, 0.14476115873549134, 0.0819549078005366, 0.16765173902967945, 0.1657565907225944, 0.08708279943675734, 0.17101516714319587, 0.13063298247288913, 0.14521747565595433, 0.12847379286540672, 0.1947495693457313, 0.10418456848128699, 0.12267937097931281, 0.11530611154739745, 0.1435427600517869, 0.19642888626549393, 0.10785603983094916, 0.12062846813932993, 0.11450770907686092, 0.14743502775672823, 0.1711791817797348, 0.21619659819407389, 0.11977061221841723, 0.29888872581068426, 0.1608015230158344, 0.1342462471802719, 0.24455545615637675, 0.11145570839289576, 0.18985595146659762, 0.1757589157205075, 0.10878416971536353, 0.19802331633400172, 0.20937416818924248, 0.12157512945123017, 0.22929458442376927, 0.13324146828381345, 0.12014674008241855, 0.10659822568413801, 0.21440367330797017, 0.09214694058755413, 0.15132685017306358, 0.16368029901059344, 0.1465536531759426, 0.11356186412740499, 0.11144448712002486, 0.09842309053055942, 0.1348272745963186, 0.20693581231171265, 0.11968949547735974, 0.12459154415410012, 0.13095688540488482, 0.10679623810574412, 0.1356495890649967, 0.11748491611797363, 0.19524924253346398, 0.19689642445882782, 0.21648213209118694, 0.21121304685948417, 0.15241191460518166, 0.11330666922731325, 0.1550354660139419, 0.16115073318360373, 0.1970049412921071, 0.1037194645323325, 0.17497406486654654, 0.09956433554179966, 0.13474336737999693, 0.13196688902098686, 0.09997475804993883, 0.08638022307422943, 0.20433062163647264, 0.22431279940064996, 0.16876660811249167, 0.14656800631200895, 0.12298060129978694, 0.15094416914507747, 0.18495517928386107, 0.07839679950848222, 0.09352243709145114, 0.15451195504283533, 0.09254944437998347, 0.16137027530930936, 0.1679564648657106, 0.09652275461121462, 0.12429677051841281], [0.06067226466257125, 0.01674663282756228, 0.03879557683831081, 0.020834630850004032, 0.024317711722687818, 0.06305336384684779, 0.028060583244950976, 0.04922541971609462, 0.010460599332873244, 0.013729173551837448, 0.05857222051417921, 0.03116859938018024, 0.033227216845261864, 0.03259429846366402, 0.03760480831260793, 0.015503558661293937, 0.058776990190381184, 0.06885146678541787, 0.03926138211681973, 0.01743825509038288, 0.02529121280531399, 0.024961901472124737, 0.05207085101574194, 0.014998760016169399, 0.023503494085161947, 0.007370944858848816, 0.044307860152912326, 0.025039209140231833, 0.03082346731389407, 0.017954942013602704, 0.02234322968433844, 0.0649692774459254, 0.030188040473149158, 0.0474721552018309, 0.05338894981832709, 0.0033331763188471086, 0.030181934453139547, 0.00698544784427213, 0.05342391239537392, 0.021825197618454695, 0.06538687652209774, 0.013229256383056054, 0.03344926743011456, 0.05360988718166482, 0.04442302291863598, 0.06783999371691607, 0.06334429315757006, 0.01172601492726244, 0.06658516300376505, 0.04348807269707322, 0.025774623682082165, 0.03904125369444955, 0.03602292053983547, 0.04402833023050334, 0.020695331586466637, 0.039597292998223566, 0.03019829138793284, 0.08383329841308296, 0.02665692038135603, 0.0519093188631814, 0.10690096998587251, 0.03351335930346977, 0.026246653724228963, 0.02539620629249839, 0.04586184317304287, 0.056337992355111055, 0.024019926822802518, 0.030347585525305476, 0.01746806716255378, 0.07289623099495657, 0.025240106660930905, 0.07355015215580352, 0.012499721506173955, 0.033781931415433064, 0.00048283913315572136, 0.028809729374188464, 0.009866575983323855, 0.037358983026933856, 0.0527477193827508, 0.01501610029663425, 0.026781077976920642, 0.032520462191314436, 0.015688701314502396, 0.058102240654989146, 0.07534951146226376, 0.02788311347103445, 0.06169336709717754, 0.029530887259170413, 0.023058160950313322, 0.023498417795053683, 0.0361060410796199, 0.03511359296680894, 0.11891198446392082, 0.022576759438379668, 0.038709803120582364, 0.04407196851389017, 0.05185000271012541, 0.05277640710119158, 0.029965821049700025, 0.042561397422105074, 0.03712105790327769, 0.018821911507984623, 0.030905728817742784, 0.06467451865319163, 0.025009706914715935, 0.04211134051729459, 0.048217876319540665, 0.03589372005080804, 0.049044109327951446, 0.04334841163654346, 0.06674694377579726, 0.09053734102053568, 0.08325207061716355, 0.06005238952639047, 0.030546308553311974, 0.04569013988657389, 0.02401524572633207, 0.05228738002188038, 0.06269240548135713, 0.01726604899886297, 0.06348364622681402, 0.04380976773973089, 0.1049424942175392, 0.03389350218640175, 0.006094955979278893, 0.018325310811633244, 0.05613270688627381, 0.06330065487418324, 0.04973940893250983, 0.026907983374258038, 0.05545587191591039, 0.011600399011513218, 0.02810973754094448, 0.032690621810615994, 0.033603931005927734, 0.07424464653013274, 0.04382859231554903, 0.06195166788529605, 0.0789439701475203, 0.015433806056535104, 0.0455656223493861, 0.04320408988860436, 0.028793433666578494, 0.03212343915947713, 0.02983853901241673, 0.015739113550807815, 0.011060558008466614, 0.040146118626580574, 0.06080477141949814, 0.00939663230383303, 0.046889925506548025, 0.04444334663276095, 0.008845925331115723, 0.05109965801239014, 0.04546817464870401, 0.02830603003530996, 0.06390366470441222, 0.05921620060689747, 0.028709513462672476, 0.07255657968926243, 0.01578629558935063, 0.04659018690290395, 0.027908519041375257, 0.025498023387626745, 0.0684512710722629, 0.017049998677975964, 0.06872061130707152, 0.059550653168116696, 0.06630400035646744, 0.04467574646696448, 0.02193356973293703, 0.0740925878926646, 0.0359703282447299, 0.018666843461687677, 0.028290122099861037, 0.016489474946865812, 0.026510520619922318, 0.050119132502004504, 0.02245540530566359, 0.06242659786948934, 0.02188480877521215, 0.042908392279059626, 0.006751641176379053, 0.01967836476978846, 0.03609153580327984, 0.024917502487369347, 0.04188817671092693, 0.03666252196126152, 0.004740155654872069, 0.0641463024658151, 0.09870979702100158, 0.00799804758571554, 0.0294755378854461, 0.028020705794915557, 0.05652800071402453, 0.059997288772137836, 0.07347207079874352, 0.02021300981141394, 0.0796183745842427, 0.0450171269767452, 0.048279994080075994, 0.06864010312710889, 0.04831089710933156, 0.04902512890112121, 0.028532808100862894, 0.03590180946048349, 0.042570603764033876, 0.024513634998584166, 0.01705288563243812, 0.03185048837622162, 0.10957689475617371, 0.03559752520231996, 0.026422670744068455, 0.011839615472126752, 0.02454386638419237, 0.024639490256959107, 0.02986769799463218, 0.01675194474955788, 0.05469350813655183, 0.07918362447526306, 0.021104624174768105, 0.054081974740256555, 0.101402494328795, 0.03932055726181716, 0.029044617258477956, 0.06521783012431115, 0.028979833332414273, 0.07568027926026843, 0.05413503087766003, 0.04097216980881058, 0.02051608436886454, 0.05698767585272435, 0.01690354140009731, 0.040826783078955486, 0.06734130016411655, 0.015544470479653683, 0.049559519757167436, 0.032260662264889106, 0.04791800041857641, 0.021350054266804364, 0.03733333069249056, 0.044926058035343885, 0.05158740117622074, 0.05641476011078339, 0.014675586244266015, 0.047323065155069344, 0.033746735061868094, 0.013479803583322791, 0.011888753997482127, 0.008022834390430944, 0.04154966831265483, 0.027154469171364326, 0.15642399463104084, 0.0613582985533867, 0.04184763318335172, 0.0607943553768564, 0.04315126752771903, 0.010514072928344831, 0.12944707501446828, 0.042069553892361, 0.05919922397879418, 0.005659337093675276, 0.03879551004501991, 0.04423865117132664, 0.042849450910580344, 0.07599737669806927, 0.03191402734955773, 0.05230295399087481, 0.0296029293895117, 0.03488416172331199, 0.045454263090505265, 0.056355228734901175, 0.03852687113976572, 0.04139142016356345, 0.020269132874091156, 0.034504972500144504, 0.0326754152047215, 0.015345360607170733, 0.016305463141179644, 0.057021131869987585, 0.04145153041463345, 0.04572667952743359, 0.045847341607441194, 0.048736659809947014, 0.03733861849468667, 0.02644591480930103, 0.05206055742746685, 0.08253756051999517, 0.026926008285954595, 0.09623635982279666, 0.016239786782534793, 0.14041019923752174, 0.021434506961668376, 0.023636418300156947, 0.007612124763909378, 0.024651282983541023, 0.04049392984597944, 0.020033176297147293, 0.030720698414370418, 0.022243169623834547, 0.05051497180829756, 0.06701134872855619, 0.07644882512977347, 0.02886081325414125, 0.025301688219769858, 0.01773538318957435, 0.04813577252207324, 0.007471903845726047, 0.04312364850193262, 0.056004771759035066, 0.01693111589702312, 0.06383557265507989, 0.0760151437134482, 0.10997958408552222, 0.03036261216038838, 0.026205065623798873, 0.017457586181990337, 0.037432552126119845, 0.0711472264083568, 0.07884786944487132, 0.02263589562062407, 0.042866698422585614, 0.03850248045637272, 0.0555325802997686, 0.04312632394430693, 0.022387417157005984, 0.02410027173027629, 0.026123748502868693, 0.04786950477864593, 0.041249606874771416, 0.025585145958757494, 0.02820016637997469, 0.049213604725082405, 0.012887446355307475, 0.03060257076867856, 0.014009813912707614, 0.09741518719238229, 0.10261695220833644, 0.036429732499527745, 0.04210328079352621, 0.0720072716649156, 0.053967539279256016, 0.05076942084997427, 0.00910055156055023, 0.059162116594961844, 0.03311162734462414, 0.008665456352900947, 0.0652830426406581, 0.07387331294012256, 0.041025173995876685, 0.04224014395731501, 0.07069332888931967, 0.19931202608859167, 0.14026849356014282, 0.1368507550796494, 0.1279895711923018, 0.09022307858685963, 0.18628438061568886, 0.1068105170270428, 0.12458048615371808, 0.1483861345332116, 0.09429078258108348, 0.12929931341204792, 0.11527154973009601, 0.09110905448324047, 0.09846287706750445, 0.1799747152836062, 0.08562483548303135, 0.12323292408837005, 0.11477748717879876, 0.20755035511683673, 0.12858458067057654, 0.20227757398970425, 0.12024882991681807, 0.1730406514252536, 0.13263143773656338, 0.12328780590905808, 0.14837236027233303, 0.10051009885501117, 0.09767360301339068, 0.08433365437667817, 0.1496563499676995, 0.06996209078351967, 0.15717512229457498, 0.08417684599407949, 0.10220255921012722, 0.16747020970797166, 0.07243088955874555, 0.20920227194437757, 0.13312702911207452, 0.18874547589803115, 0.12477483978727832, 0.1876008466933854, 0.1600860629696399, 0.20974659273633733, 0.2289909272803925, 0.13007576315430924, 0.17036449658917263, 0.21060369908809662, 0.10786161336000077, 0.1569136488251388, 0.17375051567796618, 0.13645202881889418, 0.19736279005883262, 0.08157377786119469, 0.21912413329118863, 0.12933383812196553, 0.20519270037766546, 0.14466506545431912, 0.13457834342261776, 0.19193907093722373, 0.10660566942533478, 0.17055626754881814, 0.10888658609474078, 0.14641052257502452, 0.119130650855368, 0.12855388544267043, 0.14913326944224536, 0.13619895646115765, 0.11201996327145025, 0.07913817535154521, 0.15819526364794, 0.21088561130454764, 0.21443880657898262, 0.17235748964594677, 0.13678439223440364, 0.10653213001205586, 0.07364468692685477, 0.21142590965609998, 0.16143228916916996, 0.15403478377265856, 0.1242973271291703, 0.12264175893506035, 0.0870608318655286, 0.17469880229327828, 0.17098801938118413, 0.22012886765878648, 0.11306551576126367, 0.14371287514222786, 0.18365728174103424, 0.148051232972648, 0.1684944031876512, 0.13728838472161442, 0.1307156280381605, 0.24005121347727254, 0.08820201750495471, 0.14373297250131145, 0.1315452897688374, 0.2724939171457663, 0.1849914703052491, 0.09874727547867224, 0.09530946932500228, 0.14085516129853204, 0.17693714937195182, 0.2018678342574276, 0.13593047711765394, 0.2415943908272311, 0.14176049240631983, 0.0785635007196106, 0.15009259921498597, 0.1850436136010103, 0.09004635838209651, 0.14442184881772846, 0.1401509967399761, 0.1702513635973446, 0.2630509785376489, 0.19188756588846445, 0.23844654177082703, 0.09726122865686193, 0.14810491993557662, 0.22636448149569333, 0.07583201135275885, 0.21229730977211148, 0.1374629230122082, 0.22832574031781405, 0.2765602630097419, 0.10294239138602279, 0.14075222541578114, 0.11938124443986453, 0.1656884021940641, 0.10003898350987583, 0.17302102904068306, 0.13612080831080675, 0.2319435914978385, 0.103404326364398, 0.18246251303935423, 0.11388882470782846, 0.23517251276643947, 0.18908379133790731, 0.24362624273635447, 0.12031748599838465, 0.16396773280575871, 0.1369310703012161, 0.12371997334412299, 0.18679790227906778, 0.24142286565620452, 0.13420486502582207, 0.18087304051732644, 0.1149197643098887, 0.1500284776557237, 0.25004751223605126, 0.08381021019886248, 0.08880880486685783, 0.12394193487125449, 0.10325041235773824, 0.12699047714704648, 0.1690075537771918, 0.1021239509282168, 0.148848952667322, 0.19557762803742662, 0.13134957058355212, 0.20674859813880175, 0.10884122602874413, 0.17109321139287204, 0.06363620210322551, 0.12359027561615221, 0.17319457285339013, 0.16296780755510554, 0.1756054098950699, 0.22664102056296542, 0.14540906850015745, 0.14228560641640797, 0.0834248871251475, 0.2135747388820164, 0.1482966760522686, 0.12908382341265678, 0.14522422919981182, 0.12970783602213487], [0.014592372008337406, 0.04893859077128582, 0.03028807641385356, 0.013592261220765067, 0.04662642226321623, 0.03760001032787841, 0.007368969354502042, 0.029983100102981552, 0.07008379558101296, 0.03454963123658672, 0.05202937238209415, 0.02060334609268466, 0.0308961866539903, 0.014901477443345357, 0.014478629527729936, 0.07706063683144748, 0.012395677040331066, 0.08505605350364931, 0.03549261520674918, 0.011693068208842305, 0.009969935817935038, 0.030554503719031345, 0.057363362138858065, 0.02238632248918293, 0.017203133429575246, 0.06260200447286479, 0.015196463518805103, 0.029899343171564396, 0.04450911575986538, 0.02042038999206852, 0.022283666767179966, 0.06638671271502972, 0.010555198114161612, 0.05240880651399493, 0.031216263814712875, 0.04328226401412394, 0.08904952788725495, 0.06812179461121559, 0.02263975293317344, 0.020432453602552414, 0.02769978815194918, 0.029011276274104603, 0.030979791445133742, 0.03202580221113749, 0.05909345309191849, 0.04048834147397429, 0.03687763346533757, 0.029068562653264962, 0.038609884068137035, 0.0382363277458353, 0.05891609835089184, 0.050668685435084626, 0.007120997870515566, 0.06950287206564099, 0.034286981463083066, 0.03315579997433815, 0.004956553393640206, 0.02599935713078594, 0.03510905473376624, 0.056458992112311535, 0.062062763681751676, 0.056131760647986084, 0.018588802922749892, 0.029570861188403796, 0.030663536344945896, 0.029886730371799786, 0.05887328756216448, 0.046611594152636826, 0.04135976756515447, 0.033288358681602404, 0.04575927465339191, 0.06969851703615859, 0.07371708343271166, 0.037634857872035354, 0.09634670976083726, 0.062020476107136346, 0.05999751141644083, 0.021837519125256222, 0.0370779650984332, 0.003965454598073848, 0.026889099426625762, 0.055396418465534225, 0.07554369440185837, 0.011644671831163578, 0.05002082762075588, 0.058538434241199866, 0.039296489412663504, 0.0754051428521052, 0.01429130403266754, 0.02991805271449266, 0.042397319703013636, 0.018332795370952226, 0.04418581025674939, 0.030406385885726195, 0.022453024866990745, 0.05483455701323692, 0.06766687292838469, 0.05729732583859004, 0.04694746050518006, 0.04486394398554694, 0.06615549660637043, 0.006385154738381971, 0.05773009070253465, 0.05812799689010717, 0.019380514931981452, 0.01197784325995599, 0.022552576556336135, 0.00375409418666095, 0.02813057890307391, 0.06146806219476275, 0.07880999022745527, 0.036878594546578825, 0.05271989626635332, 0.012417655743774958, 0.03893332315783482, 0.03030413277883781, 0.012897883734694915, 0.024635792506160215, 0.038027914124540985, 0.025258315254177433, 0.04763670789543539, 0.043667984136845917, 0.05518695470527746, 0.052533884372678585, 0.025486065533186775, 0.022287132596829906, 0.029433220624923706, 0.05218599151703529, 0.06789644889067858, 0.043891689711017534, 0.09685758195701055, 0.03696554456837475, 0.06475100439274684, 0.045893703572801314, 0.040298002859344706, 0.04129558292333968, 0.010618269534461433, 0.0773056123580318, 0.0190089976604213, 0.053685281964135356, 0.04183625977020711, 0.04026896262075752, 0.056095866675605066, 0.04419206285092514, 0.02711000710405642, 0.0505637420428684, 0.0402783730532974, 0.04735538568638731, 0.0620723188330885, 0.02262308800709434, 0.0463257003139006, 0.028070075313735288, 0.04390596121083945, 0.01607948845048668, 0.03546269923390355, 0.05909331208385993, 0.025411321985302493, 0.051889039677917026, 0.07137223074096255, 0.056183139531640336, 0.058078150541405194, 0.05362061121559236, 0.0447705558326561, 0.061478392890421674, 0.019317916630825493, 0.06958208890864626, 0.027088069218734745, 0.03922077921743039, 0.03547381660609972, 0.01626196586585138, 0.04470270869205706, 0.034153676897403784, 0.027114857039123308, 0.04079037702467758, 0.045882779159001075, 0.013675915179192089, 0.029003084819123615, 0.03312786553578917, 0.025949694463633932, 0.04367598819953855, 0.041779774910537526, 0.02159827112336643, 0.06211654341313988, 0.04082329498487525, 0.056894050212576985, 0.015667357147322036, 0.049575835873838514, 0.1144971112080384, 0.02229190089565236, 0.02499325721146306, 0.03447266310104169, 0.03968448792875279, 0.0306342771727941, 0.027691518771462142, 0.011686032648867695, 0.06019937929522712, 0.0643806355947163, 0.028592550988832954, 0.012731308688671561, 0.06999369885306805, 0.03224651693017222, 0.0819041374779772, 0.031005796299723443, 0.03311006883450318, 0.039639421011088416, 0.011720987804437755, 0.018162587512051687, 0.0441402609430952, 0.029329488788789604, 0.0382163417089032, 0.028127339428465348, 0.04240589893015567, 0.00846410612211912, 0.04823063012736384, 0.0355891055369284, 0.021279127213347238, 0.02785103970381897, 0.0322676792711718, 0.050452412469894625, 0.02671706588444067, 0.06599531887331977, 0.010539710419834591, 0.009240382387361024, 0.011216447055630852, 0.014988144521339564, 0.05235075943346601, 0.05743061185057741, 0.011028109456674429, 0.05290767818223685, 0.011441506121627754, 0.0115534832184494, 0.04112772767257411, 0.031034083258418832, 0.0800623421673663, 0.05095559230539948, 0.0971199460036587, 0.03612999389588367, 0.0688675491255708, 0.04596447106450796, 0.01869302457635058, 0.02269842712848913, 0.010131194303539814, 0.037878178409300745, 0.11096084432210773, 0.07396376589895226, 0.038868993797223084, 0.03214138800103683, 0.011733121918950928, 0.05920368057559244, 0.09143402610789053, 0.059635376746882685, 0.031080727239896078, 0.02942193255876191, 0.03927674457372632, 0.031776614996488206, 0.005649353815897484, 0.07102089060936123, 0.02431828874250641, 0.023975557523954194, 0.04767083555634599, 0.028174146682431456, 0.035389490076340735, 0.019906775560230017, 0.06007227537338622, 0.008607840645709075, 0.027883992916031275, 0.028175220941193402, 0.05341161500837188, 0.01645287593419198, 0.018823521968442947, 0.030786339521000627, 0.04930741219141055, 0.07190204996732064, 0.025391382332600188, 0.009949886698450428, 0.01204510410389048, 0.07480838190531358, 0.04520952505117748, 0.09514460121863522, 0.029177769683883525, 0.03708917894982733, 0.02093985069222981, 0.02258146836538799, 0.044717154596582986, 0.016079497727332637, 0.03722705885593314, 0.027078614257334266, 0.02401238845777698, 0.035189844929846004, 0.029521868309529964, 0.03370972415723372, 0.039903017022879794, 0.041767013681237586, 0.0756778969662264, 0.0035270192620373564, 0.05320517921063583, 0.06816692461143248, 0.01727160397422267, 0.01928947382111801, 0.027227915816183668, 0.025774861169338692, 0.07418461420456879, 0.06020196196914185, 0.019073566363658756, 0.05478845851030201, 0.03951632468670141, 0.10120365070179105, 0.07156858817324974, 0.02011772732657846, 0.07244985143188387, 0.012333209542703116, 0.05717214407923166, 0.05556024014367722, 0.025741883837326895, 0.02546327974414453, 0.018575596404843964, 0.035672482117661275, 0.06745276332367212, 0.04944201180478558, 0.06032669472915586, 0.02378809844231, 0.02280173222970916, 0.015922232923912816, 0.04640175560780335, 0.01588730745424982, 0.03191791249264497, 0.01948725988768274, 0.07077702830429189, 0.08202999088098295, 0.05281769648718182, 0.034886139546870254, 0.016375514460378326, 0.018718253886618186, 0.04956819175276905, 0.052176080134813674, 0.02619203722133534, 0.005593921414401848, 0.05408034201536793, 0.024552402937843, 0.0691168216872029, 0.029822636643075384, 0.04189301180304028, 0.10468946638866328, 0.029704744629270863, 0.044387039888533764, 0.054806151310913265, 0.02732672350248322, 0.0305487149671535, 0.03498910511552822, 0.06839337613200769, 0.04128515203774441, 0.058512451651040465, 0.12402294029016048, 0.22108562960056588, 0.1230293678236194, 0.15190983685897663, 0.0868462843936868, 0.12867427663877606, 0.13484734226949513, 0.1832061301684007, 0.24235736316768453, 0.12179751400253735, 0.16875764296855778, 0.24278684402815998, 0.1655321058933623, 0.12167917855549604, 0.09394428867381066, 0.18104232440236956, 0.11515254635014571, 0.10956355836242437, 0.08812867847154848, 0.0713381587411277, 0.09218686813255772, 0.10173094662604854, 0.13871467381250113, 0.17186028038850054, 0.12065513350535184, 0.14851700485451147, 0.11048698303056881, 0.12252956847078167, 0.11820014609838836, 0.11242016640608199, 0.1157258554303553, 0.18413893558317795, 0.08372863332624547, 0.07641531716217287, 0.0819114402111154, 0.09432012710021809, 0.20587927603628486, 0.1267932736664079, 0.09194630096317269, 0.08358083461644128, 0.16543081757845357, 0.22747909824829549, 0.14469887770246714, 0.15223572874674574, 0.14755662123207003, 0.16110777767607942, 0.2135783902485855, 0.12055564118782058, 0.08529874321538955, 0.18498835328500718, 0.13802235393086448, 0.15162112656980753, 0.17462653195252642, 0.14482010010397062, 0.08059299259912223, 0.12855110981035978, 0.09869447909295559, 0.17450432991608977, 0.14524904661811888, 0.16761069826316088, 0.1936198869952932, 0.13048715045442805, 0.08282677546958439, 0.12991200084798038, 0.09008325796457939, 0.1746426514000632, 0.1269761982257478, 0.17424229241441935, 0.19133059890009463, 0.22325148369418457, 0.16682354675140232, 0.14681647735415027, 0.18874589150073007, 0.1436535330140032, 0.2522867498919368, 0.12614433973794803, 0.08379652499570511, 0.10583486000541598, 0.11935273854760453, 0.10051753517473117, 0.17487172270193696, 0.24840800411766395, 0.16263853147393093, 0.1828431457397528, 0.07734417435131036, 0.24897319410229102, 0.15775531850522384, 0.17335741489659995, 0.16571909742197022, 0.11182345740962774, 0.10166264677536674, 0.14979769941419363, 0.1733490583137609, 0.13002954219700769, 0.1979219538043253, 0.10856886525289156, 0.1522502303123474, 0.12274757435079664, 0.11636295210337266, 0.11596067095524631, 0.14164876949507743, 0.13686047721421346, 0.2763921517180279, 0.1638373374589719, 0.09150312005658634, 0.053585014102282, 0.07783143882988952, 0.07886938430601731, 0.0927762224455364, 0.1303298003040254, 0.14202389545971528, 0.13411742518655956, 0.1330700915423222, 0.10972264513839036, 0.10251147818053141, 0.12079925858415663, 0.14464939129538834, 0.15046811109641567, 0.12870884587755427, 0.11471512450953014, 0.16769292822573334, 0.13196234707720578, 0.13480947789503261, 0.1992799949948676, 0.10784922691527754, 0.17779053014237434, 0.10346671129809693, 0.12313910177908838, 0.1343501775409095, 0.14870537677779794, 0.2518235903698951, 0.18867295322706923, 0.18338019348448142, 0.1282178409746848, 0.17867031652713194, 0.22213278512936085, 0.19018110120669007, 0.10937332364846952, 0.10406572837382555, 0.09099319780943915, 0.0950634251057636, 0.21858800580957904, 0.23488631093641743, 0.14227402891265228, 0.19823343318421394, 0.12187302752863616, 0.20915848523145542, 0.18277804454555735, 0.1303786929929629, 0.08174794507795013, 0.10577318753348663, 0.15289729402866215, 0.18633800820680335, 0.15888531255768612, 0.20611388375982642, 0.12126871893997304, 0.1741858446621336, 0.20450314128538594, 0.19444980105618015, 0.14308482524938881, 0.1513082519522868, 0.2202890528133139, 0.13512595935026184, 0.29008643876295537, 0.21624808839987963, 0.19356714998139068, 0.18088093696860597, 0.09739866698510014, 0.1414382370421663, 0.13792051642667502, 0.14146575587801635, 0.1331636169925332, 0.07087174119078554, 0.1541099336463958, 0.09296029733377509, 0.260633091093041]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04475029891182203, 0.026312435838917736, 0.02031924082984915, 0.03415457118535414, 0.030503002381010447, 0.11006629662006162, 0.06622427885304205, 0.017233702492376324, 0.012509513217082713, 0.032660338474670425, 0.05248922934697475, 0.03635736196883954, 0.038172874119482, 0.052508016815409064, 0.060214203695068136, 0.04475891895708628, 0.016083640766737517, 0.023213473905343562, 0.052576517045963556, 0.05009046333725564, 0.040563528455095366, 0.024635148693050724, 0.035173595606465824, 0.07116765031241812, 0.03836816285911482, 0.022352677224262152, 0.055266709605348296, 0.051090626075165346, 0.023391593058477156, 0.011438650708441855, 0.02436972143186722, 0.02854698683222523, 0.023380911698041018, 0.047337240175693296, 0.015495671486860374, 0.016731515279388987, 0.03478293649095576, 0.026570604895823635, 0.04096940901945345, 0.05174934151000343, 0.09001687285490334, 0.0001957802965080191, 0.04990679291950073, 0.014124715071375249, 0.04700325516751036, 0.08732183036045171, 0.033186480359290726, 0.02833226310031023, 0.057592006705817766, 0.03200679209840018, 0.030770761841267813, 0.028205441194586456, 0.08980453698313795, 0.028388762802933343, 0.022191013340489008, 0.07948496611788869, 0.03594853507820517, 0.023587301111547276, 0.07172014215029776, 0.045112723018974066, 0.02549948727391893, 0.008764587801124435, 0.019745684985537082, 0.02641929026140133, 0.024617537528683897, 0.03440672699071001, 0.06287326687015593, 0.03398370281502139, 0.0648182949225884, 0.025442184196435846, 0.05988535805954598, 0.06553399987751618, 0.08235751549364068, 0.021889667987124994, 0.06762491189874709, 0.029894456129113678, 0.05959738620731514, 0.0365132909064414, 0.07050170635920949, 0.026481677050469443, 0.08337838415172882, 0.009426910073671024, 0.017547161551192403, 0.050900023998110555, 0.04852098056289833, 0.011765010149247246, 0.0503561225195881, 0.026772636047098786, 0.05387309727666434, 0.021962815917504486, 0.028182191563246306, 0.041311171735287644, 0.04082968858710956, 0.020720325264846906, 0.029781940975226462, 0.030498430751322303, 0.048727939574746415, 0.02069452264549909, 0.01643122377572581, 0.04271995727322064, 0.02767517482425319, 0.05039914482040331, 0.051824888432747684, 0.03755469850148074, 0.053752182866446674, 0.11360740230884403, 0.07457230472937226, 0.032301996179739945, 0.06907247836352326, 0.017799241286411416, 0.03429020238399971, 0.0196833130394225, 0.03323680168250576, 0.07891867033322342, 0.06334538411465473, 0.025755359383765608, 0.06795985056669451, 0.04500040267885197, 0.014046439828234725, 0.03363219941093121, 0.06699438323266804, 0.024281055193569046, 0.04825296506169252, 0.028302373102633283, 0.022589505824726075, 0.017004772198561113, 0.02059706937870942, 0.04620257059286814, 0.05562348596868105, 0.05743064895796124, 0.04921005354844965, 0.05448125761176925, 0.01616161080164602, 0.0327592741814442, 0.07042166573228315, 0.07432565194903873, 0.054412913232226856, 0.022840754354547244, 0.06816049019107595, 0.08117821314954199, 0.1109820549027063, 0.02960318171972176, 0.052997941893409006, 0.0688651148811914, 0.015566664405923802, 0.03789725902606733, 0.09158117172773927, 0.030720110262336675, 0.05376817243814003, 0.023218897149490658, 0.06499366441858001, 0.021444728190544993, 0.027796040994871873, 0.011606957741605584, 0.10348480485845357, 0.024462231995130423, 0.0132884046252002, 0.019730749263544567, 0.02163916902645724, 0.0682365232205484, 0.01987690968235256, 0.01667503413045779, 0.03167327835399192, 0.038517675930052064, 0.03625271172495559, 0.0500994581670966, 0.0494151386374142, 0.04945864333421923, 0.02712125064135762, 0.012807774019165663, 0.043928492814302444, 0.026294151175534353, 0.034681859688134864, 0.036657033779192716, 0.05496491154190153, 0.018017375186900608, 0.0520908890030114, 0.09376758331200108, 0.05011198190914001, 0.030525322472385596, 0.06178341187478509, 0.029932539437140804, 0.019908703288820107, 0.05019528056436684, 0.04119119985261932, 0.05448219642858021, 0.040864617767510936, 0.03311331573058851, 0.005026241988161928, 0.05361295225156937, 0.023704753402853385, 0.042039801192004234, 0.08000648813322186, 0.0742289204208646, 0.012828652488678927, 0.020551597990561277, 0.020793849835172296, 0.03406989955692552, 0.05267125219688751, 0.07733356163953431, 0.03736220023711212, 0.03433398909692187, 0.03367424207681324, 0.06005761424603406, 0.029936441278550774, 0.018196574164903723, 0.025657572150521446, 0.0284284992449102, 0.03739817584573757, 0.034306696616113186, 0.005779645262009581, 0.03276308510976378, 0.018490926631784532, 0.024495880970789585, 0.014922947775630746, 0.07807688933098689, 0.021985764979035594, 0.029102406442689244, 0.05228127585723996, 0.026837316072487738, 0.01597892744030105, 0.04685829146183096, 0.02000470194616355, 0.08115993405226618, 0.09322923680883832, 0.04318538776715286, 0.0710953502857592, 0.044662814543698914, 0.07290513676707633, 0.044151983165647835, 0.05747501454607118, 0.03601756594434846, 0.029722661929554306, 0.0433897455513943, 0.073741574306041, 0.010380552212154726, 0.04087918241566513, 0.08991372174932621, 0.03233745970646851, 0.05404621806519572, 0.051842354878317565, 0.04927807138301432, 0.05791562391095795, 0.01972325913811801, 0.06064722088922281, 0.1038891269126907, 0.0755044718971476, 0.031199520963127725, 0.04771819199959282, 0.04506554840190802, 0.036017625316162594, 0.03609836727264337, 0.053048756744829006, 0.053343945983215235, 0.032584758155280724, 0.015547317543678218, 0.048733368385001086, 0.021345063323678914, 0.02814207848132355, 0.06115702068200335, 0.02949056823126739, 0.04500625451328233, 0.059856800216948614, 0.09947118858690374, 0.028867132641607895, 0.009081883763428777, 0.012012063689326169, 0.049127511883853, 0.04598505824105814, 0.008875946132320678, 0.040078609163174406, 0.02433262146951165, 0.03735385849722661, 0.09479994041612372, 0.01870822747150669, 0.07916760892840102, 0.018555769929662347, 0.03250929657951929, 0.06380321501637809, 0.0711718137608841, 0.05452579389384482, 0.11832803298602812, 0.04410149485920556, 0.02874395839171484, 0.013867101697542239, 0.041776951038627885, 0.020443617358978372, 0.06511823390610516, 0.012742126418743283, 0.008251388971984852, 0.1034887605055701, 0.04722755074908491, 0.026192078039457556, 0.014873232230456779, 0.12140612758230418, 0.05374223808757961, 0.08300880203023553, 0.07612092202180065, 0.04270860612450633, 0.0703267969947774, 0.012458571272873087, 0.047333188049378805, 0.042593450780259445, 0.02716741964832181, 0.014849413928459398, 0.05446755014418159, 0.02882191358366981, 0.044257045301492326, 0.024078200258372817, 0.05735181432100944, 0.0613238183723297, 0.10821731731994078, 0.022655356588074937, 0.04758751092595048, 0.0580289275967516, 0.07650612635188736, 0.0641835063288454, 0.02075970176520059, 0.012395419144013431, 0.05659364367602393, 0.04113632545340806, 0.06476169874076732, 0.023112571507226676, 0.03575799237296451, 0.027342716784914955, 0.029723036714131013, 0.018121871435141657, 0.041748686344362795, 0.07221525855129585, 0.02540337914979318, 0.023068690170475747, 0.04747613311337773, 0.055653947420069017, 0.10797614901093766, 0.052382415742613375, 0.06238347908947617, 0.019748957856791094, 0.018036964174825698, 0.06921573512954637, 0.029862536357541103, 0.03649298945674673, 0.07891208748333156, 0.05829351066495292, 0.1562125122291036, 0.029131376177247148, 0.029027824311924633, 0.02657446777448058, 0.03847749234410003, 0.05023409117711708, 0.025909991418302525, 0.03926898541976698, 0.03689495148137212, 0.11919968543224968, 0.18923965719295666, 0.10146514643565752, 0.15165290533332154, 0.23605457012308761, 0.21259068074868992, 0.0947186752455309, 0.09610230568796396, 0.11654316782369278, 0.09052453155163676, 0.13325792911928147, 0.15065257932292297, 0.08053755416767672, 0.2147717191837728, 0.11460360197816044, 0.2649974240921438, 0.1292676237062551, 0.20195010874886066, 0.1217994732724037, 0.1717051863670349, 0.1257276238175109, 0.12119709426769987, 0.11742841641535051, 0.19072515482548624, 0.14093718345975503, 0.12502696219598874, 0.1003908431448508, 0.20131818484514952, 0.12353878541034646, 0.07799028811859898, 0.09514627105090767, 0.10478992349817418, 0.10143121544388123, 0.15824660542421043, 0.07667183308512904, 0.0909404236881528, 0.12973670556675643, 0.17053588817361742, 0.20864950551185757, 0.24729797383770347, 0.11994118744041771, 0.09174233651719987, 0.16793210757896304, 0.1824258509441279, 0.13299225509399548, 0.20796304859686643, 0.1207138151221443, 0.13183748815208673, 0.2045987595920451, 0.08474969494272955, 0.1565844172728248, 0.17331839277176186, 0.2434468359570019, 0.08305359064252116, 0.17649085144512355, 0.1885542689706199, 0.10929236275842413, 0.08733368988032453, 0.19265883543994278, 0.10981001076288521, 0.10876345637370832, 0.18690376222366467, 0.14510193810565397, 0.16752063122112304, 0.15693119319621474, 0.17391266010235995, 0.16029975697165355, 0.08634022131445818, 0.2113431750331074, 0.12690159754129127, 0.21344127104384825, 0.15574942692182958, 0.17348264489555731, 0.09348256891826168, 0.18038777983747423, 0.14341845031594858, 0.16352499718777835, 0.14557713526301086, 0.16942046990152448, 0.066045109560946, 0.24816615303279832, 0.17150504398159683, 0.08893889593309723, 0.12792280758731067, 0.1514238934032619, 0.14198898483300582, 0.1642848228220828, 0.14177045202814043, 0.07520721948822029, 0.10243214259389788, 0.11388409722712822, 0.23058966180542484, 0.12679043866228312, 0.10242046118946746, 0.08980699349194765, 0.1051982086210046, 0.17264202906517312, 0.13352882786421105, 0.09057366172783077, 0.10714293239288963, 0.08139542493154295, 0.08912743112887256, 0.10396334910183214, 0.10974361081025563, 0.18787321489071473, 0.1831106306053698, 0.1725828056805767, 0.1346552892937325, 0.14634301682235673, 0.1275640237145126, 0.12593147694133222, 0.2606850117444992, 0.10947373622911982, 0.2143182817962952, 0.1890829304466024, 0.07550378169980831, 0.22754982492187992, 0.16432083182735369, 0.21989328030031174, 0.1378344718250446, 0.21212891646428034, 0.2332137624034658, 0.1345983665669337, 0.1393567948252894, 0.08277446147985756, 0.14540086034685373, 0.1613011516747065, 0.15705388505011797, 0.11807064875029027, 0.13786086259642616, 0.1280940358992666, 0.14469328190898523, 0.17606356734177098, 0.15342185884946957, 0.186041520209983, 0.3259271546266973, 0.14491711364826187, 0.0924419220245909, 0.16959208413027227, 0.1927104889182374, 0.16124321962706745, 0.12400577441439964, 0.09245928828022443, 0.1418438059045002, 0.09448433469515294, 0.11655789203359745, 0.2419290252146311, 0.1948867182363756, 0.15438483998877928, 0.14475612697424367, 0.11617399388342164, 0.12521661061327904, 0.32772992039099336, 0.08302322938106954, 0.15319167432608083, 0.2027171035297215, 0.14922636444680393, 0.2006317873019725, 0.16274681081995368, 0.15193331841146573, 0.11580661594052799, 0.11496582941617817, 0.12076253711711615, 0.17366203683195636, 0.12932436831761152, 0.1560314281960018, 0.13626560132252052, 0.2902280108537525, 0.12638779386179522, 0.11438421570346691, 0.1587423897581175, 0.2126537633012049, 0.1467436132952571, 0.16476563061587512, 0.16505971405422315, 0.09880171943223104], [0.025181384226016235, 0.018352432598476298, 0.03062361622141907, 0.02584865847893525, 0.035873607848770916, 0.009493754387221998, 0.03628555918112397, 0.04181248506938573, 0.014405184738279786, 0.06267172924708575, 0.07650332103366964, 0.010536945919739082, 0.0037896669482506695, 0.05884437348868232, 0.038765241552027874, 0.09585030944435857, 0.022960180758673232, 0.005522581077457289, 0.02666089087142609, 0.00345721215580852, 0.06659383871010505, 0.019816302192339208, 0.026967000812874176, 0.015354220922745299, 0.016350726727978326, 0.07247699919389561, 0.037083011702634394, 0.01459577939385781, 0.013517469433281804, 0.03294474430731498, 0.02199688235123176, 0.05284759390633553, 0.06942122839973308, 0.058492829266469926, 0.012001122577203205, 0.03744449328223709, 0.05048532671935391, 0.0783836338086985, 0.06063360247935634, 0.019846834147756454, 0.041934661130653694, 0.07218921658932231, 0.015350216108345194, 0.024981210299301893, 0.006708969076498761, 0.008164723749359837, 0.0266469013877213, 0.0509468238305999, 0.04241807015205268, 0.044077712736907415, 0.02638373767695157, 0.006204093433552771, 0.027752402711485047, 0.03489355731289834, 0.03303835881524719, 0.05367508114431985, 0.029182063008192927, 0.038114073759061284, 0.07359690003795549, 0.01409269418218173, 0.04609230971254874, 0.011819233313872246, 0.01825796462071594, 0.022597919924010057, 0.028175144871056546, 0.06495156238088384, 0.026749696262413636, 0.02123558911989676, 0.061643472508876584, 0.028748576405632775, 0.04078379788552411, 0.052728386435774155, 0.02967591404740233, 0.05095022657769732, 0.05684905750968028, 0.06522182287881151, 0.04917342484986875, 0.014246853097574785, 0.0421452010050416, 0.041646162353572436, 0.06324929083348252, 0.049082047917181626, 0.03316608985187486, 0.07842416991479695, 0.011405884888517903, 0.04638507583877072, 0.024305809529323597, 0.009550919239700306, 0.025398493962711655, 0.02609280465549091, 0.013034535386395874, 0.045144876567064784, 0.030857576421112753, 0.039048155667842366, 0.011308427910989849, 0.07831557886675, 0.058849642737186514, 0.036110868750256486, 0.02581738808657974, 0.022578228890779428, 0.03635587767348625, 0.03844838902296033, 0.02325988039956428, 0.06108288012910634, 0.0262672724420554, 0.0405598919314798, 0.042568937642499804, 0.046775341616012156, 0.05797867677756585, 0.017511809346615337, 0.024795077806629706, 0.041365233482792974, 0.05092332372441888, 0.07958586851600558, 0.017233129183296114, 0.033604253840167075, 0.029532911466958467, 0.043931223917752504, 0.06329539304715581, 0.03162778099067509, 0.03092273142101476, 0.048061335110105574, 0.04991205845726654, 0.004033801296827733, 0.035267432758701034, 0.03423208851017989, 0.04420288336405065, 0.032387146493420005, 0.03628429753007367, 0.04449213913176209, 0.052397678009583615, 0.05434056125523057, 0.045521464562625624, 0.002008100632338028, 0.021219818481768016, 0.045245300279930234, 0.04033699900901411, 0.05428003169072326, 0.02453716293530306, 0.04802759336598683, 0.007412622480842401, 0.009958922346413601, 0.04993193317204714, 0.0400137862743577, 0.08032062440179288, 0.04016194863652345, 0.029148651519790292, 0.07043613019050099, 0.03073682342801476, 0.040797783658490516, 0.060109794649179094, 0.04956573153322097, 0.021582118279184215, 0.027529452272574417, 0.05533825264137704, 0.015529483735008398, 0.013288919490150874, 0.05566626707150135, 0.023945506109157577, 0.0269797212240519, 0.04328093185904436, 0.08144735300447792, 0.08685966531629674, 0.03293665860837791, 0.013661086140928091, 0.010710153910622466, 0.05314313566486817, 0.06007518830301706, 0.0025319564701931085, 0.026239365834044293, 0.05115859195939265, 0.02677953616512241, 0.049029314614017494, 0.031877840228844434, 0.025227972546417732, 0.031326201860792935, 0.053544622714980505, 0.05055381952843163, 0.07657954702153802, 0.010462581794854486, 0.0256124774023192, 0.02738869283348322, 0.004908681621600408, 0.009417387391295051, 0.03723423542396631, 0.08486993028782308, 0.06555593776283786, 0.04192166612483561, 0.058676774278865196, 0.08159990145941265, 0.022579375508939847, 0.021494550419447478, 0.038689720604452305, 0.019722155193448998, 0.024367682381125633, 0.019609691989899147, 0.025350901887577493, 0.03429096679610666, 0.022904478864802513, 0.02491053928679321, 0.029196727846283466, 0.04208273072435986, 0.05057100766862277, 0.03719955857377499, 0.04386719512694981, 0.042443544371053576, 0.017033693693520036, 0.013125491150276503, 0.01156378793893964, 0.06867937758215703, 0.030028653127374128, 0.04486699421249796, 0.023223589378176257, 0.02826933268806897, 0.0456084034522064, 0.0910458383441437, 0.07924132645712234, 0.0509362667798996, 0.014687754683109233, 0.006804512240705662, 0.020935147331329063, 0.022823555082140956, 0.04985719147953205, 0.04728256244561635, 0.025292839964095037, 0.05956028624495957, 0.04668705572839826, 0.05637071364617441, 0.048932668432826176, 0.04055350203998387, 0.007414757083097356, 0.07859660792746581, 0.024674527048773598, 0.0577952141611604, 0.041531530223437585, 0.014205991374183213, 0.02706917413888732, 0.0279440530721331, 0.03175051366270054, 0.029780133845633827, 0.04474112225580029, 0.0453166614897782, 0.005723402064177208, 0.01628980753594078, 0.01967759664694313, 0.03949270954763051, 0.005725510227421182, 0.04679597703216132, 0.005003347660021973, 0.06923661916516721, 0.040499425449525006, 0.06238192057935521, 0.039069292033673264, 0.012822230128222145, 0.042114416719414294, 0.02817208536725957, 0.004386846048873849, 0.04479301322135143, 0.029737530858255923, 0.07763969013467431, 0.039617100919713266, 0.03920414768799674, 0.04853391619690228, 0.08886888172128238, 0.03716982442711014, 0.019155831578245852, 0.05335585003194865, 0.03734110840014182, 0.04004543887276668, 0.06693233968690038, 0.025727042739163153, 0.06993494302150793, 0.08115830874885432, 0.02556583898694953, 0.017702925360936206, 0.011069153933931375, 0.04770953113620635, 0.010492084020370385, 0.03959276589739602, 0.015000858438725118, 0.026727019940153696, 0.03781405685003847, 0.06686521242954768, 0.07284849605639465, 0.011351871380611556, 0.014929410026525147, 0.01706903105514357, 0.05780704399512615, 0.04849701661441941, 0.08670323542901315, 0.006695761630908237, 0.046085522772045806, 0.004070316817887942, 0.03994832142780069, 0.07196969672804698, 0.0459177640004782, 0.038792381892562844, 0.03389523510122672, 0.031159760401351377, 0.020096481493965257, 0.018886788202507887, 0.08396365665248595, 0.022755116078769788, 0.01902212625282118, 0.03856678755255416, 0.03594264242565259, 0.07319963580812328, 0.03069248195970431, 0.04712313057098072, 0.0388974737143144, 0.003899812099916744, 0.04521238231973257, 0.021393354872998316, 0.06155915711133275, 0.03895565438142512, 0.04371484334114939, 0.014038880126463482, 0.03177749073074665, 0.016535716313228477, 0.019861409928125795, 0.0719826175190974, 0.03693833001307212, 0.039531468210043386, 0.06505029028630815, 0.012834977442253148, 0.013011914725211682, 0.0768007367150858, 0.051990439314977266, 0.02435733869788237, 0.0257312377289054, 0.04344971850514412, 0.030614979477832094, 0.03571914836356882, 0.05241672151896637, 0.03851449582725763, 0.046966674708528444, 0.016162651663762517, 0.09223978326190263, 0.021356279030442238, 0.006509586464744643, 0.011646583789115539, 0.04148537977016531, 0.00926323868043255, 0.07210375828435645, 0.0500231023033848, 0.08094396907836199, 0.036916098979418166, 0.004245321733833407, 0.03100509311479982, 0.023251241800608113, 0.019983775237051304, 0.03446932343649678, 0.13008811249164864, 0.20743696979479864, 0.1453996729105711, 0.1406779364333488, 0.14174842508509755, 0.1331035772454925, 0.14839419425697997, 0.09051508401171304, 0.16596326400758699, 0.20215427357470617, 0.1321239274693653, 0.1457636518171057, 0.09243021093425341, 0.13889532739995047, 0.15701610973337665, 0.14113607903709635, 0.17868046910734847, 0.1237334507459309, 0.17106149200117216, 0.1653387615806423, 0.1449796321685426, 0.09101545481826179, 0.10717612123698927, 0.09136310647591017, 0.21705944876885042, 0.15813213656656444, 0.21619747392833233, 0.1566153796738945, 0.17559973988682032, 0.16307270270772278, 0.1443674197071232, 0.17705716949421912, 0.10056538143544458, 0.11112004984170198, 0.09371775551699102, 0.19979745004093274, 0.23836100182961673, 0.13229772361228243, 0.17154001398012042, 0.16414519515819848, 0.266122430912219, 0.10241400450468063, 0.08347896742634475, 0.16301399882650003, 0.10637287996360101, 0.13154278130969033, 0.14891688886564225, 0.15256515325745568, 0.10485524733667262, 0.13017699209740385, 0.12688976770732552, 0.09503083740128204, 0.07732218451565132, 0.15079832228366286, 0.08738443051697686, 0.1357329767779447, 0.1753858380834572, 0.21242620598059148, 0.1509192181401886, 0.1346800324972719, 0.179917837085668, 0.09759202614077367, 0.08133588984492235, 0.12554900371469557, 0.13836216850904748, 0.19328814698383212, 0.10966667236061767, 0.16192804381716996, 0.1017320598475635, 0.13241744687547907, 0.10277896304614842, 0.13217470521340147, 0.077233371703187, 0.1087569328956306, 0.1660776586504653, 0.1818685425678268, 0.1676351742935367, 0.11631621164269745, 0.1486244678380899, 0.10225484351394698, 0.15162406547460705, 0.12703959248028696, 0.13875109842047095, 0.229951785877347, 0.203618694213219, 0.17235483275726438, 0.14045512885786593, 0.19356483448063955, 0.08797033384325914, 0.11528745395480655, 0.17558041436132044, 0.17657643591519445, 0.17701954260701314, 0.15328957844758406, 0.10582048460491933, 0.16473661264171824, 0.15368817112175748, 0.14921201131073758, 0.121460920345271, 0.12859476293670014, 0.2182585367700085, 0.08700664024217986, 0.10956786281894892, 0.10822600044775754, 0.12476844247430563, 0.10871325750485994, 0.12378592058666982, 0.15085551218362525, 0.14075222541578114, 0.13626249914523214, 0.09019492892548442, 0.22571428591618314, 0.13488250522641465, 0.18048320518573746, 0.10088981871376745, 0.11718615714926273, 0.12261889336514287, 0.1692708084010519, 0.19231634913012385, 0.16425041685579345, 0.12648353091208264, 0.19445511483354494, 0.1493112216121517, 0.10189968132181093, 0.10242757096420974, 0.14309957914520055, 0.11662950928439386, 0.08525264842319302, 0.12249383406015113, 0.10337208746932447, 0.20576641021762043, 0.12492920650402084, 0.10624581685988232, 0.11088723811553791, 0.11097053677076474, 0.09939641720848158, 0.18027467653155327, 0.11455798958195373, 0.15985776350134984, 0.13220862136222422, 0.1332232856657356, 0.1413690540357493, 0.11206006893189624, 0.12735034455545247, 0.2653353090863675, 0.10166472478886135, 0.09173466271022335, 0.14878195157507434, 0.11698325397446752, 0.08879960965714417, 0.19022088032215834, 0.24353022366994992, 0.11524349654791877, 0.11921011260710657, 0.1261934105423279, 0.07683282718062401, 0.11040280864108354, 0.16371418547350913, 0.14488149055978283, 0.09333609865279868, 0.2003744401736185, 0.19661777769215405, 0.2233034637174569, 0.176652624795679, 0.08601853740401566, 0.26199873187579215, 0.10137440403923392, 0.15697285736678168, 0.1706577933509834, 0.11514132507727481, 0.07893095287727192, 0.08769214720814489, 0.09529493807349354, 0.06395704738679342, 0.113861127756536, 0.14862681302474812], [0.021286489318299573, 0.03960574606026057, 0.07072476626490243, 0.01632307430554647, 0.09783922811038792, 0.02623751603096025, 0.045488932519219816, 0.033503577797091566, 0.02714553556870669, 0.033378718871972524, 0.017393490597896744, 0.02396842548478162, 0.019302528198750224, 0.05008607353374828, 0.09334830698207952, 0.0374200580699835, 0.05231478382484056, 0.005964222491456894, 0.02462387732521165, 0.09597398835467175, 0.011196861778444145, 0.04945664695696905, 0.04421006735356059, 0.052597219255403616, 0.03048912050871877, 0.013182140210119542, 0.05552564864046872, 0.020880501142528374, 0.0487471315136645, 0.09026195228216238, 0.081115798529936, 0.026769010655698366, 0.03869714208121877, 0.10446641390444711, 0.03050793951842934, 0.0725270644761622, 0.032399299161625095, 0.019264188849774655, 0.03142036926874425, 0.05447331292089075, 0.031653526093577966, 0.018289591243956238, 0.010699406684580026, 0.04630982948583551, 0.03384680996532552, 0.03017517905391287, 0.023134065959311556, 0.007702240509388503, 0.05459475054522045, 0.029852346669940744, 0.022444065289164428, 0.07933120796224102, 0.004345105808170047, 0.037583723897114396, 0.030159920497681014, 0.04588510208122898, 0.02430105236271629, 0.02389680452324683, 0.01073842231562594, 0.045021616970188916, 0.06836492219008505, 0.05685039337549824, 0.011100266619905597, 0.0029558726146206027, 0.0837475061416626, 0.040285853901878, 0.008870141609804705, 0.011769550237659132, 0.02229527210147353, 0.04420885023137089, 0.01486207960624597, 0.023451291417586617, 0.05976254746201448, 0.02035383975453442, 0.06642856242251582, 0.02542246162192896, 0.07024961363640614, 0.027167206280864775, 0.06632944860029966, 0.015140451778279385, 0.03617690505052451, 0.034035352582577616, 0.051200493617216125, 0.025152672387775965, 0.010236353846266866, 0.06945492932572961, 0.022882988123456016, 0.036094033130211756, 0.08755318005569279, 0.09579875244526193, 0.024368817867070902, 0.025394100448465906, 0.04378495774290059, 0.021093070790811908, 0.008380718409171095, 0.01052457246260019, 0.0055427155439247144, 0.04294318045140244, 0.0560667559329886, 0.03286520834080875, 0.03818617340584751, 0.008267363700724673, 0.03483264554233756, 0.025757982875802554, 0.047264309323509224, 0.02961639936984284, 0.042734406888484955, 0.024416580636170693, 0.04827283977647312, 0.03248139182687737, 0.06949432252440602, 0.08403590472880751, 0.08240470124292187, 0.0647152254532557, 0.07206801645224914, 0.02864500042051077, 0.018987271287187468, 0.041852542490232736, 0.021541541354963556, 0.07988627505255863, 0.03264389619289432, 0.03914263106707949, 0.0780923334241379, 0.02544905277318321, 0.020870127773378044, 0.05763731482147705, 0.0602440677175764, 0.09717924360302277, 0.053724103709100746, 0.02985043935041176, 0.033357697539031506, 0.05582891986705363, 0.01055868435287266, 0.024849493929650635, 0.034318066318519413, 0.00930134332520538, 0.021171311709622387, 0.03742656670510769, 0.023306886178033892, 0.02441407588776201, 0.06972528630285524, 0.05478165672684554, 0.018591667612781748, 0.04451347587746568, 0.03658237743366044, 0.042334819736424834, 0.07130678073735908, 0.023728862070129253, 0.04941349849104881, 0.06619564679567702, 0.05787653870356735, 0.020756657104357146, 0.02834435825207038, 0.04536535750958137, 0.032022458835854195, 0.015834399746381678, 0.010951223885058425, 0.028348391824692953, 0.0276556081007584, 0.03908674363628961, 0.02642787319928175, 0.04205266261124052, 0.07521469291532412, 0.012163836599938804, 0.08778647417784669, 0.020315539368311875, 0.03262221805925947, 0.012888126348116202, 0.08876063206116669, 0.02446382390189683, 0.06217731046490371, 0.019433051566011272, 0.021946286433376372, 0.05687645018042531, 0.0076454805912362644, 0.03723679583345074, 0.025967199871956836, 0.01868898358225124, 0.046728564047953114, 0.05200254745432176, 0.04740883145132102, 0.1013242348562926, 0.04846041389100719, 0.032780432811705396, 0.03197010031726677, 0.03181920685165096, 0.019154145047650672, 0.04876457569480408, 0.05196113561396487, 0.020471280913625378, 0.04900254534732085, 0.025665258945082314, 0.060872922840644605, 0.019106565960100852, 0.027984817388642114, 0.10125123721081764, 0.051011383256991394, 0.06724407881847583, 0.06588876130990684, 0.07472080847946927, 0.07317433599382639, 0.01153744447947247, 0.036835056453128345, 0.04632902142475359, 0.05840689227625262, 0.025276288215536624, 0.01448387187338085, 0.002114446683663118, 0.039261489728232846, 0.03163310590025503, 0.08472274013911374, 0.023937758087413386, 0.029076175233058166, 0.03833820977888536, 0.04248046250722837, 0.05969604360871017, 0.0275092714218772, 0.013469143559632357, 0.011876717289851513, 0.04098333170986734, 0.034649041917873546, 0.03458997809502762, 0.02711029097554274, 0.000657425779309051, 0.01873480749054579, 0.0112154405178444, 0.04521023380220868, 0.028356889415590558, 0.03183512591931503, 0.05733870428230148, 0.09964750803192146, 0.06153740847366862, 0.003014824883393885, 0.0608370919508161, 0.0578703083738219, 0.04326866415794939, 0.01697941857855767, 0.07685961871175095, 0.023015700826363172, 0.012867996520071756, 0.05527698463993147, 0.011783177924371557, 0.029116728037479334, 0.024807894697005395, 0.05599333155259956, 0.02635833025124157, 0.08383241525734775, 0.013095725462335395, 0.07856816882849671, 0.04645888242521323, 0.06043497036444023, 0.06837558685219847, 0.08594471597461961, 0.05509555550816003, 0.0897321330558043, 0.04571719859086443, 0.048246590013150126, 0.020517062148428522, 0.03635896871855948, 0.04055019577208441, 0.04156752438575495, 0.051431212486932054, 0.018087554526573513, 0.061541304748971015, 0.02396120624325704, 0.03391434911463875, 0.01831762772781076, 0.03971180267399177, 0.027576617612794507, 0.05182954540941864, 0.034953893919009715, 0.03449125761108007, 0.0345820816437481, 0.07915445807157084, 0.04064753586135339, 0.06141942554677371, 0.05460787171614356, 0.027963070606347173, 0.03097359080129536, 0.024007314023037907, 0.06636276360950433, 0.03421528628678061, 0.016615803324384615, 0.04101652797544375, 0.06635931262280792, 0.012755404368363088, 0.0326414656592533, 0.08151053945766762, 0.02599109702714486, 0.07235903482069261, 0.03145876798953395, 0.031022127259348053, 0.009905391234497074, 0.016593655782344285, 0.07342587210587226, 0.05207126661844086, 0.0728989027265925, 0.035799701072392054, 0.03546509637089912, 0.10751207664725371, 0.03431497527344618, 0.008478937015752308, 0.08002688235137612, 0.07037262461381033, 0.027970213777734898, 0.00893172038558987, 0.03276231698691845, 0.01704389080259716, 0.03709068550961092, 0.02933444262453122, 0.0543566435953835, 0.027580916503211483, 0.032722960895625874, 0.011827536091004731, 0.02134040078090038, 0.030272738076746464, 0.06299810353084467, 0.020193114687572233, 0.02991112105519278, 0.022773005548515357, 0.014064222614251776, 0.05263217070023529, 0.018451123396516778, 0.04984363986295648, 0.03733939032827038, 0.05452577162941452, 0.008898587202565977, 0.10014592699008062, 0.05414925042714458, 0.048679948595236056, 0.043578874465310946, 0.011855412085424177, 0.026143992436118424, 0.059662839921656996, 0.037998480547685176, 0.060199720683158375, 0.05933527820161544, 0.03025506011908874, 0.07446804040228017, 0.03533833383698948, 0.040477012589690275, 0.033166223438456655, 0.033826126309577376, 0.03703745125676505, 0.031123311673582066, 0.01931615774083184, 0.006395136624632869, 0.0948934287589509, 0.02847490759450011, 0.0850945858110208, 0.024982926515804138, 0.039657759480178356, 0.174337450589519, 0.1974421998602338, 0.18654821411473677, 0.13331313006347045, 0.14981362590333447, 0.14128628972684965, 0.12672987941186875, 0.09363268312881701, 0.16237922507571056, 0.1319244084879756, 0.1560030336258933, 0.09472634905250743, 0.1346699392888695, 0.11671634056256153, 0.21300275082467124, 0.1450391672551632, 0.11377882357919589, 0.0985528995806817, 0.08509713879902847, 0.26893053960520774, 0.113139804743696, 0.2334287774283439, 0.11886269843671471, 0.11881868165801279, 0.2026293074595742, 0.11794112171628512, 0.14166509674396366, 0.11764110851800069, 0.1217426618677564, 0.15776811313116923, 0.12388901974190958, 0.1580671689589508, 0.13950256747193635, 0.17328683665255085, 0.1359231595415622, 0.1322857750346884, 0.14263768127420917, 0.1348971700645052, 0.12258703296538442, 0.1535955659346655, 0.21588114090263844, 0.06431630623410456, 0.169548015401233, 0.14762489881832153, 0.0943518835993018, 0.10006610900745727, 0.10454678107635118, 0.15076560841407627, 0.06449738284572959, 0.07091522362316027, 0.1317069146898575, 0.20028174592880532, 0.10287229553796351, 0.11438518049544655, 0.3133557370165363, 0.18691066419705749, 0.1141974022903014, 0.11948868515901268, 0.13047247077338398, 0.15068376436829567, 0.13221625064034015, 0.1684170713997446, 0.13916662690462545, 0.09184708324028179, 0.16485510393977165, 0.13424045842839405, 0.11332734546158463, 0.0970701478945557, 0.1700595035799779, 0.10233447595965117, 0.1285634739906527, 0.17777389119146392, 0.16507535852724686, 0.15742317773401737, 0.1661694623180665, 0.23225026176078245, 0.3535514941904694, 0.18187023466452956, 0.2156374344485812, 0.12642525747651234, 0.15306973946280777, 0.10693735006498173, 0.09394422188051976, 0.07986920565599576, 0.09697636269265786, 0.24273906456073746, 0.09047373154317029, 0.0971778854727745, 0.1369273298769258, 0.16439460130641237, 0.0815646568662487, 0.09719097695779055, 0.10441801103297621, 0.10330532386433333, 0.09920435681124218, 0.12254420362296514, 0.12664805020904168, 0.17005185945890844, 0.10138595927855931, 0.1190154769574292, 0.1311846950557083, 0.1233653529197909, 0.08056727718212642, 0.08013804123038426, 0.1455231662839651, 0.10897022613789886, 0.08977822042652406, 0.14271640829974785, 0.18311885360162705, 0.14471771341050044, 0.22406820236938074, 0.20119172288104892, 0.11005694555933587, 0.26642243668902665, 0.08893692182027735, 0.10254400651319884, 0.10962701941025443, 0.09299478493630886, 0.16334918240318075, 0.13985136203700677, 0.10849022728507407, 0.07375235029030591, 0.11894452021806501, 0.1605983526678756, 0.1288728605140932, 0.2013771707424894, 0.1571030745981261, 0.18866841128328815, 0.17963641468668357, 0.0835439127695281, 0.13699508795980364, 0.15826256159925833, 0.13310946989804506, 0.08529071317752823, 0.1155421367730014, 0.07981991220731288, 0.10452022703248076, 0.09929278370691463, 0.06506562305730768, 0.16367657342925668, 0.12817316368455067, 0.07103736628778279, 0.13848606264218688, 0.14729966002050787, 0.16086040501249954, 0.12593021529028192, 0.12302256975090131, 0.14868860424030572, 0.12599218462128192, 0.1210930228990037, 0.1312664945726283, 0.2681335323723033, 0.15454717737156898, 0.0900145796185825, 0.147215218457859, 0.19450081628747284, 0.10527076097787358, 0.09957062153262086, 0.15137917158426717, 0.13321869919309393, 0.1932875977945514, 0.09526145237032324, 0.1513857173267752, 0.12757769407471642, 0.2034681272925809, 0.04847654818149749, 0.14880990085657686, 0.1943427388323471, 0.2017292901291512, 0.09091936153708957, 0.09226875670719892, 0.2309841281385161, 0.0724710694339592, 0.1778217448736541, 0.07922322547528893, 0.14723110041813925], [0.020206781337037683, 0.01556056302433717, 0.02507237200916279, 0.03919088179827668, 0.021741700438724365, 0.02226752319984371, 0.024299992946907878, 0.0013678498316949117, 0.027644227266137023, 0.045727158212685026, 0.050190467736683786, 0.06625384601647966, 0.03237888638977893, 0.02642614213982597, 0.010753764363471419, 0.043394020322011784, 0.015201016594801331, 0.09948319653631188, 0.017781409333110787, 0.05747385679569561, 0.016089490745798685, 0.012721309176413342, 0.01578925675858045, 0.04179408722848166, 0.08278571243863553, 0.05246723580057733, 0.023078315825841855, 0.023302392473851796, 0.023991899615793955, 0.05369251790398266, 0.015856910940783564, 0.029709442424064036, 0.05273190050502308, 0.07180450207670219, 0.018089506374963094, 0.023641526131541468, 0.030364302401721943, 0.05478395367390476, 0.04846137868298683, 0.023471360946132336, 0.0582725561253028, 0.01582302818860626, 0.08363353452295996, 0.017911895592988003, 0.014862312455079518, 0.03405448886041995, 0.03450482778134756, 0.05035489426518325, 0.013843648903275607, 0.030616150215792004, 0.04334241137257777, 0.013295808475959348, 0.005227629790169885, 0.07221829393529333, 0.03553830181772355, 0.041540135425748304, 0.03431223303778097, 0.01754629694914911, 0.020493330121098552, 0.011964607056142995, 0.028954706067452207, 0.00970779627095908, 0.018971821627928875, 0.024057473929133266, 0.07168294570874423, 0.02894792840379523, 0.050503078891779296, 0.027242994401603937, 0.03414372098632157, 0.025820679511525668, 0.05264125458779745, 0.02147063842130592, 0.042770404761540703, 0.0071822510290076025, 0.056451648561051115, 0.017390969151165336, 0.08388011308852583, 0.10208601233898662, 0.045128100318834186, 0.0452453522302676, 0.035016724141314626, 0.01592196204001084, 0.007415193094857386, 0.05572845162532758, 0.06879925669636577, 0.02949426598206628, 0.02138245643436676, 0.04325471178162843, 0.03979573957622051, 0.10609832243062556, 0.03469268762273714, 0.026061113094328903, 0.0860306566755753, 0.055172089487314224, 0.06085730063205119, 0.004555352070383378, 0.0337649918947136, 0.008352921267942293, 0.02357607241719961, 0.0022438765427068574, 0.039840817626100034, 0.021717890485888347, 0.035345399082871154, 0.009469480592088075, 0.06819100730353966, 0.05550859779759776, 0.025848582408798393, 0.02983252205012832, 0.01773757438058965, 0.05954185871814843, 0.029637704574270174, 0.025176393282890785, 0.04217536188662052, 0.08647396374726668, 0.04048327260534279, 0.05527301043912303, 0.04676710748753976, 0.031331675199908204, 0.033457041427027434, 0.053034284865134396, 0.011367990828148322, 0.038636152385151945, 0.038121729012345895, 0.024480893298459705, 0.1215255688293837, 0.04848742806643713, 0.06898264880874194, 0.012280675691727083, 0.03347585858136881, 0.02451499498420162, 0.032631750946165994, 0.07428344601066783, 0.03842452526441775, 0.012969530671398388, 0.0430079476791434, 0.02038122314843349, 0.036974543108954094, 0.042875778599409387, 0.06492606960819103, 0.02749417984887259, 0.03509263842715882, 0.03539302269928157, 0.051364241080591455, 0.01831721398048103, 0.05467124741699081, 0.0572616136923898, 0.0233607753762044, 0.0493470391666051, 0.04973076662281528, 0.037845449696760625, 0.06986894382862374, 0.005772913982582395, 0.02911920124461176, 0.056744737521512434, 0.08760229538893327, 0.01626849676540587, 0.06925674621015787, 0.013065860512142535, 0.039252435526577756, 0.03632647749327589, 0.030591470094805118, 0.045845196800655685, 0.00622902078248444, 0.11530868679983541, 0.04334854151238687, 0.06463100653490983, 0.04019532301754225, 0.041166189475916326, 0.04791664599906653, 0.007526481849708944, 0.00796897951659048, 0.058771861949935555, 0.0720791783533059, 0.029580236368929036, 0.013471463698806474, 0.09692122854175977, 0.04055707548104692, 0.0077001304907753365, 0.0451578864158364, 0.06446518105803989, 0.06296041727182455, 0.02416042836557608, 0.03203703090548515, 0.031447387154912576, 0.06772173990611918, 0.0399258343531983, 0.03524559135257732, 0.054374284445657395, 0.013644893406308256, 0.03650795857538469, 0.04212639498291537, 0.05534008203539997, 0.014833878922217991, 0.05919728326261975, 0.06746413302607834, 0.061276547276065685, 0.020905051387671847, 0.014923751150490716, 0.02480253082467243, 0.026896285271504894, 0.033286592370131984, 0.030290675786091015, 0.051378505158936605, 0.02865579866920598, 0.016430691284767818, 0.00968662929153652, 0.051254462596261874, 0.03063046624447452, 0.05531587317818776, 0.03367113989952486, 0.04136246527195908, 0.026134238760278095, 0.05389974779973272, 0.09740915353177115, 0.06144974599010311, 0.01585363435879117, 0.044644739537034184, 0.035933384133386426, 0.029150581103749573, 0.05551888396439608, 0.017494535859441385, 0.023840271423978265, 0.009423772644368, 0.05457907638628967, 0.055806677701184526, 0.01830330613302067, 0.07057789523969404, 0.04590990465658251, 0.03194675606209785, 0.019121690929750912, 0.03782202380534727, 0.011478950254968368, 0.06017171574058011, 0.07036597497062758, 0.05322323937434703, 0.08696571821928956, 0.04976158801582642, 0.0965605373494327, 0.05010562912502792, 0.05013963433157187, 0.04998215059458744, 0.03068630729103461, 0.01682823753071716, 0.039384519259328954, 0.04428680542332586, 0.04925102381093893, 0.04339801307651214, 0.05231516974163242, 0.019176262903783936, 0.0076185378475202015, 0.04839356493903324, 0.04303740352042951, 0.08476694245473482, 0.021127313484612387, 0.0054809526227472816, 0.07581091209431179, 0.06000278066494502, 0.0054859945885255, 0.04539748879324179, 0.032204934395849705, 0.05212257499806583, 0.038906821064301766, 0.015399520689243218, 0.020187118134344928, 0.028974565939279273, 0.04190518673567567, 0.059125406260136515, 0.024754441510594916, 0.03944129726733081, 0.017863457469502464, 0.01991009667108301, 0.01832738511438947, 0.01957483145815786, 0.08111124916467816, 0.04426647428772412, 0.036798631845158525, 0.1251053181476891, 0.04528210709395353, 0.05383772651839536, 0.014507597406918649, 0.0925097320578061, 0.012974510482308688, 0.034977913528564386, 0.011920142205781303, 0.07020814984571189, 0.028953385044587776, 0.017587304319022223, 0.012173154264019104, 0.02763924374448834, 0.029106102338118944, 0.040435459741274826, 0.05127102733240463, 0.032698024733690545, 0.019971392503066454, 0.06598291016416624, 0.03718584368471056, 0.026683710057113785, 0.04526155702478718, 0.028213452678755857, 0.07488408096833155, 0.06753238834789954, 0.025078420512727462, 0.014805604951106943, 0.011241733882343397, 0.051197970315115526, 0.010107721100212075, 0.0708953637513332, 0.0526014049682999, 0.03321739823149983, 0.042757116607390344, 0.0645615860412363, 0.013915007330069784, 0.058436426043044776, 0.026266968161507975, 0.022394615989469457, 0.04879977204836905, 0.04978197852324229, 0.060836539050797, 0.03046997866476886, 0.09764595059095882, 0.03687444594106637, 0.032696659181965515, 0.012152194158261409, 0.041935466360882856, 0.02466705733240815, 0.010987309888150776, 0.05405406256613787, 0.04322168249927927, 0.036232614365871996, 0.02319358249224024, 0.05577092473686207, 0.02875924106774619, 0.023572402496938594, 0.025608480937080458, 0.025921424203261267, 0.01702776578895282, 0.10916977480519563, 0.01450544146791799, 0.024473839184793178, 0.08558844798244536, 0.014706928068335401, 0.025542179319018032, 0.03211887124052737, 0.05173030171135906, 0.01771904109773459, 0.06191163643961772, 0.028610772569663823, 0.057536553431418724, 0.05530447007913608, 0.02547188680182444, 0.013347489784791833, 0.007349034340222715, 0.1057534538267646, 0.12451381160644814, 0.10547955680522136, 0.25122280698269606, 0.12661478715017438, 0.15967632323736325, 0.10985074724885635, 0.09945441604941152, 0.14494451374048367, 0.11556952944374643, 0.19639706297311932, 0.141508859815076, 0.13206258154241368, 0.1284312381176278, 0.16669718868797645, 0.11685881807352416, 0.2466382342390716, 0.1125869937823154, 0.18221788632217795, 0.10474501614226028, 0.14016250002896413, 0.10028772172518075, 0.12412877797032706, 0.18498312856536359, 0.25284116389229894, 0.10686116118449718, 0.13167803030228242, 0.1110131063614972, 0.09695582004496828, 0.15340161306085065, 0.11296503638732247, 0.12128389585996047, 0.19136463379254565, 0.13079484488116577, 0.17860604653833434, 0.08717943448573351, 0.12183114071376622, 0.1657396845985204, 0.21023789449827746, 0.07851730944821611, 0.15391761349746957, 0.12346648538368754, 0.14970766205806285, 0.11479922468424775, 0.07938877635751851, 0.10811389904120006, 0.1427818211959675, 0.22219286940526217, 0.07077331014443189, 0.1213619475311134, 0.22520554368384182, 0.15722906158771366, 0.1221354138397146, 0.18805961270118132, 0.13142540323315188, 0.12758116732584313, 0.1517413544934243, 0.09554833697620779, 0.1524675459950231, 0.1400392738287337, 0.1306724498863332, 0.17495893989689648, 0.1160307445388753, 0.13464296964230016, 0.13571513554779813, 0.12213451584102586, 0.18221616453956813, 0.11741032285499386, 0.20437970728380606, 0.14101055217906833, 0.2051378259784542, 0.14243642566725612, 0.13353627902688459, 0.08937556078308262, 0.15694973204517737, 0.11474041690235026, 0.15131028543692082, 0.22717429819749668, 0.07958536385558546, 0.22050040162866935, 0.17491904203779995, 0.06873935795738362, 0.12165810156147927, 0.133803496719338, 0.2132162221823819, 0.12714468059130013, 0.07430807047057897, 0.19129910215269774, 0.1490314764669165, 0.17839824518887326, 0.14917831780621782, 0.11379663512343541, 0.18817960313754156, 0.33362776797730476, 0.1542092181625776, 0.13215926854172722, 0.13147465215297416, 0.19427334802458063, 0.14418609818676487, 0.09101875737542287, 0.1862982736201957, 0.20935030071996152, 0.24391786224441603, 0.08259396374342032, 0.1365011589950882, 0.14414701669011265, 0.09588314205757342, 0.08779644122114405, 0.1395357117871754, 0.12655614264076576, 0.1225520703883376, 0.11863468840601854, 0.16388090152759105, 0.14157072524540126, 0.10551361396210268, 0.12100193911464885, 0.1498511340469122, 0.13280127081088722, 0.13530226395232603, 0.1472255343105644, 0.09741320565808564, 0.134621714532841, 0.11263642081758007, 0.1407416572328657, 0.197834157734178, 0.07688042853260413, 0.1620044553419575, 0.11117631947854534, 0.12717800302198157, 0.08163073769537732, 0.25193488283548504, 0.14235418086173013, 0.08171851150109433, 0.08322193200001493, 0.10120877152075991, 0.14293123036623, 0.10001105649280362, 0.09447746240766719, 0.1817944465437904, 0.177424191206228, 0.11677525224513374, 0.1646442894707434, 0.1851862098556012, 0.20643572352128103, 0.09442055452382192, 0.13982088945340365, 0.11760394918383099, 0.09425158976227976, 0.13391916785622016, 0.14377104467712343, 0.14879029331495985, 0.20024457917315885, 0.12877792498329654, 0.09740816647536121, 0.12373728764941916, 0.11913329290109687, 0.1878074457636103, 0.09456050873268396, 0.08334225640282966, 0.2359122855705209, 0.2008684433531016, 0.1530107535654679, 0.09381016774568707, 0.12868313788203523, 0.12736495002172887, 0.08845839984132908, 0.1327321768621914, 0.10620525848935358, 0.12260273681022227, 0.16407230141339824, 0.10940729916910641, 0.24785220972262323, 0.1160827319836244, 0.1550897170091048, 0.09255469136405736, 0.24719138658838347], [0.037583746161544695, 0.06067988280847203, 0.06622309141675942, 0.0510370764095569, 0.06882968475110829, 0.020360895723570138, 0.03900761585100554, 0.046625490867882036, 0.0485470151033951, 0.06445151069783606, 0.11226297210669145, 0.04387132888950873, 0.03146931019728072, 0.03743772489542607, 0.05175065882212948, 0.05785290872154292, 0.07434369355905801, 0.05484639426867943, 0.0489546397147933, 0.08682923726155423, 0.07763531888485886, 0.020145607959420886, 0.026998853791155852, 0.0835578799888026, 0.0335419023031136, 0.007001802459853934, 0.041618780815042555, 0.03068211786739994, 0.021774844753963407, 0.001486420446781267, 0.03565170198271517, 0.005321957687556278, 0.02445314996293746, 0.028807931521441787, 0.0758366497757379, 0.10215803777100518, 0.06748931409674697, 0.03054420456464868, 0.013427858812065097, 0.021251458092592657, 0.018845565609808546, 0.05538161261938512, 0.03900544877978973, 0.04523295094259083, 0.01440023275790736, 0.008863940965966322, 0.037365306125138886, 0.015202345966827124, 0.07618911797180772, 0.01507822455096175, 0.019095131319772918, 0.04383392835734412, 0.022626856261922512, 0.031277980815502815, 0.020295139584050048, 0.029511233333323617, 0.025923077337210998, 0.062295905663631856, 0.020824687926506158, 0.005569155946432147, 0.01760770410328405, 0.031341107896878384, 0.006053671231711633, 0.01704857189906761, 0.010586113203316927, 0.037760232589789666, 0.031034743769851048, 0.03808347129961476, 0.044901533765369095, 0.02030077434028499, 0.01782324048690498, 0.06504349963506684, 0.018186132147093304, 0.05171073127712589, 0.04810525169887114, 0.006291281870289822, 0.039456403683288954, 0.02806484688335331, 0.05366603065340314, 0.03580954566132277, 0.07954522108775564, 0.02396868894720683, 0.08365771369426511, 0.04673706163885072, 0.04672190327255521, 0.01610485320270527, 0.07529072594479658, 0.04892851611657534, 0.03838683529465925, 0.02822297999955481, 0.05789645052573178, 0.11224792877328582, 0.036200494214426726, 0.031137228797888383, 0.03138028216199018, 0.014518737043545116, 0.02660367314092582, 0.02642754294356564, 0.0508245883975178, 0.02708511547098169, 0.023754417925374582, 0.03334186752908863, 0.03249103232519701, 0.1255761514767073, 0.022245689215196762, 0.06917233433341607, 0.025583541064406745, 0.023130772678996436, 0.013812410979880951, 0.04900863466900773, 0.04952899893396534, 0.024131087557179853, 0.06821920149377547, 0.04346631663793232, 0.02145874921552604, 0.05791852941911202, 0.02416228559013689, 0.037199354483163916, 0.05662573785230052, 0.019443372984824236, 0.02186340523621766, 0.053582654072670266, 0.05951651808572933, 0.019673756032716483, 0.04993533962988295, 0.05978532397421077, 0.024867003048711922, 0.08173751790309325, 0.04162347860983573, 0.011665030797303189, 0.014545105550496373, 0.0702549348352477, 0.03467376285698265, 0.08519585186149925, 0.038191409257706255, 0.008741378060221905, 0.02783265485049924, 0.015598140744259581, 0.06333658966468647, 0.030839918872516137, 0.02610274572361959, 0.02715248763706768, 0.04625341513019521, 0.012461123333196156, 0.04513742169365287, 0.004488278154894942, 0.018565798200143036, 0.07798950144206174, 0.07638472583494149, 0.025548984813212883, 0.060861708989250474, 0.012709226084552938, 0.03831256115518045, 0.027537218848010525, 0.014869800725136884, 0.023704877712589223, 0.018569709318398964, 0.033194361967616715, 0.043099484173581004, 0.0430172653432237, 0.07028130334219895, 0.025269404795835726, 0.07621988741448149, 0.02302711691299919, 0.08450083798379637, 0.0239322884590365, 0.03694773302413523, 0.01986780909646768, 0.0628432395751588, 0.003629291850302252, 0.03678049375594128, 0.025101961437030695, 0.041190813935827464, 0.03696100633533206, 0.015934973744151648, 0.018644174560904503, 0.030007882269273978, 0.006726539422743372, 0.017069552413886413, 0.03668172132165637, 0.07312622255994938, 0.055382944774464704, 0.06203734883456491, 0.02561067583883414, 0.027414475043769926, 0.02741294250881765, 0.023633132441318594, 0.06700690326397307, 0.02264721151732374, 0.049766018637456, 0.03382560309546534, 0.057910584728233516, 0.05794022981717717, 0.012404508597683161, 0.021264388160489034, 0.037909118545940146, 0.10013881721533835, 0.051555989775806665, 0.019189998201909475, 0.10337087034713477, 0.015476258759008488, 0.013752037266385742, 0.07195213751401752, 0.05392747072619386, 0.06813843356212601, 0.025118440826190636, 0.022881147597217932, 0.013774835115327733, 0.005454309057313367, 0.051594592587207444, 0.07118876441381872, 0.022456590886577033, 0.027175557297596242, 0.06074100238038227, 0.03042799908143934, 0.042044417350552976, 0.02696343664865708, 0.03751687123440206, 0.09490136973909102, 0.033720822975737974, 0.02349011872865958, 0.02568795196566498, 0.05293277390592266, 0.06380830614943989, 0.04766006699355785, 0.050094014513888396, 0.03724477763171308, 0.042521714785834774, 0.07424455005093478, 0.026038642718049232, 0.012033924576826394, 0.004012994259028346, 0.0014140234770820825, 0.10935448051895946, 0.09155127801932395, 0.020731741351482924, 0.09880997953587212, 0.05387827375670895, 0.036155816924292594, 0.03215176322555635, 0.02695764233067166, 0.05700219226127956, 0.09139206507825293, 0.019815747436950915, 0.004263806313247187, 0.010302260270691477, 0.04754303030495066, 0.09647959130234085, 0.028283316605666187, 0.03841122226731386, 0.030662567842227872, 0.039969005083548836, 0.01854666377766989, 0.038846777606522664, 0.03872664245136548, 0.08722651633433998, 0.04234046376950573, 0.03734344987606164, 0.02492074196197791, 0.07041820732410997, 0.02270015076646814, 0.012936514376633568, 0.03951396094635129, 0.003779923708862043, 0.0227862306201132, 0.04984194405551534, 0.05053578533988912, 0.07431882419041358, 0.03624839613621589, 0.02238443928945344, 0.03586945553252008, 0.05842100792506244, 0.019082479557255283, 0.02405568720860174, 0.03516592922096606, 0.015759561574668624, 0.043481363682076335, 0.00705838147950999, 0.07254492797073908, 0.08614021993707865, 0.009025037106766831, 0.05128884258738253, 0.045078558250679635, 0.02957641987450188, 0.0593942232808331, 0.06833211926277727, 0.06387622008332983, 0.024443346192128956, 0.02628718055348145, 0.00928671652218327, 0.1072802890848834, 0.043216227713855915, 0.05781078813015483, 0.05886169892619364, 0.0783926880103536, 0.06849888726719655, 0.029313334089238197, 0.017824444621510338, 0.028239843450137414, 0.022110438367235474, 0.013482810209097806, 0.07222708096378483, 0.03434955935517792, 0.024887824001780245, 0.07886888706707396, 0.056810573441907763, 0.06997820280957967, 0.09420867878361605, 0.05849007218785118, 0.0956234942714218, 0.012155088534200331, 0.01194635393403587, 0.032504394694115035, 0.0217847394378623, 0.03478617967630271, 0.01564984802826075, 0.06955280376132578, 0.05767230708443094, 0.06818518144427799, 0.03399539906240534, 0.008528213766112458, 0.014889377653162228, 0.03874503658153117, 0.034741075651254505, 0.02234694969956763, 0.028663322191277985, 0.03760056322789751, 0.014199898341757944, 0.03047674890694907, 0.027810091705759987, 0.030075772083364427, 0.10975308803608641, 0.07383406074950472, 0.03801985069003422, 0.04788357960933354, 0.0387040626083035, 0.0073803436953312485, 0.00867356246089912, 0.03307307277282234, 0.038141466429806314, 0.07200998792541213, 0.0181379296554951, 0.03202355721441563, 0.11963337427005172, 0.04509750157012604, 0.02633579493704019, 0.015029017376946285, 0.02945692296634661, 0.02163390348869143, 0.04761479969602078, 0.012013462637696648, 0.0042602310168149415, 0.12477546319132671, 0.22004384722094983, 0.14086169219808653, 0.19581703003495932, 0.10968713337206282, 0.08722805258003063, 0.129972901486326, 0.130176606180612, 0.0984274766233284, 0.25114131916780025, 0.2978457708377391, 0.2701525599695742, 0.10181984107475728, 0.14030193473445252, 0.08888183219823986, 0.15147290483582765, 0.11647509061731398, 0.1066001107392367, 0.09151230784482323, 0.1521846541436389, 0.11723665287718177, 0.1255241417675279, 0.10982664229231887, 0.2695636509452015, 0.09591815658495761, 0.1229522364155855, 0.11622421501670033, 0.09273950097849593, 0.08861384267220274, 0.08649771247291937, 0.04671051130571868, 0.14657032181276008, 0.1155671248852741, 0.11388887665816583, 0.2060878195334226, 0.19305570633150637, 0.11501865548780188, 0.1698365475749597, 0.1145185370114632, 0.08707343353307806, 0.056792157047311775, 0.1372135168639943, 0.2005752653349191, 0.11296552620478906, 0.07958652902743779, 0.0808258043252863, 0.12554043933050707, 0.1430328155402094, 0.186985932814423, 0.09828863563598134, 0.10539009832427837, 0.11641272794804536, 0.13834834971930832, 0.16309274069499224, 0.10028291260823607, 0.12221390337799676, 0.09799735009437427, 0.18044416821794584, 0.07368439182755537, 0.09529971008305438, 0.33135617268271744, 0.2329371788073331, 0.10957318401779048, 0.09756386163644493, 0.1464047041372396, 0.28377574926707894, 0.16207973880227655, 0.06621408174396493, 0.17861872242065147, 0.12086970324162394, 0.2027527563041076, 0.25106366083491594, 0.06514334818348289, 0.16997350350720808, 0.10947418893920258, 0.11420873488532379, 0.1104861889325548, 0.08935931517044082, 0.14466466469457373, 0.15472621307708323, 0.15302586369216442, 0.22870197950396687, 0.20038975810166448, 0.12698658829322085, 0.1391732320189476, 0.1191060635028407, 0.15983729506842792, 0.179488564026542, 0.15364776860224083, 0.22843165963422507, 0.13990913081215695, 0.18554434063844383, 0.10047681353171356, 0.06238831047085114, 0.15921288169920444, 0.1792746176943183, 0.10218544528470375, 0.12527424580184743, 0.1297647290630266, 0.17558694526087493, 0.12908949342090636, 0.23584298382047564, 0.1408738040481694, 0.2244417995098047, 0.13673821580596268, 0.21476213063579053, 0.14550597814377397, 0.11888196459040046, 0.16488035180373117, 0.10980492705130018, 0.13923244056059048, 0.10281244132784195, 0.11038326047128066, 0.10412471427116543, 0.19351479888428003, 0.1760023698443547, 0.11506444599945098, 0.15587208908982575, 0.19555374572519213, 0.14946086826967075, 0.09244447501259856, 0.1051347995235119, 0.11089616615208797, 0.07218453363748267, 0.10177965377806686, 0.13599293626612052, 0.09042103905812837, 0.2422555405064486, 0.19456112320767716, 0.22230036207474768, 0.14245009602745995, 0.25465342914685607, 0.13170085876481608, 0.20214110787492245, 0.1721985958283767, 0.07446842631907202, 0.1521822198992595, 0.09258131220121868, 0.09629510081140324, 0.1436757974443026, 0.1426015089964494, 0.14023690775502473, 0.14444702246692032, 0.16013452521292493, 0.13781655638013035, 0.1034021370287519, 0.09314037204603665, 0.1722620049258694, 0.12418459489708766, 0.20661930117057636, 0.19658510835142806, 0.08413480332819745, 0.15964504913426936, 0.09869222296401858, 0.16078216780442744, 0.28966810496058315, 0.11485239956527948, 0.16386071511078626, 0.1393185742199421, 0.10559673450188711, 0.1672741788206622, 0.10996320488629863, 0.07901895674876869, 0.08344995687366463, 0.19155450485413894, 0.12452472117729485, 0.11724528405466117, 0.19733485562028363, 0.17650361638516188, 0.15232699806801975, 0.13971605367260054, 0.1431791522190906, 0.13536956190364435, 0.10769359854748473, 0.08450012552202679, 0.08914423335227184], [0.017895143464556895, 0.01939861962455325, 0.022014589994796552, 0.06394721393007785, 0.04209711725707166, 0.022963967567193322, 0.018866488608182408, 0.08302621281472966, 0.10401138832094148, 0.013458259963954333, 0.018595552755868994, 0.06964230677112937, 0.042697340322774835, 0.02514807478291914, 0.012796860737580573, 0.05326784616045188, 0.016449506583740003, 0.05937107198406011, 0.038841007408336736, 0.04886808674200438, 0.03134708960715216, 0.022134136997919995, 0.0186935960300616, 0.04932443334837444, 0.02683606740902178, 0.0472367162728915, 0.0405089657579083, 0.056558154174126685, 0.02848013045877451, 0.03806831293331925, 0.004550639432636672, 0.02188151549489703, 0.06163393220049329, 0.012791507069778163, 0.02760277460765792, 0.040598001214675605, 0.052196934484527446, 0.04731272332719527, 0.059176176582695916, 0.03475056029856205, 0.06613816745812073, 0.04193340319034178, 0.07799288563546725, 0.05491143980179913, 0.01027014382998459, 0.025630557975091506, 0.042264441872248426, 0.029795164191455115, 0.04834393381315749, 0.0836855145462323, 0.07984062554896809, 0.05062800832092762, 0.008086018060566857, 0.04479552539123688, 0.16558782634092495, 0.0529571757215308, 0.03618761053076014, 0.047108287617447786, 0.04015272745164111, 0.07504365014028735, 0.022245806103455834, 0.010249357201246312, 0.04513642350502778, 0.0215435674181208, 0.04747441504150629, 0.020775030825461727, 0.03428127434744965, 0.012248719740455272, 0.048526873215450905, 0.030802106448390987, 0.030197838677850086, 0.002000924760068301, 0.0388410370942438, 0.0568674664827995, 0.06748060128302313, 0.08117694407701492, 0.03561482466466259, 0.027693780466506723, 0.038527338692802005, 0.08437696611508727, 0.01832590267440537, 0.022207446345419157, 0.02519431243854342, 0.037515360963880084, 0.017760267401172314, 0.049882353996508755, 0.09300289661041461, 0.06725915183778852, 0.041069803046411835, 0.025472619672655128, 0.09536703772027977, 0.05161359527846798, 0.028032982772856485, 0.014641091220255475, 0.0673568704223726, 0.0036448120135901263, 0.04722139463410713, 0.031181078593363054, 0.014239773936424172, 0.03862539495457895, 0.009511093740002252, 0.03900355630321428, 0.04972466987965163, 0.048909198012552224, 0.03454956444329582, 0.04654425538319629, 0.021321253370842896, 0.033430684052291326, 0.04235696171235759, 0.053188863093964756, 0.039007886734907515, 0.0492080942785833, 0.05182808708923403, 0.05807024295791052, 0.009835548644332448, 0.03437336374190636, 0.02274883008794859, 0.03642788826255128, 0.04134211929340381, 0.03759114537388086, 0.04258070810465142, 0.040285664654220454, 0.033514453971292824, 0.011315862375340657, 0.021350551505747717, 0.03577271658286918, 0.014983501459937543, 0.0579900205048034, 0.07965613505803049, 0.05201802123337984, 0.0019314564906380838, 0.05202115680731367, 0.11278606747509912, 0.007982969927979866, 0.010363483743276447, 0.019171077146893367, 0.035726451096707024, 0.028328242515271995, 0.004131103814870585, 0.013894568583054934, 0.04660785743908491, 0.026944532291963696, 0.030746066877327394, 0.013190313111408614, 0.07812681360519491, 0.061293991457205266, 0.020064392883796245, 0.041434987942921, 0.05232030169281643, 0.01968433534784708, 0.0073579665513534565, 0.11584756022784859, 0.03801811035373248, 0.019218505949538667, 0.022500830309581943, 0.05371928717067931, 0.0285232677924796, 0.01318750315476791, 0.021741390592069365, 0.01527298543805955, 0.014737337569386, 0.04812013175978791, 0.04021793996798806, 0.07475113263353705, 0.0539148690586444, 0.09279634949052706, 0.07969996629981324, 0.04414872884808574, 0.10796788890729658, 0.05227782115980517, 0.09647334984038025, 0.0417486418155022, 0.032392619832535274, 0.010324106315238168, 0.03978176864620764, 0.036944820094504394, 0.03271667861554306, 0.03319505958643276, 0.04093121438927483, 0.02599442370410543, 0.08868246906786226, 0.03695214880281128, 0.14745365566341206, 0.029020135661994573, 0.026353300345363095, 0.032080001255963, 0.06119873309216928, 0.036321976367617026, 0.021605482943414245, 0.027987375942757353, 0.053929611822240986, 0.01745762328937417, 0.027367766124370974, 0.0442945645772852, 0.00135531136265854, 0.03632928281149361, 0.023960844446264673, 0.026264765838277526, 0.05017691612010822, 0.052588187318178825, 0.01513935711045633, 0.012797806048183702, 0.018728410177573096, 0.0030137823978293454, 0.016941160865826532, 0.024286088810185902, 0.030027226348465774, 0.02934758049377706, 0.05696369335055351, 0.026567196582618635, 0.03930394057533704, 0.033874599685077555, 0.05161663066246547, 0.03394343388208654, 0.019904281944036484, 0.044952749376534484, 0.015825493974261917, 0.047481547080678865, 0.09102117677684873, 0.03911288207746111, 0.03852888235996943, 0.06275669031310827, 0.035977909283246845, 0.09324900762294419, 0.04239216919813771, 0.060511389310704544, 0.04926145098579582, 0.04526557204371784, 0.025645972382335458, 0.08560495334677398, 0.016512889706064016, 0.04596539874910377, 0.02990720993693685, 0.013262157644930994, 0.09027858381159604, 0.09173552360152826, 0.02444063178700162, 0.02474550790793728, 0.08288849247037433, 0.022013029629306402, 0.03389078592590522, 0.06895603539305739, 0.035958413063781336, 0.07246913984999992, 0.0925471363007091, 0.03069166930799838, 0.014460497932304861, 0.029542505581048317, 0.04160737029451411, 0.008237757574534044, 0.0145188288843201, 0.024918396775319707, 0.07077061614836566, 0.03555771640094463, 0.012728096116916277, 0.09994942854973488, 0.03903565419022925, 0.020780711965926457, 0.025054211655515246, 0.04185088007943705, 0.04421433841343969, 0.047457067339564674, 0.10695309843868017, 0.05181870634260122, 0.06623815701459534, 0.08031122139072977, 0.038230520440265536, 0.03720125438121613, 0.02619176077132579, 0.0473786705697421, 0.042258382236468606, 0.020028717844979838, 0.005814955720779835, 0.09906531544402242, 0.005385972099247738, 0.05909456260269508, 0.05835311996634118, 0.022775287652621046, 0.008712482540431665, 0.03542679412930738, 0.018066028533212375, 0.012400118794175796, 0.01156084903414012, 0.01985192713618744, 0.029297446562850382, 0.031139421844272874, 0.07740287081105635, 0.00694299885253713, 0.02189887618442299, 0.04648403752071317, 0.06000101064273622, 0.0474822038813727, 0.03643190328148194, 0.04933067109959666, 0.015062593993206974, 0.0244754496452515, 0.06862829555757344, 0.019526350661180913, 0.06817645378760062, 0.03586765211366583, 0.0324246175296139, 0.05172791199584026, 0.03432027420785744, 0.023771830565237906, 0.010061968623631401, 0.018745906309050042, 0.01945504696777789, 0.03278318246884737, 0.038147860032040626, 0.023432138441421557, 0.057335579840582795, 0.07042330587864853, 0.007308686090254923, 0.09054554917383939, 0.010061049288196955, 0.005693820521628368, 0.059412012560642324, 0.0663253445236478, 0.06137533826404251, 0.04453960318642203, 0.01919261056173127, 0.0255919829942286, 0.024055637113633566, 0.0970665633212775, 0.04388819419546053, 0.04522511386312544, 0.0666032565641217, 0.09504344649030827, 0.04187919301330112, 0.01453714323361055, 0.03904418888851069, 0.022719500411767513, 0.04299554268072825, 0.11972982378210872, 0.0529609384102514, 0.06377024139510468, 0.03203842614311725, 0.03167290356941521, 0.029232794367999304, 0.04933688658638857, 0.06400261525413953, 0.03821277197857853, 0.01821964939153986, 0.07527325578848831, 0.10476569979800843, 0.017640666592342313, 0.059164343037991785, 0.01816406067518983, 0.02278891533933347, 0.04585923452395946, 0.00772145610426378, 0.008109663813229417, 0.12104983732569963, 0.11788120813434944, 0.11734580795746297, 0.11628630309132859, 0.17043295229086652, 0.0943000742699951, 0.3605540137505159, 0.2071774407522753, 0.25115123426076025, 0.1056779180362355, 0.14119242288870737, 0.1844550608075224, 0.10761031473521143, 0.19551843433873728, 0.10949495423119515, 0.11945744074182585, 0.10072310265968554, 0.2103356650331989, 0.13495541381416842, 0.14206993830157444, 0.13677777227712795, 0.09388665348524228, 0.12886178767075762, 0.09066695711226203, 0.14710932882735506, 0.13353130663745105, 0.1573318341979757, 0.11985207776888274, 0.10220367243164219, 0.10829725404619239, 0.10104215194587596, 0.115891910973005, 0.15032324386993423, 0.11376532391295768, 0.09812775286263786, 0.11281478859018534, 0.11610226531047374, 0.11143513605929911, 0.1997917948756367, 0.16089994664071128, 0.16032165032811463, 0.12255522451596335, 0.13231075572548434, 0.1159103459212929, 0.13654644484631717, 0.09113482927205041, 0.10439690435305238, 0.13907896442105994, 0.2092589868698269, 0.14692379190819338, 0.16921021946473047, 0.1359518658136949, 0.27905203867703676, 0.17887176509248093, 0.24834444659063593, 0.12684164685197175, 0.16355866100639105, 0.11891564325196669, 0.1604025295819156, 0.18597830407088622, 0.12521436932729557, 0.12289126156247221, 0.18398366344626993, 0.08321526009240188, 0.12022237977362238, 0.14659772190498188, 0.09610567503841594, 0.11020928621292114, 0.171208348183427, 0.14616010710597038, 0.08981724255136214, 0.12786465289536864, 0.09055227303178981, 0.10276627974235453, 0.13593605806818232, 0.1666288368869573, 0.16241373494267464, 0.12936198036186397, 0.12564836244564503, 0.23784740595147014, 0.10092127835378051, 0.11260090162977576, 0.1515971848857589, 0.16919007757678628, 0.15856273064855486, 0.13305642118211836, 0.1443729264428839, 0.24528038600692526, 0.16560563788516447, 0.21560792665695772, 0.23739821364870295, 0.08371528951101936, 0.12339006643742323, 0.18154443183448166, 0.12760435201926157, 0.14878284215228632, 0.11978990063653328, 0.2739120426122099, 0.07127861623303033, 0.10719704237999395, 0.14170763664878905, 0.15537501341896132, 0.144374099036213, 0.2198316968861036, 0.09713022474898025, 0.1351699241786264, 0.1556215697200969, 0.12480802863137797, 0.06254790932871401, 0.11881804341101088, 0.20599969691829756, 0.09743123984662816, 0.1604818503255956, 0.129152427543886, 0.10857143308385275, 0.10659124949597754, 0.11115427027107216, 0.24765269074123353, 0.1723264530301094, 0.1416524950764142, 0.22332519380142912, 0.10897111671511084, 0.15623082843376324, 0.1082376076374203, 0.14356625644722953, 0.210907178116031, 0.09058418538188562, 0.14287929487181827, 0.19711317610926926, 0.1907157147070393, 0.12363513102172874, 0.1677391937118955, 0.18622566189151257, 0.14035737316589803, 0.09607806714484468, 0.10965020410367288, 0.07603191625094041, 0.1546948796021752, 0.061759848686051555, 0.15575224708300084, 0.10189487962634303, 0.26387209072709084, 0.1796150259906426, 0.1031342959322501, 0.11299925681669265, 0.15762839640956372, 0.15022483508801088, 0.2160027640638873, 0.08414244744926691, 0.24545465712435544, 0.10766922641778365, 0.14850321575067937, 0.09514155841316096, 0.10614460275974125, 0.07827677196473815, 0.11582680235733278, 0.15654386632377282, 0.13189175399020314, 0.12394278091960587, 0.1975948893232271, 0.10222625598544255, 0.13289403927046806, 0.15636355412425473, 0.21954230382107198, 0.1144970889436081, 0.15212473314022645, 0.1541989913675934, 0.17643508646870032, 0.16250639950158074, 0.10092852913658135, 0.2663046430097893, 0.10680822379072197, 0.1218876923667267, 0.05856161151314154, 0.10303520437446423, 0.1391030990635045], [0.036250514967832714, 0.028762487963831518, 0.038864589150762185, 0.035226247273385525, 0.017538639840495307, 0.059010373370256275, 0.029532187872973736, 0.06162144185509533, 0.070716008922318, 0.027108198119094595, 0.03511812748911325, 0.004880810729446239, 0.004224377862556139, 0.06071123483707197, 0.023674182484683115, 0.01054113812642754, 0.08879025117494166, 0.01246088770130882, 0.024698155175428838, 0.0762529500934761, 0.02688917549676262, 0.013027578679611906, 0.023936036304803565, 0.05664538621203974, 0.03225941916753072, 0.01765332206559833, 0.05284554557874799, 0.03985469578765333, 0.023081325234670658, 0.11040696466807276, 0.020094240207981784, 0.03858436903101392, 0.0451609403535258, 0.07791486365022138, 0.04630175491911359, 0.01515629941422958, 0.009685891782282852, 0.04578753563691862, 0.07863309932872653, 0.09120223112404346, 0.06186961974890437, 0.01700418219115818, 0.04274216233170591, 0.08821115334285423, 0.03489401744445786, 0.04908464914478827, 0.0318890689231921, 0.0411733437795192, 0.07469390562619083, 0.009664179324317956, 0.013377470695559168, 0.006115435080573661, 0.027391923031245824, 0.017781157002900727, 0.051315181408426724, 0.04767313250340521, 0.08626947979792021, 0.01743391538184369, 0.05627597478451207, 0.029563914686150383, 0.004305495995140518, 0.11172499667736702, 0.021413446665974334, 0.03163629713526461, 0.0675165731809102, 0.02016224134422373, 0.02881054944737116, 0.026210997239104472, 0.07917903800262138, 0.05281157747958787, 0.036911404895363376, 0.05356267545721494, 0.07224722285172902, 0.0998146396887023, 0.02871402943128487, 0.03795341734075919, 0.0233772640422103, 0.0066485401657701, 0.05238197045400739, 0.009758503510965966, 0.04232281178701669, 0.01733426164719276, 0.019072534778388217, 0.05318963492754847, 0.12984410917852074, 0.013124851047905395, 0.06160961573186796, 0.04486596262722742, 0.039499518752563745, 0.05892861096072011, 0.04065941393491812, 0.061266253687790595, 0.05097881039546337, 0.032018647907534614, 0.033044110459741205, 0.047022884973557666, 0.0788687015301548, 0.03457890525169205, 0.03650145365099888, 0.06390084454324096, 0.05163268702744972, 0.05005512597563211, 0.07912728804512881, 0.05806584202218801, 0.028211443313921336, 0.02723502188018756, 0.08473476293147542, 0.041056481495616026, 0.04177901049843058, 0.03870657106745057, 0.05721127752622124, 0.020873215107712895, 0.036753256936208345, 0.022247975030040834, 0.033741272854967974, 0.050666503520915285, 0.023201510484796017, 0.013347533385967836, 0.059305759277776815, 0.028438946828828193, 0.010371530479460489, 0.0662746855232399, 0.046310504840221256, 0.035650332720251754, 0.03744572153664194, 0.06885281749418937, 0.09663349788752384, 0.024567876716901083, 0.014589928487112047, 0.04505021934164688, 0.034808325362973846, 0.03578601586923469, 0.03951482554839458, 0.08558671877835877, 0.02372512721194653, 0.012280652499612188, 0.0704558267898392, 0.06632877324591391, 0.07967822137288749, 0.03166472139128018, 0.005714350645575905, 0.047037011754582636, 0.026185452516074292, 0.019493625659379177, 0.04097153898328543, 0.006940479725017212, 0.0536557481973432, 0.08311898869578727, 0.06775024579837918, 0.04289345284632873, 0.03572418754629325, 0.08784950478002429, 0.004217876648908714, 0.0592066120589152, 0.05402795010013506, 0.029151421585993376, 0.035052952080150135, 0.025218589944415726, 0.05651654566463549, 0.016450170805910602, 0.08149503599270247, 0.04335235986218322, 0.02850795728591038, 0.032878251586225815, 0.016689762051100843, 0.042015532962977886, 0.023394441050186288, 0.03656065477116499, 0.07221743304398842, 0.034246196737512946, 0.029766632324026432, 0.04895368234429043, 0.01712101849989267, 0.02258623109810287, 0.052798226242884994, 0.05095381486171391, 0.014957713683543261, 0.0828038876352366, 0.02566862829553429, 0.02695516170206247, 0.032411095598945394, 0.03659724636236206, 0.021359718884923495, 0.02796871278405888, 0.0723942051990889, 0.018676790095923934, 0.04384090825624298, 0.024992479811771773, 0.07973424610099755, 0.051206219286541454, 0.07217448495794088, 0.02998299434693763, 0.08887928663170896, 0.017331760609522462, 0.0065628898300928995, 0.07576149990200065, 0.025266026168537792, 0.07696217609918676, 0.023258648434421048, 0.027346746646799147, 0.02784686512313783, 0.04784302866028156, 0.020732181073981337, 0.03177049227815587, 0.047745866686454974, 0.04905567941023037, 0.006745309729012661, 0.045478156534954906, 0.025729237640916836, 0.07978359150001779, 0.1141082777758129, 0.032098428782774135, 0.04133759961405303, 0.014455867858487181, 0.05318776471540332, 0.04641388230083976, 0.02097790245898068, 0.03742862987564877, 0.010412813371658558, 0.03271353562013246, 0.029429190763039514, 0.0465834927308606, 0.04242923576384783, 0.04375992881250568, 0.04782375137438066, 0.04326300528191496, 0.012338325723249, 0.030953048153605778, 0.035564885547501035, 0.039329414794337936, 0.008563912924728356, 0.023783601027389523, 0.05377719324314967, 0.026963037744280882, 0.06573262086021714, 0.020182546504656784, 0.02327593490917934, 0.06217900998308323, 0.03658211026049685, 0.07823989464668557, 0.0302692555487738, 0.035525581406545825, 0.011275005290372064, 0.06878027998027392, 0.035005866520805284, 0.058075467677554116, 0.019813966282526962, 0.048657546867616475, 0.09837674340815283, 0.02461087304254761, 0.020301288277551066, 0.08679124672198668, 0.004556460653475369, 0.08590314086177386, 0.024957582172646653, 0.04458080722542945, 0.12727618915960193, 0.002956554694719671, 0.05912026317673735, 0.061644251763937064, 0.034974733425769955, 0.08111111557809636, 0.01723383607895812, 0.07555839634733275, 0.018619731927174143, 0.05426876217825338, 0.020692704383691307, 0.034551531134638935, 0.048924256188911386, 0.0488476108876057, 0.022406165662687272, 0.07679864385863766, 0.06417261902242899, 0.029792791174259037, 0.0004587486137097585, 0.011560303555597784, 0.04902855391264893, 0.013328586355783045, 0.05747399038227741, 0.039638181624468416, 0.06214964319951832, 0.04370716582343448, 0.017544510228617582, 0.02408955326245632, 0.08472373461700045, 0.04601111504598521, 0.09763865527929738, 0.008100065988401184, 0.04227805657137651, 0.08171113455318846, 0.062260364211397246, 0.06499776849523187, 0.027757462303270586, 0.008330724558618385, 0.0335451120918151, 0.03498146099445876, 0.03342373012856115, 0.035953911938122474, 0.02759682814939879, 0.09486763170571066, 0.04034395293274429, 0.030420419898291584, 0.005724089478462702, 0.017810724166338332, 0.0462765218981076, 0.041436546453041956, 0.08421173435635865, 0.01086632682927302, 0.02318914073839551, 0.13620156882097945, 0.044237066686037, 0.04938392390613444, 0.08535901302821003, 0.03114292849204503, 0.03422790650802199, 0.03832781600067392, 0.01302197175391484, 0.11740316112991422, 0.05660863134835381, 0.020023576616949867, 0.010708209483709652, 0.02710442615352804, 0.013829997096763691, 0.008123636598611483, 0.01397844054736197, 0.07774485246045515, 0.03511107337544672, 0.054358951674657874, 0.013667414805240696, 0.05595685499429237, 0.05332362597982865, 0.01292823200856219, 0.024338580915355124, 0.0538999518903438, 0.020902980795654003, 0.07936190319014713, 0.032574935830780305, 0.026376345886092167, 0.053176721557974815, 0.029763205457129516, 0.05954091619059909, 0.03166758608131204, 0.026544648280832916, 0.06032732555468101, 0.012876943110313732, 0.03976668078394141, 0.0658615467546042, 0.05367352263419889, 0.018284709767613094, 0.07567043096059933, 0.13028451445279643, 0.04610048075846862, 0.16506571060745046, 0.17779734305804595, 0.10842885909369215, 0.1733070527552627, 0.13991765066748485, 0.13527798088034615, 0.0655145630298648, 0.16989735915558413, 0.27715424832422286, 0.11391609121346846, 0.1751524771680124, 0.09336651928606443, 0.11727047996828333, 0.16770582675235346, 0.1503404468530789, 0.09119284295593388, 0.15426502766786143, 0.12821006326703355, 0.07879638666054234, 0.2244531098403968, 0.14270965475589037, 0.16381249035475776, 0.14438196580158547, 0.1149124393123202, 0.08284818643005565, 0.14195432653650641, 0.222484162368346, 0.10758949749288149, 0.26195916056167334, 0.1229596727353055, 0.08994584190077148, 0.17141864314908162, 0.1982083634356968, 0.31517928291577846, 0.33682271372526884, 0.13133999687852338, 0.11557502875803038, 0.11729226942406967, 0.23196413414552808, 0.107754001946887, 0.1537209888920188, 0.15756115783005953, 0.09241102641681209, 0.180448739847634, 0.11401956886402331, 0.10931933982647024, 0.12192431735456921, 0.12734727206407115, 0.2418471366399899, 0.15115522110136226, 0.16437258920632303, 0.1366196948220022, 0.17250324744964018, 0.14895565866027027, 0.11182591391843744, 0.15600336017087102, 0.15347236942034215, 0.1248401784687303, 0.1634527268470265, 0.06934066826943308, 0.08412039824179374, 0.20631224499084055, 0.10727425542427227, 0.18887722195358947, 0.21080259466543794, 0.18462814448866993, 0.10656897764420137, 0.1997305083204992, 0.12641353154322132, 0.0967589060019236, 0.15206313488306478, 0.15279512997949496, 0.219611486827489, 0.18859538395190611, 0.1842360381851904, 0.2198709119693376, 0.09650511376094073, 0.14363358408445492, 0.13021549471886829, 0.22205775399925187, 0.31025355972815305, 0.08479901065584272, 0.11503931687911972, 0.23617892438778654, 0.24074230139376596, 0.2154974505538121, 0.12054721039021388, 0.16121666558319703, 0.11693884385749698, 0.1303339414880611, 0.09027848733239807, 0.17595224519027397, 0.12575530592584983, 0.13464816467603669, 0.0796444017032627, 0.15345245017670095, 0.16978995554381981, 0.1505686275777407, 0.1531386552960612, 0.1874220187892206, 0.17756852408638224, 0.11000046812114306, 0.16826260078232735, 0.2047457345179282, 0.19539313012501225, 0.13721817755140364, 0.20074168452993035, 0.14444479602389038, 0.23266543401405215, 0.1278384996112436, 0.1953593920916319, 0.12595761538250372, 0.1288008425035514, 0.14239697309676558, 0.16815123410196975, 0.1742008063592948, 0.11345385937602259, 0.1260710007045418, 0.23300544155063108, 0.1210607543180231, 0.10469388958881609, 0.12678301718551666, 0.12233036861289293, 0.16582575888605788, 0.1251398873864673, 0.20582843892043456, 0.26941542921122164, 0.09579717167071067, 0.1484787545632571, 0.1769351604161784, 0.15273848926881328, 0.11445486816228367, 0.07432860569679178, 0.18185868684668094, 0.07672649968299083, 0.13382013567024842, 0.198538351978641, 0.13665280945133418, 0.2533679996849969, 0.099213292269269, 0.08679015576490201, 0.266135967685841, 0.13957143877632916, 0.1038828854507301, 0.0800658822117839, 0.14324217539979145, 0.12967081769602373, 0.1332108027418144, 0.17714852787321433, 0.19603577064117417, 0.09492663244600408, 0.17207799683092162, 0.14211035566404462, 0.19061680126469582, 0.18754341930616647, 0.11260836021392606, 0.102988115104381, 0.16695876605808735, 0.13012884155614302, 0.13555011159041896, 0.14213267946615815, 0.1596529158996418, 0.16915622079977766, 0.10866603464819491, 0.11036291820346378, 0.13973322696983814, 0.1462700785486959, 0.09694674357888289, 0.1398242884897627, 0.09809735449380241, 0.13657096540555358, 0.10991241229930893, 0.10081516607897356, 0.1872843355522491, 0.20389946352224797, 0.13133015600033104], [0.01775957534846384, 0.028250571194803342, 0.0015977401631062094, 0.03952369421313051, 0.03015455662534805, 0.011720666825567605, 0.051337007971596904, 0.019764465032494627, 0.014528375686495565, 0.014232857120077824, 0.05207517773669679, 0.017577597027411684, 0.03067770208872389, 0.054453215561807156, 0.06873086778796278, 0.03389824451005552, 0.0274017991614528, 0.08010181700228713, 0.05034125359088648, 0.0656533298024442, 0.021145742866792716, 0.048473167698830366, 0.03749928604520392, 0.053206845332169905, 0.04023796682304237, 0.027988700676360168, 0.05311718276061583, 0.015325621334341122, 0.030336564632307272, 0.019267376374045853, 0.056230807676911354, 0.053804192575626075, 0.045769560820190236, 0.07448163654771633, 0.037836762858205475, 0.07613969093654305, 0.037033436237834394, 0.04536568034382071, 0.029962767112010624, 0.065662139095366, 0.0606946515472373, 0.04395617492264137, 0.036236273153917864, 0.06459455966250971, 0.03070947714149952, 0.048384206456830725, 0.027845686963701155, 0.02541704579925863, 0.041911802982212976, 0.019217125554860104, 0.07667796322493814, 0.035335198263055645, 0.0845481276337523, 0.03675739440950565, 0.0478725438733818, 0.0614990134636173, 0.04106106425751932, 0.052453520911512896, 0.010191883429797599, 0.06575495208380744, 0.018583708078949712, 0.0594977343280334, 0.05910542022320442, 0.07092542815371417, 0.050794642738765106, 0.02353730633330997, 0.036634138523368165, 0.02199778777139727, 0.03721570399648044, 0.0492155528627336, 0.017331886774627492, 0.02427896048175171, 0.01604191722435644, 0.05864619779458735, 0.06205599900567904, 0.036689016633317806, 0.027191982881049626, 0.02175271019950742, 0.10315787396393716, 0.016914070620259736, 0.045681586634600535, 0.07303728358238004, 0.08482578734401613, 0.055819828558014706, 0.03265015620854683, 0.06159431635751389, 0.006144160834082868, 0.0863358129572589, 0.01629260728805093, 0.052342811031849124, 0.07468327807146125, 0.018060397487715818, 0.029983686399646103, 0.006413844312191941, 0.03963470837334171, 0.08369900679099374, 0.03668916877359152, 0.03949855767132249, 0.011050206903746584, 0.03897647533449344, 0.037290148829924874, 0.03513475530780852, 0.03021265751158353, 0.017003807406581473, 0.11654696019832045, 0.04438604912138544, 0.02383507824561093, 0.026871100490097888, 0.04170700362010393, 0.020324192810221575, 0.08908863906981423, 0.011926464376301738, 0.02956471620564116, 0.010181627876590937, 0.018778319608827587, 0.08277678440208547, 0.013940850767539814, 0.01941938306117663, 0.02186485242418712, 0.05860702724021394, 0.042522701842244714, 0.04217238587443717, 0.04251293146808166, 0.029439681020448916, 0.042621095781214535, 0.03719674212334212, 0.029452037779265083, 0.02808311299304478, 0.03265161081799306, 0.09352239256259054, 0.020501605067693163, 0.030881221246090718, 0.019555268445401452, 0.012203992355352966, 0.05427379765023943, 0.0694289690000005, 0.033614135536481626, 0.039899610565043986, 0.05256155534880236, 0.08709614325198345, 0.044711759182973765, 0.020113625105295796, 0.02821338774083415, 0.0101334328064695, 0.030977409151091706, 0.02059619735518936, 0.02327402758965036, 0.005567797352341586, 0.08302424612338655, 0.01632411702303216, 0.0014008231050866016, 0.08937469989177771, 0.03188877577485982, 0.036926793327438645, 0.020159920277365018, 0.014130002873571357, 0.04714962895377539, 0.0774144780007191, 0.009544394833937986, 0.033761997328838333, 0.07682519048103131, 0.03536995303875301, 0.014488432370853843, 0.028613689210033044, 0.030755458756175358, 0.05588904125033878, 0.02363969117141096, 0.042747650513774715, 0.04809338475752156, 0.04624403809430078, 0.05815737480588723, 0.026138199973502196, 0.09691653816844337, 0.06663011488853954, 0.02531485206418438, 0.05043599987402558, 0.04413255002873484, 0.05715347906516399, 0.08597072825068608, 0.03225039836252108, 0.016695639860699885, 0.034502404669183306, 0.02530099060095381, 0.05804983389680274, 0.057027866860153154, 0.037043180636828765, 0.04072454852575902, 0.047583748237229884, 0.07213085409603082, 0.04501029921812005, 0.0395476655830862, 0.045387358477455564, 0.05597817318630405, 0.07564325351268053, 0.08808658385532908, 0.028903150923724752, 0.03986254028859548, 0.015894830976321828, 0.029340956825762987, 0.03206218600098509, 0.04876329920080025, 0.04906316025881097, 0.05069812272267882, 0.03820728379650973, 0.017102650344895665, 0.04110308094823267, 0.007304173832380911, 0.07232067320728675, 0.014472941893473035, 0.04951378490659408, 0.032746004580985755, 0.01738695598760387, 0.04456665817997418, 0.05201553132792469, 0.03279349832155276, 0.004623419072231627, 0.06351866075419821, 0.03152403987769503, 0.021616490848828107, 0.028411589410097804, 0.05422906098829117, 0.051588213827926666, 0.01646231976337731, 0.006412110933524673, 0.012266445937711978, 0.009130359921982745, 0.016348544813808985, 0.03358253859914839, 0.05294163514918182, 0.06395058328052983, 0.062156793792382814, 0.04564250513794832, 0.023410599460476078, 0.02552316178480396, 0.06494465298601426, 0.06764147663488984, 0.032288121728925034, 0.046446492269751616, 0.04347452850197442, 0.05702234157070052, 0.07135848616599105, 0.00447094947048754, 0.015497293079533847, 0.020244079823896755, 0.022622863507422153, 0.04263454720785376, 0.04462904682441149, 0.010289723541063722, 0.031708975657238625, 0.021073619100206997, 0.043489018935360946, 0.009598631913831923, 0.022909757390152663, 0.05120099456689786, 0.03502219005895313, 0.039896753296488896, 0.04093953386473004, 0.0581318412150722, 0.04910891366307624, 0.038720326774637215, 0.04907218106382061, 0.0037855953405596665, 0.013739869755227119, 0.06558408742421307, 0.01206285163789289, 0.03079802463616943, 0.03166670292557683, 0.06480732597992755, 0.01027495109156007, 0.030596676260756794, 0.060196919075679034, 0.04999322714866139, 0.0462642616184894, 0.048655090358806774, 0.060333333240123466, 0.05103637508000247, 0.03592427798139397, 0.037334399385144934, 0.09998478446505032, 0.026216288752038963, 0.09536057361401618, 0.03901602067344356, 0.04554497209028341, 0.019360048354428727, 0.03282757032138761, 0.022562586273124907, 0.07816258512320928, 0.028078355826437473, 0.04129669243411627, 0.01754611512296833, 0.01661827653151704, 0.07325522266910411, 0.08052003206103109, 0.032429341299575754, 0.019319033563078847, 0.015532712077401811, 0.05151326062332373, 0.035661765505210496, 0.018008187398663722, 0.07990883634192869, 0.13525277754524723, 0.027485042155603878, 0.009658838644099887, 0.02162645418138709, 0.06714810428093188, 0.011205562532268232, 0.045288563778740354, 0.014355750281538349, 0.026571397138468456, 0.025574334722477943, 0.010433389415993588, 0.09465045703109354, 0.025211392967321444, 0.016043269788497128, 0.03815930394921452, 0.06778354596463032, 0.00910778193428996, 0.019765806464420166, 0.08669556904351339, 0.023124366089177784, 0.10879844121518545, 0.030308719251479488, 0.08138967328704894, 0.01070402469849796, 0.05275584589981008, 0.0697712400869932, 0.04535298219707329, 0.05450642383948434, 0.06004224807838909, 0.07341893302509561, 0.009214889614668209, 0.01682566598901758, 0.03362440686032642, 0.03910751634975895, 0.02423310317681171, 0.04079328624357004, 0.04674148483900353, 0.02908698832470691, 0.04396155178255867, 0.014755419997527497, 0.013344850522116758, 0.015372515790659236, 0.05247865374258254, 0.07231907758978195, 0.0412440556101501, 0.025410770940652583, 0.05163029731193092, 0.06343171815387905, 0.061162468045949936, 0.06942950334632769, 0.04593043246131856, 0.012713372834696202, 0.13744080701144412, 0.23736636067042127, 0.16258883726550266, 0.1249775500036776, 0.0801503608818166, 0.10725049927714281, 0.13079975789878517, 0.1169789420964662, 0.16795468371128663, 0.1559770733001642, 0.12846236379118636, 0.14645712944911793, 0.12700236635282636, 0.15711229207227007, 0.14976890408433974, 0.09852526200120337, 0.11509163829032332, 0.21012103592511266, 0.15636684925993904, 0.15207345073577017, 0.14159987680613995, 0.06805382872698829, 0.10993677700753324, 0.13901157741202042, 0.15444557735463604, 0.21525568852666765, 0.1894095347961411, 0.12808789091650397, 0.13200079032685608, 0.1525523586315103, 0.16865194629644975, 0.13617074000649154, 0.1102494883525651, 0.168908046616707, 0.09129439844400622, 0.2040702020167373, 0.18321997864404693, 0.17085885599954054, 0.1182272270671092, 0.1151380522060208, 0.1905459855333902, 0.13132503518136218, 0.10750268105766736, 0.12521561613539234, 0.14197440905263647, 0.14053054590476677, 0.1383045778493397, 0.13964741985546425, 0.13734938926063478, 0.0910251472669188, 0.10909567878115922, 0.09871185277006589, 0.193786098388955, 0.14184505271259695, 0.1689499185886234, 0.1414443226531148, 0.24655971501488239, 0.18535944196628407, 0.13949847081676126, 0.16310914215864614, 0.07528161979280412, 0.1217237593664322, 0.14846737001789734, 0.1273673100513406, 0.12211999943247065, 0.18579570605652407, 0.12078468280378729, 0.10263909789500758, 0.2171170394285582, 0.11278367775958031, 0.14038211636943743, 0.08423808802035637, 0.19761783652938902, 0.12125075896619819, 0.14303455216577277, 0.0791883519559633, 0.07235720913740806, 0.2161758329020813, 0.18547103129094467, 0.11442976130638272, 0.17981126467930153, 0.16140984662342817, 0.16130302188685164, 0.07778482453431934, 0.15056513948366046, 0.1545464649097994, 0.16730871837353334, 0.19041535269934684, 0.10621130699291825, 0.11403274198528379, 0.15385647537186742, 0.10930886070127599, 0.20959430403308943, 0.11698754358803853, 0.12743088242132217, 0.17266810813453048, 0.15578974038362503, 0.17211247701197863, 0.1857073014252819, 0.14906322554452345, 0.16172720381291583, 0.1551453780848533, 0.1727366677368991, 0.16069195233285427, 0.23968432535184547, 0.09223066968843341, 0.17957101663341746, 0.11463517294032499, 0.11418787311413325, 0.09992222883738577, 0.17347712331684306, 0.04953028656018432, 0.11611168316449039, 0.2215371819329448, 0.14233377180062234, 0.3598385240184143, 0.17073879134841263, 0.19134325993945822, 0.05926482983340975, 0.10626201794366352, 0.14229826745577157, 0.24066495476290584, 0.09411219958565198, 0.1794716133736074, 0.14805660612182692, 0.1058364704658743, 0.11708901001838967, 0.07959679292980582, 0.2112874694284983, 0.2258593906299211, 0.10695784818381071, 0.12130435687140562, 0.1205327088246122, 0.2118617729865946, 0.15860622050240636, 0.2054444220266305, 0.1536129173473455, 0.14902614784659818, 0.12748762703267857, 0.1510385554865934, 0.15562786313239485, 0.09588951710611582, 0.18694799422519282, 0.08835819506202824, 0.21056599798612297, 0.10978627688018605, 0.18105317460140213, 0.07845240121241659, 0.17650392808718607, 0.17226647265488282, 0.1630703278351575, 0.2019439489231445, 0.17299546947469935, 0.15923343918984756, 0.12421994339092635, 0.16949915239820257, 0.14094637124799192, 0.1643454859731719, 0.10618939137202688, 0.12090728559996933, 0.18377924629021436, 0.08843901494401507, 0.1380132552003488, 0.15830927237402648, 0.08803165008430369, 0.14201369835063815, 0.07780989428283647, 0.18025325814960524, 0.1326424363651313, 0.10479079923243262, 0.16282178257824853, 0.15310856862924993, 0.17110204295022413, 0.18972852471051738, 0.12716375378658995, 0.11993309803074226], [0.026593704242259264, 0.01538909165901714, 0.03974180028308183, 0.07333484769333154, 0.07933187589515, 0.0394819112989353, 0.04149605185375549, 0.05273682465485763, 0.008744961705815513, 0.06446354833315127, 0.032135610381374136, 0.012892631184513448, 0.03277497431554366, 0.03687777447339613, 0.035181009661755525, 0.058065585981239565, 0.011436048553150613, 0.04159762589551974, 0.07411533471895382, 0.018584949320938904, 0.038338836893672124, 0.03802831859502476, 0.021530474077735562, 0.04532072474830784, 0.028094879744458012, 0.03148170406348072, 0.04863508576818276, 0.008500870262651006, 0.029185977837187238, 0.03216481760318857, 0.056920752685982734, 0.03469463947112672, 0.051777057014987804, 0.06374825155944563, 0.05308777886966709, 0.046497592848027125, 0.1002783484000247, 0.03639135975390673, 0.028980991082789842, 0.02249337914690841, 0.08257168447016738, 0.032941527097136714, 0.0476036637701327, 0.055912552488734946, 0.02765964723948855, 0.019966518448200077, 0.039307324768742546, 0.055702246390865184, 0.019434469068073668, 0.040072939154924825, 0.04126993801037315, 0.016707393624528777, 0.012020310805382906, 0.027987398207187653, 0.03576100920327008, 0.0428845619171625, 0.012070585744368145, 0.05854126553458627, 0.06203151184308808, 0.03450837524724193, 0.008165137496689567, 0.0023329050418396946, 0.011673127628455404, 0.0918304368678946, 0.01518718667284702, 0.023927455222292338, 0.046669648654642515, 0.05765599096775986, 0.03901028758264147, 0.03105882089585066, 0.04686153093643952, 0.06044533816748299, 0.01695144146651728, 0.02620126397232525, 0.04667247623729054, 0.04373143405246083, 0.018857714567275252, 0.0424854126322316, 0.04908927272481378, 0.013518111391022103, 0.01216095150084584, 0.03181956308253575, 0.03783548265346326, 0.04457325216208119, 0.06126931133621838, 0.04791597064468078, 0.011046752206311794, 0.06229692240594886, 0.02245052754005883, 0.029832377331331372, 0.02151977787434589, 0.05376117398554925, 0.03483112042886205, 0.009218699615303194, 0.03970499717979692, 0.037264273851178586, 0.035255877519375645, 0.05210959483520128, 0.07152642676373944, 0.01731994005240267, 0.019705568192875944, 0.003695967789099086, 0.030654983092972543, 0.03151709708618, 0.03875806869473308, 0.012689882005361142, 0.030333596041600686, 0.064297351782443, 0.037731645061285235, 0.029099426719767507, 0.028290073860262055, 0.016302025142067578, 0.05936609217314981, 0.02313306220457889, 0.03969112643972039, 0.0451207716105273, 0.03464874505880289, 0.025523473486828152, 0.015249940825015074, 0.042726751635200344, 0.04251145088346675, 0.06049612333299592, 0.04377738412586041, 0.01704006874206243, 0.014187354190653423, 0.006378446187227382, 0.042548168639768846, 0.0160384513947065, 0.1033896541048307, 0.03201383507985156, 0.04894779711321462, 0.049062321631936356, 0.028153362836746965, 0.019251898884249385, 0.05213939948589541, 0.11101712138042785, 0.08787704588030465, 0.05652623440255411, 0.03977832879172638, 0.011246004942222498, 0.02816369538777508, 0.015514089736825554, 0.03606902275350876, 0.02039346487435978, 0.03823903658485506, 0.010137510907952674, 0.004488314334594179, 0.02763392069027759, 0.04723451580503024, 0.07113412750186399, 0.02998380885401275, 0.033149666123790666, 0.047086906342883594, 0.025659774473751895, 0.028376988630043343, 0.002782194055725995, 0.024722677590034436, 0.03580470314773265, 0.04823237417440396, 0.05721985304262489, 0.03947030410927255, 0.05403115617809817, 0.02599211933556944, 0.05401169335527811, 0.02281393313751323, 0.09629995445720851, 0.047383119745063595, 0.03649103018688038, 0.01456602298276266, 0.020922259936924092, 0.04169244639342651, 0.07850521244108677, 0.009818866092246026, 0.10648309631505981, 0.005919082286709454, 0.07743341760942712, 0.04551125632133335, 0.03851489287626464, 0.03511451322992798, 0.04137716721743345, 0.03430778386245947, 0.07442307367455214, 0.019166774545738008, 0.01930951366375666, 0.01713871501124231, 0.047461612994084135, 0.042931547286571003, 0.06540889604366384, 0.051329608759260736, 0.043256678472971544, 0.0177921185240848, 0.019405434395594057, 0.013206157964305021, 0.07812348136212677, 0.013237799430498853, 0.027626603114185855, 0.05392674713220913, 0.03749506693566218, 0.015628795154043473, 0.045330394932534546, 0.04638894242816605, 0.0041777714523050236, 0.021425922168418765, 0.029718105142819695, 0.02673219085409073, 0.04359271923021879, 0.03647017583716661, 0.018230100686196238, 0.015309710615838412, 0.0785063330840785, 0.03692101570777595, 0.03257601936638821, 0.03213000716641545, 0.0399133069004165, 0.05977162392809987, 0.04515751905273646, 0.10328185715479776, 0.03149625757941976, 0.06498707414721139, 0.08607600189861841, 0.007585942721561878, 0.05338163595297374, 0.04305699621909298, 0.07772768658469431, 0.07414507999783382, 0.07707798082265072, 0.0186790109728463, 0.026898571086348966, 0.055302017281064764, 0.0401587499800371, 0.029340711917029694, 0.02880114087020047, 0.022209541057236493, 0.026997182103514206, 0.03453700730460696, 0.005750717737100786, 0.031402264576172456, 0.041509013462928124, 0.03486748566501774, 0.04584402791806497, 0.026497627659409773, 0.07007289343164302, 0.06269403078476898, 0.04029993615404237, 0.0636724337527994, 0.03768930924707092, 0.01655938154726755, 0.014483785598713439, 0.06262288108700886, 0.024748597097641323, 0.0450524717598455, 0.08219557887059636, 0.040584746457170695, 0.02864711183065083, 0.03090589580097003, 0.0459500771103194, 0.018279293944942765, 0.05831512200529687, 0.025608924370317254, 0.014854392811685102, 0.07737889201962389, 0.04787989855685737, 0.0035170591763744596, 0.03048777907679323, 0.062384703633142635, 0.004393363033159403, 0.04918528065900318, 0.04221228744427208, 0.038582858760491945, 0.039605601341463625, 0.04415348230395466, 0.0326464232057333, 0.03130971876089461, 0.027849998841702472, 0.035169617694919, 0.0153499934640422, 0.022897699345776346, 0.015099487081897678, 0.012744922460115049, 0.03756251331651583, 0.018924689684354234, 0.03176903766870964, 0.04652327857911587, 0.054680720932083204, 0.03904981065716129, 0.0617099318333203, 0.06033118843333796, 0.02624497647047974, 0.0321926073229406, 0.046204630052670836, 0.027218184404773638, 0.04685219100792892, 0.008548126515961485, 0.0531128300644923, 0.051066743762930855, 0.044587764859898016, 0.046184180173440836, 0.04788895646925084, 0.01212697226947057, 0.048318266635760665, 0.017910132992255967, 0.04009941156255081, 0.014079515494813677, 0.1022605506295804, 0.03755861704121344, 0.024956645211204886, 0.015018457543192199, 0.0276087767269928, 0.03477869882772211, 0.03303462581243366, 0.009792754553927807, 0.059131328598596156, 0.04710798333690036, 0.020378714689286426, 0.051144802855560556, 0.07356983391218819, 0.013354084694583435, 0.0306100423404132, 0.029566050216089934, 0.0355444208253175, 0.07417580491164699, 0.037519999386859126, 0.06338761231745593, 0.01760885072144447, 0.02562482488428941, 0.01857536262832582, 0.01746682963130297, 0.04997879237635061, 0.015324533160310239, 0.09209278607158922, 0.03081232396652922, 0.016194369200093206, 0.04728356063424144, 0.030248536641011015, 0.04783132499142084, 0.02657190550962696, 0.07609963722643442, 0.09408062862348743, 0.013404609180724947, 0.020023266770294867, 0.030392973421839997, 0.056632495106896386, 0.06529285383294336, 0.05590498629317153, 0.011284052998234984, 0.020154719677520916, 0.08457500822260045, 0.052626482138293795, 0.03657785404357128, 0.03846585546853021, 0.028506578746601008, 0.052944095368729904, 0.07698671892285347, 0.1838976188446395, 0.10517523915041238, 0.15579230821458623, 0.17940582940354943, 0.14679375279229134, 0.1131091095157899, 0.12837403337471187, 0.0555833728867583, 0.12986652203835547, 0.16425231675384566, 0.10231500200461596, 0.10864736963412724, 0.10389981383923441, 0.12570872873766348, 0.14661784894997254, 0.09086663194466382, 0.3010908857686445, 0.13792741840006784, 0.08134469171636738, 0.12882772309239954, 0.11855089251184836, 0.12554673274280503, 0.1765619937214069, 0.11341632896801457, 0.17045175831299275, 0.16528734558960423, 0.12805957056116313, 0.08988514164229855, 0.10435459451400675, 0.14378660009242594, 0.1073960641224403, 0.12028115044813603, 0.2027311152778566, 0.07688966084970161, 0.13848983275238425, 0.12962337961653247, 0.14697609847644344, 0.17890447896206751, 0.1663902957807295, 0.2600488130701706, 0.176809232798405, 0.2245027298340574, 0.11414056862122379, 0.10709864844102412, 0.11810204159701243, 0.11925344660994597, 0.19323367334436625, 0.12005026830593124, 0.13392102322541177, 0.09643774901633151, 0.06283223352511413, 0.17084975726902485, 0.178695801878348, 0.1501868964987807, 0.14471330505330116, 0.15180699003394693, 0.1002309845353011, 0.14528792031342164, 0.10956435246043839, 0.15108238672837615, 0.11392312677344307, 0.16035096516134217, 0.2758347988128662, 0.11788062925916165, 0.14032091887202114, 0.13059039803920314, 0.18212609749753028, 0.2996524254558608, 0.14165179745759815, 0.14613910432672128, 0.11283395084319636, 0.09748172073159367, 0.1552649974473752, 0.23691281938226894, 0.13373846973991022, 0.05849597597261891, 0.10570764847216196, 0.12332420083112083, 0.19689651351654902, 0.12046149233356118, 0.23234237713040784, 0.09245145120075904, 0.08690161892445758, 0.13094587193336338, 0.11463555885711685, 0.11052102534449659, 0.1038518339919392, 0.12888023746199906, 0.1413377799326554, 0.13554369943449274, 0.1708060596138239, 0.11850281618535519, 0.14578898873878643, 0.1555785845266655, 0.13081097917165607, 0.09365087316837162, 0.21855232334928587, 0.22259720630245283, 0.07494956065784208, 0.10596864696708508, 0.14564645185600966, 0.17274460871703923, 0.1972693981952034, 0.0546306370961247, 0.22857680887682363, 0.19365496089449152, 0.15471111779334024, 0.15645644132746384, 0.10915983744780533, 0.13779822533251718, 0.07260002501425333, 0.12225151542224921, 0.08322845547809266, 0.09430817110114731, 0.14079237560508773, 0.13269757793750614, 0.2383838896639645, 0.07657579917577095, 0.11182123838807456, 0.1639272115426138, 0.14714084041770548, 0.06977881741477177, 0.18729525996604934, 0.0721734830585774, 0.09162414949969389, 0.06222796204383485, 0.11475887411506847, 0.16123204288305715, 0.07687061734031886, 0.08961675135651603, 0.11232851858949289, 0.23719645338132977, 0.14663858455605805, 0.11924301201361232, 0.2574022550834343, 0.17695411486783996, 0.09490303214988671, 0.13592244707979262, 0.12931175180710852, 0.08599175329436548, 0.09595355702913366, 0.10643946545314975, 0.15880293416557834, 0.1791429755394347, 0.17482588766142726, 0.10084167559398338, 0.1193589651666116, 0.13413710694294423, 0.20174986246274784, 0.176665241306182, 0.16185422980925068, 0.13948264822829515, 0.16231160057941452, 0.110327636502916, 0.07418938621412963, 0.17438637296436355, 0.10854357286007144, 0.15065030835103244, 0.18741542851785198, 0.2621231455123052, 0.14691466349177063, 0.10057846549898386, 0.22179268853506073, 0.10432028502691537, 0.14376966428244486, 0.13390941603574902, 0.07290758585440926, 0.07613705631229095, 0.09103270975174382, 0.16935481951804832, 0.14306250144727528, 0.12624806229723617, 0.2179082133807242, 0.11684672106639482, 0.1718221785267815], [0.021706702609662898, 0.0730770849622786, 0.03177960214088671, 0.026765947441163007, 0.07976550536113791, 0.052504803315969184, 0.02921854884334607, 0.06559126399224624, 0.05070647188404109, 0.05112767408718355, 0.03945352786104195, 0.056804250343702734, 0.019693964713951573, 0.06910691401571967, 0.0069722241642011795, 0.04001987930678297, 0.04320827189076226, 0.09285250038374215, 0.026710397687566, 0.036421780387172475, 0.009940506879502209, 0.05283610546030104, 0.06324855610728264, 0.03784778375120368, 0.08997370954602957, 0.04925251552776899, 0.02655649481312139, 0.013257731661724392, 0.05325975304003805, 0.03529367138980888, 0.050359079978079535, 0.06865076036774553, 0.06734522612532601, 0.07198600171250291, 0.057985003586509265, 0.08024165246752091, 0.053290915820980445, 0.05660484639520291, 0.0482470390124945, 0.02502609910152387, 0.022364557153196074, 0.040218381545855664, 0.06785257312003523, 0.04973573530151043, 0.02410099532426102, 0.08958907666965388, 0.008897019415599061, 0.02602793352707522, 0.04917541009490378, 0.03279178767115809, 0.02400458848569542, 0.034075458243023604, 0.028223662775417324, 0.09014732015202753, 0.027092765158158727, 0.05664590200467501, 0.03812700197158847, 0.019553561505745165, 0.05743221117882058, 0.07363811149843968, 0.04552834427158814, 0.06734892202075571, 0.0678700878052041, 0.05052494627307169, 0.025398380785190966, 0.013711233987123705, 0.05104165546072181, 0.08003909068065695, 0.06916463826200925, 0.018189304828410968, 0.05925048411882017, 0.04558826156426221, 0.08956682708230801, 0.07122459530364722, 0.057932340787374415, 0.022896903392393142, 0.05673028790624812, 0.03548992121068295, 0.060659221417154185, 0.05848730397701729, 0.031186848791548982, 0.04207726851745974, 0.0153992590821872, 0.032253315002890304, 0.1343082165112719, 0.030719149181095418, 0.05720990084228106, 0.0031795130189493648, 0.017897894977068063, 0.0456771894096164, 0.06008499207382556, 0.003267651172791375, 0.04412028974911664, 0.05067618483735714, 0.0719829737499822, 0.06152660651423503, 0.04884090929408558, 0.07230391551274806, 0.01811572459700983, 0.014588757749152137, 0.069032699248055, 0.008679137845319929, 0.06878602420329116, 0.0891468531335704, 0.0634519787854515, 0.023647734196856618, 0.10105815264978446, 0.06535264867125079, 0.027612754638539627, 0.029098061168042477, 0.058466375412535854, 0.027320957015035674, 0.06188678562466521, 0.014468940789811313, 0.022958241897867993, 0.06871824385598302, 0.048847217549337074, 0.03180608568072785, 0.021326530040823855, 0.024043721932685003, 0.1593600050546229, 0.022319675772450864, 0.06359710576361977, 0.009007318330986891, 0.04911480631562881, 0.019444987156020943, 0.03954626663471572, 0.013386743830778869, 0.04108755892957561, 0.08030204102396965, 0.03932187086320482, 0.02969455123093212, 0.020880400952592026, 0.06618386149057187, 0.009504839290457312, 0.014824970367044443, 0.07433708102325909, 0.048446750952280127, 0.017774256884877104, 0.005131132038513897, 0.05978163178951945, 0.033981049637077376, 0.015682101766287815, 0.02318340393685503, 0.020831797701248433, 0.04478198490687646, 0.03432654164498672, 0.07475480626453646, 0.051162232193746604, 0.04413182272401173, 0.07819998194463551, 0.03035851550521329, 0.01583490626217099, 0.06092163370340131, 0.02639644138980657, 0.05950731545453891, 0.07243225511047058, 0.054517685930477455, 0.057951046619564295, 0.044228390979696997, 0.050904016752610914, 0.0512014732521493, 0.04722635218058713, 0.04493896027270239, 0.05880323995370418, 0.01947419994394295, 0.03220604390662629, 0.05095396329124924, 0.003031939736501954, 0.024174672034860123, 0.06526629978907295, 0.04211434250464663, 0.013893601008021506, 0.012061566794727696, 0.032014447351684794, 0.033838991439552046, 0.06969024208956398, 0.03868888939905446, 0.011795218342740554, 0.044567819641088136, 0.07893609596067108, 0.05167814357264433, 0.04200586648948956, 0.03529082525346894, 0.032465699114254676, 0.02766163248452358, 0.04035452482639812, 0.024212291500589345, 0.029894326253270265, 0.06937863654457033, 0.013774247890978586, 0.10245739787933417, 0.006423949116651784, 0.06243094685487449, 0.04547074990114197, 0.1165153892361559, 0.07896615294157527, 0.0878307358652819, 0.04071089300850872, 0.0264531804350554, 0.06870583514682949, 0.07429143894114532, 0.042168033178313635, 0.009153603059530724, 0.02503485829947749, 0.031365724935312755, 0.026206182556052227, 0.008750657689233776, 0.01776075536326971, 0.05592671637714375, 0.10922611123532988, 0.02688355372811202, 0.014654520382464398, 0.026559378056845162, 0.05630298524920363, 0.05258849902020302, 0.04648117283068132, 0.01916156837978633, 0.013755024410784245, 0.029112757547409274, 0.041175885635311715, 0.05392390099586919, 0.03661971117253415, 0.047483498929068446, 0.04637369129341096, 0.03359066140546929, 0.009852124512690352, 0.08756711758906022, 0.03596270638809074, 0.07060652729705907, 0.01813211121771019, 0.059192366534261964, 0.011410295101086376, 0.08021260480745696, 0.09105945675401017, 0.03232318820664659, 0.06283723560045473, 0.07075250032357872, 0.07888675056165084, 0.014133455715636956, 0.05001388111850247, 0.01747390786476899, 0.03955527259677183, 0.04795613196620252, 0.043088125603389926, 0.008900091906980379, 0.007611417404405074, 0.07438606276991777, 0.09069523293874227, 0.05504679269506596, 0.023535645777883474, 0.06732975234626792, 0.032090417298604734, 0.025546830729581416, 0.04791242317878641, 0.08675236560520716, 0.008985933345684316, 0.04482328542508185, 0.06287833573878743, 0.01386460065987194, 0.03274913273344282, 0.023452128189092036, 0.07201735745184124, 0.02317514383321395, 0.007063211469358066, 0.06159774879051838, 0.08818566799163818, 0.06865481991553679, 0.010262496925861342, 0.0948774503194727, 0.10552296502282843, 0.02332592226593988, 0.019864603018504567, 0.08190279419068247, 0.024562998951296322, 0.09351238099043258, 0.027768980435212143, 0.009065983249456622, 0.03496394259855151, 0.02455886704410659, 0.08395881784963422, 0.03397435175429564, 0.03262047401221935, 0.014979761035647243, 0.02697588803130202, 0.03482205138425343, 0.02481080206052866, 0.04931698589643929, 0.027972275092906784, 0.017820978791860398, 0.030019031182746403, 0.058219626153004356, 0.0627643195912242, 0.013480131055985112, 0.06899652697029524, 0.028194238475407474, 0.10305427756975405, 0.034660838355193846, 0.029552372434409335, 0.11891208094311878, 0.049531507393112406, 0.043688029545592144, 0.012944883019372355, 0.00688556868226442, 0.02513016119337408, 0.04123188438825309, 0.031448040244868025, 0.026198595951427706, 0.01534345328764175, 0.013267733957036398, 0.04281560526578687, 0.017554313999426086, 0.027288868404866662, 0.022270261724770535, 0.04623195964086335, 0.07569392735604197, 0.031102512984944042, 0.016014739776437636, 0.052990390540799126, 0.04240107868099585, 0.05047275102697313, 0.018713097815634683, 0.024693800623936113, 0.022979348577791825, 0.04084132917341776, 0.026058673283841927, 0.04157243369263597, 0.01565162732731551, 0.07556051888968796, 0.020485240711423103, 0.04025573012768291, 0.010475402395968558, 0.04079852580616716, 0.006182313254612382, 0.04059341845277231, 0.0025418418772460427, 0.0640209017728921, 0.09928602274158038, 0.04993561793526169, 0.049072073452407494, 0.019407671970839147, 0.04280860310245771, 0.06951908799237572, 0.02382543960266048, 0.029917015563114546, 0.024170528995455243, 0.087616032542428, 0.031092176723177545, 0.11172114493092522, 0.04708215288701467, 0.02292810328071937, 0.03527111010043882, 0.09843416337389499, 0.13207806274294853, 0.09784357709577307, 0.15640548546798527, 0.3171303297858685, 0.09128503254032694, 0.11726293232641183, 0.10179791803238913, 0.15574138204101473, 0.13197913445765153, 0.11574518837733194, 0.21224795695161447, 0.11404285003663972, 0.15818015352124348, 0.0799967437342275, 0.14704767119837925, 0.13889703433960676, 0.17243188252905384, 0.09833962118136697, 0.278779492364265, 0.1593474330729805, 0.17087643005652353, 0.18053598672850057, 0.15857111691730097, 0.27214136731345206, 0.12310557896853425, 0.09698557274532504, 0.09588335728039965, 0.177974033576902, 0.23483965953346342, 0.13912398309912533, 0.0806970639678184, 0.20710319629870355, 0.1962539175292477, 0.20820139674469829, 0.14138910686597228, 0.11197300016647205, 0.1228990986419376, 0.08714007839444093, 0.13265606219647452, 0.1521685643820092, 0.11743697337806225, 0.19659380632219836, 0.1257502444786951, 0.0874265845050104, 0.1645955748972483, 0.1778964197728783, 0.16173860320122913, 0.16981754859443754, 0.11223025823710486, 0.12157993114669807, 0.18976781400851905, 0.147433573147282, 0.22863965394208208, 0.10107577123562805, 0.14958326326450333, 0.17441693460568786, 0.13407292601186782, 0.2201970265014097, 0.0980559500749223, 0.17579759645741433, 0.15285055356798694, 0.2587079303339124, 0.15137746464461088, 0.18138087732950225, 0.06394610813003965, 0.2474864199757576, 0.19928383931983262, 0.29845213517546654, 0.09012368274852633, 0.06583687776583247, 0.21360366779845208, 0.22462512482888997, 0.16548209998290986, 0.1429906763951294, 0.20126007468206808, 0.15670799970394, 0.10809780927957036, 0.1366292091552168, 0.1139705500099808, 0.08210324085666798, 0.13423866243101656, 0.15617196128005162, 0.16257460287306458, 0.2057978475932032, 0.09603564598364756, 0.2103678445564583, 0.12497422518208623, 0.0497523631202057, 0.1762049167882651, 0.25934834440704435, 0.10315700565115549, 0.11973778702667914, 0.10799887357279658, 0.24751635821303353, 0.16515515424543992, 0.13667125924257562, 0.1874403646797873, 0.10291617873008363, 0.11663192868581973, 0.25198208342771977, 0.10758782023913227, 0.22359548398526385, 0.16032491577789187, 0.12255384412128478, 0.12221563258208334, 0.18851008149795234, 0.15210531855700538, 0.08751200570259243, 0.10103038148372434, 0.22458362393081188, 0.08349767696927302, 0.17069865600205958, 0.09961627845768817, 0.09361556178191677, 0.17722464253893122, 0.11349642896675505, 0.11129141174023971, 0.15231573226628825, 0.1561619868152775, 0.28528100287076086, 0.22884557023644447, 0.18538195872679353, 0.210036460775882, 0.09914275113260373, 0.09316104828030802, 0.17401414137566462, 0.16443703731056303, 0.12930848635733128, 0.15221386507619172, 0.21883442852413282, 0.1754946369328536, 0.0838079243840184, 0.13778400578303263, 0.12136581412050873, 0.13035535987000912, 0.1654966757632792, 0.1665208989288658, 0.12916312931338325, 0.19658300065202639, 0.1584488109801896, 0.12029252757201903, 0.1559915006509982, 0.10241349984426051, 0.10928287068963982, 0.0955951442301739, 0.15421365620568395, 0.15053481532959267, 0.09869739573332481, 0.1947190670762211, 0.13114464876707643, 0.11725305434083566, 0.09496892002061941, 0.15981540171196684, 0.23722401674604043, 0.0810674179228954, 0.1896078811842017, 0.09591175185050815, 0.18159356201067567, 0.069346041418612, 0.18336315377382562, 0.252412588451989, 0.1427495971438475, 0.08702448147232644, 0.13762327143922448, 0.13342255231691524, 0.19186026969691738, 0.13835577119607478, 0.12723860680125654, 0.0926723366137594, 0.19464080018224195, 0.14278327580541372, 0.18065152427880093, 0.13748882396612316, 0.14890887367073447, 0.0934059866995085], [0.024908969644457102, 0.04641218278266024, 0.023357931095233653, 0.035034672982874326, 0.015780850080773234, 0.019187740217603277, 0.01867052080342546, 0.0393171842006268, 0.016081436588137876, 0.006249186790228123, 0.04209560698654968, 0.06218256115971599, 0.039097694025258534, 0.0048953368786897045, 0.04549100311123766, 0.04098513141798321, 0.07250335285789333, 0.06244466174393892, 0.04124970335396938, 0.019216450200474355, 0.020470121307880618, 0.014780646524741314, 0.03759411767532583, 0.06263627685257234, 0.04624734436220024, 0.023875901933934074, 0.10929061128990725, 0.03295605092716869, 0.052328595193102956, 0.05268396889732685, 0.04316052953072358, 0.048554150853306055, 0.04165120895777363, 0.03827949476544745, 0.05316270238836296, 0.09882799145998433, 0.010681847470550565, 0.046123517022351734, 0.008379158971365541, 0.045465395305654965, 0.013770563127764035, 0.03575562863261439, 0.053309035356505774, 0.06700719270156696, 0.05320082280377392, 0.06165881270135287, 0.045159760338719934, 0.04563289803627413, 0.042908770774374716, 0.000635729961686593, 0.0774729072873015, 0.06050417934602592, 0.05963129493466113, 0.07126337994122878, 0.020961087247997057, 0.05296256371366326, 0.02409969656582689, 0.015750919264974073, 0.02075690386845963, 0.10944350113277324, 0.01843924717832124, 0.04411377740325406, 0.07549823785666376, 0.051981017750222236, 0.044009732009726577, 0.03912346139259171, 0.05055714806076139, 0.019909527072741184, 0.007047140261420282, 0.0503858010051772, 0.08190295746317133, 0.03263886072090827, 0.10054232290713117, 0.009360516614833614, 0.007101734499883605, 0.055184999146149494, 0.021484542558027897, 0.01951485850440804, 0.035495628326316364, 0.044434262745198794, 0.03737493920198176, 0.02840772838681005, 0.07893457455793396, 0.047465550087508745, 0.06271528589422815, 0.06681606741040014, 0.03116722269624006, 0.03672540042316541, 0.054402745809056796, 0.08129098248900846, 0.03565519749827217, 0.00972652622294845, 0.07762069115415215, 0.048417577127111144, 0.09237527716322802, 0.04901513959339354, 0.02734560188400792, 0.03256257165048737, 0.08715201212908141, 0.07042130950139835, 0.02539147510105977, 0.024953925239969976, 0.0170772132332786, 0.05252864852081984, 0.0209352716410649, 0.022816382224846166, 0.09003685889183544, 0.019913143187295645, 0.05929278653638903, 0.02935515596618643, 0.019655091018648818, 0.022325881982396822, 0.07572593618533574, 0.06029283053067047, 0.043116160231875256, 0.027931803924730048, 0.017697830517136026, 0.007318140123970807, 0.056409197713946924, 0.047029838897287846, 0.0248325488428236, 0.038089471563580446, 0.05317408693372272, 0.06737720526871271, 0.04426200655871071, 0.008837719033181202, 0.0048097009221237386, 0.026139932888327166, 0.020379916968522593, 0.07412062623188831, 0.01640893708099611, 0.008531769581168192, 0.028589404282683972, 0.003602397810027469, 0.015950300949043594, 0.10468516193213873, 0.09801066422369331, 0.04121646998100914, 0.008537580597476335, 0.02905807239585556, 0.05179305771889631, 0.029338901076698676, 0.042723586375359446, 0.025985562460846268, 0.04547581876977347, 0.11224521993426606, 0.056189566530520096, 0.07286551350262016, 0.042250222322763875, 0.03931274615752045, 0.013744636198680382, 0.05742811452364549, 0.01721309861750342, 0.12567221507197246, 0.09097992078750394, 0.034881838801084086, 0.01708831019641366, 0.013179395191400545, 0.04701741905591916, 0.031337745967903174, 0.01726132151816273, 0.06038076760887634, 0.03907239421096165, 0.01434062716725748, 0.03459150691924151, 0.04939928636304103, 0.04123996266571339, 0.03246584383305162, 0.02950148336822167, 0.05127327975060325, 0.038688377317157574, 0.0425548850762425, 0.04798952490091324, 0.07490356976632029, 0.05243677434918936, 0.02415532238956075, 0.03712408215506002, 0.03271683817729354, 0.043196709229960106, 0.05906329221033957, 0.05134123450261541, 0.03216207907826174, 0.014586681591026718, 0.03222631195967551, 0.03649873367976397, 0.01117660114687169, 0.01125852033510455, 0.032541862019570544, 0.033791709211072885, 0.015583205022267066, 0.05055549678218085, 0.07756172009976581, 0.059048267430625856, 0.030076926123001613, 0.06631825701333582, 0.06621261229156516, 0.058148212992819026, 0.029861399016226642, 0.01285445325265755, 0.05232912953943014, 0.05356403729820158, 0.026686543205869384, 0.09508094721240923, 0.027285846008453518, 0.058916870184475556, 0.06467762825195678, 0.03316683942102827, 0.05135663777764421, 0.06579418943147175, 0.055036068661138415, 0.02178034406824736, 0.05485730755026452, 0.013814058547723107, 0.016217398042499553, 0.06593803991563618, 0.012217803723615361, 0.047122091564233415, 0.05041044030804187, 0.02832862657669466, 0.02508904621208785, 0.02306619098817464, 0.08554892861866392, 0.03949766709411051, 0.027349128940841183, 0.07261858612764627, 0.024496370788256172, 0.07351268854108639, 0.04716693212685641, 0.09777023806236684, 0.022813922005298082, 0.07116972832591273, 0.05522864485101309, 0.052021320079802535, 0.02464778004650725, 0.07105552664143033, 0.016710751842765603, 0.02622793304908555, 0.050935602557729, 0.056685488161747344, 0.03302777578937821, 0.049056477218982764, 0.02324443445104407, 0.014286465229815803, 0.05703862800146453, 0.03722016801475547, 0.010278912304784171, 0.08984634958324023, 0.10023940791143104, 0.060296047740848735, 0.023902446700958535, 0.04043380846269429, 0.013533984074456384, 0.052935089406673796, 0.030444808726315387, 0.05932836138526909, 0.049910663219634444, 0.053049788330099545, 0.030719050846528262, 0.11892979600816034, 0.05227630346780643, 0.04281633999198675, 0.03772122159716673, 0.020595902351487894, 0.006465524229497532, 0.06674848002148792, 0.05865269529749639, 0.01484889349740115, 0.009535880544717656, 0.07449254611856304, 0.01350029149762122, 0.06417772499844432, 0.007307103460334474, 0.03982098001870327, 0.01915623233799124, 0.07619655429152772, 0.03731315169716254, 0.07566283878986724, 0.01950177629623795, 0.01242516906131641, 0.04656269775296096, 0.017386206418450456, 0.1315408814116381, 0.055538087035529315, 0.017040868406184018, 0.053539605796686374, 0.08666600188007578, 0.026013448659796268, 0.035460168510326184, 0.07282924474566244, 0.051696545124286786, 0.027368482296878938, 0.061605626688105986, 0.02237458356830757, 0.016751276816648897, 0.05447401425044518, 0.02717455539823277, 0.016829035339469556, 0.017458994407206774, 0.08050020187511109, 0.039656405060668476, 0.008282244689326035, 0.02334737033379497, 0.028031350047967862, 0.03716924555192236, 0.044812939886469394, 0.06557232438353822, 0.029944304333184846, 0.05734425925766118, 0.031798326526768506, 0.07424489143886603, 0.03854647497064434, 0.0635637462255545, 0.009596593790774932, 0.046187690531951375, 0.03331041902129073, 0.0801611368660815, 0.014378171490534442, 0.036743861346622, 0.0554996029677568, 0.05767155751527753, 0.03792383162362967, 0.04086162691237405, 0.013945914070063736, 0.07831543785869144, 0.03293568268418312, 0.03076382832659874, 0.045028422464383766, 0.06014241946104448, 0.029677526363229845, 0.005680590347765246, 0.04257566892192699, 0.04342490479757544, 0.026165468334511388, 0.07796649486408569, 0.02470089926646324, 0.06519184753415175, 0.03221271952497773, 0.026834492200578097, 0.0067009483154834015, 0.0370804216072429, 0.06704651910695247, 0.03170748765114695, 0.057270341349067166, 0.08547063946025446, 0.02064945387246553, 0.05460479551402386, 0.04771006919327192, 0.07950567203806713, 0.017044376909325365, 0.08275485393824056, 0.07279402983840555, 0.03019992040208308, 0.21268520067678764, 0.1535745186265558, 0.10964474931824952, 0.16158108977833763, 0.15264166868291795, 0.11520820742589422, 0.0921030796598643, 0.08549847741960548, 0.09198201310937293, 0.06107563676778227, 0.10746739935711958, 0.18366805772529915, 0.13028242159634829, 0.09831426199525595, 0.25863505143206567, 0.1592617150163278, 0.19513854378601536, 0.1392675589886494, 0.12587312929099426, 0.1731481886235997, 0.19088240107521415, 0.10145886786631308, 0.12074151207343675, 0.16280998243018985, 0.16642853122903034, 0.17723561148159206, 0.28466332820244133, 0.13144889962859452, 0.24925397825427353, 0.16353746526874602, 0.1839017154998146, 0.1523433401598595, 0.16929426026763394, 0.14820462005445734, 0.18732159136561677, 0.2038935708696954, 0.1348273636540398, 0.0788596027996391, 0.11885611558682285, 0.14471293397946283, 0.13674486544914544, 0.17417891300283372, 0.16601132549112663, 0.1085139240603894, 0.1396951251081191, 0.21865362650714815, 0.15725318138720468, 0.15195881860563532, 0.15809333708602935, 0.13408042170340195, 0.189685539517086, 0.12807508144760504, 0.2349660175968893, 0.15216142492135987, 0.16700705018592998, 0.0991616387909744, 0.1141042256494984, 0.11226600749068893, 0.1336208393331617, 0.23318235471379012, 0.25242523464839906, 0.13448017212795094, 0.14334546751342714, 0.13260037143481895, 0.18851331726182252, 0.09417839915840887, 0.1309639506507665, 0.13172518636565655, 0.10088689465192147, 0.12169090448878706, 0.1835237248451449, 0.24509379523806274, 0.13820170133840293, 0.09612464433303103, 0.20029586157761514, 0.09966628436814062, 0.1317506717168726, 0.19028556591365486, 0.1023197740141768, 0.10843551615835167, 0.11412562176701613, 0.0955121053266339, 0.20871585351414979, 0.2064249772229232, 0.15997459238860756, 0.1510915151447989, 0.1378632671548985, 0.17606968263862655, 0.15382094134110957, 0.16008434118703008, 0.14963604480726644, 0.0707900826819241, 0.2562916756141931, 0.10200427961535752, 0.22085758246248588, 0.11630294204223901, 0.15116789698367938, 0.126509832625743, 0.3286400012439117, 0.14351944177178666, 0.11498887310153805, 0.12153527612099424, 0.09537759848171845, 0.11947477731155232, 0.07214332959847525, 0.14685472764540464, 0.18456301360856742, 0.17094800277845934, 0.15889096772298217, 0.2240488026291132, 0.11250699768424965, 0.1359069361933507, 0.12904627074021846, 0.13180988025851548, 0.08727218810236081, 0.17162720148917288, 0.16594083630479872, 0.07636741152964532, 0.21219211776042357, 0.14401389023987576, 0.06940653387573548, 0.1638208024087362, 0.17791279155062512, 0.1966478643589653, 0.09815741650527343, 0.1031244031037204, 0.09401306349900551, 0.23934958706377074, 0.11275218101218343, 0.15507536387303844, 0.09831120434682816, 0.12234783134772442, 0.1263412315165624, 0.18794943345710635, 0.12673804303631186, 0.37482806656043977, 0.21836325380718336, 0.1408415799960494, 0.12640026194276288, 0.21282104338752106, 0.14189817564329132, 0.07339623814914376, 0.16985847061732784, 0.15793284022947773, 0.07594979018904269, 0.2585598867153749, 0.12679220497375354, 0.15209927747491747, 0.17418222298147157, 0.11392119718948379, 0.14719017839524895, 0.1765829519717954, 0.13661032891832292, 0.21000236651161686, 0.2667435194598511, 0.1302791858324781, 0.10993835036060773, 0.15991568070603535, 0.12980827828869224, 0.08467588835628703, 0.07747235067654401, 0.1260710452334024, 0.2164240664569661, 0.25014770217239857, 0.18609789374750108, 0.17874531797133386, 0.10973554366501048, 0.14563972799805924, 0.08920657375711016, 0.1991633590660058, 0.2429916471010074, 0.19761506089707837, 0.19567237060982734, 0.197140546515584, 0.1234553605900146, 0.15341617399826646], [0.05204238594160415, 0.027464245322335046, 0.014337735574372346, 0.0550309589743847, 0.010807824255607557, 0.07780737098073587, 0.06927284339326434, 0.012494065413193312, 0.03933661362680141, 0.02509614856535336, 0.04608425741025712, 0.05384869175031781, 0.028591389527719002, 0.0111410327917838, 0.003901512081938563, 0.01490752316385624, 0.03024734920472838, 0.07279411147464998, 0.012965153855475364, 0.03838140648440458, 0.02115604202117538, 0.05135623330716044, 0.022072486790420953, 0.03370088888914324, 0.09165828087134287, 0.028603432729141787, 0.08488263585604727, 0.034370398861938156, 0.009484442289249273, 0.01357152097625658, 0.053156857975409366, 0.030687659855175298, 0.036877047168673016, 0.055704921833239496, 0.021354510863602627, 0.016680470362189226, 0.03857768599118572, 0.05845753643370699, 0.029280969029059634, 0.055997925446718, 0.04524440228124149, 0.010895471896219533, 0.06226671699550934, 0.02245181516627781, 0.03458635641436558, 0.06819778311182745, 0.14783722726861015, 0.06163191355881281, 0.0058073728268936975, 0.05229643422353547, 0.056455066151102073, 0.05546513762965333, 0.0336548423365457, 0.04209377759252675, 0.011081335360358935, 0.02358218771405518, 0.07198497754870914, 0.06569813325768337, 0.06175086498842575, 0.044865810486953706, 0.014648055348516209, 0.04274655584595166, 0.027753580870921724, 0.04487889826123137, 0.01945859257830307, 0.03925367120245937, 0.02049333754257532, 0.005173363024368882, 0.008525506782461889, 0.04518839981756173, 0.03433632315136492, 0.10178349810303189, 0.07631577289430425, 0.020972551574232057, 0.03125710420135874, 0.04108614142751321, 0.07215496647404507, 0.028600067089428194, 0.030173255036061164, 0.036288145565777086, 0.09013471848447807, 0.03945498989196494, 0.0466261847759597, 0.047537352875224315, 0.057257580119767226, 0.04776683977979701, 0.07313021531444974, 0.014150064980640309, 0.04350107141362969, 0.07441274297889322, 0.03422343506827019, 0.03976757136115339, 0.03791436924075242, 0.015611792550771497, 0.04815208121726755, 0.019105718056380283, 0.03346894918649923, 0.036876197409583256, 0.027266193937975913, 0.014537346396537032, 0.03582547957194038, 0.0363228224159684, 0.031599449503119104, 0.04459355732251424, 0.014517491163132945, 0.03507430366880726, 0.008651349053252488, 0.0635650078766048, 0.10317503241822124, 0.02835955372574972, 0.02933657629910158, 0.015178733610810013, 0.017502187401987612, 0.04141836012422573, 0.05967394245089963, 0.04806799959624186, 0.037510358888539486, 0.03431561723118648, 0.019105584469798487, 0.017032009018294048, 0.03158038744004443, 0.026526912806730252, 0.0024965861757664243, 0.0486914036446251, 0.04834349594602827, 0.010192101435677614, 0.018293075627298094, 0.0207177815536852, 0.0782026388333179, 0.06973973591811955, 0.043562142745940946, 0.0191543157416163, 0.02519097091862932, 0.007956710887810914, 0.05608197367109824, 0.04459947223949712, 0.053704514721175656, 0.012969948129466502, 0.025165292609017342, 0.034435555717209354, 0.027367536058591213, 0.008350746775249718, 0.031100793057703413, 0.051223515038145706, 0.041172501441906206, 0.018075644911732525, 0.037104700968484394, 0.034917146476800554, 0.04907906819425989, 0.012091002226952696, 0.02688016767933732, 0.0560251251590671, 0.038507979770656675, 0.03389070428966079, 0.031940993285388686, 0.02705979710299289, 0.025765730897546746, 0.0813796988222748, 0.027739893812395167, 0.0038632049700026982, 0.03026988822966814, 0.03592883476812858, 0.025073440701817162, 0.012047310137859313, 0.04678670760768, 0.04794166008650791, 0.04405639825563412, 0.006899683867231943, 0.03448378418397624, 0.05266944135655649, 0.008923853620217415, 0.016150487863342278, 0.030866899651300628, 0.013130098959663883, 0.05066593577794265, 0.0729857043188531, 0.0192708626127569, 0.044212735374458134, 0.03815765638137236, 0.05080210874439217, 0.03649791360658128, 0.03171374395606108, 0.08623312940471806, 0.020626267323677894, 0.06418842676794156, 0.028054417853127234, 0.004593128314809292, 0.048762033839011565, 0.0028396726975188358, 0.08004890929441899, 0.06519672344438732, 0.0359918839239981, 0.08473650697851554, 0.029487260107998736, 0.04447386374522466, 0.009082669512281427, 0.019867007576976903, 0.06636882695602253, 0.011488947911857395, 0.013590650760306744, 0.01474927779781865, 0.05453944941109512, 0.05391040875110775, 0.07690477097639814, 0.041475906255072914, 0.07307243169634603, 0.08306128671392798, 0.05978434062853921, 0.03877824769006111, 0.013065245457255514, 0.08562058297684416, 0.016659560351399705, 0.030181552247086074, 0.03927605808712542, 0.022578601819986943, 0.05704129231162369, 0.02229453737527365, 0.059554196923272684, 0.102800522436155, 0.0676540337735787, 0.016701079803169705, 0.04231169441482052, 0.032483336253790185, 0.04698961078247521, 0.05317230949003715, 0.03784517139138188, 0.028012794500682503, 0.02020758285652846, 0.07948317754198797, 0.021066924928163644, 0.024106646778818686, 0.015804385438968893, 0.10188969943556003, 0.03447574301389977, 0.0570776983659016, 0.036647404413088225, 0.022320811258396134, 0.0626130031014327, 0.03205310211342294, 0.05835927608131897, 0.01397142910718685, 0.028860039565188345, 0.038672495356877334, 0.03451254982792307, 0.018997861734533217, 0.008248201447713654, 0.047524190886178985, 0.02665432657522615, 0.0939761490735691, 0.05179965912248008, 0.025917741295415908, 0.06291008481639437, 0.03433952551858965, 0.01761920368153369, 0.047047750631463714, 0.02135479102435056, 0.04002002031484153, 0.03463554225163534, 0.05378290778025985, 0.023711699905106798, 0.084330195968505, 0.011256695579504594, 0.004401818878250197, 0.03370213940797839, 0.07391646882751957, 0.006731681578457938, 0.10601101617794484, 0.055268212454393506, 0.02886642574594589, 0.015711201376689132, 0.029610245110234246, 0.029075138081680052, 0.041287589992862195, 0.0506263310671784, 0.012862963831139496, 0.016981084700091742, 0.015983296834747307, 0.014460774382314412, 0.042017469968413934, 0.02950655594759155, 0.06259862770093605, 0.04973554976459127, 0.027440192316134926, 0.019218561610614415, 0.03494926662824582, 0.044856400054413825, 0.029769231696263887, 0.019184693701390643, 0.04693606482760515, 0.049948557280004025, 0.08649713359773159, 0.0515807700867299, 0.12957628292497247, 0.020814726449316368, 0.01696258481388213, 0.034590237846714444, 0.05411765720054973, 0.02813180530210957, 0.005697701026292634, 0.029203006415627897, 0.003251212833674799, 0.04430758926901035, 0.02976201616547769, 0.035348464152775705, 0.03474789969914127, 0.032794411163195036, 0.023395630341838114, 0.017930365793290548, 0.015126406633498846, 0.039968029159354046, 0.03966397125623189, 0.03554481787432451, 0.05318502619047649, 0.019915234188374598, 0.024563806036894675, 0.028171669764560647, 0.04208396640024148, 0.01849243690230651, 0.04714830050943419, 0.03585463113267906, 0.06300320950686, 0.014371203651535325, 0.049021329105016775, 0.030135121633065864, 0.04615727360942401, 0.011897063268406782, 0.050626865413505584, 0.06073381096939556, 0.01827069245337043, 0.02320523050002521, 0.03299296906334348, 0.021320010273484513, 0.020897329341096338, 0.01262843310541939, 0.01369292334857164, 0.04655045602703467, 0.03521877384628169, 0.023906784554128535, 0.01865771133452654, 0.027135839409311302, 0.09724727628054097, 0.062158285509212874, 0.02343535379623063, 0.05011476867366582, 0.06320207539829426, 0.019044461187149864, 0.05823253210110124, 0.04662320134229958, 0.05823566396429669, 0.05736636041547172, 0.009102101721509825, 0.13358322728890926, 0.15298161684768274, 0.12487347121350467, 0.13326002197572961, 0.12012093560770154, 0.09388590391608886, 0.18785592284984887, 0.23057863349094987, 0.18212014547316357, 0.22876665025250986, 0.178698280651588, 0.1236873707966879, 0.127149578765966, 0.10005859105149284, 0.15543619607342407, 0.18759465718176216, 0.10415889017167501, 0.1786923286272213, 0.18148102273698896, 0.09758955478901044, 0.20327101286966354, 0.15387911087600514, 0.1549735412118025, 0.11428188096033409, 0.08347569455509074, 0.16623253002762794, 0.10249282800941728, 0.20019354909891263, 0.17006506968755275, 0.15039733989397064, 0.19733294087927788, 0.12472170201363042, 0.09279859077651054, 0.14591081970138475, 0.12363716450636275, 0.1167051935044583, 0.10508956562262028, 0.11373058398021385, 0.1928613378549926, 0.1235335977980867, 0.12072836863808334, 0.19373928371351212, 0.12215454640681855, 0.1638069687760435, 0.14949278061976656, 0.13435813336400315, 0.22426003270084038, 0.3174863231834024, 0.13000270613702014, 0.11133363994304091, 0.14020900300238281, 0.13551990617997944, 0.18446589616360143, 0.13025080610532314, 0.09984442207496613, 0.06640250561758876, 0.1270092831691727, 0.13596848992165178, 0.18694219063036144, 0.23751832282869145, 0.2062865369953215, 0.15044684114400297, 0.12797190807759762, 0.13257956161396578, 0.15826309594558552, 0.06650021678069606, 0.11269458293099888, 0.12570207909448072, 0.17053378047421575, 0.21542108355788514, 0.14728904730873182, 0.12785261526005343, 0.1605238558840938, 0.18616326211486012, 0.231590254988987, 0.13886835775338113, 0.24088952864985913, 0.16651150333927944, 0.07189700336311944, 0.12112604104913771, 0.14312540588434786, 0.18420679756673053, 0.11557013800484128, 0.1371796749299392, 0.1839350676164031, 0.28329433291219175, 0.125569932279177, 0.10716088494518772, 0.08461073521175422, 0.163139273354318, 0.2047520873020403, 0.20391377212945372, 0.08916858321754262, 0.1582713337847963, 0.13902358536142856, 0.12947563285706565, 0.15346900006989017, 0.1250008979695849, 0.13380450604017824, 0.1065976764948573, 0.11891218484379351, 0.09669672886957414, 0.1343171816552058, 0.17784101102733985, 0.12342683985480107, 0.1624772627837956, 0.21417479496449232, 0.1434671352035366, 0.1312315691029653, 0.16909011028474197, 0.13118007889715955, 0.1203886950679589, 0.0794361402222421, 0.08827059195027687, 0.18684529582969844, 0.18167291244026273, 0.17481144546763971, 0.19890657596988603, 0.0803867274953518, 0.13861892191926017, 0.07422348789987154, 0.1352348769432865, 0.14252149063395336, 0.13079569092951715, 0.10894741251831874, 0.18843968136934564, 0.13136625406332314, 0.15063742466736585, 0.12459938123356551, 0.14922339585609734, 0.11836254285299219, 0.15378445736132562, 0.09548065310809761, 0.20584579033311456, 0.1235550013370812, 0.1369509004871361, 0.23748897830955684, 0.26228546805214137, 0.10863622257602401, 0.09576940050465055, 0.17288907518377528, 0.08950569637818262, 0.10100139319547452, 0.11305600884952582, 0.301617959048599, 0.15387108083814383, 0.1558277680305764, 0.09370286803459749, 0.10466808511409909, 0.15798854583408684, 0.04874242629739456, 0.12582935742102563, 0.14198733726516366, 0.09633243083953857, 0.1414500520331785, 0.12419751568813808, 0.14261969161452726, 0.12486863241065294, 0.13702248805202544, 0.1743103176704608, 0.16902759176446125, 0.15854724944802, 0.11406046120100655, 0.1040466403355822, 0.0749438906495925, 0.18758410384180024, 0.14760404446860775, 0.1791479330859147, 0.13490953424479812, 0.18883986223954707, 0.09706808472401462, 0.1722183369565755, 0.1457116421079263, 0.2074561468907632, 0.12565192475449294, 0.07688653640798293, 0.27600008994340897], [0.05586285828030668, 0.030250577547121793, 0.011475575338408817, 0.02294504094606964, 0.035711845630430616, 0.02364401789236581, 0.07443162321578711, 0.002584731751085201, 0.041305319900857285, 0.013462292608892312, 0.023108725326892454, 0.07740330867818557, 0.05169178795767948, 0.02291859080287395, 0.019819890476355795, 0.02314412391569931, 0.1180102676153183, 0.06465610596933402, 0.05676387379935477, 0.028126495235483162, 0.04330704432504717, 0.03456899015873205, 0.017281118307437282, 0.00623981671196816, 0.04120888152101543, 0.055891334486659616, 0.06241807801416144, 0.04948054782289546, 0.057742577337194234, 0.013496950905391714, 0.019335279175720643, 0.03160438107443042, 0.016137118072947487, 0.058497775680734776, 0.06417578799300827, 0.02718676743825199, 0.05857521879079286, 0.018132166878785938, 0.014948259649827378, 0.021654449847119395, 0.05793399206595495, 0.04697160627983976, 0.01632853836781578, 0.08692826944752596, 0.08190202235709876, 0.03843288555799518, 0.004363964708318235, 0.04861060231633019, 0.005867265535925981, 0.020041430834680796, 0.08025545641430654, 0.02343302716326434, 0.027556225250009447, 0.03498665973893367, 0.010413061063445639, 0.02214145086327335, 0.019891203446604777, 0.04268895776476711, 0.10069569514598697, 0.03380002126505133, 0.03837057112832554, 0.029068189724057447, 0.05575436742219608, 0.03292524808784947, 0.021520193477044813, 0.028026038125972264, 0.04920726678392384, 0.06261079150135629, 0.05294465569022577, 0.061740730961901136, 0.0784505829506088, 0.022561732803296763, 0.013821327884215862, 0.05414158404164482, 0.03912861560820602, 0.10194244387093931, 0.029479812656063586, 0.024098581488942727, 0.039121164445532486, 0.08553876119549386, 0.05825724932947196, 0.04188613951555453, 0.05600522075837944, 0.01436187392755528, 0.003120368951385899, 0.04499609080085065, 0.030340950725076254, 0.038671129805152304, 0.011470529661892215, 0.007489673644158756, 0.04668026878789533, 0.05423982955107931, 0.0073173515920643695, 0.03993116297351662, 0.08581429836340249, 0.05603545214398764, 0.047664790763519704, 0.0647549971472472, 0.13032904331339523, 0.04663661566155497, 0.05174684047233313, 0.016876196968951263, 0.027888915210496634, 0.04935705444950145, 0.03506080771330744, 0.00945394280279288, 0.04112991700822022, 0.045327444895519875, 0.03079060130403377, 0.02821204259817023, 0.012144756910856813, 0.027609771204879507, 0.06393855306669138, 0.03693424449011218, 0.03963043731346261, 0.07785805224557407, 0.023838527376938146, 0.036030375413247384, 0.011808556591859087, 0.06881668232381344, 0.04063958003825974, 0.07929830113425851, 0.0355328247678699, 0.05874057671462651, 0.0407301072118571, 0.022894172288943082, 0.023779242765158415, 0.01209979667692096, 0.005233162501099287, 0.06665834618615918, 0.06610417709453031, 0.03222908759198617, 0.0471752107841894, 0.01900248902529711, 0.06531568971695378, 0.03320999901916366, 0.02996984163473826, 0.08209323670598678, 0.018061045011563692, 0.025896946317516267, 0.03313570261525456, 0.0288204997923458, 0.04496025248954538, 0.04495836001296993, 0.03694801875099074, 0.039058619950083084, 0.022526927932631224, 0.01978003158001229, 0.03884698911861051, 0.010079786661663093, 0.06784541881643236, 0.02236340682429727, 0.04118175231269561, 0.028893224698549602, 0.04453626352187712, 0.03653262756415643, 0.030623219172412064, 0.0375421821809141, 0.030451116981566884, 0.003759236342375516, 0.016917864850256592, 0.03215784512576647, 0.06785022051190026, 0.05291979374305811, 0.029344029317144305, 0.05054323650256265, 0.03920837050827686, 0.02309788811544422, 0.036521699439617805, 0.06075678043998778, 0.0652557093417272, 0.09168205928290263, 0.03531418806232978, 0.0354911494650878, 0.01050924154696986, 0.043196720362175256, 0.01859355081251124, 0.0163582354070968, 0.03941151859180536, 0.02550349301600363, 0.02361525039304979, 0.011424999829614535, 0.011047328298445791, 0.019614912998804357, 0.029334331302379724, 0.024372665902774315, 0.07521926454501227, 0.0806759721308481, 0.07997091699508019, 0.030146884673740715, 0.031906876756693237, 0.0035897003590434906, 0.015388720585178817, 0.026769743526529055, 0.04945498825691175, 0.04033249417261686, 0.04085425738594495, 0.07241317449370399, 0.06915946549270302, 0.05726380302803591, 0.04456399386981502, 0.028034459646733012, 0.030186155418050475, 0.012703474440058926, 0.012142527684773086, 0.013970184154459275, 0.011858228535857052, 0.033832816770882346, 0.03200823557563126, 0.03340427101647947, 0.04538821194728371, 0.024381076291319914, 0.05533482020837255, 0.008190654389181873, 0.03742466309631709, 0.027907400253752712, 0.02513906882086303, 0.04867057527008001, 0.013777273998130113, 0.013847711234120652, 0.05967525976302568, 0.05023745310609229, 0.056179224702646025, 0.042330942014814354, 0.05270950248814188, 0.009528215086902492, 0.09865168685792014, 0.04613170291122515, 0.04622184787876904, 0.00880736333783716, 0.0663490709848702, 0.025196208625857253, 0.07672989129787311, 0.011059678563469788, 0.05522643325093668, 0.07744840157101862, 0.041897034243447706, 0.022075711422075983, 0.036208939854986966, 0.03911867825081572, 0.02551084955484839, 0.021137250842002686, 0.06429810877307318, 0.013976183490740368, 0.031208003711071797, 0.023055743404256646, 0.06983755840337835, 0.05506152803718578, 0.03189999704773072, 0.07233507829369046, 0.027244185548624955, 0.057816328262561, 0.02686950858333148, 0.018895460198109504, 0.05183957553526852, 0.02103407561662607, 0.06666507746558636, 0.04601579799782485, 0.0715574633795768, 0.038832179561723024, 0.018628205398272257, 0.050054202001774684, 0.01711207933112746, 0.017041005703504197, 0.008555754866392817, 0.010090867854160024, 0.062415666034212336, 0.05912637847359292, 0.045332780937314965, 0.0442667451716261, 0.06158154770673718, 0.07973561165272258, 0.01893936008855235, 0.007189119605754968, 0.06836452143033966, 0.03604561170504894, 0.051754369560512714, 0.059043205983471125, 0.03783445106819272, 0.049620168065303005, 0.01891964679089142, 0.05226720473729074, 0.017604787462914828, 0.023514507556683384, 0.057000763627002016, 0.02586059592431411, 0.016501286227139644, 0.01552994572193711, 0.06472925204434432, 0.013522833305614768, 0.044128286390332505, 0.07345652280491777, 0.04776369678438641, 0.011443389321357245, 0.05153864578460343, 0.008332517772942083, 0.06317955121630803, 0.02201147668529302, 0.030592234506912064, 0.02721637356444262, 0.07416414577164687, 0.025352783231937792, 0.019788493918895256, 0.04386161788715981, 0.01740266725391848, 0.02939588317531161, 0.016919200716074556, 0.026334835711168125, 0.028499021827883553, 0.03135699727863539, 0.021953396208118647, 0.0113069779399666, 0.02445658054057276, 0.0016641515958326636, 0.027777982686529867, 0.02111647256242577, 0.026861396909225732, 0.029568211721198168, 0.046668190334457904, 0.0060884668255312135, 0.007555488227808382, 0.025137066877505276, 0.05662356335960794, 0.055218636989593506, 0.05730983102694154, 0.00935499781917315, 0.08547862496925518, 0.03349998951307498, 0.09056668553967029, 0.014905831067153485, 0.045246702939039096, 0.010349762360419845, 0.08770747255766764, 0.047129308950388804, 0.05443764530355111, 0.019014910722034983, 0.010023063387052389, 0.052500684396363795, 0.039702466456219554, 0.05970068945316598, 0.03303913435956929, 0.011269441038166406, 0.04715504663181491, 0.013771284866379574, 0.019946526845160406, 0.0220412479393417, 0.07689677804592066, 0.07013977578026243, 0.09380828269058838, 0.050216780582559295, 0.011969958868576214, 0.021460341122292448, 0.16214310337090865, 0.10634441117872484, 0.16207132284762338, 0.13216045597800985, 0.10797520648338832, 0.13135587883880362, 0.10724019084591419, 0.07173317426349968, 0.08264025149401277, 0.09303451210143976, 0.19198309513740242, 0.17521012719953433, 0.145194572978653, 0.10824313663761131, 0.1397424889728427, 0.10303674062015489, 0.22856365801999345, 0.08205636680941097, 0.1192508490930777, 0.11840693070553243, 0.06241660856176168, 0.0947819952853024, 0.20010705920867622, 0.1481602099374868, 0.13397419068496674, 0.10994697411661036, 0.14053563703782856, 0.08033692196477205, 0.1093964341271203, 0.10996591372531839, 0.061467835839721374, 0.12293042469536886, 0.10394737066235393, 0.1635949668707326, 0.09709995254524983, 0.15853619144763798, 0.17384744016453624, 0.14737420133315027, 0.10009272984461859, 0.13536212558392435, 0.08572787526645698, 0.13241913897218183, 0.14682300825370476, 0.227006112691015, 0.2034083695616573, 0.18526649539126083, 0.11844207139802165, 0.1768871583044529, 0.13130465580616146, 0.12231499873450957, 0.15725907403975725, 0.12470056564779952, 0.11433305204263888, 0.12152732771937735, 0.23196400055894628, 0.11548640148248523, 0.16348428296623752, 0.1207198784686625, 0.21116272924700752, 0.16063749353634194, 0.09356083581224084, 0.07158948705182411, 0.21352508920244873, 0.11967096404987387, 0.12535511021269485, 0.10263051866786554, 0.21473573986440897, 0.0896835298044607, 0.110878940904513, 0.1443213174934499, 0.30498582520522177, 0.21139963762834668, 0.10553566316957586, 0.11835388941108249, 0.07934686727821827, 0.1607537138625048, 0.151955746114254, 0.09734930674312636, 0.1694842500728555, 0.1351283787516877, 0.16262744378764182, 0.16725748049793765, 0.14649784367065877, 0.11937455768929794, 0.07273997922311537, 0.16982445056783035, 0.13134912529494613, 0.1309546292759478, 0.08164169179508463, 0.14622451068134978, 0.1267797072068788, 0.20818073535338044, 0.11980176015640609, 0.18971544806845486, 0.21497350913705304, 0.13099470525048673, 0.17359745514113456, 0.09790708267246373, 0.3145767777459696, 0.09573968491167761, 0.15043043968034908, 0.19411484012380242, 0.16523759200936183, 0.10046544382930733, 0.09389297658344731, 0.1340001361677423, 0.14688396826386452, 0.08848792989738286, 0.17138855648227036, 0.16611724480753765, 0.17166996403830126, 0.0971969438251108, 0.12143968750024214, 0.13384903490077704, 0.1346456413739361, 0.15560294181341305, 0.11176546599017456, 0.14223332953406498, 0.13050494715571404, 0.10881364782107994, 0.16131985379615799, 0.17636902048252523, 0.12430808084900491, 0.13507507770555094, 0.10604314375086688, 0.087731518142391, 0.09753827238455415, 0.09903400423354469, 0.04548052769678179, 0.2298971192794852, 0.22346879937686026, 0.14065150113310665, 0.0944176156190224, 0.08548220954253338, 0.1807175754220225, 0.08547714809537865, 0.11651273976895027, 0.17553012643475085, 0.12113754433812574, 0.14308221288956702, 0.09688919002655894, 0.15562390006380156, 0.1626138624851592, 0.10519562594708987, 0.09493615420069546, 0.09328422995167784, 0.13575877383118495, 0.07232108880998567, 0.13849821902113035, 0.15930968744214624, 0.18625472439453006, 0.1385823785676621, 0.1357789454050362, 0.13103623583447188, 0.11429906167904846, 0.14817858551396057, 0.2587667678017169, 0.09824951703194529, 0.17949589644558728, 0.12027610384393483, 0.11171564561664127, 0.1885760881123133, 0.11746702293748967, 0.1626861179829575, 0.17086087464122102, 0.12631959049031138, 0.0921601805021055, 0.10492480883840472, 0.12590530881425366, 0.12862771429354325, 0.17219650297192857, 0.1869386580074206, 0.19273319863714278, 0.18905894423369318, 0.13423766795312986, 0.09625565566238947], [0.01852721208706498, 0.0634101068135351, 0.005879961363461916, 0.01695787959761219, 0.008267209705081768, 0.024288595413963776, 0.017585858986421954, 0.0625943900377024, 0.019638984558696393, 0.03114152954367455, 0.0468184232886415, 0.038551655161427334, 0.08937252539908513, 0.006173636156745488, 0.03884759025822859, 0.07457505067577586, 0.01419255571818212, 0.015587366615363862, 0.037035825953353196, 0.025767497209017165, 0.04012655932456255, 0.0454690837796079, 0.06972362389205955, 0.038442462973762304, 0.007824732911103638, 0.02877305985748535, 0.03510183363687247, 0.06366802539560013, 0.023768791470502038, 0.03703623413457535, 0.10383636763435788, 0.029417449986794963, 0.03872317662171554, 0.03613223147112876, 0.034062355625792406, 0.05947380377619993, 0.07214341123471968, 0.050565423007356, 0.026084294077008963, 0.04853541904594749, 0.06270693673286587, 0.06137949429103173, 0.002670520543688326, 0.09057909424882382, 0.012810981952497968, 0.060901254328200594, 0.0586804479098646, 0.01886850910523208, 0.018595096335047856, 0.011785474871430779, 0.01806857224437408, 0.00038588252550653124, 0.02448382478178246, 0.02700889319385169, 0.045702218340011314, 0.03544948900525924, 0.04667935223551467, 0.02822575748723466, 0.038693991664331406, 0.03235881500586402, 0.01510214025984169, 0.016717481266823597, 0.05396901615313254, 0.09904904014547355, 0.01522968668723479, 0.013820427102473332, 0.1280547317583114, 0.0364047109906096, 0.022355918554239906, 0.04172937566181645, 0.05733449630497489, 0.0547861355880741, 0.012588381250679959, 0.06907863076776266, 0.04912080286885612, 0.01054934256899287, 0.02250281184387859, 0.029654631107405294, 0.040879304870031774, 0.04973993214662187, 0.03695537714520469, 0.045760172652080655, 0.003158336298838549, 0.027257431029283907, 0.022104128256614786, 0.17866063892142847, 0.012460506422939943, 0.048613010585540906, 0.043332110362825915, 0.051534163212636486, 0.014301853661891073, 0.060543672734638676, 0.07055974972900003, 0.037241664322209544, 0.03677471984701697, 0.010380804542364785, 0.07434988307068124, 0.00472475609058165, 0.08569234123569913, 0.05567883905314375, 0.01280772392419749, 0.028663171906373464, 0.04164575417235028, 0.052014640750712715, 0.09425200536497869, 0.014663948441011598, 0.015952562644088175, 0.07391561535769142, 0.09531478310236707, 0.025071436903090216, 0.017684299309621565, 0.01609502902283566, 0.0672204711008817, 0.06692359718726948, 0.051801098888972774, 0.04716554802143946, 0.029525809113692958, 0.08231547282775864, 0.013225323000369826, 0.02247897777124308, 0.041165833245031536, 0.015556544294668129, 0.023174607631517574, 0.01651521448366111, 0.0630700695910491, 0.02923993939475622, 0.017000172738335095, 0.04779788381711114, 0.03268927481258288, 0.04003055510111153, 0.04232399551256094, 0.0318926757609006, 0.03710014418174978, 0.07493868077290244, 0.052590102059184574, 0.042628209266695194, 0.03259377524955198, 0.022302598954411224, 0.0740032852627337, 0.061710952286375687, 0.10822054566233419, 0.0389198717311956, 0.04922095569781959, 0.018284655961906537, 0.025318826264992822, 0.060384559983504005, 0.07512938303989358, 0.02112575497449143, 0.02853142585081514, 0.05505680055648554, 0.00828214635475888, 0.07274789051734842, 0.02289949534315383, 0.041168987372657284, 0.010925344267889159, 0.028812005912186578, 0.019204381023882888, 0.022130281540739816, 0.017300410436291713, 0.07011684341705404, 0.005194266077523935, 0.03867017243464943, 0.013505406750482507, 0.023722613186691888, 0.04474117420613766, 0.05855662428075448, 0.044049448042642325, 0.033148081638501026, 0.010889553268498275, 0.042709563495009206, 0.019601222229539417, 0.03588913728890475, 0.03961260350479279, 0.020919530688843224, 0.03893507462635171, 0.02059920490864897, 0.05200493716984056, 0.032804897709866054, 0.021652284631272778, 0.040143539663404226, 0.006344872817862779, 0.01981204597541364, 0.010400883347756462, 0.049680163283483125, 0.031743207218823954, 0.027639512773021124, 0.044247530968277715, 0.005171368502487894, 0.06476834838395007, 0.037419345608213916, 0.021182276941544842, 0.1400327280862257, 0.04042174856294878, 0.04343818924098741, 0.004194136272417381, 0.0035638193503473303, 0.0669835701410193, 0.02739557810855331, 0.03873228648444638, 0.045440284739015624, 0.011053743237425806, 0.04509217294980772, 0.06668941990938038, 0.05439017011667602, 0.020655224070651457, 0.043277154327370226, 0.008246680044976529, 0.052529409222188406, 0.05044206693128217, 0.02517708719096845, 0.027546786986931693, 0.016118647872644942, 0.03163967761793174, 0.012871823219029466, 0.015248155959852738, 0.021815627624164335, 0.03070590741117485, 0.00551029760572419, 0.04383825136756059, 0.026097790032508783, 0.04485206962272059, 0.01113261590944603, 0.024430868834315334, 0.014893685820425162, 0.058707035350380465, 0.03530038411554415, 0.04205184995953459, 0.01739866151183378, 0.018593914464872796, 0.03411184203287121, 0.026696734748838935, 0.01688007469056174, 0.06297234358498827, 0.048606008422211744, 0.056685246963752434, 0.05024770216550678, 0.03146320232190192, 0.03447995099122636, 0.058171312339254655, 0.059967784691252746, 0.026111055922228843, 0.061634247613255866, 0.05403622504672967, 0.038032081283745356, 0.036626175278797746, 0.04164986195974052, 0.013363705711526563, 0.086038070730865, 0.04688224056735635, 0.04016958162537776, 0.035529206797946244, 0.023100439248082694, 0.009992007289838511, 0.07733988473773934, 0.08480551929096691, 0.06123113525973167, 0.009512292308500037, 0.014126940586720593, 0.07964909949805588, 0.03150256583467126, 0.04135237948503345, 0.08676596175064333, 0.05866180144948885, 0.03158914849336725, 0.04265793970262166, 0.046357438259292394, 0.05766636990301777, 0.018204388979938813, 0.018644586452865042, 0.11650508822640404, 0.017928402812685817, 0.06536087166750804, 0.08541422881535254, 0.09169523982563987, 0.04237961577018723, 0.11611215071752667, 0.016209065579460002, 0.04383815117762424, 0.019280141314084176, 0.003975278777943458, 0.03934154148737434, 0.052290196472313255, 0.033522053563501686, 0.011882623857673025, 0.05629058025078848, 0.011435184878791915, 0.015083428861544235, 0.011782021101680584, 0.11101991185569204, 0.035183592335670255, 0.08663113578222692, 0.09029554188600741, 0.06232440413441509, 0.09439097993890755, 0.04108003726287279, 0.06213972439581994, 0.005219717104409938, 0.04158587027632166, 0.021018325387558434, 0.01594374407432042, 0.038040319122956134, 0.018186480956501327, 0.03711817094881553, 0.024034150083025452, 0.02298075494763907, 0.0388943529833341, 0.03303515644802246, 0.07240065446239896, 0.03648555684776511, 0.035513566035660915, 0.056349937221966684, 0.024236904828285333, 0.0452173324447358, 0.007672348656342365, 0.027882031790795736, 0.03375410087755881, 0.05717589192499872, 0.10037108717369847, 0.04861082496063318, 0.029676218327949755, 0.030721477669430897, 0.039066757599357516, 0.02699731383472681, 0.016438352104160003, 0.04397474716824945, 0.04356016492238268, 0.022900037110957783, 0.015307664143620059, 0.026657857342797797, 0.04527508637693245, 0.05698216540622525, 0.03334748929773923, 0.03429363110626582, 0.015615737065672874, 0.01926057830132777, 0.0490928535873536, 0.01931406859512208, 0.04900588872260414, 0.015265926685970044, 0.015814888683962636, 0.09096086243516766, 0.05168215117009822, 0.038630519484286197, 0.006928334478288889, 0.014122429256531177, 0.014477960667136358, 0.036327449706732295, 0.06064728026103694, 0.035881203730241396, 0.014453483709075954, 0.043119165929965675, 0.08956781413871795, 0.13675234629772604, 0.12192097026854753, 0.18805551604600623, 0.11079159012297168, 0.06046034810424317, 0.08165425635525025, 0.09195093938615173, 0.17237810650840402, 0.18054364569252357, 0.09404852331499569, 0.07164038353948854, 0.12582423660205677, 0.1436257766908966, 0.1498573977733031, 0.09331712935818359, 0.27531360334251076, 0.11980703682638705, 0.04702545651525725, 0.07128263867343776, 0.11831547584733926, 0.15292956260964274, 0.10063840134534985, 0.10508520921575837, 0.12296680477447808, 0.06094236930948682, 0.1628919897484593, 0.1349934859899804, 0.1908445663866587, 0.09515104306046851, 0.1427652416168712, 0.19024589069886133, 0.10611846431856975, 0.16446578811155632, 0.1138578326208517, 0.08525018449290656, 0.127187205653172, 0.1529233285691589, 0.11099006267613731, 0.1236823019280564, 0.1383103072294034, 0.13635517854709178, 0.11221647655474953, 0.19905093853594735, 0.10210274034761824, 0.15571068681310862, 0.11367375031113625, 0.10781735167256556, 0.149545933236368, 0.14757449214812368, 0.08322134570335038, 0.08033220932702534, 0.09081937198061496, 0.14296149514848366, 0.08467346895486116, 0.11046887462725863, 0.10496288843569346, 0.17697624571155757, 0.14526737766573206, 0.16410367941716686, 0.13077059149509296, 0.12416943282005377, 0.1519204644137062, 0.24187078146496788, 0.21756404981715605, 0.04074478318216279, 0.1388952086563222, 0.21662892890162766, 0.21476501016877592, 0.15333625953644514, 0.16724459681427106, 0.11527123802807182, 0.2012815821217373, 0.11162480674101971, 0.23061520652845502, 0.1310291260597296, 0.08347930139279924, 0.09929233841830865, 0.22030079358955845, 0.2706357871647924, 0.13383935729507357, 0.07883077036240138, 0.16660424211295322, 0.12679138861130923, 0.06487250138889067, 0.13287219044286758, 0.2297024242579937, 0.1180647560977377, 0.27953502838499844, 0.14929217810276896, 0.10914782207692042, 0.150321566616185, 0.13818443898344412, 0.1883146443287842, 0.1902491264627315, 0.12131240175222047, 0.19780398200964555, 0.20182061882223934, 0.1545771156088449, 0.16112514393171296, 0.2557236357824877, 0.1756168538122438, 0.08456395022221841, 0.09054054709849879, 0.07863965991418809, 0.21073462878121063, 0.1344271530979313, 0.1659836879116483, 0.09281810183892958, 0.3542042279150337, 0.12954656733199954, 0.12831706611905247, 0.151041078788694, 0.20097350177820772, 0.1251596730435267, 0.1778041708166711, 0.17154831119114533, 0.1266494602896273, 0.2202264007064514, 0.10442477941978723, 0.26302809070330113, 0.10290544727467932, 0.19495953776640818, 0.08534780659829266, 0.10124878070200793, 0.12422508647432551, 0.2786755026318133, 0.08859458393999375, 0.13632605667226017, 0.12698446575086564, 0.11231815078645013, 0.09235604069544934, 0.14645221643149853, 0.1216891233343631, 0.16842940589413047, 0.17931217036675662, 0.11183925773366354, 0.1850387451122515, 0.06306971336016431, 0.19167848804499954, 0.1002260047243908, 0.11233205121243373, 0.16678452462656423, 0.14382536988705397, 0.08836010238155723, 0.08851279926602729, 0.11646227372693829, 0.13698229333385825, 0.08849853518768214, 0.102938539639581, 0.1327286590822041, 0.07354589222813956, 0.15990419226000085, 0.10080560721689835, 0.16718203376512975, 0.2115017719916068, 0.13025825726799667, 0.09318268930655904, 0.07131714854040183, 0.09475423154071905, 0.20373460283735767, 0.14111249358393252, 0.16899107809877023, 0.09795355595997535, 0.16026040830183774, 0.19573401339584962, 0.15200425288639963, 0.11795059152063914, 0.14137904334347695, 0.07051758831948973, 0.09050246007973328, 0.17594566976185888, 0.2392819625674747, 0.1874261599732563, 0.1485280628548935, 0.12562266929307953, 0.09898432486806996], [0.0147997716703685, 0.05068293095973786, 0.00779668900577235, 0.06132952919870149, 0.014250459935283288, 0.02767625279375352, 0.04470702428079676, 0.07048448853311129, 0.047711338265798986, 0.006893817653690348, 0.0511988831567578, 0.07366001227637753, 0.0193019140715478, 0.005681023576471489, 0.028544437554955948, 0.041805375294643454, 0.006923542523509241, 0.05179428597330116, 0.049333995921188034, 0.021448989973578136, 0.06996432464802638, 0.023399083183903713, 0.0158794110029703, 0.06331189099000767, 0.03510213049594313, 0.020481292485783342, 0.03534011499141343, 0.02032215375947999, 0.04208906124404166, 0.03377283639565576, 0.037084952418808825, 0.029516086979128886, 0.051485767762642354, 0.058330458487034775, 0.04833087201404851, 0.0069807546879019355, 0.05415748826635536, 0.011794187685154611, 0.0395451868098462, 0.014419481285585789, 0.05517705074453261, 0.05028649051382672, 0.07127469769329764, 0.017481180912000127, 0.061125100910430774, 0.059115687836310826, 0.029715971468249336, 0.02212356139352778, 0.03693042614031583, 0.01776814529875992, 0.05824510408274364, 0.04663933563278988, 0.05843835562700406, 0.07081399468006566, 0.030378900446521584, 0.05170444899704307, 0.05276638068608008, 0.025799160939641297, 0.04193370376015082, 0.036402180267032236, 0.01378469547489658, 0.00603492597292643, 0.03379689311259426, 0.04388439811009448, 0.03926333396520931, 0.08709724905202165, 0.028714782711176667, 0.10706427216064185, 0.0725989266356919, 0.03306474958662875, 0.030454469633696135, 0.07295696836081333, 0.025233816959371325, 0.09789045856450684, 0.04726368591946084, 0.03830364796158392, 0.03731291049916763, 0.0560481651336886, 0.01870012692961609, 0.04917442303849384, 0.03247820059186779, 0.03781096209422685, 0.07992840677616186, 0.02196339293732308, 0.04499655835388694, 0.027834499087475706, 0.012873788055003388, 0.011419982911320403, 0.07526944114943035, 0.0239428009808762, 0.04485586570808664, 0.04696117539424449, 0.08118841768009588, 0.05221819330472499, 0.05723269219743088, 0.01243362119566882, 0.043869347355212085, 0.057314269070047885, 0.0424909230787307, 0.026570562222332228, 0.02910630457336083, 0.042862316040555015, 0.019423216253926512, 0.05521300779946614, 0.037148632400203496, 0.044129997040727176, 0.0797920668264851, 0.054015322457416914, 0.028625461527553853, 0.041822496641543694, 0.018981590146722738, 0.08412072478677146, 0.007432181782860425, 0.028664585697697476, 0.027708979650924448, 0.03320710464322474, 0.028647349317907356, 0.1009280096332077, 0.0175596222106833, 0.03799928577791434, 0.06981231053941883, 0.037184422471909784, 0.03782090687309392, 0.04843486545723863, 0.04477658207179047, 0.03597029113734607, 0.0506609225703869, 0.06048775932868011, 0.10293449493474327, 0.051552386648836546, 0.036675016017397866, 0.023093004783731885, 0.011446131557022454, 0.04703709710156545, 0.06915113117429428, 0.0847624079324305, 0.012633172646019375, 0.05003940357710235, 0.031913303755573, 0.07892796202213503, 0.01229961901117349, 0.045873127528466284, 0.07701334718149155, 0.0751310602936428, 0.08255752429249696, 0.03155337326461449, 0.05232783078099601, 0.04951698727381881, 0.03626384394010529, 0.031683234265074134, 0.05885521626623813, 0.04680016645579599, 0.05141620997164864, 0.10826039157109335, 0.022877043520566076, 0.03947638972022105, 0.050528553110780194, 0.04276774787285831, 0.04078911537362728, 0.006286212073973729, 0.02365955846471479, 0.017227542666660156, 0.03438956853642594, 0.029934047852293588, 0.07541347717051394, 0.11712845516740344, 0.02133938960469095, 0.09941452561179176, 0.03040498137124814, 0.03442975954385474, 0.04617566031811293, 0.0407016235840274, 0.007351005669988808, 0.022131391051516403, 0.020912934851367027, 0.008776320228207624, 0.0689024300663732, 0.022634539345744997, 0.02264545448269928, 0.07244656371767633, 0.05188504321267828, 0.041048228813451715, 0.036897344907629304, 0.04969111367245205, 0.06937573474715464, 0.022225486100069247, 0.08316915045725182, 0.032662713347235695, 0.03635430432041176, 0.0392997882590862, 0.015825685077288654, 0.05379596957936883, 0.03170396987115964, 0.02337383531994419, 0.1346332029788755, 0.026896173949353397, 0.04286984141799621, 0.06783724034903571, 0.045739388806396164, 0.019117690753773786, 0.06256606968236156, 0.012552775788208237, 0.030597123404731974, 0.023647431771678384, 0.0686013704398647, 0.028267213856452145, 0.04160077260166872, 0.05541569204069674, 0.008244868276960915, 0.027762111858464777, 0.04651258423109539, 0.057241627655457705, 0.07136063839425333, 0.011285528016742319, 0.022449904136010446, 0.04166646009252872, 0.024459571395709645, 0.05347487567632925, 0.03638679925643373, 0.037422087843879126, 0.07495927537092939, 0.04458783907466568, 0.056179866660386324, 0.028113229345763102, 0.04539239023870323, 0.05604984980891459, 0.04996835035854019, 0.039284418380702846, 0.06320249842246994, 0.07864083992899396, 0.07719618268311024, 0.020439262807485647, 0.0613961889030179, 0.031133258307818323, 0.014338925793708768, 0.018596806985442527, 0.05223621265031397, 0.032905403058975935, 0.03631728599430062, 0.032257426501018927, 0.014162827137624845, 0.03836915362626314, 0.034536142702563666, 0.04389777903270442, 0.025959485246858094, 0.020353234904177953, 0.031624192706658505, 0.025923889988916926, 0.01206915061629843, 0.08109643589705229, 0.010352199387853034, 0.04620715706550982, 0.051188994038966484, 0.036667657623183914, 0.034203827526653185, 0.014732515464856988, 0.02927901346993167, 0.028828025169786997, 0.028889291315863375, 0.050778838703990914, 0.07396746921585873, 0.03088799334364012, 0.09391971616423689, 0.052595141241909005, 0.07141432535718195, 0.008972686009656172, 0.032161040071514435, 0.044805596335208975, 0.059206597215961665, 0.060267300650593825, 0.012937072842760244, 0.03840243523882236, 0.10485299120773561, 0.04908904265903402, 0.02790057063975837, 0.03937874163966626, 0.04112712282221764, 0.02929714413767215, 0.08288872995763086, 0.049663980753393844, 0.024913324195949826, 0.04498784554016311, 0.06617214297875762, 0.07752573335892521, 0.01260840810573427, 0.05281519173877314, 0.031048618220665958, 0.08758288822718896, 0.012300991984375287, 0.027335991071595345, 0.04716334384283982, 0.02373932635236997, 0.050111054224544205, 0.032211201832978986, 0.052101742912782356, 0.04538472756394185, 0.032056838826974854, 0.028144193602201995, 0.026059107440232765, 0.023288701704586856, 0.04065966626512818, 0.02310830786882434, 0.023897479877632577, 0.06331687080091797, 0.04005373237305321, 0.01125333457821398, 0.02238018307252787, 0.028445050993468612, 0.04514250911597628, 0.029229144856799394, 0.07780807602102868, 0.01561839395435527, 0.036296739635872655, 0.02436976596072782, 0.008643826458865078, 0.03554514070856385, 0.04817392262339126, 0.027802070944744628, 0.038059485086705536, 0.04629811839549802, 0.022883913952682633, 0.014018661240697838, 0.021068650421511848, 0.022503876825794578, 0.029860779322916642, 0.007290557741725934, 0.059327645212761126, 0.0728379056090489, 0.06932560267159715, 0.07998959685210139, 0.014522051660605939, 0.06592685575014912, 0.06855845203972422, 0.04697587733971886, 0.015358970667875838, 0.006478660707216477, 0.04633671007468365, 0.01854449485108489, 0.08577820772188716, 0.030384114033950027, 0.07208030641777441, 0.07889308108133264, 0.04584873684507329, 0.0398222565127071, 0.050039422130794264, 0.04690597445005551, 0.01997187118831789, 0.016320925788022578, 0.044733069953508675, 0.026740283974504564, 0.035719556544790976, 0.0171844424403389, 0.14260608062613755, 0.09323361548013054, 0.09420219241292216, 0.1692929837736301, 0.11677687012706883, 0.12256857575266622, 0.12281375165912323, 0.16173504089238122, 0.20995363709516823, 0.09916419920045882, 0.2096605926635675, 0.14037059823749587, 0.13683672848856077, 0.16582528391154483, 0.08085977984592319, 0.19499134621582925, 0.11398086586268619, 0.11466941563412547, 0.19831324374536052, 0.09455120962229557, 0.08545575197786093, 0.12993943062610924, 0.12697649508481845, 0.20080159069038928, 0.22182287910254672, 0.08936265483498573, 0.10269100370351225, 0.14785854174988344, 0.20999026950448751, 0.10464712686371058, 0.20496938814176247, 0.08010544610442594, 0.09643978992244229, 0.1643947052070871, 0.09759777778526768, 0.12371861521387473, 0.16628563811536878, 0.06754545014700852, 0.15350450441474095, 0.14813607529504225, 0.11370756998076104, 0.12016484848572873, 0.2532577165402472, 0.1182604010682553, 0.28835877834353596, 0.23479375027818605, 0.15044268511701375, 0.09976480447221547, 0.11469012897578068, 0.15799124725162983, 0.10794444446219131, 0.14120021543931216, 0.10953681878163479, 0.14055698120500892, 0.28248049376998097, 0.17294151533860713, 0.11732753628166392, 0.10638651321642101, 0.11499265063321218, 0.06887227660627104, 0.19358494668267667, 0.12427028326783329, 0.13245866575744003, 0.11244923633057624, 0.22956693777814507, 0.16738492209697142, 0.12813236040528864, 0.20611746091162786, 0.13958356546936557, 0.11992509025731124, 0.20355237589683384, 0.15894606476649642, 0.12943183130118996, 0.21458652365254238, 0.1508476454182528, 0.19871544325724244, 0.15392372879432514, 0.17810002056648955, 0.13173391402233392, 0.18776392622385174, 0.09233718272298574, 0.11881916405400261, 0.10002180279116146, 0.12013606799882837, 0.11739657828002237, 0.10596130712656304, 0.17146682337624952, 0.15102479606866837, 0.2442213412723504, 0.0705458121956326, 0.14320684917038307, 0.17708474770188332, 0.29051287681795657, 0.14996972924564034, 0.1269377104472369, 0.11416906709200703, 0.20949185796780512, 0.1575377504923381, 0.1107315206900239, 0.10675646641175263, 0.13229615025920793, 0.15892976720351726, 0.21195816312683746, 0.18846000137273222, 0.14082569803576916, 0.07509174130973406, 0.22837748285382986, 0.24468127987347543, 0.10949289848213084, 0.19278877065517008, 0.1848685261211358, 0.1970248160068877, 0.10011477905209176, 0.0770859737531282, 0.16055836575105786, 0.09127657205681317, 0.10636899110977538, 0.20334010681835935, 0.08526560632162727, 0.11702562318532728, 0.19082148559391499, 0.1184168309555389, 0.1384794426849112, 0.12343789785518311, 0.1424449306796305, 0.12443288040230982, 0.14368415402714163, 0.22049925872124732, 0.15979384974343702, 0.12409662071149796, 0.11554615179193206, 0.1116576096683275, 0.1731260577798821, 0.11254404569626786, 0.12636665749596432, 0.16294742817990482, 0.11884412990184501, 0.13856162811862305, 0.1532398842391558, 0.15616779041010886, 0.09284895291784778, 0.14101047796430066, 0.2749728981871158, 0.12993175681913272, 0.09136352950008586, 0.11682925091008656, 0.15323408064432442, 0.1295633992413059, 0.17252131132408977, 0.1407786161871627, 0.18811217159964144, 0.13389283645665273, 0.1710781457950361, 0.206999295623973, 0.10979821061482653, 0.17929824767634273, 0.08839211863232777, 0.17226773430593312, 0.156961057218723, 0.042368468712083995, 0.17775444692233577, 0.11033585207769647, 0.15098206320544705, 0.2239194611320272, 0.2568399446317926, 0.20741854968946427, 0.13837821374181658, 0.14524438593070954, 0.15379689575638622, 0.13825841626385227, 0.10623937501804903, 0.13267471978906542, 0.11036449155653827, 0.10816098831128329, 0.08569426339818165, 0.11404759978177026], [0.008790356096142204, 0.07563019171357155, 0.074905803630827, 0.08051758297369815, 0.06407416571164504, 0.05420336041424889, 0.014378784690052271, 0.04156493429036345, 0.06076165635022335, 0.060390712387743406, 0.02605997389764525, 0.064440103888046, 0.0471494063094724, 0.02320276471436955, 0.028336849572951905, 0.016174320080608595, 0.0614142045378685, 0.046036014100536704, 0.03458908751781564, 0.09130548613029532, 0.019013984892808367, 0.04465431695280131, 0.04804306343430653, 0.018160895415348932, 0.09444782845093869, 0.019712451612576842, 0.07278912424226291, 0.09042299832799472, 0.13232789933681488, 0.01253391874342924, 0.032140875919139944, 0.021344066990423016, 0.033990285664913245, 0.018188885514973663, 0.015546734030067455, 0.013000753751839511, 0.069005432742415, 0.04064365442900453, 0.03943904484913219, 0.015677279661758803, 0.023274263221537694, 0.011844602704513818, 0.007841498027119087, 0.04662041086703539, 0.02295626592967892, 0.06260939626372419, 0.030033504917810205, 0.026464375732757617, 0.026117664747289382, 0.05106670665554702, 0.04703762402641587, 0.04879629508650396, 0.02075215041259071, 0.02902679829276167, 0.02669830068043666, 0.06117585639003664, 0.01106542371417163, 0.04921482926874887, 0.10589899640763178, 0.057610066869528964, 0.06450013621360995, 0.030815403879387304, 0.029255904846650083, 0.053575206620735116, 0.04848216995014809, 0.009889180873869918, 0.022580820841540117, 0.08810633240500465, 0.026332611123507377, 0.0952269350818824, 0.045997778652235866, 0.03574247035430744, 0.04229523729009088, 0.07401283670333214, 0.029920390479674097, 0.019695898008649237, 0.03242501086788252, 0.029349767974053975, 0.030291620169009548, 0.02060769507806981, 0.015156174176809145, 0.015361380792455748, 0.056962042071972974, 0.04228572295687627, 0.021031871438026428, 0.03673908191558439, 0.06341124972095713, 0.0125437763199443, 0.049662893507047556, 0.03979775821790099, 0.016111779295897577, 0.012088050334568834, 0.03979670065746177, 0.05028084648074582, 0.04900884989183396, 0.015229243253997993, 0.013754606025031535, 0.020508215748122893, 0.074430673266761, 0.027962705098616425, 0.03269347165769432, 0.01909490496473154, 0.0453369777824264, 0.05803115403978154, 0.02576448594481917, 0.07441816807840951, 0.05937478272244334, 0.056732506927801296, 0.04749885396449827, 0.030186220355972182, 0.026755798571684863, 0.03194749449903611, 0.052763605053769425, 0.0631731835892424, 0.033648181561147794, 0.028461317015171517, 0.0760459279990755, 0.10495084337890148, 0.033740382277756, 0.06590537799638696, 0.04111731905140914, 0.006929113733349368, 0.011841146151709836, 0.10230971049168147, 0.05936345012742095, 0.028882981205242686, 0.03405755021958612, 0.05968476296402514, 0.02388023607636569, 0.03924106582417153, 0.027963528882537503, 0.06278346700128168, 0.0777169106004294, 0.027691110590239987, 0.04520776616118383, 0.03904028890246991, 0.04051775649713818, 0.023904660156404134, 0.04310987795179244, 0.026072067194036208, 0.011323109447403112, 0.05262148748442996, 0.020217356941429898, 0.05149165299371816, 0.07378169480944052, 0.09447732139960863, 0.08533227344742045, 0.029410941351670772, 0.032132337510120124, 0.057346366957062855, 0.02921643743320601, 0.03168941264448222, 0.09696946814074181, 0.013195694609748898, 0.036166455611237325, 0.04010974596894812, 0.034884406632045284, 0.010413978543510893, 0.017998697185248602, 0.018718252031248994, 0.058400424459250644, 0.005760147651017178, 0.01992524576053256, 0.022392792161554098, 0.04246211290592328, 0.05880785240151454, 0.08087969908956438, 0.04020636246423237, 0.023044735498842783, 0.02834355858794879, 0.05897748138522729, 0.06341772867017426, 0.03169203242578078, 0.02710907756409142, 0.07332161520025693, 0.03666796561446972, 0.019090021633019205, 0.03424174756219145, 0.015259282608894864, 0.04875947714026552, 0.04613231518305838, 0.04368975874967873, 0.020391637335706037, 0.021061108345747925, 0.04780085240781773, 0.05200537503696978, 0.06547035329276696, 0.00474971869152796, 0.013421022704278585, 0.04869257994869258, 0.057093532086582854, 0.030515704238496255, 0.01575368190970039, 0.023013880709186196, 0.018195119555457495, 0.06662735409918241, 0.038779279275331646, 0.013241255983302835, 0.05487411719514057, 0.05233042829786427, 0.04282847039576154, 0.004636330586436088, 0.02401307679974707, 0.05413911640061997, 0.03846583320409991, 0.01895719575259136, 0.013115858073433628, 0.07067510174238123, 0.06794851797167212, 0.01506770739069907, 0.08432658913079649, 0.042372773168608546, 0.03200490333256312, 0.01397481979438453, 0.10186807325226255, 0.04738408082630485, 0.049308807429042645, 0.010780943666759413, 0.08682361178216524, 0.03554195318429265, 0.06536380315083079, 0.059740516808233224, 0.03944868905819021, 0.13684005331015214, 0.022883928795636166, 0.05792303054477088, 0.0623785809148103, 0.072873781027738, 0.053127031060284935, 0.0556881233205786, 0.08640782354632393, 0.03726481932972092, 0.05494685137819033, 0.024517945021216292, 0.08706004518899135, 0.01873112458270043, 0.019499967311276123, 0.041562444384908304, 0.04760309973789845, 0.05320475247572176, 0.024097854184219614, 0.058289992884965613, 0.025384343061887193, 0.039983888855203986, 0.011960104075114941, 0.07328686784603633, 0.0035914720047003357, 0.01084160125174094, 0.04823597730137408, 0.08412102164584212, 0.10532592481467873, 0.024050447646004613, 0.037346552053350024, 0.017067238768504467, 0.033600146052776836, 0.03980289387982339, 0.02180953830247745, 0.04092457216756884, 0.017662138779996894, 0.021563931950367987, 0.01714606783934869, 0.02743825902143726, 0.028723066934617236, 0.03784822532907128, 0.03638899972429499, 0.031287506280932575, 0.027506588558026124, 0.03622865871875547, 0.02749875704466831, 0.04151788954914082, 0.06731876856065355, 0.02125591468939092, 0.06564262803294696, 0.03496625809930265, 0.042502942160353996, 0.039994193575694226, 0.046146390013745986, 0.0041314920508739306, 0.03624162403866649, 0.03187399219314102, 0.053356224816525355, 0.0654587015742436, 0.07116160923033021, 0.004228118750688736, 0.044728156935889274, 0.06849260869785212, 0.04684563784394413, 0.022146749797684606, 0.059125131665496156, 0.03147674651700072, 0.06590447257622145, 0.050542564858915284, 0.016611330029263627, 0.02649743099027546, 0.0562261061713798, 0.0747480898280628, 0.04168094681517687, 0.027282114861009177, 0.0299341999925673, 0.0839657272445038, 0.06079063350625802, 0.014488718097709352, 0.02174162436858751, 0.04084961525222752, 0.046291316612041555, 0.042003595517599024, 0.030821463515167125, 0.013509859636542387, 0.026052175780932885, 0.053923793384456076, 0.015651749781682156, 0.026096687943208963, 0.0411808914213907, 0.03867103332595434, 0.03188058617524803, 0.04053822121932171, 0.02513434134016279, 0.10578613058896735, 0.01845363927714061, 0.0646914989920333, 0.07449120283126831, 0.021424578881124035, 0.031075584156496916, 0.035927884819102474, 0.04039750259835273, 0.015419149567605928, 0.03919681897968985, 0.027254673950665165, 0.042227742669638246, 0.04162596109381411, 0.03486451336357277, 0.005392110588218202, 0.02382027611020021, 0.09019614604767412, 0.033277697730227374, 0.0544243905460462, 0.0502842158311978, 0.006317615125226439, 0.0512224092381075, 0.022175162921485025, 0.023917488178994972, 0.030739179746888112, 0.1662405749084428, 0.020889295592496637, 0.04624056855391245, 0.07136375541449524, 0.02468048649461707, 0.027313967839290854, 0.05338276401744224, 0.057176916088792495, 0.04313512210501358, 0.035923524701502174, 0.07108973222784698, 0.15352632355643436, 0.1125439714815002, 0.1305941681494005, 0.08036327562876977, 0.163238646928221, 0.08988192814285867, 0.14168816269375384, 0.1452014155802317, 0.1351302638067864, 0.14281763724284247, 0.12517101306002587, 0.12934587575728074, 0.1253462489694357, 0.162360715912655, 0.07567241249489598, 0.16082625137642026, 0.1389875466702506, 0.10131308779818937, 0.19628495414508507, 0.10453698472701944, 0.09510743446298875, 0.2215772875933908, 0.16223618353251368, 0.148770077212248, 0.07804489534464665, 0.15730336541309953, 0.22249099012697116, 0.26972217368893325, 0.11440129994298331, 0.09764494869159535, 0.14646115188952535, 0.1010679935279768, 0.10048702548374422, 0.23880750755779445, 0.10991182600264437, 0.09055133050424047, 0.1262098120059818, 0.15325882384786382, 0.12325773408520035, 0.14836416696198285, 0.13575709657743573, 0.19274621590739116, 0.10982020787196234, 0.13532087701605633, 0.14078973355935887, 0.0859726726775989, 0.26839580736123025, 0.11718451700289734, 0.1031080461689271, 0.1715117975254543, 0.1531159455771558, 0.12950708507560194, 0.1612909248797223, 0.11397281356039457, 0.22362286923453212, 0.1289036893285811, 0.08741174155147746, 0.11411920218961313, 0.16306771547533572, 0.16215104435104877, 0.1983604591805488, 0.17632423929171637, 0.1668350351974368, 0.1590073067927733, 0.11841745435958728, 0.09261943632736802, 0.177624303905759, 0.148055745230522, 0.14281880983617157, 0.1307675041607581, 0.07694216779782437, 0.18607079051434994, 0.18686494790017605, 0.1303910423303023, 0.1296384452143684, 0.15525103022810072, 0.10714398624259047, 0.1451396243646741, 0.14846637554001063, 0.14929333585314453, 0.1802808660431765, 0.15020430728327483, 0.10562003051745705, 0.1742890477180481, 0.24638703209348023, 0.10420004226034507, 0.1724949650815688, 0.12044117975165136, 0.1342383655719459, 0.104196517058881, 0.10402420521131717, 0.14061507652513683, 0.1267563592409715, 0.22196225443622097, 0.10328907083021477, 0.19588618335546926, 0.094043365388643, 0.1322388564585708, 0.12383881345158443, 0.09472781850490719, 0.10868659213883802, 0.14551998989190906, 0.17707512946799397, 0.10979493774357252, 0.13426475634332746, 0.18944656796520576, 0.19632658862974495, 0.17850416450528428, 0.1385607523843646, 0.11776788218412548, 0.15541262546321377, 0.15827427268959582, 0.12484936625696719, 0.11049323933548294, 0.07396480490569957, 0.1919624040601775, 0.15142089512664825, 0.1585287254420109, 0.2217088852194138, 0.18741685344139114, 0.09920996744767763, 0.11099425581051037, 0.1433709528646432, 0.10812869004439563, 0.09115745735471137, 0.14563928270945325, 0.11373422050382942, 0.14820502081420273, 0.1273082647821866, 0.21629033144563437, 0.08711611444596201, 0.22389195713913068, 0.11873458148329519, 0.14025277487235144, 0.16871493979124352, 0.1118621975183487, 0.20580316137056798, 0.13035000156378374, 0.1295137792476453, 0.11862880317494273, 0.14035688334843144, 0.1233255812257994, 0.140735259919893, 0.1724731014110148, 0.20292723522288725, 0.1639480807352811, 0.11530625255545601, 0.1344820423400961, 0.16266391292447224, 0.07916292597656138, 0.16664121591020375, 0.20518688193988055, 0.08711455593584105, 0.11003295934642665, 0.11315292591461912, 0.09232399475877173, 0.1605015023960732, 0.12669145100517198, 0.10871555816265754, 0.10959810533677228, 0.10237595459329896, 0.1233751789550297, 0.14072684396523982, 0.15442071540746838, 0.1000252686208114, 0.36794488434679806, 0.16308523016050458, 0.17458345770137385, 0.20329039776697755, 0.10075546029838733, 0.09686412027804181, 0.12548810307634994, 0.1060173541191034, 0.17497612803708762, 0.16297730704536662], [0.007309230641112663, 0.02789220292470418, 0.10201393495663069, 0.05992333004542161, 0.046474204063997604, 0.060614911490119994, 0.025806504490901716, 0.007789880728523713, 0.021034392884757835, 0.03354507498443127, 0.058285896229790524, 0.020750129915541038, 0.08072584445471875, 0.060151692596264184, 0.05395038824644871, 0.03910368315700907, 0.009299878511228599, 0.058665170799940825, 0.02583231638709549, 0.03744173620361835, 0.04455654270714149, 0.021003797846788075, 0.0590954643121222, 0.06829693404142745, 0.023170661261247005, 0.03719776628713589, 0.04098060802789405, 0.02773475815047277, 0.13801788620185107, 0.06470964450272731, 0.04618223574652802, 0.0500770824146457, 0.020801994905923493, 0.03463445129455067, 0.006336377082334366, 0.03986438452557195, 0.03850799461361021, 0.019110388020635583, 0.03036666428670287, 0.028569726237037685, 0.02787268258543918, 0.02345125987631036, 0.10437527074827813, 0.006098102685427875, 0.02002360073674936, 0.02432073040836258, 0.06591556768398732, 0.021448390689329244, 0.007276848882611375, 0.05705792013031896, 0.03740814659977332, 0.031053987659106497, 0.01201311475597322, 0.03248770008212887, 0.051576588084571995, 0.045509887058869936, 0.06959899503272027, 0.022308053739834577, 0.01737661601509899, 0.013931572993897134, 0.038203584190341644, 0.03324345874716528, 0.02440166903397767, 0.03578589341486804, 0.057803696909104474, 0.003707011410369887, 0.05133859987836331, 0.022072646352171432, 0.05558475328143686, 0.05426169322163332, 0.08011002515559085, 0.007089778036970529, 0.022984042661846615, 0.020919139205943793, 0.03827890475804452, 0.03800199832767248, 0.0277302366157528, 0.010446584801684367, 0.0452632342785364, 0.0703575144871138, 0.04895446159935091, 0.07460653258021921, 0.026810242525243666, 0.11863607622217387, 0.012793451496690977, 0.029375793237704784, 0.07678842448513024, 0.04773853797814809, 0.030515140206262004, 0.06856648207758553, 0.006997397349550738, 0.06016109931806568, 0.03996121624368243, 0.06024770424119197, 0.05178919112950098, 0.01863417412096169, 0.06762245538993739, 0.05432958118035458, 0.014905068510415731, 0.06798587768571451, 0.015230803619488142, 0.09670495928730816, 0.05386602089856751, 0.040485395147698, 0.0706995184009429, 0.013347443400562042, 0.036004544963361695, 0.023975329313543625, 0.02291324362886371, 0.06295181578025222, 0.09342920850031078, 0.08551960636395961, 0.04583797199302353, 0.04925584406009875, 0.07558331766631454, 0.061136704389355145, 0.09154600877081975, 0.029430613831209484, 0.08114241194562055, 0.02807904231303837, 0.06504562959889881, 0.04384979547467083, 0.011711069928423967, 0.058405912641319446, 0.050899908965220675, 0.0632438508910127, 0.06770435880753212, 0.03400014138605911, 0.03765245790418703, 0.05500423794728704, 0.05596861803496722, 0.03670152924314607, 0.0731900027312804, 0.02398384916887153, 0.017062464903574437, 0.021732199093094096, 0.05361016548704356, 0.055443181190639734, 0.04013179146568291, 0.03526888736814726, 0.01647435739869252, 0.019899404178431723, 0.11221961583942175, 0.05444586829980835, 0.05062878015451133, 0.07698955392697826, 0.00738548677873041, 0.05170685726625379, 0.022091754799475893, 0.03130664255877491, 0.08133740382618271, 0.014678934257972287, 0.03272613728768192, 0.0929340030415915, 0.03428882198932115, 0.09041335040819831, 0.026243761203659233, 0.037900773095316254, 0.04742014920338988, 0.04689025205152575, 0.025075726516661234, 0.01458413138607284, 0.0620921267545782, 0.012837350459449226, 0.04871040262514725, 0.005275549337966368, 0.016048628094722517, 0.07420588415698148, 0.08852724145981483, 0.0481824127928121, 0.05307198967784643, 0.02177049947931664, 0.03948059027607087, 0.051807410854962654, 0.09757779174833558, 0.03592071938328445, 0.03137944724585395, 0.006056759029888781, 0.09563015133608133, 0.08072863492998295, 0.03503905907564331, 0.07767817791318521, 0.03756724821869284, 0.017998159128183033, 0.06526525336084887, 0.02595547579403501, 0.02966328083857661, 0.019841973080474418, 0.07810821538441814, 0.01894093529699603, 0.01908668938995106, 0.045530348070315085, 0.02887453927542083, 0.06397361212293617, 0.06951881339773536, 0.06634587232838385, 0.014211037050699815, 0.009302549315179931, 0.07739507083897479, 0.042001472975243814, 0.019162304961355403, 0.023912651231512427, 0.017104164326156024, 0.06891407436341979, 0.06027543458912987, 0.0725614778639283, 0.04806216631550342, 0.023818593290343415, 0.04294017475331202, 0.029381748972809874, 0.04830942394619342, 0.023570406119688414, 0.03443066125328187, 0.08226803474826738, 0.05480458909005392, 0.059093274976476096, 0.029489130320143886, 0.026140589689021, 0.027511926455190405, 0.04186241305433214, 0.04860704000748228, 0.02753743036009837, 0.03132006058876868, 0.06132618211267982, 0.037510518450289965, 0.06929073657374829, 0.06584567221580073, 0.021026505710324273, 0.013844733366568107, 0.04137423944484908, 0.08788173625362106, 0.04660494450945407, 0.07719208602793515, 0.07681330127525143, 0.07386808822047897, 0.05427120755484793, 0.032013623567763716, 0.05146744042576756, 0.09243943582987413, 0.04065934343088884, 0.029843029005860444, 0.010803602363012033, 0.03342678406625055, 0.023912337674119044, 0.01764665201335447, 0.009061509954335634, 0.04412806374602951, 0.04757601134770084, 0.0425739397178404, 0.03451627169852145, 0.029018495515629184, 0.01907502653921256, 0.013887787208659574, 0.023994161310838535, 0.01943075276358286, 0.0442152883624658, 0.01247547925231629, 0.07271844209753908, 0.011499080083012814, 0.17047339933924377, 0.014788418666284997, 0.11176177009474486, 0.03227041037462186, 0.07787482478306629, 0.020406057265063282, 0.03147762225125916, 0.021301465858414304, 0.06397642486263067, 0.02371259604842635, 0.031042347072798293, 0.046689248774782754, 0.011374870537110837, 0.019034631441172678, 0.040398070341325365, 0.003993043937953189, 0.021969265180814546, 0.0629303751338739, 0.020506955952441785, 0.046591222198912874, 0.03181662046699785, 0.033412686971132644, 0.07283956801984459, 0.09054565307451412, 0.04932633324642666, 0.07324817226617597, 0.10926724848104641, 0.039380355810862966, 0.09276467462768778, 0.025872262485790998, 0.027081330517830793, 0.054284417783492245, 0.02881106895074481, 0.07064428034937009, 0.026260873273713514, 0.08108542984700762, 0.10181993755395524, 0.03278885989857372, 0.013407433980319183, 0.017030971866915934, 0.042321149376221, 0.015814497201063205, 0.02677839140233118, 0.02910786493885098, 0.012445495558495168, 0.027909480122616515, 0.009972524057957344, 0.028102451506129, 0.06965098989894614, 0.015444366817973787, 0.04141202589380555, 0.023590188066009432, 0.008649505743960617, 0.039577255010954104, 0.01207213404995855, 0.09226432608556934, 0.04870916323852725, 0.0063607645188312745, 0.09863237617537379, 0.0322088529355824, 0.03687075004563667, 0.012891182141174795, 0.09255993092665449, 0.026944717828882858, 0.01604509547178168, 0.009669573810242582, 0.04082210383785423, 0.11727876975783147, 0.023909352385089733, 0.012276032630325062, 0.044431201386032626, 0.06612326513277367, 0.10862460796488449, 0.02252094251161907, 0.018546233332017437, 0.031345056122518145, 0.07392115920083597, 0.0396268750046147, 0.09265380518627353, 0.0328980186895933, 0.050275959438295104, 0.013909105400671251, 0.07392681436613202, 0.026483174333407078, 0.05217296311457176, 0.05257874719973188, 0.015205241270450642, 0.04741807118989527, 0.02012049368204316, 0.048275541194016114, 0.022475285586551763, 0.024239684171334375, 0.05402658454841003, 0.16164464730536565, 0.11454994470113888, 0.2017237537074834, 0.14436853292863816, 0.11198961685295217, 0.1688546416698955, 0.18862204189645126, 0.10642663371982053, 0.13543896755436435, 0.10194064787356183, 0.10887768774409778, 0.0929026398807764, 0.1862498707487248, 0.12945120135555044, 0.11120195325929672, 0.08646113201393746, 0.07204426030511968, 0.17108820931753144, 0.16104635753436014, 0.18169014510931447, 0.12677374033955857, 0.10621612353133969, 0.30064770486205816, 0.13063375430647284, 0.10234676592517644, 0.061656129837501794, 0.1451257462031208, 0.12489212880609557, 0.1874604620388709, 0.2849552594125271, 0.24741143337450922, 0.1156573106709402, 0.1252683234633878, 0.12072245372110046, 0.12147413799539208, 0.1370571315055713, 0.14378188003320247, 0.12302353454288095, 0.1588753826217726, 0.11805107089458033, 0.13815638580126688, 0.09999860325478949, 0.1871174413827248, 0.10144784697331488, 0.18930035002995282, 0.07665899393032305, 0.10951668431516737, 0.2128751459531486, 0.11691358857206069, 0.17623593856114894, 0.17859449872048572, 0.14185355772497132, 0.12802231474779546, 0.15645483828848228, 0.16886886121938005, 0.15794180537341163, 0.14424584107473493, 0.1421100291190669, 0.1286644654464908, 0.08833271713228896, 0.1323280922952108, 0.13638388481922448, 0.13908274937421083, 0.09558241639751941, 0.09964758224668913, 0.08177216135663912, 0.10262537558446638, 0.07819096485036425, 0.09312723603216, 0.15332959505030885, 0.10811884174472652, 0.13733478379435837, 0.13370075379498303, 0.07335553877055645, 0.11582237915717997, 0.22017697367118672, 0.08810320796328597, 0.09739813263877295, 0.15333888673922047, 0.12375005258945748, 0.09921607532305643, 0.21416228235466406, 0.1750004111090675, 0.3391875821398571, 0.12234815789270215, 0.22457039885921404, 0.21837489068275318, 0.18077478016493842, 0.11722583236405626, 0.16891045117517933, 0.10146159896976314, 0.19972353213233873, 0.1681357083725743, 0.18620504502905533, 0.14736106531927362, 0.11400796909583732, 0.13249020703369752, 0.15606822387780994, 0.07695700332988054, 0.15695477864937857, 0.14217823249055073, 0.15464387921383604, 0.13950289401691407, 0.14092186553170905, 0.1292087120236829, 0.12322286056587473, 0.14514888636767864, 0.2000717181363143, 0.17254934966331348, 0.18168981856433675, 0.14547663362463936, 0.2563835238106549, 0.16906832082895562, 0.12747737055178732, 0.20785747066838667, 0.09841976570896804, 0.24976065731607378, 0.10313488222891465, 0.1367720280541107, 0.19371976522961631, 0.1190466174739413, 0.12488341599237174, 0.0703190489730332, 0.15257784398272634, 0.1510778596275486, 0.21146150305867195, 0.27074108307715505, 0.0870683572429698, 0.14810713153565302, 0.0930054644413758, 0.28678177390247583, 0.22243411192903295, 0.10123721061972901, 0.11852953350171447, 0.10490621061762795, 0.21986835898132995, 0.16568011982599273, 0.12293691848753951, 0.09298428354668431, 0.15095083363121375, 0.053630184920621105, 0.14128360315226018, 0.14724772452609614, 0.12199330740259029, 0.10804703153553419, 0.2767718938412145, 0.09519098544842564, 0.10849211234017275, 0.18493620998924598, 0.11166312382556498, 0.2325913676759228, 0.12479067721869797, 0.10170687877689488, 0.15462229755939916, 0.11289376052445732, 0.1610735201393254, 0.11979988252278417, 0.34566255344543606, 0.11238007558858953, 0.08421907419688068, 0.1473856155644171, 0.11645256643532775, 0.2311948238639161, 0.13135386019712314, 0.1589372183661908, 0.1473478996194899, 0.12568242702400312, 0.16031007282435894, 0.19193590938812122, 0.1094498836027924, 0.18123710848158225, 0.09033163252752274, 0.1766864667297341, 0.09646701189922169, 0.1852983483695425, 0.14151734998449683], [0.06887712283059955, 0.03902170552464668, 0.07340855037909932, 0.015976912509358954, 0.03816566415480338, 0.037902105250395834, 0.054417432911577635, 0.06258135050302371, 0.07440522502292879, 0.03653709529316984, 0.006036575396137778, 0.031290901606553234, 0.03515845208312385, 0.050914896637550555, 0.027655313097056933, 0.05474067533214111, 0.07254066804307513, 0.0819911171856802, 0.03632426589319948, 0.03277543444710318, 0.058875302493106574, 0.04683208993810695, 0.0542985260108253, 0.03727877541678026, 0.020263919286662713, 0.02439056279399665, 0.04085280277649872, 0.05186827438592445, 0.04310664218792226, 0.043466468778206035, 0.03020842541445745, 0.021778132468170952, 0.043912566325161606, 0.058124627539655194, 0.007095358059814316, 0.010983460924762767, 0.03470915587968193, 0.038141110198921524, 0.05626636768283788, 0.03587072831578553, 0.06188775041664485, 0.04243630472046789, 0.0664565413899254, 0.03618164737417828, 0.006282808399191708, 0.05702801528968848, 0.05094881278637331, 0.09788557523279451, 0.060849259461974725, 0.0473965303535806, 0.033604676864342764, 0.03975049825385213, 0.05652537722198758, 0.05205392633797601, 0.009217139249813044, 0.0440757683099946, 0.033653643768047914, 0.02425839556963183, 0.04105278931092471, 0.030629210159531794, 0.05028168510762043, 0.015772979604662396, 0.008560441528970841, 0.03518908422847744, 0.06146975058072712, 0.011224247027712408, 0.03531610651407391, 0.06452747693401761, 0.06587180323549546, 0.036744981989613734, 0.035015688845305704, 0.02845938000973547, 0.01204903470352292, 0.043268500885460526, 0.12180816382169724, 0.006958144695090596, 0.04401965452416334, 0.0038685966728735366, 0.0405344845057698, 0.08923415938625112, 0.11550136317964643, 0.02935126340162242, 0.022487165515485685, 0.04051806819916237, 0.02746943850070238, 0.019493970758048818, 0.04835321436985396, 0.05511425020813476, 0.0563151638925774, 0.007584471877635224, 0.06930360541446134, 0.05120675734360702, 0.010736081767390715, 0.061120614627725445, 0.08758543379371986, 0.049515543796587735, 0.023800646304152906, 0.07104872114723548, 0.022973485611146316, 0.09998125184210949, 0.006665379032710916, 0.04734828704386018, 0.01393174647091655, 0.042928497059619986, 0.07153248268878087, 0.06519390328321606, 0.03268409833253827, 0.015918969329504762, 0.007217274833237752, 0.07691772145335563, 0.04610202813637443, 0.02501040267816279, 0.0513464146933984, 0.04531575978035107, 0.04212330764858052, 0.043581787394941784, 0.03943455856642686, 0.03485832756268792, 0.020942336886946578, 0.029228974162833765, 0.015818258034414612, 0.03311112268420402, 0.0441316520300461, 0.031041330330481287, 0.04502016236074269, 0.05365163669921458, 0.0246787535797921, 0.05588898558926303, 0.03758811370062176, 0.02976178609969793, 0.03156331062200479, 0.014641999423474772, 0.042159264703514054, 0.024498218735971022, 0.01933352028572699, 0.03492462732538115, 0.0070958455580694135, 0.038720063312212005, 0.019035807745240163, 0.016448111346107908, 0.03817753851762973, 0.02223916759248823, 0.023106634325813502, 0.015723589676781558, 0.023802112045814283, 0.02047349807980936, 0.06932502379640937, 0.024105912052618805, 0.06085988330596592, 0.058672766681411304, 0.034192580278613605, 0.03460879153863061, 0.09190087410388514, 0.0313577468477888, 0.05621027616143692, 0.018350707105128095, 0.06071484909625724, 0.050953811150975525, 0.012735050968331052, 0.04416092604515143, 0.07041221077088267, 0.06148013322672341, 0.013684624282177538, 0.020537999989755917, 0.07088394209858961, 0.048169610745389946, 0.04361955157946795, 0.09553789495839737, 0.02679512126633199, 0.02794977874145843, 0.0604739739355864, 0.026046669045172166, 0.021864190057385713, 0.05741612512792926, 0.01880902040284127, 0.013983389744680608, 0.011531771688169101, 0.028832739662902895, 0.06743549354723655, 0.037623807293130085, 0.1187577290693298, 0.03842425066977739, 0.034049835594487377, 0.06074128810723778, 0.027295685031276662, 0.013586619970737956, 0.11913678841665387, 0.03818392098764889, 0.06692330774967559, 0.0321244855877012, 0.03665427670057397, 0.021735711306973826, 0.03369998717971612, 0.03317268754472025, 0.005465686645038659, 0.08943662469391711, 0.031123267144721467, 0.05513102274562698, 0.026537529229244683, 0.043028015352319926, 0.023814127416699193, 0.04321747452195268, 0.046274711057776585, 0.0024363428019569255, 0.052607293910114095, 0.03329993618535809, 0.046136931341607124, 0.04248749064572621, 0.12643355468753725, 0.0597190316329943, 0.06655548451817594, 0.01801425445592031, 0.048618702858220786, 0.020746881164086517, 0.026103816271643154, 0.023040948690322693, 0.04589873533404898, 0.041368194652022794, 0.07320083808735944, 0.0246009598049568, 0.021689119275833946, 0.011711034676409326, 0.024262306687887758, 0.0643359508831054, 0.058652168372645974, 0.06337282131426036, 0.01882859640318202, 0.046701620376552455, 0.06321832843241282, 0.04826311022043228, 0.03790396061958745, 0.06613991892663762, 0.06194296991452575, 0.012830950363422744, 0.013835841509717284, 0.03773000120418146, 0.07824085943866521, 0.02785106382361846, 0.04322313339798711, 0.01335718872724101, 0.036763353855349123, 0.04521346956607886, 0.03257564087107312, 0.05899620948184747, 0.07543530373368412, 0.029338463209569454, 0.06452913192333654, 0.021733688954554964, 0.02191806626797188, 0.081006955151679, 0.04333484517701436, 0.025055694095499348, 0.01632288876862731, 0.022436326544266194, 0.030106365265964996, 0.06792504384065978, 0.05578517768299207, 0.09439739951631054, 0.027848559075209778, 0.019202520088583697, 0.04813537176232785, 0.05235321223153733, 0.04374251060653478, 0.06664215994533151, 0.010717913992266404, 0.07501228697947226, 0.04207191392197274, 0.03399650115170516, 0.05690607300493866, 0.022016762632119935, 0.04399398734676652, 0.10433671617647633, 0.043375741224735975, 0.01774102907802444, 0.015374697704828577, 0.11717575223883614, 0.02037120415479876, 0.06419969999114983, 0.027358300030755345, 0.06428815657272935, 0.011442444938438712, 0.04851725127082318, 0.034446906865923665, 0.04408163127664011, 0.049068711523432285, 0.010256566238240339, 0.02836198611475993, 0.01594154175108997, 0.056188427333836444, 0.06857690925244242, 0.03583994031941984, 0.01995338428969262, 0.018755116361717228, 0.016730530078348238, 0.03792777242779266, 0.019873299133905675, 0.055754508430254646, 0.04858460488321725, 0.05304460813931655, 0.05507787012902554, 0.024302770434587728, 0.05018215568270534, 0.05642519099637866, 0.046140445410856046, 0.027663432192639448, 0.03125772389466874, 0.03101218619121937, 0.013947676670795772, 0.05811320217617322, 0.011191097146365792, 0.058117974185734056, 0.12113047167076729, 0.004057652067785966, 0.026516186917433515, 0.06463481375249103, 0.06124306899437215, 0.01353016294160625, 0.05356329143978655, 0.03158388295560144, 0.01515843958259211, 0.03995945364295039, 0.03920230345102027, 0.1146857206185814, 0.08843769392115064, 0.10357054517953657, 0.062489168340107426, 0.014620419624407077, 0.036035102893947624, 0.04734344453027006, 0.026947009209834505, 0.04124914303247351, 0.02826063100656029, 0.037695072023780085, 0.021510623482754454, 0.020854466602031607, 0.029144200489099603, 0.01998668445594376, 0.04510516424488742, 0.0712834476144053, 0.0044997568602411775, 0.031887009463389404, 0.03333113607368432, 0.02908612001192523, 0.0822771705861669, 0.03833257687801961, 0.0458651345979888, 0.046569076512241736, 0.0806274579372257, 0.023795443848939613, 0.06139078606793191, 0.04693397939263377, 0.002544168278291181, 0.14890562306391075, 0.14405206631636247, 0.15083703270647675, 0.1373837803839706, 0.15005644178017974, 0.20261995639884844, 0.10534400353208184, 0.16559953743126243, 0.21159283351153135, 0.07699349473114125, 0.14017367677297443, 0.10407467867480591, 0.09561792074237019, 0.08913909026887268, 0.09779354892089032, 0.11974165361607447, 0.2009418566012755, 0.1955613007885404, 0.12568423786433414, 0.17912851850269362, 0.13881291932193562, 0.14628569333581254, 0.13422229065326974, 0.19545162620488554, 0.15265443362295628, 0.10469314001966268, 0.11454506879090331, 0.07725406278041191, 0.13003043277421966, 0.1100573834264651, 0.14535909227561206, 0.13534176105167717, 0.2854770189151168, 0.1512939581880346, 0.12457389588234946, 0.15942647180054337, 0.2542154135880992, 0.07499552186345682, 0.1395895323366858, 0.08552057115593925, 0.16182567196665332, 0.10708265515859239, 0.10601653033518232, 0.13276058627525344, 0.2080731387832202, 0.1411772979190573, 0.1393497592653148, 0.18469006929080933, 0.270355730317533, 0.28695920656900853, 0.16793437855085358, 0.12522245873697102, 0.21396000258391723, 0.131802904070355, 0.0904495375289116, 0.1915589428972453, 0.14086350303841755, 0.09205960464896634, 0.17737409623805434, 0.16676052357070148, 0.15430302562890574, 0.13119244307745248, 0.10825465476955287, 0.16267801373032853, 0.13097011047648266, 0.12086300906958058, 0.11089197301771492, 0.15024092484964058, 0.23313315032282844, 0.1443982930504717, 0.13893095048842952, 0.09251598836272024, 0.09567407163558528, 0.17939352459507063, 0.18556308728875592, 0.1306738005951047, 0.1183684726129286, 0.12761028920067474, 0.11751380792702548, 0.29364824295043945, 0.3367576125310734, 0.19912282295990735, 0.1596177974715829, 0.09792621523956768, 0.20175078272586688, 0.14474588533630595, 0.10638149629812688, 0.1806705232593231, 0.19442010030616075, 0.14496443298412487, 0.17640525213209912, 0.18986304639838636, 0.13103938254062086, 0.10935578669887036, 0.17599395388970152, 0.273645285051316, 0.11181034366018139, 0.14274600514909253, 0.20221781625878066, 0.18180636543547735, 0.12601775903021917, 0.1878154164296575, 0.10789833482704125, 0.2228615593048744, 0.15786800620844588, 0.16532890585949644, 0.07990694386535324, 0.11296984550426714, 0.21921860869042575, 0.12070123571902514, 0.12241816468304023, 0.12820268631912768, 0.14433847594773397, 0.10797592636663467, 0.13007424917304888, 0.1899032262736, 0.16865234705619514, 0.09114668879192322, 0.08641459935461171, 0.07061502488795668, 0.16521817742614076, 0.12027433011098765, 0.13571130606578663, 0.2279597576125525, 0.1558489934541285, 0.14843216253211722, 0.0694959626707714, 0.20387258293339983, 0.14349794917507097, 0.11293906121863984, 0.1258861317182891, 0.07968703066580929, 0.16338468674803153, 0.12093606608686969, 0.1257418136810884, 0.2035535336472094, 0.11813300399808213, 0.17978693707846105, 0.15860337065532804, 0.13554789999034256, 0.0768517074175179, 0.11755352024920285, 0.15986517013516277, 0.10757437252323143, 0.13803035428281873, 0.11208947282284498, 0.15008933376520872, 0.14640666340710595, 0.2067862547119148, 0.16269586980342865, 0.09461101930355653, 0.09464993752771989, 0.19624131586169824, 0.09208696021232754, 0.1622151065384969, 0.08490700798574835, 0.12248581144376658, 0.10709053676691838, 0.048661057226127014, 0.20597707625711337, 0.130964410782326, 0.10149464680580422, 0.1387419254751876, 0.0938524775847327, 0.10766083272756077, 0.11187776777660474, 0.14899871806846932, 0.25050969212315977, 0.15342947328463197, 0.08088594055152498, 0.166674003994558, 0.18234350223792717, 0.13857397745596245, 0.19726009166333824, 0.12582171329995617, 0.12866265460615978], [0.037221604070509784, 0.01981381228688406, 0.0920972389576491, 0.027587850017880555, 0.025022514528245665, 0.05832884802657645, 0.014868583602947183, 0.031088768409972545, 0.028103648219257593, 0.06460786637035199, 0.04841286820010282, 0.002824623566084483, 0.11786638002377003, 0.02717268518608762, 0.02923441967141116, 0.03981269765063189, 0.0163154543042765, 0.02748752463958226, 0.05804711392556783, 0.05300016091496218, 0.06378996768034995, 0.03348111669765785, 0.06112646275141742, 0.012136629466112936, 0.09727147029479966, 0.028811553202103823, 0.02634518124978058, 0.010030449611804215, 0.026800462874234654, 0.07825478955055587, 0.021857260253455024, 0.01843199454015121, 0.06592213569092564, 0.03769660084799398, 0.044617762468988076, 0.05992649159452412, 0.022259001489146613, 0.08278456953121349, 0.04479453091335017, 0.02585795387858525, 0.020500152313616127, 0.051519383341656066, 0.01703737103525782, 0.06761148644727655, 0.03661403003206942, 0.035683039168361574, 0.03486449480988085, 0.022712847057846375, 0.024639154435135424, 0.04644549779186491, 0.014266937469074037, 0.01587309718161123, 0.04202676165732555, 0.062148693250492215, 0.03234556766983587, 0.04278250919014681, 0.012247755876160227, 0.02686392948817229, 0.019028671995329205, 0.03259194956626743, 0.06835776788648218, 0.0479935176554136, 0.08516832560417242, 0.04736842151032761, 0.02376532749622129, 0.02405583563813707, 0.022813697505625896, 0.016990817966870964, 0.043897140785702504, 0.03719590349646751, 0.03413054044358432, 0.0562186475872295, 0.014262535605666926, 0.018665038187464233, 0.02745404821325792, 0.10033461061539128, 0.019257221938460134, 0.05441829751362093, 0.09870075024082325, 0.01816398089431459, 0.03830724366707727, 0.05726465278712567, 0.011682886870403308, 0.04099151017726399, 0.027765147242462263, 0.07623655605129898, 0.07261528357048519, 0.038824917646707036, 0.014345478030008962, 0.06075644647353329, 0.05145830458786804, 0.04260555149812717, 0.038948373912717216, 0.05384902200603392, 0.05768262664787471, 0.061945997877046466, 0.04053701522934716, 0.0720558526518289, 0.08738254546187818, 0.028070874977856874, 0.0619398603157606, 0.062264965526992455, 0.05564666324062273, 0.02993992380652344, 0.019678763674164657, 0.04539208966889419, 0.025265430595027283, 0.04403686863952316, 0.017870244410005398, 0.024207439710153267, 0.039408631637343206, 0.008074484157987172, 0.038438277260866016, 0.025613794714445248, 0.04360302395070903, 0.028264044885872863, 0.05682222516043112, 0.013535064827010501, 0.025357408667332493, 0.022232113478821702, 0.030588670342694968, 0.02783304633339867, 0.05979762878268957, 0.07548450070316903, 0.04025320311484393, 0.03582413999538403, 0.024452422658214346, 0.005588421636275598, 0.0031849754577706335, 0.02452824974170653, 0.05728298383473884, 0.059879754844587296, 0.005082284806121606, 0.03079892077948898, 0.06029776581272017, 0.02434679463476641, 0.08998706078273244, 0.03956443440984003, 0.06953794596483931, 0.022582440578844398, 0.0556700854212977, 0.0358134567795787, 0.08175447597750463, 0.03907898819306865, 0.049439803915447555, 0.0595473320572637, 0.012604807761817938, 0.026043835896416567, 0.014095308397372719, 0.049770156110753305, 0.005022625873607467, 0.018802322520059533, 0.006148860020402935, 0.02761725761956768, 0.02752011234406382, 0.02060934821201954, 0.022771983240090776, 0.04485381366976071, 0.021363711639423855, 0.06648939626757056, 0.04385602209367789, 0.07932157488539815, 0.04669755340728443, 0.07605682272696868, 0.02801132133754436, 0.014196350875863573, 0.037206571869319305, 0.03776812904106919, 0.04421321034897119, 0.04069179012731183, 0.016265767517325003, 0.041041527219931595, 0.058533565752441064, 0.07491283176932484, 0.06507500380394049, 0.06668478148640133, 0.03209643982700072, 0.01610234845429659, 0.07854863550164737, 0.0152698758392944, 0.02793996754917316, 0.05264688377792481, 0.016111051991174463, 0.05839073572133202, 0.020036634705320466, 0.026105697616003454, 0.016539811113034375, 0.062268327455967665, 0.10342881723772734, 0.022214739801711403, 0.04550428384391125, 0.07331316955969669, 0.03735699407116044, 0.05157861043699086, 0.0396636150253471, 0.032018569982028566, 0.03789163725741673, 0.04068419053510297, 0.04233553961967118, 0.017167111436720006, 0.06533836974995211, 0.011767566847993294, 0.03974196355557069, 0.061432732254615985, 0.09676081332145259, 0.06884720685775392, 0.060119023255538195, 0.021740505580964964, 0.029700339982809965, 0.04504637872742023, 0.07372957377810962, 0.06228804631973617, 0.001660869331772119, 0.0490432558581233, 0.0354211909143487, 0.04530878730292898, 0.0982031699095387, 0.03870970293064602, 0.016411818469350692, 0.059837374501512386, 0.03860039571009111, 0.02312539396370994, 0.07256523313117214, 0.07697372391703539, 0.07030122258584015, 0.020249384324415587, 0.02343835021747509, 0.01739408246066887, 0.03873823108733632, 0.05093840416520834, 0.04189362036413513, 0.09968651531380601, 0.06223247430170886, 0.022738953957741614, 0.05951831037236843, 0.0379622897162335, 0.04092889517778531, 0.03138621192192659, 0.07298197131603956, 0.03919257389497943, 0.05463714202051051, 0.008074701236182591, 0.021483379241544753, 0.037197885030764155, 0.058658365305745974, 0.07760699110804126, 0.013378146049944917, 0.06545260854181834, 0.02012882428971352, 0.0438224028039258, 0.001296475866183755, 0.07122954542865045, 0.0725294764561113, 0.07577681040856987, 0.012742763738060603, 0.01891097293992061, 0.03536720709234942, 0.031590833168593235, 0.05063432399765588, 0.09054793888935819, 0.04562744696158916, 0.05282042016915511, 0.05889887310331687, 0.02366656804952072, 0.049048447181121446, 0.017094731629185844, 0.05391850929299835, 0.07724374692770652, 0.0395241172373062, 0.05863228994712699, 0.06060423569579143, 0.04117450524063315, 0.032898690333240665, 0.08221726442570798, 0.035849933337885886, 0.08200093579944223, 0.035809467735816725, 0.032666030747350305, 0.04785986056958791, 0.05970762482320424, 0.021043493470642716, 0.051426106510916725, 0.05045134748797864, 0.056868824613047764, 0.04287180810933933, 0.05527748187887482, 0.014159984712023288, 0.02328400205442449, 0.018057584748021327, 0.05233608346316032, 0.06744839949533343, 0.03678804510855116, 0.014745742391824024, 0.0017402763501195295, 0.038351898692781106, 0.025354026329296175, 0.05914452769502532, 0.04330498857598286, 0.08449942048173398, 0.01648701843805611, 0.05188808972889092, 0.05900597614527214, 0.05403205046604853, 0.05792315299913753, 0.03345578348671552, 0.015771324615343474, 0.09228345865267329, 0.005583159809248173, 0.015828269606572576, 0.05022951212595217, 0.05547307118831668, 0.011635523933364311, 0.07009518754784949, 0.016818075673654675, 0.05846155887411442, 0.026916117312794086, 0.01222863536895602, 0.014101800334174186, 0.036584496265277267, 0.021376367112679873, 0.04788759833900258, 0.05726828188926447, 0.013252287080831593, 0.00842176752485102, 0.05062446085503325, 0.05981354785035364, 0.019995341608591843, 0.06440580182243139, 0.04345068329712376, 0.03177346457960084, 0.01351739707388333, 0.03719320950040128, 0.03683165370603092, 0.04081890518136788, 0.008469013573630946, 0.030487556432490237, 0.05071160754596349, 0.029491731547750533, 0.05251521564787254, 0.03283868027210701, 0.03539229539455846, 0.02674682229553582, 0.045315199458855204, 0.08719973964616656, 0.027902127294510137, 0.0344413889979478, 0.04982310092600528, 0.04700463927292731, 0.018586684091133066, 0.017371365320286714, 0.04131519417569507, 0.050911775906570256, 0.14177058561472222, 0.10167593121877871, 0.14139112550765276, 0.15164361364440992, 0.07960587681736797, 0.1492531262920238, 0.07476947852410376, 0.14052521728444844, 0.09670803177868947, 0.10160679274122231, 0.12783302256138995, 0.12420805418514647, 0.1873517967760563, 0.08530225357390009, 0.1377962512196973, 0.09931987209711224, 0.06876360392197967, 0.1447801131871529, 0.17534979939227924, 0.13838136044796556, 0.14353358710650355, 0.132908659579698, 0.25627701077610254, 0.056734169338596985, 0.16485023545101285, 0.14692771044792607, 0.11364030171534978, 0.12224836871610023, 0.2229389504645951, 0.21951735281618312, 0.08539943039068021, 0.1710908068343997, 0.13279151899041608, 0.12370245865895413, 0.2507553726900369, 0.21210175385931507, 0.10851703365915455, 0.11328390013659373, 0.1458579342579469, 0.07366194186033681, 0.1511199097149074, 0.1319532928755507, 0.10483198842848651, 0.15891913964878768, 0.10668619244825095, 0.13811901124427095, 0.1293745671864599, 0.1863531331764534, 0.22920294402865693, 0.1587260773521848, 0.1390008904854767, 0.10122486870386638, 0.11497731044073589, 0.13798975880490616, 0.09543820226099342, 0.1972092397045344, 0.1121753615734633, 0.12845409626606852, 0.13716833491344005, 0.10354985410231166, 0.1586993006640114, 0.08761471894104034, 0.215937499597203, 0.11416808003559709, 0.13883951789466664, 0.094094180240063, 0.09515681696939282, 0.17898994468851015, 0.24384384043514729, 0.19315132463816553, 0.10583583964034915, 0.17174100241390988, 0.09064295605639927, 0.09417621724423952, 0.18110758886905387, 0.1907705594203435, 0.1461112589458935, 0.2333058777730912, 0.18358220608206466, 0.10657238410203718, 0.1506935161887668, 0.2621884841937572, 0.18721599859418347, 0.2624913991894573, 0.14001996314618737, 0.30005891458131373, 0.1274726356496103, 0.17049440211849287, 0.10294218358467333, 0.20884053432382643, 0.17719004361424595, 0.23651634925045073, 0.13820260675856844, 0.14130269119050354, 0.20586121216183528, 0.15820534201338887, 0.23439098673406988, 0.14482827857136726, 0.14324903284432366, 0.1372255099704489, 0.21931140683591366, 0.21770318766357377, 0.09021308927913196, 0.15109112922800705, 0.1135478523792699, 0.2039211490773596, 0.1873673967202194, 0.18619627284351736, 0.1263690323685296, 0.24211523006670177, 0.17484800366219133, 0.15583432861603796, 0.11673153974697925, 0.18522775528253987, 0.19844625145196915, 0.10450702422531322, 0.1562049868516624, 0.10624274436850101, 0.08106059758574702, 0.10960393861751072, 0.16638567962218076, 0.11585548636503518, 0.185262517479714, 0.17293548909947276, 0.1308847634936683, 0.1246035669464618, 0.17163159500341862, 0.16061717353295535, 0.10947950271656737, 0.16539087519049644, 0.14585704368073493, 0.18012958666076884, 0.12516451184637845, 0.1241387969639618, 0.25469564250670373, 0.08189923188183457, 0.12051494923071004, 0.09624357349821366, 0.17415994370821863, 0.1608441668213345, 0.18457827216479927, 0.18534396076574922, 0.1713856917922385, 0.10970104121952318, 0.1204569281253498, 0.20990996912587434, 0.13440408714814112, 0.13321424630703405, 0.08970748633146286, 0.16734913573600352, 0.04955744545441121, 0.15512312849750742, 0.10976070989272557, 0.11485552400699817, 0.10500584394321777, 0.1553627976682037, 0.14193875627825037, 0.16237061616266146, 0.11677580885589123, 0.1961439906153828, 0.19296737591503188, 0.20787909685168415, 0.19705775252077729, 0.14475724019575864, 0.1171174862247426, 0.12456197699066252, 0.23056444362737238, 0.17442705749999732, 0.12754995259456336, 0.12715138960629702, 0.1330576531472616, 0.1467495207907632, 0.19765718519920483, 0.1559828026802279, 0.19689562293933704, 0.17453622742323205], [0.036743352975463495, 0.03056445963011356, 0.04765424113429617, 0.07709153986070305, 0.0705002443282865, 0.0390920351492241, 0.05229375135968439, 0.035558124582166784, 0.016708937291696202, 0.0400576954416465, 0.028425020427675918, 0.052824334998149425, 0.03025694146344904, 0.029244455363368616, 0.026331726112402976, 0.005259108911559451, 0.06796328671043739, 0.014569322756869951, 0.03449067131441552, 0.017265559181396384, 0.0460652510082582, 0.015570716532238293, 0.0674893957329914, 0.05458295410790015, 0.012043065053148894, 0.030462674076261465, 0.060218656581128016, 0.01477068597523612, 0.005588284338955418, 0.06381898565450683, 0.02737775543209864, 0.045770202777930535, 0.04753943831019569, 0.05497077821928542, 0.06799603026593104, 0.03900751195033081, 0.09112844680203125, 0.0632092371233739, 0.01587344228028087, 0.028475709113990888, 0.023791705280018505, 0.05437071100459434, 0.04622665328497533, 0.10330239980248734, 0.026792959761223756, 0.023760963667882606, 0.04520638205576688, 0.04377974044473376, 0.05969109719444532, 0.0235027964663459, 0.03517405202728696, 0.042254137151758187, 0.03709440366947092, 0.04305927832319867, 0.03479477374639828, 0.090541652898537, 0.0648452051973436, 0.08420307349297218, 0.08984661675640382, 0.08667682981467806, 0.04713516449555755, 0.028741403548337985, 0.030578695877920836, 0.044167200903757475, 0.01793492443539435, 0.07434769373503514, 0.0242145364973112, 0.03964099807490129, 0.08323722766363062, 0.036517740081762895, 0.049273199183517136, 0.061520635936176404, 0.010156300231756177, 0.04371334791358095, 0.026591056630422827, 0.09115572072914802, 0.033005964069161564, 0.05700794390577357, 0.14067435928154737, 0.022086578319431283, 0.029728762383456342, 0.0567099307954777, 0.059896920720348135, 0.060780610801884905, 0.053555777194560505, 0.05409680656157434, 0.028435920721676666, 0.02102391932567116, 0.03181690248311497, 0.04568713789922185, 0.0427984468115028, 0.05677531771652866, 0.0642307366069872, 0.041208959446521476, 0.0635212953784503, 0.05276560885249637, 0.06073017073504161, 0.06383664876921102, 0.08797787406365387, 0.047463998998864554, 0.02967227566841757, 0.08223812619689852, 0.03192992044205312, 0.03317732967843767, 0.041314626432722434, 0.047662497527198866, 0.03157191582431551, 0.05295890492561739, 0.036058940677321516, 0.014674871927127242, 0.042886105584329925, 0.050836102818720974, 0.007840536018193234, 0.0448250665795058, 0.046295342763187364, 0.05616002905298956, 0.011985740638920106, 0.021880053463974036, 0.017565789457876235, 0.04320534040743951, 0.039865631333668716, 0.05188694682146888, 0.04805787299119402, 0.01019720370095456, 0.006402905055438168, 0.029262560055940412, 0.049586188833927736, 0.048415855344501324, 0.0232309496277594, 0.013423540440271609, 0.012400877640175167, 0.011432894425524864, 0.01831630856031552, 0.04318180319387466, 0.05603870275081135, 0.06167096536955796, 0.032890563816181384, 0.019798783796431962, 0.04476673377212137, 0.038666517357341945, 0.022106540236563887, 0.020634315915231127, 0.012650275439227698, 0.007939973602333339, 0.04859228982240893, 0.01590259198565036, 0.05300528173393104, 0.05234168296738062, 0.015366919069492724, 0.03255640069255605, 0.044741148230968975, 0.02365125012147473, 0.009490583561273525, 0.04332473712565843, 0.05038409406552091, 0.044424807783798315, 0.02544249960919842, 0.007443331624017446, 0.03116778301773593, 0.05324880636180751, 0.01488509917180636, 0.011454540090198861, 0.024059320021478925, 0.0456359148665797, 0.03484259403194301, 0.02376703814661596, 0.04758544404467102, 0.026284466148354113, 0.02350708793528611, 0.008362848420802038, 0.02821062138536945, 0.020172635122435167, 0.024236082899733447, 0.0244665086211171, 0.0241358354469412, 0.05418845437816344, 0.06612543220398948, 0.02278427877172362, 0.0115996726344747, 0.052484446205198765, 0.07538111211033538, 0.04734335918328725, 0.05214632001298014, 0.04378711739263963, 0.01851471432019025, 0.033189760652021505, 0.09450845449464396, 0.08553470906917937, 0.04109018242161255, 0.011125116507173516, 0.045976857509231195, 0.0461681868910091, 0.01314127384830499, 0.014406352693185909, 0.05785626322904136, 0.012024553107039537, 0.022284702063188888, 0.028053779606125318, 0.025010406388901174, 0.0526715416344814, 0.01024092083753203, 0.013442079289234243, 0.032217020270763896, 0.0217905819954467, 0.05458407475089189, 0.02657928616827121, 0.012399842344166245, 0.04149314634560142, 0.06614130674279295, 0.024776850659691263, 0.104930233937921, 0.09197612787829712, 0.05945697186689358, 0.023813752632122487, 0.03873871348332614, 0.032840531930560246, 0.04979416829883121, 0.043216057019890286, 0.051026797664235346, 0.08549078134819865, 0.04047524256748147, 0.03729061638296116, 0.05096734792459756, 0.04756817426823545, 0.05675230371707585, 0.04083321749931201, 0.040081039696815424, 0.09529191011097282, 0.021829134711879306, 0.07971673141582869, 0.04108817120140884, 0.043531120973057114, 0.05803743260912597, 0.06527700898004696, 0.10120086764800362, 0.0033719904104145826, 0.036165539058856666, 0.04064142056449782, 0.03551982976205181, 0.06045311216439586, 0.04764394754602108, 0.026003223720181268, 0.06844413903309032, 0.03657296329038218, 0.04304490292270202, 0.049741616821847856, 0.046732386108487844, 0.03924236087186728, 0.006371620747813722, 0.03771588555537164, 0.027424748222983908, 0.04803188297955785, 0.041357685840921476, 0.03902144577295985, 0.041335306377732195, 0.054838616561028175, 0.07238322141347453, 0.06594169870368205, 0.01218754729052307, 0.018102236062986776, 0.029812702996423468, 0.014430448372877436, 0.012622693520825123, 0.016693129546183627, 0.057190653242287226, 0.06117161130532622, 0.056286568942596205, 0.0478516078874236, 0.015500425870413892, 0.10157637952943332, 0.05815181983052753, 0.04218517307890579, 0.046462489262921736, 0.03643312040367164, 0.04693365655839443, 0.052462400708463974, 0.02618410737341037, 0.01337958396106842, 0.026185098140558694, 0.01031656331178965, 0.060891558168805204, 0.020343162104836665, 0.01489836042310344, 0.06336724036373198, 0.019881559237546753, 0.017534784383315127, 0.019619148806668818, 0.08268948557088152, 0.018019263952737674, 0.02321623655006988, 0.018280349650012795, 0.0958416263165418, 0.041155183425871655, 0.01825548955821432, 0.060566393585759215, 0.04167351791693363, 0.05169093077711295, 0.03934080676117446, 0.015349869154306361, 0.05949219048488885, 0.01747654991049785, 0.02400651621428551, 0.03812848626694176, 0.06489472871180624, 0.03793445175688248, 0.07617230832693167, 0.10089378920383751, 0.006206795778780361, 0.05693803359463345, 0.06421065409085713, 0.05587222047324758, 0.030137889843899757, 0.01334185131781851, 0.017620572943997104, 0.018494613250368275, 0.05230823437159415, 0.014945272505428875, 0.023846511030569673, 0.051995051762787625, 0.039524870517197996, 0.03913831176760141, 0.05686853517545387, 0.02980583256430691, 0.054655703133903444, 0.04684607200033497, 0.0736956947366707, 0.05985727890220005, 0.05831640221003909, 0.042183811237919144, 0.02467834910930833, 0.05816331569803879, 0.02537918699090369, 0.019873634955729358, 0.03994671096734237, 0.04235808606608771, 0.09257391298888251, 0.05879155112779699, 0.017496766013209708, 0.0330609535012627, 0.008990322221507085, 0.06724300270434469, 0.024607056548120454, 0.042923353976220824, 0.03228337940527126, 0.020767442365468014, 0.025888736308843363, 0.020737422491947655, 0.014430770279432181, 0.006610795462620445, 0.06480006777564995, 0.03283626829215791, 0.060772680953959934, 0.21894558740314096, 0.10531097796047106, 0.11217899809707887, 0.16488096036482602, 0.21842917136382312, 0.13270961557282135, 0.12057518935762346, 0.17066683270968497, 0.11500589054776356, 0.1396768682752736, 0.19682920072227716, 0.11783509107772261, 0.11154753432492726, 0.19560931774321944, 0.17610187700483948, 0.13738147972617298, 0.14249254687456414, 0.09559705154970288, 0.10017698587034829, 0.1937968743732199, 0.1050320640206337, 0.07951186897116713, 0.15485789976082742, 0.0935685244621709, 0.10216819035122171, 0.05929854560235981, 0.14527395309414715, 0.14374869118910283, 0.12715259188553318, 0.12353820653515868, 0.053234583101584576, 0.13237192353699356, 0.22189734620042145, 0.16939425724558532, 0.16127358830999583, 0.1357926009222865, 0.17733700369717553, 0.21486180106876418, 0.10476353272679262, 0.09918592928443104, 0.14104800095083192, 0.19843454036163166, 0.11473734441096894, 0.23848143755458295, 0.08534180262358859, 0.1643706893082708, 0.10316936983144842, 0.16940139670623466, 0.20090308680664748, 0.15790987818036228, 0.10586151794996113, 0.20361228205729276, 0.11423809424741194, 0.19812794431345537, 0.10679244573111646, 0.2261849559727125, 0.20501923077972606, 0.18479566206224263, 0.19303121545817703, 0.15481203503441066, 0.13453041552565992, 0.18732157652266324, 0.12201655888929963, 0.1268779527163133, 0.12434870601282455, 0.16612239531241357, 0.1743600267218426, 0.1517176502966322, 0.16457059420645237, 0.11468167591374367, 0.12703133979812264, 0.16175745375221595, 0.1770960580324754, 0.10527931794058532, 0.0991378900653217, 0.15460813738172874, 0.11975009925663471, 0.17827506351750344, 0.2517512458143756, 0.15377262752735987, 0.11747733879019506, 0.1623894221847877, 0.1779480732511729, 0.15384382917545736, 0.1122398987354245, 0.151477120234631, 0.12104200024623424, 0.08773612687946297, 0.1728439229191281, 0.19709272251930088, 0.16029417602112517, 0.13505595998140052, 0.12546186073450372, 0.16918767301831394, 0.17891973751829937, 0.14770530309760943, 0.13161957875126973, 0.1038160698954016, 0.1311057899147272, 0.21466122823767364, 0.08850787882693112, 0.1663189011742361, 0.12843478558352217, 0.1022404755349271, 0.23990998277440667, 0.09293222930864431, 0.061517607973655686, 0.20831139787333086, 0.1784125092672184, 0.14779860590351745, 0.14199484779965132, 0.17096379568101838, 0.1491972871008329, 0.13955563103081658, 0.11769708871725015, 0.2544341393513605, 0.10200741147855297, 0.10189044900471345, 0.14075672283070162, 0.1380146059091203, 0.10472415437106974, 0.19583507906645536, 0.16012557491194457, 0.11624488382949494, 0.07336432579904795, 0.1505324404570274, 0.18164172739489004, 0.11298305573291145, 0.1192747091408819, 0.14903092727763578, 0.20064876764081419, 0.07867298234486952, 0.0843808772333432, 0.13517148268874735, 0.20736474398290738, 0.21402580139692873, 0.103965768503258, 0.144111571717076, 0.09437195127247833, 0.10573750507319346, 0.13966707192594185, 0.10327879950636998, 0.0905933954345528, 0.10159385710721835, 0.15091472072526813, 0.16445949469925836, 0.1136046415194869, 0.17803304916014895, 0.1542267476907, 0.12144560241722502, 0.13271967909531668, 0.09083857134100981, 0.14094711339566857, 0.12234065477969125, 0.2592252963222563, 0.1551314999233, 0.15507681848248467, 0.11381973818060942, 0.1691596198361367, 0.1595095478114672, 0.1111468042654451, 0.1001929643098265, 0.09853675786871463, 0.1538077459554188, 0.1429242838639766, 0.18100552872056141, 0.13977751834318042, 0.10889633049373515, 0.12458547338610515, 0.11482740403153002, 0.15212577214697376, 0.10706108834710903, 0.18885746598243713, 0.13438770052744076, 0.07780512227327563, 0.09715055959532037], [0.009882400427159155, 0.03924437209207099, 0.03377753047971055, 0.03859573131194338, 0.0455619041895261, 0.027709341447916813, 0.014869219066895312, 0.04768746337504126, 0.021011236021877266, 0.03528714420099277, 0.047890841524349526, 0.08044341273489408, 0.02403063786914572, 0.019251052835898008, 0.03478238359093666, 0.026183381924056448, 0.008199086114473175, 0.022782325067964848, 0.05990266494336538, 0.048706688176025636, 0.07086837926181033, 0.0633973567164503, 0.020254017181287054, 0.007521875895690755, 0.029527759106713347, 0.04682066086388659, 0.01850461554568028, 0.05854495771927759, 0.00963916709224577, 0.03299001902632881, 0.01941893406183226, 0.012567837675305782, 0.035811234047287144, 0.07438199580064975, 0.04691776346589904, 0.060476389626273885, 0.01051322780767805, 0.030478095904982183, 0.022893443128850777, 0.049157947360072285, 0.0913225109979976, 0.04697028154623695, 0.03841221674520057, 0.07509044255129993, 0.01992399338632822, 0.04407202417496592, 0.020473713302635588, 0.03995380589913111, 0.07124249590560794, 0.04240201749780681, 0.05750686381361447, 0.030432643070525955, 0.040396682525170036, 0.028498838146333583, 0.014151744089758722, 0.05087946650746744, 0.05892817680432927, 0.04732362547656521, 0.03891963424393907, 0.018060716611216776, 0.008374444478249643, 0.05108256264065858, 0.014606110089516733, 0.01753593656758312, 0.029614926206704695, 0.07199695581221022, 0.05016653347411193, 0.026447104100952856, 0.022674268366245087, 0.004024658501293743, 0.018584231293061748, 0.09389084661961533, 0.043930834290222265, 0.04260033048922196, 0.05730519631470088, 0.08590210927650332, 0.049233768877456896, 0.028048070635122713, 0.04365736029285472, 0.04390122259792406, 0.06858297259896062, 0.08894956059521064, 0.035510753295966424, 0.03187912414432503, 0.02140677661373047, 0.057631080780993216, 0.006321692299025017, 0.013838242357451236, 0.07873267328250222, 0.04473058746953029, 0.05400578957051039, 0.07019813827355392, 0.00884425735421246, 0.01789248472050531, 0.06179063297167886, 0.07465486123692244, 0.08200407508411445, 0.07209960225736722, 0.05466282404086087, 0.013628044798679184, 0.023782344942446798, 0.030117044771031942, 0.024391221450059675, 0.02603978933620965, 0.07930537380161695, 0.022144499234855175, 0.047930731961969286, 0.008649167139083147, 0.037450144736794755, 0.030246334317780565, 0.015973140543792397, 0.04645418834115844, 0.030178934321156703, 0.047473995728068985, 0.011169173176313052, 0.05327557562850416, 0.007376584717349033, 0.0017178100324599654, 0.01754358811012935, 0.02741044147114735, 0.02585378857475007, 0.09327927240519784, 0.04496747729717754, 0.08057046099565923, 0.06907238930580206, 0.020806991415156517, 0.04907818874926306, 0.016059077534009703, 0.026955458561133128, 0.04630613730114419, 0.016745916655054316, 0.035723582695936784, 0.03206627523468342, 0.030849705945001915, 0.07640181749593467, 0.005595050406554947, 0.056795749042066745, 0.04847052194236312, 0.04109263150894549, 0.023466961865779012, 0.0712413975270465, 0.08438769014901482, 0.009391115363541758, 0.031205432169372216, 0.016026100201997906, 0.03531490423483774, 0.031112452197703533, 0.05228928734140936, 0.0417745130835101, 0.07883324913564138, 0.04402873099024873, 0.057056558289332315, 0.04264877788955346, 0.04421945552167017, 0.04425538660143502, 0.0662842889141757, 0.008791753189143492, 0.06297887448454276, 0.02526520980609348, 0.032876117911655456, 0.05794750286440831, 0.04201759242278058, 0.0753892312059179, 0.057956865057349205, 0.08959647588199005, 0.023470212472602725, 0.02323295899259392, 0.04329491392127238, 0.04039153573103249, 0.051783094386337325, 0.02889972776756622, 0.030366552964551374, 0.032872388619580306, 0.10392293173936196, 0.07149449214921333, 0.036016159574501216, 0.03661468312202487, 0.034556017417344265, 0.049609622146817856, 0.081311621615896, 0.05144978844327852, 0.007890802608017111, 0.039320817013503984, 0.05498363963852171, 0.07387282312265597, 0.0492906470753951, 0.06939788785530254, 0.024370172286580782, 0.03557169846317265, 0.03757120757654775, 0.07099959097104147, 0.02169633109588176, 0.05394498541136272, 0.02739971001574304, 0.01980084511160385, 0.01736395868647378, 0.03916019028110895, 0.03852406211080961, 0.02055736262263963, 0.006286064572122996, 0.04453786285012029, 0.028936857415828854, 0.052499159282888286, 0.03303516758023761, 0.02956984444608679, 0.03035266181541374, 0.031730998889543116, 0.01802594884793507, 0.03933428699383512, 0.02546683648688486, 0.08086831454420462, 0.02487877351086354, 0.12928487121826038, 0.027049926538893487, 0.03163200010021683, 0.04260119880200364, 0.04111272886802908, 0.04560927547572646, 0.0213750776310917, 0.048705285516916774, 0.007169566797529114, 0.013304300500749378, 0.021679664314433467, 0.02049167698714882, 0.032661874720361084, 0.06750755608663894, 0.051174763357266784, 0.03309182313387282, 0.010529555056564277, 0.037783929365104996, 0.010516657457628753, 0.00388287768146256, 0.01592966367752524, 0.10610319834086113, 0.0015991713485163928, 0.07026277191471308, 0.02051398594630882, 0.08695739874383435, 0.10172853464609943, 0.04360893515695352, 0.04498037582379766, 0.04074822303664405, 0.05686811215127818, 0.03651191422250122, 0.012823408287658822, 0.029028468125034124, 0.04569819961034227, 0.06501124589703977, 0.0881307119561825, 0.03463505614490714, 0.06837082968559116, 0.0544260937749641, 0.05804278720461298, 0.05119500543514732, 0.01183882601253572, 0.06171639593958389, 0.08080581086687744, 0.035523377227946185, 0.06393747695256025, 0.042003643757198006, 0.055868082999950275, 0.007761780234432081, 0.07310486354981549, 0.0481596399913542, 0.02950462821900146, 0.020764410692208912, 0.032378782489104196, 0.005361672792787431, 0.014991388634371106, 0.024957238929346204, 0.0565874318999704, 0.059536199842114, 0.0641919148620218, 0.08276245353044942, 0.03596933005610481, 0.038631699499092065, 0.06011328274325933, 0.06786277022911236, 0.03541954334650654, 0.0273112794093322, 0.014027621746208752, 0.059901510903728195, 0.03925761200662237, 0.038282032910501584, 0.027438158831500914, 0.018948466240544803, 0.014260307307267794, 0.028605017214431427, 0.019720754389709327, 0.06455845417804085, 0.03809454785368871, 0.033797394062276, 0.03425260518270079, 0.028560508762893733, 0.04653679679904599, 0.02320789295481518, 0.012565995293698506, 0.049661412922432646, 0.02365032985835569, 0.04451568747754209, 0.07322284276597202, 0.061589663091581315, 0.04501090035773814, 0.03583368401450571, 0.041647435136837885, 0.04160643518844154, 0.03490909417450894, 0.04970048328686971, 0.017518202948849648, 0.06415975018171594, 0.038177419774001464, 0.08281531670945697, 0.028034589522576425, 0.036533655438688584, 0.018265913022332825, 0.006696472701150924, 0.011334482860547723, 0.05751430755481124, 0.03841741548967548, 0.030078698000579607, 0.005246623204584466, 0.015042524464661255, 0.042289470802643336, 0.08639811625471339, 0.07724525348749012, 0.10527499121963046, 0.04801617542398162, 0.05265284693450667, 0.03907986021658871, 0.03315000009024516, 0.04034551515360363, 0.03926104443962686, 0.058278771612094715, 0.08945680368924513, 0.04747682331071701, 0.04424019112775568, 0.0438372754433658, 0.052120207546977326, 0.12474438204662874, 0.023121553349483293, 0.06001509289490059, 0.03770164003071841, 0.03429937904002145, 0.03779402257350739, 0.04812014289200306, 0.08401728424360044, 0.06277366323047318, 0.010495864335098304, 0.014343388884299202, 0.028356750262901187, 0.03588946754462086, 0.02210876853496302, 0.07782030661473982, 0.07940859912196174, 0.09214867721311748, 0.1755961330491118, 0.10399435603176244, 0.1102740089118015, 0.1425697302329354, 0.15925608953693882, 0.11950155399972573, 0.18882300064433366, 0.17331722017843276, 0.20057572546647862, 0.10521330390474759, 0.1175959562533535, 0.23135799245210364, 0.12196278286864981, 0.1668290386442095, 0.12249170409631915, 0.12832917796913534, 0.14786611165618524, 0.1113701165013481, 0.17456413217587397, 0.11755729778087698, 0.08011042591533624, 0.0844029190193396, 0.12827644095523283, 0.2224765479331836, 0.128024585719686, 0.1687557579134591, 0.12952666293131188, 0.09513110155239701, 0.07605276317917742, 0.11268787391600199, 0.16073095961473882, 0.1119487319374457, 0.22431679215515032, 0.2081726904725656, 0.0998964837344829, 0.16972817917121574, 0.10440698271850124, 0.14753057184861973, 0.11304837214993313, 0.13985743280500174, 0.2217318324255757, 0.1521283548208885, 0.10666030633728951, 0.1655483292415738, 0.28185290400870144, 0.1512622387963347, 0.11810226424131542, 0.17683229874819517, 0.1129319662868511, 0.09556416698615067, 0.06951565927010961, 0.10028265285654925, 0.09239967897883616, 0.1497297632158734, 0.2384166035335511, 0.11331803150824271, 0.08050440243096091, 0.11169254255946726, 0.1596449303906411, 0.17206687945872545, 0.09912246823660098, 0.1270564243895933, 0.17969885899219662, 0.13637067459058017, 0.17918757861480117, 0.0861371326027438, 0.13192703569075093, 0.14197857992257923, 0.16152738797245547, 0.12653303216211498, 0.15131165098864585, 0.12293946405407041, 0.22963664028793573, 0.15710755717009306, 0.11092775195720606, 0.20241123478626832, 0.11809277959400788, 0.20534384617349133, 0.1716460965690203, 0.11469573219073936, 0.1568958372808993, 0.10302130394848064, 0.13639154378324747, 0.07198524472187273, 0.1254590108874254, 0.2387621920206584, 0.12987060385057703, 0.1479108928469941, 0.10853434054297395, 0.04123147991776932, 0.0911005272064358, 0.15896929398877546, 0.1253424640162848, 0.1491902960697189, 0.1643107831478119, 0.12885729025583714, 0.08942055719671771, 0.11224539062823169, 0.12720390397589654, 0.12068073017871939, 0.10264283831929788, 0.16489881643792614, 0.11892592199728824, 0.23323721427004784, 0.15923902014037594, 0.1757684300537221, 0.13357875955989584, 0.15418603346915916, 0.1159824307251256, 0.10612651662086137, 0.24686040356755257, 0.24358089751331136, 0.14068804448470473, 0.1631949344300665, 0.10541400290094316, 0.1485396848875098, 0.13768089178483933, 0.08943712935433723, 0.20965478906873614, 0.2086382545530796, 0.16534732596483082, 0.23545868491055444, 0.1278956004534848, 0.11395386653020978, 0.12966636480996385, 0.1471137223416008, 0.12601913942489773, 0.13028890796704218, 0.29345949995331466, 0.12852387299062684, 0.14157845842419192, 0.14682033652206883, 0.18779646197799593, 0.10241148120258003, 0.15641443576896563, 0.18507763365050778, 0.06813956904807128, 0.19782053190283477, 0.16360409528715536, 0.12032184240524657, 0.161696404684335, 0.13600598322227597, 0.1217621358227916, 0.1589543026057072, 0.18369287514360622, 0.1455927055212669, 0.15039530640933663, 0.20170016825431958, 0.2188301389105618, 0.13441668881569058, 0.11109854982350953, 0.13468288234435022, 0.10292347404174507, 0.05927534235524945, 0.2521888160845265, 0.16150169481988996, 0.10776360533782281, 0.14307685458334163, 0.17436244612326846, 0.30111727654002607, 0.22430913319112733, 0.16364108392735943, 0.15598419791786, 0.13342381396796554, 0.18007302016485482, 0.18524393410189077, 0.16663610993418843, 0.1466681665624492, 0.10155924333957955, 0.15629346569767222, 0.15658984979381785, 0.164814924064558, 0.16154747048858553], [0.005811029295728076, 0.027911031211260706, 0.039338120186585, 0.019325698049215134, 0.044510073130368255, 0.03527153312461451, 0.062416274595307186, 0.02706806277274154, 0.04491798717936035, 0.05165562681213487, 0.006598081081392593, 0.07320685690501705, 0.025392827665200457, 0.00571063805182348, 0.0898078246973455, 0.06175498019729275, 0.031725340013508685, 0.00853465375257656, 0.05510179697012063, 0.007449201084455126, 0.031100498054001946, 0.058996372754336335, 0.026465210648893844, 0.0173742893821327, 0.04418572490976658, 0.1024315414542798, 0.04498402347962838, 0.05849839908478316, 0.06122937636973802, 0.037424852343974635, 0.014221640485629905, 0.0339819513465045, 0.0054523205653822515, 0.04018713712866884, 0.03183731525496114, 0.056908681654022075, 0.021397694581537507, 0.05087875033495948, 0.025940801679098513, 0.05231716240814421, 0.0500896321318578, 0.029233033710625023, 0.035582719356170855, 0.05240307713393122, 0.015852708529564552, 0.042158221986028366, 0.04733626054076012, 0.0716889942123089, 0.07741746143437922, 0.026930958410957828, 0.0251439447310986, 0.021609989635180682, 0.06620024068979546, 0.06661089326371439, 0.03025828660611296, 0.02578062023530947, 0.03257910670072306, 0.06433961709262803, 0.06816815657657571, 0.018039550559478812, 0.04652757561416365, 0.07429726480040699, 0.038880048086866736, 0.017669424814812373, 0.030086269762250595, 0.014931504738342483, 0.008846132204780588, 0.03513485920848325, 0.021246949545457028, 0.028297719836700708, 0.08297959109768271, 0.009386262645421084, 0.014229184416763019, 0.066465261625126, 0.02845028127921978, 0.009799624986044364, 0.004855369443248492, 0.007755291080684401, 0.032224189417320304, 0.07459755259333178, 0.020060574533999898, 0.08143791288603097, 0.025782829980016686, 0.047978218281059526, 0.02312038075615419, 0.06956593977520242, 0.06126166721514892, 0.07017448602709919, 0.041499755170661956, 0.03561937031918205, 0.02002936351345852, 0.0637209702108521, 0.022877306982991286, 0.01762870688253315, 0.026652486048988067, 0.013460217378451489, 0.05192933829675894, 0.03129318371065892, 0.03032885000720853, 0.04793030151631683, 0.026011253758042585, 0.02362343257118482, 0.04350202507339418, 0.03474087156064343, 0.056446093585691415, 0.015959299489622936, 0.03840188233880326, 0.0422766873089131, 0.04409550572745502, 0.044682199441012926, 0.045567655834020115, 0.04059701786900405, 0.06615977137698792, 0.014165118518576492, 0.04890080432232935, 0.005860343617314356, 0.03336145651701372, 0.02534922463382827, 0.004114354005650966, 0.07148540826165117, 0.03638318128651008, 0.010418663350719726, 0.0258796542766504, 0.02610029849165585, 0.0856118553201668, 0.023960616235854104, 0.025230180435755756, 0.03694882027048152, 0.042862727932515554, 0.03111655627435539, 0.02585716349130962, 0.07335798043641262, 0.0810029698186554, 0.01964457107533235, 0.03349984108353965, 0.05517063858860638, 0.04932434800139163, 0.11313600494759157, 0.036672340575023554, 0.025812540006882045, 0.0022237692110138596, 0.03159518586471677, 0.08112003619316965, 0.042272954306099564, 0.04768523322127294, 0.019270033262728248, 0.048103648659889586, 0.06571215984877199, 0.08155003655701876, 0.04698472002928611, 0.03668971054139547, 0.02543366063036956, 0.06948732407181524, 0.06341887899907306, 0.04117436423257459, 0.02054113556368975, 0.023585236085637007, 0.06103410618379712, 0.03474906487099361, 0.019890958537871484, 0.015322846629715059, 0.012797750387107953, 0.015585485271003563, 0.052972875855630264, 0.017885775705508422, 0.030433401916525327, 0.002240088110738725, 0.04728205036371946, 0.10161021404201165, 0.029829282575519755, 0.04656177006836515, 0.04103360479348339, 0.017108001229644287, 0.03846491665171925, 0.036740287905558944, 0.05311194690875709, 0.0182798616879154, 0.038781928742537275, 0.042177454743068665, 0.048395064077340066, 0.038438414558186196, 0.04089733163709752, 0.016522853038622998, 0.04288793868909124, 0.048191504101851024, 0.012822446278732968, 0.03739908126590308, 0.005326090986272902, 0.04861751542193815, 0.04837267719267402, 0.04123589569644537, 0.022599417206947692, 0.06139335389889311, 0.029378860162978526, 0.07526578236138448, 0.011399007962609176, 0.03840469136775937, 0.03231445312849246, 0.04122740181628615, 0.0272663961732178, 0.02896871039411053, 0.06624762681894936, 0.02182734984671697, 0.048056767191155814, 0.03764095832593739, 0.02588632432889426, 0.05112000770168379, 0.03559473101631738, 0.03454545665590558, 0.046479703378281556, 0.039611924439668655, 0.055263414469663985, 0.020311661646701396, 0.048650455646566115, 0.01682684785919264, 0.02130733624653658, 0.027816518704639748, 0.05443918897071853, 0.08288261466077529, 0.052165385786793195, 0.010536244590184651, 0.1069968703086488, 0.043884784026886337, 0.03429662567214109, 0.034658771473914385, 0.017838163221313152, 0.022303819787339307, 0.03547467749740463, 0.04294950354960747, 0.04271595709724352, 0.022171006894495804, 0.07009647146333009, 0.06303714792011306, 0.03859282951452769, 0.035169547190889716, 0.02135130293027032, 0.11259377701207995, 0.04041262385726441, 0.045364396428340115, 0.04057756617839914, 0.017910099595610518, 0.03848460954031907, 0.05415315412392374, 0.05235934237134643, 0.08831844563246705, 0.09323760081315413, 0.05196877602429595, 0.08929431045544334, 0.013895179927203571, 0.028854876072728075, 0.062332293164217845, 0.01787807406799402, 0.014949789401725866, 0.05224511100095697, 0.02359770231123548, 0.044515928675537, 0.05735043392633088, 0.06848904638900422, 0.025129608293354977, 0.051597657657111995, 0.0009939034180206363, 0.10500557677005418, 0.022170552329043858, 0.08191967805032618, 0.05742187306168489, 0.009707209046609933, 0.03977641405072063, 0.11439476904342882, 0.03526802647684235, 0.03947144701669458, 0.041461597647867166, 0.0342938574613072, 0.030335269584611524, 0.056222569837700576, 0.0332104331755545, 0.06970141141209751, 0.04882112734776456, 0.06559126399224624, 0.01924748681631172, 0.03407218537176959, 0.058954808773705736, 0.020067001532879658, 0.02589957537566079, 0.020745764231833164, 0.03264182189013809, 0.020437041930563282, 0.03436929306189995, 0.01446619484340772, 0.05344412478734739, 0.018874192101066, 0.0023519555088569177, 0.014340279285534052, 0.0204649021543446, 0.09312715439591557, 0.028237642982276157, 0.06020552056725137, 0.03404620278161019, 0.01636780725675635, 0.060486419752123766, 0.018429634510539472, 0.03535245319653768, 0.03968825432821177, 0.06915189558640122, 0.015682259472669102, 0.047973030668799765, 0.014173651361488737, 0.026938318660540972, 0.04904440247628372, 0.10680421619326808, 0.08557157896575518, 0.05023985395382624, 0.011937012150156079, 0.06526107506942935, 0.1033572964661289, 0.04425839229952544, 0.04802975301572587, 0.020658448702306487, 0.004506371251409291, 0.024957116474979557, 0.04899080086033791, 0.09473112848354504, 0.11682833806844428, 0.022131999612611253, 0.05666784360073507, 0.013975017391203437, 0.0707490938657429, 0.03405135328648612, 0.011760782690544147, 0.09922554512741044, 0.041844070874503814, 0.07320568431168795, 0.05893451103474945, 0.007204024714155821, 0.017757263558451086, 0.006484644736701739, 0.053369386805570684, 0.014405325746338349, 0.017746897610777523, 0.059123892278876156, 0.042303849913878366, 0.050187562228529714, 0.017187342382385395, 0.02331730222067563, 0.03289171785581857, 0.11689176200889051, 0.020655921689467505, 0.06991576592554338, 0.11218370331334881, 0.031944525908329524, 0.027061390865128487, 0.017678308322501834, 0.05643085729388986, 0.13772735022939742, 0.1672589499503374, 0.15816820494364947, 0.1356171868974343, 0.1614697082550265, 0.11708619727869518, 0.15811123768799007, 0.1826848604832776, 0.1256556503358297, 0.10558089707046747, 0.18206641398137435, 0.11135562977869995, 0.058535276402835734, 0.15861399821005762, 0.22779713821364567, 0.11938148192712106, 0.15085527469636872, 0.17285305133555084, 0.18248649925226346, 0.07817999590770341, 0.12706357869319618, 0.1919992739567533, 0.11896756390342489, 0.10277025765390135, 0.10611952558974735, 0.21482824115082622, 0.11231363852857612, 0.11929288433748297, 0.07810102397343144, 0.11772664845921099, 0.14033711253432557, 0.17143833974841982, 0.11284456355497241, 0.16608843463473022, 0.08284713258035481, 0.11107817786978558, 0.1205763100006152, 0.15659638069337234, 0.10047657604445703, 0.1448503797291778, 0.11490611621411517, 0.13387797866016626, 0.1711155500379391, 0.10409365539089777, 0.11787952345912345, 0.12941163004143164, 0.12428335990989581, 0.1504227361874655, 0.15737590292701498, 0.18571236287243664, 0.10249299870338291, 0.11587457440327853, 0.14736689860001206, 0.13314804673427716, 0.14093295321799815, 0.10134329320862889, 0.14681408763863146, 0.10288232937455177, 0.1408084059949033, 0.1043143923743628, 0.23736805276712403, 0.12757675896864384, 0.1285395768354647, 0.12322103488259017, 0.08935437246691436, 0.11831956508103758, 0.19787383294897154, 0.12121140287490562, 0.2294707257533446, 0.22832246002508327, 0.20358587644295767, 0.16737343365093693, 0.1693268257076852, 0.1688671691226773, 0.2000255713937804, 0.10197192197665572, 0.1447224779985845, 0.12317377491854131, 0.09647283775848337, 0.12113789314753376, 0.2172001896542497, 0.1992664285353385, 0.17103907914133742, 0.2129488709033467, 0.14571174600860104, 0.26199065730907023, 0.13925017789006233, 0.25020330387633294, 0.13376263406826183, 0.15854910481721163, 0.12879012589110062, 0.27030386903788894, 0.32289761875290424, 0.13447027187794447, 0.17625536798732355, 0.16303317592246458, 0.09102987474761903, 0.08864323914167471, 0.1627111283596605, 0.1443646737607196, 0.06684679974569008, 0.19370860332855955, 0.14601722883526236, 0.0933913812332321, 0.1639561849879101, 0.10829510923940688, 0.18144504341762513, 0.16130141884787008, 0.2440760881290771, 0.13734990876400843, 0.15429447608767077, 0.14449765178142115, 0.1245973032200709, 0.09033299807924777, 0.1280461673741229, 0.09141988819465041, 0.09306555613875389, 0.2565316268010065, 0.11988767117145471, 0.12356925057247281, 0.19123550009680912, 0.11321688420139253, 0.18630728329299018, 0.12038340355502442, 0.21603860979666933, 0.1139347636490129, 0.20053469954291359, 0.08619527245173231, 0.13926009298302233, 0.18603389093186706, 0.2120693220058456, 0.18627005716552958, 0.27875449683051556, 0.14686722541227937, 0.1597676519304514, 0.12864087999332696, 0.09499922933173366, 0.21827943564858288, 0.12583732808707282, 0.18680386914638802, 0.16431053081760183, 0.15348457032814622, 0.1610709968372248, 0.1129081062390469, 0.13584786123828962, 0.15020648919744417, 0.1303557606297545, 0.1219545747153461, 0.11796224323916249, 0.1350073641515337, 0.1359506486915052, 0.12121672407374717, 0.2101842372212559, 0.18286095728399232, 0.12065771617926657, 0.1358979265205562, 0.07020832053967752, 0.1102296359022148, 0.11070851411204785, 0.10626129063894041, 0.110704410035396, 0.06173253023007419, 0.16214034258155152, 0.13323303748620674, 0.10930601827567443, 0.0952840581885539, 0.10557824018178508, 0.2368697154452093, 0.1778871429269202, 0.08462643905659206, 0.19219318230170757, 0.1895962146227248, 0.13896833988837898, 0.10618224448990077, 0.12226250662934035, 0.1288907165871933], [0.048682531269150786, 0.014588067551812856, 0.019830115415970795, 0.06466897481004708, 0.009015445775730768, 0.024948390673671383, 0.01379767378239194, 0.02073499381367583, 0.041358750822837465, 0.05659853071847465, 0.07181590146501549, 0.009127263310801936, 0.05273965223750565, 0.06563021190231666, 0.03936313798476476, 0.010521012936806073, 0.026308496890123934, 0.05881521079572849, 0.02553461312345462, 0.04988614637113642, 0.06823458621511236, 0.028631365312321577, 0.010776604885904817, 0.03319477014883887, 0.05125035109813325, 0.031862188334343955, 0.007559743980891653, 0.0569783247919986, 0.011520182124513667, 0.04179238028882537, 0.07602315890835598, 0.019415865281189326, 0.05551946655032225, 0.06328934454359114, 0.012163821756985271, 0.04071089300850872, 0.051234049824415706, 0.020256373500160407, 0.023399901401717216, 0.038210322891245596, 0.0380422301532235, 0.02540688765293453, 0.05620207914034836, 0.06265935764531605, 0.03698612803418655, 0.005702799116988899, 0.029924060399935115, 0.04076470242580399, 0.0065282009200018365, 0.0441178851906443, 0.018625943703227676, 0.03311697822937276, 0.0783441292878706, 0.021459443123603705, 0.02939281810540706, 0.1074927362788003, 0.013215830003900919, 0.05871194836799987, 0.03155550322844647, 0.03390719481103588, 0.03367224198882468, 0.03085932974499883, 0.051749953781836666, 0.01487339364757645, 0.04103733408555854, 0.017058091798389796, 0.0284629144880455, 0.021279110515024513, 0.013858085530955577, 0.0359020506584784, 0.01575785834575072, 0.04360687940788921, 0.02837585128872888, 0.05171279815840535, 0.03877882656524889, 0.05270390298392158, 0.01549557500766241, 0.04499848793784622, 0.04394677933305502, 0.040260053137899376, 0.05348726212105248, 0.08304244358441792, 0.05704149269149639, 0.05341063908417709, 0.030977032511145808, 0.09872979047941044, 0.1352993695763871, 0.04934879805659875, 0.07275762749486603, 0.03010382155480329, 0.06086599489208311, 0.01216192093124846, 0.042752778754220344, 0.03107884775090497, 0.03005025519087212, 0.03842765341687482, 0.0598232069023652, 0.04589039730490185, 0.021999568925821222, 0.08006087271496654, 0.046417630146606825, 0.05781710009614471, 0.0549939777556574, 0.022858404481667094, 0.058124249044340104, 0.056322225427720696, 0.039601489843335, 0.025643168919486925, 0.030871627132000867, 0.04776556328579318, 0.018738254766503815, 0.046449175133602694, 0.02994826925714733, 0.02912189895141637, 0.04149294596572872, 0.01363169523756369, 0.0634250017174054, 0.05025165039114654, 0.028496852901298553, 0.012792029356205603, 0.020384074850881007, 0.023311008808377665, 0.01840278917370597, 0.07373036045464687, 0.07417828368488699, 0.027211859451199416, 0.05109313453431241, 0.0577729942597216, 0.07168724274379201, 0.06336985272355378, 0.09385072611621581, 0.05421762078185566, 0.08121391787426546, 0.021873049445275683, 0.028752535763487685, 0.08685457418323494, 0.046970715702627786, 0.0305502642004285, 0.011591293787205359, 0.010454890361870639, 0.05214577824517619, 0.03715363818628248, 0.019121761433780193, 0.03891083979397081, 0.06625512251048349, 0.012181050715298625, 0.03832196416624356, 0.0081392801439506, 0.08877684056642465, 0.01343220686976565, 0.06794528220780194, 0.01191151381135569, 0.01249028788151918, 0.010989864731527632, 0.0059221056108071934, 0.01639610534766689, 0.0217100886584376, 0.04753839559271, 0.020262639081920497, 0.03462166780082043, 0.08028378419112414, 0.029900098306825384, 0.07520629180362448, 0.0240063195451512, 0.02233921281003859, 0.029282275208970532, 0.029908877913840115, 0.01920028622407699, 0.01917494930239627, 0.02339758775633527, 0.08336387516465038, 0.04755004731123336, 0.02986816740303766, 0.027403456006140914, 0.03889231949870009, 0.028630137057916727, 0.031219384545693174, 0.07390369646600448, 0.023916823956824373, 0.07415573723847046, 0.009755367009347538, 0.04571557328745257, 0.013567754576797597, 0.0673144195752684, 0.038369995963876136, 0.044396120065357536, 0.02035018096648855, 0.017493333580205217, 0.04843456488742959, 0.02934642274340149, 0.06607515169889666, 0.02649296511663124, 0.03267642081482336, 0.08801145624602214, 0.01960720393981319, 0.020176201142021455, 0.044468219712143764, 0.042359848666819744, 0.033516843686811626, 0.02662942380993627, 0.03374851250555366, 0.018075771076837555, 0.05328432554961182, 0.1054556893359404, 0.0376417524239514, 0.05033534238464199, 0.09708160665468313, 0.021166647311474662, 0.003284909817011794, 0.04242711322149262, 0.062375627167057246, 0.018443067383486778, 0.02243042275949847, 0.03421273700951133, 0.041021893703145906, 0.013834991750627523, 0.03961102273024153, 0.00797005284766783, 0.017856425620266236, 0.042624238776625134, 0.044708441782859154, 0.03101916423474904, 0.003029200515811681, 0.06552858962095343, 0.047449805424548686, 0.03463631779595744, 0.025212302098225337, 0.032147072852239944, 0.09526669193292037, 0.036298576451372355, 0.019751278923649807, 0.0339864895795472, 0.04617063968908042, 0.027610609831754118, 0.015764771451358683, 0.05640553150442429, 0.04664898355258629, 0.00840610913655837, 0.04688027758675162, 0.04464864694455173, 0.04388947068946436, 0.055318967933999375, 0.0618926523020491, 0.024676831417309586, 0.038319904706440866, 0.023503560878452845, 0.05825124535476789, 0.01860416723502567, 0.00614660157225444, 0.027481318429636303, 0.054864999910932966, 0.012659463227464585, 0.017616476288822014, 0.02238157274405239, 0.0737674678384792, 0.03353695588884875, 0.07663502998184413, 0.0685579028504435, 0.008491725147905527, 0.032918887882260606, 0.045842005565646105, 0.0827609766565729, 0.006223639284144156, 0.05269290064461529, 0.010379233044659486, 0.04185226789559238, 0.008296684100059792, 0.10122942549060099, 0.036159189985482953, 0.031295710723497905, 0.03627559584856499, 0.03672121099953074, 0.007645040404895553, 0.025184215519402642, 0.07384778306004591, 0.03821769612841308, 0.1112459551950451, 0.01918923378980253, 0.030778346590523142, 0.0349148124223575, 0.03125670715235174, 0.03548099317413289, 0.01924211552250199, 0.04148211060964968, 0.05691654841939453, 0.015022229508758755, 0.03288136860646773, 0.048127946574823, 0.02680255758605199, 0.021324340705177747, 0.06025287329975981, 0.020334564324002713, 0.05653053514834028, 0.10813806336955167, 0.021671868053090293, 0.042196605863864534, 0.033658901884336956, 0.059242654460831545, 0.024131595928338356, 0.032602109567960724, 0.02527868164179381, 0.08109962713206187, 0.057932708150474355, 0.006032335877534933, 0.0302787717373576, 0.10429854752146639, 0.03246464897529222, 0.05285754239594098, 0.023658356185478624, 0.08506872196448967, 0.030737333654542454, 0.006422506567105302, 0.007452576464856975, 0.06159322540042922, 0.02224381714768242, 0.053069789209985174, 0.07843500527087599, 0.03658934620034415, 0.018487408851797227, 0.029887502205383498, 0.029413036063488107, 0.014107718034210848, 0.027059817512053996, 0.03247415217629168, 0.04183894634479657, 0.006009942962919013, 0.04496936977375299, 0.013636510848300532, 0.10473264454049058, 0.07134130544727668, 0.06110591268225107, 0.032464170290040784, 0.05604235782811884, 0.09445699397474527, 0.004194114935671678, 0.017345776068395935, 0.01602935080882162, 0.01922697756526759, 0.038811547856312245, 0.03355702727276366, 0.04428861626365688, 0.0291848571941955, 0.01669711302383803, 0.028966842037334573, 0.008512057211191859, 0.030625788858742453, 0.07197367463959381, 0.036552168312482536, 0.07359399081906304, 0.044358971863402985, 0.02269184242322808, 0.05587593863310758, 0.13971219450468197, 0.15284307271940634, 0.13725351862376556, 0.15740104689029977, 0.16686967865098268, 0.19663575250888243, 0.07342721539316699, 0.19028615963179618, 0.1436804432887584, 0.12723767169518396, 0.13716685061808676, 0.10574653701041825, 0.13249071169411764, 0.11115429995697923, 0.1732342629111372, 0.08866034564562142, 0.1239416454336606, 0.27860802656505257, 0.1238956545421388, 0.08074209748883732, 0.128741396474652, 0.09571188405971043, 0.08458979180431925, 0.13412895816145465, 0.1384978776331991, 0.09799642983125523, 0.16659460903611034, 0.18623250449309126, 0.11192986654350534, 0.14285464072600007, 0.1800713429111056, 0.1102259622712154, 0.13565322558861226, 0.1674193429062143, 0.12786754727130756, 0.07661924450076185, 0.12340105764451437, 0.11076924405642785, 0.11785361508373171, 0.11032530615921132, 0.1565973603283055, 0.10074648031149991, 0.2026361203752458, 0.11920056116650812, 0.12212526868097484, 0.09950932755600661, 0.11441523747635074, 0.14106131508015096, 0.07279028199263848, 0.17254943872103468, 0.07499187791836448, 0.08442363978247158, 0.2536351134767756, 0.1450502549414523, 0.16845337726408616, 0.18999641033587977, 0.13190386584028602, 0.186288729601074, 0.20878758950857446, 0.13810620177537203, 0.1454352811560966, 0.16857348644407466, 0.11844270964502357, 0.17875625722808763, 0.1214311973308213, 0.13459695648634806, 0.10724647683673538, 0.13087450701277703, 0.11653596899122931, 0.07005385734373704, 0.21183177537750453, 0.11887435015523806, 0.09185147675452754, 0.09372133266879246, 0.15376018913229927, 0.1659420385840349, 0.15007337759016082, 0.06270403493545018, 0.12226362727233209, 0.16222913312958553, 0.2655968419276178, 0.26624527119565755, 0.16410693002399057, 0.13583371590357274, 0.17896695295348763, 0.19550169148715213, 0.23084294196451083, 0.1143237751966808, 0.159519151202403, 0.07542777093476616, 0.1392753960681148, 0.1586130482610315, 0.15940876415697858, 0.1877089182380587, 0.10354803584050387, 0.2048253224347718, 0.2098547830246389, 0.10706214961828664, 0.1634647199534811, 0.17113313893787563, 0.2354163082782179, 0.1784733950626105, 0.14865032426314428, 0.15703408455010504, 0.12832680309657007, 0.11712501902366057, 0.10697667647036724, 0.09195877646561712, 0.11656521703116596, 0.10541094525251538, 0.1226422116451431, 0.15023794141598046, 0.13351630041142926, 0.08189210726413876, 0.1225780752429273, 0.12643622641917318, 0.16791791771538556, 0.1899267968838103, 0.05173239827854559, 0.15011734241852537, 0.10868308178032748, 0.12422476735082455, 0.10693187301512808, 0.14329228521091864, 0.10572304061497562, 0.1965193243813701, 0.16856248781550676, 0.15995056164683774, 0.1486273028422147, 0.19039265782339498, 0.17985764890909195, 0.09189173826598562, 0.183197476726491, 0.13767133292276412, 0.16161800420377403, 0.1415876016835682, 0.14883436204399914, 0.21184042881941423, 0.17897866404382512, 0.11426631070207804, 0.21023562352638692, 0.14983394590672106, 0.11655672686174512, 0.16927870485233143, 0.1426456667832099, 0.1572538196342066, 0.1593107561348006, 0.12730154092423618, 0.23200415074825287, 0.12148662091931328, 0.15799559623701498, 0.1126724891946651, 0.18374783860053867, 0.17607226531254128, 0.11363170022377744, 0.10594725827104412, 0.12256761096068658, 0.35885871096979827, 0.10137742458027788, 0.16124186891829595, 0.1645091740647331, 0.08727214357350022, 0.16422178479842842, 0.1423480358789675, 0.13602391351014376, 0.1467161686741747, 0.1322625606553629, 0.11166966214659624, 0.15493981802137569, 0.08866770032909699, 0.1589767006225884, 0.1022207566711586, 0.11558526297449134, 0.14477941556833684, 0.1103260408854112, 0.11488232295960188], [0.011473621634650044, 0.03181226406013593, 0.0240825195578509, 0.04597995226504281, 0.030315519179566763, 0.02066797787847463, 0.03444324065640103, 0.021091920461913105, 0.04039831896079704, 0.043552702627494, 0.02208184898336185, 0.04145063983742148, 0.06726715218974277, 0.030717863410245627, 0.027544538279471453, 0.024333226319868118, 0.01061520724761067, 0.01396035440848209, 0.06769387968233787, 0.04466274032893125, 0.03252077389333863, 0.027437472344900016, 0.08805888690403663, 0.05691846316040028, 0.02942887720564613, 0.0724389121751301, 0.023751414082653355, 0.01913898111524759, 0.028376439440762624, 0.045171189412940294, 0.05515986631507985, 0.03618332833866589, 0.09108457845286466, 0.03193948672560509, 0.04349444403487723, 0.020313463210186455, 0.034390974906273186, 0.09002410879475065, 0.04124442297325004, 0.0612946482578991, 0.040513047570129856, 0.013149170299584512, 0.05210308991081547, 0.033446599409217015, 0.045321834259084426, 0.03768349080928601, 0.011968322432949208, 0.028136146866017953, 0.05300591998093296, 0.03045900972210802, 0.04588353243889287, 0.03736200727871619, 0.05467757422593422, 0.007346687762037618, 0.09889078457490541, 0.02868053074053023, 0.02194080938352272, 0.049373752772226, 0.06473317800555378, 0.0480324024829315, 0.020067424557055347, 0.034945470542879775, 0.03550607776560355, 0.07825559107004665, 0.043980316986562684, 0.03879112395225093, 0.06432440306525677, 0.022404553346859757, 0.06798824513680302, 0.030884488551237155, 0.014223733342078049, 0.045166165073169395, 0.03162598870403599, 0.09228720649844036, 0.015470914368052036, 0.09115252207266167, 0.043166711620870046, 0.09257178302505054, 0.02715825041377684, 0.03539954988809768, 0.021225781638349872, 0.027566513272176962, 0.02919602095062146, 0.09666796322562732, 0.007273616829479579, 0.026750418001029175, 0.03962074115406722, 0.031138160193222575, 0.07130259502446279, 0.016307402001984883, 0.060744772490579635, 0.1031998053076677, 0.08327839459525421, 0.03419102547923103, 0.016439214850834105, 0.0261743184455554, 0.02870464311854448, 0.010320685014448827, 0.0248303576518083, 0.060145807365188375, 0.057613992830738425, 0.04398296645376831, 0.01485214688727865, 0.09323225734988227, 0.007181499604484998, 0.013534359786717687, 0.03216757468180731, 0.03788734393310733, 0.06818691806984134, 0.009283536419388838, 0.05943731979641598, 0.026487369323149323, 0.03877945368003566, 0.031201584133668803, 0.03605206838983577, 0.045416806897264905, 0.021566843024629634, 0.01735711979563348, 0.029816372916684486, 0.023535970467492007, 0.01670606518018758, 0.11137368623167276, 0.03982922527939081, 0.060210069932509214, 0.0366272922110511, 0.009462965463171713, 0.04075089847901836, 0.05303306403220631, 0.009901882731355727, 0.07975092958076857, 0.055032246600603685, 0.057401267331442796, 0.0031249565836333204, 0.016250887456408236, 0.0438073520490434, 0.05434882878034841, 0.019317760779813398, 0.040585273382021114, 0.014865737466607243, 0.00907478326553246, 0.16029408696340397, 0.03704406008182559, 0.027928889139730018, 0.09563938365317881, 0.007749226806481602, 0.041912982997018844, 0.06309677206445485, 0.015700006078986917, 0.05370506762119476, 0.029485666345863137, 0.03709521632117685, 0.032300537859555334, 0.047295052791014314, 0.064674347959226, 0.029664798530575354, 0.007451002184097888, 0.04336516933108214, 0.016771997579780873, 0.05427504816907458, 0.0965582366916351, 0.0056002268865995575, 0.0038834106362628518, 0.021678938865079544, 0.09985125725506805, 0.0432012251985725, 0.062031812412897125, 0.0052434996905503795, 0.06538339584949426, 0.08431191687122919, 0.010432838371343678, 0.019672188245749567, 0.02783326341159409, 0.060047873557778075, 0.03096058837400051, 0.10490503060282208, 0.06219009395863395, 0.04482009790081065, 0.041751257886062376, 0.04332731979957316, 0.04062911575601902, 0.013794859187328257, 0.04499120004766155, 0.04678694509493653, 0.03512260635034181, 0.06638841223320924, 0.01071445094567025, 0.05027270512073301, 0.023369258124148473, 0.022053493376006372, 0.04553473416308407, 0.06284956267336383, 0.09795458012376912, 0.036313334057922475, 0.1050408065202646, 0.018835967784980312, 0.031790200009709224, 0.027254492124484386, 0.07387192512396723, 0.07099760943674482, 0.03874202346196398, 0.025407169669051655, 0.04652093710319605, 0.14344541996251792, 0.017684733466012403, 0.10165875050006434, 0.036009124014526606, 0.042506660320213996, 0.0744419613329228, 0.09041077515576035, 0.031654316480853595, 0.015481235786865, 0.039607438156963326, 0.020349793194327503, 0.046655544138047844, 0.03132179721433204, 0.02972365269670263, 0.03150962736981455, 0.05180460182600655, 0.011248240662098397, 0.016319614042004105, 0.03485687295324169, 0.030601277576352004, 0.021105848718434572, 0.03919268521713093, 0.032569896648055874, 0.033139428196591325, 0.051973959925817326, 0.07546745357103646, 0.05476062055095099, 0.028136725741205737, 0.014615420332120266, 0.026401142895338126, 0.04677492230257485, 0.10453107723151334, 0.11274832926574163, 0.032360373515984975, 0.06351524687488563, 0.053886151654296555, 0.04321520355006214, 0.051536296887206845, 0.017646093547227792, 0.05101480084704235, 0.011311379803373711, 0.01577500566781964, 0.09339080235804431, 0.05029188592743594, 0.04178470648184884, 0.02752335181867238, 0.027743556311179418, 0.032824338268255815, 0.054779459969722666, 0.0351142646104563, 0.008053137207753025, 0.011814647768915165, 0.008933020071708597, 0.035826221719617024, 0.05978546498226933, 0.032375580121879466, 0.05714986109524034, 0.06498237635241821, 0.00783243640398723, 0.05709741351893172, 0.042026802475447766, 0.07121151124010794, 0.04308816642151214, 0.009848262561718002, 0.04982755010132678, 0.11398876231396571, 0.047785170827410184, 0.045569559442810714, 0.09344862308353186, 0.025575475774530787, 0.05432442696474027, 0.011687803598761093, 0.017767944918887224, 0.0429130678094225, 0.02811306607327424, 0.029341205445234664, 0.022811988710600417, 0.013336491156223929, 0.0012425072350197297, 0.01497679615567904, 0.043894216723856516, 0.05932258747634478, 0.05038623516156804, 0.009614836708351504, 0.04863975387706887, 0.030728542915312573, 0.048416775607620366, 0.01952041347976774, 0.04881809567450546, 0.05334374189260416, 0.013481671012414154, 0.03388315664778929, 0.02052293439191999, 0.045976660840096883, 0.012869190450146561, 0.005091770844956045, 0.023166308565123472, 0.03162976252497174, 0.07239653554279357, 0.04051510331919417, 0.012584718751895707, 0.040100057231029496, 0.04369820067950059, 0.028905086073791608, 0.07101640061591752, 0.0324617100704927, 0.022382335300790146, 0.05767147958977148, 0.047553179174428806, 0.04297104438592214, 0.01648213881708216, 0.041639713090262376, 0.04509320453507826, 0.017515184263174888, 0.19064559659454972, 0.07254308002302423, 0.03240508049202617, 0.04724870566860773, 0.017939368044608273, 0.02892745626013493, 0.04886557086138055, 0.04890768032055348, 0.07095786000718363, 0.029358807332755532, 0.062317479896591976, 0.021195398112467956, 0.0338525912957266, 0.03465693836915307, 0.020761232444783673, 0.03697241314512212, 0.0375805141084129, 0.04005401067843195, 0.05258879216853529, 0.0662495415599551, 0.04711054003564641, 0.0319825312908506, 0.022838552031316794, 0.048434182681376114, 0.05066022124083247, 0.03244237712351605, 0.04287490286515094, 0.03369046171428636, 0.027003909672203008, 0.00987483237622655, 0.045410747261485085, 0.018431155913276598, 0.03161116430419497, 0.030838857601338532, 0.020252950344001874, 0.027976008095720317, 0.09480782944592647, 0.11703686672262847, 0.15147177677135915, 0.10094063356518745, 0.09631606648326851, 0.07096160043147393, 0.144476396671962, 0.1831662916811183, 0.13307767629157752, 0.14567780017387122, 0.17636505741393194, 0.12502556695835665, 0.15015816054074094, 0.10236487432848662, 0.16977518680505455, 0.17970677028642967, 0.10305789925041609, 0.14719194470671937, 0.13031002948991954, 0.06035090729710646, 0.1478975935606286, 0.21744152123574167, 0.1891267320024781, 0.09508750779787078, 0.1280967373168096, 0.15036774304462597, 0.3454976185457781, 0.070371459441958, 0.1583806224516593, 0.13309124275110662, 0.11750234916689806, 0.12521264754468575, 0.2030877023935318, 0.10627584415487945, 0.17089305416448042, 0.1504573499551043, 0.06512195206596516, 0.17843087000073865, 0.08080066036200151, 0.1527500370866619, 0.12100242151063867, 0.095697946526343, 0.12681047664955258, 0.10837075635208748, 0.1457030777237378, 0.13880888203857467, 0.1393315618042834, 0.09901896090013906, 0.18919716181699187, 0.07873883310821839, 0.1895509139285423, 0.16066896059783176, 0.16137817176058888, 0.08904626243747771, 0.11234050427447073, 0.21004229405662045, 0.13521740678697824, 0.17960331490030512, 0.26240462728310376, 0.11820412400993519, 0.17449494916945696, 0.1393339515198022, 0.10719952115323395, 0.2277999435318634, 0.10587574492092244, 0.12103653803933412, 0.10125695174792781, 0.07371113140834495, 0.12111606658436358, 0.24747972580371425, 0.23143146507209167, 0.1682159345364198, 0.16094334743684158, 0.18693368561798707, 0.12143082625698298, 0.11321504367515445, 0.22511776245664805, 0.2774324646452442, 0.16942216199822724, 0.22637604415649548, 0.23376966069918126, 0.14258061011787504, 0.1635832854663022, 0.20715199992991984, 0.07562421000329778, 0.12429859620169736, 0.19286549388198182, 0.11635156013653614, 0.11675986752379686, 0.24066442041657865, 0.19042206171434373, 0.2580025634961203, 0.15114466776140034, 0.1971377560403198, 0.2184510201914236, 0.10292180420947261, 0.11180656612850726, 0.10640651409630664, 0.10477264630026184, 0.1227976025256794, 0.09524723282083869, 0.14600251946831122, 0.14067260781303048, 0.14741565770236775, 0.13783301721559837, 0.14936183608369902, 0.11144776741275564, 0.11481569294119254, 0.14223426464013755, 0.13332089292816818, 0.14726892026374117, 0.09732120161061175, 0.21388592140283436, 0.10137890887563117, 0.2533837332157418, 0.18419809959596023, 0.12417027144692838, 0.1362070903996937, 0.13869598653400317, 0.1960056394455023, 0.09625503225834109, 0.16396883118432015, 0.14992695185355842, 0.21292207937221974, 0.16015787317883223, 0.09286839718697593, 0.27775889087934047, 0.1102343485399615, 0.14298687659902498, 0.13317418517544866, 0.1853939815191552, 0.11852382638608105, 0.08147401094902307, 0.15778046246850863, 0.1895109863835387, 0.2309033676283434, 0.06195497415319551, 0.19735970272449777, 0.15084101061802357, 0.12937661551404744, 0.2849683805834502, 0.14266433921875432, 0.15544879774097353, 0.23602351866429672, 0.08833579704514705, 0.09977676789276302, 0.1107129076262936, 0.14399609353858978, 0.18847370141884312, 0.1510822679847479, 0.12754049763316289, 0.10153082650504075, 0.11796349004725926, 0.16212242713663727, 0.07207422822830267, 0.13771568366792053, 0.05835567295434885, 0.18798107863403857, 0.0985202970332466, 0.14508667954942212, 0.09091963613172993, 0.11624549239058979, 0.16725495719583705, 0.1589739101473242, 0.15083882870385423, 0.15219526685541496, 0.07948975297040306, 0.1561788484104909, 0.1606536129838787, 0.08105196640826762, 0.09775992220966145, 0.10140043857973069, 0.14207057654857635, 0.09620288154110312, 0.21072639094199985, 0.1576604275032878], [0.009705297088657971, 0.022841687605250627, 0.053129439329495654, 0.027686279208865017, 0.06844370858743787, 0.05107576827867888, 0.049069880406023, 0.06069513394322712, 0.004588131805576268, 0.06698679106193595, 0.07584040504298173, 0.03026357626367826, 0.016642633818264585, 0.054807713531772606, 0.049850957439048216, 0.056775299162836745, 0.0373740671784617, 0.026675663320929743, 0.046100209874566644, 0.02302597957168473, 0.04520881630014628, 0.005935416029387852, 0.011295505264570238, 0.04141378107306082, 0.027852839411934838, 0.03806785651249811, 0.060710804391419515, 0.041704676987137645, 0.020245115119905677, 0.0788621706306003, 0.03614546396420337, 0.057222829054808244, 0.012445447318896186, 0.07281011960003525, 0.03511188602715265, 0.026731812358775642, 0.029268959224282298, 0.037050709725008346, 0.03162022592732683, 0.022361102455761284, 0.04400557969347574, 0.04048019269248471, 0.04215573950204998, 0.032769278332125396, 0.014881784554745536, 0.012069476233591558, 0.020976843043172266, 0.04981854413927067, 0.059078127742395736, 0.057098960896837525, 0.04044531917315908, 0.047167054581223056, 0.020291439977881964, 0.03522911938489415, 0.014840799449302722, 0.005806120916531654, 0.046726133514312096, 0.08299992594402283, 0.026259643163939472, 0.04249843361321837, 0.05241535967797972, 0.06876948915305547, 0.06054846329789143, 0.10023392344010063, 0.0406813072913792, 0.10956224476103671, 0.03744669746083673, 0.035938649671152234, 0.08558472240110859, 0.015181646540440852, 0.03826343468972482, 0.013652826037287014, 0.06617830280447379, 0.012546217058115872, 0.04551897836790886, 0.045476226950995624, 0.05447614050353877, 0.009587406930222642, 0.04704300459707156, 0.022969927013036795, 0.04084520318428986, 0.06716811258229427, 0.04844919632887468, 0.05093308296636678, 0.03440554326516576, 0.05437223611806985, 0.029461956582963467, 0.04715526556537952, 0.10453318493091501, 0.026986461780325044, 0.08770799948251806, 0.02159714676963631, 0.08094429562333971, 0.20869591942755505, 0.05743293106206693, 0.05908836938033346, 0.04074765158293303, 0.08401646045967937, 0.022713411090080626, 0.038612407370237634, 0.011131161299999803, 0.017695726528472733, 0.03328423234052025, 0.025727449065016117, 0.032047016502474435, 0.05681186477886513, 0.01575313086505048, 0.06281523834331892, 0.07167994743213058, 0.0490737544168951, 0.0697749359824229, 0.012325208263064269, 0.05913591507123783, 0.057597661871113814, 0.11570995120564476, 0.03721250905073248, 0.026210498144791927, 0.08961411673226394, 0.09232722310116515, 0.04177863571385387, 0.03529076217091642, 0.04682560727815144, 0.09721043606987223, 0.10099988663569093, 0.06775672474759631, 0.06550743099069223, 0.02004862966714427, 0.06747697218088433, 0.07529819195042364, 0.06457521187257953, 0.07428693410474807, 0.034480463073123246, 0.02069483249215409, 0.016788638386060484, 0.11806784343207255, 0.046054616032051854, 0.03409339966310654, 0.020668799807026517, 0.010918966436292976, 0.07603522622957826, 0.020985722840123344, 0.0528692238003714, 0.02215902306488715, 0.09777611587196589, 0.07943953183712438, 0.015296524506993592, 0.007906628907221602, 0.008641690001240931, 0.04916605161270127, 0.017070760259230155, 0.020548933680402115, 0.045295358140720055, 0.08663876506034285, 0.02071017268463038, 0.040469839732395485, 0.011175752315466525, 0.030462974646070506, 0.03900688112480566, 0.06445968174375594, 0.05653720334521495, 0.02665494441316696, 0.12044274568324909, 0.07061567797791213, 0.031107843460631557, 0.07814905577106401, 0.04942730243783444, 0.05295120885421056, 0.020887677710561547, 0.009553260715620127, 0.06937356025446206, 0.06397483666660264, 0.004096505817869911, 0.046553502543247305, 0.017133403089246713, 0.04071782095707022, 0.011350045697327005, 0.014718798720423365, 0.04998223594157025, 0.026359773728472646, 0.015545079968433129, 0.06660690050921403, 0.0799765127885621, 0.06938369057024829, 0.04639376638806425, 0.051425579586066306, 0.10005094693042338, 0.03370515623828396, 0.04011153825558722, 0.016472416682518087, 0.02023575292696478, 0.029867102421121672, 0.0812705437419936, 0.046012272796360776, 0.04736398346722126, 0.05967515586235095, 0.02642066694534151, 0.020862596829829272, 0.03806096938205883, 0.014838329025224084, 0.025924528235918842, 0.05154253463842906, 0.03950932623411063, 0.0340421283908654, 0.014961266715545207, 0.05065209843451157, 0.042355855912319385, 0.034558128827484325, 0.0685550678463187, 0.01602325963176554, 0.03262258542235941, 0.023444934922736138, 0.030010205191501882, 0.020805774292966817, 0.0350795617850963, 0.02400205034064129, 0.024127289616444614, 0.08053978803218342, 0.06766351099940948, 0.03554165632522199, 0.04673403738706838, 0.07374212349532172, 0.03807834305916913, 0.03326567864860408, 0.07240127786644734, 0.03314942121505737, 0.04822063710889779, 0.08841494709486142, 0.08106959241558798, 0.0092361382303352, 0.0163727314065909, 0.020763716784131248, 0.03186963949701749, 0.014061810634302674, 0.04583017202094197, 0.040565283634350635, 0.022635110799456015, 0.06322509681922384, 0.046365746602532454, 0.04500680741330143, 0.06001977213600185, 0.01798133092961507, 0.03755710305995308, 0.0063027591841091635, 0.03272095709689893, 0.0364152680413099, 0.010149708105018362, 0.03753473843971733, 0.03398723914870061, 0.006267603184824111, 0.06223154290637467, 0.01623940272111213, 0.08092954172752798, 0.0170262870597071, 0.046461628371616825, 0.06425069295801222, 0.09789946081582457, 0.059865086295758374, 0.061977223740541376, 0.09323789025074802, 0.03835628849628847, 0.022026699989510234, 0.13233555830083787, 0.1177350792568177, 0.04176865753834136, 0.06192406370246317, 0.031008978257887065, 0.10651454111211933, 0.054790477151982486, 0.19111507921479642, 0.146214239357505, 0.08067478469456546, 0.014532241348206298, 0.10112056726939045, 0.08761162418522872, 0.07152964026317932, 0.03890018997481093, 0.03850074754154775, 0.04761666619742755, 0.04367476736661047, 0.03970311212469824, 0.060391113147488795, 0.028457513508328702, 0.03299505820905324, 0.046195390314096585, 0.034247217190568335, 0.0585421004507225, 0.012180874455225421, 0.037909370876150206, 0.04970721827703528, 0.05142411384440493, 0.05826963948493358, 0.0649397548113484, 0.044653348450083286, 0.021795541397295892, 0.029801518830936402, 0.004633885209841537, 0.027375469617254566, 0.03372668594238348, 0.029858281995984726, 0.045233503842609935, 0.029029102661297657, 0.04693297378253192, 0.06656377430772409, 0.05635649409668986, 0.03896051915944554, 0.04200957351713441, 0.05616100497718435, 0.038966400679782964, 0.0077534301453852095, 0.04550444340566173, 0.03146684255625587, 0.022644023993052542, 0.018076954802381806, 0.021746837956015952, 0.025805604636843782, 0.08132305811159313, 0.02541029782150872, 0.06384205902577378, 0.033420846884837374, 0.11267433714237995, 0.01343737036222592, 0.024400359143328387, 0.01739869490847923, 0.05127310905663762, 0.008766128685238073, 0.02228531433502212, 0.02443898978526704, 0.03285492588474881, 0.019337681878823787, 0.005745899343310157, 0.024376747714995872, 0.0138830894138664, 0.004707167190645123, 0.05907663973630406, 0.028746544776367955, 0.021330019990273286, 0.03038022703549359, 0.06469601867138408, 0.04284454902517609, 0.026212013981421478, 0.05169303847651463, 0.05340960378816817, 0.04682984494138509, 0.06465572747401893, 0.02417447351035662, 0.020002002383989748, 0.020951240803697146, 0.06491838095826097, 0.03577609335479792, 0.04501955751038622, 0.04408416942169424, 0.016640622598060872, 0.06096497883845586, 0.10616297833621502, 0.11698666043230332, 0.11683051998261362, 0.2676530659664422, 0.12837240064982325, 0.16256260976660997, 0.1846712632686831, 0.09896338146063499, 0.4450637649279088, 0.14128465700196102, 0.10767949032015167, 0.07031423243461177, 0.17082747799577191, 0.15849874267587438, 0.22699851309880614, 0.12026163938571699, 0.1123911039030645, 0.15660432167351246, 0.09269446003600024, 0.10063258290756494, 0.21527214936213568, 0.14003556309035048, 0.09872455833829008, 0.1386869471753016, 0.15942711004754528, 0.12837605201639235, 0.08671440475154668, 0.15446350764250383, 0.22028480772860348, 0.15802155656274408, 0.19057610188610852, 0.11383356439182535, 0.11622374746366404, 0.17609666712814942, 0.1760954351630062, 0.156214501184877, 0.10116283257957548, 0.18509835441363975, 0.06285316951107234, 0.178831689117942, 0.1746756472857669, 0.10827284480910748, 0.10895621438976377, 0.1345377034158446, 0.2141639299225062, 0.14536908158333972, 0.12022750059259124, 0.2405051703681238, 0.21372827439336106, 0.10853296756977215, 0.1767217187443748, 0.144302882545162, 0.16577162663452327, 0.08368942566448823, 0.07659142880584113, 0.12206827173940837, 0.1869253141921945, 0.17694311623927206, 0.1450515165925026, 0.19360381207661703, 0.16779338533524424, 0.16825069673359394, 0.25364357396028936, 0.07885934304795228, 0.15872137213591486, 0.13258811115520075, 0.11931722678127699, 0.25827463483437896, 0.12612108082976192, 0.21247492055408657, 0.14398634171811864, 0.24561329861171544, 0.09222934124409221, 0.15535853774053976, 0.23610153322806582, 0.10992893250659108, 0.20493697113124654, 0.1675727596739307, 0.1923170467489399, 0.14943838119506836, 0.3099591942736879, 0.24820228078169748, 0.2887483168160543, 0.1524748932570219, 0.16493829869432375, 0.2850721328286454, 0.18413792626233771, 0.21555760904448107, 0.14639303757576272, 0.20464934437768534, 0.17095242597861215, 0.40025915193837136, 0.3464257187442854, 0.30439658963587135, 0.13873483054339886, 0.29066587798297405, 0.18981681059813127, 0.15896864089882, 0.11907860403880477, 0.16516725125256926, 0.1685422271839343, 0.11669852159684524, 0.10839270165888593, 0.21891588665312156, 0.11962657619733363, 0.10792474786285311, 0.17969716689549387, 0.13454994885250926, 0.1285008218837902, 0.13882351719075814, 0.07561807986348867, 0.18219945137389004, 0.16846712183905765, 0.21152023662580177, 0.12281925097340718, 0.10182453886955045, 0.13163157185772434, 0.14557621499989182, 0.2223351242719218, 0.11811096963356249, 0.11571719456696883, 0.22450658900197595, 0.1564176270039752, 0.187957611924503, 0.15113188797840849, 0.15974083071341738, 0.10774992755614221, 0.09925263351760805, 0.2097095298813656, 0.16960311244474724, 0.10819508257554844, 0.06733614223776385, 0.1364162573008798, 0.3262638224987313, 0.1185470778727904, 0.10213430388830602, 0.11990468861768022, 0.21214292821241543, 0.1604122220305726, 0.13076463947072625, 0.11512730590766296, 0.15168521844316274, 0.1817348223994486, 0.10419483980513178, 0.14553674758644775, 0.09310814799391665, 0.11994529151706956, 0.12834329361794516, 0.14427436923142523, 0.056535203257226385, 0.09627420193282887, 0.13545501278713346, 0.07851265618228354, 0.11192247475264594, 0.12737309880321845, 0.07501171552576125, 0.14667949173599482, 0.2166077628498897, 0.13985676487209275, 0.1477941678604111, 0.1593872270314023, 0.1956554496427998, 0.15465213189600036, 0.21060070081148297, 0.1503060112008825, 0.15631201938958839, 0.20268017426133156, 0.10787864564917982, 0.15715925517724827, 0.16272488777758554, 0.13301293132826686, 0.17671330278972164, 0.13242705026641488, 0.13450991740683094, 0.11477411782834679], [0.04231129365507513, 0.02725828264374286, 0.0487854189123027, 0.026732047990662977, 0.011918045638594776, 0.036531302830553614, 0.011954813489865046, 0.022143005662655924, 0.011617599211604102, 0.07002777827437967, 0.036497312466963194, 0.011708243273460539, 0.07586277337395586, 0.03449982941674534, 0.01782929084583884, 0.07812121039023623, 0.07443744907504879, 0.040641483647050336, 0.025699518337205518, 0.06307176168775186, 0.0364543309842702, 0.02859707994502969, 0.04633083597582299, 0.027808950653707143, 0.09289347435696982, 0.07529781345510855, 0.09336353585240431, 0.027316403939039446, 0.05557312011660542, 0.03597254355554469, 0.018219471276097465, 0.046339882756001316, 0.08331683042342775, 0.043960464536212385, 0.029192202600825112, 0.022013627058186103, 0.032397992981714197, 0.025629435476730578, 0.07919527619378641, 0.05519782345800195, 0.030440908740274608, 0.028320744968368672, 0.04378037127025891, 0.03526603009959217, 0.054539512493647635, 0.01967473010154208, 0.05333060587872751, 0.06536550266901031, 0.023087598237907514, 0.010764561684482032, 0.03816164542513434, 0.03354200249304995, 0.032070164088509046, 0.03282760371803306, 0.050828610837925225, 0.03660090143966954, 0.023805026830814313, 0.06108591922384221, 0.00820735363959102, 0.05685083866410423, 0.022460116088041104, 0.01604425870027626, 0.03221452665457036, 0.08184266538592055, 0.032675129477865994, 0.04413625334564131, 0.09851327631622553, 0.09245924375136383, 0.020575374546751846, 0.06980065139941871, 0.02006554506806424, 0.027656352103804238, 0.07679646936594509, 0.06353763747029006, 0.06091642382671125, 0.0220215068111429, 0.029128789792594034, 0.03555793533450924, 0.04912818723823875, 0.054446810827357695, 0.12203785110614263, 0.07097003122908063, 0.1414916865178384, 0.08068111521424726, 0.0720176320464816, 0.017536754785396624, 0.0035966002451459644, 0.07962216695887037, 0.01234943381859921, 0.06626227681408636, 0.07526983448769897, 0.02333526404981967, 0.10589845463982783, 0.07190487754996866, 0.07897019022493623, 0.05815227625134867, 0.0621164951735409, 0.012488045667851111, 0.08487509563565254, 0.008060033615038265, 0.1111194709665142, 0.014258083647291642, 0.0930589807103388, 0.03651632629043888, 0.048460209800396115, 0.02802375231112819, 0.019188428559573367, 0.02418831456452608, 0.01433381054084748, 0.06016066516167484, 0.0667642655025702, 0.0224106742098229, 0.021603002314805053, 0.03688086551846936, 0.030736392982362304, 0.03268344524258282, 0.018732451171672437, 0.06970287344302051, 0.01927083849295741, 0.04015158825495746, 0.016960994762484916, 0.010572755472821882, 0.024972718274511863, 0.06633902972680517, 0.029667429444089066, 0.013974519224575488, 0.07077021538862027, 0.031026372344058473, 0.011539273873495404, 0.04176558133622166, 0.026449807373865042, 0.051850503659807146, 0.04458828807401005, 0.05000160599593073, 0.042756623079185374, 0.07216274418169633, 0.027119202313770074, 0.009317338463006308, 0.03953644059947692, 0.02419195294351084, 0.06531304767122492, 0.04148016989347525, 0.048612413156661205, 0.03759491548407823, 0.023622232147317845, 0.025028013842529617, 0.039533980379928835, 0.009114837903325679, 0.0721761622116901, 0.02331115352717461, 0.03748666953470092, 0.02190442188293673, 0.022173053366714157, 0.0244032776390668, 0.013910470024711685, 0.01899895454698708, 0.03726269678736571, 0.08486638282192871, 0.031439342274097726, 0.0073699874883459415, 0.04313189747335855, 0.023651769624848384, 0.03566708670405205, 0.05372175481170416, 0.03910546060069464, 0.05142308225913439, 0.013557806087192148, 0.011201244160474744, 0.014970882166380761, 0.04050273171742447, 0.061646318645216525, 0.068787300697295, 0.005241976432444062, 0.045318676420720294, 0.014609357913286658, 0.018049582540697884, 0.022869100685056765, 0.015463469699170673, 0.0295511404692661, 0.053239908011164516, 0.04067712157848291, 0.04124963656067848, 0.00605199861638539, 0.019548865566321183, 0.041083228497882374, 0.042626936483429745, 0.08921311207814142, 0.011815143152489327, 0.03317849485029001, 0.0856809715332929, 0.03516504235449247, 0.024372573134314734, 0.03885202087985817, 0.0641078369517345, 0.02567077495768899, 0.02518389082979411, 0.05988351011183113, 0.03787438974541146, 0.05516383680514991, 0.022029698266123887, 0.038380931509891525, 0.040566868119640276, 0.08142193444655277, 0.05937904636084568, 0.08487333674565889, 0.012280245246074628, 0.04272274032700807, 0.019454375324130524, 0.061248809506651014, 0.05729856522521004, 0.018415869526506867, 0.017175920729641803, 0.024940390321717132, 0.03246396991016809, 0.028520510713860858, 0.027496217044244986, 0.032352135676774196, 0.06422401274903677, 0.04781407005793881, 0.04126414925849531, 0.031447465080418624, 0.031045608811837155, 0.08260295857326128, 0.04358382830105256, 0.021544925548369065, 0.04413657989061903, 0.01838040228903992, 0.03990994497144129, 0.03718627413036302, 0.048630510427756235, 0.07564459679997526, 0.03135543505777605, 0.013513705816876609, 0.04487770711421035, 0.018423908841214143, 0.03361652896273881, 0.04239178328134585, 0.035254912727396004, 0.055097258737077937, 0.07819800783181563, 0.03354287451657001, 0.03625183970143553, 0.11527579481480643, 0.005605297146757948, 0.05310122658556793, 0.10173463510000147, 0.012145485143264523, 0.03442530294705648, 0.06315701219136827, 0.025822408715612255, 0.021552864673139993, 0.05706905234546866, 0.05083773925434798, 0.041709233773872256, 0.020214724172546994, 0.040098680547089316, 0.036002329652546905, 0.11469718680018559, 0.09710558544611558, 0.1383953425101936, 0.04739489020721521, 0.04559428780339658, 0.06285161100095138, 0.04163104109466076, 0.041782320477068424, 0.021987841137161013, 0.02005911806918448, 0.03164230853144545, 0.10714201212977059, 0.0660737490397878, 0.09907091123750433, 0.07665998840820976, 0.1013083677389659, 0.037820936559000984, 0.08946263696998358, 0.03315205955004785, 0.06260395632125437, 0.0462308204441797, 0.016241347148024943, 0.027245380406384356, 0.06640787876676768, 0.032340383768314496, 0.018210532107332256, 0.08573000523028895, 0.01572004777699476, 0.0457833350810688, 0.05581480792898219, 0.09174719758448191, 0.014767533702979563, 0.05723530826799106, 0.023661638333578594, 0.034035430508083664, 0.04087096684088465, 0.08003558774362318, 0.024582934893260244, 0.03012058667081874, 0.03802940213063266, 0.0463968982512597, 0.06543849289300852, 0.03479637307464145, 0.01456604988561594, 0.07450833159964532, 0.01834418362705037, 0.04846661082410719, 0.03376171531272121, 0.03487540809146594, 0.02613327953440603, 0.03164127694617491, 0.021456858594319783, 0.016985617367026862, 0.03907658363459632, 0.08377224192372523, 0.029784477264911402, 0.04484094482904766, 0.0155154515778122, 0.024349338345928118, 0.029353992649703287, 0.026821326500794385, 0.02907573365519056, 0.025027197480085306, 0.09205325186485425, 0.011082718538091285, 0.03481299718259834, 0.044164733262732625, 0.02105872790707508, 0.013740547892666655, 0.08295288862427697, 0.004710530047304928, 0.037444114786922, 0.02409067761618644, 0.009358437673654407, 0.02935454554972239, 0.0354813679587096, 0.013091987821098883, 0.050907746044686064, 0.015039592981338501, 0.024265512765850872, 0.05284344901156146, 0.025244056741939858, 0.05159136424481403, 0.05284358259814326, 0.00589936806136393, 0.07168021460529417, 0.014877756548230536, 0.0358309417788405, 0.05336909736797679, 0.024078498972812667, 0.058320083262515254, 0.028861705686722416, 0.056752934542601, 0.06349675997626036, 0.019395803174120374, 0.147314814676065, 0.10046014489489608, 0.0956297579978127, 0.14898633904522285, 0.11554457843885757, 0.12084369838703424, 0.12543398566776887, 0.14149523398373276, 0.12743404397042468, 0.1373550295829773, 0.16700992971891537, 0.07230823481222615, 0.1243926263123285, 0.19425559585215524, 0.17696437134873122, 0.1856090856017545, 0.1447653296054341, 0.0703450092987623, 0.09619145246688277, 0.14340409717988223, 0.09521160231088288, 0.11942019977141172, 0.17162406962597743, 0.10286559394444339, 0.16277382499538362, 0.14248601597500965, 0.30942475888878107, 0.14426745241507888, 0.2649148675845936, 0.1567252175300382, 0.1342037518043071, 0.14327916403999552, 0.2521144232014194, 0.2158981657703407, 0.13678796938620508, 0.1223910391854588, 0.2023639451363124, 0.17027532012434676, 0.12106917769415304, 0.12689690716797486, 0.16502775717526674, 0.11786781236878596, 0.13805585447698832, 0.12502678408054635, 0.2011841381317936, 0.08373815508093685, 0.22510149457957596, 0.12448485300410539, 0.13328610104508698, 0.10615071063512005, 0.1342480134917423, 0.13939963158918545, 0.1368735686992295, 0.12982188927708194, 0.1728246419224888, 0.08651141994050704, 0.10113535085110925, 0.21733707137173042, 0.11972480686381459, 0.18451734184054658, 0.09576448006555438, 0.2852244512178004, 0.17741570103680715, 0.13438701775157824, 0.14530116022797301, 0.18673596263397485, 0.21737012662924826, 0.22545244137290865, 0.08197178423870355, 0.31151619041338563, 0.09527101123239845, 0.13767661701422185, 0.18738651444436982, 0.15242464985931292, 0.10244489269098267, 0.1418367406586185, 0.16251586930593476, 0.11742194488761015, 0.08562965202145278, 0.10174858747632243, 0.22833529917988926, 0.24369121034396812, 0.3154891147278249, 0.18409148266073316, 0.23371251532807946, 0.17130833031842485, 0.15707328479038551, 0.15158112481003627, 0.13067460211459547, 0.16377648134948686, 0.19525805924786255, 0.10529410894378088, 0.3596705017844215, 0.18148905277485028, 0.15646249725250527, 0.2015495122759603, 0.18026449426542968, 0.06793341526645236, 0.16758565820055082, 0.09492413140833378, 0.17091456160414964, 0.23912137665320188, 0.1766018322086893, 0.11381954522221349, 0.1484115605126135, 0.09978645291994326, 0.0989169452805072, 0.293622802128084, 0.14024912350578234, 0.12113712873542681, 0.22781634499551728, 0.14155258715618402, 0.10859268077183515, 0.12357152154436335, 0.15754655236378312, 0.1895698535372503, 0.10679243830963969, 0.18508659879444167, 0.12532478605862707, 0.1133531573577784, 0.18021459225565195, 0.13300827064085752, 0.14910684898495674, 0.1809612225042656, 0.1256546113290824, 0.14935319748474285, 0.10543190350290388, 0.14306224911706522, 0.16059061948908493, 0.15390965767437592, 0.1509790203999728, 0.14203755097696558, 0.2701499476097524, 0.13207628158852458, 0.12797316972864792, 0.18143921013688669, 0.09172966063488275, 0.08314532751683146, 0.16327027726219967, 0.096481238870183, 0.17651823669439182, 0.09468643635045737, 0.12429010603227653, 0.11505906542879529, 0.1771552665741183, 0.09209769908920862, 0.1601487150765024, 0.13002782041439787, 0.09608511012629606, 0.11223225461435504, 0.306459671119228, 0.06900070526171476, 0.12512210552813485, 0.11325938699883409, 0.09145004165475257, 0.08771196255111136, 0.08376917685382068, 0.14004708122229204, 0.11480054570711218, 0.07992172744707204, 0.10709895272157155, 0.20921975694363937, 0.11314332252368331, 0.19282994500827044, 0.15928953071124852, 0.20768360031070188, 0.13656309864018112, 0.12405494169797748, 0.1117565824824851, 0.18716804101131856, 0.18150475661968812, 0.1379842817550525, 0.09205426860717125, 0.113747326831799, 0.09380739953485318, 0.09769333672011271], [0.06020064094627742, 0.02764028831734322, 0.03684542796690948, 0.07433495105942711, 0.03391191487025935, 0.0726794867659919, 0.023312361372518353, 0.03316300251754001, 0.06719303390127607, 0.0703736042487435, 0.02518359211535426, 0.043597773255896755, 0.00231659704240883, 0.013139072452759137, 0.028887274529552087, 0.0358166665682802, 0.01213497540447861, 0.06278820932493545, 0.03709017713845242, 0.03794178046518937, 0.0434883213165449, 0.028818588762078434, 0.009059626754606143, 0.033127160495496355, 0.04421156278112903, 0.03374592983163893, 0.04472629043448251, 0.02378801495069638, 0.019827117139357142, 0.023608498704561498, 0.06550677790073678, 0.027688709742506035, 0.013702224314329214, 0.03164185953210108, 0.014401053758774651, 0.05261710881313775, 0.058562932536005974, 0.059289302153047174, 0.021902739063079935, 0.031371636141557246, 0.019676446318044327, 0.022086454009695444, 0.06901980072143488, 0.01469895183618064, 0.03223139567126054, 0.018875576206482947, 0.018955627965624444, 0.09957249174476601, 0.08334395592100918, 0.05414238927187398, 0.04935404875141103, 0.028088352555641904, 0.007772159633532283, 0.039945237804204226, 0.03162540240737144, 0.035989156531286426, 0.024270121502922848, 0.015078315464052139, 0.0825647973397281, 0.0426634204632137, 0.014681344382552197, 0.03646419783763122, 0.06473301473306492, 0.060444510672823526, 0.043861692101927474, 0.030598693047068082, 0.07468053954653442, 0.035870461142621934, 0.03547830288880505, 0.03941949296859093, 0.02960342291771667, 0.0679899075475987, 0.032813265424920246, 0.08949471259256825, 0.06572046448127367, 0.051607079221867025, 0.059893844518228434, 0.07588014705106616, 0.21976622461806983, 0.19422938319621608, 0.23617610422661528, 0.37382109090685844, 0.288456593407318, 0.3812930634012446, 0.3256442182464525, 0.34817979962099344, 0.1390383392572403, 0.27975838514976203, 0.2983130270149559, 0.1364293190999888, 0.3414475702447817, 0.2372287813341245, 0.3949687967542559, 0.5615482362918556, 0.48506757302675396, 0.24093839165288955, 0.43745784962084144, 0.14423488697502762, 0.04308163181121927, 0.025967878937080968, 0.01443915840354748, 0.053271074502845295, 0.06667079942417331, 0.06746655242750421, 0.08506680722348392, 0.0639578934351448, 0.040250011879834346, 0.06524006486870348, 0.050618260211194865, 0.0682378294004593, 0.07472560275346041, 0.10199488402577117, 0.01209469533932861, 0.08921836648369208, 0.01718404168059351, 0.05680851769284345, 0.033089277567341924, 0.10841025345143862, 0.028633465590246487, 0.04130592104047537, 0.02470379364240216, 0.08377371879760176, 0.026958211929013487, 0.026803080800164025, 0.02109748100338038, 0.08956724268500693, 0.02007222625252325, 0.07388196638203226, 0.1034119185351301, 0.03860226221149787, 0.045556122859125026, 0.022427778858400416, 0.017717625451041386, 0.015008711288828636, 0.041692156955832615, 0.028822677995776758, 0.07350893327384256, 0.03413527534576133, 0.022564120663446374, 0.04968891320459079, 0.041642948854132555, 0.01848642736149486, 0.026904862643277738, 0.026372559077572078, 0.03404044000490103, 0.022166014096001163, 0.05678528475982603, 0.040102465500240214, 0.05493872486113105, 0.05001143574190792, 0.06610955024370924, 0.027940761647187173, 0.03386784243048169, 0.011571300328796497, 0.011983217336819507, 0.054664575509377755, 0.018783483101287857, 0.01431598786439281, 0.042097317636944354, 0.018320251219847705, 0.04899676772765815, 0.054395424522226676, 0.026259281366947107, 0.016806405401439406, 0.016990062831609976, 0.01663318442297168, 0.055912619282025844, 0.060625494515988976, 0.06527789955725893, 0.020287250554247294, 0.025635407910158392, 0.04835690284380689, 0.06528098689159378, 0.010050725086330203, 0.07607680876390077, 0.030305103136925027, 0.09304416002123617, 0.06721525380271487, 0.03434605270740576, 0.05195559177082032, 0.034578638078528456, 0.04742117707792204, 0.03957224922487512, 0.004112449469175772, 0.0658123943139799, 0.03433868318097666, 0.013635635114042088, 0.04109167042770423, 0.044117061406723224, 0.035985861395602114, 0.03842909318336751, 0.03033765373402275, 0.07591643807245418, 0.04093836498213932, 0.02336084402486449, 0.07398989691864699, 0.04349221759184729, 0.028771657198376488, 0.015780417779751588, 0.09083615193958394, 0.07334650683333166, 0.029233759159978945, 0.051225017887190916, 0.07397306500934064, 0.01837329808040522, 0.04447633138624951, 0.024991871250676923, 0.013297093319124542, 0.02759067945589777, 0.0034945904235428316, 0.015838572471693624, 0.06198054114065599, 0.0210099892137805, 0.01297246957619791, 0.046379483756027184, 0.09848327870713547, 0.05680567155650351, 0.056909772611106746, 0.04253865801729262, 0.014229367170628393, 0.040948847818071954, 0.0010319288617210987, 0.09240492596291006, 0.026544716929493006, 0.026757817213365342, 0.06464027595939115, 0.015292748830688652, 0.029379682091530412, 0.06848132805316709, 0.034248122610733844, 0.03362798030138947, 0.011591084130486706, 0.08573566781706177, 0.07204877998447046, 0.03344731558172498, 0.13180949434172362, 0.03020275540620787, 0.04354734432126861, 0.08866528834914789, 0.11231765354750678, 0.03217394230887294, 0.03365212236531079, 0.05130722558533307, 0.06207425583852455, 0.013499582746590022, 0.0195156637346372, 0.028653878362092655, 0.11551338597200811, 0.13279276579851285, 0.047475038445554674, 0.013192227852414362, 0.007779759689583443, 0.039464608125854284, 0.15326957014622167, 0.22892239736393094, 0.2983411989407614, 0.48146542569156736, 0.25782317155972123, 0.2355616504792124, 0.1580828579608351, 0.21118659671628848, 0.1305134521680884, 0.06960565209737979, 0.12005382319330238, 0.07795093944878317, 0.06192591165017802, 0.019888539136445615, 0.15473017614567652, 0.27030662982724607, 0.29851875035092235, 0.34875858575105667, 0.32153028587345034, 0.5284083145670593, 0.34000726940575987, 0.2601342787966132, 0.051341954385861754, 0.06707511405693367, 0.05072134081274271, 0.022139369139040355, 0.026881024859903846, 0.06691271730232984, 0.03725472241058014, 0.10397319740150124, 0.011446727130532963, 0.03343573436723091, 0.0605917379289167, 0.02145394195395056, 0.05614511188468896, 0.027413013012846932, 0.06007638687151484, 0.013246085509308614, 0.0261498628242407, 0.04569317898130976, 0.13403060875134543, 0.03272692767495755, 0.06479931820649654, 0.04756844515213743, 0.047331499663414434, 0.1077688077930361, 0.009833654312387807, 0.030743510178581346, 0.032966374201350845, 0.0766460805607494, 0.04190149455098435, 0.06041317348717712, 0.0693162516108714, 0.08506281446898356, 0.017732049091137014, 0.07327999555855058, 0.002046836102636007, 0.018555664173618425, 0.0742348947096616, 0.03878372102917638, 0.028667188780673314, 0.08974241922260262, 0.03430740907788277, 0.042489412808208726, 0.04854302605963312, 0.015666687359043863, 0.019448091188678518, 0.03076406766922446, 0.054411477176472545, 0.05409410885476973, 0.024524214313714765, 0.03236335323890671, 0.0368901534966426, 0.05598618838121183, 0.03271430003223941, 0.040257585496874526, 0.02934043361165095, 0.04347640242485795, 0.03522617676935624, 0.0479302421445027, 0.022988300734141376, 0.017246395073016174, 0.034100683842552826, 0.0399350184306968, 0.03130450517346617, 0.07979410031111911, 0.05293556067044847, 0.03594949987018481, 0.06861587200546637, 0.04481366719119251, 0.028835897501267027, 0.05069248982181307, 0.011473716258478817, 0.0500107529660454, 0.05888071274966933, 0.0337160583876539, 0.017980809570872225, 0.09841066697845235, 0.007629677484146669, 0.16249023552518338, 0.14435765304369852, 0.25581352470908314, 0.12851665931520984, 0.13907296786783263, 0.16797705204226077, 0.14073416154133156, 0.10957463120575994, 0.15396006434457377, 0.15969112166203558, 0.1282611527130939, 0.15302884712582454, 0.07006654064753093, 0.16280938871204853, 0.1200667439843528, 0.1519229877158068, 0.23627103975741193, 0.15296867379220203, 0.159854453522712, 0.1918436455889605, 0.193183756491635, 0.1589402463287115, 0.07285864863661118, 0.22151999379275367, 0.1671787237864919, 0.11819567094789818, 0.12237212926265784, 0.1261545516899787, 0.07999829482287169, 0.20108132099267095, 0.16723680426366627, 0.17054923198884353, 0.08920637337723747, 0.12613587925443426, 0.07537993209552951, 0.09759340653545223, 0.13479159213602543, 0.09034131755470298, 0.12731978291412815, 0.1716117945034057, 0.12374156242003664, 0.1142185831849929, 0.16659451997838914, 0.06061447362299077, 0.12261777272215113, 0.08079823353909887, 0.14189850218826905, 0.14888724748743698, 0.13322199432877824, 0.16412394004873931, 0.1559729321161285, 0.10741829886683263, 0.1626883147400804, 0.09962641619495116, 0.09936326547176577, 0.15756390377646312, 0.18392562749795616, 0.18749523907899857, 0.2017621969571337, 0.26474372833035886, 0.12456196214770898, 0.12739938567392528, 0.28806812362745404, 0.20319057890446857, 0.09503508990746923, 0.10344814276322722, 0.1610184379387647, 0.24556908145314083, 0.12906155898235738, 0.1179705627146177, 0.12185619561932981, 0.2559280826244503, 0.2099127002293244, 0.16495992487762123, 0.1343847022508271, 0.15135009423829615, 0.10645403381204233, 0.3050024196272716, 0.5918443074915558, 0.4400176653871313, 0.5768695485312492, 0.5970491969492286, 0.4404359695035964, 0.5402483011130244, 0.49855509772896767, 0.5537643539719284, 0.2638913271948695, 0.433376245200634, 0.2153121362789534, 0.15111619897652417, 0.29939875937998295, 0.37749792798422277, 0.7271200174000114, 0.8082654944155365, 0.7664496882352978, 0.614652227377519, 0.8731475472450256, 0.5333965562749654, 0.35315058601554483, 0.21057856996776536, 0.1866449011140503, 0.13005354325287044, 0.11920427932636812, 0.17624224681640044, 0.28510811214800924, 0.1473040386918001, 0.16150105657288805, 0.15154146443819627, 0.17273068602662534, 0.18927964410977438, 0.08136922711855732, 0.22888548293849453, 0.1309044600930065, 0.1894763726158999, 0.1350500524858944, 0.10047466872492805, 0.1302944592316635, 0.2496767055708915, 0.18325672979699448, 0.2580173470778391, 0.21483033400727436, 0.1991819276008755, 0.155200460285414, 0.15432938671438023, 0.09657244139816612, 0.15979292948031798, 0.17423666693503037, 0.13981444761157036, 0.10079710962600075, 0.10422344217658974, 0.13807584793539718, 0.11925332044484094, 0.12310459933360107, 0.1178116763185244, 0.08368745897314511, 0.12111251169699244, 0.20255038747563958, 0.1006970384332817, 0.17752485611708835, 0.16414991521742195, 0.1170580179314129, 0.09636479589971714, 0.12401627580402419, 0.15246521565131843, 0.2038576063932851, 0.07370464503765106, 0.14890896272845566, 0.1409800795954652, 0.18785565567668527, 0.13183389615733176, 0.166642002586741, 0.12417270569130778, 0.13351367320865393, 0.13665392267284915, 0.16967946459772065, 0.1188940615975298, 0.08895620281691663, 0.12934206111822277, 0.20791641203686595, 0.25028419797308743, 0.11792173681897111, 0.26567064109258354, 0.15522550034802407, 0.17287031369050965, 0.1904718004516326, 0.16296259767841548, 0.1475394776207395, 0.11196186795132235, 0.13479150307830423, 0.17237230291357264, 0.13474145263899118, 0.12224210498970933, 0.16914311447180808, 0.13721578783588484, 0.18337024870561436, 0.09801177002373151], [0.07388463069219142, 0.027929046846111305, 0.01797834935132414, 0.05479880033817608, 0.0578782753291307, 0.04518234760325868, 0.020161018655926455, 0.05338605915312655, 0.055645924803684466, 0.034064730498357676, 0.023650955117773265, 0.005968648938505794, 0.03588054321880918, 0.0248089782326133, 0.09033831185661256, 0.06414996125386097, 0.03202032145054545, 0.055093525734264404, 0.04414078044646885, 0.11577308570849709, 0.07708023695158772, 0.041131427278742194, 0.015460023350897245, 0.028024132661812473, 0.05516084223927464, 0.027886621974175796, 0.05204409288126044, 0.06664428248768672, 0.07573007736937143, 0.027771017630584538, 0.04484831435547676, 0.0318480578425806, 0.03448316449066624, 0.02367465931456536, 0.025285654119215906, 0.037564338999800384, 0.07492103992262855, 0.024725002367631532, 0.012380915723042563, 0.048910151672316715, 0.03845215913315769, 0.04957280048984103, 0.05025602164096199, 0.09023980659549125, 0.03431081924645696, 0.016856012407515664, 0.05734351710998453, 0.019333960008225404, 0.0343663838430075, 0.006979918844081112, 0.06120053651102353, 0.03390275676792953, 0.015345843003160553, 0.02195031072915299, 0.017232960344699677, 0.033421388652641326, 0.059093720265082084, 0.02144630896509625, 0.04958127952704672, 0.017354947158310097, 0.06656156270764768, 0.030187459742592182, 0.06843703667982481, 0.06407812135876156, 0.0492628721985966, 0.023694459814578295, 0.027938640960201155, 0.055333862837869674, 0.0401396285451483, 0.023105378240870778, 0.10883584545808844, 0.14655291102826595, 0.30452607956249267, 0.030371211796591524, 0.28394202003255486, 0.07926696023787372, 0.2893344353651628, 3.584202560596168, 6.189862629398704, 6.686456557363272, 11.970195583999157, 15.350179765373468, 20.956922359764576, 27.71028857678175, 30.128298327326775, 29.15178682655096, 17.168806828558445, 19.832517094910145, 29.985262602567673, 35.1133344322443, 34.51861314475536, 28.075135499238968, 17.27070976048708, 20.01324489712715, 11.94234972819686, 5.58318005874753, 10.77031971886754, 2.2561073256656528, 1.0688634077087045, 0.4438388650305569, 0.6090338726062328, 0.3672162437578663, 0.12132809817558154, 0.048182943428400904, 0.013921620793553302, 0.043253479816485196, 0.04565177456242964, 0.13742315873969346, 0.15764349169330671, 0.12886733893537894, 0.0064385615405626595, 0.0839397446543444, 0.0180750307845301, 0.015559121402475284, 0.04832227423321456, 0.08727083739358932, 0.012486190298659494, 0.025883726812025998, 0.09562385792378336, 0.034583443484734744, 0.03913423737685662, 0.09393582076882012, 0.10165123254409991, 0.07036224196781404, 0.10050192780909128, 0.020212794588587712, 0.03835311952570919, 0.04046370217110962, 0.02330734445422422, 0.05942097399383783, 0.04705475650553126, 0.03032360487850383, 0.04389693298435304, 0.016385620656365063, 0.032013656964409165, 0.03301627250039019, 0.057903445267584175, 0.01939694422617322, 0.0849185929109808, 0.01689620712568285, 0.025658308732090518, 0.055618598926230334, 0.035322403637110256, 0.02676888820133172, 0.0759617387666367, 0.010416917448310414, 0.050069902135874145, 0.05004646140150726, 0.08710852969670668, 0.034590753639349714, 0.04491367901209742, 0.04908305352728348, 0.0343384531151969, 0.04451557615539059, 0.05066301171609666, 0.038886003821971826, 0.04701666948676575, 0.034051579641527496, 0.023194554705696646, 0.06639374827500433, 0.06183458666782826, 0.020167558832326904, 0.0390251305361744, 0.02388117674854584, 0.036988209758419544, 0.05164842426893301, 0.03095583862886997, 0.050737000128719956, 0.003491107895570167, 0.03958258734201081, 0.021265607138047926, 0.031199728764477186, 0.04060173792822752, 0.020793779331143014, 0.04826397853321396, 0.01826752533816034, 0.024497695521858986, 0.03602365897677373, 0.03713746307766996, 0.0433679226989625, 0.03407280135434121, 0.03253028822655324, 0.025156917472486384, 0.0597427358297864, 0.030839299179206137, 0.06539365233038552, 0.015416012138302904, 0.01216159345858614, 0.027877946267835796, 0.03709542041178793, 0.029025633120909333, 0.038061295927036554, 0.029446414155245293, 0.029177335527492687, 0.019095999632554594, 0.007348073722823756, 0.018909256723418366, 0.05183806897548493, 0.013189986566430889, 0.04495737666729838, 0.00860550473589683, 0.044052420344087295, 0.011151608396176016, 0.03693313497933559, 0.040534243307774886, 0.01934837993758265, 0.04273306731192861, 0.0053890816980128875, 0.014063833914406132, 0.006838683038949966, 0.017335681004624348, 0.039910579507704824, 0.03143366855510976, 0.04548604927549604, 0.0452291288820561, 0.051206850112066604, 0.04492811749514658, 0.0832018197979778, 0.07611256543896161, 0.09376647751196288, 0.043060064999735914, 0.05857089578057639, 0.09331485096481629, 0.014753275190741988, 0.12164601939730346, 0.01938868412253214, 0.03953913830628153, 0.06239250360522419, 0.09905017563141882, 0.035952650287072174, 0.05257735196209978, 0.11140823320602067, 0.05595183065452147, 0.026909126281680074, 0.026560973674349952, 0.061398708494380116, 0.06764456396922469, 0.05531782873731572, 0.08076171987340786, 0.09436759486561641, 0.04459890449652448, 0.027120488084619865, 0.01071318743925076, 0.06857393324025907, 0.11066765146097168, 0.028917865856783465, 0.2921647491166368, 0.23101788101485, 0.3779734071576968, 0.12264284247066826, 0.08095645200228319, 0.370698549086228, 0.9933438850566745, 9.199195224791765, 13.257633950561285, 13.015365600585938, 21.40604306012392, 29.808051511645317, 38.28413508832455, 47.088380455970764, 51.98465332388878, 47.020774483680725, 32.50922776758671, 35.19664116203785, 51.346021592617035, 57.693588584661484, 55.7864823192358, 47.88979545235634, 38.189721554517746, 41.099992990493774, 27.488025203347206, 16.13320279866457, 24.092806689441204, 8.770048152655363, 2.822077455930412, 0.31538073148112744, 0.3720336430706084, 0.32244149479083717, 0.27791198110207915, 0.05741523826145567, 0.04335033750976436, 0.018931563827209175, 0.015813578793313354, 0.05888200779736508, 0.16661294008372352, 0.05275638395687565, 0.0263029270718107, 0.04002337111160159, 0.06460130578489043, 0.022952382641960867, 0.03139216765703168, 0.04252789687598124, 0.04637631107470952, 0.0072691194145591, 0.08507857026415877, 0.03533901661285199, 0.05765150097431615, 0.017185576070914976, 0.009982523570215562, 0.03560326571459882, 0.062225453584687784, 0.027265381286269985, 0.08766168204601854, 0.031329289195127785, 0.004008606310890173, 0.017476728025940247, 0.027754764596465975, 0.04057549187564291, 0.07571332709630951, 0.059651626070262864, 0.10867483651963994, 0.05511009047040716, 0.016465713233628776, 0.05835834097524639, 0.0637010509672109, 0.04273176113201771, 0.09865681509836577, 0.07109449681593105, 0.0517952507652808, 0.048955893944366835, 0.021127768050064333, 0.041457270926912315, 0.04332082229666412, 0.024213373180828057, 0.06155963579658419, 0.01848979856731603, 0.03298120973340701, 0.03537260250595864, 0.052477904173429124, 0.039358228677883744, 0.020622961055778433, 0.056797218494466506, 0.03722993467818014, 0.011009115114575252, 0.0163170258019818, 0.017660520898061804, 0.029326985895750113, 0.04162682940659579, 0.02310540421603946, 0.015572954107483383, 0.054143565575941466, 0.053014109580544755, 0.030885097112332005, 0.03244599138270132, 0.02820728172082454, 0.015232416863000253, 0.020961189293302596, 0.08543992938939482, 0.0816300771839451, 0.016697363498678897, 0.07801687184837647, 0.04854463280935306, 0.21797920722747222, 0.09323565638624132, 0.0828648624883499, 0.16124802874401212, 0.11081900505814701, 0.22587540617678314, 0.1268260320648551, 0.1978924311697483, 0.13682086137123406, 0.14190400892402977, 0.06840959948021919, 0.06429889544961043, 0.09949055864126422, 0.16658727661706507, 0.12454035080736503, 0.13554000353906304, 0.1415961215388961, 0.2843192685395479, 0.1479529874632135, 0.287429490708746, 0.09766665651113726, 0.11557724035810679, 0.1530823708162643, 0.11876659773406573, 0.12455614370992407, 0.13709147810004652, 0.08375319841434248, 0.10229808103758842, 0.13867533998563886, 0.13157453038729727, 0.13807467534206808, 0.163034719589632, 0.1218056702055037, 0.19343595311511308, 0.1622624258743599, 0.1376295945374295, 0.117689021572005, 0.1660360093228519, 0.1405681876349263, 0.1085744090960361, 0.1340200554113835, 0.21669388166628778, 0.1840222699684091, 0.13713511638343334, 0.11931366447242908, 0.1507754492922686, 0.1512565984739922, 0.1223523732915055, 0.1691099553136155, 0.08946543486672454, 0.161901920218952, 0.09157110078376718, 0.13700699200853705, 0.13505759270628914, 0.08093268843367696, 0.18259543168824166, 0.17140084644779563, 0.1639414904639125, 0.18344290496315807, 0.19710100488737226, 0.2534050773829222, 0.10882495815167204, 0.28855013370048255, 0.1911157026188448, 0.07204613051726483, 0.1383701985469088, 0.07649738385225646, 0.18005888967309147, 0.24538965983083472, 0.13192112819524482, 0.4143349325750023, 0.33367351396009326, 0.7765107764862478, 0.24944512580987066, 0.4451850021723658, 0.35462870670016855, 0.6998424092307687, 8.286365456879139, 11.334389001131058, 11.427066028118134, 20.071412175893784, 27.514728270471096, 36.65305741131306, 46.674533262848854, 50.60892954468727, 47.34431952238083, 32.13880084455013, 36.1330971121788, 53.59902709722519, 60.97523309290409, 56.71828351914883, 47.94991962611675, 37.02755771577358, 39.47483919560909, 26.53464686125517, 14.09257359802723, 20.43424140661955, 7.41256101988256, 2.965482473373413, 0.5842974968254566, 0.7379850000143051, 0.7646459725219756, 0.4521771613508463, 0.1085262511332985, 0.15472213126486167, 0.09945987083483487, 0.1394549958058633, 0.27526497782673687, 0.25778098788578063, 0.2084140368970111, 0.17045499407686293, 0.19805033050943166, 0.1602373126661405, 0.12083865178283304, 0.20653149025747553, 0.14914115105057135, 0.09503393215709366, 0.13188332319259644, 0.1595022005494684, 0.1647211314411834, 0.09647806989960372, 0.18915808032033965, 0.15813740581506863, 0.19229824072681367, 0.21861108660232276, 0.10968592367134988, 0.17781888018362224, 0.08549417296308093, 0.12338438900769688, 0.15932178444927558, 0.11102622753242031, 0.15885617583990097, 0.15548876981483772, 0.12404168694047257, 0.19336730445502326, 0.12497861869633198, 0.121277713769814, 0.07681800649152137, 0.16275478148600087, 0.14569932245649397, 0.1911442753043957, 0.11415779386879876, 0.10415565440780483, 0.11298449549940415, 0.1292719430057332, 0.07709544355748221, 0.11910188521142118, 0.09443971677683294, 0.24379695154493675, 0.12687645357800648, 0.1290213197353296, 0.11481415669550188, 0.1251955039333552, 0.09011350790387951, 0.14418056176509708, 0.10411811657832004, 0.147475489648059, 0.1538286596769467, 0.16199443634832278, 0.13381534139625728, 0.15443033364135772, 0.10936236212728545, 0.101153377618175, 0.09633375928387977, 0.18025123950792477, 0.17142829106887802, 0.20113356818910688, 0.11992362822638825, 0.09152043436188251, 0.13256200239993632, 0.16761008970206603, 0.15158103575231507, 0.16201263380935416, 0.07629769417690113, 0.27831754996441305, 0.11690411876770668], [0.06218335896846838, 0.04930573864839971, 0.05432992627902422, 0.039415826759068295, 0.04306014292524196, 0.03840101773675997, 0.004158429692324717, 0.05430048156995326, 0.022086131175456103, 0.036323111853562295, 0.028782362678612117, 0.054354316962417215, 0.10441386984894052, 0.052653589082183316, 0.03748566021386068, 0.020684314404206816, 0.07047070685075596, 0.01837629264628049, 0.027624077956716064, 0.01939213696459774, 0.02896213496569544, 0.030021697348274756, 0.04854146754951216, 0.0164732107805321, 0.09608079824829474, 0.020693953047157265, 0.06405334104783833, 0.022543327540915925, 0.0438587865937734, 0.05800316022941843, 0.08287932694656774, 0.05076057444966864, 0.06945890723727643, 0.029445748077705503, 0.024004974402487278, 0.06797337249736302, 0.05864277649379801, 0.0017641277008806355, 0.05567147694819141, 0.011131216961075552, 0.017275247919315007, 0.042799096190719865, 0.08861416921718046, 0.036281154534663074, 0.09192670084303245, 0.04672922827012371, 0.06567868156707846, 0.04981551617674995, 0.026614376765792258, 0.08004486458958127, 0.04945722954289522, 0.06982051869272254, 0.05773370125098154, 0.046257830908871256, 0.05170394804736134, 0.029994879841979127, 0.01986624873097753, 0.1078669197158888, 0.07379800721537322, 0.07701179609284736, 0.005376771787268808, 0.054422208631876856, 0.05111489059345331, 0.02242816106445389, 0.01998772902879864, 0.022366015473380685, 0.12167579436209053, 0.1965888636186719, 0.1716173012391664, 0.7334899599663913, 2.3895989125594497, 8.270711246877909, 15.70325966924429, 14.191813822835684, 25.071632266044617, 42.77637183666229, 64.8585145175457, 96.75799280405045, 104.81659278273582, 103.344217389822, 112.25097745656967, 114.15881708264351, 120.07545679807663, 112.74902433156967, 125.47220081090927, 114.22699302434921, 118.19243744015694, 117.36090525984764, 118.9670030772686, 120.12344062328339, 121.85226425528526, 127.37662062048912, 124.74018529057503, 120.93010693788528, 107.23739728331566, 105.61576589941978, 111.5836800634861, 85.88419988751411, 58.80810298025608, 36.37553170323372, 21.28486566245556, 10.734604485332966, 2.377391355112195, 0.5286916962359101, 0.36561379849445075, 0.2579815755598247, 0.13872252573492005, 0.08365414396394044, 0.06640989740844816, 0.011144244435854489, 0.00495681592838082, 0.03220581384084653, 0.017407528321200516, 0.06544558782479726, 0.039935998065629974, 0.11440418689744547, 0.04964717852999456, 0.030915081733837724, 0.032489922814420424, 0.030098201641521882, 0.034333228395553306, 0.024847614440659527, 0.012758227312588133, 0.0240011189453071, 0.0064786198890942615, 0.019553197853383608, 0.032626129177515395, 0.032099059608299285, 0.007212915179479751, 0.011374406694812933, 0.05051024061685894, 0.06895999104017392, 0.020216917218931485, 0.01652109971473692, 0.03212081937817857, 0.06747895371518098, 0.033355894120177254, 0.02677375483472133, 0.0486728128453251, 0.07048703409964219, 0.06504065720946528, 0.034305019362363964, 0.07424443130730651, 0.02738127877819352, 0.045487934330594726, 0.015583770909870509, 0.055745569261489436, 0.002935677152891003, 0.04661083345126826, 0.05036072754592169, 0.009492801655142102, 0.03407162133953534, 0.026637516930350102, 0.03004436810442712, 0.06016524050210137, 0.03363039970281534, 0.036220380061422475, 0.005439466103780433, 0.010855903365154518, 0.03856702503981069, 0.02547189978940878, 0.042109793139388785, 0.029815005509590264, 0.018984927955898456, 0.04581781155138742, 0.013951292785350233, 0.03798669895331841, 0.033684134905342944, 0.029787260318698827, 0.09891641835565679, 0.056801025712047704, 0.05214736273046583, 0.03593595196434762, 0.02172199270717101, 0.040672293907846324, 0.030899737830623053, 0.056716072067501955, 0.029468389147950802, 0.0804663822054863, 0.04467797290999442, 0.03638071364548523, 0.04572546611598227, 0.029744451385340653, 0.02717371677135816, 0.05874700000276789, 0.01042436118950718, 0.01893793887575157, 0.030544419787474908, 0.03384208248462528, 0.005269156663416652, 0.06881268956931308, 0.05266118867439218, 0.06382039573509246, 0.059622604385367595, 0.028460098037612624, 0.08697564815520309, 0.03944726413465105, 0.012758698576362804, 0.02699824151932262, 0.015631917740392964, 0.047225394810084254, 0.007846529788366752, 0.022484584696940146, 0.01572501645568991, 0.08005080177099444, 0.05258514822344296, 0.10526101657887921, 0.09751690595294349, 0.027380250903661363, 0.05076178415038157, 0.041276012489106506, 0.02864143254555529, 0.03999880973424297, 0.08362793872947805, 0.007987946028151782, 0.05062406380602624, 0.1251713841338642, 0.04685358624556102, 0.046370934214792214, 0.06458514922996983, 0.08333149526151828, 0.03336111883982085, 0.04426793260790873, 0.04143864302022848, 0.010360311989643378, 0.0681700416316744, 0.037179694991209544, 0.10265097225783393, 0.024594846363470424, 0.044761828175978735, 0.048657628503860906, 0.021004295085731428, 0.004362139488875982, 0.028068188403267413, 0.036723593293572776, 0.049165613745572045, 0.07491489493986592, 0.0595274573424831, 0.12776964314980432, 0.11899611432454549, 0.029861688453820534, 0.05577973402978387, 0.07819604856194928, 0.11140370610519312, 0.4384966485667974, 2.5278582936152816, 6.0245406255126, 16.747284047305584, 28.221064768731594, 24.73227247595787, 40.39011888206005, 68.60546305775642, 91.72939583659172, 122.8022512793541, 127.12019518017769, 128.19160848855972, 134.4982060790062, 135.59534400701523, 138.70929211378098, 129.78779643774033, 144.23133820295334, 133.21814596652985, 138.75121146440506, 138.84374409914017, 138.24889361858368, 139.44063127040863, 139.93182331323624, 144.94533509016037, 145.80282747745514, 141.28540188074112, 132.40014106035233, 129.9375084042549, 137.15859532356262, 117.76935294270515, 91.13699242472649, 64.18273597955704, 40.15051133930683, 22.109111733734608, 6.604162473231554, 0.7365494489204139, 0.3469591151224449, 0.08670148396049626, 0.16136228980030864, 0.06436845695134252, 0.07302077821805142, 0.04453612622455694, 0.04807094592251815, 0.051728182879742235, 0.061218355476739816, 0.05456769926240668, 0.02785137181490427, 0.028718771754938643, 0.059001571498811245, 0.008024348371691303, 0.056166188878705725, 0.046670646843267605, 0.02917481408076128, 0.051741207571467385, 0.0817926149466075, 0.025920299849531148, 0.037981092027621344, 0.01066580965925823, 0.028647625767916907, 0.014256926824600669, 0.043555968077271245, 0.039493837612099014, 0.03316328824439552, 0.041384343785466626, 0.019520430178090464, 0.05133224338351283, 0.025331554097647313, 0.013311190414242446, 0.018908462625404354, 0.027538448957784567, 0.04438368167029694, 0.033102487795986235, 0.10679481318220496, 0.02168663493648637, 0.00958563690801384, 0.015964409176376648, 0.03798683996137697, 0.05223465042945463, 0.030730350044905208, 0.030801149077888113, 0.054162842861842364, 0.024328851359314285, 0.04070765724463854, 0.09792053038836457, 0.048653175617801026, 0.029706110180995893, 0.031369213029392995, 0.03280865668784827, 0.06169805747049395, 0.034126492028008215, 0.06332131626550108, 0.04963817627867684, 0.006807948384448537, 0.01953611175849801, 0.012431311261025257, 0.03567112027667463, 0.016948632437561173, 0.016379390326619614, 0.02332804480829509, 0.07277601791429333, 0.025252376217395067, 0.025036333317984827, 0.029102384178258944, 0.07026289807981811, 0.0476216348761227, 0.043601858778856695, 0.04054620301758405, 0.044532716055982746, 0.17010605108225718, 0.196969511162024, 0.21864222711883485, 0.09591018591891043, 0.08843570496537723, 0.08247911639045924, 0.2851440024096519, 0.17936291842488572, 0.08887544230674393, 0.12425579654518515, 0.19279151660157368, 0.1340255918330513, 0.15308346919482574, 0.15829880809178576, 0.11714124979334883, 0.1480254062335007, 0.18345474964007735, 0.19782210525590926, 0.08357572121894918, 0.14361945359269157, 0.11258542042924091, 0.14879410795401782, 0.28597256576176733, 0.13113838504068553, 0.16309355705743656, 0.054390385339502245, 0.13433235115371644, 0.1422564103268087, 0.13488479104125872, 0.2778119395952672, 0.2855242195073515, 0.24302217905642465, 0.14564605109626427, 0.12582141644088551, 0.13023836771026254, 0.09947400132659823, 0.12225790531374514, 0.13608368608402088, 0.18576014233985916, 0.129105108208023, 0.24416308267973363, 0.1948570174863562, 0.1827176337246783, 0.11727837641956285, 0.2784651186084375, 0.14411632146220654, 0.12058257372700609, 0.1074306333612185, 0.0819477163895499, 0.19086870102910325, 0.11703700030921027, 0.2733593503944576, 0.16467252076836303, 0.10385069108451717, 0.20266663748770952, 0.09641762197134085, 0.11944986341404729, 0.30426232027821243, 0.1465304833254777, 0.15795286337379366, 0.28038912161719054, 0.16871158528374508, 0.1846284858766012, 0.14867860008962452, 0.18097441788995638, 0.2335502373171039, 0.2875371021218598, 0.44322982896119356, 0.3345747187267989, 2.1374282939359546, 5.798823237419128, 15.677896030247211, 26.250640600919724, 24.110557436943054, 41.68755546212196, 72.05895334482193, 95.14310985803604, 133.12167674303055, 139.43319886922836, 138.53734374046326, 145.93402683734894, 151.64881378412247, 157.6564434170723, 147.9194810986519, 162.84766405820847, 151.34042233228683, 156.51120007038116, 156.37528896331787, 155.99202632904053, 156.06019467115402, 157.8768315911293, 162.94431567192078, 163.89724373817444, 161.85552209615707, 152.52931773662567, 149.40289109945297, 154.21926945447922, 129.29921865463257, 102.37559616565704, 67.54062339663506, 39.234787076711655, 21.093684621155262, 5.354261342436075, 0.6116902269423008, 0.3411252109799534, 0.4073702625464648, 0.3032369096763432, 0.14754810137674212, 0.26685300108511, 0.14348506549140438, 0.18668490287382156, 0.11273827316472307, 0.21259963104967028, 0.10613626101985574, 0.120412399264751, 0.17122794088209048, 0.10763827143819071, 0.10266882833093405, 0.21299794170772657, 0.17900484701385722, 0.182510856539011, 0.10475737290107645, 0.14648589509306476, 0.08741600890061818, 0.1030956077738665, 0.11332182388287038, 0.14789063221542165, 0.24691806844202802, 0.11852968935272656, 0.09100447103264742, 0.2093928851536475, 0.12197478339658119, 0.10547992045758292, 0.08416332406341098, 0.08985869892057963, 0.15753452957142144, 0.16454044816782698, 0.21140815748367459, 0.13181348709622398, 0.16306206031003967, 0.1944295404246077, 0.1548211189219728, 0.11601262129261158, 0.07545064392616041, 0.1075034454697743, 0.10426967797684483, 0.12940741464262828, 0.12998220801819116, 0.13806919829221442, 0.1461120307794772, 0.14236283430363983, 0.14287032972788438, 0.15653797367122024, 0.0862698137643747, 0.18269765510922298, 0.14506923907902092, 0.17235653969692066, 0.1269023396889679, 0.16852831933647394, 0.1943007332738489, 0.1166651769017335, 0.11841467130579986, 0.07521852981881239, 0.09706752811325714, 0.15881722792983055, 0.10564340816927142, 0.11855987992021255, 0.15208143624477088, 0.21362213243264705, 0.12288238547625951, 0.11455656465841457, 0.18236940319184214, 0.10373387704021297, 0.12595596781466156, 0.20602895237971097, 0.12874672509497032], [0.007671084222238278, 0.009365892547066323, 0.029873039602534845, 0.01166888810985256, 0.015602834828314371, 0.03538909302733373, 0.03046887843083823, 0.04671138332923874, 0.030979036309872754, 0.04953967101755552, 0.06522121431771666, 0.02377811098995153, 0.019226098120270763, 0.02930660095444182, 0.024001849960768595, 0.03752572134544607, 0.08434284216491506, 0.029254311084514484, 0.019794549843936693, 0.04259918387106154, 0.02889447336201556, 0.04176725858997088, 0.01729301493469393, 0.034507187810959294, 0.04953757445036899, 0.040398575001745485, 0.04278272441297304, 0.008045185095397756, 0.05969258891127538, 0.024046109792834613, 0.06257202912820503, 0.03452714787272271, 0.06057902493921574, 0.01509368812548928, 0.014387494720722316, 0.052879487702739425, 0.038157188828336075, 0.06717043550452217, 0.048691448173485696, 0.015455050033779116, 0.01688300060777692, 0.04784838696650695, 0.00998210796751664, 0.04789933911524713, 0.03383114693860989, 0.03156147009576671, 0.009806140114960726, 0.04161674361967016, 0.03254105678934138, 0.06316702376352623, 0.027540259798115585, 0.03017612900293898, 0.02220689901150763, 0.02506371856725309, 0.06253906292840838, 0.04126182262552902, 0.044592295671463944, 0.03516976983519271, 0.023411219153786078, 0.01121988227168913, 0.01866108625108609, 0.05052523942140397, 0.32809226657263935, 0.1650689315283671, 0.15104530903045088, 2.0856729336082935, 5.434683077037334, 16.539805680513382, 45.88998556137085, 71.82861730456352, 81.26804038882256, 107.54942893981934, 102.25839525461197, 109.43568572402, 99.895438849926, 100.04824385046959, 102.86963045597076, 86.72478318214417, 97.88715541362762, 94.46926921606064, 89.98093485832214, 89.23767194151878, 88.55323746800423, 96.36108130216599, 80.21485850214958, 95.65966933965683, 93.76493141055107, 90.57581573724747, 91.4858441054821, 88.78604337573051, 89.8587030172348, 92.43092179298401, 99.5034670829773, 92.3582012951374, 101.65620356798172, 96.86532944440842, 94.96499061584473, 100.97306102514267, 117.80080765485764, 122.32732996344566, 119.72632393240929, 112.0070381462574, 89.14763957262039, 57.092973813414574, 43.06754641234875, 20.241016075015068, 4.898119568824768, 0.39932288811542094, 0.20309384737629443, 0.41959304886404425, 0.07511255113058724, 0.116511604283005, 0.07687123332289048, 0.028160504152765498, 0.039648415840929374, 0.08380349376238883, 0.07551856528152712, 0.022914406945346855, 0.08667115238495171, 0.04022775116027333, 0.023073245101841167, 0.09619941571145318, 0.048135676042875275, 0.031378519561258145, 0.06599730040761642, 0.04546605581708718, 0.03694376253406517, 0.019007450282515492, 0.04776207519171294, 0.02369670481130015, 0.03781701059779152, 0.04803335614269599, 0.08493270855979063, 0.022535021053045057, 0.018720775333349593, 0.044410016780602746, 0.109965512965573, 0.06506947480374947, 0.01511389216830139, 0.08317749219713733, 0.08479596785036847, 0.029982584310346283, 0.05340386698662769, 0.05919290088058915, 0.03478612030448858, 0.0765118705749046, 0.009434785188204842, 0.053104195176274516, 0.06819103698944673, 0.0460330492205685, 0.02828401051374385, 0.09563601430272684, 0.0393605404678965, 0.032061213787528686, 0.0237224777447409, 0.008205546509998385, 0.03722968234797008, 0.015499273686145898, 0.05184033994737547, 0.04599989377311431, 0.05929617444053292, 0.021126877472852357, 0.026259427941113245, 0.05486805384862237, 0.07003820544923656, 0.0594817781529855, 0.007740865121377283, 0.01482299903727835, 0.06549171972437762, 0.02711006090976298, 0.007309354950848501, 0.0513124874123605, 0.08582995767937973, 0.03027219445357332, 0.011773120895668399, 0.054508483299287036, 0.002960465812975599, 0.03125421724689659, 0.04043291788548231, 0.08470588596537709, 0.03006946197274374, 0.0633231716346927, 0.022475415462395176, 0.021808387973578647, 0.06040433079760987, 0.05684356561687309, 0.06772570297471248, 0.007205334140962805, 0.04359406993899029, 0.03705080620420631, 0.05270966204989236, 0.015485149688174715, 0.04467897109861951, 0.003649722016234591, 0.018544821396062616, 0.023269203629752155, 0.02965869993204251, 0.04838082968490198, 0.028444752279028762, 0.021127584368514363, 0.06776833935873583, 0.026531391667958815, 0.09612527515855618, 0.015008765094535192, 0.056351362145505846, 0.028751643330906518, 0.030529472933267243, 0.015508472606597934, 0.03970447396568488, 0.03630502200394403, 0.1028886079438962, 0.04570334640447982, 0.048121159634320065, 0.06745424761902541, 0.03551305766450241, 0.06586979201529175, 0.055288751391344704, 0.04419827462697867, 0.07825409193173982, 0.05338509436114691, 0.08197769173420966, 0.06036764272721484, 0.049647501364233904, 0.04079032507434022, 0.04777524089149665, 0.05697625791071914, 0.028596339652722236, 0.0158304552314803, 0.05208502974710427, 0.03681757145386655, 0.11607076856307685, 0.016835774040373508, 0.019256993728049565, 0.016743757005315274, 0.02189770915720146, 0.05642818556225393, 0.04978470220521558, 0.04287299554562196, 0.3678780613699928, 0.1360264516551979, 0.6796700041741133, 4.854362066835165, 11.645959932357073, 27.243063747882843, 62.767992094159126, 94.88452613353729, 104.14090543985367, 126.67886406183243, 121.45001783967018, 137.08813190460205, 121.05176120996475, 118.0018624663353, 113.2257467508316, 99.19037148356438, 110.98961994051933, 107.28377759456635, 111.03704139590263, 105.08781462907791, 102.12660312652588, 117.26705029606819, 98.41817691922188, 119.15861919522285, 106.39806792140007, 105.14719024300575, 111.0854583978653, 108.91435369849205, 105.31308934092522, 107.42387607693672, 109.03155460953712, 104.22364979982376, 112.8194497525692, 107.65675038099289, 108.17623570561409, 113.80899265408516, 132.32815772294998, 134.83219295740128, 142.7025282382965, 135.60934245586395, 116.3519985973835, 86.46320521831512, 68.70031356811523, 37.25531369447708, 11.848604008555412, 1.517340992577374, 0.0780565915920306, 0.3277641482418403, 0.15996507805539295, 0.34859014791436493, 0.07219871607958339, 0.026650719737517647, 0.04546184041828383, 0.0659722751879599, 0.06877430569147691, 0.013335191470105201, 0.048531452266615815, 0.036874201032333076, 0.08541625487850979, 0.0032199939278143574, 0.029279900336405262, 0.019806914024229627, 0.060152163860038854, 0.06820763883297332, 0.0443578846170567, 0.021216684763203375, 0.043591268331510946, 0.03404962037166115, 0.08488088438753039, 0.0290773181404802, 0.030028376677364577, 0.03496304831060115, 0.02788977239106316, 0.058662302399170585, 0.040140174023690633, 0.05195011843170505, 0.026476123930478934, 0.033961137814912945, 0.04864555747190025, 0.06260711787035689, 0.023532063059974462, 0.03986094467109069, 0.016146949674293865, 0.01743652032018872, 0.003770883886318188, 0.025690779548313003, 0.04250059697369579, 0.05828119843499735, 0.012403214477672009, 0.13030544301727787, 0.028840443155786488, 0.0316243930865312, 0.03406590309168678, 0.009206257509504212, 0.011091170672443695, 0.02708470172365196, 0.0538391774171032, 0.023549603720312007, 0.014691790111101, 0.031951320270309225, 0.03808480716543272, 0.029067865034448914, 0.04958161349350121, 0.055384551524184644, 0.042013603379018605, 0.00893036596607999, 0.015674192327423953, 0.03489232905849349, 0.03159816187690012, 0.06266477532335557, 0.016549906176805962, 0.05966473610897083, 0.020311407461122144, 0.06310171476798132, 0.11415180473704822, 0.10978450314723887, 0.09409620630322024, 0.18963265407364815, 0.1562523061875254, 0.1770137983839959, 0.09930355226970278, 0.0992062567092944, 0.16896462795557454, 0.1796836152789183, 0.2635068946983665, 0.12706108507700264, 0.155384112149477, 0.12690550123807043, 0.10897861240664497, 0.13929353415733203, 0.13967287552077323, 0.1534467950114049, 0.17465652956161648, 0.2606985188322142, 0.09737317421240732, 0.14188389672199264, 0.1798013792722486, 0.08271885977592319, 0.19678381097037345, 0.22107246390078217, 0.19609830400440842, 0.06320201602648012, 0.1559027991606854, 0.1250232514576055, 0.1413139866781421, 0.08351050128112547, 0.15106684615602717, 0.15090905071701854, 0.10175253570196219, 0.1749387980089523, 0.14782591693801805, 0.13297898549353704, 0.1350964218727313, 0.14120935869868845, 0.09985878263250925, 0.16770604939665645, 0.13179454748751596, 0.11602888916968368, 0.13364501850446686, 0.1812812068965286, 0.13297530444106087, 0.07605907143442892, 0.17100489581935108, 0.1657785286079161, 0.08250112106907181, 0.155315374431666, 0.12490643741330132, 0.1524511890602298, 0.22913010965567082, 0.14266652113292366, 0.11397940383176319, 0.16545173129998147, 0.09800933577935211, 0.2435465806047432, 0.3078007319709286, 0.14822621655184776, 0.701773299369961, 0.3256546676857397, 0.49765421950723976, 4.628741098567843, 10.80695640295744, 25.256494246423244, 66.23979359865189, 99.20014455914497, 113.52320998907089, 139.22481805086136, 137.92723327875137, 146.78229331970215, 134.81504827737808, 132.97862201929092, 132.32935845851898, 110.91525793075562, 120.67628815770149, 119.11977767944336, 117.12062135338783, 114.14375469088554, 111.26088738441467, 122.28687733411789, 108.12145784497261, 123.87461453676224, 118.19520369172096, 116.73475205898285, 120.41695967316628, 117.16631770133972, 117.16043561697006, 120.70483982563019, 122.75673732161522, 119.95644718408585, 128.05311352014542, 124.0274803340435, 122.63163283467293, 130.6759911775589, 148.6123663187027, 155.80629229545593, 158.7231981754303, 152.2451689839363, 129.15172576904297, 93.88334065675735, 70.45246034860611, 35.470101088285446, 9.456670358777046, 0.8747472614049911, 0.3118420229293406, 0.7100619608536363, 0.16392835445003584, 0.3932524169795215, 0.210472502221819, 0.10642011766321957, 0.10562334791757166, 0.14626632328145206, 0.248792466300074, 0.20678340486483648, 0.2003350024460815, 0.13169296231353655, 0.17604701744858176, 0.19746597827179357, 0.24098167370539159, 0.18407353752991185, 0.17183960415422916, 0.1257140128291212, 0.09571214381139725, 0.14392947836313397, 0.13021724618738517, 0.13641558936797082, 0.1372616970911622, 0.1955906007788144, 0.18749798502540216, 0.22177699953317642, 0.1371551543707028, 0.14050758385565132, 0.13671851920662448, 0.15432561660418287, 0.06520125054521486, 0.20840884186327457, 0.15006608969997615, 0.132968150137458, 0.19730791565962136, 0.1343735255068168, 0.102695397217758, 0.12935237697092816, 0.09455492778215557, 0.1240307254192885, 0.11995197826763615, 0.08629071264294907, 0.13228777883341536, 0.17384266073349863, 0.11181116744410247, 0.10957690959912725, 0.09101843083044514, 0.09897208685288206, 0.09089168685022742, 0.11278357385890558, 0.18136990838684142, 0.12131722571211867, 0.20659712579799816, 0.09033478665514849, 0.18002997559960932, 0.16171955969184637, 0.18755612487439066, 0.2072736676200293, 0.10080071646370925, 0.06720736477291211, 0.16382764501031488, 0.11243928413023241, 0.11545226268935949, 0.13489800126990303, 0.12480553501518443, 0.14504189835861325, 0.08125367472530343, 0.16833372821565717], [0.0756168775842525, 0.02727867686189711, 0.03671589722216595, 0.04910460178507492, 0.048748712288215756, 0.06403565566870384, 0.01989094369491795, 0.09399732254678383, 0.027841853770951275, 0.0519710878143087, 0.03234131887438707, 0.014788294356549159, 0.09664039986091666, 0.06136448806500994, 0.03860959463054314, 0.04641255385649856, 0.020312394517532084, 0.046891313322703354, 0.039629583843634464, 0.005428115418908419, 0.017554022706463, 0.06913332705153152, 0.08144053266732953, 0.06907932838657871, 0.08400169914239086, 0.05852739108377136, 0.02825988885888364, 0.016876287882041652, 0.09051010420080274, 0.05600797783699818, 0.048619437584420666, 0.028837031131843105, 0.07423224524245597, 0.03382549919479061, 0.012258433525857981, 0.047636652234359644, 0.03330527222715318, 0.05518384510651231, 0.058046386620844714, 0.03245021049224306, 0.025826932105701417, 0.027912521072721574, 0.08798013761406764, 0.027300826259306632, 0.015619223304383922, 0.023587228752148803, 0.028761656758433674, 0.09438617824343964, 0.032048096327343956, 0.02925816283095628, 0.05808686706586741, 0.010654842571966583, 0.00927152290387312, 0.03382679795322474, 0.038902078740647994, 0.018796537478920072, 0.04566322961181868, 0.04010201279015746, 0.035675031394930556, 0.10369145587901585, 0.06686322347377427, 0.917632591444999, 6.764781279489398, 22.886572815477848, 46.14646799862385, 69.6443273127079, 83.74306797981262, 90.23474603891373, 93.062394708395, 93.01663756370544, 87.04035624861717, 87.39623755216599, 78.47455188632011, 48.68141457438469, 80.63770741224289, 67.58717089891434, 76.14523887634277, 72.52324283123016, 90.21160528063774, 83.02938267588615, 74.5904991030693, 86.39979422092438, 76.17949023842812, 69.99953225255013, 82.06348970532417, 60.73860079050064, 81.02447345852852, 70.07419064640999, 69.64606761932373, 79.97092679142952, 79.91510018706322, 82.70967543125153, 77.17341050505638, 74.93946477770805, 87.04377606511116, 91.75237700343132, 87.49275997281075, 89.05240148305893, 79.23822730779648, 93.69346484541893, 86.7302168905735, 99.39907908439636, 97.70861059427261, 107.91167110204697, 109.9850906431675, 120.68694278597832, 101.78724333643913, 66.16386607289314, 34.28966023027897, 14.169278182089329, 4.615049008280039, 1.484867816325277, 0.41708723176270723, 0.17770166537957266, 0.011648235067696078, 0.04631740310287569, 0.09926011436618865, 0.041313913970952854, 0.022340966133924667, 0.015537593553744955, 0.03667765064164996, 0.061970395981916226, 0.19046749599510804, 0.05246523200185038, 0.03570158172806259, 0.09261861996492371, 0.038942715036682785, 0.06235846129129641, 0.03493685791909229, 0.04175815614871681, 0.019071968890784774, 0.04822007307666354, 0.03268544533057138, 0.021515799962799065, 0.09901841913233511, 0.05228843387158122, 0.08430073270574212, 0.05985543837596197, 0.057258633969468065, 0.0439430426195031, 0.04989771645341534, 0.04862784982833546, 0.0156801128105144, 0.026091056897712406, 0.013210675788286608, 0.027508612765814178, 0.03729838666913565, 0.02300434967764886, 0.04768147424329072, 0.10513859931961633, 0.05102349881781265, 0.11858440047944896, 0.04321481021179352, 0.04086147848283872, 0.09462772504775785, 0.09247544483514503, 0.02999389464093838, 0.009561759234202327, 0.023625043031643145, 0.04860592678596731, 0.04479276089114137, 0.08607776078861207, 0.04798671587195713, 0.05145271621586289, 0.017541474844620097, 0.03980519453762099, 0.009421254908374976, 0.06757580398698337, 0.05963257513940334, 0.03271106426836923, 0.06002747562888544, 0.045097653710399754, 0.02443221768771764, 0.08396049510338344, 0.02045499819359975, 0.07991694801603444, 0.0470434164890321, 0.0509739344852278, 0.11705723867635243, 0.01923701882333262, 0.01742967957397923, 0.045695253284065984, 0.03882953380525578, 0.07899937147158198, 0.08343011926626787, 0.05988319098833017, 0.02024772376898909, 0.019187975849490613, 0.0052443322874751175, 0.0769061068422161, 0.025786596379475668, 0.08025376431760378, 0.05249138157523703, 0.00786729879109771, 0.06332067801849917, 0.01790556878404459, 0.04136845069297124, 0.02929529804532649, 0.021162567354622297, 0.017091963418351952, 0.07932991662528366, 0.018549487649579532, 0.03620843148382846, 0.02144620691979071, 0.09938575254636817, 0.004650567298085662, 0.014047066943021491, 0.04014050427940674, 0.017485999305790756, 0.018638293040567078, 0.0031465983056477853, 0.06044643283530604, 0.08638187806354836, 0.04150556989770848, 0.07629805782926269, 0.05577009353146423, 0.06864296039566398, 0.057664451451273635, 0.0481693992333021, 0.028269729737075977, 0.03331614097987767, 0.03675791020214092, 0.03897706534189638, 0.05876819202967454, 0.04907639275188558, 0.06243607509532012, 0.07805504792486317, 0.027400999497331213, 0.021217788707872387, 0.05299282478517853, 0.05122175243741367, 0.019686097948579118, 0.026425526157254353, 0.0921803001256194, 0.12110123847378418, 0.11268270856817253, 0.05426920746685937, 2.927251299843192, 13.990839757025242, 36.99188522994518, 66.54718950390816, 94.25020337104797, 106.56788840889931, 114.3511551618576, 108.76228585839272, 107.40763574838638, 99.25868421792984, 105.85589781403542, 94.48719665408134, 69.62600469589233, 97.97015056014061, 94.76081997156143, 105.37382528185844, 100.90724855661392, 125.13062953948975, 105.64874053001404, 111.10036119818687, 118.7108664214611, 107.61740729212761, 101.4815117418766, 109.36074614524841, 81.78429588675499, 112.64250084757805, 96.01172044873238, 105.03391832113266, 113.7917111814022, 117.50859573483467, 109.4265054166317, 102.28048726916313, 98.67329522967339, 112.87152975797653, 118.47226962447166, 116.70901983976364, 108.11437502503395, 99.49484154582024, 104.91151928901672, 101.82836472988129, 110.31105995178223, 107.7044378221035, 118.58175694942474, 124.73813340067863, 137.35920935869217, 131.25848472118378, 96.00592955946922, 57.88519710302353, 27.558536119759083, 11.90079990774393, 4.691304741427302, 0.9536133951041847, 0.11175774765433744, 0.16782256658189, 0.046490178792737424, 0.1068330486305058, 0.023206603473227005, 0.10864944022614509, 0.055159870025818236, 0.05393482540966943, 0.029567367528215982, 0.09356169670354575, 0.0963116210186854, 0.02502441257092869, 0.05915494744840544, 0.026081761498062406, 0.06309769974905066, 0.05324311408912763, 0.04307764276745729, 0.015142861902859295, 0.020592590517480858, 0.03719463071320206, 0.050894480154966004, 0.030304123501991853, 0.010292301576555474, 0.07866832165746018, 0.026740104003692977, 0.026707347460614983, 0.0896628164628055, 0.03335162306029815, 0.07311177294468507, 0.030430210681515746, 0.04879194610111881, 0.005674042286045733, 0.05102182156406343, 0.009217918504873523, 0.016334649953932967, 0.023530387661594432, 0.04268404845788609, 0.012637215495487908, 0.0480509487533709, 0.053208240569802, 0.005649471167998854, 0.10090455776662566, 0.004538331377261784, 0.04775204877660144, 0.041813787538558245, 0.016221865771512967, 0.026893025387835223, 0.00677180625643814, 0.07317584997508675, 0.014018873680470278, 0.06240673057618551, 0.004503321024458273, 0.08430033194599673, 0.04568077398289461, 0.003999721875516116, 0.04083307649125345, 0.08968435358838178, 0.041123679256998, 0.03693233345984481, 0.02725475002080202, 0.046018618158996105, 0.01827393934945576, 0.061192706853034906, 0.1551322717568837, 0.14089361939113587, 0.24327038292540237, 0.1663441935670562, 0.10325816037948243, 0.23803297255653888, 0.08344885107362643, 0.18804494786309078, 0.08037517225602642, 0.2087926064268686, 0.10915787075646222, 0.16994733538012952, 0.17105877574067563, 0.09809368828427978, 0.22444309084676206, 0.2031541839824058, 0.18717608589213341, 0.12471077759983018, 0.10014957835664973, 0.08917633123928681, 0.14009313890710473, 0.15750093996757641, 0.17876013123895973, 0.1355588244041428, 0.24478791165165603, 0.18341293703997508, 0.09352907931315713, 0.10601425936329179, 0.15943272068398073, 0.13900613004807383, 0.09067458639037795, 0.18742169224424288, 0.15799296903423965, 0.1407424290664494, 0.12805139209376648, 0.14334957901155576, 0.1518095875508152, 0.15545895032119006, 0.19623073283582926, 0.18292588036274537, 0.13533401302993298, 0.13051686604740098, 0.23837587446905673, 0.12328955737757497, 0.0892326825123746, 0.19934626878239214, 0.13090181804727763, 0.16299540060572326, 0.18762628751574084, 0.145849637046922, 0.18190412112744525, 0.13163810275727883, 0.07810953640728258, 0.15612199989845976, 0.10346049952204339, 0.11691650521242991, 0.16759066027589142, 0.22329424624331295, 0.17237938300240785, 0.26175735576543957, 0.12709428876405582, 2.2449558740481734, 12.543296981602907, 36.287479028105736, 69.49809595942497, 100.43694019317627, 120.8778141438961, 127.04181298613548, 121.51899933815002, 118.8749036192894, 112.20851853489876, 110.81336259841919, 98.742595911026, 72.01720878481865, 104.1598892211914, 91.512001901865, 102.44140103459358, 100.75113773345947, 117.8317303955555, 108.39932933449745, 101.11773446202278, 113.61872926354408, 103.7721960246563, 93.71718317270279, 108.49091202020645, 89.85454604029655, 115.33466398715973, 101.76490813493729, 98.53559821844101, 108.36744904518127, 111.09392434358597, 115.27056142687798, 106.27028837800026, 105.20249247550964, 121.67884916067123, 122.85325214266777, 118.83017241954803, 117.04971715807915, 109.9447064101696, 119.78187695145607, 111.8657161295414, 121.89330205321312, 124.48241472244263, 137.26091623306274, 142.6648646593094, 155.70424497127533, 143.63922357559204, 100.77402010560036, 57.176094353199005, 24.55022234469652, 10.797636453062296, 4.989625308662653, 0.6245074141770601, 0.31372090335935354, 0.21349852031562477, 0.2026824897620827, 0.2562693814979866, 0.2034963882761076, 0.2434106933651492, 0.25762059492990375, 0.24932234489824623, 0.13130668929079548, 0.265447314013727, 0.1818196350359358, 0.10477040501427837, 0.20904655451886356, 0.10021965194027871, 0.15128005034057423, 0.13998816953971982, 0.1273801492061466, 0.17605126253329217, 0.10197339142905548, 0.11770112600061111, 0.14967205381253734, 0.20333908265456557, 0.15924933599308133, 0.23542318056570366, 0.11819034232757986, 0.1605395448859781, 0.2405381662538275, 0.1468390238005668, 0.19394741160795093, 0.10411745606688783, 0.14164556341711432, 0.08298531305626966, 0.08565991680370644, 0.11835790443001315, 0.1332899008411914, 0.13811248034471646, 0.18807314947480336, 0.14189934823662043, 0.1592388717108406, 0.21104622690472752, 0.124303724442143, 0.1867178245447576, 0.21054787473985925, 0.13370455359108746, 0.16063146729720756, 0.1293674870976247, 0.11629409564193338, 0.1271194772562012, 0.16814528207760304, 0.1224402361549437, 0.13225551025243476, 0.10318068016204052, 0.13761506328592077, 0.17027603258611634, 0.10597509623039514, 0.1755877913092263, 0.13906388398027048, 0.19993571215309203, 0.12070941418642178, 0.10182109530433081, 0.21474222623510286, 0.23453563131624833, 0.20692738151410595], [0.01741003492497839, 0.08328191979671828, 0.02529190114728408, 0.07391050938167609, 0.03354001724801492, 0.021011911376263015, 0.038115109055070207, 0.030661434211651795, 0.006115843725638115, 0.046254628541646525, 0.07174477403168567, 0.026237851852783933, 0.058448018389754, 0.03500290164083708, 0.07785151392454281, 0.035242611629655585, 0.027205937112739775, 0.027165831452293787, 0.05225043962127529, 0.04932737967465073, 0.033509704226162285, 0.026481944223633036, 0.012249112151039299, 0.005870386730748578, 0.03416628598643001, 0.03755892132176086, 0.04201236028166022, 0.05408757795521524, 0.01114409136789618, 0.02098994009429589, 0.057054424614761956, 0.05696064683434088, 0.07721237634541467, 0.015783178569108713, 0.04422230907948688, 0.06561905742273666, 0.10159656594623812, 0.06386986729921773, 0.03521886290400289, 0.014879086847940926, 0.034422968892613426, 0.044180121694807895, 0.06119933052104898, 0.07272554445080459, 0.01611267914995551, 0.051720460833166726, 0.029213962370704394, 0.04689741006586701, 0.026072375185322016, 0.023333039462158922, 0.05064219076302834, 0.046916342253098264, 0.04350216237071436, 0.20652316336054355, 0.05212153970205691, 0.00736972448976303, 0.06606251292396337, 0.12213513924507424, 0.15171862993156537, 3.759096013382077, 20.393537990748882, 57.38016240298748, 77.57073998451233, 90.35898417234421, 95.58758720755577, 88.49972113966942, 87.5458887219429, 74.92640107870102, 78.70934888720512, 81.32284104824066, 69.63983595371246, 83.6427229642868, 83.9698626101017, 80.89148059487343, 77.96567559242249, 59.377035051584244, 53.99227939546108, 44.3592718988657, 42.681969702243805, 40.00524893403053, 44.653121531009674, 45.83923548460007, 53.89832563698292, 34.33660291135311, 35.37111259996891, 49.14215885102749, 30.094862021505833, 37.62233980000019, 26.61426778882742, 41.700505167245865, 30.088415667414665, 43.31702582538128, 27.207767441868782, 35.19466146826744, 40.14908641576767, 41.04148373007774, 57.593277767300606, 76.03791743516922, 56.445256769657135, 82.38467887043953, 81.11010566353798, 77.17622235417366, 98.2435990869999, 102.89885088801384, 81.0421197116375, 86.31415441632271, 88.46100121736526, 96.32942140102386, 101.71464443206787, 104.92854237556458, 90.55747792124748, 69.2489205300808, 49.267954900860786, 7.278826721012592, 0.7145636505447328, 0.2592216746415943, 0.20024885394377634, 0.044453588270698674, 0.013952919016446685, 0.07516161451349035, 0.10661202220944688, 0.009031263725773897, 0.02510900256311288, 0.050276879701414146, 0.08107932939310558, 0.06222140887985006, 0.06817675806814805, 0.09221136642736383, 0.06897060375194997, 0.1081742875976488, 0.047120013550738804, 0.03501388171571307, 0.09840806946158409, 0.014865512039250461, 0.053691671855631284, 0.046513382039847784, 0.013339089600776788, 0.051423397671896964, 0.10648209441569634, 0.0385448904853547, 0.04523085808614269, 0.04029399155115243, 0.03126342729956377, 0.04032231190649327, 0.029128218338883016, 0.029994839023856912, 0.03455973186646588, 0.04111138558073435, 0.018786340369842947, 0.05676438959199004, 0.017756263514456805, 0.03855127295537386, 0.007578229951832327, 0.04109550733119249, 0.014834561698080506, 0.032295454147970304, 0.07136805244954303, 0.05664095930114854, 0.09194987811497413, 0.04140209224715363, 0.06308340598479845, 0.026874456852965523, 0.05713776779884938, 0.050128539223806, 0.09786289519979618, 0.05683563205820974, 0.05625604811939411, 0.07167844087234698, 0.03942481416743249, 0.01757008834829321, 0.021449800769914873, 0.09120042028371245, 0.02188935442973161, 0.04232912746374495, 0.018629847400006838, 0.04335051191446837, 0.08244099968578666, 0.0420703071722528, 0.012335706869635032, 0.021424753285828047, 0.028182269488752354, 0.09296424555941485, 0.005149350836290978, 0.01671605077717686, 0.017779785885068122, 0.012043432416248834, 0.0507192627992481, 0.09042181831318885, 0.03383197443326935, 0.05152472309418954, 0.010992397310474189, 0.041611158958403394, 0.04187612794339657, 0.027364958950784057, 0.0525456770992605, 0.038706188861397095, 0.03978939421358518, 0.09836746656219475, 0.0726208570995368, 0.003109068593403208, 0.01614182514458662, 0.04916289748507552, 0.08246258134022355, 0.05914477260375861, 0.04372948591480963, 0.04126394145714585, 0.08734259565244429, 0.014466301527136238, 0.01150663885709946, 0.03712774094310589, 0.08773157751420513, 0.049327858359902166, 0.05384737072745338, 0.021442021206894424, 0.019105560349998996, 0.027523275748535525, 0.03946865283069201, 0.03046428639208898, 0.05970578800770454, 0.01415811635524733, 0.022539620513271075, 0.07153283891966566, 0.005830264371979865, 0.04719065487734042, 0.0490111653925851, 0.03616103051172104, 0.03889830863045063, 0.12755646865116432, 0.02599068327981513, 0.013270041108626174, 0.16363913950044662, 0.023170100939751137, 0.11137849534861743, 0.200134681945201, 0.3157022892264649, 7.623949376866221, 34.17339786887169, 77.28595286607742, 95.73951065540314, 106.371248960495, 106.71304821968079, 105.48935428261757, 98.30469980835915, 93.62899750471115, 93.45505803823471, 109.02485176920891, 97.24439710378647, 117.13348746299744, 125.43753907084465, 101.24973177909851, 105.61694383621216, 81.54733300209045, 75.36767899990082, 64.97169524431229, 69.80667740106583, 65.66212579607964, 62.27384760975838, 65.91168120503426, 74.06203106045723, 61.978447660803795, 56.467329785227776, 63.538180366158485, 45.2866767346859, 55.54400593042374, 50.23057624697685, 68.13187167048454, 54.9749256670475, 72.81158655881882, 60.72370558977127, 61.73781417310238, 72.48410493135452, 71.93017825484276, 85.52192732691765, 110.84675520658493, 93.21612685918808, 118.68276312947273, 117.92573735117912, 106.97508975863457, 128.54407757520676, 129.66396868228912, 100.77452927827835, 99.82394948601723, 97.70322248339653, 108.6002929508686, 115.83183690905571, 126.56228631734848, 114.05300796031952, 94.3584443628788, 72.39601045846939, 17.773684971034527, 1.4227766543626785, 0.1092129158496391, 0.3340800624573603, 0.02909289025410544, 0.033218322205357254, 0.029660256586794276, 0.09513219993095845, 0.05328139777702745, 0.03625760247814469, 0.007711070211371407, 0.059624968125717714, 0.038385373263736255, 0.0055570171934959944, 0.04243053452228196, 0.02109272940288065, 0.021515521657420322, 0.04717942989373114, 0.0232018240421894, 0.021640365739585832, 0.005301121427692124, 0.01871979569841642, 0.04293257887184154, 0.06538763351272792, 0.034928842724184506, 0.056049549239105545, 0.035440969149931334, 0.03533999995852355, 0.037772752621094696, 0.026168253243668005, 0.016933804326981772, 0.02575165606685914, 0.027326113086019177, 0.0213815176175558, 0.06263844392378815, 0.014076634106459096, 0.016188847621378954, 0.05541712809645105, 0.0365392734966008, 0.039526395630673505, 0.06829654812463559, 0.0352512613608269, 0.06211400897882413, 0.027960361767327413, 0.014790202603762737, 0.013999146467540413, 0.05161275294085499, 0.038740409290767275, 0.01672357986535644, 0.036180044335196726, 0.04687698616180569, 0.033423451823182404, 0.05597121926257387, 0.04800452370545827, 0.049913980619749054, 0.05023208737839013, 0.01941729391546687, 0.02188207767176209, 0.06495880574220791, 0.027542597563297022, 0.08875632018316537, 0.0340484589105472, 0.01518324030257645, 0.17223335802555084, 0.15242411551298574, 0.17785570555133745, 0.0953387025219854, 0.23346750269411132, 0.1448569106287323, 0.11578329766052775, 0.07106614677468315, 0.13642682548379526, 0.12295693421037868, 0.1322615216486156, 0.1072877921978943, 0.10097178892465308, 0.12963062297785655, 0.138627412088681, 0.1598798349732533, 0.12014765292406082, 0.09110869825235568, 0.22075957444030792, 0.19819326815195382, 0.08890641955076717, 0.1773829574813135, 0.19025829940801486, 0.06935177822015248, 0.07879844983108342, 0.08152078851708211, 0.18041329487459734, 0.1355968223651871, 0.1255107979523018, 0.27110010443720967, 0.16171163355465978, 0.09267093395465054, 0.12753136921674013, 0.13268193346448243, 0.1810672605643049, 0.1643711791257374, 0.1746507259667851, 0.12360049498965964, 0.1224513683700934, 0.11105159414000809, 0.07345776961301453, 0.06962121493415907, 0.2005576912779361, 0.1911945632309653, 0.0778348972380627, 0.15107370360055938, 0.17222938011400402, 0.10729559959145263, 0.2205479732947424, 0.15129809937207028, 0.19760239985771477, 0.17856473859865218, 0.08395343727897853, 0.35558863019105047, 0.20447857619728893, 0.1429799449397251, 0.2167712282971479, 0.2940844773547724, 0.2756625018082559, 7.076022103428841, 34.89328823983669, 83.08450251817703, 108.7267653644085, 119.76720213890076, 122.96660766005516, 111.76002860069275, 108.31411510705948, 95.1220665872097, 99.06938597559929, 102.42342039942741, 91.82812973856926, 105.10931387543678, 107.27016672492027, 102.10962563753128, 101.71016067266464, 79.69400525093079, 76.32754549384117, 65.09211078286171, 59.11212466657162, 57.71878503262997, 61.17711625993252, 66.6342656314373, 74.64248031377792, 52.18939773738384, 55.4568500071764, 71.44217044115067, 47.06924848258495, 59.913114085793495, 43.10725048184395, 61.02637454867363, 46.87919408082962, 65.91442465782166, 46.9825903326273, 54.62491124868393, 62.35938481986523, 63.164379224181175, 81.22071772813797, 98.34190741181374, 80.07495760917664, 113.99180844426155, 112.79792010784149, 110.36083728075027, 128.47575724124908, 129.75280791521072, 103.59664544463158, 109.60862204432487, 107.99728810787201, 121.6879990696907, 132.86718159914017, 141.33321851491928, 124.55551519989967, 105.85653617978096, 74.46556940674782, 16.76571685820818, 1.0919025214388967, 0.3247618046589196, 0.43611070315819234, 0.0901991814316716, 0.14382744790054858, 0.17595813784282655, 0.19785483396844938, 0.11570887509151362, 0.1243381600943394, 0.14517340692691505, 0.2155116997892037, 0.18761583807645366, 0.20371499529574066, 0.37939016707241535, 0.11200961031136103, 0.21743461926234886, 0.10457835203851573, 0.15488090633880347, 0.27165647770743817, 0.041450558201177046, 0.1537009805906564, 0.15865929890424013, 0.1530670974170789, 0.23748994310153648, 0.20964053983334452, 0.14417895872611552, 0.2354858920443803, 0.1455121676553972, 0.1340199663536623, 0.18652008671779186, 0.10819640359841287, 0.10692650728742592, 0.10512383800232783, 0.0925210423883982, 0.13682384480489418, 0.10632143428665586, 0.08122182916849852, 0.17762758419848979, 0.11262846499448642, 0.13481029425747693, 0.10159802055568434, 0.11543859232915565, 0.14664069225545973, 0.15206604410195723, 0.2161550527671352, 0.20821940124733374, 0.1860105578089133, 0.08190612643375061, 0.13571132090874016, 0.19408577762078494, 0.22597510629566386, 0.21162596298381686, 0.17224665731191635, 0.28621940407902, 0.14843554672552273, 0.1266303870943375, 0.09047080005984753, 0.24447867355775088, 0.12228350940858945, 0.20533793867798522, 0.17010174662573263, 0.16722337139071897], [0.04043084729346447, 0.012507578994700452, 0.013671011438418645, 0.07795594152412377, 0.09863777158898301, 0.0391466572182253, 0.04752707412990276, 0.005457775814647903, 0.024345280653506052, 0.05660143622662872, 0.04374286683741957, 0.08946916786953807, 0.015557085134787485, 0.023927776201162487, 0.04789596234331839, 0.006901797132741194, 0.0035243716502009192, 0.09181914880173281, 0.01749166003719438, 0.0461316249857191, 0.01682333564531291, 0.04713053349405527, 0.06665835360763595, 0.010519383922655834, 0.04254639490682166, 0.06652437368757091, 0.05570515932049602, 0.021952531606075354, 0.02086580847389996, 0.06040011168806814, 0.03552696180122439, 0.06485319070634432, 0.009798711216717493, 0.01949588920979295, 0.06432309688534588, 0.022494867153000087, 0.00217843187328981, 0.0729447155026719, 0.03433211888477672, 0.04137006115342956, 0.0822340592276305, 0.0834253546781838, 0.05834087452967651, 0.06724799735820852, 0.02161134034395218, 0.013288417612784542, 0.02511926089937333, 0.08223436350817792, 0.054172060335986316, 0.04304355592466891, 0.031571967774652876, 0.012566624263854465, 0.05240828701062128, 0.12185165367554873, 0.13722770672757179, 0.11385640027583577, 0.12262342788744718, 3.787014065310359, 23.345667980611324, 65.77404499053955, 81.4290301501751, 88.95404756069183, 83.46465691924095, 91.6501472890377, 86.66177496314049, 87.27849707007408, 79.63578477501869, 52.022381499409676, 54.03783895075321, 51.39671467244625, 40.440165996551514, 34.35315482318401, 14.494858961552382, 49.51615758240223, 77.29143217206001, 33.94374579191208, 36.17069609463215, 41.30481719970703, 41.64544232189655, 30.801470205187798, 44.1131629049778, 44.95408818125725, 39.182684272527695, 54.90020267665386, 43.91894772648811, 37.08463825285435, 49.592636078596115, 43.960411101579666, 47.30612017214298, 44.21905942261219, 41.33135877549648, 36.704172268509865, 37.51168593764305, 28.953454568982124, 26.182443760335445, 32.23780833184719, 25.99862102419138, 19.656672030687332, 15.908711794763803, 22.464814446866512, 33.67550678551197, 42.01949045062065, 51.699243038892746, 49.718458727002144, 86.20546504855156, 77.99867302179337, 89.01131808757782, 73.92979055643082, 74.1619049012661, 80.51681309938431, 82.71132454276085, 94.62570682168007, 102.48328238725662, 89.00910660624504, 52.98271916806698, 8.578762616962194, 2.3833997827023268, 0.43013136775698513, 0.20695193175924942, 0.018239791279484052, 0.10235550842480734, 0.06042107364919502, 0.12406467867549509, 0.08595195933594368, 0.0591991980036255, 0.043373685475671664, 0.10313356862752698, 0.0028672400048890267, 0.021211209568718914, 0.039323893215623684, 0.05460296612000093, 0.052416098114917986, 0.03671014928841032, 0.04856246661802288, 0.06582748959772289, 0.0108001792068535, 0.032366262457799166, 0.03617532427597325, 0.01231384319908102, 0.05697308522940148, 0.04182111624686513, 0.014830209001956973, 0.0941359854186885, 0.02538725228077965, 0.026954391723847948, 0.07257117773406208, 0.013290283186506713, 0.020962350754416548, 0.01951808499143226, 0.12469635024899617, 0.05852418871654663, 0.05065271812782157, 0.10585132826236077, 0.035818659234791994, 0.035774742646026425, 0.060343637960613705, 0.0603220822813455, 0.04322316679463256, 0.11520756175741553, 0.026346921586082317, 0.038351943221641704, 0.04562459340377245, 0.08181691286154091, 0.016018847563827876, 0.014740167935087811, 0.007664591357752215, 0.04973603587131947, 0.008025789065868594, 0.019696849813044537, 0.029305530406418256, 0.054361408183467574, 0.05294936832797248, 0.0387165455322247, 0.023048583534546196, 0.07781695952871814, 0.00845214362925617, 0.034996905087609775, 0.025906894807121716, 0.0451411546964664, 0.04027331531688105, 0.08706006745342165, 0.028242956759640947, 0.06821992137702182, 0.023728945561742876, 0.029900100162194576, 0.02251737463666359, 0.05052489061199594, 0.03685730232973583, 0.04639899110770784, 0.02434315625578165, 0.0263992448526551, 0.06993557384703308, 0.03728411888005212, 0.16694417543476447, 0.04129222841584124, 0.09775652317330241, 0.023827089025871828, 0.06259125075303018, 0.07616297210915945, 0.019948324697907083, 0.037904068231000565, 0.07073520828271285, 0.026715965650510043, 0.017446236888645217, 0.04743176752526779, 0.003186453723174054, 0.02759078150120331, 0.08062720560701564, 0.03978891181759536, 0.06252154082176276, 0.049297181685687974, 0.03396591724595055, 0.009036883639055304, 0.012759398978232639, 0.0696511754358653, 0.06561757312738337, 0.04190388055576477, 0.05901500066102017, 0.043550457630772144, 0.011032515030819923, 0.020980906301701907, 0.03269580571213737, 0.02010196967603406, 0.07196857608505525, 0.03435143698879983, 0.08232358450186439, 0.047224500522133894, 0.02490630347892875, 0.04575693317747209, 0.08710377995157614, 0.22726080293068662, 0.071240046818275, 0.2006293975864537, 10.214993767440319, 39.53893415629864, 88.44509527087212, 95.38699597120285, 103.6348257958889, 92.45794594287872, 108.09730634093285, 104.06972765922546, 113.43852013349533, 113.5601744055748, 82.44597718119621, 86.35244876146317, 76.04650497436523, 61.56661815941334, 52.44157500565052, 31.42059188336134, 55.26778355240822, 88.00020754337311, 45.060847252607346, 40.96184380352497, 35.8033812046051, 45.80809235572815, 41.57003916800022, 39.2416875064373, 44.22613084316254, 40.214081928133965, 44.557267874479294, 41.4787832647562, 45.034769251942635, 49.52100232243538, 46.653345599770546, 43.16803202033043, 46.59687303006649, 42.74093873798847, 42.23393194377422, 43.21444272994995, 37.6841776818037, 38.3286838978529, 43.04108463227749, 38.3894008398056, 35.7678759098053, 26.467225179076195, 44.499917551875114, 68.54094251990318, 64.47106450796127, 82.41230338811874, 79.69387605786324, 124.27810728549957, 110.43026715517044, 132.5758284330368, 104.16042119264603, 93.41529697179794, 99.0327787399292, 95.27975052595139, 108.57214406132698, 114.44919750094414, 113.34217250347137, 78.73663142323494, 24.018547274172306, 7.201363127678633, 0.7104142138268799, 0.21876760554732755, 0.028617084535653703, 0.1434795290697366, 0.06465063634095713, 0.11666742560919374, 0.04863910078711342, 0.07990308469743468, 0.03825107422017027, 0.026863944331125822, 0.027386464535084087, 0.015431462725246092, 0.01620525094040204, 0.08300650137243792, 0.04142772602790501, 0.04258631874108687, 0.03854044873150997, 0.06266975513426587, 0.007457746451109415, 0.04552334219624754, 0.03618110189563595, 0.019593310935306363, 0.10982701336615719, 0.045168458309490234, 0.015279245453712065, 0.05942928233707789, 0.04655190321500413, 0.051123755547450855, 0.04949622569256462, 0.06490188301540911, 0.052179742633597925, 0.026693439613154624, 0.008793101114861201, 0.05342983473383356, 0.025177107600029558, 0.03227926790714264, 0.036122286692261696, 0.05691165024472866, 0.05011255336285103, 0.03868518237140961, 0.06503294629510492, 0.04322592758398969, 0.08762374345678836, 0.031016928514873143, 0.00890664692633436, 0.05343291093595326, 0.040096981028909795, 0.06382579114870168, 0.01159652128990274, 0.07233009106130339, 0.012318417611822952, 0.033433908683946356, 0.02039527942542918, 0.011987866892013699, 0.025241334915335756, 0.0581863074330613, 0.026772919918585103, 0.07480831511202268, 0.0977707353013102, 0.16393680009059608, 0.13848460803274065, 0.11404438628233038, 0.14029454294359311, 0.23990514397155493, 0.1739971461938694, 0.10826284065842628, 0.05938776288530789, 0.10819556497153826, 0.151747751806397, 0.17259370040846989, 0.1201796394889243, 0.18909759528469294, 0.06057935519493185, 0.1577122590970248, 0.06382596184266731, 0.12729079462587833, 0.33469016721937805, 0.10700344573706388, 0.1752629829570651, 0.17935003474121913, 0.09570222871843725, 0.19698463613167405, 0.17265317612327635, 0.11412028572522104, 0.1128100611094851, 0.1643186795990914, 0.08883242742740549, 0.12118063343223184, 0.2115878462791443, 0.11577321929507889, 0.1437530995463021, 0.15489220182644203, 0.13268925104057416, 0.108977721829433, 0.12344223941909149, 0.05574652663199231, 0.20428849733434618, 0.13424461445538327, 0.11852070194436237, 0.16840809141285717, 0.10674586112145334, 0.26683035073801875, 0.10819937961059622, 0.12019112793495879, 0.06992433773120865, 0.0964432186447084, 0.2158007663092576, 0.19242670648964122, 0.1825048154569231, 0.11749562530894764, 0.08043858877499588, 0.17903189087519422, 0.2914621727541089, 0.2674493019003421, 0.2737517387140542, 0.1800172551884316, 7.968191429972649, 39.37744282186031, 95.4124242067337, 109.78145956993103, 113.41943755745888, 103.88476118445396, 111.5293125808239, 105.73843091726303, 107.87531465291977, 104.46714833378792, 72.87541553378105, 75.26539608836174, 69.38531041145325, 57.418008372187614, 47.630599960684776, 24.917561933398247, 62.058471366763115, 97.72776156663895, 53.526648581027985, 58.23518492281437, 60.236818715929985, 63.861987590789795, 45.75403265655041, 67.43034571409225, 63.4113659709692, 56.39199122786522, 73.66868376731873, 66.48064747452736, 59.48828548192978, 74.88673880696297, 70.79167574644089, 69.44704949855804, 63.86970117688179, 64.00995165109634, 52.016199231147766, 56.49774715304375, 44.54195849597454, 43.80370371043682, 50.55505223572254, 41.119801327586174, 30.71733321994543, 27.91197795420885, 39.91146236658096, 48.26827794313431, 64.07843917608261, 71.74606293439865, 70.25458216667175, 114.57519114017487, 108.70634526014328, 118.54560568928719, 101.41873151063919, 96.40994668006897, 100.74436649680138, 103.75578090548515, 119.6518175303936, 130.96723794937134, 125.1822991669178, 84.67040061950684, 23.033951707184315, 6.8697587214410305, 0.47605300205759704, 0.38183040800504386, 0.12768739834427834, 0.19882649823557585, 0.12923225294798613, 0.22324918303638697, 0.1134016047581099, 0.25672369461972266, 0.1486514077987522, 0.2602806006325409, 0.09755593549925834, 0.0800238766532857, 0.13827205693814903, 0.1795443586888723, 0.11402665637433529, 0.11123813295853324, 0.20998657360905781, 0.12629694014322013, 0.09313904360169545, 0.11761164525523782, 0.12713144067674875, 0.1866668538423255, 0.2633456705370918, 0.18905459524830803, 0.14332299528177828, 0.15645537263480946, 0.13220871041994542, 0.11219688385608606, 0.08151096990332007, 0.17503116570878774, 0.11114110457128845, 0.15308528003515676, 0.12187985528726131, 0.11048991451389156, 0.13121467782184482, 0.2266601679730229, 0.19838546955725178, 0.16217694530496374, 0.15567717142403126, 0.15423556440509856, 0.1526416389970109, 0.2068521425826475, 0.2514655189588666, 0.21000848180847242, 0.12536521826405078, 0.15616823569871485, 0.10948565512080677, 0.1135974501085002, 0.06454652786487713, 0.24623173027066514, 0.08760794313275255, 0.14273117703851312, 0.1329127117060125, 0.17778034787625074, 0.15847858594497666, 0.17873029690235853, 0.15327147004427388, 0.15521804918535054, 0.21262189547996968], [0.04755438145366497, 0.05098477726278361, 0.026222511660307646, 0.04168558894889429, 0.058417890904820524, 0.04888389819825534, 0.003376960712557775, 0.024642996904731262, 0.04680383266531862, 0.06038845996954478, 0.044228550541447476, 0.037745025983895175, 0.05993795035465155, 0.032919874938670546, 0.01629280024644686, 0.05231778952293098, 0.052432770462473854, 0.03894124187354464, 0.020367075958347414, 0.0727214923244901, 0.03035106619790895, 0.07139240973629057, 0.007970979604579043, 0.030753011524211615, 0.06207651567819994, 0.05289496519253589, 0.016543215715500992, 0.07890405002399348, 0.010739688605099218, 0.022591171946260147, 0.01354463945972384, 0.027533157444850076, 0.005610915668512462, 0.005581938048635493, 0.043091888292110525, 0.026139014480577316, 0.0630614161491394, 0.09744603084982373, 0.05113161118060816, 0.034782194343279116, 0.04332602104113903, 0.02560304470534902, 0.07470612137694843, 0.06133582632173784, 0.05934253640589304, 0.04139334603678435, 0.03665762378659565, 0.09377861904795282, 0.0892785175528843, 0.16374700324377045, 0.08837178378598765, 0.05153391830390319, 0.02648029480042169, 0.05079392285551876, 2.4616912566125393, 12.36428003758192, 34.059240594506264, 70.70708468556404, 96.32500603795052, 84.96966496109962, 81.58729165792465, 68.3409820497036, 80.68948343396187, 60.05096308887005, 54.22707259654999, 61.08874060213566, 37.74355709552765, 31.05601094663143, 25.39852872490883, 34.21265356242657, 35.78938655555248, 45.22551901638508, 67.78663739562035, 37.21394531428814, 35.74914291501045, 49.08154830336571, 41.20525114238262, 50.222372487187386, 61.670075207948685, 63.64745110273361, 78.00523906946182, 66.48973658680916, 51.71229913830757, 84.7550904750824, 56.36077970266342, 35.55355980992317, 44.64406281709671, 42.51282937824726, 69.55510050058365, 69.97391402721405, 64.06071692705154, 69.29251939058304, 86.72379523515701, 56.544522643089294, 67.78853729367256, 82.45190486311913, 55.94578117132187, 55.27554653584957, 88.15245777368546, 51.94903403520584, 33.074390441179276, 44.61398743093014, 31.299019306898117, 38.17339763045311, 30.512940287590027, 22.909626178443432, 25.19263867288828, 37.49520242214203, 60.737274661660194, 65.33182471990585, 63.817165195941925, 55.57622820138931, 74.68380689620972, 76.73448085784912, 92.92199984192848, 93.34842815995216, 64.64098379015923, 37.76336923241615, 5.473278556019068, 0.26281055237632245, 0.2938844240270555, 0.02196806661231676, 0.03353297426656354, 0.03630710001743864, 0.1026729769364465, 0.02894180939620128, 0.057602515516919084, 0.027955894038314, 0.022192924370756373, 0.03723827270732727, 0.03135245533485431, 0.059586317074717954, 0.052899247384630144, 0.06454983784351498, 0.05254620402411092, 0.03766684443689883, 0.009166559102595784, 0.028571657676366158, 0.03494392316497397, 0.016033373249229044, 0.08110995782772079, 0.04159247539064381, 0.046095734724076465, 0.06134877308795694, 0.06019127133185975, 0.055171057902043685, 0.0347264479205478, 0.08015862840693444, 0.05784356879303232, 0.06514749678899534, 0.02634546697663609, 0.036770641745533794, 0.03251848065701779, 0.05913381479331292, 0.018834591101040132, 0.049145531229441985, 0.049120583935291506, 0.05708670061721932, 0.09476939361775294, 0.01623002754058689, 0.05355314257030841, 0.03497957965009846, 0.017406365004717372, 0.07517919599195011, 0.08452758498606272, 0.06053488941688556, 0.0930576967948582, 0.019918430989491753, 0.022097252258390654, 0.008064621943049133, 0.05715866667742375, 0.029324386523512658, 0.04276116131222807, 0.038762087424402125, 0.01615013534319587, 0.06858191132778302, 0.0507266768545378, 0.0736187859729398, 0.0490792425989639, 0.07299461009097286, 0.06015522150846664, 0.04056903890159447, 0.051165686891181394, 0.03370628059201408, 0.021646314053214155, 0.02460306008288171, 0.009004977782751666, 0.10025036943261512, 0.09372972635901533, 0.053805316929356195, 0.04736206872621551, 0.056753713797661476, 0.05113460203574505, 0.07777450126013719, 0.007950879462441662, 0.011671217525872635, 0.024983603725559078, 0.04243480187142268, 0.023400958962156437, 0.03975520718086045, 0.05416762229287997, 0.06497521462733857, 0.04083200779859908, 0.018145019021176267, 0.04632030861102976, 0.006304922544586589, 0.03889613784849644, 0.05443810914584901, 0.022062117132009007, 0.04554578474198934, 0.07083401782438159, 0.06903116300236434, 0.05829759989865124, 0.02327304238860961, 0.057844986295094714, 0.036599402301362716, 0.028707197961921338, 0.05877205861906987, 0.07646456608199514, 0.0027492503522807965, 0.06529116173624061, 0.024919691823015455, 0.022339886309055146, 0.07603541918797418, 0.04892561802989803, 0.040867300631362014, 0.03860542376060039, 0.022901269076101016, 0.1425151526927948, 0.14998258324339986, 6.543231317773461, 23.409388661384583, 53.34281824529171, 91.2098953127861, 113.25819700956345, 99.88942757248878, 97.97827452421188, 89.26974222064018, 99.72480520606041, 90.75454294681549, 93.52594703435898, 82.66691252589226, 57.19891972839832, 32.01876908540726, 28.07480301707983, 25.076684094965458, 27.21324484795332, 23.27170304954052, 25.32331556081772, 15.892595909535885, 24.852726012468338, 25.297235660254955, 23.19083958864212, 35.0009972602129, 19.471285678446293, 22.729464545845985, 37.48649708926678, 33.912040293216705, 24.18797068297863, 36.87017776072025, 23.54855429381132, 15.729484912008047, 25.95833368599415, 21.990069821476936, 27.173831462860107, 25.103022381663322, 21.96091588586569, 32.84076377749443, 34.41696099936962, 22.524670735001564, 24.350533559918404, 46.410736218094826, 26.830652877688408, 18.398246057331562, 48.96022081375122, 32.71079555153847, 16.624717824161053, 35.442495569586754, 24.171585962176323, 27.63778656721115, 36.67920000851154, 35.288451835513115, 40.08993498980999, 59.89735633134842, 84.8802101612091, 102.62819141149521, 95.09856104850769, 80.99127843976021, 97.04735487699509, 89.42818611860275, 104.54580411314964, 113.46170648932457, 89.02315065264702, 59.75955672562122, 13.584878090769053, 0.40284387418068945, 0.281378582585603, 0.060291824920568615, 0.10992798255756497, 0.07461496337782592, 0.13737392466282472, 0.06753731620847248, 0.06403983396012336, 0.04271383826562669, 0.04531713275355287, 0.022148239659145474, 0.07449034936144017, 0.029773152091365773, 0.03454633981164079, 0.0672660389682278, 0.010694314623833634, 0.048597919012536295, 0.05903479745029472, 0.0791077250323724, 0.02500583290384384, 0.018197698518633842, 0.0266453744188766, 0.015048315999592887, 0.05917501141084358, 0.057766389145399444, 0.0204730026962352, 0.056933135419967584, 0.061437322437996045, 0.03143036970868707, 0.03678441971715074, 0.029662219567399006, 0.027759104305005167, 0.06682675433694385, 0.022804799154982902, 0.0324903272849042, 0.04050667252158746, 0.06181730204843916, 0.053275493992259726, 0.017328118519799318, 0.017874626792035997, 0.02133931910066167, 0.0444264924590243, 0.03400524365133606, 0.03259153767430689, 0.07728297685389407, 0.03923304691852536, 0.009458442073082551, 0.008452394104097039, 0.060565143066924065, 0.02399780525593087, 0.014650588855147362, 0.05825390595418867, 0.009677310699771624, 0.017217315871675964, 0.034714143112068996, 0.02834275150235044, 0.07033632617094554, 0.265948916785419, 0.17251215322175995, 0.23398282035486773, 0.14424134365981445, 0.16559639072511345, 0.10571311067906208, 0.18867596634663641, 0.11068044608691707, 0.1075459185813088, 0.1515659553115256, 0.13871041388483718, 0.27750347333494574, 0.25257874047383666, 0.13576552737504244, 0.10885883719311096, 0.1491947637987323, 0.1996825062087737, 0.13258981809485704, 0.147686185373459, 0.20498512167250738, 0.11779407999711111, 0.15610645932611078, 0.08388630260014907, 0.1278076262678951, 0.13111120759276673, 0.0965397572144866, 0.12030571553623304, 0.1359222095925361, 0.15692723012762144, 0.10375882804510184, 0.19902686326531693, 0.12546652142191306, 0.0814034030190669, 0.09696546054328792, 0.1275277920649387, 0.10844908261788078, 0.1906751934438944, 0.14292190899141133, 0.11143729570903815, 0.09250181334209628, 0.10108054324518889, 0.138194517348893, 0.1357122857007198, 0.101119691535132, 0.23854227882111445, 0.13576862955233082, 0.2211865913704969, 0.171186484512873, 0.1376445562345907, 0.3079048701329157, 0.19054604490520433, 0.16166578367119655, 0.2294351175078191, 0.2334719110513106, 4.996561836451292, 20.794636867940426, 55.218617990612984, 100.34037977457047, 121.5377627313137, 106.21606528759003, 101.32306784391403, 89.13510024547577, 105.71871757507324, 81.5586107969284, 74.63076934218407, 76.4857006072998, 48.98516647517681, 43.016993924975395, 36.751335337758064, 49.571429416537285, 52.039222195744514, 62.411065846681595, 94.59697276353836, 54.814247488975525, 54.32973928749561, 67.14553579688072, 60.72635404765606, 78.00287559628487, 85.76278120279312, 88.6100672185421, 104.6331538259983, 92.74874433875084, 72.07776993513107, 118.19407895207405, 78.24444383382797, 56.44329987466335, 68.936448097229, 62.037838473916054, 99.92718234658241, 96.22862800955772, 89.7953300178051, 95.04076614975929, 118.39072600007057, 77.57425859570503, 91.20402082800865, 114.22005459666252, 77.0748969912529, 72.23809093236923, 121.59271538257599, 74.99839201569557, 48.4052187949419, 69.83913525938988, 48.251726031303406, 54.03619363903999, 47.379140853881836, 34.47786033153534, 35.79242259263992, 51.86420738697052, 82.53793224692345, 90.23452565073967, 87.85871833562851, 80.86507201194763, 98.94518584012985, 97.07450821995735, 119.31656911969185, 127.45317131280899, 99.4194307923317, 64.49658393859863, 12.015738040208817, 0.31385223381221294, 0.4751933872466907, 0.13047195127001032, 0.27304263145197183, 0.16542329220101237, 0.2483091945759952, 0.13401156524196267, 0.2586781850550324, 0.09473336976952851, 0.13953510322608054, 0.07818817437510006, 0.15821871551452205, 0.3529331961181015, 0.20274542388506234, 0.21814767475007102, 0.09406429395312443, 0.18853101006243378, 0.07049510124488734, 0.14725530927535146, 0.14332957071019337, 0.08871003243257292, 0.21672186063369736, 0.16279956267680973, 0.12445636195479892, 0.13385831174673513, 0.1851441597682424, 0.19401372992433608, 0.10368770061177202, 0.17433445231290534, 0.15199358080280945, 0.15454539621714503, 0.08462692145258188, 0.1191493975056801, 0.08032591591472737, 0.14715082972543314, 0.06600629523745738, 0.1461162164923735, 0.10756393792689778, 0.18717985600233078, 0.17454124434152618, 0.09846586792264134, 0.19194010994397104, 0.1557256336673163, 0.08966468667495064, 0.16971762583125383, 0.245143712090794, 0.2333849758724682, 0.21578991611022502, 0.14822637982433662, 0.1936547679360956, 0.1381270115962252, 0.12283017538720742, 0.12183049504528753, 0.0986778327205684, 0.07620327814947814, 0.0848642157507129, 0.17751240287907422], [0.03879386618791614, 0.031202192694763653, 0.05648276310239453, 0.06728899359586649, 0.0240146854048362, 0.04087957946467213, 0.032008365451474674, 0.025959167978726327, 0.09721767200971954, 0.04134365182835609, 0.005061372012278298, 0.016115413964143954, 0.00906144872715231, 0.017339582846034318, 0.037889815284870565, 0.06821989911259152, 0.042313419908168726, 0.020198532365611754, 0.009414157193532446, 0.06003194706863724, 0.02891087111493107, 0.0702236607321538, 0.06551957252668217, 0.03503156709484756, 0.02583610505098477, 0.03959435038268566, 0.009043806949193822, 0.023223886237246916, 0.0008540915507637692, 0.04392744267533999, 0.015194685147434939, 0.06950694645638578, 0.0809496984584257, 0.030471921236312483, 0.04120769408473279, 0.05027117258578073, 0.035137241502525285, 0.09359781703096814, 0.046259574955911376, 0.05034617774072103, 0.02020967200223822, 0.05765842892287765, 0.042736150935525075, 0.08994612391688861, 0.056309694264200516, 0.08473821391817182, 0.06950693903490901, 0.062263518339022994, 0.041545208005118184, 0.05729680633521639, 0.04429193366377149, 0.165533768304158, 1.578853279352188, 29.232251308858395, 63.347236812114716, 90.87093830108643, 90.82322806119919, 82.2376723587513, 52.40955792367458, 61.282435208559036, 67.20137000083923, 59.81851436197758, 48.061363846063614, 36.34123094379902, 12.505208775401115, 33.38098458945751, 39.794694632291794, 57.79915452003479, 61.151619628071785, 69.33926448225975, 57.17012867331505, 72.1143239736557, 85.47637537121773, 73.49482029676437, 61.13201268017292, 86.06206074357033, 52.899150252342224, 43.54383945465088, 89.60667014122009, 99.63205218315125, 81.21548160910606, 71.33333668112755, 67.91948586702347, 64.54215869307518, 72.39329740405083, 76.33322238922119, 68.26036557555199, 70.42356669902802, 79.8037737607956, 93.06892275810242, 89.46474015712738, 75.32705917954445, 77.13572412729263, 80.8793592453003, 87.27599680423737, 79.74918588995934, 92.02941253781319, 95.13611063361168, 100.93451589345932, 124.2602102458477, 112.92160347104073, 66.29797607660294, 84.0848596394062, 90.40150389075279, 75.16337156295776, 51.040282398462296, 57.672442719340324, 36.5266077965498, 26.32377527654171, 22.06188026815653, 26.034977473318577, 40.02426691353321, 67.51846298575401, 65.50455585122108, 78.48433256149292, 67.93967798352242, 81.57428115606308, 87.54502236843109, 75.6277522444725, 31.30853969603777, 9.923800192773342, 0.5218874488491565, 0.5630375188775361, 0.06948326452402398, 0.11412997075240128, 0.06758692878065631, 0.08691565293702297, 0.07217637743451633, 0.032556745791225694, 0.09489652351476252, 0.03593214103602804, 0.036822042893618345, 0.05156019775313325, 0.03737825289135799, 0.03165967849781737, 0.02766699079074897, 0.019595689518610016, 0.03374929918209091, 0.028269922695471905, 0.05460212749312632, 0.01271512615858228, 0.020009160398331005, 0.04151976347202435, 0.028147831981186755, 0.05505746477865614, 0.07852683862438425, 0.054617122586932965, 0.018978912848979235, 0.05259613571979571, 0.046588034674641676, 0.0641191250178963, 0.03199648737790994, 0.04786701487319078, 0.022951601531531196, 0.012690382027358282, 0.08292138445540331, 0.03227218039683066, 0.042644024433684535, 0.10357174003729597, 0.05277685238979757, 0.03610559579101391, 0.05980864225421101, 0.04577259620418772, 0.11274455915554427, 0.02643977724801516, 0.056706216346356086, 0.033828156083473004, 0.059868748794542626, 0.0321126891503809, 0.01822474237997085, 0.03104049541434506, 0.060424817784223706, 0.02235051757452311, 0.05317645067407284, 0.022404675801226404, 0.026041271776193753, 0.011142171060782857, 0.0022234602920434554, 0.01838779222453013, 0.06931595475180075, 0.01491083407017868, 0.025122917832050007, 0.01599804516445147, 0.05089724094432313, 0.0407810333854286, 0.012083419333066558, 0.04984211103874259, 0.025458388990955427, 0.006196709991854732, 0.019865632748405915, 0.020141967725066934, 0.12392914766678587, 0.012248445145814912, 0.07394807689706795, 0.011430228259996511, 0.04055134981172159, 0.01161297841463238, 0.021100340127304662, 0.005615407517325366, 0.05369207632611506, 0.12295532374992035, 0.011428791276557604, 0.07713197206612676, 0.0348664318153169, 0.05545561587496195, 0.04009426476841327, 0.020771930503542535, 0.03577421943191439, 0.013780273202428361, 0.024131315767590422, 0.02717080198635813, 0.02130537512130104, 0.031220891105476767, 0.05769031158706639, 0.024475503450958058, 0.010068760202557314, 0.042249443067703396, 0.028930636362929363, 0.01647440378292231, 0.025415628297196236, 0.03693288264912553, 0.11525496272952296, 0.03675805863167625, 0.07504960216465406, 0.024586309809819795, 0.08328059877385385, 0.11002921150065958, 0.1690162517479621, 6.1090547405183315, 43.939785808324814, 82.01708659529686, 107.89276331663132, 107.9004693031311, 93.72342243790627, 76.49534448981285, 90.47376841306686, 88.3191928267479, 81.16451114416122, 79.1052420437336, 34.13369379937649, 15.397616419941187, 25.45996952801943, 25.676155127584934, 32.36616924405098, 29.674085900187492, 36.5781482309103, 26.819019801914692, 38.34561958909035, 56.244365349411964, 60.889612287282944, 42.358101680874825, 52.762935161590576, 44.19215306639671, 37.4638807028532, 62.98088327050209, 69.91005465388298, 64.58492919802666, 54.001303911209106, 51.39342024922371, 51.01323924958706, 57.13853716850281, 61.439351588487625, 52.09548197686672, 59.63294751942158, 63.25308546423912, 66.21670603752136, 67.6447606086731, 61.96776643395424, 59.85374227166176, 61.11029304563999, 68.61243188381195, 58.04337501525879, 61.55831940472126, 60.35064160823822, 84.80418384075165, 91.25823631882668, 57.53726117312908, 47.298858761787415, 53.18415015935898, 60.80106943845749, 43.46332937479019, 28.34195338189602, 22.829543575644493, 33.65862049162388, 38.422744050621986, 31.53375171124935, 39.222962111234665, 67.90078327059746, 100.03971710801125, 94.46501344442368, 96.65356680750847, 77.25748479366302, 90.70065423846245, 100.22903814911842, 98.72732073068619, 52.66386687755585, 20.686905048787594, 0.9664597338996828, 0.5518883233889937, 0.15811848104931414, 0.05906491009227466, 0.05991194921080023, 0.087451416766271, 0.10217027578619309, 0.028337892290437594, 0.050615595901035704, 0.06057306549337227, 0.016605064447503537, 0.03845450803055428, 0.08161288904375397, 0.05261919795884751, 0.011648361232801108, 0.04673322102462407, 0.0022499048691315693, 0.014059009954507928, 0.016919081972446293, 0.018666505784494802, 0.011923126567126019, 0.051082317731925286, 0.035494964104145765, 0.050140558305429295, 0.06887010953505524, 0.035549519379856065, 0.026999646033800673, 0.07168411088059656, 0.013421148869383615, 0.07305539940716699, 0.02595944628410507, 0.04640465369448066, 0.03984222770668566, 0.08768047322519124, 0.02753520577243762, 0.009953650314855622, 0.04308745395974256, 0.0200214447977487, 0.04487885002163239, 0.015147898302529939, 0.009944304820237448, 0.04495493500144221, 0.1129799461341463, 0.025449076892982703, 0.044570895843207836, 0.013533903365896549, 0.09036461357027292, 0.04104208383068908, 0.02510621208784869, 0.03027693306648871, 0.030791664430580568, 0.019135943875880912, 0.11600241676205769, 0.04916447454888839, 0.042722770012915134, 0.10163787388592027, 0.19325624947668985, 0.09252188843674958, 0.11759827917558141, 0.1799917995231226, 0.11770695185987279, 0.1463991974014789, 0.12901170150144026, 0.14959452906623483, 0.08872419261024334, 0.10661214837455191, 0.09915974631439894, 0.16461395047372207, 0.16939790861215442, 0.09171420912025496, 0.22711489669745788, 0.10164682418690063, 0.1167966409411747, 0.15268395625753328, 0.18806228443281725, 0.1099901225825306, 0.19156234193360433, 0.17033967917086557, 0.1250493453699164, 0.10853484520339407, 0.16440726234577596, 0.1185657799942419, 0.12040223926305771, 0.13143950403900817, 0.13703497097594664, 0.11826969275716692, 0.1806601183488965, 0.1465312106302008, 0.165551342361141, 0.1296968077076599, 0.10053486432298087, 0.0713210077083204, 0.1415726845152676, 0.10472373876837082, 0.09030329732922837, 0.14956136990804225, 0.1270344716613181, 0.20767929585417733, 0.19332722848048434, 0.18404492031550035, 0.24713032267754897, 0.2170549365109764, 0.15788443735800683, 0.1606392746907659, 0.228833413857501, 0.23534394887974486, 0.15200425288639963, 4.720965474843979, 43.10394085943699, 87.60885134339333, 119.69613835215569, 116.40429139137268, 102.51211524009705, 71.87506601214409, 81.86719223856926, 89.48677137494087, 77.1478758752346, 68.91721352934837, 49.00349289178848, 20.110878758132458, 49.344984367489815, 60.80816365778446, 89.20087471604347, 91.39676168560982, 99.07683357596397, 78.35719898343086, 104.10184353590012, 126.3248598575592, 106.4271591603756, 83.73321130871773, 118.66087630391121, 82.6849539577961, 62.35767871141434, 126.5736249089241, 138.6295571923256, 113.82431343197823, 102.47378289699554, 94.09506529569626, 89.39775735139847, 100.47909513115883, 107.1487632393837, 95.55608689785004, 99.46622148156166, 112.00089767575264, 126.58953845500946, 125.43232575058937, 109.21111777424812, 114.22494113445282, 116.03100702166557, 121.92545592784882, 112.95351415872574, 128.45923572778702, 129.5264008641243, 130.17767071723938, 153.12349945306778, 148.88897627592087, 88.46010446548462, 113.24000358581543, 120.74108988046646, 103.16736727952957, 68.86439636349678, 82.71967649459839, 51.99816919863224, 39.47059482336044, 32.03908659517765, 38.4823514521122, 56.65378957986832, 90.22642448544502, 92.36886352300644, 100.94206228852272, 85.21251752972603, 103.50876376032829, 113.67509543895721, 108.66701737046242, 53.796175718307495, 18.19368213415146, 0.7048435346223414, 0.8706606400664896, 0.25584273564163595, 0.2739086881047115, 0.12355270810076036, 0.16439865343272686, 0.17726060701534152, 0.12666362046729773, 0.16440522886114195, 0.15932631155010313, 0.22250019275816157, 0.0930813564627897, 0.24217005993705243, 0.127280953747686, 0.07339937743381597, 0.09959606977645308, 0.11957159789744765, 0.22014192945789546, 0.28257278725504875, 0.11967036291025579, 0.16788885521236807, 0.10424034830066375, 0.1079845501226373, 0.15385159204015508, 0.20174233708530664, 0.1136656831658911, 0.13888526387745515, 0.19176962377969176, 0.15916713571641594, 0.20059824222698808, 0.11625949671724811, 0.07428815864841454, 0.10731447982834652, 0.21264649025397375, 0.10238668604870327, 0.11170210884301923, 0.11075549948145635, 0.17056104697985575, 0.18200411810539663, 0.12830427149310708, 0.20903258729958907, 0.16072160855401307, 0.19851945689879358, 0.16187043831450865, 0.11310184389003552, 0.15317925077397376, 0.2214912578347139, 0.13515971222659573, 0.09331310691777617, 0.16214814997510985, 0.09565299464156851, 0.11415466942708008, 0.16240932658547536, 0.20420074579305947, 0.214746797864791], [0.059873064383282326, 0.06151792338641826, 0.007308345166165964, 0.053772911051055416, 0.046277497822302394, 0.041977501605288126, 0.08752504523727112, 0.054480470935232006, 0.037128501644474454, 0.1477137190522626, 0.061352825214271434, 0.02995699134771712, 0.0832565309247002, 0.009155137449852191, 0.022962579751037993, 0.09421994458534755, 0.021466623402375262, 0.04233664913044777, 0.0362788241909584, 0.0598053248540964, 0.053314671968109906, 0.11015114636393264, 0.0747033160587307, 0.021790116297779605, 0.009237632730219048, 0.009275931261072401, 0.03557919786544517, 0.0683941702300217, 0.05670007136359345, 0.08569447119953111, 0.0349767594889272, 0.034249284071847796, 0.03175925987306982, 0.0763249458395876, 0.07506175112212077, 0.05215178221988026, 0.0031825502583160414, 0.11611073321546428, 0.018405318041914143, 0.03987041818618309, 0.01086087575458805, 0.04380001962999813, 0.07645232806680724, 0.05842549420776777, 0.03837998156086542, 0.06954740834771655, 0.10710383605328389, 0.2435474266530946, 0.0635178666561842, 0.03960508183808997, 0.5998271447606385, 24.565909802913666, 64.8918767273426, 89.00599837303162, 88.52057442069054, 73.63074660301208, 62.8860479593277, 63.54957975447178, 50.80059885978699, 42.124041840434074, 53.60068380832672, 24.333052597939968, 22.395042590796947, 62.46551312506199, 110.88084697723389, 64.97691616415977, 66.60979494452477, 54.303946271538734, 51.693778932094574, 56.89634196460247, 74.14362028241158, 61.889471635222435, 50.89101880788803, 45.7519655674696, 60.73303408920765, 57.09406055510044, 51.95700980722904, 59.190294072031975, 45.71035020053387, 46.73523120582104, 40.37426993250847, 47.025113850831985, 46.112045645713806, 36.06228791177273, 39.49471592903137, 36.62278063595295, 45.722395554184914, 42.29867286980152, 45.52221469581127, 43.97869952023029, 44.20967012643814, 43.59025776386261, 47.147197499871254, 43.60530115664005, 35.53081043064594, 48.80798578262329, 56.300910115242004, 64.61174815893173, 58.4461610019207, 42.841074764728546, 67.74412527680397, 62.26865328848362, 57.70064100623131, 50.341404899954796, 63.82681667804718, 81.06646880507469, 87.14376389980316, 76.75450578331947, 45.63943460583687, 59.900696352124214, 46.74959823489189, 23.325593657791615, 19.474745392799377, 23.917810879647732, 59.21278886497021, 79.13090586662292, 74.3829694390297, 70.74727892875671, 71.85352876782417, 85.53872242569923, 78.12180161476135, 37.95008361339569, 8.510487880557775, 0.6548181502148509, 0.5563747545238584, 0.04178756003966555, 0.0643469495116733, 0.06472242428571917, 0.09164444723865017, 0.01979049586225301, 0.030591980321332812, 0.041384744545212016, 0.03416811909119133, 0.04565334049402736, 0.00983287227427354, 0.05658197340380866, 0.043757709790952504, 0.04598832740157377, 0.06092545205319766, 0.0482537665811833, 0.036502110451692715, 0.02455889858538285, 0.00894846323717502, 0.09003237631986849, 0.07027728090179153, 0.024305451443069614, 0.07061260548653081, 0.038577121958951466, 0.00875549278134713, 0.05298934782331344, 0.09188692914904095, 0.02733556062594289, 0.02289038176968461, 0.0068554871177184395, 0.03805888023634907, 0.028054339927621186, 0.059161808603676036, 0.07515231540310197, 0.012837813374062534, 0.04036049540445674, 0.0053008510076324455, 0.0687933863082435, 0.007394420845230343, 0.06841313952463679, 0.016006487094273325, 0.03948790043068584, 0.046254008848336525, 0.03507909052132163, 0.016488205874338746, 0.0072037079098663526, 0.06288497796049342, 0.0536253386962926, 0.016462373569083866, 0.03762226733670104, 0.03260970173869282, 0.07709440455073491, 0.041870213026413694, 0.029058235668344423, 0.04788676342286635, 0.049271867028437555, 0.024878105577954557, 0.014050000281713437, 0.05285056249704212, 0.024386518089158926, 0.03205619315849617, 0.023961222941579763, 0.029368735413299873, 0.03320444033306558, 0.04694641778769437, 0.03582057026505936, 0.041274531904491596, 0.06977083190577105, 0.012047874170093564, 0.10274709522491321, 0.043767854949692264, 0.058144287031609565, 0.028585532127181068, 0.044058101484552026, 0.10667744994862005, 0.06493393637356348, 0.006381703287843266, 0.013018994814046891, 0.07743188878521323, 0.06795635505113751, 0.024217018981289584, 0.0652505514153745, 0.07931907384772785, 0.012877655572083313, 0.04594778016326018, 0.040623178574605845, 0.014765271080250386, 0.05533073839615099, 0.0796902590082027, 0.05314840862411074, 0.07766230337438174, 0.037955836742185056, 0.03247322820243426, 0.06103642168454826, 0.06677251818473451, 0.0883079219784122, 0.030313079369079787, 0.03133168262138497, 0.006234551174202352, 0.16854368179338053, 0.03365664204466157, 0.14771618298254907, 2.7719498332589865, 42.28957615792751, 86.16448804736137, 101.08993515372276, 103.41914176940918, 90.9395170211792, 86.45362973213196, 89.36813414096832, 73.45729351043701, 60.34046955406666, 74.42099779844284, 29.310741797089577, 26.305002383887768, 46.22675009071827, 58.52226331830025, 48.45433495938778, 45.04624083638191, 51.42049379646778, 47.636850625276566, 61.196913197636604, 78.64505633711815, 67.96726450324059, 55.7027880102396, 49.28479939699173, 64.73577350378036, 62.74690702557564, 54.53945383429527, 61.496891900897026, 51.56066447496414, 53.4514544159174, 43.6435841023922, 46.536722257733345, 40.86101621389389, 33.58932361006737, 36.16824522614479, 32.07191303372383, 43.026409819722176, 42.34833620488644, 46.19713447988033, 47.71234877407551, 48.97536680102348, 46.94703184068203, 52.111528515815735, 45.80493472516537, 40.557526499032974, 53.999141827225685, 56.67793728411198, 65.64619705080986, 58.519740253686905, 49.038884192705154, 65.45705080032349, 66.70428827404976, 63.00390623509884, 62.55034737288952, 67.64109000563622, 73.68557006120682, 69.8916332423687, 45.33352442085743, 28.19923684000969, 34.507004767656326, 27.278971821069717, 17.562775388360023, 21.576796397566795, 35.92525586485863, 76.36807411909103, 104.34672519564629, 96.95551380515099, 87.81646460294724, 87.02423751354218, 96.92013010382652, 97.18914046883583, 58.72907482087612, 20.781609266996384, 2.1655862079933286, 0.24476104590576142, 0.13930658111348748, 0.1075682275404688, 0.024007714782783296, 0.06224776996532455, 0.023944530184962787, 0.036819048327743076, 0.187898121366743, 0.02371981714532012, 0.06516231005662121, 0.024355418390769046, 0.003976164716732455, 0.055164998266263865, 0.016344886025763117, 0.03824449879175518, 0.0721772234828677, 0.04100603029655758, 0.010559110160102136, 0.03434509533690289, 0.04573267979139928, 0.05476501406519674, 0.029765250073978677, 0.05776979189249687, 0.030344774640980177, 0.030893967632437125, 0.021508502795768436, 0.03725119349837769, 0.05499116872670129, 0.018493624338589143, 0.05077542482467834, 0.022941222596273292, 0.03198175945726689, 0.01620880953851156, 0.027869329933309928, 0.050886067911051214, 0.03599216965085361, 0.03290584092610516, 0.04394908370159101, 0.023059045961417723, 0.10934348931186832, 0.02411671772279078, 0.027298325221636333, 0.01574851656187093, 0.02024321522185346, 0.06700452096993104, 0.022764897585147992, 0.03506203225697391, 0.02606552701763576, 0.015396451908600284, 0.009134888878179481, 0.019902263302356005, 0.03452917022514157, 0.09042569232406095, 0.11589377376367338, 0.12955893151229247, 0.19312698219437152, 0.0824135921720881, 0.1397037340211682, 0.17661370657151565, 0.16890481085283682, 0.13984904653625563, 0.20581539196427912, 0.09871804228168912, 0.08966429333668202, 0.11198782827705145, 0.06422040591132827, 0.12126202476792969, 0.13121415831847116, 0.10828877129824832, 0.26269219466485083, 0.18436315323924646, 0.12853702384745702, 0.1182779305963777, 0.2096668563899584, 0.1779185506165959, 0.13811703713145107, 0.11265076653216965, 0.11304749641567469, 0.21841950860107318, 0.18324334145290777, 0.11555183664313518, 0.12901993934065104, 0.17717281094519421, 0.0792665891640354, 0.12958509963937104, 0.13995698449434713, 0.17373377282638103, 0.2104495104867965, 0.193116606969852, 0.23961070430232212, 0.18439631239743903, 0.16869876097189263, 0.10401276871562004, 0.16291229490889236, 0.21192596876062453, 0.245391812059097, 0.12340810804744251, 0.1618722194689326, 0.17180576222017407, 0.3335415304172784, 0.1852822140790522, 0.3392248973250389, 1.7697501671500504, 43.29489201307297, 93.55267480015755, 112.804524153471, 110.2375490963459, 89.66325670480728, 84.96199697256088, 83.813706189394, 67.61507660150528, 55.34962736070156, 71.63577765226364, 35.96198469400406, 33.45953777432442, 88.66013333201408, 138.89879554510117, 92.4116188287735, 94.11625295877457, 74.1440762579441, 70.57856038212776, 83.62256124615669, 107.29258552193642, 91.19295582175255, 73.86387169361115, 70.98656728863716, 93.69234770536423, 86.38165399432182, 76.1458620429039, 88.1926292181015, 72.69162699580193, 72.98766911029816, 63.59570547938347, 70.82961291074753, 66.43786936998367, 56.202647387981415, 58.06264378130436, 53.65015335381031, 66.81290924549103, 63.39401230216026, 69.93447214365005, 68.64822596311569, 68.62864941358566, 69.00117382407188, 74.91133868694305, 69.81254428625107, 57.820038199424744, 78.24829682707787, 84.9107301235199, 96.99114829301834, 82.34974354505539, 70.51396384835243, 100.69202810525894, 91.27118602395058, 82.87859156727791, 77.68139004707336, 92.69493162631989, 110.28037279844284, 119.36199188232422, 105.79003974795341, 63.64797167479992, 79.0980376303196, 68.50683555006981, 34.83150355517864, 30.001539029181004, 36.69301986694336, 80.77696993947029, 107.39131182432175, 98.3716370165348, 90.86219117045403, 93.22004064917564, 109.3445286154747, 110.59745818376541, 62.014693915843964, 17.464670352637768, 1.3884288724511862, 0.7693839026615024, 0.23285160918021575, 0.22483789856778458, 0.16778807155787945, 0.14356639003381133, 0.12624111579498276, 0.11111230924143456, 0.2512611908605322, 0.0678636014345102, 0.20455059420783073, 0.11147959070513025, 0.1340636788518168, 0.13876178534701467, 0.13897433644160628, 0.11117606714833528, 0.22522014915011823, 0.2933693735394627, 0.1115371442574542, 0.1649098892812617, 0.14961527951527387, 0.14335055864648893, 0.10308030468877405, 0.16223539685597643, 0.10590777601464652, 0.08997180964797735, 0.1846974462387152, 0.28697989764623344, 0.1589961745776236, 0.10430590962641872, 0.1547404919983819, 0.07141152003896423, 0.09749506454681978, 0.1711119432002306, 0.17024928558385, 0.14002955169416964, 0.16117399209178984, 0.08404699983657338, 0.17056775599485263, 0.14479207660770044, 0.33020287519320846, 0.08466851882985793, 0.13520835258532315, 0.08217743335990235, 0.1268404148868285, 0.1779241464100778, 0.05782721927971579, 0.13657084666192532, 0.15629572182660922, 0.1408494616043754, 0.10599429559078999, 0.12825960904592648, 0.17439655523048714], [0.05129164048412349, 0.06103687068389263, 0.03173823111865204, 0.02988709031342296, 0.05564564649830572, 0.01069474043106311, 0.030012160750629846, 0.018957694846903905, 0.020492094445216935, 0.08741215715417638, 0.017053835581464227, 0.06904812107677571, 0.013032062179263448, 0.05553308124945033, 0.13367476378334686, 0.01819778943172423, 0.0547973791253753, 0.041693533639772795, 0.06124599305621814, 0.013725549088121625, 0.06315946870017797, 0.05058169459516648, 0.11344821905368008, 0.0311546432931209, 0.039652594132348895, 0.029012139020778704, 0.008155151899700286, 0.022412332909880206, 0.031895581269054674, 0.03661459777504206, 0.019730192652787082, 0.055303924600593746, 0.04346505869762041, 0.0641584736877121, 0.034699374373303726, 0.029670093754248228, 0.0101326804542623, 0.03817492615780793, 0.051487790115061216, 0.014388803683687001, 0.01592251308466075, 0.010121180876012659, 0.11794582693255506, 0.027794046472990885, 0.058332788830739446, 0.02894023975386517, 0.05010029308323283, 0.19500406662700698, 0.1154144799511414, 10.400176830589771, 55.06051227450371, 85.34325331449509, 81.41519129276276, 76.68456673622131, 66.33665800094604, 54.019523933529854, 50.7673392444849, 42.309703677892685, 41.156058982014656, 40.80355189740658, 30.245957113802433, 51.887595131993294, 52.65320084989071, 42.98006370663643, 92.15257152915001, 95.40258273482323, 59.33833792805672, 53.58066648244858, 52.23547026515007, 41.51081554591656, 27.593482844531536, 20.120786726474762, 10.748325549066067, 7.982650604099035, 6.38428489677608, 7.321209646761417, 10.739596467465162, 12.773102950304747, 20.747071020305157, 16.16734966635704, 6.577408108860254, 3.946989756077528, 1.626076076645404, 0.9024251543451101, 0.5453744635451585, 0.7663390785455704, 0.8402385818772018, 1.9835662376135588, 1.87429906334728, 3.480920777656138, 5.075779035687447, 6.146119851619005, 8.337534461170435, 5.787221034988761, 6.801532432436943, 4.695029966533184, 5.508709754794836, 7.787289312109351, 21.16983823478222, 21.42255697399378, 13.921610321849585, 22.840374894440174, 27.039312981069088, 33.463291972875595, 39.41881500184536, 46.35303631424904, 47.65761271119118, 70.69294944405556, 76.54459744691849, 78.58761101961136, 73.26261475682259, 113.36645320057869, 73.75316843390465, 44.313218370079994, 23.568261936306953, 24.374303184449673, 62.598426192998886, 57.06202067434788, 65.17429277300835, 70.96184581518173, 72.27787479758263, 82.80104532837868, 73.83889183402061, 49.172013849020004, 15.016539618372917, 1.1479978426359594, 0.6371340772602707, 0.027912248333450407, 0.03284553029516246, 0.051746844183071516, 0.05739864755014423, 0.03496969053230714, 0.047773686092114076, 0.060531987619469874, 0.02359263158723479, 0.02821919504640391, 0.04146121544181369, 0.04914661476504989, 0.0408635639178101, 0.04954973825078923, 0.02010104199143825, 0.05523370629816782, 0.04489837592700496, 0.009345552134618629, 0.04919851686281618, 0.046976244702818803, 0.027209770305489656, 0.0787542549369391, 0.03298145464214031, 0.08595751802204177, 0.0346165618248051, 0.041015949100255966, 0.015046353018988157, 0.03765336332435254, 0.05313808534992859, 0.01449617482649046, 0.01471399053116329, 0.02799190489895409, 0.01016873120534001, 0.05260562407784164, 0.0068508152980939485, 0.01948621531482786, 0.0754088164831046, 0.1039723661961034, 0.02354823074711021, 0.00928503648538026, 0.04196920068352483, 0.04478341725189239, 0.03558684569725301, 0.0182773829146754, 0.050789143424481153, 0.010488812076800968, 0.04790620027051773, 0.03855318027490284, 0.06422111095162109, 0.014150516763038468, 0.053614956050296314, 0.04384077838039957, 0.025834433363343123, 0.06895608734339476, 0.01772381681803381, 0.05117245156725403, 0.12917150073917583, 0.04938831742038019, 0.024821186561894137, 0.06939915692782961, 0.034380852011963725, 0.041561346006346866, 0.04879054344200995, 0.02201244333264185, 0.06242384450160898, 0.03854100163152907, 0.0743615347892046, 0.030903552469681017, 0.09179810149362311, 0.08645406676805578, 0.06504445700556971, 0.048811468295753, 0.06420362595235929, 0.040857307612895966, 0.031205224368022755, 0.05714770515623968, 0.07642284996109083, 0.009818230628297897, 0.08562940711271949, 0.021843339418410324, 0.05391430502641015, 0.035944846604252234, 0.027696055149135645, 0.006204155124578392, 0.015189193254627753, 0.03827874519629404, 0.09855189025984146, 0.041749602896743454, 0.04693648043030407, 0.029048368814983405, 0.058155497172265314, 0.0778794706275221, 0.10399011836852878, 0.049093076231656596, 0.0313608675787691, 0.17244604270672426, 0.02806108233926352, 0.37550742854364216, 0.6593410356435925, 19.280285127460957, 76.56459197402, 100.43385475873947, 97.26187616586685, 93.27429413795471, 86.20056331157684, 86.59243628382683, 78.33041802048683, 59.95384410023689, 56.27797454595566, 27.46506493538618, 30.834551230072975, 36.205984801054, 24.676466770470142, 42.29444369673729, 81.82249903678894, 91.7707984149456, 61.042808666825294, 59.99662600457668, 55.92340797185898, 45.624486207962036, 27.777318879961967, 19.235759116709232, 9.238153584301472, 6.614718306809664, 4.950750069692731, 5.031534684821963, 8.897507563233376, 11.318696793168783, 20.83690769970417, 15.034346412867308, 5.547416852787137, 2.527641705237329, 0.8416354819200933, 0.6215456512290984, 0.06577432213816792, 0.5057452025357634, 0.224035874416586, 1.025576724205166, 1.3100804015994072, 3.637542435899377, 3.6975243547931314, 5.636780457571149, 7.170337792485952, 5.158502496778965, 6.760045783594251, 2.956497143022716, 3.395132781006396, 5.293319262564182, 17.428893372416496, 19.191941767930984, 13.339833989739418, 20.524473264813423, 23.482855819165707, 31.00750844925642, 38.46199594438076, 52.065205201506615, 55.93213230371475, 67.29825720191002, 64.98599007725716, 60.527123138308525, 52.22086384892464, 73.85196313261986, 49.019676223397255, 28.24927255511284, 28.30242410302162, 43.79798121750355, 92.05452919006348, 85.9098333120346, 85.98887667059898, 88.85228142142296, 85.71693286299706, 93.83618518710136, 92.8133636713028, 72.06155240535736, 27.158892564475536, 2.9839625442400575, 0.38711224333383143, 0.0584653475380037, 0.030083963538345415, 0.05395897118432913, 0.0540617363731144, 0.02648928220878588, 0.024552226677769795, 0.09137441680650227, 0.005141145002198755, 0.02838813939888496, 0.06342098669847474, 0.027840191360155586, 0.02936042335932143, 0.03976494415837806, 0.0418403564253822, 0.012770501507475274, 0.07720385649008676, 0.021129205961187836, 0.045637966904905625, 0.03153063385980204, 0.05390011516283266, 0.03407442294701468, 0.01967453343240777, 0.04276052306522615, 0.029796579838148318, 0.031819462892599404, 0.052906431374140084, 0.09984465956222266, 0.01813510763895465, 0.02255201994557865, 0.021128990738361608, 0.03291170018201228, 0.04133029688091483, 0.03642679730546661, 0.014813808465987677, 0.005195792582526337, 0.038334729106281884, 0.008630977099528536, 0.02436759703414282, 0.013316830736584961, 0.0244754941741121, 0.005200905052333837, 0.058502295360085554, 0.022611514214077033, 0.01415264301613206, 0.04148620355408639, 0.04373203519207891, 0.007215475125121884, 0.02769030907074921, 0.03143867805192713, 0.14920712797902524, 0.1118546053476166, 0.1242834044387564, 0.16690642980393022, 0.08805467892671004, 0.18523278704378754, 0.18555376591393724, 0.17536859057145193, 0.14281780051533133, 0.25964407541323453, 0.11351970271789469, 0.1556768300361, 0.1732448162510991, 0.15323801402701065, 0.18832518282579258, 0.1332938639097847, 0.2887951908633113, 0.11881360536790453, 0.365208734292537, 0.152317424362991, 0.13210969307692721, 0.1567541464464739, 0.20999991742428392, 0.10374808174674399, 0.07257426506839693, 0.14295836328528821, 0.16721795371267945, 0.08340372849488631, 0.1127323582477402, 0.0807550479657948, 0.19415659335209057, 0.14380274922586977, 0.11270453513134271, 0.19879391795257106, 0.2224885261966847, 0.1344788956339471, 0.18809162895195186, 0.176625803578645, 0.14182666229316965, 0.1262381175183691, 0.1562027307227254, 0.12225229467730969, 0.1811751539935358, 0.15415370551636443, 0.2406962140230462, 0.18231218360597268, 0.18546371371485293, 0.6066534190904349, 0.45334699389059097, 17.806526608765125, 82.24268049001694, 111.49722710251808, 100.55296316742897, 97.57421940565109, 85.14644667506218, 75.3312237560749, 67.58768007159233, 54.169102907180786, 55.92868588864803, 58.0065093934536, 42.340326234698296, 76.38648793101311, 75.03207340836525, 61.569232419133186, 118.08693990111351, 119.38150763511658, 84.10581171512604, 81.57577827572823, 80.25378361344337, 65.52867695689201, 44.45593871176243, 33.89553777873516, 20.58974426239729, 15.906276125460863, 12.294673472642899, 14.567064587026834, 21.687613651156425, 23.298402316868305, 32.403699830174446, 26.964337304234505, 12.448701057583094, 7.473619943484664, 3.8134402222931385, 2.402389501221478, 1.5094623528420925, 1.6714294929988682, 1.9689198047854006, 4.804327301681042, 5.984781933948398, 7.29833297431469, 10.237421113997698, 12.880381643772125, 15.671598818153143, 12.292996812611818, 14.500689748674631, 9.395162109285593, 9.928702879697084, 13.975897058844566, 31.42157793045044, 31.1203395947814, 24.088229835033417, 38.281433433294296, 43.77297855913639, 53.67630735039711, 61.72400191426277, 75.2422097325325, 74.04104858636856, 106.93332999944687, 111.21943160891533, 110.71984961628914, 94.48403522372246, 135.99099397659302, 99.93004739284515, 64.78119626641273, 39.21019099652767, 39.240224584937096, 81.80037662386894, 76.9126532971859, 84.79096814990044, 89.85642313957214, 91.01014003157616, 104.76705104112625, 104.2807987332344, 75.66314354538918, 26.862422972917557, 2.3944545770063996, 0.7297652692068368, 0.17043503030436113, 0.15478876128327101, 0.12353285565041006, 0.228692346427124, 0.12372338722343557, 0.17929728288436309, 0.15948793647112325, 0.12099742685677484, 0.28104716911911964, 0.18568315193988383, 0.16385774652007967, 0.1313157138065435, 0.11331132249324583, 0.16269771032966673, 0.20426415489055216, 0.20775858691195026, 0.13104442914482206, 0.11006411470589228, 0.1594929682323709, 0.11768235708586872, 0.13040769612416625, 0.1641105517046526, 0.14961480454076082, 0.10720349906478077, 0.165030577336438, 0.18792491289786994, 0.13237866223789752, 0.11538379214471206, 0.11173493403475732, 0.10499559488380328, 0.13842467218637466, 0.08317321742651984, 0.15711540909251198, 0.06265926116611809, 0.1408972856006585, 0.15896148659521714, 0.16235804418101907, 0.1369880375568755, 0.12066659226547927, 0.20541019417578354, 0.10315276056644507, 0.2091313077835366, 0.233028611401096, 0.11050174434785731, 0.13463706214679405, 0.12455926073016599, 0.07626477250596508, 0.24193549674237147, 0.1581951745902188], [0.03675772837596014, 0.041333343397127464, 0.018919207068393007, 0.06060228013666347, 0.00805480054623331, 0.026723953014879953, 0.020261535137251485, 0.06610815500607714, 0.016303882366628386, 0.020817520635318942, 0.016288903971144464, 0.05417441665485967, 0.04968423025275115, 0.013969478186481865, 0.07986306067323312, 0.058906172125716694, 0.07902602199465036, 0.06555347383255139, 0.056800064630806446, 0.028943789075128734, 0.034626766355358995, 0.02631482740980573, 0.019244909708504565, 0.050372698387946, 0.04543398390524089, 0.00472369157250796, 0.04026901828183327, 0.08015439074370079, 0.04806836324860342, 0.0497159348014975, 0.04167984843661543, 0.07109212936484255, 0.03209622089343611, 0.07512616211897694, 0.0184100195474457, 0.016598260808677878, 0.028316316202108283, 0.020595225141732953, 0.07542078732512891, 0.03380768765055109, 0.10899999368120916, 0.10328305943403393, 0.08433168768533505, 0.06956843339139596, 0.04303507688746322, 0.08785990226897411, 0.047993228217819706, 5.610397048294544, 36.63034223020077, 80.00691846013069, 80.66093176603317, 76.51175200939178, 75.70113390684128, 54.62219059467316, 49.91531476378441, 24.527241177856922, 28.461607061326504, 29.13603287190199, 34.918819069862366, 67.24167823791504, 50.51390804350376, 58.6724616587162, 81.35404497385025, 60.34705460071564, 41.712569519877434, 38.7184289842844, 24.63055193424225, 18.239828757941723, 7.984092626720667, 2.581696417182684, 1.2809730134904385, 0.13249650044599548, 0.12120872372179292, 0.3862132056383416, 0.08125517386361025, 0.1761484838789329, 0.12368740048259497, 0.5297938152216375, 0.5861808895133436, 0.3392883064225316, 0.14959601336158812, 0.0829666703066323, 0.05427658812550362, 0.05996864929329604, 0.021754977460659575, 0.0847116153454408, 0.129876674618572, 0.11891456713783555, 0.021064024986117147, 0.05560952617088333, 0.04864681541221216, 0.16608322475804016, 0.12319173489231616, 0.18419372092466801, 0.14849900035187602, 0.3410875395638868, 0.07063187906169333, 0.030294831813080236, 0.10008826211560518, 0.7870326493866742, 1.41019327333197, 0.6008102232590318, 0.6319281784817576, 0.8044727041851729, 1.8258211459033191, 8.303829319775105, 19.176311306655407, 35.6007494777441, 53.324241042137146, 59.872760251164436, 53.913209438323975, 65.58009579777718, 81.88921585679054, 62.525956481695175, 45.658570379018784, 36.02986045181751, 19.890441186726093, 18.787046894431114, 39.00333769619465, 57.58528299629688, 60.34421235322952, 60.019196793437004, 67.93283075094223, 74.6287402510643, 77.44793817400932, 44.41292122006416, 10.749479737132788, 0.9004562662448734, 0.2800393622601405, 0.0745659222593531, 0.0821644086681772, 0.11900637080543675, 0.033532128218212165, 0.04158013718551956, 0.08207558843423612, 0.06682814957457595, 0.0949816923821345, 0.04313895529776346, 0.036705173188238405, 0.031414988698088564, 0.07021725599770434, 0.0042393015246489085, 0.052617795299738646, 0.03456197686318774, 0.008660589719511336, 0.02581193701189477, 0.0944559698109515, 0.06823749543400481, 0.017962148267542943, 0.06115835283708293, 0.01474151586080552, 0.05055791618360672, 0.038410457855206914, 0.05652188541716896, 0.05342128519259859, 0.04521705413935706, 0.03691222496854607, 0.026638049421308096, 0.007146086636566906, 0.02467738802806707, 0.10080336593091488, 0.03248994878958911, 0.009650777064962313, 0.03659027017420158, 0.04445374041097239, 0.014283253585745115, 0.07496314196032472, 0.08922652268665843, 0.05323193734511733, 0.032545097783440724, 0.030252128635765985, 0.022688057470077183, 0.007289970981219085, 0.020769735601788852, 0.011305423140584026, 0.06260463909711689, 0.02888055438234005, 0.06190429659909569, 0.0863999270950444, 0.028557699733937625, 0.022362297313520685, 0.04716462404758204, 0.04571561781631317, 0.013970541313028662, 0.03261627345636953, 0.024855831870809197, 0.07031234737951308, 0.019892110722139478, 0.09662705604569055, 0.025486722333880607, 0.03746072034118697, 0.05055715548223816, 0.04129381290113088, 0.036945933316019364, 0.0418476368940901, 0.00646427649371617, 0.05435511106043123, 0.06633430224610493, 0.05164849848370068, 0.02743364286288852, 0.031893343693809584, 0.04677017997892108, 0.05553589027840644, 0.03127049254544545, 0.05394852545578033, 0.06557464730576612, 0.03543354767316487, 0.042016805746243335, 0.06474687063018791, 0.055119244861998595, 0.02373141691350611, 0.05757857012213208, 0.04886141112365294, 0.04328277980675921, 0.022278534815995954, 0.11177939610206522, 0.10368138493504375, 0.02818288361595478, 0.03649590980785433, 0.045406580102280714, 0.07734278653515503, 0.2715596422785893, 0.18789755733450875, 11.921647489070892, 52.66107402741909, 99.07407492399216, 90.21344438195229, 96.26971140503883, 95.39208009839058, 86.60404086112976, 73.47747802734375, 33.40743497014046, 36.16921417415142, 22.85095352679491, 15.249733105301857, 38.1938861310482, 24.772149436175823, 38.717832416296005, 73.97053956985474, 62.39189587533474, 46.15705423057079, 37.254314348101616, 23.49503606557846, 14.347101040184498, 5.502038262784481, 1.1208896222524345, 0.8618780644610524, 0.1335940181161277, 0.11037686315830797, 0.5928645527455956, 0.10126829176442698, 0.12005544849671423, 0.10698987927753478, 0.3904883028008044, 0.09239294027793221, 0.6620860914699733, 0.1474365862668492, 0.2837823989102617, 0.13033008232014254, 0.25480363983660936, 0.20755883044330403, 0.05682471135514788, 0.27728804270736873, 0.18612131592817605, 0.19248134340159595, 0.1715837710071355, 0.10391271236585453, 0.17068079992895946, 0.0620499876094982, 0.22084643540438265, 0.09136691369349137, 0.3191417281050235, 0.12043834474752657, 0.0770375931460876, 0.12916158564621583, 0.19278817693702877, 0.7768529956229031, 0.27274108200799674, 0.317735803546384, 0.15614646108588204, 0.5281474348157644, 6.09772564843297, 17.449127286672592, 32.00475163757801, 52.22653314471245, 59.680323377251625, 56.89104504883289, 68.3161997795105, 78.40677872300148, 56.65644943714142, 43.58662895858288, 25.113753005862236, 24.001790173351765, 27.334158159792423, 59.41406026482582, 91.28253221511841, 87.81848609447479, 80.68142026662827, 84.56307917833328, 86.45868346095085, 92.94906198978424, 65.75030386447906, 21.98486790060997, 1.3894466240890324, 0.18044529628241435, 0.12798085837857798, 0.026130394435313065, 0.08861403563059866, 0.018613362444739323, 0.0684363093751017, 0.01238246773937135, 0.060248112422414124, 0.05455673031974584, 0.052939779779990204, 0.03663941519334912, 0.02687729000172112, 0.14998060913057998, 0.004517669058259344, 0.06775760790333152, 0.02985541916132206, 0.03790305148868356, 0.011555190158105688, 0.03636353663750924, 0.024750239099375904, 0.022660026552330237, 0.00902101373867481, 0.05208406124438625, 0.05944460768660065, 0.02907341629907023, 0.03363882678968366, 0.003731156489266141, 0.016428830349468626, 0.06616250248043798, 0.0561936594749568, 0.0773635295627173, 0.043691758837667294, 0.027718798264686484, 0.026321089280827437, 0.019551255281839985, 0.07186251576058567, 0.09982238771044649, 0.024827954948705155, 0.04298231018765364, 0.036603187254513614, 0.035057360437349416, 0.1033933054713998, 0.01696262748737354, 0.024382991032325663, 0.04408388369483873, 0.048550236024311744, 0.006709864755976014, 0.03152052580844611, 0.1373630596208386, 0.2512533834669739, 0.1450635096989572, 0.1430939239799045, 0.12718285666778684, 0.13999124203110114, 0.109442491811933, 0.16487880813656375, 0.13411841966444626, 0.15872894204221666, 0.1324644693522714, 0.1513026561588049, 0.18155817640945315, 0.1629281768691726, 0.11493746453197673, 0.145616855006665, 0.13863496715202928, 0.10310153753380291, 0.14635763713158667, 0.12965937377884984, 0.16707796981791034, 0.12418864702340215, 0.12110077834222466, 0.06172219953441527, 0.1069767506851349, 0.17264510155655444, 0.12152203620644286, 0.14974867313867435, 0.10817819129442796, 0.1930797370732762, 0.17862087464891374, 0.1152201188961044, 0.1985794075881131, 0.14645448740338907, 0.08127456618240103, 0.09428273027879186, 0.09601842073607258, 0.10228889324935153, 0.13210308796260506, 0.20847611012868583, 0.28644255304243416, 0.15779512730659917, 0.14383997535333037, 0.09927113525918685, 0.16491239774040878, 0.4339121945668012, 0.22422086214646697, 10.440693106502295, 54.81848806142807, 109.8364806175232, 101.97181463241577, 95.75023368000984, 96.79578557610512, 72.92985901236534, 68.06925863027573, 36.10309772193432, 42.2956558316946, 44.63825672864914, 49.11201886832714, 88.2456211745739, 70.25527372956276, 83.56633186340332, 114.24191102385521, 92.50321671366692, 64.66312140226364, 61.84023767709732, 40.89499779045582, 29.472425021231174, 12.151654846966267, 4.762245984748006, 3.6338357347995043, 1.0575079545378685, 0.25795414578169584, 0.6531388778239489, 0.2574821695452556, 0.40123284969013184, 0.5462123185861856, 1.0964593081735075, 1.2486756965517998, 1.313035455532372, 0.3847668191883713, 0.7698850007727742, 0.4023738275282085, 0.41075971035752445, 0.32911794434767216, 0.33394071680959314, 0.3643112996360287, 0.3011895914096385, 0.47122945776209235, 0.4041209619026631, 0.27308828837703913, 0.5819125904235989, 0.6013449851889163, 0.5838021577801555, 0.24881671968614683, 0.5912570608779788, 0.4766452655894682, 0.2225281420396641, 0.35482092294842005, 1.2286004237830639, 2.586135766468942, 1.8339354917407036, 1.5962530206888914, 3.1745771784335375, 3.714478095062077, 14.535299241542816, 33.1662543118, 55.60695715248585, 79.0255831182003, 94.4160720705986, 81.21374890208244, 90.43390095233917, 100.83683833479881, 90.95773324370384, 67.03578248620033, 53.34471434354782, 32.799410596489906, 30.351021476089954, 54.87733170390129, 77.58541479706764, 80.87584063410759, 79.4124099612236, 85.8685827255249, 95.03402531147003, 103.30371156334877, 70.6112614274025, 19.518990218639374, 1.064859728794545, 0.3645171714015305, 0.2688288950594142, 0.17561962944455445, 0.2528273599455133, 0.09958871509297751, 0.1180115070019383, 0.19373092713067308, 0.17881148785818368, 0.21400509547675028, 0.13749216363066807, 0.15898415178526193, 0.06660616578301415, 0.304309461498633, 0.10968368238536641, 0.0885011327045504, 0.08924617475713603, 0.09285143911256455, 0.2047141783987172, 0.17795665247831494, 0.20572862005792558, 0.10156551448744722, 0.15405137819470838, 0.1316229481017217, 0.162506963533815, 0.09902609293931164, 0.08310432385769673, 0.16108451876789331, 0.09546286382828839, 0.074644070409704, 0.09733355094795115, 0.17732186388457194, 0.10566982862656005, 0.14996426703874022, 0.08685225868248381, 0.11336978146573529, 0.14161854924168438, 0.1811909765820019, 0.1856284259702079, 0.10314377315808088, 0.12698894832283258, 0.10300808629835956, 0.16641184774925932, 0.09684918826678768, 0.15351897629443556, 0.18104925606166944, 0.17643766914261505, 0.09494318976067007, 0.10491764711332507], [0.01341575623882818, 0.008584528859501006, 0.026725505958893336, 0.025087608300964348, 0.008585994601162383, 0.03427165611356031, 0.06595617058337666, 0.0543858137098141, 0.05925903737079352, 0.05234280732111074, 0.044568840094143525, 0.03738946674275212, 0.04623226763214916, 0.045678866663365625, 0.02356864537432557, 0.0527228648570599, 0.06473613175330684, 0.051722386706387624, 0.054962002323009074, 0.02948427110823104, 0.0682776010944508, 0.06771291577024385, 0.021170502768654842, 0.061571955448016524, 0.014353010828926926, 0.027253067200945225, 0.05943838848907035, 0.010444413092045579, 0.12345871509751305, 0.04517399473115802, 0.07386500830762088, 0.0479024450032739, 0.046521887052222155, 0.04481761912757065, 0.07987082353793085, 0.09171403842628933, 0.020375421408971306, 0.03873195622873027, 0.057387793640373275, 0.026271409915352706, 0.026263982872478664, 0.04298206156818196, 0.37233171926345676, 0.09256636534701101, 0.35501851234585047, 6.2858716025948524, 34.94780391454697, 69.80103850364685, 83.72596129775047, 79.2052374780178, 83.22791442275047, 59.142196252942085, 60.81540606915951, 28.873233273625374, 23.350864201784134, 61.19342878460884, 48.10567706823349, 60.66328503191471, 97.22963869571686, 55.77625326812267, 63.205857798457146, 62.83040374517441, 28.8894622027874, 19.948323480784893, 8.0018718726933, 2.3438187316060066, 0.27471572917420417, 0.13416241417871788, 0.2172335862996988, 0.1091596222249791, 0.044025246606906876, 0.056349284132011235, 0.033498861448606476, 0.29493678943254054, 0.12786782928742468, 0.052155667362967506, 0.1311643750523217, 0.10317524764104746, 0.08425081585301086, 0.09272514784242958, 0.05930102808633819, 0.35411416087299585, 0.1683047102415003, 0.18076385575113818, 0.04617468068317976, 0.20495721691986546, 0.10683882996090688, 0.16882218013051897, 0.27461874531582, 0.7129765825811774, 0.1655619847588241, 0.2166011874214746, 0.10719146885094233, 0.0839853347861208, 0.11775159204262309, 0.008084077344392426, 0.0885467896296177, 0.07282878461410291, 0.1151742615911644, 0.15526029223110527, 0.03750552379642613, 0.05750683783844579, 0.11663364304695278, 0.105965344409924, 0.06856221472844481, 0.11950427026022226, 0.04988267312000971, 0.3725032147485763, 2.9418375296518207, 8.276711124926805, 19.294173382222652, 32.622537687420845, 45.43934494256973, 42.98651956021786, 39.72945973277092, 62.338280752301216, 66.61253839731216, 53.968321681022644, 24.727423936128616, 17.85120841115713, 30.971815064549446, 49.72888916730881, 41.98932006955147, 63.166187927126884, 63.0605535954237, 81.7873965203762, 68.82097229361534, 32.789694517850876, 7.754438174888492, 0.49199148430489004, 0.23551591933937743, 0.050443989093764685, 0.04891357668384444, 0.052795524825342, 0.05043074175773654, 0.036858281964669004, 0.013281443279993255, 0.011969256611337187, 0.024172046687453985, 0.020996845778427087, 0.08071969947195612, 0.04156548347964417, 0.08816027169814333, 0.04996437615773175, 0.01743223812809447, 0.07164243186707608, 0.09510287767625414, 0.024997958716994617, 0.036874876386718825, 0.04896676640782971, 0.04231077786243986, 0.03297358787676785, 0.04602252185577527, 0.03218541220121551, 0.032762357805040665, 0.02551546014728956, 0.029693651376874186, 0.04392360948259011, 0.0305877556456835, 0.01990312975976849, 0.10050812474219128, 0.02697829815588193, 0.10075045822304673, 0.04484606564801652, 0.043609421263681725, 0.016199901911022607, 0.0696112478908617, 0.03813154391536955, 0.030252228825702332, 0.08679158068844117, 0.09886584841297008, 0.0189302520811907, 0.07974853986524977, 0.024083799762593117, 0.04425609535246622, 0.0280357899464434, 0.010298692395735998, 0.013696347432414768, 0.08069033268839121, 0.036624178901547566, 0.0484168127150042, 0.06128121167421341, 0.04788142738107126, 0.015920039877528325, 0.0800063471251633, 0.014228447835193947, 0.06892379649798386, 0.019006721122423187, 0.08632923010736704, 0.01672593247349141, 0.013846353103872389, 0.03598065894038882, 0.0410915887914598, 0.03589520805689972, 0.03959318150009494, 0.09552909308695234, 0.10392818614491262, 0.07545384258264676, 0.011377352093404625, 0.032078576332423836, 0.038649462803732604, 0.020475360870477743, 0.05288537664455362, 0.016100702741823625, 0.048864568962017074, 0.05046940023021307, 0.021613320022879634, 0.04406852494867053, 0.02716442322707735, 0.04035892947285902, 0.027518791321199387, 0.0696720668929629, 0.07308890737476759, 0.015650885179638863, 0.1796080349595286, 0.013546034697355935, 0.07699972877162509, 0.042435362192918546, 0.448473755386658, 0.21868286712560803, 0.9641099162399769, 11.957796849310398, 51.665208265185356, 87.24445089697838, 96.64500206708908, 90.67242175340652, 105.89115232229233, 78.69762271642685, 87.85388499498367, 46.320867240428925, 32.89815969765186, 45.53028166294098, 23.768666982650757, 36.98851481080055, 61.28398172557354, 47.59232081472874, 58.77083458006382, 65.63507124781609, 29.202540703117847, 17.475963346660137, 5.392293501645327, 1.3712780177593231, 0.2235796465538442, 0.203603821573779, 0.3484617860522121, 0.17268925934331492, 0.018017540314758662, 0.11143207841087133, 0.1137587484845426, 0.3206623886944726, 0.023375883647531737, 0.21877919789403677, 0.15565125562716275, 0.09852994495304301, 0.03989949924289249, 0.22694556828355417, 0.08439671466476284, 0.41870505432598293, 0.1507797685917467, 0.25723485625348985, 0.040667395733180456, 0.21466836769832298, 0.0366911206219811, 0.32413534296210855, 0.2827311318833381, 0.384472394362092, 0.11196139297680929, 0.2824039338156581, 0.17464259202824906, 0.24980955000501126, 0.22404086164897308, 0.09658314316766337, 0.2132631407584995, 0.26746292773168534, 0.26134970888961107, 0.18542696256190538, 0.06420974124921486, 0.10464052174938843, 0.10411492534331046, 0.10377960818004794, 0.05886458216991741, 0.014966609251132468, 0.2669367747148499, 0.2222536809858866, 1.2749860784970224, 6.166254496201873, 15.782611761242151, 32.79816426336765, 45.065699592232704, 45.035308822989464, 41.10262244939804, 53.720267191529274, 41.92888431251049, 34.74094681441784, 29.459245428442955, 33.922759518027306, 48.92409235239029, 74.5658004283905, 68.3752790093422, 88.78187879920006, 80.54395124316216, 91.1109334230423, 89.5558212697506, 50.07413104176521, 16.22773602604866, 0.6376842164900154, 0.30678639421239495, 0.10786044076667167, 0.01618484744540183, 0.047074078320292756, 0.061796239897375926, 0.03395033585547935, 0.03485758541501127, 0.019583525718189776, 0.04406332620419562, 0.04399154568091035, 0.09616016352083534, 0.014891463088133605, 0.0344859846518375, 0.01467027339458582, 0.04022769549919758, 0.15455603861482814, 0.02744628905929858, 0.0715004070661962, 0.013340590594452806, 0.02172831580537604, 0.024493893870385364, 0.02786890876450343, 0.05383310664910823, 0.06179350508318748, 0.046651002194266766, 0.04249326455465052, 0.09231238014763221, 0.08311177502037026, 0.02415090104477713, 0.031351850484497845, 0.056096816624631174, 0.016673295649525244, 0.01856003171269549, 0.07718421926256269, 0.11038368349545635, 0.040930064060376026, 0.026946756879624445, 0.02750356616161298, 0.0500951648427872, 0.0009718501519273559, 0.024041634642344434, 0.003563497211871436, 0.02212857645645272, 0.008747629726713058, 0.031881398826953955, 0.01895667995995609, 0.10966449044644833, 0.14764970139367506, 0.19062207051320001, 0.14232709247153252, 0.11940782816964202, 0.11621318670222536, 0.14847116981400177, 0.18998352665221319, 0.14740100770723075, 0.1095886058465112, 0.09377596958074719, 0.10361927459598519, 0.1715828210581094, 0.1424288409180008, 0.18050808197585866, 0.13719456241233274, 0.18103908863849938, 0.16124195797601715, 0.14802512421738356, 0.20535641815513372, 0.19859839172568172, 0.180453029461205, 0.12929368793265894, 0.14498758799163625, 0.1784366142237559, 0.14259484451031312, 0.24466471513733268, 0.13073508715024218, 0.2173220057738945, 0.1569104427471757, 0.17922762490343302, 0.13266689755255356, 0.10523063305299729, 0.2037387143354863, 0.12871717277448624, 0.20964951982023194, 0.14495113369775936, 0.11005117165041156, 0.2803367853630334, 0.09667699516285211, 0.22609003528486937, 0.14252091175876558, 0.5653608567081392, 0.25352661148644984, 0.8425845997408032, 10.776995960623026, 52.87564471364021, 95.66061928868294, 108.98143529891968, 98.39544653892517, 105.66487446427345, 76.54605656862259, 76.26850426197052, 40.05470708012581, 34.752699583768845, 89.66709449887276, 66.52074292302132, 82.77213647961617, 132.86208987236023, 75.98091289401054, 93.1775513291359, 93.2189767062664, 44.98820275068283, 32.23509527742863, 13.507806826382875, 4.273861041292548, 1.0360942035913467, 0.4783678794046864, 0.3860965993953869, 0.28239511710125953, 0.05390210782934446, 0.23172600864199921, 0.24016884388402104, 0.9670999401714653, 0.408519611810334, 0.4774395120330155, 0.2874314202927053, 0.28695718792732805, 0.1854092549183406, 0.3621446737088263, 0.4946862522047013, 0.7290585665032268, 0.5555474082939327, 0.5907861236482859, 0.26585561397951096, 0.7371395453810692, 0.5747750296723098, 0.7233193900901824, 1.0050058155320585, 2.5486721517518163, 0.3852165903663263, 0.8323333435691893, 0.5300546356011182, 0.5774146411567926, 0.4732439434155822, 0.36898843303788453, 0.509326154133305, 0.5248286097776145, 0.5203384975902736, 0.4073460685322061, 0.15490049903746694, 0.21702495374483988, 0.2903225307818502, 0.25656012527178973, 0.1981921846163459, 0.25689201371278614, 0.4290609830059111, 1.1621361714787781, 4.14298846386373, 15.245765168219805, 31.672881245613098, 53.736826702952385, 69.11357179284096, 62.69804544746876, 61.574647128582, 89.0582911670208, 95.487280189991, 73.60145777463913, 36.58197082579136, 28.607068955898285, 41.828250512480736, 68.12536641955376, 61.06995441019535, 85.746730864048, 82.66822725534439, 99.88299831748009, 99.79766249656677, 53.903082981705666, 13.368375208228827, 0.502537046559155, 0.4023517412133515, 0.20459378720261157, 0.13995981949847192, 0.17569376999745145, 0.1997297810157761, 0.1301496959058568, 0.1350960211129859, 0.06687667861115187, 0.15156291250605136, 0.14468928915448487, 0.18634743348229676, 0.11459110421128571, 0.1958488384843804, 0.11493615835206583, 0.13727686658967286, 0.2254955007811077, 0.17013076459988952, 0.14288759208284318, 0.1482563477475196, 0.07840524514904246, 0.15781832684297115, 0.12184333420009352, 0.11246388632571325, 0.16524015984032303, 0.1457948368624784, 0.0794883725757245, 0.14026540622580796, 0.09671260340837762, 0.11225933558307588, 0.10252717460389249, 0.15565227979095653, 0.0898338740807958, 0.1927806664025411, 0.22684613533783704, 0.15650928224204108, 0.0942889197904151, 0.16725653054891154, 0.21072471368825063, 0.14522357610985637, 0.23679838021053, 0.10791351174702868, 0.07118129098671488, 0.21531535719987005, 0.21382674254709855, 0.11162217953824438, 0.18037643982097507], [0.02636326738866046, 0.08420498823397793, 0.02822728260071017, 0.06645666755503044, 0.03693960279633757, 0.018711823177000042, 0.03965899515605997, 0.06992474591243081, 0.04263466595148202, 0.07311903114896268, 0.0314148922188906, 0.06876790837850422, 0.04829135265026707, 0.008624853453511605, 0.05025842991017271, 0.032524603375350125, 0.05886965474928729, 0.06514694017823786, 0.019949348861700855, 0.037334699954953976, 0.003940460919693578, 0.05433901758806314, 0.01732696076942375, 0.08678965852595866, 0.026197601473541, 0.021526954442379065, 0.009818047874432523, 0.008993840001494391, 0.043654016917571425, 0.03034467630641302, 0.09780936408787966, 0.08764402635279112, 0.04933121286740061, 0.05410666228272021, 0.028706405719276518, 0.015107900253497064, 0.04339071405411232, 0.06274181767366827, 0.039867074810899794, 0.03161391396133695, 0.06704171741148457, 0.037303425851860084, 0.3200533823110163, 1.7853146069683135, 36.121093556284904, 78.97823005914688, 82.88547679781914, 81.44516408443451, 64.5009309053421, 68.60837370157242, 44.61989611387253, 61.540015786886215, 25.841904133558273, 47.510537803173065, 50.62568284571171, 37.874300479888916, 55.730249136686325, 63.322351947426796, 45.31029626727104, 39.15881395339966, 31.073001734912395, 8.917593285441399, 2.9072004882618785, 0.023591922836203594, 0.14985138637712225, 0.04910203395411372, 0.05342220545571763, 0.021319231018424034, 0.2021156225237064, 0.030350312918017153, 0.10349296106141992, 0.026317335868952796, 0.012203432033857098, 0.13462373317452148, 0.03123221998976078, 0.032405221500084735, 0.058791128103621304, 0.25615238933824, 0.09759287961060181, 0.151878904143814, 0.09170724777504802, 0.1813645797665231, 0.12110708659747615, 0.11008405621396378, 0.1533692702651024, 0.1745856396155432, 0.11150533580803312, 0.23852474929299206, 0.12080759290256537, 0.24196101177949458, 0.13986112870043144, 0.02124275270034559, 0.12124960121582262, 0.1648373666102998, 0.06258265668293461, 0.2413283011992462, 0.05493848366313614, 0.09652938198996708, 0.017217835375049617, 0.1415619530598633, 0.1734241785015911, 0.07170535114710219, 0.1647989233606495, 0.16112147772219032, 0.12095900587155484, 0.034400062504573725, 0.05064541910542175, 0.04032470162201207, 0.03979812558100093, 0.08722454964299686, 0.030424325450439937, 2.3456070106476545, 13.152207657694817, 27.012760005891323, 52.70028792321682, 42.8119645267725, 48.172131702303886, 54.422876089811325, 59.24721881747246, 46.625664085149765, 31.966700479388237, 26.639937311410904, 29.19853761792183, 30.985424034297466, 53.12762439250946, 59.82295252382755, 66.48243337869644, 76.24836534261703, 74.51478436589241, 38.45797955989838, 5.318169454112649, 0.32677275768946856, 0.11994457905529998, 0.0728813954629004, 0.06534789150464348, 0.046640983200632036, 0.06476198075688444, 0.03607395803555846, 0.07177519466495141, 0.049965129437623546, 0.10274443091475405, 0.05797596793854609, 0.04735371214337647, 0.08954796910984442, 0.034791441503330134, 0.02270085951749934, 0.029298749032022897, 0.046082227636361495, 0.057552079160814174, 0.03111053189059021, 0.07843640792998485, 0.0189123922973522, 0.06024545924447011, 0.01633732725167647, 0.044430477792047895, 0.004593993380694883, 0.03158996485581156, 0.034594004246173427, 0.07426098120049573, 0.03157769715471659, 0.06904862573719583, 0.0364475588867208, 0.047214885998982936, 0.08321522298501804, 0.01870699921710184, 0.0878947832097765, 0.009467313520872267, 0.011723201259883353, 0.013856859131919919, 0.007121374974303762, 0.07802555497619323, 0.030653059075120836, 0.037676102729164995, 0.056143913316191174, 0.06227145189768635, 0.0337917945580557, 0.08037106817937456, 0.045787598719471134, 0.026582586870063096, 0.08227488477132283, 0.011880148795171408, 0.040784814627841115, 0.03276853989518713, 0.028609798500838224, 0.06158883930766024, 0.017002660788421053, 0.014107097413216252, 0.03306300925032701, 0.050089491123799235, 0.07732130878139287, 0.06858289096271619, 0.020120143017265946, 0.030900645106157754, 0.03913028915121686, 0.06068415386835113, 0.04567400559608359, 0.025097378675127402, 0.06869203120004386, 0.0764040439389646, 0.05340686526324134, 0.040343485379708, 0.052395774400793016, 0.028581511542142835, 0.05132944919751026, 0.04545155054074712, 0.05520440259715542, 0.060582379446714185, 0.12542432290501893, 0.0589902723004343, 0.0636253370612394, 0.036076232718187384, 0.039462797285523266, 0.0911066796106752, 0.03918373862688895, 0.045868630113545805, 0.1256741743418388, 0.03136618877761066, 0.03223086132493336, 0.2042157668620348, 5.497694620862603, 54.398986771702766, 95.42255446314812, 100.35382345318794, 106.34993210434914, 89.95341673493385, 93.79416704177856, 77.54668727517128, 83.34969028830528, 30.202833227813244, 33.92195776104927, 27.806799598038197, 25.374096035957336, 39.059244096279144, 56.39424450695515, 50.49302436411381, 42.94386304914951, 30.42129870504141, 6.987408483400941, 1.2212662235833704, 0.22454593767179176, 0.21263163245748729, 0.03159701154800132, 0.04730090462544467, 0.107316275825724, 0.06981519007240422, 0.07816979137714952, 0.08606305142166093, 0.007034677282717894, 0.08578941415180452, 0.1500298283644952, 0.03867951236316003, 0.08620080145192333, 0.07738335232716054, 0.37333985266741365, 0.2033995380043052, 0.30682572803925723, 0.19676295662065968, 0.11274736447376199, 0.10368463554186746, 0.1627435305272229, 0.16014761669794098, 0.1903930288972333, 0.15171806589933112, 0.17119025462307036, 0.26497317070607096, 0.3234115708619356, 0.2557738346513361, 0.02271549281431362, 0.23028947791317478, 0.1497367542469874, 0.07229144001030363, 0.2126847702311352, 0.28284865838941187, 0.12030431287712418, 0.08763903912040405, 0.03355681576067582, 0.27379389270208776, 0.09620271826861426, 0.1402456354117021, 0.27773395471740514, 0.07649862323887646, 0.05102206276205834, 0.10994490352459252, 0.0787542994657997, 0.059409144159872085, 0.1560590954613872, 0.3679355629719794, 1.0096579534001648, 9.946919102221727, 22.3316315934062, 45.76447069644928, 43.65877188742161, 51.0101006180048, 42.64885447919369, 29.288892969489098, 20.364541746675968, 24.32226687669754, 40.64471282064915, 43.322991505265236, 51.61703824996948, 80.4073865711689, 85.05813181400299, 82.33556270599365, 91.23565033078194, 93.05237844586372, 57.6333200186491, 10.920715648680925, 0.23512491141445935, 0.10661532476660796, 0.12254683082574047, 0.04983669707144145, 0.057140090721077286, 0.027014737606805284, 0.04719761622254737, 0.12155133619671687, 0.017873352153401356, 0.09465764102060348, 0.027354444573575165, 0.05180078718694858, 0.0803908241505269, 0.052285250058048405, 0.018680599168874323, 0.02358675563300494, 0.047989164959290065, 0.046775052178418264, 0.02228660938271787, 0.04941991064697504, 0.031696878650109284, 0.05060810020950157, 0.027359220293874387, 0.027470885688671842, 0.029784167418256402, 0.06563668343005702, 0.03904825214704033, 0.03729301351995673, 0.02273431182402419, 0.0537114760663826, 0.018308695980522316, 0.011665605034067994, 0.0018978118055201776, 0.03595081718231086, 0.05544239822484087, 0.030768947290198412, 0.07091564664733596, 0.031873951375018805, 0.02280370819789823, 0.07038463998469524, 0.02865629219741095, 0.03610191844927613, 0.03831292851828039, 0.02987319545354694, 0.07589524233480915, 0.1176967028004583, 0.10266846467857249, 0.11582546649151482, 0.11425241027609445, 0.1849987730383873, 0.11465481758932583, 0.07018391872406937, 0.1623114521498792, 0.24640922230901197, 0.20541136676911265, 0.0651773830759339, 0.1219794737698976, 0.1347620991873555, 0.12555412453366444, 0.1890297481440939, 0.12663798668654636, 0.12255147667019628, 0.3652357484679669, 0.15224024100461975, 0.12859786511398852, 0.09272197145037353, 0.08993236449896358, 0.18555213318904862, 0.259642472374253, 0.11974548309808597, 0.13075230497634038, 0.08374206619919278, 0.12457561766495928, 0.20201605599140748, 0.09268519061151892, 0.13999404734931886, 0.15795948333106935, 0.12697622791165486, 0.12700552790192887, 0.18546035920735449, 0.1744316885014996, 0.1595625074696727, 0.1860496838344261, 0.10264200711390004, 0.21097695484058931, 0.13606136228190735, 0.13690162188140675, 0.438654221361503, 4.390203198418021, 55.42978025972843, 108.48013579845428, 110.11264219880104, 104.52760308980942, 84.16284665465355, 90.1599432528019, 61.10759139060974, 81.1928728222847, 38.283147141337395, 67.74267375469208, 71.89407259225845, 59.91510517895222, 81.10499873757362, 82.68445998430252, 67.01578795909882, 60.326182320714, 51.95062234997749, 15.427839998155832, 6.116143260151148, 0.5138173943851143, 0.3473940136609599, 0.12933374906424433, 0.26097364781890064, 0.183683538925834, 0.42770041851326823, 0.3736354352440685, 0.42692146031185985, 0.21272070502163842, 0.28638603107538074, 0.30614149756729603, 0.3363664116477594, 0.38631850155070424, 0.2873825572896749, 0.739596172934398, 0.5173387366812676, 0.3712235443526879, 0.5126528756227344, 0.4104875202756375, 0.4146659898106009, 0.3776884818216786, 0.5989460670389235, 0.5340497649740428, 0.6891662289854139, 0.5984285823069513, 0.6180059036705643, 0.5230508395470679, 0.576259265653789, 0.35013722896110266, 0.3742325969506055, 0.35803029604721814, 0.4110228759236634, 0.5535047210287303, 0.44223552918992937, 0.4084491077810526, 0.3741905023343861, 0.2693095989525318, 0.8738499751780182, 0.2612567920004949, 0.706100317183882, 0.44873083534184843, 0.3133581712609157, 0.18783269362756982, 0.26193089957814664, 0.1762817587587051, 0.31160020153038204, 0.366960559040308, 0.5353216279763728, 3.734368602745235, 21.925414390861988, 42.78148256242275, 78.74103918671608, 64.90047186613083, 76.00288331508636, 83.68921726942062, 81.54221847653389, 61.59457705914974, 45.770014598965645, 40.259291902184486, 40.121606290340424, 42.76389330625534, 73.12792718410492, 82.34456822276115, 83.67893502116203, 101.42146736383438, 103.94992008805275, 62.28700250387192, 9.972099401056767, 0.4695215681567788, 0.39610161096788943, 0.21400957804871723, 0.16172842093510553, 0.10861310467589647, 0.1598442712565884, 0.14549546933267266, 0.2095437192474492, 0.1448045446886681, 0.3786975651746616, 0.1684366789413616, 0.16037309600505978, 0.19853367644827813, 0.1593468541977927, 0.15284008928574622, 0.12943168287165463, 0.18226143554784358, 0.20544152765069157, 0.09736441686982289, 0.17073343304218724, 0.08367627480765805, 0.1513164007337764, 0.07560795696917921, 0.22815633768914267, 0.15458988054888323, 0.1697280307416804, 0.1485999918077141, 0.08281851536594331, 0.14183406892698258, 0.21065135981189087, 0.11704370932420716, 0.19977405754616484, 0.248904679028783, 0.13648490596096963, 0.18653632490895689, 0.11665359197650105, 0.12588693323777989, 0.10897996311541647, 0.10840017508598976, 0.16225414350628853, 0.1706912790541537, 0.1540741027565673, 0.07677249057451263, 0.14719507656991482, 0.15630813053576276], [0.06914658180903643, 0.03051870622584829, 0.04970279878762085, 0.053479335983865894, 0.07262026338139549, 0.03785416251048446, 0.014555017860402586, 0.033340724621666595, 0.049070388777181506, 0.014052031910978258, 0.05207295500440523, 0.007455771874447237, 0.04121821402804926, 0.029559415415860713, 0.07819876482244581, 0.04657888028305024, 0.03285531922301743, 0.01518737684818916, 0.03901959411450662, 0.0865002951468341, 0.04708395259513054, 0.0031112013402889716, 0.0034950556573676295, 0.019214591120544355, 0.08196671537007205, 0.016544948630325962, 0.05209061440837104, 0.015116165923245717, 0.10493741050595418, 0.04603376910381485, 0.04593178688082844, 0.1376005171914585, 0.03593632303818595, 0.04078586476680357, 0.07698379486100748, 0.10583301947917789, 0.03488103728159331, 0.03769014045246877, 0.10036436331574805, 0.05330773659807164, 0.07307195672183298, 1.2138922442682087, 16.785528995096684, 61.16903409361839, 98.6547826230526, 81.78646937012672, 81.73827275633812, 46.602587923407555, 50.25976628065109, 44.26573991775513, 25.4745664447546, 24.19374067336321, 52.663908675312996, 57.746960520744324, 60.534745529294014, 59.643586948513985, 64.8471151292324, 59.58910547196865, 34.927881583571434, 13.268041592091322, 1.2016881303861737, 0.11679652219754644, 0.10784728990984149, 0.042132387825404294, 0.09880126672214828, 0.022158186293381732, 0.05369050668377895, 0.054579391799052246, 0.11294225245364942, 0.07768253432004713, 0.04532085462415125, 0.054217171782511286, 0.05138385975442361, 0.06680830454570241, 0.03196789984940551, 0.07320649325265549, 0.08153956485330127, 0.056429647593176924, 0.06690344787784852, 0.005521273506019497, 0.06645693472819403, 0.14401696273125708, 0.06591944169485942, 0.08922202527173795, 0.11561356848687865, 0.14751656010048464, 0.1723935580230318, 0.20740811509313062, 0.15927759697660804, 0.2816415106644854, 0.12915722181787714, 0.030018621146155056, 0.04614047509676311, 0.10431061484268866, 0.08891174817108549, 0.10912297497270629, 0.024456771643599495, 0.12671272095758468, 0.030613055459980387, 0.161986421153415, 0.03532756156346295, 0.08951092851930298, 0.03455847763689235, 0.20699620828963816, 0.06179189091199078, 0.16443001659354195, 0.04617472521204036, 0.021031101459811907, 0.04626258807547856, 0.06633475495618768, 0.1032780647801701, 0.0771827349672094, 0.2727169176796451, 0.031133833472267725, 5.597477266564965, 31.604089736938477, 49.802487418055534, 62.26384274661541, 64.093699157238, 75.91491043567657, 69.11401256918907, 39.73220318555832, 35.967767983675, 32.3067594319582, 35.88313892483711, 37.5673833489418, 53.01071606576443, 54.63300101459026, 64.67961251735687, 72.4945467710495, 64.13508653640747, 19.258185513317585, 0.7950267079286277, 0.26029253436718136, 0.05275406103464775, 0.016105582362797577, 0.011381488639017334, 0.007290144458238501, 0.052207524931873195, 0.08075844700215384, 0.05249059489869978, 0.015489666584471706, 0.021426426828838885, 0.06316203653113917, 0.05702194081095513, 0.08842236115015112, 0.011117537324025761, 0.024369474667764734, 0.018105915260093752, 0.031520588890998624, 0.048260175026371144, 0.0414169945725007, 0.09809801500523463, 0.02457324429997243, 0.06312766767223366, 0.044663252410828136, 0.02346920871787006, 0.02765316457953304, 0.0430940405203728, 0.028719311667373404, 0.04429267952218652, 0.04182334268989507, 0.04884974085143767, 0.016619233902019914, 0.02290043601533398, 0.02207948338764254, 0.0763396403635852, 0.03016479455254739, 0.0464037594065303, 0.050979953302885406, 0.03016307091456838, 0.035714966361410916, 0.03662736271508038, 0.05453086276247632, 0.02459832889144309, 0.02659980284079211, 0.02049700004135957, 0.06693876668578014, 0.06327384850010276, 0.051614790136227384, 0.062352101085707545, 0.08538685840903781, 0.04736195369332563, 0.01221307438754593, 0.05103792987938505, 0.008653030945424689, 0.019142122255288996, 0.058759583116625436, 0.011088180744991405, 0.03042227341211401, 0.13133857195498422, 0.07532466435804963, 0.039285520470002666, 0.03780958169954829, 0.05797832054668106, 0.08632575685624033, 0.0919447944033891, 0.033532198722241446, 0.03702126501593739, 0.09165954252239317, 0.08126777553115971, 0.013506725917977747, 0.039289212654693983, 0.026313903435948305, 0.028474428909248672, 0.02358030636969488, 0.015580998988298234, 0.01906591482111253, 0.029877425695303828, 0.043179320709896274, 0.025299869957962073, 0.030356745483004488, 0.0791042072523851, 0.01400745759383426, 0.13310981128597632, 0.02109099834342487, 0.09805814683204517, 3.4910087613388896, 30.59044662863016, 84.4925245642662, 110.86454585194588, 95.59252694249153, 95.127462297678, 58.22725474834442, 67.43443429470062, 67.92714625597, 31.754225380718708, 22.475923150777817, 22.063301391899586, 29.737854078412056, 41.930088847875595, 52.323275953531265, 64.95684564113617, 60.25320343673229, 34.492409750819206, 11.440034732222557, 0.5410499987192452, 0.25585630210116506, 0.1196700957370922, 0.03822477621724829, 0.20761156745720655, 0.05069331360573415, 0.13201524736359715, 0.08502695389324799, 0.09927666425937787, 0.06151412359031383, 0.09967711972421966, 0.10432264505652711, 0.1124134573910851, 0.23647743102628738, 0.11376899754395708, 0.4087339440593496, 0.15345415711635724, 0.2397944897529669, 0.19754555134568363, 0.406055711209774, 0.491970733855851, 0.1084311078011524, 0.24156062310794368, 0.10419823142001405, 0.2660414477577433, 0.20522051607258618, 0.45368179155047983, 0.35568700928706676, 0.6447299290448427, 1.0095107113011181, 0.5453702481463552, 0.7588429120369256, 0.7910651830025017, 0.6886232737451792, 0.6436633144039661, 0.4922242811881006, 0.14541200740495697, 0.12349243828793988, 0.08999021491035819, 0.18306531506823376, 0.07278545803274028, 0.14891090715536848, 0.11771830671932548, 0.13232230354333296, 0.046934164929552935, 0.08849495061440393, 0.04017766361357644, 0.12746981548843905, 0.05365649405575823, 0.033496082105557434, 0.14931850950233638, 0.2340454130899161, 0.5110570206306875, 0.09589477151166648, 3.4584542457014322, 25.07013324648142, 44.06684339046478, 64.1932462155819, 60.584207475185394, 46.196990087628365, 36.63708306849003, 17.64121077954769, 20.8834096044302, 42.37855598330498, 58.17600689828396, 62.751029804348946, 87.6011149585247, 75.82371532917023, 78.34633156657219, 83.67910221219063, 84.21257078647614, 35.2612528949976, 1.282121145632118, 0.4094669781625271, 0.07310134576982819, 0.020034456501889508, 0.028132974184700288, 0.04956297074386384, 0.07999425011803396, 0.11595070391194895, 0.04731206652650144, 0.04160682852671016, 0.03434122132603079, 0.047619794349884614, 0.07632739492692053, 0.07198238003184088, 0.01452804264772567, 0.039429229946108535, 0.068264056899352, 0.022649697712040506, 0.07003120699664578, 0.017647485074121505, 0.05796738500066567, 0.016394801023125183, 0.06981429207371548, 0.01830393695854582, 0.013776786963717313, 0.015119382205739385, 0.06107757377321832, 0.04931324176141061, 0.019206021170248277, 0.10798269475344568, 0.008629530839243671, 0.062283051665872335, 0.03338219583383761, 0.029789965446980204, 0.06809187863836996, 0.05307457235176116, 0.028964391094632447, 0.02583865432825405, 0.08339592110132799, 0.05725921655539423, 0.049673565590637736, 0.03595527377910912, 0.022149983706185594, 0.02945966520201182, 0.20270398235879838, 0.16250441054580733, 0.21435111440951005, 0.1650503629934974, 0.23086977802449837, 0.10218921539490111, 0.15326591877965257, 0.09878985991235822, 0.13192200392950326, 0.12362586901872419, 0.17541748326038942, 0.1982889013015665, 0.06259194837184623, 0.10759893018985167, 0.192155065597035, 0.12082884059054777, 0.16205131454626098, 0.09584236846421845, 0.11186977484612726, 0.1691769267199561, 0.13576662575360388, 0.12616602529305965, 0.2203416413976811, 0.1963925061863847, 0.2216427747043781, 0.09188594951410778, 0.1574432008783333, 0.2187325168051757, 0.18106982839526609, 0.15947477077133954, 0.13017568591749296, 0.21434179303469136, 0.1712422791752033, 0.08395768978516571, 0.17501022230135277, 0.17449990671593696, 0.15138642978854477, 0.10471620596945286, 0.2248607121873647, 0.12303484487347305, 0.19591347954701632, 2.80971173197031, 30.667269006371498, 91.85305640101433, 125.79467430710793, 101.46977797150612, 101.38714000582695, 65.84430322051048, 65.8782809972763, 57.911081314086914, 38.71878616511822, 36.3275820761919, 72.71567970514297, 79.99599024653435, 86.41803324222565, 81.23571932315826, 84.0111891925335, 80.89468002319336, 52.84950211644173, 23.696622848510742, 2.7418882213532925, 0.6614258175250143, 0.31458856305107474, 0.18335677130380645, 0.3744866489432752, 0.2875591884367168, 0.3076445544138551, 0.189227189111989, 0.2962957805721089, 0.3756110917311162, 0.3196383733302355, 0.37673307058867067, 0.2072803766350262, 0.4530511738266796, 0.1892353972652927, 0.6503910315223038, 0.20962676557246596, 0.21746026788605377, 0.2645145234419033, 0.5051175830885768, 0.4773385205771774, 0.5748118995688856, 0.43776964070275426, 0.5627433315385133, 0.3783600957831368, 0.41182498913258314, 0.5583990958984941, 0.5869960645213723, 0.6075159728061408, 0.9700380731374025, 0.32801573630422354, 0.4009937000228092, 0.26837520534172654, 0.5388263461645693, 0.4275364038767293, 0.39537421718705446, 0.22556527750566602, 0.39234542346093804, 0.2630149101605639, 0.31270344858057797, 0.12995161669095978, 0.2778579527512193, 0.19065229076659307, 0.44094196578953415, 0.17394455760950223, 0.2993639378109947, 0.12353551996056922, 0.45068253530189395, 0.13388225343078375, 0.3229033184470609, 0.2624810684937984, 0.43691450846381485, 0.6006582907866687, 0.207611775258556, 8.41634888201952, 47.12258622050285, 67.49516263604164, 91.51663765311241, 97.86649212241173, 114.2262102663517, 95.81008806824684, 53.327052891254425, 51.0107047855854, 43.309973403811455, 46.22239552438259, 50.2001778781414, 74.37312796711922, 72.76101887226105, 80.64026847481728, 94.20759245753288, 92.25393489003181, 35.45636482536793, 1.0135791054926813, 0.5823587696067989, 0.17674793140031397, 0.1361671628546901, 0.10286108910804614, 0.16761670965934172, 0.19948744011344388, 0.20638605899875984, 0.2044479106552899, 0.15715360001195222, 0.10682352687581442, 0.1950441871304065, 0.20375383930513635, 0.2036466880235821, 0.15375477145425975, 0.10521121846977621, 0.09785810834728181, 0.12678531784331426, 0.153346560546197, 0.15938629192532972, 0.20736744540045038, 0.09856095930445008, 0.19169674487784505, 0.11956359012401663, 0.116998683224665, 0.071310691855615, 0.24425592535408214, 0.20596021466189995, 0.10624920105328783, 0.1567481944221072, 0.07742135770968162, 0.1922354698763229, 0.08499789881170727, 0.13922439567977563, 0.20144751149928197, 0.14331824553664774, 0.12309056532103568, 0.09713784660561942, 0.1984828690183349, 0.13806903501972556, 0.1788731900160201, 0.1420668954961002, 0.14026052289409563, 0.11340084776747972], [0.012408478160068626, 0.045456203806679696, 0.008877890559233492, 0.029549867686000653, 0.05881768956896849, 0.04045961664814968, 0.01677546155406162, 0.06424337538192049, 0.006672007802990265, 0.02107107538904529, 0.020289812819100916, 0.0846309884218499, 0.03731768621946685, 0.027101578161818907, 0.005472462453326443, 0.010326362444175174, 0.048226091894321144, 0.019223405979573727, 0.013466388336382806, 0.052414513629628345, 0.023137986354413442, 0.07749065203825012, 0.06853862927528098, 0.0073906173383875284, 0.04686127489549108, 0.013499903725460172, 0.04293214842618909, 0.015938185388222337, 0.04288856580387801, 0.050441762650734745, 0.02448186365654692, 0.0358333537587896, 0.032489165823790245, 0.011272064530203352, 0.04897952021565288, 0.07208092982182279, 0.1323700533248484, 0.07241744926432148, 0.20950420730514452, 0.2069558502989821, 10.77531075105071, 50.573029071092606, 80.89024946093559, 79.85526099801064, 70.5635891854763, 69.64731395244598, 75.71931213140488, 102.07916647195816, 65.9211502969265, 31.450317688286304, 59.855942353606224, 63.53297084569931, 66.42489686608315, 59.87181790173054, 64.15290758013725, 61.59736230969429, 34.37296696007252, 11.88672736287117, 1.2520450470037758, 0.168542999017518, 0.06742705532815307, 0.012077451538061723, 0.11765982548240572, 0.022445762951974757, 0.034366873660474084, 0.009422890416317387, 0.039861876066424884, 0.11196899999049492, 0.14498555450700223, 0.038851416029501706, 0.052564379220712, 0.02081853923300514, 0.09670717830886133, 0.08236330424551852, 0.04465060992515646, 0.010462071568326792, 0.05176839615160134, 0.2409163350239396, 0.13454041967634112, 0.43433337821625173, 0.3943825891474262, 0.2526300377212465, 0.3164598438888788, 0.08479425348923542, 0.14917266264092177, 0.3631014801794663, 0.09621343488106504, 0.32802458270452917, 0.1654803633573465, 0.2214584845933132, 0.16158845188328996, 0.3510523564182222, 0.6594477267935872, 0.2230151987168938, 0.03943923409678973, 0.08210197178414091, 0.28041512647178024, 0.07405064912745729, 0.1465410366654396, 0.13955493341200054, 0.22396888816729188, 0.1414433281752281, 0.15973539819242433, 0.19605190493166447, 0.12200964207295328, 0.051422674077912234, 0.15045914595248178, 0.028005196763842832, 0.12015390180749819, 0.054758835685788654, 0.056761895975796506, 0.06678848920273595, 0.2016385699971579, 0.04147493404161651, 0.19164314697263762, 0.262665239861235, 1.6027911636047065, 18.260936625301838, 47.76174992322922, 49.44501779973507, 57.2989721596241, 75.18427804112434, 105.02859860658646, 46.24028496444225, 26.878399215638638, 23.29822562634945, 27.477535866200924, 44.17582154273987, 55.0226055085659, 54.3756066262722, 73.59154030680656, 65.64518630504608, 43.54362666606903, 4.441808704286814, 0.3392336843535304, 0.05658794769260567, 0.014907751374266809, 0.09287023029173724, 0.06292846039286815, 0.05004956357879564, 0.059193056731601246, 0.030706796133017633, 0.04767354439536575, 0.054447018628707156, 0.01999060856178403, 0.06621578126214445, 0.07179426043876447, 0.056482288127881475, 0.06388760462868959, 0.09943770288373344, 0.019042052917939145, 0.03207141089660581, 0.034227342475787736, 0.06960693601286039, 0.05898895498830825, 0.0186412319453666, 0.01742016709613381, 0.024681996765139047, 0.05662281750119291, 0.06428618245990947, 0.0048779024382383795, 0.0331261771498248, 0.05922871321672574, 0.049586441164137796, 0.05355877918191254, 0.027687585388775915, 0.12497386895120144, 0.06126429441792425, 0.02937850949820131, 0.01920000049722148, 0.023165803904703353, 0.029261003401188646, 0.06103571293351706, 0.02115863582730526, 0.04971656933776103, 0.05011969282350037, 0.05542266080738045, 0.0601710107002873, 0.03164457950333599, 0.016701274616934825, 0.018934664149128366, 0.06666429078904912, 0.03158581253956072, 0.005976640941298683, 0.028058709322067443, 0.04992395879526157, 0.037528560060309246, 0.09625797858461738, 0.01207197448820807, 0.02696966883377172, 0.03104954961600015, 0.06902248729602434, 0.021115568997629452, 0.05149117801920511, 0.05786928421002813, 0.02197557158069685, 0.01941372232977301, 0.04992787362425588, 0.0141437595084426, 0.05467686918564141, 0.026033124850073364, 0.05458689120132476, 0.03118418448138982, 0.028508192917797714, 0.0792998076940421, 0.039011983390082605, 0.09064780970220454, 0.003040460055672156, 0.031538088733213954, 0.03657843291875906, 0.0930864698602818, 0.012462832128221635, 0.021872314719075803, 0.0645329465623945, 0.17361151141813025, 0.6738136277999729, 21.52630850672722, 73.88285547494888, 95.78133881092072, 90.77105686068535, 89.35484245419502, 97.79609709978104, 111.08147621154785, 106.51585400104523, 57.46382251381874, 23.667784295976162, 25.20515140146017, 32.28585295379162, 49.772765412926674, 51.847602277994156, 63.79088580608368, 63.502317890524864, 28.313832990825176, 8.086607325822115, 0.10765127386548556, 0.2530724467942491, 0.0565389399707783, 0.06670726856100373, 0.042043853318318725, 0.07266134125529788, 0.060992557046120055, 0.08778137562330812, 0.02123947055224562, 0.21952069248072803, 0.1479970116633922, 0.2756615518592298, 0.48692439682781696, 0.12678417493589222, 0.41154980077408254, 0.5246502568479627, 0.49813510151579976, 0.6262015295214951, 0.39135017374064773, 0.6942983285989612, 0.8862363011576235, 1.1998452292755246, 1.3686826382763684, 1.3293270813301206, 1.2195400474593043, 1.5750549081712961, 1.3014418026432395, 2.0378790982067585, 0.8086157287470996, 1.4919933839701116, 1.503013267647475, 2.1729962853714824, 2.4614858301356435, 1.898899299558252, 3.1448644353076816, 1.8887807987630367, 1.1766556673683226, 0.932168533327058, 1.42759871436283, 0.38863055873662233, 0.5588062677998096, 0.44014596787746996, 0.9616461640689522, 0.8755631488747895, 0.9749758488032967, 1.6487798583693802, 0.7212824618909508, 0.37399659398943186, 0.21328357950551435, 0.13708364102058113, 0.43691130238585174, 0.07142208080040291, 0.14488711603917181, 0.1093492929066997, 0.2498411654960364, 0.10975031982525252, 0.13726306264288723, 0.43096272158436477, 0.5879760556854308, 13.675356935709715, 44.09555844962597, 51.27069063484669, 57.444660142064095, 51.740026250481606, 60.23259714245796, 19.939707443118095, 18.21381725370884, 30.809105895459652, 43.689280450344086, 72.8123389184475, 76.30299121141434, 74.97718915343285, 83.15802857279778, 78.27778324484825, 65.10897427797318, 12.06105250865221, 0.2383915931568481, 0.05163444591744337, 0.08171986220986582, 0.03183648776030168, 0.039893079665489495, 0.18222257669549435, 0.04039783285406884, 0.052869802675559185, 0.05285026563797146, 0.01678934528172249, 0.04733796748041641, 0.043671012099366635, 0.037617231864714995, 0.10229678227915429, 0.04056923928146716, 0.01749533366819378, 0.05188897288462613, 0.034073187271133065, 0.03453511111729313, 0.018843238976842258, 0.040710384637350217, 0.02013880803133361, 0.02882618093281053, 0.028789635725843254, 0.013617405184049858, 0.036104222817812115, 0.02665830634214217, 0.008226155023294268, 0.0236921127725509, 0.04924650784232654, 0.015310400813177694, 0.05658694950398058, 0.07576521806186065, 0.018757509787974413, 0.028779295753338374, 0.019092888178420253, 0.035025789475184865, 0.09388170336023904, 0.11902766302227974, 0.03907074293238111, 0.03890185238560662, 0.05846281310368795, 0.13150935497833416, 0.11859579244628549, 0.18909565085778013, 0.07689766862313263, 0.12958728155354038, 0.13097201037453488, 0.09745501083671115, 0.19043887878069654, 0.10729183690273203, 0.1152358078979887, 0.06859410481411032, 0.17519219691166654, 0.10963967302814126, 0.12236156850121915, 0.1046305472846143, 0.1252260952605866, 0.16548849729588255, 0.17608065158128738, 0.09862784165306948, 0.17122336925240234, 0.15284160326700658, 0.14619915891671553, 0.12159011341282167, 0.07812813462805934, 0.09289040928706527, 0.1351463535684161, 0.10569302816293202, 0.10108882561326027, 0.1777704624691978, 0.14295462286099792, 0.19713024550583214, 0.2453049659379758, 0.17515958694275469, 0.1184464649122674, 0.1539303784375079, 0.21496926405234262, 0.279037730069831, 0.2460102437180467, 0.4148243641247973, 0.5252833978738636, 23.436882086098194, 84.13988828659058, 110.7324193418026, 102.95106008648872, 91.20746344327927, 95.24372085928917, 97.33819127082825, 121.57421797513962, 79.9227225780487, 45.95973841845989, 79.17988523840904, 88.75588819384575, 94.00549650192261, 80.83779707551003, 81.91946223378181, 82.69875481724739, 46.50193132460117, 16.85563523322344, 2.322062524035573, 0.5058668553829193, 0.18228666856884956, 0.09631669730879366, 0.2526183711597696, 0.2713645464973524, 0.09168492397293448, 0.2214873838238418, 0.1806078414665535, 0.22331786138238385, 0.17327346315141767, 0.2192216514959, 0.263352527981624, 0.12586941855261102, 0.3708992851898074, 0.2842973900260404, 0.286488892743364, 0.23737352981697768, 0.28296654112637043, 0.9982843324542046, 0.620375907747075, 0.8768413646612316, 1.2811837834306061, 0.5505826778244227, 0.7939847919624299, 0.8424007846042514, 0.9273939114063978, 1.0348042915575206, 0.49478857952635735, 0.9049830702133477, 1.1259295768104494, 1.230550550390035, 1.4019766892306507, 0.9986701305024326, 2.220235113054514, 0.6802167592104524, 0.3674641210818663, 0.346231751027517, 0.7380916317924857, 0.5154817050788552, 0.6338805612176657, 0.4980528121814132, 0.6786688766442239, 0.37835012131836265, 0.4744856752222404, 0.5148823466151953, 0.31016649096272886, 0.23880465771071613, 0.32379386597312987, 0.23573966202093288, 0.4150584968738258, 0.16839222429553047, 0.23470311920391396, 0.3149596368893981, 0.7240041845943779, 0.2643149154027924, 0.3084142506122589, 0.39306076476350427, 3.516172436065972, 26.077618785202503, 65.25362491607666, 71.08261093497276, 86.1876668035984, 109.4141560792923, 131.02339893579483, 57.081346437335014, 37.60488733649254, 33.40267762541771, 37.511355355381966, 59.44274112582207, 76.49586886167526, 72.96874612569809, 90.70861861109734, 93.06718245148659, 68.73383536934853, 10.33352080732584, 0.35932985600084066, 0.17385357030434534, 0.12850563100073487, 0.18551906308857724, 0.16564700519666076, 0.2600286860251799, 0.26741480687633157, 0.1104675313399639, 0.22711975034326315, 0.12765165651217103, 0.12485015293350443, 0.1865049617481418, 0.09000950332847424, 0.22240665246499702, 0.19921461178455502, 0.1950957960798405, 0.0999458142905496, 0.14823910023551434, 0.16230121051194146, 0.11297066186671145, 0.17366374377161264, 0.1534073127550073, 0.05581401754170656, 0.10044902010122314, 0.18923112249467522, 0.13923521619290113, 0.10077137194457464, 0.13024522515479475, 0.12079925858415663, 0.152506033773534, 0.14288259000750259, 0.16530074877664447, 0.14222098019672558, 0.1245747716166079, 0.11160897673107684, 0.15117650589672849, 0.11826264235423878, 0.1306163435219787, 0.1819788702414371, 0.22723209665855393, 0.2670133049832657, 0.15044250700157136], [0.05836286065459717, 0.02436077113088686, 0.060163745074532926, 0.08251103616203181, 0.03201983534381725, 0.06601082233828492, 0.014079762258916162, 0.009943057084456086, 0.041627823884482495, 0.016297802321787458, 0.04866927280090749, 0.009573613187967567, 0.08251644641859457, 0.019175507768522948, 0.05805033855722286, 0.06946388704818673, 0.0479867232934339, 0.009096503144974122, 0.04110700319870375, 0.07701451977482066, 0.06468466381193139, 0.04128380875044968, 0.018570247375464533, 0.005043664832555805, 0.02537690117605962, 0.01232232873007888, 0.02439882289763773, 0.022756190337531734, 0.03421356450417079, 0.09043565936735831, 0.062203638153732754, 0.06489453575341031, 0.0343023773166351, 0.12368183437502012, 0.009987321554945083, 0.09869580011582002, 0.036329286522231996, 0.08506272541126236, 5.8323227148503065, 38.94829764962196, 77.26487919688225, 94.62818428874016, 75.7594607770443, 77.66773357987404, 72.50583976507187, 51.524798199534416, 21.51250384747982, 38.13998982310295, 102.57649898529053, 98.52292209863663, 63.11139486730099, 62.13450908660889, 56.19708448648453, 52.924320101737976, 31.271466985344887, 5.7765250839293, 0.5047657457180321, 0.09844280197285116, 0.10539388327742927, 0.05101364309666678, 0.03236166856368072, 0.09099199553020298, 0.02719855274335714, 0.04816052314708941, 0.037575883106910624, 0.06622368513490073, 0.1739018247462809, 0.1247346747550182, 0.19796153996139765, 0.05781368992757052, 0.16586274752626196, 0.8145900175441056, 0.08817766763968393, 0.30886274529621005, 0.8964357851073146, 0.758166192099452, 0.5911550007294863, 0.7764273590873927, 0.3153083869256079, 0.4478822340024635, 2.9838846484199166, 4.970613978803158, 10.459452699869871, 6.324689844623208, 2.203544983640313, 1.1431326786987484, 2.036914899945259, 0.663179779658094, 0.5427464889362454, 2.1925469487905502, 2.7508690394461155, 3.776977378875017, 4.981864700093865, 1.5094193676486611, 1.4454074087552726, 0.9909651533234864, 0.23813295469153672, 0.12424342494341545, 0.1429137898958288, 0.3707890911027789, 0.18728075840044767, 0.2722040342632681, 0.22047424834454432, 0.23010851262370124, 0.13794928207062185, 0.14481300517218187, 0.2532349474495277, 0.6763575912918895, 0.5412991822231561, 0.07759915402857587, 0.03254697541706264, 0.1718777060159482, 0.2194779596175067, 0.04604217021551449, 0.14280491683166474, 0.25023435533512384, 0.1916202888241969, 0.2610365819418803, 0.9526467625983059, 13.195028509944677, 36.87044374644756, 60.37764295935631, 44.89210210740566, 70.24454310536385, 77.05908983945847, 51.822801008820534, 41.471145674586296, 24.85383365303278, 41.54817894101143, 46.92587077617645, 59.56879936158657, 71.36050522327423, 78.19449931383133, 67.23319709300995, 18.091798201203346, 0.6586057157255709, 0.328791132196784, 0.05466415248520207, 0.022118152992334217, 0.06881154666189104, 0.11673280139802955, 0.055939128797035664, 0.02798055375023978, 0.03521939353959169, 0.03039674167666817, 0.025651486539572943, 0.023083941305230837, 0.01890780211397214, 0.06533088147989474, 0.060965130978729576, 0.07564320898381993, 0.04036002042994369, 0.007353595301538007, 0.026616011346050072, 0.08022532521863468, 0.05380830778449308, 0.07278588847839274, 0.032397428949479945, 0.05628932602121495, 0.011819118280982366, 0.023056967947923113, 0.0419455261726398, 0.00976379873463884, 0.02149350770196179, 0.09241743115126155, 0.030566300156351645, 0.06414925621356815, 0.03447665585554205, 0.043224272594670765, 0.0776798180595506, 0.060765430171159096, 0.04582541856507305, 0.03297038179880474, 0.04177460585196968, 0.016229446810029913, 0.0007572638912733964, 0.005380705169955036, 0.019413371664995793, 0.05547944994759746, 0.09758709828020073, 0.04497968191571999, 0.020411591831361875, 0.016489823756273836, 0.007169259270085604, 0.0961477770761121, 0.07712192338658497, 0.08680122118676081, 0.02810537742334418, 0.08127292603603564, 0.07218647806439549, 0.0005710253526558517, 0.028121482027927414, 0.02031884934694972, 0.013624369312310591, 0.10328907083021477, 0.024883039004635066, 0.09467355266679078, 0.02511571528884815, 0.04731867535156198, 0.03180174040608108, 0.027616860570560675, 0.014086236569710309, 0.07316828006878495, 0.028332213005342055, 0.01170499173895223, 0.029294468695297837, 0.05275304429233074, 0.015408877316076541, 0.0442164609557949, 0.12693376222159714, 0.05695563733752351, 0.06528037090902217, 0.07163167814724147, 0.16344583971658722, 12.597775608301163, 61.11747466027737, 97.18744575977325, 103.97005140781403, 98.87241974473, 107.75087893009186, 105.45701801776886, 79.12304788827896, 24.71605684608221, 48.23317922651768, 89.39957365393639, 57.832053154706955, 50.82284666597843, 61.02309912443161, 66.35803565382957, 53.47263067960739, 24.840372875332832, 2.88702760823071, 0.29061395733151585, 0.053285108515410684, 0.11170302910613827, 0.1157888415036723, 0.07836024873540737, 0.058329011299065314, 0.14478464028798044, 0.18989872885867953, 0.10672206786694005, 0.3029749315464869, 0.40504487638827413, 0.28293284762185067, 0.6956670270301402, 1.1110204830765724, 2.4170821253210306, 4.184477962553501, 1.7589576775208116, 3.57049360871315, 3.0439663119614124, 3.4316521463915706, 3.4605374839156866, 2.798072244040668, 3.6227742908522487, 3.5051114670932293, 10.871200505644083, 17.98545900732279, 24.330265447497368, 11.008008364588022, 7.290476895868778, 4.97166414745152, 3.8539436738938093, 2.9124311450868845, 5.148220248520374, 7.184796966612339, 3.4745527943596244, 5.41825988329947, 8.712212406098843, 4.814281342551112, 4.187168693169951, 2.7696530940011144, 1.6322633321397007, 1.120977255050093, 0.7649888447485864, 1.135931946337223, 0.6613044021651149, 1.9368387199938297, 1.8183902883902192, 0.5467643577139825, 0.5555935995653272, 0.7482610736042261, 0.6495790032204241, 0.4521484550787136, 0.7335549127310514, 0.42370748589746654, 0.1240392675390467, 0.3526992117986083, 0.26632405759301037, 0.037768952824990265, 0.11168475000886247, 0.30814084340818226, 0.07623722398420796, 0.31037533131893724, 0.17241797468159348, 9.977466613054276, 40.060851350426674, 66.1308154463768, 50.47008119523525, 44.72549244761467, 30.509904250502586, 20.630624368786812, 23.965621814131737, 32.10556782782078, 60.06385199725628, 76.50866657495499, 82.99645364284515, 85.35183325409889, 86.4751061797142, 86.88966393470764, 32.309122905135155, 1.6967931319959462, 0.44042308581992984, 0.0583450379781425, 0.10653554389136843, 0.15741168928798288, 0.1491241855546832, 0.057508173704263754, 0.014705167322972557, 0.02700657398236217, 0.013260367213661084, 0.02470970113790827, 0.03313337598228827, 0.05944309370534029, 0.006141221929283347, 0.07059131326968782, 0.07140289628296159, 0.06768436534912325, 0.008852956252667354, 0.015993929955584463, 0.044249801940168254, 0.06600461798370816, 0.054670197278028354, 0.028461793845053762, 0.041894061942002736, 0.023774285218678415, 0.025876839681586716, 0.0681026249367278, 0.09011839123559184, 0.027461625541036483, 0.03198038648406509, 0.04444805555976927, 0.03718091582413763, 0.020012876702821814, 0.006755979957233649, 0.056236856180476025, 0.024556239841331262, 0.027420098667789716, 0.040342698703170754, 0.03134854050586, 0.03987650008639321, 0.033256364695262164, 0.13858677208190784, 0.11102249452960677, 0.18890140112489462, 0.20537040021736175, 0.09953759596101008, 0.1550557860173285, 0.15351378126069903, 0.09733990373206325, 0.19087284221313894, 0.19954771734774113, 0.17435625661164522, 0.10032997219241224, 0.24493745440850034, 0.15659409487852827, 0.1937826696666889, 0.15033781965030357, 0.16803640901343897, 0.12159418038208969, 0.15715829038526863, 0.11289106652839109, 0.1691115731955506, 0.08760438082390465, 0.1388326010783203, 0.16283138596918434, 0.062074341185507365, 0.12312008053413592, 0.14732661482412368, 0.09983888565329835, 0.10835451073944569, 0.14075163169763982, 0.1880307579995133, 0.24192535900510848, 0.12576127279317006, 0.23561685142340139, 0.21234161598840728, 0.1307391095906496, 0.10566006938461214, 0.25422710983548313, 11.260720454156399, 66.41191676259041, 112.84854859113693, 117.9925985634327, 97.54458859562874, 103.48173961043358, 97.42316991090775, 69.75548654794693, 31.402521952986717, 53.47185552120209, 120.00482618808746, 122.28856444358826, 85.87481439113617, 85.0307808816433, 78.31528723239899, 72.64412954449654, 44.14554476737976, 8.217094223946333, 1.4037432381883264, 0.27314620558172464, 0.16380797809688374, 0.26617325318511575, 0.45908465632237494, 0.3711739688878879, 0.24187144939787686, 0.2803131256951019, 0.29297591652721167, 0.2477470473968424, 0.3610844712238759, 0.31554821936879307, 0.3511321224505082, 0.3296407131711021, 0.8624882879666984, 2.99231497105211, 0.8403438481036574, 2.1465428173542023, 1.7229243298061192, 1.8120532971806824, 2.2165884962305427, 1.4266335661523044, 2.671223650686443, 3.5182796604931355, 9.696792773902416, 16.891906186938286, 21.00745964795351, 13.393840491771698, 7.109824614599347, 6.985478661954403, 5.778919430449605, 2.8070492623373866, 4.540374940261245, 7.128512486815453, 8.530805390328169, 9.925091173499823, 13.014830779284239, 7.550609037280083, 7.0444790460169315, 3.3386820601299405, 1.7317646741867065, 1.1704903794452548, 1.662080332171172, 1.0581732750870287, 0.657985161524266, 0.8436461677774787, 0.8901664183940738, 0.586694396333769, 0.25829752266872674, 1.019669584929943, 0.6503878848161548, 1.8136930279433727, 1.0836054291576147, 0.47856535005848855, 0.24224733235314488, 0.47936419781763107, 0.36083035985939205, 0.12924103997647762, 0.5794474727008492, 0.603286859113723, 0.29240520496387035, 0.3115638956660405, 2.4410472018644214, 20.331234633922577, 56.46941587328911, 84.02711033821106, 67.22539231181145, 107.9632419347763, 108.18386569619179, 67.86353006958961, 56.65984645485878, 32.86975622177124, 53.52712355554104, 64.1435980796814, 78.90984132885933, 89.60748329758644, 100.03251269459724, 96.8600857257843, 31.457246616482735, 1.4725168165750802, 0.5601695040240884, 0.18289943021954969, 0.1473390235332772, 0.2591640839818865, 0.3977298829704523, 0.1483099308097735, 0.0860988674685359, 0.11897684817085974, 0.1263256761012599, 0.1342291184118949, 0.11544282257091254, 0.10787716877530329, 0.11688935002894141, 0.19609119422966614, 0.16678106621839106, 0.2057181260897778, 0.142462964868173, 0.05320564305293374, 0.2239016941166483, 0.20061179384356365, 0.25175439252052456, 0.11125424498459324, 0.19913733936846256, 0.16411306016379967, 0.1138416983303614, 0.16507250868016854, 0.147557734453585, 0.18083992588799447, 0.13648820109665394, 0.09125726137426682, 0.19295587262604386, 0.18088098149746656, 0.09968557278625667, 0.17967110266909003, 0.18627468816703185, 0.14591545070288703, 0.1322154639638029, 0.13187046919483691, 0.1478474392206408, 0.11680390656692907], [0.03042986001673853, 0.01970754972717259, 0.10017103384598158, 0.07447714655427262, 0.040714492424740456, 0.06010290380800143, 0.061076030106050894, 0.053358128425315954, 0.04744489611766767, 0.04754238834721036, 0.031163408057182096, 0.05127013304445427, 0.05657658912241459, 0.03301595708762761, 0.06448985004681163, 0.017279515268455725, 0.023620521496923175, 0.05327347906131763, 0.022409312368836254, 0.0641649823228363, 0.03634798122220673, 0.03182497704983689, 0.015504450166190509, 0.013410773644864094, 0.06374736840371042, 0.07019307682639919, 0.00620037991211575, 0.054326512399711646, 0.07158889333368279, 0.025669921487860847, 0.07171670600655489, 0.06373770564096048, 0.19272154691861942, 0.024372526750084944, 0.06740853132214397, 0.04041868349304423, 0.9705721226055175, 26.152079589664936, 75.7648640871048, 99.98945340514183, 90.89516580104828, 68.8639023900032, 61.159492805600166, 43.73004466295242, 34.90775786340237, 31.887805312871933, 51.075251922011375, 32.89234600961208, 35.30963569879532, 64.22872111201286, 65.20388558506966, 54.66656841337681, 32.96453073620796, 4.830284658819437, 0.4460358002688736, 0.1494853591430001, 0.07561296646599658, 0.07912155124358833, 0.10182870231801644, 0.034292269265279174, 0.07256408280227333, 0.0853575584187638, 0.13396909955190495, 0.02181197254685685, 0.37179039674811065, 0.610947604291141, 0.26927860686555505, 0.1256880525033921, 0.6883671437390149, 0.45426440716255456, 0.6530679878778756, 1.0923974448814988, 0.961280552437529, 5.564765771850944, 1.4238600712269545, 3.1216906663030386, 2.497964110225439, 2.1663635037839413, 1.621346992906183, 2.863166076131165, 4.718452859669924, 11.652793865650892, 32.02571511268616, 9.134492296725512, 7.7425300888717175, 7.290690159425139, 3.181366939097643, 5.608718963339925, 2.0345326652750373, 4.80381527915597, 5.607260791584849, 4.0014066360890865, 8.153471387922764, 8.205764181911945, 5.773366503417492, 5.546079324558377, 4.696528036147356, 1.5834440267644823, 1.317420657724142, 1.3925416767597198, 3.215346378274262, 6.273481417447329, 6.09931823797524, 10.366267450153828, 5.208357721567154, 2.671810006722808, 0.4401429696008563, 0.3865465190028772, 1.4975664974190295, 0.2101156479329802, 0.08024649127037264, 0.14412610296858475, 0.059982597958878614, 0.0125898108126421, 0.056138050349545665, 0.01938316254381789, 0.14518342592054978, 0.2617986488621682, 0.033220470722881146, 0.20707894291263074, 2.9700372414663434, 18.792245015501976, 30.265640057623386, 79.28171217441559, 57.91536368429661, 72.29052811861038, 65.8023002743721, 50.99971957504749, 28.121662102639675, 29.07237108796835, 50.54019123315811, 42.25808344781399, 58.82976941764355, 64.9793404340744, 82.21748024225235, 36.937358155846596, 6.194052854552865, 0.15187100769253448, 0.1520661628455855, 0.08730436762562022, 0.10027771757449955, 0.05056020199845079, 0.05013438734749798, 0.050318788780714385, 0.06996917829383165, 0.04906194313662127, 0.03101982845691964, 0.03348484227899462, 0.04072198069479782, 0.015586433364660479, 0.013310420436027925, 0.04534225074166898, 0.05527477303985506, 0.03138217463856563, 0.023579701519338414, 0.03304013254819438, 0.027857091918122023, 0.0344438455067575, 0.07847764165489934, 0.029418941703625023, 0.054913462154217996, 0.08353608311153948, 0.057555099701858126, 0.10304690062184818, 0.015404948571813293, 0.08549101141397841, 0.02319639337656554, 0.009184774189634481, 0.039039606126607396, 0.05497922385984566, 0.08113640797091648, 0.017969415748666506, 0.04048989256261848, 0.022694566105201375, 0.02878142386180116, 0.01677913147432264, 0.041667287587188184, 0.04689197383413557, 0.06543738709297031, 0.06071030715247616, 0.008211023559852038, 0.04447957828233484, 0.007027336514511262, 0.03295519003586378, 0.017728572129271924, 0.04727680337964557, 0.02520876205380773, 0.03950241683924105, 0.010086095844599186, 0.047406345256604254, 0.014242780562199187, 0.023342236527241766, 0.051587078341981396, 0.06395907344995067, 0.03655461368907709, 0.00014502387472248301, 0.07181950088124722, 0.024675807253515813, 0.022114928360679187, 0.047231617718352936, 0.046833752348902635, 0.028895133873447776, 0.03835029936453793, 0.022992351005086675, 0.045253734788275324, 0.06211398671439383, 0.059057262260466814, 0.046380986605072394, 0.17549775395309553, 0.018890613973781, 0.03171897609718144, 0.04778682952746749, 4.255024027079344, 48.73792514204979, 99.43474397063255, 117.56104052066803, 105.13185426592827, 93.48777428269386, 88.1795883178711, 71.77638530731201, 49.13921020925045, 26.28588940948248, 36.183246821165085, 20.826545655727386, 34.25507068634033, 66.89857184886932, 72.1620874106884, 57.18172945082188, 28.509226106107235, 2.87864217069, 0.5206405220087618, 0.1440592057770118, 0.1436875233775936, 0.17335204174742103, 0.0650211980973836, 0.1116388407535851, 0.2584359480533749, 0.38278270221780986, 0.12791215034667403, 0.2938387671019882, 0.36610257695429027, 1.1920712026767433, 0.6402685528155416, 1.0072947177104652, 1.403347346931696, 3.803168898448348, 5.3383325971663, 6.801296370103955, 6.281999135389924, 10.86021814495325, 9.120848178863525, 6.20899697765708, 7.75091053918004, 5.687752822414041, 7.583394153043628, 8.113153651356697, 13.735767044126987, 19.673345535993576, 41.942384988069534, 16.2946580350399, 10.002091191709042, 12.650185246020555, 10.017158333212137, 10.038658529520035, 8.597793895751238, 12.374858669936657, 9.48562765493989, 6.4989641681313515, 5.621954128146172, 3.956528906710446, 2.456533508375287, 1.9672322203405201, 1.3416122971102595, 1.3915773597545922, 0.730897489702329, 0.9889158757869154, 0.8811348967719823, 1.771573950536549, 1.5697186882607639, 1.373545783571899, 3.256992856040597, 1.0738724889233708, 0.9421939391177148, 1.5181250567547977, 3.4519767807796597, 1.3231945666484535, 0.06633166020037606, 0.14561718155164272, 0.18604266311740503, 0.47301654936745763, 0.09506807095021941, 0.07927120532258414, 0.07257100704009645, 0.41024587699212134, 0.0845954469696153, 0.364451595232822, 0.9047549637034535, 15.387670453637838, 31.553668342530727, 89.50936496257782, 61.23570531606674, 53.30990821123123, 38.049980252981186, 20.414754152297974, 26.25891275703907, 44.70827557146549, 74.05331432819366, 71.4012086391449, 80.39424687623978, 77.82861694693565, 96.77545666694641, 57.51165434718132, 14.308504611253738, 0.07173714475356974, 0.3971170471049845, 0.15040026395581663, 0.12433688360033557, 0.03930382554244716, 0.06292423757258803, 0.033881609269883484, 0.04214753134874627, 0.05134058512339834, 0.04266283787728753, 0.013192147143854527, 0.023920443782117218, 0.07097779409377836, 0.06286156320129521, 0.052201751022948883, 0.029467121930792928, 0.02904510522057535, 0.041205170782632194, 0.04544981762592215, 0.03579453572456259, 0.011590045123739401, 0.04207451886031777, 0.04535934982413892, 0.10502617136808112, 0.024963187242974527, 0.02185759978601709, 0.04000863576948177, 0.013221660501585575, 0.22594616253627464, 0.02079720434267074, 0.07212214870378375, 0.02708688178245211, 0.02162156528356718, 0.04349620663560927, 0.02610886102047516, 0.024099648326227907, 0.04734148154966533, 0.00199583687390259, 0.07312570305657573, 0.15885976783465594, 0.1456296644755639, 0.15384175116196275, 0.21253418846754357, 0.1359791323193349, 0.1655797369312495, 0.1439937631948851, 0.1455590417026542, 0.11355542970704846, 0.1275688922032714, 0.15242502093315125, 0.15927416825434193, 0.19076739787124097, 0.14748114481335506, 0.16012931533623487, 0.09841974344453774, 0.11090271931607276, 0.13162045448552817, 0.12120836749090813, 0.1397621855721809, 0.12427823166945018, 0.20098694949410856, 0.08070467840298079, 0.140804220282007, 0.15378714393591508, 0.2522361354203895, 0.15204965748125687, 0.09174792488920502, 0.14723357919137925, 0.11639984426437877, 0.2663714956725016, 0.1648222713265568, 0.32451924111228436, 0.1592679342138581, 0.2300607183133252, 0.10500024814973585, 3.2741313613951206, 51.01625628769398, 111.09124928712845, 127.42855623364449, 109.92552503943443, 92.80832514166832, 83.91060099005699, 57.99532279372215, 46.40585348010063, 43.244871497154236, 77.28417456150055, 49.404899552464485, 54.08109962940216, 92.2298213839531, 84.48208272457123, 73.30157786607742, 44.35645245015621, 8.715774714946747, 0.9429367398843169, 0.43531007424462587, 0.20735105877975002, 0.4049048776505515, 0.3290814900537953, 0.18050576647510752, 0.22161941189551726, 0.23667156201554462, 0.16312022984493524, 0.26833509968128055, 0.9736651566345245, 1.8716007331386209, 1.574761492665857, 1.922354253474623, 2.2159019205719233, 4.034555107355118, 5.433125635609031, 7.816865500062704, 7.524094060063362, 16.068290881812572, 8.637516014277935, 10.67949129268527, 11.605379059910774, 7.0023611560463905, 8.940809089690447, 9.599868524819613, 12.479805238544941, 24.05784096568823, 50.928864777088165, 24.32970117777586, 22.41824794560671, 20.82697693258524, 14.05447494238615, 17.82087653875351, 13.734610006213188, 16.936316303908825, 23.128950409591198, 22.72996611893177, 21.30452200770378, 21.72143943607807, 17.215200439095497, 17.465707696974277, 13.698915671557188, 7.970130275934935, 6.19895126670599, 5.929333409294486, 9.133927077054977, 15.184936132282019, 10.871748626232147, 19.95233416557312, 9.351448304951191, 6.094652088358998, 1.587173764128238, 1.6856745723634958, 5.2878394816070795, 0.7450019766110927, 0.21121524361660704, 0.27838867739774287, 0.3531584230950102, 0.31880737573374063, 0.19848206749884412, 0.1353628232027404, 0.4267553676618263, 0.6860820413567126, 0.25600764085538685, 0.533787579042837, 4.187372457236052, 27.06763856112957, 45.15248693525791, 100.94138592481613, 82.5785368680954, 109.12556916475296, 90.69647446274757, 67.79983028769493, 39.70913462340832, 37.763954401016235, 62.729120180010796, 60.21189205348492, 77.29280009865761, 81.23025521636009, 110.7123564183712, 64.16136592626572, 13.187028039246798, 0.15395869879284874, 0.46669713221490383, 0.2485867726500146, 0.350969799910672, 0.2664048329461366, 0.13780781388049945, 0.13998632901348174, 0.20731573255034164, 0.14466536231338978, 0.13124687218805775, 0.14039065106771886, 0.1792317660874687, 0.12256158472155221, 0.15644139057258144, 0.16240439872490242, 0.09985268960008398, 0.09056698239874095, 0.16314093576511368, 0.1308274845359847, 0.13387875049374998, 0.12487468833569437, 0.16101027431432158, 0.12090533375157975, 0.18190511560533196, 0.1729030572460033, 0.16159260791027918, 0.1213345697033219, 0.11839652579510584, 0.34960496064741164, 0.10584790696157143, 0.13835148158250377, 0.1374266023049131, 0.09448725133552216, 0.11227285751374438, 0.05623773191473447, 0.06724042745190673, 0.09535638790111989, 0.1631163409911096, 0.16272810869850218], [0.04711960908025503, 0.034809642675099894, 0.014156827801343752, 0.05688418706995435, 0.012385392728901934, 0.04094792384421453, 0.0532237996958429, 0.06026530056260526, 0.05262725768261589, 0.01328454731265083, 0.03768534988921601, 0.049303504783893004, 0.027711170841939747, 0.07988817495061085, 0.10236070345854387, 0.021111348032718524, 0.032641161378705874, 0.06591193858184852, 0.02923654221376637, 0.013647786854562582, 0.04285478324163705, 0.008995946773211472, 0.06601834771572612, 0.042905234440695494, 0.010427851138956612, 0.02606449357699603, 0.07216422847704962, 0.00984873011475429, 0.02644475705892546, 0.026156742533203214, 0.041427651813137345, 0.12962533888639882, 0.0948801072081551, 0.09051329543581232, 0.26467040413990617, 5.727092111483216, 68.30755144357681, 92.27001562714577, 89.55177068710327, 74.83967453241348, 68.01556751132011, 53.132643923163414, 66.6634176671505, 40.90343713760376, 44.61278289556503, 66.36030793190002, 50.01163199543953, 68.9588212966919, 73.41264590620995, 71.94404751062393, 42.560159638524055, 6.0351829044520855, 0.22756898717489094, 0.3629374655429274, 0.2762946631992236, 0.03242184189730324, 0.10293246887158602, 0.15426617057528347, 0.01395540335579426, 0.07093224849086255, 0.0986430408374872, 0.09030907123815268, 0.09510767195024528, 0.5383358162362128, 0.17553184821736068, 0.7069564587436616, 0.46684271190315485, 2.5699866330251098, 2.834920766763389, 8.788101933896542, 10.575982946902514, 3.3715158607810736, 5.402997052296996, 5.331764649599791, 6.807945538312197, 6.0800651460886, 4.509105943143368, 7.172869881615043, 5.550994835793972, 2.5878425873816013, 11.409164238721132, 9.613054767251015, 15.873253047466278, 11.036022361367941, 6.8415219616144896, 10.370788257569075, 9.039557240903378, 5.3717575035989285, 8.520749229937792, 8.42709755524993, 1.6269248561002314, 4.404927408322692, 7.563724033534527, 3.290198561735451, 2.1014594240114093, 3.740648478269577, 3.5428289556875825, 2.0157832838594913, 1.3984976196661592, 1.4259087550453842, 1.5359466942027211, 11.184200160205364, 5.490551479160786, 2.378198099322617, 4.168477496132255, 0.883179068332538, 0.7254691247362643, 0.5297116446308792, 1.8864491488784552, 0.6613219762220979, 0.2974055882077664, 0.3118611703393981, 0.07838521458324976, 0.0606141804746585, 0.11054055124986917, 0.125171295076143, 0.1412961899768561, 0.16636905551422387, 0.10408201851532795, 0.13405616831732914, 0.13269892864627764, 0.12302823975915089, 2.529784790240228, 30.257441997528076, 57.66133591532707, 55.557141825556755, 51.63721136748791, 73.2066285610199, 54.01489578187466, 41.53033509850502, 23.249474242329597, 21.83005850762129, 41.17365583777428, 52.27376461029053, 51.479580625891685, 73.96078169345856, 73.94004240632057, 28.066413067281246, 0.6034266797360033, 0.2121224597794935, 0.1428522658534348, 0.13755487510934472, 0.0033823623880380183, 0.05869960274139885, 0.027322300302330405, 0.014093213685555384, 0.05476005651871674, 0.03132222394924611, 0.00385603605536744, 0.015146171881497139, 0.015400678439618787, 0.03387513403140474, 0.02925391589087667, 0.02172699478251161, 0.09760239394381642, 0.030753629362152424, 0.037038096925243735, 0.030221017805160955, 0.06070593219192233, 0.021668311310349964, 0.046932064651628025, 0.0521936022414593, 0.01840857235947624, 0.07839732643333264, 0.009859757501544664, 0.03671849102829583, 0.0375291018281132, 0.05900477015529759, 0.03680039073515218, 0.032343137136194855, 0.04998537522624247, 0.025255945947719738, 0.014440010945691029, 0.08570356250857003, 0.054647546930937096, 0.04384164298244286, 0.0640382086567115, 0.03408479446079582, 0.03513129318889696, 0.018817263808159623, 0.0913833522645291, 0.05173032026505098, 0.027620920118351933, 0.06753603229299188, 0.024622277996968478, 0.029962563021399546, 0.049948019222938456, 0.012479246579459868, 0.02892267868446652, 0.08189595901058055, 0.042407576183904894, 0.04761030970257707, 0.02020147683651885, 0.02577649018348893, 0.027131538663525134, 0.02783834897854831, 0.10939051178866066, 0.053463865915546194, 0.011694165659719147, 0.04101571161299944, 0.027574799350986723, 0.0407890893984586, 0.030717186200490687, 0.04641223102225922, 0.026639379721018486, 0.05740272194088902, 0.019238089371356182, 0.1366682312800549, 0.07264232001034543, 0.0714982399949804, 0.21264681679895148, 14.110069759190083, 95.58344542980194, 108.86592149734497, 104.5603497326374, 100.06772920489311, 103.4928198158741, 85.16637280583382, 94.88242864608765, 39.88198734819889, 25.106660686433315, 47.97670438885689, 37.3448520898819, 68.02005887031555, 85.0975888967514, 80.17171561717987, 39.233920723199844, 2.9956032196059823, 0.48369747935794294, 0.16450789757072926, 0.2888539689593017, 0.05018561038014013, 0.08642577609862201, 0.2606199402362108, 0.4109216172946617, 0.23524068645201623, 0.18128801981220022, 0.882268245331943, 0.4867645975900814, 0.14970522781368345, 0.3802717197686434, 0.9109189454466105, 0.5469045345671475, 2.33539957087487, 2.8066802071407437, 1.5055559249594808, 5.232741013169289, 3.4296491788700223, 8.116373978555202, 9.889035858213902, 9.872407000511885, 10.875174142420292, 14.239486064761877, 17.0363687351346, 15.692085418850183, 10.124268885701895, 15.832256097346544, 13.745093643665314, 16.443429552018642, 15.235367976129055, 12.472929507493973, 15.778910759836435, 13.181864116340876, 6.901766778901219, 5.37024138495326, 5.26967978104949, 1.6521677328273654, 1.0435097431764007, 0.23319540166994557, 1.025974634103477, 2.65803883317858, 2.184202359057963, 1.51136759435758, 2.643305598758161, 1.1060366942547262, 2.6297158654779196, 2.2240097355097532, 3.3901814091950655, 0.992374224588275, 0.9308707248419523, 0.8012842596508563, 0.6632616533897817, 0.8004049630835652, 0.31099303567316383, 0.6539657490793616, 0.25795405672397465, 0.5327778425998986, 0.7548143563326448, 0.3295734745915979, 0.31066931085661054, 0.34969001077115536, 0.2512787946034223, 0.09060370386578143, 0.06295727798715234, 0.08502167722326703, 0.185766376380343, 0.08708519657375291, 0.38024633831810206, 0.5635970388539135, 23.979477770626545, 60.38049280643463, 68.02089482545853, 53.13827142119408, 54.42115858197212, 30.889055505394936, 14.376559909433126, 28.640839643776417, 39.80545945465565, 66.3073767721653, 85.35763174295425, 70.14669835567474, 84.28444772958755, 90.47202050685883, 45.021865144371986, 1.3735131290741265, 0.3487368853529915, 0.1778523955726996, 0.07432329934090376, 0.053727981430711225, 0.02894756104069529, 0.020604980672942474, 0.03938614456274081, 0.0454565785912564, 0.023052255310176406, 0.038807187738711946, 0.04607096554536838, 0.05159686355909798, 0.025319854139524978, 0.017143240256700665, 0.03269205415563192, 0.06289226585067809, 0.007017403795543942, 0.05619832758384291, 0.016638169799989555, 0.030936218099668622, 0.03155190010147635, 0.0290538588524214, 0.030074458481976762, 0.05116771666507702, 0.08553080537240021, 0.03386412427062169, 0.023258533401531167, 0.017702073746477254, 0.02774476230115397, 0.044746703206328675, 0.06676008721115068, 0.022832208524050657, 0.04239100402628537, 0.03338654481922276, 0.04512172155955341, 0.01526493591882172, 0.03873291359923314, 0.11996324406936765, 0.1132006905390881, 0.15556396421743557, 0.07246175548061728, 0.19655991985928267, 0.15213221398880705, 0.08835784625262022, 0.1971301416051574, 0.09657742863055319, 0.17054237454431131, 0.13092887675156817, 0.16795238305348903, 0.08031217133975588, 0.2734296763082966, 0.13970452069770545, 0.13669318228494376, 0.14466119144344702, 0.09777259067050181, 0.09568536712322384, 0.12008152014459483, 0.21248942211968824, 0.1878485013730824, 0.19177616952219978, 0.2634709153790027, 0.07663487413083203, 0.1611584663623944, 0.15841639396967366, 0.12702237465418875, 0.1300153078045696, 0.09614428898203187, 0.13827524817315862, 0.31599371577613056, 0.17240448243683204, 0.18319205904845148, 0.37043760996311903, 12.885031644254923, 106.08027577400208, 125.69794669747353, 111.53074130415916, 94.74563598632812, 90.74625939130783, 67.8401917219162, 82.0808319747448, 57.1009723842144, 62.017080187797546, 93.39907944202423, 67.32629209756851, 98.1334961950779, 99.75672349333763, 90.45137241482735, 59.4742414355278, 9.842443708330393, 1.1926645645871758, 0.45188810967374593, 0.5851177184376866, 0.2133360641892068, 0.28850403148680925, 0.4162777861347422, 0.26774019410368055, 0.12635784078156576, 0.254730464075692, 0.5380383040755987, 1.0106627619825304, 1.2982586422003806, 0.8510427677538246, 1.654832458589226, 2.6499345805495977, 7.136447886005044, 10.365693680942059, 16.896372847259045, 24.011179469525814, 13.259079772979021, 20.183293372392654, 23.846847787499428, 22.827590480446815, 20.585644282400608, 20.118883028626442, 24.006249234080315, 16.42034389078617, 12.947846073657274, 23.409859836101532, 24.873586893081665, 27.975599840283394, 21.640923656523228, 21.520225033164024, 20.60087576508522, 19.185373820364475, 17.020291797816753, 19.492707028985023, 16.13137699663639, 6.52322824113071, 12.60626720264554, 16.602228730916977, 15.947512462735176, 12.71152725443244, 12.286492511630058, 10.20662471652031, 8.73907696455717, 4.8997012339532375, 10.809278078377247, 12.584981694817543, 22.544241584837437, 17.572244480252266, 12.586803697049618, 8.208102956414223, 2.4868409195914865, 2.1605548029765487, 1.104494333267212, 4.777778126299381, 2.6123852329328656, 2.2799489088356495, 1.4229894429445267, 0.36372898088302463, 0.28934482543263584, 0.6245249882340431, 0.4890778422122821, 0.23718527663731948, 0.2663410676177591, 0.3498720150673762, 0.40021661203354597, 0.27058950683567673, 0.37276382732670754, 4.551594313234091, 41.586078107357025, 73.82029563188553, 73.96846488118172, 74.96753767132759, 106.69957414269447, 75.21597594022751, 54.29921552538872, 30.89444361627102, 30.03841035068035, 55.75094282627106, 71.28813430666924, 64.96164098381996, 94.20991033315659, 103.28205272555351, 46.82176396250725, 0.9647789178416133, 0.4327891767024994, 0.31852087704464793, 0.36667566339019686, 0.1069857603579294, 0.1709293748717755, 0.07002700644079596, 0.13145093311322853, 0.11089999563409947, 0.15354042436229065, 0.11591038302867673, 0.18653337116120383, 0.15851815725909546, 0.053763007090310566, 0.12405853369273245, 0.18055155698675662, 0.1656048363656737, 0.10994679600116797, 0.15699872863478959, 0.20939275156706572, 0.12003056428511627, 0.09689314567367546, 0.17124478763435036, 0.18076121370540932, 0.16565105732297525, 0.21397201053332537, 0.08587888005422428, 0.18207721965154633, 0.14184919389663264, 0.16807715292088687, 0.16923943039728329, 0.1942988927476108, 0.09779794243513606, 0.12902927555842325, 0.09400521157658659, 0.15647394116967916, 0.13882066734367982, 0.1548550499137491], [0.056526412517996505, 0.04782388867170084, 0.04227537370752543, 0.022146104129205924, 0.015896812510618474, 0.06006007446558215, 0.01630237209610641, 0.07607714273035526, 0.049866104673128575, 0.03224747058993671, 0.02735331465373747, 0.09912968933349475, 0.011980182880506618, 0.012386900216370123, 0.0740949553437531, 0.0028741851156155462, 0.020708168885903433, 0.009019790122692939, 0.03176228412485216, 0.054592230953858234, 0.03695180370414164, 0.009964113669411745, 0.045259119069669396, 0.030282146653917152, 0.058332914995844476, 0.037692259284085594, 0.05423238952062093, 0.0355259636125993, 0.033872877902467735, 0.026445712574059144, 0.026839397796720732, 0.05255668314930517, 0.3168777917744592, 0.04081086030055303, 12.851726431399584, 93.21818634867668, 90.75531050562859, 72.92074710130692, 75.71986690163612, 84.67194333672523, 47.369888350367546, 31.165509670972824, 32.41127662360668, 62.624485194683075, 69.73730072379112, 53.160025253891945, 71.18003770709038, 68.90390664339066, 56.28674067556858, 18.281727209687233, 1.0025900951586664, 0.2852899977006018, 0.08384635279071517, 0.16769003384979442, 0.09055827700649388, 0.05304140577209182, 0.047402281998074614, 0.06682031991658732, 0.2482937282184139, 0.03500181439449079, 0.6222655344754457, 1.164800541009754, 0.504137888783589, 0.5426646745763719, 1.2353096762672067, 2.794137792661786, 3.1300259940326214, 1.2876433180645108, 2.2862161975353956, 4.850357081741095, 8.226565215736628, 8.027544245123863, 7.247035726904869, 11.612829510122538, 10.930492524057627, 6.023397361859679, 7.200079271569848, 8.251919355243444, 9.134056270122528, 6.931462185457349, 12.094664555042982, 9.877019952982664, 17.203061990439892, 15.079250503331423, 9.442026894539595, 10.637221410870552, 10.707392245531082, 9.41589379683137, 5.642358558252454, 10.444669593125582, 2.6653344416990876, 2.585900891572237, 2.3994674580171704, 2.448022202588618, 2.6523581380024552, 1.7498593032360077, 1.75242202822119, 2.451592586003244, 2.0649495581164956, 1.5965315932407975, 0.5940926587209105, 0.7585470622871071, 0.2740511507727206, 0.5000280530657619, 2.331643234938383, 2.6119188079610467, 2.255561579950154, 4.804959017783403, 3.368510459549725, 2.5326165882870555, 0.8172200701665133, 0.19181312847649679, 0.5672593892086297, 0.724700556602329, 0.1642082628677599, 0.04067363348440267, 0.18035712913842872, 0.04034416073409375, 0.04910808245767839, 0.06276478714426048, 0.2522347995545715, 0.12600221845787019, 0.33428373746573925, 0.32313653093297035, 6.66245942004025, 49.49880011379719, 84.08634915947914, 65.2487763762474, 60.919600278139114, 77.55033507943153, 56.28611370921135, 36.745453253388405, 26.545979753136635, 21.09158143401146, 47.21213221549988, 57.902394980192184, 60.30728593468666, 80.61252236366272, 46.01633258163929, 4.939460400491953, 0.9098280477337539, 0.07063774202833883, 0.20034364104503766, 0.050384795395075344, 0.06963033592910506, 0.032678791976650245, 0.007586161655126489, 0.03732497410965152, 0.016678781976224855, 0.04641561521566473, 0.06539333320688456, 0.03132250225462485, 0.010458312590344576, 0.030925859573471826, 0.08380028768442571, 0.02779211132292403, 0.027772448120231275, 0.011726762641046662, 0.04649450180295389, 0.03697544110764284, 0.030074621754465625, 0.010357729315728648, 0.030452521496044938, 0.0599347516981652, 0.05334835434041452, 0.015071167654241435, 0.03793473377299961, 0.046698280712007545, 0.03859254749841057, 0.015392116838484071, 0.0222117971861735, 0.025315176753792912, 0.08879456305294298, 0.05651421161019243, 0.06209315833984874, 0.022519525009556673, 0.053927830667817034, 0.037459510640474036, 0.013260426585475216, 0.015586114241159521, 0.02840596021997044, 0.034272520715603605, 0.051642264443216845, 0.045787253620801494, 0.018639897934917826, 0.09135097978287376, 0.02992789730342338, 0.0295410268518026, 0.023176583599706646, 0.021377962730184663, 0.10381837797467597, 0.04800503949809354, 0.06563510265550576, 0.03776129015022889, 0.036594719349523075, 0.034787059121299535, 0.015815063088666648, 0.0633220880990848, 0.05495199446158949, 0.04279323693481274, 0.022977378175710328, 0.03863286096020602, 0.05905879479541909, 0.10073860612465069, 0.025158283024211414, 0.03403514107048977, 0.06663804102572612, 0.053381851175799966, 0.2698893944034353, 0.19019662693608552, 28.84729016572237, 119.0106551349163, 97.54295468330383, 97.48639851808548, 104.05373811721802, 109.06412646174431, 75.54797172546387, 46.99458248913288, 27.638898007571697, 40.94864711165428, 56.018425673246384, 50.92558175325394, 75.25236278772354, 79.70835328102112, 51.849118396639824, 11.630437765270472, 0.9300145832821727, 0.24652541294926777, 0.18508708861190826, 0.088939697452588, 0.20018863608129323, 0.3438235115027055, 0.29226179234683514, 0.3724897967185825, 0.8529549557715654, 0.9803407453000546, 0.7522587559651583, 0.27211527340114117, 0.6832678173668683, 1.365339767653495, 2.519802013412118, 4.983239276334643, 6.349288774654269, 4.79793319478631, 4.440214214846492, 3.373164259828627, 2.7940311608836055, 1.2316320673562586, 1.29764188779518, 1.658003032207489, 1.895998155232519, 3.5761477053165436, 8.305195346474648, 10.674111731350422, 15.227377004921436, 12.121393270790577, 18.80507692694664, 17.268826961517334, 13.665978088974953, 12.839569933712482, 14.734346810728312, 11.688956525176764, 14.238383173942566, 11.431154608726501, 4.830046221613884, 2.5851276330649853, 0.10404893357190304, 0.7147232419811189, 0.9717539779376239, 1.8833412718959153, 3.381661078892648, 3.8546478236094117, 3.6922996351495385, 4.627706604078412, 4.05213818885386, 3.4653470758348703, 2.017185646109283, 1.5748639684170485, 0.4476961330510676, 1.038299035280943, 2.369584674015641, 3.246948095038533, 3.206691867671907, 3.199380347505212, 1.994461202993989, 1.858544871211052, 0.316842999891378, 0.511830160394311, 0.44616819941438735, 0.549357837298885, 0.6236277020070702, 0.4385233955690637, 0.4261095210677013, 0.30812849407084286, 0.02565980230428977, 0.046620900684501976, 0.14220429671695456, 0.23539315327070653, 0.1163664401974529, 0.49757439410313964, 2.535936185158789, 42.609602585434914, 93.18727880716324, 73.31593349575996, 54.733049646019936, 45.13344995677471, 23.864568136632442, 25.39281003177166, 32.17207185924053, 39.61311377584934, 73.53521972894669, 78.88904124498367, 77.00990527868271, 92.36198589205742, 63.36258038878441, 9.65126171708107, 1.0275300568901002, 0.1195597235346213, 0.1994734283653088, 0.07041082295472734, 0.0095319536558236, 0.051932967398897745, 0.023250933809322305, 0.014489818331639981, 0.0254026889524539, 0.04533996121608652, 0.07356555172009394, 0.046074242127360776, 0.023689563495281618, 0.03577980038244277, 0.06337789760436863, 0.04997589057893492, 0.022104872259660624, 0.043548772955546156, 0.049699455412337556, 0.0538131948269438, 0.014435400353249861, 0.03443533678364474, 0.06210767103766557, 0.02226781078206841, 0.036167613361612894, 0.02098152970575029, 0.00856726279380382, 0.019999219330202322, 0.01104195700463606, 0.00947721006014035, 0.02044967328401981, 0.03215488024579827, 0.05590064472926315, 0.11526081085321493, 0.109651948150713, 0.08467807769193314, 0.1280158432200551, 0.09085329555091448, 0.16358214255888015, 0.12478309246944264, 0.16755435441154987, 0.16911525424802676, 0.1465150763397105, 0.2192217405536212, 0.08916517675970681, 0.18280777498148382, 0.09637054754421115, 0.33814489434007555, 0.09806346803088672, 0.14259631396271288, 0.22952037543291226, 0.16626015276415274, 0.1565713554737158, 0.22778167185606435, 0.08979733815067448, 0.13165848213247955, 0.11454733234131709, 0.1511850257520564, 0.1743287526187487, 0.09172602411126718, 0.09156102241831832, 0.12954864534549415, 0.09578153461916372, 0.1637774461414665, 0.13512223376892507, 0.08671277944813482, 0.21234966086922213, 0.19898432336049154, 0.30711083149071783, 0.37186241475865245, 29.44833431392908, 138.83646368980408, 112.5643390417099, 93.81209447979927, 96.48487105965614, 101.91718116402626, 57.44647644460201, 39.935321286320686, 44.226377829909325, 89.66527819633484, 96.27861052751541, 75.27857378125191, 98.8526152074337, 87.81125128269196, 70.63164353370667, 27.106768861413002, 2.2771028615534306, 0.3976236074231565, 0.3290308458963409, 0.43338488379959017, 0.2538387884851545, 0.3051699965726584, 0.31680399260949343, 0.29079426953103393, 0.3981684328755364, 0.6776168674696237, 2.4174768291413784, 3.3839483186602592, 2.549558929167688, 2.0776769751682878, 2.6157499523833394, 4.977533407509327, 5.731204440817237, 4.287564055994153, 6.6374885849654675, 8.783172648400068, 13.180848620831966, 15.981628932058811, 16.264176070690155, 21.66910484433174, 29.984194859862328, 19.66685738414526, 22.504400722682476, 19.275618977844715, 23.521535843610764, 23.645407296717167, 27.667848654091358, 25.49397200345993, 37.14575417339802, 26.239117719233036, 24.75195351988077, 19.483747109770775, 25.132892578840256, 25.6789992749691, 15.204165950417519, 20.310008972883224, 7.528154142200947, 5.520978346467018, 6.049681976437569, 6.226209104061127, 3.867464060895145, 2.928856238722801, 1.9355875183828175, 2.909901668317616, 2.560960929840803, 2.134752762503922, 1.1049125483259559, 0.8068155159708112, 0.24022765166591853, 0.7633135502692312, 2.8065142035484314, 4.520746618509293, 5.660989433526993, 9.332404676824808, 7.508029472082853, 7.1550659369677305, 1.8841520533896983, 3.9562907069921494, 2.2521674120798707, 1.9325292762368917, 0.7008080917876214, 0.40083363361191005, 0.4713865555822849, 0.19869219919200987, 0.21136861585546285, 0.21304209949448705, 0.4039798054145649, 0.32566784822847694, 0.37649356469046324, 0.6180047162342817, 9.807232897728682, 64.09683018922806, 103.9484229683876, 81.07046619057655, 85.23914650082588, 107.77404248714447, 72.04096511006355, 47.54234969615936, 33.65434572100639, 27.37693816423416, 63.644221276044846, 77.2993129491806, 76.37411579489708, 106.85639932751656, 70.98965272307396, 8.759391624480486, 1.2763521051965654, 0.23076470475643873, 0.3124787559499964, 0.11428092358983122, 0.12402812790242024, 0.19174255023244768, 0.15023770392872393, 0.13667357474332675, 0.21845443407073617, 0.17017296311678365, 0.1941018970683217, 0.13039598503382877, 0.11861888808198273, 0.14943017304176465, 0.14255182963097468, 0.08545295408111997, 0.11808116498286836, 0.10523276301682927, 0.1237197729642503, 0.10885309297009371, 0.15056476840982214, 0.14345324219902977, 0.21382375911343843, 0.15815310965990648, 0.17420681775547564, 0.08536564040696248, 0.2667426288826391, 0.1392343849875033, 0.12143887113779783, 0.09456472413148731, 0.08121872699121013, 0.1232560642529279, 0.19324900611536577, 0.19177070731529966, 0.1658860212774016, 0.11425865915953182], [0.03025162954145344, 0.048850304883671924, 0.04677869983424898, 0.020882937242276967, 0.04014435973658692, 0.029562241143139545, 0.03776355370064266, 0.058075167107745074, 0.018514699477236718, 0.049727467776392587, 0.061858357657911256, 0.034643564868019894, 0.019618883488874417, 0.027050414500990883, 0.05029009364079684, 0.029796509334119037, 0.04742103235912509, 0.1329685063683428, 0.036281202774262056, 0.020237771568645258, 0.02513389234081842, 0.05430760247691069, 0.03697565261973068, 0.037879083829466254, 0.08821283801808022, 0.025841814021987375, 0.03387036944332067, 0.07256205673911609, 0.05089468424557708, 0.04044759014504962, 0.03142983536235988, 0.1356511772610247, 0.18549423082731664, 13.312453608959913, 102.95852288603783, 83.93304258584976, 94.74550679326057, 69.76659715175629, 60.23405246436596, 57.17808544635773, 34.95892211794853, 61.19518429040909, 81.18082746863365, 57.539845034480095, 45.93802258372307, 84.74914759397507, 89.18800860643387, 39.12391282618046, 2.6650183461606503, 0.5197835492435843, 0.05718853812140878, 0.2954578067874536, 0.059257241373416036, 0.04904762339720037, 0.018400777953502256, 0.07026488703559153, 0.0263894188174163, 0.16968704934697598, 2.2531957319006324, 2.188007617369294, 0.5132912413682789, 2.4547592410817742, 3.116977969184518, 6.984286475926638, 10.710869058966637, 17.232563607394695, 17.33230445533991, 14.761150572448969, 10.121961459517479, 5.972446370869875, 4.842129573225975, 3.8930604374036193, 4.239336093887687, 5.827040048316121, 5.378450844436884, 6.363342795521021, 10.335396006703377, 14.901597686111927, 20.341659374535084, 11.86808841302991, 15.397546123713255, 11.752682905644178, 17.723390869796276, 15.855665691196918, 8.31779072061181, 4.251247504726052, 9.299175459891558, 5.300725540146232, 2.5075327092781663, 2.5075507583096623, 1.7135958303697407, 1.5935722645372152, 5.84342809394002, 18.075609169900417, 37.3051518201828, 56.94682605564594, 66.1170069873333, 65.97631573677063, 67.0741680264473, 54.98501792550087, 38.62528458237648, 25.110663771629333, 26.423516124486923, 22.42222063243389, 16.28464177250862, 11.306268610060215, 7.941343495622277, 6.592678064480424, 3.4953723521903157, 1.4734235429205, 1.1502220295369625, 2.2285393299534917, 1.5031913830898702, 0.46599028108175844, 0.3211485844803974, 0.20603300450602546, 0.3214442858006805, 0.024932959568104707, 0.08749247237574309, 0.11380159266991541, 0.19573940138798207, 0.017972271161852404, 0.11809280927991495, 0.17291365511482581, 0.5348552030045539, 0.19160808791639283, 16.75066016614437, 82.97373086214066, 81.44115909934044, 53.509883880615234, 66.14200964570045, 68.07606026530266, 48.809156119823456, 37.114307060837746, 25.88339600712061, 48.06729532778263, 48.52958232164383, 49.51144963502884, 88.32742318511009, 58.61511513590813, 14.063453860580921, 0.42179506039246917, 0.0518911473773187, 0.011852129009639611, 0.05345031800970901, 0.024409882753388956, 0.018477488192729652, 0.020527372435026336, 0.020132488643866964, 0.09808890143176541, 0.026723435366875492, 0.054069465841166675, 0.10545023455051705, 0.13569738337537274, 0.04877503255556803, 0.06024686561431736, 0.021200136725383345, 0.03305639300378971, 0.018502416933188215, 0.038811718550277874, 0.020427841154742055, 0.057305281661683694, 0.12712133262539282, 0.02712673696805723, 0.044903403977514245, 0.052510851819533855, 0.02511128466721857, 0.002362526938668452, 0.029891066369600594, 0.028169716060801875, 0.045210597454570234, 0.014950803360989084, 0.035180942868464626, 0.05333488807082176, 0.04578704210871365, 0.008549369613319868, 0.0453985277999891, 0.05380711663747206, 0.05144565839145798, 0.020029999905091245, 0.07445641836966388, 0.06577272652066313, 0.02372992705204524, 0.029837770889571402, 0.05660844581143465, 0.042507599137024954, 0.07602448735269718, 0.021609969226119574, 0.020806082284252625, 0.04423774575116113, 0.020665352531068493, 0.03717114173923619, 0.1154429190501105, 0.022297287032415625, 0.058246180196874775, 0.01586977236001985, 0.031011961691547185, 0.06209642378962599, 0.035533396221580915, 0.19613207172369584, 0.044798286180594005, 0.033231680863536894, 0.07436802858137526, 0.06488942977739498, 0.12492165144067258, 0.07414004081510939, 0.029540908108174335, 0.1669729856075719, 0.0974209388368763, 31.901564374566078, 123.28018203377724, 94.43161323666573, 120.77085748314857, 99.97379824519157, 91.34516805410385, 77.39379867911339, 37.49450705945492, 31.545513980090618, 45.356570184230804, 45.33279865980148, 46.21266804635525, 91.53587222099304, 94.6912457048893, 33.41268248856068, 0.9885326307266951, 0.5558978801127523, 0.06641896645305678, 0.09750775527209044, 0.12471968337194994, 0.2830066764727235, 0.1934522358351387, 0.19680147408507764, 0.24414087762124836, 0.3765802178531885, 0.8430843916721642, 2.270464380271733, 1.8365484452806413, 4.890566524118185, 5.103489048779011, 10.11421462520957, 15.182243026793003, 23.44442468136549, 21.269810870289803, 18.651325777173042, 12.527470830827951, 8.815848995000124, 5.267768958583474, 3.860348230227828, 2.5235590618103743, 1.8706353474408388, 0.7818146981298923, 1.4007637230679393, 1.4540727250277996, 2.597779054194689, 4.394555389881134, 9.316376186907291, 11.21904619038105, 8.681126274168491, 14.94712209329009, 26.482127979397774, 8.49707555025816, 3.5029892809689045, 10.618201531469822, 5.255711730569601, 1.9054519291967154, 0.796088216593489, 2.352117723785341, 2.984800636768341, 8.043198455125093, 25.073456168174744, 49.06007945537567, 71.23867616057396, 82.04605624079704, 81.01429760456085, 81.99223592877388, 70.31101673841476, 55.370511040091515, 41.89736120402813, 44.31283079087734, 41.54136970639229, 36.36828549206257, 28.82337424904108, 24.073000252246857, 17.19066895544529, 11.517897304147482, 4.962468640878797, 1.551191476173699, 2.1610297774896026, 1.5292451600544155, 0.7816465571522713, 0.2204597764648497, 0.6379852909594774, 0.6035629380494356, 0.18874888977734372, 0.21527001197682694, 0.19916438322979957, 0.23870623408583924, 0.041981208632932976, 0.09307066211476922, 0.1703668269328773, 0.2924227196490392, 0.5817569175269455, 8.960942309349775, 80.65750434994698, 91.47654220461845, 63.21549408137798, 46.58133186399937, 38.96036960184574, 21.663619838654995, 19.14323218166828, 34.719633758068085, 77.1581581234932, 76.22221514582634, 71.96239292621613, 99.85845923423767, 75.81363067030907, 25.23499310016632, 0.23162206343840808, 0.0642959788092412, 0.033252980501856655, 0.03190437571902294, 0.0625808235781733, 0.08727600274141878, 0.13095942354993895, 0.06743622085195966, 0.08600358312833123, 0.038499649162986316, 0.07238905469421297, 0.015801474364707246, 0.06520285358419642, 0.038045759065425955, 0.04951512448315043, 0.016467616842419375, 0.023880621993157547, 0.034248271040269174, 0.024328515537490603, 0.10637022307491861, 0.10746979649411514, 0.0507210550858872, 0.03632734209531918, 0.022835446143290028, 0.09369815539685078, 0.06293608967098407, 0.028836105302616488, 0.02283335885294946, 0.06492144602816552, 0.06874122816952877, 0.09969709091819823, 0.0936601277498994, 0.005445738643174991, 0.08777254406595603, 0.02266564089950407, 0.12824326695408672, 0.2576813619816676, 0.32554868899751455, 0.09367103732074611, 0.1387386748683639, 0.09691448984085582, 0.07423458300763741, 0.14261221076594666, 0.21115152281709015, 0.11887986431247555, 0.16936727275606245, 0.11425742719438858, 0.08369847986614332, 0.08600827350164764, 0.19394524453673512, 0.10418269084766507, 0.19387379055842757, 0.15525943133980036, 0.26201185304671526, 0.1763878858764656, 0.11775374427088536, 0.13427318714093417, 0.15693436958827078, 0.44462082150857896, 0.20776578574441373, 0.09637924551498145, 0.18829905922757462, 0.12947419309057295, 0.18506828258978203, 0.15420662064570934, 0.10178142751101404, 0.28718107903841883, 0.29552691557910293, 35.134286507964134, 144.01148200035095, 101.2872813642025, 119.44290474057198, 91.79598346352577, 76.0333500802517, 65.816450715065, 49.3272203207016, 81.90498501062393, 106.0406742990017, 79.62788119912148, 64.7326272726059, 106.10926821827888, 105.40717989206314, 52.42807812988758, 6.596845965832472, 1.2220230954699218, 0.1857206303975545, 0.6124532141257077, 0.25589290482457727, 0.23980168858543038, 0.17298046324867755, 0.12405979534378275, 0.1856557370047085, 0.35242040175944567, 4.132112022489309, 6.166723296046257, 2.5340272625908256, 5.906382165849209, 4.965752139687538, 8.793111015111208, 13.091782350093126, 22.92931292206049, 21.185474395751953, 18.735422864556313, 11.524922177195549, 10.433791726827621, 8.39922795072198, 8.49482037127018, 12.041980382055044, 14.980669543147087, 13.629231210798025, 21.948025077581406, 31.283120959997177, 34.27281193435192, 40.39690151810646, 29.002017863094807, 31.39430109411478, 29.920609071850777, 33.97638984024525, 31.452684961259365, 17.846126183867455, 11.228766068816185, 21.862162984907627, 13.30219890922308, 8.421213570982218, 6.042712675407529, 4.673792431131005, 2.699747057631612, 7.0384069718420506, 24.56460267305374, 53.4136426448822, 80.01470804214478, 94.89109978079796, 94.10387322306633, 92.02159255743027, 78.80885034799576, 63.857435435056686, 48.11410501599312, 55.93521013855934, 51.966710686683655, 42.37078160047531, 34.030479937791824, 28.161869645118713, 19.16340909898281, 12.430249247699976, 5.082367407158017, 1.9393488415516913, 3.66410443559289, 3.410161924548447, 2.3906958661973476, 1.2546106218360364, 1.4017921616323292, 0.4549625900108367, 0.11441607610322535, 0.20911045343382284, 0.1609598528011702, 0.3244914551032707, 0.104041371087078, 0.4900263069430366, 0.25979096128139645, 0.6328827585093677, 0.5645330355037004, 22.78485417366028, 102.19205841422081, 96.24419197440147, 72.54792630672455, 98.98636043071747, 92.86722958087921, 66.92368850111961, 47.625101655721664, 28.466862179338932, 63.61774429678917, 65.2996252477169, 66.71013236045837, 110.64194619655609, 85.98951503634453, 25.544165410101414, 0.4428682546131313, 0.15488611621549353, 0.14311511971754953, 0.19638135912828147, 0.20088567602215335, 0.18512456706957892, 0.17823381494963542, 0.21540955058299005, 0.2634787524584681, 0.11725076852599159, 0.14539594732923433, 0.37032705964520574, 0.25134814088232815, 0.08749010492465459, 0.19756759313168004, 0.1189148417324759, 0.08345964932232164, 0.11266227724263445, 0.11708060148521326, 0.16190184600418434, 0.21177869697567075, 0.23710649023996666, 0.11199304557521828, 0.08516749439877458, 0.19572243589209393, 0.15204406168777496, 0.11851721385028213, 0.06291808516834863, 0.15883457934251055, 0.11590098001761362, 0.1595144608290866, 0.16315660992404446, 0.12234170120791532, 0.167209864303004, 0.0730189451132901], [0.07815053264494054, 0.011648634899756871, 0.017587421207281295, 0.07816038836608641, 0.05550530637265183, 0.046921496468712576, 0.06478570721810684, 0.018057286033581477, 0.046858024288667366, 0.04954296244250145, 0.019910907467419747, 0.0505704696115572, 0.038819351539132185, 0.0369989968748996, 0.03767177971894853, 0.02177960934204748, 0.031083042740647215, 0.10917301056906581, 0.03603465018386487, 0.011704636435752036, 0.04297378291084897, 0.09631197724957019, 0.04928961177938618, 0.11547880931175314, 0.03502979707263876, 0.1309037476312369, 0.0907152338186279, 0.0905463655362837, 0.06526134966406971, 0.046540028852177784, 0.10987838482833467, 0.38500516733620316, 24.91095408797264, 101.01602911949158, 90.44593870639801, 103.654805123806, 67.63356640934944, 44.38747398555279, 36.52199484407902, 35.90960830450058, 71.54445335268974, 101.86640828847885, 75.59281691908836, 70.58543801307678, 119.66646194458008, 79.74553048610687, 11.770473551005125, 0.34345326886978, 0.05899733383557759, 0.07936271213111468, 0.2655538567341864, 0.14862967771477997, 0.018187915156886447, 0.09855228359811008, 0.43482625333126634, 0.9218221041373909, 1.631370261311531, 1.2466096761636436, 3.685415117070079, 5.637044543400407, 6.220733597874641, 13.01458664238453, 19.089723452925682, 24.24718100577593, 33.105081394314766, 31.726055592298508, 31.172286607325077, 25.31017016619444, 22.771045714616776, 18.065309822559357, 15.232691019773483, 8.236343041062355, 3.1368701392784715, 1.857690867036581, 0.5481140571646392, 0.6616410403512418, 4.168912572786212, 7.870486322790384, 12.50286715105176, 8.314260710030794, 16.496393010020256, 14.866705108433962, 9.13133941590786, 15.45225178822875, 9.960140492767096, 2.565351356752217, 3.773149559274316, 1.5866512921638787, 1.400671221781522, 1.0985085857100785, 3.964205444790423, 11.713606752455235, 36.048924028873444, 58.575882241129875, 66.30833432078362, 59.470719024538994, 55.95032952725887, 55.678385719656944, 56.53067618608475, 61.270994022488594, 59.65144872665405, 48.57801832258701, 41.67042218148708, 41.46669991314411, 52.28738307952881, 56.61361813545227, 62.79365211725235, 62.41306833922863, 63.49029913544655, 47.550222873687744, 24.883071184158325, 4.482085593044758, 2.057928959839046, 1.9344582664780319, 2.112007183022797, 1.2980541656725109, 1.2193786748684943, 1.177894282154739, 0.18198629171820357, 0.10288568388205022, 0.10002695329603739, 0.0488060023781145, 0.2102311112685129, 0.059608362571452744, 0.773416911251843, 0.1528072715154849, 0.46167650318238884, 3.2060530269518495, 62.71461635828018, 89.79210019111633, 50.55253677070141, 44.69239242374897, 66.44438982009888, 85.72976857423782, 40.18099710345268, 17.372724786400795, 26.536837443709373, 36.20808228850365, 49.38473783433437, 72.280253469944, 73.59875231981277, 33.67813244462013, 0.43058508716057986, 0.13996416848385707, 0.047769518932909705, 0.10906954776146449, 0.06908483512233943, 0.04437559597135987, 0.03793941672483925, 0.1020481924933847, 0.011024320792785147, 0.021580847351287957, 0.0862189989129547, 0.08870128993294202, 0.05818209203425795, 0.04747087870782707, 0.03568001491657924, 0.02097067208524095, 0.04203114775009453, 0.024170057731680572, 0.1345628622220829, 0.0815596770553384, 0.08682572690304369, 0.02443310269882204, 0.054449816525448114, 0.10099408304085955, 0.037608556158374995, 0.03834354953141883, 0.019692025853146333, 0.018247999432787765, 0.05266663232760038, 0.010016859960160218, 0.05505664841621183, 0.03643595911853481, 0.01998105155507801, 0.04219463175104465, 0.061671128642046824, 0.03030530166142853, 0.08393290947424248, 0.058570231558405794, 0.036626472137868404, 0.09226778449374251, 0.03338353541039396, 0.04518809924775269, 0.030604183084506076, 0.054147662231116556, 0.033962892994168214, 0.09806859627133235, 0.002458693275002588, 0.013098225572321098, 0.04054596181958914, 0.039584554033353925, 0.020044278826389927, 0.049093855486717075, 0.0349730635934975, 0.036661442136392, 0.03630734121543355, 0.056799559970386326, 0.02913031119533116, 0.030281747749540955, 0.02697990490560187, 0.14673558325739577, 0.09804960471228696, 0.02711624671064783, 0.06668238434940577, 0.06004683455103077, 0.06452364003052935, 0.36220698442775756, 43.60973171889782, 122.16013133525848, 100.32135039567947, 133.8228303194046, 97.44407638907433, 69.90288063883781, 53.596982806921005, 24.58664909005165, 29.109620489180088, 70.84346696734428, 68.28543663024902, 76.48160442709923, 129.27570551633835, 74.03103992342949, 7.08213122561574, 0.5916441057343036, 0.07535262106102891, 0.25848887802567333, 0.27579781017266214, 0.2834767528111115, 0.23968016932485625, 0.14527003455441445, 1.3292280491441488, 0.7756001316010952, 0.680306232534349, 0.6683030922431499, 3.857417874969542, 6.23793669976294, 10.150421932339668, 17.027101032435894, 25.489104464650154, 31.15489114075899, 36.22128278017044, 37.01357826590538, 35.75322389602661, 32.43227429687977, 29.115183390676975, 25.586221553385258, 20.819983407855034, 12.087161857634783, 5.550565458834171, 2.5113154063001275, 1.1853695497848094, 0.1841571627301164, 1.3798945304006338, 0.9633791085798293, 1.7820790805853903, 2.877862975001335, 3.597344155423343, 5.034830057993531, 9.74589278921485, 15.299504734575748, 13.354365359991789, 5.552950305864215, 5.738273486495018, 1.4315603580325842, 0.48018091649282724, 2.097005588002503, 5.890601137652993, 17.31790892779827, 47.107409834861755, 72.94204115867615, 78.25979501008987, 70.06187170743942, 67.08976998925209, 66.59401819109917, 67.16427639126778, 72.74424657225609, 70.5492639541626, 61.81584678590298, 51.54631644487381, 49.044184908270836, 57.1967538446188, 66.56127914786339, 73.1642684340477, 78.51764917373657, 79.13852825760841, 67.41136953234673, 44.29244488477707, 19.495298489928246, 4.156354246661067, 2.1690604090690613, 2.131184753961861, 1.1479075974784791, 0.7859713188372552, 1.119215099606663, 0.876600849442184, 0.1329539602738805, 0.2802029316080734, 0.1701955244061537, 0.20113080739974976, 0.15251305449055508, 0.2988297102274373, 0.1756361941806972, 0.2191723432042636, 0.42722116922959685, 55.11552572250366, 103.01212280988693, 60.747727900743484, 40.052921175956726, 61.28868967294693, 45.72753667831421, 7.101518260315061, 16.552405804395676, 41.908574402332306, 66.00132599473, 74.92450878024101, 86.09317347407341, 88.40167120099068, 50.10824181139469, 0.772336641093716, 0.28208920382894576, 0.04020070729893632, 0.1536205763113685, 0.11255432444158942, 0.01550080900415196, 0.021698633609048557, 0.021766577228845563, 0.0806792895309627, 0.03309408297354821, 0.06976271281018853, 0.14766721607884392, 0.05815773103677202, 0.04474125584238209, 0.02067691890260903, 0.02523926432331791, 0.03885735321091488, 0.05871734749234747, 0.04809356287296396, 0.1596650277497247, 0.11645581704215147, 0.10897459738771431, 0.08393201147555374, 0.1170618028845638, 0.0276462459078175, 0.05294800648698583, 0.027656404054141603, 0.032230549622909166, 0.09125493103056215, 0.020899091941828374, 0.008398028076044284, 0.02044570279394975, 0.0064974722954502795, 0.06484838901087642, 0.17203556082677096, 0.13601756072603166, 0.15153226180700585, 0.20321762276580557, 0.15251679491484538, 0.20153265068074688, 0.18328065663808957, 0.1334919431246817, 0.12981234525796026, 0.1331987205776386, 0.15565176028758287, 0.1759494695579633, 0.15542303037364036, 0.08411844639340416, 0.14483483915682882, 0.15693180175730959, 0.15174508007476106, 0.2660883218050003, 0.10437871431349777, 0.24954107066150755, 0.08958403748692945, 0.22699791938066483, 0.12246617421624251, 0.22825106541858986, 0.14696480298880488, 0.3020353429019451, 0.1765530731063336, 0.1989440989564173, 0.21890012343646958, 0.14805181184783578, 0.14856751542538404, 0.6130008003674448, 45.1679141074419, 141.05262637138367, 109.66433465480804, 131.8620291352272, 84.0791903436184, 56.17461249232292, 48.44599820673466, 47.09007516503334, 99.74168390035629, 143.21577429771423, 102.51159846782684, 93.55307757854462, 136.97210133075714, 94.04087260365486, 16.896785125136375, 1.0317927156575024, 0.09942197677446529, 0.5678401642944664, 0.4537531564710662, 0.27338398969732225, 0.21216433175140992, 0.18065413663862273, 0.6520426366478205, 1.5686355088837445, 4.124639248475432, 2.436036220751703, 7.858896469697356, 8.453486189246178, 8.008140586316586, 15.097558870911598, 23.82825158536434, 29.82169847935438, 37.46656335890293, 38.33283707499504, 38.419069647789, 31.984012350440025, 30.358664765954018, 24.07772909849882, 20.989038236439228, 12.813190799206495, 6.595093784853816, 4.27289541810751, 4.107378674671054, 4.9380378518253565, 12.330624293535948, 17.83344056457281, 29.293940998613834, 24.271910078823566, 30.736045315861702, 31.947454512119293, 19.820580035448074, 26.30467750132084, 20.58680322021246, 8.808969464153051, 9.510073643177748, 3.9536149380728602, 3.268083273433149, 2.8278132481500506, 5.366555582731962, 18.136113323271275, 51.41738176345825, 81.33380725979805, 84.9104717373848, 76.9388946890831, 70.99893182516098, 73.2346710562706, 70.92814922332764, 76.14712357521057, 71.50833249092102, 61.69189743697643, 53.16337667405605, 51.9738695025444, 68.17221030592918, 75.57791411876678, 84.89586532115936, 89.92247119545937, 89.66291472315788, 77.22235187888145, 52.003644704818726, 25.346336625516415, 6.632681842893362, 2.6465539494529366, 6.041006566956639, 4.605988869443536, 4.921150133013725, 3.945528259500861, 1.2920433632098138, 0.14542484655976295, 0.3191558882826939, 0.22507572721224278, 0.38834316947031766, 0.28416145825758576, 1.1219026241451502, 0.20506892498815432, 0.6857594742905349, 4.684943407773972, 76.98962956666946, 104.84824508428574, 64.88821372389793, 68.5589687526226, 93.64640817046165, 122.82628118991852, 55.820357501506805, 22.927110940217972, 33.4442587941885, 50.85963249206543, 66.97722762823105, 92.81055942177773, 99.25917819142342, 59.15217071771622, 0.9600016835611314, 0.3458932426292449, 0.18364172632573172, 0.19074589043157175, 0.2982702199369669, 0.21798364527057856, 0.12506029946962371, 0.20403796312166378, 0.1381767651764676, 0.14913313585566357, 0.22018141171429306, 0.2870009152684361, 0.11257403588388115, 0.13855604716809466, 0.07368455510004424, 0.17565574235050008, 0.11873762428876944, 0.12960172374732792, 0.18324798729736358, 0.2936841332120821, 0.17949758854229003, 0.19851271819788963, 0.17587319161975756, 0.1837061150581576, 0.11190363904461265, 0.11526484071509913, 0.12177219934528694, 0.1293462616740726, 0.17469807498855516, 0.16089264390757307, 0.13988095888635144, 0.10628374802763574, 0.1643058256013319, 0.2769268839620054], [0.07433328864863142, 0.05432669793663081, 0.05048583137977403, 0.04148187683313154, 0.0278244745277334, 0.06916667916812003, 0.10260371971526183, 0.11392346073989756, 0.03903638520569075, 0.035698865467566065, 0.03201780928066, 0.10795168040203862, 0.017299681276199408, 0.026454019061930012, 0.09611298519303091, 0.05480613275722135, 0.11944803030928597, 0.043165746828890406, 0.09108816302614287, 0.03492828611342702, 0.10024343777331524, 0.057952619972638786, 0.06147781772597227, 0.16639183944789693, 0.022548884371644817, 0.01741225951263914, 0.15572530712233856, 0.05380169895943254, 0.0020157514791208087, 0.019875848411174957, 0.10214312802418135, 32.01388634741306, 91.30599215626717, 91.53331115841866, 89.1957525908947, 60.341822281479836, 35.395153909921646, 34.29376021027565, 56.31273128092289, 76.01563543081284, 86.6454054415226, 68.29221546649933, 85.38805291056633, 119.28256094455719, 52.93630465865135, 3.0463027115911245, 0.8830510033294559, 0.38289429154247046, 0.1321520993951708, 0.057221901370212436, 0.06423136001103558, 0.09163095499388874, 0.582934794947505, 1.1582495737820864, 0.6568297266494483, 2.36903702840209, 2.4328807275742292, 3.8744390616193414, 5.425162212923169, 13.86961866170168, 23.078261129558086, 33.52063089609146, 42.68565930426121, 45.99954508244991, 48.00831489264965, 59.5528744161129, 60.029566437006, 58.83844435214996, 55.802160277962685, 51.34407989680767, 37.00508952140808, 31.26666784286499, 25.020378716289997, 16.023533083498478, 6.136000044643879, 3.5554932011291385, 0.2728531166212633, 0.3666317282477394, 0.7633766625076532, 2.793096648529172, 5.754540888592601, 3.980927634984255, 2.356260451488197, 8.464385904371738, 6.6630469635128975, 1.65634679608047, 3.043588944710791, 2.4313840828835964, 3.4195246221497655, 7.240569423884153, 25.30165482312441, 42.323766723275185, 61.037690341472626, 68.54863330721855, 78.32700580358505, 90.07247194647789, 90.89944437146187, 89.43255588412285, 93.64133924245834, 88.87921437621117, 90.11273458600044, 87.52216279506683, 77.27765411138535, 59.541475027799606, 42.269615828990936, 40.97774215042591, 43.24044853448868, 46.48912601172924, 47.462010607123375, 48.72100464999676, 52.88199417293072, 40.66324822604656, 28.131566271185875, 7.804630631580949, 4.189122263342142, 2.437883634120226, 2.5984789291396737, 1.7507498804479837, 0.8404886559583247, 0.6258256465662271, 0.2869389014085755, 0.09878272787318565, 0.3282114851754159, 0.01793113577150507, 0.418232306255959, 0.03907787497155368, 1.00760962581262, 0.03804520245466847, 1.0725995572283864, 42.69554257392883, 100.58963879942894, 77.06920489668846, 57.56568744778633, 93.85493338108063, 127.43461310863495, 82.70318537950516, 42.11606606841087, 22.185607329010963, 44.69322457909584, 51.5254707634449, 58.54709878563881, 73.83316174149513, 45.723056718707085, 1.4888805197551847, 0.4432212497340515, 0.13554889446822926, 0.3342998865991831, 0.015038402762002079, 0.11432692190282978, 0.08573009428801015, 0.07696215383475646, 0.06173078618303407, 0.04713609960163012, 0.06262248774874024, 0.04918273880321067, 0.018092777390847914, 0.025407652065041475, 0.03523697130731307, 0.08995436175609939, 0.07207152681075968, 0.023417030170094222, 0.033694350568111986, 0.2367380287614651, 0.27379398175980896, 0.24842338141752407, 0.16138548933668062, 0.0750037819670979, 0.11880064004799351, 0.030725225515197963, 0.025523260119371116, 0.03877087445289362, 0.08048405274166726, 0.08328059877385385, 0.05341511052392889, 0.04990301909856498, 0.040230890444945544, 0.09424597170436755, 0.08663398562930524, 0.07355762558290735, 0.06334009260172024, 0.06233961816178635, 0.0644052674761042, 0.08996961289085448, 0.1114407392742578, 0.06605589296668768, 0.037218071447568946, 0.026921249263978098, 0.09516265767160803, 0.05983809067402035, 0.04128625041630585, 0.043608137348201126, 0.07022783160209656, 0.15029872331069782, 0.1189522682398092, 0.03777159858145751, 0.07726901705609635, 0.03503335938148666, 0.059814776104758494, 0.1383770114625804, 0.1775450722198002, 0.1222819063696079, 0.020531376321741845, 0.05529366069822572, 0.02986346218676772, 0.13874764001229778, 0.07376510780886747, 0.33649462508037686, 52.99996644258499, 107.38707885146141, 105.10257303714752, 110.70515960454941, 86.9924484193325, 64.17986333370209, 39.72934193909168, 23.40587195008993, 37.44118832051754, 65.0248771905899, 66.80895745754242, 94.73857596516609, 124.37299579381943, 45.282215774059296, 2.2543012350797653, 0.457386503694579, 0.33266425249166787, 0.10315500927390531, 0.03367955214343965, 0.03154340622131713, 0.47787503397557884, 1.1924078408628702, 2.158179455436766, 1.9469654140993953, 0.9851680893916637, 2.208347450941801, 4.3090191297233105, 7.954947715625167, 17.65709202736616, 28.090463876724243, 38.86576987802982, 47.27178901433945, 56.29234537482262, 61.7594388127327, 67.50829473137856, 69.13661375641823, 65.81037104129791, 64.56513226032257, 59.53319527208805, 48.67691181600094, 44.421086981892586, 36.088799089193344, 23.58600128442049, 13.298989031463861, 7.260822337120771, 2.0350150018930435, 0.70214330451563, 0.6279057380743325, 0.06574770872248337, 2.4510430404916406, 2.2687406977638602, 2.451072013936937, 6.183060519397259, 8.012803886085749, 3.534687180072069, 4.834890011698008, 3.836993733420968, 3.310578055679798, 11.488986555486917, 31.867242716252804, 58.42679724097252, 77.94014096260071, 83.11154946684837, 93.13434764742851, 102.68661707639694, 106.77059233188629, 103.13535779714584, 106.49818494915962, 100.81299841403961, 102.19723373651505, 101.04332685470581, 93.91290307044983, 74.16738420724869, 56.988194435834885, 49.06391724944115, 49.563282653689384, 53.071376010775566, 54.85861390829086, 57.11272895336151, 62.25160740315914, 55.61315841972828, 49.95277315378189, 25.923035480082035, 9.935934841632843, 6.182691939175129, 3.4600546723231673, 1.6573143191635609, 0.7709164079278708, 0.3972969140158966, 0.30632083013188094, 0.13051161164185032, 0.18998576793819666, 0.08237071087933145, 0.3476363397203386, 0.21555259212618694, 0.5997691978700459, 0.04999363161914516, 0.6208551570307463, 33.252771869301796, 107.63550192117691, 82.59850099682808, 55.01978985965252, 97.78427213430405, 105.2851152420044, 41.81626595556736, 15.574153997004032, 28.813867159187794, 70.45312911272049, 81.00441053509712, 79.11758378148079, 82.16810569167137, 67.67807722091675, 3.0393545469269156, 0.45378450478892773, 0.12293906329432502, 0.16346762917237356, 0.06711692665703595, 0.050548416693345644, 0.12680047249887139, 0.14122201973805204, 0.1342551232664846, 0.020128763062530197, 0.11674048262648284, 0.030128136168059427, 0.006613418490815093, 0.051420495874481276, 0.08778550938586704, 0.1845566905103624, 0.07765982460114174, 0.055389097178704105, 0.08196179493097588, 0.17844985413830727, 0.13525237678550184, 0.17400700191501528, 0.20132952486164868, 0.17106751824030653, 0.15909240144537762, 0.044151664042146876, 0.024040181888267398, 0.03585125436075032, 0.10350627519073896, 0.058705439732875675, 0.048916278101387434, 0.09986695367842913, 0.07003377482760698, 0.22979685512837023, 0.1977268877089955, 0.14004938188008964, 0.15252654673531651, 0.08109803893603384, 0.17669930588454008, 0.19155288697220385, 0.21876563143450767, 0.1816597764263861, 0.17439752002246678, 0.11291491915471852, 0.18422432709485292, 0.2047656537615694, 0.15225230832584202, 0.2648347453214228, 0.13316369120730087, 0.15204581315629184, 0.24878051772248, 0.11149058191222139, 0.15222144982544705, 0.33787849301006645, 0.21035785524873063, 0.2399321284610778, 0.3278589650290087, 0.2256467059487477, 0.1309637725353241, 0.4039608361199498, 0.16463391424622387, 0.26232002244796604, 0.17881518375361338, 0.3396011661970988, 54.009800255298615, 128.71113181114197, 111.64037302136421, 114.64997112751007, 73.70272994041443, 47.29014202952385, 50.734755992889404, 77.74449706077576, 108.94678875803947, 125.9468561410904, 86.3117453455925, 100.84550186991692, 134.36659634113312, 67.99422025680542, 5.534641463309526, 0.9950226824730635, 0.610659591620788, 0.6224806979298592, 0.3159025206696242, 0.23717999254586175, 0.2764038776513189, 1.183551822323352, 3.3615801064297557, 3.2657295372337103, 5.828925222158432, 6.491707507520914, 6.245988942682743, 7.47237503528595, 17.17569585889578, 27.57852304726839, 41.599445790052414, 48.971012234687805, 59.82186198234558, 64.0466196835041, 70.60287907719612, 71.45807638764381, 68.37258115410805, 66.41754806041718, 64.35365840792656, 49.03452582657337, 41.80951751768589, 32.47151859104633, 19.683456793427467, 9.28691066801548, 5.549452593550086, 1.4674798306077719, 1.3675513677299023, 3.657880607061088, 10.88986985385418, 13.170000202953815, 8.989237491041422, 5.583758102729917, 16.8778982385993, 15.454220082610846, 6.1314398143440485, 9.085127245634794, 6.289879912510514, 5.086320145055652, 11.807905342429876, 32.65833176672459, 64.45854038000107, 86.00573256611824, 87.31103092432022, 96.57291993498802, 107.98200532793999, 107.75033175945282, 106.4654915034771, 109.285449385643, 102.82863065600395, 104.04408663511276, 99.84225690364838, 88.37071806192398, 71.0980761051178, 55.46453319489956, 51.982301250100136, 52.813837230205536, 59.30383577942848, 62.20119170844555, 64.59410950541496, 71.55455321073532, 66.47942394018173, 61.79104171693325, 35.41175901889801, 10.850992240011692, 7.024159636348486, 7.975257150828838, 8.027785532176495, 5.3428158815950155, 3.8497221004217863, 0.8724508783780038, 0.211221982317511, 0.48388681607320905, 0.2703825366916135, 0.7822465687058866, 0.27073048520833254, 1.0661179362796247, 0.12051056313794106, 1.7768705100752413, 56.140718311071396, 118.85246962308884, 91.04457378387451, 70.62898367643356, 117.06457436084747, 162.39588350057602, 112.6838730275631, 52.92242780327797, 27.348232604563236, 55.594254434108734, 67.92701706290245, 79.67991560697556, 97.69163310527802, 76.5144194662571, 2.735468940809369, 0.6233321491163224, 0.29509783547837287, 0.5667987826745957, 0.1329154724953696, 0.14290149993030354, 0.31785288476385176, 0.28574060008395463, 0.30001530598383397, 0.0940890445781406, 0.2136599225923419, 0.14327448850963265, 0.11332588343066163, 0.170683293545153, 0.12736953649437055, 0.28765290684532374, 0.13485601055435836, 0.1144690060755238, 0.21951821370748803, 0.31877866946160793, 0.3852186386939138, 0.32964329584501684, 0.32949246175121516, 0.29421660932712257, 0.2724625985138118, 0.14046535565285012, 0.17903610627399758, 0.12592537648743019, 0.3277443180559203, 0.16417456936324015, 0.17010048497468233, 0.26723651331849396, 0.17300217848969623], [0.053411010158015415, 0.055957790100364946, 0.08998311997856945, 0.047405669902218506, 0.10929194715572521, 0.10332171048503369, 0.18201165832579136, 0.2418522277730517, 0.13559645129134879, 0.12292212006286718, 0.02916297311458038, 0.04326047084759921, 0.16110011871205643, 0.15961433906340972, 0.12302637696848251, 0.1881964350468479, 0.17655546282185242, 0.0870694407785777, 0.08599549371865578, 0.08283743271022104, 0.08450111257843673, 0.0408820211305283, 0.08312143036164343, 0.10691587231121957, 0.2896262181457132, 0.2631984284380451, 0.14036602660780773, 0.034408244682708755, 0.15645978099200875, 0.1992154578329064, 48.04452694952488, 103.56188490986824, 91.68454304337502, 91.12382993102074, 52.43120156228542, 42.65319764614105, 43.633575439453125, 56.15491434931755, 84.66350018978119, 70.83823084831238, 79.38554540276527, 112.2082069516182, 99.35009211301804, 25.35555873066187, 0.6035835994407535, 0.04992951377062127, 0.059688384644687176, 0.489852525643073, 0.33985682122875005, 0.08033392368815839, 0.18354266445385292, 0.6593373545911163, 1.3031335431151092, 1.9166290294378996, 5.9484354592859745, 2.559506082907319, 3.6615832708775997, 10.121333543211222, 17.592242807149887, 31.737314388155937, 42.882731929421425, 65.49605190753937, 70.29225334525108, 85.10121390223503, 80.16772583127022, 79.07272338867188, 74.18610960245132, 72.92414411902428, 74.99304190278053, 77.80019447207451, 85.5143429338932, 89.3410111963749, 75.78001007437706, 71.73971727490425, 66.74855589866638, 55.869629457592964, 36.8480933457613, 20.31879600137472, 7.235337579622865, 1.9218468619510531, 1.119961878284812, 1.1542989732697606, 0.7572469383012503, 3.0241748364642262, 2.490307758562267, 5.481347423046827, 2.120083887130022, 2.1198447374626994, 5.649761036038399, 28.230590857565403, 49.34741623699665, 58.84266212582588, 70.88736221194267, 93.47861677408218, 105.19905745983124, 105.30267030000687, 102.66424387693405, 100.56365579366684, 97.08144664764404, 91.90439164638519, 92.37430483102798, 90.23271694779396, 93.87374237179756, 93.63794982433319, 83.82271930575371, 60.801700204610825, 49.219332709908485, 47.86295749247074, 47.82849334180355, 47.83253252506256, 43.58273036777973, 42.55290202796459, 36.7469047755003, 27.9235977306962, 11.877634450793266, 11.785984318703413, 6.00692049600184, 2.4450448248535395, 1.145273745059967, 1.5409310767427087, 1.2158611323684454, 0.32580395811237395, 0.20933593274094164, 0.08200791198760271, 0.32623378036078066, 0.09321971505414695, 0.2767408423824236, 0.11976031863014214, 0.4017758049303666, 0.24852395727066323, 13.632126655429602, 89.60226997733116, 105.69412529468536, 79.0412686765194, 79.96832013130188, 101.11033245921135, 98.59289154410362, 54.42895956337452, 22.759479135274887, 35.62599152326584, 49.81264427304268, 60.72550669312477, 80.54119259119034, 46.214096769690514, 2.1800572564825416, 0.37848352978471667, 0.045865219944971614, 0.07677828674786724, 0.036918462719768286, 0.12373198129353113, 0.09159948051092215, 0.030069962922425475, 0.24259452387923375, 0.09933576147886924, 0.16408392344601452, 0.06899562155012973, 0.07015109353233129, 0.07452322650351562, 0.12942083267262205, 0.16051803744630888, 0.19983124744612724, 0.15083332196809351, 0.08519593349774368, 0.10349503165343776, 0.16004381992388517, 0.08355284080607817, 0.07551679154857993, 0.11759849439840764, 0.12486180465202779, 0.06066160371119622, 0.036367774300742894, 0.07575807860121131, 0.08798807859420776, 0.09924382422468625, 0.027860429727297742, 0.054961497662588954, 0.06325352849671617, 0.013883628398616565, 0.0913261623645667, 0.08590870696934871, 0.06273629609495401, 0.07339318792219274, 0.09970720639103092, 0.20435641868971288, 0.1488869803142734, 0.12663096596952528, 0.014656752391601913, 0.007218816645035986, 0.06909377058036625, 0.14257819071644917, 0.06660552753601223, 0.12094222591258585, 0.13339325232664123, 0.10560020775301382, 0.09683715063147247, 0.02094597712130053, 0.08261741561000235, 0.029258775102789514, 0.058859042037511244, 0.004269335777280503, 0.1589664292987436, 0.2980095479870215, 0.1070425717625767, 0.10411439841846004, 0.22953564883209765, 1.4044370572082698, 74.66722458600998, 116.8444673717022, 106.02539151906967, 119.12391185760498, 88.21873381733894, 59.548668041825294, 27.580388747155666, 21.234742552042007, 47.86605812609196, 72.9911345243454, 88.15761789679527, 126.63938418030739, 100.27003794908524, 18.52775640785694, 0.8292939222883433, 0.10639481784892268, 0.005397755548983696, 0.41080738592427224, 0.2846167213283479, 0.0645418449130375, 0.9814451797865331, 1.9487663987092674, 0.9688075329177082, 1.063383270520717, 2.4170856876298785, 1.8578613828867674, 5.386275574564934, 13.322360627353191, 22.35077116638422, 37.48619690537453, 54.47380855679512, 76.60108521580696, 85.1661068201065, 91.58451721072197, 84.2196536064148, 83.30461710691452, 80.6825602054596, 83.74275639653206, 86.00513219833374, 89.97265130281448, 94.16418358683586, 96.69859439134598, 85.18845722079277, 81.72203242778778, 77.00394719839096, 68.10708180069923, 47.41378739476204, 30.757571160793304, 12.854288443922997, 3.008392145857215, 1.559496761765331, 1.1030804528854787, 0.6275721872225404, 2.401059572584927, 4.0293702855706215, 6.78507219068706, 2.073222426697612, 3.8498358568176627, 8.659307844936848, 35.812523514032364, 61.39231011271477, 77.25262105464935, 83.21586906909943, 103.29633235931396, 110.1606336236, 108.74847739934921, 105.5103063583374, 101.48680865764618, 99.17396396398544, 96.49339020252228, 99.0793414413929, 98.98730278015137, 98.1500481069088, 99.60885062813759, 95.63977360725403, 79.25327450037003, 67.13038980960846, 59.452875182032585, 60.01048386096954, 59.94600512087345, 58.24658431112766, 56.34403020143509, 50.303475335240364, 42.61572405695915, 28.22609569877386, 18.36444117128849, 13.205469399690628, 7.625636961311102, 2.792840162292123, 1.9758834061212838, 1.0869459249079227, 0.27529840415809304, 0.1600660991971381, 0.10444527011713944, 0.05175547536055092, 0.005690003099516616, 0.36172069958411157, 0.17709960549836978, 0.2576788980513811, 0.30116572394035757, 6.424439242109656, 85.65441861748695, 110.70877701044083, 79.151721149683, 88.23476135730743, 106.31786182522774, 65.72030827403069, 12.535471301525831, 21.392644979059696, 56.81637905538082, 68.27013865113258, 78.66467848420143, 88.35811033844948, 64.21333953738213, 4.351333659142256, 0.35602159914560616, 0.09000458288937807, 0.032337192533304915, 0.045986141776666045, 0.016638513043290004, 0.16874564986210316, 0.0732781772967428, 0.33502416335977614, 0.04104325642401818, 0.19631198316346854, 0.01773829982994357, 0.07708883844316006, 0.042303330410504714, 0.14778480195673183, 0.122834606008837, 0.17539879598189145, 0.10048507363535464, 0.08188014384359121, 0.07252864525071345, 0.005324584426489309, 0.057935290824389085, 0.07061159616569057, 0.0377596945327241, 0.11088444021879695, 0.1066593341238331, 0.15055859374115244, 0.08849284291500226, 0.04465489211725071, 0.07413102372083813, 0.0634422418079339, 0.013288991849549348, 0.19405609171371907, 0.14494521135929972, 0.18773337942548096, 0.23932232055813074, 0.14780681405682117, 0.17076023941626772, 0.2358508060569875, 0.3157575643854216, 0.38579427811782807, 0.25258613226469606, 0.08592921993113123, 0.07896572991739959, 0.23117110482417047, 0.24264320876682177, 0.19758369773626328, 0.3577924822457135, 0.2084402198670432, 0.17432714957976714, 0.16755238029872999, 0.09169414144707844, 0.2740719012217596, 0.19837018131511286, 0.13393813715083525, 0.1749913123785518, 0.42147136526182294, 0.4247869842220098, 0.2994163037510589, 0.351292931009084, 0.363591238274239, 1.418127603828907, 83.79245012998581, 135.5336657166481, 113.600133061409, 118.80130916833878, 70.20408287644386, 59.35703292489052, 62.15788163244724, 79.04747754335403, 128.57702940702438, 99.00143042206764, 97.40597203373909, 131.58760786056519, 121.89280807971954, 34.69569884240627, 2.071296642534435, 0.25744396378286183, 0.4952772689284757, 0.565164751606062, 0.6801079900469631, 0.1919884089147672, 0.8517448988277465, 2.6528530614450574, 3.768917298875749, 4.85297086648643, 12.61684488505125, 5.476669874042273, 5.421704398468137, 14.716192334890366, 23.150082975625992, 39.81187351047993, 54.66292820870876, 79.81933012604713, 90.10004326701164, 97.57133156061172, 96.84536531567574, 98.48973467946053, 94.31434392929077, 98.9105013012886, 98.36515456438065, 100.84389075636864, 104.00200009346008, 108.9153416454792, 94.90966558456421, 91.5999747812748, 85.63528284430504, 72.78559595346451, 48.054041638970375, 28.668775744736195, 11.58038780093193, 2.970669907517731, 2.321697031147778, 3.109416849911213, 2.9480582708492875, 5.99016672000289, 6.4088325295597315, 10.802683532238007, 4.8848858289420605, 5.297467689961195, 8.250452633947134, 36.13053224980831, 66.08571946620941, 79.68428537249565, 87.58287593722343, 106.91138237714767, 110.20208939909935, 107.499058842659, 105.28540402650833, 104.94134768843651, 100.03321185708046, 98.36740404367447, 102.47942939400673, 103.26470285654068, 104.3493926525116, 103.80529224872589, 98.14896136522293, 80.4535160958767, 70.18581345677376, 65.70827051997185, 65.21989792585373, 67.28455513715744, 61.23485416173935, 60.3497638553381, 56.97395280003548, 51.80552713572979, 41.712767109274864, 28.57110008597374, 13.481136057525873, 7.209730753675103, 5.873825987800956, 5.695306342095137, 5.050684232264757, 1.9956873496994376, 0.324820137466304, 0.17722249031066895, 0.42394690273795277, 0.1928142856922932, 0.3913936042226851, 0.2705635910388082, 0.35105882794596255, 0.2679354086285457, 18.828164488077164, 113.14017534255981, 120.26549980044365, 85.88131204247475, 87.1931080520153, 124.19585689902306, 135.75710892677307, 69.23282459378242, 28.11352863907814, 41.780905053019524, 65.04809394478798, 79.2771752178669, 97.90612399578094, 72.45256662368774, 3.9378626458346844, 0.8236656524240971, 0.1386630945489742, 0.13486956217093393, 0.20648805977543816, 0.16919402580242604, 0.23779017152264714, 0.13068224623566493, 0.3858750534709543, 0.28542958083562553, 0.29779616568703204, 0.17201371199917048, 0.15002849249867722, 0.17867527407361194, 0.3012479835888371, 0.24296363844769076, 0.2389375021448359, 0.1918000666773878, 0.2126719756051898, 0.1688097565784119, 0.2229954130598344, 0.18493361247237772, 0.2073191019007936, 0.20593802444636822, 0.3941700083669275, 0.21580872213235125, 0.2848465496208519, 0.17303588683716953, 0.23152141337050125, 0.32825690461322665, 0.15303616470191628, 0.11647283448837698], [0.04784154436492827, 0.03178396596922539, 0.006395416785380803, 0.02091875885525951, 0.017740609764587134, 0.04080085986061022, 0.07558725847047754, 0.08535833767382428, 0.06510163948405534, 0.02943604820757173, 0.16586660669418052, 0.036454371802392416, 0.06511194791528396, 0.04442304518306628, 0.15228025760734454, 0.030458807486866135, 0.015486215597775299, 0.10278035086230375, 0.07734812999842688, 0.23618563340278342, 0.08621998596936464, 0.1561350023257546, 0.03885270365572069, 0.1676786196185276, 0.012728832698485348, 0.15078692289534956, 0.42018664826173335, 0.17682276957202703, 1.4027302362956107, 56.227737441658974, 101.46463304758072, 90.09023979306221, 72.02609270811081, 54.26248289644718, 33.27456749975681, 32.48161464929581, 76.9816879928112, 70.70629432797432, 73.66371363401413, 100.19946053624153, 123.88916015625, 62.57295235991478, 4.395552836358547, 0.33576527202967554, 0.05720423454476986, 0.08286520387628116, 0.2351557105430402, 0.1939471295918338, 0.190531023836229, 0.7339691498782486, 2.0675274822860956, 1.4514053869061172, 2.3622437054291368, 2.677824371494353, 4.76081108674407, 7.900024987757206, 15.983487032353878, 29.70181491225958, 44.18029010295868, 68.10940727591515, 84.76902812719345, 96.48081287741661, 94.9249179661274, 83.18836614489555, 74.63003978133202, 77.06371799111366, 79.4488500058651, 77.63615727424622, 77.85175010561943, 79.80477690696716, 71.47586703300476, 75.52144154906273, 71.20710745453835, 64.61340487003326, 62.02305726706982, 69.07794490456581, 69.35969218611717, 74.5768578350544, 64.29130375385284, 37.44968846440315, 17.867042161524296, 4.010899476706982, 0.9495301579590887, 0.4411241185152903, 1.0110188741236925, 5.196786392480135, 3.9056626986712217, 12.56776861846447, 27.93710220605135, 67.08640336990356, 65.13843789696693, 78.52011144161224, 94.39978614449501, 106.33106991648674, 113.86397570371628, 107.77040228247643, 106.44260913133621, 99.57055628299713, 97.30511024594307, 88.50067868828773, 88.76477211713791, 85.76367795467377, 87.29453220963478, 87.23250433802605, 88.27351927757263, 87.33050867915154, 78.44938203692436, 62.70267739892006, 52.701526656746864, 49.393648356199265, 50.316227450966835, 49.49606046080589, 46.335291266441345, 38.25115665793419, 24.954530149698257, 15.146488845348358, 14.02115548029542, 16.108868904411793, 10.244274996221066, 2.5830527069047093, 2.6921158796176314, 0.5062007624655962, 0.1423222091398202, 0.36522633803542703, 0.20510131231276318, 0.13531620148569345, 0.22249679372180253, 0.22486871253931895, 0.11977698726695962, 0.7187509071081877, 0.6942850886844099, 2.9517155745998025, 54.03495490550995, 97.0165005326271, 79.33268263936043, 63.986301720142365, 85.19141346216202, 130.61490565538406, 75.52986949682236, 31.13657422363758, 37.77650512754917, 54.54419977962971, 68.98107290267944, 80.84805652499199, 58.28251898288727, 8.322735205292702, 0.22028164617950097, 0.02420138378511183, 0.06143782338767778, 0.06800852803280577, 0.08338487052242272, 0.14948466152418405, 0.047441244751098566, 0.04862454727117438, 0.07437311971443705, 0.02133617610525107, 0.05651336185110267, 0.0371627962886123, 0.04237528904923238, 0.06612380690057762, 0.08930013631470501, 0.03492015217489097, 0.07018407457508147, 0.023096318473108113, 0.008523453816451365, 0.016769329558883328, 0.06794704851927236, 0.02357763278268976, 0.026624345664458815, 0.08284610099508427, 0.0973766548850108, 0.04824283103516791, 0.06061360159947071, 0.20542451762594283, 0.2435341867385432, 0.1358080079080537, 0.09251133509678766, 0.04463632729311939, 0.055724061821820214, 0.006366340830936679, 0.03096682241448434, 0.022508062538690865, 0.08048622723435983, 0.07695140753639862, 0.05105419404571876, 0.06980600228416733, 0.06313127450994216, 0.036938864359399304, 0.054168227143236436, 0.05390451980929356, 0.16640536137856543, 0.025151492372970097, 0.06099646816437598, 0.07778423823765479, 0.012528883271443192, 0.14931435347534716, 0.052813629517913796, 0.07814308148226701, 0.05954030762950424, 0.24714302824577317, 0.0439616334188031, 0.040986445019370876, 0.40469713567290455, 0.19358803401701152, 5.370086068287492, 80.00987470149994, 113.47362264990807, 112.02398523688316, 106.8556621670723, 85.55468156933784, 59.21158812940121, 29.414039254188538, 22.794294767081738, 45.15502519905567, 78.69283497333527, 109.97204214334488, 133.35031807422638, 57.6750797778368, 1.886632489040494, 0.35100082168355584, 0.03664987947558984, 0.1241201616358012, 0.12826618447434157, 0.31457526376470923, 0.43360295647289604, 1.7017268110066652, 4.277475122362375, 2.3825947009027004, 2.157154935412109, 2.252025632187724, 4.908869192004204, 11.079023703932762, 21.763632372021675, 39.723513051867485, 56.646816954016685, 80.14606699347496, 89.75797802209854, 97.65227481722832, 92.58188009262085, 86.8633845448494, 84.83633011579514, 86.81261166930199, 87.92193174362183, 83.78371059894562, 82.71852895617485, 82.74188250303268, 76.90114751458168, 79.34917375445366, 78.74063640832901, 72.8440672159195, 68.89781177043915, 77.30915442109108, 77.46544003486633, 82.88162380456924, 76.2084598839283, 46.16566836833954, 24.210100695490837, 7.201414899900556, 2.0011816173791885, 0.6700407864991575, 1.37807929655537, 7.935290420427918, 7.003557616844773, 15.331475269049406, 36.93357355892658, 76.00854501128197, 77.37371295690536, 90.71933403611183, 104.2498379945755, 112.51407533884048, 113.28180894255638, 111.83961912989616, 108.60352277755737, 103.10429826378822, 101.03919267654419, 93.34725022315979, 93.59142512083054, 90.86811125278473, 93.79760205745697, 91.07036679983139, 90.6909267604351, 91.52510359883308, 88.3475849032402, 77.28373378515244, 69.3941867351532, 64.96851101517677, 65.08750542998314, 64.35900092124939, 60.99244996905327, 54.54355001449585, 45.33066317439079, 31.497972831130028, 27.91690818965435, 27.60544840246439, 21.831384636461735, 9.855693597346544, 3.8554837787523866, 1.3439722079783678, 0.7914959255140275, 0.2603113552322611, 0.2152044209651649, 0.18570379848824814, 0.21103879058500752, 0.13194599014241248, 0.15711390995420516, 0.5238026648294181, 0.5696315900422633, 1.218851215671748, 43.002794086933136, 102.01961606740952, 84.35302644968033, 68.29009518027306, 92.792958766222, 111.07320785522461, 33.9073171466589, 25.929107554256916, 58.01744140684605, 79.41437065601349, 86.14675059914589, 94.39233854413033, 78.60954344272614, 16.83311954140663, 0.15215461200568825, 0.015689833089709282, 0.06833165913121775, 0.015155266901274445, 0.012151085575169418, 0.11768912547267973, 0.049685176491038874, 0.06974725387408398, 0.02547996507928474, 0.05839416815433651, 0.0302831541193882, 0.07289778208360076, 0.02369794419792015, 0.0373834739002632, 0.08113238553050905, 0.037902198018855415, 0.09186528812278993, 0.07799065177096054, 0.05592089051788207, 0.06914238125318661, 0.0828762396122329, 0.017656505879131146, 0.050594322237884626, 0.06833050880231895, 0.03474738019576762, 0.060591823275899515, 0.04697852309618611, 0.2695699443574995, 0.10735900126746856, 0.10563047995674424, 0.19220618472900242, 0.12814876186894253, 0.13022304978221655, 0.08539453963749111, 0.08491367247188464, 0.1420300404424779, 0.18172235431848094, 0.2397130909957923, 0.14651148434495553, 0.20526013191556558, 0.256989739718847, 0.20376195840071887, 0.12801756500266492, 0.14352312282426283, 0.21765818382846192, 0.14049979130504653, 0.18878093571402133, 0.20499503676546738, 0.16275987261906266, 0.46851349412463605, 0.17389688204275444, 0.24815215612761676, 0.1936141576152295, 0.4118617105996236, 0.13547457579988986, 0.1703357309452258, 0.4184647469082847, 0.3428744530538097, 5.898328498005867, 97.74483025074005, 132.7798166871071, 112.62173116207123, 98.27484861016273, 70.46011313796043, 44.31249640882015, 48.72956559062004, 110.37503331899643, 103.50022941827774, 94.72608983516693, 119.5818480849266, 146.02049499750137, 78.62081363797188, 7.24383819848299, 0.7986601442098618, 0.27231716725509614, 0.4120799317024648, 0.5623806884977967, 0.2610189188271761, 0.557243482908234, 2.064481945708394, 7.411017827689648, 6.0389466024935246, 7.271466990932822, 5.464747538790107, 6.983715081587434, 10.78641565516591, 21.207214929163456, 36.11259341239929, 55.83687901496887, 80.79285308718681, 94.66798335313797, 106.54116824269295, 103.89080286026001, 105.02731427550316, 98.04936110973358, 97.48688489198685, 95.04540950059891, 91.5042807161808, 88.56369450688362, 93.43691021203995, 88.26638326048851, 89.08552050590515, 89.68614667654037, 85.23246645927429, 78.13757076859474, 85.90894415974617, 83.44602271914482, 87.80948057770729, 78.00669059157372, 43.940712958574295, 22.257453873753548, 6.063127554953098, 2.666351837106049, 1.8775754375383258, 3.062953418120742, 10.949739441275597, 8.719392120838165, 13.023273926228285, 35.788239017128944, 76.18348762392998, 80.82519695162773, 92.0580630004406, 107.80267775058746, 110.85116297006607, 111.39813601970673, 109.01507869362831, 108.7206856906414, 105.63398972153664, 106.03942796587944, 96.23266339302063, 98.16888749599457, 94.80374246835709, 99.86352056264877, 99.96072694659233, 97.6949617266655, 94.856316447258, 90.5696676671505, 80.02109929919243, 73.3999165892601, 68.84113401174545, 72.0596145093441, 70.26743307709694, 66.36193424463272, 58.695720210671425, 48.543668165802956, 40.577027052640915, 37.86498337984085, 35.298802480101585, 24.494144953787327, 10.183805041015148, 7.337196338921785, 3.2701703114435077, 2.2129098186269403, 1.2134446995332837, 0.42930847441311926, 0.19201772374799475, 0.3761696320725605, 0.2215360093396157, 0.13646489765960723, 0.504525467986241, 0.41838878067210317, 4.556885529309511, 65.17467275261879, 114.48789462447166, 93.55448350310326, 75.106291025877, 100.11635139584541, 159.32061731815338, 90.3626623749733, 40.521812215447426, 45.52053898572922, 69.98155921697617, 86.32711932063103, 103.61855506896973, 88.6295373737812, 16.28802929073572, 0.33336258376948535, 0.13565476925577968, 0.15894950833171606, 0.1719996557221748, 0.12233531873789616, 0.23727837164187804, 0.1287102114292793, 0.19197773683117703, 0.11085116973845288, 0.11813805060228333, 0.12397808488458395, 0.14509531814837828, 0.09451517093111761, 0.1968194340588525, 0.14136921730823815, 0.1462538552004844, 0.17291070136707276, 0.28019325400236994, 0.14651911362307146, 0.15466133452719077, 0.16664747963659465, 0.11793591926107183, 0.15982743934728205, 0.18073675251798704, 0.21916732628596947, 0.13542372384108603, 0.2421941648935899, 0.30758874490857124, 0.33372380188666284, 0.2596090757288039], [0.0937148611410521, 0.08985537409898825, 0.05506413297553081, 0.07566076819784939, 0.034888562659034505, 0.10396000943728723, 0.02909960112447152, 0.055312036274699494, 0.0437720963236643, 0.10002040755352937, 0.034157947957282886, 0.06971646958845668, 0.051876081779482774, 0.05216090321482625, 0.028359011957945768, 0.03474218516203109, 0.031090532866073772, 0.08279133791802451, 0.052018863570992835, 0.054988719639368355, 0.11584926716750488, 0.09375751978950575, 0.23301471839658916, 0.19663625716930255, 0.08681832026923075, 0.16998781211441383, 0.3314388182479888, 3.8443323271349072, 67.86422163248062, 107.67238274216652, 83.10353189706802, 79.05030459165573, 36.70898661017418, 28.609624318778515, 46.385592967271805, 61.451305747032166, 59.03640232980251, 76.16855442523956, 102.2729180753231, 108.36513116955757, 39.54963818192482, 1.1153323017060757, 0.11938175652176142, 0.44117235811427236, 0.35314108652528375, 0.4079922416713089, 0.39707067771814764, 0.27235219662543386, 0.1323021764983423, 1.823237759526819, 2.542316517792642, 2.3889042623341084, 3.2446019584313035, 8.979285825043917, 19.719273671507835, 38.51147308945656, 66.70505583286285, 88.56078386306763, 100.83353251218796, 98.55040222406387, 95.65864339470863, 85.6518879532814, 71.50892525911331, 77.80590176582336, 82.27674946188927, 85.57992741465569, 82.83379957079887, 78.83971989154816, 74.59763512015343, 69.79900941252708, 64.78921383619308, 56.25367484986782, 54.17620092630386, 57.161628529429436, 67.56579324603081, 73.04752349853516, 77.60362342000008, 72.9358322918415, 79.1221435368061, 77.83374667167664, 70.99592238664627, 46.74078270792961, 31.432413049042225, 13.72637489810586, 6.209706114605069, 8.516619801521301, 14.784692209213972, 32.865310460329056, 64.69334498047829, 81.77146017551422, 72.40460559725761, 94.79641646146774, 107.19111576676369, 118.59953999519348, 107.99680933356285, 94.2768931388855, 83.14005553722382, 85.14027580618858, 79.22275453805923, 76.25635251402855, 69.71975326538086, 70.91472834348679, 72.63931140303612, 75.60395032167435, 74.60272684693336, 74.91303339600563, 76.78887873888016, 80.03429219126701, 73.33959862589836, 65.20198568701744, 56.17286458611488, 57.56668299436569, 51.923096626996994, 53.16136658191681, 51.74513317644596, 39.91459719836712, 24.37724992632866, 14.790705386549234, 15.524044185876846, 17.617872431874275, 11.797685790807009, 4.546946212649345, 2.336131981573999, 0.4185273841721937, 0.41083460790105164, 0.099498573836172, 0.12531856686109677, 0.30136022600345314, 0.12517473864136264, 0.20580751035595313, 0.22039244882762432, 0.32460734888445586, 0.08750983863137662, 19.684604331851006, 88.70488733053207, 99.88025486469269, 75.51694259047508, 55.47502823174, 58.87836880981922, 78.29748898744583, 28.640467263758183, 34.19535309076309, 46.55619241297245, 61.26575410366058, 65.3924086689949, 70.92190235853195, 27.506256625056267, 0.9821730782277882, 0.056520330617786385, 0.02212015493569197, 0.15676152339437976, 0.04411273839650676, 0.2061415064963512, 0.015907911329122726, 0.08163925012922846, 0.10209166750428267, 0.018989839118148666, 0.014116573711362435, 0.14326550852274522, 0.06643774278927594, 0.1312544717802666, 0.03929999234969728, 0.06015805651259143, 0.0651588813343551, 0.06068604634492658, 0.03586536258808337, 0.09389285041834228, 0.04734988266136497, 0.062124146716087125, 0.04486943216761574, 0.0025098752576013794, 0.045761204237351194, 0.09899648124701343, 0.05230738090176601, 0.024259711026388686, 0.01596566340595018, 0.013084567272017011, 0.1817968807881698, 0.03252901915402617, 0.010362645116401836, 0.06503433411126025, 0.03626884972618427, 0.021347211841202807, 0.0624976956169121, 0.059057069302070886, 0.040922995103755966, 0.01612151441804599, 0.046049717857385986, 0.10185492239543237, 0.17816044623032212, 0.12614236562512815, 0.04077444311405998, 0.033237844399991445, 0.016484532243339345, 0.08767275488935411, 0.00938158247663523, 0.12151265545981005, 0.07335264439461753, 0.07797929691150784, 0.2094982552807778, 0.026998527246178128, 0.17695303133223206, 0.5377920297905803, 10.63233582302928, 91.2203523516655, 114.27524283528328, 97.7441918849945, 103.6299392580986, 64.53689217567444, 42.202583625912666, 11.927607469260693, 25.080915167927742, 57.1406764537096, 87.17635855078697, 112.22945541143417, 118.6130140721798, 36.67544201016426, 1.0088863573037088, 0.1625870561110787, 0.45673807442653924, 0.39308774925302714, 0.2896200434770435, 0.6597980204969645, 1.443152348510921, 0.8943225641269237, 2.6547631714493036, 1.9655021256767213, 2.4982937425374985, 5.206428375095129, 13.816294223070145, 25.681229755282402, 50.52496924996376, 77.08781629800797, 94.48770582675934, 102.30479836463928, 100.67399427294731, 97.52477645874023, 88.41022834181786, 82.54316076636314, 86.28197774291039, 87.27457568049431, 90.33850327134132, 88.47880706191063, 85.81255093216896, 81.75802409648895, 80.50781518220901, 72.93478354811668, 67.40553304553032, 62.773403003811836, 67.73335665464401, 77.67539396882057, 84.01237472891808, 88.48454475402832, 80.75834333896637, 85.78944057226181, 85.39630606770515, 80.31505152583122, 56.739634573459625, 38.81458282470703, 22.49961107969284, 11.14220766350627, 13.170920703560114, 21.73275712877512, 39.59654286503792, 73.55399832129478, 93.62968146800995, 86.29248797893524, 102.84015163779259, 109.62108537554741, 118.14256131649017, 109.0445727109909, 98.32584947347641, 88.08846160769463, 88.88281658291817, 82.23016396164894, 83.20370972156525, 79.44494381546974, 78.37403208017349, 76.97871655225754, 80.87107568979263, 80.33597320318222, 80.36108985543251, 79.82785686850548, 86.40685424208641, 84.4764894247055, 78.70047256350517, 71.26163452863693, 73.66678386926651, 66.94708004593849, 65.17559230327606, 65.61992526054382, 59.91276070475578, 46.90497189760208, 34.63357217609882, 29.761638902127743, 29.765472896397114, 22.387560792267323, 7.598227607086301, 2.802318991161883, 1.2041013571433723, 0.40467513841576874, 0.13765898358542472, 0.13010592403588817, 0.13835412362823263, 0.1429506449494511, 0.2630945871351287, 0.100064973521512, 0.11444070798461325, 0.3388108086073771, 12.563605941832066, 87.70277470350266, 106.75196573138237, 78.21498781442642, 61.857082173228264, 63.91230449080467, 32.30894811451435, 27.528257444500923, 55.600721687078476, 65.58145612478256, 83.56073096394539, 73.1258524954319, 86.93099811673164, 45.179682075977325, 1.6573223937302828, 0.06103881882154383, 0.0588657584739849, 0.16059490910265595, 0.06432327500078827, 0.08822230782243423, 0.06262834329390898, 0.08412238719756715, 0.054228508088272065, 0.03232755945646204, 0.07355290552368388, 0.026011457848653663, 0.06149027838546317, 0.22215472301468253, 0.040160327043849975, 0.012255284036655212, 0.06415143070626073, 0.017107214553107042, 0.005553319442697102, 0.14842261851299554, 0.06044815090717748, 0.061719294026261196, 0.021795294633193407, 0.023436815827153623, 0.03335114066430833, 0.07835003678337671, 0.02557212683313992, 0.16210182511713356, 0.0024434639408354997, 0.15441293769981712, 0.19966843508882448, 0.19456391368294135, 0.17064433079212904, 0.11009512163582258, 0.2037582328193821, 0.12337848893366754, 0.11435317908762954, 0.10831200052052736, 0.25857704516965896, 0.12294294472667389, 0.2040251239668578, 0.20602871489245445, 0.2265304999309592, 0.21322754735592753, 0.12356344697764143, 0.18732815195107833, 0.19106195628410205, 0.22382777620805427, 0.15796096762642264, 0.28484049369581044, 0.20983084134059027, 0.32759300898760557, 0.3074635594384745, 0.1164125201466959, 0.20853595691733062, 0.6623148510698229, 12.730081658810377, 111.67343884706497, 129.52016919851303, 102.9444408416748, 100.65834671258926, 46.176471188664436, 38.578554689884186, 64.86449539661407, 90.71623340249062, 90.94039857387543, 103.89685213565826, 122.18350768089294, 128.21845024824142, 52.220742255449295, 2.1909899823367596, 0.2960220171371475, 0.8685933134984225, 0.7750354462768883, 0.5580405495129526, 0.7679436018224806, 0.7929502974729985, 0.7655185007024556, 4.783275481313467, 4.581906236708164, 3.509713257662952, 4.7497546300292015, 10.553016029298306, 21.194669902324677, 43.8030843436718, 71.11294850707054, 93.67110684514046, 110.37858992815018, 110.56412637233734, 105.04145711660385, 98.75389650464058, 93.9816489815712, 93.8640832901001, 97.4850457906723, 99.38168361783028, 101.93727448582649, 94.73999708890915, 93.4454445540905, 90.01155361533165, 84.56608861684799, 77.78605923056602, 72.98229619860649, 75.36754980683327, 85.13058632612228, 87.93498784303665, 92.56950035691261, 84.81545403599739, 93.6064039170742, 93.4259743988514, 85.24343267083168, 58.72719772160053, 35.60187041759491, 20.430114828050137, 10.191599372774363, 14.106679391115904, 24.95618876069784, 36.77981100976467, 70.40243983268738, 94.74144101142883, 80.900197327137, 101.77651271224022, 104.03587907552719, 114.19005140662193, 109.53803703188896, 103.20429369807243, 92.29698657989502, 94.8004138469696, 85.30249670147896, 88.02227675914764, 84.54442217946053, 83.96504446864128, 85.71144595742226, 87.55487143993378, 91.0072673857212, 89.47481721639633, 91.79354399442673, 97.66206309199333, 92.86815673112869, 84.8445376753807, 76.02588728070259, 78.07454735040665, 72.73187443614006, 70.43955624103546, 70.40127709507942, 64.52640473842621, 53.19358505308628, 43.277283757925034, 39.29178021848202, 37.85257324576378, 26.850295923650265, 7.452982300892472, 3.8810086715966463, 3.499435046687722, 1.9123860821127892, 0.476753797265701, 0.14758713834453374, 0.2444560083677061, 0.24622874683700502, 0.2419265464413911, 0.27195378206670284, 0.21612848388031125, 0.3590202913619578, 25.072352327406406, 106.80153027176857, 116.4329494535923, 90.12905091047287, 67.78150007128716, 86.28941014409065, 97.6237915456295, 33.059065863490105, 41.95714719593525, 60.76856978237629, 77.38306045532227, 81.43948718905449, 98.01106676459312, 51.73154890537262, 2.9448125325143337, 0.28709294158034027, 0.17419718467863277, 0.34053244278766215, 0.20939291483955458, 0.35732029820792377, 0.20146426919382066, 0.2203283124254085, 0.1932784990640357, 0.12637496954994276, 0.12151490416727029, 0.3204847779124975, 0.15611315349815413, 0.2770113106817007, 0.13413513283012435, 0.08908696923754178, 0.20365572738228366, 0.12761199614033103, 0.08342624525539577, 0.19085085979895666, 0.11013510113116354, 0.13256087433546782, 0.09843420790275559, 0.1719679363304749, 0.12000864124274813, 0.16843436344061047, 0.11832965828943998, 0.3089766204357147, 0.16558540693949908], [0.15402526943944395, 0.09829931514104828, 0.02336845103855012, 0.11251007017563097, 0.20665847172494978, 0.1052588495076634, 0.15653436683351174, 0.16993874131003395, 0.16135716898133978, 0.20827690284932032, 0.05706390555133112, 0.03361044706252869, 0.0648329671821557, 0.02548486696468899, 0.022955481108510867, 0.1623851028853096, 0.11607701002503745, 0.0819983308610972, 0.1545601204270497, 0.16784207022283226, 0.2428588768816553, 0.1510362102999352, 0.15289135684724897, 0.1720618031686172, 0.08714608979062177, 0.20109505072468892, 8.272107671946287, 82.39628344774246, 112.21564695239067, 85.27062401175499, 79.63326171040535, 54.00753937661648, 40.20588956773281, 60.45185677707195, 104.63246986269951, 67.86090821027756, 67.97915026545525, 97.67454162240028, 108.69284078478813, 42.63996295630932, 0.5944519175682217, 0.09628087384044193, 0.12294600237510167, 0.39660110604017973, 0.29951156582683325, 0.6442269904073328, 0.5953815614338964, 1.6826093243435025, 2.258745334111154, 3.58980274759233, 3.2843820238485932, 9.979071076959372, 26.739640161395073, 49.69874158501625, 84.08378049731255, 102.00006231665611, 107.43238002061844, 103.11410933732986, 102.79676556587219, 101.68566718697548, 95.91077506542206, 76.17479369044304, 86.6327141225338, 89.08524692058563, 84.75111588835716, 78.960150629282, 74.49634775519371, 72.25164100527763, 65.1418349146843, 60.65987281501293, 49.9191677570343, 47.727962136268616, 51.202697083353996, 60.25085136294365, 68.27672749757767, 80.62437772750854, 94.6578074991703, 87.334855645895, 85.80467015504837, 76.00193336606026, 70.12019097805023, 70.45858561992645, 86.65086194872856, 72.4235437810421, 44.85444612801075, 35.51855228841305, 45.188429206609726, 77.24943682551384, 77.98654407262802, 68.1162241101265, 91.20204493403435, 129.23477411270142, 114.49348032474518, 105.61660185456276, 83.71815651655197, 78.8396742939949, 73.38869199156761, 78.63653719425201, 81.05650573968887, 73.99905323982239, 68.6363933980465, 73.12789678573608, 78.80782440304756, 76.2624853849411, 73.20595219731331, 75.13805732131004, 72.59236872196198, 62.310565039515495, 61.06282219290733, 58.18733029067516, 63.75052437186241, 64.64400082826614, 66.71251103281975, 65.22446528077126, 53.38661849498749, 45.160781890153885, 40.612897127866745, 36.25939853489399, 26.39417789876461, 20.992226265370846, 19.19191136956215, 17.501361183822155, 11.909317150712013, 4.271531291306019, 0.27917814441025257, 0.846188171999529, 0.4631758789764717, 0.2294906449969858, 0.1853300232323818, 0.08499255534843542, 0.17139579984359443, 0.2634132653474808, 0.29320084664504975, 0.0894892578071449, 6.396836573258042, 59.04652878642082, 99.8104678094387, 80.14750331640244, 40.92197634279728, 68.95230084657669, 83.11673238873482, 27.868686877191067, 29.313327558338642, 40.401286482810974, 46.73781506717205, 60.00245489180088, 75.32545566558838, 51.76195107400417, 4.030950525775552, 0.18134797050151974, 0.10010921294451691, 1.0191940166987479, 0.3467808512505144, 0.6344862724654377, 0.13695520494366065, 0.08555302527383901, 0.027640108346531633, 0.05187430804653559, 0.06517211382742971, 0.031090195188880898, 0.03392910301045049, 0.058309470550739206, 0.05583416314038914, 0.383618776104413, 0.34100513148587197, 0.004031297012261348, 0.04296440216421615, 0.1212568000482861, 0.03762371823540889, 0.03890675427101087, 0.039088676930987276, 0.16791178757557645, 0.7118256599642336, 0.2314279176061973, 0.02395802985120099, 0.06951355157070793, 0.04114224408112932, 0.10383886125055142, 0.10491586595890112, 0.05811928778712172, 0.03571838766220026, 0.036209351746947505, 0.032027071283664554, 0.08467019608360715, 0.03578197858587373, 0.17024977540131658, 0.08503116929205135, 0.029275818524183705, 0.043176500548725016, 0.03175442478095647, 0.10351892880862579, 0.034239929300383665, 0.09415636479388922, 0.07131518184905872, 0.04070015413162764, 0.03578540730813984, 0.22868505853693932, 0.1899721272638999, 0.19726084865396842, 0.3775545093230903, 0.03917869944416452, 0.13132021122146398, 16.997472122311592, 106.45455569028854, 123.31739723682404, 110.11522606015205, 102.10787773132324, 79.69321489334106, 41.64928011596203, 12.901016436517239, 61.98909088969231, 61.270754635334015, 80.01080185174942, 105.18168479204178, 117.43779793381691, 39.53712545335293, 0.5338073498569429, 0.1281314401421696, 0.0943071988876909, 0.1768816664116457, 0.1683233233052306, 0.5119475978426635, 2.043089331127703, 4.1227184515446424, 2.723094429820776, 2.991396845318377, 4.106746958568692, 14.819725379347801, 32.28502079844475, 56.33689038455486, 88.79989743232727, 104.98875394463539, 105.32881289720535, 106.76450505852699, 101.76098674535751, 104.8766827583313, 95.87890237569809, 87.54023462533951, 97.00349003076553, 91.7626516520977, 88.91857266426086, 87.6817162334919, 85.09877443313599, 79.79298993945122, 76.70741111040115, 72.36730679869652, 63.93849268555641, 61.12572781741619, 63.71885307133198, 71.77076920866966, 74.95246008038521, 85.53823605179787, 98.89055237174034, 94.55620855093002, 93.9101368188858, 86.56880915164948, 79.25113141536713, 81.44341617822647, 97.20613315701485, 84.59775611758232, 58.234846740961075, 46.83443248271942, 59.182242304086685, 84.14527639746666, 81.25164046883583, 75.44622078537941, 101.94696396589279, 124.9023985862732, 111.50509268045425, 102.93909072875977, 87.28246405720711, 81.2803441286087, 77.76744022965431, 79.97608691453934, 84.44659262895584, 81.9953441619873, 75.33119335770607, 77.47894451022148, 84.27936360239983, 80.82330465316772, 76.07193320989609, 80.4468284547329, 79.48121666908264, 69.40205231308937, 67.41930350661278, 66.10493883490562, 73.04158821702003, 72.53918677568436, 74.79950308799744, 77.78421252965927, 65.00590860843658, 61.555545553565025, 57.931790202856064, 55.89810512959957, 45.13504207134247, 41.828489899635315, 38.71881656348705, 36.32245995104313, 24.005589969456196, 9.360194485634565, 1.8986285640858114, 0.31476884556468576, 0.39055675850249827, 0.1080106662993785, 0.839227776741609, 0.1354500255547464, 0.09325446240836754, 0.1673648544237949, 0.21051093062851578, 0.11117966656456701, 2.3580216569826007, 52.141421511769295, 106.5648789703846, 82.93510213494301, 38.99533152580261, 67.97623962163925, 33.12761038541794, 26.213615387678146, 55.777077823877335, 65.77250227332115, 69.94466319680214, 73.4854955971241, 85.7878066599369, 71.7672809958458, 8.156504575163126, 0.46717747987713665, 0.14423570333747193, 0.6716995756141841, 0.12942727451445535, 0.5815699556842446, 0.07244071559398435, 0.12726336484774947, 0.14252058521378785, 0.06657994570559822, 0.03134629921987653, 0.04677580174757168, 0.022004771381034516, 0.06466421764343977, 0.02380852234637132, 0.13322655111551285, 0.10407079724245705, 0.06076356366975233, 0.036755253313458525, 0.011891645590367261, 0.04420810808369424, 0.03645723649242427, 0.029721125683863647, 0.14799266267800704, 0.22024027886800468, 0.16693973739165813, 0.022421670983021613, 0.08271445884020068, 0.24196933867642656, 0.2658589091151953, 0.21842378337169066, 0.2430551007273607, 0.33267609716858715, 0.32383590121753514, 0.22470339172286913, 0.38011343451216817, 0.31765286112204194, 0.4909576429054141, 0.18868705403292552, 0.11166666386998259, 0.18268466752488166, 0.08035279650357552, 0.2462284648208879, 0.2017951334710233, 0.2013364268350415, 0.12719847145490348, 0.2253982052206993, 0.1309833355480805, 0.3206308325752616, 0.29152267263270915, 0.2589654555777088, 0.3127973747905344, 0.1454988683690317, 0.46492716937791556, 20.857563391327858, 125.90694308280945, 137.5749769806862, 107.53777876496315, 101.2792257964611, 64.8803861439228, 55.40696248412132, 82.17650324106216, 140.000402033329, 104.72558006644249, 90.2748490869999, 115.52798241376877, 127.71040230989456, 57.5807536393404, 1.1956223496235907, 0.1373412404791452, 0.2940520900301635, 0.3434077900601551, 0.28500599262770265, 0.5252021178603172, 0.896554053761065, 2.8181472793221474, 6.345697967335582, 7.255295533686876, 4.6613499987870455, 14.079259112477303, 28.805437311530113, 53.11343215405941, 92.54500687122345, 112.62129038572311, 119.61810573935509, 117.92971193790436, 113.69977131485939, 114.33018788695335, 108.99349585175514, 98.87786105275154, 101.98112413287163, 99.42133069038391, 98.96505117416382, 95.77321484684944, 93.74125108122826, 94.11325871944427, 87.96215638518333, 87.1756973862648, 74.762774258852, 70.77073127031326, 72.05931812524796, 82.16712534427643, 83.29993575811386, 94.4727574288845, 104.10898715257645, 97.46794670820236, 98.54661762714386, 91.96259692311287, 86.94770961999893, 88.98381516337395, 105.2379597723484, 90.96135824918747, 60.51430642604828, 42.604491859674454, 58.736340031027794, 82.52181351184845, 89.7186653316021, 75.2525831758976, 93.22269290685654, 117.06284925341606, 106.39138787984848, 102.95816570520401, 92.64121770858765, 87.55742490291595, 81.2415862083435, 86.65788397192955, 89.41636115312576, 83.15340042114258, 75.47906622290611, 81.49963036179543, 90.16574174165726, 87.80454844236374, 82.43416741490364, 85.42564049363136, 81.85354337096214, 77.84383893013, 77.29006424546242, 75.26884630322456, 80.29074802994728, 81.06922745704651, 86.90012097358704, 84.0401816368103, 72.51758113503456, 68.97771388292313, 62.20017336308956, 60.43960243463516, 49.603723883628845, 48.217254281044006, 49.237313345074654, 45.77042497694492, 29.569644704461098, 10.315763410180807, 3.8890400156378746, 1.900166175328195, 0.47449651057831943, 0.2783836011076346, 1.1691698315553367, 0.275540403672494, 0.2196490394999273, 0.3207442624261603, 0.2588287816615775, 0.3469798358855769, 9.091424457728863, 72.54633039236069, 117.16836959123611, 99.49972808361053, 54.62035909295082, 97.52571880817413, 103.90970304608345, 36.70161500573158, 38.911116644740105, 52.22019888460636, 59.745854660868645, 74.07929733395576, 96.71443954110146, 86.93950206041336, 10.8556935377419, 0.5070914584212005, 0.3862697572913021, 1.1706053232774138, 0.3095160727389157, 0.6482823821716011, 0.22203017579158768, 0.20184503548080102, 0.2001390012446791, 0.2171450777677819, 0.1325622250442393, 0.28708730125799775, 0.2511260309256613, 0.09306349296821281, 0.1344081838033162, 0.37868043640628457, 0.3002554946579039, 0.16854660585522652, 0.2022691728780046, 0.176970130414702, 0.14784542057896033, 0.16748546826420352, 0.19149609783198684, 0.1984885983983986, 1.0324735916219652, 0.2748529671225697, 0.17344411258818582, 0.20858674950432032], [0.15189204015769064, 0.2522313263034448, 0.10408831934910268, 0.29324745351914316, 0.1742446969728917, 0.1136976623092778, 0.29934859019704163, 0.15243342204485089, 0.0974175769079011, 0.13183380709961057, 0.030507247465720866, 0.028260605031391606, 0.07510630966862664, 0.017410014515917283, 0.028244869645277504, 0.04875674603681546, 0.08817241323413327, 0.05757410610385705, 0.039131628727773204, 0.06030441916664131, 0.08830149497953244, 0.14934442529920489, 0.20376137952553108, 0.5256411724258214, 1.4604660007171333, 26.686562709510326, 87.32445940375328, 94.74633514881134, 74.61365506052971, 59.97155115008354, 43.49354915320873, 34.95097294449806, 59.44470562040806, 119.321668446064, 68.35665240883827, 58.74019302427769, 110.40375977754593, 99.51508685946465, 24.638041332364082, 0.9111965680494905, 0.3889669891213998, 0.4091548902215436, 0.6661733658984303, 0.4231391492066905, 0.44839197071269155, 0.3740282391663641, 1.5400673355907202, 14.680443853139877, 7.857913272455335, 2.663174970075488, 11.796331163495779, 33.60455699265003, 63.786630034446716, 89.93601366877556, 98.93267691135406, 97.26041704416275, 95.35275980830193, 93.48196059465408, 90.81651002168655, 90.18108531832695, 80.84302559494972, 88.83935451507568, 88.18115383386612, 80.71826308965683, 78.02183657884598, 73.75582069158554, 71.79992124438286, 74.46900442242622, 76.20776072144508, 65.5696539580822, 59.67699475586414, 59.45466868579388, 60.69906011223793, 60.65356895327568, 64.23177614808083, 71.9240453839302, 77.78057232499123, 75.74571311473846, 75.47474205493927, 79.3365128338337, 72.49367281794548, 75.79206302762032, 83.22671368718147, 95.88109865784645, 85.61506032943726, 90.29443323612213, 88.13965246081352, 88.41313898563385, 61.9499795883894, 57.45871938765049, 87.383903414011, 92.79966160655022, 73.86504963040352, 64.03199046850204, 60.675311386585236, 63.85382562875748, 67.36025467514992, 72.14343801140785, 68.61072957515717, 63.858453780412674, 67.05507025122643, 65.52664026618004, 67.52759009599686, 61.99674367904663, 61.18888422846794, 62.90532812476158, 68.0577452480793, 54.63014356791973, 46.24378077685833, 46.11871048808098, 49.559045881032944, 54.63318720459938, 58.49747344851494, 52.0344914495945, 51.61166533827782, 49.61606562137604, 48.96034620702267, 46.95720009505749, 50.06701022386551, 50.39464384317398, 37.585865557193756, 27.335277199745178, 21.69946901500225, 18.55791348963976, 7.446500798687339, 0.4546158586163074, 1.1826056730933487, 0.36614686832763255, 0.7022576546296477, 0.3069106297334656, 0.12557109002955258, 0.06671889059362002, 0.04338874736276921, 0.5124174663797021, 0.3800931293517351, 0.08839553251164034, 26.737327985465527, 106.4834189414978, 125.2490083873272, 63.518018648028374, 76.3476312160492, 75.49540534615517, 26.332974582910538, 22.46441926807165, 21.626678220927715, 45.11163532733917, 60.50190769135952, 78.73703420162201, 53.12326602637768, 3.100142735056579, 0.3521343186730519, 0.046669982621097006, 1.086750472895801, 0.13364316313527524, 0.17306612193351611, 0.0730249639309477, 0.13883674226235598, 0.1810850275796838, 0.03274011192843318, 0.05652867606841028, 0.06671204799204133, 0.04382947547128424, 0.07995453037437983, 0.17981199198402464, 0.1641202441533096, 0.08096804434899241, 0.06417935030185618, 0.07784425572026521, 0.08339030304341577, 0.08740566336200573, 0.07828054949641228, 0.32024524232838303, 0.07157252155593596, 0.04808375539141707, 0.03001207169290865, 0.13374042900977656, 0.13705998135264963, 0.1752537357970141, 0.05490127980010584, 0.06270870304433629, 0.0897579375305213, 0.11647976614767686, 0.24356961686862633, 0.05862371814146172, 0.043505910216481425, 0.09596376898116432, 0.08174839036655612, 0.09420369897270575, 0.04688490487751551, 0.06438822034397162, 0.03142150475468952, 0.05831770096847322, 0.11683379285386764, 0.04474868474062532, 0.013439253561955411, 0.0767080498917494, 0.061129334862926044, 0.10846986275282688, 0.1323887554462999, 0.7527475641109049, 3.661939976736903, 39.65710401535034, 106.24172151088715, 106.15187153220177, 104.31661561131477, 91.12711295485497, 71.41889289021492, 36.88953772187233, 15.342951603233814, 96.53391882777214, 73.2401655614376, 69.57277715206146, 118.68485301733017, 107.60755822062492, 21.80141944438219, 0.8698328782338649, 0.6481545546557754, 0.6372047890909016, 0.5734825052786618, 0.4777158878277987, 0.9064411232247949, 0.5521677865181118, 1.3649713061749935, 7.75386868044734, 4.325700234621763, 3.046642793342471, 15.340575780719519, 36.732761934399605, 69.35133263468742, 94.68002110719681, 98.52150857448578, 98.72510924935341, 96.64860427379608, 95.35802632570267, 95.26536449790001, 93.40855613350868, 86.75878375768661, 96.24485313892365, 92.20441594719887, 86.38834923505783, 84.20464441180229, 81.58357545733452, 79.36699479818344, 83.75258266925812, 81.7986287176609, 73.27070072293282, 73.50292906165123, 74.49427306652069, 72.48774513602257, 71.2891298532486, 75.87280109524727, 80.10266572237015, 83.28249469399452, 81.71663671731949, 81.61381423473358, 84.39762085676193, 81.90738648176193, 93.16995173692703, 92.36935749650002, 100.7033059000969, 90.40906548500061, 93.24094712734222, 93.39853227138519, 92.9997968673706, 69.52134311199188, 64.30429905653, 87.60743021965027, 87.27934822440147, 73.15606847405434, 64.69118669629097, 64.85764056444168, 68.45284044742584, 71.85437232255936, 75.59511199593544, 69.41692471504211, 68.66525664925575, 70.88657945394516, 71.70032098889351, 72.86254182457924, 67.63185650110245, 69.88504439592361, 73.03645089268684, 73.74713435769081, 64.36573415994644, 56.22869499027729, 55.425657480955124, 59.07902844250202, 63.288127183914185, 67.72235244512558, 60.860973224043846, 59.828409031033516, 60.68755052983761, 61.478052511811256, 59.256315529346466, 63.397477716207504, 65.12662813067436, 59.01772253215313, 50.185043290257454, 43.522689789533615, 35.54954722523689, 18.776390366256237, 3.354125856421888, 0.3856253356207162, 0.30606772808823735, 0.46442604158073664, 0.6849638326093554, 0.21257646119920537, 0.06574773098691367, 0.20068296580575407, 0.24607319268397987, 0.3369833738543093, 0.39690298202913254, 21.333738639950752, 109.23208504915237, 120.6290490925312, 61.94196581840515, 68.05367186665535, 30.464794971048832, 23.36091846227646, 34.703203439712524, 38.73929746448994, 71.43200218677521, 74.02270317077637, 82.96144992113113, 70.06921291351318, 5.542114712297916, 0.33763349521905184, 0.04901759610220324, 0.554639435140416, 0.023498178452427965, 0.054538963304366916, 0.12765465478878468, 0.14961602166295052, 0.15797161002410576, 0.018180881452281028, 0.02601318890810944, 0.051860210951417685, 0.03297909090179019, 0.056360954404226504, 0.03156406390189659, 0.15594280092045665, 0.05239605270617176, 0.0275636059086537, 0.060196792910574004, 0.034223910042783245, 0.046015612460905686, 0.045347779741859995, 0.09531251213047653, 0.01975293391296873, 0.20996747072786093, 0.03180083498591557, 0.049196127147297375, 0.17260021646507084, 0.3832485928433016, 0.22464407928055152, 0.37355154287070036, 0.34071492205839604, 0.33243890677113086, 0.4577818902907893, 0.1928315925761126, 0.15841391519643366, 0.3214216948254034, 0.1645677740452811, 0.1667721604462713, 0.28373870125506073, 0.08604195216321386, 0.1660420949338004, 0.10760546851088293, 0.2368710661539808, 0.12050372053636238, 0.13797493069432676, 0.17028936155838892, 0.1486709708115086, 0.1643719064304605, 0.21973224909743294, 0.8358613948803395, 4.027910688892007, 47.43676096200943, 126.28045544028282, 113.17577183246613, 94.80919137597084, 78.94075646996498, 55.03807447850704, 46.82902157306671, 85.98427131772041, 146.82772368192673, 86.60745307803154, 79.52248245477676, 127.78220325708389, 122.04799175262451, 35.602330192923546, 1.624493699055165, 0.7574344344902784, 0.70972835063003, 0.6730056961532682, 0.4830129520269111, 0.8244854584336281, 0.5270476313307881, 3.0132269114255905, 20.64726747572422, 11.05065442621708, 4.27160301245749, 14.940309058874846, 37.22740039229393, 75.97566157579422, 102.19202801585197, 108.0934989452362, 107.90784850716591, 106.79551899433136, 108.36598232388496, 105.67652463912964, 105.12601777911186, 94.85629364848137, 98.60565885901451, 100.97727119922638, 96.29997298121452, 94.13371682167053, 88.16840171813965, 86.77905946969986, 90.9679850935936, 93.73824164271355, 83.30432072281837, 81.21789067983627, 81.12374693155289, 78.86789157986641, 77.41076856851578, 82.94905498623848, 89.76538762450218, 91.36187195777893, 84.05222699046135, 84.29969251155853, 89.11035597324371, 84.63684841990471, 97.39255115389824, 99.20523628592491, 110.90151026844978, 102.41176262497902, 99.09476861357689, 99.98576000332832, 102.70466610789299, 78.69981899857521, 65.80467134714127, 86.08608305454254, 89.79405328631401, 81.5768726170063, 78.7913028895855, 73.8640008866787, 76.5079978108406, 76.03197455406189, 81.73524811863899, 78.06975960731506, 72.31625273823738, 73.31406399607658, 76.56783699989319, 82.00342252850533, 74.39433842897415, 74.33359488844872, 82.25727930665016, 87.89799302816391, 71.87079504132271, 64.154754281044, 63.652375638484955, 68.83515313267708, 74.56713035702705, 78.20109575986862, 70.32188415527344, 69.81395781040192, 67.31860131025314, 67.00224548578262, 63.377395793795586, 68.97392928600311, 71.70617267489433, 64.20127138495445, 56.17161825299263, 55.31305432319641, 49.357880875468254, 22.500319741666317, 3.3076094649732113, 2.165790209546685, 0.5159188597463071, 1.7318587191402912, 0.6918537535239011, 0.26726382435299456, 0.22805209562648088, 0.20744502951856703, 0.2873443515272811, 0.77988107688725, 0.7728173153009266, 34.30089242756367, 112.51956984400749, 144.41226929426193, 78.90924856066704, 113.34858655929565, 97.13182434439659, 34.18272256851196, 29.553632363677025, 27.65749040991068, 60.75025476515293, 73.47716644406319, 94.63579148054123, 84.23120498657227, 7.799465283751488, 0.6081963737960905, 0.15999351715436205, 1.1327369115315378, 0.3563971258699894, 0.2967774641001597, 0.22234542528167367, 0.23863434966187924, 0.29769553046207875, 0.20030059647979215, 0.10615448074531741, 0.15438537433510646, 0.1337353527196683, 0.16857554961461574, 0.15922018443234265, 0.2584382041823119, 0.24159951164619997, 0.10172084599616937, 0.2004564623348415, 0.13852224976290017, 0.1733602795866318, 0.16996433056192473, 0.33121258195023984, 0.10091463613207452, 0.304717316175811, 0.12726245942758396, 0.15435773675562814], [0.06202698845299892, 0.03586344413633924, 0.05902315315324813, 0.08284745912533253, 0.0747629847319331, 0.0363979166286299, 0.005739079006161774, 0.029351101984502748, 0.02588002349511953, 0.08866867996403016, 0.05782591309980489, 0.02747541650023777, 0.13141918403562158, 0.06562649374245666, 0.06941033367183991, 0.02210965354606742, 0.09078884002519771, 0.012698489990725648, 0.06561452290043235, 0.06446693252655677, 0.01909206810523756, 0.02964615578093799, 0.3795439697569236, 19.19645592570305, 67.27288216352463, 106.96853131055832, 94.16808217763901, 81.10629826784134, 50.15610784292221, 47.48464599251747, 32.01796352863312, 57.16116115450859, 95.15580877661705, 36.77491307258606, 80.68193703889847, 120.48251375555992, 84.45549935102463, 7.029383406043053, 1.56270521460101, 0.4150250705424696, 0.9678929101210088, 0.6720291485544294, 0.3366576600819826, 0.20495064149145037, 0.37225109233986586, 1.0946259065531194, 5.648452481254935, 2.6866327738389373, 0.36821615416556597, 8.705300576984882, 34.429219141602516, 66.29267156124115, 95.56415766477585, 96.5933096408844, 97.37055033445358, 92.74598568677902, 89.45625141263008, 88.06038111448288, 85.18169358372688, 76.7756250500679, 86.38072684407234, 84.84218180179596, 75.93254908919334, 78.92768517136574, 78.29064175486565, 81.60186007618904, 75.28101325035095, 79.52300682663918, 73.90641421079636, 66.7472867667675, 59.82441544532776, 61.22827671468258, 61.766605228185654, 61.83620989322662, 62.79512643814087, 62.031090036034584, 58.17979909479618, 73.89660313725471, 68.87153998017311, 58.82851928472519, 65.1527251303196, 74.36761826276779, 79.53566014766693, 87.06723600625992, 85.53914800286293, 79.19050186872482, 79.16208699345589, 83.79641711711884, 70.70605874061584, 64.94672298431396, 50.529551804065704, 52.801161110401154, 52.86822371184826, 58.20685364305973, 62.40500517189503, 62.46716223657131, 62.537488862872124, 66.55865728855133, 62.97502778470516, 65.75313851237297, 66.97823077440262, 66.80657118558884, 63.403086215257645, 65.4467761516571, 69.57770928740501, 71.3173471391201, 52.71189630031586, 52.8168960660696, 45.81959813833237, 41.042874455451965, 41.071437522768974, 45.141505524516106, 51.76796235144138, 51.95305421948433, 47.42629632353783, 46.362345814704895, 51.07614867389202, 51.26224748790264, 52.86644160747528, 54.150210320949554, 57.89219252765179, 53.71684357523918, 42.97464519739151, 25.96812956035137, 18.36909592151642, 14.855368416756392, 3.516242732293904, 0.5383770202752203, 0.6765810668002814, 0.38814982515759766, 0.11144586751470342, 0.06408389526768588, 0.10518582217628136, 0.053796136562596075, 0.17498222849098966, 0.1838591755949892, 0.5128062923904508, 11.62556167691946, 79.32015091180801, 113.94973710179329, 68.86651664972305, 69.52872231602669, 94.42469760775566, 46.30998842418194, 29.2041290178895, 36.916793659329414, 51.7118089646101, 69.95793968439102, 74.85823273658752, 54.98877972364426, 6.412266120314598, 0.564386862097308, 0.07941873685922474, 0.16764266998507082, 0.1393207858200185, 0.0596278699231334, 0.0747408984170761, 0.006487435211965931, 0.053068698252900504, 0.08367989648832008, 0.03465429261268582, 0.05100298956676852, 0.08135474039590918, 0.024269531495519914, 0.07431974445353262, 0.03872545130434446, 0.12470344518078491, 0.09447430828004144, 0.02679264434846118, 0.015401048585772514, 0.030741010996280238, 0.018993271551153157, 0.07107877812813967, 0.025369553914060816, 0.013886565448046895, 0.0463304797449382, 0.1100211740413215, 0.08814634158625267, 0.03969586505263578, 0.1030833920231089, 0.07945545090478845, 0.022559625103895087, 0.06164155034639407, 0.04719059921626467, 0.08511489839293063, 0.09157046253676526, 0.02382588489126647, 0.013143297128408449, 0.12214713235152885, 0.06597143656108528, 0.06813709769630805, 0.03400160341698211, 0.01177531394205289, 0.07402771676424891, 0.03240319914766587, 0.09551045775879174, 0.029579546171589755, 0.0906232520355843, 1.4226170629262924, 30.317332483828068, 88.87694209814072, 123.02035957574844, 109.49984908103943, 113.62393498420715, 87.91880831122398, 66.53237789869308, 23.83222047239542, 19.97274287045002, 83.20307895541191, 49.851212203502655, 90.1708410680294, 125.67336961627007, 91.31395652890205, 6.63733184337616, 1.3038059882819653, 0.2539509121561423, 0.7351239316631109, 0.6252967030741274, 0.2829270885558799, 1.4479704899713397, 1.3496992131695151, 3.0869415309280157, 0.7185524271335453, 1.1775186960585415, 0.5636528483591974, 10.591082386672497, 41.358268931508064, 76.3288526237011, 102.18609273433685, 98.73902410268784, 100.8561260998249, 92.65606731176376, 92.53521099686623, 95.54073572158813, 92.11143493652344, 86.66476920247078, 92.45696559548378, 86.48247018456459, 82.98655897378922, 86.66022464632988, 89.68341082334518, 90.07964596152306, 85.14566391706467, 86.92309454083443, 83.01230639219284, 75.99750280380249, 71.88265800476074, 73.00726845860481, 73.65137949585915, 74.23696607351303, 74.17143478989601, 72.0952033996582, 70.04085123538971, 78.78630235791206, 76.23318135738373, 69.24297004938126, 73.74845668673515, 80.2951329946518, 87.71504044532776, 90.96254378557205, 89.6421830356121, 79.98418807983398, 82.87137195467949, 87.77094304561615, 79.13994178175926, 68.58215510845184, 56.41490399837494, 56.10812745988369, 57.54603870213032, 62.61759236454964, 68.37876722216606, 69.06681910157204, 68.36840137839317, 72.64643982052803, 71.91093608736992, 74.50819551944733, 75.01578748226166, 74.61247712373734, 72.76446148753166, 72.79722332954407, 74.26886156201363, 77.73645669221878, 62.1478995680809, 60.928149819374084, 57.06352919340134, 53.5119965672493, 54.267897605895996, 51.97071947157383, 59.42807771265507, 62.5872927904129, 58.53031508624554, 60.54838299751282, 60.612926334142685, 61.50180123746395, 62.263778150081635, 63.68138708174229, 66.23824328184128, 67.60236248373985, 64.7310921549797, 51.77773542702198, 41.52106739580631, 27.894992865622044, 11.40158649533987, 1.9401325494982302, 0.5432706826832145, 0.2484027942409739, 0.5230208567809314, 0.4068749235011637, 0.2291529974900186, 0.12406919835484587, 0.0894021445128601, 0.12865327385952696, 0.3386056493036449, 9.323526453226805, 81.77002385258675, 111.31792232394218, 72.32703655958176, 60.28100274503231, 31.23172491788864, 23.472444377839565, 45.113318637013435, 53.640931248664856, 76.65775537490845, 91.36925116181374, 83.0386009812355, 74.22646343708038, 12.181309405714273, 0.37606380181387067, 0.09697565765236504, 0.14108899718848988, 0.03877560935507063, 0.04775562963914126, 0.02604124580102507, 0.02643170639203163, 0.029336687621253077, 0.0625657728232909, 0.05598528296104632, 0.02861867458705092, 0.06531563034513965, 0.012389666571834823, 0.04962022001564037, 0.06312020908808336, 0.020718204577860888, 0.09222392356605269, 0.0392749337333953, 0.018952392201754265, 0.02179874190915143, 0.025894408172462136, 0.09124099349719472, 0.04396646108943969, 0.021871396311325952, 0.037920328686595894, 0.20777196041308343, 0.18859067873563617, 0.2006925395107828, 0.29820939351338893, 0.17420270625734702, 0.12919658533064649, 0.15849249379243702, 0.2840486221248284, 0.17814192222431302, 0.1629237536690198, 0.16079009394161403, 0.12865535187302157, 0.2207502827513963, 0.2129659551428631, 0.2815988817019388, 0.14405782538233325, 0.17703508317936212, 0.25848365330602974, 0.1587733966880478, 0.1933016540715471, 0.15639399702195078, 0.22280943085206673, 1.7873873957432806, 36.40332341194153, 106.91237032413483, 141.609448492527, 112.40375205874443, 106.72645390033722, 66.32790327072144, 59.147641360759735, 46.27134829759598, 74.36173617839813, 126.53300508856773, 53.9370683580637, 109.40922394394875, 139.71429258584976, 109.60970118641853, 12.97911174595356, 1.7260000272653997, 0.5030699679628015, 1.3081645919010043, 0.7341318286489695, 0.4832108976552263, 0.7374453695956618, 0.9297937201336026, 2.806219244375825, 11.159929912537336, 5.3279301803559065, 1.4524031896144152, 10.202567484229803, 43.09570290148258, 90.32198935747147, 111.99544116854668, 107.93366432189941, 108.49939316511154, 102.39874452352524, 103.03469359874725, 101.34217321872711, 101.70010641217232, 94.4235272705555, 97.68545463681221, 94.79328542947769, 90.44025421142578, 89.78682607412338, 91.85908287763596, 91.71973675489426, 90.14899224042892, 93.29107403755188, 89.25744608044624, 82.81869158148766, 77.76157334446907, 80.36150023341179, 79.20106530189514, 79.8147551715374, 80.38855478167534, 78.38726297020912, 80.77484965324402, 85.2447322010994, 83.7826618552208, 74.80450361967087, 80.05889967083931, 88.60636621713638, 96.99375495314598, 97.30214640498161, 94.60771098732948, 90.26439964771271, 91.49042665958405, 95.8391185104847, 86.78213730454445, 68.85677397251129, 59.40193511545658, 62.39111311733723, 65.77344462275505, 71.42646208405495, 75.95898047089577, 72.97420263290405, 71.47243961691856, 77.47734099626541, 74.94460210204124, 78.94893363118172, 75.2532747387886, 78.59385028481483, 75.38866147398949, 75.52998349070549, 75.53921699523926, 77.48346626758575, 67.42200896143913, 72.09887400269508, 62.17855632305145, 61.61110997200012, 61.17001064121723, 62.138871252536774, 70.45285552740097, 68.96118476986885, 66.00963994860649, 67.88952827453613, 68.50178182125092, 69.89135205745697, 70.59812933206558, 69.6561598777771, 75.10347917675972, 72.50862121582031, 71.52013465762138, 60.01554898917675, 53.642078787088394, 38.37367728352547, 11.910817120224237, 2.8995400993153453, 1.0195557097904384, 0.9478745155502111, 0.7937247434165329, 0.399335534311831, 0.24708010896574706, 0.21831182297319174, 0.22530260175699368, 0.22508791327709332, 0.8495388203300536, 17.49392308294773, 90.92891559004784, 129.36971247196198, 81.33541837334633, 102.80263245105743, 124.88967686891556, 58.517433777451515, 41.15996137261391, 45.80900430679321, 74.00407657027245, 90.54211914539337, 91.19692280888557, 89.1248331964016, 16.362757980823517, 0.531846476951614, 0.2702665241668001, 0.3234146285103634, 0.2108178977505304, 0.15574810589896515, 0.22449661453720182, 0.11314139293972403, 0.15631955960998312, 0.17011865274980664, 0.14795332885114476, 0.1661973967566155, 0.24122768081724644, 0.17938730539754033, 0.3419874975224957, 0.09260258957510814, 0.2999826811719686, 0.30628879903815687, 0.17966250859899446, 0.14025188429513946, 0.09700042312033474, 0.14865336706861854, 0.2188241868861951, 0.07952520536491647, 0.2117041705059819, 0.140138098213356], [0.02863599445845466, 0.04743526304082479, 0.06223089723789599, 0.053896434110356495, 0.04930022820190061, 0.07724097871687263, 0.07990631303982809, 0.06872184327221476, 0.016245848273683805, 0.058381811395520344, 0.02973680355353281, 0.06153178299427964, 0.15710872976342216, 0.05910753163334448, 0.057422622630838305, 0.10165227155084722, 0.052205814281478524, 0.07391608291072771, 0.0409317524463404, 0.03576505019736942, 0.30582896433770657, 5.329200737178326, 40.15780694782734, 90.03246769309044, 104.41718101501465, 78.50008651614189, 61.659321784973145, 47.7837735414505, 42.67465889453888, 60.95192514359951, 102.98607900738716, 113.05047735571861, 54.08760488033295, 94.73625808954239, 118.83192792534828, 81.95181369781494, 4.6494172140955925, 0.8924509270582348, 0.06963815816561691, 0.5262069858144969, 0.2584583609132096, 0.4384620941709727, 0.22210998635273427, 1.4681636751629412, 1.4423901331610978, 1.5423397324047983, 1.299634287133813, 0.887980229454115, 5.115061802789569, 33.75478573143482, 73.24138149619102, 86.8700797855854, 88.72752651572227, 92.07299619913101, 90.78351259231567, 88.9642234146595, 89.595787525177, 94.62068349123001, 79.25834342837334, 83.142099827528, 84.93066385388374, 78.85842248797417, 88.17184433341026, 87.31343239545822, 89.56943213939667, 84.04807761311531, 77.50127211213112, 74.13390040397644, 79.14465352892876, 75.9426337480545, 78.71444061398506, 82.55702242255211, 81.41270622611046, 81.71883299946785, 77.0705196261406, 75.84557935595512, 67.1232233941555, 63.357465863227844, 78.4422156214714, 80.8449786901474, 63.206055387854576, 64.46546360850334, 71.9010642170906, 63.831460028886795, 76.97338923811913, 88.86357441544533, 83.21255564689636, 66.79859161376953, 78.0793122947216, 67.79578730463982, 50.03770999610424, 42.634970024228096, 49.130854457616806, 54.534335508942604, 53.00854258239269, 57.77102842926979, 57.01450042426586, 64.56692576408386, 67.52475544810295, 69.08940508961678, 74.7401350736618, 71.8138512969017, 71.98788195848465, 71.2666654586792, 71.16893470287323, 63.15433256328106, 70.57750403881073, 57.335548996925354, 57.743916884064674, 53.90797331929207, 53.538895323872566, 47.728596702218056, 48.16963903605938, 49.6547931432724, 48.603332564234734, 50.29089421033859, 45.824055299162865, 47.4020042270422, 50.01653753221035, 54.54100415110588, 50.29399484395981, 53.96550603210926, 57.90673054754734, 56.157490611076355, 37.53107249736786, 21.007543243467808, 18.560497350990772, 10.518518630415201, 0.35869374638423324, 0.7382458203937858, 0.4693798179505393, 0.19388179091038182, 0.2616041764849797, 0.20937439083354548, 0.051036965087405406, 0.15660089295124635, 0.4526054399320856, 0.15943001926643774, 9.16111271828413, 73.94922271370888, 106.4858128130436, 75.60440629720688, 79.09088641405106, 68.46529617905617, 42.51627579331398, 36.54992714524269, 35.67448832094669, 44.80917155742645, 72.81231611967087, 72.75879219174385, 75.76953023672104, 14.4832344353199, 0.7091199676506221, 0.0777591610676609, 0.1481974360649474, 0.06871957230032422, 0.1169118148391135, 0.10548899692366831, 0.02866733535483945, 0.09890347530017607, 0.0605453722528182, 0.0354607844928978, 0.009889002758427523, 0.025440150711801834, 0.022499904480355326, 0.07643747027032077, 0.057281414192402735, 0.05130395642481744, 0.06191781852976419, 0.024333823748747818, 0.028463333801482804, 0.024535619268135633, 0.05866958657861687, 0.03705219773110002, 0.0858965802763123, 0.052874474495183676, 0.027550646154850256, 0.006023066453053616, 0.06547937780851498, 0.0302791038484429, 0.06198531686095521, 0.018519547556934413, 0.017517846717964858, 0.0028820984971389407, 0.017286651018366683, 0.04050974501296878, 0.032043276078184135, 0.008227537273342023, 0.0939290301175788, 0.06039933614374604, 0.056650729675311595, 0.048361656299675815, 0.08663766668178141, 0.033081336587201804, 0.059014069265685976, 0.06124809333414305, 0.30850286304485053, 9.383028410375118, 54.88460451364517, 106.46059736609459, 114.18061271309853, 99.39492210745811, 97.63193070888519, 82.52488374710083, 42.83384755253792, 37.147517278790474, 57.142469957470894, 95.86802735924721, 66.10221818089485, 98.35269883275032, 129.59549635648727, 88.04910331964493, 3.738356251269579, 0.9398877597413957, 0.22700801258906722, 0.29184342885855585, 0.16609064623480663, 0.4295545112108812, 0.5829576530959457, 2.9543089354410768, 3.2300100289285183, 1.8078796961344779, 0.6310985761228949, 0.9972934168763459, 8.106938134878874, 44.43346291780472, 85.7920092344284, 95.3287222981453, 91.62782728672028, 98.5668857395649, 94.45084020495415, 97.9347288608551, 95.31249716877937, 94.17174518108368, 85.90964332222939, 89.71992686390877, 88.00961583852768, 84.85573947429657, 92.99030497670174, 92.0866146683693, 90.66527053713799, 87.86062583327293, 80.22229090332985, 79.29188042879105, 81.76455214619637, 82.17226266860962, 84.8967544734478, 87.63068497180939, 85.57185664772987, 85.76892167329788, 84.09766495227814, 84.99753266572952, 79.01033833622932, 74.78194043040276, 81.99007004499435, 85.81604674458504, 74.3609382212162, 71.13982066512108, 82.26713597774506, 78.64798218011856, 88.90219554305077, 96.44911497831345, 90.28817117214203, 72.54776671528816, 82.23483011126518, 74.04938533902168, 58.2547652721405, 50.79260028898716, 60.26652552187443, 66.71045914292336, 63.04651714861393, 68.47511485219002, 67.0496517419815, 75.41912823915482, 75.1300397515297, 78.95616844296455, 82.0272396504879, 77.16934472322464, 73.10765147209167, 74.10268887877464, 76.91749423742294, 70.70131659507751, 77.55191579461098, 67.78003334999084, 66.49310320615768, 67.28822574019432, 65.75278133153915, 59.834332913160324, 58.866855427622795, 62.833538576960564, 60.38662567734718, 63.043819293379784, 55.2826901525259, 56.961774453520775, 56.56100615859032, 61.15661635994911, 57.01569736003876, 58.80210690200329, 63.23637396097183, 73.45045387744904, 62.538982182741165, 49.63066823780537, 33.524179905653, 19.444411620497704, 3.337827818468213, 0.552417979342863, 0.5121130077168345, 0.13309814472449943, 0.18891404732130468, 0.12863997457316145, 0.11620814751950093, 0.29224228870589286, 0.4725598910590634, 0.20428834890481085, 8.571050930768251, 75.84614932537079, 110.05362376570702, 81.17980912327766, 76.46289423108101, 36.14063210785389, 22.140758335590363, 44.98648524284363, 54.24758769571781, 67.99694091081619, 89.55595046281815, 77.94109851121902, 92.71015360951424, 23.107783645391464, 0.5699144373647869, 0.05320658929122146, 0.11814875237178057, 0.06555891377502121, 0.07778801576932892, 0.05827350607432891, 0.13017705146921799, 0.03838903576252051, 0.022921650306670927, 0.04621959546057042, 0.027217731694690883, 0.032102525437949225, 0.03608906816225499, 0.055853291996754706, 0.03904621866240632, 0.026735615865618456, 0.022291828536253888, 0.048718736943555996, 0.04306523405830376, 0.015641753052477725, 0.0875939684920013, 0.03810073365457356, 0.035537630174076185, 0.027349833981133997, 0.1451390454894863, 0.2548520575510338, 0.12879828951554373, 0.11632029345491901, 0.19064078747760504, 0.1432765368372202, 0.21246657881420106, 0.18217583623481914, 0.19947004417190328, 0.16785336571047083, 0.07989746663952246, 0.23818796267732978, 0.2982384560164064, 0.22928686608793214, 0.1749447055044584, 0.17883133288705721, 0.14019905822351575, 0.13107389240758494, 0.1324204748379998, 0.11608607906964608, 0.4001356882508844, 12.79656384140253, 71.74110040068626, 126.71626925468445, 122.85398930311203, 96.30135610699654, 84.49428766965866, 59.17444512248039, 53.54554496705532, 82.54590421915054, 112.45333939790726, 131.94539666175842, 74.30954217910767, 122.25034609436989, 134.9889725446701, 101.77345007658005, 7.796490518376231, 1.3747629057615995, 0.3563476988347247, 0.5746835970785469, 0.34281335945706815, 0.7876524317543954, 0.3510131413349882, 2.736478499136865, 5.261107916012406, 7.662665024399757, 4.725250694900751, 2.5430315919220448, 7.261831182986498, 51.164759919047356, 103.32451924681664, 108.23703244328499, 102.25872203707695, 104.9479441344738, 102.39078775048256, 100.12418657541275, 96.26666396856308, 105.04315182566643, 94.28506270051003, 94.90646615624428, 92.32729375362396, 88.99204552173615, 94.88353058695793, 93.8882651925087, 98.50619539618492, 98.58495756983757, 90.94733700156212, 93.10245975852013, 94.37646299600601, 91.48319184780121, 89.9456499516964, 92.29843810200691, 88.98366317152977, 90.18462672829628, 91.70920372009277, 89.68303844332695, 84.48297947645187, 84.90309253334999, 85.78326970338821, 93.17564383149147, 80.99953919649124, 78.92209187150002, 83.7333633005619, 83.23528602719307, 92.72136300802231, 95.92795014381409, 93.60170736908913, 88.11645850539207, 87.91356459259987, 76.85392364859581, 62.634330466389656, 56.39313876628876, 65.62455341219902, 69.17788714170456, 64.65752810239792, 71.52030944824219, 68.70639324188232, 76.2472178041935, 81.8739102780819, 80.57352125644684, 83.5484728217125, 80.00542134046555, 82.95717135071754, 81.23400941491127, 83.22086960077286, 77.75829792022705, 83.34250867366791, 73.69168773293495, 71.56107366085052, 73.79717767238617, 69.42516267299652, 67.26126238703728, 66.71894788742065, 68.02051484584808, 64.33883160352707, 68.72439667582512, 64.21852245926857, 66.22045263648033, 63.303254172205925, 67.823556214571, 61.54676042497158, 64.79558229446411, 70.09222447872162, 80.66265687346458, 69.20653000473976, 58.069027438759804, 45.74788838624954, 23.82112506777048, 2.7690434642136097, 2.009401051327586, 1.6408595396205783, 0.19128075626213104, 0.63369324314408, 0.2842175349360332, 0.388744879164733, 0.27384815854020417, 0.43528329755645245, 0.6909885874483734, 13.395444955676794, 86.6159038245678, 117.17354491353035, 90.96676915884018, 113.35680171847343, 95.63439309597015, 52.333470806479454, 47.83141918480396, 45.2565823495388, 61.16879090666771, 91.88531666994095, 89.59206372499466, 108.03008034825325, 32.370915189385414, 0.8270823222119361, 0.2040109786321409, 0.26061617012601346, 0.11348012398229912, 0.1743124847416766, 0.1495407975744456, 0.18683195201447234, 0.20569148298818618, 0.1851622384856455, 0.13033251656452194, 0.17674371600151062, 0.17810442892368883, 0.1188048702897504, 0.1716359588317573, 0.19872409669915214, 0.16189675487112254, 0.20381983107654378, 0.09485925285844132, 0.17781850910978392, 0.0648638850543648, 0.1402662374312058, 0.09905397542752326, 0.23260732385097072, 0.12617160624358803], [0.019840800487145316, 0.01804399045795435, 0.02175490324589191, 0.05224588654527906, 0.07268919405760244, 0.022776454679842573, 0.13063471909845248, 0.1270345607190393, 0.07333763816859573, 0.0924739456968382, 0.056678478576941416, 0.12157999793998897, 0.030754391918890178, 0.05262460450467188, 0.03644831587735098, 0.12120364743168466, 0.01109787133827922, 0.08892674697563052, 0.08210717423935421, 0.32535228703636676, 20.374383218586445, 93.67021009325981, 102.90718004107475, 90.02584084868431, 64.62702333927155, 57.2102165222168, 40.43394573032856, 50.072341337800026, 121.46737530827522, 86.40817657113075, 130.0583267211914, 74.89212691783905, 100.02527788281441, 113.1546601653099, 93.61097887158394, 9.25343256443739, 0.7620288035832345, 0.045769122953061014, 0.380828597699292, 0.11478547268779948, 0.5606374726630747, 0.21385672531323507, 0.20716569997603074, 1.8615620280615985, 2.6270441338419914, 1.8885193252936006, 1.205696677789092, 13.725712783634663, 61.05691730976105, 89.78628650307655, 81.34586781263351, 82.68414080142975, 87.44917631149292, 88.59219297766685, 94.19309243559837, 96.32879063487053, 91.3990567624569, 81.25940725207329, 82.17973306775093, 90.74343994259834, 87.74035468697548, 88.63316237926483, 83.3759392797947, 77.85756379365921, 70.52746072411537, 70.32546356320381, 71.22114390134811, 74.74578157067299, 72.0972552895546, 73.60990852117538, 77.26571515202522, 81.36509478092194, 85.05807101726532, 88.77201452851295, 88.43317151069641, 91.71713009476662, 88.45172211527824, 75.28823286294937, 74.99905318021774, 87.4261723458767, 88.08090761303902, 74.32341143488884, 95.27532756328583, 90.98426342010498, 79.73201841115952, 83.54194477200508, 109.13730293512344, 79.52357679605484, 60.307160541415215, 69.29530084133148, 52.53826841711998, 60.674274042248726, 65.8556342124939, 74.09648761153221, 75.28358191251755, 79.64255601167679, 78.79473030567169, 84.5215018093586, 78.62515300512314, 78.07375699281693, 78.06662857532501, 69.37490656971931, 46.08627922832966, 64.66554567217827, 66.39590442180634, 69.51007291674614, 70.90081349015236, 66.70110404491425, 66.80531725287437, 60.83267234265804, 67.62734234333038, 61.12655997276306, 60.53433135151863, 56.043663918972015, 61.34190961718559, 54.65414308011532, 41.768996492028236, 45.17405077815056, 38.38719695806503, 45.38242019712925, 46.57712168991566, 48.31813886761665, 49.97710324823856, 60.5341337621212, 58.405674174427986, 47.22247526049614, 26.027621068060398, 15.60975143685937, 13.222219850867987, 1.022059537936002, 0.8779779192991555, 0.21300849504768848, 0.12276966808713041, 0.19426991930231452, 0.13966370257548988, 0.0516707146744011, 0.01998225383431418, 0.1431139768101275, 0.18785118794767186, 4.80852322652936, 63.43679800629616, 104.57760840654373, 71.48856595158577, 61.91025272011757, 85.08524715900421, 46.531387344002724, 30.417010635137558, 35.91296352446079, 48.225218653678894, 58.359582647681236, 62.058060988783836, 68.01746740937233, 25.06782867014408, 0.704692848958075, 0.07696908549405634, 0.16046711127273738, 0.11791924320277758, 0.061352977354545146, 0.09493825447862037, 0.08462050929665565, 0.035329287056811154, 0.048801798111526296, 0.03132737445412204, 0.024969293262984138, 0.07148994278395548, 0.09370978485094383, 0.019346186891198158, 0.0684895362064708, 0.029314517814782448, 0.05599559510301333, 0.013118475999363, 0.023726268263999373, 0.03752585864276625, 0.10037974803708494, 0.04644757580535952, 0.024185370093618985, 0.02394361548795132, 0.027683750340656843, 0.062055909947957844, 0.04834384104469791, 0.04778472182806581, 0.030772505888307933, 0.1090381846006494, 0.10253444022964686, 0.045703862197115086, 0.048689770919736475, 0.042197214424959384, 0.03229801826819312, 0.08717445467482321, 0.02911023981141625, 0.0117138733912725, 0.02421213564957725, 0.015246146595018217, 0.05905057922063861, 0.06914927580510266, 0.3201109729707241, 29.265805408358574, 113.0162563920021, 118.22947025299072, 109.07330676913261, 98.73943448066711, 94.65968459844589, 63.59295442700386, 44.20484818518162, 59.95046988129616, 57.526355758309364, 133.97818118333817, 83.33485588431358, 106.74961745738983, 120.67889481782913, 102.03762710094452, 8.2605847902596, 0.7549288251902908, 0.17805372539442033, 0.37596082140225917, 0.07483469846192747, 0.14843214768916368, 0.39830578956753016, 0.8242184633854777, 3.708283002488315, 2.139880587346852, 0.35485057916957885, 1.8006391846574843, 20.257769376039505, 79.8791541159153, 101.86415120959282, 93.81467074155807, 94.64738085865974, 95.63921883702278, 92.07585364580154, 96.23406931757927, 94.8842753469944, 89.66752767562866, 83.30174446105957, 89.89389672875404, 91.97028771042824, 93.12227949500084, 92.42786675691605, 87.45291531085968, 80.68167865276337, 76.64132505655289, 79.2156109213829, 81.63913607597351, 84.61490079760551, 82.00877264142036, 82.48422592878342, 79.81023341417313, 83.74302238225937, 87.85460695624352, 86.59460976719856, 90.20680993795395, 92.07595244050026, 90.29078543186188, 82.7170242369175, 81.79338499903679, 88.99408981204033, 90.70726588368416, 78.94124284386635, 94.68068987131119, 92.0468308031559, 82.07034453749657, 87.39146500825882, 113.33294659852982, 93.40689182281494, 68.15951138734818, 73.6891570687294, 62.024033814668655, 70.54830640554428, 73.68291020393372, 81.19850412011147, 82.72647053003311, 84.64315608143806, 84.33848842978477, 89.41187739372253, 84.93013188242912, 83.11913385987282, 82.35561802983284, 70.39648935198784, 51.29567429423332, 71.28495007753372, 70.36453306674957, 74.0660360455513, 73.48219737410545, 70.52184462547302, 68.61634567379951, 64.94729295372963, 72.69445404410362, 72.47031167149544, 68.0271264910698, 64.73929971456528, 70.41928052902222, 63.48002448678017, 54.1643151640892, 56.300480738282204, 52.09276892244816, 54.02068667113781, 55.15452682971954, 57.575954496860504, 57.84633278846741, 68.59142661094666, 70.65375074744225, 65.99885612726212, 57.13037520647049, 34.718725606799126, 21.77735723555088, 6.242468906566501, 0.19157696224283427, 0.1877267297822982, 0.08143274753820151, 0.16985443333396688, 0.10075076250359416, 0.1464140255120583, 0.04170199783402495, 0.15647074993466958, 0.4348985682008788, 4.107125988230109, 69.84067797660828, 107.22032099962234, 80.25015860795975, 61.13823674619198, 35.900709182024, 23.60256839543581, 41.99694626033306, 59.46587048470974, 69.01717856526375, 81.01113617420197, 68.19266840815544, 81.2187722325325, 36.69637888669968, 0.27446057880297303, 0.039841518955654465, 0.053526043047895655, 0.11902967424248345, 0.015018823978607543, 0.06871212855912745, 0.02769424801954301, 0.03736938793736044, 0.04308155388571322, 0.05051431871834211, 0.01078293633327121, 0.0805553953978233, 0.048548425183980726, 0.017957682393898722, 0.004926687979605049, 0.06003853734000586, 0.06460159522248432, 0.021907984191784635, 0.028979132002859842, 0.10623184221913107, 0.019860506363329478, 0.0841021265659947, 0.007733941347396467, 0.0975932358414866, 0.10128527952474542, 0.17443762568291277, 0.13198514585383236, 0.21832118887687102, 0.1296663351240568, 0.2164256398100406, 0.21427498490083963, 0.23966762702912092, 0.25752928107976913, 0.23897221981314942, 0.22341168369166553, 0.12761091260472313, 0.16037771216360852, 0.11733332503354177, 0.1862484309822321, 0.12406991081661545, 0.2314632586785592, 0.23365351458778605, 0.44971676368732005, 36.9557149708271, 131.78214222192764, 132.07433134317398, 113.89494404196739, 89.58192586898804, 81.96860119700432, 49.78373162448406, 63.3476547896862, 140.7957449555397, 102.86887049674988, 148.77397924661636, 95.27862578630447, 123.14307019114494, 128.51070016622543, 116.3556008040905, 14.28178634494543, 0.9163518820423633, 0.5580760538578033, 0.40185791614931077, 0.1665708899963647, 0.8207858225796372, 0.3846866375533864, 0.3451704204780981, 9.671082403510809, 6.539350776001811, 6.829608175903559, 2.5035821087658405, 18.901861533522606, 84.05791908502579, 108.60324159264565, 99.6320141851902, 97.60967910289764, 99.31415364146233, 99.45894107222557, 102.05889835953712, 103.89556020498276, 101.73330903053284, 91.98751598596573, 92.16552883386612, 97.07753285765648, 97.11083427071571, 101.01080819964409, 95.73868229985237, 92.42496371269226, 89.07054170966148, 89.09221574664116, 88.99674966931343, 89.46971029043198, 86.11430794000626, 89.63319271802902, 86.80204063653946, 92.05813899636269, 93.63232612609863, 94.90393549203873, 94.49338272213936, 97.20937818288803, 93.76666411757469, 83.42658296227455, 88.3678226172924, 93.53201150894165, 89.91591274738312, 86.64418190717697, 102.09466964006424, 97.06844374537468, 94.13009941577911, 100.39293095469475, 117.47005820274353, 95.3583151102066, 74.07723784446716, 82.37712487578392, 67.76874035596848, 74.23166915774345, 78.43598395586014, 85.18583536148071, 82.30872854590416, 87.0981739461422, 84.71166640520096, 95.46026363968849, 90.77385351061821, 90.6189738214016, 87.67094001173973, 83.65784615278244, 64.86549094319344, 75.97022786736488, 76.2703737616539, 85.52014142274857, 83.34650605916977, 78.16774114966393, 77.89933875203133, 76.27936407923698, 80.08558943867683, 77.07799762487411, 78.60534086823463, 72.80202627182007, 70.53524270653725, 69.24936130642891, 61.82366296648979, 61.7629574239254, 58.313567116856575, 57.835723757743835, 59.28532317280769, 61.48795858025551, 63.49527306854725, 71.98722839355469, 76.46896630525589, 73.90684738755226, 64.44043815135956, 45.74197590351105, 29.240546263754368, 5.779786733910441, 3.1034756312146783, 0.5111336102709174, 0.17878309328807518, 0.6691489031072706, 0.22238863311940804, 0.21393963805167004, 0.13040034886216745, 0.23467972670914605, 1.4139496092684567, 7.419573068618774, 76.44613713026047, 118.52123379707336, 85.54339617490768, 85.63075348734856, 120.2000293135643, 55.063229128718376, 40.905705615878105, 48.07159669697285, 63.60805481672287, 79.75191414356232, 74.05829206109047, 98.31115946173668, 51.75201840698719, 1.3779001124203205, 0.3087368473643437, 0.31763727602083236, 0.21501349605387077, 0.07707904951530509, 0.251206093817018, 0.21139868767932057, 0.11340812081471086, 0.10282355870003812, 0.10514650319237262, 0.11080323442001827, 0.2540043764747679, 0.183026441372931, 0.18288626451976597, 0.08019061497179791, 0.16130943404277787, 0.1783200228237547, 0.09854843185166828, 0.1609547616681084, 0.19848736643325537, 0.11125005185022019, 0.18338650173973292, 0.1138033664028626], [0.057252091937698424, 0.060532803981914185, 0.1109941370668821, 0.03013881196238799, 0.03851300039968919, 0.09178164065815508, 0.05163560366781894, 0.08016765292268246, 0.1461155930883251, 0.0784795118670445, 0.053006810558144934, 0.1285092972102575, 0.015240753036778187, 0.06309797434369102, 0.01931441183842253, 0.026985157455783337, 0.18292409920832142, 0.09839611346251331, 0.15646580723114312, 13.860712889581919, 93.02832573652267, 78.7866747379303, 82.95099288225174, 69.22050565481186, 66.0935166478157, 42.93914370238781, 62.96350680291653, 190.49978345632553, 160.99980801343918, 102.63411909341812, 69.2267145216465, 95.43704688549042, 108.75067368149757, 98.66769433021545, 10.555368103086948, 1.184318431187421, 0.1659706112695858, 0.39795745513401926, 0.15577163198031485, 0.37914775195531547, 0.03136742816423066, 0.12271863801288418, 1.493250047788024, 4.645827831700444, 2.12488089222461, 1.458683421369642, 15.815085768699646, 78.70286643505096, 93.5405382514, 99.86513167619705, 93.86193260550499, 90.92823162674904, 87.89018824696541, 81.07317164540291, 77.37153947353363, 76.3503822684288, 72.00314193964005, 78.47935482859612, 81.5671755373478, 84.23508077859879, 79.4672030210495, 72.48233422636986, 71.01255789399147, 70.96892103552818, 74.51498195528984, 85.11800900101662, 91.47929325699806, 94.4269622862339, 93.54064464569092, 89.18116137385368, 76.85817942023277, 75.56030586361885, 76.16968676447868, 80.95245212316513, 90.18709659576416, 86.91832199692726, 86.31579592823982, 84.38091695308685, 80.41033521294594, 70.76146736741066, 78.83114755153656, 87.60606229305267, 90.10458782315254, 75.79203262925148, 69.27351281046867, 70.75220346450806, 88.56578439474106, 106.61277920007706, 82.26030394434929, 57.81831309199333, 75.12537360191345, 77.7961590886116, 74.69218164682388, 81.7540343105793, 90.8766607940197, 88.5532982647419, 89.65037539601326, 90.63069239258766, 93.44435021281242, 91.75594121217728, 81.4277458190918, 52.9388315230608, 52.27293625473976, 69.52422335743904, 66.62739560008049, 67.38572850823402, 62.27945610880852, 63.04483383893967, 56.68093912303448, 55.31325191259384, 52.17754237353802, 60.16893915832043, 55.39602667093277, 59.068879187107086, 52.20004476606846, 62.500566244125366, 46.49377316236496, 41.3337754458189, 38.90211872756481, 34.607212990522385, 39.18055258691311, 45.022309720516205, 49.124474599957466, 64.4087402522564, 57.18796491622925, 52.79530182480812, 43.20969678461552, 27.793697901070118, 9.736750479787588, 15.539905484765768, 3.3008691016584635, 1.4045064034871757, 0.2174688916420564, 0.10795929483720101, 0.11535750527400523, 0.12251237290911376, 0.20326552097685635, 0.04570303841319401, 0.4874269792344421, 0.15384733211249113, 3.7924964586272836, 59.5535621792078, 103.3640219271183, 91.65691092610359, 75.91247096657753, 70.48342108726501, 46.96531645953655, 27.704408392310143, 32.381505221128464, 29.659209698438644, 62.97846280038357, 63.17462347447872, 71.78004071116447, 38.154261857271194, 1.6447399626486003, 0.07933537883218378, 0.050046765682054684, 0.016327901976183057, 0.12291276158066466, 0.03982847942097578, 0.047044091843417846, 0.021839704750163946, 0.03909050632501021, 0.08479699201416224, 0.02874852259992622, 0.05105007141537499, 0.08309066834044643, 0.057185268960893154, 0.13721650029765442, 0.018835400042007677, 0.04829101868381258, 0.0033741352172000916, 0.08239011804107577, 0.0594625899248058, 0.04837393884372432, 0.04417818097863346, 0.023149738262873143, 0.026940294628730044, 0.06729234810336493, 0.009372256463393569, 0.036337272031232715, 0.09166113813989796, 0.024850243498804048, 0.020125729533901904, 0.06957745790714398, 0.04304009009501897, 0.059602614637697116, 0.005723721187678166, 0.024418614120804705, 0.03570962660887744, 0.075131149351364, 0.06170790577016305, 0.06369721406372264, 0.13986161851789802, 0.2685573877533898, 21.675617694854736, 112.66556560993195, 88.64361941814423, 99.42415773868561, 91.61271929740906, 82.37209394574165, 57.13021941483021, 45.12729428708553, 118.13320621848106, 150.6095239520073, 103.01823288202286, 82.06538200378418, 103.47006663680077, 115.83408638834953, 110.34421697258949, 11.491229385137558, 1.0852578654885292, 0.14778634562389925, 0.3766425879439339, 0.11361076423781924, 0.549520991044119, 0.05594435722741764, 0.481795622035861, 3.158970228396356, 2.4357054010033607, 2.1667123725637794, 2.350448425859213, 22.83465050160885, 92.7644906938076, 102.35087469220161, 105.01923590898514, 100.6370298564434, 95.44742792844772, 91.4924481511116, 85.13108029961586, 80.89927777647972, 83.58606800436974, 83.82034063339233, 88.25730174779892, 86.47217273712158, 88.03573563694954, 79.71421256661415, 79.87234488129616, 79.69610273838043, 81.63393035531044, 85.53127482533455, 89.38641875982285, 92.61410236358643, 93.41683968901634, 93.10413926839828, 93.29768568277359, 85.31851664185524, 84.30802166461945, 83.51387187838554, 86.61568343639374, 91.96363046765327, 88.50665956735611, 89.16524782776833, 89.43554252386093, 85.58730661869049, 74.52169239521027, 80.90084329247475, 91.13073796033859, 93.01225259900093, 80.66954210400581, 79.69661191105843, 77.36057326197624, 93.01855266094208, 106.22378647327423, 87.60412439703941, 68.40468943119049, 82.2419661283493, 82.85280615091324, 75.84407463669777, 85.78040465712547, 93.20067688822746, 91.26124575734138, 91.32082656025887, 91.98256105184555, 96.85766905546188, 95.14214470982552, 84.39068242907524, 62.963016629219055, 66.69587552547455, 75.43992072343826, 72.38617658615112, 70.78835472464561, 69.79641035199165, 70.28466135263443, 63.5435076802969, 61.251425072550774, 56.731898188591, 65.07523208856583, 61.88321717083454, 64.2330376803875, 54.956314265728, 67.49096006155014, 57.027427330613136, 54.168304949998856, 50.19109256565571, 48.864173367619514, 51.11459121108055, 55.83067014813423, 56.11977003514767, 69.81186792254448, 71.48079916834831, 69.69144478440285, 62.59510517120361, 56.91544733941555, 29.82169657945633, 22.367155887186527, 7.94179804623127, 0.35751444404013455, 0.16413780336733907, 0.03194110460754018, 0.15487363329157233, 0.05966186028672382, 0.18439745530486107, 0.06916381447808817, 0.38084970437921584, 0.15824347356101498, 3.640763950534165, 64.80841040611267, 107.5482814013958, 98.78004670143127, 76.67175382375717, 37.04691007733345, 15.647005587816238, 28.886017687618732, 57.69344799220562, 54.59434188902378, 83.49173426628113, 72.5478883087635, 82.79160663485527, 51.639696434140205, 0.9701349679380655, 0.04082451210706495, 0.08522051342879422, 0.07889351894846186, 0.17186430282890797, 0.06308633004664443, 0.08220141957281157, 0.029577627719845623, 0.06202262833539862, 0.07980852766195312, 0.07914255402283743, 0.08259739988716319, 0.09240254366886802, 0.022483469620055985, 0.1239810831611976, 0.005257470156720956, 0.05248745561402757, 0.034321558123338036, 0.021054829776403494, 0.041986040014307946, 0.06751183085725643, 0.06355803910992108, 0.09591805268428288, 0.10743832943262532, 0.2076233527623117, 0.10907170741120353, 0.13277623074827716, 0.16839667718159035, 0.19142553443089128, 0.22981073328992352, 0.23574190330691636, 0.17797248990973458, 0.3353824425721541, 0.2903334848815575, 0.32232408702839166, 0.17194662184920162, 0.14909160527167842, 0.18129879579646513, 0.24948790320195258, 0.24897501978557557, 0.5215197592042387, 27.43641447275877, 129.84859317541122, 101.93267673254013, 104.48284149169922, 89.95221599936485, 81.32563009858131, 53.15734259784222, 83.4913694858551, 203.83629262447357, 159.889857172966, 111.56343474984169, 93.20269078016281, 114.30860504508018, 124.90476965904236, 124.38973009586334, 20.0271787494421, 1.491635253187269, 0.5447074212133884, 0.7265389454551041, 0.39581404358614236, 0.8145010785665363, 0.08616863677161746, 0.43023031088523567, 4.053592085838318, 12.429109308868647, 7.653811974450946, 3.0592847149819136, 23.41244749724865, 104.56842049956322, 106.24664604663849, 108.364128023386, 100.14770731329918, 102.16111287474632, 101.58710047602654, 95.99592849612236, 90.2134595811367, 95.01251086592674, 88.45747500658035, 94.47761356830597, 93.86710032820702, 98.0599245429039, 89.69413384795189, 90.17264977097511, 86.13679513335228, 86.61031812429428, 87.41932511329651, 91.99728146195412, 98.0719242990017, 101.58403024077415, 98.45037639141083, 101.88742116093636, 89.05419498682022, 88.77044901251793, 86.5454176068306, 89.55724999308586, 97.5242368876934, 95.71039661765099, 92.24548414349556, 92.32451230287552, 84.46291655302048, 80.43478310108185, 83.80973160266876, 92.1441587805748, 97.74637296795845, 89.03815224766731, 84.84640717506409, 89.44145500659943, 103.21445435285568, 114.07221972942352, 95.33423960208893, 75.84591373801231, 88.0339041352272, 87.76338905096054, 80.01280054450035, 86.82773485779762, 98.34156543016434, 93.74922305345535, 91.89502894878387, 96.64726674556732, 100.4792395234108, 98.23026940226555, 90.03404080867767, 71.17272689938545, 61.09880246222019, 76.69940114021301, 79.23962563276291, 80.53460374474525, 79.59324985742569, 80.52248999476433, 72.92447090148926, 70.70714548230171, 69.16324272751808, 77.4874484539032, 73.68579044938087, 79.3064184486866, 68.12753990292549, 75.40057763457298, 65.42657643556595, 59.4383105635643, 56.81700222194195, 54.82706040143967, 54.76874493062496, 57.86385364830494, 59.20313738286495, 71.17685347795486, 70.9838542342186, 72.91846722364426, 68.32259863615036, 65.40481880307198, 38.43571275472641, 32.1821603178978, 8.634941652417183, 2.7640317706391215, 0.6864228355698287, 0.25509960833005607, 0.7266341778449714, 0.13066516199614853, 0.2794887183699757, 0.21241353009827435, 0.5065043305512518, 1.0009793378412724, 6.450380925089121, 72.79535382986069, 120.50678685307503, 107.82461017370224, 97.18879088759422, 98.47726374864578, 56.63203954696655, 38.17485675215721, 44.22234244644642, 45.97288191318512, 84.04148876667023, 78.88309836387634, 93.36038991808891, 71.70754820108414, 2.2494781063869596, 0.18816389929270372, 0.14175366464769468, 0.15432404325110838, 0.2820050739683211, 0.13272772397613153, 0.13926145853474736, 0.13153256935765967, 0.10412838048068807, 0.22053033986594528, 0.10247158774291165, 0.1146757387323305, 0.18915140099124983, 0.1345848891651258, 0.2651891950517893, 0.10931785553111695, 0.1441783650079742, 0.16498787415912375, 0.09566390421241522, 0.145206966844853, 0.16951580619206652, 0.1486288761952892], [0.048875070351641625, 0.02644969048560597, 0.0735977609292604, 0.0769957657030318, 0.06311560035101138, 0.0847318017622456, 0.033837521987152286, 0.08153788017807528, 0.06053785058611538, 0.11462064911029302, 0.1041480251296889, 0.04201229719910771, 0.11134211526950821, 0.025828895086306147, 0.09436188032850623, 0.04661058854253497, 0.005709649140044348, 0.02232054222986335, 0.9896402712911367, 71.03535667061806, 92.48788833618164, 91.3847467303276, 69.70526084303856, 57.86204494535923, 58.60957123339176, 61.84325851500034, 88.719911724329, 153.21104675531387, 110.66950231790543, 61.00374676287174, 103.51200118660927, 109.22640055418015, 92.8920878469944, 9.204225204885006, 0.8125174068845809, 0.19425495760515332, 0.20757558813784271, 0.08382872678339481, 0.42964837804902345, 0.12137291647377424, 0.4259861761238426, 0.26129381032660604, 3.4752906672656536, 2.4807493714615703, 1.6564876260235906, 12.707212585955858, 82.267424762249, 89.86734375357628, 97.03806817531586, 93.11970323324203, 90.9420096874237, 80.83467364311218, 74.5110833644867, 71.2163333594799, 64.4557437300682, 69.44063544273376, 76.35851383209229, 79.10536363720894, 77.01117441058159, 74.0536867082119, 70.89418664574623, 76.1424270272255, 81.91956102848053, 90.46115309000015, 89.29753392934799, 84.96436044573784, 87.27099627256393, 88.90950635075569, 91.74801483750343, 93.62468853592873, 96.62567630410194, 95.88344693183899, 95.6032195687294, 83.5518166422844, 83.39614659547806, 89.26467329263687, 81.80809780955315, 87.12333619594574, 80.7194410264492, 74.21217620372772, 76.07988238334656, 74.43100646138191, 77.88316681981087, 70.58894142508507, 72.19025149941444, 80.84484949707985, 87.4254883825779, 90.53531751036644, 94.32378262281418, 75.7038925588131, 75.40847361087799, 74.0940709412098, 78.27275231480598, 94.50206145644188, 95.037771910429, 91.16955667734146, 87.48924136161804, 88.80926012992859, 91.50520786643028, 99.78630870580673, 81.08978435397148, 77.28437215089798, 88.91782030463219, 83.72073277831078, 84.31318938732147, 77.09775656461716, 74.55161198973656, 72.5911071896553, 62.26244442164898, 62.013322189450264, 59.1977758705616, 52.72759705781937, 54.330392852425575, 57.49293655157089, 31.91518284380436, 45.23941867053509, 58.2593060284853, 39.55784194171429, 32.18692146241665, 21.67112823575735, 28.444302789866924, 36.97347901761532, 41.10333301126957, 49.77925546467304, 67.59215623140335, 66.14240482449532, 48.409140184521675, 38.36074277758598, 29.41373147070408, 9.918825309723616, 11.071088779717684, 3.4768825443461537, 0.5764826817903668, 0.2618645812617615, 0.08308132470119745, 0.1128685794537887, 0.407843129360117, 0.12132207935792394, 0.04691788592026569, 0.24610862281406298, 0.2826209081104025, 1.1891833576373756, 48.74881915748119, 86.49520710110664, 90.7064451277256, 67.04386085271835, 66.378463357687, 68.56699392199516, 22.245387621223927, 33.6761299520731, 34.99806381762028, 44.92096155881882, 59.0471975505352, 72.6276384294033, 34.32603947818279, 1.9569550780579448, 0.023514982531196438, 0.13349114160519093, 0.08118927114992402, 0.045751979341730475, 0.03712282421474811, 0.010884190323849907, 0.08438144126557745, 0.03063784504774958, 0.018083491268043872, 0.047744100374984555, 0.011593342114792904, 0.10452308430103585, 0.033805906496127136, 0.08568406628910452, 0.054821829180582426, 0.09209346142597497, 0.04027436545584351, 0.10851106679183431, 0.09135793370660394, 0.05132300364493858, 0.07167179122916423, 0.06477973292930983, 0.08005630850675516, 0.1144042240048293, 0.10563491057837382, 0.03186264104442671, 0.042787711645360105, 0.10145039996132255, 0.019811650781775825, 0.04781624455063138, 0.01704829544905806, 0.09262823077733628, 0.030118942813714966, 0.0388722221396165, 0.06119391655374784, 0.0424240629945416, 0.03294636961072683, 0.07567872075014748, 3.0488846730440855, 90.94137132167816, 101.8420971930027, 116.62673905491829, 102.74751260876656, 93.68372976779938, 91.64667427539825, 60.56421674787998, 70.3732118010521, 156.86611622571945, 117.80462265014648, 67.28723019361496, 103.55582043528557, 117.81996622681618, 103.12231689691544, 9.832793176174164, 0.8334969123825431, 0.1695385604398325, 0.26100867718923837, 0.053847637900616974, 0.36573346238583326, 0.41943805874325335, 1.2960408674553037, 2.6673642452806234, 5.768566885963082, 0.45930008694995195, 1.7370574339292943, 18.872952684760094, 100.51939576864243, 96.65007099509239, 104.17525559663773, 97.9120896756649, 94.64842200279236, 88.1768448650837, 84.03207287192345, 80.83782747387886, 76.2784293293953, 77.04194515943527, 82.81906396150589, 86.3696314394474, 83.40598806738853, 78.01503494381905, 81.87329471111298, 83.91790419816971, 87.12592005729675, 90.45515701174736, 88.97661834955215, 88.28962281346321, 89.14288222789764, 90.79515516757965, 93.11822891235352, 93.3028382062912, 98.71812522411346, 97.03028619289398, 97.8269362449646, 86.04151144623756, 87.42434084415436, 89.60302993655205, 86.6150450706482, 91.33664891123772, 80.71038231253624, 78.87202575802803, 77.61588916182518, 75.38490727543831, 80.73037683963776, 74.06434133648872, 73.08610662817955, 86.51147022843361, 92.11120694875717, 94.25919368863106, 92.85633936524391, 82.93203949928284, 79.01902467012405, 74.69419553875923, 79.57017749547958, 97.45926797389984, 94.38213989138603, 91.75296977162361, 88.55323746800423, 89.51077848672867, 88.47161024808884, 97.35423400998116, 84.57007840275764, 88.80447998642921, 90.16472339630127, 87.34911248087883, 87.47501492500305, 83.98715168237686, 79.11713540554047, 77.11154222488403, 69.71091493964195, 69.5502595603466, 66.05693221092224, 61.03156507015228, 61.03786513209343, 65.91663613915443, 43.9201370626688, 53.55288237333298, 63.66804979741573, 54.33723248541355, 50.887644588947296, 38.302020728588104, 41.89981207251549, 46.31932072341442, 51.95995844900608, 56.12538233399391, 70.09874492883682, 77.05940902233124, 72.10528805851936, 59.6591205149889, 56.55141547322273, 31.70083824545145, 19.106550849974155, 6.85541401617229, 0.680914674885571, 0.3198899910785258, 0.06271705962717533, 0.044623603171203285, 0.26006101397797465, 0.1940352373640053, 0.06053291530406568, 0.4060912749264389, 0.3834204445593059, 1.5405838703736663, 55.6864944845438, 91.7958314716816, 97.03672304749489, 67.28536829352379, 42.19898521900177, 25.66010668873787, 27.04174105077982, 54.501638263463974, 58.891098126769066, 72.66190499067307, 71.1301463842392, 84.02952700853348, 49.052031487226486, 1.0821412014774978, 0.015506979962083278, 0.06100473568949383, 0.11859614125569351, 0.04880954984400887, 0.08811183914076537, 0.009759750319062732, 0.04781797375471797, 0.038543016562471166, 0.07318156451219693, 0.10854003281565383, 0.05672931198205333, 0.06373504875227809, 0.04969562593032606, 0.03390469377336558, 0.03548547945683822, 0.06165184393466916, 0.05890873995667789, 0.03450343254371546, 0.022319633098959457, 0.02466836722305743, 0.20801835344173014, 0.184107186505571, 0.20848232932621613, 0.4003156739054248, 0.17119503405410796, 0.10040771216154099, 0.08494505789713003, 0.2612401085207239, 0.24155302351573482, 0.22084106225520372, 0.24110721540637314, 0.2337483165320009, 0.32966849918011576, 0.169604359252844, 0.16507954424014315, 0.16968816256849095, 0.20434553880477324, 0.3042660013306886, 5.478540798649192, 108.25587183237076, 117.10775524377823, 121.09899267554283, 94.20506939291954, 80.87691977620125, 75.2920326590538, 84.68613177537918, 112.70105570554733, 155.25529146194458, 114.80342209339142, 76.85659870505333, 125.39392501115799, 127.45563358068466, 120.35030364990234, 16.733416691422462, 1.1007669707760215, 0.6207849201746285, 0.3429074340965599, 0.2560953627107665, 0.7059990288689733, 0.3900655754841864, 0.8503358869347721, 2.053929199464619, 9.650929234921932, 9.773985631763935, 4.343076702207327, 18.98583322763443, 110.87350577116013, 101.09872028231621, 105.47117605805397, 99.62964311242104, 101.35903671383858, 93.4689348936081, 91.07340663671494, 86.21495693922043, 82.65527755022049, 84.86006364226341, 95.45782417058945, 97.43004754185677, 94.08473744988441, 90.2253757417202, 88.09955701231956, 87.57389321923256, 91.05969697237015, 97.37031474709511, 97.02260300517082, 92.77854233980179, 95.27097299695015, 95.71526035666466, 99.63335931301117, 99.30862873792648, 103.2869316637516, 102.1070645749569, 101.35743319988251, 91.0872682929039, 94.03870671987534, 93.24779435992241, 90.73837101459503, 92.078125923872, 80.89580476284027, 79.94859918951988, 79.75478678941727, 77.2680102288723, 82.55224987864494, 79.63522240519524, 77.28922069072723, 94.15982142090797, 97.53608465194702, 99.92325335741043, 99.07829269766808, 88.11549335718155, 82.85190179944038, 77.94128850102425, 81.27523720264435, 97.20224216580391, 101.4089584350586, 95.08634090423584, 91.25960424542427, 89.71064016222954, 96.14733517169952, 102.41000711917877, 97.86413624882698, 88.96028682589531, 91.07937231659889, 92.95069590210915, 91.91234081983566, 86.27287343144417, 83.25998470187187, 83.73405486345291, 78.03215682506561, 76.03673189878464, 73.8072395324707, 67.6517902314663, 69.87176030874252, 77.39197477698326, 55.23559547960758, 63.65352317690849, 73.0882117152214, 60.46737514436245, 55.449865981936455, 44.45277348160744, 49.26450848579407, 55.493616834282875, 58.10491271317005, 60.89964374899864, 69.85656872391701, 71.61098778247833, 69.8763732612133, 62.652166709303856, 63.06743502616882, 39.24932509660721, 26.832993552088737, 7.514880979433656, 2.5376038206741214, 0.7166425546165556, 0.14703135879244655, 0.19477542577078566, 0.7314139057416469, 0.2501975744962692, 0.15238996187690645, 0.4402629897231236, 1.4781617699190974, 3.544273115694523, 64.1551722586155, 103.6027555167675, 104.58057224750519, 85.31811386346817, 96.72867357730865, 93.69344964623451, 33.99068847298622, 44.251965656876564, 48.257471323013306, 67.23014205694199, 77.58114382624626, 92.65162155032158, 73.40121611952782, 3.6369035951793194, 0.163029984687455, 0.21399158838903531, 0.2684378722915426, 0.17089965927880257, 0.2773652854375541, 0.10667575043044053, 0.1657614146824926, 0.1367755903629586, 0.11693392341840081, 0.20971626858226955, 0.2161847535171546, 0.20119679917115718, 0.15851910720812157, 0.16237524716416374, 0.14729798276675865, 0.16982053202809766, 0.15166210796451196, 0.17234082100912929, 0.1259804141591303, 0.141999656916596], [0.036773547253687866, 0.03532423674187157, 0.08239753209636547, 0.07202281223726459, 0.08945709312683903, 0.07752449397230521, 0.0904647886636667, 0.05600468641205225, 0.09726415271870792, 0.12676769925747067, 0.08205262638512067, 0.005000482506147819, 0.06978884382988326, 0.05470222466101404, 0.005398357152444078, 0.040016821658355184, 0.10708091111155227, 0.08914397360058501, 29.275025613605976, 94.48352605104446, 76.23928382992744, 56.201146468520164, 37.53238342702389, 36.583904922008514, 37.120481729507446, 28.58886033296585, 21.468412913382053, 62.11236007511616, 75.7099874317646, 102.56148219108582, 111.0476504266262, 82.82554641366005, 4.812243226915598, 0.7021674688439816, 0.14599860092857853, 0.17464290373027325, 0.11427372475736775, 0.382452862104401, 0.10174125505727716, 0.45582864666357636, 0.2315814679604955, 0.6255357933696359, 2.5183222303166986, 1.0755471303127706, 5.569716906175017, 67.45397284626961, 89.88552957773209, 100.31115934252739, 92.71686404943466, 89.54369992017746, 82.92392313480377, 84.30271714925766, 82.20427975058556, 84.71696332097054, 79.55476552248001, 66.91225871443748, 65.93872055411339, 73.96037891507149, 72.16687515377998, 70.6774690747261, 86.48526683449745, 85.47099485993385, 81.71909898519516, 80.57616591453552, 82.22346872091293, 86.43349081277847, 88.91711354255676, 92.00127884745598, 91.58409923315048, 97.76797100901604, 93.92677992582321, 90.17665475606918, 87.4119383096695, 82.16258078813553, 83.78269225358963, 89.35298055410385, 87.40718856453896, 91.04711204767227, 82.53533318638802, 75.29865190386772, 74.69951525330544, 75.0489217042923, 73.1604078412056, 71.5019716322422, 72.54158064723015, 62.153717055916786, 56.364625096321106, 66.89199820160866, 70.75230985879898, 63.474260196089745, 80.17084166407585, 72.31384366750717, 81.22948005795479, 93.49650621414185, 85.50594538450241, 85.3226812183857, 87.5152775645256, 88.34666535258293, 88.65823343396187, 91.16837114095688, 84.76653546094894, 94.64790523052216, 82.42878690361977, 83.24845612049103, 81.3029833137989, 83.3523577451706, 82.81458780169487, 77.35429599881172, 74.06978264451027, 68.31529542803764, 68.93942713737488, 65.72078704833984, 59.12529096007347, 55.26194326579571, 51.02607116103172, 34.91142466664314, 47.02631838619709, 47.977183163166046, 38.87244611978531, 24.180933460593224, 18.316200859844685, 20.248526372015476, 24.90430634468794, 42.90635906159878, 57.69386976957321, 71.30166158080101, 72.7989636361599, 47.94006675481796, 40.56450292468071, 27.02576480805874, 9.937137477099895, 9.506015460938215, 2.659099926240742, 1.004981710575521, 0.3490866150241345, 0.16144380730111152, 0.2939581935061142, 0.7648812630213797, 0.10451662019477226, 0.10296539796399884, 0.20886628684820607, 0.09819637183682062, 0.6134383706375957, 43.98864358663559, 86.23912364244461, 96.66142478585243, 58.66359293460846, 62.64644801616669, 69.28011685609818, 30.400361828505993, 23.604200407862663, 36.12147353589535, 49.444269239902496, 61.223986744880676, 65.08380442857742, 37.567634135484695, 1.113158818334341, 0.028576210752362385, 0.2631194639252499, 0.024018054755288176, 0.07207980917883106, 0.10231399268377572, 0.02509564204956405, 0.0744395270885434, 0.02823999930114951, 0.024857885764504317, 0.04715002971352078, 0.017860340449260548, 0.022164711626828648, 0.013761163827439304, 0.08098750346107408, 0.09756219180417247, 0.08991741022327915, 0.03477665421087295, 0.039681352354818955, 0.0044436152438720455, 0.016119634929054882, 0.050581802206579596, 0.034171165607403964, 0.015710342340753414, 0.06314256999758072, 0.07546687469584867, 0.01637177774682641, 0.09046398714417592, 0.04004292670288123, 0.1151395810302347, 0.04959153971867636, 0.05195367702981457, 0.10280735761625692, 0.02449759718729183, 0.042933087243000045, 0.09205238355207257, 0.047429778569494374, 0.1692433637799695, 41.638978868722916, 107.46970161795616, 95.14713004231453, 80.34917369484901, 42.56770223379135, 46.259435936808586, 44.3518128991127, 36.242158859968185, 26.90773744136095, 63.35604093968868, 82.10942924022675, 105.0131106376648, 118.37044268846512, 91.54253706336021, 5.764835011214018, 0.6627372815273702, 0.0912209035595879, 0.24637370312120765, 0.12617481232155114, 0.5626245285384357, 0.03205908011295833, 0.4271510214312002, 0.9653694892767817, 3.5056705120950937, 3.3711719792336226, 0.7412160735111684, 6.982070244848728, 86.28931894898415, 97.90004432201385, 105.44184923171997, 97.44562670588493, 91.34218901395798, 88.806873857975, 91.25732436776161, 90.10917037725449, 89.48417991399765, 87.1517662703991, 76.54390588402748, 76.54780447483063, 86.27803355455399, 83.01812008023262, 81.73434376716614, 88.41739475727081, 87.57765501737595, 83.51017087697983, 84.46017310023308, 86.32946759462357, 90.49049511551857, 91.3766759634018, 91.1523512005806, 91.4297667145729, 94.00155991315842, 94.22670543193817, 93.28754782676697, 88.27618673443794, 87.4935807287693, 88.62478002905846, 91.88663899898529, 89.83881488442421, 91.56903684139252, 85.87547555565834, 78.9073258638382, 76.59747540950775, 78.76226484775543, 75.90143635869026, 72.55886971950531, 73.93301278352737, 62.91736587882042, 66.01202622056007, 72.67337277531624, 76.65028497576714, 67.54652827978134, 79.73654016852379, 73.07187259197235, 80.86257934570312, 93.74210223555565, 87.76651248335838, 89.10942122340202, 88.93406823277473, 88.78295034170151, 90.34933269023895, 89.72707808017731, 93.32371428608894, 95.2560093998909, 82.02077999711037, 89.27445396780968, 83.1444101035595, 86.77915826439857, 83.19546416401863, 78.72781589627266, 76.23053669929504, 71.88825890421867, 70.90476527810097, 69.9475510418415, 64.77888599038124, 60.57213552296162, 60.15918128192425, 44.2376784235239, 53.44980910420418, 52.777040004730225, 56.643575727939606, 45.80296263098717, 39.61010813713074, 42.692491337656975, 41.075442507863045, 55.114043802022934, 62.44710311293602, 72.39784196019173, 81.96765124797821, 74.59259659051895, 60.87037391960621, 55.22661276161671, 29.280824102461338, 18.129279389977455, 4.901233026757836, 1.2231361982412636, 0.34711380838416517, 0.07774245532345958, 0.20466344518354163, 0.43609241663943976, 0.2950020687421784, 0.018097562387993094, 0.05958534115052316, 0.002714554948397563, 0.4500010656192899, 53.57313148677349, 95.80360561609268, 103.94130975008011, 63.74975301325321, 58.26790116727352, 20.154711306095123, 25.912481546401978, 42.46069237589836, 50.10169096291065, 70.8529968559742, 72.8180918097496, 76.81068956851959, 52.84113496541977, 1.1166910850442946, 0.015253023520926945, 0.19133687746943906, 0.04849351738812402, 0.03668741730507463, 0.10004111347370781, 0.023414360293827485, 0.03836310512269847, 0.029266740202729125, 0.033246690800297074, 0.030692153559357394, 0.0853526008722838, 0.08359737708815373, 0.04112082940991968, 0.0496780444518663, 0.08794258494162932, 0.045936636815895326, 0.0035174993627151707, 0.04330272873630747, 0.009614812588552013, 0.0953744888829533, 0.20956651802407578, 0.1288677248521708, 0.17679563665296882, 0.1511056604795158, 0.2799171453807503, 0.16881248768186197, 0.22125556657556444, 0.13200105750001967, 0.23639045131858438, 0.17207088705617934, 0.19037474237848073, 0.2056144183734432, 0.2869013784220442, 0.1426116467337124, 0.18835647177184, 0.21110181376570836, 0.3485749487299472, 55.50271734595299, 127.32466980814934, 101.9110406935215, 77.47474953532219, 56.29734970629215, 51.41935005784035, 50.764143615961075, 38.2648017257452, 28.728466741740704, 73.98220494389534, 94.51865136623383, 122.63374552130699, 126.55734658241272, 103.37297424674034, 14.10119153559208, 0.7008592702914029, 0.22976126172579825, 0.36260575521737337, 0.27836032735649496, 1.0005202749744058, 0.2041992763406597, 0.5843822204042226, 1.1330080032348633, 3.1133228028193116, 6.462423903867602, 3.2937266724184155, 6.283838236704469, 91.61221012473106, 103.40575128793716, 108.95458593964577, 102.39084854722023, 95.07423475384712, 93.75564470887184, 95.08558094501495, 95.28082966804504, 95.69179281592369, 96.83312237262726, 87.62920305132866, 85.32109290361404, 91.53222441673279, 86.91774442791939, 87.57199332118034, 96.95641055703163, 96.12640589475632, 91.96923896670341, 93.38016405701637, 88.90821442008018, 94.94006395339966, 94.14282113313675, 95.23507252335548, 94.02703374624252, 101.0576368868351, 99.07773032784462, 97.48192235827446, 91.70668825507164, 91.31274819374084, 93.50605890154839, 97.88720861077309, 93.22545155882835, 94.89977091550827, 88.0360472202301, 79.87731501460075, 77.68842726945877, 78.37533161044121, 76.55462130904198, 77.50009417533875, 83.05855751037598, 76.18784219026566, 72.94649451971054, 81.52117520570755, 83.3274082839489, 73.7988343834877, 87.93235838413239, 71.69214382767677, 83.46599444746971, 96.47191375494003, 90.49759313464165, 93.21858912706375, 92.14858174324036, 91.00678861141205, 91.42550334334373, 95.12076705694199, 96.33552387356758, 97.29653030633926, 88.67138832807541, 94.31192725896835, 87.70357266068459, 91.32208049297333, 89.9060408771038, 83.38197335600853, 81.2954293191433, 80.71439489722252, 80.44426739215851, 74.56397652626038, 71.74486979842186, 72.98383131623268, 68.14671367406845, 56.34613148868084, 69.2966839671135, 64.12420392036438, 58.77242669463158, 49.608827009797096, 44.82196927070618, 50.08359633386135, 52.50865660607815, 63.29072244465351, 67.42957055568695, 71.1357244849205, 76.3039867579937, 69.27949368953705, 62.23567485809326, 61.558091416954994, 36.743317767977715, 23.453280106186867, 6.599512472748756, 2.2573907067999244, 0.5440746364183724, 0.3689682763069868, 1.3567872578278184, 1.4287260663695633, 0.41572467831429094, 0.40663152874913067, 0.4294231510721147, 0.5297825939487666, 2.0117754489183426, 67.32990950345993, 103.78767639398575, 115.36706104874611, 77.71508663892746, 93.26300114393234, 93.68508249521255, 46.32018327713013, 33.08289438486099, 47.424126639962196, 70.50631865859032, 81.98928728699684, 86.77817791700363, 77.38089457154274, 3.4628845704719424, 0.2090834837872535, 0.3744591597933322, 0.16687282535713166, 0.18938170425826684, 0.2343808044679463, 0.09629396532545798, 0.2235480904346332, 0.12225227983435616, 0.18405971874017268, 0.19208610523492098, 0.16816661140182987, 0.2114837378030643, 0.19061326864175498, 0.16749765432905406, 0.2509147860109806, 0.181362739240285, 0.15767071367008612, 0.09646238089771941, 0.14830801606876776], [0.010782769350043964, 0.0682169156789314, 0.05691273006959818, 0.03645918834081385, 0.08352623481187038, 0.11714775100699626, 0.07885404411354102, 0.0402438038145192, 0.029538230810430832, 0.11722004361217842, 0.07192088567535393, 0.02563884962000884, 0.08225501005654223, 0.0296980968414573, 0.08856499451212585, 0.026606055434967857, 0.31048840493895113, 4.55394116230309, 73.42291295528412, 82.18517437577248, 74.10911813378334, 84.68249157071114, 98.5350814461708, 115.91868504881859, 115.94020709395409, 61.55459940433502, 56.876598224043846, 65.43938934803009, 94.60271805524826, 106.9752037525177, 77.48193114995956, 3.662879476323724, 0.4450501984683797, 0.16851723165018484, 0.059426714506116696, 0.1439868166926317, 0.16952589940046892, 0.0438588088582037, 0.14591067127184942, 0.7068777910899371, 0.4844100895570591, 4.866914693266153, 3.2630511559545994, 1.213452061638236, 32.63603836297989, 92.50355869531631, 96.79752588272095, 100.99313154816628, 89.5325817167759, 88.75934600830078, 86.90458953380585, 90.27898326516151, 87.94242024421692, 85.27621731162071, 77.43919104337692, 70.4785193502903, 76.72321826219559, 82.6641158759594, 86.66294530034065, 81.36897057294846, 74.23705726861954, 88.91699954867363, 80.74398010969162, 83.79076302051544, 89.05813917517662, 85.82747653126717, 89.88743707537651, 89.05536532402039, 90.83304673433304, 88.29854473471642, 93.21165069937706, 91.4211031794548, 89.16687414050102, 86.2572030723095, 87.12375417351723, 84.5986832678318, 84.6725133061409, 85.37698030471802, 90.1492278277874, 76.23190462589264, 74.6129558980465, 74.72163766622543, 79.36075553297997, 65.78852221369743, 45.97944796085358, 27.59732823818922, 55.74226029217243, 56.62354700267315, 46.92862942814827, 51.10694982111454, 62.00978457927704, 76.55273661017418, 78.85139286518097, 90.27016013860703, 84.85608145594597, 85.11154174804688, 83.18148851394653, 85.24340987205505, 86.2752141058445, 88.5030497610569, 94.40188363194466, 88.82670879364014, 80.83139821887016, 81.62700712680817, 77.7885214984417, 77.39848762750626, 78.50967720150948, 81.92472875118256, 79.25364688038826, 74.21594560146332, 66.48999497294426, 61.937527656555176, 64.4515335559845, 60.56331239640713, 52.77421295642853, 47.82411217689514, 38.523947820067406, 43.238696828484535, 49.04882825911045, 36.38588234782219, 20.333430916070938, 23.842677511274815, 18.94148200750351, 27.49590028077364, 40.89380465447903, 56.22138798236847, 67.23046883940697, 74.22611385583878, 49.562469497323036, 40.76681166887283, 21.99129905551672, 12.229272332042456, 10.96958102658391, 1.5112376888282597, 0.9321620617993176, 0.14754780451767147, 0.31714846787508577, 0.33341364352963865, 0.820266081718728, 0.08558441812056117, 0.08287605407531373, 0.11922092569875531, 0.0485616650985321, 1.2067907815799117, 42.9286752641201, 83.5021761059761, 97.8576309978962, 49.225978553295135, 63.72087076306343, 64.0039935708046, 36.39271058142185, 43.10174837708473, 33.26453223824501, 47.927360236644745, 58.27038623392582, 60.28018958866596, 33.76526556909084, 1.5318553824909031, 0.07892561683547683, 0.14235395821742713, 0.025157398013107013, 0.030386427679331973, 0.07230063522001728, 0.03210642171325162, 0.014502147259918274, 0.05991154845105484, 0.09424422765732743, 0.1912731269840151, 0.030461815040325746, 0.030948201929277275, 0.043624134341371246, 0.03184276261890773, 0.010711431332310895, 0.017351058304484468, 0.03200940445822198, 0.06041079861461185, 0.04270867291779723, 0.039487136018578894, 0.01946004162164172, 0.047919944845489226, 0.028725786905852146, 0.19969878892879933, 0.04349286697106436, 0.03171844546159264, 0.043529985487111844, 0.04286254239559639, 0.10574786545475945, 0.012728140645776875, 0.10085286718094721, 0.030430791412072722, 0.1219235900498461, 0.12498296768171713, 0.33219972741790116, 6.477326704189181, 90.67239135503769, 93.1122936308384, 89.01495069265366, 91.93559557199478, 97.78456851840019, 99.87012460827827, 82.34130039811134, 21.905216574668884, 36.885255351662636, 66.80496767163277, 99.27867874503136, 117.52164423465729, 87.08781570196152, 3.897567708045244, 0.391397611820139, 0.09657363625592552, 0.06064218170649838, 0.2069341202150099, 0.11904594211955555, 0.1318099396303296, 0.33244813908822834, 3.622205746360123, 4.566955463960767, 5.464543299749494, 1.3980643241666257, 1.2171713495627046, 39.26368072628975, 105.81621274352074, 101.44993543624878, 107.16029942035675, 94.26796361804008, 93.57482761144638, 93.70750889182091, 95.34945398569107, 92.71488055586815, 92.3485042154789, 84.66610684990883, 84.79135572910309, 88.7826007604599, 86.98554039001465, 89.55078274011612, 89.89339515566826, 79.66186657547951, 91.02843225002289, 87.77405887842178, 85.96085697412491, 92.24496737122536, 88.83031100034714, 92.51112028956413, 90.48535019159317, 90.33484026789665, 87.46933802962303, 93.69903534650803, 92.53680691123009, 91.74986153841019, 91.88094690442085, 89.65222969651222, 85.92352777719498, 87.50731319189072, 89.72194075584412, 94.00247946381569, 80.68194463849068, 76.1566686630249, 73.60750705003738, 82.98296436667442, 71.91719815135002, 48.25792349874973, 30.057886205613613, 63.0920235067606, 65.18822282552719, 46.00332967936993, 57.64468140900135, 62.752245739102364, 74.91613402962685, 77.86532297730446, 90.78699320554733, 87.9324571788311, 86.48328334093094, 84.40693035721779, 85.21222874522209, 86.0153080523014, 92.4860568344593, 93.47942993044853, 87.84845128655434, 83.16713288426399, 85.721006244421, 84.29533034563065, 81.8701408803463, 82.1775671839714, 82.59777143597603, 83.58592361211777, 77.47654303908348, 73.17578941583633, 66.89772069454193, 65.66439047455788, 66.56776160001755, 58.20331983268261, 56.727406829595566, 49.58955064415932, 52.59051561355591, 54.25256162881851, 57.49843865633011, 44.73960109055042, 49.191734790802, 44.001323506236076, 39.72546234726906, 50.47187089920044, 60.88618867099285, 70.48335269093513, 84.07710805535316, 75.02267271280289, 59.83967162668705, 49.35401648283005, 27.76245977729559, 17.09255062043667, 4.1954536736011505, 1.283465086016804, 0.24115359963616356, 0.3444580774521455, 0.5662745889276266, 0.16136660909978673, 0.09809511320781894, 0.17682840989436954, 0.07832383897039108, 0.1975458482047543, 0.6970961065962911, 53.52215342223644, 95.34357950091362, 105.29196247458458, 58.01869913935661, 60.168175399303436, 24.029589481651783, 33.80954459309578, 62.09767006337643, 50.498211085796356, 68.93630370497704, 68.02874520421028, 72.39091873168945, 49.8934431374073, 0.9853832528460771, 0.08040799002628773, 0.1121121751202736, 0.04122098966035992, 0.02262919588247314, 0.04130451095988974, 0.06450651868362911, 0.08525368742994033, 0.011812165284936782, 0.03327970152895432, 0.024855830015440006, 0.07430105717503466, 0.032825978414621204, 0.01389265940815676, 0.0049968130497290986, 0.0409588853653986, 0.008808708480501082, 0.049674471010803245, 0.1811854846891947, 0.14762789709493518, 0.17347108223475516, 0.13071509369183332, 0.17102055513532832, 0.2650661766529083, 0.42062994791194797, 0.1613405894022435, 0.10018818487878889, 0.11635865506832488, 0.21234047308098525, 0.19961108191637322, 0.08805520585156046, 0.231850971467793, 0.34700729534961283, 0.3592897206544876, 0.22636813286226243, 0.5671249714214355, 10.095942355692387, 108.87684971094131, 104.98630687594414, 97.8512853384018, 107.37352877855301, 122.80581548810005, 135.17628729343414, 137.82489717006683, 84.4589951634407, 77.73894935846329, 91.4253817498684, 112.4620409309864, 128.08057844638824, 101.01670548319817, 6.207421962171793, 0.8133274165447801, 0.40079875267110765, 0.13985992642119527, 0.9493548923637718, 0.2140366515959613, 0.7652266882359982, 0.42260358575731516, 3.847306380048394, 3.642167975194752, 12.202218733727932, 7.618542267009616, 1.575670475140214, 42.490896955132484, 110.06783500313759, 103.71589824557304, 108.39728504419327, 95.2229131758213, 97.61216416954994, 98.975500613451, 102.12933138012886, 96.95454865694046, 96.73138663172722, 91.90218016505241, 88.13117131590843, 91.71795845031738, 95.85632398724556, 95.914156883955, 94.6365438401699, 87.5766670703888, 97.61274173855782, 91.12351074814796, 94.02038410305977, 99.93199288845062, 97.84516766667366, 99.01726797223091, 93.36719915270805, 94.88112151622772, 93.45700353384018, 98.98126870393753, 98.12705174088478, 94.52991396188736, 99.03356149792671, 93.78457635641098, 93.07083025574684, 92.229562997818, 92.10155546665192, 95.31774088740349, 82.42022976279259, 76.83352634310722, 75.00540643930435, 81.6725666821003, 75.50682753324509, 59.45678137242794, 44.11879800260067, 66.09876036643982, 71.50871247053146, 64.41978245973587, 65.30642688274384, 69.84495654702187, 75.46110078692436, 81.60217925906181, 95.2737544476986, 91.02676793932915, 90.85276767611504, 88.55024322867393, 88.49965274333954, 87.03312143683434, 94.04249131679535, 98.10420736670494, 97.88320362567902, 89.75976392626762, 92.15752646327019, 85.85661336779594, 85.13481169939041, 86.01211622357368, 85.06035849452019, 85.46788662672043, 82.35279098153114, 79.64480549097061, 72.67741575837135, 72.21281468868256, 73.46381396055222, 68.05326908826828, 64.76806417107582, 61.174000427126884, 68.80939811468124, 64.19223546981812, 55.78196436166763, 45.949972942471504, 54.88392435014248, 48.02724547684193, 52.616061642766, 62.494794353842735, 71.3739413022995, 70.74836567044258, 76.64513245224953, 72.8735688328743, 62.625986114144325, 54.1524787992239, 34.830158427357674, 21.172579787671566, 7.15940672904253, 3.8252193527296185, 1.0011428478173912, 0.35838453797623515, 0.933535925578326, 1.7229831079021096, 0.22941738017834723, 0.2602298080455512, 0.3207562555326149, 0.3764788404805586, 2.952903723344207, 72.8476694226265, 100.17013370990753, 118.4618429839611, 69.66328829526901, 101.46678373217583, 91.0149809718132, 50.82601949572563, 60.583694502711296, 46.582821384072304, 66.06187954545021, 79.01380375027657, 83.5250660777092, 71.92834675312042, 3.191123865544796, 0.10474736132891849, 0.2652586007025093, 0.1340654303203337, 0.1399468319141306, 0.3264973615296185, 0.1486895393463783, 0.12661348097026348, 0.1478528420557268, 0.15524927875958383, 0.2868963615037501, 0.236372921790462, 0.17479586036643013, 0.28836652636528015, 0.1010899017273914, 0.12850466620875522, 0.08657808706630021, 0.17526388837723061, 0.41902405908331275], [0.0892399629810825, 0.050016022214549594, 0.08318627180415206, 0.03635614113591146, 0.09977939509553835, 0.09408460653503425, 0.11673567350953817, 0.05564728664467111, 0.03175923389790114, 0.06168833904666826, 0.22354227199684829, 0.031258840826922096, 0.09901121287839487, 0.04783468320965767, 0.23481479758629575, 0.025962208928831387, 0.07008295695413835, 19.855688251554966, 87.04147338867188, 78.20136174559593, 72.00200960040092, 66.13056465983391, 35.36038197577, 32.926734164357185, 70.93799069523811, 101.81745171546936, 91.33639052510262, 104.83880639076233, 117.0091125369072, 79.71712321043015, 3.170523983426392, 0.43155756779015064, 0.03249753724958282, 0.15880421065958217, 0.10521265081479214, 0.13937408686615527, 0.039216686272993684, 0.23661677667405456, 0.16330085374647751, 0.12395579076837748, 1.7141146212816238, 3.2489023776724935, 0.9369021293241531, 3.420925559476018, 75.66854685544968, 97.00862735509872, 100.20892962813377, 97.17226937413216, 99.33477133512497, 92.63790428638458, 94.80922937393188, 92.23795294761658, 87.72447153925896, 89.13190081715584, 83.49957704544067, 89.1286937892437, 87.87476107478142, 84.76240128278732, 80.199264138937, 89.69168677926064, 78.92702400684357, 78.01891833543777, 92.39171549677849, 77.46590360999107, 84.07758682966232, 83.75962749123573, 87.9929119348526, 83.24367597699165, 85.23149371147156, 85.5682772397995, 92.5635726749897, 88.41273620724678, 88.99823918938637, 83.40516731142998, 85.52289247512817, 80.26629254221916, 87.58563458919525, 86.3493025302887, 90.28907552361488, 86.6835705935955, 77.77040407061577, 73.55296477675438, 74.4743849337101, 68.39084297418594, 43.981933146715164, 28.920141756534576, 78.06776851415634, 58.8945559412241, 24.15764831006527, 26.135134398937225, 49.82678711414337, 72.06508621573448, 79.00919079780579, 82.95025572180748, 77.85843014717102, 80.83326771855354, 81.40693813562393, 80.46995401382446, 85.34442365169525, 85.10484650731087, 77.8147704899311, 80.40499269962311, 79.34700027108192, 82.64786034822464, 81.83853417634964, 80.16272529959679, 75.05934834480286, 76.74442872405052, 77.77313992381096, 82.56230413913727, 77.20254734158516, 71.37112945318222, 65.10677799582481, 66.83367133140564, 56.061747148633, 58.86503912508488, 55.21735645830631, 46.049728989601135, 47.622434198856354, 53.823823034763336, 35.88868282735348, 30.90253908187151, 29.57729559391737, 21.417793929576874, 30.705711543560028, 38.78532439470291, 58.02681930363178, 82.40277349948883, 68.78333151340485, 47.491937801241875, 38.867563381791115, 18.713207356631756, 12.626099288463593, 8.34742533043027, 1.208014078438282, 0.8805445628240705, 1.0263774124905467, 1.3781296438537538, 0.17719476367346942, 0.172589692811016, 0.07845787826227024, 0.1233206459437497, 0.1393203850602731, 0.23327222879743204, 1.6837918921373785, 51.40660174190998, 85.21416664123535, 91.71773046255112, 43.085956424474716, 54.83155556023121, 71.21040567755699, 27.03620094805956, 36.791757568717, 43.41738224029541, 55.61090134084225, 57.2219692915678, 61.80404841899872, 32.61862009763718, 2.3525962606072426, 0.003864788759528892, 0.1189572925795801, 0.050556016285554506, 0.17721748823532835, 0.029583941541204695, 0.051580410145106725, 0.04929463982989546, 0.062120313523337245, 0.028423515723261517, 0.10443302468047477, 0.05413074868556578, 0.07316389397601597, 0.09694989028503187, 0.031357542757177725, 0.03893979468557518, 0.04788751670275815, 0.010185396131419111, 0.03221099774236791, 0.047079963551368564, 0.10227982420474291, 0.08197299393941648, 0.020360468988656066, 0.02725268499489175, 0.06437339965486899, 0.06239668189664371, 0.05183968685742002, 0.07040357959340326, 0.2427027141675353, 0.10632540477672592, 0.08967933667008765, 0.0618010490143206, 0.08075127785559744, 0.07047625811537728, 0.06613209669012576, 29.27008207887411, 99.7939082980156, 92.23175927996635, 95.84703728556633, 89.42148327827454, 71.24810725450516, 60.846917778253555, 54.9274206161499, 75.72845444083214, 96.76568359136581, 111.30808845162392, 124.58473563194275, 89.75629851222038, 3.6351640010252595, 0.4575422656489536, 0.10367172217229381, 0.7017462851945311, 0.10817719681654125, 0.21918254031334072, 0.05708067437808495, 0.20164662972092628, 1.0476998495869339, 2.1967293368652463, 4.0966765489429235, 1.4616643614135683, 0.7801564433611929, 3.905033594928682, 88.16394075751305, 102.84674808382988, 103.58662158250809, 99.97560694813728, 104.33968797326088, 98.4933976829052, 99.08539831638336, 97.9062607884407, 94.81787011027336, 95.59176698327065, 92.32334196567535, 94.45721626281738, 91.5346410870552, 89.20463651418686, 86.0791902244091, 93.30710917711258, 87.05785050988197, 81.27776026725769, 94.59487527608871, 81.89594149589539, 89.03786346316338, 90.07780686020851, 90.88293805718422, 83.95024806261063, 88.52669969201088, 88.2940685749054, 90.54807722568512, 92.31071904301643, 90.45340150594711, 87.78602823615074, 88.32723319530487, 83.68977963924408, 90.45462504029274, 87.88324221968651, 91.71386986970901, 88.32494571805, 81.11439943313599, 74.16870653629303, 76.9705317914486, 72.0846551656723, 54.010324627161026, 38.62066403031349, 79.29574862122536, 63.32200236618519, 30.375710651278496, 28.55462606996298, 50.18441632390022, 71.5805134177208, 78.88815969228745, 84.25433814525604, 80.39134383201599, 82.62461319565773, 84.12545666098595, 83.7418520450592, 85.75716510415077, 86.9805246591568, 82.91843622922897, 81.23930633068085, 85.23517951369286, 84.87056627869606, 87.54543274641037, 86.24373659491539, 83.84180188179016, 81.12123906612396, 78.6517059803009, 82.96861633658409, 79.67216402292252, 76.75260588526726, 67.89891377091408, 69.66433703899384, 65.95043152570724, 64.45703566074371, 62.24911853671074, 55.96876993775368, 53.802023604512215, 58.9051079750061, 56.901627480983734, 50.342579036951065, 57.41618826985359, 43.664425984025, 45.2171366661787, 51.28595821559429, 61.772035136818886, 79.56876397132874, 90.14901503920555, 72.49809578061104, 59.19826604425907, 48.22485387325287, 24.82276652008295, 13.48136119544506, 2.8565853042528033, 0.673069164622575, 2.0311183109879494, 1.639192735310644, 0.14994464465416968, 0.5172657687216997, 0.14146912522846833, 0.019712008179340046, 0.1707646923023276, 0.3245903388597071, 0.8122558740433306, 64.81277257204056, 95.25286316871643, 98.81695792078972, 54.83456499874592, 55.54874807596207, 28.536255955696106, 34.052879735827446, 56.893465518951416, 57.47076854109764, 73.9703419804573, 69.2060436308384, 75.46247631311417, 45.678507909178734, 1.7498607281595469, 0.07730517449090257, 0.09873034709016792, 0.04867877971264534, 0.07420638139592484, 0.06876694358652458, 0.012937436495121801, 0.040735869988566265, 0.04460255957383197, 0.07749077820335515, 0.07260806989506818, 0.06376267891027965, 0.042328648778493516, 0.05725961731513962, 0.009451208916289033, 0.08695452663232572, 0.02809553283441346, 0.02775909502815921, 0.17663079081103206, 0.22890409600222483, 0.2478697689366527, 0.24609559070086107, 0.17350582958897576, 0.3596219059545547, 0.2709095209138468, 0.2125588574563153, 0.20318905008025467, 0.11839046987006441, 0.35555630223825574, 0.24155933177098632, 0.29717584897298366, 0.18393788777757436, 0.4579769860720262, 0.17223738046595827, 0.2469040863798, 40.26636332273483, 120.02453193068504, 99.47666332125664, 91.81818947196007, 85.95920786261559, 46.03184334933758, 46.730538457632065, 89.76779669523239, 132.9459285736084, 115.11066600680351, 118.01862716674805, 135.9274309873581, 104.53225404024124, 5.386983761563897, 0.9133992029819638, 0.17026846267981455, 0.6843160267453641, 0.3300814895192161, 0.32293754629790783, 0.19127894542180002, 0.6451259390451014, 1.286225994117558, 2.6809736900031567, 5.107727246358991, 9.564966447651386, 2.396314814686775, 3.637958038598299, 91.01264789700508, 101.20122358202934, 108.26249107718468, 102.17030838131905, 107.92433962225914, 101.62554681301117, 102.13538825511932, 99.64975163340569, 96.79134741425514, 96.9509008526802, 95.72212278842926, 97.88798376917839, 101.05910360813141, 93.40077415108681, 94.16745141148567, 98.87416765093803, 91.82686820626259, 87.67464101314545, 103.87366577982903, 89.07751813530922, 94.17689010500908, 92.60520324110985, 98.54157149791718, 88.37660014629364, 92.28143021464348, 94.96983155608177, 99.0776315331459, 95.2951928973198, 96.48686215281487, 92.38967880606651, 93.92250135540962, 88.46234634518623, 94.86608192324638, 90.33123046159744, 94.80491280555725, 91.26346483826637, 83.46578165888786, 74.94613721966743, 77.7403324842453, 73.19139137864113, 54.6001023799181, 40.01346409320831, 81.69363275170326, 67.67141997814178, 34.82485771179199, 43.74197602272034, 60.19930712878704, 72.94146358966827, 82.15482920408249, 88.82391974329948, 85.41504666209221, 85.31826585531235, 86.78769260644913, 86.06120198965073, 87.92820900678635, 89.29551243782043, 85.83322942256927, 84.87473845481873, 85.32522708177567, 88.92037376761436, 91.91356435418129, 89.31773364543915, 86.36957064270973, 83.73856142163277, 81.86702504754066, 85.8293080329895, 83.15900892019272, 82.99719080328941, 73.59843313694, 76.84658244252205, 72.06423506140709, 71.64822578430176, 69.7496348619461, 64.50431272387505, 67.03570649027824, 69.81259748339653, 57.48290129005909, 51.80514715611935, 56.833291947841644, 49.16203938424587, 60.61511501669884, 63.39725352823734, 72.15537697076797, 77.73834139108658, 77.2453710436821, 70.3908808529377, 59.8872184753418, 54.28089290857315, 30.534050054848194, 16.681957952678204, 6.103332722559571, 4.8451827093958855, 3.3274356136098504, 2.1166733326390386, 0.5384330078959465, 0.8081250207033008, 0.2198957442305982, 0.13376150600379333, 0.2876676607411355, 0.4826755420072004, 5.576762678101659, 88.25687617063522, 93.64336833357811, 115.61305224895477, 62.18567714095116, 91.52652472257614, 99.3232199549675, 38.32986183464527, 47.89723165333271, 56.98434144258499, 73.62976625561714, 82.05411940813065, 85.64213767647743, 67.99341470003128, 2.4129871325567365, 0.16523962549399585, 0.18962216010550037, 0.18632994848303497, 0.2921275229891762, 0.10680180421331897, 0.16943406604696065, 0.20068173384061083, 0.13808674266329035, 0.17405123391654342, 0.2716323727509007, 0.24450181372230873, 0.237046925467439, 0.23686414933763444, 0.1483320616534911, 0.19548025826225057, 0.18247204221552238, 0.1553150627296418], [0.061945697307237424, 0.127174811786972, 0.07873173075495288, 0.07062490287353285, 0.07513715332606807, 0.09324033191660419, 0.08772690198384225, 0.12400855746818706, 0.040629627837915905, 0.027209117215534206, 0.02280319054989377, 0.13969698047731072, 0.13736736407736316, 0.08656042395159602, 0.09050038206623867, 0.24920692609157413, 0.06213131215190515, 44.42773662507534, 89.28298071026802, 62.37763524055481, 70.1537811756134, 47.99066483974457, 35.66586658358574, 43.40995363891125, 49.64291878044605, 55.367706790566444, 99.26333516836166, 103.33991602063179, 84.53377515077591, 6.924210749566555, 0.48197456868365407, 0.12149783477070741, 0.32419795054011047, 0.16055380896432325, 0.23956115852342919, 0.11181234003743157, 0.06443323160056025, 0.08489444342558272, 0.24670351354870945, 2.044396223500371, 8.388067949563265, 1.4754411159083247, 0.9566740714944899, 25.836004950106144, 90.76751545071602, 97.38450318574905, 101.69119209051132, 92.98595041036606, 98.26031059026718, 91.4931321144104, 100.72418197989464, 97.38173693418503, 91.81302934885025, 86.34585991501808, 86.04911863803864, 83.65739017724991, 90.13682529330254, 79.11528870463371, 86.26896724104881, 82.92527586221695, 86.02538511157036, 74.18476447463036, 84.41758498549461, 84.76651266217232, 84.62994799017906, 84.15704056620598, 80.72523191571236, 82.54328235983849, 83.2236510515213, 82.75864720344543, 86.30903989076614, 90.86336150765419, 88.19736376404762, 84.91018295288086, 88.88150185346603, 86.28380924463272, 85.8047841489315, 80.00048160552979, 79.84713703393936, 78.278938382864, 74.68606397509575, 73.91608089208603, 74.6136474609375, 69.02162432670593, 70.74093326926231, 76.05181708931923, 75.21975293755531, 48.533275723457336, 64.28960904479027, 23.09484723955393, 40.74463985860348, 72.41140723228455, 75.86455553770065, 79.6293631196022, 77.25588127970695, 80.75539469718933, 84.65103685855865, 82.86953285336494, 79.38056766986847, 79.00146201252937, 79.8921038210392, 84.18025732040405, 86.48068428039551, 86.18592649698257, 85.6527391076088, 80.74153304100037, 81.26063078641891, 76.91223531961441, 77.10375264286995, 75.41054829955101, 81.71794384717941, 76.51688173413277, 73.85263949632645, 70.27493387460709, 66.83861866593361, 55.19752912223339, 59.3829133361578, 62.789650931954384, 53.025892451405525, 45.150636434555054, 47.848598062992096, 39.94046241044998, 40.84009453654289, 32.268700674176216, 29.919581227004528, 29.850356541574, 39.78927232325077, 60.09752199053764, 93.09428259730339, 72.3092383146286, 45.17622046172619, 39.83939163386822, 15.94524398446083, 16.088661588728428, 5.892287772148848, 0.7732982863672078, 0.17801587586291134, 0.08535387736628763, 0.5302250920794904, 0.045540136998170055, 0.5660530726891011, 0.0545235414756462, 0.0341312974342145, 0.13093715911963955, 0.4562485538190231, 5.194566361606121, 69.94432881474495, 76.664397418499, 92.75613114237785, 55.626951679587364, 70.6997586786747, 64.77943316102028, 27.72361446171999, 30.67318718880415, 27.38672833889723, 51.64205990731716, 56.06248050928116, 51.38885669410229, 32.59290687739849, 1.1343794921413064, 0.032199769048020244, 0.07449034936144017, 0.06455675465986133, 0.04970998277713079, 0.019307888360344805, 0.05183874804060906, 0.02424469552352093, 0.013334287905308884, 0.06126357082393952, 0.09158176544588059, 0.0300234358292073, 0.036892513526254334, 0.023784532422723714, 0.10110717892530374, 0.012151711762271589, 0.04831929079955444, 0.009948021124728257, 0.06855566898593679, 0.018671262951102108, 0.07087854668498039, 0.06358810351230204, 0.09512806616839953, 0.0638809624069836, 0.10009076315327547, 0.0435556897718925, 0.05675259686540812, 0.07128162935259752, 0.00909262171262526, 0.06098728779761586, 0.028397347596182954, 0.15420233103213832, 0.05330654174031224, 0.1558009468135424, 57.02183023095131, 100.50909072160721, 75.57048931717873, 74.24497604370117, 59.76960338652134, 55.36367520689964, 19.794055558741093, 27.37857587635517, 70.0690533220768, 108.99471938610077, 113.5605239868164, 95.24596273899078, 10.334640797227621, 0.5307631788309664, 0.14741711231181398, 0.17814134334912524, 0.12246333179064095, 0.46796762966550887, 0.0551921237638453, 0.32247272436507046, 0.11980500334175304, 1.592766351532191, 1.198729989118874, 4.673983845859766, 1.7647535540163517, 0.8297848084475845, 32.47084602713585, 98.09076368808746, 96.18959650397301, 101.31114408373833, 99.14942488074303, 101.90051525831223, 97.69528090953827, 104.73932772874832, 100.25710344314575, 96.76306933164597, 89.49938669800758, 91.03076532483101, 88.17292347550392, 93.12937751412392, 81.90894439816475, 89.99382376670837, 85.9978137910366, 90.67585676908493, 85.09717091917992, 85.80285385251045, 86.52957245707512, 82.73625120520592, 86.47730246186256, 84.22941908240318, 85.79197123646736, 86.84585988521576, 86.90529629588127, 85.51722317934036, 89.74831894040108, 92.87894815206528, 91.44652381539345, 91.92731201648712, 90.14043509960175, 88.12791109085083, 82.34764605760574, 80.13038903474808, 76.90955266356468, 75.16965642571449, 75.59663951396942, 77.72400856018066, 70.73806822299957, 74.9503929913044, 76.59876734018326, 76.40820756554604, 56.1685898154974, 72.21254870295525, 33.82845997810364, 47.857858166098595, 73.94441977143288, 78.76383036375046, 81.18435367941856, 79.75124537944794, 87.0682543516159, 86.5298992395401, 86.50655329227448, 81.18450567126274, 82.75430023670197, 82.22196400165558, 84.607605189085, 84.50882568955421, 86.30579486489296, 83.1513561308384, 86.58367395401001, 84.29248049855232, 83.52142587304115, 79.34263810515404, 76.50017023086548, 80.44693484902382, 78.41583743691444, 77.29965493083, 72.62178674340248, 70.33013731241226, 64.56413671374321, 62.441354021430016, 66.35707810521126, 59.74067933857441, 53.111387863755226, 55.50580658018589, 57.74916060268879, 57.601158544421196, 57.25131891667843, 47.692760825157166, 46.5771596878767, 49.21987608075142, 58.745182156562805, 78.2929976284504, 92.04180747270584, 74.2768107354641, 61.68693110346794, 44.66919466853142, 26.716626696288586, 10.49035644158721, 0.6106445705518126, 0.3051903611049056, 0.03036440259165829, 0.11880846970598213, 0.08637185906991363, 0.7769887789618224, 0.19486313278321177, 0.05954726897471119, 0.10627617069985718, 0.6904061499517411, 7.259345166385174, 83.64063307642937, 86.17595583200455, 100.48597276210785, 70.13382464647293, 54.73658725619316, 28.602830283343792, 38.2141238451004, 46.47838018834591, 44.5509298145771, 73.28727543354034, 67.05046489834785, 65.2365106344223, 43.84860210120678, 0.6631511030718684, 0.04176402653683908, 0.050795191928045824, 0.08926967115257867, 0.02018092305661412, 0.02315816906047985, 0.010145017731701955, 0.0438092779222643, 0.02107392152538523, 0.028724399089696817, 0.07462130874046125, 0.06096641860494856, 0.08663674641866237, 0.06938806182006374, 0.05781463987659663, 0.07598720185342245, 0.10925103997578844, 0.10777122719446197, 0.22180674481205642, 0.20998045831220224, 0.21562199777690694, 0.19733350491151214, 0.2064249772229232, 0.33523873309604824, 0.20603429584298283, 0.2171599949360825, 0.15324746898841113, 0.20615867979358882, 0.2410506785963662, 0.27135433454532176, 0.19313671917188913, 0.23701884259935468, 0.27813272550702095, 0.47564725507982075, 73.76763045787811, 116.557886749506, 80.19404321908951, 86.69251531362534, 64.21096846461296, 53.550693690776825, 63.14125366508961, 75.66122084856033, 77.66759678721428, 119.24194112420082, 123.47049102187157, 113.43807935714722, 14.435902275145054, 0.7397364091593772, 0.6487940484657884, 0.520395910134539, 0.5039126321207732, 0.6610195362009108, 0.30247089453041553, 0.42562952963635325, 0.4006846103584394, 2.8188585536554456, 7.533740317448974, 19.147814735770226, 8.179591186344624, 2.1362622315064073, 38.225367441773415, 111.42842799425125, 104.45034563541412, 108.99338185787201, 103.60837921500206, 106.78641468286514, 98.24052885174751, 105.1046173274517, 100.61408668756485, 99.91892158985138, 95.76464250683784, 96.56522154808044, 92.5604796409607, 99.43505555391312, 88.38478490710258, 97.25588008761406, 93.24131950736046, 96.87578648328781, 89.70079109072685, 91.87818065285683, 92.47565299272537, 90.61212658882141, 93.93162086606026, 92.00517743825912, 89.76237818598747, 91.95897951722145, 90.5142742395401, 93.19205895066261, 97.30215400457382, 97.85511553287506, 95.15749588608742, 97.65233561396599, 92.56988033652306, 95.57876408100128, 85.46350166201591, 81.67712643742561, 79.58419874310493, 77.69212827086449, 77.04710528254509, 77.67546236515045, 71.99085339903831, 75.84456101059914, 75.02787843346596, 85.0474239885807, 59.64431270956993, 64.47062373161316, 31.042757257819176, 49.83755573630333, 73.46955925226212, 79.96886730194092, 82.3458905518055, 82.51923725008965, 87.80132621526718, 90.72859793901443, 88.22437271475792, 86.0231964290142, 86.38754367828369, 83.41918095946312, 88.06559443473816, 90.35959213972092, 93.85702326893806, 90.16153916716576, 89.07397672533989, 84.64796662330627, 84.41145971417427, 81.00178867578506, 82.80923768877983, 89.60371389985085, 83.98125439882278, 83.41371685266495, 76.42307996749878, 75.74871495366096, 68.88385891914368, 69.7799800336361, 73.23273316025734, 64.87268015742302, 65.65795361995697, 68.23641926050186, 60.85898973047733, 56.686828806996346, 56.0496523976326, 52.66189098358154, 56.01619899272919, 60.07044464349747, 69.633779078722, 77.86883398890495, 79.32807728648186, 72.14472234249115, 64.74322110414505, 49.61004674434662, 34.336374923586845, 12.485674973577261, 2.214994481764734, 0.5768256133887917, 0.33740811981260777, 0.46361751621589065, 0.15163766162004322, 2.4732207879424095, 0.2270742121618241, 0.1667515584267676, 0.2498164668213576, 1.624075840227306, 17.246729247272015, 100.81625863909721, 88.13718259334564, 118.94546583294868, 78.69956061244011, 113.22018384933472, 89.66039165854454, 40.39221256971359, 41.021865382790565, 41.16269342601299, 72.2232261300087, 79.15121957659721, 77.12801054120064, 63.67229416966438, 2.01627844478935, 0.2135086283669807, 0.24725878844037652, 0.15042070270283148, 0.13081945449812338, 0.09837329242145643, 0.1316439954098314, 0.11273656622506678, 0.10875198277062736, 0.14951850345823914, 0.19205728021916002, 0.12350899560260586, 0.2505822741659358, 0.12214456452056766, 0.27752380818128586, 0.17617389501538128, 0.24428581906249747], [0.09967055171728134, 0.06177489573019557, 0.05682790630089585, 0.17103480437071994, 0.08478537740302272, 0.0907135491434019, 0.09769951881025918, 0.12319828805630095, 0.07814397205947898, 0.02007409460929921, 0.027182488956896123, 0.06308423719019629, 0.05564417704590596, 0.15087598061654717, 0.023381243809126318, 0.0637063647445757, 4.4103962648659945, 60.50615206360817, 73.29685091972351, 69.71053496003151, 89.75820600986481, 64.21891003847122, 60.84660239517689, 79.54870864748955, 55.06448686122894, 89.54990118741989, 108.0594451725483, 94.05225679278374, 18.18973984569311, 0.6049343082122505, 0.12487728585256264, 0.4705541330622509, 0.09883709019050002, 0.5680954037234187, 1.0973175871185958, 0.19070259353611618, 0.0850599943078123, 0.23450021602911875, 0.9294579725246876, 2.973428559489548, 4.4057966116815805, 1.4801990543492138, 1.6718930681236088, 63.56405697762966, 77.42757886648178, 85.98994821310043, 82.62968212366104, 76.04186162352562, 101.3829830288887, 95.85972100496292, 94.56900626420975, 87.94649362564087, 89.34196874499321, 86.5414810180664, 82.32640519738197, 84.21651497483253, 85.88494464755058, 80.82550093531609, 81.99520736932755, 83.50378721952438, 87.27088987827301, 79.72337007522583, 73.73811364173889, 85.94936639070511, 77.93852224946022, 80.00749602913857, 87.81166166067123, 86.2631231546402, 83.60179156064987, 86.04636758565903, 84.27838325500488, 88.30730706453323, 90.48401266336441, 90.62037214636803, 88.68110060691833, 87.61249914765358, 79.83433932065964, 79.92661356925964, 75.51632702350616, 77.11120784282684, 80.4156169295311, 79.18911874294281, 81.82278782129288, 73.78924369812012, 72.6687142252922, 62.977284863591194, 51.572542637586594, 65.46124577522278, 79.52231526374817, 72.68387541174889, 63.18456374108791, 65.8004155755043, 79.24891233444214, 82.87058919668198, 79.86099109053612, 75.21518558263779, 75.52290067076683, 81.62053227424622, 77.37109109759331, 73.59133511781693, 77.54185393452644, 79.26161125302315, 77.47316882014275, 79.762963950634, 78.50531503558159, 83.17536324262619, 78.18601056933403, 76.2157478928566, 80.41997149586678, 75.4668840765953, 72.50214636325836, 78.15139442682266, 74.06589925289154, 71.3347502052784, 67.39982575178146, 69.96571406722069, 58.4235218167305, 60.149985775351524, 61.5064711868763, 53.488643020391464, 46.74416072666645, 47.997401878237724, 44.108941331505775, 42.48268559575081, 34.835820123553276, 29.70925111323595, 32.424708902835846, 38.47100146114826, 51.2011543661356, 102.006825953722, 80.63399121165276, 49.092092737555504, 36.60686329007149, 19.83114156872034, 19.353020824491978, 2.465496277436614, 0.16015388042433187, 0.18921880284324288, 0.1784435161971487, 0.36082635226193815, 0.0995099064311944, 0.15088390675373375, 0.45017659838777035, 0.04898083381704055, 0.2059797925176099, 3.115244787186384, 15.842736884951591, 66.78039819002151, 66.98623314499855, 84.32303085923195, 55.865924656391144, 61.179574728012085, 63.226669281721115, 30.39139810949564, 38.31813186407089, 33.52312356233597, 58.15564379096031, 64.25064593553543, 67.39047065377235, 36.61588400602341, 2.4249762017279863, 0.06527196237584576, 0.04417232543346472, 0.07930873573059216, 0.05238674617430661, 0.06591607234440744, 0.020857516828982625, 0.010964766224788036, 0.06866808951599523, 0.03535702853696421, 0.039776395497028716, 0.10070081596495584, 0.10204428137512878, 0.04899061532341875, 0.04903194923826959, 0.04064726126671303, 0.01159742207164527, 0.03538732671586331, 0.06159507334814407, 0.07600934754009359, 0.037880727686570026, 0.03387982440472115, 0.05149929711478762, 0.09486462600762025, 0.17626736109377816, 0.0316914090217324, 0.024043540106504224, 0.07156914478400722, 0.023752976303512696, 0.1591720784199424, 0.07969379163114354, 0.2582494611851871, 4.886171109974384, 74.03478652238846, 82.86867409944534, 79.87885773181915, 94.5454703271389, 72.19428688287735, 31.541241109371185, 56.23936101794243, 63.58703814446926, 100.30436530709267, 117.84258261322975, 110.39125844836235, 24.46476873010397, 0.6720577063970268, 0.02912053525506053, 0.4800057993270457, 0.05765075511590112, 1.02849354268983, 0.7022711320314556, 0.21288707968778908, 0.14860527589917183, 0.5034070811234415, 0.411865035421215, 2.381446212530136, 2.2052902774885297, 1.468466471415013, 2.4208168499171734, 78.52254331111908, 86.09978511929512, 95.42301043868065, 89.87848475575447, 84.7000390291214, 103.01865085959435, 100.32834962010384, 97.96081826090813, 91.64271488785744, 92.4370014667511, 87.6365214586258, 86.24179869890213, 84.60677683353424, 86.62910431623459, 86.10708832740784, 85.07009357213974, 84.90395128726959, 89.32078868150711, 87.5482825934887, 81.55150517821312, 86.57041266560555, 81.54869332909584, 81.65005668997765, 90.25073558092117, 90.19512936472893, 88.1445161998272, 90.53464114665985, 89.26888346672058, 88.19422513246536, 88.11201274394989, 91.70578390359879, 87.9377768933773, 88.57862010598183, 80.89416325092316, 80.81918567419052, 76.70010030269623, 77.03498393297195, 80.39037108421326, 82.13607341051102, 83.69329825043678, 76.39983281493187, 71.6582116484642, 66.90734937787056, 56.22704587876797, 70.01166120171547, 72.24651888012886, 72.48139187693596, 66.11190006136894, 66.48228138685226, 80.41969031095505, 83.59537750482559, 79.89069789648056, 77.21950203180313, 78.77434059977531, 81.03899627923965, 83.75350221991539, 80.3960707783699, 79.88598614931107, 81.13354280591011, 79.69168737530708, 81.0958868265152, 79.66621354222298, 82.2368212044239, 85.18483981490135, 81.21222898364067, 83.29077064990997, 79.00090724229813, 76.89341872930527, 80.33747032284737, 76.62307843565941, 75.38897305727005, 71.83145195245743, 71.5281218290329, 66.16258934140205, 64.01549935340881, 63.955500572919846, 62.20203906297684, 56.09031401574612, 56.56748481094837, 57.213963121175766, 58.37377108633518, 61.19842551648617, 48.773293644189835, 45.84968492388725, 53.43744836747646, 51.96799501776695, 78.53651896119118, 100.61655655503273, 77.78976023197174, 64.59343314170837, 43.93817089498043, 25.228854529559612, 7.219677669927478, 0.11284172112937085, 0.25998273224104196, 0.15652342757675797, 0.24753670790232718, 0.15247392846504226, 0.3095619671512395, 0.40851308091077954, 0.061464314348995686, 0.08621450149803422, 2.666143085807562, 20.30125044286251, 79.09977033734322, 80.62437012791634, 93.72924372553825, 69.87629726529121, 39.04526464641094, 30.61711549758911, 42.33453534543514, 50.34170888364315, 52.31416404247284, 77.2403173148632, 75.42076215147972, 79.52282443642616, 53.025402277708054, 1.4860801887698472, 0.09342307836050168, 0.15234025282552466, 0.07078117690980434, 0.05209527509578038, 0.028657596521952655, 0.07841783939511515, 0.06104192099883221, 0.055795463849790394, 0.062058240291662514, 0.06860850247903727, 0.04223927935527172, 0.10096026337123476, 0.05611625347228255, 0.021974818300805055, 0.01311004149101791, 0.22704540198901668, 0.3240176086546853, 0.1369083605823107, 0.28217956773005426, 0.13202208996517584, 0.10808232065755874, 0.12683651119004935, 0.45009787136223167, 0.39132764213718474, 0.1330867304932326, 0.2259348818915896, 0.16457063873531297, 0.24828143825288862, 0.312526787747629, 0.29489223088603467, 0.5884405213873833, 7.666903221979737, 94.00284424424171, 94.56417292356491, 96.00671991705894, 115.48183009028435, 79.21694085001945, 87.56440132856369, 119.1984410583973, 80.83529680967331, 113.74998942017555, 125.71776643395424, 124.60720762610435, 38.33632528781891, 1.352049030829221, 0.5475434346590191, 0.8600081491749734, 0.250156904803589, 2.588444142602384, 2.9889497766271234, 0.5251102102920413, 0.4678277496714145, 1.567664542235434, 2.8933138959109783, 9.931188896298409, 13.82027355954051, 5.639177178964019, 2.7768366085365415, 85.20798817276955, 90.81575006246567, 103.52615162730217, 94.32781040668488, 89.22442585229874, 109.6066765487194, 101.86480477452278, 103.29925820231438, 94.20126959681511, 97.4198716878891, 92.55614027380943, 90.75503692030907, 89.2385458946228, 92.45401695370674, 89.7056320309639, 91.8565446138382, 93.37124973535538, 95.92978164553642, 95.10493710637093, 89.16850045323372, 92.23054334521294, 87.5858473777771, 87.82318264245987, 96.98497742414474, 95.4192866384983, 91.40649676322937, 94.21725153923035, 93.87378796935081, 93.43380957841873, 92.24923074245453, 97.03251287341118, 93.69708225131035, 91.3254927098751, 84.83759924769402, 85.01360580325127, 77.8031051158905, 79.17214125394821, 82.75805443525314, 83.40699881315231, 86.39011234045029, 76.72243550419807, 73.8024289906025, 69.65196490287781, 60.74215739965439, 70.6258450448513, 80.86623474955559, 72.3786149919033, 66.48530602455139, 67.89576753973961, 83.39140444993973, 87.50751838088036, 85.50197079777718, 83.37818115949631, 82.3530949652195, 84.9531738460064, 86.7646886408329, 81.96015805006027, 82.26797953248024, 83.05630803108215, 80.55451467633247, 83.87293741106987, 82.38725513219833, 87.06590607762337, 90.07876440882683, 82.56262332201004, 86.30672961473465, 79.02228489518166, 82.92466789484024, 84.3750424683094, 81.044612377882, 80.2162492275238, 78.05248573422432, 77.42500260472298, 73.97057756781578, 70.6393115222454, 69.88535597920418, 65.85947960615158, 65.06624177098274, 65.2127543091774, 60.137560442090034, 56.38462722301483, 61.084724217653275, 51.31079748272896, 55.838923305273056, 60.876210406422615, 59.96180847287178, 76.98993355035782, 87.60921612381935, 77.46673196554184, 69.27035138010979, 50.401688665151596, 33.201638013124466, 7.689767545089126, 0.12539579474832863, 0.5221132398582995, 0.24708705546800047, 0.3970103559549898, 0.28586067957803607, 0.6351375218946487, 0.629931801231578, 0.15957861207425594, 0.19016342324903235, 4.688983066007495, 32.67003893852234, 92.10931465029716, 87.33234018087387, 107.64048725366592, 79.77038115262985, 97.05025032162666, 84.31542366743088, 45.29249042272568, 49.58248682320118, 49.07453007996082, 78.0326659977436, 87.59239062666893, 90.40079712867737, 74.578917324543, 3.483528862707317, 0.277654129313305, 0.21169953950447962, 0.18549823842477053, 0.23340192652540281, 0.08312479229061864, 0.09067866078112274, 0.16273774177534506, 0.2917360846186057, 0.14828814135398716, 0.12760366924339905, 0.20072081533726305, 0.257341725518927, 0.2214565550093539, 0.1120344277296681, 0.12165893276687711], [0.04468759856536053, 0.09952020001946948, 0.08638457205961458, 0.09485940870945342, 0.032068739164969884, 0.048511874410905875, 0.04142100216995459, 0.07603332633152604, 0.10010016616433859, 0.06697697244817391, 0.059039910847786814, 0.07697649212786928, 0.053750646620756015, 0.14702613407280296, 0.07366346326307394, 0.24128280754666775, 13.496448285877705, 77.09600865840912, 70.97148969769478, 64.2841449379921, 46.06887236237526, 48.08157496154308, 81.19775176048279, 36.57622933387756, 68.79400134086609, 88.63693937659264, 97.02813550829887, 30.456710904836655, 0.6949717237148434, 0.024529398215236142, 0.13204999471781775, 0.04246118522132747, 0.26993935578502715, 0.4109022917691618, 0.4835787060437724, 0.17201797192683443, 0.16917680797632784, 0.29811015352606773, 1.0913558257743716, 1.0236764699220657, 0.27288378216326237, 1.6715309000574052, 21.03689096868038, 96.46661683917046, 81.21893182396889, 80.82896634936333, 91.67486876249313, 90.39227798581123, 93.99358794093132, 88.6718063056469, 88.93775403499603, 85.84717467427254, 82.1596397459507, 79.53119918704033, 76.70231938362122, 76.17083430290222, 79.04360175132751, 81.10672384500504, 85.29920607805252, 84.83465820550919, 82.21377164125443, 87.47884511947632, 73.0253554880619, 78.54012116789818, 79.03075084090233, 79.95456486940384, 82.7317750453949, 83.11465010046959, 84.79792177677155, 84.07845318317413, 83.14507886767387, 80.08619740605354, 87.79445618391037, 88.7437516450882, 84.02419969439507, 86.16524800658226, 85.18477901816368, 80.17072767019272, 78.18480983376503, 79.8529203236103, 81.1880774796009, 80.92889338731766, 82.99641564488411, 80.83259135484695, 79.75057661533356, 67.00993627309799, 56.39826849102974, 67.69817814230919, 75.21076261997223, 57.15658240020275, 76.29702553153038, 67.21578642725945, 70.16513496637344, 75.02322748303413, 75.77592149376869, 74.71207737922668, 77.20439404249191, 74.0653520822525, 78.8666832447052, 76.33632302284241, 77.43238180875778, 81.31039291620255, 84.44864451885223, 85.5734221637249, 84.78583842515945, 83.56853574514389, 82.80470073223114, 80.39902701973915, 76.29949539899826, 80.71355134248734, 78.74994590878487, 72.17692941427231, 83.83276596665382, 76.55956104397774, 74.44395616650581, 64.11472722887993, 67.1037532389164, 58.74265529215336, 56.39692336320877, 63.49293999373913, 57.893047481775284, 52.20773935317993, 53.78919169306755, 53.56643244624138, 53.06337743997574, 44.73358601331711, 36.31140634417534, 36.538113579154015, 39.307564571499825, 50.45547477900982, 100.33638998866081, 83.31155553460121, 51.61886215209961, 37.26542875170708, 23.054438307881355, 16.91621918231249, 0.4369678540388122, 0.12416066063451581, 0.25378882710356265, 0.34589184739161283, 0.43632743996568024, 0.43525408662389964, 0.3227829124080017, 0.1925186437438242, 0.12607012497028336, 0.22468207724159583, 2.3112620785832405, 17.23040722310543, 61.92962408065796, 70.19060119986534, 69.4637306034565, 51.98057234287262, 69.45539385080338, 41.215054616332054, 27.217551916837692, 35.083582028746605, 23.753435499966145, 44.931156411767006, 58.28313834965229, 62.800404354929924, 44.916595593094826, 1.0307341162115335, 0.015085776831256226, 0.1074616180267185, 0.04391055139421951, 0.08279337140265852, 0.057168748753611, 0.13796486717183143, 0.018560864773462527, 0.024815329161356203, 0.10392256066552363, 0.05846092804858927, 0.11577931232750416, 0.055602590800845064, 0.033599329690332524, 0.059680658887373284, 0.06851655780337751, 0.07677065746975131, 0.024208115064539015, 0.034304344007978216, 0.009217514034389751, 0.03498097859846894, 0.00916955645152484, 0.02630983461131109, 0.1716935494914651, 0.04106419983145315, 0.10065339272841811, 0.005521329167095246, 0.08029259348404594, 0.1878197505720891, 0.042341076041338965, 0.25888747069984674, 17.172162048518658, 88.187735080719, 81.49681091308594, 87.45611473917961, 72.24300786852837, 61.29121653735638, 54.99155357480049, 38.994252383708954, 79.88863080739975, 101.68485403060913, 111.42680168151855, 40.067884773015976, 0.6608500890433788, 0.07702777453232557, 0.24581281759310514, 0.12044040049659088, 0.36220440175384283, 0.17814379243645817, 0.7039380550850183, 0.12608824821654707, 0.16281482123304158, 0.14220002194633707, 0.90983891277574, 1.6026459401473403, 0.5840090091805905, 1.1619556811638176, 25.245189853012562, 106.03408545255661, 88.19929406046867, 89.37868997454643, 97.57663607597351, 95.07197767496109, 97.36393108963966, 93.22869658470154, 94.08966198563576, 92.44314193725586, 85.19444569945335, 81.5418840944767, 80.78775376081467, 83.64161342382431, 83.68907287716866, 84.34695437550545, 90.29922097921371, 88.6765256524086, 84.27561700344086, 91.78722113370895, 81.17976352572441, 82.57779210805893, 81.76779717206955, 81.11602574586868, 87.37783893942833, 86.29175081849098, 90.11757552623749, 87.85102754831314, 83.57587695121765, 79.60230857133865, 85.33137515187263, 85.70956125855446, 85.7297533750534, 88.30742105841637, 86.23125806450844, 82.9940901696682, 82.53698229789734, 82.29491248726845, 81.56998738646507, 81.93112760782242, 84.24285516142845, 82.59684428572655, 81.57716900110245, 72.5828692317009, 62.264036536216736, 71.14045143127441, 78.61025780439377, 59.068252220749855, 74.9532200396061, 70.74702054262161, 73.4710943698883, 76.95692092180252, 75.66913962364197, 76.29950299859047, 82.39945247769356, 78.19155067205429, 77.08605319261551, 81.03947505354881, 81.93525418639183, 82.65012502670288, 83.57266992330551, 84.9772797524929, 84.87586319446564, 84.0564751625061, 83.70490282773972, 84.34579163789749, 82.35766991972923, 81.35293543338776, 81.3244217634201, 76.46160989999771, 84.51112076640129, 80.82124516367912, 79.08270925283432, 69.26044911146164, 70.25930151343346, 65.95248341560364, 63.52079629898071, 65.79317316412926, 65.04824593663216, 61.199983432888985, 57.46569201350212, 56.268566250801086, 62.48609282076359, 65.98087549209595, 57.32113637030125, 48.47224339842796, 53.4375661611557, 50.60145154595375, 76.0864332318306, 102.20547169446945, 78.60167026519775, 65.93227609992027, 44.37324374914169, 21.982945203781128, 3.5968905547633767, 0.1398435843293555, 0.1941692692344077, 0.29524421668611467, 0.2631311008008197, 0.3291581687517464, 0.4055995278758928, 0.1651176461018622, 0.07333429108257405, 0.2896442968631163, 2.3917769081890583, 22.644193321466446, 76.91878616809845, 82.59831860661507, 82.78541296720505, 60.141968205571175, 40.204324051737785, 32.05671384930611, 42.78233751654625, 48.97576577961445, 41.78344711661339, 66.64853766560555, 72.8666304051876, 75.26249304413795, 57.067385986447334, 0.6235782452858984, 0.08241077201091684, 0.07629127459949814, 0.03116301100817509, 0.03901825082721189, 0.054395847546402365, 0.1265206086100079, 0.01037239322613459, 0.03447119364864193, 0.07230276518384926, 0.03646537043096032, 0.070196260639932, 0.12356623003142886, 0.03664503325126134, 0.0492131631472148, 0.2694442542269826, 0.18965490366099402, 0.12288857498788275, 0.27075951802544296, 0.2494188240962103, 0.12431360984919593, 0.18111653917003423, 0.1466230588266626, 0.42266542150173336, 0.13493579142959788, 0.21962897182675079, 0.2668865164741874, 0.19839395972667262, 0.3365766175556928, 0.2236964605981484, 0.7193332852330059, 22.33895570039749, 105.6255541741848, 93.27452972531319, 91.17663189768791, 64.4270096719265, 72.12792724370956, 118.58013063669205, 56.06386363506317, 91.47107809782028, 113.20504546165466, 115.65702348947525, 66.19009226560593, 1.8695724732242525, 0.16051339160185307, 0.4505011544097215, 0.21725182828959078, 0.543407000368461, 0.5170940654352307, 1.8648544326424599, 0.7372151257004589, 0.45523095061071217, 0.3693662158912048, 3.0610368959605694, 3.478401037864387, 3.0165529204532504, 4.191298596560955, 34.27292972803116, 113.60055863857269, 93.57016146183014, 96.96904107928276, 100.21652162075043, 95.5602590739727, 97.42617174983025, 99.25209537148476, 97.13099598884583, 95.98083570599556, 88.88211742043495, 86.00925117731094, 83.36197882890701, 87.67839521169662, 86.65300503373146, 87.50304982066154, 93.14163565635681, 90.80804407596588, 89.01952564716339, 97.52112105488777, 86.7899040877819, 87.88248986005783, 87.73710206151009, 88.45658585429192, 90.80133363604546, 92.15467661619186, 93.55172485113144, 89.17421534657478, 87.46632099151611, 81.55050203204155, 89.07519266009331, 88.26576769351959, 88.49256992340088, 90.72821035981178, 87.28659823536873, 86.45920023322105, 84.87392529845238, 84.00688782334328, 84.87976938486099, 86.57216817140579, 87.4615028500557, 86.59535452723503, 83.80425989627838, 71.0878774523735, 61.47475428879261, 74.2246775329113, 86.26420229673386, 65.17601788043976, 73.18529650568962, 71.97597339749336, 73.77222061157227, 76.27779856324196, 79.0165776014328, 79.35608178377151, 82.66140282154083, 81.46519660949707, 78.52274090051651, 82.46201232075691, 84.16513413190842, 86.79715409874916, 87.61233195662498, 89.79877263307571, 88.15707832574844, 88.28494906425476, 85.4881851375103, 86.7234456539154, 84.44129571318626, 83.15360561013222, 82.81655609607697, 81.82740837335587, 88.18657234311104, 83.9159283041954, 85.5200806260109, 77.13207632303238, 76.04884564876556, 72.39692240953445, 69.34611931443214, 70.90300977230072, 70.89493900537491, 68.49726006388664, 67.92601391673088, 64.8498585820198, 64.73815977573395, 64.68492463231087, 57.56247282028198, 58.65955375134945, 60.618637427687645, 58.61674144864082, 74.59545403718948, 91.26859456300735, 79.56497937440872, 70.97860291600227, 53.075491189956665, 28.530071787536144, 3.4360601473599672, 0.14112543663941324, 0.5471233197022229, 0.5357188254129142, 0.4585812130244449, 1.0577561287209392, 1.0593069205060601, 0.33434895740356296, 0.30945183243602514, 1.278970402199775, 3.725622659549117, 36.687244176864624, 92.49329924583435, 95.39770379662514, 93.39895024895668, 78.38008895516396, 109.01932686567307, 58.08867618441582, 41.73870451748371, 46.50666207075119, 36.935017481446266, 68.07195648550987, 83.7594299018383, 88.01130294799805, 74.23769563436508, 1.0182035760954022, 0.13712880812818184, 0.1604581461288035, 0.09612561654648744, 0.15464328549569473, 0.19524904957506806, 0.26466197334229946, 0.14097829844104126, 0.09821586063480936, 0.20909828221192583, 0.15511348057771102, 0.2064356641494669, 0.2819293749053031, 0.11935284986975603, 0.1757727493532002], [0.024823138410283718, 0.06615234247874469, 0.04200481635052711, 0.08733141890843399, 0.07392627259832807, 0.041197645405191, 0.03313022927613929, 0.03452546319749672, 0.05832378657942172, 0.0790818537643645, 0.013941509423602838, 0.05157848798262421, 0.07635810499778017, 0.03309183055534959, 0.03252224334573839, 0.08899029708118178, 21.796413213014603, 67.04340487718582, 59.62166592478752, 50.78523248434067, 40.06913110613823, 42.086621448397636, 20.832281447947025, 57.841305658221245, 85.25733232498169, 89.1484147310257, 60.27858227491379, 1.2797323800623417, 0.49396381597034633, 0.16424056113464758, 0.07135234118322842, 0.46218772418797016, 0.062181076864362694, 0.3448961820686236, 0.49129247025121003, 0.18963927403092384, 0.16280030482448637, 2.289663562551141, 1.5785624762065709, 0.5362339352723211, 1.2079592188820243, 1.077244570478797, 45.667119920253754, 65.80117553472519, 83.5158097743988, 73.60086500644684, 82.60759770870209, 90.6358753144741, 92.5875873863697, 89.60845604538918, 87.07156777381897, 80.03752201795578, 77.87463247776031, 80.26909679174423, 77.4315382540226, 81.81727051734924, 81.52693569660187, 84.26281169056892, 82.77222007513046, 84.63231906294823, 83.45828086137772, 87.95112937688828, 78.57267782092094, 70.70020705461502, 77.48501658439636, 77.43631079792976, 83.89281034469604, 82.68472597002983, 79.75786462426186, 82.46726363897324, 79.87938210368156, 84.55107182264328, 85.34778267145157, 88.07177290320396, 92.06626296043396, 83.15254926681519, 80.65351456403732, 79.54449087381363, 76.17639720439911, 74.84690934419632, 78.30683648586273, 80.87204083800316, 82.09793865680695, 84.00149211287498, 81.5675251185894, 82.66635775566101, 74.47449132800102, 63.70232775807381, 49.76092144846916, 63.906202018260956, 83.4967651963234, 73.17515105009079, 74.64079320430756, 76.05105713009834, 74.01013344526291, 78.0583906173706, 79.74046915769577, 79.30103033781052, 77.3440745472908, 80.19196093082428, 81.14456221461296, 72.98332214355469, 72.2064158320427, 71.60573646426201, 78.21924358606339, 81.2629334628582, 79.92960780858994, 79.40015941858292, 77.61775866150856, 78.54126110672951, 83.06616470217705, 76.58920705318451, 73.96192163228989, 82.79671356081963, 70.29391765594482, 71.69498607516289, 68.0591131746769, 65.72652474045753, 56.06352165341377, 57.50802934169769, 58.11881996691227, 51.3577401638031, 45.20352579653263, 46.49258002638817, 49.85848121345043, 55.880941450595856, 50.45896299183369, 39.68095913529396, 39.211881905794144, 40.975473672151566, 52.570695877075195, 105.33116117119789, 83.20874825119972, 49.961326494812965, 39.85521778464317, 24.382419548928738, 12.670158874243498, 0.2456862517283298, 0.15421977150253952, 0.21798751928145066, 0.21900541934883222, 0.6484727875795215, 0.12274816064746119, 0.021679710698663257, 0.07318209885852411, 0.16747576097259298, 0.10533198073972017, 1.0513717588037252, 24.23202931880951, 60.78508749604225, 69.00668352842331, 64.9212871491909, 47.38231748342514, 68.66955801844597, 40.40109649300575, 30.446770638227463, 28.81583545356989, 44.88766394555569, 49.34827499091625, 60.14975018799305, 65.19791230559349, 26.99347034096718, 0.19871608150424436, 0.10041673667728901, 0.07931672123959288, 0.04991978421458043, 0.096554807969369, 0.06929918221430853, 0.11381766758859158, 0.027550108097784687, 0.024084052092803176, 0.014582796447939472, 0.027021121932193637, 0.08290123514598235, 0.006633517241425579, 0.05782845495559741, 0.023240170812641736, 0.024210109586420003, 0.037151857031858526, 0.03401159272470977, 0.11042720303521492, 0.0635538533970248, 0.04552050719212275, 0.01468197891881573, 0.09031016961671412, 0.04388594919873867, 0.03644024873210583, 0.013975158399262, 0.04812949395272881, 0.12391625656164251, 0.09699152476969175, 0.12821877608075738, 26.931144185364246, 78.35540547966957, 73.66204172372818, 69.15181294083595, 52.248465567827225, 54.506551399827, 27.542898058891296, 63.7550613284111, 96.49257704615593, 99.70873206853867, 73.84821653366089, 1.6915175900794566, 0.7073800172656775, 0.05120110959978774, 0.10839759241207503, 0.3714726387988776, 0.06048575924069155, 0.42040920350700617, 0.2004574122838676, 0.1489879420842044, 0.20357740111649036, 2.6719342125579715, 2.2370850713923573, 0.41140463668853045, 1.502521075308323, 1.2490552011877298, 58.74977231025696, 75.81590294837952, 90.1626107096672, 79.35934200882912, 90.5957342684269, 91.39493778347969, 96.4266049861908, 92.22204700112343, 92.11711943149567, 85.4061171412468, 82.26978063583374, 82.24803060293198, 82.6857291162014, 82.77424916625023, 85.50038248300552, 88.68970334529877, 88.86154532432556, 89.67547684907913, 87.4066261947155, 90.71133926510811, 83.46824392676353, 77.13529855012894, 86.35781407356262, 82.39541709423065, 83.41804102063179, 82.07143127918243, 80.15322580933571, 83.94419118762016, 85.63417330384254, 88.14183354377747, 89.93506371974945, 86.29581660032272, 87.06522971391678, 83.70658233761787, 83.45970958471298, 80.56411296129227, 76.23115986585617, 79.6917861700058, 78.59471663832664, 82.40095719695091, 83.11494648456573, 84.16980788111687, 81.8567655980587, 85.44895604252815, 78.56782168149948, 73.88883635401726, 63.39280776679516, 72.10080429911613, 82.78358906507492, 74.77722868323326, 76.90132230520248, 79.94034603238106, 75.47793388366699, 81.51322603225708, 79.3309423327446, 82.62188494205475, 81.35634005069733, 77.53550067543983, 80.7341918349266, 77.13925793766975, 74.00177389383316, 75.34711450338364, 79.12482619285583, 81.71576276421547, 80.96531063318253, 80.01940459012985, 81.72156125307083, 80.75762897729874, 83.4558641910553, 77.43600681424141, 77.99086064100266, 83.74969482421875, 73.73768046498299, 77.26718947291374, 73.70077684521675, 70.49692556262016, 66.38084962964058, 62.59729005396366, 62.58001238107681, 60.242503210902214, 56.446518301963806, 53.44290867447853, 51.09760992228985, 57.889730259776115, 66.02960407733917, 59.556609615683556, 52.46938191354275, 53.86663153767586, 51.051199212670326, 82.003483325243, 103.94655346870422, 77.99000188708305, 64.24758329987526, 41.98715798556805, 16.874001547694206, 1.0268194950185716, 0.42748391919303685, 0.038881881191628054, 0.4538233042694628, 0.21433417859952897, 0.18997948936885223, 0.08156128009431995, 0.08712298673344776, 0.29029839613940567, 0.3992834355449304, 0.43664139811880887, 33.70964415371418, 78.13936427235603, 82.59109139442444, 78.58210891485214, 51.291623711586, 22.568438686430454, 30.174587443470955, 39.313214868307114, 43.814597725868225, 54.97203782200813, 69.32712033390999, 71.5785451233387, 80.47199070453644, 33.60779821872711, 0.19669938425067812, 0.19211277802241966, 0.11757346917875111, 0.045778292187605985, 0.10173942937399261, 0.012134926237195032, 0.09621445904485881, 0.08638302097097039, 0.0611228818888776, 0.070141950272955, 0.06795908615458757, 0.05166051756532397, 0.04247268479957711, 0.0326142882113345, 0.180898986000102, 0.17119105614256114, 0.138298180536367, 0.11058249743655324, 0.19898522878065705, 0.12782810954377055, 0.08849402292980812, 0.08163231846992858, 0.31926388561259955, 0.24172771023586392, 0.1258954530931078, 0.16459740058053285, 0.22798245248850435, 0.22178422805154696, 0.22806708700954914, 0.19048806832870468, 38.11296567320824, 92.35041931271553, 79.44712489843369, 72.18167155981064, 57.671800553798676, 61.13500311970711, 32.88673751056194, 83.00970733165741, 115.20683884620667, 110.66060319542885, 91.79235845804214, 9.065892677754164, 1.715429350733757, 0.2111098586465232, 0.5175631621386856, 0.7033133448567241, 0.19604136643465608, 0.527827717596665, 1.3699170970357955, 0.944035118445754, 0.5382665887009352, 4.2078443337231874, 3.3407750353217125, 1.5482930629514158, 6.405644975602627, 1.1322454316541553, 71.87600836157799, 85.56703090667725, 95.05838960409164, 91.17126658558846, 94.12886068224907, 95.2795073390007, 102.70978823304176, 94.1720263659954, 97.36048087477684, 88.10373678803444, 85.45725479722023, 84.49298813939095, 85.69069907069206, 86.81568190455437, 91.75492286682129, 89.38429847359657, 92.8347185254097, 93.48972737789154, 89.8623888194561, 96.28184795379639, 90.55699914693832, 83.72851476073265, 91.95664644241333, 87.05471947789192, 88.33389803767204, 85.32245323061943, 84.90826025605202, 86.40813857316971, 84.67049941420555, 87.66298323869705, 93.82107719779015, 90.81818953156471, 92.9623992741108, 89.90867793560028, 87.60164692997932, 83.32084983587265, 81.33954495191574, 84.54833596944809, 83.34535852074623, 85.88372871279716, 87.68217220902443, 87.42792785167694, 88.88586401939392, 89.74090173840523, 80.32181516289711, 71.45366102457047, 64.22299101948738, 68.70529890060425, 83.25230911374092, 74.72978442907333, 78.31078067421913, 83.61187621951103, 75.62326088547707, 84.19055476784706, 86.23865246772766, 86.82641252875328, 84.72638681530952, 80.19109457731247, 84.7961662709713, 79.58432793617249, 76.80030852556229, 77.38525673747063, 80.01611396670341, 85.96277207136154, 82.28523820638657, 84.18499946594238, 84.88994523882866, 83.2243350148201, 84.81587961316109, 78.90822261571884, 83.74804571270943, 90.39242997765541, 78.40957537293434, 81.22482150793076, 76.751868724823, 76.06329247355461, 76.96456611156464, 73.33558604121208, 71.19785875082016, 68.63615781068802, 62.762159407138824, 64.82430875301361, 62.483003586530685, 67.92662188410759, 67.76623249053955, 59.24669824540615, 56.97768419981003, 61.89765639603138, 58.4503635764122, 80.879275649786, 94.2566554248333, 80.81851691007614, 72.10910305380821, 52.22112223505974, 21.51372168213129, 1.3507489068433642, 0.46730465430300683, 0.45239437313284725, 0.3901026531821117, 0.781466185580939, 0.3974900802131742, 0.19892321492079645, 0.07910346510470845, 0.6718984118197113, 1.0698553919792175, 1.1796768615022302, 46.65262743830681, 87.99501702189445, 94.01953294873238, 87.39011988043785, 74.36208575963974, 98.42318505048752, 57.81215742230415, 44.72421191632748, 41.47932283580303, 57.28719279170036, 72.3507396876812, 85.51332458853722, 93.35063204169273, 46.02974206209183, 0.20684172282926738, 0.4363505059154704, 0.1374987539020367, 0.21008976182201877, 0.34518653992563486, 0.15093376423465088, 0.1959139693644829, 0.2251297704060562, 0.10845142038306221, 0.2931694983271882, 0.22593885980313644, 0.2875686879269779, 0.1702873726026155, 0.09840590239036828], [0.07227593654533848, 0.057686185245984234, 0.02125116308889119, 0.05514019569091033, 0.07111645696568303, 0.040578389962320216, 0.03322862692584749, 0.025043431960511953, 0.03893760163919069, 0.054167870912351646, 0.08798856099019758, 0.043950504914391786, 0.049587027460802346, 0.013872705840185517, 0.052184781816322356, 0.9139970177784562, 43.543964847922325, 71.2441098690033, 61.262102499604225, 65.54242461919785, 57.08327293395996, 50.86108781397343, 36.48126482963562, 51.60699158906937, 80.1996137201786, 55.86079493165016, 6.957876468077302, 1.4056388614699244, 1.1549211898818612, 0.11223815468838438, 0.3486858255928382, 0.09311824120231904, 0.37286820297595114, 0.08290300887892954, 0.1813101803418249, 0.06515953442431055, 0.2362908105715178, 4.5083725824952126, 1.0673035914078355, 0.6060957396402955, 0.8765110792592168, 17.957036532461643, 67.23078042268753, 69.38941419124603, 61.72620199620724, 66.71316459774971, 85.08461639285088, 90.16285389661789, 87.46343314647675, 85.7316380739212, 83.41400563716888, 83.87824952602386, 80.5896931886673, 78.17734703421593, 79.71256345510483, 81.37413069605827, 85.23869812488556, 84.4095142185688, 82.05161154270172, 86.95854663848877, 81.22544467449188, 85.50586178898811, 74.57717701792717, 71.14511758089066, 83.46971064805984, 75.34731969237328, 79.20407474040985, 78.096282184124, 79.00855243206024, 84.4873720407486, 86.22303530573845, 81.4669369161129, 78.52163136005402, 77.32196733355522, 82.80698820948601, 84.25828233361244, 80.496316999197, 83.47135975956917, 81.05272114276886, 77.84675717353821, 76.69238671660423, 78.85026052594185, 78.82076650857925, 79.10444408655167, 77.69614845514297, 80.34718260169029, 80.20739570260048, 78.48158150911331, 80.88477775454521, 76.01292237639427, 72.2534953057766, 69.52053755521774, 73.06829318404198, 74.03197467327118, 71.83172553777695, 75.61177030205727, 75.82341134548187, 76.1789658665657, 74.44524049758911, 74.01644110679626, 80.52794650197029, 80.8163358271122, 76.69384583830833, 78.70804935693741, 76.39247640967369, 79.73559021949768, 82.24584192037582, 75.82670956850052, 71.28236621618271, 74.05923441052437, 75.42295843362808, 78.1838446855545, 75.9928822517395, 73.82296308875084, 75.35698637366295, 72.46630668640137, 69.87193509936333, 65.59479340910912, 64.47654381394386, 53.70113141834736, 52.31718868017197, 53.07480342686176, 50.59348337352276, 44.01875697076321, 43.92309330403805, 44.63537648320198, 47.36665092408657, 51.895760893821716, 46.74991361796856, 40.825947895646095, 41.88993640244007, 59.166617542505264, 109.8683913052082, 81.35270744562149, 50.10031543672085, 37.21222020685673, 20.864114239811897, 5.360639300197363, 0.3249136480735615, 0.06608460666029714, 0.25139005738310516, 0.169666105939541, 0.08181114637409337, 0.15186860313406214, 0.17430552339646965, 0.18593410175526515, 0.47621677920687944, 0.09861852769972757, 1.6105425101704895, 31.066838465631008, 46.04703113436699, 71.44885048270226, 58.870020657777786, 60.18854230642319, 70.76867938041687, 43.09667184948921, 37.10039600729942, 56.445754542946815, 42.08467595279217, 53.41797821223736, 58.75251196324825, 64.37312856316566, 8.62894082441926, 0.4944912454811856, 0.16462119383504614, 0.16769459063652903, 0.12508394429460168, 0.07822599422070198, 0.025334988386020996, 0.07206168593256734, 0.06336640173685737, 0.018004176090471447, 0.09772216915735044, 0.08021025219932199, 0.08909125142963603, 0.035338582456461154, 0.060607556806644425, 0.04028624352940824, 0.020592820583260618, 0.05034494948631618, 0.055669588182354346, 0.08113496820442379, 0.030114491783024278, 0.053926754553685896, 0.013500970562745351, 0.04908101633191109, 0.028166144475108013, 0.0480926463205833, 0.045876044168835506, 0.08202877375879325, 0.13879761623684317, 0.8028870017733425, 49.70426648855209, 78.10390457510948, 73.22780102491379, 73.79276230931282, 63.41555334627628, 45.92093110084534, 22.181252762675285, 61.09636679291725, 92.40433841943741, 73.36404651403427, 6.915967566892505, 2.0838630432263017, 2.095222771167755, 0.009635411825001938, 0.3466033295262605, 0.14159713085973635, 0.36838672938756645, 0.19759309332584962, 0.16571461485000327, 0.255908104008995, 0.96029581152834, 6.7654115706682205, 0.9693147463258356, 0.5203164112754166, 1.003041558433324, 21.8724300339818, 81.44885748624802, 76.60182237625122, 72.49808058142662, 75.45772656798363, 91.43002510070801, 92.53644973039627, 90.57376384735107, 89.00385528802872, 86.80802911520004, 86.23433589935303, 83.35960015654564, 82.62779742479324, 85.5567866563797, 85.16046032309532, 88.09524044394493, 85.28217539191246, 85.8232207596302, 89.15787622332573, 85.56590616703033, 87.74207219481468, 77.09781736135483, 77.0611721277237, 87.37436592578888, 78.53771969676018, 79.57552760839462, 78.86191070079803, 81.01989850401878, 88.77996370196342, 90.98065361380577, 83.47210451960564, 80.17764329910278, 78.31777229905128, 79.628154784441, 84.04963552951813, 84.98633086681366, 86.66260331869125, 85.04826754331589, 80.4084125161171, 83.18312242627144, 80.5568553507328, 78.61598789691925, 83.04167121648788, 80.1551865041256, 81.66130408644676, 83.43587726354599, 81.36870458722115, 83.56598228216171, 78.29942688345909, 74.43132564425468, 68.18609476089478, 73.50080117583275, 75.71156054735184, 78.0697900056839, 75.0652228295803, 78.00483629107475, 78.35846811532974, 79.23695057630539, 79.3149907886982, 81.02973237633705, 83.15780818462372, 80.90708255767822, 80.39930820465088, 76.32294774055481, 78.66928383708, 79.7765064239502, 77.22921431064606, 72.10089549422264, 75.44201821088791, 80.46324357390404, 79.97958272695541, 76.02723240852356, 77.25889831781387, 80.16328766942024, 76.59470155835152, 77.5147233903408, 69.42073971033096, 70.89539498090744, 65.69178700447083, 63.07385668158531, 61.229112669825554, 62.947213277220726, 57.05891624093056, 54.02787588536739, 49.739049822092056, 51.57331399619579, 58.647964373230934, 63.525557443499565, 55.928207114338875, 55.29115229845047, 53.4716959297657, 86.15873515605927, 102.45799094438553, 84.4082298874855, 57.53878869116306, 33.84734496474266, 8.304346092045307, 0.2773782581789419, 0.0628411170328036, 0.15136069210711867, 0.09209819632815197, 0.03532762835675385, 0.15589181537507102, 0.36097864096518606, 0.26281099766492844, 0.30311353504657745, 0.0629216994275339, 1.1023611039854586, 40.75128950178623, 63.84592205286026, 85.69108664989471, 69.65939730405807, 58.47389951348305, 27.904437258839607, 29.214700050652027, 51.256486997008324, 78.56324672698975, 57.262805700302124, 72.57731392979622, 69.61101070046425, 82.61833593249321, 11.074046920984983, 0.47757924359757453, 0.22604473459068686, 0.1293050724780187, 0.035156255326000974, 0.1282833726145327, 0.012452016253519105, 0.034388633430353366, 0.03427359311899636, 0.019900407933164388, 0.04909577764919959, 0.0855088971729856, 0.04488611935812514, 0.045617954892804846, 0.13069630251266062, 0.19227591692470014, 0.06472057633800432, 0.1413683861028403, 0.12552559637697414, 0.21234039886621758, 0.15431173844262958, 0.12163696519564837, 0.1450099266367033, 0.18190339382272214, 0.216385712265037, 0.23585221613757312, 0.1540368321002461, 0.24367093486944214, 0.3180516022257507, 1.599143121857196, 62.6400263607502, 95.36382481455803, 79.64433431625366, 86.20915845036507, 77.80289232730865, 73.64956319332123, 52.93460614979267, 77.44496673345566, 105.08320167660713, 88.22229042649269, 12.58907312527299, 3.4038853738456964, 2.8549376176670194, 0.2196863992139697, 0.35455140459816903, 0.26332676061429083, 0.5781565513461828, 0.47572708048392087, 0.2993900317233056, 0.5289592850022018, 1.6601589415222406, 14.594369921833277, 3.2724390272051096, 1.1601709644310176, 2.147132735699415, 23.676558025181293, 92.58759498596191, 76.76364809274673, 81.1993020772934, 83.21899250149727, 98.62733289599419, 98.1675423681736, 95.45080974698067, 95.01802057027817, 92.44092285633087, 90.35985812544823, 91.22372657060623, 85.24997591972351, 89.94064942002296, 89.0113028883934, 92.94831722974777, 90.41937813162804, 89.95912402868271, 93.32420825958252, 89.09580275416374, 90.39398029446602, 82.1683032810688, 82.62917295098305, 94.94723036885262, 83.83238598704338, 85.71093678474426, 81.25524267554283, 84.36533018946648, 92.39248305559158, 98.4860260784626, 89.14826273918152, 83.07319432497025, 80.29371947050095, 83.52707996964455, 87.004364579916, 88.05243194103241, 90.71393072605133, 88.32551568746567, 85.03939881920815, 88.22833970189095, 83.51471543312073, 85.47750011086464, 85.49188613891602, 84.61341887712479, 86.32699012756348, 87.56745636463165, 83.66976231336594, 85.29840812087059, 82.73668438196182, 76.1432021856308, 69.29246619343758, 76.58218502998352, 78.08653190732002, 80.7786114513874, 78.01467776298523, 81.77348926663399, 81.70933350920677, 83.55671837925911, 82.05334424972534, 84.97984081506729, 85.22290617227554, 83.992760181427, 82.99288183450699, 75.60807690024376, 79.49523791670799, 84.77981954813004, 77.14567959308624, 75.27557954192162, 78.85969161987305, 82.43489697575569, 79.59506615996361, 81.3700345158577, 82.24117577075958, 82.650056630373, 82.62881577014923, 82.14893952012062, 77.68766731023788, 77.27762371301651, 72.32290998101234, 72.45746836066246, 65.19007712602615, 64.88946005702019, 58.56554679572582, 59.328526854515076, 57.52303473651409, 63.048443645238876, 63.96066069602966, 65.10686919093132, 57.91141949594021, 61.09747253358364, 60.789841040968895, 85.6428824365139, 93.88776361942291, 88.63975122570992, 69.05945509672165, 43.745464235544205, 9.516312908381224, 0.6838677101768553, 0.21406218147603795, 0.4840785276610404, 0.2315394178731367, 0.1076065817323979, 0.33231856010388583, 0.661502288421616, 0.547058010706678, 1.861966943833977, 0.22825447929790244, 1.9324290566146374, 53.181342110037804, 78.83104115724564, 104.92251589894295, 80.45561358332634, 98.35181728005409, 109.01228964328766, 62.34154857695103, 51.63096830248833, 68.46233993768692, 56.643077954649925, 76.90104112029076, 80.04435405135155, 96.65929690003395, 14.350650049746037, 0.7213813753332943, 0.3958481823792681, 0.22594589536311105, 0.2092676848405972, 0.4082557337824255, 0.09099908304051496, 0.17767852521501482, 0.1496415663859807, 0.14138293219730258, 0.16531772911548615, 0.22336572990752757, 0.1761680023628287, 0.18372695456491783], [0.03298808944236953, 0.026913703477475792, 0.05862852725840639, 0.010167666223424021, 0.0363149890472414, 0.09316385359852575, 0.015207589240162633, 0.0034102427889592946, 0.07452800593455322, 0.08922071167035028, 0.037003601901233196, 0.022293169968179427, 0.0945513580518309, 0.049152748615597375, 0.15011409181170166, 5.594594646245241, 64.7471196949482, 70.58368250727654, 61.24067924916744, 60.4141665995121, 48.124075680971146, 53.634969368577, 48.590462654829025, 82.57801249623299, 69.19657453894615, 11.441300064325333, 1.0846482357010245, 0.12481850775657222, 1.0824251174926758, 0.09487539457040839, 0.13175200758269057, 0.287042802083306, 0.049556925951037556, 0.0804810322006233, 0.36496741755399853, 0.3569790883921087, 0.43698836700059474, 1.1588413920253515, 0.3179510263726115, 0.28366101323626935, 1.681309794075787, 55.15402905642986, 86.00051924586296, 73.249421864748, 50.002261698246, 68.37517261505127, 80.54229453206062, 81.24081864953041, 82.13616460561752, 79.41247835755348, 82.91952297091484, 81.78888604044914, 81.79943427443504, 83.91335964202881, 79.73511904478073, 81.22550547122955, 81.98608785867691, 81.2992975115776, 82.75464221835136, 88.57255563139915, 78.99605110287666, 84.06827732920647, 72.82366991043091, 70.10306149721146, 78.86789157986641, 72.97331348061562, 82.81468659639359, 77.53737017512321, 81.62313893437386, 82.5578735768795, 83.93826350569725, 79.70307916402817, 82.52932950854301, 79.91932556033134, 85.41815489530563, 87.07428842782974, 84.81274858117104, 79.7355218231678, 81.76735639572144, 80.43275400996208, 75.8224005997181, 73.84056374430656, 74.40164923667908, 81.03267341852188, 78.343595713377, 75.79587042331696, 77.43511006236076, 73.49528387188911, 71.79793775081635, 73.15413057804108, 69.15444999933243, 67.25329801440239, 69.87648725509644, 67.18702957034111, 67.30425328016281, 66.75378441810608, 71.49807304143906, 71.74408704042435, 74.10417839884758, 74.91859629750252, 72.46464237570763, 81.67794719338417, 75.00678196549416, 76.5002766251564, 75.6048546731472, 73.77504765987396, 74.804108440876, 80.37465512752533, 75.97167178988457, 69.76218178868294, 68.42192530632019, 75.36458596587181, 71.01923793554306, 76.7083990573883, 81.37748971581459, 73.082375228405, 69.30673062801361, 67.34589904546738, 66.2798510491848, 63.75653564929962, 58.152318969368935, 59.98884402215481, 64.13856714963913, 59.38901200890541, 59.08174529671669, 50.61411626636982, 46.000533029437065, 40.84449850022793, 45.64556747674942, 47.35404700040817, 50.55095225572586, 54.73825916647911, 63.00965912640095, 99.16412249207497, 80.76965913176537, 49.17833670973778, 28.594018556177616, 14.44094080477953, 1.677576256915927, 1.4824319095350802, 0.1454716018633917, 0.24468332820106298, 0.17978843621676788, 0.03444080641202163, 0.4150705790380016, 0.5430157401133329, 0.5847584002185613, 0.02508785135432845, 0.14370819961186498, 4.086690209805965, 23.943070024251938, 40.05261719226837, 64.2179448902607, 45.91450944542885, 50.82791179418564, 56.01137325167656, 35.956201404333115, 22.014147229492664, 30.963622704148293, 42.0191864669323, 47.91950225830078, 61.9333440810442, 35.22982858121395, 0.07796386766131036, 0.05814758587803226, 0.02067519526463002, 0.06661228850134648, 0.002559293016020092, 0.08251877676229924, 0.0323849126289133, 0.05838762241182849, 0.056592088876641355, 0.11905593142728321, 0.07750542819849215, 0.07308930071303621, 0.05955489083135035, 0.022478894279629458, 0.017536387422296684, 0.08589637247496285, 0.008427467219007667, 0.010261442148475908, 0.009142886447079945, 0.1266696912352927, 0.025427691907680128, 0.08765190053964034, 0.07434459897922352, 0.09199481515679508, 0.05621478099783417, 0.0656114800949581, 0.059426517836982384, 0.10667393959010951, 6.080136392265558, 75.64226746559143, 76.93072512745857, 77.276331782341, 71.238714158535, 63.88566792011261, 37.48769402503967, 45.219621732831, 100.32116040587425, 84.07068639993668, 15.785636398941278, 1.6521494463086128, 0.33935934479814023, 1.4483651937916875, 0.08983558844192885, 0.10351731834816746, 0.42790845734998584, 0.07578930075396784, 0.028141829861851875, 0.46637165592983365, 1.174426255747676, 1.0735971224494278, 2.80685618519783, 0.5003274651244283, 0.336125124595128, 3.1930648488923907, 64.56865847110748, 92.99203768372536, 78.80183592438698, 63.10678191483021, 81.77997171878815, 84.61573675274849, 86.17506667971611, 87.30356052517891, 84.84836027026176, 86.65785357356071, 84.1664944589138, 87.2499530017376, 91.18053808808327, 83.9931933581829, 84.87056627869606, 85.34749388694763, 87.19984889030457, 84.61080461740494, 89.60207998752594, 82.83177807927132, 87.15388655662537, 76.59801498055458, 76.39405712485313, 77.52405568957329, 79.66059744358063, 88.23347702622414, 82.06532880663872, 83.98558616638184, 85.84967494010925, 85.47873884439468, 83.24193567037582, 85.9073406457901, 83.03489238023758, 85.78678071498871, 87.10911735892296, 84.40665677189827, 85.11556953191757, 83.17318975925446, 80.64727529883385, 79.62099596858025, 77.9478469491005, 76.46833553910255, 81.76222667098045, 81.53979420661926, 79.49682623147964, 79.32388991117477, 78.20798859000206, 74.52948957681656, 77.27976679801941, 72.54129186272621, 68.49736645817757, 66.78795978426933, 69.86275479197502, 66.59493774175644, 70.12895330786705, 70.45615375041962, 72.8596843779087, 75.89737057685852, 79.05923411250114, 74.92374882102013, 82.31068164110184, 79.34324607253075, 79.35472145676613, 78.05354207754135, 76.14387854933739, 76.58726155757904, 81.25843450427055, 78.9574071764946, 73.09750601649284, 69.48334515094757, 76.24168530106544, 70.46054631471634, 77.6708722114563, 84.60283264517784, 77.26410403847694, 73.39786469936371, 72.36226826906204, 70.89345708489418, 69.96339619159698, 68.92050415277481, 68.36419880390167, 68.64896312355995, 69.25002247095108, 66.92877262830734, 59.61267180740833, 56.04117885231972, 48.82869467139244, 50.659261643886566, 59.61318477988243, 62.48415872454643, 72.85342991352081, 62.878045588731766, 79.52280163764954, 96.66263312101364, 78.79067212343216, 47.5675955414772, 21.670035794377327, 2.6434846641495824, 1.431100582703948, 0.6024007347878069, 0.15303384920116514, 0.08473343448713422, 0.07493164521292783, 0.6830507540144026, 0.07727257194346748, 0.9368725027889013, 0.10973780721542425, 0.1323201513150707, 3.863475937396288, 33.33081588149071, 61.36649049818516, 80.70007726550102, 56.75955690443516, 47.87761710584164, 31.420855969190598, 27.151123881340027, 30.504381246864796, 34.324747547507286, 55.50211697816849, 73.53495374321938, 72.4226850271225, 45.59205874800682, 0.027211857595830224, 0.0274209651252022, 0.009932374796335353, 0.051888958041672595, 0.049883352185133845, 0.06988892986555584, 0.06254425054066814, 0.04956740878697019, 0.029155848496884573, 0.045606006315210834, 0.015564116984023713, 0.02589370313216932, 0.04546691670839209, 0.22573013819055632, 0.10277041350491345, 0.16039449954405427, 0.08865803756634705, 0.12052311285515316, 0.17378705902956426, 0.14469593879766762, 0.16743001498980448, 0.3404503018828109, 0.14840486634057015, 0.2662961825262755, 0.10841924085980281, 0.14733923133462667, 0.17662556609138846, 0.5132024211343378, 9.112240690737963, 91.93227455019951, 89.12112459540367, 81.81812927126884, 78.56982797384262, 66.18639126420021, 74.93901640176773, 75.34277513623238, 112.94208437204361, 101.42104178667068, 21.278818286955357, 2.327810190618038, 1.6821654606610537, 2.258380791172385, 0.45948292245157063, 1.08494188869372, 0.7555234339088202, 0.15018556063296273, 0.17923990002600476, 1.014559690374881, 3.6204495280981064, 3.499027043581009, 7.691568648442626, 0.7756986888125539, 1.0418619378469884, 4.070322113111615, 77.55978137254715, 95.06168782711029, 88.79517808556557, 75.30203372240067, 90.2113164961338, 90.62553226947784, 94.64181035757065, 91.06318518519402, 89.99704599380493, 88.79868149757385, 88.03985461592674, 91.94208562374115, 93.908761292696, 87.64988154172897, 87.65517845749855, 88.62309291958809, 89.96847152709961, 89.86739695072174, 92.66780868172646, 87.63819336891174, 92.32574343681335, 81.80894136428833, 83.31464856863022, 81.69936284422874, 81.58996671438217, 91.95236787199974, 87.16002702713013, 88.50937262177467, 90.9985962510109, 88.18498402833939, 83.32842662930489, 87.68649637699127, 83.98101881146431, 87.70970553159714, 93.01229819655418, 88.58936592936516, 91.08686551451683, 88.42706143856049, 86.91137596964836, 85.85435628890991, 84.3474331498146, 79.11847293376923, 87.37349197268486, 84.82109293341637, 84.23739865422249, 84.02451887726784, 81.7771902680397, 79.1012142598629, 81.0226571559906, 72.92460009455681, 69.06819462776184, 69.52798515558243, 71.72482207417488, 69.39681619405746, 75.69972798228264, 72.73150205612183, 74.66185167431831, 78.05986493825912, 81.26509174704552, 78.0905368924141, 83.63433301448822, 79.18826758861542, 82.80023217201233, 79.74108472466469, 76.49102032184601, 77.88993045687675, 87.05851167440414, 80.28312563896179, 73.44241350889206, 71.09258159995079, 78.94830286502838, 72.4386365711689, 80.97967386245728, 86.71976745128632, 81.47813871502876, 75.04786536097527, 75.95958843827248, 76.12707585096359, 77.0033772289753, 75.13719096779823, 74.37142565846443, 72.90814697742462, 70.84781393408775, 70.16268789768219, 64.00754258036613, 62.00583279132843, 58.76423813402653, 57.80871860682964, 62.41371810436249, 62.77818314731121, 70.46199023723602, 67.76022121310234, 82.64589205384254, 93.13381567597389, 85.58553591370583, 57.89472319185734, 29.57088153809309, 3.438818324357271, 2.492860509082675, 0.878781279316172, 0.21403703751275316, 0.22344061260810122, 0.179151228221599, 0.9826496557798237, 1.7051757196895778, 1.7863191780634224, 0.44226450263522565, 0.25625204492826015, 5.280405655503273, 48.03121626377106, 76.3240496814251, 97.48902797698975, 65.90362563729286, 82.60447427630424, 84.87628877162933, 51.38060353696346, 30.478681325912476, 46.4197189360857, 62.484409511089325, 70.88053777813911, 85.5765987932682, 54.85666461288929, 0.1000625615415629, 0.22333530185278505, 0.25675076816696674, 0.164016759081278, 0.20964767929399386, 0.14264799712691456, 0.18692970770644024, 0.13815451558912173, 0.16769919195212424, 0.18310065614059567, 0.13842430111253634, 0.1213696287595667, 0.24150859855581075], [0.017772913597582374, 0.018827126950782258, 0.02961915459309239, 0.03691147911013104, 0.04786806501215324, 0.030010025220690295, 0.0980396376689896, 0.04343685708590783, 0.04250176214554813, 0.13517287792637944, 0.1199747622013092, 0.07284645515028387, 0.05297918040014338, 0.06809384532971308, 0.1292816354543902, 11.286203786730766, 68.01188930869102, 64.88737776875496, 62.085423320531845, 65.36956429481506, 46.634445413947105, 50.923727452754974, 57.65602000057697, 75.67693680524826, 16.7478122189641, 1.4742693537846208, 0.03260622477682773, 0.47391861502546817, 0.5449075635988265, 0.35450188850518316, 0.13392379885772243, 0.08189691638108343, 0.14730299968505278, 0.09193379577482119, 0.3936356323538348, 1.0348732816055417, 0.44062319851946086, 0.5767105508130044, 0.24614249443402514, 0.23615612561115995, 22.99472451210022, 56.65786676108837, 52.08496034145355, 52.26958483457565, 69.0450918674469, 79.5054441690445, 88.37551340460777, 79.79107484221458, 80.15875831246376, 79.86362054944038, 75.28513222932816, 79.38713371753693, 77.94235244393349, 79.27509292960167, 77.36701771616936, 77.58112862706184, 77.43241980671883, 79.19577598571777, 83.12307044863701, 80.27180224657059, 79.14205446839333, 81.15251898765564, 68.50749671459198, 76.43156871199608, 79.09197315573692, 80.97104832530022, 79.11509111523628, 76.60865440964699, 79.73841726779938, 81.16033136844635, 81.94989860057831, 84.89333465695381, 80.2571502327919, 79.3720181286335, 79.47731047868729, 78.7127611041069, 81.05600416660309, 80.04473403096199, 75.85398450493813, 73.56045797467232, 72.78412163257599, 75.76475009322166, 76.72895595431328, 79.47561576962471, 77.83179357647896, 75.29576405882835, 77.51367464661598, 71.90198376774788, 74.43723812699318, 69.50821101665497, 67.0503281056881, 68.33876296877861, 62.606116980314255, 64.87872183322906, 66.10408008098602, 64.11838263273239, 60.913057029247284, 69.14257943630219, 69.73387330770493, 74.07013982534409, 70.22131875157356, 76.85273051261902, 79.49492633342743, 79.24899592995644, 74.7204901278019, 77.28325501084328, 72.68170952796936, 76.5604729950428, 75.97430124878883, 75.82247659564018, 69.4284000992775, 66.09525695443153, 65.06776168942451, 67.3153106868267, 80.7873509824276, 75.25812327861786, 74.20462980866432, 72.1404741704464, 68.77216011285782, 63.120670169591904, 65.9328080713749, 64.02897343039513, 64.5936231315136, 69.09949734807014, 65.29727697372437, 67.11729571223259, 56.810078993439674, 52.15365685522556, 37.60573089122772, 37.86745324730873, 44.83448579907417, 82.76142865419388, 67.60867774486542, 68.6508098244667, 86.42393812537193, 72.9834209382534, 40.065312311053276, 21.655243188142776, 5.632303822785616, 0.26318688062019646, 1.3118427945300937, 0.07252352443174459, 0.23032691184198484, 1.074426902923733, 1.2822801433503628, 0.15612741757649928, 0.08562470189644955, 0.06864086753921583, 0.035779009995167144, 0.08526083431206644, 7.609444130212069, 10.792869608849287, 47.54804939031601, 61.64001502096653, 46.59375719726086, 42.84445658326149, 73.14690336585045, 55.72030887007713, 99.06719729304314, 50.45159138739109, 35.145735293626785, 53.16411003470421, 54.69439052045345, 2.0403556153178215, 0.14355401101056486, 0.0824708266009111, 0.03394859180843923, 0.07357440554187633, 0.1323754561599344, 0.05526371875021141, 0.06251530678127892, 0.008485283306072233, 0.04265405084879603, 0.05560846118896734, 0.04148153544520028, 0.10138454919797368, 0.055346969165839255, 0.048909131219261326, 0.05341718111594673, 0.053150130406720564, 0.0340383211732842, 0.1330761771532707, 0.03833947885141242, 0.05884411002625711, 0.029443939092743676, 0.0644995276525151, 0.0276016279894975, 0.022353239401127212, 0.041650719140307046, 0.06514046122902073, 0.35469490627292544, 15.24248594418168, 76.48216679692268, 74.69944685697556, 74.37151685357094, 72.859076410532, 49.91906516253948, 26.6292579844594, 67.05655977129936, 88.74215573072433, 26.008888073265553, 1.2472938769496977, 0.024580832759966142, 0.6903671426698565, 1.0521402675658464, 0.4902818729169667, 0.18245562590891495, 0.2046379301464185, 0.19946624437579885, 0.12468063156120479, 1.044823641423136, 2.178572011180222, 1.787820691242814, 2.141960975714028, 0.07522065978264436, 0.38773217413108796, 38.03373612463474, 73.59907910227776, 66.14416033029556, 65.50446465611458, 83.05708318948746, 87.9368345439434, 93.00212994217873, 86.66877418756485, 83.50461557507515, 85.59103801846504, 80.81962645053864, 83.19918796420097, 80.94879671931267, 81.7401422560215, 85.04088073968887, 82.01631903648376, 83.50960850715637, 81.31365314126015, 86.65528491139412, 85.09082525968552, 82.76895985007286, 84.27554860711098, 71.26610308885574, 77.93887183070183, 82.39229366183281, 82.57205441594124, 80.88550731539726, 81.90943077206612, 81.26555532217026, 84.54944550991058, 83.27199965715408, 87.21057951450348, 81.44136428833008, 82.79534563422203, 79.94600012898445, 77.15093851089478, 80.81958845257759, 81.69201403856277, 81.2149116396904, 77.50909209251404, 74.57160651683807, 76.64020791649818, 80.24353176355362, 79.62520614266396, 76.8650570511818, 79.28437203168869, 78.61770540475845, 74.7185218334198, 78.89552369713783, 70.25131434202194, 66.34424239397049, 69.15653228759766, 65.50227597355843, 66.69921934604645, 68.61100316047668, 68.992700278759, 68.81765887141228, 67.6927824318409, 72.71389380097389, 74.39947575330734, 73.81965726613998, 76.29007950425148, 81.17527216672897, 80.46391993761063, 78.15224558115005, 77.83338189125061, 73.93194124102592, 79.34985771775246, 77.24649578332901, 78.41919645667076, 75.11762961745262, 71.32220327854156, 69.77469831705093, 66.87504351139069, 78.99832338094711, 78.37831065058708, 76.98692411184311, 76.57925918698311, 73.08141767978668, 68.12775269150734, 71.13757118582726, 69.71718460321426, 68.36609870195389, 71.50074049830437, 71.0861599445343, 69.00080144405365, 62.26505868136883, 56.67265556752682, 51.110248044133186, 44.538557678461075, 56.452236995100975, 88.58315706253052, 76.17152586579323, 75.42409837245941, 77.81059831380844, 89.97442960739136, 69.23911705613136, 34.19134050607681, 9.853432718664408, 0.4235922748921439, 0.931055786786601, 0.08518657501554117, 0.17283019318711013, 0.6631714676041156, 1.6459561348892748, 0.5252439749892801, 0.3811093373224139, 0.08829186932416633, 0.3147274337243289, 0.024830090478644706, 8.155087251216173, 23.067342415452003, 70.61836704611778, 74.96483981609344, 58.011464327573776, 43.678371235728264, 27.38192919641733, 40.253896191716194, 89.43698644638062, 57.61149778962135, 49.721855744719505, 61.74948714673519, 69.22230675816536, 3.424294078722596, 0.14296593319159, 0.06611916105612181, 0.014676551036245655, 0.05410905941971578, 0.06112557959568221, 0.12182239821413532, 0.08855032225255854, 0.04315179816330783, 0.02380410471232608, 0.06147152431367431, 0.033579811206436716, 0.029848997728549875, 0.21330887189833447, 0.08257700566900894, 0.14856729278108105, 0.3032463794806972, 0.14889233862049878, 0.24397168279392645, 0.19614896300481632, 0.21740046562626958, 0.10936608770862222, 0.2707384410314262, 0.19394006434595212, 0.20135609374847263, 0.23467505117878318, 0.2720102743478492, 0.47920671408064663, 21.50170672684908, 92.33544051647186, 83.84133070707321, 83.06279808282852, 83.40162590146065, 67.82306984066963, 72.75949135422707, 82.68237009644508, 106.4425939321518, 33.186081647872925, 1.9138727523386478, 0.21118959499290213, 0.9901388757862151, 2.590323379263282, 1.639949488453567, 0.98328344989568, 0.3956559958169237, 0.26754266407806426, 0.4919822816736996, 3.551356648094952, 4.7678126860409975, 3.326854007318616, 5.78970942646265, 0.39438410312868655, 0.4831985186319798, 46.90916307270527, 83.80739852786064, 71.12752452492714, 74.19142171740532, 89.47262093424797, 92.72340729832649, 95.65808102488518, 92.78740346431732, 89.05234828591347, 89.45044532418251, 86.66716307401657, 88.81584897637367, 89.40062239766121, 89.79725271463394, 91.58524677157402, 85.81058263778687, 84.94550585746765, 87.17069685459137, 89.94352206587791, 87.90911123156548, 88.2280433177948, 88.32070514559746, 77.08939701318741, 81.41741037368774, 85.3268837928772, 87.63622507452965, 85.67727819085121, 83.69703724980354, 85.34130021929741, 88.07341441512108, 88.34699213504791, 92.7074633538723, 85.11148855090141, 84.61932376027107, 82.2340777516365, 80.44682085514069, 86.93514749407768, 86.55472710728645, 87.8628297150135, 81.56925782561302, 77.45973274111748, 80.96037089824677, 84.25317540764809, 84.83870878815651, 81.22599944472313, 83.59576508402824, 84.15572583675385, 78.84127020835876, 79.60925459861755, 73.79302829504013, 70.25792598724365, 71.22770234942436, 64.39907357096672, 66.61287277936935, 68.93313467502594, 71.55380845069885, 67.71557360887527, 70.14561161398888, 74.4974572956562, 78.23970168828964, 76.73616036772728, 81.14269271492958, 82.64571726322174, 85.05523636937141, 78.95366817712784, 80.63841417431831, 76.04341194033623, 84.54879954457283, 82.89558425545692, 81.36253371834755, 78.20609629154205, 71.36577174067497, 67.60606348514557, 68.28968480229378, 87.37365156412125, 84.45768043398857, 80.70213675498962, 81.44800633192062, 79.53233912587166, 73.32752287387848, 76.80388033390045, 78.02132740616798, 75.05465939640999, 76.13580778241158, 72.96651184558868, 73.45532521605492, 67.07516357302666, 65.76154366135597, 58.64790357649326, 55.542041435837746, 59.339580461382866, 77.25494652986526, 77.0023512840271, 76.21399998664856, 80.56922748684883, 90.62328279018402, 79.00719210505486, 42.600076496601105, 12.722879145294428, 1.6150195011869073, 2.781846639700234, 0.139882784569636, 0.4890398739371449, 1.6703421575948596, 4.658207092434168, 1.2885013595223427, 1.3073994079604745, 0.3775030339602381, 0.36425881495233625, 0.22108689125161618, 10.494891498237848, 42.168051078915596, 89.35358092188835, 97.12106332182884, 68.60824450850487, 70.17723351716995, 109.61311340332031, 82.46304586529732, 115.86239486932755, 60.24084649980068, 51.19053393602371, 74.3452450633049, 81.88093990087509, 4.872011644765735, 0.2303790402947925, 0.2729830815223977, 0.10994204625603743, 0.12358477630186826, 0.23753061279421672, 0.178184729302302, 0.13452079729177058, 0.15932421869365498, 0.11716205219272524, 0.1399466983275488, 0.12020380381727591, 0.20624208234949037], [0.1135563499701675, 0.06915040386957116, 0.002473344661666488, 0.04069504444487393, 0.028440336500352714, 0.04418552452989388, 0.06260574489715509, 0.052164513763273135, 0.06999188801273704, 0.029819389746990055, 0.07734076047199778, 0.031052989470481407, 0.12979868974070996, 0.08426130982115865, 0.13969951862236485, 18.732844702899456, 74.93428945541382, 55.19625999033451, 78.71615812182426, 73.38327348232269, 53.34009759128094, 57.812674194574356, 80.19516035914421, 56.041159853339195, 2.2270056372508407, 0.10921492706984282, 0.24851085094269365, 0.26005519554018974, 0.5606855044607073, 0.302191223599948, 0.2389706316171214, 0.22123429662315175, 0.13983378798002377, 0.20341329742223024, 1.6934632044285536, 1.7187205678783357, 0.685789753915742, 0.9088616527151316, 0.2806730376323685, 10.889077596366405, 61.432800740003586, 57.21051290631294, 61.35205887258053, 79.72808182239532, 83.38260412216187, 87.41068437695503, 87.47035637497902, 82.11363941431046, 77.41971328854561, 77.05408170819283, 74.89017382264137, 75.52058279514313, 73.34260046482086, 69.98168081045151, 72.16239139437675, 69.23249021172523, 75.11790320277214, 76.10474064946175, 77.38062098622322, 75.9476874768734, 74.74309891462326, 70.42779207229614, 62.967219203710556, 78.05671870708466, 85.84989532828331, 78.76544147729874, 81.80318847298622, 85.54850310087204, 84.11280333995819, 82.9166579246521, 81.55656650662422, 75.8535285294056, 75.99512413144112, 73.65123510360718, 74.43222999572754, 74.29422900080681, 79.53046202659607, 78.03922444581985, 77.51139476895332, 76.0239265859127, 72.74692922830582, 69.476338326931, 76.62633866071701, 75.31099364161491, 70.20550400018692, 73.14681217074394, 70.39442986249924, 71.66982382535934, 71.33277431130409, 62.157000079751015, 64.24301594495773, 64.13149952888489, 65.02623751759529, 72.6494188606739, 74.78681176900864, 72.17573627829552, 73.18569928407669, 71.50858327746391, 73.34301844239235, 72.83614084124565, 69.6567602455616, 65.78995853662491, 71.20551154017448, 71.09619900584221, 73.90743255615234, 71.59280955791473, 74.92444038391113, 76.41390725970268, 73.06393101811409, 67.52955079078674, 74.33962136507034, 73.43691140413284, 75.0580108165741, 61.487278416752815, 65.57396292686462, 74.63075414299965, 74.3605886399746, 74.84797328710556, 69.94062021374702, 74.20432582497597, 65.73812171816826, 63.90037313103676, 60.6024768948555, 63.819703459739685, 62.93237887322903, 60.188952684402466, 61.955641284585, 56.25209413468838, 42.31476120650768, 42.88302071392536, 33.8464368134737, 56.93720877170563, 87.59452611207962, 79.18974190950394, 81.80688187479973, 80.9104871749878, 67.25131452083588, 28.87673668563366, 14.473056681454182, 1.1852023587562144, 0.15987747494364157, 0.07512660740758292, 0.03364700525708031, 0.577643282013014, 0.544110496994108, 0.19881177402567118, 0.10063806737889536, 0.0781482171441894, 0.10246297882986255, 0.051330514179426245, 0.805311924777925, 3.730016886256635, 16.60343136638403, 51.807221844792366, 52.75949254631996, 28.168703578412533, 49.39808651804924, 35.53219735622406, 46.847727969288826, 44.337024092674255, 56.651631295681, 52.46586710214615, 70.13821721076965, 10.190722569823265, 0.41125522751826793, 0.06828103723819368, 0.073209654801758, 0.04363497340818867, 0.17027120862621814, 0.04793626838363707, 0.03687951109895948, 0.09598641190677881, 0.04145924875047058, 0.07266897053341381, 0.05260698962956667, 0.018575091744423844, 0.05696253931091633, 0.01929028090671636, 0.05945232973317616, 0.044313827020232566, 0.03350587845488917, 0.08853778737829998, 0.023632837437617127, 0.03631477753515355, 0.02458003680658294, 0.0407450021157274, 0.03850629509543069, 0.015592173876939341, 0.05514467826287728, 0.0273469563035178, 0.05917909322306514, 24.489718191325665, 81.70476615428925, 70.25566130876541, 71.07457056641579, 84.94907766580582, 37.322794273495674, 48.3499051630497, 98.62135961651802, 67.81228601932526, 2.8154005017131567, 0.07837154422304593, 0.12098487713956274, 0.22665314725600183, 0.805097414413467, 1.2617035349830985, 0.30963823024649173, 0.4143926716642454, 0.06122254861111287, 0.4237319767707959, 3.4589933417737484, 2.5030584493651986, 2.0397512102499604, 1.1883748322725296, 0.325598472263664, 17.48614490032196, 78.47306236624718, 68.98975163698196, 72.73021772503853, 89.72977593541145, 88.30906257033348, 90.68252921104431, 91.19637563824654, 86.00741967558861, 81.96150317788124, 80.75687661767006, 80.76303988695145, 83.32192897796631, 79.80028554797173, 76.71442553400993, 79.28293570876122, 75.12650594115257, 79.08812776207924, 80.76923355460167, 79.85571697354317, 80.04583597183228, 77.4974875152111, 73.13538998365402, 66.17577463388443, 82.95874446630478, 86.20703056454659, 83.90153467655182, 85.04175469279289, 88.83866295218468, 86.05811655521393, 83.72245788574219, 83.68375316262245, 79.61559265851974, 78.64118054509163, 79.66439723968506, 76.94496676325798, 75.9929658472538, 76.63304150104523, 79.76751610636711, 78.17505195736885, 79.56868037581444, 75.8278951048851, 72.34882459044456, 79.23245921730995, 77.46398851275444, 73.3254861831665, 76.40613287687302, 71.89312264323235, 74.44602325558662, 70.88759779930115, 66.24747678637505, 65.77672004699707, 64.6818619966507, 66.15044519305229, 76.09049901366234, 77.6773090660572, 77.84865707159042, 75.4958613216877, 74.72168326377869, 72.30948150157928, 75.81850960850716, 70.288757532835, 70.13934955000877, 74.18028831481934, 71.82385995984077, 73.25227171182632, 76.0558220744133, 74.94794592261314, 75.84364905953407, 73.88448938727379, 70.09005099534988, 72.8705669939518, 77.47043296694756, 78.58577951788902, 69.58829551935196, 64.05557960271835, 73.43206286430359, 75.83357959985733, 77.02432930469513, 71.5188655257225, 76.985282599926, 70.88973328471184, 70.18289521336555, 67.06163629889488, 68.13868090510368, 67.07409963011742, 67.21290618181229, 63.76456081867218, 61.21935099363327, 47.61526398360729, 59.0303910523653, 44.46721650660038, 55.63476786017418, 82.73900985717773, 75.19734933972359, 81.57962366938591, 79.26066890358925, 89.11930829286575, 54.13591168820858, 21.403970271348953, 2.677207854576409, 0.20674421946750954, 0.07673489337321371, 0.03759891194931697, 1.349153348710388, 0.181028550141491, 0.36878036451525986, 0.17858700302895159, 0.11908061525900848, 0.13426299003185704, 0.0851243756187614, 0.43693493236787617, 3.925926061347127, 33.9382740855217, 67.78398513793945, 66.46382197737694, 38.527633622288704, 50.59416353702545, 25.8232756331563, 64.58927616477013, 44.80428121984005, 55.73561444878578, 61.2858322262764, 81.80077940225601, 12.4517722427845, 0.37184884829912335, 0.32606234424747527, 0.03013852438016329, 0.12249502149643376, 0.14375501428730786, 0.05076683817605954, 0.020069730780960526, 0.06704246698063798, 0.1016183479805477, 0.05423258618975524, 0.03695987084938679, 0.0288952173650614, 0.20993806683691218, 0.3308749938150868, 0.20122486719628796, 0.13501438486855477, 0.13303190062288195, 0.207014390907716, 0.13027857727138326, 0.2575805189553648, 0.22164148336742073, 0.09965043951524422, 0.29856612905859947, 0.1716974680311978, 0.2967330242972821, 0.1282362759229727, 0.2620552241569385, 30.881455913186073, 95.58609768748283, 73.10516640543938, 92.92171105742455, 88.83952170610428, 79.90435436367989, 80.59224665164948, 107.84659579396248, 87.56322339177132, 3.6185930902138352, 0.21736276452429593, 0.46750791370868683, 0.44065401249099523, 2.1799703361466527, 1.9005720410495996, 0.7611796085257083, 0.7706650870386511, 0.2828763553407043, 1.437009028159082, 6.217898949980736, 4.777141660451889, 5.224167248234153, 2.8785013407468796, 0.47881278209388256, 22.888761498034, 88.81702691316605, 79.00888681411743, 79.45448890328407, 91.55593514442444, 93.53022560477257, 97.43401452898979, 98.96950453519821, 91.81807547807693, 85.42415857315063, 85.39667844772339, 84.76537272334099, 88.31454947590828, 83.52252021431923, 83.35426524281502, 84.77998673915863, 79.87431317567825, 83.50677385926247, 84.97473388910294, 84.44683581590652, 84.39692929387093, 83.02379697561264, 78.71662929654121, 69.99977543950081, 87.58435785770416, 88.24641153216362, 86.68241545557976, 85.52447319030762, 94.29245710372925, 88.64765480160713, 87.26483300328255, 88.65258693695068, 84.5136134326458, 84.32892814278603, 82.63130843639374, 77.07000285387039, 78.45604687929153, 80.81673100590706, 83.71228963136673, 85.57497248053551, 85.8690918982029, 80.97883030772209, 78.00472229719162, 83.39985519647598, 82.58698761463165, 77.43910744786263, 81.3935324549675, 74.84628617763519, 75.83756938576698, 75.49765482544899, 67.63792857527733, 67.8485056757927, 67.57061138749123, 67.91529849171638, 78.66711795330048, 80.77202260494232, 82.95280158519745, 80.71257099509239, 75.8486419916153, 75.72350710630417, 78.93047422170639, 73.40015217661858, 72.7923671901226, 74.54157292842865, 74.49554979801178, 75.0239646434784, 77.08444207906723, 75.27835339307785, 81.98821574449539, 75.57370394468307, 76.07343792915344, 78.80724683403969, 80.62687039375305, 79.15762603282928, 68.58027040958405, 67.9418970644474, 80.38370624184608, 82.26182386279106, 81.74158617854118, 77.48357266187668, 83.67584198713303, 74.78269279003143, 76.696817278862, 72.3635981976986, 74.28543627262115, 72.60007470846176, 69.94929134845734, 66.52220204472542, 69.02456536889076, 56.135144010186195, 67.46987119317055, 47.74763748049736, 64.38770458102226, 90.02070352435112, 77.10816040635109, 82.22072526812553, 79.4727735221386, 93.44457060098648, 62.38926641643047, 26.150004900991917, 3.403151063248515, 0.38430268003139645, 0.5300110566895455, 0.15023391897557303, 2.6538300840184093, 1.2365689524449408, 1.4571017562411726, 1.3445724570192397, 0.19252392783528194, 0.18346772238146514, 0.18364430899964646, 0.7102514163125306, 8.753824923187494, 55.748890936374664, 84.45644170045853, 85.24606972932816, 48.19876067340374, 80.61668694019318, 55.129668563604355, 56.77223302423954, 56.836954951286316, 78.40762987732887, 70.48026725649834, 99.07393053174019, 14.80484252795577, 0.3680319234263152, 0.6334922695532441, 0.1372765252017416, 0.2198016399051994, 0.27819058333989233, 0.14637163403676823, 0.14774013950955123, 0.2325207894318737, 0.16612007981166244, 0.15523183828918263, 0.1384770529693924, 0.15127887774724513], [0.0317587552126497, 0.08915005179005675, 0.03884658835886512, 0.06198995157319587, 0.03228011024475563, 0.03278165735537186, 0.011121890020149294, 0.016367844364140183, 0.022383274117601104, 0.023228788122651167, 0.1182430719200056, 0.14203225204255432, 0.015066207324707648, 0.1185273144801613, 0.12379392093862407, 15.811095982789993, 67.79923751950264, 60.26370607316494, 72.59965673089027, 39.640221521258354, 35.76287917792797, 47.7118282020092, 84.56736534833908, 13.61964337527752, 0.5511293734889477, 0.10595298765110783, 0.25649027433246374, 0.03428088100918103, 0.5938143830280751, 0.4973082896322012, 0.20776277262484655, 0.3311931970529258, 0.5857500282581896, 0.815115220611915, 1.8359231413342059, 0.5840316892135888, 0.7940068782772869, 0.09165158669929951, 2.5111125921830535, 54.40786309540272, 54.43942800164223, 63.982684314250946, 72.83927947282791, 83.83146643638611, 81.94528564810753, 78.9160729944706, 81.65309652686119, 80.77609598636627, 77.30384230613708, 77.80204117298126, 82.1787679195404, 81.74251332879066, 82.79940381646156, 72.6195752620697, 71.44410833716393, 72.77154430747032, 72.85183399915695, 79.18185353279114, 73.25543314218521, 74.06836912035942, 69.2652140557766, 67.50802114605904, 69.97345045208931, 78.01741361618042, 84.28304180502892, 85.13976663351059, 85.75293973088264, 77.82622307538986, 75.4109662771225, 78.3916175365448, 79.68395099043846, 77.90244698524475, 78.28491166234016, 75.25156483054161, 73.18259105086327, 71.20292767882347, 76.15951851010323, 75.09850904345512, 76.64263218641281, 71.66425332427025, 70.99900022149086, 77.92611211538315, 77.20560997724533, 68.44281658530235, 74.42178815603256, 70.13735085725784, 67.54797980189323, 69.34551894664764, 65.06254836916924, 61.55231572687626, 64.36649411916733, 69.28165197372437, 69.68259885907173, 74.21043589711189, 72.74015799164772, 70.69979667663574, 69.17127549648285, 72.33765318989754, 71.3137449324131, 75.57419791817665, 69.76671114563942, 67.03322902321815, 72.65343904495239, 71.53030291199684, 73.35705488920212, 72.04704478383064, 74.83955293893814, 77.6628090441227, 77.34040394425392, 75.22926762700081, 66.7243055999279, 69.25804764032364, 70.3368629515171, 69.41140741109848, 61.34461887180805, 63.911217749118805, 66.6201151907444, 72.95621439814568, 69.02570530772209, 68.05780604481697, 67.95146495103836, 64.99478280544281, 60.13704366981983, 59.96335878968239, 59.38666373491287, 58.14933232963085, 57.56765574216843, 60.94289682805538, 45.59983693063259, 42.02469617128372, 42.411807999014854, 25.38331814110279, 56.29095084965229, 67.87212520837784, 82.54540264606476, 83.73289972543716, 76.08551368117332, 50.02885267138481, 21.764027550816536, 7.596128219738603, 0.12887413700809702, 0.20186482113786042, 0.48039216140750796, 2.5817367900162935, 0.35901607596315444, 0.2556050999555737, 0.0340266137936851, 0.10313785081962124, 0.03114465027465485, 0.06679469355731271, 0.028886925720144063, 0.7963871536776423, 0.3992294962517917, 33.84001515805721, 61.488942727446556, 26.104046367108822, 14.221091251820326, 38.812424540519714, 18.57688967138529, 49.83608901500702, 64.31499928236008, 44.90493021905422, 65.71921393275261, 10.835808254778385, 0.2576800261158496, 0.27743041631765664, 0.05465348411235027, 0.11291845919913612, 0.04985305400623474, 0.03420431363338139, 0.022370214173861314, 0.07595936389407143, 0.03946289747545961, 0.04227827179420274, 0.02884515022742562, 0.13735238753724843, 0.04566561932733748, 0.025354185891046654, 0.06933923592441715, 0.09595970943337306, 0.048311520513379946, 0.04468786202778574, 0.015570037467114162, 0.048178761426243, 0.012188825639896095, 0.06541614682646468, 0.062403754564002156, 0.04074109470820986, 0.03189210801792797, 0.045952355503686704, 0.07449608616298065, 19.59353081882, 78.89336541295052, 64.68730330467224, 93.19081261754036, 59.15304847061634, 29.62185200303793, 52.667716071009636, 98.15592259168625, 19.54801496118307, 0.5640752194449306, 0.07163797155953944, 0.3701291437027976, 0.07677264642552473, 1.426024530082941, 0.8909934083931148, 0.7536303042434156, 0.9854154917411506, 1.5537704690359533, 2.969492683187127, 4.8798624984920025, 1.1787238251417875, 0.628546834923327, 0.3342154301935807, 4.127956470474601, 67.94075712561607, 65.9752593934536, 76.75679326057434, 83.10958117246628, 89.45874407887459, 84.90883022546768, 86.16169899702072, 87.62926384806633, 86.30930587649345, 81.91159665584564, 82.53281772136688, 84.80419144034386, 86.01717755198479, 85.68218752741814, 80.62955304980278, 75.02310588955879, 77.66150951385498, 77.22894832491875, 82.9655309021473, 74.99994993209839, 78.26823815703392, 69.33000057935715, 74.07251089811325, 77.40660399198532, 80.53490772843361, 84.2242893576622, 87.17644974589348, 87.70345866680145, 81.74251332879066, 82.25348711013794, 81.48808658123016, 79.06603574752808, 83.39840367436409, 80.62490969896317, 81.14289790391922, 79.04820710420609, 75.66465586423874, 75.57495787739754, 77.38460317254066, 78.12832206487656, 75.43473780155182, 76.7138859629631, 81.01647108793259, 78.85805770754814, 72.76652857661247, 75.33536553382874, 68.29183548688889, 68.50872784852982, 69.14403095841408, 64.80639651417732, 63.934525698423386, 67.42332369089127, 71.2420503795147, 73.61307755112648, 73.7636786699295, 74.13383960723877, 72.17404156923294, 73.00698727369308, 74.92953971028328, 74.46340352296829, 73.31632867455482, 74.64353665709496, 71.21339231729507, 75.01889571547508, 72.8920966386795, 73.9338943362236, 75.68675547838211, 75.2760811150074, 77.09338679909706, 79.52433675527573, 77.57197871804237, 70.01787006855011, 69.90126192569733, 74.75954443216324, 73.44220072031021, 68.55265349149704, 65.83240985870361, 66.39779672026634, 75.47677114605904, 74.37087088823318, 73.39901983737946, 72.91214436292648, 72.10578203201294, 67.81718775629997, 68.51343959569931, 65.9846068918705, 64.70299646258354, 63.14297117292881, 61.89881533384323, 52.88315691053867, 47.62052670121193, 51.89055897295475, 35.085861906409264, 57.69630923867226, 65.12060925364494, 75.52652567625046, 80.65751194953918, 80.71354374289513, 79.77108031511307, 34.484973549842834, 11.22886961326003, 0.31842555559705943, 0.15912838076474145, 0.537407003575936, 2.0341966208070517, 0.7502319803461432, 0.48589773941785097, 0.155361803190317, 0.11970228268182836, 0.01751057552610291, 0.07886289051384665, 0.0605929550511064, 1.1383071751333773, 3.0199727369472384, 50.730013847351074, 72.67463430762291, 32.81036540865898, 24.235566928982735, 29.059685468673706, 22.177451066672802, 57.6586988568306, 60.60427039861679, 55.98847568035126, 74.0994742512703, 13.71132580563426, 0.3295700903981924, 0.485202792333439, 0.0653648644220084, 0.07529937196522951, 0.0260887785043451, 0.08703387706191279, 0.019324618224345613, 0.03622346368501894, 0.05048131170042325, 0.05976263651973568, 0.035030884318985045, 0.06587164738448337, 0.16863204189576209, 0.14824790210695937, 0.15784528164658695, 0.1420754153514281, 0.22063142037950456, 0.08483009922201745, 0.17120391014032066, 0.13179969799239188, 0.19460105075268075, 0.15889930946286768, 0.24107595614623278, 0.17922047059983015, 0.14335864805616438, 0.35976327024400234, 0.14975610945839435, 23.14534842967987, 91.41008377075195, 75.15274733304977, 94.07821699976921, 54.37866546213627, 55.22551082074642, 63.360201716423035, 113.17705616354942, 23.797374442219734, 0.740826060064137, 0.16027384117478505, 0.48555088927969337, 0.21803218172863126, 2.9856002563610673, 1.9240256887860596, 1.1298356484621763, 2.0427195634692907, 2.5452326238155365, 5.772868730127811, 7.44681048206985, 3.707167049869895, 3.1450662994757295, 0.39438757637981325, 5.753588089719415, 78.93353685736656, 78.60328897833824, 84.88959565758705, 87.37520948052406, 93.78698542714119, 90.9182457625866, 90.65450191497803, 92.11081176996231, 92.75224775075912, 85.37254214286804, 86.11776575446129, 89.74712580442429, 91.99594393372536, 91.15097567439079, 84.69310820102692, 85.38849368691444, 83.09288486838341, 82.40252271294594, 86.55709818005562, 78.5136365890503, 82.79612839221954, 77.4261425435543, 76.3323712348938, 81.51685863733292, 87.58684292435646, 89.73336294293404, 91.61671668291092, 96.07956200838089, 86.25608593225479, 83.99990379810333, 85.52682906389236, 84.14081543684006, 87.04870820045471, 85.73860689997673, 84.75566804409027, 83.01250398159027, 77.47743219137192, 80.11438429355621, 79.91194635629654, 83.00038263201714, 82.00456246733665, 78.74288588762283, 83.65511029958725, 84.99335289001465, 77.8344838321209, 77.36949518322945, 72.26418793201447, 70.1407478749752, 73.67683053016663, 67.07504957914352, 65.98687157034874, 68.18357169628143, 73.51294532418251, 75.01387238502502, 78.27733486890793, 76.90752357244492, 76.79906979203224, 78.79069492220879, 79.24348622560501, 78.34510043263435, 78.61382961273193, 79.55155849456787, 76.28528416156769, 76.23833388090134, 74.84067767858505, 77.0346799492836, 77.24997639656067, 78.0363517999649, 78.63852828741074, 82.23644882440567, 80.47655045986176, 72.58609145879745, 74.2944797873497, 77.93878823518753, 75.53559198975563, 68.78947958350182, 69.4495801627636, 70.83074524998665, 79.89224821329117, 76.49216786026955, 75.37646412849426, 76.4296992123127, 75.08325666189194, 71.84861183166504, 72.44126603007317, 72.04162627458572, 71.20830819010735, 69.85767066478729, 70.34864231944084, 60.701241195201874, 59.54600438475609, 57.334941029548645, 42.36225485801697, 65.92370375990868, 73.69809418916702, 80.50250306725502, 82.83387556672096, 82.13354274630547, 86.85749486088753, 43.32637332379818, 14.100203588604927, 0.6619614700321108, 0.47727030236274004, 1.1575861531309783, 6.772720953449607, 0.7216888025868684, 1.029486833140254, 0.2659605536609888, 0.5697863129898906, 0.12920112727442756, 0.22995799023192376, 0.22372487001121044, 2.03245441429317, 9.309761691838503, 75.48424154520035, 85.06034329533577, 49.971186965703964, 34.220591336488724, 61.74710087478161, 29.468482732772827, 63.451271429657936, 79.11002978682518, 57.60453276336193, 93.2037091255188, 17.19326801598072, 0.40459240379277617, 0.6513881217688322, 0.15462415292859077, 0.18754411692498252, 0.11312246817396954, 0.11742219721782021, 0.12565297860419378, 0.12193992472020909, 0.20891007356112823, 0.10487183433724567, 0.13871431758161634, 0.23583029309520498], [0.06529186677653342, 0.11616493226028979, 0.03498626268992666, 0.041895345857483335, 0.05219912753091194, 0.021771672072645742, 0.04965205072949175, 0.07592463880428113, 0.02522504477383336, 0.02223067742306739, 0.04302656445361208, 0.015045777854538755, 0.06413779745344073, 0.07874993563746102, 0.09692714345874265, 8.566354382783175, 63.61688934266567, 69.03536438941956, 33.20798747241497, 36.314962953329086, 43.40559907257557, 66.59059837460518, 70.08815109729767, 2.2496205987408757, 0.1876128843287006, 0.19026321242563426, 0.2791725634597242, 0.12803714285837486, 0.26531384617555887, 0.2679471345618367, 0.2424765075556934, 0.09004654391901568, 0.29953148507047445, 0.6620541494339705, 2.2778675705194473, 1.1494181351736188, 0.457427054643631, 0.9183109737932682, 32.57860444486141, 54.68044526875019, 67.44794636964798, 78.04531171917915, 86.33926346898079, 78.90690788626671, 85.76519027352333, 84.00035977363586, 84.36494261026382, 81.0613314807415, 81.42581552267075, 80.7454240322113, 80.68094909191132, 79.32171642780304, 79.62313905358315, 79.17056053876877, 69.7761270403862, 72.90997847914696, 77.70587593317032, 74.88990023732185, 69.55919668078423, 65.23480072617531, 63.94098535180092, 73.12349662184715, 75.66226959228516, 78.75396609306335, 83.02185907959938, 82.05850437283516, 84.85515430569649, 79.21936511993408, 80.38675367832184, 76.99894666671753, 76.87459453940392, 76.95963397622108, 78.30369785428047, 71.03284880518913, 73.143430352211, 68.74371483922005, 71.9782380759716, 76.93149268627167, 75.23132711648941, 73.84284362196922, 75.72303593158722, 77.7358715236187, 73.45930740237236, 73.10131341218948, 71.01966351270676, 62.238319516181946, 68.98577705025673, 66.15064278244972, 65.28245776891708, 62.116843834519386, 68.93415302038193, 66.9511230289936, 69.42373394966125, 68.22824209928513, 70.57520136237144, 70.78434973955154, 74.00294423103333, 67.12374776601791, 70.65555185079575, 70.57171314954758, 70.46515926718712, 62.60474905371666, 65.24916395545006, 71.93390965461731, 72.28801265358925, 68.9981035888195, 68.536496758461, 71.61379963159561, 75.58639526367188, 75.2963188290596, 76.20646119117737, 72.40868657827377, 68.39803978800774, 64.55621793866158, 70.12947767972946, 67.50727638602257, 69.04728814959526, 65.4500363767147, 72.61138290166855, 74.60079655051231, 75.5204764008522, 68.19642260670662, 63.63713465631008, 57.53434292972088, 57.805709168314934, 52.545320838689804, 52.93856553733349, 54.879812970757484, 58.416898772120476, 47.03981526196003, 39.99503128230572, 32.79755249619484, 37.23771683871746, 53.04254695773125, 63.19922335445881, 82.45807573199272, 74.99737367033958, 69.83430191874504, 26.753317527472973, 16.846090145409107, 1.2875299178995192, 0.1705242512980476, 0.31922475958708674, 0.6693457800429314, 0.7530918612610549, 0.7991204538848251, 0.3363217640435323, 0.048512928260606714, 0.35393037542235106, 0.05013741902075708, 0.08007565629668534, 0.04784630153153557, 0.7328112807590514, 5.745140668004751, 54.60839353501797, 48.63016292452812, 51.77575573325157, 24.20310527086258, 34.29734341800213, 29.478453397750854, 52.062864527106285, 49.562853276729584, 50.028563886880875, 2.495160810649395, 0.10614833576255478, 0.07996843080036342, 0.02765836146863876, 0.014030637648829725, 0.06538187444675714, 0.07493785698898137, 0.04103280327399261, 0.045840135353500955, 0.12231962973601185, 0.053111976594664156, 0.017088349159166683, 0.04920921492157504, 0.06953522970434278, 0.03825891872111242, 0.02100102778058499, 0.05414987012045458, 0.0045627438612427795, 0.018266720107931178, 0.10118503763806075, 0.0783739636244718, 0.06862546797492541, 0.012838648290198762, 0.028347772131382953, 0.06069337876397185, 0.07482218585209921, 0.07455182145349681, 0.1004209669190459, 10.937919225543737, 77.65289917588234, 75.80292284488678, 58.00139866769314, 38.68573173880577, 33.73900517821312, 83.80669936537743, 83.66834878921509, 3.8620322523638606, 0.21303881920175627, 0.06484897530754097, 0.15309540292946622, 0.19276226114016026, 0.6481410772539675, 0.8227686036843807, 0.7475078233983368, 0.20116653438890353, 0.30129993392620236, 2.1718575339764357, 2.799789276905358, 3.930920180864632, 0.1733092198264785, 1.8126226728782058, 40.13571113348007, 65.65564334392548, 73.62940907478333, 84.3451988697052, 90.39418548345566, 91.60748317837715, 90.28133913874626, 89.79227498173714, 89.08252626657486, 84.55664992332458, 86.22495800256729, 82.48633861541748, 83.8083104789257, 83.46686840057373, 85.58907732367516, 83.26781988143921, 78.5337071120739, 77.62726575136185, 80.42757868766785, 80.4724694788456, 73.35981354117393, 68.94182860851288, 68.25364753603935, 78.23980808258057, 80.3194060921669, 82.82484725117683, 86.2720374763012, 83.29342290759087, 86.20297998189926, 82.99408257007599, 84.29094538092613, 79.34299528598785, 78.94628137350082, 78.93927454948425, 79.37666147947311, 76.64993539452553, 77.62711375951767, 73.5366028547287, 72.92915984988213, 74.13938730955124, 74.11564618349075, 76.10175400972366, 79.6373350918293, 78.55996370315552, 75.2621890604496, 80.90297877788544, 70.68525865674019, 63.24699819087982, 70.54006844758987, 67.90376231074333, 66.731076836586, 65.01200348138809, 71.06945604085922, 68.88013511896133, 72.22574919462204, 71.5166312456131, 71.7768868803978, 71.53197482228279, 74.53363135457039, 71.66216343641281, 72.33782038092613, 73.19011464715004, 72.11194530129433, 69.92387071251869, 68.95589545369148, 73.62610325217247, 73.51888820528984, 74.20901477336884, 71.80328026413918, 74.7816364467144, 76.38977855443954, 75.80441236495972, 75.40797963738441, 74.15156185626984, 72.56469860672951, 71.09145686030388, 72.9664434492588, 71.65115162730217, 69.83177125453949, 67.27345213294029, 74.64368864893913, 79.69571515917778, 77.55778267979622, 72.87405520677567, 71.05894580483437, 63.587015345692635, 63.22146736085415, 59.78197552263737, 62.17549368739128, 61.788533851504326, 60.55665135383606, 57.969263792037964, 44.3619279563427, 44.45103317499161, 45.291065499186516, 61.22120149433613, 64.56345275044441, 74.00306582450867, 75.88524162769318, 83.89882922172546, 54.01523396372795, 23.080679699778557, 2.4268943862989545, 0.13995113637065515, 0.6296148151159286, 1.0198289388790727, 0.7941654010210186, 1.3152196258306503, 0.35802961327135563, 0.10871460079215467, 0.18786248343531042, 0.04870361568464432, 0.06920561965671368, 0.24570438981754705, 0.5639466794673353, 14.20618750154972, 70.67942976951599, 53.87620322406292, 59.84215289354324, 30.926479697227478, 37.98484414815903, 38.918628841638565, 55.081099569797516, 55.37649191915989, 62.63204298913479, 3.9485438726842403, 0.19262521615019068, 0.03586266117054038, 0.012089304564142367, 0.07677974135731347, 0.04905813962977845, 0.015128843660932034, 0.04512988147325814, 0.07881969009758905, 0.07111078695743345, 0.008352265394933056, 0.02176322272134712, 0.022950499442231376, 0.1377363599021919, 0.3392023657215759, 0.13512722100131214, 0.1797967779566534, 0.20156735350610688, 0.14105640206253156, 0.1961800886783749, 0.2669672027695924, 0.1903311931528151, 0.10452275775605813, 0.1890173097490333, 0.18584666191600263, 0.25492959714028984, 0.3007661219453439, 0.31416954647284, 14.406846184283495, 90.06565511226654, 89.28788244724274, 48.9276147633791, 48.38534206151962, 67.59015753865242, 93.86342972517014, 92.62984111905098, 3.7800832372158766, 0.4792957421159372, 0.31710667011793703, 0.6817603076342493, 0.3600242984248325, 1.6556672262959182, 3.3680418971925974, 1.0740060755051672, 0.4153436596971005, 0.5496749421581626, 5.354129299521446, 6.462401105090976, 5.778794987127185, 1.027497521135956, 2.579801743850112, 48.756198361516, 77.27462187409401, 80.21165147423744, 91.06430992484093, 95.58716922998428, 96.69148117303848, 95.04425436258316, 97.51115798950195, 93.4535913169384, 89.61850270628929, 92.41321474313736, 88.06509286165237, 87.11135923862457, 87.29624971747398, 90.01706331968307, 88.85448530316353, 83.36144685745239, 87.37550586462021, 87.2671964764595, 84.8326975107193, 77.16071918606758, 74.15008753538132, 73.4051451086998, 77.9200628399849, 84.8369836807251, 85.82845687866211, 90.55461287498474, 87.85364180803299, 91.80205553770065, 86.86482086777687, 86.68243065476418, 83.07678893208504, 82.71124854683876, 84.12066131830215, 86.7880953848362, 81.06652200222015, 80.52236840128899, 76.09075739979744, 78.58593910932541, 81.80234491825104, 80.89326649904251, 80.54908856749535, 83.75366181135178, 82.91281253099442, 79.475007802248, 83.22508737444878, 73.96282598376274, 65.44064328074455, 72.76610299944878, 72.5472803413868, 71.17252930998802, 67.29951873421669, 75.67410975694656, 73.159549087286, 76.94888055324554, 75.79017832875252, 76.15618228912354, 75.7451431453228, 81.46558418869972, 75.01226887106895, 75.14859035611153, 75.35593003034592, 77.24015772342682, 71.53908804059029, 70.45062124729156, 76.37257307767868, 76.11716598272324, 75.94425246119499, 74.99831601977348, 77.53659501671791, 81.64216831326485, 81.60447433590889, 78.41883927583694, 77.75357097387314, 76.03160977363586, 71.52133539319038, 75.32808512449265, 76.29219219088554, 72.89249181747437, 68.61079797148705, 79.02741461992264, 81.14990472793579, 80.01179739832878, 75.48182487487793, 73.23336392641068, 68.58911633491516, 69.27974447607994, 67.08684414625168, 67.71788388490677, 67.71409168839455, 67.54946932196617, 63.42482104897499, 53.21389116346836, 48.528807163238525, 53.356714099645615, 63.85114297270775, 69.85257893800735, 79.44631934165955, 76.35767787694931, 88.63272920250893, 60.43652079999447, 28.172866255044937, 2.7602927712723613, 0.34952920221257955, 1.2472383049316704, 2.3103287536650896, 2.4975119344890118, 1.955202422104776, 0.9307904541492462, 0.16969680116744712, 0.5238672019913793, 0.14286954305134714, 0.18234253744594753, 0.4854670265922323, 2.1676250360906124, 24.362607412040234, 87.876455783844, 75.53956657648087, 80.54454401135445, 46.205041855573654, 54.68149021267891, 43.64981196820736, 65.64156129956245, 63.09013120830059, 77.19873234629631, 6.1005412973463535, 0.309402642888017, 0.21599516447167844, 0.12497012852691114, 0.1829463933245279, 0.17804020346375182, 0.16133612167323008, 0.17282584420172498, 0.16654990206006914, 0.2774302678881213, 0.11880328209372237, 0.18385212519206107, 0.19254840386565775], [0.10438455501571298, 0.008772758847044315, 0.05443802750960458, 0.054389453944168054, 0.03625405501225032, 0.09146468422841281, 0.10634025515173562, 0.057686864311108366, 0.04398766795929987, 0.05024259618949145, 0.11975956163951196, 0.0439963362441631, 0.13396616064710543, 0.109614766552113, 0.3583656280534342, 11.08528956770897, 60.920493230223656, 55.23684561252594, 50.01397266983986, 52.523403614759445, 43.939177840948105, 58.725244626402855, 20.203267000615597, 0.3771650599082932, 0.11793157769716345, 0.1660623704083264, 0.1867394507280551, 0.25332118500955403, 0.16049124591518193, 0.38311043463181704, 0.55499097565189, 0.21107013890286908, 0.4319117800332606, 0.36327140231151134, 2.4041378824040294, 1.103723212145269, 1.0111896274611354, 9.208257738500834, 46.17987960577011, 59.26731213927269, 70.33260717988014, 79.58732217550278, 79.93894010782242, 88.22998121380806, 84.88845571875572, 85.6382466852665, 82.54829049110413, 84.28239583969116, 80.05404353141785, 77.44554430246353, 78.39534893631935, 80.95815181732178, 80.67243754863739, 77.99139261245728, 78.21667492389679, 69.19459864497185, 67.89468839764595, 74.26287308335304, 66.69804140925407, 63.3676341176033, 66.02941408753395, 78.0924291908741, 77.48961433768272, 81.25820651650429, 78.68750765919685, 80.31250566244125, 79.59992229938507, 83.49432572722435, 76.74205765128136, 76.0306066274643, 77.26332128047943, 72.36055076122284, 71.52304530143738, 73.91655966639519, 70.32778903841972, 68.88693675398827, 72.18135997653008, 69.28051203489304, 75.80655544996262, 78.28186422586441, 76.83466628193855, 70.62499389052391, 74.88969504833221, 73.10851022601128, 65.34514680504799, 71.22320339083672, 70.95336467027664, 69.3323564529419, 67.63903051614761, 64.28133308887482, 62.83655561506748, 64.87406328320503, 68.95907208323479, 66.54133021831512, 64.83221232891083, 69.28334668278694, 68.54440793395042, 68.48034337162971, 65.17333522439003, 72.09372147917747, 73.31256687641144, 72.30495974421501, 68.49920555949211, 71.55821621417999, 72.9221910238266, 74.03091073036194, 72.31316730380058, 70.90309336781502, 73.2905812561512, 73.19271370768547, 72.67762094736099, 72.10798591375351, 71.95067435503006, 69.57397028803825, 68.8303729891777, 65.18041044473648, 70.4713149368763, 74.00589287281036, 66.5112966299057, 73.41854318976402, 77.20025226473808, 76.64638638496399, 70.59210285544395, 63.64167921245098, 55.51305279135704, 52.207648158073425, 49.332053661346436, 49.90594066679478, 49.28844340145588, 57.25243225693703, 41.87590375542641, 35.890970304608345, 44.2417898029089, 55.096241757273674, 56.99435010552406, 63.65260362625122, 78.70663583278656, 73.59325021505356, 44.59509864449501, 19.65131051838398, 8.482871912419796, 0.055210350910783745, 0.8220469986554235, 1.3886016444303095, 0.3801802871748805, 0.6993172655347735, 0.06775006768293679, 0.06878877014969476, 0.12597857363289222, 0.3055669565219432, 0.1064437253808137, 0.3311993717215955, 0.22683654678985476, 0.19752012536628172, 34.116085544228554, 60.409093871712685, 76.57185718417168, 34.76398877799511, 25.44940609484911, 43.48191037774086, 44.791551902890205, 60.6770820915699, 27.91899997740984, 0.24345795332919806, 0.10765873987111263, 0.036446167359827086, 0.09558535530231893, 0.03840788631350733, 0.08797333954134956, 0.035619028931250796, 0.05691400285286363, 0.0183327786726295, 0.034891431059804745, 0.06623489898629487, 0.09404504264239222, 0.022928142243472394, 0.0986928834754508, 0.04423562320880592, 0.04773686443513725, 0.04064349857799243, 0.07972410836373456, 0.08734207614907064, 0.02136407158104703, 0.04413579692482017, 0.07250372393173166, 0.034520271874498576, 0.05958147827186622, 0.05635942186927423, 0.14450158516410738, 0.060221799576538615, 0.4354454716667533, 13.389140143990517, 73.1402537226677, 68.07216167449951, 63.65439713001251, 27.52782616764307, 42.92110987007618, 79.82357829809189, 27.449751757085323, 0.5164340289775282, 0.03183865854225587, 0.11664884223137051, 0.19921887171221897, 0.31462979677598923, 0.10079701314680278, 0.2984254772309214, 0.6262020638678223, 0.6176449230406433, 1.5198791376315057, 0.911289663054049, 5.3415272757411, 0.5793337756767869, 1.2592139560729265, 14.919344633817673, 62.0466236025095, 71.78193300962448, 80.62910467386246, 87.19849616289139, 86.15075558423996, 93.09170633554459, 90.39596378803253, 91.51672884821892, 87.17071205377579, 89.11325141787529, 83.06621789932251, 81.9654093682766, 82.81329587101936, 84.60289344191551, 82.5920033454895, 82.01775535941124, 81.56986579298973, 78.94517943263054, 75.78077763319016, 79.23791572451591, 73.1121276319027, 69.46120753884315, 75.44913902878761, 81.96868479251862, 81.45044580101967, 85.2088013291359, 81.20524495840073, 82.24349364638329, 81.43441066145897, 86.29266276955605, 79.58230644464493, 81.55538097023964, 78.5864482820034, 75.68283408880234, 75.22181242704391, 79.0376740694046, 71.69590562582016, 74.47360217571259, 77.0323620736599, 74.05476585030556, 75.17659485340118, 79.08253446221352, 78.79990562796593, 75.67206546664238, 76.47750064730644, 74.19992566108704, 70.32857179641724, 75.00078588724136, 73.88241469860077, 73.80584120750427, 67.67890557646751, 67.05828487873077, 65.31575918197632, 69.94622871279716, 70.24971842765808, 68.59322011470795, 67.89866298437119, 69.65644866228104, 69.09694388508797, 70.18079772591591, 70.59819012880325, 73.75537991523743, 74.7169791162014, 75.90186193585396, 73.06057959794998, 74.38217908143997, 73.12807157635689, 73.96521225571632, 77.26994052529335, 74.93168279528618, 74.44426774978638, 72.98785910010338, 73.62828433513641, 73.58775570988655, 73.68762195110321, 74.25145849585533, 72.63470605015755, 70.51105320453644, 71.67020380496979, 75.90516775846481, 67.67987832427025, 70.65317317843437, 78.26060816645622, 77.11510643362999, 73.48051026463509, 71.21843844652176, 62.64785014092922, 62.82851904630661, 58.72921921312809, 57.63315662741661, 55.301635935902596, 58.331764340400696, 48.97084504365921, 43.95225293934345, 55.084477588534355, 62.66795106232166, 65.50127282738686, 65.146045088768, 71.5257203578949, 79.81692105531693, 72.55678743124008, 33.33702094852924, 11.705576833337545, 0.10276812026859261, 0.3945193224353716, 1.5223139757290483, 0.8941581042017788, 0.9768906491808593, 0.3378964529838413, 0.23047817638143897, 0.05765798363427166, 0.31184068706352264, 0.12753037473885342, 0.09993901621783152, 0.2580958663020283, 0.16215856972848997, 45.612866431474686, 72.11729541420937, 87.44541451334953, 42.81431280076504, 29.262742772698402, 40.58825924992561, 48.524870574474335, 66.13900020718575, 33.483271300792694, 0.22131850069854409, 0.052440392319113016, 0.038785899232607335, 0.08925667614676058, 0.0326351796684321, 0.04001237990451045, 0.0721847933891695, 0.04277987085515633, 0.14937172149075195, 0.10259539281832986, 0.012164592662884388, 0.055646670662099496, 0.031081333945621736, 0.26211839576717466, 0.10311255100532435, 0.2012790142907761, 0.1441754261031747, 0.22540535952430218, 0.17480004607932642, 0.19611486874055117, 0.1949614376644604, 0.15411848318763077, 0.20199822960421443, 0.21490450424607843, 0.22685749019728974, 0.5006959266029298, 0.4219200380612165, 0.8366979437414557, 18.419749103486538, 86.05481073260307, 74.15800631046295, 60.96877723932266, 74.54348042607307, 68.51802974939346, 89.31550696492195, 35.14885492622852, 0.6009213672950864, 0.17668242944637313, 0.2929241146193817, 0.5187378928530961, 0.9533347631804645, 0.24741699948208407, 0.9282618679571897, 1.359273036941886, 1.6881769755855203, 1.7959020263515413, 4.804324451833963, 8.972782474011183, 3.098734673112631, 1.2182621285319328, 24.01223961263895, 72.9758669435978, 77.40140587091446, 85.59147119522095, 89.2369195818901, 89.76331293582916, 94.86355125904083, 94.36311811208725, 92.83614724874496, 90.68987041711807, 94.04648870229721, 88.46005126833916, 87.60627508163452, 87.96230837702751, 88.70420336723328, 87.03741520643234, 87.44499653577805, 85.8492037653923, 84.36143159866333, 85.28801947832108, 82.89894327521324, 74.5579044520855, 78.01960229873657, 77.1501861512661, 83.78528371453285, 85.43588474392891, 89.18215692043304, 87.2208009660244, 86.15457057952881, 85.87953373789787, 93.84458273649216, 85.61213448643684, 86.49403676390648, 82.18232452869415, 79.71418976783752, 79.77142989635468, 83.56310963630676, 77.79479116201401, 76.46257504820824, 81.28975242376328, 74.36086982488632, 79.7753132879734, 82.57053449749947, 83.89072045683861, 78.73390316963196, 82.03086465597153, 78.72273936867714, 71.18148922920227, 77.01682090759277, 76.85627952218056, 76.01289957761765, 70.89917197823524, 68.54034215211868, 68.4555535018444, 71.80149435997009, 74.24446687102318, 72.59662449359894, 70.88300004601479, 75.36352202296257, 73.29025447368622, 73.46893608570099, 73.76389905810356, 78.33735644817352, 77.71595299243927, 79.05528232455254, 75.658188611269, 77.30847045779228, 78.21046605706215, 78.68297830224037, 78.12041848897934, 77.38276407122612, 78.71612012386322, 76.53625309467316, 77.97129169106483, 78.40409606695175, 78.253213763237, 77.29229852557182, 74.93422865867615, 72.91039645671844, 76.31841078400612, 80.98332166671753, 69.9131628870964, 75.20838394761086, 81.29165232181549, 80.017299503088, 76.96423172950745, 71.50916084647179, 65.57489767670631, 67.21461609005928, 66.46034136414528, 63.56874592602253, 62.15882398188114, 69.00618955492973, 57.48601712286472, 53.54763865470886, 60.18470071256161, 65.27897715568542, 67.01198816299438, 70.10492339730263, 75.62237173318863, 82.15299010276794, 79.06670451164246, 38.84236693382263, 14.12980305030942, 0.17793665901990607, 1.6198870399966836, 4.386853203177452, 0.9491397882811725, 2.3591808322817087, 0.4423388361465186, 0.3147316788090393, 0.17780976661015302, 0.6064351089298725, 0.26536066085100174, 0.5208958801813424, 0.8088284579571337, 1.0642892844043672, 59.486309587955475, 86.92691713571548, 100.40179207921028, 59.39846210181713, 41.03005014359951, 65.27107357978821, 60.585408210754395, 78.5012948513031, 43.25630508363247, 0.5724347708746791, 0.19256436004070565, 0.22977657965384424, 0.20661676302552223, 0.21994146052747965, 0.14161961793433875, 0.18002976779825985, 0.14857900387141854, 0.17270160868065432, 0.18574374087620527, 0.13517724175471812, 0.23169108317233622, 0.1370582150411792], [0.0176248013303848, 0.09085590791073628, 0.051360396755626425, 0.007759071859254618, 0.028852694158558734, 0.033832564440672286, 0.04726137784018647, 0.03611729574913625, 0.05717721665860154, 0.053567024442600086, 0.018395336155663244, 0.05997599655529484, 0.030235617705329787, 0.12193855916848406, 0.13074547721771523, 27.674815580248833, 74.97516006231308, 42.85602696239948, 48.590702041983604, 51.93336747586727, 61.54386878013611, 28.258160278201103, 7.560004033148289, 0.02847202806151472, 0.23336835176451132, 0.16767787747085094, 0.38933841919060796, 0.3109561954624951, 0.07717313157627359, 0.0946058910631109, 0.4476013162638992, 0.057392279923078604, 0.044262496376177296, 0.944204565603286, 1.2485277419909835, 0.573173415614292, 1.9728321698494256, 32.69294410943985, 49.870644360780716, 59.86753553152084, 74.28760975599289, 80.57954013347626, 83.21975246071815, 84.98143672943115, 84.27431747317314, 86.60785585641861, 81.32196709513664, 79.74913269281387, 76.92570179700851, 79.49343681335449, 79.21952471137047, 80.81498309969902, 75.46635210514069, 79.27290424704552, 76.99982821941376, 83.16853120923042, 70.7547265291214, 61.14432021975517, 69.8839120566845, 61.72313556075096, 75.53078144788742, 79.73216280341148, 75.75563818216324, 76.58704116940498, 75.65558955073357, 77.57704764604568, 79.87011060118675, 80.44141754508018, 76.66179835796356, 76.33481070399284, 70.17134383320808, 70.77756330370903, 75.80942049622536, 68.94347012042999, 70.69740280508995, 69.58999022841454, 71.30339428782463, 74.86434280872345, 75.44111385941505, 77.96189859509468, 76.46464213728905, 69.41060185432434, 73.72702583670616, 76.17838069796562, 69.80096250772476, 67.6432254910469, 74.30093944072723, 73.95623713731766, 69.69924956560135, 75.37939757108688, 68.96718844771385, 68.16495269536972, 69.18562352657318, 67.82066076993942, 66.61199122667313, 64.89302426576614, 69.71580907702446, 67.79501214623451, 64.02309134602547, 64.2820854485035, 66.87089413404465, 66.31045460700989, 66.47680208086967, 66.90728098154068, 67.46658056974411, 69.12463679909706, 68.49805042147636, 69.7474005818367, 70.43939664959908, 71.1066560447216, 74.52084884047508, 70.25554731488228, 72.38747611641884, 69.59831178188324, 67.21066430211067, 71.24521180987358, 70.3578682243824, 72.5367321074009, 74.08375069499016, 64.93782386183739, 74.80707228183746, 75.3868755698204, 74.08659294247627, 71.5924371778965, 63.094972148537636, 57.90299154818058, 53.687398955225945, 48.451853692531586, 52.40406721830368, 46.07983477413654, 44.582753106951714, 30.776180662214756, 37.16722682118416, 54.10679765045643, 66.41399905085564, 62.16108866035938, 60.70432662963867, 75.78463822603226, 58.95007096230984, 20.233372785151005, 15.106174908578396, 1.216062877792865, 0.08143284401739947, 0.2051269164076075, 0.5085837689694017, 0.5770672566723078, 0.6691079365555197, 0.17448231781600043, 0.10450228932313621, 0.05519832811842207, 0.4318175569642335, 0.5809510638937354, 0.150019378925208, 1.1497214064002037, 7.6507065910845995, 56.63534536957741, 59.37436379492283, 52.99511790275574, 40.0803405046463, 49.774353727698326, 51.755187436938286, 49.99981462955475, 9.534774217754602, 0.07725191055214964, 0.11517889259266667, 0.15276534017175436, 0.13867384084733203, 0.10088348077260889, 0.041514590702718124, 0.013121591164235724, 0.03780830891628284, 0.08838904614094645, 0.025842838185781147, 0.0399666450539371, 0.02687973166757729, 0.10153321622055955, 0.029545891629823018, 0.04552200261969119, 0.0489795832982054, 0.06210590843693353, 0.04869485834205989, 0.05011030465539079, 0.03693084174301475, 0.04118296943488531, 0.05936686400673352, 0.0314476691710297, 0.03641748335212469, 0.10359242369304411, 0.014294704924395774, 0.07400475471513346, 0.1541188987903297, 33.270076140761375, 80.97730278968811, 60.57128056883812, 53.38412582874298, 28.287042528390884, 77.95847877860069, 46.73942618072033, 8.470736313611269, 0.036654106006608345, 0.12369641757686622, 0.145928512501996, 0.27816413319669664, 0.3401176119223237, 0.2407509696786292, 0.12701317202299833, 0.46508302039001137, 0.037041206524008885, 0.256676969002001, 1.545702195726335, 1.0504422336816788, 0.5955412716139108, 4.441536543890834, 47.05431908369064, 62.99595706164837, 73.73929917812347, 81.38948187232018, 87.36154541373253, 87.35252469778061, 89.31558296084404, 89.0447486937046, 92.2137102484703, 87.30939701199532, 81.27061665058136, 80.23872122168541, 82.3356007039547, 83.96047711372375, 83.79596874117851, 80.12858033180237, 82.81751364469528, 81.68313771486282, 86.4115659892559, 79.20369476079941, 69.73121345043182, 74.4186495244503, 70.56415915489197, 78.4881703555584, 84.00969207286835, 80.06776079535484, 79.17820572853088, 78.91943201422691, 84.03212606906891, 81.45977810025215, 82.47183859348297, 80.26766046881676, 77.28503331542015, 72.51578763127327, 73.9744533598423, 79.9505066871643, 70.9499904513359, 76.84146031737328, 75.66740691661835, 76.55418813228607, 77.5112883746624, 77.4460306763649, 78.78010109066963, 78.2232865691185, 74.37875166535378, 77.40009114146233, 79.12285029888153, 75.20820155739784, 71.44074931740761, 75.94403207302094, 74.66081812977791, 70.88914811611176, 79.26667258143425, 74.06082272529602, 72.13956981897354, 69.90541130304337, 71.32399678230286, 70.41254729032516, 66.10681593418121, 68.89753058552742, 70.88565230369568, 69.21570271253586, 69.33744058012962, 68.78830924630165, 69.64464649558067, 70.65862968564034, 68.70961546897888, 68.90880838036537, 69.80497509241104, 70.85672825574875, 74.44692760705948, 71.51643365621567, 71.31893545389175, 72.92228981852531, 70.02362295985222, 74.87607657909393, 73.58285397291183, 72.34498679637909, 74.44790795445442, 71.39372304081917, 72.84953892230988, 74.7789765894413, 67.15153187513351, 71.15222319960594, 76.55285060405731, 74.85652282834053, 74.66901808977127, 72.34548076987267, 66.17544785141945, 62.094212248921394, 57.82489813864231, 57.59805791079998, 53.56001079082489, 50.73999211192131, 40.54277949035168, 40.86158998310566, 58.85143205523491, 71.78089186549187, 69.52698200941086, 61.310234516859055, 73.68671000003815, 72.87627428770065, 48.33948612213135, 18.08240320533514, 2.7127639716491103, 0.12148375622928143, 0.40822465263772756, 0.5738384986761957, 1.1762882745824754, 1.3637481280602515, 0.08421157108386979, 0.07811463496182114, 0.028255374745640438, 0.7810350868385285, 0.1023807266028598, 0.1422638021176681, 1.5338762803003192, 10.908429957926273, 67.30333372950554, 74.06125590205193, 67.76571571826935, 39.72774222493172, 51.197757348418236, 54.41415935754776, 60.19315905869007, 10.166125539690256, 0.07004064711509272, 0.07642261989531107, 0.02989865854033269, 0.059576450221356936, 0.05201876338105649, 0.007828586512914626, 0.03851330096949823, 0.03550891648046672, 0.024632566019135993, 0.07114282547263429, 0.04723792597360443, 0.055916270648594946, 0.022049925501050893, 0.10593223720206879, 0.26385555567685515, 0.19570938893593848, 0.18458159698639065, 0.11672348744468763, 0.09377640744787641, 0.16173860320122913, 0.15913771698251367, 0.20174333156319335, 0.1594745778129436, 0.11365819489583373, 0.19810723839327693, 0.13598186342278495, 0.2335763312294148, 0.5102160782553256, 39.81550611555576, 97.24284678697586, 59.187087044119835, 65.9799787402153, 79.18195232748985, 88.80211651325226, 68.10604825615883, 10.498455706983805, 0.12355530561762862, 0.3175538289360702, 0.9039682277943939, 0.8511919097509235, 1.031367969699204, 0.8642429625615478, 0.47771404730156064, 1.2864105217158794, 0.1387947960756719, 0.2294298037304543, 4.184262799099088, 3.725222493521869, 0.966321041341871, 8.13559239730239, 62.14656583964825, 68.26271384954453, 87.82369181513786, 87.02930644154549, 93.56633886694908, 92.02616751194, 92.86590725183487, 95.20840555429459, 97.59827971458435, 93.10724750161171, 87.58672133088112, 87.18974903225899, 87.203139513731, 87.22643986344337, 87.14801967144012, 83.31122115254402, 88.5644468665123, 87.20276713371277, 91.88492149114609, 84.3443401157856, 76.67904943227768, 80.39935380220413, 74.34291958808899, 82.6516905426979, 85.72332412004471, 84.1679459810257, 83.29153820872307, 82.9328678548336, 86.31262689828873, 86.94546774029732, 87.22379520535469, 85.56909039616585, 82.16725453734398, 75.83974286913872, 76.32003709673882, 84.29325565695763, 75.66381990909576, 78.41304838657379, 79.1279724240303, 77.73832619190216, 80.03866195678711, 81.75366953015327, 81.64745762944221, 84.07414421439171, 79.60188299417496, 79.10144224762917, 82.03198179602623, 75.85191741585732, 76.0840393602848, 79.96189847588539, 80.70552617311478, 76.58959463238716, 82.27386921644211, 76.55102670192719, 76.67252898216248, 73.37062776088715, 74.72097650170326, 73.67385149002075, 70.71020051836967, 74.38433736562729, 75.11188432574272, 71.95707321166992, 73.71914505958557, 71.38735458254814, 72.83568486571312, 74.24624517560005, 72.88622215390205, 71.416385024786, 73.07020828127861, 71.83661207556725, 79.78761702775955, 74.17343348264694, 74.51063498854637, 76.52116790413857, 74.35608968138695, 79.60498362779617, 75.36952570080757, 74.81131285429001, 76.56560271978378, 75.08003443479538, 78.8084627687931, 77.33783528208733, 69.65100735425949, 75.98747134208679, 78.87549117207527, 78.7793031334877, 80.8952347934246, 73.37991446256638, 68.83546471595764, 67.92344525456429, 64.65510383248329, 65.57845428586006, 61.48689843714237, 59.6566354483366, 51.248195841908455, 55.37119120359421, 65.77516973018646, 69.70567882061005, 71.5464748442173, 64.99512478709221, 77.03552350401878, 76.68227925896645, 54.48360063135624, 23.07656642049551, 3.0104245617985725, 0.26819830702152103, 1.6798201552592218, 0.9859854611568153, 1.4678416424430907, 2.395559842698276, 0.2506849280325696, 0.21558195148827508, 0.13120174960931763, 1.4905208442360163, 2.3297257628291845, 0.43389684695284814, 1.8612244399264455, 14.691297970712185, 83.3628299832344, 83.42786729335785, 80.63738822937012, 62.45152227580547, 72.78892457485199, 64.55453842878342, 73.29653173685074, 13.774197231978178, 0.22440224303863943, 0.22185165958944708, 0.30683187302201986, 0.19375133619178087, 0.25375430239364505, 0.203642591368407, 0.12393286582664587, 0.10887597338296473, 0.12707349378615618, 0.12804201134713367, 0.08885522620403208, 0.1338943949667737, 0.13546000001952052], [0.05963325791526586, 0.05488804730703123, 0.047757436768733896, 0.08504122539306991, 0.05650080100167543, 0.04248859273502603, 0.04101004531548824, 0.011388808070478262, 0.025381840168847702, 0.08786369464360178, 0.025048634415725246, 0.07939034228911623, 0.03538969045621343, 0.12376517755910754, 0.09873061426333152, 42.216380685567856, 63.8106295466423, 46.104677841067314, 59.5547629147768, 45.038645043969154, 68.72171401977539, 2.6065917313098907, 1.5168024902231991, 0.0484626254910836, 0.1585351227549836, 0.2915737027069554, 0.24985485069919378, 0.1395542357931845, 0.3542408306384459, 0.07367596845142543, 0.34794539969880134, 0.2419892727630213, 0.5105995608028024, 1.2376267206855118, 0.1535200301441364, 1.6883015376515687, 22.461901903152466, 44.90014247596264, 56.54626674950123, 66.50673687458038, 76.27910569310188, 75.85642397403717, 81.07823297381401, 79.57629516720772, 85.14993488788605, 82.8611809015274, 81.64182633161545, 78.65903958678246, 77.53841891884804, 75.65089300274849, 77.83711329102516, 79.35510903596878, 79.29960921406746, 79.28415924310684, 82.28536739945412, 75.06969138979912, 76.34350463747978, 66.63320168852806, 63.22397902607918, 67.32750043272972, 75.48078373074532, 80.28182610869408, 73.16714867949486, 77.90465086698532, 78.81376728415489, 81.75498425960541, 73.71883347630501, 75.69379270076752, 73.63371044397354, 71.17451280355453, 72.99191728234291, 77.45543897151947, 71.95531770586967, 72.30928391218185, 73.86363610625267, 73.08018654584885, 74.19619426131248, 72.02075019478798, 74.10673186182976, 69.66917037963867, 72.85092204809189, 72.93334722518921, 76.90687000751495, 71.07056558132172, 69.69236433506012, 70.27634739875793, 67.84392312169075, 62.324662283062935, 66.9733290374279, 70.71631819009781, 69.1922427713871, 70.9189385175705, 66.20943322777748, 65.68171754479408, 64.027841091156, 63.2667875289917, 65.8786989748478, 68.19757014513016, 65.7999823987484, 63.965995609760284, 65.12627854943275, 69.81434538960457, 66.24890550971031, 63.24582405388355, 67.42886379361153, 67.98522233963013, 67.66164690256119, 67.84861966967583, 68.41482728719711, 71.70687943696976, 70.09780257940292, 70.70402204990387, 69.95427668094635, 70.42036727070808, 68.1801974773407, 65.14705583453178, 70.35430401563644, 69.0824742615223, 73.12794998288155, 73.77264618873596, 67.26451501250267, 74.46994677186012, 76.85217574238777, 69.7976566851139, 65.35342276096344, 59.32213179767132, 56.85652770102024, 50.79277127981186, 44.870572462677956, 49.7346268594265, 48.30740064382553, 41.43714889883995, 27.63005018234253, 36.50048039853573, 52.73974120616913, 67.11785808205605, 59.92406889796257, 64.13077756762505, 67.82504573464394, 31.24128520488739, 18.15820913761854, 7.161324676126242, 0.2919554931577295, 0.7137656339909881, 0.6379521614871919, 0.8190066274255514, 0.4786100273486227, 0.5163029360119253, 0.282415155088529, 0.24619244097266346, 0.6506017420906574, 0.24610473396023735, 0.4358052648603916, 0.13890154659748077, 0.2235434445901774, 36.164973601698875, 75.64424335956573, 47.65898443758488, 36.9445663690567, 47.77646653354168, 40.64674191176891, 36.612399592995644, 1.7124998266808689, 0.08897138715838082, 0.03185126020980533, 0.07872153364587575, 0.06996437659836374, 0.053043981024529785, 0.09147384233074263, 0.031083820140338503, 0.023203354721772484, 0.04763189877849072, 0.01947840049979277, 0.01869336596428184, 0.014485552837868454, 0.11620546836638823, 0.0935002468759194, 0.12944156827870756, 0.11365131518687122, 0.04832614824408665, 0.13185636838898063, 0.029783152531308588, 0.025136109507002402, 0.02414639064227231, 0.028095343586755916, 0.025878294291032944, 0.0336095156671945, 0.1077862482634373, 0.028462465488701127, 0.029562528725364245, 0.018824664875864983, 50.68080648779869, 69.97424840927124, 61.60615123808384, 47.08714932203293, 44.906811118125916, 86.03668570518494, 8.525504674762487, 2.0776705630123615, 0.13070370914647356, 0.6506921059917659, 0.2695928025059402, 0.1297018097830005, 0.13801301771309227, 0.2851512160850689, 0.13058665761491284, 0.8556746004614979, 0.17941414145752788, 0.7099323521833867, 3.192745903506875, 0.1362288650125265, 2.1855795476585627, 34.02672953903675, 63.64989437162876, 68.02129000425339, 75.77984288334846, 86.33894428610802, 81.1389385163784, 86.29758730530739, 83.50816458463669, 91.50465309619904, 89.22577857971191, 86.71513170003891, 82.21313327550888, 80.85030600428581, 78.39889794588089, 82.69664973020554, 82.0087118446827, 84.18385192751884, 84.6882900595665, 87.24280178546906, 77.63070076704025, 78.16975504159927, 76.33207485079765, 72.16819748282433, 75.16087129712105, 80.92107340693474, 83.9984978735447, 79.300756752491, 81.26151993870735, 83.75799357891083, 82.24391922354698, 75.18385246396065, 78.86120393872261, 74.36172857880592, 73.36761072278023, 74.82010558247566, 78.02363008260727, 74.15916904807091, 77.01039165258408, 77.39591896533966, 78.99672746658325, 76.96113109588623, 77.04846560955048, 77.77495622634888, 73.63566353917122, 74.13364201784134, 75.80923810601234, 80.16990691423416, 70.08134186267853, 71.6533175110817, 75.04778936505318, 69.98385429382324, 62.6072683185339, 69.35141623020172, 71.02881342172623, 70.38201212882996, 73.16454961895943, 69.43086996674538, 68.29440414905548, 65.20079255104065, 66.43131852149963, 66.25657349824905, 70.69474294781685, 68.53403449058533, 66.59520372748375, 67.06951707601547, 68.21488961577415, 71.25896707177162, 66.72206372022629, 70.39477944374084, 70.32893657684326, 69.85256373882294, 72.21990510821342, 69.1154944896698, 71.53659537434578, 72.25039467215538, 73.51992174983025, 70.62107250094414, 72.21449419856071, 73.07184979319572, 71.91635459661484, 72.26288080215454, 70.15777096152306, 73.06913673877716, 73.6841793358326, 68.03669437766075, 71.16125151515007, 75.51096931099892, 71.4861036837101, 70.38138896226883, 65.73631301522255, 62.71913431584835, 60.18268682062626, 54.59189102053642, 54.491743594408035, 53.76911737024784, 50.33667415380478, 39.72831219434738, 42.595573738217354, 57.48734325170517, 74.07179653644562, 67.21236661076546, 59.82809364795685, 70.11108666658401, 60.479496493935585, 29.146242924034595, 9.158736895769835, 0.4570587712805718, 0.5552802351303399, 2.0122349867597222, 2.1209899010136724, 0.4928961623227224, 0.4029394331155345, 0.33216538082342595, 0.9356456436216831, 0.4868579003959894, 0.4803897568490356, 0.13670896034454927, 0.2937623258912936, 0.21762955177109689, 45.891060903668404, 86.72913774847984, 59.80423092842102, 38.04668962955475, 55.10288380086422, 48.98137807846069, 48.397493809461594, 2.106366860680282, 0.007981438320712186, 0.07192867822595872, 0.02431757628073683, 0.02901064173784107, 0.018160691324737854, 0.04715446033515036, 0.01316281932304264, 0.004745827054648544, 0.09612159410608001, 0.07658720598556101, 0.02328334525373066, 0.07190783129772171, 0.07590022956719622, 0.2448998868931085, 0.23809342790627852, 0.1729683217126876, 0.20792674273252487, 0.20906179823214188, 0.12416474244673736, 0.14351650286698714, 0.23137267213314772, 0.23822931514587253, 0.12147404151619412, 0.15647241234546527, 0.20653077779570594, 0.1659913468756713, 0.2817277185386047, 0.278739831992425, 61.441494673490524, 80.36861345171928, 60.75018256902695, 80.41660487651825, 69.01695817708969, 98.80494296550751, 18.402752615511417, 2.9023151379078627, 0.32992219494190067, 0.9359158447477967, 0.5809239903464913, 0.6233305460773408, 0.2959983277833089, 1.3210196583531797, 0.3901269065681845, 2.2519572358578444, 0.6130029971245676, 1.3476352114230394, 7.07902679219842, 0.5982497544027865, 2.7337488206103444, 44.211653620004654, 70.06646186113358, 80.68699836730957, 87.00602889060974, 92.46166214346886, 89.28443983197212, 92.1667143702507, 88.81452664732933, 93.32809165120125, 91.70096576213837, 90.5024416744709, 88.0733460187912, 86.18259787559509, 85.35339877009392, 87.2215761244297, 85.02433642745018, 90.3684988617897, 90.75985506176949, 91.4826674759388, 84.23421442508698, 83.1391815841198, 81.28842249512672, 76.12361803650856, 78.26585948467255, 82.03357011079788, 86.20873287320137, 80.79501897096634, 85.4107528924942, 88.0115157365799, 87.36024588346481, 80.72523191571236, 83.27751696109772, 78.47049370408058, 76.76560118794441, 76.9008207321167, 83.32306131720543, 79.46565270423889, 82.44919180870056, 80.66730782389641, 80.18943786621094, 78.67130532860756, 77.12459832429886, 79.39452812075615, 74.7206649184227, 77.45422303676605, 78.92721399664879, 84.13967549800873, 76.45493745803833, 77.51752763986588, 77.85565629601479, 72.52334162592888, 67.13836178183556, 72.0104755461216, 76.45764291286469, 76.38738468289375, 76.14254102110863, 72.8522215783596, 70.44341683387756, 69.53318327665329, 70.48904478549957, 71.29259526729584, 76.17293938994408, 73.11429351568222, 71.37558281421661, 71.90841302275658, 72.19428688287735, 75.84773764014244, 69.07503426074982, 73.7966836988926, 72.15277031064034, 72.56039723753929, 75.83133772015572, 74.24607038497925, 74.96157959103584, 79.0508821606636, 77.59065091609955, 75.9900552034378, 76.9647105038166, 75.73155507445335, 74.35464575886726, 76.52524128556252, 73.3497516810894, 80.51924496889114, 79.33674082159996, 71.94850847125053, 78.20997208356857, 81.02350071072578, 75.59746026992798, 75.5063183605671, 69.32637557387352, 65.66847905516624, 63.783035427331924, 61.02295093238354, 61.176968067884445, 64.2225806415081, 58.096613958477974, 48.109256476163864, 55.499533116817474, 63.48058685660362, 71.32392838597298, 69.4656229019165, 68.50904703140259, 75.98392233252525, 64.56684976816177, 32.679477632045746, 11.141360308974981, 0.8068815374281257, 1.1850186623632908, 3.3301690919324756, 4.607571484521031, 1.234900604467839, 1.4034284488298, 0.6802365893963724, 2.4576271371915936, 2.8242889372631907, 0.37079342524521053, 0.7777453539893031, 0.28659068571869284, 0.5301017768215388, 57.17469222843647, 93.2591025531292, 60.8839163929224, 52.226058170199394, 64.99298930168152, 57.80265413224697, 60.65074950456619, 3.3208724157884717, 0.16591447521932423, 0.20108887605601922, 0.11363635348971002, 0.1343943946994841, 0.14142649626592174, 0.11521533204359002, 0.1396119748824276, 0.12056746360030957, 0.1892315677832812, 0.18632191844517365, 0.15855817386182025, 0.12794588838005438, 0.19901742314687], [0.04724579644971527, 0.07363238953985274, 0.19558141299057752, 0.07510861774790101, 0.0771640996390488, 0.019039609396713786, 0.05776249658083543, 0.029000606045883615, 0.031025617208797485, 0.13025528867729008, 0.0494826852082042, 0.04337230137025472, 0.0466001576569397, 0.1285551767796278, 1.8226091307587922, 57.47249744832516, 54.67132955789566, 50.925691947340965, 40.93100845813751, 57.24681615829468, 52.629547119140625, 0.5792406213004142, 0.5742669850587845, 0.07988977056811564, 0.1774808467598632, 0.4398724716156721, 0.2702733816113323, 0.08158378943335265, 0.09622064113500528, 0.1481378119206056, 0.7197573187295347, 0.18657285341760144, 0.1585795625578612, 0.4257807199610397, 0.8268745802342892, 9.120772182941437, 42.0866784453392, 52.60587818920612, 64.09423872828484, 76.0098597407341, 73.65606844425201, 77.88965687155724, 76.72650128602982, 78.92317101359367, 82.63797327876091, 84.70877856016159, 77.50347599387169, 75.1962473988533, 75.60787171125412, 80.44106036424637, 78.04301664233208, 75.83611026406288, 77.76397481560707, 79.88676130771637, 74.97983381152153, 75.68651989102364, 75.37888839840889, 80.24272620677948, 69.70925822854042, 65.75278133153915, 69.57314193248749, 78.71330067515373, 76.16790845990181, 79.5296260714531, 76.8115559220314, 73.55368673801422, 72.60263577103615, 74.90988716483116, 71.81217178702354, 77.59125888347626, 74.1290670633316, 70.53654983639717, 74.29235190153122, 77.11072146892548, 76.2753514945507, 78.19126948714256, 72.76347354054451, 74.17755246162415, 67.12000116705894, 68.63766252994537, 78.49250212311745, 75.21901577711105, 67.50686600804329, 64.23701226711273, 70.0942611694336, 67.10754543542862, 59.50455620884895, 63.07840123772621, 68.33208292722702, 68.91386210918427, 64.65403988957405, 66.6473825275898, 67.59290099143982, 66.76822364330292, 63.051323890686035, 67.36799865961075, 66.67994678020477, 65.55744901299477, 64.39715847373009, 61.52173116803169, 60.04793845117092, 65.21346107125282, 64.9139991402626, 64.30809885263443, 60.094546750187874, 62.54027411341667, 64.5314584672451, 69.38929259777069, 67.34870329499245, 68.22003453969955, 69.10142004489899, 70.47797217965126, 70.08435890078545, 66.85311108827591, 68.53642076253891, 66.16052985191345, 66.99105128645897, 68.37920039892197, 67.25198328495026, 70.55288136005402, 70.74344873428345, 65.28066426515579, 72.25886061787605, 73.87195006012917, 70.78581646084785, 59.61397513747215, 63.02167788147926, 56.62445895373821, 49.27886411547661, 43.45246955752373, 45.330423787236214, 42.45711296796799, 40.42117841541767, 35.91319531202316, 39.587271362543106, 59.65724341571331, 60.55619157850742, 54.5346736907959, 59.92302395403385, 53.62288981676102, 11.982455626130104, 14.932662919163704, 2.5763579411432147, 0.5933786532841623, 1.7386820842511952, 0.6340093386825174, 0.12916488078190014, 0.8662248530890793, 2.461760602891445, 0.25254258303903043, 0.08044320493354462, 0.40556158928666264, 0.259270656388253, 0.2552246453706175, 0.30404564284253865, 7.863360280171037, 77.3642286658287, 30.38376621901989, 36.757946982979774, 37.124289125204086, 43.44512455165386, 43.49690817296505, 0.9252314118202776, 0.11435925727710128, 0.08102464795229025, 0.00982238851065631, 0.1019652871764265, 0.07357346301432699, 0.09422943665413186, 0.09207704511936754, 0.06519028902403079, 0.06898696810822003, 0.08480606848024763, 0.050427947571733966, 0.05690743484592531, 0.009113793330470799, 0.08140384830767289, 0.05361868905310985, 0.02950693444290664, 0.05650228529702872, 0.1081880321726203, 0.03486357454676181, 0.09925388774718158, 0.028935827685927507, 0.045789929063175805, 0.03962481925555039, 0.003724726939253742, 0.023782764255884103, 0.02080674094031565, 0.004198519582132576, 2.3142648674547672, 67.04689309000969, 65.67062214016914, 62.73093268275261, 35.20319581031799, 65.2466256916523, 68.81499141454697, 0.7501170365139842, 0.14776332420296967, 0.086554894951405, 0.19649000954814255, 0.7868867728393525, 0.16950550518231466, 0.2591960853897035, 0.7155189430341125, 0.12309743760852143, 0.9790918591897935, 0.5572548822965473, 0.6918035249691457, 1.3898575957864523, 1.0229776636697352, 14.449261408299208, 60.71033790707588, 66.74544766545296, 74.84410509467125, 82.6606884598732, 78.73586386442184, 83.38097020983696, 80.55623978376389, 85.76472669839859, 87.48506918549538, 90.80951079726219, 83.88766542077065, 81.27774506807327, 78.74597132205963, 84.8489074409008, 81.3374550640583, 81.2699706852436, 80.5371268093586, 84.33644413948059, 78.71998071670532, 80.31092494726181, 79.40441519021988, 83.91611829400063, 78.02011147141457, 73.70903760194778, 74.37752813100815, 83.20931062102318, 81.60474792122841, 80.21257862448692, 79.22362089157104, 77.2403173148632, 77.22593128681183, 78.81108462810516, 73.87520268559456, 79.40635308623314, 76.49777635931969, 74.7200645506382, 78.0768196284771, 78.17098617553711, 79.63627874851227, 80.68707436323166, 77.47350320219994, 76.91877856850624, 68.90572294592857, 74.30015668272972, 78.68178516626358, 74.58831042051315, 71.17357805371284, 70.33460587263107, 71.97266757488251, 70.55549561977386, 65.93471556901932, 68.91076147556305, 72.26950004696846, 72.25443005561829, 66.59046158194542, 68.23159351944923, 67.4300417304039, 68.4627503156662, 64.43105265498161, 68.49922075867653, 70.80298393964767, 68.90207514166832, 66.07406929135323, 65.77963069081306, 64.7063858807087, 66.2682768702507, 67.65726953744888, 67.0175738632679, 62.87475496530533, 65.55898413062096, 66.46674022078514, 70.7275427877903, 69.61926385760307, 69.83972802758217, 69.16622936725616, 72.65077918767929, 70.51591694355011, 69.3784099817276, 70.60443699359894, 72.1676579117775, 69.99917507171631, 70.64401566982269, 67.61631533503532, 71.48465976119041, 71.80739924311638, 67.23225474357605, 73.20772290229797, 76.09271049499512, 73.04774388670921, 68.25182363390923, 66.63962334394455, 63.215520679950714, 58.7871129065752, 54.34448629617691, 50.89491739869118, 51.51300363242626, 47.91821792721748, 46.80194042623043, 44.991489574313164, 67.58043006062508, 69.62736502289772, 62.00187720358372, 56.91559933125973, 69.81087237596512, 37.58756406605244, 20.721574388444424, 3.6858943663537502, 0.1226004955242388, 2.3350502271205187, 0.4645309515763074, 1.0569776454940438, 0.3963699418818578, 5.049257408827543, 0.4404642601730302, 0.10967592694214545, 0.4111640917835757, 0.546777241397649, 0.2934488723985851, 0.42463350808247924, 11.504873502999544, 84.88086372613907, 37.79482014477253, 35.70875868201256, 46.15880973637104, 50.56455172598362, 56.36780932545662, 1.8943249387666583, 0.1373255960061215, 0.11713252955814824, 0.03361276256327983, 0.08705528802238405, 0.054340108545147814, 0.014678523293696344, 0.023123803912312724, 0.09232421740307473, 0.022465248039225116, 0.04045102257805411, 0.029002097762713674, 0.06893046840559691, 0.021505530494323466, 0.21501312498003244, 0.13838673359714448, 0.30962237797211856, 0.15371160814538598, 0.1753647462464869, 0.07273759692907333, 0.1255281048361212, 0.14478043973213062, 0.18623266776558012, 0.2530009037582204, 0.22239998797886074, 0.19175533001543954, 0.15203094051685184, 0.50451869959943, 3.6706666834652424, 82.85909101366997, 70.28232827782631, 66.72888055443764, 62.44577318429947, 78.5177555680275, 83.07964637875557, 1.2605759454891086, 0.9299710043706, 0.5637650610879064, 1.1927643092349172, 2.0157293742522597, 1.0612766398116946, 0.45600026089232415, 1.891043339855969, 0.2433615186600946, 2.0850053569301963, 0.5554693343583494, 1.9063393003307283, 4.429747676476836, 1.618755531962961, 23.550623282790184, 69.6399499475956, 75.1186403632164, 87.89524957537651, 89.27544951438904, 88.39660987257957, 87.04208895564079, 89.38765749335289, 90.14138504862785, 92.72814184427261, 95.719675719738, 88.82592603564262, 84.23513397574425, 83.91184732317924, 88.57176527380943, 84.90572199225426, 83.59046056866646, 83.10253635048866, 91.58832460641861, 83.61308455467224, 84.49310213327408, 84.30220037698746, 86.75282567739487, 82.73313537240028, 79.6067163348198, 78.20358842611313, 86.1528454720974, 83.83999317884445, 86.87806695699692, 83.14349815249443, 80.56152909994125, 77.0949675142765, 84.69572246074677, 77.60838836431503, 82.47141301631927, 79.75031822919846, 80.67110002040863, 79.68002960085869, 83.71848329901695, 84.47313040494919, 84.7477188706398, 79.27844434976578, 81.25537186861038, 71.97690814733505, 74.9084584414959, 82.79315695166588, 82.06361889839172, 74.97186943888664, 73.28085377812386, 74.60933089256287, 76.92026808857918, 67.05243319272995, 68.50413769483566, 74.84725132584572, 75.95975562930107, 72.4274043738842, 73.84513109922409, 73.97569969296455, 73.23546901345253, 69.54666495323181, 72.83908948302269, 73.30137267708778, 71.9404225051403, 70.76560154557228, 68.44203382730484, 66.87449634075165, 70.69123953580856, 71.36437341570854, 69.83335956931114, 64.31917905807495, 68.61666485667229, 68.98846730589867, 75.47196060419083, 72.56973713636398, 73.52990001440048, 73.67287874221802, 76.59768059849739, 75.84199994802475, 74.89880695939064, 76.17256700992584, 72.79651656746864, 69.54101085662842, 74.10718023777008, 70.42881041765213, 77.66250506043434, 76.98415786027908, 70.68851888179779, 78.67343321442604, 80.74210301041603, 77.73151695728302, 71.49338409304619, 70.81481650471687, 68.00694957375526, 63.58238339424133, 60.80720990896225, 60.81447891891003, 62.4185324460268, 57.70314507186413, 54.651832804083824, 53.518254831433296, 68.19517627358437, 67.36533120274544, 65.04009157419205, 64.40485686063766, 76.24363079667091, 41.313712522387505, 26.713246777653694, 4.9658438097685575, 1.5009952196851373, 5.101765841245651, 3.979624779894948, 1.8098526215180755, 1.3654382061213255, 6.5726683381944895, 1.2163329008035362, 0.4040274809813127, 1.5571577497757971, 0.9590669930912554, 0.6815324979834259, 0.6308040325529873, 15.202518738806248, 96.4310735464096, 44.41056154668331, 53.30770432949066, 52.708240896463394, 58.77506375312805, 68.582633882761, 2.4429513746872544, 0.20986210060073063, 0.24253381619928405, 0.10695284610847011, 0.22703136055497453, 0.14879548834869638, 0.1502830788376741, 0.2856696507660672, 0.23226301185786724, 0.10288799196132459, 0.1272619399242103, 0.3137761785183102, 0.13800602668197826, 0.20530473499093205], [0.05542667211557273, 0.016460351216665003, 0.06089248585340101, 0.09410983955604024, 0.02870343712856993, 0.037381785514298826, 0.03429616554058157, 0.01979786353331292, 0.05297557727317326, 0.029805557969666552, 0.04111659545742441, 0.07405583673971705, 0.06720445555401966, 0.36091707239393145, 11.72895697876811, 70.33130005002022, 49.186179488897324, 62.56031423807144, 46.61230020225048, 85.72748109698296, 18.037964589893818, 0.4929178924066946, 0.05227027722867206, 0.5939733807463199, 0.44793142355047166, 0.4057246836600825, 0.3698904986958951, 0.40665512904524803, 0.1970011118100956, 0.6880420236848295, 0.7324035745114088, 1.0464557725936174, 0.4670593299670145, 0.9231383178848773, 0.9198680589906871, 44.92392539978027, 53.66938792169094, 67.12388455867767, 70.58575719594955, 77.1832823753357, 76.43748879432678, 74.54014420509338, 77.5647135078907, 81.0927101969719, 81.3705512881279, 83.60746085643768, 82.30286926031113, 78.55320766568184, 75.08804440498352, 77.62082129716873, 78.34929540753365, 76.79358288645744, 77.72944986820221, 73.43004137277603, 70.94205647706985, 70.18323719501495, 75.68649709224701, 76.17909505963326, 77.58929058909416, 66.19190096855164, 63.75841274857521, 75.22786930203438, 80.62314659357071, 74.83266770839691, 71.3952961564064, 72.21298947930336, 75.72061166167259, 69.84432578086853, 79.42307978868484, 76.884094029665, 73.20849046111107, 75.036830753088, 73.84880930185318, 75.10511308908463, 78.35113450884819, 73.48278254270554, 73.3448575437069, 63.57483319938183, 69.47743266820908, 71.44641101360321, 63.770936876535416, 61.97667695581913, 73.18449094891548, 72.86271661520004, 74.56070110201836, 62.327493131160736, 68.73490691184998, 65.6758126616478, 67.9769691824913, 72.88962677121162, 70.77130123972893, 62.27892033755779, 55.034305080771446, 58.58079917728901, 62.05638147890568, 62.35302396118641, 65.66785588860512, 65.9090593457222, 65.91118723154068, 64.71327871084213, 65.13839989900589, 65.42024597525597, 65.4070682823658, 63.61872844398022, 63.55037771165371, 61.54350399971008, 61.63449391722679, 62.09856681525707, 68.685023188591, 67.50103712081909, 68.28179642558098, 67.90876284241676, 70.73958814144135, 70.28374940156937, 64.18314635753632, 64.78987500071526, 66.36951863765717, 66.27596765756607, 68.82786512374878, 71.1215740442276, 72.46173173189163, 72.08055898547173, 66.30455732345581, 71.5179231762886, 69.6382400393486, 66.9110655784607, 64.37220141291618, 62.73351274430752, 54.94162805378437, 48.28726552426815, 41.35962925851345, 41.471753641963005, 41.95780076086521, 37.58344888687134, 36.940075010061264, 57.687098532915115, 62.42043994367123, 53.6734689027071, 53.59161749482155, 56.42640598118305, 23.019573278725147, 12.879531439393759, 9.435732532292604, 0.7754556206054986, 1.1394246714189649, 0.22640614566626027, 0.5837304960004985, 1.6299198078922927, 2.1842980664223433, 0.7414046383928508, 0.46245258185081184, 0.13506715156836435, 0.48511533765122294, 0.19745379220694304, 0.06325460461084731, 0.7406515069305897, 55.043838769197464, 44.96828801929951, 31.776731573045254, 38.400317654013634, 35.29910646378994, 48.06251518428326, 4.749184660613537, 0.30093838926404715, 0.15431691863341257, 0.11850062684970908, 0.01887400656414684, 0.033088201453210786, 0.147701503301505, 0.06375844866852276, 0.037398517233668827, 0.07495228433981538, 0.11167564385687001, 0.025031761688296683, 0.043030757587985136, 0.06266841184697114, 0.042399820740683936, 0.03604751902457792, 0.021079240868857596, 0.03114357044978533, 0.05921829346334562, 0.04496076457144227, 0.05899985713767819, 0.06344867622829042, 0.09196146304020658, 0.025638085207901895, 0.02863500740204472, 0.1418859005207196, 0.09415896231075749, 0.7355397124774754, 15.240739937871695, 78.65915358066559, 58.322819620370865, 60.74550502002239, 35.784853398799896, 97.98929393291473, 25.246949158608913, 0.6232448131777346, 0.10761130179162137, 0.8074414730072021, 0.4190786514664069, 0.49289913091342896, 0.2685072482563555, 0.20135967090027407, 0.347792903194204, 0.8306916535366327, 1.4399251341819763, 2.282579317688942, 2.561002727597952, 1.0527156991884112, 1.4573920844122767, 59.58639241755009, 65.28142422437668, 80.80343171954155, 76.98668092489243, 84.74373668432236, 82.51509547233582, 82.2920398414135, 82.61886790394783, 86.03079602122307, 86.93539828062057, 86.49198487401009, 87.62402012944221, 83.45613777637482, 78.75516682863235, 82.18655750155449, 82.14211508631706, 80.25827497243881, 81.32091075181961, 75.83840534090996, 74.75936964154243, 76.3788503408432, 77.86204755306244, 77.77513861656189, 81.48190811276436, 76.24170050024986, 73.49599823355675, 77.99048826098442, 83.87521728873253, 79.26560863852501, 74.96067523956299, 77.10941433906555, 78.05577635765076, 75.1688964664936, 82.2485701739788, 77.54261389374733, 76.38679191470146, 80.50815716385841, 78.57408374547958, 76.39250680804253, 77.12640702724457, 77.95101597905159, 74.38300743699074, 69.985191822052, 75.80315843224525, 74.06441733241081, 64.22062754631042, 65.90296447277069, 74.65876623988152, 76.08307421207428, 74.24574360251427, 64.827561378479, 74.39683869481087, 68.26845154166222, 70.66964149475098, 72.82205879688263, 75.51330238580704, 65.78742027282715, 57.93262615799904, 59.138122871518135, 64.78868946433067, 62.41345211863518, 67.66579627990723, 69.06543597579002, 68.74999970197678, 68.52679967880249, 68.90863358974457, 69.07531544566154, 66.12201511859894, 66.66875258088112, 68.13336119055748, 63.485518991947174, 64.38934609293938, 63.39474946260452, 68.9478474855423, 70.94077214598656, 70.02196624875069, 69.83569264411926, 72.42370337247849, 73.71425852179527, 68.77533674240112, 68.05226594209671, 69.47794184088707, 68.57224524021149, 68.62470522522926, 72.21852198243141, 71.93412244319916, 74.33387607336044, 67.98840656876564, 69.91942495107651, 69.79683592915535, 71.59600898623466, 69.8346135020256, 67.3086230456829, 63.50364401936531, 59.550605937838554, 54.193197414278984, 53.30201603472233, 51.06942303478718, 43.50424937903881, 42.9892136156559, 63.45183379948139, 68.37860003113747, 68.04018259048462, 55.13385593891144, 61.55642710626125, 48.57625901699066, 27.804322130978107, 13.69798282161355, 2.809442658908665, 1.0180331789888442, 0.12608189543243498, 0.06961184160900302, 2.0541569497436285, 2.263691481202841, 0.37677546206396073, 0.478632262093015, 0.45311903581023216, 1.4223800506442785, 0.27184486447367817, 0.024989886005641893, 0.77545176143758, 62.66752928495407, 48.62005926668644, 29.967489056289196, 44.54438276588917, 40.30273877084255, 61.55990391969681, 6.387433027848601, 0.1697072951355949, 0.08270702994195744, 0.18111799377948046, 0.046248798971646465, 0.047323009493993595, 0.010688051825127332, 0.0012600205286616983, 0.04181549076747615, 0.05059007344243582, 0.059672224379028194, 0.049280887833447196, 0.057289997130283155, 0.02279119929880835, 0.11985481629380956, 0.09974987246096134, 0.11497137325932272, 0.14808559441007674, 0.13554028555518016, 0.14665872644400224, 0.17063368839444593, 0.0958480681583751, 0.19957781885750592, 0.18752344069071114, 0.13268123584566638, 0.2842588280327618, 0.21673766837920994, 1.086403385270387, 18.551292344927788, 92.71250188350677, 61.97374351322651, 81.41061633825302, 61.08410865068436, 112.33695164322853, 30.062339566648006, 0.6933395331725478, 0.17946901585673913, 1.6840014746412635, 1.2181096617132425, 1.284297478850931, 1.0166309354826808, 0.8295562269631773, 1.1196286836639047, 3.485447522252798, 2.3604404646903276, 4.777906844392419, 5.8925775066018105, 1.9783763098530471, 3.3673158986493945, 70.7756558060646, 69.58268702030182, 87.61182278394699, 83.39566022157669, 90.89954316616058, 90.93319416046143, 87.71003231406212, 88.51149290800095, 90.04082724452019, 87.56471291184425, 90.91582909226418, 88.40986356139183, 85.97439184784889, 82.36327841877937, 88.39419320225716, 87.46481627225876, 84.6390675008297, 84.67083379626274, 81.94485247135162, 79.72238972783089, 78.91399070620537, 83.9737232029438, 81.7902159690857, 82.97302410006523, 77.24679216742516, 76.78808078169823, 82.84830719232559, 86.20693936944008, 83.81775677204132, 78.13185587525368, 80.32701328396797, 81.81087166070938, 76.91782101988792, 86.51621237397194, 84.45568934082985, 79.33104112744331, 83.25487017631531, 81.77550315856934, 78.54283422231674, 84.51334744691849, 79.52600106596947, 79.07779231667519, 70.1112462580204, 76.23596280813217, 80.506432056427, 70.40338218212128, 66.2973453104496, 78.81864622235298, 79.99516949057579, 79.59013402462006, 68.42757940292358, 76.57918319106102, 69.75180834531784, 72.75963574647903, 78.3249843120575, 74.83082100749016, 66.6424959897995, 61.856071427464485, 64.77488100528717, 69.75828319787979, 69.3034628033638, 71.6575200855732, 70.53154930472374, 72.83484891057014, 71.3334658741951, 71.86143234372139, 72.17388197779655, 71.03827491402626, 71.39436900615692, 69.69827681779861, 67.86957934498787, 65.92684999108315, 65.54961383342743, 73.35759446024895, 72.82107844948769, 75.00377252697945, 76.09047621488571, 76.04139804840088, 80.54981052875519, 70.4758670926094, 72.61539548635483, 72.38389670848846, 70.46990141272545, 73.60843420028687, 77.62613341212273, 77.10268869996071, 77.92694047093391, 71.03249922394753, 75.49925073981285, 76.28377184271812, 74.20474380254745, 74.592125415802, 72.1661227941513, 69.01500508189201, 63.64793747663498, 57.854031175374985, 58.75592418015003, 56.19293890893459, 55.51930345594883, 51.18977017700672, 67.74768188595772, 64.58060503005981, 65.89408814907074, 60.083588138222694, 66.44331827759743, 53.22907514870167, 31.23894263058901, 17.36317589879036, 3.8370075076818466, 2.721912218257785, 0.3329215105623007, 1.6891323868185282, 4.796277908608317, 6.304429806768894, 2.0179831283167005, 1.253411192446947, 0.41186874615959823, 3.8318416848778725, 0.8980322338175029, 0.15092347806785256, 1.0935624386183918, 69.98268395662308, 61.08944356441498, 49.937391579151154, 52.1181895583868, 46.968113109469414, 72.16974020004272, 6.86348763294518, 0.5203795235138386, 0.3259051573695615, 0.3119635273469612, 0.1310924460995011, 0.17887244786834344, 0.26003319828305393, 0.13812076271278784, 0.12970584706636146, 0.15781314665218815, 0.14979864936321974, 0.25103902153205127, 0.12394667719490826, 0.17458425922086462], [0.06080026658310089, 0.02383077564445557, 0.03948832716559991, 0.05976615801046137, 0.09870540350675583, 0.018182195053668693, 0.0032439193773825536, 0.042465359802008606, 0.006251995355341933, 0.07807275556842797, 0.01491432216425892, 0.019248969256295823, 0.03508178822812624, 0.046431170630967245, 36.19476020336151, 63.51682931184769, 42.934089973568916, 45.44800087809563, 47.273305132985115, 75.45889690518379, 3.168198033235967, 0.29203027195762843, 0.17460653849411756, 0.08420561163802631, 0.33772047492675483, 0.6223827344365418, 0.29892221151385456, 0.10504593476071022, 0.09548509115120396, 1.6966923186555505, 2.377329608425498, 0.6306520407088101, 0.3959902888163924, 0.4633727855980396, 30.38761731237173, 62.06549718976021, 79.58728417754173, 82.13303357362747, 81.31244480609894, 77.52983897924423, 80.05442351102829, 79.4754409790039, 81.89413279294968, 74.86197173595428, 82.8273019194603, 82.966138869524, 79.37407001852989, 79.20781373977661, 79.98050227761269, 77.60315224528313, 76.36352196335793, 69.3951366841793, 68.1842328608036, 66.04595839977264, 67.22109094262123, 67.77437925338745, 66.44499018788338, 63.77062529325485, 70.54869398474693, 74.28336918354034, 75.88678434491158, 70.4487669467926, 73.54901298880577, 72.55226567387581, 75.90319946408272, 74.59371373057365, 77.84041911363602, 76.53162494301796, 76.01565062999725, 76.1918243765831, 78.60161706805229, 74.01394084095955, 73.07516321539879, 77.10479378700256, 75.33659666776657, 71.70918971300125, 62.9871491342783, 74.56204622983932, 63.852168917655945, 58.12765069305897, 64.71465423703194, 73.99323955178261, 72.52939850091934, 74.14661452174187, 59.00641433894634, 63.62410515546799, 69.12624031305313, 63.00281949341297, 66.87618345022202, 67.99850642681122, 72.53806203603745, 72.91255474090576, 65.60024991631508, 57.05189421772957, 53.75172570347786, 58.35213504731655, 65.55568590760231, 64.12664338946342, 69.12564754486084, 70.69791197776794, 68.33450719714165, 68.76781314611435, 65.35483628511429, 65.36036878824234, 60.340792536735535, 62.8711261600256, 59.575293213129044, 60.70214934647083, 60.52992358803749, 62.50926397740841, 65.10490089654922, 68.19377794861794, 65.91997236013412, 70.40637642145157, 69.22752767801285, 68.1273727118969, 64.37917023897171, 62.728436216712, 66.7866450548172, 68.69624018669128, 74.57524672150612, 70.9218567609787, 69.10567581653595, 66.27223625779152, 66.53240829706192, 73.25620830059052, 67.96221077442169, 62.81767062842846, 61.88865467905998, 53.23592238128185, 49.79427985846996, 46.689052283763885, 47.90793567895889, 30.227108225226402, 32.287718653678894, 48.8036198168993, 59.074552282691, 56.9794625043869, 45.93585290014744, 51.72961100935936, 40.8056265860796, 6.840008217841387, 13.40870339423418, 6.407355833798647, 0.2626907400554046, 1.0623352392576635, 0.10106878020451404, 0.27807932056020945, 0.33168868452776223, 0.4605321411509067, 0.1449467401835136, 0.3174521547043696, 0.18108566582668573, 0.23397303884848952, 0.3700279741315171, 0.5042840028181672, 22.83321037888527, 59.09294329583645, 20.943288691341877, 50.5476388335228, 34.85267221927643, 51.805625930428505, 4.977021859958768, 0.10415776952868327, 0.09313623828347772, 0.009002563947433373, 0.027288528872304596, 0.01578452927788021, 0.012285726006666664, 0.02744515357335331, 0.044003234506817535, 0.0814134516986087, 0.08898548054276034, 0.03924789358279668, 0.032377127499785274, 0.022865107930556405, 0.07350971252890304, 0.015073865361046046, 0.03053394622838823, 0.04668334870075341, 0.11791201468440704, 0.03166231312206946, 0.059494754605111666, 0.020157829276286066, 0.008840593000059016, 0.06513978587463498, 0.029288030564202927, 0.06705464562401175, 0.030078571835474577, 0.047091567030292936, 43.80506403744221, 70.87188184261322, 59.99411813914776, 46.39359913766384, 45.04334919154644, 91.37764871120453, 4.8938139248639345, 0.38096746837254614, 0.08459739881800488, 0.13598812714917585, 0.23036103579215705, 0.4849183716578409, 0.07892180219641887, 0.14847554848529398, 0.2724403637694195, 3.3037692960351706, 3.658832930959761, 0.49445565207861364, 0.485024765948765, 0.9260257473215461, 39.46140691637993, 74.70235750079155, 89.9398210644722, 89.6594949066639, 89.98190760612488, 84.73445758223534, 86.56304106116295, 83.75097155570984, 88.86136293411255, 79.11417156457901, 84.68311473727226, 86.68799355626106, 85.06845206022263, 81.87685132026672, 84.75862428545952, 81.78393110632896, 78.98412734270096, 75.34843683242798, 71.7594838142395, 68.26677963137627, 70.46537965536118, 71.58486038446426, 70.52752152085304, 65.73964163661003, 69.5421127974987, 75.56399166584015, 80.78175768256187, 75.30522555112839, 76.63634732365608, 77.19034999608994, 79.61998522281647, 77.71054968237877, 82.36336961388588, 79.08922210335732, 78.96340325474739, 78.0423478782177, 79.85201597213745, 76.1693523824215, 77.64431923627853, 79.10278737545013, 77.22751960158348, 71.44731536507607, 69.76905182003975, 76.50402322411537, 67.13824778795242, 64.4633661210537, 73.96230921149254, 77.45956555008888, 73.1608334183693, 74.39739346504211, 61.869070529937744, 67.6393648982048, 70.7802003622055, 69.78594571352005, 71.30051404237747, 72.0502670109272, 74.68004509806633, 77.1738512814045, 68.64349901676178, 59.85428184270859, 58.11994470655918, 57.60036438703537, 65.52560672163963, 66.28922134637833, 70.8497366309166, 72.2438134253025, 69.94165375828743, 72.60376811027527, 68.012216091156, 67.54741743206978, 65.68218871951103, 66.39034152030945, 63.86628895998001, 64.04619410634041, 62.92656898498535, 66.68256863951683, 68.87465581297874, 68.21125701069832, 67.7560642361641, 71.6831611096859, 71.74834281206131, 70.80934479832649, 69.6571934223175, 66.70789808034897, 67.11177080869675, 69.51287716627121, 74.8688417673111, 70.94115972518921, 72.17184528708458, 65.53395107388496, 68.59809905290604, 71.07240468263626, 71.36655449867249, 67.97690838575363, 66.80640399456024, 64.46068346500397, 62.483311370015144, 53.71073730289936, 53.90263840556145, 41.956011056900024, 40.75338698923588, 51.12170822918415, 63.58239859342575, 66.4736558496952, 61.20945252478123, 57.26787842810154, 56.256988272070885, 35.52132993936539, 26.676067672669888, 11.379661671817303, 0.2158528205472976, 2.0894162077456713, 0.08741087323869579, 0.40533143444918096, 0.5653440544847399, 0.11630300141405314, 0.508235968882218, 0.5324993294198066, 0.31843903299886733, 0.3552505373954773, 0.417349417693913, 0.3970271581783891, 25.934674255549908, 65.31021147966385, 21.514215655624866, 46.04230418801308, 42.41513282060623, 61.92265905439854, 8.13213363289833, 0.16742194042308256, 0.12897432694444433, 0.025415411219000816, 0.019404467748245224, 0.03750828829652164, 0.11131247389130294, 0.0715885593672283, 0.034358346383669414, 0.02643886811711127, 0.08550473372451961, 0.027039232190873008, 0.04514206753810868, 0.03429577591305133, 0.22608718543779105, 0.13748998171649873, 0.1488810876617208, 0.18823416583472863, 0.24872513866284862, 0.13824676454532892, 0.2006583265028894, 0.08534066713764332, 0.12694691307842731, 0.15890171402134, 0.13501744251698256, 0.1432183524593711, 0.16365895484341308, 0.13920619821874425, 51.84130981564522, 83.42055648565292, 57.79098495841026, 63.60177755355835, 66.90356478095055, 98.2304897904396, 7.5405338779091835, 0.5662579054478556, 0.439020634512417, 0.35875834291800857, 1.251177506055683, 2.2459167474880815, 1.0285216849297285, 0.4050926706986502, 0.3629214648390189, 5.730662019923329, 5.662078075110912, 1.081046147737652, 2.669321377761662, 0.9703011496458203, 54.94663618505001, 79.83060032129288, 93.48504602909088, 94.38704162836075, 93.69139775633812, 90.24682179093361, 94.32717964053154, 90.56179448962212, 94.67445820569992, 83.0856728553772, 84.91698458790779, 92.00437188148499, 88.61902713775635, 86.8434888124466, 89.55161109566689, 85.33176273107529, 82.57117286324501, 80.14096766710281, 78.81217896938324, 74.14265513420105, 81.50625720620155, 79.6576564013958, 78.13056394457817, 74.26886156201363, 78.4025077521801, 80.83163380622864, 84.62871685624123, 78.92288222908974, 79.78226691484451, 79.46118414402008, 83.52903306484222, 79.73256558179855, 84.51243549585342, 81.84163480997086, 81.99211433529854, 81.15659236907959, 85.69906622171402, 80.72290644049644, 79.30929109454155, 83.65791454911232, 80.648772418499, 78.29398557543755, 70.24325117468834, 79.97126117348671, 72.22407728433609, 66.98283612728119, 72.66771867871284, 80.23001968860626, 78.10802355408669, 80.80830305814743, 68.49912196397781, 68.88097867369652, 75.40034964680672, 70.70738106966019, 72.2691884636879, 75.66626697778702, 79.2729726433754, 81.62451446056366, 71.4277920126915, 62.50714369118214, 61.371057853102684, 62.565839141607285, 69.9166738986969, 69.17846471071243, 74.55059364438057, 75.554089397192, 74.20852079987526, 75.27272209525108, 69.97372403740883, 69.03534919023514, 67.48161256313324, 68.34852084517479, 68.07330921292305, 65.79215481877327, 63.98653730750084, 71.27098202705383, 73.46068292856216, 73.5551306605339, 73.5862585902214, 76.03735506534576, 76.85877218842506, 72.55829975008965, 71.60126030445099, 68.20079237222672, 73.05017575621605, 75.9719605743885, 80.9579162299633, 76.18433117866516, 74.55309391021729, 69.4371472299099, 72.04689279198647, 75.1247276365757, 77.01444983482361, 72.01926067471504, 71.53556942939758, 67.86803662776947, 63.240800723433495, 57.41437576711178, 61.726980954408646, 49.064791202545166, 47.67044082283974, 60.25823436677456, 70.24171605706215, 64.81883704662323, 58.09093326330185, 60.319019705057144, 63.0998282879591, 41.08491539955139, 33.136190325021744, 14.796985499560833, 0.5491919524502009, 3.0468950048089027, 0.2290396863827482, 1.0350674274377525, 1.306780397426337, 1.0061135748401284, 0.9818513423670083, 0.8010806143283844, 1.8492073472589254, 1.0025842767208815, 1.4763731346465647, 1.1357545433565974, 34.22712318599224, 74.76034238934517, 33.7518484890461, 65.38741573691368, 44.698646888136864, 76.66866838932037, 10.748858470469713, 0.3443245205562562, 0.20111900725169107, 0.14591271959943697, 0.1728668255964294, 0.1489789769402705, 0.24620038195280358, 0.291644295793958, 0.06435408155084588, 0.10345730828703381, 0.1555666804779321, 0.14321107941213995, 0.2564289729343727, 0.1001840659591835], [0.13128423190210015, 0.0047202605310303625, 0.02067544759484008, 0.0437002564285649, 0.026678474205255043, 0.03652423758467194, 0.0805007510643918, 0.031116550708247814, 0.003732458726517507, 0.001524023909951211, 0.1156400705804117, 0.04914867793559097, 0.07045348902465776, 0.35375303181353956, 49.85547177493572, 51.122707575559616, 34.32893492281437, 32.65961229801178, 52.05962710082531, 56.07188120484352, 0.59095473960042, 0.09460041401325725, 0.45480540313292295, 0.25358363811392337, 0.23773660330334678, 0.3014844615245238, 0.2796284796204418, 0.6431052193511277, 2.3159085167571902, 0.7242641737684608, 0.8629636780824512, 0.18527773150708526, 1.5785014419816434, 19.360952898859978, 66.89804747700691, 80.01860663294792, 87.34937846660614, 80.41153594851494, 83.52307498455048, 84.26638349890709, 78.08823421597481, 82.61936947703362, 81.64991229772568, 83.09666186571121, 80.10582715272903, 80.67024126648903, 76.15660786628723, 75.76474249362946, 69.67749953269958, 75.96255987882614, 74.57777738571167, 71.71479821205139, 67.82903552055359, 65.29346957802773, 63.375131115317345, 62.549066841602325, 64.59521144628525, 67.53759875893593, 64.82127651572227, 60.68219281733036, 68.79357576370239, 73.19532036781311, 69.08776357769966, 76.77507027983665, 79.93108212947845, 78.52782502770424, 74.52228516340256, 75.55927991867065, 75.59054464101791, 75.4908835887909, 76.59678384661674, 74.65517923235893, 76.18224889039993, 72.53047004342079, 66.74825191497803, 62.292128428816795, 77.70111098885536, 65.55459156632423, 59.17399674654007, 73.34976688027382, 75.39500713348389, 66.35090723633766, 77.94858410954475, 60.628995671868324, 65.04616364836693, 75.75913399457932, 68.2930514216423, 70.91342121362686, 63.34416277706623, 65.68964391946793, 64.68729570508003, 64.49536800384521, 63.53682763874531, 65.78690350055695, 58.25721234083176, 51.99638329446316, 56.24394737184048, 65.96889853477478, 62.790441289544106, 69.68933209776878, 69.88269612193108, 74.55089002847672, 67.78931245207787, 69.22666132450104, 70.13747245073318, 66.06051921844482, 63.44436340034008, 59.89790730178356, 61.96300528943539, 59.25251193344593, 60.744691863656044, 64.96923297643661, 64.95510533452034, 68.63827809691429, 69.71227526664734, 67.91395336389542, 65.55247887969017, 62.70850628614426, 63.29322271049023, 64.59350913763046, 70.76960653066635, 68.48171889781952, 71.3958129286766, 70.40807873010635, 69.34723645448685, 69.58646401762962, 70.79875096678734, 65.27713045477867, 64.6262937784195, 63.378794118762016, 54.13044758141041, 42.69212655723095, 43.53048697113991, 49.475970938801765, 32.1816473454237, 28.508317954838276, 55.280136689543724, 54.28274340927601, 49.51585739850998, 42.3994130641222, 41.14903315901756, 20.180152840912342, 8.939527608454227, 16.819335781037807, 2.7958797616884112, 0.09896900694002397, 0.3293598548043519, 0.05746309194364585, 0.37912872328888625, 0.28207382652908564, 0.2916431677294895, 0.16350950114428997, 0.22924364340724424, 0.22601908596698195, 0.25834240776021034, 0.211876155808568, 4.179751966148615, 55.872125923633575, 30.94799604266882, 39.2071283608675, 26.57633252441883, 54.46492463350296, 9.009310863912106, 0.09659306568210013, 0.098218287457712, 0.02735419780947268, 0.06299737622612156, 0.09406933313584886, 0.09283401348511688, 0.08115354416077025, 0.05307317340339068, 0.06127951586677227, 0.046386151952901855, 0.05871964443940669, 0.030201154222595505, 0.00334614094299468, 0.04913768672849983, 0.05494571589224506, 0.001442018910893239, 0.032562742344453, 0.020118994543736335, 0.013056712614343269, 0.005389757980083232, 0.04021166510938201, 0.027985106826236006, 0.013927724030509125, 0.042513580847298726, 0.03995454062533099, 0.04181250733381603, 0.5353886587545276, 61.20844937860966, 61.65572717785835, 58.58851656317711, 27.725901938974857, 52.37666688859463, 67.4538816511631, 0.6612268032040447, 0.08336747458088212, 0.5446854536421597, 0.16607289406238124, 0.3507199930027127, 1.485556410625577, 0.6579870614223182, 1.801777936052531, 4.627371747046709, 0.9721550345420837, 1.1186780221760273, 0.4753609048202634, 2.4814273975789547, 26.19719836860895, 80.92556476593018, 89.85092863440514, 96.99373215436935, 88.59131902456284, 89.86906886100769, 90.01479104161263, 87.17129722237587, 87.42877900600433, 87.64168158173561, 83.35731267929077, 83.77501666545868, 82.99766957759857, 80.58287635445595, 77.94839411973953, 75.55268347263336, 77.75081992149353, 77.03426957130432, 74.50223743915558, 72.59094759821892, 71.45979389548302, 70.78992784023285, 71.76380798220634, 73.52702736854553, 76.42357394099236, 73.25159534811974, 67.85266265273094, 72.76870205998421, 77.61249974370003, 75.86873531341553, 78.9086177945137, 81.62585958838463, 81.47249981760979, 77.09520310163498, 76.86157643795013, 77.4767330288887, 77.71450147032738, 79.20152887701988, 77.07060322165489, 75.95736935734749, 73.4384161233902, 68.13818693161011, 69.7896771132946, 79.15778562426567, 67.04204455018044, 69.0259636938572, 79.83099550008774, 76.88920855522156, 71.15486785769463, 77.37861469388008, 59.9418481439352, 70.31119152903557, 77.34133869409561, 72.86338537931442, 73.28611269593239, 70.26924937963486, 69.65321123600006, 68.86943489313126, 65.13410612940788, 64.5534060895443, 67.7495589852333, 62.24604830145836, 54.43772949278355, 55.93722403049469, 66.90573066473007, 63.50540712475777, 69.61005315184593, 70.86701050400734, 76.01061210036278, 73.75886052846909, 70.23571997880936, 73.3825135231018, 71.35035216808319, 66.68240144848824, 64.51237589120865, 65.98930343985558, 62.94252432882786, 62.91066683828831, 65.50218477845192, 65.69782868027687, 69.50565755367279, 72.39982545375824, 69.9910207092762, 69.45888966321945, 67.33812466263771, 67.39231735467911, 66.00982993841171, 70.36358311772346, 70.74384391307831, 69.97359484434128, 71.75163343548775, 68.94255816936493, 71.27862721681595, 72.27887034416199, 70.88924691081047, 66.26174882054329, 65.90403601527214, 64.65198040008545, 56.554128527641296, 48.60410772264004, 53.61821986734867, 38.664623871445656, 37.53081791102886, 59.39134508371353, 65.3545854985714, 66.56672045588493, 61.08795024454594, 54.03904728591442, 50.06153851747513, 25.039774775505066, 26.556157507002354, 5.447091311216354, 0.09855717435129918, 0.37481138308066875, 0.014072744324948872, 1.0490657575428486, 0.9070868510752916, 0.18779160833219066, 0.5993384553585202, 0.25543802767060697, 0.08615548591478728, 0.198473903874401, 0.04412298745592125, 5.704108094796538, 67.53130629658699, 28.99988617748022, 40.45965515077114, 37.070666402578354, 60.99416367709637, 12.14736582711339, 0.14883621741319075, 0.12962903478182852, 0.06417687152861618, 0.06035789832822047, 0.05882425015443005, 0.04004434420494363, 0.03407313903153408, 0.024406338998232968, 0.031105581765586976, 0.011578591002034955, 0.07295330957276747, 0.026136316773772705, 0.1231430796906352, 0.34651385620236397, 0.18043006741208956, 0.1088003559561912, 0.08151944522978738, 0.11771860357839614, 0.09344410340418108, 0.2075406478252262, 0.08623923728009686, 0.1107007364043966, 0.11333438102155924, 0.25844283518381417, 0.2530279476195574, 0.18633076484547928, 0.9733567200601101, 72.81952813267708, 67.90932521224022, 46.09433479607105, 50.34523889422417, 70.47656625509262, 74.99629452824593, 0.6473681749776006, 0.19209214631700888, 0.63142987084575, 0.5063618975691497, 0.8968710398767143, 3.2948079518973827, 3.635637075640261, 3.002195628359914, 7.768412875011563, 3.046283950097859, 2.263187295757234, 1.6125929751433432, 3.410637849010527, 33.34056995809078, 90.8018048107624, 93.48220378160477, 100.92239454388618, 91.11797824501991, 93.34771379828453, 93.6495392024517, 89.86017733812332, 91.85108050704002, 92.23346918821335, 84.4108897447586, 88.30529317259789, 88.72659176588058, 85.55190771818161, 83.99321615695953, 81.02846324443817, 86.319550126791, 83.02265703678131, 80.26171758770943, 79.98232617974281, 80.599724650383, 80.81892728805542, 79.07080829143524, 79.06514659523964, 80.85282906889915, 80.13036623597145, 75.73623642325401, 80.58901682496071, 81.81978598237038, 80.45977056026459, 82.31035485863686, 85.11743903160095, 86.44721567630768, 81.59559801220894, 78.98145988583565, 82.35311016440392, 80.78990444540977, 84.83258351683617, 81.05393707752228, 82.29466170072556, 78.65017846226692, 72.54698395729065, 70.01918479800224, 83.54227915406227, 71.29849255084991, 67.38456577062607, 82.5151638686657, 81.67613089084625, 72.41750970482826, 81.89901173114777, 67.00765639543533, 72.19135344028473, 81.50648519396782, 75.87635770440102, 76.98770686984062, 69.2920558154583, 72.34592154622078, 72.49459996819496, 69.21808138489723, 67.87262678146362, 69.54503864049911, 64.23420041799545, 57.353807017207146, 60.977277383208275, 72.34266892075539, 68.83101135492325, 76.64425849914551, 73.70542779564857, 78.83000761270523, 73.67141202092171, 73.40964406728745, 74.12912026047707, 75.1139286160469, 67.45461881160736, 65.07843151688576, 67.65636518597603, 66.59880593419075, 66.29453346133232, 70.55395290255547, 69.00599956512451, 75.72920680046082, 76.97237089276314, 74.74869221448898, 70.6306403875351, 69.16662454605103, 69.11389097571373, 69.88404124975204, 75.0576688349247, 73.16397964954376, 75.58638006448746, 75.14975309371948, 72.09559097886086, 74.1693677008152, 75.0242306292057, 75.04442274570465, 71.45543172955513, 70.4131780564785, 67.00927510857582, 55.08682206273079, 57.32595071196556, 64.01644930243492, 49.287478253245354, 51.57431334257126, 67.32222631573677, 66.3117465376854, 59.944834783673286, 57.23041623830795, 55.02315267920494, 54.04813639819622, 29.755682721734047, 33.5251222550869, 5.716436533257365, 0.9352806257084012, 0.84568653954193, 0.22164583235280588, 2.004579585045576, 2.163709346204996, 1.3718140264973044, 0.9082826587837189, 1.173625448718667, 0.3521885845111683, 1.543585353065282, 0.7595931936521083, 9.202312957495451, 73.41605052351952, 47.49392129480839, 54.20245751738548, 36.064772978425026, 75.41056349873543, 13.869779203087091, 0.36615114309825003, 0.2414349775062874, 0.14015003194799647, 0.19207840174203739, 0.28448352066334337, 0.16359125613234937, 0.13517198734916747, 0.1737791477353312, 0.20100649766391143, 0.08863388808094896, 0.18769235350191593, 0.1284440772724338, 0.2728154155192897], [0.043650517691276036, 0.0664441252592951, 0.04832843776966911, 0.02655735755979549, 0.016889522230485454, 0.033594097549212165, 0.02773106225504307, 0.0731415108020883, 0.05355590707040392, 0.12595087668159977, 0.049641018704278395, 0.016950331955740694, 0.1697680473444052, 7.567146699875593, 69.19151321053505, 37.76862055063248, 40.4946056753397, 29.725871421396732, 75.01330241560936, 26.870524138212204, 0.34785022668074816, 0.49989381339401007, 0.6694359064567834, 0.025819239745032974, 0.2239435660885647, 0.37110931298229843, 0.6771191535517573, 1.7320234165526927, 2.528492147102952, 0.18549558153608814, 0.6127133220434189, 1.784550966694951, 20.090040676295757, 65.25376170873642, 79.39261302351952, 87.41195350885391, 88.10582667589188, 88.0853533744812, 84.91449192166328, 85.04550889134407, 82.18824461102486, 84.85837653279305, 87.29241952300072, 85.47800168395042, 83.63571614027023, 79.74011957645416, 77.06336840987206, 73.06272268295288, 71.95703521370888, 66.30629763007164, 65.98309457302094, 67.01549917459488, 59.36484910547733, 56.57468922436237, 61.610718593001366, 59.293093755841255, 59.46725361049175, 67.35519334673882, 72.28155300021172, 73.89021188020706, 71.00656181573868, 71.50730654597282, 73.52338716387749, 75.46960473060608, 77.41945490241051, 80.76033443212509, 73.68465051054955, 79.07612040638924, 75.74595630168915, 75.31330391764641, 71.36748924851418, 72.50507980585098, 69.6765647828579, 65.66726312041283, 68.97527441382408, 77.71097525954247, 63.354148641228676, 66.22098460793495, 74.48117136955261, 69.50792223215103, 65.16690596938133, 75.92732056975365, 58.220012336969376, 55.75096942484379, 74.11520540714264, 63.397409319877625, 67.64311149716377, 66.26324594020844, 69.00878861546516, 64.28871229290962, 69.47718188166618, 65.11604949831963, 64.9432423710823, 68.17079678177834, 72.63332292437553, 60.659325644373894, 55.061264634132385, 54.61646430194378, 63.92748087644577, 60.001185759902, 64.87511962652206, 66.71216145157814, 72.48852029442787, 69.18071419000626, 72.12895318865776, 67.23413184285164, 65.54961383342743, 65.4072430729866, 63.32551337778568, 62.99707420170307, 61.156129986047745, 57.23691388964653, 65.99536791443825, 66.24646604061127, 68.44047591090202, 66.02467954158783, 66.31056100130081, 65.62968313694, 66.1507035791874, 64.89846557378769, 65.12231156229973, 67.6304429769516, 67.29599252343178, 68.43403905630112, 68.37796166539192, 66.6863152384758, 71.09415471553802, 66.87946647405624, 66.62257745862007, 61.62393048405647, 57.79764600098133, 48.055705949664116, 47.71068446338177, 44.63234804570675, 31.264500059187412, 28.358074016869068, 50.473736599087715, 55.577155351638794, 48.652821108698845, 45.18513098359108, 36.836857348680496, 27.19014398753643, 9.951962381601334, 10.595108270645142, 12.842377033084631, 1.4274309296160936, 0.7353399856947362, 0.033188625166076235, 0.30844761757180095, 1.868598775472492, 0.8417668123729527, 0.6964857643470168, 0.3897097602020949, 0.2686986332992092, 0.24324918718775734, 0.18921476555988193, 0.16548391082324088, 40.71911662817001, 31.40194058418274, 43.1203293800354, 37.212311401963234, 48.60989101231098, 17.18268558382988, 0.4369513486744836, 0.17885515582747757, 0.11972980893915519, 0.08882110967533663, 0.0864125436055474, 0.0628002395387739, 0.029990619914315175, 0.06516686684335582, 0.022014821915945504, 0.02676652631635079, 0.07351727501372807, 0.08874459424987435, 0.03637865047494415, 0.03805404143349733, 0.1224741003534291, 0.06052055112377275, 0.05868232183274813, 0.04235522879753262, 0.01836794905102579, 0.023156720017141197, 0.003037493784177059, 0.022834099145256914, 0.04828057295526378, 0.019855715800076723, 0.1085029699606821, 0.36334793257992715, 9.902477636933327, 75.87226152420044, 50.059923604130745, 49.011787846684456, 29.53682206571102, 88.33148896694183, 33.95110219717026, 0.4947825236013159, 0.17868551571154967, 0.542303693946451, 0.08236848443630151, 0.4286840610438958, 0.22427555843023583, 2.197603527456522, 2.166479635052383, 3.083565649576485, 0.5141482735052705, 0.6813468423206359, 2.2995000472292304, 25.281892083585262, 77.88113012909889, 89.71617266535759, 96.3183031976223, 93.43033656477928, 94.18037071824074, 89.4381719827652, 88.06097388267517, 86.79610535502434, 91.95500493049622, 88.97438406944275, 89.69540297985077, 88.10217887163162, 83.60542416572571, 80.70360347628593, 75.86545988917351, 73.03517416119576, 72.83835232257843, 73.47174033522606, 73.42940300703049, 65.55448517203331, 66.94397941231728, 68.80259647965431, 66.6063143312931, 65.21467700600624, 70.76272889971733, 77.62273639440536, 82.30172172188759, 81.46570578217506, 78.36052760481834, 81.70204550027847, 78.01733762025833, 81.17603972554207, 80.2241300046444, 78.22963982820511, 81.26954510807991, 79.98323813080788, 78.73467072844505, 75.8586810529232, 74.29943472146988, 69.27779138088226, 70.1178503036499, 73.7529556453228, 74.78089928627014, 65.79522505402565, 72.7222989499569, 78.19131508469582, 72.51198023557663, 72.93212369084358, 81.25417113304138, 59.8195631057024, 62.4467459321022, 73.97767558693886, 66.6898262500763, 69.58255782723427, 69.09844100475311, 74.42596033215523, 69.75257590413094, 70.92326268553734, 65.50670653581619, 67.73866876959801, 67.87316635251045, 73.81230846047401, 65.30419260263443, 59.654982537031174, 55.25823086500168, 65.26865690946579, 62.493954598903656, 67.57889494299889, 66.77495688199997, 72.85036727786064, 70.17974898219109, 73.4429682791233, 69.72646370530128, 67.47397497296333, 68.3860856294632, 67.93439626693726, 66.62741079926491, 63.74568723142147, 61.289088651537895, 66.37410879135132, 67.36514881253242, 71.01058200001717, 68.18633794784546, 69.30730059742928, 67.21974581480026, 68.63589942455292, 67.94783994555473, 67.08546102046967, 70.02699717879295, 70.011425614357, 70.64741268754005, 67.73605450987816, 65.61625465750694, 71.91149085760117, 68.20691764354706, 67.26704567670822, 66.1912702023983, 62.00782768428326, 59.069753140211105, 57.6406954228878, 52.01616883277893, 41.33744604885578, 38.72153341770172, 55.19402951002121, 62.568103820085526, 68.59757468104362, 64.26857337355614, 59.54837545752525, 52.310447841882706, 38.302708491683006, 23.57228022068739, 20.319185480475426, 2.3341798363253474, 0.9985570865683258, 0.11733189268852584, 0.24514286604244262, 4.085628166794777, 0.5418561492115259, 0.46223626064602286, 0.4302616888890043, 0.32636668416671455, 0.36457793845329434, 0.12233403482241556, 0.14656678918981925, 49.13802467286587, 36.680066362023354, 38.56528580188751, 43.41453239321709, 55.78103721141815, 22.32046589255333, 0.3924114746041596, 0.32566054549533874, 0.11136554487165995, 0.10434369236463681, 0.10410282091470435, 0.03835301562503446, 0.051763538795057684, 0.07181328168371692, 0.04515888089372311, 0.045086235768394545, 0.10534796660067514, 0.06926018235390075, 0.033169481466757134, 0.16545878170290962, 0.2659918722929433, 0.1350075422669761, 0.09017972231958993, 0.09749407006893307, 0.16487281158333644, 0.07714031380601227, 0.14471262227743864, 0.1481845078524202, 0.20288183062803, 0.14804372243816033, 0.19801436603302136, 0.4879910411546007, 11.92549953237176, 94.8761285841465, 50.495722219347954, 52.395753264427185, 49.81151953339577, 95.82597881555557, 41.251578256487846, 0.6114225788041949, 0.9682157740462571, 0.9495932108256966, 0.4484807909466326, 0.8697295119054615, 1.2825382919982076, 4.208080871030688, 5.18207548186183, 5.935567449778318, 0.9035216923803091, 1.0945776966400445, 3.128340309485793, 30.364005379378796, 90.38266450166702, 95.4852283000946, 102.58117273449898, 95.35555645823479, 95.5802384018898, 91.76018938422203, 93.78571629524231, 88.29339981079102, 94.05516743659973, 93.54566037654877, 92.58982926607132, 91.86044320464134, 88.69789570569992, 82.95955002307892, 79.07159104943275, 81.9992807507515, 81.0931433737278, 81.92944809794426, 86.17656379938126, 76.44283130764961, 73.03027242422104, 73.99258598685265, 69.15057420730591, 70.51812842488289, 74.87955719232559, 79.20060932636261, 81.93911477923393, 84.57459256052971, 81.40213519334793, 85.80998227000237, 83.67627516388893, 83.9477401971817, 84.2737703025341, 79.57673594355583, 84.87603038549423, 81.87191918492317, 82.23834112286568, 80.03789439797401, 80.48331409692764, 74.19233366847038, 75.20553410053253, 77.13803440332413, 80.2889621257782, 70.87144866585732, 73.54232534766197, 82.75631412863731, 75.8988144993782, 74.37196522951126, 83.08409214019775, 66.75882294774055, 62.70090289413929, 77.59230762720108, 70.55203780531883, 72.1543738245964, 71.659587174654, 75.38214862346649, 70.7518082857132, 75.03418609499931, 67.21150785684586, 69.32079747319221, 70.6031982600689, 77.10633650422096, 66.71376496553421, 60.04510000348091, 58.33405181765556, 68.79292219877243, 64.88271921873093, 71.69177144765854, 73.72024700045586, 76.80938243865967, 72.26771414279938, 75.73011875152588, 72.36039876937866, 70.56339159607887, 67.99001008272171, 69.5929616689682, 67.60968089103699, 65.69940939545631, 63.826246708631516, 71.34370252490044, 72.32334315776825, 75.47920301556587, 72.0205906033516, 71.4441767334938, 70.21986722946167, 72.4200327694416, 71.68640613555908, 69.70720633864403, 77.20253214240074, 73.22767943143845, 73.61431628465652, 73.76340508460999, 69.9326254427433, 75.11742442846298, 74.39540237188339, 73.3680135011673, 71.37097746133804, 68.73739957809448, 63.49013574421406, 61.90034665167332, 60.27597941458225, 50.563347190618515, 51.96121618151665, 66.44400224089622, 66.67454347014427, 66.59814476966858, 59.402539283037186, 52.895445451140404, 52.32854627072811, 42.874011397361755, 32.18595631420612, 26.615782007575035, 3.109077005647123, 1.5843721269629896, 0.25505727622658014, 0.4817677172832191, 5.1622880436480045, 1.400273668114096, 1.6432081698440015, 0.8319799625314772, 1.5056454576551914, 0.7939762424211949, 0.292924678651616, 0.2465704019414261, 59.90812495350838, 43.85984189808369, 57.973105385899544, 47.66265504062176, 67.31714978814125, 27.717855870723724, 0.5889461911283433, 0.5572148063220084, 0.20649791549658403, 0.2423011083737947, 0.31659595377277583, 0.21050347946584225, 0.20896638772683218, 0.23425453546224162, 0.17758059140760452, 0.14337714237626642, 0.15336262062191963, 0.13619138655485585, 0.12669428600929677], [0.17812586214859039, 0.05854207447555382, 0.05947351433860604, 0.01621421608433593, 0.08198266412364319, 0.061900081200292334, 0.021046257970738225, 0.005356572382879676, 0.037248343651299365, 0.03551803747541271, 0.14562593889422715, 0.05713443926651962, 0.16963132889941335, 15.089663844555616, 64.63245704770088, 34.08691070973873, 51.820616126060486, 24.67291586101055, 75.38416251540184, 11.185943316668272, 0.40631026786286384, 0.11434780593845062, 0.6480735121294856, 0.27822908596135676, 0.4717134271049872, 0.40016121813096106, 0.6085845467168838, 0.07452240271959454, 0.4354173591127619, 1.9914324092678726, 0.506760876160115, 14.876973107457161, 64.10855636000633, 78.25128346681595, 86.95533201098442, 89.24534752964973, 89.51837047934532, 85.48384577035904, 83.29828664660454, 79.67198923230171, 83.78788277506828, 81.66538506746292, 80.67661732435226, 79.8078091442585, 83.81364539265633, 80.10525718331337, 74.95961889624596, 73.71427372097969, 69.59749862551689, 68.35288301110268, 70.90809389948845, 65.79765692353249, 65.61531230807304, 72.12725847959518, 68.99618089199066, 70.11034950613976, 71.41549587249756, 70.46845749020576, 72.4925708770752, 75.09826585650444, 76.29088506102562, 73.6730383336544, 78.14450919628143, 76.45935282111168, 73.12218189239502, 76.03235453367233, 73.26079845428467, 74.06985104084015, 70.86173638701439, 72.03931599855423, 70.49234300851822, 67.62028232216835, 66.08625143766403, 71.79133370518684, 72.58941248059273, 59.06005226075649, 69.61850389838219, 74.04069140553474, 69.04779732227325, 72.02053740620613, 77.84562483429909, 55.86094692349434, 53.01876023411751, 72.27861195802689, 65.1756227016449, 71.43150061368942, 69.83859568834305, 69.12045702338219, 70.11698395013809, 67.13839218020439, 65.38047730922699, 63.40155489742756, 61.43249675631523, 63.17574441432953, 66.40731900930405, 70.74740812182426, 68.13396155834198, 60.10955594480038, 59.51427608728409, 63.341062143445015, 61.888810470700264, 60.22434018552303, 62.57085107266903, 66.79691210389137, 69.7188413143158, 67.69290402531624, 65.34019947052002, 66.76574617624283, 69.21304285526276, 67.10048541426659, 65.60792550444603, 62.83214405179024, 57.80746087431908, 64.28958624601364, 65.31753748655319, 67.10974931716919, 65.21720767021179, 64.17341887950897, 63.73264633119106, 64.7580099105835, 65.36372020840645, 65.02860099077225, 69.40815478563309, 67.72334799170494, 65.97410425543785, 60.07233314216137, 64.41667422652245, 67.37699657678604, 67.33186259865761, 65.58230727910995, 64.69237223267555, 60.42122662067413, 52.14755818247795, 47.814304903149605, 43.128282353281975, 30.059620812535286, 38.570518121123314, 51.27322129905224, 42.2624684125185, 46.44293189048767, 42.972152531147, 31.46066453307867, 14.111731220036745, 5.049658762291074, 9.07941710203886, 7.369413860142231, 0.0426286731089931, 0.795268410583958, 0.16953084210399538, 1.1276907823048532, 0.9119216166436672, 0.8190488407853991, 0.7948542921803892, 0.13528170646168292, 0.5088577698916197, 0.19692421046784148, 0.4665327613474801, 13.754095360636711, 48.046605437994, 39.556724801659584, 30.16343504190445, 45.83792835474014, 17.762251384556293, 0.3485963522689417, 0.11244906563661061, 0.08109063972369768, 0.05735654180170968, 0.09179764136206359, 0.07797946760547347, 0.045267839304869995, 0.08837181347189471, 0.037468932205229066, 0.02302743974723853, 0.054297902606776915, 0.018913295862148516, 0.06726702602463774, 0.02544922161177965, 0.03907759666617494, 0.01690682169282809, 0.06341000291286036, 0.06251192258787341, 0.019636476099549327, 0.13249338342575356, 0.060191390075488016, 0.04025214926514309, 0.03623990596679505, 0.03179275299771689, 0.0995767665153835, 0.4054422816261649, 19.312870278954506, 74.1078869998455, 42.520713955163956, 49.41843442618847, 26.22408002614975, 87.74082586169243, 14.161933176219463, 0.40053983218967915, 0.12581855175085366, 1.2419824744574726, 0.19945005071349442, 0.23182305187219754, 0.9697258961386979, 1.9387937150895596, 0.17700394266285002, 0.5968501826282591, 4.099849378690124, 1.1055488954298198, 18.571915738284588, 77.06445515155792, 88.6939287185669, 95.53730830550194, 94.59461688995361, 95.98151206970215, 90.01334711909294, 87.4865511059761, 82.43672847747803, 88.51199448108673, 86.16394847631454, 85.55212810635567, 82.31692090630531, 85.17788618803024, 85.10755956172943, 79.17389675974846, 76.23996019363403, 73.23168441653252, 73.84313240647316, 75.69820806384087, 72.6287479698658, 73.15714001655579, 75.56818664073944, 74.34512346982956, 72.83608004450798, 77.07097560167313, 74.64865878224373, 74.12095829844475, 74.14926677942276, 80.16986891627312, 81.1763209104538, 81.65827184915543, 81.94416090846062, 76.98921158909798, 76.94256529211998, 75.22835567593575, 77.51603052020073, 74.83318448066711, 72.5665833055973, 71.85416713356972, 71.02430686354637, 69.85857501626015, 74.6102124452591, 72.72660791873932, 62.73011192679405, 73.43792974948883, 73.85026842355728, 70.09814456105232, 78.57352897524834, 80.1714876294136, 57.38762900233269, 60.84779553115368, 74.17489260435104, 67.86577954888344, 74.37771052122116, 74.09302219748497, 71.13021478056908, 72.62719005346298, 69.67722594738007, 68.21995854377747, 66.86933621764183, 63.799534142017365, 64.47861090302467, 66.05541989207268, 70.68925604224205, 71.25075951218605, 64.26689386367798, 59.29677575826645, 65.06744250655174, 67.15458691120148, 63.096913844347, 63.051985055208206, 66.14699497818947, 73.4373065829277, 69.96322140097618, 69.05291184782982, 68.50534602999687, 73.01802948117256, 70.15657022595406, 68.53002190589905, 66.25468879938126, 63.844622522592545, 63.755167722702026, 65.470350086689, 68.29328700900078, 68.29183548688889, 66.61118566989899, 66.9409167766571, 67.04272091388702, 65.8824759721756, 64.76668864488602, 70.69766879081726, 68.31953600049019, 66.54408887028694, 59.21113595366478, 63.225392550230026, 68.68603393435478, 69.45543944835663, 69.44507360458374, 66.96193724870682, 64.16277945041656, 60.59159807860851, 56.943330243229866, 51.416260823607445, 37.903566509485245, 43.92091982066631, 55.945006012916565, 58.59770447015762, 66.7201030254364, 65.12285113334656, 58.350706323981285, 49.094881787896156, 29.209201745688915, 20.61576146632433, 11.109614912420511, 0.380476611899212, 0.8491092652548105, 0.07304020022274926, 0.7394543930422515, 1.114944841247052, 0.9873754740692675, 1.067280792631209, 0.30627131403889507, 0.7882063707802445, 0.2659888443304226, 0.5845555267296731, 17.780621498823166, 51.587893813848495, 38.73133309185505, 39.65565629303455, 52.6897244900465, 22.495304010808468, 0.4777515702880919, 0.19305600319057703, 0.03703551796206739, 0.10039297310868278, 0.01741610383760417, 0.07444210976245813, 0.014354875474964501, 0.0522458791238023, 0.05233963835053146, 0.07695837630308233, 0.07520764993387274, 0.019535128412826452, 0.04830667428905144, 0.27885973337106407, 0.13705833378480747, 0.1290047846850939, 0.1123329195252154, 0.1778427031240426, 0.17478554451372474, 0.15989310457371175, 0.20575615373672917, 0.18761616462143138, 0.1410248756292276, 0.18149626645026729, 0.21263112779706717, 0.4926860751584172, 21.789693273603916, 86.8571300804615, 44.13938149809837, 70.04440784454346, 39.07211400568485, 96.95710971951485, 19.473766945302486, 0.41961139475461096, 0.25849505269434303, 1.456084717065096, 0.5211169214453548, 2.4977850448340178, 2.3633900564163923, 4.189955843612552, 1.2106858100742102, 0.961932692443952, 6.68276553042233, 1.6207405691966414, 22.551749981939793, 92.18380585312843, 95.94230577349663, 100.08797451853752, 99.54906463623047, 101.52589336037636, 93.68578165769577, 91.4743535220623, 85.38173764944077, 92.7773568034172, 89.7864080965519, 88.55223432183266, 83.74123647809029, 90.18005937337875, 87.32077360153198, 82.79429689049721, 82.6160104572773, 81.01161494851112, 80.14621138572693, 80.42567878961563, 77.13469058275223, 76.27704620361328, 81.297747194767, 78.16262662410736, 76.7788852751255, 79.15688887238503, 78.155118227005, 79.64757934212685, 78.86859074234962, 80.27564764022827, 81.319869607687, 82.98039570450783, 84.50885608792305, 81.80498957633972, 82.28406026959419, 78.39679285883904, 82.35790550708771, 76.28506377339363, 78.28664436936378, 77.60858595371246, 74.13312524557114, 72.21906155347824, 77.59012654423714, 79.25772026181221, 64.87837225198746, 74.53357815742493, 78.899095505476, 72.76408910751343, 79.06702369451523, 83.78276064991951, 62.354528680443764, 59.817818999290466, 78.25936183333397, 70.55780589580536, 76.8457692861557, 77.54064559936523, 74.63260844349861, 76.19849681854248, 72.74617686867714, 73.4884974360466, 69.16380509734154, 69.81122195720673, 69.57501143217087, 71.06453150510788, 77.39824444055557, 74.29021641612053, 64.54188510775566, 63.815835267305374, 67.5689546763897, 67.24851787090302, 65.04636123776436, 67.65609920024872, 71.80543854832649, 76.90786555409431, 71.64001822471619, 71.72893345355988, 69.79099184274673, 74.411361515522, 71.67911052703857, 70.81536367535591, 65.96219569444656, 67.0458671450615, 69.87548410892487, 70.3244300186634, 73.08000415563583, 73.53081956505775, 69.0044416487217, 69.3215574324131, 71.5200586616993, 70.41330724954605, 68.7176026403904, 75.82759112119675, 73.11611741781235, 69.48145285248756, 61.672149896621704, 67.71786108613014, 73.34668904542923, 72.82401949167252, 75.92277601361275, 70.52247539162636, 69.85691830515862, 63.7445966899395, 63.42090725898743, 58.51684480905533, 49.413312301039696, 59.35429707169533, 64.43281576037407, 63.927587270736694, 63.12979727983475, 58.51386956870556, 51.567922085523605, 45.63034929335117, 36.34949930012226, 30.984538681805134, 12.533546704798937, 0.5338600126560777, 1.512365397065878, 0.24901886587031186, 2.75698599871248, 1.4322300720959902, 1.276719260495156, 2.149061132222414, 0.4230410966556519, 1.4114728546701372, 0.6887883273884654, 0.8253348316065967, 22.996949292719364, 62.39454433321953, 57.751326486468315, 39.17487949132919, 59.2823251336813, 28.090114295482635, 0.6970565649680793, 0.37211210292298347, 0.20361069386126474, 0.1644129620399326, 0.1595971212373115, 0.17800374916987494, 0.08402905470575206, 0.1698631906765513, 0.20317278220318258, 0.18243438564240932, 0.1831370807485655, 0.21035742480307817, 0.13511732075130567], [0.11478467858978547, 0.04849125754844863, 0.054785493630333804, 0.06533914900501259, 0.08889082702808082, 0.06211787185748108, 0.022197367979970295, 0.01999622105358867, 0.029904480688855983, 0.050071371588273905, 0.014986461701482767, 0.09682071206043474, 0.15567009133519605, 30.305589213967323, 55.35395912826061, 38.61314043402672, 48.38139407336712, 38.08964632451534, 69.43245068192482, 1.8463293579407036, 0.1411502540577203, 0.09877228585537523, 0.3005430323537439, 0.20752706652274355, 0.20470031508011743, 1.1789528816007078, 0.9757458418607712, 0.31679876788984984, 0.6970839353743941, 0.937424007570371, 8.571933433413506, 54.314939081668854, 80.05866408348083, 81.1491371691227, 86.9114975631237, 87.09733039140701, 85.63637718558311, 82.85599038004875, 81.23152434825897, 81.96684569120407, 81.41940146684647, 84.88185167312622, 83.01678255200386, 80.00140115618706, 80.34527510404587, 79.14193287491798, 75.92035934329033, 68.96092638373375, 68.53914141654968, 72.04913467168808, 71.7389041185379, 74.70005482435226, 72.79637217521667, 72.19377011060715, 74.41536650061607, 68.13581585884094, 73.77666637301445, 77.51860678195953, 74.18838188052177, 74.52736929059029, 77.18293279409409, 78.67427676916122, 77.80701890587807, 75.59742987155914, 72.65225350856781, 72.69939377903938, 75.71729823946953, 72.43576392531395, 70.38558393716812, 66.55362635850906, 66.62488773465157, 68.68272051215172, 75.11945351958275, 70.78632563352585, 58.57829511165619, 72.04066872596741, 73.8549117743969, 69.20428812503815, 71.1006523668766, 72.68410339951515, 55.711485743522644, 56.526507809758186, 71.00410714745522, 68.950165361166, 68.93311187624931, 64.63979825377464, 64.1046729683876, 63.45376789569855, 61.03141687810421, 62.54804849624634, 62.45484709739685, 59.01331476867199, 61.99067920446396, 59.42073650658131, 60.818328112363815, 66.8216259777546, 64.4565036892891, 69.87841755151749, 63.39846186339855, 57.513022273778915, 67.97490209341049, 64.91146087646484, 62.32846587896347, 60.35847298800945, 57.928043603897095, 65.24217993021011, 66.52714177966118, 65.08557513356209, 63.28485555946827, 67.80145660042763, 66.7181347310543, 66.61315396428108, 66.62360340356827, 58.37980516254902, 60.261540189385414, 64.73135814070702, 62.23117969930172, 64.06938806176186, 65.07245063781738, 63.91632467508316, 62.14248485863209, 63.20874944329262, 66.33954584598541, 70.35792902112007, 66.89458206295967, 64.31053072214127, 55.52127555012703, 64.2820930480957, 68.59886661171913, 65.13786792755127, 63.09297725558281, 65.86479172110558, 59.3981771171093, 54.72609221935272, 43.71478468179703, 40.55584318935871, 28.54649070650339, 41.87168598175049, 41.24508440494537, 42.87215329706669, 41.56645596027374, 40.79463377594948, 22.970092333853245, 6.679770816117525, 1.7758956248871982, 11.158848870545626, 1.95390360429883, 0.16640040383208543, 0.09701005619717762, 0.3240165993338451, 1.0565777169540524, 0.5100734671577811, 0.38469405903015286, 0.17372418427839875, 0.23115599469747394, 0.10552197796641849, 0.1439595947158523, 3.0551175260916352, 47.78507687151432, 34.02284994721413, 26.147818118333817, 44.256202429533005, 24.979779794812202, 0.374767329194583, 0.19821204448817298, 0.07380574781564064, 0.04277914355043322, 0.07424741474096663, 0.06595057478989474, 0.05554084411414806, 0.02392312107986072, 0.00901195304322755, 0.029164078914618585, 0.07251723844092339, 0.060411217928049155, 0.03454877405602019, 0.06100667640566826, 0.02731255404796684, 0.07335137532209046, 0.023468837644031737, 0.07079701434122398, 0.05871033790754154, 0.03376422748260666, 0.05640492294332944, 0.04200446011964232, 0.1115322757686954, 0.02364391399169108, 0.04386833432363346, 0.04057579986692872, 34.90046225488186, 64.84744191169739, 50.485219582915306, 39.58404913544655, 39.92689713835716, 80.42269214987755, 2.7290743589401245, 0.11228177812881768, 0.20504069369053468, 0.3578088094945997, 0.43570590612944216, 0.18653311883099377, 2.3924900824204087, 1.6515376791357994, 0.3307609702460468, 0.7601211871951818, 0.4654094169382006, 10.79494809731841, 65.13738915324211, 90.15169769525528, 89.3170876801014, 96.15600630640984, 91.69246941804886, 89.23182025551796, 86.74152508378029, 84.21016171574593, 84.4240902364254, 85.36271587014198, 88.37637975811958, 84.7411984205246, 83.68971884250641, 84.27731171250343, 82.7265465259552, 80.82536414265633, 76.18537992238998, 72.91328430175781, 75.72429746389389, 75.13306438922882, 79.85155999660492, 76.26253858208656, 74.01171416044235, 75.95572784543037, 72.80560567975044, 75.92550426721573, 77.85710781812668, 76.62733420729637, 78.68952915072441, 80.2098199725151, 78.0829145014286, 79.33378458023071, 79.25309211015701, 77.69064635038376, 77.27680295705795, 78.94739851355553, 73.41229632496834, 73.75435397028923, 71.93957135081291, 69.11182388663292, 73.79251912236214, 75.45276403427124, 68.14631849527359, 63.14443029463291, 75.8716231584549, 75.24138897657394, 71.54994785785675, 74.673410654068, 72.42473691701889, 57.79482655227184, 63.63464958965778, 73.06378662586212, 72.8213520348072, 71.41131609678268, 65.89168667793274, 65.2294734120369, 67.38963469862938, 64.4422772526741, 67.03161790966988, 66.88793241977692, 62.83298000693321, 66.87393397092819, 63.049085810780525, 64.21358272433281, 69.49228227138519, 67.98000141978264, 73.19980412721634, 66.39396652579308, 58.82438510656357, 66.93886488676071, 69.0981674194336, 64.00859892368317, 63.2236522436142, 59.92717333137989, 67.91063994169235, 68.42711582779884, 68.84292751550674, 64.92556571960449, 69.33912768959999, 67.10699826478958, 69.61769834160805, 70.44657066464424, 62.35906183719635, 60.85034899413586, 68.22777092456818, 66.81817576289177, 67.0595996081829, 66.38973355293274, 66.40621706843376, 65.9080258011818, 64.86269429326057, 67.49313354492188, 70.26440843939781, 69.824658036232, 68.33711385726929, 57.29541555047035, 65.5546447634697, 69.94349285960197, 65.82858726382256, 66.07503443956375, 68.35481330752373, 62.82271295785904, 61.12748332321644, 51.55898116528988, 48.45209687948227, 37.36618034541607, 50.534799322485924, 53.55083808302879, 64.21233639121056, 60.64667232334614, 65.60680076479912, 52.49469995498657, 46.45080126821995, 20.634872540831566, 14.630537331104279, 3.7267265003174543, 0.2610277949133888, 0.0873656541807577, 0.43398824986070395, 2.51674460247159, 0.3246972674969584, 0.3880966280121356, 0.008766075807216112, 0.05908252867811825, 0.10403466949355789, 0.06810319639043882, 3.5910193948075175, 58.75137582421303, 30.505409091711044, 27.979870811104774, 54.17238213121891, 31.47281628102064, 0.2104199878522195, 0.15078365744557232, 0.07353726105066016, 0.131783296528738, 0.004899893201582017, 0.14051454520085827, 0.06413776776753366, 0.024416665983153507, 0.0950137828476727, 0.017760105984052643, 0.08727537191589363, 0.060700826215907, 0.02228133085736772, 0.18965855502756312, 0.1435101352399215, 0.149940058181528, 0.14056593150598928, 0.14191270689480007, 0.14964627160225064, 0.10295271466020495, 0.09264196050935425, 0.15342978498665616, 0.25093345844652504, 0.2808978490065783, 0.18232441419968382, 0.16726754402043298, 40.57914353907108, 74.28985923528671, 52.861410677433014, 70.59285521507263, 56.206120401620865, 89.88766506314278, 4.312803251668811, 0.3081801178632304, 0.47451239253859967, 1.1613954487256706, 1.8073522369377315, 0.7870831154286861, 5.296091688796878, 3.4550959384068847, 1.4163529803045094, 1.1836918210610747, 1.5622789249755442, 13.22053274139762, 80.69193050265312, 100.02999722957611, 96.48161843419075, 100.53148671984673, 97.06795737147331, 95.20189270377159, 88.17074999213219, 88.37413027882576, 87.00798958539963, 89.19006809592247, 90.90849548578262, 88.85383933782578, 84.33721169829369, 87.60549992322922, 88.27688589692116, 85.56114122271538, 79.24512013792992, 76.13940998911858, 80.18714278936386, 79.55753937363625, 82.78749525547028, 81.3134403526783, 81.1014649271965, 82.78927356004715, 77.25345700979233, 80.12952268123627, 82.10537865757942, 80.59867590665817, 81.73795357346535, 84.4454374909401, 82.5741595029831, 83.83625417947769, 83.78291264176369, 79.90361720323563, 78.99078458547592, 83.67252856492996, 77.31713399291039, 77.70101979374886, 74.49466064572334, 72.99086093902588, 75.81986233592033, 77.79729142785072, 77.11096465587616, 65.89264422655106, 76.85277611017227, 79.67484667897224, 73.0714850127697, 76.5150198340416, 78.40426325798035, 61.38287901878357, 61.693451553583145, 75.90102598071098, 73.39309215545654, 74.90952998399734, 70.12194648385048, 69.21854496002197, 71.72232940793037, 67.34484270215034, 70.76162695884705, 69.67949822545052, 65.26688620448112, 68.01519513130188, 64.79584828019142, 65.11353403329849, 73.74920904636383, 69.5179308950901, 75.68166375160217, 68.63698616623878, 64.25973504781723, 71.66334137320518, 70.43218463659286, 66.3341273367405, 65.24211153388023, 64.52659472823143, 73.370840549469, 70.90313896536827, 70.10686129331589, 66.92422047257423, 74.18650478124619, 70.11569201946259, 72.26368635892868, 71.91630139946938, 64.88908007740974, 67.21571803092957, 73.61366271972656, 69.16152521967888, 70.66536292433739, 69.3755829334259, 69.67703595757484, 69.64416772127151, 68.21433484554291, 72.11230248212814, 76.84138432145119, 73.04574519395828, 70.10697528719902, 62.44798086583614, 69.6094223856926, 73.09295386075974, 72.42972984910011, 70.24375274777412, 75.14681965112686, 66.65257304906845, 66.9714367389679, 58.3729313313961, 56.86406649649143, 48.30872677266598, 63.520788699388504, 59.59177292883396, 65.74170872569084, 58.05393844842911, 57.76716023683548, 43.95085081458092, 44.76519651710987, 29.030083157122135, 25.435502640902996, 4.413625616580248, 0.7327437750063837, 0.33557243237737566, 1.1202824860811234, 4.178908411413431, 1.0757698933593929, 1.0929213417693973, 0.27080490777734667, 0.9350704494863749, 0.39427536365110427, 0.24476935795973986, 6.209012176841497, 68.04111734032631, 46.84886410832405, 36.303221583366394, 60.81441432237625, 38.137633949518204, 0.4979177413042635, 0.28995807690080255, 0.31632058729883283, 0.27604239236097783, 0.11469060395029373, 0.24439469212666154, 0.18229842418804765, 0.07972142921062186, 0.12394552686600946, 0.1150044210953638, 0.20742530323332176, 0.15260962274624035, 0.1252703569480218], [0.08228142309235409, 0.047450666315853596, 0.037853082685614936, 0.02412007965176599, 0.048317476248485036, 0.023750601430947427, 0.07231016439618543, 0.049248363211518154, 0.03840457633486949, 0.045392683387035504, 0.10048715907032602, 0.034904374115285464, 0.45924127916805446, 50.5904321372509, 47.295290753245354, 29.15629718452692, 31.64509903639555, 42.919700145721436, 44.65015389025211, 0.6890928454231471, 0.05220704995736014, 0.1885140742524527, 0.09106866680667736, 0.06746820741682313, 0.09599894678103738, 0.8533782768063247, 0.5178502248600125, 0.35301889933180064, 0.3309944795910269, 2.325715790502727, 26.862136088311672, 74.0634597837925, 76.38895019888878, 87.29466140270233, 83.60933035612106, 82.79044389724731, 81.43758729100227, 79.35856685042381, 75.0529570877552, 82.8410191833973, 84.4671343266964, 82.23307460546494, 79.72489759325981, 70.87556004524231, 76.32033348083496, 77.76840537786484, 74.09976303577423, 73.67922440171242, 71.53829768300056, 73.82391303777695, 74.6795891225338, 71.50362074375153, 68.7928158044815, 68.35802033543587, 69.9584336578846, 73.24964985251427, 76.56129375100136, 69.76666554808617, 73.50716203451157, 77.86327108740807, 77.44994446635246, 74.6927972137928, 76.28183394670486, 74.24540162086487, 78.25497686862946, 74.06075432896614, 70.53589627146721, 65.10373815894127, 68.1657126545906, 69.38006669282913, 74.69515308737755, 74.07012462615967, 65.16037032008171, 57.699550464749336, 74.27041947841644, 72.50064924359322, 68.60040172934532, 73.63652989268303, 71.252431422472, 52.54527144134045, 60.37859670817852, 73.99929642677307, 67.00670644640923, 67.18245461583138, 59.5551922917366, 59.192292764782906, 61.499642953276634, 66.63808822631836, 68.52944433689117, 66.02987006306648, 66.1372447013855, 64.91097450256348, 62.86059312522411, 63.96631479263306, 66.64782330393791, 66.7620375752449, 66.06283709406853, 66.06334626674652, 69.57131043076515, 65.37252053618431, 54.00278963148594, 65.31633675098419, 68.1133134663105, 66.49197086691856, 62.99037516117096, 58.37030187249184, 63.60398143529892, 67.22508072853088, 66.91616490483284, 61.52968794107437, 63.996257185935974, 65.96279606223106, 64.40956100821495, 66.89227178692818, 62.676390409469604, 59.67236280441284, 60.755498483777046, 65.13211503624916, 62.90421858429909, 64.25432413816452, 64.01098519563675, 63.717899322509766, 66.90766096115112, 65.93894094228745, 64.98056396842003, 66.35834723711014, 57.596450597047806, 55.07450312376022, 65.73947444558144, 66.43543750047684, 63.88425439596176, 61.943075358867645, 60.41464537382126, 52.04788193106651, 49.94805380702019, 48.73898148536682, 35.80532290041447, 35.92238321900368, 46.97253227233887, 42.059350311756134, 43.31516772508621, 37.94215723872185, 30.976538211107254, 16.45970217883587, 5.645007966086268, 6.716538118198514, 5.098153185099363, 0.3596388269215822, 0.17384954786393791, 0.7280867092777044, 0.4725983046228066, 0.2948731428477913, 0.5176373175345361, 0.20919401926221326, 0.3503171255579218, 0.15895761258434504, 0.14573393622413278, 0.10290704289218411, 34.47829730808735, 48.76034773886204, 35.91097243130207, 39.35159280896187, 36.65783755481243, 0.055285367197939195, 0.060219792067073286, 0.058506024652160704, 0.10958199331071228, 0.043910477179451846, 0.04634587930922862, 0.06065332505386323, 0.0446682396432152, 0.02248618588055251, 0.06250576276215725, 0.06862675931188278, 0.01491126358814654, 0.018442766813677736, 0.04209683153021615, 0.04812295563169755, 0.037891696629230864, 0.02918423379014712, 0.05092649269499816, 0.045815128687536344, 0.10343385642045178, 0.026465724586159922, 0.05567299092945177, 0.06748774816514924, 0.07727527336101048, 0.07716922787949443, 0.4743407783098519, 59.13637116551399, 56.13364689052105, 46.43222786486149, 37.940044552087784, 47.17761866748333, 55.28098784387112, 0.5128995061386377, 0.027162567857885733, 0.19621149636805058, 0.2300298004411161, 0.6448438041843474, 0.5697689764201641, 1.3011455372907221, 0.3997912129852921, 0.8050471264868975, 0.023744413774693385, 3.175390809774399, 32.48073689639568, 83.44637230038643, 85.69079786539078, 92.46025621891022, 90.23701831698418, 88.48385319113731, 84.54237028956413, 84.0809914469719, 79.87622067332268, 87.99146801233292, 89.15743544697762, 85.7400432229042, 79.53939154744148, 75.50042107701302, 78.40316891670227, 84.87656235694885, 80.09534731507301, 79.29456308484077, 74.31624501943588, 76.4621114730835, 78.4386058151722, 75.60126006603241, 73.22039142251015, 73.6685773730278, 73.23644176125526, 75.77602028846741, 80.29238194227219, 74.59583401679993, 76.04186162352562, 79.14648503065109, 78.57473731040955, 78.36778521537781, 78.82513627409935, 79.47607174515724, 80.26386067271233, 77.76212811470032, 72.86952584981918, 68.29175189137459, 71.8887984752655, 75.48919647932053, 78.02851662039757, 76.29374250769615, 65.13692557811737, 64.17514398694038, 78.27419623732567, 73.26620176434517, 72.42322459816933, 77.58035346865654, 72.13282898068428, 55.652695298194885, 68.2596056163311, 75.72020128369331, 70.4419881105423, 66.72466278076172, 61.49157218635082, 68.15919980406761, 64.78964701294899, 73.12898352742195, 70.71019291877747, 68.88212621212006, 70.83852723240852, 68.66225481033325, 65.61092734336853, 66.59101635217667, 69.29050549864769, 68.97943139076233, 70.26117861270905, 69.22313511371613, 70.31906470656395, 69.30770337581635, 56.465904861688614, 63.73030565679073, 71.15628138184547, 67.87264958024025, 67.66007378697395, 62.73702755570412, 63.364043310284615, 67.89838939905167, 69.32179301977158, 64.50206324458122, 67.86618232727051, 68.53828266263008, 65.10202825069427, 67.30685234069824, 65.7531613111496, 62.041801661252975, 63.6850842833519, 68.60173165798187, 66.01798430085182, 65.77019199728966, 67.18019753694534, 66.41047284007072, 69.6389240026474, 68.4236428141594, 66.74043193459511, 70.23264974355698, 61.45096376538277, 56.48993477225304, 67.2795470058918, 66.52969524264336, 67.06451654434204, 64.56349074840546, 63.53519752621651, 57.44144931435585, 56.8733835965395, 55.408919379115105, 46.31389081478119, 43.29727828502655, 52.210494205355644, 58.78249995410442, 62.5946643948555, 59.79925699532032, 60.76023682951927, 53.30847568809986, 33.03002402186394, 14.429737105965614, 7.804339472204447, 0.5893579940311611, 0.14782461075810716, 0.7466005033347756, 0.5479963822290301, 0.985492259496823, 0.5336872406769544, 0.16264394915197045, 0.18701263528782874, 0.15072769951075315, 0.080608889402356, 0.1319318448076956, 41.888405084609985, 44.892884865403175, 32.96961106359959, 49.625504314899445, 42.62292467057705, 0.1602571873809211, 0.05936458190262783, 0.03789416055951733, 0.07536747885751538, 0.021100765006849542, 0.0687521748477593, 0.02935838987468742, 0.05956053857516963, 0.026492985525692347, 0.05227738329267595, 0.01408056377840694, 0.03665003532660194, 0.050754466574289836, 0.18338222696911544, 0.17365293810144067, 0.11488336196634918, 0.21911021060077474, 0.20052986074006185, 0.1269916645833291, 0.2790840103989467, 0.11172045473358594, 0.1204668654827401, 0.13458653673296794, 0.23800457798643038, 0.1254247681936249, 0.8118812378961593, 69.89987879991531, 66.15262627601624, 39.05844993889332, 50.93381591141224, 58.0831702798605, 62.76451148092747, 1.0853279242292047, 0.45114376523997635, 0.3616719850106165, 0.38597182952798903, 1.11650335136801, 0.8878527581691742, 3.0605547968298197, 1.8376252125017345, 1.6633128910325468, 0.3902448486769572, 5.084689557552338, 39.40617688000202, 96.11648082733154, 92.51772433519363, 103.38719308376312, 93.73613655567169, 93.27080592513084, 87.41836756467819, 88.38733837008476, 83.43873471021652, 92.1962995827198, 90.60862317681313, 88.42685624957085, 87.11174681782722, 75.30999049544334, 80.03821358084679, 87.88948148488998, 82.21216812729836, 84.89410981535912, 80.31626746058464, 80.96956640481949, 83.11959743499756, 78.89093354344368, 76.55057072639465, 79.257021099329, 75.7996018230915, 80.66452637314796, 85.2716651558876, 76.80991441011429, 79.78787541389465, 83.9135192334652, 81.72205522656441, 80.80715551972389, 80.47139033675194, 80.44571131467819, 83.35533678531647, 78.75270456075668, 76.90143629908562, 71.57410696148872, 73.44932913780212, 77.57179632782936, 80.40899008512497, 79.44232195615768, 72.53326669335365, 65.56955516338348, 82.44135662913322, 78.75302374362946, 75.38914784789085, 79.12961393594742, 79.20057132840157, 58.06392051279545, 66.73008129000664, 79.7179439663887, 71.44840970635414, 72.51160025596619, 63.38323228061199, 69.44969415664673, 64.98423457145691, 74.09162387251854, 76.94838657975197, 72.21097558736801, 74.1313849389553, 72.07518607378006, 67.81457349658012, 68.91563281416893, 71.12776011228561, 71.81509003043175, 72.32198283076286, 72.3401990532875, 73.68525087833405, 68.65331009030342, 59.99718837440014, 70.39490103721619, 72.62392222881317, 70.71276918053627, 70.23511961102486, 65.80021038651466, 67.93907761573792, 73.3893683552742, 71.98023676872253, 65.27464538812637, 70.956070125103, 71.4015506207943, 68.22903245687485, 71.40573039650917, 68.00143986940384, 65.99176570773125, 67.83259212970734, 72.76949241757393, 69.98170360922813, 70.26544958353043, 69.71488952636719, 68.80511194467545, 73.10401886701584, 73.08242842555046, 71.6472378373146, 74.09568965435028, 64.23794701695442, 60.17305053770542, 72.0750492811203, 70.78711599111557, 72.56418943405151, 70.18228724598885, 70.07631093263626, 63.636416494846344, 63.235253021121025, 62.29627400636673, 51.50373972952366, 56.17685817182064, 64.57209348678589, 66.98092103004456, 63.21512550115585, 55.34012787044048, 52.580085173249245, 46.74465090036392, 34.60845172405243, 25.96479333937168, 8.490273915231228, 1.0846684221178293, 0.27893279038835317, 2.7553884219378233, 2.366455541923642, 1.9812433747574687, 0.668029566295445, 1.088819105643779, 0.5858335050288588, 0.34182321571279317, 0.3532959282165393, 0.8654936298262328, 48.71112897992134, 65.27840718626976, 49.721331372857094, 52.71730720996857, 52.3259662091732, 0.29144525178708136, 0.213911451282911, 0.17580292507773265, 0.19754880195250735, 0.08500525349518284, 0.22849848261103034, 0.18182291532866657, 0.16348570788977668, 0.12912211823277175, 0.12039886991260573, 0.12052615566062741, 0.19379785400815308, 0.1446307633887045], [0.03052579744689865, 0.03574446302081924, 0.06374013988533989, 0.0432155449379934, 0.02288427946041338, 0.037766885943710804, 0.06458187635871582, 0.0904844407341443, 0.05634011118672788, 0.023366656896541826, 0.06372441377607174, 0.032168487523449585, 1.847686122637242, 55.222246795892715, 44.399055764079094, 42.83306859433651, 33.288117572665215, 61.82365916669369, 19.54882051795721, 0.6075054046232253, 0.12926395749673247, 0.0892509838740807, 0.13499498512828723, 0.11647982551949099, 0.46231878746766597, 0.4443946445826441, 0.48480891971848905, 0.49435258260928094, 0.3434247407130897, 8.298734743148088, 50.169076547026634, 74.4566398859024, 82.28307992219925, 82.07422032952309, 81.95407077670097, 78.63717555999756, 83.88058260083199, 79.83120068907738, 76.90627723932266, 79.68203589320183, 82.67076551914215, 86.88392624258995, 72.75889858603477, 80.18075153231621, 74.53394293785095, 73.62472772598267, 78.1799764931202, 72.92067110538483, 72.02030181884766, 70.50676703453064, 72.76141405105591, 73.07750388979912, 71.08068823814392, 70.06226688623428, 74.64388623833656, 72.6896359026432, 72.24379822611809, 74.78161364793777, 77.47915729880333, 74.16194289922714, 72.47611775994301, 76.14600643515587, 77.89707407355309, 75.61200588941574, 74.1290594637394, 71.67642027139664, 67.11502343416214, 71.51833355426788, 71.3220664858818, 75.23774117231369, 70.16635850071907, 62.867892533540726, 61.27210736274719, 76.51128083467484, 69.65579509735107, 71.27800405025482, 73.2970105111599, 73.29715490341187, 53.02954405546188, 60.94125151634216, 70.89989393949509, 69.16578859090805, 66.6857984662056, 59.2748661339283, 65.00191122293472, 65.81303849816322, 66.45868465304375, 65.93593150377274, 67.12897628545761, 60.56143909692764, 66.22535437345505, 63.93844708800316, 64.68030408024788, 62.65098497271538, 66.19462922215462, 65.72652474045753, 67.79861435294151, 66.54562398791313, 64.4973286986351, 65.72181299328804, 67.34176486730576, 50.848985463380814, 65.50862923264503, 68.24935376644135, 66.68347299098969, 62.48106189072132, 60.199105739593506, 57.962705343961716, 59.7437609732151, 66.58384993672371, 66.43743619322777, 69.79881942272186, 65.50152361392975, 62.299511432647705, 65.69447726011276, 63.451244831085205, 60.99920220673084, 62.17538729310036, 62.445803582668304, 64.18344274163246, 63.55469048023224, 65.35976082086563, 66.06678128242493, 65.11006101965904, 66.8353508412838, 64.01869878172874, 64.86088559031487, 54.992697313427925, 60.411271154880524, 63.38034823536873, 65.00715494155884, 58.94048027694225, 58.667723312973976, 52.19661734998226, 53.0498843640089, 51.29983127117157, 52.742507457733154, 37.5243354588747, 47.18695476651192, 43.145381435751915, 47.34181925654411, 44.771014004945755, 38.20856474339962, 26.839918680489063, 12.568994052708149, 5.557007063180208, 6.492824172601104, 1.5338268829509616, 0.10899159999098629, 0.11581060127355158, 0.15159611619310454, 0.7940371579024941, 1.115141361951828, 0.36914802447427064, 0.13825106900185347, 0.11284658961812966, 0.12226195001858287, 0.3267283772584051, 15.811844542622566, 50.56234024465084, 35.51564544439316, 35.757901445031166, 38.78542318940163, 0.2408508479129523, 0.049605581152718514, 0.05000168392143678, 0.029427541339828167, 0.21451434236951172, 0.06941401472431608, 0.034576994221424684, 0.042346549380454235, 0.058078714573639445, 0.01929473193740705, 0.09753537800861523, 0.03326523335999809, 0.061296596395550296, 0.04251864600519184, 0.01622900894290069, 0.015808368916623294, 0.03451864657108672, 0.04174471214355435, 0.028260120780032594, 0.07250585389556363, 0.041127434524241835, 0.04017458741145674, 0.07097274748957716, 0.11311057154671289, 0.05893216213735286, 2.3095787689089775, 66.36732995510101, 51.503230556845665, 46.578508615493774, 32.04112708568573, 65.5856890976429, 27.06257153302431, 0.4778573411749676, 0.08738354736124165, 0.3843969921581447, 0.00905630749912234, 0.24346389051061124, 0.6482790573500097, 0.7814141164999455, 0.5648026429116726, 1.0009028669446707, 0.7017005688976496, 9.990228228271008, 60.586000978946686, 87.49754011631012, 89.16995197534561, 87.84890726208687, 87.88065075874329, 83.69739443063736, 87.50219866633415, 83.37717801332474, 79.7166596353054, 85.45378178358078, 87.30558201670647, 88.64609688520432, 76.87654003500938, 80.92019185423851, 77.17164739966393, 78.63478168845177, 82.24724784493446, 77.13662087917328, 75.83726540207863, 72.7841368317604, 76.02942869067192, 76.80039212107658, 73.74817550182343, 74.14044365286827, 77.10624530911446, 74.4246532022953, 74.33772906661034, 77.68383711576462, 79.747354388237, 77.9569436609745, 76.2234690785408, 75.7262809574604, 79.05367881059647, 79.27213668823242, 76.85049623250961, 71.30054444074631, 71.15695014595985, 74.21392410993576, 75.61854913830757, 78.05106461048126, 72.75547876954079, 67.22489073872566, 67.07469999790192, 78.31056788563728, 71.12146005034447, 73.0798901617527, 75.45464113354683, 71.52908697724342, 57.25693501532078, 67.11454465985298, 73.12281265854836, 74.27951619029045, 67.61442303657532, 65.7157789170742, 69.76504683494568, 68.51426035165787, 69.19291913509369, 66.9772732257843, 69.16170001029968, 65.76855808496475, 66.41860440373421, 65.81888258457184, 67.37438231706619, 66.26525223255157, 67.28653863072395, 69.47079062461853, 69.64170545339584, 69.06425043940544, 66.06496497988701, 66.95298492908478, 68.97190019488335, 55.209794864058495, 62.36025497317314, 71.69677957892418, 67.64984473586082, 66.95556119084358, 63.78969267010689, 61.359601467847824, 61.6270387172699, 67.99824804067612, 68.37321951985359, 72.21743524074554, 66.85367345809937, 64.63820993900299, 67.11865603923798, 67.38676205277443, 64.37635079026222, 65.00835567712784, 65.7057474553585, 65.80008119344711, 65.89547887444496, 67.06729039549828, 65.25350332260132, 66.6468657553196, 70.36729171872139, 66.99653059244156, 68.05142238736153, 58.068180084228516, 60.42437665164471, 66.29041448235512, 66.70223638415337, 60.9695827960968, 61.2026546895504, 57.96506881713867, 58.354452922940254, 57.78076350688934, 60.1966966688633, 46.78364060819149, 52.22449645400047, 53.716049417853355, 63.29759627580643, 61.36573813855648, 64.51925352215767, 58.84221754968166, 47.90422707796097, 21.147541031241417, 6.7279731296002865, 2.952619926072657, 0.04690581117756665, 0.13994819746585563, 0.4963942605536431, 1.6154899634420872, 1.2859326973557472, 1.0317155322991312, 0.17252631339943036, 0.12067885996657424, 0.13883295730920509, 0.4380204569315538, 19.971471838653088, 53.3786541223526, 36.2718390673399, 47.27647416293621, 46.91549353301525, 0.4574526735814288, 0.03417875777813606, 0.1036524708615616, 0.03057421330595389, 0.1055899883795064, 0.039942206130945124, 0.1310754509177059, 0.04506874334765598, 0.020462156207941007, 0.044651122007053345, 0.047659903721068986, 0.03905518009560183, 0.06699113262584433, 0.08434156567091122, 0.25907428411301225, 0.17807826079661027, 0.1542474387679249, 0.11554437063750811, 0.17138193652499467, 0.14842733857221901, 0.1765282853739336, 0.19272650446509942, 0.09702517374535091, 0.18150928372051567, 0.38960737350862473, 3.68508477229625, 75.72536900639534, 60.151992067694664, 56.66308008134365, 51.991861537098885, 84.50542867183685, 34.66807812452316, 0.5292507412377745, 0.7928298320621252, 0.5852744600269943, 0.3214060503523797, 0.7512318610679358, 1.6838239529170096, 1.5322499675676227, 1.5697456430643797, 1.8524292181245983, 1.84981697704643, 11.92288052290678, 74.33674111962318, 100.05705937743187, 95.60120567679405, 95.19235521554947, 91.60805314779282, 88.14210712909698, 93.42028990387917, 88.56640756130219, 83.15776258707047, 89.44378808140755, 90.95730766654015, 93.53593289852142, 81.9889073073864, 83.67021068930626, 82.00379490852356, 82.67239943146706, 89.03528720140457, 83.38600873947144, 81.40049368143082, 77.69787356257439, 80.35874918103218, 82.02877476811409, 78.45741480588913, 80.29309630393982, 81.25338837504387, 78.36568772792816, 79.87136453390121, 81.75424709916115, 83.1981012225151, 80.16019463539124, 78.92693281173706, 79.7853371500969, 83.82896617054939, 81.09304457902908, 80.84640741348267, 76.17309138178825, 74.43724572658539, 75.80394878983498, 79.01234462857246, 82.48356476426125, 77.16621369123459, 70.69962188601494, 68.34777608513832, 85.27228832244873, 76.8486875295639, 76.14836990833282, 80.54173976182938, 79.33670282363892, 60.33462546765804, 67.84631699323654, 77.33408868312836, 75.98987281322479, 71.95537090301514, 66.51356130838394, 72.50580936670303, 71.72283858060837, 69.01615262031555, 71.215391010046, 74.25110891461372, 71.22381135821342, 69.59442839026451, 67.50431254506111, 68.25002253055573, 66.61687016487122, 70.26725828647614, 71.84415847063065, 73.18635284900665, 71.00698739290237, 68.66379752755165, 68.76864150166512, 69.91165056824684, 57.5845268368721, 69.11476492881775, 75.00865906476974, 69.92917522788048, 65.70183366537094, 65.86364418268204, 63.13050404191017, 64.71400827169418, 71.84150621294975, 69.66543897986412, 76.26981139183044, 70.48792764544487, 67.60275766253471, 70.58397889137268, 68.67382138967514, 68.69330674409866, 70.1229952275753, 69.46934670209885, 68.45511272549629, 70.55008471012115, 69.24459636211395, 69.34987351298332, 73.15267905592918, 74.93685811758041, 69.60601776838303, 73.5146552324295, 60.834937021136284, 64.54873234033585, 72.03070566058159, 72.18958273530006, 66.97022080421448, 67.94290781021118, 62.677214965224266, 64.72198024392128, 64.3663041293621, 63.87043073773384, 54.010092839598656, 66.43001899123192, 60.58603897690773, 68.35056513547897, 62.38037109375, 60.64156919717789, 50.94154089689255, 45.18474720418453, 29.812413677573204, 11.005986873060465, 4.319064365699887, 0.28032624686602503, 0.6371696409769356, 1.1046038148924708, 2.653123321942985, 1.8683542823418975, 1.8075265525840223, 0.30124228389468044, 0.36039765807799995, 0.26347450737375766, 0.6144709652289748, 26.104477643966675, 68.81010487675667, 48.056880086660385, 48.253800719976425, 56.38692229986191, 0.7277108856942505, 0.1349433761788532, 0.18220942583866417, 0.08129042587825097, 0.22818943747552112, 0.1382300365366973, 0.19714143709279597, 0.16968158714007586, 0.111555645999033, 0.11331098852679133, 0.1701243969728239, 0.1349009104887955, 0.1665995962684974], [0.05296158778946847, 0.026216828664473724, 0.005631250051010284, 0.012475990406528581, 0.031822368400753476, 0.035139434548909776, 0.014218791566236177, 0.00607513321483566, 0.02855818955140421, 0.04572626392473467, 0.07047635459457524, 0.21188041573623195, 4.49715843424201, 60.11102266609669, 41.38723857700825, 56.10275074839592, 38.71955752372742, 52.81279608607292, 5.492430478334427, 0.4083233285928145, 0.0851418160891626, 0.2749195822980255, 0.085156644199742, 0.2646551455836743, 1.2383914296515286, 0.794504473451525, 0.10085913832881488, 0.25724399951286614, 0.3790378844132647, 19.98654942959547, 62.870677784085274, 74.54208970069885, 83.2909606397152, 78.95151749253273, 83.8597597181797, 89.60440546274185, 89.81551453471184, 85.29162168502808, 76.97425559163094, 81.27422645688057, 83.4202829003334, 84.69651281833649, 81.67217910289764, 83.44745144248009, 80.13763904571533, 77.72742077708244, 79.00672852993011, 76.31077319383621, 73.37391838431358, 70.06011620163918, 70.02658680081367, 71.92608967423439, 68.96959751844406, 72.35163643956184, 74.84712213277817, 71.5225437283516, 75.04519030451775, 73.71260941028595, 74.63901489973068, 74.41261544823647, 73.64460065960884, 72.92545884847641, 72.22388729453087, 69.664815813303, 69.94858458638191, 70.31199708580971, 74.69004616141319, 72.36063435673714, 73.15772518515587, 68.2621818780899, 62.32348054647446, 66.11192286014557, 75.61118513345718, 69.47886139154434, 69.52105432748795, 71.04657366871834, 68.38881388306618, 52.253732085227966, 57.836434319615364, 74.20681849122047, 69.2852009832859, 64.83886197209358, 57.39627733826637, 70.9888243675232, 68.56501802802086, 65.15568137168884, 63.97168770432472, 66.38072043657303, 66.27346739172935, 64.92213070392609, 63.86441186070442, 66.36835590004921, 66.55144527554512, 65.3911167383194, 62.97619052231312, 60.54838299751282, 63.300142139196396, 64.86613690853119, 67.30422288179398, 63.1487962603569, 66.00224554538727, 65.94509661197662, 51.916348189115524, 63.57416823506355, 70.46339616179466, 65.88416308164597, 66.04692354798317, 66.26276716589928, 58.07795695960522, 59.23501767218113, 65.79453349113464, 66.71073272824287, 67.76242509484291, 63.368321880698204, 65.2633447945118, 66.2922915816307, 70.95244511961937, 64.19969066977501, 60.089702010154724, 62.90143333375454, 61.36339746415615, 64.6310131251812, 64.74177718162537, 63.10571037232876, 66.0696691274643, 64.48615729808807, 60.48535957932472, 59.23957742750645, 56.291057243943214, 60.647200495004654, 59.24388639628887, 58.53914201259613, 57.153816148638725, 56.90530188381672, 56.20032951235771, 56.64853446185589, 59.79370169341564, 52.6457304507494, 43.1368774920702, 54.42249231040478, 45.197750106453896, 51.30730926990509, 45.06142482161522, 38.94705891609192, 24.873423501849174, 12.888200674206018, 5.028500547632575, 1.8178279185667634, 0.14397517981706187, 0.38386597065255046, 1.2318492494523525, 0.46049782424233854, 0.29845970508176833, 0.1193341551697813, 0.06507835088996217, 0.07242057370604016, 0.07359856987022795, 0.18371046404354274, 5.972095364704728, 46.74507647752762, 33.445584923028946, 33.80179300904274, 46.78859554231167, 0.7736444240435958, 0.06081285340769682, 0.01455416253520525, 0.006393600842784508, 0.1267890285816975, 0.057424682090641, 0.044993489573244005, 0.0787470857903827, 0.060031887696823105, 0.015246555703924969, 0.027510100771905854, 0.006401829868991626, 0.043667924765031785, 0.04874707214185037, 0.008661776228109375, 0.08797059359494597, 0.04101797516341321, 0.05759351326560136, 0.05728861302486621, 0.008910838205338223, 0.0079126050513878, 0.08178253658115864, 0.031114877165236976, 0.05302931989717763, 0.23681163496803492, 5.946036837995052, 71.09655618667603, 49.966642409563065, 56.735868975520134, 32.162606567144394, 63.55559483170509, 8.558431807905436, 0.34880816121585667, 0.09957296671927907, 0.5656017281580716, 0.18700365530094132, 0.5218623939435929, 2.3714826721698046, 1.7664466006681323, 0.16963106172624975, 0.17652252630796283, 0.4450510296737775, 23.12768317759037, 73.23032408952713, 82.65838578343391, 90.53629025816917, 84.7505459189415, 87.25603267550468, 94.47572126984596, 94.79891672730446, 87.33797147870064, 79.04434651136398, 83.0608981847763, 85.76853409409523, 83.64668235182762, 84.76474955677986, 85.56135401129723, 83.53436037898064, 82.42760136723518, 82.41371691226959, 81.71915218234062, 77.59195044636726, 74.07333165407181, 75.15658512711525, 75.29856070876122, 73.56185629963875, 75.26494771242142, 76.59269526600838, 74.67174634337425, 80.23564338684082, 76.77722856402397, 74.97974261641502, 75.3697156906128, 76.60399585962296, 75.54750055074692, 75.06810307502747, 71.62174120545387, 73.55082169175148, 73.58277797698975, 75.8940951526165, 75.0209628045559, 75.39892852306366, 67.52277955412865, 65.18253073096275, 69.33633863925934, 78.5756416618824, 71.55364885926247, 74.11781966686249, 72.46214210987091, 69.93609085679054, 57.39988714456558, 66.74384415149689, 73.80828067660332, 69.46335822343826, 65.32550185918808, 61.90726228058338, 72.32297837734222, 70.91926530003548, 68.94153222441673, 67.6121735572815, 70.95553055405617, 70.70390805602074, 68.56896981596947, 68.72521743178368, 70.10490819811821, 68.96634489297867, 66.73920080065727, 66.06035202741623, 62.64900527894497, 65.26033535599709, 67.13604390621185, 69.30112972855568, 67.98453077673912, 67.23177596926689, 69.82955977320671, 56.67495444417, 62.672575414180756, 71.83309346437454, 68.03374573588371, 67.43902444839478, 68.96832078695297, 62.05567851662636, 60.70307269692421, 65.34339889883995, 68.98188605904579, 70.45594096183777, 67.9651366174221, 67.56443291902542, 66.5293076634407, 72.1289911866188, 66.8779693543911, 61.80435620248318, 65.04580646753311, 63.93457889556885, 66.19620233774185, 66.82351067662239, 65.7083161175251, 67.20650732517242, 68.82674038410187, 63.079879358410835, 64.53015133738518, 60.42996235191822, 61.705850288271904, 64.30578857660294, 61.5985706448555, 60.603434443473816, 60.516069531440735, 60.75583666563034, 60.82516014575958, 63.06096777319908, 58.07750478386879, 52.0991487801075, 60.379732847213745, 57.3740903288126, 61.91565603017807, 65.89341178536415, 62.11218148469925, 58.09210740029812, 35.21103098988533, 7.375221848487854, 3.61524214502424, 0.020552019159367774, 0.47952260181773454, 1.7526540532708168, 1.023928087670356, 0.651606610044837, 0.17413146008038893, 0.014809189524385147, 0.09468499658396468, 0.1346560165984556, 0.2235648184432648, 8.348221387714148, 55.597222074866295, 32.230934500694275, 40.079990923404694, 56.46431654691696, 1.7324480437673628, 0.1510518993018195, 0.046100647741695866, 0.03640169416030403, 0.08077336417045444, 0.08572810533223674, 0.10084320441819727, 0.08454760813037865, 0.10330320874345489, 0.01234508019479108, 0.10877625099965371, 0.0964307579852175, 0.03510273163556121, 0.14291687723016366, 0.13884074985980988, 0.26620994496624917, 0.1689155274652876, 0.11398744129110128, 0.12853392167016864, 0.10223772958852351, 0.1637451330316253, 0.18592633889056742, 0.07519358623540029, 0.10245172044960782, 0.34383502963464707, 7.610093895345926, 86.09395623207092, 53.67737129330635, 80.9914456307888, 57.93402448296547, 74.23217073082924, 12.48429849743843, 0.5196507938671857, 0.3091197361936793, 0.7014015724416822, 0.25890860706567764, 1.2863486562855542, 4.337390307337046, 3.688344284892082, 0.7604080124292523, 0.6515301391482353, 1.1611397936940193, 29.57658503204584, 86.79931238293648, 93.49120169878006, 99.67592462897301, 93.24456453323364, 94.2026375234127, 98.47755253314972, 98.18515822291374, 91.21703132987022, 83.56282845139503, 88.36830899119377, 91.77843600511551, 87.17729330062866, 86.1954715847969, 89.18401882052422, 87.83943817019463, 86.3042825460434, 88.84102642536163, 86.49385437369347, 82.65139415860176, 77.1982079744339, 79.94804441928864, 78.94815847277641, 78.25823709368706, 78.86689603328705, 80.899178981781, 78.41881647706032, 81.16739138960838, 81.97014391422272, 80.15507251024246, 79.74217906594276, 78.49621832370758, 79.39468011260033, 78.29782336950302, 75.35741195082664, 76.39376074075699, 76.38987734913826, 79.75637510418892, 77.48211354017258, 78.01952630281448, 72.46984049677849, 69.74897369742393, 72.25325211882591, 83.9778345823288, 77.04931676387787, 75.54881528019905, 76.25537976622581, 75.96556171774864, 59.779125675559044, 66.45182222127914, 80.22308886051178, 75.42028337717056, 72.44638815522194, 63.16360026597977, 75.33025860786438, 72.62002363801003, 69.31768923997879, 68.66303756833076, 72.26770654320717, 73.54621633887291, 72.21417501568794, 68.15057426691055, 70.71783050894737, 72.71037518978119, 69.21563431620598, 68.47993299365044, 66.70731291174889, 70.18924847245216, 71.47632300853729, 70.63375622034073, 69.25104841589928, 71.19967505335808, 71.15299835801125, 58.90243671834469, 68.43836322426796, 77.15211644768715, 71.73594787716866, 70.11597320437431, 72.99311801791191, 64.69991862773895, 63.51345509290695, 69.7751846909523, 73.68639081716537, 72.86981463432312, 70.68408071994781, 72.20069333910942, 71.06656819581985, 78.64748060703278, 70.55291175842285, 66.55381634831429, 69.98443186283112, 65.95213383436203, 69.9074935913086, 72.09955036640167, 68.95262762904167, 72.89070591330528, 71.99865818023682, 67.16588750481606, 68.11892196536064, 65.3054541349411, 67.15258821845055, 69.9249042570591, 66.456328779459, 68.54030415415764, 65.52211850881577, 68.44951942563057, 64.80557575821877, 70.0325220823288, 61.00498549640179, 59.61418032646179, 68.1993180513382, 62.62401022017002, 64.90817785263062, 67.21374213695526, 58.654644414782524, 52.35491305589676, 38.41245800256729, 17.767113223671913, 5.1234389282763, 0.9104074572678655, 0.7144404540304095, 4.4078052788972855, 2.4072166671976447, 1.4111517718993127, 1.4196740020997822, 0.1419658149825409, 0.5019278917461634, 0.39405185845680535, 0.7453419989906251, 13.584721349179745, 67.28242725133896, 45.50537019968033, 46.96470469236374, 66.20277598500252, 1.8619720498099923, 0.20207624416798353, 0.167774801957421, 0.1592393169994466, 0.241908245079685, 0.13746641110628843, 0.2011179385590367, 0.15246325638145208, 0.19321644067531452, 0.08454650233034045, 0.1931379659799859, 0.17503082432085648, 0.13612947659566998], [0.03171394062519539, 0.053991417880752124, 0.06368902817484923, 0.04546286829281598, 0.05124033952597529, 0.08911289987736382, 0.0320779640605906, 0.04569802520563826, 0.06213924199983012, 0.06343214117805474, 0.17945567204151303, 0.3585472167469561, 13.439060915261507, 56.44190154969692, 42.13363252580166, 42.35253497958183, 32.39270702004433, 46.73160620033741, 0.9706751327030361, 0.06280733447056264, 0.04821769820409827, 0.07237032288685441, 0.18521274905651808, 0.29747540946118534, 0.24326064594788477, 0.5392151128035039, 0.4121637943899259, 0.1924733875785023, 1.5717334114015102, 26.472102217376232, 66.22549116611481, 76.92259356379509, 80.01819625496864, 76.923718303442, 85.77835276722908, 84.28643882274628, 85.83326742053032, 86.94260269403458, 77.45436742901802, 82.07225203514099, 82.87508055567741, 85.84107220172882, 86.0700935125351, 81.46301552653313, 83.08148548007011, 81.7586624622345, 80.85478976368904, 77.80186638236046, 76.32438406348228, 73.56137752532959, 67.73527175188065, 71.67895093560219, 71.82443752884865, 74.77747187018394, 71.69933304190636, 75.0119648873806, 70.57912275195122, 71.20999529957771, 74.65692713856697, 75.66518023610115, 75.75889840722084, 72.77442455291748, 69.63340669870377, 70.11977300047874, 73.65490570664406, 75.35852149128914, 75.31353190541267, 74.7771754860878, 67.3681278526783, 63.88547033071518, 69.4418665766716, 74.85541328787804, 65.49377202987671, 70.19923433661461, 71.49278372526169, 65.38334995508194, 55.424088165163994, 61.410469338297844, 73.90509948134422, 66.22658550739288, 64.8815868794918, 57.67725706100464, 64.20401483774185, 65.4248209297657, 66.39113947749138, 67.89314568042755, 68.25743973255157, 67.22296804189682, 63.639042153954506, 64.04975831508636, 65.86666882038116, 64.36074122786522, 65.36261066794395, 62.81656488776207, 62.04646781086922, 56.87322400510311, 59.780626595020294, 62.23832331597805, 64.37825828790665, 68.69758531451225, 64.48153674602509, 66.66065141558647, 66.13265454769135, 51.07578009366989, 59.59629848599434, 65.61410397291183, 65.6096962094307, 62.20403015613556, 65.76715975999832, 61.63873828947544, 58.4164883941412, 58.72693173587322, 65.297482162714, 64.35252606868744, 63.84292021393776, 61.773809641599655, 62.10607521235943, 65.09724050760269, 60.29182456433773, 60.75801394879818, 62.06216096878052, 63.53243127465248, 64.75062310695648, 63.98184835910797, 61.92612066864967, 61.815235018730164, 60.11124685406685, 60.496397987008095, 58.059562146663666, 54.82840932905674, 55.35224162042141, 60.5034314095974, 55.861448496580124, 57.70258650183678, 56.123524233698845, 60.52317135035992, 58.374949023127556, 63.516639322042465, 46.77083149552345, 52.89172925055027, 55.307354629039764, 48.88596899807453, 56.70574799180031, 46.5480000525713, 39.79724049568176, 22.27422807365656, 8.733415268361568, 1.2534496653825045, 0.3727881994564086, 0.5112052126787603, 0.1990067065344192, 0.5618947301991284, 0.5218348454218358, 0.20938357862178236, 0.18486088200006634, 0.1472478432697244, 0.0186588041469804, 0.1663647362147458, 3.9923726208508015, 38.53544980287552, 46.45617417991161, 19.8867591843009, 49.02800537645817, 2.8254476375877857, 0.12160914207925089, 0.08159356351825409, 0.05880825316125993, 0.14973452780395746, 0.04780337942065671, 0.07193272293079644, 0.056432898200000636, 0.04244853160344064, 0.012646409777516965, 0.047448187542613596, 0.10088489827467129, 0.05544404579268303, 0.0193781586131081, 0.1202214669319801, 0.02166242979001254, 0.027452335707494058, 0.053449831902980804, 0.11879159326781519, 0.08868700359016657, 0.11303652005153708, 0.11203415313502774, 0.10930285672657192, 0.2973380230832845, 0.575986570911482, 19.618780463933945, 63.19239892065525, 53.08437131345272, 43.803202137351036, 28.10547687113285, 59.56748083233833, 1.2183926277793944, 0.07038042458589189, 0.3410734684439376, 0.14773636939935386, 0.26962735690176487, 0.46393281023483723, 1.645112936384976, 1.2377510452643037, 0.4235062748193741, 0.06960493963561021, 2.54444464109838, 32.47213415801525, 80.38801521062851, 87.06830754876137, 86.0904224216938, 83.07820245623589, 91.06801092624664, 89.1541676223278, 90.88398680090904, 89.66441184282303, 80.78490391373634, 84.85990405082703, 84.68132123351097, 88.87036085128784, 87.7487750351429, 84.82965007424355, 85.05706027150154, 84.82265084981918, 83.57695609331131, 82.48288840055466, 80.33564642071724, 78.98900628089905, 71.89245387911797, 74.56757873296738, 74.35008600354195, 77.90851145982742, 74.71941858530045, 76.88594073057175, 73.16122099757195, 73.19485679268837, 76.87009558081627, 78.6649976670742, 78.02543878555298, 73.92076224088669, 72.04284220933914, 74.16306763887405, 75.98047971725464, 78.11255291104317, 79.18707445263863, 76.37845516204834, 68.30426841974258, 68.6089588701725, 74.43376511335373, 75.73320418596268, 68.5027089715004, 73.493133187294, 73.36547523736954, 65.02911016345024, 57.54093937575817, 69.07337754964828, 75.62427163124084, 69.14767116308212, 66.68891429901123, 61.64536893367767, 65.96294805407524, 66.02306842803955, 68.45950528979301, 69.18553233146667, 70.68204402923584, 70.36994397640228, 67.75386795401573, 66.57519400119781, 66.4902837574482, 66.09380543231964, 68.01200330257416, 66.67980998754501, 65.64968526363373, 59.52365018427372, 63.28523173928261, 67.32698366045952, 65.50815045833588, 70.24672418832779, 68.00005674362183, 67.39041745662689, 67.14667573571205, 57.3475943505764, 59.75770242512226, 66.15607649087906, 68.8640695810318, 64.37596321105957, 69.48067009449005, 63.9077827334404, 60.65946243703365, 59.8423732817173, 66.89513683319092, 66.84982046484947, 67.82041758298874, 64.26076099276543, 62.90001600980759, 67.99584656953812, 64.97528985142708, 64.36406224966049, 63.78934308886528, 65.27105078101158, 65.77697083353996, 65.82138285040855, 66.13318651914597, 64.68595057725906, 63.81993904709816, 64.15427550673485, 59.44108821451664, 57.92337365448475, 58.81439924240112, 61.948022693395615, 59.481506645679474, 58.98361176252365, 60.969164818525314, 64.14626553654671, 63.231042847037315, 66.04538843035698, 57.6932618021965, 56.02124512195587, 63.445165157318115, 56.991272270679474, 68.65528598427773, 64.24886003136635, 67.33646795153618, 50.15393815934658, 18.157584071159363, 3.3256162237375975, 0.1662202549050562, 0.5772216233890504, 0.47091852757148445, 0.788863260531798, 0.6104972097091377, 0.5525265110190958, 0.00858704659549403, 0.1879972277674824, 0.030263594817370176, 0.3287472267402336, 5.819233367219567, 46.68840251863003, 43.33619199693203, 22.885619066655636, 58.47452647984028, 4.112589620053768, 0.12595466163475066, 0.07715345724136569, 0.053689745982410386, 0.13175356609281152, 0.007916182203189237, 0.034506211886764504, 0.04885629401542246, 0.05862353260454256, 0.006752412546120468, 0.064422529831063, 0.05394555686507374, 0.03486443543806672, 0.14063275448279455, 0.22323629935272038, 0.10050081458757631, 0.1636698644142598, 0.16414823796367273, 0.1891256929957308, 0.2514250570675358, 0.16156026511453092, 0.21745783364167437, 0.23152830050094053, 0.32419907860457897, 0.7632105995435268, 21.516888812184334, 78.82395073771477, 54.322280287742615, 58.42478334903717, 46.824959591031075, 70.23030146956444, 3.6334374686703086, 0.22786370886024088, 0.6180938333272934, 0.33408317947760224, 0.48249024257529527, 1.305017292033881, 4.455099916085601, 2.6581468898802996, 0.9505014808382839, 0.4289539059391245, 4.0850078500807285, 39.34921033680439, 93.77158865332603, 99.17231485247612, 95.85741832852364, 87.94530808925629, 95.46923875808716, 95.37938117980957, 96.22133240103722, 94.68251377344131, 85.26033416390419, 88.06966781616211, 87.68023431301117, 91.21475145220757, 93.26199799776077, 89.9655456840992, 91.1191637814045, 89.01715457439423, 88.62199857831001, 84.56217482686043, 81.25571385025978, 84.40528124570847, 75.195472240448, 79.8891019821167, 78.23986127972603, 84.50751096010208, 76.4787469804287, 82.07805052399635, 75.0208792090416, 74.8965422809124, 80.4703263938427, 81.6248032450676, 82.36485913395882, 77.44289204478264, 76.37500494718552, 75.62481880187988, 78.34330692887306, 81.5761886537075, 81.8507619202137, 79.95274096727371, 75.68076699972153, 71.43774747848511, 75.8692216873169, 80.19817739725113, 72.97734126448631, 77.74036288261414, 78.06149125099182, 73.2006248831749, 62.998362332582474, 71.72729194164276, 79.97512936592102, 72.3970440030098, 69.69731166958809, 64.75245460867882, 71.12050250172615, 68.364647179842, 71.08410805463791, 72.12235674262047, 72.33807116746902, 73.659488260746, 70.94240605831146, 71.44955724477768, 70.586828738451, 70.62822371721268, 71.60047754645348, 69.46998506784439, 70.00403881072998, 64.9812251329422, 65.94533979892731, 69.88072782754898, 68.71808141469955, 73.23274075984955, 70.29335528612137, 73.09287026524544, 68.72158482670784, 57.606713846325874, 67.61496260762215, 70.18942326307297, 71.35906130075455, 67.08752050995827, 72.66601637005806, 66.66284769773483, 63.69416959583759, 62.40011103451252, 69.37859997153282, 69.81635168194771, 70.7774569094181, 67.08790048956871, 67.70163595676422, 73.17745372653008, 68.09680715203285, 66.40126213431358, 68.2891072332859, 67.5831963121891, 69.47000026702881, 69.98086005449295, 71.03853330016136, 67.94099271297455, 67.55333751440048, 68.563422113657, 66.40343561768532, 61.43450304865837, 64.95049238204956, 69.55915868282318, 67.34067812561989, 65.84906056523323, 65.97905918955803, 70.03496915102005, 68.37410107254982, 70.94684422016144, 61.95809595286846, 62.61711739003658, 70.59664741158485, 60.16972191631794, 73.0141232907772, 65.3745648264885, 63.717306554317474, 50.3729622066021, 27.514889761805534, 4.444602504372597, 1.2233248818665743, 0.9618780703749508, 1.6426893789321184, 1.9840381247922778, 1.967572420835495, 0.9879855788312852, 0.7753586070612073, 0.3368125908309594, 0.2624348772224039, 0.5523733317386359, 10.538803841918707, 56.8314528465271, 62.455143481492996, 30.815276764333248, 66.50153115391731, 5.199851877987385, 0.4284101788653061, 0.23261761001776904, 0.15890615206444636, 0.22859007847728208, 0.13942081248387694, 0.11275418481091037, 0.1421908786869608, 0.15574561228277162, 0.1119811786338687, 0.1655676102382131, 0.1836677163373679, 0.19982430094387382], [0.03277443254773971, 0.0908982177497819, 0.06503518015961163, 0.09981133713154122, 0.0369031002628617, 0.04155535687459633, 0.06488194150733761, 0.02146756036381703, 0.019928138281102292, 0.039625694989808835, 0.09057526476681232, 0.30645483231637627, 24.85957134515047, 58.4125442057848, 33.11216801404953, 45.685917511582375, 34.58382524549961, 35.222388580441475, 0.24725725961616263, 0.011539398183231242, 0.23010404489468783, 0.03350130682520103, 0.1976170646958053, 0.11706526871421374, 0.32383898855187, 0.4310838697711006, 0.13576554221799597, 0.21766162739368156, 2.53638266120106, 32.72203914821148, 58.50081726908684, 76.63615733385086, 74.33566197752953, 84.8063725233078, 87.71707713603973, 90.39383590221405, 84.74819004535675, 86.79761007428169, 77.50310361385345, 83.4114445745945, 81.74676150083542, 85.02198815345764, 78.08031544089317, 80.63742622733116, 78.9360523223877, 78.7525449693203, 82.56102740764618, 81.12143665552139, 77.6347741484642, 74.47710558772087, 73.5548646748066, 70.34607365727425, 73.10769706964493, 71.00687339901924, 73.2778063416481, 72.57920622825623, 75.59348568320274, 74.95208770036697, 71.18300914764404, 73.60651910305023, 69.75609451532364, 69.72328707575798, 71.09368354082108, 73.88375222682953, 74.67214152216911, 71.18646696209908, 73.52467149496078, 64.73256647586823, 63.66953171789646, 71.50901645421982, 73.21767076849937, 71.43746629357338, 69.27830815315247, 68.96857157349586, 58.87437902390957, 55.361866503953934, 66.90278202295303, 70.90296417474747, 65.5921183526516, 66.82645171880722, 59.074358493089676, 58.9863096177578, 52.734611481428146, 57.78208963572979, 67.14192599058151, 64.51980069279671, 63.037295043468475, 65.53318351507187, 65.9210667014122, 62.55796976387501, 61.84092164039612, 61.792573034763336, 67.93123483657837, 64.89488616585732, 51.03330597281456, 49.987807273864746, 56.477980613708496, 60.72860732674599, 62.09111161530018, 61.227140575647354, 67.15479210019112, 66.37800738215446, 63.4345181286335, 68.82134467363358, 54.20242711901665, 56.93814732134342, 65.38207322359085, 66.23434469103813, 61.21261015534401, 64.91242602467537, 61.73736959695816, 58.64594668149948, 58.99914152920246, 64.16987746953964, 64.65170681476593, 62.35169783234596, 59.44577716290951, 59.34546634554863, 63.6686235666275, 62.00731851160526, 61.334074437618256, 65.68624690175056, 64.18963640928268, 64.1058737039566, 65.14435037970543, 61.67673625051975, 57.77716889977455, 58.857842311263084, 56.66725605726242, 55.64887270331383, 57.28041395545006, 55.72967156767845, 55.693771094083786, 55.42652003467083, 60.48500619828701, 58.7082177400589, 63.5917878895998, 63.50125394761562, 61.46358668804169, 48.68142977356911, 62.7016818523407, 56.37684904038906, 61.179437935352325, 55.35311937332153, 53.22903715074062, 28.651583567261696, 13.241267278790474, 1.2203059438616037, 0.3872046555625275, 0.1944059698143974, 0.45730053330771625, 0.952608942752704, 0.5555215815547854, 0.147572607093025, 0.2530328161083162, 0.04689221874286886, 0.21151375025510788, 0.2054237457923591, 2.2418286418542266, 25.91467022895813, 60.983254462480545, 29.71154998987913, 49.42526265978813, 8.199408072978258, 0.5062246893066913, 0.1584992473362945, 0.16056788008427247, 0.11203934816876426, 0.09040355405886658, 0.16017035610275343, 0.07883217302151024, 0.04929929680656642, 0.07281884725671262, 0.04973141971277073, 0.035275548143545166, 0.06749659456545487, 0.0032121160302267526, 0.03689753786602523, 0.044781016404158436, 0.11588239663979039, 0.08544227457605302, 0.03087638058786979, 0.03133032820187509, 0.08241551433457062, 0.1214560295920819, 0.021071262781333644, 0.13225456030340865, 0.42815502849407494, 30.45639932155609, 66.12578451633453, 54.728417694568634, 48.20580169558525, 34.997186064720154, 45.27457058429718, 0.38396731833927333, 0.15329039481002837, 0.37224450206849724, 0.016529313434148207, 0.6582100025843829, 0.12527678394690156, 1.786257668863982, 0.5093836854211986, 0.18584232777357101, 0.1824107111315243, 2.951584244146943, 41.895229518413544, 74.12035793066025, 86.27273663878441, 81.39825940132141, 88.75075086951256, 88.99567052721977, 93.54443684220314, 88.32636684179306, 92.14389279484749, 79.39043954014778, 85.94793766736984, 85.33173993229866, 87.94185787439346, 81.55126959085464, 83.12845855951309, 82.42370277643204, 81.44631162285805, 82.40107879042625, 84.3502525985241, 83.22637170553207, 79.4611157476902, 77.53445193171501, 73.28813418745995, 76.70800387859344, 75.81654891371727, 76.47322967648506, 76.8517653644085, 79.69585955142975, 76.6654385626316, 74.89738583564758, 76.34358063340187, 70.4828891158104, 74.7908091545105, 73.95877540111542, 75.90865597128868, 74.16163891553879, 74.055655002594, 74.14365828037262, 66.45294696092606, 68.82031872868538, 75.4083140194416, 73.49653780460358, 72.7512077987194, 72.49979808926582, 68.88437569141388, 60.697065219283104, 59.62383180856705, 72.67305359244347, 71.33038803935051, 67.9273970425129, 69.61243942379951, 61.15365631878376, 60.386720672249794, 54.77843061089516, 55.65200753509998, 67.62499406933784, 67.40066170692444, 67.70866557955742, 67.72675260901451, 68.14308866858482, 64.35297444462776, 64.71588537096977, 64.15058210492134, 69.23677638173103, 65.72131142020226, 52.71110974252224, 52.69382826983929, 56.54647953808308, 61.10707841813564, 65.90028941631317, 64.65337112545967, 67.02519625425339, 68.09853985905647, 65.36907032132149, 71.86935871839523, 59.1827666759491, 57.72709518671036, 66.03248432278633, 68.52119877934456, 64.7024416923523, 66.705861389637, 68.13741937279701, 60.327269062399864, 58.726806342601776, 65.00988319516182, 66.92358210682869, 66.98642313480377, 64.02904942631721, 62.45302699506283, 64.5895117521286, 64.10163313150406, 65.31647354364395, 66.6169461607933, 65.59969514608383, 65.97211316227913, 67.3837374150753, 66.68129190802574, 63.49919065833092, 62.1526987105608, 60.99457785487175, 59.131066650152206, 61.2546207010746, 60.55689834058285, 59.02225188910961, 59.584203734993935, 63.38950574398041, 61.83313585817814, 65.66502884030342, 65.65422222018242, 68.01846295595169, 56.62690222263336, 64.45776522159576, 62.990667745471, 65.79051330685616, 67.59578123688698, 70.61677873134613, 54.198095351457596, 28.760803006589413, 2.843054230324924, 0.35860492615029216, 0.2753808122361079, 0.6284517806489021, 2.2520795417949557, 0.7420567783992738, 0.19633479678304866, 0.130097508081235, 0.03956489083066117, 0.16688590199919418, 0.42780702060554177, 2.39835768006742, 37.264201417565346, 58.78644794225693, 33.78722459077835, 63.07364009320736, 10.446260757744312, 0.33124188194051385, 0.20844814600422978, 0.13134241627994925, 0.03037556634808425, 0.050371529505355284, 0.14271421154262498, 0.05466880575113464, 0.03219157202693168, 0.04169641688349657, 0.05242796876700595, 0.07530291943112388, 0.13451993640046567, 0.12356583669316024, 0.2035725919995457, 0.1362685699132271, 0.20822444785153493, 0.3199141554068774, 0.17661903519183397, 0.28304437757469714, 0.1219530013622716, 0.1731344440486282, 0.10016016880399548, 0.2532908756984398, 0.4964015929726884, 34.7487173974514, 78.63698557019234, 45.62156416475773, 63.32300931215286, 52.504708617925644, 51.24427065253258, 0.7173751434311271, 0.2606603130698204, 0.8059628179762512, 0.2369616081705317, 0.9732592909131199, 0.8429462928324938, 3.6977245565503836, 0.8689521567430347, 0.5840212397743016, 0.41526169690769166, 4.353035967797041, 51.48852154612541, 88.7428092956543, 94.83381405472755, 88.92196208238602, 95.63616380095482, 96.76279574632645, 97.52624318003654, 94.02819648385048, 96.46380499005318, 85.06415069103241, 88.96917834877968, 88.3175741136074, 89.3441042304039, 83.78011599183083, 87.69044816493988, 84.37587842345238, 87.71725952625275, 86.38992995023727, 88.57488110661507, 87.63207569718361, 83.97623866796494, 80.1696789264679, 79.01226863265038, 78.93954813480377, 77.46177703142166, 80.20084485411644, 80.30346214771271, 82.0012566447258, 81.25904247164726, 76.50840058922768, 80.92288210988045, 74.45195093750954, 77.77244836091995, 75.74310645461082, 78.49362686276436, 78.86475294828415, 75.51970884203911, 78.0572658777237, 70.80467104911804, 68.79587084054947, 78.46403405070305, 78.38265761733055, 77.19807118177414, 73.59297662973404, 74.66597065329552, 65.81349447369576, 61.808239594101906, 73.3013042807579, 78.63608881831169, 71.4241062104702, 74.02449667453766, 64.36560496687889, 64.17050063610077, 58.86152811348438, 62.19846725463867, 72.0623579621315, 70.90123906731606, 69.15343925356865, 69.59508955478668, 71.86353743076324, 66.25174015760422, 67.39495441317558, 65.24795562028885, 71.9636544585228, 70.78672081232071, 56.50221571326256, 54.0807044506073, 63.43550227582455, 64.15135726332664, 67.9641942679882, 65.90782821178436, 72.12338268756866, 73.07433485984802, 70.02470970153809, 75.14808878302574, 60.280877351760864, 60.29034644365311, 70.61945378780365, 71.64983689785004, 66.95649594068527, 71.58671468496323, 69.3837220966816, 63.40926468372345, 62.06984415650368, 67.84812569618225, 69.67446729540825, 69.14513289928436, 67.19642266631126, 67.77663633227348, 69.39778134226799, 71.01555973291397, 67.52178400754929, 70.09545430541039, 68.69840607047081, 69.21842336654663, 72.43951052427292, 69.90746319293976, 66.82150438427925, 66.14534586668015, 64.7556160390377, 63.58883164823055, 66.90937086939812, 67.41130873560905, 66.10407248139381, 65.46200573444366, 69.32124584913254, 67.15806752443314, 72.36093074083328, 69.80672299861908, 70.54226472973824, 62.173764780163765, 72.3769810795784, 67.5475162267685, 70.16911715269089, 70.45945957303047, 67.96417146921158, 55.97120940685272, 42.87217229604721, 4.682090235874057, 1.4951611077412963, 0.6412071618251503, 1.334424982778728, 4.279806297272444, 2.0691445330157876, 0.35599995811935514, 0.34170800470747054, 0.19906974455807358, 0.4434560355730355, 0.7155657873954624, 5.999509943649173, 43.86367969214916, 78.85483548045158, 40.84105968475342, 68.17613929510117, 13.081236965954304, 0.7162945764139295, 0.44280166912358254, 0.25357651349622756, 0.24269095854833722, 0.1416869307286106, 0.3231818019412458, 0.18249908607685938, 0.11808274575741962, 0.10364443340222351, 0.13640194869367406, 0.17758350062649697, 0.23820405243895948], [0.05992030208290089, 0.0612760574585991, 0.03279027368989773, 0.04817981527594384, 0.014023214316694066, 0.025900631080730818, 0.02454428940836806, 0.058415608800714836, 0.03205722103302833, 0.012160155547462637, 0.13209511729655787, 0.023841301153879613, 35.32033212482929, 51.04650266468525, 34.42476958036423, 29.585248567163944, 43.56011018157005, 23.371839076280594, 0.1901424946845509, 0.07965928918565623, 0.18837069132132456, 0.06494284956716001, 0.1455759775126353, 0.39433871337678283, 0.40378052392043173, 0.5075969500467181, 0.1321515502058901, 0.28169251105282456, 8.439289201050997, 40.931388437747955, 57.57082097232342, 78.98998662829399, 72.91806444525719, 83.04757609963417, 85.07356658577919, 87.2157396376133, 82.3207738995552, 81.30938217043877, 81.72297477722168, 84.65136364102364, 85.41145205497742, 79.41287353634834, 77.59153246879578, 76.12685546278954, 76.26811668276787, 80.3434208035469, 77.80443504452705, 81.14207714796066, 76.19313150644302, 72.98649877309799, 74.21744272112846, 69.6708270907402, 73.08874368667603, 75.58076396584511, 71.67302325367928, 73.04560840129852, 76.46715000271797, 70.10308429598808, 73.12605768442154, 68.8575491309166, 69.89002972841263, 72.91991874575615, 72.31483921408653, 68.72782409191132, 71.32340401411057, 74.62514564394951, 64.6028034389019, 65.79900965094566, 72.78930455446243, 68.37453424930573, 69.56387042999268, 70.29324889183044, 65.3528755903244, 58.30138497054577, 58.71084339916706, 69.44182857871056, 70.20543560385704, 64.21303555369377, 64.47475031018257, 52.907897382974625, 48.97690571844578, 51.266640052199364, 50.061861500144005, 47.6081545650959, 53.568503335118294, 70.86286872625351, 66.81304603815079, 67.59323537349701, 67.25389078259468, 67.08443507552147, 66.14301279187202, 68.27399924397469, 63.9504012465477, 49.30786035954952, 46.8711993098259, 49.26929622888565, 49.251858964562416, 50.25465555489063, 55.78560456633568, 64.57751199603081, 60.760951191186905, 62.82680533826351, 61.50514505803585, 63.68867889046669, 66.65395617485046, 59.12007384002209, 55.4559950530529, 65.23841053247452, 64.5299081504345, 62.02598311007023, 65.1252070069313, 64.90768387913704, 58.66103187203407, 56.77563764154911, 63.37808355689049, 65.5217233300209, 63.973739594221115, 59.41381327807903, 58.845519572496414, 62.891447469592094, 60.71556642651558, 62.29891486465931, 60.309364423155785, 63.43993283808231, 61.71462781727314, 60.12919709086418, 59.95399609208107, 60.84151066839695, 58.645479306578636, 56.85902796685696, 53.37226286530495, 54.47874069213867, 52.27988228201866, 56.19225114583969, 58.029684349894524, 61.96823760867119, 63.145342245697975, 67.78701737523079, 63.75388339161873, 56.69390022754669, 58.62723648548126, 64.89450618624687, 61.70411758124828, 61.47935964167118, 56.03709027171135, 42.937870770692825, 19.109319001436234, 3.9315328979864717, 0.250283099594526, 0.0978315765678417, 0.557017691899091, 0.8469196921214461, 0.15669467073166743, 0.21910989889875054, 0.15866841247770935, 0.07927337239379995, 0.26902707817498595, 0.3181655070511624, 0.9389417292550206, 13.36942870169878, 57.089500799775124, 29.27828773856163, 40.12828633189201, 16.248743198812008, 0.5062981916125864, 0.19816692190943286, 0.12058839958626777, 0.06301116532995366, 0.04743763791339006, 0.11028548251488246, 0.028511083582998253, 0.06877280655317008, 0.10249126949929632, 0.05245847103651613, 0.11641332166618668, 0.05291819070407655, 0.07853348084609024, 0.02193620806792751, 0.03059724585909862, 0.06252946695894934, 0.04437941432115622, 0.0693905702792108, 0.007158991193136899, 0.033711160212988034, 0.029171121896069963, 0.06140930265246425, 0.09040981036378071, 0.013063788992440095, 43.789188489317894, 57.24558122456074, 50.038314163684845, 28.768104314804077, 45.35136066377163, 28.52716874331236, 0.22547850559931248, 0.33508249616716057, 0.24522476946003735, 0.10217348928563297, 0.4829438135493547, 0.7474737439770252, 0.825096572516486, 0.681081450311467, 0.12814791582059115, 0.14072199031943455, 10.406925268471241, 50.167894810438156, 72.32778891921043, 88.65558117628098, 81.2338650226593, 88.06817069649696, 90.63744843006134, 90.32541677355766, 86.3096934556961, 87.5358572602272, 84.57936510443687, 84.73571911454201, 85.42874112725258, 82.6894149184227, 81.83737143874168, 81.59647196531296, 79.46674704551697, 82.38903343677521, 80.72185769677162, 82.51995921134949, 80.63107296824455, 78.7653198838234, 76.73552200198174, 73.72880414128304, 76.73035427927971, 79.06302630901337, 75.93750402331352, 74.21894744038582, 76.76855742931366, 72.19865664839745, 74.86614391207695, 74.07137095928192, 73.92582356929779, 75.71210011839867, 73.36337774991989, 71.56513184309006, 75.40394425392151, 76.32082745432854, 65.99617347121239, 70.55599719285965, 74.20403704047203, 71.74573615193367, 71.59958839416504, 73.93147006630898, 67.65255019068718, 60.84091030061245, 63.81350219249725, 73.93520146608353, 72.22229897975922, 67.06498011946678, 66.42222180962563, 55.47258876264095, 53.21965165436268, 53.23642015457153, 53.78586687147617, 49.49432775378227, 54.76025238633156, 72.27054879069328, 72.13108107447624, 68.40688571333885, 69.97457519173622, 68.96376103162766, 69.65919211506844, 73.5283724963665, 65.89901268482208, 49.710399359464645, 50.64396746456623, 53.149838000535965, 52.13054649531841, 52.69707329571247, 55.10128028690815, 63.930520713329315, 64.7145402431488, 65.1005083322525, 66.15761920809746, 67.2588837146759, 67.34106570482254, 63.23086805641651, 56.466034054756165, 65.12624055147171, 65.970289260149, 64.5577834546566, 66.49325519800186, 66.56080797314644, 61.75721973180771, 60.16295447945595, 63.89136001467705, 66.24128311872482, 68.0080059170723, 62.82794147729874, 60.263246297836304, 67.99834683537483, 62.365274503827095, 64.89284187555313, 63.48291613161564, 63.67785707116127, 65.41575461626053, 64.46023508906364, 64.7623036801815, 65.68982630968094, 62.02985130250454, 59.28921416401863, 58.742146119475365, 58.207431212067604, 58.52365404367447, 59.591742530465126, 60.42549379169941, 65.53494662046432, 67.67613172531128, 69.42128688097, 66.51587918400764, 62.735234051942825, 63.928727209568024, 66.75686225295067, 67.15744435787201, 69.96188387274742, 66.98763906955719, 64.54290345311165, 35.69523520767689, 8.106801342219114, 0.6164722109679133, 0.1628095519845374, 0.992628870299086, 1.4540371019393206, 0.30359414988197386, 0.40658040961716324, 0.0630046492733527, 0.1032234649755992, 0.16811771871289238, 0.8630006667226553, 1.978909824974835, 14.31727359071374, 64.05216738581657, 28.994967341423035, 50.35926394164562, 20.87163783609867, 0.49316660093609244, 0.26395779394079, 0.07170124707045034, 0.03951707054511644, 0.07808264839695767, 0.10824491779203527, 0.032441219373140484, 0.05929173268668819, 0.07018031188636087, 0.07716486405115575, 0.020886961538053583, 0.031502940619247966, 0.16457139572594315, 0.1449214032618329, 0.13261527376016602, 0.19340836006449535, 0.20087516721105203, 0.10618383268592879, 0.11610250279773027, 0.09493772013229318, 0.17496138898422942, 0.09706444077892229, 0.19942416460253298, 0.15312735980842263, 50.446712449193, 66.33131548762321, 47.90623337030411, 43.06701444089413, 60.637408420443535, 36.964412704110146, 0.2931575052207336, 0.6536890764255077, 0.3764982847496867, 0.30000844853930175, 1.1508531519211829, 2.1129186591133475, 1.395673539955169, 1.3316417508758605, 0.5476612283382565, 0.5318199971225113, 14.012645836919546, 60.893689468503, 88.36279928684235, 97.67486840486526, 88.23795318603516, 93.79699409008026, 96.69377624988556, 96.15792140364647, 87.11611658334732, 90.04501461982727, 87.20957636833191, 89.62353363633156, 89.97170135378838, 86.60018786787987, 83.1474195420742, 85.01690402626991, 84.22701761126518, 87.1196959912777, 83.46910268068314, 87.71972939372063, 85.14846816658974, 83.23305174708366, 83.2101009786129, 75.9409162402153, 79.71046596765518, 82.44834825396538, 78.92128631472588, 77.29834020137787, 82.75997713208199, 76.65030017495155, 78.13192427158356, 78.49428042769432, 78.21386307477951, 78.88034731149673, 74.86315727233887, 74.24007430672646, 74.72112089395523, 81.8394461274147, 70.72524771094322, 70.71240440011024, 81.30071103572845, 74.19121652841568, 75.94885781407356, 78.75708192586899, 72.4938552081585, 64.37228500843048, 63.70090663433075, 77.10920915007591, 76.83842808008194, 70.60474097728729, 70.26169538497925, 57.967626079916954, 56.285072565078735, 56.97053678333759, 56.69414721429348, 51.864716559648514, 59.02984768152237, 76.36170566082001, 71.15135684609413, 71.77446261048317, 72.01327219605446, 73.57224494218826, 72.9813614487648, 76.82983294129372, 71.14880338311195, 54.96900178492069, 52.16570220887661, 54.2310281842947, 55.33109575510025, 56.5248928964138, 59.40519914031029, 69.50688108801842, 65.35576343536377, 69.62155893445015, 65.22985339164734, 68.72859165072441, 70.54801002144814, 64.24549341201782, 58.519664257764816, 69.75055441260338, 69.5647519826889, 65.8011907339096, 70.40041834115982, 69.07926723361015, 62.46571831405163, 63.18902090191841, 68.79261061549187, 69.31531056761742, 68.99067118763924, 65.58685183525085, 64.69328418374062, 72.92660638689995, 65.62776044011116, 68.10841172933578, 63.883486837148666, 68.3896878361702, 68.58593970537186, 68.62101942300797, 67.94813632965088, 67.91656762361526, 64.5360866189003, 64.27998796105385, 65.58985367417336, 64.72948104143143, 63.70178438723087, 67.09125190973282, 66.63719147443771, 71.20788261294365, 71.92762479186058, 74.76377740502357, 69.69935595989227, 66.42380252480507, 69.72071081399918, 73.75488594174385, 71.17050021886826, 73.59701961278915, 70.59322759509087, 66.62351980805397, 47.85557068884373, 12.647802773863077, 1.6780975414440036, 0.38752092921640724, 1.9320661760866642, 3.210373632609844, 1.066291539464146, 0.7572963356506079, 0.3673568362137303, 0.43795262463390827, 0.49684563477057964, 1.2945612031035125, 6.0141372587531805, 22.81607709825039, 74.99467581510544, 41.02535739541054, 58.36370922625065, 24.170542918145657, 0.7722272188402712, 0.39447001414373517, 0.16831946413731202, 0.1497509441105649, 0.1692844193894416, 0.22542035090737045, 0.18065977696096525, 0.2895702898968011, 0.2006371901370585, 0.13912652124417946, 0.23888699157396331, 0.15324608859373257], [0.08018625114345923, 0.06272433267440647, 0.03440819644310977, 0.0410457092220895, 0.017955220318981446, 0.11001550403307192, 0.09601497717085294, 0.057344678571098484, 0.04174354697170202, 0.04842639384150971, 0.07561618738691323, 0.9001922991592437, 49.094984382390976, 44.045594930648804, 45.85150122642517, 44.92164932191372, 41.29847913980484, 14.042706973850727, 0.2928410831373185, 0.28365109814330935, 0.03494911448797211, 0.10983016749378294, 0.24258290184661746, 0.3937561868224293, 0.30459183384664357, 0.1672347410931252, 0.22724992304574698, 0.3217696730280295, 18.78384556621313, 50.971722677350044, 57.99752287566662, 73.53747680783272, 75.28973758220673, 79.25183817744255, 82.11642846465111, 86.22260212898254, 81.35320141911507, 85.21431103348732, 82.1869146823883, 82.3448646068573, 82.77403637766838, 76.02074235677719, 76.01161524653435, 71.0506622493267, 71.53589621186256, 74.94632720947266, 76.53472557663918, 77.5587098300457, 79.02715623378754, 74.67869997024536, 73.18829834461212, 73.43092292547226, 73.21542888879776, 72.50928238034248, 73.72976928949356, 73.98678749799728, 68.97832185029984, 71.42301946878433, 68.4972296655178, 71.11744746565819, 74.85820233821869, 69.17195186018944, 70.60815319418907, 70.93570321798325, 69.91272211074829, 63.184829726815224, 67.36918419599533, 70.82596510648727, 64.0112891793251, 69.8391580581665, 71.65805965662003, 62.74597227573395, 56.942026913166046, 64.25144389271736, 71.03947564959526, 66.40440836548805, 68.5215711593628, 64.74670931696892, 49.46584068238735, 52.343110889196396, 54.5377591252327, 55.969077721238136, 50.38974590599537, 51.42358683049679, 47.45825260877609, 56.85496598482132, 67.67746165394783, 66.75933972001076, 66.55326917767525, 63.78856033086777, 62.66825884580612, 65.50665333867073, 51.5524835139513, 48.843388482928276, 48.56696471571922, 51.41137048602104, 54.466600343585014, 53.26094403862953, 48.568648025393486, 51.35275863111019, 60.667480006814, 63.45275714993477, 61.013850420713425, 66.8861997127533, 62.80335299670696, 66.35799005627632, 60.371415093541145, 57.01225854456425, 58.33757422864437, 64.04649809002876, 63.25412280857563, 61.703897193074226, 64.55560997128487, 60.638780146837234, 56.76725149154663, 59.939131289720535, 61.78996257483959, 61.31417490541935, 58.25248159468174, 61.36505037546158, 62.4554056674242, 59.71216946840286, 63.63813400268555, 61.93588614463806, 60.39895601570606, 59.46128413081169, 58.66445168852806, 62.406513690948486, 59.56758722662926, 58.21697250008583, 50.447160825133324, 52.990725338459015, 53.83094385266304, 57.318244725465775, 58.543846160173416, 61.43666133284569, 60.23043505847454, 65.28704032301903, 65.28655394911766, 62.44382008910179, 58.84873799979687, 61.9880573451519, 66.35023087263107, 66.3918386399746, 64.83552575111389, 51.84145040810108, 26.322186961770058, 5.985095892101526, 1.177984052337706, 0.14548159117111936, 0.24503957392880693, 0.2970397984609008, 0.10285068419761956, 0.06218256115971599, 0.08540708193322644, 0.16284517507301643, 0.16124302666867152, 0.1087840880791191, 0.818833380471915, 2.664384967647493, 44.020128697156906, 42.20548287034035, 31.949035227298737, 30.429675355553627, 0.30021725920960307, 0.1356081326957792, 0.07764829162624665, 0.018405134360364173, 0.0687153494800441, 0.0762281623610761, 0.03997225569037255, 0.08327272458700463, 0.0513310114183696, 0.05960785420029424, 0.0464763080526609, 0.10360760061303154, 0.12126859277486801, 0.027211145134060644, 0.020386156575114, 0.06542031769640744, 0.019973322087025736, 0.019810090416285675, 0.026169323791691568, 0.05724344962800387, 0.081821232161019, 0.07865606879931875, 0.0679145053436514, 1.3587151793763041, 57.82524012029171, 57.19153292477131, 48.497439846396446, 28.91180880367756, 54.869420528411865, 16.287451721727848, 0.3718033101176843, 0.07266097018145956, 0.10464205057360232, 0.11082638200605288, 0.35152169060893357, 0.510620994027704, 0.5728393897879869, 0.1764281844953075, 0.20062346040504053, 0.32629656605422497, 21.479356326162815, 57.901350036263466, 74.35545891523361, 85.19299417734146, 80.49250200390816, 86.22347608208656, 86.01531565189362, 88.80632668733597, 84.88789334893227, 87.130586206913, 85.94645574688911, 85.98612561821938, 85.84292650222778, 79.96519669890404, 78.09685975313187, 75.90220391750336, 74.7778594493866, 80.55628538131714, 79.02245968580246, 79.91194635629654, 81.51469275355339, 78.51738318800926, 78.44179004430771, 74.82035636901855, 74.89164054393768, 74.45309087634087, 76.44800662994385, 74.09529447555542, 72.8616526722908, 71.29919171333313, 69.34396862983704, 74.20360386371613, 76.47322967648506, 73.39963540434837, 77.46479406952858, 76.86323314905167, 69.88119900226593, 63.81072834134102, 70.04160359501839, 74.08843204379082, 68.5449931025505, 73.78081575036049, 72.78925895690918, 63.08931425213814, 60.736735090613365, 70.13108119368553, 73.83772149682045, 69.03423964977264, 71.54487133026123, 65.39062276482582, 52.06010967493057, 58.06485526263714, 57.87425749003887, 60.34840352833271, 52.68550671637058, 52.89813570678234, 51.198870688676834, 58.738612309098244, 67.0618262887001, 68.47616359591484, 68.73694360256195, 66.74730956554413, 66.36633440852165, 67.3481485247612, 53.94177630543709, 51.58323906362057, 51.198760494589806, 53.18825013935566, 56.95498041808605, 56.484307274222374, 53.099243715405464, 52.391113713383675, 61.354688331484795, 66.83300256729126, 64.33603495359421, 69.84535932540894, 66.03804722428322, 70.26927217841148, 63.90329897403717, 58.83591368794441, 60.935593619942665, 64.52259734272957, 64.02827426791191, 63.20778429508209, 68.45920890569687, 64.06931206583977, 60.220791175961494, 62.875541523098946, 65.29289200901985, 65.01739919185638, 63.15094694495201, 63.44087518751621, 66.3995598256588, 62.759450152516365, 65.95231622457504, 63.117816522717476, 64.52539399266243, 64.14230614900589, 63.82851138710976, 64.66363817453384, 64.29533913731575, 61.2944957613945, 55.4276067763567, 56.9521913677454, 58.38932365179062, 60.6804259121418, 62.278775945305824, 64.89268228411674, 65.03237038850784, 67.27416649460793, 66.90363317728043, 66.24034076929092, 63.65794233977795, 67.2045086324215, 69.25525099039078, 70.08351534605026, 71.81636676192284, 66.98177978396416, 46.01328134536743, 13.741658627986908, 2.3729365691542625, 0.18560910044470802, 0.40822239650879055, 0.18809446395607665, 0.9115627140272409, 0.16581372125074267, 0.07145535870222375, 0.1348165431409143, 0.09443867777008563, 0.8823468536138535, 1.450682356953621, 2.6344862719997764, 51.055219396948814, 39.50784042477608, 42.44692951440811, 38.509121015667915, 0.17555276193888858, 0.12520580494310707, 0.142929196881596, 0.07478041035938077, 0.10099812032422051, 0.04435198825376574, 0.023897732207842637, 0.14390190015546978, 0.024425189549219795, 0.04340834006143268, 0.07357213456998579, 0.051598941572592594, 0.41402527887839824, 0.18743073160294443, 0.13848690869053826, 0.12773869559168816, 0.14230769273126498, 0.23438813688699156, 0.22470489086117595, 0.17634375777561218, 0.22749367402866483, 0.11333086324157193, 0.15555124380625784, 1.0786465764977038, 71.49967655539513, 56.713058799505234, 59.84095215797424, 62.51631639897823, 62.382202595472336, 23.53337410837412, 0.34773593593854457, 0.7186175580136478, 0.24697649030713364, 0.6242482562083751, 0.644127958221361, 1.458463508170098, 0.7751674891915172, 0.8787915506400168, 0.7185462524648756, 0.6633098039310426, 25.853223726153374, 71.881502866745, 90.82728624343872, 91.88905566930771, 90.64899981021881, 91.94335475564003, 93.95885020494461, 91.88165366649628, 87.52915441989899, 90.78314021229744, 87.69914209842682, 89.99503970146179, 90.681571662426, 82.57374912500381, 82.68651187419891, 79.73790049552917, 75.66125884652138, 84.02875944972038, 80.81499069929123, 82.71868094801903, 85.20059376955032, 84.26934733986855, 81.67253628373146, 79.11543309688568, 76.86247318983078, 78.12187761068344, 78.50453987717628, 79.12286549806595, 73.41908276081085, 76.70647636055946, 72.03588098287582, 77.64238893985748, 80.23655533790588, 75.18567636609077, 78.87413084506989, 77.944845110178, 76.21979087591171, 67.72496670484543, 73.22912335395813, 75.99833115935326, 72.80252024531364, 76.06307968497276, 77.65125006437302, 69.19260755181313, 64.69534367322922, 71.37148663401604, 75.973761677742, 71.26579150557518, 75.14982908964157, 70.91991886496544, 57.03182369470596, 57.89745904505253, 59.89023931324482, 62.47796505689621, 56.097241044044495, 54.7685207426548, 52.530676424503326, 63.97435516119003, 72.4717327952385, 72.76092007756233, 73.1495252251625, 69.9344189465046, 69.78395462036133, 72.21384063363075, 58.89160729944706, 53.274076133966446, 53.20021569728851, 57.008268758654594, 59.20376054942608, 58.577580749988556, 54.22497130930424, 56.3701082020998, 66.21186509728432, 68.30730065703392, 67.23895758390427, 73.5276885330677, 70.07783085107803, 72.00827926397324, 65.66242977976799, 63.68342377245426, 66.15214750170708, 69.6171435713768, 66.13935738801956, 63.942018896341324, 69.71175089478493, 66.89797908067703, 62.14084714651108, 67.20033645629883, 70.65616741776466, 68.47111746668816, 67.0380699634552, 67.36702591180801, 67.21365094184875, 64.70095977187157, 67.97195345163345, 64.97212082147598, 68.53582039475441, 67.63264685869217, 68.17195951938629, 69.97417241334915, 69.57463145256042, 68.4761255979538, 61.083823665976524, 63.891382813453674, 65.1307775080204, 69.4341453909874, 68.36102217435837, 70.88939130306244, 66.74722597002983, 71.77864998579025, 70.75055435299873, 70.88071256875992, 64.55021426081657, 75.20469814538956, 74.6273723244667, 74.72072571516037, 76.53898894786835, 69.63624894618988, 58.748997151851654, 21.109670363366604, 3.6160125536844134, 0.3884948941413313, 0.9403489006217569, 0.3729215485509485, 2.323972159065306, 0.49289156100712717, 0.12005342985503376, 0.32285540539305657, 0.24914734647609293, 2.127990312874317, 3.644491075538099, 6.3008983712643385, 62.954037711024284, 55.80297343432903, 50.4387366771698, 43.44923973083496, 0.34428768034558743, 0.3217282908735797, 0.2045136204105802, 0.21831660240422934, 0.18733272358076647, 0.12792893772711977, 0.15971098153386265, 0.20905174955260009, 0.13210129196522757, 0.11398674367228523, 0.12742884893668815, 0.10526067519094795], [0.134098693379201, 0.034736782326945104, 0.009969419097615173, 0.047525281843263656, 0.038728486688341945, 0.0888532075623516, 0.06657545571215451, 0.07628078805282712, 0.044899492859258316, 0.13590836111688986, 0.1620869673206471, 4.4720793049782515, 55.49411840736866, 31.495010890066624, 49.75742943584919, 40.04675030708313, 37.305885180830956, 7.281264765188098, 0.2592795027885586, 0.17546888440847397, 0.07164953422034159, 0.07749276715912856, 0.1330210652668029, 0.10340094959246926, 0.4665775870671496, 0.4353717318736017, 0.039853226335253567, 2.920578382909298, 36.29021868109703, 56.02468393743038, 64.47225004434586, 74.64263990521431, 72.08871334791183, 78.98011475801468, 81.4364093542099, 81.92146852612495, 80.3030289709568, 79.55820813775063, 79.92164343595505, 75.81988513469696, 78.43799024820328, 74.42118778824806, 69.95231598615646, 68.89833614230156, 71.2456601858139, 75.19473508000374, 75.62585234642029, 76.65439635515213, 75.6532184779644, 75.16030892729759, 72.29568064212799, 70.77425748109818, 71.95243746042252, 70.04011407494545, 74.07698705792427, 70.76101899147034, 70.27060970664024, 67.50334739685059, 74.3010838329792, 73.14032971858978, 71.91453829407692, 70.82865536212921, 67.1232233941555, 66.87850892543793, 64.01385024189949, 70.25232508778572, 71.94869846105576, 67.8100137412548, 70.91990366578102, 71.41459912061691, 60.47086715698242, 57.904154285788536, 68.82997781038284, 73.3837066590786, 68.01548391580582, 72.69944697618484, 61.36068820953369, 48.81319150328636, 55.24198293685913, 61.95759817957878, 54.893165454268456, 50.39730750024319, 50.266602113842964, 46.921918988227844, 47.89536975324154, 47.218071296811104, 56.81256785988808, 57.937261909246445, 61.939507350325584, 61.958741918206215, 59.69469800591469, 54.75516065955162, 46.934234127402306, 48.21904018521309, 49.14189666509628, 50.625534653663635, 52.4479054659605, 56.66116498410702, 60.183404982089996, 55.694481655955315, 48.15403327345848, 55.60660757124424, 64.48722124099731, 61.10812336206436, 65.5711130797863, 64.56260159611702, 65.49660667777061, 59.84192490577698, 57.942441031336784, 53.831342831254005, 62.21837438642979, 63.784175366163254, 61.492818519473076, 63.48627895116806, 59.023764207959175, 58.93516056239605, 64.57961708307266, 60.80141521990299, 62.49821417033672, 59.424893483519554, 64.47381556034088, 62.62460298836231, 58.54035794734955, 63.87417733669281, 58.36107596755028, 60.19344784319401, 59.69149857759476, 58.14999349415302, 57.08923481404781, 55.367965176701546, 50.76865017414093, 50.26702769100666, 53.78113612532616, 56.11033894121647, 57.541516944766045, 61.04370541870594, 63.68636101484299, 66.05769976973534, 66.71308100223541, 63.67383688688278, 60.289126709103584, 59.83353115618229, 71.67528793215752, 67.11772128939629, 65.10716557502747, 59.9578832834959, 31.38912197202444, 11.685387566685677, 2.8977677319198847, 0.08647968570585363, 0.1903236677753739, 0.045868422312196344, 0.12167800596216694, 0.31197602511383593, 0.15226256480673328, 0.154404774075374, 0.06471860222518444, 0.2791900187730789, 0.1639517766307108, 0.5665291158948094, 28.62351067364216, 45.232214257121086, 28.91059096902609, 41.602352634072304, 0.16672472236678004, 0.03448643365118187, 0.056956579865072854, 0.07714434366789646, 0.0580605319555616, 0.08778955409070477, 0.04727413906948641, 0.050839628020185046, 0.02467097216140246, 0.03208668058505282, 0.02679440880456241, 0.10327455442165956, 0.07521467065089382, 0.015625251398887485, 0.018224690429633483, 0.02934934866061667, 0.017311494411842432, 0.022198243714228738, 0.08273069703136571, 0.06582037982298061, 0.04822706410777755, 0.13604785519419238, 0.18696261453442276, 7.208077842369676, 69.35342252254486, 37.12295159697533, 40.83514340221882, 44.225614070892334, 46.92682072520256, 9.821825064718723, 0.5612369498703629, 0.35286129685118794, 0.06117589720815886, 0.11444973250036128, 0.15797278261743486, 0.14953474164940417, 0.45574039046186954, 0.6783721956890076, 0.07329636733629741, 3.197567369788885, 39.47683788836002, 66.04022070765495, 77.15758815407753, 85.75653433799744, 80.738136023283, 85.1742459833622, 87.72713899612427, 85.0503346323967, 83.03306847810745, 84.03601706027985, 83.99157464504242, 76.86076328158379, 79.58748936653137, 78.06663617491722, 71.97967439889908, 71.86194911599159, 74.02936801314354, 78.08455601334572, 79.5400071144104, 80.27920424938202, 80.6534917652607, 79.40646708011627, 75.83085894584656, 74.80657830834389, 74.25139009952545, 73.40202927589417, 74.98605027794838, 73.21446374058723, 72.43004143238068, 72.64103651046753, 76.56890094280243, 75.04702940583229, 73.91191631555557, 73.29397827386856, 70.45547738671303, 69.43979948759079, 67.72153168916702, 73.98075342178345, 73.41730445623398, 68.61491695046425, 73.52715656161308, 72.03498423099518, 62.769044637680054, 61.274793818593025, 70.61938539147377, 73.70941758155823, 69.99986663460732, 76.80208683013916, 61.22751295566559, 51.40484243631363, 59.75141756236553, 62.85351790487766, 57.86857679486275, 52.20271222293377, 51.94954700767994, 50.94755217432976, 49.777731746435165, 50.323884040117264, 56.79002746939659, 57.64243192970753, 61.895988285541534, 61.53612859547138, 60.169547125697136, 54.2071882635355, 50.56745857000351, 49.40882474184036, 50.1366300880909, 54.1916660964489, 54.07942391932011, 57.85971187055111, 63.7198182195425, 60.08725494146347, 51.64815478026867, 55.672898814082146, 68.40638414025307, 65.16024872660637, 64.52906459569931, 68.04079055786133, 67.19952329993248, 65.06916761398315, 62.19706133008003, 57.09587685763836, 62.80531749129295, 65.25964379310608, 63.93975421786308, 64.89832118153572, 61.51433676481247, 61.12640418112278, 66.06533735990524, 63.290194272994995, 65.4618613421917, 62.812582701444626, 67.08571180701256, 64.15353834629059, 61.97491765022278, 66.88420861959457, 61.58953092992306, 64.24721091985703, 63.83375510573387, 63.34856674075127, 60.77456586062908, 58.9887984842062, 54.53848108649254, 55.18936716020107, 58.16479749977589, 60.83127021789551, 61.48325823247433, 64.67803180217743, 65.43059661984444, 69.16923120617867, 67.69039615988731, 65.7438214123249, 63.70616935193539, 67.40858808159828, 73.01699593663216, 73.08696538209915, 67.95073539018631, 71.47688537836075, 49.26091007888317, 19.92846954613924, 4.069500882178545, 0.130598220275715, 0.21111475682118908, 0.11403886470361613, 0.5090950196608901, 0.15667332656448707, 0.16648233693558723, 0.06382811407092959, 0.1094385287433397, 0.4381781484698877, 0.7116147712804377, 0.451035886653699, 34.15069028735161, 49.63032245635986, 31.860727965831757, 53.775672018527985, 0.37418961175717413, 0.07322811943595298, 0.00857943308801623, 0.03974078725150321, 0.07798768318025395, 0.04321862856158987, 0.02256760504678823, 0.06188194682181347, 0.02149511630705092, 0.07254458658280782, 0.009404837674082955, 0.11978076479863375, 0.23781936761224642, 0.10145653752260841, 0.15455556364031509, 0.18429803720209748, 0.11697488254867494, 0.16822915960801765, 0.1912903448101133, 0.25322479486931115, 0.1983634871430695, 0.1993444430991076, 0.33234587113838643, 7.603216264396906, 85.88147163391113, 39.30708959698677, 71.94600060582161, 57.4733942002058, 52.179427072405815, 15.011389944702387, 0.9032564191147685, 0.7303082244470716, 0.0861557234020438, 0.5189374415203929, 0.5416590347886086, 0.745071501005441, 1.4472389104776084, 1.3124574115499854, 0.3149376396322623, 3.75174293294549, 45.68966791033745, 77.54929393529892, 90.5806490778923, 94.416414052248, 90.11591121554375, 91.59057408571243, 92.33325943350792, 86.22211575508118, 83.63038882613182, 89.92912083864212, 87.7168795466423, 81.92160531878471, 84.99452322721481, 81.21735870838165, 75.32652720808983, 75.95762774348259, 77.65127286314964, 81.96469500660896, 82.32122987508774, 83.8400387763977, 81.85398414731026, 83.2089914381504, 79.78304967284203, 79.24762040376663, 79.49894651770592, 76.10072046518326, 79.60327371954918, 77.69331380724907, 75.79957142472267, 76.54411107301712, 80.92570155858994, 78.29040616750717, 77.04827561974525, 75.08520975708961, 74.84779089689255, 73.09474736452103, 69.66383546590805, 76.5839633345604, 77.41417318582535, 71.60891309380531, 76.00525438785553, 78.68860200047493, 68.17958191037178, 63.65117110311985, 74.14960876107216, 79.26009893417358, 73.52421551942825, 80.51704108715057, 67.75748535990715, 54.5264433324337, 60.56324779987335, 66.8892927467823, 63.46056953072548, 56.451834216713905, 54.94942903518677, 51.02707430720329, 52.82603457570076, 51.72752872109413, 61.86324544250965, 60.644783824682236, 67.61754646897316, 65.34845262765884, 64.80443581938744, 59.737742096185684, 53.11061650514603, 54.1801793128252, 53.86259615421295, 57.39474982023239, 58.80680724978447, 61.928617134690285, 66.49828612804413, 59.49854873120785, 53.02472211420536, 61.470110937952995, 70.19918113946915, 66.75021260976791, 67.07484439015388, 71.12443909049034, 70.99375650286674, 65.87136536836624, 64.92310345172882, 58.62784065306187, 67.73673847317696, 68.62295731902122, 66.85341507196426, 67.85402297973633, 63.84337618947029, 65.40040343999863, 69.8605129122734, 66.64706334471703, 70.91803416609764, 67.55358070135117, 70.40644481778145, 65.98188623785973, 65.72610676288605, 71.30008846521378, 65.1275172829628, 71.3047394156456, 65.9036636352539, 66.56346023082733, 63.90688598155975, 66.11754655838013, 61.25085890293121, 63.68072971701622, 64.46899741888046, 67.83956855535507, 65.17127573490143, 68.97256895899773, 68.29649403691292, 73.52270320057869, 71.22939705848694, 70.80621376633644, 66.47703006863594, 72.45143428444862, 76.10400348901749, 77.59039252996445, 73.29493582248688, 75.70532888174057, 60.82132235169411, 32.39698939025402, 5.248524891212583, 0.21098399040056393, 0.7417104032356292, 0.4991549311671406, 1.4528424222953618, 0.4042273265076801, 0.3643545520026237, 0.339804959949106, 0.2607931278180331, 2.1247896971181035, 1.945533009711653, 1.059559725690633, 42.169301211833954, 60.20197458565235, 43.88323724269867, 61.862348690629005, 0.3870298352558166, 0.1565232197754085, 0.0775993469869718, 0.08764390018768609, 0.1506592586520128, 0.08713699848158285, 0.18088170880218968, 0.15374003240140155, 0.10786151688080281, 0.21595186757622287, 0.06120519719843287, 0.24701364221982658], [0.06917332138982601, 0.040279423192259856, 0.057568606789573096, 0.09595207273378037, 0.034111608256353065, 0.016575319168623537, 0.0904338485270273, 0.024459912783640902, 0.050499312492320314, 0.04856773215578869, 0.17223678674781695, 21.794007942080498, 49.96198005974293, 35.59134878218174, 43.83246436715126, 36.78054057061672, 38.70023936033249, 4.607614707201719, 0.8258137840311974, 0.2000001008855179, 0.07232729316456243, 0.17446131503675133, 0.05517823447007686, 0.0923041719943285, 0.27426729386206716, 0.1787294656969607, 0.07275440657394938, 7.809097766876221, 52.79675334692001, 65.80455735325813, 65.07533088326454, 70.77646896243095, 73.9846596121788, 80.60320526361465, 84.60144951939583, 80.68958222866058, 76.80702656507492, 80.05772933363914, 79.29477587342262, 75.4517836868763, 74.30838704109192, 71.4264240860939, 66.02546229958534, 66.99963122606277, 68.01088616251945, 72.64647021889687, 74.1107976436615, 73.59445855021477, 79.69608753919601, 74.41814795136452, 72.93401598930359, 73.53083476424217, 72.71051958203316, 70.2473321557045, 71.23004302382469, 69.11486372351646, 69.88620713353157, 69.48939442634583, 70.98363384604454, 69.8661670088768, 70.76374724507332, 70.22982269525528, 66.1636532843113, 66.30032435059547, 69.98040407896042, 71.17175415158272, 69.47544917464256, 69.82190698385239, 67.57952570915222, 57.860411033034325, 63.4458377212286, 66.37367561459541, 68.61546412110329, 66.01353853940964, 69.5547205209732, 58.52495737373829, 48.011423125863075, 60.692349672317505, 61.65983095765114, 57.62326955795288, 52.12116859853268, 50.83682991564274, 47.88003757596016, 47.97127068042755, 48.25507365167141, 48.66297036409378, 46.35629653930664, 47.102215513587, 53.241876661777496, 50.13958252966404, 46.21167249977589, 44.39839079976082, 49.057852774858475, 47.34631061553955, 47.57123574614525, 47.86126658320427, 50.26299610733986, 48.8669054210186, 53.80241118371487, 60.94849772751331, 62.71892532706261, 48.108743503689766, 55.016476437449455, 67.24795550107956, 62.392937019467354, 63.83630096912384, 62.36509591341019, 65.63104346394539, 63.28807018697262, 58.72525982558727, 54.16417457163334, 58.945541605353355, 66.05411276221275, 64.12515386939049, 63.36251579225063, 55.51937185227871, 59.88572135567665, 59.63265113532543, 58.97561699151993, 61.6690568625927, 57.688880637288094, 61.40831105411053, 61.004597917199135, 59.819061532616615, 61.493753269314766, 57.41769298911095, 57.21924103796482, 59.22364108264446, 57.062070071697235, 50.65752133727074, 49.313256070017815, 49.56005282700062, 53.906685188412666, 56.44466780126095, 59.12966452538967, 58.67305442690849, 60.9404269605875, 64.96719628572464, 67.55784407258034, 63.910275399684906, 62.37347066402435, 62.7370161563158, 66.2283182144165, 70.59619903564453, 65.03813087940216, 63.94222408533096, 37.569203451275826, 15.167629960924387, 4.629748994484544, 0.1228184717183467, 0.244354794267565, 0.025724302358867135, 0.049654065660433844, 0.05746517737861723, 0.11133249703561887, 0.1031007657002192, 0.23272032325621694, 0.08023436457733624, 0.04563787784718443, 0.13261530344607309, 13.055162765085697, 51.02871581912041, 27.08663184195757, 43.62333498895168, 2.9825122095644474, 0.4916117718676105, 0.07094691332895309, 0.05189076517126523, 0.06462601930252276, 0.03701936511788517, 0.03604600133257918, 0.03516189564834349, 0.032264332185150124, 0.056446806047460996, 0.31481643207371235, 0.09065327933058143, 0.04115114985324908, 0.034686004582908936, 0.032088213120005094, 0.04673651616030838, 0.040116822347044945, 0.08763094228925183, 0.030436821361945476, 0.036289577910793014, 0.023881904053268954, 0.004665084170483169, 0.12539206916699186, 34.798346534371376, 61.53976880013943, 49.984300062060356, 46.7827932536602, 40.54668568074703, 43.03628169000149, 7.71564225666225, 1.6824236093088984, 0.20058255322510377, 0.10674412449588999, 0.14368660311447456, 0.07164270646171644, 0.12632488942472264, 0.38187268073670566, 0.4329053673427552, 0.15388378640636802, 8.515193928033113, 55.145190730690956, 73.93319517374039, 77.32742384076118, 79.528166949749, 81.62614837288857, 83.46325099468231, 88.59495922923088, 83.79593834280968, 79.66489881277084, 82.6237316429615, 81.62542641162872, 79.19140622019768, 76.13376349210739, 76.08328700065613, 70.99662154912949, 70.13447061181068, 70.95964953303337, 76.3110239803791, 78.04213508963585, 77.65819609165192, 81.43745049834251, 78.63557204604149, 77.02325776219368, 75.20212948322296, 75.171457529068, 73.63131657242775, 74.24949780106544, 72.71773159503937, 73.0640298128128, 72.24220231175423, 71.67608588933945, 70.2285535633564, 73.78782257437706, 72.92185664176941, 69.4662156701088, 71.0266475379467, 72.7710123360157, 71.2700928747654, 70.60223311185837, 72.61876210570335, 66.39470368623734, 60.68638779222965, 66.47369384765625, 69.12013784050941, 68.80227729678154, 70.42762488126755, 73.42833906412125, 57.51594431698322, 52.75484159588814, 63.95278751850128, 63.56422416865826, 59.16496463119984, 55.468192398548126, 52.130960673093796, 51.96294128894806, 49.46582928299904, 50.74526622891426, 49.39743295311928, 49.22820143401623, 49.20676298439503, 55.737366154789925, 51.90317049622536, 49.13202479481697, 47.22602806985378, 51.30335368216038, 50.3898598998785, 48.779194727540016, 51.65961876511574, 52.22744129598141, 52.565919533371925, 56.09802380204201, 60.45868121087551, 65.40463641285896, 53.66809979081154, 53.5574497282505, 66.57884940505028, 66.16304531693459, 64.03949126601219, 66.10686913132668, 67.13383242487907, 66.48506283760071, 58.58942471444607, 57.18129627406597, 59.49046276509762, 67.67814561724663, 65.53263634443283, 66.02234646677971, 60.221178755164146, 63.690825775265694, 62.494323179125786, 63.65123189985752, 64.53550904989243, 59.52617704868317, 61.39346145093441, 64.51660126447678, 60.57305887341499, 63.13790984451771, 61.03045932948589, 61.32361739873886, 61.14785023033619, 60.162840485572815, 55.60210481286049, 56.447719037532806, 55.49064539372921, 59.59837697446346, 58.48228566348553, 62.097514271736145, 61.4291263371706, 65.02651110291481, 68.83123934268951, 69.17727157473564, 68.32006797194481, 66.00819602608681, 69.88653391599655, 67.44789317250252, 73.5186830163002, 66.35709330439568, 70.52897304296494, 53.260818645358086, 24.501070082187653, 6.081517618149519, 0.17536533996462822, 0.17234309198101982, 0.026351702872489113, 0.10486618659342639, 0.17432680819183588, 0.23828698002034798, 0.11580163612961769, 0.07271390757523477, 0.22721709043253213, 0.4996446892619133, 0.27716419310308993, 15.823942143470049, 54.63828273117542, 30.87069869041443, 58.514587730169296, 5.359787670895457, 0.27538128721062094, 0.03867219107632991, 0.08996703021693975, 0.0498657224670751, 0.044647897375398315, 0.05263025224849116, 0.02432636516459752, 0.071769710193621, 0.09843062332947738, 0.16950050310697407, 0.06553214450832456, 0.16217434778809547, 0.20019063988002017, 0.16200561309233308, 0.20872959808912128, 0.06635739788180217, 0.13592544535640627, 0.1792533477419056, 0.19988701242255047, 0.11235922866035253, 0.2560801338404417, 0.2489684146712534, 41.71438582241535, 70.91750219464302, 48.57669599354267, 63.889566510915756, 49.275448098778725, 58.29046055674553, 12.163022886961699, 3.0371145671233535, 0.5945942911785096, 0.3986619313945994, 0.30735565116629004, 0.36768447957001626, 0.3531450644368306, 1.1863837391138077, 0.9911207668483257, 0.48471778398379683, 12.051046695560217, 60.62599003314972, 87.47235506772995, 88.34652855992317, 89.43227469921112, 91.79578587412834, 88.66017132997513, 92.20919609069824, 87.59376615285873, 80.48158138990402, 84.81934502720833, 85.44441908597946, 83.63678008317947, 81.19247764348984, 79.6063743531704, 72.63599038124084, 73.07239696383476, 74.58082482218742, 78.96124497056007, 81.15061908960342, 79.95388850569725, 84.75720316171646, 79.52504351735115, 81.26221150159836, 79.77375537157059, 78.61323684453964, 76.43061876296997, 80.24250581860542, 76.32266655564308, 75.30649468302727, 75.51568105816841, 75.84816321730614, 73.91373261809349, 77.32502236962318, 77.02084869146347, 72.86432772874832, 70.68620100617409, 76.52464851737022, 74.18993979692459, 73.04374650120735, 75.49523815512657, 72.14590787887573, 63.703467696905136, 68.84774565696716, 72.14955568313599, 71.90159618854523, 73.44875156879425, 74.98762339353561, 63.58308635652065, 56.09503336250782, 64.86280828714371, 67.32144355773926, 61.31127946078777, 57.5492799282074, 57.32206732034683, 55.24073660373688, 52.56991311907768, 51.70321382582188, 52.204175144433975, 52.12594494223595, 51.640604585409164, 59.0766915678978, 55.09421266615391, 53.35947275161743, 49.20138627290726, 55.939655900001526, 54.14959475398064, 52.34520457684994, 52.05523453652859, 56.76957316696644, 55.28159961104393, 58.714996576309204, 64.79239046573639, 68.82814630866051, 54.153683334589005, 60.36127343773842, 71.6171358525753, 69.39297839999199, 67.57809698581696, 66.77543565630913, 71.89101755619049, 68.70310261845589, 62.565763145685196, 58.55190932750702, 62.96418696641922, 70.5301433801651, 66.69700026512146, 68.52171555161476, 64.04788881540298, 67.24024191498756, 64.75773632526398, 66.91314786672592, 67.69764617085457, 62.293705344200134, 65.45910269021988, 67.12022915482521, 65.21484419703484, 66.27312541007996, 63.70886340737343, 65.85393190383911, 67.14187279343605, 65.47012209892273, 63.215117901563644, 62.82142862677574, 61.622038185596466, 65.1294019818306, 64.74870800971985, 65.08122056722641, 66.19014546275139, 68.13976004719734, 72.08814337849617, 71.62297233939171, 73.56869593262672, 67.17799365520477, 73.40243965387344, 70.77872604131699, 77.03512072563171, 69.23243701457977, 75.20929589867592, 65.06086885929108, 35.28302952647209, 7.6546018570661545, 0.20456834638025612, 0.5337543308269233, 0.12473072652937844, 0.2943226177012548, 0.24374332395382226, 0.4216547647956759, 0.21303956134943292, 0.48437942401506007, 0.7442021195311099, 0.9570089285261929, 0.4109111084835604, 20.87539203464985, 70.40807873010635, 39.97815638780594, 69.8269759118557, 7.239728244021535, 0.7048450189176947, 0.25686633540317416, 0.21609623014228418, 0.1939686221885495, 0.152538480469957, 0.12327979813562706, 0.18787199776852503, 0.1511634440976195, 0.27588478988036513, 0.37897981877904385, 0.12006782009848393], [0.04428480904607568, 0.04991114190488588, 0.06323288936982863, 0.014078624917601701, 0.06322644752799533, 0.03494411241263151, 0.06295521481661126, 0.25956701079849154, 0.14484745566733181, 0.009266478155041113, 8.514784500002861, 50.603093057870865, 30.340917818248272, 24.222765415906906, 30.5622236430645, 60.718572065234184, 11.625764016062021, 1.657643832731992, 1.008621915243566, 0.6815907417330891, 0.07253818184835836, 0.10174653914873488, 0.2691542526008561, 0.2340581186581403, 2.3463092604652047, 0.8655284810811281, 1.1787450802512467, 24.860306605696678, 67.54348084330559, 79.12558615207672, 63.33723954856396, 73.07961657643318, 78.87926056981087, 84.27164241671562, 82.93602168560028, 81.60759776830673, 74.43503424525261, 80.66323444247246, 77.58453324437141, 80.26155039668083, 75.93149274587631, 76.68025016784668, 72.81186774373055, 66.99311077594757, 64.78979900479317, 68.4843635559082, 74.13684904575348, 74.58384945988655, 75.07545188069344, 74.61703687906265, 71.56243398785591, 71.82766735553741, 72.0408283174038, 71.49918258190155, 72.31119900941849, 67.76159673929214, 69.87244427204132, 71.74211874604225, 70.50498872995377, 71.46718829870224, 68.8115867972374, 69.3504586815834, 67.18637600541115, 72.26852729916573, 71.8576629459858, 72.43149295449257, 71.51120513677597, 65.24989351630211, 56.974697560071945, 63.136697709560394, 71.35667502880096, 68.60152646899223, 65.92402294278145, 70.52592560648918, 55.573203563690186, 50.95390163362026, 63.68221543729305, 62.50249274075031, 53.779969587922096, 55.48768915235996, 52.01890468597412, 45.85947699844837, 46.46368257701397, 45.14060117304325, 46.744422912597656, 48.616453260183334, 54.12086829543114, 58.562666550278664, 60.23727849125862, 58.798622488975525, 56.11071892082691, 49.58700858056545, 46.44145376980305, 46.32442384958267, 45.97657151520252, 45.88832505047321, 47.875230833888054, 51.62789426743984, 55.753469690680504, 53.66503335535526, 57.13326305150986, 64.61681708693504, 48.88689614832401, 51.02186858654022, 63.16415123641491, 62.593418061733246, 61.990470215678215, 58.77343364059925, 61.90418444573879, 61.63251422345638, 61.26515753567219, 57.087289318442345, 60.340613946318626, 61.0289204120636, 61.773885637521744, 60.72152450680733, 56.524706706404686, 60.18796853721142, 60.61067685484886, 59.48455788195133, 59.20700557529926, 59.103480130434036, 59.68577988445759, 59.6576651930809, 60.38848377764225, 58.97416926920414, 56.89132243394852, 54.695823043584824, 51.603799760341644, 50.84101349115372, 50.68101927638054, 52.129862532019615, 53.96364413201809, 55.84979072213173, 58.24157238006592, 59.922769367694855, 61.84846043586731, 67.08138763904572, 61.97693534195423, 63.39513324201107, 64.47289600968361, 66.01720914244652, 63.452848345041275, 69.60144281387329, 64.76869493722916, 66.14829450845718, 39.857835844159126, 20.478999204933643, 6.325000477954745, 0.15897551318630576, 0.27746657375246286, 0.20332645130110905, 0.03625569515861571, 0.46302174974698573, 0.09765599184902385, 0.13910461304476485, 0.126809764187783, 0.1278140235808678, 0.14889696962200105, 0.2976121724350378, 8.21862269192934, 48.43763865530491, 28.426844626665115, 25.75665570795536, 20.312334448099136, 0.5579940020106733, 0.10399919483461417, 0.04709781220299192, 0.07110453065251932, 0.027393531636334956, 0.04976749922207091, 0.055637375262449495, 0.06989582441747189, 0.01765023473126348, 0.14235330512747169, 0.14085335045820102, 0.06488729239208624, 0.008982421131804585, 0.03314322428195737, 0.037235779091133736, 0.06398158278898336, 0.030714586828253232, 0.07717521701124497, 0.032815454760566354, 0.2050439442973584, 0.02641862603923073, 13.977225087583065, 65.86479932069778, 42.971073389053345, 36.47186793386936, 24.471811652183533, 60.03693804144859, 15.901465583592653, 3.602832960896194, 2.333962772972882, 1.4150532125495374, 0.053688150364905596, 0.10652445620507933, 0.32159690104890615, 0.3008004982257262, 3.698737439699471, 1.1510600033216178, 1.7804166697897017, 26.82127308100462, 71.40245497226715, 86.98845863342285, 78.62269833683968, 80.78491911292076, 85.58683544397354, 87.9742169380188, 86.81782498955727, 83.2887415587902, 75.38182944059372, 83.73459443449974, 78.92640843987465, 85.76300919055939, 80.03900393843651, 78.95713359117508, 76.2541638314724, 69.88230094313622, 67.2876101732254, 70.21964684128761, 77.74928480386734, 78.0224597454071, 78.72396290302277, 78.42423498630524, 76.90898269414902, 75.5914793908596, 74.4619520008564, 75.4614807665348, 73.76889199018478, 71.90978094935417, 72.25824505090714, 71.31613880395889, 74.37486827373505, 75.13881728053093, 71.81631356477737, 71.07051998376846, 70.38143455982208, 73.78225207328796, 72.76086688041687, 73.24569046497345, 72.35986679792404, 65.67946806550026, 60.85914932191372, 68.10823693871498, 72.01472371816635, 70.08575722575188, 69.10745412111282, 71.36821120977402, 56.65837973356247, 55.71426339447498, 65.96630707383156, 63.78408417105675, 58.15038487315178, 59.04691256582737, 54.67626169323921, 48.45129892230034, 49.92006830871105, 47.68514983355999, 49.97046500444412, 49.839885011315346, 60.124158561229706, 63.9566633105278, 66.23836487531662, 64.81664076447487, 61.65652513504028, 52.85978816449642, 49.18331064283848, 47.930909246206284, 48.99656966328621, 48.315619602799416, 49.943524450063705, 55.092426761984825, 60.6051329523325, 57.25972406566143, 58.42562310397625, 65.0989656150341, 55.36769159138203, 51.1592236161232, 63.4123083204031, 65.60827508568764, 63.73323529958725, 62.85895921289921, 64.63078513741493, 64.71918359398842, 64.76961448788643, 60.37671200931072, 60.23508220911026, 65.37640392780304, 63.8623371720314, 65.55264607071877, 57.55421206355095, 60.91096334159374, 66.16469442844391, 61.23288966715336, 62.65016421675682, 59.53789941966534, 62.979112565517426, 63.76180216670036, 61.7851672321558, 61.617896407842636, 60.98598651587963, 59.30182188749313, 58.05749125778675, 55.88160261511803, 56.019326224923134, 56.193634271621704, 60.46735234558582, 61.372045800089836, 61.67217269539833, 64.44062054157257, 64.7173672914505, 67.77165859937668, 63.836878538131714, 67.15286180377007, 66.70421987771988, 70.9515255689621, 67.05788969993591, 73.49977523088455, 67.6761545240879, 72.90974289178848, 53.39451067149639, 28.580544479191303, 7.811236577108502, 0.12056012375978753, 0.3435480559710413, 0.1121706489357166, 0.02685973078769166, 0.3061536094173789, 0.1527318693115376, 0.1618061089538969, 0.2455294507672079, 0.24789544724626467, 0.4277781955897808, 0.36219323985278606, 9.35901939868927, 55.98530285060406, 33.862114772200584, 38.87651950120926, 30.570898577570915, 0.5000588670372963, 0.04700305107689928, 0.05783402106317226, 0.13045347179286182, 0.03361466988280881, 0.013279520189826144, 0.09287518041674048, 0.08012856400455348, 0.03257094678701833, 0.05118011053127702, 0.05584849772276357, 0.12802437791833654, 0.10684425506042317, 0.16251720517175272, 0.16629025427391753, 0.15795793966390193, 0.11807023314759135, 0.29263924865517765, 0.5078648950438946, 0.3503011545399204, 0.16866083722561598, 13.398792576044798, 83.40560808777809, 45.62748804688454, 34.59137164056301, 43.791111186146736, 77.55566239356995, 20.411720015108585, 8.542461264878511, 4.928930215537548, 1.711150542832911, 0.1160010883177165, 0.33991135424003005, 0.6484564603306353, 0.7180066220462322, 5.1037507597357035, 2.409546892158687, 2.180453147739172, 35.40232792496681, 83.01329433917999, 98.54067474603653, 88.55488657951355, 89.35468286275864, 90.73248893022537, 93.4990444779396, 91.49994894862175, 87.84778252243996, 77.39968836307526, 87.4895529448986, 83.9720968902111, 89.54556941986084, 82.62104898691177, 82.78738126158714, 80.24714916944504, 73.72701823711395, 70.64636394381523, 75.13804972171783, 80.97867831587791, 80.5109766125679, 83.6340594291687, 79.48427930474281, 79.04208183288574, 79.13184821605682, 78.67378279566765, 77.81507447361946, 76.8267323076725, 71.90047144889832, 76.57440304756165, 76.5793351829052, 76.20773032307625, 78.90961334109306, 75.62880858778954, 75.84462180733681, 71.86191111803055, 77.15040653944016, 77.10075080394745, 77.74818286299706, 77.89264351129532, 70.95172315835953, 61.417749747633934, 68.61910432577133, 78.05089741945267, 74.05902922153473, 72.60548561811447, 75.27434840798378, 62.85015128552914, 55.978801399469376, 68.64347621798515, 68.65278571844101, 60.57862937450409, 61.61963291466236, 57.52480164170265, 50.23597955703735, 50.809224396944046, 50.39559379220009, 51.736492440104485, 51.18908241391182, 60.46222262084484, 63.818365931510925, 67.32595771551132, 63.65782454609871, 64.45774242281914, 56.81620046496391, 52.21020922064781, 50.99458605051041, 52.28060804307461, 49.633917063474655, 54.479481652379036, 56.675345823168755, 62.46281906962395, 59.272426664829254, 61.46785765886307, 70.75077474117279, 53.537899777293205, 55.52603669464588, 66.50653168559074, 66.8168306350708, 66.85699447989464, 66.19805663824081, 67.92289808392525, 66.59444376826286, 66.878911703825, 60.883532613515854, 63.77573221921921, 67.84597501158714, 67.94022515416145, 66.63664430379868, 63.0796779692173, 66.617371737957, 69.2697586119175, 66.78175091743469, 65.27725204825401, 64.56909164786339, 66.05516910552979, 65.77929630875587, 65.87237611413002, 66.03322148323059, 64.06312599778175, 64.79587107896805, 64.45230111479759, 64.80050683021545, 63.37277144193649, 62.363800182938576, 65.30015721917152, 65.42677402496338, 63.58370192348957, 69.78147715330124, 68.13384756445885, 71.95337980985641, 67.086600959301, 72.2363430261612, 70.50546750426292, 74.84945520758629, 72.711933106184, 78.4062771499157, 73.97105634212494, 77.35592991113663, 63.9040133357048, 41.32475093007088, 8.949471674859524, 0.37627917306963354, 0.713127861963585, 0.31356401334051043, 0.42548288125544786, 0.6496178917586803, 0.4000643827021122, 0.25991561240516603, 0.40232238185126334, 0.4256532486760989, 0.48373669444117695, 0.4420462221605703, 12.289382256567478, 69.47421804070473, 42.95934721827507, 46.74067251384258, 37.74787366390228, 0.6517084920778871, 0.16290914820274338, 0.19167519290931523, 0.2877556497696787, 0.13010920432861894, 0.1199401484336704, 0.14610799349611625, 0.2465837902855128, 0.11903866907232441, 0.23699904209934175, 0.11871772730955854], [2.447090777568519, 0.2583356393733993, 0.07961801093188114, 0.05077218163933139, 0.23352187243290246, 0.2056943328352645, 0.7295941596385092, 2.465558499097824, 0.1616924416157417, 3.807410183362663, 52.1552299708128, 50.87450869381428, 25.42626913636923, 28.020764216780663, 55.66356651484966, 45.359511226415634, 0.840830400120467, 0.4271615302423015, 0.7553905597887933, 0.9601279080379754, 0.18951126839965582, 0.06134397139248904, 0.12490002525737509, 0.2484312778688036, 2.202127897180617, 7.685364056378603, 6.74961106851697, 55.27796320617199, 85.0484499335289, 67.98738062381744, 74.89470317959785, 80.78000977635384, 83.24537068605423, 82.76447609066963, 83.47635269165039, 82.79382571578026, 77.53528028726578, 80.30421450734138, 76.93753436207771, 78.88767331838608, 77.6877661049366, 77.2380830347538, 72.33868673443794, 65.74811518192291, 63.638012409210205, 61.92609027028084, 67.14805886149406, 74.81246039271355, 74.17560696601868, 71.53879165649414, 75.44975459575653, 75.05409702658653, 71.70912891626358, 68.76371696591377, 71.20693266391754, 73.58144044876099, 67.96237796545029, 69.5016297698021, 69.49213027954102, 66.27748757600784, 67.08443507552147, 67.85510212182999, 71.2275579571724, 66.84219047427177, 72.74864673614502, 69.77665141224861, 63.604672998189926, 58.28240118920803, 65.54194584488869, 67.79643326997757, 68.02113801240921, 66.71316459774971, 69.97405841946602, 53.6844427138567, 51.58222831785679, 67.96484023332596, 62.27235808968544, 57.76451177895069, 57.244866862893105, 54.49598416686058, 50.846268609166145, 45.96464015543461, 45.2444913983345, 48.462048545479774, 49.43274065852165, 54.211026057600975, 61.08470901846886, 64.85082373023033, 68.17537173628807, 65.0133790075779, 62.634596452116966, 54.80906456708908, 44.87955518066883, 45.23169368505478, 45.79529084265232, 47.359416112303734, 45.303927809000015, 48.403163105249405, 53.990360498428345, 59.261433854699135, 60.95865838229656, 59.795255810022354, 61.40954598784447, 48.7195835262537, 50.250532776117325, 63.48052605986595, 64.25072953104973, 62.85922519862652, 59.85989414155483, 62.71277345716953, 61.516012474894524, 63.41019183397293, 58.54898728430271, 62.20487751066685, 60.148408859968185, 61.37267656624317, 59.485272243618965, 56.32010668516159, 60.042519941926, 59.103924706578255, 60.72022117674351, 62.39514850080013, 56.999540627002716, 62.907406613230705, 58.660252913832664, 59.42631460726261, 55.96846595406532, 53.380098044872284, 50.28888411819935, 50.10318048298359, 51.102606654167175, 52.31930136680603, 55.57934023439884, 55.35004913806915, 58.0879770219326, 58.763960748910904, 60.53788796067238, 62.07603022456169, 61.85380294919014, 63.79429802298546, 59.94640789926052, 66.25580593943596, 59.36400555074215, 68.83313924074173, 68.98603543639183, 64.35264006257057, 44.99419502913952, 24.906445629894733, 8.9269407838583, 0.04048987400892656, 0.14137714344542474, 0.12952746445080265, 0.1241435763949994, 0.1599847894976847, 0.176578038954176, 0.09764355345396325, 0.23937591846333817, 0.19743050361284986, 0.40718077740166336, 0.29272919695358723, 7.8694565780460835, 33.828551173210144, 40.14505863189697, 23.16315997391939, 34.856992587447166, 19.530174918472767, 0.7502122689038515, 0.1335839249077253, 0.16356893233023584, 0.17835687787737697, 0.03955723928811494, 0.014767296215723036, 1.1936960904859006, 5.236630104482174, 5.174031788483262, 5.741824870929122, 1.2528278050012887, 0.07568960063508712, 0.027448198234196752, 0.07237720259581693, 0.0965471267409157, 0.18076455336995423, 0.17271757969865575, 0.7882708485703915, 0.4479794256621972, 5.71811699308455, 68.00091549754143, 59.028472155332565, 41.4985042065382, 27.360614240169525, 46.141611859202385, 51.782720759510994, 1.488115454558283, 0.5902987997978926, 1.4450954692438245, 1.2614614167250693, 0.06285025287070312, 0.09592274305759929, 0.10837313122465275, 0.04768148537550587, 3.105299058370292, 10.291108433157206, 9.55035338178277, 56.183534413576126, 87.0534959435463, 81.17562934756279, 79.45019513368607, 84.63660523295403, 86.20542705059052, 87.35777601599693, 85.30929833650589, 83.8980920612812, 80.50131753087044, 81.05255395174026, 80.62353417277336, 82.38220900297165, 81.95261165499687, 79.79687333106995, 77.26991012692451, 71.03517428040504, 66.60674750804901, 65.11763021349907, 71.09594821929932, 76.72947272658348, 74.70637008547783, 74.52754408121109, 78.85007053613663, 76.31334185600281, 75.36473035812378, 73.7384632229805, 72.72794544696808, 76.74487709999084, 71.78672075271606, 70.9113997220993, 69.9286736547947, 66.58223122358322, 68.8279639184475, 70.6045737862587, 73.10669392347336, 68.61560091376305, 73.05952325463295, 70.6707814335823, 64.79513391852379, 63.66352804005146, 70.46513646841049, 71.12136125564575, 69.36950325965881, 69.11804035305977, 71.76177129149437, 55.13791412115097, 56.35401226580143, 70.93140184879303, 63.008215203881264, 64.33339029550552, 60.85450977087021, 54.33986194431782, 52.77741998434067, 49.66636352241039, 49.25768785178661, 48.95320639014244, 50.74050508439541, 57.31311500072479, 63.69933731853962, 66.53895914554596, 69.60323631763458, 66.70354351401329, 64.14563477039337, 56.30469851195812, 50.09367719292641, 49.586290419101715, 48.43991093337536, 49.02979128062725, 47.14924179017544, 51.469237580895424, 55.50389528274536, 60.25478795170784, 63.513998463749886, 62.034384459257126, 64.62070807814598, 53.797410652041435, 52.41194799542427, 64.00247365236282, 65.9351259469986, 65.19563242793083, 62.33176790177822, 63.011904805898666, 63.31212289631367, 64.67118456959724, 59.37406741082668, 64.7753369808197, 62.63912960886955, 63.917168229818344, 63.23569379746914, 58.453213423490524, 63.658447712659836, 62.196772545576096, 60.78035295009613, 63.60526576638222, 58.90405163168907, 64.35203969478607, 60.66254407167435, 62.67644740641117, 60.36702632904053, 58.056928887963295, 57.49803587794304, 53.2195832580328, 55.85297495126724, 57.72424913942814, 61.56244978308678, 60.45632153749466, 62.845450937747955, 61.70125633478165, 64.10229429602623, 64.00770217180252, 63.96188423037529, 67.18068391084671, 63.837737292051315, 70.09168490767479, 62.474222257733345, 72.20320120453835, 71.78817987442017, 69.3123771250248, 56.16431884467602, 31.14674437791109, 9.641282502561808, 0.02796067903545918, 0.150081570900511, 0.061750300956191495, 0.3169162943959236, 0.15118547104066238, 0.2767801168374717, 0.23462169076083228, 0.48738728917669505, 0.16588136058999225, 0.519883472006768, 0.3335248172516003, 8.157980795949697, 42.296043410897255, 44.81074847280979, 29.938128031790257, 48.577307760715485, 26.461996659636497, 0.6108296918682754, 0.05183996516279876, 0.12159331206930801, 0.13188976503442973, 0.013993391112308018, 0.06787422156776302, 0.6516913929954171, 2.0400608936324716, 3.0555074801668525, 3.0861870339140296, 3.5828303592279553, 0.39156394195742905, 0.10563580857706256, 0.11733710998669267, 0.3808111423859373, 1.3127197162248194, 0.9471054130699486, 4.315504906699061, 0.9617261972744018, 5.568040246143937, 77.46862426400185, 74.34101209044456, 41.72393091022968, 40.118281468749046, 78.8019423186779, 65.13912945985794, 3.381657279096544, 1.3055641064420342, 4.47758330963552, 2.3316650837659836, 0.35519092809408903, 0.22231380979064852, 0.44118880410678685, 0.4245701583568007, 4.8513084556907415, 12.602354362607002, 14.277197141200304, 65.27944833040237, 94.60265725851059, 87.75575146079063, 89.83369275927544, 90.73030024766922, 91.82426914572716, 90.48912718892097, 90.87610602378845, 88.9950929582119, 84.87911581993103, 83.12244728207588, 80.479506701231, 86.59654006361961, 85.88251277804375, 81.11293271183968, 79.30700361728668, 74.44046795368195, 70.06001740694046, 68.60531106591225, 75.19094288349152, 83.48874002695084, 77.88649544119835, 78.89727160334587, 79.28889378905296, 79.9974949657917, 78.20428758859634, 77.49026030302048, 75.70151388645172, 79.82943758368492, 75.96365422010422, 72.16596320271492, 75.20447015762329, 70.9357488155365, 71.41729697585106, 73.44859957695007, 77.6107670366764, 71.6996218264103, 77.05278217792511, 75.26465892791748, 69.42181125283241, 63.95689129829407, 71.06517747044563, 74.6622696518898, 73.41088280081749, 72.81196653842926, 75.4565942287445, 59.30516950786114, 56.90826952457428, 74.50677439570427, 68.01930651068687, 63.999866992235184, 63.34296964108944, 58.87624092400074, 57.093574181199074, 52.4894904345274, 50.564274340867996, 54.71761867403984, 54.154249504208565, 58.29454533755779, 68.57159167528152, 69.62601229548454, 74.8594182729721, 71.23803779482841, 67.91155949234962, 59.38187979161739, 52.35234819352627, 53.427158519625664, 52.3015259206295, 50.402691811323166, 48.29585686326027, 54.73769299685955, 61.35407276451588, 66.2613308429718, 66.72489076852798, 67.61874720454216, 68.12902182340622, 54.61414262652397, 56.10776647925377, 69.7478261590004, 70.05614921450615, 67.58400946855545, 64.78569522500038, 66.62022158503532, 65.32035693526268, 68.24857100844383, 61.04547992348671, 67.30375930666924, 64.22633484005928, 67.84232720732689, 65.17960488796234, 61.897679194808006, 65.86077153682709, 65.92567205429077, 64.78089988231659, 65.84901496767998, 61.84944458305836, 68.33512276411057, 64.77182596921921, 66.80458769202232, 63.93510326743126, 62.50759206712246, 63.33790071308613, 62.25948818027973, 62.76863045990467, 63.78586247563362, 64.82766017317772, 63.560819551348686, 66.71406134963036, 65.88021129369736, 68.20608168840408, 67.45192855596542, 69.12298008799553, 70.70455402135849, 65.98326176404953, 72.25594997406006, 64.26375523209572, 77.1940889954567, 76.82280331850052, 74.62035030126572, 67.04554796218872, 41.13854192197323, 11.690026167780161, 0.08842029055813327, 0.3705523459939286, 0.12730793823720887, 0.7025657943449914, 0.21226746059255674, 0.5901309556793422, 0.38229303318075836, 0.6839567678980529, 0.22613043780438602, 0.6186261016409844, 0.4064821789506823, 10.917235985398293, 50.83415485918522, 56.78511053323746, 36.782816648483276, 60.81292100250721, 33.25910232961178, 0.7226407108828425, 0.3409417817601934, 0.19217596447560936, 0.3016683063469827, 0.19173000793671235, 0.10199536642176099, 1.5535713359713554, 4.997617229819298, 7.075150525197387, 6.594517165794969], [16.366295590996742, 10.023618936538696, 0.789905710844323, 0.1466751575935632, 3.085739607922733, 1.4782699453644454, 0.6300105282571167, 6.636709151789546, 2.14803708717227, 21.707368791103363, 61.81426227092743, 37.211395651102066, 25.05873005837202, 27.94819761067629, 64.58970174193382, 14.032041896134615, 0.0052615579988923855, 0.08908725867513567, 0.5175983102526516, 0.08316512801684439, 0.06651450312347151, 0.0594227514375234, 0.12572159757837653, 0.1251000043703243, 0.7807148946449161, 5.437173843383789, 24.479325748980045, 74.27935659885406, 72.80415415763855, 73.38470220565796, 84.3426302075386, 80.21094471216202, 81.52658611536026, 80.46447470784187, 81.28868088126183, 81.28175005316734, 78.60017314553261, 77.81633600592613, 78.60098630189896, 77.03104734420776, 78.66686716675758, 76.46721839904785, 75.75683131814003, 71.72916904091835, 61.666362807154655, 61.318586468696594, 62.39200606942177, 70.69380819797516, 72.40045621991158, 71.27779126167297, 70.3362625837326, 71.28129467368126, 72.2050479054451, 68.63560304045677, 67.1654087305069, 69.37046080827713, 69.83777493238449, 68.16002815961838, 67.06860512495041, 61.97551041841507, 66.06608211994171, 72.38018810749054, 67.0825807750225, 66.16230815649033, 70.91558709740639, 64.29247409105301, 61.43773667514324, 67.38575130701065, 68.4552039206028, 67.17471063137054, 66.36902466416359, 68.74040901660919, 56.52581624686718, 51.69313296675682, 67.88600206375122, 63.97599667310715, 62.582261860370636, 64.0661658346653, 54.13477934896946, 50.171846598386765, 47.51754842698574, 46.444478407502174, 45.25154381990433, 46.94202370941639, 51.12994618713856, 55.51496408879757, 61.07014819979668, 63.641227036714554, 63.01936000585556, 58.884098902344704, 59.41659092903137, 55.66887862980366, 49.29879404604435, 43.795990124344826, 42.20723457634449, 46.88142456114292, 45.31249634921551, 45.73779232800007, 48.01238067448139, 52.75280110538006, 56.610585898160934, 63.830190896987915, 60.09023778140545, 60.23336470127106, 50.723060220479965, 52.648291513323784, 53.156012669205666, 60.07706768810749, 61.477167159318924, 60.49941882491112, 62.514207512140274, 61.751402243971825, 61.05243355035782, 59.20373015105724, 61.141724959015846, 59.62933771312237, 61.63211904466152, 56.29609577357769, 58.62566716969013, 58.915827199816704, 58.39941591024399, 62.33301043510437, 54.62833486497402, 57.191126346588135, 58.289677798748016, 57.06879951059818, 56.332725808024406, 53.28017860651016, 50.10726906359196, 47.73251809179783, 49.72929194569588, 55.39190389215946, 56.1094231903553, 54.412996619939804, 57.05849066376686, 59.427063167095184, 58.576285019516945, 62.09347888827324, 63.93991380929947, 63.55074629187584, 62.19954639673233, 61.787796691060066, 64.29266408085823, 64.7446346282959, 65.01334100961685, 64.66637402772903, 45.4941114038229, 31.512051075696945, 9.766007959842682, 0.37466995941940695, 0.5617360887117684, 0.5366731085814536, 0.07316828006878495, 0.18170316237956285, 0.28397523856256157, 0.11890795460203663, 0.3233404434286058, 0.15489352284930646, 0.604834504192695, 0.42944007203914225, 7.690089577808976, 43.68514247238636, 45.47480843961239, 43.38094599545002, 20.07531076669693, 49.57723170518875, 7.9305321257561445, 0.2647891180822626, 0.14763270621187985, 0.09091827800148167, 0.1881679959478788, 6.771628987044096, 10.873743519186974, 11.979124154895544, 8.94075209274888, 15.06460988894105, 18.01116842776537, 7.060943087562919, 0.6874350656289607, 0.14230473898351192, 0.7465708174277097, 1.1589455301873386, 1.1539575853385031, 5.000922102481127, 1.2527925381436944, 33.704708218574524, 72.49200850725174, 54.38485153019428, 40.55804327130318, 25.358606167137623, 64.27941039204597, 18.642992824316025, 0.17676131974440068, 0.10043967646197416, 0.577511714072898, 0.37710960663389415, 0.26432025886606425, 0.01631367500522174, 0.30274424236267805, 0.09306059117079712, 1.2657830910757184, 13.050172682851553, 27.86187954246998, 72.5950437784195, 81.63227364420891, 76.6892708837986, 86.76379188895226, 85.35263121128082, 87.66378879547119, 83.96066710352898, 83.42373311519623, 83.39752972126007, 82.80361399054527, 82.64553487300873, 80.10150298476219, 81.54306963086128, 81.80881217122078, 79.22644034028053, 78.21389347314835, 74.5287524163723, 67.38045439124107, 66.30924627184868, 68.47834467887878, 70.28950989246368, 73.56221348047256, 74.76689323782921, 73.24017316102982, 76.49157509207726, 73.44561293721199, 72.70704656839371, 69.20300379395485, 72.81401082873344, 72.65299826860428, 70.01976236701012, 70.95914036035538, 66.60257533192635, 70.41339084506035, 73.65097671747208, 68.48539710044861, 69.24105495214462, 73.12232628464699, 63.62477771937847, 64.88667100667953, 71.98920428752899, 70.45781046152115, 70.54208993911743, 69.72595453262329, 70.63721403479576, 56.17317236959934, 57.52362750470638, 71.30106881260872, 63.616805747151375, 65.87853938341141, 65.09851723909378, 53.53286124765873, 51.89074516296387, 49.787653014063835, 47.60728061199188, 47.67597332596779, 49.34756822884083, 52.93974727392197, 57.74563819169998, 61.61041460931301, 64.4679182767868, 63.96627679467201, 62.43479177355766, 63.84928107261658, 59.15419980883598, 52.85416826605797, 47.140236273407936, 47.371370270848274, 50.18589824438095, 48.69534842669964, 50.213993936777115, 50.671212002635, 54.01040822267532, 57.19599008560181, 64.81996938586235, 64.02876824140549, 63.19632031023502, 54.22860391438007, 53.41681927442551, 56.962811797857285, 61.478668078780174, 64.99701708555222, 61.118758991360664, 63.614267483353615, 60.38671687245369, 62.376103922724724, 62.66812965273857, 63.197684437036514, 61.803505048155785, 62.832957208156586, 60.56905008852482, 59.86877426505089, 61.55986592173576, 60.20717650651932, 64.18154284358025, 57.51842178404331, 60.15163868665695, 61.92241966724396, 60.777286514639854, 61.39870896935463, 59.47048343718052, 56.29445046186447, 52.35232159495354, 52.73704335093498, 58.834861144423485, 60.372589230537415, 59.37516175210476, 61.553539261221886, 61.5267127007246, 62.13230520486832, 64.33756247162819, 66.2454628944397, 65.35017773509026, 64.22784715890884, 65.9461073577404, 68.09705033898354, 70.11117026209831, 66.75674825906754, 70.32745465636253, 52.230800315737724, 32.816593274474144, 9.299264755100012, 0.07845256448490545, 1.266074012964964, 0.3444405033951625, 0.32756667758803815, 0.15061044017784297, 0.3822465747362003, 0.20494454103754833, 0.32500629778951406, 0.13551879295846447, 0.7039094972424209, 0.43796194600872695, 8.672980461269617, 51.41303099691868, 46.987309679389, 51.13644003868103, 29.889006167650223, 62.86383055150509, 7.606101259589195, 0.24885468796128407, 0.06282625923631713, 0.1267974148504436, 0.08180880118743517, 3.877455862239003, 11.813118662685156, 18.11985209584236, 18.426013067364693, 19.486348070204258, 28.948955610394478, 14.138060007244349, 2.046864191070199, 0.4054159205406904, 4.6270758379250765, 3.9340336387977004, 2.1128654619678855, 12.083350662142038, 5.357342977076769, 36.79665170609951, 87.9890513420105, 62.843615636229515, 37.186845168471336, 41.032447814941406, 82.10740014910698, 24.76631484925747, 0.5168268328998238, 0.26392208179458976, 1.9782668282277882, 1.2242687749676406, 0.6684915977530181, 0.14198180084349588, 0.7338936883024871, 0.20296379341743886, 1.9931189250200987, 21.832526475191116, 35.575515031814575, 77.83468902111053, 88.34670335054398, 83.39838087558746, 93.34011420607567, 92.58659183979034, 90.87071791291237, 87.0272545516491, 88.932586312294, 86.60683751106262, 88.40810045599937, 87.22485154867172, 83.95293071866035, 84.82695981860161, 85.27095079421997, 82.70985782146454, 81.1930400133133, 81.23413860797882, 69.566211104393, 68.86327162384987, 68.7974439561367, 77.37978503108025, 78.34036588668823, 77.41512313485146, 77.72385656833649, 79.02138814330101, 77.07470700144768, 75.92576265335083, 74.40979599952698, 75.03353253006935, 73.27858909964561, 76.19138360023499, 72.74538651108742, 68.28778490424156, 73.9094540476799, 78.81362289190292, 70.65916165709496, 70.85546672344208, 76.68717339634895, 68.1093692779541, 69.0658387541771, 73.05329158902168, 72.69136860966682, 73.78815695643425, 72.14222967624664, 75.4548691213131, 60.432770401239395, 58.405089005827904, 73.22048261761665, 68.87568935751915, 68.62918138504028, 68.32452893257141, 56.74743935465813, 53.6680655926466, 53.32204096019268, 51.774961575865746, 50.726594030857086, 52.36711420118809, 55.4276941716671, 61.4272416383028, 66.72334045171738, 70.73302209377289, 68.91044229269028, 65.93771740794182, 65.21852999925613, 61.68061584234238, 55.31125321984291, 49.41830903291702, 49.82262633740902, 54.17550936341286, 51.98028355836868, 52.84212291240692, 53.1701935082674, 58.37161660194397, 61.340420097112656, 70.10802403092384, 66.41710728406906, 63.90024393796921, 56.116585806012154, 56.66056841611862, 58.73054914176464, 68.88342574238777, 67.956473082304, 64.26085218787193, 66.83559402823448, 63.826041519641876, 65.8297424018383, 65.3425857424736, 66.11656621098518, 62.361090928316116, 64.93649393320084, 62.6283647865057, 65.15457183122635, 64.44809094071388, 64.5433822274208, 67.66929969191551, 58.773213252425194, 62.8458309173584, 66.09919354319572, 63.040802255272865, 65.4755862057209, 62.83144488930702, 63.285794109106064, 59.35196399688721, 61.6194923222065, 67.06613525748253, 65.71755722165108, 62.897451147437096, 65.0451985001564, 65.89658081531525, 65.99330082535744, 66.98690950870514, 70.78107431530952, 70.0456465780735, 67.32227191329002, 67.86470040678978, 70.09533271193504, 74.33722749352455, 72.74341061711311, 74.06722158193588, 63.25509935617447, 40.357220247387886, 10.86259301751852, 0.5068320035934448, 2.0902951480820775, 0.9846617071889341, 1.2173195416107774, 0.2563159290002659, 0.4769870691234246, 0.4954922542674467, 0.6969728507101536, 0.26303058431949466, 0.8615411294158548, 0.5512769124470651, 9.427146892994642, 60.402011051774025, 61.336080729961395, 59.47263032197952, 35.08827097713947, 77.47042536735535, 10.333378314971924, 0.3547305887332186, 0.1641302483039908, 0.23034994810586795, 0.7034884917084128, 8.434506207704544, 21.40093043446541, 27.66073163598776, 32.70141005516052, 31.209824793040752], [19.013571739196777, 24.533605836331844, 8.06604377925396, 4.103913260623813, 10.633064433932304, 3.070505987852812, 3.0579699855297804, 7.232705745846033, 6.459492836147547, 39.26868125796318, 49.811937510967255, 25.641081109642982, 16.38193555176258, 47.06270143389702, 56.894073486328125, 4.678781563416123, 0.08715715521248057, 0.037679546294384636, 0.12167333785328083, 0.9099570626858622, 0.2664385561365634, 0.10592936509056017, 0.08157865377143025, 0.024085705226752907, 0.25647937960457057, 0.7646071433555335, 28.90140686184168, 75.25249198079109, 63.22939373552799, 85.82100167870522, 79.32309195399284, 81.05968996882439, 75.61834394931793, 83.51450264453888, 79.33766797184944, 81.65794506669044, 73.12813237309456, 77.77718290686607, 74.07561153173447, 78.40272054076195, 79.17464911937714, 74.52348589897156, 73.15546050667763, 71.59717932343483, 62.04486809670925, 59.92885664105415, 61.912650391459465, 65.93634188175201, 65.9019385278225, 70.17167821526527, 67.69808694720268, 70.52793189883232, 67.81640499830246, 67.65894904732704, 67.18075230717659, 66.10562279820442, 69.5401369035244, 69.51011091470718, 62.756338119506836, 65.24518936872482, 66.2382584810257, 69.4487290084362, 68.07362839579582, 72.04713597893715, 64.00998964905739, 61.82466231286526, 67.14795246720314, 68.0716373026371, 66.58353075385094, 68.71356725692749, 66.14677459001541, 58.948387652635574, 50.35528555512428, 66.38716489076614, 63.171161860227585, 62.69858881831169, 62.25581757724285, 53.369268625974655, 50.21719716489315, 47.687984481453896, 46.61541983485222, 46.254762187600136, 45.90069718658924, 49.34121496975422, 53.802684769034386, 53.905062675476074, 56.561192348599434, 59.10551302134991, 60.11323794722557, 60.67968875169754, 55.92097230255604, 51.23045839369297, 47.629904597997665, 46.71997122466564, 47.44499132037163, 46.1814109236002, 44.15866166353226, 43.81100311875343, 46.52412973344326, 50.43992221355438, 52.573241740465164, 55.93527093529701, 62.166123390197754, 64.56022292375565, 58.44812169671059, 51.02127201855183, 56.92093804478645, 54.57457534968853, 57.447532787919044, 62.122706919908524, 56.65276363492012, 61.82529307901859, 59.335583075881004, 61.01038500666618, 60.1955871284008, 61.52244172990322, 61.97351552546024, 60.45062184333801, 54.24343451857567, 57.753933146595955, 57.97831870615482, 61.31004452705383, 57.08540841937065, 56.44206494092941, 56.830084919929504, 56.72230750322342, 51.13354079425335, 51.51102393865585, 47.48108558356762, 48.16859029233456, 46.509641110897064, 55.467899814248085, 56.89582139253616, 53.21196086704731, 53.15360739827156, 55.37705808877945, 59.190499261021614, 59.86884266138077, 61.16920508444309, 59.22078363597393, 61.367843225598335, 61.491651982069016, 63.211610689759254, 62.9390437155962, 69.5375606417656, 60.467500537633896, 53.00079479813576, 35.87171673774719, 8.162807486951351, 0.5807164858561009, 0.5071798630524427, 0.09354122084914707, 0.11750939214834943, 0.07498550286982208, 0.11940436233999208, 0.11807941351435147, 0.08584410301409662, 0.05636838330246974, 0.3627067169873044, 0.20499994978308678, 4.2712197080254555, 53.76389645040035, 35.50749868154526, 45.14867193996906, 17.62414399534464, 56.575008407235146, 34.00862731039524, 0.18337863497436047, 0.041066452249651775, 0.15897162433248013, 2.583138202317059, 22.998047433793545, 25.947546064853668, 21.480914242565632, 22.3432494699955, 13.097901921719313, 34.95535410940647, 27.88700569421053, 9.296177420765162, 2.1155683044344187, 4.722256930544972, 1.945607343222946, 1.5244641853496432, 10.566126275807619, 3.6458848882466555, 58.62219035625458, 58.72125864028931, 42.7762084454298, 21.289868094027042, 33.09826835989952, 68.83677944540977, 6.739050010219216, 0.06011227713315748, 0.12481457437388599, 0.12077663050149567, 1.5722507773898542, 0.08516384303220548, 0.06952256124350242, 0.11376000271411613, 0.17496793472673744, 0.243819824536331, 1.2562051112763584, 28.965950198471546, 80.58488264679909, 71.54778957366943, 88.02714809775352, 82.5867748260498, 83.62245485186577, 81.64411380887032, 83.49075391888618, 83.04626896977425, 84.94216963648796, 76.71862810850143, 78.95952746272087, 76.11650481820107, 81.90115481615067, 79.4160957634449, 79.04549404978752, 75.8571307361126, 74.42131698131561, 65.02021104097366, 62.49978728592396, 65.23901090025902, 70.80920040607452, 68.96891355514526, 73.82803201675415, 71.83269828557968, 71.75618559122086, 71.11914977431297, 70.81737756729126, 68.45492273569107, 68.84839162230492, 73.851567953825, 69.99846071004868, 61.997579634189606, 67.84784451127052, 68.65359887480736, 70.45126721262932, 70.02396494150162, 74.29244309663773, 64.78591561317444, 66.01549163460732, 73.0449852347374, 67.92638629674911, 68.83089736104012, 70.4763762652874, 68.39579030871391, 58.03663417696953, 54.914440512657166, 71.54804795980453, 64.14013266563416, 67.47410416603088, 65.56729808449745, 56.58709175884724, 54.320137202739716, 50.357105657458305, 49.523665979504585, 50.62314838171005, 48.829032853245735, 51.672838255763054, 56.650597751140594, 54.64587852358818, 57.28245444595814, 59.18132275342941, 63.5074058175087, 61.924809738993645, 56.38793684542179, 53.61790828406811, 48.46109479665756, 50.52796348929405, 49.13162961602211, 48.015591502189636, 47.68473945558071, 48.53149741888046, 51.09321355819702, 53.07335950434208, 55.65038502216339, 58.94509702920914, 61.0060266405344, 65.7857483625412, 63.69168072938919, 55.276595279574394, 58.70619624853134, 57.93788127601147, 58.40709529817104, 62.050111815333366, 62.025732323527336, 63.134881407022476, 61.81006349623203, 63.928848803043365, 61.585962921381, 64.10553932189941, 64.85674381256104, 62.60462746024132, 59.1517299413681, 59.51047249138355, 61.06340356171131, 61.89464695751667, 59.88667890429497, 59.644426703453064, 59.825046211481094, 59.199117198586464, 56.88423961400986, 58.39544132351875, 53.67883421480656, 54.031641483306885, 55.109525844454765, 59.612261429429054, 60.156734213232994, 58.78512181341648, 58.84005926549435, 59.77747656404972, 62.13853307068348, 62.06340350210667, 62.81174294650555, 60.65683297812939, 64.1841647028923, 64.50020134449005, 67.15412333607674, 66.67395830154419, 75.20599767565727, 64.00840893387794, 57.7385363727808, 34.91497367620468, 8.082594741135836, 0.708632703172043, 0.2783545386046171, 0.16665138333337381, 0.11224012880120426, 0.03227379827876575, 0.060184206085978076, 0.1731012700474821, 0.18532524380134419, 0.08150679903337732, 0.33314611413516104, 0.18623728392412886, 5.04159084521234, 61.02434165775776, 40.56718558073044, 54.80931155383587, 27.842831164598465, 65.44612258672714, 38.411063477396965, 0.2413483540294692, 0.05491327290656045, 0.0841402135847602, 2.698039524257183, 27.552114464342594, 35.12183837592602, 32.95697674155235, 28.61153371632099, 33.214766308665276, 49.00083303451538, 41.61680705845356, 19.086778610944748, 5.872421013191342, 17.383263520896435, 9.84309347346425, 8.907919954508543, 14.907817002385855, 11.786760427057743, 61.217656284570694, 80.64288273453712, 49.64852347970009, 27.03967586159706, 61.31360113620758, 79.79102924466133, 10.06396897137165, 0.2088036050554365, 0.34486100426875055, 0.5729898379649967, 3.32939678337425, 0.4394764022435993, 0.2225226056179963, 0.14812351815635338, 0.3933883784338832, 0.41939302522223443, 1.6742972703650594, 34.12657678127289, 85.74781760573387, 78.96742343902588, 94.97814550995827, 88.22286799550056, 88.63567024469376, 86.55195325613022, 90.29614314436913, 87.33739390969276, 89.70446169376373, 79.75285649299622, 83.01204040646553, 78.43032225966454, 89.45720136165619, 84.047811627388, 81.63117170333862, 78.28866586089134, 77.88531750440598, 65.7813785970211, 65.39465054869652, 67.80276373028755, 75.86539149284363, 72.42016956210136, 77.67209574580193, 74.6061922609806, 76.79361328482628, 73.02325040102005, 73.82689207792282, 72.14893251657486, 73.37366759777069, 74.5305535197258, 72.16986179351807, 66.21077835559845, 72.16424569487572, 71.26411199569702, 72.49341443181038, 73.36726114153862, 79.4417291879654, 68.3014565706253, 67.52263516187668, 75.17064437270164, 73.74825909733772, 74.18922543525696, 75.29788434505463, 73.38698968291283, 64.73461076617241, 55.628323405981064, 72.06966876983643, 69.51554462313652, 68.33045661449432, 67.8346136212349, 59.47293810546398, 56.34065218269825, 53.65541987121105, 50.59303879737854, 52.90186710655689, 51.86452277004719, 55.46792261302471, 60.40798433125019, 58.85910764336586, 61.93223834037781, 62.62062840163708, 66.84290483593941, 65.00535383820534, 61.46032266318798, 57.23741166293621, 51.184971034526825, 54.16622266173363, 52.73531824350357, 50.5253454297781, 50.407141372561455, 50.95713146030903, 53.00850838422775, 53.96486386656761, 57.86690108478069, 61.878117844462395, 66.3477686047554, 68.46241593360901, 63.90060871839523, 57.81604461371899, 62.203760370612144, 61.30355067551136, 63.68743255734444, 67.37796172499657, 62.975510358810425, 65.27210712432861, 62.42027275264263, 65.1557345688343, 65.26611864566803, 67.4053430557251, 67.1098405122757, 65.92230543494225, 62.14023157954216, 63.36947321891785, 63.163444474339485, 65.24270430207253, 60.44519193470478, 62.278939336538315, 62.80376337468624, 64.88148808479309, 61.701605916023254, 62.398013547062874, 60.913889184594154, 59.42631080746651, 60.159340873360634, 67.48556435108185, 64.85766336321831, 62.646653205156326, 61.857450753450394, 62.46720403432846, 67.50010997056961, 66.14703297615051, 66.06194034218788, 66.13905340433121, 67.87262678146362, 68.85191023349762, 71.46357089281082, 71.3901436328888, 80.30312016606331, 67.73615330457687, 64.7416403889656, 38.25736552476883, 10.166593864560127, 1.334301964379847, 1.2862667231820524, 0.17288051079958677, 0.13944948907010257, 0.13898018456529826, 0.13663787744008005, 0.3548620082437992, 0.3884934989036992, 0.2681359072448686, 0.43755118211265653, 0.3400237747700885, 6.168405655771494, 69.15676027536392, 49.075544625520706, 56.12745702266693, 30.671203695237637, 77.26193815469742, 48.36944751441479, 0.3261619701515883, 0.13089081941870973, 0.23542092443676665, 6.542373988777399, 36.67256556451321, 48.9891866594553, 47.06528149545193, 45.163278356194496, 47.37520806491375], [6.6463288106024265, 11.825190614908934, 12.500851359218359, 6.0193016566336155, 7.2361459862440825, 8.377119787037373, 10.319816842675209, 14.325143918395042, 5.794401224702597, 27.288608103990555, 32.99278981983662, 24.261910915374756, 42.20610983669758, 59.92682375013828, 32.54072047770023, 1.395256631076336, 0.1841575634898618, 0.06883517664391547, 0.1920628166408278, 0.10337434359826148, 0.19255619641626254, 0.13570179173257202, 0.03680325913592242, 0.34650405985303223, 0.09114043990848586, 1.4915146096609533, 45.82860745489597, 61.034498512744904, 81.59889623522758, 77.65605300664902, 81.98082894086838, 77.98150554299355, 76.89246878027916, 78.91749411821365, 81.72480627894402, 77.01973155140877, 72.50517100095749, 68.69280517101288, 72.62021362781525, 76.84418097138405, 73.70075404644012, 74.29349184036255, 73.46076652407646, 72.56854400038719, 62.896011024713516, 59.45142365992069, 61.98918208479881, 63.89181599020958, 64.393480271101, 63.59184488654137, 63.36906664073467, 65.65055921673775, 67.83845901489258, 67.40041092038155, 69.50577154755592, 65.12761607766151, 64.74536418914795, 64.92894753813744, 62.91079223155975, 64.08559799194336, 66.74590364098549, 69.60246115922928, 69.7388206422329, 63.20039749145508, 60.76610371470451, 72.2298301756382, 67.35431179404259, 62.98789769411087, 66.8687130510807, 67.20180317759514, 59.026576057076454, 50.63513673841953, 65.20754098892212, 65.12587577104568, 62.821139842271805, 67.48837620019913, 56.590169593691826, 55.241222977638245, 50.985838919878006, 45.30291706323624, 47.91023835539818, 45.97687549889088, 48.35953004658222, 48.574039936065674, 47.52882622182369, 46.68569326400757, 54.542877450585365, 59.00004208087921, 58.94207999110222, 61.13551989197731, 59.35376510024071, 52.849714905023575, 47.38744720816612, 46.05086512863636, 47.15794712305069, 46.183234825730324, 44.53521005809307, 45.486895591020584, 45.24061180651188, 50.30334994196892, 57.15103089809418, 57.67699867486954, 54.49878841638565, 58.647329807281494, 64.19913589954376, 55.57168744504452, 51.663483157753944, 60.08037731051445, 52.06692650914192, 55.16724854707718, 60.46428970992565, 61.170930191874504, 59.74137470126152, 59.293325543403625, 60.493730530142784, 58.73101271688938, 57.24177002906799, 59.31852199137211, 56.5504465252161, 55.654443204402924, 57.05159403383732, 59.469605684280396, 54.22114111483097, 54.977243542671204, 54.50424112379551, 51.842301562428474, 50.75611464679241, 52.761441841721535, 48.537930473685265, 50.3871164470911, 52.95977599918842, 52.653763219714165, 57.288283333182335, 53.448821157217026, 53.940100595355034, 51.77306927740574, 51.39592431485653, 52.9477496445179, 54.423134475946426, 56.76737308502197, 62.85642854869366, 61.04988768696785, 65.71947231888771, 57.64227993786335, 63.95319029688835, 55.07308579981327, 45.40152557194233, 16.16447512060404, 5.571636278182268, 0.7986400171648711, 0.5528741329908371, 0.08204608806408942, 0.16205112158786505, 0.14302402851171792, 0.04877299907093402, 0.12528132589068264, 0.13651992048835382, 0.16889522230485454, 0.05864686943823472, 0.07000540252192877, 3.4914376633241773, 67.3301374912262, 28.71779501438141, 29.96696088463068, 18.694434463977814, 36.45713232457638, 52.41607077419758, 1.3902158453129232, 0.09371581851155497, 0.45767163683194667, 12.993200439959764, 30.152143947780132, 46.07643015682697, 53.842404037714005, 41.809958294034004, 21.001383773982525, 32.80208945274353, 29.89262167364359, 26.13130610436201, 4.060259778052568, 14.307964090257883, 6.48032046854496, 7.887827642261982, 17.192270569503307, 6.936836522072554, 37.420456632971764, 46.54579997062683, 44.76332701742649, 31.462847515940666, 59.17879968881607, 45.783272087574005, 2.395796380005777, 0.1423366364906542, 0.2570341498358175, 0.04313525940233376, 0.9043167997151613, 0.22624821664066985, 0.14253830770030618, 0.2865962072974071, 0.21540469693718478, 0.06189100844494533, 1.236158455722034, 48.53832185268402, 70.78093752264977, 84.61593434214592, 83.90642881393433, 85.36685764789581, 79.80999022722244, 80.38765043020248, 80.65507248044014, 82.89259761571884, 77.57021561264992, 76.09980091452599, 70.4364176094532, 76.26381531357765, 78.53649616241455, 78.71183395385742, 77.2572036087513, 77.057835906744, 74.50496569275856, 67.85467654466629, 63.68718557059765, 64.6229575574398, 66.0524408519268, 68.28439548611641, 68.28497305512428, 67.2877849638462, 67.63320922851562, 67.89726465940475, 70.19848197698593, 71.40050187706947, 68.90148997306824, 67.02518865466118, 65.75788825750351, 67.13440239429474, 68.61198350787163, 70.21574065089226, 72.24128276109695, 70.5260244011879, 66.14152327179909, 63.988026827573776, 73.71472969651222, 67.59264260530472, 65.52166253328323, 71.05646073818207, 67.61430144309998, 60.68939343094826, 55.063647106289864, 67.03465014696121, 66.7562846839428, 65.37180617451668, 67.3670183122158, 58.8516790419817, 58.39211270213127, 52.66814164817333, 48.25715593993664, 50.33808007836342, 52.12859719991684, 52.00924940407276, 51.840553656220436, 48.98198984563351, 50.25785878300667, 57.407186552882195, 62.065880969166756, 61.11410044133663, 63.898853212594986, 61.15848205983639, 55.374823808670044, 50.43964862823486, 50.19539773464203, 49.36756655573845, 48.992587476968765, 45.86510829627514, 49.33722898364067, 48.848240822553635, 50.210691913962364, 56.0850664973259, 63.166909888386726, 59.65945489704609, 60.356861874461174, 64.33866441249847, 61.66167385876179, 52.08512373268604, 64.06317919492722, 55.48349417746067, 56.63050062954426, 59.15050260722637, 63.67933139204979, 61.25021293759346, 59.747716560959816, 61.161438301205635, 62.831585481762886, 59.12213712930679, 61.64664186537266, 61.115156784653664, 58.1396846473217, 59.278525337576866, 60.604171603918076, 55.616730228066444, 56.27951346337795, 58.84776905179024, 55.65643049776554, 56.17224521934986, 57.19254367053509, 52.684324979782104, 57.72766895592213, 58.500042110681534, 56.84038616716862, 60.99756069481373, 56.752401888370514, 58.52621130645275, 55.244566798210144, 55.06929360330105, 54.63751517236233, 57.0769614726305, 59.223549887537956, 65.35468429327011, 64.33724328875542, 70.6185494363308, 63.66768501698971, 64.8025207221508, 62.13673196732998, 49.134198278188705, 23.081460557878017, 8.934409283101559, 1.2897689477540553, 0.26417708373628557, 0.06075430166674778, 0.06505570054287091, 0.21049307455541566, 0.0771726862876676, 0.18442161963321269, 0.16071682912297547, 0.2860840957146138, 0.3000786853954196, 0.3125567111419514, 4.50077299028635, 73.59496772289276, 36.12292505800724, 35.067615285515785, 24.968975074589252, 45.34271612763405, 63.64593878388405, 1.1812322842888534, 0.12850399827584624, 0.5188113951589912, 15.03188794478774, 42.29490727186203, 54.80088360607624, 56.670964658260345, 54.07501995563507, 38.20189230144024, 46.917579621076584, 35.9150306135416, 47.6799251139164, 29.032370634377003, 18.10231603682041, 18.24648790061474, 21.178572066128254, 27.706298790872097, 11.657654754817486, 50.62654919922352, 67.75325238704681, 42.58693300187588, 61.65784366428852, 79.32457387447357, 51.859005466103554, 5.346265146508813, 0.29170078807510436, 0.7808616617694497, 0.2823173993965611, 1.8649963312782347, 0.6499472272116691, 0.3548403375316411, 0.4933399963192642, 0.8938751381356269, 0.08510484971338883, 2.5083183171227574, 57.55736209452152, 78.29762578010559, 94.64808002114296, 90.54579734802246, 92.93156772851944, 87.94533088803291, 87.85757079720497, 85.44102966785431, 88.68803903460503, 84.65425908565521, 80.28147652745247, 73.28051179647446, 79.73707973957062, 81.42561793327332, 79.99098211526871, 79.39107790589333, 78.82247641682625, 77.0680421590805, 71.9170917570591, 65.16973301768303, 68.48591387271881, 69.72533136606216, 70.0483900308609, 70.93067228794098, 71.24626815319061, 72.14574068784714, 72.86023914813995, 72.72869020700455, 76.4327922463417, 72.7580626308918, 71.19258463382721, 68.88617679476738, 68.94295334815979, 71.28650799393654, 74.06881749629974, 73.7781710922718, 74.34964522719383, 70.57771682739258, 65.73090970516205, 76.76702231168747, 72.1398738026619, 67.4099788069725, 74.81367632746696, 71.17556914687157, 66.16272613406181, 58.0059090256691, 70.89567616581917, 69.13774609565735, 69.67703595757484, 71.91792771220207, 64.03689980506897, 60.69470934569836, 56.40999086201191, 49.67531584203243, 54.12801191210747, 53.4019772708416, 54.84742350876331, 52.69165098667145, 51.97839505970478, 50.013607889413834, 57.63588488101959, 65.56464582681656, 65.2619768679142, 68.08682888746262, 63.27885188162327, 57.48553454875946, 51.294587552547455, 49.81084696948528, 52.25968636572361, 52.284977808594704, 49.41029906272888, 52.105414643883705, 51.24090023338795, 54.61251251399517, 61.055990159511566, 62.924281507730484, 57.20499940216541, 63.845086097717285, 67.68262937664986, 61.55529856681824, 57.136690467596054, 65.16334176063538, 56.80782571434975, 59.900388568639755, 63.06919053196907, 66.37856975197792, 63.157569989562035, 63.335480242967606, 64.33752447366714, 63.88339564204216, 61.65989175438881, 65.40187016129494, 65.17036378383636, 61.03522427380085, 63.038127198815346, 63.486172556877136, 58.61872114241123, 58.83842535316944, 62.38803528249264, 60.56317180395126, 60.84366515278816, 61.87808744609356, 58.10647442936897, 63.38376425206661, 64.2058615386486, 65.61264485120773, 69.63937237858772, 60.421545803546906, 61.48256666958332, 59.45662558078766, 60.33109165728092, 60.74799008667469, 61.77911415696144, 62.24961631000042, 69.9991674721241, 70.11401250958443, 73.76525178551674, 68.60765933990479, 70.84424212574959, 65.60346454381943, 53.86766128242016, 31.04585599154234, 10.229733176529408, 1.4320724993012846, 0.5651050829328597, 0.2060079199145548, 0.301710786879994, 0.4022047662874684, 0.26822003710549325, 0.32732349063735455, 0.5236363643780351, 0.5050605861470103, 0.4958413902204484, 0.58682287693955, 4.769902573898435, 84.17999133467674, 40.95748923718929, 40.31638003885746, 32.855484187603, 53.18111792206764, 74.657291918993, 1.9517900864593685, 0.2662386215524748, 0.9924093727022409, 23.339453414082527, 54.642477706074715, 73.33513006567955, 86.95562079548836, 93.110241740942, 59.4847896695137], [7.875158172100782, 2.9345331341028214, 21.155769489705563, 21.523924134671688, 33.78109931945801, 32.113308012485504, 38.69092606008053, 18.850347697734833, 5.326521880924702, 21.574146039783955, 13.971860725432634, 16.329673156142235, 45.979197174310684, 62.22375489771366, 41.75720952451229, 1.021582663524896, 0.09226578811649233, 0.09617252770112827, 0.09966637342586182, 0.060958496178500354, 0.5961061350535601, 0.08233706932514906, 0.008976497865660349, 0.36929161520674825, 0.08460959972580895, 4.38307193107903, 56.754100397229195, 69.84032079577446, 79.47924837470055, 76.46024197340012, 77.46933862566948, 77.63238787651062, 76.49282902479172, 81.0717961192131, 80.69133773446083, 75.68744704127312, 70.72066515684128, 68.20230469107628, 69.84784439206123, 75.70752516388893, 75.04963606595993, 76.16667732596397, 74.73075717687607, 72.27709963917732, 69.80170726776123, 57.65966780483723, 59.0819276869297, 62.98320114612579, 66.7954757809639, 66.48939460515976, 65.93519434332848, 65.03177002072334, 65.44494464993477, 67.62604281306267, 65.83301022648811, 67.72164568305016, 62.519105449318886, 65.30041560530663, 67.0847998559475, 62.74971887469292, 65.984006524086, 64.50106009840965, 65.14293685555458, 63.524630293250084, 70.19364103674889, 62.42800913751125, 62.828359454870224, 66.20984360575676, 64.09709617495537, 59.50049802660942, 54.62532922625542, 60.27517385780811, 64.13042038679123, 65.46826019883156, 65.61461314558983, 56.195401176810265, 62.75391384959221, 54.964803010225296, 48.62682290375233, 45.55648885667324, 45.648143738508224, 49.433025643229485, 50.93353092670441, 52.131363451480865, 50.0989855080843, 55.38100987672806, 60.95176935195923, 65.52032500505447, 64.2631396651268, 64.10830557346344, 63.820569813251495, 58.8758647441864, 56.686802208423615, 53.236043974757195, 50.043785870075226, 45.78347347676754, 44.3507831543684, 43.815239891409874, 47.138032391667366, 48.14921133220196, 49.862265810370445, 57.74210438132286, 61.8491367995739, 62.43970490992069, 58.56099843978882, 64.90134581923485, 53.73736247420311, 54.792733043432236, 61.93732626736164, 54.68356490135193, 54.00272123515606, 58.27078141272068, 59.19371768832207, 53.720069602131844, 53.39327573776245, 53.718063309788704, 52.16278776526451, 54.15432929992676, 60.5577988922596, 57.85276584327221, 57.069760859012604, 58.867995366454124, 58.66784870624542, 53.36155503988266, 55.83020657300949, 49.84033338725567, 50.784141942858696, 50.024859085679054, 46.207880303263664, 49.30853292346001, 51.96566194295883, 49.36315879225731, 56.64465866982937, 56.24025397002697, 55.53329050540924, 49.89790789783001, 50.21820791065693, 50.85808977484703, 55.33686384558678, 56.83240659534931, 59.529862850904465, 62.564459815621376, 58.416435196995735, 63.12942869961262, 63.26753988862038, 45.4333982616663, 14.311279412359, 8.435136023908854, 3.48357992246747, 0.4529424640350044, 0.03313205124868546, 0.21306782233295962, 0.010353683683206327, 0.12229976986418478, 0.017550618103996385, 0.09147381264483556, 0.17012646014336497, 0.17628912086365744, 0.12707923800917342, 0.12689905939623713, 3.6197213921695948, 68.76261502504349, 34.737625792622566, 31.169866137206554, 56.331859454512596, 44.93628993630409, 50.81392094492912, 6.4253131952136755, 0.8643121900968254, 3.383993203751743, 24.145511761307716, 29.971526339650154, 38.77045959234238, 47.544564977288246, 33.48775126039982, 17.136917039752007, 30.038370452821255, 20.917782559990883, 32.74629324674606, 30.56885428726673, 17.026690654456615, 16.655720360577106, 19.363855943083763, 32.740395963191986, 11.667332835495472, 23.248845376074314, 37.582331746816635, 30.903990603983402, 40.586921721696854, 71.05956897139549, 48.006654381752014, 1.6872842609882355, 0.054588616694672965, 0.1695687955361791, 0.08001177964615636, 0.1667362850275822, 0.7591283123474568, 0.07740121582173742, 0.0794906064402312, 0.08158634984283708, 0.28551486844662577, 3.9234488317742944, 57.981981709599495, 76.7264936864376, 86.00948676466942, 82.03524202108383, 83.02451133728027, 80.61921760439873, 79.58187326788902, 83.71925845742226, 81.84583738446236, 78.09947401285172, 73.30337136983871, 69.42961603403091, 72.53376066684723, 78.57383295893669, 77.34890788793564, 78.96223291754723, 77.11936220526695, 76.4784961938858, 72.83744797110558, 60.544651597738266, 62.232923805713654, 65.95918625593185, 71.34089827537537, 71.86376541852951, 67.15858429670334, 70.11859506368637, 67.0789785683155, 68.88983219861984, 69.00451764464378, 67.48774543404579, 65.40394484996796, 70.14877304434776, 66.39919504523277, 65.09368389844894, 67.58220836520195, 66.49548947811127, 69.24203529953957, 67.13956251740456, 73.18353340029716, 66.0219056904316, 64.08732309937477, 70.41466757655144, 65.2287894487381, 62.192896753549576, 57.07095019519329, 62.63875722885132, 68.76054793596268, 68.24293211102486, 68.33700746297836, 60.391857996582985, 65.06656855344772, 56.58252440392971, 51.356148049235344, 48.44857066869736, 50.59295520186424, 53.059953823685646, 54.940157532691956, 53.47826197743416, 54.035380482673645, 60.9454844892025, 65.78564196825027, 68.04304763674736, 65.62517657876015, 66.93669900298119, 65.06181880831718, 60.28105974197388, 60.32646730542183, 55.30271127820015, 54.38485153019428, 50.352561101317406, 46.92378468811512, 47.28817753493786, 49.660439640283585, 50.81583224236965, 50.48993892967701, 58.86707581579685, 63.012641966342926, 64.86459419131279, 60.97791574895382, 66.09277948737144, 57.42944575846195, 57.01068162918091, 63.89583617448807, 57.60843135416508, 55.837885960936546, 59.25829902291298, 60.70612013339996, 57.11524821817875, 54.283537566661835, 56.27808474004269, 53.033834025263786, 55.32949984073639, 62.208741903305054, 61.16479732096195, 58.285045847296715, 59.74686920642853, 60.74822187423706, 56.108484640717506, 59.07045990228653, 54.29904453456402, 56.953525096178055, 53.41404162347317, 51.53741352260113, 58.68852339684963, 55.17659604549408, 55.08085638284683, 57.13632948696613, 58.981924653053284, 56.027001813054085, 54.852382242679596, 53.204805850982666, 53.88515554368496, 57.68199160695076, 61.213370114564896, 64.52549278736115, 65.63073948025703, 64.8584309220314, 62.34676569700241, 72.7443453669548, 48.29271823167801, 26.344180181622505, 11.209134422242641, 5.524868862703443, 0.6221156206447631, 0.06687641143798828, 0.07727779666311108, 0.04532479171757586, 0.08046860122703947, 0.03995396546088159, 0.05523511266801506, 0.13354104361496866, 0.26658220624085516, 0.2903772419085726, 0.1795078004943207, 5.134687749668956, 75.15695750713348, 42.3463337123394, 32.156846076250076, 56.612250208854675, 50.73570594191551, 62.35689215362072, 7.56757085211575, 0.913452043896541, 2.762175570242107, 34.77552115917206, 43.84491629898548, 71.8709546327591, 82.35650718212128, 71.84338331222534, 46.374041587114334, 51.595884785056114, 35.73534585535526, 73.57640951871872, 97.57595211267471, 61.82633802294731, 61.004400327801704, 64.12600502371788, 47.01602853834629, 9.461770635098219, 46.701922193169594, 52.0693089812994, 33.2827028632164, 64.21862125396729, 79.1542138159275, 65.42176589369774, 2.550125573761761, 0.260182844940573, 0.5452347616665065, 0.20919204514939338, 0.41206583089660853, 1.870021561626345, 0.24924655677750707, 0.3631250804755837, 0.7468552084174007, 0.5993366148322821, 5.562822176143527, 65.82589700818062, 87.99212917685509, 96.28757804632187, 94.09839391708374, 91.15067929029465, 89.15507957339287, 84.46816027164459, 89.78110358119011, 87.24565163254738, 83.77052530646324, 76.34222030639648, 74.37580302357674, 77.90784269571304, 83.83826807141304, 82.3749665915966, 81.21125623583794, 81.42249450087547, 79.26095008850098, 76.0899518430233, 62.022061720490456, 64.1779026389122, 68.69746372103691, 74.1984361410141, 73.08552145957947, 69.07238960266113, 71.77505537867546, 71.15804448723793, 72.39339619874954, 71.57894030213356, 71.96223333477974, 69.78327825665474, 73.33849668502808, 71.50894045829773, 70.50865933299065, 71.01598531007767, 69.60207358002663, 68.96221071481705, 67.97078311443329, 74.97568443417549, 67.79915392398834, 66.33763074874878, 72.75945335626602, 69.28941875696182, 67.19442397356033, 59.772814214229584, 65.7565051317215, 72.27499455213547, 72.28241935372353, 71.45917072892189, 62.76040390133858, 67.99187198281288, 60.75290322303772, 55.896315425634384, 50.43150186538696, 52.26033993065357, 56.276393830776215, 57.75157727301121, 56.65801875293255, 54.98930789530277, 61.00498549640179, 66.9934755563736, 71.49780705571175, 69.17367696762085, 71.31482407450676, 67.00197950005531, 62.96817675232887, 63.893389105796814, 59.979872703552246, 55.467272847890854, 52.73160584270954, 49.2231211066246, 48.30110818147659, 51.32900230586529, 54.22599345445633, 53.673533499240875, 63.73728588223457, 67.06699401140213, 69.75512936711311, 63.1636268645525, 71.46703630685806, 58.40651772916317, 60.64527779817581, 65.53124561905861, 61.012607887387276, 58.111493960022926, 62.946320325136185, 63.45773868262768, 58.582725673913956, 57.79031239449978, 59.40944731235504, 54.58728946745396, 61.113040298223495, 67.61420264840126, 63.69536653161049, 61.747887432575226, 65.29577985405922, 62.754666209220886, 61.53667576611042, 61.895646303892136, 60.86400546133518, 62.70825169980526, 63.545494973659515, 57.94449672102928, 62.12470941245556, 60.00837877392769, 60.006095096468925, 65.44218599796295, 64.45250630378723, 62.64765255153179, 57.90497504174709, 56.263900101184845, 57.44624465703964, 61.001751869916916, 63.728660345077515, 68.87172237038612, 70.86275473237038, 69.25110161304474, 65.76382353901863, 75.03034830093384, 53.95771265029907, 42.97164335846901, 16.192768402397633, 6.8142356257885695, 0.8282160270027816, 0.13195470295613632, 0.2910040598362684, 0.2756155683891848, 0.3746651503024623, 0.14864024589769542, 0.2620966063113883, 0.27195707720238715, 0.390722494921647, 0.5055476725101471, 0.5489877727814019, 6.922722654417157, 84.10182192921638, 51.951146721839905, 43.984334617853165, 72.11088135838509, 61.089990735054016, 76.67231619358063, 10.255738031119108, 1.3714815443381667, 4.476014468818903, 46.13938517868519, 53.43821592628956, 85.26753857731819, 96.04436069726944, 84.96045425534248, 64.96187657117844], [11.755981128662825, 19.94708474725485, 35.5576977878809, 33.02039533853531, 48.94325852394104, 40.48957474529743, 29.297835789620876, 7.663500979542732, 0.2001327820471488, 14.487468358129263, 13.614827133715153, 26.977081820368767, 55.398234352469444, 66.09657168388367, 38.56584817171097, 0.8614459563978016, 0.18974909704411402, 0.06781323929317296, 0.04403308739711065, 0.050578288137330674, 0.2155705966288224, 0.34926401800476015, 0.17414502653991804, 0.3293324843980372, 0.2713000390212983, 10.801876075565815, 82.22915321588516, 74.15020912885666, 73.32807764410973, 70.31496852636337, 71.37798428535461, 74.50378015637398, 75.9177678823471, 79.97877717018127, 78.42323184013367, 71.92869633436203, 70.33795729279518, 66.02413237094879, 65.06005570292473, 72.0461556315422, 70.5468700826168, 74.22132611274719, 72.98240259289742, 71.21951758861542, 70.82566112279892, 61.41546227037907, 58.31088826060295, 62.058798149228096, 63.97836774587631, 65.59375986456871, 66.0050193965435, 69.10815328359604, 67.32455939054489, 66.26483425498009, 67.57866695523262, 66.10880702733994, 65.49450159072876, 62.90134213864803, 55.28071045875549, 59.86297957599163, 61.151019260287285, 62.74630665779114, 62.0333357155323, 68.0696614086628, 68.00470769405365, 66.1934132874012, 64.15049090981483, 63.17447908222675, 60.96646696329117, 59.590378403663635, 57.19443216919899, 64.69269901514053, 64.94107648730278, 64.58872139453888, 63.253252655267715, 62.437820211052895, 57.67705947160721, 48.68722826242447, 46.40095554292202, 49.24523591995239, 51.446077823638916, 51.664915680885315, 51.039784625172615, 52.98886723816395, 56.92636415362358, 59.78185012936592, 60.702871307730675, 60.165686532855034, 60.59343717992306, 64.02110025286674, 58.54824252426624, 58.15456844866276, 53.835887387394905, 52.31093421578407, 54.86228071153164, 55.52841156721115, 49.20265540480614, 44.61849018931389, 45.259910970926285, 49.084797129034996, 47.28948086500168, 49.29700054228306, 55.26992663741112, 58.70974525809288, 62.348741590976715, 59.30874891579151, 62.383505925536156, 51.70884132385254, 56.152972653508186, 62.01385036110878, 54.648823365569115, 56.09955511987209, 56.12705424427986, 58.61866794526577, 52.170235365629196, 54.724895283579826, 50.7028529047966, 48.5416504740715, 45.935438722372055, 59.64292198419571, 56.9807468354702, 53.12596008181572, 55.315269604325294, 54.28368955850601, 50.96415348351002, 49.58132028579712, 47.981940507888794, 46.82244412600994, 47.775322794914246, 54.538640677928925, 52.55488492548466, 53.94499473273754, 53.08903746306896, 55.44600918889046, 49.626070484519005, 53.01925800740719, 51.34751871228218, 53.97964887320995, 55.73107749223709, 57.838193625211716, 59.86109487712383, 58.779353722929955, 55.42543329298496, 47.086879536509514, 34.374087899923325, 11.267507839947939, 11.280522141605616, 3.781184940598905, 1.6401027864776552, 0.06740603770595044, 0.08400605554925278, 0.08796731330221519, 0.04815154316020198, 0.19715225760592148, 0.06851786398328841, 0.15880704566370696, 0.1792075572302565, 0.060829611102235503, 0.27875814819708467, 0.42344357818365097, 7.102708546444774, 64.17937695980072, 36.76964655518532, 28.30183893442154, 99.89253580570221, 64.174475222826, 54.05689112842083, 15.221510119736195, 1.2684016255661845, 4.32857858017087, 9.14759874343872, 17.292549088597298, 16.880157217383385, 14.12143399938941, 13.928781487047672, 10.14579663053155, 21.367948204278946, 31.086981184780598, 49.67587821185589, 63.98566335439682, 50.75648322701454, 46.177782118320465, 45.73622681200504, 28.123221918940544, 2.9197664139792323, 8.542358670383692, 29.080850332975388, 28.084984570741653, 52.325951009988785, 78.59334871172905, 46.588790863752365, 1.2470742012374103, 0.23324836132815108, 0.24709922668989748, 0.03935410233680159, 0.12452595314243808, 0.4359714762540534, 0.5863919563125819, 0.28378504095599055, 0.19611947005614638, 0.3561905713286251, 8.664294127374887, 82.62701466679573, 79.9005925655365, 80.46645060181618, 77.99637034535408, 79.16800707578659, 79.83547165989876, 79.56003963947296, 79.60387408733368, 79.55098092556, 76.28351345658302, 70.46331256628036, 66.54312372207642, 66.51401728391647, 75.24214133620262, 73.03182274103165, 74.73932951688766, 77.78095230460167, 75.30278608202934, 72.99495711922646, 65.6208448112011, 61.715026795864105, 64.19652923941612, 67.28981405496597, 69.51332554221153, 70.61794146895409, 70.96581280231476, 68.62155139446259, 68.3086533844471, 69.60232436656952, 67.40562424063683, 72.87698104977608, 63.08829590678215, 56.45075127482414, 62.86436252295971, 63.34565989673138, 64.4397845864296, 64.79571908712387, 70.77738851308823, 70.67483201622963, 68.56519281864166, 68.83481875061989, 64.01503577828407, 63.34511272609234, 59.87947829067707, 58.62029045820236, 68.05814802646637, 67.21451729536057, 67.591852247715, 66.48718312382698, 64.53056931495667, 60.48374846577644, 51.537607312202454, 48.14073398709297, 51.88778892159462, 53.49162586033344, 54.210049510002136, 54.11042645573616, 56.18223488330841, 59.48586881160736, 59.51195441186428, 61.47276319563389, 63.278042525053024, 62.93782398104668, 64.13950949907303, 59.97591711580753, 60.213332176208496, 55.45924387872219, 54.882617220282555, 59.12647269666195, 59.292166605591774, 53.715954422950745, 48.83278325200081, 48.40611554682255, 50.58552660048008, 50.45493520796299, 49.132492169737816, 58.918566852808, 59.31604452431202, 65.43847739696503, 59.182268902659416, 65.08733063936234, 55.55311404168606, 56.1980040371418, 64.35093775391579, 58.08400243520737, 58.90976272523403, 57.06406496465206, 61.074863746762276, 55.85090026259422, 58.074130564928055, 55.09790986776352, 50.509314090013504, 47.24903963506222, 61.871411204338074, 57.63162910938263, 57.06767477095127, 57.22351960837841, 56.90697379410267, 54.54480014741421, 56.160861030220985, 53.06308105587959, 51.77154555916786, 55.36385379731655, 59.74241964519024, 58.07798735797405, 59.954858645796776, 55.8142626285553, 58.075802475214005, 52.80106231570244, 57.78634160757065, 54.576235860586166, 57.85577528178692, 58.52063700556755, 63.48822444677353, 62.38961219787598, 65.8998030424118, 61.21165260672569, 54.0149299800396, 35.664996430277824, 20.993759483098984, 12.918329257518053, 6.256743790581822, 2.3665999341756105, 0.06541432114318013, 0.011820813160738908, 0.15496212698053569, 0.02823489146976499, 0.07482846442144364, 0.22742892906535417, 0.188921854714863, 0.3438617172650993, 0.03411626152228564, 0.48283076961524785, 0.6006944482214749, 9.766240697354078, 72.81756743788719, 45.30568331480026, 31.427750699222088, 104.76699024438858, 66.5679819881916, 67.38620728254318, 13.919625878334045, 0.9866146242711693, 8.706002589315176, 33.26221436262131, 32.573375925421715, 43.498036712408066, 49.96059313416481, 40.92735305428505, 27.0957912504673, 44.275607988238335, 73.36045190691948, 80.01912340521812, 122.31643974781036, 79.77500930428505, 69.71089974045753, 54.80291649699211, 31.830215603113174, 1.0532851936295629, 48.69101665914059, 37.31476150453091, 50.05266219377518, 72.66285493969917, 86.41307830810547, 57.95397341251373, 2.052181768231094, 0.4702010191977024, 0.5972076009493321, 0.2797880710568279, 0.28259036131203175, 1.3778792135417461, 1.1304320977069438, 0.8135228091850877, 0.9440557204652578, 1.0439437511377037, 12.680868599563837, 91.55081301927567, 88.75746890902519, 91.52978494763374, 84.81052950024605, 85.76253041625023, 88.05753886699677, 87.42621794342995, 86.87460914254189, 87.68638238310814, 80.7952393591404, 76.46712720394135, 70.28905391693115, 71.37330293655396, 79.96563747525215, 76.00935816764832, 79.26004573702812, 79.97180074453354, 78.69987219572067, 77.00017020106316, 67.07647070288658, 65.22014871239662, 67.71561160683632, 70.90380012989044, 74.0067820250988, 73.74607801437378, 75.52627488970757, 71.32645905017853, 70.9433788061142, 73.66318926215172, 71.54053956270218, 71.75157263875008, 67.48075380921364, 60.36404728889465, 65.55090576410294, 66.13972216844559, 67.47362539172173, 68.5869200527668, 72.4627348780632, 71.98068514466286, 69.5571219921112, 69.27436396479607, 67.76624768972397, 66.71826392412186, 63.17727193236351, 60.80722890794277, 71.4460538327694, 68.9993043243885, 72.02789381146431, 70.44980049133301, 68.10385197401047, 63.59087213873863, 55.78318789601326, 49.19338010251522, 54.75908204913139, 56.10485203564167, 57.34888628125191, 55.72090543806553, 59.73206900060177, 63.64554740488529, 64.74496141076088, 65.27053400874138, 67.05906003713608, 65.2108696103096, 68.88779550790787, 62.4708366394043, 62.88217596709728, 59.17216144502163, 60.40891148149967, 61.1046389490366, 60.44628247618675, 54.431235641241074, 52.215031161904335, 50.34770876169205, 56.153907403349876, 54.8756255954504, 54.26007002592087, 57.895243763923645, 63.53145472705364, 66.50255709886551, 62.1521857380867, 67.53973424434662, 57.67212353646755, 60.91727860271931, 65.92073991894722, 58.9755903929472, 62.537686452269554, 61.15149423480034, 62.561594769358635, 56.310599595308304, 60.7974748313427, 54.097336158156395, 53.766411915421486, 49.65053357183933, 65.32592743635178, 60.588246658444405, 58.47432889044285, 60.14321833848953, 59.83327656984329, 59.346097111701965, 63.72300244867802, 62.31840401887894, 59.23583462834358, 59.10870864987373, 66.12286627292633, 60.28653904795647, 63.85121896862984, 60.1566506177187, 64.24490064382553, 57.74864763021469, 62.14251905679703, 59.033256098628044, 61.586510092020035, 63.168828785419464, 66.90544188022614, 69.1172043979168, 69.64963182806969, 67.17500701546669, 64.43684354424477, 49.19426545500755, 40.63316524028778, 19.01332665234804, 8.151000570505857, 2.4275933112949133, 0.30551185947842896, 0.15431010571774095, 0.20726994203869253, 0.15967243438353762, 0.21264359587803483, 0.5148292088415474, 0.1792421264690347, 0.6850157829467207, 0.14957174513256177, 0.8970278408378363, 0.6716140208300203, 12.073009517043829, 82.90672525763512, 54.85185407102108, 47.776797115802765, 107.36344411969185, 70.86443424224854, 77.65327915549278, 17.36481551080942, 1.092767568770796, 14.872163515537977, 43.801948204636574, 45.11814817786217, 53.745942413806915, 41.51827074587345, 30.971340090036392, 28.219083175063133], [10.36329885944724, 39.52129930257797, 35.275289341807365, 46.015960201621056, 24.395295158028603, 36.41042523086071, 18.89189086854458, 12.936838064342737, 0.38679911638610065, 12.942400015890598, 25.06916429847479, 44.4837836176157, 75.59670031070709, 60.58880142867565, 44.78126585483551, 2.8533547651022673, 0.4440283204894513, 0.22189050359884277, 0.1761168535449542, 0.09347819024696946, 0.08068852184806019, 0.30483727692626417, 0.1731928065419197, 0.40396454685833305, 0.23609754047356546, 16.802215799689293, 87.79785320162773, 71.28722995519638, 76.05639204382896, 65.15138760209084, 70.45280233025551, 71.37022510170937, 72.15915396809578, 75.68106338381767, 75.91983497142792, 71.6171358525753, 67.54639148712158, 64.86456379294395, 60.631457939743996, 73.07190299034119, 71.72894105315208, 73.4758061170578, 72.3677171766758, 73.63476678729057, 69.27948608994484, 67.4474447965622, 57.10789181292057, 56.4381967484951, 62.64512188732624, 63.246770203113556, 62.12238013744354, 66.56663686037064, 66.89639076590538, 67.09095552563667, 68.54716658592224, 65.76013773679733, 66.65637284517288, 56.91273048520088, 57.58961856365204, 60.825847908854485, 60.60614749789238, 64.41995725035667, 67.78365835547447, 64.95176151394844, 68.16216364502907, 62.54751272499561, 60.62087170779705, 59.85543318092823, 60.72748638689518, 56.167883053421974, 61.1115849763155, 66.5289656817913, 62.81524635851383, 63.898458033800125, 64.34533685445786, 58.27021524310112, 54.75486047565937, 47.75936745107174, 47.210783287882805, 51.97715252637863, 54.65453065931797, 59.5012541860342, 60.83900660276413, 56.31450578570366, 54.028331860899925, 52.6988971978426, 57.980051413178444, 59.71369318664074, 60.98396882414818, 61.47542305290699, 59.205531254410744, 56.837236136198044, 49.97871056199074, 51.97204940021038, 57.87859685719013, 60.12930728495121, 60.085689425468445, 54.42247711122036, 49.06326748430729, 43.780828937888145, 50.50799936056137, 49.414357244968414, 56.126526072621346, 59.81807738542557, 57.79799938201904, 60.48557236790657, 61.07640266418457, 59.495896473526955, 51.901255398988724, 57.03626185655594, 62.148157954216, 59.91269990801811, 54.85166408121586, 57.74877682328224, 58.4464155882597, 58.56399267911911, 54.53487507998943, 51.53441548347473, 48.21219675242901, 53.626283034682274, 53.632921278476715, 57.751831859350204, 53.243385180830956, 52.798641845583916, 49.37209211289883, 46.17133006453514, 41.63650140166283, 45.26630222797394, 49.351090639829636, 54.43710632622242, 52.08649925887585, 54.191525503993034, 50.45043624937534, 57.02140845358372, 52.09758326411247, 50.180054157972336, 49.8556237667799, 55.0768855959177, 57.62763552367687, 59.00918059051037, 53.65488409996033, 54.63293641805649, 31.282328702509403, 23.454845622181892, 19.271800182759762, 15.029367730021477, 4.2651656828820705, 1.3613901170901954, 0.3819538716925308, 0.05952500825515017, 0.11520186206325889, 0.1246345293475315, 0.14228432992240414, 0.11573093914194033, 0.06495658672065474, 0.04565613839076832, 0.021828103126608767, 0.020447406022867654, 0.032187720280489884, 0.3058157837949693, 8.104946091771126, 62.125245183706284, 42.91475661098957, 23.954566307365894, 35.52903592586517, 45.108420699834824, 54.14697669446468, 6.608012141659856, 0.7214275072328746, 1.5551224839873612, 6.38842049986124, 8.859236966818571, 1.5512294741347432, 3.1066745845600963, 5.973829971626401, 3.2238379726186395, 11.803622972220182, 48.22382792830467, 60.20763248205185, 78.08875858783722, 50.32779783010483, 47.19030998647213, 42.60934419929981, 11.534662004560232, 3.6492118472233415, 17.345560044050217, 39.09766003489494, 36.54645033180714, 82.82748430967331, 67.62140706181526, 52.99631863832474, 3.2325402181595564, 0.2866347396047786, 0.12303949813940562, 0.1717788667883724, 0.12239708768902346, 0.17741185671184212, 0.2215463251923211, 0.4132564732572064, 0.2256835758453235, 0.24186442868085578, 17.162238880991936, 88.04702863097191, 76.43677443265915, 81.95249766111374, 72.45456531643867, 75.54613262414932, 79.01508048176765, 78.13649162650108, 77.23870620131493, 76.38414725661278, 73.33707556128502, 68.64091515541077, 66.59157872200012, 63.00090819597244, 75.2283176779747, 74.03198227286339, 75.63494145870209, 73.73638093471527, 77.47060775756836, 73.56938749551773, 71.42583131790161, 61.77653029561043, 61.10929749906063, 64.2119488120079, 66.59231588244438, 64.8767839372158, 68.98911327123642, 67.42407605051994, 72.00683534145355, 70.51679089665413, 68.77835378050804, 68.73982384800911, 62.80250184237957, 60.71803629398346, 64.2572195827961, 65.11028900742531, 67.6812918484211, 69.86021652817726, 68.88694435358047, 69.50788423418999, 64.43084746599197, 64.77178797125816, 63.249916434288025, 63.62302981317043, 59.378665164113045, 62.88247235119343, 67.45591834187508, 67.05681815743446, 65.59363067150116, 66.67840406298637, 60.2430921792984, 57.26576954126358, 51.27356708049774, 50.262992307543755, 55.37002466619015, 59.926645159721375, 64.746602922678, 64.79004219174385, 60.95773123204708, 57.93269835412502, 54.83280189335346, 60.31034477055073, 63.7114130705595, 62.829149812459946, 64.27999556064606, 62.57213540375233, 57.549424320459366, 54.092620611190796, 54.55704689025879, 58.90805661678314, 62.822872549295425, 64.43128064274788, 59.9423573166132, 52.21478037536144, 46.94475956261158, 51.79625563323498, 53.44684526324272, 57.28249244391918, 63.10913398861885, 59.82473462820053, 63.76189336180687, 63.749361634254456, 65.09088724851608, 55.251683816313744, 56.18877813220024, 63.47261868417263, 61.0431544482708, 58.5572100430727, 58.79348136484623, 60.41042000055313, 59.26642298698425, 58.062229603528976, 54.00886170566082, 51.87659852206707, 54.77275371551514, 56.34580850601196, 60.005939304828644, 58.542550429701805, 58.008238300681114, 54.87617276608944, 48.35047893226147, 48.20087715983391, 51.830974370241165, 55.336981639266014, 59.226730316877365, 57.439712807536125, 59.75828759372234, 54.66627582907677, 59.71464693546295, 56.13086923956871, 53.06605629622936, 52.72228114306927, 56.80802710354328, 59.79768007993698, 64.9743627011776, 59.94378983974457, 60.67165598273277, 36.187320202589035, 26.01685244590044, 18.546848483383656, 13.987114056944847, 8.68022857233882, 3.5774731216952205, 1.2435211543925107, 0.15982280834577978, 0.22428164404118434, 0.16893712396267802, 0.12726075248792768, 0.14622354588937014, 0.10090927782584913, 0.01767165867931908, 0.2790900960098952, 0.026147552889597137, 0.3078001085668802, 0.3985886072041467, 10.837213229387999, 72.16220900416374, 49.752675890922546, 31.326970607042313, 47.11594417691231, 49.199060797691345, 67.91266143321991, 8.222132753580809, 0.7624829385895282, 11.582349445670843, 15.757431462407112, 16.698019690811634, 12.767843082547188, 10.977494101971388, 16.156231462955475, 11.430912371724844, 20.96020918339491, 91.40593439340591, 80.74888184666634, 154.25799697637558, 58.46850000321865, 58.35246562957764, 48.511176109313965, 27.54387080669403, 1.7774601909331977, 51.52400404214859, 58.604642897844315, 68.05426463484764, 94.22549709677696, 79.46825176477432, 65.10044753551483, 4.302521953359246, 0.7013050932437181, 0.5141960678156465, 0.4221957013942301, 0.42451773304492235, 0.3011437563691288, 1.013998151756823, 0.7224386685993522, 0.6650963018182665, 0.4309854906750843, 19.520439840853214, 94.21604320406914, 85.23160770535469, 90.23286134004593, 79.99205365777016, 82.96063676476479, 84.60844114422798, 85.44641777873039, 85.21915197372437, 83.2867656648159, 77.88420036435127, 74.19412717223167, 70.85646227002144, 69.34975191950798, 80.42528361082077, 79.35295075178146, 78.72435808181763, 78.47550943493843, 80.80704912543297, 76.78202390670776, 76.06472119688988, 66.6633340716362, 64.4280356168747, 68.99168193340302, 71.44377395510674, 68.58814358711243, 74.78900045156479, 71.00647062063217, 74.90772888064384, 74.17663291096687, 69.83334437012672, 74.13176491856575, 66.10733270645142, 62.01660521328449, 68.30334886908531, 63.5498571395874, 70.42070165276527, 72.47032687067986, 68.92165929079056, 72.5376744568348, 69.11175549030304, 64.93799865245819, 66.63093701004982, 65.2426815032959, 63.09217169880867, 62.902474477887154, 72.14197129011154, 67.2605936229229, 68.0964195728302, 69.26310896873474, 64.9451270699501, 61.09150305390358, 55.49596510827541, 54.07221570611, 58.88880304992199, 61.12888164818287, 64.60063755512238, 66.52480110526085, 62.994349747896194, 59.83811371028423, 56.427196338772774, 61.66617661714554, 66.42390131950378, 66.1796960234642, 67.76589810848236, 64.8421297967434, 60.91800816357136, 54.92271646857262, 59.02684964239597, 62.255521193146706, 67.04369366168976, 66.19940936565399, 59.86774832010269, 54.63822193443775, 49.88331288099289, 54.38777357339859, 54.55969534814358, 60.09510152041912, 64.08371329307556, 60.68517565727234, 65.70678859949112, 63.25376942753792, 65.64307361841202, 56.058600917458534, 60.08363753557205, 67.66249045729637, 63.848764300346375, 60.27317516505718, 62.96456694602966, 61.75785429775715, 62.86444611847401, 61.375955790281296, 59.777951538562775, 51.24484062194824, 60.0756161659956, 57.53926366567612, 62.479975149035454, 59.02244947850704, 60.84313318133354, 59.60128001868725, 58.585366532206535, 56.247940957546234, 58.52562613785267, 60.01022167503834, 62.651231959462166, 60.89116260409355, 63.117162957787514, 61.88693717122078, 68.00426691770554, 61.392659693956375, 60.08260399103165, 56.51512362062931, 62.70122967660427, 63.03657688200474, 69.08799916505814, 64.28138628602028, 67.49843806028366, 47.907259315252304, 47.21065789461136, 33.765413761138916, 21.593996174633503, 12.461580466479063, 4.585050093010068, 1.9381438312120736, 0.3344523534178734, 0.42850552999880165, 0.3985753672895953, 0.26334510650485754, 0.3973107476485893, 0.22590329608647153, 0.12197223040857352, 0.658381765242666, 0.15072936192154884, 0.6780476099811494, 0.4945383273297921, 14.09127026796341, 80.81298440694809, 59.813445433974266, 39.83150705695152, 54.327425211668015, 55.765211060643196, 84.28616523742676, 12.035243343561888, 0.49824113957583904, 22.60270904749632, 31.38891488313675, 33.10507379472256, 13.068651091307402, 6.2861010152846575, 7.7565879095345736, 7.670038528740406], [15.636211317032576, 52.6479647308588, 50.1098795235157, 28.03116425871849, 13.029910270124674, 39.8056760430336, 18.35469089448452, 11.289421264082193, 0.8086958213243634, 12.442648932337761, 24.346049800515175, 34.56866405904293, 86.41598135232925, 54.868519976735115, 42.0927619189024, 5.4737787041813135, 0.5639950674958527, 0.20189079630654305, 0.24053322355030105, 0.1222531333041843, 0.2532819996122271, 0.17773236060747877, 0.13618044729810208, 0.08850535552483052, 0.09984603995690122, 20.655530132353306, 67.0714321732521, 72.47995555400848, 74.715436398983, 66.9482047855854, 67.82018959522247, 68.11670288443565, 70.16961112618446, 71.85331597924232, 72.47923359274864, 71.45199671387672, 66.02953568100929, 63.429171815514565, 57.974108532071114, 65.60752272605896, 70.89231714606285, 75.5297403037548, 71.02589517831802, 73.33238661289215, 72.3003239929676, 69.69315469264984, 63.052353635430336, 54.06172826886177, 57.33580358326435, 59.2964755743742, 59.483410343527794, 60.655066072940826, 65.95771193504333, 66.53057679533958, 67.57816538214684, 67.00915351510048, 60.858742743730545, 52.31191836297512, 57.60903552174568, 61.58885456621647, 62.18251571059227, 64.71045926213264, 65.42265504598618, 64.45897355675697, 63.419106155633926, 59.801996648311615, 63.59467953443527, 67.76462897658348, 60.5978487432003, 59.4783566147089, 63.45002509653568, 61.38081572949886, 63.88473317027092, 62.47304052114487, 60.84970682859421, 61.50122366845608, 54.331422597169876, 46.20728373527527, 48.46789263188839, 59.07020911574364, 61.18620917201042, 63.90851989388466, 61.147888228297234, 53.74102547764778, 53.209813982248306, 49.92869384586811, 55.97019866108894, 57.079769521951675, 59.09514717757702, 58.45849134027958, 59.0279857814312, 54.84380230307579, 50.85069917142391, 50.98787181079388, 51.39330245554447, 59.208886474370956, 58.02509419620037, 59.5688221603632, 56.89245097339153, 44.85626623034477, 46.4261519908905, 54.157019555568695, 50.65478928387165, 56.298261657357216, 60.35119637846947, 56.16855561733246, 61.27283312380314, 58.45331981778145, 56.767262890934944, 51.209548115730286, 61.09682276844978, 58.44017252326012, 57.68518723547459, 55.0265496969223, 56.82275891304016, 56.95653073489666, 56.72928012907505, 51.780516877770424, 54.858640506863594, 52.89255380630493, 56.66102059185505, 54.019276946783066, 53.357785642147064, 49.47753265500069, 45.19747652113438, 38.83974887430668, 41.94013170897961, 46.70448325574398, 51.869458705186844, 54.113705679774284, 53.803361132740974, 54.49772447347641, 51.1545916646719, 55.47659754753113, 50.268163830041885, 52.1925363689661, 53.376780822873116, 57.1101450920105, 54.196457639336586, 58.43559756875038, 50.599920228123665, 30.186723992228508, 23.018611930310726, 19.460089579224586, 11.296384390443563, 14.560690429061651, 7.504242975264788, 2.8364071995019913, 1.2541076238267124, 0.4143174772616476, 0.14989020070061088, 0.13394345092820004, 0.32951030298136175, 0.10278108558850363, 0.042348441857029684, 0.08650623232824728, 0.0582327844313113, 0.0346384292060975, 0.386074127163738, 0.28774822829291224, 12.03223580494523, 60.3547377884388, 49.23385173082352, 29.060610719025135, 30.18855929374695, 43.34606386721134, 38.973338305950165, 4.283964699134231, 0.30414384382311255, 4.475228860974312, 4.522046623751521, 4.225123906508088, 1.2059429520741105, 0.12993031705264002, 1.0874935705214739, 0.5699829524382949, 16.847313679754734, 58.30583073198795, 66.95169299840927, 86.08825653791428, 32.996475622057915, 52.79274456202984, 34.92088995873928, 13.776575904339552, 4.5279809553176165, 31.509733200073242, 41.010587587952614, 41.89998686313629, 97.02467769384384, 64.20057222247124, 50.37304200232029, 6.48713112808764, 0.5442225316073745, 0.14841605792753398, 0.13220407941844314, 0.06578339118277654, 0.17133610148448497, 0.13039038924034685, 0.13637913507409394, 0.05089050595415756, 0.07856375304982066, 21.835252828896046, 82.13907524943352, 79.37092378735542, 79.47956755757332, 72.56080001592636, 72.46709704399109, 76.51559740304947, 75.08095398545265, 76.49994984269142, 74.03677761554718, 73.12640726566315, 67.21556603908539, 63.1931246817112, 58.08175675570965, 69.38977137207985, 72.59777963161469, 77.46659517288208, 71.10273465514183, 76.30481511354446, 75.29879629611969, 72.7979376912117, 66.54117062687874, 58.048352748155594, 60.669934675097466, 63.63304227590561, 62.79981918632984, 63.49468030035496, 67.67239272594452, 71.9210359454155, 69.8960942029953, 69.41898420453072, 64.98435616493225, 55.877905413508415, 61.5701025724411, 66.77473649382591, 63.987692445516586, 67.32287988066673, 67.11295634508133, 67.72424474358559, 67.1640408039093, 63.09043899178505, 67.6496547460556, 67.97376215457916, 62.75850020349026, 62.5156020373106, 65.87822020053864, 63.10956336557865, 63.756512850522995, 64.24222558736801, 63.996728360652924, 63.33117127418518, 55.203339010477066, 48.47855485975742, 52.202700823545456, 62.28537619113922, 64.68457505106926, 66.45155623555183, 62.62092478573322, 57.50185467302799, 55.765116065740585, 53.16589213907719, 57.770861238241196, 60.988167598843575, 60.87985821068287, 61.39701046049595, 60.10642871260643, 55.61869852244854, 53.33725154399872, 52.04191245138645, 52.48183764517307, 62.43986450135708, 59.53184254467487, 64.93734508752823, 59.01395693421364, 49.119781851768494, 46.962899789214134, 53.9927201718092, 52.29143746197224, 56.568370163440704, 64.43517163395882, 60.13059161603451, 60.54316587746143, 61.73180669546127, 59.445955753326416, 55.94298452138901, 61.019656509160995, 59.68503512442112, 60.201944187283516, 57.02219881117344, 58.25653597712517, 59.158900156617165, 58.415876626968384, 54.85217325389385, 56.917449831962585, 58.32184687256813, 57.904804050922394, 57.427519261837006, 54.6494085341692, 54.00346979498863, 48.43979313969612, 46.327068507671356, 49.76038567721844, 51.410610526800156, 55.75891099870205, 58.76008115708828, 57.71802507340908, 59.256425723433495, 55.98186403512955, 55.675866454839706, 53.60046721994877, 53.78840893507004, 56.14702217280865, 61.83500915765762, 61.02416306734085, 60.39861023426056, 57.4420078843832, 33.79621110856533, 19.852036647498608, 23.3533226698637, 15.539793390780687, 18.408144526183605, 10.595204215496778, 3.832902302965522, 0.9006213198881596, 0.062156185231287964, 0.3053164668381214, 0.1828962835134007, 0.15220786852296442, 0.6480762432329357, 0.030398780727409758, 0.13146495970431715, 0.07043837889796123, 0.04141340628848411, 0.43088844744488597, 0.2680846693692729, 14.513081833720207, 69.23249021172523, 57.9525750875473, 34.895134940743446, 31.16042174398899, 49.65519592165947, 48.45690742135048, 3.7315816897898912, 0.47631601919420063, 12.588073778897524, 13.489196375012398, 7.032128283753991, 1.737375904340297, 1.5800846507772803, 3.540547890588641, 2.101227161474526, 25.66353600472212, 99.7578938305378, 119.4513250887394, 144.26155418157578, 39.38218496739864, 69.76385369896889, 51.16116151213646, 32.20275901257992, 4.0819931868463755, 64.6974715590477, 54.48445178568363, 55.77629506587982, 104.63234826922417, 76.94169133901596, 62.37017624080181, 8.287877775728703, 0.7554450631141663, 0.6878423562739044, 0.26146729476749897, 0.49153286672662944, 0.5847227771300822, 0.5950363737065345, 0.41219932842068374, 0.23164823156548664, 0.24939382856246084, 27.6901363581419, 90.68949803709984, 86.1703397333622, 87.20868721604347, 78.74098598957062, 79.04567644000053, 81.46275714039803, 82.86226764321327, 82.6133506000042, 81.11982554197311, 78.37895661592484, 71.11064583063126, 70.12416556477547, 64.36897918581963, 72.95013472437859, 76.81279465556145, 81.90052404999733, 74.70344424247742, 81.28884807229042, 78.56441706418991, 77.53575146198273, 69.06799703836441, 60.10715067386627, 62.76088647544384, 69.02008920907974, 66.54861062765121, 69.47423323988914, 70.25373861193657, 73.67335751652718, 72.15612173080444, 74.10106256604195, 66.72443479299545, 56.13541379570961, 63.830259293317795, 70.7089313864708, 66.8282376229763, 70.09554550051689, 69.94683668017387, 69.41046506166458, 69.59842577576637, 65.29878929257393, 67.66152530908585, 72.5986459851265, 68.52011203765869, 66.46922528743744, 69.07491266727448, 64.36831802129745, 67.62094348669052, 67.6337032020092, 66.41832321882248, 67.49536022543907, 60.47072276473045, 52.97815561294556, 52.86366015672684, 64.74694490432739, 65.7142286002636, 70.5324536561966, 67.3956535756588, 59.003116115927696, 60.118515864014626, 57.131157964468, 59.55575466156006, 63.30802671611309, 64.2823514342308, 65.25687754154205, 63.03164094686508, 59.293504133820534, 58.462234139442444, 58.27734366059303, 58.368550166487694, 65.42141631245613, 62.116019278764725, 66.85590773820877, 60.04935957491398, 49.60395187139511, 52.202298045158386, 58.714422807097435, 52.44484283030033, 62.27735482156277, 65.28687313199043, 62.83738777041435, 63.13792124390602, 63.98016884922981, 61.920667961239815, 57.36018307507038, 63.253416046500206, 63.22398662567139, 62.280835434794426, 60.097248405218124, 61.29793077707291, 61.395729929208755, 59.96864430606365, 58.715999722480774, 59.64492827653885, 60.9503748267889, 60.73534816503525, 61.8023157119751, 58.926307037472725, 58.71330566704273, 54.77192535996437, 54.80178415775299, 55.64105652272701, 58.53501543402672, 57.17738248407841, 64.59043890237808, 61.608146131038666, 62.90367901325226, 60.334944650530815, 62.0935320854187, 56.86552941799164, 60.388924553990364, 61.51956908404827, 65.07039114832878, 64.12664338946342, 65.47345072031021, 63.55994939804077, 47.561903446912766, 35.30944190919399, 25.061255022883415, 18.337800800800323, 23.991927802562714, 16.7568177357316, 6.185959288850427, 2.196858529932797, 1.0998589382506907, 0.462656375602819, 0.40395653166342527, 0.4347294179024175, 1.4317645970731974, 0.13948966894531623, 0.2295178224449046, 0.24624246172606945, 0.12790532258804888, 0.7970838225446641, 0.46314637118484825, 18.51890478283167, 80.9148721396923, 69.23077270388603, 47.26359665393829, 46.963534355163574, 57.35697224736214, 67.78100609779358, 4.90735687315464, 0.49141326220706105, 29.161284416913986, 35.78371345996857, 13.99144297465682, 3.3113596262410283, 1.0904635861515999, 1.4796791947446764, 1.8846199032850564], [26.219322681427002, 66.86641797423363, 24.751374050974846, 27.468876130878925, 11.376191508024931, 33.455806374549866, 14.667116068303585, 14.051542449742556, 1.2689502211287618, 19.007625058293343, 24.539780505001545, 38.180305659770966, 89.29374173283577, 52.00438566505909, 43.90696316957474, 10.744445957243443, 0.769070953829214, 0.5290326091926545, 0.2792879822663963, 0.1863391511142254, 0.09482370398472995, 0.10599658882711083, 0.042152930473093875, 0.05884565740416292, 0.2109965030103922, 20.648405514657497, 52.50048704445362, 75.05385383963585, 76.44460961222649, 66.03238552808762, 69.8434366285801, 66.70605897903442, 68.08778643608093, 66.38731688261032, 68.42014700174332, 67.31981724500656, 67.8693437576294, 63.54548737406731, 56.30972944200039, 63.691692128777504, 69.70033630728722, 73.21132510900497, 73.42338413000107, 70.22315785288811, 69.42895486950874, 69.08515691757202, 66.2328627705574, 62.10571423172951, 54.16230887174606, 54.60652403533459, 55.65623290836811, 62.264112532138824, 66.68410375714302, 65.08885055780411, 69.87513452768326, 62.52939909696579, 58.313266932964325, 55.83426855504513, 62.39363618195057, 62.70796671509743, 65.61182409524918, 63.403017818927765, 65.86945787072182, 58.22396032512188, 64.6921594440937, 68.13941046595573, 64.12687137722969, 59.932930022478104, 55.68017542362213, 60.65938264131546, 63.796866685152054, 62.21465818583965, 64.82379958033562, 60.027343556284904, 63.28583210706711, 54.53387953341007, 49.5981951802969, 45.2919964492321, 53.125124126672745, 59.499377086758614, 60.04084423184395, 61.04099616408348, 53.00386883318424, 50.32890737056732, 49.32355351746082, 48.85249279439449, 57.255149111151695, 57.743438109755516, 57.48130917549133, 58.396497666835785, 57.05740012228489, 51.969849318265915, 48.49823780357838, 44.29959610104561, 48.5046062618494, 55.84535256028175, 61.49761386215687, 56.66570954024792, 57.33770728111267, 54.67739023268223, 47.12787173688412, 45.535388588905334, 55.015351697802544, 54.67982970178127, 56.69100098311901, 61.71251133084297, 57.35683165490627, 59.060337245464325, 57.77806185185909, 52.39915028214455, 54.574415758252144, 56.738468036055565, 58.75989876687527, 58.16776134073734, 56.39316916465759, 54.364359229803085, 55.120811238884926, 51.64356842637062, 56.01820148527622, 53.883677423000336, 52.98142723739147, 51.32253885269165, 51.08287811279297, 47.04240672290325, 40.230512246489525, 39.45163384079933, 46.05461172759533, 52.559771463274956, 54.84093725681305, 52.168810442090034, 53.285642713308334, 50.432524010539055, 48.28321114182472, 55.24959392845631, 55.286672338843346, 54.652759954333305, 54.46343131363392, 57.417229413986206, 55.89395575225353, 61.57432034611702, 32.89736934006214, 25.280993431806564, 31.15201659500599, 11.584208495914936, 2.5590541446581483, 14.138375390321016, 17.648202404379845, 4.325688360258937, 1.4710239716805518, 0.8524721441790462, 0.05764502944657579, 0.18688388750888407, 0.3994652320398018, 0.28180306137073785, 0.0370531105727423, 0.010609766377456253, 0.07033956193481572, 0.009384302447870141, 0.14974957855883986, 0.14553937478922307, 14.812947493046522, 55.360426381230354, 52.62795880436897, 29.53101597726345, 37.92169153690338, 42.73267038166523, 26.785551197826862, 4.0509802009910345, 0.21971932088490576, 10.670029800385237, 3.915840690024197, 1.235374747775495, 0.5603936919942498, 0.26896191760897636, 0.4387557174777612, 1.1713664699345827, 25.100510716438293, 64.04189273715019, 81.71095982193947, 71.49174258112907, 20.88295552879572, 53.91525752842426, 29.997011572122574, 17.315625250339508, 2.9620474576950073, 43.76781843602657, 33.49212482571602, 47.48877637088299, 103.19849520921707, 57.14913859963417, 56.60528898239136, 12.470943164080381, 0.5936898803338408, 0.37257202668115497, 0.055836571409599856, 0.19153509027091786, 0.026604996019159444, 0.06914251483976841, 0.08347412862349302, 0.07500307692680508, 0.11226706876186654, 26.564220674335957, 65.49600630998611, 82.01903969049454, 79.15713965892792, 70.6904947757721, 72.46390521526337, 73.91956150531769, 74.75105568766594, 72.76566982269287, 69.4314855337143, 72.2256276011467, 68.2040373980999, 64.58332568407059, 59.20217223465443, 62.65030860900879, 72.29884967207909, 74.83569234609604, 74.92127135396004, 71.52312889695168, 71.9273892045021, 72.96903491020203, 69.75968912243843, 64.74066764116287, 55.237347185611725, 55.97769185900688, 58.568807020783424, 65.83065435290337, 68.98409754037857, 69.38315212726593, 70.59233844280243, 64.74573656916618, 58.249502554535866, 57.128878086805344, 64.1297896206379, 66.58106088638306, 67.7191910147667, 65.07322579622269, 66.97094276547432, 61.76014557480812, 68.27418923377991, 68.22344675660133, 66.48507043719292, 60.93737572431564, 58.23890492320061, 64.5387464761734, 64.95330423116684, 65.0195574760437, 65.26361837983131, 66.0403499007225, 65.34477442502975, 54.39229913055897, 52.00243636965752, 49.01306837797165, 56.829647943377495, 62.89786532521248, 61.05630934238434, 62.48358115553856, 55.80728240311146, 52.84592650830746, 50.842898190021515, 52.39565446972847, 57.80046924948692, 60.54758884012699, 60.465965420007706, 59.08505491912365, 57.14995935559273, 53.29338289797306, 49.60333630442619, 47.526538744568825, 50.275410041213036, 59.43918451666832, 65.79250440001488, 59.074905663728714, 60.92983692884445, 56.58595561981201, 49.96638782322407, 48.013797998428345, 56.83832287788391, 60.57612530887127, 56.926538944244385, 65.32335117459297, 59.889410957694054, 60.160363018512726, 60.05799651145935, 54.71827983856201, 56.59225948154926, 59.293488934636116, 60.22782079875469, 59.8795922845602, 58.31308454275131, 56.430300772190094, 56.65080673992634, 54.656772539019585, 58.685996532440186, 56.682884618639946, 58.81301611661911, 55.694481655955315, 55.94268813729286, 49.643006175756454, 44.20828700065613, 48.771982714533806, 52.73000992834568, 57.05513924360275, 58.22971701622009, 54.97944362461567, 55.27021922171116, 55.74499994516373, 53.7595646828413, 58.1211606413126, 56.35818064212799, 58.55478577315807, 59.065482169389725, 59.93237145245075, 58.50652076303959, 63.79233732819557, 38.48495431244373, 28.784470036625862, 33.089654222130775, 17.22801335155964, 7.743581207469106, 17.158099003136158, 17.201359681785107, 5.555779254063964, 0.5514159018639475, 0.9809859981760383, 0.049369526241207495, 0.1448206789791584, 0.4207016690634191, 0.47567186469677836, 0.059261475325911306, 0.08145460378727876, 0.015081118926900672, 0.0647572310117539, 0.36023319815285504, 0.24981979164294899, 19.196564219892025, 66.72319605946541, 59.997040182352066, 38.4739501029253, 39.7420484572649, 49.793405905365944, 35.4734031111002, 4.600810697302222, 0.3111060202354565, 17.64881607145071, 10.393024664372206, 5.603995341807604, 0.9288814722094685, 0.14585650933440775, 0.5749580136034638, 1.4782213792204857, 42.15087220072746, 103.47717225551605, 152.8878664970398, 92.05033421516418, 20.593283772468567, 62.9005441814661, 50.40407493710518, 31.789270900189877, 13.31171739846468, 78.8230311870575, 45.192741975188255, 58.69711473584175, 104.95843157172203, 68.80564391613007, 66.28583952784538, 14.655925668776035, 0.7424125343095511, 1.012355333659798, 0.22669237718218938, 0.6865268549881876, 0.15153146028751507, 0.32635032723192126, 0.11732047103578225, 0.41792713513132185, 0.27122534927912056, 27.605281211435795, 74.7932106256485, 89.48260679841042, 82.22552061080933, 76.52355417609215, 78.5232424736023, 79.90529671311378, 78.39202031493187, 79.95379731059074, 74.69886168837547, 74.63835373520851, 75.1556047797203, 69.7417388856411, 62.52254046499729, 68.60119208693504, 77.15940445661545, 80.42921259999275, 80.35847559571266, 72.86366656422615, 75.68053901195526, 76.45990759134293, 72.32975721359253, 70.06111934781075, 58.76388855278492, 59.88319829106331, 62.34174616634846, 68.73788595199585, 71.91693216562271, 70.84979742765427, 75.17649605870247, 67.7132785320282, 59.43841315805912, 59.904572144150734, 66.65622845292091, 64.46529641747475, 70.18753096461296, 69.06143099069595, 68.89707460999489, 63.17999258637428, 71.07871234416962, 70.14448687434196, 70.70406004786491, 65.6196516752243, 61.57505750656128, 67.60797098279, 66.9847360253334, 67.3172789812088, 69.49992746114731, 64.14796024560928, 68.93243551254272, 59.273019433021545, 55.53424045443535, 51.295822486281395, 57.62322776019573, 65.04204466938972, 66.17043972015381, 67.01652511954308, 57.80693270266056, 54.70206990838051, 53.296301141381264, 56.0105486959219, 60.84291659295559, 64.68705251812935, 62.45460011065006, 63.33557903766632, 56.88880696892738, 56.04486085474491, 51.92120052874088, 49.910990595817566, 54.29803378880024, 61.61944292485714, 68.31331953406334, 60.5509402602911, 63.665443137288094, 61.207127049565315, 53.10357168316841, 51.52057662606239, 59.300769343972206, 63.63024562597275, 61.42073638737202, 66.95237696170807, 61.013953015208244, 64.36908558011055, 60.84084190428257, 56.60224534571171, 57.741336822509766, 61.045073345303535, 61.390558406710625, 63.89709010720253, 57.78520166873932, 59.20796312391758, 60.139996111392975, 58.47906343638897, 61.73096314072609, 59.92707073688507, 59.974393397569656, 60.08992999792099, 59.04262639582157, 58.65916237235069, 51.82738356292248, 54.24517102539539, 56.65227726101875, 61.432747542858124, 61.08580715954304, 61.703106835484505, 60.10455921292305, 60.68004213273525, 57.33265735208988, 64.94003534317017, 61.81506782770157, 63.66007782518864, 63.51491421461105, 65.99965408444405, 60.628292709589005, 71.6667003929615, 45.78608773648739, 43.00291188061237, 39.25106920301914, 21.459863372147083, 10.248567815870047, 19.10728421062231, 28.384885378181934, 12.823415100574493, 4.066643435508013, 2.4416501820087433, 0.24756017461186275, 0.4024834278970957, 1.2215938372537494, 0.5917319166474044, 0.2530230791307986, 0.14940985303837806, 0.148442879144568, 0.09524861321551725, 0.48451574170030653, 0.5289406422525644, 25.60196030884981, 77.42895439267159, 68.97166460752487, 48.47629778087139, 56.81183069944382, 59.43873234093189, 51.812271773815155, 5.525306314229965, 0.3567945311078802, 34.51880693435669, 36.505116149783134, 8.777619246393442, 2.7282787766307592, 0.5766052845865488, 0.45686842524446547, 3.017227384261787], [36.691480949521065, 69.12722826004028, 19.19823992997408, 31.215993762016296, 10.449637826532125, 21.206244081258774, 7.951667541638017, 7.187416926026344, 2.6658666506409645, 15.297771077603102, 24.76423256099224, 35.236143842339516, 66.43454074859619, 54.648420587182045, 39.575985968112946, 19.86033920198679, 1.0957701201550663, 0.2661917475052178, 0.18194505799328908, 0.23086916946340352, 0.055966328509384766, 0.09047663334058598, 0.040315090809599496, 0.12293856605538167, 0.13472249818732962, 10.29467549175024, 50.75997143983841, 68.08156237006187, 75.6284362077713, 68.55226591229439, 66.44691288471222, 63.60856778919697, 66.10829025506973, 65.31590357422829, 66.52144208550453, 64.89097237586975, 65.36456376314163, 63.498434498906136, 59.96219225227833, 58.34700532257557, 62.8251638263464, 72.83483371138573, 69.4390319287777, 71.26089736819267, 65.87923854589462, 70.38532555103302, 67.16679945588112, 64.32521313428879, 55.47973617911339, 55.12223616242409, 53.683044388890266, 57.27285996079445, 64.87562119960785, 63.69727402925491, 67.14126482605934, 62.858339846134186, 56.87864251434803, 59.84834276139736, 62.146280854940414, 59.18333664536476, 65.55747181177139, 67.10404962301254, 63.70394267141819, 60.85117734968662, 61.10691122710705, 63.223770037293434, 58.87443982064724, 56.43372058868408, 62.04932525753975, 63.075779378414154, 64.16075795888901, 61.55923515558243, 64.90266054868698, 61.97746731340885, 51.87463402748108, 52.10152365267277, 51.02469943463802, 47.518179193139076, 59.39166806638241, 53.73908378183842, 60.838634222745895, 55.138791874051094, 50.973447784781456, 42.86126308143139, 45.59443362057209, 46.47573933005333, 52.678047716617584, 55.17106734216213, 58.565068021416664, 57.01173037290573, 56.402174681425095, 50.55296994745731, 43.25184032320976, 43.124577552080154, 45.489555448293686, 51.90038904547691, 58.17735202610493, 59.07205581665039, 59.74895529448986, 54.991994351148605, 49.31604892015457, 51.690127328038216, 49.99110169708729, 54.75607641041279, 54.12285938858986, 53.959327563643456, 59.63337689638138, 53.039655312895775, 57.55188278853893, 55.848878771066666, 54.06518988311291, 56.00526697933674, 57.83967174589634, 55.12780286371708, 58.28003391623497, 54.057848677039146, 55.24637170135975, 50.42949557304382, 55.84190994501114, 52.581422701478004, 55.032169595360756, 49.61964502930641, 48.71643349528313, 42.564970180392265, 40.05824849009514, 47.945230677723885, 53.67485202848911, 55.75006507337093, 49.63742047548294, 50.96862584352493, 48.674198761582375, 51.29909411072731, 49.2279202491045, 56.873657181859016, 58.592525348067284, 56.033408269286156, 58.333607241511345, 57.692638635635376, 55.86799934506416, 40.212280824780464, 25.2154678478837, 33.678307235240936, 19.151846319437027, 4.790927795693278, 5.9428127110004425, 17.6187501847744, 24.508969858288765, 14.841537158936262, 6.0193372797220945, 1.836948967538774, 0.5531384563073516, 0.08025199800613336, 0.23203356948215514, 0.12514200992882252, 0.07753834244795144, 0.04372730771137867, 0.11171532649314031, 0.048804436446516775, 0.5871339258737862, 0.16409575327998027, 21.355648264288902, 51.72800749540329, 57.78894066810608, 30.35880535840988, 39.46491412818432, 48.01832735538483, 26.956697814166546, 3.547106576152146, 0.24126140400767326, 12.286663502454758, 3.004656946286559, 1.140222866088152, 1.391509200911969, 0.07041537231998518, 0.3904939134372398, 2.032025274820626, 37.18253239989281, 66.91789001226425, 85.85874125361443, 43.90677697956562, 16.34146962314844, 43.42313513159752, 27.20741406083107, 19.603176601231098, 1.7345733172260225, 39.47154097259045, 34.78193141520023, 42.06982634961605, 86.07709273695946, 57.027298137545586, 54.280433133244514, 24.545654989778996, 0.9784334257710725, 0.224455455027055, 0.07456757724867202, 0.11565920314751565, 0.01811551865102956, 0.21752664557425305, 0.03073882166063413, 0.18828181171556935, 0.09009437533677556, 18.44340093433857, 63.970798552036285, 78.08018624782562, 81.91920384764671, 72.97411903738976, 70.46624600887299, 68.91916662454605, 72.43937373161316, 71.8890492618084, 70.5883714556694, 67.72799894213676, 69.13532182574272, 64.7547572851181, 60.58058626949787, 58.92668701708317, 63.90983462333679, 73.28977569937706, 69.50415283441544, 71.53948321938515, 68.11246231198311, 74.8203107714653, 70.87871387600899, 67.95658707618713, 58.8251830637455, 59.320072308182716, 55.379299968481064, 60.35095699131489, 67.22403198480606, 69.61118549108505, 68.0702693760395, 63.40042635798454, 57.62020692229271, 64.15975481271744, 61.6912704706192, 63.57877358794212, 67.37866088747978, 68.35925906896591, 64.94136527180672, 66.37243688106537, 64.20592233538628, 64.73463356494904, 60.70099040865898, 59.62703123688698, 65.74203550815582, 65.25756910443306, 63.442300111055374, 64.43762630224228, 65.21811202168465, 63.210128769278526, 54.41417455673218, 57.816815972328186, 53.27799752354622, 52.67990581691265, 61.29637286067009, 60.130743607878685, 62.3233475536108, 57.98633247613907, 50.905857011675835, 46.526493206620216, 48.36092837154865, 47.986382469534874, 54.51607748866081, 54.95724901556969, 61.91942922770977, 56.7415002733469, 57.31513649225235, 52.396980598568916, 47.2991057485342, 45.05696766078472, 46.078713834285736, 52.82781668007374, 59.88933876156807, 61.23216010630131, 59.57306273281574, 59.22640733420849, 50.90689055621624, 55.92049352824688, 52.86802992224693, 55.52598349750042, 56.82593934237957, 55.47448866069317, 61.688101440668106, 58.42167891561985, 59.68178249895573, 58.163064792752266, 55.05878336727619, 59.91169676184654, 59.67365473508835, 56.99287958443165, 60.12361899018288, 55.42131811380386, 56.989721953868866, 55.10830610990524, 57.731848731637, 59.04741793870926, 56.213769391179085, 53.87703537940979, 53.416397497057915, 46.90450832247734, 47.80118800699711, 53.24211224913597, 57.34036713838577, 60.0396852940321, 54.79248225688934, 53.694781959056854, 53.70132140815258, 52.75307469069958, 54.83141116797924, 58.697684705257416, 61.04916572570801, 57.96589337289333, 60.870594307780266, 60.703908652067184, 60.8009098470211, 41.70637585222721, 27.664081156253815, 39.598959535360336, 24.761320017278194, 9.091695193201303, 7.761695310473442, 20.315531976521015, 27.31072671711445, 15.642725117504597, 4.242844730615616, 0.583466172683984, 0.25429431872908026, 0.1439582885359414, 0.16120470216264948, 0.1943350353394635, 0.08825534081552178, 0.12534295383375138, 0.12690695584751666, 0.043539889447856694, 0.43512768403161317, 0.30176561675034463, 25.413868501782417, 62.16456927359104, 68.571135699749, 36.36407911777496, 47.57735721766949, 56.40275225043297, 39.97831977903843, 3.7163314456120133, 0.10078559149405919, 23.721465915441513, 10.746863577514887, 7.299307147040963, 4.251849297434092, 0.13588752161012962, 0.1593176432652399, 3.069204082712531, 56.640247106552124, 116.71102613210678, 158.98941189050674, 54.24432747066021, 22.197384797036648, 48.7530293315649, 40.70387564599514, 23.411552645266056, 19.633738361299038, 72.20783695578575, 50.69946728646755, 50.83792045712471, 84.64448601007462, 67.84246399998665, 64.7229377925396, 30.619486570358276, 1.347214027773589, 0.5423824209719896, 0.23590096039697528, 0.3939602477476001, 0.1402905205031857, 0.391844236291945, 0.17128579871496186, 0.3567640733672306, 0.23804932949133217, 24.635161086916924, 68.32478731870651, 81.77939414978027, 82.3055063188076, 79.0397335588932, 73.4644903242588, 77.44634225964546, 78.27778324484825, 80.72384878993034, 76.46690681576729, 75.06351292133331, 75.49048081040382, 71.09802290797234, 67.02439829707146, 63.63478638231754, 67.02063649892807, 77.49102786183357, 72.25297093391418, 72.07935824990273, 71.3916939496994, 77.70838379859924, 75.07836252450943, 70.84515407681465, 61.66595622897148, 64.20456200838089, 59.389460384845734, 61.26419238746166, 71.24183759093285, 71.3380940258503, 72.26604983210564, 63.10399666428566, 59.18248549103737, 63.83965998888016, 63.80730852484703, 65.59030964970589, 69.66363787651062, 71.42298147082329, 71.55049502849579, 66.2698195874691, 67.00448736548424, 67.90794968605042, 64.32880774140358, 61.53343454003334, 70.60135155916214, 67.14829444885254, 68.78945678472519, 65.88555380702019, 70.18987163901329, 69.18080538511276, 56.54741428792477, 57.83622533082962, 57.30929620563984, 54.53446090221405, 65.37381246685982, 61.454151794314384, 65.54276660084724, 60.53946867585182, 53.92694190144539, 45.69199338555336, 51.7717469483614, 51.65018767118454, 56.39509566128254, 58.271985948085785, 66.01731553673744, 61.52814902365208, 61.54992565512657, 55.871001183986664, 49.34759862720966, 49.76396508514881, 49.377556219697, 56.54720909893513, 62.70471788942814, 64.35411438345909, 62.83796153962612, 61.30163177847862, 54.893499836325645, 58.314938843250275, 55.8210376650095, 60.15484571456909, 58.666256591677666, 58.498662784695625, 64.15548384189606, 60.07270932197571, 61.90904438495636, 60.446396470069885, 58.52992370724678, 62.94445842504501, 61.99189893901348, 61.01316265761852, 63.79857659339905, 60.15662021934986, 61.62754409015179, 58.7953432649374, 60.99237397313118, 61.14787682890892, 61.945587024092674, 58.565497398376465, 59.392154440283775, 53.99316094815731, 52.15481959283352, 60.09011998772621, 62.560652419924736, 65.5407527089119, 58.44133526086807, 58.37274134159088, 57.65117906033993, 58.29510770738125, 59.14041414856911, 64.610266238451, 67.33962938189507, 64.73208010196686, 64.3162228167057, 65.38920924067497, 66.19833782315254, 48.945690393447876, 36.834060698747635, 46.810356974601746, 29.510132297873497, 11.050872914493084, 21.41584273427725, 29.075057543814182, 34.70248147845268, 26.694388389587402, 10.552369114011526, 5.421237498521805, 0.5538825038820505, 0.17161516385385767, 0.2736551110865548, 0.27943097928073257, 0.20607388200005516, 0.15215311286738142, 0.30398745846468955, 0.16873036161996424, 0.969488883856684, 0.31153729709330946, 32.631782591342926, 74.06381696462631, 76.77478909492493, 48.2596942037344, 55.055526942014694, 64.9068783223629, 54.05917480587959, 4.691300466656685, 0.3197408787673339, 36.2498040497303, 44.09666799008846, 11.673082876950502, 4.582778764888644, 0.5356521508656442, 0.7267638458870351, 5.567368632182479], [47.81619340181351, 45.15037804841995, 34.08106282353401, 20.08350122720003, 12.172189895063639, 18.748534061014652, 8.044989109039307, 2.89050679653883, 8.910704255104065, 13.581374678760767, 18.900092728435993, 21.957781054079533, 61.14558555185795, 50.489342361688614, 33.03045719861984, 24.171684756875038, 0.6377646059263498, 0.32561364176217467, 0.06256757624214515, 0.1647949602920562, 0.015882913940004073, 0.1682805162272416, 0.11083880555815995, 0.14619816443882883, 0.23115157149732113, 3.7348915496841073, 23.42721540480852, 63.18139851093292, 66.81993886828423, 69.69180196523666, 66.3090942800045, 64.73728582262993, 63.449675515294075, 63.42237398028374, 63.18122752010822, 64.19429495930672, 65.03517463803291, 63.077675476670265, 64.26419600844383, 63.551247864961624, 58.18886540830135, 68.45629826188087, 71.81485444307327, 71.25743195414543, 70.34216746687889, 70.43826431035995, 69.1485147178173, 67.06864312291145, 60.761122182011604, 51.385303884744644, 53.62054154276848, 55.17425537109375, 64.11750867962837, 65.13332337141037, 66.86505004763603, 67.32526615262032, 64.06529188156128, 62.510761097073555, 60.53681641817093, 60.99945679306984, 59.99088451266289, 65.13876467943192, 66.08185887336731, 62.53955215215683, 62.50834442675114, 58.30104298889637, 58.07908929884434, 61.14501938223839, 63.5164949297905, 60.320041850209236, 59.78780820965767, 62.6509203761816, 56.94400280714035, 55.600052922964096, 60.726821422576904, 54.808897376060486, 47.487932816147804, 50.70401184260845, 58.45572888851166, 57.75887668132782, 59.15491797029972, 55.21473079919815, 45.73968082666397, 41.61918953061104, 41.762802824378014, 42.65031740069389, 44.01861637830734, 48.181992173194885, 50.73790222406387, 53.41460779309273, 49.701652228832245, 46.71476170420647, 42.16439187526703, 41.70970447361469, 42.028112187981606, 43.80648136138916, 54.409120827913284, 55.400062054395676, 55.37758246064186, 53.49477209150791, 49.7977414727211, 51.468887999653816, 57.84971460700035, 50.59840030968189, 59.18541133403778, 55.17373859882355, 57.880675345659256, 56.742446422576904, 54.49501521885395, 58.83035458624363, 53.32304410636425, 51.57169908285141, 58.30648049712181, 55.32652460038662, 56.63977213203907, 53.82051721215248, 54.18625898659229, 50.81455551087856, 54.496861919760704, 53.33378233015537, 50.454228445887566, 48.6677011102438, 44.773046895861626, 38.862889632582664, 44.071038365364075, 53.412016332149506, 53.84048894047737, 50.8932226896286, 48.39933671057224, 50.01481242477894, 50.42816944420338, 50.58915160596371, 51.500194519758224, 59.67634119093418, 58.7083925306797, 55.082608088850975, 56.98537118732929, 51.626541540026665, 42.963116616010666, 37.23507598042488, 39.782903864979744, 32.39966444671154, 15.671329032629728, 8.385830819606781, 17.72679928690195, 35.37560395896435, 35.30152693390846, 20.824598260223866, 14.465834219008684, 7.584162186831236, 2.910515572875738, 0.05342128519259859, 0.042849899909924716, 0.041189255425706506, 0.030389848980121315, 0.06556252803420648, 0.02097744418279035, 0.05376602020987775, 0.1831894466886297, 0.07048675208352506, 21.229990907013416, 53.13811182975769, 58.48219446837902, 34.33919057250023, 22.595457136631012, 34.07937191426754, 51.01486176252365, 2.0278666354715824, 0.2167943981476128, 12.248144969344139, 8.211533222347498, 4.854405764490366, 3.6995453713461757, 0.12110064475564286, 0.0706142233684659, 5.041344333440065, 49.79364149272442, 73.15722361207008, 73.42176541686058, 28.36563181132078, 14.52960904687643, 31.322110667824745, 20.86466521024704, 8.302899319678545, 5.811763918027282, 36.08173526823521, 30.667274706065655, 34.50656019151211, 66.94128915667534, 55.343764275312424, 46.510746851563454, 34.49797265231609, 0.4403263394488022, 0.23576948151458055, 0.09607346582924947, 0.12272718755411915, 0.007660362507522223, 0.1742457805084996, 0.0514448791363975, 0.11185890238266438, 0.20967873075278476, 2.316117030568421, 41.47854387760162, 72.96788737177849, 73.98440882563591, 77.44266405701637, 70.3175599873066, 69.5061819255352, 66.81775018572807, 69.31325107812881, 65.88990837335587, 64.55117180943489, 65.41982039809227, 66.9279670715332, 66.24218747019768, 62.77159050107002, 59.760347083210945, 69.90380018949509, 70.79359084367752, 73.42480525374413, 70.92685729265213, 72.57648557424545, 71.68807044625282, 70.38877576589584, 63.2837650179863, 54.71212796866894, 55.02149596810341, 57.51039281487465, 68.60648140311241, 68.41487288475037, 68.06815668940544, 69.17278781533241, 68.0597211420536, 66.4968042075634, 65.82797929644585, 65.77147632837296, 64.87725511193275, 66.96147367358208, 69.5628672838211, 63.59208047389984, 64.2371566593647, 61.049944683909416, 61.84633634984493, 63.33459869027138, 64.25167948007584, 63.41923914849758, 62.456051632761955, 61.4006582647562, 59.53003004193306, 61.40240237116814, 61.53382211923599, 55.335397124290466, 50.528685450553894, 53.220643401145935, 61.19224704802036, 59.53917995095253, 60.026933178305626, 58.054356426000595, 47.36078783869743, 44.50674198567867, 44.20767903327942, 44.98471073806286, 46.61481186747551, 47.76478976011276, 51.717953234910965, 54.106991440057755, 49.562116116285324, 46.80796690285206, 46.25243291258812, 41.63424052298069, 41.8302796036005, 45.48859030008316, 56.5801153331995, 59.20728296041489, 55.11556752026081, 57.37676918506622, 52.50283531844616, 52.01849430799484, 60.557848289608955, 53.84466491639614, 60.052855387330055, 60.306696966290474, 59.385706186294556, 57.73846037685871, 57.630424574017525, 61.266415268182755, 56.647314727306366, 53.29713709652424, 60.051749646663666, 58.65675710141659, 59.52166669070721, 56.853495463728905, 56.18535451591015, 56.63129098713398, 57.429954931139946, 55.149777084589005, 53.34380239248276, 52.51137726008892, 48.569453582167625, 45.819339752197266, 50.4503982514143, 57.78740935027599, 55.80581188201904, 55.74897073209286, 52.317074686288834, 51.03973522782326, 53.94131653010845, 53.87405253946781, 53.126720041036606, 61.89824156463146, 62.28001467883587, 60.28539910912514, 60.40896847844124, 52.31323689222336, 43.04081104695797, 42.332187071442604, 41.54411695897579, 40.27692675590515, 21.541175208985806, 10.8131187222898, 27.94861748814583, 38.14417339861393, 42.13208220899105, 24.892477579414845, 12.52056185156107, 6.050522681325674, 1.65410598507151, 0.1338322920491919, 0.03116061387117952, 0.12908845441415906, 0.046588984623667784, 0.10378340797615238, 0.07205772286397405, 0.10788579253130592, 0.1836483462830074, 0.12311539758229628, 27.587547563016415, 63.494668900966644, 67.96619296073914, 42.43386961519718, 32.20242083072662, 45.198582261800766, 61.26352362334728, 2.0608339039608836, 0.04709174143499695, 16.926248744130135, 15.06015557795763, 12.678197342902422, 8.446458466351032, 0.1651702495291829, 0.34278361417818815, 4.949288573116064, 74.3078550696373, 120.06041720509529, 126.43753901124, 31.541024520993233, 28.06013200432062, 39.45957541465759, 30.952409505844116, 8.321567717939615, 25.06520491093397, 67.20955476164818, 43.750540763139725, 39.80825990438461, 79.22171339392662, 66.15848556160927, 59.49441455304623, 46.121298149228096, 0.6589429476298392, 0.8845668251160532, 0.24222085252404213, 0.24399336834903806, 0.20349812490167096, 0.2983998286072165, 0.1685189682757482, 0.3444401768501848, 0.21862178837182, 4.686595369130373, 52.983403131365776, 74.26262989640236, 76.5893666446209, 78.44901725649834, 74.13124054670334, 72.6216271519661, 73.76206755638123, 76.90274342894554, 71.8795345723629, 73.23751330375671, 73.73024046421051, 73.38819041848183, 73.21441054344177, 68.29403936862946, 66.54245495796204, 74.79289144277573, 76.78570210933685, 76.29913061857224, 73.61687734723091, 75.5275060236454, 73.89315292239189, 73.8932517170906, 68.34326192736626, 57.797076031565666, 58.287523314356804, 62.737635523080826, 72.92626440525055, 71.06165885925293, 70.55009990930557, 70.92872679233551, 68.83769899606705, 68.3307833969593, 65.49689546227455, 67.1198719739914, 68.46268191933632, 70.25097236037254, 72.08304405212402, 67.36989095807076, 69.03000667691231, 65.54845109581947, 63.55866126716137, 68.19124728441238, 67.38082677125931, 66.24429255723953, 63.95915597677231, 65.58309003710747, 61.64197191596031, 62.54955321550369, 64.3955397605896, 61.15753211081028, 53.07539999485016, 56.62014618515968, 63.43370497226715, 62.93562009930611, 62.892982587218285, 59.99354436993599, 50.026257410645485, 47.07367904484272, 44.82129670679569, 44.594125896692276, 48.549679443240166, 51.23240768909454, 53.40221285820007, 57.724974900484085, 51.98279522359371, 49.990748316049576, 46.57848961651325, 44.89012621343136, 44.17022444307804, 47.86067381501198, 56.55248701572418, 60.41765861213207, 59.48580801486969, 60.00224970281124, 55.87915174663067, 56.30893148481846, 61.1208488792181, 53.86836804449558, 64.0077705681324, 60.89279271662235, 64.9060195684433, 59.35910381376743, 59.93085913360119, 67.89004504680634, 57.41489253938198, 55.86942806839943, 64.24259796738625, 61.57694600522518, 62.005768194794655, 58.39740201830864, 59.482217207551, 59.09748025238514, 61.159697994589806, 57.7903275936842, 57.40729674696922, 56.84782236814499, 54.41532589495182, 51.45986348390579, 53.37879851460457, 63.67118842899799, 61.03905826807022, 60.467698127031326, 53.875306472182274, 56.38999633491039, 59.26986560225487, 61.378064677119255, 62.24633328616619, 68.17382141947746, 70.18149688839912, 64.534110724926, 67.36916899681091, 57.795255929231644, 50.385866314172745, 47.799599692225456, 49.293284341692924, 53.231928795576096, 38.4002036601305, 40.463637337088585, 44.35954928398132, 51.19222104549408, 51.11944355070591, 32.05667205154896, 27.40447148680687, 12.974589988589287, 4.127271082252264, 0.41287328756880015, 0.14618122862884775, 0.2755910181440413, 0.11355729249771684, 0.19388428452657536, 0.2290327547234483, 0.21851200988749042, 0.40080546168610454, 0.19204458949388936, 35.839612260460854, 77.74249076843262, 74.92787539958954, 55.3280483186245, 37.42841720581055, 50.13218432664871, 73.63279089331627, 2.7218495216220617, 0.38065113534685224, 24.941217564046383, 40.48897057771683, 18.100936710834503, 10.90001530945301, 0.3459867829224095, 0.37655712221749127, 8.403772506862879], [58.87852840125561, 29.62902221828699, 34.94644358754158, 9.693855531513691, 17.2163175791502, 19.622751250863075, 0.48984222463332117, 3.990438524633646, 13.314280360937119, 16.50764610618353, 14.503345806151628, 23.929259665310383, 53.690237402915955, 51.107580587267876, 30.76844807714224, 25.814224518835545, 0.43596919043920934, 0.07577986063552089, 0.036125028927926905, 0.07024981401627883, 0.024204845904023387, 0.02871221488021547, 0.07964770426042378, 0.031890671962173656, 0.01816296971810516, 1.1310810316354036, 9.77859478443861, 43.44525754451752, 69.40325304865837, 68.31069007515907, 70.7333792746067, 62.209327071905136, 60.1275859773159, 57.93391428887844, 56.186122074723244, 58.45803156495094, 60.7649751752615, 62.23626762628555, 67.82895192503929, 65.95170825719833, 58.8430193066597, 61.292405873537064, 67.61538058519363, 69.08087834715843, 69.03003707528114, 71.24676212668419, 68.53333532810211, 66.05096653103828, 63.030478209257126, 56.9361562281847, 52.56558895111084, 52.8910718858242, 60.19282087683678, 63.79454880952835, 64.05693992972374, 67.54124656319618, 65.70524588227272, 65.64216166734695, 65.07204785943031, 63.88706624507904, 62.93737940490246, 59.85237054526806, 62.32248120009899, 62.43119336664677, 58.00276659429073, 61.63231663405895, 59.62504394352436, 59.30266924202442, 61.56566821038723, 63.954102247953415, 61.52737766504288, 53.3148555457592, 60.96394769847393, 63.23825865983963, 53.753625601530075, 52.28500820696354, 51.94732412695885, 50.173442512750626, 59.783928617835045, 55.600033923983574, 60.02733215689659, 47.2471359372139, 44.71897579729557, 41.61764681339264, 45.174871534109116, 42.33021877706051, 40.60802958905697, 45.076084434986115, 45.98927803337574, 43.06123875081539, 41.463701874017715, 43.09970408678055, 43.93204562366009, 39.75138835608959, 39.774149134755135, 42.098454013466835, 51.30792483687401, 58.931649550795555, 56.157817393541336, 52.4348683655262, 54.49769027531147, 44.23694126307964, 51.20405741035938, 58.1983382999897, 50.499863997101784, 57.27064087986946, 56.99431970715523, 53.661845326423645, 55.4492162168026, 53.4545436501503, 57.701598554849625, 54.835925325751305, 53.22199612855911, 53.992571979761124, 54.01303768157959, 56.460649743676186, 53.323348090052605, 48.874128833413124, 48.626796305179596, 50.835017412900925, 49.082471653819084, 46.40538610517979, 34.99256931245327, 39.17000815272331, 49.19594116508961, 51.04781359434128, 50.6372494250536, 49.01742294430733, 46.890749260783195, 50.1680164039135, 51.56379170715809, 51.69355474412441, 49.98301953077316, 57.36427925527096, 57.61655531823635, 53.18297602236271, 55.362801253795624, 54.37615379691124, 51.561842411756516, 48.59621174633503, 48.17195311188698, 51.25959523022175, 47.92190372943878, 36.30535326898098, 36.254945173859596, 47.45486319065094, 36.84419475495815, 27.927416525781155, 23.430827111005783, 18.2243312895298, 6.194380111992359, 0.6112213677261025, 0.059974920441163704, 0.09811149240704253, 0.07090238446835428, 0.05621756034088321, 0.23931158910272643, 0.023115117073757574, 0.2054441548534669, 0.15743261785246432, 30.619682259857655, 54.9860742688179, 61.264709159731865, 33.838860020041466, 32.63133801519871, 40.45490920543671, 66.33839070796967, 1.4224895322695374, 0.19502045324770734, 10.075394008308649, 7.18821250833571, 8.956347405910492, 7.338433647528291, 0.3215551032917574, 0.4247673915233463, 8.469021655619144, 67.31867730617523, 80.37993684411049, 69.29829508066177, 12.428058665245771, 21.394974254071712, 27.588850893080235, 13.714821618050337, 4.735681135207415, 12.789469622075558, 34.04889754951, 28.48602455109358, 26.4782502874732, 76.96322858333588, 57.78859108686447, 43.023065999150276, 41.43580377101898, 0.6500935193616897, 0.1479168894002214, 0.026533551317697857, 0.035826670718961395, 0.04735972725029569, 0.08006882853806019, 0.12029811594402418, 0.17754519096342847, 0.08500652998918667, 1.6363459755666554, 8.075916599482298, 62.01874069869518, 72.90863335132599, 73.13435643911362, 72.08715543150902, 66.33648321032524, 63.95113840699196, 61.539578810334206, 63.41622211039066, 61.88670918345451, 63.95721048116684, 67.15487569570541, 70.45354709029198, 66.98714509606361, 60.608887150883675, 63.21369677782059, 68.90903636813164, 70.19693166017532, 72.78573274612427, 73.04877743124962, 71.33256912231445, 70.75160309672356, 66.12997949123383, 59.91678848862648, 55.37705048918724, 55.332573875784874, 63.43121990561485, 66.87913969159126, 67.15071871876717, 69.2491789162159, 68.04216608405113, 67.60148093104362, 66.65344700217247, 66.90385356545448, 65.58838695287704, 61.95427715778351, 64.4726300239563, 67.19415798783302, 60.384448394179344, 63.99548202753067, 59.82409626245499, 64.21910762786865, 64.59879085421562, 65.75579836964607, 62.343140691518784, 58.0801722407341, 63.227748423814774, 62.98493765294552, 55.909394323825836, 57.26966813206673, 55.55565990507603, 54.65264976024628, 59.929844588041306, 59.270747154951096, 61.696787774562836, 48.18690910935402, 47.32017941772938, 44.05223697423935, 47.912799417972565, 43.739943131804466, 42.19276875257492, 45.13785772025585, 47.04329587519169, 44.17489439249039, 42.93289303779602, 42.82940939068794, 45.402448922395706, 41.80066019296646, 40.660633966326714, 42.814267203211784, 51.97771489620209, 58.4945248067379, 59.57385689020157, 56.106459349393845, 57.13926672935486, 50.208446234464645, 53.97597447037697, 59.264469891786575, 54.176801294088364, 56.262091398239136, 60.023638755083084, 58.11491757631302, 58.58882054686546, 57.002557665109634, 60.28173230588436, 56.787964180111885, 56.81319862604141, 58.2830623537302, 56.939093470573425, 57.39559717476368, 55.45429274439812, 49.90442834794521, 51.141554564237595, 54.338342025876045, 50.63066437840462, 48.75642254948616, 44.75920803844929, 49.219845682382584, 54.024927243590355, 54.78900924324989, 54.74115081131458, 51.0569217056036, 48.95284540951252, 51.81557759642601, 54.55188296735287, 55.833880975842476, 53.578914776444435, 59.044404700398445, 59.65599328279495, 56.54466323554516, 55.48741936683655, 56.540852040052414, 53.32913137972355, 51.241823583841324, 55.445226430892944, 54.93981555104256, 51.50250479578972, 38.131615072488785, 37.5891599804163, 51.99117757380009, 41.91898584365845, 31.138063743710518, 27.44661882519722, 19.577655270695686, 7.181688258424401, 0.09926288257702254, 0.07843659346690401, 0.09755166815011762, 0.09656710535637103, 0.07362634103628807, 0.11997076202533208, 0.1481635050731711, 0.16965809074463323, 0.15523266949458048, 36.99566602706909, 67.77967616915703, 69.745082706213, 42.10985720157623, 37.467843890190125, 47.45574854314327, 72.89722636342049, 1.1892909393645823, 0.031588929559802637, 15.696507431566715, 11.596430540084839, 18.43198824673891, 13.909912649542093, 0.1792461340664886, 0.3737887035822496, 7.144251242280006, 93.4495635330677, 104.67393323779106, 84.40941542387009, 15.829956270754337, 36.09249249100685, 39.01485487818718, 19.583852738142014, 12.784096710383892, 26.011135652661324, 63.79046022891998, 35.31620554625988, 38.648406341671944, 70.83620935678482, 66.74702078104019, 54.92791458964348, 59.15340945124626, 0.8015474549029022, 0.3343117015901953, 0.17718048475217074, 0.2565696247620508, 0.16439400758827105, 0.22399474459234625, 0.1436689103138633, 0.4142056801356375, 0.15214659681078047, 1.3587882067076862, 24.570936933159828, 69.71300482749939, 74.19709101319313, 77.82893612980843, 76.9125697016716, 73.74142706394196, 68.64992067217827, 69.75582852959633, 67.70864278078079, 70.13785243034363, 71.04306265711784, 73.6403600871563, 78.56354311108589, 72.93644785881042, 67.13729783892632, 67.94554486870766, 70.42884841561317, 73.47459018230438, 76.36824890971184, 76.0670618712902, 74.46758329868317, 75.32644361257553, 70.54453700780869, 64.39165636897087, 59.7226607054472, 59.14008356630802, 66.3309659063816, 70.2490496635437, 67.42523118853569, 72.79855325818062, 69.99224424362183, 70.50645545125008, 68.39446797966957, 69.35239657759666, 68.74312207102776, 66.76924958825111, 66.80128186941147, 68.59589517116547, 61.77725985646248, 67.98312485218048, 64.65051367878914, 66.29160761833191, 66.41784444451332, 68.45190569758415, 66.66271090507507, 61.293393820524216, 66.92945659160614, 65.8743292093277, 60.882392674684525, 59.558323323726654, 56.11378535628319, 56.985553577542305, 63.06086517870426, 61.9371172785759, 65.91936439275742, 52.788830772042274, 48.63010212779045, 46.49552866816521, 48.244350627064705, 46.301917657256126, 41.65586896240711, 46.94018840789795, 47.83561795949936, 47.48616211116314, 44.73149612545967, 45.631876811385155, 47.20393605530262, 43.69299665093422, 43.351752161979675, 45.675791054964066, 55.11327624320984, 62.26148687303066, 63.59801195561886, 59.66141939163208, 59.17369656264782, 51.41126409173012, 56.54354229569435, 63.535942286252975, 54.88897807896137, 62.41842605173588, 63.05014215409756, 60.377734154462814, 58.519645258784294, 61.210197284817696, 63.314649760723114, 60.50853073596954, 58.9660757035017, 60.50040677189827, 58.547531962394714, 65.03114685416222, 56.76479682326317, 55.02962753176689, 55.68038821220398, 59.08947788178921, 57.727152183651924, 58.192733600735664, 51.35382257401943, 53.11331816017628, 58.91082286834717, 59.959600791335106, 59.081904888153076, 55.51166966557503, 51.709027513861656, 58.76192405819893, 60.2411162853241, 61.46384507417679, 59.98580798506737, 66.54943898320198, 68.61477255821228, 62.368017956614494, 64.23299208283424, 63.618777841329575, 62.08369441330433, 62.70535625517368, 69.24473315477371, 66.9406507909298, 66.8515607714653, 54.94266539812088, 53.949869871139526, 58.586179688572884, 49.74788434803486, 41.40461124479771, 33.34207847714424, 27.287304773926735, 10.482828095555305, 0.5707274749875069, 0.12855085748014972, 0.1637162041151896, 0.15376958472188562, 0.22680113150272518, 0.46536334441043437, 0.2823198336409405, 0.2801944414386526, 0.30161697941366583, 41.781858801841736, 77.77237236499786, 78.89188349246979, 55.71680925786495, 46.40114553272724, 57.16696344316006, 85.841915756464, 2.7362388744950294, 0.43646764650475234, 25.11982887983322, 36.524343118071556, 28.388438187539577, 17.835615947842598, 0.2891825622646138, 0.6211926264222711, 9.290642067790031], [74.13473635911942, 35.98619319498539, 10.320827588438988, 3.6261418601498008, 15.433919671922922, 18.31146251410246, 1.9734154385514557, 6.17083752527833, 9.51792212203145, 17.319388948380947, 26.12368181347847, 39.236424788832664, 23.563563488423824, 41.86711102724075, 32.95641057193279, 25.077155269682407, 1.2985095474869013, 0.3090563270961866, 0.06659189428319223, 0.05172070574190002, 0.07504903071094304, 0.061485257756430656, 0.14445077773416415, 0.19867434311890975, 0.1407814066624269, 1.2747964449226856, 7.07979055121541, 20.155264176428318, 67.29431301355362, 73.29650893807411, 72.40954533219337, 65.80563649535179, 58.178560361266136, 56.20586201548576, 53.4295067936182, 54.15941342711449, 58.27588453888893, 61.641546338796616, 64.7199435532093, 66.2713623046875, 63.76776024699211, 56.76459543406963, 62.644149139523506, 72.21175074577332, 68.72757330536842, 71.7791211605072, 64.98621046543121, 68.72375831007957, 65.33114835619926, 58.394293785095215, 50.17139442265034, 51.158019080758095, 56.03236332535744, 65.04110231995583, 64.52265053987503, 67.07881897687912, 68.26222747564316, 66.13768547773361, 64.77458462119102, 63.58097366988659, 64.41794335842133, 63.86194199323654, 59.86428290605545, 59.17415253818035, 60.54861478507519, 59.96035695075989, 61.63815692067146, 60.634535774588585, 59.935168102383614, 60.69529831409454, 56.78079396486282, 59.87872593104839, 61.36030822992325, 53.658596500754356, 55.86531288921833, 57.35288746654987, 52.574263885617256, 58.32083232700825, 58.64808216691017, 57.23288230597973, 49.75446179509163, 44.372791573405266, 41.113482266664505, 43.46373975276947, 44.47616122663021, 42.190876454114914, 42.795488610863686, 41.81893341243267, 40.530566945672035, 37.750655114650726, 39.06629651784897, 39.509854316711426, 42.951375246047974, 42.90495693683624, 39.50192414224148, 39.1123728454113, 50.64795725047588, 53.12904551625252, 56.773437559604645, 52.615047097206116, 55.42641744017601, 50.584116876125336, 47.80669391155243, 55.00620558857918, 57.65275597572327, 51.39219671487808, 57.925429344177246, 56.694306805729866, 59.502131938934326, 54.46861423552036, 54.359924867749214, 54.408588856458664, 51.58022202551365, 51.719495952129364, 54.243096336722374, 51.65944017469883, 47.740455865859985, 44.62566040456295, 47.37633280456066, 39.191123619675636, 34.36121039092541, 33.3396390080452, 37.25734658539295, 48.57122428715229, 50.36219738423824, 50.529946982860565, 49.40027140080929, 46.040510684251785, 47.18124747276306, 51.402300372719765, 52.28849641978741, 52.853058725595474, 51.44685298204422, 53.58297295868397, 52.73743852972984, 48.94773468375206, 59.626643657684326, 56.62404477596283, 52.913977056741714, 53.53400118649006, 53.410276025533676, 60.909834802150726, 56.57402046024799, 56.37774579226971, 60.56651562452316, 68.03445249795914, 41.77349165081978, 32.19895161688328, 25.53552657365799, 17.287324368953705, 3.663913020864129, 0.8890912542119622, 0.40546416013967246, 0.2204928910941817, 0.06429723303881474, 0.04998246229661163, 0.0975126979756169, 0.20263594225980341, 0.23416711046593264, 0.16776721720816568, 17.604835331439972, 57.14138701558113, 54.49556238949299, 39.661952555179596, 36.29227437078953, 38.88006471097469, 61.831357553601265, 1.364241389092058, 0.19063290586927906, 3.511757547967136, 8.225556369870901, 13.312794640660286, 8.110194560140371, 0.105625975120347, 0.5098526040092111, 11.789169497787952, 86.69768303632736, 67.11493223905563, 37.528393641114235, 2.7807354368269444, 21.56710311770439, 26.522895991802216, 4.879138637334108, 10.034768488258123, 13.04807709529996, 31.652204655110836, 30.708187110722065, 33.24307478964329, 43.45085084438324, 50.37000976502895, 44.597066938877106, 46.70443005859852, 1.6244140220806003, 0.23221996729262173, 0.005542088892980246, 0.15910917398286983, 0.03431083408941049, 0.0356770797225181, 0.16280836454825476, 0.05722068795876112, 0.048856835783226416, 0.2585651708068326, 2.687402945011854, 37.941914051771164, 75.56719109416008, 73.34158211946487, 74.89883735775948, 68.70404496788979, 62.25153140723705, 60.12529470026493, 58.48662123084068, 60.94558708369732, 62.94180616736412, 66.44841000437737, 66.99564903974533, 70.95921635627747, 66.50473818182945, 57.094672322273254, 62.75552496314049, 73.44315826892853, 71.3311479985714, 73.43251124024391, 66.96456670761108, 70.89522019028664, 69.38709631562233, 60.553337931632996, 54.42420221865177, 52.61567786335945, 60.361338034272194, 68.68160337209702, 67.3819287121296, 70.25417938828468, 71.16226986050606, 68.12588319182396, 66.27379417419434, 66.92729070782661, 67.20621094107628, 67.40254640579224, 65.22251218557358, 65.06070926785469, 62.16053768992424, 60.7334178686142, 61.836160495877266, 62.76552602648735, 60.8611024171114, 62.82201759517193, 57.560158744454384, 63.38170476257801, 60.83038106560707, 57.3079738765955, 59.355657398700714, 56.457948088645935, 55.93956470489502, 61.06940343976021, 61.197205781936646, 58.777442425489426, 53.78618985414505, 47.94822871685028, 43.6580765247345, 46.055466681718826, 46.69430360198021, 42.654546573758125, 43.07195797562599, 42.898991256952286, 39.17306698858738, 38.72482404112816, 39.64309796690941, 39.624779149889946, 44.21749770641327, 46.36653319001198, 38.890673741698265, 41.633275374770164, 52.45458170771599, 54.74522799253464, 57.93160021305084, 57.10162214934826, 57.67366625368595, 53.658311516046524, 52.837787345051765, 57.38110475242138, 59.51192781329155, 54.999016374349594, 59.81005601584911, 59.93746317923069, 61.40403248369694, 56.76803804934025, 57.548953145742416, 58.59994634985924, 55.75787365436554, 55.183006301522255, 56.66297748684883, 55.97921557724476, 50.828595757484436, 50.358769968152046, 50.95646269619465, 43.93041931092739, 42.49583289027214, 43.538014367222786, 44.694223925471306, 50.66281445324421, 55.357846319675446, 54.85312320291996, 53.41648109257221, 49.40035119652748, 51.078090369701385, 53.87183725833893, 55.674768313765526, 55.032743364572525, 54.26375202834606, 55.698589235544205, 55.244961977005005, 53.695553317666054, 61.15602359175682, 61.74328587949276, 59.96150828897953, 58.391025960445404, 59.06916797161102, 66.46990165114403, 62.10023872554302, 61.333679258823395, 65.94813644886017, 72.09349349141121, 47.12549306452274, 33.86932298541069, 27.672427408397198, 25.411482229828835, 6.94757997058332, 0.7799992861691862, 0.06034148944308981, 0.13522606022888795, 0.06379099184414372, 0.032160123519133776, 0.37357529159635305, 0.8980175689794123, 0.3015071415575221, 0.018618219801282976, 30.047907941043377, 69.53187614679337, 64.18413430452347, 47.4673493206501, 40.23479461669922, 46.06889896094799, 76.949952095747, 1.7817270057275891, 0.2972325193695724, 6.590768191963434, 13.015743680298328, 19.80260320007801, 16.41768593341112, 0.11695949782733805, 0.14744562562555075, 9.553881492465734, 114.36497882008553, 95.269475877285, 38.96055579185486, 8.245248813182116, 38.13493609428406, 36.56798377633095, 6.906726462766528, 18.62746685743332, 24.80172324925661, 59.700500294566154, 46.966570392251015, 57.2837083786726, 31.918234080076218, 58.778377175331116, 57.90213279426098, 66.26649856567383, 3.540697507560253, 0.33781805250328034, 0.08436437929049134, 0.23446086735930294, 0.19479538954328746, 0.11827350739622489, 0.20116130966925994, 0.4640446073608473, 0.15548229828709736, 3.4118592459708452, 15.809791702777147, 54.32913891971111, 78.560890853405, 78.46323609352112, 80.92543557286263, 74.15476128458977, 67.36108303070068, 65.33304065465927, 64.19335260987282, 68.35515528917313, 69.60292473435402, 75.33251568675041, 74.65699553489685, 77.0294438302517, 74.01194974780083, 60.885155126452446, 67.50062674283981, 77.27674216032028, 76.79614394903183, 75.64026117324829, 70.68993240594864, 74.98525232076645, 71.94751292467117, 62.41970658302307, 57.45583534240723, 56.21456354856491, 62.40451879799366, 72.36072555184364, 69.64586243033409, 72.28938058018684, 71.93555116653442, 71.68122321367264, 68.76677960157394, 70.4071743786335, 69.30564388632774, 68.21395486593246, 68.30750584602356, 66.91356584429741, 63.80429908633232, 65.68500816822052, 66.8753170967102, 64.70386281609535, 65.44021010398865, 66.85065641999245, 59.94968332350254, 64.26750183105469, 64.07561212778091, 60.17575979232788, 60.417540818452835, 59.91491138935089, 57.08690173923969, 61.87519960105419, 63.20183381438255, 62.15351566672325, 54.85045574605465, 50.45465402305126, 45.580271780490875, 47.82169550657272, 48.86222407221794, 45.05041301250458, 43.54884758591652, 44.230151027441025, 41.82311698794365, 40.40323957800865, 39.67642977833748, 40.96688613295555, 45.156165137887, 47.59877286851406, 41.50165803730488, 44.18389990925789, 54.926626458764076, 56.56696043908596, 64.37554523348808, 59.94029402732849, 62.19989597797394, 54.846952334046364, 55.71832537651062, 62.92512506246567, 62.25464724004269, 57.108659371733665, 64.1647781431675, 61.91757492721081, 63.93619000911713, 58.94045747816563, 59.656981229782104, 62.50383786857128, 55.53715869784355, 58.093741312623024, 59.925315231084824, 60.102180540561676, 54.19331520795822, 51.732324063777924, 53.870495930314064, 51.31845787167549, 48.61290045082569, 47.87507124245167, 48.33549253642559, 55.36057077348232, 60.56559607386589, 59.196331948041916, 57.4832546710968, 54.03523989021778, 55.32797992229462, 57.761471942067146, 61.6139218211174, 61.17712385952473, 62.21180833876133, 61.4966145157814, 66.15659326314926, 62.02608950436115, 69.62601229548454, 69.74699780344963, 71.1792853474617, 69.95481625199318, 64.86145555973053, 70.14992818236351, 61.89949929714203, 61.83589071035385, 65.97881600260735, 73.34200769662857, 55.18666550517082, 48.70073653757572, 34.3281027674675, 28.81251633167267, 9.004349280148745, 1.923316433094442, 0.4177238163538277, 0.4741260007722303, 0.23774081870215014, 0.14848265826003626, 0.33622380055021495, 0.3811953077092767, 0.3937986079836264, 0.2295050723478198, 44.85149368643761, 75.04177808761597, 78.05345848202705, 57.62539364397526, 53.64521361887455, 54.014181420207024, 91.03511229157448, 2.927971836179495, 0.5617747991345823, 14.927009772509336, 37.8632240742445, 29.955569095909595, 21.705664582550526, 0.262161351274699, 0.39929338032379746, 11.039411779493093], [71.76500871777534, 31.84038955718279, 1.8855686648748815, 4.213223420083523, 15.961288623511791, 13.808180708438158, 2.339821346104145, 1.499165736604482, 5.661705220118165, 17.17490930110216, 38.09872403740883, 47.07633890211582, 34.3082070350647, 29.152066111564636, 34.87833984196186, 26.734951213002205, 1.5829314105212688, 0.11989027610979974, 0.23436186485923827, 0.083206866402179, 0.1505722344154492, 0.16712911863578483, 0.12413290431140922, 0.3230026474921033, 0.30245723901316524, 0.9878787095658481, 8.781980462372303, 20.434630885720253, 70.08916184306145, 78.00447151064873, 77.0859543979168, 67.76354223489761, 64.2014841735363, 52.55887471139431, 52.37677328288555, 53.895209804177284, 57.20150738954544, 59.863359555602074, 60.80768868327141, 63.92051964998245, 64.41341400146484, 57.861011400818825, 56.27536788582802, 65.06156042218208, 69.10319074988365, 73.13304930925369, 66.38865441083908, 65.03817647695541, 65.75606435537338, 63.00906255841255, 50.80817945301533, 48.38376894593239, 56.617326736450195, 61.6248120367527, 62.21112817525864, 66.71981424093246, 65.66228538751602, 61.57151609659195, 59.74682740867138, 59.08915489912033, 61.95321321487427, 62.551783695816994, 63.591620698571205, 56.814984530210495, 55.3094445168972, 60.65518766641617, 61.37065127491951, 58.9509829133749, 63.14272798597813, 59.02703583240509, 61.3727031648159, 60.30545063316822, 56.50544933974743, 56.59625306725502, 57.3449344933033, 52.551297917962074, 56.2216729670763, 59.97635029256344, 58.56677033007145, 56.65762737393379, 49.08623345196247, 39.87489312887192, 41.87613554298878, 45.74112854897976, 50.53922228515148, 39.40328523516655, 40.41268587112427, 36.3024578243494, 36.897790879011154, 35.30169032514095, 38.5308862477541, 37.42967873811722, 43.908255100250244, 46.0405220836401, 41.219496577978134, 37.45894476771355, 51.32902890443802, 57.66585387289524, 51.40845984220505, 54.38207007944584, 55.65256990492344, 53.26097443699837, 47.68434427678585, 51.83552272617817, 54.431931003928185, 55.483326986432076, 49.66114640235901, 57.28918768465519, 56.3687364757061, 53.852591291069984, 53.39387230575085, 54.28994782269001, 53.98004025220871, 53.11949282884598, 53.05722177028656, 50.72174169123173, 49.42845068871975, 49.634224846959114, 39.422394409775734, 35.49210950732231, 46.15353561937809, 50.060128793120384, 51.68219335377216, 48.32699999213219, 50.54977431893349, 50.573473647236824, 49.85633432865143, 45.340329855680466, 48.43175657093525, 52.156521901488304, 55.92199444770813, 57.88287542760372, 52.88496181368828, 52.76018790900707, 53.24270881712437, 52.78717406094074, 49.295556619763374, 39.67546842992306, 47.47179888188839, 54.65665854513645, 62.82183140516281, 62.28101782500744, 62.42116950452328, 53.55311416089535, 57.757010981440544, 62.676219418644905, 57.76614189147949, 39.73615117371082, 34.969318360090256, 18.432645611464977, 6.043992731720209, 1.0717413970269263, 0.3399646404432133, 0.16561754193389788, 0.1378518232377246, 0.08322122695972212, 0.035666916010086425, 2.4368828628212214, 0.26052755769342184, 1.204717280343175, 37.515257745981216, 50.66999986767769, 64.03937727212906, 38.76130968332291, 45.92787332832813, 43.74236740171909, 53.47514234483242, 1.0903994645923376, 0.1661761713330634, 1.3271672534756362, 7.908496633172035, 14.515516553074121, 8.604196552187204, 0.06606197115615942, 0.7262046227697283, 9.461636692285538, 93.68935346603394, 60.83815164864063, 3.665075758472085, 4.748399527743459, 25.753393582999706, 24.03472300618887, 1.545341215096414, 6.3050315994769335, 8.767092861235142, 29.702394381165504, 49.602557346224785, 44.06300939619541, 18.65843139588833, 33.39519202709198, 47.714765444397926, 51.66423551738262, 3.525674776174128, 0.18628834368428215, 0.12004784890450537, 0.11324511549901217, 0.08900477638235316, 0.01442123182641808, 0.04892201490292791, 0.18301695672562346, 0.3137435537064448, 1.9659908744506538, 7.603845605626702, 36.24565087258816, 79.92643117904663, 75.94783186912537, 79.50010165572166, 70.22494375705719, 67.0811216533184, 57.023456543684006, 57.07761123776436, 57.72746376693249, 64.4439947605133, 64.39465820789337, 66.10959738492966, 69.09972533583641, 69.98165041208267, 61.839633509516716, 55.32973922789097, 65.23137331008911, 71.19972065091133, 72.51781672239304, 67.32026562094688, 66.32979556918144, 69.6706523001194, 65.86865231394768, 54.734618961811066, 51.115107983350754, 58.30090619623661, 66.73658654093742, 63.37634325027466, 69.10350233316422, 66.94521814584732, 64.05025228857994, 62.97422222793102, 63.456986322999, 63.200994059443474, 64.70943331718445, 67.50677481293678, 62.31586955487728, 59.241283535957336, 62.460972368717194, 64.74170118570328, 60.06316043436527, 64.34971421957016, 60.778548046946526, 64.21029970049858, 60.933724120259285, 58.938671573996544, 57.78895206749439, 60.1371044665575, 56.6192152351141, 58.184313252568245, 63.042679354548454, 58.5170803964138, 58.57960984110832, 50.71302115917206, 40.857983976602554, 44.94810350239277, 50.09396217763424, 53.44925053417683, 41.49632312357426, 39.992816001176834, 37.63737179338932, 38.51560726761818, 37.77238614857197, 38.499781116843224, 38.20619747042656, 47.19710022211075, 49.38842363655567, 44.65683773159981, 39.00587975978851, 52.28606455028057, 55.08977450430393, 55.21499678492546, 57.011278197169304, 57.07943134009838, 57.343327179551125, 50.958430990576744, 51.94064028561115, 56.746656596660614, 58.59303072094917, 53.525713831186295, 56.866760551929474, 59.00353029370308, 57.21163384616375, 55.86621344089508, 56.995801627635956, 57.4975761026144, 56.03860259056091, 55.08265748620033, 53.37546229362488, 52.50408165156841, 49.80814911425114, 43.751065135002136, 46.07863023877144, 53.63311506807804, 55.62232732772827, 55.32367095351219, 51.124858260154724, 53.8512347638607, 54.36571955680847, 52.79294595122337, 48.80270406603813, 49.730884060263634, 54.55495700240135, 55.48803873360157, 58.945336416363716, 56.04381211102009, 56.474712789058685, 56.6479454934597, 54.927963986992836, 55.39647124707699, 48.686494901776314, 55.87520755827427, 61.66067451238632, 68.36973130702972, 63.71735595166683, 66.47689327597618, 59.939138889312744, 62.104768082499504, 66.58342435956001, 61.75908923149109, 48.073542192578316, 33.23636814951897, 17.53850419074297, 9.0304652787745, 1.6643172246403992, 0.5847404105588794, 0.04879133382928558, 0.1550908450735733, 0.170886552950833, 0.38778765709139407, 3.52194313891232, 0.2719396218890324, 2.3296630661934614, 50.222482681274414, 61.333645060658455, 74.1505891084671, 48.028085231781006, 49.69614252448082, 44.795488491654396, 69.7997997701168, 1.2518758373335004, 0.12800246971892193, 5.097226509824395, 12.58430153131485, 18.967145830392838, 15.13963496312499, 0.11913417605683208, 0.2222054117009975, 9.391792640089989, 108.37170481681824, 77.804906219244, 21.482133977115154, 10.953092761337757, 42.80104011297226, 33.812310844659805, 4.040631931275129, 12.002793084830046, 25.18926825374365, 59.34213772416115, 55.08792780339718, 68.78658413887024, 51.52226373553276, 45.823994502425194, 63.81366178393364, 73.9075617492199, 7.416891362518072, 0.3971213515615091, 0.28670764819253236, 0.4083160258596763, 0.2101035657688044, 0.15903212421108037, 0.2622572664404288, 0.6475189793854952, 0.4156598442932591, 7.225992931053042, 18.797492533922195, 50.354027822613716, 87.43173524737358, 78.32722619175911, 85.20643025636673, 74.6803566813469, 74.38445895910263, 61.33856579661369, 62.77292042970657, 65.27505576610565, 71.43428966403008, 73.16920816898346, 72.44856923818588, 77.74498343467712, 76.59481555223465, 66.03490859270096, 59.742408245801926, 69.15275529026985, 74.29913833737373, 77.96221017837524, 69.5033472776413, 69.47641432285309, 70.07238954305649, 69.01521787047386, 58.255323842167854, 52.60126903653145, 61.61847397685051, 68.26107233762741, 65.55282086133957, 72.03467264771461, 69.74566787481308, 65.98489567637444, 64.96259853243828, 64.59367632865906, 66.5822160243988, 69.77886289358139, 70.53458154201508, 66.25347286462784, 64.12612661719322, 64.21138644218445, 66.37485355138779, 63.86369749903679, 68.06720674037933, 63.93049791455269, 68.5954999923706, 65.23143410682678, 62.463639825582504, 61.905746161937714, 60.992111787199974, 58.472455590963364, 61.97712533175945, 65.13018473982811, 62.088330164551735, 60.127802565693855, 53.79482679069042, 45.26227064430714, 46.18817076086998, 50.72215586900711, 53.901479467749596, 40.62515527009964, 41.50340594351292, 38.33439499139786, 37.62760631740093, 36.77888385951519, 40.30333153903484, 37.467646300792694, 46.61295376718044, 51.073409020900726, 48.41263219714165, 42.17308200895786, 54.530315324664116, 58.53597678244114, 56.31661467254162, 60.7457672059536, 62.083629816770554, 59.743711575865746, 53.5461263358593, 58.59282933175564, 59.55909088253975, 60.288286954164505, 55.76745294034481, 62.168946638703346, 61.76975145936012, 59.9734016507864, 57.408353090286255, 57.28755757212639, 60.72992205619812, 58.55385102331638, 58.42941150069237, 56.020751148462296, 52.111699506640434, 53.4231573343277, 50.6113538146019, 48.30456979572773, 55.95796711742878, 58.89504611492157, 59.46310803294182, 55.6027165800333, 58.65726627409458, 59.32371251285076, 58.51903349161148, 53.001839742064476, 55.72337910532951, 59.673145562410355, 62.23745696246624, 65.9371854364872, 62.5376408547163, 65.54791152477264, 66.31610110402107, 64.46652755141258, 62.22597777843475, 60.03625027835369, 66.2940014898777, 69.79266375303268, 72.48740315437317, 69.12124738097191, 69.21932771801949, 62.45808832347393, 61.535608023405075, 68.29708680510521, 64.35507193207741, 57.739379927515984, 44.973011165857315, 31.714920289814472, 16.61355022341013, 6.131401816383004, 0.7387278601527214, 0.3056800301419571, 0.3744434262625873, 0.3314065793529153, 0.7493723358493298, 5.598493712022901, 0.5089673108886927, 2.6846053451299667, 72.44717091321945, 66.88892036676407, 90.65163686871529, 54.338171035051346, 66.57439604401588, 58.48311401903629, 84.39342588186264, 2.2394806053489447, 0.3430832934100181, 15.097093395888805, 31.32929228246212, 32.80655801296234, 21.479272730648518, 0.1918778585968539, 0.797702120617032, 8.968791738152504], [61.977509111166, 39.590288400650024, 2.661877339705825, 5.674644950777292, 24.642796777188778, 12.568047903478146, 2.210297458805144, 1.8088840297423303, 3.279326632618904, 22.252109460532665, 21.954541727900505, 51.147831827402115, 99.4547688961029, 32.29274578392506, 41.31503865122795, 23.302131816744804, 1.495832484215498, 0.15859887324040756, 0.2567600895417854, 0.06515749351819977, 0.06232278625248, 0.060177845880389214, 0.0187542591811507, 0.12869400292402133, 0.09819654995226301, 1.1580295418389142, 5.096067572012544, 36.95042945444584, 79.855055809021, 74.36707869172096, 80.5130361020565, 68.42985928058624, 67.21811950206757, 53.06281507015228, 52.75177516043186, 50.5219180136919, 58.68679068982601, 58.42913031578064, 56.79109901189804, 58.99845376610756, 65.60768231749535, 61.389616057276726, 55.46243570744991, 61.47897966206074, 66.36571884155273, 69.63076964020729, 63.49851809442043, 65.00289916992188, 64.87335652112961, 65.69658234715462, 51.697654724121094, 52.584895715117455, 56.233851313591, 61.483129039406776, 61.23366862535477, 64.8452228307724, 63.94035458564758, 60.81491209566593, 57.647858038544655, 56.64791129529476, 61.14096499979496, 62.0093210041523, 62.712534070014954, 60.10988272726536, 59.26883205771446, 56.40479654073715, 60.70960454642773, 58.69666635990143, 62.743620201945305, 62.10406892001629, 60.573290660977364, 54.761202335357666, 56.70057646930218, 54.57484893500805, 56.979276314377785, 54.59439128637314, 57.56083130836487, 59.598232582211494, 58.650658428668976, 55.88433466851711, 44.54433336853981, 40.90419329702854, 43.173268139362335, 50.77214978635311, 55.458981692790985, 48.658000230789185, 38.012822046875954, 35.77196069061756, 39.18688304722309, 37.56950743496418, 37.77519039809704, 40.14810226857662, 53.446111902594566, 50.06574109196663, 45.84657669067383, 36.92405126988888, 42.69115000963211, 40.272488594055176, 49.54498663544655, 58.50646756589413, 57.71480284631252, 53.542049154639244, 51.544108763337135, 51.333030089735985, 51.10960967838764, 56.86383090913296, 54.619830921292305, 52.48267740011215, 55.4201477766037, 54.351504519581795, 53.26470963656902, 52.93506592512131, 51.77484758198261, 52.16218739748001, 51.84121862053871, 52.723394483327866, 49.63533438742161, 40.39332590997219, 41.22047692537308, 51.81481383740902, 52.90703482925892, 50.47936789691448, 50.205539390444756, 50.08644238114357, 51.42115876078606, 50.509906858205795, 47.71707572042942, 46.972076296806335, 50.44322423636913, 57.63527311384678, 57.12083391845226, 61.17757983505726, 53.23797047138214, 53.448596969246864, 56.92585498094559, 47.27545961737633, 34.60215166211128, 33.624008148908615, 50.96355311572552, 58.75104904174805, 62.55569748580456, 63.83996397256851, 60.33820867538452, 53.75871732831001, 55.05062520503998, 58.6198078840971, 67.90800288319588, 57.162365689873695, 46.35254234075546, 36.972506269812584, 15.534783359616995, 4.807557603344321, 1.6342765116132796, 0.5162036069668829, 0.19459474249742925, 0.23457116534700617, 0.3865768579998985, 4.335234872996807, 0.2879710210254416, 4.502211213111877, 44.71676051616669, 61.08820103108883, 64.5262223482132, 40.602109506726265, 46.84360519051552, 38.82860027253628, 56.837992295622826, 3.384933890774846, 0.14494394970824942, 1.9040426798164845, 5.727936616167426, 12.470198404043913, 6.032605692744255, 0.10595713625662029, 0.30422360985539854, 5.514093115925789, 89.69737127423286, 59.51345533132553, 8.278162647038698, 8.754752073436975, 25.556558445096016, 22.77161568403244, 1.959744959603995, 1.4896094868890941, 1.9627453736029565, 34.65248756110668, 33.396354764699936, 54.8083122074604, 84.28895428776741, 35.61017297208309, 53.12103174626827, 45.801169127225876, 4.497578786686063, 0.30597507837228477, 0.21514386171475053, 0.10539390554185957, 0.08745689381612465, 0.0272078574198531, 0.034100925040547736, 0.13526992115657777, 0.15819990949239582, 3.4509914461523294, 11.737670861184597, 45.992515459656715, 82.72194117307663, 74.86151576042175, 82.13285118341446, 72.58695781230927, 72.68160313367844, 56.40856973826885, 56.3637625426054, 55.287409499287605, 64.03831332921982, 63.79549875855446, 64.29233729839325, 66.62263825535774, 71.08019426465034, 65.04027396440506, 55.30646167695522, 62.582569643855095, 68.70831593871117, 71.39136716723442, 66.01458728313446, 66.79524019360542, 70.39878442883492, 69.0993681550026, 55.576281398534775, 54.75710615515709, 56.140486523509026, 66.54763787984848, 65.93275487422943, 66.04887664318085, 65.43480679392815, 63.04096944630146, 62.40353085100651, 59.978037402033806, 63.975677490234375, 63.44123996794224, 62.674976885318756, 61.826452016830444, 62.68936291337013, 57.78848469257355, 63.393491730093956, 62.0351368188858, 63.986240923404694, 64.41867291927338, 61.07749320566654, 58.3260228484869, 58.23122553527355, 56.43549509346485, 60.69263085722923, 55.61622105538845, 59.54648695886135, 62.94586434960365, 62.56317548453808, 58.465699553489685, 46.764599829912186, 44.092947989702225, 46.85297928750515, 56.47647589445114, 61.79398275911808, 53.1124822050333, 41.40576258301735, 39.57726649940014, 38.381083086133, 38.39560970664024, 39.37053859233856, 42.081620916724205, 56.17490127682686, 53.34595687687397, 49.62390460073948, 40.24869047105312, 43.3853005617857, 39.461095333099365, 49.591606333851814, 62.36473113298416, 60.453410893678665, 58.62938717007637, 54.02818366885185, 56.68728098273277, 53.561986684799194, 58.22842128574848, 57.6688215136528, 55.053786635398865, 58.3008947968483, 57.476852014660835, 54.77024585008621, 57.970122545957565, 54.436604753136635, 55.503272116184235, 55.720730647444725, 55.91469123959541, 50.73839619755745, 44.884909093379974, 48.77127215266228, 55.17349921166897, 54.80565994977951, 53.44434879720211, 51.634490713477135, 53.17930541932583, 53.9871496707201, 55.29427193105221, 51.147463247179985, 50.48720307648182, 51.18198819458485, 57.57433198392391, 57.4590727686882, 61.68623574078083, 56.17523565888405, 54.652896746993065, 58.25057789683342, 51.19327358901501, 42.85405106842518, 45.68091697990894, 60.84422752261162, 62.851492613554, 65.46539515256882, 67.27964580059052, 64.40323054790497, 59.35760289430618, 58.39063838124275, 65.88225558400154, 69.33369398117065, 60.79664647579193, 52.253500297665596, 36.8900240957737, 14.448326658457518, 4.15346022695303, 0.8287593384739012, 0.6057700852397829, 0.31142570776864886, 0.1402962498832494, 0.33095939084887505, 0.6041338574141264, 0.24515923782018945, 6.119869910180569, 57.31541387736797, 70.14052748680115, 75.52125915884972, 48.62974114716053, 52.489148452878, 46.525007486343384, 68.95957365632057, 3.737880801782012, 0.13821514905430377, 3.6022838903591037, 10.525468457490206, 17.579861171543598, 10.440643709152937, 0.22883209283463657, 0.3434873482910916, 6.361529817804694, 95.59857621788979, 82.44362130761147, 22.19040647149086, 16.50611288845539, 58.32049414515495, 34.00149889290333, 3.1752860778942704, 5.214877696707845, 17.505419366061687, 64.26686346530914, 38.77225309610367, 73.11884567141533, 115.41622281074524, 50.10870158672333, 64.87106904387474, 71.71521618962288, 12.61976882815361, 0.4677002487005666, 0.2929068967932835, 0.5925115279387683, 0.21381314640166238, 0.1647593520465307, 0.09885174018563703, 0.2729430649196729, 0.2642176049994305, 8.350859396159649, 20.844860672950745, 62.70282939076424, 86.77807912230492, 80.32799363136292, 85.58961689472198, 77.03732460737228, 77.18186125159264, 62.54007652401924, 62.27356642484665, 64.22733038663864, 73.83086666464806, 75.05001604557037, 71.1235423386097, 76.05236425995827, 80.68031832575798, 72.39452093839645, 60.367041528224945, 65.19910544157028, 71.14521637558937, 73.20218279957771, 69.0600934624672, 69.39706698060036, 74.35946390032768, 71.32219567894936, 58.60783092677593, 59.00597736239433, 60.496698170900345, 69.12066981196404, 66.66323527693748, 68.29765677452087, 70.1030158996582, 66.63432642817497, 64.55082222819328, 61.29970148205757, 67.99032926559448, 69.07455548644066, 66.48893103003502, 65.02880617976189, 66.02826654911041, 63.40012617409229, 66.10885262489319, 63.75087395310402, 68.4694455564022, 70.72127312421799, 67.09224745631218, 61.53917983174324, 59.5391533523798, 60.25527812540531, 61.29752039909363, 58.76160867512226, 62.136564776301384, 65.79061210155487, 61.828013733029366, 63.39691534638405, 49.119842648506165, 45.40053762495518, 48.570095747709274, 56.82191535830498, 62.39113591611385, 51.0443177819252, 38.88120844960213, 38.248033225536346, 39.959674179553986, 38.52127656340599, 38.34895960986614, 40.561128705739975, 57.97908626496792, 54.67398941516876, 51.632742807269096, 41.34871244430542, 46.193509474396706, 43.208974823355675, 50.97256243228912, 67.21726834774017, 64.30359229445457, 59.15728524327278, 56.682687029242516, 59.017118364572525, 55.113128051161766, 61.60998523235321, 59.182113111019135, 57.7329620718956, 61.17410682141781, 56.75398640334606, 57.532659620046616, 60.476829037070274, 57.37961523234844, 59.79763448238373, 58.317648097872734, 56.221821159124374, 57.22761578857899, 52.026401683688164, 51.36100418865681, 59.04604621231556, 59.92112025618553, 59.6335668861866, 58.64383399486542, 58.19673478603363, 57.897405847907066, 58.238817527890205, 56.159667894244194, 53.4979335218668, 56.37690223753452, 63.494839891791344, 62.975339367985725, 67.98313245177269, 62.286124750971794, 65.15621334314346, 67.3406857252121, 60.21257221698761, 54.470973908901215, 61.07840895652771, 68.68376925587654, 73.06331545114517, 68.81957396864891, 72.19876304268837, 63.56970727443695, 61.07907012104988, 60.275158658623695, 67.77809545397758, 71.1029626429081, 71.19959905743599, 57.6519276201725, 49.29083727300167, 26.54498040676117, 15.05323139950633, 5.974584706127644, 0.695589903043583, 0.3919858083827421, 0.5402378516737372, 1.6772335628047585, 7.6152340695261955, 0.32208205782808363, 8.285794537514448, 72.54550963640213, 75.08052840828896, 87.86693349480629, 56.062966883182526, 67.9990004003048, 58.63039791584015, 79.7676832973957, 4.8775360733270645, 0.15030765876872465, 14.956537988036871, 23.90726264566183, 28.860370963811874, 17.048094905912876, 0.39165605732705444, 0.895407049683854, 4.6245204750448465], [57.11764968931675, 45.889415591955185, 9.362056385725737, 10.406807474792004, 37.09623523056507, 14.286212157458067, 0.16506890184246004, 0.4242403479292989, 2.334097665734589, 27.598937451839447, 51.42653547227383, 36.02174788713455, 46.17973901331425, 36.46041914820671, 36.15302324295044, 29.22828432172537, 3.4860778134316206, 0.06286153351538815, 0.05773637669335585, 0.03428101088502444, 0.05472173943417147, 0.08335597871337086, 0.08486958889989182, 0.016187656474357937, 0.13166259363060817, 2.1172212157398462, 10.348618347197771, 62.007508501410484, 87.6761457324028, 77.51476898789406, 78.1006671488285, 70.98391503095627, 68.12577679753304, 53.218971490859985, 50.605433732271194, 49.78236749768257, 57.27774649858475, 57.36108362674713, 57.567131370306015, 57.38580510020256, 61.81796707212925, 63.95933076739311, 54.508945271372795, 56.62377879023552, 65.6006070971489, 68.36878135800362, 66.6357171535492, 67.42096021771431, 64.81065228581429, 66.30008116364479, 52.12803862988949, 49.080936536192894, 54.48814518749714, 59.79016028344631, 62.059303522109985, 62.291364669799805, 62.48693637549877, 56.12618789076805, 53.61332193017006, 54.22131970524788, 58.155860379338264, 59.73601318895817, 58.414873480796814, 57.349562644958496, 59.70490425825119, 54.1313823312521, 56.146676391363144, 59.10732552409172, 56.95966936647892, 65.15764206647873, 57.619363367557526, 55.857128128409386, 56.47822380065918, 56.631131395697594, 54.607610777020454, 53.60413022339344, 57.19606988132, 58.72823506593704, 52.30265446007252, 45.607121139764786, 44.45286467671394, 40.630288794636726, 46.66946813464165, 50.26201196014881, 56.24677062034607, 57.46321454644203, 57.034749537706375, 46.34169012308121, 37.724352926015854, 39.23164464533329, 48.85410390794277, 54.50527086853981, 56.76913619041443, 52.13098347187042, 47.98818737268448, 38.91869343817234, 43.14140684902668, 42.3229193687439, 40.53774856030941, 52.65896514058113, 57.111839801073074, 56.11861489713192, 52.49341182410717, 53.068134784698486, 55.17523191869259, 52.52001039683819, 55.54057091474533, 58.27924355864525, 53.54022145271301, 55.486568212509155, 51.88092648983002, 51.279194578528404, 54.12556104362011, 52.60638356208801, 54.53734114766121, 47.582277953624725, 39.12230931222439, 43.660295605659485, 53.647508695721626, 50.25775998830795, 49.05233547091484, 48.30629490315914, 50.58695152401924, 50.45544818043709, 51.083679869771004, 48.42081695795059, 47.126644402742386, 47.53848910331726, 48.17405819892883, 57.13920973241329, 58.3581805229187, 63.234059885144234, 58.415173664689064, 49.18725863099098, 51.41927406191826, 36.91550552845001, 25.667419396340847, 31.700710952281952, 45.04749096930027, 54.966045543551445, 63.60548995435238, 62.480328530073166, 58.794556707143784, 52.76253618299961, 51.93351186811924, 53.058099523186684, 59.779794439673424, 69.20660600066185, 62.31086142361164, 46.10717810690403, 41.96329526603222, 20.201629288494587, 5.704302359372377, 0.7999234576709569, 0.2979952690657228, 0.08825899960356764, 0.041413525032112375, 1.7677206010557711, 0.1178340520709753, 2.3619929188862443, 49.83974441885948, 59.6451448649168, 66.41067802906036, 44.209913313388824, 42.99212425947189, 28.289504796266556, 42.0022963732481, 2.573021245189011, 1.4214164461009204, 5.98756480962038, 4.021314242854714, 8.926482908427715, 5.219058897346258, 0.34426912665367126, 0.25522060808725655, 5.539022628217936, 77.99396887421608, 61.984895914793015, 11.36673191562295, 12.762716207653284, 39.791745990514755, 19.217153415083885, 1.5322625543922186, 0.6867479556240141, 3.7419665325433016, 35.038064271211624, 46.226575300097466, 44.58309508860111, 55.197190940380096, 42.4091025441885, 47.28177107870579, 48.494001030921936, 6.311670793220401, 0.30744165123905987, 0.05785707588074729, 0.01850238724728115, 0.06506301811896265, 0.03260465142375324, 0.03825803185463883, 0.097930304473266, 0.1799742699950002, 4.382793121039867, 19.125177450478077, 65.92043593525887, 82.91427165269852, 78.69367092847824, 78.46997693181038, 74.68471884727478, 72.35037490725517, 59.185578525066376, 55.23135110735893, 54.94496047496796, 64.45742323994637, 63.91340643167496, 65.43425962328911, 66.8680214881897, 68.1539636850357, 67.92361244559288, 57.05181062221527, 58.67566868662834, 68.38496088981628, 68.88404130935669, 70.27749493718147, 72.31306090950966, 68.92159089446068, 67.8778325021267, 56.71531967818737, 52.8343865275383, 57.16462656855583, 62.83496730029583, 63.080103546381, 66.00082442164421, 63.64786148071289, 60.35566493868828, 57.46058128774166, 59.68869432806969, 60.72643004357815, 62.72428683936596, 60.74977979063988, 61.40832245349884, 61.2920942902565, 58.331239968538284, 59.165519401431084, 62.12580755352974, 58.68219293653965, 64.3014644086361, 60.417506620287895, 57.17931278049946, 60.80944038927555, 58.36091257631779, 56.920159086585045, 57.68889203667641, 59.417814463377, 61.53576001524925, 51.89551390707493, 48.44151444733143, 48.20288725197315, 42.14192368090153, 49.61218982934952, 54.762068688869476, 58.75623196363449, 62.73899205029011, 57.84621499478817, 50.95379903912544, 40.46816669404507, 42.559696063399315, 52.251862585544586, 56.685954853892326, 58.762186244130135, 53.778468668460846, 52.275178134441376, 41.679230108857155, 44.644522592425346, 45.20561568439007, 40.63432797789574, 52.70098328590393, 56.75754301249981, 58.89722339808941, 54.871084839105606, 55.56327849626541, 56.84125252068043, 56.08646102249622, 57.52473704516888, 60.85828676819801, 56.83371752500534, 57.6426637172699, 55.35267099738121, 54.91999201476574, 55.592970103025436, 57.32320725917816, 57.12422713637352, 50.71506924927235, 46.18254706263542, 51.405902579426765, 56.759769693017006, 52.445078417658806, 53.77134025096893, 51.20842717587948, 51.72351233661175, 52.62445919215679, 52.7682700753212, 54.32880833745003, 50.15972524881363, 50.5777408182621, 49.940454214811325, 59.28236313164234, 57.954231798648834, 62.29371674358845, 60.823568031191826, 56.695507541298866, 57.1916127204895, 43.54967974126339, 34.51609008014202, 44.371100664138794, 54.0999998152256, 62.060109078884125, 68.68006825447083, 65.86432054638863, 62.82893322408199, 56.91682666540146, 56.17160305380821, 55.610445365309715, 64.11000788211823, 70.12443155050278, 63.43680560588837, 53.85237090289593, 40.06133772432804, 15.636688191443682, 3.2461817236617208, 1.4907425385899842, 0.2701054484350607, 0.12289390360820107, 0.227536570164375, 1.8396452791057527, 0.1622572011547163, 3.152395156212151, 61.31205841898918, 67.73461058735847, 75.92065572738647, 52.78389483690262, 53.920721635222435, 36.11943684518337, 52.70173564553261, 2.8278137231245637, 1.3518227054737508, 8.867617417126894, 5.485321534797549, 14.859078917652369, 7.675166828557849, 0.3552806389052421, 0.2399428896023892, 4.976856093853712, 78.6201524734497, 84.82548549771309, 43.30854468047619, 27.130813971161842, 72.47870922088623, 47.663012221455574, 6.095434371381998, 1.61016502417624, 14.263034351170063, 66.46074414253235, 68.45708101987839, 53.95220674574375, 59.02742341160774, 54.1035982221365, 57.183142974972725, 76.84341341257095, 16.3518088683486, 0.4447053076000884, 0.10318808679585345, 0.1028935209615156, 0.17172752501210198, 0.17178622889332473, 0.1689931412693113, 0.2853326266631484, 0.36173557222355157, 8.037422765046358, 28.304173909127712, 78.37467804551125, 84.68792527914047, 84.49973657727242, 83.09315845370293, 80.37314280867577, 76.8468864262104, 64.88663300871849, 60.56005597114563, 61.97548381984234, 71.66787832975388, 73.44521015882492, 75.06794348359108, 75.1892937719822, 74.9797274172306, 74.66022536158562, 61.630637124180794, 63.08267220854759, 71.87391087412834, 71.70664384961128, 71.78749591112137, 71.54478013515472, 72.41590619087219, 68.88563722372055, 59.258302822709084, 54.645555540919304, 60.262072160840034, 65.34913659095764, 65.93625068664551, 69.84868794679642, 67.544514387846, 65.17258286476135, 60.54814361035824, 61.535266041755676, 63.14778171479702, 65.06742730736732, 62.860612124204636, 65.16884386539459, 64.45183753967285, 62.51358434557915, 61.63318678736687, 65.19549563527107, 61.50267519056797, 68.71519356966019, 65.10547086596489, 59.82168339192867, 62.477566078305244, 61.19059793651104, 59.25793804228306, 58.70121851563454, 62.327200546860695, 64.81439128518105, 54.080940037965775, 50.09250685572624, 50.891185998916626, 44.653980284929276, 53.270671516656876, 55.85838206112385, 62.78533436357975, 64.52038586139679, 57.98800818622112, 49.38705191016197, 38.97055305540562, 40.43549604713917, 50.771063044667244, 58.92878830432892, 60.79294167459011, 56.37563310563564, 55.342745929956436, 43.83495703339577, 46.56707122921944, 44.067230969667435, 42.9124691337347, 56.411848962306976, 60.25247387588024, 61.679567098617554, 57.647550255060196, 59.56571392714977, 60.86208276450634, 57.50992923974991, 59.572276175022125, 62.30254366993904, 60.288784727454185, 61.0128852725029, 56.45384430885315, 58.20404939353466, 58.79616402089596, 58.744452595710754, 58.434613421559334, 56.117873936891556, 50.81796392798424, 52.63916440308094, 59.265165254473686, 57.59542465209961, 57.052346393465996, 55.25733791291714, 56.87589146196842, 58.29244405031204, 57.081870809197426, 60.09205028414726, 55.910165682435036, 54.16254445910454, 54.31400813162327, 64.03151169419289, 64.30716410279274, 70.322195738554, 67.39263653755188, 66.85783803462982, 65.10019674897194, 51.295864284038544, 48.5868376493454, 56.592620462179184, 63.425261825323105, 66.4403772354126, 73.0769719183445, 68.88369932770729, 67.04615592956543, 58.10618944466114, 58.23449335992336, 57.43362173438072, 68.91888543963432, 70.66227748990059, 72.92278379201889, 60.33279396593571, 63.74634459614754, 43.632906675338745, 14.132689945399761, 3.2741515478119254, 1.979262731038034, 0.24036580987740308, 0.18721224332693964, 2.986063831485808, 0.27978073863778263, 4.939496973529458, 74.55272153019905, 73.02639663219452, 86.07938781380653, 62.30618767440319, 65.1397830247879, 47.76660606265068, 62.47952677309513, 2.6653149677440524, 2.7743866899982095, 23.341775089502335, 15.510624255985022, 26.26105584204197, 11.542932260781527, 0.4840470012277365, 0.7035172870382667, 4.600473465397954], [52.28350728750229, 61.07362501323223, 24.881184585392475, 18.462363816797733, 54.46659654378891, 22.27870423346758, 4.461085544899106, 1.085483122151345, 2.0378199638798833, 40.56545667350292, 54.65570479631424, 41.1565225571394, 46.722057312726974, 43.09560790657997, 34.333107098937035, 31.317216530442238, 4.104945855215192, 0.2032607267028652, 0.08864317234838381, 0.08469372216495685, 0.09365172663819976, 0.11937301402213052, 0.03512456933094654, 0.23573848942760378, 1.1484881350770593, 3.1448188377544284, 22.639426477253437, 74.80698108673096, 78.74464899301529, 78.50842326879501, 74.68806266784668, 72.78067901730537, 66.04063868522644, 54.885448068380356, 49.08508211374283, 48.676623031497, 54.097362756729126, 58.4892088919878, 57.09401495754719, 55.93693904578686, 62.022893875837326, 61.110680624842644, 56.08835332095623, 56.076874136924744, 60.80700471997261, 66.50621250271797, 66.88032522797585, 67.44171470403671, 58.46481040120125, 63.94280165433884, 51.537557914853096, 48.58964189887047, 52.92160324752331, 56.50874376296997, 61.306248530745506, 59.35095705091953, 55.757596269249916, 52.40487277507782, 50.13976112008095, 52.787295654416084, 55.6488461047411, 58.62387366592884, 57.94989623129368, 58.77359323203564, 58.21560837328434, 58.261335119605064, 54.81850706040859, 56.59737400710583, 60.758637115359306, 56.27673581242561, 55.348388627171516, 58.756106570363045, 54.80810321867466, 53.55466827750206, 55.20968846976757, 57.610240057110786, 56.44148737192154, 52.58264243602753, 45.44550061225891, 45.06397448480129, 45.490634590387344, 41.18494123220444, 45.98862826824188, 51.09560742974281, 51.09574042260647, 53.02331238985062, 52.869994416832924, 54.59299676120281, 48.459168300032616, 48.5685720294714, 55.532754734158516, 52.09434203803539, 54.8298342525959, 49.40746061503887, 50.93927621841431, 39.94233191013336, 42.931893691420555, 46.95778526365757, 38.73919107019901, 44.74062703549862, 55.04932947456837, 53.17680515348911, 54.67348024249077, 50.232001170516014, 54.74051624536514, 53.30656439065933, 53.63355204463005, 53.891926780343056, 55.66227838397026, 53.329461961984634, 53.432957008481026, 46.40177249908447, 56.857895627617836, 53.656871393322945, 48.21918837726116, 43.43840651214123, 49.31577913463116, 53.644385263323784, 49.828538820147514, 49.06055063009262, 50.80744609236717, 48.07062014937401, 47.91577845811844, 46.17150105535984, 47.561808452010155, 46.469853445887566, 43.237135112285614, 44.866130501031876, 49.25625152885914, 56.916591078042984, 60.36248937249184, 61.641177758574486, 56.768266037106514, 38.3966850489378, 32.10940182209015, 27.45012603700161, 19.151010364294052, 25.757670253515244, 40.78863009810448, 48.56506481766701, 52.00390309095383, 57.14330971240997, 52.86155886948109, 51.57597005367279, 50.23046225309372, 52.03488662838936, 54.21577200293541, 64.23730865120888, 69.14183467626572, 67.96791806817055, 51.29924610257149, 37.3904724419117, 19.202155619859695, 5.254412200301886, 0.8977545518428087, 1.0180695145390928, 0.6910006399266422, 0.8194859954528511, 0.2876779914367944, 8.117802701890469, 70.90424090623856, 58.81242334842682, 70.10005205869675, 43.03840957581997, 44.30566817522049, 34.270843639969826, 16.509684696793556, 4.897360084578395, 1.0662909457460046, 6.19939299300313, 6.707817111164331, 4.339217059314251, 1.1740047158673406, 0.19666459236759692, 0.1539491696166806, 4.8036200646311045, 63.05136948823929, 64.30511981248856, 21.70208517462015, 20.061553604900837, 54.46848124265671, 20.187085568904877, 5.925606284290552, 1.7046152497641742, 7.426312481984496, 52.04909406602383, 54.61551055312157, 41.665562242269516, 42.70593501627445, 50.95500737428665, 48.03179383277893, 50.49315355718136, 7.587339291349053, 0.4040300933411345, 0.04671623697504401, 0.08047330644330941, 0.04085921864316333, 0.06210163366631605, 0.07427004282362759, 0.06240644113859162, 1.0064151836559176, 6.25418652780354, 28.948611728847027, 77.20032826066017, 79.38803046941757, 77.55868703126907, 77.56602823734283, 77.07080081105232, 71.55481919646263, 60.14949940145016, 54.89257648587227, 54.52273093163967, 62.76777170598507, 66.39050871133804, 64.38577428460121, 65.64660742878914, 66.27338379621506, 68.19677978754044, 60.35583212971687, 61.668540090322495, 62.668030858039856, 70.5503810942173, 68.6191575229168, 70.56839972734451, 64.66639682650566, 65.9711404144764, 57.11979277431965, 49.922317788004875, 56.99641339480877, 59.45720314979553, 63.11185084283352, 61.701073944568634, 60.578986555337906, 54.92592729628086, 54.87735070288181, 55.03672935068607, 58.93887296319008, 60.247040167450905, 61.60164847970009, 60.964954644441605, 62.73426130414009, 60.25647886097431, 57.454136833548546, 57.95984409749508, 62.52072416245937, 57.358583360910416, 56.74900867044926, 62.12712988257408, 57.33170360326767, 56.849927455186844, 58.14776301383972, 59.44686010479927, 59.63420145213604, 54.24293674528599, 47.899378538131714, 49.4397284835577, 47.94614262878895, 43.77734072506428, 50.761897936463356, 54.58059422671795, 52.25351169705391, 55.702465027570724, 54.09453570842743, 59.00990255177021, 51.441685259342194, 51.57672621309757, 57.64897897839546, 55.134007930755615, 54.55546237528324, 52.7091908454895, 50.60287266969681, 42.99061954021454, 45.94205416738987, 47.78984181582928, 41.033390164375305, 45.73226362466812, 56.59046597778797, 56.62853233516216, 56.808270290493965, 56.093099266290665, 55.98857067525387, 57.421884164214134, 57.27398470044136, 56.29279375076294, 56.08446232974529, 56.973367631435394, 55.089854300022125, 51.21047146618366, 59.018797874450684, 56.259192153811455, 49.872016087174416, 48.72287794947624, 56.10022008419037, 57.42089241743088, 53.753454610705376, 52.278563752770424, 55.30756741762161, 48.515488877892494, 50.71222700178623, 47.58019186556339, 48.65769624710083, 49.200664311647415, 46.84386357665062, 45.875481739640236, 50.64379267394543, 57.38379120826721, 60.75427494943142, 63.34257826209068, 58.7520407885313, 54.1595958173275, 46.83165103197098, 36.041772812604904, 29.697925820946693, 41.248652413487434, 50.570430010557175, 55.900958776474, 56.064148619771004, 60.86748227477074, 56.24294422566891, 55.46077139675617, 53.46415713429451, 58.26872952282429, 57.8324369341135, 67.69120171666145, 72.16782510280609, 68.3342108130455, 60.49292117357254, 42.590687200427055, 15.379551239311695, 2.0290939696133137, 1.3165772217325866, 0.9738665458280593, 2.4811443127691746, 1.5793207730166614, 0.35878054797649384, 9.459272269159555, 79.30565848946571, 67.15274021029472, 79.18693006038666, 50.044618025422096, 50.532580241560936, 47.12816812098026, 24.59505993872881, 7.322651669383049, 4.670690847560763, 4.378647543489933, 9.19487675651908, 7.040342492982745, 1.0071114962920547, 0.1284942464553751, 0.14100136439083144, 4.8103803768754005, 60.902854576706886, 94.30018588900566, 62.81194433569908, 44.787075743079185, 90.09878173470497, 70.0614233314991, 28.868785612285137, 1.2850272771902382, 21.485116817057133, 73.31363841891289, 67.36908540129662, 59.063544273376465, 61.69045351445675, 59.833363965153694, 64.0361550450325, 68.42166692018509, 20.965376906096935, 0.5318995553534478, 0.24205416615586728, 0.4415044840425253, 0.12281319504836574, 0.17986688122618943, 0.3123580530518666, 0.2801249467302114, 2.673485716804862, 10.028586219996214, 38.02665330469608, 83.06764662265778, 81.67931511998177, 83.15550550818443, 79.50873479247093, 82.9410982131958, 75.68624630570412, 68.88072788715363, 59.39415693283081, 62.69578456878662, 67.01906338334084, 75.16286239027977, 72.20215246081352, 72.30302944779396, 75.91576918959618, 74.1045431792736, 65.14819577336311, 63.88861656188965, 66.77966102957726, 72.34204575419426, 70.35466119647026, 71.95365339517593, 65.77612727880478, 69.44871380925179, 59.53028842806816, 54.143986254930496, 60.66785618662834, 61.873744279146194, 66.05453833937645, 63.52222502231598, 64.87721711397171, 57.57013700902462, 57.36202597618103, 59.13469925522804, 63.2636982947588, 63.72381940484047, 63.58031630516052, 62.773684188723564, 64.22676801681519, 63.203851506114006, 60.61037667095661, 62.919524163007736, 67.06415176391602, 63.86324152350426, 58.82867507636547, 64.49580878019333, 60.34214146435261, 59.43166472017765, 60.61707951128483, 61.72332935035229, 63.41850198805332, 57.61708348989487, 47.14524060487747, 49.2154835164547, 49.53134536743164, 45.577364936470985, 53.614689856767654, 55.58624446392059, 55.34105882048607, 59.681866094470024, 55.8226677775383, 61.86565451323986, 50.63783839344978, 52.1722986549139, 62.61030815541744, 57.3150908946991, 57.786903977394104, 54.97611500322819, 54.65689413249493, 45.05680426955223, 49.43962588906288, 48.63476447761059, 40.319917649030685, 48.51290121674538, 60.452715530991554, 59.065706357359886, 59.75501976907253, 57.69546188414097, 60.39122723042965, 57.64045983552933, 59.755175560712814, 60.24808511137962, 58.225791826844215, 60.800887048244476, 58.95227484405041, 51.62283293902874, 62.118496745824814, 59.817784801125526, 58.05013485252857, 52.02011302113533, 58.69268797338009, 61.85873128473759, 55.94348229467869, 54.440085366368294, 59.0098075568676, 54.11892279982567, 55.72565898299217, 53.054181933403015, 54.03056614100933, 53.62219825387001, 51.062594801187515, 49.32359151542187, 53.160154446959496, 62.133084163069725, 66.77836149930954, 69.4467531144619, 67.26347386837006, 62.113009840250015, 58.35678219795227, 45.16637519001961, 43.388135209679604, 54.38910350203514, 59.18550252914429, 59.08243305981159, 59.07997839152813, 63.63412141799927, 58.79904046654701, 56.09936513006687, 57.029878199100494, 61.38557307422161, 61.57120071351528, 69.64127227663994, 74.83433201909065, 73.1024381518364, 62.00581759214401, 53.94611567258835, 38.27648609876633, 13.405484966933727, 3.7817097874358296, 1.9675852451473475, 1.9127291324548423, 2.621689746156335, 0.6951923493761569, 11.810958478599787, 84.41355720162392, 75.121900588274, 87.55827605724335, 61.56001791357994, 59.282648116350174, 60.06048537790775, 36.85027062892914, 11.422131042927504, 16.661604344844818, 15.777841117233038, 16.295621283352375, 13.482577130198479, 2.169971647672355, 0.46032944577746093, 0.4976665391586721, 4.090356063097715], [36.82633191347122, 62.89336636662483, 41.538219675421715, 17.67010062932968, 55.8327030390501, 45.227521508932114, 24.201273769140244, 0.6898797594476491, 5.7954927161335945, 43.436328023672104, 45.02546735107899, 53.20787988603115, 74.54988688230515, 49.04268778860569, 35.08270427584648, 37.446158453822136, 1.2508307746611536, 0.3180813475046307, 0.0385881799593335, 0.0770909980928991, 0.054552377623622306, 0.023124883737182245, 0.19565740891266614, 0.1864206834579818, 6.182561796158552, 15.526949129998684, 43.974637538194656, 79.20230403542519, 74.21830147504807, 78.41842129826546, 72.24086478352547, 70.89203596115112, 59.78523574769497, 53.232126384973526, 49.04324255883694, 50.98862797021866, 53.90890046954155, 56.6863614320755, 55.52667126059532, 58.079541474580765, 58.49593833088875, 59.3390066921711, 58.61184351146221, 55.662840753793716, 55.19267678260803, 64.23787862062454, 65.2001541852951, 65.02075061202049, 61.8209233134985, 63.415735736489296, 50.59914126992226, 47.74677872657776, 51.73235446214676, 56.21545650064945, 56.306708604097366, 53.92682030797005, 53.56771297752857, 51.76011957228184, 51.49626933038235, 53.17022770643234, 54.89939332008362, 54.506011828780174, 59.831194281578064, 57.07842439413071, 60.09149171411991, 57.60195270180702, 54.43131163716316, 57.38521233201027, 53.9247190207243, 55.53274713456631, 56.58698916435242, 55.757774859666824, 54.79245945811272, 56.97087116539478, 55.95435731112957, 55.92272400856018, 58.66907224059105, 56.65210247039795, 55.698513239622116, 45.32489128410816, 43.299383372068405, 42.024012207984924, 44.527203887701035, 48.89171428978443, 44.42676767706871, 48.74415300786495, 50.51383964717388, 43.86427626013756, 52.511973828077316, 48.811865374445915, 46.13920658826828, 51.07236407697201, 44.651373624801636, 47.04045742750168, 46.96058951318264, 41.439390778541565, 40.300287902355194, 43.71625520288944, 44.54975187778473, 40.655344650149345, 49.63144339621067, 54.17764104902744, 52.733779326081276, 53.00869457423687, 49.38210837543011, 51.80442899465561, 54.64035362005234, 54.80191335082054, 54.28188465535641, 51.66105888783932, 50.963431522250175, 50.82434378564358, 46.13324470818043, 45.37556916475296, 42.28941656649113, 50.389981493353844, 54.024623259902, 49.80190984904766, 52.6431617885828, 49.975758120417595, 45.59666410088539, 43.27926345169544, 45.14830335974693, 41.44171245396137, 44.51278746128082, 42.83418953418732, 44.62190240621567, 44.67735283076763, 50.09630665183067, 58.51809874176979, 58.67305442690849, 53.34994286298752, 45.051807537674904, 24.968593195080757, 17.498074360191822, 17.544192485511303, 15.177095253020525, 25.569384656846523, 39.854446426033974, 46.46779775619507, 51.340105310082436, 49.37856696546078, 50.56724198162556, 50.29126279056072, 53.091252744197845, 51.4424604177475, 55.36311663687229, 62.28902779519558, 68.69364872574806, 65.80875992774963, 69.1360741853714, 45.67045994102955, 32.592405304312706, 26.963550746440887, 6.534096132963896, 8.292949553579092, 6.4298786502331495, 1.877310045529157, 0.22674977488350123, 16.280726082623005, 71.63722917437553, 60.7704658806324, 71.68434664607048, 42.19686113297939, 48.93423780798912, 43.792463913559914, 36.22865438461304, 4.8166989628225565, 6.822429886087775, 5.089407479390502, 3.2968660164624453, 1.5976279531605542, 0.14368602423928678, 0.3676814219215885, 0.03313741326564923, 2.3692146688699722, 52.303980588912964, 65.33779039978981, 36.220712810754776, 29.398209303617477, 63.056100234389305, 36.56404338777065, 13.652813695371151, 1.1287104338407516, 6.312298709526658, 55.76012693345547, 45.833539590239525, 57.707309648394585, 79.57171261310577, 59.904290959239006, 49.027727991342545, 56.59825935959816, 12.158371936529875, 0.4285970516502857, 0.093086113629397, 0.0635759174474515, 0.00556047513782687, 0.07204718436696567, 0.2629403391620144, 0.2471799575141631, 9.427811857312918, 19.443300180137157, 46.234060898423195, 80.88604688644409, 74.91247862577438, 81.8152566254139, 76.63222074508667, 75.51863729953766, 69.41671192646027, 59.01505507528782, 55.74239708483219, 56.53664946556091, 60.46318396925926, 63.35192956030369, 64.7126479446888, 65.52095577120781, 65.40673390030861, 66.77891626954079, 61.27911418676376, 58.88614699244499, 59.88772764801979, 67.8750890493393, 68.89731779694557, 68.03944543004036, 66.31830498576164, 65.3866557776928, 52.53200635313988, 49.72368724644184, 55.165040865540504, 57.92789541184902, 59.76347051560879, 58.108423724770546, 57.35004521906376, 53.382070139050484, 54.737901985645294, 55.85138663649559, 56.71985663473606, 56.19578495621681, 62.39919148385525, 59.06158357858658, 62.58973605930805, 58.51478531956673, 55.5231374502182, 54.37840707600117, 55.474443063139915, 58.64704482257366, 61.12752132117748, 58.26254345476627, 59.20676998794079, 58.972493559122086, 57.60075196623802, 58.86356100440025, 61.321812495589256, 56.69394202530384, 55.78061543405056, 47.45297089219093, 47.03143671154976, 44.92186591029167, 47.98419378697872, 52.192486971616745, 49.44216415286064, 50.249297842383385, 52.77020797133446, 46.17425590753555, 55.587574392557144, 50.16651928424835, 48.32051374018192, 52.83036254346371, 48.27656529843807, 47.66635604202747, 50.20261734724045, 44.75396811962128, 43.55286777019501, 46.68968304991722, 43.403683975338936, 42.18479298055172, 49.39950384199619, 56.2796388566494, 55.4227202385664, 56.099976897239685, 53.23961578309536, 52.84729823470116, 57.67561934888363, 59.20882947742939, 57.090557143092155, 52.966801822185516, 53.24743576347828, 53.66091437637806, 47.723398581147194, 50.086343586444855, 50.44390060007572, 54.54553730785847, 54.69944424927235, 53.05089510977268, 55.46677887439728, 51.84810385107994, 47.4733529984951, 46.757585406303406, 46.427208334207535, 45.69565258920193, 47.929100543260574, 46.37308023869991, 46.292836144566536, 46.96048691868782, 52.5263674557209, 58.24758365750313, 61.91906824707985, 60.83372488617897, 53.41680787503719, 40.90110786259174, 34.836933463811874, 28.64363819360733, 26.519687063992023, 40.3799544274807, 51.47699296474457, 52.97728165984154, 56.0885015130043, 51.79179087281227, 55.202719643712044, 52.66446344554424, 57.48721785843372, 55.07726177573204, 60.082011222839355, 66.58256560564041, 71.78630277514458, 70.85839256644249, 74.48918133974075, 52.76746831834316, 39.48972299695015, 22.81853936612606, 7.453720886260271, 9.841749295592308, 5.06788020953536, 0.7884575729258358, 0.10459860524861142, 17.698167823255062, 82.82030269503593, 65.22194981575012, 82.90611729025841, 47.04620271921158, 56.127392426133156, 50.98760962486267, 53.40389996767044, 12.935531884431839, 16.417630836367607, 7.0146378222852945, 8.912444561719894, 3.793194671161473, 0.1295195531565696, 0.282165941898711, 0.018997802362719085, 3.5791870672255754, 45.69992735981941, 90.23276254534721, 74.95079576969147, 58.01076136529446, 75.8916100859642, 76.46436855196953, 61.46069884300232, 0.52776686148718, 19.921392425894737, 73.63902255892754, 65.54943904280663, 71.90408125519753, 93.35714489221573, 65.90845137834549, 61.96995511651039, 73.67176160216331, 35.20683601498604, 0.9721283765975386, 0.14348220080137253, 0.32953431888017803, 0.09694355976535007, 0.21323223772924393, 0.27109568123705685, 1.1353740887716413, 14.359585270285606, 31.02084383368492, 58.51873330771923, 83.51478382945061, 78.134014159441, 88.1714415550232, 79.02050659060478, 79.71501812338829, 71.27672731876373, 64.7125643491745, 59.22631613910198, 63.24642822146416, 66.58115968108177, 68.52898076176643, 68.83609548211098, 72.2842888534069, 71.08424484729767, 73.89175459742546, 67.19284325838089, 62.46246948838234, 62.17492751777172, 70.43138667941093, 70.80993756651878, 67.38774999976158, 67.41466015577316, 67.82473415136337, 55.15519559383392, 53.15717540681362, 57.668437734246254, 61.235055550932884, 61.89361721277237, 60.02155266702175, 62.146786227822304, 57.1761741489172, 58.0887483805418, 59.23219442367554, 59.21890653669834, 58.41301538050175, 65.75375407934189, 60.976274237036705, 65.05512356758118, 62.646463215351105, 58.83588328957558, 60.41369542479515, 58.91626417636871, 61.787941083312035, 63.70181858539581, 60.72480373084545, 59.09597173333168, 60.93888804316521, 60.681535452604294, 60.23613095283508, 63.41837279498577, 57.966007366776466, 57.05015771090984, 50.91183789074421, 48.479113429784775, 47.14203357696533, 51.402858942747116, 54.844303876161575, 50.66202029585838, 53.183830976486206, 54.94274899363518, 48.839793875813484, 58.00875507295132, 55.16077369451523, 50.272115617990494, 54.252383038401604, 49.375082552433014, 54.029129818081856, 50.78944645822048, 48.17115515470505, 45.09986735880375, 50.20328231155872, 45.34921757876873, 43.99211660027504, 54.19657923281193, 55.927245765924454, 57.20590755343437, 60.146478563547134, 54.81646277010441, 57.83016465604305, 59.549131616950035, 60.072234347462654, 58.910682275891304, 55.959395840764046, 56.577159091830254, 56.277731359004974, 53.814517334103584, 58.486632630228996, 51.059953942894936, 57.35443398356438, 59.376761466264725, 57.5804952532053, 56.34892053902149, 57.6789365708828, 50.803957879543304, 48.73166307806969, 50.12320540845394, 49.097222462296486, 52.591112181544304, 51.094630882143974, 49.85671430826187, 50.011970177292824, 56.12239569425583, 61.83851636946201, 70.01511141657829, 71.1414697766304, 63.32143619656563, 49.763900488615036, 44.9471877515316, 37.22390457987785, 40.17966337502003, 53.785258904099464, 57.00755439698696, 57.903485521674156, 58.84496860206127, 53.65247502923012, 56.67471505701542, 55.91346390545368, 59.936585426330566, 57.57853455841541, 61.79888069629669, 68.10975685715675, 75.15632674098015, 72.91156679391861, 76.76467403769493, 60.00283107161522, 52.51446649432182, 45.4022741317749, 12.280946709215641, 11.702224463224411, 11.104349344968796, 5.494644334539771, 0.5924123176373541, 21.67683932930231, 90.8484511077404, 71.9576507806778, 93.04980978369713, 54.47592504322529, 68.96729484200478, 58.04540030658245, 71.72028511762619, 23.429141901433468, 38.743652030825615, 33.088658675551414, 16.333051174879074, 8.865938857197762, 0.21101486374391243, 0.49484112358186394, 0.4241299460409209, 3.0900879995897412], [15.954511687159538, 63.630431815981865, 50.62244541943073, 35.83300441503525, 43.26005928218365, 46.35901339352131, 31.027645468711853, 1.6339921206235886, 3.6579461535438895, 39.60311271250248, 46.321870386600494, 46.13118141889572, 64.92558091878891, 41.583349853754044, 39.99994821846485, 43.85772921144962, 7.247602846473455, 4.278540015220642, 0.1431469281669706, 0.15020196209661663, 0.08029626711504534, 0.045522566651925445, 0.2640432002954185, 0.18786870263284072, 4.613149110227823, 21.664039716124535, 64.35040578246117, 75.76427891850471, 76.263936907053, 76.30028575658798, 70.99829345941544, 70.33832967281342, 59.6483138948679, 52.00297974050045, 49.89496685564518, 49.877256006002426, 54.5561159402132, 58.22652518749237, 60.484238639473915, 59.721380174160004, 62.550807148218155, 60.18472731113434, 59.77673180401325, 55.04532068967819, 55.193432942032814, 60.04813604056835, 62.678164914250374, 65.25671795010567, 60.18436633050442, 60.67321389913559, 46.23813807964325, 48.59576337039471, 50.124390944838524, 53.439405262470245, 55.58729700744152, 50.49889124929905, 51.15604318678379, 51.68130800127983, 50.09618125855923, 52.51646138727665, 54.94832329452038, 54.70090337097645, 60.040874630212784, 58.98662120103836, 60.7299068570137, 56.915553733706474, 52.16931961476803, 54.94768872857094, 54.824339747428894, 55.742305889725685, 55.95787972211838, 58.155552595853806, 59.393621161580086, 56.02274224162102, 60.196738466620445, 64.6927598118782, 57.296403497457504, 51.78619757294655, 48.551617339253426, 45.217368453741074, 50.382127314805984, 46.15648806095123, 44.23162154853344, 45.24900555610657, 47.89491757750511, 46.471122577786446, 50.291574373841286, 45.04739597439766, 50.805766582489014, 49.53666888177395, 47.056317776441574, 50.64513400197029, 47.99761846661568, 45.43793521821499, 47.13243909180164, 40.43047271668911, 44.5112219452858, 42.93071575462818, 44.15070489048958, 41.83373361825943, 42.52254165709019, 58.98273780941963, 55.51143027842045, 51.57505050301552, 53.058323711156845, 51.001573875546455, 52.98838846385479, 57.433093562722206, 55.50715170800686, 52.17043675482273, 49.9372585862875, 47.16136693954468, 39.88153517246246, 47.751444876194, 54.79823514819145, 50.82807518541813, 50.788728296756744, 50.83699330687523, 47.25437454879284, 45.144454166293144, 44.7248350828886, 45.802335664629936, 44.237663224339485, 45.79375572502613, 47.142747938632965, 45.952579602599144, 47.855517491698265, 45.33133573830128, 47.164364978671074, 57.75085151195526, 51.310691088438034, 40.473782792687416, 31.210349164903164, 21.616000793874264, 12.102551031857729, 13.049525767564774, 14.60966220125556, 21.76941566169262, 36.916090697050095, 46.441134586930275, 49.53587092459202, 49.14672240614891, 50.704897195100784, 50.63272766768932, 49.95774328708649, 53.69632467627525, 56.98754847049713, 60.50074115395546, 64.09710377454758, 67.83062383532524, 61.631606072187424, 53.38127978146076, 31.362363807857037, 37.04057961702347, 22.87943869829178, 13.86150324717164, 8.36070941761136, 1.2457961635664105, 0.34424991987179965, 28.421777598559856, 79.04100269079208, 62.305317521095276, 67.10775062441826, 43.67647513747215, 42.96986885368824, 55.740804970264435, 43.14272917807102, 10.93636890873313, 22.392126247286797, 10.791240446269512, 4.188234061002731, 1.4379278663545847, 1.1634822492487729, 0.2526198554551229, 0.5477016011718661, 0.863446252187714, 30.75263522565365, 71.36181235313416, 49.093715250492096, 31.778093799948692, 64.24245357513428, 56.315026357769966, 30.06107423454523, 5.355933727696538, 5.579804414883256, 48.477517515420914, 53.41477878391743, 55.386333391070366, 72.76799529790878, 51.30793623626232, 54.44045774638653, 59.70960080623627, 25.57203121483326, 5.6572941318154335, 0.2393371783546172, 0.28255625220481306, 0.05904733232455328, 0.09351080021588132, 0.19462154887150973, 1.1413295567035675, 8.529993183910847, 34.764319360256195, 65.15252754092216, 77.54795640707016, 78.62541139125824, 79.89605560898781, 74.54979568719864, 76.10381349921227, 64.5399472117424, 57.45337687432766, 56.76377087831497, 55.970312654972076, 60.09340301156044, 65.93045979738235, 65.5649346113205, 68.60227882862091, 65.35936564207077, 67.821154743433, 61.73416256904602, 58.752169981598854, 56.797490268945694, 61.61258049309254, 63.39113585650921, 66.89794108271599, 67.01666191220284, 63.141508251428604, 50.60381501913071, 50.037003234028816, 52.59830519556999, 53.76508578658104, 57.29404002428055, 53.49022753536701, 54.623011350631714, 53.664296194911, 53.973835185170174, 55.26081472635269, 57.81453229486942, 57.37292759120464, 62.79701113700867, 62.29413092136383, 63.47400940954685, 59.68678303062916, 51.98554627597332, 56.86012230813503, 56.82689689099789, 55.70969603955746, 59.735291227698326, 59.30155590176582, 62.05866135656834, 58.75676393508911, 64.68669533729553, 65.05459159612656, 57.05745331943035, 52.45134428143501, 53.7138607352972, 48.236367255449295, 52.06372328102589, 48.89911249279976, 45.692563354969025, 47.01439082622528, 50.5819433927536, 49.10525143146515, 51.0236506909132, 49.260853081941605, 54.22883950173855, 54.033545181155205, 52.02664107084274, 51.99534595012665, 50.46053610742092, 47.9013392329216, 49.26190562546253, 44.33661751449108, 47.255263701081276, 45.43339066207409, 45.942692533135414, 43.21669600903988, 45.977954640984535, 62.873147651553154, 58.20806197822094, 57.40568183362484, 57.60696843266487, 54.30369168519974, 55.677743554115295, 58.402337953448296, 57.85527750849724, 53.13814602792263, 50.53559347987175, 50.084569081664085, 45.525493919849396, 55.61001978814602, 55.55541291832924, 55.47853544354439, 54.35333602130413, 55.7404325902462, 50.39305932819843, 49.150294214487076, 48.09939980506897, 47.883677780628204, 47.96655513346195, 50.23787185549736, 49.78054739534855, 50.567849949002266, 49.86638858914375, 49.29743751883507, 48.87814901769161, 59.967454969882965, 58.86066555976868, 49.801218286156654, 42.65254408121109, 34.25027534365654, 26.349950172007084, 23.840612322092056, 25.527651496231556, 36.23344212770462, 50.49362853169441, 51.63029193878174, 54.508105516433716, 52.761544436216354, 53.70721869170666, 52.78215453028679, 55.673179998993874, 56.238259077072144, 61.14612892270088, 64.39927116036415, 71.47179365158081, 73.118906468153, 72.31760546565056, 62.487479746341705, 42.24223829805851, 47.09353297948837, 27.33537219464779, 15.219191294163465, 9.22375425696373, 1.287867387291044, 0.3589800075860694, 31.847725063562393, 85.8786141872406, 68.82663398981094, 76.18952929973602, 50.11620618402958, 53.60511437058449, 54.69738095998764, 67.05462947487831, 21.475951708853245, 39.8805396258831, 21.83980878442526, 1.265374138019979, 1.1193423927761614, 0.38958985882345587, 0.024403580064245034, 0.1411408733110875, 0.8345200668554753, 22.746100053191185, 74.71473723649979, 78.61278846859932, 69.01131927967072, 66.3526551425457, 65.97796484827995, 60.10709747672081, 11.636433843523264, 12.485363390296698, 65.61640664935112, 71.17632910609245, 59.97104577720165, 80.28301164507866, 57.89508797228336, 68.25144365429878, 73.64949479699135, 56.76099702715874, 8.633595574647188, 0.4050592740532011, 0.44409211550373584, 0.16396284947404638, 0.2599618036765605, 0.2241190691711381, 1.943677046801895, 12.112134117633104, 47.804452031850815, 70.82397401332855, 80.49175724387169, 80.66441997885704, 82.90291026234627, 80.85561811923981, 80.26504620909691, 69.51841726899147, 65.43602272868156, 60.28627686202526, 63.293538093566895, 65.1458702981472, 71.37271776795387, 74.75061491131783, 75.25351792573929, 72.99012377858162, 73.41548055410385, 66.60263612866402, 63.770480901002884, 59.68255765736103, 64.8756667971611, 66.29970878362656, 69.59642708301544, 66.39230221509933, 66.54471203684807, 49.926820546388626, 53.7213197350502, 55.56659571826458, 57.57486775517464, 61.35826773941517, 54.39417622983456, 57.29984991252422, 57.60105215013027, 56.57438524067402, 58.48721019923687, 60.25597728788853, 60.7184124737978, 66.09356224536896, 63.97592827677727, 66.46240085363388, 62.35477566719055, 53.30772712826729, 58.86186249554157, 60.02341456711292, 57.32008382678032, 58.847491666674614, 62.059603706002235, 63.94445836544037, 62.32434310019016, 62.255152612924576, 66.562320291996, 61.934689208865166, 58.3195023983717, 56.64925642311573, 50.9240086376667, 51.979538798332214, 51.41178846359253, 48.18279393017292, 49.892827570438385, 53.41711945831776, 51.518494337797165, 56.18280865252018, 50.845128670334816, 55.531185418367386, 53.6552906781435, 53.44226270914078, 55.60852266848087, 52.34160237014294, 50.095330104231834, 53.145285844802856, 47.29974411427975, 51.02450184524059, 48.02767485380173, 46.65216766297817, 43.52686196565628, 46.3757248967886, 59.78541053831577, 60.56628383696079, 59.954463467001915, 58.65511938929558, 57.40226201713085, 58.33582252264023, 61.2625926733017, 60.941563099622726, 56.73068605363369, 53.58489565551281, 56.3060512393713, 49.19290512800217, 59.582539424300194, 60.355524346232414, 59.084477350115776, 58.92782315611839, 58.93824979662895, 54.69061732292175, 52.05692544579506, 52.114135175943375, 51.39525555074215, 50.81665679812431, 53.80795508623123, 53.2608338445425, 52.82009929418564, 55.31114682555199, 52.962177470326424, 53.14170263707638, 64.09113049507141, 66.02987766265869, 60.08641138672829, 54.552266746759415, 46.733274310827255, 38.52544493973255, 34.27251175045967, 39.628122970461845, 50.61309792101383, 58.54611083865166, 56.485276222229004, 57.170546650886536, 54.54456835985184, 55.50872482359409, 55.52741602063179, 58.026477321982384, 60.84482029080391, 64.29070338606834, 68.091791421175, 70.57392463088036, 77.75841951370239, 71.27200797200203, 67.15951904654503, 44.55971874296665, 52.05357022583485, 33.77012550830841, 15.145916976034641, 15.107329096645117, 2.608416583389044, 0.37704192276578397, 34.94778871536255, 95.8659602701664, 72.73942083120346, 86.93356677889824, 57.408052906394005, 69.4753047823906, 63.63816440105438, 85.11929333209991, 39.21804137527943, 70.44797658920288, 67.74862423539162, 12.557683009654284, 5.01290000975132, 1.762245213612914, 0.4158310132334009, 1.5632122498936951, 5.923916799947619], [4.529574494808912, 45.431749150156975, 45.92727676033974, 43.89749027788639, 31.710609421133995, 36.67521022260189, 19.391845241189003, 3.0735118640586734, 4.308016933500767, 29.16812974959612, 44.32533212006092, 23.713957518339157, 47.47041575610638, 47.58760146796703, 47.283925563097, 46.51749528944492, 13.491690941154957, 6.430624360218644, 0.09137520348303951, 0.1184711858513765, 0.1036226365249604, 0.21312262251740322, 0.21187519101658836, 0.820602779276669, 3.2894991617649794, 17.577955573797226, 69.4054265320301, 74.9398523569107, 77.62523666024208, 69.99795153737068, 71.70141533017159, 65.64379557967186, 57.8755684196949, 54.014166221022606, 53.01113024353981, 48.12597557902336, 54.88515928387642, 56.30408674478531, 59.146330431103706, 60.87802290916443, 61.40473924577236, 60.92245772480965, 60.85753060877323, 57.084040492773056, 54.73978288471699, 55.15635833144188, 58.5235970467329, 61.48845635354519, 58.08108039200306, 55.06804347038269, 47.529016211628914, 49.36858110129833, 49.39649820327759, 49.45818409323692, 51.789735183119774, 50.27466148138046, 53.15550349652767, 49.83651079237461, 51.959662064909935, 52.647314965724945, 54.520169869065285, 54.8487002402544, 57.47411236166954, 59.397325962781906, 58.31368871033192, 55.76831929385662, 47.88930147886276, 54.00583326816559, 54.42762203514576, 53.92873540520668, 55.115168541669846, 53.60504977405071, 58.7588994204998, 55.54393753409386, 60.051981434226036, 51.590371280908585, 44.86746042966843, 47.15919725596905, 53.90503607690334, 47.61901058256626, 44.31807830929756, 46.1969330906868, 44.699710831046104, 42.833406776189804, 47.40136206150055, 51.71873979270458, 50.4329913854599, 49.53582912683487, 54.29215930402279, 53.95003326237202, 50.37873789668083, 45.99752739071846, 48.13303180038929, 43.58199700713158, 41.73173949122429, 42.5673146545887, 46.92538060247898, 43.449646309018135, 46.81596167385578, 46.60523638129234, 43.802833557128906, 47.457895427942276, 52.90159732103348, 56.08372516930103, 55.72069264948368, 57.679483741521835, 52.84990109503269, 53.83933760225773, 52.455763444304466, 47.54952751100063, 43.82039621472359, 44.412811025977135, 49.728980362415314, 53.87377515435219, 49.4858618080616, 50.263600274920464, 51.66659519076347, 47.66159109771252, 46.38783484697342, 44.31368574500084, 42.141262516379356, 46.14376254379749, 48.28062728047371, 51.822493225336075, 51.65609635412693, 54.91068251430988, 54.07194972038269, 54.25441972911358, 51.73310302197933, 51.97553761303425, 50.43631240725517, 37.3883293569088, 27.648346200585365, 23.804512359201908, 11.542347092181444, 14.11839796230197, 17.651719115674496, 25.991103127598763, 36.69868916273117, 47.76231989264488, 46.66488938033581, 48.52480597794056, 50.853849202394485, 54.84676614403725, 55.62242612242699, 59.862622395157814, 60.353491455316544, 63.98149877786636, 61.41512788832188, 66.11565425992012, 60.67790664732456, 60.45876480638981, 37.88068413734436, 41.603340581059456, 33.66487495601177, 17.231518663465977, 10.364285856485367, 0.2679409005213529, 0.05454531237774063, 40.28786636888981, 75.9202453494072, 53.30963842570782, 62.62242190539837, 42.273164838552475, 39.737036526203156, 61.62606976926327, 38.25041949748993, 22.427490949630737, 32.28671930730343, 24.585805535316467, 19.214187674224377, 8.15159048885107, 1.1964906030334532, 0.7793508865870535, 2.79704914893955, 2.5056912330910563, 11.168653294444084, 60.97774475812912, 55.28129182755947, 43.85309346020222, 53.96240919828415, 52.92818829417229, 30.31240414828062, 6.553969541564584, 4.360924819484353, 34.93921637535095, 52.91512839496136, 38.68599392473698, 56.8193618953228, 54.384304359555244, 57.17751547694206, 63.39550942182541, 33.82681846618652, 16.94286335259676, 0.23762865050230175, 0.19543013360816985, 0.08200444615795277, 0.20551275898469612, 0.20798832614673302, 0.6823627534322441, 5.657675536349416, 30.470585860311985, 73.38508978486061, 75.42773097753525, 80.069949477911, 74.73264187574387, 76.19356468319893, 72.55657464265823, 63.71200583875179, 58.137321174144745, 58.852089419960976, 54.949683621525764, 60.75404316186905, 62.91347108781338, 66.80402532219887, 66.45817548036575, 66.8405869603157, 66.42131745815277, 64.76379320025444, 60.19700065255165, 58.51521089673042, 58.83824676275253, 62.211177572607994, 62.70819470286369, 59.92926701903343, 57.364423647522926, 49.64315816760063, 50.874926671385765, 50.43535865843296, 52.12012365460396, 55.84799341857433, 54.696974381804466, 54.41119931638241, 54.53669138252735, 55.32833710312843, 55.998909920454025, 57.504867911338806, 55.61542309820652, 60.55958479642868, 60.93208260834217, 61.47514566779137, 57.60704442858696, 48.303331062197685, 55.72929918766022, 54.735819697380066, 56.41950935125351, 57.670409828424454, 55.18871359527111, 60.369648188352585, 56.37736961245537, 60.924479216337204, 53.114902675151825, 45.17403557896614, 49.56494316458702, 56.26185201108456, 52.05045059323311, 47.19633266329765, 48.16667139530182, 46.70545220375061, 45.17201028764248, 46.41846880316734, 52.61729657649994, 53.15697781741619, 52.44450084865093, 57.43537724018097, 56.89484864473343, 50.67240133881569, 50.57331405580044, 50.82798019051552, 46.740425527095795, 46.41270071268082, 46.96331776678562, 47.37660638988018, 47.45601072907448, 49.90529090166092, 48.883400335907936, 45.435780733823776, 47.45646670460701, 49.80962723493576, 56.500627398490906, 57.75691978633404, 59.0719798207283, 55.44500604271889, 55.71560852229595, 53.97967167198658, 53.635501340031624, 45.20869731903076, 49.871183931827545, 53.988114818930626, 56.15049138665199, 53.89890320599079, 52.140213176608086, 53.75187769532204, 51.01847156882286, 49.09347966313362, 46.10773667693138, 44.3525006622076, 49.99086230993271, 51.89670704305172, 54.59406070411205, 54.540939554572105, 55.631564632058144, 57.17958256602287, 57.02948302030563, 52.29958802461624, 55.36761939525604, 58.12952019274235, 48.46999391913414, 39.099977910518646, 34.988492131233215, 24.847613386809826, 24.604764617979527, 29.29878193885088, 37.226264253258705, 47.063427194952965, 52.44355469942093, 53.29405166208744, 50.752345249056816, 54.17302809655666, 58.269508481025696, 58.179578706622124, 62.06747308373451, 63.983026295900345, 67.21036791801453, 67.55071565508842, 72.3589700460434, 73.79868999123573, 68.30095499753952, 50.589174404740334, 53.74648578464985, 43.289503902196884, 20.07016584277153, 10.04970833659172, 2.0080438116565347, 0.06040643849701155, 45.258231461048126, 80.67508980631828, 63.34395378828049, 69.67764392495155, 52.17323340475559, 51.257353350520134, 57.88824833929539, 55.245930925011635, 39.36522647738457, 59.777848944067955, 40.664589554071426, 9.265379123389721, 2.4372873036190867, 0.8039783744607121, 0.055076578792068176, 1.2863511499017477, 2.456679088063538, 6.672320840880275, 54.99443382024765, 62.69550338387489, 67.46869325637817, 57.5802406668663, 53.19046542048454, 44.495080411434174, 16.099920384585857, 9.308325368911028, 50.55519662797451, 72.7990548312664, 39.052161276340485, 63.71607542037964, 62.92226381599903, 67.12761595845222, 75.09898021817207, 59.40623268485069, 32.21665866672993, 0.2980211254907772, 0.5974339856766164, 0.11269414506386966, 0.42451669403817505, 0.5938118894118816, 2.1797817712649703, 13.186861798167229, 44.57721300423145, 81.87684372067451, 76.3383749127388, 84.24327313899994, 76.27236485481262, 80.74575081467628, 74.90659654140472, 66.97708323597908, 64.01810601353645, 64.33076083660126, 58.08095879852772, 64.44689780473709, 67.2622275352478, 73.20949360728264, 71.44791573286057, 74.73831117153168, 72.74401858448982, 69.4748792052269, 64.09852489829063, 62.31244593858719, 59.46108654141426, 62.72478461265564, 64.79336321353912, 62.75082841515541, 59.91056062281132, 51.47478528320789, 55.286284759640694, 53.598647117614746, 54.438869431614876, 59.70946781337261, 57.93008029460907, 58.506919741630554, 55.455850660800934, 57.67129898071289, 59.586210027337074, 60.797463431954384, 59.9051459133625, 61.40341691672802, 63.71721535921097, 63.091696724295616, 59.806446209549904, 50.06921790540218, 57.30236537754536, 58.58913592994213, 60.21535746753216, 59.62767720222473, 57.998282834887505, 65.86489051580429, 62.698490023612976, 61.97108745574951, 53.334006518125534, 48.2810490578413, 50.275744423270226, 57.21800610423088, 54.359883069992065, 50.616118758916855, 50.807054713368416, 49.52425494790077, 46.44388563930988, 50.64418025314808, 58.58536273241043, 56.038192212581635, 54.64456379413605, 58.731932267546654, 58.809410110116005, 53.88861335813999, 52.41319052875042, 52.78410382568836, 49.767312705516815, 48.51736597716808, 51.288466081023216, 52.59936913847923, 49.91544395685196, 50.44461876153946, 49.17592003941536, 45.32892666757107, 49.30370718240738, 54.34357434511185, 60.56942626833916, 60.998845025897026, 62.276959642767906, 58.21569196879864, 59.25650931894779, 57.34147667884827, 57.09301181137562, 50.797570422291756, 53.50772179663181, 55.96770599484444, 58.88890944421291, 55.07781274616718, 55.375142991542816, 57.65091687440872, 55.31663753092289, 52.899142652750015, 51.72860786318779, 48.021781370043755, 53.38197134435177, 56.3222611695528, 59.67105947434902, 57.905936390161514, 60.09602107107639, 59.998556300997734, 59.65949289500713, 55.63374571502209, 60.03610968589783, 63.9755254983902, 61.32615566253662, 52.78450280427933, 49.31544475257397, 36.78594768047333, 40.61274513602257, 47.19867713749409, 51.69342175126076, 56.64218120276928, 56.33947044610977, 56.20528444647789, 53.403979763388634, 57.307696491479874, 59.70268897712231, 60.976882204413414, 64.75776672363281, 66.98700070381165, 70.60310706496239, 69.59138095378876, 71.71604454517365, 75.6908592581749, 71.23833417892456, 58.431159406900406, 58.73962305486202, 48.23149211704731, 21.056442819535732, 15.677709840238094, 3.1224933732300997, 0.13673165522050112, 50.414019003510475, 87.78637021780014, 66.43675222992897, 79.84353482723236, 60.22381581366062, 62.26178325712681, 64.82186168432236, 61.804876774549484, 70.42373389005661, 84.62326034903526, 67.08761170506477, 27.192720249295235, 11.100988425314426, 3.690194310620427, 0.6736055889632553, 9.322720896452665, 13.040568698197603], [1.2757879542186856, 15.995640680193901, 35.10436691343784, 38.37753787636757, 34.83569473028183, 28.401961661875248, 9.148946721106768, 5.538253169506788, 4.183418294414878, 19.036934785544872, 40.72873771190643, 24.075084440410137, 42.38453306257725, 46.147862523794174, 55.06984457373619, 55.466623082756996, 21.567312106490135, 3.0875817965716124, 0.1059181141317822, 0.2937299385666847, 0.06689869813271798, 0.10519714734982699, 0.8065173507202417, 2.3183491732925177, 8.361738212406635, 38.850103318691254, 74.32730242609978, 75.92571705579758, 77.11661875247955, 73.13394606113434, 70.59125170111656, 66.98304131627083, 63.5923008620739, 56.61516845226288, 55.0144549459219, 48.52778501808643, 52.191457226872444, 54.917742535471916, 59.969829842448235, 59.93368238210678, 61.02304592728615, 60.81066012382507, 61.89623527228832, 60.14652796089649, 55.14735661447048, 53.889627903699875, 54.96785804629326, 57.57503494620323, 54.430566877126694, 50.8366285264492, 46.27786494791508, 49.590793177485466, 48.22450429201126, 48.07261884212494, 47.82126992940903, 51.78850404918194, 49.120006039738655, 50.444383174180984, 51.18833765387535, 52.015948444604874, 53.50220829248428, 55.04906728863716, 55.392257273197174, 58.80581170320511, 59.64319556951523, 58.46895597875118, 48.17721202969551, 52.30966128408909, 53.0967852473259, 52.436973452568054, 50.74577160179615, 53.75039577484131, 54.764948934316635, 56.299830973148346, 46.51335351169109, 44.90828923881054, 50.0495083630085, 48.08869577944279, 52.86930665373802, 45.77944949269295, 42.908946722745895, 42.869474440813065, 44.51818697154522, 46.37259006500244, 45.25333732366562, 45.16477547585964, 48.38536486029625, 46.482115387916565, 52.20234364271164, 53.827748224139214, 49.1545157879591, 44.8903352022171, 45.69317892193794, 43.48539859056473, 42.220993638038635, 41.72126345336437, 41.75373271107674, 41.31317675113678, 46.887720823287964, 47.125014290213585, 37.175574973225594, 34.77851539850235, 46.43109172582626, 44.233221262693405, 49.393101185560226, 53.14932502806187, 56.14078290760517, 56.38603314757347, 49.41667132079601, 47.354890555143356, 45.98933883011341, 47.80405305325985, 55.90768061578274, 50.301461443305016, 51.86655566096306, 48.641459718346596, 49.88181576132774, 45.72577737271786, 43.42102624475956, 42.655583918094635, 42.179454267024994, 47.64199934899807, 51.082661524415016, 52.3649787157774, 54.292489886283875, 56.934043541550636, 58.4486498683691, 58.59770447015762, 57.07235611975193, 51.89622826874256, 48.43792364001274, 40.94121851027012, 37.73822218179703, 28.4889579936862, 19.213887490332127, 21.734928712248802, 25.145350210368633, 35.773131027817726, 41.919901594519615, 47.637861371040344, 47.11458384990692, 49.72632050514221, 53.41117277741432, 54.09309558570385, 60.1261268556118, 61.345762610435486, 64.96654272079468, 61.298470348119736, 64.75022032856941, 63.934799283742905, 62.44190499186516, 63.13657231628895, 49.06090781092644, 51.03011034429073, 49.52760636806488, 23.298229426145554, 10.962494406849146, 1.16779311792925, 0.374256701907143, 51.18397928774357, 74.92495715618134, 54.52532239258289, 60.69403298199177, 38.68289329111576, 35.27387581765652, 55.33781759440899, 24.98613305389881, 21.653117202222347, 17.923947907984257, 30.611664690077305, 20.514105521142483, 2.9577194899320602, 2.2331871930509806, 0.22502438543597236, 2.842872552573681, 1.700583784841001, 2.8655093628913164, 31.804084405303, 49.63803604245186, 46.1273892223835, 42.69385166466236, 39.48499225080013, 19.86768800765276, 6.5991605166345835, 3.9008944295346737, 25.674935393035412, 48.37702430784702, 32.063374891877174, 51.32391057908535, 51.882108226418495, 63.31028759479523, 69.85884860157967, 40.90078108012676, 9.439285341650248, 0.07717100903391838, 0.33229418797418475, 0.10816160429385491, 0.08502865341142751, 0.5588618398178369, 0.8120115590281785, 6.733536506071687, 49.056180864572525, 74.8138815164566, 76.13309472799301, 79.98861104249954, 77.58208617568016, 75.38321256637573, 71.8526928126812, 67.72998243570328, 60.762581303715706, 58.37390407919884, 54.74100261926651, 60.38004443049431, 61.87734268605709, 66.22134938836098, 66.89193740487099, 67.42989733815193, 66.2782171368599, 66.65831834077835, 64.54383820295334, 59.426755383610725, 56.618295684456825, 58.19217503070831, 58.81838522851467, 55.536106154322624, 53.29562097787857, 49.75109897553921, 51.217041313648224, 49.93382357060909, 50.19645407795906, 51.229664236307144, 54.30582717061043, 53.06835897266865, 55.29183246195316, 54.61986131966114, 55.88577479124069, 58.09326633810997, 58.47036950290203, 59.57772508263588, 60.21578684449196, 63.42699073255062, 59.54992577433586, 51.31204001605511, 52.84944511950016, 54.418563321232796, 53.973724991083145, 52.50552177429199, 57.25980386137962, 57.23930776119232, 58.09906862676144, 49.40890833735466, 49.1329937428236, 51.040951162576675, 48.90834219753742, 55.18217794597149, 47.47325800359249, 44.54872213304043, 45.499047338962555, 45.104263722896576, 49.040084928274155, 46.43693961203098, 47.12140828371048, 50.76169654726982, 50.96802927553654, 54.44589525461197, 55.943102315068245, 48.84894758462906, 49.00309771299362, 48.02398145198822, 46.133294105529785, 45.455752462148666, 44.74728047847748, 43.28649066388607, 42.84620828926563, 46.24730698764324, 51.95729099214077, 40.425323992967606, 37.96807184815407, 47.67490178346634, 43.912457674741745, 51.01802699267864, 55.6575932353735, 58.17941911518574, 59.48369912803173, 54.01455000042915, 49.346587881445885, 50.41254848241806, 48.490125238895416, 58.69697034358978, 54.180361703038216, 54.488312378525734, 53.09950590133667, 50.178853422403336, 50.74120804667473, 46.22521497309208, 46.00575014948845, 41.97480104863644, 48.55874955654144, 52.842939868569374, 55.14580249786377, 57.05079607665539, 57.30684153735638, 60.84213763475418, 59.595523327589035, 60.304211899638176, 56.700933650135994, 55.47439366579056, 50.29567435383797, 48.41363534331322, 36.92626275122166, 32.44683891534805, 33.51752266287804, 37.39748306572437, 44.34042491018772, 49.56400081515312, 51.860593780875206, 51.13703280687332, 54.85436953604221, 56.19872219860554, 60.133787244558334, 63.22410821914673, 67.90777489542961, 68.86756539344788, 67.5614158809185, 69.98900681734085, 72.66628235578537, 70.63797399401665, 69.87440496683121, 59.26412791013718, 57.28248484432697, 58.06009791791439, 29.675999097526073, 11.844070851802826, 1.8029608600772917, 0.2939053229056299, 59.92131784558296, 77.02674597501755, 64.95870754122734, 63.38683068752289, 51.217736676335335, 42.60054387152195, 56.388746201992035, 46.34362041950226, 48.598514422774315, 44.3006182461977, 40.42956456542015, 21.849426068365574, 9.157437365502119, 1.6812790394760668, 0.41490318020805717, 3.1539618596434593, 2.6314271986484528, 1.8755224789492786, 19.78978268802166, 47.865362763404846, 50.47363020479679, 47.17843942344189, 38.31498563289642, 23.74124575406313, 16.716131418943405, 8.157303482294083, 38.44542883336544, 72.60805428028107, 38.77587050199509, 58.8011721521616, 61.38039395213127, 75.44230699539185, 78.76115530729294, 60.747127532958984, 25.337112620472908, 0.32092457462567836, 0.7325400703120977, 0.2481194571009837, 0.31467928318306804, 0.6297328462824225, 4.924353836104274, 23.477304317057133, 62.71020479500294, 77.8136457502842, 77.24280998110771, 84.48790401220322, 78.3234415948391, 78.82189884781837, 75.30365243554115, 73.33981141448021, 65.55066257715225, 62.635914981365204, 56.4546612650156, 64.4678346812725, 63.43872830271721, 71.65079444646835, 72.8243462741375, 74.62217420339584, 71.6838450729847, 70.66492974758148, 68.82835909724236, 61.83155134320259, 59.85555857419968, 59.48791690170765, 61.30412444472313, 58.403485491871834, 55.19741132855415, 51.010928973555565, 54.21497784554958, 54.24116984009743, 54.28443431854248, 54.81308855116367, 57.282830625772476, 57.2528388351202, 59.29790809750557, 57.7140960842371, 56.79298371076584, 57.931414023041725, 61.00614823400974, 59.85965855419636, 64.16132032871246, 64.00658503174782, 63.724852949380875, 52.70096808671951, 57.641641572117805, 57.70094878971577, 55.81252612173557, 56.75835996866226, 61.62904500961304, 60.26906378567219, 61.3422591984272, 52.311785370111465, 48.685476556420326, 52.40613050758839, 52.69086442887783, 55.85071787238121, 51.417256370186806, 46.59712761640549, 47.42388725280762, 47.96178638935089, 53.131469786167145, 49.021655917167664, 50.77571779489517, 53.702955320477486, 53.12103174626827, 55.456485226750374, 58.590743243694305, 54.24119643867016, 51.792034059762955, 50.78924506902695, 47.83744566142559, 47.36443564295769, 47.205740958452225, 46.66412942111492, 46.07599318027496, 49.62041638791561, 53.686825186014175, 41.67156971991062, 40.887295603752136, 49.48679655790329, 45.00905603170395, 55.06606377661228, 59.294594675302505, 60.18983043730259, 61.61457158625126, 55.642679035663605, 51.61353103816509, 54.142356142401695, 57.1182918548584, 62.95604780316353, 55.918962210416794, 57.37523406744003, 57.035650089383125, 56.93027414381504, 54.95917551219463, 50.654990673065186, 51.0931109637022, 46.57016046345234, 54.704862758517265, 57.962815538048744, 58.423286229372025, 60.311758294701576, 59.72814001142979, 63.33380453288555, 62.98431448638439, 63.03830958902836, 60.25697663426399, 60.017954260110855, 59.839196652173996, 61.461724787950516, 49.52809654176235, 45.35266399383545, 49.972551092505455, 54.19880211353302, 57.958210185170174, 56.370070204138756, 55.22971719503403, 54.35913451015949, 55.87582692503929, 58.77832777798176, 62.45312198996544, 66.02970287203789, 69.19830724596977, 70.39915680885315, 68.6273042857647, 71.68139800429344, 73.32696050405502, 72.70718336105347, 70.52095547318459, 64.34870347380638, 65.72451084852219, 64.93182018399239, 30.768600068986416, 19.44566175341606, 2.9571917932480574, 0.36520754685625434, 65.84197774529457, 81.77235692739487, 69.59717944264412, 73.23948919773102, 58.63723374903202, 52.147903963923454, 63.08657079935074, 52.939762473106384, 63.929578363895416, 51.56743571162224, 37.59666457772255, 28.10425903648138, 20.890213139355183, 3.8849782710894942, 1.8763899011537433, 9.298067819327116, 13.918532487004995], [0.13999765418702736, 2.1004828764125705, 13.44325304031372, 23.82288247346878, 18.869418874382973, 10.459367204457521, 1.432312005199492, 3.3615430584177375, 3.7750525446608663, 18.931596837937832, 34.171729758381844, 30.070554725825787, 37.141874581575394, 43.17507304251194, 55.96812777221203, 65.85419028997421, 32.27467015385628, 13.764735739678144, 0.411497731693089, 0.08876231673639268, 0.10182375961448997, 0.29708625690545887, 2.1310745598748326, 6.667033899575472, 16.13268032670021, 59.98384349048138, 76.42696335911751, 72.06326231360435, 74.84522983431816, 76.05731159448624, 73.00182715058327, 71.23944371938705, 67.17908799648285, 60.53231745958328, 53.6552032828331, 51.23499155044556, 47.78509587049484, 57.41103954613209, 58.60625021159649, 63.19738805294037, 60.87185584008694, 61.06369234621525, 64.2544837296009, 62.18859538435936, 61.45649626851082, 55.39070315659046, 50.46145185828209, 51.51866912841797, 51.74518257379532, 49.56892155110836, 51.26510493457317, 47.780638709664345, 47.16017000377178, 48.98391254246235, 48.056743294000626, 49.175984635949135, 48.94758269190788, 52.03408487141132, 51.59873843193054, 54.13920611143112, 56.31313405930996, 58.44915524125099, 58.51729318499565, 57.13958591222763, 60.86005747318268, 58.42526592314243, 53.23572099208832, 52.68448457121849, 51.042649671435356, 48.2644097507, 50.22874474525452, 54.40627858042717, 56.163004115223885, 53.116677179932594, 50.500190779566765, 42.84855276346207, 47.32545733451843, 50.59681199491024, 49.07784730195999, 46.06669507920742, 43.04116062819958, 41.576593816280365, 43.112357407808304, 43.61472465097904, 44.01371084153652, 43.59810434281826, 43.69467616081238, 47.178188636898994, 51.46611414849758, 52.22206458449364, 47.95302025973797, 43.05616222321987, 44.25494849681854, 41.20153494179249, 42.32721693813801, 40.09758397936821, 39.36394214630127, 42.43617609143257, 45.170995742082596, 45.90598650276661, 44.4908132404089, 41.976009383797646, 42.21335984766483, 44.09905806183815, 45.61906009912491, 49.79751728475094, 50.46174444258213, 50.466490387916565, 47.990626841783524, 46.565353721380234, 49.281930550932884, 44.11185957491398, 50.10303609073162, 57.70308427512646, 50.80142721533775, 51.83944411575794, 48.08182954788208, 47.51857817173004, 44.105194732546806, 42.90018819272518, 42.35483005642891, 44.60824593901634, 49.84604448080063, 53.63434240221977, 58.380762711167336, 58.63301217556, 60.239991545677185, 62.327474132180214, 59.828887805342674, 57.2227368503809, 54.104943349957466, 47.80346788465977, 48.537322506308556, 40.324067026376724, 30.954691283404827, 37.27186560630798, 42.292536199092865, 45.67888788878918, 46.780034601688385, 49.98441405594349, 49.06845040619373, 51.03339336812496, 54.14845481514931, 58.07367078959942, 64.53356355428696, 60.260563641786575, 64.1676963865757, 64.2349299788475, 66.88759803771973, 64.81648877263069, 66.03207394480705, 62.22924180328846, 66.78042098879814, 58.81256394088268, 65.4393969476223, 41.100422367453575, 10.135911460965872, 0.2762547059683129, 1.5720561565831304, 56.47175274789333, 66.44923835992813, 49.08130131661892, 53.08896146714687, 38.73001456260681, 24.729916602373123, 44.14761945605278, 25.707782730460167, 28.97326100617647, 45.30328184366226, 45.40538236498833, 14.326110016554594, 4.545410145074129, 4.807045105844736, 1.8403645092621446, 4.985842611640692, 1.048706795554608, 0.2389916789252311, 7.622262267395854, 24.64830458164215, 35.75665891170502, 30.13426400721073, 24.860395900905132, 12.0500672981143, 4.915880765765905, 3.0798660730943084, 24.234339594841003, 42.99356058239937, 32.26240821182728, 45.20979546010494, 49.68871772289276, 67.26140677928925, 74.07760262489319, 52.589877247810364, 23.69570329785347, 0.24463747831759974, 0.2893036213936284, 0.3418563154991716, 0.1295990965445526, 2.447344888933003, 7.004314726218581, 17.58102960884571, 64.27988916635513, 75.51512628793716, 75.88538601994514, 78.3011519908905, 78.23518753051758, 75.20899951457977, 75.87780922651291, 70.99912941455841, 64.94951203465462, 56.32678672671318, 54.494677037000656, 54.26912114024162, 62.158269211649895, 63.8480119407177, 67.70330026745796, 64.84038189053535, 68.53518962860107, 67.78945684432983, 66.67603299021721, 65.287184715271, 58.64943489432335, 53.09013560414314, 52.851147428154945, 53.86033147573471, 51.33228152990341, 52.118972316384315, 49.60707530379295, 48.91870804131031, 50.796232894062996, 51.48289404809475, 53.089485839009285, 53.6874445527792, 54.251330494880676, 54.36932556331158, 58.781291618943214, 59.36735697090626, 59.505973532795906, 61.14949934184551, 61.60990923643112, 62.81851038336754, 59.69797343015671, 55.768999457359314, 53.83343271911144, 52.61997923254967, 51.58603571355343, 53.59239265322685, 57.127164378762245, 58.91089886426926, 55.84270030260086, 51.39690466225147, 46.0244907438755, 47.36865721642971, 51.689971536397934, 51.19557626545429, 47.30915240943432, 44.94430370628834, 43.768703788518906, 46.61629758775234, 45.563875660300255, 45.123342499136925, 43.90636660158634, 44.820285961031914, 48.862467259168625, 54.504461511969566, 52.83908307552338, 50.03243587911129, 45.631071254611015, 45.305573120713234, 42.15325087308884, 45.13708636164665, 42.505020797252655, 43.52676697075367, 43.87878768146038, 47.788990661501884, 48.20604868233204, 47.251102924346924, 44.29545812308788, 42.21486076712608, 45.0994835793972, 47.76704303920269, 52.84050799906254, 51.85632660984993, 52.999806851148605, 50.84479808807373, 48.496486097574234, 51.20582051575184, 50.76972171664238, 51.396950259804726, 60.04155479371548, 56.02762497961521, 52.936521247029305, 50.97437493503094, 51.07543811202049, 47.15271860361099, 46.44565634429455, 44.41812314093113, 45.56481420993805, 51.0152455419302, 55.04124730825424, 59.280436635017395, 60.51471680402756, 61.6599677503109, 64.07907754182816, 61.91632479429245, 60.43163426220417, 59.310390427708626, 54.59964260458946, 56.75750121474266, 50.87917864322662, 44.13737140595913, 47.85870172083378, 52.23946385085583, 53.79911296069622, 54.76158231496811, 53.80179941654205, 53.35956774652004, 54.2850536853075, 59.00715529918671, 62.10017032921314, 68.3234877884388, 64.14571076631546, 69.011220484972, 69.31731685996056, 72.91484981775284, 71.17346405982971, 74.74415525794029, 69.93338540196419, 76.5147614479065, 68.0464218556881, 73.36345374584198, 48.66865485906601, 13.306397683918476, 0.8192207221873105, 2.1888352604582906, 67.55057126283646, 71.66321218013763, 61.37000530958176, 62.06913739442825, 46.36606201529503, 32.47419744729996, 51.90521478652954, 35.522177293896675, 37.99808643758297, 40.833596885204315, 45.805979669094086, 18.327269665896893, 6.085363011807203, 6.988405454903841, 4.53575343824923, 3.4976220689713955, 3.652381827123463, 0.30815304431598634, 2.543397559784353, 17.601176127791405, 29.749145172536373, 27.85184048116207, 19.140973202884197, 12.034185100346804, 9.763518143445253, 5.929911453276873, 34.9997965246439, 69.0161070227623, 44.1633316129446, 55.70751875638962, 58.98853249847889, 76.6021491587162, 83.40031117200851, 69.94970932602882, 38.50659795105457, 0.6790054554585367, 0.7829275040421635, 0.37432990735396743, 0.2927004313096404, 1.7530637187883258, 10.164463128894567, 40.191400945186615, 68.4832464158535, 79.64874967932701, 74.53374534845352, 83.19858759641647, 80.83190739154816, 80.45084863901138, 78.1843538582325, 76.82803183794022, 69.11620885133743, 59.51275236904621, 56.95812284946442, 56.68423734605312, 66.93013295531273, 69.05007719993591, 72.34991893172264, 71.61752343177795, 72.71224468946457, 71.94118246436119, 69.7729580104351, 69.73628997802734, 60.26348568499088, 55.33271446824074, 55.7210536301136, 55.93475416302681, 55.579891204833984, 54.19214107096195, 50.718815848231316, 51.773453056812286, 53.97264584898949, 53.199292346835136, 55.68302147090435, 55.59373006224632, 59.098718985915184, 54.55312170088291, 60.205854177474976, 62.963780388236046, 65.79809010028839, 63.31198990345001, 61.82340458035469, 63.591381311416626, 63.04954178631306, 57.088463455438614, 59.91861239075661, 56.7776857316494, 53.780816942453384, 55.52614688873291, 60.71783870458603, 59.65084455907345, 59.04786631464958, 55.8744627982378, 50.06153851747513, 49.688326343894005, 55.4028283059597, 52.89660818874836, 48.02442602813244, 48.67273963987827, 48.84244993329048, 49.255271181464195, 49.01626780629158, 49.50753204524517, 49.222300350666046, 47.50574246048927, 50.10339327156544, 58.5013872385025, 57.568324506282806, 52.898637279868126, 50.08609279990196, 48.83302263915539, 45.70097990334034, 47.15327337384224, 45.47821305692196, 45.33309504389763, 48.03181283175945, 49.16954018175602, 50.88631846010685, 48.70122671127319, 45.37564896047115, 43.92747826874256, 46.476575285196304, 48.878992572426796, 55.3357695043087, 53.97751338779926, 56.62723280489445, 52.577812895178795, 51.75620578229427, 52.55837693810463, 56.13741248846054, 57.390353456139565, 63.547527864575386, 58.13188746571541, 57.08671934902668, 56.06389403343201, 52.82498583197594, 50.45984074473381, 50.0885246694088, 49.0067683160305, 48.82950022816658, 56.65584146976471, 57.82843194901943, 63.34695182740688, 61.224697306752205, 65.98548844456673, 66.91814839839935, 66.44318908452988, 63.065079152584076, 62.72691249847412, 59.48933802545071, 63.982631117105484, 57.09408335387707, 53.3159688860178, 58.59991975128651, 61.66471749544144, 60.614830031991005, 58.16812612116337, 55.85975378751755, 56.53131455183029, 55.50862982869148, 59.33393396437168, 64.64517876505852, 69.62266847491264, 65.76821610331535, 70.86748167872429, 71.81353211402893, 73.50004881620407, 69.99638602137566, 75.68375363945961, 70.92336148023605, 74.05975118279457, 65.71426659822464, 75.03201261162758, 51.52690328657627, 20.31106721609831, 1.8214955530129373, 2.7131183026358485, 73.9011400938034, 79.24643486738205, 67.76351183652878, 71.189484000206, 56.686106845736504, 39.02946889400482, 58.37954677641392, 47.74438865482807, 58.31815347075462, 72.33138352632523, 73.50419819355011, 36.921904385089874, 17.25029345601797, 18.43362405896187, 14.071897007524967, 20.73821559548378, 8.75050200149417], [0.0446273398847552, 0.2038657700177282, 2.184973005205393, 9.572355151176453, 8.986745774745941, 2.6224012579768896, 1.3540598354302347, 1.9469157792627811, 2.7768275840207934, 16.488177850842476, 36.000921204686165, 30.850263386964798, 44.161526709795, 49.81738641858101, 53.20806607604027, 74.27212178707123, 44.00065094232559, 33.682190626859665, 0.24584180588135496, 0.1606044828076847, 0.6523328460752964, 0.2488361787982285, 1.7203854722902179, 17.2991531342268, 38.43701608479023, 72.52015739679337, 80.57532235980034, 75.36293685436249, 72.54969701170921, 73.85819479823112, 71.11795663833618, 72.64973044395447, 69.24499914050102, 65.1264077425003, 52.42643281817436, 50.04803404211998, 50.099901258945465, 52.82828785479069, 57.04179435968399, 57.97301419079304, 62.155936136841774, 63.5560318082571, 62.955702021718025, 60.45418985188007, 61.4767149835825, 62.02440619468689, 56.63183815777302, 50.969313606619835, 51.345911398530006, 48.859457820653915, 50.526207983493805, 48.08062881231308, 47.597412541508675, 48.1349278986454, 48.465650752186775, 47.53468170762062, 51.22668519616127, 52.62338384985924, 54.499426782131195, 54.01255890727043, 56.735637187957764, 54.83336426317692, 56.46135650575161, 58.122862949967384, 56.13870441913605, 56.41911417245865, 53.88606749475002, 52.62589551508427, 48.29046495258808, 48.77194091677666, 49.31177414953709, 52.460152208805084, 54.00397516787052, 52.20125690102577, 46.69440999627113, 45.75334869325161, 45.33882133662701, 49.85419504344463, 45.012225061655045, 44.38450254499912, 44.47622962296009, 45.935678109526634, 43.139902129769325, 44.07899893820286, 42.35141023993492, 45.32393753528595, 43.37211526930332, 47.645236775279045, 46.75891913473606, 47.697700560092926, 44.326536655426025, 42.10903264582157, 41.46701529622078, 42.529407888650894, 42.06940457224846, 42.21372462809086, 41.04062877595425, 42.45942324399948, 42.89624400436878, 43.074636831879616, 44.84387129545212, 44.91581663489342, 40.57270668447018, 41.71221233904362, 46.77066430449486, 48.37007448077202, 48.08586113154888, 44.57701161503792, 51.48517772555351, 49.25101161003113, 46.97751760482788, 48.97416226565838, 48.48190627992153, 49.51312534511089, 54.10935491323471, 50.79986169934273, 50.59218384325504, 48.36060918867588, 45.99913090467453, 46.09506815671921, 44.27151560783386, 43.72792437672615, 49.65250566601753, 51.589440330863, 53.6606901884079, 56.983691677451134, 59.120320826768875, 59.47590954601765, 59.841784313321114, 57.48314447700977, 58.2787761837244, 53.22801120579243, 56.40235707163811, 41.65931537747383, 40.663859993219376, 49.78364422917366, 53.16972233355045, 53.94480474293232, 50.292851105332375, 48.79691317677498, 47.509226873517036, 49.18472036719322, 53.90879787504673, 58.503575921058655, 59.77850250899792, 63.728325963020325, 63.32910418510437, 61.555252969264984, 60.5241023004055, 63.526955768465996, 63.58164243400097, 66.14372715353966, 66.42968460917473, 62.805104702711105, 66.35489702224731, 69.73106905817986, 27.947103269398212, 0.3641569329192862, 5.291010411456227, 68.65212455391884, 62.547660917043686, 46.07111804187298, 48.0039869248867, 44.56956401467323, 30.81722415983677, 30.66375609487295, 33.737527057528496, 35.73430471122265, 49.39304418861866, 27.921815626323223, 5.423357309773564, 3.488722234033048, 4.298083316534758, 5.359492711722851, 7.903359783813357, 0.10716336371842772, 0.0625841409782879, 1.1620114906691015, 7.775973994284868, 16.915719509124756, 18.251100853085518, 11.033447999507189, 5.631552888080478, 2.5353923393413424, 2.69944426137954, 24.313027672469616, 46.64912022650242, 26.258635371923447, 47.09066793322563, 56.96476869285107, 62.895691841840744, 83.6626110970974, 59.60627295076847, 48.078147545456886, 0.39860644843429327, 0.37071487633511424, 1.6219056816771626, 0.16474732925416902, 2.1277069905772805, 17.652988247573376, 43.59881490468979, 76.50843098759651, 79.75038662552834, 77.75908067822456, 77.51714766025543, 79.95584160089493, 77.79938131570816, 76.6090951859951, 73.11340436339378, 70.69072276353836, 56.83212161064148, 54.665622264146805, 55.75310491025448, 57.44707301259041, 62.233372181653976, 64.31781873106956, 67.31287121772766, 67.18888387084007, 66.92073985934258, 66.45249098539352, 65.51236063241959, 64.05266895890236, 58.46859119832516, 52.86695837974548, 53.67102563381195, 50.15883609652519, 51.1822085827589, 51.120777279138565, 49.763098731637, 50.4934461414814, 51.179970502853394, 50.391338020563126, 54.87465284764767, 55.15392266213894, 58.24171297252178, 57.034920528531075, 58.63823689520359, 57.49290615320206, 58.24444122612476, 59.27746519446373, 60.02224043011665, 57.67520137131214, 56.81639425456524, 55.43036922812462, 53.1484130769968, 53.16516637802124, 51.30999952554703, 53.78376178443432, 59.83742214739323, 53.70909959077835, 49.0599312633276, 48.344885632395744, 48.49432781338692, 50.72416216135025, 45.27873136103153, 45.727335289120674, 47.42799483239651, 47.27229058742523, 45.64123950898647, 47.20996253192425, 43.77964720129967, 47.99515999853611, 45.25462545454502, 47.71118603646755, 49.789564311504364, 50.279764607548714, 47.7717661857605, 44.77455161511898, 43.97119112312794, 45.95258720219135, 45.158509612083435, 46.94939151406288, 43.87189105153084, 44.40380930900574, 44.267480224370956, 45.947092697024345, 46.60359486937523, 45.37254072725773, 42.432782873511314, 41.67880453169346, 48.71594712138176, 49.48079288005829, 50.46124666929245, 48.41715395450592, 51.03047892451286, 51.663551554083824, 49.816037490963936, 52.596420496702194, 53.96602280437946, 52.85697251558304, 56.715331077575684, 52.66711950302124, 53.53351481258869, 50.699991658329964, 47.43444308638573, 49.14183586835861, 48.56813125312328, 45.364545956254005, 50.41126035153866, 52.70633339881897, 55.857736095786095, 58.84446702897549, 60.74163302779198, 61.44829250872135, 63.03145095705986, 62.19851665198803, 62.19456486403942, 59.4000618159771, 64.96439963579178, 51.4650122076273, 50.43343976140022, 59.09716106951237, 62.48705416917801, 59.50575314462185, 57.156191021203995, 55.23659482598305, 53.27469930052757, 54.83958452939987, 58.88861306011677, 62.99118831753731, 64.75231021642685, 68.047364205122, 67.97698438167572, 68.10004457831383, 70.36499664187431, 72.03675493597984, 72.51711755990982, 72.5950437784195, 75.68830579519272, 71.7906041443348, 70.63678845763206, 73.98573115468025, 34.83399622142315, 0.5657266464550048, 6.572262234985828, 79.11209687590599, 69.47506159543991, 57.590583711862564, 56.66423141956329, 53.92095722258091, 41.57563626766205, 33.86657193303108, 37.24119745194912, 46.85516037046909, 60.5274423211813, 45.84323666989803, 16.82504877448082, 8.841648660600185, 4.70979074947536, 6.266170609742403, 5.551699222996831, 0.4232818493619561, 0.11059271681006067, 0.44673873286228627, 2.8792648622766137, 12.054153978824615, 12.086665034294128, 7.357003726065159, 3.821156183257699, 3.576346244663, 4.014453236013651, 38.264015167951584, 67.47468933463097, 46.88645549118519, 60.06148472428322, 67.08552181720734, 70.36210879683495, 91.78827747702599, 67.55462944507599, 64.0723367035389, 0.8544090902432799, 0.5158087844029069, 1.327230662573129, 0.3696547925937921, 5.242928741499782, 23.52454338222742, 58.099308013916016, 80.87346196174622, 82.87304386496544, 78.95965665578842, 78.34321573376656, 81.38681441545486, 77.64668270945549, 77.06136211752892, 73.76193836331367, 72.78745785355568, 58.7951684743166, 58.21656212210655, 59.18917313218117, 61.030022352933884, 65.88442146778107, 68.00421372056007, 70.60072839260101, 69.00808945298195, 70.22527813911438, 68.72804448008537, 69.72922995686531, 65.56846842169762, 62.842844277620316, 56.36989541351795, 55.44488824903965, 52.28576056659222, 55.44011950492859, 52.47108422219753, 52.51448169350624, 52.489061057567596, 54.36243273317814, 51.85631521046162, 56.71407334506512, 57.50688560307026, 59.6339126676321, 59.503701254725456, 63.88219490647316, 59.012684002518654, 60.91858193278313, 62.101013883948326, 63.265582993626595, 60.85044778883457, 56.99126847088337, 60.08380092680454, 52.74569928646088, 55.30037060379982, 54.337065294384956, 57.58712209761143, 60.817188173532486, 58.37323151528835, 50.42606055736542, 49.34222191572189, 48.47799248993397, 53.88386361300945, 48.714537397027016, 49.71206746995449, 48.612303882837296, 51.2597282230854, 48.27148877084255, 50.792965069413185, 45.44023409485817, 52.325194850564, 46.53894133865833, 53.11997540295124, 52.645069286227226, 53.54770325124264, 49.640988484025, 47.581077218055725, 46.25049501657486, 47.375006675720215, 47.73214191198349, 49.608314037323, 45.74147433042526, 46.925160214304924, 46.85316547751427, 47.91697919368744, 49.57462504506111, 49.2397528141737, 44.287835732102394, 44.152167811989784, 53.248556703329086, 51.86004661023617, 53.87947104871273, 51.268167570233345, 57.76552252471447, 56.556081622838974, 53.39650556445122, 53.58396850526333, 56.095603331923485, 56.092859879136086, 60.84312938153744, 58.67666803300381, 58.09581980109215, 54.30199697613716, 51.94598279893398, 51.77694886922836, 50.71116305887699, 48.16076271235943, 54.527081698179245, 57.502569034695625, 57.55864642560482, 60.27972221374512, 63.53852994740009, 64.46564599871635, 66.38268113136292, 63.48559878766537, 64.04862597584724, 59.1091114282608, 66.02740779519081, 52.948201820254326, 55.93143314123154, 65.28919100761414, 66.61397472023964, 60.868990793824196, 57.889574468135834, 55.70338077843189, 54.80949014425278, 55.787094086408615, 60.27278758585453, 65.97507700324059, 65.5700871348381, 67.1457713842392, 68.12931820750237, 68.59267294406891, 70.27663618326187, 74.13510873913765, 73.79102200269699, 74.50733676552773, 75.8873163163662, 74.19468954205513, 74.34201523661613, 76.13910600543022, 42.115089520812035, 0.7331501157023013, 7.009803056716919, 87.47482493519783, 75.80580309033394, 65.27310267090797, 62.66614615917206, 65.65024763345718, 45.36439776420593, 43.702340349555016, 53.07975456118584, 65.41429549455643, 76.56014621257782, 54.67032641172409, 31.38547606766224, 27.434001602232456, 19.233600832521915, 33.968721851706505, 41.68769225478172, 0.39070299128070474], [0.08470256114378572, 0.040228389407275245, 0.12426082830643281, 0.9904562181327492, 1.4377455948852003, 0.4269063501851633, 0.9389723651111126, 0.7279993139673024, 2.8400502540171146, 14.859950970858335, 32.36645042896271, 32.906059473752975, 37.50405974686146, 42.20785014331341, 42.96190448105335, 78.92131671309471, 51.76980905234814, 63.7782096862793, 5.216105980798602, 0.07528504109359346, 2.4613497499376535, 0.807847932446748, 5.4553948156535625, 27.565081268548965, 70.87407812476158, 75.03582760691643, 74.76576089859009, 75.13786733150482, 75.89980244636536, 70.15011057257652, 72.1642304956913, 70.39485543966293, 72.57390931248665, 64.95431497693062, 58.89019377529621, 49.515921995043755, 51.474682688713074, 49.47625212371349, 54.91529166698456, 55.737100169062614, 61.65082164108753, 59.403971806168556, 62.72675670683384, 61.49313770234585, 64.56744253635406, 61.60092271864414, 62.694450840353966, 54.472946003079414, 49.5236773788929, 49.51610058546066, 52.62187913060188, 48.629034385085106, 44.72329996526241, 47.95389421284199, 49.541502222418785, 51.2354551255703, 53.34704741835594, 53.24881888926029, 55.07857270538807, 57.26466380059719, 57.90185160934925, 58.11635009944439, 56.72153614461422, 53.994692265987396, 57.39525519311428, 56.98429584503174, 55.79546883702278, 54.218298867344856, 52.55566768348217, 52.448087856173515, 48.198327496647835, 48.21068063378334, 52.76673875749111, 50.45293651521206, 46.831168457865715, 46.97279065847397, 45.63134104013443, 46.318518966436386, 44.98316802084446, 40.92386104166508, 42.54822827875614, 45.23100212216377, 45.27111656963825, 42.75424562394619, 41.83377541601658, 45.82274816930294, 41.95549428462982, 45.29127448797226, 44.10995587706566, 44.932440742850304, 44.2515666782856, 43.26547399163246, 41.931950747966766, 41.840888634324074, 42.267392948269844, 43.346402049064636, 41.30052722990513, 42.07616440951824, 41.874452233314514, 43.85411940515041, 45.575959011912346, 45.21470479667187, 42.782101929187775, 37.45200254023075, 40.376838594675064, 42.126785293221474, 48.323071002960205, 45.52656166255474, 46.87908388674259, 50.0724021345377, 54.01652589440346, 52.994901314377785, 54.94118347764015, 51.42376162111759, 52.852123975753784, 52.42265202105045, 51.045837700366974, 48.93128536641598, 51.38327099382877, 50.392504557967186, 48.09535302221775, 45.798509269952774, 46.26713052392006, 48.65768104791641, 53.48060645163059, 57.511145174503326, 60.12250564992428, 58.57411153614521, 58.56916040182114, 57.10794880986214, 57.50248923897743, 55.70292480289936, 55.28505362570286, 43.70620474219322, 50.18464431166649, 53.8156458735466, 57.97190845012665, 57.724545523524284, 52.38740511238575, 49.92087386548519, 47.430274710059166, 50.41170872747898, 55.24230591952801, 59.91218313574791, 64.22536969184875, 65.64758017659187, 66.63164377212524, 67.564417719841, 67.73653328418732, 70.96905782818794, 71.64200931787491, 68.62916618585587, 69.72666889429092, 62.4728087335825, 67.7047897875309, 64.74354788661003, 19.243917278945446, 0.3104191180318594, 9.417833592742682, 63.93698796629906, 61.866935044527054, 44.06322218477726, 43.527705520391464, 42.885467782616615, 26.833396330475807, 27.72292859852314, 45.26246443390846, 48.70627664029598, 39.29632097482681, 11.398642603307962, 0.9112638956867158, 0.6744592369068414, 7.983309868723154, 7.30148253031075, 1.3837517984211445, 0.07707184326136485, 0.1331323874182999, 0.1586083578877151, 0.9450097661465406, 4.322866061702371, 6.084211673587561, 2.531033498235047, 1.4653664315119386, 1.228140292223543, 1.1565925064496696, 24.74815182387829, 39.59806278347969, 29.67178702354431, 45.280190482735634, 50.747549906373024, 50.95807000994682, 87.31822773814201, 60.94640403985977, 78.10729399323463, 7.8181469812989235, 0.04861640220042318, 2.956522791646421, 0.6563458463642746, 6.948266783729196, 33.615697994828224, 76.13083764910698, 77.88716420531273, 80.61755329370499, 77.79664546251297, 78.91803368926048, 75.97899779677391, 76.55699998140335, 77.04556256532669, 75.35922065377235, 70.94068095088005, 62.39265203475952, 53.22340965270996, 54.90703471004963, 55.789229571819305, 58.615088537335396, 62.47259974479675, 68.08785483241081, 66.56091436743736, 65.23160889744759, 65.39981827139854, 67.90883123874664, 64.34244900941849, 67.02218681573868, 56.36088989675045, 52.72987313568592, 51.84675112366676, 54.500600919127464, 50.91308802366257, 47.360844835639, 51.45970769226551, 50.501167327165604, 53.27041693031788, 55.18150918185711, 55.29261901974678, 58.825840428471565, 60.75869411230087, 61.010274812579155, 59.16668213903904, 59.25795704126358, 57.019246369600296, 59.83690157532692, 60.34732438623905, 59.38661813735962, 56.89265616238117, 55.544013530015945, 57.30577379465103, 50.61897240579128, 50.00657446682453, 53.41594912111759, 52.77518570423126, 49.29369851946831, 48.0074979364872, 48.10919187963009, 47.50621743500233, 47.19449736177921, 42.24766440689564, 44.18968699872494, 46.61700055003166, 46.95974975824356, 45.22388510406017, 45.80797456204891, 46.196176931262016, 44.48688045144081, 46.151757314801216, 46.43401376903057, 47.009112909436226, 46.40657924115658, 44.14099261164665, 44.8073248565197, 43.733270689845085, 42.26091429591179, 45.13093449175358, 44.181521236896515, 43.02538387477398, 43.039701506495476, 45.55317163467407, 47.43103086948395, 47.040180042386055, 43.51879879832268, 37.96661652624607, 40.841983035206795, 42.07888886332512, 50.85106775164604, 49.0003352612257, 49.21174831688404, 53.4702368080616, 59.93724659085274, 54.974363297224045, 56.66931174695492, 56.679392606019974, 54.743844866752625, 57.092392444610596, 53.50493274629116, 52.20317579805851, 51.77030682563782, 51.81275434792042, 51.25863008201122, 48.96916553378105, 47.002835646271706, 50.69063276052475, 53.94966848194599, 58.18845123052597, 62.25256495177746, 61.116581708192825, 61.55437521636486, 60.73788642883301, 62.33115993440151, 58.930714800953865, 58.99360902607441, 48.78622815012932, 57.03444555401802, 60.18500469624996, 66.67570620775223, 63.616942539811134, 58.52532975375652, 52.24687345325947, 53.20354051887989, 54.64345045387745, 59.605942368507385, 63.442987874150276, 69.85900819301605, 70.48933357000351, 72.48165026307106, 72.42446333169937, 70.92560335993767, 74.74350169301033, 78.53685334324837, 76.24323561787605, 76.28549695014954, 70.26212856173515, 75.09659394621849, 68.59865382313728, 22.883988954126835, 0.36009714764077216, 11.746816020458937, 72.97500059008598, 68.08635771274567, 54.22080673277378, 47.794169783592224, 55.33980868756771, 30.703589357435703, 21.975379809737206, 47.443342208862305, 55.587669387459755, 55.99746599793434, 27.912606820464134, 7.142822993919253, 10.698553919792175, 7.782591339200735, 13.792213965207338, 5.918228030204773, 0.08844400217640214, 0.2523062832187861, 0.25374845426995307, 0.4491268453421071, 1.4417734974995255, 3.280330253764987, 0.9127028903458267, 1.90310139907524, 1.5837535914033651, 4.478074908256531, 43.280619978904724, 59.498305544257164, 53.442578092217445, 57.556035965681076, 57.56954424083233, 56.440556421875954, 91.61803901195526, 68.0774737894535, 89.521015137434, 9.031761959195137, 0.10497005758224986, 5.9344935324043036, 0.6835373654030263, 10.222751051187515, 45.081734731793404, 78.84978175163269, 76.96559965610504, 81.69085890054703, 80.03967270255089, 81.2370340526104, 76.38332650065422, 77.93094545602798, 78.3692367374897, 77.18129888176918, 71.64241969585419, 66.26607298851013, 55.53394787013531, 58.03096108138561, 58.327288180589676, 62.08120934665203, 65.46695306897163, 73.11553224921227, 69.6183443069458, 70.35005584359169, 70.10926276445389, 71.52299210429192, 66.72369003295898, 69.67569082975388, 58.46504978835583, 55.42507231235504, 54.88580524921417, 56.8380530923605, 53.09211149811745, 51.03132247924805, 51.88776612281799, 54.1761439293623, 55.728508830070496, 57.586844712495804, 57.727117985486984, 62.545335441827774, 63.21914568543434, 62.865833044052124, 62.848692163825035, 63.399639800190926, 58.55364963412285, 61.44881308078766, 61.350785940885544, 60.0968874245882, 59.24188770353794, 57.34105110168457, 60.33337153494358, 53.27512487769127, 56.31251469254494, 59.20805811882019, 55.86034655570984, 51.65301091969013, 51.14437401294708, 52.40552634000778, 50.89574575424194, 49.239904806017876, 45.17061196267605, 47.42746666073799, 52.344946190714836, 49.60855342447758, 48.01124073565006, 49.429149851202965, 50.49536883831024, 45.894663110375404, 49.44404885172844, 48.95409934222698, 50.12234665453434, 50.03234088420868, 47.336598336696625, 47.428405210375786, 47.31763735413551, 46.28398261964321, 48.19373734295368, 47.957253232598305, 47.870154306292534, 47.1857388317585, 50.387112647295, 52.62152574956417, 50.02169005572796, 46.60520598292351, 39.05876152217388, 43.16684268414974, 47.22446635365486, 55.531861782073975, 52.734121307730675, 52.783324867486954, 54.47574645280838, 61.429506316781044, 59.11806374788284, 59.318920969963074, 58.85204002261162, 59.175569862127304, 61.190464943647385, 58.61890733242035, 53.91204670071602, 58.198041915893555, 55.51520727574825, 54.46102224290371, 51.216269955039024, 50.714142099022865, 53.143731728196144, 57.28265583515167, 61.95916369557381, 64.74862441420555, 61.65907099843025, 63.1231552362442, 61.86930611729622, 62.52124473452568, 58.666693568229675, 58.85629199445248, 49.04122106730938, 60.099752470850945, 60.25864094495773, 68.11994791030884, 64.26950812339783, 59.48320895433426, 52.73880645632744, 52.890251129865646, 55.471133440732956, 62.38971099257469, 64.25128430128098, 70.14546722173691, 71.53585821390152, 70.7540425658226, 72.2912272810936, 71.35829374194145, 72.27846756577492, 77.95258909463882, 76.3584378361702, 74.81899604201317, 70.47358721494675, 77.41736501455307, 75.06192460656166, 31.28782130777836, 0.3676647087559104, 12.20192139968276, 78.8215720653534, 76.28010123968124, 60.32822661101818, 58.63086149096489, 63.21609444916248, 36.58361993730068, 39.63541477918625, 60.68060450255871, 67.21675917506218, 71.03208884596825, 38.83576288819313, 23.952168636024, 30.873115360736847, 36.76490440964699, 63.25928293168545, 4.641167381778359, 0.38862898538354784], [0.02040665283857379, 0.0629848190874327, 0.05596282186161261, 0.06540148198837414, 0.22380053938832134, 0.15247355739120394, 0.4734475293662399, 1.9400437292642891, 2.014910993166268, 10.89375514537096, 25.38430418819189, 23.53246595710516, 31.53164852410555, 44.514402374625206, 41.52074061334133, 75.51518708467484, 55.73035553097725, 68.21147739887238, 19.931446686387062, 0.050681951324804686, 3.223169445991516, 0.8991263969801366, 9.112740363925695, 44.76014658808708, 76.18911892175674, 75.11202111840248, 73.8920433819294, 73.43658462166786, 73.71298938989639, 73.65296021103859, 70.12698501348495, 70.08144825696945, 70.73621392250061, 66.0629890859127, 62.59034022688866, 52.92904704809189, 50.39429046213627, 47.542402893304825, 52.784191220998764, 55.71436978876591, 58.71512196958065, 59.81914132833481, 58.35010975599289, 57.41941049695015, 62.90422238409519, 65.8615542948246, 60.54901376366615, 63.518474623560905, 55.75373187661171, 53.66954371333122, 50.539773255586624, 47.7821434289217, 47.54695124924183, 49.30445194244385, 48.72070826590061, 51.10983766615391, 54.08986955881119, 57.1483938395977, 57.19707302749157, 56.19025245308876, 56.306887194514275, 54.52379487454891, 53.916956037282944, 58.95478270947933, 58.21212016046047, 55.17969287931919, 56.633928045630455, 55.21174795925617, 53.842206448316574, 49.22362267971039, 48.17247748374939, 41.7317508906126, 49.984881430864334, 48.32870610058308, 43.00949312746525, 47.92672947049141, 45.0015552341938, 44.285229071974754, 45.08757881820202, 42.51741573214531, 41.07934109866619, 42.90790557861328, 43.38854178786278, 46.21669963002205, 44.21611838042736, 45.56052803993225, 45.25462545454502, 45.18270291388035, 44.486086294054985, 45.018536522984505, 43.81888389587402, 41.82596683502197, 43.492538407444954, 42.483103573322296, 44.169677272439, 41.46383486688137, 41.734547540545464, 43.024669513106346, 43.91320243477821, 43.745395839214325, 43.44158694148064, 44.50562484562397, 43.48766326904297, 38.2453353703022, 36.76801264286041, 33.88015620410442, 44.40219059586525, 48.12272295355797, 46.946325078606606, 52.402691692113876, 52.62649208307266, 54.68695431947708, 53.17841246724129, 56.44931495189667, 53.41593012213707, 53.49395893514156, 55.1838194578886, 54.60332080721855, 52.66508661210537, 51.913578137755394, 53.643879890441895, 49.70302775502205, 49.16110083460808, 45.54495267570019, 47.10231430828571, 53.87316718697548, 57.69348219037056, 57.14134521782398, 59.94482718408108, 51.445219069719315, 48.17346163094044, 50.889297500252724, 48.1888660043478, 48.243252485990524, 53.711717650294304, 59.309334084391594, 60.42360909283161, 58.208495154976845, 53.635999113321304, 49.020284190773964, 47.27254897356033, 50.50750158727169, 54.64823819696903, 56.879805251955986, 61.221748664975166, 65.81323608756065, 67.79528573155403, 65.53138241171837, 70.06163612008095, 68.21417525410652, 68.00833269953728, 68.53706672787666, 76.08381897211075, 69.37837958335876, 61.96604512631893, 45.89018315076828, 6.5358734875917435, 0.3947505756514147, 12.640543263405561, 66.43500432372093, 61.49714648723602, 40.76570212841034, 43.900237530469894, 37.31542266905308, 24.037584252655506, 32.8475958108902, 44.59585100412369, 41.04886673390865, 28.350645415484905, 11.136460471898317, 2.564552924595773, 5.727536687627435, 12.697647549211979, 3.4187162155285478, 0.0686100016173441, 0.0404543436889071, 0.05163682821148541, 0.05716236628359184, 0.09292305636336096, 0.6801306107081473, 1.496411596890539, 0.317012001760304, 0.565144446445629, 1.00251326803118, 1.7552286526188254, 20.00970158725977, 37.61635132133961, 22.83057902008295, 39.502710700035095, 52.30357401072979, 47.97223582863808, 85.5149357020855, 63.38475599884987, 80.46153366565704, 25.77559009194374, 0.025653957891336177, 4.573303973302245, 1.1261157668195665, 11.419834066182375, 55.83451934158802, 82.04951405525208, 81.43434226512909, 77.3595929145813, 78.4739439189434, 77.75245383381844, 78.87985333800316, 75.29711678624153, 75.48388436436653, 76.11117750406265, 70.93037590384483, 67.59258180856705, 55.85881523787975, 54.723838940262794, 52.34510198235512, 59.119978845119476, 61.66541665792465, 65.32558545470238, 64.15701135993004, 64.0335787832737, 64.21868205070496, 66.60597994923592, 66.6404440999031, 64.06194806098938, 65.80365300178528, 58.51019136607647, 53.75043377280235, 53.34689162671566, 49.31725725531578, 48.786912113428116, 52.334173768758774, 51.37238837778568, 56.27016596496105, 58.564091473817825, 59.86259959638119, 59.21705603599548, 58.1826451420784, 61.60047434270382, 57.547596618533134, 56.977828592062, 61.52979053556919, 62.42689959704876, 57.95955151319504, 59.7070549428463, 56.9434480369091, 54.96429763734341, 54.04608070850372, 48.7815809994936, 44.65059846639633, 51.478490084409714, 50.39325691759586, 46.344072595238686, 48.60717795789242, 47.46706433594227, 46.60221554338932, 45.973273292183876, 45.22001311182976, 43.05371515452862, 45.02285309135914, 45.776721239089966, 47.445451095700264, 47.839626744389534, 47.73509055376053, 45.25041148066521, 48.24269771575928, 47.128829285502434, 47.71995596587658, 47.25662022829056, 44.764618948102, 44.0778324007988, 46.63052022457123, 44.8149548470974, 44.746573716402054, 43.18451553583145, 44.144416227936745, 46.13709770143032, 46.973045244812965, 45.18730826675892, 49.08812575042248, 47.675000578165054, 40.8392433822155, 38.22789430618286, 36.12462356686592, 45.26655301451683, 50.101409777998924, 49.01815250515938, 56.38788364827633, 55.84251791238785, 59.01807591319084, 55.78936256468296, 57.3085780441761, 56.224359422922134, 59.19638894498348, 56.1673928797245, 57.16512814164162, 57.06730619072914, 51.7089819163084, 54.412491247057915, 51.372597366571426, 50.57512655854225, 48.08689087629318, 50.77781908214092, 54.799257293343544, 60.63031040132046, 61.499008387327194, 64.46203619241714, 55.90982370078564, 51.041961908340454, 51.35893329977989, 51.117433458566666, 55.10534226894379, 59.08273704349995, 64.27581578493118, 66.43976926803589, 63.13000626862049, 57.63106293976307, 52.733418345451355, 52.807233184576035, 54.64546054601669, 59.70331594347954, 62.094649225473404, 66.28410682082176, 68.41415092349052, 73.10951337218285, 71.18538782000542, 74.39216494560242, 72.25218057632446, 74.46886762976646, 73.3683554828167, 82.12189257144928, 73.75845775008202, 70.58329492807388, 51.79375156760216, 8.44943180680275, 0.5479228205513209, 15.52574934437871, 76.25118479132652, 71.26684784889221, 46.29943259060383, 51.307012885808945, 45.532356351614, 21.82228982448578, 26.34101875126362, 47.05309174954891, 51.337711438536644, 43.586746752262115, 15.72319244965911, 5.443642046302557, 10.723907109349966, 15.663652494549751, 10.180520117282867, 0.11674135836074129, 0.035856931790476665, 0.10266267592669465, 0.3126993519254029, 0.17866494337795302, 0.3060983936302364, 0.5079720017965883, 0.23073587974067777, 1.041451203636825, 2.6827458199113607, 5.608261562883854, 39.545629397034645, 59.85493540763855, 32.470363453030586, 53.28110195696354, 61.12449288368225, 58.133737966418266, 86.70083686709404, 70.75433135032654, 89.31253552436829, 29.817927181720734, 0.1340540309320204, 12.520751841366291, 1.4353331993333995, 12.759147249162197, 61.073704808950424, 80.89235454797745, 81.75037130713463, 75.5955071747303, 79.53122958540916, 79.38344791531563, 78.67766618728638, 74.9725154042244, 74.17401865124702, 79.40539553761482, 72.70143046975136, 69.36628103256226, 59.12769243121147, 57.540111020207405, 53.73257473111153, 60.51810622215271, 63.41058321297169, 66.12312465906143, 66.20041251182556, 65.95670878887177, 65.6014734506607, 68.25631499290466, 70.53805455565453, 66.15134954452515, 67.29435101151466, 60.917662382125854, 57.37321637570858, 55.53526259958744, 51.46112501621246, 50.023487359285355, 53.37564468383789, 55.26101231575012, 56.5930650383234, 60.15945106744766, 64.31605562567711, 63.9104425907135, 59.567739218473434, 63.563528805971146, 60.3605704754591, 58.49474519491196, 64.61222693324089, 62.846093103289604, 60.12160889804363, 63.54362167418003, 61.33312068879604, 56.36100769042969, 57.39825703203678, 55.48293940722942, 49.967637956142426, 57.45776183903217, 56.05261243879795, 48.48683461546898, 53.74333955347538, 49.70633737742901, 48.59701730310917, 49.7734721750021, 46.61036230623722, 45.933337435126305, 48.25904443860054, 50.29409743845463, 53.19488078355789, 49.13624256849289, 51.853518560528755, 49.86366033554077, 50.08401431143284, 52.83762015402317, 51.71199135482311, 49.694071635603905, 49.11387696862221, 48.02150398492813, 47.93757028877735, 49.76736210286617, 47.31352597475052, 46.4558207988739, 47.53579504787922, 49.84528072178364, 49.01766613125801, 49.34792920947075, 51.643272042274475, 48.28006111085415, 43.8532530516386, 40.1248437166214, 37.970420122146606, 48.999043330550194, 56.7739125341177, 51.23668625950813, 56.60191476345062, 60.793648436665535, 60.27688376605511, 58.05018424987793, 61.21246196329594, 60.02930045127869, 60.97077213227749, 61.829590648412704, 60.77339932322502, 59.46079395711422, 55.04510410130024, 57.434070110321045, 54.65261556208134, 53.455660790205, 49.84281465411186, 53.897303491830826, 57.843680530786514, 63.278171718120575, 62.996793016791344, 65.59014245867729, 56.44048422574997, 51.71376585960388, 50.53599625825882, 51.94487705826759, 56.842168271541595, 57.48920515179634, 64.47664260864258, 65.93595430254936, 65.22929862141609, 57.94151768088341, 54.35869753360748, 52.78560474514961, 56.17412991821766, 62.37635090947151, 63.966124802827835, 67.67393544316292, 71.46479442715645, 73.8379418849945, 70.02537846565247, 75.59223935008049, 73.03835079073906, 74.09230023622513, 73.93154606223106, 82.63285115361214, 74.89650428295135, 72.6669891178608, 60.19645348191261, 10.201093163341284, 0.4710787127260119, 16.191432774066925, 83.78846794366837, 75.19253119826317, 58.22915084660053, 62.67102889716625, 52.69605115056038, 34.18512023985386, 51.52659550309181, 57.36718229949474, 61.38539828360081, 62.58567027747631, 33.47126014530659, 23.10560256242752, 39.210228994488716, 50.715608820319176, 9.783798605203629, 0.2141065470641479, 0.24537754798075184], [0.05084024400275666, 0.11201407804037444, 0.05091082966828253, 0.06626667032833211, 0.10733089613495395, 0.0920278555713594, 0.23578637279570103, 1.3103383127599955, 2.0793814212083817, 9.731544759124517, 23.304706178605556, 24.654758535325527, 40.47700881958008, 59.269246235489845, 36.19532257318497, 71.1813372373581, 62.208263128995895, 68.48027497529984, 33.99302914738655, 0.06587393319932744, 0.7870626915246248, 3.7887448724359274, 10.287114847451448, 60.67188397049904, 74.41045716404915, 73.78362759947777, 72.93043658137321, 72.27521494030952, 71.80157795548439, 68.0478885769844, 75.31508222222328, 70.78968465328217, 67.3550033569336, 67.1733047068119, 63.82927894592285, 53.99729512631893, 51.93785883486271, 50.88055036962032, 51.87502160668373, 53.68123948574066, 57.06457793712616, 58.930912390351295, 62.69352748990059, 58.708840906620026, 56.51961877942085, 64.82821494340897, 61.69363774359226, 62.13946782052517, 57.46123105287552, 55.234835520386696, 52.26133167743683, 49.13208559155464, 49.18465957045555, 50.70116199553013, 53.11563603579998, 54.09197084605694, 55.80241106450558, 56.00611813366413, 56.36124327778816, 56.43064275383949, 56.59206569194794, 55.87475158274174, 58.87739986181259, 55.71863315999508, 56.09383262693882, 53.457138910889626, 50.162784084677696, 52.73289397358894, 54.34729814529419, 50.719860792160034, 46.7692431807518, 39.62119214236736, 40.26912957429886, 43.62322859466076, 45.95600321888924, 48.01450856029987, 41.95498511195183, 43.067261427640915, 43.26380968093872, 45.856144577264786, 43.25271047651768, 42.846029698848724, 41.01767420768738, 42.059008330106735, 44.713329300284386, 46.44092559814453, 41.10602706670761, 45.44451646506786, 44.9309816211462, 42.88479521870613, 46.832779571413994, 46.586947962641716, 43.26713070273399, 44.65679973363876, 43.37333880364895, 44.88331697881222, 40.915163308382034, 45.4076736420393, 44.56794910132885, 42.138439267873764, 39.70580220222473, 46.276010647416115, 47.163130044937134, 41.718580797314644, 37.88907028734684, 34.32746060192585, 42.07481548190117, 48.596481531858444, 50.253766402602196, 52.081928104162216, 53.78196828067303, 56.96963623166084, 54.785494431853294, 54.42803241312504, 52.185833528637886, 55.562928915023804, 54.419178888201714, 56.38857901096344, 61.11027404665947, 51.96019783616066, 55.73715716600418, 52.90974788367748, 53.53503853082657, 49.5418594032526, 45.78202575445175, 46.38077102601528, 53.24988663196564, 58.600398525595665, 59.336046651005745, 61.29125453531742, 52.928940653800964, 48.44602860510349, 59.49640944600105, 60.61380788683891, 59.29780550301075, 59.71934728324413, 59.93858031928539, 55.145506113767624, 51.75924941897392, 47.120769917964935, 48.06077107787132, 48.73920567333698, 54.333831667900085, 57.65892304480076, 63.53020079433918, 63.57948414981365, 68.09729352593422, 64.92305025458336, 72.94338628649712, 67.27295815944672, 71.09727814793587, 70.59426873922348, 74.35035958886147, 65.83519890904427, 68.0929845571518, 27.47525218874216, 3.2279085041955113, 0.15460853814147413, 14.589332342147827, 66.90134570002556, 56.04625158011913, 36.4867327362299, 46.77036412060261, 33.603865429759026, 31.93201594054699, 42.862433418631554, 42.1172896027565, 37.06334039568901, 31.492594219744205, 14.172637201845646, 12.768675237894058, 11.060696337372065, 5.180446319282055, 0.1435812033014372, 0.05033353896578774, 0.0832356617320329, 0.022833351431472693, 0.10209466578089632, 0.060930324252694845, 0.041625690209912136, 0.05921215961279813, 0.3263155650347471, 0.3060067829210311, 3.0419707065448165, 5.015467721968889, 18.437271863222122, 33.435944840312004, 27.059326507151127, 48.95380675792694, 69.40709084272385, 42.13719293475151, 80.20476624369621, 67.90152803063393, 80.7304984331131, 41.740653812885284, 0.0896366557572037, 0.7737318787258118, 2.450002608820796, 13.239881303161383, 69.85092222690582, 81.04736343026161, 80.64368069171906, 77.7487376332283, 77.5187511742115, 76.32879942655563, 75.69122403860092, 80.15685841441154, 75.80106854438782, 71.31306856870651, 73.0689087510109, 68.53174701333046, 60.48061743378639, 56.267878487706184, 54.7321604937315, 55.46354524791241, 58.70963126420975, 60.250083804130554, 63.2446651160717, 64.30150240659714, 64.97429430484772, 63.425064235925674, 66.34917452931404, 66.14998921751976, 63.89028087258339, 61.39731824398041, 57.762524485588074, 53.30285958945751, 51.52897037565708, 51.16758696734905, 51.640501990914345, 55.80330781638622, 56.60175897181034, 58.59530679881573, 60.90090528130531, 59.2463106662035, 60.272027626633644, 56.736796125769615, 57.734588384628296, 60.657106563448906, 57.72866450250149, 57.23556496202946, 57.184343710541725, 55.00083647668362, 55.83416596055031, 57.948307916522026, 54.34854067862034, 49.385133013129234, 42.03794606029987, 42.11955428123474, 44.61159735918045, 47.52468444406986, 49.029168114066124, 44.369421154260635, 44.60069194436073, 46.60935156047344, 46.87854811549187, 46.72427259385586, 44.243982285261154, 44.73458535969257, 43.197184056043625, 45.801484510302544, 48.451785296201706, 45.37220634520054, 48.44005532562733, 48.32265682518482, 46.62061795592308, 48.46128858625889, 48.402992114424706, 45.37279911339283, 46.24914608895779, 45.31869761645794, 45.03452606499195, 44.29044999182224, 47.51004382967949, 47.00709521770477, 43.98992791771889, 40.581864193081856, 49.09734785556793, 49.87232007086277, 45.15528358519077, 39.136353358626366, 38.85264918208122, 42.82072685658932, 50.538538321852684, 53.50560910999775, 55.55679604411125, 56.895703598856926, 57.58808724582195, 58.81034106016159, 59.00871701538563, 54.872437566518784, 56.46841272711754, 56.69739603996277, 60.48836141824722, 60.82014821469784, 54.47710677981377, 57.630690559744835, 54.74849581718445, 56.184845343232155, 50.88451735675335, 47.650073915719986, 46.99017092585564, 54.61646430194378, 62.174330949783325, 60.16489237546921, 64.4954439997673, 55.662909150123596, 52.70298957824707, 64.54742521047592, 66.06314107775688, 64.1886180639267, 64.34834629297256, 65.14273166656494, 60.45761726796627, 57.27909542620182, 51.646539866924286, 52.29744493961334, 53.643366917967796, 57.78583623468876, 60.588683634996414, 70.26691630482674, 68.54342758655548, 72.19284296035767, 70.19323825836182, 78.12702253460884, 72.06779167056084, 77.60382860898972, 75.1396456360817, 79.84951570630074, 71.33777484297752, 75.574501901865, 31.867844983935356, 4.103658674284816, 0.2774338301969692, 17.531691156327724, 74.04505357146263, 64.94827330112457, 44.746129140257835, 50.48179976642132, 42.287064492702484, 24.887290857732296, 43.690150603652, 43.11929203569889, 40.95083959400654, 42.467136830091476, 23.62191505730152, 12.15073624625802, 16.446896865963936, 9.880626909434795, 0.28551973693538457, 0.02972326492454158, 0.02927973520854721, 0.16014954628190026, 0.3046366892522201, 0.12131163734011352, 0.11487347655929625, 0.12521588330855593, 0.31363576417788863, 0.4612871428253129, 7.26742590777576, 7.681299699470401, 39.19380247592926, 51.565144434571266, 37.59639099240303, 60.75046755373478, 75.2257490158081, 53.42001870274544, 85.17911732196808, 75.50367370247841, 86.6404277086258, 47.20954455435276, 0.1960086080362089, 4.953984646126628, 5.458448426797986, 15.673008542507887, 72.30161592364311, 78.02518039941788, 80.6474120914936, 77.71097525954247, 77.70492598414421, 77.3797470331192, 77.92893156409264, 81.5257653594017, 77.23312810063362, 72.81004384160042, 73.33693116903305, 71.2045007944107, 60.801958590745926, 58.02855961024761, 56.64002671837807, 58.7446615844965, 61.86726562678814, 63.31742361187935, 65.56950956583023, 67.29208633303642, 66.68257623910904, 67.28757977485657, 70.0603973865509, 67.81512066721916, 67.68803268671036, 62.15752065181732, 61.58643029630184, 56.70939579606056, 54.7427087277174, 53.568400740623474, 55.72222016751766, 59.64722715318203, 59.8583248257637, 61.8791513890028, 64.94957283139229, 62.231673672795296, 62.71518632769585, 61.28179304301739, 60.75901709496975, 62.02705845236778, 61.18877403438091, 61.442026644945145, 60.47258846461773, 57.09631383419037, 58.44516925513744, 60.50769478082657, 57.19762779772282, 54.33334529399872, 48.04667003452778, 46.32595896720886, 48.250688686966896, 50.675140991806984, 54.66122210025787, 47.49154642224312, 48.51696699857712, 49.04898405075073, 50.285023525357246, 49.42082829773426, 47.02279597520828, 47.167940586805344, 47.905519008636475, 49.41440284252167, 52.6841501891613, 47.432151809334755, 51.87624514102936, 50.97353138029575, 49.03866000473499, 51.31378032267094, 52.35929802060127, 48.19578543305397, 50.95169015228748, 48.62132079899311, 50.94926968216896, 45.42922228574753, 51.37953959405422, 50.67000366747379, 47.148896008729935, 45.246319100260735, 51.40302233397961, 54.67717744410038, 47.31593884527683, 42.87074737250805, 40.49188122153282, 46.39369793236256, 53.964240700006485, 56.74632981419563, 60.04078723490238, 59.87208388745785, 61.12185962498188, 61.05916678905487, 60.83267234265804, 58.08821640908718, 58.4557668864727, 57.823264226317406, 61.503750532865524, 65.63411369919777, 57.1892112493515, 62.16455027461052, 56.16906099021435, 58.88911463320255, 52.80884809792042, 51.06533445417881, 48.02818022668362, 56.734216064214706, 64.30413946509361, 63.36395211517811, 65.74129074811935, 55.40981613099575, 52.173715978860855, 64.64175894856453, 65.60473367571831, 63.33166524767876, 63.548109233379364, 64.68009129166603, 60.87953522801399, 56.60766005516052, 53.65351237356663, 52.192076593637466, 55.14114394783974, 59.10000331699848, 62.49020040035248, 71.37629717588425, 68.26437816023827, 71.73622906208038, 71.55731946229935, 77.15625062584877, 72.76501625776291, 76.99663639068604, 75.30716344714165, 81.57074734568596, 73.64745050668716, 78.52428361773491, 38.014410361647606, 5.258107502013445, 0.2955213049426675, 19.16787575930357, 83.34076836705208, 69.53881457448006, 57.539552450180054, 61.7946021258831, 51.2867371737957, 42.02990189194679, 62.253161519765854, 59.285041987895966, 54.08296912908554, 72.3643809556961, 29.78521093726158, 31.955012306571007, 35.10386914014816, 7.851162934675813, 0.219635829271283, 0.2090033912099898, 0.1731123132049106], [0.030503815032716375, 0.12062978174071759, 0.025888702912197914, 0.0795438332716003, 0.0631767681625206, 0.05453913770907093, 0.17726449586916715, 6.53436591848731, 2.4314398923888803, 7.707299804314971, 27.28158798068762, 24.307599663734436, 36.50803059339523, 49.68367539346218, 34.93380546569824, 59.35260996222496, 61.51321962475777, 68.31953600049019, 40.80972656607628, 0.8727410284336656, 0.4789954097941518, 3.7592660542577505, 25.74613217264414, 69.68302443623543, 73.2484795153141, 70.41212171316147, 71.6424272954464, 67.96442225575447, 71.17927774786949, 70.04987195134163, 70.49915224313736, 65.53574457764626, 69.94812861084938, 67.35983669757843, 66.79742127656937, 58.23111154139042, 50.88005259633064, 50.60099937021732, 50.10002285242081, 51.76429934799671, 53.41713085770607, 55.33363401889801, 57.287055999040604, 62.37766943871975, 59.07574161887169, 57.62873746454716, 64.06954005360603, 61.974830254912376, 61.76204167306423, 56.30857050418854, 50.478417947888374, 48.28929461538792, 49.66438002884388, 51.92715860903263, 57.1970996260643, 56.436912417411804, 55.44419288635254, 58.01142632961273, 57.82498933374882, 55.08894234895706, 57.63732500374317, 57.67160676419735, 55.10834030807018, 56.47784002125263, 50.906122997403145, 50.057480335235596, 48.73037114739418, 49.390764310956, 51.243643686175346, 52.14438535273075, 46.18314743041992, 36.80828668177128, 34.74753566086292, 41.49818882346153, 42.81590111553669, 48.62665571272373, 42.3964986205101, 41.17652848362923, 44.15662497282028, 44.6019496768713, 46.521690264344215, 45.26466831564903, 42.163324132561684, 41.9274365901947, 40.123863369226456, 45.147505402565, 44.507129564881325, 43.22639308869839, 42.46665045619011, 44.574461951851845, 44.04980890452862, 42.35162302851677, 43.1023183465004, 41.700839549303055, 40.63475355505943, 42.87453576922417, 42.49072976410389, 41.23825617134571, 42.75104999542236, 42.25999474525452, 41.020562052726746, 44.14246313273907, 48.93085598945618, 43.493936732411385, 35.894975289702415, 35.82409389317036, 39.547008723020554, 47.77731768786907, 53.5375539958477, 53.51734668016434, 53.65443952381611, 54.097294360399246, 52.85978816449642, 56.70087665319443, 52.918377220630646, 54.30042766034603, 53.818556517362595, 57.37733155488968, 56.41409084200859, 58.278039023280144, 54.98147651553154, 58.67042116820812, 54.753329157829285, 54.59042049944401, 48.771880120038986, 46.983935460448265, 45.725568383932114, 56.32484123110771, 56.08893468976021, 60.7857296615839, 57.041068598628044, 55.730119943618774, 61.65423385798931, 55.68270608782768, 59.70719933509827, 56.16749167442322, 57.68326073884964, 51.987411975860596, 50.668479949235916, 44.9658827483654, 49.41615454852581, 50.9071983397007, 58.607105165719986, 59.52720679342747, 64.21080127358437, 63.27165126800537, 70.12442395091057, 67.46984079480171, 72.06070885062218, 65.77085316181183, 70.80723211169243, 67.11281195282936, 77.47395157814026, 64.71707090735435, 70.423384308815, 18.1375914439559, 1.5766267175786197, 0.04429660548339598, 18.69106214493513, 70.88151052594185, 57.498966827988625, 40.09462393820286, 42.116890624165535, 32.190177887678146, 35.765284448862076, 48.93115617334843, 34.63868670165539, 30.54189283400774, 35.79642757773399, 1.5437405509874225, 7.410849686712027, 0.16073477425379679, 0.0766014181135688, 0.10252845851937309, 0.10827479665749706, 0.0798145093722269, 0.03500801874906756, 0.1242525533598382, 0.05989535478875041, 0.0862005417002365, 0.12187408879981376, 0.07822668441804126, 0.1947735110297799, 8.020068146288395, 5.581719037145376, 14.571645241230726, 37.10527494549751, 29.263859912753105, 43.93918164074421, 56.998210698366165, 41.015983298420906, 69.4157163798809, 67.89470359683037, 75.79620480537415, 47.9736265540123, 1.2612808076664805, 0.5215819808654487, 3.385275872424245, 29.733755998313427, 78.12374711036682, 80.25947570800781, 78.44574183225632, 76.63221314549446, 74.12899866700172, 74.66473191976547, 77.09712579846382, 77.35438719391823, 71.99592232704163, 72.41057127714157, 71.8116246163845, 70.80820485949516, 62.93582908809185, 54.941339269280434, 54.57028917968273, 54.178389608860016, 58.09973359107971, 56.705326214432716, 61.54743678867817, 61.72675296664238, 65.7251188158989, 64.13059517741203, 63.773087561130524, 64.70162853598595, 63.520154133439064, 62.78227932751179, 59.65910151600838, 52.604738250374794, 51.02867782115936, 51.5678308904171, 53.27741615474224, 58.411392867565155, 59.47665810585022, 59.46265585720539, 61.0084281116724, 61.43951877951622, 58.57047513127327, 59.587874338030815, 60.663760006427765, 57.5027210265398, 58.02959315478802, 53.522704392671585, 51.87570556998253, 50.428948402404785, 52.1808747947216, 53.830012902617455, 53.904086127877235, 48.763433173298836, 41.08254432678223, 36.724649369716644, 43.08807671070099, 44.98847633600235, 50.361479222774506, 44.11432184278965, 44.585789144039154, 45.940891429781914, 47.57828816771507, 46.39902524650097, 47.58744567632675, 41.097781509160995, 43.82267229259014, 42.60445386171341, 46.79619513452053, 45.48112750053406, 46.71668820083141, 44.9947801977396, 46.6220048815012, 46.75572730600834, 42.90302284061909, 44.575704485177994, 45.57208701968193, 42.67083629965782, 44.798034355044365, 44.99310068786144, 43.63479137420654, 44.13748539984226, 43.551613837480545, 43.97508591413498, 48.21771025657654, 52.240987569093704, 47.31425553560257, 39.15638968348503, 38.320681527256966, 43.65481249988079, 51.164923310279846, 55.94384707510471, 58.78094203770161, 54.87516961991787, 55.385930612683296, 55.75387626886368, 59.67887945473194, 55.17011359333992, 55.3520630300045, 55.96002660691738, 57.65157803893089, 58.68078701198101, 60.965418219566345, 56.6900510340929, 59.53282289206982, 57.91285961866379, 56.39106407761574, 50.30954360961914, 47.98517033457756, 48.68127778172493, 57.18335576355457, 61.703597009181976, 62.74685002863407, 60.57539574801922, 59.158470779657364, 64.32117015123367, 60.200416669249535, 66.2019856274128, 61.478291898965836, 61.73681862652302, 55.57899445295334, 53.961265459656715, 50.77410288155079, 54.78186562657356, 55.50305552780628, 63.826459497213364, 64.34807270765305, 68.19918125867844, 67.70193234086037, 74.1618213057518, 72.09765046834946, 75.74892774224281, 71.55528277158737, 76.56777620315552, 72.11126893758774, 82.46549293398857, 69.38712671399117, 76.50434240698814, 23.860272467136383, 1.8904332350939512, 0.013233875324658584, 20.439226739108562, 82.16958001255989, 64.46938499808311, 44.76712681353092, 47.74134501814842, 41.63885347545147, 35.64076133072376, 54.85175907611847, 35.432893484830856, 34.438103064894676, 55.00283516943455, 7.116504181176424, 11.636177357286215, 1.4919051574543118, 0.12101944637834094, 0.08132832736009732, 0.053615876313415356, 0.04791413382918108, 0.14689507079310715, 0.2252648858120665, 0.13781660090899095, 0.2995212434325367, 0.24984069052152336, 0.34561360138468444, 0.21797288412926719, 12.883901204913855, 6.4018698781728745, 36.305691450834274, 61.83638088405132, 36.56000420451164, 54.1101186722517, 66.86314254999161, 51.574697121977806, 74.0142372250557, 73.27564805746078, 82.59413883090019, 54.73985128104687, 1.4148075319826603, 2.96447339002043, 4.179849335923791, 32.653707414865494, 78.36115837097168, 79.46124494075775, 77.58840903639793, 77.84967541694641, 74.36211615800858, 74.91220504045486, 78.23179051280022, 76.76868662238121, 72.21206232905388, 76.57738208770752, 72.98998698592186, 71.7626528441906, 65.51321178674698, 56.049014031887054, 56.41437582671642, 56.13318331539631, 59.005627781152725, 59.30052235722542, 64.72612202167511, 65.70536747574806, 68.59565198421478, 65.47540381550789, 66.44306749105453, 64.25067633390427, 66.41238033771515, 68.78970757126808, 60.770374685525894, 54.85406555235386, 54.26031321287155, 54.11051765084267, 56.24440714716911, 60.86215876042843, 60.90852007269859, 61.906775906682014, 63.79072621464729, 63.2269998639822, 59.779083877801895, 63.45117263495922, 64.94519546627998, 59.63949076831341, 61.929612681269646, 56.129467114806175, 57.61089362204075, 53.943163231015205, 56.901612281799316, 55.36748640239239, 57.962036579847336, 52.59874977171421, 46.119170263409615, 42.96964846551418, 50.10330207645893, 47.100961580872536, 53.999115228652954, 46.70462004840374, 47.92178213596344, 48.95905427634716, 50.36971338093281, 50.31797155737877, 51.293994784355164, 46.730599254369736, 49.21686664223671, 45.46920374035835, 51.299063712358475, 49.15128976106644, 48.71665008366108, 48.19301538169384, 50.56139409542084, 50.48530697822571, 47.57950410246849, 47.878901436924934, 47.788777872920036, 45.694201067090034, 49.25125479698181, 48.64215888082981, 47.83655270934105, 47.51067839562893, 48.1549908220768, 46.731731593608856, 52.03095763921738, 53.71469289064407, 48.26135091483593, 43.77438448369503, 43.736219331622124, 48.56036826968193, 54.42385643720627, 59.92533802986145, 59.49016638100147, 58.822367414832115, 57.547520622611046, 58.85767512023449, 61.3847941160202, 57.284434139728546, 57.44720220565796, 59.71584387123585, 60.769542530179024, 60.10725326836109, 63.220228627324104, 60.142876356840134, 63.02520789206028, 60.26966795325279, 60.98610430955887, 53.16926255822182, 50.45833222568035, 48.92884969711304, 60.23498721420765, 61.94505885243416, 65.1572772860527, 60.7329922914505, 60.02358175814152, 63.445602133870125, 61.74822561442852, 65.46770542860031, 62.40187793970108, 62.4715244024992, 57.2780504822731, 56.413589268922806, 49.9939401447773, 53.76956954598427, 57.418642938137054, 65.5622747540474, 65.59669330716133, 68.00984501838684, 67.48205333948135, 75.41823908686638, 71.0866767168045, 75.81753686070442, 72.29082450270653, 73.13359647989273, 72.41563260555267, 84.1549126803875, 71.27657532691956, 81.42984330654144, 30.70469129830599, 2.8340434888377786, 0.22824561805464327, 23.16842459142208, 88.65012466907501, 71.37298375368118, 59.05565969645977, 57.02253319323063, 49.821026623249054, 51.33310988545418, 68.78778487443924, 52.42733716964722, 51.033731549978256, 82.63009250164032, 11.451937593519688, 15.559983607381582, 0.4660071129910648, 0.2099547948455438, 0.11701137394993566, 0.22361559618730098, 0.1601979639963247], [0.09052383393282071, 0.02882491742639104, 0.040652578754816204, 0.06775343703338876, 0.10302558614057489, 0.15460507973330095, 0.12924489914439619, 2.687348322942853, 0.6236895080655813, 6.3207898288965225, 20.417731292545795, 29.35699101537466, 40.40146127343178, 56.95038266479969, 31.575310081243515, 54.856539219617844, 66.57822623848915, 70.85049659013748, 51.02234736084938, 2.7179283695295453, 0.5489322007633746, 6.736648539081216, 43.15456934273243, 75.83221927285194, 73.80024030804634, 72.94162318110466, 73.57599154114723, 72.30964869260788, 68.0212140083313, 66.12955391407013, 71.14494279026985, 71.67041659355164, 68.6503766477108, 67.67772004008293, 67.2806641459465, 61.927408799529076, 51.19623363018036, 50.43820470571518, 51.60797953605652, 50.365431010723114, 49.81044419109821, 53.57035383582115, 56.24784976243973, 56.893043741583824, 60.41684925556183, 59.762892946600914, 55.1626355946064, 63.13501439988613, 60.20846463739872, 56.36898726224899, 50.09027637541294, 48.2413449883461, 47.932299971580505, 58.410819098353386, 58.220722898840904, 59.90647964179516, 59.629960879683495, 56.929419189691544, 55.84868498146534, 57.16655306518078, 56.30493029952049, 54.937756061553955, 55.3210224956274, 53.36457587778568, 46.968945264816284, 44.63207446038723, 45.27956731617451, 48.13014395534992, 50.46852707862854, 52.64097310602665, 46.454186886548996, 35.64987324178219, 31.854731887578964, 42.48066410422325, 45.217121466994286, 44.780866876244545, 45.15705808997154, 39.93363797664642, 41.33527256548405, 43.724291771650314, 45.11402539908886, 42.681198343634605, 40.12799374759197, 42.44184158742428, 42.51588821411133, 40.890578627586365, 41.176365092396736, 43.7721312046051, 42.123460471630096, 40.88800996541977, 42.45531566441059, 39.965316876769066, 41.08860120177269, 42.41749249398708, 43.683215975761414, 40.173393711447716, 40.351018980145454, 39.81783539056778, 40.74811667203903, 41.29402957856655, 42.782265320420265, 43.61944019794464, 48.563518300652504, 50.22226609289646, 34.390852600336075, 36.07363410294056, 40.69730579853058, 50.51036283373833, 53.03796820342541, 55.282108783721924, 51.36803761124611, 50.15698179602623, 51.2934286147356, 55.585191920399666, 57.35580950975418, 58.66591840982437, 53.90010394155979, 57.30366110801697, 57.219640016555786, 58.098715245723724, 59.21829096972942, 53.931885436177254, 55.29478870332241, 56.97846315801144, 51.341416239738464, 48.38006794452667, 46.274414733052254, 52.17017076909542, 55.88306553661823, 59.64595802128315, 56.97480395436287, 56.261798813939095, 61.57897509634495, 57.25306682288647, 55.91031387448311, 51.95694521069527, 53.3474387973547, 47.66792915761471, 50.43619841337204, 47.24223420023918, 51.32041476666927, 54.317272156476974, 61.78784228861332, 62.78642110526562, 67.83582955598831, 65.77618047595024, 69.36170607805252, 67.32261389493942, 70.04945397377014, 63.02002117037773, 67.05071568489075, 64.19837594032288, 74.14447143673897, 61.76567427814007, 68.69698494672775, 15.129398312419653, 1.4187127724289894, 0.08200016396585852, 21.030684001743793, 74.87037688493729, 56.3150529563427, 39.67320755124092, 39.517674297094345, 34.18983578681946, 32.86805011332035, 44.31434690952301, 28.50187160074711, 29.691935442388058, 54.98200088739395, 7.540116375312209, 0.4947427741717547, 0.054831696033943444, 0.0619845004985109, 0.09015788091346622, 0.028717751301883254, 0.032998861715896055, 0.054278565949061885, 0.14259653660701588, 0.049010508591891266, 0.08319285465404391, 0.04192985572444741, 0.09793601158889942, 0.07539975485997275, 4.466785714030266, 2.624691347591579, 14.946928303688765, 35.64847871661186, 34.06091250479221, 49.201865047216415, 67.94641882181168, 37.29898855090141, 63.62800374627113, 72.93434277176857, 77.74343311786652, 56.25984951853752, 3.5069277696311474, 0.45785708469338715, 6.883157752454281, 48.44198562204838, 82.91034266352654, 80.95130458474159, 78.25993940234184, 79.1227439045906, 79.01844710111618, 73.30291539430618, 73.67859363555908, 74.33198377490044, 74.76149752736092, 71.84184059500694, 72.09517300128937, 71.05739548802376, 66.87394917011261, 54.91656839847565, 55.24595372378826, 53.17265957593918, 53.900886699557304, 54.64463219046593, 58.20260167121887, 60.00407740473747, 62.03091524541378, 64.17171657085419, 63.44810239970684, 60.47225408256054, 64.57644805312157, 61.14559315145016, 59.260172322392464, 54.37064789235592, 50.199923291802406, 52.6230912655592, 58.231932297348976, 61.246838718652725, 61.326288655400276, 60.606614872813225, 56.91015802323818, 60.23592196404934, 58.26989606022835, 58.62747587263584, 57.95177333056927, 55.46523995697498, 54.11489121615887, 48.35764154791832, 46.87436453998089, 48.02093781530857, 50.75848191976547, 53.32272492349148, 55.898557305336, 51.942262798547745, 41.31359852850437, 35.85338272154331, 46.495167687535286, 47.77800925076008, 47.381591722369194, 46.70093424618244, 44.335789158940315, 42.829633578658104, 44.583953842520714, 47.38550931215286, 44.883400574326515, 42.59752303361893, 44.21430587768555, 45.37086881697178, 44.38573367893696, 43.67237135767937, 45.70432372391224, 43.890806436538696, 44.56988699734211, 44.20107878744602, 43.25911693274975, 42.32324235141277, 45.19059129059315, 45.596762895584106, 41.538356468081474, 42.94173136353493, 41.09823748469353, 44.075480327010155, 44.382488653063774, 44.41192947328091, 45.779799073934555, 52.12351307272911, 53.27209264039993, 37.582726925611496, 39.62647385895252, 45.226544961333275, 54.16654944419861, 54.341480657458305, 55.02776563167572, 51.90842181444168, 51.90099701285362, 52.65894614160061, 55.797589123249054, 56.35778546333313, 60.445032343268394, 56.78237088024616, 57.7707776427269, 58.55302266776562, 58.9591296762228, 59.975233152508736, 58.13356317579746, 57.53912307322025, 59.208498895168304, 53.36337514221668, 50.1650183647871, 48.78877401351929, 55.63906542956829, 59.74673621356487, 62.843554839491844, 59.54103045165539, 61.920968145132065, 64.91732776165009, 62.178069949150085, 59.470874816179276, 57.1568787842989, 55.745383724570274, 54.13731761276722, 52.75155857205391, 52.359172627329826, 53.69741141796112, 58.84897738695145, 67.25632265210152, 68.17295506596565, 70.40209025144577, 72.78611272573471, 73.615243434906, 71.93821102380753, 73.6624065041542, 68.1895449757576, 70.5561263859272, 69.29020151495934, 78.69201421737671, 67.02942162752151, 74.5738559961319, 20.43252009898424, 1.9724203669466078, 0.08960674720583484, 23.821360655128956, 85.0827468931675, 61.872562542557716, 49.07363712787628, 46.467383578419685, 41.754853650927544, 36.195045188069344, 53.86046826839447, 28.501757606863976, 38.61669324338436, 70.9883987903595, 9.561070706695318, 1.2650838098488748, 0.05028027873777319, 0.028977130059502088, 0.03294377580459695, 0.06118811295891646, 0.07013873677351512, 0.1365563747822307, 0.32631286361720413, 0.149788853013888, 0.33459398488048464, 0.21036579622887075, 0.3499513358110562, 0.17995111498748884, 5.548253757879138, 4.078656015917659, 38.27166795730591, 53.50353442132473, 41.845930963754654, 58.22571963071823, 77.0044107735157, 49.96865250170231, 68.44516485929489, 80.77814787626266, 82.31559097766876, 66.7291009426117, 3.957755765877664, 0.9210850030649453, 7.308946279808879, 47.41227127611637, 83.46919387578964, 81.0723964869976, 78.23527872562408, 78.86081635951996, 78.3187298476696, 74.46552380919456, 72.74409458041191, 77.0163269340992, 75.36180451512337, 73.66182133555412, 73.21436494588852, 73.36603000760078, 68.89204367995262, 57.34843410551548, 56.92137122154236, 57.94002816081047, 57.45240792632103, 55.95311477780342, 61.512326672673225, 64.56691816449165, 63.99680435657501, 66.41185596585274, 64.76261526346207, 63.6862014234066, 66.72346204519272, 64.59683015942574, 59.040407314896584, 56.46451413631439, 52.122418731451035, 54.94227021932602, 61.269690692424774, 64.15953442454338, 63.02990823984146, 64.40740272402763, 62.10163705050945, 60.21041393280029, 62.38857865333557, 63.114487901329994, 62.77957007288933, 61.17541775107384, 60.75731098651886, 51.68447323143482, 52.08588369190693, 52.65444338321686, 52.89915405213833, 56.33629761636257, 58.055427968502045, 54.966680109500885, 46.85555174946785, 41.748207807540894, 49.47086401283741, 51.06953322887421, 50.426083356142044, 51.201538145542145, 46.46720498800278, 46.02959766983986, 49.619120657444, 51.35872431099415, 47.37989701330662, 44.77329008281231, 46.917040050029755, 47.931494414806366, 47.657696306705475, 45.87611250579357, 48.122016191482544, 46.58552683889866, 48.565516993403435, 48.64576108753681, 46.498382315039635, 47.01194375753403, 47.17269793152809, 48.1624536216259, 45.44025309383869, 44.53991040587425, 43.979619070887566, 47.079393938183784, 47.947905734181404, 47.69524589180946, 48.94146502017975, 57.02446348965168, 52.267776131629944, 40.988138392567635, 43.6665690690279, 49.71778616309166, 56.399875804781914, 55.62519237399101, 59.308726117014885, 57.00342781841755, 56.843908578157425, 56.28421001136303, 58.36263008415699, 58.943801298737526, 64.9832846224308, 57.93877802789211, 61.91788651049137, 60.00544913113117, 62.68027000129223, 61.27716489136219, 59.83545005321503, 59.88059163093567, 60.50349220633507, 55.00079087913036, 51.31620079278946, 50.071911960840225, 58.01798477768898, 59.611592665314674, 63.55844847857952, 61.286311000585556, 61.26593269407749, 65.15814363956451, 62.03541800379753, 61.23425379395485, 56.0565148293972, 57.36129641532898, 54.55514319241047, 55.061925798654556, 53.34644325077534, 55.59890158474445, 59.86048310995102, 66.99353635311127, 68.89950647950172, 71.65378868579865, 73.0725945532322, 73.55372473597527, 72.3320446908474, 71.92312583327293, 68.60723376274109, 68.8451997935772, 69.81229349970818, 78.70231166481972, 69.42795932292938, 81.18863224983215, 26.478793658316135, 2.583151739090681, 0.18758745834929869, 26.812558248639107, 88.47043991088867, 68.40003848075867, 57.80630573630333, 52.93295703828335, 51.01581171154976, 50.577110052108765, 61.813779696822166, 48.34213078022003, 54.46257255971432, 90.71086809039116, 19.17098969221115, 0.9200467087794095, 0.3701471630483866, 0.280981533578597, 0.2397890275460668, 0.09949432132998481, 0.2919927192851901], [0.04175591115199495, 0.04148034429817926, 0.0374274053319823, 0.06875773353385739, 0.06230283732293174, 0.11765692368499003, 0.17749295860994607, 0.4973895399598405, 0.6463922210969031, 5.965415798127651, 21.189994253218174, 31.052986308932304, 31.927023008465767, 60.25039538741112, 34.13823455572128, 54.83659788966179, 65.1245154440403, 69.16159361600876, 57.39889919757843, 3.820851487107575, 0.10896739113377407, 11.591289415955544, 48.63536864519119, 71.81391969323158, 69.91361886262894, 69.39886808395386, 70.44366762042046, 69.82306212186813, 68.91361892223358, 69.82544839382172, 69.30473953485489, 70.26700749993324, 66.94119796156883, 66.72815099358559, 67.51489877700806, 64.37229260802269, 55.40091700851917, 49.91292469203472, 48.845797553658485, 48.980340734124184, 48.30899275839329, 49.085481092333794, 50.128566920757294, 53.64905521273613, 57.71591238677502, 59.651133343577385, 57.79249347746372, 57.272016406059265, 58.62268052995205, 51.58397242426872, 49.608241841197014, 46.94268487393856, 51.36833779513836, 56.857903227210045, 59.61756594479084, 57.9570322483778, 52.87393480539322, 53.229827508330345, 54.29964870214462, 54.8305220156908, 55.420675948262215, 54.57202188670635, 49.49662663042545, 44.789811596274376, 44.50307138264179, 42.60066546499729, 43.069431111216545, 45.65092518925667, 49.448152631521225, 52.959323823451996, 48.54573145508766, 36.43127851188183, 30.245651230216026, 39.58265081048012, 40.1554586738348, 45.63316874206066, 45.714111998677254, 42.66025386750698, 39.08971086144447, 39.52069133520126, 39.84688863158226, 41.039675027132034, 41.1026718467474, 44.75313976407051, 43.67311991751194, 42.809988632798195, 39.3562475591898, 43.325708359479904, 39.28882397711277, 41.42400920391083, 40.35958372056484, 43.796168714761734, 41.96917735040188, 43.98538336157799, 43.61652575433254, 41.56671814620495, 40.87121106684208, 40.28242886066437, 40.283557400107384, 44.335230588912964, 39.567968398332596, 43.29935297369957, 44.44111570715904, 53.55928882956505, 34.01265509426594, 36.23144343495369, 44.53135326504707, 50.21867148578167, 53.196195513010025, 50.98952852189541, 49.28793042898178, 47.07333706319332, 47.44255185127258, 51.89599648118019, 53.69939111173153, 57.623717933893204, 58.20671305060387, 56.022122874855995, 52.84504875540733, 56.083573177456856, 52.88677051663399, 59.28276211023331, 52.8353288769722, 56.29337511956692, 52.0169135928154, 47.43447728455067, 44.60721619427204, 48.69201220571995, 57.161860316991806, 58.60661879181862, 58.56574058532715, 58.27699027955532, 60.579355135560036, 58.19903366267681, 51.8632460385561, 50.89883878827095, 48.08538995683193, 48.58370661735535, 49.0119094401598, 46.999225839972496, 53.895502388477325, 59.99115809798241, 64.94822010397911, 64.50466230511665, 64.837167263031, 64.72942024469376, 70.62381595373154, 66.78928211331367, 72.42782235145569, 69.36741337180138, 70.7820774614811, 63.82861018180847, 72.8872860968113, 62.32954502105713, 57.6535577327013, 12.641403917223215, 1.7042629374191165, 0.061949497103341855, 27.547708600759506, 77.35143095254898, 53.500255197286606, 35.321947038173676, 35.4718603938818, 40.58513201773167, 42.6588973402977, 34.826145842671394, 26.710579320788383, 40.406784787774086, 67.35567212104797, 9.698529280722141, 0.2620906394440681, 0.10288410310749896, 0.03119810346106533, 0.03569767803128343, 0.06055267127521802, 0.0711483099439647, 0.10257162182824686, 0.047967661230359226, 0.023299691056308802, 0.08631306613096967, 0.03539427321811672, 0.12170384012279101, 0.07388000711216591, 1.6289146430790424, 0.643512747483328, 15.635012481361628, 39.1763462126255, 25.020232424139977, 34.779556542634964, 72.25218057632446, 37.83932335674763, 63.20521183311939, 72.55856573581696, 77.18626141548157, 59.18668806552887, 5.061288513243198, 0.051324844171176665, 13.549878168851137, 54.46808606386185, 80.60496836900711, 78.44239801168442, 78.1602631509304, 76.29149302840233, 77.04424023628235, 71.79357558488846, 76.20000153779984, 74.82461214065552, 74.72270920872688, 70.1991355419159, 73.85000243782997, 73.13551157712936, 69.49587687849998, 58.793253377079964, 54.843532517552376, 52.500198259949684, 53.32262232899666, 51.97356931865215, 52.80160568654537, 53.97639624774456, 57.97761954367161, 60.32011404633522, 62.294811084866524, 61.678290367126465, 59.69022564589977, 61.60808153450489, 54.83145296573639, 52.97650270164013, 47.65003591775894, 56.063780039548874, 60.40022514760494, 60.62526427209377, 58.27804662287235, 56.360585913062096, 58.37046906352043, 56.83911323547363, 57.79029719531536, 58.91081906855106, 56.82650551199913, 52.28341989219189, 49.60356809198856, 47.210825085639954, 46.11747935414314, 46.02647043764591, 48.72782148420811, 52.32746332883835, 54.95694123208523, 51.374345272779465, 41.54846392571926, 34.33776564896107, 41.60494789481163, 42.95976899564266, 48.26736219227314, 47.362239360809326, 45.88703691959381, 42.25889280438423, 40.52854545414448, 40.765956714749336, 43.71294938027859, 42.470378056168556, 46.357132494449615, 46.608135625720024, 45.2228781580925, 43.398592248559, 45.676288828253746, 41.00970983505249, 44.068321511149406, 43.25447738170624, 45.5719768255949, 44.06070291996002, 46.04630537331104, 44.200189635157585, 43.748507872223854, 43.058267310261726, 42.611901462078094, 42.53376625478268, 44.88452911376953, 42.684903144836426, 43.992610573768616, 47.52786487340927, 53.11210222542286, 39.82011526823044, 40.092442855238914, 47.72875629365444, 54.49408046901226, 55.11217050254345, 52.40318566560745, 51.3318445533514, 48.09397749602795, 47.903417721390724, 52.398933693766594, 56.72990329563618, 58.622384145855904, 58.457218408584595, 59.10126484930515, 54.56805109977722, 58.89905869960785, 55.65974771976471, 59.620005413889885, 56.6537743806839, 58.71858738362789, 55.374345034360886, 49.74470391869545, 48.01911771297455, 51.895810291171074, 60.153151005506516, 61.186015382409096, 61.065079271793365, 63.93501967191696, 63.14028471708298, 60.48849821090698, 55.38401171565056, 51.18001990020275, 51.89058557152748, 51.50702275335789, 53.19481238722801, 52.92770951986313, 59.497226402163506, 65.53404986858368, 68.70855152606964, 67.97205984592438, 68.08263391256332, 70.47281205654144, 74.90626215934753, 72.28357449173927, 75.46614691615105, 72.66692072153091, 74.46480944752693, 67.31053054332733, 73.08928325772285, 69.84453856945038, 64.46429327130318, 17.215781807899475, 2.28560253046453, 0.10391046365839429, 31.488342247903347, 83.96804630756378, 61.04125835001469, 44.40604358911514, 43.10913898050785, 42.9859533905983, 49.061523377895355, 39.80702877044678, 28.141736425459385, 46.808297485113144, 81.87989875674248, 11.594776678830385, 0.43475233542267233, 0.09872796479612589, 0.07251687478856184, 0.07408735575154424, 0.07076352121657692, 0.04424747530720197, 0.19126625469652936, 0.16497499047545716, 0.15583652537316084, 0.13585660373792052, 0.10569992271484807, 0.26601618505083025, 0.12598701927345246, 1.180001744069159, 1.908846809528768, 35.21287389099598, 60.701431185007095, 40.88641785085201, 50.19189812242985, 78.69212821125984, 52.841731533408165, 66.24002918601036, 79.9805174767971, 80.37493631243706, 68.83557870984077, 5.939947189763188, 0.16419444407802075, 13.84397953748703, 55.336613059043884, 78.95670801401138, 79.27607327699661, 77.08114385604858, 77.5027160346508, 77.94907048344612, 72.38677695393562, 76.33231803774834, 74.47025075554848, 77.56469070911407, 72.19061627984047, 71.79864451289177, 73.90431672334671, 70.23128181695938, 61.15046828985214, 54.95229788124561, 53.150343373417854, 54.86693926155567, 56.04256957769394, 55.06939619779587, 55.55756360292435, 59.575885981321335, 63.42154562473297, 64.31616201996803, 63.60367365181446, 61.84463404119015, 63.41971032321453, 56.952453553676605, 53.47839497029781, 52.529312297701836, 57.85293683409691, 62.09977515041828, 62.55516551434994, 61.12902984023094, 57.9885895550251, 60.67669451236725, 58.60432371497154, 62.08005800843239, 61.79079093039036, 60.96767529845238, 56.18400178849697, 51.233901008963585, 49.876629039645195, 48.33717584609985, 48.394871950149536, 51.80125616490841, 55.64777836203575, 60.46455569565296, 55.36860354244709, 44.65059466660023, 38.02442282438278, 44.57705341279507, 47.56577543914318, 51.84111222624779, 48.924054354429245, 47.75160066783428, 45.21681368350983, 43.4852010011673, 44.71492901444435, 45.51742695271969, 45.823755115270615, 49.95650455355644, 49.45547863841057, 47.91168987751007, 46.72581531107426, 49.578048661351204, 43.45588177442551, 48.817207887768745, 45.72848282754421, 48.61652925610542, 46.58116467297077, 50.02468429505825, 49.24484074115753, 46.18016459047794, 47.595064267516136, 46.28145195543766, 45.7728074491024, 48.41583922505379, 45.3413899987936, 49.339128881692886, 52.873486429452896, 57.00533911585808, 42.09460102021694, 47.250992730259895, 51.694474294781685, 58.13651941716671, 57.2293446958065, 57.41873413324356, 53.59218366444111, 52.63961657881737, 50.89326448738575, 55.93065418303013, 58.898515328764915, 60.49304656684399, 59.88378345966339, 62.206625416874886, 55.67864790558815, 61.89633406698704, 56.21766038239002, 61.69215202331543, 58.84092181921005, 60.079583153128624, 55.05787521600723, 51.861425936222076, 49.77454371750355, 53.34270045161247, 60.80074645578861, 63.16320888698101, 61.755148842930794, 63.25844697654247, 63.281173557043076, 61.79796114563942, 55.88512122631073, 52.06319510936737, 52.23259001970291, 52.95091487467289, 53.96996319293976, 54.03102591633797, 59.594561979174614, 64.98134672641754, 68.63276079297066, 67.36216217279434, 67.38063678145409, 69.62682545185089, 74.4327999651432, 72.66616076231003, 75.82819148898125, 72.71319463849068, 73.1459154188633, 66.82382225990295, 74.7756327688694, 70.68272799253464, 67.28398516774178, 20.4023440182209, 2.8044551890343428, 0.14360658475197852, 34.10749040544033, 90.42748689651489, 67.36294493079185, 50.91335400938988, 47.96115942299366, 61.73364579677582, 63.98728206753731, 48.138583302497864, 48.84980633854866, 65.3455875813961, 90.81279382109642, 15.112915746867657, 0.446842277306132, 0.30500307271722704, 0.1592491430346854, 0.1822383250691928, 0.1613021461525932, 0.16195422678720206], [0.06373213953338563, 0.05170998541871086, 0.06729626664309762, 0.0319739001133712, 0.05666088225552812, 0.01923566440382274, 0.004386654482004815, 0.3222993586678058, 0.6388662499375641, 5.3662316501140594, 35.4836967587471, 53.39212819933891, 38.490931391716, 69.09096300601959, 34.519642889499664, 50.28157331049442, 66.02436035871506, 68.5280992090702, 58.39118555188179, 3.8788698613643646, 0.036174923516227864, 17.54672884941101, 55.82117825746536, 72.12957635521889, 70.4375347495079, 69.4885128736496, 70.13487339019775, 68.44018712639809, 69.033342897892, 66.11522108316422, 68.3326604962349, 67.2683148086071, 68.52128237485886, 66.45866945385933, 67.32469618320465, 65.53941518068314, 60.26488021016121, 49.15676906704903, 50.8676652610302, 47.89758883416653, 49.39073771238327, 48.22216361761093, 47.399412766098976, 49.112923219799995, 54.42048221826553, 56.53030000627041, 57.56624221801758, 54.423620849847794, 56.90459132194519, 53.01185220479965, 49.215859696269035, 45.72697430849075, 52.97679528594017, 58.15962977707386, 58.729454800486565, 55.34034825861454, 53.723200634121895, 57.04047203063965, 53.30142706632614, 56.490345150232315, 54.740295857191086, 51.63932405412197, 50.19283667206764, 44.09383714199066, 43.143614530563354, 44.39984232187271, 42.4361988902092, 44.40373711287975, 49.32594358921051, 53.92580196261406, 51.31958641111851, 38.34440365433693, 29.27341639995575, 45.52992448210716, 42.5847215205431, 43.096664249897, 44.01116117835045, 43.90413612127304, 40.1774100959301, 42.07229621708393, 39.73217658698559, 39.76608596742153, 41.715658754110336, 44.91152286529541, 45.778830125927925, 46.2070519477129, 43.25321204960346, 41.59803606569767, 38.625417575240135, 39.11040835082531, 41.03230342268944, 42.09830202162266, 40.287562385201454, 43.171527832746506, 42.27621227502823, 40.79867295920849, 38.4502811729908, 41.10692761838436, 38.126975521445274, 40.746429562568665, 41.215825974941254, 43.164479210972786, 42.19828225672245, 47.29272209107876, 33.96063208580017, 34.32892732322216, 48.16532626748085, 51.24651253223419, 51.200063824653625, 51.10371619462967, 45.08510135114193, 44.46494422852993, 43.597378581762314, 45.87890535593033, 51.60559706389904, 51.887758523225784, 55.7295385748148, 58.97230736911297, 54.11942437291145, 55.35791091620922, 52.00025908648968, 48.89367118477821, 59.42255660891533, 56.23086467385292, 56.55040092766285, 47.54525274038315, 45.494263395667076, 50.93442767858505, 57.208799198269844, 59.97878976166248, 58.14098417758942, 57.389924079179764, 60.53235545754433, 57.410693764686584, 49.10842806100845, 48.85788470506668, 48.9676646143198, 50.65232701599598, 51.4353433996439, 51.076460257172585, 59.86067309975624, 63.34552690386772, 65.8997954428196, 62.81375303864479, 68.15496683120728, 64.98764678835869, 68.40368628501892, 68.33851978182793, 70.228211581707, 66.30020275712013, 72.7253083884716, 71.96341887116432, 69.19574618339539, 61.87977075576782, 55.128167644143105, 16.775533631443977, 1.4236184279434383, 0.018879726667364594, 30.65693736076355, 73.69690105319023, 59.88767445087433, 30.11977918446064, 37.92686685919762, 52.19838045537472, 50.88810056447983, 32.89388492703438, 38.38919185101986, 53.233900889754295, 45.55843435227871, 1.1406642361544073, 0.14677263126941398, 0.015214381746773142, 0.018702819070313126, 0.03309512940177228, 0.056564269470982254, 0.027412387753429357, 0.07889190106652677, 0.046905944764148444, 0.010836611236300087, 0.027360259300621692, 0.010241415293421596, 0.05303183577780146, 0.050815998038160615, 0.4797095339745283, 1.1667291750200093, 18.44274926930666, 49.32957999408245, 59.10315714776516, 43.985493555665016, 80.74368372559547, 40.87397351861, 58.537671491503716, 73.10584276914597, 76.55934825539589, 65.02417802810669, 4.643135676160455, 0.028267857669561636, 19.84638825058937, 59.8511204123497, 78.73635783791542, 78.92454653978348, 74.06941026449203, 74.57964688539505, 75.02154037356377, 74.28130209445953, 72.24797800183296, 71.66910946369171, 72.27703124284744, 72.10616961121559, 70.28160631656647, 71.76169529557228, 71.3609991967678, 65.56799724698067, 54.079663306474686, 53.875340670347214, 53.64736810326576, 52.82174080610275, 52.18942433595657, 52.121305391192436, 50.87052270770073, 58.321558088064194, 60.1644553989172, 61.45950570702553, 57.213499546051025, 59.34567533433437, 54.96647112071514, 51.44531026482582, 48.04679922759533, 54.77751486003399, 59.770294949412346, 60.695480704307556, 58.68992172181606, 57.79117874801159, 59.69673469662666, 57.46569961309433, 59.944071024656296, 58.00652079284191, 52.35103726387024, 50.59415973722935, 47.91851431131363, 46.10763408243656, 47.052666172385216, 45.335295125842094, 46.26059107482433, 51.88149645924568, 54.83862318098545, 52.9845354706049, 42.15562954545021, 33.37866671383381, 48.14164973795414, 46.74680158495903, 46.11617982387543, 46.93188205361366, 45.30144654214382, 42.43746802210808, 43.80097545683384, 42.71431736648083, 42.55115792155266, 43.21639962494373, 45.266446620225906, 49.64526705443859, 48.15206877887249, 45.90296946465969, 43.71650218963623, 42.076407596468925, 42.48658798635006, 42.92930983006954, 44.193604588508606, 44.390738010406494, 44.5469818264246, 45.713093653321266, 43.09169791638851, 42.25649893283844, 43.75647984445095, 40.98531134426594, 41.8344783782959, 43.384476006031036, 43.123779594898224, 46.295021027326584, 48.3411580324173, 37.78357654809952, 39.663092494010925, 53.29897619783878, 55.51880568265915, 54.92260627448559, 52.88124941289425, 48.2174214720726, 46.74582503736019, 48.181855380535126, 46.511176228523254, 53.58100846409798, 55.83807595074177, 56.11663140356541, 58.188694417476654, 58.40425305068493, 57.79603868722916, 54.3198674172163, 51.37573219835758, 61.63191385567188, 58.280774876475334, 60.48260472714901, 49.612007439136505, 48.17603029310703, 51.57013736665249, 60.18242463469505, 62.4215342849493, 62.127380669116974, 60.26011906564236, 63.425964787602425, 60.22407419979572, 53.22209492325783, 52.709529027342796, 51.39438159763813, 52.264819890260696, 54.78427469730377, 55.059060752391815, 65.68465858697891, 68.17990869283676, 69.90011438727379, 68.37599337100983, 71.16998344659805, 68.14820319414139, 73.14785331487656, 72.50348389148712, 75.1723238825798, 72.50088483095169, 77.03951328992844, 76.67955860495567, 73.69778260588646, 66.85992032289505, 63.015146031975746, 19.047787003219128, 1.7005410371348262, 0.04455722177226562, 33.58070947229862, 80.1443798840046, 64.16693642735481, 40.08220240473747, 43.12340721487999, 56.37849435210228, 58.08897256851196, 32.34991751611233, 41.68267272412777, 65.98244860768318, 56.41194395720959, 1.3150715525262058, 0.2070953295333311, 0.006158730120660039, 0.034905157081084326, 0.06020658925990574, 0.027617328123596963, 0.060137602922623046, 0.12423550622770563, 0.15334161784267053, 0.14596976106986403, 0.11993742475169711, 0.12282602678169496, 0.13115272333379835, 0.21791722305351868, 0.38158974435646087, 2.8224130254238844, 40.86320489645004, 69.76837545633316, 67.4895541369915, 53.46091590821743, 83.44372764229774, 51.352325454354286, 65.88379830121994, 79.59546133875847, 80.51501199603081, 71.0050418972969, 6.238341853022575, 0.17523858114145696, 21.086656898260117, 60.8642752468586, 79.57489684224129, 80.50958588719368, 75.96182271838188, 75.50990536808968, 75.1102352142334, 74.79324862360954, 71.69020593166351, 72.94940516352654, 71.59317433834076, 72.26411193609238, 70.92413663864136, 73.6555440723896, 70.80258876085281, 66.4548772573471, 54.81547102332115, 55.83640784025192, 54.833413660526276, 55.213036090135574, 53.034578785300255, 52.86753974854946, 53.9047396928072, 59.73294675350189, 61.824403926730156, 62.717492803931236, 60.68983420729637, 61.312138214707375, 56.52458131313324, 54.16215308010578, 49.1613782197237, 57.18805231153965, 62.43677146732807, 62.68705263733864, 60.42825624346733, 59.195241406559944, 63.20801988244057, 59.75835599005222, 62.812616899609566, 60.32554395496845, 56.38555817306042, 55.97497120499611, 49.687752574682236, 47.15183325111866, 49.54399108886719, 48.93728144466877, 52.01237663626671, 55.06754569709301, 60.16211472451687, 56.71261042356491, 47.12774254381657, 41.34944200515747, 49.040358513593674, 47.37826690077782, 51.58265009522438, 48.71359884738922, 50.88435396552086, 46.208404675126076, 46.63549415767193, 46.04252077639103, 44.9525036662817, 46.37310303747654, 50.20378388464451, 52.47909039258957, 51.209016144275665, 50.16635589301586, 46.904014348983765, 43.998819440603256, 45.02992071211338, 46.5564090013504, 49.18416179716587, 48.532751351594925, 49.26598280668259, 48.841397389769554, 45.95361314713955, 43.94218347966671, 46.93923465907574, 44.26249869167805, 44.06136408448219, 46.406636238098145, 46.702043786644936, 49.164691641926765, 53.951781168580055, 42.66311891376972, 42.92998619377613, 55.90402141213417, 58.02664831280708, 58.1552904099226, 56.9892393797636, 51.90242953598499, 49.98209998011589, 51.25919625163078, 50.83041585981846, 55.334401577711105, 58.2202061265707, 59.42136347293854, 60.39199098944664, 58.505582213401794, 61.00491710007191, 53.98070141673088, 53.69550012052059, 64.30213317275047, 59.64973121881485, 59.86022852361202, 51.83132775127888, 48.35215464234352, 54.90831144154072, 61.25219643115997, 64.82767537236214, 62.758747190237045, 62.65817418694496, 64.33012247085571, 61.38846851885319, 53.944071382284164, 53.66597190499306, 52.03134901821613, 55.15360347926617, 56.106820330023766, 57.043169885873795, 67.12885469198227, 68.95081132650375, 70.19437059760094, 68.90310108661652, 73.23195800185204, 69.55477371811867, 73.59372138977051, 74.25902768969536, 77.11615517735481, 75.26635363698006, 79.25705909729004, 75.4005928337574, 73.76811683177948, 68.81037846207619, 66.61178603768349, 20.86928006261587, 2.7510115318000317, 0.18994250072864816, 36.51174299418926, 83.6979492008686, 70.48780605196953, 43.35744045674801, 51.350702941417694, 77.04053923487663, 68.85042831301689, 49.10058908164501, 59.845515713095665, 80.94844713807106, 63.54211315512657, 1.4760962245054543, 0.2488769227056764, 0.17483186937170103, 0.16973935591522604, 0.19178365037078038, 0.11605012201471254, 0.11588221110287122], [0.09407371180714108, 0.060038188530597836, 0.015473295734409476, 0.02801589111186331, 0.1286056131357327, 0.09773449623025954, 0.057594496611272916, 0.14195006660884246, 1.0414077434688807, 4.839135808870196, 36.44554294645786, 37.07204952836037, 47.25758537650108, 53.422986343503, 44.48743902146816, 31.713702455163002, 61.7135638743639, 66.96952164173126, 62.890934497117996, 5.176615174859762, 0.19838073465507478, 23.39770808815956, 52.20078952610493, 70.90877786278725, 70.08273258805275, 66.86800628900528, 68.13008576631546, 66.1179493367672, 65.17835855484009, 67.93495863676071, 65.49147695302963, 65.40257692337036, 66.35662212967873, 65.04123911261559, 65.2070926129818, 66.62231907248497, 62.82475344836712, 54.32505413889885, 49.60910439491272, 47.79618747532368, 49.84903112053871, 47.795123532414436, 47.91260562837124, 47.508797496557236, 48.25221620500088, 53.63596111536026, 55.61631225049496, 54.4309164583683, 55.93657046556473, 53.03165294229984, 48.36004301905632, 46.21970906853676, 50.626176819205284, 57.77962736785412, 56.535125747323036, 57.285281494259834, 57.42799423635006, 52.68032759428024, 60.21176666021347, 55.695811584591866, 53.382928892970085, 49.9398348480463, 45.173507407307625, 45.96451096236706, 44.59374211728573, 43.58855925500393, 43.47617268562317, 43.273537158966064, 47.11745649576187, 51.48904591798782, 52.41263195872307, 41.18141122162342, 31.592519357800484, 48.26279863715172, 45.685438737273216, 42.45570324361324, 41.7021618783474, 40.82804538309574, 40.06620906293392, 40.078816786408424, 41.180522069334984, 40.67814722657204, 40.84169425070286, 39.68203827738762, 41.438079848885536, 43.06633807718754, 43.18959206342697, 42.460859566926956, 39.13199499249458, 41.7158829420805, 40.65654158592224, 40.841907039284706, 43.895426988601685, 41.340390890836716, 38.596124947071075, 42.397349774837494, 40.381041169166565, 38.350916504859924, 39.00283232331276, 40.42975455522537, 40.27805529534817, 42.669578567147255, 46.41871578991413, 39.74225364625454, 30.939450301229954, 37.01019264757633, 51.19939886033535, 54.18787010014057, 49.40835356712341, 46.528780683875084, 43.74366693198681, 43.00693206489086, 43.77092286944389, 45.09087324142456, 46.47234991192818, 51.993620842695236, 53.29182878136635, 55.07038414478302, 59.00021307170391, 54.37575101852417, 51.93350046873093, 58.92091512680054, 61.916723772883415, 55.98477087914944, 57.68075667321682, 48.60463589429855, 44.73814956843853, 47.13971570134163, 57.231601774692535, 57.37811051309109, 58.39010640978813, 58.20517413318157, 61.964111030101776, 55.72329171001911, 48.636219799518585, 48.45829054713249, 49.09297049045563, 47.59147346019745, 49.7473181784153, 54.84349451959133, 64.5140478014946, 63.06757941842079, 66.75867855548859, 65.01984626054764, 67.42029905319214, 65.65647929906845, 65.17121493816376, 62.77396537363529, 70.59535548090935, 65.04899829626083, 69.84633207321167, 69.13234278559685, 77.87467047572136, 65.58128133416176, 61.988239735364914, 21.627869457006454, 1.3938114023767412, 0.2714035240933299, 27.66926407814026, 77.16496735811234, 50.87166264653206, 28.93308386206627, 50.77061466872692, 34.39294248819351, 53.609149754047394, 32.480265721678734, 34.48395900428295, 48.80993887782097, 18.56290452182293, 0.1385163571103476, 0.04649311027606018, 0.1324585618567653, 0.12034981395117939, 0.11130930492072366, 0.049370249835192226, 0.10403972351923585, 0.07602382684126496, 0.026021285739261657, 0.11710191596648656, 0.10985321117914282, 0.022990644065430388, 0.07141963913454674, 0.11774168437113985, 0.09495657068328, 1.1312914453446865, 13.741126656532288, 50.93591719865799, 43.4251756221056, 59.411970376968384, 62.497837990522385, 48.17765660583973, 39.43976327776909, 70.45040085911751, 73.49922806024551, 70.23735389113426, 7.005713526159525, 0.29570657468866557, 27.358264066278934, 58.117049261927605, 77.8655357658863, 76.31238430738449, 72.87964090704918, 74.8449182510376, 71.20599031448364, 70.47623947262764, 71.20440199971199, 70.93949541449547, 70.77876403927803, 70.48185557126999, 69.06640872359276, 66.38562977313995, 70.67167818546295, 67.7673876285553, 59.48669336736202, 51.52047783136368, 53.05225543677807, 51.80624529719353, 51.10275484621525, 52.000335082411766, 50.76695166528225, 53.044036477804184, 55.711975917220116, 59.310056045651436, 57.99013987183571, 58.726411163806915, 55.29587544500828, 50.32003104686737, 48.38736355304718, 51.32599286735058, 60.202810540795326, 58.27163636684418, 60.10264031589031, 57.22435936331749, 58.854825273156166, 65.24683088064194, 58.4231798350811, 54.57422576844692, 51.38144709169865, 50.08409030735493, 50.804892629384995, 48.37046965956688, 45.439998507499695, 44.93675731122494, 43.44385161995888, 49.957716688513756, 54.4902578741312, 55.614682137966156, 44.62718792259693, 35.293904542922974, 46.45638696849346, 48.67959067225456, 44.380911737680435, 45.750316455960274, 42.97709606587887, 42.46173731982708, 43.39558281004429, 43.578136414289474, 42.42817372083664, 43.3533138781786, 40.59544466435909, 43.285054340958595, 45.724299252033234, 45.643230602145195, 46.22706167399883, 41.12313374876976, 43.054543510079384, 44.04322765767574, 43.38351085782051, 45.24592772126198, 43.02345737814903, 43.03245909512043, 43.724489361047745, 41.265040934085846, 40.767165049910545, 39.88247752189636, 43.19068640470505, 43.36565941572189, 44.94177684187889, 46.81848853826523, 42.028385773301125, 36.1956911534071, 40.07679529488087, 53.18077594041824, 56.05138510465622, 52.60014809668064, 48.49192254245281, 45.61833813786507, 47.388769537210464, 44.86530974507332, 46.59688822925091, 48.069529607892036, 53.36140684783459, 56.73791326582432, 57.14029647409916, 60.55163562297821, 57.108530178666115, 53.738525211811066, 62.19977058470249, 63.12963388860226, 58.1588090211153, 59.77415174245834, 51.23041659593582, 47.91794054210186, 49.613747745752335, 58.93497057259083, 60.7647205889225, 63.562635853886604, 60.74176222085953, 64.34166625142097, 57.37223982810974, 51.76990024745464, 50.387435629963875, 51.79609604179859, 51.43016807734966, 53.57406243681908, 58.66564482450485, 68.13733577728271, 67.13083058595657, 70.67311450839043, 67.18362495303154, 70.26417285203934, 68.06355133652687, 69.1058886051178, 67.60495394468307, 72.42684200406075, 69.59749102592468, 74.42271530628204, 74.25857931375504, 82.84929513931274, 71.16503611207008, 69.069182574749, 27.215074449777603, 1.840577891562134, 0.2938203915255144, 31.408597826957703, 84.15531545877457, 58.591453805565834, 33.98283429443836, 46.89240217208862, 42.377043664455414, 62.16122165322304, 25.486556701362133, 42.6586389541626, 57.00610287487507, 21.06651797890663, 0.21363768784794956, 0.06603917237953283, 0.1272003713529557, 0.12340393717749976, 0.13216671970440075, 0.06307182105956599, 0.05262643389869481, 0.1863225715351291, 0.20805223990464583, 0.2867615281138569, 0.18590276828035712, 0.14898580469889566, 0.15966470120474696, 0.2590808743843809, 0.22596490918658674, 3.6216426640748978, 37.15471029281616, 64.13586169481277, 48.05453561246395, 61.024896427989006, 69.96834352612495, 61.9680742174387, 45.478338450193405, 76.31961151957512, 78.39908793568611, 74.99794363975525, 8.007183987647295, 0.2861902822041884, 31.102566048502922, 61.5003877133131, 77.1904867887497, 77.58474603295326, 72.4201999604702, 77.39051565527916, 71.72780871391296, 70.27628660202026, 72.7757316827774, 72.16614559292793, 70.30325755476952, 70.98744124174118, 68.99273827672005, 68.09542402625084, 72.51739114522934, 67.6341363787651, 61.502979174256325, 52.563757449388504, 52.496098279953, 54.573670998215675, 52.69285552203655, 55.24831339716911, 53.539495691657066, 54.39976952970028, 59.55303020775318, 61.08945116400719, 58.49841199815273, 61.947851702570915, 58.03776651620865, 52.44860462844372, 49.25082542002201, 52.7904798835516, 63.05768094956875, 61.23179152607918, 62.58962206542492, 60.66064417362213, 60.94369478523731, 66.96908846497536, 60.38931593298912, 58.12537081539631, 55.441377237439156, 52.3137878626585, 53.24765235185623, 52.53341607749462, 48.63095708191395, 49.05686862766743, 48.0116169154644, 52.031109631061554, 57.772996723651886, 60.051928237080574, 50.19049979746342, 40.97048074007034, 49.344623386859894, 52.32774831354618, 50.24993620812893, 48.26721780002117, 46.304360926151276, 46.75196930766106, 47.00926870107651, 46.7219091206789, 46.49035334587097, 47.46060848236084, 45.54636240005493, 47.550291270017624, 48.25429469347, 51.16477511823177, 48.79855468869209, 44.53949622809887, 47.15628281235695, 48.88993978500366, 47.33534060418606, 48.958347514271736, 46.978653743863106, 44.15995739400387, 47.27113924920559, 44.204870983958244, 44.072197303175926, 42.31475740671158, 45.01974105834961, 45.38060009479523, 50.072854310274124, 49.31583613157272, 51.21534660458565, 41.41234762966633, 45.57193882763386, 55.70005975663662, 58.5429722070694, 54.812951758503914, 51.373345926404, 49.43343982100487, 50.39221577346325, 49.05629485845566, 48.83779138326645, 49.48161743581295, 56.21453694999218, 58.37184078991413, 58.21254953742027, 63.49941864609718, 57.81301237642765, 57.47680641710758, 63.334579691290855, 63.564292564988136, 60.08194662630558, 62.26690158247948, 52.99125351011753, 50.030589178204536, 50.82150153815746, 60.643119513988495, 61.23910993337631, 64.19028997421265, 61.483763605356216, 66.00960955023766, 59.85323689877987, 51.95647403597832, 52.64232963323593, 52.227046117186546, 51.83555692434311, 54.19724799692631, 61.16265803575516, 67.90994837880135, 69.6163684129715, 70.97514510154724, 67.35401540994644, 69.25627693533897, 70.07691890001297, 70.1633870601654, 68.95328879356384, 76.44894897937775, 69.10883724689484, 75.0328865647316, 75.79275459051132, 81.56508564949036, 70.54853439331055, 68.24236214160919, 28.226777762174606, 2.8559115529060364, 0.42378662852570415, 34.124293103814125, 90.50097495317459, 64.18497025966644, 42.68378600478172, 65.72614476084709, 54.29254688322544, 71.87634274363518, 47.720955312252045, 56.53219610452652, 79.63043466210365, 27.006285153329372, 0.16650512086926028, 0.2023658450343646, 0.21186834841500968, 0.27932983939535916, 0.20940073707606643, 0.3049857361475006, 0.2850696095265448], [0.012392239968903596, 0.04364835062006023, 0.07795208235620521, 0.033442706844653, 0.07088319995091297, 0.02362153638387099, 0.017791817954275757, 0.049626431791693904, 0.49815700971521437, 1.4087759493850172, 44.37495745718479, 36.75601288676262, 17.977882213890553, 48.50479245185852, 48.04477773606777, 27.45301578193903, 55.15351228415966, 67.74759829044342, 59.92412969470024, 7.2610612493008375, 0.6189819169230759, 29.119281470775604, 55.99100634455681, 76.33433192968369, 68.21273893117905, 66.25959813594818, 65.89746996760368, 66.09487697482109, 65.63968420028687, 66.78876534104347, 66.01326495409012, 64.9093633890152, 67.18192264437675, 65.58850854635239, 66.44438982009888, 63.13190616667271, 65.06919041275978, 58.522141724824905, 48.87737385928631, 47.92167954146862, 47.8891608864069, 50.347647964954376, 48.19816790521145, 49.1303376853466, 46.54578097164631, 50.427584275603294, 53.92905838787556, 53.554603680968285, 53.538595139980316, 51.90701588988304, 45.93866854906082, 47.641968950629234, 50.17735630273819, 57.49102525413036, 57.902163192629814, 57.219374030828476, 51.176592484116554, 59.935624077916145, 58.30727085471153, 55.65866097807884, 51.352770030498505, 48.48246864974499, 47.776755318045616, 49.05947148799896, 44.45109397172928, 42.201485484838486, 42.26414792239666, 43.253831416368484, 46.90693639218807, 51.04988448321819, 52.27121114730835, 41.8010363727808, 31.717735938727856, 37.881280705332756, 39.424598291516304, 44.4227284938097, 40.109078362584114, 40.38687005639076, 42.01026454567909, 40.68397991359234, 39.36134688556194, 39.725580140948296, 38.81422944366932, 40.96914321184158, 39.793125316500664, 41.09994739294052, 40.087598115205765, 40.46707235276699, 40.68833827972412, 45.407859832048416, 43.93304117023945, 42.43690185248852, 43.22136975824833, 44.35331381857395, 41.30023844540119, 42.63559699058533, 39.756468683481216, 40.32282069325447, 39.74283501505852, 39.28914695978165, 39.93862710893154, 45.34262493252754, 41.66805110871792, 34.048050194978714, 26.919796094298363, 38.878377601504326, 52.69596755504608, 51.175213158130646, 49.81348782777786, 44.24983777105808, 43.93338695168495, 41.63967423141003, 41.390871182084084, 44.47735816240311, 48.28038029372692, 48.34223337471485, 50.37841871380806, 53.84872689843178, 54.28160347044468, 57.81993180513382, 54.76370260119438, 59.627183228731155, 56.30606643855572, 56.925201416015625, 55.15938676893711, 46.776964366436005, 45.33070497214794, 47.97978602349758, 56.65518790483475, 58.06597240269184, 57.90147162973881, 58.54053653776646, 59.472520127892494, 52.058715149760246, 46.05633683502674, 46.78119353950024, 48.00616420805454, 49.17491689324379, 50.85536912083626, 56.45116165280342, 64.77177277207375, 63.636538088321686, 66.01061269640923, 63.357587456703186, 66.90367117524147, 63.72947350144386, 64.13705483078957, 61.143746450543404, 66.23701214790344, 63.82099539041519, 71.74926236271858, 68.16318199038506, 71.81842625141144, 69.95205760002136, 68.4619827568531, 40.92458300292492, 2.109059253707528, 0.04123379912925884, 26.509108431637287, 71.00760295987129, 47.296187505126, 44.031797870993614, 52.34852559864521, 30.271639935672283, 38.461760357022285, 28.392270281910896, 40.30248798429966, 21.316481865942478, 1.8893749918788671, 0.30471856298390776, 0.07007275984506123, 0.20626168989110738, 0.04859437896811869, 0.041790651084738784, 0.03565987673937343, 0.03717963190865703, 0.038415519302361645, 0.08624568654340692, 0.07657748385099694, 0.02561181132477941, 0.06685805812594481, 0.03302108532807324, 0.012934586648043478, 0.05165522976312786, 0.3348328673746437, 20.28025846928358, 60.39272055029869, 35.61030216515064, 26.54999803751707, 66.90828412771225, 51.8331478536129, 32.21336804330349, 62.284521237015724, 72.74395778775215, 68.43864440917969, 8.478226661682129, 0.7969960710033774, 34.15537543594837, 63.555287048220634, 80.7522788643837, 73.37014898657799, 70.95639690756798, 68.85830909013748, 69.59631308913231, 68.9946761727333, 73.0890628695488, 70.18673300743103, 70.21942645311356, 71.82640582323074, 70.1251383125782, 70.4450811445713, 68.98895367980003, 70.52999138832092, 63.38665969669819, 52.047068774700165, 53.11645679175854, 52.004150077700615, 54.06233623623848, 50.721627697348595, 51.72272577881813, 48.03232580423355, 54.12967622280121, 56.81026138365269, 57.02438369393349, 56.2022066116333, 53.11725474894047, 49.125587940216064, 50.20983695983887, 52.10332475602627, 60.29367886483669, 60.003591030836105, 59.24377240240574, 57.052749171853065, 63.67502622306347, 60.03449857234955, 57.517069056630135, 52.91950576007366, 50.787022188305855, 50.62259741127491, 51.74930155277252, 45.962417274713516, 46.81962467730045, 46.92843943834305, 49.26084168255329, 49.260252714157104, 54.474336728453636, 56.35759547352791, 44.907875061035156, 33.934911265969276, 40.82039639353752, 42.61565946042538, 46.992811784148216, 43.94821375608444, 42.82109163701534, 43.02259482443333, 42.536851689219475, 41.858907267451286, 41.72299236059189, 41.71899497509003, 42.23069451749325, 43.222437500953674, 44.51238088309765, 43.13390985131264, 42.75045722723007, 44.64224651455879, 46.94343343377113, 45.0899650901556, 45.122168362140656, 44.238305389881134, 45.63270516693592, 43.347712978720665, 43.39184761047363, 42.63723470270634, 43.644739240407944, 39.92848165333271, 41.00111089646816, 42.04756714403629, 47.48751863837242, 43.3078683167696, 38.22114206850529, 30.67027274519205, 46.40096314251423, 56.405613496899605, 54.613888040184975, 51.096002608537674, 47.1789637953043, 46.5536617487669, 45.098054856061935, 44.222562834620476, 47.553319707512856, 50.095045119524, 51.27677410840988, 52.523848190903664, 57.00894892215729, 56.25824600458145, 58.44955421984196, 60.05736194550991, 59.352955743670464, 57.71868243813515, 61.47358015179634, 56.576851308345795, 49.70716953277588, 48.41797091066837, 51.40491463243961, 58.10986004769802, 61.46862141788006, 60.182238444685936, 60.299914330244064, 61.075205728411674, 54.88859809935093, 49.06086601316929, 49.63616654276848, 50.623106583952904, 51.802494898438454, 53.313168436288834, 59.15443539619446, 69.59068179130554, 66.09876796603203, 70.01521781086922, 68.02453503012657, 69.54338192939758, 68.87106880545616, 67.01039224863052, 64.67216491699219, 69.47545677423477, 67.85173550248146, 74.70293506979942, 72.82376110553741, 74.27478164434433, 74.63781416416168, 72.49532952904701, 48.28704513609409, 3.8871128065511584, 0.04034566358313896, 29.156490974128246, 77.72245064377785, 55.98876066505909, 43.132724314928055, 49.2655648291111, 42.909410297870636, 45.2323130518198, 28.653559461236, 52.967839166522026, 31.91422149538994, 2.61285949498415, 0.19259456545114517, 0.1632986421464011, 0.1606116519542411, 0.09812188247451559, 0.019261800989625044, 0.0732546734798234, 0.07631338317878544, 0.13955542322946712, 0.12363064102828503, 0.19348778470885009, 0.10907889882219024, 0.18039313814369962, 0.10371613971074112, 0.10568242287263274, 0.23427626554621384, 0.6880460015963763, 45.10671839118004, 72.69235655665398, 52.83471331000328, 27.455557845532894, 64.65723171830177, 66.9762472808361, 39.49752017855644, 69.53803181648254, 77.13364943861961, 74.92825537919998, 9.604942202568054, 1.0417231265455484, 36.28400981426239, 65.17670944333076, 79.98595118522644, 74.00299742817879, 71.10674723982811, 71.23646467924118, 70.4231259226799, 70.91077655553818, 73.87809053063393, 72.895098477602, 69.61600363254547, 71.35966166853905, 71.66771113872528, 71.19324579834938, 70.05212903022766, 70.03027260303497, 66.21384099125862, 51.91461928188801, 54.138446152210236, 54.10102196037769, 56.1473223567009, 52.80650742352009, 53.134703412652016, 50.89882358908653, 55.1932467520237, 59.03685450553894, 58.4672574698925, 59.6211339533329, 55.40430262684822, 50.50273284316063, 52.730811685323715, 55.483395382761955, 63.16841080784798, 61.73487313091755, 61.37737311422825, 57.890364825725555, 61.58552594482899, 63.50750841200352, 60.088117495179176, 56.71955265104771, 53.44132415950298, 53.0625756829977, 54.133601412177086, 49.70025010406971, 48.95304299890995, 50.33069707453251, 52.08906032145023, 53.24567265808582, 57.97795012593269, 56.85133337974548, 51.489638686180115, 40.598533898591995, 41.942008808255196, 44.960927814245224, 48.32085572183132, 45.898265317082405, 47.11253196001053, 47.016393318772316, 45.480200350284576, 45.64656302332878, 45.145989283919334, 44.32729281485081, 46.115621253848076, 47.22166210412979, 48.165261670947075, 46.12588830292225, 47.51266568899155, 47.41030678153038, 53.05889368057251, 49.697837233543396, 49.38083544373512, 46.67429007589817, 50.613512098789215, 47.90395349264145, 45.77851474285126, 46.2490700930357, 46.69034041464329, 43.25988069176674, 43.83932679891586, 44.66702498495579, 49.37226690351963, 46.63142077624798, 42.403129264712334, 37.90900781750679, 47.71959878504276, 59.683591201901436, 58.14798720180988, 55.69196239113808, 49.79307532310486, 49.336993396282196, 46.1185546964407, 46.359275579452515, 49.273365810513496, 51.90553396940231, 53.12323562800884, 53.965517431497574, 58.001318871974945, 59.02823656797409, 60.567761957645416, 60.382974073290825, 61.55701607465744, 58.49974572658539, 62.4895354360342, 60.073161497712135, 52.330392971634865, 50.73496498167515, 52.5135887414217, 60.6967194378376, 62.18753144145012, 62.80853971838951, 62.56598733365536, 64.80489939451218, 57.16057598590851, 49.03028145432472, 51.26511253416538, 51.793793365359306, 53.84976044297218, 55.58697022497654, 60.527655109763145, 70.8377292752266, 66.66875258088112, 71.94362953305244, 70.18106371164322, 71.27462983131409, 69.41917419433594, 67.87191241979599, 67.08143323659897, 72.49268487095833, 70.56166648864746, 76.3286854326725, 74.89924013614655, 77.45605453848839, 74.57423597574234, 71.06173485517502, 46.43591746687889, 4.592485819011927, 0.1808248009183444, 32.783922627568245, 82.30046778917313, 61.98783315718174, 62.58906349539757, 69.44732308387756, 45.601185858249664, 53.22225831449032, 47.978699281811714, 72.15030804276466, 54.79615665972233, 3.0452620424330235, 0.45067330298479646, 0.3509708389174193, 0.336953480145894, 0.19771915453020483, 0.1366015270468779, 0.1308644434902817, 0.15986889571649954], [0.001581651677042828, 0.051658743832376786, 0.0672374885471072, 0.11360393647919409, 0.04946695167745929, 0.03480744220723864, 0.06979680707445368, 0.06930486706551164, 0.017708216873870697, 3.817980741150677, 50.991747602820396, 52.594319209456444, 21.162384934723377, 38.4258446842432, 55.62629051506519, 25.513782240450382, 43.63335885107517, 65.02775743603706, 64.34539765119553, 5.486599216237664, 1.4118898822925985, 34.66436952352524, 59.090625420212746, 73.07754188776016, 67.18746274709702, 68.0608382821083, 65.59078082442284, 64.50501948595047, 64.05206099152565, 66.18266746401787, 63.689720034599304, 66.51650995016098, 67.403883934021, 65.748191177845, 63.996393978595734, 65.29011815786362, 65.84008544683456, 58.334310203790665, 48.758630231022835, 49.422108829021454, 46.456003189086914, 49.51070487499237, 46.63379184901714, 46.64875164628029, 46.47557593882084, 46.15631327033043, 51.506334990262985, 52.4984123557806, 49.37718763947487, 49.188212379813194, 46.18542730808258, 45.152627527713776, 49.297631308436394, 55.78216575086117, 58.95496889948845, 55.765655636787415, 56.67779669165611, 60.08489906787872, 55.40888138115406, 54.95524272322655, 50.61567798256874, 50.725993663072586, 48.5501392185688, 50.89357227087021, 46.7990829795599, 44.71454903483391, 43.037976399064064, 46.2021654099226, 44.16905790567398, 51.30863539874554, 54.41567927598953, 54.095174074172974, 31.603531166911125, 39.36811812222004, 44.97077688574791, 42.5992139428854, 45.800139382481575, 40.26917137205601, 38.80165211856365, 39.28951933979988, 38.255499824881554, 39.036699905991554, 39.49987605214119, 41.19569465517998, 41.59621976315975, 41.95406176149845, 43.089410439133644, 43.25807958841324, 40.507730171084404, 41.22882127761841, 44.89065818488598, 45.20826794207096, 40.666930228471756, 41.81830644607544, 39.3390990793705, 40.4672509431839, 40.42922258377075, 40.80211937427521, 38.53815905749798, 41.69744253158569, 38.597728461027145, 46.078926622867584, 44.244951233267784, 34.62443746626377, 23.618918918073177, 48.37190218269825, 54.784312695264816, 51.036285012960434, 48.63412991166115, 42.826958522200584, 43.32225814461708, 43.97740758955479, 41.69764772057533, 45.529669895768166, 48.301419764757156, 47.01708488166332, 47.33130902051926, 49.71583306789398, 53.41277629137039, 55.21581754088402, 54.986024871468544, 51.65300711989403, 53.31164471805096, 58.41688357293606, 52.30377919971943, 48.368166983127594, 44.70115855336189, 48.90886276960373, 52.85113602876663, 58.8711491972208, 58.28306995332241, 60.314201563596725, 56.43908590078354, 50.28107553720474, 45.96217028796673, 46.92266374826431, 47.15563304722309, 50.964544862508774, 47.16059938073158, 55.68791560828686, 62.78308488428593, 62.217652425169945, 63.71156506240368, 63.80798488855362, 64.94876727461815, 61.22562825679779, 60.30793569982052, 58.3553496748209, 60.065778493881226, 64.97066169977188, 66.19044944643974, 66.66698187589645, 69.00354489684105, 75.6174623966217, 66.91060200333595, 61.803102269768715, 7.709801495075226, 0.1027299219276756, 27.790658064186573, 72.3607787489891, 41.94997698068619, 49.1546031832695, 47.975879833102226, 24.400187395513058, 52.84026101231575, 32.00621455907822, 42.1123992651701, 7.351830303668976, 0.15207236720016226, 0.05088868027087301, 0.05908120765525382, 0.08057099534198642, 0.04061191648361273, 0.06886329661938362, 0.04482275478949305, 0.061409874106175266, 0.012254596622369718, 0.037484205604414456, 0.02155125421268167, 0.06073611162719317, 0.032763986819190904, 0.02205759930802742, 0.012708995091088582, 0.05859523451363202, 0.021648082220053766, 14.587365947663784, 64.80502858757973, 51.33572414517403, 19.254062734544277, 52.04252041876316, 62.61796474456787, 30.78535906970501, 53.70934657752514, 70.91560989618301, 72.17028737068176, 6.213228050619364, 1.93074467824772, 42.600369080901146, 65.68021282553673, 76.06372565031052, 73.33609521389008, 71.16706520318985, 67.7308563888073, 68.0866464972496, 67.72891089320183, 70.40791913866997, 69.09505158662796, 69.90797996520996, 70.65505787730217, 69.07266318798065, 68.46825242042542, 68.53208139538765, 68.04653584957123, 62.479169592261314, 51.766643822193146, 53.55627939105034, 51.78142122924328, 50.31814634799957, 48.4080458432436, 50.25442756712437, 48.17328304052353, 50.26656411588192, 54.95513252913952, 54.29318904876709, 52.529285699129105, 51.68170318007469, 49.2783435434103, 48.42301703989506, 51.00318118929863, 58.547634556889534, 60.51610752940178, 58.01057517528534, 59.669740945100784, 60.46689257025719, 58.10968905687332, 57.29081019759178, 52.722854912281036, 51.44701637327671, 52.273437827825546, 53.26197378337383, 49.367536157369614, 46.997219547629356, 48.086944073438644, 48.29716399312019, 50.21035373210907, 55.02214953303337, 57.435039058327675, 57.39256873726845, 31.664776280522346, 41.93498678505421, 47.150457724928856, 46.486154571175575, 47.99202136695385, 44.81862545013428, 41.58671647310257, 42.49638386070728, 41.5607600659132, 41.32011517882347, 42.71968647837639, 43.13093461096287, 43.86437885463238, 47.01908737421036, 46.81372359395027, 44.77944575250149, 43.49020533263683, 44.375877007842064, 44.53544944524765, 45.92118948698044, 42.1021132171154, 43.22428420186043, 39.84510652720928, 42.3156351596117, 41.81224197149277, 42.92930603027344, 40.74696533381939, 42.97508977353573, 43.84370036423206, 48.65044243633747, 47.29315906763077, 39.54451225697994, 29.416790306568146, 53.93463268876076, 56.924198269844055, 53.67900900542736, 50.25274805724621, 46.307130977511406, 44.79185588657856, 47.01241113245487, 43.738373816013336, 47.74020127952099, 51.008082926273346, 49.34803180396557, 50.36581099033356, 51.07060097157955, 54.028134271502495, 58.584029003977776, 56.77809230983257, 55.46051301062107, 54.734919145703316, 59.84644666314125, 56.08820132911205, 50.86745627224445, 46.977529004216194, 50.63720762729645, 55.699755772948265, 60.858279168605804, 60.562598034739494, 60.78865170478821, 59.22711789608002, 53.30640859901905, 48.510343953967094, 49.083235412836075, 49.13816526532173, 53.20430047810078, 50.67788064479828, 59.71206687390804, 66.6696797311306, 65.30867636203766, 68.00541445612907, 65.76303318142891, 68.63966882228851, 63.43085512518883, 62.030105888843536, 63.62717159092426, 66.04370892047882, 68.94182100892067, 69.96963545680046, 73.25033381581306, 75.6595641374588, 78.6463026702404, 71.83453738689423, 68.62901419401169, 11.334886774420738, 0.08080906889517792, 32.96193927526474, 77.63124793767929, 54.65999096632004, 55.806758031249046, 48.85504625737667, 39.82423424720764, 53.88447917997837, 34.10571590065956, 61.586012318730354, 9.434948824346066, 0.11432050232542679, 0.07742665664409287, 0.04400654819619376, 0.12311634753132239, 0.04928918875521049, 0.08907050098059699, 0.03149691066937521, 0.03706068418978248, 0.11487110910820775, 0.17044215492205694, 0.16568387509323657, 0.35702050023246557, 0.13976721733342856, 0.12554548593470827, 0.16647737938910723, 0.16850041458383203, 0.0798104572459124, 37.43183322250843, 75.07775455713272, 72.34135419130325, 34.26172032952309, 49.654059782624245, 76.63269191980362, 37.73501135408878, 58.35588164627552, 75.82998499274254, 78.17455798387527, 7.627796195447445, 2.028206717222929, 45.3070854395628, 72.359828799963, 78.16571205854416, 73.13026785850525, 72.98825427889824, 69.04808610677719, 71.19672641158104, 68.04789617657661, 70.19086718559265, 69.74890530109406, 72.90005341172218, 72.83168748021126, 72.77526810765266, 69.71287563443184, 70.09610787034035, 69.98413547873497, 63.35333168506622, 52.232875004410744, 55.674167945981026, 51.62776127457619, 53.0408788472414, 51.49981454014778, 52.30261646211147, 50.67014046013355, 52.403436452150345, 57.05074667930603, 57.82517932355404, 55.054926574230194, 54.60751958191395, 51.054140254855156, 51.565057039260864, 53.595113307237625, 60.53674042224884, 62.84931533038616, 61.53292536735535, 59.82745908200741, 64.54666525125504, 61.15935981273651, 60.944169759750366, 56.193360686302185, 54.342578798532486, 56.418339014053345, 56.14707536995411, 52.58457273244858, 49.25118640065193, 49.21996347606182, 50.96050567924976, 51.94294296205044, 58.9250835031271, 60.663057044148445, 57.54848197102547, 37.95695744454861, 43.5821034014225, 50.862577334046364, 48.37128661572933, 50.46707555651665, 47.63197548687458, 45.69327391684055, 46.29650294780731, 42.57501684129238, 43.09265546500683, 44.681866988539696, 47.41313382983208, 46.74477629363537, 49.377176240086555, 49.707199931144714, 48.60353395342827, 47.12413653731346, 47.18638859689236, 48.63818049430847, 48.33485037088394, 46.82484179735184, 47.91534148156643, 44.89880874752998, 45.18919676542282, 44.711923375725746, 46.67245477437973, 44.20581333339214, 44.75000873208046, 45.96055157482624, 52.707442939281464, 50.666823238134384, 43.72109234333038, 35.40875717997551, 53.23813006281853, 60.44842176139355, 57.5158379226923, 54.237746223807335, 48.41855987906456, 49.251395389437675, 49.795226007699966, 45.63527762889862, 50.866118744015694, 53.571429178118706, 50.354411602020264, 51.445640847086906, 53.833356723189354, 56.57989874482155, 61.10776998102665, 57.96652413904667, 58.20589229464531, 58.62426124513149, 62.28309251368046, 55.22757031023502, 52.94555716216564, 49.34161774814129, 52.650753781199455, 57.24742032587528, 63.59015017747879, 62.5409846752882, 63.000600412487984, 59.50749345123768, 54.01231952011585, 50.62791332602501, 50.4497142881155, 51.20486676692963, 56.30488470196724, 51.336503103375435, 61.09462648630142, 68.07273924350739, 65.6758962571621, 70.28102114796638, 65.57768672704697, 71.35602906346321, 65.5745404958725, 64.37823548913002, 64.32131454348564, 66.8045648932457, 70.3200526535511, 72.46081218123436, 75.51523268222809, 77.6261942088604, 79.59287747740746, 73.75222608447075, 68.49795162677765, 11.302506811916828, 0.14193866722052917, 36.09705224633217, 84.62178602814674, 61.83976270258427, 70.4069995880127, 65.87268009781837, 37.068755105137825, 69.0337760746479, 51.435658782720566, 80.08511066436768, 17.562537901103497, 0.4000574361998588, 0.136636734532658, 0.19009337935131043, 0.21133514499524608, 0.13998778362292796, 0.14418982376810163, 0.12040710775181651, 0.1663932643714361], [0.04663948406232521, 0.08531248036888428, 0.06519802962429821, 0.1591946990811266, 0.043263725165161304, 0.041533756666467525, 0.09885454550385475, 0.03989019271102734, 0.2638221887173131, 2.4266970343887806, 52.7985430508852, 50.30488505959511, 47.33106963336468, 18.552145399153233, 57.095899656414986, 28.398462049663067, 36.03766143321991, 66.72546073794365, 67.27010071277618, 7.406570166349411, 2.705436064861715, 47.74241276085377, 57.602640464901924, 71.26753941178322, 67.27110385894775, 66.84496432542801, 62.933150231838226, 65.65191194415092, 63.7981054186821, 64.50379595160484, 65.28748109936714, 65.46867057681084, 65.00953361392021, 65.8009247481823, 62.7763706445694, 65.06160601973534, 64.03705939650536, 63.90604242682457, 51.012137308716774, 48.81491661071777, 47.2590596973896, 49.32028569281101, 47.56075590848923, 45.88749669492245, 45.97165457904339, 44.234292805194855, 46.146585792303085, 48.79647620022297, 47.721152901649475, 47.869588136672974, 44.51025299727917, 44.13814656436443, 49.834344908595085, 56.66890136897564, 59.43255387246609, 56.78459756076336, 57.9025811702013, 56.86158522963524, 59.43460576236248, 53.73928137123585, 48.97088684141636, 48.19648839533329, 50.72734639048576, 50.56754216551781, 48.23648504912853, 47.66510970890522, 48.77067558467388, 47.15645760297775, 49.779137670993805, 50.48604793846607, 53.668722957372665, 63.970593363046646, 27.83513467758894, 35.775334909558296, 42.678899466991425, 41.56791128218174, 44.019931107759476, 39.244161173701286, 38.51010516285896, 38.24749365448952, 40.84629960358143, 37.51141995191574, 37.07207232713699, 37.49276675283909, 39.23092268407345, 41.66332796216011, 42.663498893380165, 39.58583123981953, 40.486584305763245, 39.55456271767616, 42.317713648080826, 42.682011500000954, 40.88504992425442, 41.10380418598652, 41.02756887674332, 41.545268297195435, 40.415110141038895, 39.75429520010948, 40.2828848361969, 42.32552222907543, 41.78872123360634, 41.600312143564224, 44.75299537181854, 33.97380217909813, 28.73923536390066, 53.1565560400486, 52.23830871284008, 48.99848856031895, 46.83231219649315, 42.714024782180786, 43.09980288147926, 42.272667065262794, 42.60716311633587, 49.693239480257034, 49.26310256123543, 51.781520023941994, 49.355061426758766, 48.837650790810585, 49.230428114533424, 52.27858655154705, 53.64344671368599, 56.37227788567543, 53.6377964168787, 54.94318597018719, 50.12009717524052, 46.29458025097847, 44.46336731314659, 48.51983204483986, 51.707002222537994, 57.12679959833622, 57.603867799043655, 57.14274354279041, 52.921781837940216, 48.61537031829357, 46.27892509102821, 47.08556480705738, 47.42883458733559, 49.52125310897827, 47.55994275212288, 55.802650451660156, 58.63804690539837, 63.15106853842735, 63.2080502808094, 63.56303483247757, 62.68120855093002, 61.11383445560932, 56.5272069722414, 60.62498688697815, 60.585864186286926, 64.12040412425995, 61.57349959015846, 66.16298452019691, 72.3600035905838, 73.02773416042328, 69.63646933436394, 70.92394664883614, 16.22993230819702, 0.036847301889793016, 36.65651522576809, 65.41672736406326, 32.26615481078625, 36.732161566615105, 32.42486469447613, 25.93605548143387, 40.62924765050411, 35.54247960448265, 34.95282344520092, 0.9269799711182714, 0.04594028818246443, 0.01805215037165908, 0.027496139118738938, 0.011104766817879863, 0.09568215362378396, 0.04669871486839838, 0.08499662973918021, 0.09923693709424697, 0.058259100987925194, 0.02731683252932271, 0.007490941789001226, 0.09040069679031149, 0.008967426037997939, 0.04187438389635645, 0.025368600254296325, 0.053542325767921284, 0.11847543835756369, 3.355040894821286, 67.73912474513054, 55.16636699438095, 31.611780524253845, 29.45800479501486, 72.40598872303963, 29.517245516180992, 46.61277897655964, 71.56555742025375, 75.09074985980988, 8.178838826715946, 3.021382223814726, 56.336445808410645, 65.85053488612175, 76.95915520191193, 70.07251113653183, 73.76140639185905, 68.33085179328918, 68.09060588479042, 67.29586333036423, 65.73068931698799, 68.5954923927784, 70.16410902142525, 70.5269667506218, 68.8881678879261, 65.99022299051285, 67.323107868433, 67.83218175172806, 65.97946956753731, 53.97127032279968, 52.771328911185265, 49.961634278297424, 51.729375422000885, 50.70828281342983, 49.27690342068672, 49.085481092333794, 48.38409572839737, 49.801784455776215, 51.20046280324459, 52.50168398022652, 49.36544626951218, 49.02932770550251, 47.74349570274353, 51.47415451705456, 56.279600858688354, 59.28647831082344, 58.5171639919281, 60.53248465061188, 59.50059302151203, 60.9116131067276, 55.115476325154305, 52.36383497714996, 52.034343257546425, 53.568024560809135, 53.77097927033901, 53.79853159189224, 51.255552247166634, 50.48245333135128, 49.377210438251495, 52.76002071797848, 53.832980543375015, 57.53680519759655, 61.41228944063187, 31.041727513074875, 38.476518765091896, 45.19212640821934, 45.43544255197048, 46.05394296348095, 44.03132289648056, 41.12922482192516, 42.18150995671749, 43.956052735447884, 39.90700140595436, 39.99803692102432, 40.79270727932453, 43.488328233361244, 45.06307393312454, 45.06579838693142, 42.557955756783485, 42.83963084220886, 43.47581170499325, 44.57748278975487, 44.565551429986954, 43.843992948532104, 42.523955181241035, 44.10144813358784, 42.28667311370373, 39.766937121748924, 41.52338907122612, 43.33347134292126, 44.47298839688301, 43.08146506547928, 43.668605759739876, 45.99077895283699, 36.346398666501045, 34.26235869526863, 60.437922924757004, 54.761517718434334, 53.011658415198326, 49.10102225840092, 45.942057967185974, 45.596907287836075, 45.25444306433201, 45.551655516028404, 50.14964058995247, 51.68044164776802, 53.90246741473675, 53.256118297576904, 50.554626658558846, 52.66369588673115, 53.09657245874405, 55.76224721968174, 56.93294160068035, 56.25325307250023, 55.59537537395954, 53.623205199837685, 47.89574973285198, 47.64503538608551, 50.56780435144901, 55.42233645915985, 60.5933877825737, 60.34491151571274, 59.95884083211422, 55.66447466611862, 51.581126376986504, 49.21275146305561, 48.54449652135372, 51.16554647684097, 52.2639649361372, 51.34665995836258, 58.770325407385826, 62.78158016502857, 67.84073129296303, 66.27534449100494, 68.2080727815628, 66.5738944709301, 63.189100697636604, 58.866220861673355, 64.63394656777382, 64.79261085391045, 67.69659742712975, 66.46079733967781, 71.62372469902039, 74.03206586837769, 76.56522274017334, 74.81597900390625, 77.99327731132507, 20.209952741861343, 0.0378710612130817, 41.21480002999306, 72.71660685539246, 40.070122852921486, 41.97363071143627, 37.835291773080826, 40.29365725815296, 34.64901454746723, 48.05906876921654, 44.8477166891098, 0.6523146783001721, 0.052051685051992536, 0.08161876685335301, 0.04934522832627408, 0.08832789317239076, 0.0680051364179235, 0.06118531877291389, 0.03090314243308967, 0.02997820934979245, 0.19635075295809656, 0.2739967068191618, 0.17657165648415685, 0.25991089234594256, 0.1336597724002786, 0.17505187162896618, 0.24027569830650464, 0.18222882557893172, 0.5563960690051317, 10.74698232114315, 89.49915871024132, 61.06166325509548, 69.77048054337502, 28.523857221007347, 79.67984721064568, 38.42470854520798, 48.15296933054924, 77.17080384492874, 79.43298205733299, 9.4938475638628, 3.285194467753172, 57.37937964498997, 69.96685400605202, 82.19528943300247, 71.65570378303528, 74.41570848226547, 70.47213569283485, 70.159952044487, 69.83182445168495, 67.78037533164024, 70.46598002314568, 69.1774083673954, 70.79755783081055, 72.50119641423225, 66.2704199552536, 70.29757305979729, 68.28757211565971, 70.93648597598076, 54.73410978913307, 55.35225301980972, 50.8085822314024, 54.413057416677475, 52.96133391559124, 51.37479364871979, 50.623125582933426, 49.13117744028568, 51.22008115053177, 53.97089794278145, 54.36590574681759, 52.751056998968124, 50.94127491116524, 48.326183035969734, 54.91806551814079, 59.24421317875385, 65.00683575868607, 62.49660685658455, 60.22889994084835, 61.163881570100784, 63.618948832154274, 58.542808815836906, 56.6759879887104, 54.42352965474129, 55.21898277103901, 56.097332239151, 56.22369445860386, 54.25098091363907, 54.089326187968254, 53.97367939352989, 55.46756163239479, 56.95779986679554, 62.219917103648186, 64.46582078933716, 32.96571247279644, 42.42948465049267, 46.714898496866226, 48.169240057468414, 51.4443489164114, 47.53793813288212, 42.76346392929554, 45.67645601928234, 48.823279961943626, 43.624691516160965, 41.763361394405365, 44.44276861846447, 46.965069472789764, 48.766081631183624, 49.06443402171135, 45.52956350147724, 47.4612620472908, 46.44268490374088, 47.8224478662014, 49.59233209490776, 47.77808904647827, 45.05222551524639, 48.58108475804329, 46.84029936790466, 44.24753129482269, 44.23634089529514, 45.22231198847294, 47.148329839110374, 46.02360159158707, 46.319202929735184, 48.36099296808243, 39.847382605075836, 38.81733387708664, 55.36272905766964, 56.16334609687328, 54.472569823265076, 52.78764143586159, 47.913570776581764, 48.48837733268738, 47.03623965382576, 48.15443605184555, 54.699615240097046, 54.69311758875847, 56.373490020632744, 55.73375254869461, 51.91499926149845, 55.79386532306671, 55.821018666028976, 58.88161763548851, 59.05293144285679, 59.1582465916872, 58.66995759308338, 54.11847822368145, 52.01843351125717, 51.65906019508839, 51.297289207577705, 55.222356989979744, 62.473355904221535, 64.95337262749672, 61.27339169383049, 56.67042888700962, 51.92399337887764, 50.931403040885925, 49.96465511620045, 52.929712012410164, 53.342651054263115, 52.87100896239281, 59.94337186217308, 63.26532080769539, 69.17026475071907, 69.85832422971725, 70.67968815565109, 68.73249024152756, 66.52284801006317, 63.05260822176933, 66.3975839316845, 68.40278953313828, 70.5752469599247, 69.80689778923988, 71.68532699346542, 78.09511944651604, 77.96865463256836, 76.63296550512314, 78.16825032234192, 19.89608008414507, 0.1194705767557025, 44.5330061763525, 77.03441396355629, 47.5700768083334, 51.40936799347401, 47.593434154987335, 40.2563014626503, 53.91123354434967, 58.797113969922066, 64.6720889210701, 1.3547955709509552, 0.13756605185335502, 0.16983751236693934, 0.08625325644970872, 0.17120413278462365, 0.1933423089212738, 0.15208143624477088, 0.14516579249175265, 0.2958796435268596], [0.05688210534572136, 0.025366037989442702, 0.10253000218654051, 0.09338425661553629, 0.034481494658393785, 0.0854553809040226, 0.09850097150774673, 0.12420373488566838, 0.34099889744538814, 0.052408223928068765, 38.279879316687584, 61.9599274545908, 61.973678916692734, 23.3066725730896, 32.06347368657589, 43.20476084947586, 26.025540679693222, 60.825315937399864, 72.82695293426514, 11.935744732618332, 3.82601042278111, 58.66213381290436, 54.27874982357025, 69.15501236915588, 64.99809622764587, 68.77100497484207, 60.92196375131607, 65.49977570772171, 64.16296184062958, 68.37804526090622, 66.00908517837524, 64.78212341666222, 64.50829491019249, 64.65835645794868, 62.5178287178278, 64.82699140906334, 61.241530403494835, 61.89109034836292, 48.74766021966934, 46.47762782871723, 47.45648570358753, 48.24763365089893, 46.30270801484585, 46.20617039501667, 44.59794469177723, 46.45449087023735, 46.44797421991825, 48.29290822148323, 45.91233216226101, 45.0969111174345, 43.739908933639526, 44.71209816634655, 50.05224421620369, 57.807099893689156, 56.6988779604435, 57.19759359955788, 59.84234668314457, 60.29495179653168, 55.05419321358204, 52.21110977232456, 49.740299955010414, 53.18581447005272, 50.18898367881775, 51.82046413421631, 50.20088084042072, 51.47973641753197, 48.09215359389782, 49.77718837559223, 45.41747331619263, 55.42750038206577, 50.19116476178169, 51.34747311472893, 30.923426561057568, 34.37626898288727, 45.24408482015133, 43.810482546687126, 44.827326983213425, 41.00133888423443, 37.779921144247055, 40.175202414393425, 37.72155627608299, 39.20148566365242, 38.27087759971619, 38.92871730029583, 38.05733285844326, 41.43589496612549, 43.746459782123566, 44.067094177007675, 42.547263130545616, 42.393903359770775, 41.79935686290264, 39.29979018867016, 40.92858038842678, 40.890886411070824, 40.234783217310905, 36.692639887332916, 38.306291699409485, 38.08226712048054, 38.730953112244606, 39.02921810746193, 43.534522354602814, 40.72251744568348, 45.37495739758015, 31.640687473118305, 33.76069821417332, 60.295859947800636, 50.486720502376556, 52.14738339185715, 44.03225764632225, 43.75677242875099, 40.603937208652496, 44.39994491636753, 44.347538128495216, 49.82871741056442, 48.639461025595665, 51.45072117447853, 50.53408496081829, 50.45418284833431, 50.24338535964489, 51.321444511413574, 50.74559301137924, 50.840728506445885, 50.01705430448055, 50.813107788562775, 51.379395201802254, 44.605597481131554, 44.53519485890865, 47.220867946743965, 51.202670484781265, 54.57141391932964, 55.856759548187256, 55.70765174925327, 48.93881656229496, 46.873916164040565, 45.86174547672272, 49.05695982277393, 48.682182133197784, 47.86388084292412, 47.5350046902895, 54.40653316676617, 58.37371788918972, 60.82450658082962, 63.195336163043976, 63.930794298648834, 59.651099145412445, 59.06867779791355, 54.92348402738571, 59.26960341632366, 58.891500905156136, 62.815128564834595, 62.965364903211594, 67.59581163525581, 66.74438372254372, 72.15482220053673, 69.55013796687126, 76.37605369091034, 24.597611501812935, 0.05764335219282657, 41.76183007657528, 65.45321300625801, 33.97450514137745, 43.96277077496052, 27.709942795336246, 38.88908542692661, 42.14817814528942, 51.47443950176239, 18.719655610620975, 0.49626943131443113, 0.03166081398376264, 0.09966091864043847, 0.081834865413839, 0.026599301891110372, 0.10618666769005358, 0.006380742670444306, 0.21501834969967604, 0.028984161908738315, 0.058529550733510405, 0.055456610352848656, 0.07156403138651513, 0.05152221834578086, 0.04237272121827118, 0.07077016343828291, 0.17291225987719372, 0.09806173882680014, 0.290932219941169, 0.02483636162651237, 39.539815708994865, 70.54383024573326, 49.396752789616585, 24.83560223132372, 50.248963460326195, 43.735242784023285, 34.40266236662865, 64.40139144659042, 79.59924593567848, 13.705289829522371, 5.691545968875289, 64.4643084704876, 63.12825836241245, 75.21764025092125, 68.12568560242653, 71.69807150959969, 64.91032853722572, 67.1931928396225, 65.13316377997398, 72.58961006999016, 70.06900012493134, 70.53841933608055, 67.8919069468975, 67.94821232557297, 67.6019749045372, 68.38485449552536, 65.26528269052505, 65.12887760996819, 54.38785716891289, 50.31711660325527, 50.56639842689037, 50.776424556970596, 50.50042636692524, 50.7210349291563, 47.709723114967346, 48.7032026052475, 47.980131804943085, 51.4392913877964, 49.719161689281464, 46.08896188437939, 47.91928566992283, 46.7264498770237, 51.6784505546093, 59.84810717403889, 58.189895153045654, 58.94227758049965, 59.89209361374378, 61.603240594267845, 57.13366582989693, 54.88724157214165, 52.59287528693676, 55.78014425933361, 54.884042143821716, 55.64901329576969, 53.70561517775059, 54.90567438304424, 53.60045202076435, 52.0291755348444, 50.7107412815094, 57.9229860752821, 53.64656254649162, 52.13099867105484, 37.30238176882267, 35.10907106101513, 47.36323110759258, 47.05116905272007, 47.75141827762127, 43.08307237923145, 41.3687639683485, 42.634985223412514, 41.31059288978577, 42.26689137518406, 40.448905527591705, 40.443597212433815, 43.78665402531624, 43.52248080074787, 46.112224236130714, 48.031299859285355, 44.860651195049286, 43.1302734464407, 45.67578345537186, 41.90615013241768, 44.85117070376873, 42.774658128619194, 39.6897404640913, 39.18491095304489, 42.530110850930214, 40.05507946014404, 41.988176330924034, 42.56235592067242, 46.2962331622839, 41.72453127801418, 47.51943692564964, 34.26173932850361, 42.223961278796196, 71.64395481348038, 53.25616769492626, 55.34387826919556, 47.45985612273216, 46.91507175564766, 46.27766735851765, 48.03745552897453, 46.24319940805435, 50.217527747154236, 50.91155670583248, 55.55111154913902, 53.04574258625507, 52.32604220509529, 52.171709686517715, 55.22303715348244, 54.42112058401108, 51.22603163123131, 54.7620040923357, 53.726312667131424, 50.62942944467068, 46.72655627131462, 47.62181483209133, 49.754731580615044, 56.22709907591343, 57.07098439335823, 56.85439981520176, 55.67032255232334, 50.8222196996212, 48.798102512955666, 47.97095909714699, 52.08596348762512, 51.36225812137127, 50.987784415483475, 50.73200114071369, 57.361600399017334, 63.331285268068314, 65.10928586125374, 65.30388861894608, 64.68990236520767, 63.645197823643684, 62.375803738832474, 58.67572568356991, 63.533575013279915, 63.32275852560997, 65.49638628959656, 66.82148918509483, 70.16001284122467, 70.81391215324402, 78.49678069353104, 71.92445576190948, 81.62167981266975, 28.097060322761536, 0.06045723108400125, 46.60682089626789, 72.03798606991768, 40.99907800555229, 48.5738879442215, 31.97483204305172, 48.07590186595917, 46.01549282670021, 67.11167201399803, 18.520907275378704, 0.6888307782355696, 0.18756440724246204, 0.2425323467468843, 0.09784215959371068, 0.007150572919272236, 0.06948795489734039, 0.035080712113995105, 0.11213850651984103, 0.022042216442059726, 0.17112605884904042, 0.17049596062861383, 0.23138745571486652, 0.17401978169800714, 0.18708649382460862, 0.29603534610942006, 0.24950313207227737, 0.23138758930144832, 0.3599823819240555, 0.117020992183825, 65.30494496226311, 73.97434696555138, 83.20516124367714, 30.48527967184782, 46.71601563692093, 58.01159352064133, 39.84236687421799, 68.20222109556198, 85.37429004907608, 15.41244987398386, 5.045783445239067, 67.96319112181664, 67.38149553537369, 80.1498743891716, 70.25648966431618, 74.62761551141739, 64.64783862233162, 69.29198741912842, 65.09209558367729, 73.86813506484032, 69.65626627206802, 70.877695530653, 68.62537398934364, 70.61132982373238, 69.1625663638115, 70.43750435113907, 65.20073935389519, 65.97555577754974, 55.25519482791424, 51.75256557762623, 51.16028755903244, 53.5000804066658, 52.85743609070778, 51.98202386498451, 49.91140857338905, 52.26702377200127, 48.998024985194206, 54.9435393512249, 51.209479719400406, 49.12222132086754, 49.62573990225792, 49.32145982980728, 54.714081063866615, 63.63124117255211, 59.864518493413925, 59.756866469979286, 62.52841874957085, 65.83070755004883, 59.954121485352516, 57.470445558428764, 54.67375382781029, 58.90486478805542, 57.82496653497219, 57.07672968506813, 56.24860592186451, 58.76898027956486, 56.62443995475769, 56.43291123211384, 50.25904431939125, 61.04582570493221, 57.80745707452297, 55.736963376402855, 40.01941077411175, 39.593461230397224, 50.913745388388634, 50.682919174432755, 50.98476357758045, 48.194554299116135, 45.283158123493195, 45.854104086756706, 41.548741310834885, 45.335021540522575, 43.18518429994583, 44.157339334487915, 44.18312095105648, 45.2979127317667, 49.13341172039509, 50.360715463757515, 49.66473340988159, 47.454559206962585, 49.189705699682236, 46.257634833455086, 46.465487480163574, 45.86555287241936, 44.48055379092693, 42.41386368870735, 43.21335978806019, 42.807191982865334, 43.014448061585426, 43.031691536307335, 49.070509895682335, 45.29108069837093, 48.08061361312866, 40.461638644337654, 41.514045372605324, 64.00816574692726, 56.20241940021515, 58.019113317131996, 50.30071288347244, 47.54406340420246, 49.54196199774742, 49.96745176613331, 48.937114253640175, 53.164767399430275, 53.61400209367275, 57.6452361792326, 54.75842468440533, 55.486868396401405, 56.76126301288605, 56.44440941512585, 56.52559965848923, 54.28343877196312, 57.0486605912447, 54.55529898405075, 53.19627910852432, 49.12800081074238, 51.59104764461517, 50.654629692435265, 56.79314710199833, 58.277286663651466, 57.94054873287678, 60.58117523789406, 52.407680824398994, 53.325088396668434, 49.48771990835667, 53.21873590350151, 53.83914761245251, 52.87472516298294, 53.211998865008354, 58.78283813595772, 64.66769635677338, 65.6933981180191, 68.89207407832146, 69.30293083190918, 65.7372173666954, 64.19973626732826, 61.302353739738464, 67.6714351773262, 66.05231165885925, 68.09930741786957, 69.32059988379478, 72.90457516908646, 72.53669410943985, 80.46043932437897, 75.42124852538109, 81.26357182860374, 29.20320186764002, 0.17072797083528712, 50.469963401556015, 80.20822405815125, 48.55381742119789, 60.66184110939503, 40.45223414897919, 54.13506433367729, 58.024600222706795, 79.23326477408409, 28.711705841124058, 0.6440489343367517, 0.39904030796606094, 0.3861139953369275, 0.1921505236532539, 0.14705255453009158, 0.2372550533618778, 0.14230723259970546, 0.3736258763819933, 0.17052984709152952], [0.014954582748032408, 0.027271157050563488, 0.07254062351421453, 0.08094399134279229, 0.06976794495130889, 0.07595763468998484, 0.07946706551592797, 0.13536488637328148, 0.19340102764545009, 0.7029765879269689, 8.09930244460702, 59.61334057152271, 53.96018631756306, 29.033366180956364, 24.27590176463127, 49.87756758928299, 28.85575231164694, 51.8883740901947, 77.24013492465019, 18.057316951453686, 5.8279429748654366, 58.5524071007967, 55.27961991727352, 65.6024993956089, 60.02481669187546, 68.6046651005745, 63.71150806546211, 64.05200779438019, 67.35415980219841, 69.9262797832489, 67.22280085086823, 67.26893797516823, 63.461766466498375, 63.37975166738033, 61.09581582248211, 63.15326102077961, 62.550712153315544, 59.41334590315819, 49.27715800702572, 45.8853118121624, 48.780935034155846, 47.26181074976921, 47.81186543405056, 45.81459380686283, 46.76581956446171, 45.649405270814896, 44.27927479147911, 44.79156330227852, 41.59825265407562, 44.89090897142887, 42.499849274754524, 46.64204120635986, 52.02629528939724, 59.03761826455593, 54.69471350312233, 58.252075016498566, 57.382928654551506, 57.26911336183548, 53.02564546465874, 50.44293165206909, 52.811865136027336, 52.771192118525505, 54.873269721865654, 54.190077781677246, 52.121578976511955, 52.78132997453213, 50.45290231704712, 54.20182295143604, 49.6141467243433, 51.514686942100525, 54.058129861950874, 54.123987928032875, 38.01191009581089, 35.49683265388012, 41.849757358431816, 44.256468415260315, 45.43883576989174, 41.23801678419113, 40.30554682016373, 39.13652054965496, 39.34032641351223, 38.25333394110203, 38.75462964177132, 35.94867020845413, 35.933881402015686, 39.8254007846117, 40.41105955839157, 41.19484730064869, 42.966057658195496, 43.58950160443783, 41.76946386694908, 40.20271293818951, 41.17418400943279, 41.285286247730255, 40.97399555146694, 36.86109624803066, 38.54688338935375, 40.84810450673103, 42.95020870864391, 39.26299676299095, 44.53053630888462, 41.62243455648422, 47.47922368347645, 32.04408332705498, 37.77015946805477, 51.21405467391014, 51.455527916550636, 49.94844138622284, 45.08959650993347, 46.30920946598053, 45.086066499352455, 46.85615971684456, 48.05606313049793, 50.85888013243675, 51.44750274717808, 52.27918691933155, 52.22557179629803, 51.07506573200226, 51.43538519740105, 50.535065308213234, 48.2091873139143, 52.08616107702255, 47.892029732465744, 47.87924721837044, 45.37498019635677, 43.09904292225838, 42.52593867480755, 46.97373680770397, 51.356208845973015, 51.34938821196556, 53.44470977783203, 52.31617033481598, 48.531987592577934, 44.821479097008705, 45.856186375021935, 47.31753095984459, 48.913696110248566, 47.9518461227417, 47.11575038731098, 52.4106028676033, 58.64744760096073, 58.90334866940975, 60.0536685436964, 56.63066402077675, 57.871369644999504, 57.282101064920425, 54.61377404630184, 55.83125151693821, 60.7200463861227, 61.35139010846615, 63.62324260175228, 63.929525166749954, 67.76719003915787, 71.82207405567169, 69.86955642700195, 75.5324837565422, 32.42248222231865, 0.09703777541290037, 51.06418691575527, 48.704357743263245, 37.10533954203129, 35.40507137775421, 37.223501801490784, 48.38381454348564, 41.17319606244564, 59.830259531736374, 4.779342692345381, 0.4684840457048267, 0.037139771156944335, 0.08151288464432582, 0.036094237220822833, 0.09466700692428276, 0.06060142666683532, 0.024951620871433988, 0.06866445299237967, 0.03200963823474012, 0.04998185744625516, 0.0595418884040555, 0.036292527947807685, 0.04712844434834551, 0.08721568097826093, 0.029392024007393047, 0.15972800640156493, 0.08766349288634956, 0.23893664125353098, 0.5492873035836965, 5.839210320264101, 66.14675179123878, 56.92253015935421, 18.07616773992777, 35.8640069514513, 53.24870869517326, 32.00853243470192, 63.97497072815895, 82.94144779443741, 22.368956990540028, 7.088378565385938, 64.52727109193802, 62.367470785975456, 74.68107104301453, 63.164884597063065, 73.76431703567505, 64.6456803381443, 70.01634255051613, 69.58115190267563, 73.44947353005409, 68.76929506659508, 70.42800486087799, 66.9650074839592, 67.85548210144043, 64.11626234650612, 67.17738568782806, 65.40402084589005, 63.00068400800228, 51.72614939510822, 50.07950775325298, 51.747477650642395, 49.40699703991413, 49.75504316389561, 49.09798622131348, 48.30059140920639, 48.67254205048084, 47.92743243277073, 47.30381369590759, 43.36199261248112, 48.53613317012787, 46.629429683089256, 47.84391671419144, 55.30905693769455, 60.632229298353195, 57.440381571650505, 57.24727973341942, 59.25256513059139, 59.93687801063061, 54.1494769603014, 53.13793703913689, 53.94892752170563, 54.939051792025566, 56.334329321980476, 56.04629337787628, 55.851854011416435, 54.1244401037693, 52.7590973675251, 57.20441423356533, 52.34135538339615, 54.22494851052761, 56.84372238814831, 57.901084050536156, 43.513976857066154, 38.629490956664085, 45.050169825553894, 47.0637159794569, 47.77466922998428, 42.56729185581207, 44.14938636124134, 42.230880707502365, 42.3052579164505, 41.37114264070988, 42.20624662935734, 37.90211498737335, 40.409357249736786, 42.99857251346111, 43.26814904808998, 44.55995813012123, 45.06150461733341, 45.55877633392811, 42.748599126935005, 40.76042801141739, 44.047825410962105, 43.79307948052883, 43.40454272925854, 39.37273867428303, 40.8923265337944, 40.51248371601105, 44.94338035583496, 40.76564513146877, 46.290408074855804, 44.14829961955547, 48.201036751270294, 34.66544486582279, 50.06419077515602, 64.77035164833069, 52.100467309355736, 52.036170959472656, 48.03223080933094, 48.25448848307133, 47.13962450623512, 49.97123636305332, 49.84085775911808, 53.62393856048584, 52.15304508805275, 54.9698681384325, 53.092951253056526, 52.60764129459858, 52.373380064964294, 53.483790680766106, 50.99455185234547, 52.51499846577644, 52.75551415979862, 50.21531626582146, 46.26376770436764, 46.40984706580639, 45.362608060240746, 50.04851661622524, 53.50779019296169, 55.13843849301338, 55.955254063010216, 56.431999281048775, 50.74840106070042, 47.46052108705044, 45.453890562057495, 50.087475925683975, 51.59503363072872, 51.39981910586357, 50.21100729703903, 54.743100106716156, 62.8953954577446, 62.50821903347969, 63.033126667141914, 60.503214821219444, 61.64305865764618, 57.839899733662605, 58.28783109784126, 60.15123590826988, 64.94180604815483, 66.63822501897812, 67.9261203110218, 67.33294934034348, 69.48539704084396, 76.25589653849602, 72.59612292051315, 79.52669262886047, 35.132485404610634, 0.023181791621027514, 53.54018725454807, 53.78756158053875, 42.61204585433006, 43.097747191786766, 39.11754436790943, 44.80637110769749, 45.43875977396965, 66.05219766497612, 2.3389110574498773, 0.22438894375227392, 0.07602186014992185, 0.11153951913001947, 0.028384601209836546, 0.06289234748692252, 0.05812591887661256, 0.0565761660982389, 0.09014683033456095, 0.04075466487847734, 0.1380885238177143, 0.12062401525327004, 0.21310774987796322, 0.1730528671760112, 0.18624890595674515, 0.11529757684911601, 0.33157472033053637, 0.2669435431016609, 0.38433180190622807, 1.197454088833183, 15.83925437182188, 85.67801535129547, 69.45024132728577, 41.00362256169319, 34.868456572294235, 70.12023657560349, 38.35551045835018, 65.69506242871284, 89.81189712882042, 24.294283278286457, 8.13726905733347, 66.48469045758247, 67.63514712452888, 77.63150632381439, 65.58258086442947, 77.11712792515755, 66.03085041046143, 71.86226069927216, 69.92362752556801, 73.4914080798626, 69.07406911253929, 72.2820545732975, 67.76709884405136, 67.98101976513863, 65.10876148939133, 68.00365895032883, 67.77000188827515, 66.25646710395813, 51.96009524166584, 51.59452065825462, 51.5421936661005, 53.11873286962509, 52.03305512666702, 50.389141738414764, 50.30591480433941, 53.74451369047165, 49.46647524833679, 49.55681160092354, 47.302571162581444, 49.921641424298286, 48.21634232997894, 50.2036888897419, 57.99599535763264, 63.398549258708954, 59.90980066359043, 58.704930916428566, 60.61180919408798, 61.32734499871731, 58.22033531963825, 56.36746734380722, 57.97579564154148, 57.120123356580734, 59.09662529826164, 59.64475728571415, 59.92496185004711, 57.790635377168655, 56.10634155571461, 62.3320072889328, 54.521731585264206, 58.25695775449276, 62.44258135557175, 60.41662886738777, 47.943300381302834, 42.73308075964451, 46.517309099435806, 50.37342198193073, 51.90461061894894, 45.69832764565945, 45.86477391421795, 44.5890037715435, 45.19168563187122, 44.87122982740402, 45.557822585105896, 39.47111539542675, 42.395096495747566, 47.0768328756094, 45.10579124093056, 49.2370929569006, 47.55985155701637, 49.12294328212738, 46.575901955366135, 43.66491995751858, 46.395453438162804, 47.79290825128555, 46.40887811779976, 41.60393334925175, 43.337689116597176, 45.71688964962959, 47.18104608356953, 43.91801297664642, 47.52623476088047, 47.01049603521824, 50.90614199638367, 40.15554986894131, 45.794394090771675, 61.22939005494118, 56.43712520599365, 54.02963139116764, 51.05462282896042, 50.97002416849136, 51.82934045791626, 51.39457918703556, 52.807860150933266, 58.2016821205616, 56.62092134356499, 57.21495866775513, 56.854635402560234, 55.87193973362446, 55.86049094796181, 56.22019864618778, 55.230290964245796, 55.75229935348034, 54.56664137542248, 53.45420926809311, 50.16016602516174, 48.65985073149204, 47.25080654025078, 52.336833626031876, 55.40378585457802, 55.86154729127884, 57.8279759734869, 59.36318479478359, 54.732388481497765, 50.34747697412968, 49.454224705696106, 53.28154653310776, 56.003154292702675, 53.048273250460625, 52.117737382650375, 58.244030848145485, 64.61842820048332, 65.89949905872345, 67.23297670483589, 63.546790704131126, 64.62134644389153, 63.411198779940605, 61.85798652470112, 61.87953896820545, 68.59665513038635, 69.06177297234535, 70.90198382735252, 71.13382458686829, 73.71814951300621, 80.98853498697281, 73.70024487376213, 83.12647506594658, 37.742455154657364, 0.3005286050029099, 56.31108596920967, 63.24885629117489, 50.30006691813469, 51.36229231953621, 54.09374535083771, 66.73895761370659, 53.72619487345219, 80.58111324906349, 5.845032557845116, 0.41600648663006723, 0.31406324123963714, 0.1791797563782893, 0.11546623733011074, 0.11981776828179136, 0.225087764847558, 0.11583004554267973, 0.15059438010212034, 0.12154644544352777], [0.05078051224700175, 0.03748013492440805, 0.004421855473992764, 0.01729151394101791, 0.05240632403001655, 0.0412391203281004, 0.013162298891984392, 0.061200829659355804, 0.03845050414383877, 0.04369460868474562, 0.1369152922416106, 33.79027962684631, 64.1930790245533, 46.129049733281136, 32.568333595991135, 48.86929929256439, 33.409927636384964, 34.655371606349945, 82.48081371188164, 23.622893504798412, 6.743928948417306, 52.535836547613144, 56.75406239926815, 65.05703866481781, 66.51641875505447, 66.4095912873745, 65.26897609233856, 67.69778296351433, 68.86603027582169, 67.61005327105522, 68.38256701827049, 65.99374160170555, 65.06409868597984, 63.44844438135624, 62.74443715810776, 63.12927670776844, 60.18730737268925, 54.019250348210335, 45.99556289613247, 47.92871296405792, 48.68478499352932, 44.903645887970924, 47.577835991978645, 46.41069442033768, 47.063385397195816, 43.609154149889946, 45.300215408205986, 43.626458421349525, 42.27280765771866, 43.40777635574341, 46.693289056420326, 43.173773512244225, 54.20284129679203, 61.60229444503784, 58.98850589990616, 55.68691246211529, 57.396520525217056, 57.92069099843502, 51.04845196008682, 52.869128063321114, 51.78737930953503, 54.303235709667206, 53.79450760781765, 53.67010988295078, 51.197970137000084, 53.64769488573074, 53.07957597076893, 53.836282566189766, 49.85224574804306, 53.29971335828304, 50.89263752102852, 53.83837625384331, 41.285183653235435, 36.57371386885643, 43.34813095629215, 43.32251653075218, 45.54435230791569, 39.57742989063263, 38.64623285830021, 40.76480157673359, 39.677714109420776, 37.4468994140625, 39.79013107717037, 37.77603015303612, 39.36049573123455, 43.352223336696625, 42.79631316661835, 44.13774758577347, 43.61395329236984, 43.465046882629395, 42.61597104370594, 42.0662697404623, 40.136288702487946, 41.52518257498741, 39.779894426465034, 41.393892019987106, 39.98615875840187, 38.82808730006218, 40.12232065200806, 39.45053569972515, 44.159208834171295, 41.762521639466286, 49.66558076441288, 31.601359583437443, 36.01639397442341, 40.53798034787178, 52.232833206653595, 50.355372950434685, 48.046521842479706, 46.2987220287323, 44.994628205895424, 47.01642371714115, 49.917017072439194, 50.23652292788029, 49.98282194137573, 52.4699404835701, 54.27980996668339, 48.0073269456625, 49.16379489004612, 49.47324648499489, 50.25569669902325, 49.53810140490532, 46.05785675346851, 47.142713740468025, 44.37575161457062, 44.74439263343811, 44.58242252469063, 44.553916454315186, 46.31234049797058, 50.48483580350876, 50.95914915204048, 46.910420805215836, 46.40283264219761, 46.72637768089771, 47.96015627682209, 46.240106374025345, 47.61663571000099, 48.094156086444855, 46.17655858397484, 51.46084763109684, 56.86324954032898, 57.44637385010719, 57.32790760695934, 55.83713740110397, 57.742005586624146, 52.94410564005375, 52.72830381989479, 51.709430292248726, 59.690579026937485, 60.25240167975426, 64.48674246668816, 65.60393571853638, 65.3566525876522, 69.07606020569801, 69.7040981054306, 78.51725399494171, 29.842840544879436, 0.37127602903638035, 53.891170620918274, 44.80425462126732, 39.538048803806305, 28.792508505284786, 72.07055032253265, 71.54457494616508, 44.30711589753628, 48.60070310533047, 0.3752302215434611, 0.04479334718780592, 0.007869241362641333, 0.02167433383874595, 0.0857305915269535, 0.20287264283979312, 0.032924520783126354, 0.05369104474084452, 0.03775271834456362, 0.023184635901998263, 0.03962230337492656, 0.10656615748303011, 0.05133300037414301, 0.027208358369534835, 0.016817177674965933, 0.04047014772368129, 0.0598610749875661, 0.03020249008841347, 0.009861093367362628, 0.026996094857167918, 0.15086762403370813, 33.25538232922554, 72.82639816403389, 36.660850793123245, 35.33061057329178, 57.45494619011879, 32.026938647031784, 42.37765163183212, 84.29402321577072, 30.61685711145401, 8.059604074805975, 57.75934025645256, 64.4481897354126, 71.23146414756775, 68.69560942053795, 71.16192027926445, 67.54905134439468, 70.05640000104904, 71.0014320909977, 71.69997900724411, 71.20268449187279, 72.27349743247032, 67.67041683197021, 69.28598374128342, 65.87608471512794, 66.06304228305817, 63.97726580500603, 58.56610916554928, 49.36567045748234, 52.002314776182175, 49.759656116366386, 49.48295496404171, 50.46020932495594, 52.187041863799095, 49.07891884446144, 47.06447213888168, 47.36203797161579, 46.259143352508545, 44.752748385071754, 46.40070095658302, 49.8365031927824, 45.628172010183334, 55.70803552865982, 62.92690336704254, 60.12931868433952, 56.57250054180622, 59.68119353055954, 57.6159131526947, 53.26243735849857, 55.8279836922884, 53.76038543879986, 57.057388722896576, 57.699653059244156, 57.84385532140732, 53.671869188547134, 56.6898762434721, 56.74448311328888, 55.094357058405876, 52.57576860487461, 53.6025533080101, 55.19679196178913, 57.115217819809914, 46.06620870530605, 40.20667612552643, 45.32040372490883, 45.68317785859108, 49.49779316782951, 43.58606278896332, 41.14215932786465, 43.08415152132511, 41.527724638581276, 40.51685728132725, 42.56703346967697, 41.307306066155434, 43.02105210721493, 46.548342034220695, 46.55814170837402, 46.97587609291077, 46.300150752067566, 49.763478711247444, 45.5675158649683, 43.194353207945824, 40.080652087926865, 43.7596070766449, 41.82905226945877, 42.520257979631424, 42.375706136226654, 40.99109463393688, 42.48212702572346, 41.99812799692154, 46.37862794101238, 42.774684727191925, 50.41690684854984, 33.8177939504385, 53.79084840416908, 51.612736880779266, 52.68139533698559, 53.134179040789604, 49.78266388177872, 48.792501613497734, 48.92293721437454, 49.35276634991169, 52.47049905359745, 54.5484783500433, 53.48004408180714, 54.291976913809776, 56.397219747304916, 52.019087076187134, 51.997204050421715, 54.955968484282494, 54.084337055683136, 54.57138732075691, 50.33448927104473, 49.69772323966026, 47.74330951273441, 48.12683053314686, 46.737758070230484, 48.508508652448654, 51.340979263186455, 52.02327825129032, 52.41804666817188, 51.05028346180916, 50.277982503175735, 48.2696420699358, 50.21033853292465, 48.98242302238941, 49.761696606874466, 51.37364611029625, 48.51053774356842, 53.835629001259804, 57.86795362830162, 61.284620091319084, 58.88056889176369, 59.30700100958347, 58.92442613840103, 56.768968999385834, 56.58904865384102, 56.13242335617542, 61.40978157520294, 64.22477692365646, 66.16746068000793, 68.68731826543808, 69.94070380926132, 76.50955572724342, 72.73623660206795, 82.10745334625244, 31.36735673993826, 0.6890286051202565, 60.35498097538948, 50.66275365650654, 48.989619836211205, 33.97537909448147, 78.18396627902985, 69.40195351839066, 46.692969873547554, 59.14139449596405, 0.3550230839755386, 0.15916470147203654, 0.023140363082347903, 0.02718332387303235, 0.04748172148538288, 0.07549759960966185, 0.036169565210002474, 0.07162123612943105, 0.048987108675646596, 0.020994769620301668, 0.11259046703344211, 0.12842423224356025, 0.1488915816298686, 0.16345956944860518, 0.29069146723486483, 0.09712632847367786, 0.1900139547069557, 0.16044358519138768, 0.10197725059697405, 0.11380354451830499, 0.2335323960869573, 59.00592416524887, 80.43947204947472, 65.08831858634949, 46.05251803994179, 65.47579139471054, 44.93551477789879, 46.05108551681042, 94.02696534991264, 32.52734899520874, 10.069791208952665, 60.346040055155754, 69.85767066478729, 74.12337496876717, 72.46806979179382, 73.75151932239532, 69.35238897800446, 72.8144820034504, 70.09823575615883, 71.36163756251335, 71.15877404808998, 71.68386787176132, 69.85359728336334, 69.05674204230309, 68.23690563440323, 68.0577452480793, 66.60752266645432, 59.35035288333893, 51.4826774597168, 53.160652220249176, 51.20898574590683, 49.948901161551476, 52.8022288531065, 54.702385291457176, 51.41380235552788, 48.28391790390015, 51.948403269052505, 49.992583617568016, 48.02793703973293, 49.953343123197556, 52.52200148999691, 45.75826942920685, 58.07567708194256, 65.4153898358345, 63.21098372340202, 60.24679698050022, 60.66541291773319, 62.441859394311905, 55.33187851309776, 59.22807164490223, 57.205421179533005, 60.40673799812794, 59.51941721141338, 58.629580959677696, 57.3351576179266, 60.78653521835804, 61.462127566337585, 60.529756397008896, 54.029540196061134, 60.140554681420326, 58.582889065146446, 60.93951880931854, 49.19192478060722, 43.62049654126167, 48.13213124871254, 49.93267223238945, 50.018532425165176, 45.5808075517416, 42.651742324233055, 47.7326662838459, 45.21774083375931, 42.81245470046997, 45.36612667143345, 43.729360699653625, 45.14694683253765, 49.99769814312458, 46.800416707992554, 50.3288047760725, 49.18064318597317, 51.32375478744507, 47.81503826379776, 45.83748757839203, 43.24730336666107, 44.81225699186325, 44.26098257303238, 47.510572001338005, 44.322121292352676, 44.00278262794018, 45.546176210045815, 44.22255143523216, 50.38969650864601, 45.52218049764633, 49.15955051779747, 40.31646743416786, 46.574940606951714, 50.01440964639187, 57.95668266713619, 53.87020714581013, 54.778343215584755, 52.19006650149822, 50.23424305021763, 52.55395017564297, 55.77803157269955, 56.16383247077465, 57.95904614031315, 57.43074148893356, 60.11790789663792, 52.99010597169399, 54.60968166589737, 55.54421491920948, 57.419167309999466, 58.03281158208847, 52.54901044070721, 53.43729257583618, 50.009097531437874, 52.04294599592686, 51.00874789059162, 48.8714499771595, 52.99955986440182, 54.68953438103199, 57.13683865964413, 53.22314366698265, 52.91128300130367, 51.19585745036602, 54.013900235295296, 51.84119202196598, 52.546346783638, 54.94063250720501, 51.185605600476265, 56.83450028300285, 62.21831738948822, 66.52353957295418, 64.1832223534584, 61.63389354944229, 63.96530404686928, 58.943003341555595, 60.147971883416176, 60.54635390639305, 67.05499425530434, 68.25880765914917, 68.46512898802757, 72.93311923742294, 72.82365471124649, 78.08492839336395, 74.65179741382599, 85.08994370698929, 36.2243378162384, 0.9972523315809667, 62.92125307023525, 61.74398124217987, 55.55861234664917, 44.49037626385689, 91.49485722184181, 91.76341161131859, 56.34135514497757, 72.56711527705193, 0.7599805353675038, 0.24617525283247232, 0.08323256697622128, 0.08893720383639447, 0.14861208881484345, 0.15578827093122527, 0.0925370876211673, 0.14943536807550117, 0.17087387706851587, 0.1306826321524568], [0.015021809267636854, 0.04178493283689022, 0.05062039017502684, 0.027568537479965016, 0.038163051794981584, 0.0197759571892675, 0.04812129322090186, 0.08798369250143878, 0.0663487370184157, 0.04878075822489336, 0.3451946738641709, 9.06014358624816, 66.24723359942436, 47.63283044099808, 40.18929585814476, 45.74889533221722, 37.69868150353432, 29.053113721311092, 72.45944425463676, 39.147722348570824, 5.488982638344169, 44.98694881796837, 55.38398131728172, 68.2736724615097, 65.63501805067062, 67.4657978117466, 68.17388981580734, 69.12914335727692, 68.69612619280815, 71.10671684145927, 70.01024007797241, 66.35498821735382, 67.84583821892738, 64.04931753873825, 60.96701793372631, 59.973192662000656, 58.111296370625496, 50.7680232077837, 48.25576141476631, 46.32309012115002, 46.10368989408016, 46.82423382997513, 46.83034390211105, 48.965745717287064, 46.70615516602993, 44.676197692751884, 42.444307655096054, 39.95741710066795, 42.073534950613976, 43.316045477986336, 43.83292034268379, 46.15588389337063, 56.24639444053173, 60.01640774309635, 61.604148745536804, 57.606740444898605, 57.595113068819046, 57.06562668085098, 52.92404271662235, 51.83055639266968, 51.48426577448845, 53.700512051582336, 53.122148886322975, 54.92548272013664, 50.96749730408192, 51.2116190046072, 54.10511814057827, 53.78370858728886, 50.57124316692352, 50.30512824654579, 53.00035782158375, 55.00620938837528, 45.07421873509884, 36.245871260762215, 42.14696601033211, 41.40918239951134, 43.33192102611065, 41.899998262524605, 40.703974440693855, 40.078303813934326, 39.48335833847523, 37.945216074585915, 36.94924771785736, 37.41578668355942, 42.55283363163471, 45.43955773115158, 43.20637956261635, 39.950258284807205, 42.446769922971725, 44.752987772226334, 43.96874785423279, 46.61913223564625, 44.262453094124794, 42.35200300812721, 41.08237713575363, 42.673488557338715, 42.66934297978878, 46.79584555327892, 45.33230468630791, 42.31730706989765, 40.81783153116703, 49.08572427928448, 48.74515235424042, 32.127621844410896, 30.65178293734789, 36.111328080296516, 52.826931327581406, 49.62184891104698, 48.308380991220474, 45.379201769828796, 47.85676762461662, 49.25616033375263, 52.10417591035366, 51.337677240371704, 51.37543961405754, 49.53858017921448, 52.37383224070072, 51.950485557317734, 49.708795845508575, 49.891060665249825, 49.74691540002823, 49.2695964127779, 47.30980597436428, 45.73520086705685, 44.392660707235336, 42.3278971016407, 44.61168855428696, 45.37814922630787, 47.410705760121346, 49.63019706308842, 48.57709877192974, 45.29950864613056, 45.616046860814095, 45.78142538666725, 43.93830768764019, 44.441305696964264, 44.42166455090046, 46.84732899069786, 45.46883895993233, 48.152862936258316, 50.12934967875481, 53.20117324590683, 52.180027440190315, 53.44101257622242, 52.150229439139366, 53.30688737332821, 48.573629558086395, 52.48454309999943, 55.93691244721413, 58.735773861408234, 57.39962115883827, 65.16351655125618, 62.16700494289398, 73.26012209057808, 66.36788472533226, 85.18602535128593, 21.389265060424805, 1.494992373045534, 58.12145322561264, 47.176706716418266, 35.52389480173588, 29.59961749613285, 80.98885416984558, 53.49685437977314, 48.091078251600266, 51.113162487745285, 0.16785202984465286, 0.09329236389021389, 0.05673371291777585, 0.05104758522065822, 0.029293581828824244, 0.06429679517168552, 0.010815196565090446, 0.08633766832645051, 0.06663794454652816, 0.03663668408989906, 0.036132520908722654, 0.06075699937355239, 0.06712451140629128, 0.03951033555495087, 0.0625063713232521, 0.06125844629423227, 0.039520002028439194, 0.013816356422466924, 0.22545947693288326, 0.07456124672899023, 0.34051053458824754, 7.909898282960057, 75.56863501667976, 44.778457805514336, 45.533245503902435, 56.57918058335781, 38.037159740924835, 33.97966906428337, 80.11551663279533, 45.443513318896294, 8.007778655737638, 47.80499920248985, 62.10615500807762, 74.35036718845367, 69.4925406575203, 71.368028819561, 71.76418796181679, 71.26462876796722, 71.2838177382946, 73.71143147349358, 72.30387300252914, 67.81773492693901, 68.9679180085659, 66.21703281998634, 65.55219769477844, 63.09265427291393, 61.053801476955414, 54.367866441607475, 50.29062822461128, 49.340037032961845, 50.11465586721897, 47.78009533882141, 48.88824887573719, 50.21836370229721, 49.39429052174091, 48.04815575480461, 45.978657603263855, 44.23117317259312, 45.338904932141304, 47.316197231411934, 45.541092082858086, 47.857079207897186, 56.83881685137749, 62.03966997563839, 63.186657428741455, 59.50572654604912, 57.57224589586258, 59.668266624212265, 55.938120782375336, 54.14074122905731, 55.60842007398605, 55.63181921839714, 56.5610783547163, 56.74186885356903, 55.44494904577732, 55.28159961104393, 57.53071032464504, 55.550085604190826, 53.28809358179569, 53.87051112949848, 54.46243956685066, 58.472687378525734, 48.54956924915314, 41.17488697171211, 44.6996196359396, 46.34815737605095, 45.81129178404808, 45.05877636373043, 43.136102333664894, 41.32818214595318, 40.595121681690216, 41.86884753406048, 41.21206037700176, 40.130816996097565, 43.55092607438564, 47.55741208791733, 44.46214757859707, 42.1417298913002, 43.079960346221924, 46.89266435801983, 44.88178186118603, 48.05433802306652, 47.80321329832077, 44.78087827563286, 42.97646909952164, 44.03211325407028, 43.850965574383736, 49.40656766295433, 46.38003386557102, 43.481374606490135, 42.53132298588753, 51.20404601097107, 45.22747591137886, 38.57627101242542, 49.34841938316822, 43.26281413435936, 53.8292795419693, 54.037147387862206, 52.9673869907856, 49.054740741848946, 49.21565070748329, 49.72450040280819, 53.84981743991375, 52.897546738386154, 55.928248912096024, 55.028943568468094, 56.12727843225002, 55.53935497999191, 54.21793408691883, 53.72841015458107, 52.79079146683216, 51.6159401088953, 51.06287218630314, 46.617783308029175, 48.78832183778286, 46.04437127709389, 46.95512540638447, 47.16543652117252, 49.01546984910965, 52.451568469405174, 50.883571207523346, 49.07463267445564, 47.71677553653717, 47.86115258932114, 48.72957319021225, 47.95572571456432, 49.18084837496281, 50.28339721262455, 48.44464547932148, 53.27497288584709, 53.506764248013496, 55.97692809998989, 55.8928120136261, 56.624709740281105, 55.498187988996506, 58.48004758358002, 52.9007613658905, 55.60308516025543, 59.39705617725849, 62.25934758782387, 59.37660567462444, 69.06795904040337, 66.6555292904377, 75.72123482823372, 68.80525633692741, 88.3615605533123, 20.587196499109268, 2.4038274865597486, 64.4031697511673, 53.82725425064564, 43.69298905134201, 31.459366902709007, 85.27274429798126, 57.92826399207115, 57.954360991716385, 53.13952535390854, 0.04232133120240178, 0.0856293180549983, 0.06930542367626913, 0.0780727481469512, 0.05407448647019919, 0.04731234483188018, 0.1124609103135299, 0.05844589584739879, 0.04354291369963903, 0.08252996834926307, 0.18628441030159593, 0.19152611028403044, 0.11765581788495183, 0.17393749236362055, 0.21023149718530476, 0.1987582354922779, 0.2658583747688681, 0.12779098731698468, 0.3961476538097486, 0.2527367288712412, 0.9022706688847393, 16.9272917881608, 87.69019737839699, 62.06350989639759, 54.447734355926514, 60.097035616636276, 52.40582272410393, 40.05638659000397, 87.52962559461594, 47.96541519463062, 11.423086691647768, 54.339721351861954, 70.58225378394127, 77.9015426337719, 73.04724991321564, 73.71536046266556, 73.37605386972427, 72.21846118569374, 73.84613424539566, 73.76171037554741, 75.54173246026039, 68.4016951918602, 70.99263176321983, 66.97216629981995, 67.97465890645981, 63.58944721519947, 62.95507125556469, 54.61709886789322, 53.01299974322319, 51.82638421654701, 52.07933284342289, 51.870496049523354, 51.57620944082737, 53.358222618699074, 51.78943879902363, 51.89537711441517, 51.076657846570015, 44.16013218462467, 46.52135968208313, 48.90687167644501, 49.064095839858055, 50.83369508385658, 59.439085721969604, 63.47784720361233, 66.3201592862606, 64.44585666060448, 60.50730720162392, 60.89838221669197, 59.57393668591976, 58.18179398775101, 56.815850883722305, 58.97007308900356, 58.71968552470207, 58.86805236339569, 59.96884569525719, 57.77692571282387, 63.62548828125, 60.131780952215195, 56.973892003297806, 57.64788843691349, 58.613861203193665, 62.275895699858665, 50.145685002207756, 45.10554425418377, 46.8863794952631, 48.610700368881226, 49.79540079832077, 48.01074296236038, 44.983832985162735, 43.67991015315056, 44.41366218030453, 44.26440618932247, 43.52337755262852, 41.57467491924763, 47.98985928297043, 53.12482014298439, 47.99777805805206, 43.8680000603199, 46.55706636607647, 50.778411850333214, 48.08041222393513, 50.90176083147526, 49.01255540549755, 46.99877366423607, 45.08755221962929, 44.91050831973553, 48.14377762377262, 52.38927461206913, 48.85125406086445, 45.56670270860195, 46.10489822924137, 50.965103432536125, 47.29022182524204, 42.42218904197216, 40.83472542464733, 44.31983761489391, 58.36050979793072, 56.35646693408489, 55.62434121966362, 51.82726576924324, 50.9910674393177, 52.31555476784706, 57.5666905939579, 54.97310936450958, 57.49530002474785, 55.343163907527924, 55.78221894800663, 58.75093884766102, 56.83650657534599, 56.63254112005234, 53.29574637115002, 53.460775315761566, 53.96959841251373, 50.31772077083588, 51.345345228910446, 49.75218951702118, 48.61461415886879, 49.928336665034294, 51.368968561291695, 55.68418800830841, 54.67275068163872, 51.666545793414116, 51.97311334311962, 52.12124079465866, 50.980599001049995, 49.49690781533718, 50.946427434682846, 52.613941356539726, 49.7077888995409, 55.56193716824055, 55.9657035022974, 58.202784061431885, 61.16829693317413, 60.14390230178833, 60.79999029636383, 61.31060689687729, 56.42539523541927, 57.601356133818626, 63.06452438235283, 66.59287825226784, 63.890250474214554, 74.78920564055443, 69.58432853221893, 80.53116872906685, 72.198276668787, 91.69547885656357, 24.616452790796757, 2.352532376535237, 68.92285242676735, 63.75251546502113, 47.76186391711235, 44.29852455854416, 93.62669482827187, 64.01585653424263, 62.090568244457245, 67.05951601266861, 0.628964159404859, 0.2851600031135604, 0.1584076217841357, 0.23266176780452952, 0.13267172151245177, 0.20576724142301828, 0.17919596488354728, 0.12100015053874813, 0.21750231797341257, 0.15679689415264875], [0.049632502559688874, 0.09985861193854362, 0.02086024051095592, 0.018265078106196597, 0.11343137972289696, 0.04724516562419012, 0.010784736041387077, 0.06748876490746625, 0.11532505857758224, 0.01135338628955651, 0.2986438467632979, 1.7923406674526632, 56.9500482827425, 41.144971176981926, 37.19094514846802, 37.94219143688679, 41.78403228521347, 30.22524632513523, 63.86107563972473, 53.211596086621284, 5.961122503504157, 35.51909185945988, 55.602032616734505, 70.55875584483147, 71.15323394536972, 69.60351750254631, 68.81323590874672, 69.7756178677082, 69.06926617026329, 69.12135377526283, 69.56270009279251, 66.592847853899, 65.55484995245934, 63.149278834462166, 62.789491340518, 59.24117334187031, 51.024615839123726, 47.49782748520374, 47.21816249191761, 46.19628332555294, 47.37579703330994, 46.872388646006584, 47.36364148557186, 47.46497064828873, 48.01803857088089, 47.33154460787773, 42.981465831398964, 38.37415225803852, 43.387466445565224, 43.800097703933716, 46.42279677093029, 45.23408755660057, 57.76047259569168, 58.48819054663181, 61.754043102264404, 62.55914390087128, 54.49245795607567, 58.0641371011734, 49.616475999355316, 52.5424025952816, 50.32904416322708, 52.59699426591396, 54.339447766542435, 55.261802673339844, 52.30933830142021, 50.59013195335865, 49.621997103095055, 52.726745903491974, 50.67829102277756, 50.25752820074558, 50.769125148653984, 56.60153478384018, 48.49490538239479, 39.30276542901993, 43.030156418681145, 42.49535031616688, 42.15637810528278, 38.78498621284962, 41.26164771616459, 41.830393597483635, 38.122491762042046, 40.44140852987766, 41.62245735526085, 40.949988439679146, 39.966498613357544, 39.438190162181854, 36.092374697327614, 40.96199579536915, 38.68385083973408, 38.03903304040432, 42.17794194817543, 38.657187670469284, 39.928941428661346, 40.94090312719345, 41.58753722906113, 43.74967820942402, 38.89590986073017, 42.79597118496895, 44.1449785977602, 43.59279602766037, 38.09576399624348, 50.625397861003876, 45.341245606541634, 29.98212207108736, 26.73145540058613, 39.19273093342781, 54.93724308907986, 49.54594798386097, 48.38127247989178, 46.34856015443802, 47.38507233560085, 54.07159633934498, 53.0836683511734, 48.86219747364521, 50.01781806349754, 51.795343682169914, 52.34673589468002, 51.61468617618084, 50.85788458585739, 49.97647248208523, 51.94358512759209, 51.66452430188656, 48.03261458873749, 45.01176908612251, 43.53215888142586, 43.2524710893631, 43.7193900346756, 45.43243691325188, 43.698943331837654, 45.45263662934303, 44.73165191709995, 43.88780079782009, 43.56198728084564, 46.66884496808052, 45.04769615828991, 43.800842463970184, 44.76437196135521, 45.89687839150429, 46.43934488296509, 49.46164570748806, 49.9898287653923, 52.074054926633835, 51.62285193800926, 49.21492874622345, 47.85483732819557, 49.1123266518116, 48.342442363500595, 50.57127736508846, 53.26325811445713, 55.86745597422123, 57.53989063203335, 65.10298579931259, 63.368941247463226, 71.76509231328964, 68.4185890853405, 82.14927390217781, 12.998819388449192, 4.494229266420007, 66.44585654139519, 45.463135465979576, 32.19466544687748, 23.640022985637188, 68.3153486251831, 40.879285633563995, 47.92573392391205, 38.44743512570858, 0.08235465822508559, 0.10491323133464903, 0.011475330429675523, 0.13250991847598925, 0.10922810761258006, 0.07081217641825788, 0.09473256082856096, 0.003303225325907988, 0.02910073846578598, 0.06089093476475682, 0.0611440405191388, 0.08679176622536033, 0.02070270111289574, 0.010112394775205757, 0.014119640636636177, 0.046035064151510596, 0.06259917689021677, 0.04331181633460801, 0.05573688613367267, 0.04432432840985712, 0.129603341629263, 1.4712026808410883, 67.6355043053627, 44.29988868534565, 37.36179158091545, 53.19483518600464, 45.77349901199341, 34.12783831357956, 69.91072341799736, 59.82954517006874, 9.378545600920916, 37.245027646422386, 62.922696992754936, 73.8512259721756, 75.33970490098, 72.34395325183868, 71.46625354886055, 72.66077265143394, 72.37966373562813, 71.81771948933601, 72.47481063008308, 71.28517046570778, 68.19881647825241, 66.88362345099449, 63.39596539735794, 62.30016879737377, 53.08279439806938, 50.385839715600014, 51.359545066952705, 49.776265025138855, 50.15047274529934, 49.44422364234924, 51.73397697508335, 51.35737158358097, 49.98480163514614, 49.17769454419613, 46.72214090824127, 42.0978232473135, 45.163312554359436, 46.542425751686096, 48.707838356494904, 47.31977663934231, 58.8432776927948, 61.150958463549614, 62.02511675655842, 66.3665471971035, 57.48602472245693, 58.91902282834053, 52.8394478559494, 53.82751643657684, 53.52618120610714, 55.99308483302593, 57.51044601202011, 58.3632380515337, 56.75769500434399, 55.26712238788605, 53.30724075436592, 55.56433863937855, 53.70003327727318, 53.56623865664005, 54.20104019343853, 60.09323962032795, 51.25084809958935, 45.14155112206936, 43.90978641808033, 44.09932404756546, 44.9458160251379, 41.78896062076092, 43.665261939167976, 44.11144159734249, 41.361871138215065, 42.57598578929901, 41.768506318330765, 42.42847390472889, 38.86901870369911, 41.70325241982937, 38.533910885453224, 40.9887957572937, 40.5425439029932, 40.29758244752884, 43.44685345888138, 41.28868706524372, 41.06263339519501, 42.750597819685936, 43.386155515909195, 44.103762209415436, 37.792019695043564, 43.7379140406847, 45.486553609371185, 46.02665662765503, 42.05989748239517, 48.69819447398186, 43.010914251208305, 41.366320699453354, 40.97635142505169, 41.04606248438358, 56.771397069096565, 52.11016058921814, 51.247519478201866, 47.314209938049316, 50.80868482589722, 55.387268140912056, 56.0815516859293, 53.26722890138626, 52.30916351079941, 54.1984411329031, 56.654507741332054, 54.50943164527416, 54.17002245783806, 54.32710222899914, 55.50574578344822, 54.9684964120388, 52.49366261065006, 47.07034282386303, 47.39947356283665, 45.93288525938988, 46.79613433778286, 48.39065797626972, 46.70196779072285, 47.89838299155235, 46.02216526865959, 48.189511969685555, 47.59419411420822, 48.786190152168274, 49.184268191456795, 45.992317870259285, 47.529240399599075, 49.442148953676224, 49.722353518009186, 51.72851286828518, 53.05880628526211, 56.86673395335674, 54.95490834116936, 53.724762350320816, 52.6392176002264, 54.70546692609787, 51.93856559693813, 54.63501110672951, 55.56363567709923, 60.365882590413094, 61.471406668424606, 70.39082765579224, 67.65430569648743, 75.73856949806213, 72.9120683670044, 84.33905839920044, 11.066026501357555, 6.2480726558715105, 73.98521438241005, 53.15344400703907, 38.87778103351593, 29.648815356194973, 70.00693425536156, 45.88338531553745, 56.48035168647766, 43.62456992268562, 0.03746408227016218, 0.08217942973715253, 0.048394329351140186, 0.0973009632434696, 0.1074403258098755, 0.0130473661920405, 0.12558444868773222, 0.07342379409237765, 0.024563987863075454, 0.05972549202851951, 0.13855368713848293, 0.19831912155495957, 0.12976162688573822, 0.22866812272695825, 0.0709801318589598, 0.1415021062712185, 0.11849165428429842, 0.13810341130010784, 0.22089840058470145, 0.14098889630986378, 0.6124964368063956, 4.157982459291816, 81.70488014817238, 52.3437986522913, 47.317090183496475, 54.57905150949955, 54.421481564641, 40.51420122385025, 75.48134610056877, 61.08021005988121, 10.814377404749393, 42.37907275557518, 68.38695958256721, 77.14136302471161, 78.37864503264427, 74.43199440836906, 74.51904013752937, 74.37258079648018, 73.55114847421646, 73.15744400024414, 72.03773528337479, 71.8256838619709, 68.64675164222717, 68.65296050906181, 67.43004932999611, 64.20942574739456, 56.244855523109436, 53.760203048586845, 52.48089149594307, 51.760332360863686, 52.74599187076092, 50.34628003835678, 54.26346704363823, 54.880481734871864, 52.33557969331741, 53.538165763020515, 49.1346200555563, 42.98091486096382, 48.73263582587242, 48.07690881192684, 52.6451300829649, 49.97329585254192, 62.25063465535641, 65.52744582295418, 64.3109031021595, 67.43330955505371, 60.14065347611904, 64.14931297302246, 55.1848454028368, 56.98273032903671, 56.67932040989399, 58.423559814691544, 58.52270029485226, 63.04759629070759, 58.63985940814018, 56.44749864935875, 57.74513281881809, 57.903629913926125, 58.11862237751484, 57.857006415724754, 58.523540049791336, 62.758310213685036, 55.985276252031326, 47.889164686203, 45.74378080666065, 48.25315095484257, 46.395753622055054, 43.39947760105133, 47.62133605778217, 47.807830050587654, 44.91591162979603, 46.401954889297485, 47.01863519847393, 46.41716547310352, 44.56545643508434, 45.69958917796612, 42.40066319704056, 44.244746044278145, 45.02100259065628, 44.74374286830425, 46.45167522132397, 43.643462508916855, 45.40811441838741, 46.07916980981827, 47.81259499490261, 47.84318335354328, 41.86773419380188, 47.05259017646313, 50.07419563829899, 48.54093611240387, 44.248321652412415, 50.98344124853611, 48.918411657214165, 39.198377430438995, 34.86013501882553, 43.476024493575096, 60.42327471077442, 57.43150144815445, 54.02443706989288, 48.764709904789925, 53.386306911706924, 59.33860391378403, 59.19598236680031, 57.458688989281654, 54.788572266697884, 57.100615203380585, 60.52590720355511, 57.22826175391674, 56.293724700808525, 53.00666928291321, 58.021127209067345, 58.30006264150143, 55.53756147623062, 51.224409118294716, 48.19858208298683, 49.366886392235756, 48.121510818600655, 51.04163132607937, 49.28109459578991, 51.412290036678314, 51.778400391340256, 50.33184841275215, 49.181893318891525, 51.10379979014397, 50.665280520915985, 48.02142798900604, 49.750908985733986, 52.5616979598999, 54.3547685444355, 56.48575879633427, 56.02928549051285, 58.83336782455444, 60.58339051902294, 59.11847412586212, 57.00423717498779, 58.244004249572754, 55.36431737244129, 56.9019390642643, 59.77104350924492, 63.401912078261375, 64.11637634038925, 73.11995521187782, 72.97088161110878, 77.9660251736641, 77.21738934516907, 89.56272929906845, 16.345020532608032, 6.576758343726397, 78.20362642407417, 59.13347192108631, 44.954008385539055, 39.06121999025345, 87.81747534871101, 51.870857030153275, 64.17982533574104, 51.92882291972637, 0.15629141737008467, 0.2300293551525101, 0.21745008561993018, 0.18697419203817844, 0.22657517722109333, 0.18542236124631017, 0.2627208415651694, 0.13063650025287643, 0.07844392588594928, 0.17438992043025792], [0.01909715181682259, 0.076854119397467, 0.0419244120712392, 0.05816674070956651, 0.04248963545251172, 0.03189082410244737, 0.04255063999153208, 0.022306408027361613, 0.05489733528520446, 0.06456684044678695, 0.044981325772823766, 0.039633383639738895, 42.89195403456688, 55.65488398075104, 37.73164853453636, 34.04701665043831, 38.89741078019142, 26.23597338795662, 47.71342031657696, 70.1127053797245, 11.40384927392006, 21.759944669902325, 50.817739740014076, 68.10907289385796, 73.93819570541382, 69.95617657899857, 71.39706686139107, 71.06238082051277, 68.85528445243835, 66.72918453812599, 69.33158129453659, 65.4739598929882, 64.17825222015381, 61.01073078811169, 60.85417538881302, 53.4291648119688, 47.96751648187637, 45.11988468468189, 47.40743413567543, 46.06169454753399, 47.31995142996311, 46.13058865070343, 46.45378790795803, 46.056450828909874, 45.793964713811874, 46.389590352773666, 43.32033924758434, 40.05484767258167, 44.358230754733086, 45.33971048891544, 45.603492334485054, 45.987970903515816, 54.792980030179024, 57.56192944943905, 58.80785599350929, 64.05470564961433, 58.28191101551056, 52.842195108532906, 53.4066092222929, 50.329287350177765, 53.72595548629761, 53.59057255089283, 55.25742910802364, 55.84088020026684, 53.1195954233408, 49.74336639046669, 50.27686916291714, 50.14840565621853, 52.55431495606899, 51.08963035047054, 51.57359138131142, 54.42061901092529, 50.58947838842869, 40.92286929488182, 43.806306570768356, 39.123361855745316, 40.216612592339516, 41.90073922276497, 38.69688794016838, 39.17673759162426, 38.67730759084225, 37.94317938387394, 39.553586170077324, 35.7132538408041, 38.048608526587486, 33.96943241357803, 39.54411327838898, 38.151191622018814, 39.19232055544853, 40.589657574892044, 41.96954593062401, 49.139043018221855, 48.6368315666914, 40.17102263867855, 40.13966292142868, 44.502292424440384, 43.559202030301094, 44.54726681113243, 46.1517421156168, 45.34895159304142, 39.15974870324135, 38.357056975364685, 38.373494893312454, 27.093988247215748, 22.075548134744167, 45.46343185007572, 55.79996399581432, 50.37015415728092, 47.09119230508804, 48.842263743281364, 52.96853832900524, 51.49205535650253, 46.973979994654655, 45.329283848404884, 46.455368623137474, 48.2337149977684, 49.85346928238869, 52.70216882228851, 51.56792588531971, 52.95317955315113, 52.61828452348709, 51.004153937101364, 47.51687966287136, 42.85459063947201, 43.64417307078838, 44.713234305381775, 42.708313688635826, 43.252562284469604, 40.948058143258095, 42.102261409163475, 41.545063108205795, 44.445200487971306, 45.21960273385048, 44.074047803878784, 43.4244916588068, 44.37200501561165, 43.466118425130844, 45.331377536058426, 44.105099737644196, 47.005829885602, 47.3135943710804, 49.707097336649895, 49.03003066778183, 49.430589973926544, 47.35985308885574, 50.258972123265266, 50.18180586397648, 53.10523979365826, 51.03633061051369, 57.879740595817566, 58.97798806428909, 65.01579567790031, 65.50036087632179, 73.78731340169907, 68.53018149733543, 73.21762517094612, 4.635402616113424, 11.425739899277687, 72.83835992217064, 38.98692637681961, 31.645410619676113, 31.87951795756817, 41.3928546756506, 38.86005498468876, 60.19700825214386, 36.114284321665764, 0.02815497515257448, 0.050768396686180495, 0.0728443697153125, 0.05421927577117458, 0.03455688201938756, 0.02352911302295979, 0.04722009958641138, 0.036784449403057806, 0.05995046296447981, 0.04620143139618449, 0.05706049167201854, 0.10431584698380902, 0.04904514833469875, 0.09177207437460311, 0.03852947978884913, 0.12549594015581533, 0.033621616385062225, 0.058130598117713816, 0.07719387460383587, 0.05503497399331536, 0.11795489597716369, 0.07539919824921526, 46.04011170566082, 60.784198343753815, 37.78700776398182, 43.34142431616783, 44.19186808168888, 31.654912009835243, 53.801054656505585, 79.29352194070816, 14.397281147539616, 22.463932894170284, 56.128471568226814, 73.55120167136192, 75.50643995404243, 72.51790031790733, 74.33107942342758, 73.53618487715721, 71.93559676408768, 71.2546581029892, 71.92745000123978, 67.44407057762146, 66.2602137029171, 67.05062448978424, 64.12347435951233, 57.01368346810341, 50.751881673932076, 48.67808975279331, 49.76345211267471, 49.31754224002361, 50.59577465057373, 48.981207087635994, 50.09565308690071, 49.15890075266361, 48.43767665326595, 50.53301341831684, 46.45064167678356, 43.84343057870865, 46.65258564054966, 46.9170780479908, 47.11865723133087, 48.71655888855457, 57.95358583331108, 61.38333119452, 59.5786864310503, 63.095819503068924, 60.50854213535786, 54.8831681907177, 54.82467792928219, 51.77249550819397, 55.24203233420849, 55.654162019491196, 57.407357543706894, 56.8969651311636, 56.86195760965347, 56.49992063641548, 53.52927803993225, 52.912776321172714, 54.965179190039635, 54.47627082467079, 55.41765131056309, 57.053820714354515, 54.3798092007637, 45.62103599309921, 46.146190613508224, 40.523381531238556, 42.271637320518494, 44.54198509454727, 41.380649730563164, 41.95612125098705, 40.167629420757294, 40.673576071858406, 43.23042467236519, 38.14746782183647, 40.723980367183685, 36.5113440155983, 42.24196471273899, 41.213941276073456, 40.99012948572636, 41.64086356759071, 42.34542176127434, 51.44730515778065, 49.887511655688286, 43.8395281881094, 42.34805881977081, 43.9308562874794, 45.76712675392628, 46.62704721093178, 46.19446702301502, 47.46004991233349, 39.10168781876564, 38.868874311447144, 40.071391984820366, 39.592948257923126, 28.91974087804556, 46.959179788827896, 55.74716962873936, 52.614610120654106, 50.65952003002167, 51.68696969747543, 54.511320143938065, 53.933249562978745, 50.22728942334652, 49.583144187927246, 48.591492399573326, 50.87860107421875, 53.802753165364265, 54.56759512424469, 53.97097773849964, 54.5200976729393, 56.81641325354576, 55.017908960580826, 51.47950083017349, 47.21091628074646, 47.5362928211689, 46.68513849377632, 44.86448138952255, 45.69768168032169, 43.24388734996319, 45.464978367090225, 43.94065976142883, 47.762802466750145, 46.97543911635876, 48.93645688891411, 46.43791235983372, 46.23429648578167, 47.72115670144558, 47.98813417553902, 48.81676331162453, 50.12627184391022, 52.09130600094795, 53.17112445831299, 51.934587210416794, 54.26815219223499, 51.3436771184206, 54.0149337798357, 54.69530627131462, 57.42102541029453, 55.35088129341602, 61.91622979938984, 63.151011541485786, 69.09071981906891, 67.89410322904587, 77.07140877842903, 72.84335285425186, 75.45166969299316, 4.062270820140839, 14.970660880208015, 79.89091828465462, 46.680510342121124, 36.68949745595455, 37.8596218675375, 51.749149560928345, 39.49506551027298, 67.52665534615517, 38.803772404789925, 0.088940142741194, 0.048042514245025814, 0.06802527830586769, 0.0523119636636693, 0.04690823800046928, 0.036459752373048104, 0.07087319580023177, 0.03991054240032099, 0.032790047334856354, 0.11747137934435159, 0.17798271670471877, 0.29950399592053145, 0.1241967586975079, 0.1661458471789956, 0.16173199808690697, 0.17535745835630223, 0.12869836675236002, 0.19382077152840793, 0.18680538312764838, 0.1376909256214276, 0.11369949541403912, 0.1438689636415802, 57.14895620942116, 74.16051417589188, 48.54629762470722, 49.78343524038792, 52.83118709921837, 39.15253289043903, 59.52624924480915, 81.34408950805664, 15.487309657037258, 29.17370595037937, 60.61354950070381, 77.2712704539299, 80.89117661118507, 74.50773194432259, 76.88072741031647, 75.32303899526596, 75.56314811110497, 72.96655744314194, 72.7198138833046, 70.03078937530518, 68.6129942536354, 70.3389224410057, 66.37224689126015, 59.14645202457905, 52.215897515416145, 50.15265002846718, 53.0824676156044, 52.08519212901592, 55.311283618211746, 52.26342536509037, 52.36771456897259, 51.74939654767513, 51.392671689391136, 52.19898462295532, 47.668088749051094, 45.08236549794674, 48.842031955718994, 48.308646976947784, 50.221034958958626, 51.585716530680656, 62.32765652239323, 62.88412906229496, 63.7943360209465, 64.11465883255005, 63.300218135118484, 56.29707612097263, 58.46924476325512, 54.9121530354023, 58.771225959062576, 59.44164298474789, 59.794374257326126, 60.434605702757835, 60.8551861345768, 57.66060255467892, 58.6017132550478, 56.101622208952904, 59.47633132338524, 58.39074097573757, 60.470012202858925, 62.65780180692673, 57.28986404836178, 52.933975383639336, 48.65800403058529, 40.90629078447819, 47.25079894065857, 47.8984247893095, 44.972452595829964, 42.96828433871269, 42.96574607491493, 44.47005495429039, 46.00654810667038, 40.11588379740715, 44.25615303218365, 39.632006362080574, 44.89680625498295, 41.455015540122986, 43.613029941916466, 42.2399128228426, 43.024403527379036, 52.740706354379654, 51.37597918510437, 44.46715950965881, 45.85164561867714, 47.81848467886448, 47.075054571032524, 51.39908194541931, 49.286877885460854, 49.725096970796585, 40.38868635892868, 39.42018672823906, 47.695667669177055, 39.17670339345932, 27.23103169351816, 50.01771166920662, 61.01389221847057, 57.4824795126915, 54.05554600059986, 54.62442867457867, 59.0591137111187, 58.27399984002113, 53.192046135663986, 51.636762991547585, 50.516279116272926, 52.63895161449909, 55.975301787257195, 57.754841297864914, 54.54880513250828, 56.76429145038128, 59.40934091806412, 58.36869075894356, 54.86702285706997, 47.3847721517086, 49.2446431517601, 48.96796479821205, 46.30735896527767, 49.30707760155201, 46.111357882618904, 48.25141824781895, 46.78468555212021, 51.71926036477089, 50.06976507604122, 52.07460969686508, 49.598286375403404, 49.086906015872955, 49.471528977155685, 51.85815051198006, 50.71275137364864, 54.82824593782425, 55.32286919653416, 58.34985896945, 56.123087257146835, 57.333063930273056, 54.66946005821228, 57.47940927743912, 58.43529358506203, 60.146615356206894, 58.02247613668442, 64.63484331965446, 66.24395057559013, 73.46625342965126, 69.60221037268639, 81.20104998350143, 75.03818348050117, 83.49759355187416, 6.371102454140782, 13.32612432539463, 86.412842720747, 53.25396381318569, 43.91545191407204, 50.071904361248016, 57.863523066043854, 54.122376814484596, 79.20066252350807, 50.20899720489979, 0.22427192190662026, 0.14379552070749924, 0.1115482542081736, 0.09410210637724958, 0.11985247852862813, 0.1260619465028867, 0.14872688421746716, 0.12494119961047545, 0.14559331408236176, 0.18188792746514082], [0.047453156221308745, 0.024644098994031083, 0.07098681118804961, 0.08185464364942163, 0.041918011047528125, 0.03335269917442929, 0.028792433622584213, 0.10157923679798841, 0.02209227801358793, 0.052829693304374814, 0.08186008359189145, 0.12235940143000335, 27.813472039997578, 63.76275971531868, 33.622644022107124, 39.39272180199623, 33.76297049224377, 31.67590208351612, 46.91237390041351, 74.0549786388874, 18.485688865184784, 9.409399945288897, 47.554091066122055, 64.89078998565674, 75.0611874461174, 70.6530211865902, 70.14699473977089, 68.79729196429253, 66.26343593001366, 64.7873367369175, 70.02513527870178, 61.7813066393137, 64.09527227282524, 62.22825385630131, 59.03693810105324, 49.58028294146061, 48.46385344862938, 46.891323029994965, 46.00750185549259, 48.09557721018791, 48.345588594675064, 43.81409615278244, 45.790989473462105, 45.82954600453377, 48.584280386567116, 47.586324736475945, 46.55647359788418, 39.166383147239685, 42.751205787062645, 44.431471824645996, 45.07289260625839, 46.08066312968731, 54.20085400342941, 58.353236988186836, 57.82584808766842, 58.59555758535862, 60.12061335146427, 54.701165556907654, 51.19419313967228, 50.101428776979446, 51.04019120335579, 53.595584481954575, 54.7434800863266, 56.2414813041687, 52.70159885287285, 51.11902557313442, 51.36658988893032, 51.03567324578762, 51.45414479076862, 52.9398612678051, 52.404998168349266, 51.20178893208504, 52.28196457028389, 44.56662677228451, 48.537124916911125, 46.14434391260147, 42.72920496761799, 38.82472448050976, 38.759310990571976, 39.59080517292023, 36.90843790769577, 37.30547480285168, 36.81311622262001, 38.43469820916653, 39.25710707902908, 43.1932170689106, 45.7024010270834, 54.18639197945595, 64.48937952518463, 55.9183694422245, 61.569050028920174, 60.42179279029369, 54.584424421191216, 50.48623412847519, 44.515549913048744, 44.03991423547268, 43.450520262122154, 39.87182669341564, 43.4039081633091, 39.64433670043945, 35.315061807632446, 39.88524757325649, 40.90711914002895, 22.610219344496727, 28.08597631752491, 53.14015232026577, 52.86612242460251, 50.80367669463158, 52.5325421243906, 48.85942742228508, 47.503428384661674, 49.26265798509121, 51.824526116251945, 46.994688883423805, 48.6065623909235, 51.292117685079575, 51.79777555167675, 50.24696856737137, 52.25079484283924, 53.96437369287014, 55.93882754445076, 55.19653357565403, 49.029118716716766, 43.962322399020195, 44.0703734010458, 46.70910760760307, 40.78847050666809, 42.002034187316895, 41.28041110932827, 42.38218478858471, 42.84568391740322, 45.95672518014908, 42.613265588879585, 42.232586815953255, 41.54839172959328, 43.814571127295494, 46.642668172717094, 46.585925817489624, 42.12581254541874, 47.11671933531761, 46.94283686578274, 48.05708147585392, 48.37585397064686, 48.94103564321995, 49.35889922082424, 48.4833388030529, 50.205744579434395, 49.43567410111427, 53.26926939189434, 57.85468094050884, 64.27216038107872, 68.04715141654015, 66.36461690068245, 73.36229860782623, 73.79596173763275, 53.74141305685043, 1.952599324285984, 24.74299170076847, 68.87859240174294, 34.22184906899929, 44.73784938454628, 33.38254250586033, 43.990638479590416, 41.54603585600853, 60.236887112259865, 20.451209396123886, 0.3080287791090086, 0.0303268870266038, 0.06912827302585356, 0.11639599251793697, 0.014778264230699278, 0.04282655194401741, 0.08276502136141062, 0.15643629943951964, 0.09840247366810217, 0.019199213820684236, 0.036648814493673854, 0.0352092112734681, 0.018469094502506778, 0.09575806048815139, 0.08098872800474055, 0.07381575938779861, 0.046573963554692455, 0.09598955119145103, 0.0346186212846078, 0.056908989645307884, 0.024708253949938808, 0.14324699935968965, 31.687651053071022, 69.40194591879845, 33.79349045455456, 50.27398891746998, 41.8026664853096, 35.74093535542488, 51.24510280787945, 80.48857301473618, 22.514312490820885, 9.550678264349699, 47.48684607446194, 68.55264589190483, 78.29884171485901, 70.8064341545105, 72.11157292127609, 73.68145868182182, 67.23910957574844, 67.2253467142582, 70.10852560400963, 65.48057913780212, 69.61563885211945, 66.72242850065231, 61.45693324506283, 53.18441994488239, 50.01184098422527, 48.36163513362408, 49.309338480234146, 49.8937813192606, 51.94507084786892, 46.33394993841648, 48.043219819664955, 49.129919707775116, 51.54521070420742, 50.93771070241928, 49.70971919596195, 42.683497220277786, 46.57943956553936, 48.89318861067295, 49.088148549199104, 48.297095596790314, 55.06169021129608, 60.06583169102669, 59.70365032553673, 58.67875412106514, 58.835864290595055, 58.99148873984814, 53.47389601171017, 53.10082443058491, 55.20449794828892, 54.70768600702286, 60.1178964972496, 56.6392857581377, 55.384498089551926, 55.46410761773586, 56.08054853975773, 56.465262696146965, 55.77538311481476, 55.91182619333267, 56.863880306482315, 52.13234759867191, 56.48051127791405, 48.30785281956196, 52.52266265451908, 47.52293273806572, 44.30232435464859, 40.69848753511906, 40.66681243479252, 42.202032655477524, 39.81462076306343, 39.33417074382305, 38.10070753097534, 40.35772182047367, 39.810277596116066, 42.163582518696785, 46.985736563801765, 48.61385799944401, 61.29307083785534, 55.027229860424995, 60.48689469695091, 61.16521529853344, 53.98330047726631, 47.252938225865364, 45.55586189031601, 47.195226922631264, 43.56989465653896, 39.59068737924099, 41.37075126171112, 38.2601697742939, 36.538303568959236, 40.87404191493988, 47.316687405109406, 29.59134913980961, 32.12086580693722, 56.4756665378809, 52.776663824915886, 53.901445269584656, 53.1089673936367, 52.61133469641209, 50.24368554353714, 53.283492028713226, 55.11801838874817, 50.81166386604309, 51.58885136246681, 52.512976974248886, 55.24719625711441, 54.01292368769646, 53.630109429359436, 55.80683782696724, 59.088394939899445, 57.31921747326851, 53.45508702099323, 46.63176655769348, 46.51851363480091, 49.0788808465004, 45.3996978700161, 44.62428867816925, 44.8836437612772, 45.250221490859985, 45.12199357151985, 48.54361116886139, 49.39114049077034, 46.662734895944595, 46.33200064301491, 47.55942977964878, 50.21173305809498, 50.31716600060463, 48.748477175831795, 49.02583189308643, 49.99103710055351, 49.87106613814831, 53.178898841142654, 51.96776703000069, 52.705204859375954, 52.64336697757244, 54.659918770194054, 53.53983387351036, 60.14166422188282, 62.646702602505684, 67.33526721596718, 70.96202820539474, 69.79592397809029, 74.23885837197304, 75.31133562326431, 50.829367116093636, 2.3129594000056386, 29.826058745384216, 76.51049047708511, 42.22768507897854, 48.521370962262154, 42.713637202978134, 58.57471190392971, 46.982100158929825, 64.05560240149498, 23.98429401218891, 0.3015338588738814, 0.13271541916765273, 0.1443157365429215, 0.06247076307772659, 0.0506307357136393, 0.061006969554000534, 0.07673246655031107, 0.0629052756994497, 0.08090421964880079, 0.015072942314873217, 0.17964190657949075, 0.10950077266898006, 0.2807937405304983, 0.1643863634672016, 0.12319279616349377, 0.1608039127313532, 0.17065939638996497, 0.3024241095408797, 0.10595473169814795, 0.16155955265276134, 0.2578309492673725, 0.21872148849070072, 44.07516874372959, 79.35756370425224, 43.51393885910511, 56.19470201432705, 48.48786436021328, 43.74577581882477, 60.167187452316284, 83.91329124569893, 22.52596076577902, 13.244820088148117, 54.259047880768776, 75.3469929099083, 82.15323328971863, 74.58499699831009, 76.80826529860497, 74.29261028766632, 69.97574552893639, 71.56910642981529, 73.42190220952034, 65.86909309029579, 71.43321052193642, 69.18368563055992, 66.39015913009644, 56.65915869176388, 52.51163184642792, 51.18648335337639, 52.212629690766335, 52.98248738050461, 53.24894808232784, 49.366449415683746, 51.8116220086813, 52.71318823099136, 55.96428997814655, 53.06964710354805, 51.512524858117104, 45.11570870876312, 49.58521507680416, 50.62239222228527, 50.02792552113533, 50.83982415497303, 58.538819029927254, 62.84125216305256, 62.253256514668465, 62.149085104465485, 62.73602440953255, 62.1341785043478, 57.85498112440109, 56.65964886546135, 58.1883030384779, 55.45989364385605, 63.98076921701431, 60.82566551864147, 58.510856330394745, 58.18095423281193, 59.06262472271919, 60.5234145373106, 58.92872370779514, 60.43587863445282, 58.89422155916691, 54.89813558757305, 59.34325486421585, 54.02362011373043, 54.43168021738529, 44.953210428357124, 41.784328669309616, 43.26180338859558, 45.9673798084259, 44.882199838757515, 43.637888208031654, 41.380547136068344, 43.25268007814884, 44.23718065023422, 42.68572390079498, 42.484707087278366, 49.64905545115471, 50.773327723145485, 58.290354162454605, 50.49272038042545, 55.280334278941154, 60.26122860610485, 59.99314159154892, 49.197833463549614, 47.221939489245415, 47.58010447025299, 47.190366983413696, 43.03836777806282, 41.300960406661034, 38.84710907936096, 36.018749848008156, 41.14848218858242, 46.16620033979416, 30.59234082698822, 29.679964184761047, 58.992636278271675, 55.36577649414539, 57.01159358024597, 55.797539725899696, 55.1411097496748, 54.80949394404888, 55.630819872021675, 57.89232172071934, 54.15204182267189, 52.986283376812935, 56.30829691886902, 56.93245142698288, 56.28492817282677, 55.388434678316116, 59.14421394467354, 62.128581404685974, 60.698900520801544, 53.95166717469692, 48.19404512643814, 48.417784720659256, 52.557772770524025, 46.18139952421188, 47.952047511935234, 48.27925555408001, 48.75978156924248, 47.36074984073639, 52.84231290221214, 52.476719319820404, 48.422534465789795, 48.83925810456276, 50.24142846465111, 53.502493277192116, 54.563662335276604, 50.654158517718315, 53.19318227469921, 54.607447385787964, 55.34195937216282, 55.22804528474808, 54.61226932704449, 54.89283487200737, 55.86558647453785, 57.867630645632744, 56.572667732834816, 62.260700315237045, 65.36775559186935, 69.15079459547997, 73.4718619287014, 70.61564639210701, 78.2080189883709, 80.36367371678352, 60.65020993351936, 2.812489620409906, 29.259657338261604, 84.38261166214943, 49.6299234777689, 58.74093018472195, 57.4127646535635, 52.290141731500626, 58.36377002298832, 80.35871878266335, 33.27656999230385, 0.3590242099016905, 0.18141323496820405, 0.19562843546736985, 0.18465624219970778, 0.10667363530956209, 0.11610067711444572, 0.2529075712664053, 0.22082210780354217, 0.17545552575029433, 0.13015049742534757], [0.03890702886565123, 0.00696319872076856, 0.03005852642672835, 0.02486829809640767, 0.2195878716884181, 0.042140547739109024, 0.04909492046863306, 0.04142599311308004, 0.04743310339108575, 0.15163865609792992, 0.06836881104391068, 0.2980262314667925, 18.471101447939873, 62.52504073083401, 43.97242605686188, 38.261210918426514, 30.15454161912203, 30.991064831614494, 31.968319192528725, 69.71311882138252, 29.48632087558508, 3.0353322252631187, 31.645585410296917, 64.65902522206306, 71.50612860918045, 75.02555295825005, 64.7181348502636, 68.69677975773811, 64.55334529280663, 64.34051871299744, 63.56394678354263, 66.18248507380486, 63.75852674245834, 60.09054936468601, 50.459080785512924, 47.573188841342926, 45.46863377094269, 46.43743358552456, 43.96346613764763, 45.53103782236576, 45.0290809571743, 46.35301351547241, 45.134567096829414, 46.64732292294502, 47.00982727110386, 49.88757625222206, 46.55738174915314, 40.83886720240116, 41.1552420258522, 48.45180809497833, 47.100790590047836, 45.96002720296383, 51.80979810655117, 57.30462625622749, 56.75486035645008, 57.96173259615898, 53.34868513047695, 55.8094634860754, 49.31121937930584, 50.3590739518404, 51.005259677767754, 54.92948390543461, 53.094930946826935, 51.711668372154236, 53.386401906609535, 52.91181497275829, 55.27708165347576, 55.72188958525658, 55.54036572575569, 51.846469938755035, 52.857937663793564, 53.95692229270935, 53.21602284908295, 44.0689180791378, 49.540670067071915, 52.915683165192604, 48.34308072924614, 54.71194937825203, 44.23781521618366, 41.4549395442009, 37.89700426161289, 38.468516394495964, 38.09323713183403, 38.74563552439213, 39.44344148039818, 41.984688118100166, 28.394918739795685, 42.322258204221725, 80.33348053693771, 75.70537447929382, 59.02184151113033, 53.12681883573532, 47.67132617533207, 44.77442242205143, 44.00896109640598, 44.270960837602615, 38.606388196349144, 38.7737388163805, 37.78160445392132, 38.78006927669048, 38.992101699113846, 51.54486492276192, 44.344175308942795, 24.642040617763996, 44.87757168710232, 52.83964544534683, 50.21204464137554, 45.28601557016373, 50.65356954932213, 46.410409435629845, 46.67424067854881, 51.15074247121811, 48.02304670214653, 49.18267987668514, 51.54800355434418, 53.68638060986996, 52.868451699614525, 53.663475438952446, 55.049815848469734, 55.078397914767265, 56.1568408459425, 56.32598876953125, 54.999814331531525, 45.06911940872669, 45.76773092150688, 46.302704215049744, 42.84722663462162, 44.26433399319649, 41.06940843164921, 40.521724820137024, 41.87645472586155, 43.81324499845505, 45.47780267894268, 43.72167371213436, 43.579671531915665, 43.98027263581753, 46.98543258011341, 47.56355635821819, 47.87931941449642, 45.52580930292606, 43.96332174539566, 44.54171150922775, 44.088411033153534, 45.36073096096516, 47.58135840296745, 51.048641949892044, 52.01959624886513, 54.36752445995808, 58.196233212947845, 60.70091061294079, 66.33192345499992, 63.764393627643585, 68.01772579550743, 69.14546728134155, 63.72085556387901, 30.991659499704838, 0.7288618676830083, 36.5814046561718, 66.3470770418644, 29.928505048155785, 39.80121128261089, 28.375283293426037, 30.080270804464817, 28.94012488424778, 56.231529638171196, 17.789708711206913, 0.5754128016997129, 0.04502100469835568, 0.0637368818570394, 0.13101915159495547, 0.03164699148328509, 0.02669110741408076, 0.01754903918481432, 0.11653016539639793, 0.0975079853378702, 0.030625378822151106, 0.05342750810086727, 0.03682237314933445, 0.006213726974237943, 0.022202945219760295, 0.17715284717269242, 0.06806474571931176, 0.055394718947354704, 0.12236573937116191, 0.11366096310666762, 0.14141981693683192, 0.11831545358290896, 0.3880253521492705, 21.714134328067303, 71.74113839864731, 37.462288588285446, 43.90946723520756, 42.95766390860081, 35.84810100495815, 37.4662821739912, 74.67061400413513, 34.51781898736954, 4.181503197178245, 33.22535254061222, 69.82944577932358, 74.69663500785828, 80.39119184017181, 67.10519716143608, 70.30827328562737, 68.18699911236763, 65.77218309044838, 65.98369494080544, 69.4681079685688, 64.90772187709808, 65.65787002444267, 54.979740008711815, 52.35545262694359, 49.4255780428648, 48.01982447504997, 46.91368483006954, 47.999024391174316, 48.757019117474556, 49.28835600614548, 47.83669330179691, 48.66756811738014, 48.31274315714836, 51.67368181049824, 50.05941443145275, 45.78543417155743, 44.14065442979336, 53.447586223483086, 49.72542755305767, 49.02480974793434, 53.208252266049385, 58.330768793821335, 58.02147679030895, 59.36595104634762, 55.59923976659775, 58.379569575190544, 53.09889033436775, 51.90770365297794, 52.249905690550804, 58.56743909418583, 56.56884893774986, 54.46916900575161, 54.312761798501015, 56.178028509020805, 59.6144463121891, 57.4443219602108, 59.21497754752636, 56.72639228403568, 58.099513202905655, 57.064437344670296, 55.06914161145687, 48.19493427872658, 51.940332502126694, 54.493639692664146, 49.26261618733406, 53.90939064323902, 45.23935787379742, 43.64888481795788, 39.834664687514305, 39.517339915037155, 38.51714238524437, 40.847333148121834, 40.061219930648804, 45.89241363108158, 27.367060594260693, 37.34104849398136, 73.57514798641205, 75.47079786658287, 60.523289144039154, 55.6673701107502, 49.63377647101879, 43.66170912981033, 44.79701600968838, 44.05422046780586, 38.70083212852478, 36.80556982755661, 37.18616120517254, 38.66572581231594, 38.36177632212639, 51.98051914572716, 47.14018687605858, 28.299006186425686, 45.433842837810516, 51.787428706884384, 52.03283093869686, 48.995999693870544, 51.45488575100899, 46.20751552283764, 52.1471706032753, 54.416222646832466, 53.71538445353508, 50.63825637102127, 53.23163241147995, 56.10481783747673, 55.37546597421169, 56.05975225567818, 56.72305226325989, 57.568358704447746, 59.9195471405983, 59.81838896870613, 58.59283693134785, 46.4443302154541, 47.635452300310135, 51.68760046362877, 46.3960500061512, 44.24244336783886, 44.97293896973133, 44.75516125559807, 43.79912495613098, 47.82794617116451, 51.02191038429737, 47.9113744944334, 47.187528535723686, 47.27695293724537, 52.01951265335083, 52.593684643507004, 56.40937529504299, 49.15265008807182, 49.85180117189884, 48.21848161518574, 48.368166983127594, 48.08782942593098, 48.97249415516853, 54.6309757232666, 57.65137664973736, 58.425782695412636, 65.47981917858124, 65.79361394047737, 67.2765451669693, 70.12507751584053, 73.53542491793633, 71.87606915831566, 64.40110266208649, 28.251689225435257, 1.0370850004255772, 42.894678488373756, 74.67576652765274, 33.60782481729984, 42.48609021306038, 40.40341816842556, 37.971636056900024, 35.04503309726715, 67.7849654853344, 26.17410320788622, 0.4824014817131683, 0.061657198530156165, 0.13205559051129967, 0.07561720412923023, 0.025081520834646653, 0.028444731869967654, 0.05189875439100433, 0.06016612736857496, 0.07589784727315418, 0.06481270655058324, 0.1101498921343591, 0.10174572278629057, 0.15283441927749664, 0.14878785907058045, 0.312162185437046, 0.18974939390318468, 0.17559543543029577, 0.22724999726051465, 0.19808301469311118, 0.3402177424868569, 0.2857649722136557, 0.7406257989350706, 30.529083721339703, 81.02863043546677, 52.990132570266724, 51.91740073263645, 44.37966160476208, 46.49718537926674, 44.93402145802975, 80.91405898332596, 35.23143209517002, 6.767164701595902, 41.41902007162571, 74.98011499643326, 77.34747156500816, 82.58375018835068, 70.27193203568459, 74.41164270043373, 72.58567348122597, 67.30014190077782, 69.61132228374481, 73.38600933551788, 68.08426782488823, 68.13351318240166, 57.641007006168365, 54.8602744191885, 52.28130720555782, 53.73731687664986, 50.43878987431526, 50.95018923282623, 51.4380906522274, 52.62962691485882, 50.77525041997433, 51.06268219649792, 50.80162100493908, 54.52780365943909, 51.060611307621, 45.412943959236145, 47.02786110341549, 55.23545488715172, 53.434723913669586, 52.85009868443012, 57.52536021173, 62.383300736546516, 58.020355850458145, 61.39871656894684, 56.74294039607048, 59.75641429424286, 55.44744931161404, 55.491002574563026, 54.35606427490711, 59.2948454618454, 59.96367797255516, 56.22794643044472, 56.78537271916866, 56.75061218440533, 62.784703597426414, 62.843391448259354, 63.27444411814213, 58.17232109606266, 59.89506505429745, 61.94735012948513, 58.574381321668625, 52.559984251856804, 56.27270422875881, 59.68746319413185, 48.94675433635712, 52.358572259545326, 42.332529053092, 44.24159221351147, 41.97970278561115, 41.414813697338104, 40.7648965716362, 41.02439604699612, 41.873536482453346, 48.99055078625679, 30.635402016341686, 40.116316974163055, 73.68758395314217, 74.31134328246117, 62.21558913588524, 58.35249222815037, 50.88715061545372, 44.51592229306698, 45.058187395334244, 44.92791138589382, 38.62626492977142, 38.40355888009071, 39.00729328393936, 38.93734283745289, 40.193065255880356, 52.87045419216156, 51.18391469120979, 29.87190518528223, 47.771823182702065, 55.38419410586357, 55.70634461939335, 51.29296503961086, 56.262501776218414, 50.736051723361015, 55.017521381378174, 56.69171914458275, 53.97223547101021, 54.085552990436554, 56.32127322256565, 58.366407081484795, 58.960246816277504, 58.54273281991482, 59.1151113063097, 60.34836173057556, 62.18982271850109, 62.53377266228199, 61.55068941414356, 49.36788573861122, 51.52643971145153, 53.48939158022404, 47.898736372590065, 47.74636834859848, 48.04396077990532, 47.201204001903534, 47.16324403882027, 50.75792334973812, 54.84135523438454, 49.7769869863987, 50.05991980433464, 50.116897746920586, 55.35428211092949, 55.665462613105774, 60.59384375810623, 54.44052994251251, 52.93898731470108, 52.11186669766903, 52.23217964172363, 52.87725582718849, 52.167001739144325, 58.868835121393204, 60.46059250831604, 61.530858278274536, 67.2809149324894, 69.28127959370613, 71.23454198241234, 71.93015545606613, 76.52765035629272, 77.3698827624321, 73.23814406991005, 34.02803286910057, 1.3929977710358799, 42.77368538081646, 85.8821251988411, 38.95037993788719, 53.09479035437107, 44.202720299363136, 34.031551480293274, 41.74009904265404, 79.60574358701706, 28.49394902586937, 0.8856109972111881, 0.18569078121799976, 0.24810897797578946, 0.46440244128461927, 0.10585803727735765, 0.1385098707396537, 0.10892361184232868, 0.23742663790471852, 0.24101885530399159, 0.18310037412447855], [0.1393022618140094, 0.1505083206575364, 0.05564999548369087, 0.02741608550422825, 0.32479410292580724, 0.12535090965684503, 0.04008958552731201, 0.03787563655350823, 0.0433419846376637, 0.3215834533330053, 0.2551192604005337, 0.696323619922623, 15.937547497451305, 58.83043818175793, 48.85726533830166, 43.55093367397785, 30.469178035855293, 40.23961275815964, 34.86598290503025, 61.86038039624691, 47.230059653520584, 2.2243343805894256, 26.42329763621092, 71.74654930830002, 69.5549789071083, 73.52274119853973, 65.89339658617973, 67.20053404569626, 67.33696192502975, 65.60319095849991, 57.76282846927643, 67.31133610010147, 63.455884382128716, 56.65932588279247, 47.407369539141655, 48.974177464842796, 47.313111796975136, 45.207697972655296, 43.29306051135063, 47.182752192020416, 46.12651526927948, 44.07478876411915, 43.93259659409523, 44.66910347342491, 45.43793521821499, 45.830735340714455, 46.53091236948967, 44.08303812146187, 39.78317365050316, 49.76151421666145, 47.99564637243748, 45.60240179300308, 45.58494172990322, 52.90257386863232, 58.21209356188774, 57.21653178334236, 58.22300657629967, 56.28145895898342, 47.36824683845043, 49.614579901099205, 53.12831215560436, 56.75635367631912, 51.96482598781586, 53.28338943421841, 53.955459371209145, 55.70717677474022, 54.63551267981529, 57.09425434470177, 54.47483070194721, 55.94048425555229, 56.71170227229595, 51.4134755730629, 51.60694219172001, 48.657156676054, 49.08769637346268, 51.88193343579769, 44.691119492053986, 46.8533668667078, 48.161119893193245, 51.83000922203064, 40.92356085777283, 47.56616681814194, 43.44429239630699, 49.731039851903915, 52.07734934985638, 76.60084962844849, 38.373985067009926, 32.677136957645416, 56.86898723244667, 38.24474640190601, 42.21904054284096, 45.80306522548199, 42.94448621571064, 48.48437614738941, 46.76438324153423, 45.08149914443493, 39.05676282942295, 38.41178923845291, 40.80753408372402, 39.0145280957222, 43.57784382998943, 54.3722628057003, 37.74566978216171, 37.82340221107006, 52.844106405973434, 50.63354842364788, 49.364553317427635, 45.89718997478485, 49.053745195269585, 47.69659481942654, 51.787360310554504, 50.05561463534832, 49.448958188295364, 49.03027385473251, 50.43781712651253, 52.47427985072136, 49.91564154624939, 48.955406472086906, 52.52372279763222, 56.10421746969223, 56.9185745716095, 58.309657126665115, 48.662502989172935, 39.3353296816349, 49.55645442008972, 47.348928675055504, 43.66790659725666, 40.89949294924736, 42.96023637056351, 40.85297204554081, 43.4326346218586, 45.074610114097595, 44.072866067290306, 44.71778646111488, 43.45109403133392, 42.91170537471771, 49.217231422662735, 48.886675760149956, 51.3077462464571, 47.8608638048172, 46.29863083362579, 44.90839183330536, 45.195546224713326, 45.76805770397186, 51.064943075180054, 52.686452865600586, 54.724705293774605, 59.251041412353516, 65.45301541686058, 61.58749803900719, 71.85846850275993, 67.2048582136631, 72.39143550395966, 66.80280938744545, 48.09363551437855, 15.452818907797337, 1.6840644087642431, 53.82144056260586, 56.37996107339859, 30.230187959969044, 27.766821943223476, 23.617100715637207, 32.81403221189976, 33.7717442214489, 55.819190964102745, 25.18054962158203, 0.18948704469949007, 0.05243120082013775, 0.1978105425951071, 0.029349081487453077, 0.15441871160874143, 0.009108825579460245, 0.07146856150939129, 0.1587236431078054, 0.050656989187700674, 0.07345391786657274, 0.05142235866514966, 0.12842439551604912, 0.1190537420916371, 0.006284491682890803, 0.3098688303725794, 0.0917586415016558, 0.1246243470814079, 0.053074138195370324, 0.022270408298936673, 0.306055408436805, 0.32323054620064795, 0.7372972369194031, 20.470975935459137, 66.05407476425171, 49.74221125245094, 47.87908762693405, 33.94565708935261, 48.925057500600815, 38.93131636083126, 64.05511602759361, 54.64168734848499, 3.61253360286355, 28.79894345998764, 75.30142575502396, 71.19701519608498, 78.89656484127045, 69.84845995903015, 71.1879412829876, 71.06921285390854, 68.29467013478279, 61.57047115266323, 70.1929646730423, 66.28719985485077, 62.45970703661442, 50.97160868346691, 51.658338233828545, 51.16882190108299, 50.36272935569286, 47.27360911667347, 50.53427875041962, 50.165861919522285, 46.3850723952055, 47.77200937271118, 46.40277944505215, 47.41700582206249, 49.79206457734108, 48.605228662490845, 46.577231884002686, 42.61805333197117, 51.79154008626938, 51.54883190989494, 48.822679594159126, 47.175977155566216, 55.57519465684891, 59.62629787623882, 59.228428825736046, 60.379569455981255, 59.83788572251797, 49.99682419002056, 51.50875926017761, 57.42630712687969, 61.96129538118839, 53.59631784260273, 55.695708990097046, 54.67459738254547, 58.1032408028841, 57.98800818622112, 60.61985716223717, 55.639832988381386, 59.135987386107445, 60.28068356215954, 54.46519061923027, 53.78275103867054, 51.32115192711353, 52.60066866874695, 54.391174390912056, 47.54789359867573, 48.72681833803654, 48.9125219732523, 50.962230786681175, 43.04690212011337, 47.58529879152775, 44.9844903498888, 51.2599828094244, 52.98877224326134, 77.37624362111092, 48.57658199965954, 38.58370341360569, 59.54417668282986, 47.74358689785004, 43.67261454463005, 43.483947068452835, 41.21983475983143, 46.23230919241905, 45.923423767089844, 45.28080604970455, 37.34755374491215, 38.627492263913155, 40.18884368240833, 38.3730199187994, 44.27208937704563, 53.469161465764046, 39.55943025648594, 40.633845403790474, 53.324153646826744, 52.2491305321455, 50.29336027801037, 49.86855447292328, 51.55515477061272, 48.387701734900475, 52.91796304285526, 51.54834933578968, 51.823530569672585, 50.74291035532951, 53.314293175935745, 55.001573637127876, 54.00345839560032, 51.86459496617317, 52.843464240431786, 55.8512232452631, 58.89314241707325, 60.96754990518093, 49.22109201550484, 42.752113938331604, 52.50057063996792, 51.65618374943733, 47.10287667810917, 42.81924493610859, 43.017404302954674, 42.45397053658962, 44.962428733706474, 46.97343662381172, 47.630314975976944, 48.09832826256752, 48.06170962750912, 47.569689229130745, 52.07954563200474, 54.98177669942379, 59.13509823381901, 53.110958486795425, 50.4966189712286, 48.34617756307125, 49.008615016937256, 47.22522251307964, 53.26571278274059, 57.136546075344086, 59.26972880959511, 62.74330481886864, 72.53919437527657, 66.22688949108124, 76.28337666392326, 71.72198742628098, 74.80641111731529, 70.12116372585297, 52.14884631335735, 13.39970737695694, 3.212176635861397, 63.89882281422615, 61.4846945554018, 35.072384029626846, 37.07084119319916, 33.09403918683529, 38.818641006946564, 43.81788454949856, 66.39949142932892, 26.119811721146107, 0.2570896327961236, 0.05158080719411373, 0.2375450253020972, 0.04071299699717201, 0.1382325153099373, 0.023455076370737515, 0.0520964885072317, 0.08363960529095493, 0.12280938040930778, 0.040027965005720034, 0.16484164138091728, 0.32819794840179384, 0.312570960377343, 0.15846861148020253, 0.39396609587129205, 0.2797297976212576, 0.18484789441572502, 0.1334725582273677, 0.12188211141619831, 0.4776195273734629, 0.47101672855205834, 0.9882271033711731, 27.52367489039898, 74.18818429112434, 64.12118688225746, 61.96547515690327, 44.21072266995907, 53.39013330638409, 44.312386214733124, 72.31230095028877, 54.94783312082291, 4.184519285336137, 35.76626859605312, 77.55041867494583, 72.69046425819397, 82.05329865217209, 74.45092499256134, 76.46155670285225, 74.69858050346375, 72.38256677985191, 61.86353042721748, 74.75199043750763, 68.92612025141716, 65.06506383419037, 57.52509042620659, 56.67163722217083, 55.60227580368519, 55.57853847742081, 48.18733088672161, 51.97756290435791, 52.297095358371735, 48.445952609181404, 49.1104381531477, 49.64548744261265, 49.409212321043015, 51.08372546732426, 51.08471341431141, 47.82672643661499, 46.08581565320492, 56.8990246206522, 54.931839779019356, 52.096538320183754, 51.71479560434818, 59.68403197824955, 64.10285666584969, 61.79566986858845, 62.84053020179272, 64.07009482383728, 54.007383584976196, 55.9940005838871, 58.79415012896061, 64.35449436306953, 55.39754658937454, 58.76045733690262, 56.43297202885151, 58.384611904621124, 59.16338011622429, 65.4407724738121, 61.57407335937023, 60.911385118961334, 64.45103958249092, 58.02585415542126, 55.45078553259373, 54.79766517877579, 55.69322392344475, 55.096234157681465, 51.57584086060524, 55.917077511548996, 52.73912563920021, 53.01591798663139, 42.302955240011215, 48.69187921285629, 45.76232001185417, 52.47524119913578, 54.201549366116524, 74.76234868168831, 54.84026849269867, 44.40464146435261, 70.66329583525658, 55.592077150940895, 48.231480717659, 44.285282269120216, 40.95160335302353, 47.62735493481159, 46.76164358854294, 46.93769194185734, 39.62900832295418, 40.008482560515404, 41.21501661837101, 38.503170534968376, 45.854788050055504, 57.93208658695221, 42.93485753238201, 44.173974841833115, 56.33295759558678, 55.637902691960335, 52.37105458974838, 51.76923528313637, 52.988384664058685, 50.9806028008461, 53.78104493021965, 55.94962656497955, 54.19373318552971, 54.220141768455505, 56.314992159605026, 60.06659924983978, 58.26193928718567, 55.823393538594246, 57.8118572384119, 60.482874512672424, 59.8264217376709, 63.290855437517166, 50.88856793940067, 43.97292762994766, 58.290190771222115, 55.68421460688114, 47.74163380265236, 43.867840468883514, 47.60175570845604, 44.96877819299698, 47.22701981663704, 51.84148460626602, 49.648656472563744, 52.27713882923126, 52.191457226872444, 50.234368443489075, 56.22848980128765, 58.10367397964001, 63.19442801177502, 56.10071785748005, 55.97337909042835, 50.569434463977814, 53.02679680287838, 51.40518441796303, 56.289746314287186, 60.17333172261715, 60.84218703210354, 63.64065706729889, 75.64701721072197, 67.77533680200577, 78.34371730685234, 72.51757353544235, 81.5769562125206, 75.5004058778286, 59.97856177389622, 15.21316196769476, 2.5488858902826905, 65.64493551850319, 71.40358731150627, 39.3814592063427, 35.75541637837887, 36.55354455113411, 46.5589814633131, 50.35388723015785, 73.63374084234238, 34.40531462430954, 0.5474008235614747, 0.2972328756004572, 0.3253165155183524, 0.2566444926196709, 0.18799198820488527, 0.10146992586669512, 0.09559466183418408, 0.3405414376175031, 0.27092166244983673, 0.30677119502797723], [0.26641174976248294, 0.07365636090980843, 0.015472320737899281, 0.03708537173224613, 0.1405229017836973, 0.2147362445248291, 0.06324764326564036, 0.01891409181553172, 0.034611055089044385, 0.16364083159714937, 0.04772598455019761, 0.22957315697567537, 11.394639518111944, 67.97494009137154, 35.03930680453777, 44.68576557934284, 53.772267401218414, 26.9262158498168, 46.23806968331337, 53.167598247528076, 72.22130343317986, 6.983754504472017, 16.27821061760187, 69.20197784900665, 69.30291563272476, 70.80913960933685, 63.564402759075165, 68.95030215382576, 63.164181634783745, 64.07389461994171, 66.24026477336884, 63.121555522084236, 59.740033373236656, 49.74522829055786, 45.437494441866875, 47.75369435548782, 45.58693662285805, 46.504632979631424, 48.120868653059006, 51.27303130924702, 48.09537202119827, 47.67081320285797, 48.266062662005424, 46.00565515458584, 45.550010204315186, 47.736116498708725, 46.77517466247082, 46.77887946367264, 40.35521775484085, 45.90396121144295, 47.715947180986404, 48.95165607333183, 46.28401681780815, 48.62035185098648, 56.50775581598282, 59.44370247423649, 56.19344428181648, 53.86199578642845, 46.38249613344669, 51.930069252848625, 56.29758529365063, 56.846386045217514, 53.2525958865881, 55.4574503749609, 53.43711398541927, 57.36255034804344, 55.94712629914284, 52.524030581116676, 53.55844907462597, 52.59491577744484, 54.01502877473831, 51.78747050464153, 54.979002848267555, 49.33754436671734, 47.33626015484333, 54.84358951449394, 54.49678972363472, 47.14927978813648, 37.55257174372673, 40.432680398225784, 44.041247963905334, 45.56496620178223, 44.350657761096954, 45.379080176353455, 49.32228438556194, 75.80310523509979, 73.1347744166851, 38.65426942706108, 48.053277879953384, 38.77902053296566, 38.965347334742546, 36.53052158653736, 35.0963531434536, 39.835565239191055, 44.7196027636528, 41.9291502982378, 42.669532969594, 40.00511974096298, 34.39108818769455, 44.138834327459335, 50.203377306461334, 51.548223942518234, 40.784932896494865, 43.28361801803112, 50.68812109529972, 50.67075602710247, 50.53599625825882, 48.870880007743835, 51.49107500910759, 50.36626696586609, 51.41763634979725, 49.04377073049545, 50.01084543764591, 48.96098457276821, 50.65895766019821, 50.89588634669781, 51.03525146842003, 50.845660641789436, 49.61445830762386, 46.390198320150375, 48.79348196089268, 48.03815469145775, 42.74308182299137, 43.055109679698944, 47.80822902917862, 45.566052943468094, 46.27544067800045, 41.98230944573879, 42.12983272969723, 41.67830675840378, 43.48135180771351, 41.192134246230125, 44.53263759613037, 42.97462239861488, 44.634171947836876, 44.491531401872635, 47.05843806266785, 49.585921838879585, 53.039526119828224, 49.68662403523922, 51.70648165047169, 49.07458707690239, 49.19525720179081, 45.456763207912445, 47.30917140841484, 46.54265753924847, 54.610939398407936, 59.19303372502327, 66.17487788200378, 66.2161436676979, 70.77469065785408, 69.2830502986908, 72.79762610793114, 63.69370222091675, 40.57173773646355, 7.230751225724816, 10.76201906427741, 67.49244198203087, 47.28196866810322, 31.57086431980133, 21.89465694129467, 29.750870279967785, 43.267430886626244, 44.07323844730854, 53.585887402296066, 17.357360310852528, 0.32821682863868773, 0.10400101309642196, 0.10313264836440794, 0.013235830883786548, 0.017955893817998003, 0.015216795582091436, 0.04419675322424155, 0.11629217347945087, 0.05479330844536889, 0.05354752080165781, 0.18697828869335353, 0.06131892019766383, 0.0308549770488753, 0.07115708955097944, 0.057849372387863696, 0.1252878864761442, 0.07070932959322818, 0.034901197723229416, 0.08093734169960953, 0.2253028392442502, 0.22930259961867705, 0.540711876237765, 15.463697724044323, 74.82612445950508, 42.10524044930935, 53.112991377711296, 52.47037746012211, 36.78174890577793, 52.087012231349945, 59.17836271226406, 80.9439405798912, 10.330180786550045, 15.22193094715476, 73.6515998840332, 67.29239791631699, 76.55578404664993, 65.4389713704586, 71.49122580885887, 67.54005342721939, 69.38315972685814, 69.55853551626205, 66.2608976662159, 62.88912199437618, 53.313502818346024, 47.9865762591362, 50.813666358590126, 49.097237661480904, 50.35051681101322, 52.47605435550213, 56.02574788033962, 51.231320947408676, 52.19597138464451, 48.757858872413635, 50.01830443739891, 46.80053450167179, 50.75407795608044, 48.73843431472778, 47.97810651361942, 41.62571758031845, 48.01871873438358, 49.811371341347694, 51.67875833809376, 50.17566159367561, 52.46940851211548, 57.95730583369732, 62.059200927615166, 57.74498462677002, 56.50234870612621, 49.66610513627529, 54.51902613043785, 59.08051796257496, 60.193463042378426, 53.20056527853012, 55.400164648890495, 56.59259006381035, 60.46280398964882, 59.05451975762844, 56.69145695865154, 57.24981799721718, 57.183374762535095, 58.24120759963989, 55.872236117720604, 59.15714845061302, 51.56947620213032, 50.93536622822285, 57.1918711066246, 55.14464735984802, 52.25472003221512, 38.09375010430813, 41.16323299705982, 42.81404301524162, 46.85372784733772, 43.56832534074783, 42.56404682993889, 47.74327911436558, 70.85422039031982, 76.37757360935211, 43.467106372117996, 46.960319727659225, 39.587776735424995, 36.62903890013695, 37.24539242684841, 32.810669392347336, 39.24744799733162, 42.989038825035095, 43.1355931609869, 40.52083946764469, 40.91515190899372, 35.26064112782478, 44.58259351551533, 51.23592630028725, 51.95747338235378, 44.886068031191826, 44.20047461986542, 52.599654123187065, 52.46233329176903, 50.797851607203484, 49.806553199887276, 54.940336123108864, 52.75258831679821, 53.381625562906265, 50.61948537826538, 52.31949135661125, 50.49457088112831, 53.01734670996666, 52.46777459979057, 51.92973867058754, 54.06321778893471, 51.971152648329735, 46.71730376780033, 48.739756643772125, 46.45014010369778, 42.3730006814003, 44.32955749332905, 53.39019030332565, 49.53324906527996, 48.90906795859337, 45.529901683330536, 43.55055369436741, 44.640593603253365, 46.45817667245865, 45.92353016138077, 49.40250188112259, 46.69004783034325, 48.471327647566795, 47.13646687567234, 51.27655752003193, 56.60253033041954, 58.87635871767998, 54.47085231542587, 56.76399126648903, 52.257873862981796, 53.86414647102356, 47.40727074444294, 49.83404092490673, 51.284263506531715, 58.332794085145, 62.625283151865005, 70.59503629803658, 67.6835261285305, 74.69231843948364, 70.93949541449547, 76.88008144497871, 67.94761955738068, 44.22402575612068, 5.801673084497452, 14.147589895874262, 72.5392247736454, 49.47963774204254, 39.15073178708553, 29.891270846128464, 36.75756320357323, 48.755518198013306, 52.38392069935799, 64.74067524075508, 27.52741388976574, 0.5019614368211478, 0.19135581707814708, 0.19728289043996483, 0.06885788636282086, 0.052151040072203614, 0.09536631783703342, 0.05948109908786137, 0.11813970559160225, 0.0759927234321367, 0.11799633750342764, 0.37318278453312814, 0.25750811502803117, 0.26681722956709564, 0.16375237639294937, 0.12541004398372024, 0.31002447358332574, 0.1340725549380295, 0.10211262575467117, 0.1596598920878023, 0.2818547445349395, 0.3920074494089931, 0.6539799983147532, 20.778010860085487, 89.71658304333687, 45.90333804488182, 63.55516545474529, 75.54365515708923, 35.088563561439514, 60.6046237796545, 62.20567166805267, 86.22314170002937, 10.176169350743294, 21.67442075908184, 74.63283643126488, 71.90038025379181, 79.2531681060791, 66.87560588121414, 74.8359203338623, 75.1453985273838, 72.236517816782, 71.584632396698, 71.13472893834114, 67.11022049188614, 54.90639254450798, 53.07934798300266, 57.4569258838892, 52.1463118493557, 52.44292393326759, 53.89615975320339, 58.82492087781429, 55.09441025555134, 54.13552410900593, 51.09124906361103, 50.94885170459747, 48.53506922721863, 53.33959221839905, 48.26659843325615, 49.50004264712334, 45.57115986943245, 51.96337066590786, 50.88423237204552, 55.27893215417862, 51.08209915459156, 54.612679705023766, 61.18671454489231, 63.38789843022823, 61.14423282444477, 61.73717200756073, 52.18451499938965, 55.78677110373974, 60.29044523835182, 65.21613612771034, 54.25605744123459, 58.638035506010056, 57.33136922121048, 61.310432106256485, 61.041026562452316, 60.113017559051514, 61.27507880330086, 60.83859242498875, 63.2026469707489, 62.63975277543068, 62.39751197397709, 56.04198060929775, 53.867608085274696, 60.93011811375618, 54.797482788562775, 54.704733565449715, 42.11640045046806, 45.00713333487511, 44.82689380645752, 51.289579421281815, 44.224063754081726, 45.175418704748154, 51.50441609323025, 76.12149775028229, 63.68892587721348, 41.197818741202354, 52.83676519989967, 39.81351122260094, 37.31696918606758, 37.22700521349907, 33.86007808148861, 41.28262259066105, 45.10332517325878, 42.3348393291235, 40.66605627536774, 41.17674507200718, 35.99980406463146, 46.38705588877201, 53.83445866405964, 54.642948880791664, 47.33594097197056, 48.95998142659664, 53.505597710609436, 55.86605004966259, 53.209753185510635, 53.2781533151865, 57.94962264597416, 55.63017390668392, 55.20117312669754, 53.04066985845566, 53.640441074967384, 54.15460288524628, 55.126092955470085, 57.11867183446884, 55.4583927243948, 54.97077628970146, 52.52927049994469, 49.73447106778622, 54.864344000816345, 48.79595562815666, 44.53539624810219, 44.48860935866833, 56.92455165088177, 50.90699315071106, 51.55207693576813, 46.25468239188194, 48.488426730036736, 47.392200753092766, 48.441598042845726, 49.17684718966484, 52.38494664430618, 48.565953969955444, 50.71645237505436, 52.21901334822178, 54.85593885183334, 60.80456905066967, 64.65585619211197, 57.250714749097824, 59.28385265171528, 53.61852765083313, 54.78923723101616, 49.56599570810795, 53.222186118364334, 56.864609867334366, 65.2421647310257, 67.15926066040993, 76.37074917554855, 69.57936599850655, 75.9484550356865, 75.38698956370354, 81.74835741519928, 70.86352229118347, 50.77545940876007, 7.188412472605705, 13.641858883202076, 79.37788501381874, 62.39347659051418, 40.22961549460888, 29.330333545804024, 46.89509242773056, 69.6799997985363, 63.73454622924328, 73.36806669831276, 34.06034633517265, 0.7459334610030055, 0.20047330908710137, 0.3679276962066069, 0.20442269247723743, 0.13434262247756124, 0.21449099440360442, 0.13418475282378495, 0.23251143837114796, 0.1733321076608263, 0.25557764049153775], [0.010192763802479021, 0.053477098408620805, 0.050745297339744866, 0.039571458837599494, 0.0756109255598858, 0.03854326147120446, 0.05854803021065891, 0.09087836529943161, 0.059514766617212445, 0.07191895609139465, 0.1496411210973747, 0.19125386083032936, 12.143337093293667, 67.44416937232018, 40.559088215231895, 33.571947142481804, 45.519277453422546, 21.294038370251656, 36.19675509631634, 44.33179937303066, 75.78915238380432, 18.936348482966423, 2.8677372308447957, 65.7771684229374, 70.50600707530975, 73.87992203235626, 66.53888314962387, 69.52162429690361, 61.64250388741493, 70.50729900598526, 63.723405227065086, 61.819806173443794, 54.31105948984623, 49.15529474616051, 48.71777102351189, 47.175471782684326, 47.226727232337, 49.08646143972874, 50.1850850880146, 52.27025359869003, 50.78709818422794, 50.22390000522137, 48.6601585149765, 46.23538322746754, 46.205178648233414, 46.26457326114178, 45.3403564542532, 51.18831105530262, 44.35783937573433, 42.56300188601017, 45.75168438255787, 48.86813275516033, 47.32685565948486, 47.45604872703552, 53.90384294092655, 59.18878935277462, 54.4697617739439, 52.87999168038368, 49.6618265658617, 50.88554710149765, 54.64736804366112, 55.12243755161762, 56.99097968637943, 55.60080528259277, 54.7463109344244, 54.374907463788986, 50.28715901076794, 53.01188640296459, 51.047099232673645, 51.2191615998745, 51.40217497944832, 53.86215537786484, 54.01097819209099, 48.539799973368645, 50.11705733835697, 57.34531447291374, 57.8649365901947, 59.6913655847311, 44.192411452531815, 36.016545966267586, 39.108364060521126, 40.425897762179375, 42.620716989040375, 36.43312521278858, 40.13369344174862, 34.45061579346657, 51.611817330121994, 45.56909658014774, 43.73480200767517, 47.51369923353195, 48.70299741625786, 43.419411331415176, 38.85575741529465, 38.908046409487724, 37.65552341938019, 37.73798659443855, 41.23142413794994, 39.22029085457325, 37.90881022810936, 49.02161791920662, 51.178496181964874, 50.24736374616623, 42.04687178134918, 46.70822225511074, 47.12935745716095, 47.3190850764513, 50.42685091495514, 47.858124151825905, 49.34794440865517, 49.35772888362408, 48.771424144506454, 51.16120330989361, 51.99668347835541, 53.88786859810352, 52.85764507949352, 50.25802217423916, 52.313442081213, 51.07016779482365, 53.503667414188385, 47.1040166169405, 40.51090680062771, 38.66692654788494, 39.536247700452805, 49.08940248191357, 51.32526330649853, 43.81155028939247, 46.35222315788269, 45.005347430706024, 42.93111853301525, 42.51460388302803, 41.61139614880085, 40.60429058969021, 43.16073641180992, 42.15114578604698, 42.71323062479496, 44.947560131549835, 50.76534815132618, 51.90781004726887, 55.689465925097466, 55.82357972860336, 57.68583320081234, 55.63909202814102, 56.05645403265953, 51.35345779359341, 46.998728066682816, 47.19274565577507, 51.20969630777836, 60.10661110281944, 69.1754324734211, 67.36720830202103, 73.29404667019844, 66.79605334997177, 73.61982598900795, 55.05894675850868, 29.674669168889523, 2.2286112885922194, 21.415635645389557, 67.81829729676247, 42.44607076048851, 28.977934755384922, 25.405275262892246, 35.37701368331909, 34.22129049897194, 32.954054698348045, 58.99097956717014, 22.391354888677597, 0.19827527547022328, 0.13816411898005754, 0.10035314946435392, 0.040585080423625186, 0.0905739214795176, 0.015594827054883353, 0.08874489110894501, 0.03266210107540246, 0.07845993401133455, 0.0076450302003649995, 0.016958024316409137, 0.06620519823627546, 0.07550114707555622, 0.04428405576618388, 0.02611780204460956, 0.042355959812994115, 0.07126324635464698, 0.12087541777873412, 0.07528177564381622, 0.138342575810384, 0.13185668009100482, 0.18608288752147928, 19.09893035888672, 77.51188114285469, 44.79255124926567, 42.35634237527847, 51.08165457844734, 30.370161049067974, 46.593438014388084, 45.5587687343359, 85.3002168238163, 23.081965930759907, 3.594756731763482, 66.95699751377106, 72.95219421386719, 77.31383576989174, 69.58491370081902, 72.98113346099854, 68.65494400262833, 73.06993469595909, 68.69852006435394, 62.732961773872375, 58.22297237813473, 53.597187995910645, 54.1209252923727, 53.684784695506096, 51.27866640686989, 53.67933198809624, 54.751623049378395, 54.40272197127342, 53.817416578531265, 54.10246588289738, 51.42870135605335, 48.494901582598686, 47.87754110991955, 47.65056028962135, 48.09648536145687, 53.05098630487919, 46.585986614227295, 44.08411346375942, 47.28438913822174, 53.52607101202011, 50.718945041298866, 50.75215145945549, 55.36985747516155, 59.34508256614208, 58.66421230137348, 54.058893620967865, 50.82502394914627, 55.93964070081711, 57.109259739518166, 60.387511029839516, 60.024334117770195, 58.081068992614746, 57.35870115458965, 57.27731332182884, 53.066014498472214, 55.392481461167336, 54.10661906003952, 54.63616244494915, 55.7700178027153, 58.10010977089405, 58.577649146318436, 53.459821566939354, 54.601686894893646, 60.125298500061035, 60.764587596058846, 60.96718892455101, 45.82630857825279, 36.30694158375263, 38.07724379003048, 39.51798968017101, 40.84926724433899, 38.724778443574905, 38.79070870578289, 33.341447710990906, 44.97340254485607, 42.13985659182072, 41.0335573554039, 45.30658386647701, 48.27960893511772, 43.041912987828255, 38.1381469219923, 38.14772240817547, 37.99961395561695, 39.21212889254093, 40.912454053759575, 39.7399927675724, 39.91232872009277, 49.20939244329929, 51.64790779352188, 51.31373852491379, 41.57490670681, 49.694071635603905, 49.146426022052765, 47.032797038555145, 51.18204139173031, 49.05379839241505, 51.249670162796974, 51.41732096672058, 49.97443579137325, 51.387431770563126, 53.347169011831284, 57.73060999810696, 55.06113164126873, 52.32419550418854, 55.118014588952065, 52.22810246050358, 54.7684371471405, 48.94806146621704, 38.18947836756706, 39.53875556588173, 41.84165999293327, 52.65808738768101, 54.5015736669302, 48.4458614140749, 49.18114095926285, 47.52802066504955, 45.02974972128868, 44.81471925973892, 44.01319406926632, 43.21103811264038, 45.420285165309906, 46.06270149350166, 46.025478690862656, 47.19812236726284, 53.79142977297306, 56.70345291495323, 57.90611878037453, 59.4066696614027, 62.16751031577587, 60.920637622475624, 60.71970820426941, 53.624269142746925, 51.25229202210903, 48.888777047395706, 54.552198350429535, 62.97326847910881, 70.32086580991745, 73.00394743680954, 76.58772513270378, 68.78023087978363, 75.46817600727081, 61.155598014593124, 29.03805512934923, 1.7656854540109634, 24.824432730674744, 74.50136348605156, 46.85038022696972, 37.87117324769497, 29.46290273219347, 42.427740544080734, 40.8986721932888, 40.04687950015068, 67.69772976636887, 34.63122010231018, 0.1444091580924578, 0.14733718300703913, 0.2061495662201196, 0.08792794236796908, 0.18823706021066755, 0.03254673421906773, 0.08856348053086549, 0.025515189263387583, 0.03631293700891547, 0.04291840385121759, 0.16588018799666315, 0.16671707824571058, 0.141692066390533, 0.1939686667174101, 0.1871403440600261, 0.21523318660911173, 0.12771076115313917, 0.22449838084867224, 0.2461946228868328, 0.2642013964941725, 0.4398203728487715, 0.37492080533411354, 23.478225767612457, 91.3087660074234, 51.91504865884781, 41.532117202878, 61.820835918188095, 30.530174262821674, 49.57843244075775, 54.31795991957188, 90.79582393169403, 23.89276832342148, 5.801286930218339, 72.25824505090714, 71.99191734194756, 80.00285267829895, 71.83446899056435, 78.72318014502525, 68.19928765296936, 78.64435717463493, 72.2709059715271, 65.983497351408, 62.16029070317745, 56.50556333363056, 56.72096237540245, 58.05850960314274, 53.389350548386574, 56.998203098773956, 57.06882990896702, 60.25907792150974, 55.34964635968208, 55.819225162267685, 54.99960534274578, 52.748579531908035, 48.841765969991684, 49.27562668919563, 48.479911386966705, 56.587338745594025, 48.55920173227787, 46.60429023206234, 49.91783022880554, 57.40449629724026, 51.959369480609894, 52.4992711097002, 60.53265944123268, 63.90110269188881, 59.90333341062069, 57.26300708949566, 52.54996418952942, 58.292094469070435, 60.9690660238266, 64.02797028422356, 64.89743962883949, 60.8208891749382, 62.62136556208134, 60.74172042310238, 55.55833496153355, 58.03640238940716, 59.096800088882446, 59.950089901685715, 58.71014043688774, 59.32830646634102, 61.785839796066284, 55.751729384064674, 59.2464816570282, 63.96984860301018, 65.83353459835052, 65.03699094057083, 46.62420876324177, 37.4019668251276, 39.5237235724926, 39.44482460618019, 42.257961854338646, 37.90666714310646, 39.89462926983833, 34.14198875427246, 50.32112538814545, 43.3442247658968, 40.515930131077766, 47.28408895432949, 51.5136343985796, 45.05165174603462, 39.32905241847038, 39.42726954817772, 38.20497773587704, 39.95810866355896, 43.45520541071892, 42.95489005744457, 41.95894829928875, 51.423199251294136, 54.312666803598404, 54.97865326702595, 46.63372725248337, 52.731480449438095, 50.51667809486389, 49.280824810266495, 54.29485335946083, 51.03129208087921, 54.533822536468506, 55.12591056525707, 51.89163811504841, 54.94014233350754, 55.917085111141205, 59.72204513847828, 56.38574056327343, 54.47309419512749, 56.83664336800575, 54.064604714512825, 57.87958100438118, 50.88514432311058, 40.39639234542847, 38.132314234972, 41.747265458106995, 54.24876183271408, 60.00006482005119, 51.90858140587807, 52.90678784251213, 53.50240208208561, 49.927257522940636, 46.983266696333885, 48.51332299411297, 46.7134165763855, 49.30819854140282, 47.97952763736248, 49.391531869769096, 50.799713507294655, 57.31448292732239, 59.15054440498352, 62.851557210087776, 60.01262694597244, 64.92898553609848, 63.07245455682278, 62.40954972803593, 57.220076993107796, 53.848080933094025, 51.97778329253197, 57.177390083670616, 66.69487237930298, 72.19969779253006, 75.38100868463516, 80.41018322110176, 69.74110811948776, 80.64839243888855, 65.5663937330246, 36.64273336529732, 3.414456881582737, 24.23990059643984, 81.93096801638603, 54.45248790085316, 38.704206347465515, 36.05885669589043, 53.482624143362045, 49.786342084407806, 48.258447870612144, 77.366713732481, 42.77587406337261, 0.37008310086093843, 0.24623429810162634, 0.23871698038419709, 0.3018365066964179, 0.2504654601216316, 0.14836075308267027, 0.15262633591191843, 0.11240733467275277, 0.20955495536327362, 0.10785912716528401], [0.04317891252867412, 0.06741110657458194, 0.04456832059076987, 0.05328231432940811, 0.06751318898750469, 0.12749089248245582, 0.11732221508282237, 0.12862158415373415, 0.04191473075479735, 0.1257528123096563, 0.12429077396518551, 0.2559008012758568, 20.979656539857388, 62.89923705160618, 42.23008655011654, 32.74505831301212, 29.77876078337431, 29.226224832236767, 25.4317332431674, 43.181593492627144, 62.33475834131241, 42.8691628575325, 1.6626619384624064, 56.20462328195572, 69.15282368659973, 71.72631919384003, 65.26971325278282, 68.30182895064354, 65.63005551695824, 64.51309025287628, 62.55318962037563, 54.412647038698196, 48.06722313165665, 52.201336696743965, 47.50530168414116, 48.042421862483025, 46.41309969127178, 49.67097647488117, 49.22203816473484, 50.35344645380974, 50.18965244293213, 50.06602227687836, 49.77062612771988, 48.85634958744049, 46.918772757053375, 46.67648255825043, 46.801841631531715, 46.61282457411289, 45.568241626024246, 44.38998945057392, 46.25530555844307, 48.20477195084095, 48.57378914952278, 48.1792601197958, 51.62146881222725, 53.570160046219826, 53.74234400689602, 53.04060146212578, 52.59030282497406, 55.73427692055702, 56.67436547577381, 56.192091554403305, 55.32804071903229, 49.38149280846119, 43.462398424744606, 52.90214069187641, 51.993902027606964, 54.173476472496986, 51.98299661278725, 49.80430372059345, 50.15192426741123, 51.49446442723274, 53.59731338918209, 49.15228150784969, 47.047357857227325, 57.679293751716614, 55.46666108071804, 54.41457733511925, 40.978524908423424, 41.790982112288475, 41.895419508218765, 45.259610787034035, 44.32052157819271, 42.565072774887085, 43.33954721689224, 42.15185634791851, 43.052195236086845, 45.426931008696556, 54.43675674498081, 51.049766689538956, 49.447810649871826, 44.8377650231123, 40.0010197609663, 37.5171310454607, 37.03025937080383, 38.721803203225136, 38.95520567893982, 42.03841723501682, 40.02072170376778, 49.018148705363274, 47.17289172112942, 45.774388164281845, 37.909372597932816, 45.27860216796398, 44.79584567248821, 44.56462427973747, 51.80851377546787, 47.99590855836868, 48.77554692327976, 50.52759110927582, 51.071170940995216, 52.50554837286472, 52.44081124663353, 54.071011170744896, 54.264363795518875, 51.57858431339264, 52.56172455847263, 53.75445395708084, 52.839219868183136, 44.0959308296442, 39.37153793871403, 41.05618134140968, 45.50504721701145, 51.657274290919304, 46.81104093790054, 44.52455922961235, 43.90274919569492, 42.85350389778614, 42.234285324811935, 42.86851689219475, 44.091986641287804, 43.660261407494545, 42.44701690971851, 42.819548919796944, 43.908847868442535, 48.01099754869938, 51.45541772246361, 53.49984861910343, 58.61508093774319, 56.544952020049095, 54.90772247314453, 59.02304984629154, 56.870225965976715, 55.558574348688126, 53.60772483050823, 48.997398018836975, 51.805899515748024, 63.06003302335739, 68.0711281299591, 66.97284266352654, 70.09496793150902, 68.87060523033142, 70.82360163331032, 49.450193122029305, 14.711918514221907, 0.30773954931646585, 32.13275536894798, 65.28935819864273, 40.7676400244236, 23.96360982209444, 33.907358944416046, 32.59820759296417, 36.39476627111435, 43.83825905621052, 57.79419578611851, 32.884244844317436, 0.04788298218045384, 0.03490240371320397, 0.10216599359409884, 0.04000127737526782, 0.11039583245292306, 0.09141688249655999, 0.04003764261142351, 0.050077282794518396, 0.06586499031982385, 0.03220054459234234, 0.017947531669051386, 0.06773604109184816, 0.055333966738544405, 0.058101851027458906, 0.03994905615400057, 0.03877003211528063, 0.1319903408875689, 0.12381121297948994, 0.0890205247560516, 0.1200270836125128, 0.06696962518617511, 0.32696731912437826, 25.633365623652935, 76.62002339959145, 43.38726885616779, 38.72028328478336, 38.53443905711174, 29.1095881909132, 40.88800236582756, 47.04540856182575, 68.56314852833748, 50.12913689017296, 2.541469163261354, 59.033453688025475, 71.81550800800323, 72.70526826381683, 69.85438004136086, 73.61244678497314, 69.72369745373726, 66.95762827992439, 65.91795086860657, 57.07285389304161, 56.38170897960663, 56.83966040611267, 51.92487113177776, 52.122316136956215, 52.91029505431652, 53.46647500991821, 54.68511521816254, 54.65582638978958, 52.83483870327473, 53.200439885258675, 51.91299296915531, 51.049869284033775, 47.85064235329628, 49.6457876265049, 51.280927285552025, 50.51260471343994, 47.02904284000397, 44.888708889484406, 49.39381554722786, 52.57277436554432, 49.680213779211044, 50.92210114002228, 53.1570690125227, 57.511555552482605, 56.765127405524254, 54.219077825546265, 54.12483528256416, 60.41878715157509, 59.19643834233284, 60.76758563518524, 59.92963559925556, 53.420410081744194, 44.45448338985443, 52.47836083173752, 54.08710330724716, 56.762315556406975, 55.49384482204914, 52.361186519265175, 53.930198326706886, 58.70255224406719, 61.900954619050026, 57.7572275698185, 49.78437379002571, 62.24297806620598, 61.586852073669434, 61.275401785969734, 43.68928425014019, 42.35256537795067, 44.85086292028427, 45.10852329432964, 45.29244862496853, 41.41158007085323, 40.7239955663681, 39.688516929745674, 42.78839439153671, 45.15254773199558, 53.341845497488976, 51.22801132500172, 46.85534656047821, 42.420794516801834, 35.78327648341656, 34.94031831622124, 37.37653858959675, 39.17192704975605, 36.67415767908096, 43.1957895308733, 40.3237060457468, 48.95847670733929, 49.48219880461693, 46.807279139757156, 39.05581668019295, 44.39723186194897, 43.36854346096516, 44.325294122099876, 55.01169629395008, 49.53088939189911, 50.51808021962643, 49.69174236059189, 53.07529740035534, 54.19263884425163, 55.08044220507145, 58.84115360677242, 55.34440264105797, 52.36036576330662, 52.537766844034195, 52.606771141290665, 51.694234907627106, 42.516211196780205, 38.79725955426693, 42.917557060718536, 48.393002450466156, 56.804462894797325, 50.340709537267685, 47.70447179675102, 45.044409334659576, 43.327741250395775, 46.4506758749485, 46.637850031256676, 43.86955417692661, 44.72511246800423, 46.45691134035587, 45.33951289951801, 45.07642641663551, 52.63676293194294, 56.868082880973816, 56.104726642370224, 59.162680953741074, 60.759381875395775, 63.17721113562584, 62.74793677031994, 60.195264145731926, 58.31795588135719, 55.31645514070988, 50.28427876532078, 54.71047505736351, 63.01822006702423, 72.40066900849342, 71.6660164296627, 72.06406027078629, 69.60319831967354, 76.00219935178757, 52.849338725209236, 14.93119714781642, 0.3955508186481893, 39.559418857097626, 70.18120810389519, 47.788177505135536, 26.89183909446001, 32.46371001005173, 39.1369841247797, 42.96471633017063, 55.609305426478386, 62.06976056098938, 44.93272192776203, 0.11469286007923074, 0.040607088812976144, 0.06512618230772205, 0.1015884691150859, 0.1146943517960608, 0.04286269824660849, 0.042750886277644895, 0.058012040026369505, 0.04004795104265213, 0.07338689450989477, 0.2579928858904168, 0.2020566663122736, 0.1664199965307489, 0.24083707365207374, 0.15487985248910263, 0.3095082059735432, 0.22352558851707727, 0.3370641788933426, 0.3138240915723145, 0.474177683936432, 0.4264973080717027, 0.4779864748707041, 35.278135389089584, 85.86734399199486, 56.32547199726105, 43.67350369691849, 44.00592505931854, 38.11022222042084, 35.07255882024765, 55.272396504879, 73.19232612848282, 49.019778817892075, 2.9816211573779583, 64.44748297333717, 72.7353398501873, 78.59214037656784, 68.30996051430702, 78.71817961335182, 71.88707336783409, 72.54936262965202, 69.59560632705688, 61.873007118701935, 59.15855437517166, 63.596172854304314, 54.7218706458807, 56.5192312002182, 54.77548576891422, 56.72404021024704, 56.71181246638298, 58.186087757349014, 54.33069683611393, 55.26063613593578, 52.82699212431908, 51.13442614674568, 51.12735092639923, 52.068549022078514, 53.191951140761375, 51.9125521928072, 46.577771455049515, 45.994597747921944, 51.770390421152115, 56.3866601139307, 53.383639454841614, 55.59250272810459, 57.25591666996479, 59.04279738664627, 57.74735189974308, 55.844805389642715, 57.23278731107712, 63.01345132291317, 63.513793274760246, 67.47792676091194, 65.18844321370125, 59.69814442098141, 48.05865839123726, 56.96949563920498, 54.639141485095024, 60.811340287327766, 63.03292527794838, 56.88708946108818, 57.571915313601494, 63.55103127658367, 67.49132484197617, 63.6796809732914, 53.474648371338844, 66.0481470823288, 64.01443541049957, 63.96022751927376, 46.0867466032505, 45.92195324599743, 45.87478257715702, 47.391178607940674, 46.87493830919266, 41.357668563723564, 41.67256526648998, 40.771075040102005, 43.72743420302868, 46.81919150054455, 58.170926570892334, 53.49830970168114, 49.22017626464367, 43.85129235684872, 37.77186177670956, 36.80814228951931, 38.116275295615196, 40.38797579705715, 38.39424937963486, 47.170144468545914, 43.89504700899124, 53.79140317440033, 53.40340979397297, 49.414083659648895, 42.81071439385414, 46.10126942396164, 46.06669507920742, 47.576266676187515, 55.91024927794933, 55.198475271463394, 51.5409055352211, 51.245581582188606, 54.337939247488976, 58.25840167701244, 58.18212077021599, 62.92831689119339, 58.737240582704544, 55.95812290906906, 57.47097373008728, 54.331490993499756, 53.29185537993908, 44.155865013599396, 37.73144714534283, 43.94162870943546, 49.73129443824291, 60.71154624223709, 54.98420096933842, 51.184963434934616, 49.011358469724655, 46.87607064843178, 49.343080669641495, 47.06278122961521, 47.127818539738655, 47.46199920773506, 48.7894693762064, 47.700512409210205, 47.39182837307453, 55.84323987364769, 58.800818771123886, 59.44177597761154, 62.56627231836319, 63.36018271744251, 64.05816346406937, 66.40095055103302, 63.27367275953293, 61.05750247836113, 58.505103439092636, 54.25340138375759, 59.74758356809616, 68.50601479411125, 74.15008753538132, 73.05658981204033, 74.47606444358826, 72.13491886854172, 77.17520400881767, 61.917700320482254, 21.12216219305992, 1.1733461637049913, 36.785902082920074, 75.98582223057747, 52.738494873046875, 29.883572459220886, 47.96000428497791, 46.800108924508095, 48.128312453627586, 60.895984545350075, 74.45715665817261, 53.41250650584698, 0.2633747330401093, 0.09893261201796122, 0.18061161157675087, 0.16541020071599633, 0.22522880259202793, 0.14486148225842044, 0.13973827357403934, 0.198124174203258, 0.18727318849414587, 0.23745445359963924], [0.0616076824371703, 0.03778086800593883, 0.07111401529982686, 0.019707740830199327, 0.05663478463247884, 0.0872838546638377, 0.047909031563904136, 0.047441920105484314, 0.1265548513038084, 0.12159685211372562, 0.07416649837978184, 0.3953455406008288, 14.490760881453753, 55.01656763255596, 54.042136520147324, 33.50322782993317, 35.362395867705345, 41.09139025211334, 16.945209726691246, 40.76130196452141, 49.762999936938286, 70.18390595912933, 3.8967616762965918, 39.778325110673904, 75.04195287823677, 66.19062423706055, 70.10159477591515, 64.79393318295479, 63.350117057561874, 63.28410319983959, 53.888351172208786, 50.38710504770279, 48.34825985133648, 46.700774654746056, 49.204608500003815, 52.32731893658638, 53.66270408034325, 53.87812592089176, 54.82291102409363, 55.376746505498886, 54.792071878910065, 56.242856830358505, 57.94343277812004, 53.781709894537926, 49.7004970908165, 45.89139148592949, 45.838521122932434, 45.00711053609848, 45.07188946008682, 46.197111681103706, 44.93725888431072, 45.53660072386265, 46.57570816576481, 46.2863726913929, 49.43789318203926, 51.99750043451786, 54.40953500568867, 53.71595822274685, 46.329690366983414, 47.89898335933685, 51.77765563130379, 52.42047093808651, 50.47171130776405, 50.471069142222404, 49.5404876768589, 53.359142169356346, 50.177147313952446, 51.90838761627674, 51.89280465245247, 52.10762232542038, 50.64418785274029, 50.45953296124935, 48.49772863090038, 49.396110624074936, 43.45367029309273, 54.66784134507179, 57.5540866702795, 53.70624974370003, 43.15312162041664, 41.380847319960594, 40.69202408194542, 42.16559641063213, 45.88451385498047, 47.096363827586174, 44.04663227498531, 48.053167685866356, 54.210596680641174, 51.06251500546932, 51.942221000790596, 54.77230913937092, 52.19740390777588, 41.527527049183846, 37.2586765140295, 34.79010857641697, 35.41193000972271, 37.44677782058716, 37.26868897676468, 40.24762652814388, 40.536278039216995, 48.372061774134636, 51.220867708325386, 47.883704379200935, 38.3745626360178, 49.14281241595745, 45.84220312535763, 44.99547556042671, 50.14069966971874, 50.72611905634403, 49.33944806456566, 52.61025935411453, 50.71011811494827, 52.0232592523098, 50.03582909703255, 53.76996852457523, 51.91112346947193, 49.994821697473526, 52.42932826280594, 51.89260706305504, 45.38381852209568, 38.87781523168087, 40.001794919371605, 42.27281905710697, 47.75965243577957, 46.39779791235924, 44.53155465424061, 43.939348831772804, 43.99787329137325, 43.84061872959137, 44.305432587862015, 44.087734669446945, 42.62567572295666, 45.62561094760895, 43.50888133049011, 45.9108654409647, 46.273574978113174, 47.0257294178009, 52.650290206074715, 56.32673352956772, 56.62446275353432, 64.60095673799515, 71.73291563987732, 58.60409572720528, 62.44834944605827, 59.948117807507515, 58.692554980516434, 49.33241464197636, 50.26193216443062, 58.98453511297703, 68.37084084749222, 66.18567690253258, 70.18975764513016, 66.97226509451866, 72.87620589137077, 35.51556944847107, 6.649110736325383, 2.3840630846098065, 45.29023714363575, 61.73317842185497, 31.04035008698702, 23.90987690538168, 33.718068301677704, 28.602815084159374, 39.4758765399456, 37.36361548304558, 53.89391407370567, 38.560900837183, 0.11652739718556404, 0.016555750589759555, 0.06506604608148336, 0.0528227022732608, 0.026266229724569712, 0.057732881177798845, 0.17956979951122776, 0.08614940772531554, 0.03887204031343572, 0.01708195370156318, 0.07058192510157824, 0.035055018961429596, 0.07705172363785096, 0.05861743957211729, 0.07924285528133623, 0.05677883920725435, 0.3225190640660003, 0.04548408258415293, 0.07643477627425455, 0.020620586183213163, 0.15005037101218477, 0.353503551450558, 18.56942307204008, 66.3624358177185, 52.5390549749136, 28.76750584691763, 38.458294942975044, 38.01282584667206, 21.24418694525957, 45.935206934809685, 50.82963690161705, 80.86505681276321, 5.950790857896209, 39.86919343471527, 79.975965321064, 69.14361298084259, 76.03027984499931, 67.58472383022308, 66.64062649011612, 62.82425567507744, 55.736902579665184, 53.09370741248131, 53.3175989985466, 51.524839997291565, 55.474013686180115, 58.21371987462044, 59.685194715857506, 59.5785116404295, 61.802562698721886, 61.07266366481781, 59.060132056474686, 59.7310696542263, 61.438990607857704, 56.00965574383736, 51.08010046184063, 46.29608877003193, 48.33290867507458, 46.969880014657974, 46.111616268754005, 49.43945869803429, 48.009785413742065, 49.58570525050163, 46.60927556455135, 49.22602415084839, 51.0676409304142, 54.67792220413685, 59.211732521653175, 58.016677647829056, 54.22542728483677, 50.80323211848736, 53.89397867023945, 56.238893643021584, 54.4665889441967, 53.86077605187893, 52.300097197294235, 53.48440244793892, 52.01198145747185, 56.42667196691036, 58.45519311726093, 59.70119185745716, 55.52289046347141, 55.99925570189953, 57.07731865346432, 55.35923324525356, 51.284871473908424, 60.807567089796066, 64.5322336256504, 56.95242315530777, 46.1648628115654, 44.23601791262627, 39.97363083064556, 42.1091428399086, 44.80910696089268, 44.62172381579876, 43.117658123373985, 46.85592792928219, 52.06565357744694, 51.34683854877949, 51.153440326452255, 53.111756443977356, 52.6850925385952, 39.23299357295036, 37.224368155002594, 34.79823254048824, 35.86859330534935, 38.334410190582275, 37.25830793380737, 41.19874969124794, 41.87985934317112, 48.97734269499779, 49.81642507016659, 49.014402106404305, 40.37162147462368, 48.74841257929802, 43.55813808739185, 45.15732787549496, 51.68503560125828, 51.44770793616772, 50.6295358389616, 54.90321971476078, 52.62795500457287, 55.66416308283806, 53.20788748562336, 55.84559194743633, 50.5866589397192, 49.31975372135639, 52.137340530753136, 49.34191033244133, 44.6489417552948, 38.10048334300518, 41.89301423728466, 44.87356290221214, 50.703115090727806, 52.31075942516327, 49.02544051408768, 47.8102733194828, 44.37869645655155, 45.91732129454613, 45.726727321743965, 45.99191129207611, 44.23176974058151, 48.92783135175705, 47.51103177666664, 47.945101484656334, 47.851941883563995, 52.45605602860451, 57.13847637176514, 59.35879223048687, 59.07301336526871, 68.8116779923439, 76.15579470992088, 63.64583618938923, 62.302076295018196, 61.84833124279976, 59.166036173701286, 50.53839012980461, 53.72327283024788, 63.99719953536987, 72.45019555091858, 69.51969400048256, 73.74071270227432, 73.2957261800766, 76.0450990498066, 42.98821046948433, 6.128000048920512, 3.3556949347257614, 56.3371791690588, 70.63301905989647, 37.3331069201231, 24.907408878207207, 33.269905149936676, 31.245217993855476, 39.384913221001625, 39.3842938542366, 65.08065819740295, 47.51372203230858, 0.43426803953479975, 0.08020887180464342, 0.08655098383314908, 0.004892762090094038, 0.0193512019541231, 0.020256356801837683, 0.15152693318668753, 0.036344159161671996, 0.012864682830695529, 0.02719344676734181, 0.16885064891539514, 0.1646479853661731, 0.1850645718513988, 0.1532376281102188, 0.1538906735368073, 0.14762081700609997, 0.6285283109173179, 0.17210496647749096, 0.19489544589305297, 0.22077180503401905, 0.27655771002173424, 0.6078722630627453, 23.5289853438735, 74.4699315726757, 68.26616406440735, 46.95524699985981, 45.21750144660473, 55.072728618979454, 21.98044303804636, 53.720586374402046, 55.42488232254982, 81.85600563883781, 6.551718637347221, 44.869945496320724, 80.83186939358711, 71.20954692363739, 77.38013461232185, 73.1285959482193, 70.27894645929337, 66.85266271233559, 59.37403701245785, 57.820904552936554, 56.022594049572945, 55.65631650388241, 58.43088202178478, 62.40999050438404, 63.642078191041946, 61.54676802456379, 64.51837956905365, 62.20673941075802, 59.191692396998405, 61.191399693489075, 62.28950656950474, 57.69962266087532, 52.57231459021568, 49.71312381327152, 49.05471794307232, 50.015340596437454, 47.7359265089035, 51.937323063611984, 50.57677946984768, 51.23335763812065, 48.643207624554634, 54.50171045958996, 55.38203202188015, 58.14022421836853, 61.730453968048096, 58.33107277750969, 53.45278434455395, 54.08938318490982, 59.06345687806606, 62.5230610370636, 58.92781935632229, 56.87839552760124, 53.08750994503498, 57.67757244408131, 52.91446343064308, 61.44565165042877, 64.66065153479576, 66.34653747081757, 62.0767217874527, 62.80168108642101, 60.163516849279404, 59.06305409967899, 55.168574675917625, 62.69964516162872, 68.14447179436684, 58.91830086708069, 47.68049508333206, 45.694406256079674, 41.73879191279411, 45.389389023184776, 47.2286993265152, 46.20433509349823, 44.98518571257591, 50.08450448513031, 54.81415629386902, 53.14092367887497, 52.08547331392765, 57.95444838702679, 55.28212018311024, 43.35367865860462, 42.00894221663475, 37.42006525397301, 37.474960908293724, 37.9014690220356, 39.775308072566986, 44.45138655602932, 45.20322561264038, 51.680403649806976, 54.265359342098236, 51.722060814499855, 42.4191378057003, 50.182368233799934, 45.567546263337135, 48.921250104904175, 55.14186590909958, 55.710980370640755, 52.30509772896767, 57.72692419588566, 55.17340041697025, 59.95381750166416, 55.78136399388313, 61.56768970191479, 56.345595717430115, 50.87262399494648, 55.01480832695961, 49.600851237773895, 43.27097609639168, 37.624015510082245, 40.62048152089119, 45.464343801140785, 55.10099910199642, 56.880413219332695, 54.327991381287575, 52.14026257395744, 46.88404642045498, 47.88314200937748, 50.577634423971176, 51.48304983973503, 47.92924493551254, 51.21777847409248, 50.28076395392418, 50.070848017930984, 49.96708698570728, 53.781656697392464, 60.61671853065491, 62.31595695018768, 61.11136458814144, 71.04056999087334, 74.24171581864357, 66.82769805192947, 65.81717267632484, 66.13408327102661, 61.46956376731396, 56.931452080607414, 59.83837969601154, 67.54080578684807, 78.47130686044693, 71.66122108697891, 76.36317238211632, 75.55913552641869, 79.47524338960648, 52.70495027303696, 8.767994362860918, 2.7886413875967264, 52.63532280921936, 72.4529618024826, 42.34462380409241, 31.18287093937397, 46.083429381251335, 38.43876779079437, 54.040449410676956, 49.429184049367905, 69.24243047833443, 60.02406433224678, 0.5169093003496528, 0.3825816692551598, 0.14331492071505636, 0.1124074163089972, 0.1759722683345899, 0.16097931191325188, 0.182660028222017, 0.19287330127554014, 0.11565103210159577, 0.13686485588550568], [0.027142611506860703, 0.03797139957896434, 0.04949706060870085, 0.04152359666477423, 0.107284274417907, 0.08879656685166992, 0.0910804298473522, 0.1768015293055214, 0.054073491992312483, 0.08107688030577265, 0.15646475338144228, 0.1465718654799275, 18.974817618727684, 58.15281294286251, 46.66259050369263, 65.3253422677517, 50.22840276360512, 37.35486075282097, 31.065557934343815, 29.81902152299881, 39.45162244141102, 80.7657453417778, 16.084253825247288, 21.940913759171963, 81.5816679596901, 63.15465174615383, 71.2396489083767, 60.3929029405117, 65.0639770925045, 54.75772552192211, 51.185313016176224, 47.49512203037739, 49.52460452914238, 52.9999740421772, 58.49670968949795, 56.49233244359493, 59.360418543219566, 60.844045132398605, 59.70219500362873, 57.84151844680309, 60.5549680441618, 57.13214971125126, 59.759514927864075, 57.73070879280567, 51.80698625743389, 46.78136833012104, 45.61233066022396, 47.628179490566254, 46.41193315386772, 44.58048462867737, 43.38458999991417, 44.6981643140316, 46.62470653653145, 45.44333852827549, 47.08251737058163, 49.380083084106445, 52.82763049006462, 49.71205987036228, 48.396790847182274, 44.14496719837189, 53.80275696516037, 54.03764896094799, 54.40171882510185, 54.47501689195633, 55.564209446311, 52.765876203775406, 49.57287333905697, 50.978421717882156, 50.19690625369549, 51.25952683389187, 48.78497041761875, 46.54734268784523, 46.66712746024132, 48.64425256848335, 44.76879872381687, 51.26337602734566, 52.11975507438183, 49.295727610588074, 40.46654038131237, 40.764953568577766, 41.366871669888496, 43.988221809268, 43.577938824892044, 47.688885033130646, 47.79695883393288, 48.600041940808296, 45.37942215800285, 40.69770857691765, 39.182957857847214, 41.51914469897747, 38.3712188154459, 39.94810380041599, 37.34909266233444, 32.20668040215969, 29.657837972044945, 28.249863423407078, 30.738739371299744, 42.41641715168953, 44.48887154459953, 46.73183798789978, 54.74820323288441, 52.50838302075863, 40.66816136240959, 51.0576930642128, 46.910644993186, 49.33740757405758, 52.61397935450077, 52.54539683461189, 52.53224954009056, 51.977505907416344, 48.560945838689804, 50.99641755223274, 51.20506435632706, 49.71082493662834, 51.45315304398537, 52.84061439335346, 53.26988875865936, 51.075559705495834, 45.975579768419266, 46.01020731031895, 45.840082839131355, 46.96404732763767, 48.69063287973404, 45.76415531337261, 43.832107186317444, 42.57453426718712, 41.6105829924345, 45.746106281876564, 44.41971145570278, 43.11895005404949, 43.48317950963974, 45.72901099920273, 45.099692568182945, 44.51312944293022, 46.14142566919327, 52.32905924320221, 56.99109748005867, 57.549766302108765, 58.11719745397568, 58.741032779216766, 71.33202195167542, 59.620598182082176, 59.87520731985569, 59.4530613720417, 59.58207584917545, 52.9546120762825, 48.693064749240875, 55.57472728192806, 63.95735487341881, 67.8883807361126, 71.02872222661972, 66.37748301029205, 70.29870539903641, 26.92533429712057, 2.5801472878083587, 9.54849623143673, 48.330727592110634, 54.74231734871864, 29.718818999826908, 27.079144343733788, 27.797383703291416, 37.2526728361845, 49.1586347669363, 43.28181691467762, 50.798634365200996, 42.46437817811966, 0.3636163822375238, 0.04601616536092479, 0.08744739432586357, 0.04766713595017791, 0.06327931812847964, 0.07003824997809716, 0.024574222079536412, 0.052331886618048884, 0.03727696828718763, 0.0816229080373887, 0.08185286249499768, 0.12348707256023772, 0.08396853256272152, 0.027110903247375973, 0.0450251829897752, 0.037390045617939904, 0.11649426771327853, 0.14158878911985084, 0.064486977935303, 0.019957727708970197, 0.1655949212727137, 0.17901192710269243, 25.33770728856325, 67.58387267589569, 52.38525062799454, 68.16357716917992, 52.44527220726013, 37.59125366806984, 28.79601001739502, 42.404554188251495, 42.819567918777466, 89.05747041106224, 20.304098390042782, 22.783769331872463, 84.23452600836754, 67.41667404770851, 73.54604914784431, 63.724510967731476, 66.1242114007473, 57.93130002915859, 52.96088933944702, 51.910868883132935, 54.19070854783058, 57.9400547593832, 62.94139578938484, 61.92321002483368, 66.01969420909882, 65.82864046096802, 62.62267269194126, 62.777449786663055, 62.72096961736679, 62.000615671277046, 62.900099605321884, 59.620974361896515, 53.15769597887993, 47.578949332237244, 48.415793627500534, 50.058544278144836, 47.91719198226929, 47.66301982104778, 44.08036686480045, 44.09241981804371, 46.28206752240658, 46.58139646053314, 50.639305114746094, 52.68999807536602, 54.94681857526302, 54.94903385639191, 51.764842718839645, 50.060421377420425, 57.90756270289421, 60.146170780062675, 57.25739859044552, 57.95495755970478, 61.05949357151985, 56.939864829182625, 53.09832036495209, 54.05663654208183, 54.02797847986221, 52.563620656728745, 52.83506289124489, 52.89445750415325, 51.50555223226547, 53.583056554198265, 49.29882064461708, 55.318533629179, 57.63261705636978, 54.75882366299629, 43.77663776278496, 42.065285593271255, 42.05638647079468, 43.659129068255424, 43.359503746032715, 45.98522365093231, 45.617847964167595, 47.830761820077896, 44.69587303698063, 41.32959187030792, 41.59550540149212, 44.24159601330757, 41.73498451709747, 39.86092887818813, 36.70000769197941, 32.11846813559532, 32.571445629000664, 32.748060151934624, 34.61223252117634, 42.42911987006664, 45.53568497300148, 46.450428888201714, 53.0334198474884, 52.769220024347305, 42.75101959705353, 52.30281785130501, 49.25798423588276, 50.62238462269306, 53.18027816712856, 53.53776678442955, 53.8267906755209, 52.54846327006817, 49.4096264988184, 52.195196226239204, 51.58516936004162, 53.744734078645706, 53.6299042403698, 53.83731611073017, 54.729208052158356, 53.20373050868511, 48.81387546658516, 47.83236913383007, 48.41329336166382, 53.08590643107891, 50.75811333954334, 47.26548135280609, 46.297224909067154, 45.98248779773712, 45.55150352418423, 47.63770177960396, 47.25572727620602, 45.3679733723402, 44.03094291687012, 47.08491884171963, 46.74381874501705, 45.79331874847412, 48.811538591980934, 56.60370446741581, 60.42954057455063, 63.132677525281906, 61.13480553030968, 61.2041138112545, 69.25797924399376, 61.56534142792225, 61.801893934607506, 62.485416457057, 62.11413457989693, 56.07935920357704, 52.01215624809265, 59.765089228749275, 70.03597989678383, 71.76269084215164, 71.21514022350311, 70.28845354914665, 71.35441035032272, 31.764665320515633, 1.2210732651874423, 12.586733400821686, 59.2500838637352, 56.219697073102, 33.73297110199928, 25.492072105407715, 29.60794284939766, 35.98536103963852, 38.82191643118858, 47.06819213926792, 60.41122555732727, 52.91743107140064, 0.7458682707510889, 0.022218895828700624, 0.0913015750120394, 0.068221917754272, 0.022925891680642962, 0.04250445243087597, 0.05654688095091842, 0.032732612526160665, 0.08449836663203314, 0.05571850313572213, 0.09683653464890085, 0.1865606228238903, 0.23347306880168617, 0.16872947104275227, 0.1295082873548381, 0.13850620453013107, 0.17693645175313577, 0.292563698021695, 0.15429981955094263, 0.15688564017182216, 0.47251399664673954, 0.4123424441786483, 28.175134733319283, 77.9235890507698, 57.00344301760197, 77.89748445153236, 66.57982215285301, 49.37479376792908, 41.92359119653702, 46.482974141836166, 52.08795838057995, 94.4595417380333, 21.424270682036877, 27.675349451601505, 91.0345347225666, 70.02694398164749, 79.50104400515556, 68.44631999731064, 70.84624081850052, 59.40479636192322, 55.95106668770313, 55.0921493768692, 58.03152345120907, 59.32664975523949, 65.5431617796421, 65.24279549717903, 69.43104475736618, 69.91897657513618, 66.40542671084404, 62.89365515112877, 67.57289126515388, 64.69140708446503, 65.37471681833267, 60.819673240184784, 53.06405380368233, 50.72719059884548, 49.86010752618313, 52.69329249858856, 52.8202360868454, 51.016879454255104, 46.94928891956806, 46.09818398952484, 50.47620266675949, 50.00043399631977, 54.68680992722511, 55.78385666012764, 57.567104771733284, 56.465657874941826, 52.15581513941288, 50.18716357648373, 60.186080038547516, 63.250482603907585, 62.149985656142235, 60.48736207187176, 63.772874772548676, 60.88414438068867, 55.6708887219429, 57.55883261561394, 56.42559662461281, 56.02540969848633, 56.449527740478516, 59.25842821598053, 53.54109540581703, 55.18183596432209, 54.3538223952055, 59.72109138965607, 58.69528703391552, 55.088421776890755, 44.83698986470699, 42.969709262251854, 41.17014862596989, 45.776918828487396, 42.46068857610226, 48.201390132308006, 47.40842588245869, 52.25269854068756, 49.34827879071236, 46.07841745018959, 47.02347233891487, 47.372126430273056, 46.63787662982941, 45.13542965054512, 40.04336088895798, 34.32052597403526, 32.46832296252251, 34.56787750124931, 37.1932478249073, 44.665634259581566, 48.381511867046356, 48.01412098109722, 54.00255024433136, 56.90377436578274, 45.722619742155075, 55.14875873923302, 50.22098936140537, 50.854715555906296, 56.957640275359154, 56.75631567835808, 57.39071063697338, 56.296323761343956, 51.02978736162186, 54.65959958732128, 53.252576887607574, 56.664919182658195, 56.530888974666595, 54.940370321273804, 55.54954223334789, 52.98131704330444, 46.57084062695503, 48.94072785973549, 49.848708137869835, 58.14943112432957, 57.574343383312225, 52.942224740982056, 52.32499346137047, 48.86735759675503, 48.01249846816063, 53.12416657805443, 50.06153091788292, 48.04297663271427, 48.169308453798294, 51.77036002278328, 48.460703417658806, 49.37552712857723, 50.55991217494011, 60.62899187207222, 63.86835604906082, 67.47818514704704, 62.88000248372555, 64.38866972923279, 71.51031598448753, 63.38145777583122, 64.99127939343452, 63.91698583960533, 64.68794167041779, 57.97213263809681, 54.99384865164757, 63.39398950338364, 73.49303439259529, 75.9614123404026, 75.27904495596886, 76.12448439002037, 74.26912754774094, 40.13130336999893, 3.297212985344231, 10.373656153678894, 60.265237390995026, 67.59866148233414, 43.41947592794895, 33.03648367524147, 38.99676024913788, 51.3124655932188, 63.89325991272926, 56.731856390833855, 66.89004510641098, 65.82491666078568, 0.989393403287977, 0.24212314136093482, 0.1604933536145836, 0.10403365275124088, 0.19201889634132385, 0.2215660217916593, 0.16733346157707274, 0.14666264498373494, 0.2121107338462025, 0.13504133967217058], [0.0458240789885167, 0.018233232549391687, 0.022280599841906223, 0.04044948633236345, 0.012123458200221648, 0.08622633875347674, 0.10261810995871201, 0.09777843879419379, 0.11827711423393339, 0.03720714332303032, 0.0163866967704962, 0.15952142217429355, 18.93065258860588, 63.38075861334801, 41.21424525976181, 20.267654545605183, 44.163042828440666, 25.385810807347298, 24.2198433727026, 18.779276311397552, 32.47118800878525, 78.44707176089287, 32.070286720991135, 13.144028596580029, 76.05525210499763, 62.92615860700607, 70.70345968008041, 60.9670939296484, 59.82234835624695, 54.630850329995155, 53.67064565420151, 49.5834481716156, 54.29290026426315, 59.02271546423435, 59.908801317214966, 63.20891663432121, 61.34749911725521, 57.503196001052856, 60.24593822658062, 62.94276371598244, 65.28038308024406, 59.86859567463398, 59.057293608784676, 59.52377177774906, 57.337813675403595, 47.20953695476055, 46.54598616063595, 47.80192516744137, 45.88214658200741, 45.887580290436745, 43.897604271769524, 44.89258088171482, 46.46923787891865, 45.00889644026756, 45.56686609983444, 46.940416395664215, 48.57899107038975, 49.234535694122314, 50.208712220191956, 52.35864445567131, 56.72827698290348, 56.32443465292454, 53.584952652454376, 53.034252002835274, 52.464928552508354, 52.44530260562897, 51.01668566465378, 48.61077256500721, 49.438558146357536, 48.17860275506973, 49.06879618763924, 46.521295085549355, 47.62958161532879, 49.07162703573704, 45.17213188111782, 50.266336128115654, 54.85356017947197, 44.479672238230705, 40.620280131697655, 44.02476824820042, 40.168256387114525, 38.44466507434845, 42.1584489941597, 40.288189351558685, 39.558928683400154, 30.945241190493107, 23.224346190690994, 19.719108380377293, 14.215051475912333, 16.56920090317726, 16.388123519718647, 19.02632385492325, 18.521883822977543, 15.70197343826294, 12.555261589586735, 11.164738554507494, 16.961005479097366, 32.251043021678925, 44.716209545731544, 47.896429896354675, 50.56576766073704, 50.822584480047226, 40.608413368463516, 51.78503483533859, 46.34869694709778, 45.78683629631996, 48.36506634950638, 51.63948744535446, 48.688964769244194, 48.04688662290573, 50.84030672907829, 50.80273434519768, 50.081301257014275, 52.834888100624084, 52.246485874056816, 52.77927428483963, 52.25028946995735, 54.707830399274826, 51.55077740550041, 50.128285735845566, 47.74522460997105, 44.02160681784153, 44.41204346716404, 42.272838056087494, 43.49721595644951, 42.937680780887604, 41.555679738521576, 43.615241423249245, 43.838916420936584, 43.33606660366058, 44.84563060104847, 45.40065921843052, 46.98258273303509, 47.136360481381416, 48.74361723661423, 55.694447457790375, 59.46007959544659, 58.32734137773514, 59.449975937604904, 55.23833513259888, 56.116904988884926, 60.00407360494137, 57.32464738190174, 63.285246938467026, 59.495957270264626, 59.1148567199707, 48.32111030817032, 53.821223974227905, 64.00564268231392, 66.59518092870712, 69.94627431035042, 64.43153902888298, 64.54355701804161, 19.229373559355736, 0.411807355703786, 20.69317851215601, 53.4300197660923, 49.015697836875916, 22.44666662067175, 29.453585632145405, 27.45250280946493, 52.919190376996994, 58.62017646431923, 48.160253539681435, 52.2980111092329, 40.60861475765705, 1.216990384273231, 0.06042447639629245, 0.060130830825073645, 0.07797225393005647, 0.08819308946840465, 0.09599757380783558, 0.026805498346220702, 0.04184103549050633, 0.07970407779794186, 0.047985457931645215, 0.03389035176951438, 0.04343448221334256, 0.0052123396926617716, 0.01965153427590849, 0.0479611154878512, 0.02778289570414927, 0.10089113973663189, 0.0004769111126279313, 0.027863737850566395, 0.0795292945986148, 0.0987471938424278, 0.12328074808465317, 26.457062624394894, 70.57197153568268, 49.05316382646561, 26.600124947726727, 55.4950949549675, 30.313770174980164, 30.831310003995895, 36.347462609410286, 34.11378666758537, 85.60819789767265, 37.62821048498154, 14.592574518173933, 75.44135704636574, 68.68278130888939, 72.53250673413277, 65.87600111961365, 61.36873237788677, 55.91096743941307, 56.0706652700901, 53.899172991514206, 58.94303373992443, 61.208962351083755, 62.814965173602104, 67.57425159215927, 64.22608405351639, 61.013740226626396, 63.81711199879646, 66.17825970053673, 68.13048854470253, 62.03761428594589, 61.146679893136024, 61.34672395884991, 61.07609488070011, 50.021910443902016, 49.06591214239597, 50.36117523908615, 49.28325667977333, 48.557860404253006, 46.72941371798515, 47.471829280257225, 48.87209214270115, 47.0919256657362, 47.75844790041447, 50.956090316176414, 51.26690223813057, 52.53628492355347, 54.91319417953491, 54.57914650440216, 57.899883314967155, 57.275318428874016, 58.05565595626831, 53.895631581544876, 54.724002331495285, 54.94265399873257, 55.230933129787445, 54.0872211009264, 52.98220619559288, 52.292189821600914, 52.505601570010185, 52.23141208291054, 54.18404370546341, 52.60861024260521, 48.50471645593643, 53.358807787299156, 54.32993307709694, 47.78770633041859, 41.87309950590134, 44.3242833763361, 39.56502355635166, 40.38694605231285, 41.7646761238575, 40.130790397524834, 41.789078414440155, 35.949711352586746, 29.307954646646976, 24.766920916736126, 21.076785027980804, 23.421954587101936, 23.3086009696126, 24.535313844680786, 23.890950120985508, 20.56622162461281, 18.0453247949481, 15.589395929127932, 21.53934370726347, 35.86546987295151, 44.94080409407616, 46.847496181726456, 52.4186622351408, 50.89287310838699, 44.480941370129585, 54.83100078999996, 47.72943265736103, 47.57744461297989, 49.95654635131359, 54.63118091225624, 52.19691753387451, 51.31506845355034, 51.87275692820549, 53.85742463171482, 52.03160360455513, 55.141364336013794, 54.62626397609711, 53.53380359709263, 54.245961382985115, 56.49480231106281, 54.55368787050247, 56.02617725729942, 51.25814750790596, 47.66841933131218, 48.26648063957691, 44.41655382514, 46.942373290658, 44.83154475688934, 45.477396100759506, 46.51708871126175, 46.449076160788536, 46.05538688600063, 47.961600199341774, 47.38865174353123, 47.71067686378956, 48.741823732852936, 55.02242311835289, 60.40131948888302, 61.99734404683113, 60.71785390377045, 60.76242171227932, 59.11448813974857, 59.929757192730904, 63.315318524837494, 59.41928878426552, 66.82186916470528, 63.40848572552204, 62.78621591627598, 52.59118437767029, 56.44988492131233, 66.12785920500755, 69.44581836462021, 72.46860176324844, 68.28878805041313, 67.02680736780167, 23.777189925312996, 0.11381843942217529, 27.294284999370575, 57.89354145526886, 49.38705191016197, 31.710989400744438, 31.76799964159727, 32.95477285981178, 62.11997866630554, 58.3404316753149, 49.58926945924759, 60.50613686442375, 58.64400878548622, 4.1193964798003435, 0.04576576844556257, 0.04658490281144623, 0.043986079763271846, 0.06883882058900781, 0.05124728231749032, 0.02127702879079152, 0.03319473675219342, 0.03493598960631061, 0.042997557611670345, 0.09820242034038529, 0.1609932494466193, 0.14585518831154332, 0.0927290589606855, 0.17302889580605552, 0.15280877065379173, 0.20002770877908915, 0.20233743562130257, 0.25938800477888435, 0.13785728544462472, 0.2352126777986996, 0.24588979315012693, 32.00646914541721, 83.71839210391045, 53.7160874158144, 29.233719930052757, 61.31658777594566, 37.64126278460026, 31.965746730566025, 35.12359008193016, 42.41820685565472, 90.88964849710464, 38.92033115029335, 16.36792190372944, 82.85129383206367, 69.41110342741013, 75.67204266786575, 67.50008717179298, 66.72817379236221, 60.15696980059147, 60.211401879787445, 56.678108274936676, 62.28872001171112, 64.69597443938255, 65.12055605649948, 69.27347481250763, 68.86092334985733, 65.67553907632828, 68.79918426275253, 68.04262965917587, 69.81691405177116, 64.956184476614, 64.85754176974297, 64.08473923802376, 63.19271810352802, 52.74903170764446, 51.99133716523647, 51.901084408164024, 51.016066297888756, 52.01432593166828, 50.640806034207344, 51.65776066482067, 53.20680074393749, 50.41036359965801, 49.707766100764275, 54.7152704000473, 56.521036103367805, 56.9653994590044, 55.79806789755821, 56.17924444377422, 62.91486941277981, 61.7607269436121, 60.5459663271904, 60.08784770965576, 58.9121337980032, 60.64433164894581, 58.77247989177704, 56.30823992192745, 56.533298045396805, 57.62314036488533, 57.47972086071968, 54.77235473692417, 58.65446962416172, 56.64950720965862, 53.879243060946465, 56.45418629050255, 59.71934348344803, 51.54633544385433, 43.946819230914116, 45.4861394315958, 42.24794939160347, 39.00065504014492, 42.151799350976944, 41.1307979375124, 46.087099984288216, 36.20209760963917, 29.693727046251297, 27.618787586688995, 17.352656163275242, 21.670368276536465, 20.407300852239132, 22.230329029262066, 22.570135295391083, 21.130037270486355, 17.041240073740482, 14.590736366808414, 20.9998619556427, 38.425282314419746, 50.496706366539, 48.44392351806164, 52.69430324435234, 52.91748806834221, 48.10382276773453, 54.81829807162285, 48.235098123550415, 51.331297382712364, 51.90357707440853, 59.82178598642349, 55.37415884435177, 54.80691768229008, 55.16338415443897, 55.44303774833679, 53.091552928090096, 58.72332192957401, 57.207119688391685, 56.92288354039192, 56.32910080254078, 59.00901719927788, 56.72270268201828, 58.428396955132484, 54.028666242957115, 52.11863033473492, 51.920885145664215, 47.01881758868694, 49.87764358520508, 48.38405393064022, 46.23221039772034, 51.00796893239021, 47.867847830057144, 48.43552216887474, 50.57494796812534, 50.115301832556725, 50.45989014208317, 50.28748959302902, 54.841875806450844, 64.90055546164513, 67.7635346353054, 67.70191714167595, 67.57154613733292, 62.832767218351364, 61.34931541979313, 61.52469500899315, 64.85441833734512, 71.67371481657028, 65.974400639534, 65.54989501833916, 54.500334933400154, 60.410560593008995, 69.50174376368523, 73.1774765253067, 76.06668949127197, 72.35352873802185, 67.58218556642532, 30.702363923192024, 0.5784906365443021, 24.256253018975258, 63.66494536399841, 61.14118158817291, 36.15790978074074, 35.860640332102776, 37.94285640120506, 77.21187964081764, 81.94452568888664, 61.21149301528931, 67.25307002663612, 67.6154337823391, 4.592065941542387, 0.2096513900323771, 0.17776271444745362, 0.10675479657948017, 0.212840621243231, 0.31705178087577224, 0.15710587991634384, 0.16548995190532878, 0.17683065118035302, 0.11196556384675205], [0.05470173855428584, 0.040334401492145844, 0.16164486994966865, 0.022840110541437753, 0.03626847123086918, 0.014267080332501791, 0.06915216275956482, 0.061152575217420235, 0.08678117577801459, 0.04178963805316016, 0.14889515878167003, 0.10861114540603012, 27.289138175547123, 55.94759367406368, 54.98817555606365, 51.94542422890663, 41.21913179755211, 32.80040234327316, 19.195209592580795, 9.788214918226004, 25.789770931005478, 65.1907230913639, 52.354840859770775, 7.421236904338002, 57.343790754675865, 70.52763551473618, 63.74654218554497, 67.17777326703072, 58.78562718629837, 55.1526041328907, 53.403671979904175, 52.07480728626251, 59.062867909669876, 63.79301369190216, 62.56037883460522, 61.05647273361683, 56.14126168191433, 62.282153964042664, 62.60753430426121, 59.29181322455406, 65.1119077205658, 60.95334246754646, 57.14495502412319, 59.281344786286354, 56.65538929402828, 46.85823820531368, 46.793284490704536, 47.18749813735485, 46.35624714195728, 45.28193838894367, 46.091310158371925, 46.695337146520615, 42.631394416093826, 42.37331986427307, 44.669251665472984, 45.289203599095345, 45.612178668379784, 48.831700310111046, 52.38044388592243, 53.15519191324711, 54.003059417009354, 54.511354342103004, 54.581517577171326, 51.499499157071114, 53.5757951438427, 52.9558090120554, 51.42569571733475, 50.23637093603611, 51.50779411196709, 51.21921479701996, 48.66594560444355, 48.80306884646416, 48.90967972576618, 47.329625710844994, 41.820403933525085, 49.07958760857582, 49.707895293831825, 41.18900701403618, 43.52291777729988, 39.62487414479256, 27.686138972640038, 23.81001826375723, 25.546188801527023, 22.88544237613678, 18.61183449625969, 10.808944646269083, 12.682672552764416, 18.429461382329464, 7.336280113086104, 5.656870454549789, 6.404334995895624, 6.324989553540945, 7.94053366407752, 6.981410030275583, 5.256582358852029, 7.049402631819248, 7.999175917357206, 19.54569138586521, 41.59197919070721, 45.56263692677021, 51.81322552263737, 46.12385921180248, 40.72452753782272, 55.89091971516609, 47.13174752891064, 49.59358602762222, 47.19904191792011, 47.83436022698879, 49.82444263994694, 52.774440944194794, 52.74439975619316, 51.91087648272514, 51.779711320996284, 52.32449188828468, 53.825848326087, 52.76485785841942, 51.63627661764622, 51.75561681389809, 50.58243736624718, 49.298995435237885, 45.67908547818661, 42.54095546901226, 42.80566446483135, 44.50463689863682, 43.70148919522762, 44.23336185514927, 44.18224319815636, 41.82639621198177, 43.79797361791134, 44.443973153829575, 44.148147627711296, 42.776425033807755, 46.0458379983902, 46.553091779351234, 52.4245785176754, 55.92443771660328, 56.639175564050674, 55.99599547684193, 58.342867344617844, 60.66734321415424, 56.35568417608738, 59.005703777074814, 58.50620537996292, 61.313863322138786, 62.242408096790314, 59.80424612760544, 54.38018538057804, 51.46574176847935, 64.90468204021454, 68.30727025866508, 69.8008181154728, 63.24164427816868, 65.65479978919029, 11.978941764682531, 0.15683254692703485, 40.25820516049862, 55.81901617348194, 39.40714202821255, 19.42944422364235, 27.784451097249985, 23.382539302110672, 47.72540107369423, 62.54407770931721, 44.43732351064682, 40.272701382637024, 56.83876745402813, 9.340583737939596, 0.4527141200378537, 0.136787939700298, 0.03010192722285865, 0.005618738832708914, 0.033845748694147915, 0.13529065676266328, 0.014828418570687063, 0.03702873473230284, 0.030354966183949728, 0.012576915996760363, 0.011000693593814503, 0.03149658783513587, 0.05926854057179298, 0.03756282872927841, 0.023705972380412277, 0.03848572276183404, 0.048455196592840366, 0.10471291825524531, 0.06582714078831486, 0.25192642235197127, 0.10670959978597239, 35.07241442799568, 66.93660780787468, 59.035144597291946, 49.332885816693306, 50.84426611661911, 35.30020460486412, 18.870991989970207, 17.398597598075867, 33.350373432040215, 67.81591102480888, 60.22255428135395, 8.911360669881105, 55.436342507600784, 76.09658628702164, 65.56207716464996, 70.91715261340141, 61.916552782058716, 58.31553541123867, 54.61999051272869, 56.978333964943886, 64.05632436275482, 66.2995719909668, 66.00925236940384, 62.53488980233669, 60.67018926143646, 66.98485761880875, 61.521081402897835, 59.38993535935879, 65.94948917627335, 62.545472234487534, 59.11720119416714, 62.96555869281292, 58.218211233615875, 48.74408461153507, 46.49600364267826, 49.0293201059103, 45.530901029706, 48.731412291526794, 48.49238611757755, 49.06858339905739, 44.577095210552216, 45.70729896426201, 47.35378481447697, 46.79543897509575, 47.58621074259281, 49.74188446998596, 56.41773484647274, 55.394445955753326, 57.90456086397171, 56.55552685260773, 58.7756223231554, 55.20835094153881, 54.047805815935135, 55.25643736124039, 53.62529508769512, 53.9178603887558, 53.029099479317665, 53.72396059334278, 52.93187789618969, 53.08759354054928, 51.9034630805254, 51.158448457717896, 48.3702302724123, 50.7220608741045, 48.63815389573574, 40.54203853011131, 44.20780062675476, 40.61983175575733, 29.414455331861973, 28.302133418619633, 30.553309321403503, 27.045476250350475, 25.10189574211836, 17.631925977766514, 15.530841071158648, 26.022698432207108, 10.534870103001595, 10.56138128042221, 11.829386539757252, 11.03941747918725, 12.400051318109035, 11.54647272080183, 8.52802773937583, 8.657039366662502, 10.759761985391378, 23.467789627611637, 43.848693296313286, 45.79112246632576, 50.766339898109436, 48.437798246741295, 44.39922295510769, 54.89049419760704, 52.187015265226364, 51.94330774247646, 49.90695521235466, 51.00880108773708, 53.15933749079704, 54.191928282380104, 54.61326107382774, 54.846671149134636, 52.305166125297546, 54.99416023492813, 55.01508951187134, 57.50210925936699, 54.00494031608105, 54.44117970764637, 54.302034974098206, 53.30284059047699, 48.347879871726036, 45.758299827575684, 46.44969552755356, 46.18605047464371, 44.65456925332546, 45.35921864211559, 45.9562312066555, 44.75735753774643, 43.90188664197922, 47.259105294942856, 45.709164664149284, 46.1488276720047, 47.8412264585495, 48.5629977285862, 55.49813099205494, 59.946882873773575, 60.01590996980667, 61.20390862226486, 62.89227582514286, 62.21078619360924, 61.9465521723032, 63.338189497590065, 61.218180656433105, 65.73587983846664, 64.44591745734215, 64.35589268803596, 57.244832664728165, 54.164394959807396, 67.5031878054142, 71.3032878935337, 70.0713711977005, 65.35450950264931, 67.06607446074486, 12.116670124232769, 0.22724395617842674, 49.65401038527489, 57.10154615342617, 44.022716358304024, 26.96386232972145, 27.22495771944523, 16.149758510291576, 56.02648884057999, 69.19589057564735, 47.898143604397774, 49.46652464568615, 70.87782472372055, 17.76320893317461, 0.6086281850002706, 0.1549638487631455, 0.024679861235199496, 0.10031935205915943, 0.028340602984826546, 0.018939245055662468, 0.08221566138672642, 0.04270986406481825, 0.04757399270602036, 0.14641800342360511, 0.14397615945199504, 0.17282502783928066, 0.1535982673522085, 0.19456287467619404, 0.14465503161773086, 0.13785157090751454, 0.15967635292327031, 0.31501621822826564, 0.19462295895209536, 0.4949616186786443, 0.23986097134184092, 41.03130027651787, 76.41342088580132, 70.69906711578369, 66.3920970261097, 56.73656813800335, 46.17109827697277, 26.496090330183506, 14.66215543448925, 41.56233698129654, 77.64928936958313, 61.042542681097984, 12.349387686699629, 66.64753451943398, 77.12829932570457, 71.27175718545914, 73.6054627597332, 66.18996307253838, 59.33082193136215, 59.049447029829025, 58.77018101513386, 64.91260841488838, 69.34116438031197, 67.4495878815651, 66.4009277522564, 63.065755516290665, 68.44759672880173, 64.44105371832848, 63.680228143930435, 65.86585566401482, 63.785505294799805, 62.801829278469086, 64.75802510976791, 62.29988381266594, 51.50777891278267, 51.463777273893356, 51.735147312283516, 49.19957377016544, 50.75434394180775, 53.552160412073135, 51.12640857696533, 49.16564919054508, 47.50295341014862, 49.036733508110046, 49.99262921512127, 50.981096774339676, 52.99233265221119, 57.72890388965607, 58.62460322678089, 59.97989170253277, 57.55667433142662, 61.331570371985435, 56.371407732367516, 58.916146382689476, 58.57928305864334, 56.216934621334076, 58.57505388557911, 58.79683658480644, 60.11997878551483, 57.32487536966801, 57.186110615730286, 56.39558583498001, 52.8253848105669, 51.421002969145775, 56.256790682673454, 51.94694794714451, 43.802654966712, 44.175570756196976, 42.68910191953182, 30.74388049542904, 27.623503133654594, 31.311311647295952, 26.373482309281826, 24.222218245267868, 17.05922070890665, 21.8254379555583, 38.715662732720375, 20.502516143023968, 11.500688027590513, 11.481478158384562, 12.696716599166393, 12.435497716069221, 10.780760608613491, 10.373167879879475, 11.753589157015085, 11.568090710788965, 25.13877086341381, 46.276234835386276, 47.068667113780975, 53.2736923545599, 47.6132994890213, 49.19827803969383, 60.27882546186447, 52.06207796931267, 55.08636608719826, 51.979428604245186, 52.82438926398754, 55.84609352052212, 58.76417733728886, 55.83598606288433, 56.59664824604988, 56.15105375647545, 59.47995252907276, 59.347339645028114, 57.43288457393646, 55.2890358120203, 55.15977814793587, 55.41087247431278, 56.20019651949406, 51.54145270586014, 49.508197009563446, 49.99474570155144, 50.60203671455383, 48.72828505933285, 49.54290434718132, 49.86165404319763, 48.09500344097614, 46.63193754851818, 48.38618941605091, 49.26983579993248, 47.38838195800781, 51.754157692193985, 52.22044587135315, 58.59196297824383, 64.67470318078995, 62.901532128453255, 64.17878419160843, 65.38796290755272, 66.30001276731491, 64.39593493938446, 61.10337361693382, 63.600873202085495, 69.13306474685669, 68.4751908481121, 66.9550596177578, 62.90231868624687, 58.51732358336449, 71.39002203941345, 74.53366935253143, 74.51174452900887, 69.22919198870659, 69.65115934610367, 20.359754003584385, 0.2624532824847847, 49.75064679980278, 65.87660908699036, 52.05803498625755, 29.16797775775194, 34.58581253886223, 32.874999940395355, 62.888035252690315, 82.17154070734978, 59.47299510240555, 51.94516584277153, 81.66470110416412, 19.581899642944336, 0.7543447846546769, 0.23449067200999707, 0.2375454705907032, 0.42092499614227563, 0.12151275936048478, 0.21597411716356874, 0.20093525148695335, 0.12588614656124264, 0.14664205780718476], [0.03840517376374919, 0.03800107064307667, 0.11360110889654607, 0.015242480385495583, 0.08979341218946502, 0.021512918574444484, 0.22510081180371344, 0.09902981109917164, 0.19560176267987117, 0.15044109692098573, 0.2787981054279953, 0.40611107542645186, 28.017885871231556, 57.14446485042572, 47.20990553498268, 36.88860297203064, 47.403957322239876, 27.47132509946823, 35.9582494944334, 25.265796147286892, 19.57210946828127, 50.53194187581539, 61.09676957130432, 7.744172075763345, 24.06252421438694, 79.1463254392147, 57.727881744503975, 72.24113076925278, 57.485101372003555, 59.5731995254755, 49.34398502111435, 60.05961522459984, 60.085096657276154, 64.16714921593666, 57.42693789303303, 57.94759355485439, 62.90176771581173, 62.38850645720959, 57.348042726516724, 57.623942121863365, 55.11197671294212, 58.92669081687927, 56.41687989234924, 59.12256270647049, 54.517570808529854, 47.36158959567547, 45.0223933160305, 49.82480742037296, 46.21783956885338, 45.51665559411049, 44.704684764146805, 48.77545952796936, 45.219462141394615, 43.86530600488186, 42.29389652609825, 43.32098141312599, 43.890255466103554, 47.95924052596092, 51.10696122050285, 52.26692117750645, 53.99799048900604, 55.12989655137062, 52.70510606467724, 52.578610852360725, 52.85683572292328, 53.388905972242355, 52.034651041030884, 49.13351431488991, 49.30694080889225, 51.547581776976585, 50.54649129509926, 48.12579318881035, 49.31849978864193, 49.86527144908905, 43.28237168490887, 47.517962604761124, 46.45064927637577, 39.353948682546616, 45.86048014461994, 25.478546731173992, 12.824718430638313, 10.68768935278058, 10.41984362527728, 11.095634512603283, 8.482704721391201, 9.913330804556608, 16.069666408002377, 10.811440162360668, 7.377119846642017, 3.485234258696437, 3.6688468186184764, 5.115660270676017, 5.478799184784293, 5.160632282495499, 6.172141330316663, 7.408142331987619, 9.70549525693059, 23.560436256229877, 39.51075866818428, 41.43662452697754, 46.420228108763695, 44.7978899627924, 41.43755927681923, 57.379660829901695, 50.5299773812294, 49.70778129994869, 49.02036018669605, 53.6694373190403, 50.738821774721146, 50.50842493772507, 53.326178938150406, 51.58795081079006, 49.49739798903465, 52.339447885751724, 52.0991487801075, 52.48948283493519, 52.24670246243477, 51.950648948550224, 52.0364635437727, 48.42421777546406, 47.78786972165108, 44.94292438030243, 43.15300762653351, 43.39005030691624, 44.18040789663792, 43.100559040904045, 43.86728569865227, 42.624626979231834, 44.8314193636179, 44.53336715698242, 44.1341757774353, 43.6369838565588, 44.40826267004013, 47.02657297253609, 58.83601628243923, 56.21345400810242, 59.36064653098583, 57.889540269970894, 59.62956190109253, 57.77066744863987, 56.03951074182987, 62.22037687897682, 63.83978918194771, 58.686057329177856, 65.482357442379, 59.94279429316521, 59.545529410243034, 47.528666630387306, 65.8127573132515, 63.59319381415844, 73.58240559697151, 60.0028120726347, 63.36433969438076, 1.4738685940392315, 3.5607920167967677, 50.999111607670784, 50.77382929623127, 29.37179882079363, 14.915504939854145, 34.38011437654495, 32.73482546210289, 20.930544175207615, 56.82252712547779, 31.018581055104733, 29.493399895727634, 64.9049100279808, 28.549443148076534, 0.03373427069163881, 0.047030399218783714, 0.018526584972278215, 0.010895168543356704, 0.032584747023065574, 0.041468562703812495, 0.01779790170985507, 0.07055191264953464, 0.07179293199442327, 0.03250843568821438, 0.019173427899659146, 0.09274966098018922, 0.029087210969009902, 0.09344299018266611, 0.06236878456547856, 0.17616924917092547, 0.015771740218042396, 0.17436085792724043, 0.21853100886801258, 0.3112279996275902, 0.4009889205917716, 34.10758540034294, 64.76155132055283, 56.82515658438206, 43.23210418224335, 54.613690450787544, 35.143599808216095, 31.17905404418707, 25.940227657556534, 29.218841828405857, 52.01109990477562, 68.57450231909752, 10.371198635548353, 23.436745293438435, 81.28709256649017, 61.033453568816185, 75.14311864972115, 61.4810885488987, 61.51516892015934, 52.18038462102413, 63.9985066652298, 62.65878215432167, 68.6003865301609, 59.448767602443695, 65.4316757619381, 64.01506617665291, 61.544191762804985, 60.20835444331169, 59.37615729868412, 57.9280474036932, 59.58869889378548, 60.02340316772461, 61.34552702307701, 57.09744617342949, 49.531881138682365, 47.6828433573246, 51.32012978196144, 47.47124791145325, 49.01314057409763, 47.95813858509064, 49.436498656868935, 47.669555470347404, 45.782705917954445, 44.34868186712265, 45.7210998237133, 45.92371255159378, 49.09738965332508, 54.94291618466377, 54.27423186600208, 54.80598293244839, 58.43699589371681, 56.3221699744463, 55.21978832781315, 55.04772216081619, 55.089424923062325, 54.741006419062614, 53.78127671778202, 51.31290636956692, 52.7842216193676, 54.64137576520443, 51.37433007359505, 52.44324691593647, 51.65329210460186, 48.501726016402245, 50.507171005010605, 49.02837015688419, 41.61865375936031, 47.703985422849655, 26.616809852421284, 13.633547779172659, 13.06952504441142, 14.030248392373323, 16.899496279656887, 12.595197446644306, 13.260208312422037, 27.34776332974434, 27.970352321863174, 16.203062050044537, 6.273052990436554, 5.031455364078283, 5.636453200131655, 6.156181236729026, 5.746833002194762, 7.736535910516977, 8.990500923246145, 7.064253659918904, 23.80978837609291, 42.527128010988235, 41.67981147766113, 47.500985115766525, 46.898493245244026, 45.461178570985794, 55.33867634832859, 51.95001058280468, 53.86422626674175, 49.57284674048424, 55.913140922784805, 52.18632750213146, 52.191012650728226, 53.60052801668644, 54.260658994317055, 52.4732881039381, 55.289206802845, 54.82873611152172, 55.307046845555305, 52.22030147910118, 54.31481368839741, 55.01405596733093, 52.547748908400536, 48.58562171459198, 46.832996159791946, 46.33724436163902, 45.854343473911285, 46.296024173498154, 45.260777324438095, 46.25196173787117, 45.07175646722317, 45.43070800602436, 47.45606392621994, 47.872350588440895, 45.77993966639042, 46.403668597340584, 50.94643123447895, 62.03722670674324, 61.44640401005745, 62.84415900707245, 59.4871873408556, 62.767775505781174, 59.32707533240318, 59.95390109717846, 64.28404614329338, 65.64638704061508, 60.7999636977911, 67.59714916348457, 63.054831102490425, 61.62333011627197, 50.29889278113842, 68.01011860370636, 64.41147610545158, 76.73418447375298, 63.234181478619576, 64.48521494865417, 1.9399020681157708, 5.116740362718701, 59.962173253297806, 54.117102697491646, 36.00420042872429, 21.762944608926773, 23.69168121367693, 17.585843950510025, 24.02172390371561, 62.73228161036968, 35.37490099668503, 39.999222457408905, 70.9749399125576, 43.999188020825386, 0.5315972934477031, 0.054700321052223444, 0.008265714277513325, 0.03433393343584612, 0.058924970726366155, 0.019253939790360164, 0.09118923611822538, 0.04354273929493502, 0.056925023745861836, 0.17202585353516042, 0.1772465804242529, 0.2141292716260068, 0.11353702444466762, 0.36314431694336236, 0.16891996550839394, 0.3384494420606643, 0.23095134005416185, 0.2417320740642026, 0.2657367812935263, 0.4579267872031778, 0.5659408599603921, 44.58846800029278, 75.31904920935631, 63.65131549537182, 45.85590519011021, 64.9085882306099, 39.870329573750496, 49.389662370085716, 33.4310507029295, 34.74675290286541, 61.580054238438606, 71.6036769747734, 11.306709386408329, 31.376324258744717, 85.08606791496277, 61.78064927458763, 78.65457862615585, 65.09114563465118, 64.84298095107079, 54.185685217380524, 66.32595017552376, 67.86576434969902, 70.41741102933884, 63.05701598525047, 67.55937159061432, 66.07218459248543, 64.59060609340668, 64.04963672161102, 61.28422111272812, 57.79003120958805, 62.679855823516846, 62.521016746759415, 62.53124959766865, 61.031781658530235, 53.00396382808685, 49.3559467792511, 57.08043448626995, 50.595368072390556, 51.75900623202324, 49.36524488031864, 54.89358723163605, 49.96217384934425, 48.8889442384243, 47.95834377408028, 48.04932229220867, 50.35783141851425, 51.27410665154457, 57.15922325849533, 56.64073348045349, 59.949960708618164, 62.155871540308, 58.189184591174126, 57.10716985166073, 60.59421993792057, 55.70822551846504, 61.34087987244129, 54.75890725851059, 57.71126143634319, 57.75309719145298, 58.350406140089035, 55.88517442345619, 57.29815520346165, 54.809341952204704, 54.41577427089214, 53.54418843984604, 52.315102592110634, 42.64324598014355, 47.03300602734089, 29.127774015069008, 16.87187746167183, 14.887082464993, 14.860511440783739, 16.621402502059937, 12.353643458336592, 18.53410016745329, 42.214423790574074, 41.76301561295986, 32.18212231993675, 16.375567093491554, 8.105960637331009, 8.092209175229073, 9.146165270358324, 7.61852896772325, 9.602801017463207, 14.36879312619567, 15.415272172540426, 27.583215795457363, 45.05087658762932, 43.785339295864105, 50.33053748309612, 48.97681452333927, 47.10097678005695, 56.384201645851135, 52.412012591958046, 55.257147923111916, 53.2219847291708, 59.622243493795395, 55.773031041026115, 56.22556395828724, 56.129535511136055, 57.764659970998764, 53.49028833210468, 58.586145490407944, 55.927496552467346, 59.44133140146732, 56.03009104728699, 58.77338044345379, 58.63991640508175, 55.60609459877014, 53.79147157073021, 50.94122551381588, 48.75213257968426, 48.84211555123329, 49.662867709994316, 49.59529973566532, 49.5680096000433, 48.13108630478382, 49.079230427742004, 50.389844700694084, 50.452529937028885, 49.09804701805115, 49.390646517276764, 51.42221510410309, 64.87473964691162, 63.658044934272766, 68.58090877532959, 63.54722388088703, 66.78824856877327, 61.36281229555607, 64.85702499747276, 67.11317673325539, 66.95202738046646, 64.22171428799629, 71.8611815571785, 64.61134538054466, 65.27691766619682, 53.07343930006027, 71.80951952934265, 66.31877616047859, 82.07460790872574, 64.31756034493446, 76.48440107703209, 6.820200830698013, 3.9417192013934255, 63.42935040593147, 61.22403994202614, 46.148318499326706, 23.257231526076794, 41.683398485183716, 47.70086199045181, 30.328948460519314, 67.22421437501907, 46.02898210287094, 39.86414350569248, 83.41541916131973, 49.91450160741806, 0.7828167162369937, 0.17876830970635638, 0.11676124791847542, 0.16171990107977763, 0.1713758212281391, 0.1340323602198623, 0.16106565337395296, 0.18716081249294803, 0.19509644916979596], [0.02168331568100257, 0.00648768104838382, 0.07399227921268903, 0.03903252974851057, 0.06083266875066329, 0.05264317675027996, 0.08373821445275098, 0.04462364027858712, 0.07819757738616318, 0.12407385904225521, 0.2982863096985966, 0.2566072961781174, 31.301247887313366, 57.99418285489082, 38.788208439946175, 27.57665164768696, 45.18391504883766, 27.080282382667065, 17.7643583714962, 28.86870201677084, 14.451262950897217, 37.07051441073418, 67.56946384906769, 22.046698182821274, 4.40696457400918, 72.12706089019775, 60.76513096690178, 71.58156216144562, 63.00732225179672, 58.76983143389225, 51.852447018027306, 65.13243421912193, 59.105494022369385, 66.2738473713398, 53.038291186094284, 63.43522869050503, 59.045046865940094, 60.240094140172005, 59.68995586037636, 62.026340290904045, 55.74682764708996, 59.31332767009735, 57.693683579564095, 59.27264705300331, 52.285973355174065, 48.68663169443607, 45.057811215519905, 47.4008072912693, 45.34634493291378, 46.684036552906036, 46.205703020095825, 46.16936556994915, 46.60870559513569, 45.514269322156906, 41.305797547101974, 45.6645854562521, 42.84070998430252, 47.271667420864105, 50.58847524225712, 53.5813694447279, 51.6544396430254, 52.96782396733761, 51.53434708714485, 54.01865378022194, 51.78563140332699, 52.05523833632469, 49.99680519104004, 49.71768356859684, 50.28133772313595, 50.58060586452484, 47.9328965395689, 48.18347409367561, 46.40157490968704, 50.71857646107674, 43.85285787284374, 44.06918026506901, 41.78579159080982, 38.62783804535866, 43.291776180267334, 23.61110843718052, 7.686865925788879, 8.227805849164724, 11.404047813266516, 6.474746642634273, 9.83385806903243, 21.671113036572933, 28.761739656329155, 24.716980196535587, 23.404397629201412, 18.641370311379433, 14.133704490959644, 14.209065847098827, 12.662589680403471, 12.943544704467058, 5.832765866070986, 6.921064518392086, 9.005701057612896, 16.331346966326237, 37.21367172896862, 40.42068064212799, 44.3628741055727, 41.33132837712765, 41.88486747443676, 54.35843914747238, 49.15055260062218, 51.7065804451704, 50.78215844929218, 49.235333651304245, 52.21771381795406, 49.26270358264446, 49.894472882151604, 51.43771067261696, 49.9498625099659, 52.0394691824913, 52.783207073807716, 53.11229221522808, 49.801081493496895, 50.06135992705822, 50.25579169392586, 49.19480882585049, 47.81304717063904, 46.235972195863724, 46.96644499897957, 44.476309418678284, 45.220294296741486, 44.05291333794594, 45.103971138596535, 44.37729813158512, 45.09934678673744, 42.19111584126949, 44.66014735400677, 44.137238413095474, 45.681475549936295, 51.149325147271156, 57.83407084643841, 57.300469279289246, 59.41778406500816, 58.73675800859928, 59.21454057097435, 59.014314115047455, 61.978337466716766, 51.66727155447006, 65.70759415626526, 58.64460155367851, 65.11006861925125, 60.50320342183113, 62.67856769263744, 49.11362238228321, 62.1754214912653, 64.21445667743683, 69.0198764204979, 61.77614651620388, 46.01724073290825, 0.2789061621297151, 15.616738311946392, 55.67881129682064, 51.52110479772091, 19.33142278343439, 37.76010140776634, 117.98464938998222, 87.92866498231888, 24.963161386549473, 30.24367343634367, 44.16539490222931, 30.446818135678768, 52.28407345712185, 55.28302453458309, 4.754087347537279, 0.28080677264370024, 0.034274839927093126, 0.043547589230001904, 0.12489880813518539, 0.06895446946145967, 0.07314084286917932, 0.0362795552064199, 0.04193724751530681, 0.08307512034662068, 0.09810752191697247, 0.06560432579135522, 0.03367139222973492, 0.07851495684008114, 0.05020105447329115, 0.015023223986645462, 0.0646545400377363, 0.10384744047769345, 0.07307304025744088, 0.07528115223976783, 0.1938233690452762, 39.76959317922592, 65.98637759685516, 44.832737892866135, 30.7248093187809, 49.992549419403076, 36.94412559270859, 20.347678251564503, 23.465868830680847, 17.819022238254547, 37.74853102862835, 74.06690239906311, 28.338375873863697, 3.9448036858811975, 71.58340886235237, 65.43188855051994, 74.3088810145855, 68.33766102790833, 61.268318966031075, 55.553060844540596, 65.9946459531784, 63.138525411486626, 67.08568140864372, 58.03846187889576, 65.99431157112122, 59.421789050102234, 64.86665368080139, 62.02602490782738, 63.09632487595081, 59.95377570390701, 61.70633286237717, 60.97258843481541, 60.44149853289127, 53.76237653195858, 49.69846799969673, 47.799607291817665, 50.30372992157936, 48.33428040146828, 47.81074449419975, 48.52257929742336, 47.46681734919548, 49.76946339011192, 49.97177213430405, 45.68974390625954, 47.06514090299606, 44.85923387110233, 49.74754236638546, 53.750091791152954, 55.23210346698761, 54.90625575184822, 58.21418344974518, 53.18959526717663, 55.748446360230446, 54.57358360290527, 54.781489446759224, 52.46322624385357, 52.27658785879612, 53.37845653295517, 53.22032421827316, 52.55919009447098, 49.71366338431835, 51.176995262503624, 52.77480572462082, 45.40772303938866, 45.082395896315575, 44.00828093290329, 38.27661149203777, 45.008375868201256, 22.537141665816307, 9.042198099195957, 7.748939394950867, 11.880940273404121, 9.981312956660986, 8.720354419201612, 23.446763455867767, 34.54774238169193, 30.998345240950584, 27.772422842681408, 16.693585328757763, 5.472451150417328, 8.50449750199914, 8.630581386387348, 8.299353159964085, 5.2820053696632385, 7.715298850089312, 12.025378122925758, 20.189238153398037, 40.107672438025475, 40.39217837154865, 46.77948743104935, 42.93331101536751, 42.60270595550537, 55.72185158729553, 52.484318912029266, 54.40683715045452, 52.13830567896366, 52.418407648801804, 54.78899024426937, 53.477152436971664, 52.588497921824455, 54.02955919504166, 52.264648899436, 53.13137099146843, 54.856026247143745, 54.384536147117615, 54.560481905937195, 53.26815985143185, 54.756330996751785, 51.82979643344879, 50.221281945705414, 48.318963423371315, 49.33420054614544, 47.425711154937744, 50.920581221580505, 46.62608586251736, 48.94524581730366, 45.94554238021374, 46.329580172896385, 46.11751355230808, 45.61478152871132, 47.94315978884697, 47.56572224199772, 54.02782268822193, 60.80368369817734, 60.34632883965969, 61.34858585894108, 61.88889026641846, 61.74596093595028, 61.28269739449024, 63.13153378665447, 56.28829479217529, 67.29312747716904, 61.07084736227989, 68.38114589452744, 61.56946420669556, 66.10486283898354, 53.388598188757896, 64.93359848856926, 67.73285508155823, 72.23397195339203, 66.2182867527008, 50.815440863370895, 0.28567440051119775, 22.138427160680294, 64.44711819291115, 55.46337425708771, 24.43587888032198, 45.302556082606316, 123.82753506302834, 99.40295487642288, 32.19541400671005, 41.7079945653677, 44.617270454764366, 33.31959508359432, 63.949557691812515, 68.54874730110168, 12.76568004861474, 0.3519472974585369, 0.14476786775048822, 0.11780858898418956, 0.09113479958614334, 0.08468860876746476, 0.09090519393794239, 0.09529464121442288, 0.06120298188761808, 0.14914221974322572, 0.12235174988745712, 0.2366601477842778, 0.22441518609412014, 0.23924728942802176, 0.19107393454760313, 0.2426838339306414, 0.1936457582633011, 0.1832804933656007, 0.17534032958792523, 0.37547777232248336, 0.6664565694518387, 48.05889777839184, 75.04272803664207, 50.81490509212017, 36.426353976130486, 62.08844415843487, 38.40448223054409, 25.44927880167961, 36.43030196428299, 24.696278907358646, 48.42676743865013, 81.20184794068336, 27.33004868030548, 7.0030308701097965, 82.62266010046005, 66.68299421668053, 79.95786309242249, 69.9340769648552, 63.79869058728218, 55.61340920627117, 70.821952521801, 64.65961039066315, 70.29759585857391, 59.92835886776447, 66.04551002383232, 61.052900925278664, 66.29244357347488, 64.17775064706802, 62.75452181696892, 61.74354046583176, 65.19256219267845, 63.3208092302084, 63.12882073223591, 56.527320966124535, 51.77167475223541, 51.031603664159775, 54.60852272808552, 51.06814630329609, 50.059425830841064, 51.55653789639473, 50.9940654784441, 53.12120273709297, 53.42288754880428, 46.43220506608486, 49.40747581422329, 47.73047000169754, 51.909291967749596, 56.37652225792408, 59.763280525803566, 57.433496341109276, 61.72413490712643, 57.7768687158823, 60.26402525603771, 57.79807157814503, 57.62921243906021, 55.354175716638565, 55.60255318880081, 56.879178285598755, 56.2141265720129, 55.7604955136776, 53.37914049625397, 53.50079096853733, 56.65874071419239, 50.084732472896576, 47.94501028954983, 43.767313063144684, 40.02514846622944, 44.759265035390854, 26.331572458148003, 11.820206232368946, 12.771465238183737, 17.403499335050583, 12.696827743202448, 14.799661505967379, 35.6609458476305, 42.87794418632984, 41.13480292260647, 39.37540613114834, 30.806723423302174, 24.590623676776886, 23.56072884052992, 18.392392471432686, 16.897273398935795, 10.15930775552988, 12.034386489540339, 16.30833350121975, 22.99094371497631, 42.73445628583431, 41.698069497942924, 48.76991182565689, 44.816763550043106, 47.3752498626709, 57.049610540270805, 52.80798554420471, 56.04563981294632, 56.693318858742714, 54.06057693064213, 59.17237803339958, 56.51557579636574, 54.28181625902653, 55.834891721606255, 53.97203028202057, 56.52753755450249, 56.55545465648174, 59.282298535108566, 56.460984125733376, 56.78360961377621, 56.70840784907341, 56.284703984856606, 51.938223615288734, 51.842540949583054, 52.50838302075863, 51.72134645283222, 54.075802713632584, 49.589299857616425, 52.03205578029156, 49.832346215844154, 49.71068814396858, 48.75269494950771, 48.854578882455826, 52.18204513192177, 51.506498381495476, 57.18952663242817, 62.62058660387993, 64.9663907289505, 64.21710893511772, 65.77542811632156, 63.89780446887016, 64.90390688180923, 65.727269500494, 59.29868325591087, 70.4092338681221, 62.50990614295006, 73.78257125616074, 66.07394009828568, 70.47019019722939, 55.03527782857418, 68.29531610012054, 69.30801495909691, 76.95276394486427, 67.72582545876503, 62.061951979994774, 0.5602121923584491, 18.764495104551315, 71.35853692889214, 64.47334438562393, 35.76349854469299, 47.18661658465862, 128.98971766233444, 99.7325187921524, 37.647160068154335, 41.85216262936592, 59.72114838659763, 42.766066789627075, 67.14587017893791, 79.12604972720146, 12.061736471951008, 0.6698542996309698, 0.37093945022206753, 0.19313177646836266, 0.24630452011479065, 0.21196611894993111, 0.19120357290375978, 0.15581880288664252, 0.1613284181803465], [0.03494073935144115, 0.03012489298271248, 0.016392494799220003, 0.05791726776806172, 0.04541921145573724, 0.05876445160538424, 0.09917567280353978, 0.1516937234555371, 0.009910324661177583, 0.049177031687577255, 0.03554795344825834, 0.07349918887484819, 42.182258516550064, 54.884642511606216, 47.886584624648094, 37.551435604691505, 37.803700268268585, 42.35878564417362, 19.154236391186714, 39.58275340497494, 10.634914934635162, 43.64932179450989, 55.16924723982811, 57.485401555895805, 2.79486236628145, 28.95628921687603, 78.46597954630852, 59.37771141529083, 68.01081776618958, 56.951647996902466, 61.313361749053, 60.938242077827454, 65.55950090289116, 60.57430900633335, 60.34504070878029, 65.10529607534409, 62.939974665641785, 62.614734917879105, 59.09853659570217, 56.442460119724274, 61.374230682849884, 59.6898228675127, 57.3837798088789, 59.00050945580006, 53.00279729068279, 46.21436655521393, 46.325909569859505, 46.42154663801193, 47.02541783452034, 47.68691673874855, 47.76094816625118, 46.82476580142975, 48.183800876140594, 45.591956153512, 46.48093745112419, 47.69980564713478, 47.50339798629284, 48.94250236451626, 50.75392596423626, 52.04536646604538, 52.4405262619257, 54.937053099274635, 50.29002405703068, 53.06455537676811, 49.33495290577412, 50.65172664821148, 48.02479460835457, 49.015842229127884, 48.261107727885246, 49.53451059758663, 47.34871968626976, 49.78904373943806, 50.61430625617504, 50.62043912708759, 40.17347730696201, 42.19221018254757, 41.446697786450386, 39.04683016240597, 42.83010475337505, 19.853541366755962, 6.796429781243205, 9.175303056836128, 9.826844595372677, 15.91124340891838, 32.93268844485283, 41.9264904409647, 34.54457335174084, 32.44340009987354, 26.98393665254116, 24.43444635719061, 24.525985345244408, 30.16353003680706, 26.24894019216299, 24.826629012823105, 17.222959622740746, 10.432698335498571, 8.693000636994839, 15.324962418526411, 32.203142791986465, 35.04118770360947, 40.109009966254234, 35.99669583141804, 41.57460652291775, 55.127738267183304, 50.01825504004955, 51.30828581750393, 47.62483187019825, 50.967607498168945, 49.48739692568779, 46.91893994808197, 48.756297156214714, 51.02273114025593, 50.798942148685455, 50.958225801587105, 51.989247277379036, 53.23703572154045, 51.78586319088936, 50.16605190932751, 49.86327275633812, 49.50986132025719, 47.81387932598591, 44.682106375694275, 47.79237248003483, 47.865062579512596, 45.58693662285805, 43.53961408138275, 44.732529670000076, 43.83700132369995, 44.09525066614151, 43.023905754089355, 44.92250807583332, 43.42950738966465, 43.75413157045841, 53.86048346757889, 56.82720087468624, 55.88095284998417, 57.19811037182808, 57.04079121351242, 59.05085675418377, 60.08022151887417, 61.10647425055504, 55.875427946448326, 55.71443438529968, 62.717534601688385, 59.84317883849144, 61.853438168764114, 58.04761938750744, 54.26922753453255, 53.3639907091856, 66.3020570576191, 61.1906511336565, 73.31453517079353, 29.828621707856655, 0.15286196779925376, 37.785031870007515, 49.58086811006069, 40.28864152729511, 11.772160660475492, 41.09936222434044, 86.48223459720612, 29.12873726338148, 20.693442597985268, 27.49607317149639, 36.29468724131584, 43.225063160061836, 32.549733594059944, 63.935589641332626, 28.818558007478714, 0.11909916152944788, 0.08245561257353984, 0.051184875119361095, 0.014615075233450625, 0.045158969951444305, 0.04419078635692131, 0.09478638137807138, 0.033903265139088035, 0.04515501801506616, 0.007962119289004477, 0.09656608861405402, 0.09063558652997017, 0.036972465095459484, 0.007033959718683036, 0.03858875141304452, 0.0696486966626253, 0.028944757577846758, 0.015717517053417396, 0.02388136970694177, 0.22320585645502433, 52.073393762111664, 62.24447138607502, 51.46299451589584, 35.401902347803116, 40.79981669783592, 49.78887654840946, 25.7650076597929, 32.785499542951584, 12.848175521939993, 52.33635865151882, 57.78125748038292, 66.94343224167824, 4.36878327280283, 24.173835441470146, 81.42339885234833, 64.2659667134285, 72.71897032856941, 59.10105586051941, 65.89509129524231, 63.68450291454792, 68.51724699139595, 60.93711353838444, 64.48294267058372, 65.81167057156563, 66.83623239398003, 63.66226650774479, 62.71030358970165, 60.325049981474876, 63.046589344739914, 60.36858044564724, 60.36834105849266, 61.69334515929222, 54.895806312561035, 47.84685775637627, 48.59200157225132, 49.69819821417332, 49.99763734638691, 49.899275824427605, 50.12609705328941, 49.44891259074211, 49.901909083127975, 49.86423410475254, 50.02773553133011, 50.24126507341862, 49.149891436100006, 49.36448112130165, 52.637359499931335, 53.32093141973019, 56.205375641584396, 57.96216197311878, 54.95083495974541, 52.408718168735504, 51.737051010131836, 52.259218990802765, 52.83835731446743, 52.693870067596436, 53.70666392147541, 53.15896891057491, 52.1751295030117, 51.791999861598015, 52.55313701927662, 52.70588502287865, 44.51006680727005, 44.74291831254959, 41.768035143613815, 39.33791734278202, 43.984026834368706, 23.397523798048496, 8.534950017929077, 9.759917836636305, 8.993686102330685, 10.08946180343628, 26.21238235384226, 42.415170818567276, 37.26963132619858, 37.2688789665699, 32.882614731788635, 31.102089174091816, 30.094681531190872, 31.05417564511299, 27.492868043482304, 21.339046955108643, 15.346599407494068, 11.84712778776884, 10.51866302266717, 18.171213939785957, 36.94341883063316, 35.65867356956005, 40.422356352210045, 40.47913670539856, 44.98573288321495, 56.06486298143864, 53.31976108253002, 55.3876519203186, 50.97805313766003, 53.52976821362972, 50.83776466548443, 51.77122637629509, 51.43501661717892, 53.23568679392338, 50.032800659537315, 52.952856570482254, 54.16726000607014, 53.19321267306805, 53.76992292702198, 51.16138570010662, 52.97116778790951, 53.32166098058224, 51.24071404337883, 49.41317930817604, 50.66475994884968, 51.871183812618256, 49.228277429938316, 45.919335186481476, 48.514246344566345, 47.01528377830982, 46.355536580085754, 47.103807628154755, 48.10578726232052, 46.501726135611534, 45.66654235124588, 57.204478830099106, 60.41649207472801, 60.572108924388885, 57.82084375619888, 60.84994241595268, 60.626491606235504, 60.589652583003044, 61.91255159676075, 60.01650273799896, 60.81939585506916, 65.4779040813446, 61.29026658833027, 65.82546383142471, 61.842506155371666, 57.88935787975788, 56.945241540670395, 71.88303038477898, 65.38252919912338, 78.74016523361206, 29.73716251552105, 0.19113550311885774, 48.40388126671314, 53.52964662015438, 42.98174701631069, 15.104160066694021, 44.90529119968414, 106.02665305137634, 43.38243171572685, 34.791742488741875, 31.078574135899544, 43.063951805233955, 40.514368414878845, 44.07138414680958, 71.51308223605156, 43.64151321351528, 0.6085469643585384, 0.05603148165391758, 0.10454977935296483, 0.07003689926932566, 0.027398889942560345, 0.021518850189750083, 0.06447551175369881, 0.057073839197983034, 0.20473204931477085, 0.07808238122379407, 0.24892332177842036, 0.18814902665326372, 0.2421180799137801, 0.11940348660573363, 0.2779228164581582, 0.1652488874970004, 0.11822392450994812, 0.1211708593473304, 0.14897539978846908, 0.2490750909782946, 61.55228912830353, 68.44142585992813, 65.50916120409966, 49.564338997006416, 52.631724402308464, 58.35930526256561, 25.74994906783104, 53.01798887550831, 18.025809042155743, 56.664729192852974, 65.51549166440964, 72.46863216161728, 3.824170371517539, 37.02175922691822, 81.5571516752243, 66.21852993965149, 73.25826779007912, 62.39084333181381, 65.6313094496727, 68.35670560598373, 71.46808505058289, 67.58485302329063, 67.16408640146255, 67.77706190943718, 67.20043525099754, 69.24337282776833, 64.87243697047234, 63.84358897805214, 64.75864067673683, 63.0413456261158, 63.65022495388985, 65.15378147363663, 57.01011545956135, 49.93633523583412, 50.92767924070358, 53.567861169576645, 52.85378448665142, 51.28972381353378, 53.54445822536945, 52.49623127281666, 52.211865931749344, 51.13843113183975, 53.040453270077705, 50.4846116155386, 55.42138651013374, 53.884619772434235, 54.97517265379429, 55.699216201901436, 59.03824523091316, 62.818901762366295, 58.3268816024065, 56.145570650696754, 53.773198351264, 56.112143844366074, 55.78083962202072, 55.87548494338989, 57.42343068122864, 58.00711736083031, 56.696955263614655, 57.0589504390955, 59.06881459057331, 56.41231633722782, 50.96661575138569, 50.01411706209183, 43.97290103137493, 41.58721424639225, 46.2504456192255, 26.206969544291496, 11.296777669340372, 15.432933624833822, 14.651129376143217, 19.609963037073612, 35.83004057407379, 44.070069417357445, 38.92866790294647, 40.59615522623062, 40.26514358818531, 36.78348921239376, 39.27629604935646, 42.338517531752586, 39.093408063054085, 32.12276570498943, 22.054907642304897, 14.144708700478077, 11.577648147940636, 19.158856943249702, 39.28772583603859, 35.82742251455784, 41.49666890501976, 42.35601179301739, 49.39049452543259, 58.697563111782074, 52.71647125482559, 57.768562361598015, 52.09754906594753, 59.01182904839516, 55.20012438297272, 56.08993403613567, 55.950717106461525, 56.1337760835886, 54.91013154387474, 56.342061907052994, 57.93177880346775, 57.56193704903126, 56.54421865940094, 54.42423261702061, 56.35365508496761, 54.6164833009243, 52.51726694405079, 50.698114559054375, 53.70892100036144, 54.18478086590767, 52.09514379501343, 48.521089777350426, 50.83425745368004, 47.87342593073845, 49.77975703775883, 50.371297895908356, 52.10102587938309, 50.738734379410744, 49.18468616902828, 60.763884633779526, 63.40711399912834, 62.42255263030529, 61.3492888212204, 63.788438737392426, 63.78467693924904, 65.04409655928612, 65.4026073217392, 60.65806031227112, 64.0287834405899, 70.13361945748329, 67.01202616095543, 67.79932871460915, 66.16198137402534, 60.461823642253876, 59.684088975191116, 72.02129736542702, 68.556217700243, 81.52932196855545, 39.14017215371132, 0.23747432831441984, 45.75438603758812, 63.10521639883518, 52.18919634819031, 24.23764541745186, 48.30648869276047, 96.06234133243561, 32.02891834080219, 30.718872137367725, 35.20276643335819, 50.406704396009445, 57.254848927259445, 47.31450252234936, 82.17265784740448, 47.532652616500854, 0.7274330849759281, 0.22170003881910816, 0.21544095827266574, 0.10458713164553046, 0.14012684725457802, 0.17843416513642296, 0.18821929319528863, 0.1762017552391626], [0.015551373380731093, 0.039098855486372486, 0.08624375695944764, 0.15391553548397496, 0.05851562804309651, 0.04276914682122879, 0.02896425750805065, 0.08712429291335866, 0.06593240701477043, 0.15345565625466406, 0.10973788143019192, 0.9291416394989938, 46.013695523142815, 52.57012590765953, 36.68114550411701, 55.9194827824831, 52.14011438190937, 45.42934387922287, 20.82436077296734, 31.926179453730583, 23.423254117369652, 41.90722547471523, 64.16885912418365, 61.76558308303356, 25.0369306281209, 2.200794881209731, 72.27507814764977, 63.019637390971184, 71.63363456726074, 59.71961326897144, 66.37532472610474, 61.05809144675732, 67.59317457675934, 57.13176593184471, 64.71739768981934, 62.39016696810722, 60.845416858792305, 57.50011816620827, 59.82569217681885, 57.93964058160782, 61.256425604224205, 58.20447497069836, 59.101644828915596, 58.19802671670914, 52.837984934449196, 46.87703959643841, 47.469283416867256, 47.24051669239998, 48.17322984337807, 51.285962015390396, 52.34006345272064, 49.41069044172764, 48.60986441373825, 47.65717573463917, 47.30778448283672, 47.461649626493454, 49.96054373681545, 47.8052993863821, 54.39339727163315, 50.09159870445728, 50.51115699112415, 52.19961158931255, 53.656563609838486, 53.49042132496834, 50.66114254295826, 49.05447855591774, 49.0432121604681, 48.34267035126686, 47.556758522987366, 47.227924168109894, 48.081688955426216, 48.264915123581886, 48.68726626038551, 50.503219217062, 38.97226296365261, 37.99359127879143, 35.94185337424278, 39.23523545265198, 40.6461301445961, 18.634042404592037, 11.791905350983143, 9.11577545106411, 14.714549873024225, 44.23155315220356, 44.92142133414745, 41.76996923983097, 38.41069869697094, 35.78016445040703, 30.18768534064293, 25.68989899009466, 22.529302686452866, 23.2729284837842, 28.40018715709448, 34.370915070176125, 35.70220023393631, 28.06975308805704, 18.750046379864216, 11.346886530518532, 30.86485080420971, 33.368031084537506, 40.48121139407158, 34.56433609127998, 39.06356066465378, 52.14250065386295, 50.67534618079662, 51.36741824448109, 50.7302912324667, 46.6489340364933, 48.39316204190254, 46.38567276299, 49.80390094220638, 49.39795732498169, 49.210783168673515, 49.16822165250778, 46.58922404050827, 51.13913029432297, 50.809361189603806, 50.43020613491535, 46.72022581100464, 48.142649084329605, 45.34517079591751, 46.69014662504196, 47.98945650458336, 49.012034833431244, 45.00034309923649, 46.823211684823036, 45.06239756941795, 46.48784928023815, 45.301784723997116, 44.44088011980057, 43.61849784851074, 45.46552553772926, 44.63965505361557, 54.88298200070858, 56.488065272569656, 58.345390409231186, 55.113264843821526, 59.69380885362625, 57.92602591216564, 60.08336395025253, 55.124858021736145, 62.486871778964996, 59.18319225311279, 63.99453967809677, 58.49344186484814, 64.43907782435417, 55.14336682856083, 57.44211047887802, 52.3244234919548, 73.5536715388298, 55.21256871521473, 85.2312733232975, 13.142085950821638, 2.6189574552699924, 50.985280349850655, 48.0644416809082, 34.57426495850086, 10.536016691476107, 27.221868485212326, 13.776123728603125, 11.24907597899437, 25.3678035736084, 37.574485167860985, 28.18417824804783, 35.61072774231434, 37.33239255845547, 58.690841272473335, 52.91936136782169, 2.1633227169513702, 0.0523368849826511, 0.10675811397959478, 0.03290038242994342, 0.13580299098975956, 0.06988725261180662, 0.08963857791968621, 0.016567062775720842, 0.06527701640152372, 0.06675695534795523, 0.0409180301357992, 0.08515815818100236, 0.04679748359194491, 0.05742985485994723, 0.04739768439321779, 0.017705886530166026, 0.014116163674771087, 0.344189687166363, 0.026888038155448157, 1.5444314014166594, 58.71894456446171, 60.20578198134899, 43.14346633851528, 60.46190343797207, 58.258196488022804, 51.756524965167046, 34.538535475730896, 37.57627107203007, 30.932095795869827, 45.88013269007206, 65.90921893715858, 66.65900990366936, 34.783287942409515, 2.3396147321909666, 65.44553741812706, 67.92102098464966, 73.80394130945206, 64.55428004264832, 67.26804122328758, 64.57822635769844, 68.9788082242012, 58.79659719765186, 67.03503012657166, 62.52970688045025, 63.63701306283474, 60.88176570832729, 64.47756215929985, 61.49447903037071, 63.17324794828892, 59.09139297902584, 59.513322338461876, 59.45971481502056, 54.08419266343117, 47.965510189533234, 48.911689817905426, 48.84484000504017, 49.12667088210583, 53.51918198168278, 54.32944290339947, 52.360346764326096, 50.351823940873146, 51.0354870557785, 52.3231353610754, 50.334534868597984, 54.488133788108826, 51.21756188571453, 53.198726177215576, 52.13007912039757, 54.256422221660614, 55.454573929309845, 56.2161860615015, 54.262030720710754, 51.92358300089836, 52.24666826426983, 52.28231035172939, 54.34239260852337, 53.91129054129124, 53.57148237526417, 51.8423243612051, 51.601766869425774, 49.21151652932167, 53.420075699687004, 42.91446402668953, 38.646023869514465, 35.4972468316555, 40.10969392955303, 42.21053659915924, 24.2481841519475, 14.84957467764616, 12.413438949733973, 14.70608962699771, 41.57394915819168, 45.97984313964844, 43.93896505236626, 40.879388228058815, 36.039055958390236, 32.7843102067709, 29.186030589044094, 24.899157620966434, 28.799357637763023, 35.298304706811905, 37.48641349375248, 32.726914286613464, 24.550621323287487, 21.67466964572668, 14.749045372009277, 33.1602468341589, 36.326263546943665, 39.45826828479767, 38.31478424370289, 41.7975177615881, 54.66456972062588, 54.74897459149361, 55.22230379283428, 52.56028823554516, 50.791954323649406, 52.20055393874645, 52.172317653894424, 51.252045035362244, 54.685122817754745, 51.516719833016396, 52.83396854996681, 51.487624794244766, 53.42947639524937, 52.64295279979706, 52.32342794537544, 52.11931049823761, 51.77276149392128, 50.86218975484371, 50.390600860118866, 51.46464742720127, 49.47926916182041, 46.54501721262932, 47.72133149206638, 47.46294155716896, 50.114994049072266, 47.93556399643421, 48.5770645737648, 46.309954226017, 48.57948124408722, 46.790685430169106, 58.27440641820431, 57.51697786152363, 61.598369255661964, 54.52895499765873, 61.592213585972786, 60.23913659155369, 62.93879672884941, 59.233873933553696, 65.20840734243393, 59.93694260716438, 66.72698065638542, 60.14932841062546, 67.7209997177124, 57.325224950909615, 60.78495070338249, 56.10062286257744, 78.74978631734848, 56.644415482878685, 87.13109537959099, 12.649623826146126, 4.2657271027565, 58.67005258798599, 51.8815116584301, 37.22829334437847, 13.006436079740524, 29.294659160077572, 19.30065393447876, 18.824349492788315, 41.621013432741165, 36.879407465457916, 35.20888790488243, 38.974109664559364, 41.45513713359833, 63.62182527780533, 66.31353244185448, 7.402052683755755, 0.49661402532365173, 0.34332713345065713, 0.09721206879476085, 0.15685405436670408, 0.06341355037875473, 0.03564213569916319, 0.054878321461728774, 0.22402463830076158, 0.16700099426088855, 0.12742294144118205, 0.23351586103672162, 0.1609881137846969, 0.19290010764962062, 0.19238801090978086, 0.1666730095166713, 0.22230284084798768, 0.694851673906669, 0.1802363371825777, 1.6978847421705723, 68.06346774101257, 69.5771013200283, 53.38538736104965, 66.21333181858063, 68.99323984980583, 64.29903253912926, 30.704886987805367, 46.93296119570732, 35.48843130469322, 54.35081675648689, 73.0534815788269, 74.15769472718239, 29.454788267612457, 4.183898493647575, 78.9525206387043, 65.32413393259048, 80.93062609434128, 62.95143865048885, 71.81619957089424, 67.52952799201012, 75.6224325299263, 61.05840303003788, 67.40087449550629, 66.13666713237762, 65.836680829525, 63.43971244990826, 68.06076228618622, 66.05111092329025, 66.51431366801262, 64.40352693200111, 65.54273620247841, 63.19551855325699, 58.448361083865166, 51.59445606172085, 53.30469869077206, 51.28045231103897, 53.328793197870255, 56.21242046356201, 58.773547634482384, 56.26798488199711, 54.101880714297295, 54.670459404587746, 54.48969170451164, 52.96495892107487, 58.053961247205734, 53.87518867850304, 58.14989849925041, 54.60355259478092, 55.02210773527622, 58.15553739666939, 61.648431569337845, 58.64420637488365, 55.27988590300083, 56.14353395998478, 55.849323347210884, 57.720696330070496, 57.53175526857376, 56.47496737539768, 56.649655401706696, 55.9244567155838, 57.653439939022064, 57.52482444047928, 51.18150182068348, 43.60624350607395, 37.68123283982277, 40.75260803103447, 43.77602219581604, 28.27810350805521, 16.31046898663044, 14.553440418094397, 20.64216434955597, 47.67607592046261, 43.9701309800148, 46.252961084246635, 40.94308041036129, 40.69244585931301, 37.83600613474846, 33.889059126377106, 29.24604456871748, 32.61609323322773, 38.978304639458656, 41.693654134869576, 39.386182352900505, 32.75330387055874, 24.02684412896633, 19.878352135419846, 36.877336576581, 37.198582738637924, 39.9687784910202, 42.43876755237579, 46.033066883683205, 54.91100549697876, 58.02407205104828, 56.476342901587486, 55.60177803039551, 52.42560066282749, 53.881173357367516, 52.78270170092583, 54.32136073708534, 58.45694862306118, 55.21192654967308, 56.03753484785557, 53.39079447090626, 56.079112216830254, 56.96863308548927, 56.072622165083885, 53.09278406202793, 52.05265827476978, 52.22826585173607, 51.64036899805069, 56.01901464164257, 53.640243485569954, 49.90165449678898, 50.50207927823067, 50.54616071283817, 53.8471157848835, 51.62718750536442, 51.063521951437, 49.992549419403076, 52.61953465640545, 51.33679188787937, 60.99631056189537, 60.93166083097458, 64.4177457690239, 59.76500563323498, 64.21294435858727, 63.55487287044525, 65.58853894472122, 62.11595468223095, 68.9062625169754, 63.60726445913315, 71.08299851417542, 63.27276460826397, 72.64797493815422, 61.51477754116058, 62.8747321665287, 58.82884606719017, 79.8493181169033, 58.55811059474945, 92.3636882007122, 17.304003573954105, 3.254603259265423, 61.11598514020443, 61.4022009819746, 48.30539435148239, 20.610080771148205, 33.21722477674484, 17.897009253501892, 18.279496729373932, 38.19097548723221, 50.54951973259449, 40.65476328134537, 48.840599432587624, 50.33673495054245, 75.25760650634766, 77.89522737264633, 9.093398451805115, 0.5934559553861618, 0.35110362397972494, 0.23389275331282988, 0.3019266331102699, 0.24760176456766203, 0.2992926916340366, 0.17295965342782438], [0.07280188176082447, 0.041022865916602314, 0.08223127617384307, 0.12766486674081534, 0.04582692512485664, 0.06659428399871103, 0.02551602417952381, 0.05540542071685195, 0.035419509949861094, 0.13777639134787023, 0.18435325298924, 3.022659905254841, 63.50125774741173, 51.058426424860954, 46.26300774514675, 35.17932929098606, 36.88992150127888, 40.287262201309204, 29.261519238352776, 18.176723644137383, 23.079399168491364, 28.53864412754774, 60.34607045352459, 58.33489537239075, 70.97316160798073, 7.59167960844934, 16.052829511463642, 84.42276790738106, 55.287143513560295, 70.46889066696167, 58.62759746611118, 66.77662119269371, 61.56395450234413, 64.3298488855362, 64.43411529064178, 63.5368238389492, 58.6212670058012, 59.81162153184414, 54.254545122385025, 57.64565795660019, 58.018288761377335, 61.949721202254295, 58.82119707763195, 60.39745509624481, 50.21630801260471, 47.336761727929115, 43.0832851678133, 49.64752413332462, 48.050705417990685, 52.027860805392265, 52.504298239946365, 52.76933401823044, 49.08233106136322, 47.64946974813938, 48.36282826960087, 49.99592363834381, 50.24106748402119, 49.629414305090904, 48.73487390577793, 49.97924253344536, 49.67251539230347, 52.29704976081848, 51.88799411058426, 52.602937147021294, 50.305705815553665, 47.254241555929184, 46.26371830701828, 49.31743964552879, 44.05808486044407, 45.33355101943016, 44.57911290228367, 47.92369723320007, 45.98129466176033, 47.44442515075207, 34.68986235558987, 32.50692509114742, 37.172231152653694, 40.50063595175743, 40.494525879621506, 26.37467734515667, 24.096425995230675, 26.912048310041428, 37.52813905477524, 43.13724607229233, 40.40895827114582, 44.1141052544117, 39.243868589401245, 38.3288548886776, 38.50516922771931, 35.62927834689617, 29.817406609654427, 28.29767055809498, 31.420097909867764, 31.83310154825449, 34.25132028758526, 37.40789830684662, 32.36200466752052, 28.845122382044792, 30.75905118137598, 34.868927747011185, 35.88874742388725, 31.710987500846386, 38.18885900080204, 48.41742753982544, 47.33431465923786, 50.665709897875786, 47.572922855615616, 45.9143840521574, 47.76155233383179, 49.87733580172062, 50.3090800344944, 49.76402588188648, 46.97028659284115, 50.97051814198494, 49.67775151133537, 49.09366585314274, 50.01278333365917, 49.979702308773994, 45.61767317354679, 49.04959961771965, 45.714780762791634, 46.628236547112465, 44.34923283755779, 46.857048869132996, 45.62157176434994, 47.00981967151165, 47.358542159199715, 47.33725570142269, 45.559604689478874, 46.08822092413902, 45.28965197503567, 46.34302005171776, 43.14909003674984, 54.6735904365778, 55.43168395757675, 61.285589039325714, 55.85725352168083, 60.07771745324135, 58.015374317765236, 60.21188825368881, 60.13353645801544, 63.786630034446716, 59.31569114327431, 60.991579815745354, 58.87369126081467, 63.03963951766491, 53.954121842980385, 59.160032495856285, 53.08489568531513, 71.4094465970993, 56.536607667803764, 81.96676209568977, 4.586625583469868, 14.734623245894909, 53.54119420051575, 50.1721315830946, 29.259005673229694, 9.446480255573988, 23.908421583473682, 31.124196387827396, 30.39596166461706, 35.556983426213264, 37.821262925863266, 28.248208612203598, 30.388434268534184, 31.794147938489914, 47.49563880264759, 58.13248783349991, 17.228936702013016, 0.504191976506263, 0.20951419661287218, 0.13841097214026377, 0.12623146787518635, 0.05720976354496088, 0.13330633199075237, 0.08327716263011098, 0.07848704466596246, 0.04284551010641735, 0.07674414053326473, 0.05926314515818376, 0.007951796942506917, 0.07896719194832258, 0.10098206024849787, 0.17129883082816377, 0.04794824664713815, 0.12115717414417304, 0.09955379704479128, 4.253678424283862, 72.71938070654869, 56.03110559284687, 48.51019196212292, 39.75298807024956, 42.11004339158535, 40.03170691430569, 32.733381539583206, 26.748130805790424, 23.29040564596653, 31.246029250323772, 64.26715224981308, 61.12228900194168, 75.2924582362175, 14.208922404795885, 10.365764927119017, 86.27177909016609, 60.876708179712296, 73.37378919124603, 63.710497319698334, 70.49212262034416, 62.59342186152935, 65.49001783132553, 66.70906841754913, 67.1964530646801, 61.98652982711792, 64.54509973526001, 58.6377277225256, 59.28288370370865, 58.99669446051121, 61.750691682100296, 60.370446145534515, 62.46007941663265, 52.25082904100418, 49.00332950055599, 45.805189311504364, 52.173579186201096, 50.86068123579025, 57.00166471302509, 53.847419768571854, 55.09991995990276, 54.183781519532204, 51.16544768214226, 50.21551765501499, 51.902946308255196, 52.77474872767925, 54.822538644075394, 49.300933331251144, 50.09784936904907, 51.676372066140175, 54.09050792455673, 53.91908772289753, 54.50519487261772, 53.42801347374916, 51.45484775304794, 49.48812648653984, 53.224621787667274, 49.502527713775635, 50.09637124836445, 49.14197266101837, 51.94204621016979, 48.67669142782688, 49.9982301145792, 39.126147106289864, 34.23442639410496, 38.13740976154804, 39.9407359957695, 41.250316724181175, 29.23073709011078, 19.332446828484535, 23.971545696258545, 39.22826662659645, 45.82582600414753, 45.256198570132256, 41.577186584472656, 40.295606553554535, 40.80301992595196, 39.13770228624344, 37.7628942579031, 31.231713518500328, 29.73280794918537, 31.248261630535126, 33.04849103093147, 37.44734399020672, 38.180484250187874, 30.319239981472492, 27.092228941619396, 35.096839517354965, 34.86459977924824, 36.38788864016533, 36.09182372689247, 42.27242007851601, 54.72231902182102, 53.80996137857437, 53.91118414700031, 52.60033428668976, 51.051001623272896, 49.55082692205906, 54.06980283558369, 53.43899108469486, 53.12815636396408, 50.77905021607876, 53.269976153969765, 50.39570018649101, 51.701386123895645, 52.9097630828619, 52.63221077620983, 52.77672842144966, 52.28835582733154, 51.254001930356026, 53.128057569265366, 49.193444699048996, 48.58988508582115, 47.349289655685425, 48.653147891163826, 49.529582262039185, 50.93413129448891, 48.6868254840374, 49.91778843104839, 47.892861887812614, 47.20525458455086, 43.744624480605125, 56.70821025967598, 57.44117572903633, 64.15733814239502, 59.64204043149948, 60.797113850712776, 57.567173168063164, 61.819608584046364, 61.19839131832123, 65.11690825223923, 62.21009083092213, 64.40875545144081, 60.13139337301254, 66.4948283135891, 57.098369523882866, 62.853605300188065, 55.922659412026405, 73.77763152122498, 60.18216624855995, 82.65001103281975, 3.965146606788039, 20.81300888210535, 64.91640821099281, 54.31577883660793, 32.77960605919361, 12.360179107636213, 19.7602753713727, 29.718644209206104, 32.71355800330639, 43.997215926647186, 43.87519687414169, 30.483356975018978, 30.98444938659668, 33.40356297791004, 56.633190885186195, 67.76808679103851, 30.922556407749653, 0.6422433780971915, 0.2983338665217161, 0.09125269716605544, 0.14791610272368416, 0.1206170093792025, 0.1192548789549619, 0.0765044565196149, 0.23252242215676233, 0.12800235097529367, 0.20784708060091361, 0.18307122256373987, 0.12936811050167307, 0.11649359978036955, 0.18756167613901198, 0.3088339202804491, 0.17908151086885482, 0.3296486986801028, 0.32538805855438113, 5.04825996235013, 82.15967014431953, 65.434001237154, 57.65182502567768, 41.593590304255486, 51.028259843587875, 55.53101822733879, 38.23845013976097, 25.946368128061295, 35.63096545636654, 37.66432374715805, 74.48915854096413, 65.75506120920181, 80.91279745101929, 9.784274529665709, 17.956037186086178, 88.58712404966354, 61.02260895073414, 78.08593913912773, 63.9505760371685, 72.32239320874214, 66.39651998877525, 66.393563747406, 69.00045946240425, 70.2776925265789, 64.26829218864441, 67.21675157546997, 60.664326176047325, 64.10287946462631, 63.38834300637245, 66.95119142532349, 62.87440538406372, 67.41915911436081, 55.76923504471779, 51.28935903310776, 47.818936854600906, 55.21832920610905, 52.87461876869202, 57.182174026966095, 55.849057361483574, 59.45316396653652, 56.64775550365448, 51.26946710050106, 52.43578031659126, 54.300260469317436, 57.19318963587284, 58.35927106440067, 54.516594260931015, 54.10795658826828, 54.07798379659653, 56.95941098034382, 57.006270065903664, 60.54153576493263, 57.10211992263794, 55.65418861806393, 54.040620401501656, 57.9370529204607, 54.836115315556526, 55.7837350666523, 54.713678285479546, 56.065847128629684, 55.059163346886635, 52.66187198460102, 42.93968327343464, 37.92305946350098, 40.65819449722767, 41.28522165119648, 43.4172872453928, 29.734219573438168, 22.650329992175102, 28.32680929452181, 42.30213448405266, 45.2723591029644, 44.490794241428375, 43.25928032398224, 39.54882502555847, 40.71781329810619, 40.092940628528595, 39.799961149692535, 35.16498506069183, 34.3475691229105, 33.627351969480515, 33.71850147843361, 38.36481995880604, 38.564928621053696, 33.1165985763073, 35.12267433106899, 39.60687071084976, 38.47179941833019, 37.870105504989624, 38.67858052253723, 45.2796471118927, 55.1165896654129, 51.96610651910305, 58.002846390008926, 52.92378053069115, 52.55539409816265, 51.262395679950714, 55.905792117118835, 55.476190969347954, 55.03579460084438, 53.72945889830589, 56.68430954217911, 53.550754487514496, 53.22240650653839, 56.34765140712261, 56.036615297198296, 53.02952125668526, 53.84467251598835, 52.733623534440994, 55.3308829665184, 52.00359530746937, 52.250608652830124, 50.10499678552151, 52.01069712638855, 52.41656094789505, 52.98448607325554, 52.56079360842705, 52.37335346639156, 50.81535346806049, 51.635315269231796, 46.93057872354984, 60.95003664493561, 61.359267085790634, 68.67479413747787, 61.089466363191605, 65.50751209259033, 60.501998886466026, 65.50185039639473, 64.96832862496376, 68.16401794552803, 65.44038489460945, 66.73014968633652, 63.787435591220856, 68.55873316526413, 60.218423902988434, 66.03680849075317, 59.459528625011444, 76.25466540455818, 62.684844955801964, 90.3558075428009, 6.293180510401726, 17.484837770462036, 71.09101608395576, 61.29082515835762, 42.3660584539175, 19.206797070801258, 31.354258842766285, 42.99102231860161, 42.1639396995306, 50.78513368964195, 53.83627496659756, 41.68219015002251, 40.95903195440769, 45.225781202316284, 66.92146182060242, 75.58508813381195, 36.07600137591362, 0.9853062476031482, 0.5017558916006237, 0.29021803638897836, 0.2072720052092336, 0.31970685871783644, 0.3426901629427448, 0.17312626558123156], [0.032328780289390124, 0.06434182869270444, 0.07866633270168677, 0.14175332325976342, 0.0444295909255743, 0.028451053112803493, 0.017309618633589707, 0.06567314514541067, 0.14810005144681782, 0.014364682028826792, 0.05578551907092333, 1.6240949579514563, 52.436498478055, 51.283336356282234, 41.84643253684044, 24.78042919188738, 36.19001045823097, 50.60028500854969, 35.17443895339966, 33.09880033135414, 16.176186092197895, 22.14590135961771, 50.123251006007195, 59.07183162868023, 57.14269034564495, 62.189997509121895, 1.9347311393357813, 36.04149542748928, 78.97122323513031, 58.90199974179268, 67.60439917445183, 61.32223427295685, 59.44872960448265, 67.23876759409904, 67.29591652750969, 60.667404010891914, 59.45425070822239, 53.66131715476513, 55.68196892738342, 55.705508664250374, 59.648021310567856, 58.03001493215561, 59.79945458471775, 55.85514843463898, 49.66659910976887, 46.68626703321934, 44.23441059887409, 49.41281832754612, 48.86224687099457, 55.47667354345322, 53.768596798181534, 54.48575131595135, 51.27055004239082, 49.886664301157, 48.46363306045532, 52.926273196935654, 51.39888435602188, 50.40198504924774, 50.56099131703377, 49.777868539094925, 52.33097814023495, 52.901517525315285, 53.69095556437969, 51.50067329406738, 50.30448228120804, 48.52405361831188, 45.58056056499481, 48.17014440894127, 43.45631495118141, 42.3146016150713, 42.20468491315842, 43.03190432488918, 43.206067979335785, 45.65891616046429, 30.22730391472578, 27.34391413629055, 35.20162649452686, 35.954502895474434, 38.40065963566303, 47.63757258653641, 66.91325426101685, 68.60520467162132, 45.510108545422554, 39.67500865459442, 44.354886934161186, 44.513577818870544, 40.12845352292061, 42.49263346195221, 44.57856573164463, 42.82588317990303, 37.428861781954765, 31.62769977003336, 34.807108864188194, 37.93027527630329, 36.74178645014763, 36.332533210515976, 38.15354369580746, 33.39736931025982, 34.543790593743324, 37.532801404595375, 35.3985471278429, 37.349465042352676, 33.54953594505787, 41.35123550891876, 47.477145195007324, 47.83955454826355, 48.344182670116425, 45.97353547811508, 44.95910011231899, 46.63359045982361, 48.759067207574844, 46.81298643350601, 47.89136856794357, 48.845375776290894, 47.53055892884731, 49.47685249149799, 47.43757411837578, 51.63268581032753, 47.83756725490093, 48.368486166000366, 49.14905168116093, 45.990782752633095, 46.066364496946335, 46.19361586868763, 47.102264910936356, 46.77603341639042, 47.922960072755814, 48.86909030377865, 46.46418794989586, 47.29608491063118, 47.40511246025562, 48.913639113307, 43.84670600295067, 48.796077221632004, 57.044887393713, 56.50915414094925, 55.95567964017391, 53.57148237526417, 58.04065816104412, 59.53111678361893, 60.77281415462494, 64.67493876814842, 62.65048339962959, 62.287994250655174, 58.61681744456291, 64.94844049215317, 54.78300556540489, 57.98186011612415, 56.65915489196777, 69.8975533246994, 62.24198631942272, 61.028772220015526, 1.1024381686002016, 37.420209646224976, 41.875276789069176, 54.59772750735283, 23.334124200046062, 6.351716369390488, 27.620024420320988, 29.776524603366852, 31.14868227392435, 43.998431861400604, 37.54708103835583, 30.998463034629822, 44.64121676981449, 43.554889261722565, 48.79619501531124, 64.44285482168198, 38.441461846232414, 0.8511022583115846, 0.3135616681538522, 0.06357655569445342, 0.14470436959527433, 0.029803199795424007, 0.07571869282401167, 0.027894720660697203, 0.0819279307324905, 0.1643237707321532, 0.17347172048175707, 0.17166485806228593, 0.01900473958812654, 0.0393252179492265, 0.03052312385989353, 0.011829589984699851, 0.17122887598816305, 0.05448046351375524, 0.11953331792028621, 2.7830656617879868, 65.40117099881172, 56.09692566096783, 48.41566823422909, 29.37915712594986, 40.240357518196106, 51.83372542262077, 26.834433674812317, 43.34947608411312, 25.72066403925419, 22.592932172119617, 57.61922277510166, 68.16467151045799, 58.19081470370293, 71.73708021640778, 4.813652951270342, 22.791940793395042, 85.76428592205048, 64.83482658863068, 76.0785448551178, 64.68969717621803, 64.6774922311306, 66.20377913117409, 70.08874386548996, 62.26533226668835, 63.32789205014706, 58.52223291993141, 60.48766605556011, 58.466900289058685, 61.11409284174442, 57.46277756989002, 59.670196920633316, 56.811184734106064, 50.48089921474457, 49.634912610054016, 50.464320704340935, 53.19743424654007, 54.39396724104881, 55.43578013777733, 55.30750662088394, 54.15309436619282, 54.513892605900764, 52.360149174928665, 52.000437676906586, 53.68998281657696, 53.81506830453873, 55.50680212676525, 53.29975515604019, 50.84743894636631, 52.92675197124481, 51.240117475390434, 54.745987951755524, 51.90882459282875, 53.2243862003088, 51.0294833779335, 48.998127579689026, 49.97318185865879, 50.52328214049339, 48.859302029013634, 48.536653742194176, 47.41299703717232, 44.3732475489378, 49.452697187662125, 34.4281779974699, 32.364622727036476, 37.18521125614643, 35.142262279987335, 38.91685053706169, 44.6401110291481, 59.6920495480299, 50.157509967684746, 43.403923362493515, 41.81174419820309, 46.397186145186424, 45.61058655381203, 41.05960115790367, 41.562272384762764, 45.76156385242939, 42.856072559952736, 35.26798613369465, 31.34643316268921, 36.72779940068722, 37.511955723166466, 36.00164316594601, 36.19477540254593, 39.84253406524658, 33.536799028515816, 35.70277400314808, 39.51526902616024, 35.82191661000252, 42.015994638204575, 40.2655653655529, 45.0073005259037, 51.935951337218285, 52.32934042811394, 51.58296927809715, 51.86225429177284, 51.999742314219475, 46.81061536073685, 50.50079494714737, 52.112128883600235, 50.96142902970314, 49.892390593886375, 49.492332860827446, 50.35017102956772, 50.22910572588444, 54.00272883474827, 53.95068682730198, 53.79530556499958, 51.907791048288345, 52.06906579434872, 51.31061129271984, 52.41416707634926, 48.48437614738941, 48.27184975147247, 48.486188650131226, 53.31781178712845, 50.225948095321655, 51.73159450292587, 47.59553924202919, 48.75617176294327, 43.143736124038696, 49.35599237680435, 59.03819963335991, 62.102951779961586, 60.489710345864296, 53.1170267611742, 56.746675595641136, 58.796650394797325, 57.3003438860178, 60.002732276916504, 60.8051086217165, 65.97653612494469, 60.73373705148697, 62.453581765294075, 60.443850606679916, 64.68980357050896, 62.851393818855286, 70.63067838549614, 64.0203782916069, 58.07549849152565, 1.895012108143419, 48.2286536693573, 48.683375269174576, 63.120320588350296, 25.406861677765846, 8.480539787560701, 20.31160868704319, 29.911383166909218, 29.638322219252586, 46.65255904197693, 47.36246354877949, 33.63689325749874, 55.459221079945564, 49.91769343614578, 61.59717991948128, 66.45930022001266, 53.24576385319233, 1.3766166125424206, 0.3965007676742971, 0.028771644210792147, 0.10009982477640733, 0.0349737723445287, 0.060396519693313166, 0.05113770050229505, 0.21233135950751603, 0.2332632488105446, 0.3317017463268712, 0.17740615701768547, 0.0688603799790144, 0.12670130672631785, 0.10123808635398746, 0.22042237222194672, 0.26106564444489777, 0.27621789544355124, 0.33177504083141685, 4.393329955637455, 76.9266365468502, 65.34257054328918, 54.62913662195206, 31.244402937591076, 52.279798686504364, 69.76254656910896, 52.90951229631901, 38.73376876115799, 26.272937804460526, 34.591117054224014, 63.597107604146004, 70.11459767818451, 68.3589018881321, 71.08094662427902, 3.6936454754322767, 40.554175078868866, 85.126573741436, 63.16812962293625, 76.47864818572998, 67.59672358632088, 63.63004043698311, 70.69827675819397, 73.11862528324127, 66.07360571622849, 67.24033311009407, 60.161107778549194, 63.12856614589691, 63.82868617773056, 64.61427882313728, 60.753241404891014, 63.65500129759312, 58.30361545085907, 52.940267845988274, 51.233008056879044, 51.76389656960964, 57.91848711669445, 57.341347485780716, 60.75104892253876, 58.40904839336872, 57.76356942951679, 58.29763077199459, 53.935692831873894, 55.259883776307106, 58.78940798342228, 57.85449855029583, 58.23646165430546, 56.3912046700716, 53.314532563090324, 57.403105571866035, 53.697020038962364, 59.10295955836773, 55.56565336883068, 56.578025445342064, 54.74861741065979, 52.930597364902496, 56.09721064567566, 53.36575001478195, 51.40347070991993, 51.54526770114899, 51.440047547221184, 48.84937696158886, 57.664193361997604, 40.82066237926483, 35.030920654535294, 38.565802574157715, 39.818773940205574, 38.47803868353367, 46.266784742474556, 55.5727019906044, 45.173043832182884, 41.279491558671, 42.725283578038216, 45.73506407439709, 48.88055808842182, 40.52450247108936, 44.329880475997925, 52.88414865732193, 45.053205862641335, 38.100015968084335, 32.5950613617897, 36.932897195219994, 40.42355328798294, 38.60692396759987, 35.88894121348858, 42.70733714103699, 36.11597903072834, 37.06496670842171, 41.72518104314804, 37.2456394135952, 44.63491290807724, 41.965282559394836, 46.62387818098068, 54.93279352784157, 53.92367407679558, 52.80430354177952, 53.680821508169174, 51.32079094648361, 52.36254304647446, 55.04758156836033, 54.26579251885414, 54.68584857881069, 53.55738893151283, 54.73381720483303, 52.931573912501335, 52.89729595184326, 56.90244063735008, 55.87231211364269, 57.920102030038834, 54.93632733821869, 52.417104318737984, 53.685487657785416, 53.94827015697956, 53.07831823825836, 52.348084822297096, 51.15057148039341, 54.622912555933, 53.77499185502529, 56.19072362780571, 52.45392434298992, 52.30114594101906, 46.234068498015404, 54.45405721664429, 63.526894971728325, 64.44138050079346, 62.22818545997143, 54.22052934765816, 62.515674233436584, 61.384151950478554, 62.77178429067135, 65.13092949986458, 65.41355073451996, 65.90096578001976, 63.535942286252975, 69.79589357972145, 61.15327253937721, 66.6480740904808, 64.37499046325684, 74.48546513915062, 65.93827217817307, 68.2028366625309, 2.9890279099345207, 42.67253860831261, 59.31542135775089, 66.71694159507751, 34.7537749260664, 13.695330563932657, 35.9637364000082, 40.69433815777302, 41.091614440083504, 59.47027064859867, 53.750357776880264, 43.41223731637001, 65.2315405011177, 54.66470651328564, 67.78197884559631, 76.62888452410698, 61.750357300043106, 2.099325838498771, 0.37843796191737056, 0.09778831677976996, 0.29381855099927634, 0.10246619232930243, 0.2548866713186726, 0.17649147484917194], [0.14340206369524822, 0.013307730150700081, 0.09046173101523891, 0.09932813220075332, 0.05825270738569088, 0.03701426656334661, 0.0567943872010801, 0.14592998195439577, 0.20932192099280655, 0.06411109498003498, 0.15193924074992537, 3.9454558258876204, 57.319840639829636, 50.947970151901245, 40.15654921531677, 33.56350779533386, 41.708427742123604, 40.67367486655712, 37.024609073996544, 26.537441611289978, 12.260824888944626, 9.195155091583729, 32.7874868363142, 72.18820720911026, 49.72174935042858, 64.34406012296677, 34.88635741174221, 0.7393925869837403, 35.89683338999748, 70.3565838932991, 64.78602960705757, 60.617197304964066, 63.31350602209568, 66.32827565073967, 63.81547808647156, 60.12274503707886, 55.53260654211044, 53.78276623785496, 53.12287084758282, 57.75615982711315, 55.53732588887215, 55.088824555277824, 59.852127358317375, 57.28663042187691, 45.84497317671776, 45.42867511510849, 47.48194433748722, 47.49735631048679, 51.07948109507561, 50.478307753801346, 53.37691381573677, 53.43615643680096, 55.7167674601078, 52.670520320534706, 51.13973826169968, 49.922059401869774, 52.3775864392519, 52.14808635413647, 50.04578076303005, 50.4490265250206, 48.67664963006973, 48.35952624678612, 52.421436086297035, 47.9837454110384, 49.01110768318176, 49.33989264070988, 48.553984612226486, 45.72939857840538, 44.644864574074745, 43.643093928694725, 41.0291837900877, 38.552545085549355, 37.1356201171875, 33.40602524578571, 20.7606153935194, 27.968131341040134, 31.50701444596052, 30.191040560603142, 36.42243638634682, 52.20737837255001, 75.72727650403976, 102.80925929546356, 77.97667220234871, 39.41571816802025, 41.804000213742256, 41.299786269664764, 43.14354233443737, 43.70321810245514, 47.511282563209534, 42.52644404768944, 42.23808512091637, 43.202602565288544, 35.86894288659096, 36.90428093075752, 36.296621337533, 36.882390305399895, 47.28347718715668, 49.78079438209534, 32.60062426328659, 23.2380710542202, 16.971048340201378, 23.050564415752888, 34.26330104470253, 36.05473771691322, 43.75089414417744, 43.077756464481354, 47.61744886636734, 47.13839337229729, 45.6827636808157, 44.642299711704254, 46.7106731235981, 46.3496582955122, 46.94209210574627, 45.554193779826164, 47.10749343037605, 48.28586719930172, 50.886409655213356, 46.63967773318291, 53.83406348526478, 46.58696696162224, 50.010283067822456, 49.48006331920624, 47.30625316500664, 46.84241585433483, 47.6358512789011, 46.98649652302265, 48.244726806879044, 51.74314588308334, 52.86565504968166, 48.00532445311546, 48.76441352069378, 43.49696137011051, 46.43579587340355, 41.45919531583786, 51.937083676457405, 60.712260603904724, 57.97119788825512, 54.40782509744167, 54.087080508470535, 55.63525803387165, 58.123634308576584, 57.652136608958244, 62.68256887793541, 62.28708989918232, 64.17422443628311, 58.38492348790169, 61.63429632782936, 53.615761399269104, 63.276792392134666, 56.66360825300217, 79.71415936946869, 24.281172081828117, 4.3238345347344875, 45.01576267182827, 36.48079365491867, 69.37553733587265, 14.06980711966753, 7.8458137717098, 28.59154488891363, 23.280113898217678, 36.61474786698818, 37.59308136999607, 44.919544234871864, 29.91397462785244, 29.982665441930294, 22.540637478232384, 38.89232665300369, 63.447239845991135, 57.013010904192924, 1.6524292062968016, 0.2395471467752941, 0.13598587102023885, 0.1096184401831124, 0.018551680695964023, 0.04265297844540328, 0.019686958839884028, 0.08045001784921624, 0.013413938904704992, 0.08018209511647001, 0.18013708235230297, 0.09339296200778335, 0.06986433509155177, 0.1137546073005069, 0.045110196006135084, 0.08523801327100955, 0.11127602701890282, 0.11704488191753626, 6.256322963163257, 75.22264078259468, 53.92466202378273, 48.54277141392231, 25.786235220730305, 45.42196847498417, 45.21124318242073, 29.44328248500824, 23.486815206706524, 25.79760041087866, 18.292982205748558, 31.731816083192825, 77.1124617755413, 60.30524164438248, 62.28882260620594, 44.5691954344511, 1.0188386170193553, 21.926259845495224, 64.2781412601471, 66.08517989516258, 69.51564341783524, 70.19875556230545, 68.8752181828022, 63.970524966716766, 65.03332033753395, 60.840340331196785, 62.78925955295563, 59.64724615216255, 61.184016689658165, 57.91774995625019, 58.732559233903885, 59.65785138309002, 56.46935127675533, 49.67174023389816, 48.67671802639961, 51.319643408060074, 55.703129991889, 57.114404663443565, 52.59898915886879, 54.84967678785324, 53.58019530773163, 54.2063295096159, 54.80448201298714, 54.61916595697403, 51.119618341326714, 54.197392389178276, 54.44205746054649, 55.503245517611504, 52.097826451063156, 49.23885226249695, 49.80310298502445, 50.424472242593765, 50.66730201244354, 49.35435466468334, 52.25089743733406, 51.70753799378872, 49.58500608801842, 48.95372696220875, 50.889590084552765, 47.36865721642971, 43.248120322823524, 40.816839784383774, 37.43410550057888, 30.636283569037914, 34.96962994337082, 37.02217720448971, 34.55481380224228, 42.308537140488625, 55.54142206907272, 77.3198090493679, 96.82708829641342, 53.98382864892483, 42.26124107837677, 41.46150179207325, 41.40604376792908, 39.906131252646446, 43.316026479005814, 50.947711765766144, 46.06804400682449, 44.14807163178921, 40.19969969987869, 33.200900852680206, 36.681635677814484, 37.7479762583971, 36.42320014536381, 38.15474823117256, 43.35180155932903, 33.376785814762115, 26.81130811572075, 17.98214938491583, 24.693128876388073, 43.74538443982601, 41.95390596985817, 50.45705549418926, 47.6457953453064, 52.51490347087383, 55.39397098124027, 51.87230095267296, 48.912795558571815, 49.46752019226551, 50.55325873196125, 52.61070393025875, 48.57966363430023, 50.2577143907547, 50.30655317008495, 52.0106515288353, 49.99271281063557, 54.46347691118717, 53.71030032634735, 52.34629511833191, 54.34084989130497, 53.39999757707119, 50.35719305276871, 50.264132246375084, 47.42692328989506, 51.05182617902756, 53.336312994360924, 57.019493356347084, 53.2741255313158, 48.05194795131683, 43.52448329329491, 46.07960678637028, 41.55257910490036, 55.41170462965965, 62.3556762188673, 65.37557557225227, 57.614929005503654, 57.23734326660633, 57.4654146283865, 56.58604681491852, 57.552768141031265, 62.30347461998463, 61.93524777889252, 68.37677612900734, 60.35359784960747, 65.13434171676636, 60.458761006593704, 72.72571876645088, 58.60886827111244, 80.6070126593113, 20.492182597517967, 7.026565382257104, 50.59689559042454, 38.46856199204922, 76.89101725816727, 13.902065120637417, 9.510866850614548, 26.5800354257226, 26.012575775384903, 36.64059028029442, 40.03353841602802, 53.64432826638222, 36.72733962535858, 40.15857070684433, 27.222689241170883, 47.67082080245018, 63.75107914209366, 71.40535041689873, 3.68018327280879, 0.384294367977418, 0.14461553451837972, 0.05250760121271014, 0.01755200035404414, 0.041522706087562256, 0.034522542846389115, 0.272166125359945, 0.16464553627884015, 0.15848480514250696, 0.1804078178247437, 0.14607247430831194, 0.13486473821103573, 0.14254960318794474, 0.21256972249830142, 0.23369615839328617, 0.2840219938661903, 0.2655393403256312, 6.160925282165408, 82.08406180143356, 61.85552425682545, 55.36131173372269, 41.39218971133232, 60.96894063055515, 55.75470842421055, 53.18930648267269, 34.400971457362175, 16.82171445339918, 21.645774096250534, 43.98931235074997, 81.68177738785744, 60.79516835510731, 73.92184898257256, 40.581666603684425, 1.205672810319811, 41.1235099285841, 75.5068351328373, 71.11064583063126, 66.04272097349167, 71.33662730455399, 69.73803788423538, 68.45378279685974, 68.85322496294975, 63.9847894012928, 65.05165055394173, 61.90004266798496, 62.70237721502781, 59.738566651940346, 58.83174151182175, 63.00425961613655, 62.318992987275124, 51.353302001953125, 49.383890479803085, 53.72907131910324, 57.03362479805946, 58.98045793175697, 55.65969452261925, 58.18394847214222, 56.33944384753704, 57.4517847597599, 57.0221646130085, 56.79923437535763, 53.908870071172714, 57.72254303097725, 56.95206597447395, 58.20932351052761, 55.379531756043434, 53.11071529984474, 53.5927764326334, 55.50679072737694, 54.855520874261856, 54.15816329419613, 55.818753987550735, 55.49671746790409, 54.05141182243824, 52.99478732049465, 57.53509908914566, 52.060387060046196, 49.86628219485283, 48.382393419742584, 45.83863131701946, 39.15480896830559, 41.394165605306625, 39.84755739569664, 36.17096967995167, 47.32546113431454, 60.66818296909332, 79.04712036252022, 83.8384960591793, 44.92022439837456, 41.292642652988434, 39.9009445309639, 41.41256421804428, 41.96158915758133, 42.32028990983963, 51.408079862594604, 43.05468790233135, 44.083919674158096, 42.7301587164402, 35.603135749697685, 35.60701534152031, 37.07643449306488, 40.49891084432602, 36.785191521048546, 43.23067165911198, 37.409866601228714, 29.403624013066292, 21.944878846406937, 29.887104369699955, 46.48382909595966, 41.2263248115778, 50.34594185650349, 49.540867656469345, 54.9678960442543, 58.0528175085783, 52.95596860349178, 52.203377187252045, 53.9399866014719, 53.453126326203346, 54.85182747244835, 50.85666865110397, 54.22664701938629, 54.79644924402237, 56.61793850362301, 53.73292811214924, 58.49755324423313, 55.26895008981228, 57.29273669421673, 58.32603804767132, 57.31521248817444, 52.109290435910225, 51.90008506178856, 52.215004563331604, 54.550062865018845, 56.980066671967506, 60.19818998873234, 52.83217504620552, 54.58049163222313, 47.01113060116768, 50.03905892372131, 46.43075734376907, 58.83184410631657, 64.8929026722908, 68.3547069132328, 60.27703955769539, 59.646725580096245, 60.38232050836086, 63.22137236595154, 61.49639792740345, 67.2769783437252, 65.54975062608719, 69.99141588807106, 62.318787798285484, 68.19009214639664, 62.194070890545845, 72.81841099262238, 60.78364737331867, 82.38040030002594, 30.026059113442898, 6.9977520033717155, 56.76974415779114, 48.042277470231056, 82.36555069684982, 23.108828589320183, 17.323093749582767, 35.93624107539654, 32.288638204336166, 49.71639923751354, 54.54723961651325, 64.66911748051643, 37.7298778295517, 46.18184030056, 31.970169693231583, 57.11296074092388, 77.06499472260475, 82.86969244480133, 4.868135377764702, 0.675524485995993, 0.24820847029332072, 0.1901418119086884, 0.11741473121219315, 0.18788075511110947, 0.15882055275142193], [0.07766917566186748, 0.0843236650689505, 0.12172800445114262, 0.21470225416123867, 0.10967734444420785, 0.0652318270294927, 0.08418480181717314, 0.2812627184903249, 0.021128140979271848, 0.04678599514591042, 0.27510600979439914, 5.985040320083499, 69.43916112184525, 45.1786333322525, 47.93476223945618, 31.93160556256771, 36.38269051909447, 48.08170795440674, 26.44490137696266, 37.8776329010725, 17.428063116967678, 6.252071466296911, 10.154017489403486, 43.9660120010376, 65.89677840471268, 52.600547075271606, 65.64216926693916, 11.750297583639622, 0.12473501614294946, 12.348197400569916, 44.63919907808304, 68.78784567117691, 64.35927450656891, 66.87444314360619, 59.61229182779789, 57.63639785349369, 54.28889907896519, 53.254712373018265, 56.379569694399834, 60.144061893224716, 56.65297642350197, 57.342194840312004, 58.57706017792225, 51.78911201655865, 46.6467909514904, 43.70389066636562, 48.960695788264275, 52.03036867082119, 53.90494108200073, 53.96933242678642, 52.58317820727825, 54.795879274606705, 58.01044598221779, 54.19714540243149, 50.46123906970024, 51.94752171635628, 51.36824660003185, 51.16818353533745, 50.01893140375614, 51.314593479037285, 50.19535593688488, 51.22665099799633, 47.60215848684311, 48.79455350339413, 48.75807166099548, 48.26073914766312, 47.0515376329422, 45.96268706023693, 45.21046422421932, 40.75399875640869, 36.23109005391598, 30.16903594136238, 26.759571991860867, 13.99892097339034, 6.23471399769187, 12.487224340438843, 11.91180981695652, 14.918360486626625, 23.278852365911007, 38.58089156448841, 46.722984462976456, 49.683550000190735, 92.97447502613068, 53.569232895970345, 35.01753777265549, 37.794155180454254, 39.18292745947838, 40.84773972630501, 38.78665432333946, 36.4827049523592, 38.83721821010113, 41.400784850120544, 40.51729805767536, 36.50453858077526, 34.53141085803509, 56.334181129932404, 75.57069450616837, 49.39156986773014, 38.493899032473564, 21.586578972637653, 11.019515097141266, 5.866180323064327, 11.416209060698748, 20.763412043452263, 35.764357298612595, 39.78541173040867, 43.44079278409481, 44.16908450424671, 44.790924936532974, 47.23731346428394, 43.22142295539379, 47.41605207324028, 47.894997373223305, 47.83855140209198, 47.41540610790253, 47.74207077920437, 49.18644167482853, 47.56764113903046, 48.081764951348305, 49.29014950990677, 46.56067997217178, 45.70827171206474, 53.61182101070881, 49.43926490843296, 47.933044731616974, 45.09226776659489, 53.13315689563751, 50.62549665570259, 52.28666491806507, 50.572694689035416, 49.30391617119312, 46.54771126806736, 43.716042414307594, 38.70014816522598, 44.60213966667652, 53.933139368891716, 62.72614113986492, 56.31468437612057, 58.55675406754017, 50.87293937802315, 57.55285553634167, 50.470005199313164, 62.68248908221722, 60.239930748939514, 66.64348393678665, 57.21504606306553, 62.055040150880814, 54.38177369534969, 66.56885594129562, 56.94590650498867, 73.6719211935997, 3.1373339518904686, 17.090903408825397, 52.94281750917435, 50.16864717006683, 52.459202259778976, 5.577229578047991, 6.832676036283374, 18.653508760035038, 27.407211139798164, 30.562502928078175, 34.57493372261524, 40.88230647146702, 28.179225213825703, 31.300653219223022, 29.71412245184183, 36.306694597005844, 55.974120050668716, 57.818092703819275, 5.158056020736694, 0.23986426647752523, 0.20201509119942784, 0.1703311296296306, 0.17709797277348116, 0.11102013449999504, 0.041637931935838424, 0.08661235944600776, 0.03640363858721685, 0.12209368287585676, 0.14066557225305587, 0.14293060696218163, 0.04996295494493097, 0.10673528551706113, 0.20961422327673063, 0.05044863864895888, 0.15039983351016417, 0.42879942047875375, 7.259978782385588, 79.65498894453049, 53.09817597270012, 45.20506091415882, 25.850265584886074, 42.88836322724819, 53.21536548435688, 14.830367658287287, 16.622363850474358, 17.32654396444559, 16.74513716250658, 13.189730644226074, 40.43234221637249, 76.60543218255043, 59.56684626638889, 71.17200493812561, 16.455786488950253, 0.29176360345445573, 8.052296116948128, 44.666705802083015, 72.34298050403595, 70.06915971636772, 69.97905895113945, 61.18772529065609, 60.33039629459381, 60.99648915231228, 64.59695935249329, 63.918756544589996, 62.00957179069519, 61.44002415239811, 59.390782713890076, 60.4417759180069, 52.06351049244404, 51.540042981505394, 49.093251675367355, 53.45455504953861, 59.01831530034542, 57.70748443901539, 61.55601292848587, 56.68371297419071, 54.01626370847225, 57.334735840559006, 56.53038740158081, 53.76519978046417, 55.137815326452255, 52.01480470597744, 51.996630281209946, 54.10992108285427, 54.27807725965977, 54.049777910113335, 55.36083675920963, 51.814502254128456, 53.25383082032204, 50.57039201259613, 50.63106335699558, 51.12008951604366, 49.807024374604225, 49.33984324336052, 47.862034142017365, 45.58199308812618, 36.804760470986366, 28.725198917090893, 15.520249139517546, 10.540420655161142, 15.77102143317461, 11.79978707805276, 14.218395296484232, 30.847749821841717, 49.29731972515583, 60.67109361290932, 72.38367632031441, 95.23013278841972, 44.13481794297695, 39.23496186733246, 41.456866040825844, 39.92971658706665, 40.59260621666908, 38.94372269511223, 37.595802024006844, 38.29157508909702, 38.106464222073555, 38.44671316444874, 37.45810881257057, 32.33007498085499, 41.71113319694996, 60.234478041529655, 51.58032841980457, 42.344297021627426, 24.559303857386112, 13.168425187468529, 8.343122061342001, 14.635613858699799, 25.17959777265787, 39.78365622460842, 45.321334674954414, 47.29945532977581, 49.96824212372303, 49.82774846255779, 49.23417471349239, 49.34307686984539, 52.91609354317188, 53.062697276473045, 51.01657547056675, 49.99482549726963, 52.25760407745838, 51.15766949951649, 50.416728258132935, 51.4665587246418, 50.30888244509697, 49.12660248577595, 50.152714625000954, 56.88340745866299, 53.54630872607231, 52.429761439561844, 51.38272002339363, 53.70949476957321, 54.36616413295269, 57.4918270111084, 53.4567741304636, 50.78908167779446, 46.403660997748375, 44.15239579975605, 43.43806453049183, 48.09193320572376, 53.17325994372368, 66.41082242131233, 62.08252027630806, 62.048911079764366, 53.194299414753914, 57.895141169428825, 53.479458913207054, 62.37652190029621, 60.745413824915886, 66.10550120472908, 61.707077622413635, 66.39865547418594, 64.74285632371902, 70.78762516379356, 62.314114049077034, 64.54608008265495, 2.3357562767341733, 23.34867361932993, 61.17629550397396, 59.1747111082077, 55.78482560813427, 4.793213848024607, 13.182088304311037, 21.769791841506958, 23.380468413233757, 27.983678206801414, 39.027971774339676, 48.92687380313873, 31.662462204694748, 37.09438093006611, 28.98101259022951, 41.88077889382839, 59.380295276641846, 64.17278811335564, 8.445474319159985, 0.30482712434604764, 0.1593140364275314, 0.0766868467326276, 0.07144301678636111, 0.16797117423266172, 0.01502906932728365, 0.2921845199307427, 0.20264075137674809, 0.2534963912330568, 0.27936994505580515, 0.2657337236450985, 0.19191498082363978, 0.15312773088226095, 0.38449445099104196, 0.13186603115173057, 0.24682227201992646, 0.4683770873816684, 10.2296201325953, 93.91940832138062, 59.84596028923988, 62.38060288131237, 40.89812882244587, 51.13228686153889, 67.70718365907669, 34.78584140539169, 54.443550780415535, 25.52263956516981, 14.285295456647873, 23.74527543783188, 54.22060154378414, 81.88426852226257, 63.85474517941475, 78.89268904924393, 13.591005261987448, 0.3122908144723624, 21.35158058255911, 49.88026164472103, 72.90844336152077, 70.13694047927856, 71.7388965189457, 63.16059082746506, 63.468017131090164, 65.75534999370575, 65.23889690637589, 66.18909671902657, 65.15639573335648, 60.94603545963764, 62.848889753222466, 63.134999200701714, 56.29527121782303, 55.724796429276466, 51.37028709053993, 56.13225616514683, 62.762725576758385, 59.816093891859055, 61.940613090991974, 59.98135842382908, 58.848753198981285, 63.07267114520073, 58.69057148694992, 55.1179575920105, 57.03496992588043, 54.42794881761074, 56.805405244231224, 54.62314814329147, 55.13004094362259, 54.468169659376144, 55.665523409843445, 53.22651408612728, 53.405917659401894, 54.02919441461563, 54.88961264491081, 52.204646319150925, 50.86610734462738, 55.61286963522434, 51.04085236787796, 52.987525910139084, 42.473927065730095, 39.29252117872238, 30.95786791294813, 26.74515936523676, 30.80449104309082, 21.710330732166767, 20.220706164836884, 37.38654725253582, 53.928009644150734, 68.10886010527611, 77.46297016739845, 83.96264299750328, 39.825446382164955, 43.03973950445652, 40.80071344971657, 42.444961220026016, 39.3686006963253, 39.07826967537403, 35.26208125054836, 37.58308030664921, 37.69442953169346, 40.77642895281315, 36.30959004163742, 34.51496534049511, 41.562830954790115, 60.74046649038792, 50.75617544353008, 48.84484000504017, 28.043827079236507, 16.435793861746788, 12.366229332983494, 20.55466264486313, 33.95749345421791, 45.08621849119663, 46.83883264660835, 50.835815370082855, 52.19794347882271, 53.43432493507862, 51.18071526288986, 53.6147278547287, 56.19255132973194, 54.91876468062401, 54.029274210333824, 52.40325406193733, 54.150932282209396, 55.1177904009819, 53.366806358098984, 55.09964257478714, 55.77301204204559, 51.66135147213936, 51.83921992778778, 60.00017501413822, 56.115316674113274, 55.57639539241791, 52.48141206800938, 56.24696061015129, 56.407878175377846, 59.88872319459915, 54.07828018069267, 53.142291605472565, 49.85189236700535, 50.11584900319576, 46.70815005898476, 49.89484526216984, 58.60573723912239, 70.73778703808784, 64.32889133691788, 64.46984097361565, 54.14474621415138, 63.1731453537941, 56.73053786158562, 66.28284528851509, 64.07280787825584, 72.42140829563141, 62.62132756412029, 72.76503145694733, 62.63268135488033, 76.06352806091309, 60.10230213403702, 79.43017780780792, 5.184212867170572, 19.09277468919754, 69.93552848696709, 63.86864483356476, 63.15027058124542, 12.284947894513607, 14.540033787488937, 23.893646076321602, 39.23804730176926, 41.13463193178177, 51.42159193754196, 60.514029040932655, 34.186472967267036, 46.310653388500214, 40.99346950650215, 53.26557978987694, 71.18927881121635, 78.62446904182434, 14.257773533463478, 0.7758453371934593, 0.6859293370507658, 0.3368323022732511, 0.34190785023383796, 0.2635775471571833, 0.10058868487249129], [0.10109322654898278, 0.11920254270080477, 0.1087792641192209, 0.10537782320170663, 0.11562959145521745, 0.032552177872275934, 0.12670834228629246, 0.05233302210399415, 0.05368703343265224, 0.18278819712577388, 0.38305094407405704, 4.736459143459797, 63.01274836063385, 47.14945077896118, 46.85087040066719, 31.17100227624178, 38.39774139225483, 45.63144363462925, 39.73599538207054, 99.44846883416176, 68.47229540348053, 12.251424193382263, 4.954846249893308, 14.52140148729086, 68.88958901166916, 55.58740720152855, 65.43710947036743, 34.30733688175678, 0.4604228970129043, 0.6369307881686836, 20.840952582657337, 79.15368184447289, 62.286386936903, 64.94046092033386, 60.59957005083561, 61.66398033499718, 55.4851508885622, 56.90919287502766, 56.67442627251148, 59.08126652240753, 59.13349092006683, 57.481088787317276, 57.133278250694275, 50.33444367349148, 48.008276894688606, 47.89007283747196, 48.0128138512373, 56.18371680378914, 55.419406816363335, 59.03910778462887, 61.079852879047394, 59.71234045922756, 54.851189106702805, 56.277301982045174, 53.47746782004833, 54.38813075423241, 49.83417011797428, 53.42406928539276, 51.7281898856163, 52.14020937681198, 53.086054623126984, 52.53151997923851, 53.71486008167267, 50.74458986520767, 50.379357263445854, 49.05703581869602, 46.7045022547245, 44.38840493559837, 39.49640303850174, 33.85333724319935, 30.907934792339802, 21.0468977317214, 6.536179846152663, 3.4417890524491668, 5.3077043406665325, 2.9637663904577494, 1.9090173253789544, 0.5888434185180813, 8.76478923484683, 22.26591221988201, 19.174466505646706, 27.378450483083725, 42.01964624226093, 50.58744549751282, 31.74737434834242, 32.410782650113106, 32.692142352461815, 33.12436915934086, 28.292548432946205, 29.62154421955347, 31.476963758468628, 34.41894829273224, 36.389256566762924, 36.06250450015068, 44.708115980029106, 67.25168690085411, 46.70517481863499, 34.58952873945236, 34.137482196092606, 14.487652648240328, 2.5925153866410255, 0.8421190653461963, 0.07201120504760183, 2.161364397034049, 8.271881584078074, 25.46644438058138, 31.73439994454384, 40.08571721613407, 42.63157680630684, 44.577361196279526, 43.71915824711323, 45.40732026100159, 49.13930140435696, 49.78457897901535, 48.29634703695774, 50.6952191144228, 49.50916975736618, 51.781641617417336, 49.168594032526016, 47.625572830438614, 49.50994871556759, 49.503599256277084, 47.68207959830761, 49.93653282523155, 47.10989110171795, 48.820346519351006, 51.525269374251366, 53.16026844084263, 53.46729576587677, 51.48941829800606, 52.874436378479004, 50.03632307052612, 45.26645042002201, 44.63208205997944, 44.053905084729195, 48.678830713033676, 60.7942184060812, 58.79494048655033, 59.40075717866421, 59.337992146611214, 53.10927137732506, 55.77434957027435, 55.12697070837021, 63.3632605522871, 57.260962799191475, 59.9248668551445, 56.55330017209053, 63.92876520752907, 57.116574347019196, 74.01628911495209, 30.087585411965847, 0.5154739273712039, 47.70666427910328, 54.03610624372959, 57.81822569668293, 26.82382084429264, 1.299749230965972, 9.136487189680338, 23.416971154510975, 56.542584747076035, 49.95555840432644, 38.348465636372566, 39.96701538562775, 32.75219053030014, 39.35011848807335, 34.69833590090275, 29.3060015514493, 48.55694465339184, 53.79478879272938, 3.648300371132791, 0.03237473407352809, 0.130372651910875, 0.08357868980965577, 0.034403769532218575, 0.09095266170334071, 0.04270233868737705, 0.1477115965099074, 0.07478872983483598, 0.16114804660901427, 0.11258092301432043, 0.022519862686749548, 0.010701480059651658, 0.16056075546657667, 0.11212881407118402, 0.2354524953989312, 0.19110967637971044, 0.5388621473684907, 7.4632080271840096, 74.13314044475555, 53.84920947253704, 48.88557381927967, 33.66653926670551, 46.99148565530777, 58.53566139936447, 46.29871062934399, 104.06532749533653, 64.97586742043495, 8.654022328555584, 6.923886816948652, 15.359242279082537, 75.93042120337486, 65.90028941631317, 69.8787671327591, 39.48523923754692, 0.7404872251208872, 0.46713998657651246, 20.614935010671616, 80.64171999692917, 68.59109222888947, 66.63523077964783, 62.58708760142326, 64.5546904206276, 64.88941445946693, 67.85213068127632, 62.49558471143246, 62.93913871049881, 64.36082482337952, 60.89900158345699, 57.31004856526852, 53.60087379813194, 52.44967617094517, 55.052756890654564, 54.27745409309864, 58.36531654000282, 55.759800150990486, 64.11994814872742, 65.86645603179932, 61.17034122347832, 54.276481345295906, 59.93698440492153, 56.082380041480064, 55.903896018862724, 51.31993219256401, 56.71433173120022, 56.83309815824032, 56.324484050273895, 57.95247249305248, 57.349638640880585, 59.21713583171368, 53.58731232583523, 53.26961137354374, 54.82247404754162, 52.53541097044945, 51.09936162829399, 45.03234878182411, 41.50731973350048, 36.82496778666973, 28.018024563789368, 6.5403244737535715, 1.96645611198619, 4.624271113425493, 3.611657749861479, 4.2494953237473965, 1.0225679981522262, 13.805167470127344, 33.619558587670326, 30.326301902532578, 36.061280965805054, 59.04595501720905, 53.7810905277729, 32.98966258764267, 31.87704049050808, 34.61840718984604, 39.93426114320755, 34.62992437183857, 34.99809041619301, 34.90953616797924, 36.24924547970295, 35.19588500261307, 33.60124357044697, 41.51212267577648, 60.32622791826725, 57.49507203698158, 36.30593463778496, 35.844836980104446, 24.70120344310999, 4.586019041016698, 2.7466876013204455, 1.2890510237775743, 2.9998397547751665, 9.540844392031431, 27.906468249857426, 38.38712476193905, 46.23259037733078, 45.051739141345024, 47.15072751045227, 50.75898349285126, 53.228790163993835, 53.53751219809055, 54.2408886551857, 52.29746013879776, 54.12935324013233, 53.83619137108326, 52.53328688442707, 54.01540495455265, 49.41278412938118, 54.62690994143486, 52.50969015061855, 52.87132814526558, 53.949003517627716, 52.37967632710934, 54.15349334478378, 53.3840574324131, 55.63311494886875, 58.11874017119408, 54.00878190994263, 51.59639775753021, 49.34710465371609, 47.483593448996544, 48.628946989774704, 42.99620904028416, 52.34546296298504, 60.73561035096645, 63.767319470644, 61.55681848526001, 61.25527426600456, 57.21121966838837, 60.64667612314224, 56.78948409855366, 64.11798745393753, 61.64102576673031, 65.2754357457161, 60.66834636032581, 69.88506719470024, 58.78416046500206, 75.7461766898632, 20.865210480988026, 1.265310135204345, 56.082836017012596, 61.57407335937023, 71.47205203771591, 27.230032347142696, 2.936054477468133, 15.027633123099804, 19.408834129571915, 56.600022464990616, 37.59523205459118, 30.964388363063335, 49.85743246972561, 28.311463817954063, 44.43562500178814, 30.9372179210186, 32.3392628878355, 57.55079984664917, 62.19085246324539, 6.656858995556831, 0.43155166029464453, 0.23333519260631874, 0.24168717412976548, 0.10800112228025682, 0.08797535076155327, 0.017072526570700575, 0.2953685412649065, 0.1308632708969526, 0.26273280498571694, 0.1418745011324063, 0.11890221780049615, 0.18549418629845604, 0.1985572322155349, 0.32967016159091145, 0.328155200695619, 0.44045585906133056, 0.42787583253812045, 8.876795824617147, 87.43419751524925, 60.090097188949585, 65.66553801298141, 41.54591806232929, 55.975104197859764, 61.655275002121925, 44.215548411011696, 103.30838531255722, 87.35726684331894, 17.108462266623974, 10.642311237752438, 23.33710514008999, 82.31821283698082, 68.92634063959122, 75.03663316369057, 40.88701441884041, 0.47051548201125115, 0.86668670643121, 31.27541497349739, 81.94463968276978, 68.1639039516449, 68.45917850732803, 65.19273698329926, 69.10629138350487, 66.80469408631325, 69.06167417764664, 64.7540733218193, 63.901003897190094, 64.7623036801815, 63.03179293870926, 62.6568366587162, 57.558255046606064, 55.07201045751572, 57.81470708549023, 57.23764345049858, 64.08178299665451, 59.09755624830723, 64.84125584363937, 64.98428776860237, 60.51858879625797, 56.43706440925598, 62.217052057385445, 57.054120898246765, 59.13165181875229, 55.105323269963264, 60.10243512690067, 57.659519612789154, 56.250600814819336, 59.55780655145645, 60.19646868109703, 61.41573965549469, 53.706865310668945, 57.689876183867455, 56.47125117480755, 54.387040212750435, 52.753656059503555, 48.03479567170143, 47.29269169270992, 46.879403069615364, 40.916219651699066, 28.686657585203648, 13.983457703143358, 9.452243596315384, 5.843051914125681, 6.229834109544754, 7.630082247778773, 24.013995118439198, 40.728156343102455, 36.21569328010082, 46.2984674423933, 61.72206021845341, 52.734660878777504, 30.001592226326466, 32.927110344171524, 35.67590944468975, 42.204529121518135, 35.77729940414429, 35.21797701716423, 34.78969059884548, 37.6201169192791, 35.36932669579983, 34.4779097288847, 41.707861572504044, 54.54694323241711, 52.84247249364853, 38.69086906313896, 39.529962837696075, 28.70135899633169, 6.379685718566179, 3.117726529017091, 2.151820734143257, 10.31938936561346, 25.032547563314438, 41.49109460413456, 43.17631937563419, 49.458400681614876, 45.65269209444523, 51.674707755446434, 54.976772367954254, 57.7011501789093, 55.756007954478264, 55.56457042694092, 52.60899782180786, 57.94975183904171, 54.73624907433987, 54.60290662944317, 58.171184957027435, 52.40204192698002, 57.94852830469608, 54.23543594777584, 53.36497485637665, 56.11975483596325, 52.811238169670105, 52.242427691817284, 53.65567445755005, 56.97741441428661, 61.54286943376064, 55.51347076892853, 57.084982842206955, 54.87611196935177, 53.67829464375973, 55.08796580135822, 48.93205672502518, 56.54167279601097, 67.04760745167732, 67.4858683347702, 63.99306535720825, 63.43432053923607, 60.76344005763531, 62.27680765092373, 58.11658948659897, 67.6604613661766, 61.469020396471024, 64.31911826133728, 60.557323917746544, 70.45669332146645, 63.12222808599472, 77.93384090065956, 38.82609240710735, 1.4100917475298047, 56.72428339719772, 67.45093300938606, 73.40936288237572, 34.017173051834106, 6.200202824547887, 14.193827714771032, 34.10236448049545, 74.98218968510628, 69.06499519944191, 54.17433522641659, 61.25945024192333, 37.03996405005455, 58.564270064234734, 47.316729202866554, 44.167853370308876, 63.817499577999115, 78.91263037919998, 13.064411468803883, 0.7291128323413432, 0.34058976627420634, 0.40244118485134095, 0.18721464788541198, 0.1583168125944212, 0.14117367623839527], [0.012219702693982981, 0.08477348819724284, 0.03563636179023888, 0.03670861304271966, 0.11403613360016607, 0.06500281509943306, 0.2413285238435492, 0.03801745355303865, 0.15259893581969664, 0.13790447119390592, 0.4821162298321724, 6.656457642093301, 64.12274479866028, 50.297920033335686, 41.35309740900993, 19.494542330503464, 36.81194208562374, 34.98849593102932, 11.127960328012705, 47.7530749887228, 53.62148009240627, 16.644921340048313, 8.173764199018478, 9.850945752114058, 46.71418413519859, 68.62745627760887, 55.29665820300579, 54.92519773542881, 6.000657482072711, 0.150294522754848, 2.907440112903714, 60.48452742397785, 69.23660919070244, 64.52619954943657, 63.85292127728462, 60.469685420393944, 55.725970566272736, 57.24721133708954, 56.203642934560776, 59.4552880525589, 56.07431307435036, 58.366011902689934, 58.15449245274067, 48.32514189183712, 46.70610196888447, 51.71339727938175, 50.209757164120674, 53.831213638186455, 53.890999630093575, 59.86840568482876, 58.412437811493874, 61.01705364882946, 58.777374029159546, 54.72035452723503, 56.76043465733528, 54.24324452877045, 51.60092331469059, 53.10991354286671, 53.59933868050575, 54.063738361001015, 55.53384527564049, 56.56457416713238, 54.32832956314087, 53.25169913470745, 45.03361791372299, 45.58872252702713, 46.1523424834013, 38.887789696455, 38.03534343838692, 29.552173241972923, 19.153191447257996, 2.7166677871719003, 2.9335404373705387, 1.53416957706213, 1.0418063658289611, 0.3176622121827677, 0.7196908222977072, 0.6300143280532211, 2.819233783520758, 7.544854246079922, 8.344924114644527, 23.214542716741562, 26.37544870376587, 28.86992745101452, 24.85904697328806, 25.433279760181904, 20.49736551940441, 16.535929888486862, 14.63876673951745, 14.866262432187796, 18.473476320505142, 22.998393215239048, 29.510882757604122, 34.04995769262314, 39.97463017702103, 33.1798841804266, 29.18492864817381, 28.06699823588133, 17.56544854491949, 7.452167244628072, 0.25827828620094806, 0.2808388037374243, 0.18577882961835712, 0.15818981628399342, 1.3589485106058419, 3.8786511356011033, 19.13584727793932, 30.16218300908804, 35.44472984969616, 42.89133846759796, 41.82045333087444, 47.63607166707516, 48.44199702143669, 51.37502543628216, 48.48245345056057, 52.45559245347977, 50.96158482134342, 52.22934879362583, 48.79491448402405, 50.65450809895992, 51.71589374542236, 51.109218299388885, 47.62158304452896, 48.162913396954536, 48.954650312662125, 52.49750040471554, 51.66880667209625, 54.64088559150696, 54.86142955720425, 51.89267925918102, 57.83537417650223, 64.54007640480995, 49.02242727577686, 46.110647320747375, 43.82552973926067, 43.580613881349564, 53.19915175437927, 59.001691192388535, 57.6993452757597, 61.48995727300644, 54.2525540292263, 60.397158712148666, 61.054154857993126, 60.25009520351887, 63.366315588355064, 61.222520023584366, 60.69572389125824, 64.47591304779053, 61.45778439939022, 63.29722009599209, 0.36481346643995494, 7.445327611640096, 54.617319256067276, 45.65415881574154, 60.43424852192402, 11.21348138898611, 1.9199895928613842, 15.236526913940907, 35.35855047404766, 45.951800644397736, 82.0023661851883, 47.77132160961628, 30.16925822943449, 34.88436631858349, 29.55789763480425, 30.04345268011093, 32.86102429032326, 51.54976665973663, 51.74774743616581, 2.689650049433112, 0.09858354285825044, 0.07642827506060712, 0.09954158871551044, 0.13139114569639787, 0.0763595818716567, 0.020811772701563314, 0.08949427472543903, 0.2491312864003703, 0.019994215399492532, 0.04137748263019603, 0.1483163281227462, 0.08958725098636933, 0.30480370216537267, 0.08792557491688058, 0.11246661742916331, 0.011009477839252213, 0.5441630410496145, 7.324799029156566, 76.48250117897987, 58.092274591326714, 43.925456777215004, 20.20138420164585, 43.749271631240845, 43.354400619864464, 22.3041058704257, 73.08514907956123, 58.96764501929283, 13.169372286647558, 6.36167848482728, 15.360973086208105, 47.866339311003685, 78.32959726452827, 58.23158651590347, 59.915359765291214, 10.70993335917592, 0.07268523841048591, 1.5894247870892286, 55.24057321250439, 70.65704137086868, 66.022939234972, 64.7305753827095, 61.00046753883362, 62.91348248720169, 62.48296558856964, 61.18666134774685, 64.61050942540169, 61.75128825008869, 63.065979704260826, 59.92939621210098, 51.07009179890156, 49.90643844008446, 53.72235707938671, 53.758743926882744, 55.854263082146645, 57.04395264387131, 64.49795946478844, 61.97182081639767, 65.73236882686615, 65.10217264294624, 59.55891989171505, 59.413737282156944, 56.43937088549137, 51.72411270439625, 59.2126102745533, 57.06661082804203, 58.91270376741886, 58.28235559165478, 59.230708703398705, 58.52065220475197, 58.44051830470562, 48.049162700772285, 50.24848088622093, 46.741633862257004, 43.71324576437473, 42.34014764428139, 39.428063705563545, 26.827968321740627, 4.575072778388858, 2.5444322917610407, 2.5302847009152174, 2.2258873097598553, 1.2926818476989865, 0.729838830884546, 1.9980239868164062, 1.3761168206110597, 14.770505670458078, 15.546907559037209, 29.85374975949526, 39.26744632422924, 34.8258912563324, 31.635569147765636, 31.6906775906682, 27.649144157767296, 23.444679267704487, 22.57234487682581, 23.1818625703454, 26.103276908397675, 28.173894099891186, 33.99480365216732, 35.93759000301361, 40.48074021935463, 43.551142662763596, 40.90085707604885, 39.5577659457922, 29.671376645565033, 10.298281498253345, 0.04157850817136932, 0.14208642882294953, 0.21603179688099772, 0.40359471982810646, 1.8015948333777487, 3.873034087009728, 25.125714763998985, 39.691408574581146, 40.94864711165428, 49.19801965355873, 51.64431318640709, 55.90108796954155, 53.783613592386246, 55.77276885509491, 51.46277032792568, 54.317108765244484, 54.23455059528351, 55.56847661733627, 53.316189274191856, 50.897299870848656, 58.1708125770092, 54.45728324353695, 53.14674496650696, 49.6937258541584, 54.56553563475609, 56.88810020685196, 55.13037532567978, 54.612140133976936, 56.25334046781063, 51.1845188587904, 56.57544158399105, 64.8622839152813, 52.0666529238224, 49.69496078789234, 43.897991850972176, 46.39659717679024, 53.49789932370186, 62.053128853440285, 62.57139824330807, 63.97224247455597, 60.342764630913734, 60.210406333208084, 61.25811271369457, 62.68757700920105, 67.81996160745621, 64.06677380204201, 63.85495036840439, 63.491754457354546, 65.76093569397926, 47.60004960000515, 0.6404555146582425, 12.75123417377472, 60.55003970861435, 53.018380254507065, 71.41781374812126, 12.277693133801222, 4.695863546803594, 10.422084555029869, 29.798897802829742, 50.91108553111553, 76.68507590889931, 37.56730355322361, 38.21052543818951, 31.489362493157387, 36.89246356487274, 30.69239515811205, 37.83117659389973, 60.28961308300495, 59.174456521868706, 4.592729955911636, 0.6652418815065175, 0.11028920067474246, 0.07612200555740856, 0.056215764343505725, 0.02776220462692436, 0.03561235702363774, 0.2027606379124336, 0.29983529064338654, 0.13038791046710685, 0.23934676690259948, 0.3179676801664755, 0.19450509105809033, 0.38895974576007575, 0.2773710445035249, 0.21176179085159674, 0.19775955704972148, 0.5731784622184932, 12.000895086675882, 88.00232782959938, 64.61604952812195, 57.07144036889076, 28.287489004433155, 51.67605668306351, 50.93423768877983, 12.97776946797967, 57.39277392625809, 58.27070541679859, 22.70485896617174, 12.705812361091375, 16.835800297558308, 56.04182481765747, 80.53442895412445, 65.05423441529274, 65.30731603503227, 10.260355733335018, 0.28072267246898264, 5.5857933685183525, 68.20165112614632, 75.28484344482422, 69.043640345335, 69.51156243681908, 64.5878778398037, 62.83346638083458, 64.52119141817093, 62.266008630394936, 64.92450177669525, 62.76509664952755, 64.42373424768448, 63.547733053565025, 53.95900458097458, 52.30640485882759, 58.065383434295654, 57.283377796411514, 58.19424971938133, 59.44275252521038, 69.38977897167206, 64.84364971518517, 65.0878170132637, 64.83582213521004, 60.19057519733906, 61.49363547563553, 59.344520196318626, 54.28198724985123, 62.14076355099678, 56.62060596048832, 60.72807915508747, 57.613884061574936, 62.30012319982052, 61.50806710124016, 58.15741069614887, 49.53031562268734, 54.085442796349525, 51.33845239877701, 50.24486348032951, 46.144020929932594, 49.87405277788639, 43.61146442592144, 25.250194184482098, 6.327248057350516, 2.2632960649207234, 4.463758701458573, 1.6180424764752388, 3.188907871954143, 1.798667802941054, 13.222088757902384, 26.909654438495636, 18.28524772077799, 42.458336502313614, 48.54335278272629, 44.527006298303604, 32.11934208869934, 36.097914800047874, 30.617807060480118, 30.769428424537182, 25.037297308444977, 26.12080156803131, 30.126626417040825, 31.03944193571806, 35.51718816161156, 37.73100256919861, 40.20460903644562, 44.34145465493202, 46.09253369271755, 33.452530950307846, 32.26128727197647, 22.92182732373476, 0.49530033487826586, 0.6030833919066936, 0.4476533259730786, 0.8655805501621217, 4.550497597083449, 19.975816905498505, 40.48138618469238, 42.417990267276764, 43.498268499970436, 53.28663446009159, 54.46508042514324, 58.332794085145, 56.41765885055065, 58.371183425188065, 53.60682427883148, 56.75285026431084, 55.70816472172737, 54.55709628760815, 55.58215968310833, 55.469776913523674, 61.3104435056448, 55.95420531928539, 51.30472540855408, 50.31941927969456, 53.65284360945225, 59.93844732642174, 54.94445890188217, 57.96279653906822, 57.20630273222923, 56.987054497003555, 54.10992868244648, 67.22058936953545, 60.54675668478012, 55.095557793974876, 51.45200930535793, 50.48859380185604, 59.128045812249184, 64.52225536108017, 64.44555267691612, 67.42879539728165, 59.6374236792326, 66.48611158132553, 61.18160381913185, 65.29103010892868, 67.82736361026764, 65.10258302092552, 65.35087689757347, 73.04531961679459, 67.0388375222683, 75.63262358307838, 0.6532703863922507, 10.127094984054565, 67.7538451552391, 56.39220021665096, 77.19211310148239, 18.73531647026539, 7.710798941552639, 21.31513673812151, 48.45326341688633, 61.96371965110302, 100.28018340468407, 59.78784620761871, 50.202339962124825, 41.28812849521637, 47.86521077156067, 40.46195402741432, 49.20972302556038, 66.7903384566307, 77.91894569993019, 9.889339841902256, 1.121740776579827, 0.17983810073928908, 0.18049329839413986, 0.2246193212340586, 0.1188395285862498, 0.15534798440057784], [0.07931074695079587, 0.07880461707827635, 0.1165895743179135, 0.09825541710597463, 0.11745905227144249, 0.009395950455655111, 0.0752032118907664, 0.054948038814472966, 0.2390403489698656, 0.21944328647805378, 0.4393274086760357, 2.3562435898929834, 56.17440350353718, 59.76181760430336, 32.63985335826874, 44.78996738791466, 39.31093119084835, 54.8516146838665, 27.70549513399601, 17.082798443734646, 31.77718184888363, 8.589801024645567, 5.3214349038898945, 25.82361001521349, 51.09852187335491, 57.759971022605896, 60.82309305667877, 62.07664579153061, 35.35743713378906, 0.6084594503045082, 0.3062475653132424, 16.129270009696484, 66.98149859905243, 61.85005635023117, 67.37583383917809, 54.771739169955254, 59.50280450284481, 54.6296039968729, 59.97363343834877, 57.375389859080315, 60.30221700668335, 57.0953980833292, 55.45854091644287, 46.07290394604206, 50.33056028187275, 49.584850296378136, 51.19338758289814, 53.54820102453232, 55.4439876973629, 57.59711176156998, 58.61770659685135, 51.31729133427143, 59.60077844560146, 61.98157489299774, 56.642185002565384, 55.384144708514214, 52.83923126757145, 52.55905710160732, 52.910770028829575, 54.325426518917084, 52.95295536518097, 53.231396824121475, 48.715643137693405, 48.15972536802292, 39.74398635327816, 41.60093531012535, 27.814431488513947, 16.97789367288351, 27.653388530015945, 19.565725810825825, 6.02288106456399, 2.2201987775042653, 0.8400921116117388, 0.7511379348579794, 0.34698648552875966, 0.08520706571289338, 0.32835059333592653, 0.9555751585867256, 0.6916151382029057, 2.0764992758631706, 6.828991658985615, 15.136456433683634, 18.311156630516052, 19.020702056586742, 18.814059644937515, 16.165605559945107, 11.695669814944267, 8.149990774691105, 9.194540474563837, 8.950032144784927, 8.345323093235493, 12.293771971017122, 15.995376594364643, 27.256921604275703, 20.16000062227249, 14.542895033955574, 22.920417599380016, 16.65470201522112, 10.932176783680916, 2.519175997003913, 0.07464851587428711, 0.057515231528668664, 0.06140510209661443, 0.09220102831022814, 0.33332936523947865, 2.356051937676966, 6.669076289981604, 20.623421855270863, 30.06060115993023, 39.43787097930908, 43.94192889332771, 44.627035930752754, 50.387340635061264, 49.116943404078484, 50.2168133854866, 47.20404624938965, 53.40834192931652, 50.9158618748188, 52.25918859243393, 50.65111868083477, 52.38883763551712, 52.86572724580765, 50.087871104478836, 48.0314252525568, 51.16860531270504, 53.83363030850887, 54.360312446951866, 54.05392348766327, 55.1514907926321, 55.388810858130455, 84.58979174494743, 61.419706642627716, 50.15584945678711, 52.71093875169754, 44.54564809799194, 39.59314204752445, 48.05365785956383, 56.33696638047695, 57.79222369194031, 59.86667297780514, 58.938071206212044, 56.08703099191189, 58.89103353023529, 62.96294063329697, 61.921876296401024, 60.84583103656769, 61.50771751999855, 58.88613939285278, 59.543781504034996, 6.292381603270769, 0.1345658308127895, 25.825019739568233, 51.170117631554604, 54.33643452823162, 46.574203446507454, 10.22504422813654, 4.665794810280204, 11.60367390140891, 29.093034379184246, 41.97761669754982, 79.32728692889214, 57.499096021056175, 28.055794537067413, 32.39441692829132, 36.378161162137985, 29.06861688941717, 43.697693198919296, 56.84402637183666, 46.30320578813553, 1.7183397570624948, 0.30425394885241985, 0.037428466603159904, 0.03820775877102278, 0.059107390625285916, 0.12573099316796288, 0.08139254539855756, 0.05246407054073643, 0.2581865567481145, 0.1421807409496978, 0.04965780237398576, 0.16118739527883008, 0.06152839880087413, 0.04685486273956485, 0.11894702867721207, 0.29020248097367585, 0.17230990313692018, 0.5123435484711081, 3.309642830863595, 68.96956712007523, 65.42332381010056, 43.98098699748516, 37.37060710787773, 42.79308333992958, 58.02146919071674, 29.011167772114277, 18.510653525590897, 34.192826226353645, 12.286906689405441, 5.282963868230581, 30.07914036512375, 56.0038610547781, 63.435304686427116, 65.95945984125137, 64.48591411113739, 41.97204999625683, 1.8337532202713192, 0.5236028193030506, 13.302279654890299, 67.9801458120346, 66.0476303100586, 69.22229155898094, 60.48366107046604, 65.14428958296776, 58.39404679834843, 61.79313160479069, 62.91886679828167, 64.74947556853294, 61.460866034030914, 58.148606568574905, 50.31919129192829, 51.73859752714634, 53.703236505389214, 52.890866696834564, 53.487503081560135, 61.00983403623104, 60.1439592987299, 62.7419862896204, 53.64558979868889, 64.0248392522335, 69.03359368443489, 59.77991223335266, 57.07494378089905, 56.00201815366745, 56.388248428702354, 57.61030465364456, 58.319339007139206, 54.60115112364292, 55.534590035676956, 49.8664303869009, 48.27844999730587, 42.36038535833359, 45.69858603179455, 31.152178086340427, 15.610268209129572, 31.057736054062843, 27.601557411253452, 12.024464271962643, 0.9339281357824802, 2.1055477671325207, 2.645418760366738, 1.5213192603550851, 0.10691970179323107, 0.5769142555072904, 0.4714503209106624, 2.0284845773130655, 2.5744226574897766, 10.44726675376296, 16.879237666726112, 21.970536969602108, 24.06489148736, 25.85353720933199, 22.767038829624653, 16.95126850157976, 13.247148413211107, 10.043439622968435, 10.385331027209759, 11.67910935357213, 17.334018163383007, 22.887009792029858, 30.199791491031647, 29.81380060315132, 21.356299929320812, 27.431624829769135, 30.01214426010847, 20.124613121151924, 0.9779452113434672, 0.17309818271314725, 0.007756783725199057, 0.08856257511069998, 0.062278977275127545, 0.18808638938935474, 1.6095147840678692, 5.437757112085819, 27.345150969922543, 39.37788359820843, 46.65975585579872, 52.03249275684357, 51.29857733845711, 53.87877568602562, 51.809604316949844, 52.76625998318195, 51.07177510857582, 55.47358810901642, 53.42591978609562, 57.48899236321449, 53.352203741669655, 56.70015849173069, 55.034586265683174, 54.14541497826576, 48.28921481966972, 55.64427115023136, 56.953019723296165, 56.76442064344883, 54.925391525030136, 55.8826969563961, 58.91311414539814, 87.52258077263832, 66.47877037525177, 53.14670316874981, 53.27674739062786, 46.382849514484406, 45.662765353918076, 49.70012091100216, 57.058030888438225, 62.773042023181915, 62.506980299949646, 63.82601872086525, 59.939363077282906, 57.628520876169205, 63.12164671719074, 64.94423031806946, 64.50326398015022, 64.61945414543152, 61.889882013201714, 53.58187481760979, 0.38959873490966856, 0.47440169379115105, 32.395921647548676, 55.357253551483154, 60.676341131329536, 53.23186419904232, 15.09559627622366, 8.214831445366144, 8.499667961150408, 28.19921024143696, 45.66832445561886, 75.79755753278732, 52.18703046441078, 32.472901716828346, 31.020847633481026, 39.08800855278969, 28.093019239604473, 47.33514301478863, 63.41003604233265, 57.47109152376652, 3.7354161590337753, 0.354384183883667, 0.09300708974478766, 0.027726049047487322, 0.047311290982179344, 0.07323134035686962, 0.10337006140616722, 0.18266774655785412, 0.37631907092873007, 0.21642731706378981, 0.3413165663369, 0.37573182431515306, 0.1498838627594523, 0.1796997940982692, 0.3497324022464454, 0.5379982281010598, 0.6908940675202757, 0.5556262540630996, 5.791407460346818, 78.69949981570244, 74.64946433901787, 53.046662136912346, 57.153280377388, 55.961702316999435, 73.42836946249008, 40.48724167048931, 24.376841448247433, 39.57146801054478, 13.59378481283784, 11.344339717179537, 34.61013123393059, 60.57605691254139, 68.52127477526665, 68.79465490579605, 71.26734182238579, 44.01844538748264, 1.3837751909159124, 0.5637613206636161, 23.982772193849087, 73.05524468421936, 67.36330211162567, 75.71716904640198, 62.57542982697487, 68.9958693087101, 60.82743622362614, 63.904142528772354, 64.3460588157177, 67.28997364640236, 63.20725992321968, 61.268843337893486, 53.55643518269062, 54.24254156649113, 57.136785462498665, 56.21364779770374, 57.01769985258579, 60.66252127289772, 61.90718628466129, 66.31545513868332, 57.16767780482769, 66.04215860366821, 68.88236939907074, 61.95265844464302, 60.41171573102474, 60.42330890893936, 57.47771456837654, 57.131735533475876, 59.79555979371071, 57.551669999957085, 58.797258362174034, 53.9919526129961, 53.41279149055481, 47.93496362864971, 48.384650498628616, 37.41854153573513, 26.305161975324154, 41.538991034030914, 39.88186575472355, 30.448282957077026, 7.690503280609846, 2.4892547400668263, 4.717283947393298, 1.709989111404866, 0.18202336941612884, 0.9977543796412647, 1.6787382820621133, 1.680342152249068, 16.30714986473322, 22.41003278642893, 23.954632803797722, 35.93751020729542, 40.56620143353939, 30.2122700214386, 29.393347464501858, 24.642475694417953, 23.595504574477673, 16.166753098368645, 17.874311171472073, 17.65226248651743, 27.220519557595253, 29.064076133072376, 32.95549862086773, 32.902613058686256, 28.588256165385246, 34.71336029469967, 32.00390428304672, 27.148315832018852, 7.371414927765727, 0.3897934447741136, 0.15844900393858552, 0.19319281069329008, 0.17487041652202606, 0.6932124181184918, 3.4928402630612254, 25.038532242178917, 42.80997343361378, 41.035430654883385, 52.34784163534641, 52.468701750040054, 55.179225504398346, 57.379987612366676, 56.535201743245125, 55.64511850476265, 51.83818258345127, 57.4543534219265, 54.56509865820408, 58.085020780563354, 56.100987643003464, 60.01407086849213, 55.8302141726017, 54.40579980611801, 47.2753494232893, 56.71100310981274, 58.77992369234562, 60.16846418380737, 57.28880010545254, 61.127445325255394, 55.395388305187225, 76.36587023735046, 77.68660336732864, 56.677583903074265, 60.03887593746185, 51.386633813381195, 47.74167940020561, 54.451834335923195, 60.37776455283165, 61.89085476100445, 64.65094685554504, 66.15663886070251, 63.97809416055679, 61.36507697403431, 63.354524821043015, 65.00262558460236, 63.966732770204544, 67.12071552872658, 64.39606413245201, 70.95582693815231, 8.033392131328583, 0.40177209419198334, 33.03409360349178, 62.58127771317959, 67.44502812623978, 60.0660140812397, 16.74319736659527, 12.40568071603775, 21.209460608661175, 36.980584636330605, 51.2309105694294, 90.69842755794525, 66.97951510548592, 44.89866055548191, 40.96184000372887, 53.79336766898632, 40.64841382205486, 61.087661460042, 72.70307198166847, 77.11848065257072, 7.627406716346741, 0.8580324333161116, 0.18490765214664862, 0.20659576024627313, 0.3042898984858766, 0.14036374079296365, 0.22699585621012375], [0.020297100709285587, 0.07225862966151908, 0.020401355759531725, 0.08123476480250247, 0.07244064880069345, 0.055574144280399196, 0.11994727305136621, 0.0687684427248314, 0.024007013453228865, 0.11277025972958654, 0.3653619432589039, 2.0250165509060025, 65.57247340679169, 52.43917353451252, 34.703632816672325, 32.846478670835495, 44.4891869276762, 44.921440333127975, 50.60567691922188, 56.83050289750099, 36.74188144505024, 11.253627184778452, 2.0953374775126576, 17.31338147073984, 60.16534835100174, 55.830723345279694, 54.56471487879753, 54.69749875366688, 48.54709558188915, 7.034303667023778, 0.18930230929981917, 1.0351087502203882, 45.64364477992058, 68.61952990293503, 63.41094419360161, 60.4954594373703, 55.39372019469738, 57.55521520972252, 58.291965276002884, 60.204060673713684, 59.08142611384392, 60.64978435635567, 52.537759244441986, 45.61496011912823, 46.39020971953869, 49.28101100027561, 49.361456483602524, 50.09340360760689, 55.11001221835613, 58.82636100053787, 60.82502715289593, 57.49224878847599, 48.189891949296, 54.65975157916546, 61.826907992362976, 55.30651107430458, 53.139779940247536, 50.437839925289154, 52.34555035829544, 51.390467807650566, 53.43831852078438, 44.58921276032925, 35.27764901518822, 39.84914191067219, 47.11999095976353, 48.53250436484814, 33.35863418877125, 13.726350199431181, 20.433378852903843, 7.465872634202242, 1.3371361372992396, 1.51259706588462, 0.6789229286368936, 0.41117988468613476, 0.07575189651106484, 0.10404877772089094, 0.2857040270464495, 0.10585381445707753, 0.3634796489495784, 3.8896484579890966, 2.02181997243315, 7.820420209318399, 13.859566301107407, 16.096703857183456, 12.115707825869322, 13.76889556646347, 9.274922311306, 6.193652926012874, 3.9066504081711173, 2.523225867189467, 3.146159928292036, 8.50706521421671, 14.365370459854603, 14.968865476548672, 8.017394989728928, 10.278543457388878, 13.008525017648935, 4.8963165655732155, 3.59753105789423, 1.19345064740628, 0.09411976949195378, 0.17466596968006343, 0.11365879603545181, 0.1362669817171991, 0.09322143683675677, 0.19738204136956483, 3.0947878723964095, 5.8302955236285925, 23.455029912292957, 33.85547652840614, 36.60919636487961, 40.36869563162327, 44.30295892059803, 49.203544557094574, 47.160420790314674, 52.798923030495644, 49.056652039289474, 51.27195216715336, 55.49084298312664, 48.22887025773525, 48.47652956843376, 54.622266590595245, 51.68770305812359, 51.84343010187149, 50.45311130583286, 56.384106650948524, 52.48381733894348, 57.30619557201862, 49.74632263183594, 77.15543746948242, 60.11508084833622, 47.375709637999535, 55.46708665788174, 48.543299585580826, 42.71837554872036, 40.84984481334686, 47.11588717997074, 51.27868540585041, 57.32806719839573, 58.21625053882599, 57.86092780530453, 63.86676013469696, 58.855057060718536, 60.794222205877304, 59.337847754359245, 62.21626169979572, 58.52083459496498, 59.55638162791729, 7.04849923029542, 0.4854490963043645, 2.8264788072556257, 38.93567852675915, 50.13465419411659, 55.88314153254032, 51.11429862678051, 29.93804443627596, 7.10483405739069, 6.030771816149354, 17.99801353365183, 40.61987355351448, 66.36486768722534, 38.25157843530178, 35.69165959954262, 23.908697068691254, 38.1185057759285, 24.0280619636178, 41.28476567566395, 57.10275448858738, 35.89632801711559, 1.1707913945429027, 0.3856990160420537, 0.06220344148459844, 0.049269354858552106, 0.05359922623028979, 0.0466498667083215, 0.04267959186108783, 0.03247611515689641, 0.13455260574119166, 0.020368866389617324, 0.06926902875420637, 0.18575177091406658, 0.09703246905701235, 0.1737178463372402, 0.10143701161723584, 0.09565478321746923, 0.015704568431829102, 0.36776347376871854, 2.853110865689814, 71.13850593566895, 61.318046897649765, 38.976100757718086, 32.14739218354225, 48.58784459531307, 58.35730656981468, 40.97549267113209, 42.456201016902924, 36.09974630177021, 17.56041571497917, 4.044735711067915, 17.768443152308464, 63.42387489974499, 60.52243039011955, 58.951853066682816, 56.88303127884865, 54.35341961681843, 9.00651516392827, 0.1355832113767974, 0.39259727869648486, 44.08789426088333, 72.0308880507946, 67.48883977532387, 63.43397095799446, 57.49393589794636, 63.57630752027035, 60.32049402594566, 64.8526856303215, 64.09588783979416, 64.15255799889565, 55.986355394124985, 47.79748320579529, 48.75684812664986, 51.891128942370415, 53.374052569270134, 52.51360774040222, 55.48243783414364, 57.422571927309036, 62.06288293004036, 60.645091608166695, 50.313825979828835, 58.022901713848114, 64.73249047994614, 61.245843172073364, 55.77789478003979, 54.85800974071026, 55.708749890327454, 57.46131844818592, 55.56976094841957, 49.77991662919521, 40.321555361151695, 45.62786042690277, 47.408938854932785, 54.144332036376, 38.00564043223858, 28.031914718449116, 30.612342953681946, 17.105640918016434, 3.9728682674467564, 1.7332159588113427, 2.2553675528615713, 0.44863043760415167, 0.5759998108260334, 0.24363507429370657, 0.25950413604732603, 0.40116222691722214, 0.975836799480021, 2.2211632132530212, 3.0616111401468515, 15.117916278541088, 16.686827391386032, 19.09294568002224, 16.009756922721863, 15.41093185544014, 9.625101070851088, 6.437340499833226, 5.220695659518242, 4.432970378547907, 5.723767289891839, 9.294755347073078, 15.734094064682722, 21.710026748478413, 14.651269968599081, 16.18914719671011, 21.441666148602962, 16.898618526756763, 5.357450321316719, 1.0219958913512528, 0.16617318789940327, 0.05118861925438978, 0.07325421334826387, 0.14242041012039408, 0.018925001386378426, 0.043213003082200885, 2.389460694976151, 6.628846898674965, 27.48982820659876, 38.909068554639816, 40.79136975109577, 44.48543652892113, 45.565669164061546, 51.930779814720154, 50.0780638307333, 57.0560359954834, 52.29549944400787, 56.16585776209831, 58.656437918543816, 51.922154277563095, 51.862265691161156, 54.257090985774994, 52.82698832452297, 53.79983872175217, 53.76323528587818, 58.91520403325558, 55.95124527812004, 61.94971740245819, 52.52434976398945, 85.64042016863823, 67.74709671735764, 51.294458359479904, 60.381773337721825, 51.78595818579197, 48.94415907561779, 43.66477556526661, 49.36385415494442, 52.111623510718346, 59.26875986158848, 60.67602954804897, 61.77968792617321, 64.6439628303051, 62.31341868638992, 64.1989915072918, 61.38030655682087, 62.22997896373272, 62.33805276453495, 53.783811181783676, 2.4553980818018317, 0.4224829125450924, 4.0881806798279285, 46.9204218685627, 53.80433768033981, 62.6499742269516, 55.980275720357895, 38.91371950507164, 12.865406647324562, 7.590829404070973, 19.09906905144453, 39.380942434072495, 69.7252781689167, 41.277629658579826, 38.74065399169922, 27.488549575209618, 42.39345498383045, 22.862865887582302, 43.837605491280556, 67.91785195469856, 46.08241863548756, 2.4541028263047338, 0.4801164090167731, 0.033545624173711985, 0.03619069044361822, 0.0646381163096521, 0.10040069144451991, 0.0650027408846654, 0.14100859290920198, 0.19526702439179644, 0.1607172001968138, 0.19561089109629393, 0.25810964056290686, 0.22363996831700206, 0.22868679516250268, 0.19731944863451645, 0.1781533661414869, 0.2691455843159929, 0.39661716611590236, 4.41137851215899, 86.82045444846153, 66.19450002908707, 53.98866578936577, 41.97766229510307, 64.07826438546181, 64.39395904541016, 67.25737899541855, 69.9123877286911, 48.12456965446472, 17.25823312997818, 6.989402426406741, 25.799914486706257, 70.91095134615898, 65.49042820930481, 68.14438819885254, 64.8278197646141, 59.91192474961281, 9.598308708518744, 0.3882125217933208, 2.2386242263019085, 52.22169980406761, 75.06006270647049, 72.70239561796188, 66.5973012149334, 60.182888209819794, 66.13936498761177, 65.3262922167778, 67.3044964671135, 66.5334190428257, 66.58483788371086, 59.063852056860924, 49.75523315370083, 50.95147356390953, 54.72068890929222, 56.145031079649925, 52.71614067256451, 60.00557832419872, 63.50674465298653, 65.53102523088455, 63.97800296545029, 56.10606037080288, 61.14307388663292, 65.93592390418053, 61.58101178705692, 59.695594757795334, 57.66497991979122, 57.84577041864395, 59.41407546401024, 58.788059055805206, 50.97978584468365, 43.42782028019428, 44.8545753210783, 51.31755352020264, 53.153371810913086, 44.401578828692436, 42.20210865139961, 40.27835167944431, 29.64752532541752, 15.16349958255887, 5.1212279219180346, 3.6946766451001167, 1.2551885470747948, 0.735419187694788, 0.4896517004817724, 0.6315670197363943, 0.356963918893598, 1.106057830620557, 8.998418748378754, 17.966125644743443, 26.18170280009508, 39.30974565446377, 31.296703331172466, 25.064429752528667, 27.487134151160717, 15.94911027699709, 7.705199467018247, 4.387189960107207, 3.89137071557343, 4.845026917755604, 11.3628732226789, 20.797955989837646, 31.037481240928173, 19.51477624475956, 27.246977537870407, 27.842907160520554, 24.946427084505558, 16.222450509667397, 2.449694825336337, 0.2141726278932765, 0.15308081230614334, 0.16443789820186794, 0.3220540046459064, 0.09041536162840202, 0.7434324233327061, 5.380648076534271, 24.67137884348631, 36.1585633456707, 44.80042062699795, 46.36450029909611, 48.04038517177105, 49.41179618239403, 53.86916220188141, 51.78568460047245, 58.24655771255493, 55.22279396653175, 54.92228329181671, 59.541224241256714, 56.591583117842674, 55.16787551343441, 59.656251668930054, 54.729808419942856, 54.581893756985664, 57.437619119882584, 61.01819358766079, 57.8182826936245, 65.58018699288368, 54.720761105418205, 70.28423577547073, 74.74889740347862, 56.66771203279495, 60.85222229361534, 57.06988625228405, 48.51773455739021, 47.59001433849335, 51.840185075998306, 57.39062324166298, 60.966413766145706, 64.217010140419, 64.52284812927246, 67.83210575580597, 62.523528411984444, 66.63524597883224, 62.23837651312351, 64.66992303729057, 62.013356387615204, 71.07302024960518, 10.703157372772694, 0.5291083676274866, 3.9795190980657935, 48.57882007956505, 61.5387998521328, 66.46588906645775, 62.51442790031433, 38.05154576897621, 16.244135946035385, 13.506427500396967, 22.915056087076664, 50.11307895183563, 77.38779500126839, 46.21895670890808, 51.40958458185196, 34.44658041000366, 58.428294360637665, 33.72509032487869, 55.18550656735897, 77.88659423589706, 71.13696321845055, 5.015254933387041, 0.8235439995769411, 0.1547851544455625, 0.2548253402346745, 0.0869850734306965, 0.3203386638779193, 0.14293498563347384], [0.08717425429495052, 0.002264498971271678, 0.12794155423762277, 0.04495196641073562, 0.08765646474785171, 0.06723366648657247, 0.040489933380740695, 0.043294906499795616, 0.017513525563117582, 0.013751871210843092, 0.14190795714966953, 0.656535776797682, 52.22476243972778, 49.63373087346554, 45.1614810526371, 34.73117753863335, 41.1581526696682, 39.658323749899864, 28.56974545866251, 58.426888436079025, 34.80286069214344, 20.279566906392574, 2.087126593105495, 8.331743571907282, 47.76743821799755, 65.60113906860352, 59.287812039256096, 44.14098501205444, 59.46862913668156, 17.547804191708565, 0.029031507219769992, 0.12842438067309558, 19.597796089947224, 66.54703751206398, 60.90010352432728, 59.67211201786995, 53.60020883381367, 57.51492977142334, 57.66202747821808, 60.56679680943489, 59.91324707865715, 56.89472325146198, 46.91501095890999, 48.98211143910885, 50.05952462553978, 49.016476795077324, 50.637120231986046, 52.13735952973366, 56.62095174193382, 54.80958513915539, 56.79898738861084, 60.28053157031536, 58.239015117287636, 49.039184376597404, 55.761342868208885, 59.5111982524395, 53.93318496644497, 54.57816235721111, 55.71129955351353, 50.95042861998081, 52.3530587553978, 47.57138393819332, 44.82210226356983, 43.840991109609604, 39.47096720337868, 35.54009333252907, 43.76204274594784, 51.82173706591129, 22.923767119646072, 3.417773391120136, 2.260544062592089, 1.0754988016560674, 0.7371603255160153, 0.11055834052967839, 0.13830515672452748, 0.27558819798287004, 0.02239480152638862, 0.05433567421277985, 0.36245732568204403, 1.385798582341522, 2.7502629719674587, 8.315014019608498, 11.98224188759923, 6.950941365212202, 7.421842971816659, 6.76127121783793, 3.2129123713821173, 1.0493662976659834, 0.8327795227523893, 0.07980805268744007, 0.5521231982856989, 1.22054758714512, 4.150879690423608, 6.184867322444916, 5.831611678004265, 8.861475996673107, 7.202077489346266, 1.999569316394627, 0.8791282481979579, 0.18622331670485437, 0.08300686502479948, 0.10190140310442075, 0.05167593939404469, 0.029173480070312507, 0.022650925966445357, 0.03865500293613877, 0.0930219326983206, 3.092822190374136, 9.24980090931058, 23.88734221458435, 29.188946932554245, 37.28663921356201, 43.428800627589226, 45.72193577885628, 50.21549865603447, 43.97700101137161, 48.063989505171776, 57.1941813826561, 48.22638899087906, 48.08736205101013, 52.14042976498604, 51.11091300845146, 52.5564656406641, 50.66910311579704, 50.680605098605156, 55.72920419275761, 57.670307233929634, 50.39802186191082, 63.72740641236305, 61.165021508932114, 33.02911967039108, 59.94486138224602, 53.962732180953026, 53.72524872422218, 46.90070852637291, 43.57028603553772, 47.20154978334904, 45.35813570022583, 52.96156570315361, 57.083174139261246, 60.11850446462631, 58.0695404112339, 63.53196009993553, 60.903926119208336, 61.75829127430916, 56.71986423432827, 60.98857417702675, 8.760107886046171, 0.40126850246451795, 0.15246626950101927, 9.537057895213366, 69.07454028725624, 52.39643342792988, 60.27604401111603, 51.06329396367073, 51.485052332282066, 10.595320109277964, 5.927130002528429, 19.639559648931026, 45.41201300919056, 55.212538316845894, 20.98123725503683, 32.50105440616608, 25.3130941092968, 33.85437838733196, 24.410416446626186, 44.8824468255043, 55.418430268764496, 20.439384430646896, 0.5237168131861836, 0.21772570442408323, 0.15243095811456442, 0.025219573290087283, 0.09513206634437665, 0.12421674473444, 0.03026732782018371, 0.03232397859392222, 0.021721155935665593, 0.11420053415349685, 0.0419289725687122, 0.1873225561575964, 0.040548885881435126, 0.09816198813496158, 0.04326827824115753, 0.02669741566933226, 0.037337015455705114, 0.25524426775518805, 0.6860471901018173, 56.95550099015236, 56.54796525835991, 44.95214268565178, 35.142931044101715, 52.953525334596634, 45.456755608320236, 32.09507279098034, 60.906540378928185, 36.76874600350857, 21.7454731464386, 6.38338434509933, 8.587157316505909, 54.80467960238457, 70.31775757670403, 66.75751581788063, 44.66825991868973, 65.38139685988426, 21.02442193776369, 0.20952054939698428, 0.06802135976613499, 17.97712605446577, 71.49501040577888, 64.17591914534569, 64.46068346500397, 59.410059079527855, 63.40403616428375, 62.07354515790939, 63.708449229598045, 63.06543633341789, 60.9423990547657, 49.2562211304903, 51.40386588871479, 53.27514007687569, 51.529411152005196, 51.29333361983299, 53.658037930727005, 56.410294845700264, 58.124671652913094, 59.73411329090595, 61.13938428461552, 59.39231403172016, 52.23246082663536, 56.105361208319664, 65.93498155474663, 57.95930452644825, 55.34176178276539, 58.50999377667904, 54.37773451209068, 56.17954842746258, 51.530311703681946, 46.49446092545986, 46.39212481677532, 43.56071054935455, 40.677467063069344, 46.90852090716362, 62.380162104964256, 34.34131845831871, 10.757966581732035, 1.5534655353985727, 2.3682155599817634, 1.0349744511768222, 0.2296392823336646, 0.14124315610388294, 0.28343044279608876, 0.09047412488143891, 0.18972689198562875, 0.6905374210327864, 1.6739524388685822, 5.861477600410581, 11.274245828390121, 12.074265349656343, 12.02919501811266, 13.571629151701927, 14.85461700707674, 8.712440393865108, 4.229274708777666, 3.2609365694224834, 0.8531988551840186, 0.9861939155962318, 3.2846584590151906, 10.860960055142641, 14.471238479018211, 11.281330548226833, 6.435842430219054, 7.285225577652454, 4.444360742345452, 1.1767871165648103, 1.1297335289418697, 0.08470515866065398, 0.18980520340846851, 0.07391359671601094, 0.023612721524841618, 0.08243867676355876, 0.08244413154898211, 0.3181655367370695, 1.9158836756832898, 13.018537480384111, 30.05441889166832, 35.109530836343765, 38.98725315928459, 46.90178006887436, 47.84104786813259, 54.29172232747078, 49.11770336329937, 51.1423297226429, 56.64058528840542, 51.153801307082176, 51.589326336979866, 53.656932190060616, 53.91136273741722, 56.10043667256832, 52.79645696282387, 55.25212459266186, 57.13333524763584, 60.808011665940285, 51.60634562373161, 69.50246572494507, 73.69496315717697, 39.314271211624146, 62.327363938093185, 57.22689762711525, 57.39223435521126, 49.11174148321152, 46.42861045897007, 48.94607417285442, 47.43783250451088, 54.58016484975815, 59.11955326795578, 62.41084925830364, 60.933226346969604, 65.36568850278854, 62.04372055828571, 63.29372048377991, 57.99515940248966, 61.085780560970306, 5.678699808195233, 0.3650633624056354, 0.17451068270020187, 14.950545709580183, 80.6798167526722, 54.905951768159866, 68.24128299951553, 53.76225493848324, 62.54173703491688, 12.301429510116577, 8.39416567236185, 26.133245900273323, 43.3463716506958, 59.632635936141014, 25.12661151587963, 36.1142273247242, 27.0591327175498, 39.54641595482826, 26.19047272950411, 51.301772966980934, 68.19975882768631, 32.68212988972664, 1.5156097104772925, 0.1570115826325491, 0.1532655773917213, 0.16304396674968302, 0.08802039912552573, 0.01196029703351087, 0.07282541526365094, 0.15530963020864874, 0.0829405986587517, 0.2622189122484997, 0.12365203714580275, 0.32703909964766353, 0.10772174820885994, 0.1473063838784583, 0.16964118462055922, 0.25595278129912913, 0.11174716462846845, 0.4153906524879858, 1.561798369511962, 77.19191551208496, 60.815292075276375, 65.36090835928917, 45.18561355769634, 61.61191172897816, 52.33868032693863, 37.48832859098911, 68.84956195950508, 45.49772500991821, 28.706771805882454, 7.595635196194053, 15.716035533696413, 57.81810410320759, 73.92709270119667, 69.25876960158348, 54.32834096252918, 71.47486388683319, 20.11790458112955, 0.2935154578881338, 0.25541603041347116, 24.221794568002224, 74.34011533856392, 68.07390958070755, 67.8780072927475, 60.9532854706049, 64.38319802284241, 63.16808022558689, 66.05893850326538, 66.64087727665901, 65.15361428260803, 53.88508714735508, 55.636728554964066, 54.85223405063152, 53.355900943279266, 55.72888880968094, 58.95862430334091, 59.982657954096794, 59.809482246637344, 63.095272332429886, 65.11598110198975, 63.24521228671074, 56.31189152598381, 60.79433999955654, 67.44065836071968, 60.65020993351936, 59.83795031905174, 59.372422099113464, 55.653234869241714, 60.527457520365715, 54.7808700799942, 45.38478747010231, 45.56621253490448, 45.111012160778046, 39.86513525247574, 53.70576336979866, 73.78239646553993, 44.12351734936237, 21.876678206026554, 9.288679473102093, 4.6602309588342905, 2.1629807353019714, 0.5248349625617266, 0.22678692679619417, 0.42768171639181674, 0.12211337947519496, 0.29128269175998867, 1.8887771177105606, 2.2882906487211585, 18.597562462091446, 21.94184470921755, 21.145388446748257, 18.427398093044758, 18.716416284441948, 17.85371247678995, 7.513493578881025, 4.1526575200259686, 2.2645110497251153, 0.4546367871807888, 0.720931930700317, 2.2856006305664778, 9.29867198690772, 18.727880269289017, 18.735863640904427, 15.912446044385433, 16.93679317831993, 13.005486130714417, 4.187928652390838, 2.3874679394066334, 0.13356050272705033, 0.2406986482674256, 0.12081397537258454, 0.10498689691303298, 0.09984590637031943, 0.11968021120992489, 0.3635884477989748, 9.155177436769009, 28.524875566363335, 34.57228906452656, 38.67242105305195, 44.0143796056509, 47.42848880589008, 49.65130493044853, 54.64980371296406, 51.10231027007103, 54.479721039533615, 60.52746891975403, 54.123611748218536, 52.90854334831238, 56.70039027929306, 55.63253737986088, 58.963153660297394, 57.13723763823509, 55.87217912077904, 60.34922048449516, 61.591655015945435, 56.3898329436779, 65.37948176264763, 68.22378113865852, 43.22618789970875, 62.88328930735588, 59.830878898501396, 57.830890417099, 53.43126989901066, 48.258774653077126, 53.15200388431549, 50.158117935061455, 58.46870519220829, 61.18712492287159, 66.76732689142227, 62.21979171037674, 70.7303774356842, 65.40652871131897, 68.06873425841331, 59.59616929292679, 67.72002696990967, 14.620015695691109, 0.4765188926830888, 0.2746032492723316, 11.949450597167015, 79.53170835971832, 61.53226800262928, 72.2266535460949, 62.07502327859402, 65.07400095462799, 18.99736750870943, 12.65795012935996, 26.773709133267403, 55.05842998623848, 66.8069739639759, 28.125503696501255, 48.083463460206985, 33.69948349893093, 49.984307661652565, 34.65841144323349, 60.12886270880699, 79.33386817574501, 52.655290737748146, 2.727227658033371, 0.3147616615751758, 0.23950298898853362, 0.1927550177788362, 0.21773322980152443, 0.2083512512035668, 0.23635708435904235], [0.06696914279018529, 0.035711556192836724, 0.020604335004463792, 0.08056714359554462, 0.028341541801637504, 0.08745365805225447, 0.0688949714822229, 0.02915250512160128, 0.08874253850081004, 0.020218293902871665, 0.17495733685791492, 0.4288471257314086, 42.62922093272209, 54.99313808977604, 43.84717717766762, 33.653661757707596, 30.88335771113634, 54.26511995494366, 25.067182704806328, 17.08708841353655, 42.80645102262497, 31.09670866280794, 15.91736488044262, 1.3191962311975658, 30.97633682191372, 65.51910907030106, 61.846594735980034, 52.68023259937763, 60.33959940075874, 30.682736076414585, 0.6748980539850891, 0.07392344501568004, 6.2449705973267555, 60.9914506226778, 58.682797104120255, 60.3015748411417, 58.776735663414, 57.35623888671398, 59.05621066689491, 61.81033708155155, 60.30865766108036, 49.52675521373749, 47.724401727318764, 54.04165394604206, 53.0555384606123, 51.616757065057755, 51.48046217858791, 49.58701618015766, 55.52085377275944, 52.60932080447674, 56.345751509070396, 59.61738735437393, 56.30930006504059, 55.898314118385315, 55.7315144687891, 55.50303652882576, 64.60258305072784, 55.92096470296383, 55.46598091721535, 51.9375092536211, 53.55836547911167, 48.32694299519062, 41.03533186018467, 42.438615560531616, 39.60360288619995, 29.9429252743721, 40.032827854156494, 50.892299339175224, 11.87238598242402, 2.08922550547868, 2.142231473699212, 0.16798159398604184, 0.35011158033739775, 0.12993137090234086, 0.07874626942793839, 0.12045774448779412, 0.12293259176658466, 0.22293614514637738, 0.9064331080298871, 0.5817462899722159, 1.1837889533489943, 4.852995565161109, 5.923123117536306, 3.401145008392632, 4.127422599121928, 3.659162325784564, 0.5316256731748581, 0.9892417083028704, 0.1573336450383067, 0.08017261046916246, 0.33064011891838163, 0.4174721392337233, 0.6649765488691628, 2.4546490469947457, 1.2997171701863408, 8.605493232607841, 6.551942825317383, 4.591167764738202, 0.5797879700548947, 0.3803474782034755, 0.055853544326964766, 0.1317106551141478, 0.0654698560538236, 0.05872751120477915, 0.07433691032929346, 0.035527863510651514, 0.19338317157234997, 0.8126665488816798, 2.005800507031381, 18.833989575505257, 31.916182190179825, 36.86711512506008, 44.24044847488403, 43.15030977129936, 49.88851860165596, 50.457237884402275, 46.45010210573673, 43.78866031765938, 45.70560425519943, 49.78207491338253, 50.172807946801186, 52.50538118183613, 51.17259129881859, 52.370473220944405, 55.810599625110626, 52.54997178912163, 55.66703952848911, 56.20662197470665, 61.1055850982666, 38.21312829852104, 45.022704899311066, 58.404085859656334, 54.45098698139191, 51.924297362565994, 44.93693970143795, 46.60764165222645, 41.692795380949974, 46.24330960214138, 50.526808351278305, 53.66991609334946, 57.77089923620224, 58.997154235839844, 58.175866305828094, 59.871361926198006, 63.11095409095287, 65.70529147982597, 33.35896857082844, 0.18498112476663664, 0.45262043131515384, 0.10554065040196292, 18.47686193883419, 40.24921104311943, 52.41722211241722, 57.288857102394104, 53.83260056376457, 51.265937089920044, 4.37018159776926, 8.059674371033907, 29.620174393057823, 51.73622265458107, 46.361213475465775, 27.698457911610603, 34.787661507725716, 23.8821953907609, 41.02128781378269, 31.483609601855278, 46.86499424278736, 53.36245559155941, 18.263917565345764, 0.5961525638122112, 0.1643344428157434, 0.15218768210615963, 0.09887701031402685, 0.056403416383545846, 0.0673479720717296, 0.07986347627593204, 0.024765868729446083, 0.08893586797057651, 0.03187730588251725, 0.06639280574745499, 0.06710373127134517, 0.041132930127787404, 0.023659215221414343, 0.06813589541707188, 0.02079872203466948, 0.1114268165838439, 0.17754053027601913, 0.9525196475442499, 54.81042109429836, 65.27418181300163, 47.24015191197395, 32.43565991520882, 44.31637600064278, 56.20060309767723, 28.42281874269247, 29.87469233572483, 44.47196625173092, 30.555285215377808, 20.263668559491634, 2.7217395650222898, 29.789381213486195, 70.38541674613953, 68.56186419725418, 58.25827248394489, 67.36007988452911, 34.70540352165699, 0.8086876280140132, 0.06148320571810473, 5.899611404165626, 65.54637640714645, 62.2710395604372, 63.43301720917225, 62.09238454699516, 62.815386950969696, 61.27741567790508, 64.17309209704399, 61.622638553380966, 51.24223776161671, 48.87209974229336, 54.80146877467632, 56.2858971208334, 54.92908112704754, 54.62866544723511, 52.22308672964573, 56.30516208708286, 53.60458239912987, 60.37817873060703, 61.757318526506424, 57.14384168386459, 56.69773422181606, 58.33376303315163, 57.99341529607773, 67.75117009878159, 59.498324543237686, 56.14074110984802, 54.976122602820396, 54.8462987691164, 48.840386644005775, 44.06851910054684, 42.5015439838171, 42.91604094207287, 34.73297864198685, 48.99119295179844, 54.42721165716648, 21.47053699940443, 4.27667954005301, 2.38272603135556, 1.6707595414482057, 0.6939856172539294, 0.013908963464928092, 0.0604646785359364, 0.08212338274461217, 0.1522630694671534, 0.49292507639620453, 1.3335986458696425, 0.4566144326236099, 3.6720412597060204, 9.235933553427458, 12.53602797165513, 16.09710093587637, 13.965190183371305, 10.383247788995504, 2.8109241044148803, 2.488662446849048, 0.12134871503803879, 0.0423045289790025, 0.15236901846947148, 0.6476772646419704, 1.5078397211618721, 8.274587988853455, 13.42177564278245, 12.169281151145697, 6.900541819632053, 4.639480272307992, 1.242555056232959, 0.5143124959431589, 0.052849649655399844, 0.04404583007271867, 0.05655321147060022, 0.027974546064797323, 0.08569274199544452, 0.020791129863937385, 0.230504552309867, 1.1171596474014223, 8.09591207653284, 26.639587730169296, 38.505055233836174, 41.44227862358093, 48.05508278310299, 46.06550954282284, 57.31258302927017, 53.15246745944023, 48.777272030711174, 44.53701116144657, 49.31525096297264, 49.36498649418354, 51.31096087396145, 54.23915594816208, 55.27110457420349, 54.09334257245064, 58.561116233468056, 54.57613706588745, 60.591993257403374, 56.41134358942509, 72.7620980143547, 49.4932372123003, 48.57578404247761, 60.0354029238224, 56.61033511161804, 56.74669459462166, 47.77764067053795, 49.08379018306732, 44.24930199980736, 49.187475219368935, 53.42539921402931, 55.243024080991745, 58.18785846233368, 62.02515095472336, 62.63688772916794, 63.520480915904045, 63.601842150092125, 65.53602576255798, 32.818789556622505, 0.07124815107090399, 1.3167277886532247, 0.29384229972492903, 21.266805231571198, 41.56425207853317, 56.01165063679218, 61.22548386454582, 60.90470127761364, 55.19172303378582, 4.035297967493534, 16.26319382339716, 32.61343337595463, 48.220427110791206, 51.357272788882256, 27.55557607859373, 39.57875981926918, 27.784023620188236, 42.860761508345604, 31.732595041394234, 52.969723865389824, 67.20295071601868, 26.923322305083275, 0.912058053072542, 0.13949732790933922, 0.05204273104027379, 0.06152894056867808, 0.09767545838258229, 0.04238285153405741, 0.11276536897639744, 0.26176130399107933, 0.17027212888933718, 0.17180055234348401, 0.18240370525745675, 0.15759682544739917, 0.13305259170010686, 0.18959673412609845, 0.189021450933069, 0.3368323022732511, 0.27658282429911196, 0.2269203501055017, 1.7933121090754867, 71.24905720353127, 69.90864112973213, 62.22239077091217, 42.99778215587139, 48.86719800531864, 74.41475093364716, 33.30057330429554, 25.488418601453304, 51.77654229104519, 41.447993516922, 23.532249368727207, 5.895364182069898, 41.827691942453384, 77.10443660616875, 75.55063918232918, 61.89239367842674, 74.84669655561447, 35.67767634987831, 1.0924868588335812, 0.28343252080958337, 11.518738009035587, 72.88690611720085, 66.21851474046707, 68.10443714261055, 67.90758490562439, 63.044636249542236, 63.60299348831177, 69.22400146722794, 65.28851464390755, 55.844102427363396, 50.957598835229874, 55.29432512819767, 56.76615335047245, 58.228208497166634, 59.466904029250145, 55.477152317762375, 61.31883345544338, 57.032142877578735, 62.09578536450863, 62.77168169617653, 57.69622564315796, 60.58109924197197, 60.06264366209507, 63.66488076746464, 67.21847668290138, 58.647227212786674, 59.51067008078098, 59.866027012467384, 53.86609576642513, 52.674130126833916, 45.84864377975464, 47.35297545790672, 47.3179679363966, 40.208199843764305, 51.03294499218464, 54.15116786956787, 33.406188637018204, 15.3934689424932, 6.95029397495091, 3.733627167530358, 1.6375778219662607, 0.19254669692600146, 0.19306268251966685, 0.19449965853709728, 0.27418084850069135, 0.942515853093937, 2.6259683165699244, 0.5732516676653177, 11.892918180674314, 17.555770464241505, 22.591026574373245, 22.87134513258934, 18.27100608497858, 9.467511177062988, 2.242806851863861, 3.4018401335924864, 0.25680859631393105, 0.3964133426779881, 0.45124962518457323, 0.5769349762704223, 1.3594712200574577, 7.718628421425819, 14.269869234412909, 22.59788140654564, 11.346862781792879, 11.404988262802362, 3.5151479160413146, 0.6595474714413285, 0.4552233807044104, 0.18732222961261868, 0.3069214057177305, 0.14475387084530666, 0.17093396134441718, 0.15620653051882982, 0.23600368847837672, 1.0545759368687868, 19.837618321180344, 38.23533050715923, 44.29329223930836, 45.711402744054794, 50.426315143704414, 50.45921377837658, 57.72333338856697, 54.37511645257473, 50.04865720868111, 52.47195057570934, 50.248834267258644, 53.83114144206047, 55.69793947041035, 58.22018712759018, 57.6767098903656, 57.402949780225754, 59.759275540709496, 60.67108981311321, 62.979325354099274, 65.0788950920105, 65.56967675685883, 49.42635700106621, 50.06765998899937, 62.49727942049503, 58.739163279533386, 56.82598493993282, 49.456436187028885, 53.88455517590046, 46.289678514003754, 52.05094836652279, 56.253944635391235, 61.56096786260605, 62.84830458462238, 65.38561463356018, 63.79621312022209, 66.19216695427895, 66.2093648314476, 68.24950575828552, 42.87796698510647, 0.3451724391197786, 1.6268224990926683, 0.29530266823712736, 21.756431758403778, 52.09130600094795, 61.794244945049286, 67.45648831129074, 64.26722824573517, 64.47655901312828, 10.65790655091405, 15.028034951537848, 38.37066024541855, 62.840716391801834, 56.99066050350666, 37.76153393089771, 50.759728252887726, 32.52862952649593, 57.30458825826645, 42.55639024078846, 65.07131829857826, 76.19361028075218, 42.706683576107025, 1.9424152770079672, 0.31116191879846156, 0.2465182141168043, 0.2640834840713069, 0.2169028259231709, 0.16833190253237262, 0.1746829500189051], [0.02372713843215024, 0.09918325013131835, 0.026410870596009772, 0.01549228172734729, 0.007972930525284028, 0.061206495956867, 0.16475228680064902, 0.04330220923293382, 0.046518272793036886, 0.0500082964572357, 0.17815461294958368, 0.055964458297239617, 35.48482149839401, 56.94132775068283, 43.61136943101883, 33.96829627454281, 34.51099835336208, 44.5331771671772, 38.31660054624081, 19.763077720999718, 26.795981638133526, 23.705117292702198, 12.95792693272233, 7.652573715895414, 18.00646997988224, 56.78109034895897, 61.54678702354431, 45.9957604855299, 58.24666030704975, 36.876910999417305, 1.3191799633204937, 0.012073025554855121, 0.5727668374311179, 41.88630759716034, 58.62431824207306, 57.01169237494469, 58.373714089393616, 59.08037357032299, 57.83691689372063, 60.11666916310787, 58.10552068054676, 47.65798509120941, 53.36972840130329, 58.77238869667053, 60.20837724208832, 56.51186719536781, 51.175615936517715, 50.59760235249996, 51.22910566627979, 53.418996557593346, 57.80702769756317, 60.57577572762966, 54.72485348582268, 58.971927389502525, 54.99269351363182, 58.31085406243801, 58.10359798371792, 59.76997196674347, 63.52016173303127, 57.77966916561127, 45.44556520879269, 46.4132858812809, 47.20602594316006, 43.25193151831627, 39.10670354962349, 36.50907173752785, 35.5907978117466, 36.48198299109936, 4.157631453126669, 4.21421374194324, 0.9644457825925201, 1.049658169504255, 0.37602900993078947, 0.042053965080413036, 0.14140124840196222, 0.02860047712601954, 0.2578021539375186, 0.8992384909652174, 1.0777512495405972, 3.317435262724757, 2.8503545885905623, 3.068970632739365, 1.5864077489823103, 3.3730873139575124, 2.3847700841724873, 1.117176627740264, 0.2934372652089223, 0.20202447194606066, 0.10980481572914869, 0.03572362722479738, 0.30176882282830775, 0.13747880497248843, 0.1524265794432722, 0.8243582840077579, 0.9784385317470878, 2.019244423136115, 2.001858693547547, 2.2957833716645837, 1.706166872754693, 0.9153959958348423, 0.5909764103125781, 0.19973693531937897, 0.03711081626533996, 0.2367274754215032, 0.054440075837192126, 0.16033570660511032, 0.010936188900814159, 0.10152120827115141, 2.7983546163886786, 8.970110267400742, 24.368592090904713, 36.63942754268646, 40.810725912451744, 49.05048877000809, 48.26708860695362, 37.90036328136921, 39.038896188139915, 46.72322764992714, 49.896832555532455, 49.364055544137955, 43.14525984227657, 50.97787834703922, 50.67004546523094, 54.54801857471466, 52.906996831297874, 58.1585468351841, 52.7107335627079, 61.90862640738487, 51.94391191005707, 30.75986433774233, 52.048740684986115, 53.12501773238182, 59.464570954442024, 51.32493272423744, 46.21610686182976, 47.5441849976778, 45.02079740166664, 48.536600545048714, 48.046803027391434, 50.00261127948761, 51.282291412353516, 57.13678926229477, 58.10450233519077, 63.33625540137291, 58.240052461624146, 55.70042073726654, 12.464889138936996, 0.09117679772316478, 0.15260962274624035, 1.4423763589002192, 14.123373795300722, 46.98597975075245, 64.00261044502258, 55.92336617410183, 60.09479373693466, 22.801468782126904, 1.6522202175110579, 22.259087786078453, 29.145682454109192, 46.161651983857155, 34.88899067044258, 28.98411512374878, 37.05051228404045, 23.05147636681795, 35.37109360098839, 24.03497189283371, 48.55097137391567, 57.058095484972, 17.43355382233858, 0.3070025669876486, 0.15870054747210816, 0.06606718103284948, 0.03450263844570145, 0.11155256608617492, 0.011106749279861106, 0.07194162128143944, 0.014391634977073409, 0.05205238638154697, 0.0631865719333291, 0.034009139926638454, 0.05344453667930793, 0.05151015102455858, 0.10224440149613656, 0.007212853024611832, 0.10472211346495897, 0.03611322506912984, 0.11453501268988475, 0.08062965469434857, 42.85471983253956, 66.33257701992989, 45.35780131816864, 31.139365173876286, 46.03641830384731, 47.42788843810558, 36.055904254317284, 26.76445472985506, 26.386207826435566, 28.07036105543375, 12.612026743590832, 11.956872548907995, 23.519882932305336, 56.181999295949936, 66.95640474557877, 51.68307110667229, 65.4576587677002, 43.989342749118805, 2.0773682417348027, 0.13424118573311716, 0.5176550103351474, 44.522264152765274, 67.04468160867691, 60.8497030287981, 63.04672613739967, 62.70803891122341, 62.87317045032978, 63.329366371035576, 58.02680790424347, 49.86347794532776, 56.99868947267532, 65.26519909501076, 63.87122109532356, 60.10876938700676, 54.17015165090561, 53.011742010712624, 54.327056631445885, 58.09552721679211, 60.36543421447277, 61.17342285811901, 59.863617941737175, 59.00501601397991, 55.863576382398605, 57.6085339486599, 59.88977573812008, 65.45308381319046, 68.44029352068901, 57.87498705089092, 48.68782863020897, 46.888777166604996, 46.55965022742748, 44.89680625498295, 43.06044079363346, 40.602451488375664, 46.36223562061787, 42.47112661600113, 12.463381569832563, 3.3943566726520658, 3.465163973160088, 1.5264346171170473, 0.4410971043398604, 0.06596768129384145, 0.12639978696824983, 0.017732806081767194, 0.22167692834045738, 0.5084078502841294, 1.905250777490437, 1.1735160858370364, 5.54609214887023, 13.453599885106087, 17.88197536021471, 16.45529631525278, 9.39196553081274, 4.350751340389252, 0.6730787828564644, 1.0779051412828267, 0.1482963643502444, 0.23719154036371037, 0.3431771305622533, 0.03859421733068302, 0.39183485554531217, 2.3249660432338715, 7.222938369959593, 12.437839340418577, 11.714062727987766, 8.185092341154814, 3.1343147763982415, 0.3030791290802881, 0.03962493428844027, 0.23295887920539826, 0.05476807913510129, 0.16151809628354385, 0.07237033772980794, 0.1468078832840547, 0.025047279996215366, 0.271290450473316, 2.8661835892125964, 13.679130133241415, 32.359082624316216, 42.793258130550385, 44.72240701317787, 52.27254867553711, 51.900408044457436, 41.22675038874149, 42.466285675764084, 47.54669666290283, 51.82935945689678, 53.50091256201267, 44.220495745539665, 52.6318383961916, 53.90716776251793, 56.74268580973148, 54.396095126867294, 60.65206803381443, 53.83964158594608, 60.41754461824894, 64.88133609294891, 36.79634012281895, 52.66924358904362, 56.61932922899723, 61.12448528409004, 56.76845222711563, 49.010997489094734, 50.80209977924824, 49.05657984316349, 51.44887067377567, 49.67368572950363, 51.76666282117367, 54.495182409882545, 59.210007414221764, 59.78549413383007, 67.39678591489792, 60.713366344571114, 58.282697573304176, 12.329482454806566, 0.1444336341228336, 0.17552827106555924, 2.0338715007528663, 18.916369155049324, 56.403546407818794, 70.05287379026413, 58.055401369929314, 65.13765513896942, 21.55582532286644, 2.6077841548249125, 27.39721767604351, 31.360108628869057, 49.05963867902756, 42.791757211089134, 30.849883407354355, 40.93470185995102, 26.40035256743431, 40.508828312158585, 25.350151620805264, 53.96822668612003, 70.92767804861069, 21.93128127604723, 0.4974674357799813, 0.16923778282944113, 0.1418193892459385, 0.053510606376221403, 0.13590282469522208, 0.07370947641902603, 0.02672159855137579, 0.13776003441307694, 0.3343776933616027, 0.1949131238507107, 0.08745906830881722, 0.15264316782122478, 0.12328697470366023, 0.2034522156463936, 0.1325965122669004, 0.3159208071883768, 0.22931117884581909, 0.2808073366759345, 0.3530000487808138, 58.97740289568901, 75.50182700157166, 57.029904797673225, 47.56128028035164, 48.230629563331604, 66.26037329435349, 49.819654896855354, 31.879901736974716, 33.72999206185341, 32.390271350741386, 20.496204681694508, 14.166896659880877, 24.332602322101593, 62.48651459813118, 72.47373908758163, 57.16645047068596, 70.39188399910927, 45.43908655643463, 2.409135801717639, 0.20486722409259528, 2.445472776889801, 58.24571035802364, 69.44698110222816, 68.99358183145523, 67.17756807804108, 68.01420718431473, 65.18223434686661, 66.7577438056469, 62.24653087556362, 53.783860579133034, 58.198266103863716, 66.09198912978172, 65.80895751714706, 64.5038415491581, 58.45900811254978, 55.99810056388378, 56.8137001991272, 60.31759098172188, 62.8645259141922, 61.70188330113888, 60.93811668455601, 61.49639032781124, 59.74514029920101, 60.71674816310406, 64.90995615720749, 66.92184939980507, 65.64445674419403, 57.28188067674637, 59.18147474527359, 51.19905687868595, 47.764098197221756, 49.51749891042709, 45.7519655674696, 47.214598283171654, 45.10837510228157, 45.31472682952881, 26.000604517757893, 8.613087125122547, 6.101913023740053, 4.602614175528288, 1.1474988819099963, 0.16978743224171922, 0.27806593221612275, 0.16811659064842388, 0.4593829996883869, 1.9216045062057674, 4.21340961009264, 5.06103060208261, 15.502884071320295, 24.120995476841927, 26.334032826125622, 21.507765501737595, 10.363671239465475, 4.368171980604529, 1.0503181465901434, 1.7053173808380961, 0.2760294789914042, 0.3196298534749076, 0.46292544866446406, 0.1787232464994304, 0.6201741029508412, 4.172092527151108, 8.60227670520544, 14.523800108581781, 15.595373958349228, 12.78958361595869, 6.442574243992567, 3.1269113486632705, 1.7137615964747965, 0.4636906029190868, 0.1974758636788465, 0.23175139009254053, 0.1102206262294203, 0.2801039587939158, 0.30116462556179613, 0.6590458983555436, 4.292839597910643, 30.333838798105717, 37.84714713692665, 47.05554261803627, 48.58527213335037, 55.42831353843212, 51.701583713293076, 47.77112402021885, 49.17497009038925, 50.64121261239052, 54.324347376823425, 55.23993864655495, 49.25324209034443, 58.23871873319149, 59.30299982428551, 60.53901270031929, 58.37323531508446, 66.39167904853821, 57.95821778476238, 67.68854185938835, 53.51145699620247, 39.02266725897789, 55.1122161000967, 58.18660832941532, 63.87106150388718, 60.12692481279373, 50.84438771009445, 52.55477853119373, 50.1930570602417, 55.57268679141998, 51.50376632809639, 55.013242810964584, 56.10211618244648, 65.14954090118408, 63.33269119262695, 69.6582193672657, 62.98910602927208, 66.1394713819027, 15.095358788967133, 0.20608225342584774, 0.3487998788477853, 1.986958149354905, 17.86326326429844, 59.23623360693455, 74.10743102431297, 66.49974524974823, 70.30147165060043, 34.387447983026505, 5.236632479354739, 31.092109009623528, 39.454046711325645, 56.32747448980808, 45.29459170997143, 40.42841322720051, 52.566364109516144, 32.34313488006592, 50.21472729742527, 35.78343987464905, 65.08269488811493, 79.10423889756203, 36.11404113471508, 1.6270069079473615, 0.3907474607694894, 0.15027372777694836, 0.24344677658518776, 0.2673058892833069, 0.17740744835464284, 0.18734441982815042], [0.02069304206088418, 0.07045326638035476, 0.05171936245460529, 0.06187996899825521, 0.03711854573339224, 0.11832280826638453, 0.07417836532113142, 0.08914087142329663, 0.06720550198224373, 0.08384356973692775, 0.21919741295278072, 0.037091205012984574, 31.640721671283245, 59.415994361042976, 42.69150339066982, 37.924096807837486, 30.146183967590332, 50.94893530011177, 41.73625744879246, 32.60019488632679, 22.047988213598728, 31.94818027317524, 14.484895896166563, 5.3586439322680235, 39.897186532616615, 63.19663569331169, 64.32429358363152, 44.64331045746803, 57.06930488348007, 46.186023876070976, 4.03242627158761, 0.05515768069017213, 0.08036690473090857, 20.661763697862625, 59.44781765341759, 54.737586602568626, 63.81505250930786, 59.87896911799908, 60.44712983071804, 59.75995570421219, 51.90059043467045, 51.65360368788242, 63.07452164590359, 59.53585892915726, 63.46097610890865, 59.79636915028095, 54.482867270708084, 45.41571021080017, 51.31058469414711, 53.75940889120102, 59.76361870765686, 55.470267087221146, 57.10621990263462, 57.72657461464405, 53.74324455857277, 53.42676714062691, 55.555135533213615, 51.16131350398064, 55.28245076537132, 70.10054603219032, 76.83852687478065, 47.20625013113022, 39.704502671957016, 43.22637028992176, 38.636478781700134, 31.212021075189114, 27.500708922743797, 18.979175984859467, 3.281709817238152, 4.180790260434151, 0.39200489642098546, 0.6415724765975028, 0.203352574899327, 0.14026611868757755, 0.08723338862182572, 0.30921428580768406, 1.1787228751927614, 1.660578225273639, 9.001129902899265, 6.71699789352715, 7.934952713549137, 5.996758891269565, 3.6800559796392918, 2.0238618878647685, 1.1749404156580567, 0.29761048033833504, 0.3375154046807438, 0.5909743916708976, 0.20562445221003145, 0.10538537084357813, 0.12527209357358515, 0.04395257921714801, 0.28516908700112253, 0.1478976826183498, 1.1966574378311634, 1.1011623870581388, 4.494987800717354, 4.329470582306385, 4.035691721364856, 3.345542591996491, 5.139538664370775, 0.16034823405789211, 0.1438919108477421, 0.09973082153010182, 0.023117115306376945, 0.06545407057274133, 0.01634741489397129, 0.07361692318227142, 0.1372685396927409, 4.197311298921704, 19.750897474586964, 38.13816972076893, 38.796989768743515, 46.320635452866554, 41.05813443660736, 44.9200876057148, 52.75544196367264, 44.519923478364944, 44.02944579720497, 55.373984053730965, 46.79560996592045, 39.9872986972332, 43.16306188702583, 55.03917641937733, 54.72114108502865, 56.74732156097889, 51.85824170708656, 69.98108044266701, 32.416459545493126, 31.97408728301525, 58.707168996334076, 56.90458372235298, 56.92773588001728, 48.576167821884155, 47.25251644849777, 44.90589536726475, 44.845463410019875, 48.61653685569763, 51.091150268912315, 54.212937355041504, 54.864480793476105, 56.031812354922295, 56.868098080158234, 63.05159367620945, 55.280360877513885, 45.47470964491367, 8.894717562943697, 0.052466853594523855, 0.1519973954418674, 2.2102309623733163, 56.04354612529278, 59.58578445017338, 53.79215933382511, 49.246489852666855, 51.314293295145035, 17.67962671816349, 2.9277892084792256, 33.92380066215992, 36.466905400156975, 60.94893850386143, 28.476690351963043, 29.77625671774149, 29.49602745473385, 24.358610026538372, 36.07673093676567, 31.20784319937229, 48.382986187934875, 61.408789828419685, 11.384047586470842, 0.2822937397286296, 0.16437006590422243, 0.042516159810475074, 0.14354339829878882, 0.06161734891065862, 0.021134234011697117, 0.018306098463654052, 0.040864628899726085, 0.2134823118103668, 0.1230441959341988, 0.05405239273386542, 0.041991227626567706, 0.11536399906617589, 0.0331950076360954, 0.05036782247771043, 0.12955030775628984, 0.11767233067075722, 0.11292363938991912, 0.11507302522659302, 38.32131989300251, 68.5900890827179, 47.55960077047348, 34.98409576714039, 38.5766775906086, 56.87128230929375, 33.080796897411346, 34.257164373993874, 23.261200413107872, 38.4360471367836, 19.381678886711597, 4.821858610957861, 40.31217746436596, 69.70428049564362, 65.38491547107697, 50.23190997540951, 63.82056221365929, 50.81834390759468, 5.057685831561685, 0.17113017034716904, 0.7082413241732866, 23.173529617488384, 69.70387011766434, 56.90951205790043, 65.97817003726959, 62.170318365097046, 64.38652664422989, 62.24545173346996, 56.238688454031944, 52.91178837418556, 65.48399895429611, 62.556757628917694, 66.34603589773178, 62.22922280430794, 57.265910133719444, 48.3620835095644, 53.539913669228554, 55.47920800745487, 61.16305701434612, 58.35267461836338, 60.907630920410156, 60.877547934651375, 55.77307663857937, 54.44145329296589, 58.5772729665041, 51.652722135186195, 60.28430476784706, 74.9461980164051, 68.38467210531235, 53.02166327834129, 44.46146361529827, 43.78308601677418, 40.42996734380722, 40.62495008111, 44.07522574067116, 28.074668124318123, 4.168314104899764, 5.870455568656325, 2.109604999423027, 0.9502253425307572, 0.547848962014541, 0.034448316946509294, 0.016530148350284435, 0.27084824920166284, 0.9189992712344974, 1.1761162150651217, 6.952998004853725, 9.444794096052647, 13.27035091817379, 14.568478111177683, 18.531187623739243, 12.404019255191088, 4.813789743930101, 1.0770080331712961, 0.13887165288906544, 1.0104861902073026, 0.23857908934587613, 0.07966847697389312, 0.10288163175573573, 0.04492075167945586, 0.369393348810263, 1.0456293169409037, 4.22064489684999, 8.90987304970622, 10.035770684480667, 7.469215504825115, 4.552421243861318, 3.56350792106241, 3.2530793035402894, 0.0472639382496709, 0.10352708501159213, 0.06836340078734793, 0.03575590693799313, 0.0839991684188135, 0.11410855979193002, 0.06117060569522437, 0.25354305747896433, 7.565183630213141, 28.004197105765343, 44.16165970265865, 44.298357367515564, 49.8436164110899, 46.66995830833912, 53.880409598350525, 47.849832996726036, 45.684116408228874, 43.95612493157387, 57.40292698144913, 50.95322526991367, 42.15264290571213, 43.773214146494865, 57.52320192754269, 57.14713990688324, 59.406449273228645, 51.02992035448551, 76.99954703450203, 42.75774143636227, 36.01461187005043, 64.72066551446915, 57.10948012769222, 59.74822573363781, 52.54298776388168, 49.11091312766075, 47.838957980275154, 49.045058861374855, 50.21392174065113, 51.85139447450638, 57.92850337922573, 57.8528418391943, 60.66354721784592, 60.1593978703022, 64.84636276960373, 58.98810692131519, 49.962227046489716, 7.859042761847377, 0.05695672829460818, 0.19963687896961346, 3.1390937324613333, 54.005692675709724, 59.04305577278137, 60.465870425105095, 57.01225094497204, 59.19264614582062, 20.571322850883007, 3.288490790873766, 36.296343952417374, 42.59989030659199, 67.81616941094398, 35.463204458355904, 30.07158637046814, 36.24693900346756, 27.15951383113861, 39.852664321660995, 31.848329231142998, 56.00808642804623, 72.06738889217377, 13.979116436094046, 0.13406583108007908, 0.17646498017711565, 0.1264135167002678, 0.05937336522038095, 0.08863781404215842, 0.03399496119527612, 0.030431550258072093, 0.18420575855998322, 0.4656467854510993, 0.22081226692534983, 0.12522101897047833, 0.25088578287977725, 0.18625518452608958, 0.11798684543464333, 0.15031473885755986, 0.19434538087807596, 0.17634957621339709, 0.48353281163144857, 0.18183343898272142, 51.11062802374363, 79.2091816663742, 56.74014754593372, 55.658767372369766, 40.87413690984249, 76.8247564136982, 54.070213213562965, 47.21039570868015, 31.311921514570713, 41.651977971196175, 22.189072743058205, 13.230160474777222, 48.41129086911678, 75.08836358785629, 74.62259978055954, 56.64736032485962, 67.58232995867729, 55.63428908586502, 5.856749229133129, 0.5541991931386292, 0.9189586015418172, 34.61858578026295, 77.58248135447502, 62.76894964277744, 72.00472265481949, 69.07117366790771, 66.5558834373951, 66.62862673401833, 59.37373302876949, 55.61676822602749, 66.76914319396019, 63.97543430328369, 69.80612263083458, 68.19184005260468, 58.91272656619549, 49.15823198854923, 57.81772032380104, 59.609688967466354, 64.89000722765923, 60.29973953962326, 62.701970636844635, 66.12820118665695, 55.619439482688904, 57.50180907547474, 59.24338102340698, 58.036957159638405, 67.7096763253212, 67.32784241437912, 56.28940433263779, 51.288215294480324, 46.250954791903496, 51.349084228277206, 45.60763031244278, 42.95462027192116, 41.38062693178654, 40.739939510822296, 18.15902229398489, 8.29329438507557, 5.96654006280005, 3.9365749899297953, 1.0303012956865132, 0.32919946184847504, 0.18807306041708216, 0.7380180701147765, 2.2521726367995143, 5.7861504424363375, 19.42362103611231, 20.865079388022423, 23.090173490345478, 21.424703858792782, 24.60668731480837, 17.414509244263172, 4.887568010017276, 0.7702920539304614, 0.3723494417499751, 0.9674568241462111, 0.2691425563534722, 0.19683880411321297, 0.21436839160742238, 0.12187538013677113, 0.37046604906208813, 0.6971577939111739, 5.081951804459095, 12.541110198944807, 13.706680554896593, 12.92080007493496, 8.008485417813063, 7.52608135342598, 8.134258668869734, 0.5892875790596008, 0.169078636681661, 0.13711025443626568, 0.127516437205486, 0.1745389585266821, 0.3668892534915358, 0.2354738098802045, 0.36786808690521866, 15.553997978568077, 38.73785734176636, 45.47366090118885, 49.27058055996895, 52.7234248816967, 53.72566670179367, 56.81219927966595, 51.290050595998764, 44.234327003359795, 46.87687620520592, 57.97771833837032, 52.76871085166931, 50.33512003719807, 51.012771874666214, 60.202088579535484, 59.821599796414375, 64.61683228611946, 57.89085499942303, 67.26443141698837, 42.45680518448353, 37.11396507918835, 62.92723394930363, 62.42948345839977, 64.57520171999931, 54.05761308968067, 51.39962911605835, 51.66976422071457, 50.31727999448776, 54.103013053536415, 56.270082369446754, 59.829081594944, 60.36525562405586, 64.50516387820244, 63.13262812793255, 68.46758365631104, 60.74643976986408, 56.00496679544449, 12.148533314466476, 0.1370615398627706, 1.0571334371343255, 4.5615388546139, 63.5316751152277, 68.81563737988472, 63.10233995318413, 60.71819968521595, 63.931934237480164, 25.714493170380592, 6.218288904055953, 43.33184503018856, 49.416466131806374, 73.58950361609459, 35.297628343105316, 40.16659587621689, 47.31096111238003, 33.5469064861536, 49.631318002939224, 45.23204706609249, 66.20611220598221, 85.40797904133797, 24.106263667345047, 0.941070921253413, 0.5343241814989597, 0.20097298227483407, 0.5102396488655359, 0.2282114198897034, 0.13389077328611165, 0.17118574236519635], [0.04796797293238342, 0.08334765181643888, 0.09060728101758286, 0.05649293052556459, 0.05893937581276987, 0.03301402750366833, 0.08338115236256272, 0.023015012484393083, 0.2571098192129284, 0.05306312472384889, 0.44055667240172625, 0.08819038805086166, 23.294655717909336, 63.83770689368248, 41.26524992287159, 36.6101311147213, 37.23996251821518, 40.714838057756424, 48.80838856101036, 36.77668757736683, 22.58899938315153, 22.561809942126274, 40.930119305849075, 2.7541112154722214, 15.633826944977045, 62.40459479391575, 64.5089864730835, 54.078857749700546, 53.5553864389658, 54.09936144948006, 4.398315288126469, 0.21019628969952464, 0.5946951638907194, 6.196302808821201, 59.6544885635376, 55.83142250776291, 59.15413521230221, 57.925566136837006, 60.2633260935545, 56.14637240767479, 51.56035289168358, 55.80297343432903, 64.02556881308556, 60.74303135275841, 60.09753338992596, 57.193372026085854, 58.24174337089062, 51.73763617873192, 51.859632432460785, 51.12172342836857, 57.52949818968773, 60.5355928838253, 61.41344837844372, 56.754058599472046, 56.153246238827705, 48.9569415897131, 56.38277292251587, 61.72861106693745, 48.09610158205032, 41.578858494758606, 70.29960975050926, 103.20686236023903, 60.47720521688461, 40.78485310077667, 32.32215240597725, 37.48835138976574, 30.166693367064, 11.809890735894442, 5.751395607367158, 2.4888087389990687, 1.1973425885662436, 0.24971372389700264, 0.3504193341359496, 0.04469680119655095, 0.40839398105163127, 0.9924439864698797, 2.619680128991604, 9.429480917751789, 29.049327224493027, 22.641252279281616, 10.92530770227313, 3.6181456642225385, 3.2800965663045645, 1.8518983153626323, 0.8849754219409078, 0.05961726092209574, 0.18317136797122657, 0.815912049729377, 0.23104211955796927, 0.013211222194513539, 0.04765091260196641, 0.019152311942889355, 0.07829117705114186, 0.057743542129173875, 0.8371359296143055, 4.290260961279273, 2.9154985304921865, 5.085031064227223, 6.534633804112673, 13.716474529355764, 9.75852806121111, 0.8510103507433087, 0.4047943273326382, 0.04171229884377681, 0.03996350948000327, 0.040013470861595124, 0.025434447306906804, 0.02550198831158923, 0.1322581819840707, 1.966069838963449, 15.301776062697172, 30.395192205905914, 42.03092023730278, 37.866864278912544, 48.81539538502693, 54.25464391708374, 42.23332777619362, 41.73474133014679, 47.647577449679375, 54.424582198262215, 59.63529959321022, 48.51456552743912, 38.43633592128754, 41.6429952532053, 48.891459703445435, 52.58237265050411, 65.85858285427094, 47.2160080075264, 24.01016492396593, 51.66925884783268, 60.7170445472002, 58.596883714199066, 52.71394059062004, 50.588395446538925, 44.54412437975407, 45.33260866999626, 47.181566655635834, 54.865784123539925, 51.47048391401768, 59.128304198384285, 56.39717034995556, 59.55145709216595, 58.88410650193691, 59.727342054247856, 53.568085357546806, 34.70450296998024, 2.541054510511458, 0.01942416620295262, 0.6050576828420162, 6.136954268440604, 58.6199826747179, 57.83072702586651, 59.42113168537617, 39.40063677728176, 59.21994008123875, 12.654319424182177, 4.61871343664825, 44.94738534092903, 29.210258089005947, 56.25079080462456, 30.076564103364944, 37.2196564078331, 28.575990423560143, 27.668975293636322, 28.323136791586876, 21.046916730701923, 47.87743851542473, 62.477455884218216, 6.763549195602536, 0.3263901954051107, 0.11176120606251061, 0.008010084293346154, 0.07330514694331214, 0.05579376804234926, 0.04040259002067614, 0.028553065021696966, 0.06986877313465811, 0.03339480121212546, 0.13862788706319407, 0.08221689335186966, 0.03758580933208577, 0.1024675504595507, 0.06584389106137678, 0.04412475376739167, 0.056338222420890816, 0.18829101434675977, 0.2949860383523628, 0.18172619864344597, 24.488278068602085, 71.93607553839684, 49.483593329787254, 30.628359094262123, 38.81896398961544, 49.273939579725266, 35.034891441464424, 35.82186721265316, 20.569527447223663, 25.938713438808918, 56.95664472877979, 4.546935288235545, 13.8569244928658, 65.44772610068321, 68.23672324419022, 57.461056262254715, 57.84972980618477, 60.54941654205322, 5.3766844142228365, 0.5057207413483411, 0.38441486307419837, 9.01992179453373, 68.52789402008057, 62.26268760859966, 63.498331904411316, 60.723067224025726, 64.60826754570007, 59.48399931192398, 53.389684930443764, 60.61921499669552, 66.02238446474075, 64.3890269100666, 64.85075533390045, 59.792417362332344, 58.911643624305725, 55.086575075984, 53.77040550112724, 53.850045427680016, 59.092399924993515, 62.27267347276211, 65.95816031098366, 60.604676976799965, 59.241754710674286, 48.85323755443096, 58.3275655657053, 63.12282845377922, 48.80890533328056, 48.45689222216606, 74.73170712590218, 89.90864753723145, 56.12978249788284, 44.459666311740875, 41.03983461856842, 49.15343664586544, 46.95958636701107, 22.516845054924488, 5.964041221886873, 7.217622930184007, 3.0439672619104385, 1.3605437125079334, 0.7031734054908156, 0.15968043473549187, 0.5208090192172676, 1.4467007643543184, 2.8150437958538532, 7.734800828620791, 25.812657102942467, 24.952223673462868, 18.333944007754326, 15.33616991713643, 14.460455607622862, 8.531634695827961, 2.070820005610585, 0.28947458253242075, 0.15324647451052442, 0.8512328169308603, 0.1205847185337916, 0.029861801631341223, 0.0534500768117141, 0.07098559406585991, 0.10909062475548126, 0.08588744443841279, 2.181805637665093, 5.760359801352024, 9.287797920405865, 10.142308417707682, 12.390680070966482, 15.6347312964499, 10.779741313308477, 0.4469750326825306, 0.11309201785479672, 0.03065945638809353, 0.08857722510583699, 0.0495421535015339, 0.06227713674888946, 0.04963878855051007, 0.31367046700324863, 1.9004606595262885, 23.669982478022575, 37.94779233634472, 46.90714918076992, 43.076738119125366, 56.61129266023636, 51.955957263708115, 42.25012667477131, 44.58071641623974, 47.96096943318844, 56.368166506290436, 62.89931684732437, 60.41000582277775, 43.116381391882896, 44.80205073952675, 50.67408844828606, 52.2230639308691, 66.45802348852158, 56.81614346802235, 30.477332398295403, 56.04872904717922, 60.42707830667496, 61.728823855519295, 56.28943473100662, 53.1680504232645, 45.34928597509861, 49.59362782537937, 51.462952718138695, 57.989725694060326, 54.80439081788063, 61.441623866558075, 59.28004525601864, 63.172301799058914, 60.86642973124981, 61.30241073668003, 56.30596004426479, 36.200653687119484, 2.159137004055083, 0.06860459136078134, 0.6184842623770237, 7.385840378701687, 60.4512982070446, 60.11380411684513, 66.37055218219757, 47.00586028397083, 64.22536969184875, 11.225197110325098, 7.182584535330534, 55.72120562195778, 31.7026374489069, 65.6650972366333, 33.19205492734909, 33.254048600792885, 35.172113478183746, 30.646738708019257, 31.903080493211746, 23.819960430264473, 54.27104003727436, 68.2534271478653, 10.463042557239532, 0.0928757073415909, 0.08117738936562091, 0.031003746116766706, 0.10013019345933571, 0.02686305746465223, 0.05567071624682285, 0.036051871720701456, 0.14587261393899098, 0.16030533792218193, 0.23812617146177217, 0.16448207083158195, 0.12316544802160934, 0.24223284563049674, 0.2387362316949293, 0.20813883369555697, 0.2566015667980537, 0.18757911660941318, 0.45308792497962713, 0.30035182542633265, 35.613923370838165, 90.61407208442688, 56.63394704461098, 53.15510831773281, 47.23731726408005, 65.54568484425545, 60.62098190188408, 52.14474633336067, 32.212003916502, 31.60579964518547, 53.02848391234875, 6.879334207624197, 23.17820906639099, 73.00919875502586, 74.75712776184082, 66.86201021075249, 64.52094823122025, 64.85571026802063, 5.237007234245539, 0.9380209911614656, 1.2311156513169408, 14.817617442458868, 78.93745064735413, 67.23926156759262, 69.83309358358383, 65.12539699673653, 67.70100519061089, 62.69295372068882, 58.16887088119984, 61.739543080329895, 70.3124150633812, 67.30637356638908, 67.2580173611641, 62.45186045765877, 62.682375088334084, 56.658334136009216, 56.680517345666885, 55.77422417700291, 63.068601563572884, 67.69230365753174, 65.25188460946083, 63.97216647863388, 60.61793066561222, 54.43073786795139, 62.63808846473694, 63.17634478211403, 51.656556129455566, 63.031686544418335, 79.14576306939125, 80.18792554736137, 54.6956292539835, 49.96612563729286, 39.66989792883396, 50.637093633413315, 55.17204388976097, 39.617164358496666, 14.716532416641712, 10.028204340487719, 6.818136591464281, 3.6644801404327154, 1.4268281869590282, 0.23613245110027492, 0.6367517821490765, 2.078300379216671, 4.401447745040059, 20.262777507305145, 49.82454903423786, 46.38169437646866, 30.77452775090933, 20.70982351899147, 16.359197571873665, 8.358828518539667, 1.9063929724507034, 0.25264651339966804, 0.25567984906956553, 1.4163273316808045, 0.40860196051653475, 0.14395002101082355, 0.14499141747364774, 0.17292570759309456, 0.17961904843105003, 0.08573430226533674, 1.4730504504404962, 6.833529565483332, 12.479623798280954, 18.93825028091669, 25.369241796433926, 31.52472909539938, 19.041808024048805, 7.073205029591918, 0.7375270058400929, 0.31876762630417943, 0.15074267605086789, 0.20266688981791958, 0.19965835672337562, 0.4654165415558964, 0.6940239120740443, 4.758326970040798, 35.84276609122753, 41.54255524277687, 50.109993517398834, 46.23428888618946, 61.078104972839355, 54.22457613050938, 45.176235660910606, 47.159820422530174, 50.41891314089298, 57.40715995430946, 60.856675654649734, 58.33237610757351, 48.188501223921776, 52.29711055755615, 57.42553576827049, 56.58578082919121, 63.15240986645222, 58.284692466259, 33.238689824938774, 55.76320476830006, 66.13849863409996, 63.644563257694244, 60.498560070991516, 55.488403514027596, 50.269303768873215, 51.090549901127815, 53.740694895386696, 59.09061402082443, 56.77712716162205, 66.27028316259384, 63.17375712096691, 66.45648077130318, 65.68419501185417, 66.67340353131294, 63.30709956586361, 42.506829500198364, 5.436705043539405, 0.3408461040817201, 1.0459304507821798, 7.7849391382187605, 69.62709903717041, 70.26574596762657, 67.92194813489914, 53.43825772404671, 68.46468061208725, 19.321476817131042, 8.566399980336428, 60.69858133792877, 39.16125722229481, 68.15049827098846, 34.41484071314335, 47.47872970998287, 47.90259696543217, 38.28686714172363, 43.15131291747093, 34.54744599759579, 62.94065102934837, 86.1187992990017, 16.337804719805717, 0.6572496041189879, 0.455579700646922, 0.0974707369459793, 0.5703035602346063, 0.0894095363037195, 0.18708978896029294, 0.15665449085645378], [0.03240140315028839, 0.07827453067875467, 0.19152729772031307, 0.03203727581421845, 0.03831538502709009, 0.11191545403562486, 0.031742669161758386, 0.032370474145864137, 0.028636298739002086, 0.18544279999332502, 0.11527545342687517, 0.29818816808983684, 9.036104176193476, 60.81027254462242, 47.949862629175186, 39.110514745116234, 27.340859100222588, 38.92612963914871, 47.930970042943954, 25.608079880475998, 33.53054456412792, 24.571911580860615, 35.702925994992256, 6.600332278758287, 8.185001146048307, 56.651764288544655, 65.03591939806938, 55.66434547305107, 54.29153233766556, 55.9487260133028, 6.426447909325361, 0.2139785117469728, 0.181077902961988, 2.6661839336156845, 50.94849452376366, 58.85541804134846, 60.174065083265305, 58.42933930456638, 62.90539652109146, 53.39571140706539, 53.86245556175709, 59.96143229305744, 61.79796874523163, 59.57789607346058, 61.47365614771843, 60.12008138000965, 56.417430862784386, 49.473371878266335, 50.492541790008545, 51.40086404979229, 55.97725868225098, 57.968313843011856, 57.98364222049713, 64.01584893465042, 57.04596273601055, 50.043614879250526, 46.37721061706543, 50.85056237876415, 57.464734464883804, 46.137701869010925, 31.303256079554558, 35.898516699671745, 46.00028984248638, 37.821278125047684, 42.781782746315, 43.52029591798782, 33.11534844338894, 10.979216359555721, 6.5314320009201765, 1.6681364946998656, 1.9319433951750398, 0.5502769723534584, 0.16195612668525428, 0.3485446987906471, 0.8847951097413898, 2.0291863521561027, 3.9162988029420376, 25.68061798810959, 41.8132147192955, 27.642042338848114, 11.971490364521742, 2.82018824480474, 1.9551873416639864, 1.2866224790923297, 0.6350270309485495, 0.2576088986825198, 0.2600681979674846, 1.7550019710324705, 0.2682833868311718, 0.06379318117978983, 0.06040499501978047, 0.04349594317318406, 0.24037971772486344, 0.5784995423164219, 0.4060475475853309, 2.3297618608921766, 4.423684626817703, 10.30416738241911, 19.771068692207336, 30.12005466967821, 25.776612237095833, 5.571686150506139, 1.9227894488722086, 0.0793830469774548, 0.18092721729772165, 0.0159928371431306, 0.09526051726425067, 0.06484230339992791, 0.18859406292904168, 0.2622313209576532, 9.889110904186964, 32.23954863846302, 41.250643506646156, 42.26346015930176, 51.215635389089584, 46.391072273254395, 43.22007402777672, 44.75262299180031, 45.806424245238304, 52.14524410665035, 55.574240908026695, 68.88309136033058, 66.57045185565948, 63.37187089025974, 63.098787143826485, 66.69928014278412, 55.96649385988712, 41.212577149271965, 50.48063702881336, 55.82257278263569, 57.00734540820122, 56.20195962488651, 52.44192458689213, 46.62012778222561, 42.15538635849953, 48.56921799480915, 53.76885898411274, 54.42770183086395, 54.60692301392555, 56.31281107664108, 56.70886382460594, 60.702966302633286, 58.524148017168045, 58.76996822655201, 52.37369164824486, 23.268554918468, 0.8209929708391428, 0.16588032158324495, 0.05076729830761906, 18.942086175084114, 54.541634917259216, 41.38523608446121, 40.4867172986269, 43.358576595783234, 51.58443599939346, 1.9347798242233694, 13.738072570413351, 41.39250509440899, 25.598428398370743, 31.144464500248432, 20.463173054158688, 38.09020109474659, 28.836179561913013, 30.749716982245445, 34.14833441376686, 26.843025013804436, 51.056344136595726, 51.945162042975426, 4.973649540916085, 0.14457348443102092, 0.05774029894382693, 0.11226665315916762, 0.10367227136157453, 0.18651504011359066, 0.06882177345687523, 0.13358772470382974, 0.015193309391179355, 0.16157696343725547, 0.24341801094124094, 0.08750157852773555, 0.056374357591266744, 0.035191306960769, 0.06492166867246851, 0.08757929623243399, 0.04344428227341268, 0.14654461381724104, 0.12799782387446612, 0.39921539544593543, 11.924377642571926, 75.42018458247185, 55.77320583164692, 37.094730511307716, 31.389467753469944, 53.108325228095055, 39.03900258243084, 31.374416761100292, 33.16686227917671, 22.060461044311523, 45.684906765818596, 12.584608364850283, 10.302815604954958, 61.632601618766785, 70.89376866817474, 61.740580424666405, 58.75902861356735, 58.47438208758831, 8.486679308116436, 0.7089040917344391, 0.14377632876858115, 3.099255245178938, 57.97462910413742, 64.20985132455826, 65.20206928253174, 60.76871037483215, 66.14449471235275, 55.50775967538357, 56.05453513562679, 62.02474057674408, 66.413793861866, 61.95285603404045, 64.97516825795174, 62.2484839707613, 59.96889129281044, 52.15550355613232, 54.14272092282772, 50.5302357673645, 56.96720816195011, 58.673168420791626, 61.532340198755264, 64.6084575355053, 62.501311004161835, 52.47131980955601, 50.42031526565552, 49.268973246216774, 55.4427869617939, 46.23602919280529, 43.654523715376854, 43.164445012807846, 44.30271193385124, 39.18298825621605, 49.79707270860672, 50.50851233303547, 44.526637718081474, 18.993968591094017, 7.331629637628794, 6.5906033758074045, 3.0465387739241123, 1.7122327722609043, 0.31116521393414587, 0.24065806763246655, 0.5549685924779624, 1.666659798938781, 5.109668467193842, 24.313652738928795, 41.9990361481905, 31.821795254945755, 19.303490482270718, 10.054827611893415, 7.008496876806021, 3.574364888481796, 1.2815258838236332, 0.134981136652641, 0.2698823291575536, 0.6275820429436862, 0.20203193795168772, 0.05692789585737046, 0.11015089403372258, 0.03843576509098057, 0.2905657474184409, 0.06722749923937954, 1.1877522594295442, 3.5371444607153535, 6.072764787822962, 9.411992356181145, 12.935364693403244, 22.521874085068703, 23.430059552192688, 7.8170540649443865, 1.1806655209511518, 0.06748149928171188, 0.1442810337175615, 0.03844654107524548, 0.011798292689491063, 0.07948763784952462, 0.0769784142903518, 0.700499655213207, 11.779204532504082, 42.98851065337658, 43.52807030081749, 49.674305096268654, 52.046434208750725, 52.47949697077274, 47.29057140648365, 45.0705823302269, 47.52614736557007, 54.751049280166626, 52.808973491191864, 66.74861669540405, 70.01038447022438, 70.36253437399864, 66.80965662002563, 71.67572870850563, 64.27760928869247, 50.37675440311432, 55.058262795209885, 59.65291544795036, 59.948683977127075, 56.96813531219959, 54.728505089879036, 49.987146109342575, 45.89674159884453, 53.188048750162125, 56.426793560385704, 58.9470349252224, 57.679381147027016, 59.44174937903881, 60.57324506342411, 64.74730208516121, 61.92617766559124, 62.476201951503754, 57.349631041288376, 22.656058184802532, 0.8245154411997646, 0.3894013533135876, 0.5741383857093751, 26.241422295570374, 61.95552349090576, 47.75224283337593, 45.061523616313934, 47.160078808665276, 48.20379540324211, 2.264830945059657, 18.25144473463297, 54.87195499241352, 28.513177894055843, 35.60633137822151, 24.375787004828453, 33.338472470641136, 32.79536381363869, 33.41117016971111, 32.700615897774696, 31.959298476576805, 57.160974964499474, 63.34777258336544, 5.730406483635306, 0.05064776800281834, 0.029216248185548466, 0.061124804051360115, 0.03692586935358122, 0.03201288142008707, 0.04717616073321551, 0.09049857122590765, 0.13688864914001897, 0.24083328869892284, 0.37866419821511954, 0.2835797629086301, 0.20685987576143816, 0.16789461427833885, 0.15105235943337902, 0.22964814357692376, 0.18334875610889867, 0.14689636213006452, 0.3056222019949928, 0.5514584120828658, 18.89767035841942, 87.21626400947571, 63.07875081896782, 57.874105498194695, 38.225591629743576, 65.49794420599937, 62.4605467915535, 37.620234712958336, 44.89071898162365, 33.150648549199104, 44.922511875629425, 10.55798426270485, 15.230748374015093, 67.26920396089554, 75.49845278263092, 66.73129722476006, 65.2834989130497, 65.5204389989376, 8.797104600816965, 1.4797165989875793, 0.5237546924035996, 5.495147332549095, 68.03035631775856, 66.90814733505249, 67.8369314968586, 64.38586547970772, 71.77825480699539, 60.25387600064278, 59.57720831036568, 63.82492437958717, 66.72334045171738, 64.27406787872314, 67.95529514551163, 62.753207087516785, 60.92988632619381, 55.40346287190914, 59.88562636077404, 54.259348064661026, 61.22448071837425, 63.97750899195671, 62.47186258435249, 67.15368255972862, 61.89073696732521, 51.928731724619865, 54.07557092607021, 56.39173664152622, 55.40062062442303, 44.52531538903713, 56.11666560173035, 61.832353100180626, 51.89924530684948, 36.86180680990219, 49.213294833898544, 56.172119826078415, 54.22791235148907, 36.64434067904949, 13.590100910514593, 11.538956724107265, 7.025680979713798, 2.5190406292676926, 0.4192619916284457, 0.40246398362796754, 1.1853965045884252, 4.874415015801787, 12.403094004839659, 42.25921958684921, 45.95276199281216, 37.13410019874573, 24.37993448227644, 14.19122390449047, 7.821589121595025, 2.7443224657326937, 1.191238691098988, 0.4955056426115334, 0.9328006650321186, 1.8183948006480932, 0.5243684188462794, 0.3827450901735574, 0.11607413791352883, 0.11244047156651504, 0.35070485319010913, 0.6007051351480186, 1.2298302515409887, 3.2671964960172772, 6.6253444366157055, 12.995796650648117, 24.233866520226, 35.90818338096142, 40.998318046331406, 19.45758931338787, 3.855586373247206, 0.3021468728547916, 0.3002548118820414, 0.14259454765124246, 0.321850567124784, 0.2639552706386894, 0.29755680821835995, 1.3347759889438748, 23.629501350224018, 49.89725053310394, 48.49553234875202, 53.6128431558609, 53.72489154338837, 56.88460819423199, 51.37779928743839, 49.04551483690739, 49.53701466321945, 57.47513450682163, 55.12515440583229, 63.75419497489929, 64.38433796167374, 68.65144819021225, 69.48304116725922, 71.07482135295868, 71.02910220623016, 59.55649942159653, 57.93920360505581, 62.45327778160572, 63.464194536209106, 62.32370473444462, 57.696590423583984, 54.144586622714996, 48.055386766791344, 54.829146489501, 58.9629902690649, 59.50933255255222, 56.91158674657345, 60.065778493881226, 61.48348622024059, 67.75428593158722, 62.37197734415531, 66.59443616867065, 63.11381533741951, 31.196430511772633, 2.9196547949686646, 1.2829555571079254, 0.7720434630755335, 23.746825754642487, 67.45640471577644, 53.517225086688995, 50.76835758984089, 53.41173134744167, 56.93232603371143, 5.62557153403759, 19.950166381895542, 64.16056036949158, 32.17073433101177, 45.19096367061138, 25.324729084968567, 50.933770313858986, 42.80627243220806, 42.52517871558666, 47.97656759619713, 42.099859938025475, 70.24086490273476, 83.55715155601501, 12.694079540669918, 0.28649064421188086, 0.19726604368770495, 0.13783200789475814, 0.3266186284599826, 0.20334059663582593, 0.3037234320072457, 0.19687367021106184], [0.008511604501109105, 0.10647069502738304, 0.07794921024469659, 0.14874193497234955, 0.097723549552029, 0.1063595361483749, 0.038528117947862484, 0.012233749694132712, 0.10833117019501515, 0.2407764401868917, 0.252874530851841, 0.2674909809138626, 5.602221786975861, 63.89868602156639, 48.10442313551903, 34.96045343577862, 30.735661536455154, 26.195357367396355, 46.98900818824768, 23.120691552758217, 28.40885069221258, 33.9028599858284, 54.145563170313835, 10.477963406592607, 1.7694325279444456, 38.22339914739132, 72.30115234851837, 56.60360187292099, 54.818716049194336, 60.731985345482826, 15.830876771360636, 0.5510424531530589, 0.11521574022481218, 0.20627887803129852, 35.66487103700638, 63.829658925533295, 61.03423252701759, 61.64224170148373, 57.79988408088684, 52.50748626887798, 53.986689895391464, 62.344307228922844, 65.24692207574844, 62.44807206094265, 62.650905176997185, 62.68259547650814, 57.15998701751232, 52.039883360266685, 53.081399872899055, 49.68975126743317, 55.700432136654854, 55.570843890309334, 58.86172570288181, 59.04000073671341, 60.14174781739712, 53.399872183799744, 52.81199812889099, 45.26125609874725, 45.33753700554371, 54.67207431793213, 58.090663477778435, 39.928656443953514, 33.293855264782906, 46.27898208796978, 48.85734133422375, 47.72924646735191, 37.22980186343193, 9.798741303384304, 6.128730559721589, 2.406460507772863, 0.7362559146713465, 1.501052810344845, 0.1514082044013776, 0.7072783727198839, 2.472643693909049, 4.770928518846631, 7.2377680242061615, 34.372039809823036, 40.932323187589645, 32.935447096824646, 17.157074958086014, 8.01123172044754, 3.5131613351404667, 0.8977216598577797, 0.24841536622261629, 0.1946454608696513, 1.5593204274773598, 1.7816792707890272, 0.28487056551966816, 0.16329723206581548, 0.0689236109610647, 0.04360994076705538, 0.033109786818386056, 0.03984450610005297, 0.34315097727812827, 1.0735909477807581, 6.996127590537071, 13.545419108122587, 23.17810647189617, 33.725865483284, 28.824835270643234, 11.816597376018763, 1.117190639488399, 0.11395198889658786, 0.4214998340466991, 0.1848451781552285, 0.02853430538380053, 0.17317750345682725, 0.1280308494460769, 0.46978419937659055, 1.8784883385524154, 24.41914837807417, 42.3904075473547, 42.56672948598862, 44.9342380464077, 45.93525633215904, 44.886315017938614, 45.169160440564156, 48.17590489983559, 48.520721197128296, 52.71003060042858, 52.72081822156906, 61.49031065404415, 68.00167545676231, 67.66630545258522, 56.66448600590229, 54.46884982287884, 55.2468428760767, 60.39645574986935, 56.304580718278885, 54.82027016580105, 51.4412634819746, 50.51573574542999, 46.667545437812805, 52.001201435923576, 54.81992818415165, 58.360232412815094, 58.50219279527664, 59.274562150239944, 60.30472867190838, 62.987190932035446, 61.05755567550659, 65.61405837535858, 61.7433200776577, 46.84587746858597, 8.173099234700203, 0.19324719527503476, 0.237391474947799, 3.1983959628269076, 45.75463682413101, 58.95489290356636, 49.18451897799969, 43.242572620511055, 59.2935611307621, 27.65433467924595, 1.37956382939592, 19.260645881295204, 35.411120653152466, 33.87028433382511, 38.500332087278366, 25.371909253299236, 38.92971284687519, 28.082833886146545, 34.75149504840374, 24.348553866147995, 27.7484917268157, 45.87154135107994, 40.60960650444031, 3.0484488839283586, 0.17146425554528832, 0.07363526907283813, 0.053901747887721285, 0.11258089332841337, 0.10367569266236387, 0.11712798761436716, 0.04412826783664059, 0.026233319185848814, 0.10077389524667524, 0.09200217726174742, 0.04493059626838658, 0.07305171835469082, 0.03948492812924087, 0.02019506282522343, 0.016351056983694434, 0.030789226475462783, 0.1543935528025031, 0.1349352570832707, 0.35473141993861645, 5.897026117891073, 73.65512609481812, 52.83676519989967, 39.09769803285599, 34.78367552161217, 38.75583417713642, 42.8151373565197, 28.014859333634377, 36.05704039335251, 32.48020872473717, 44.613694846630096, 13.63325709477067, 1.9836472207680345, 36.553704142570496, 78.22547525167465, 63.587349727749825, 59.633889868855476, 65.35926684737206, 19.45456277579069, 0.7931642141193151, 0.33206839696504176, 0.08500078576616943, 40.166413486003876, 67.33798786997795, 65.55383920669556, 63.60976092517376, 62.38449767231941, 55.91353990137577, 59.425725638866425, 63.56405697762966, 65.02492278814316, 65.06966158747673, 65.38423150777817, 62.72492900490761, 61.65660113096237, 53.64745169878006, 55.06927080452442, 54.13946829736233, 57.628821060061455, 59.21346142888069, 62.43424080312252, 61.12476646900177, 62.13388592004776, 54.67134855687618, 54.114872217178345, 47.54261188209057, 49.4085131585598, 53.62391196191311, 57.92116217315197, 46.002634316682816, 45.109040066599846, 51.01909473538399, 51.613181456923485, 50.39833344519138, 48.399473503232, 15.139146689325571, 7.948002638295293, 6.373690590262413, 3.0516031896695495, 1.1149966134689748, 0.2043354307534173, 0.42218192713335156, 2.0605441695079207, 4.168452797457576, 8.139655329287052, 39.23854887485504, 45.03011830151081, 32.20397114753723, 19.50515516102314, 9.25486983731389, 6.809271667152643, 2.464720644056797, 0.5883240338880569, 0.00864954285134445, 0.8085171121638268, 1.460978735703975, 0.13416153844445944, 0.19434306537732482, 0.04431223882420454, 0.129432306275703, 0.13889189867768437, 0.09129793848842382, 0.29464227554854006, 2.611944219097495, 8.784197643399239, 11.633078623563051, 20.027458034455776, 32.69099861383438, 34.83012802898884, 19.33603383600712, 1.311159662436694, 0.5239342921413481, 0.16563655575737357, 0.19667720887809992, 0.05210952804191038, 0.21751475636847317, 0.11488362913951278, 0.6692988763097674, 2.969962670467794, 29.33735366910696, 46.7227678745985, 44.73075896501541, 49.131823405623436, 49.53080579638481, 47.68656335771084, 47.54097416996956, 48.37208077311516, 49.55444052815437, 52.80477851629257, 51.260689571499825, 56.34350962936878, 66.60743147134781, 65.55796578526497, 62.66654893755913, 58.58758941292763, 58.0153439193964, 60.90960681438446, 59.08822014927864, 57.63514772057533, 54.02613177895546, 52.27662205696106, 50.451063215732574, 53.42595398426056, 58.40597815811634, 60.10694168508053, 59.964358136057854, 61.584796383976936, 63.47169913351536, 64.94522586464882, 64.07981470227242, 67.5290036201477, 63.54484900832176, 48.46452981233597, 6.469287760555744, 0.6507788482122123, 0.21945428510662168, 3.715867633000016, 55.03231018781662, 64.57294464111328, 55.393116027116776, 41.98981784284115, 64.0569931268692, 27.64078840613365, 1.6689792182296515, 25.5533305183053, 47.796510457992554, 34.56172563135624, 40.951086580753326, 23.19569192826748, 31.704419553279877, 35.86078852415085, 41.14454559981823, 27.896054908633232, 30.525853894650936, 56.88974931836128, 49.04805690050125, 4.152309838682413, 0.15320426115067676, 0.056429361866321415, 0.05642111660563387, 0.14594592328649014, 0.0750271967262961, 0.05168991403479595, 0.026780304287967738, 0.12194497874588706, 0.44552840874530375, 0.24157093896064907, 0.18648102006409317, 0.1675601431634277, 0.2379182365257293, 0.11533005323144607, 0.08861344933393411, 0.29507465078495443, 0.32479181711096317, 0.32074470771476626, 0.5911339237354696, 12.257425971329212, 90.38251250982285, 63.497275561094284, 52.6687990128994, 41.452716663479805, 46.43503971397877, 65.77749520540237, 30.641798973083496, 40.491182059049606, 43.855209946632385, 62.215714529156685, 15.975632853806019, 3.971475404687226, 47.10429400205612, 83.45096245408058, 69.43556651473045, 66.67254477739334, 72.1758882701397, 24.086451530456543, 1.4655174734070897, 0.8127960981801152, 0.8711134688928723, 49.304999113082886, 73.40024337172508, 70.68925604224205, 69.13029089570045, 64.13720682263374, 58.5896261036396, 60.579655319452286, 67.15697318315506, 70.4497092962265, 67.47305542230606, 69.4767715036869, 68.01565870642662, 64.7012409567833, 56.96126148104668, 59.935719072818756, 55.34673571586609, 60.71730673313141, 59.45025712251663, 63.213643580675125, 65.80551490187645, 67.2586253285408, 56.71790353953838, 53.89262214303017, 47.23491579294205, 54.94445510208607, 57.2875689715147, 56.10403887927532, 46.5768177062273, 46.46166108548641, 52.72941716015339, 59.28124979138374, 53.3488105237484, 58.96491676568985, 25.472358763217926, 13.915529698133469, 11.50662710890174, 8.181644026190042, 2.3881773138418794, 0.248552025295794, 2.589233787730336, 3.63346335478127, 6.232356699183583, 25.776783227920532, 46.60618253052235, 46.79889298975468, 44.5132814347744, 37.64291949570179, 20.4450898244977, 9.628943614661694, 2.8880283795297146, 0.9850682853721082, 0.31430865463335067, 1.7545850621536374, 2.551308497786522, 1.160606516059488, 0.9461315372027457, 0.08172608140739612, 0.25471416651271284, 0.2646834362531081, 0.16435793921118602, 0.4807911696843803, 4.182285480201244, 14.545411448925734, 22.557259686291218, 31.353060007095337, 37.577521204948425, 40.82664705812931, 32.524411752820015, 9.518563337624073, 0.5233387334737927, 0.36853842437267303, 0.3331589384470135, 0.12953552417457104, 0.24469512834912166, 0.1978150400100276, 1.318272405769676, 9.20625239610672, 43.76394264400005, 52.502394542098045, 51.76542788743973, 54.85156148672104, 54.35438096523285, 52.926565781235695, 54.09298539161682, 53.276922181248665, 52.95335054397583, 55.93041479587555, 55.25252737104893, 59.422476813197136, 64.74819883704185, 65.88236957788467, 66.25376164913177, 65.12972876429558, 61.438443437218666, 63.96988660097122, 61.715627163648605, 59.31878037750721, 56.89028888940811, 54.75167244672775, 52.98109285533428, 55.587711185216904, 59.94703106582165, 62.635109424591064, 64.1000448167324, 64.93984535336494, 65.98095148801804, 69.35048148036003, 65.73056772351265, 71.02275654673576, 69.06826302409172, 55.25160402059555, 12.77030535042286, 1.109162976499647, 0.4558507032925263, 3.530044066719711, 55.0391536206007, 68.93779322504997, 61.732091680169106, 48.85068029165268, 70.49888625741005, 34.570313170552254, 3.8194880727678537, 26.388939879834652, 53.168548196554184, 39.96196925640106, 54.81676295399666, 31.459630988538265, 50.941195115447044, 44.59077067673206, 48.669046238064766, 37.65976779162884, 42.46294945478439, 68.18883061408997, 68.33047941327095, 7.471639774739742, 0.38359939120709896, 0.37619453854858875, 0.25843796669505537, 0.370794078335166, 0.1977598835946992, 0.2858281141379848, 0.1539079804206267], [0.08899685024516657, 0.02246799398562871, 0.09918926152749918, 0.07490424512070604, 0.038068034627940506, 0.02053282907581888, 0.024778281149338, 0.028949275401828345, 0.08638184095616452, 0.15053821436595172, 0.028943228753632866, 0.2529068588046357, 1.667279046960175, 50.43620981276035, 53.254738971590996, 27.974391505122185, 26.045808792114258, 29.681172519922256, 50.858857333660126, 32.9038479924202, 27.269023954868317, 24.800957590341568, 68.13142329454422, 49.98891681432724, 3.821840384043753, 18.41981939971447, 59.04295697808266, 70.95551535487175, 55.415496826171875, 61.67961269617081, 17.15741503983736, 0.19900586048606783, 0.600111298263073, 0.13990398030728102, 19.119677245616913, 63.310295194387436, 64.25488650798798, 61.58018343150616, 62.91042745113373, 53.48903439939022, 56.95529580116272, 63.465315476059914, 62.035885378718376, 62.060245871543884, 59.96984124183655, 62.15624392032623, 57.71566919982433, 53.95366966724396, 53.107983246445656, 55.10414533317089, 56.94221310317516, 57.69458793103695, 57.83210635185242, 60.44290065765381, 60.20969197154045, 54.38588127493858, 51.76570147275925, 55.16284458339214, 52.88539879024029, 48.574864491820335, 48.896304443478584, 58.626012951135635, 57.21709035336971, 53.180905133485794, 52.96677902340889, 49.681319519877434, 23.84602513164282, 6.050898861140013, 7.136471634730697, 6.1525472067296505, 4.611278185620904, 3.4273381903767586, 0.9246590081602335, 3.435497540049255, 4.360625110566616, 7.78855511918664, 11.496472153812647, 33.05132567882538, 42.754807993769646, 34.90592636168003, 16.09963919967413, 5.3321783524006605, 0.9243099018931389, 1.755303223617375, 0.9219927981030196, 0.3188167267944664, 1.503512584604323, 1.738967781420797, 0.4987946629989892, 0.3507256630109623, 0.18607641599373892, 0.4007057467242703, 0.8536602929234505, 0.5297108134254813, 0.8846733381506056, 0.9382844832725823, 5.7382421381771564, 12.29965690523386, 22.98319213092327, 30.23748356848955, 24.532103016972542, 13.598012086004019, 0.9577301179524511, 1.2355701997876167, 0.28555628028698266, 0.06712683432851918, 0.08701360900886357, 0.0477281553321518, 0.037812732116435654, 0.17811024736147374, 0.3924752399325371, 6.085593374446034, 34.85207565128803, 42.35724292695522, 43.43045353889465, 42.846698462963104, 43.16047042608261, 42.79534041881561, 48.10854211449623, 46.2417820841074, 52.014071345329285, 52.03220397233963, 48.954718708992004, 51.15516923367977, 50.225613713264465, 54.24427047371864, 55.68046800792217, 51.95325940847397, 53.48911039531231, 54.45800520479679, 54.86558273434639, 52.24863275885582, 48.04393418133259, 47.119493186473846, 53.6904463917017, 57.86478079855442, 59.24357861280441, 59.993076995015144, 62.0591439306736, 58.2637669891119, 58.77062179148197, 62.552547454833984, 60.84468349814415, 56.00929856300354, 25.253253020346165, 0.5258360307198018, 0.9380212880205363, 0.5215125752147287, 11.065004356205463, 53.1243983656168, 54.957385808229446, 55.44437147676945, 53.861004039645195, 61.73451974987984, 18.83744738996029, 2.0554887782782316, 25.619205683469772, 37.68696293234825, 48.68543855845928, 53.20482484996319, 37.27783128619194, 41.15607038140297, 27.858754210174084, 35.580317974090576, 23.53122342377901, 31.315877102315426, 49.021587520837784, 28.822228610515594, 1.4096157043240964, 0.09530402938253246, 0.057119926568702795, 0.06449475564295426, 0.048613608014420606, 0.0490705223637633, 0.026155710947932675, 0.031999897546484135, 0.02360171918553533, 0.136681352450978, 0.02904117925936589, 0.06576111933100037, 0.0022843256783744437, 0.10080200780066662, 0.049925721395993605, 0.026822270883712918, 0.034035994540317915, 0.21415754745248705, 0.08504360768711194, 0.1870824713842012, 1.6713475598953664, 60.442691668868065, 61.737107411026955, 32.40009002387524, 26.79715197533369, 47.69355498254299, 48.14506195485592, 31.218076050281525, 37.56699576973915, 32.14445114135742, 64.38491553068161, 43.71771812438965, 5.784105202183127, 20.211248472332954, 64.0340119600296, 74.12122428417206, 65.37059023976326, 64.69434812664986, 22.32735112309456, 0.3982166131027043, 1.7281800415366888, 0.14197244978277013, 23.579288944602013, 66.14457070827484, 67.34972164034843, 64.50745895504951, 65.93089297413826, 56.78156912326813, 61.153747513890266, 65.23192808032036, 66.57986015081406, 63.209570199251175, 65.17106294631958, 64.00749698281288, 60.815919041633606, 56.75077937543392, 56.683861166238785, 56.87114551663399, 59.5843481272459, 60.05640059709549, 62.20943346619606, 63.4942015260458, 62.42743916809559, 55.48144988715649, 55.680110827088356, 55.837156400084496, 56.539180129766464, 48.38927485048771, 49.419399574398994, 57.806860506534576, 58.39403919875622, 53.85330565273762, 55.79058989882469, 54.649492129683495, 31.57942146062851, 12.800942156463861, 10.985798556357622, 8.962268438190222, 4.635815368965268, 3.3842900628224015, 1.0786812496371567, 2.160509442910552, 4.595220722258091, 6.122992392629385, 17.975543439388275, 43.089463636279106, 44.26141954958439, 36.03026703000069, 22.75694277137518, 12.903326712548733, 3.2110497588291764, 0.5832703644409776, 0.6025667977519333, 0.3976330772275105, 1.3827859377488494, 2.058975803665817, 0.5788509640842676, 0.1952080533374101, 0.15953372698277235, 0.29447704378981143, 0.14099998399615288, 0.7001439586747438, 0.5850372696295381, 1.3998364540748298, 6.869032960385084, 18.12307622283697, 25.926481895148754, 34.985627084970474, 36.28220871090889, 24.109624586999416, 4.433112870901823, 1.6593485162593424, 0.16559832030907273, 0.04120081437577028, 0.027538265276234597, 0.1499337944551371, 0.16895040840609, 0.4601317079504952, 1.6078915586695075, 9.762966223061085, 40.87780371308327, 45.56444562971592, 47.2403609007597, 48.23053456842899, 48.88562701642513, 45.10962523519993, 50.199828296899796, 47.401187270879745, 52.93232247233391, 53.75060856342316, 53.08062091469765, 53.46653200685978, 52.14325301349163, 54.424711391329765, 58.00507687032223, 54.47442412376404, 55.636823549866676, 55.98485827445984, 56.48516222834587, 55.23306101560593, 50.96098445355892, 50.69448955357075, 57.83252812922001, 58.73144969344139, 59.01022553443909, 60.51796182990074, 62.49395839869976, 60.530630350112915, 62.54514165222645, 65.26105731725693, 59.67985600233078, 54.781850427389145, 23.435236774384975, 0.5045074783265591, 1.1274484265595675, 2.4819501070305705, 16.496315114200115, 59.52728658914566, 60.03236688673496, 59.275968074798584, 55.33559091389179, 68.29533129930496, 19.470719508826733, 2.5140640838071704, 34.697921723127365, 44.477244168519974, 46.85935914516449, 53.13523918390274, 28.95036343485117, 33.783063814044, 35.321817845106125, 39.82674591243267, 25.931868106126785, 37.95985288918018, 62.83895328640938, 31.788455843925476, 1.771028561051935, 0.14022495917743072, 0.05523397718206979, 0.060129751000204124, 0.008015318289835704, 0.0096103671239689, 0.03199635379132815, 0.021696540752600413, 0.15590297727612779, 0.22588359948713332, 0.12267119993339293, 0.15323185420129448, 0.08333813748322427, 0.1607022384996526, 0.1439379240036942, 0.15138686023419723, 0.198957264656201, 0.4845448338892311, 0.20907159458147362, 0.37774999102111906, 3.586051636375487, 74.98380079865456, 70.85556551814079, 45.184587612748146, 33.99127744138241, 44.5310340821743, 70.98139956593513, 43.817531168460846, 38.14613789319992, 34.094343110919, 71.7773124575615, 56.40066996216774, 9.71145523712039, 23.850807175040245, 73.42594519257545, 79.53227832913399, 69.6955181658268, 73.11542585492134, 25.096260644495487, 0.5309706833213568, 1.5153149887919426, 0.2974871650803834, 29.722219817340374, 68.70219066739082, 69.54984918236732, 67.08850845694542, 67.6675745844841, 59.71329800784588, 61.989235281944275, 67.4538816511631, 68.3219526708126, 66.97391420602798, 66.87262684106827, 66.88224032521248, 63.1006870418787, 60.08817449212074, 58.90865318477154, 58.68782043457031, 61.79052494466305, 62.534110844135284, 63.40937867760658, 64.59283277392387, 65.7553043961525, 58.30283649265766, 55.37102401256561, 56.304314732551575, 56.72673426568508, 53.921322003006935, 53.96600000560284, 62.79674895107746, 60.943516194820404, 60.56292101740837, 56.79975114762783, 59.03641752898693, 41.243309900164604, 24.370011314749718, 17.944398410618305, 17.516205087304115, 13.190296813845634, 5.678007770329714, 2.341569014824927, 5.426907744258642, 5.6536980997771025, 11.723707560449839, 32.810908779501915, 45.311003029346466, 43.695762902498245, 44.89769160747528, 35.80776996910572, 19.205695129930973, 5.873106401413679, 2.2908659605309367, 1.810930457431823, 1.1300661298446357, 2.207194925285876, 2.7837700489908457, 2.0713253784924746, 1.2227973039261997, 0.37076955777592957, 1.1382413911633193, 1.1557694943621755, 1.5205432707443833, 0.8499277650844306, 0.990359679562971, 9.703692253679037, 24.26688674837351, 29.45733033120632, 37.37138606607914, 36.513829082250595, 32.301439717411995, 17.596338987350464, 1.4217769517563283, 1.3189073279500008, 0.3920723724877462, 0.13105326070217416, 0.34045487351249903, 0.2542234881548211, 1.6184308868832886, 6.09992953017354, 17.689551785588264, 50.693535804748535, 50.931600630283356, 51.964936181902885, 52.16676615178585, 51.60982623696327, 48.64220827817917, 56.7250357568264, 50.27259819209576, 55.48339918255806, 56.181079745292664, 56.34154133498669, 57.72773735225201, 56.617653518915176, 56.670808866620064, 62.391702085733414, 57.189686223864555, 60.143940299749374, 59.52179588377476, 61.56784549355507, 58.41132827103138, 54.286968782544136, 53.13373066484928, 59.61545705795288, 62.56954774260521, 63.993977308273315, 64.29187372326851, 65.33725082874298, 62.8166788816452, 64.55616474151611, 65.83544969558716, 63.409329280257225, 58.32239404320717, 31.70174829661846, 1.6357424017041922, 2.709923624061048, 2.308270689100027, 14.5331846550107, 67.5984638929367, 64.95491534471512, 66.89129903912544, 63.46257962286472, 74.64496538043022, 27.3341391608119, 4.054292198270559, 34.89025600254536, 52.99390196800232, 53.632244914770126, 72.28327810764313, 43.597104996442795, 58.11855398118496, 43.52643258869648, 50.47942869365215, 33.958424404263496, 45.716866850852966, 73.29320311546326, 50.89069202542305, 4.260680498555303, 0.27447343280073255, 0.2612037135986611, 0.23584590788232163, 0.1514028460951522, 0.10589800192974508, 0.1730317753390409, 0.11673657150822692], [0.040156653412850574, 0.02890244773880113, 0.0531947409035638, 0.015300525610655313, 0.06456243951106444, 0.10435026037157513, 0.04375622178486083, 0.09590047120582312, 0.02870728145353496, 0.23465248988941312, 0.04557680651487317, 0.20698237465694547, 0.14724037726409733, 52.77841553092003, 52.5201053917408, 41.25017613172531, 45.243780836462975, 13.23797570541501, 45.60558222234249, 36.38025484979153, 39.6275682002306, 24.221245497465134, 41.008547097444534, 47.46388390660286, 3.4848884772509336, 29.03272021561861, 51.00329898297787, 61.49453982710838, 45.458598509430885, 65.53719609975815, 31.601222790777683, 2.2608093358576298, 0.28016567579470575, 0.1793683657888323, 9.151960909366608, 63.82996290922165, 64.68004569411278, 64.81913343071938, 60.623482167720795, 54.776431918144226, 57.883787378668785, 62.990679144859314, 62.91260853409767, 65.45438334345818, 62.55440175533295, 60.885470509529114, 58.56491222977638, 57.76206851005554, 50.920623019337654, 56.142656207084656, 58.54884289205074, 60.74638657271862, 58.80990028381348, 59.78373482823372, 57.855942472815514, 53.44542793929577, 57.60338522493839, 56.86752811074257, 54.54062037169933, 52.09621913731098, 50.087468326091766, 50.07885418832302, 54.87063266336918, 50.75493671000004, 53.47198851406574, 29.910117834806442, 15.215856023132801, 9.341554585844278, 8.034677412360907, 8.239629864692688, 9.21037232503295, 5.8737181685864925, 3.476590672507882, 5.218261890113354, 11.911373790353537, 8.732244931161404, 16.947240717709064, 28.76934874802828, 32.58457392454147, 26.996128298342228, 13.32694698125124, 4.735197136178613, 2.720732856541872, 1.3696114509366453, 0.509969744598493, 1.1238957359455526, 1.8134108930826187, 3.2363891741260886, 3.103826637379825, 2.505331914871931, 2.0266974857077003, 0.9720370033755898, 2.0476336497813463, 0.9405019017867744, 1.6601589415222406, 1.507030720822513, 2.596883727237582, 9.724319446831942, 20.826769843697548, 26.520264632999897, 23.173421323299408, 13.752257209271193, 3.8244361197575927, 2.394162230193615, 0.6223326839972287, 0.26831301336642355, 0.09525290282908827, 0.1358381094178185, 0.2428490508464165, 0.2099870188976638, 1.4540245151147246, 4.059177311137319, 11.590132378041744, 33.984122425317764, 42.627955600619316, 46.02812334895134, 44.91309218108654, 45.292634814977646, 44.38707880675793, 45.26948265731335, 47.53096550703049, 53.824225813150406, 55.49272768199444, 53.396323174238205, 51.92204028367996, 53.17416809499264, 51.6285440325737, 54.43321913480759, 53.04657854139805, 53.258812353014946, 51.38294421136379, 49.75907854735851, 46.90502509474754, 51.73814155161381, 55.43370924890041, 55.99232867360115, 57.668525129556656, 60.286641642451286, 57.75495529174805, 62.94831141829491, 62.04733036458492, 59.54691253602505, 56.47444300353527, 44.857546761631966, 5.186716932803392, 0.09681861178250983, 0.04463072407816071, 3.6008903151378036, 33.42613376677036, 53.634593188762665, 52.77695260941982, 50.08928082883358, 51.00590564310551, 56.78668364882469, 9.988246634602547, 3.0922123230993748, 34.16990585625172, 53.63976091146469, 60.8134301751852, 51.422245502471924, 40.77214278280735, 28.5299900919199, 27.311460077762604, 30.05903374403715, 26.014530770480633, 43.629331067204475, 51.3170101493597, 21.42148733139038, 1.0112049453891814, 0.2689691015984863, 0.08550921629648656, 0.08741231300518848, 0.0633666392241139, 0.059254039006191306, 0.0290492111525964, 0.06939875616808422, 0.019199302878405433, 0.07170013384893537, 0.11809179253759794, 0.0033692892247927375, 0.018691992991080042, 0.04758495793794282, 0.05576071278483141, 0.09152109487331472, 0.025141517908195965, 0.061269500583875924, 0.0655801391985733, 0.1864712088718079, 0.7213107228744775, 59.3128564953804, 61.042713671922684, 45.86089052259922, 41.3226268440485, 13.940361365675926, 40.3083510696888, 35.349309369921684, 50.19871115684509, 28.70796874165535, 53.588665053248405, 49.6582205593586, 3.8312377547845244, 25.964130274951458, 60.87215222418308, 65.10252222418785, 51.701093539595604, 72.60412529110909, 40.34769415855408, 3.401368483901024, 0.6476753647439182, 0.2094354695873335, 9.043728467077017, 65.84945574402809, 65.29397115111351, 68.44100028276443, 63.83917361497879, 57.932914942502975, 62.03216917812824, 67.2457668185234, 65.09080365300179, 68.9735797047615, 65.50360590219498, 63.846226036548615, 60.36307834088802, 59.04109887778759, 53.59231285750866, 58.965691924095154, 59.72193494439125, 63.77865046262741, 61.30891218781471, 61.078678742051125, 58.89941208064556, 54.11658212542534, 59.42807771265507, 57.930847853422165, 56.797190085053444, 54.505001083016396, 51.787291914224625, 51.89611807465553, 55.067120119929314, 54.67709004878998, 55.50259955227375, 34.49617154896259, 22.626362778246403, 19.606035947799683, 18.391360826790333, 14.46468098089099, 11.726792994886637, 7.324994243681431, 3.4414062229916453, 5.5187958385795355, 10.782889444380999, 12.431121300905943, 23.68370734155178, 33.703097105026245, 42.34186515212059, 42.90279485285282, 25.63047967851162, 8.480194006115198, 3.533205734565854, 0.6987247348297387, 0.841328410897404, 1.0688840691000223, 2.242657709866762, 2.546822363510728, 0.8573307772167027, 0.9891821583732963, 0.7146093074698001, 0.6335036095697433, 1.0819434933364391, 1.9605190493166447, 1.5467561641708016, 1.741823684424162, 6.661489997059107, 17.977205850183964, 28.548612892627716, 30.591770857572556, 28.73854000121355, 23.107131980359554, 9.780977256596088, 1.8006157921627164, 0.9550273348577321, 0.6127565447241068, 0.05266596068395302, 0.4168735822895542, 0.20681003312347457, 1.2104287301190197, 2.9664295725524426, 7.776006767526269, 18.10728047043085, 37.71206058561802, 47.67829120159149, 48.668426871299744, 47.7667922526598, 48.17122735083103, 47.47057534754276, 47.85449914634228, 49.459350630640984, 54.10998187959194, 59.528285935521126, 56.371210142970085, 55.092768743634224, 56.417712047696114, 55.40497899055481, 55.61946988105774, 55.381967425346375, 55.56541018188, 54.13509093225002, 51.67017079889774, 50.54687887430191, 55.306188091635704, 58.64245846867561, 59.601329416036606, 60.214977487921715, 61.41424633562565, 60.861641988158226, 64.08068865537643, 64.24192160367966, 60.32951474189758, 56.310215815901756, 42.58428834378719, 5.269559612497687, 0.058863851154455915, 0.06649760442087427, 5.947194825857878, 39.71591345965862, 60.933518931269646, 57.42377266287804, 57.7697478979826, 58.212363347411156, 60.98525695502758, 8.853666465729475, 4.805557485669851, 43.484349846839905, 51.11641891300678, 60.82763001322746, 55.111095160245895, 31.890362575650215, 26.043120436370373, 36.449137553572655, 29.783643521368504, 25.341292396187782, 48.57201844453812, 63.56645084917545, 26.937934421002865, 1.2032981752417982, 0.20310707244789228, 0.14076070074224845, 0.0864261100650765, 0.05748252879129723, 0.013632497684739064, 0.01941200054716319, 0.10548512291279621, 0.18805582774803042, 0.20269900996936485, 0.24570308363763615, 0.13350448542041704, 0.11452295279013924, 0.2244788029929623, 0.25643989734817296, 0.21852970268810168, 0.12751198431942612, 0.4670376592548564, 0.20806677115615457, 0.2420534982229583, 1.8049977882765234, 76.67844906449318, 71.16986185312271, 57.52091445028782, 57.4857397377491, 19.465200304985046, 67.04617872834206, 49.0433831512928, 51.475685834884644, 32.96655982732773, 54.7481120377779, 54.5082651078701, 6.909680804237723, 33.20690833032131, 63.478291779756546, 71.38781815767288, 58.61116334795952, 78.80403220653534, 41.76341839134693, 4.584884801879525, 0.6903641147073358, 0.26213555422145873, 13.739918321371078, 73.31752181053162, 69.36655461788177, 70.02607002854347, 66.03506818413734, 62.5527336448431, 63.8751120865345, 70.59639662504196, 66.46667942404747, 71.02789387106895, 67.97622442245483, 66.76373988389969, 62.95378692448139, 63.17405350506306, 55.906297490000725, 62.48045392334461, 64.35614347457886, 67.15144068002701, 64.2284095287323, 63.816306442022324, 62.469103932380676, 55.964704155921936, 62.183290868997574, 62.19146803021431, 60.4531829059124, 56.52925506234169, 54.5203560590744, 55.13003334403038, 57.19853974878788, 57.674768194556236, 60.14110565185547, 44.652840346097946, 31.13197837024927, 30.99807545542717, 26.210885234177113, 20.125659964978695, 18.562152162194252, 9.973074048757553, 7.050636140629649, 8.963606916368008, 14.308166429400444, 25.209409072995186, 35.00247158110142, 38.03115226328373, 46.579982936382294, 49.005654975771904, 30.651532150804996, 9.189671035856009, 5.830257050693035, 3.0829187342897058, 1.814932117704302, 1.5919637633487582, 3.452833159826696, 5.039260145276785, 3.8279454689472914, 3.4890851145610213, 2.4748539878055453, 3.3570718858391047, 5.8998574409633875, 4.903896683827043, 6.495552901178598, 2.8882473427802324, 5.341613246127963, 18.195259049534798, 36.00019544363022, 36.673139333724976, 33.396069779992104, 28.44310585409403, 23.412950970232487, 4.149135584011674, 1.0518720257095993, 1.7709536338225007, 0.4052573681110516, 0.3609336371300742, 0.3336090955417603, 2.3114834167063236, 5.820959899574518, 11.607483197003603, 24.469360783696175, 43.390358090400696, 53.20753410458565, 53.01426887512207, 52.25088603794575, 53.46036113798618, 53.485299199819565, 49.74995143711567, 52.564555406570435, 55.413551330566406, 58.489786460995674, 58.78211997449398, 57.33484223484993, 59.53678607940674, 58.46273951232433, 60.64459003508091, 61.40783227980137, 59.58838351070881, 57.54969410598278, 55.37206515669823, 53.482418954372406, 58.44541624188423, 61.00920706987381, 59.28467720746994, 63.32537278532982, 63.804549872875214, 61.35802835226059, 67.66846373677254, 65.39367780089378, 62.108594477176666, 58.9065632969141, 48.84120360016823, 10.751372035592794, 0.31529339554253966, 0.26284952997229993, 6.219086861237884, 42.80928187072277, 66.39439970254898, 64.27580058574677, 62.237365767359734, 63.02387796342373, 66.7524316906929, 15.67316623404622, 6.030631698668003, 45.1381579041481, 58.15789707005024, 67.19486474990845, 62.33703821897507, 49.33076553046703, 41.920672953128815, 42.249393314123154, 42.05407999455929, 37.54638947546482, 59.05942149460316, 76.24401077628136, 39.81068417429924, 2.3539663245901465, 0.44673267693724483, 0.25059676088858396, 0.5607699905522168, 0.13642439123941585, 0.2010725042782724, 0.15120329742785543, 0.2657537319464609], [0.03206624554877635, 0.05400843532697763, 0.070373715570895, 0.06423956816433929, 0.10810099309310317, 0.01938984187290771, 0.01688509903033264, 0.01491727220127359, 0.08154585826559924, 0.17098378913942724, 0.0964047531306278, 0.11513402234413661, 0.11175984051078558, 23.62980343401432, 62.582740634679794, 35.079166665673256, 36.32477782666683, 67.12556406855583, 57.058365270495415, 42.099757343530655, 33.38568113744259, 47.767502814531326, 19.793774373829365, 58.01559090614319, 3.651396492496133, 12.58581954985857, 51.523631662130356, 63.16545456647873, 50.4313612729311, 54.22296121716499, 56.54691271483898, 7.941427091136575, 0.2161176039953716, 0.6949411472305655, 1.1207060446031392, 32.228825613856316, 59.62918572127819, 67.14004129171371, 61.743650659918785, 58.56464244425297, 62.29631580412388, 64.1705310344696, 60.35954833030701, 62.302251085639, 61.71394385397434, 61.52009345591068, 59.33640003204346, 56.76166199147701, 55.505080819129944, 59.095204174518585, 58.92101392149925, 59.269725009799004, 59.59930032491684, 60.73022224009037, 57.19831556081772, 57.515963315963745, 57.09394656121731, 60.210938304662704, 59.70642037689686, 59.2330189794302, 57.48138517141342, 56.357986852526665, 51.11902937293053, 49.311515763401985, 28.45555018633604, 19.717867746949196, 13.51370980963111, 13.35303258150816, 16.48218747228384, 18.78109071403742, 16.077239401638508, 9.64483531191945, 6.10676821321249, 7.606132132932544, 14.337445758283138, 12.059866972267628, 20.727013796567917, 27.152332216501236, 26.241484992206097, 19.402230083942413, 9.84149755910039, 4.134763805195689, 1.2732046865858138, 1.1163190612569451, 1.2457591155543923, 0.30803970352280885, 2.96320425812155, 7.9685429111123085, 8.076003044843674, 8.553355280309916, 4.845996340736747, 8.62615842372179, 9.105012528598309, 7.970034331083298, 8.446594309061766, 6.167875584214926, 5.263915490359068, 6.978102782741189, 14.717883244156837, 22.892420701682568, 24.335511066019535, 18.526715263724327, 9.456466119736433, 3.629404460079968, 1.3907495979219675, 0.8553089294582605, 0.6562877213582397, 0.14879979280522093, 0.25941724539734423, 1.7701597139239311, 3.1835107365623116, 3.681856608018279, 13.761482164263725, 15.644340980798006, 23.530978336930275, 39.97065559029579, 42.20499649643898, 41.654379442334175, 42.97122538089752, 40.846322402358055, 45.91153420507908, 57.62689456343651, 51.0482619702816, 47.964457646012306, 52.73612380027771, 53.194565400481224, 54.251243099570274, 51.34517043828964, 51.28666877746582, 50.038606747984886, 51.50211721658707, 45.89993342757225, 51.834549978375435, 49.41046245396137, 55.80154851078987, 54.4279982149601, 59.14997823536396, 54.58063222467899, 61.381476894021034, 59.449428766965866, 58.498670384287834, 54.329860880970955, 57.7641773968935, 19.8971364274621, 0.5176653410308063, 0.262846412952058, 10.490697473287582, 26.782688051462173, 50.755335688591, 58.51808734238148, 49.901316314935684, 55.032743364572525, 54.52553518116474, 47.80971094965935, 3.8281803438439965, 11.005586944520473, 44.127944111824036, 56.35588176548481, 65.13168185949326, 59.34037461876869, 40.90151064097881, 28.790910691022873, 26.35829832404852, 36.36028312146664, 25.147742182016373, 43.34094554185867, 48.110244423151016, 11.418116558343172, 0.21009056334150955, 0.1055909828573931, 0.15871939802309498, 0.08448436972685158, 0.026537349258433096, 0.0859784911153838, 0.029508055085898377, 0.04142566285736393, 0.04694649571320042, 0.05928682709054556, 0.0273627584829228, 0.06573473598109558, 0.09047814732184634, 0.04370043083326891, 0.04077539677382447, 0.01191740739159286, 0.007383506172118359, 0.03999233820650261, 0.05851623660419136, 0.15912999864667654, 0.31211358960717916, 33.225056156516075, 74.03600245714188, 41.458496153354645, 37.42192715406418, 54.28060792386532, 53.10767166316509, 33.37713159620762, 44.140137657523155, 51.4374902844429, 38.207238614559174, 70.19766122102737, 5.165588641539216, 11.6767249815166, 53.633350655436516, 70.25626927614212, 54.37624119222164, 57.09835812449455, 62.61882349848747, 12.773094400763512, 0.43226370646152645, 0.5835296411532909, 0.6468995532486588, 34.34359833598137, 64.27399948239326, 71.08217775821686, 64.44051414728165, 62.79375471174717, 64.85192567110062, 66.69912055134773, 63.3242404460907, 61.966827884316444, 64.66869950294495, 64.64775502681732, 61.694428101181984, 60.7111244648695, 58.873964846134186, 60.609977692365646, 60.26998333632946, 61.097286343574524, 61.4683972299099, 62.327930107712746, 61.12369492650032, 60.95257490873337, 59.49898190796375, 60.53115092217922, 60.436877980828285, 58.803269639611244, 56.04343593120575, 57.6580984890461, 56.60294450819492, 51.12734712660313, 33.9172688126564, 28.93729403614998, 24.80912335216999, 26.72177542001009, 26.10659223049879, 24.182578772306442, 18.91536220908165, 10.589737258851528, 7.2825562208890915, 9.280811995267868, 15.773857031017542, 17.297940999269485, 24.25748035311699, 32.44914919137955, 39.30219165980816, 33.897506073117256, 17.022738866508007, 6.974859181791544, 3.346273577772081, 2.6622680062428117, 1.4566548052243888, 1.9294016878120601, 3.539882213808596, 6.046964172273874, 4.595132851973176, 4.461648864671588, 2.7191768400371075, 2.1212900849059224, 2.4144659657031298, 2.7709181886166334, 2.668249597772956, 4.607488363981247, 4.819846618920565, 11.430672984570265, 22.241851910948753, 27.830977700650692, 27.485150657594204, 22.28106200695038, 12.967068292200565, 2.5858669308945537, 1.2745331902988255, 0.9911153640132397, 0.30543028260581195, 0.18177706544520333, 0.6581993156578392, 2.5815365882590413, 3.309174980968237, 8.723702989518642, 16.341781206429005, 20.779234394431114, 28.679297380149364, 43.58207680284977, 47.66056515276432, 44.32858854532242, 44.31826829910278, 45.0572906434536, 47.90992297232151, 59.4974771887064, 53.871354684233665, 52.534886598587036, 55.151038616895676, 55.83126291632652, 56.37282505631447, 54.6794269233942, 54.03866730630398, 53.32084022462368, 54.45983670651913, 50.14787368476391, 51.461185812950134, 52.76936821639538, 59.208001121878624, 59.52099032700062, 59.42248061299324, 56.30566745996475, 59.69336427748203, 58.11555594205856, 59.84354741871357, 54.39422182738781, 54.892762675881386, 18.938504867255688, 0.4957837995607406, 1.0073629952967167, 17.922906763851643, 36.590980142354965, 54.66011255979538, 64.35267046093941, 55.82985319197178, 60.52216440439224, 60.18972784280777, 50.41290566325188, 3.9783618226647377, 18.973702378571033, 52.88650453090668, 55.43188914656639, 66.92751869559288, 67.8584535419941, 35.1261093467474, 29.872078076004982, 33.509854674339294, 38.10186646878719, 30.519637428224087, 51.48102454841137, 57.25937448441982, 11.924976110458374, 0.1715651134145446, 0.02930647478933679, 0.10101902662427165, 0.07611234279465862, 0.05772048360086046, 0.02692503792786738, 0.046050326418480836, 0.031624237235519104, 0.1560946146491915, 0.1456569755100645, 0.17486535507487133, 0.16341750451829284, 0.2630657621193677, 0.171460960409604, 0.07916363843833096, 0.1527965845889412, 0.16226469684625044, 0.2432010811753571, 0.1464602316264063, 0.3213435912039131, 0.5138374620582908, 48.78112882375717, 82.44380369782448, 50.67362107336521, 52.517795115709305, 76.43343821167946, 83.86484384536743, 54.36852000653744, 41.84170939028263, 56.22824281454086, 34.571369513869286, 67.51632750034332, 6.875323047861457, 18.619599379599094, 63.49602162837982, 72.00279235839844, 61.29916191101074, 65.62902957201004, 68.63276079297066, 13.148976881057024, 2.771152351051569, 2.7298084320500493, 1.9045650330372155, 43.57460260391235, 66.28010183572769, 74.495739787817, 68.92380237579346, 64.33596655726433, 69.22396346926689, 70.19003883004189, 66.4673025906086, 63.97304803133011, 69.02042359113693, 67.55824685096741, 65.42530730366707, 66.51339411735535, 61.597537100315094, 65.51916226744652, 64.2154598236084, 63.86630415916443, 66.13577038049698, 63.45291294157505, 62.396812811493874, 64.17115420103073, 63.31039018929005, 64.34776112437248, 63.31356681883335, 64.23481598496437, 63.51155899465084, 61.04128874838352, 61.882483810186386, 54.736093282699585, 38.647900968790054, 35.74160411953926, 34.77242812514305, 31.588717661798, 32.821267023682594, 29.529784843325615, 18.72025027871132, 11.224854178726673, 11.06030685827136, 11.084468811750412, 25.0161362439394, 28.17419808357954, 32.887261882424355, 41.67724281549454, 43.78494791686535, 36.352417543530464, 18.221781626343727, 10.730151124298573, 5.81690551713109, 2.623797683045268, 2.233115709386766, 2.7559260930866003, 5.854103621095419, 13.896183036267757, 11.537167970091105, 13.71351733803749, 9.23016831278801, 16.526810377836227, 15.671074446290731, 14.215178769081831, 16.304839588701725, 12.904060073196888, 9.153067599982023, 9.236368630081415, 21.804088801145554, 33.255515322089195, 35.4638884216547, 30.610800236463547, 24.351263120770454, 14.432403612881899, 1.733496431261301, 2.143589425832033, 1.701103881932795, 0.6470960145816207, 0.8191115374211222, 2.9246555641293526, 4.926312630996108, 13.18491630256176, 20.7060769200325, 25.381720326840878, 35.441560819745064, 50.80774247646332, 49.06821861863136, 48.49370464682579, 48.787717670202255, 50.49998939037323, 48.08768503367901, 57.18317337334156, 58.055135384202, 56.10083945095539, 57.9713498800993, 58.518444523215294, 61.497507467865944, 58.81211556494236, 57.85906970500946, 56.33138447999954, 58.66784490644932, 52.16353252530098, 55.4519634693861, 53.733490481972694, 61.36186994612217, 60.05961522459984, 64.65771049261093, 59.017057567834854, 63.87293100357056, 61.4689140021801, 61.536808758974075, 55.26038534939289, 59.88624952733517, 26.79233953356743, 1.9407897954806685, 0.7598693913314492, 13.154414389282465, 35.406085923314095, 62.00330592691898, 69.67080429196358, 61.90649852156639, 67.1215058863163, 65.13038232922554, 59.06625732779503, 7.992565222084522, 15.405722334980965, 59.028415158391, 59.67483647167683, 72.3854698240757, 67.56151467561722, 51.665052473545074, 41.985296085476875, 37.623639330267906, 50.1950291544199, 39.08950947225094, 58.82672198116779, 77.91409716010094, 25.96390798687935, 0.8574646012857556, 0.379673044080846, 0.30502438719850034, 0.39976019121240824, 0.16164294036570936, 0.15782748494530097, 0.19867417984642088, 0.22229711146792397], [0.015134854129428277, 0.04797292305738665, 0.12443607905879617, 0.10601253758068196, 0.06450141270761378, 0.04259538036421873, 0.019232814556744415, 0.04783346608746797, 0.11222133762203157, 0.11382255092030391, 0.07363650845945813, 0.14990994182880968, 0.17024812783347443, 26.31049308925867, 70.37355378270149, 41.69362373650074, 40.68938322365284, 103.11305299401283, 69.3513934314251, 48.21864880621433, 24.873313307762146, 39.879118502140045, 20.682525783777237, 46.36347055435181, 24.54765748232603, 2.742896592244506, 28.462382219731808, 52.02009402215481, 69.97808620333672, 50.206481739878654, 53.033917620778084, 44.81024689972401, 2.8701662505045533, 0.7561967696528882, 0.15780952497152612, 12.80713677406311, 59.07031551003456, 63.5056959092617, 60.89459381997585, 61.5865632891655, 62.55216367542744, 63.225502744317055, 64.10914912819862, 61.235716715455055, 62.58284702897072, 60.16553074121475, 59.28986392915249, 55.45878790318966, 58.912209793925285, 57.8537005931139, 60.9412857145071, 59.34547774493694, 59.03440363705158, 59.33435954153538, 59.250080063939095, 56.812780648469925, 59.981054440140724, 58.775534927845, 58.580951169133186, 57.25694261491299, 47.88738638162613, 40.6954362988472, 34.30228695273399, 31.280548498034477, 28.071994967758656, 18.180455043911934, 19.70230758190155, 22.673466950654984, 24.82211295515299, 25.66495332866907, 17.88109950721264, 7.28192925453186, 5.47855457291007, 7.654087459668517, 19.44812022149563, 21.527516841888428, 26.304003037512302, 27.18548733741045, 22.8901332244277, 14.996092915534973, 6.768066678196192, 1.0331201506778598, 0.8637399645522237, 0.7179484376683831, 2.4231207137927413, 4.0085569024086, 3.851978466846049, 10.239623095840216, 11.33980656042695, 14.409558288753033, 15.793279688805342, 20.071507170796394, 25.243725031614304, 24.714783914387226, 23.138998970389366, 12.177693899720907, 4.614125657826662, 5.280829332768917, 9.07473100349307, 17.74579256772995, 24.421304762363434, 22.08892721682787, 17.878711335361004, 10.233743861317635, 6.381234610453248, 2.591532664373517, 1.3861098093912005, 0.533501406898722, 1.0795360850170255, 2.4389556515961885, 5.9747514221817255, 4.944221070036292, 11.44900320097804, 20.489249154925346, 19.7333063185215, 17.644577398896217, 28.052836395800114, 34.79427695274353, 37.8098863363266, 38.09379570186138, 49.650594368577, 45.29223583638668, 47.8080390393734, 52.274475172162056, 51.4914245903492, 53.544880002737045, 50.03330983221531, 52.566151320934296, 49.90537069737911, 51.619519516825676, 47.618250623345375, 48.1984680891037, 51.03298678994179, 56.56257547438145, 55.20629145205021, 53.876594603061676, 55.35820730030537, 59.73789408802986, 49.418928399682045, 60.79715944826603, 64.31429252028465, 53.37699741125107, 39.15312185883522, 3.3792482083663344, 0.11994962565950118, 13.015322852879763, 51.07663884758949, 53.18486452102661, 53.99096466600895, 47.47643083333969, 52.137253135442734, 47.87323214113712, 64.95059117674828, 23.4208944439888, 0.965274969348684, 12.973942123353481, 40.56802913546562, 59.017194360494614, 67.3929101228714, 38.15391227602959, 32.334041967988014, 21.711736656725407, 29.232980869710445, 25.033581107854843, 18.754794225096703, 53.17352972924709, 30.840032435953617, 2.203201577067375, 0.05142641079146415, 0.06561417409102432, 0.029140460064809304, 0.09804125555092469, 0.0027924595815420616, 0.08392815230763517, 0.12763000064296648, 0.04486289755732287, 0.07781727123074234, 0.06185957106936257, 0.15167895471677184, 0.11120690338429995, 0.03365915050380863, 0.025428309745620936, 0.022208707996469457, 0.008517189162375871, 0.08213568755309097, 0.012936999555677176, 0.02603326956887031, 0.14765646978048608, 0.0971089251106605, 34.92635786533356, 81.94592401385307, 45.810197442770004, 40.28244026005268, 105.09708613157272, 81.92323163151741, 33.168006017804146, 34.887056574225426, 48.485398292541504, 29.72365614026785, 74.08801406621933, 29.079406410455704, 3.919823351316154, 28.89904148876667, 54.61407423019409, 67.83372446894646, 58.51715259253979, 58.27457740902901, 50.764348804950714, 6.591891031712294, 0.8638139418326318, 0.11863316700328141, 12.750050537288189, 60.05573183298111, 68.58770281076431, 65.97581416368484, 64.71349149942398, 64.97675657272339, 65.7749493420124, 64.61870178580284, 63.703733682632446, 62.36638404428959, 62.09322050213814, 61.88278019428253, 58.584602773189545, 59.93748217821121, 59.73376750946045, 61.910036131739616, 62.6264800876379, 60.23330770432949, 61.30948595702648, 61.37636236846447, 59.81441058218479, 62.27328144013882, 59.45525765419006, 59.35111664235592, 56.19128219783306, 53.69849435985088, 46.11922346055508, 39.22037065029144, 36.02594666182995, 35.55537611246109, 28.89313280582428, 31.896981820464134, 30.445408411324024, 32.3519504070282, 29.59016740322113, 19.956266954541206, 10.4097836650908, 7.53453922457993, 11.883902214467525, 22.768575847148895, 24.327835477888584, 28.697099424898624, 36.49303279817104, 34.01925154030323, 23.01715850830078, 12.486614473164082, 6.219567060470581, 4.310989798977971, 2.522945632226765, 1.8806054187007248, 5.355931352823973, 5.4111618641763926, 9.3584237806499, 9.739975556731224, 11.477159690111876, 7.435618657618761, 5.735931387171149, 9.574405141174793, 7.493629194796085, 3.858236256055534, 6.436152113601565, 8.703001700341702, 8.349597863852978, 13.851786218583584, 23.53363249450922, 28.19070439785719, 25.183709152042866, 18.73924545943737, 11.321398448199034, 3.9796547032892704, 1.7732060817070305, 2.2376132430508733, 0.9224851685576141, 0.6002250546589494, 0.5270405067130923, 5.071453442797065, 7.692472999915481, 15.313318893313408, 24.323498010635376, 24.90026906132698, 23.411018773913383, 33.92925336956978, 40.88051676750183, 41.238123178482056, 38.947389498353004, 45.96491374075413, 47.063427194952965, 48.81592735648155, 54.967443868517876, 52.63010188937187, 57.689097225666046, 53.084614500403404, 54.1902943700552, 53.786554634571075, 54.32490214705467, 49.42862167954445, 50.021154284477234, 52.03212797641754, 57.8636484593153, 57.16578550636768, 58.07499311864376, 57.29839839041233, 59.58315499126911, 50.1349201798439, 60.898959785699844, 64.43188101053238, 53.64429406821728, 35.973308086395264, 2.5490355072543025, 0.5156756134238094, 20.76280787587166, 57.435270845890045, 58.378764018416405, 58.40166538953781, 52.49983727931976, 59.0192386507988, 53.285274133086205, 71.61249250173569, 20.080634281039238, 2.220986522734165, 19.808337092399597, 40.767472833395004, 59.70066748559475, 72.00057327747345, 47.38320283591747, 28.268520422279835, 29.059630371630192, 32.78160095214844, 30.407007671892643, 22.770943120121956, 63.83031249046326, 42.60319612920284, 3.5043873684480786, 0.11126945159048773, 0.11212537792744115, 0.04152322559093591, 0.04158159550570417, 0.009026847947097849, 0.05594712543825153, 0.05108953882881906, 0.05211725379922427, 0.18883661163272336, 0.17822793714003637, 0.437412578612566, 0.20006732462206855, 0.24429095472441986, 0.21310114476364106, 0.09273023897549137, 0.2160952950362116, 0.15759520756546408, 0.2651688305195421, 0.1403392944484949, 0.3343971079448238, 0.3628394426777959, 45.586815029382706, 92.08631828427315, 58.648625537753105, 55.392276272177696, 117.76182174682617, 97.95682087540627, 65.42234346270561, 32.725044786930084, 47.42100700736046, 29.982914328575134, 68.61193031072617, 27.930152378976345, 6.4691932406276464, 35.25283634662628, 64.0232889354229, 72.14707061648369, 62.99740858376026, 61.31965421140194, 52.77086153626442, 5.017866343259811, 3.505330430343747, 1.0375889483839273, 20.18908616155386, 67.60474115610123, 69.24999967217445, 68.97303253412247, 68.6272206902504, 69.84079197049141, 69.31852519512177, 69.38601717352867, 65.74122995138168, 64.69864189624786, 64.86825719475746, 64.95249107480049, 62.098775804042816, 63.42073626816273, 63.48810285329819, 65.49574792385101, 66.03541016578674, 63.653181195259094, 66.33340537548065, 64.66692879796028, 62.25360229611397, 66.02721780538559, 64.23583433032036, 64.6852970123291, 60.92055782675743, 57.07777842879295, 50.51870338618755, 42.56759583950043, 39.423921927809715, 41.78777128458023, 35.17925709486008, 39.3826599419117, 38.33455838263035, 39.42945063114166, 34.66654680669308, 23.58297284692526, 14.466226547956467, 9.707250762730837, 18.453886471688747, 38.03270258009434, 34.4781719148159, 38.88080947101116, 44.98023837804794, 41.4834950119257, 22.69283641129732, 13.616927471011877, 8.398704528808594, 5.582351703196764, 7.900242526084185, 9.015946257859468, 10.848146192729473, 11.698259375989437, 20.22530771791935, 16.274712905287743, 23.67529459297657, 21.68599683791399, 26.617812998592854, 32.83901587128639, 32.07678057253361, 30.278576463460922, 26.45727351307869, 20.990482158958912, 10.160505641251802, 14.428852703422308, 26.948028579354286, 35.45399375259876, 33.70843581855297, 29.81068667024374, 24.074981845915318, 14.459818191826344, 2.321521765552461, 2.3036337504163384, 0.9022330865263939, 1.3566738576628268, 3.3288448629900813, 7.614137353375554, 12.98844214528799, 20.26767924427986, 30.175866074860096, 30.92239111661911, 31.133517287671566, 40.70703327655792, 47.174331843853, 46.02953687310219, 42.77639843523502, 49.42293718457222, 53.38427022099495, 51.45732522010803, 57.58320830762386, 56.800982281565666, 60.30109226703644, 54.91556905210018, 58.347202911973, 58.18786606192589, 58.50663475692272, 52.163570523262024, 52.61213645339012, 55.424707531929016, 61.78100265562534, 62.144498750567436, 59.233144372701645, 60.817359164357185, 63.65225404500961, 52.46516793966293, 60.30520364642143, 65.39733320474625, 54.70235489308834, 44.437730088829994, 5.309903472661972, 0.30656303744763136, 15.411980599164963, 60.964928045868874, 65.94554498791695, 64.05564799904823, 60.28397038578987, 63.67717690765858, 57.515191957354546, 77.48809441924095, 34.25024874508381, 3.2561146281659603, 20.57367492467165, 51.029091998934746, 62.474093064665794, 76.03803142905235, 43.51067863404751, 44.2627988755703, 35.639047622680664, 39.38459783792496, 37.08637475967407, 29.710987620055676, 74.35277625918388, 59.35577139258385, 6.700990777462721, 0.3590854222420603, 0.4292626987444237, 0.21066546061774716, 0.34519375360105187, 0.19155622663674876, 0.3091036464320496, 0.14890810183715075, 0.191230483178515], [0.02256047857372323, 0.04530817132035736, 0.09474448714172468, 0.0417677187215304, 0.07483132168999873, 0.10345200193114579, 0.03659824826172553, 0.020184682034596335, 0.1732640081900172, 0.06493054475868121, 0.044512013846542686, 0.09765369861270301, 0.3021333063952625, 15.573261994868517, 64.81176942586899, 49.41222935914993, 27.371189072728157, 43.54940615594387, 45.85566580295563, 50.20445644855499, 35.855495408177376, 19.44112479686737, 28.44840656965971, 19.645236544311047, 38.1805070489645, 5.009492067620158, 19.60870150476694, 52.881067022681236, 59.534312412142754, 72.06833884119987, 55.26581905782223, 52.694033458828926, 39.961387887597084, 3.7487750547006726, 0.8578353782650083, 0.017318752616120037, 22.830248437821865, 66.4991220831871, 64.352146089077, 62.43861436843872, 65.10552406311035, 65.60175463557243, 59.89118926227093, 53.5192845761776, 64.55149099230766, 60.68535044789314, 62.24436119198799, 58.23268845677376, 57.75786593556404, 58.812522143125534, 59.80077311396599, 59.24111634492874, 61.39395162463188, 58.91840346157551, 60.95827840268612, 56.880173832178116, 58.87122139334679, 57.87762030959129, 56.91045440733433, 43.22162814438343, 29.80623710900545, 25.08287586271763, 31.572712920606136, 33.012905940413475, 27.42420382797718, 22.629512809216976, 27.079096846282482, 29.603464789688587, 32.40476757287979, 27.6013845205307, 17.301968783140182, 7.536825276911259, 4.931809986010194, 11.43419824540615, 22.586841098964214, 25.507873557507992, 24.719389267265797, 21.646891236305237, 13.328139167279005, 5.850113835185766, 0.6524543208070099, 2.117462265305221, 2.9123689234256744, 2.9885389236733317, 8.144071642309427, 14.656506087630987, 10.129287466406822, 13.633521180599928, 12.304078917950392, 20.216093212366104, 21.259027048945427, 25.444546155631542, 33.60935613512993, 37.50125929713249, 34.527979642152786, 17.999769039452076, 4.062142577022314, 0.5020378483459353, 2.9430038295686245, 9.292633160948753, 16.770538799464703, 26.44924644380808, 24.166526533663273, 21.645280122756958, 15.524153430014849, 4.916595127433538, 3.3026782795786858, 1.6130709182471037, 1.1374925938434899, 1.4618555386550725, 4.3963393941521645, 8.320566471666098, 8.601549994200468, 17.442853823304176, 20.75972244143486, 20.523354224860668, 17.383022233843803, 17.21170272678137, 24.279317781329155, 28.13563395291567, 28.31725660711527, 36.17859207093716, 44.12321716547012, 49.866578578948975, 51.9851890951395, 52.348126620054245, 53.40701200067997, 51.31885685026646, 49.19220216572285, 48.56232516467571, 50.37412114441395, 51.50988779962063, 50.97654841840267, 51.29069656133652, 52.42762975394726, 54.47616063058376, 56.7162012308836, 55.659048557281494, 54.88169766962528, 56.55312158167362, 56.50091618299484, 46.818047761917114, 10.948949083685875, 0.561110369162634, 15.106314551085234, 54.052316173911095, 47.67394043505192, 46.2447839230299, 53.62977884709835, 58.73578906059265, 55.20642064511776, 59.419714361429214, 37.942780405282974, 0.6318537855986506, 6.5905587282031775, 27.1938468888402, 39.98067185282707, 63.98385465145111, 68.01729261875153, 34.00827772915363, 33.10954235494137, 19.651272520422935, 28.02115559577942, 22.739473208785057, 28.350544720888138, 55.63570261001587, 35.26565305888653, 1.7164845066145062, 0.049289793605566956, 0.1908659253967926, 0.05423972936114296, 0.014728803798789158, 0.05501356674358249, 0.08987534529296681, 0.05911211439524777, 0.06632823147810996, 0.062420289614237845, 0.0671867404889781, 0.04586871546052862, 0.11996011962764896, 0.05111172162287403, 0.061122829938540235, 0.10353757897973992, 0.09170338118565269, 0.04187954924418591, 0.048777871270431206, 0.09196901810355484, 0.05658562477037776, 0.2690832142252475, 16.11424371600151, 78.26982647180557, 53.31667184829712, 29.08026896417141, 49.46531631052494, 55.68408161401749, 39.91268590092659, 35.30647426843643, 30.229245610535145, 30.38555972278118, 34.68815624713898, 49.55085352063179, 6.12232600338757, 17.509564943611622, 59.86318476498127, 60.5837818980217, 74.22105252742767, 62.44706131517887, 59.591791927814484, 46.41720727086067, 8.512877002358437, 2.0187777606770396, 0.14884328265907243, 21.94997627288103, 69.22442704439163, 68.87285470962524, 66.62554129958153, 68.22340115904808, 69.16834205389023, 62.928244695067406, 55.01288183033466, 63.950158059597015, 63.696263283491135, 66.80480048060417, 62.71878473460674, 59.9029154330492, 62.1575016528368, 62.08582989871502, 60.428457632660866, 62.23008155822754, 61.17510996758938, 63.157022818923, 59.92925561964512, 60.89475341141224, 59.19473983347416, 57.72748276591301, 48.58684524893761, 36.24442733824253, 29.950631260871887, 33.84338557720184, 37.05737091600895, 33.42780567705631, 32.71052576601505, 35.59409223496914, 34.400241896510124, 35.738701075315475, 28.530147783458233, 19.915630035102367, 8.611794244498014, 6.3596379943192005, 19.548697024583817, 28.656000830233097, 24.555376768112183, 32.54911042749882, 34.23173613846302, 27.116999812424183, 13.332497533410788, 7.561494503170252, 5.774833699688315, 3.8945012725889683, 3.352747242897749, 1.4051366946659982, 3.555670604109764, 9.249924402683973, 15.798807442188263, 13.086954709142447, 19.134684540331364, 19.356989711523056, 22.515102848410606, 30.057441629469395, 24.024680145084858, 27.330170273780823, 16.889341324567795, 12.386585790663958, 9.050447456538677, 8.233662284910679, 15.916957352310419, 23.070283457636833, 27.943022288382053, 22.252812422811985, 18.83187308907509, 17.49568808823824, 7.203501462936401, 2.6359622552990913, 0.9551047557033598, 1.3687259797006845, 1.2413267721422017, 5.09299211204052, 11.135621666908264, 12.314650900661945, 20.932217985391617, 25.00306874513626, 25.77156040817499, 22.820952236652374, 24.141824059188366, 30.078220814466476, 34.2397803068161, 34.46821644902229, 40.683162957429886, 46.48159481585026, 52.65184812247753, 53.92688490450382, 53.86824645102024, 57.080670073628426, 54.0451193600893, 52.657338827848434, 50.637188628315926, 53.26881721615791, 52.8474236279726, 54.35873173177242, 55.783750265836716, 56.2125838547945, 57.61866420507431, 59.036816507577896, 56.76740348339081, 57.049120366573334, 58.610209599137306, 56.88885256648064, 43.332791179418564, 10.240713637322187, 1.0418377141468227, 25.025265254080296, 59.1062767803669, 54.606676027178764, 53.64663854241371, 60.099889263510704, 63.203087747097015, 63.513576686382294, 65.45793235301971, 35.46673446893692, 1.140150788705796, 14.361945893615484, 26.7263275757432, 44.79144170880318, 64.1464327275753, 77.05874785780907, 38.479528203606606, 31.25794731080532, 28.375857062637806, 28.91312923282385, 19.827149882912636, 31.71888157725334, 69.18041780591011, 45.581936091184616, 2.3829148337244987, 0.060826226908829994, 0.193488868244458, 0.05539191733987536, 0.12445262895198539, 0.03635244524048176, 0.07563004328403622, 0.02251215177238919, 0.08498926763422787, 0.22751702199457213, 0.18574173707747832, 0.22342824842780828, 0.23434785311110318, 0.16554892295971513, 0.19014130724826828, 0.21971982554532588, 0.079006139858393, 0.28034352406393737, 0.1423527707811445, 0.35377767111640424, 0.4974610829958692, 0.5292830988764763, 28.43431692570448, 88.66543784737587, 63.69056738913059, 41.15387409925461, 53.39788869023323, 63.24865870177746, 70.31448975205421, 46.0060503333807, 26.557485535740852, 39.054870530962944, 33.416873663663864, 49.77848030626774, 9.50244365260005, 27.123657055199146, 65.11742502450943, 64.49206218123436, 72.82558500766754, 64.2989033460617, 71.33601933717728, 51.9679494202137, 5.477828336879611, 1.2735470244660974, 0.4020682704867795, 33.36898483335972, 76.66566655039787, 69.29356813430786, 72.66286253929138, 73.20855125784874, 72.72206336259842, 63.442995473742485, 55.75433224439621, 68.66224721074104, 67.46456667780876, 68.2270185649395, 65.87196573615074, 62.43873976171017, 66.72539994120598, 66.71757236123085, 64.26540434360504, 65.85665255784988, 65.50429746508598, 67.63279125094414, 64.24499183893204, 63.74366953969002, 63.56421656906605, 62.187793627381325, 56.55581183731556, 41.665064468979836, 34.577817767858505, 39.616073817014694, 44.04493376612663, 40.23980654776096, 38.379293382167816, 41.66110888123512, 40.366370156407356, 40.31163029372692, 33.16905476152897, 22.38515742123127, 12.739416807889938, 11.023236997425556, 28.001865930855274, 36.56534291803837, 29.895424023270607, 40.685735419392586, 41.72801189124584, 29.871859587728977, 13.01551379263401, 9.668914619833231, 8.491105120629072, 7.979421727359295, 15.468920543789864, 25.473301112651825, 27.31684058904648, 26.483645997941494, 24.81154952198267, 21.025584675371647, 26.302720606327057, 29.875142611563206, 37.18660958111286, 45.071900859475136, 40.572490096092224, 41.92900970578194, 32.11872652173042, 24.08066064119339, 12.971215769648552, 8.784878756850958, 16.95075362920761, 26.04015089571476, 37.16988667845726, 32.163328528404236, 29.37252838164568, 30.835579074919224, 15.041162297129631, 4.5085487980395555, 1.4522826648317277, 1.3033148646354675, 1.6875659208744764, 7.533996803686023, 16.185130812227726, 17.637836560606956, 26.325291395187378, 30.29434561729431, 30.678759589791298, 29.18712493032217, 30.92196173965931, 40.90642377734184, 39.9388512969017, 42.45337016880512, 44.69000995159149, 49.07803729176521, 58.042865842580795, 57.21495106816292, 58.54553706943989, 58.849129378795624, 58.04797276854515, 54.75908204913139, 53.886960446834564, 56.30816012620926, 56.02559968829155, 58.164512515068054, 58.050587028265, 57.711253836750984, 59.94318187236786, 62.23936066031456, 61.910488307476044, 57.63931229710579, 58.50075267255306, 61.03136368095875, 49.72282849252224, 16.611220948398113, 0.8713431190699339, 19.75895494222641, 63.187386989593506, 57.90544621646404, 58.97195778787136, 64.48024481534958, 64.80280950665474, 69.04556304216385, 68.79973903298378, 54.41608965396881, 2.9699754947796464, 11.081927698105574, 34.88500088453293, 50.06536491215229, 66.98451563715935, 80.20811766386032, 36.5718899667263, 49.68280903995037, 31.292945332825184, 36.181077137589455, 31.26524291932583, 39.808708280324936, 75.89464232325554, 59.11515690386295, 4.3856410682201385, 0.18453242228133604, 0.55367226828821, 0.14379560976522043, 0.3368090285221115, 0.16284857410937548, 0.23700800724327564, 0.11810827563749626, 0.14601100963773206], [0.022935673187021166, 0.053844494905206375, 0.016877072703209706, 0.05966362288745586, 0.045721855567535385, 0.020952650884282775, 0.05985427320410963, 0.03761165833566338, 0.11892802227521315, 0.03626449703006074, 0.18917601060820743, 0.22071835555834696, 0.2397950686281547, 5.474621783941984, 67.57205531001091, 62.08785519003868, 34.785415828228, 36.7836108058691, 60.873200967907906, 39.26625698804855, 54.17691148817539, 33.583969697356224, 33.294258043169975, 28.361400738358498, 29.76316262036562, 14.077097028493881, 4.012610334903002, 37.94198624789715, 66.22607633471489, 59.75807100534439, 43.81720818579197, 44.37222920358181, 61.289183646440506, 60.11752791702747, 31.948047280311584, 10.312957260757685, 1.8354590912349522, 30.94998713582754, 61.40636555850506, 64.03012096881866, 66.7004656791687, 64.55309450626373, 64.31479409337044, 57.82993666827679, 60.58483824133873, 59.69647631049156, 58.9807391166687, 63.01745630800724, 61.802140921354294, 60.02782993018627, 59.07578721642494, 63.253355249762535, 62.9139194637537, 60.93427509069443, 57.87980519235134, 57.57993668317795, 56.57131500542164, 52.46000021696091, 36.358223631978035, 24.052677042782307, 22.186019606888294, 20.25971297174692, 26.83976858854294, 31.948203071951866, 31.442729495465755, 40.16400061547756, 36.683558374643326, 31.39924082905054, 29.1470180824399, 23.88492364436388, 14.590904507786036, 4.971877411007881, 9.670162852853537, 17.979170344769955, 28.998005278408527, 25.967979468405247, 20.66363699734211, 10.038531236350536, 2.5223314901813865, 0.5020510288886726, 3.7491360353305936, 3.390684169717133, 3.91664054710418, 8.326771538704634, 14.579687509685755, 22.479711547493935, 14.122370649129152, 21.8641122803092, 19.096215404570103, 24.90781545639038, 30.013614781200886, 27.037348486483097, 35.09762987494469, 40.05965441465378, 37.014611810445786, 26.34367100894451, 7.035693442448974, 2.247036974877119, 1.6262915963307023, 1.799597090575844, 6.923741474747658, 15.428568609058857, 21.642498672008514, 24.623913690447807, 24.899047426879406, 9.333167485892773, 5.109580596908927, 3.508630315773189, 0.38380178972147405, 0.23864301794674248, 1.6042923205532134, 8.439640682190657, 8.73995566740632, 13.123353905975819, 19.67746641486883, 18.34407426416874, 20.83474561572075, 17.67391562461853, 15.018118433654308, 17.354322373867035, 24.551873356103897, 33.90233941376209, 38.28431747853756, 44.044523388147354, 48.456466645002365, 49.123349860310555, 50.98704345524311, 54.288245514035225, 48.49521316587925, 47.65945181250572, 47.727867141366005, 49.21991027891636, 51.237047240138054, 55.16467608511448, 57.33639255166054, 54.210098907351494, 55.345458984375, 55.883445516228676, 50.44054917991161, 50.972022861242294, 45.39611466228962, 21.58225480467081, 2.0223091961815953, 13.282082788646221, 60.13998471200466, 42.10938222706318, 46.05078153312206, 55.004856660962105, 50.86534358561039, 49.65551130473614, 55.374850407242775, 42.39194266498089, 3.4536817017942667, 6.404905915260315, 58.27661029994488, 40.80419026315212, 47.6309609413147, 68.87099280953407, 55.50546459853649, 31.53447177261114, 27.608503438532352, 13.309379573911428, 37.34756514430046, 28.951309584081173, 32.78006963431835, 62.064558640122414, 35.776011273264885, 0.8081134431995451, 0.13935149589087814, 0.1833649497712031, 0.022988668097241316, 0.02622309053549543, 0.015238774285535328, 0.12613861035788432, 0.05479633640788961, 0.049343762584612705, 0.09004787978483364, 0.09606271953089163, 0.07194513163994998, 0.03707035808474757, 0.03545139261404984, 0.029435506439767778, 0.014862855150568066, 0.046548522732337005, 0.02485808428900782, 0.050467960463720374, 0.09739597298903391, 0.20498856523772702, 0.13321469159564003, 6.591407032683492, 78.30384224653244, 71.47903606295586, 34.17458340525627, 42.15355485677719, 72.234116345644, 44.9934084713459, 36.6085010021925, 41.19893208146095, 39.57212537527084, 34.76827874779701, 44.8687219619751, 21.710680313408375, 4.686186416074634, 30.393520295619965, 73.31195890903473, 62.038704827427864, 47.66552768647671, 52.228664830327034, 66.08600065112114, 65.22755071520805, 43.376431837677956, 16.563843190670013, 2.273637210018933, 30.29595673084259, 62.67814211547375, 65.8035010099411, 69.39801692962646, 64.96917217969894, 64.22075673937798, 60.79285807907581, 62.32087388634682, 62.41369150578976, 62.37126678228378, 65.75242415070534, 62.11820416152477, 60.78544847667217, 60.93948841094971, 64.51343223452568, 62.9723185300827, 60.113671123981476, 59.66364607214928, 60.17128363251686, 59.60559658706188, 57.88849152624607, 42.93498292565346, 28.00329465419054, 25.48309698700905, 25.745290517807007, 34.3728681653738, 36.230436488986015, 34.03865709900856, 44.141972959041595, 39.74970884621143, 34.23864036798477, 29.35680102556944, 24.024531953036785, 16.595841273665428, 8.253058344125748, 14.497874099761248, 24.171101488173008, 28.863999769091606, 29.471423774957657, 34.125725626945496, 27.27520052343607, 12.856593020260334, 5.176355838775635, 5.603723181411624, 4.6763145457953215, 3.824098650366068, 2.9269558656960726, 4.899030094966292, 13.319564927369356, 14.613406900316477, 20.7714182138443, 17.962662130594254, 25.233393386006355, 30.715285129845142, 39.46742579340935, 42.21383102238178, 46.96940504014492, 38.891084119677544, 26.936589293181896, 11.554294601082802, 8.319906257092953, 6.3592062424868345, 6.378805115818977, 15.287730116397142, 24.63580135256052, 28.746586069464684, 23.31159520894289, 26.531684920191765, 16.288582161068916, 7.649018531665206, 2.8345384122803807, 1.6538434429094195, 1.9561581895686686, 5.144656514748931, 12.039419319480658, 13.744748812168837, 18.438035622239113, 25.301402136683464, 23.471614122390747, 25.149662978947163, 24.807470440864563, 20.321909934282303, 23.31592507660389, 31.193725056946278, 39.61147986352444, 43.314054384827614, 46.71569645404816, 52.97276750206947, 53.345618695020676, 53.95832061767578, 56.41356647014618, 53.60894076526165, 50.547114461660385, 51.93028204143047, 51.7856390029192, 54.73340682685375, 57.93639935553074, 59.459623619914055, 57.88659542798996, 59.30125191807747, 55.54129287600517, 52.099000588059425, 50.54799221456051, 44.467178508639336, 23.95639780908823, 2.8087558457627892, 19.925754591822624, 65.70717617869377, 45.03301754593849, 51.792041659355164, 63.58560562133789, 56.908641904592514, 54.00055535137653, 63.955568969249725, 36.47941052913666, 3.184079281054437, 12.875280417501926, 66.04173302650452, 42.157605439424515, 52.502101957798004, 68.13973724842072, 65.27288228273392, 30.819956213235855, 32.55760297179222, 19.16543059051037, 35.42447313666344, 27.30616696178913, 38.19021172821522, 73.98313969373703, 39.06596973538399, 0.8370775077491999, 0.09908469291985966, 0.09642971155699342, 0.1111468933231663, 0.058993066486436874, 0.03879104602674488, 0.027443162762210704, 0.03062441774090985, 0.030512730081682093, 0.1655664821737446, 0.26896550960373133, 0.29618146014399827, 0.19032203505048528, 0.1739000139059499, 0.10435837204568088, 0.19018095277715474, 0.13228976778918877, 0.27512227767147124, 0.1727007477893494, 0.20362801558803767, 0.5236289429012686, 0.4353823297424242, 10.852488409727812, 97.32573553919792, 81.40846565365791, 49.726100116968155, 47.97144927084446, 75.0273084640503, 59.88568715751171, 68.88182982802391, 44.09707836806774, 48.98689538240433, 43.40673141181469, 43.81447993218899, 22.101660333573818, 8.133834041655064, 45.72707310318947, 79.61972683668137, 68.22723135352135, 53.633077070117, 60.59293940663338, 74.2648033797741, 74.21736672520638, 40.83999954164028, 11.951113007962704, 2.842284059152007, 43.15844513475895, 71.40863344073296, 70.80158561468124, 74.74194377660751, 67.64312669634819, 66.19246333837509, 62.087403014302254, 66.00859880447388, 63.95295470952988, 66.06416702270508, 70.64669072628021, 67.64124199748039, 66.27381697297096, 62.83364497125149, 68.79775553941727, 66.98811024427414, 67.56178826093674, 64.88412514328957, 65.01068875193596, 62.03655034303665, 62.7077691257, 50.20603336393833, 33.77531222999096, 30.16705434769392, 30.037713088095188, 38.528465777635574, 44.25888128578663, 40.20350709557533, 50.578474178910255, 43.89271393418312, 37.06166088581085, 34.18877564370632, 28.657433353364468, 17.077581323683262, 11.175613570958376, 19.892905354499817, 34.41787675023079, 39.994780495762825, 39.445690959692, 42.09134079515934, 27.528208047151566, 10.405009221285582, 3.7950211856514215, 7.774951849132776, 12.492031082510948, 17.303918078541756, 25.074098333716393, 32.09161877632141, 36.779222041368484, 32.86272279918194, 37.68216758966446, 28.280594274401665, 37.033109217882156, 42.197214514017105, 43.46415393054485, 47.80603654682636, 49.6220351010561, 45.85290715098381, 40.15067473053932, 28.281196542084217, 12.19257865101099, 7.332355873659253, 5.11394988745451, 13.280016649514437, 25.7955789193511, 34.111343398690224, 31.050514541566372, 38.089235946536064, 28.294083550572395, 10.99637908861041, 3.191874325275421, 1.7981434310786426, 2.1507185557857156, 5.895351357758045, 15.443442910909653, 21.57162867486477, 26.786651238799095, 29.178752079606056, 29.761057533323765, 31.98512189090252, 31.781927794218063, 24.58136547356844, 30.460869781672955, 35.70303998887539, 44.08541299402714, 46.27987124025822, 50.08915923535824, 54.266077503561974, 55.637826696038246, 58.46897877752781, 60.82544133067131, 56.56708583235741, 54.956656247377396, 54.2259706556797, 55.802228674292564, 55.10557405650616, 61.25092729926109, 64.78818789124489, 59.03089642524719, 60.06734400987625, 61.29152052104473, 51.15540862083435, 54.2189372330904, 49.36511568725109, 32.20105290412903, 3.6121384240686893, 16.037423238158226, 69.81694445014, 51.588938757777214, 57.63710841536522, 65.70277601480484, 62.31872320175171, 59.462557062506676, 68.932154327631, 52.32445769011974, 6.694382457062602, 10.903549119830132, 71.39886796474457, 49.6195500344038, 56.757429018616676, 72.14865133166313, 66.27057194709778, 35.480759516358376, 46.401647105813026, 19.664685800671577, 51.398800760507584, 38.31759989261627, 48.36490675806999, 79.13514643907547, 60.52860885858536, 1.9368887110613286, 0.402460124460049, 0.30271850468125194, 0.13343230413738638, 0.18791351350955665, 0.18754784250631928, 0.30101494921837, 0.1525342502282001, 0.1547362914425321], [0.07922846503788605, 0.014437543304666178, 0.04930739363771863, 0.0979812974401284, 0.03826633277640212, 0.06400569516699761, 0.012716885048575932, 0.05686277239874471, 0.07709204452112317, 0.03345008379255887, 0.0516397300089011, 0.07294196213479154, 0.1451712250127457, 0.9520409919787198, 36.36405631899834, 61.15436688065529, 41.332722902297974, 31.790921911597252, 43.72101254761219, 30.802017375826836, 50.56077852845192, 38.50426107645035, 31.08924776315689, 23.57821360230446, 28.029579743742943, 37.53115229308605, 8.849295750260353, 3.1948065804317594, 26.93296618759632, 60.291630774736404, 66.683738976717, 51.6536720842123, 47.17787705361843, 58.19714896380901, 60.20757168531418, 59.7152055054903, 13.50254600867629, 1.8536187917925417, 25.774391256272793, 53.1388907879591, 56.59363880753517, 53.66132475435734, 49.615849032998085, 51.73574008047581, 58.21970835328102, 63.63772742450237, 57.131769731640816, 59.795411601662636, 58.08349326252937, 58.40625174343586, 60.38483217358589, 59.30567108094692, 56.75810158252716, 60.16474798321724, 53.80388170480728, 49.540096297860146, 38.8232197612524, 27.08823535591364, 24.62867483496666, 25.192032605409622, 17.470618933439255, 24.530742689967155, 29.514496363699436, 34.48376141488552, 34.279305785894394, 40.501335114240646, 31.34930770844221, 31.839114725589752, 24.820612035691738, 19.07172191888094, 8.196721617132425, 7.499866085126996, 19.86354622989893, 28.596193939447403, 30.682289600372314, 20.756091736257076, 9.861883465200663, 2.8896017326042056, 0.777949474286288, 1.5655447309836745, 2.107785609550774, 4.108726652339101, 1.906611816957593, 11.210422553122044, 14.04134189710021, 16.681433580815792, 22.687144316732883, 29.46055255830288, 23.94904900342226, 38.05408023297787, 38.69631037116051, 32.915878146886826, 39.31209392845631, 41.18441306054592, 39.8464934527874, 23.50193839520216, 3.1128383288159966, 1.948987974319607, 2.257735775783658, 1.194671094417572, 1.3731076195836067, 6.523043001070619, 13.600299563258886, 22.49300893396139, 26.366175301373005, 21.395945101976395, 8.774650655686855, 6.438928339630365, 0.203003067872487, 4.396089557558298, 7.032560985535383, 7.750791795551777, 11.299605667591095, 9.96590668335557, 14.038432203233242, 23.985008373856544, 15.854849684983492, 17.44247194379568, 20.81817090511322, 21.195492558181286, 27.49326892197132, 31.331070587038994, 41.3372066617012, 44.14990693330765, 50.25138773024082, 51.578975692391396, 52.04227343201637, 50.114564672112465, 50.224447175860405, 49.996957182884216, 51.369158551096916, 51.3467663526535, 53.02968084812164, 51.521401181817055, 53.83537821471691, 55.146433264017105, 55.00049449503422, 47.207378670573235, 50.41516274213791, 41.08533717691898, 35.48959404230118, 16.21973365545273, 6.791856251657009, 50.4738087952137, 51.3465915620327, 51.25156246125698, 44.84623856842518, 40.19268147647381, 43.02414134144783, 54.968944787979126, 48.91556181013584, 6.91424673423171, 2.7800184627994895, 64.93385687470436, 58.55003982782364, 22.821527905762196, 52.45200164616108, 59.09661389887333, 45.78968994319439, 34.598123878240585, 17.32811328023672, 20.32676037400961, 38.737914338707924, 18.62135488539934, 40.71778669953346, 65.00209361314774, 16.309382244944572, 0.5014178878627717, 0.36759117676410824, 0.1402781266369857, 0.0492610131186666, 0.07773865552735515, 0.08135146752465516, 0.023280703208001796, 0.07545497806859203, 0.025544776835886296, 0.01262091051103198, 0.06164247803098988, 0.09228630849975161, 0.07008524276898243, 0.12741795420879498, 0.08091296214843169, 0.030500772227242123, 0.06014827871695161, 0.039494282900705, 0.09572783281328157, 0.06183606725244317, 0.06379128128173761, 0.0706899150100071, 0.9840666234958917, 39.14533227682114, 77.58002668619156, 39.88098420202732, 34.86964210867882, 51.57174848020077, 34.38571147620678, 40.75892709195614, 36.18536330759525, 39.85801063477993, 30.83946816623211, 37.19114273786545, 53.068784549832344, 16.44183173775673, 2.7793784346431494, 22.78567872941494, 60.201024636626244, 72.71662965416908, 60.87184064090252, 57.695047706365585, 65.33755481243134, 63.12005080282688, 64.8644270002842, 20.460184514522552, 2.0096373511478305, 26.88799560070038, 53.6579467356205, 56.660811603069305, 55.5987685918808, 50.65906785428524, 51.49866320192814, 59.20311838388443, 66.9308777153492, 63.369583413004875, 61.810717061161995, 63.76694709062576, 62.68690824508667, 63.725153133273125, 60.18377736210823, 61.0277196764946, 59.955132231116295, 56.45940341055393, 52.78190754354, 48.299728855490685, 34.03164267539978, 28.96849986165762, 28.657155968248844, 25.1993453130126, 28.917043022811413, 33.10058243572712, 34.74095061421394, 39.52297121286392, 42.77352958917618, 35.73909245431423, 33.13199155032635, 25.134617686271667, 20.60982808470726, 9.307831395417452, 12.409010287374258, 19.72889855504036, 28.414858169853687, 38.4036310762167, 34.889207258820534, 22.066012546420097, 10.582210812717676, 2.642551101744175, 1.5695630153641105, 3.451369763351977, 2.319348519667983, 3.2396795600652695, 11.095585115253925, 22.895470038056374, 29.162323661148548, 23.106865994632244, 30.78820511698723, 25.477159805595875, 32.81839817762375, 37.56782792508602, 35.775471702218056, 43.03726203739643, 45.265880450606346, 42.69566036760807, 37.30801306664944, 12.17852795496583, 2.6995960157364607, 2.590805240906775, 2.098424336872995, 5.330811375752091, 14.405318666249514, 22.042488008737564, 25.948416218161583, 27.529974952340126, 22.40930512547493, 13.152966666966677, 6.706896610558033, 3.6200258508324623, 7.265548808500171, 9.675818849354982, 10.206568669527769, 14.656243901699781, 16.42314624041319, 18.667757995426655, 28.967586010694504, 22.01820731163025, 23.09326082468033, 25.70788912475109, 25.416515059769154, 30.6030847504735, 36.106490939855576, 44.56872045993805, 47.52319872379303, 52.8152621537447, 55.228060483932495, 54.9086382240057, 55.46370483934879, 52.995862662792206, 52.2372979670763, 53.048873618245125, 54.12259340286255, 56.35646693408489, 55.05463019013405, 58.78106363117695, 59.39878508448601, 57.172818928956985, 48.924430534243584, 54.3056333810091, 40.29271490871906, 42.658148780465126, 18.976860009133816, 11.135043147951365, 57.15663939714432, 55.708134323358536, 58.0643916875124, 47.90049187839031, 47.98982888460159, 48.02750006318092, 61.62319332361221, 48.69268096983433, 4.565611761063337, 5.817200001329184, 69.84699323773384, 65.69935619831085, 29.62891772389412, 52.33311362564564, 66.2771911919117, 50.79445078969002, 32.706779167056084, 26.496234722435474, 24.01758212596178, 37.904030084609985, 23.082463704049587, 50.19257068634033, 75.54664939641953, 19.64156024158001, 0.5196710396558046, 0.26598166034091264, 0.1289941422874108, 0.033337681816192344, 0.020909745471726637, 0.02091846941766562, 0.03709910888574086, 0.14208841777872294, 0.04187263984931633, 0.18560862547019497, 0.18024271965259686, 0.17829633346991614, 0.22899928386323154, 0.31888268887996674, 0.1095140422694385, 0.16303096432238817, 0.22906417725607753, 0.11323929706122726, 0.2425889132427983, 0.1409864323795773, 0.2698597975540906, 0.2296278384164907, 2.5329519202932715, 62.86096550524235, 85.47087326645851, 56.43209807574749, 46.9657876342535, 55.17733320593834, 47.152342423796654, 72.3207288980484, 48.11050280928612, 44.15048450231552, 39.28166516125202, 38.191503658890724, 48.66729073226452, 15.062007028609514, 4.647683082148433, 35.0031441450119, 72.66726270318031, 80.32737046480179, 64.63703200221062, 59.74279202520847, 69.99494969844818, 71.55326128005981, 68.48191648721695, 18.078128434717655, 3.5255325213074684, 38.45382258296013, 63.19181755185127, 61.57560467720032, 59.96915727853775, 53.99222619831562, 52.775641679763794, 65.42650043964386, 69.91782143712044, 66.15598529577255, 67.17984035611153, 68.88899624347687, 65.79361394047737, 69.11340460181236, 64.072595089674, 63.68332117795944, 63.38336147367954, 60.836962312459946, 58.93345445394516, 53.87407913804054, 40.99815085530281, 33.754306957125664, 32.65692204236984, 28.848513700067997, 36.363976523280144, 39.716437831521034, 41.25285118818283, 46.19302690029144, 46.86247877776623, 38.374798223376274, 35.026341900229454, 28.128022961318493, 22.344471104443073, 11.262785643339157, 16.929147988557816, 26.505745612084866, 34.65949438512325, 47.74293713271618, 41.994787976145744, 24.264017902314663, 8.974190298467875, 2.215035567060113, 5.909274760633707, 10.653224252164364, 20.55838644504547, 24.185536913573742, 34.37517084181309, 36.29578158259392, 37.3537740111351, 35.90867355465889, 43.47702383995056, 35.40555775165558, 45.85786208510399, 50.64114421606064, 48.99907372891903, 53.517396077513695, 51.785012036561966, 46.774460300803185, 47.85466633737087, 22.766140177845955, 10.068675968796015, 7.079680357128382, 3.297399412840605, 4.196963142603636, 15.280153322964907, 25.55826835334301, 31.827306859195232, 32.604393661022186, 32.11309902369976, 18.943748585879803, 9.60888734087348, 6.13057061098516, 7.890561120584607, 11.972041334956884, 13.840350732207298, 18.779124319553375, 24.576104655861855, 26.866011880338192, 33.84423293173313, 27.073182463645935, 30.275048352777958, 32.50608533620834, 27.418164052069187, 34.31404732167721, 38.68073880672455, 47.34676279127598, 49.48244199156761, 57.420204654335976, 59.01025213301182, 57.23822861909866, 59.1544695943594, 56.75858795642853, 57.139916494488716, 57.727288976311684, 58.391660526394844, 58.94646115601063, 57.635056525468826, 59.41099762916565, 62.31531098484993, 60.06977967917919, 50.87279498577118, 54.45948712527752, 47.192570865154266, 44.3629615008831, 22.611532174050808, 8.5851557739079, 61.32098414003849, 59.83739174902439, 62.959338426589966, 50.15404835343361, 52.23304219543934, 54.298622757196426, 66.52693659067154, 58.87769624590874, 12.415869869291782, 5.973939215764403, 78.22124987840652, 66.11721977591515, 34.65878762304783, 56.134053468704224, 70.49561843276024, 50.133472457528114, 49.32212479412556, 29.603631980717182, 28.78697220236063, 53.59379477798939, 27.15800531208515, 59.78693425655365, 83.76129940152168, 34.49470102787018, 1.1535551631823182, 0.6918892578687519, 0.29275665641762316, 0.1485732596484013, 0.2277778126881458, 0.2553927863482386, 0.13340993580641225, 0.3957238281145692, 0.1790870472905226], [0.04079507110873237, 0.11422506213421002, 0.06133707684057299, 0.06202827236847952, 0.04283012167434208, 0.0743713830888737, 0.0737389396817889, 0.0391920284164371, 0.028249762253835797, 0.10141019040020183, 0.05106634671392385, 0.027358357547200285, 0.26746978517621756, 0.177954648679588, 6.7723732721060514, 64.60705921053886, 50.14460206031799, 42.49147832393646, 29.417569264769554, 18.99252276867628, 38.872408121824265, 49.669296965003014, 30.917352586984634, 20.144299864768982, 15.766973700374365, 34.793801978230476, 47.916162237524986, 7.2120956517755985, 2.86187129560858, 28.98871097713709, 52.007588893175125, 61.032321229577065, 72.97053202986717, 57.66845293343067, 57.70268529653549, 54.50966723263264, 49.256384521722794, 7.402909062802792, 0.9850351558998227, 16.523504555225372, 35.01002177596092, 39.62029159069061, 60.98757103085518, 52.84569092094898, 52.05978289246559, 51.75782449543476, 56.40567809343338, 57.413353621959686, 57.26130858063698, 57.214031517505646, 58.31585839390755, 57.56913386285305, 54.94279459118843, 45.400089249014854, 37.06066533923149, 23.75513780862093, 24.239710606634617, 26.137165389955044, 29.32907961308956, 29.35488972812891, 24.164461344480515, 21.928087547421455, 27.44716789573431, 31.02257464081049, 37.33665972948074, 33.939531818032265, 26.03039111942053, 21.710541620850563, 13.63700084388256, 7.084495648741722, 4.709393195807934, 18.696028478443623, 29.51051987707615, 30.335168726742268, 18.636417277157307, 10.272930208593607, 2.76350739877671, 0.28277684818021953, 0.18590028950711712, 3.072254369035363, 2.6805238891392946, 2.5146689638495445, 0.2056549841654487, 9.556979276239872, 17.379361130297184, 24.107454903423786, 32.062105759978294, 32.115511894226074, 27.803702764213085, 42.28891499340534, 40.59738636016846, 28.976583927869797, 31.05131059885025, 31.321647092700005, 28.50952059030533, 15.044465269893408, 2.0458494080230594, 2.657885178923607, 2.466034898534417, 2.3859608452767134, 1.4625687128864229, 3.1843597535043955, 9.520226698368788, 18.59367147088051, 24.419040083885193, 24.680659845471382, 14.777875375002623, 8.723569046705961, 7.874283269047737, 4.092104444280267, 9.251046292483807, 11.35567070916295, 14.906785357743502, 12.97905569896102, 3.675227388739586, 10.500254910439253, 24.70134973526001, 19.873273707926273, 23.830748051404953, 29.059056602418423, 30.978854186832905, 39.640343114733696, 44.72130127251148, 50.231169015169144, 48.12469504773617, 49.81416419148445, 48.73152248561382, 50.07296450436115, 50.72522230446339, 50.95783442258835, 49.1981640458107, 50.37497989833355, 54.06815752387047, 56.8283674120903, 57.63256385922432, 57.88906529545784, 52.56764464080334, 54.476145431399345, 41.80228650569916, 33.436032235622406, 41.24943517148495, 12.684263717383146, 30.35362433642149, 60.59139668941498, 47.23310329020023, 60.32304748892784, 48.22168484330177, 46.48426227271557, 55.67963965237141, 52.37986631691456, 19.11934856325388, 0.7707586570177227, 21.97516892105341, 57.32188493013382, 14.999656174331903, 23.980895094573498, 55.465034767985344, 54.27957437932491, 31.443688943982124, 33.22054199874401, 10.494705308228731, 31.351730078458786, 30.452234745025635, 23.56799405068159, 52.33757458627224, 59.697886034846306, 7.569593768566847, 0.05257771561446134, 0.2723008400062099, 0.07787132184603252, 0.14800602133618668, 0.09704408366815187, 0.022129580211185385, 0.04246810945915058, 0.09186471666907892, 0.038339115199050866, 0.05845148793014232, 0.03641651484940667, 0.027913187150261365, 0.05652892097714357, 0.050617076485650614, 0.015381651628558757, 0.052859071220154874, 0.047864205844234675, 0.04451859669643454, 0.12995994358789176, 0.023860930959926918, 0.08227547848946415, 0.3426376188872382, 0.04938127443892881, 9.553564209491014, 81.72291398048401, 57.73852117359638, 41.063283160328865, 32.75934934616089, 22.180238217115402, 36.52615562081337, 41.30056522786617, 35.53091682493687, 28.12235366553068, 19.628745429217815, 43.59898969531059, 59.56976071000099, 9.807286094874144, 2.662451108917594, 31.11174825578928, 57.54248969256878, 67.60961249470711, 76.90851151943207, 62.759818732738495, 63.370244577527046, 59.68205988407135, 58.2121429592371, 12.83470619469881, 1.235784413293004, 19.335243478417397, 38.315415009856224, 41.749564334750175, 62.15818181633949, 58.711679354310036, 55.98673917353153, 54.878646433353424, 60.103130489587784, 61.41999922692776, 61.22587524354458, 58.704201355576515, 62.40884676575661, 61.87025986611843, 56.11030854284763, 50.285870879888535, 43.53376239538193, 30.951729342341423, 29.44163527339697, 29.271731190383434, 33.396989330649376, 31.825482957065105, 27.32508234679699, 26.898883916437626, 28.658427000045776, 33.76336187124252, 40.28711020946503, 35.49772560596466, 30.362512059509754, 22.799354195594788, 16.570230647921562, 8.694876786321402, 9.738625679165125, 20.04821442067623, 28.156453035771847, 37.15955503284931, 37.30039827525616, 21.941696517169476, 8.151587639003992, 1.3400669675320387, 1.3784310151822865, 2.492297664284706, 1.8021990009583533, 1.518173860386014, 8.267108090221882, 19.054406248033047, 26.230372488498688, 30.650023631751537, 33.34814295172691, 36.20216980576515, 31.67939029633999, 40.909452214837074, 40.57845197618008, 40.455148592591286, 49.72735404968262, 47.52541400492191, 46.42531603574753, 35.13746693730354, 13.510905560106039, 4.45733324624598, 3.44458214007318, 2.6496626576408744, 2.096350360661745, 4.888846641406417, 16.195855736732483, 26.03736374527216, 29.615246057510376, 24.426683373749256, 17.563280761241913, 11.659573651850224, 8.68952002376318, 7.361409114673734, 14.023624397814274, 21.166887693107128, 17.638461627066135, 22.052000798285007, 6.964498087763786, 14.029571078717709, 26.76040604710579, 25.206388235092163, 26.37821115553379, 31.289593912661076, 32.974900379776955, 42.341336980462074, 46.60312369465828, 52.44656413793564, 48.67361359298229, 52.56756864488125, 49.55021895468235, 53.863850086927414, 53.23829345405102, 54.6894545853138, 53.26690211892128, 54.260719791054726, 57.130242213606834, 60.76687127351761, 60.19572392106056, 62.282302156090736, 53.30512046813965, 56.3093114644289, 41.04375220835209, 38.36086817085743, 39.69537176191807, 14.111995305866003, 37.56875887513161, 65.99300444126129, 51.125219240784645, 64.41279843449593, 50.072991102933884, 47.63461634516716, 59.74572166800499, 58.30523036420345, 17.581519782543182, 2.6549317874014378, 29.918213300406933, 70.81222504377365, 23.314063176512718, 25.56685209274292, 53.784761130809784, 64.45455059409142, 35.52404299378395, 34.96833421289921, 17.713509500026703, 30.351916328072548, 31.203275844454765, 21.779623813927174, 61.065276861190796, 66.37596309185028, 11.67971447110176, 0.15343837905675173, 0.19964571052696556, 0.10858030917006545, 0.17050627648131922, 0.06550801728735678, 0.04760241325129755, 0.024056861657300033, 0.10019211083999835, 0.1667597220512107, 0.14945976989110932, 0.22256679309066385, 0.17537617532070726, 0.14523141318932176, 0.17015731864375994, 0.11528159840963781, 0.2739860792644322, 0.17776520806364715, 0.16417361941421404, 0.2050576888723299, 0.17003648215904832, 0.16334389831172302, 0.6018237001262605, 0.378759044688195, 23.59510749578476, 97.09286883473396, 67.39321410655975, 59.96274322271347, 41.77449479699135, 33.135289773344994, 57.59677357971668, 62.78544455766678, 41.91588521003723, 33.44121515750885, 23.072833120822906, 45.688577368855476, 58.63221041858196, 11.924278847873211, 4.932015174999833, 35.42614124715328, 64.34155225753784, 72.20509350299835, 80.57652309536934, 70.85855215787888, 65.56140080094337, 64.77007806301117, 60.040293261408806, 11.726763546466827, 2.8567026229575276, 29.097191356122494, 46.9365444034338, 46.73953637480736, 71.49567157030106, 64.24810007214546, 60.39246216416359, 59.63814564049244, 65.6045512855053, 65.77757880091667, 65.63865065574646, 62.393556386232376, 64.76742580533028, 67.59996101260185, 60.310135781764984, 58.44827748835087, 52.96557068824768, 38.04281383752823, 33.22736643254757, 33.613684102892876, 38.395773097872734, 35.854860842227936, 31.181780397892, 32.593708634376526, 36.86159402132034, 40.948685109615326, 45.21056301891804, 38.64347040653229, 34.4447261095047, 27.31197115033865, 17.751602455973625, 9.52384790405631, 12.09595363587141, 25.125986449420452, 32.88500480353832, 47.01808042824268, 43.25527913868427, 22.289812937378883, 6.446990557014942, 1.420639269053936, 4.827093780040741, 9.609710946679115, 14.61907334625721, 19.15567461401224, 30.418969430029392, 33.99327993392944, 38.7317168712616, 43.047513887286186, 49.1045218706131, 42.16851845383644, 39.4588116556406, 48.35979983210564, 50.93999058008194, 46.23855225741863, 52.76580400764942, 50.31805895268917, 50.579348132014275, 43.98421302437782, 22.71015588194132, 12.206286415457726, 9.943429939448833, 10.09241234511137, 4.1852393466979265, 5.286105824634433, 19.72785361111164, 31.555399149656296, 35.76629899442196, 28.80966078490019, 24.363610558211803, 14.65968081727624, 13.26832752674818, 10.4879036732018, 18.202469162642956, 28.0508092045784, 23.141218051314354, 29.40544981509447, 10.908150672912598, 19.232014417648315, 34.68897320330143, 31.049488596618176, 30.086238384246826, 35.41734091937542, 37.325530126690865, 44.76478233933449, 49.75131556391716, 56.57354548573494, 52.45271220803261, 55.56360527873039, 54.882472828030586, 58.16030614078045, 58.91628697514534, 57.18914285302162, 55.81623092293739, 55.475214421749115, 59.104791060090065, 62.040308341383934, 65.6873108446598, 62.67511747777462, 56.80652618408203, 55.803729593753815, 47.53778614103794, 42.59407661855221, 52.28134140372276, 16.708816811442375, 35.76914124190807, 70.23371368646622, 55.42001098394394, 71.35179609060287, 55.05634389817715, 54.54187050461769, 66.29714772105217, 64.12057131528854, 26.58422090113163, 4.100278280675411, 29.644348695874214, 71.70301884412766, 19.289157651364803, 32.63608396053314, 57.61672630906105, 66.01638078689575, 35.98536103963852, 50.7703372836113, 18.363776206970215, 43.247554153203964, 42.766203582286835, 30.670063756406307, 70.23751348257065, 80.66348522901535, 19.974667467176914, 0.4151576478034258, 0.7612515077926219, 0.17646226391661912, 0.42021832312457263, 0.208078675204888, 0.2093549762503244, 0.12609586265170947, 0.1943935759481974, 0.25950149400159717], [0.06540638758451678, 0.08293847611639649, 0.09045274360687472, 0.10076561287860386, 0.05990761135763023, 0.022682921808154788, 0.07803073516697623, 0.030796649807598442, 0.06361308420309797, 0.1383958916994743, 0.02983120288263308, 0.00947728334722342, 0.031774099115864374, 0.2929735416546464, 0.32757127890363336, 31.752637065947056, 67.57739782333374, 43.57639990746975, 34.01942253112793, 36.607186272740364, 37.844722867012024, 48.65567855536938, 39.73868563771248, 26.009604334831238, 23.56717139482498, 23.96271876990795, 51.95657663047314, 30.57317465543747, 4.8737201280891895, 13.175940234214067, 50.340169966220856, 35.20293742418289, 51.87452383339405, 57.527248710393906, 63.139707148075104, 50.98065599799156, 42.36900709569454, 34.98645544052124, 9.095990862697363, 0.1947704385383986, 18.10257252305746, 40.558495447039604, 34.91287238895893, 52.97736145555973, 56.12781800329685, 54.937182292342186, 57.56373055279255, 54.38478693366051, 58.112375512719154, 57.60512933135033, 50.531292110681534, 41.968599781394005, 34.23262529075146, 27.13579550385475, 23.426603637635708, 26.234658658504486, 28.73039323836565, 28.156012259423733, 35.53573876619339, 31.61626048386097, 29.586388505995274, 21.029559262096882, 23.35438661277294, 26.37437906116247, 28.9467878267169, 29.47403233498335, 28.350937999784946, 18.053346164524555, 11.765177585184574, 7.834562100470066, 15.274541024118662, 29.462247267365456, 33.54474060237408, 26.285566426813602, 14.036092478781939, 5.820295410230756, 0.8004005101975054, 1.1526161385700107, 1.8800086132250726, 2.814231114462018, 2.90293687954545, 1.5971225802786648, 5.157936327159405, 16.344593055546284, 29.665656052529812, 39.56796459853649, 35.00359632074833, 32.88547217845917, 29.06715776771307, 40.204099863767624, 42.6213363558054, 24.483758211135864, 22.372186817228794, 21.613542325794697, 15.021059475839138, 9.912656340748072, 6.144727226346731, 7.726595168933272, 3.6947661777958274, 3.6598251527175307, 1.2404371448792517, 2.0071757957339287, 7.5226363632828, 17.514783963561058, 27.505528964102268, 26.69229280203581, 22.362155355513096, 11.990305054932833, 11.010455433279276, 9.072624016553164, 11.28094581887126, 7.130763391032815, 14.838097393512726, 23.89720268547535, 17.96063493937254, 3.7893780134618282, 6.3422411028295755, 12.359042018651962, 25.124797113239765, 26.786446049809456, 31.984665915369987, 38.03477726876736, 43.085561245679855, 46.592727452516556, 51.83893494307995, 52.27720342576504, 53.87665539979935, 50.89855000376701, 50.062925443053246, 51.67417198419571, 56.17503046989441, 54.31769773364067, 55.62385104596615, 52.322838976979256, 58.33135396242142, 55.78825302422047, 51.56507983803749, 45.29597483575344, 32.18252509832382, 26.310941465198994, 5.431482698768377, 19.79442983865738, 47.82770678400993, 42.733798921108246, 47.092856615781784, 48.81359428167343, 48.05036723613739, 58.24772424995899, 65.98216742277145, 37.95160353183746, 6.395918447524309, 4.645174741744995, 48.14831458032131, 16.586060598492622, 11.71730300411582, 37.79777638614178, 57.510081231594086, 50.5050203204155, 26.063143461942673, 21.173503138124943, 16.30307838320732, 38.03003512322903, 27.53752514719963, 37.415516898036, 48.41496907174587, 44.322429075837135, 2.1288949018344283, 0.07712349673965946, 0.2618980372790247, 0.04400767254992388, 0.031464979765587486, 0.026094546847161837, 0.022761172003811225, 0.0433278207492549, 0.043598474585451186, 0.12393223500112072, 0.053887609974481165, 0.07883296711952426, 0.024923962882894557, 0.017624049905862194, 0.009863743762252852, 0.01320533696343773, 0.01565541599120479, 0.07711760408710688, 0.061030725701129995, 0.10045647868537344, 0.0927951694757212, 0.01623435426154174, 0.046927819566917606, 0.3369674028363079, 1.600070153363049, 39.20031912624836, 80.93756452202797, 44.7214038670063, 33.645222410559654, 43.28103795647621, 35.06486043334007, 38.6540262401104, 39.52270522713661, 33.62312279641628, 30.612633638083935, 29.28290829062462, 61.76490671932697, 41.7725683003664, 5.446048267185688, 12.762137688696384, 53.679852560162544, 42.54363812506199, 60.33670395612717, 64.08034667372704, 66.1886939406395, 58.36695045232773, 49.35323752462864, 42.26617321372032, 14.880188684910536, 0.44247681624256074, 19.935337677598, 48.36712583899498, 39.93478551506996, 54.42392483353615, 54.60552468895912, 58.22784371674061, 59.26552623510361, 59.10840466618538, 63.57681669294834, 65.146045088768, 56.85521297156811, 47.974413111805916, 40.80911099910736, 36.059799045324326, 27.617875635623932, 30.53439773619175, 29.914388805627823, 32.74238705635071, 35.886288955807686, 36.46839112043381, 31.51077624410391, 25.68245518952608, 24.732698053121567, 30.999143198132515, 31.282706782221794, 32.33007498085499, 29.844685345888138, 19.717525765299797, 15.867567602545023, 9.865702260285616, 21.11937504261732, 28.26032616198063, 37.19493493437767, 44.11544278264046, 25.770870745182037, 10.215881019830704, 2.495720568113029, 0.9554980346001685, 2.5467960024252534, 2.423073216341436, 1.2545559997670352, 3.906236942857504, 11.209814585745335, 22.976817972958088, 29.486229680478573, 34.87368889153004, 40.00503234565258, 38.629198372364044, 33.222449496388435, 43.86261194944382, 45.06628856062889, 37.77811624109745, 42.164851650595665, 41.58660247921944, 38.71141076087952, 29.284473806619644, 10.56372670456767, 6.395546542480588, 3.960959231480956, 6.897309143096209, 5.085050538182259, 6.2217034958302975, 10.927767120301723, 22.31449071317911, 32.30903171002865, 28.72253715991974, 25.156276524066925, 16.5767814964056, 12.633572537451982, 12.1672473102808, 14.708541445434093, 13.736365512013435, 17.355506010353565, 26.067572124302387, 20.068925209343433, 5.853549325838685, 6.310804914683104, 19.096680879592896, 26.979513689875603, 30.010383054614067, 33.248440101742744, 40.93986198306084, 46.01272277534008, 49.751509353518486, 52.97062061727047, 52.62683406472206, 56.24634124338627, 54.749825745821, 51.70630685985088, 54.78914603590965, 56.769364178180695, 58.710186034440994, 57.97132708132267, 54.53246980905533, 61.1362836509943, 55.73462650179863, 51.49807423353195, 47.73938812315464, 34.265174344182014, 23.06092645972967, 5.084319077432156, 27.598059698939323, 51.045058742165565, 48.51983584463596, 50.81382215023041, 55.53722709417343, 51.76684521138668, 62.8580966591835, 65.08328005671501, 41.432703137397766, 4.5242889784276485, 10.492492876946926, 53.633350655436516, 25.508682914078236, 15.840897783637047, 35.5505807697773, 57.63242706656456, 58.1673813611269, 30.33754739910364, 28.759680166840553, 20.1407565549016, 39.43292744457722, 28.24819341301918, 36.65725618600845, 62.170667946338654, 49.64530885219574, 2.72664035204798, 0.07843738014344126, 0.11229420910240151, 0.03502352592477109, 0.039118181011872366, 0.05846012652909849, 0.025586281444702763, 0.06833736624685116, 0.04736849201435689, 0.01818828623072477, 0.21394713374320418, 0.2321776797180064, 0.2490726567339152, 0.2653617592295632, 0.11523729961481877, 0.09763083304278553, 0.15890744340140373, 0.1807031183852814, 0.1757032991736196, 0.2771918603684753, 0.21156997536309063, 0.12185134197352454, 0.27382093656342477, 0.46249381557572633, 3.3007781440392137, 68.53988617658615, 90.15970766544342, 59.203190580010414, 46.33358895778656, 51.58132016658783, 56.006859093904495, 61.83581471443176, 52.207442969083786, 41.178815960884094, 34.38469313085079, 29.659783467650414, 62.147337198257446, 40.43806470930576, 7.279646527022123, 20.326053611934185, 61.13684222102165, 47.170703038573265, 65.67540228366852, 67.6288166642189, 72.82746970653534, 63.60642850399017, 55.93155473470688, 44.21315833926201, 13.212213087826967, 0.7358019577804953, 29.938618205487728, 53.187053203582764, 43.530931547284126, 56.62606246769428, 60.447004437446594, 59.51276756823063, 64.72788512706757, 61.9610445946455, 68.96665647625923, 68.64894792437553, 62.30223968625069, 50.88161811232567, 48.585515320301056, 40.562192648649216, 31.365251652896404, 33.524039313197136, 35.566072538495064, 37.6503898948431, 42.97035902738571, 40.13999730348587, 38.921562284231186, 31.71743955463171, 34.942244812846184, 34.6427258849144, 35.45328699052334, 37.13751241564751, 35.646012648940086, 21.114232018589973, 19.742802008986473, 12.60580837726593, 23.109689243137836, 33.31796497106552, 39.08781856298447, 51.92183889448643, 31.97068266570568, 12.64154925942421, 3.008039714768529, 2.163473046384752, 5.065104933455586, 12.861059680581093, 18.779490999877453, 19.019573517143726, 23.392713256180286, 39.40989688038826, 46.30664460361004, 52.64111749827862, 46.26472145318985, 43.44415940344334, 37.60532811284065, 45.853241533041, 48.14696945250034, 42.40400321781635, 47.05027990043163, 44.01983991265297, 42.880752235651016, 34.07117195427418, 28.591729179024696, 23.338545262813568, 26.56068306416273, 22.65617597848177, 19.425042159855366, 12.36499059945345, 16.532320082187653, 28.925636261701584, 39.72697466611862, 34.76194828748703, 31.71878468245268, 22.728185914456844, 17.38634515553713, 17.466872334480286, 20.28066124767065, 19.571537598967552, 23.408805392682552, 28.639792799949646, 22.800123654305935, 6.010560700669885, 14.334259629249573, 30.017283484339714, 36.671003848314285, 34.45183552801609, 37.092199847102165, 45.97239553928375, 48.39142173528671, 52.45035633444786, 57.868257611989975, 57.52884462475777, 61.39101818203926, 58.46601113677025, 55.39583668112755, 58.74632969498634, 61.279231980443, 60.917628183960915, 63.460436537861824, 56.249776259064674, 63.0490668118, 57.47309781610966, 52.10346154868603, 46.82542696595192, 42.271527126431465, 32.424013540148735, 8.748437762260437, 24.367322959005833, 56.230575889348984, 50.83654873073101, 56.084705516695976, 57.51835718750954, 59.05511252582073, 66.29029288887978, 73.440992385149, 49.06303949654102, 10.130026526749134, 9.138555228710175, 57.35929772257805, 26.102283261716366, 18.743949607014656, 45.1731426268816, 63.66143435239792, 59.64223802089691, 33.2929091155529, 35.70580244064331, 21.668681167066097, 54.48124475777149, 36.439611464738846, 50.70941135287285, 69.19297233223915, 67.18857988715172, 6.577103650197387, 0.23372625990305096, 0.3381272905971855, 0.2127838766318746, 0.1963261581840925, 0.3374966135015711, 0.2891285339137539, 0.14628314034780487, 0.1780128775862977, 0.22629967716056854], [0.1258799125207588, 0.07432524376781657, 0.10176279960433021, 0.007087424964993261, 0.1383244525641203, 0.05242636943876278, 0.05928255974140484, 0.03635306122305337, 0.03771694682654925, 0.04854589074966498, 0.04937352270644624, 0.08236075867898762, 0.04933621494274121, 0.26996230299118906, 0.47114535758737475, 15.226546749472618, 63.02027575671673, 58.435506373643875, 36.050478145480156, 38.234388157725334, 43.91616627573967, 48.022552728652954, 43.81472311913967, 24.35897670686245, 22.05562200397253, 26.46464701741934, 37.76609368622303, 50.69345600903034, 10.624280255287886, 0.7930946303531528, 9.51383164152503, 46.570859625935555, 62.962921634316444, 58.4441053122282, 60.824244394898415, 63.022871017456055, 49.05611626803875, 42.857539281249046, 23.642781637609005, 1.6284220945090055, 1.8202996859326959, 35.82452706992626, 52.190480679273605, 40.707960426807404, 42.93704241514206, 46.226069927215576, 46.432961225509644, 47.54118695855141, 45.26938386261463, 36.70134522020817, 33.14853586256504, 30.07810492068529, 26.813301108777523, 27.374876774847507, 24.27243635058403, 24.850778616964817, 27.30663053691387, 35.701664462685585, 35.506142154335976, 30.659730210900307, 26.909266859292984, 16.239942871034145, 17.41111222654581, 20.236946493387222, 20.244092009961605, 16.022362746298313, 18.184194043278694, 12.354539260268211, 12.557018995285034, 17.83761654049158, 21.458520144224167, 27.966662719845772, 31.36099398136139, 22.460556775331497, 13.323613610118628, 5.247515570372343, 0.8281126013025641, 0.9401744068600237, 2.9976116493344307, 2.726941010914743, 9.016206543892622, 11.329497713595629, 20.073163881897926, 31.09527613967657, 41.89388059079647, 48.441932424902916, 39.61882866919041, 36.89081825315952, 31.59627355635166, 43.75773377716541, 45.784978196024895, 29.072352088987827, 18.403987549245358, 17.669745348393917, 11.846164539456367, 16.540419347584248, 18.621094599366188, 25.552287474274635, 22.37127296626568, 23.24212733656168, 14.334319476038218, 13.990532923489809, 14.483962096273899, 21.008269004523754, 29.766063764691353, 26.77958931773901, 21.004486307501793, 18.94997075200081, 17.64565084129572, 10.115793440490961, 15.297317001968622, 17.20548626035452, 10.925771277397871, 18.033925406634808, 23.501300029456615, 24.813905395567417, 7.651745835319161, 2.6204795110970736, 11.541976612061262, 26.32456373423338, 33.88704143464565, 35.19391290843487, 46.772754192352295, 47.07268349826336, 46.153505221009254, 47.206170335412025, 48.94170060753822, 51.60026594996452, 50.34119971096516, 52.95508325099945, 53.16094100475311, 52.495516911149025, 53.42126503586769, 60.55991157889366, 56.79165378212929, 47.157384753227234, 48.300686404109, 39.30350258946419, 9.999425634741783, 0.20093268365599215, 8.484943751245737, 50.80950938165188, 47.74656593799591, 51.10729940235615, 53.64871323108673, 55.233239606022835, 31.7482578009367, 38.31462845206261, 43.53270225226879, 7.377980500459671, 1.2497338210232556, 22.153202667832375, 59.25077922642231, 15.682223998010159, 28.89189787209034, 50.56686580181122, 56.49624243378639, 43.14158543944359, 26.883300952613354, 17.1772575750947, 27.62520544230938, 28.79727154970169, 36.951299607753754, 38.112011924386024, 55.75674891471863, 27.328205779194832, 0.9697236400097609, 0.10770477529149503, 0.1880384169635363, 0.06391343878931366, 0.04981792073522229, 0.11069121464970522, 0.012102828350180062, 0.029795264381391462, 0.04949993272020947, 0.040706625659368, 0.10326963398256339, 0.05743358415202238, 0.02364809042774141, 0.029736297037743498, 0.06814927633968182, 0.029176474636187777, 0.05500779654539656, 0.0594501737941755, 0.05477094011439476, 0.005839709592692088, 0.026991617851308547, 0.09477651823544875, 0.04959336540196091, 0.4328803124371916, 0.343125625513494, 21.82815480977297, 79.56100478768349, 60.92399284243584, 36.24171048402786, 48.97105023264885, 50.51448941230774, 39.436989426612854, 39.79969136416912, 29.3853659927845, 30.317091196775436, 30.509647764265537, 48.702343851327896, 64.55671951174736, 20.200369656085968, 2.617218573577702, 5.897674458101392, 45.92427872121334, 67.14906960725784, 65.73896527290344, 66.69408202171326, 68.26092034578323, 53.412316516041756, 48.79183664917946, 28.514086045324802, 3.4761812444776297, 1.2115753185935318, 36.06185853481293, 53.98576274514198, 48.77039059996605, 49.31990571320057, 47.22026377916336, 47.14315451681614, 48.843772262334824, 50.02557724714279, 40.71557141840458, 37.08395428955555, 36.322353556752205, 29.81244407594204, 28.524335995316505, 25.087409019470215, 26.703574396669865, 30.7372859492898, 39.27972726523876, 35.42312040925026, 34.36510518193245, 28.389817513525486, 20.959295332431793, 21.193243078887463, 23.908602073788643, 22.903592102229595, 19.13324061781168, 20.850254483520985, 18.080039732158184, 15.892874244600534, 22.624358385801315, 25.87633788585663, 27.237637639045715, 38.37759107351303, 34.752262607216835, 19.933840557932854, 6.216648817062378, 1.4928276767022908, 2.1631419891491532, 3.4360273741185665, 5.504541853442788, 3.1028272910043597, 5.794374151155353, 12.758654225617647, 25.149932764470577, 38.98515947163105, 49.29292716085911, 44.319248646497726, 40.339418202638626, 35.483331978321075, 46.17578722536564, 47.626036405563354, 36.700938642024994, 35.66890262067318, 34.48656566441059, 30.822623670101166, 23.521425649523735, 14.48018604889512, 14.414182640612125, 9.170297775417566, 8.222488984465599, 4.931123172864318, 7.812943160533905, 12.871529068797827, 24.823817163705826, 33.47111575305462, 28.930560797452927, 25.237820148468018, 24.199706353247166, 20.73556713759899, 16.248414516448975, 17.787689119577408, 19.037109576165676, 14.20023512095213, 22.838011421263218, 26.374143473803997, 28.658493496477604, 11.05309484526515, 8.403920698910952, 15.557223055511713, 28.216881193220615, 34.125459641218185, 35.6663453578949, 47.50207185745239, 51.156373769044876, 50.65844468772411, 49.16765548288822, 50.19754841923714, 51.807734817266464, 53.89488682150841, 53.68596263229847, 53.15167710185051, 54.909261390566826, 56.53047859668732, 62.64106370508671, 55.337635204195976, 47.941088899970055, 49.969610050320625, 38.21839101612568, 5.870314026251435, 0.6061953655444086, 13.694604802876711, 55.717584416270256, 48.99916872382164, 53.888119384646416, 57.93955318629742, 61.48182570934296, 38.105168491601944, 43.43744516372681, 41.83599449694157, 4.862055703997612, 3.7758191535249352, 36.82402923703194, 67.29461699724197, 24.719896540045738, 22.36782655119896, 49.36383895576, 59.94873717427254, 51.60116270184517, 30.98318785429001, 25.597676038742065, 25.223504416644573, 30.30597109347582, 33.556839153170586, 44.62127164006233, 69.19152840971947, 34.333734065294266, 0.956285601714626, 0.09322963756858371, 0.029379125480772927, 0.11057005904149264, 0.04003550893685315, 0.08599450666224584, 0.06196112655743491, 0.026039911790576298, 0.03919711583876051, 0.07480476022465155, 0.3528638498391956, 0.18587398779345676, 0.14391611970495433, 0.14341037574922666, 0.2244209303171374, 0.23349249822786078, 0.10548230275162496, 0.2709320228314027, 0.22683342976961285, 0.18390373414149508, 0.12406444118823856, 0.29277129156980664, 0.26237247744575143, 0.7585996063426137, 0.6335949234198779, 36.486842930316925, 92.88527861237526, 74.89597991108894, 49.60878521203995, 49.28167596459389, 60.657885521650314, 66.90709859132767, 59.790308475494385, 39.254648610949516, 34.909376576542854, 30.59594303369522, 46.72135815024376, 58.55398781597614, 14.759396016597748, 2.586181601509452, 14.36705281957984, 56.70054227113724, 78.04129913449287, 73.44541534781456, 71.02266535162926, 74.5904915034771, 61.78658075630665, 58.35158407688141, 33.170844465494156, 2.0860681124031544, 2.447281717322767, 47.53819651901722, 68.54468911886215, 58.1070140004158, 52.894693091511726, 50.302635580301285, 52.49854914844036, 54.51003961265087, 54.8312895745039, 45.8148217946291, 41.64987288415432, 42.865271866321564, 34.22619603574276, 33.46486508846283, 30.040505938231945, 32.35005050897598, 36.628145948052406, 44.622723162174225, 41.21958777308464, 38.9491868019104, 35.635677203536034, 28.71139995753765, 28.550976365804672, 27.648095414042473, 25.51785372197628, 19.40781008452177, 24.570368863642216, 23.47906932234764, 18.98491557687521, 25.297089368104935, 31.836812049150467, 33.4861895442009, 42.12136298418045, 45.6302011013031, 28.770494386553764, 10.182689800858498, 2.231599590741098, 5.0853226985782385, 9.806409291923046, 22.439477406442165, 30.181330181658268, 34.67987269163132, 35.866530016064644, 49.99081291258335, 51.76132410764694, 56.97198070585728, 46.5654107183218, 46.464013159275055, 42.44684211909771, 45.15768505632877, 51.66543625295162, 48.70053514838219, 41.02378807961941, 43.04103143513203, 36.06639929115772, 40.06865993142128, 45.17455615103245, 46.605650559067726, 40.006400272250175, 44.196218848228455, 38.95723097026348, 33.97284083068371, 31.567070223391056, 36.76000267267227, 43.70422504842281, 34.121249467134476, 29.462249167263508, 28.83945308625698, 26.535801999270916, 22.564306408166885, 23.235846273601055, 23.890971019864082, 19.35657173395157, 27.348357997834682, 30.786694698035717, 31.9255068898201, 14.149210508912802, 16.186475940048695, 25.031172037124634, 36.32314011454582, 38.21305230259895, 40.27683936059475, 50.733950436115265, 53.92570696771145, 53.13847281038761, 54.30006667971611, 53.70276913046837, 56.602036356925964, 55.8483961969614, 59.34318266808987, 56.490542739629745, 56.6721273958683, 55.96085876226425, 65.70383995771408, 57.78383754193783, 47.08718731999397, 48.35485629737377, 48.68467099964619, 15.057645812630653, 0.5218008253723383, 10.033692196011543, 55.55989667773247, 55.30503675341606, 58.28658476471901, 65.15616774559021, 64.39352586865425, 43.49842049181461, 47.55073584616184, 55.23856312036514, 12.695552911609411, 4.470037389546633, 30.735429748892784, 72.3391655087471, 20.18592283129692, 37.302051186561584, 57.54320785403252, 65.80343261361122, 50.569255873560905, 39.51621517539024, 27.60316852480173, 35.125539377331734, 42.69049644470215, 43.702511340379715, 54.65177580714226, 74.3635980784893, 52.615586668252945, 1.4428243786096573, 0.20083059382159263, 0.2237182203680277, 0.21539018052862957, 0.22076753026340157, 0.2220918334205635, 0.10412130039185286, 0.1740856101969257, 0.17857726605143398, 0.2334518582210876], [0.09526257301331498, 0.03655214975879062, 0.005083502855995903, 0.03768548718653619, 0.056192561096395366, 0.08401233411859721, 0.0372180157864932, 0.05833216171595268, 0.008549340855097398, 0.07116752414731309, 0.2073222931358032, 0.011005117721651914, 0.11470668629044667, 0.2825816336553544, 0.21038684353698045, 7.188101364299655, 54.9621469527483, 51.37926980853081, 34.67366002500057, 33.77632297575474, 27.78803050518036, 42.65444777905941, 48.06455187499523, 34.33992013335228, 22.044188417494297, 21.83205720037222, 18.72868202626705, 58.11527855694294, 62.52078115940094, 9.274435937404633, 1.8203400587663054, 15.592087134718895, 62.74214208126068, 53.03265608847141, 47.577999383211136, 52.934488356113434, 63.75800237059593, 45.57815529406071, 34.0915160626173, 12.871639262884855, 0.7154804700985551, 0.03377679946424905, 7.320629702880979, 11.138577908277512, 25.41748970746994, 32.90344901382923, 33.51292110979557, 35.68787880241871, 34.31057810783386, 33.64291973412037, 29.382326155900955, 30.7537941634655, 23.70195396244526, 22.154701687395573, 24.040088318288326, 26.72861125320196, 35.135650634765625, 35.26154927909374, 31.488857120275497, 26.64603978395462, 19.38920058310032, 16.261236928403378, 18.459597565233707, 21.283843517303467, 19.01701245456934, 15.400390271097422, 13.519667889922857, 9.995974469929934, 16.071484610438347, 21.52696967124939, 30.213195271790028, 38.90602871775627, 38.329694643616676, 24.656660333275795, 13.766984269022942, 4.145479705184698, 0.7943083089776337, 3.9537519682198763, 5.221308376640081, 13.175293318927288, 25.210720002651215, 30.777977965772152, 36.169320568442345, 44.61352005600929, 41.97917461395264, 48.15068565309048, 46.85737945139408, 49.15984310209751, 43.36486145853996, 43.52060370147228, 46.8880970031023, 33.22023041546345, 18.97476252168417, 18.13860408961773, 17.208035923540592, 30.024721585214138, 37.94766694307327, 43.0621886998415, 39.943304657936096, 43.58792468905449, 31.83362402021885, 34.1976747661829, 32.12654270231724, 30.736696980893612, 33.21610763669014, 28.002905175089836, 21.195654049515724, 19.46270953863859, 20.081437937915325, 16.994747668504715, 18.856110088527203, 19.644410088658333, 18.061768412590027, 18.61157041043043, 27.762184292078018, 34.97224040329456, 25.605085641145706, 13.840126544237137, 13.89171827584505, 9.65938188135624, 25.59668429195881, 31.30125168710947, 39.34961311519146, 47.642424926161766, 52.83974044024944, 51.70038677752018, 51.30394645035267, 52.759762331843376, 51.61183252930641, 54.505909234285355, 56.840830743312836, 58.73210705816746, 53.22572372853756, 50.44463396072388, 47.60180130600929, 49.845508709549904, 36.76518179476261, 7.948201652616262, 0.17732057254761457, 4.536640690639615, 32.87514813244343, 50.883286222815514, 49.67783510684967, 53.97839494049549, 51.083999052643776, 49.76334571838379, 22.685909382998943, 36.150747165083885, 7.745489180088043, 0.5702235864009708, 13.05199658498168, 54.720031544566154, 34.312664195895195, 11.431007366627455, 29.75845467299223, 45.92153526842594, 49.36942845582962, 23.932719379663467, 25.320266224443913, 18.61294973641634, 36.74332156777382, 28.09528011828661, 31.578790694475174, 42.06897519528866, 53.92075203359127, 9.885661639273167, 0.535317650064826, 0.09796825048397295, 0.20250529458280653, 0.1402829505968839, 0.02737345468631247, 0.08579699890105985, 0.005732899699069094, 0.07527991285314783, 0.04201777795969974, 0.05563557555433363, 0.14385610964382067, 0.11017925891792402, 0.03198299884388689, 0.06391521994373761, 0.0370487949840026, 0.017097681666200515, 0.06197171700478066, 0.023718201118754223, 0.007261797200044384, 0.10871892751310952, 0.13118971197400242, 0.04617142636561766, 0.15740695438580588, 0.2570377418305725, 0.2204936629277654, 9.30039519444108, 68.29571887850761, 60.33768430352211, 33.86049225926399, 39.90985505282879, 40.96841745078564, 39.55523908138275, 38.990695774555206, 38.04472513496876, 30.829292312264442, 28.406889997422695, 23.640121780335903, 64.73685264587402, 68.42866614460945, 18.559456206858158, 2.8578869719058275, 15.52693298086524, 69.69722807407379, 61.077238619327545, 53.04984636604786, 59.382179975509644, 66.78797498345375, 51.5062589943409, 39.01900805532932, 17.175239883363247, 1.8727619270794094, 1.3830643915571272, 7.174374125897884, 11.930567510426044, 28.47296465188265, 40.133921429514885, 41.92620165646076, 43.4870021045208, 41.21523700654507, 38.980516120791435, 35.206319242715836, 34.723399356007576, 25.11206589639187, 24.08344779163599, 26.96436770260334, 31.80146634578705, 37.1395643055439, 37.93897680938244, 34.416740611195564, 29.73779708147049, 22.261405661702156, 20.091476999223232, 20.449691377580166, 23.290291652083397, 20.708121210336685, 17.875812090933323, 15.679976418614388, 14.488697592169046, 17.88679350167513, 23.709650449454784, 34.26814578473568, 37.37777352333069, 41.155895590782166, 36.95624694228172, 20.514859780669212, 6.517847254872322, 2.619331735186279, 6.322043286636472, 5.16637472435832, 1.973690923769027, 13.677705209702253, 18.8245090842247, 26.10620465129614, 40.32533995807171, 47.70557373762131, 54.78221520781517, 50.40681079030037, 48.77689205110073, 43.46079871058464, 48.13982203602791, 52.95776970684528, 38.61044637858868, 30.22377010434866, 29.000163562595844, 24.86944891512394, 26.01588349789381, 27.786227501928806, 28.824706077575684, 29.915198162198067, 31.063810028135777, 23.59618853777647, 21.37658704072237, 27.700686492025852, 31.786626242101192, 36.56294904649258, 31.623485796153545, 23.466074019670486, 23.360709473490715, 21.361762136220932, 21.1890310049057, 23.210053257644176, 22.659035325050354, 18.422405160963535, 23.623824454843998, 31.925803273916245, 34.79983605444431, 31.491195894777775, 17.345858328044415, 19.18334472924471, 15.13586176559329, 31.07190929353237, 34.35916610062122, 39.64964501559734, 48.31714332103729, 55.25109104812145, 52.40088298916817, 55.50110623240471, 53.970327973365784, 55.67462012171745, 53.204779252409935, 57.70702086389065, 59.82579097151756, 56.036828085780144, 50.45358248054981, 50.373467579483986, 48.14563952386379, 31.887265741825104, 5.338848894461989, 0.3437707299599424, 7.366488492116332, 36.76837742328644, 54.285665452480316, 55.46828739345074, 56.355953961610794, 56.5605615824461, 52.43776760995388, 26.744625493884087, 32.60842904448509, 7.996844742447138, 1.2890138570219278, 27.74279773235321, 56.55111528933048, 46.760089471936226, 13.661505728960037, 22.709536515176296, 45.119706094264984, 61.781758815050125, 33.44466157257557, 25.504890717566013, 23.594168946146965, 30.324479900300503, 30.604249387979507, 29.660298340022564, 51.1373557895422, 62.277472615242004, 13.30109791830182, 0.5827976460568607, 0.13864415494026616, 0.311977420351468, 0.06937007958185859, 0.07581615165690891, 0.06319034204352647, 0.05810921313241124, 0.11602081460296176, 0.035896811095881276, 0.026007222040789202, 0.43605501239653677, 0.18129406089428812, 0.08864384770276956, 0.11945897698751651, 0.1430262697977014, 0.16898870322620496, 0.1410980662330985, 0.229752816085238, 0.1464062774903141, 0.20884093508357182, 0.20210698392475024, 0.16752898780396208, 0.4499380721244961, 0.46931931807193905, 0.2498227305477485, 17.045391350984573, 85.26512190699577, 72.26136848330498, 47.30434946715832, 42.93628245592117, 39.966586008667946, 59.567895010113716, 61.18141382932663, 53.36208701133728, 35.511047691106796, 30.116927437484264, 20.064023472368717, 66.4512674510479, 68.28488945960999, 16.403239108622074, 3.9114531129598618, 22.730270102620125, 74.23495218157768, 65.1048780977726, 59.53258350491524, 66.93118169903755, 72.31425404548645, 60.54754324257374, 44.6540030837059, 18.177206218242645, 1.2997199012897909, 0.5446987529285252, 9.82789808884263, 18.89161728322506, 41.71993352472782, 52.56209313869476, 52.54965640604496, 51.061891838908195, 47.69023776054382, 43.83531801402569, 38.9104288816452, 38.4494262188673, 31.752796657383442, 28.25024150311947, 34.79289762675762, 37.52441145479679, 44.31214302778244, 42.748272344470024, 41.15520782768726, 34.938995987176895, 28.82531214505434, 25.2994604408741, 27.736007496714592, 27.661039419472218, 25.666243359446526, 21.00257121026516, 20.280216671526432, 17.923003658652306, 22.715154513716698, 28.05194154381752, 37.763722613453865, 44.51373741030693, 46.460300758481026, 50.25984987616539, 33.728282153606415, 11.644900739192963, 8.745816852897406, 19.748148322105408, 26.94161832332611, 41.19943365454674, 46.42171002924442, 48.39641086757183, 47.99476861953735, 53.482616543769836, 50.11631637811661, 53.99098366498947, 54.94505926966667, 54.8445812612772, 51.53210140764713, 43.971369713544846, 54.594072103500366, 48.067504316568375, 40.92334806919098, 41.90227814018726, 42.52777777612209, 50.429712161421776, 50.21555185317993, 46.30151867866516, 46.360381320118904, 52.38631837069988, 47.188265696167946, 48.96595470607281, 48.33083018660545, 45.394875928759575, 43.86307552456856, 36.006598100066185, 28.533341512084007, 27.051257640123367, 27.801789566874504, 26.741217076778412, 30.364014878869057, 29.757003150880337, 25.54285828024149, 27.91276641190052, 33.33988219499588, 40.10348506271839, 32.47759446501732, 23.919718377292156, 25.694371350109577, 21.01593889296055, 39.97809939086437, 40.42608015239239, 44.10766460001469, 53.58941361308098, 59.03060384094715, 56.378182768821716, 57.249935790896416, 57.563658356666565, 59.39167946577072, 58.15714091062546, 61.21994376182556, 63.29411946237087, 57.38392040133476, 54.23252530395985, 46.32417306303978, 53.46632681787014, 42.93416976928711, 11.104462388902903, 0.22458608786109835, 5.8686064928770065, 37.56816990673542, 59.31588493287563, 57.26689048111439, 62.535079792141914, 58.85678216814995, 61.128904446959496, 30.08313775062561, 45.719317719340324, 14.042039159685373, 1.8068750062957406, 20.00767059624195, 66.48210659623146, 47.04182155430317, 12.52925768494606, 38.13526667654514, 50.76594091951847, 62.63862043619156, 30.368954613804817, 38.54406774044037, 25.69236695766449, 47.84194082021713, 40.57704985141754, 41.130391359329224, 56.27049274742603, 76.9544130563736, 26.54150929301977, 0.6953077088110149, 0.4080635472200811, 0.4991074337158352, 0.3080468578264117, 0.0860021062544547, 0.25844900985248387, 0.30060534307267517, 0.1950519351521507, 0.11287814573734067, 0.11154984240420163], [0.048089725969475694, 0.02347658752114512, 0.008879310844349675, 0.016246902123384643, 0.046258977527031675, 0.0091972524751327, 0.01711321296170354, 0.024252616094599944, 0.039999069485929795, 0.11487479016068392, 0.09067119477549568, 0.10625503433402628, 0.034314429794903845, 0.10908131080213934, 0.04405502899317071, 1.5742888930253685, 45.42580246925354, 60.825410932302475, 43.552890568971634, 33.36434528231621, 31.91441148519516, 33.02741356194019, 52.687224224209785, 34.94810789823532, 26.68540947139263, 22.99905437976122, 26.583434343338013, 20.169289223849773, 76.3620400428772, 41.23770520091057, 2.9378862166777253, 6.4977045357227325, 41.51957027614117, 67.75689259171486, 61.96792222559452, 54.73966509103775, 53.2951308041811, 47.99204036593437, 45.6534406542778, 29.385217800736427, 8.302906919270754, 0.1476955512771383, 15.092214457690716, 17.200500927865505, 3.179028402082622, 3.8871033070608974, 8.294365927577019, 16.560259982943535, 22.077322639524937, 23.268245235085487, 25.053279250860214, 20.730217024683952, 19.90078803151846, 13.6042988486588, 14.556674994528294, 18.271864838898182, 21.59617155790329, 23.1444725766778, 29.12895195186138, 22.873072139918804, 23.46384733915329, 25.552971437573433, 28.41693475842476, 23.46816960722208, 15.845807120203972, 14.282910134643316, 19.165673777461052, 18.99958658963442, 24.643032364547253, 28.221991918981075, 30.174940824508667, 31.482707150280476, 41.12057268619537, 34.35798816382885, 22.59239450097084, 12.346731629222631, 2.278328058309853, 6.359296962618828, 21.318434961140156, 30.26189535856247, 42.76113085448742, 47.81132586300373, 43.036673069000244, 42.11441695690155, 46.13205537199974, 44.80289809405804, 42.43567071855068, 55.965509712696075, 52.83962644636631, 48.61283965408802, 48.671147525310516, 37.61049583554268, 24.790065474808216, 25.001351237297058, 30.628891065716743, 43.32681030035019, 46.30348317325115, 48.21579895913601, 38.277341052889824, 20.29296688735485, 7.729376144707203, 15.52418952807784, 25.84410421550274, 31.582827977836132, 32.443479895591736, 26.89473833888769, 19.20455329120159, 24.884254820644855, 22.758783772587776, 23.91736440360546, 14.050498455762863, 15.540062226355076, 22.25275732576847, 16.84006556868553, 22.281675674021244, 30.769561417400837, 33.07027146220207, 18.073583878576756, 17.18236070126295, 12.00519360601902, 4.938547499477863, 24.523944854736328, 34.83013942837715, 36.04627937078476, 40.90571701526642, 45.17262205481529, 45.72121001780033, 52.13601440191269, 54.392846301198006, 51.934108436107635, 46.98189117014408, 51.32500112056732, 46.428082287311554, 56.466763615608215, 47.57355362176895, 24.599680490791798, 2.224724334664643, 0.1025911996839568, 3.3739211317151785, 30.412050001323223, 45.95333956182003, 54.69727076590061, 51.009523048996925, 53.36036950349808, 53.340979143977165, 42.82011888921261, 65.96537232398987, 48.241151198744774, 2.2985527105629444, 10.023921020328999, 42.34105959534645, 71.59950479865074, 12.657218668609858, 27.18811109662056, 40.32799981534481, 50.551632419228554, 38.84643651545048, 21.74942683428526, 27.680758461356163, 26.865806691348553, 43.14561702311039, 22.835796140134335, 40.951591953635216, 46.656457632780075, 51.06056571006775, 2.053565843962133, 0.06283805938437581, 0.18875292706070468, 0.09680321963969618, 0.036068844638066366, 0.07764951616991311, 0.0677236620686017, 0.05922636431932915, 0.03908949700416997, 0.00939593282964779, 0.07683690899284557, 0.004282993613742292, 0.031639729568269104, 0.04675744101405144, 0.0466863840847509, 0.03419359331019223, 0.0016984412536658056, 0.04051198258821387, 0.04153823923843447, 0.050699276762316, 0.020908493097522296, 0.07677908084588125, 0.026600966157275252, 0.09964755998225883, 0.05296477160300128, 0.1068455983477179, 1.1934257112443447, 51.02790266275406, 73.03869277238846, 43.83096344769001, 32.79785268008709, 32.53452681005001, 35.084851160645485, 39.92060087621212, 35.53944356739521, 30.933112241327763, 30.072338730096817, 27.611556574702263, 28.32423683255911, 74.57864373922348, 46.53446137905121, 4.818565612658858, 5.202197777107358, 44.451983124017715, 69.3997648358345, 66.76138401031494, 63.332770988345146, 60.86083643138409, 54.63925927877426, 50.46005353331566, 33.58941100537777, 8.003334794193506, 1.2853001500479877, 23.23697481304407, 26.66859157383442, 5.320347687229514, 5.813847156241536, 9.801655746996403, 20.187999419867992, 23.559866286814213, 25.934541262686253, 26.769122779369354, 28.045383095741272, 22.771636582911015, 20.338648036122322, 16.96468748152256, 21.960321217775345, 23.002481795847416, 25.653964318335056, 30.451060608029366, 27.43084967136383, 25.651321560144424, 30.837268084287643, 31.15975297987461, 28.1890419870615, 22.115423195064068, 20.193877704441547, 21.500897370278835, 23.444422781467438, 27.180868685245514, 26.228894367814064, 33.61771568655968, 35.948354825377464, 45.65042741596699, 37.99688570201397, 23.201199732720852, 9.988929647952318, 5.73325633071363, 5.267062671482563, 6.958381365984678, 22.628437466919422, 36.23413749039173, 42.17368617653847, 43.506320267915726, 50.58379389345646, 53.13847281038761, 52.164858654141426, 50.67444562911987, 56.4044925570488, 52.829838171601295, 49.46882352232933, 54.381868690252304, 41.81024327874184, 30.143204927444458, 30.229426100850105, 28.10759335756302, 40.49498565495014, 47.12612763047218, 48.15986596047878, 47.38427817821503, 47.73659907281399, 30.603894107043743, 35.58314882218838, 39.54635515809059, 38.97193618118763, 35.30647426843643, 30.62931664288044, 22.32438538223505, 25.306495763361454, 25.37540316581726, 28.05465269833803, 20.452355034649372, 18.537738472223282, 23.808498345315456, 20.31612854450941, 23.328466303646564, 36.98083162307739, 36.91833637654781, 22.79470134526491, 21.7991965636611, 16.54199056327343, 8.856141082942486, 29.63077012449503, 38.164042532444, 38.77482935786247, 41.02211616933346, 47.822656854987144, 46.740315333008766, 55.25006130337715, 56.3392348587513, 54.75952282547951, 50.181064903736115, 51.90380126237869, 49.342704489827156, 57.35640987753868, 40.39366789162159, 18.20598017424345, 3.9439366199076176, 0.11883582526934333, 4.925821982324123, 33.571380972862244, 49.66220274567604, 56.651053726673126, 56.68270222842693, 57.89690047502518, 57.937459498643875, 47.713435515761375, 65.13563364744186, 44.013619646430016, 3.9732157113030553, 13.800766356289387, 54.795047119259834, 68.07296723127365, 16.048701032996178, 18.572067730128765, 36.222719103097916, 51.41187205910683, 54.052874743938446, 25.035102926194668, 30.956689976155758, 26.4230677485466, 37.77694210410118, 22.702409997582436, 40.19178092479706, 58.85435409843922, 59.70616199076176, 2.999583980999887, 0.11452286373241805, 0.12113384102121927, 0.1188073045341298, 0.03905497600499075, 0.12862035218859091, 0.1054869857034646, 0.021508387762878556, 0.05278106407786254, 0.005874413345736684, 0.07996816362719983, 0.1597000125912018, 0.11986982994130813, 0.10154421484912746, 0.06771143889636733, 0.13011543836910278, 0.08308075324748643, 0.10563802017713897, 0.18378853797912598, 0.16056566848419607, 0.20620524213882163, 0.16964229784207419, 0.25300031004007906, 0.15135511115659028, 0.2016885016928427, 0.17933548864675686, 1.8736357614398003, 66.10651955008507, 83.89661774039268, 59.25443463027477, 47.94304959475994, 39.464309960603714, 49.45938102900982, 67.28191047906876, 49.36439752578735, 40.39323091506958, 35.61414375901222, 30.77839784324169, 28.12598057091236, 80.27272179722786, 50.408950075507164, 6.973290340974927, 8.459053840488195, 52.87370681762695, 75.46335026621819, 73.16906377673149, 68.08931395411491, 66.12165793776512, 60.235815569758415, 59.30253624916077, 38.35718996822834, 12.627136632800102, 0.4564075218513608, 23.903559744358063, 28.34751818329096, 6.768320789560676, 10.524141378700733, 18.520164415240288, 33.07126700878143, 34.71494100987911, 38.688752576708794, 37.74193458259106, 37.158624082803726, 28.04829753935337, 30.364054776728153, 24.992860592901707, 26.15473374724388, 27.95599479228258, 29.94273718446493, 36.333004385232925, 31.06805630028248, 30.358385480940342, 36.76266632974148, 39.059270694851875, 34.253839552402496, 24.057210199534893, 22.290244214236736, 27.53767143934965, 27.46972158551216, 33.29524219036102, 31.547947749495506, 37.54527613520622, 41.529335752129555, 43.60042221844196, 47.29203052818775, 41.84304691851139, 26.819323785603046, 27.176546417176723, 38.25726293027401, 44.20315347611904, 48.51099751889706, 54.46606457233429, 55.62000945210457, 48.65857020020485, 48.478342071175575, 52.87874914705753, 50.72782136499882, 51.24941557645798, 58.902930691838264, 57.89643310010433, 46.59081995487213, 53.08669678866863, 52.33929209411144, 44.242903143167496, 45.44697493314743, 47.79198870062828, 53.55278737843037, 54.80327747762203, 49.6586499363184, 49.80737775564194, 45.048129335045815, 25.50147470086813, 31.52573984116316, 40.40344476699829, 43.084721490740776, 40.130406618118286, 33.793805837631226, 26.850485913455486, 29.16868072003126, 31.1356907710433, 31.675444208085537, 24.481554329395294, 23.777351416647434, 30.06159670650959, 26.261654309928417, 29.828578010201454, 43.5793599486351, 40.89629352092743, 26.691563241183758, 27.716202959418297, 20.637538097798824, 14.123340547084808, 36.98630712926388, 43.42857263982296, 41.79944805800915, 46.80823668837547, 50.656525790691376, 51.05919398367405, 58.11058580875397, 60.0762203335762, 59.60589297115803, 53.0005744099617, 53.945967480540276, 45.394583344459534, 55.950751304626465, 52.43888095021248, 32.7762508392334, 4.671146348118782, 0.22193426062585786, 4.417551755905151, 34.33414064347744, 51.308924183249474, 60.78578285872936, 61.21057726442814, 62.18593932688236, 63.65740656852722, 55.143097043037415, 76.52165427803993, 54.95203569531441, 4.830955797806382, 13.578100204467773, 53.896539732813835, 83.38336408138275, 17.467075623571873, 33.76732125878334, 50.837358087301254, 57.87557601928711, 52.43146754801273, 27.651524730026722, 43.701200410723686, 32.55224905908108, 59.38311852514744, 32.30662263929844, 54.88991282880306, 64.48242589831352, 77.07168236374855, 7.682152753695846, 0.3219274536240846, 0.3653363243211061, 0.27642278757411987, 0.10037948086392134, 0.21081607206724584, 0.15002773550804704, 0.16290313680656254, 0.19172519881976768, 0.14577555586583912, 0.22175225632963702], [0.04051550778967794, 0.02219618982053362, 0.10320028028218076, 0.0744282390223816, 0.14091690798522905, 0.032710934392525814, 0.047446154057979584, 0.07998687317012809, 0.13857385871233419, 0.1550457373377867, 0.08978953817859292, 0.046256843852461316, 0.08449438129900955, 0.022098007393651642, 0.48252200649585575, 0.14521496719680727, 17.800851613283157, 66.71942666172981, 58.87057162821293, 46.699915900826454, 49.27309222519398, 28.720297180116177, 46.709563583135605, 43.46312038600445, 38.33439499139786, 21.793867349624634, 40.9481455385685, 24.831036776304245, 42.45162606239319, 70.78098312020302, 17.637612372636795, 2.759439004585147, 22.19649374485016, 55.426223650574684, 65.73339477181435, 55.91315232217312, 58.70665222406387, 57.90578059852123, 48.696142584085464, 43.73067542910576, 15.763888265937567, 7.598191509023309, 6.996278632432222, 36.55177764594555, 29.990873001515865, 5.237867413088679, 6.515328465029597, 3.4186409320682287, 1.5415065083652735, 2.244559032842517, 4.161473521962762, 7.4910301342606544, 8.25429042801261, 5.90497481636703, 7.155074011534452, 11.840632986277342, 13.066121377050877, 15.483797695487738, 19.691421166062355, 21.842369846999645, 28.334087803959846, 35.06227657198906, 26.01690374314785, 14.099499676376581, 8.483636621385813, 17.480471804738045, 27.02317524701357, 22.907338701188564, 29.80631310492754, 30.509860552847385, 29.31117307394743, 24.78072937577963, 31.94979138672352, 33.803195133805275, 30.16280997544527, 27.562628500163555, 13.267510570585728, 2.7317658020183444, 11.123969592154026, 20.735878720879555, 37.960438057780266, 43.586944341659546, 50.688132494688034, 48.88874664902687, 49.633255898952484, 46.147452145814896, 48.31762209534645, 54.2276805639267, 51.721411049366, 49.7865966707468, 50.91844953596592, 41.621184423565865, 35.014619529247284, 31.830909065902233, 41.93792402744293, 49.83381673693657, 50.220647379755974, 44.76794756948948, 19.70313023775816, 7.421876695007086, 6.148005975410342, 8.902510944753885, 22.755002975463867, 29.975918903946877, 34.025403410196304, 24.46800235658884, 18.375867158174515, 22.115850672125816, 17.7872521430254, 28.518358916044235, 17.50951174646616, 9.96757099404931, 17.461957298219204, 25.748436748981476, 17.751619555056095, 24.257303662598133, 35.6507433950901, 26.14688716828823, 17.423706650733948, 16.580575592815876, 3.1538117676973343, 3.1161166029050946, 14.88521771505475, 30.589456781744957, 43.8282123953104, 41.90879099071026, 47.3026205599308, 44.057302102446556, 46.19972974061966, 46.36591002345085, 44.509375244379044, 46.09629549086094, 38.40355888009071, 21.01990208029747, 3.8754647690802813, 5.010802997276187, 2.5854779267683625, 3.172018015757203, 17.384544052183628, 47.25488752126694, 59.10246178507805, 54.5996730029583, 45.77661484479904, 45.97273372113705, 44.46787767112255, 53.954859003424644, 54.84906882047653, 30.329470932483673, 5.050351275131106, 16.010076105594635, 77.03515872359276, 61.93869799375534, 28.16676188260317, 30.32928854227066, 40.900731682777405, 43.046115562319756, 30.275819711387157, 24.39414381980896, 16.280581690371037, 37.64804542064667, 26.421851813793182, 28.42889841645956, 45.532018169760704, 51.29953868687153, 31.16692889481783, 1.1050339043140411, 0.17341628205031157, 0.23461576842237264, 0.12173381546745077, 0.11166996642714366, 0.032531512770219706, 0.12500117998570204, 0.04380741513159592, 0.1054978062165901, 0.08349172494490631, 0.05377433968533296, 0.058434600359760225, 0.05986296004266478, 0.055295775819104165, 0.07186276066931896, 0.13338869553990662, 0.04856635918258689, 0.05956814929959364, 0.139587587909773, 0.13122532021952793, 0.044081612722948194, 0.028409947408363223, 0.08663522501592524, 0.06582386049558409, 0.118369444826385, 0.46687809750437737, 0.1821415638551116, 18.72312482446432, 78.24702769517899, 60.35202093422413, 47.255066111683846, 47.07851238548756, 35.108793675899506, 37.63828754425049, 37.67570413649082, 42.624797970056534, 26.108999401330948, 39.82198856770992, 26.577825844287872, 44.42524015903473, 66.90933287143707, 20.665191113948822, 3.3469791524112225, 25.50726369023323, 59.19561378657818, 70.08293777704239, 61.01529814302921, 62.21890635788441, 62.54056289792061, 51.23184911906719, 49.34476397931576, 17.44318250566721, 3.9494817098602653, 10.523454565554857, 42.02650487422943, 35.01459293067455, 8.630734328180552, 15.145682338625193, 5.044660605490208, 2.5382528733462095, 3.7466122582554817, 7.514994498342276, 10.461202505975962, 10.31317574903369, 9.565506968647242, 7.9979058355093, 15.710693970322609, 15.575268287211657, 18.37498750537634, 21.249508559703827, 22.81875215470791, 35.03931440412998, 39.397045969963074, 30.960142090916634, 17.90560819208622, 10.295904725790024, 21.797520853579044, 30.737160556018353, 24.620319083333015, 31.740244030952454, 30.093912072479725, 32.44915299117565, 29.238950349390507, 37.22744219005108, 41.13878130912781, 34.244579449296, 22.20669999718666, 6.620219461619854, 10.947215426713228, 25.95839638262987, 40.7534933835268, 56.131473407149315, 58.52633289992809, 55.970464646816254, 54.24208179116249, 53.40596705675125, 49.75438579916954, 49.63696449995041, 55.506513342261314, 55.02005584537983, 52.73415170609951, 55.5464605987072, 46.851379573345184, 38.50632816553116, 36.42189681529999, 43.58215659856796, 53.59056495130062, 56.15394540131092, 54.277826473116875, 42.893561348319054, 21.99125725775957, 11.806619111448526, 16.521570459008217, 31.52006294578314, 38.080788999795914, 36.765117198228836, 27.098614498972893, 22.688945420086384, 26.391096264123917, 21.14076789468527, 33.371880277991295, 23.510828018188477, 15.183374416083097, 23.1529613211751, 32.14921988546848, 22.277391403913498, 28.03398370742798, 39.352645352482796, 32.12452121078968, 22.237250357866287, 20.565782748162746, 5.055174641311169, 5.962976329028606, 17.385055124759674, 35.93151032924652, 47.94257462024689, 47.939158603549004, 51.89289964735508, 49.50315847992897, 51.43434405326843, 48.81228715181351, 45.6903974711895, 47.324936762452126, 34.936389327049255, 15.286897011101246, 4.515735637396574, 8.82688645273447, 8.430946748703718, 6.433265218511224, 20.76022781431675, 50.96655875444412, 59.71656583249569, 58.27253691852093, 49.66172397136688, 51.77902355790138, 53.332061022520065, 62.34244912862778, 56.64727672934532, 36.34716622531414, 6.5459562465548515, 26.270296946167946, 82.60015770792961, 64.69478130340576, 32.1592665463686, 18.161651752889156, 40.26231274008751, 47.00323462486267, 42.818169593811035, 25.19296545535326, 23.502510264515877, 36.40285603702068, 30.471699200570583, 26.982878409326077, 48.06467346847057, 62.39174768328667, 33.76420542597771, 1.1464054905809462, 0.20754447730723768, 0.16836504684761167, 0.12475484632886946, 0.1291601310367696, 0.09059313568286598, 0.016594978660577908, 0.03426049050176516, 0.04899783270957414, 0.044919297070009634, 0.04031889060570393, 0.2242883827420883, 0.17769229947589338, 0.21012197103118524, 0.18760519567877054, 0.21520060632610694, 0.17851222422905266, 0.23479711962863803, 0.2480927694705315, 0.25555911648552865, 0.21069827838800848, 0.17587488371646032, 0.1904727949295193, 0.19806388212600723, 0.3079021390294656, 0.6807248038239777, 0.19132233137497678, 27.924521081149578, 95.3501607477665, 71.16233825683594, 67.89097979664803, 58.4954671561718, 41.13461293280125, 64.89085838198662, 57.20136299729347, 56.896885335445404, 31.52806531637907, 51.16163268685341, 27.80379395931959, 55.864655524492264, 80.7656617462635, 25.218462087213993, 5.0215597450733185, 31.71154797077179, 63.75734880566597, 76.19682490825653, 66.82851120829582, 69.15319606661797, 68.30065101385117, 58.64508792757988, 54.07743662595749, 20.92938143759966, 13.661740366369486, 10.337798427790403, 48.966209292411804, 40.33997677266598, 8.448632899671793, 20.061549805104733, 5.617557289078832, 4.123319294303656, 5.0777615793049335, 10.233703963458538, 12.298593912273645, 14.2016457952559, 15.989760495722294, 12.495753932744265, 19.990263730287552, 20.45796163380146, 21.268680430948734, 26.61771420389414, 25.502686835825443, 40.733259469270706, 46.094087809324265, 39.390350729227066, 22.713400907814503, 15.301154796034098, 25.51300708204508, 38.012248277664185, 32.023233845829964, 35.51347576081753, 37.02073708176613, 35.751802772283554, 35.83440653979778, 37.17387266457081, 41.99890695512295, 44.66829791665077, 43.54705028235912, 33.81348878145218, 26.251886934041977, 34.80851858854294, 47.22723260521889, 58.4881791472435, 57.78174385428429, 60.089823603630066, 56.91122196614742, 54.832007735967636, 48.94127123057842, 53.258185386657715, 55.0309232622385, 55.69535940885544, 46.14228442311287, 52.39532768726349, 52.07414232194424, 49.50880877673626, 48.534286469221115, 54.20836240053177, 57.4343740940094, 57.14569978415966, 52.718815729022026, 43.568044155836105, 20.703610852360725, 13.874248713254929, 19.348901845514774, 39.26332734525204, 42.246076092123985, 42.70521305501461, 31.63477499037981, 25.856537148356438, 30.20011067390442, 26.005316264927387, 39.67392571270466, 28.105051293969154, 19.077258221805096, 28.566420637071133, 38.19607101380825, 27.629147730767727, 32.22962737083435, 44.4249551743269, 38.07341739535332, 27.166632749140263, 25.12948416173458, 7.06907750107348, 9.022246319800615, 23.703948855400085, 41.32801875472069, 53.909504637122154, 53.9361298084259, 57.25606106221676, 51.69061750173569, 53.24718117713928, 52.78935134410858, 48.09800527989864, 51.81244656443596, 44.48038659989834, 26.95199366658926, 7.0332330744713545, 7.889370359480381, 4.412206867709756, 6.801701998338103, 23.442473486065865, 52.66260914504528, 66.77467569708824, 61.508929654955864, 55.040160566568375, 57.949121072888374, 58.330202624201775, 67.8425095975399, 63.97411957383156, 40.07204554975033, 9.69689441844821, 23.394822143018246, 87.83296331763268, 75.7721596956253, 33.48090782761574, 39.455958008766174, 46.9805346429348, 51.02678172290325, 41.963884234428406, 35.607972890138626, 28.57910055667162, 45.90511254966259, 42.30678543448448, 38.096816539764404, 60.249346643686295, 67.07680508494377, 54.01735045015812, 1.5435348870232701, 0.36517290340270847, 0.40978515171445906, 0.24319319956703112, 0.18884029268519953, 0.19579059473471716, 0.2831115567823872, 0.12609154335223138, 0.14622841437812895, 0.22824131359811872, 0.1771375589305535], [0.07633812638232484, 0.09542114770738408, 0.0880499959748704, 0.0741136352007743, 0.016192315306398086, 0.04870099961408414, 0.07781744192470796, 0.12562258023535833, 0.10193044334300794, 0.06570014447788708, 0.19219300418626517, 0.043981259514112025, 0.20197733072564006, 0.1119812231627293, 0.20099245622986928, 0.1455008573248051, 2.190877413377166, 56.42332434654236, 63.00862178206444, 33.66154633462429, 37.427987828850746, 28.0838655307889, 33.766287714242935, 50.516123324632645, 38.37029546499252, 30.252135582268238, 28.03720973432064, 40.36424607038498, 47.51735083758831, 77.05516844987869, 43.71525585651398, 6.61440197378397, 12.929907236248255, 53.7471317499876, 61.787469908595085, 65.5892913043499, 54.87717591226101, 59.00267533957958, 46.69822499155998, 35.70872828364372, 20.46386081725359, 21.214461140334606, 9.746130276471376, 3.2716474821791053, 9.204681180417538, 28.07250414043665, 20.982835069298744, 15.128765646368265, 22.663406990468502, 12.746799811720848, 21.360445506870747, 25.93858804553747, 16.573853753507137, 11.116516292095184, 18.316322453320026, 19.270145371556282, 11.112359315156937, 10.385761354118586, 15.206758361309767, 24.689420275390148, 35.27903974056244, 27.746120654046535, 11.25010097399354, 15.592272374778986, 16.105449087917805, 26.05958115309477, 33.45481462776661, 17.47587975114584, 27.798565439879894, 33.85978549718857, 24.283178374171257, 22.899526320397854, 23.25555771589279, 34.27877001464367, 42.783861234784126, 35.309221521019936, 20.69606825709343, 5.319386338815093, 12.226898409426212, 16.64167631417513, 34.32513892650604, 39.79516960680485, 48.90715666115284, 53.228292390704155, 53.66010881960392, 46.6377854347229, 45.08430339396, 50.64997114241123, 46.10730729997158, 48.57768774032593, 50.87825149297714, 46.344004198908806, 43.447811007499695, 41.78606517612934, 46.70409567654133, 51.771017387509346, 54.516670256853104, 33.776372373104095, 16.978619433939457, 8.871485609561205, 4.8551415000110865, 8.299848083406687, 21.27954214811325, 30.82526072859764, 35.30674025416374, 27.260292023420334, 19.3097772449255, 19.601278603076935, 20.046419017016888, 29.298160672187805, 21.86589438468218, 14.057237394154072, 16.769334264099598, 30.622013434767723, 21.851588152348995, 14.351731091737747, 21.983013600111008, 27.560890093445778, 26.131009720265865, 19.529836736619473, 7.101742923259735, 4.048604853451252, 1.9361790991388261, 2.887609452009201, 11.126634199172258, 17.873389720916748, 19.832351803779602, 26.381440982222557, 37.79866933822632, 33.66063818335533, 24.72128726541996, 13.61087154597044, 6.771799977868795, 2.9915979970246553, 27.718750722706318, 20.674069337546825, 2.9699322720989585, 10.723582226783037, 38.811189606785774, 55.645878463983536, 52.174992710351944, 52.46225729584694, 54.14555937051773, 51.91751092672348, 56.62276804447174, 54.000840336084366, 55.92037573456764, 35.94635993242264, 4.262192817404866, 10.92744318768382, 34.44358617067337, 34.42571572959423, 13.189327865839005, 25.369532480835915, 43.506362065672874, 40.17592057585716, 27.491118237376213, 22.3774666339159, 21.347579397261143, 28.615534901618958, 22.434007599949837, 29.869099035859108, 45.4324597120285, 61.35831333696842, 7.85783015191555, 0.339420082163997, 0.3273037198232487, 0.3520811512134969, 0.1289652578998357, 0.12859712296631187, 0.09923902252921835, 0.08130874208291061, 0.11964552322751842, 0.013518296927941265, 0.12812795204808936, 0.01955630003067199, 0.13716244226088747, 0.14162902836687863, 0.08661301995743997, 0.0605947918666061, 0.05349870974896476, 0.018424240952299442, 0.01338657777523622, 0.0792937888763845, 0.06988658467889763, 0.18052972300210968, 0.09829989401623607, 0.06559602858033031, 0.1871083871810697, 0.12583219242515042, 0.09777267230674624, 0.14641990332165733, 2.154235979542136, 62.09827043116093, 71.2486620247364, 39.16384108364582, 36.91487096250057, 29.674368984997272, 37.08882562816143, 39.7538848221302, 38.60467068850994, 33.3110037446022, 35.663719698786736, 39.78190451860428, 44.54197369515896, 73.63915175199509, 49.65028278529644, 8.631428740918636, 14.88017063587904, 57.571512535214424, 70.5774736404419, 72.75316089391708, 58.27888637781143, 61.633528769016266, 51.758162677288055, 39.397064968943596, 26.6567837074399, 16.555147357285023, 5.517893861979246, 4.336213795468211, 6.356496987864375, 26.679694578051567, 25.250180885195732, 18.519311361014843, 31.94885663688183, 19.458011090755463, 30.95022652298212, 31.425303630530834, 24.026184864342213, 14.569449909031391, 22.549779787659645, 26.884059011936188, 15.531677026301622, 12.817224282771349, 18.91356110572815, 25.43354194611311, 39.764501452445984, 32.53452681005001, 15.458727590739727, 15.43513560667634, 17.54686564207077, 27.40305606275797, 36.567896381020546, 20.311534591019154, 30.167926400899887, 35.822832360863686, 26.53097625821829, 29.354901127517223, 25.948948189616203, 39.672386795282364, 50.544378608465195, 44.359712675213814, 19.847427494823933, 13.011763393878937, 27.27739680558443, 35.73550544679165, 47.099270671606064, 53.14251199364662, 54.53178584575653, 56.473116874694824, 57.473481595516205, 50.88993966579437, 50.75715199112892, 55.54724335670471, 53.67094203829765, 53.08850549161434, 54.893097057938576, 50.597906336188316, 44.22872610390186, 46.33880987763405, 51.51211068034172, 59.07294496893883, 57.784958481788635, 47.92102977633476, 33.03986929357052, 14.66396413743496, 9.67096270993352, 14.7673299908638, 29.51725121587515, 39.69107799232006, 35.43266549706459, 27.547493912279606, 22.023633420467377, 21.883137859404087, 25.578829050064087, 32.940136045217514, 26.34759619832039, 18.884382471442223, 22.680602967739105, 33.50774198770523, 25.130124427378178, 16.264246366918087, 28.03947441279888, 29.423719234764576, 28.469111658632755, 25.141432620584965, 12.663012407720089, 8.183200042694807, 4.139536349102855, 3.526259232312441, 11.649956367909908, 18.66338063031435, 18.317198306322098, 24.940831884741783, 39.01494227349758, 33.29112321138382, 21.203190945088863, 11.29755187779665, 8.137379251420498, 6.810496151447296, 43.17041449248791, 28.67449253797531, 5.09285531938076, 13.978384975343943, 42.48121127486229, 62.26541966199875, 54.92075577378273, 58.838326558470726, 56.496519818902016, 56.956192553043365, 61.18655875325203, 56.57556317746639, 59.416397139430046, 38.53873282670975, 4.9366385769099, 14.436560589820147, 36.885126158595085, 47.439705803990364, 14.5958480425179, 25.340498238801956, 44.44753356277943, 49.16424706578255, 35.990965738892555, 21.936874575912952, 26.689864732325077, 26.92908089607954, 26.619454510509968, 31.04919221252203, 52.94494919478893, 71.7121459543705, 12.727724835276604, 0.370285261888057, 0.23070329945767298, 0.3383146086707711, 0.13343565864488482, 0.21347968460759148, 0.10044750611996278, 0.09141054455540143, 0.06560573587194085, 0.049224803733523004, 0.02551106663304381, 0.010169575398322195, 0.3215785254724324, 0.14414395904168487, 0.1433468033792451, 0.12080008236807771, 0.12512134853750467, 0.12677835649810731, 0.1769274569232948, 0.2163673218456097, 0.23846619384130463, 0.3246314241550863, 0.18831664812751114, 0.24601870420156047, 0.38515894033480436, 0.34109264553990215, 0.48596996522974223, 0.3568826388800517, 5.0046126544475555, 82.5485260784626, 79.37142536044121, 51.928431540727615, 48.774562776088715, 35.85702672600746, 53.83825846016407, 64.77135479450226, 52.00836405158043, 42.08545111119747, 39.532535299658775, 46.71549506485462, 53.25484536588192, 85.067920088768, 53.599882051348686, 9.551516119390726, 17.65833456069231, 62.71148532629013, 74.31332677602768, 76.03431522846222, 64.04460579156876, 67.47940868139267, 56.21622025966644, 44.16132152080536, 28.07893719524145, 28.491826839745045, 13.470652420073748, 6.196995321661234, 12.522270809859037, 36.0543767362833, 32.97243431210518, 23.292123153805733, 39.124459996819496, 25.623351261019707, 38.04893150925636, 39.167686477303505, 26.72961249947548, 17.829154394567013, 25.393661186099052, 35.97939155995846, 18.18646252155304, 15.72722403332591, 21.982382833957672, 30.213518254458904, 47.55977176129818, 38.375630378723145, 18.46459999680519, 24.022523760795593, 23.404612317681313, 36.165744960308075, 44.66144688427448, 26.6169960424304, 37.8699155151844, 41.236759051680565, 32.820461466908455, 33.88023979961872, 32.33652323484421, 41.654824018478394, 54.760670363903046, 52.491306737065315, 35.752471536397934, 30.062871538102627, 38.70723478496075, 45.368224158883095, 54.604627937078476, 58.00650179386139, 57.88147710263729, 57.87592560052872, 60.37148728966713, 49.664513021707535, 48.99087756872177, 52.604156881570816, 50.79424940049648, 47.31323339045048, 51.34369611740112, 51.6485233604908, 50.807826071977615, 50.32441981136799, 53.11493307352066, 58.659857735037804, 58.54147508740425, 48.10353398323059, 42.22013868391514, 22.592894174158573, 15.72903748601675, 23.713224157691002, 38.490847796201706, 46.91110856831074, 40.42217396199703, 35.007992684841156, 24.86214380711317, 25.168198384344578, 27.952603474259377, 38.266382440924644, 29.95640505105257, 23.027402758598328, 27.421238087117672, 38.187232688069344, 30.601906813681126, 22.479027584195137, 33.0066704750061, 33.224592581391335, 32.617187574505806, 31.013890206813812, 16.966019310057163, 8.702642619609833, 5.235740952193737, 7.312497664242983, 17.141022719442844, 24.644704274833202, 26.171758733689785, 34.91661138832569, 44.229911640286446, 40.176813527941704, 29.33557726442814, 18.266294337809086, 11.181956380605698, 6.112558152526617, 37.101836130023, 26.509775295853615, 7.615856286138296, 14.064870234578848, 42.088696137070656, 64.26402881741524, 59.09240372478962, 59.5463577657938, 60.33365651965141, 60.30116826295853, 64.27827805280685, 62.303455621004105, 64.48861956596375, 45.440693870186806, 5.842860024422407, 17.491800896823406, 43.8230636715889, 59.33944746851921, 16.492543816566467, 35.801986679434776, 48.88267457485199, 52.049907222390175, 34.65246856212616, 32.84045599400997, 31.192712411284447, 39.36643861234188, 37.49084785580635, 41.28130026161671, 62.15146377682686, 82.4179270863533, 23.43160606920719, 0.6462963949888945, 0.6029004673473537, 0.6310009688604623, 0.22022236342309043, 0.2804618520895019, 0.21499930619029328, 0.2149810642004013, 0.1983261719578877, 0.18444079672917724, 0.23636593075934798, 0.16854337009135634], [0.058658847701735795, 0.11978718437603675, 0.043032089743064716, 0.052261471646488644, 0.12355726488749497, 0.01509889336375636, 0.014714757726324024, 0.03643430412921589, 0.012833438413508702, 0.07095198961906135, 0.091285062226234, 0.03317639828310348, 0.04657561112253461, 0.06999651901423931, 0.041817609599092975, 0.29622696863953024, 0.17548818024806678, 32.514661476016045, 74.90386068820953, 43.69862034916878, 39.66343827545643, 42.07131586968899, 27.019692733883858, 51.1544206738472, 42.33954347670078, 36.152145490050316, 21.424150988459587, 28.71875636279583, 51.230325400829315, 65.41051089763641, 61.068286299705505, 15.340408589690924, 3.34023570176214, 25.562691316008568, 49.41432684659958, 45.950094535946846, 50.51612712442875, 56.080529540777206, 48.359902426600456, 40.590979903936386, 41.247136294841766, 15.100160781294107, 18.07732667773962, 7.866185903549194, 1.6953943320550025, 6.745527237653732, 8.51787468418479, 18.125430196523666, 55.504355058074, 8.270443361252546, 25.146948024630547, 14.472973085939884, 8.109441250562668, 11.287038791924715, 12.600503861904144, 12.199618723243475, 4.763269079849124, 6.354170087724924, 15.665696784853935, 32.18272268772125, 37.617806643247604, 11.269552130252123, 5.973261427134275, 15.027552377432585, 12.36389435827732, 26.330246329307556, 25.422513037919998, 18.95746774971485, 28.520462103188038, 33.58618877828121, 24.697280153632164, 21.90938875079155, 27.81935602426529, 41.680028066039085, 47.88165628910065, 35.39282463490963, 17.93794445693493, 6.772350948303938, 11.546490769833326, 19.2226555198431, 32.77804434299469, 37.183672338724136, 47.55254074931145, 52.356539368629456, 54.300165474414825, 46.7371691018343, 43.59936207532883, 44.430210292339325, 42.014315128326416, 44.64169554412365, 50.028153508901596, 51.411818861961365, 48.69980938732624, 45.98031431436539, 49.05599847435951, 52.228049263358116, 53.666792660951614, 34.19867791235447, 18.45296122133732, 9.3812339566648, 7.57172497920692, 8.66952644661069, 26.36377952992916, 35.80605626106262, 39.09902036190033, 31.938418596982956, 22.390323244035244, 14.132070578634739, 18.056218810379505, 22.814745269715786, 23.968576155602932, 28.48369337618351, 20.106771178543568, 29.451024569571018, 22.598407678306103, 15.676260218024254, 10.280916430056095, 20.838473215699196, 20.36243285983801, 25.536354929208755, 14.72443314269185, 2.822015709243715, 4.247422059997916, 3.082046681083739, 2.7611595997586846, 5.843487940728664, 10.28289707377553, 5.834352755919099, 13.162493705749512, 11.652834713459015, 6.93934771232307, 12.36093146726489, 15.410149097442627, 27.78287798166275, 40.12855611741543, 8.458024095743895, 12.250784877687693, 16.102755032479763, 37.3332779109478, 54.308859407901764, 51.89882352948189, 53.38966593146324, 55.1382827013731, 58.3189058303833, 53.98822121322155, 56.00450702011585, 56.04143723845482, 20.810806900262833, 3.2880839752033353, 17.92190931737423, 28.439811430871487, 20.419386103749275, 26.84439294040203, 40.61027906835079, 45.52300505340099, 43.58151823282242, 24.577014707028866, 28.33404790610075, 21.867159716784954, 43.25179472565651, 22.996519915759563, 39.267252534627914, 57.3189552873373, 43.48500341176987, 2.3207741556689143, 0.25674319826066494, 0.29539677256252617, 0.05052563275967259, 0.14982799388235435, 0.01644235228013713, 0.10815660221851431, 0.026938726841763128, 0.04935549965011887, 0.04135177834541537, 0.11276136880042031, 0.06111327849794179, 0.025627403847465757, 0.15830005489988253, 0.05568128814047668, 0.05518483587366063, 0.048294328662450425, 0.037435398262459785, 0.03580334872822277, 0.059678091056412086, 0.02656380682310555, 0.07407213430269621, 0.06595786268007942, 0.024288992462970782, 0.09837329242145643, 0.05832070666656364, 0.05124853654706385, 0.18687913776375353, 0.14007753896294162, 35.31409665942192, 87.68235459923744, 49.618155509233475, 40.49501985311508, 35.75121760368347, 31.69495426118374, 43.03649827837944, 38.92381936311722, 39.85666170716286, 28.566287644207478, 32.789367735385895, 50.46951502561569, 74.72145527601242, 68.90182435512543, 23.155902363359928, 5.244090529158711, 25.468120090663433, 52.970487624406815, 54.71958316862583, 56.220217645168304, 62.22098484635353, 51.05787545442581, 43.183565586805344, 45.004139095544815, 19.24814835190773, 12.728825826197863, 3.9781098486855626, 0.9578041546046734, 5.102338660508394, 11.90820001065731, 27.142167761921883, 58.45561109483242, 13.107990380376577, 29.877492785453796, 16.790615022182465, 10.266346111893654, 14.421335756778717, 13.760356474667788, 14.017927553504705, 5.951065393164754, 7.675567232072353, 17.702818773686886, 33.35086740553379, 41.02680891752243, 16.24352417886257, 7.3530524130910635, 15.468770451843739, 15.998781211674213, 27.663951963186264, 26.537686698138714, 24.309212677180767, 28.562231361865997, 37.66815394163132, 29.765868075191975, 24.428545273840427, 29.79182068258524, 43.80623817443848, 55.08652187883854, 46.94325864315033, 27.256623320281506, 13.563167005777359, 20.619692355394363, 31.25372003763914, 44.58671249449253, 49.59424339234829, 54.3048620223999, 59.309299886226654, 59.37808759510517, 50.649974942207336, 52.46500834822655, 51.8681363761425, 49.482324197888374, 49.359169006347656, 54.669722244143486, 54.098004922270775, 53.155043721199036, 49.026519656181335, 52.69983574748039, 58.66301916539669, 60.09489633142948, 42.570654675364494, 27.02104926109314, 15.634654350578785, 12.65845075249672, 16.034396700561047, 33.75204987823963, 43.350312039256096, 40.702868700027466, 32.20975063741207, 23.34738738834858, 15.642314739525318, 21.693108156323433, 26.18060275912285, 28.335032053291798, 31.271750070154667, 26.549599058926105, 30.660070292651653, 27.694926001131535, 18.886740244925022, 13.237508330494165, 25.680980868637562, 22.14130360633135, 28.922776915133, 17.856410332024097, 8.556274473667145, 11.013713758438826, 7.525509959086776, 6.27174586057663, 10.403093174099922, 14.15250113233924, 9.425414185971022, 14.926066473126411, 18.792254514992237, 11.355062741786242, 20.336438454687595, 22.714141868054867, 32.68730141222477, 44.867072850465775, 13.111747428774834, 11.68231638148427, 19.667452052235603, 41.83421619236469, 58.850991278886795, 53.36518004536629, 57.89800241589546, 58.04481893777847, 60.19856616854668, 57.11087465286255, 60.56545168161392, 58.810215666890144, 26.37463554739952, 4.300871416926384, 19.809079952538013, 29.579678066074848, 31.351473592221737, 18.770371489226818, 41.879855543375015, 46.87290161848068, 62.95460008084774, 27.427982725203037, 26.30173835903406, 25.558049865067005, 41.02653533220291, 28.918587639927864, 37.57027119398117, 66.28073260188103, 48.17218869924545, 2.8721970040351152, 0.3773864870890975, 0.19658654811792076, 0.05145514674950391, 0.1559925841866061, 0.10546384553890675, 0.08518773276591673, 0.10108714093803428, 0.0464730759995291, 0.03890158150170464, 0.01916375957080163, 0.038458300405181944, 0.18561239558039233, 0.2359397747204639, 0.10565694494289346, 0.17763928044587374, 0.28621171542908996, 0.1597738711279817, 0.20462123182369396, 0.2666834945557639, 0.1245672462391667, 0.22439770109485835, 0.20412547717569396, 0.12426978602888994, 0.25494723056908697, 0.14574190689017996, 0.12292392348172143, 0.5279215250629932, 0.22145324503071606, 48.91879543662071, 95.72531461715698, 58.12685653567314, 57.36000448465347, 52.814118415117264, 41.34263277053833, 68.87970954179764, 52.54698894917965, 54.01548095047474, 28.633272349834442, 36.49467431008816, 51.87401086091995, 80.57085379958153, 66.57369688153267, 21.43224075436592, 5.361905582249165, 32.71829254925251, 58.12543161213398, 57.184043526649475, 60.919737070798874, 71.25263661146164, 55.604073107242584, 50.793162658810616, 47.46087446808815, 21.784048676490784, 24.781426638364792, 13.071613032370806, 3.0600833846256137, 8.82201511412859, 15.813806187361479, 34.58446741104126, 64.79581788182259, 21.004908084869385, 34.064685702323914, 19.730781354010105, 14.29184915497899, 20.091488398611546, 19.581540562212467, 19.41414814442396, 7.997796591371298, 9.645227640867233, 20.44175550341606, 38.54626402258873, 48.133035600185394, 19.329401291906834, 11.675025522708893, 25.422285050153732, 21.99781760573387, 33.576879277825356, 33.6224502325058, 26.97240237146616, 35.602269396185875, 41.41063392162323, 36.9963613897562, 30.98143994808197, 34.86223630607128, 46.46089732646942, 56.19547337293625, 52.99250744283199, 38.43682989478111, 32.11387798190117, 38.33405300974846, 46.81195288896561, 53.21181647479534, 56.504279002547264, 57.169714495539665, 60.38482077419758, 58.30001704394817, 50.23323230445385, 51.44493408501148, 49.29774530231953, 47.669787257909775, 43.90182204544544, 51.0173050314188, 54.47495609521866, 52.23351337015629, 49.026998430490494, 51.15710332989693, 58.06342653930187, 58.16125608980656, 46.5588066726923, 43.2873722165823, 32.41680532693863, 26.98735646903515, 35.13075649738312, 47.39326469600201, 53.26883241534233, 49.3272203207016, 36.84498891234398, 27.857521176338196, 18.320589624345303, 24.22376286238432, 31.842958219349384, 31.55472658574581, 36.72785259783268, 30.17094723880291, 37.65665575861931, 33.8557843118906, 21.13102711737156, 17.99241643399, 30.388168282806873, 26.480123586952686, 32.32904143631458, 22.819257527589798, 11.162432078272104, 10.06537014618516, 8.32089800387621, 7.802297081798315, 12.815983649343252, 15.69917868822813, 11.700468007475138, 19.326304458081722, 23.763330169022083, 13.983847182244062, 20.556625239551067, 28.988372795283794, 42.02063798904419, 51.57823473215103, 12.872568313032389, 22.787652723491192, 21.324400641024113, 43.381371572613716, 61.65304832160473, 58.41217562556267, 61.30765825510025, 61.29047177731991, 62.369279488921165, 62.22324572503567, 64.42945674061775, 64.3783038854599, 26.74689207226038, 4.48914703913033, 22.96400126069784, 35.740399584174156, 34.62604857981205, 33.632420897483826, 49.1814449429512, 50.38949511945248, 60.03124214708805, 29.653869085013866, 43.10458682477474, 28.60061690211296, 58.72986517846584, 35.21332986652851, 51.2587820738554, 73.59104633331299, 67.02018812298775, 5.944485571235418, 0.48094078665599227, 0.6649213924538344, 0.17963067046366632, 0.34646324173081666, 0.20819304016185924, 0.1857254988863133, 0.2576263539958745, 0.187282940314617, 0.19252689642598853, 0.2429422942805104, 0.26202004635706544], [0.07532973322668113, 0.055459556679124944, 0.030798145235166885, 0.014450554081122391, 0.03898585979186464, 0.16256836883258075, 0.015192373357422184, 0.0651934060442727, 0.04791404848219827, 0.1055921331862919, 0.1229920971672982, 0.12051399928168394, 0.02341085364605533, 0.09175058919936419, 0.04315408026741352, 0.39388478617183864, 0.19659849669551477, 7.448060614988208, 73.48402127623558, 57.98101656138897, 33.51187616586685, 44.31535005569458, 35.49414619803429, 37.969302982091904, 49.221061617136, 43.141608238220215, 38.82269538938999, 19.471241980791092, 44.97683756053448, 41.292293071746826, 46.992021426558495, 56.87414735555649, 15.511152427643538, 10.85325786843896, 37.45076760649681, 58.629390969872475, 55.2678557485342, 66.20068609714508, 58.837570399045944, 54.947084560990334, 48.431684374809265, 32.64348216354847, 14.858778733760118, 4.651557449251413, 1.5890286583453417, 0.4064168402692303, 5.445193788036704, 14.941799528896809, 20.09065054357052, 11.077347993850708, 4.425415908917785, 2.16966291423887, 3.1309552816674113, 21.86381969600916, 22.803963348269463, 6.733497558161616, 7.779662646353245, 8.881571218371391, 22.96704489737749, 40.16276188194752, 16.121246740221977, 3.5595841566100717, 13.743952754884958, 12.111844383180141, 18.280642367899418, 30.708711482584476, 23.358119912445545, 23.262735530734062, 26.24570656567812, 28.479042425751686, 31.98044814169407, 19.607255682349205, 31.46872580051422, 49.65002819895744, 53.479424715042114, 34.026733338832855, 14.766210000962019, 11.23920600861311, 11.850858237594366, 19.779648631811142, 33.50701242685318, 42.69265092909336, 48.905043974518776, 56.4342487603426, 53.74555863440037, 46.15001700818539, 45.087738409638405, 44.29632067680359, 44.623950496315956, 42.19111204147339, 47.790860161185265, 50.752147659659386, 48.48417095839977, 42.21647948026657, 46.24262943863869, 53.563058227300644, 49.690401032567024, 42.144442945718765, 27.65262857079506, 15.602346584200859, 11.637353394180536, 10.987230129539967, 21.039940305054188, 32.64352396130562, 41.384457126259804, 37.96473942697048, 24.542189575731754, 10.993644185364246, 12.506938632577658, 17.918561697006226, 27.09406804293394, 28.644356355071068, 25.51097609102726, 24.6610376983881, 24.577278792858124, 21.242224350571632, 14.834333695471287, 3.238997971639037, 20.349591448903084, 18.47941730171442, 29.259058870375156, 10.335301011800766, 3.5281258821487427, 3.3660918893292546, 2.5185471307486296, 8.937266729772091, 34.87161800265312, 28.96752331405878, 28.81967704743147, 42.770618945360184, 29.801952838897705, 20.068096853792667, 3.5688592214137316, 3.029410718008876, 7.1847133710980415, 5.741712776944041, 13.309401422739029, 24.4936927780509, 41.56965918838978, 58.49890597164631, 49.14764195680618, 54.045370146632195, 53.96984159946442, 53.77137824892998, 56.54992215335369, 55.81286430358887, 55.2240364998579, 19.742085747420788, 6.039920775219798, 46.97137713432312, 59.26315136253834, 28.092299178242683, 46.86605058610439, 34.857961535453796, 52.1409085392952, 24.106664545834064, 28.42778317630291, 25.503435395658016, 30.916866213083267, 27.811515145003796, 24.843807891011238, 49.80653800070286, 55.16622640192509, 15.63926825299859, 0.7036157255060971, 0.41899490752257407, 0.37814748531673104, 0.13556903635617346, 0.028019937672070228, 0.044053407400497235, 0.09965265853679739, 0.02173598961235257, 0.06419971483410336, 0.022501626262965146, 0.05012199719203636, 0.05080351511423942, 0.06704251150949858, 0.08994558214908466, 0.017065034589904826, 0.07790760544594377, 0.06527447083499283, 0.12849521124735475, 0.034816218103514984, 0.04963196079188492, 0.03486161898763385, 0.03547355685441289, 0.06801152630941942, 0.061252197410794906, 0.05120349189382978, 0.06144846949609928, 0.030871048256813083, 0.21163831232115626, 0.11015264550223947, 7.204147428274155, 84.39686849713326, 66.46607145667076, 36.21935248374939, 41.94931201636791, 35.83040155470371, 38.72390069067478, 38.15591096878052, 48.509640991687775, 40.15603244304657, 25.26897467672825, 46.841579899191856, 47.47815974056721, 54.662954807281494, 65.90407401323318, 23.100531734526157, 14.1857816465199, 36.964256912469864, 61.669467240571976, 61.07609108090401, 72.37442761659622, 58.665793016552925, 54.61855798959732, 50.688056498765945, 37.1067226678133, 16.68685019016266, 7.055463306605816, 3.900063461624086, 0.14216671435860917, 8.084483239799738, 19.60142869502306, 28.683784939348698, 14.190658684819937, 6.066174041479826, 3.7037664698436856, 4.3182607088238, 25.7553618773818, 27.127690538764, 8.116486072540283, 9.165200348943472, 12.015946079045534, 28.362609073519707, 44.70977269113064, 22.9622495546937, 6.520499512553215, 13.74475546181202, 15.697222743183374, 21.086508706212044, 32.10517264902592, 25.517207756638527, 28.09511862695217, 27.61669009923935, 33.01960498094559, 33.71123626828194, 25.687911696732044, 32.18378663063049, 50.117942690849304, 58.78995895385742, 47.27607138454914, 26.00259181112051, 14.980247765779495, 23.572097830474377, 33.692427277565, 43.837347105145454, 48.420828357338905, 55.40098160505295, 56.26104645431042, 61.12808369100094, 50.079063177108765, 48.553566634655, 51.58487677574158, 49.63245414197445, 46.772617399692535, 54.466018974781036, 56.73955477774143, 53.167039677500725, 47.2203853726387, 52.31518238782883, 57.88232445716858, 57.29895696043968, 43.5696666687727, 30.456496216356754, 21.34832415729761, 16.48312982171774, 21.933129876852036, 36.84889890253544, 43.69092956185341, 48.23762498795986, 37.237025275826454, 23.86890560388565, 12.260390762239695, 15.374773945659399, 20.422370843589306, 29.558194018900394, 29.793446995317936, 29.640239216387272, 28.038475066423416, 25.75302880257368, 29.402903951704502, 18.78996893763542, 12.148547563701868, 23.477059230208397, 22.60731440037489, 29.815945588052273, 11.890841592103243, 7.575165219604969, 8.462733943015337, 6.394504448398948, 11.766073387116194, 39.52189587056637, 35.083418637514114, 36.938292905688286, 49.127218052744865, 37.875277027487755, 24.401067048311234, 3.1954164477065206, 1.7411793814972043, 8.231419455260038, 4.744047811254859, 14.7179364413023, 27.597022354602814, 46.301039904356, 64.25601124763489, 55.82598879933357, 59.742252454161644, 59.77989703416824, 60.077440068125725, 61.41701638698578, 62.02311046421528, 63.479576110839844, 25.284320153295994, 7.615485331043601, 48.84696029126644, 49.49668362736702, 31.92188188433647, 40.499009639024734, 35.14063976705074, 56.5226624161005, 38.948582634329796, 21.508141681551933, 28.945554792881012, 30.942727625370026, 32.03161619603634, 27.861634455621243, 49.50244791805744, 69.9348521232605, 19.977376721799374, 0.630865185521543, 0.44120566570200026, 0.1317944287438877, 0.05816574252094142, 0.1310590939829126, 0.12882260227343068, 0.08538229420082644, 0.05338069713616278, 0.057657026263768785, 0.07642144730198197, 0.03368702557054348, 0.055342000487144105, 0.21806774544529617, 0.14991106989327818, 0.11599361489061266, 0.29133767005987465, 0.09921573393512517, 0.370600734022446, 0.11619616925599985, 0.2236288064159453, 0.16805312217911705, 0.16451384959509596, 0.1311301620444283, 0.17264735768549144, 0.14419338607694954, 0.25108610338065773, 0.2648620563559234, 0.8005553518887609, 0.5003909335937351, 15.717321764677763, 98.85677218437195, 74.95087176561356, 50.79532094299793, 58.47866825759411, 47.43453048169613, 57.013542875647545, 60.00375062227249, 61.854475513100624, 49.33614984154701, 27.277039624750614, 50.538272336125374, 48.3836929500103, 55.685194954276085, 64.44043055176735, 24.1445979103446, 18.055447451770306, 48.26541669666767, 70.08754312992096, 68.35754156112671, 79.0317539870739, 67.55045726895332, 63.7080692499876, 56.66863538324833, 39.66137118637562, 18.859438709914684, 10.032585505396128, 5.345341796055436, 1.187702149618417, 10.78672343865037, 24.476052224636078, 31.117829829454422, 15.864694956690073, 9.522082898765802, 5.632599256932735, 5.387423587962985, 27.770617939531803, 32.03032046556473, 9.811723306775093, 12.51891653984785, 17.266115806996822, 34.26609009504318, 54.01060201227665, 23.192344307899475, 8.657512441277504, 21.300811506807804, 21.585330739617348, 24.6928932890296, 38.29651482403278, 29.496867209672928, 33.107969239354134, 34.91360194981098, 37.6425851136446, 40.81924505531788, 30.823685713112354, 39.734068885445595, 54.95915271341801, 64.46357890963554, 52.81521275639534, 36.07424207031727, 29.935114793479443, 38.609424233436584, 44.98461954295635, 54.158923253417015, 58.243358284235, 58.682386726140976, 58.39055098593235, 58.998157382011414, 50.636117085814476, 49.74795274436474, 51.862204894423485, 52.53207474946976, 43.27258720993996, 49.919889718294144, 54.80802342295647, 53.99548642337322, 45.885737389326096, 50.88082775473595, 56.25798001885414, 54.05704312026501, 50.138685777783394, 45.40546976029873, 45.14449596405029, 41.87352508306503, 42.61178366839886, 49.67360973358154, 51.78038388490677, 60.44670045375824, 48.89838673174381, 33.68400692939758, 17.040445916354656, 17.711111828684807, 24.97751511633396, 35.21292708814144, 35.95471948385239, 33.745381236076355, 32.86906845867634, 32.985243424773216, 32.20642201602459, 25.974152237176895, 10.99095392972231, 25.0699033588171, 27.322754971683025, 33.91331322491169, 17.518503963947296, 8.498433027416468, 7.3699657805264, 8.268818948417902, 16.981132999062538, 47.537900134921074, 39.8135682195425, 37.227240800857544, 50.146688148379326, 42.74441555142403, 33.195558339357376, 8.16305922344327, 6.2791032157838345, 10.710606873035431, 10.615585371851921, 20.785089880228043, 28.010573163628578, 49.05432656407356, 66.68702200055122, 57.009195908904076, 63.00096899271011, 65.44989958405495, 62.330578565597534, 65.96632227301598, 67.30726271867752, 67.96362429857254, 25.33284354954958, 8.806355204433203, 51.77724525332451, 67.15864509344101, 33.28237988054752, 59.0881023555994, 36.594221368432045, 63.237920477986336, 34.46313992142677, 34.88099589943886, 37.35084816813469, 41.156332567334175, 42.34486699104309, 35.3068770468235, 66.62015318870544, 80.92700868844986, 33.88180531561375, 0.8818482491187751, 0.6584397121332586, 0.4807875776896253, 0.13671182503458112, 0.16655647748848423, 0.23032505647279322, 0.182397055614274, 0.11595694537390955, 0.16396273073041812, 0.2258750202599913, 0.09380114322993904, 0.19679850549437106], [0.030273177799244877, 0.036884001092403196, 0.05207235015404876, 0.04327155482314993, 0.05630256964650471, 0.0988896787748672, 0.02367115823290078, 0.08981383609352633, 0.09066861952305771, 0.05889997148187831, 0.1264542160788551, 0.10508545412449166, 0.042694538715295494, 0.03663804593088571, 0.04631015232007485, 0.04102527418581303, 0.07421332789817825, 0.7527532638050616, 53.961060270667076, 74.19476553797722, 35.09631134569645, 38.94156061112881, 40.60237929224968, 36.47842638194561, 52.26992681622505, 37.25319340825081, 43.05538326501846, 22.68191769719124, 21.1092371866107, 41.01967290043831, 62.722010761499405, 71.83515295386314, 33.39549981057644, 8.52503065019846, 31.804612576961517, 71.1724305152893, 62.002663761377335, 58.28204780817032, 57.94532887637615, 58.22138786315918, 58.78514841198921, 42.59171314537525, 33.002521097660065, 6.47985546849668, 0.5032767006196082, 0.17460161063354462, 5.380933536216617, 7.85001777112484, 5.185277285054326, 2.9751132940873504, 1.0729409451596439, 6.498528616502881, 3.7578306812793016, 12.23045026883483, 12.076794113963842, 8.325801640748978, 6.811806606128812, 12.798884566873312, 36.62892870604992, 33.69424358010292, 5.170817635953426, 7.477701874449849, 16.902061142027378, 13.24666678905487, 23.17897852510214, 24.738477542996407, 22.053062841296196, 26.4201533049345, 24.646474979817867, 24.78488825261593, 26.956352032721043, 21.861429624259472, 34.177767634391785, 51.46761506795883, 53.05913686752319, 30.259643979370594, 11.12660950049758, 9.286575336009264, 10.051567386835814, 21.993217952549458, 34.29728642106056, 46.353625282645226, 52.25751668214798, 54.98451255261898, 55.12972556054592, 45.76601341366768, 46.26180700957775, 47.18670777976513, 45.00329174101353, 42.984391674399376, 45.534051060676575, 45.78204855322838, 42.74657383561134, 37.85999044775963, 45.972536131739616, 54.22988824546337, 53.65659020841122, 41.40279494225979, 33.13125438988209, 25.1713902130723, 17.373583540320396, 12.30767922475934, 14.691763445734978, 29.9315619841218, 39.867996498942375, 44.82820853590965, 28.590184561908245, 10.627431236207485, 6.568254875019193, 14.570457804948092, 22.77291141450405, 23.748129084706306, 29.410684034228325, 26.69917043298483, 28.255779705941677, 24.046604968607426, 19.124860167503357, 6.918670646846294, 3.0862680170685053, 20.032629556953907, 21.783241219818592, 22.048858366906643, 6.573432572185993, 1.179496014956385, 2.09854023065418, 2.1318587427958846, 2.4114209040999413, 3.341688411310315, 8.449778538197279, 10.774940270930529, 12.499916609376669, 2.7788502629846334, 0.2920898812590167, 0.45531282434239984, 3.7569541158154607, 9.772131331264973, 18.67087572813034, 34.6215458214283, 43.18742237985134, 57.35817678272724, 53.61624397337437, 53.81467692553997, 51.774239614605904, 58.52302707731724, 53.1003038585186, 62.54243619740009, 40.4124540835619, 7.235206961631775, 16.758208461105824, 54.78908523917198, 60.105224177241325, 37.80958615243435, 20.989978685975075, 43.72429557144642, 38.780798837542534, 19.182185791432858, 33.03326904773712, 25.059110037982464, 37.16830216348171, 32.97835439443588, 34.561611637473106, 49.50459860265255, 53.25871355831623, 5.851830393075943, 0.18297915172297508, 0.39672501501627266, 0.4848452552687377, 0.08663094282383099, 0.14620647649280727, 0.06072905380278826, 0.07235861179651693, 0.06455887720221654, 0.01064036234311061, 0.07244558408274315, 0.026611230059643276, 0.019342978957865853, 0.03586446830013301, 0.12749224319122732, 0.0654107439913787, 0.04403939194162376, 0.07740629211184569, 0.017777160537661985, 0.06598304375074804, 0.02326497338799527, 0.07063603508868255, 0.09778070976608433, 0.06749832376954146, 0.1104338675213512, 0.019276512211945374, 0.07456321342033334, 0.1168265420710668, 0.13053669623332098, 0.10907224175753072, 0.896065483102575, 62.446825727820396, 87.8003078699112, 38.77529293298721, 44.980796948075294, 38.21510039269924, 39.028047770261765, 41.00178346037865, 37.570335790514946, 45.81852659583092, 27.56724715232849, 30.045867450535297, 40.78824631869793, 63.49700577557087, 73.36443409323692, 38.78313571214676, 12.99429003149271, 34.76854093372822, 72.38970279693604, 69.26937103271484, 61.49557337164879, 61.494319438934326, 61.19947046041489, 62.74778097867966, 45.66409528255463, 36.031346172094345, 9.906136840581894, 1.5053704474121332, 0.04857828920648899, 5.506380954757333, 12.357729189097881, 8.471035547554493, 4.745317418128252, 1.54858066001907, 6.135409651324153, 3.0914077162742615, 15.723504982888699, 14.380458500236273, 9.873119462281466, 9.099793508648872, 18.992621563374996, 42.0018669962883, 38.86895030736923, 10.858991760760546, 7.281286139041185, 17.998393513262272, 17.6760321110487, 27.362799122929573, 28.091655112802982, 27.817307934165, 31.79943535476923, 29.26587950438261, 28.314518854022026, 31.326552629470825, 24.98946737498045, 36.156697645783424, 56.42764091491699, 56.7026511579752, 42.50016085803509, 23.495813123881817, 14.142411723732948, 21.775903813540936, 31.280176118016243, 47.28741757571697, 51.87972195446491, 57.59520046412945, 59.5597368478775, 59.028198570013046, 48.81976135075092, 51.49179317057133, 53.992222398519516, 51.05782985687256, 47.65091747045517, 52.27317564189434, 53.31963948905468, 50.161685943603516, 45.50679512321949, 50.2168095856905, 58.69738072156906, 56.24798275530338, 46.74856849014759, 39.36028674244881, 30.256592743098736, 23.657754734158516, 25.402668602764606, 29.770095348358154, 40.3106689453125, 49.89050589501858, 45.42170248925686, 29.59438517689705, 12.291503492742777, 6.886247461661696, 20.2188328653574, 26.47746752947569, 29.21132393181324, 32.66032285988331, 31.611645631492138, 30.5373577773571, 28.16355485469103, 22.998621203005314, 9.142701756209135, 10.549314077943563, 22.034314647316933, 22.040920592844486, 23.727961666882038, 7.030011797323823, 6.4169493690133095, 6.550683192908764, 4.184169229120016, 5.726959593594074, 4.455275181680918, 10.065411943942308, 12.001800388097763, 12.968849446624517, 2.437651134096086, 0.2812257001642138, 1.0634091566316783, 1.771289084572345, 9.535709917545319, 15.009839627891779, 36.37108974158764, 46.424309089779854, 62.413733303546906, 57.671268582344055, 59.383475705981255, 58.4916103631258, 61.81708171963692, 57.953281849622726, 70.73233053088188, 48.29535149037838, 10.13011297211051, 23.17525092512369, 51.47740714251995, 58.77823278307915, 37.19422057271004, 26.647878885269165, 45.24376183748245, 50.38006782531738, 25.412230789661407, 25.503860972821712, 28.997241519391537, 32.6820994913578, 37.75273360311985, 30.737512037158012, 57.13630668818951, 63.1680042296648, 7.579976236447692, 0.2937042008852586, 0.2039536551455967, 0.17552470875671133, 0.06263995048357174, 0.0998083091690205, 0.0707468822656665, 0.1251509750727564, 0.1143994445737917, 0.09638216215535067, 0.026408375124447048, 0.10479933393071406, 0.01337125799182104, 0.10429914866108447, 0.19293611665489152, 0.1423691722447984, 0.09813050623051822, 0.12493270944105461, 0.2433301554992795, 0.12063020476489328, 0.20261670579202473, 0.11879583093104884, 0.21025701222242787, 0.19517292006639764, 0.27630894212052226, 0.09842561383266002, 0.24338030983926728, 0.2755195938516408, 0.38183999655302614, 0.17778019944671541, 1.746086343191564, 76.58818870782852, 94.42369446158409, 47.3726812005043, 53.04163120687008, 51.155951991677284, 53.50188910961151, 67.6843848824501, 49.73285995423794, 60.72131931781769, 30.22060677409172, 28.396959230303764, 44.76733200252056, 73.0852022767067, 80.31332641839981, 41.03418052196503, 14.112167246639729, 40.052833780646324, 80.014388859272, 74.52966436743736, 69.74195927381516, 66.23951241374016, 67.53437653183937, 69.55462172627449, 50.06024278700352, 37.270315289497375, 9.278568215668201, 1.5771882561966777, 0.2166261087404564, 9.320639558136463, 17.51801759004593, 12.084506750106812, 7.619363022968173, 2.8329973574727774, 10.78429726883769, 5.4022779408842325, 19.57031026482582, 17.55989894270897, 10.832679122686386, 11.552192363888025, 22.077140249311924, 48.03853467106819, 43.458632826805115, 11.521050184965134, 13.097302503883839, 24.905803464353085, 19.60563886910677, 32.86242641508579, 34.09253440797329, 30.15594184398651, 35.923325568437576, 30.676983185112476, 33.08965802192688, 36.18175350129604, 30.546287298202515, 41.10468953847885, 57.615126594901085, 59.93017137050629, 48.41600261628628, 32.02975049614906, 25.133373253047466, 35.450600534677505, 46.98877640068531, 56.09194792807102, 58.195461854338646, 60.253317430615425, 58.97946238517761, 58.26188609004021, 48.041950687766075, 52.38310754299164, 55.91151461005211, 53.37175749242306, 46.205900609493256, 51.414452120661736, 51.03104509413242, 47.835313975811005, 46.092845275998116, 49.395457059144974, 56.751930713653564, 54.94485788047314, 47.63352580368519, 52.58066654205322, 49.42388713359833, 44.82920788228512, 38.215282782912254, 36.026676222682, 48.05271551012993, 54.62980158627033, 53.182303458452225, 37.51520074903965, 18.495990112423897, 11.071976982057095, 21.949242912232876, 31.78761798888445, 32.723099291324615, 38.40032905340195, 35.90598329901695, 34.607410579919815, 32.277899980545044, 27.00964607298374, 14.526078086346388, 6.888351598754525, 24.70972068607807, 28.21179136633873, 27.63686891645193, 11.21637113392353, 4.798689829185605, 6.795597150921822, 4.160874104127288, 6.246671956032515, 6.6758351773023605, 12.247607298195362, 16.853250861167908, 17.735438123345375, 4.501103097572923, 0.33788098662626, 1.731106834486127, 8.715160097926855, 21.52890756726265, 25.01797914505005, 41.548665314912796, 49.6100277453661, 69.04269799590111, 62.00643315911293, 62.901421934366226, 62.96821095049381, 65.47236397862434, 63.43262203037739, 75.22244319319725, 52.829640582203865, 10.967536736279726, 20.992002077400684, 61.37781769037247, 67.92310327291489, 41.6526847332716, 30.202183462679386, 47.228174954652786, 51.924023777246475, 24.36253521591425, 45.684785172343254, 34.614861980080605, 50.179864168167114, 49.0643086284399, 47.1097657084465, 66.04118585586548, 76.67173102498055, 11.043031085282564, 0.5125147174112499, 0.5622986366506666, 0.5493900168221444, 0.25799805123824626, 0.37780695827677846, 0.18733493518084288, 0.10563512580120005, 0.224306283344049, 0.15179026202531531, 0.19319505197927356, 0.2787489158799872, 0.13566429843194783], [0.058148075695498846, 0.09084346951567568, 0.07800892344675958, 0.03934588676202111, 0.07387118297629058, 0.04288546733732801, 0.04345774112152867, 0.045067990067764185, 0.017536470913910307, 0.12163906547357328, 0.0244128828853718, 0.1514338975539431, 0.09426464413991198, 0.023283031696337275, 0.16732553543988615, 0.020257343858247623, 0.7645458122715354, 0.05794792217784561, 30.528004579246044, 83.92482742667198, 37.73632228374481, 34.95101474225521, 52.69339129328728, 47.25703440606594, 42.090204656124115, 46.21319241821766, 42.18501716852188, 27.97018513083458, 18.220159113407135, 61.527727246284485, 71.01093158125877, 54.247325509786606, 14.098309390246868, 11.859516073018312, 44.79908689856529, 73.88113796710968, 56.36280879378319, 52.966019064188, 57.307054325938225, 50.12656442821026, 51.80984370410442, 45.99303983151913, 26.180108785629272, 16.971000842750072, 3.4268919518217444, 0.719907529419288, 0.49440414702985436, 1.012050756253302, 6.890774918720126, 3.0701060593128204, 1.096665565855801, 1.8717057025060058, 4.177497737109661, 10.061575099825859, 9.077849686145782, 7.083578947931528, 4.7420168202370405, 21.38434622436762, 38.92183966934681, 17.947126664221287, 3.5479099955409765, 16.499427147209644, 15.188112761825323, 21.653730869293213, 24.90187257528305, 25.805863067507744, 28.588449954986572, 29.50018633157015, 24.690706506371498, 24.201209172606468, 25.402425415813923, 28.892502039670944, 37.84528523683548, 54.13761019706726, 51.34351372718811, 27.618728689849377, 9.401296880096197, 9.463775027543306, 11.044972781091928, 20.18966183066368, 37.62840807437897, 48.605392053723335, 52.42856830358505, 56.66076980531216, 53.03489796817303, 50.81479869782925, 45.86331859230995, 47.42397844791412, 45.1346392929554, 41.958952099084854, 43.863725289702415, 43.30673597753048, 40.50120212137699, 36.14519566297531, 45.25615677237511, 55.500528663396835, 53.55475187301636, 46.87584646046162, 38.5915157943964, 25.508173741400242, 15.742866843938828, 10.657258685678244, 11.583749670535326, 22.811792828142643, 37.20941215753555, 41.68752506375313, 29.94782891124487, 10.96528535708785, 5.3839553240686655, 8.198416326195002, 15.577518716454506, 23.20591527968645, 26.259997598826885, 22.976924367249012, 28.69786888360977, 27.571497224271297, 16.03783931583166, 15.415584705770016, 4.562679743394256, 5.895860530436039, 18.715719021856785, 18.239872455596924, 12.79870692640543, 3.1472079595550895, 1.3738985708914697, 4.841552954167128, 8.716151844710112, 4.372162241488695, 2.8172771260142326, 1.0299616889096797, 3.3596650091931224, 0.8077638619579375, 0.9137608960736543, 1.2180479150265455, 2.0834799762815237, 3.60782019328326, 12.285304125398397, 45.32782472670078, 51.031200885772705, 55.16511306166649, 50.71740232408047, 54.28272821009159, 54.232057929039, 53.07254634797573, 57.43172563612461, 49.27076295018196, 16.888389475643635, 11.923241503536701, 41.295036524534225, 65.58734580874443, 40.6775164604187, 15.974420718848705, 25.636219270527363, 46.90424993634224, 24.598390460014343, 23.30931533128023, 27.96434674412012, 27.480003833770752, 54.838797971606255, 34.53621760010719, 42.9135786741972, 65.84222853183746, 30.6204916164279, 1.394451311789453, 0.2188820150331594, 0.33388392766937613, 0.1148221644689329, 0.10381434811279178, 0.02071065693598939, 0.037080477268318646, 0.04444654899998568, 0.07626348116900772, 0.049572084317333065, 0.05339156588888727, 0.06020581742632203, 0.08588258337113075, 0.05713693659345154, 0.04089906455192249, 0.10284715899615549, 0.022983454509812873, 0.08568437056965195, 0.05477276208694093, 0.032327221779269166, 0.058579333999659866, 0.0713544934114907, 0.04545353578578215, 0.04634991659258958, 0.12304760981351137, 0.0616800529678585, 0.02156928097974742, 0.06594559497898445, 0.046724489657208323, 0.6751836917828768, 0.0207485009013908, 34.34678256511688, 99.83779594302177, 41.14382363855839, 38.97282153367996, 53.43958765268326, 41.003238782286644, 34.590003713965416, 39.12761762738228, 47.80631013214588, 33.32897298038006, 28.88351932168007, 60.653614550828934, 73.55884686112404, 61.03665679693222, 19.208516478538513, 15.225861836224794, 53.172724172472954, 83.60572054982185, 62.377065271139145, 58.00181284546852, 61.483813002705574, 54.28020894527435, 57.00120493769646, 51.81001469492912, 28.833943381905556, 16.808101683855057, 5.240009073168039, 0.6998065486550331, 0.770975126652047, 4.0044554974883795, 12.43954449892044, 4.622736945748329, 1.7682070937007666, 2.980750291608274, 3.471998618915677, 10.37419667467475, 11.386572550982237, 11.64698587730527, 10.44190239161253, 27.399212568998337, 41.02467343211174, 28.001263663172722, 5.407889289781451, 14.555802941322327, 19.126813262701035, 23.84565655142069, 30.46465627849102, 30.413957498967648, 34.05099503695965, 33.085854426026344, 32.52066135406494, 27.686401158571243, 27.874071188271046, 30.811725854873657, 40.71788929402828, 53.62003996968269, 59.49602946639061, 43.548175022006035, 17.961328402161598, 12.729039564728737, 20.39502941071987, 32.353132143616676, 47.584516033530235, 52.52586588263512, 60.89783124625683, 59.743855968117714, 58.636336997151375, 52.8339609503746, 48.9499119669199, 52.40486517548561, 50.13905055820942, 49.94510896503925, 48.80974508821964, 50.407012179493904, 47.29611150920391, 41.08262412250042, 50.61483442783356, 57.638879120349884, 58.49484018981457, 49.85698029398918, 45.81545256078243, 35.80538749694824, 30.699225291609764, 21.85558933764696, 22.809169068932533, 35.81869438290596, 46.94556511938572, 49.300325363874435, 33.12451355159283, 15.66850958392024, 8.505435101687908, 13.086845465004444, 19.437216706573963, 28.877652436494827, 29.362576715648174, 25.297425650060177, 32.148672714829445, 27.153688743710518, 22.581088207662106, 12.175432071089745, 7.73266201838851, 16.43372867256403, 17.85168718546629, 19.131682701408863, 11.001258976757526, 5.736962556838989, 8.721515256911516, 11.913063749670982, 14.54620560631156, 7.499990053474903, 3.2189179491251707, 0.8262238057795912, 4.570210464298725, 1.4580519427545369, 0.09589805180439726, 0.39921738440170884, 0.5249849357642233, 3.3548957901075482, 13.429800812155008, 45.54055631160736, 58.81285272538662, 59.62974049150944, 57.36584097146988, 59.426933974027634, 60.172632560133934, 57.730480805039406, 64.09440591931343, 53.09453196823597, 20.654481388628483, 14.355721827596426, 44.696264415979385, 60.86777865886688, 50.19290506839752, 19.340344704687595, 26.941031254827976, 47.38386020064354, 41.83855555951595, 23.427555486559868, 25.94327699393034, 28.028990775346756, 50.006209686398506, 38.98935064673424, 41.568070873618126, 78.84622514247894, 35.01342639327049, 1.5999297983944416, 0.2202978398418054, 0.18815675983205438, 0.08470351851428859, 0.12344910428510047, 0.13347482919925824, 0.03234222800529096, 0.07030907450825907, 0.017984928490477614, 0.04833640472497791, 0.025682825580588542, 0.04342075619206298, 0.020566557832353283, 0.09821041327086277, 0.1425124512752518, 0.17573323741089553, 0.1288449260755442, 0.22883906902279705, 0.16602897376287729, 0.12935953127453104, 0.23960252583492547, 0.1263127478887327, 0.17233225662494078, 0.1828369710710831, 0.22916870133485645, 0.23166869999840856, 0.103752816648921, 0.20088224729988724, 0.2790533151710406, 0.9604029182810336, 0.20468559087021276, 46.61127805709839, 111.62648856639862, 49.95967738330364, 47.82414257526398, 67.71332412958145, 62.20800094306469, 59.578390046954155, 55.68190053105354, 63.09658706188202, 37.69451692700386, 26.681132800877094, 67.15299859642982, 82.0680570602417, 60.74167102575302, 19.76293332874775, 16.778848953545094, 54.13007900118828, 90.82207292318344, 67.10285648703575, 65.26210606098175, 69.39097970724106, 58.57578344643116, 59.47547256946564, 54.76478174328804, 34.526288732886314, 23.726297356188297, 7.154311677441001, 1.4286296465434134, 2.2453755140304565, 8.670231308788061, 19.174219518899918, 7.86238563247025, 3.3552144980058074, 4.514383859932423, 6.716635012999177, 13.654335513710976, 12.90357369929552, 14.791866224259138, 13.775150030851364, 34.55805882811546, 48.33290107548237, 31.219514273107052, 7.423431761562824, 22.04673808068037, 23.377920649945736, 27.663461789488792, 36.47710405290127, 33.350837007164955, 39.20027732849121, 39.31788481771946, 37.58080042898655, 30.568806789815426, 34.60528649389744, 36.429963782429695, 48.87958914041519, 58.95968444645405, 61.515738889575005, 50.80124482512474, 26.40090923756361, 23.6556838452816, 36.82412043213844, 46.312275901436806, 60.60313045978546, 58.61377000808716, 61.91717974841595, 57.970293536782265, 59.828811809420586, 51.94769650697708, 49.730834662914276, 54.01769623160362, 53.74935083091259, 46.745004281401634, 51.82480350136757, 50.950337424874306, 46.884977370500565, 40.999028608202934, 49.91518177092075, 56.58646859228611, 57.378767877817154, 51.058464422822, 54.06279221177101, 52.11642265319824, 47.138906344771385, 32.09914617240429, 30.51664888858795, 43.070141673088074, 53.32596234977245, 52.83085651695728, 41.7145112156868, 23.990221694111824, 9.887630883604288, 15.754547417163849, 23.32001555711031, 30.67813642323017, 34.86921653151512, 31.195351369678974, 37.75883227586746, 33.76610152423382, 25.38980059325695, 22.462678961455822, 11.38568814843893, 11.832404527813196, 23.6701762676239, 23.60673677176237, 20.696862414479256, 6.864181570708752, 4.866045014932752, 10.041785761713982, 14.550286587327719, 6.981886904686689, 5.603897497057915, 1.9790466176345944, 6.683762026950717, 4.339630762115121, 1.9126631109975278, 0.8225825917907059, 7.566811367869377, 9.547958560287952, 20.068058855831623, 51.88042491674423, 60.81697538495064, 65.80914750695229, 59.97894935309887, 63.76722827553749, 65.67604824900627, 65.04032716155052, 69.5748670399189, 59.99506048858166, 22.145646773278713, 15.264069736003876, 45.682444497942924, 73.73578816652298, 49.37072038650513, 20.989165529608727, 31.27438522875309, 51.89501613378525, 38.11864636838436, 31.906253322958946, 39.958310052752495, 35.84843538701534, 68.59243735671043, 48.6399170011282, 57.7919615060091, 86.55664220452309, 52.154378816485405, 1.8324948940426111, 0.4059661488281563, 0.4872505262028426, 0.15970931912306696, 0.11867532841279171, 0.25609322532545775, 0.11895058356458321, 0.1919122348772362, 0.23365661676507443, 0.17516902706120163, 0.17612644209293649, 0.1385370481875725, 0.16122617991641164], [0.12103531349566765, 0.058788419264601544, 0.08443871280178428, 0.1303871683194302, 0.061117560690036044, 0.0293490981857758, 0.05940782684774604, 0.06170991327962838, 0.03128516109427437, 0.07063209428451955, 0.11455262385425158, 0.1345524424687028, 0.02712639186938759, 0.05429630327853374, 0.04258273416780867, 0.07125057789380662, 0.27610265475232154, 0.11015478288754821, 3.6698513897135854, 68.54060053825378, 46.22939854860306, 36.49655140936375, 50.81590063869953, 81.28095969557762, 56.860236302018166, 46.484490260481834, 42.243230044841766, 40.60184732079506, 14.70839325338602, 27.94343076646328, 61.18530102074146, 62.844789773225784, 36.064487993717194, 19.194215945899487, 35.87034121155739, 52.33105033636093, 54.07174073159695, 47.17170238494873, 58.27854059636593, 37.97852888703346, 31.157277412712574, 48.08993451297283, 43.83567899465561, 22.045641839504242, 3.387494715861976, 0.3895412926794961, 1.161521791946143, 5.269686905667186, 2.2582886461168528, 2.3984020901843905, 1.1492401384748518, 1.3616753392852843, 1.5448072250001132, 5.7590768951922655, 8.938828445971012, 6.272985069081187, 7.726498749107122, 30.3293664380908, 27.84926801919937, 11.125277671962976, 12.114971615374088, 17.954344376921654, 16.77320245653391, 24.1302327811718, 24.51779868453741, 35.95265619456768, 28.23599986732006, 28.384172916412354, 29.258420504629612, 17.225032411515713, 15.756300073117018, 28.828505873680115, 38.327103182673454, 52.11096614599228, 48.124983832240105, 26.690615192055702, 8.144154287874699, 8.212722558528185, 9.912062622606754, 23.843262679874897, 36.99742533266544, 49.219230115413666, 54.7276159375906, 56.7713438719511, 52.141155526041985, 46.572421342134476, 47.098594307899475, 47.014292031526566, 47.4310764670372, 42.218181788921356, 42.240972965955734, 43.06401640176773, 39.91834379732609, 38.47236558794975, 46.402855440974236, 54.199569672346115, 57.24193722009659, 47.66155689954758, 38.04228186607361, 22.21894484013319, 13.225348982959986, 8.757099397480488, 9.77563664317131, 20.158642195165157, 37.452640905976295, 40.15316739678383, 32.977104261517525, 11.269370689988136, 5.483720395714045, 3.7759896693751216, 11.00907040759921, 21.288844048976898, 29.1641266644001, 23.82952641695738, 22.37560473382473, 26.931159384548664, 20.04692818969488, 8.102522771805525, 11.529862862080336, 3.154713031835854, 9.209856502711773, 17.37055890262127, 13.952381070703268, 12.745843213051558, 7.102990681305528, 2.6986828772351146, 2.9216278390958905, 9.541977681219578, 8.131101988255978, 1.420861438382417, 1.5889836545102298, 0.3894218959612772, 0.7006354385521263, 0.5025666730944067, 1.6802559443749487, 6.8693706672638655, 11.826003771275282, 34.55327108502388, 54.73877593874931, 53.179138228297234, 49.890220910310745, 48.65048423409462, 51.65729708969593, 51.28629259765148, 55.82706034183502, 41.35462872684002, 18.193003870546818, 29.434128776192665, 74.74400326609612, 45.68430259823799, 15.639912318438292, 19.12543773651123, 36.06913894414902, 49.769258201122284, 17.89477687329054, 32.64451190829277, 24.64078478515148, 42.382249385118484, 61.26685984432697, 27.399586848914623, 50.69409437477589, 66.16230815649033, 9.547428488731384, 0.9141823172103614, 0.6118244072422385, 0.27436044823843986, 0.09017905438668095, 0.10530983505304903, 0.05772081756731495, 0.14899989066179842, 0.031287231686292216, 0.10965574794681743, 0.06427179963793606, 0.16220064950175583, 0.11457401255029254, 0.12536407535662875, 0.03791003880905919, 0.09763698544702493, 0.043822881489177234, 0.09013940143631771, 0.06541570895933546, 0.05547826993279159, 0.09700892813270912, 0.07949359729536809, 0.06005093491694424, 0.013502889014489483, 0.10039019747637212, 0.06195832866069395, 0.02303815635968931, 0.02466563611960737, 0.09206985370838083, 0.02110018984240014, 0.48331120633520186, 0.17091401241486892, 5.915525425225496, 83.41674908995628, 54.039814844727516, 36.66439600288868, 49.18372482061386, 71.92297384142876, 46.42023950815201, 32.86619961261749, 44.40809927880764, 43.21891888976097, 22.992944307625294, 36.75612308084965, 64.7550916671753, 65.03344193100929, 39.52807813882828, 22.45165765285492, 40.79447418451309, 61.47503927350044, 59.24701362848282, 55.63955940306187, 64.31828990578651, 43.24776314198971, 37.97278359532356, 51.85157686471939, 48.20027679204941, 25.21099168807268, 7.223260877653956, 1.1134049738757312, 1.247146159876138, 5.565571328625083, 3.7695532897487283, 3.1992544792592525, 1.9276225520297885, 1.81301488308236, 1.9648201810196042, 8.282700553536415, 11.738126836717129, 9.46050625294447, 12.47818747535348, 25.78502308577299, 29.329427294433117, 15.779799912124872, 8.766622636467218, 18.93758911639452, 20.88634494692087, 29.51871983706951, 29.84483353793621, 40.000225603580475, 32.45020933449268, 33.705927953124046, 34.77348446846008, 24.774241223931313, 20.469628907740116, 31.732270158827305, 42.393192797899246, 54.9829888343811, 58.450393974781036, 39.50438641011715, 15.542919673025608, 12.978846710175276, 19.102125987410545, 34.24265295267105, 48.38014014065266, 55.63202440738678, 59.0755782276392, 64.00466233491898, 56.720890179276466, 51.61907874047756, 51.850121542811394, 51.54402136802673, 52.196431159973145, 48.66451308131218, 48.09437647461891, 50.6266213953495, 44.835473746061325, 42.052354887127876, 51.46481841802597, 58.62244114279747, 60.880481377243996, 51.18535481393337, 48.952970802783966, 40.5110739916563, 25.863053798675537, 18.42716820538044, 20.383384935557842, 32.76374191045761, 47.56699897348881, 47.218629866838455, 37.84399710595608, 14.551473073661327, 6.7678700387477875, 7.439410854130983, 16.7708370834589, 29.12367593497038, 33.258148580789566, 28.913349620997906, 28.715999610722065, 31.945357024669647, 20.949881337583065, 11.308943666517735, 6.911071529611945, 8.684455845505, 14.761581849306822, 16.960131525993347, 15.855712238699198, 7.892859047278762, 10.151670165359974, 6.449447125196457, 8.895701710134745, 16.92229885607958, 14.155565667897463, 2.8534255363047123, 2.1716361958533525, 0.2162183728069067, 0.6601728941313922, 0.4259081615600735, 1.79547063075006, 4.299601335078478, 12.434353977441788, 39.23675537109375, 58.94190900027752, 58.331627547740936, 54.58712227642536, 54.222053065896034, 58.45375679433346, 57.017684653401375, 61.33024804294109, 45.53446523845196, 17.708125188946724, 29.5955441147089, 67.27766990661621, 46.7305688560009, 23.07551007717848, 23.209074810147285, 32.97950193285942, 55.03673315048218, 31.989662647247314, 25.925051271915436, 27.654767856001854, 33.598332926630974, 63.81981745362282, 28.190453611314297, 53.90617221593857, 74.75778132677078, 12.98533771187067, 0.5561740777920932, 0.4296387895010412, 0.26432598824612796, 0.09524853900074959, 0.12345634022494778, 0.09871815360384062, 0.05674414009263273, 0.026016819865617435, 0.03105733103438979, 0.027334350925229955, 0.012816956241294974, 0.09841755410889164, 0.03977408370701596, 0.23200499679660425, 0.11027514439774677, 0.2663070772541687, 0.26677017740439624, 0.17684775026282296, 0.20431454671779647, 0.1475476412451826, 0.2175594781874679, 0.17255807731999084, 0.13454421947244555, 0.2500527666416019, 0.2412925148382783, 0.18179131468059495, 0.2284427621634677, 0.25899941625539213, 0.16571740532526746, 0.7722596358507872, 0.1595564218587242, 9.843387957662344, 100.33005192875862, 60.896413922309875, 46.527975127100945, 64.21414509415627, 97.31014117598534, 82.12580636143684, 56.911104172468185, 58.40924598276615, 54.95197109878063, 19.482295587658882, 34.95133392512798, 67.66521871089935, 72.22685873508453, 46.41901597380638, 26.013725213706493, 45.29826231300831, 63.98184835910797, 64.83468979597092, 62.43411161005497, 70.37609204649925, 48.466927483677864, 39.98038686811924, 55.67292161285877, 52.11785137653351, 29.254624508321285, 8.475143127143383, 1.9941370328888297, 1.669185000937432, 7.989483587443829, 6.802067728713155, 5.270999735221267, 2.565976185724139, 3.7268383568152785, 2.8347730496898293, 10.383118595927954, 16.842985711991787, 10.358841698616743, 14.440125748515129, 35.67936345934868, 37.63128452003002, 18.41107226908207, 16.289805695414543, 25.900060012936592, 22.370093129575253, 33.794577196240425, 35.57559862732887, 45.30329704284668, 37.42521017789841, 38.02004545927048, 41.428842544555664, 27.146579325199127, 22.232677303254604, 35.141335129737854, 48.17142874002457, 56.08928807079792, 58.81239674985409, 50.06861373782158, 25.461573041975498, 24.011143371462822, 36.2908760458231, 48.599844351410866, 57.97441631555557, 59.4637805968523, 59.675049260258675, 62.427188381552696, 55.41994258761406, 51.51288963854313, 53.56085814535618, 53.0239849537611, 54.11215536296368, 48.56556259095669, 50.33691734075546, 53.890194073319435, 47.231853157281876, 43.641817197203636, 50.56449092924595, 56.4013197273016, 61.02531440556049, 52.42585524916649, 56.95758707821369, 51.16621524095535, 38.77055838704109, 29.180545583367348, 31.39371022582054, 42.121632769703865, 56.57459422945976, 50.03889933228493, 40.79803839325905, 20.690378062427044, 10.552992280572653, 9.921502266079187, 19.857519753277302, 31.25152375549078, 37.47921667993069, 33.63438539206982, 33.02247002720833, 38.12306933104992, 26.921597197651863, 15.652819275856018, 22.29381412267685, 7.538107233121991, 16.018196269869804, 22.990635931491852, 21.168787591159344, 20.402646102011204, 9.021419864147902, 3.1048801308497787, 4.458932485431433, 14.761493504047394, 13.979289326816797, 2.992543908767402, 4.572521690279245, 1.5846641175448895, 1.4981586718931794, 1.723204089794308, 4.373317854478955, 11.107445228844881, 15.647309571504593, 42.25384287536144, 59.57299813628197, 62.81665228307247, 58.54699619114399, 61.15243658423424, 60.896174535155296, 61.84736609458923, 65.86843192577362, 52.83977083861828, 20.822344981133938, 33.418245390057564, 78.58776301145554, 52.81399682164192, 20.451218895614147, 28.26463893055916, 38.259482011199, 60.86713649332523, 25.883297212421894, 43.27201724052429, 39.53523315489292, 53.34065996110439, 76.1122490465641, 39.58283320069313, 66.31911814212799, 87.21666678786278, 20.260186046361923, 1.2423913087695837, 0.8890365727711469, 0.5526073754299432, 0.29981721192598343, 0.1577910454943776, 0.15711916435975581, 0.16591422288911417, 0.16497809265274554, 0.22724840906448662, 0.2518464782042429, 0.36033392243552953, 0.13674952613655478, 0.21499439317267388], [0.019892659911420196, 0.08931307194870897, 0.06047239316103514, 0.035344241332495585, 0.05265679516014643, 0.07844861625926569, 0.0408497970784083, 0.05548192129936069, 0.04794848784513306, 0.004579555361488019, 0.10371644399128854, 0.08147857515723445, 0.15167653531534597, 0.0757336025708355, 0.03408425269299187, 0.13498765270924196, 0.10242757096420974, 0.3719932702369988, 0.2468099375255406, 52.354472279548645, 54.681391417980194, 79.41902160644531, 84.11044746637344, 51.43891900777817, 54.53607201576233, 44.21895682811737, 41.61407880485058, 40.12877270579338, 21.63271989673376, 23.429115302860737, 56.917054653167725, 58.52838099002838, 62.133847922086716, 21.294408850371838, 19.403335824608803, 42.614644914865494, 67.54331365227699, 57.6227717846632, 51.14234872162342, 39.706121385097504, 33.12453635036945, 38.1709049642086, 44.72320877015591, 21.42083376646042, 7.645367402583361, 0.8946508902590722, 1.7965203244239092, 0.876966817304492, 1.04744573822245, 0.3481657581869513, 1.2862407183274627, 0.1515646936604753, 2.444288902916014, 9.294877890497446, 4.970527533441782, 0.5671042506583035, 13.235408943146467, 23.86407796293497, 20.396574027836323, 16.377069912850857, 16.207946687936783, 19.131813794374466, 20.40064360946417, 22.87279285490513, 33.826837465167046, 38.63008372485638, 27.393047399818897, 22.79686152935028, 25.02474658191204, 13.121314365416765, 14.430477116256952, 23.418470174074173, 37.60388419032097, 56.04454167187214, 51.68192356824875, 26.842407546937466, 10.01162962988019, 7.73668410256505, 9.602016359567642, 23.25766660273075, 39.67836767435074, 48.05275350809097, 51.606474816799164, 57.53411114215851, 52.7508670091629, 47.480823397636414, 46.52791053056717, 47.882313653826714, 47.43950441479683, 42.86157466471195, 43.97791676223278, 44.78693135082722, 40.755818858742714, 39.772982597351074, 46.64283536374569, 54.872395768761635, 52.615020498633385, 49.7527214884758, 32.515030056238174, 16.586543172597885, 11.150305029004812, 7.256447346881032, 11.729161217808723, 23.300442807376385, 38.60486067831516, 41.556629687547684, 29.8827688023448, 15.979875326156616, 15.303653161972761, 11.519837100058794, 7.986044771969318, 21.93628180772066, 27.374515794217587, 22.96557627618313, 20.98757341504097, 20.79981029033661, 20.228151865303516, 8.117683958262205, 7.96232501976192, 10.233741961419582, 2.826878735795617, 14.477436896413565, 10.920235924422741, 10.547684915363789, 19.94294486939907, 16.491154991090298, 9.859180860221386, 2.3311651730909944, 1.3822596659883857, 2.289392352104187, 1.9639906380325556, 0.284809204749763, 0.26429268065840006, 0.2711481956066564, 1.035704487003386, 1.256913891993463, 15.497664101421833, 37.221799492836, 54.3050330132246, 49.08427655696869, 47.22813315689564, 46.561736315488815, 51.504241302609444, 50.45052744448185, 56.550826504826546, 46.27500370144844, 35.12965835630894, 58.814718425273895, 61.501102074980736, 42.836211025714874, 18.975854963064194, 23.037559613585472, 45.953651145100594, 41.82769574224949, 16.350855119526386, 33.74054029583931, 20.3138467669487, 60.83705730736256, 42.310399040579796, 36.48862883448601, 63.63439500331879, 50.45398145914078, 2.3143460880964994, 0.3183483425527811, 0.33833693247288465, 0.12801864853827283, 0.24270842870464548, 0.061287564458325505, 0.09563100480590947, 0.12187462314614095, 0.026413226914883126, 0.07269830020959489, 0.08860883317538537, 0.08615068421931937, 0.028896174735564273, 0.014482918213616358, 0.08200829790439457, 0.036136654671281576, 0.04404683568282053, 0.032480731315445155, 0.015246404491335852, 0.046118010286591016, 0.009874282259261236, 0.06078610269469209, 0.09238967482815497, 0.07929221552331, 0.024404500327364076, 0.014178409455780638, 0.07658808914129622, 0.1165276049869135, 0.07010530302068219, 0.07786126574501395, 0.05273627546557691, 0.3515138238435611, 0.4276616784045473, 63.906065225601196, 66.07675194740295, 76.66426822543144, 83.17061349749565, 56.99042871594429, 51.14283889532089, 29.09963082522154, 41.05556957423687, 45.39236046373844, 26.11336536705494, 33.754641339182854, 69.15162295103073, 63.77921283245087, 63.27284060418606, 28.304474093019962, 23.342683240771294, 47.25476212799549, 71.09462589025497, 63.99582400918007, 60.66387020051479, 46.582908779382706, 33.5946661233902, 46.43585667014122, 50.768122002482414, 24.359607473015785, 9.905989598482847, 2.6492499047890306, 3.4700505109503865, 0.4275704832980409, 1.8290108372457325, 0.744337368523702, 2.0806997129693627, 1.121695654001087, 5.3878862131386995, 12.508569695055485, 11.216040551662445, 4.490220956504345, 10.81666773185134, 20.344062745571136, 24.932016357779503, 16.053709164261818, 13.942090272903442, 20.502844825387, 26.355685964226723, 27.88263212889433, 37.111415416002274, 40.89653290808201, 31.54127150774002, 30.35995289683342, 30.839190781116486, 19.702514670789242, 15.704184919595718, 28.006015308201313, 41.08203135430813, 54.46742869913578, 59.29556742310524, 37.622883170843124, 15.604965593665838, 11.673255767673254, 18.602416701614857, 34.68390427529812, 48.23778837919235, 57.815159261226654, 57.72714838385582, 63.20931561291218, 58.32403935492039, 51.186779737472534, 49.53677147626877, 52.433990612626076, 51.577577367424965, 49.58232343196869, 49.76586878299713, 49.6965529024601, 46.802278608083725, 40.748926028609276, 47.94428072869778, 58.969826102256775, 57.907505705952644, 55.54755873978138, 46.32918879389763, 36.19287170469761, 22.035351991653442, 16.7760257050395, 19.522620923817158, 34.72351334989071, 45.5545699596405, 51.51836894452572, 36.885502338409424, 16.789919659495354, 17.094157934188843, 14.719135276973248, 15.668206550180912, 28.15464623272419, 30.65753772854805, 27.47162338346243, 27.951735220849514, 29.886505901813507, 22.418399937450886, 11.294963266700506, 6.1304528173059225, 11.270256992429495, 8.580767959356308, 15.1775455288589, 12.879058364778757, 8.991492670029402, 18.661877810955048, 19.402953945100307, 12.501639816910028, 5.911956941708922, 5.918692080304027, 6.423060391098261, 6.008501686155796, 1.2799841165542603, 0.8904267044272274, 0.029545108664024156, 0.8844681491609663, 0.46405891596805304, 15.757714547216892, 40.82875594496727, 58.20863954722881, 54.2119076102972, 50.62630221247673, 53.818127140402794, 55.612520053982735, 59.153823629021645, 62.53808543086052, 49.02206629514694, 33.72392758727074, 57.35601469874382, 60.715570226311684, 49.09830920398235, 21.00920755416155, 24.769544675946236, 40.531843677163124, 57.0183952152729, 23.35280019789934, 30.78271821141243, 22.39224784076214, 50.45903518795967, 52.29930303990841, 36.810520961880684, 72.84435600042343, 56.200975477695465, 2.18203148804605, 0.16086325485957786, 0.30758613254874945, 0.12058675943990238, 0.1731274530175142, 0.03228204725019168, 0.0695777176588308, 0.023946958863234613, 0.011534144705365179, 0.12297948807827197, 0.06506315170554444, 0.0594791657931637, 0.0023667942878091708, 0.01576735969138099, 0.19188192556612194, 0.1493343320908025, 0.22168719966430217, 0.15595713921356946, 0.18299383140401915, 0.13830794719979167, 0.1154056929226499, 0.09089245868381113, 0.16507577412994578, 0.09636791291995905, 0.21426168561447412, 0.1597942505031824, 0.5690117483027279, 0.11527624010341242, 0.22862604295369238, 0.24809716298477724, 0.4469095158856362, 0.31052536389324814, 1.6059400071389973, 79.40139055252075, 76.73762708902359, 85.53005889058113, 93.15377220511436, 60.96476465463638, 73.95209535956383, 63.09917852282524, 54.58454601466656, 61.987855955958366, 26.122418381273746, 29.469457380473614, 65.17415598034859, 67.20642372965813, 71.99987411499023, 30.846708677709103, 24.379210621118546, 54.522031769156456, 78.57653081417084, 67.32991710305214, 64.60131391882896, 50.21547585725784, 39.15601350367069, 52.43049480021, 54.66781474649906, 31.177670918405056, 14.19163903221488, 4.605349553748965, 4.744755048304796, 3.0197473615407944, 3.1276261853054166, 1.2591526843607426, 3.1009140936657786, 1.5519687719643116, 5.655948054045439, 15.002916399389505, 9.562392085790634, 3.4782340843230486, 19.868421368300915, 29.741834364831448, 30.28915509581566, 22.713970877230167, 22.793897688388824, 25.16383431851864, 28.351728357374668, 30.288039855659008, 42.290708497166634, 48.5904436558485, 34.35380078852177, 35.37440702319145, 34.06318478286266, 22.316588200628757, 22.06034705042839, 32.27136433124542, 45.87520055472851, 57.24718853831291, 62.86744795739651, 48.854476287961006, 27.357490807771683, 21.40189368277788, 31.266850233078003, 47.764535173773766, 56.24201327562332, 60.67981794476509, 56.10260635614395, 60.67359767854214, 57.56696417927742, 51.48013539612293, 52.15785562992096, 54.25548367202282, 52.79960319399834, 48.28275516629219, 53.959996327757835, 55.901513546705246, 50.21574184298515, 42.9460783302784, 48.653284683823586, 57.65159323811531, 56.96044832468033, 58.9533843845129, 52.0846563577652, 49.533028677105904, 34.42147895693779, 26.642401479184628, 32.58569486439228, 50.696469247341156, 51.32984586060047, 55.56523539125919, 38.33517774939537, 24.189285412430763, 24.065978229045868, 17.846939340233803, 13.982440307736397, 32.51039430499077, 34.97334614396095, 34.522952511906624, 33.463728949427605, 35.24208292365074, 26.730963326990604, 15.135875064879656, 17.784077413380146, 21.23017519712448, 7.364830831065774, 21.110770404338837, 16.607459150254726, 20.34454721957445, 28.574303314089775, 22.17390775680542, 11.581804174929857, 3.19246519356966, 3.783473842777312, 3.2216279162093997, 6.10817888751626, 1.4245641021989286, 1.2050510686822236, 0.5608643917366862, 2.66646393109113, 3.2238624338060617, 18.31845223903656, 46.66418641805649, 60.165439546108246, 61.58238351345062, 53.60369324684143, 57.580233067274094, 62.21252270042896, 62.839215472340584, 67.12308660149574, 57.26591773331165, 39.23650838434696, 66.63144618272781, 68.72410029172897, 50.423366501927376, 22.22038496285677, 31.13722588866949, 46.93621762096882, 56.6271910071373, 20.697181597352028, 47.10577592253685, 30.96644215285778, 71.24311432242393, 61.12004712224007, 48.44426929950714, 82.8292778134346, 69.4100546836853, 4.5119325164705515, 0.2040992199908942, 0.5129677837248892, 0.1522317063063383, 0.39868333493359387, 0.1675304869422689, 0.18967120122397318, 0.12014007559628226, 0.15025383821921423, 0.1941115895169787, 0.15586025925586, 0.1789323688717559, 0.05301482575305272, 0.09365866571897641], [0.07530582122853957, 0.11075818605604582, 0.04513317660894245, 0.05316389353538398, 0.06663553998805583, 0.03171127260429785, 0.05926424724748358, 0.010062122619274305, 0.06610425130929798, 0.032528529336559586, 0.06764837118680589, 0.28508463059552014, 0.03521568280120846, 0.19815982697764412, 0.028399349539540708, 0.1449660657090135, 0.0051332453040231485, 0.7767401298042387, 0.1754403265658766, 26.12627137452364, 61.97709873318672, 61.213548704981804, 95.53582638502121, 38.42271365225315, 48.7428230792284, 46.46574206650257, 41.39795020222664, 39.81726922094822, 35.33255226910114, 15.435183104127645, 20.29474899172783, 44.50817830860615, 67.15106070041656, 43.49267520010471, 22.323530428111553, 33.526311591267586, 62.2909314930439, 53.79205293953419, 52.832342237234116, 42.88240894675255, 38.810589239001274, 49.72534395754337, 51.01489216089249, 29.195393286645412, 12.972488701343536, 3.0988220684230328, 0.3325536131160334, 0.06745590260834433, 0.9850874030962586, 0.2607138961320743, 0.7708605984225869, 1.0381488245911896, 6.261370042338967, 4.901650529354811, 2.0263414923101664, 7.434372324496508, 17.529682964086533, 15.103997625410557, 16.298588924109936, 15.7790732011199, 12.379484921693802, 19.570194371044636, 18.992853350937366, 29.267342425882816, 35.19247658550739, 30.563770160079002, 26.656109243631363, 19.972860664129257, 16.398259475827217, 12.444117553532124, 13.419635407626629, 19.842132478952408, 33.00107717514038, 50.52149623632431, 51.048136577010155, 30.338793732225895, 10.839766692370176, 8.469050154089928, 10.805639773607254, 24.24850143492222, 37.53424532711506, 51.573298797011375, 54.16615426540375, 56.68582186102867, 53.694071397185326, 47.777370885014534, 48.16711977124214, 49.506266713142395, 49.61100049316883, 41.78924560546875, 45.13171344995499, 44.40410189330578, 43.382047936320305, 37.74716690182686, 44.64855417609215, 55.123246908187866, 56.97445057332516, 44.513406828045845, 23.721597008407116, 12.603247314691544, 9.618486575782299, 5.4557553213089705, 13.210053853690624, 29.96775884181261, 44.446750804781914, 42.77906969189644, 31.45217388868332, 12.915677949786186, 3.0934154335409403, 8.991735856980085, 6.895535588264465, 18.8317533954978, 27.51015141606331, 24.769550375640392, 19.571343809366226, 21.851529255509377, 15.850730706006289, 8.328660037368536, 4.139376757666469, 9.366340655833483, 4.406948424875736, 8.8837874494493, 10.26575904339552, 8.032551426440477, 17.32878014445305, 19.136873222887516, 22.761038951575756, 17.922815568745136, 8.167117405682802, 2.4995182268321514, 2.5938818883150816, 3.2839103741571307, 0.10357260092860088, 0.8683759532868862, 0.9374836168717593, 1.637019133195281, 12.347461190074682, 37.786259204149246, 54.82218526303768, 48.85840907692909, 53.27139347791672, 51.14440441131592, 50.85486374795437, 44.415581077337265, 59.6541465818882, 46.66548974812031, 55.728843212127686, 62.33171470463276, 54.02390129864216, 39.20724235475063, 24.941827431321144, 26.74918904900551, 48.653113692998886, 22.907245606184006, 28.564680330455303, 29.828528612852097, 27.499804571270943, 61.02976776659489, 30.89773613959551, 47.30892442166805, 63.51002387702465, 22.04367734491825, 1.012424798682332, 0.4655931133311242, 0.3186618257313967, 0.07856191252358258, 0.06273740189499222, 0.09438384047825821, 0.14586905163014308, 0.0465394722414203, 0.02542782178352354, 0.0019920433396691806, 0.07929277213406749, 0.05224580490903463, 0.016076948450063355, 0.08446685504168272, 0.03399810419068672, 0.04694129696872551, 0.07553544171969406, 0.016578853646933567, 0.06085353423259221, 0.01515992666099919, 0.041910541331162676, 0.05781174550065771, 0.030488521224469878, 0.07419590969220735, 0.07163235350162722, 0.06361896201269701, 0.04421845733304508, 0.1534775792970322, 0.04307634771976154, 0.08853860374074429, 0.0602905447158264, 0.7140636211261153, 0.17068795423256233, 36.1249465495348, 72.48961463570595, 67.74999976158142, 92.58051976561546, 44.59614738821983, 50.84301598370075, 33.615451008081436, 36.40652284026146, 45.34555837512016, 35.01232825219631, 27.111222222447395, 30.78392654657364, 47.27790668606758, 69.37434419989586, 46.62692941725254, 23.673368096351624, 32.725698351860046, 66.78100615739822, 57.366832718253136, 55.322808399796486, 49.21516053378582, 43.40501010417938, 58.11765342950821, 56.133882477879524, 31.41670849174261, 13.866293840110302, 4.478946961462498, 0.6627108016982675, 0.16619273606920615, 1.5135086607187986, 0.6122871511615813, 1.8791187484748662, 3.164853025227785, 9.124498832970858, 12.830523569136858, 7.1064874436706305, 7.97070974484086, 14.567430317401886, 20.54167114198208, 22.180002629756927, 16.938066110014915, 11.87882948666811, 23.62140778452158, 23.991097547113895, 34.45440798997879, 41.13022416830063, 36.707918867468834, 32.355472818017006, 26.32611785084009, 20.804780423641205, 20.64036324620247, 17.070544101297855, 23.004700876772404, 37.983350828289986, 55.10716997087002, 60.6804259121418, 39.79882501065731, 17.513967007398605, 12.233045529574156, 18.0872992426157, 35.771808698773384, 48.84842701256275, 57.676474303007126, 60.811089500784874, 61.1743576079607, 57.581931576132774, 49.94854398071766, 52.719594687223434, 55.37535957992077, 52.51560263335705, 52.62910254299641, 50.37077732384205, 51.448296904563904, 46.214792132377625, 39.88371625542641, 47.7372944355011, 59.01309818029404, 58.6363559961319, 54.68129262328148, 46.3535188883543, 29.825570471584797, 18.00761751830578, 15.991992875933647, 23.894233144819736, 38.57212923467159, 52.78780862689018, 51.658870205283165, 34.05377268791199, 17.51458067446947, 7.865029815584421, 13.021665662527084, 11.100474502891302, 26.04465175420046, 32.62188792228699, 34.0825941413641, 25.82030989229679, 26.185069419443607, 19.066202715039253, 10.884376298636198, 4.413210488855839, 9.455041196197271, 9.29720051586628, 11.133077703416348, 11.693380437791348, 8.032798413187265, 12.472763266414404, 16.91810578107834, 21.938276700675488, 21.542360745370388, 13.858165126293898, 7.181958518922329, 7.226679744198918, 7.019588006660342, 0.35724002751521766, 1.4240280934609473, 2.0124537125229836, 0.9775974112562835, 13.801579512655735, 42.91952155530453, 58.51496011018753, 53.68345096707344, 58.72460626065731, 54.97190102934837, 59.1655346006155, 52.78284229338169, 63.0204239487648, 51.65605075657368, 57.427097484469414, 62.85994715988636, 56.03556275367737, 45.17310082912445, 26.329045593738556, 25.98180502653122, 47.867042273283005, 39.517381712794304, 21.74297098070383, 34.20827619731426, 25.969163104891777, 60.73224373161793, 35.51380634307861, 48.063259944319725, 75.21491199731827, 26.10606785863638, 0.6742581445723772, 0.3602138429414481, 0.18021940137259662, 0.1510843905271031, 0.02842932488420047, 0.08850482117850333, 0.06598852080060169, 0.051790256111416966, 0.11236391903366894, 0.05291859146382194, 0.030609188870585058, 0.004530312935457914, 0.01799694015062414, 0.04271050973329693, 0.20619822142180055, 0.33362497750204057, 0.1597198873059824, 0.11930520398891531, 0.2123301275423728, 0.09951758023817092, 0.1542016037274152, 0.12267847298062406, 0.12998266814975068, 0.18850739492336288, 0.2624005899997428, 0.27441210171673447, 0.23250621365150437, 0.3324349585454911, 0.07622691555297934, 0.24581179342931136, 0.16032230341807008, 0.7161373004782945, 0.2107414713827893, 49.27550129592419, 84.51505735516548, 74.5774582028389, 100.5783762037754, 51.48451656103134, 62.22486063838005, 69.40409660339355, 54.13677044212818, 62.52638205885887, 43.4651342779398, 21.175560727715492, 25.39151430130005, 49.765750989317894, 85.27342826128006, 52.912073358893394, 30.767357535660267, 39.494237154722214, 75.59089422225952, 63.55643078684807, 60.83230756223202, 51.35884590446949, 43.73372286558151, 64.43854585289955, 63.53679724037647, 37.573474422097206, 19.34642817825079, 10.289758555591106, 1.9761826400645077, 0.22331349755404517, 2.8661026060581207, 1.6678145807236433, 1.9295869278721511, 3.580930936150253, 11.414571348577738, 9.56112865358591, 3.627244750969112, 11.305106822401285, 26.64509743452072, 24.09639559686184, 25.815406255424023, 24.548679627478123, 17.686183266341686, 26.674154475331306, 27.389973364770412, 39.86284397542477, 47.34005995094776, 41.50225080549717, 37.58576676249504, 29.971501640975475, 24.731022343039513, 21.616603061556816, 22.073163762688637, 25.418730340898037, 41.487815380096436, 53.18386137485504, 61.48315563797951, 51.69315956532955, 33.29943336546421, 23.368776440620422, 33.515865951776505, 47.66922488808632, 56.04363352060318, 62.445039823651314, 59.04545724391937, 58.558878153562546, 60.42635254561901, 51.84315651655197, 57.01022565364838, 59.04926083981991, 56.32562778890133, 52.065034210681915, 54.880044758319855, 54.608572125434875, 52.226882725954056, 42.15633250772953, 49.29399110376835, 57.16483175754547, 59.12790521979332, 58.94539721310139, 50.733977034687996, 42.34143577516079, 28.12222257256508, 29.474756196141243, 35.45470051467419, 48.98819111287594, 56.83025971055031, 52.45348736643791, 38.16577523946762, 18.259853683412075, 12.35477389767766, 11.472608484327793, 12.162388321012259, 28.677927553653717, 40.679294764995575, 41.73059195280075, 35.382443591952324, 28.59894309192896, 23.044707030057907, 15.40113978087902, 11.053332332521677, 20.215538442134857, 11.21445793658495, 15.438735913485289, 15.596789382398129, 15.919885095208883, 26.689247265458107, 23.9130687341094, 28.213715963065624, 21.67051836848259, 10.482028238475323, 3.636495117098093, 4.524097563698888, 4.456756627187133, 0.4408910544589162, 1.4136804174631834, 3.116481858305633, 2.477076156064868, 15.533322338014841, 42.86413952708244, 61.396030113101006, 56.785030737519264, 63.19719046354294, 59.98024508357048, 61.55361905694008, 53.165667951107025, 72.28545919060707, 55.97117140889168, 63.90909746289253, 66.77937224507332, 64.03810814023018, 46.123186647892, 32.55546748638153, 30.495694912970066, 54.6352618932724, 35.39063975214958, 35.40562614798546, 46.000909209251404, 38.2967884093523, 73.71794432401657, 43.91347602009773, 58.90652909874916, 88.64900752902031, 34.63470071554184, 1.4795695943757892, 0.49343430844601244, 0.312636299058795, 0.13404775236267596, 0.18190091504948214, 0.13968172192107886, 0.1967857257113792, 0.10548578342422843, 0.20388439792441204, 0.0978252015192993, 0.24770872289082035, 0.1326542958850041, 0.12726823333650827, 0.18309460021555424], [0.08227152284234762, 0.04369096473965328, 0.027449602748674806, 0.0397343491204083, 0.08212936445488594, 0.07683381423703395, 0.028315787421888672, 0.02448285071295686, 0.026024347098427825, 0.008429663976130541, 0.07235921293613501, 0.08585801828303374, 0.05363434465834871, 0.0948962637630757, 0.054261982659227215, 0.06439375676563941, 0.12218452917295508, 0.21518426423426718, 0.12051392506691627, 6.857467330992222, 64.94704976677895, 54.2949141561985, 60.805765986442566, 42.54464127123356, 44.5185137540102, 41.897760182619095, 45.64782075583935, 36.515337601304054, 50.52251078188419, 21.6200190782547, 24.600867927074432, 59.73824746906757, 66.97310104966164, 63.36302876472473, 34.26340363919735, 33.731762766838074, 46.280110627412796, 52.191913202404976, 63.149689212441444, 30.58008648455143, 17.742213159799576, 42.76359312236309, 43.26460003852844, 27.26833999156952, 6.138148354366422, 3.1335372431203723, 1.3166073826141655, 0.32420370960608125, 0.9306131105404347, 1.3520523556508124, 1.1644815956242383, 5.070154862478375, 6.034360723569989, 5.276666656136513, 11.56339606270194, 13.84415527805686, 11.1538958363235, 9.40505487844348, 19.645268842577934, 17.7938561886549, 13.674648273736238, 16.457942873239517, 26.386473812162876, 32.954096496105194, 32.485068663954735, 35.82969479262829, 26.120598278939724, 16.53718762099743, 13.221895918250084, 6.483157016336918, 4.7989054676145315, 11.768459659069777, 23.02054412662983, 46.51606276631355, 55.82406610250473, 39.296339973807335, 16.323652379214764, 9.654718581587076, 9.73829984664917, 21.527944318950176, 39.38236355781555, 48.53983797132969, 54.27235096693039, 59.35503423213959, 55.09210757911205, 49.862497597932816, 45.385855212807655, 49.16977196931839, 49.51842226088047, 41.036494597792625, 48.25194261968136, 44.99831400811672, 44.684378653764725, 39.01214562356472, 47.692829221487045, 58.59164759516716, 56.22965633869171, 38.50145682692528, 18.521919921040535, 11.535227224230766, 7.883517248556018, 6.654246635735035, 18.58066286891699, 34.60809454321861, 47.16564550995827, 42.495243921875954, 31.420375294983387, 9.289938155561686, 5.006883507594466, 11.938522383570671, 12.811173107475042, 14.229602795094252, 23.93837347626686, 26.22662588953972, 20.68078737705946, 23.063329830765724, 17.029432207345963, 9.19248953461647, 3.815757860429585, 5.335034849122167, 8.54689372703433, 8.487453516572714, 11.255802568048239, 7.143456609919667, 16.406518332660198, 23.157150596380234, 18.192006424069405, 16.413635350763798, 15.312186554074287, 10.537407416850328, 4.597037499770522, 3.5931943031027913, 1.5884485957212746, 0.49690381914842874, 0.2189736405853182, 0.40251744794659317, 12.62811603024602, 40.507285594940186, 46.9732466340065, 41.16670981049538, 47.573154643177986, 58.58033560216427, 39.87857513129711, 41.66351415216923, 61.93595454096794, 58.25549103319645, 60.930748879909515, 55.15446223318577, 58.416135013103485, 38.573854342103004, 20.44182199984789, 36.83251418173313, 45.52328623831272, 13.843951988965273, 36.1888363212347, 20.907906889915466, 42.886068150401115, 49.66727927327156, 30.833897665143013, 57.85566508769989, 57.09518909454346, 3.9397345203906298, 0.1763166396995075, 0.31419195933267474, 0.398133551934734, 0.16714768717065454, 0.11991595441941172, 0.0725911340850871, 0.043080963878310286, 0.16235703486017883, 0.019630138158390764, 0.033108076167991385, 0.04782843061548192, 0.03962412534747273, 0.05810019974887837, 0.07861056030378677, 0.12714325566776097, 0.05300915574480314, 0.04336348836659454, 0.017593660813872702, 0.14276490022893995, 0.012780066863342654, 0.038829348268336616, 0.036968988133594394, 0.07210881231003441, 0.1212865898560267, 0.025220990792149678, 0.18287629005499184, 0.08446293650195003, 0.0543660948460456, 0.023072840631357394, 0.12352573845419101, 0.01806864089303417, 0.34929174464195967, 0.09593353388481773, 11.244335733354092, 78.23681384325027, 63.25661927461624, 69.54614818096161, 48.76788653433323, 56.74376115202904, 43.658418506383896, 30.509079694747925, 43.860081285238266, 46.23583920300007, 31.224723793566227, 30.294907987117767, 62.82303974032402, 71.06631740927696, 64.46619316935539, 40.071604773402214, 37.843807116150856, 51.95221446454525, 56.57187357544899, 69.64305818080902, 39.99380774796009, 24.173696748912334, 52.763543128967285, 51.13704040646553, 29.940972179174423, 6.335714953020215, 2.7390754222869873, 1.7996884044259787, 1.0131023498252034, 0.9481932234484702, 2.8744018357247114, 4.48784370906651, 8.92227178439498, 16.086089126765728, 11.584967505186796, 11.911744270473719, 9.140339232981205, 16.932852789759636, 18.34762517362833, 27.795975878834724, 20.765995904803276, 14.592162240296602, 20.65765041857958, 29.270310066640377, 39.48287196457386, 36.25224731862545, 41.77669107913971, 33.24319638311863, 22.808097526431084, 17.5144761800766, 10.502946116030216, 6.428285110741854, 16.712187230587006, 31.342108994722366, 50.540168434381485, 64.33836802840233, 48.57072651386261, 21.120560579001904, 13.426126409322023, 16.782209873199463, 34.08870801329613, 47.80910298228264, 58.405974358320236, 60.52990458905697, 62.2547460347414, 59.39343877136707, 50.43773353099823, 50.072888508439064, 54.30663652718067, 55.484903901815414, 49.104974046349525, 54.53337036073208, 52.325780019164085, 48.268661722540855, 41.12585820257664, 47.50318139791489, 56.98634393513203, 61.474784687161446, 53.13917577266693, 37.23830580711365, 24.495093002915382, 17.231218479573727, 16.154664047062397, 26.618225276470184, 43.322501331567764, 55.24981431663036, 47.13699884712696, 35.675689056515694, 14.143889844417572, 5.980536611750722, 10.103892479091883, 15.563687458634377, 19.64599460363388, 27.695533968508244, 30.742263682186604, 23.474306277930737, 23.660507686436176, 19.4864259660244, 10.692559741437435, 5.2162940707057714, 4.2816900461912155, 7.468093615025282, 11.564556900411844, 13.450552448630333, 11.431568786501884, 8.952540010213852, 12.796505894511938, 9.390223324298859, 11.577480006963015, 16.525717936456203, 17.2739851847291, 10.64699163660407, 10.391780231148005, 5.845118528231978, 1.449675529729575, 1.0660471650771797, 0.6853319378569722, 12.446805909276009, 43.618038073182106, 52.46463596820831, 46.54193937778473, 53.28656226396561, 62.09646932780743, 42.38387189805508, 43.53523291647434, 69.2386382818222, 60.65946623682976, 63.51524479687214, 59.02471035718918, 65.08573472499847, 45.457268580794334, 26.013917103409767, 34.952321872115135, 55.76305277645588, 21.57101310789585, 27.967105396091938, 26.765005700290203, 33.24347376823425, 58.96629989147186, 31.85736134648323, 64.03770536184311, 70.06222888827324, 5.468908790498972, 0.026334650174248964, 0.09798954270081595, 0.17102134181186557, 0.09022562415339053, 0.0316740130801918, 0.05808552377857268, 0.012319588349782862, 0.13668721541762352, 0.04758058668812737, 0.10375692814704962, 0.06134630173619371, 0.04695003946835641, 0.013082517089060275, 0.05519379359611776, 0.31474310788325965, 0.1808845141204074, 0.1151111196668353, 0.12117172023863532, 0.1906497377785854, 0.15226569666992873, 0.11581622675294057, 0.12887199962278828, 0.10987651461618952, 0.25947385642211884, 0.25314894737675786, 0.3055470669642091, 0.1724439943791367, 0.29472717724274844, 0.09712396102258936, 0.4000403668032959, 0.3221633972134441, 0.6740123452618718, 0.1903303767903708, 16.542121656239033, 101.13033458590508, 70.81661760807037, 82.59982332587242, 51.995205357670784, 61.310131922364235, 64.55380886793137, 59.41004008054733, 55.80565229058266, 66.92905381321907, 29.866059198975563, 30.543108768761158, 71.13640084862709, 82.09806025028229, 69.39757615327835, 47.363987267017365, 41.041107550263405, 59.226198345422745, 67.80771106481552, 78.84006947278976, 39.6917999535799, 22.277036122977734, 57.19290465116501, 58.60756494104862, 37.05626517534256, 12.800453882664442, 6.926979376003146, 3.604149827733636, 1.8501956504769623, 1.8725898675620556, 2.5124142598360777, 4.937276942655444, 8.715483080595732, 10.677059423178434, 6.633802782744169, 16.642761155962944, 25.766039304435253, 23.76583233475685, 18.740132711827755, 30.077935829758644, 26.359434463083744, 18.488770499825478, 23.26958656311035, 32.324413284659386, 43.37949067354202, 42.739920392632484, 47.14479982852936, 37.485706731677055, 27.237842828035355, 19.713349789381027, 14.41720062866807, 11.200896464288235, 19.407927878201008, 33.552473187446594, 51.69501766562462, 61.98890469968319, 61.61251209676266, 40.26999972760677, 27.104312293231487, 30.19392840564251, 48.1297791749239, 58.898378536105156, 63.75880032777786, 63.51610355079174, 63.17260958254337, 63.03246550261974, 54.04325745999813, 53.75858813524246, 56.135812774300575, 60.48653371632099, 46.95481762290001, 59.319513738155365, 57.06992045044899, 53.79601992666721, 43.16864378750324, 49.676432982087135, 58.44629779458046, 59.62197370827198, 58.4889505058527, 45.56903958320618, 36.23764090240002, 29.336420819163322, 31.638527289032936, 43.10039184987545, 50.46920724213123, 55.918551832437515, 46.61908283829689, 36.87585085630417, 19.065511152148247, 11.68389804661274, 16.48681752383709, 21.676480248570442, 22.182255908846855, 34.73582088947296, 37.503987550735474, 26.571565680205822, 29.71343658864498, 23.7604708224535, 15.069007202982903, 11.410669907927513, 15.609083622694016, 17.61035643517971, 14.32189129292965, 16.31180841475725, 14.94801789522171, 29.527917243540287, 35.42431354522705, 25.13979870826006, 20.420396849513054, 19.25118248909712, 13.976069949567318, 5.862247534096241, 6.504744607955217, 4.244693331420422, 1.718439501710236, 0.6669359374791384, 0.9519584651570767, 13.578349091112614, 47.55818724632263, 56.018254682421684, 48.17107155919075, 55.83917789161205, 67.27617278695107, 48.42576429247856, 52.452100440859795, 75.07356718182564, 69.31995391845703, 69.02489215135574, 65.47460585832596, 70.0074054300785, 47.18464069068432, 27.982308380305767, 37.048346400260925, 57.93511122465134, 19.16301392018795, 50.03283865749836, 32.57813706994057, 49.197491481900215, 66.98260813951492, 42.62820638716221, 73.64134803414345, 83.31195071339607, 7.596058873459697, 0.3092764184111729, 0.480579657596536, 0.6455470633227378, 0.23981405276572332, 0.1625085368868895, 0.10897827101871371, 0.20233526855008677, 0.37073141138534993, 0.16672018042299896, 0.1829569021356292, 0.14303116797236726, 0.16829639818752185, 0.12412459967890754, 0.11975870074820705], [0.019513099614414386, 0.19673261762363836, 0.038456879192381166, 0.0715824069629889, 0.006774111552658724, 0.0745497434400022, 0.15444954042322934, 0.029032329148321878, 0.020015450099890586, 0.08552074184990488, 0.2265367191284895, 0.040710429166210815, 0.14976204663980752, 0.12666087452089414, 0.06936239093192853, 0.007211864576674998, 0.13473973085638136, 0.02018221995967906, 0.5111934570595622, 0.4741879552602768, 32.19967357814312, 68.60670939087868, 58.46517138183117, 56.95148080587387, 24.571166820824146, 34.47075091302395, 53.231404423713684, 38.99399399757385, 52.091986164450645, 31.975041031837463, 24.509304240345955, 63.001519963145256, 67.11721211671829, 62.13024191558361, 53.618394657969475, 42.97851338982582, 44.85222704708576, 53.043831288814545, 48.86223167181015, 35.78852400183678, 22.255287989974022, 42.87658765912056, 42.012992799282074, 20.352471694350243, 8.062259182333946, 0.32172511448152363, 0.4288528551114723, 0.16441394167486578, 0.6009660742711276, 2.2257517045363784, 6.401215838268399, 6.16285415366292, 7.656554002314806, 16.670590862631798, 17.535591647028923, 9.356828816235065, 4.887674879282713, 12.202637661248446, 31.09530083835125, 26.553835831582546, 14.921226482838392, 19.155558720231056, 31.019620299339294, 30.354779474437237, 34.79736618697643, 37.65875704586506, 23.45316231250763, 19.884832687675953, 6.55256456695497, 5.595812005922198, 3.9513345854356885, 4.141597263514996, 9.003066848963499, 19.806197807192802, 41.206660866737366, 43.845159485936165, 23.572337217628956, 10.135815516114235, 11.457337103784084, 20.133884623646736, 38.83441776037216, 47.54680685698986, 56.66868858039379, 60.95201253890991, 55.78953355550766, 45.900864377617836, 48.83830815553665, 49.18220490217209, 51.95204347372055, 39.22440603375435, 44.19356279075146, 46.744061931967735, 45.58259725570679, 41.484520956873894, 46.47051081061363, 58.568001464009285, 54.54490274190903, 33.9376775175333, 14.033470619469881, 9.783420525491238, 8.44483595341444, 9.528583399951458, 21.97239886969328, 38.66121165454388, 46.63794502615929, 45.8545258641243, 28.952599614858627, 10.340944658964872, 4.069728869944811, 15.68564286455512, 16.04732170701027, 5.013585397973657, 13.870640806853771, 26.62704460322857, 19.175737537443638, 19.150791876018047, 17.452596500515938, 9.020395819097757, 2.9991588788107038, 5.045145554468036, 11.706700623035431, 12.731927409768105, 13.878667876124382, 6.31474862806499, 3.700201786123216, 12.500342186540365, 34.280042946338654, 46.0957483202219, 31.20335564017296, 19.973825812339783, 10.75208069756627, 4.8585294932127, 3.558310749940574, 2.8396978229284286, 0.5331647687125951, 0.15478745510336012, 6.1634312476962805, 39.93931867182255, 41.93285129964352, 42.56719686090946, 60.05384713411331, 43.25485736131668, 45.31272813677788, 61.10963948071003, 55.83041936159134, 55.43953813612461, 55.10122708976269, 53.76544676721096, 53.75063136219978, 28.14999908208847, 18.311382718384266, 64.24373790621758, 51.41830511391163, 31.077424697577953, 22.68800877034664, 28.48226275295019, 60.83260014653206, 40.38738302886486, 40.796054899692535, 62.518649473786354, 19.262517280876637, 0.6137928203679621, 0.46487628773320466, 0.14551623462466523, 0.09802923275856301, 0.03538953089446295, 0.18255648377817124, 0.16124552028486505, 0.09373898836201988, 0.103787519474281, 0.008293795290228445, 0.07692373284953646, 0.034644863626454026, 0.01734180928906426, 0.04018280298623722, 0.03588894433050882, 0.03255242278100923, 0.07867456311942078, 0.0886613030161243, 0.0926174919004552, 0.0050328336510574445, 0.03358549976837821, 0.04379893609439023, 0.013579674396169139, 0.09222511842381209, 0.13222008012235165, 0.13941803685156628, 0.07147889962652698, 0.17950929963262752, 0.08789934741798788, 0.1963285478996113, 0.04342950982390903, 0.19269442884251475, 0.05391774859162979, 0.6460517831146717, 0.8481953549198806, 45.769877806305885, 77.55595877766609, 67.8685761988163, 63.79549115896225, 30.687715709209442, 39.562633484601974, 38.406655713915825, 35.16390971839428, 52.026694267988205, 32.57820166647434, 29.707858487963676, 68.65136459469795, 74.79866713285446, 67.58622854948044, 57.79810577630997, 48.02042104303837, 48.2841344922781, 57.48322807252407, 58.63176964223385, 42.292004227638245, 24.59317523986101, 51.516085267066956, 49.40398380160332, 25.699825957417488, 10.500824879854918, 0.8419262256938964, 1.6604929673485458, 0.5978985107503831, 2.024941029958427, 7.184855388477445, 13.247131314128637, 15.89678993448615, 14.735406003892422, 15.530866719782352, 11.983435973525047, 14.276894107460976, 17.938033752143383, 22.494255267083645, 35.91512180864811, 32.60907121002674, 17.12141577154398, 21.606062427163124, 34.763813987374306, 34.917318150401115, 40.216988772153854, 43.60118977725506, 31.13574016839266, 24.158645756542683, 11.889625657349825, 8.139869067817926, 4.185581803321838, 6.906918352469802, 15.035674441605806, 33.02379235625267, 51.50833748281002, 56.189880073070526, 33.2386290282011, 15.72683835402131, 16.886348985135555, 30.89379385113716, 46.72450438141823, 54.00570407509804, 60.32360225915909, 63.3148093521595, 56.32887661457062, 50.07946975529194, 51.54739938676357, 55.63571020960808, 55.591168999671936, 49.237776920199394, 51.81712791323662, 52.53889158368111, 49.842636063694954, 43.276538997888565, 49.10249277949333, 58.94991897046566, 61.465668976306915, 48.98063711822033, 32.56363704800606, 20.140519067645073, 17.2978688031435, 17.229219786822796, 31.548854000866413, 47.28463992476463, 54.40605439245701, 47.97205723822117, 32.522166073322296, 12.323002852499485, 7.396137826144695, 16.974010281264782, 20.31834002584219, 13.54884272441268, 16.97317622601986, 31.213609389960766, 23.7718341127038, 19.826971292495728, 19.30169127881527, 11.281030364334583, 5.710804285481572, 5.136172519996762, 7.99497714266181, 17.796191163361073, 17.380580864846706, 11.077914163470268, 9.06667448580265, 18.34525030106306, 28.809020519256592, 31.86373360455036, 24.244390055537224, 18.190233819186687, 14.711062610149384, 9.779054559767246, 7.998701892793179, 6.246786424890161, 1.8312435736879706, 0.6217880069743842, 5.877931667491794, 40.689542815089226, 44.809688329696655, 45.640460550785065, 64.76408958435059, 47.2974756360054, 51.56550921499729, 63.65392595529556, 62.54530884325504, 59.609757363796234, 61.77592232823372, 54.445583671331406, 61.9101083278656, 33.739875331521034, 25.304308980703354, 60.51271811127663, 70.63869595527649, 30.25199119001627, 20.639637485146523, 26.410653814673424, 56.76848642528057, 55.23902669548988, 41.40828184783459, 74.80913177132607, 26.040291488170624, 0.6628914701286703, 0.33807477622758597, 0.09527410598821007, 0.1666112628299743, 0.07495056255720556, 0.22135621664347127, 0.06236209039343521, 0.06415905998437665, 0.029794537076668348, 0.06811858853325248, 0.12123075808631256, 0.06815505024860613, 0.02118064421665622, 0.016438695347460452, 0.027418642202974297, 0.07972050152602606, 0.242771080811508, 0.2050433654221706, 0.20745473681017756, 0.1302790967747569, 0.19780101341893896, 0.2386071128421463, 0.11507900693686679, 0.19798070221440867, 0.2335118831251748, 0.3456792369252071, 0.20246509986463934, 0.2986087877070531, 0.31472039816435426, 0.33193522598594427, 0.14379431842826307, 0.22461632295744494, 0.13940009172074497, 0.5247814685571939, 1.2383441696874797, 65.22446528077126, 89.96432214975357, 74.73340943455696, 73.81601706147194, 35.016865208745, 51.54019497334957, 73.23926880955696, 47.94487729668617, 72.99162849783897, 40.2941170334816, 29.03816532343626, 72.87935212254524, 81.7187950015068, 73.78349840641022, 63.95518139004707, 54.359214305877686, 56.26196600496769, 62.69272953271866, 66.09298467636108, 42.06453703343868, 25.659519620239735, 57.93007269501686, 54.20209273695946, 33.261165618896484, 15.242141112685204, 2.9573461599648, 1.6041530342772603, 1.0363263473846018, 2.0698420330882072, 8.44591224566102, 10.234462972730398, 9.93868114426732, 10.404907576739788, 24.200914688408375, 28.385090567171574, 22.802071049809456, 13.1945126876235, 21.365685425698757, 39.135563001036644, 35.63039168715477, 21.701068729162216, 25.54009772837162, 37.272082194685936, 39.151685535907745, 48.20016659796238, 49.55056093633175, 36.84356398880482, 28.131988048553467, 10.865767747163773, 11.312401480972767, 6.960097448900342, 8.665928039699793, 15.408958811312914, 26.763611175119877, 44.83670487999916, 63.81889030337334, 52.67625421285629, 31.873700469732285, 30.438521280884743, 47.354624569416046, 55.10680519044399, 60.39414927363396, 61.79131530225277, 61.06597602367401, 60.12268424034119, 53.62643502652645, 55.47630876302719, 61.51715621352196, 63.50324124097824, 50.19109636545181, 55.74422098696232, 58.08146797120571, 55.92621982097626, 47.23311848938465, 51.837156638503075, 57.942878007888794, 59.540616273880005, 53.49780432879925, 42.234121933579445, 31.581575945019722, 28.62744726240635, 33.2756732404232, 44.15511265397072, 55.12561038136482, 51.6258005797863, 43.99579480290413, 32.468474954366684, 18.53452194482088, 7.758142026141286, 22.80020534992218, 22.75540005415678, 10.919456966221333, 20.079788826406002, 39.392528012394905, 28.706209436058998, 23.640140779316425, 24.09754503518343, 15.01590695232153, 10.185450352728367, 13.935091998428106, 20.425638668239117, 21.558146998286247, 19.577653370797634, 12.679683063179255, 11.46407414227724, 22.271309830248356, 42.44031026959419, 56.29417307674885, 38.22002112865448, 27.54825197160244, 12.885618712753057, 6.926361909136176, 3.7546618888154626, 3.9027069322764874, 1.2758707185275853, 0.28044739505276084, 6.044989228248596, 45.823078751564026, 48.81457082927227, 46.80689916014671, 68.76329898834229, 54.39785823225975, 55.27567572891712, 73.08035373687744, 68.47610279917717, 66.76868721842766, 65.89519008994102, 61.06305778026581, 63.90797272324562, 37.19169370830059, 25.187292359769344, 68.79988342523575, 59.95791748166084, 37.513532638549805, 34.0917706489563, 39.638036638498306, 76.16492182016373, 63.17216880619526, 50.4920744150877, 88.12976539134979, 34.09294858574867, 1.1495711957104504, 0.3689249942544848, 0.37569905107375234, 0.1809449991560541, 0.1512729108799249, 0.3749349061399698, 0.13563489454099908, 0.1421417633537203, 0.13200668297940865, 0.15820307104149833, 0.1638171510421671, 0.24718528613448143, 0.10990116134053096, 0.17766749690053985, 0.20534841780317947], [0.046405340181081556, 0.018228282424388453, 0.04813722342078108, 0.063383923843503, 0.055249024226213805, 0.020481101382756606, 0.07365746670984663, 0.0708396581467241, 0.18420727254124358, 0.011112361771665746, 0.13097520160954446, 0.05307639803504571, 0.017941978549060877, 0.07958212067023851, 0.0619465878844494, 0.06845302254077978, 0.12564684846438468, 0.05976612461381592, 0.4801147762918845, 0.046604399030911736, 12.454834878444672, 79.76258397102356, 53.055390268564224, 68.64010199904442, 46.12525753676891, 33.16228352487087, 49.85058143734932, 44.51961189508438, 48.38284179568291, 53.45835104584694, 18.27013213187456, 45.97723267972469, 65.80095514655113, 61.33018724620342, 63.68416093289852, 64.4585707783699, 52.846576273441315, 64.37738433480263, 63.69634307920933, 73.94447296857834, 53.529186844825745, 44.12835069000721, 38.30838918685913, 17.084895931184292, 3.914493187330663, 0.6806640070863068, 0.3185445663984865, 1.4304116321727633, 2.0170312793925405, 7.286455761641264, 5.364075740799308, 14.434174317866564, 33.277329951524734, 40.19242689013481, 20.355141051113605, 5.8592817932367325, 8.142184093594551, 18.8934962823987, 40.48995852470398, 39.03172977268696, 20.344621315598488, 21.460011564195156, 29.230830185115337, 35.382340997457504, 41.99407361447811, 33.67969036102295, 27.83461980521679, 9.984173253178596, 6.986810490489006, 7.9146157298237085, 1.9611954130232334, 1.9214263907633722, 8.508142456412315, 19.736767932772636, 39.31916534900665, 49.01857428252697, 29.575234204530716, 12.087504789233208, 11.876296922564507, 19.366943277418613, 37.25296542048454, 46.94858975708485, 57.191133946180344, 60.65359175205231, 56.55214123427868, 47.019273564219475, 46.35438144207001, 48.9446796476841, 47.910424545407295, 43.52665677666664, 43.976146057248116, 45.42735658586025, 49.155841916799545, 42.205539867281914, 46.09599910676479, 57.51903735101223, 55.579986199736595, 33.8621261715889, 15.373789798468351, 10.175771322101355, 8.550685923546553, 7.976329643279314, 21.651046313345432, 37.29534834623337, 50.43440870940685, 45.252486169338226, 30.60965459793806, 4.487170195207, 6.38232515193522, 9.931193646043539, 20.629368536174297, 13.912616204470396, 7.754194987937808, 22.052496671676636, 26.353198997676373, 21.437184289097786, 17.11949497461319, 10.226080622524023, 3.921392192132771, 1.650864165276289, 10.358502566814423, 19.225290678441525, 18.12574177980423, 7.061096504330635, 6.322173904627562, 7.9267860017716885, 5.828239358961582, 20.852065086364746, 37.90904961526394, 31.5676648914814, 26.95522729307413, 17.125443555414677, 8.403744008392096, 4.596258066594601, 2.5274631148204207, 0.37545194558333606, 3.2530030701309443, 29.319690316915512, 41.14684447646141, 45.86372137069702, 61.64751581847668, 57.89523996412754, 53.50703403353691, 50.95550514757633, 58.997712805867195, 56.0115822404623, 57.24807769060135, 47.88496971130371, 61.64564251899719, 21.92946307361126, 23.015513196587563, 68.00396293401718, 55.53521320223808, 33.93928483128548, 20.367868468165398, 48.02980273962021, 56.37750640511513, 37.61871479451656, 43.80252197384834, 64.92706283926964, 6.229250840842724, 0.12611622718395665, 0.38254699611570686, 0.1661462924676016, 0.17809737852076069, 0.04669169044063892, 0.13958199211629108, 0.11083878329372965, 0.2869662124430761, 0.06873938764329068, 0.06713290509651415, 0.02197043962951284, 0.05608818544715177, 0.016251497872872278, 0.036508307384792715, 0.08017992062377743, 0.06498026123153977, 0.02865626065613469, 0.09542827974655665, 0.12065805014572106, 0.0909939176926855, 0.03708305623149499, 0.05061680931248702, 0.042444783757673576, 0.18306813522940502, 0.100543599401135, 0.07768076058709994, 0.016758885685703717, 0.08331801043823361, 0.036740325012942776, 0.13022928382270038, 0.07025427432381548, 0.22494775126688182, 0.046572757564717904, 0.520157057326287, 0.02566898452641908, 15.91541938483715, 90.68066731095314, 62.17341899871826, 70.48640012741089, 44.80095259845257, 37.02615559101105, 39.877180606126785, 32.39657901227474, 51.97595179080963, 46.13340049982071, 25.395680777728558, 59.26644578576088, 73.51900979876518, 69.67327415943146, 70.81839591264725, 67.62259259819984, 58.8026312738657, 65.79115927219391, 67.60750740766525, 67.45538637042046, 46.31526254117489, 47.40478187799454, 43.99473465979099, 22.367387674748898, 4.688557963818312, 1.546074457000941, 1.4348911168053746, 3.283856464549899, 5.835164487361908, 17.00773347169161, 13.203823138028383, 19.1016586124897, 27.872313782572746, 25.814557000994682, 23.39831605553627, 15.858502238988876, 12.027378715574741, 22.26352594792843, 39.78609949350357, 44.29640807211399, 22.614266127347946, 24.775523655116558, 33.23712810873985, 36.61697834730148, 47.382819056510925, 39.40912552177906, 31.06978140771389, 19.07499734312296, 9.435925371944904, 8.359316792339087, 2.124729612842202, 2.6914426032453775, 12.472674921154976, 20.350683890283108, 44.877157509326935, 57.78461270034313, 39.16984476149082, 18.18695269525051, 21.039991602301598, 29.708996526896954, 49.22745667397976, 54.921196550130844, 62.69934497773647, 62.70862028002739, 58.267278000712395, 48.07360678911209, 50.81474930047989, 56.439682468771935, 56.59602887928486, 48.941427022218704, 51.25210963189602, 53.20029929280281, 54.19357739388943, 44.4939898699522, 48.01383979618549, 58.09667855501175, 61.21231757104397, 47.51170814037323, 30.883739590644836, 20.219017155468464, 15.521195288747549, 17.857747860252857, 34.33743126690388, 49.60079804062843, 52.45755694806576, 45.809065103530884, 32.72443301975727, 7.988589685410261, 6.724422695115209, 15.93397568911314, 21.732601337134838, 20.400863997638226, 15.067643076181412, 26.049819476902485, 28.47359921783209, 23.324691206216812, 16.778423376381397, 11.101541295647621, 6.577407633885741, 4.9895797111094, 12.38942138850689, 26.298774518072605, 19.972524382174015, 15.03255195915699, 8.676680512726307, 11.034999266266823, 12.782529294490814, 27.734193094074726, 39.63421784341335, 28.783768974244595, 24.676578864455223, 19.607168287038803, 12.527231443673372, 8.854486271739006, 4.8016018979251385, 0.9362356807105243, 3.295662668533623, 32.14353919029236, 44.99039523303509, 49.52113911509514, 64.08847823739052, 64.63042795658112, 61.860384196043015, 57.746318355202675, 63.44218611717224, 61.34522683918476, 62.80151009559631, 53.48811864852905, 65.71986749768257, 28.56681201606989, 26.374838836491108, 68.54934006929398, 68.282161206007, 29.95783757418394, 23.704427629709244, 40.09154610335827, 61.75082087516785, 41.67083255946636, 49.57773707807064, 75.32507568597794, 8.808895368129015, 0.06893906247569248, 0.2983454737113789, 0.1298584177857265, 0.1501875792746432, 0.09264025356969796, 0.1151863660197705, 0.07356981164775789, 0.15991686814231798, 0.029708755937463138, 0.1005536258162465, 0.0789974196231924, 0.04107602595468052, 0.011481814945000224, 0.00295126758828701, 0.016905107331695035, 0.08729017034056596, 0.11995577064226381, 0.24792462849291041, 0.1912200337392278, 0.1884889748180285, 0.14964829024393111, 0.17404649901436642, 0.13339150085812435, 0.3104155557230115, 0.21146931045223027, 0.2631045912858099, 0.21182891068747267, 0.25279898021835834, 0.200278450793121, 0.303072776296176, 0.15277939644875005, 0.43463080131914467, 0.15715046814875677, 0.7240740652196109, 0.15586445981170982, 22.3359614610672, 107.72876411676407, 69.17960464954376, 83.98326829075813, 56.8726122379303, 49.008056446909904, 72.01692759990692, 56.02250285446644, 64.44508150219917, 68.42263206839561, 21.59568328410387, 57.58840262889862, 73.07289853692055, 76.79916858673096, 75.76034992933273, 77.61496961116791, 63.53976868093014, 72.82207399606705, 74.22419875860214, 82.65387162566185, 56.907330974936485, 56.4557746052742, 48.96425999701023, 27.03565377742052, 6.770551269873977, 2.23316534422338, 1.404060402419418, 3.4442753065377474, 6.553727779537439, 12.813324742019176, 7.530181808397174, 20.11611297726631, 42.143139615654945, 52.368432730436325, 30.74511542916298, 13.136156369000673, 9.409702979028225, 24.894679561257362, 47.474143356084824, 48.58238808810711, 27.936325147747993, 28.36501434445381, 37.06297181546688, 42.91294030845165, 53.40048775076866, 43.96377392113209, 38.370622247457504, 14.827315472066402, 11.435463577508926, 13.514211382716894, 2.740404875949025, 4.687963295727968, 13.922123294323683, 21.93453960120678, 43.98518957197666, 62.54595100879669, 58.35545986890793, 37.19575189054012, 35.41145883500576, 45.85122384130955, 59.93219666182995, 62.07682818174362, 64.4105413556099, 66.06045082211494, 60.79382322728634, 52.15901076793671, 55.418935641646385, 62.70909905433655, 62.38230898976326, 50.57635389268398, 55.98894685506821, 57.717420905828476, 59.89619739353657, 46.70044407248497, 50.04055604338646, 55.970191061496735, 57.44943268597126, 54.46988716721535, 45.50117142498493, 33.806660547852516, 29.91880226880312, 32.70889565348625, 45.79813688993454, 53.51158618927002, 52.397330179810524, 43.21349278092384, 33.11083808541298, 15.040043257176876, 8.81877863779664, 16.081470474600792, 30.32104678452015, 22.786738872528076, 14.538545217365026, 33.89013446867466, 32.4997016787529, 28.233904279768467, 19.4426941126585, 15.234369579702616, 9.72016816958785, 10.54127560928464, 17.55986664444208, 28.21432013064623, 23.27157575637102, 15.140161234885454, 8.410401251167059, 10.588081497699022, 7.894888138398528, 26.42570100724697, 48.953236788511276, 42.343267276883125, 33.69686543941498, 21.15820325911045, 12.5251330062747, 7.16401825658977, 4.24985820427537, 0.7287621824070811, 3.008717028424144, 37.764623165130615, 48.03455628454685, 53.15749078989029, 69.1475647687912, 65.09800806641579, 66.24745398759842, 64.4081474840641, 70.82994729280472, 66.46177008748055, 68.198983669281, 58.221581652760506, 75.49820959568024, 28.975290097296238, 26.551204472780228, 81.17131277918816, 59.539073556661606, 42.490425780415535, 30.195425525307655, 63.06262828409672, 68.80861535668373, 49.87280264496803, 57.75852330029011, 89.49733480811119, 11.229514628648758, 0.5148791405372322, 0.568259566789493, 0.29265524935908616, 0.1653182040899992, 0.21783221745863557, 0.1878699494409375, 0.18719115148996934, 0.2886367868632078, 0.13602836639620364, 0.22162040637340397, 0.1675677130697295, 0.16156727098859847, 0.1784299942664802, 0.13764219620497897, 0.12643757712794468], [0.051335082098376006, 0.008817993675620528, 0.04214557950035669, 0.011507872677611886, 0.03523224753735121, 0.056217129895230755, 0.028651614811678883, 0.05029140353144612, 0.03732160104846116, 0.08696407807292417, 0.019854973652400076, 0.1068231558019761, 0.08496874725096859, 0.05725914605136495, 0.09850328700849786, 0.09719208275782876, 0.00706849788002728, 0.10852908613742329, 0.05624185454507824, 1.1428324948064983, 0.7047157071065158, 60.326463505625725, 70.24954363703728, 66.88556894659996, 59.59478236734867, 45.88250756263733, 36.62035636603832, 58.92652362585068, 35.99292263388634, 59.34259369969368, 19.307132586836815, 30.608790144324303, 65.01658603549004, 66.08739897608757, 50.20295172929764, 61.78484424948692, 63.7449386715889, 66.79134920239449, 63.323814868927, 71.5816305577755, 65.90901374816895, 45.367460399866104, 36.61858946084976, 11.802477333694696, 0.7614789018407464, 1.1224997858516872, 2.004505251534283, 4.175064917653799, 7.170457486063242, 6.6067928820848465, 21.206139586865902, 48.60487148165703, 48.05456981062889, 27.783567644655704, 8.906620424240828, 10.987408719956875, 22.576009780168533, 18.47298614680767, 39.11342918872833, 44.828622713685036, 25.031027644872665, 22.368276827037334, 26.47836048156023, 37.57667385041714, 43.226579278707504, 34.5906762778759, 21.00022103637457, 6.898930706083775, 13.275541439652443, 7.686949521303177, 7.607827791944146, 3.1334588723257184, 9.994786083698273, 32.674503698945045, 52.3744136095047, 54.334937408566475, 32.205388471484184, 15.555419102311134, 11.685082633048296, 20.02834528684616, 34.04284067451954, 46.21970146894455, 56.8502314388752, 62.827223315835, 55.61878211796284, 49.173548966646194, 45.83131290972233, 49.2825423181057, 46.82024024426937, 41.27311550080776, 47.96875521540642, 47.54666246473789, 46.72326944768429, 42.74820774793625, 47.99255333840847, 59.73037049174309, 58.94245237112045, 40.92309728264809, 16.225765831768513, 7.849623542279005, 6.3113862834870815, 4.125429131090641, 14.419359862804413, 33.30587401986122, 48.609799817204475, 45.99599987268448, 24.283801540732384, 2.6784325763583183, 10.581183917820454, 18.365149833261967, 22.51546762883663, 25.211687050759792, 7.494837054982781, 12.753594797104597, 23.798607476055622, 24.965304471552372, 19.10269595682621, 12.963999006897211, 5.875382954254746, 1.5400845534168184, 17.623129449784756, 27.645766139030457, 24.854344725608826, 7.660306300967932, 8.561294004321098, 20.940892919898033, 17.04871617257595, 9.729452021420002, 12.72255901247263, 19.131154529750347, 24.601289704442024, 20.340783521533012, 14.781679920852184, 12.362780068069696, 7.25383878685534, 4.524524565786123, 0.07844303530873731, 12.690543830394745, 36.88523255288601, 44.95365880429745, 55.74887953698635, 41.84863641858101, 52.97534376382828, 52.72880919277668, 55.96366301178932, 56.469146087765694, 58.9087937772274, 47.137200236320496, 60.26736527681351, 18.561895675957203, 24.12538044154644, 58.61617907881737, 47.043592259287834, 42.09623113274574, 26.509005837142467, 66.39211222529411, 64.1027882695198, 38.96090917289257, 63.0254814773798, 41.21322691440582, 1.1167086591012776, 0.1993573861545883, 0.17401681310730055, 0.05598614014161285, 0.059407526277936995, 0.0563938872073777, 0.07595373841468245, 0.13003942760406062, 0.0994182140857447, 0.06558462177054025, 0.0732534563576337, 0.028340523203951307, 0.0829678428999614, 0.02992627942148829, 0.046951252879807726, 0.08439370154519565, 0.03868908606818877, 0.02036245979979867, 0.018775061580527108, 0.025540554015606176, 0.04253993080055807, 0.07142541304347105, 0.0578391901217401, 0.02206308377935784, 0.06552633349201642, 0.06723470549331978, 0.10871785139897838, 0.07438768807332963, 0.047052570880623534, 0.031074079452082515, 0.04395182593725622, 0.10547417623456568, 0.06571889854967594, 0.07796289544785395, 0.06231831110198982, 0.8850466681178659, 1.1331186722964048, 71.4327621459961, 79.9021352827549, 74.34124767780304, 60.36196880042553, 50.446020886301994, 38.76788333058357, 32.966787815093994, 39.33891288936138, 51.14634610712528, 23.249645233154297, 45.23851431906223, 73.23875203728676, 74.86214652657509, 57.100717797875404, 72.26022094488144, 71.39883756637573, 72.80297622084618, 65.42519330978394, 71.80288508534431, 59.60636414587498, 50.83095543086529, 42.71959528326988, 14.592972546815872, 1.5480179339647293, 1.9215009617619216, 2.7815466932952404, 9.223172888159752, 14.706589300185442, 14.324870333075523, 22.731505036354065, 44.52292151749134, 47.92270928621292, 32.034587636590004, 16.21968425810337, 14.91249455139041, 21.054069846868515, 16.832503974437714, 44.465411603450775, 48.443448543548584, 32.13058188557625, 25.611260309815407, 28.903240263462067, 39.54330772161484, 48.698004484176636, 36.12557731568813, 30.311285108327866, 15.354943759739399, 16.958138532936573, 11.62920568138361, 7.485825838521123, 4.41671627573669, 13.251730967313051, 31.206646263599396, 50.92994011938572, 64.59546223282814, 46.369808614254, 22.6950478926301, 19.628975316882133, 30.63837345689535, 45.84741644561291, 53.66803139448166, 60.24752654135227, 63.3703737705946, 56.362067833542824, 51.01789779961109, 49.173377975821495, 57.34391614794731, 54.1229809820652, 48.24416823685169, 55.52330084145069, 55.65516136586666, 53.023525178432465, 44.18561361730099, 47.92306646704674, 60.75729198753834, 62.303292229771614, 49.65855114161968, 33.358580991625786, 21.34768009185791, 15.399538166821003, 14.225214030593634, 29.480955563485622, 48.82498987019062, 53.380364030599594, 48.030330911278725, 29.638878889381886, 3.0553379142656922, 11.011460479348898, 18.906457386910915, 22.377721220254898, 25.166895054280758, 15.602948851883411, 18.924899697303772, 25.250887647271156, 27.121380977332592, 18.966446667909622, 14.139141999185085, 7.241450976580381, 3.39525627437979, 19.618523977696896, 34.89195071160793, 26.7823688685894, 14.243191815912724, 11.367708463221788, 20.529834777116776, 16.925401389598846, 11.58247958868742, 15.23291140794754, 21.57694648951292, 25.67426472902298, 24.399431236088276, 21.583843119442463, 19.03243202716112, 10.476334244012833, 3.840455822646618, 0.4677501803962514, 9.69658948481083, 42.7391642332077, 50.3264033049345, 59.818255975842476, 51.85186944901943, 60.937573313713074, 58.52950572967529, 62.41134323179722, 62.38101705908775, 62.833101600408554, 52.28374667465687, 65.63327014446259, 26.003030687570572, 20.043477974832058, 68.0206136405468, 49.26122546195984, 43.49465489387512, 26.897802874445915, 57.42594234645367, 73.34899932146072, 42.78254650533199, 68.25832888484001, 51.71044863760471, 1.3175998418591917, 0.21056915953522548, 0.29474109993316233, 0.0576069609815022, 0.0999682791007217, 0.09819513987167738, 0.046672390890307724, 0.03759485982300248, 0.031523446159553714, 0.05362151292501949, 0.06258636742131785, 0.02026265392487403, 0.03449350260780193, 0.055749502644175664, 0.038439516647486016, 0.0584968183102319, 0.12129588154493831, 0.15562403365038335, 0.16481246013427153, 0.1341366022825241, 0.07079534450895153, 0.12576528039062396, 0.166178026702255, 0.1715134154073894, 0.1993060889071785, 0.22773083474021405, 0.12064584181644022, 0.21808251418406144, 0.20245276537025347, 0.17354998737573624, 0.26363341603428125, 0.1304680178873241, 0.1204025064362213, 0.13174727268051356, 0.1970396886463277, 1.1533069889992476, 1.3659083121456206, 85.84989532828331, 92.61503711342812, 83.4502936899662, 75.24629831314087, 60.65214402973652, 60.174186676740646, 74.93760287761688, 46.86618357896805, 76.77475109696388, 24.584578201174736, 41.18543520569801, 75.12632355093956, 79.24592569470406, 66.00045964121819, 76.44011065363884, 77.77415826916695, 81.34613379836082, 72.3348717391491, 83.80768731236458, 71.91918164491653, 59.86532025039196, 49.20543685555458, 17.71907240152359, 2.1317528234794736, 3.3005874417722225, 3.9028760232031345, 12.06252682954073, 12.48946812003851, 9.861470237374306, 26.53879813849926, 59.57033447921276, 57.81610541045666, 36.231147050857544, 13.448280170559883, 18.207021318376064, 32.47927397489548, 25.70081390440464, 48.662407994270325, 55.841442570090294, 36.03871777653694, 32.197234109044075, 33.39868023991585, 43.774783462285995, 53.17549042403698, 43.68175685405731, 33.97775776684284, 11.992641929537058, 21.743729040026665, 13.19244084879756, 11.193269323557615, 7.000601375475526, 17.52848032861948, 39.562086313962936, 53.77845346927643, 66.44737645983696, 57.092768624424934, 40.60884274542332, 34.16175149381161, 48.2022412866354, 57.856071665883064, 59.330369755625725, 65.70425033569336, 66.02780297398567, 59.18402820825577, 55.42331300675869, 57.342650815844536, 63.39287996292114, 59.26447369158268, 49.04692456126213, 57.67595373094082, 59.54978138208389, 57.026112601161, 49.11831133067608, 49.05154891312122, 60.075562968850136, 60.07171757519245, 56.82304009795189, 47.251498103141785, 35.82248277962208, 31.674853339791298, 24.591206945478916, 39.72720645368099, 52.6814029365778, 51.7578586935997, 45.75106121599674, 31.934934183955193, 10.32525435090065, 15.688693150877953, 26.250101029872894, 31.643258035182953, 37.63499312102795, 14.684351943433285, 21.385311372578144, 30.112029500305653, 29.674475379288197, 20.681838020682335, 17.420961298048496, 12.115027662366629, 8.007289431989193, 25.906295478343964, 38.96046459674835, 31.010344997048378, 14.742859303951263, 13.365825545042753, 32.03304871916771, 24.62818656116724, 13.114781565964222, 16.105215400457382, 25.563831254839897, 33.67275193333626, 26.797953732311726, 20.490706376731396, 17.03629843890667, 10.634049531072378, 7.261239839717746, 0.34136661677621305, 15.574737265706062, 51.14811681210995, 52.916044145822525, 67.4506214261055, 53.18865291774273, 66.95057585835457, 64.71267834305763, 70.84529086947441, 67.18450650572777, 71.34716033935547, 54.61225412786007, 77.0113568007946, 23.310527466237545, 29.291653521358967, 71.891800314188, 51.84655733406544, 51.29631265997887, 39.0983060002327, 77.86127239465714, 82.01573386788368, 50.2268448472023, 80.09597048163414, 61.51084095239639, 1.7920178035274148, 0.22150494303787127, 0.38957700482569635, 0.1634388486854732, 0.1673635927727446, 0.25823835865594447, 0.17940719495527446, 0.12547900434583426, 0.15697302063927054, 0.17699882184388116, 0.23142695281421766, 0.15049162233481184, 0.1846749146352522, 0.18386416282737628, 0.12581792834680527, 0.2076864501577802], [0.022171604323375504, 0.09399512578966096, 0.050217155367136, 0.09195411577820778, 0.03417484294914175, 0.08502748823957518, 0.06946120047359727, 0.028306829699431546, 0.05264961117063649, 0.19483030016999692, 0.07467511444701813, 0.17939104582183063, 0.03997050422185566, 0.2008357146405615, 0.015435040804732125, 0.0657115587091539, 0.056245509622385725, 0.09945131387212314, 0.14715272962348536, 0.4205337952589616, 0.07391305494820699, 15.08495969697833, 80.21835431456566, 60.90110287070274, 68.43806684017181, 65.65102279186249, 44.86283987760544, 53.45434986054897, 37.93754428625107, 48.62359307706356, 42.635072618722916, 14.769873954355717, 58.02775405347347, 60.474856942892075, 58.53048227727413, 55.98844148218632, 59.85642872750759, 65.15882760286331, 68.82885307073593, 58.0735719949007, 49.223869666457176, 42.53058582544327, 35.67908987402916, 6.828441163524985, 0.43336900183930993, 2.1951082488521934, 3.5636898363009095, 7.916190745308995, 6.841179504990578, 20.838798098266125, 36.17013372480869, 32.29680396616459, 18.65743774920702, 13.146386370062828, 14.701668564230204, 22.499060109257698, 19.73867543041706, 12.504957988858223, 37.464070692658424, 45.62097139656544, 29.22361247241497, 21.973096132278442, 27.374821677803993, 42.23598763346672, 41.64064697921276, 35.11833116412163, 12.595786415040493, 16.053027100861073, 17.65986777842045, 8.94177233800292, 4.397316891700029, 4.077490903437138, 17.95061867684126, 40.978414714336395, 56.79176017642021, 55.648078545928, 38.150256872177124, 14.440422132611275, 11.764479372650385, 15.382948257029057, 28.445442728698254, 43.33254799246788, 56.193299889564514, 59.61585983633995, 57.51985430717468, 49.35192659497261, 46.124383583664894, 48.99854555726051, 51.05569817125797, 46.41395844519138, 47.4555167555809, 48.64769898355007, 46.18445076048374, 40.18131248652935, 49.408072382211685, 56.9264667481184, 56.652493849396706, 44.81115125119686, 21.703768484294415, 7.514168517664075, 7.234929101541638, 1.7144437786191702, 9.3627973459661, 28.485551476478577, 45.39277844130993, 37.46024049818516, 11.33873786777258, 4.138398785144091, 8.825431130826473, 20.469929091632366, 21.838389560580254, 30.954425297677517, 15.818525534123182, 4.309940105304122, 21.997211538255215, 24.13900651037693, 19.73820425570011, 12.381236627697945, 6.891646971926093, 3.755993004888296, 27.652470879256725, 36.85867577791214, 22.750291228294373, 11.598583124578, 15.157973729074001, 15.733917374163866, 22.120868302881718, 23.220369704067707, 23.43965783715248, 24.138297848403454, 27.685614600777626, 21.892481558024883, 14.932415932416916, 12.168121263384819, 13.108092974871397, 6.898187370970845, 0.3649337834212929, 1.0795695707201958, 18.92113219946623, 36.63730725646019, 38.42226527631283, 36.62683121860027, 51.50748632848263, 52.60891042649746, 53.98947134613991, 60.04125460982323, 56.195427775382996, 47.61993393301964, 50.295662954449654, 18.06971948593855, 24.091634452342987, 27.068060338497162, 41.59353710711002, 32.89650298655033, 48.21981534361839, 76.05783596634865, 44.07244808971882, 37.51731723546982, 69.73929941654205, 21.484322659671307, 0.1751564847654663, 0.2962223079521209, 0.1435492464224808, 0.12739671394228935, 0.04895653219136875, 0.08784686273429543, 0.012718520556518342, 0.12038421991746873, 0.0365764105663402, 0.0558163775713183, 0.10349212985602207, 0.0188125994100119, 0.0849037425359711, 0.12593451974680647, 0.04701903693785425, 0.06429541477700695, 0.04651625044061802, 0.09892715723253787, 0.05136010360729415, 0.07857015036279336, 0.049174953674082644, 0.06972710456466302, 0.11767504693125375, 0.050869005935965106, 0.06607706643990241, 0.11121104456833564, 0.1003797554585617, 0.09486822542385198, 0.016452786876470782, 0.1861354018910788, 0.10465410305187106, 0.11692218264215626, 0.06111796144978143, 0.2387100041960366, 0.18596847803564742, 0.6998914503492415, 0.09124390271608718, 23.903010673820972, 91.46599397063255, 70.59177607297897, 74.07985970377922, 65.806844830513, 52.76874125003815, 32.44093783199787, 32.266265004873276, 53.63533794879913, 35.00188261270523, 27.833263278007507, 66.72434359788895, 68.2816444337368, 61.44834950566292, 62.17505671083927, 66.44961833953857, 75.81806883215904, 75.06528362631798, 64.27267715334892, 52.76529103517532, 47.88088113069534, 39.97204251587391, 7.765667047351599, 0.6793629925232381, 4.367242455482483, 6.068107187747955, 18.67995724081993, 13.944217208772898, 25.205702371895313, 35.43878696858883, 39.80271980166435, 18.971713185310364, 18.05280279368162, 16.34884312748909, 20.06369289010763, 17.777722254395485, 10.2616685628891, 42.863755747675896, 49.81753461062908, 35.19700214266777, 23.076545521616936, 28.522918671369553, 43.552248403429985, 45.69864682853222, 34.384909719228745, 21.71409633010626, 19.039875827729702, 21.09051939100027, 10.526608396321535, 7.163989758118987, 9.232903216034174, 22.754830084741116, 42.17080973088741, 60.41109636425972, 62.49871954321861, 48.565953969955444, 24.37455777078867, 18.43685008585453, 27.790977247059345, 44.76369559764862, 54.97785910964012, 61.253294572234154, 63.23456145823002, 58.7206506729126, 50.89388385415077, 52.96806715428829, 57.77485862374306, 56.693577244877815, 54.10607948899269, 54.21457886695862, 55.39231427013874, 50.99641755223274, 45.12091442942619, 48.43998692929745, 56.51791267096996, 60.74189901351929, 56.58541604876518, 36.18923529982567, 20.197914987802505, 14.48151407763362, 9.165971707552671, 21.39206361025572, 42.17200666666031, 53.89361009001732, 44.269357323646545, 15.17416276037693, 3.611629488877952, 9.837882053107023, 19.591716416180134, 23.10180276632309, 29.405461214482784, 22.410975135862827, 12.905205711722374, 21.595385000109673, 25.84854617714882, 20.569166466593742, 13.712900821119547, 7.740369429811835, 6.44430885091424, 32.52255745232105, 39.51345272362232, 28.31284124404192, 15.075691994279623, 17.87052657455206, 17.839696928858757, 20.244135707616806, 21.055534668266773, 18.39447095990181, 23.045088909566402, 25.97322888672352, 21.73000607639551, 17.265070863068104, 17.913238182663918, 22.079121842980385, 10.374924335628748, 1.4460760541260242, 1.2207334209233522, 22.03622594475746, 38.404151648283005, 45.74504613876343, 43.14397931098938, 58.01674224436283, 60.08868366479874, 59.67475287616253, 66.42472967505455, 59.732296988368034, 53.168301209807396, 58.98047313094139, 24.402404576539993, 17.128726579248905, 46.06915734708309, 51.15930341184139, 40.35332165658474, 39.542859345674515, 80.26055485010147, 56.15133494138718, 42.67603442072868, 78.40386807918549, 29.266861751675606, 0.43920480587985367, 0.1592675779829733, 0.14712825359310955, 0.03787270135944709, 0.06595985163585283, 0.24094848486129194, 0.03849769360385835, 0.08036278581130318, 0.06650650277151726, 0.06512760723126121, 0.09586329702869989, 0.02956005551823182, 0.08488190112984739, 0.06260154434130527, 0.01777900477463845, 0.04246115182468202, 0.07980484660947695, 0.19300212326925248, 0.12596082146046683, 0.1591305181500502, 0.13319870573468506, 0.13522790075512603, 0.30004715896211565, 0.27186347753740847, 0.15908250119537115, 0.26941412303131074, 0.21535852050874382, 0.2506374305812642, 0.2091521176043898, 0.4811423836508766, 0.2235263751936145, 0.2044556735199876, 0.16576377471210435, 0.2338623401010409, 0.2767075051087886, 0.9024515154305845, 0.22885230893734843, 25.236653611063957, 111.67814299464226, 78.50014731287956, 91.68018087744713, 76.60594895482063, 71.07404619455338, 75.86307361721992, 48.48397336900234, 67.33406648039818, 53.69930751621723, 20.507590770721436, 68.79067271947861, 72.61465072631836, 70.05985021591187, 70.0082565844059, 74.79649364948273, 79.02131214737892, 80.4431502521038, 69.54266756772995, 58.73524568974972, 52.31810823082924, 48.380926698446274, 11.763881854712963, 3.613408743403852, 6.8084727600216866, 9.45215430110693, 20.202847123146057, 9.214141722768545, 28.469438441097736, 46.02552808821201, 44.54445496201515, 24.348707757890224, 20.88727779686451, 21.43270432949066, 32.831773459911346, 30.018013045191765, 18.002767078578472, 48.601181879639626, 56.31040200591087, 40.09387157857418, 28.086107410490513, 32.37309627234936, 46.759804487228394, 48.941092640161514, 42.919460758566856, 19.035952538251877, 24.100360684096813, 27.93950367718935, 12.742893621325493, 6.313621513545513, 10.59877222403884, 28.047674372792244, 46.252470910549164, 58.92461992800236, 63.1646604090929, 61.08691670000553, 43.2650788128376, 32.00370289385319, 42.238563895225525, 54.73991207778454, 64.96177777647972, 65.38654938340187, 64.09719496965408, 62.7427614480257, 55.47977037727833, 58.42301644384861, 61.48638926446438, 63.69154393672943, 55.80242246389389, 57.312970608472824, 61.723971515893936, 55.685658529400826, 47.406974360346794, 51.61262668669224, 56.395057663321495, 55.382225811481476, 61.56442567706108, 51.739821061491966, 39.893371537327766, 27.52659883350134, 16.670691557228565, 28.312242776155472, 46.35491341352463, 54.20900456607342, 40.948692709207535, 18.392109386622906, 8.86811139062047, 13.60390366986394, 25.922100730240345, 29.552722312510014, 43.52181203663349, 26.30633421242237, 12.078201938420534, 28.52331005036831, 28.431860357522964, 21.587646715343, 16.25461768358946, 11.559008248150349, 13.277110755443573, 36.8950018286705, 43.981754556298256, 31.655223593115807, 18.768722377717495, 22.33521670103073, 22.851789481937885, 31.673734299838543, 30.8622270449996, 30.052349902689457, 29.679827392101288, 36.00016884505749, 28.36833156645298, 20.132222212851048, 17.629140727221966, 19.743130691349506, 12.696455363184214, 3.2392618199810386, 2.6709365285933018, 25.544682182371616, 45.479265600442886, 51.71330228447914, 44.05297413468361, 67.74847224354744, 65.43129578232765, 67.78212323784828, 73.70208397507668, 68.46376106142998, 57.85257585346699, 65.72236776351929, 22.092552222311497, 31.1550260335207, 39.94955152273178, 46.57434023916721, 40.27591980993748, 63.23777988553047, 94.59429770708084, 55.30890114605427, 47.0956988632679, 92.66317293047905, 35.919730961322784, 0.6000506796408445, 0.369702082243748, 0.20976015919586644, 0.21328007656848058, 0.26954631437547505, 0.2686089224880561, 0.14544475096045062, 0.1811438353615813, 0.1126551600464154, 0.10886259246035479, 0.17574671481270343, 0.14176893804688007, 0.3126392379635945, 0.2925140334991738, 0.14757118216948584, 0.2452592644840479], [0.006940501989447512, 0.028497878920461517, 0.02677446544112172, 0.03068487309064949, 0.06895343787618913, 0.02628012458444573, 0.02943872179457685, 0.0675351639802102, 0.04374692638521083, 0.17264950991375372, 0.15708078048191965, 0.15982763230567798, 0.1358522695954889, 0.18254823109600693, 0.05451974910101853, 0.04496707653743215, 0.03738785257155541, 0.242483988404274, 0.070476807304658, 0.29593714512884617, 0.5163671169430017, 1.4691599342040718, 39.83875706791878, 63.66343304514885, 62.81752623617649, 71.2565504014492, 83.20073068141937, 48.57954204082489, 53.00106458365917, 26.995009258389473, 47.93508522212505, 15.5994881875813, 50.08271858096123, 67.17763647437096, 71.13539770245552, 73.6723467707634, 57.299500331282616, 61.3311105966568, 67.84078449010849, 61.479336842894554, 47.7326662838459, 45.750833228230476, 47.91305400431156, 5.181712601333857, 0.20430074277101085, 1.5808836766518652, 7.821224341169, 10.300827361643314, 18.812534026801586, 30.42581096291542, 28.8191032782197, 26.50559362024069, 24.04344543814659, 20.89538086205721, 23.995695300400257, 18.753348402678967, 17.079925797879696, 7.526766266673803, 27.399184070527554, 45.74820376932621, 37.1617741137743, 22.3100658506155, 30.448605939745903, 39.71130430698395, 38.81081722676754, 28.517133481800556, 10.879428964108229, 25.636126175522804, 19.530268013477325, 16.323806270956993, 7.167993793264031, 2.9486337024718523, 23.867444582283497, 40.991911590099335, 53.817861154675484, 55.930376797914505, 38.290317356586456, 13.490571901202202, 9.846305251121521, 14.171447865664959, 22.41065215319395, 39.20620501041412, 50.53823433816433, 58.00205983221531, 55.2695656567812, 50.99590077996254, 50.16080819070339, 50.15682600438595, 49.44850601255894, 54.08537060022354, 52.213332653045654, 51.117228269577026, 44.27519001066685, 41.19048893451691, 52.65320844948292, 60.28292164206505, 58.31244237720966, 47.60170631110668, 18.283982388675213, 3.9827505871653557, 5.672545563429594, 2.7179483184590936, 7.479380434378982, 25.50562407821417, 37.43222840130329, 27.599104642868042, 7.257390171289444, 2.57348220795393, 9.020267575979233, 21.37519061565399, 22.616640999913216, 31.399200931191444, 25.508152842521667, 6.463101217523217, 11.97960577905178, 22.837331257760525, 22.08539340645075, 13.99484284222126, 6.268385415896773, 12.003228161484003, 40.44663704931736, 40.98772421479225, 18.626543506979942, 9.184343721717596, 20.448517240583897, 21.06678206473589, 21.60482559353113, 19.647852703928947, 24.77869838476181, 26.828832775354385, 27.989015020430088, 26.63047581911087, 28.025413267314434, 20.787905529141426, 9.245564136654139, 11.511829029768705, 4.018154237419367, 0.4518812522292137, 9.860031064599752, 27.664886713027954, 41.7934899777174, 69.08609926700592, 49.1293041408062, 50.25972828269005, 47.90574699640274, 60.244425907731056, 49.74425174295902, 52.60670654475689, 28.845544159412384, 20.88584527373314, 18.62316358834505, 5.1921021938323975, 20.73466658592224, 27.80250582844019, 64.92353662848473, 72.37963333725929, 45.34705549478531, 43.628088533878326, 63.00889536738396, 10.818103104829788, 0.4176244279369712, 0.39505598426330835, 0.09773126788786612, 0.03216378601791803, 0.10341882792999968, 0.09598991484381258, 0.02945151642052224, 0.13422987540252507, 0.09838600541115738, 0.09373678418342024, 0.0288340885163052, 0.046937482329667546, 0.029905289629823528, 0.10700117476517335, 0.010010374517150922, 0.046577900648117065, 0.05259271812974475, 0.03288829655502923, 0.04288504431315232, 0.031164576939772815, 0.10536893969401717, 0.04433491514646448, 0.04216926885419525, 0.061192695720819756, 0.035357885717530735, 0.15033289178973064, 0.054765826716902666, 0.05506791792868171, 0.01565712664159946, 0.027327593670634087, 0.0298362884495873, 0.04614472018147353, 0.0868289107165765, 0.11932117500691675, 0.06666810542810708, 0.03166675116517581, 0.4436475393595174, 0.855277581140399, 62.44412787258625, 84.14517760276794, 70.38080379366875, 75.51585584878922, 81.96710407733917, 46.11133508384228, 31.427577808499336, 36.44972272217274, 38.66343833506107, 23.885723501443863, 61.98147229850292, 72.72210896015167, 77.66695082187653, 83.50078538060188, 65.61071455478668, 71.2419743835926, 74.8374630510807, 68.7834683060646, 53.047741279006004, 52.14960627257824, 48.629573956131935, 5.721590006724, 1.9782616035081446, 4.883893132209778, 10.632072687149048, 21.246979795396328, 24.688930101692677, 31.870020367205143, 28.790211528539658, 25.97635231912136, 15.853173024952412, 24.349813498556614, 22.38937519490719, 19.6242293715477, 12.880040612071753, 6.330970907583833, 31.460548639297485, 47.96320751309395, 43.12260165810585, 25.963723696768284, 32.07225501537323, 42.63101443648338, 41.847329288721085, 33.824033215641975, 18.24155956506729, 27.527125105261803, 20.367429591715336, 15.132995769381523, 7.890620967373252, 6.416875747963786, 29.350787848234177, 46.32529400289059, 55.57953022420406, 65.49186453223228, 54.68415006995201, 22.256507724523544, 15.89917715638876, 25.071976147592068, 38.16698357462883, 50.46756573021412, 56.11688978970051, 59.76868763566017, 58.70113492012024, 52.44631715118885, 54.411712288856506, 55.690742656588554, 54.68612216413021, 58.99552792310715, 60.425900369882584, 56.399438828229904, 49.662335738539696, 43.46051752567291, 54.082775339484215, 59.54210579395294, 60.93768730759621, 59.910705015063286, 39.75357323884964, 20.358802154660225, 11.665199249982834, 7.284461343660951, 17.544517368078232, 38.7564991414547, 49.644845277071, 33.60386162996292, 9.139946904033422, 4.36349063180387, 9.70821876078844, 22.262304313480854, 20.50690110772848, 30.75152948498726, 24.675243236124516, 14.96329877525568, 19.37665555626154, 22.988895624876022, 23.285923786461353, 16.6248869150877, 6.388321230188012, 15.891027543693781, 45.97803823649883, 42.22918979823589, 24.249930158257484, 13.648566473275423, 23.08862317353487, 19.28556304425001, 17.62368991971016, 18.77398319542408, 22.032234258949757, 26.56134232878685, 25.521015152335167, 25.58155920356512, 25.44662654399872, 24.08308871090412, 16.585640721023083, 22.81504925340414, 6.056928662583232, 0.4236302134813741, 8.311215173453093, 30.882346965372562, 51.90641172230244, 70.15970885753632, 54.627221524715424, 59.2829255014658, 53.46924506127834, 67.03545570373535, 54.71690431237221, 53.847035989165306, 42.10985720157623, 24.390832297503948, 17.61126648634672, 14.708369504660368, 33.832426965236664, 28.508357852697372, 57.680692076683044, 78.16181346774101, 42.007369101047516, 44.347621724009514, 76.71727538108826, 16.927003003656864, 0.1934949538554065, 0.26368934428319335, 0.1179335814958904, 0.05734843012760393, 0.04696937612607144, 0.08290277139167301, 0.03552719186700415, 0.11589757355977781, 0.15223908325424418, 0.01987783551157918, 0.04408794324262999, 0.13156483793864027, 0.028496520790213253, 0.07445995841408148, 0.140001097752247, 0.0814209770760499, 0.1524785891524516, 0.13358619587961584, 0.11967575832386501, 0.10882809001486748, 0.20704280032077804, 0.09322720332420431, 0.12644805625313893, 0.24572076159529388, 0.23630356066860259, 0.20486585854087025, 0.19759224727749825, 0.30866485903970897, 0.25287844939157367, 0.15434354689205065, 0.20624442753614858, 0.11412610416300595, 0.19250976765761152, 0.291135924635455, 0.21363569889217615, 0.30493158905301243, 0.42869513388723135, 1.3945161458104849, 82.74822816252708, 98.0531533062458, 80.04796385765076, 88.06872546672821, 90.37648603320122, 81.37229919433594, 68.35923627018929, 40.84100268781185, 60.74348732829094, 20.387752801179886, 62.66860082745552, 73.74993860721588, 87.1697849035263, 87.71115705370903, 76.66869878768921, 76.59891933202744, 78.00533786416054, 73.91697004437447, 56.08814053237438, 58.67553569376469, 57.36756227910519, 9.31604465469718, 1.5909235691651702, 6.222388884052634, 14.348228629678488, 17.358146868646145, 24.464723132550716, 41.70505352318287, 38.85810948908329, 35.78731566667557, 32.91291430592537, 30.93077726662159, 34.38971646130085, 30.02975821495056, 28.089187145233154, 14.908822048455477, 37.045036777853966, 56.883335262537, 47.57521793246269, 30.969937965273857, 33.06217409670353, 47.18700036406517, 45.77166751027107, 39.099685326218605, 17.14074533432722, 36.68750636279583, 28.019299395382404, 23.09070736169815, 10.436361338943243, 9.819164257496595, 33.919381499290466, 46.21330261230469, 54.790966138243675, 63.965326845645905, 65.4052671790123, 38.01077015697956, 28.585108034312725, 35.935321524739265, 50.48349827528, 62.527670189738274, 62.33115993440151, 62.029117941856384, 64.39061522483826, 56.88841558992863, 60.2530400454998, 60.95991611480713, 60.782663226127625, 60.224856957793236, 63.84146109223366, 63.65994103252888, 54.298862144351006, 47.421595975756645, 59.7001127153635, 60.69283984601498, 61.473359763622284, 61.09009712934494, 50.533951967954636, 37.46049888432026, 24.692408815026283, 17.171060107648373, 24.226443618535995, 44.5415785163641, 49.924248084425926, 29.968634694814682, 12.290115617215633, 8.547680284827948, 13.363513369113207, 29.814834147691727, 28.48356608301401, 42.025342136621475, 36.33312217891216, 13.16455414518714, 19.71905328333378, 25.416535958647728, 26.316095888614655, 18.713822923600674, 9.669296499341726, 24.481677822768688, 52.83429533243179, 48.50758910179138, 27.705472335219383, 18.612719848752022, 31.64170201867819, 28.567925356328487, 28.141875118017197, 26.701843589544296, 32.20749355852604, 35.289318189024925, 35.75570896267891, 37.60666564106941, 36.23931281268597, 27.138899937272072, 13.251097351312637, 22.6122123375535, 11.489253491163254, 1.742639453150332, 16.895411498844624, 39.658958315849304, 52.10337795317173, 80.74195101857185, 63.25740583240986, 65.11050939559937, 60.38298547267914, 75.16512706875801, 61.3631808757782, 59.93530869483948, 40.29032103717327, 26.46313849836588, 24.265857003629208, 10.313911959528923, 28.654429614543915, 36.356183141469955, 79.09216314554214, 85.16870588064194, 55.051548555493355, 53.3394668251276, 87.262993901968, 22.578207962214947, 0.6817853031679988, 0.6557097961194813, 0.24823733983794227, 0.3099039488006383, 0.17757649475242943, 0.33670747303403914, 0.2092272081063129, 0.26624153077136725, 0.18583483208203688, 0.1593181924545206, 0.1961658097570762, 0.3004865994444117, 0.10856044929823838, 0.17749686230672523, 0.2532213513040915, 0.23441691737389192], [0.04385568441648502, 0.04988062479242217, 0.05021636126912199, 0.007328920282816398, 0.025014080019900575, 0.10245262586977333, 0.020256052521290258, 0.017404151549271774, 0.0627144101599697, 0.29767997504677624, 0.05850219517014921, 0.14070900273509324, 0.008766281753196381, 0.11980580486124381, 0.03787383313465398, 0.12136853780248202, 0.06254382009501569, 0.13084676553262398, 0.12256292058737017, 0.05824636944453232, 0.168166893417947, 0.32254797813948244, 22.30444025248289, 50.60267508029938, 58.767965734004974, 73.89142781496048, 91.37517124414444, 56.49026155471802, 55.28150461614132, 27.177712954580784, 41.40816405415535, 32.270235791802406, 27.795780189335346, 70.27564823627472, 63.4183993935585, 63.248210325837135, 60.77178440988064, 64.88593384623528, 65.02533316612244, 66.67720332741737, 47.20897078514099, 55.13951763510704, 33.78784395754337, 1.1196442390792072, 1.26689073164016, 5.402697818353772, 14.564538672566414, 15.118911825120449, 31.444091722369194, 32.2331003844738, 34.68784846365452, 29.903422594070435, 21.5822035074234, 18.481108210980892, 27.540469989180565, 20.11261146515608, 15.12055903673172, 3.7312470702454448, 15.3208795376122, 39.40356642007828, 37.30660334229469, 24.6838041767478, 33.12514431774616, 36.742348819971085, 37.700129225850105, 18.281958997249603, 14.19034045189619, 33.26784186065197, 30.985785014927387, 19.301875568926334, 8.607036899775267, 5.63696569763124, 22.41753738373518, 39.350886046886444, 54.07428279519081, 56.615996807813644, 33.873897939920425, 12.17763690277934, 9.744937140494585, 13.163892980664968, 19.50320016592741, 34.541339725255966, 46.961117684841156, 58.75296413898468, 58.64941969513893, 52.03896760940552, 50.93770690262318, 50.65935663878918, 48.156446143984795, 50.163418650627136, 48.521097376942635, 50.945929661393166, 41.2288136780262, 43.86377088725567, 54.37782570719719, 58.63141626119614, 57.92569153010845, 39.41091142594814, 14.444685503840446, 7.87478294223547, 4.888147478923202, 1.3979134010151029, 9.457782749086618, 27.707045450806618, 31.540471650660038, 19.515405111014843, 8.607389330863953, 6.61057130433619, 10.368192046880722, 18.616772331297398, 26.41669549047947, 27.762334384024143, 27.13980808854103, 13.179849274456501, 5.799084473401308, 16.86446975916624, 20.308610647916794, 14.495957102626562, 5.910940496250987, 23.79029542207718, 42.97365725040436, 35.54128646850586, 7.669832864776254, 14.56280691549182, 23.269596062600613, 22.48429410159588, 25.791330747306347, 29.478481896221638, 25.485340766608715, 27.4483610317111, 22.275273017585278, 25.253534205257893, 25.910404957830906, 29.125440940260887, 16.08652040362358, 10.865300372242928, 5.209538033232093, 0.6430186552461237, 1.4063799404539168, 19.538437575101852, 49.679381623864174, 62.984797060489655, 50.88075935840607, 49.100437089800835, 49.85112480819225, 59.30015757679939, 51.57736457884312, 45.1313828676939, 22.69767165184021, 25.470238476991653, 17.007746770977974, 14.013854172080755, 26.286485977470875, 46.54936037957668, 77.25375339388847, 76.6525648534298, 99.6324473619461, 53.308186903595924, 55.5832464247942, 4.9431846756488085, 0.09119265741901472, 0.35884098848327994, 0.07281828322447836, 0.06486607439001091, 0.1327897229930386, 0.10082214226713404, 0.033849329556687735, 0.10095799239934422, 0.08471896260743961, 0.08524945718818344, 0.05337521266483236, 0.019908013091480825, 0.04834340688830707, 0.09337680545286275, 0.055960840327315964, 0.07933727130875923, 0.02474194930982776, 0.08486883190926164, 0.023924822453409433, 0.034571717551443726, 0.04931590607156977, 0.05864714774361346, 0.07078577822539955, 0.12771181500284, 0.041216280733351596, 0.20490401977440342, 0.08415771342697553, 0.13392425898928195, 0.009404155825905036, 0.0959459351724945, 0.024337445429409854, 0.10128642243216746, 0.06972737915930338, 0.05805760789371561, 0.06424124541808851, 0.05792268544610124, 0.2734147442970425, 0.39738819818012416, 34.44316439330578, 73.99467587471008, 71.10992386937141, 85.31920820474625, 91.10479295253754, 67.74661034345627, 36.37393578886986, 30.693037323653698, 41.00288160145283, 31.106042861938477, 43.83023388683796, 73.77210661768913, 78.01352262496948, 69.88586515188217, 71.39002203941345, 70.69088995456696, 78.56575459241867, 71.43352970480919, 52.988221272826195, 59.70064848661423, 37.40249879658222, 1.091129262931645, 4.621043186634779, 10.943522024899721, 26.696236990392208, 23.385052867233753, 34.137824177742004, 30.698700919747353, 29.58094909787178, 23.866673223674297, 19.665162675082684, 21.98978863656521, 23.841303884983063, 17.954749055206776, 11.596493236720562, 4.235607068985701, 17.422450818121433, 42.7076905220747, 44.739593490958214, 28.855064548552036, 34.51892852783203, 40.53399816155434, 36.42107605934143, 25.950302816927433, 20.175517089664936, 29.813694208860397, 27.36208476126194, 18.65966632962227, 10.561238788068295, 6.04817203246057, 28.755126111209393, 45.41901983320713, 54.67706725001335, 63.99750351905823, 48.65241453051567, 20.50990864634514, 14.485748000442982, 20.145967975258827, 32.555463686585426, 48.133438378572464, 52.652718275785446, 61.959471479058266, 60.17257936298847, 58.11741404235363, 56.01646117866039, 58.059725537896156, 55.62270350754261, 55.67806273698807, 57.326589077711105, 57.44104653596878, 49.59070198237896, 48.20494294166565, 56.10731430351734, 57.108967155218124, 60.71030370891094, 56.95318691432476, 36.375296115875244, 17.709586210548878, 8.043215554207563, 6.106565399095416, 16.901884451508522, 34.54840734601021, 39.017997309565544, 23.173831701278687, 11.725487764924765, 7.785254521295428, 9.657855313271284, 19.13119252771139, 25.71129184216261, 30.139576122164726, 23.137959726154804, 17.738825641572475, 13.124275356531143, 18.919414691627026, 22.11582027375698, 14.349909089505672, 8.560384903103113, 31.996623873710632, 44.763991981744766, 37.65932321548462, 11.175396032631397, 17.14055724442005, 24.552954398095608, 22.469860576093197, 25.425254590809345, 25.75846441090107, 23.832646049559116, 26.814051568508148, 23.40346857905388, 25.299390144646168, 24.573815278708935, 28.479367308318615, 19.115349277853966, 19.060691110789776, 16.866280362010002, 1.8849331489764154, 1.51371301850304, 22.70430989563465, 58.16127888858318, 66.72834858298302, 57.83166937530041, 55.795316845178604, 59.00501221418381, 64.71137881278992, 58.395133540034294, 53.85392501950264, 34.75281357765198, 25.636563152074814, 20.479821860790253, 17.335568480193615, 23.955723345279694, 34.09444570541382, 75.90516775846481, 71.62325352430344, 91.53803050518036, 57.17167139053345, 68.77155214548111, 8.545463103801012, 0.2282442821888253, 0.26994832092896104, 0.025422235266887583, 0.09476876279222779, 0.18568911880720407, 0.07636620925040916, 0.1297824367065914, 0.14055511099286377, 0.026970500039169565, 0.023005468465271406, 0.036775636399397627, 0.04339860679465346, 0.049432894520577975, 0.05473786259244662, 0.04176985239610076, 0.10848571502720006, 0.1107639451220166, 0.1179047193727456, 0.14416203775908798, 0.12734609947074205, 0.1714550529140979, 0.23383157065836713, 0.2308986327261664, 0.2201959429658018, 0.26762311288621277, 0.30234538251534104, 0.25274964224081486, 0.3563659853534773, 0.12889041972812265, 0.2442459954181686, 0.10252517080516554, 0.1748616888653487, 0.15839764731936157, 0.1896227538236417, 0.19326864334288985, 0.3272639407077804, 0.24397652159677818, 0.17413398338248953, 39.8151109367609, 97.9419256746769, 79.63187098503113, 94.5172530412674, 94.9319551885128, 83.13370987772942, 78.99458438158035, 35.56340888142586, 58.21037605404854, 37.28181727230549, 38.857581317424774, 76.77263081073761, 81.89162492752075, 75.59235334396362, 77.08593919873238, 79.78940293192863, 82.45021775364876, 80.07058024406433, 56.302540227770805, 65.66948220133781, 44.45875436067581, 3.0985088227316737, 3.6142337741330266, 9.589488431811333, 22.873750403523445, 20.797045938670635, 39.370523393154144, 44.296111688017845, 44.79923889040947, 40.53976625204086, 29.973737820982933, 27.770156264305115, 36.96251280605793, 32.45702996850014, 25.67764464765787, 10.41428642347455, 23.276006318628788, 50.128730311989784, 47.94593743979931, 32.285841554403305, 37.20239393413067, 42.47941017150879, 40.836127549409866, 28.340760245919228, 21.7966677993536, 46.86578840017319, 42.153790444135666, 22.599659711122513, 12.916932832449675, 10.507429875433445, 32.79562599956989, 46.1632326990366, 53.67601856589317, 65.07166787981987, 59.67495046555996, 34.59092706441879, 24.69714906066656, 31.647908985614777, 43.6362124979496, 59.84270766377449, 61.08704589307308, 69.58561286330223, 67.5509512424469, 61.38897769153118, 60.69553770124912, 62.11319603025913, 57.67064541578293, 55.9248860925436, 59.73691754043102, 62.882324159145355, 51.82869829237461, 54.19865772128105, 60.91866172850132, 57.60159932076931, 59.443998858332634, 56.95747688412666, 48.927561566233635, 32.683319225907326, 17.899809703230858, 10.538088530302048, 25.539681650698185, 39.78978909552097, 42.060250863432884, 23.214595913887024, 13.652634155005217, 13.474559560418129, 16.39559391885996, 25.662745647132397, 33.95826481282711, 39.487249329686165, 35.65322086215019, 21.614811457693577, 10.481996890157461, 23.18897768855095, 28.00531044602394, 18.029928021132946, 11.95131154730916, 37.37265519797802, 52.39917688071728, 44.22231584787369, 14.067721981555223, 25.2540547773242, 33.175928592681885, 29.19917408376932, 34.20686647295952, 35.95654338598251, 34.08720709383488, 38.24742145836353, 29.381706789135933, 33.42969037592411, 32.75480479001999, 37.905777990818024, 21.016862243413925, 17.215303033590317, 15.9817486256361, 1.7141490569338202, 3.562842719256878, 32.047107964754105, 64.88251402974129, 75.26642963290215, 59.07093107700348, 60.6277759373188, 60.82503095269203, 72.2823129594326, 60.57558573782444, 58.62149879336357, 32.54965379834175, 32.14304521679878, 21.238223165273666, 19.87346939742565, 33.67689751088619, 54.80049982666969, 91.79928168654442, 85.81828102469444, 98.18027168512344, 67.79253467917442, 82.337067425251, 11.753809545189142, 0.4253416950814426, 0.4315882036462426, 0.2259708908968605, 0.17691647313768044, 0.1715421216795221, 0.26209328148979694, 0.3035286330850795, 0.24442520923912525, 0.157565877889283, 0.12345661481958814, 0.1628014477319084, 0.14730207942193374, 0.119315542106051, 0.1941976638045162, 0.1461806645966135, 0.18599859438836575], [0.015137585232878337, 0.07199128580396064, 0.062164734772522934, 0.06907755465363152, 0.030724759817530867, 0.017506859221612103, 0.04412508031236939, 0.11779258085880429, 0.07640719064511359, 0.05306372586346697, 0.0455131487979088, 0.11089073363109492, 0.1798746144049801, 0.013821477241435787, 0.0704244858934544, 0.060718070017173886, 0.049994184519164264, 0.08288204320706427, 0.17347888962831348, 0.09901596262352541, 0.4065867030294612, 0.8850558113772422, 12.755062468349934, 35.84963992238045, 50.75141429901123, 59.91338387131691, 67.96177759766579, 63.85921373963356, 49.750437811017036, 37.82075755298138, 21.146708875894547, 45.665379613637924, 13.201296273618937, 43.998903036117554, 68.72690454125404, 76.4549070596695, 67.39406526088715, 66.30226984620094, 60.695419907569885, 66.4452713727951, 50.20359769463539, 60.50556309521198, 17.764278575778008, 0.4344775032950565, 2.898413697257638, 12.2420016489923, 13.265207894146442, 23.88699073344469, 33.9868088811636, 33.37324060499668, 31.78199429064989, 25.436976961791515, 18.102226741611958, 25.585294403135777, 26.05179727077484, 17.95904092490673, 13.130330331623554, 2.863725833594799, 7.781929224729538, 27.433802112936974, 37.710016295313835, 29.257514253258705, 31.020520851016045, 30.00726532191038, 29.351186826825142, 11.288561560213566, 19.09502036869526, 36.86740390956402, 34.57061715424061, 22.45662398636341, 11.6081234626472, 5.082393055781722, 20.14605537056923, 32.841375544667244, 46.48453585803509, 52.2763142734766, 33.284036591649055, 12.945151068270206, 10.504092704504728, 13.139609433710575, 17.055263221263885, 29.11811873316765, 42.31926016509533, 58.29711399972439, 57.08632417023182, 53.17603759467602, 50.49212381243706, 52.15372905135155, 47.85601906478405, 46.74989841878414, 51.940393298864365, 50.27634859085083, 44.58746485412121, 46.252600103616714, 57.02263958752155, 60.384619385004044, 54.2059875279665, 27.457336150109768, 8.183372933417559, 7.119006346911192, 2.0954604959115386, 6.1166776064783335, 19.396270103752613, 34.590501487255096, 23.277579434216022, 15.312174204736948, 12.027456611394882, 11.49822860956192, 13.621814958751202, 18.750154674053192, 25.65503016114235, 31.484686844050884, 21.38615682721138, 22.633740082383156, 4.667044468224049, 10.18442440778017, 15.570985917001963, 11.82533310726285, 10.324499141424894, 30.609295517206192, 43.01829345524311, 14.999393038451672, 4.328290745615959, 16.59155510365963, 21.107474081218243, 25.82530852407217, 21.71918425709009, 23.573064878582954, 22.25537348538637, 24.59966529160738, 26.167170479893684, 25.472229570150375, 31.179669611155987, 33.878742679953575, 32.0673418790102, 11.807044688612223, 6.3663356099277735, 3.872806099243462, 0.14054397877771407, 9.83265733346343, 41.61441698670387, 67.08267956972122, 57.58359968662262, 52.63514801859856, 51.4896234869957, 52.44262754917145, 51.056686118245125, 46.88478358089924, 19.77748464792967, 27.0259016007185, 20.95526184886694, 27.856909409165382, 35.208796709775925, 61.12978219985962, 71.46759107708931, 90.4599067568779, 94.35333743691444, 54.892941266298294, 53.30350935459137, 2.2160161519423127, 0.1349100240622647, 0.16960373584879562, 0.0240859056066256, 0.08420028301770799, 0.13864983979146928, 0.049292190742562525, 0.03248572596930899, 0.04358225494797807, 0.06129912711912766, 0.04485619596380275, 0.03280801101936959, 0.12478898512199521, 0.03316690992505755, 0.10428204957861453, 0.07809127957443707, 0.019250850600656122, 0.004609303423421807, 0.07000984056503512, 0.05266600150207523, 0.022024300997145474, 0.031084441689017694, 0.061945125853526406, 0.06689552174066193, 0.1252390828449279, 0.145611897460185, 0.12283609772566706, 0.07215151548734866, 0.022715969644195866, 0.021741253294749185, 0.016196298784052487, 0.07982817231095396, 0.03679161854961421, 0.052325804717838764, 0.12912076752400026, 0.046620325520052575, 0.14055316656595096, 0.3937566914828494, 0.9364581468980759, 16.636751778423786, 58.13472591340542, 65.76121687889099, 71.30385026335716, 83.1416742503643, 67.31236964464188, 49.596998244524, 29.807749427855015, 33.10374766588211, 37.48897835612297, 27.408987544476986, 50.833653286099434, 80.19886136054993, 78.15933600068092, 75.28057247400284, 69.81241509318352, 68.63530665636063, 74.38476294279099, 58.95847611129284, 65.46714305877686, 23.226037099957466, 0.8993151993490756, 3.858857760205865, 21.309805624186993, 20.676924884319305, 28.04648693650961, 36.6885931044817, 32.8198155015707, 32.88289971649647, 22.11065825074911, 19.522763416171074, 25.384361185133457, 25.157517157495022, 18.20138432085514, 10.348748490214348, 3.671519737690687, 7.127563962712884, 29.393909834325314, 44.759360030293465, 38.73665660619736, 34.74329128861427, 30.490726679563522, 31.33086919784546, 21.43215335905552, 19.77811921387911, 30.9728467091918, 30.419531799852848, 21.987322568893433, 12.830461822450161, 4.523815903812647, 21.767012290656567, 41.206558272242546, 48.08713026344776, 63.33570443093777, 49.627503007650375, 20.70043422281742, 13.80601292476058, 19.968939274549484, 28.405309282243252, 40.79228550195694, 51.40655614435673, 61.58222772181034, 60.29511518776417, 57.78427451848984, 55.96989467740059, 58.663554936647415, 53.76803822815418, 52.02520094811916, 58.149336129426956, 57.30885162949562, 47.81872786581516, 52.5417186319828, 60.03292925655842, 59.9190341681242, 61.91687196493149, 48.9907331764698, 25.264992490410805, 10.742474813014269, 5.732193812727928, 10.072871893644333, 20.785629451274872, 38.66748511791229, 33.17043028771877, 18.44497784972191, 17.265680730342865, 13.805251065641642, 12.091630417853594, 19.533978514373302, 25.531561486423016, 30.235908553004265, 22.38877672702074, 23.33908673375845, 12.332097664475441, 16.966555081307888, 15.736869815737009, 12.207312360405922, 17.035597376525402, 35.10188564658165, 44.83123317360878, 20.2494041249156, 9.480172097682953, 17.63605445623398, 21.039125248789787, 23.870919495821, 21.105376593768597, 22.450605109333992, 26.205495223402977, 24.38514780253172, 27.260377518832684, 26.79026674479246, 28.387387543916702, 32.17244043946266, 36.67896442115307, 17.881034910678864, 16.57606903463602, 9.2545354552567, 0.40531335573177785, 14.613618738949299, 55.98613880574703, 69.29708674550056, 59.79265674948692, 57.8398085385561, 59.650973752141, 58.19956563413143, 58.963841423392296, 52.21067659556866, 30.370953306555748, 29.214631654322147, 22.52143520861864, 25.044007748365402, 27.199898064136505, 52.16224439442158, 78.42835396528244, 97.1294304728508, 95.66333994269371, 59.46997806429863, 68.39327484369278, 3.0610447330400348, 0.032746453580330126, 0.15530489530647174, 0.0615549639769597, 0.16810360306408256, 0.06867099873488769, 0.03388524208276067, 0.05585250532021746, 0.02024809113208903, 0.043493297416716814, 0.06594616643269546, 0.06465462167398073, 0.04642959356715437, 0.031424814733327366, 0.050118535073124804, 0.07075864530634135, 0.03315968882816378, 0.10020684989285655, 0.11827677284600213, 0.2485732507193461, 0.1441442855866626, 0.13718506292207167, 0.19641067396150902, 0.2472151056281291, 0.34556907252408564, 0.35469229391310364, 0.17548761621583253, 0.18974492617417127, 0.13303935178555548, 0.34654734190553427, 0.1433904268196784, 0.1869577163597569, 0.18746969435596839, 0.0934753478213679, 0.2659601380582899, 0.19916120683774352, 0.1553470641374588, 0.36654302675742656, 0.7877367991022766, 17.79675353318453, 86.32072046399117, 77.0112656056881, 81.20859637856483, 90.83398908376694, 76.65079414844513, 74.34134647250175, 48.58450457453728, 35.35553343594074, 56.90978944301605, 21.119872815907, 48.43158558011055, 83.28786000609398, 91.06877088546753, 82.76810109615326, 78.10081154108047, 75.76171785593033, 80.38970991969109, 62.33871012926102, 69.09728586673737, 28.54659140110016, 0.7813928613904864, 8.802806194871664, 18.225834108889103, 17.887091785669327, 31.03286638855934, 45.00679895281792, 44.40946340560913, 41.868064776062965, 34.654744639992714, 28.37232895195484, 37.11154840886593, 38.07741478085518, 32.19933159649372, 23.650466725230217, 10.220337230712175, 12.307547181844711, 34.1983587294817, 50.1473531126976, 41.46767646074295, 36.94993928074837, 33.9005421102047, 35.89974403381348, 17.704329192638397, 27.250021174550056, 49.96047914028168, 44.05411407351494, 28.656027428805828, 16.614053696393967, 9.349288120865822, 26.929229088127613, 41.71079881489277, 46.702849343419075, 64.20510917901993, 61.48573189973831, 35.093400701880455, 23.49720384925604, 33.66576410830021, 44.21481505036354, 56.13521620631218, 56.90910927951336, 65.65131917595863, 63.95252153277397, 61.46785765886307, 60.664231181144714, 63.15584868192673, 58.216710314154625, 54.833626449108124, 62.54043750464916, 60.28463535010815, 51.799819841980934, 58.6439023911953, 64.76935610175133, 60.56133650243282, 65.7019704580307, 55.81009425222874, 31.092941164970398, 22.332237660884857, 11.90923260524869, 17.993970550596714, 26.686494313180447, 45.661933198571205, 30.070064552128315, 19.356140457093716, 22.564553394913673, 18.430166244506836, 22.684900537133217, 28.278278298676014, 34.65935379266739, 39.30556207895279, 31.181949488818645, 32.468604147434235, 11.086606197059155, 18.32896627485752, 19.780248999595642, 17.11055025458336, 22.101624235510826, 41.7545572668314, 53.52829769253731, 24.64434139430523, 13.55870509520173, 25.344632416963577, 31.36506736278534, 33.71253579854965, 28.263092413544655, 32.44672492146492, 32.40248389542103, 30.649592354893684, 37.086796537041664, 32.603458911180496, 39.12496916949749, 41.89908251166344, 43.95052783191204, 18.956263214349747, 13.764521051198244, 7.203623056411743, 0.5822460225317627, 20.57297196239233, 57.92012482881546, 80.32037883996964, 66.34818658232689, 62.45765134692192, 66.97531253099442, 64.98114913702011, 65.62725886702538, 53.44620309770107, 28.97042255848646, 32.85678751766682, 26.185436099767685, 35.16025431454182, 48.223934322595596, 75.61844274401665, 89.84762281179428, 95.2800165116787, 102.4463863670826, 65.01267224550247, 79.05944690108299, 3.1259680492803454, 0.2537082595517859, 0.3533523908117786, 0.15413298475323245, 0.23273478029295802, 0.3076624550158158, 0.15148366597713903, 0.19856603408697993, 0.11199245927855372, 0.25884442613460124, 0.1879102480597794, 0.17611511691939086, 0.2339456684421748, 0.1493337532156147, 0.15410809312015772, 0.09330739238066599, 0.2009391997125931], [0.027158840421179775, 0.08362158594536595, 0.059426495572552085, 0.026270248454238754, 0.03980640052759554, 0.06384499050909653, 0.06377051598974504, 0.024409229663433507, 0.063749765540706, 0.04360428560175933, 0.08454221271676943, 0.09096910027437843, 0.023667274945182726, 0.05041981363319792, 0.029939634368929546, 0.045200385502539575, 0.06455452079535462, 0.03539023222401738, 0.11336112802382559, 0.038722152457921766, 0.12741655897116289, 0.2149414483574219, 1.5380099834874272, 37.77555137872696, 58.378995805978775, 50.564787313342094, 60.77408328652382, 82.85108864307404, 48.01293544471264, 56.61282777786255, 25.88240996003151, 43.9447445422411, 20.442600958049297, 36.63197234272957, 62.8082737326622, 75.55622488260269, 63.46679739654064, 74.36150819063187, 72.44370549917221, 59.350402280688286, 67.48120218515396, 53.13746206462383, 9.411554429680109, 0.3687242284649983, 6.304913805797696, 15.315200742334127, 23.068845234811306, 29.95802566409111, 32.17605784535408, 32.386916130781174, 28.313513807952404, 20.848117098212242, 13.152312152087688, 24.54573478549719, 24.80834249407053, 19.724956266582012, 11.57309789210558, 4.298939220607281, 3.22579154279083, 16.167172975838184, 32.67701156437397, 36.30493529140949, 29.05903570353985, 30.410218499600887, 15.5235112644732, 13.023828696459532, 26.127348616719246, 19.786273576319218, 19.638600200414658, 21.45660124719143, 17.328016385436058, 6.169014573097229, 16.927331686019897, 28.739615343511105, 39.08471792936325, 49.67191882431507, 37.70528934895992, 14.29858524352312, 11.631886437535286, 15.709803868085146, 16.4957432448864, 25.660676658153534, 39.21541191637516, 56.193653270602226, 59.45354774594307, 55.671595484018326, 53.5528139770031, 54.17175896465778, 46.2892035394907, 41.97490744292736, 52.95732133090496, 49.605859369039536, 44.833262264728546, 48.77723403275013, 60.53601086139679, 60.7915623486042, 39.40472915768623, 13.248032815754414, 8.299351260066032, 5.611754050478339, 6.598028177395463, 16.377299800515175, 38.05605232715607, 31.03453639894724, 28.146573565900326, 14.598145019263029, 19.223899953067303, 17.656324468553066, 14.235715717077255, 18.735500760376453, 24.737535193562508, 32.39067792892456, 24.9545681476593, 24.171791151165962, 16.801769323647022, 7.264454942196608, 9.343263544142246, 9.669078011065722, 24.26452897489071, 37.586412727832794, 24.074544869363308, 1.4496597368270159, 8.180518336594105, 16.83149892836809, 23.747889697551727, 23.113969713449478, 20.69155029952526, 23.911856599152088, 19.70193900167942, 29.94567822664976, 29.24999825656414, 30.830728635191917, 29.35172449797392, 34.06079091131687, 32.95147843658924, 19.43674173206091, 11.72339502722025, 9.097703620791435, 1.266209261957556, 5.071761226281524, 32.69617013633251, 44.24742870032787, 57.19259686768055, 56.527776941657066, 52.84232050180435, 46.036566495895386, 58.16478990018368, 51.29953868687153, 19.333031997084618, 30.59306088835001, 31.224934682250023, 33.26936557888985, 42.21509635448456, 72.9833373427391, 57.06064514815807, 31.017452515661716, 42.79888942837715, 71.12099647521973, 23.8941153511405, 0.4986019420903176, 0.3720405005151406, 0.11130143073387444, 0.03181755557307042, 0.05238830839516595, 0.12403095548506826, 0.08223303506383672, 0.02382433565799147, 0.05938967391557526, 0.016657070445944555, 0.05152205136255361, 0.07414948093355633, 0.028455172032408882, 0.09723791779833846, 0.07405565120279789, 0.027897477739315946, 0.03343420183227863, 0.05336831069143955, 0.007104203532435349, 0.08177180512575433, 0.03390073812624905, 0.030983259130152874, 0.04203911099466495, 0.04328780043579172, 0.03866937833663542, 0.025677782687125728, 0.027372779331926722, 0.07840812468202785, 0.020131419951212592, 0.14252851135097444, 0.043906150458496995, 0.05013456546294037, 0.013768281951342942, 0.06991181769990362, 0.030928186206438113, 0.10846316115930676, 0.06864406619570218, 0.07693577048485167, 0.4321681772125885, 3.242629626765847, 55.56376487016678, 77.05081388354301, 60.3837264329195, 76.29029989242554, 78.4744530916214, 46.73338070511818, 43.6442756652832, 31.202048510313034, 35.625687539577484, 26.78423836827278, 45.650606006383896, 71.36808961629868, 81.32550850510597, 68.94055187702179, 81.75087288022041, 81.23564332723618, 64.29644107818604, 71.65708690881729, 58.53484444320202, 13.696917928755283, 0.6321105686947703, 9.660485722124577, 23.02415393292904, 28.389798514544964, 33.97408716380596, 31.30452711135149, 32.01232463121414, 28.04997894912958, 22.454336509108543, 16.400564052164555, 22.51738842576742, 24.371098056435585, 19.152978658676147, 9.718083031475544, 5.358463916927576, 2.2127459524199367, 17.19282913953066, 38.26752997934818, 43.43450792133808, 34.915482848882675, 27.510945573449135, 23.414267599582672, 20.645247884094715, 24.32094644755125, 24.91835419088602, 18.18466331809759, 22.02318124473095, 14.97897768393159, 7.057347530499101, 19.395261257886887, 33.932278007268906, 46.564240381121635, 57.81475268304348, 48.70026156306267, 25.20361438393593, 16.044665649533272, 18.65826230496168, 28.063460625708103, 40.96104584634304, 48.24470400810242, 60.403340980410576, 61.46821103990078, 62.070193737745285, 58.71254950761795, 59.17752295732498, 52.748150154948235, 47.281125113368034, 58.214179649949074, 57.85311922430992, 48.82571563124657, 54.47605423629284, 62.14878872036934, 65.88583499193192, 53.57269451022148, 33.25646907091141, 13.489852789789438, 8.579952903091908, 7.4238302651792765, 19.48365591466427, 36.45585939288139, 35.408920571208, 30.617563873529434, 17.32813037931919, 24.06135767698288, 19.058614522218704, 10.968691874295473, 17.05910101532936, 23.158951699733734, 26.976557448506355, 21.957549266517162, 24.549110904335976, 22.574742548167706, 19.412426836788654, 11.60651994869113, 13.626273069530725, 32.54315234720707, 38.88013310730457, 26.919929087162018, 5.261035719886422, 10.311767924576998, 15.034149773418903, 18.956791386008263, 21.489621475338936, 19.66017734259367, 26.203034855425358, 21.439371071755886, 30.022019930183887, 32.011940851807594, 26.81534729897976, 23.746120892465115, 33.468710482120514, 36.30697578191757, 26.589196734130383, 15.513485502451658, 14.873574189841747, 2.2258692607283592, 3.802436012774706, 45.419426411390305, 54.99832481145859, 63.64952199161053, 62.96290643513203, 60.623953342437744, 53.91325123608112, 62.06670552492142, 55.775474309921265, 27.948632687330246, 30.472968332469463, 25.48551745712757, 28.138599693775177, 33.68280619382858, 73.75813096761703, 65.48442453145981, 44.8457407951355, 52.75517217814922, 81.72632619738579, 35.83515889942646, 0.8698343031574041, 0.26438286644406617, 0.07926790276542306, 0.04360424107289873, 0.18011634674621746, 0.04754361660161521, 0.03537025360856205, 0.02017844613874331, 0.14993376476923004, 0.06317538776784204, 0.12050947960233316, 0.049626951295067556, 0.05371586958062835, 0.16335823660483584, 0.09648057093727402, 0.06559883389854804, 0.015999588831618894, 0.18244973325636238, 0.12921553978230804, 0.1792622238281183, 0.10972168776788749, 0.12092383549315855, 0.17848181101726368, 0.16015327186323702, 0.2420683708623983, 0.33392323181033134, 0.08953844735515304, 0.1596646715188399, 0.3727841918589547, 0.3168810869101435, 0.2912970003671944, 0.17598270293092355, 0.08595864608651027, 0.13675488444278017, 0.21726934297475964, 0.23103511368390173, 0.06685298183583654, 0.16270090156467631, 0.48834756889846176, 1.5177808189764619, 73.9560167491436, 92.53166198730469, 66.38107001781464, 85.87615191936493, 90.63657447695732, 69.46420177817345, 73.61741691827774, 37.91028834879398, 53.553095161914825, 27.065877355635166, 44.84835505485535, 75.60828968882561, 87.5818195939064, 78.5665525496006, 87.2946386039257, 84.04385983943939, 71.84699311852455, 74.61468860507011, 65.94565898180008, 17.56928063929081, 0.27616876526735723, 12.335941158235073, 20.113593712449074, 32.606141567230225, 36.96847088634968, 41.43742248415947, 42.16164082288742, 37.24070727825165, 29.060209840536118, 22.060284353792667, 33.76878418028355, 37.67432101070881, 31.85675337910652, 23.054926581680775, 12.508623842149973, 6.731218630447984, 24.704938642680645, 45.71343943476677, 48.10265243053436, 36.969865411520004, 34.27592396736145, 21.23232588171959, 17.767432406544685, 35.79756751656532, 29.83362603932619, 28.77920161932707, 29.761844091117382, 21.891138330101967, 12.396540306508541, 22.894140109419823, 37.33450144529343, 45.54168865084648, 54.64552894234657, 61.635295674204826, 42.997519969940186, 26.09260518103838, 33.088643476367, 43.50062817335129, 57.38068297505379, 55.32928705215454, 68.54480311274529, 65.70065572857857, 65.15892639756203, 58.600132539868355, 63.57381485402584, 56.45295135676861, 49.62748020887375, 58.702434450387955, 57.874044701457024, 51.083030104637146, 57.92134456336498, 65.59482380747795, 67.13053420186043, 59.46136012673378, 40.44486254453659, 23.268705010414124, 18.35645589977503, 20.883451402187347, 32.41261035203934, 47.2881281375885, 44.98879171907902, 35.80993205308914, 21.00715946406126, 26.980199553072453, 23.607179448008537, 23.827945701777935, 24.885539151728153, 31.278378814458847, 42.830921709537506, 33.80265936255455, 31.035492047667503, 28.336263187229633, 16.235489509999752, 15.364190563559532, 18.085091561079025, 37.952154502272606, 49.94299627840519, 32.14080713689327, 7.554262541234493, 15.144366659224033, 24.96961534023285, 33.96154023706913, 31.707069911062717, 29.974520578980446, 33.26947197318077, 28.34655113518238, 39.77783113718033, 40.31321480870247, 38.002927377820015, 37.89020262658596, 43.70808184146881, 40.1317935436964, 29.624342769384384, 17.873110435903072, 13.703584671020508, 1.575402827002108, 9.29764699190855, 52.85375788807869, 59.41347509622574, 73.20227399468422, 66.57650113105774, 71.24423146247864, 58.563559502363205, 73.521259278059, 59.45495367050171, 27.260899990797043, 33.78188207745552, 37.382435873150826, 46.38043284416199, 54.236108511686325, 92.49478116631508, 71.29656225442886, 48.257136940956116, 57.84760192036629, 93.50271508097649, 35.50533279776573, 0.8707844302989542, 0.6151859799865633, 0.2888732054270804, 0.17375339521095157, 0.22738156520063058, 0.2536425646394491, 0.21752807049779221, 0.2114584157243371, 0.2776663895929232, 0.1712127120117657, 0.3394697466865182, 0.10206276085227728, 0.1257656663074158, 0.26030663517303765, 0.25960144645068794, 0.2988639974500984, 0.16839519288623706], [0.07296106501598842, 0.02613387881865492, 0.08468389612971805, 0.06486679427325726, 0.09635019043344073, 0.09109851598623209, 0.07598927986691706, 0.05099717483972199, 0.038358507517841645, 0.01559830030601006, 0.0446106526942458, 0.10450657151523046, 0.1255229691741988, 0.018632645296747796, 0.012557917943922803, 0.08815630862955004, 0.03890396750648506, 0.13281250692671165, 0.11848241454572417, 0.08555467284168117, 0.08399746890063398, 0.3198375360807404, 0.4884695779765025, 10.5468375608325, 64.78805869817734, 50.29412403702736, 54.51473616063595, 75.736054033041, 76.38923898339272, 48.559669107198715, 38.58117654919624, 33.904657289385796, 30.914789624512196, 44.48555052280426, 68.1135642528534, 77.07134038209915, 70.22705644369125, 60.21108269691467, 66.16119861602783, 77.79792979359627, 71.40389129519463, 45.91661833226681, 4.57471844740212, 3.1833074474707246, 8.524814061820507, 18.973746076226234, 32.24231868982315, 27.248940132558346, 36.66358284652233, 33.420312479138374, 27.95546282082796, 25.046711303293705, 17.36719038337469, 22.507366463541985, 25.860392041504383, 18.403976149857044, 12.799960859119892, 3.2605736888945103, 1.990168027114123, 7.2065341752022505, 19.92196809500456, 38.06681714951992, 30.35188402980566, 23.255236633121967, 6.253678305074573, 22.16215118765831, 27.48517155647278, 20.013085305690765, 15.57482561096549, 19.81140162795782, 21.554035618901253, 6.604353887960315, 13.749910835176706, 23.490727096796036, 26.89236916601658, 41.99072979390621, 52.103640139102936, 27.694534622132778, 14.117563907057047, 16.699197627604008, 17.68901601433754, 25.391846783459187, 39.82088662683964, 52.7936565130949, 59.007873460650444, 55.69015748798847, 58.574176132678986, 58.69448907673359, 39.55411434173584, 44.304019063711166, 58.06511364877224, 49.63396646082401, 48.6441195756197, 53.80370691418648, 62.727661058306694, 54.28672179579735, 25.551996789872646, 13.349975645542145, 9.615991059690714, 6.419007908552885, 20.294712893664837, 35.92399053275585, 28.596273735165596, 22.538408897817135, 14.666637293994427, 9.831445198506117, 18.756621927022934, 22.359541095793247, 21.862124986946583, 16.556539982557297, 23.13509088009596, 38.27404282987118, 34.917591735720634, 22.84116145223379, 33.088324293494225, 11.581085063517094, 9.936040285974741, 18.78756556659937, 33.641878589987755, 26.759581491351128, 6.041200356557965, 4.292825823649764, 11.734450533986092, 17.32918292284012, 17.90685072541237, 18.108114525675774, 18.66502784192562, 18.05272299796343, 27.884619422256947, 28.423918783664703, 23.662360087037086, 32.66302831470966, 34.57051835954189, 44.870150685310364, 33.71869906783104, 31.988636702299118, 31.408481933176517, 27.952120900154114, 6.799444919452071, 0.8109586592763662, 19.61652908474207, 38.69774289429188, 33.195239156484604, 46.36804550886154, 55.46372763812542, 39.47037063539028, 60.97422994673252, 43.24599623680115, 24.965232275426388, 35.93083016574383, 36.669863909482956, 37.03279383480549, 60.483611673116684, 71.59615337848663, 45.84942653775215, 35.15864700078964, 62.682762667536736, 33.461183086037636, 1.1218586890026927, 0.034764568335958757, 0.08786226229858585, 0.06456692208303139, 0.06106905020715203, 0.08272356499219313, 0.045241114567033947, 0.05336266665835865, 0.06961319973925129, 0.022718433574482333, 0.015284096316463547, 0.02921079154475592, 0.049540524487383664, 0.06477844901382923, 0.07548756577307358, 0.07867953550885431, 0.24835888878442347, 0.04065861241542734, 0.05538583543966524, 0.04503675678279251, 0.2084080848726444, 0.024523069550923537, 0.08643042194307782, 0.03176690770487767, 0.0921106050373055, 0.034661639874684624, 0.03803098290518392, 0.05204283865168691, 0.05472521639603656, 0.06744304861058481, 0.09086425707209855, 0.04033701756270602, 0.022983345043030567, 0.051037354714935645, 0.026588520340737887, 0.07734421145869419, 0.08282784416223876, 0.12946549511980265, 0.03493629388685804, 0.4170032206457108, 0.3965619206428528, 18.497354239225388, 83.0884999036789, 61.84101663529873, 65.02344086766243, 88.99968311190605, 66.63078501820564, 43.20802107453346, 40.80301612615585, 36.67602717876434, 28.270405121147633, 55.208730921149254, 67.70207673311234, 84.90132942795753, 75.63021451234818, 69.78716924786568, 64.6744903922081, 81.89240768551826, 75.36086216568947, 58.38703617453575, 7.466710489243269, 1.6395958699285984, 17.125838734209538, 22.11518570780754, 33.424249067902565, 26.430583745241165, 33.72509032487869, 33.641114830970764, 27.690193355083466, 28.118456974625587, 19.31520715355873, 18.923649564385414, 26.221978738904, 19.15762770920992, 9.303472079336643, 3.7315759900957346, 1.8547790357843041, 6.501665823161602, 24.85712807625532, 44.03811693191528, 37.04490378499031, 26.357754953205585, 16.46891288459301, 23.9731378108263, 29.84045047312975, 21.10664002597332, 15.576348379254341, 21.35548487305641, 18.015369102358818, 8.58095034956932, 14.928586687892675, 26.236577555537224, 30.715872198343277, 48.794963881373405, 56.03210113942623, 33.37396256625652, 18.761280477046967, 19.806777276098728, 27.845532819628716, 36.041396632790565, 49.992633014917374, 59.200207740068436, 63.52259360253811, 61.471285074949265, 62.473492696881294, 64.60439175367355, 47.907996475696564, 48.48997324705124, 64.12348195910454, 55.84018103778362, 52.5221648812294, 57.19414338469505, 62.966189458966255, 62.79722012579441, 40.70639491081238, 20.035764388740063, 12.91103744879365, 11.382523868232965, 21.279346458613873, 38.689250349998474, 34.70511473715305, 27.86734364926815, 21.025428883731365, 16.238696537911892, 20.262201838195324, 22.41439875215292, 12.67775846645236, 17.648213803768158, 19.284641593694687, 31.679783575236797, 30.496344678103924, 24.943012967705727, 35.83338059484959, 19.582638703286648, 14.900483395904303, 24.331135600805283, 38.531733602285385, 28.246379010379314, 10.643663015216589, 5.801411848515272, 12.577358353883028, 12.121629808098078, 17.670448310673237, 15.237243175506592, 16.675697788596153, 21.46084561944008, 28.914307169616222, 29.005715064704418, 23.085471242666245, 26.772690787911415, 28.498225696384907, 41.91497705876827, 33.94631825387478, 35.220382288098335, 26.692518889904022, 28.654697500169277, 9.923584554344416, 0.10328992430004291, 19.938102029263973, 53.94571669399738, 45.78533537685871, 57.57652826607227, 62.13988959789276, 47.13636428117752, 64.7261980175972, 49.98539440333843, 28.59703179448843, 29.254909493029118, 26.608064621686935, 31.461185105144978, 48.444470688700676, 78.05156618356705, 55.217383056879044, 36.51106283068657, 65.9712316095829, 53.3527547121048, 3.2869357243180275, 0.03423596252105199, 0.08948580682044849, 0.03337884874781594, 0.04076306599017698, 0.11045614679460414, 0.041013373847818, 0.018715357655310072, 0.08773010806180537, 0.057910963223548606, 0.022598906980419997, 0.03833836562989745, 0.03855388902593404, 0.06255684478674084, 0.012688659317063866, 0.047988500737119466, 0.05414254141214769, 0.09262524734367616, 0.13588988163974136, 0.16546829603612423, 0.17448884871555492, 0.13838990998920053, 0.1634100533556193, 0.23378368729026988, 0.22918824950465932, 0.27128492889460176, 0.14397742110304534, 0.11660760108497925, 0.18927612632978708, 0.24290638917591423, 0.21703255333704874, 0.16803591919597238, 0.1205189419852104, 0.27603393187746406, 0.1121432488434948, 0.17851456941571087, 0.2497572434367612, 0.23816238826839253, 0.14954829326597974, 0.5446720949839801, 0.6953743239864707, 16.117291152477264, 110.7441759109497, 71.49787545204163, 74.93784606456757, 96.86971440911293, 93.30359056591988, 66.60262852907181, 49.6822352707386, 46.30923606455326, 33.85301046073437, 55.22888503968716, 73.27105790376663, 88.34570780396461, 84.13627848029137, 77.53466472029686, 73.93898606300354, 87.74132743477821, 81.1164665222168, 63.466850593686104, 10.715937986969948, 4.231938365846872, 14.940172266215086, 23.154114559292793, 43.000255823135376, 35.2917842566967, 49.89672236144543, 45.69952078163624, 36.826411709189415, 30.654239505529404, 27.56623450666666, 32.631360813975334, 40.87343014776707, 32.14033976197243, 24.13909960538149, 12.537441495805979, 5.572481257840991, 12.297478672116995, 30.555950179696083, 53.51931497454643, 42.90610067546368, 30.07764894515276, 12.238774672150612, 29.524474628269672, 37.200889214873314, 28.324474319815636, 26.02347359061241, 30.182586014270782, 29.146337918937206, 13.033810760825872, 20.71351882070303, 29.243808388710022, 28.070587143301964, 45.82817427814007, 60.05296178162098, 49.86612640321255, 34.29347902536392, 34.64467138051987, 46.80301196873188, 48.61065097153187, 59.83823910355568, 65.75266733765602, 67.64289110898972, 62.75534637272358, 63.50761480629444, 68.6490087211132, 50.33865764737129, 52.226407751441, 65.62461420893669, 57.780577316880226, 54.95530351996422, 61.659982949495316, 64.05368730425835, 63.69063198566437, 49.42325636744499, 27.906614542007446, 19.867110438644886, 25.044127441942692, 39.95423287153244, 51.3119488209486, 43.605852127075195, 35.35098887979984, 24.77538876235485, 22.41373758763075, 22.918394207954407, 28.25117815285921, 25.449026115238667, 23.591898567974567, 29.296617954969406, 50.51981292665005, 40.89247092604637, 32.99284681677818, 48.40921238064766, 17.079314030706882, 17.253399789333344, 30.306962840259075, 44.820244163274765, 38.44060309231281, 13.993871044367552, 8.483496028929949, 19.213585406541824, 26.501328349113464, 26.890917643904686, 28.471904508769512, 26.692383997142315, 27.496665939688683, 39.21564370393753, 37.97732815146446, 31.849699057638645, 43.40825133025646, 41.346614956855774, 55.71746662259102, 40.98384842276573, 42.756145521998405, 37.65548922121525, 35.32259300351143, 10.374810341745615, 1.0985116730444133, 31.544592529535294, 57.258348539471626, 51.06151945888996, 64.84460726380348, 70.08677557110786, 53.69752921164036, 74.4023559987545, 54.08180259168148, 29.709253013134003, 41.47692136466503, 44.959255903959274, 52.59894356131554, 69.9094694852829, 94.05842006206512, 61.11005365848541, 50.70277690887451, 83.31613808870316, 57.600155398249626, 2.70869676489383, 0.20454682409763336, 0.3702160937245935, 0.09255620534531772, 0.13516241364413872, 0.2919488138286397, 0.12835075962357223, 0.14635576691944152, 0.3440225258236751, 0.1712447134195827, 0.14836048590950668, 0.12230208536493592, 0.1337401766795665, 0.162690392753575, 0.15143979020649567, 0.1553692840388976, 0.42852945683989674, 0.2372063387883827], [0.049559185790712945, 0.06403410458005965, 0.018526879975979682, 0.03329228093207348, 0.042691499620559625, 0.03950892176362686, 0.03833987590041943, 0.044407159512047656, 0.07321509474422783, 0.004130813449592097, 0.06679979953332804, 0.10774694412248209, 0.21653819392668083, 0.011586102464207215, 0.024276502117572818, 0.06579441949725151, 0.2342263190075755, 0.0467756867146818, 0.01581597407493973, 0.04843873204663396, 0.1030523850931786, 0.13277076854137704, 0.3690911759622395, 1.4877642109058797, 57.346055433154106, 62.761080265045166, 45.76165124773979, 71.04357942938805, 95.32398775219917, 66.063581854105, 47.628935649991035, 31.33980631828308, 32.459876015782356, 33.4442587941885, 81.22985243797302, 70.80295354127884, 71.2824422121048, 60.25745540857315, 59.568210393190384, 56.927903071045876, 51.721399649977684, 28.613648302853107, 3.7768857087939978, 1.780371309723705, 10.849758256226778, 20.963693596422672, 40.223421826958656, 44.553589671850204, 33.25796999037266, 37.488913759589195, 31.87590815126896, 26.406411342322826, 17.699001878499985, 16.407808363437653, 23.475598208606243, 15.980570688843727, 10.517791919410229, 4.561618650332093, 1.889121236745268, 3.5339459823444486, 9.974033497273922, 27.117653377354145, 39.823740273714066, 27.986328564584255, 12.227631770074368, 25.369105003774166, 25.772968232631683, 23.090876452624798, 13.64696390926838, 22.70674366503954, 19.247236400842667, 12.377530876547098, 14.94029575958848, 15.988755449652672, 12.07036105915904, 27.533427067101, 48.7690644711256, 51.14062361419201, 28.731888458132744, 17.668981589376926, 22.90038887411356, 25.86014125496149, 36.79345987737179, 47.29480437934399, 58.39066877961159, 59.71321061253548, 58.07774797081947, 56.01720593869686, 32.947177067399025, 46.54653713107109, 59.23075430095196, 49.92108665406704, 50.63173972070217, 58.53705212473869, 59.23779532313347, 48.80838856101036, 21.68314889073372, 14.371365588158369, 12.05005019903183, 21.883709728717804, 41.2091763317585, 38.330139219760895, 27.461286038160324, 12.467613592743874, 3.212548540905118, 4.896326065063477, 11.853413600474596, 21.321476697921753, 17.443400993943214, 14.808377288281918, 23.204921633005142, 35.36461114883423, 28.834123872220516, 25.16638208180666, 32.52066135406494, 22.994454726576805, 20.34536987543106, 34.824739918112755, 36.2548615783453, 14.834902714937925, 3.151710480451584, 8.703915551304817, 11.548218727111816, 13.816294223070145, 14.458573758602142, 18.934440985322, 19.186962135136127, 30.352178514003754, 27.214458882808685, 26.847225688397884, 36.200304105877876, 30.59174995869398, 29.03441872447729, 42.987572103738785, 39.91727605462074, 35.79982079565525, 33.0334248393774, 39.09085460007191, 22.33997594565153, 0.7823356857988983, 5.447479365393519, 26.023743376135826, 39.8422034829855, 47.37989321351051, 45.99724240601063, 45.52070617675781, 60.48312909901142, 41.15668594837189, 23.375190496444702, 42.6866814494133, 35.80246165394783, 35.74123553931713, 76.47451400756836, 60.245961025357246, 36.43818274140358, 49.90657903254032, 40.93586079776287, 0.9045954316388816, 0.09925163161824457, 0.04853387908951845, 0.11880033576744609, 0.03613330016378313, 0.03789541107835248, 0.06879982815007679, 0.038237830594880506, 0.1080972229829058, 0.06710784276947379, 0.03548185035469942, 0.23157247313065454, 0.0475125020602718, 0.018432601245876867, 0.05126834446855355, 0.06321768276393414, 0.21203766198595986, 0.08070969532127492, 0.06745777282048948, 0.04728517109469976, 0.05982405295071658, 0.02647194007295184, 0.01061547256540507, 0.031078213214641437, 0.04135166331252549, 0.033560689771547914, 0.060437946376623586, 0.1658422642503865, 0.013111204807501053, 0.19703164376551285, 0.052071767568122596, 0.13083891361020505, 0.04911657262709923, 0.01606365472980542, 0.01803896240744507, 0.015527054129051976, 0.04512422630796209, 0.13521102431695908, 0.02987256462802179, 0.16127287584822625, 0.04671304202929605, 0.41632724285591394, 1.5858513163402677, 75.05620211362839, 74.94539245963097, 54.72670018672943, 78.14488917589188, 94.08569499850273, 51.44347496330738, 37.751399874687195, 37.91643641889095, 30.060502365231514, 44.31987941265106, 83.18612426519394, 78.42580050230026, 76.92867323756218, 68.47704514861107, 67.98171892762184, 72.01128870248795, 66.15353062748909, 42.61211045086384, 4.139423780143261, 1.8359658890403807, 17.709943391382694, 22.763970494270325, 43.201291635632515, 34.939022585749626, 30.134174712002277, 35.49763821065426, 28.88932541012764, 24.264234490692616, 22.56069280207157, 15.974147133529186, 20.50476372241974, 15.618624910712242, 8.241612408310175, 1.3493014220148325, 0.4165251587983221, 2.0239345589652658, 12.268745563924313, 34.73879612982273, 45.587928369641304, 35.88907040655613, 16.66525974869728, 27.38102864474058, 23.297724053263664, 27.29380052536726, 13.555640559643507, 20.31442243605852, 21.09584480524063, 10.530342645943165, 11.254909615963697, 20.425192192196846, 17.362940311431885, 37.85275183618069, 58.88611279428005, 56.6551461070776, 33.57277549803257, 24.899602197110653, 29.197247587144375, 38.171763718128204, 50.486994087696075, 58.40776026248932, 66.2295113503933, 64.65182080864906, 65.19837588071823, 63.46837431192398, 39.79232355952263, 52.73193642497063, 61.9889996945858, 56.510309278964996, 54.038811698555946, 59.286721497774124, 66.79077163338661, 55.631857216358185, 31.302319429814816, 18.56659982353449, 15.850218683481216, 21.94828536361456, 42.03437425196171, 39.00169238448143, 30.359029546380043, 20.938293859362602, 5.634576100856066, 6.635684156790376, 15.526621397584677, 27.452611103653908, 15.555026773363352, 12.75133391842246, 18.767369650304317, 33.55683155357838, 30.82400869578123, 29.743931852281094, 34.731914699077606, 25.162825472652912, 27.34507117420435, 36.64806827902794, 37.11573578417301, 20.719148218631744, 5.98384290933609, 8.709365408867598, 8.886362761259079, 10.365768726915121, 9.473344814032316, 14.07559895887971, 18.24378814548254, 27.69259862601757, 23.92432752996683, 23.944107368588448, 31.886349990963936, 29.639745242893696, 29.57372948527336, 38.88098046183586, 32.95272096991539, 37.69521228969097, 34.04581591486931, 40.0308633595705, 28.185795061290264, 1.2635545106604695, 1.927599753253162, 33.95836740732193, 48.100159764289856, 58.55538614094257, 55.40796183049679, 51.00252762436867, 67.33474284410477, 45.7882422208786, 28.113901019096375, 28.115464635193348, 28.898874297738075, 32.262989580631256, 71.58915415406227, 75.75868561863899, 43.14698874950409, 53.860361874103546, 67.29853078722954, 4.331803657114506, 0.07196099875727668, 0.04559567561955191, 0.08461880235699937, 0.02865100439521484, 0.02521885897294851, 0.11095083274994977, 0.04301440807466861, 0.049876283228513785, 0.027062917833973188, 0.059601315879262984, 0.10964603323373012, 0.016699196603440214, 0.06361147374263965, 0.06473908550105989, 0.052180258426233195, 0.03197927326255012, 0.05095421933219768, 0.03865724793286063, 0.15299706836231053, 0.12867049168562517, 0.09496494953054935, 0.09151302772806957, 0.16955251281615347, 0.12456907192245126, 0.14303838164778426, 0.13057647534878924, 0.320816250750795, 0.15411413420224562, 0.3204640868352726, 0.19791186059592292, 0.2758145530242473, 0.18672874895855784, 0.14467895845882595, 0.12967013492016122, 0.29448547458741814, 0.133203410950955, 0.2717562817269936, 0.15235558559652418, 0.16092707955976948, 0.15858621220104396, 0.48225038044620305, 1.0168502549640834, 88.83635267615318, 94.87983718514442, 62.07871288061142, 86.98443844914436, 112.21305549144745, 89.34201434254646, 62.67670579254627, 44.62256357073784, 35.31612955033779, 43.522492200136185, 86.07251778244972, 88.85828509926796, 80.25219529867172, 75.3517958521843, 73.24698239564896, 76.8247640132904, 66.32656574249268, 46.51638574898243, 6.8386749643832445, 3.5523956548422575, 13.867057599127293, 27.76120774447918, 57.28014796972275, 54.5333057641983, 43.66048939526081, 44.6491963416338, 40.981579944491386, 34.380889534950256, 27.47783984988928, 26.822711303830147, 35.0485061109066, 28.818521909415722, 21.360291615128517, 13.856710754334927, 6.877436209470034, 6.91221859306097, 17.664228044450283, 43.524920269846916, 55.303573831915855, 34.960400238633156, 19.030636623501778, 36.13359108567238, 32.39151768386364, 34.95832175016403, 24.250505827367306, 33.63425999879837, 27.96350698918104, 18.45090363174677, 20.39562977850437, 19.819637686014175, 19.135408401489258, 34.61711525917053, 57.78517507016659, 62.57121205329895, 53.93611080944538, 42.08621867001057, 45.609435215592384, 49.99484069645405, 57.71316133439541, 67.0173154771328, 67.9225181043148, 65.61720460653305, 65.3989215195179, 64.48630169034004, 43.80936540663242, 52.15307168662548, 62.87059798836708, 57.15908266603947, 56.6119272261858, 60.887666791677475, 66.8976978957653, 62.37893097102642, 41.21495582163334, 27.1502423286438, 35.3231667727232, 42.85593196749687, 56.56448297202587, 46.41229793429375, 44.03954565525055, 19.91872686892748, 6.1466727219522, 11.560979392379522, 21.057884842157364, 32.39073112607002, 23.646564334630966, 19.814785346388817, 32.43661746382713, 41.0658860206604, 34.06975843012333, 36.638040617108345, 46.282314509153366, 33.568139746785164, 27.792896144092083, 45.44971838593483, 47.535783648490906, 27.236307710409164, 7.555986223742366, 13.477716241031885, 18.250099606812, 21.50327794253826, 25.408514589071274, 30.229581892490387, 28.450939133763313, 41.72158643603325, 36.3836632668972, 35.24346224963665, 46.873042210936546, 40.00849395990372, 38.877640441060066, 52.05745741724968, 43.8950128108263, 46.90272621810436, 42.460525184869766, 49.4574773311615, 30.849769413471222, 1.1065432545728981, 6.245124964043498, 44.65517722070217, 54.786121398210526, 67.90506944060326, 63.038959354162216, 58.47037710249424, 74.14036005735397, 50.70170156657696, 30.55590458214283, 49.88536477088928, 46.763775274157524, 49.82820063829422, 90.43177306652069, 83.24463352560997, 52.62536734342575, 68.82113188505173, 76.59933730959892, 5.455190101638436, 0.18051088729407638, 0.15076860669068992, 0.2066151303006336, 0.16349510347936302, 0.1561587510514073, 0.17465019162045792, 0.1682364771841094, 0.15203413175186142, 0.15612793707987294, 0.18567497347248718, 0.2642582153202966, 0.15732527361251414, 0.1215382521331776, 0.2293426013784483, 0.11980749695794657, 0.3137231001164764, 0.09959140908904374, 0.2232602855656296], [0.03451142547419295, 0.03603958175517619, 0.07602936326293275, 0.041261414444306865, 0.14178354351315647, 0.0006744621850884869, 0.054522034915862605, 0.09685045733931474, 0.03194050717866048, 0.03858243202557787, 0.043716041909647174, 0.07980506183230318, 0.07426184209180064, 0.008628259911347413, 0.05754693607741501, 0.024873825241229497, 0.08979271457064897, 0.02480336574080866, 0.07569795721792616, 0.09586885571479797, 0.06675470664049499, 0.02108211483573541, 0.21563648449955508, 0.3268365527037531, 21.898475736379623, 93.33442211151123, 47.098499312996864, 55.69333031773567, 82.3229169845581, 79.20451551675797, 60.72187028825283, 48.01051877439022, 35.233183801174164, 27.924538180232048, 65.6680154800415, 82.38142624497414, 62.84333065152168, 65.38130566477776, 59.2602027207613, 57.67449840903282, 45.16476787626743, 23.457307890057564, 0.10035637038527057, 10.064316652715206, 20.206876806914806, 27.265345752239227, 35.18201194703579, 50.233604684472084, 39.991033896803856, 39.659551084041595, 39.50549595057964, 42.86508187651634, 23.95312048494816, 18.678192235529423, 20.967561788856983, 16.09590020030737, 6.505435220897198, 4.655100284144282, 2.671859166584909, 2.903508748859167, 5.458959974348545, 15.611497443169355, 39.67386491596699, 39.54836905002594, 25.26998732239008, 24.407509602606297, 31.9489174336195, 22.04446390271187, 13.015659134835005, 24.995759837329388, 18.327034078538418, 11.65933521464467, 13.67652252316475, 7.798241274431348, 3.683212185278535, 7.0499954000115395, 30.352205112576485, 53.10834042727947, 56.710573732852936, 30.486296117305756, 23.256154283881187, 28.029914125800133, 34.66798312962055, 48.58768120408058, 56.733323112130165, 62.5377244502306, 62.6131846010685, 48.36406700313091, 31.378837823867798, 56.7029969394207, 57.84418970346451, 51.91502586007118, 50.62290899455547, 58.70436854660511, 58.56654614210129, 51.85273960232735, 25.256745032966137, 22.170071862637997, 31.93518877029419, 44.71938617527485, 54.15198102593422, 34.72472168505192, 12.849439904093742, 3.7458055140450597, 2.2689389996230602, 1.0574393207207322, 1.8534050532616675, 4.581729071214795, 3.25827956199646, 14.532553888857365, 23.11121106147766, 19.378806240856647, 25.452379435300827, 31.336587890982628, 23.980334624648094, 38.786544129252434, 31.042090393602848, 40.98437279462814, 27.87637386471033, 3.2511083967983723, 6.041934667155147, 5.641852235421538, 9.525645207613707, 10.412469170987606, 13.461922388523817, 18.172401376068592, 19.48274776339531, 24.704355373978615, 28.133984841406345, 34.92952689528465, 28.076100647449493, 17.91684988886118, 20.825333520770073, 43.298722207546234, 45.80797456204891, 38.80041338503361, 29.742740616202354, 39.78218950331211, 34.63244363665581, 3.1042617140337825, 0.29080409556627274, 14.324832335114479, 42.22597137093544, 45.0333671271801, 51.05172738432884, 46.82149037718773, 64.20889377593994, 30.640037767589092, 26.90578244626522, 47.935035824775696, 27.780123129487038, 54.96963255107403, 77.39186838269234, 45.423123612999916, 36.24253883957863, 45.046799406409264, 8.12253724783659, 0.14513675967464224, 0.08673916279803962, 0.24109170451993123, 0.02751143849309301, 0.025724001789058093, 0.07328477498958819, 0.04762616939842701, 0.0600761085661361, 0.05663341908075381, 0.15613728814059868, 0.06772034466848709, 0.017618923520785756, 0.0650213316839654, 0.10467528394656256, 0.02701009918382624, 0.06936772697372362, 0.052359416586114094, 0.19236723077483475, 0.12050932375132106, 0.020480754428717773, 0.05147065021446906, 0.07213511402369477, 0.02988800872117281, 0.02110807145072613, 0.062175636921892874, 0.04731690904009156, 0.1040166278835386, 0.04157499781285878, 0.07759167317999527, 0.13691774132894352, 0.08505373800289817, 0.16237647912930697, 0.042508404367254116, 0.10387854388682172, 0.012988405342184706, 0.1590817145188339, 0.07641885720659047, 0.2596055727917701, 0.07193099372670986, 0.2306341758230701, 0.033130177325801924, 0.7425750349648297, 0.6818501371890306, 33.466764986515045, 103.48513662815094, 55.083337649703026, 69.83414992690086, 92.38384991884232, 70.88522672653198, 47.91184186935425, 39.13570359349251, 36.2620659917593, 38.31668794155121, 75.8148542046547, 80.7293888926506, 68.77667427062988, 70.11027351021767, 69.39268201589584, 71.66648000478745, 58.86584848165512, 25.13189323246479, 0.15765729564009234, 13.787531666457653, 23.394692949950695, 22.068719901144505, 43.614580258727074, 49.51356612145901, 37.54644647240639, 32.99160808324814, 35.289025604724884, 35.45443832874298, 21.684036143124104, 19.464024268090725, 17.97189373522997, 10.361794140189886, 8.127521630376577, 2.7394373528659344, 0.8658095472492278, 0.49815095379017293, 3.9775144681334496, 20.806591026484966, 44.06262181699276, 45.57634279131889, 20.644444227218628, 28.51013045758009, 27.73681305348873, 23.458962701261044, 13.616443946957588, 23.858737349510193, 22.326344177126884, 10.074340514838696, 10.61449958011508, 10.177159197628498, 7.147390823811293, 9.315776769071817, 37.690679132938385, 63.25680546462536, 60.72216287255287, 36.38038024306297, 28.98975022137165, 38.354982286691666, 48.299231082201004, 54.005118906497955, 62.14949928224087, 64.80416223406792, 68.49969953298569, 56.40623286366463, 38.61104674637318, 62.474119663238525, 62.94763885438442, 56.639468148350716, 53.98575134575367, 60.39888381958008, 62.863716557621956, 52.06864781677723, 31.058397218585014, 24.805912524461746, 27.454313412308693, 44.95268225669861, 52.924498692154884, 45.30724123120308, 19.211047142744064, 5.615532947704196, 2.511448636651039, 1.996311703696847, 2.600018084049225, 10.744712892919779, 8.419121783226728, 8.823773469775915, 18.0975453928113, 21.08902797102928, 26.72925341874361, 32.6742909103632, 27.020162008702755, 34.06973943114281, 33.754531145095825, 44.64095838367939, 33.325959742069244, 8.70031239464879, 6.335873119533062, 6.29449381493032, 5.954356016591191, 8.599088676273823, 7.5742347445338964, 12.975341398268938, 14.632935002446175, 21.126469261944294, 23.376940302550793, 31.094181798398495, 26.445923522114754, 19.496423229575157, 18.507032319903374, 42.98281855881214, 38.13775934278965, 34.40152242779732, 28.366080187261105, 43.20173621177673, 41.048646345734596, 5.09205736219883, 0.2799948333995417, 9.22286320477724, 48.276162520051, 52.87148013710976, 58.21285732090473, 55.051119178533554, 69.5525774359703, 39.78575371205807, 25.857135616242886, 30.461342856287956, 27.28912677615881, 48.142478093504906, 82.04980283975601, 56.72569312155247, 44.434815645217896, 62.66089104115963, 17.547597102820873, 0.00805894358563819, 0.3603140328777954, 0.04795781664142851, 0.17730718420352787, 0.048392674361821264, 0.03660953261714894, 0.0702498214377556, 0.06684124848106876, 0.06802933785365894, 0.19472530111670494, 0.1300038193585351, 0.07765055517666042, 0.09394337583216839, 0.0671978504396975, 0.09200211788993329, 0.02788248450087849, 0.07439795939717442, 0.13006216700887308, 0.08479803102090955, 0.15219225373584777, 0.10866144817555323, 0.11645318983937614, 0.16026506898924708, 0.26166814961470664, 0.14260446274420246, 0.13101832038955763, 0.29759908095002174, 0.1231542119057849, 0.22776899597374722, 0.23901153879705817, 0.17012822645483539, 0.185042574594263, 0.13302400417160243, 0.3113619424402714, 0.19171690160874277, 0.28561265382450074, 0.16950878547504544, 0.27772534580435604, 0.26770296797621995, 0.24622000433737412, 0.08584848168538883, 0.7741391693707556, 0.5770680285058916, 35.03009609878063, 127.61872082948685, 69.79498162865639, 77.33341991901398, 100.04853263497353, 100.5400362610817, 78.57662200927734, 64.38433796167374, 41.83887854218483, 34.7186154127121, 75.0028757750988, 90.57861238718033, 75.5895034968853, 75.75198277831078, 75.52464857697487, 75.18590435385704, 58.627719059586525, 33.81140649318695, 0.7512192742433399, 13.346683122217655, 26.451224237680435, 34.113478884100914, 45.229356810450554, 61.42414100468159, 52.46705263853073, 49.20471869409084, 50.42399726808071, 53.582061007618904, 34.1275305300951, 32.83674359321594, 35.69162160158157, 29.787411019206047, 19.193070307374, 12.986338008195162, 8.09709856286645, 5.113339070230722, 9.71976539120078, 32.38421447575092, 55.50095424056053, 48.91060687601566, 33.54984372854233, 37.53856189548969, 40.9408613294363, 31.764342337846756, 23.1811311095953, 39.70427468419075, 27.133832909166813, 19.122690483927727, 19.567004442214966, 16.845256090164185, 11.97306253015995, 9.282894283533096, 37.90868863463402, 58.78263294696808, 65.79327955842018, 51.84325151145458, 38.878909572958946, 50.23814544081688, 56.64928302168846, 61.99957072734833, 65.77459216117859, 64.27871122956276, 69.64259460568428, 58.250479102134705, 42.95074827969074, 63.299404978752136, 63.11499707400799, 57.43744432926178, 55.875196158885956, 60.13782262802124, 64.2065379023552, 57.7762645483017, 44.374163299798965, 43.383993431925774, 49.620754569768906, 53.37467573583126, 61.350512355566025, 54.10903953015804, 20.880037285387516, 4.458733946084976, 8.563920613378286, 3.631121967919171, 5.462669050320983, 9.194702915847301, 10.225713942199945, 24.025318510830402, 32.149246484041214, 23.569105491042137, 30.314545333385468, 42.87820637226105, 35.00140383839607, 50.05237340927124, 42.365074306726456, 52.15544655919075, 38.67055915296078, 13.28511692583561, 9.694466348737478, 14.240413215011358, 17.1321938931942, 22.486788667738438, 24.081352204084396, 29.589929915964603, 29.725772626698017, 39.074207693338394, 40.10802961885929, 48.4880543500185, 39.22874540090561, 26.141160875558853, 28.127065412700176, 49.84412558376789, 52.79741831123829, 47.67329066991806, 38.98261360824108, 46.9747893512249, 44.04657527804375, 5.805329438298941, 0.4646674473769963, 18.443125449121, 61.65007308125496, 62.553113624453545, 68.87278631329536, 60.87082229554653, 79.13327693939209, 41.50468647480011, 31.59364029765129, 59.8612354695797, 38.781186416745186, 68.01397919654846, 96.09297528862953, 67.09142670035362, 56.84868112206459, 83.34385380148888, 21.277298368513584, 0.2949423703830689, 0.4821537231327966, 0.29515610891394317, 0.2856906980741769, 0.2840387960895896, 0.1845822500763461, 0.35713027871679515, 0.19642906438093632, 0.11675267611281015, 0.25209126819390804, 0.4418356600217521, 0.1685841882135719, 0.27492920053191483, 0.13042969338130206, 0.14998240512795746, 0.12058309323037975, 0.16734708740841597, 0.3217155853053555, 0.11840298247989267], [0.011915563154616393, 0.012458240089472383, 0.04869667289312929, 0.10128275622264482, 0.06589958182303235, 0.08133554845699109, 0.02400503377430141, 0.08036520521272905, 0.007512993779528188, 0.059491355568752624, 0.041750879390747286, 0.1175765268271789, 0.07010134737356566, 0.036631166221923195, 0.12337184671196155, 0.05437912324850913, 0.23631213989574462, 0.02399253786279587, 0.10342417139327154, 0.048261841147905216, 0.14515108312480152, 0.09884299026452936, 0.1295099942944944, 0.15067077678395435, 1.5911417012102902, 67.61205196380615, 69.31594893336296, 41.67272485792637, 64.23324286937714, 94.21499446034431, 44.48647767305374, 57.54728123545647, 44.00986544787884, 27.867254354059696, 61.71918757259846, 84.69164907932281, 69.07739013433456, 68.77971410751343, 65.1702193915844, 65.34485042095184, 58.53156141936779, 6.201293841004372, 1.0709014046005905, 17.746286541223526, 34.48883414268494, 37.67043761909008, 22.782023325562477, 40.237260684370995, 34.25835371017456, 40.57451158761978, 30.761372856795788, 27.641954943537712, 21.810246370732784, 16.674842834472656, 14.899177215993404, 14.870444107800722, 5.111184110864997, 3.454024870879948, 4.389884965494275, 2.071180986240506, 2.2347631584852934, 6.71397895552218, 26.504330188035965, 51.2091301381588, 51.84794045984745, 23.78873560577631, 28.333158753812313, 24.50570583343506, 13.02836375311017, 21.92340809851885, 32.73988679051399, 8.27473808079958, 5.65446755848825, 6.115909097716212, 3.2575006037950516, 2.1228273399174213, 16.70666042715311, 46.332513615489006, 57.85621605813503, 55.151536390185356, 28.312066085636616, 30.37562135607004, 40.46127766370773, 50.57934433221817, 51.43501281738281, 67.83805623650551, 59.72568914294243, 23.446461372077465, 24.899963177740574, 61.03841610252857, 60.38520075380802, 51.89915031194687, 54.0867081284523, 58.63801650702953, 54.74126860499382, 55.96834436058998, 46.5179056674242, 40.8248383551836, 47.944064140319824, 55.56404605507851, 47.9461844265461, 14.585841279476881, 8.895070943981409, 8.290933761745691, 0.7398778921924531, 0.22491865907795727, 0.6520741037093103, 2.8457580227404833, 0.6413068471010774, 7.598591912537813, 18.625044487416744, 20.310121066868305, 33.29276852309704, 33.54813002049923, 28.592225052416325, 46.9980289041996, 49.76323552429676, 39.196268543601036, 16.59985575824976, 1.4293114724569023, 7.095748269930482, 5.5843043234199286, 9.266124833375216, 3.8170051435008645, 14.968326855450869, 15.797936338931322, 23.629155568778515, 25.698855109512806, 28.617275208234787, 26.515484489500523, 23.100710324943066, 21.160901114344597, 24.191895872354507, 35.29892407357693, 48.465711548924446, 37.62276917695999, 43.685583248734474, 41.73465773463249, 42.72145338356495, 15.004281476140022, 0.05204125045565888, 1.9719464611262083, 21.114706993103027, 40.576134100556374, 51.5957023948431, 51.627681478857994, 67.26949274539948, 23.445990197360516, 36.21928408741951, 39.4084719568491, 32.233807146549225, 70.44771820306778, 68.63587662577629, 34.78600099682808, 46.976248472929, 22.85575456917286, 0.6350072007626295, 0.44349753647111356, 0.018929868019768037, 0.052950637400499545, 0.09397583737154491, 0.09799196952371858, 0.05365009303204715, 0.06498046903288923, 0.052833378067589365, 0.023399957062792964, 0.08081234176643193, 0.07024244448984973, 0.033176505894516595, 0.06545325421029702, 0.030092052948020864, 0.014712249267176958, 0.07223862878163345, 0.07307011619559489, 0.06032292832969688, 0.06510480845463462, 0.027501759032020345, 0.048864019772736356, 0.042858998640440404, 0.15230911230901256, 0.13351362867979333, 0.06924232628080063, 0.07645858437172137, 0.06577047781320289, 0.056411873156321235, 0.08679585545905866, 0.1180447700608056, 0.11085834630648606, 0.029033357022854034, 0.042770419604494236, 0.06479121395386755, 0.0926797284046188, 0.1405666588107124, 0.021718901662097778, 0.14010523591423407, 0.030771288766118232, 0.08653813725686632, 0.04166210739640519, 0.11471876103314571, 0.22704209201037884, 3.1541972095146775, 88.51511791348457, 76.64743512868881, 47.8637782484293, 83.10833483934402, 95.0580096244812, 41.68536297976971, 51.99451379477978, 31.081971153616905, 35.370877012610435, 73.07526960968971, 85.06331473588943, 72.23344758152962, 74.04880777001381, 74.19073775410652, 72.3218460381031, 63.88404160737991, 3.8816923974081874, 2.163008521310985, 22.81290616840124, 36.33307658135891, 33.30653138458729, 27.416676431894302, 45.291802659630775, 35.66387549042702, 39.292737767100334, 29.270743243396282, 29.261169657111168, 22.278124764561653, 19.833668433129787, 12.654248178005219, 9.917561877518892, 4.751742873340845, 3.655482460744679, 3.4372437838464975, 1.2315852823667228, 0.8872794639319181, 9.341489039361477, 33.970230370759964, 53.46636861562729, 35.08073218166828, 26.11333876848221, 32.305505499243736, 26.420738473534584, 14.852446373552084, 22.368765100836754, 29.11823272705078, 6.983138462528586, 9.41579120233655, 6.760953459888697, 3.083606497384608, 3.1807843828573823, 20.327556431293488, 53.91261667013168, 69.67465728521347, 61.6932425647974, 32.527421191334724, 37.12275020778179, 48.725632801651955, 59.78263668715954, 57.616122141480446, 69.52413216233253, 70.29632672667503, 33.74622479081154, 32.50498719513416, 66.94980829954147, 64.68307793140411, 58.77777300775051, 55.40997952222824, 65.18320709466934, 62.174501940608025, 60.753568187355995, 47.38490514457226, 40.483137890696526, 49.386899918317795, 56.572504341602325, 55.349828749895096, 26.70814175158739, 9.602496083825827, 7.132755909115076, 1.3877724576741457, 0.20841354707954451, 0.47068846179172397, 7.716983109712601, 4.480173820629716, 10.296311303973198, 15.890736859291792, 20.724703520536423, 33.38552534580231, 34.265337735414505, 29.13316212594509, 41.24331749975681, 43.33527624607086, 50.631211549043655, 23.064078390598297, 4.190161982551217, 4.36924684792757, 3.678204291500151, 7.42990423925221, 5.926366718485951, 13.088151644915342, 14.88142741844058, 19.226451516151428, 22.668692506849766, 24.64460738003254, 24.941090270876884, 23.64829134196043, 19.03984732925892, 23.5514098405838, 36.02789215743542, 40.37636362016201, 26.49245772510767, 44.657761082053185, 43.33490386605263, 48.623091503977776, 16.85498546808958, 0.18668206786969677, 0.8085160434711725, 21.765606366097927, 45.71138754487038, 58.73662881553173, 60.52198201417923, 71.27190917730331, 35.65026842057705, 26.834450773894787, 30.210755802690983, 29.396757781505585, 65.4308170080185, 82.22863644361496, 47.50307500362396, 56.254054829478264, 40.03115214407444, 1.1688113445416093, 0.46775029913987964, 0.02827661686751526, 0.0534407591476338, 0.022074533262639306, 0.2016633577295579, 0.09740718684042804, 0.04796059598447755, 0.06198566195962485, 0.1686964009422809, 0.1014410711650271, 0.04636304518498946, 0.08598356740549207, 0.03204966225894168, 0.027001792695955373, 0.025084196277020965, 0.057075171353062615, 0.10096317259012721, 0.10890808611293323, 0.02996751129103359, 0.08057854298385791, 0.08756049763178453, 0.15799049026099965, 0.2788582490757108, 0.2527830982580781, 0.19218172354158014, 0.27018408640287817, 0.13660793920280412, 0.1503003411926329, 0.16927011078223586, 0.34968451887834817, 0.2520458784420043, 0.14661600842373446, 0.11673637112835422, 0.1505091370199807, 0.24668323807418346, 0.3495588287478313, 0.12321106783929281, 0.16120971908094361, 0.14166873326757923, 0.47820083680562675, 0.17521927045891061, 0.2834343019640073, 0.280304605839774, 2.6259053824469447, 100.10071143507957, 100.38438141345978, 60.94929948449135, 87.12592005729675, 117.21059292554855, 60.61754688620567, 79.04769793152809, 54.19152930378914, 33.88539232313633, 75.07754176855087, 93.93171206116676, 82.33732581138611, 80.4724694788456, 84.92526814341545, 80.28128653764725, 75.99183350801468, 8.799536470323801, 2.6911982288584113, 23.753101117908955, 43.01647715270519, 49.34627629816532, 30.083958506584167, 48.9479398727417, 42.08053037524223, 51.65026366710663, 40.90533323585987, 39.8638167232275, 31.955225095152855, 27.660796232521534, 28.444226793944836, 29.403272531926632, 15.880138278007507, 14.181530624628067, 10.021281111985445, 9.616581927984953, 7.680009193718433, 15.588843058794737, 43.28958749771118, 58.97612616419792, 58.11204873025417, 39.02338922023773, 40.56967444717884, 37.721111699938774, 21.828574687242508, 35.41045568883419, 39.57077644765377, 14.70978207886219, 15.01748576760292, 13.690725211054087, 7.104713888838887, 4.341257074847817, 23.423713892698288, 58.01269546151161, 62.208734303712845, 66.3801808655262, 43.242641016840935, 48.8609017431736, 60.4446105659008, 65.33831477165222, 60.70756785571575, 69.4297756254673, 72.36944988369942, 34.32042717933655, 33.59740197658539, 69.72059682011604, 63.76717507839203, 59.02852535247803, 56.4735272526741, 67.31328159570694, 58.536881133913994, 59.778312519192696, 60.74539102613926, 57.788165509700775, 54.497618079185486, 58.05537477135658, 61.04145973920822, 32.211228758096695, 11.900676414370537, 10.981452539563179, 1.9949924619868398, 0.9969313675537705, 0.5362515093293041, 14.205013364553452, 6.702742958441377, 18.034024201333523, 29.285133071243763, 23.946731127798557, 44.34610940515995, 44.97481606900692, 41.17119736969471, 60.650863498449326, 58.568978011608124, 50.87164364755154, 28.052959889173508, 10.19035303965211, 16.46510548889637, 13.554143439978361, 19.55622062087059, 16.267244406044483, 30.18099769949913, 27.03181028366089, 36.00377105176449, 39.335306882858276, 41.8426251411438, 37.73985229432583, 35.256028175354004, 30.872906371951103, 33.597588166594505, 43.159041702747345, 55.78447222709656, 46.4733112603426, 54.383472204208374, 47.545465528964996, 53.200911059975624, 16.954213343560696, 0.32461928261909634, 2.1800368325784802, 29.441209696233273, 52.8486205637455, 71.36512577533722, 61.6207804530859, 83.61015871167183, 31.628218442201614, 43.07683691382408, 51.83345943689346, 46.31421759724617, 87.94807434082031, 92.57298097014427, 53.422982543706894, 75.33219650387764, 56.08051814138889, 1.6854097740724683, 0.48381939937826246, 0.08430275876889937, 0.10886772070080042, 0.2171306949458085, 0.16151481599081308, 0.22958532819757238, 0.19323009619256482, 0.19904495682567358, 0.31812783563509583, 0.21528295503230765, 0.20962174865417182, 0.2691701939329505, 0.2588777040364221, 0.14391156291821972, 0.12722648010822013, 0.14190806105034426, 0.2369857724988833, 0.20752102544065565, 0.20275821851100773], [0.04168368534010369, 0.023881596061983146, 0.08610910168499686, 0.10226179743767716, 0.06936061719898134, 0.10414645177661441, 0.036033485012012534, 0.028147037883172743, 0.03474283825198654, 0.08195264425012283, 0.024891471657610964, 0.021441657554532867, 0.07047751234495081, 0.11944070531171747, 0.0794273977226112, 0.006219313490873901, 0.3050352225545794, 0.06737929812516086, 0.04489769686188083, 0.1316058193333447, 0.10548550882958807, 0.31513223075307906, 0.08027924224734306, 0.20408734562806785, 0.5471613770350814, 10.163238644599915, 67.26611852645874, 51.89843975007534, 46.86341352760792, 97.86789804697037, 74.6075601875782, 40.8166877925396, 60.861022621393204, 34.18540522456169, 49.672564789652824, 80.60906454920769, 59.769728779792786, 69.33173328638077, 65.10272741317749, 68.4228752553463, 24.323967285454273, 0.13717309950152412, 6.6766901314258575, 27.911459282040596, 27.739130929112434, 42.72654511034489, 43.75059016048908, 51.57822713255882, 41.32019877433777, 22.074277102947235, 28.809153512120247, 24.08650852739811, 16.82605192065239, 16.244960501790047, 8.95291619002819, 5.2815199457108974, 4.655831744894385, 1.1659045005217195, 4.28227094002068, 0.18851509841624647, 1.8253187416121364, 3.812592630274594, 13.00759406760335, 42.89898745715618, 71.0240788757801, 34.12951022386551, 25.826910138130188, 24.91223841905594, 15.357908550649881, 19.611158072948456, 35.57083748281002, 12.643766440451145, 1.702608244959265, 9.997653029859066, 5.6297622341662645, 3.38515380397439, 12.958211917430162, 38.57057511806488, 52.475115805864334, 58.02856720983982, 48.89451093971729, 36.26938059926033, 43.29319730401039, 52.917408272624016, 55.69761648774147, 64.43909302353859, 62.55954667925835, 13.56140200048685, 14.544547945261002, 67.462537586689, 59.25870180130005, 56.596864834427834, 53.179370015859604, 59.77235443890095, 56.914577186107635, 58.634212911129, 59.8993094265461, 51.62041246891022, 55.52409499883652, 62.00502723455429, 39.48238559067249, 22.861893139779568, 11.99858671054244, 3.3751308917999268, 0.4758753319038078, 0.2653325186111033, 0.5446663952898234, 9.493925459682941, 7.077424703165889, 7.314523905515671, 12.085469048470259, 24.379833787679672, 30.495267435908318, 31.551109179854393, 38.244138434529305, 62.468716353178024, 64.22022476792336, 27.300072088837624, 8.113198298960924, 3.032830534502864, 2.8320013359189034, 5.8759823720902205, 5.114242946729064, 6.894212309271097, 18.539577573537827, 13.647056054323912, 22.27577269077301, 24.19085282832384, 26.753716506063938, 21.265900880098343, 19.143845848739147, 18.779777884483337, 20.337998270988464, 29.50466439127922, 45.88465824723244, 47.634612545371056, 37.18931503593922, 36.072934940457344, 34.890373796224594, 14.756435975432396, 0.5028509453404695, 0.05503099979250692, 5.662177819758654, 34.74905177950859, 45.30835077166557, 62.61684760451317, 54.16269265115261, 20.27290776371956, 46.45310774445534, 30.72616584599018, 48.282690569758415, 77.39328190684319, 49.81398940086365, 27.63698671013117, 31.355735063552856, 5.568197462707758, 0.09612606183509342, 0.17582014290383086, 0.03484661276161205, 0.04424919708981179, 0.10685868241125718, 0.1958195978659205, 0.11791025579441339, 0.06670505696092732, 0.11968461956712417, 0.04620393614459317, 0.06945217595784925, 0.00859626221426879, 0.028640644013648853, 0.042505821693339385, 0.058851802386925556, 0.10391719493782148, 0.029552370579040144, 0.07269513866049238, 0.006219662300281925, 0.1797094865469262, 0.06639171479037032, 0.041163295099977404, 0.03955319458327722, 0.0054962227750365855, 0.047459067427553236, 0.013754653336945921, 0.08624988709925674, 0.040924223358160816, 0.013142939969839063, 0.10068193572806194, 0.121298783342354, 0.027541499184735585, 0.07000784418778494, 0.08795490459306166, 0.07546615481260233, 0.04979282872227486, 0.23960356484167278, 0.0834735349053517, 0.04077438745298423, 0.15995939320418984, 0.12293683685129508, 0.4264502855949104, 0.04606533264450263, 0.2637225924991071, 0.5763170938007534, 21.964301504194736, 88.35999503731728, 64.05318573117256, 59.98713031411171, 105.2215826511383, 59.593148455023766, 39.85248953104019, 43.04893121123314, 37.5558015704155, 69.72729206085205, 87.11467266082764, 64.80050683021545, 79.04720395803452, 73.62267583608627, 75.39237767457962, 20.4080456122756, 0.2651569858426228, 8.509304244071245, 32.72524617612362, 27.712547555565834, 39.70794528722763, 36.255648136138916, 47.49822646379471, 38.84884558618069, 25.92363964766264, 31.0714191198349, 23.960623182356358, 16.265779584646225, 19.270671643316746, 7.400323776528239, 4.4458963349461555, 5.505018252879381, 5.278340941295028, 5.123855955898762, 2.8706737607717514, 2.390474290587008, 4.151708520948887, 18.299768641591072, 45.7949298620224, 61.00837491452694, 26.567864678800106, 29.432029388844967, 26.594689339399338, 18.18810783326626, 16.234549060463905, 31.544995307922363, 12.543777655810118, 4.761787159368396, 12.127817776054144, 10.046511758118868, 4.0637503657490015, 15.729848742485046, 44.21220079064369, 58.62762786448002, 64.9943496286869, 49.056849628686905, 40.86031325161457, 51.43254674971104, 59.06446382403374, 59.40173752605915, 67.99882560968399, 70.68781971931458, 21.533275432884693, 18.144043497741222, 72.39844992756844, 66.08736857771873, 62.50684350728989, 57.76510834693909, 65.08476197719574, 60.37114530801773, 65.84537476301193, 66.36472329497337, 56.91469117999077, 58.324027955532074, 61.54080234467983, 47.85033456981182, 19.523912854492664, 12.526420187205076, 4.166812710464001, 0.6113104848191142, 0.43879534816369414, 0.4962639987934381, 8.639343716204166, 5.326895685866475, 12.305107712745667, 12.722569461911917, 23.947160504758358, 32.18565613031387, 30.16886305063963, 37.12236262857914, 51.8511588871479, 58.64811636507511, 39.142072051763535, 13.528585061430931, 2.946656858548522, 0.6166532356292009, 4.4987918715924025, 9.579407572746277, 11.529744118452072, 22.309281192719936, 16.334567293524742, 19.92550380527973, 21.782825142145157, 23.501469120383263, 18.60933993011713, 21.357432268559933, 18.783883564174175, 22.294425889849663, 31.544788219034672, 46.6626513004303, 40.797829404473305, 35.76263979077339, 37.8691403567791, 40.29422342777252, 16.645736396312714, 0.8149062911979854, 0.05566655279835686, 5.961435986682773, 38.970021083950996, 49.40601289272308, 68.82484808564186, 63.53265546262264, 29.261485040187836, 29.143068194389343, 29.394090324640274, 41.16879589855671, 81.69322997331619, 65.9334084391594, 36.42580680549145, 61.068483889102936, 15.873488634824753, 0.0787061192386318, 0.10807315513375215, 0.04340811741712969, 0.03954969906772021, 0.03572881483705714, 0.08301689886138774, 0.11230681076995097, 0.004348434340499807, 0.136101542157121, 0.057226788412663154, 0.02143671670637559, 0.04523843541392125, 0.00832338007967337, 0.009355893034808105, 0.041019344425876625, 0.027415141121309716, 0.03328897095343564, 0.04995541101379786, 0.04338164872024208, 0.044928388379048556, 0.1348754993523471, 0.08334854981512763, 0.172046841471456, 0.1682389114284888, 0.15025285858428106, 0.22996815765509382, 0.15097579947905615, 0.15597379300743341, 0.12878527224529535, 0.22495967015856877, 0.19754095003008842, 0.17398282274371013, 0.1725729796453379, 0.1544297399232164, 0.2381079740007408, 0.1914398727240041, 0.42134638759307563, 0.20472027885261923, 0.23597486346261576, 0.22108418983407319, 0.1955265534343198, 0.5475603556260467, 0.12735616299323738, 0.9087625017855316, 0.9280152374412864, 23.825253546237946, 112.28544920682907, 81.05238676071167, 69.74873051047325, 119.8164626955986, 92.10325017571449, 54.93463642895222, 76.13975957036018, 43.01721811294556, 61.16935707628727, 90.22351384162903, 73.0743956565857, 85.14846816658974, 82.67391175031662, 86.98311612010002, 30.454467125236988, 0.3817140689352527, 13.07800143957138, 39.470211043953896, 38.154201060533524, 54.064065143465996, 50.48347547650337, 58.92951786518097, 52.43444658815861, 31.948552653193474, 38.65884818136692, 33.570172637701035, 28.625967241823673, 26.874905303120613, 21.625711172819138, 17.17047493904829, 20.51373314112425, 14.43531995639205, 12.519176825881004, 10.840629246085882, 13.136592395603657, 10.412651561200619, 23.542691208422184, 52.14892990887165, 75.70107311010361, 48.72735410928726, 37.52618595957756, 35.15872299671173, 27.917419262230396, 30.547001659870148, 44.586013332009315, 19.00336928665638, 5.330164935439825, 13.245391007512808, 12.581022307276726, 8.11223790049553, 14.897446408867836, 43.565315902233124, 57.55962297320366, 60.070315450429916, 61.188800632953644, 52.80627563595772, 62.192740961909294, 59.62463736534119, 64.49651554226875, 66.20963081717491, 72.26614102721214, 26.925602182745934, 21.756864935159683, 72.39071354269981, 65.75401246547699, 62.751698568463326, 57.88115032017231, 66.76196917891502, 56.83921962976456, 67.09753677248955, 66.87323480844498, 62.50680550932884, 54.65152122080326, 64.06487390398979, 57.099319472908974, 28.830059990286827, 13.782808519899845, 5.396345034241676, 0.9240247984416783, 0.4160833137575537, 0.4267456603702158, 16.091937012970448, 12.486574575304985, 15.773059073835611, 23.059925213456154, 31.63456980139017, 41.60453371703625, 42.74049416184425, 50.91307282447815, 73.79457861185074, 70.95582693815231, 35.94861701130867, 17.853777073323727, 12.562224715948105, 12.418632321059704, 18.68528265506029, 16.9591910764575, 20.335099026560783, 33.010196685791016, 24.22907117754221, 38.324857503175735, 40.627587139606476, 42.041225284338, 34.72151465713978, 34.0562691539526, 28.988458290696144, 29.23012152314186, 36.00039303302765, 57.80681870877743, 58.892709240317345, 48.20640966296196, 43.6842343211174, 47.436928153038025, 17.52733089029789, 0.7364384829998016, 0.24733252823352814, 7.999212015420198, 47.34913386404514, 57.303383722901344, 74.14168998599052, 70.41936412453651, 25.691289715468884, 53.18825773894787, 45.89134208858013, 61.65261514484882, 98.18742290139198, 71.94625899195671, 42.99978464841843, 83.70833784341812, 19.626395255327225, 0.09001279104268178, 0.3375551837962121, 0.13967229664558545, 0.14685639005620033, 0.18034906941466033, 0.28583434817846864, 0.23500147741287947, 0.14796373376157135, 0.2945170900784433, 0.21062887273728848, 0.2910451451316476, 0.11839385406346992, 0.15071904606884345, 0.13919134042225778, 0.24673987878486514, 0.18487351335352287, 0.21904788503888994, 0.1596321357646957, 0.16577765287365764, 0.27888950833585113], [0.0263180872934754, 0.03290577784355264, 0.051986995749757625, 0.09185615970636718, 0.028185772425786126, 0.04294051614124328, 0.02580902222689474, 0.025215317073161714, 0.09190932716592215, 0.06964709362364374, 0.18544049933552742, 0.07707061871769838, 0.03720411907124799, 0.05742678607930429, 0.04891862699878402, 0.05859293385583442, 0.010791351360239787, 0.04676261749409605, 0.060177938648848794, 0.19740360818104818, 0.024207309834309854, 0.06329630588879809, 0.038939917139941826, 0.19099857687251642, 0.39974098443053663, 0.7065447745844722, 25.49172632396221, 57.44538590312004, 38.32053333520889, 74.94788512587547, 100.79748764634132, 57.585799768567085, 53.3063630014658, 45.51431491971016, 39.999864622950554, 74.91263061761856, 60.6551268696785, 62.997093200683594, 66.98749467730522, 40.6948359310627, 2.6642712112516165, 0.034886451248894446, 18.0095649138093, 36.43426135182381, 42.58081533014774, 50.030167400836945, 37.51058779656887, 44.5670485496521, 44.203560054302216, 29.502042531967163, 24.64922983199358, 27.947338856756687, 20.98236959427595, 17.524091564118862, 9.564917050302029, 4.189938269555569, 3.728151423856616, 1.9765342399477959, 5.466919597238302, 3.148028003051877, 2.7136229630559683, 3.3593261148780584, 8.94009567797184, 38.93694765865803, 55.73119528591633, 38.06863725185394, 25.51119837909937, 24.09064080566168, 13.073223195970058, 21.77799940109253, 26.672068387269974, 12.120221983641386, 2.1609257580712438, 10.28408546000719, 2.65951719135046, 3.3857439598068595, 10.70772472769022, 27.82968956977129, 47.310888916254044, 53.70484761893749, 56.01866886019707, 51.333493664860725, 45.711634531617165, 53.21070693433285, 57.71836705505848, 57.556385546922684, 71.07639446854591, 35.871693938970566, 12.660565339028835, 57.73057200014591, 61.33553735911846, 58.70900049805641, 54.12703916430473, 56.755730509757996, 54.45512115955353, 56.58814810216427, 62.040076553821564, 53.13980653882027, 52.19470985233784, 56.338281109929085, 42.07168824970722, 16.875415071845055, 2.9889728128910065, 0.7833343197125942, 1.0466990782879293, 0.23438326839823276, 0.5354192352388054, 13.81783314049244, 12.176535911858082, 10.438953749835491, 12.962576933205128, 27.004090771079063, 31.850816197693348, 30.06097923964262, 42.044249922037125, 73.2034595310688, 66.62202268838882, 26.401232220232487, 3.8806044682860374, 2.0737598603591323, 1.9968356005847454, 6.2426256481558084, 4.62036207318306, 13.211836908012629, 15.437257792800665, 17.657437808811665, 17.612024545669556, 20.514709688723087, 23.842865601181984, 20.655562430620193, 17.58302830159664, 19.480918161571026, 16.535107232630253, 19.83148355036974, 33.04179958999157, 46.163684874773026, 46.930700317025185, 48.39574210345745, 52.36975505948067, 18.712158612906933, 0.9120400040410459, 0.06585125316632912, 0.7187960296869278, 14.334632009267807, 40.081776827573776, 66.72728464007378, 45.124501436948776, 27.963647581636906, 40.10204493999481, 33.840908110141754, 57.91204646229744, 79.41441625356674, 32.568231001496315, 29.873941875994205, 22.763848900794983, 2.1418918669223785, 0.4920208436669782, 0.13363554870011285, 0.0751004318590276, 0.033765856496756896, 0.029554240791185293, 0.08237946822191589, 0.14476598269538954, 0.06097975870943628, 0.10216775248409249, 0.00789395673564286, 0.030300512953544967, 0.051104211088386364, 0.04273559432476759, 0.10355772086768411, 0.029807075661665294, 0.050875258530140854, 0.056442846689606085, 0.04973292256181594, 0.03677153603348415, 0.11842252322821878, 0.06168001586047467, 0.05879604854271747, 0.03220059283194132, 0.032737495857873, 0.054400608423748054, 0.05385626165661961, 0.04146113380556926, 0.034527455864008516, 0.05485653571668081, 0.12339163979049772, 0.13784318463876843, 0.011062816920457408, 0.06254027262912132, 0.029416809884423856, 0.029566074335889425, 0.025893224446917884, 0.024849664623616263, 0.014852061540295836, 0.08962774998508394, 0.09854561169049703, 0.08769664462306537, 0.0022431313800552743, 0.07708189936238341, 0.11710848397342488, 0.6541003449819982, 0.9555572282988578, 53.77026490867138, 69.1140429675579, 46.91431559622288, 92.15595334768295, 91.54961228370667, 46.47749483585358, 40.319678261876106, 34.99846659600735, 59.704094901680946, 87.61982515454292, 69.72563534975052, 69.20512408018112, 74.5104070007801, 39.80108208954334, 1.6290929960086942, 0.12331779609667137, 20.628944858908653, 43.477506414055824, 40.253964588046074, 45.726719722151756, 35.65927393734455, 45.510564520955086, 44.910747706890106, 29.3372168764472, 24.493035413324833, 27.378203496336937, 21.16050973534584, 14.263804759830236, 7.389932284131646, 4.8249392956495285, 8.986845519393682, 8.842614758759737, 7.735319500789046, 6.622105110436678, 5.734370620921254, 2.6423444878309965, 14.03984097763896, 38.79777632653713, 54.950147196650505, 28.272344917058945, 28.09448216110468, 29.065466858446598, 18.92198145389557, 17.64898706227541, 25.543291456997395, 19.089689254760742, 5.514463121071458, 13.077770601958036, 3.0067382846027613, 4.1120899468660355, 11.105420887470245, 33.085907623171806, 53.22005443274975, 57.471475303173065, 63.99862065911293, 52.03930199146271, 51.386394426226616, 57.83269912004471, 65.39450615644455, 65.01274064183235, 75.55889993906021, 42.47328110039234, 15.743901338428259, 63.01196560263634, 66.23863086104393, 62.47207537293434, 57.45220273733139, 62.68606089055538, 59.5280085504055, 65.78090742230415, 69.59359243512154, 58.542010858654976, 56.44527196884155, 62.32520945370197, 44.87891301512718, 23.33667006343603, 4.588392013683915, 1.0090102069079876, 1.008481322787702, 0.274376745801419, 0.24503887630999088, 17.32187021523714, 7.1935702208429575, 14.767923709005117, 14.052585493773222, 24.439564682543278, 30.391907282173634, 28.380384519696236, 42.21132315695286, 61.16920128464699, 62.412008196115494, 33.595391884446144, 10.803189855068922, 3.3953814301639795, 3.817618335597217, 9.3478973954916, 9.682680331170559, 17.43507944047451, 23.90654258430004, 23.19046910852194, 21.025696769356728, 18.76299988478422, 22.76402749121189, 19.9898761510849, 16.540339551866055, 21.051677875220776, 22.236817181110382, 25.89474029839039, 38.448168486356735, 49.36977803707123, 52.67007194459438, 53.03259149193764, 59.12963792681694, 22.17997793108225, 1.3271763967350125, 0.037599995484924875, 0.7107921154238284, 15.730230621993542, 45.91230936348438, 67.74464964866638, 59.26727034151554, 27.33443934470415, 25.737491436302662, 29.183416329324245, 57.635037526488304, 89.63019087910652, 46.45875424146652, 41.424419581890106, 46.139415577054024, 3.603477026335895, 0.7415382249746472, 0.08938115657656454, 0.09226288631907664, 0.13439166359603405, 0.08924264955567196, 0.06839661189587787, 0.08917548519093543, 0.04753176821395755, 0.06662850442808121, 0.07670105886063538, 0.04423293663421646, 0.027673404802044388, 0.013005553591938224, 0.07630131585756317, 0.02788413763482822, 0.010873174996959278, 0.06072781812690664, 0.048743613733677194, 0.022892797460372094, 0.021725349070038646, 0.11218555868254043, 0.255255964002572, 0.13243727706139907, 0.14043739152839407, 0.2303796191699803, 0.1832495754933916, 0.11115251138107851, 0.1184862143418286, 0.11331012021400966, 0.2390860504237935, 0.2604273974429816, 0.24931634834501892, 0.18527543084928766, 0.25305451650638133, 0.11650257976725698, 0.20346349629107863, 0.1534594560507685, 0.3268541267607361, 0.19286470720544457, 0.4000137385446578, 0.2647932741092518, 0.18555913906311616, 0.13522934052161872, 0.3547963430173695, 0.9649864817038178, 0.9186409029643983, 64.99309569597244, 94.13877815008163, 63.422381579875946, 103.33803132176399, 122.90912434458733, 77.66522571444511, 73.6216650903225, 54.19256664812565, 47.81640239059925, 87.48467400670052, 71.64370402693748, 78.34638476371765, 84.34488728642464, 50.07296830415726, 3.5149878496304154, 0.18550337408669293, 25.97353097051382, 48.36275227367878, 55.71404680609703, 66.34294286370277, 46.8770357966423, 55.805162116885185, 55.21808601915836, 41.014584973454475, 38.05897817015648, 42.92980000376701, 33.712820783257484, 33.36298495531082, 22.843726314604282, 15.905596911907196, 17.344655692577362, 16.34404968470335, 18.650601916015148, 15.59812881052494, 15.531427189707756, 12.573268823325634, 18.819056376814842, 43.035498932003975, 66.92703992128372, 48.39473135769367, 37.85484932363033, 35.86835391819477, 25.109491534531116, 27.83726256340742, 35.2948696911335, 18.841484673321247, 7.0764258317649364, 17.951281741261482, 4.782511247321963, 5.760331302881241, 14.368692431598902, 33.79159055650234, 50.615184009075165, 60.35787642002106, 62.6074431091547, 62.30239547789097, 55.30458077788353, 57.74886801838875, 66.35086923837662, 63.53131793439388, 74.70473617315292, 51.7063182592392, 19.817407205700874, 61.10852614045143, 65.64346119761467, 63.99457007646561, 58.87265011668205, 63.43523249030113, 58.94414708018303, 65.69083705544472, 68.96908834576607, 63.44347804784775, 61.077831387519836, 67.84414350986481, 52.74199068546295, 22.230576016008854, 2.50904502812773, 0.797442962648347, 1.737520534079522, 0.4230797180207446, 0.40130486770067364, 22.484805174171925, 17.58728977292776, 22.15118307620287, 25.146575644612312, 36.627458184957504, 42.0269912481308, 38.513931557536125, 53.820315822958946, 83.55570763349533, 67.95677706599236, 33.803255930542946, 12.289749886840582, 14.134207013994455, 13.109064772725105, 19.051598198711872, 14.778038766235113, 27.939817160367966, 30.929196551442146, 31.39888744801283, 32.08242326974869, 35.22032529115677, 39.62802417576313, 33.531251326203346, 29.366374611854553, 33.51161777973175, 26.724275685846806, 30.876877158880234, 40.904839262366295, 56.06189154088497, 58.834329172968864, 61.82661920785904, 59.924338683485985, 26.751913502812386, 1.052243693266064, 0.15323755389545113, 1.1145070334896445, 22.08660364151001, 51.4348304271698, 80.13054862618446, 59.71235565841198, 33.719071447849274, 49.533587247133255, 52.29078009724617, 74.36773225665092, 106.00874841213226, 53.83640415966511, 55.86722418665886, 69.22258794307709, 4.216739181429148, 0.8398454217240214, 0.1968311154632829, 0.18941228074254468, 0.48387298244051635, 0.20051101018907502, 0.18958723463583738, 0.1941280800383538, 0.11721855931682512, 0.14180846483213827, 0.0978485940140672, 0.1410862067132257, 0.07784343193634413, 0.12507276755059138, 0.21355948032578453, 0.12481570243835449, 0.11286067558103241, 0.2231797922286205, 0.18379958113655448, 0.09572317954734899, 0.1378547472995706], [0.033691203861963004, 0.035557174633140676, 0.0948277635325212, 0.033866851663333364, 0.08939219231251627, 0.05539176519960165, 0.05235411394096445, 0.02982958685606718, 0.01828821827075444, 0.11525425026775338, 0.03461205698840786, 0.09386074510985054, 0.09556541379424743, 0.07946773344883695, 0.09658243070589378, 0.0449039234808879, 0.15834128862479702, 0.0619975140580209, 0.0923249966581352, 0.017027747235260904, 0.3602821798995137, 0.06308128344244324, 0.1733891639742069, 0.12628950382350013, 0.0853885653486941, 0.2674158458830789, 4.119445877149701, 52.67361335456371, 43.56903590261936, 45.9587998688221, 95.52354544401169, 69.11214306950569, 44.94363494217396, 58.734987303614616, 39.181278347969055, 68.37872922420502, 61.739740669727325, 68.09640437364578, 54.24807406961918, 12.974517792463303, 0.038481217925436795, 0.2168621710734442, 12.11535444483161, 33.79225552082062, 58.09302315115929, 46.89623236656189, 31.238999627530575, 47.06495851278305, 33.55535343289375, 24.446634203195572, 23.378230333328247, 19.221036806702614, 17.33147419989109, 13.095087222754955, 6.48206552490592, 6.361450972035527, 6.9696909841150045, 5.070630311965942, 5.569201558828354, 3.3276415150612593, 3.468005508184433, 2.6439465768635273, 3.1394214648753405, 22.596154399216175, 43.408999890089035, 31.3381078094244, 27.56620980799198, 27.487525530159473, 14.896775744855404, 20.936762541532516, 23.229817897081375, 16.956048645079136, 13.39619256556034, 10.13149419799447, 0.36174308275803924, 1.7810227372683585, 5.630555916577578, 16.313018649816513, 36.611723229289055, 50.34917928278446, 55.78053943812847, 55.42058855295181, 55.9811382740736, 49.1798110306263, 52.54487246274948, 57.53558926284313, 64.69278261065483, 65.47802567481995, 12.755212560296059, 37.29439839720726, 64.14656952023506, 52.259260788559914, 56.121920719742775, 54.34710815548897, 51.59830525517464, 52.11188569664955, 59.90170329809189, 54.98086094856262, 51.0980848968029, 49.52558487653732, 35.9723125398159, 20.322852283716202, 6.5559501852840185, 1.921270836610347, 0.1676338681136258, 0.3215255361283198, 0.11091751031926833, 11.259879749268293, 13.006294537335634, 13.607106897979975, 16.35328508913517, 29.03128769248724, 33.720557168126106, 30.56356117129326, 45.22710733115673, 59.145745262503624, 47.316854596138, 23.992488272488117, 7.67824181355536, 3.7548706401139498, 3.0314319720491767, 5.981138404458761, 8.195073455572128, 15.535324830561876, 18.868862204253674, 21.031001284718513, 18.10482580214739, 18.58988117426634, 17.253656275570393, 19.644282795488834, 22.795808985829353, 21.301877349615097, 18.486598916351795, 16.16042833775282, 27.81826738268137, 31.788345649838448, 34.52577196061611, 36.2649804353714, 38.3300556242466, 25.0414751842618, 2.1199447195976973, 0.03843353864795063, 0.09390920735313557, 4.9370508547872305, 31.773209162056446, 67.24860906600952, 38.33568312227726, 30.622744895517826, 42.90987767279148, 44.45387922227383, 69.11476492881775, 59.75127317011356, 26.13121870905161, 37.3177557438612, 14.334950242191553, 0.24430622812360525, 0.2596905338577926, 0.0734529976034537, 0.1583410066086799, 0.0836270407307893, 0.1715372531907633, 0.040932657866505906, 0.21720039745559916, 0.08487211220199242, 0.047085173428058624, 0.0875119908596389, 0.02846893887181068, 0.05735311679018196, 0.03941751143429428, 0.014568220667570131, 0.028148340352345258, 0.02185609508160269, 0.0488239957485348, 0.013394189427344827, 0.024870461456885096, 0.014078322492423467, 0.11958388786297292, 0.03096758868196048, 0.06828493351349607, 0.04741162934806198, 0.15407524566398934, 0.061963909611222334, 0.10117140438524075, 0.03673851417261176, 0.046675522753503174, 0.09635666938265786, 0.08167703286744654, 0.05868906795512885, 0.03391675738384947, 0.028541932806547265, 0.08277958972030319, 0.04859003740421031, 0.09156887434073724, 0.012410172112140572, 0.07609942942508496, 0.18355893233092502, 0.19047426438191906, 0.10098515500430949, 0.14286525343777612, 0.053575447818730026, 0.08635230347863398, 0.7730387721676379, 10.193527769297361, 78.31414729356766, 56.964415311813354, 64.0667662024498, 109.81419861316681, 62.38096386194229, 44.350847750902176, 31.674617752432823, 51.08593314886093, 84.54435378313065, 70.04474222660065, 72.88316711783409, 59.7001127153635, 10.890842601656914, 0.16791024390840903, 0.7086160790640861, 13.194471839815378, 40.95254190266132, 63.8361793756485, 55.06145842373371, 32.82152161002159, 46.619060039520264, 30.90585060417652, 22.590418606996536, 23.660748973488808, 21.28062129020691, 17.81670816242695, 9.582026582211256, 9.738387241959572, 10.69757167249918, 14.907778054475784, 12.027887888252735, 8.913736492395401, 6.262591201812029, 7.218638900667429, 5.6276818457990885, 7.169710351154208, 24.64119516313076, 43.90112668275833, 24.781848415732384, 28.68469499051571, 28.348555527627468, 19.316584579646587, 20.295381657779217, 23.82943332195282, 20.78669149428606, 13.558072429150343, 13.731084745377302, 2.432841779664159, 3.1606984231621027, 9.70119958743453, 22.23545115441084, 43.055865839123726, 50.58217138051987, 58.09056468307972, 58.83142992854118, 59.15484957396984, 54.246432557702065, 60.37259683012962, 64.81759831309319, 68.3749370276928, 67.90556341409683, 15.778093803673983, 41.220758110284805, 67.01663911342621, 58.06108586490154, 64.53828290104866, 62.567666843533516, 61.02482043206692, 61.60704419016838, 68.89393597841263, 60.58972477912903, 56.762786731123924, 57.85840854048729, 40.43484628200531, 16.508485861122608, 5.814869776368141, 0.9397886088117957, 0.48719976330175996, 0.41014322312548757, 0.34836121019907296, 8.498410228639841, 5.62493696808815, 13.242494612932205, 15.773265212774277, 23.37347488850355, 29.90973975509405, 30.129225477576256, 37.15490408241749, 49.85992133617401, 49.65641185641289, 28.227727711200714, 13.095076773315668, 8.426766972988844, 8.120171874761581, 11.082783602178097, 13.567343931645155, 23.035986497998238, 26.114972680807114, 26.638259701430798, 24.38284892588854, 24.454057104885578, 21.627082899212837, 20.280041880905628, 22.417801469564438, 21.34651355445385, 21.71980742365122, 21.77104577422142, 37.34735615551472, 46.984345838427544, 51.529555544257164, 46.79214835166931, 45.868706703186035, 25.483585260808468, 3.238022611476481, 0.03576490547857247, 0.06741903271176852, 5.046086004003882, 37.988906130194664, 69.42378714680672, 55.90479277074337, 24.791156016290188, 32.13068827986717, 43.944527953863144, 74.35561090707779, 76.50621950626373, 37.37241581082344, 56.645513623952866, 27.76629377156496, 0.15580863546347246, 0.6158503505866975, 0.13174344319850206, 0.12762305414071307, 0.08835174579871818, 0.1255553713417612, 0.03575835231458768, 0.16755172720877454, 0.07543211992015131, 0.17601479339646176, 0.06244071351829916, 0.03730365962837823, 0.048716120872995816, 0.056373990228166804, 0.052992386918049306, 0.09359677060274407, 0.010731085258157691, 0.024584660386608448, 0.029517762377508916, 0.030663271027151495, 0.048639278902555816, 0.18946938158478588, 0.11481264271424152, 0.2233814337523654, 0.17523933813208714, 0.16960660053882748, 0.2246243233093992, 0.2564410847844556, 0.3532985702622682, 0.2677428361494094, 0.2257514972006902, 0.2759199379943311, 0.4505989991594106, 0.2139599877409637, 0.1517586613772437, 0.19498003588523716, 0.1442781838704832, 0.2507357799913734, 0.07126613330910914, 0.18849188403692096, 0.27359802508726716, 0.4096973704872653, 0.1723228907212615, 0.23153916554292664, 0.2517527004238218, 0.2822367724729702, 0.9873336763121188, 12.379013746976852, 100.14188602566719, 79.13233458995819, 68.42881813645363, 128.46157640218735, 85.91940879821777, 68.26959148049355, 70.60629889369011, 45.25438226759434, 85.27156636118889, 77.01800644397736, 81.77454560995102, 66.78687304258347, 14.651185423135757, 0.20365053234854713, 0.9069844346959144, 17.767232917249203, 46.86800368130207, 76.19266793131828, 63.2994619756937, 40.05750373005867, 59.694059640169144, 46.964469105005264, 36.34888373315334, 36.983578875660896, 33.940458968281746, 32.35440507531166, 27.93235246092081, 20.75388975441456, 18.650778606534004, 19.894894547760487, 21.418002918362617, 19.49228525161743, 16.186734326183796, 16.07524450868368, 16.804007403552532, 10.626465138047934, 27.076005712151527, 53.431285098195076, 39.34257209300995, 42.210582196712494, 40.551249235868454, 25.615785866975784, 24.938065633177757, 30.67805092781782, 22.244460470974445, 18.612784445285797, 17.397909834980965, 4.520379463210702, 4.58399897441268, 9.756339378654957, 24.904956109821796, 44.141277596354485, 54.22991864383221, 59.5087093859911, 60.946681424975395, 61.33054442703724, 56.32939338684082, 59.17767874896526, 66.7195862531662, 68.73697400093079, 72.20920488238335, 19.67200990766287, 41.329097896814346, 65.91502502560616, 56.14557825028896, 65.68625450134277, 63.71368154883385, 64.92004841566086, 64.89718124270439, 69.29433569312096, 62.20400735735893, 60.80250196158886, 69.48132365942001, 46.99204042553902, 27.29786440730095, 11.623050961643457, 1.8917979556135833, 0.5758070305455476, 0.34996276488527656, 0.8557315974030644, 14.600342251360416, 18.980728201568127, 24.616889767348766, 27.291666939854622, 37.982245087623596, 44.658319652080536, 38.862589448690414, 54.74675551056862, 67.30828866362572, 53.776306584477425, 30.742394775152206, 17.316316813230515, 17.117541879415512, 15.72353633120656, 19.109879471361637, 19.90509320050478, 29.016515985131264, 30.309294015169144, 34.087127298116684, 32.60052166879177, 34.47433032095432, 30.732688196003437, 33.056193217635155, 35.41871264576912, 34.384704530239105, 30.24633139371872, 25.034785643219948, 40.19008621573448, 42.945356369018555, 48.06531943380833, 45.31314991414547, 49.769550785422325, 29.246973618865013, 3.262859028764069, 0.16789332294138148, 0.16172368603292853, 6.43234851770103, 43.091040551662445, 80.59377416968346, 52.30095215141773, 33.90591502189636, 55.01293882727623, 62.27671645581722, 94.1930240392685, 87.52014890313148, 45.60433968901634, 78.019799888134, 37.274449467659, 0.16461908613564447, 0.6332093628589064, 0.3184065566165373, 0.42068231385201216, 0.30638023163191974, 0.3414994908962399, 0.10066266215289943, 0.6614137650467455, 0.20319639734225348, 0.33685026224702597, 0.1476912319776602, 0.09936392598319799, 0.20951004058588296, 0.18049234844511375, 0.1535809604683891, 0.13603730185423046, 0.13650374166900292, 0.11070762353483588, 0.13482550828484818, 0.1452607280225493, 0.19455272209597751], [0.07048612867947668, 0.0233344606749597, 0.03406736512260977, 0.1505362699390389, 0.004157578541708062, 0.07183013585745357, 0.038693449896527454, 0.05897529576031957, 0.16945281269727275, 0.05787604517536238, 0.06135742652986664, 0.03741274791536853, 0.04440772354428191, 0.14185946522047743, 0.14379310130607337, 0.041348375598317944, 0.07631106025655754, 0.07440411922289059, 0.1251873403089121, 0.07580991019494832, 0.012120178835175466, 0.0884777847386431, 0.27110856492072344, 0.09022638856549747, 0.061108116860850714, 0.2527715207543224, 1.2958145420998335, 40.06574548780918, 41.70275464653969, 37.28570066392422, 84.19703722000122, 81.82882189750671, 37.67891876399517, 54.59460027515888, 45.34667171537876, 63.83879363536835, 66.6978970170021, 57.191031351685524, 30.29292829334736, 0.341244904557243, 0.125208476674743, 1.00350750843063, 19.10464335232973, 31.770233921706676, 30.833694376051426, 35.93675024807453, 33.509315103292465, 57.78266720473766, 41.67089715600014, 22.914235331118107, 16.017846688628197, 17.144828215241432, 14.772396069020033, 9.233897812664509, 7.44675918482244, 8.823047708719969, 9.68388581648469, 7.041925583034754, 8.060295637696981, 7.52120858989656, 5.8654688112437725, 4.562058476731181, 7.083451179787517, 12.769535891711712, 18.74436378479004, 18.18895898759365, 26.5424345433712, 28.9385137706995, 25.183882042765617, 17.856321036815643, 21.95694699883461, 22.648696079850197, 18.3488430082798, 11.351793967187405, 2.6814035419374704, 0.9653261478524655, 1.23720221221447, 9.97639887034893, 22.93237555772066, 35.37119619548321, 58.43558996915817, 60.13369984924793, 56.89494363963604, 53.0700308829546, 51.19224764406681, 57.58140720427036, 57.010130658745766, 73.9300337433815, 17.862353213131428, 17.153335958719254, 65.40967494249344, 50.73995031416416, 60.816158428788185, 52.23461531102657, 55.84274969995022, 55.58329202234745, 59.212367087602615, 57.55876801908016, 52.14602306485176, 50.06093814969063, 39.09510277211666, 30.142859145998955, 15.265114679932594, 8.4345119073987, 1.3376772520132363, 0.3136955515947193, 1.0662281303666532, 3.8966692937538028, 15.651114117354155, 17.04608291387558, 18.481100611388683, 26.81201107800007, 28.318575136363506, 29.93531808257103, 40.073698461055756, 41.75860784947872, 32.08551250398159, 21.330552510917187, 14.133462253957987, 4.3338726460933685, 4.848736943677068, 8.352457210421562, 14.771184884011745, 21.235365718603134, 21.80201031267643, 24.213051237165928, 22.988428249955177, 20.54711055010557, 19.574963115155697, 19.532126113772392, 20.079365149140358, 23.458438329398632, 21.312360987067223, 22.889443561434746, 23.839901760220528, 20.16598530113697, 24.5496029779315, 28.934544883668423, 44.41788375377655, 23.34566418081522, 1.6430996381677687, 0.19787911704042926, 0.09985642260289751, 1.176154688000679, 22.71534450352192, 56.511593610048294, 26.072793044149876, 31.869121715426445, 35.64407095313072, 42.33053416013718, 70.40471971035004, 44.448510110378265, 32.7901466935873, 39.88138698041439, 5.187751427292824, 0.3980938025051728, 0.03344264376210049, 0.08935564896091819, 0.09779602769413032, 0.1014545930956956, 0.15949200344039127, 0.18860798561945558, 0.02410709948890144, 0.04507531506533269, 0.07212013748358004, 0.09650899519328959, 0.13039283832767978, 0.054961887290119193, 0.0278073884328478, 0.08612018937128596, 0.013963507608423242, 0.01686641546257306, 0.050323011600994505, 0.04788972459209617, 0.15071705711307004, 0.09385629222379066, 0.02158672701625619, 0.0779473251895979, 0.049388094776077196, 0.050176500517409295, 0.03931919171009213, 0.03617449678131379, 0.04277023777831346, 0.1980434582219459, 0.15373544592875987, 0.08876411273377016, 0.18360513844527304, 0.07000864570727572, 0.05293505601002835, 0.13336925127077848, 0.14877423323923722, 0.053209116304060444, 0.01892574167868588, 0.03864239013637416, 0.0789849366992712, 0.05118331660924014, 0.035313497864990495, 0.15377050498500466, 0.23725680483039469, 0.19202719355234876, 0.02190554623666685, 0.398503111791797, 1.6974180797114968, 54.3322129547596, 62.91393466293812, 49.60178978741169, 109.16218400001526, 76.87441974878311, 43.79366084933281, 32.427847534418106, 41.7195725440979, 82.89663299918175, 71.79763376712799, 63.72682884335518, 29.595580212771893, 0.4296386707574129, 0.22519524267408997, 1.8828310305252671, 19.210097193717957, 37.111305221915245, 42.480797097086906, 51.47225081920624, 33.582160994410515, 53.15333381295204, 46.1158150434494, 25.41787538677454, 19.411039911210537, 19.932280741631985, 13.836346697062254, 11.258814856410027, 13.11844551935792, 16.1789770424366, 18.70147168636322, 12.313736099749804, 10.243964362889528, 11.29470868036151, 10.901560876518488, 9.617744665592909, 10.445394404232502, 12.898438274860382, 23.592307046055794, 18.68889056146145, 29.540013894438744, 34.545447304844856, 28.447794802486897, 19.112415835261345, 18.934703171253204, 25.204505436122417, 15.786871332675219, 13.057241253554821, 4.053486166521907, 1.2885933858342469, 2.768496531061828, 14.37880938872695, 27.210942171514034, 39.9423661082983, 59.9466472864151, 61.12990379333496, 61.34685315191746, 58.99184592068195, 55.25229938328266, 62.840047627687454, 61.23780280351639, 77.43960902094841, 18.19095578044653, 19.176157414913177, 67.50373497605324, 56.316610872745514, 65.50166040658951, 58.50645996630192, 65.25876224040985, 62.53284551203251, 68.98041173815727, 62.67219543457031, 60.84470249712467, 58.77001762390137, 48.07883530855179, 33.243861347436905, 16.539148315787315, 9.236134942620993, 2.2111063404008746, 0.6363075028639287, 1.02334042545408, 8.690393026918173, 7.780584571883082, 7.657521525397897, 11.082747504115105, 16.510412357747555, 28.474592864513397, 32.546887546777725, 38.215788155794144, 38.6651748418808, 34.04635168612003, 27.515522427856922, 14.95966712012887, 8.00191842019558, 8.620424531400204, 14.01718944311142, 19.883546456694603, 31.62877131253481, 28.861176520586014, 29.15058609098196, 29.022234678268433, 28.14027350395918, 27.408092692494392, 26.808880046010017, 23.14941231161356, 25.7043382152915, 20.17298262566328, 25.037802681326866, 31.130507849156857, 32.89826989173889, 37.53653280436993, 42.22255155444145, 49.079659804701805, 28.250872269272804, 1.6543134301900864, 0.39259267738088965, 0.15669936110498384, 1.7228676890954375, 24.755242243409157, 65.62109559774399, 39.99781273305416, 22.758342996239662, 35.954453498125076, 50.029901415109634, 80.83414927124977, 59.287356063723564, 42.70871266722679, 64.02327373623848, 10.920044984668493, 0.543373633408919, 0.12770200381055474, 0.05946528763161041, 0.06681828643195331, 0.14050062251044437, 0.04441361619683448, 0.32044770021457225, 0.05445813229016494, 0.05386186116083991, 0.08856626358465292, 0.043348062827135436, 0.15748735866509378, 0.02031046122283442, 0.039665295989834704, 0.08807508056634106, 0.07498654929804616, 0.021204289041634183, 0.060693234045174904, 0.05219791411946062, 0.14987522416049615, 0.07795980069204234, 0.13530316937249154, 0.1384261267958209, 0.17141224583610892, 0.2122453594347462, 0.04978605662472546, 0.1562350883614272, 0.11904925951967016, 0.30047297361306846, 0.28271866380237043, 0.19616619567386806, 0.28151115984655917, 0.20224322739522904, 0.14230748492991552, 0.2032719925045967, 0.27000686153769493, 0.14805911458097398, 0.09850664151599631, 0.28732449165545404, 0.16288551822071895, 0.11067204497521743, 0.20330329629359767, 0.30442087270785123, 0.5083893262781203, 0.38114932423923165, 0.11379080184269696, 0.7284012017771602, 0.986054273089394, 67.72555187344551, 83.57485100626945, 65.85848405957222, 122.69157841801643, 104.33631375432014, 58.974526450037956, 68.92758697271347, 52.77003698050976, 78.40942338109016, 82.76549443602562, 72.1676579117775, 39.528488516807556, 0.9110518789384514, 0.9559107874520123, 2.8283801302313805, 25.861499682068825, 45.068074464797974, 44.91498827934265, 50.9394434094429, 45.60105286538601, 67.52258196473122, 55.662719160318375, 35.16309656202793, 30.118660144507885, 33.977176398038864, 30.781494677066803, 24.845664091408253, 18.687967211008072, 20.48632711172104, 23.341131024062634, 18.869753256440163, 22.735937498509884, 23.241872750222683, 18.30371093004942, 18.720698654651642, 15.17827793955803, 18.443416133522987, 26.950222961604595, 28.43645431101322, 42.7238966524601, 47.95705184340477, 37.320343405008316, 23.341271616518497, 26.840908527374268, 29.654114171862602, 23.71177263557911, 20.150649324059486, 4.290814781561494, 1.9231234746985137, 3.4986943239346147, 17.916640900075436, 29.75906454026699, 42.03521400690079, 60.192159712314606, 65.00908523797989, 63.41887056827545, 64.49555039405823, 55.03168322145939, 63.48771907389164, 59.01042692363262, 80.85437178611755, 21.51315551251173, 20.352836474776268, 69.53925535082817, 60.191867128014565, 68.691536039114, 60.74069827795029, 66.67908802628517, 64.94971722364426, 65.85017770528793, 62.24509455263615, 64.25348058342934, 63.47252368927002, 54.476411417126656, 40.65455809235573, 18.79246160387993, 11.32915573194623, 3.1326309917494655, 1.913310382515192, 2.3812241619452834, 14.784457571804523, 28.769990913569927, 28.296790905296803, 28.326343819499016, 35.76425850391388, 37.583300694823265, 39.382545948028564, 52.12580434978008, 51.091279461979866, 37.333281710743904, 33.91441896557808, 25.778793320059776, 16.20488215237856, 15.159686487168074, 21.60413023084402, 26.115495152771473, 35.07171146571636, 31.194587610661983, 35.909304320812225, 33.893664479255676, 31.80192232131958, 31.89521111547947, 32.7474369853735, 33.03890034556389, 37.304160073399544, 32.87824496626854, 37.817702516913414, 35.51608622074127, 30.97972624003887, 37.29697085916996, 39.06509958207607, 53.36641497910023, 29.750670790672302, 2.1250388212502003, 0.3486035659443587, 0.1673320514964871, 1.8700330797582865, 29.226627610623837, 70.80187439918518, 35.46013422310352, 36.40843413770199, 53.784289956092834, 64.2835445702076, 99.95965540409088, 69.85897779464722, 50.57245150208473, 86.03793203830719, 11.86672143638134, 0.4851449345005676, 0.20024362922413275, 0.2102709497557953, 0.1662874489556998, 0.340700019733049, 0.33320863265544176, 0.37950157828163356, 0.1964538817992434, 0.19848839059704915, 0.24587040825281292, 0.11092834567534737, 0.2724592143204063, 0.12051091194734909, 0.23873572703450918, 0.266862470889464, 0.1876875146990642, 0.10453899594722316, 0.1643315187538974, 0.13705264893360436, 0.24269178975373507, 0.13678044400876388], [0.006754909873052384, 0.07621723794727586, 0.04783131385920569, 0.10834829896339215, 0.034163421296398155, 0.04546394069620874, 0.08837917557684705, 0.058080941016669385, 0.04599940395564772, 0.052582046046154574, 0.15361707337433472, 0.03851858877169434, 0.021507662313524634, 0.04497584130149335, 0.1446145845693536, 0.06169621323351748, 0.04756752117828, 0.12690150848357007, 0.0180133935646154, 0.13870661408873275, 0.07544080304796807, 0.05251600232440978, 0.04109246452571824, 0.06329650626867078, 0.04192850872641429, 0.19227428419981152, 0.9217425459064543, 24.274355247616768, 47.5262613594532, 50.264861807227135, 62.46450237929821, 102.27731823921204, 50.61432905495167, 40.811121091246605, 57.43097327649593, 43.056747391819954, 64.75459009408951, 45.892683416604996, 11.448571924120188, 0.4340510949259624, 0.9364501910749823, 0.167442646343261, 25.750741325318813, 45.12030266225338, 34.42280128598213, 39.74801793694496, 40.43579243123531, 50.504419952631, 28.15172988921404, 19.95811365544796, 16.532126292586327, 20.290842801332474, 9.801867585629225, 11.049098409712315, 14.59662415087223, 14.789858032017946, 12.20190905034542, 7.340419040992856, 10.465134344995022, 8.005663119256496, 10.619525760412216, 8.11713868752122, 10.59234106913209, 8.74898113310337, 10.550410319119692, 13.047135695815086, 22.23866008222103, 27.621341049671173, 23.4676718339324, 17.794323563575745, 23.315980173647404, 21.5067832544446, 20.978778786957264, 11.591354012489319, 3.484601117670536, 0.4673699336126447, 0.9725223085843027, 2.201356301084161, 11.625616773962975, 27.01233822852373, 43.15253645181656, 58.41051131486893, 62.73194342851639, 54.69874128699303, 52.486367002129555, 52.12448962032795, 52.2800000756979, 72.28717669844627, 22.195270210504532, 8.057538885623217, 55.47917380928993, 48.7784081697464, 57.85716600716114, 51.18675693869591, 57.612227350473404, 53.78758057951927, 59.58942085504532, 58.900985196232796, 54.10229109227657, 54.83882836997509, 48.407133892178535, 39.17819671332836, 22.791883796453476, 9.309407360851765, 1.3344013527967036, 0.3183665400138125, 0.2623204974224791, 2.6365595357492566, 9.738088008016348, 18.725839778780937, 26.35755356401205, 36.08732856810093, 29.839663915336132, 36.99717454612255, 33.54002885520458, 26.158303655683994, 18.099059611558914, 23.98901715874672, 20.36416556686163, 5.949485152959824, 9.812640957534313, 12.363547626882792, 21.991724632680416, 20.7136233150959, 29.055841974914074, 29.57519430667162, 30.29505617916584, 29.626463055610657, 30.32952792942524, 18.54222983121872, 20.633886493742466, 18.939487114548683, 19.429721608757973, 35.47448605298996, 44.37735132873058, 32.12176635861397, 24.93295680731535, 19.885984025895596, 32.301937490701675, 21.181112229824066, 1.7277845065109432, 0.19912415882572532, 0.055374833100358956, 0.10184760481934063, 15.424537025392056, 35.3748781979084, 30.810722708702087, 40.572543293237686, 32.947477251291275, 52.384236082434654, 66.30371376872063, 35.7949760556221, 46.20808929204941, 21.625108905136585, 0.5812102218624204, 0.4492681799456477, 0.05423585535027087, 0.13572735129855573, 0.08327953008119948, 0.11826470552477986, 0.08984188927570358, 0.02044064320216421, 0.10169619185035117, 0.12534118752228096, 0.1411265498609282, 0.07061397845973261, 0.013401447631622432, 0.14208044711267576, 0.020384729796205647, 0.014773318744119024, 0.03142014662444126, 0.03913872737030033, 0.05444063986942638, 0.03439021791564301, 0.07428193945088424, 0.004093860989087261, 0.06337428334518336, 0.056965211042552255, 0.06442416997742839, 0.09221859494573437, 0.035927313365391456, 0.010661074757081224, 0.09322415309725329, 0.01624560336495051, 0.007039090278340154, 0.06306233641225845, 0.11176988919032738, 0.046176294854376465, 0.06221180548891425, 0.01930588456161786, 0.06249254511203617, 0.13038575823884457, 0.046672917815158144, 0.04399611359986011, 0.039807710418244824, 0.07720097695710137, 0.04730678985652048, 0.06819645466748625, 0.09540147337247618, 0.07529456284828484, 0.05494098470080644, 0.06255241416511126, 1.513105882331729, 30.69838933646679, 64.96542558073997, 61.174129620194435, 81.75168603658676, 106.78321525454521, 54.144259840250015, 37.952135503292084, 36.155728697776794, 64.09135848283768, 71.8490982055664, 52.435088753700256, 12.474239487200975, 0.1709853031206876, 0.31673788209445775, 0.8685518719721586, 28.556220084428787, 60.72254665195942, 40.04709608852863, 39.874908328056335, 41.05584695935249, 54.23254430294037, 39.9738360196352, 25.78804962337017, 15.614614225924015, 18.22112236171961, 12.113668285310268, 18.534996919333935, 23.867615573108196, 23.88441637158394, 18.532116673886776, 12.01530011370778, 16.440942585468292, 11.867533642798662, 16.284672170877457, 11.011488027870655, 14.366018325090408, 11.765963193029165, 15.433494094759226, 16.579277962446213, 27.413258515298367, 31.26624796539545, 24.22621563076973, 19.376609958708286, 21.233408823609352, 21.695255041122437, 16.91237948834896, 14.257919825613499, 4.749880973249674, 0.7467175845522434, 1.2657511490397155, 4.819681802764535, 18.30642208456993, 31.83943960815668, 46.47839918732643, 57.32323385775089, 65.00856086611748, 61.710558235645294, 59.52339559793472, 58.54156248271465, 57.85943828523159, 78.50887164473534, 22.959105223417282, 9.231631234288216, 61.62500582635403, 58.879143968224525, 66.28828659653664, 59.79670733213425, 66.24433055520058, 63.327599465847015, 67.30856984853745, 65.54949223995209, 64.60278823971748, 65.80074235796928, 52.760944068431854, 39.38435845077038, 24.632092751562595, 9.910509455949068, 1.5172664215788245, 1.186142808292061, 0.893721068277955, 5.79061615280807, 4.731665700674057, 5.501910969614983, 12.00875686481595, 37.4815421551466, 34.293532222509384, 37.899090349674225, 33.12998525798321, 26.42077647149563, 23.558034785091877, 25.615981556475163, 21.88491426408291, 12.144131250679493, 15.90984033420682, 19.87722549587488, 28.466831780970097, 29.39660008996725, 32.43970289826393, 34.56500105559826, 35.86772695183754, 36.541715785861015, 38.98981802165508, 26.60686768591404, 28.80444936454296, 27.28313449770212, 21.944432370364666, 34.130406975746155, 40.79780660569668, 32.938730120658875, 32.290351912379265, 30.378005728125572, 34.69860188663006, 21.845506578683853, 1.6439103009179235, 0.19011154712643474, 0.07860991463530809, 0.4479948920197785, 14.695005621761084, 54.46831785142422, 29.959351792931557, 29.633692167699337, 38.3541539311409, 61.91106967628002, 77.71033689379692, 49.00776386260986, 61.08433283865452, 44.056975319981575, 1.5747112641111016, 0.5403728631790727, 0.027065383619628847, 0.04958312747476157, 0.2613505400950089, 0.05674086722137872, 0.08488407562253997, 0.14802534686168656, 0.06862245485535823, 0.07997496169991791, 0.11026110296370462, 0.1437756311497651, 0.07943088581669144, 0.07692442304687575, 0.03993919301137794, 0.048289475016645156, 0.035374914295971394, 0.05758790633990429, 0.029377745086094365, 0.010647229064488783, 0.12241955992067233, 0.028516584752651397, 0.1063979793980252, 0.12882603099569678, 0.17673093621851876, 0.24746188457356766, 0.12562979391077533, 0.19251371588325128, 0.2546557743335143, 0.13899468613089994, 0.08493918008753099, 0.2232861568336375, 0.15986799029633403, 0.11650384141830727, 0.18462864914909005, 0.18725252710282803, 0.4187684634234756, 0.17636857519391924, 0.19197589630493894, 0.3131840337300673, 0.1256698401994072, 0.26597441697958857, 0.17478775611380115, 0.1919994966010563, 0.28621450590435416, 0.14530680055031553, 0.08486952952807769, 0.4530610592337325, 1.2726381607353687, 32.2291523963213, 90.25971069931984, 82.74435237050056, 101.45754262804985, 129.70044672489166, 75.50542160868645, 58.37046526372433, 74.09847870469093, 54.88910727202892, 83.84086713194847, 55.020610615611076, 16.495156176388264, 0.5854492506477982, 1.6946417349390686, 2.5307767745107412, 34.4670195132494, 64.70036700367928, 51.20127975940704, 54.92525093257427, 53.659341260790825, 65.39578288793564, 42.18116797506809, 35.23071013391018, 29.938399717211723, 34.63307820260525, 27.582837715744972, 25.205941759049892, 30.420491248369217, 23.911830000579357, 24.173347167670727, 19.32330831885338, 26.47472407668829, 21.20423398911953, 24.103012941777706, 22.974148616194725, 23.658963069319725, 15.575320534408092, 18.249428942799568, 20.22020649164915, 34.754629880189896, 39.81808237731457, 32.47111961245537, 24.144174233078957, 33.76436501741409, 29.90123201161623, 28.652759604156017, 20.530017167329788, 5.420934464782476, 1.8208384257741272, 1.4869566354900599, 6.509027453139424, 20.523591712117195, 35.535537376999855, 43.594695925712585, 60.63753381371498, 67.14109763503075, 67.58719369769096, 60.438078716397285, 60.67211575806141, 57.984580770134926, 78.74721005558968, 26.059584952890873, 10.498950630426407, 61.16680361330509, 58.924745321273804, 65.36698803305626, 58.89706000685692, 66.02295443415642, 63.4059664607048, 67.11237877607346, 67.62599721550941, 65.67558467388153, 64.78454768657684, 58.34852144122124, 46.45738631486893, 28.631818927824497, 10.449280645698309, 2.8667055862024426, 2.919705379754305, 1.614545714110136, 11.487960610538721, 26.219924949109554, 30.591844953596592, 39.92011070251465, 43.47847916185856, 37.827376797795296, 48.04074615240097, 44.230948984622955, 33.164137825369835, 26.202010810375214, 36.96844808757305, 35.06476543843746, 20.10850388556719, 24.812299981713295, 26.257408037781715, 33.912906646728516, 34.840630665421486, 40.000183805823326, 42.59004503488541, 40.09026177227497, 42.22287833690643, 41.37894742190838, 32.90001779794693, 36.77930563688278, 33.36884804069996, 31.33361455053091, 49.082395657896996, 51.354673728346825, 42.97556474804878, 36.63688167929649, 29.919476732611656, 40.02535365521908, 24.149404652416706, 1.279002819210291, 0.20725598966237158, 0.16823800600832328, 0.46716869284864515, 18.94966296851635, 50.817070975899696, 34.667496755719185, 52.08329223096371, 54.42068360745907, 75.62520638108253, 98.91145125031471, 52.213598638772964, 71.5078917145729, 51.73291303217411, 1.1797920428216457, 0.8061281684786081, 0.10327550437068567, 0.24263287807116285, 0.20079102250747383, 0.307466053054668, 0.18858508294215426, 0.18755280005279928, 0.18013172404607758, 0.23040075553581119, 0.19095266761723906, 0.25418700417503715, 0.2866221230942756, 0.2222850441467017, 0.1327605269034393, 0.15923002531053498, 0.08998358753160574, 0.0873448740458116, 0.12945664871949703, 0.16115907492348924, 0.2548823965480551, 0.09534977536532097], [0.06146482643089257, 0.06335256810416467, 0.061503952456405386, 0.017411749286111444, 0.055072022005333565, 0.03246548760216683, 0.022472693635791074, 0.11151761093060486, 0.019460329203866422, 0.02292854114784859, 0.061420831916620955, 0.04978576718713157, 0.06429837594623677, 0.07025403683655895, 0.18286012607859448, 0.09747464064275846, 0.07448873890098184, 0.05711316189263016, 0.03237642617023084, 0.04520301641605329, 0.05913293163757771, 0.010914650847553276, 0.054234864583122544, 0.0354702134791296, 0.16191299306228757, 0.13354542228626087, 0.7496839785017073, 7.500350559130311, 54.25056293606758, 64.34334576129913, 58.01795057952404, 92.07147628068924, 78.42175751924515, 36.91973850131035, 44.13020879030228, 39.291358441114426, 47.84454748034477, 38.12149241566658, 1.7966156755574048, 0.8122198353521526, 0.08114961077808402, 0.4811282828450203, 19.09710455685854, 41.88742473721504, 37.082278579473495, 54.42608691751957, 47.62171223759651, 39.8402351886034, 29.061782956123352, 29.957676082849503, 23.74340783804655, 14.234718270599842, 11.860840301960707, 21.026116646826267, 30.071498975157738, 24.015323147177696, 14.743046443909407, 12.154280506074429, 12.526246346533298, 10.328267589211464, 10.641664322465658, 10.476444438099861, 17.296620570123196, 9.338947925716639, 7.349206069484353, 13.362513072788715, 26.683672964572906, 34.09643679857254, 29.913921430706978, 20.68362582474947, 22.590346410870552, 20.188801176846027, 22.367391474545002, 9.753789715468884, 3.8713740510866046, 0.8299742045346648, 0.6155969516839832, 2.075348887592554, 0.8539355406537652, 2.0167284831404686, 22.116190753877163, 47.87435308098793, 60.70195555686951, 55.89457131922245, 49.14796493947506, 55.86299881339073, 46.00016064941883, 64.4932097196579, 17.681416422128677, 5.0932808965444565, 58.291281312704086, 54.13084276020527, 62.99929328262806, 54.86989550292492, 65.13235822319984, 56.74885667860508, 62.47746728360653, 55.94210296869278, 54.05019968748093, 57.34440632164478, 53.69114935398102, 49.68989945948124, 28.502312377095222, 5.96725394949317, 0.7485072291456163, 1.0797450738027692, 0.26977991277817637, 2.992955236695707, 6.231611464172602, 11.6892671585083, 30.99184948951006, 26.252063624560833, 26.959842145442963, 38.352915197610855, 24.68111392110586, 18.451549597084522, 15.495831649750471, 21.088501699268818, 16.457933373749256, 8.386828266084194, 10.929767712950706, 17.798159457743168, 23.72781727463007, 22.740064077079296, 31.68029274791479, 30.05948591977358, 32.428550496697426, 41.23721122741699, 38.873916640877724, 25.530412048101425, 24.779334850609303, 19.85334187746048, 22.65030339360237, 42.047715336084366, 56.16630993783474, 44.78098846971989, 38.11886675655842, 23.86853702366352, 25.51609631627798, 13.50944833829999, 1.7907021241262555, 0.5174011364579201, 0.41710382618475705, 0.18229671724839136, 8.467400092631578, 18.408961482346058, 35.51451690495014, 35.094533041119576, 34.53988440334797, 56.95526160299778, 54.701553136110306, 29.810356087982655, 57.35674425959587, 10.27581425383687, 0.7808422471862286, 0.29959254898130894, 0.14817150542512536, 0.04384217732877005, 0.08007109950995073, 0.12262224045116454, 0.015349363566201646, 0.16325224307365716, 0.02387636763160117, 0.047436353997909464, 0.10002741342759691, 0.05945994416833855, 0.04036380909383297, 0.0540064723463729, 0.030236923885240685, 0.0434244038478937, 0.04731807050120551, 0.08569995567086153, 0.04087615816388279, 0.07398157744319178, 0.16562987642828375, 0.03299220836197492, 0.12367207513307221, 0.027208093051740434, 0.08081876876531169, 0.08040148139116354, 0.06365330860717222, 0.0431348512211116, 0.03512790528475307, 0.065628675656626, 0.020341970957815647, 0.05185271154914517, 0.10531431762501597, 0.04945328502799384, 0.019606361602200195, 0.0701418389508035, 0.12067662610206753, 0.059784722834592685, 0.021537797219934873, 0.021719506512454245, 0.12204843413201161, 0.005652167019434273, 0.019809151599474717, 0.03181154417688958, 0.017571880634932313, 0.01750428396917414, 0.07299731892999262, 0.07699057809077203, 2.3528016870841384, 10.151492524892092, 71.75072148442268, 72.18170955777168, 74.98199969530106, 106.0621203482151, 76.7011946439743, 38.81671831011772, 30.072053745388985, 49.818146377801895, 71.31982460618019, 38.33598330616951, 2.8055402683094144, 0.6649953697342426, 0.8695221261586994, 0.12810536107281223, 24.081735983490944, 46.77995100617409, 46.686187237501144, 65.15749007463455, 58.662927970290184, 49.59457777440548, 34.03274081647396, 30.04105120897293, 26.377230808138847, 18.785365484654903, 19.519651383161545, 29.722202718257904, 35.66246196627617, 30.52668984979391, 21.683340780436993, 16.92478582262993, 19.422291107475758, 13.695116825401783, 14.282564353197813, 13.7518354319036, 18.85091956704855, 10.93252731487155, 9.513714797794819, 18.77996027469635, 27.561610154807568, 37.19431936740875, 27.62747012078762, 19.76876601576805, 20.268095321953297, 20.187596641480923, 18.95058061927557, 13.910512067377567, 5.109116546809673, 0.753191962139681, 0.7078063662629575, 2.207838515751064, 1.845180275849998, 8.672310747206211, 28.606003113090992, 49.86899524927139, 61.969255954027176, 62.99322120845318, 56.056860610842705, 62.44019888341427, 53.220050632953644, 70.254627764225, 20.688120983541012, 6.2375500705093145, 63.99548962712288, 61.229002475738525, 67.61164918541908, 60.86845122277737, 70.76924175024033, 62.63838104903698, 67.76677206158638, 61.590754464268684, 61.440518125891685, 65.12232676148415, 64.80896517634392, 54.60060395300388, 30.966147668659687, 10.030965842306614, 1.8757604411803186, 0.8409288385882974, 0.3867409023223445, 2.4207983259111643, 2.5960938446223736, 4.184845117852092, 26.462046056985855, 35.349943935871124, 27.246399968862534, 38.949619978666306, 28.753568194806576, 20.61668671667576, 20.765161849558353, 23.426586538553238, 16.90117958933115, 12.851317953318357, 16.81190337985754, 23.9637903124094, 29.601823277771473, 29.43943329155445, 36.92781686782837, 32.74726219475269, 38.94840404391289, 46.678443253040314, 44.99458260834217, 34.88946184515953, 31.89261205494404, 25.78682418912649, 29.40256766974926, 45.442236587405205, 55.46657368540764, 44.61842559278011, 44.38434295356274, 27.023522928357124, 25.3170382976532, 12.818042188882828, 2.062265477143228, 0.5030636745505035, 0.11760515888454393, 0.17975115071749315, 9.831113666296005, 26.1464748904109, 23.67441114038229, 36.474090814590454, 44.313047379255295, 69.48451548814774, 70.50409197807312, 40.03066956996918, 72.84725144505501, 16.99523214250803, 0.4810568585526198, 0.14383469126187265, 0.311770984553732, 0.03243869978177827, 0.25985166896134615, 0.01025613672027248, 0.16132727527292445, 0.15323783591156825, 0.057168800703948364, 0.08404974578297697, 0.057996833420475014, 0.07775614794809371, 0.05935807326750364, 0.03784533837460913, 0.07997156266355887, 0.024734854378039017, 0.03268143402237911, 0.03129931013972964, 0.0004508411751658059, 0.07097624300513417, 0.022820547528681345, 0.058059285147464834, 0.1695458631729707, 0.1977291883667931, 0.24983887968119234, 0.1421018803375773, 0.16582109819864854, 0.1500031110481359, 0.11014530566171743, 0.2809811773477122, 0.17013410426443443, 0.1340700761647895, 0.22809453163063154, 0.1837812500889413, 0.15945442108204588, 0.15353132563177496, 0.45287065382581204, 0.19455644767731428, 0.19450544728897512, 0.10771840854431503, 0.2723043132573366, 0.1944204862229526, 0.13067890657112002, 0.2103591911145486, 0.2236937591806054, 0.133394276490435, 0.4302882874617353, 0.11718928159098141, 3.0051718186587095, 9.703281875699759, 95.16896367073059, 97.13387623429298, 90.66831037402153, 126.22976616024971, 101.8218594789505, 55.25611437857151, 56.695746928453445, 49.65968728065491, 72.36786156892776, 45.98672837018967, 3.340687402524054, 0.9548887610435486, 1.1533530615270138, 2.261128518730402, 25.881385914981365, 58.61821196973324, 52.968481332063675, 72.31494560837746, 65.7854063808918, 53.78046736121178, 39.754538387060165, 45.37739686667919, 40.54221712052822, 31.73005487769842, 26.832279190421104, 33.380722403526306, 41.58843398094177, 35.445960983633995, 28.286641649901867, 27.30157110840082, 25.841263867914677, 22.613698057830334, 22.632339857518673, 24.978565759956837, 30.5990968644619, 17.00156070291996, 13.006851207464933, 19.86616048961878, 38.23747739195824, 50.59980623424053, 38.8844458758831, 29.242505058646202, 28.504696749150753, 30.474788434803486, 27.765226028859615, 20.227927677333355, 6.1525472067296505, 1.1184830451384187, 0.7037453341763467, 3.1627612374722958, 3.9818680845201015, 13.704721760004759, 30.218537785112858, 50.45215755701065, 66.96902006864548, 68.58704164624214, 58.29708740115166, 66.53966590762138, 55.58367200195789, 70.42717650532722, 21.195800341665745, 6.815608777105808, 65.84873378276825, 64.14269372820854, 70.36345392465591, 62.39275462925434, 72.55018338561058, 60.215938836336136, 68.49120318889618, 59.9977545440197, 59.86804470419884, 62.95555002987385, 63.244007751345634, 56.251242980360985, 36.59374259412289, 12.384494952857494, 2.6217647921293974, 1.9877875735983253, 0.36503385461401194, 12.57875382900238, 15.646306425333023, 23.569360077381134, 47.69581966102123, 33.025338873267174, 33.607809618115425, 47.36336030066013, 34.948522076010704, 26.523331068456173, 23.70856560766697, 37.43113785982132, 30.72440654039383, 23.108712695538998, 21.818820610642433, 31.32094793021679, 36.50521494448185, 36.94492354989052, 43.22208032011986, 42.10543803870678, 43.589551001787186, 53.25092017650604, 48.74090038239956, 40.52617058157921, 38.89829993247986, 33.64660553634167, 34.283010587096214, 53.13059203326702, 63.33308257162571, 54.76927310228348, 51.700990945100784, 32.945866137742996, 30.37856049835682, 16.743972525000572, 1.3326999940909445, 1.2153635965660214, 0.5683715420309454, 0.5466422892641276, 10.389269515872002, 27.63005968183279, 38.89283962547779, 58.59994634985924, 60.39162240922451, 89.40385982394218, 85.36567211151123, 43.88048239052296, 93.61585780978203, 20.60027539730072, 0.6623884721193463, 0.3152421279810369, 0.3461664420319721, 0.0958841662213672, 0.34325179061852396, 0.2561800566036254, 0.14487622131127864, 0.32339346245862544, 0.11876519507495686, 0.12665533809922636, 0.194958335487172, 0.1646025659283623, 0.1479893081705086, 0.1264148674090393, 0.1401943975361064, 0.16371519479434937, 0.1415299961809069, 0.13655076414579526, 0.11433403167757206, 0.16545118211070076, 0.23053233831888065, 0.11268680522334762], [0.05798085498099681, 0.08381061838008463, 0.03808531182585284, 0.04729717162263114, 0.029675010482606012, 0.12604376388480887, 0.024196493031922728, 0.016657035193929914, 0.017104589205700904, 0.0555057553719962, 0.012323564405960497, 0.04482513708353508, 0.0633342815854121, 0.01650514910579659, 0.017845599541033152, 0.07127799282898195, 0.02238003278762335, 0.004820680533157429, 0.10228303770418279, 0.10772095411084592, 0.07925224344944581, 0.22105388052295893, 0.07410481848637573, 0.07138593820855021, 0.05564030303503387, 0.07359079958405346, 0.27644644724205136, 1.4242033590562642, 50.937319323420525, 69.80032414197922, 46.536087691783905, 73.3488017320633, 89.09935936331749, 53.476939648389816, 34.844145476818085, 47.293706238269806, 36.62990905344486, 27.87550751119852, 0.105030846898444, 0.06368303904309869, 0.390579171362333, 0.3936994570540264, 12.875895984470844, 38.73010575771332, 37.57203809916973, 39.96076092123985, 41.496794298291206, 37.58780725300312, 36.625117510557175, 37.67881616950035, 17.248129472136497, 14.953410755842924, 20.67072171717882, 40.00744141638279, 35.946948900818825, 33.66180092096329, 15.16647957265377, 11.832262985408306, 11.00631270557642, 10.429722145199776, 9.61943557485938, 10.379517339169979, 14.021637104451656, 12.645213212817907, 12.926914896816015, 18.475775197148323, 31.09470047056675, 31.22457180172205, 23.827609419822693, 22.47500739991665, 25.964922532439232, 27.583628073334694, 19.560212306678295, 5.839015580713749, 5.054119722917676, 0.6030825013294816, 0.11789055177359842, 0.41538919787853956, 1.020598872564733, 2.9280829802155495, 12.249427400529385, 25.868609100580215, 50.669730082154274, 55.209829062223434, 50.20813845098019, 42.76564121246338, 47.24340833723545, 66.99633300304413, 10.808992143720388, 6.315117683261633, 66.1049996316433, 61.877012103796005, 64.84254017472267, 55.78849621117115, 63.90636160969734, 59.34702426195145, 56.13967336714268, 53.69764320552349, 53.74200962483883, 60.89776664972305, 59.137986078858376, 50.234129056334496, 18.623477071523666, 1.2410598364658654, 1.7536523309536278, 0.31139189552050084, 0.3184195590438321, 1.0129260155372322, 1.1471352889202535, 5.4488463420420885, 23.91815096139908, 20.897351056337357, 31.018119379878044, 38.06281216442585, 25.51198873668909, 14.135684184730053, 16.719013564288616, 18.932793773710728, 17.18033540993929, 9.375646356493235, 12.173098046332598, 20.209542363882065, 29.498793706297874, 31.46876759827137, 25.87692305445671, 29.94318176060915, 32.99092411994934, 42.89760813117027, 46.9624400138855, 35.004329681396484, 27.8904103115201, 26.909758932888508, 24.43555399775505, 47.703582644462585, 53.512509539723396, 43.950235247612, 30.303902104496956, 27.298768758773804, 18.656508699059486, 6.7548353131860495, 0.874345195479691, 0.3378495789365843, 0.1066037398413755, 0.07072492953739129, 2.84812078345567, 18.313765190541744, 24.928226061165333, 19.87366508692503, 35.03932200372219, 66.18025079369545, 42.34909236431122, 43.621784672141075, 54.38050076365471, 1.8627291591838002, 0.39773697790224105, 0.03019050811417401, 0.20102174137718976, 0.06172934270580299, 0.12355054845102131, 0.06813439627876505, 0.16508595639606938, 0.14843983633909374, 0.03600255600758828, 0.0723596136958804, 0.027422391904110555, 0.0918134194216691, 0.04873773221333977, 0.03870020715112332, 0.06239305279450491, 0.07805835790350102, 0.06394989308319055, 0.029695683006139006, 0.05469422430905979, 0.03719658627233002, 0.025442915211897343, 0.0004438406642748305, 0.03437124119955115, 0.04795960150659084, 0.038872196164447814, 0.100350255088415, 0.03714696256793104, 0.08454033508314751, 0.041396837841602974, 0.07395018459646963, 0.03620214920374565, 0.01965654006198747, 0.009316228952229721, 0.08077090766164474, 0.05115154526720289, 0.06028114541550167, 0.02181085932534188, 0.0743641248845961, 0.16084459726698697, 0.05100273723655846, 0.06907425209647045, 0.02914854576374637, 0.04639827493519988, 0.15694814384914935, 0.04186226462479681, 0.03578073548851535, 0.1382032153196633, 0.2790713938884437, 0.6911589845549315, 2.0633025839924812, 66.51399448513985, 82.32304617762566, 66.79777845740318, 88.84541898965836, 98.82515028119087, 51.79279021918774, 25.980212911963463, 41.62547439336777, 51.64911612868309, 28.612814247608185, 0.08189274551114067, 0.13912867347244173, 0.08957179205026478, 0.7683861593250185, 15.978818982839584, 48.2795063406229, 44.62376430630684, 49.141942262649536, 53.01182180643082, 48.80805417895317, 40.120268762111664, 45.26920527219772, 24.121388755738735, 22.26284008473158, 29.25291270017624, 47.96481102705002, 46.203027963638306, 39.514243081212044, 20.805895663797855, 18.94634384661913, 16.46779764443636, 15.30643841251731, 16.0941256955266, 12.121698204427958, 15.246102400124073, 11.603355668485165, 15.304992590099573, 21.382738910615444, 25.933659709990025, 32.57740370929241, 23.385508842766285, 16.181038431823254, 19.08450823277235, 14.234132152050734, 16.323192603886127, 11.987753491848707, 5.591983236372471, 0.8351624105125666, 0.18280778982443735, 0.49922071513719857, 1.6241979086771607, 3.511922601610422, 15.244252849370241, 29.735426008701324, 52.69983194768429, 61.83651767671108, 57.43878945708275, 56.03162236511707, 54.690541326999664, 73.02096292376518, 15.064496845006943, 7.518142154440284, 73.04478764533997, 66.72110617160797, 70.45546218752861, 61.59297734498978, 71.19410455226898, 63.890037685632706, 64.93381887674332, 58.856128603219986, 64.85715419054031, 71.20762422680855, 68.0161602795124, 59.145574271678925, 24.428197592496872, 5.184997525066137, 1.967434915713966, 0.7820911332964897, 0.8794121048413217, 1.4748358796350658, 4.162300452589989, 6.808874113485217, 28.75436805188656, 25.071928650140762, 26.715427860617638, 32.87827916443348, 27.358606047928333, 21.65614753961563, 18.84409323334694, 19.28123887628317, 16.974433958530426, 12.773356586694717, 22.74518620222807, 25.246004909276962, 35.56113660335541, 37.09238983690739, 31.750186197459698, 31.511325314641, 36.147239953279495, 45.333117842674255, 49.844832345843315, 40.891718566417694, 35.929010063409805, 32.96663582324982, 33.195592537522316, 50.94019576907158, 58.70720699429512, 49.241337329149246, 32.90878392755985, 21.60322777926922, 18.96576840430498, 5.732514895498753, 1.3111302140168846, 1.00604850333184, 0.38559556065592915, 0.08093802447547205, 4.103852938860655, 8.987000361084938, 19.392703995108604, 37.83185675740242, 49.028655141592026, 75.4219476878643, 56.22782863676548, 49.5091887563467, 78.00443351268768, 4.6558246202766895, 0.4760269378311932, 0.06855678220745176, 0.17265614471398294, 0.0706462915695738, 0.10951850257697515, 0.06156765099149197, 0.1470424613216892, 0.10090340001625009, 0.12043795140925795, 0.005861776426172582, 0.10803068202221766, 0.07185790702351369, 0.04583924477628898, 0.0816688989289105, 0.03375117310497444, 0.058172963617835194, 0.034387071209494025, 0.029249437029648107, 0.04541023889032658, 0.035017514528590254, 0.040924130589701235, 0.027291946462355554, 0.16574336565099657, 0.12935061065945774, 0.15127519669476897, 0.1540723512880504, 0.15045209554955363, 0.305483479751274, 0.09513569544651546, 0.15205053321551532, 0.14871110615786165, 0.144098955206573, 0.0480343283561524, 0.23898770101368427, 0.12635410035727546, 0.22103933442849666, 0.10283189301844686, 0.26500143168959767, 0.28779433050658554, 0.13418119051493704, 0.19559932843549177, 0.11990082202828489, 0.44811232946813107, 0.3262238058960065, 0.208187295938842, 0.17220425099367276, 0.2915622142609209, 0.34991075517609715, 0.841909364098683, 1.2622087891213596, 73.44549894332886, 100.5463819205761, 79.16027069091797, 106.44430384039879, 125.819091796875, 74.60902690887451, 53.63765202462673, 62.32127666473389, 51.896710842847824, 36.491851061582565, 0.17152647720649838, 0.4370819666655734, 0.6167316064238548, 1.2276969035156071, 20.257288701832294, 54.34759832918644, 53.554964661598206, 55.54132707417011, 55.277066454291344, 52.01189786195755, 48.605228662490845, 55.65148316323757, 30.97525767982006, 30.853989087045193, 35.089182928204536, 55.24284549057484, 51.0816165804863, 48.014937937259674, 28.079778850078583, 26.582262106239796, 25.503779277205467, 24.263702519237995, 25.629883110523224, 24.035642556846142, 25.636519454419613, 23.252278491854668, 20.623904429376125, 25.4313475638628, 40.60400180518627, 43.58751431107521, 31.660856790840626, 27.926077097654343, 31.615131944417953, 36.9930137693882, 27.10332814604044, 21.754784546792507, 8.982425406575203, 1.2151196971535683, 0.21486957877641544, 0.6769210891798139, 2.7741902880370617, 6.377989109605551, 15.94659861177206, 28.805072531104088, 52.20489710569382, 66.88764363527298, 60.19765041768551, 61.53592720627785, 56.178499683737755, 74.41497892141342, 16.17136225104332, 9.441395178437233, 70.79038381576538, 66.58807530999184, 69.19646054506302, 60.01668132841587, 68.67986306548119, 61.17007903754711, 63.43603424727917, 58.71140196919441, 65.33671885728836, 66.51418447494507, 70.395767390728, 58.11983071267605, 27.92309995740652, 8.055181112140417, 3.9101685443893075, 1.7990704625844955, 1.0718424478545785, 3.633824335411191, 6.000192007049918, 18.1553440913558, 39.06517177820206, 27.264314107596874, 38.270645812153816, 48.11245210468769, 32.66112461686134, 21.989391557872295, 24.943330250680447, 33.4867899119854, 30.819956213235855, 25.424363538622856, 28.259697295725346, 34.24144081771374, 44.77257192134857, 45.37392385303974, 40.08982099592686, 41.589543521404266, 46.73626095056534, 51.54906369745731, 55.70032574236393, 48.82451109588146, 41.13775156438351, 40.347982943058014, 36.00784443318844, 58.11834879219532, 64.69565525650978, 57.88949467241764, 38.955270275473595, 36.32693991065025, 24.000332951545715, 6.774023333564401, 0.7217177166603506, 2.167558539658785, 0.41644281009212136, 0.11021652215276845, 4.764694953337312, 21.616466268897057, 28.768934570252895, 59.88908037543297, 65.71232870221138, 99.63119342923164, 65.80676883459091, 67.27633237838745, 89.83009815216064, 2.846351503394544, 0.4959979240084067, 0.2093665092252195, 0.413407277665101, 0.1998991094296798, 0.20566743740346283, 0.12475984840421006, 0.3232079552253708, 0.207867756835185, 0.19789115467574447, 0.204339571937453, 0.19521433190675452, 0.19247674208600074, 0.10786122002173215, 0.18074129446176812, 0.20961630129022524, 0.20274385053198785, 0.15182290168013424, 0.31971947522833943, 0.11943546574912034, 0.20203511434374377, 0.11559690727153793, 0.1741214410867542], [0.018704321919358335, 0.029074030426272657, 0.07002419370110147, 0.11280574923148379, 0.05045437173976097, 0.01752321801177459, 0.04952883566147648, 0.07948317754198797, 0.028856553326477297, 0.024014917325985152, 0.017360186720907222, 0.15574751218082383, 0.17025452514644712, 0.06850722900708206, 0.002228473035756906, 0.040160935604944825, 0.04523498813796323, 0.056715315076871775, 0.06439782373490743, 0.1081665841047652, 0.07372607084107585, 0.06610903816181235, 0.07417809814796783, 0.14653135905973613, 0.09617729971068911, 0.05854359958902933, 0.020561852616083343, 1.507656262256205, 16.312650069594383, 60.69965288043022, 52.94612713158131, 62.01211765408516, 81.32160991430283, 67.12804913520813, 46.41055002808571, 44.370868876576424, 37.24549122154713, 17.192369364202023, 0.18913658772362396, 0.17034867400070652, 0.3510997351258993, 0.4255548695800826, 8.718803152441978, 34.686431139707565, 35.434462800621986, 53.351276591420174, 41.39938272535801, 42.363702580332756, 49.17870528995991, 35.856718942523, 27.04309567809105, 20.491646826267242, 28.477659299969673, 54.58850920200348, 42.55837753415108, 31.675734892487526, 19.7920036688447, 14.297159370034933, 15.322510600090027, 14.102965090423822, 9.85746145248413, 10.40275689214468, 13.8929608091712, 13.504996877163649, 11.31036764010787, 26.50090467184782, 33.01979877054691, 31.510814242064953, 26.327827759087086, 24.899172820150852, 26.979595385491848, 39.606179147958755, 25.24371363222599, 8.062433023005724, 3.5277378279715776, 0.281278986367397, 0.213232712703757, 0.04913698910968378, 0.44811817759182304, 0.3164109808858484, 5.076569868251681, 13.969249315559864, 29.93126939982176, 42.99938566982746, 42.3884354531765, 36.15184910595417, 48.39088216423988, 63.59535209834576, 8.462914433330297, 11.946463007479906, 68.11060801148415, 60.360969454050064, 63.185027316212654, 57.860506027936935, 56.945781111717224, 54.7617457062006, 53.541406989097595, 56.47434040904045, 56.19854360818863, 61.99254870414734, 55.49786880612373, 37.832590118050575, 9.228375758975744, 0.9805762732867151, 0.5721259780693799, 0.07070937412208878, 0.09207138995407149, 0.04397015327413101, 1.291640941053629, 3.6060763243585825, 22.199928760528564, 27.563931830227375, 27.638046853244305, 38.390962556004524, 29.358649626374245, 11.70703500509262, 18.27380083501339, 18.998691737651825, 14.157679304480553, 9.857501350343227, 10.844298899173737, 17.39209044724703, 25.970217548310757, 24.653692692518234, 30.99139541387558, 24.243789687752724, 31.303294077515602, 36.54558777809143, 41.39086738228798, 39.84028838574886, 29.090423919260502, 26.887950003147125, 35.36077335476875, 49.96734157204628, 49.342807084321976, 43.563096821308136, 32.27662704885006, 24.23600010573864, 8.785596918314695, 2.0997910760343075, 1.2873920565471053, 1.3573582959361374, 0.2134961899719201, 0.10766030580271035, 0.7726428215391934, 6.707894057035446, 3.7207541707903147, 17.273322120308876, 51.06037572026253, 68.24569836258888, 40.58268114924431, 50.01814864575863, 9.637663196772337, 0.3797028190456331, 0.4650387290166691, 0.2757191425189376, 0.08908782270736992, 0.061312456091400236, 0.07935480083688162, 0.04328729948610999, 0.20520846359431744, 0.043858296776306815, 0.09503443681751378, 0.026693717918533366, 0.08934804936870933, 0.08331676363013685, 0.09244794826372527, 0.028006115171592683, 0.07123353818315081, 0.04555086845357437, 0.056131519449991174, 0.1307729515247047, 0.04486087891564239, 0.028914952927152626, 0.028529607589007355, 0.10873587816604413, 0.06710859976010397, 0.06477058224845678, 0.044685676402878016, 0.07883330850745551, 0.03167857357766479, 0.032669047577655874, 0.040531749691581354, 0.1095277645799797, 0.04432536741660442, 0.03318335220683366, 0.022881357253936585, 0.07340362994000316, 0.07989436446223408, 0.061021578731015325, 0.050210331319249235, 0.07687117395107634, 0.13746057782555, 0.050089984652004205, 0.04041892469103914, 0.12524233345175162, 0.030485727038467303, 0.1948825770523399, 0.038629209593636915, 0.0604306176683167, 0.07892860026913695, 0.23283796850591898, 0.02191075611335691, 1.6001770226284862, 29.07587070018053, 80.63631668686867, 68.29091593623161, 79.12092000246048, 94.21248659491539, 74.50661480426788, 43.706014752388, 33.513886258006096, 41.094384491443634, 21.079007908701897, 0.19413021742366254, 0.04912045034870971, 1.1514047160744667, 0.4831053939415142, 9.292166735976934, 40.02136766910553, 47.747162505984306, 61.10023118555546, 52.445454597473145, 50.04423804581165, 50.4917324334383, 46.074150279164314, 33.694342374801636, 27.3444727063179, 38.914521262049675, 60.84437571465969, 46.95629194378853, 35.23560047149658, 26.572511829435825, 21.292985826730728, 18.85061178356409, 18.596213534474373, 13.50971907377243, 13.236798718571663, 11.381775308400393, 10.571096409112215, 15.09879570454359, 28.699464797973633, 30.75874339789152, 27.946111522614956, 28.806923031806946, 19.05440054833889, 14.350589253008366, 19.64728843420744, 15.10171014815569, 11.684917341917753, 3.5785776749253273, 0.14348721771966666, 0.11546647481736727, 0.04065498331328854, 0.3493276349036023, 2.895941692404449, 8.0859518609941, 16.602221131324768, 34.859682843089104, 49.58807252347469, 53.95157977938652, 47.98977568745613, 54.62443247437477, 72.65827998518944, 13.874516598880291, 15.829125065356493, 79.02320444583893, 68.75312313437462, 70.20530641078949, 62.79538482427597, 64.62146043777466, 60.501801297068596, 60.4996582120657, 62.66181439161301, 63.603316470980644, 72.47015967965126, 63.54237154126167, 45.5001150816679, 11.945684999227524, 2.995694652199745, 1.3717656978406012, 0.18957200576551259, 0.1647325902013108, 0.09049879387021065, 2.36131489276886, 6.058336962014437, 27.43048869073391, 28.539814464747906, 26.734504736959934, 32.361449897289276, 30.9895259141922, 19.837755113840103, 17.825795374810696, 20.338615737855434, 15.196839943528175, 17.258649207651615, 19.301334097981453, 22.287493161857128, 31.22805431485176, 30.550516471266747, 34.10281665623188, 28.19657888263464, 35.12279212474823, 41.250711902976036, 43.42389889061451, 44.84269715845585, 34.95148591697216, 32.783424854278564, 41.01901553571224, 56.99196383357048, 56.15812137722969, 50.283298417925835, 31.76148299127817, 15.581310912966728, 8.94812274724245, 3.131683417595923, 1.0481221019290388, 0.5832814669702202, 0.26334665017202497, 0.16377250343794003, 0.8823993382975459, 3.803143724799156, 12.48983670026064, 43.631603345274925, 55.01688301563263, 78.30837920308113, 50.13471879065037, 71.70789018273354, 28.770621679723263, 0.1509803265798837, 0.37071036407724023, 0.31750846887007356, 0.02607956288557034, 0.09611918212613091, 0.060642730895779096, 0.028839070182584692, 0.1277250549173914, 0.07139669192838483, 0.0790183556091506, 0.11935791131691076, 0.13855294499080628, 0.08219480703701265, 0.0314366037491709, 0.042454420545254834, 0.03525933592754882, 0.14292294799815863, 0.02051823103101924, 0.03611011547036469, 0.0796470363275148, 0.041113697370747104, 0.03937572109862231, 0.047838349419180304, 0.29569294885732234, 0.1426302152685821, 0.1152386206376832, 0.15667605766793713, 0.1285736562567763, 0.0725294764561113, 0.2000457132817246, 0.15182686474872753, 0.09817735801334493, 0.09406962257344276, 0.057624412584118545, 0.3187470242846757, 0.21526158117922023, 0.1684891784680076, 0.11043371909181587, 0.17867659509647638, 0.28673540451563895, 0.2467636126675643, 0.08685611785040237, 0.32535335572902113, 0.17529600852867588, 0.3921628254465759, 0.21733097091782838, 0.18274501897394657, 0.217800869140774, 0.8910817536525428, 0.09079463619855233, 1.8134194426238537, 28.027396760880947, 95.23172870278358, 83.47699865698814, 98.14416602253914, 118.69753673672676, 98.7339323759079, 73.01850065588951, 60.788134932518005, 48.66223320364952, 24.459595307707787, 0.4250559088541195, 0.2029421820770949, 2.255546380765736, 0.7664282550103962, 9.685372486710548, 47.86854699254036, 46.84451714158058, 66.3721252977848, 56.77485108375549, 54.84554260969162, 62.34436422586441, 54.232232719659805, 43.07676091790199, 36.322946324944496, 41.99387602508068, 67.0857498049736, 53.037709817290306, 43.72262366116047, 34.61394242942333, 27.554899714887142, 29.690305329859257, 26.83439377695322, 22.723892144858837, 24.71428234130144, 27.80055273324251, 21.97615496814251, 20.499595999717712, 37.30493903160095, 43.85649427771568, 38.668602257966995, 36.971959099173546, 32.757871225476265, 29.96033973991871, 45.96332922577858, 31.244456134736538, 17.851119115948677, 6.329206852242351, 0.3389179747318849, 0.1829353056382388, 0.08275344385765493, 0.46815637266263366, 3.2437185058370233, 8.610846195369959, 15.894532855600119, 35.48492789268494, 50.77071726322174, 57.42869719862938, 58.33097778260708, 56.11516088247299, 75.70622563362122, 15.97968153655529, 20.39461523294449, 79.8626098036766, 70.11743992567062, 66.88239231705666, 61.78888723254204, 63.32699529826641, 60.86954176425934, 58.11777502298355, 60.61180159449577, 62.80231185257435, 68.05532857775688, 63.82342725992203, 44.33933436870575, 17.592867873609066, 4.55806584097445, 2.3220473248511553, 0.53063232335262, 0.3077749942895025, 0.16099664848297834, 4.893429195508361, 16.730914525687695, 37.87031449377537, 35.74034258723259, 36.22076600790024, 44.293607622385025, 38.101653680205345, 17.64925304800272, 26.546906903386116, 35.70575684309006, 29.102199487388134, 27.97364864498377, 25.320524610579014, 29.76541019976139, 39.34478357434273, 39.46025937795639, 45.759451165795326, 34.59639497101307, 44.299276918172836, 48.01986627280712, 52.118903920054436, 51.26788258552551, 40.77310413122177, 37.5612922757864, 48.646570444107056, 62.63897381722927, 62.43223451077938, 53.776830956339836, 42.903133034706116, 32.083551809191704, 11.948366705328226, 2.0316854305565357, 3.0972121423110366, 2.7782161720097065, 0.5657020071521401, 0.3633358801016584, 1.289238401222974, 7.676826864480972, 20.37036493420601, 66.9265079498291, 75.03184542059898, 98.15508663654327, 60.72217807173729, 91.08118861913681, 26.636046320199966, 0.4959889588644728, 0.6644932029303163, 0.48308603873010725, 0.12660720240091905, 0.29209219675976783, 0.13923770980909467, 0.1760437074699439, 0.3846188052557409, 0.18317797308554873, 0.2540358732221648, 0.19172279426129535, 0.27298183471430093, 0.09889167515211739, 0.13705043733352795, 0.12497603602241725, 0.09667111735325307, 0.22799348080297932, 0.1220299546548631, 0.19319702609209344, 0.22315421781968325, 0.10439029181725346, 0.13229729316662997, 0.2272342934156768], [0.029760210891254246, 0.05436298895801883, 0.03873278743412811, 0.1985458328272216, 0.02085938333038939, 0.045565703985630535, 0.0247733458672883, 0.18394775834167376, 0.15115507267182693, 0.13962417579023167, 0.05757823986641597, 0.030812567019893322, 0.02866569149773568, 0.009172088102786802, 0.07046393846394494, 0.03875993890687823, 0.026077162037836388, 0.05095916574646253, 0.0787802597915288, 0.14336440712213516, 0.07673021784285083, 0.09097264031879604, 0.03862133169604931, 0.017120220691140275, 0.07355851616011932, 0.07166335301008075, 0.10086044450872578, 0.23303450405364856, 2.5631344132125378, 69.97889176011086, 75.52245989441872, 61.11134558916092, 73.32879960536957, 68.18899020552635, 42.149827256798744, 27.218156084418297, 23.359390944242477, 5.706976940855384, 0.0732249949942343, 0.6590297492220998, 0.5744705710094422, 0.3343359549762681, 1.5992070059292018, 36.08627602458, 38.588688746094704, 41.286441385746, 35.90743862092495, 35.63818506896496, 56.33930705487728, 44.05371129512787, 27.679004855453968, 29.085442386567593, 35.828756242990494, 51.35417975485325, 40.32331086695194, 27.854295149445534, 19.73044317215681, 15.149408038705587, 12.638988196849823, 13.4427210688591, 14.302939809858799, 11.155204866081476, 14.373687263578176, 14.759946037083864, 17.253762669861317, 23.59709668904543, 29.58670388907194, 27.6231212541461, 21.618962734937668, 16.50250118225813, 43.27309638261795, 35.019456669688225, 14.67067077755928, 8.93265662714839, 3.865458481013775, 1.1367215914651752, 0.18104082526406273, 0.19456030684523284, 0.0913955457508564, 0.3227189986500889, 1.3605310069397092, 10.147984363138676, 19.837361834943295, 34.13896031677723, 37.587982043623924, 31.40581827610731, 47.26888597011566, 60.874812081456184, 12.072064317762852, 15.512888934463263, 60.312571451067924, 56.99929744005203, 57.40351974964142, 51.94727472960949, 55.72750948369503, 54.46998596191406, 51.77751883864403, 52.547885701060295, 60.28987146914005, 58.745584934949875, 42.14646823704243, 17.303199917078018, 2.1456610271707177, 1.3154776557348669, 0.16839767165947706, 0.41606098995544016, 0.2525660052197054, 0.32067111635115, 2.275834917090833, 4.746007081121206, 20.757146179676056, 20.421506389975548, 30.47315262258053, 29.031181298196316, 31.911398246884346, 16.667733415961266, 13.012549951672554, 21.54024425894022, 15.06696481257677, 7.694228505715728, 9.287224151194096, 13.41642078012228, 21.551945731043816, 26.749227046966553, 26.631142683327198, 25.169516913592815, 23.857656307518482, 26.778048500418663, 33.64092864096165, 38.20246607065201, 31.720257103443146, 30.256412252783775, 44.80761744081974, 41.05531498789787, 42.543087154626846, 40.00154033303261, 34.26854856312275, 15.751454383134842, 3.818652592599392, 0.568501625675708, 0.5185970035381615, 0.4789296258240938, 0.10054369588033296, 0.6648196885362267, 0.4204568197019398, 3.731467458419502, 22.609031908214092, 29.445055089890957, 73.69677186012268, 43.07463303208351, 41.858914867043495, 43.93604300916195, 2.207512683235109, 0.36746878176927567, 0.08159428340150043, 0.32027575944084674, 0.05853272341482807, 0.03807809443969745, 0.03577653493266553, 0.08809371589450166, 0.049992440472124144, 0.12946730596013367, 0.07085517645464279, 0.09915387592627667, 0.11183536887983792, 0.03397254091396462, 0.0518793732044287, 0.04966998101735953, 0.03376495478732977, 0.08435268304310739, 0.032018707279348746, 0.07110289792763069, 0.030701621508342214, 0.03622707423346583, 0.04097763943718746, 0.037238521326798946, 0.01637387802475132, 0.04042604559799656, 0.06375891622155905, 0.1847628442919813, 0.048650444514350966, 0.12113999342545867, 0.006303892350842943, 0.04418025528138969, 0.11516243917867541, 0.05634641944197938, 0.0871240628475789, 0.07194130215793848, 0.036924325686413795, 0.08834469539579004, 0.06944852459128015, 0.12601156951859593, 0.04722468234831467, 0.05538720841286704, 0.03252246599004138, 0.15165611141128466, 0.05460939682961907, 0.0361637393507408, 0.037644164403900504, 0.012178472679806873, 0.0721490070282016, 0.030448181787505746, 0.057952067072619684, 0.7405309227760881, 5.134065533056855, 83.49228903651237, 80.95505878329277, 78.2306581735611, 81.89210370182991, 81.52008086442947, 59.550898522138596, 26.474336497485638, 23.793120570480824, 7.610374130308628, 0.2521558350417763, 0.6410169345326722, 0.07370675273705274, 0.12410994968377054, 2.60289310477674, 38.75889301300049, 45.328546687960625, 56.302179247140884, 45.98809249699116, 49.65283624827862, 61.96156896650791, 49.32726211845875, 38.86470973491669, 35.69373048841953, 46.22544676065445, 62.802627235651016, 47.745429798960686, 37.91959024965763, 25.4973766207695, 20.670125149190426, 18.768304400146008, 18.635797910392284, 18.51210694760084, 13.6992253549397, 11.373347360640764, 12.772813215851784, 16.438132636249065, 23.136323913931847, 29.511517323553562, 23.372638933360577, 25.69902990013361, 19.318273589015007, 41.86991147696972, 30.675102286040783, 8.346965555101633, 11.379265543073416, 4.518272951245308, 1.2519043358042836, 0.37753978511318564, 0.2225350885419175, 0.13999955408507958, 0.04474623565329239, 1.5931009710766375, 12.437334917485714, 25.21829679608345, 35.84041781723499, 45.39902150630951, 42.85832203924656, 53.44254769384861, 68.74197453260422, 21.41308218240738, 22.503591366112232, 71.97061568498611, 65.36938950419426, 65.91450825333595, 58.15232276916504, 64.381472915411, 60.85421338677406, 61.613059267401695, 59.8783003538847, 67.22351521253586, 67.1162697672844, 47.443779185414314, 19.249850660562515, 1.3796837604604661, 1.188613388221711, 0.1533209119224921, 0.3512133134063333, 0.17843385343439877, 0.08097257144981995, 2.4784041848033667, 6.829038206487894, 19.62159041315317, 21.17746252566576, 30.502709336578846, 23.172642365098, 30.22083666175604, 21.948923729360104, 20.635909885168076, 20.796645060181618, 20.601343140006065, 18.520762883126736, 19.168174043297768, 23.990147598087788, 27.509083673357964, 33.26034106314182, 27.81130425632, 29.085558280348778, 28.26388657093048, 31.402299664914608, 38.83661404252052, 43.89134980738163, 38.06085146963596, 39.09284949302673, 49.824568033218384, 48.29804174602032, 52.345880940556526, 46.98632933199406, 21.044754646718502, 11.195653695613146, 4.127615913748741, 0.9170296706724912, 0.48234448477160186, 0.7608790090307593, 0.06636325342697091, 0.7222634030040354, 0.07614346846821718, 2.1736232517287135, 40.987530425190926, 41.28597021102905, 74.45408642292023, 63.98982793092728, 60.96329793334007, 64.59648817777634, 3.9907349087297916, 0.24896875605918467, 0.0767164584249258, 0.03423333902901504, 0.1344900723779574, 0.03344595374073833, 0.04824921350518707, 0.014976565162214683, 0.1040305060450919, 0.051311901115695946, 0.04354848351795226, 0.22990905301412567, 0.19303995795780793, 0.08913756144465879, 0.016422440457972698, 0.03551882786268834, 0.08996939024655148, 0.05803878702863585, 0.02119874334312044, 0.022596736198465806, 0.04591328513924964, 0.06319970794720575, 0.05008026251744013, 0.1267542812274769, 0.11189396886038594, 0.068179778609192, 0.12513412832049653, 0.31675649515818805, 0.12878717214334756, 0.18881308555137366, 0.13850602641468868, 0.2724708215100691, 0.3572582546621561, 0.22632672102190554, 0.24790991912595928, 0.1792199956253171, 0.13582825369667262, 0.155298023018986, 0.31030485697556287, 0.21251156780635938, 0.13033077993895859, 0.1626307686092332, 0.09745121846208349, 0.28258198988623917, 0.26110200968105346, 0.18406473565846682, 0.2333631122019142, 0.1525300942012109, 0.17085711937397718, 0.18756780627882108, 0.19918065110687166, 0.6827005790546536, 3.367055137641728, 103.88166055083275, 102.86726698279381, 92.525924295187, 104.99927937984467, 103.7911494076252, 89.44095343351364, 47.51736603677273, 33.04475963115692, 10.806363634765148, 0.8148282766342163, 1.138361559715122, 1.062772215809673, 0.9133318159729242, 2.700678720138967, 49.16208878159523, 51.11552216112614, 50.222277492284775, 49.541536420583725, 53.549500554800034, 74.34934124350548, 58.426964432001114, 44.58192475140095, 41.857945919036865, 53.4911622852087, 69.66232314705849, 56.78053177893162, 42.610727325081825, 35.41414149105549, 27.50874549150467, 28.384716287255287, 26.41070131212473, 30.0265758857131, 25.146423652768135, 29.068311005830765, 25.69070264697075, 26.412470117211342, 33.03049519658089, 43.26451264321804, 35.57526424527168, 28.987350650131702, 23.75298712402582, 52.23107390105724, 46.79346688091755, 23.439650237560272, 19.279479570686817, 5.533024175092578, 1.0419797315262258, 0.30830785632133484, 0.21753087581600994, 0.2306799663347192, 0.2940669923555106, 2.647857517004013, 13.014329206198454, 27.701074071228504, 37.813682332634926, 50.618752017617226, 51.852257028222084, 57.6412919908762, 72.55288124084473, 32.341151386499405, 26.62911169230938, 72.46385961771011, 63.2425220310688, 62.95395031571388, 52.54826568067074, 59.397428557276726, 59.29149404168129, 60.3286711871624, 60.49313776195049, 65.54960623383522, 64.55016106367111, 46.66485138237476, 21.13799214363098, 5.926158679649234, 2.5070867082104087, 0.9864007669966668, 0.4314111272105947, 0.35738100588787347, 0.43592881760559976, 5.95829070545733, 19.80895645916462, 33.0056407302618, 28.209524787962437, 42.4181042611599, 38.86725179851055, 40.49345813691616, 21.73365008085966, 28.76465979963541, 36.0036950558424, 30.14282114803791, 23.06282065808773, 23.177775889635086, 26.69977270066738, 33.97868491709232, 42.70596541464329, 40.59109769761562, 36.09891414642334, 36.20022431015968, 40.004006400704384, 45.134088322520256, 47.6738378405571, 44.4743487238884, 44.20696087181568, 54.62446287274361, 53.79495598375797, 52.97006964683533, 52.05480135977268, 41.44878387451172, 21.200540587306023, 5.011605704203248, 0.9142379486002028, 1.6176554909907281, 1.3596774777397513, 0.13022962521063164, 1.139228269457817, 1.2411999539472163, 7.827578550204635, 63.047079518437386, 54.328584149479866, 102.68206492066383, 68.63852888345718, 71.12401351332664, 84.27490264177322, 3.5139652295038104, 0.3111842426005751, 0.17924209678312764, 0.3170736593892798, 0.3208242362597957, 0.10801649215864018, 0.18327182508073747, 0.16197065793676302, 0.12449291272787377, 0.18223381281131878, 0.20930381258949637, 0.2597165387123823, 0.19548453303286806, 0.20982543850550428, 0.16032274870667607, 0.14188876521075144, 0.14810177322942764, 0.2294641057960689, 0.15937432850478217, 0.24947398051153868, 0.14928673073882237, 0.21046698064310476, 0.11105897108791396, 0.4024896025657654], [0.048999124046531506, 0.03540575424267445, 0.06017513333063107, 0.0657811424753163, 0.12615872255992144, 0.10351552977226675, 0.046437174605671316, 0.1349994380143471, 0.09919775169692002, 0.05634044515318237, 0.06949799615540542, 0.01157848153525265, 0.05989613404381089, 0.058533866322250105, 0.04800051981874276, 0.057753045330173336, 0.042876398292719387, 0.014618927907577017, 0.11414394539315253, 0.06006354400597047, 0.05737152576330118, 0.011186685078428127, 0.061606532108271495, 0.13538520637666807, 0.010141037964785937, 0.11921067663934082, 0.25239139271434397, 0.037256010036799125, 1.339069758541882, 44.19544368982315, 96.70446127653122, 68.64146992564201, 65.74677765369415, 71.82950645685196, 57.41759419441223, 7.347027361392975, 6.023580227047205, 1.0315985698252916, 0.07202742839581333, 0.4376964352559298, 0.09099642615183257, 0.6874218850862235, 0.43652948224917054, 16.355177387595177, 48.01147632300854, 37.56674878299236, 42.33428455889225, 33.83073225617409, 56.73219457268715, 48.7895567715168, 33.20800647139549, 28.557616509497166, 42.4783918261528, 49.23044331371784, 36.20911963284016, 24.78405609726906, 19.304261840879917, 13.92838440835476, 12.377114798873663, 14.761429857462645, 12.940516266971827, 13.329517543315887, 13.466293103992939, 14.169042594730854, 17.73843616247177, 25.654066912829876, 25.889593474566936, 25.638827830553055, 18.509325496852398, 13.631859719753265, 17.400738783180714, 3.7044537579640746, 5.9214146342128515, 3.607480823993683, 4.441629163920879, 1.6851816675625741, 0.08156172538292594, 0.25365114386659116, 0.4297079873504117, 0.4838564177043736, 2.825479698367417, 7.11651130579412, 19.083799570798874, 27.81021561473608, 32.4996180832386, 44.55389365553856, 43.80271576344967, 45.89627042412758, 8.76161640509963, 10.807789508253336, 50.3791406750679, 52.98097886145115, 47.970742508769035, 50.08636638522148, 50.53022816777229, 43.30819509923458, 36.98042884469032, 39.856266528367996, 46.972779259085655, 44.810752272605896, 19.903597980737686, 4.8793694749474525, 1.32707605836913, 1.0606816154904664, 0.059225314180366695, 1.0241076280362904, 0.012187402571726125, 0.3459389292402193, 2.1112640853971243, 8.050442766398191, 18.79915874451399, 29.088890701532364, 24.135905876755714, 22.058561146259308, 26.226185113191605, 29.32026408612728, 12.84854220226407, 10.95798309892416, 8.365267273038626, 10.714153982698917, 15.43186018243432, 11.333826631307602, 17.268304489552975, 19.91450909525156, 20.16193851828575, 14.246313348412514, 17.85463012754917, 22.40376692265272, 21.862949542701244, 33.82977470755577, 35.21712966263294, 41.5933433175087, 43.48128721117973, 37.48202092945576, 30.85770718753338, 36.07399508357048, 28.972122967243195, 8.688496928662062, 1.4973991876468062, 0.8951225399505347, 0.05572692651185207, 0.11029412111383863, 0.6170632573775947, 0.5761010991409421, 1.7665979987941682, 35.479600578546524, 22.03225515782833, 53.63219931721687, 67.85071715712547, 28.411966525018215, 53.184644132852554, 14.36260325834155, 0.23455915739759803, 0.2914830419467762, 0.02515358337404905, 0.08359354018466547, 0.07059358424157836, 0.04877778592344839, 0.03790568982367404, 0.03356927270942833, 0.01772710824297974, 0.08753964328207076, 0.020136631683271844, 0.16343126393621787, 0.03634287895692978, 0.04852922211284749, 0.04261701767973136, 0.05426199750218075, 0.13011870381888002, 0.06384709820849821, 0.08444554056040943, 0.03369275123986881, 0.015158697478909744, 0.057312421122333035, 0.010813038770720595, 0.07244301625178196, 0.04368347646959592, 0.08941705425968394, 0.035660856374306604, 0.05494651741173584, 0.13322555663762614, 0.09852426752331667, 0.06183116165630054, 0.09230129246134311, 0.05149197211721912, 0.1674927116255276, 0.01691425986791728, 0.07615828915731981, 0.03196032623236533, 0.05719883913116064, 0.07062838354613632, 0.09477406914811581, 0.0708709767786786, 0.0777826871490106, 0.011705694923875853, 0.021721391567552928, 0.11530280899023637, 0.045337842384469695, 0.06336696576909162, 0.19207411212846637, 0.04607868017046712, 0.08336065424373373, 0.2366474422160536, 0.039614622146473266, 0.47067732957657427, 67.96411827206612, 112.82035410404205, 73.52084890007973, 89.00987416505814, 74.98027458786964, 76.34853556752205, 22.260856591165066, 4.935300098732114, 2.53896058537066, 0.08691272887517698, 0.6958374241366982, 0.8857575268484652, 0.5217873479705304, 0.2349402947584167, 18.16511146724224, 44.84073266386986, 49.15815979242325, 53.56069475412369, 42.49918811023235, 67.22096934914589, 61.138723120093346, 44.30835083127022, 39.761860594153404, 52.20843091607094, 55.593456476926804, 44.282322227954865, 31.255635134875774, 25.46350333839655, 20.912170261144638, 19.828255623579025, 21.180306673049927, 20.484503209590912, 16.437593065202236, 16.22514456510544, 17.307278998196125, 18.52888874709606, 24.933319687843323, 28.747461922466755, 21.82453740388155, 13.093853238970041, 13.088310286402702, 17.050733864307404, 5.273371282964945, 6.607594164088368, 6.443982543423772, 3.721667309291661, 1.9087051483802497, 0.22967492026509717, 0.2539283805526793, 0.45428049692418426, 0.48714410222601146, 2.9931979486718774, 8.381758388131857, 23.406069539487362, 31.678214259445667, 35.002528578042984, 44.20942313969135, 46.95683531463146, 46.54956176877022, 13.335894551128149, 15.217421539127827, 58.91260117292404, 62.84967251121998, 56.518326848745346, 58.54704558849335, 59.10513684153557, 51.255749836564064, 46.70400828123093, 46.443441063165665, 57.344835698604584, 48.9195591956377, 20.831356197595596, 4.1913109458982944, 1.1060110456310213, 1.2390484381467104, 0.0738024155725725, 0.507802851498127, 0.08323483794811182, 0.39451448363251984, 1.8670895439572632, 5.8116385247558355, 12.558525614440441, 23.42058476060629, 21.63330126553774, 22.504784502089024, 26.5972713008523, 29.114033952355385, 18.76141157001257, 20.58158040046692, 22.17919897288084, 21.51849042624235, 25.31655002385378, 23.665909096598625, 28.424030877649784, 25.251478515565395, 25.13636939227581, 22.51718893647194, 23.63903883844614, 32.31847420334816, 30.846490189433098, 42.65189051628113, 44.775258377194405, 50.2027503401041, 54.050678461790085, 51.685651168227196, 41.487325206398964, 30.525494813919067, 16.716722287237644, 8.339800089597702, 1.9249469018541276, 0.4618664039298892, 0.2707807731349021, 0.08184860256733373, 0.5717150657437742, 0.2895118680316955, 0.7048335601575673, 45.35474248230457, 44.499685764312744, 51.79789334535599, 85.96286326646805, 41.58821739256382, 66.70206159353256, 35.76665997505188, 0.35588768601883203, 0.3359761607134715, 0.09815849261940457, 0.08101345636532642, 0.026592205103952438, 0.06405679203453474, 0.08815689492621459, 0.0037501281030927203, 0.05289601904223673, 0.04717364856333006, 0.0731714787252713, 0.08293399354442954, 0.07102751798811369, 0.11476903411676176, 0.050166826622444205, 0.10150851754588075, 0.018303430442756508, 0.06136559015430976, 0.03049890758120455, 0.007987586086528609, 0.026461926645424683, 0.05967566423350945, 0.05129225646669511, 0.10637760744430125, 0.16334121173713356, 0.17116137023549527, 0.08711557267815806, 0.10866593816899695, 0.23349073191639036, 0.2578609617194161, 0.25099755031988025, 0.2259187921299599, 0.2873507043113932, 0.26661676063667983, 0.09422139177331701, 0.20824024075409397, 0.19644859770778567, 0.10988579888362437, 0.18507616419810802, 0.11393755412427709, 0.12095362530089915, 0.160154162440449, 0.1547170104458928, 0.2354367618681863, 0.19622347463155165, 0.2128874062327668, 0.12599466339452192, 0.3084410569863394, 0.12877553526777774, 0.24012807029066607, 0.33806738443672657, 0.20720311906188726, 0.7952096918597817, 65.55329963564873, 134.3030485510826, 92.15792164206505, 105.80819517374039, 94.85513851046562, 104.17246654629707, 41.281589046120644, 9.151644576340914, 3.6579091055318713, 0.17371838068356737, 2.35090677626431, 3.0212855665013194, 0.8017394039779902, 0.3990016272291541, 19.5115939155221, 56.57040685415268, 51.893735602498055, 56.82309329509735, 50.70480220019817, 74.94611442089081, 70.281553119421, 50.48346407711506, 45.86355797946453, 60.223500430583954, 67.83055543899536, 54.334603026509285, 40.1329904794693, 33.56007277965546, 27.930306270718575, 28.617092818021774, 32.047081366181374, 28.456883914768696, 27.669322974979877, 29.72802970558405, 27.682417072355747, 29.493831172585487, 38.071133717894554, 37.03894570469856, 32.89409011602402, 22.30251755565405, 21.50062758475542, 22.546521462500095, 6.331328563392162, 12.966863103210926, 12.329718992114067, 5.117522645741701, 1.8637783778831363, 0.4038907476933673, 0.42740165954455733, 0.5497135338373482, 0.34125817415770143, 2.880628751590848, 9.425761867314577, 24.48956999927759, 35.57486906647682, 39.49806734919548, 53.52509826421738, 50.10579474270344, 53.358446806669235, 25.689669102430344, 27.34591282904148, 69.59049180150032, 65.02828940749168, 56.19387365877628, 59.726646691560745, 61.144468411803246, 57.20653831958771, 55.75462482869625, 53.260826244950294, 59.245938286185265, 47.85770997405052, 26.055108793079853, 6.811443725600839, 3.795985858887434, 3.8733672816306353, 0.3992622101213783, 1.1577880172990263, 0.16186084976652637, 1.528566658962518, 4.581655925139785, 17.949661128222942, 24.65759128332138, 41.68936036527157, 33.04983615875244, 29.182352386415005, 34.743876457214355, 37.38555550575256, 22.298105992376804, 25.592147335410118, 24.96260281652212, 25.675999335944653, 29.560477696359158, 26.408641822636127, 32.905637696385384, 32.935051918029785, 32.03455723822117, 25.929820016026497, 30.26012845337391, 38.57885107398033, 39.17923025786877, 46.732027977705, 50.17216958105564, 55.23121431469917, 56.350372061133385, 50.07924556732178, 43.611031249165535, 45.08408300578594, 38.96842136979103, 11.528018061071634, 1.9932507304474711, 1.5537715377286077, 0.4992505197878927, 0.25697296718135476, 1.0880353976972401, 0.9759795293211937, 2.9162888880819082, 69.90816995501518, 52.595341354608536, 81.26951470971107, 97.49798029661179, 48.1827787309885, 89.18827459216118, 35.19544802606106, 0.3133848588913679, 0.53426843136549, 0.20577764633344486, 0.38574401987716556, 0.23088972695404664, 0.22320869145914912, 0.19611544761573896, 0.11447627170127816, 0.09992584309657104, 0.26989447069354355, 0.15627422922989354, 0.28616032912395895, 0.13775656116195023, 0.1754466793499887, 0.13552866352256387, 0.20141546556260437, 0.2638044662307948, 0.1522677598404698, 0.15270945645170286, 0.07533399315434508, 0.11097910115495324, 0.12980498315300792, 0.1714253521640785, 0.1453574447077699], [0.06509131620987318, 0.03444457281148061, 0.18589507963042706, 0.10605662857415155, 0.09567016051732935, 0.009514240446151234, 0.034077076124958694, 0.0567961572232889, 0.03155091304506641, 0.046544069846277125, 0.0800202698155772, 0.01698532978480216, 0.07196198581368662, 0.06315148319117725, 0.16271397820673883, 0.015299093265639385, 0.1036759524140507, 0.08880418128683232, 0.06220708542969078, 0.07827366978744976, 0.05570186047407333, 0.11845833185361698, 0.022649441671092063, 0.062214863137342036, 0.040971353446366265, 0.16754789772676304, 0.13576534925960004, 0.38118325523100793, 0.2847785095218569, 6.91800900734961, 94.36853662133217, 93.90355557203293, 47.75485709309578, 73.0599944293499, 61.016251891851425, 38.539819568395615, 3.548690853640437, 0.23831009049899876, 0.39338674570899457, 0.25504507531877607, 0.32272834971081465, 0.9723544644657522, 0.4211484716506675, 0.5641403503250331, 24.420345313847065, 48.74853417277336, 32.76628777384758, 50.52132144570351, 51.59312233328819, 49.172048047184944, 40.47567129135132, 39.4206503033638, 41.04940630495548, 35.00003591179848, 30.848162099719048, 29.083325900137424, 19.69461489468813, 14.405916184186935, 15.075628347694874, 13.585238121449947, 18.470005206763744, 10.951878726482391, 8.503465857356787, 9.112961702048779, 22.60999895632267, 24.13698311895132, 21.98214914649725, 22.527433186769485, 22.36587345600128, 11.919546201825142, 6.717182183638215, 2.5159912928938866, 4.26104242913425, 4.445456508547068, 3.097378145903349, 0.2681928448146209, 0.36823093774728477, 0.05083919386379421, 0.2156408631708473, 0.6359477096702904, 1.9514241185970604, 2.2057949379086494, 7.918432150036097, 17.48916383832693, 29.444232434034348, 50.21608382463455, 44.289792627096176, 29.465066716074944, 8.020243886858225, 5.434500211849809, 31.28704994916916, 34.86569032073021, 33.958842381834984, 29.435914680361748, 32.93504051864147, 24.708215966820717, 19.80749163776636, 25.95434010028839, 35.9419521689415, 19.302234649658203, 5.659099509939551, 3.9140773471444845, 1.6541120409965515, 1.7869839048944414, 0.11434198007918894, 0.3983589570270851, 0.19901383115211502, 0.3916721174027771, 2.9895038343966007, 7.368326168507338, 22.10497185587883, 27.584692016243935, 21.640169396996498, 21.464487724006176, 18.57114437967539, 16.54801893979311, 5.023756977170706, 4.836862105876207, 4.740873081609607, 13.04521394893527, 21.030452214181423, 16.536440961062908, 20.01805353909731, 18.666357770562172, 16.417995616793633, 14.477646835148335, 16.328487619757652, 13.151214960962534, 18.27536065131426, 30.58420166373253, 39.187453016638756, 42.795017436146736, 44.76585388183594, 39.912055134773254, 38.20979967713356, 30.14770768582821, 12.406054995954037, 3.3986181439831853, 0.27815923502203077, 0.0705683215346653, 0.5102364427875727, 0.30546655878424644, 0.5879219085909426, 1.227472359314561, 34.27820764482021, 24.98750288039446, 39.874247163534164, 77.8325155377388, 33.00249829888344, 39.77370075881481, 56.16475962102413, 2.6398971816524863, 0.7395894639194012, 0.06254894091398455, 0.15179898968199268, 0.03230008886021096, 0.10059158666990697, 0.06089229660574347, 0.15395279129734263, 0.044043399539077654, 0.12752967712003738, 0.028514503028418403, 0.07428114535287023, 0.009567814231559169, 0.003473857136668812, 0.08033245423575863, 0.05868951695447322, 0.09028845437569544, 0.060263994382694364, 0.03236093383748084, 0.06137215816124808, 0.0320705277408706, 0.08672301366459578, 0.07663805052288808, 0.011251869764237199, 0.10828794009285048, 0.0821236647607293, 0.037906491343164816, 0.07270247850101441, 0.08473341222270392, 0.0658642259077169, 0.06973373936489224, 0.05001428558898624, 0.06115358082752209, 0.039956403415999375, 0.04987009000615217, 0.1438925787806511, 0.026031833513116, 0.06518020323710516, 0.042834095875150524, 0.024764473491813987, 0.03293687383120414, 0.0301329230205738, 0.12436380871804431, 0.0432248626020737, 0.014140212970232824, 0.01797534179786453, 0.046759318647673354, 0.07540638966020197, 0.024461037137371022, 0.12808386847609654, 0.20008918829262257, 0.0644088297849521, 0.028205886483192444, 0.7577055261936039, 17.678688168525696, 113.37605908513069, 97.35258489847183, 72.15587094426155, 89.84092757105827, 74.23266470432281, 56.262004002928734, 2.2926898626610637, 0.2735258883330971, 0.22865276027005166, 0.43097415065858513, 0.10064596383017488, 0.7593150367029011, 0.5954899149946868, 2.3592250049114227, 24.95683092623949, 42.04001694917679, 39.07746411859989, 56.02971866726875, 68.06893184781075, 55.417366325855255, 52.66493462026119, 54.53900545835495, 54.141379594802856, 42.62490816414356, 41.28958761692047, 38.04170049726963, 27.54325333982706, 22.27678533643484, 23.685897924005985, 21.985549964010715, 28.165703639388084, 17.666671313345432, 13.253690712153912, 15.599610731005669, 26.101016029715538, 22.639010399580002, 24.891295842826366, 21.62777066230774, 21.50404740124941, 13.099421840161085, 8.416791558265686, 5.970160318538547, 9.338624943047762, 7.935551181435585, 3.8647799799218774, 0.34310333139728755, 0.4512338322820142, 0.026542316081759054, 0.10627715775626712, 0.5158819898497313, 2.4850455159321427, 3.9722337014973164, 9.783211536705494, 21.139738149940968, 32.45526306331158, 48.67547169327736, 50.40275640785694, 35.73020853102207, 12.783080264925957, 15.587741117924452, 33.9959891885519, 38.44997338950634, 33.05645540356636, 31.332641802728176, 38.98801691830158, 28.454303853213787, 27.537323758006096, 38.67774456739426, 37.09428213536739, 16.230844259262085, 5.844758972525597, 1.105972572695464, 1.6864276444539428, 1.8724580621346831, 0.05147086543729529, 0.3262603789335117, 0.24715177074540406, 0.218440615280997, 2.9580120742321014, 4.359761606901884, 10.425033196806908, 14.577448479831219, 12.40824082866311, 17.821851186454296, 16.098297871649265, 18.50856363773346, 16.197126768529415, 18.516254425048828, 20.396756418049335, 26.12269576638937, 30.36462664604187, 31.06225971132517, 31.774822175502777, 26.95892259478569, 25.75927946716547, 22.447994649410248, 24.262040108442307, 22.481510750949383, 27.659922279417515, 40.63637226819992, 52.56039083003998, 52.82124683260918, 57.45493099093437, 49.50284689664841, 37.44364678859711, 21.607755236327648, 9.706922080367804, 3.028367911465466, 0.4561270494014025, 0.11715345812262967, 0.1182405708823353, 0.3753337066154927, 0.4823394084814936, 1.2021999154239893, 41.39696225523949, 52.09432303905487, 40.89477360248566, 83.45237597823143, 57.93709471821785, 51.24332070350647, 72.1697250008583, 5.646743047982454, 0.6465296074748039, 0.03138340660370886, 0.05787353300547693, 0.06897837403812446, 0.062196465296437964, 0.031822034434298985, 0.03270062596129719, 0.02996070765220793, 0.0766038300935179, 0.03639879607362673, 0.09931705935741775, 0.025537199508107733, 0.0336734108714154, 0.0534978377254447, 0.05834905299707316, 0.030923716622055508, 0.05172840552404523, 0.05908467348490376, 0.03166781985783018, 0.0795711888349615, 0.01209512671266566, 0.03614834349718876, 0.08805220015347004, 0.16085099457995966, 0.1489678001962602, 0.19141794968163595, 0.2406721090665087, 0.260402342537418, 0.18245170736918226, 0.11236757040023804, 0.2129141235491261, 0.2383273231680505, 0.1448532147333026, 0.16467364883283153, 0.22619485622271895, 0.10438945319037884, 0.23182971635833383, 0.16816008050227538, 0.1835518522420898, 0.11327115003950894, 0.18419427011394873, 0.19791061378782615, 0.15902725572232157, 0.2718893636483699, 0.17009356815833598, 0.2300323682720773, 0.24069668899755925, 0.19311595387989655, 0.22365987271768972, 0.3750965162180364, 0.1608219023910351, 0.7240646844729781, 0.8253480715211481, 15.525499507784843, 133.08624744415283, 122.31833204627037, 80.12997105717659, 108.8288962841034, 98.75637397170067, 85.35674259066582, 10.142220072448254, 0.5618399893864989, 0.8804055140353739, 1.9422458298504353, 1.1390742589719594, 2.388280383311212, 0.4195034864824265, 3.4320131270214915, 30.505171604454517, 58.21896739304066, 38.814183846116066, 64.73752900958061, 70.95803081989288, 65.66141903400421, 60.765590742230415, 60.51244452595711, 59.58462551236153, 52.85392887890339, 50.03909312188625, 48.18075343966484, 36.10100403428078, 30.51710106432438, 30.824696458876133, 27.43127904832363, 33.37253004312515, 27.054401971399784, 19.579120092093945, 24.64987389743328, 36.32400266826153, 32.13399030268192, 32.390905916690826, 29.13715571165085, 31.91514864563942, 18.48272692412138, 9.664619900286198, 7.748821601271629, 14.679032228887081, 12.037049196660519, 5.560930827632546, 0.42681465041823685, 0.8785961579997092, 0.13688648206880316, 0.3457214799709618, 0.521093113347888, 2.6291722571477294, 4.531475817784667, 12.452606298029423, 25.13119027018547, 37.22818695008755, 51.636865586042404, 52.786045521497726, 41.20550572872162, 18.127461187541485, 19.618960954248905, 41.95997044444084, 48.21946956217289, 46.62197448313236, 47.108781561255455, 55.47098524868488, 47.895202562212944, 45.6029337644577, 47.95995868742466, 46.86321973800659, 22.276986725628376, 9.827309120446444, 4.480164321139455, 3.644464951939881, 2.7552592288702726, 0.16616889828583226, 0.40310905838850886, 0.5296668189112097, 0.44782663229852915, 7.914134105667472, 11.760378442704678, 35.17874792218208, 32.996836602687836, 27.63000078499317, 31.138464622199535, 23.625376671552658, 25.332060791552067, 17.296012602746487, 19.69138126820326, 18.019702769815922, 28.898121938109398, 36.693247854709625, 32.2558231651783, 34.67696204781532, 29.69935454428196, 28.264410942792892, 29.062259830534458, 30.038163363933563, 27.94890057295561, 34.66723456978798, 43.99316534399986, 53.70912618935108, 53.574465215206146, 57.87606239318848, 49.36831131577492, 50.593376979231834, 40.280384570360184, 15.827718190848827, 3.6955845588818192, 0.5121986812446266, 0.3942507243482396, 0.7540435320697725, 0.7424307020846754, 1.0407817270606756, 2.135114693082869, 65.57718515396118, 54.78576801717281, 66.19630873203278, 105.46847820281982, 60.51241032779217, 65.04137590527534, 90.45423746109009, 4.273081133142114, 1.066494828555733, 0.15482996532227844, 0.28276153025217354, 0.1965752081014216, 0.251494106487371, 0.19259946362581104, 0.19599177612690255, 0.16578879993176088, 0.20505049003986642, 0.15608637680998072, 0.26800983119755983, 0.17949325439985842, 0.426008440554142, 0.2833770675351843, 0.2490700443740934, 0.1439705933444202, 0.150988356617745, 0.10644454916473478, 0.19118142721708864, 0.18614837463246658, 0.13824430061504245, 0.15509679709794, 0.10198343268712051, 0.22844056540634483], [0.12789373024133965, 0.13855073339072987, 0.0871750112855807, 0.038234271996770985, 0.012354462796793086, 0.03156452774419449, 0.09372270564199425, 0.09555572134559043, 0.10613806443870999, 0.0439932823064737, 0.03581755343475379, 0.08354868477908894, 0.027387266054574866, 0.05315606758813374, 0.18434713769238442, 0.04940432925650384, 0.05045409343438223, 0.0594488898786949, 0.03563185324310325, 0.06948482303414494, 0.045940228810650297, 0.018162748929171357, 0.07341566757531837, 0.08179202864994295, 0.05006107428926043, 0.15014600416179746, 0.13967907987535, 0.0279639055224834, 0.29218888375908136, 0.5478901660535485, 78.20061698555946, 89.68078896403313, 57.56765574216843, 60.36438547074795, 75.44371291995049, 51.252911388874054, 43.80774289369583, 2.903921501711011, 0.2985859295586124, 0.22177073580678552, 0.18824701983248815, 0.9854069421999156, 0.5655249010305852, 0.031024140334920958, 4.437647927552462, 25.23507099598646, 43.21100011467934, 45.30870035290718, 50.859792083501816, 56.71768695116043, 56.13632194697857, 40.32705366611481, 42.98737831413746, 29.709589295089245, 27.72536426782608, 19.372509978711605, 16.21450513601303, 14.786068685352802, 14.235005155205727, 16.992441192269325, 25.148251354694366, 14.835901111364365, 3.369434284977615, 2.4593251710757613, 6.860671509057283, 14.885863680392504, 23.18578016012907, 22.471931464970112, 12.90553629398346, 9.519099108874798, 8.282749950885773, 5.761553887277842, 4.873880194500089, 6.925515029579401, 3.7861918844282627, 0.0788413459667936, 0.10431480797706172, 0.15601300809066743, 0.28351255401503295, 0.15199999295873567, 0.5593533196952194, 1.2162703229114413, 6.964595457538962, 17.357502803206444, 15.91808209195733, 34.55016665160656, 24.438276551663876, 17.87581969052553, 9.026404246687889, 24.633101597428322, 26.139916442334652, 16.266687735915184, 13.139366246759892, 8.674424383789301, 13.041692487895489, 9.359519071877003, 12.288695443421602, 18.673835769295692, 10.295963622629642, 3.0262108147144318, 2.375252307392657, 0.6803970714099705, 0.691691015381366, 0.4134560812963173, 0.33396565297152847, 0.2413752643042244, 0.1012920553330332, 0.07570545290946029, 2.904749382287264, 3.2292389078065753, 14.190379399806261, 24.043739922344685, 16.069674007594585, 16.246195435523987, 15.319544859230518, 10.129316914826632, 6.602469189092517, 5.035866927355528, 3.784322147257626, 14.363946486264467, 28.536117263138294, 26.362282410264015, 20.99356759339571, 18.25574230402708, 12.276125717908144, 11.759781874716282, 12.442035265266895, 12.687626536935568, 20.987373925745487, 36.42530143260956, 44.61204953491688, 39.60787385702133, 37.395659163594246, 38.85017931461334, 36.27737917006016, 20.9342185780406, 4.880948765203357, 0.2507913816953078, 0.38133833440952003, 0.36237666907254606, 0.1173135542194359, 0.37258351512718946, 0.606598500162363, 29.69400253146887, 20.42752906680107, 34.71627093851566, 75.00634878873825, 54.16479013860226, 23.446468971669674, 52.566725090146065, 22.620157711207867, 0.2953412302304059, 0.3350357705494389, 0.1258404302643612, 0.008620641765446635, 0.07804090259014629, 0.05371873798139859, 0.06001164932968095, 0.037546137828030623, 0.059022893401561305, 0.04879452506429516, 0.040943938511190936, 0.07979068643180653, 0.04666147018724587, 0.08064780020504259, 0.04126982297748327, 0.11935713206185028, 0.13599689933471382, 0.027617292871582322, 0.11900942845386453, 0.04348261791164987, 0.06597675775992684, 0.05759806634159759, 0.09512595104752108, 0.05609717656625435, 0.06453309499192983, 0.07880317731178366, 0.07054172296193428, 0.03705652074131649, 0.048607296048430726, 0.08315397353726439, 0.012560175928229, 0.02366939192143036, 0.13568467780714855, 0.02053616502962541, 0.056153164186980575, 0.06462509903940372, 0.08508239974617027, 0.037321100098779425, 0.037840365985175595, 0.051621792299556546, 0.12285514123504981, 0.10378207211033441, 0.09705859265523031, 0.08596365558332764, 0.08733260634471662, 0.051800846558762714, 0.042121682345168665, 0.032292530086124316, 0.05477364895341452, 0.07003801249084063, 0.02145847276551649, 0.10806860576849431, 0.009431308226339752, 0.343716464121826, 1.5216322685591877, 92.6558469235897, 108.5572412610054, 69.75415661931038, 87.88885831832886, 88.71232733130455, 75.55736482143402, 45.69801226258278, 1.5295351319946349, 0.38664240448269993, 0.21684700157493353, 0.8423905726522207, 0.6411208352074027, 0.16830236505484208, 0.4275735409464687, 5.778533276170492, 17.1475450694561, 27.559358775615692, 44.26740042865276, 60.671177208423615, 70.072480738163, 68.33507716655731, 54.2552100867033, 54.47426453232765, 39.77358676493168, 38.7824859470129, 31.587847508490086, 25.39260294288397, 25.846783071756363, 25.72772216051817, 28.732251338660717, 34.40042428672314, 25.651015676558018, 15.236351173371077, 11.52677932754159, 13.9696653932333, 22.03589726239443, 25.777548886835575, 25.37923716008663, 21.467172279953957, 12.765965033322573, 11.924798469990492, 9.036264717578888, 10.88557893410325, 11.134005803614855, 2.239956292323768, 0.145993405894842, 0.03923266842321027, 0.14703861699672416, 0.4454674042062834, 0.25919709471054375, 0.7963192323222756, 1.3157943449914455, 8.60858341678977, 21.1139964312315, 19.9061818420887, 36.8915706127882, 29.298050478100777, 20.779580175876617, 8.387732617557049, 30.748926624655724, 29.689986146986485, 16.64898332208395, 10.34914081916213, 5.87472558952868, 8.793046418577433, 17.26153325289488, 23.74659776687622, 20.66779587417841, 8.094451054930687, 2.851983276195824, 1.0765106161125004, 0.3709139203419909, 0.4432715673465282, 0.2408177184406668, 0.16753879899624735, 0.1762471449910663, 0.029354790458455682, 0.13007660920266062, 0.9000769397243857, 2.936590723693371, 2.2103378316387534, 5.305056357756257, 7.82037983648479, 12.529741209000349, 20.111376531422138, 20.713932998478413, 17.951274141669273, 16.95129320025444, 19.1677313670516, 28.47238328307867, 41.76731318235397, 37.276539355516434, 33.638895750045776, 29.75036110728979, 21.802872866392136, 20.58687351644039, 25.435920618474483, 23.80741160362959, 32.49090135097504, 43.90284799039364, 52.54215940833092, 52.4381247907877, 46.92176699638367, 40.78271001577377, 29.037395864725113, 14.305943548679352, 5.360941383987665, 0.3541036817478016, 0.3821831656387076, 0.23875901562860236, 0.2568196691572666, 0.5598013987764716, 0.7723437657114118, 42.56799101829529, 51.19752936065197, 39.34167914092541, 70.4188321530819, 77.33965918421745, 40.08885204792023, 68.6462652683258, 38.95239382982254, 0.514044847805053, 0.38710491091478616, 0.3071292070671916, 0.21852072270121425, 0.037346462995628826, 0.04236739259795286, 0.01666418022068683, 0.09511467040283605, 0.013086151757306652, 0.10047982665128075, 0.00688009998157213, 0.07291090325452387, 0.025984503045037854, 0.061963957850821316, 0.08402680599829182, 0.022110636891738977, 0.08077039557974786, 0.2206413503154181, 0.06934269433259033, 0.02927341211034218, 0.031349278942798264, 0.02613940781884594, 0.033753195457393304, 0.06760239513823763, 0.038861973080202006, 0.2561652136500925, 0.12576127279317006, 0.20119363762205467, 0.13198156870203093, 0.14247641258407384, 0.18857742397813126, 0.17614468408282846, 0.26912753528449684, 0.15958459378452972, 0.2377024941961281, 0.13955110392998904, 0.4146143957041204, 0.16790837369626388, 0.12049664044752717, 0.4030480538494885, 0.15640745958080515, 0.2134038371150382, 0.2207654225639999, 0.21092294133268297, 0.19780356640694663, 0.12533467146568, 0.20812177914194763, 0.1676325619337149, 0.11438146233558655, 0.21894683421123773, 0.21100806567119434, 0.2886106335790828, 0.14920263056410477, 0.38781897572334856, 0.8780817012302577, 100.11082649230957, 123.82269412279129, 87.83132180571556, 96.72251790761948, 118.56196761131287, 93.59505772590637, 78.98491010069847, 4.987827530130744, 0.5880099569913, 0.3400209842948243, 3.402311308309436, 2.4155795434489846, 0.4794356814818457, 0.5041855049785227, 6.43526011146605, 33.8393197953701, 58.315634205937386, 59.00387227535248, 67.4238708615303, 76.01324915885925, 79.52778697013855, 64.12557184696198, 60.845124274492264, 46.91980630159378, 45.040335953235626, 37.97001734375954, 29.820167161524296, 34.69275400042534, 32.87507213652134, 32.62148514389992, 41.65701650083065, 33.512514531612396, 18.641227819025517, 15.370662566274405, 22.041845843195915, 25.91767966747284, 31.802477091550827, 28.39088525623083, 23.39502353221178, 16.168820187449455, 12.385880928486586, 11.989731285721064, 10.50302591174841, 13.789555057883263, 3.7431829422712326, 0.3450889920350164, 0.28926443599630147, 0.3112962772138417, 0.7610597962047905, 0.5410349182784557, 2.1765792556107044, 2.694728714413941, 11.532745007425547, 24.180606678128242, 23.353043384850025, 39.91632990539074, 34.55862499773502, 26.56522572040558, 15.180406775325537, 38.83853293955326, 39.7062923759222, 36.838973835110664, 36.668628975749016, 34.76669803261757, 33.02384555339813, 30.828486755490303, 33.03315505385399, 28.894738219678402, 13.738557044416666, 3.7481647124513984, 2.434777063317597, 0.5926525359973311, 1.1232116539031267, 1.0336658963933587, 0.3892126400023699, 0.4525815724628046, 0.2150348253780976, 0.10415537981316447, 4.213892184197903, 12.581933308392763, 25.46188272535801, 32.82678812742233, 21.564961932599545, 22.602068781852722, 26.86450906097889, 23.143079951405525, 13.75477647408843, 18.528143987059593, 17.298721857368946, 30.53301651030779, 48.53074885904789, 41.77920274436474, 35.50030566751957, 30.02259559929371, 23.244865089654922, 25.41382860392332, 28.82443629205227, 28.27343925833702, 36.845517084002495, 48.38140547275543, 55.23720659315586, 52.959187030792236, 47.47371017932892, 49.83496427536011, 49.8430160433054, 24.860278107225895, 8.240151386708021, 0.32519512984436005, 1.1329555185511708, 0.594907714985311, 0.24808401212794706, 0.9289448813069612, 0.975002566119656, 66.14836290478706, 53.230788856744766, 61.67912632226944, 98.43716070055962, 83.9858977496624, 46.47681087255478, 93.29206958413124, 34.702261090278625, 0.4244780429871753, 0.612174344714731, 0.46931272780057043, 0.3034860041225329, 0.15205483767203987, 0.11366270715370774, 0.2509591664420441, 0.16458690661238506, 0.181048157683108, 0.13831193995429203, 0.19346213608514518, 0.17366334301186725, 0.203964831889607, 0.20419721317011863, 0.16811495792353526, 0.28737032669596374, 0.24245192762464285, 0.17406333092367277, 0.1712645436055027, 0.16384376445785165, 0.18546398088801652, 0.1683108403813094, 0.3522811451693997, 0.1389705069595948, 0.10154809628147632], [0.0647436645522248, 0.1279938014340587, 0.16809597378596663, 0.11923452926566824, 0.03404094837605953, 0.03607956867199391, 0.08825147422612645, 0.01971783218323253, 0.06999642995651811, 0.054190476730582304, 0.09526488109258935, 0.02394287148490548, 0.02365607779211132, 0.029084170018904842, 0.02953612867713673, 0.11639225951512344, 0.09752780068083666, 0.10259889575536363, 0.028485125112638343, 0.06950333961867727, 0.1253281850949861, 0.045769549687975086, 0.04578955798933748, 0.009857063505478436, 0.10746146959718317, 0.09080958305275999, 0.03454152698395774, 0.17156987800262868, 0.1357356781954877, 0.38252211932558566, 8.952127732336521, 88.07814136147499, 85.45621365308762, 53.60324487090111, 84.11704391241074, 59.72465179860592, 51.34383291006088, 44.685374200344086, 3.260661084204912, 0.4791195265715942, 0.174213511927519, 0.47672583314124495, 0.5224971380084753, 0.16682158748153597, 0.19886390247847885, 7.97109542414546, 30.917772464454174, 50.41969209909439, 48.60899806022644, 47.899602726101875, 51.995429545640945, 59.483934715390205, 47.69932307302952, 35.17774857580662, 26.000720411539078, 22.645452953875065, 18.045402690768242, 14.189826529473066, 17.173653468489647, 25.52382320165634, 36.83254458010197, 21.073175221681595, 2.244700575247407, 1.9510024599730968, 7.118909452110529, 11.692622378468513, 18.085921816527843, 18.594380132853985, 12.720191739499569, 10.663330759853125, 7.970732543617487, 4.987230012193322, 3.4112063935026526, 6.450497768819332, 1.8747856747359037, 0.07097095149219967, 0.1094548188848421, 0.07294014387298375, 0.07001343255979009, 0.38626159366685897, 0.3930240432964638, 0.8757091441657394, 5.768731227144599, 6.734332563355565, 10.335554648190737, 17.791948691010475, 15.646220929920673, 12.856346033513546, 3.757789833471179, 7.942701922729611, 18.16006913781166, 3.3147241082042456, 2.9682292509824038, 4.324729386717081, 4.1345548164099455, 8.41622918844223, 10.140157733112574, 4.497811049222946, 1.365290607791394, 1.1167425010353327, 2.614698358811438, 1.1748578888364136, 1.6002813982777297, 0.3639595810091123, 0.4045642021810636, 0.13277761114295572, 0.11958658185903914, 0.23222637944854796, 1.666112628299743, 2.2115651657804847, 3.23305556550622, 3.569483100436628, 12.995714955031872, 15.598159208893776, 8.482039757072926, 6.178087061271071, 1.2898578867316246, 9.323497954756021, 2.642890946008265, 19.311088174581528, 39.682334661483765, 44.50347036123276, 34.889860823750496, 24.294532164931297, 15.862346682697535, 17.63449463993311, 17.933808378875256, 24.625085927546024, 33.06428298354149, 42.03310512006283, 47.78674878180027, 36.369721814990044, 35.59386424720287, 30.63101325184107, 24.802217222750187, 8.662905301898718, 0.5689181189518422, 0.20712546072900295, 0.1713460759492591, 0.2090919591137208, 1.0230961698107421, 1.068581510335207, 28.1167945638299, 22.509370855987072, 26.7525689676404, 77.84622520208359, 63.61277036368847, 23.397333808243275, 48.28824207186699, 41.69865846633911, 0.7934036606457084, 0.394762420328334, 0.1465061111957766, 0.21406281972303987, 0.19719187344890088, 0.12284262120374478, 0.0788956563337706, 0.08673051677760668, 0.05959570153208915, 0.05537400189496111, 0.1049503758258652, 0.08432931281276979, 0.040354198281420395, 0.060205412955838256, 0.03460750762315001, 0.01745721139741363, 0.0806098616158124, 0.057444701524218544, 0.07971456434461288, 0.008271798033092637, 0.05078978167148307, 0.015601767991029192, 0.027229837978666183, 0.07731123041594401, 0.027754556795116514, 0.0466740124829812, 0.025908887473633513, 0.05331254200427793, 0.15122047072509304, 0.09757298263139091, 0.019809851073659956, 0.06619594365474768, 0.028802554661524482, 0.038438596384366974, 0.05067927959316876, 0.03669127276225481, 0.21123479178640991, 0.050700000356300734, 0.058576510127750225, 0.034865359411924146, 0.025201993666996714, 0.15722591488156468, 0.051263264467706904, 0.06960938510019332, 0.055077302386052907, 0.028170543555461336, 0.036421917684492655, 0.04767342936247587, 0.052788058819714934, 0.05461561231641099, 0.04824762530915905, 0.021412531968962867, 0.07623720171977766, 0.13487714692018926, 0.15210034616757184, 0.4059808433521539, 31.863334625959396, 103.88126537203789, 85.15086963772774, 78.07843074202538, 96.82034745812416, 79.73923042416573, 78.55829179286957, 44.461835995316505, 1.6535559645853937, 0.46188207808882, 0.11440742266131565, 0.6356360670179129, 0.6615352397784591, 0.04084251289896201, 0.13904731924412772, 5.332551207393408, 16.112765595316887, 36.8192832916975, 54.00684781372547, 61.95916369557381, 67.24959701299667, 72.85156801342964, 61.78314954042435, 47.43511565029621, 38.458792716264725, 31.78653884679079, 26.969896405935287, 24.72416941076517, 25.895215272903442, 39.14274461567402, 47.78230682015419, 30.3984809294343, 9.61933583021164, 10.216722674667835, 14.227892886847258, 17.184287197887897, 25.177051909267902, 26.11308418214321, 19.87713050097227, 15.50518674775958, 12.791037037968636, 10.881463754922152, 10.034182369709015, 8.052284717559814, 0.9462546743452549, 0.276125394157134, 0.07345981794060208, 0.07740067405393347, 0.065070729033323, 0.35720262327231467, 0.5925558786839247, 0.6577126448974013, 6.172247249633074, 7.786090476438403, 10.021718088537455, 20.371537171304226, 17.13935650885105, 13.759858701378107, 3.1826524576172233, 4.186328463256359, 16.42335332930088, 11.672423612326384, 5.661863386631012, 8.50066065788269, 12.539436388760805, 15.175674129277468, 12.694285679608583, 4.669708125293255, 2.4350333120673895, 1.681093918159604, 2.507685888558626, 1.2678846158087254, 1.0486705787479877, 0.29495703522115946, 0.1661692396737635, 0.1360374502837658, 0.20013583969557658, 0.4618485626997426, 0.3374602779513225, 0.7470150967128575, 3.154111714102328, 8.004961106926203, 13.635106645524502, 19.869483411312103, 18.009979091584682, 13.794850073754787, 14.179757069796324, 23.259634897112846, 17.967210486531258, 37.09030754864216, 57.30395749211311, 53.741910830140114, 46.027313992381096, 40.128502920269966, 32.38699592649937, 34.25811052322388, 30.382517985999584, 32.5656433403492, 40.55620037019253, 54.06022734940052, 60.57265229523182, 46.8785785138607, 35.77030397951603, 23.97456843405962, 16.356974691152573, 8.018975704908371, 0.7795579161029309, 0.06860794586827978, 0.1640126178972423, 0.5873950431123376, 1.1785788391716778, 1.7761765723116696, 36.865359619259834, 47.54767321050167, 29.993557557463646, 68.12945500016212, 83.6683639883995, 49.7548683732748, 52.89169505238533, 62.90297985076904, 4.105626018717885, 0.6511033745482564, 0.13081195880658925, 0.11369812986231409, 0.14900765352649614, 0.07470215830835514, 0.03467669062956702, 0.028408079051587265, 0.08671079791383818, 0.03327784244902432, 0.037591375439660624, 0.032875969482120126, 0.0670094191445969, 0.014254387751861941, 0.04707116539066192, 0.018645573509274982, 0.02479877926816698, 0.06712906077154912, 0.08926199734560214, 0.04116634161619004, 0.036577494101948105, 0.05554523020691704, 0.01930389003973687, 0.04902233100438025, 0.07970389968249947, 0.1483626529807225, 0.14493635011604056, 0.14209843677235767, 0.2670962770935148, 0.1415396886295639, 0.11236643491429277, 0.18339292873861268, 0.1784270108328201, 0.168263120285701, 0.12448969180695713, 0.10961648091324605, 0.30901589489076287, 0.1617212369455956, 0.1600565403350629, 0.16335115651600063, 0.3541700297500938, 0.25247350393328816, 0.17693329020403326, 0.2361045018187724, 0.14380757318576798, 0.14802944351686165, 0.24073989683529362, 0.1752820413094014, 0.16520821780432016, 0.10082605338538997, 0.2694161713588983, 0.19380425132112578, 0.2360451893764548, 0.16889167483896017, 0.275368700386025, 1.239029795397073, 19.111473485827446, 120.58963000774384, 111.80523857474327, 93.85155156254768, 112.99478754401207, 109.28709089756012, 87.01651632785797, 87.93542861938477, 5.809086486697197, 0.6830744433682412, 0.20731457479996607, 1.4104616339318454, 1.404565537814051, 0.26108559337444603, 1.1241198051720858, 9.805228505283594, 37.25801534950733, 66.21658444404602, 63.44281308352947, 60.178670436143875, 71.08468562364578, 78.3821028470993, 66.80397972464561, 50.535057708621025, 45.67310839891434, 39.05524291098118, 33.72426576912403, 30.965843684971333, 31.584492288529873, 42.077555134892464, 59.336305037140846, 35.90249128639698, 13.408515304327011, 9.431510958820581, 18.389725014567375, 19.0067321062088, 26.248345524072647, 28.867867961525917, 20.99427055567503, 17.231875844299793, 11.830745916813612, 8.81988437846303, 9.19357342645526, 11.163362078368664, 1.399287621024996, 0.2813819964649156, 0.17211464408319443, 0.2669704385334626, 0.13193794526159763, 0.5142914189491421, 0.6896736205089837, 1.606388739310205, 6.791307181119919, 10.331349223852158, 12.917217817157507, 21.884492486715317, 24.530672393739223, 16.165244579315186, 3.6613709572702646, 11.699310969561338, 42.0634350925684, 21.7833761125803, 19.77234162390232, 17.865944020450115, 20.95480017364025, 25.456654205918312, 20.53225714713335, 7.6734089478850365, 3.417049767449498, 4.0078401658684015, 3.3464008709415793, 1.8257460999302566, 1.4631022280082107, 0.6336694944184273, 0.6560695893131196, 0.3656488872366026, 0.3119552449788898, 1.7351859156042337, 2.8481770679354668, 7.453695237636566, 10.6267368234694, 16.542047560214996, 24.315888918936253, 24.583755545318127, 15.484706796705723, 8.227071538567543, 12.780915331095457, 25.681645832955837, 17.546267174184322, 38.08315247297287, 62.16566741466522, 58.052384331822395, 43.8519611209631, 39.03197295963764, 31.31273467093706, 33.900454714894295, 31.76502250134945, 37.846482172608376, 43.13387185335159, 56.55161686241627, 58.87907177209854, 45.76502926647663, 45.5449602752924, 40.072334334254265, 29.005281887948513, 12.133891750127077, 0.6698663521092385, 0.4690763389226049, 0.18481224164133891, 0.531545877456665, 1.2809436838142574, 2.6774239679798484, 70.32578274607658, 53.23355130851269, 49.155241549015045, 103.4203577041626, 90.4171134531498, 51.28995940089226, 79.7201706469059, 75.91658994555473, 1.9896602793596685, 0.8856416924390942, 0.2893683663569391, 0.23025099013466388, 0.23176955786766484, 0.15701230993727222, 0.2003357742796652, 0.18785681342706084, 0.23897596023743972, 0.18529313849285245, 0.30145578493829817, 0.17488803510786965, 0.11068627936765552, 0.16341499605914578, 0.18976947641931474, 0.15717718546511605, 0.17589000868611038, 0.10469942601048388, 0.10275205277139321, 0.08957942874985747, 0.12175211682915688, 0.25114209100138396, 0.1293866048217751, 0.25765102298464626, 0.11741117632482201, 0.2951820840826258], [0.06791199688450433, 0.07272271686815657, 0.05330856038199272, 0.08090741830528714, 0.08255400651250966, 0.0416207623493392, 0.09382820935570635, 0.08356124933925457, 0.015158776332100388, 0.01384638371746405, 0.029516062859329395, 0.048716888995841146, 0.03315887617645785, 0.02497923433111282, 0.015325124095397769, 0.026893184949585702, 0.011956205016758759, 0.06394593001459725, 0.06085897046432365, 0.01778514419129351, 0.016151539857673924, 0.09936112808645703, 0.01801880196580896, 0.04632517709978856, 0.06246376462513581, 0.07611636523506604, 0.051330272981431335, 0.05307659099344164, 0.29678616207093, 0.013712471518374514, 0.45656028552912176, 31.898330748081207, 98.41448351740837, 65.3623066842556, 67.89202854037285, 86.59942030906677, 49.00878220796585, 47.0602847635746, 49.408235773444176, 3.9023428643122315, 0.5004743509925902, 0.15430663246661425, 1.1307934345677495, 0.322213833569549, 0.22724636073689908, 0.3737963625462726, 9.439495280385017, 31.36691976338625, 40.52617438137531, 43.18452313542366, 47.520595863461494, 53.061458542943, 45.69419726729393, 42.02756881713867, 32.15891316533089, 29.068105816841125, 26.445497944951057, 25.644326135516167, 27.39160917699337, 38.48044015467167, 46.486359760165215, 41.99573412537575, 16.787193305790424, 4.001719644293189, 5.330201033502817, 14.76466728374362, 11.866359505802393, 21.531193144619465, 20.239589251577854, 10.064377449452877, 4.348261998966336, 3.192790076136589, 1.8850898905657232, 3.7493027513846755, 0.47331423964351416, 0.04553642625978682, 0.00942486174608348, 0.05648840713547543, 0.17391720204614103, 0.22906955040525645, 0.2214050351176411, 2.695864853449166, 2.9903419269248843, 5.5532989371567965, 8.311493508517742, 14.21377569437027, 9.671798665076494, 7.177138002589345, 3.0201890878379345, 0.24013390357140452, 1.5600180462934077, 3.9458372304216027, 2.0803764928132296, 2.6624437468126416, 3.236749917268753, 4.543382953852415, 2.2280976036563516, 1.0079910303466022, 0.3697538247797638, 0.367196710431017, 0.6705688987858593, 0.2801263419678435, 0.15662477526348084, 0.09622865632991306, 0.020008479477837682, 0.056046599202090874, 0.24518138350686058, 0.6076214765198529, 1.590156841557473, 0.4465787555091083, 1.7926047532819211, 2.412154977209866, 3.8086026068776846, 6.200223723426461, 3.672084719873965, 1.3786698086187243, 12.658730037510395, 13.569213431328535, 3.2713857712224126, 30.712553076446056, 34.089023396372795, 45.199121832847595, 42.77995124459267, 27.034430243074894, 26.724822856485844, 29.01038121432066, 37.93283253908157, 36.2012692540884, 41.12144663929939, 47.27496184408665, 38.286517560482025, 40.049448162317276, 31.829172559082508, 23.95720526576042, 7.880046609789133, 1.138442661613226, 0.351338914479129, 0.3368122346000746, 0.06304055437794887, 1.1641690623946488, 2.0703424187377095, 40.16102537512779, 26.65294401347637, 22.09155287593603, 67.06561848521233, 82.10811451077461, 31.11402813345194, 30.837604366242886, 63.50219249725342, 6.664151754230261, 0.44101692270487547, 0.2105946745723486, 0.24523214640794322, 0.0045896137817180716, 0.19322991807712242, 0.03187443006027024, 0.16099954285891727, 0.04473129622056149, 0.04503360636590514, 0.03251312977226917, 0.0653424218762666, 0.058380720438435674, 0.07419463319820352, 0.06451521665439941, 0.07393954219878651, 0.06614640529733151, 0.15954895585309714, 0.0434832747123437, 0.09666288693551905, 0.11253229007706977, 0.019075117452302948, 0.014186246535246028, 0.05106502569105942, 0.06674668402411044, 0.11942257464397699, 0.02971985661133658, 0.03551574423909187, 0.04306594652007334, 0.004516579956543865, 0.02184541186579736, 0.08703056708327495, 0.060544281295733526, 0.031171734954114072, 0.03694301296491176, 0.04239278146997094, 0.07741679350147024, 0.03268545646278653, 0.03630481049185619, 0.08182422301615588, 0.03638777146989014, 0.050659905828069896, 0.07556804426712915, 0.013150742724974407, 0.04907278220343869, 0.09386605146573856, 0.0950895858113654, 0.027766284583776724, 0.0641859405732248, 0.06066302863473538, 0.037527502499870025, 0.019022660599148367, 0.03697802378155757, 0.04710315195552539, 0.0459699295606697, 0.0948901113588363, 0.10326271716621704, 0.6946575280744582, 69.37441259622574, 104.97458830475807, 76.37540012598038, 100.29537498950958, 95.17541572451591, 75.30921533703804, 75.66082566976547, 49.80694077908993, 2.963163172826171, 0.7201093342155218, 0.2731784444767982, 0.7037630269769579, 0.21761678683105856, 0.1923929387703538, 0.3585412201937288, 6.03500003926456, 15.182115733623505, 30.187561847269535, 47.338357642292976, 56.76372528076172, 64.32339683175087, 58.0145725607872, 57.60020859539509, 43.81696879863739, 38.6285600066185, 39.50719825923443, 37.577650398015976, 35.43646529316902, 49.476442113518715, 58.36200691759586, 52.35919162631035, 26.86033308506012, 9.71300745382905, 13.410370554775, 17.766592651605606, 19.60259523242712, 29.274123162031174, 26.87877919524908, 17.406877353787422, 13.472144789993763, 7.262016423046589, 5.132802100852132, 5.986218256875873, 0.9696876013185829, 0.183299551717937, 0.035271748347440735, 0.016847683655214496, 0.205128044472076, 0.6128150853328407, 0.2981172187719494, 3.0920292204245925, 4.021276719868183, 7.498093005269766, 10.400471314787865, 17.565917819738388, 10.653003863990307, 5.3887848649173975, 1.9266539602540433, 0.06339953863061965, 0.15898381039733067, 4.018132388591766, 2.8539510956034064, 4.558477168902755, 4.839596059173346, 5.350006045773625, 1.1301190895028412, 1.7219335329718888, 0.8711581758689135, 0.12985108536668122, 0.5927846382837743, 0.151455256564077, 0.17837651510490105, 0.0503727429168066, 0.03267343738116324, 0.1881673577008769, 1.1781569430604577, 0.6226779904682189, 2.8597274981439114, 1.4564683777280152, 3.317857990041375, 2.9618767043575644, 7.945501422509551, 9.716033041477203, 13.193532340228558, 14.688215386122465, 25.603989399969578, 21.871029809117317, 18.213935047388077, 50.18136128783226, 60.096572041511536, 68.96205872297287, 58.319285809993744, 45.7208376377821, 40.51745764911175, 40.442457273602486, 47.453898042440414, 50.114462077617645, 51.63110889494419, 60.50012178719044, 45.343115106225014, 36.79635152220726, 23.052891790866852, 18.458058647811413, 6.532856449484825, 1.1495527904480696, 0.7472707517445087, 0.46654439822304994, 0.3650103136897087, 0.8883835421875119, 2.177390274591744, 42.03600436449051, 53.03887635469437, 27.017840333282948, 58.7325744330883, 89.78413581848145, 57.73761302232742, 39.95724990963936, 82.79413729906082, 23.02611082792282, 0.31708027934655547, 0.5022451747208834, 0.19228528282837942, 0.03976093285018578, 0.0801178473921027, 0.09229170391336083, 0.049498259177198634, 0.011462719485280104, 0.053525653420365416, 0.07528626563725993, 0.07314018235774711, 0.07441970432410017, 0.070564803754678, 0.0723583743092604, 0.06546915843500756, 0.03198711034201551, 0.043901604803977534, 0.07661663214094006, 0.08034590195165947, 0.05243650346528739, 0.06548011253471486, 0.028073504036001395, 0.023373744406853803, 0.0596937132650055, 0.059393744595581666, 0.08296114130644128, 0.17381399899022654, 0.1563883715425618, 0.10296059626853094, 0.25065764668397605, 0.15102340083103627, 0.24679387744981796, 0.19128575833747163, 0.1530711495433934, 0.17275208956561983, 0.19418767449678853, 0.17924043437233195, 0.1467407782911323, 0.14551935164490715, 0.17330429196590558, 0.15130179526749998, 0.24026646598940715, 0.10316402636817656, 0.2308325667399913, 0.17760968359652907, 0.26095999230165035, 0.10531084437388927, 0.2480379247572273, 0.20796552737010643, 0.18611618026625365, 0.15351718029705808, 0.1537378059583716, 0.1316368707921356, 0.1865671537234448, 0.27922460285481066, 0.21420801349449903, 0.4281918687047437, 59.9902955442667, 128.73590648174286, 98.09223040938377, 111.19885191321373, 122.59019985795021, 91.05489403009415, 76.52993023395538, 97.01077803969383, 11.74099188297987, 0.6710424483753741, 0.2940899692475796, 1.5748283453285694, 0.5895175854675472, 0.2487320257932879, 1.9335546274669468, 12.883002553135157, 38.74206371605396, 53.62968385219574, 55.427021607756615, 59.1171669960022, 70.94087854027748, 62.987293526530266, 61.75994038581848, 48.70038315653801, 44.71996754407883, 42.67457149922848, 41.77495077252388, 43.052958995103836, 53.02807733416557, 63.37223567068577, 57.38784559071064, 28.69435977190733, 11.806651409715414, 16.621615290641785, 26.179979592561722, 20.92922754585743, 29.53232880681753, 28.44052579253912, 17.750918492674828, 12.457917463034391, 6.041383221745491, 3.658079383894801, 9.783860351890326, 1.0546758002601564, 0.331407351186499, 0.11260371436947025, 0.2640223904745653, 0.2841477730544284, 0.5937291251029819, 0.26861361286137253, 3.1564417015761137, 4.534142324700952, 7.796443970873952, 12.866144757717848, 22.393915951251984, 15.066184904426336, 9.20581541955471, 4.945085048675537, 0.20176662015728652, 3.1385228130966425, 14.597148522734642, 8.75799709931016, 11.387217566370964, 10.212977975606918, 9.958860911428928, 4.570296434685588, 2.494532181881368, 2.096581435762346, 0.6815579091198742, 1.1162948375567794, 0.47382949793245643, 0.39818351331632584, 0.16443996137240902, 0.1707100702333264, 0.19984104379545897, 2.482276177033782, 0.734703519847244, 5.789807271212339, 2.5291328877210617, 2.5591574516147375, 2.19743134919554, 9.065087120980024, 8.270615302026272, 7.263296954333782, 16.54653511941433, 31.22805431485176, 21.838718242943287, 14.612369555979967, 46.95706710219383, 51.05109661817551, 60.99675513803959, 53.5367788374424, 41.7946907132864, 36.68788634240627, 39.10832226276398, 47.8867594152689, 50.799413323402405, 51.98431134223938, 55.728516429662704, 48.25095847249031, 56.76076903939247, 45.54071590304375, 32.362418845295906, 11.36946301907301, 1.1739987786859274, 0.923548280261457, 0.5105555662885308, 0.5001545744016767, 2.1768668526783586, 6.479552434757352, 74.99753326177597, 55.564232245087624, 40.488324612379074, 95.4395167529583, 99.21556413173676, 55.49152314662933, 50.96405848860741, 112.23460793495178, 17.25327629595995, 0.6269460520707071, 0.4878053558059037, 0.44422421779017895, 0.07913565947092138, 0.44834171247202903, 0.18054615415167063, 0.2853806287748739, 0.265422526281327, 0.1618874483392574, 0.24683338939212263, 0.23983138933544978, 0.22585107857594267, 0.14153556228848174, 0.1677980163367465, 0.2645451296120882, 0.11868657195009291, 0.1793156287749298, 0.11238976803724654, 0.19475238950690255, 0.17713292792905122, 0.10695584438508376, 0.14110591815551743, 0.1735401464975439, 0.19925158558180556, 0.2538772317348048, 0.25124839623458683], [0.053163626362220384, 0.09822110761888325, 0.028465942450566217, 0.05890511085453909, 0.09275825505028479, 0.06302879133727401, 0.02101273144944571, 0.09945857949787751, 0.051355932737351395, 0.019328362359374296, 0.030424598189711105, 0.06589869866729714, 0.10070952877867967, 0.05536128148378339, 0.029009684367338195, 0.11303246792522259, 0.05178602958039846, 0.06074176308175083, 0.022245566760830116, 0.008113225194392726, 0.007129365585569758, 0.036057092729606666, 0.08311655445140786, 0.09805917099583894, 0.028278689314902294, 0.17469724378315732, 0.041205619781976566, 0.07024447797448374, 0.05817293764266651, 0.33553983725141734, 0.55277990992181, 3.4960914636030793, 83.93232062458992, 71.59343272447586, 52.42715857923031, 72.58144050836563, 85.3873385488987, 40.09052395820618, 46.367695927619934, 66.3380715250969, 7.830816926434636, 0.2270034558023326, 0.06850115823908709, 0.8205738652031869, 0.2298522787168622, 0.2521379344398156, 0.21141877019545063, 11.133467182517052, 28.433275781571865, 38.63369733095169, 43.80040928721428, 61.738684326410294, 58.43902878463268, 56.991557255387306, 49.67675596475601, 33.68639700114727, 32.91072182357311, 36.130311861634254, 39.68102753162384, 55.420641750097275, 57.37955443561077, 62.08106115460396, 30.968317352235317, 15.795931946486235, 7.133955219760537, 18.49221881479025, 25.603928603231907, 23.574434705078602, 27.045141868293285, 17.29648757725954, 7.258388567715883, 3.6374678649008274, 3.3208047319203615, 1.6956933285109699, 0.7896988594438881, 0.13631392997922376, 0.1503384578973055, 0.08583406175603159, 0.16755975724663585, 0.010550612569204532, 0.5884703260380775, 0.7738767459522933, 1.379684591665864, 2.5774513324722648, 2.9767061211168766, 7.131257364526391, 4.353606412187219, 2.4472672306001186, 0.39337665250059217, 0.032602131832391024, 0.16190279595321044, 0.21430781751405448, 0.2564009197521955, 0.5193014501128346, 1.4094575378112495, 0.9700298798270524, 0.12877274479251355, 0.39452977187465876, 0.10577699475106783, 0.071551355504198, 0.058744502675835975, 0.08620834909379482, 0.16734990756958723, 0.13008211593842134, 0.042242452036589384, 0.17710157961118966, 0.17443217831896618, 0.6880105566233397, 0.04841716894588899, 0.23887136194389313, 0.46113123244140297, 0.07110064179869369, 0.49094882619101554, 2.846258170902729, 4.520634049549699, 13.450678791850805, 25.069375187158585, 11.935246959328651, 3.7292652390897274, 24.48658335953951, 15.926879569888115, 19.058950804173946, 24.969640038907528, 24.821229502558708, 24.402442574501038, 33.82160134613514, 28.846773393452168, 27.34222322702408, 36.94132514297962, 36.40169329941273, 37.49168761074543, 33.55551302433014, 23.733317479491234, 8.282351922243834, 2.1953264996409416, 0.39440132095478475, 0.40447229461278766, 0.5794668279122561, 0.5037690117023885, 10.45186260715127, 43.304570093750954, 26.21298462152481, 22.868664376437664, 66.09079599380493, 87.71797388792038, 41.55898176133633, 36.35719768702984, 60.63255228102207, 10.659805499017239, 0.21804447169415653, 0.37974544800817966, 0.11133913925732486, 0.05642553238430992, 0.09487235176493414, 0.06787169826566242, 0.03396620668354444, 0.08297795837279409, 0.08126125947455876, 0.0515647025895305, 0.034794046441675164, 0.07101939889253117, 0.026745872346509714, 0.014504138998745475, 0.06345168192638084, 0.05351530788175296, 0.02966833857499296, 0.060411481390474364, 0.09110613784287125, 0.20460459287278354, 0.07108214747859165, 0.042393037510919385, 0.06776237249141559, 0.13905729370890185, 0.12033057006192394, 0.07468361203791574, 0.04187399426882621, 0.013869624999642838, 0.06066935915441718, 0.048390644587925635, 0.10596487685688771, 0.019506006537994836, 0.03914121727575548, 0.028105405253882054, 0.04330686620960478, 0.0591078581783222, 0.02095801475661574, 0.048805883634486236, 0.020787563844351098, 0.06542756105773151, 0.0324089693458518, 0.04895319252682384, 0.04322470304032322, 0.055507710931124166, 0.0437986986071337, 0.09368331986479461, 0.018055972432193812, 0.12910723075037822, 0.04476664100366179, 0.16150745388586074, 0.09616204115445726, 0.1819844511919655, 0.14393329300219193, 0.07265527790877968, 0.03796742166741751, 0.15698749251896515, 0.13675356341991574, 0.97988530411385, 10.896787382662296, 109.97795462608337, 80.00327065587044, 74.67765882611275, 102.66314193606377, 88.88922303915024, 65.75949177145958, 80.47838196158409, 60.62620662152767, 5.483293393626809, 0.4107701004249975, 0.3065438603516668, 0.763500037137419, 0.2588809991721064, 0.2201551990583539, 0.41246243461500853, 7.32229876331985, 15.743270572274923, 24.189313910901546, 43.32942456007004, 67.22017899155617, 63.45903441309929, 66.96428552269936, 65.68139836192131, 51.1830635368824, 47.31604903936386, 50.20029567182064, 55.80548509955406, 63.81784915924072, 71.00125730037689, 72.7682612836361, 43.29222075641155, 25.306258276104927, 16.05962924659252, 24.986248947679996, 23.776838444173336, 21.67881142348051, 26.4791052415967, 25.89633621275425, 18.20526011288166, 9.79951361194253, 8.541893195360899, 6.338688293471932, 0.480320529313758, 0.21522917901165783, 0.18422454973915592, 0.04150220054725651, 0.4129304032539949, 0.08986885150079615, 0.23057158308802173, 0.6058712548110634, 0.6853631080593914, 1.3855922059156, 1.8827772396616638, 3.1032250821590424, 1.137669284362346, 1.7780568776652217, 0.3720770141808316, 0.040186194601119496, 0.18236273870570585, 0.33036647422704846, 0.6839391344692558, 0.6687421468086541, 0.9411280369386077, 2.096162033267319, 0.2900037635117769, 0.48315719584934413, 0.1266006418154575, 0.17323637061053887, 0.0623599010577891, 0.07389040460111573, 0.03648864418209996, 0.053223543654894456, 0.08380546045373194, 0.20794439100427553, 1.7196218320168555, 0.9162213234230876, 1.1269417474977672, 0.647070484701544, 1.492773648351431, 1.91137877991423, 2.9798870254307985, 11.424621809273958, 13.237239494919777, 30.835535377264023, 41.539625599980354, 24.46375608444214, 20.55372979491949, 39.71406675875187, 34.654170870780945, 36.32570497691631, 42.35697694122791, 36.853861436247826, 36.34439617395401, 48.34046646952629, 45.813875645399094, 39.33086112141609, 45.37248373031616, 39.73209299147129, 28.892110660672188, 23.66074327379465, 16.905452460050583, 6.923326347023249, 1.4467279566451907, 0.3333990974351764, 0.3671479661716148, 0.3487752692308277, 1.2953512044623494, 3.490548273548484, 50.66439516842365, 55.46902075409889, 29.121779836714268, 50.734345614910126, 85.65708607435226, 75.3399708867073, 42.050663977861404, 65.73671579360962, 44.21539641916752, 0.8534052316099405, 0.7466507912613451, 0.060000064404448494, 0.1321912551065907, 0.06446706611313857, 0.09776470164069906, 0.06873785881907679, 0.1794016733765602, 0.018824102698999923, 0.10982233783579431, 0.07995254884008318, 0.02346109333302593, 0.01059578431522823, 0.03420226901653223, 0.06480506985099055, 0.1283322207746096, 0.0689793610945344, 0.04249367644661106, 0.03585728431062307, 0.12422806990798563, 0.028178979919175617, 0.052695394260808825, 0.11709519210853614, 0.01925861903146142, 0.0537445201916853, 0.09214968653395772, 0.036771458107978106, 0.10087514645420015, 0.12244117868249305, 0.18205686996225268, 0.2512464072788134, 0.14732879673829302, 0.0940570209058933, 0.09478120118728839, 0.14277833310188726, 0.1651388715254143, 0.15726670331787318, 0.1212900185782928, 0.23179560725111514, 0.18954310653498396, 0.18858990690205246, 0.12329970253631473, 0.28887670836411417, 0.10689810529584065, 0.18931776081444696, 0.13597714336356148, 0.10110817340319045, 0.21839194523636252, 0.18411527591524646, 0.1980339438887313, 0.2490943274460733, 0.26960711111314595, 0.15755890170112252, 0.15652327914722264, 0.16903369221836329, 0.2617732674116269, 0.261713390937075, 0.877033076249063, 6.951154628768563, 121.81942641735077, 100.20117804408073, 87.44324862957001, 106.239532828331, 124.76569712162018, 77.88159370422363, 75.20745679736137, 113.3310467004776, 20.144071877002716, 0.4819075675914064, 0.2794376586098224, 0.9461754723452032, 0.2722401620121673, 0.26814968150574714, 0.5698420631233603, 14.850781112909317, 37.047111466526985, 51.99104458093643, 54.092970192432404, 73.44049081206322, 70.16384303569794, 72.15153157711029, 68.69529783725739, 53.550325110554695, 47.8287935256958, 50.579443126916885, 53.95958974957466, 69.96895149350166, 70.6976991891861, 76.90084353089333, 45.67551746964455, 28.94798096269369, 18.54168266057968, 31.217705570161343, 37.05203600227833, 27.50679809600115, 28.056501299142838, 23.5141072422266, 14.09451624378562, 5.478747887536883, 5.855903774499893, 8.240804001688957, 2.632888932712376, 0.4960879613645375, 0.40774204884655774, 0.26868414657656103, 0.45042483194265515, 0.19166262092767283, 1.2276825355365872, 3.066520714201033, 2.459897752851248, 3.0966585595160723, 5.42193666100502, 9.941469244658947, 5.875442801043391, 3.579093497246504, 0.6794815580360591, 0.15338461787905544, 0.2890254941303283, 0.5975066567771137, 1.128753419034183, 2.132142302580178, 2.062238403595984, 4.575617099180818, 0.766881974413991, 1.007811608724296, 0.23049998068017885, 0.3960299491882324, 0.18651858757948503, 0.17683887417661026, 0.20014384004753083, 0.26698575646150857, 0.11792238990892656, 0.42924491688609123, 2.2366226837038994, 1.2239644350484014, 1.617757729254663, 0.7665787031874061, 1.185143580660224, 0.7495167281012982, 1.4021610980853438, 7.0800042897462845, 10.439396426081657, 36.57022945582867, 47.65725553035736, 24.601618386805058, 21.076726131141186, 37.45892196893692, 30.66801566630602, 32.88690470159054, 39.08345639705658, 38.65770824253559, 36.919058337807655, 47.74703711271286, 41.79939106106758, 36.38144038617611, 43.33008952438831, 47.382294684648514, 55.005920603871346, 48.09918701648712, 31.616781055927277, 11.930892392992973, 2.7558284858241677, 0.5188746855128556, 1.1354608903639019, 1.1973028094507754, 1.8731949850916862, 19.127491526305676, 61.96480259299278, 44.7620464861393, 37.6115445792675, 82.10883647203445, 99.818264991045, 69.36090052127838, 52.68760420382023, 95.12843504548073, 37.913282588124275, 0.46754591166973114, 0.9875075169838965, 0.1557390665402636, 0.1939357302035205, 0.1558681853930466, 0.1577697161701508, 0.14090878888964653, 0.2737816917942837, 0.1977435266599059, 0.2086331634200178, 0.19775060674874112, 0.16204453131649643, 0.10433579591335729, 0.0766397723054979, 0.2438269046251662, 0.17773893603589386, 0.15151183790294454, 0.15436408953974023, 0.1291613481589593, 0.33311776409391314, 0.12010068239760585, 0.1298472855705768, 0.21826152020366862, 0.17540500033646822, 0.16801470861537382, 0.17158332571852952, 0.24843771971063688], [0.049760070323827676, 0.06927853566594422, 0.023801128700142726, 0.08163787715602666, 0.04037728278490249, 0.1039523133658804, 0.0483746290410636, 0.0628941880131606, 0.06058942242816556, 0.02924965781858191, 0.08507098551490344, 0.11423051691963337, 0.12786894250893965, 0.03992333702626638, 0.08462298806989565, 0.018428166913508903, 0.054751881762058474, 0.05322899101884104, 0.04206012861686759, 0.13655962538905442, 0.06434012917452492, 0.02993885882460745, 0.09202188128256239, 0.03067393940000329, 0.10331307930755429, 0.027188789790670853, 0.11664155434118584, 0.083938327152282, 0.22438846877776086, 0.06662174346274696, 0.20955755288014188, 1.2568427645601332, 21.106301844120026, 90.00847578048706, 70.31797036528587, 46.901973858475685, 78.79179686307907, 94.419324696064, 46.89871363341808, 44.97854746878147, 70.52713394165039, 16.745374649763107, 0.18738053273409605, 0.34043617139104754, 0.47427063051145524, 0.2566862606909126, 0.4332556016743183, 0.5585967446677387, 9.131546504795551, 22.376117706298828, 31.727398820221424, 33.82232330739498, 34.83164794743061, 39.259466752409935, 53.170786276459694, 45.19018091261387, 39.423253163695335, 40.12629523873329, 49.41504880785942, 54.9511731415987, 48.82780931890011, 46.37723721563816, 37.42146737873554, 19.08222835510969, 10.642217192798853, 22.464069686830044, 30.39696481078863, 39.07876364886761, 46.237894892692566, 22.830238938331604, 8.715355787426233, 8.887645192444324, 6.487949984148145, 2.2989020543172956, 1.753466259688139, 0.4048782493919134, 0.3507802257081494, 0.15616738965036348, 0.23616476421011612, 0.6571708177216351, 0.6844164244830608, 0.7911693805363029, 0.5979263561312109, 0.814823645632714, 1.8407759559340775, 0.6316914630588144, 0.1376934043946676, 0.22234518779441714, 0.06712756905471906, 0.029166444510337897, 0.12158306300989352, 0.20214800984831527, 0.14912010374246165, 0.21718837466323748, 0.47061300021596253, 0.24373484862735495, 0.061424802406691015, 0.05443933368951548, 0.12281168848858215, 0.031821886004763655, 0.054861166718183085, 0.2254802719107829, 0.10818419526913203, 0.04626097019354347, 0.08205218109651469, 0.2633116504875943, 0.15396325557958335, 0.4396826302399859, 0.9428774274419993, 0.9568317630328238, 0.5959757545497268, 0.15650548244593665, 1.7964750831015408, 2.276080478914082, 12.434657961130142, 25.687765404582024, 28.62638521939516, 7.524870168417692, 0.786353851435706, 10.482765398919582, 14.852428324520588, 18.988092206418514, 28.735773749649525, 29.14010815322399, 23.809370398521423, 26.750268191099167, 33.78151349723339, 42.074154317379, 35.71554511785507, 36.43423095345497, 34.407446309924126, 21.51646513491869, 8.090138286352158, 1.9290401134639978, 0.016217941665672697, 0.23008590680547059, 0.2764659211970866, 0.47084710327908397, 17.107347026467323, 28.61867543309927, 16.402279660105705, 30.904326885938644, 66.2300281226635, 87.8329861164093, 50.50578027963638, 38.48519749939442, 69.18377682566643, 33.4453759342432, 0.16402652574470267, 0.7847015338484198, 0.13304718886502087, 0.07265980500960723, 0.0239678762955009, 0.029598788205476012, 0.08955798068200238, 0.04239344569214154, 0.03716632891155314, 0.051358674973016605, 0.11885243453434668, 0.058698140710475855, 0.03510773000016343, 0.07256671000504866, 0.017896030331030488, 0.11139682639623061, 0.043788085895357653, 0.09442547496291809, 0.06436261624912731, 0.0843323853041511, 0.040352350333705544, 0.024445511407975573, 0.05282314756186679, 0.04697831529483665, 0.07837054974515922, 0.06167309533338994, 0.017402765588485636, 0.07147715557948686, 0.050986024070880376, 0.043737078085541725, 0.043206943446421064, 0.0293212342512561, 0.006562114285770804, 0.07769175921566784, 0.057657174693304114, 0.07566847911220975, 0.03896522808645386, 0.03301014978205785, 0.02546551917475881, 0.04509205791691784, 0.041392076964257285, 0.040752327113295905, 0.021596749720629305, 0.05203831897233613, 0.01719592160952743, 0.05221066050580703, 0.051573489618021995, 0.07412501974613406, 0.018317189860681538, 0.08637798920972273, 0.0716567701601889, 0.1054038577422034, 0.0595852224068949, 0.04519552814599592, 0.046253997716121376, 0.043800468629342504, 0.19502898794598877, 0.1452553697163239, 0.2978272765176371, 1.3980796420946717, 52.04540826380253, 96.28330707550049, 71.40047147870064, 70.03446757793427, 100.18889710307121, 80.49068570137024, 63.303512558341026, 81.8367026746273, 70.86810484528542, 5.311336945742369, 0.12911382102174684, 0.2523324958747253, 0.4969009099295363, 0.24298847070895135, 0.054929010148043744, 0.7758779916912317, 6.409785328432918, 13.549017515033484, 17.964419536292553, 28.711574748158455, 38.22358153760433, 46.32062025368214, 61.80859297513962, 58.481563702225685, 59.25367087125778, 52.69936077296734, 67.00451776385307, 70.21916806697845, 56.905495673418045, 63.66422340273857, 58.238061368465424, 31.787916272878647, 22.68225207924843, 29.10573899745941, 33.774666264653206, 29.29076436907053, 27.062556333839893, 23.951344080269337, 17.500563226640224, 11.12476659938693, 11.35882643982768, 8.517181221395731, 1.2602590187452734, 0.6684804358519614, 0.19857780454913154, 0.14181826118147, 0.14715186873218045, 0.7008291687816381, 0.5170623015146703, 1.4086683676578104, 1.5786034427583218, 0.9643433068413287, 0.7680463744327426, 0.3994347742991522, 0.07590164706925862, 0.16629576100967824, 0.07432013037032448, 0.05860876015503891, 0.12456159107387066, 0.19170283048879355, 0.07748977630399168, 0.1989131365553476, 0.3458382049575448, 0.3736773814307526, 0.03201416533556767, 0.04229635793308262, 0.015899419304332696, 0.033766865817597136, 0.08354803911061026, 0.13326207030331716, 0.09021453646710142, 0.04382204657304101, 0.07973119587404653, 0.2354315816774033, 0.08169949025614187, 1.0431898478418589, 2.2246165154501796, 2.6607886981219053, 2.5630643544718623, 0.7387922191992402, 9.923755545169115, 10.49364136531949, 27.078008204698563, 55.698357447981834, 44.99660409986973, 25.363821387290955, 24.259680435061455, 25.40075920522213, 30.55795457214117, 34.96041163802147, 43.45878101885319, 47.87173502147198, 38.99003081023693, 40.412435084581375, 36.29895061254501, 39.46044556796551, 29.67632967978716, 19.161621294915676, 18.37408695369959, 12.768243961036205, 8.18757550790906, 0.1329042957513593, 0.08136324540828355, 0.09584737796103582, 1.093058728147298, 1.0808598389849067, 12.582584973424673, 51.222984194755554, 40.0312889367342, 29.552519023418427, 49.248290956020355, 92.62938514351845, 84.07197073101997, 46.749636232852936, 66.99020773172379, 61.87991514801979, 1.6007653973065317, 0.6650114001240581, 0.044905366958118975, 0.16541039367439225, 0.08501820397214033, 0.08179406955605373, 0.09059714328031987, 0.08628048584796488, 0.044337568324408494, 0.03523132356349379, 0.09274465890484862, 0.014107037113717524, 0.04312969700549729, 0.029989931572345085, 0.10409738097223453, 0.08177588693797588, 0.07339201532886364, 0.08279849222162738, 0.11469385455711745, 0.15513062418904155, 0.11472304322523996, 0.0732679282373283, 0.006323840816548909, 0.10170111228944734, 0.0824311662290711, 0.014432028219744097, 0.01918109799589729, 0.07874556438764557, 0.1160813367459923, 0.13926571846241131, 0.15170239174040034, 0.15075175993843004, 0.08763806690694764, 0.19703775906236842, 0.0957637676037848, 0.14578913716832176, 0.14819218165939674, 0.10015462496085092, 0.13553466007579118, 0.1557192363543436, 0.1974001943017356, 0.13146789860911667, 0.19359362981049344, 0.11776037907111458, 0.1286294509191066, 0.13166131713660434, 0.134537436242681, 0.1670055213617161, 0.16710829397197813, 0.1983142679091543, 0.14809239248279482, 0.1221071751206182, 0.13259965897304937, 0.15080854907864705, 0.1266520726494491, 0.16663716378388926, 0.24363724136492237, 0.2227253603632562, 0.2658757410245016, 1.1751063005067408, 40.97342178225517, 124.41022619605064, 102.24854618310928, 80.29836282134056, 106.92079827189445, 128.90416145324707, 80.60647308826447, 72.54638358950615, 111.65157482028008, 33.26413705945015, 0.5288150708656758, 0.4502448166022077, 0.8077047276310623, 0.3907644411083311, 0.8452299702912569, 0.6572254397906363, 11.849280372262001, 27.021596431732178, 38.63862566649914, 44.402331188321114, 46.58526085317135, 51.60244323313236, 66.40818536281586, 57.61808663606644, 57.80067063868046, 53.97069275379181, 58.901395574212074, 66.91128596663475, 58.63624580204487, 62.71822236478329, 51.98987804353237, 31.90195195376873, 25.69742638617754, 39.438421949744225, 48.71221952140331, 54.08964917063713, 55.13172805309296, 31.078595034778118, 13.937525767832994, 10.29974726960063, 15.409864112734795, 12.27149661630392, 3.7322046188637614, 1.7478661914356053, 0.5120239499956369, 0.2687414700631052, 0.253735362784937, 1.404473155271262, 1.3778163981623948, 1.4827818470075727, 1.9218750041909516, 1.9224292994476855, 2.455707765184343, 1.9884276017546654, 0.7461455371230841, 0.23412454087520018, 0.24336347792996094, 0.20522522128885612, 0.23878732114098966, 0.214603029016871, 0.17375247494783252, 0.8355960028711706, 0.6725323246791959, 0.6029657763428986, 0.1220769845531322, 0.21974793809931725, 0.15838443709071726, 0.14837209309916943, 0.10117651036125608, 0.44776435126550496, 0.33079683082178235, 0.19086245214566588, 0.20323454373283312, 0.4820736008696258, 0.738603298086673, 2.1893976302817464, 2.562392265535891, 3.280159975402057, 1.896304632537067, 0.12832904438255355, 6.303010107949376, 11.796098425984383, 28.2623153552413, 64.3876513838768, 52.42392495274544, 19.608473517000675, 23.22064708918333, 30.212385915219784, 34.80075180530548, 36.43796995282173, 42.81362123787403, 39.89764630794525, 35.173029229044914, 37.39543877542019, 39.64282438158989, 50.805629789829254, 47.17655472457409, 50.0526811927557, 41.93598233163357, 27.831844054162502, 13.480276353657246, 2.382896547205746, 0.1168647181475535, 0.5337296915240586, 2.8347861114889383, 0.9825634479057044, 30.700847804546356, 47.049166560173035, 28.939041942358017, 48.22757072746754, 81.94970861077309, 103.3900049328804, 72.80802235007286, 58.53137522935867, 87.98327565193176, 63.598764315247536, 0.6076359038706869, 0.8924251596909016, 0.2634510851930827, 0.27479567332193255, 0.1823709171731025, 0.2651743224123493, 0.1790301690925844, 0.17755644192220643, 0.1253814564552158, 0.21401171543402597, 0.1434234672342427, 0.10933945944998413, 0.21734137582825497, 0.15767139644594863, 0.23860506451455876, 0.22458139748778194, 0.1946587601560168, 0.2259267627960071, 0.13601583894342184, 0.1299524330534041, 0.1949978622724302, 0.15712180640548468, 0.09531927309581079, 0.24782396358205006, 0.10847479061339982, 0.1272544590756297, 0.06915475285495631, 0.12983254651771858], [0.05350992731109727, 0.04749749583425, 0.0064805851889104815, 0.02437321138131665, 0.04737377239507623, 0.03323520235426258, 0.05031103333749343, 0.1374936182401143, 0.08562742557842284, 0.10485463877557777, 0.051717418027692474, 0.0428925288724713, 0.08077170175965875, 0.03830099849437829, 0.11219999345485121, 0.017269394229515456, 0.04094129275472369, 0.01890464798634639, 0.05089671401947271, 0.042521967116044834, 0.04717557443655096, 0.006688927842333214, 0.0349799247487681, 0.03160138279781677, 0.037283758938428946, 0.057095621232292615, 0.06403151448466815, 0.022308615916699637, 0.013705629844480427, 0.09073108609300107, 0.0672710633079987, 0.2603639883454889, 0.3461687278468162, 51.72421149909496, 93.57260093092918, 64.1950549185276, 44.077976793050766, 83.66103038191795, 96.52210146188736, 49.99451771378517, 42.63122342526913, 76.293955296278, 33.913583010435104, 0.1466575390077196, 0.19596001220634207, 0.595411128597334, 1.2763544800691307, 0.5797635682392865, 0.25068095012102276, 4.220374161377549, 16.981060802936554, 31.46532118320465, 33.72522331774235, 31.48578118532896, 34.13255386054516, 38.17030839622021, 39.561922922730446, 34.29040499031544, 30.91689471155405, 25.63933700323105, 26.74798261374235, 26.462853513658047, 14.26678379997611, 17.451532557606697, 12.185800764709711, 24.793057814240456, 40.45686990022659, 70.0905829668045, 89.16398629546165, 61.75308175384998, 15.456511359661818, 5.912010138854384, 4.354738276451826, 2.1152823697775602, 0.8615394670050591, 0.8041953190695494, 0.7026642328128219, 0.45907456311397254, 0.4361967329168692, 0.20334730565082282, 0.29779842181596905, 0.1264581791474484, 0.03640428425569553, 0.12831868400098756, 0.25079743762034923, 0.1904427824774757, 0.22318402247037739, 0.14868547237711027, 0.20232752052834257, 0.08955026234616525, 0.15800744091393426, 0.09395031491294503, 0.12621790141565725, 0.15484749485040084, 0.06466415085014887, 0.02875963440601481, 0.057445310085313395, 0.07620594988111407, 0.020169061681372114, 0.06767496975953691, 0.11478112370241433, 0.005864371623829356, 0.04066303190484177, 0.04706342479039449, 0.06268932556849904, 0.11102979726274498, 0.1779369410360232, 0.25918587343767285, 0.38248088560067117, 0.1764738414203748, 0.6418060453142971, 1.2477814382873476, 6.779852220788598, 15.247246138751507, 15.889897104352713, 26.413724049925804, 16.143374852836132, 6.036660550162196, 6.830601347610354, 9.318498373031616, 12.245925888419151, 15.874794814735651, 23.695340417325497, 24.775519855320454, 31.66866347193718, 33.051622062921524, 30.70570584386587, 27.735802307724953, 25.654025115072727, 21.410654112696648, 10.87069608271122, 3.855865658260882, 0.5886849551461637, 0.10165764470002614, 0.3502779401605949, 1.3793018809519708, 2.9212200734764338, 23.15303161740303, 19.619181342422962, 17.656527757644653, 45.63694193959236, 75.3893606364727, 98.68499100208282, 48.025725558400154, 33.664183393120766, 69.05927270650864, 61.88925124704838, 0.9838156588375568, 0.2684264729032293, 0.1993030312587507, 0.06823440809966996, 0.026548889654804952, 0.05059941337094642, 0.1180736544483807, 0.1101180020486936, 0.04665531778300647, 0.009765307149791624, 0.027071346776210703, 0.062379137525567785, 0.04745384641864803, 0.055980466422624886, 0.07636182315764017, 0.029767545165668707, 0.02468891914759297, 0.08235891073127277, 0.0434887628944125, 0.08188712745322846, 0.08827739744447172, 0.05705306648451369, 0.03916293993825093, 0.033946736439247616, 0.08089224138529971, 0.03637175221228972, 0.10073834637296386, 0.04812482955458108, 0.021294113030307926, 0.04555438252282329, 0.06176660594064742, 0.03563232450687792, 0.08020556182600558, 0.10365765105234459, 0.05253522394923493, 0.11515479505760595, 0.06179682990477886, 0.08698621633811854, 0.0668397344998084, 0.008862506765581202, 0.052877283524139784, 0.05195211109821685, 0.05949410151515622, 0.030071204164414667, 0.04647512061637826, 0.031222991383401677, 0.011518710816744715, 0.037226873319013976, 0.12238841198268346, 0.14494482544250786, 0.053201371993054636, 0.06948318288777955, 0.03991424571722746, 0.07378144990070723, 0.048649720920366235, 0.07480267478968017, 0.09639777694246732, 0.033070549470721744, 0.06069451424991712, 0.16592265368672088, 0.9428472665604204, 2.113293414004147, 84.81752872467041, 92.56412744522095, 66.17349475622177, 70.42207717895508, 105.61990767717361, 79.7559267282486, 56.23130165040493, 75.13385474681854, 80.69704502820969, 8.893031403422356, 0.1365590316709131, 0.2286785127944313, 0.2736427914351225, 1.1929852911271155, 1.0052087483927608, 0.5564712337218225, 6.84073350392282, 12.166266962885857, 15.642252042889595, 19.48381930589676, 21.385451965034008, 35.14325022697449, 36.66159175336361, 45.94806544482708, 47.982677668333054, 41.76561087369919, 43.7125314027071, 33.99600438773632, 36.31849676370621, 29.09366324543953, 35.1985714584589, 26.64123874157667, 38.97587276995182, 56.78882293403149, 78.78389328718185, 76.03338807821274, 55.211835354566574, 24.596864841878414, 8.110437747091055, 7.987902872264385, 5.063039269298315, 2.9463198641315103, 1.0821131779812276, 0.5568868957925588, 0.5016560282092541, 0.2005214150995016, 0.5415433784946799, 0.27628320443909615, 0.07483554451027885, 0.05726191426219884, 0.20194170763716102, 0.23061829386278987, 0.4519191908184439, 0.12703735119430348, 0.10386450245277956, 0.32139031682163477, 0.5566618766169995, 1.0271060233935714, 0.46084232919383794, 0.3961903421441093, 0.17177113360958174, 0.12315108004258946, 0.0700244534527883, 0.06525737917399965, 0.030146001518005505, 0.03183476597769186, 0.016578044705966022, 0.1224825088866055, 0.06016204926709179, 0.10353541933000088, 0.03167007598676719, 0.050606118675204925, 0.15660031407605857, 0.26046257524285465, 0.6416627811267972, 0.644152300665155, 1.5543311764486134, 1.3656172715127468, 3.596705077216029, 13.8099105656147, 24.023783393204212, 38.41200962662697, 35.923762544989586, 30.46866126358509, 19.374523870646954, 18.428773619234562, 18.449877686798573, 22.07935933023691, 25.305690206587315, 36.501430347561836, 40.535179898142815, 36.19167096912861, 29.62120793759823, 24.9866821244359, 13.59357487410307, 11.735245641320944, 13.39231202378869, 10.335149019956589, 2.4029314471408725, 0.5658252630382776, 0.4607867868617177, 0.9453381516505033, 2.037669396959245, 6.066803382709622, 25.386964045464993, 41.71610713005066, 31.64767909795046, 29.101317934691906, 53.362425193190575, 98.3967536687851, 74.86081659793854, 49.044697880744934, 65.81769704818726, 86.52896448969841, 8.124058116227388, 0.17421557509806007, 0.20721013977890834, 0.1989377461723052, 0.11790765827754512, 0.03543935868947301, 0.14707852969877422, 0.057959009864134714, 0.04501694886130281, 0.03110426816419931, 0.03826584666967392, 0.03417524370888714, 0.09738645123434253, 0.03066093697270844, 0.013222780216892716, 0.12253903827513568, 0.03583953213819768, 0.03444230183959007, 0.04778496302606072, 0.048014616913860664, 0.052403073423192836, 0.07393865162157454, 0.04989898552594241, 0.07266046552103944, 0.030949042411521077, 0.04027550094178878, 0.06756628965376876, 0.13204797607613727, 0.024571240501245484, 0.1311867285403423, 0.1185866937157698, 0.23256430897163227, 0.19297521299449727, 0.14299615344498307, 0.17660051118582487, 0.21564696362474933, 0.13128856604453176, 0.13693825429072604, 0.18832240719348192, 0.06755661946954206, 0.1350556334364228, 0.20129673677729443, 0.15706077218055725, 0.1688495950656943, 0.09299407989601605, 0.09386804784298874, 0.16483184503158554, 0.1738282630685717, 0.22702739748638123, 0.295336302369833, 0.17846569156972691, 0.09944800389348529, 0.09879862467641942, 0.1196151842304971, 0.16308877762639895, 0.11701311799697578, 0.1323099690489471, 0.16742093110224232, 0.21393643197370693, 0.22721115325111896, 0.5697280692402273, 0.542696735356003, 85.75860902667046, 118.96001905202866, 96.2649692595005, 70.6171815097332, 118.2836401462555, 121.3111960887909, 79.68563809990883, 66.27122551202774, 106.14883169531822, 55.72352349758148, 0.31477104232180864, 0.5076433788053691, 0.7058548147324473, 1.7210059077478945, 1.4151644753292203, 0.519633338553831, 8.040047474205494, 22.039227783679962, 39.36888948082924, 41.73674002289772, 44.88118529319763, 51.355935260653496, 55.89317299425602, 49.500624015927315, 49.27501492202282, 40.63946530222893, 37.78538905084133, 34.482659474015236, 40.64460642635822, 26.90237022936344, 33.36666315793991, 29.362971894443035, 42.827163711190224, 62.299287244677544, 96.24870613217354, 108.69211882352829, 81.99910596013069, 27.57431287318468, 12.180810682475567, 8.119238074868917, 5.359393917024136, 2.329681827686727, 2.7697112783789635, 1.2414527591317892, 0.89611915522255, 2.2549935104325414, 1.4048025500960648, 0.4977901215897873, 0.21479301882209256, 0.4375708044972271, 0.43875628150999546, 0.7889852102380246, 0.4694125318201259, 0.6791537662502378, 0.26901870674919337, 1.3502744073048234, 1.5053564356639981, 1.4123941864818335, 0.5489049491006881, 0.7144369510933757, 0.732856165850535, 0.41055487759876996, 0.1202077446214389, 0.16301082243444398, 0.21281066816300154, 0.19182001560693607, 0.18378362496150658, 0.24014689115574583, 0.20293582929298282, 0.156891206279397, 0.15751910774270073, 0.14110640797298402, 0.23675527627347037, 0.39245134277734905, 1.5864659333601594, 1.3052716408856213, 1.7064690752886236, 0.5616141983773559, 2.103138933889568, 11.785046719014645, 40.513167679309845, 55.3917670994997, 49.248857125639915, 28.311577811837196, 17.7572413533926, 22.776462323963642, 18.239771761000156, 24.20404762029648, 27.35455546528101, 34.15279157459736, 38.34561958909035, 45.16774691641331, 44.616609290242195, 46.443399265408516, 39.259493350982666, 35.62152676284313, 30.54391622543335, 20.201294906437397, 7.000252269208431, 0.39250439149327576, 0.6991252570878714, 2.406207346357405, 3.810891746543348, 8.870596457272768, 41.53980799019337, 30.89724786579609, 28.346059061586857, 62.24712364375591, 86.48124665021896, 110.34021958708763, 64.52274173498154, 54.46333631873131, 85.34467443823814, 97.06386879086494, 4.234959203749895, 0.6338805612176657, 0.2450690371915698, 0.26093808410223573, 0.14903414819855243, 0.10679770013666712, 0.1268363924464211, 0.12658830732107162, 0.12291756327613257, 0.10140526996110566, 0.08735652576433495, 0.2611308346968144, 0.22192220814758912, 0.2583518478786573, 0.16441643529105932, 0.25598374370019883, 0.08454616094240919, 0.25184730940964073, 0.12477571552153677, 0.10599904533592053, 0.1902815731591545, 0.2336747251683846, 0.18955645035021007, 0.22369675745721906, 0.16451659554149956, 0.13216758059570566, 0.23163427918916568, 0.2769913914380595, 0.12851318606408313], [0.09214980527758598, 0.04079038444615435, 0.03382477931154426, 0.07484675094019622, 0.08569335055653937, 0.017436273556086235, 0.04950966227625031, 0.04888130439212546, 0.10415064491098747, 0.024602900521131232, 0.08126563814585097, 0.06240814065677114, 0.08674154509208165, 0.019622002364485525, 0.03725350528839044, 0.022910243496880867, 0.016014092252589762, 0.05393435785663314, 0.12554961227579042, 0.043611428773147054, 0.05044899859058205, 0.04968345099769067, 0.02353859024879057, 0.10778986252262257, 0.0750603929918725, 0.029069321499264333, 0.036685550803667866, 0.04877865794696845, 0.03352482177433558, 0.03742345710634254, 0.09704743075417355, 0.06957716846955009, 0.8481460763141513, 2.347963359206915, 61.30977854132652, 90.06203010678291, 54.56337355077267, 60.2424082159996, 100.0195249915123, 98.96630510687828, 63.630937188863754, 37.1633168309927, 59.935795068740845, 54.297232031822205, 6.895558387041092, 0.3083768463693559, 0.23585318092955276, 0.5671136314049363, 0.12430400645826012, 0.17516237741801888, 1.2782730208709836, 6.009297268465161, 20.02440869808197, 28.724765740334988, 27.90805086493492, 32.18132056295872, 31.48759938776493, 25.999266989529133, 34.864424988627434, 31.63368634879589, 20.139738209545612, 20.062708742916584, 29.288642182946205, 19.876870214939117, 21.61164242774248, 24.89864844828844, 40.91260984539986, 68.64488214254379, 64.27144601941109, 29.068943671882153, 12.435233630239964, 8.272496201097965, 4.099647989496589, 4.71468061208725, 1.8382606096565723, 0.4302721383282915, 0.3541199496248737, 0.13866802240954712, 0.573044935008511, 0.11153921484947205, 0.043779250627267174, 0.07483757799491286, 0.01858124971477082, 0.09563220708514564, 0.011241847059864085, 0.010733382205216913, 0.07170215249061584, 0.050773435868904926, 0.049570637129363604, 0.09227533213561401, 0.3032238775631413, 0.06843791983556002, 0.11575171185540967, 0.02241831833089236, 0.09662372380262241, 0.0941983777738642, 0.06192120643390808, 0.021386102234828286, 0.0373920828133123, 0.02778707399556879, 0.05803400017612148, 0.03723976442415733, 0.027042224901379086, 0.05182392735150643, 0.06641625761403702, 0.06037035898771137, 0.312584942439571, 0.1869799807900563, 0.22874190704897046, 0.5133649217896163, 2.078716456890106, 4.082798268646002, 6.1601705476641655, 6.112856911495328, 7.270184084773064, 25.34528788179159, 17.25282222032547, 6.616950687021017, 7.163265896961093, 6.596224224194884, 10.378158912062645, 17.573255226016045, 26.163999550044537, 31.86041448265314, 27.23724626004696, 23.518049530684948, 23.44755571335554, 23.977619670331478, 18.19982450455427, 9.243552144616842, 3.096134662628174, 0.6319839286152273, 0.26422538270708174, 0.8186592429410666, 1.4431921276263893, 7.405917076393962, 16.00345116108656, 15.273224394768476, 23.28799467533827, 50.56784614920616, 78.62138360738754, 106.71621724963188, 43.820874989032745, 34.89273726940155, 62.571584433317184, 79.26459029316902, 6.96060567162931, 0.047283519816119224, 0.1403488829964772, 0.07456027451553382, 0.01548374331832747, 0.10072511387988925, 0.17118537129135802, 0.13142616022378206, 0.07382306954241358, 0.026784853653225582, 0.05699194320186507, 0.13334038172615692, 0.01642074279516237, 0.020340876289992593, 0.04398258795845322, 0.09640155447414145, 0.05105102878587786, 0.04130858163989615, 0.028090731138945557, 0.043843123567057773, 0.004734298254334135, 0.05712267622584477, 0.02453497174428776, 0.05714467348298058, 0.03598734940169379, 0.013708195820072433, 0.07147120355512016, 0.07291811692994088, 0.0371081742196111, 0.023826979559089523, 0.03892825057846494, 0.03656219101685565, 0.04470233390748035, 0.14368881471455097, 0.0867307987937238, 0.06406266984413378, 0.02167635248042643, 0.03430935350479558, 0.08672596741234884, 0.06671175113297068, 0.0372706229245523, 0.033073866870836355, 0.11431700680986978, 0.04894411235000007, 0.043244195549050346, 0.02802036626235349, 0.009321481502411189, 0.048869355814531446, 0.05704986040655058, 0.07528047688538209, 0.03806917753536254, 0.08442674938123673, 0.13763109367573634, 0.09380181858432479, 0.07643341814400628, 0.040540703703300096, 0.06179685587994754, 0.07711925165494904, 0.048348746640840545, 0.014818526669841958, 0.10812005144543946, 0.10530280691455118, 1.3621320272795856, 13.840647116303444, 97.05082029104233, 90.45191198587418, 63.56762118637562, 79.63065505027771, 112.65560254454613, 87.00116515159607, 57.72551827132702, 69.69901397824287, 84.31127429008484, 25.22113524377346, 1.0173874511383474, 0.312291081645526, 0.45235512836370617, 0.4602771095233038, 0.2310517377918586, 0.17454642453230917, 2.1358459163457155, 10.103457402437925, 15.528406351804733, 15.672201085835695, 13.547155614942312, 17.069666348397732, 18.334930054843426, 20.811925940215588, 33.14111106097698, 36.696926057338715, 26.450870856642723, 19.69181064516306, 23.258589953184128, 20.772111676633358, 24.78358492255211, 27.524410150945187, 43.07361848652363, 65.82272797822952, 68.2462303340435, 40.700208842754364, 13.323323875665665, 4.0452691074460745, 3.644872955046594, 6.006019469350576, 3.2271806057542562, 0.8701887528877705, 1.111889686435461, 0.4600558307720348, 0.2629629895091057, 0.09161789319477975, 0.03442911387537606, 0.1277668378315866, 0.07720755238551646, 0.11076237919041887, 0.08687910958542489, 0.07897301038610749, 0.07579652185086161, 0.11744808332878165, 0.03743267458048649, 0.4264900350244716, 1.4858508948236704, 0.1771028115763329, 0.15351735841250047, 0.023956669865583535, 0.09349324842332862, 0.04886483984591905, 0.033060003552236594, 0.013412911030172836, 0.08625471105915494, 0.031801068762433715, 0.034350431378697976, 0.04847783209697809, 0.028248867965885438, 0.03357466070156079, 0.18086777126882225, 0.033901636124937795, 0.5740581743884832, 0.0591049600916449, 0.3361721767578274, 1.6479021054692566, 1.9106052839197218, 5.085938265547156, 6.178823271766305, 13.96092776209116, 18.97122111171484, 35.55222608149052, 23.73454101383686, 14.66125013306737, 9.017957299947739, 6.895520389080048, 16.74918584525585, 23.3921679854393, 26.715127676725388, 26.134750619530678, 19.552985094487667, 16.554041616618633, 13.988662473857403, 15.535035096108913, 13.206529542803764, 7.600498935207725, 1.9003768265247345, 0.7366006867960095, 1.0228428896516562, 2.2515067225322127, 4.743692530319095, 12.317830380052328, 32.36352078616619, 36.11693277955055, 30.26312079280615, 33.43177266418934, 56.445933133363724, 101.29649966955185, 78.35519269108772, 48.33714544773102, 54.822565242648125, 90.24337157607079, 24.130468368530273, 0.2408969501266256, 0.3467297914903611, 0.12346903095021844, 0.07778942584991455, 0.04298747924622148, 0.20675615320215002, 0.23506248195189983, 0.07680039532715455, 0.04159520278335549, 0.07255470947711729, 0.03217110730474815, 0.004427434105309658, 0.03335557870741468, 0.06587581083294936, 0.04454744768736418, 0.052308397644083016, 0.06551537939230911, 0.09155372710665688, 0.055358168174279854, 0.024060535288299434, 0.02418834796117153, 0.05253642251773272, 0.02819247958541382, 0.07944897195557132, 0.025512619577057194, 0.05907345221203286, 0.049695470079313964, 0.10776470371638425, 0.02571054850704968, 0.1467829619650729, 0.13740133959800005, 0.13382065517362207, 0.16752290219301358, 0.3008862608112395, 0.14231086912332103, 0.08787589555140585, 0.13561473781010136, 0.18827627529390156, 0.1480662391986698, 0.11390620580641553, 0.14137809339445084, 0.1702174177626148, 0.15579934377456084, 0.10527713602641597, 0.16954237507889047, 0.11836281002615578, 0.1433371554594487, 0.18308521946892142, 0.17900771170388907, 0.128548052161932, 0.211652620928362, 0.1850940499571152, 0.309903800371103, 0.19092048809397966, 0.17628713190788403, 0.13822804758092389, 0.09494680401985534, 0.17307786270976067, 0.09479305328568444, 0.12665253278100863, 0.1545136619824916, 1.267661852762103, 5.437765186652541, 104.64085221290588, 116.03723868727684, 88.39704304933548, 85.82418590784073, 134.3293735384941, 123.09494197368622, 89.03893500566483, 59.30225506424904, 88.63592863082886, 87.01145499944687, 12.281739916652441, 0.35846569924615324, 0.910325167933479, 1.4246227615512908, 0.490004844032228, 0.3479649033397436, 2.498518880456686, 16.532895751297474, 32.3258002102375, 37.42611072957516, 37.12575204670429, 48.50826546549797, 49.82427164912224, 39.89251658320427, 47.995027005672455, 40.0540117174387, 29.25985112786293, 30.23823782801628, 38.34929399192333, 33.24386514723301, 35.13889566063881, 41.62719950079918, 57.63043977320194, 81.47231742739677, 78.62368628382683, 49.84355941414833, 27.1724958345294, 14.926255512982607, 10.59774437919259, 6.490925224497914, 4.656190825626254, 2.0805667201057076, 2.9197623766958714, 0.7520599197596312, 1.1874555191025138, 0.3440626314841211, 0.19981282734079286, 0.301063159131445, 0.14309637306723744, 0.2496464259456843, 0.11321978599880822, 0.2183824754320085, 0.318693530280143, 0.29249304556287825, 0.11992321262368932, 0.6729241192806512, 1.1827114736661315, 0.11381750431610271, 0.31431301846168935, 0.25588465214241296, 0.21489616250619292, 0.2172221423825249, 0.21650778071489185, 0.128820939862635, 0.10443643855978735, 0.14876909757731482, 0.13874376600142568, 0.248770379985217, 0.13834218989359215, 0.2536314621102065, 0.28357281640637666, 0.1914036410744302, 0.776698807021603, 0.30869617767166346, 0.2847437176387757, 1.6374068311415613, 3.560468084178865, 7.363896556198597, 7.263776678591967, 17.13198110461235, 20.81105388700962, 56.618459075689316, 31.46251503378153, 19.05751258134842, 14.309229422360659, 11.156504396349192, 32.45595462620258, 35.55310383439064, 36.3442175835371, 43.015834987163544, 36.808301880955696, 34.52460162341595, 34.243865087628365, 31.999466121196747, 29.226650409400463, 13.300623893737793, 2.8181365923956037, 0.8934007573407143, 2.230475088581443, 4.348286222666502, 5.886704446747899, 20.493542924523354, 32.537798434495926, 25.405083373188972, 37.29636289179325, 69.23578843474388, 91.77003085613251, 118.51738080382347, 66.41960754990578, 57.77546279132366, 73.16888898611069, 109.24134895205498, 14.25906166434288, 0.5517957033589482, 0.34316760138608515, 0.23137835698435083, 0.16488677880261093, 0.11592273236601613, 0.19085161678958684, 0.26067661063279957, 0.1648615309386514, 0.11761134097469039, 0.14056808373425156, 0.2547147305449471, 0.12919033644720912, 0.23550502461148426, 0.1756905490765348, 0.21142939775018021, 0.0892882322659716, 0.17445383418817073, 0.21034471923485398, 0.13070032495306805, 0.19443191529717296, 0.14003660209709778, 0.1702592897345312, 0.2037330888560973, 0.1555937243392691, 0.13339740835363045, 0.16915956046432257, 0.16846758197061718, 0.12451508810045198, 0.10192847665166482], [0.048108168339240365, 0.006802361867812579, 0.055583417415618896, 0.03132842459308449, 0.06463593439548276, 0.06651785020949319, 0.05042892349592876, 0.08687298686709255, 0.1452571211848408, 0.04106202533876058, 0.0762157907593064, 0.06522295094328001, 0.02188595539337257, 0.024121005480992608, 0.10207450162852183, 0.025822293682722375, 0.040242954055429436, 0.12449955494957976, 0.05061721749370918, 0.0533353890205035, 0.0077347614205791615, 0.05404114548582584, 0.04201872419798747, 0.015401347300212365, 0.017613227537367493, 0.11445737662143074, 0.08873943632352166, 0.06919545965502039, 0.13869810907635838, 0.0360664252366405, 0.0600580261379946, 0.11125961813377216, 0.08613411206169985, 1.8888013414107263, 7.419558819383383, 81.57447874546051, 84.77051764726639, 52.78973892331123, 57.709118351340294, 98.02378088235855, 104.08187180757523, 82.80557468533516, 36.31747081875801, 37.86804601550102, 57.62930363416672, 30.897473953664303, 3.3882299764081836, 0.14917842170689255, 0.360302128829062, 0.777036810759455, 0.1767198633751832, 0.13677073671715334, 1.4054892444983125, 5.204103849828243, 12.387487292289734, 17.948053814470768, 27.422245033085346, 29.627215415239334, 24.812109991908073, 35.77783137559891, 24.306841604411602, 15.692298207432032, 28.324865698814392, 37.13216990232468, 45.178925916552544, 39.512039199471474, 56.708145663142204, 37.62362413108349, 10.042385179549456, 13.22333699092269, 15.36188218742609, 6.190011296421289, 3.296970510855317, 1.5965670975856483, 0.6430964323226362, 0.10483521677087992, 0.6087365979328752, 0.3350354143185541, 0.04683883234974928, 0.10805628611706197, 0.14103438996244222, 0.010147092962142779, 0.06488192666438408, 0.025785869074752554, 0.04099862366274465, 0.06308739131782204, 0.06161426157632377, 0.04590238670061808, 0.0974656458129175, 0.10212179127847776, 0.8061969210393727, 0.45307441789191216, 0.07705279975198209, 0.07981603077496402, 0.01421447968823486, 0.03595985283027403, 0.018509107394493185, 0.10819564660778269, 0.11184923961991444, 0.015636222196917515, 0.11635070666670799, 0.05469520765473135, 0.03415167680941522, 0.10207477622316219, 0.028458537672122475, 0.11069100684835576, 0.2172161903581582, 0.129182840755675, 0.44033010955899954, 1.0154066886752844, 1.732590061146766, 4.081153431907296, 6.014324398711324, 3.6426999466493726, 2.5534311588853598, 16.714835688471794, 2.997920145280659, 5.348294712603092, 6.799001768231392, 4.2411234229803085, 6.876434963196516, 12.309868857264519, 13.85812047868967, 18.832961730659008, 18.479740284383297, 32.65702083706856, 23.91373559832573, 9.694725684821606, 4.882707595825195, 2.015397842042148, 0.6960691523272544, 0.5686143133789301, 1.5784478886052966, 5.557447364553809, 9.005770403891802, 13.680084832012653, 18.62289760261774, 32.732290998101234, 65.5642506480217, 83.60748365521431, 99.1068671643734, 39.96003516018391, 42.419088408350945, 60.99295914173126, 80.9828732907772, 15.616227239370346, 0.09659046816523187, 0.28482585854362696, 0.06398962766979821, 0.040115044903359376, 0.019844624403049238, 0.03258855052990839, 0.061837447647121735, 0.09938331830198877, 0.09119854265009053, 0.019835176863125525, 0.08133435359923169, 0.03841520017886069, 0.04339875893492717, 0.01986896870221244, 0.03742048480489757, 0.013510211229004199, 0.06349819232127629, 0.05765519315900747, 0.040108191169565544, 0.07811154020600952, 0.05171010416233912, 0.030670662818010896, 0.08082489890512079, 0.06666433531790972, 0.0352741900132969, 0.10478640571818687, 0.03409262040804606, 0.049773002247093245, 0.013743604613409843, 0.02560489079769468, 0.14064879971556365, 0.0019931772021664074, 0.03288168030849192, 0.04880513035459444, 0.11861686201882549, 0.064469626522623, 0.15339008008595556, 0.0455087218870176, 0.1147900517389644, 0.09442375318030827, 0.012497997868194943, 0.07672573527088389, 0.03429189448070247, 0.10471726724063046, 0.10987851841491647, 0.029867057892261073, 0.0871858985919971, 0.05886530576390214, 0.0352611764537869, 0.017720434479997493, 0.0023651304854865884, 0.026819018421520013, 0.07527760477387346, 0.10568054523901083, 0.08838027395540848, 0.10118255886482075, 0.14908928977092728, 0.09852755523752421, 0.06956631827051751, 0.06371391980792396, 0.029205574246589094, 0.14189350011292845, 0.16724471555789933, 2.1330898767337203, 28.907190151512623, 107.65328496694565, 81.81561380624771, 75.18456682562828, 88.06513845920563, 114.31789174675941, 92.74669244885445, 62.65663146972656, 58.55167753994465, 76.67515844106674, 53.93606901168823, 6.601664582267404, 1.463433166500181, 0.4825300513766706, 1.3621131470426917, 1.166618624702096, 0.1539381709881127, 0.35139882063958794, 1.6205134126357734, 7.387612033635378, 11.166731547564268, 10.76481856405735, 14.155792705714703, 12.656339015811682, 8.61679857596755, 21.87958884984255, 26.27391055226326, 17.7069890499115, 21.194641403853893, 18.222209103405476, 33.96339073777199, 41.18749849498272, 52.14058555662632, 41.04837276041508, 24.283115677535534, 11.027801502496004, 7.8002651408314705, 3.738341764546931, 4.098578346893191, 3.645546706393361, 1.3182328641414642, 0.2901338768424466, 0.41047226171940565, 0.2677140408195555, 0.5924811295699328, 0.06065350316930562, 0.06243174837436527, 0.07629977219039574, 0.09807964685023762, 0.039833808041294105, 0.032146913290489465, 0.07723860384430736, 0.02521672344300896, 0.12472360191168264, 0.09311521323979832, 0.40033185272477567, 2.5890478352084756, 0.606127978535369, 0.0719999466673471, 0.10552126550464891, 0.07627637227415107, 0.07301107092644088, 0.049831023352453485, 0.03432728750340175, 0.011611981153691886, 0.06160100681881886, 0.03642858217062894, 0.06836274027591571, 0.019797256827587262, 0.05312226276146248, 0.03987841853813734, 0.11396316564059816, 0.3564555774210021, 0.05122519600263331, 0.5663160898257047, 1.3627299014478922, 1.9573552440851927, 5.017885342240334, 6.987661169841886, 5.691713159903884, 7.011185232549906, 18.934224396944046, 12.997108530253172, 5.136102698743343, 5.419563688337803, 10.798222571611404, 16.42149142920971, 21.80493615567684, 17.971504256129265, 13.64889895543456, 12.972930427640676, 21.87539767473936, 17.04075749963522, 7.94265347532928, 4.763382123783231, 1.4272150536999106, 1.323281368240714, 2.4502142099663615, 5.2505948301404715, 12.778143379837275, 22.111372612416744, 25.8541888743639, 28.09659294784069, 31.253832131624222, 42.03698851168156, 57.89212413132191, 97.04352468252182, 82.08086997270584, 49.465012326836586, 52.75828801095486, 94.36345249414444, 36.69930472970009, 0.411668544402346, 0.2803876076359302, 0.08720322031877004, 0.05755082493124064, 0.047408297104993835, 0.03596881426346954, 0.09753630569321103, 0.06428074993891641, 0.09401039918884635, 0.04706847139459569, 0.0728935666847974, 0.052241021767258644, 0.1117293382412754, 0.08015206039999612, 0.10938737250398844, 0.00890245100890752, 0.06569572127773426, 0.023656153862248175, 0.05430254474049434, 0.021239116176730022, 0.03409699536859989, 0.06889791038702242, 0.07412804770865478, 0.057470316751278006, 0.042639571547624655, 0.04675424606830347, 0.017375638235535007, 0.06173074165417347, 0.04049970746564213, 0.007798126916895853, 0.2313756852527149, 0.09030714907567017, 0.19932568160584196, 0.20396195235662162, 0.24210859526647255, 0.20958416629582644, 0.27614822261966765, 0.17513864353531972, 0.39645855431444943, 0.2756883285474032, 0.1336245352285914, 0.14410465490072966, 0.15541875560302287, 0.16001312469597906, 0.22035072528524324, 0.10954927944112569, 0.17588153335964307, 0.24214586592279375, 0.08884816837962717, 0.11316442178213038, 0.12381585140246898, 0.11742636808776297, 0.25098796177189797, 0.12323387403739616, 0.2003882292774506, 0.17906041903188452, 0.2793458994710818, 0.3181111521553248, 0.2851596171967685, 0.19755782646825537, 0.2717228850815445, 0.43960681243333966, 0.1820996473543346, 2.6060958579182625, 16.62347339093685, 119.14563909173012, 106.02486714720726, 85.96230089664459, 81.88448131084442, 134.70199674367905, 125.55032461881638, 105.49258410930634, 59.476046338677406, 57.10403881967068, 84.77174118161201, 50.37283681333065, 6.174198919907212, 0.49462664290331304, 2.4193308921530843, 2.190775293856859, 0.332149617606774, 0.3629707731306553, 3.1601562397554517, 15.841671042144299, 26.413914039731026, 27.721872255206108, 36.33361995220184, 40.61308331787586, 37.220879942178726, 47.15592943131924, 34.50799271464348, 30.07762424647808, 44.14473541080952, 48.75473544001579, 58.459627479314804, 54.20917555689812, 73.58028531074524, 58.31632576882839, 31.098143085837364, 20.417712293565273, 24.030140452086926, 12.389643676578999, 6.526317475363612, 2.9092096304520965, 1.4148967084474862, 0.37130526965484023, 1.3450804422609508, 0.9105164045467973, 0.827832663198933, 0.34483960072975606, 0.39314810070209205, 0.15156006265897304, 0.19855899852700531, 0.17690657288767397, 0.14059981796890497, 0.3098927572136745, 0.13342305697733536, 0.5183428328018636, 0.1989087281981483, 0.500368372304365, 1.9205846171826124, 1.0832958645187318, 0.19046708039240912, 0.15936322597553954, 0.14578371949028224, 0.12552890635561198, 0.12972457887372002, 0.18714829988311976, 0.25204201927408576, 0.2314002058119513, 0.2606613817624748, 0.2348691673250869, 0.1844652133877389, 0.20422265399247408, 0.13689872750546783, 0.22387108794646338, 0.575331759173423, 0.4943091224413365, 1.2396705360151827, 1.7799492948688567, 2.8920169780030847, 7.852115258574486, 15.474616438150406, 14.58251740783453, 21.168563403189182, 36.51053845882416, 27.117856666445732, 16.12310864031315, 8.19623239338398, 26.46221324801445, 28.906386494636536, 26.28765631467104, 22.34052501618862, 27.21790909767151, 27.420512326061726, 41.80265128612518, 35.85676833987236, 16.902213133871555, 6.750011472031474, 2.8028785111382604, 3.2809961680322886, 4.027405790984631, 7.309667766094208, 19.06758204102516, 23.299536556005478, 24.325392208993435, 30.73437910526991, 54.83648769557476, 85.53813725709915, 96.9412113726139, 110.4420693218708, 62.44010388851166, 64.65701133012772, 71.82750776410103, 117.5992588698864, 22.419125698506832, 0.33419512503314763, 0.5224906664807349, 0.14808808802627027, 0.13335770345292985, 0.07592508409288712, 0.10193298890953884, 0.27711826900485903, 0.2089280929067172, 0.23384452855680138, 0.25679773127194494, 0.19055483193369582, 0.08967816407675855, 0.223728506534826, 0.22502591426018625, 0.2521867083851248, 0.13990067032864317, 0.1394587807590142, 0.1258210898959078, 0.18917777691967785, 0.19995996553916484, 0.1409946256899275, 0.17701851844321936, 0.20810001937206835, 0.20133218175033107, 0.12289110571146011, 0.3368211700581014, 0.10288123099599034, 0.18868821178330109, 0.11982337891822681, 0.08708828390808776], [0.018033218184427824, 0.042780471994774416, 0.12338202155660838, 0.036974817703594454, 0.034553379082353786, 0.06935378201887943, 0.09990708160330541, 0.06276671672821976, 0.05014323003706522, 0.060497136364574544, 0.02306507962202886, 0.05749001706135459, 0.0530224216345232, 0.17019454477122054, 0.05743237445130944, 0.03627288700954523, 0.02187669524573721, 0.03715593884408008, 0.06901666143676266, 0.05214800468820613, 0.029264133409014903, 0.08236325971665792, 0.023611699216417037, 0.02456185975461267, 0.053838331368751824, 0.21727538405684754, 0.17310502531472594, 0.02360604405112099, 0.04591546705341898, 0.04343023341789376, 0.12244078534422442, 0.0615957078844076, 0.11048340587876737, 0.1036646866123192, 2.4052687967196107, 16.22288178652525, 85.11669427156448, 79.15894836187363, 63.93456369638443, 67.81664058566093, 94.99965235590935, 104.81337815523148, 94.26140516996384, 47.2150656580925, 31.955464482307434, 37.67176374793053, 36.19949094951153, 16.092132702469826, 3.110292940400541, 0.11920306220417842, 0.3812381741590798, 1.1433778842911124, 0.7036271248944104, 1.487942801322788, 4.188223611563444, 9.242377057671547, 11.27742625772953, 22.419110499322414, 26.754242777824402, 30.55461835116148, 26.76735207438469, 14.387880451977253, 23.531364016234875, 19.919887706637383, 26.14885926246643, 4.190761400386691, 4.553872290998697, 3.287240657955408, 3.825412429869175, 3.843071269802749, 3.7216107873246074, 1.2394222430884838, 0.9280990704428405, 0.5881333316210657, 0.019860641805280466, 0.2798431977862492, 0.2568717679241672, 0.2655844035325572, 0.018659683591977227, 0.135850963415578, 0.05629493294691201, 0.05848337801580783, 0.032099211748573, 0.07278901292011142, 0.03819488250883296, 0.09026569270645268, 0.0782712503860239, 0.026852656264964025, 0.0692381257249508, 0.12270755774807185, 2.529241181910038, 0.4201392695540562, 0.04736126349598635, 0.14502086589345708, 0.016752826049923897, 0.04717452058685012, 0.04303261295717675, 0.018228356639156118, 0.03530794660036918, 0.06536639324622229, 0.02837492174876388, 0.04301264176319819, 0.0701913476223126, 0.018304554796486627, 0.018649605226528365, 0.09427992496057414, 0.1780162172508426, 0.06927438706043176, 0.039372563260258175, 0.866732185240835, 3.3946782303974032, 9.407652039080858, 3.8744283746927977, 3.71039355173707, 1.9100241526030004, 6.206902340054512, 3.7744414899498224, 2.3911181185394526, 4.003350231796503, 0.7840771798510104, 3.817660608328879, 8.409057073295116, 12.226001657545567, 17.57152821868658, 17.05341462045908, 8.138478342443705, 4.799247924238443, 1.7481543822214007, 0.5928929918445647, 2.3909815633669496, 2.3836263455450535, 4.037064872682095, 10.34837231040001, 9.55926675349474, 12.885618712753057, 32.373206466436386, 48.69740031659603, 69.50267091393471, 95.6439533829689, 87.60147973895073, 36.86414748430252, 39.11953546106815, 62.650931775569916, 78.49925816059113, 11.152888890355825, 0.09133134997682646, 0.20302390737924725, 0.08433299386524595, 0.2596929087303579, 0.08273160245153122, 0.07937811911688186, 0.0550503253180068, 0.1488283506478183, 0.1254647847963497, 0.06709154520649463, 0.030462811373581644, 0.03452367091085762, 0.0654301956819836, 0.038398973119910806, 0.13776315143331885, 0.08285577117931098, 0.037624738688464276, 0.10179027391131967, 0.02539485001761932, 0.007701872218603967, 0.0808456345112063, 0.08210163781768642, 0.07068674603942782, 0.11791187367634848, 0.029297598703124095, 0.11378159921150655, 0.02775392225885298, 0.07108071513357572, 0.025551320723025128, 0.05223570427915547, 0.06470109496149234, 0.019732526707230136, 0.04027038754429668, 0.059562713067862205, 0.005851539890500135, 0.023466284656024072, 0.12956780759850517, 0.040035252895904705, 0.05006467741623055, 0.05256710290268529, 0.026029928048956208, 0.03112257138127461, 0.016338872774213087, 0.036357710778247565, 0.046102666383376345, 0.12465332052670419, 0.06152378635306377, 0.0968879357969854, 0.06462395613198169, 0.08764381855144165, 0.06254688516492024, 0.013156833902030485, 0.06986950043938123, 0.06971741211600602, 0.055225739342859015, 0.07737696243566461, 0.11817318387329578, 0.10016262531280518, 0.07221076855785213, 0.08729656023206189, 0.026760898981592618, 0.09783798872376792, 0.091933484072797, 0.16900986927794293, 0.4165162827121094, 4.64297323487699, 51.69721394777298, 104.48226392269135, 75.58090835809708, 74.76123914122581, 94.35300305485725, 114.28988724946976, 107.07781344652176, 66.32233276963234, 47.436061799526215, 67.29248151183128, 68.33766102790833, 41.59157641232014, 11.635301504284143, 2.110108472406864, 1.70868210028857, 3.173932400532067, 2.3138274159282446, 0.5571246799081564, 0.8611828205175698, 4.712692368775606, 9.204707778990269, 10.12450447306037, 12.779450509697199, 14.27563352510333, 16.553496345877647, 17.250099666416645, 16.147795915603638, 22.05067276954651, 29.610897190868855, 33.49508486688137, 16.022653430700302, 20.320794694125652, 9.589881710708141, 9.279646407812834, 9.548980705440044, 6.340715009719133, 1.9641599664464593, 0.7740036235190928, 1.7739867023192346, 0.6415564462076873, 0.2796886826399714, 0.1904910517623648, 0.10700612489017658, 0.20589273859513924, 0.033883998985402286, 0.12027642296743579, 0.08566266275011003, 0.05721740766603034, 0.04240211026626639, 0.09073140521650203, 0.048957983090076596, 0.005467683486131136, 0.11694829139742069, 0.12255952155101113, 0.29911947436630726, 2.5632826052606106, 0.33101166773121804, 0.08445822386420332, 0.06906044814968482, 0.07369623650447465, 0.03772307696635835, 0.05444728580187075, 0.023390459427901078, 0.037860860393266194, 0.06317728766589426, 0.06947625122847967, 0.06753187626600266, 0.039627739606658, 0.032561499247094616, 0.058281409947085194, 0.012374074049148476, 0.23994076706003398, 0.04101790094864555, 0.39977114531211555, 1.848472086712718, 3.6211719643324614, 6.711458265781403, 6.70963816344738, 2.261349381878972, 4.150924813002348, 14.75901983678341, 7.597507545724511, 2.608021879568696, 3.51644198410213, 7.086823498830199, 8.545538149774075, 14.574239552021027, 16.098484061658382, 18.370841927826405, 13.775131031870842, 8.605378288775682, 5.859582927078009, 2.4140218645334244, 2.314329701475799, 6.401126068085432, 7.290949495509267, 13.392257876694202, 21.594030372798443, 25.036765336990356, 21.19712457060814, 34.096011221408844, 40.06800636649132, 50.86260013282299, 72.32952922582626, 100.70413425564766, 71.69664278626442, 42.450345531105995, 60.01564018428326, 91.90037906169891, 34.731622114777565, 0.587322668870911, 0.48890604986809194, 0.12183762708446011, 0.22193115844856948, 0.06078742371755652, 0.1410523647791706, 0.05165514441614505, 0.07845275744330138, 0.16585065051913261, 0.2461679797852412, 0.09457748907152563, 0.06449790977058001, 0.027115172451885883, 0.03204488653864246, 0.02841693101800047, 0.11404311720980331, 0.1333039571181871, 0.05169961390492972, 0.037821682417416014, 0.04185108788078651, 0.09047969098901376, 0.024267238259199075, 0.05364429685869254, 0.03692017708090134, 0.032117179143824615, 0.10806203776155598, 0.05122788257722277, 0.07643583012395538, 0.0563556220731698, 0.028737557368003763, 0.04514147753070574, 0.14203925791662186, 0.19121328019537032, 0.18961142865009606, 0.22964835137827322, 0.11780276312492788, 0.21966879547107965, 0.2150001670815982, 0.26427249424159527, 0.2529970445903018, 0.11370938082109205, 0.13220391614595428, 0.09164818766294047, 0.18008744751568884, 0.3333438222762197, 0.27396523975767195, 0.18538161733886227, 0.13002102234167978, 0.1223758771084249, 0.13872411393094808, 0.131046878232155, 0.12928322365041822, 0.2098319842480123, 0.15036792116006836, 0.1154654951824341, 0.22681202623061836, 0.2189543002168648, 0.23982577869901434, 0.1789302908582613, 0.19920160935726017, 0.21135035902261734, 0.16231980873271823, 0.17970877408515662, 0.6345615559257567, 0.26925120677333325, 3.116490407846868, 34.37585860490799, 130.21360158920288, 95.8904841542244, 95.53929179906845, 95.48644423484802, 130.38406044244766, 131.05723232030869, 111.63801714777946, 67.38237708806992, 51.93438962101936, 59.798223450779915, 65.45242264866829, 38.046875819563866, 7.284439969807863, 3.4257900109514594, 4.2026276886463165, 2.4080340983346105, 0.6260875950101763, 1.1411590408533812, 6.456389352679253, 15.622689742594957, 23.375469781458378, 33.97688001394272, 35.05108617246151, 39.28851239383221, 36.930875703692436, 22.741299010813236, 31.230640076100826, 33.37108612060547, 36.53999827802181, 10.840811636298895, 9.877051301300526, 3.9426670130342245, 7.559260223060846, 17.5125477835536, 12.3327911272645, 1.9875644543208182, 1.1634709686040878, 1.4187582512386143, 1.324690142646432, 0.8254213363397866, 0.5964890832547098, 0.7844930200371891, 0.261968481936492, 0.26225836481899023, 0.1551850384566933, 0.26190400414634496, 0.19150935258949175, 0.20344587770523503, 0.19566502334782854, 0.18313452776055783, 0.16930917743593454, 0.15584350156132132, 0.2593159570824355, 0.2594106551259756, 5.027663642540574, 0.8929313044063747, 0.17712261207634583, 0.30117554997559637, 0.12517227471107617, 0.19071982620516792, 0.17246238479856402, 0.06980131191085093, 0.10343277288484387, 0.13840015162713826, 0.16240162309259176, 0.11052507004933432, 0.09493214660324156, 0.2172195300227031, 0.13764561008429155, 0.15821654844330624, 0.3729954664595425, 0.15781425987370312, 1.121258558705449, 1.7927625635638833, 5.369221139699221, 12.514514476060867, 11.645398512482643, 16.371913589537144, 18.379100784659386, 23.02864909172058, 11.509302165359259, 2.2665964253246784, 7.860688548535109, 16.526456996798515, 20.888020657002926, 29.457280933856964, 31.219592168927193, 38.10701139271259, 30.124895609915257, 19.39822319895029, 8.63730987533927, 4.330591997131705, 3.60481692943722, 8.275024015456438, 9.691164325922728, 17.952011302113533, 24.900103770196438, 19.22629952430725, 22.268820963799953, 53.94896171987057, 72.53652691841125, 88.9482794702053, 105.39467856287956, 95.10720178484917, 56.70818746089935, 60.08939802646637, 80.30814349651337, 115.96436619758606, 23.137591145932674, 0.4928819427732378, 0.5021097476128489, 0.26940254552755505, 0.31407312664669007, 0.13242117245681584, 0.23937090154504403, 0.1827604853315279, 0.1686987461289391, 0.3240309376269579, 0.2600056497612968, 0.16255530703347176, 0.09340620192233473, 0.12579273985465989, 0.15778300061356276, 0.22249179164646193, 0.17182624549604952, 0.1526098305475898, 0.23624712775927037, 0.07945184406707995, 0.12394866615068167, 0.1836500977515243, 0.17723881755955517, 0.12985737877897918, 0.26671329920645803, 0.09542741143377498, 0.20912554871756583, 0.13513511745259166, 0.25887660565786064, 0.13513137702830136, 0.2145621069939807, 0.11621930942055769], [0.027989533737127203, 0.04377457138616592, 0.09142302005784586, 0.05659450085659046, 0.019479567527014297, 0.10722387843998149, 0.060395900000003166, 0.08641665510367602, 0.09613349815481342, 0.026584612933220342, 0.018366049152973574, 0.01833159494708525, 0.03209844733646605, 0.0771082159189973, 0.05738486957852729, 0.04521380724327173, 0.014793982918490656, 0.07652651314856485, 0.03253216957091354, 0.014481697380688274, 0.009616295028536115, 0.037356378088588826, 0.05228243360761553, 0.02193579432059778, 0.08209494364564307, 0.08975401156931184, 0.07234149787109345, 0.404010945931077, 0.07174428421421908, 0.1668613962829113, 0.05216613906668499, 0.17254204693017527, 0.08989444075268693, 0.05110868994961493, 0.07032327921479009, 1.134771821089089, 16.86431396752596, 95.85348933935165, 85.37410765886307, 81.96258991956711, 74.52984675765038, 85.48263743519783, 101.65457725524902, 92.03890442848206, 65.0234104692936, 38.61066676676273, 26.238492652773857, 26.263622604310513, 27.92100816965103, 12.712266314774752, 5.804172875359654, 0.46634606667794287, 1.27216556109488, 1.0293246293440461, 0.7687530771363527, 1.5167133137583733, 3.596259313635528, 7.2550594713538885, 14.125225245952606, 23.82060069590807, 29.91201013326645, 18.32043193280697, 14.017846807837486, 3.562473664060235, 17.38405767828226, 10.35132760182023, 4.596602898091078, 1.5223158756271005, 1.5905220969580114, 1.1747301206924021, 2.229797774925828, 3.599709291011095, 0.44922798522748053, 0.06725663595716469, 0.0665349789778702, 0.05364180324249901, 0.04594675971020479, 0.08565081065171398, 0.05729258351493627, 0.0534060340578435, 0.030268205409811344, 0.02699851982470136, 0.028580212783708703, 0.019064950029132888, 0.05835901632963214, 0.05853068993019406, 0.10247898695524782, 0.015649543747713324, 0.13238547515356913, 0.4106877220328897, 3.0586456367745996, 0.3819398005725816, 0.08591862948378548, 0.11028524502762593, 0.04361564788268879, 0.045271935960045084, 0.047338101066998206, 0.1845834671985358, 0.039627427904633805, 0.030374827911145985, 0.06212797619809862, 0.06096544268075377, 0.03561825709766708, 0.04185191537544597, 0.03806475804594811, 0.013619780056615127, 0.04151749250013381, 0.057227742072427645, 0.48725055588874966, 0.29517846240196377, 3.1087153125554323, 3.252529283054173, 6.4199987053871155, 5.394683573395014, 3.0538913793861866, 4.210088588297367, 1.7697498109191656, 4.251594711095095, 7.081809667870402, 9.386111944913864, 9.9500035867095, 7.843226110562682, 6.232005693018436, 6.898196395486593, 2.9182426957413554, 0.41456277191173285, 2.9757469100877643, 1.8446966330520809, 2.973114838823676, 3.6828965647146106, 6.816697418689728, 11.654715612530708, 13.272399008274078, 23.968374766409397, 45.77660344541073, 52.92020872235298, 72.76883125305176, 97.14937180280685, 59.61882747709751, 19.685753770172596, 47.092993408441544, 67.81990081071854, 78.2977169752121, 12.367582060396671, 0.10199783035204746, 0.28190779325086623, 0.19664010149426758, 0.13212575315264985, 0.11845354500110261, 0.1206120740971528, 0.09870639798464254, 0.12428138579707593, 0.034000178493442945, 0.0751645682612434, 0.03112808924925048, 0.13484811410307884, 0.04966959881130606, 0.03296281189250294, 0.07046589773381129, 0.019624987653514836, 0.06594410326215439, 0.04770216532051563, 0.09415230524609797, 0.08357299753697589, 0.026353452485636808, 0.05256891003227793, 0.014840242838545237, 0.08278802793938667, 0.008433240200247383, 0.058581846169545315, 0.06514930020784959, 0.07235249649966136, 0.008390306029468775, 0.026216448313789442, 0.031415619523613714, 0.03873549998388626, 0.03952451057557482, 0.03200212027877569, 0.08180094184353948, 0.04173509019892663, 0.058794467768166214, 0.07812883966835216, 0.016730023562558927, 0.04585071095789317, 0.07168230004026555, 0.010161676163988886, 0.04246151547704358, 0.025698711251607165, 0.03068137200898491, 0.09490361844655126, 0.06515245433547534, 0.01923075324157253, 0.008994398467621068, 0.0572721484786598, 0.09409746053279378, 0.07571041787741706, 0.06025997194228694, 0.06631987489527091, 0.025390963019162882, 0.04044412802613806, 0.03162552857247647, 0.14231325883883983, 0.06574335973709822, 0.13557023863540962, 0.14300393115263432, 0.1272478688042611, 0.05282232006720733, 0.18067141383653507, 0.08841930350172333, 0.273755686939694, 0.4984627745579928, 4.178427737206221, 56.35174758732319, 108.7200017273426, 82.65102937817574, 86.48587480187416, 93.19816902279854, 109.10181283950806, 112.98365414142609, 75.25674015283585, 50.41957810521126, 50.951853543519974, 51.384935304522514, 55.450356155633926, 36.575191989541054, 14.505676031112671, 5.2272493578493595, 2.5176054937765002, 4.526678575202823, 5.62204104848206, 2.1616196958348155, 1.475241151638329, 4.359829528257251, 8.462939132004976, 11.734102852642536, 14.89456806331873, 18.447417318820953, 16.65493570268154, 18.81393425166607, 10.946518164128065, 22.30093114078045, 15.534754861146212, 9.449902921915054, 4.047562759369612, 2.6273618917912245, 4.879962718114257, 7.648271871730685, 4.500277591869235, 1.0890438873320818, 0.06687325731036253, 0.04248311568517238, 0.07572728689410724, 0.03433969621255528, 0.10277865134412423, 0.05578297350439243, 0.16952548379777, 0.13612211449071765, 0.09810935502173379, 0.028716962769976817, 0.06486718019004911, 0.04585322312777862, 0.0645340300980024, 0.018367186494288035, 0.056070333084790036, 0.1486595268943347, 0.26671971136238426, 3.4029857721179724, 0.07642014112207107, 0.12351378245512024, 0.06607145580346696, 0.034832066667149775, 0.08905904222046956, 0.03388866338355001, 0.08479216063278727, 0.03172027485561557, 0.06868861732073128, 0.02694241346034687, 0.05069662358437199, 0.039840290701249614, 0.047443653020309284, 0.05095890228403732, 0.04572571844619233, 0.054976266401354223, 0.21944763546343893, 0.1506610694923438, 0.49295167496893555, 4.284538943320513, 5.364583488553762, 6.161908004432917, 10.650785733014345, 8.143717311322689, 3.369559678249061, 2.326879478059709, 3.783792075701058, 2.737155337817967, 5.686484640464187, 8.889033067971468, 4.474868830293417, 5.031083459034562, 11.111177578568459, 7.7041226997971535, 2.605735589750111, 6.540714427828789, 7.712040049955249, 12.322497479617596, 17.861097380518913, 23.340711146593094, 26.855870224535465, 28.612795248627663, 29.478309005498886, 47.28875130414963, 54.88636761903763, 61.414698511362076, 83.98265272378922, 85.63155144453049, 52.93050616979599, 45.26676580309868, 60.04453383386135, 87.92230412364006, 35.64136169850826, 0.3245580109069124, 0.27179288445040584, 0.39061755524016917, 0.2989222708856687, 0.16814051748951897, 0.19090677320491523, 0.1140114052395802, 0.15628024062607437, 0.05245424821623601, 0.07332660985412076, 0.02140155189408688, 0.10798990100738592, 0.03971951358835213, 0.09767709110747091, 0.04116644922760315, 0.012113220273022307, 0.02285221497004386, 0.04706287931185216, 0.04438020841917023, 0.055392941503669135, 0.03705695860844571, 0.08259892871137708, 0.024856416312104557, 0.027711938964785077, 0.042741167853819206, 0.043331765264156274, 0.02580797765403986, 0.06371427603880875, 0.029351217017392628, 0.05082527859485708, 0.03970752048189752, 0.006213674096215982, 0.08767959006945603, 0.20311407832195982, 0.2722379652550444, 0.1831606068299152, 0.2599974861368537, 0.19036683108424768, 0.1213026573532261, 0.1612720446428284, 0.21437860355945304, 0.21370978007325903, 0.08927708520786837, 0.20761205727467313, 0.16828554798848927, 0.3039071284001693, 0.10314176935935393, 0.23340826446656138, 0.0889400536834728, 0.2431837742915377, 0.15130463027162477, 0.13782097958028316, 0.14059993671253324, 0.2592342911520973, 0.15007346664788201, 0.17537852050736547, 0.11529606286785565, 0.24249673850135878, 0.16177121317014098, 0.4673978977371007, 0.2523122797720134, 0.3243125381413847, 0.16101493500173092, 0.29505707672797143, 0.14217493735486642, 0.5245226074475795, 0.2597154403338209, 1.3512566545978189, 39.67128865420818, 132.16776072978973, 99.50792044401169, 110.30196323990822, 99.58786815404892, 117.41392761468887, 132.82257199287415, 111.13503813743591, 87.6716011762619, 54.38178509473801, 41.71755485236645, 52.751923352479935, 57.74112403392792, 32.070313319563866, 14.874118510633707, 5.307939453050494, 6.857349062338471, 5.319799091666937, 1.8701226124539971, 2.4504968198016286, 5.329265808686614, 11.73790929839015, 23.796622082591057, 36.31104156374931, 41.69685736298561, 31.553630344569683, 30.91365348547697, 11.859624367207289, 24.835022762417793, 12.913022842258215, 5.095938853919506, 1.3863842259161174, 0.8929198456462473, 1.8647937546484172, 5.964588392525911, 4.501364333555102, 0.9749846952036023, 0.12548360566142946, 0.1367193800979294, 0.13889733119867742, 0.2317014435539022, 0.35650702309794724, 0.11354670947184786, 0.29211262066382915, 0.14864480268443003, 0.18108814459992573, 0.2124578511575237, 0.20220086560584605, 0.18668003438506275, 0.1494136973633431, 0.1779732172144577, 0.1017408246116247, 0.3813462902326137, 0.754497132729739, 6.534024886786938, 0.7332204119302332, 0.23347223759628832, 0.22090746962931007, 0.09958890805137344, 0.23972928465809673, 0.1225224364316091, 0.23850874858908355, 0.11914782415260561, 0.177564813347999, 0.11927651998121291, 0.18876106099924073, 0.16530834836885333, 0.17869577219244093, 0.1808764395536855, 0.1485357218189165, 0.18798029195750132, 0.9908909979276359, 0.9509022405836731, 0.49874235643073916, 5.249098185449839, 4.22410081140697, 8.692830596119165, 17.667737156152725, 12.938297186046839, 4.478580756112933, 3.114626845344901, 18.037364222109318, 22.520205974578857, 28.387670628726482, 37.82999485731125, 28.106552213430405, 20.052196606993675, 25.103717744350433, 14.7604276612401, 4.6528892777860165, 8.050766699016094, 9.00892423465848, 15.01550892367959, 18.497435934841633, 22.454235814511776, 23.512988202273846, 22.976825572550297, 41.31977699697018, 73.48096624016762, 74.45768862962723, 89.383295327425, 104.02595400810242, 72.15855360031128, 42.94854819774628, 67.19246327877045, 79.79935839772224, 109.1932587325573, 24.302627630531788, 0.24596803035819903, 0.6205311650410295, 0.38610695977695286, 0.4016590799437836, 0.40656049037352204, 0.37363626644946635, 0.1438926678383723, 0.3081848379224539, 0.1435602450510487, 0.1322095564682968, 0.14261924632592127, 0.2360889909323305, 0.09533553355140612, 0.16472156188683584, 0.13311445713043213, 0.11648406318272464, 0.11893868693732657, 0.1665036811027676, 0.2518005244201049, 0.22138725325930864, 0.12377758626826108, 0.20964013907359913, 0.132265989377629, 0.28685560275334865, 0.15690455009462312, 0.21083076659124345, 0.13768391974736005, 0.15829624026082456, 0.09953419692465104, 0.13329022738616914, 0.131400897516869, 0.10122814157512039], [0.014885922028042842, 0.06646033376455307, 0.03979817010986153, 0.06745939812390134, 0.06418191813281737, 0.029523256125685293, 0.06418105724151246, 0.028919680407852866, 0.04334905730502214, 0.05881581935682334, 0.05592429697571788, 0.03402316651772708, 0.05784808105090633, 0.049695963607518934, 0.03609657127526589, 0.0403844519314589, 0.02790661914332304, 0.09106341982260346, 0.023604854759469163, 0.07062574892188422, 0.04894989739113953, 0.017217788990819827, 0.043029195367125794, 0.047506345945294015, 0.015392343193525448, 0.0805979353026487, 0.1384976995177567, 0.07403910873108543, 0.24482518230797723, 0.03954824816901237, 0.08681324397912249, 0.03967276570620015, 0.16145715111633763, 0.20800061611225829, 0.1444782965700142, 0.04279614244296681, 1.7700047534890473, 20.34901387989521, 104.43674236536026, 83.7553945183754, 80.78477472066879, 65.80707281827927, 82.01310440897942, 96.36916726827621, 90.24918526411057, 99.05047059059143, 66.46997764706612, 24.215236119925976, 15.166962146759033, 20.5112461745739, 20.26393834501505, 10.31611679121852, 2.7217552391812205, 3.1367029482498765, 2.3252467531710863, 2.246725154109299, 2.405450949445367, 2.2159810038283467, 1.626254073344171, 3.5006925417110324, 6.080664088949561, 9.660760257393122, 23.558961935341358, 14.366866629570723, 19.872606843709946, 21.550805792212486, 3.9295976143330336, 3.897407641634345, 3.0393490847200155, 3.8527804613113403, 4.172621173784137, 2.666762452572584, 1.7591923149302602, 0.3858021448832005, 0.22458982828538865, 0.23790645122062415, 0.10220545358606614, 0.0634122293558903, 0.12106366353691556, 0.03720067550602835, 0.04927919573674444, 0.022442670051532332, 0.014420338466152316, 0.11576012038858607, 0.09543748979922384, 0.036812298494623974, 0.08472377914586104, 0.1596822901046835, 0.1562549630762078, 0.3475611750036478, 1.3343505305238068, 0.15676373499445617, 0.10822349941008724, 0.0686792959459126, 0.005897192640986759, 0.017284344794461504, 0.01368232640743372, 0.04618711165676359, 0.11920849472517148, 0.06437656862544827, 0.06505826095235534, 0.056586901264381595, 0.03337860012834426, 0.016393472578783985, 0.0371069570974214, 0.034390607543173246, 0.1764267892576754, 0.7099485606886446, 0.7878500211518258, 0.0950015225680545, 0.7137487130239606, 2.358115464448929, 10.264068134129047, 6.698108157142997, 3.2324677845463157, 3.217137032188475, 5.710092298686504, 6.149126440286636, 8.724530395120382, 6.424346622079611, 5.270926114171743, 1.8440676480531693, 0.5244155006948858, 2.683417433872819, 3.928032573312521, 3.6332800146192312, 13.89535278081894, 20.350934676826, 17.99140188843012, 14.979966580867767, 16.152520962059498, 23.6923423781991, 37.772443145513535, 56.5448722243309, 69.65869814157486, 99.90337282419205, 78.88931483030319, 38.277838826179504, 23.859183825552464, 56.83427229523659, 68.35454732179642, 75.47265216708183, 11.529660522937775, 0.1550498785218224, 0.21740726369898766, 0.2040255840984173, 0.2329633617773652, 0.21427473257062957, 0.15750479913549498, 0.028561473554873373, 0.273396042175591, 0.07660342191229574, 0.08810528597678058, 0.09381100637256168, 0.19263994036009535, 0.11948564235353842, 0.05679899222741369, 0.017157619367935695, 0.12323349554208107, 0.07606018465594389, 0.10254287844873033, 0.0044503302888188045, 0.06683634288492613, 0.10802614749991335, 0.03919400623999536, 0.06446142579079606, 0.10207244587945752, 0.05793718701170292, 0.05405304582382087, 0.014690441257698694, 0.07821004546713084, 0.04615099875081796, 0.0520741350192111, 0.03419138171011582, 0.03313353183330037, 0.014706475358252646, 0.12594375206390396, 0.026037605566671118, 0.032674027388566174, 0.056772716488922015, 0.02298118910402991, 0.026888837819569744, 0.11402926873415709, 0.040409120920230635, 0.08274965890450403, 0.08087743553915061, 0.0548229424020974, 0.04217995949147735, 0.036113599853706546, 0.03633443331636954, 0.03600122014177032, 0.04170898886513896, 0.07288525463081896, 0.10650878946762532, 0.03240171485231258, 0.05283069520373829, 0.10841770461411215, 0.016086653886304703, 0.06539363748743199, 0.03566471925296355, 0.038324632187141106, 0.11210758122615516, 0.1533650400233455, 0.1028972613858059, 0.16464038577396423, 0.03253161667089444, 0.10222207769402303, 0.011125153614557348, 0.12685485708061606, 0.04184658304438926, 0.4929801734397188, 0.5515734746586531, 5.193121964111924, 62.68457517027855, 115.11273309588432, 93.34564670920372, 88.69459748268127, 86.85504779219627, 105.05756065249443, 106.10685914754868, 83.37081715464592, 69.3610829114914, 51.910105124115944, 45.6831930577755, 47.73355923593044, 44.44012776017189, 39.67089347541332, 19.779477640986443, 13.236218299716711, 10.219559222459793, 6.834277650341392, 6.710904445499182, 6.6380181815475225, 7.4242002703249454, 6.505631860345602, 8.415030352771282, 8.417390026152134, 10.533532574772835, 28.183541782200336, 19.00102861225605, 25.287954658269882, 27.301079034805298, 11.822106130421162, 5.318776471540332, 2.6688160048797727, 5.267625516280532, 5.4029215313494205, 2.9206021316349506, 0.7518595992587507, 0.17036324978107587, 0.21032520075095817, 0.21235332707874477, 0.03430452212342061, 0.04970478774339426, 0.173124439897947, 0.04668891109758988, 0.05356974812457338, 0.056758545179036446, 0.05216856960032601, 0.06770298583433032, 0.05186430389585439, 0.09038997275638394, 0.13711095205508173, 0.012847501184296561, 0.16690870077582076, 0.09598522447049618, 1.4912920841015875, 0.1780669653089717, 0.11025166284525767, 0.09323247999418527, 0.08926380818593316, 0.02348740803427063, 0.06616938961087726, 0.023432867601513863, 0.0755055554327555, 0.10016373111284338, 0.10204985490418039, 0.015322994131565792, 0.047620688637834974, 0.022610395426454488, 0.013499473279807717, 0.06464014237280935, 0.15342454542405903, 0.8742978167720139, 0.7527808123268187, 0.10382334294263273, 1.4465357107110322, 2.367163491435349, 7.14111783541739, 6.75905023701489, 3.786855423822999, 3.53039697278291, 4.702416770160198, 5.763215348124504, 9.828621950000525, 11.713012084364891, 7.780116721987724, 3.978380346670747, 3.3558428892865777, 7.811340121552348, 8.201227225363255, 11.100585646927357, 22.061673179268837, 34.3655763566494, 37.23092280328274, 30.82626197487116, 30.251379422843456, 38.53070005774498, 39.91632990539074, 52.6284983754158, 62.52292804419994, 78.34242537617683, 88.20430219173431, 77.61891379952431, 46.98926277458668, 37.79924310743809, 64.92499575018883, 84.52744469046593, 30.058404877781868, 0.7249611394945532, 0.6239727116189897, 0.21001263783546165, 0.3166301816236228, 0.14342811307869852, 0.23048991715768352, 0.12195542818517424, 0.032069028602563776, 0.06776505164452828, 0.04879658081335947, 0.0786243865150027, 0.14451816474320367, 0.13806940609356388, 0.05009842658182606, 0.08469608961604536, 0.15263175358995795, 0.030779988592257723, 0.048072905192384496, 0.1016469651949592, 0.03444381582085043, 0.07285072249942459, 0.045548259804490954, 0.06850293939351104, 0.1031799751217477, 0.04237860644934699, 0.03576493887521792, 0.026034915281343274, 0.053930253779981285, 0.055363311257679015, 0.16620210197288543, 0.03474635232123546, 0.05473840064951219, 0.008534535936632892, 0.2392202158807777, 0.17759899666998535, 0.14291760453488678, 0.2552990976255387, 0.11034575232770294, 0.09869597823126242, 0.20704507129266858, 0.19178039976395667, 0.20638588088331744, 0.1433874582289718, 0.12019877205602825, 0.11200992201338522, 0.24050862877629697, 0.20302597054978833, 0.13066332146991044, 0.21529990568524227, 0.20746459253132343, 0.2636398875620216, 0.16173294803593308, 0.1510070587391965, 0.202153293939773, 0.11179619090398774, 0.17082360398489982, 0.11080428084824234, 0.10787015547975898, 0.1886506739538163, 0.20054762775544077, 0.18631376966368407, 0.327462064451538, 0.2163328416645527, 0.19149019033648074, 0.17720217030728236, 0.252941235085018, 0.18734303943347186, 0.9195670438930392, 0.3699623385909945, 1.9989577867090702, 41.70449495315552, 141.96457743644714, 102.72188678383827, 105.61670064926147, 92.28074625134468, 107.8520219027996, 130.50392121076584, 112.07484170794487, 118.67281526327133, 88.27662751078606, 41.8710932135582, 32.67049491405487, 42.87436477839947, 51.504575684666634, 35.57884365320206, 22.49984286725521, 13.963048998266459, 9.532663431018591, 8.17155746743083, 6.921555167064071, 7.628179499879479, 7.220253814011812, 12.130070105195045, 11.737652812153101, 17.31828510761261, 39.34318765997887, 34.972738176584244, 33.054145127534866, 33.89793924987316, 8.006934151053429, 7.277822149917483, 4.10203093662858, 8.936290182173252, 9.120422601699829, 3.6596415750682354, 1.6912634787149727, 0.553754260763526, 0.4435688123339787, 0.5420205497648567, 0.5480515386443585, 0.2424210394383408, 0.312234292505309, 0.16305904719047248, 0.12292534840526059, 0.12170939880888909, 0.2291994114057161, 0.2722042420646176, 0.20176838646875694, 0.13569171336712316, 0.3240528458263725, 0.21742690092651173, 0.2649032900808379, 0.6057808315381408, 6.4347965363413095, 0.3424408903811127, 0.1920096788671799, 0.2058828531880863, 0.163632771873381, 0.15491716767428443, 0.18542866950156167, 0.11425187592976727, 0.2061411354225129, 0.27136938530020416, 0.2153974981047213, 0.15413112938404083, 0.15110254345927387, 0.2398719996563159, 0.23962342471349984, 0.2432471388601698, 0.23590343917021528, 1.527577880769968, 1.099801347590983, 0.20567883679177612, 1.1226004804484546, 4.0849280543625355, 14.183502718806267, 17.44965735822916, 9.187448155134916, 7.140616737306118, 27.338058650493622, 25.719845183193684, 28.990158699452877, 18.6259488388896, 9.325012173503637, 4.157092832028866, 3.6675218772143126, 7.7467250637710094, 7.119860351085663, 14.331740364432335, 28.242197334766388, 38.716570883989334, 37.37013213336468, 25.82307044416666, 24.289649426937103, 42.785669937729836, 63.21450233459473, 78.38769614696503, 84.34435531497002, 114.6729750931263, 90.35241052508354, 59.862588196992874, 48.570430129766464, 73.41325387358665, 84.8775427043438, 101.66748136281967, 17.55834672600031, 0.6353799963835627, 1.3064152607694268, 0.3779997682431713, 0.5456999992020428, 0.19064246473135427, 0.23313770710956305, 0.10996617347700521, 0.3532307973364368, 0.1752857372048311, 0.23196809721412137, 0.27348079544026405, 0.23340560757787898, 0.22171045857248828, 0.30261837411671877, 0.10092552343849093, 0.20365792413940653, 0.16859591414686292, 0.15890172886429355, 0.3329993173247203, 0.1131166126288008, 0.26892923342529684, 0.14597976522054523, 0.10991612303769216, 0.29494305315893143, 0.1252881091204472, 0.14057102263905108, 0.18942994385724887, 0.28738326975144446, 0.1262359949760139, 0.3374573984183371, 0.07928089034976438, 0.16699588828487322, 0.13675831316504627], [0.03907128098944668, 0.060225298802834004, 0.03725498216226697, 0.04819466936169192, 0.05137792628374882, 0.07411977276206017, 0.09424500691238791, 0.02529744313505944, 0.05006211700674612, 0.08906944713089615, 0.09773045152542181, 0.01134943806391675, 0.054775637909187935, 0.06623964130994864, 0.0894148055522237, 0.051648023509187624, 0.14681521570309997, 0.09291993192164227, 0.06548325181938708, 0.0459034665254876, 0.048480544646736234, 0.09584480270859785, 0.008335379679920152, 0.026185801325482316, 0.01271350363822421, 0.020777967874892056, 0.006237671441340353, 0.06255932355998084, 0.10630213844706304, 0.03443216781306546, 0.16550060914596543, 0.16173748997971416, 0.055990437176660635, 0.05101568400277756, 0.06871649238746613, 0.05848958608112298, 0.018319377340958454, 0.8849666942842305, 13.842339925467968, 102.43771523237228, 90.39059847593307, 81.9810189306736, 69.39961284399033, 62.03574858605862, 97.361651211977, 95.91897502541542, 89.328753054142, 74.64149236679077, 34.96004305779934, 12.57193699479103, 23.804073482751846, 34.90300431847572, 23.58151562511921, 18.529553711414337, 12.7073560282588, 12.774244789034128, 9.276321586221457, 9.335456863045692, 6.166892386972904, 9.838920347392559, 7.7199426759034395, 1.3046389748342335, 17.94546615332365, 12.279258649796247, 6.891161072999239, 12.656011283397675, 6.233182679861784, 5.188769297674298, 3.4511712240055203, 1.651130982208997, 2.193691162392497, 0.6582189677283168, 0.706504579866305, 0.303133602719754, 1.0606281808577478, 0.3908009547740221, 0.15122260811040178, 0.09862721082754433, 0.024171885270334315, 0.06869156364700757, 0.06110261383582838, 0.03732515964657068, 0.05745423441112507, 0.1034190654172562, 0.010367434751969995, 0.16740914579713717, 0.08868979406543076, 0.007639737759745913, 0.027956830999755766, 0.17323645966826007, 1.4579374738968909, 0.06277729233261198, 0.07342772747506388, 0.05556675620027818, 0.0205249456121237, 0.01577576080308063, 0.11949760577408597, 0.10589858080493286, 0.01997861731069861, 0.07763330024317838, 0.055485561533714645, 0.08674656201037578, 0.051469703976181336, 0.17201316280988976, 0.08401259387028404, 0.11393331646104343, 0.11124902768642642, 0.5638832109980285, 0.12532883818494156, 0.04552083002636209, 0.09123150142841041, 1.8643253110349178, 2.2401393949985504, 3.649853775277734, 6.197218559682369, 2.2541152825579047, 2.998354034498334, 6.107019949704409, 6.677164630964398, 5.404534544795752, 6.8353430181741714, 8.88376085087657, 5.834979247301817, 5.934683522209525, 11.889486014842987, 30.300924964249134, 34.51923631131649, 27.940512523055077, 26.87895778566599, 40.34166768193245, 56.213393211364746, 66.28104418516159, 75.9643229842186, 89.14744198322296, 86.81697383522987, 51.819278597831726, 31.102018877863884, 38.83374139666557, 68.08232992887497, 75.13822451233864, 57.09231644868851, 6.7649969179183245, 0.2617891790578142, 0.46894812548998743, 0.2552068931981921, 0.3893797122873366, 0.3864829317899421, 0.3467834339244291, 0.1162896204914432, 0.11071480752434582, 0.012416224326443626, 0.01882460364868166, 0.07086931436788291, 0.0999682345718611, 0.08642271845019422, 0.11557534046005458, 0.06707739245030098, 0.1260784815531224, 0.06977560391533189, 0.06143970473203808, 0.049426226323703304, 0.08591264035203494, 0.09765073002199642, 0.06036725681042299, 0.03592622611904517, 0.12585969641804695, 0.09125776603468694, 0.07810932118445635, 0.018460899336787406, 0.012468976183299674, 0.010908058720815461, 0.06966887565795332, 0.0208671721702558, 0.020758466089318972, 0.017063001105270814, 0.01898623970191693, 0.015415260713780299, 0.030293868876469787, 0.057239861343987286, 0.09723458555527031, 0.0785091903526336, 0.04982641832611989, 0.11823496024589986, 0.023168939478637185, 0.0663487815472763, 0.16216639196500182, 0.08706843145773746, 0.03842578691546805, 0.03149398289679084, 0.06449743479606695, 0.03233389368688222, 0.0491327143390663, 0.012130320283176843, 0.05838015269546304, 0.06226811223314144, 0.04739329087897204, 0.05096173357742373, 0.02132385274308035, 0.02731607368332334, 0.06339559040497988, 0.005585646003964939, 0.02626067289384082, 0.04936696954246145, 0.07340744457906112, 0.03339474926178809, 0.0768677971791476, 0.006457117551690317, 0.030090743057371583, 0.0716343498788774, 0.06571856458322145, 0.02894827164709568, 0.2002518967492506, 0.7168929849285632, 3.9461692376062274, 53.500426188111305, 115.49123838543892, 98.63586723804474, 86.1617673933506, 92.68613129854202, 98.83740842342377, 110.69065198302269, 100.60549154877663, 75.18349528312683, 43.722912445664406, 33.30182723701, 38.316368758678436, 52.32578381896019, 57.45012424886227, 39.16331671178341, 31.082432828843594, 24.63556006550789, 25.930967554450035, 20.96211288124323, 20.791285447776318, 20.27586590498686, 24.769833460450172, 19.63279601186514, 13.325775694102049, 29.170375429093838, 29.430011697113514, 25.24096827954054, 29.511348232626915, 13.819664642214775, 10.31161593273282, 4.4756316393613815, 6.361942570656538, 3.747842204757035, 0.9769177820999175, 0.7106341270264238, 0.5587409588042647, 0.603007395984605, 0.3133204998448491, 0.0924033229239285, 0.22313214634777978, 0.03601123913540505, 0.09251999596017413, 0.046922309120418504, 0.028826210618717596, 0.06436860538087785, 0.06897101193317212, 0.09349738218588755, 0.19267410883912817, 0.11442035087384284, 0.06342668639263138, 0.01874883037089603, 0.06695911637507379, 0.30434170039370656, 0.19772939616814256, 0.09353026674943976, 0.04669543828640599, 0.009037184208864346, 0.08390296381548978, 0.10203555371845141, 0.05374384854803793, 0.061455545874196105, 0.04318436360335909, 0.057842381356749684, 0.01638999932765728, 0.04331043593992945, 0.04235758511640597, 0.07162162204622291, 0.22965139418374747, 0.4000794334569946, 1.3640916533768177, 0.5763843620661646, 0.08881806686986238, 0.4774695838568732, 2.5695731677114964, 5.4625070840120316, 4.475629264488816, 3.3546039182692766, 3.2258183788508177, 4.747787285596132, 7.793292040005326, 12.612233832478523, 12.658823132514954, 12.787089049816132, 8.755976557731628, 6.460615200921893, 7.598582413047552, 15.889386981725693, 38.59122321009636, 45.932102501392365, 43.74690055847168, 40.73875777423382, 45.58429956436157, 50.737149864435196, 49.20037552714348, 63.37861932814121, 73.96081209182739, 84.12290319800377, 81.41039595007896, 60.713514536619186, 39.519106820225716, 51.40207998454571, 76.1936254799366, 75.20197749137878, 21.413908638060093, 0.643046738114208, 0.6582665839232504, 0.39850616944022477, 0.35884437267668545, 0.2615563228027895, 0.28765456925611943, 0.1235326923779212, 0.11551901145139709, 0.05927264835918322, 0.03321511241665576, 0.04814452615391929, 0.16899667389225215, 0.2462942636338994, 0.0355737467907602, 0.08042223184020258, 0.08858326618792489, 0.06742845056578517, 0.054055108994361944, 0.004244188103257329, 0.013028034172748448, 0.12587255041580647, 0.06735965347616002, 0.11061294033424929, 0.07895614879089408, 0.08733686627238058, 0.009799471918086056, 0.01754609100316884, 0.050232892608619295, 0.013936101022409275, 0.10847132478374988, 0.06992805589106865, 0.03270396191510372, 0.09442232083529234, 0.07851605521864258, 0.07348807150265202, 0.274791368865408, 0.1341098255943507, 0.24958435271400958, 0.13223753543570638, 0.11267409965512343, 0.22751832817448303, 0.1828056524391286, 0.22154662205139175, 0.2909270249074325, 0.15425071906065568, 0.12637176347197965, 0.08058327788603492, 0.2523848321288824, 0.14322639734018594, 0.14075218088692054, 0.2646523847943172, 0.30326157866511494, 0.13189346092985943, 0.12593609309988096, 0.16054530395194888, 0.16981468390440568, 0.12245334248291329, 0.22537705401191488, 0.09254174830857664, 0.15632530383300036, 0.11154504813021049, 0.3921313880709931, 0.21793095278553665, 0.19692382455104962, 0.2140889284783043, 0.16722755710361525, 0.15073676855536178, 0.11384626996004954, 0.08495130678056739, 0.4008238669484854, 0.30026615189854056, 1.3283111108466983, 30.32128807157278, 142.6434490084648, 109.11602407693863, 102.08977550268173, 99.3076103925705, 87.12807074189186, 119.35667976737022, 121.66618064045906, 110.41098698973656, 100.59083193540573, 55.44875644147396, 34.95074115693569, 48.372635543346405, 57.69453853368759, 46.37383259832859, 45.309441313147545, 40.944634526968, 38.178333565592766, 23.66731882095337, 23.579127453267574, 23.940469063818455, 30.45526698231697, 24.54106293618679, 22.318446300923824, 41.23957470059395, 36.52730315923691, 23.442610278725624, 29.400795064866543, 9.82298020273447, 15.368270594626665, 6.7864743154495955, 7.138759586960077, 4.001880660653114, 0.6261247023940086, 1.193081473466009, 0.7970894034951925, 2.081376789137721, 1.7327827820554376, 0.33053241844754666, 0.3764862025855109, 0.07806698165950365, 0.19839375192532316, 0.1632170207449235, 0.14894189924234524, 0.2012171340174973, 0.15405773097882047, 0.1431056795991026, 0.26013938477262855, 0.33391854143701494, 0.21520394599065185, 0.1696056654327549, 0.5505615414585918, 3.2634608214721084, 0.19064525520661846, 0.23990924062673002, 0.22968477598624304, 0.1484956161584705, 0.2033512687194161, 0.3381549281766638, 0.3892294125398621, 0.14333587896544486, 0.23733612557407469, 0.21815475483890623, 0.29913520789705217, 0.15926845371723175, 0.30459836474619806, 0.14634815248427913, 0.347544580581598, 0.8521603234112263, 1.4384712371975183, 0.35754080512560904, 0.41090558690484613, 0.5954095849301666, 2.811857429333031, 3.873424041084945, 6.723441397771239, 13.534161262214184, 7.584516992792487, 6.318124746903777, 10.747510492801666, 13.242183029651642, 13.979511614888906, 19.032511822879314, 13.884697202593088, 12.708176784217358, 20.166779458522797, 36.05783075094223, 50.60682825744152, 51.53108686208725, 40.09940408170223, 36.420950666069984, 54.772958904504776, 75.26858791708946, 85.2298142015934, 91.77724286913872, 106.28833740949631, 97.29420483112335, 67.33227297663689, 57.30584979057312, 59.74319480359554, 87.34978884458542, 102.25242957472801, 84.25691440701485, 9.732631500810385, 0.5401194642763585, 1.1955309170298278, 0.42171149456407875, 0.6338281952776015, 0.27535816188901663, 0.3769717155955732, 0.24706600815989077, 0.18230406451039016, 0.17237274820217863, 0.17188204015837982, 0.3040835220599547, 0.2898080146405846, 0.24034120026044548, 0.14596425433410332, 0.14714419492520392, 0.22028885985491797, 0.2194689796306193, 0.1763040231890045, 0.09583410836057737, 0.27619527478236705, 0.24677502689883113, 0.2033752400893718, 0.2547201333800331, 0.18432335928082466, 0.1292237627785653, 0.1752830357872881, 0.19826366828056052, 0.1232124408124946, 0.04752076587465126, 0.31191505026072264, 0.13720253307837993, 0.19134400208713487, 0.1458863288280554, 0.2570462616859004], [0.011549843911780044, 0.08391233714064583, 0.055728010047459975, 0.020188364942441694, 0.03985555667895824, 0.08215130234020762, 0.07773504868964665, 0.052432863230933435, 0.05339706149243284, 0.047693905216874555, 0.041200272607966326, 0.0777800079958979, 0.09572633367497474, 0.049632480295258574, 0.03407053038245067, 0.08212270739022642, 0.0530377358518308, 0.05464915368065704, 0.07990364872966893, 0.09880629848339595, 0.05661914387019351, 0.03533386981871445, 0.05431717247120105, 0.05092406958283391, 0.04178919276455417, 0.11983802891336381, 0.044255011816858314, 0.13176564825698733, 0.11946898855967447, 0.058009824715554714, 0.0853313309198711, 0.177287413389422, 0.09655891946749762, 0.021882034998270683, 0.038033101736800745, 0.07311768786166795, 0.16455693868920207, 0.10556945315329358, 0.7946660835295916, 20.420887023210526, 106.90961927175522, 97.6215648651123, 71.7280974984169, 60.961413234472275, 55.20773157477379, 79.06143799424171, 97.30270877480507, 110.76546996831894, 95.71192413568497, 63.66578131914139, 39.326327964663506, 30.03816146403551, 25.129463262856007, 21.064336895942688, 33.917956575751305, 36.42016790807247, 22.675043866038322, 10.176427736878395, 11.122302431613207, 17.454507797956467, 17.74397436529398, 22.905161418020725, 30.906357876956463, 18.50569099187851, 8.00464192405343, 6.109660807996988, 5.712257707491517, 4.269499350339174, 3.0728998593986034, 0.8685203455388546, 0.4700758634135127, 0.3622766869375482, 0.35082600137684494, 0.1623157862923108, 0.021072101408208255, 0.11769961201935075, 0.11793223820859566, 0.05833518225699663, 0.12744265288347378, 0.037916610526735894, 0.05000316450605169, 0.07654364933841862, 0.07162912515923381, 0.05691326441592537, 0.12455584685085341, 0.021159956850169692, 0.16566616744967178, 0.0755726826901082, 0.24160449887858704, 0.09522122796624899, 0.4983364313375205, 0.09700117268948816, 0.12769863446010277, 0.08419953344855458, 0.05161617424164433, 0.04733430869237054, 0.04857343184994534, 0.04385621134133544, 0.0853203545557335, 0.06802841016906314, 0.05680505928467028, 0.11673246743157506, 0.08368304319446906, 0.11990265513304621, 0.10283182622515596, 0.31927371164783835, 0.2961639454588294, 0.14956178551074117, 0.19608598435297608, 0.5216146947350353, 0.11285283850156702, 2.826418485492468, 2.5918698962777853, 2.4196203891187906, 6.36982049793005, 2.8825692599639297, 3.2078674295917153, 3.4645282197743654, 3.3038255805149674, 3.9485709462314844, 8.758715260773897, 14.512875694781542, 16.561363823711872, 12.224400993436575, 28.247959725558758, 38.29742297530174, 44.88515228033066, 48.227612525224686, 71.51559010148048, 89.89009693264961, 96.77468910813332, 86.50504857301712, 77.34365656971931, 55.905123353004456, 26.647261418402195, 29.48506884276867, 57.62880966067314, 73.98821622133255, 70.35406842827797, 27.392925806343555, 0.386002910672687, 0.5179383920039982, 0.7953945163171738, 0.6496915128082037, 0.667030873009935, 0.4048797633731738, 0.4454903810983524, 0.1775295613333583, 0.26160100009292364, 0.0744083420431707, 0.07881216472014785, 0.071222695405595, 0.09298464719904587, 0.015048510813358007, 0.021705709987145383, 0.006101017934270203, 0.11656787391984835, 0.1047556585399434, 0.061884889437351376, 0.1594149091397412, 0.1890914948307909, 0.13620291952975094, 0.1302227974520065, 0.06018244348524604, 0.01475514725825633, 0.0730511691654101, 0.04297885920095723, 0.09862096194410697, 0.01736418875225354, 0.04609102208632976, 0.022460357286036015, 0.041807534944382496, 0.04656263467040844, 0.09202970351907425, 0.04734065405500587, 0.04307743496610783, 0.02565064605732914, 0.021943612846371252, 0.06080011815356556, 0.05512593903404195, 0.028346640356176067, 0.08423768726061098, 0.0820591053343378, 0.020062197982042562, 0.051749608683167025, 0.0495906676951563, 0.027990294438495766, 0.050332718892605044, 0.00536383522558026, 0.05770030460553244, 0.0504360852210084, 0.058090076854568906, 0.0828909564006608, 0.08636371028842404, 0.024409916150034405, 0.09263790838303976, 0.0581207980576437, 0.022634468841715716, 0.0633948779432103, 0.027893748447240796, 0.021717714225815143, 0.033379947126377374, 0.02777030702418415, 0.08011748373974115, 0.13760816131252795, 0.15520782239036635, 0.14121431624516845, 0.05808071837236639, 0.01644141346332617, 0.04682719547417946, 0.07941654752357863, 0.06005191455187742, 0.37557745759841055, 0.7126318698283285, 4.075700249522924, 57.1763451397419, 118.76460313796997, 100.8501148223877, 83.10124441981316, 73.74673917889595, 94.7665348649025, 104.08938780426979, 106.70373111963272, 92.19307735562325, 61.21109023690224, 37.50742256641388, 42.43693985044956, 55.18043763935566, 49.478551000356674, 51.55820220708847, 56.22580714523792, 52.404568791389465, 34.9226226657629, 27.616547606885433, 27.739640101790428, 33.220238015055656, 32.34295628964901, 42.581503093242645, 49.65413577854633, 32.75059461593628, 21.47874455899, 17.58878879249096, 6.337469983845949, 3.359190747141838, 3.3344234386458993, 1.7854607803747058, 1.0933918040245771, 1.2502409750595689, 0.3973145177587867, 0.11356317030731589, 0.4894249595236033, 0.505642726784572, 0.3441159176873043, 0.04179807998298202, 0.07612045446876436, 0.06987860659137368, 0.07489246723707765, 0.01331515348283574, 0.14988350652856752, 0.046859961294103414, 0.14314685395220295, 0.04143932950682938, 0.02079688521916978, 0.03962130147556309, 0.15427697624545544, 0.07572291564429179, 0.750623953063041, 0.13740142865572125, 0.07330636406550184, 0.008147779590217397, 0.02360205315198982, 0.030814314777671825, 0.0633156685216818, 0.0534537281782832, 0.03179149505740497, 0.02917049849202158, 0.11905066217877902, 0.023373723997792695, 0.059240186819806695, 0.16827603365527466, 0.1139902243448887, 0.245463473838754, 0.3813670406816527, 0.7120566163212061, 0.44829768827185035, 0.18637833651155233, 0.615761827211827, 2.987242005765438, 4.716790448874235, 6.789707466959953, 6.046945648267865, 2.044209558516741, 4.8183822724968195, 9.549098499119282, 13.788813147693872, 19.243541099131107, 27.386063374578953, 25.06420746445656, 19.50606521219015, 20.54097767919302, 41.014448180794716, 45.22002451121807, 52.364917919039726, 45.65331906080246, 50.98670147359371, 61.77141956984997, 72.47912719845772, 78.66963341832161, 80.99413588643074, 80.85798919200897, 62.38378331065178, 43.63636068999767, 54.27963897585869, 66.51976257562637, 85.03180682659149, 58.967356234788895, 8.435399159789085, 0.2887493558228016, 0.9122918592765927, 0.40617317834403366, 0.525520647643134, 0.24505342240445316, 0.5363287520594895, 0.22033674322301522, 0.3372201189631596, 0.0628084476920776, 0.11494696402223781, 0.019086008469457738, 0.11673071596305817, 0.09689316793810576, 0.0767813072889112, 0.06635057754465379, 0.047574452837579884, 0.07977413653861731, 0.07588610649690963, 0.07185543567175046, 0.11140162809169851, 0.04122520134842489, 0.07208600611193106, 0.07460872933734208, 0.06393896124791354, 0.03658795838418882, 0.14309849560959265, 0.025254034917452373, 0.049451681989012286, 0.01776578341377899, 0.03532552807882894, 0.04339107028499711, 0.0065874989832082065, 0.05332344044290949, 0.011761556379497051, 0.049487564829178154, 0.12945704947924241, 0.13078153075184673, 0.2630285656778142, 0.11688053331454284, 0.2052258892217651, 0.2695303433574736, 0.22513872070703655, 0.12559310212964192, 0.18256019451655447, 0.1995359468855895, 0.22054386179661378, 0.18708002229686826, 0.165682939987164, 0.1535881741438061, 0.27238036855123937, 0.19929191388655454, 0.248738823866006, 0.15483456663787365, 0.24087786208838224, 0.30849936010781676, 0.19200761569663882, 0.15297066274797544, 0.20347654324723408, 0.1201015803962946, 0.11348055442795157, 0.17192322935443372, 0.19351493247086182, 0.1827938374481164, 0.21400383382569999, 0.18997052422491834, 0.16720618325052783, 0.20195227582007647, 0.1743855862878263, 0.186809939914383, 0.19671088753966615, 0.19011617812793702, 0.7765330409165472, 0.3735989809501916, 1.9609561446122825, 34.05980296432972, 146.6744703054428, 113.7993335723877, 90.28158992528915, 82.55145192146301, 82.41875544190407, 101.19789496064186, 124.62306797504425, 128.92778098583221, 113.99683937430382, 84.08672153949738, 63.5064634680748, 53.8694129884243, 47.70724564790726, 49.65747579932213, 56.613416746258736, 57.175254598259926, 45.02099499106407, 37.580789029598236, 33.04677352309227, 40.1995363086462, 41.100661754608154, 54.05330412089825, 66.46529629826546, 43.444501385092735, 22.40847487002611, 21.009253151714802, 9.720585197210312, 4.105000952258706, 2.4371253373101354, 2.715001576580107, 2.300325552932918, 2.1796791767701507, 0.461998803075403, 0.4274298611562699, 1.4190883585251868, 0.9217809000983834, 0.5096647515892982, 0.21364254149375483, 0.25867367279715836, 0.1265488102217205, 0.2372412642580457, 0.17428308085072786, 0.3038372180890292, 0.11217378079891205, 0.2615699189482257, 0.13360170676605776, 0.2262993951444514, 0.12310661797528155, 0.3149647428654134, 0.36664835235569626, 1.939020634163171, 0.4087802837602794, 0.3053454402834177, 0.1782317814650014, 0.17891846102429554, 0.17996140115428716, 0.13750059442827478, 0.19922210747608915, 0.2053196818451397, 0.23862416739575565, 0.2029052231227979, 0.202039270370733, 0.12547946447739378, 0.44599887100048363, 0.3097329579759389, 0.9570235339924693, 1.659567360766232, 2.36082733143121, 0.8477171743288636, 0.9591982641723007, 1.362933071795851, 3.722905805334449, 5.0513572711497545, 12.459314838051796, 16.345501206815243, 9.395668432116508, 12.505934536457062, 13.979255128651857, 16.381715163588524, 21.755478009581566, 28.990588076412678, 29.144280329346657, 22.862275019288063, 17.809555046260357, 46.20398931205273, 50.796669870615005, 57.555374801158905, 60.10284550487995, 84.77742567658424, 101.20720446109772, 106.67653977870941, 102.89926886558533, 92.94641733169556, 70.98323866724968, 49.35638375580311, 52.48881407082081, 82.84687846899033, 95.85750192403793, 105.85139885544777, 52.599448934197426, 2.95722100418061, 0.5334493378177285, 1.1676544253714383, 0.6122202984988689, 0.729033867828548, 0.28549566166475415, 0.5882423976436257, 0.35876810958143324, 0.4363977658795193, 0.2116267941892147, 0.2811633894452825, 0.16075994790298864, 0.23848589044064283, 0.21133345289854333, 0.2088797790929675, 0.1917632858385332, 0.24111750157317147, 0.2894451341126114, 0.12020235662930645, 0.17122660501627252, 0.21530318597797304, 0.20049465325428173, 0.23934399127028883, 0.19719696458196267, 0.19064219755819067, 0.1352045824751258, 0.13826435344526544, 0.22998200613074005, 0.1412768941372633, 0.18403743946691975, 0.18684631999349222, 0.19396194285945967, 0.12973805627552792, 0.3850607987260446, 0.12479941971832886, 0.1601227547507733], [0.01755543093167944, 0.09831743096583523, 0.062405854841927066, 0.07595759016112424, 0.08485667553031817, 0.011290075526630972, 0.027155775351275224, 0.0666338849987369, 0.035398692707531154, 0.13611669681267813, 0.077813404641347, 0.11175581064890139, 0.06226906960364431, 0.07483683584723622, 0.08351968164788559, 0.06729902001097798, 0.062126740522217005, 0.04535670035693329, 0.03785795488511212, 0.0681749323848635, 0.09411949489731342, 0.0273351153373369, 0.08958430466009304, 0.10368209739681333, 0.04334961762651801, 0.05738158928579651, 0.06937690734048374, 0.05811215945868753, 0.10321493027731776, 0.12128774760640226, 0.04430985281942412, 0.15045362437376752, 0.14263655320974067, 0.16028307349188253, 0.09134767722571269, 0.03496099256153684, 0.02454530058457749, 0.11534780540387146, 0.14212595560820773, 0.1790291746146977, 9.567879941314459, 80.25887534022331, 107.46489107608795, 84.46569040417671, 68.73192027211189, 52.32229940593243, 47.36525259912014, 77.16672286391258, 97.09035336971283, 104.79989647865295, 96.60255074501038, 85.53484663367271, 62.132825776934624, 36.981435790658, 39.53765742480755, 40.83091042935848, 36.12541012465954, 34.047449827194214, 25.159945227205753, 26.67227927595377, 28.02716877311468, 31.20186612010002, 28.82219061255455, 10.03022488206625, 7.787170568481088, 8.766938969492912, 11.942118890583515, 4.138296190649271, 0.8068347524385899, 2.5987522769719362, 4.060731427744031, 2.905553989112377, 3.990702610462904, 3.6492222966626287, 0.3251906769583002, 0.14804829406784847, 0.1701793455868028, 0.02308336985151982, 0.06003091919410508, 0.015858170736464672, 0.04467901191674173, 0.1294995448552072, 0.04899576582829468, 0.03263348015025258, 0.0471183103218209, 0.10821801493875682, 0.09116873057791963, 0.06688126508379355, 0.09154493265668862, 0.07273065042681992, 0.36503557639662176, 0.28424356947652996, 0.08325151400640607, 0.07751256023766473, 0.019977461415692233, 0.09539644161122851, 0.06354353012284264, 0.09577339325915091, 0.11256517464062199, 0.09602602774975821, 0.1215753001451958, 0.07652325512026437, 0.062005900326767005, 0.0745793551323004, 0.2667573234066367, 0.9240622026845813, 0.3541283210506663, 0.2252631343435496, 0.88353690225631, 0.8588057511951774, 1.5286400425247848, 5.448909513652325, 3.691829410381615, 10.967610832303762, 15.064381901174784, 15.463147703558207, 11.260257828980684, 21.838298365473747, 28.16042762249708, 35.19487425684929, 50.44452376663685, 61.25999741256237, 56.27273842692375, 49.74553607404232, 44.36687149107456, 50.492800176143646, 69.39031094312668, 81.47642120718956, 87.97000676393509, 75.91168820858002, 71.06518507003784, 49.700375497341156, 33.03845576941967, 36.57505139708519, 48.832935243844986, 70.13333067297935, 76.62453755736351, 63.14215041697025, 9.375033639371395, 1.0537776234559715, 1.360720165539533, 1.4481562050059438, 0.8420178364031017, 0.9671922633424401, 0.7802938297390938, 0.5669184762518853, 0.3587218886241317, 0.24093592772260308, 0.18766186607535928, 0.2651253406656906, 0.08741223879042082, 0.15329318528529257, 0.09136189677519724, 0.045546081601059996, 0.08201795324566774, 0.035144529392709956, 0.023737780829833355, 0.05608346909866668, 0.08145039580995217, 0.14436051773373038, 0.12478965305490419, 0.08625791713711806, 0.11524026078404859, 0.06755768816219643, 0.1323797309305519, 0.04149116110056639, 0.030706681100127753, 0.04601754204486497, 0.06343888730043545, 0.08238670416176319, 0.04539720306638628, 0.0348620939621469, 0.037796104297740385, 0.03466856411250774, 0.06104359825258143, 0.05541467158764135, 0.012105590067221783, 0.03563047284842469, 0.007651227597307297, 0.036869725881842896, 0.06856754334876314, 0.05512953102879692, 0.027645759801089298, 0.14297331013949588, 0.01856608949310612, 0.07821217543096282, 0.0028864998967037536, 0.07976033259183168, 0.016994098259601742, 0.03581885961466469, 0.033177953082486056, 0.0629721803124994, 0.13554040429880843, 0.03881303215166554, 0.10128423309652135, 0.1618669056915678, 0.024058353374130093, 0.07677113986574113, 0.09727026801556349, 0.06116789314546622, 0.039785920962458476, 0.10282238610670902, 0.01195045244458015, 0.0809412899252493, 0.1477408074424602, 0.1554149409639649, 0.16792887181509286, 0.19734910485567525, 0.045583949686260894, 0.17911793547682464, 0.06803786513046362, 0.05595060982159339, 0.03496241377433762, 0.3446677193278447, 0.5794611282180995, 4.131625648587942, 48.03117826581001, 111.85995563864708, 99.23729136586189, 79.62620928883553, 67.62104228138924, 76.83924123644829, 83.95364508032799, 106.64750173687935, 108.78241717815399, 88.7765970826149, 63.42454366385937, 50.11772610247135, 45.43344385921955, 41.429161727428436, 48.18661272525787, 50.97801133990288, 54.30491901934147, 42.923978716135025, 33.388986960053444, 40.84286078810692, 48.535623997449875, 52.29298397898674, 45.337954983115196, 34.06638041138649, 23.530788347125053, 13.458217587321997, 9.812899343669415, 7.334675649181008, 4.802681040018797, 2.446548119187355, 2.0055067352950573, 2.35339920502156, 1.6147659835405648, 1.0747971455566585, 1.7837205925025046, 0.44133073242846876, 0.17708903731545433, 0.019139435680699535, 0.019124492537230253, 0.062259503320092335, 0.0710320079815574, 0.09678528193035163, 0.024278452110593207, 0.04026088434329722, 0.06776981623261236, 0.12422065585269593, 0.05008230342355091, 0.037010681990068406, 0.052565362566383556, 0.04777601643581875, 0.5566045234445482, 1.3388636196032166, 0.19385387131478637, 0.35743331245612353, 0.07989713267306797, 0.19180947710992768, 0.1255241862963885, 0.09649497602367774, 0.06217425652721431, 0.06348503404296935, 0.010173147911700653, 0.046426409753621556, 0.038136371586006135, 0.04654924261558335, 0.3449581959284842, 0.16884800686966628, 0.7716210919898003, 0.6380362319760025, 0.8683103474322706, 1.4858639566227794, 1.6393619449809194, 4.14406618103385, 3.547596037387848, 9.738725423812866, 9.662199430167675, 0.9464253683108836, 9.923667199909687, 9.783043395727873, 14.879487622529268, 24.759287126362324, 31.92899890244007, 37.105620726943016, 35.44214218854904, 25.759676545858383, 38.019201904535294, 54.882978200912476, 67.1872727572918, 75.59909418225288, 87.116868942976, 88.45137253403664, 83.01735252141953, 75.3916785120964, 60.407292768359184, 51.24091163277626, 41.22410573065281, 64.86815840005875, 82.62365564703941, 85.54648160934448, 32.850662246346474, 2.0090861432254314, 1.1270132311619818, 1.323152887634933, 0.580860759364441, 0.7425559766124934, 0.5304095009341836, 0.5614490259904414, 0.46829711354803294, 0.25939189363271, 0.30431293474975973, 0.1293362575233914, 0.15688382933149114, 0.1653984302538447, 0.08093639175058343, 0.06546736985910684, 0.13371473585721105, 0.031376820043078624, 0.057134936505462974, 0.15290609590010718, 0.13433082232950255, 0.10389343879069202, 0.10709756490541622, 0.18096285522915423, 0.1253444975009188, 0.13708712911466137, 0.14390117285074666, 0.03279850039689336, 0.07070383027894422, 0.10010146492277272, 0.027537461901374627, 0.03839381148281973, 0.05249355235719122, 0.06903579400386661, 0.039348992650047876, 0.18010554107604548, 0.03591967295506038, 0.04286542935005855, 0.08885036513675004, 0.15568880829960108, 0.16395250393543392, 0.11666007834719494, 0.25022782443556935, 0.17138520197477192, 0.08489908184856176, 0.21785096410894766, 0.14793143549468368, 0.29194780450779945, 0.2251646958757192, 0.32005822111386806, 0.15597420861013234, 0.1373692342895083, 0.189598559809383, 0.1704776444239542, 0.23609847557963803, 0.1129664687323384, 0.16041185095673427, 0.2160148016992025, 0.12345559065579437, 0.23035671649267897, 0.39136765873990953, 0.2672007418004796, 0.20359073008876294, 0.19910230999812484, 0.1265603580395691, 0.2793986216420308, 0.2669764350866899, 0.37341228628065437, 0.32408054277766496, 0.25765710859559476, 0.3441323043080047, 0.3155114088440314, 0.1967599880299531, 0.23886932845925912, 0.14672853285446763, 0.500846077920869, 0.33274873858317733, 1.119063701480627, 23.889489099383354, 123.95041286945343, 126.4778396487236, 88.7267741560936, 82.37078681588173, 73.68273541331291, 65.33016040921211, 97.99594357609749, 125.42771279811859, 128.2764807343483, 113.78696903586388, 101.02400109171867, 86.91997110843658, 64.59546223282814, 72.04781234264374, 68.53815346956253, 63.044780641794205, 52.52510592341423, 42.917769849300385, 53.67226056754589, 65.26597425341606, 66.61918804049492, 62.86497808992863, 31.253756135702133, 24.150688983500004, 24.613095670938492, 28.216535411775112, 12.342349514365196, 6.388221485540271, 4.9520239513367414, 5.118903871625662, 3.218343467451632, 4.472616501152515, 5.8316420763731, 2.8080060984939337, 0.44897921732626855, 0.8726164663676172, 0.09992229563067667, 0.37141059525310993, 0.1721278394688852, 0.1875002114684321, 0.22930737904971465, 0.11988945974735543, 0.10843980577192269, 0.230678066436667, 0.229547745839227, 0.2266731407144107, 0.19625547603936866, 0.13654978451086208, 0.2351973598706536, 0.653637422947213, 2.230592407286167, 0.24025123711908236, 0.5300191312562674, 0.13377913943259045, 0.3487083868822083, 0.17176622059196234, 0.2278111202758737, 0.2963250211905688, 0.20266737963538617, 0.14703698427183554, 0.1329725733376108, 0.1840503528364934, 0.2208126528421417, 0.44940426014363766, 2.093992349691689, 1.4092221879400313, 1.8047807249240577, 3.713331981562078, 2.640136331319809, 2.388360654003918, 5.298192501068115, 3.5217426996678114, 13.559689242392778, 27.28342518210411, 37.04571694135666, 33.54413643479347, 44.41196747124195, 54.583368077874184, 53.43522548675537, 62.22152441740036, 61.84265814721584, 60.53472653031349, 68.35295140743256, 76.25732526183128, 76.50125697255135, 87.37343117594719, 93.65358978509903, 99.03273314237595, 90.29059544205666, 86.77028194069862, 67.5957964360714, 52.61053293943405, 58.73050734400749, 68.50326374173164, 94.56285819411278, 104.93843704462051, 94.26173955202103, 22.41856522858143, 0.6761208164971322, 1.474121636711061, 1.424617893062532, 0.731991712236777, 0.6602841569110751, 0.4791138565633446, 0.6080652808304876, 0.6949140143115073, 0.36942484555765986, 0.4382719559362158, 0.251386376330629, 0.20056410343386233, 0.3132185584399849, 0.19254711252870038, 0.20829055836657062, 0.3731167037039995, 0.19107118860119954, 0.34888706635683775, 0.2885826991405338, 0.3186519106384367, 0.17543431516969576, 0.1849865572876297, 0.22810802387539297, 0.34877503174357116, 0.22139317559776828, 0.1689004321815446, 0.1545251058996655, 0.20415764185599983, 0.20992043340811506, 0.18073755403747782, 0.18901524657849222, 0.2530767215648666, 0.20433934929315, 0.19908653193851933, 0.26978549372870475, 0.08927958624553867, 0.17254700447665527], [0.07596920477226377, 0.017110706357925665, 0.06421259851776995, 0.08617237719590776, 0.04418910168169532, 0.12631216901354492, 0.08687156936503015, 0.09607066793250851, 0.057206832061638124, 0.07627750776009634, 0.11715102387825027, 0.0936293434642721, 0.15051451016915962, 0.029576952365459874, 0.018098332366207615, 0.04966820728441235, 0.11808539522462524, 0.041816704178927466, 0.04030831500131171, 0.04524229087110143, 0.06925092777237296, 0.036651330374297686, 0.036291474098106846, 0.13871854782337323, 0.03733758690941613, 0.029945590104034636, 0.06475038098869845, 0.1696753827854991, 0.03587670260458253, 0.0400471383909462, 0.0571147909067804, 0.17617195058846846, 0.20553796231979504, 0.3345802699914202, 0.22220095881493762, 0.25851497193798423, 0.4212265752721578, 0.07732311962172389, 0.14833679655566812, 0.3787570557324216, 1.31600190885365, 2.9529044358059764, 52.021959722042084, 122.88873463869095, 81.00616604089737, 75.13118728995323, 59.09772723913193, 39.969834834337234, 47.85692721605301, 76.99379414319992, 89.99545767903328, 90.3340271115303, 86.95852383971214, 80.58989077806473, 63.08826170861721, 68.34751009941101, 66.23240679502487, 69.51464027166367, 60.70149578154087, 63.66547353565693, 65.6506884098053, 59.09670889377594, 46.37076236307621, 39.642512798309326, 51.67376160621643, 51.61514215171337, 43.598700910806656, 40.369877368211746, 30.55327322334051, 17.921761125326157, 9.10666923969984, 6.189086996018887, 4.7336102463305, 7.410824988037348, 0.9348444209899753, 0.43269676447380334, 0.5591893941164017, 0.10627438954543322, 0.2417220699135214, 0.11206685958313756, 0.07546755747171119, 0.055957537770154886, 0.0813699841091875, 0.15253376041073352, 0.11334710143273696, 0.1257302361773327, 0.17622084327740595, 0.05976133776130155, 0.08568122386350296, 0.04033039389469195, 0.4010827577440068, 0.647516188910231, 0.1353687752271071, 0.08510581450536847, 0.09122386472881772, 0.07258553087012842, 0.046320453329826705, 0.19127030682284385, 0.2049880160484463, 0.19179726135917008, 0.11809795236331411, 0.07374028296908364, 0.060285765284788795, 0.3271761001087725, 0.38570949516724795, 0.2040868706535548, 0.6089128134772182, 1.1139478697441518, 3.082098215818405, 2.9761845991015434, 6.469400804489851, 6.075641233474016, 8.456069100648165, 23.85063238441944, 26.085647754371166, 26.77110817283392, 33.44697564840317, 45.19836187362671, 62.01135389506817, 79.84870254993439, 86.72427400946617, 71.87252774834633, 54.09559205174446, 32.49247446656227, 35.121758580207825, 52.81351424753666, 63.392161801457405, 56.247135400772095, 48.454426154494286, 42.98157222568989, 37.8718876093626, 35.6790366768837, 49.86752092838287, 64.95827436447144, 75.59046864509583, 63.59121412038803, 26.355121694505215, 6.15175542421639, 1.7767784837633371, 2.8024814324453473, 1.3170511275529861, 1.2447373266331851, 1.6006142366677523, 1.5594398835673928, 1.1891409661620855, 0.484008468920365, 0.3801071410998702, 0.22947182413190603, 0.3312916058348492, 0.22652453306363896, 0.19302594620967284, 0.29105084482580423, 0.2990680583752692, 0.0957329610537272, 0.18960123154101893, 0.2690388634800911, 0.09646258127759211, 0.17625572421820834, 0.07537710451288149, 0.18198934936663136, 0.08274096093373373, 0.19545109185855836, 0.13595467113191262, 0.30101266340352595, 0.055721731478115544, 0.12382892062305473, 0.11529398485436104, 0.07300696684978902, 0.08297413631225936, 0.13837496313499287, 0.14916786836693063, 0.0314917787181912, 0.02438722312945174, 0.06389300746377558, 0.09871361908153631, 0.13830659649102017, 0.02268787007778883, 0.04075954821018968, 0.09449099175981246, 0.047885379317449406, 0.06519005153677426, 0.09860915437457152, 0.0746327823435422, 0.12537692935438827, 0.0979923183331266, 0.028851131937699392, 0.14305463468190283, 0.05586202707490884, 0.044520904775708914, 0.12541713891550899, 0.16347380384104326, 0.05755853955633938, 0.06887606898089871, 0.10434360330691561, 0.1195608738635201, 0.12248276121681556, 0.03273377398727462, 0.11410585095291026, 0.049469961086288095, 0.15296156401745975, 0.11024990395526402, 0.031802846206119284, 0.054068901808932424, 0.07738052474451251, 0.10440841506351717, 0.03748290313524194, 0.14798093674471602, 0.1336571155115962, 0.2850664034485817, 0.1973982498748228, 0.29133315780200064, 0.06374996592057869, 0.16477277007652447, 0.04232504936226178, 0.7418414962012321, 0.5008102767169476, 5.412851823493838, 25.97190085798502, 89.03369888663292, 110.65656021237373, 83.48247036337852, 64.17013585567474, 56.676880940794945, 62.0830674469471, 77.74303033947945, 97.75210306048393, 100.65124109387398, 94.26287949085236, 81.93352147936821, 70.35902336239815, 67.25642144680023, 71.7476512491703, 66.00703328847885, 76.27231925725937, 74.96330469846725, 76.54155761003494, 78.54745477437973, 71.39260590076447, 63.19032043218613, 38.69491204619408, 27.651834413409233, 15.143876485526562, 19.889120757579803, 15.124294236302376, 8.187261074781418, 4.849398583173752, 5.688494257628918, 6.06264878064394, 5.250889789313078, 3.2953266240656376, 1.54531687265262, 0.09179375992971472, 0.5977424816228449, 0.09482186345849186, 0.14661948167486116, 0.08746995561523363, 0.06384924301528372, 0.10618486427119933, 0.10341536210034974, 0.03440292719460558, 0.060692098559229635, 0.024508790629624855, 0.15550788753898814, 0.0338959920918569, 0.04968234519765247, 0.14813122164923698, 0.7751595927402377, 1.1323847179301083, 0.05900030242628418, 0.03807386048720218, 0.04285449751478154, 0.09511242911685258, 0.0521782434952911, 0.12003905445453711, 0.08990888294647448, 0.0832034376799129, 0.1042907327064313, 0.07000419282121584, 0.10229657447780482, 0.14249903324525803, 0.40090538444928825, 0.30883985746186227, 1.172925098799169, 1.8923592567443848, 0.8824627473950386, 2.3458656342700124, 5.1149264350533485, 6.390586383640766, 6.198999239131808, 20.021207369863987, 26.337627433240414, 20.406607389450073, 13.267538119107485, 27.123242877423763, 39.218185767531395, 51.212660148739815, 62.798629850149155, 64.41244125366211, 59.59873415529728, 56.4395646750927, 58.46347287297249, 72.26639181375504, 81.31955802440643, 79.76753890514374, 74.63000178337097, 64.59369912743568, 63.54690469801426, 52.33216367661953, 53.145935609936714, 62.87591390311718, 79.37049821019173, 84.52601596713066, 55.1598085463047, 17.020909264683723, 1.9639172544702888, 2.553286054171622, 1.456685084849596, 1.1691376520320773, 1.2717577954754233, 1.1048644571565092, 0.9632676083128899, 0.5292268737684935, 0.17602960666408762, 0.2520745253423229, 0.19289299787487835, 0.23006672970950603, 0.19085648527834564, 0.14118366554612294, 0.3783454903168604, 0.35048036836087704, 0.1474463677732274, 0.26112341322004795, 0.19754004460992292, 0.08370272495085374, 0.09291852184105664, 0.22839308279799297, 0.08668225491419435, 0.15512309881160036, 0.12566152814542875, 0.21609026327496395, 0.08458295662421733, 0.1392101909732446, 0.17245784285478294, 0.13630233763251454, 0.1252284404472448, 0.09057415896677412, 0.09467327065067366, 0.05256207485217601, 0.13558116304920986, 0.1032480745925568, 0.06389602058334276, 0.008284537925646873, 0.1303906860994175, 0.19701497512869537, 0.26384667959064245, 0.2533308626152575, 0.13030731322942302, 0.3484596486669034, 0.32448525074869394, 0.2741750894347206, 0.21793044812511653, 0.3577755019068718, 0.2860959997633472, 0.12874020903836936, 0.3274434513878077, 0.19958455755840987, 0.23463681573048234, 0.21162222255952656, 0.18221916281618178, 0.2591228799428791, 0.12254649685928598, 0.21650963608408347, 0.16957025014562532, 0.16579239192651585, 0.2494713681517169, 0.2541327680228278, 0.1778860148624517, 0.16633726190775633, 0.18873327499022707, 0.3450241283280775, 0.3060247132088989, 0.17660045181401074, 0.2710877254139632, 0.34978648996911943, 0.5665766133461148, 0.391939349938184, 0.5200018000323325, 0.26129006990231574, 0.5439295317046344, 0.10345330811105669, 0.917089992435649, 0.38685495557729155, 2.2223397251218557, 8.370533790439367, 74.18740153312683, 136.56584233045578, 96.42130807042122, 83.63378584384918, 73.56314063072205, 55.90629369020462, 65.12367188930511, 97.80855283141136, 115.58187112212181, 120.87586104869843, 109.97854739427567, 106.30507171154022, 95.11379063129425, 102.15513199567795, 103.71985763311386, 114.50256183743477, 100.95658510923386, 92.46072739362717, 99.51767072081566, 97.42474302649498, 87.36875742673874, 74.0135608613491, 84.32723343372345, 75.85444808006287, 68.59033226966858, 47.74400107562542, 35.18909476697445, 26.224564500153065, 21.52715016156435, 13.236703723669052, 11.193665452301502, 16.270555928349495, 4.218611055985093, 1.152093904092908, 1.2015655869618058, 0.60823401552625, 0.5114459060132504, 0.21093288611155003, 0.11800733613199554, 0.20567791652865708, 0.201133850205224, 0.30229815223719925, 0.3659338125726208, 0.16369324206607416, 0.3911661508027464, 0.10483808146091178, 0.20557607902446762, 0.2629849867662415, 2.0685909502208233, 1.3474665954709053, 0.2004660657257773, 0.3358479175949469, 0.28651032596826553, 0.21506875636987388, 0.19061461935052648, 0.17215118743479252, 0.22901218238985166, 0.20001274708192796, 0.23310776887228712, 0.2062225787085481, 0.31580767419654876, 0.5742497078608721, 0.6027769739739597, 1.3827550644055009, 1.8942362372763455, 4.314035810530186, 6.574719753116369, 4.274259069934487, 9.719496555626392, 7.746922178193927, 8.808873519301414, 24.55083031207323, 34.40674714744091, 39.92640696465969, 51.367323249578476, 61.99566453695297, 67.33865663409233, 78.98326858878136, 81.64468377828598, 81.1243548989296, 77.87691235542297, 70.57862877845764, 75.98136126995087, 85.60275658965111, 88.73015597462654, 79.03854802250862, 69.24535632133484, 65.32418712973595, 61.15704193711281, 58.99228669703007, 77.94314280152321, 90.17142623662949, 106.1614242196083, 96.82514280080795, 43.690051808953285, 7.920124484226108, 1.317730697337538, 2.8318189457058907, 1.1209341511130333, 1.0245848586782813, 1.151711312122643, 1.0440300777554512, 0.9924115694593638, 0.6156362558249384, 0.5280324316117913, 0.34226604038849473, 0.3542684088461101, 0.24025171209359542, 0.21078595571452752, 0.4012931417673826, 0.5821119609754533, 0.4551427537808195, 0.36452165397349745, 0.43038714153226465, 0.2512181462952867, 0.224492859269958, 0.3285245824372396, 0.3875515057006851, 0.20001733355456963, 0.3880506445420906, 0.32691453758161515, 0.3107532032299787, 0.13305244327057153, 0.2358036648365669, 0.2289271174231544, 0.12600771035067737, 0.2694096998311579, 0.27606332092545927, 0.23771049454808235, 0.22740195941878483, 0.20305730402469635, 0.15891137678408995, 0.21063105465145782, 0.15840294625377283], [0.05321546908817254, 0.05409321827755775, 0.13927695457823575, 0.08944262124714442, 0.026473172038095072, 0.07578893710160628, 0.06251394865103066, 0.09700858674477786, 0.17564437264809385, 0.1399237065925263, 0.02024274395807879, 0.07896059425547719, 0.08934940749895759, 0.058919530783896334, 0.13407052145339549, 0.13341134588699788, 0.10635695347446017, 0.059566716954577714, 0.1750967715634033, 0.1146139029879123, 0.03027818544069305, 0.09719115507323295, 0.0755513904732652, 0.06188443672726862, 0.10421290367958136, 0.10532878950471058, 0.15036125667393208, 0.10368546674726531, 0.06740827899193391, 0.13725860975682735, 0.031820991716813296, 0.033815602655522525, 0.24800072831567377, 0.5399689567275345, 0.686932245735079, 0.6572548882104456, 0.7319679041393101, 0.5791793495882303, 0.25092864932958037, 0.1787518191849813, 0.6224200793076307, 1.0298282210715115, 2.2279118886217475, 13.866388835012913, 70.3708103299141, 91.63117870688438, 89.35788229107857, 81.57623425126076, 63.957909643650055, 46.376177072525024, 42.270223796367645, 65.26288121938705, 75.99409818649292, 75.64733639359474, 77.07477539777756, 68.45419317483902, 76.5635584294796, 74.90215077996254, 74.3863208591938, 72.87764221429825, 82.30767980217934, 65.18455222249031, 54.932310953736305, 53.26069325208664, 46.45639456808567, 45.160671696066856, 48.042919635772705, 34.655166417360306, 30.90798418968916, 25.96308533102274, 20.01087762415409, 15.450971256941557, 11.468054428696632, 15.64293410629034, 10.18727995455265, 3.841410046443343, 0.45210291689727455, 0.4734003287740052, 0.20116675703320652, 0.19121840101433918, 0.111795070260996, 0.08847615201375447, 0.030922508776711766, 0.09719449473777786, 0.05319876334397122, 0.05931872459768783, 0.07036198221612722, 0.0494455704028951, 0.018872717082558665, 0.17346144915791228, 0.28609884961042553, 0.34002885106019676, 0.09153055725619197, 0.08449557615676895, 0.07317299270653166, 0.20082982198800892, 0.3826413082424551, 0.24371858075028285, 0.42170374654233456, 0.21865074697416276, 0.18894836422987282, 0.07704391624429263, 0.153795218502637, 0.0779537002381403, 0.498907231958583, 2.015680451877415, 2.967250091023743, 7.404489777982235, 7.055886033922434, 12.278656382113695, 16.752060391008854, 17.670526206493378, 11.513181757181883, 9.162827376276255, 14.590789563953876, 21.57736636698246, 27.70210761576891, 37.47364617884159, 37.8146892786026, 34.927102625370026, 28.232532553374767, 22.118544727563858, 22.978377789258957, 26.738507822155952, 33.82404461503029, 33.755275905132294, 30.64416814595461, 25.747287310659885, 26.577556058764458, 34.753771126270294, 42.371229976415634, 57.62773431837559, 71.04202151298523, 76.69275909662247, 41.56220778822899, 14.239034838974476, 2.2815678594633937, 1.7121419333852828, 1.9942752504721284, 0.8573561883531511, 1.6674621496349573, 1.896719760261476, 1.0951653588563204, 1.1136362864635885, 0.45535640325397253, 0.790527630597353, 0.46812063083052635, 0.5075024301186204, 0.21757402428193018, 0.4105016804533079, 0.4137063928646967, 0.4751686588861048, 0.2994504425441846, 0.3348164807539433, 0.28315881674643606, 0.29013654857408255, 0.2209524140926078, 0.2520325197838247, 0.2540408307686448, 0.30184285948053, 0.2893211360787973, 0.2485548157710582, 0.33471819071564823, 0.2039085770957172, 0.18362406321102753, 0.06517726433230564, 0.1059011634788476, 0.09225009169313125, 0.29939240659587085, 0.2771639556158334, 0.1608467791811563, 0.11633277637884021, 0.08451169560430571, 0.09530679759336635, 0.09394840759341605, 0.02350973925786093, 0.07581501617096364, 0.04182290482276585, 0.09305492858402431, 0.021560933673754334, 0.026658855531422887, 0.09575607895385474, 0.10406705681816675, 0.1749447055044584, 0.13932284899055958, 0.2167517543421127, 0.05649415877996944, 0.13196215411880985, 0.055596761230845004, 0.16261396638583392, 0.24451687932014465, 0.19235158630181104, 0.13900951424147934, 0.2397699246648699, 0.1811846683267504, 0.1633828313788399, 0.014376076778717106, 0.1309958630008623, 0.14485796447843313, 0.12650129792746156, 0.12001514245639555, 0.2531780692515895, 0.12638599786441773, 0.17890890216222033, 0.048484767467016354, 0.13330453599337488, 0.050867926111095585, 0.10984492138959467, 0.24854965042322874, 0.41983145638369024, 0.5934155231807381, 0.6261488073505461, 0.5534734320826828, 0.2448514840216376, 0.1453909749398008, 0.9546497894916683, 0.2687392436200753, 4.790297029539943, 12.807660195976496, 43.55113886296749, 88.30099180340767, 93.88059720396996, 78.89241546392441, 61.914759278297424, 56.773608550429344, 66.69741064310074, 68.6681216955185, 85.94573378562927, 91.5101931989193, 96.5747894346714, 91.62218078970909, 87.5061884522438, 87.64744967222214, 97.91907370090485, 93.31631228327751, 93.15469935536385, 98.81568878889084, 93.45025509595871, 80.41011482477188, 76.26272097229958, 63.42734031379223, 56.71863690018654, 45.360445976257324, 38.14305245876312, 32.56268709897995, 27.38295704126358, 20.70256780833006, 15.711832009255886, 13.33978459239006, 10.855794232338667, 3.7588851246982813, 2.6348702888935804, 0.6969005358405411, 0.741229432169348, 0.30521918612066656, 0.13139024027623236, 0.09366938975290395, 0.06838516055722721, 0.0628172792494297, 0.08451323927147314, 0.019612180039985105, 0.12568839389132336, 0.06229617283679545, 0.04184129895293154, 0.06359419654472731, 0.02951667698653182, 0.16272316599497572, 2.0226611522957683, 0.5406881275121123, 0.3221085376571864, 0.2789075573673472, 0.1471550451242365, 0.21273753693094477, 0.23464969941414893, 0.22408769116736948, 0.062295868556248024, 0.05979135763482191, 0.09484161200816743, 0.17109934153268114, 0.25666289788205177, 0.47273785807192326, 0.6330513744615018, 1.365411845035851, 3.6399880796670914, 4.813197450712323, 8.497467879205942, 13.014955222606659, 12.188069242984056, 11.023642625659704, 25.208835303783417, 26.335818730294704, 34.7230763733387, 36.76099821925163, 49.389780163764954, 57.647660449147224, 58.568077459931374, 58.67979906499386, 50.02218022942543, 47.014257833361626, 46.30982503294945, 59.03790324926376, 63.2158512622118, 61.439324989914894, 52.5115330517292, 53.78755398094654, 53.9846646040678, 54.30495321750641, 61.74652710556984, 78.42126354575157, 85.88884323835373, 65.17517432570457, 27.49168250709772, 4.0074701607227325, 1.9823005492798984, 2.0685959374532104, 1.4428306720219553, 1.126221448648721, 1.6649272106587887, 1.0542322928085923, 1.3007250661030412, 0.505182595225051, 0.5648190889041871, 0.4501047288067639, 0.34006278205197304, 0.27934681973420084, 0.4418840480502695, 0.4351763689192012, 0.47506199742201716, 0.11022432954632677, 0.3107472660485655, 0.3489617264131084, 0.31307223660405725, 0.1589543916634284, 0.2943173929816112, 0.3234101162524894, 0.2558115654392168, 0.23135003662901, 0.19942680664826185, 0.20191751362290233, 0.33941194822546095, 0.2395273611182347, 0.20368676399812102, 0.1930513425031677, 0.1805597502971068, 0.23655918601434678, 0.2690145210362971, 0.1382679009111598, 0.17747882811818272, 0.0869095599045977, 0.11693447260768153, 0.08662387757794932, 0.06001741952786688, 0.2103408006951213, 0.18842224089894444, 0.27783942874521017, 0.22458736435510218, 0.2542380936210975, 0.2728959236992523, 0.2219798433361575, 0.36994046007748693, 0.33945282571949065, 0.3502928128000349, 0.16995063051581383, 0.26328603154979646, 0.28993955289479345, 0.5460810475051403, 0.6361292686779052, 0.45203567831777036, 0.4038195015164092, 0.44537617941387, 0.36359414749313146, 0.2087685459991917, 0.15767473611049354, 0.3016382938949391, 0.17091980116674677, 0.2761386934434995, 0.19139703596010804, 0.23273626458831131, 0.42240837123245, 0.3911707818042487, 0.19866166723659262, 0.5088881682604551, 0.16367836942663416, 0.1936399398255162, 0.23216905596200377, 0.5187354586087167, 0.5270225170534104, 0.5806246970314533, 0.5912207253277302, 0.9426322812214494, 0.27100332838017493, 1.1182608758099377, 0.5272784095723182, 2.203198252245784, 3.655597879551351, 19.40892342478037, 97.06706061959267, 120.12023359537125, 105.18807604908943, 94.17826563119888, 81.47575244307518, 65.08555233478546, 60.22986888885498, 88.9613127708435, 104.41815376281738, 109.60742130875587, 111.21672615408897, 98.95794555544853, 104.87320214509964, 109.87591490149498, 109.2700070142746, 102.97082662582397, 116.21687784790993, 104.40177664160728, 92.84714385867119, 99.71692442893982, 92.56023645401001, 92.11810737848282, 92.73150086402893, 71.99422761797905, 53.252345100045204, 33.930777087807655, 24.39842998981476, 16.109923347830772, 12.910581473261118, 17.33442284166813, 9.493160750716925, 5.7052019611001015, 2.8756659803912044, 2.1645956486463547, 0.3262750734575093, 0.3261200536508113, 0.13672202214365825, 0.15823584428289905, 0.19720778509508818, 0.17467296071117744, 0.09419557987712324, 0.22648977086646482, 0.2190373168559745, 0.11207382834982127, 0.19842478854116052, 0.3907798184081912, 1.0419420897960663, 2.6670559868216515, 0.563885704614222, 0.5808010313194245, 0.37721519940532744, 0.32864481036085635, 0.43095734843518585, 0.5794687871821225, 0.5012449971400201, 0.21294784673955292, 0.19793221028521657, 0.2250724023906514, 0.2248629237874411, 0.2522014919668436, 0.6565220619086176, 3.410245757550001, 4.457419691607356, 11.21919248253107, 14.32462714612484, 13.577434290200472, 19.523251689970493, 20.479686968028545, 21.410182937979698, 32.4378751963377, 34.09995540976524, 42.327334731817245, 45.643504187464714, 54.207948222756386, 52.452795803546906, 48.92904728651047, 52.70865507423878, 51.48640125989914, 57.35543712973595, 67.99170479178429, 75.85712313652039, 73.46993923187256, 63.38817201554775, 60.214247927069664, 63.01168441772461, 67.65238299965858, 73.3985486626625, 92.4471241235733, 103.3864027261734, 101.7514568567276, 56.819726675748825, 17.202549017965794, 1.7098982725292444, 1.397105825599283, 2.1126346243545413, 0.8019692322704941, 1.4192718174308538, 1.6796092665754259, 0.8143259317148477, 1.1396021931432188, 0.39007406565360725, 0.6973733135964721, 0.3741446079220623, 0.4683918709633872, 0.32925764622632414, 0.523817982757464, 0.3835528437048197, 0.39830326626542956, 0.33740022336132824, 0.5281140678562224, 0.4682807862991467, 0.4699654912110418, 0.3473773004952818, 0.34242013993207365, 0.5044771987013519, 0.3668536007171497, 0.24768763105385005, 0.2801238186657429, 0.5012689833529294, 0.501064684940502, 0.5128327128477395, 0.22973408427787945, 0.3631400124868378, 0.1939448734628968, 0.289158308878541, 0.2790360676590353, 0.24196093756472692, 0.2908778650453314, 0.17054163239663467, 0.28507973242085427, 0.15222631831420586, 0.1378233396098949], [0.12492556998040527, 0.045835237178835087, 0.10900862485868856, 0.10992127354256809, 0.07429779914673418, 0.12713112897472456, 0.22617996874032542, 0.06562446025782265, 0.08822236719424836, 0.10729907284257933, 0.1552936591906473, 0.17493625986389816, 0.23767362465150654, 0.2785047789802775, 0.22051546722650528, 0.24819292972097173, 0.18902004085248336, 0.08430794638115913, 0.2196949190692976, 0.3229400992859155, 0.26759529719129205, 0.058573916321620345, 0.10365387352067046, 0.06831797392806038, 0.0988478290673811, 0.05622210599540267, 0.1385360091808252, 0.11064144622650929, 0.26686095690820366, 0.18273014633450657, 0.1792418147670105, 0.15675511123845354, 0.07125687130610459, 0.23406990396324545, 0.29369930271059275, 0.591143601341173, 1.2586683291010559, 0.6812524411361665, 1.2283267197199166, 0.5956822203006595, 0.8916782622691244, 0.8506028226111084, 1.389427506364882, 4.541666870936751, 0.9787524305284023, 15.995885767042637, 57.63864353299141, 80.90299397706985, 68.68326008319855, 71.26974329352379, 66.66214093565941, 43.24074871838093, 38.50172281265259, 36.361772641539574, 48.840721026062965, 67.1062383055687, 73.29029247164726, 75.6561367213726, 68.06561082601547, 63.023076206445694, 64.00986805558205, 60.81099450588226, 53.43285821378231, 46.98545917868614, 33.30785371363163, 27.633654288947582, 23.470916859805584, 22.21493985503912, 17.889850437641144, 14.15494630113244, 9.203002620488405, 5.5601827427744865, 3.3221933199092746, 9.65932298451662, 13.528784550726414, 5.828138189390302, 2.012385316193104, 1.2253841338679194, 0.16774838150013238, 0.20933900523232296, 0.11449322977568954, 0.22424554597819224, 0.09574349212925881, 0.2108245325507596, 0.3510494768852368, 0.18063682975480333, 0.3008348448202014, 0.2980925497831777, 0.2977773151360452, 0.44364688626956195, 0.3017816471401602, 0.5610545596573502, 0.06732521782396361, 0.2724848926300183, 0.5116424860898405, 0.18413262732792646, 0.2207801170879975, 0.19150246545905247, 0.3003598703071475, 0.16553066612686962, 0.22336721420288086, 0.6289812584873289, 0.6593594409059733, 0.8528929122257978, 0.14228202926460654, 1.0914881061762571, 4.804222332313657, 9.756944496184587, 17.48412910848856, 36.698100194334984, 39.65434156358242, 28.64335510879755, 9.287592731416225, 7.726755710318685, 3.474818067625165, 3.6404708912596107, 3.4246890200302005, 1.918315663933754, 4.19417979195714, 6.561340671032667, 8.434834890067577, 15.213911477476358, 21.19921635836363, 25.306778848171234, 23.59132669866085, 13.279477078467607, 17.13837806135416, 33.23890261352062, 45.74794918298721, 58.90771083533764, 63.2652448117733, 54.639099687337875, 34.41769815981388, 15.07062591612339, 3.8032866921275854, 1.45053677726537, 1.6201419825665653, 1.0609043785370886, 0.7854688551742584, 1.7321811080910265, 1.1708428105339408, 0.9903700102586299, 1.0532107413746417, 0.6677490938454866, 0.7052603247575462, 0.35737153608351946, 0.2730195951880887, 0.2572122949641198, 0.43306074338033795, 0.36666453117504716, 0.24589218286564574, 0.04966011045326013, 0.1906074650469236, 0.12034424784360453, 0.4374402458779514, 0.27698058576788753, 0.39887374034151435, 0.47956858528777957, 0.5422153486870229, 0.37175239878706634, 0.26701805472839624, 0.28070631553418934, 0.4023018985753879, 0.3508674429031089, 0.2227447007317096, 0.15525613620411605, 0.07129048317437991, 0.16082993242889643, 0.19912648916943, 0.17289254843490198, 0.18732929485850036, 0.13825623434968293, 0.14869238919345662, 0.2251690300181508, 0.11499823158374056, 0.1200368873833213, 0.02224038657004712, 0.10151815804420039, 0.10207234197878279, 0.04967896471498534, 0.12302317831199616, 0.24444901733659208, 0.3070183302043006, 0.08318242005771026, 0.13217316154623404, 0.1502059103222564, 0.16968418465694413, 0.2669040608452633, 0.16822451376356184, 0.3292852541198954, 0.1578309730393812, 0.2402023147442378, 0.2025013612001203, 0.19264345814008266, 0.26666256599128246, 0.17220907495357096, 0.1927894979598932, 0.13519509782781824, 0.11980299954302609, 0.12859485199442133, 0.09168216318357736, 0.0693908374523744, 0.08361647996935062, 0.16591168474406004, 0.2667830017162487, 0.24451132805552334, 0.2616182476049289, 0.15282776963431388, 0.18646542011993006, 0.3912929689977318, 0.4003953211940825, 0.7474201312288642, 0.9934767591767013, 0.7120754371862859, 0.6140433100517839, 0.46207180072087795, 0.8533927635289729, 0.6272739032283425, 2.4948086170479655, 6.237815581262112, 3.9601004775613546, 49.89528223872185, 91.62789568305016, 98.9594654738903, 82.17803835868835, 64.42668288946152, 61.03265181183815, 63.80543902516365, 66.27275303006172, 65.87654829025269, 77.18244642019272, 80.64907640218735, 93.84003058075905, 87.84314677119255, 80.28494194149971, 86.09283149242401, 93.09483736753464, 92.3171178996563, 91.56427189707756, 85.11288687586784, 71.08263373374939, 59.77384775876999, 54.11755487322807, 45.576874762773514, 35.08297026157379, 27.799156308174133, 22.253448888659477, 14.412173498421907, 12.170775420963764, 18.40253982692957, 12.374714277684689, 5.484710717573762, 1.77757834084332, 1.1705725500360131, 0.1251183354179375, 0.26070507941767573, 0.12820382922654971, 0.2426503482274711, 0.11512626690091565, 0.2219835837604478, 0.23851499747252092, 0.1084616026491858, 0.07699330177274533, 0.09253072741557844, 0.05849941211636178, 0.21479987626662478, 0.19130168482661247, 2.1916010370478034, 0.19391741399886087, 0.11603527906117961, 0.49366006976924837, 0.26293986418750137, 0.21647805027896538, 0.13845293316990137, 0.2317857218440622, 0.2735757309710607, 0.26343443139921874, 0.31588266079779714, 0.8058764319866896, 0.2547293360112235, 0.20112101105041802, 1.8978858226910233, 4.133083820343018, 10.205432530492544, 13.527457471936941, 23.01869362592697, 26.12637396901846, 23.69100484997034, 14.895442966371775, 12.328523006290197, 14.523238688707352, 21.566799134016037, 23.156871311366558, 29.06664479523897, 30.517893321812153, 29.87330351024866, 30.289977751672268, 30.430969186127186, 37.29672387242317, 49.339178279042244, 52.32480727136135, 46.546198949217796, 48.40335309505463, 56.77077770233154, 60.677959844470024, 68.16199645400047, 75.38844868540764, 76.85687229037285, 58.556092903018, 31.239275112748146, 7.935709822922945, 2.14712489861995, 1.5363403293304145, 1.94202532293275, 0.8959903183858842, 1.4964254898950458, 1.2111493851989508, 1.1951027275063097, 0.9716932999435812, 0.6154430599417537, 0.6751982378773391, 0.4514008155092597, 0.3797069750726223, 0.22689398902002722, 0.3824080660706386, 0.34488074539694935, 0.2939199283719063, 0.13917664589826018, 0.3290083142928779, 0.214363033301197, 0.4371017374796793, 0.31001672556158155, 0.4737796849803999, 0.49988217651844025, 0.41812463547103107, 0.36868940689601004, 0.40596792998258024, 0.30958524090237916, 0.38064383261371404, 0.19507489720126614, 0.19685728359036148, 0.1918384653981775, 0.1333303627325222, 0.17826220951974392, 0.27760609751567245, 0.34283755347132683, 0.3459670417942107, 0.16298927046591416, 0.22842931444756687, 0.13521678338292986, 0.15380350087070838, 0.13103550852974877, 0.28190057957544923, 0.2389156533172354, 0.22208071604836732, 0.22743578650988638, 0.1973412380903028, 0.38729730527848005, 0.502952589886263, 0.2038880789768882, 0.15234516584314406, 0.23269134981092066, 0.24842102138791233, 0.5350683478172868, 0.3214601083891466, 0.4334314609877765, 0.3427675541024655, 0.2895729913143441, 0.38689610024448484, 0.3003035264555365, 0.36557823477778584, 0.39866875915322453, 0.44356928730849177, 0.3215171943884343, 0.21894356876146048, 0.2326268720207736, 0.17341041908366606, 0.1375557211576961, 0.3163345099892467, 0.29924290836788714, 0.5718401027843356, 0.4239919065730646, 0.3116891998797655, 0.32625604479108006, 0.2440449030837044, 0.31368774420116097, 0.3517207346158102, 0.6990576325915754, 1.4178911852650344, 0.6010392203461379, 1.0488596186041832, 0.4039980919333175, 1.276779226027429, 0.6498128094244748, 1.2767284037545323, 5.275132013484836, 0.5555139819625765, 33.6186808347702, 102.09501162171364, 117.05081149935722, 97.68610820174217, 91.41941606998444, 89.24293085932732, 64.59280997514725, 60.716360583901405, 60.617094710469246, 74.20637771487236, 91.78696274757385, 106.56794160604477, 103.64912062883377, 93.6565688252449, 97.2546337544918, 103.05430054664612, 112.3291164636612, 106.84557750821114, 98.37985217571259, 86.51536881923676, 78.5072909295559, 61.10452875494957, 50.79316645860672, 45.12603275477886, 41.22110389173031, 32.6830380409956, 24.813905395567417, 18.179923072457314, 22.31226023286581, 17.99681279808283, 12.592908069491386, 9.402775950729847, 2.8804807970300317, 0.3180220350623131, 1.247512602712959, 0.22753950906917453, 0.7290691940579563, 0.34072394657414407, 0.6241805129684508, 0.5419265641830862, 0.3867310762871057, 0.48721707018557936, 0.6453445460647345, 0.42203688179142773, 0.6622521544340998, 0.6473526195622981, 2.728018253110349, 0.1608156386646442, 0.3488992672646418, 0.7848306675441563, 0.34149316779803485, 0.2527620509499684, 0.3297216072678566, 0.35623842501081526, 0.31638378859497607, 0.5682004918344319, 0.602753225248307, 1.7094237729907036, 1.2175342300906777, 0.3397043247241527, 0.9306523553095758, 4.397492157295346, 10.793732162564993, 21.023462489247322, 38.72313313186169, 38.52869376540184, 36.98477581143379, 35.5120812356472, 31.55856627970934, 29.875860773026943, 32.43708483874798, 35.83738178014755, 35.16320675611496, 39.02891032397747, 45.14865294098854, 51.94452367722988, 59.965878054499626, 63.90511527657509, 59.24273505806923, 60.49470707774162, 51.17186173796654, 56.04061648249626, 73.31573590636253, 79.86780792474747, 91.28008514642715, 94.34636101126671, 84.99830782413483, 49.09730605781078, 18.302489295601845, 3.05023692548275, 1.0226456564851105, 1.7346444446593523, 1.4409680594690144, 0.5576066602952778, 1.7846524924971163, 0.9108882502187043, 0.9427645616233349, 0.8790510054677725, 0.5434306897222996, 0.68931317422539, 0.5276362434960902, 0.37048489961307496, 0.2484219119651243, 0.32045951520558447, 0.324123824830167, 0.2860588923795149, 0.23155381553806365, 0.2805914607597515, 0.28687944053672254, 0.6085236312355846, 0.4037046170560643, 0.5303764308337122, 0.6357401458080858, 0.46038136642891914, 0.4256305983290076, 0.40504956676159054, 0.45550130016636103, 0.6593197805341333, 0.4506290116114542, 0.34819241613149643, 0.24706056079594418, 0.33778596203774214, 0.30599986610468477, 0.3134987340308726, 0.3484150010626763, 0.39708911266643554, 0.32714258471969515, 0.24105949531076476, 0.34510261786635965, 0.21613388671539724, 0.3002859227126464], [0.2903935097856447, 0.1787337553105317, 0.05347184029233176, 0.08030092038097791, 0.13524874026188627, 0.04456206428585574, 0.10640255102771334, 0.12357656814856455, 0.15176219400018454, 0.18395500170299783, 0.23157352698035538, 0.34963060927111655, 0.21134004316991195, 0.4027679970022291, 0.07911539883934893, 0.275353827746585, 0.19036288285860792, 0.19895831850590184, 0.1539927039993927, 0.17341942875646055, 0.2970179496333003, 0.33200047560967505, 0.244714439031668, 0.08377103964448906, 0.0953136030875612, 0.16747813584515825, 0.0633540004491806, 0.02702162844798295, 0.1760364492656663, 0.20213528943713754, 0.204805581306573, 0.1375523369642906, 0.27599958528298885, 0.29014560277573764, 0.2158949596923776, 0.3491528145968914, 0.47890314599499106, 0.6989635282661766, 0.7632489537354559, 1.5928315417841077, 0.8634765318129212, 1.4620695146732032, 1.1997567652724683, 0.760527765378356, 2.1871666749939322, 4.215319007635117, 1.3454531785100698, 17.18880705535412, 56.12309865653515, 79.07233580946922, 86.07286736369133, 74.21036750078201, 71.36352226138115, 56.446662694215775, 48.54686759412289, 51.67868234217167, 51.16988964378834, 54.27910700440407, 46.966672986745834, 51.42129935324192, 44.78630818426609, 29.820224158465862, 22.993603572249413, 20.971956253051758, 23.812159448862076, 26.24505490064621, 20.29559064656496, 18.963249139487743, 15.726230386644602, 15.832390040159225, 12.806863188743591, 12.124962229281664, 7.95923768542707, 17.206535004079342, 23.35281729698181, 26.310580484569073, 12.520511504262686, 3.3807593397796154, 0.3014575660927221, 0.7484228617977351, 0.6402741931378841, 0.25725617073476315, 0.1207210733264219, 0.060099927795818076, 0.00718742611752532, 0.08888033305993304, 0.10179490491282195, 0.14960048109060153, 0.10701981751481071, 0.1817948473035358, 0.2591462427517399, 0.8840061177033931, 0.38803695933893323, 0.472006278578192, 0.4459596856031567, 0.5140283424407244, 0.34216297091916203, 0.14343492599437013, 0.12191498855827376, 0.3527661832049489, 0.5793318164069206, 0.39217553101480007, 1.1194428498856723, 1.7036235029809177, 2.1689789509400725, 4.939979547634721, 10.608813185244799, 14.980331361293793, 23.03423099219799, 31.53274856507778, 34.67866815626621, 22.388248555362225, 6.5216404013335705, 5.105067389085889, 6.206944137811661, 2.75213033426553, 6.352554699406028, 7.528358856216073, 2.1350557962432504, 6.106755863875151, 16.681247390806675, 15.577064640820026, 13.4821449033916, 9.923730846494436, 14.828199874609709, 29.973532631993294, 41.42703004181385, 38.97900000214577, 57.190628573298454, 57.820596769452095, 36.29165880382061, 7.067767521366477, 2.938245297409594, 0.9567910339683294, 1.0734988027252257, 0.7345325290225446, 0.46679687686264515, 0.7225317042320967, 0.9594024438410997, 0.6871996563859284, 0.5901060195174068, 0.6792096351273358, 0.3045301465317607, 0.3482665418414399, 0.37308407889213413, 0.4225410078652203, 0.2393536688759923, 0.1934982044622302, 0.170682625612244, 0.10734942756243981, 0.10425192580441944, 0.08198054900276475, 0.22223111969651654, 0.16323327377904207, 0.24444745882647112, 0.3846653230721131, 0.41282353398855776, 0.5525382666382939, 0.14100425876677036, 0.15043453633552417, 0.4169052868383005, 0.2374590400722809, 0.11528999952133745, 0.2560456091305241, 0.3148150962078944, 0.3957464487757534, 0.3337035560980439, 0.2821057091932744, 0.22623513999860734, 0.22371856175595894, 0.2658855076879263, 0.14307728502899408, 0.25505884957965463, 0.3459307656157762, 0.2804759528953582, 0.30341671721544117, 0.20409162039868534, 0.14861223724437878, 0.09156677406281233, 0.06548075078171678, 0.1492541652987711, 0.21665782813215628, 0.16348493605619296, 0.17730538820615038, 0.016370484554499853, 0.19679757038829848, 0.264289058977738, 0.4480396583676338, 0.1582812043488957, 0.35205372143536806, 0.08691113325767219, 0.26022894715424627, 0.18336057109991089, 0.2513443410862237, 0.09602850652299821, 0.24852573842508718, 0.30483980022836477, 0.1858272176468745, 0.09938354094629176, 0.16637723398162052, 0.12264386663446203, 0.075947905133944, 0.058830090856645256, 0.06959034901228733, 0.24771137977950275, 0.2840626041870564, 0.4108686279505491, 0.21928883070359007, 0.2463688049465418, 0.2568805549526587, 0.24581970472354442, 0.40900298743508756, 0.8401694137137383, 0.8452033123467118, 0.8226435072720051, 1.1809119139797986, 0.633409267757088, 1.146052940748632, 0.6813888775650412, 1.5858682966791093, 3.6110523948445916, 5.550695601850748, 6.9700519647449255, 54.626537561416626, 84.03811454772949, 93.09922993183136, 88.73134151101112, 70.5626468360424, 63.881761729717255, 56.45813047885895, 64.97300997376442, 81.39815300703049, 79.93615105748177, 86.72491237521172, 79.16408568620682, 74.99887079000473, 73.94686684012413, 74.37987640500069, 70.02908706665039, 72.24727883934975, 64.78469207882881, 58.43997113406658, 43.83947879076004, 36.63967452943325, 35.32523386180401, 30.80295592546463, 21.58765621483326, 15.655918959528208, 6.494308467954397, 21.10827773809433, 18.430189043283463, 11.84017701074481, 8.206460494548082, 3.1738917902112007, 0.3891069581732154, 1.189455280546099, 0.4693440464325249, 0.11721411385224201, 0.1146160923235584, 0.12451801216229796, 0.10521694784983993, 0.16016841167584062, 0.10682899650419131, 0.4410445305984467, 0.10723558953031898, 0.18625319557031617, 0.12068081181496382, 0.9737211442552507, 0.4133891692617908, 0.3364478697767481, 1.4912316435948014, 0.4789519793121144, 0.15824120258912444, 0.2518606383819133, 0.132123111106921, 0.158753878204152, 0.8112068334594369, 0.9387041826266795, 2.244985797442496, 1.6029145382344723, 0.9719420084729791, 2.446531495079398, 9.409438893198967, 16.069470718503, 23.32763034850359, 40.80555438995361, 46.18016459047794, 37.414232566952705, 15.650053974241018, 8.320647217333317, 9.008493907749653, 11.838350258767605, 13.379014637321234, 13.78948476165533, 13.601688388735056, 14.83988044783473, 24.011777937412262, 31.75780288875103, 35.09638354182243, 35.972931906580925, 45.19497625529766, 38.89980845153332, 48.746873661875725, 60.765985921025276, 71.83576092123985, 73.26069205999374, 56.803596541285515, 21.43202606588602, 6.683331225067377, 1.601369446143508, 0.9043028473388404, 1.0845070495270193, 0.81699053873308, 0.7434322452172637, 0.9132220374885947, 0.9638655418530107, 0.5520099762361497, 0.8072204317431897, 0.4398874333128333, 0.4036533791804686, 0.4232479480560869, 0.36253287631552666, 0.2655223599867895, 0.17508868215372786, 0.16514702030690387, 0.1457081688567996, 0.14301881863502786, 0.01983338086574804, 0.1094425586052239, 0.22518557991134003, 0.2412949045537971, 0.3374250407796353, 0.4419765790225938, 0.47329823893960565, 0.23358439095318317, 0.10434594107209705, 0.2651366509962827, 0.38062548672314733, 0.12848997168475762, 0.309213810833171, 0.33841557044070214, 0.34905520733445883, 0.2938432793598622, 0.2137394659803249, 0.16132000222569332, 0.3780593181727454, 0.30988854181487113, 0.15589168178848922, 0.19481121213175356, 0.2029310498619452, 0.28812040050979704, 0.21068325731903315, 0.37026703474111855, 0.3095692995702848, 0.26041866978630424, 0.20523399347439408, 0.2050251976470463, 0.367193118436262, 0.2457634944585152, 0.17241646070033312, 0.19379954610485584, 0.34144801553338766, 0.3392590954899788, 0.5446134356316179, 0.37046456476673484, 0.3916212357580662, 0.14319264446385205, 0.294480457669124, 0.2591593936085701, 0.22040160692995414, 0.19176304835127667, 0.45863271807320416, 0.4164015466812998, 0.5022823414765298, 0.49837662605568767, 0.19551160658011213, 0.25424465420655906, 0.2371568523813039, 0.10327833195333369, 0.19779653084697202, 0.3239216934889555, 0.34476752334740013, 0.43572086782660335, 0.3140142001211643, 0.5317251803353429, 0.39623006188776344, 0.2329962092335336, 0.44521931908093393, 0.5308557394891977, 0.7183510973118246, 0.50696054357104, 1.2916111364029348, 0.43720780522562563, 1.4043318503536284, 0.6525847606826574, 0.6219122721813619, 3.0331981647759676, 3.87478721793741, 1.3629404339008033, 43.24399374425411, 98.38403955101967, 112.07057073712349, 113.68462532758713, 96.82684510946274, 96.8759460747242, 80.78656822443008, 75.98297238349915, 83.52474689483643, 80.87011814117432, 87.93159082531929, 79.24977108836174, 80.90590462088585, 78.86232107877731, 77.3626783490181, 74.59385812282562, 79.34918895363808, 76.90666481852531, 77.0865547657013, 58.22577282786369, 45.687315836548805, 46.544576436281204, 44.57424536347389, 38.33990469574928, 38.776356875896454, 40.465875416994095, 45.46659708023071, 39.1134861856699, 36.48016668856144, 19.94498535990715, 7.493649618700147, 0.4602132848231122, 1.4165130467154086, 1.0033301054500043, 0.35795896081253886, 0.128998520958703, 0.17976112518226728, 0.1576652069343254, 0.28217582730576396, 0.19812307582469657, 0.29616729996632785, 0.18483710358850658, 0.3725442703580484, 0.2748360758414492, 2.6349747832864523, 0.5460622266400605, 0.7454313535708934, 1.959491204470396, 0.5264694092329592, 0.3884426469448954, 0.3539775760145858, 0.1588314920081757, 0.27101190760731697, 0.9564497054088861, 2.0058233058080077, 3.728711656294763, 2.4940861808136106, 2.8373447991907597, 6.4654304925352335, 13.260036371648312, 21.171035170555115, 29.35417916625738, 40.33403389155865, 49.70872364938259, 48.57993721961975, 39.254192635416985, 34.0381745249033, 26.50049429386854, 30.81958383321762, 33.57998751103878, 31.236299872398376, 42.68679924309254, 50.92856079339981, 54.097507148981094, 45.3768914937973, 42.577403113245964, 42.85525560379028, 57.96454444527626, 65.76537385582924, 76.73650234937668, 74.14524659514427, 85.14129415154457, 76.40582129359245, 48.18928398191929, 10.566581301391125, 2.49805293045938, 0.6599877728149295, 0.8032936987001449, 1.0611297539435327, 0.5911894363816828, 0.7707835338078439, 1.3684627250768244, 0.5637418467085809, 0.46351904806215316, 0.7444429316092283, 0.4283719731029123, 0.3193306195316836, 0.35476202610880136, 0.45748325006570667, 0.3148363810032606, 0.24897671188227832, 0.20492353825829923, 0.1508548145648092, 0.1647396554471925, 0.18543754558777437, 0.2881385385990143, 0.20429376658285037, 0.3331567416898906, 0.4408524034079164, 0.4616182891186327, 0.4753669013734907, 0.1944046191056259, 0.17603210028028116, 0.4276011191541329, 0.4370112845208496, 0.10100335988681763, 0.39844261191319674, 0.43938102142419666, 0.4809698194731027, 0.5848823091946542, 0.3252777160378173, 0.29509290761779994, 0.339045564760454, 0.4101274302229285, 0.2512213820591569, 0.2857896708883345, 0.4413712240057066, 0.5015499901492149, 0.37496741220820695], [0.18698501255130395, 0.23054652818245813, 0.10395372344646603, 0.07325917089474387, 0.1598843323881738, 0.07309816937777214, 0.10115293975104578, 0.18803899583872408, 0.15631659101927653, 0.20950854144757614, 0.21108063287101686, 0.16286427795421332, 0.030570649141736794, 0.1821665742318146, 0.09722858158056624, 0.11535106343217194, 0.2292088366812095, 0.08591571284341626, 0.132935703441035, 0.0998753918975126, 0.10066312970593572, 0.16698836290743202, 0.14671919663669541, 0.2004731458146125, 0.2466200219350867, 0.16814541566418484, 0.061269856814760715, 0.0577159824752016, 0.11770277356845327, 0.08160192010109313, 0.06732585607096553, 0.11861111037433147, 0.21393634291598573, 0.3631304536247626, 0.199272291501984, 0.12923324742587283, 0.16295934707159176, 0.1841963332844898, 0.6203196826390922, 0.5439162324182689, 1.290039208251983, 0.9331541054416448, 1.1797726876102388, 1.403172912541777, 0.6464118731673807, 0.3899973869556561, 1.5013266331516206, 2.3567083524540067, 1.3870507339015603, 12.60964997112751, 48.07848572731018, 66.89686954021454, 61.630131751298904, 62.2984778881073, 61.90615274012089, 65.91190919280052, 67.56637081503868, 53.079727962613106, 41.28140665590763, 37.11602456867695, 33.566657826304436, 31.590796150267124, 37.493355721235275, 36.57088302075863, 32.6264438778162, 22.369555458426476, 9.506296645849943, 3.964109024964273, 10.927311144769192, 9.751489888876677, 10.379106011241674, 14.799186531454325, 17.326802350580692, 17.755520045757294, 42.66199417412281, 47.668320536613464, 18.265737667679787, 2.0915443310514092, 1.0964543209411204, 0.9932865912560374, 0.943144066259265, 0.6279467639978975, 0.6711030669976026, 0.6213450338691473, 0.6254462013021111, 0.2097059675725177, 0.25997168908361346, 0.327039307449013, 0.2367703864001669, 0.2329244583961554, 0.14372679783264175, 0.5606522562447935, 0.12897975946543738, 0.11593917093705386, 0.15989237726898864, 0.24259471683762968, 0.11501673332531936, 1.3480476080439985, 1.0085685993544757, 0.6727033155038953, 0.4475793190067634, 1.4433819986879826, 0.3943287389120087, 3.0825318675488234, 7.230578809976578, 11.05771254748106, 11.323244199156761, 11.931619103997946, 15.855954475700855, 20.68224459886551, 23.03338173776865, 15.020764991641045, 11.337753720581532, 9.651907682418823, 7.223950540646911, 9.831341654062271, 10.690612345933914, 15.919957291334867, 16.223263666033745, 16.42436597496271, 14.31819124147296, 8.32334317266941, 7.118627792224288, 23.362708166241646, 33.83435346186161, 34.47303079068661, 52.38555461168289, 45.01920148730278, 24.98140800744295, 9.596963580697775, 1.2675254163332283, 0.8619215246289968, 0.8134989417158067, 0.6505879678297788, 0.4545113642234355, 0.42539070651400834, 0.37249368557240814, 0.29206841834820807, 0.2830067655304447, 0.31084769347216934, 0.21965767809888348, 0.2280612091999501, 0.19293476594612002, 0.22510179143864661, 0.2697979024378583, 0.07397934357868508, 0.14044472394743934, 0.12169731664471328, 0.1128547012922354, 0.09978141373721883, 0.01882878008473199, 0.07565300533315167, 0.0887516001239419, 0.036649345129262656, 0.09257595389499329, 0.15768033190397546, 0.13803210575133562, 0.1597219950053841, 0.13267473463201895, 0.049943013436859474, 0.17086835548980162, 0.17223344708327204, 0.1630621642107144, 0.06375133147230372, 0.21297233761288226, 0.2644417335977778, 0.25544690375681967, 0.33383147267159075, 0.1756822518655099, 0.1436910856864415, 0.12108052513212897, 0.21368816873291507, 0.21163388912100345, 0.38227922923397273, 0.224467848893255, 0.24456072540488094, 0.1839024873333983, 0.2620407671201974, 0.19812127982731909, 0.1759474806021899, 0.15088687534444034, 0.050842771015595645, 0.1770407977164723, 0.18766550259897485, 0.24940573261119425, 0.19436166359810159, 0.1713825747719966, 0.28318301076069474, 0.2414407959440723, 0.217781038954854, 0.03279433694842737, 0.15028036257717758, 0.1656234049005434, 0.10252960884827189, 0.13711957581108436, 0.22870083659654483, 0.2611125778639689, 0.2505235554417595, 0.2009107160847634, 0.26631319255102426, 0.19447012105956674, 0.11869372625369579, 0.028448051125451457, 0.0941362525918521, 0.16289271705318242, 0.2554176631383598, 0.20044439501361921, 0.13477854517986998, 0.26837179146241397, 0.28907937405165285, 0.10940183696220629, 0.14228844142053276, 0.17775474378140643, 0.3886359615717083, 0.8306701015681028, 0.7457872875966132, 1.4177627046592534, 1.000370301771909, 1.2919687922112644, 0.8494454284664243, 0.7105630589649081, 1.6643433482386172, 2.039105244912207, 5.045885564759374, 10.070113241672516, 50.69101274013519, 80.06219029426575, 92.65312626957893, 86.39505207538605, 81.31059050559998, 73.11121568083763, 66.81015059351921, 72.16068148612976, 74.18786510825157, 69.23447370529175, 71.58902496099472, 67.91547328233719, 47.91310340166092, 46.77417151629925, 48.411788642406464, 47.26623371243477, 42.248013988137245, 34.11903038620949, 29.301958568394184, 23.021991848945618, 23.50792497396469, 20.38049329072237, 21.87412664294243, 20.326386094093323, 36.0203305631876, 47.44168929755688, 48.21360647678375, 26.65730617940426, 6.730133313685656, 1.5868284576572478, 1.0032759583555162, 1.0281574982218444, 0.3509032737929374, 0.21821515081683174, 0.1601929173921235, 0.10298772918758914, 0.24437919608317316, 0.2696428826311603, 0.34679881122428924, 0.18984446302056313, 0.12719495367491618, 0.5926318152341992, 1.5711626107804477, 0.11250799958361313, 0.3022345947101712, 0.432913382537663, 0.9260348312091082, 0.8529933693353087, 1.3712651934474707, 1.20520448544994, 2.520894929766655, 1.9583690771833062, 3.098217900842428, 3.430615752004087, 3.4889302728697658, 5.91651052236557, 9.933972246944904, 14.323900435119867, 18.250413089990616, 23.4317409619689, 32.90441416203976, 39.32651035487652, 33.857577815651894, 19.123477041721344, 18.10338567942381, 17.18401361256838, 15.507481824606657, 13.731064796447754, 10.861416030675173, 17.78332505375147, 24.737797379493713, 32.35166162252426, 30.696179755032063, 30.466797463595867, 32.207755744457245, 38.837009221315384, 57.96065345406532, 68.9724625647068, 62.03786127269268, 47.17257633805275, 23.62047303467989, 5.834779758006334, 1.3514057965949178, 0.934497689595446, 0.6998890161048621, 0.5995217361487448, 0.564013235270977, 0.6182147737126797, 0.5542602273635566, 0.3467191936215386, 0.3942369797732681, 0.358421437558718, 0.313840092276223, 0.41237500961869955, 0.30082062527071685, 0.28867947519756854, 0.22768094757338986, 0.15129927196539938, 0.03314536908874288, 0.023464000696549192, 0.024074435714283027, 0.027334888982295524, 0.018932539751403965, 0.06256365028093569, 0.036276289756642655, 0.17860696680145338, 0.21208159712841734, 0.1996986850281246, 0.286899478523992, 0.15365121216746047, 0.02606035239296034, 0.20003392797661945, 0.14433516596909612, 0.1753112522419542, 0.18032251537078992, 0.33989769872277975, 0.3109567001229152, 0.3428802121197805, 0.39644216769374907, 0.22796875244239345, 0.11032021502614953, 0.13036294461926445, 0.18294671986950561, 0.15378126612631604, 0.34648681234102696, 0.22785386798204854, 0.24307038896949962, 0.37185911962296814, 0.3891625895630568, 0.2767418813891709, 0.2617047226522118, 0.32030312984716147, 0.1349477400071919, 0.3319860779447481, 0.27686908550094813, 0.26224129542242736, 0.22377493529347703, 0.5048449477180839, 0.31142291729338467, 0.26401185197755694, 0.2734970930032432, 0.13275077508296818, 0.23577286570798606, 0.26370727457106113, 0.17724864359479398, 0.2263327472610399, 0.23176696035079658, 0.28983387106563896, 0.4064213822130114, 0.4275551059981808, 0.3891839931020513, 0.2588779415236786, 0.25064120069146156, 0.16612570529105142, 0.2562019944889471, 0.2865080995252356, 0.3964675491442904, 0.34699381794780493, 0.27347755967639387, 0.34216184285469353, 0.59401577222161, 0.2647480327868834, 0.25330856849905103, 0.24868872889783233, 0.23266037256689742, 0.7674932666122913, 0.5371071759145707, 1.247144853696227, 0.593775138258934, 0.9584568883292377, 1.4730283641256392, 0.5629207938909531, 0.7517115853261203, 2.1472740406170487, 2.1092406939715147, 2.25527327042073, 33.901621252298355, 77.75107070803642, 102.65302687883377, 90.78491851687431, 88.59739109873772, 88.77377763390541, 88.37393268942833, 89.79494243860245, 80.05399033427238, 71.04892194271088, 70.80222398042679, 74.7743408381939, 63.188200145959854, 77.64106661081314, 84.4986954331398, 85.09879723191261, 69.48425710201263, 60.90632379055023, 50.654603093862534, 40.42537339031696, 36.344871148467064, 33.800151497125626, 47.56810091435909, 69.03530359268188, 72.91073843836784, 81.93221434950829, 74.55405905842781, 39.817926585674286, 10.056991595774889, 2.866832879371941, 1.2361298385076225, 2.508237808942795, 1.269850297830999, 0.7888944307342172, 0.997142968699336, 1.137056804727763, 0.5527314625214785, 0.6429015146568418, 0.6598800129722804, 0.6047041830606759, 0.44774262118153274, 0.6565543008036911, 3.9549543661996722, 0.8390253782272339, 0.48640064836945385, 2.57540846709162, 1.8647898361086845, 1.425903767812997, 2.908951719291508, 2.271805708296597, 4.763518441468477, 4.0290881507098675, 5.6038314756006, 5.134416539222002, 4.822878381237388, 8.766153361648321, 15.763841718435287, 19.369707629084587, 25.090950429439545, 31.65059734135866, 38.825674429535866, 45.042118057608604, 45.80509811639786, 38.14936392009258, 37.903258726000786, 41.801142767071724, 44.25793893635273, 51.46003447473049, 57.09207326173782, 56.710642129182816, 44.599441811442375, 43.98180775344372, 40.901590436697006, 48.29983524978161, 64.02665555477142, 70.53667142987251, 75.60789451003075, 84.43465366959572, 69.85334649682045, 36.02174408733845, 11.561280526220798, 1.5965528483502567, 0.6789506552740932, 0.6173594633582979, 0.9104068635497242, 0.617043130332604, 0.39462657761760056, 0.729921298334375, 0.4748935892712325, 0.44392240117304027, 0.5365496152080595, 0.3104396309936419, 0.27106489695142955, 0.31764754734467715, 0.3526447678450495, 0.38697637093719095, 0.3450764645822346, 0.14347431919304654, 0.19085586187429726, 0.19845061528030783, 0.15486869058804587, 0.2401928449398838, 0.15600255865138024, 0.22586780658457428, 0.12209156775497831, 0.255441649351269, 0.3370465157786384, 0.18316792440600693, 0.2497436769772321, 0.23308771604206413, 0.2503824880113825, 0.2469884091988206, 0.19870632968377322, 0.2863685163902119, 0.28181253117509186, 0.299626390915364, 0.35912618099246174, 0.35282380355056375, 0.43389500642661005, 0.3947238583350554, 0.25393773161340505, 0.2552837203256786, 0.33281437412369996, 0.3827822272432968, 0.3937261743703857, 0.43604904552921653, 0.2736698352964595], [0.06994997151196003, 0.19658409903058782, 0.10196490868111141, 0.12355805156403221, 0.0792131396883633, 0.08655516954604536, 0.028599653342098463, 0.1112064952030778, 0.07000624857028015, 0.19215220090700313, 0.13377559196669608, 0.0663389109831769, 0.09141637783613987, 0.08920102249248885, 0.09508361894404516, 0.08855957683408633, 0.030431793311436195, 0.10678705031750724, 0.1217960445501376, 0.011224910322198411, 0.03143480404105503, 0.13132951775332913, 0.022288028740149457, 0.02384948147664545, 0.21802195493364707, 0.17073500639526173, 0.07116251465049572, 0.19529630953911692, 0.14930250879842788, 0.07369340150034986, 0.17584479704964906, 0.12804854224668816, 0.021545784584304783, 0.04130314911890309, 0.14932190853869542, 0.14408255374291912, 0.15815346589079127, 0.07236028905026615, 0.06921850334038027, 0.2541223185835406, 0.11570586197194643, 0.3557585523230955, 0.6020615436136723, 0.8401835442055017, 0.7350482326000929, 0.49229407275561243, 0.20758676488185301, 0.28176794294267893, 0.5458982416894287, 0.6260471628047526, 0.04992500151274726, 3.9494114136323333, 26.364547088742256, 50.655051469802856, 53.07876281440258, 55.525747910141945, 52.44607016444206, 55.30128635466099, 56.160158067941666, 55.64465872943401, 33.14988858997822, 18.739422149956226, 15.200918074697256, 15.899299699813128, 24.06001254916191, 23.892021663486958, 23.599063083529472, 13.798785712569952, 6.3930220529437065, 2.6236946135759354, 4.123363941907883, 7.929699495434761, 12.03563092276454, 10.764335989952087, 29.29595109075308, 57.30516962707043, 33.771140053868294, 7.1820601634681225, 3.3704395685344934, 2.432257798500359, 0.9987842431291938, 0.6128689355682582, 0.3273186815204099, 0.08881232264684513, 0.15625202417140827, 0.21685773303033784, 0.07647525300853886, 0.08870303397998214, 0.1503311106353067, 0.12574025517096743, 0.4143617092631757, 0.699792061932385, 0.5646554008126259, 0.19901015009963885, 1.0826500179246068, 1.3648478128015995, 0.7265282585285604, 0.1244372887595091, 0.30053881695494056, 0.21772656531538814, 0.2367605603649281, 0.19939562160288915, 1.11018025316298, 3.4835592610761523, 9.166152197867632, 13.652513511478901, 16.421060152351856, 20.32567173242569, 14.280355721712112, 10.063694436103106, 11.953304540365934, 12.183590233325958, 14.977805446833372, 8.360151797533035, 7.810411071404815, 7.138175368309021, 14.384358990937471, 14.592502322047949, 15.417550150305033, 6.408346630632877, 8.094871882349253, 15.405576042830944, 21.055392175912857, 23.886169977486134, 32.79553860425949, 50.66252566874027, 36.97966128587723, 10.690190568566322, 1.6183228301815689, 0.5010523949749768, 0.41413651197217405, 0.5654948588926345, 0.21061520237708464, 0.4383885918650776, 0.48994645185302943, 0.2021218862500973, 0.17979575379285961, 0.2011076227063313, 0.29527906794101, 0.15093993890332058, 0.14674977312097326, 0.07459235755959526, 0.051288512331666425, 0.13328613073099405, 0.06591671059140936, 0.013565768404077971, 0.04178291048447136, 0.07168957308749668, 0.07716373598668724, 0.0642031806637533, 0.052080866298638284, 0.042515955719863996, 0.007724881115791504, 0.01333470258032321, 0.05244560961727984, 0.11466033174656332, 0.1345098135061562, 0.06072849348129239, 0.10661625987268053, 0.09024468250572681, 0.1109833165537566, 0.19486529985442758, 0.140068469918333, 0.18051277234917507, 0.1616777470917441, 0.08237552741775289, 0.09945819358108565, 0.08374528712010942, 0.1695139062940143, 0.07912872039014474, 0.17393489484675229, 0.08195257745683193, 0.058328807208454236, 0.2757097617723048, 0.11137445064377971, 0.07797615762683563, 0.2022617810871452, 0.3250086132902652, 0.13269392657093704, 0.1770193051197566, 0.1748539853724651, 0.028419856935215648, 0.16287679056404158, 0.11843105050502345, 0.09577188669936731, 0.182190649502445, 0.21409433131339028, 0.19025311921723187, 0.17499852605396882, 0.17842993489466608, 0.15923504222882912, 0.11267274894635193, 0.07101466399035417, 0.09344010322820395, 0.0928310894232709, 0.1200618532311637, 0.07563057020888664, 0.10397247009677812, 0.13615565956570208, 0.12340928806224838, 0.3120820038020611, 0.4472682997584343, 0.24823670159094036, 0.2492748771328479, 0.1820560239139013, 0.11383200588170439, 0.15607948967954144, 0.11769204953452572, 0.16822475125081837, 0.0980038513080217, 0.24369368911720812, 0.1065418595680967, 0.1750374591210857, 0.039658594396314584, 0.13322831742698327, 0.23446291568689048, 0.2548051835037768, 0.7383303064852953, 0.6453337403945625, 1.0360779357142746, 0.7433355285320431, 0.503888645907864, 0.5118239857256413, 0.8913133630994707, 0.571114697959274, 3.2167333038523793, 1.8017925415188074, 27.041138783097267, 56.49646282196045, 74.1122567653656, 80.81956565380096, 87.13507756590843, 83.66920754313469, 71.001515686512, 64.90563958883286, 66.14988282322884, 61.17738984525204, 59.58765394985676, 61.771715953946114, 59.879911467432976, 53.82823459804058, 40.09318381547928, 23.88626117259264, 18.586714044213295, 22.251142412424088, 20.17164319753647, 21.884036511182785, 25.125064998865128, 26.735416688024998, 28.658744283020496, 52.665743976831436, 71.18745490908623, 40.86957335472107, 10.297383796423674, 1.1906594596803188, 1.1820240668021142, 0.7304526166990399, 0.2882266166852787, 0.29388011957053095, 0.39129822340328246, 0.25630396557971835, 0.3086932981386781, 0.30795542523264885, 0.21274975268170238, 0.1636805958696641, 0.26639574905857444, 0.4901204409543425, 0.4140695108799264, 0.3821075853193179, 0.19200274720788002, 0.07760497988783754, 0.5756546824704856, 0.5707096634432673, 1.8664600839838386, 0.892654275521636, 1.0254049021750689, 0.6769722083117813, 0.3601672360673547, 1.8698275345377624, 5.114566879346967, 14.426053203642368, 22.79961258172989, 22.630517855286598, 20.44249266386032, 18.510294444859028, 18.372576534748077, 24.867873899638653, 24.065539352595806, 22.27188739925623, 19.382338151335716, 20.009990371763706, 21.19505748152733, 22.1356039121747, 29.291978403925896, 31.504335589706898, 26.77360273897648, 30.136332996189594, 27.056913636624813, 31.117404252290726, 47.03643724322319, 62.17558868229389, 63.034129813313484, 54.33437503874302, 23.314608447253704, 4.435110138729215, 1.1262978008016944, 0.5090604058932513, 0.6325915397610515, 0.4316088353516534, 0.5882156209554523, 0.5563897162210196, 0.4981985699851066, 0.3400686598615721, 0.16551963781239465, 0.22764557681512088, 0.19359490630449727, 0.07401474402286112, 0.08783680663327686, 0.14510327397147194, 0.0856910647416953, 0.05830557427543681, 0.04383631807286292, 0.04335377365350723, 0.07737700696452521, 0.05950585342361592, 0.037422763198264875, 0.06746871207724325, 0.06796086730901152, 0.018232440306746867, 0.09627823921618983, 0.0838909855519887, 0.11166844502440654, 0.1583703956566751, 0.09309328277595341, 0.06105921675043646, 0.08982699437183328, 0.16037312569096684, 0.32280974846798927, 0.25617794890422374, 0.24341743206605315, 0.20169541850918904, 0.2448585641104728, 0.18622687901370227, 0.28080119169317186, 0.12283013085834682, 0.13964963145554066, 0.1316318241879344, 0.09718713263282552, 0.14319488574983552, 0.09589256733306684, 0.2398470338084735, 0.2206957052112557, 0.23591973673319444, 0.3920805954840034, 0.33019634429365396, 0.29704891203437, 0.224105725355912, 0.42984374100342393, 0.24069893028354272, 0.24698956694919616, 0.21163475001230836, 0.3757231857161969, 0.49489233177155256, 0.2599726093467325, 0.30351874767802656, 0.19021782267373055, 0.16902848234167323, 0.15151152620092034, 0.09779348212759942, 0.14260915311751887, 0.2392656946904026, 0.2541140955872834, 0.1483742453274317, 0.23128386674216017, 0.22185706242453307, 0.2277014753781259, 0.40348645532503724, 0.5223837378434837, 0.4701577965170145, 0.5487675627227873, 0.5148609727621078, 0.20409776538144797, 0.22156173217808828, 0.1481414187583141, 0.19186654826626182, 0.16402747569372877, 0.3131574945291504, 0.27973324118647724, 0.2575371181592345, 0.18815088202245533, 0.10538148941122927, 0.38294873549602926, 0.20642025716369972, 0.5069468286819756, 0.6989340204745531, 0.7302571053151041, 0.7920281344559044, 0.5258403648622334, 0.4094261897262186, 0.47078378323931247, 1.0564345121383667, 1.0743757244199514, 0.31646931369323283, 11.939332690089941, 48.875553756952286, 82.62713626027107, 88.80665346980095, 94.60676863789558, 94.39863100647926, 87.23376587033272, 86.28354325890541, 89.37035322189331, 73.43226045370102, 66.76525220274925, 62.787963822484016, 65.34874901175499, 70.4375347495079, 74.58316549658775, 66.47621691226959, 59.793754890561104, 56.95415586233139, 51.608275920152664, 46.27461612224579, 46.90089851617813, 58.24799783527851, 75.97595036029816, 87.6344695687294, 97.65820249915123, 79.20222043991089, 26.933465860784054, 9.925606995821, 3.351346543058753, 1.2283618678338826, 0.3916158329229802, 0.35202364961151034, 0.2975571941351518, 0.29599544825032353, 0.27596696047112346, 0.25612635479774326, 0.2128130430355668, 0.28472038451582193, 0.23783070762874559, 1.080384033266455, 1.224653860554099, 0.7687233318574727, 0.18029710423434153, 1.5034225769340992, 2.828260436654091, 2.0914341369643807, 3.0197473615407944, 1.7162682744674385, 3.1223166827112436, 2.364519308321178, 2.092043054290116, 2.966692945919931, 6.273195957764983, 18.823477439582348, 33.32100100815296, 40.84733694791794, 44.83539395034313, 44.300485253334045, 35.21372504532337, 34.521880969405174, 33.24361056089401, 41.594095677137375, 44.23448659479618, 49.002447947859764, 47.89221592247486, 58.4814041107893, 48.36052179336548, 41.02124601602554, 32.219554111361504, 46.0030484944582, 55.91569058597088, 60.08777171373367, 67.90000811219215, 78.3679524064064, 77.77345910668373, 47.345045283436775, 12.755809128284454, 1.5085439896211028, 0.47070891538169235, 0.35793182789348066, 0.5623540899250656, 0.3060962859308347, 0.4627196065848693, 0.6049402453936636, 0.5174833664204925, 0.4025646485388279, 0.29019283305387944, 0.5309323885012418, 0.3234186361078173, 0.3573420876637101, 0.16451407223939896, 0.14477658056421205, 0.15962216129992157, 0.16325679986039177, 0.10622209039865993, 0.1896991950343363, 0.12796724739018828, 0.17517579544801265, 0.1661137567134574, 0.15815729537280276, 0.11828216083813459, 0.09289757101214491, 0.1378803959232755, 0.1523302189889364, 0.1521497732028365, 0.22014224115991965, 0.18769226444419473, 0.24382357980357483, 0.12440126491128467, 0.27261619339697063, 0.38950002926867455, 0.36257384286727756, 0.3615718841319904, 0.3114623698638752, 0.25332091783639044, 0.19689642445882782, 0.32168788835406303, 0.37219169083982706, 0.27409125643316656, 0.14077521715080366, 0.14739211677806452, 0.2851451898459345, 0.4099081107415259, 0.42364259250462055, 0.27411604416556656], [0.03825279600278009, 0.1334764767671004, 0.08779777708696201, 0.08189527623471804, 0.08756276860367507, 0.07966198318172246, 0.1294253597734496, 0.10102569111040793, 0.11277480909484439, 0.08311531506478786, 0.06300369190284982, 0.06363605367369018, 0.09010630164993927, 0.08831202605506405, 0.04235489483107813, 0.008423210074397502, 0.014329931891552405, 0.042302517758798786, 0.0821534990973305, 0.05838461671373807, 0.06371531504555605, 0.07562941987998784, 0.019372796596144326, 0.09959154267562553, 0.051378768621361814, 0.04743600518850144, 0.08329235439305194, 0.07894404436228797, 0.08379017963306978, 0.180309260613285, 0.10060046275611967, 0.06061533451429568, 0.08337953448062763, 0.07661474708584137, 0.15672520268708467, 0.04255514111719094, 0.03114749641099479, 0.12217807248816825, 0.05790433213405777, 0.11338034964865074, 0.030999257978692185, 0.11677454720484093, 0.02755146622803295, 0.18430317286401987, 0.15092411631485447, 0.20838687429204583, 0.4834111290983856, 0.5401319917291403, 0.32057529024314135, 0.08634086698293686, 0.22807927307439968, 0.2552293357439339, 0.07418606881401502, 2.366949515417218, 6.623548083007336, 28.419520519673824, 44.449539855122566, 51.126393377780914, 41.55225612223148, 35.1861385256052, 38.904394805431366, 34.2877147346735, 25.62721185386181, 19.761213921010494, 16.512376852333546, 8.829058986157179, 6.635042941197753, 7.247417131438851, 5.302440673112869, 6.6511849500238895, 4.825499765574932, 9.555158223956823, 13.639921937137842, 21.619173623621464, 30.6009416654706, 50.90173423290253, 42.5980170071125, 2.9468409111723304, 5.902806082740426, 3.5743504017591476, 0.37119356158655137, 1.0960798035375774, 0.02896916681493167, 0.17617238103412092, 0.2532128611346707, 0.11796685939771123, 0.2355273484135978, 0.040280558678205125, 0.19453857676126063, 0.6651350716128945, 0.46931148099247366, 0.6230221688747406, 0.24209157039877027, 0.10908362630289048, 0.37646174139808863, 0.31829419545829296, 0.15646058251149952, 0.0719530726200901, 0.14239281706977636, 0.3720356913981959, 0.530711169121787, 1.8020823947153986, 5.670126993209124, 12.380075789988041, 14.12639083340764, 10.907304268330336, 7.762207807973027, 8.509201649576426, 8.452461194247007, 7.955919513478875, 9.44730481132865, 9.54527210444212, 3.1985717033967376, 3.3494606567546725, 11.364111006259918, 15.198116675019264, 8.143231887370348, 8.815794847905636, 5.796859217807651, 11.670548412948847, 22.33484622091055, 28.99281855672598, 29.60695680230856, 34.91978421807289, 31.574591919779778, 15.553469806909561, 3.3293849090114236, 0.2764841780299321, 0.2516975440084934, 0.42507505626417696, 0.20524378982372582, 0.28675870795268565, 0.256363752996549, 0.4905617219628766, 0.22148876421852037, 0.3269788372563198, 0.35181932151317596, 0.07407812343444675, 0.02167074184399098, 0.10461424230015837, 0.0484583544312045, 0.049574102959013544, 0.14041019923752174, 0.05509149224963039, 0.10579184512607753, 0.09601117737474851, 0.07990064303157851, 0.07493473996873945, 0.0628894753754139, 0.039659859758103266, 0.05681819158780854, 0.08809493301669136, 0.016247100647888146, 0.09166176896542311, 0.012063924041285645, 0.022052959029679187, 0.013398914124991279, 0.06823643416282721, 0.09233494885847904, 0.03321225514810067, 0.08090810850262642, 0.10852798033738509, 0.025476061382505577, 0.10763565165689215, 0.18783248582622036, 0.21220788097707555, 0.07238480218802579, 0.06472145949373953, 0.11319634155370295, 0.03330640771309845, 0.05433849437395111, 0.07310411398066208, 0.02371916034462629, 0.10783646939671598, 0.042121407750528306, 0.03355970271513797, 0.019146905397064984, 0.13275542092742398, 0.013605345284304349, 0.125759209622629, 0.017978054347622674, 0.03239145466068294, 0.029624002672790084, 0.10212953187874518, 0.2090553563903086, 0.2227661487995647, 0.3386021463666111, 0.2462154030217789, 0.046870599981048144, 0.05837542892550118, 0.08062353197601624, 0.07066065212711692, 0.03177475962729659, 0.08024649127037264, 0.1758776741917245, 0.04177220871497411, 0.1069210673449561, 0.04930657727527432, 0.10053038175101392, 0.14678150735562667, 0.11598565164604224, 0.10577890207059681, 0.18125379196135327, 0.29145855107344687, 0.23755915579386055, 0.23016525723505765, 0.20674444211181253, 0.20550250250380486, 0.14734795899130404, 0.1376376542611979, 0.10487819454283454, 0.02994037280586781, 0.08321380548295565, 0.16103650181321427, 0.06623346664127894, 0.14417656901059672, 0.03267397914896719, 0.03997415929916315, 0.21206403791438788, 0.47887663647998124, 0.28647865110542625, 0.3936294576851651, 0.5418635706882924, 0.5351444624830037, 0.46840626862831414, 0.29176698764786124, 0.5256474658381194, 1.2876775162294507, 0.841162585420534, 13.298895936459303, 32.55284942686558, 56.06716185808182, 71.75136744976044, 79.75205853581429, 76.43843874335289, 65.226821154356, 56.56849555671215, 50.591644272208214, 45.26847191154957, 44.84919860959053, 49.318967163562775, 41.398710161447525, 35.70001535117626, 24.090961888432503, 15.432845279574394, 20.92559114098549, 21.633363962173462, 29.174120128154755, 34.12115067243576, 44.491189420223236, 49.759260937571526, 65.82192242145538, 63.46031494438648, 24.474405013024807, 1.3640358438715339, 3.7296703923493624, 4.269555397331715, 2.582289185374975, 0.03578324023692403, 0.11397939641028643, 0.4884892894187942, 0.6143639178480953, 1.095854309387505, 1.1604939470998943, 0.1659916585776955, 0.3198267600964755, 0.14911720936652273, 0.28512446908280253, 0.1598705878132023, 0.23603340407134965, 0.5572809465229511, 0.981866957154125, 1.0419038543477654, 0.2609810989815742, 0.18814775015925989, 0.7752121367957443, 0.7457709603477269, 2.1063260128721595, 6.348635209724307, 15.54322175681591, 22.328789345920086, 24.432383067905903, 23.572758994996548, 22.629535607993603, 23.159897848963737, 14.091143924742937, 15.267310962080956, 16.011096350848675, 19.871957078576088, 17.911057099699974, 16.98862999677658, 20.754366628825665, 28.27572863548994, 29.362158738076687, 27.57590688765049, 21.370106488466263, 25.43421071022749, 37.3803573846817, 44.178724586963654, 52.845177948474884, 49.64061990380287, 33.47218729555607, 11.38164421543479, 1.50530775077641, 0.5124630639329553, 0.3957652399549261, 0.38638146535959095, 0.3165050852112472, 0.24590218701632693, 0.4600460937945172, 0.3189628111431375, 0.17870038835098967, 0.18216789525467902, 0.2034533437108621, 0.0386031193920644, 0.05910031424718909, 0.07771950811729766, 0.05279317592794541, 0.08939325358369388, 0.0831646381993778, 0.05096996028441936, 0.09842588842730038, 0.09422951829037629, 0.09078158182092011, 0.04344475353718735, 0.03204235210432671, 0.08413111485424452, 0.09018758166348562, 0.047858925463515334, 0.10829887192812748, 0.018305564117326867, 0.0506888310337672, 0.07109924656106159, 0.041824953150353394, 0.026021159574156627, 0.00805619021775783, 0.2094866629340686, 0.07592463138280436, 0.0766669497534167, 0.20796358294319361, 0.1556337409419939, 0.04940924598486163, 0.08612174045993015, 0.04267644515493885, 0.06311067991191521, 0.02402901998721063, 0.019848927004204597, 0.1420254836557433, 0.1280170603422448, 0.1270738203311339, 0.0691009100410156, 0.006591903629669105, 0.19911810290068388, 0.3205703920684755, 0.28040927834808826, 0.2297263065702282, 0.2266120322747156, 0.2572165697347373, 0.13535627746023238, 0.32008529466111213, 0.32163768948521465, 0.43251324619632214, 0.32532785553485155, 0.29652433237060905, 0.221720700210426, 0.19028056383831427, 0.13859818631317466, 0.22776647267164662, 0.14946854207664728, 0.19154071575030684, 0.17584236280526966, 0.11159531379234977, 0.17755765904439613, 0.23487865197239444, 0.24324906844412908, 0.3919174714246765, 0.19417520641582087, 0.29526066267862916, 0.41261653415858746, 0.468078565900214, 0.554133290424943, 0.48336921259760857, 0.3766716207610443, 0.31832768116146326, 0.2864773152396083, 0.23938430473208427, 0.17352430906612426, 0.15937944932375103, 0.1335812680190429, 0.3066870948532596, 0.10588971214019693, 0.23014947917545214, 0.1481292920652777, 0.2244257988058962, 0.22041567804990336, 0.4787891817977652, 0.17381426616339013, 0.39281264995224774, 0.6417207873892039, 0.7407241186592728, 0.5674984795041382, 0.22763662651414052, 0.4928734229179099, 0.7579342264216393, 0.1621135658933781, 3.5428847651928663, 17.987871877849102, 46.695029363036156, 72.91312471032143, 85.72566479444504, 82.57751852273941, 71.24226316809654, 81.45700424909592, 76.41994133591652, 62.65002362430096, 61.00445732474327, 62.55910210311413, 50.00283546745777, 49.10479545593262, 51.4127954095602, 52.606797739863396, 49.708993434906006, 53.578907176852226, 60.39623536169529, 73.04011389613152, 73.74379053711891, 87.49986559152603, 84.97501507401466, 99.79925841093063, 62.47945077717304, 20.294992178678513, 14.736386351287365, 7.195578413084149, 2.3069048998877406, 0.11119254282675683, 0.928828987525776, 1.1140537890605628, 0.7052753458265215, 0.7553095766343176, 0.7207241887226701, 0.6730629899539053, 1.3263684650883079, 0.6951139192096889, 0.8340655162464827, 0.5552385561168194, 1.1381744197569788, 1.4601214067079127, 1.8056660774163902, 1.8965491256676614, 0.9150191629305482, 0.5622308340389282, 0.8234956709202379, 0.4947738256305456, 3.3167237509042025, 9.337682593613863, 28.058408796787262, 42.95156143605709, 47.820658162236214, 43.77476066350937, 35.94328589737415, 38.870143443346024, 46.72354683279991, 35.29225543141365, 32.14915528893471, 32.54311054944992, 36.48983336985111, 45.11838376522064, 46.14086329936981, 37.62068688869476, 42.241634130477905, 44.213952496647835, 51.407616287469864, 60.9287615865469, 69.63072404265404, 66.78298205137253, 68.61332103610039, 51.51412837207317, 20.40137317031622, 3.829848454333842, 0.44192329281941056, 0.3286721807671711, 0.4752550448756665, 0.25299363071098924, 0.26519602281041443, 0.21649598056683317, 0.7498936797492206, 0.2998498367378488, 0.47297748271375895, 0.3908930404577404, 0.3564494918100536, 0.22493654483696446, 0.3604611265473068, 0.1698614688939415, 0.18788733053952456, 0.22655022621620446, 0.15361885452875867, 0.2550638368120417, 0.29945302521809936, 0.2600388682913035, 0.12949052033945918, 0.15363516693469137, 0.14545514102792367, 0.21601140266284347, 0.16313921398250386, 0.11563742853468284, 0.21224304393399507, 0.08368762224563397, 0.11741218564566225, 0.1412790166796185, 0.18321709911106154, 0.16788691078545526, 0.1041966506454628, 0.29730578418821096, 0.23378609184874222, 0.2008823660435155, 0.30263787775766104, 0.31617429514881223, 0.45453837839886546, 0.23450101754860952, 0.18072806939017028, 0.22648720303550363, 0.15710402454715222, 0.15054538351250812, 0.20602344564395025, 0.20924371347064152, 0.2752566954586655, 0.09401638832059689, 0.31956448510754853], [0.07226394343888387, 0.12313560626353137, 0.07399877300485969, 0.06557556756888516, 0.07128004857804626, 0.07590329463710077, 0.022565157814824488, 0.07032608453300782, 0.06079894184949808, 0.09446115742321126, 0.06273498249356635, 0.03406163945328444, 0.0344872463028878, 0.02005873957386939, 0.030324241270136554, 0.05396717562689446, 0.028899024582642596, 0.0809286956791766, 0.050557070135255344, 0.028899352982989512, 0.013176138090784661, 0.021958487341180444, 0.036186950019327924, 0.003075705576520704, 0.021936111588729545, 0.016301526047755033, 0.08809642473352142, 0.09212907709297724, 0.14194141316693276, 0.06904587236931548, 0.08081779655185528, 0.08140275735058822, 0.09270781127270311, 0.09932656626915559, 0.040716177099966444, 0.072173750231741, 0.06646609283052385, 0.06402562925359234, 0.03819897545326967, 0.017292964839725755, 0.08840715454425663, 0.04883693138253875, 0.04212411287880968, 0.0531444344233023, 0.06411206719349138, 0.1401783077744767, 0.11745148236514069, 0.2950096386484802, 0.2889728610171005, 0.22976152889896184, 0.08305690804263577, 0.038911845404072665, 0.014236119786801282, 0.027578827357501723, 0.19308067217934877, 0.265076388604939, 1.5198564575985074, 15.924249161034822, 34.71697390079498, 41.73783056437969, 37.66387537121773, 29.225195087492466, 33.09085115790367, 33.20880822837353, 27.40434229373932, 11.149345580488443, 2.0914317620918155, 3.5203253757208586, 11.575164031237364, 4.871695311740041, 14.774416610598564, 12.68579313531518, 12.242445275187492, 22.646450400352478, 32.950710877776146, 42.82593257725239, 53.499096259474754, 24.707758091390133, 7.80707105062902, 5.480377525091171, 2.4504728335887194, 0.6468556774780154, 1.6955749411135912, 0.9948279429227114, 0.4947100899880752, 0.26373090455308557, 0.7718906400259584, 0.6909406743943691, 0.3281641658395529, 0.1463414286263287, 0.25068469054531306, 0.8644818747416139, 0.7231019111350179, 0.25314019003417343, 0.24824817519402131, 0.4460389766609296, 0.13254791643703356, 0.2305274549871683, 0.49320477701257914, 2.4323665676638484, 3.850507470779121, 7.881703795865178, 9.267165027558804, 8.9761414937675, 9.110055807977915, 6.284750187769532, 8.850479386746883, 6.3610747922211885, 4.550556968897581, 8.090197183191776, 6.603482784703374, 13.73184660449624, 6.85000310651958, 7.175345923751593, 6.136390948668122, 4.452600125223398, 11.077064909040928, 15.216398444026709, 15.144892930984497, 28.473504222929478, 31.34137563407421, 44.039671048521996, 36.218421533703804, 19.497312381863594, 4.925227789208293, 0.7589392724912614, 0.09752469108207151, 0.08682842832058668, 0.1437865407206118, 0.017220514528162312, 0.2408942487090826, 0.3005677310284227, 0.2453628386138007, 0.17062120547052473, 0.12179562894743867, 0.025914533362083603, 0.02117479052685667, 0.07704859919613227, 0.12065335977240466, 0.05384318501455709, 0.05462998400616925, 0.07393416904960759, 0.11871998343849555, 0.0625816176761873, 0.14318983914563432, 0.11335170274833217, 0.08284308787551709, 0.03746166286873631, 0.06798693153541535, 0.10901161571382545, 0.00824003132947837, 0.121463399118511, 0.062380651506828144, 0.07292947178939357, 0.05901363510929514, 0.05406738411693368, 0.07090090017300099, 0.09247192705515772, 0.08767765306401998, 0.02838120773958508, 0.010152202648896491, 0.07868956934544258, 0.030898142213118263, 0.11989694059593603, 0.05110356541990768, 0.022688907229166944, 0.049651991357677616, 0.032947427171166055, 0.1881525741191581, 0.11509840667713434, 0.0561428668879671, 0.034372384106973186, 0.0675163950654678, 0.04887934512225911, 0.05633485307043884, 0.02402213285677135, 0.02825694995408412, 0.09590301677235402, 0.0999768880137708, 0.04507164143433329, 0.05387648518080823, 0.04508314472332131, 0.06653543910942972, 0.21242807619273663, 0.12170190311735496, 0.1342038853908889, 0.18041267147054896, 0.16360338282538578, 0.16541042336029932, 0.05562195343372878, 0.016598279362369794, 0.08721340258489363, 0.11919080934603699, 0.025522545802232344, 0.010417028770461911, 0.03299519179563504, 0.01250012319360394, 0.056044109296635725, 0.07879105804022402, 0.07323531084693968, 0.09491406788583845, 0.11775179984397255, 0.2442421214072965, 0.18559654330601916, 0.17133568588178605, 0.1877347895060666, 0.17507609532913193, 0.1886165648465976, 0.19029142888030037, 0.18329655344132334, 0.10212513836449943, 0.10821455653058365, 0.053134537884034216, 0.06921363485162146, 0.03976580504968297, 0.09284094514441676, 0.01244316243173671, 0.05920605544815771, 0.05470157528179698, 0.12988860835321248, 0.14745907334145159, 0.16452922689495608, 0.16939315886702389, 0.33180879370775074, 0.3020164626650512, 0.36902913241647184, 0.09791614429559559, 0.17549154959851876, 0.10091220930917189, 0.3536802716553211, 0.7041240076068789, 3.8974330527707934, 17.031474597752094, 41.23733662068844, 58.883764520287514, 65.84781423211098, 65.9333248436451, 52.63069465756416, 44.85470451414585, 40.59109389781952, 36.39496386051178, 32.304304763674736, 32.28840261697769, 30.618027448654175, 26.65704969316721, 17.221749387681484, 20.481256283819675, 30.545162558555603, 36.103162318468094, 43.908676877617836, 53.64967837929726, 59.9932935833931, 79.45128187537193, 66.28592312335968, 32.76696413755417, 6.808202974498272, 2.6496785692870617, 4.201715737581253, 4.134506843984127, 1.761795412749052, 0.6719225761480629, 0.5733898852486163, 0.933358819456771, 1.369952007662505, 1.2684975704178214, 0.07759019630611874, 0.19722503260709345, 0.34982724871952087, 0.41144848277326673, 0.45885260158684105, 0.3951780527131632, 0.6653742212802172, 0.5078114604111761, 0.4688021005131304, 0.8043489733245224, 2.645660759881139, 6.210559168830514, 11.38733061030507, 15.587660372257233, 18.033032454550266, 20.92443410307169, 18.20857733488083, 13.21103135123849, 13.290363494306803, 11.52006983757019, 15.737458784133196, 19.070226699113846, 18.377254083752632, 15.389703344553709, 13.17027473822236, 22.085406705737114, 24.880029447376728, 24.226323924958706, 24.567435421049595, 21.540377251803875, 33.11459228396416, 48.79163146018982, 58.22323836386204, 52.60199099779129, 36.751000955700874, 14.43339915946126, 2.5637012952938676, 0.7083768106531352, 0.19692520494572818, 0.19611813419032842, 0.08058351537329145, 0.2788862132001668, 0.26785751280840486, 0.37557241099420935, 0.17626231448957697, 0.14960462227463722, 0.0575932164065307, 0.10179284174228087, 0.07398454603389837, 0.15781246387632564, 0.06855067433207296, 0.1246926246676594, 0.11658873569103889, 0.08468277548672631, 0.06862906739115715, 0.05935739420237951, 0.04461588483536616, 0.03458233768469654, 0.06939410290215164, 0.09472113917581737, 0.07018948483164422, 0.06849038225482218, 0.09849493784713559, 0.11319778132019565, 0.026871052250498906, 0.03551673871697858, 0.009588906996214064, 0.05728579286369495, 0.056171962787630036, 0.08063211120315827, 0.04205031000310555, 0.12278055539354682, 0.1535985790542327, 0.031375179896713234, 0.08867217547958717, 0.02431612909276737, 0.02594578891148558, 0.06453584835981019, 0.06925487599801272, 0.057973426082753576, 0.12472925707697868, 0.28912051871884614, 0.10107569702086039, 0.18682266032556072, 0.06063366927264724, 0.023949235401232727, 0.09899743119603954, 0.17592293035704643, 0.25317833642475307, 0.2751526760403067, 0.3348178759915754, 0.2010249622981064, 0.17793130071368068, 0.19652929884614423, 0.22122317925095558, 0.18810287991072983, 0.3982675838051364, 0.3773185657337308, 0.2755263919243589, 0.24922752811107785, 0.11314787188894115, 0.104880658473121, 0.22976437874604017, 0.19338297861395404, 0.27037968684453517, 0.13365805061766878, 0.14372038567671552, 0.2537200745427981, 0.2108498546294868, 0.2655037766089663, 0.22805510874604806, 0.2549142495263368, 0.1713955178274773, 0.4906388162635267, 0.28923706558998674, 0.40840175875928253, 0.2258551010163501, 0.23137259791838005, 0.35574955749325454, 0.46058723819442093, 0.25838568981271237, 0.18352825194597244, 0.14061819354537874, 0.10626820745528676, 0.24034412432229146, 0.08179064083378762, 0.12429161259206012, 0.1490175537765026, 0.11399852155591361, 0.12311127866269089, 0.31071069301106036, 0.22247579094255343, 0.182550739555154, 0.19408487220061943, 0.2702933602267876, 0.36265135277062654, 0.6336089945398271, 0.23114340787287802, 0.1849909804877825, 0.19559490523533896, 0.24108814221108332, 0.3284961433382705, 0.6219788279850036, 5.792896505445242, 27.93289203196764, 60.10764464735985, 80.42733550071716, 76.78894713521004, 70.9246078133583, 80.15569567680359, 73.02657142281532, 56.08131229877472, 41.97276055812836, 36.76342248916626, 37.93391168117523, 50.72355419397354, 47.40438669919968, 59.68065395951271, 63.491119891405106, 58.66935342550278, 70.49766272306442, 80.90035691857338, 78.945741802454, 97.54519656300545, 105.05654230713844, 69.77740377187729, 39.143812358379364, 28.955248072743416, 17.335509583353996, 8.799285683780909, 1.8532231380231678, 0.6012998032383621, 0.8572421944700181, 1.2708142586052418, 1.4480024320073426, 1.7472304380498827, 0.2413559684646316, 0.2056061360053718, 1.4996589976362884, 0.8675417792983353, 0.6381739745847881, 0.481034861295484, 0.9291556512471288, 0.7814968808088452, 0.42683831008616835, 0.8520139718893915, 4.708002470433712, 11.459801271557808, 23.403844758868217, 39.36608903110027, 47.402900978922844, 47.59064510464668, 42.67431691288948, 40.65284438431263, 40.74643716216087, 38.24204474687576, 47.00415417551994, 49.26778391003609, 57.478318735957146, 48.427918776869774, 42.92773671448231, 31.677439101040363, 29.469974152743816, 44.0088015049696, 54.26108457148075, 57.7618633210659, 67.90376231074333, 76.34893074631691, 76.14162907004356, 59.09863539040089, 29.3547510355711, 6.577206244692206, 0.710777094354853, 0.27059532527346164, 0.3345080144936219, 0.14201582089299336, 0.1157130608044099, 0.25114793912507594, 0.35095427418127656, 0.3681145393056795, 0.2235884335823357, 0.1933760172687471, 0.3775768628111109, 0.22531533701112494, 0.12740897422190756, 0.3121278388425708, 0.11906526764505543, 0.3660903760464862, 0.2606125781312585, 0.1521962761762552, 0.06854731982457452, 0.21745908044977114, 0.13075355178443715, 0.10323513895855285, 0.15105742088053375, 0.17628814122872427, 0.21464589546667412, 0.17789782985346392, 0.26654088345821947, 0.23417184536810964, 0.15428643120685592, 0.08875801227986813, 0.0997736731369514, 0.11456480991910212, 0.12164283558377065, 0.1508656350779347, 0.07450650591636077, 0.198166981281247, 0.28272074181586504, 0.2964304358465597, 0.2948738553095609, 0.2135144468047656, 0.2071074562263675, 0.12214214511914179, 0.11528529430506751, 0.2609712729463354, 0.3329958737595007, 0.2153607172658667, 0.1128113450249657, 0.16387487528845668, 0.192313484440092, 0.27016271254979074, 0.17416874557966366], [0.05667139106662944, 0.03267572319600731, 0.15711480053141713, 0.20567827275954187, 0.12814341840567067, 0.05727468291297555, 0.055004486566758715, 0.08758636889979243, 0.020964697796443943, 0.11507492512464523, 0.06670769158517942, 0.033555112531757914, 0.10516807000385597, 0.09446053401916288, 0.08210333733586594, 0.030560663544747513, 0.11457495507784188, 0.07450152610545047, 0.09174971346510574, 0.06445321021601558, 0.021989286469761282, 0.06385581102222204, 0.05336116380931344, 0.05869014777999837, 0.04317876780987717, 0.04217227455228567, 0.03545549669070169, 0.05044955891207792, 0.08804430370219052, 0.0799059568089433, 0.031630827506887726, 0.04639593717001844, 0.07418448061798699, 0.03341731055115815, 0.036805014315177687, 0.1137322760769166, 0.01902152882394148, 0.04807026685739402, 0.03737050858035218, 0.03440370273892768, 0.06620332060265355, 0.04380388621939346, 0.047270242794184014, 0.07804868771927431, 0.05009605170926079, 0.053325711414800026, 0.027286499098408967, 0.057579931963118725, 0.15488008997635916, 0.18558521813247353, 0.027276433720544446, 0.08788654537056573, 0.07327141633140855, 0.08055354745010845, 0.04187427999568172, 0.08463956764899194, 0.262676490820013, 0.018863891091314144, 0.348960182745941, 10.068704467266798, 32.46510453522205, 49.001915976405144, 49.82420325279236, 46.10793426632881, 31.050620935857296, 28.078735806047916, 26.693166755139828, 9.851541370153427, 1.3684668811038136, 6.298519698902965, 5.021981997415423, 14.180638622492552, 12.27415457367897, 32.131239250302315, 35.212896689772606, 37.22321681678295, 51.65491461753845, 38.98536466062069, 12.935339044779539, 12.770109660923481, 8.103858400136232, 6.174654895439744, 3.5690147755667567, 0.5161812237929553, 1.6832804633304477, 0.7777857268229127, 1.3606185209937394, 0.6694439216516912, 0.5308244505431503, 0.41374774533323944, 1.156057685147971, 1.0428941762074828, 2.0941398292779922, 2.782456981949508, 3.143458035774529, 2.3605318972840905, 3.8139130594208837, 3.4358696825802326, 2.26173244882375, 1.986320021096617, 1.5676762978546321, 3.148212768137455, 10.94900418072939, 13.527366276830435, 13.93297741189599, 12.884084545075893, 11.85986565425992, 11.699263472110033, 9.66202748939395, 3.131893831305206, 0.5705028120428324, 7.07503130659461, 5.778993051499128, 7.2315197344869375, 2.8794764634221792, 8.120990730822086, 6.789925955235958, 13.664285279810429, 32.68686443567276, 49.50305588543415, 50.71235239505768, 19.344247095286846, 4.472411312162876, 0.576866342453286, 0.11763241796870716, 0.1681436345097609, 0.01628192036150722, 0.0514555475092493, 0.04802878451300785, 0.18604261858854443, 0.0923660077387467, 0.0624418786901515, 0.11679915682179853, 0.1485956576652825, 0.04908579576294869, 0.08069508985499851, 0.13703434757189825, 0.041123679256998, 0.04172654065769166, 0.0479778472072212, 0.035650759455165826, 0.05402664763096254, 0.04178681047051214, 0.09968126090825535, 0.06821762814070098, 0.02274492824653862, 0.07882710415287875, 0.04404881350637879, 0.027809874627564568, 0.12985530076548457, 0.04470288309676107, 0.07334761263336986, 0.001914762574415363, 0.035303742333780974, 0.017586671638127882, 0.030051797002670355, 0.06609724543523043, 0.14094084966927767, 0.05261518665065523, 0.07005441395449452, 0.022505207125504967, 0.09850396236288361, 0.06492730157333426, 0.04783719537954312, 0.045877958909841254, 0.0879559807071928, 0.024758397157711443, 0.05116476662806235, 0.11574665040825494, 0.1766891681472771, 0.09671088904724456, 0.029393537988653407, 0.03672543381981086, 0.06673398587736301, 0.04932671916321851, 0.015229134714900283, 0.05621378651994746, 0.12819829280488193, 0.14584821212338284, 0.07218228493002243, 0.09266127861337736, 0.03750400239368901, 0.14267225051298738, 0.13594049611128867, 0.14959651802200824, 0.2569146640598774, 0.17491678590886295, 0.18690014054300264, 0.08414400595938787, 0.08900077620637603, 0.02725879843637813, 0.07130370082450099, 0.049746355434763245, 0.01997672483412316, 0.06323921988951042, 0.05099394649732858, 0.025198433213518, 0.06829707504948601, 0.13168298784876242, 0.07258452154928818, 0.08049802738241851, 0.03159631392918527, 0.12043399576214142, 0.1415320296655409, 0.12320645910222083, 0.07135601481422782, 0.11736370855942369, 0.11471615609480068, 0.13930851069744676, 0.17382879741489887, 0.057747672180994414, 0.08054153207922354, 0.07945298697450198, 0.021511337799893226, 0.09968641883460805, 0.0508040717249969, 0.13628845947096124, 0.04836606836761348, 0.039097720000427216, 0.09668262064224109, 0.07993682273081504, 0.06250057514989749, 0.12742657796479762, 0.09415666165295988, 0.28134913416579366, 0.22419377375626937, 0.19405085215112194, 0.07164257287513465, 0.0891531168599613, 0.04029452218674123, 0.04898666338704061, 0.1581099463510327, 0.7552819687407464, 0.2647282026009634, 11.010478232055902, 32.16148182749748, 49.98570218682289, 63.74343395233154, 67.6634556055069, 60.68983420729637, 44.350855350494385, 24.831234365701675, 23.43567755073309, 24.524121545255184, 27.971328869462013, 26.718779280781746, 28.068438358604908, 28.288697339594364, 37.663419395685196, 54.637674763798714, 60.77141962945461, 57.4893419444561, 80.21025314927101, 77.68977999687195, 61.77287109196186, 25.62906615436077, 7.8531564027071, 7.753799809142947, 9.417559057474136, 8.501020688563585, 6.964363195002079, 4.070072276517749, 3.98143467027694, 2.639814536087215, 2.0200996147468686, 2.5394747452810407, 5.670364480465651, 7.929006507620215, 6.921680085361004, 5.462144678458571, 1.8269470729865134, 2.6631495589390397, 4.654525090008974, 3.6758405808359385, 4.42889747209847, 7.221395177766681, 7.153983470052481, 6.466751871630549, 3.515486097894609, 11.761108953505754, 18.373978659510612, 22.733948305249214, 26.134330742061138, 24.51209519058466, 29.274928718805313, 24.211858101189137, 25.342042855918407, 29.72766112536192, 27.0954492688179, 27.888614907860756, 22.05198559910059, 17.363711670041084, 19.52915657311678, 30.927942618727684, 41.18380129337311, 54.87438306212425, 60.03255307674408, 38.75051066279411, 15.608610548079014, 3.6826125299558043, 0.4970086697721854, 0.3715509205358103, 0.0813441351056099, 0.14607026270823553, 0.12201308563817292, 0.23602403816767037, 0.3144815156701952, 0.09500066909822635, 0.1433639321476221, 0.1499563705874607, 0.11258723126957193, 0.06285800089244731, 0.05332351094693877, 0.11703797994414344, 0.015533485766354715, 0.04766469428432174, 0.028306338026595768, 0.022702176829625387, 0.05113683218951337, 0.05994065919367131, 0.12987553171114996, 0.05484190056449734, 0.1024683000287041, 0.062090475475997664, 0.01813492395740468, 0.16268009174382314, 0.04354888056695927, 0.026993246865458786, 0.027394804419600405, 0.029435901633405592, 0.06572623839019798, 0.02317004527867539, 0.11390516679966822, 0.11748924283892848, 0.03923082789697219, 0.06744854792486876, 0.06655185541603714, 0.04697206641139928, 0.14433841657591984, 0.1696693417034112, 0.06070705654565245, 0.013341958001547027, 0.10643691988661885, 0.018475417600711808, 0.046979918333818205, 0.07747566065518185, 0.1105160010047257, 0.0850191390782129, 0.11609963810769841, 0.13107988896081224, 0.08596476138336584, 0.023972677990968805, 0.14317226508865133, 0.3880058485083282, 0.40512131759896874, 0.3516664984636009, 0.23109700880013406, 0.12788857973646373, 0.3410729340976104, 0.30275014985818416, 0.21118405857123435, 0.41133558726869524, 0.4671086382586509, 0.41607805935200304, 0.3179118112893775, 0.3871546051232144, 0.0937843781139236, 0.1943896128796041, 0.16593007516348734, 0.17069144232664257, 0.17461249051848426, 0.243291845836211, 0.20126669463934377, 0.25260275637265295, 0.4026135115418583, 0.1937747880583629, 0.17876771598821506, 0.223513521195855, 0.2857322880299762, 0.29802777513395995, 0.22509549802634865, 0.4481086484156549, 0.27994448610115796, 0.12676340964389965, 0.22554807452252135, 0.32521923480089754, 0.31158322119154036, 0.22793139272835106, 0.17500691232271492, 0.19360838370630518, 0.40269574150443077, 0.08200743701308966, 0.1611090690130368, 0.12253647786565125, 0.14175364980474114, 0.23826024786103517, 0.16221317695453763, 0.1774340172414668, 0.1863574524759315, 0.1578190689906478, 0.21901364234508947, 0.27849673409946263, 0.1562744815601036, 0.27350739401299506, 0.4717464081477374, 0.2746763062896207, 0.1569389263750054, 0.17046438966644928, 0.22110373800387606, 0.08131990398396738, 3.411450292915106, 20.968568734824657, 51.16521589457989, 84.58539918065071, 86.17988482117653, 84.35747221112251, 69.96275022625923, 63.60042482614517, 62.56621532142162, 49.76643115282059, 36.3956668227911, 36.34096875786781, 44.897053241729736, 53.34456615149975, 76.49231225252151, 79.81430679559708, 83.57110440731049, 80.90658098459244, 100.0939629971981, 102.15100541710854, 96.44414484500885, 54.592149406671524, 28.55585340410471, 26.778401881456375, 25.459068976342678, 18.473288230597973, 6.962165012955666, 2.3414887441322207, 1.8341485178098083, 0.932094199815765, 0.3463879879564047, 0.6373298855032772, 1.6589370695874095, 5.199825754389167, 5.394721096381545, 6.7464809864759445, 7.03270822763443, 6.231972444802523, 7.667244728654623, 10.05994213744998, 14.275613576173782, 23.22562862187624, 26.937670335173607, 30.91963056474924, 29.600291959941387, 40.51599472761154, 50.96427507698536, 59.96488630771637, 64.9601362645626, 64.6080319583416, 72.99577787518501, 53.51735807955265, 46.58074289560318, 42.0636934787035, 42.37786442041397, 40.6402138620615, 34.878890812397, 45.92828370630741, 45.779061913490295, 54.40017990767956, 75.18420204520226, 81.59962579607964, 78.34585279226303, 30.412105098366737, 6.629965463653207, 0.8454115292988718, 0.22421410860260949, 0.37983688060194254, 0.1423438946949318, 0.20762617292348295, 0.10698767509893514, 0.25280880625359714, 0.23498329479480162, 0.14130882133031264, 0.18637369066709653, 0.3158193704439327, 0.2492779347812757, 0.19464611395960674, 0.23729434265987948, 0.314765342627652, 0.16075193270808086, 0.11306366039207205, 0.12828040402382612, 0.15581483981804922, 0.10858371562790126, 0.14305381831945851, 0.12456813681637868, 0.16384656977606937, 0.21516063425224274, 0.14588355319574475, 0.1261790722492151, 0.35281902411952615, 0.209275254746899, 0.2491556288441643, 0.11665241938317195, 0.16846143698785454, 0.14536072500050068, 0.1763820822816342, 0.1796529200510122, 0.15010877803433686, 0.11702735238941386, 0.13111135602230206, 0.10087224465678446, 0.19688484695507213, 0.4115530662238598, 0.3253773122560233, 0.17801259557018057, 0.15808324387762696, 0.17952558235265315, 0.1987033017212525, 0.21266045747324824, 0.22594178386498243, 0.233819340064656, 0.12086700182408094, 0.18505358806578442, 0.22021124605089426, 0.22691681748256087, 0.20257762429537252], [0.04779326023708563, 0.025945666457118932, 0.044251638755667955, 0.020527762062556576, 0.06542511939187534, 0.07084384385962039, 0.09579298595781438, 0.12031679580104537, 0.0653995895117987, 0.060989974372205324, 0.09260914273909293, 0.07687817240366712, 0.12245009929756634, 0.06955312288482673, 0.014115460489847464, 0.059771616506623104, 0.12488179811043665, 0.09270096124964766, 0.16910536884097382, 0.10991574454237707, 0.04771449610416312, 0.08574033592594787, 0.21033297845860943, 0.14664873713627458, 0.1395070055150427, 0.0839419785188511, 0.07429851160850376, 0.0728814622561913, 0.06722181438817643, 0.0633443970582448, 0.02072477258479921, 0.0724203436402604, 0.064500611188123, 0.05916831723880023, 0.056323464814340696, 0.00626774280135578, 0.0242892095411662, 0.08084289598627947, 0.02678921191545669, 0.019506038079271093, 0.030533998178725597, 0.04721249257272575, 0.032677404160494916, 0.021421743876999244, 0.024489889983669855, 0.03948035649955273, 0.09827581874560565, 0.06414186442270875, 0.04270336285117082, 0.043070648025604896, 0.026458785505383275, 0.054109471311676316, 0.035459136925055645, 0.050391842087265104, 0.08543132047634572, 0.08653233366203494, 0.04269131037290208, 0.03271866386057809, 0.11879296624101698, 0.23030081792967394, 1.8225944065488875, 11.561696603894234, 29.17357675731182, 45.50899140536785, 50.308449268341064, 30.810910798609257, 21.497509852051735, 22.865981720387936, 23.112276904284954, 17.89452038705349, 11.379283592104912, 12.309106048196554, 11.40005137771368, 12.355639301240444, 21.680918410420418, 32.19078205525875, 33.179865181446075, 42.339452281594276, 31.543025113642216, 18.96812617778778, 9.254154525697231, 10.616653114557266, 10.119654033333063, 3.843801305629313, 4.454556545242667, 16.13255113363266, 23.674964010715485, 22.13043998926878, 21.492777206003666, 34.86127495765686, 29.747697450220585, 26.66633639484644, 12.569421529769897, 12.832183130085468, 17.456951066851616, 7.533145174384117, 7.147144787013531, 14.804257359355688, 12.845919393002987, 5.978405401110649, 6.749279061332345, 11.741764191538095, 5.941381612792611, 13.152447994798422, 19.194806814193726, 14.813475664705038, 9.274336192756891, 8.969658091664314, 11.66994234547019, 8.668277263641357, 4.667504243552685, 6.990805976092815, 11.793809998780489, 12.116854414343834, 11.419843565672636, 9.650960583239794, 19.560058414936066, 40.463261157274246, 49.846367463469505, 32.59675607085228, 7.013275120407343, 1.2345551792532206, 0.1800232072127983, 0.0654354871949181, 0.06340433290461078, 0.10371374257374555, 0.05211825940932613, 0.11392377244192176, 0.046179920245776884, 0.031063049282238353, 0.07729253571596928, 0.01573743258632021, 0.10495980110135861, 0.05254509080259595, 0.010672427761164727, 0.046084706409601495, 0.13545720954425633, 0.07461167566361837, 0.11904601633432321, 0.07757884144666605, 0.10597175656585023, 0.024256267461169045, 0.03743316439795308, 0.056256467432831414, 0.0343780912226066, 0.058152458077529445, 0.036798197688767686, 0.015587166235491168, 0.09297003431129269, 0.04097224031283986, 0.0408311172213871, 0.04492274805670604, 0.04626269939763006, 0.0723682448733598, 0.005902253160456894, 0.07787767463014461, 0.025328811861982103, 0.08910211647162214, 0.08513601991580799, 0.16505345032783225, 0.08576003994676284, 0.040422605743515305, 0.004788692112924764, 0.07060404110234231, 0.04610728254192509, 0.04273772799933795, 0.06984394829487428, 0.1426579715916887, 0.06474476293078624, 0.08586705022025853, 0.006533119039886515, 0.07955417881021276, 0.03387890043086372, 0.08609140146290883, 0.04079416197782848, 0.04982949452823959, 0.05297667936247308, 0.19341183331562206, 0.08951274678111076, 0.26814585202373564, 0.10109619513968937, 0.11338213080307469, 0.03645941469585523, 0.10953893390251324, 0.20273592439480126, 0.24967459787148982, 0.34577910031657666, 0.09679045469965786, 0.20617362664779648, 0.0278065256861737, 0.011516976974235149, 0.0615324769023573, 0.13294118049088866, 0.006913688657732564, 0.04115822623134591, 0.038801643895567395, 0.126849647203926, 0.11694958273437805, 0.26162448164541274, 0.005283646169118583, 0.03771497271372937, 0.07503370536142029, 0.09565850137732923, 0.16240567521890625, 0.03016509141161805, 0.03242996470362414, 0.07369556857156567, 0.19275525526609272, 0.11258085622102953, 0.09005013591377065, 0.08495224188663997, 0.030582916842831764, 0.052932528997189365, 0.1032718678470701, 0.07691727616474964, 0.05483722132339608, 0.06671691648080014, 0.07625294267199934, 0.052749467140529305, 0.04083837542566471, 0.04414990144141484, 0.08850716636516154, 0.1128079163026996, 0.07455758051946759, 0.06388498484739102, 0.07732332742307335, 0.03879895361023955, 0.10744325729319826, 0.1527589577017352, 0.030860585829941556, 0.0816403930366505, 0.035626279714051634, 0.028197210776852444, 0.06651909701758996, 0.393230093177408, 1.7712580924853683, 11.373555399477482, 31.25463578850031, 53.42797927558422, 70.79705625772476, 68.92124131321907, 58.71145136654377, 46.90206125378609, 35.108801275491714, 20.248484574258327, 26.104186959564686, 26.107086203992367, 34.07437518239021, 42.97885537147522, 43.518289625644684, 50.53336679935455, 63.64130303263664, 69.30616065859795, 76.09245210886002, 67.47821554541588, 66.61981120705605, 52.75902137160301, 48.13245043158531, 51.18689373135567, 53.590241968631744, 63.482748940587044, 61.08702689409256, 65.7306057214737, 69.06958535313606, 62.97861859202385, 74.05395269393921, 62.122999504208565, 53.20399649441242, 33.33067908883095, 35.960172191262245, 44.298045784235, 25.866505913436413, 31.139794550836086, 38.60052511096001, 43.144849464297295, 34.229338467121124, 32.458211705088615, 37.6197749376297, 29.671405144035816, 33.639632910490036, 40.203689485788345, 45.3064850717783, 40.287759974598885, 36.19067542254925, 37.95397840440273, 29.92992427200079, 21.481421515345573, 25.99929928779602, 20.107050463557243, 19.88232482224703, 14.61670322343707, 23.438897877931595, 34.255553260445595, 52.417499497532845, 63.04741010069847, 54.041425958275795, 24.31365843862295, 4.989767326042056, 0.6501260551158339, 0.24824770021950826, 0.07654530432773754, 0.0958407876896672, 0.024818704077915754, 0.06406584623618983, 0.0659990964049939, 0.07637534508830868, 0.10291505066561513, 0.05412670398072805, 0.0273397630371619, 0.06882829693495296, 0.09581637103110552, 0.0630789679416921, 0.20972797967260703, 0.06707691747578792, 0.09187859483063221, 0.06558455497724935, 0.02743696026300313, 0.026810134913830552, 0.04676543023379054, 0.13117193011566997, 0.16950222488958389, 0.10064728485303931, 0.08245173114119098, 0.04183727280178573, 0.09421642680536024, 0.11406803852878511, 0.08575401370762847, 0.023038664730847813, 0.18008516170084476, 0.01919939008075744, 0.04066098728799261, 0.027257037691015285, 0.1066704440745525, 0.09759241205756553, 0.043138101827935316, 0.05725355396862142, 0.07811665360350162, 0.061223346419865265, 0.021838496904820204, 0.08453245347482152, 0.06849156969110481, 0.062224399734986946, 0.0665572656725999, 0.1560371130472049, 0.06548034260049462, 0.1063994636933785, 0.10399678285466507, 0.14668464224087074, 0.19432017754297704, 0.19315515412017703, 0.060303083300823346, 0.04526095217443071, 0.18256089213537052, 0.24876114766811952, 0.30928953958209604, 0.40546938485931605, 0.24139142828062177, 0.17792009428376332, 0.2748916775453836, 0.17753946158336475, 0.2462669525993988, 0.3160584013676271, 0.408578182104975, 0.30907514796126634, 0.3459372074576095, 0.1709720483631827, 0.09685530356364325, 0.11869862442836165, 0.33571890264283866, 0.2943829691503197, 0.21601701329927891, 0.3303331963252276, 0.3036285558482632, 0.3912928205681965, 0.5325415427796543, 0.4359615908470005, 0.3131211589789018, 0.30645171529613435, 0.2899782336317003, 0.34437801456078887, 0.3912971547106281, 0.25745753024239093, 0.2612567029427737, 0.260663726949133, 0.1883868404547684, 0.17680976714473218, 0.22042986791348085, 0.13149915786925703, 0.20444311638129875, 0.24440325651085004, 0.12222051591379568, 0.3059000027133152, 0.11668612030916847, 0.18286269390955567, 0.16439851984614506, 0.16933864069869742, 0.1268297724891454, 0.228228147898335, 0.23814107378711924, 0.2153659865143709, 0.17326632369076833, 0.17265966249397025, 0.15038846380775794, 0.18577366427052766, 0.26017120806500316, 0.1128905767109245, 0.19161378761054948, 0.2237761821015738, 0.1415351318428293, 0.21257862827042118, 0.24848402972565964, 0.36759821232408285, 4.115294124931097, 19.102758653461933, 47.00272545218468, 73.83646756410599, 84.45308268070221, 73.199173361063, 70.45197397470474, 73.3590991795063, 56.95421665906906, 56.78814277052879, 48.53929080069065, 51.70039437711239, 59.50012564659119, 56.91079258918762, 59.471843764185905, 76.7625081539154, 73.4880718588829, 78.66039991378784, 73.4943263232708, 77.47572988271713, 72.93438836932182, 72.29269400238991, 74.35346022248268, 77.33240157365799, 89.2127376794815, 80.11370792984962, 79.08102214336395, 77.99496442079544, 64.90304812788963, 73.68434652686119, 68.6048474907875, 56.41998432576656, 37.2456394135952, 44.53899845480919, 57.64826461672783, 43.14024791121483, 48.33758242428303, 61.76584526896477, 64.5014400780201, 65.55158212780952, 61.139836460351944, 65.38627579808235, 48.86535510420799, 47.90652595460415, 59.103898108005524, 63.26072685420513, 58.00544165074825, 53.01736570894718, 62.926880568265915, 53.92226815223694, 42.5359283387661, 44.23247650265694, 42.95685835182667, 52.51286678016186, 45.00120185315609, 51.40898801386356, 64.04174834489822, 85.1200532913208, 81.03384375572205, 47.581350803375244, 11.743912026286125, 1.5177261969074607, 0.31119522638618946, 0.20458998740650713, 0.12898686924017966, 0.12854998174589127, 0.1540780212963, 0.17730409686919302, 0.10592319042189047, 0.11732436731108464, 0.2083077168208547, 0.10851604660274461, 0.11124205149826594, 0.14504330843919888, 0.11817332488135435, 0.26151464378926903, 0.426581705105491, 0.1050507216132246, 0.34810315060894936, 0.1860719927935861, 0.2512352750636637, 0.10843899683095515, 0.07869213717640378, 0.21280266781104729, 0.20471971482038498, 0.18626745964866132, 0.11463080169050954, 0.1163618166174274, 0.2325144811766222, 0.19257929205195978, 0.1613486194401048, 0.32684738805983216, 0.28183298476506025, 0.18068817153107375, 0.1819334359606728, 0.23512924555689096, 0.32655447721481323, 0.210847687558271, 0.21578642801614478, 0.20896908914437518, 0.1163308542163577, 0.128126660711132, 0.12767090782290325, 0.0984722726570908, 0.1895428542047739, 0.1853532821405679, 0.2882672566920519, 0.29547585581894964, 0.17165982630103827, 0.1958209040458314, 0.19726472266484052, 0.19743370969081298, 0.2468719068565406, 0.24914547626394778, 0.1747682227869518, 0.11486429619253613], [0.07574050454422832, 0.03057376616197871, 0.10028168064309284, 0.04320075393479783, 0.0705013501283247, 0.03534702067554463, 0.10760646298876964, 0.03185857778589707, 0.06189032195834443, 0.058153352365479805, 0.14616564352763817, 0.1213409447518643, 0.15884679509326816, 0.15593279676977545, 0.00914529100555228, 0.051869313392671756, 0.021482856027432717, 0.11005126812960953, 0.20154731551883742, 0.11316860749502666, 0.05054537017713301, 0.11838286285637878, 0.06285294686676934, 0.06559820307302289, 0.06371775671141222, 0.025760326207091566, 0.20505285006947815, 0.04008691379567608, 0.0869393942411989, 0.029547609701694455, 0.020589720261341427, 0.10007022792706266, 0.0719627205398865, 0.1130347685830202, 0.10462826146977022, 0.056600489988340996, 0.11657367009320296, 0.04449143409146927, 0.05119687564729247, 0.03322734672110528, 0.0274817618628731, 0.10243537835776806, 0.0644348123751115, 0.13581244595116004, 0.06964446642086841, 0.01857119732449064, 0.07259400619659573, 0.099369454983389, 0.08165194085449912, 0.025212997861672193, 0.02129779964889167, 0.03885953512508422, 0.10609289733110927, 0.0424470361758722, 0.07597224015626125, 0.07885085287853144, 0.03954423315008171, 0.10358011888456531, 0.04054995828482788, 0.024946418416220695, 0.01611600397154689, 0.03787092020502314, 0.5690851912368089, 5.800105668604374, 21.51809334754944, 48.949478790163994, 51.47729314863682, 43.745224848389626, 38.392797857522964, 33.082100227475166, 34.18923161923885, 27.03050695359707, 26.614227890968323, 39.05810795724392, 36.758915930986404, 36.95647872984409, 37.70924113690853, 41.288424879312515, 32.43540532886982, 18.33091177046299, 24.515376314520836, 23.61806396394968, 17.06456322222948, 14.241681396961212, 20.18040742725134, 36.9681479036808, 42.22541280090809, 50.29024064540863, 66.93015575408936, 72.38746091723442, 72.34398365020752, 60.131807550787926, 50.67074462771416, 41.729661002755165, 36.16632632911205, 23.072513937950134, 25.586880818009377, 18.254792355000973, 17.06396095454693, 18.57450719922781, 16.408726014196873, 10.121987108141184, 10.744750890880823, 9.20427080243826, 20.823236033320427, 19.202533699572086, 23.547064773738384, 19.73870772868395, 21.332336515188217, 22.911985851824284, 16.07966937124729, 21.588777154684067, 23.387410640716553, 23.0278492346406, 12.609605323523283, 15.890704561024904, 25.562343634665012, 23.483326993882656, 8.957544341683388, 1.2456163857132196, 0.19884465116774663, 0.09789395408006385, 0.06943736269022338, 0.10658736064215191, 0.04619803607056383, 0.0688885964336805, 0.06481257296400145, 0.030599398087360896, 0.07380879804259166, 0.02869944251870038, 0.06302973386482336, 0.015814050057088025, 0.00965288012594101, 0.015983743978722487, 0.07382369294646196, 0.06326905422611162, 0.17247255222173408, 0.10191008623223752, 0.0703155534574762, 0.04501235867792275, 0.06680079401121475, 0.06446852814406157, 0.04718686992418952, 0.06831425576820038, 0.09644835430663079, 0.05405874180723913, 0.09505558060482144, 0.10754617833299562, 0.022479209692392033, 0.04520507587585598, 0.01501988710515434, 0.032239982319879346, 0.07411488200887106, 0.07509843548177741, 0.0691154709784314, 0.1525099968421273, 0.067123375920346, 0.042492370266700163, 0.1207283760595601, 0.026076761278091, 0.07963145864778198, 0.06992853828705847, 0.0841627006593626, 0.020596755821316037, 0.05566044863371644, 0.021487776466528885, 0.03215117321815342, 0.047851845374680124, 0.08925415284465998, 0.08865516545483842, 0.05904119105252903, 0.06923008826561272, 0.03852902336802799, 0.22617731185164303, 0.09177490195725113, 0.02251202560728416, 0.06416665215510875, 0.06849744007922709, 0.19891132571501657, 0.11331720772432163, 0.05134790641022846, 0.0118175393618003, 0.029032650127192028, 0.05144511291291565, 0.07128341792849824, 0.3005464165471494, 0.4715740220854059, 0.29389787174295634, 0.12622861802810803, 0.08762919082073495, 0.07787207141518593, 0.031546296886517666, 0.0366372295684414, 0.05472592143632937, 0.1703535276465118, 0.09395473811309785, 0.03675884901895188, 0.0868081305816304, 0.10982740670442581, 0.10254312335746363, 0.030787285759288352, 0.026882781894528307, 0.1373224492999725, 0.07242320090881549, 0.05228953967161942, 0.1037847957923077, 0.06962272149394266, 0.1108804919931572, 0.18614064145367593, 0.1472776776063256, 0.13445188145851716, 0.1060099845926743, 0.03615918627474457, 0.021112197791808285, 0.04882107168668881, 0.029593133040179964, 0.07021224650088698, 0.05519420177733991, 0.04502920543018263, 0.13896051765186712, 0.030739042449567933, 0.014831084736215416, 0.022909436411282513, 0.10570675789494999, 0.07413741361233406, 0.07799911967595108, 0.10836841858690605, 0.19619919155957177, 0.033847218146547675, 0.07619232404977083, 0.06749657972250134, 0.06687022934784181, 0.03993601661932189, 0.019959033888881095, 0.07357021982898004, 0.030618998207501136, 0.16197666933294386, 1.3371283002197742, 5.936098471283913, 23.578390292823315, 48.23034077882767, 63.906148821115494, 70.39949879050255, 62.14288003742695, 51.264823749661446, 45.841325372457504, 42.00003929436207, 40.78834131360054, 38.07165049016476, 42.265420854091644, 51.51793956756592, 51.93195015192032, 53.697673603892326, 65.09252116084099, 61.976114585995674, 58.64580608904362, 67.91731238365173, 74.69243243336678, 73.69389921426773, 78.15589338541031, 68.08462500572205, 83.00975292921066, 78.3385343849659, 75.59965655207634, 90.9089058637619, 106.06834441423416, 99.47001367807388, 103.55714276432991, 88.86939570307732, 83.92832323908806, 85.7149113714695, 66.98547318577766, 73.64088445901871, 60.75454093515873, 61.48130513727665, 60.81133268773556, 57.53440372645855, 45.115685909986496, 43.290738835930824, 43.155697882175446, 46.84566468000412, 45.460107028484344, 35.14906391501427, 33.59924867749214, 42.373304665088654, 37.22932308912277, 28.194302804768085, 29.16460733860731, 36.81454874575138, 39.8652758449316, 34.616594687104225, 37.13794179260731, 48.74098017811775, 46.216722428798676, 27.980480678379536, 6.706478632986546, 1.1685172165744007, 0.11874598087160848, 0.12916019040858373, 0.039397718355758116, 0.058371369377709925, 0.10548734935582615, 0.1767602510517463, 0.10921368026174605, 0.06916198137332685, 0.02320759609574452, 0.00646940890874248, 0.05697025764675345, 0.03397545384359546, 0.053294622848625295, 0.051076510426355526, 0.07888482097769156, 0.1529513075365685, 0.2309807884739712, 0.04817190769244917, 0.042744644815684296, 0.020013557623315137, 0.08648616465507075, 0.08734549744985998, 0.08718934957869351, 0.065999474900309, 0.042459218529984355, 0.04115053015993908, 0.1062825160624925, 0.038571808181586675, 0.0705770862987265, 0.09641582597396336, 0.10758241740404628, 0.0836967135546729, 0.12414384356816299, 0.06154195412818808, 0.10242409771308303, 0.07886299441452138, 0.006668281293968903, 0.10338676715036854, 0.019121386649203487, 0.07273951167007908, 0.08484847479849122, 0.033566693746251985, 0.06895305195939727, 0.05821879123686813, 0.06377153273206204, 0.008343558147316799, 0.01310883086262038, 0.023375100681732874, 0.024858433098415844, 0.05055203095253091, 0.09059883537702262, 0.014179742538544815, 0.18642844632267952, 0.05132553807925433, 0.06845444004284218, 0.22181720909429714, 0.19538572349119931, 0.24400914640864357, 0.24135405372362584, 0.20785880653420463, 0.1280386419966817, 0.2468879075604491, 0.146962383587379, 0.15046454878756776, 0.2716896665515378, 0.5487870366778225, 0.3676993225235492, 0.2532228355994448, 0.2874901983886957, 0.2236132658435963, 0.1576288416981697, 0.14399744424736127, 0.2881794754648581, 0.45903003425337374, 0.2510933467419818, 0.3090142027940601, 0.3091383492574096, 0.2514080470427871, 0.14364991133334115, 0.18045157485175878, 0.27388826420065016, 0.21114989009220153, 0.1671019263449125, 0.12791324872523546, 0.18305531091755256, 0.267114385496825, 0.22996719286311418, 0.2179364743642509, 0.35842437646351755, 0.33252686611376703, 0.15850378928007558, 0.23670252441661432, 0.1052763567713555, 0.25996506912633777, 0.14630504854721949, 0.25610661366954446, 0.29310187383089215, 0.1438102894462645, 0.2582637401064858, 0.22169411648064852, 0.11461645597591996, 0.11887731874594465, 0.1880281011108309, 0.20799579215236008, 0.09940242860466242, 0.1331156148808077, 0.25474129943177104, 0.22884264617459849, 0.18098195811035112, 0.24762247048784047, 0.1861122765694745, 0.19653970375657082, 0.16509431297890842, 0.10448492306750268, 0.08828734964481555, 0.08754751004744321, 0.2917765168240294, 1.347349751740694, 12.267985604703426, 36.777911111712456, 73.24409455060959, 95.49155876040459, 91.28276780247688, 76.27463713288307, 75.90520575642586, 84.60126712918282, 75.96238508820534, 71.38042375445366, 84.35298845171928, 85.65953314304352, 76.46213427186012, 75.68533435463905, 85.67695900797844, 78.29236686229706, 66.7051774263382, 70.19586011767387, 82.22709372639656, 89.17660921812057, 93.13815504312515, 83.8360033929348, 103.48645895719528, 100.22433400154114, 96.42625540494919, 105.54757475852966, 110.25125876069069, 102.19569101929665, 105.74844717979431, 87.18202024698257, 98.46615314483643, 112.48089551925659, 80.17277956008911, 79.97309267520905, 66.09210312366486, 71.33442342281342, 76.33810892701149, 80.7148052752018, 56.14738315343857, 65.3380411863327, 56.48614637553692, 66.45217940211296, 71.02444365620613, 71.99901536107063, 67.06180348992348, 74.99237313866615, 71.16660922765732, 57.63080455362797, 59.04694676399231, 68.72298315167427, 76.29520162940025, 62.82135263085365, 63.06502975523472, 62.33505852520466, 39.06147077679634, 15.107995960861444, 1.810551902744919, 0.4482830531196669, 0.2449633553624153, 0.21979687531711534, 0.1575997643521987, 0.1332192335394211, 0.26201170461717993, 0.21412725298432633, 0.19627572182798758, 0.12064337788615376, 0.10254639622871764, 0.10294628766132519, 0.09549337351927534, 0.09261096842237748, 0.17647961532929912, 0.32528386102057993, 0.2336098169325851, 0.423931228579022, 0.3569733293261379, 0.23260488960659131, 0.24286574916914105, 0.14680473657790571, 0.20952176651917398, 0.1307272945996374, 0.21004961163271219, 0.15726686659036204, 0.12895467487396672, 0.19346835528267547, 0.19646396016469225, 0.20619485207134858, 0.11404936609324068, 0.18816756550222635, 0.0990959513001144, 0.14415458659641445, 0.2543969132238999, 0.18618787173181772, 0.2305400269688107, 0.23003852809779346, 0.19298607803648338, 0.22459218831500039, 0.08763479403569363, 0.1541351666674018, 0.1789298455696553, 0.2349286578828469, 0.15170718601439148, 0.10089355913805775, 0.13543433655286208, 0.15913369454210624, 0.13703565375180915, 0.11487878291518427, 0.16803919948870316, 0.10558269306784496, 0.16705664049368352, 0.11421502829762176, 0.21450616390211508, 0.22835371928522363, 0.32140661438461393], [0.10533572858548723, 0.07356878006248735, 0.05740035448980052, 0.03477275422483217, 0.09556357326800935, 0.0739771913504228, 0.021040988722234033, 0.04201857576845214, 0.04195290312054567, 0.12089502532035112, 0.1859830686589703, 0.04112848466320429, 0.05124737879668828, 0.11619685945333913, 0.05231259077845607, 0.07242827719892375, 0.009884243736451026, 0.062140488807926886, 0.08430789443082176, 0.005821483373438241, 0.03128254131297581, 0.08430818386841565, 0.09419785084901378, 0.051853980621672235, 0.06266473821597174, 0.038120292956591584, 0.030981214513303712, 0.07130162281100638, 0.05575916911766399, 0.04834946652408689, 0.03863813391944859, 0.008883403788786381, 0.002261990744045761, 0.05359854345442727, 0.036286434915382415, 0.038686518237227574, 0.011302835828246316, 0.06681413782644086, 0.06890956952702254, 0.05220457118412014, 0.02239715598989278, 0.00243032189700898, 0.08178579460945912, 0.13604662322904915, 0.06769733809051104, 0.0560042337019695, 0.07478359417291358, 0.09942246659193188, 0.0363389567064587, 0.11202861671335995, 0.018416361199342646, 0.027719004210666753, 0.04392009912407957, 0.023981878766790032, 0.025702292114146985, 0.04661331964598503, 0.053952481102896854, 0.10946622569463216, 0.08530494014848955, 0.02203098774771206, 0.05848119610163849, 0.056837832526071, 0.05922574091528077, 0.0589017229503952, 0.1977584438282065, 3.891729796305299, 19.497109092772007, 39.700695276260376, 51.00756235420704, 63.36430549621582, 58.992412090301514, 57.98325464129448, 49.59824837744236, 43.99847365915775, 47.90777608752251, 46.5101008862257, 49.18753981590271, 50.47170750796795, 51.00644901394844, 51.95477552711964, 62.685532718896866, 64.64594632387161, 50.69499872624874, 42.92219281196594, 45.567622259259224, 59.18244369328022, 60.087216943502426, 59.53420601785183, 60.017095506191254, 58.66377152502537, 58.7890850007534, 40.348883494734764, 35.920160338282585, 22.39676769822836, 92.95265659689903, 37.95977309346199, 24.75673746317625, 35.07624842226505, 30.258952416479588, 48.86069655418396, 45.58546610176563, 33.75645384192467, 35.514638498425484, 38.11854377388954, 34.81802187860012, 26.28987729549408, 27.134699262678623, 25.479870960116386, 23.28229308128357, 29.892215095460415, 35.9146012365818, 31.117370054125786, 31.571322195231915, 27.671954333782196, 17.08462994545698, 8.775610104203224, 1.8988791131414473, 0.5934541742317379, 0.057987378459074534, 0.06486818208941258, 0.11268205547821708, 0.06286888819886371, 0.05641893469146453, 0.07904833095381036, 0.11255954916123301, 0.017294354511250276, 0.03592469358409289, 0.08017177926376462, 0.020031794047099538, 0.01151456221123226, 0.011038622906198725, 0.03066236931772437, 0.04651746014133096, 0.01626644101634156, 0.04284333932446316, 0.04316502694564406, 0.07010569635895081, 0.09553541618515737, 0.10471452871570364, 0.017587883194210008, 0.0396697229007259, 0.10551384402788244, 0.013740786307607777, 0.01702660618320806, 0.029009669524384663, 0.08751496687182225, 0.015077733805810567, 0.02929263373516733, 0.06587230789591558, 0.0035423077360974276, 0.028105071287427563, 0.02447236231091665, 0.040902244654716924, 0.030071445362409577, 0.06433312330045737, 0.062162051908671856, 0.047517281491309404, 0.03688837605295703, 0.09226840047631413, 0.12189942572149448, 0.053876143792876974, 0.09641627126256935, 0.10746138053946197, 0.02803969178785337, 0.02597295337182004, 0.0061480552540160716, 0.06784875848097727, 0.07938996379380114, 0.05160312728548888, 0.026938138689729385, 0.03393752638658043, 0.016831395369081292, 0.08936743426602334, 0.12537695904029533, 0.032641265279380605, 0.025694707364891656, 0.05145466064277571, 0.11108851598692127, 0.11454723586211912, 0.05299343705701176, 0.05117655935464427, 0.03673489991342649, 0.0314632505615009, 0.08951312527642585, 0.14482976286672056, 0.13496773346560076, 0.09712832485092804, 0.07723087808699347, 0.011922447502001887, 0.020348175312392414, 0.05989760349621065, 0.03400346991838887, 0.05966087323031388, 0.02069739104626933, 0.11081113829277456, 0.11440739297540858, 0.04414543742313981, 0.05197478742047679, 0.04762124895933084, 0.08371963849640451, 0.11159828980453312, 0.04811728562344797, 0.030221604101825505, 0.031618018037988804, 0.05785335772088729, 0.0821482521132566, 0.052626170436269604, 0.09100127237616107, 0.018402993264317047, 0.05454291153000668, 0.019187762482033577, 0.02223332874564221, 0.042924708395730704, 0.03065586439333856, 0.028371669286570977, 0.024159901440725662, 0.008148887245624792, 0.03810544258158188, 0.060684135314659216, 0.07159871936892159, 0.12196235984447412, 0.05481313492055051, 0.03655599779449403, 0.04117444586881902, 0.05894384354178328, 0.04098563236766495, 0.034871485840994865, 0.10921600318397395, 0.049777317835832946, 0.034971531058545224, 0.028148292112746276, 0.04467048463993706, 0.056929795755422674, 0.07604926024214365, 0.026697638313635252, 0.04266671930963639, 0.1365907659055665, 0.04240892689267639, 0.2369987452402711, 1.0843486455269158, 2.8259658347815275, 17.858105041086674, 41.107805371284485, 59.88342247903347, 75.05256950855255, 79.26790371537209, 74.32117715477943, 65.64881891012192, 60.603312849998474, 59.4681541621685, 63.59529510140419, 58.925311490893364, 59.350314885377884, 62.76424929499626, 66.97120875120163, 68.42546671628952, 78.14659908413887, 81.41707599163055, 78.37109863758087, 66.32021248340607, 66.29396349191666, 80.34332200884819, 80.41279748082161, 72.23467111587524, 67.89546355605125, 60.86298331618309, 66.85306549072266, 52.94075421988964, 46.30608223378658, 46.607554256916046, 127.5540179014206, 69.2741359770298, 47.900047302246094, 54.587468057870865, 43.77026930451393, 61.48448936641216, 66.87407836318016, 55.192490592598915, 58.97846683859825, 53.23900781571865, 57.467933893203735, 53.17978419363499, 52.72881679236889, 47.69702419638634, 48.838524743914604, 51.21709071099758, 56.32408507168293, 61.46314591169357, 58.34604777395725, 50.78297920525074, 34.12841968238354, 22.129303850233555, 10.29168600216508, 3.3605375373736024, 0.2615252713439986, 0.2346158426371403, 0.04443755045940634, 0.060420342633733526, 0.0026385854653199203, 0.071670559264021, 0.05703233829990495, 0.02482405681803357, 0.07620960866915993, 0.09879466160782613, 0.07582818187074736, 0.03558944692485966, 0.055433036031899974, 0.04486241887207143, 0.025934894183592405, 0.00623313738287834, 0.03824899249593727, 0.06938291873666458, 0.038462029697257094, 0.11156041058711708, 0.09565282394760288, 0.07311644847504795, 0.10328268093871884, 0.05968564983049873, 0.02458864571963204, 0.026360655028838664, 0.040349563569179736, 0.05756852144259028, 0.024422976093774196, 0.06979145618970506, 0.13877368939574808, 0.060582527876249515, 0.011264077165833442, 0.005196707279537804, 0.04945418673742097, 0.061685633918386884, 0.0473394963046303, 0.02374716343183536, 0.05462660723424051, 0.05881898832740262, 0.1054681945242919, 0.17960099939955398, 0.0272642049822025, 0.11150338395964354, 0.01963696035090834, 0.01080314037608332, 0.008352646673301933, 0.06340411768178456, 0.07188861709437333, 0.054745250672567636, 0.003539104905030399, 0.017963278187380638, 0.0864632693992462, 0.056915119785116985, 0.016603511503490154, 0.04893203760730103, 0.030088245730439667, 0.012818524955946486, 0.31769296678248793, 0.18516695854486898, 0.16290010884404182, 0.15614196367096156, 0.11304305095109157, 0.17487028293544427, 0.11609828739892691, 0.19397298601688817, 0.2763679577037692, 0.23026106850011274, 0.16460798360640183, 0.26248249341733754, 0.15369312866823748, 0.2100737314322032, 0.20595580630470067, 0.1323890671483241, 0.09857719007413834, 0.14239894720958546, 0.24742155626881868, 0.2327528886962682, 0.11118225665995851, 0.17670212604571134, 0.2028325668652542, 0.19554436497855932, 0.36574774130713195, 0.09356294351164252, 0.16699240019079298, 0.14936594758182764, 0.2916868356987834, 0.26184914459008723, 0.11771379446145147, 0.1973303730483167, 0.06717810189002194, 0.19368806068086997, 0.11707143596140668, 0.178355764655862, 0.12688650225754827, 0.14633310172939673, 0.14861636358546093, 0.180689180851914, 0.12123164124204777, 0.21211138693615794, 0.21357531775720417, 0.22700761182932183, 0.3013297979487106, 0.165710206492804, 0.2064627970685251, 0.27770759363193065, 0.10571860257186927, 0.18116615916369483, 0.08829353173496202, 0.10688097652746364, 0.06759040203178301, 0.0994425565295387, 0.12014024629024789, 0.14328225137433037, 0.13599280267953873, 0.14996974408859387, 0.16972439421806484, 0.08967276866314933, 0.17873696138849482, 0.16404242254793644, 0.2099216653732583, 0.3641650074860081, 0.5493201955687255, 6.893115118145943, 27.858275435864925, 59.40122835338116, 87.1622385084629, 110.28309345245361, 105.25100067257881, 105.06090447306633, 100.03173753619194, 90.070511251688, 96.59642547369003, 88.04313004016876, 84.73210170865059, 87.29013204574585, 88.85105028748512, 90.11537164449692, 111.66553527116776, 106.27642124891281, 94.51246529817581, 78.07976827025414, 75.3294986486435, 96.60721689462662, 90.65602943301201, 83.42991158366203, 83.04506823420525, 83.53916332125664, 86.35811045765877, 66.0273925960064, 52.23702438175678, 56.81178890168667, 142.4034082889557, 78.12440067529678, 59.41857062280178, 76.43230587244034, 62.57707893848419, 88.02908599376678, 88.400918841362, 77.58163779973984, 84.1237923502922, 84.1438476741314, 79.38781768083572, 76.43871992826462, 71.46840423345566, 76.12517595291138, 80.43367356061935, 84.09217804670334, 93.8194964826107, 87.30695754289627, 75.10456591844559, 62.83987283706665, 39.56087417900562, 17.695956341922283, 3.9014342380687594, 0.7823458383791149, 0.18712815799517557, 0.21700552431866527, 0.17866647220216691, 0.22069999482482672, 0.15359375509433448, 0.21651368821039796, 0.1503531078924425, 0.14737415680428967, 0.2108069436508231, 0.21418432414066046, 0.16556205897359177, 0.13659493677550927, 0.11053390160668641, 0.11248204667936079, 0.13852854317519814, 0.1378372177714482, 0.12747328873956576, 0.1713659951929003, 0.19476058281725273, 0.2265054450253956, 0.2232668164651841, 0.15623813116690144, 0.180324355897028, 0.43671350518707186, 0.11097975424490869, 0.09447669057408348, 0.1628164094290696, 0.10696534387534484, 0.12186060397652909, 0.15669002488721162, 0.2071794297080487, 0.11773209582315758, 0.10399979597423226, 0.12016909357043914, 0.10859932299354114, 0.12954494945006445, 0.11352257482940331, 0.1307702501071617, 0.1927128786337562, 0.13365523045649752, 0.26847210014238954, 0.2705732686445117, 0.20837682561250404, 0.18473281699698418, 0.22287588275503367, 0.11132638916024007, 0.06467739076470025, 0.17000314488541335, 0.21384263935033232, 0.24636546528199688, 0.11603127888520248, 0.08547492907382548, 0.1771002882742323, 0.18344581418205053, 0.2621296764118597, 0.1900355363613926, 0.08303925977088511, 0.10203923477092758], [0.06503453449113294, 0.05002200021408498, 0.06841274618636817, 0.09179006403428502, 0.03907310667273123, 0.07778732557198964, 0.02375432144617662, 0.034151613726862706, 0.0426132030406734, 0.08745342798647471, 0.06604533962672576, 0.08399569516768679, 0.00882685491887969, 0.06122450045950245, 0.044205677550053224, 0.0424012456642231, 0.04255583873600699, 0.015790273500897456, 0.019229508288844954, 0.06108535890234634, 0.0565507364080986, 0.0254690406654845, 0.03347600701090414, 0.030477997570415027, 0.020019259172840975, 0.052753723357454874, 0.04726891434984282, 0.03421722329221666, 0.07657326103071682, 0.0343706771673169, 0.04566443560179323, 0.026437968263053335, 0.02451338637911249, 0.009230288251274033, 0.060841455779154785, 0.038000614222255535, 0.0433368935046019, 0.038352689080056734, 0.08965298300608993, 0.024016787538130302, 0.039121806403272785, 0.022697193307976704, 0.024433111975667998, 0.025709088331495877, 0.06777216884074733, 0.0406135826051468, 0.05486330410349183, 0.049286773064523004, 0.06251692466321401, 0.05168144612980541, 0.03284380851255264, 0.005270864994599833, 0.023764952711644582, 0.008147279568220256, 0.000772947558971282, 0.03419308122829534, 0.029140769911464304, 0.06377257916028611, 0.08020142064196989, 0.06271509293583222, 0.13758738117758185, 0.049929176093428396, 0.12577546265674755, 0.08995442112791352, 0.04181444804999046, 0.028300135527388193, 0.062315676477737725, 0.4336013237480074, 2.2297438653185964, 10.273581873625517, 19.43608056753874, 45.316429138183594, 54.47213664650917, 65.09495303034782, 74.87370550632477, 73.54825302958488, 80.96594139933586, 75.83173289895058, 69.60816845297813, 73.24056833982468, 70.88113814592361, 71.02532520890236, 70.96235498785973, 64.26842138171196, 62.06736668944359, 78.24132040143013, 82.94344648718834, 78.76968964934349, 81.38537809252739, 69.01916205883026, 68.5408741235733, 64.69999462366104, 80.19726544618607, 61.13020397722721, 52.26021073758602, 57.494156286120415, 51.917317137122154, 57.666518837213516, 68.54126170277596, 81.92503273487091, 70.53258284926414, 58.57421413064003, 58.40012647211552, 57.77855962514877, 50.25070756673813, 53.26865762472153, 47.18322716653347, 35.04617303609848, 30.533656775951385, 30.04719167947769, 18.628433905541897, 9.60577530786395, 5.536565110087395, 1.5432101231999695, 0.43368417711462826, 0.09455982595682144, 0.07666556193726137, 0.03849180837278254, 0.10754225979326293, 0.04730923152237665, 0.06290124583756551, 0.024148861994035542, 0.07187689858255908, 0.043464528062031604, 0.026772324345074594, 0.057630564988357946, 0.002727432834035426, 0.026877423588302918, 0.0624516156676691, 0.01902246949612163, 0.05616444112092722, 0.013872210456611356, 0.02577986324467929, 0.011290957754681585, 0.05265234598482493, 0.05339151022781152, 0.013303592677402776, 0.04712689325970132, 0.024361134783248417, 0.032054337789304554, 0.0315796638460597, 0.05225265493209008, 0.03408660530112684, 0.0690488780674059, 0.013655326147272717, 0.015171508803177858, 0.06649731498328038, 0.06115932876127772, 0.07481949927750975, 0.02048004938842496, 0.10208722946117632, 0.045978519920026883, 0.017662931022641715, 0.13420223782304674, 0.02990548629895784, 0.02736251914029708, 0.03445946400461253, 0.0435471031232737, 0.07686570432269946, 0.039692462305538356, 0.04538888359093107, 0.02073765997920418, 0.018254693604831118, 0.04317116450692993, 0.048816715279826894, 0.06964427346247248, 0.03913056003511883, 0.12976613914361224, 0.08496623879182152, 0.0904174470633734, 0.036140038864687085, 0.02555149512772914, 0.032055451010819525, 0.02023792556428816, 0.03522866296407301, 0.03749998737475835, 0.04305361944716424, 0.14596936031011865, 0.06873472695588134, 0.17881614854559302, 0.03802337589149829, 0.03553858754457906, 0.011059616408601869, 0.04732096858788282, 0.07482591143343598, 0.03217929319362156, 0.07262673490913585, 0.04029236995847896, 0.09324537109932862, 0.0760943308705464, 0.04436944727785885, 0.05267921915219631, 0.034965690356330015, 0.030201165354810655, 0.0678167273872532, 0.03813658680883236, 0.010221901447948767, 0.11280117760179564, 0.03066343801037874, 0.09633731417125091, 0.039197316218633205, 0.03974953717261087, 0.03332959982799366, 0.022800188562541734, 0.033326137709082104, 0.0343614262965275, 0.05804940345115028, 0.04010624674265273, 0.0152436715325166, 0.0364834120409796, 0.057878865336533636, 0.044686270121019334, 0.05960656657407526, 0.0453321315580979, 0.09333990587037988, 0.029946360082249157, 0.05455366896057967, 0.037680819077650085, 0.07049285995890386, 0.023088724447006825, 0.053868466275162064, 0.04446697661478538, 0.04882737994194031, 0.04054589873703662, 0.07554691532277502, 0.02151057338778628, 0.01185581655590795, 0.01899566312204115, 0.022849932865938172, 0.01777322901034495, 0.10595444226055406, 0.04984900187992025, 0.05021213844884187, 0.1463595370296389, 0.06594645587028936, 0.037573404333670624, 0.02253176488011377, 0.061347663577180356, 0.13606220833025873, 0.15101324825081974, 0.035224558887421153, 0.26137547625694424, 0.02200666942371754, 4.5420910231769085, 16.117019467055798, 35.79618439078331, 53.8326233625412, 75.52526414394379, 82.76989459991455, 88.17905634641647, 88.68661031126976, 92.46026381850243, 92.77024358510971, 90.39885923266411, 88.24915498495102, 90.15561148524284, 94.78446990251541, 92.79262438416481, 93.00340667366982, 91.71830803155899, 89.62542593479156, 109.15592193603516, 113.55210363864899, 105.76568305492401, 105.06576821208, 87.60953530669212, 77.24069729447365, 64.090606123209, 69.0949147939682, 61.941471844911575, 60.068958923220634, 66.72674506902695, 66.60431563854218, 77.80733808875084, 95.49962192773819, 106.70219600200653, 97.25206509232521, 82.26309299468994, 82.7268885076046, 80.39236217737198, 72.84179493784904, 73.72209370136261, 73.83475005626678, 67.48757064342499, 59.86207902431488, 61.61979250609875, 47.366354539990425, 28.63990869373083, 17.63516340404749, 8.720937687903643, 3.183572245761752, 0.8251422888133675, 0.11430291342549026, 0.12180083140265197, 0.038098997029010206, 0.006366786583384965, 0.06933748445590027, 0.03940319540561177, 0.09122501505771652, 0.029587902754428796, 0.09236410041921772, 0.02874005469493568, 0.027239307783020195, 0.06599580869078636, 0.028175009429105558, 0.03493591910228133, 0.04364515196357388, 0.04584484428050928, 0.04924817767459899, 0.06040924010449089, 0.024975909509521443, 0.021782045441796072, 0.06435851217247546, 0.021861217755940743, 0.07855309580918401, 0.06400772865163162, 0.0558918465685565, 0.11118278358480893, 0.053769500882481225, 0.025359811370435636, 0.03543214872479439, 0.03660457135993056, 0.06480883996118791, 0.0357708315277705, 0.11215926439035684, 0.1140410169318784, 0.06644249253440648, 0.0702074596483726, 0.061967928340891376, 0.008818430615065154, 0.028828539107053075, 0.026244570144626778, 0.09479438173002563, 0.008836757024255348, 0.07113205690984614, 0.01909555991005618, 0.04454869078472257, 0.02251222227641847, 0.04941294559102971, 0.014150294118735474, 0.03823381557594985, 0.011127304915135028, 0.043666592609952204, 0.11034055729396641, 0.023737359661026858, 0.038802170820417814, 0.022258674944168888, 0.062172323232516646, 0.06856451538624242, 0.03561893245205283, 0.05495996883837506, 0.005062002837803448, 0.14197853539371863, 0.26250858732964844, 0.11289983129245229, 0.24063035583822057, 0.2665920916479081, 0.1673738640965894, 0.10022271701018326, 0.15467530174646527, 0.10194601360126399, 0.21420267003122717, 0.2158573328051716, 0.1103892273386009, 0.30539385799784213, 0.20404551818501204, 0.07263069797772914, 0.0974753382615745, 0.15839050785871223, 0.11171783495228738, 0.13383877841988578, 0.19536068342858925, 0.18323192722164094, 0.1548917416948825, 0.14239280222682282, 0.14985576504841447, 0.10382982189184986, 0.18040139082586393, 0.11354581147315912, 0.1919375272700563, 0.27024194423574954, 0.14952972473111004, 0.08726022468181327, 0.10234902205411345, 0.08983671650639735, 0.11724869793397374, 0.16250240674708039, 0.1970409057685174, 0.1857465907232836, 0.12161475271568634, 0.22655257140286267, 0.1543781309737824, 0.12796215625712648, 0.13313122966792434, 0.1423939599771984, 0.1978075146325864, 0.2052117884159088, 0.248619174817577, 0.18905389762949198, 0.20771913434145972, 0.1456145098200068, 0.09334418064099737, 0.06372477000695653, 0.09675262743257917, 0.09616118026315235, 0.0623402267228812, 0.26186244387645274, 0.12004736650851555, 0.17892799020046368, 0.25785018573515117, 0.1835432878579013, 0.14687492890516296, 0.26438705215696245, 0.1507720650988631, 0.14311491191620007, 0.23860493092797697, 0.187791088828817, 0.10405169436126016, 0.15604184794938192, 0.7836532650981098, 5.701784044504166, 20.476153157651424, 43.16329747438431, 78.03074330091476, 99.11017298698425, 120.09570211172104, 122.1495147049427, 124.58907499909401, 126.32207080721855, 124.79788139462471, 117.22628608345985, 115.01618027687073, 116.23913705348969, 106.22478201985359, 110.03029301762581, 103.54429185390472, 102.18765065073967, 135.14860957860947, 138.4636428952217, 119.16947901248932, 116.0189388692379, 89.57531422376633, 90.03856256604195, 76.26619398593903, 91.55465081334114, 77.96702072024345, 77.91467472910881, 82.80758857727051, 75.04750818014145, 86.78531393408775, 101.05765208601952, 121.82723119854927, 119.47854682803154, 108.84394347667694, 107.97581925988197, 104.22250986099243, 104.9584011733532, 111.09118849039078, 105.84686189889908, 95.29650002717972, 78.23108375072479, 75.91130822896957, 45.31897880136967, 21.52106288820505, 9.008210822939873, 2.8775616036728024, 0.695873819058761, 0.2190156461438164, 0.17911352711962536, 0.2079298152239062, 0.13117783761117607, 0.07158543492550962, 0.11934093839954585, 0.18474200478522107, 0.2500878256978467, 0.12060250781360082, 0.12480341247282922, 0.16472809278639033, 0.08893235761206597, 0.16049268568167463, 0.14817483024671674, 0.1515759149333462, 0.13033045339398086, 0.10925768219749443, 0.14740868151420727, 0.09453207705519162, 0.10709878944908269, 0.1976103408378549, 0.2380086449556984, 0.1277504363679327, 0.19789939251495525, 0.14431321324082091, 0.18869950727093965, 0.12704915134236217, 0.18949085933854803, 0.20076167798833922, 0.09296524003730156, 0.09144738476607017, 0.17820706794736907, 0.2094399818452075, 0.20443078188691288, 0.279172029113397, 0.16338514687959105, 0.12572628795169294, 0.18493822863092646, 0.2259029250126332, 0.13454788568196818, 0.14107875555055216, 0.15521324006840587, 0.11920718112378381, 0.17046875349478796, 0.114881588233402, 0.22148423711769283, 0.0940928517957218, 0.13436242297757417, 0.15878924896242097, 0.12796899885870516, 0.15494219289394096, 0.23471885273465887, 0.15833103214390576, 0.11147903409437276, 0.1821055993787013, 0.06817830915679224, 0.12882335926406085, 0.1907272476819344, 0.19455398374702781, 0.09164509290712886, 0.17133196030044928], [0.046035476043471135, 0.0475434199324809, 0.04376633354695514, 0.05827090855746064, 0.04421481709869113, 0.10460563338710926, 0.020105771327507682, 0.020086952317797113, 0.054835610862937756, 0.04919998631521594, 0.12254631132236682, 0.008773255158303073, 0.10662639760994352, 0.10689514412661083, 0.037679256856790744, 0.09573018542141654, 0.06217781512532383, 0.037080833499203436, 0.08845876349369064, 0.02112257858243538, 0.05623280034342315, 0.009616627139621414, 0.04851926249102689, 0.012561648163682548, 0.05754314741352573, 0.0251829631451983, 0.08962861829786561, 0.045992052982910536, 0.013668455667357193, 0.042056625679833815, 0.024073181484709494, 0.041733754333108664, 0.02394957122305641, 0.03230972193705384, 0.0497553947934648, 0.06647540678386576, 0.04834630868572276, 0.036713871159008704, 0.04151241621002555, 0.09599755154340528, 0.05290645363857038, 0.06509512342745438, 0.022974700877966825, 0.0732481203158386, 0.10597228349070065, 0.05775392477517016, 0.017347464454360306, 0.08075226491200738, 0.049491835889057256, 0.049801393106463365, 0.0421239755814895, 0.027322599016770255, 0.0824879108404275, 0.05340994888683781, 0.04671042966947425, 0.013660340282513062, 0.02387928427197039, 0.06810531151131727, 0.00957590549660381, 0.025427847758692224, 0.014030363981873961, 0.06059721497877035, 0.06072243384551257, 0.061505982230301015, 0.0680731023021508, 0.04642088446416892, 0.09692333624116145, 0.08718160897842608, 0.021061065672256518, 0.270167343551293, 0.18280933349160478, 0.33390096738003194, 1.7389218276366591, 1.4957118406891823, 12.129330094903708, 25.554004982113838, 30.866496115922928, 36.005021184682846, 52.312659323215485, 67.2191834449768, 83.8679064810276, 85.67457273602486, 84.38494473695755, 83.36520105600357, 78.5558371245861, 34.140997007489204, 25.086438171565533, 55.017908960580826, 86.12187713384628, 120.42748510837555, 118.63962784409523, 108.40158641338348, 103.1033407151699, 88.31581100821495, 102.26362377405167, 108.0690510571003, 113.49820733070374, 107.85732641816139, 95.855503231287, 61.01446598768234, 29.127443432807922, 29.76509101688862, 28.2877853885293, 23.563451394438744, 21.04559250175953, 21.365605629980564, 13.837805818766356, 7.771588079631329, 3.9995385613292456, 1.5496436529792845, 1.095322456676513, 0.060749856202164665, 0.15801556000951678, 0.008065733309194911, 0.16691938770236447, 0.08819092981866561, 0.033182784463861026, 0.040635364639456384, 0.035203823281335644, 0.019878256680385675, 0.012462758841138566, 0.04647603716875892, 0.04662384330003988, 0.018207969842478633, 0.04189189487078693, 0.04086645087227225, 0.08395146316615865, 0.07676591514609754, 0.037920684917480685, 0.025012987207446713, 0.02942483621154679, 0.04686694861447904, 0.07236054880195297, 0.05735593324061483, 0.04587922427162994, 0.022689493525831494, 0.018918145797215402, 0.044659062987193465, 0.02011544336710358, 0.04824209259822965, 0.07382203053566627, 0.02830807279678993, 0.03612099164456595, 0.04336398189479951, 0.05724746093619615, 0.04176851281954441, 0.02179971597797703, 0.04557225343887694, 0.017517271553515457, 0.04978241639037151, 0.04217087189317681, 0.018307452883163933, 0.025219345079676714, 0.00950675866988604, 0.021672027614840772, 0.011743298618966946, 0.03213520591089036, 0.031141800427576527, 0.021677552904293407, 0.15796438150573522, 0.12140122940763831, 0.0510476557246875, 0.0945761235198006, 0.008504996603733161, 0.0491314081591554, 0.012899356897833059, 0.07895770730101503, 0.021298612300597597, 0.05945654884271789, 0.04219611604639795, 0.007683934509259416, 0.019299197811051272, 0.022752774602849968, 0.06476414040662348, 0.016113391611725092, 0.06297381303738803, 0.01381772939566872, 0.011204130187252304, 0.06075596778828185, 0.06052232114598155, 0.01205256268804078, 0.05139297332789283, 0.07174253274570219, 0.023250345657288563, 0.04064234082761686, 0.02131555553205544, 0.07214863595436327, 0.06833496910985559, 0.09020649900776334, 0.04189750921796076, 0.037276448783813976, 0.07512821786804125, 0.028902787271363195, 0.039715309321763925, 0.05884374266315717, 0.03209957169019617, 0.012103499066142831, 0.03226538232411258, 0.06228670303244144, 0.003237629675822973, 0.018468393172952347, 0.056644647775101475, 0.06295316648902372, 0.08918568972148933, 0.038114622948342, 0.03721820132341236, 0.033999191437033005, 0.03382715047337115, 0.07304326529265381, 0.02285851580381859, 0.07070691761327907, 0.006411398471755092, 0.06839737630798481, 0.029056283819954842, 0.07624517980730161, 0.015735070701339282, 0.012736517637677025, 0.05909907857130747, 0.009453866732656024, 0.1105755360913463, 0.046436896300292574, 0.036542461020872, 0.05253792536677793, 0.10138767363969237, 0.06493136112112552, 0.044530040613608435, 0.05249187881418038, 0.02708762578549795, 0.08695252283359878, 0.041760334352147765, 0.06385086089721881, 0.06655181088717654, 0.061995814539841376, 0.018475502947694622, 0.030238324688980356, 0.02732152475800831, 0.06513982298201881, 0.03119939108728431, 0.018833450048987288, 0.0533354335493641, 0.08201567485230044, 0.08131731388857588, 0.10338466687244363, 0.09874507872154936, 0.13188044365961105, 0.9482262935489416, 1.3921716716140509, 3.784073260612786, 12.850493397563696, 18.718139491975307, 34.87001448869705, 49.64972421526909, 58.261593505740166, 64.44160848855972, 81.98691621422768, 97.91619345545769, 111.92046359181404, 116.63939237594604, 113.87345999479294, 111.33041605353355, 111.02107465267181, 55.93686684966087, 45.21334446966648, 78.08654710650444, 110.45090764760971, 140.07965058088303, 136.7299783229828, 128.73321622610092, 121.53846189379692, 110.83544701337814, 129.90692764520645, 133.88484299182892, 136.04375034570694, 130.2577856183052, 121.33806824684143, 86.08652383089066, 54.75359134376049, 56.59830495715141, 55.319232791662216, 55.2523335814476, 49.934484735131264, 43.179511204361916, 32.64332637190819, 17.2510914131999, 11.6739596799016, 5.516024837270379, 2.602566797286272, 0.5122499784920365, 0.39271183661185205, 0.12371805860311724, 0.14560786017682403, 0.10289069337886758, 0.019306708345538937, 0.03916528512490913, 0.0659659669327084, 0.018206849199486896, 0.011999621583527187, 0.05067020312708337, 0.040580579297966324, 0.05118982895510271, 0.035687903946381994, 0.035694527614396065, 0.06001440640829969, 0.061172865534899756, 0.03216283606889192, 0.03702076035551727, 0.05513948322914075, 0.029727940454904456, 0.022960368150961585, 0.022273484501056373, 0.07225390960229561, 0.032591333583695814, 0.06361064995871857, 0.04021476357593201, 0.05039428004238289, 0.00827027013656334, 0.05215778619458433, 0.023551898812002037, 0.028703578136628494, 0.025740243690961506, 0.04739780313684605, 0.041187555907526985, 0.0701282502268441, 0.01833854887081543, 0.08188158361008391, 0.053154182533035055, 0.012596740616572788, 0.06409744688426144, 0.02182359643484233, 0.10960650644847192, 0.07016291594482027, 0.038002105939085595, 0.024698348133824766, 0.022305426537059247, 0.015080282155395253, 0.0560500464780489, 0.11672523149172775, 0.04927039015456103, 0.10622520741890185, 0.023430479741364252, 0.04530360711214598, 0.07128013763576746, 0.08541271483409218, 0.0742066337261349, 0.0466752741340315, 0.011930338387173833, 0.03453234661719762, 0.027622072302619927, 0.03400207839149516, 0.012727160083159106, 0.041343213961226866, 0.00951169859035872, 0.13216386985732242, 0.14069583703530952, 0.1469528692541644, 0.18024110177066177, 0.07807780959410593, 0.18579665600555018, 0.13034019037149847, 0.15681617514928803, 0.12521349359303713, 0.1668439558125101, 0.19604880275437608, 0.1322714812704362, 0.23123755672713742, 0.21301055821822956, 0.1495013598469086, 0.1212675982969813, 0.13424969074549153, 0.22986330703133717, 0.16037560446420684, 0.11687176855048165, 0.1393803209066391, 0.1303195141372271, 0.12256123591214418, 0.12075652572093531, 0.18965273658977821, 0.13580815633758903, 0.14341772301122546, 0.18158119783038273, 0.12750436988426372, 0.19871698692440987, 0.07802305393852293, 0.16848325612954795, 0.23711906222160906, 0.09072915650904179, 0.29418454854749143, 0.10389000264694914, 0.08266561810160056, 0.06940465624211356, 0.26991421182174236, 0.25596605089958757, 0.216608356568031, 0.13513367768609896, 0.13564831257099286, 0.17204842966748402, 0.329399990150705, 0.11179337074281648, 0.21319793566362932, 0.19694868649821728, 0.10927331182756461, 0.3002152405679226, 0.15254293335601687, 0.09974323766073212, 0.22270379355177283, 0.11418222537031397, 0.14208562730345875, 0.12472461123252288, 0.166099596535787, 0.0839458080008626, 0.09787093265913427, 0.15616203134413809, 0.16436510835774243, 0.14751112757949159, 0.16804936691187322, 0.14484588231425732, 0.2502426673891023, 0.19591588410548866, 0.23401005717460066, 0.2027141794678755, 0.15670048916945234, 0.30930960725527257, 0.3740848501911387, 0.8423958567436785, 4.848083378747106, 9.91554418578744, 21.721751019358635, 38.766222819685936, 48.269535675644875, 57.810417115688324, 79.51526284217834, 96.94718465209007, 118.28909665346146, 124.61348488926888, 127.79994070529938, 115.64332142472267, 120.55980160832405, 60.799967497587204, 51.54499031603336, 85.77011480927467, 129.2703402042389, 167.3239454627037, 162.52386063337326, 148.73590528964996, 140.56116074323654, 123.53481397032738, 145.13885110616684, 152.2294682264328, 157.84129589796066, 153.19365888834, 132.61358320713043, 93.60797703266144, 49.19681891798973, 50.72281323373318, 51.70474894344807, 50.45603334903717, 45.83484672009945, 35.36805376410484, 22.439587600529194, 10.776054561138153, 6.70001232996583, 1.8793828343041241, 0.8651026070583612, 0.2628387836739421, 0.3367046528728679, 0.1592543232254684, 0.15374656330095604, 0.17056649434380233, 0.16092756937723607, 0.13597562938230112, 0.17905704968143255, 0.11399976094253361, 0.05187818947888445, 0.1493043196387589, 0.12993362703127787, 0.07962437113747001, 0.08915031154174358, 0.16447233385406435, 0.1549333761795424, 0.1695764099713415, 0.16208022861974314, 0.09890792076475918, 0.1229907241940964, 0.07257705554366112, 0.1119587138236966, 0.18154609424527735, 0.1811253558844328, 0.12282474286621436, 0.1084727793931961, 0.23823946772608906, 0.17567070404766127, 0.11906299667316489, 0.2477889638976194, 0.10943019442493096, 0.11617843192652799, 0.09867671949905343, 0.11742743678041734, 0.133181324636098, 0.14668961463030428, 0.21450233442010358, 0.19244914903538302, 0.131673785217572, 0.12935666658449918, 0.13222837733337656, 0.15456550841918215, 0.13110142608638853, 0.15356653311755508, 0.20045312267029658, 0.18982032837811857, 0.08135056210448965, 0.0705993062001653, 0.23288316529942676, 0.2066541524254717, 0.13816745864460245, 0.17538960819365457, 0.2582831250037998, 0.09269500922528096, 0.22491943091154099, 0.30116367561277, 0.15686909027863294, 0.24104137206450105, 0.11237788625294343, 0.17351794143905863, 0.10986147870426066, 0.08458812197204679, 0.2250370613182895, 0.16771746362792328, 0.19567011448089033], [0.0509955569577869, 0.01780325259460369, 0.012695140121650184, 0.017312485178990755, 0.039041543132043444, 0.04917068261420354, 0.019033918979403097, 0.016059342851804104, 0.008625385016785003, 0.0167093361960724, 0.02234404419141356, 0.03456852260569576, 0.03794782154727727, 0.03696727748319972, 0.06096602155594155, 0.03960671827371698, 0.051231637844466604, 0.03146556977299042, 0.01109824519517133, 0.03346339792187791, 0.02376765969529515, 0.028355872673273552, 0.031421931489603594, 0.054590063882642426, 0.044353739722282626, 0.01473773369070841, 0.02373042985709617, 0.05777248217782471, 0.06025292896083556, 0.024453947771689855, 0.05234318210568745, 0.06047183655027766, 0.04616952646756545, 0.05049628824053798, 0.06578336891834624, 0.04521256414591335, 0.042475686786929145, 0.04178269155090675, 0.10864874260732904, 0.048191047681029886, 0.011138920453959145, 0.0638935566530563, 0.05829056062793825, 0.025647850015957374, 0.060995930107310414, 0.058841508798650466, 0.04341437372204382, 0.0571729975490598, 0.06028307128872257, 0.02996498984430218, 0.04624546301783994, 0.010013281880674185, 0.051982739532832056, 0.04138327138207387, 0.01410177714205929, 0.06964953528949991, 0.013328691184142372, 0.05595026472292375, 0.012190052038931753, 0.021684527237084694, 0.019391398527659476, 0.0497120385261951, 0.05659959941112902, 0.013833105767844245, 0.03913773660315201, 0.006382621231750818, 0.07220255298307166, 0.020787550856766757, 0.024540291087760124, 0.049138440008391626, 0.025847250253718812, 0.027417300771048758, 0.11814114535809495, 0.09558610487147234, 0.27465190447401255, 0.15308753616409376, 0.10383587039541453, 0.11682139898766764, 0.3164502850268036, 0.4235245910240337, 0.8346360793802887, 1.1991647095419466, 1.8636711523868144, 0.9654648997820914, 0.2763508289353922, 0.05993684826535173, 0.23985883395653218, 0.08473189824144356, 0.8677941688802093, 12.890500500798225, 27.776862904429436, 45.75207196176052, 53.96566942334175, 58.629022389650345, 62.34606273472309, 51.33222073316574, 26.50652837008238, 9.419047627598047, 2.2782254638150334, 0.11470729485154152, 0.11353803376550786, 0.28333434951491654, 0.2006887990864925, 0.311881416128017, 0.28685839322861284, 0.1050651934929192, 0.12430364280589856, 0.11528616261784919, 0.1193029033311177, 0.021687694352294784, 0.04738664494652767, 0.04777606467541773, 0.09067575156223029, 0.008980918282759376, 0.05304855636495631, 0.0259102400377742, 0.0373846019647317, 0.016377061838284135, 0.03251220579841174, 0.05082673691504169, 0.036240863337297924, 0.016734739911044016, 0.08434667164692655, 0.035200505881221034, 0.023493367480114102, 0.023913382246973924, 0.03563917081919499, 0.01583979701536009, 0.05828645655128639, 0.049350211847922765, 0.01547561865663738, 0.06228648780961521, 0.026595644958433695, 0.07132482234737836, 0.044540898234117776, 0.039080539281712845, 0.08194605397875421, 0.06601307104574516, 0.018422393004584592, 0.00415438545132929, 0.06302619382040575, 0.03288527230324689, 0.04706676074420102, 0.03090401445660973, 0.06353470598696731, 0.07914671747130342, 0.02360622773267096, 0.025761105462152045, 0.022413134429370984, 0.0044577086282515666, 0.029816484238835983, 0.04553522769128904, 0.01930727423314238, 0.012403532673488371, 0.015188594898063457, 0.03045682780793868, 0.02929765065346146, 0.04060263963765465, 0.057946560336858965, 0.04266196585376747, 0.020420085711521097, 0.00996191691228887, 0.04423218335432466, 0.024864409242582042, 0.022314157904474996, 0.09349461397505365, 0.02747650745732244, 0.05987461547192652, 0.02578518815425923, 0.09232509313733317, 0.006891361144880648, 0.043586273677647114, 0.035742956461035646, 0.019003863853868097, 0.024276808253489435, 0.07233576849102974, 0.027440763769845944, 0.07582861973787658, 0.060926008663955145, 0.03610319494327996, 0.008505702571710572, 0.010568933412287151, 0.035489999136189, 0.025398852048965637, 0.009598068809282267, 0.03100462185102515, 0.05862425248778891, 0.050828395615099, 0.023306785988097545, 0.04793084328412078, 0.010820591978699667, 0.042042432105517946, 0.04172503038716968, 0.09829414237174205, 0.052978972598793916, 0.04199253009574022, 0.043441829475341365, 0.07358699236647226, 0.012525299625849584, 0.007739129887340823, 0.0909842475084588, 0.07021738958428614, 0.04021648164780345, 0.0339728340622969, 0.009879716635623481, 0.02264410377392778, 0.05917599846725352, 0.03905723955540452, 0.03116828025667928, 0.03466228554316331, 0.025867533149721567, 0.01941083351994166, 0.04615835343429353, 0.052215454779798165, 0.05893432549783029, 0.025308443618996534, 0.030062764089962002, 0.051605093976831995, 0.018414476144243963, 0.03220998842152767, 0.031705647124908864, 0.03295287082437426, 0.01806891363230534, 0.04310075324610807, 0.03628568163549062, 0.04467161270440556, 0.03278678559581749, 0.041450131466262974, 0.08989137568278238, 0.05172146644326858, 0.02352323706872994, 0.057408414213568904, 0.042750841748784296, 0.04251751051924657, 0.05427485149994027, 0.028641510471061338, 0.02937364472018089, 0.029376795137068257, 0.049272453325102106, 0.019473403990559746, 0.02340013703360455, 0.04334469347668346, 0.04054626238939818, 0.0743290880927816, 0.04823555798793677, 0.05491581105161458, 0.04305888869566843, 0.043662106327246875, 0.13532531505916268, 0.12238293493282981, 0.43426421005278826, 0.5768932378850877, 0.5157291668001562, 0.40412945207208395, 1.3855140726082027, 1.8614290351979434, 4.375883666798472, 4.129253625869751, 4.886282728984952, 3.069188646040857, 0.9480649803299457, 0.05438288222649135, 0.18963660229928792, 0.12897106149466708, 1.91878434503451, 18.979103788733482, 38.452412858605385, 61.45816057920456, 77.5083701312542, 80.3358668088913, 78.2781708240509, 70.53157210350037, 44.10008780658245, 18.920621126890182, 6.484688334167004, 0.4971713782288134, 0.29584844363853335, 0.4278115922352299, 0.33904856303706765, 0.48343959788326174, 0.7247627782635391, 0.4161275754449889, 0.24294042406836525, 0.15083289152244106, 0.102284937602235, 0.019906706911569927, 0.11569702299311757, 0.03251360103604384, 0.05550755136937369, 0.06359717997838743, 0.07698963556322269, 0.008575446827308042, 0.03362127499713097, 0.0733971361478325, 0.04768930761201773, 0.07458606414729729, 0.034620053629623726, 0.04074554759426974, 0.03091088859946467, 0.05318436938978266, 0.05564095241425093, 0.03099375680903904, 0.049023956307792105, 0.07026249732007273, 0.014189670619089156, 0.033522662124596536, 0.03724500027601607, 0.030027044522284996, 0.027938331113546155, 0.10428188630612567, 0.022417874897655565, 0.05980385540169664, 0.019564027643355075, 0.055150526386569254, 0.010775504651974188, 0.025738748263393063, 0.020953005259798374, 0.0836270629952196, 0.030064730781305116, 0.07045798643957824, 0.08887464820872992, 0.018968691620102618, 0.05054624591139145, 0.02103143728163559, 0.04923071865050588, 0.005114631776450551, 0.04091250855708495, 0.009732122016430367, 0.023186470862128772, 0.03314265653898474, 0.07152116493671201, 0.013527004175557522, 0.058085449563805014, 0.1066832832293585, 0.013318290912138764, 0.04220135560899507, 0.04067185232997872, 0.05383393043302931, 0.058378679532324895, 0.028239500206836965, 0.07680300026549958, 0.0007697673981965636, 0.038582836496061645, 0.014609263289457886, 0.01647892717301147, 0.0780220891465433, 0.03980482346378267, 0.014782788548473036, 0.032929033041000366, 0.02301188989804359, 0.029263445067044813, 0.05483209308295045, 0.11792526202043518, 0.10653095741872676, 0.29781139455735683, 0.2155374374706298, 0.07838774530682713, 0.1032657599716913, 0.08823416734230705, 0.08906546921934932, 0.09944179953890853, 0.1702248540823348, 0.1388102475902997, 0.23557172884466127, 0.12423688662238419, 0.09474854668951593, 0.16882804309716448, 0.1235287738381885, 0.2361503368592821, 0.16589207720244303, 0.11820657309726812, 0.1412820743280463, 0.15633723756764084, 0.1553765867720358, 0.10776647744933143, 0.15766167431138456, 0.18890600244048983, 0.18151766998926178, 0.1227862031373661, 0.11406256147893146, 0.13956530863652006, 0.1385013954131864, 0.1840240362798795, 0.189527343318332, 0.0956780940759927, 0.18190918257459998, 0.14176257041981444, 0.0882730855664704, 0.10020786663517356, 0.12040845103911124, 0.21845198498340324, 0.17201199021656066, 0.12211167995701544, 0.1811447853106074, 0.18999949767021462, 0.14547083002980798, 0.11685098099405877, 0.15215523540973663, 0.15626363136107102, 0.14267838065279648, 0.2083691963343881, 0.1993947458686307, 0.12582741299411282, 0.09430849764612503, 0.18249561282573268, 0.17598476610146463, 0.1747306701145135, 0.12444496256648563, 0.12710975512163714, 0.17481845134170726, 0.10776937182527035, 0.12785276368958876, 0.15298265585443005, 0.14531349472235888, 0.17574107449036092, 0.1293732164776884, 0.06682217528577894, 0.19886087451595813, 0.17874770768685266, 0.26231156196445227, 0.17629722511628643, 0.13315871881786734, 0.08102008374407887, 0.13583831721916795, 0.2831704536220059, 0.23742227407637984, 0.3940335422521457, 0.32099243660923094, 0.28555725992191583, 0.20011314481962472, 0.5737736646551639, 0.6250106496736407, 1.6198749281466007, 1.5847886796109378, 2.5743478490039706, 1.579015483148396, 0.4113391198916361, 0.15409295330755413, 0.3446649288525805, 0.27676016790792346, 1.4373571844771504, 18.44753321260214, 41.146521493792534, 69.8221805691719, 93.02089333534241, 93.39474007487297, 86.92139223217964, 76.77129328250885, 41.31915383040905, 14.630059506744146, 3.865504078567028, 0.23286214767722413, 0.31803857011254877, 0.3115033661015332, 0.3105369710829109, 0.29975525743793696, 0.5929879867471755, 0.29011279984842986, 0.26469139207620174, 0.22976593725616112, 0.2783649286720902, 0.11691067193169147, 0.1475295625277795, 0.1606243575224653, 0.20644924545194954, 0.10926911869319156, 0.16547041857847944, 0.1255001110257581, 0.11484551985631697, 0.1746571678086184, 0.0960899044002872, 0.25815574277658015, 0.20165016234386712, 0.10824989760294557, 0.14082632143981755, 0.16672305995598435, 0.1890258296043612, 0.11333565751556307, 0.0965273856127169, 0.1628794622956775, 0.13180757960071787, 0.18435761681757867, 0.0889376194390934, 0.12216247996548191, 0.10809930841787718, 0.25998492899816483, 0.10552846433711238, 0.08247057427070104, 0.2607221785001457, 0.1192846464982722, 0.12673200195422396, 0.119142027979251, 0.14413340570172295, 0.1582152274204418, 0.14404700486920774, 0.2169536630390212, 0.16356171865481883, 0.1292867711163126, 0.14100443688221276, 0.09816399193368852, 0.1295156791456975, 0.08317571104271337, 0.1229921416961588, 0.13436616340186447, 0.11158688299474306, 0.09436029213247821, 0.13734691048739478, 0.19412067340454087, 0.20000562246423215, 0.1874159331782721, 0.12933584192069247, 0.13923160935519263, 0.10227351594949141, 0.14742537983693182, 0.18201511673396453, 0.07536429504398257, 0.2062519232276827, 0.18509784975321963, 0.1480072978301905, 0.1554230452165939, 0.15261823165928945, 0.20900503877783194, 0.07641489413799718, 0.09610924476874061, 0.08810307437670417, 0.1594092688173987, 0.08336268772836775, 0.15218664309941232], [0.057044624554691836, 0.044562082839547656, 0.07698988789343275, 0.07584287639474496, 0.025713216527947225, 0.08087971393251792, 0.043345105368644, 0.020081890870642383, 0.01870898446213687, 0.005934244363743346, 0.04465834310394712, 0.006844522349638282, 0.03654473570350092, 0.047218522522598505, 0.045708370744250715, 0.08031292833038606, 0.0009727967380968039, 0.01739673378324369, 0.05271504633128643, 0.030335110022861045, 0.013076280265522655, 0.07135080493753776, 0.04202079479000531, 0.060166268376633525, 0.015251941840688232, 0.046386908943532035, 0.015338223001890583, 0.028547396868816577, 0.043956664740107954, 0.03653977815702092, 0.04759245362947695, 0.008808421825960977, 0.03601446747779846, 0.037300190087989904, 0.04888790208497085, 0.016875118999450933, 0.03941440554626752, 0.08002864866284654, 0.032382270583184436, 0.02493147156201303, 0.017184435018862132, 0.02330158167751506, 0.053905005916021764, 0.045718356341239996, 0.05868405845831148, 0.05749331961851567, 0.016862059055711143, 0.0625052432587836, 0.04217672743834555, 0.03916790861694608, 0.022347129670379218, 0.036353706891532056, 0.057075241857091896, 0.05311363158398308, 0.024503974091203418, 0.01014842511722236, 0.016554030662518926, 0.028615320079552475, 0.028316893221926875, 0.04110602356377058, 0.08369424962438643, 0.04315932354074903, 0.043148451077286154, 0.01723791046970291, 0.09470796605455689, 0.04070875562319998, 0.0908316916320473, 0.06425484898500144, 0.03731892560608685, 0.016495135678269435, 0.03598138253437355, 0.022811426533735357, 0.048264846845995635, 0.04150569606281351, 0.0773202846175991, 0.01638050911424216, 0.08147723186993971, 0.1440690763411112, 0.05049778366810642, 0.03770293878915254, 0.012658472460316261, 0.17343709187116474, 0.019476303932606243, 0.032952529436443, 0.00873385639351909, 0.03154609279590659, 0.18707064155023545, 0.13486448588082567, 0.015446918878296856, 0.3887250192929059, 0.8600171143189073, 0.6343225250020623, 0.4989401833154261, 0.2413930610055104, 0.06287682917900383, 0.6462753773666918, 0.7150816102512181, 0.2367583487648517, 0.0456643317011185, 0.19399204436922446, 0.09230095849488862, 0.05959803187579382, 0.13623747392557561, 0.10066137081594206, 0.12276181616471149, 0.050779243174474686, 0.047040692807058804, 0.03909126702637877, 0.040185044272220694, 0.04277041218301747, 0.022774152166675776, 0.07264778963872232, 0.09562837018165737, 0.04241966576955747, 0.02120365265000146, 0.03642654868599493, 0.12113349963328801, 0.06748987812898122, 0.046123850988806225, 0.05689383870048914, 0.06605862407013774, 0.026532126394158695, 0.07124913070583716, 0.058216171455569565, 0.03487936744932085, 0.037083093338878825, 0.01000823898721137, 0.05928879007115029, 0.05124443618115038, 0.025621952772780787, 0.04737472234410234, 0.06980703386943787, 0.05886711289349478, 0.03973858678364195, 0.10067030627396889, 0.04806500503036659, 0.04923560940369498, 0.03139653890684713, 0.040406768312095664, 0.013463871528074378, 0.009525021068839123, 0.0417672326148022, 0.018836797135008965, 0.08224509496358223, 0.09433321858523414, 0.012019344158034073, 0.003588284248507989, 0.03397275984752923, 0.02101878922985634, 0.04380515900265891, 0.01587330683832988, 0.011604686769715045, 0.03844284146907739, 0.010795030557346763, 0.0074082688570342725, 0.04559854402032215, 0.04902852051600348, 0.05601358105195686, 0.02661415968759684, 0.018108980329998303, 0.06496590809547342, 0.041485019828542136, 0.047821216940064915, 0.04674310272093862, 0.0417560113419313, 0.028351859509712085, 0.019461446136119775, 0.025499769290036056, 0.062353637331398204, 0.08368871320271865, 0.008519731945852982, 0.01743390424962854, 0.011869094505527755, 0.04772975094965659, 0.05626208549074363, 0.07413094950607046, 0.09876625219476409, 0.033926045362022705, 0.07221963722258806, 0.008729897963348776, 0.05444400179840159, 0.012654422189370962, 0.004619518622348551, 0.031404134788317606, 0.06985951855313033, 0.02488920439645881, 0.014467792316281702, 0.014169772712193662, 0.01566430692037102, 0.049132885033031926, 0.02657606153661618, 0.06930742005351931, 0.06923347245901823, 0.06411953319911845, 0.08835455111693591, 0.008675624703755602, 0.06126575644884724, 0.024870739762263838, 0.05511486990144476, 0.020925456738041248, 0.02239787958387751, 0.020106201773160137, 0.06130971014499664, 0.038876352191437036, 0.041680416179588065, 0.04117021191632375, 0.019428667328611482, 0.05358187481760979, 0.03916993839084171, 0.05061600408225786, 0.034352138318354264, 0.03866879203997087, 0.049007684719981626, 0.08667639194754884, 0.041409220575587824, 0.00838916497741593, 0.009961949381249724, 0.01468058924729121, 0.05690006903023459, 0.001246942842954013, 0.08514444329193793, 0.0750283693196252, 0.01822109657950932, 0.0980285054538399, 0.042522345611359924, 0.05742855239077471, 0.03264378487074282, 0.026891522538790014, 0.04986605272279121, 0.02698525207961211, 0.03707959040184505, 0.03011673121363856, 0.012688696424447699, 0.03349902843183372, 0.02148923849745188, 0.018116296050720848, 0.04946635053784121, 0.03419451357331127, 0.025753392692422494, 0.05407962955359835, 0.07453308964613825, 0.02422826994006755, 0.1125103521917481, 0.048491101697436534, 0.06448901141993701, 0.05781109241070226, 0.07606595114339143, 0.020679421795648523, 0.07047735649393871, 0.06607778632314876, 0.09677319234469905, 0.11880118181579746, 0.10835281864274293, 0.16315362649038434, 0.01872914861451136, 0.01654042338486761, 0.07563126040622592, 0.04757031907502096, 0.00827459036372602, 0.015639790071872994, 0.043567111424636096, 0.1230588459293358, 0.22175488353241235, 0.14469872927293181, 0.0402729071356589, 0.24418962188065052, 0.35276935959700495, 0.23667969595408067, 0.28685343568213284, 0.22377610788680613, 0.055790335609344766, 0.515965229133144, 0.4516587860416621, 0.2572290081297979, 0.041360461473232135, 0.08693232899531722, 0.06327493945718743, 0.1182803871051874, 0.0542413361108629, 0.09644315927289426, 0.06223937627510168, 0.08424054452916607, 0.043225430345046334, 0.051179917572881095, 0.011442647173680598, 0.04218620095343795, 0.03953246268793009, 0.025779686984606087, 0.04649862814403605, 0.017773086146917194, 0.02659768215380609, 0.08784727833699435, 0.046257530339062214, 0.05432449375803117, 0.03128686803393066, 0.03708431417180691, 0.029939942360215355, 0.04780127543199342, 0.018552500769146718, 0.008383169351873221, 0.007648047958355164, 0.013851640906068496, 0.03724659218278248, 0.04924694942019414, 0.026554685828159563, 0.009735225121403346, 0.01679251239693258, 0.06512831969303079, 0.04185734418570064, 0.05257653559965547, 0.07305640130653046, 0.01598920061951503, 0.012695243094640318, 0.01668893270107219, 0.011745653082471108, 0.04326912428950891, 0.017520921064715367, 0.04159543284913525, 0.02016638252825942, 0.027658654616971035, 0.044643537257798016, 0.03204790707968641, 0.040865441551432014, 0.029006519107497297, 0.07211497955722734, 0.04321326283388771, 0.04271217214409262, 0.0363700526941102, 0.06690859096124768, 0.03597560862544924, 0.022045886362320744, 0.032607241519144736, 0.1282224868191406, 0.011178036274941405, 0.03800083686655853, 0.027636401318886783, 0.06553632279974408, 0.03329375038447324, 0.012071955934516154, 0.07925578349386342, 0.059974085525027476, 0.05904557343455963, 0.07139770124922507, 0.040278469532495365, 0.07500098407035694, 0.014628534081566613, 0.04840915746171959, 0.005772770655312343, 0.0373549680080032, 0.018281062111782376, 0.03517992612614762, 0.011740740064851707, 0.16543072852073237, 0.11648498344584368, 0.2436977857723832, 0.17309120652498677, 0.1461880118586123, 0.1632339713978581, 0.1591523372917436, 0.19406492327107117, 0.138587751716841, 0.15363102575065568, 0.09745567134814337, 0.12259415016160347, 0.1334329869132489, 0.07702962248004042, 0.12611293204827234, 0.1572082072379999, 0.1293161601643078, 0.10459499841090292, 0.16353719809558243, 0.09713825478684157, 0.15784054674440995, 0.09224228429957293, 0.13344952196348459, 0.12040122994221747, 0.1207147205423098, 0.14139550417894498, 0.10899113985942677, 0.1271239301422611, 0.18844861682737246, 0.12347880503511988, 0.13785462855594233, 0.1835737010696903, 0.1532336650416255, 0.1413879491155967, 0.08822939533274621, 0.09943641154677607, 0.10178682292462327, 0.15767446893732995, 0.0956858198333066, 0.1496819985914044, 0.17124131438322365, 0.1526970328995958, 0.10068422154290602, 0.11910550689208321, 0.2462785894749686, 0.21413903828943148, 0.09064641446457244, 0.14101513865171, 0.14289194106822833, 0.14002505427924916, 0.13899793673772365, 0.10772882829769515, 0.16847553779371083, 0.07699641879298724, 0.13786807627184317, 0.11264588320045732, 0.09040919438120909, 0.21191741921938956, 0.14176058146404102, 0.10278877423843369, 0.1391083831549622, 0.1462777375127189, 0.15828740870347247, 0.1527010404970497, 0.2098820050014183, 0.1159525295952335, 0.23073184245731682, 0.3030923393089324, 0.10364354282501154, 0.20215059252223, 0.21247640484943986, 0.1043231794028543, 0.1945912989322096, 0.2069489928544499, 0.24638816015794873, 0.1338622599723749, 0.10763559228507802, 0.22878201270941645, 0.1723405093071051, 0.11954304005485028, 0.13376959541346878, 0.2563192241359502, 0.16853602282935753, 0.1481299748411402, 0.221913821878843, 0.22201917716301978, 0.37979303451720625, 0.35861329757608473, 0.11905097388080321, 0.42416165058966726, 0.9705548454076052, 0.5778233567252755, 0.3136064938735217, 0.24342212243936956, 0.09093141401535831, 0.8728975325357169, 0.7290509075392038, 0.2943539363332093, 0.1991369534516707, 0.2981382957659662, 0.18000480195041746, 0.25063285895157605, 0.21927128633251414, 0.207428568683099, 0.31040534377098083, 0.1650972370407544, 0.1520832916139625, 0.21425822720630094, 0.07306793428142555, 0.15997855545720086, 0.14242845500120893, 0.25967031775508076, 0.1891192511538975, 0.13280521903652698, 0.15300947707146406, 0.15456061024451628, 0.19857456878526136, 0.19728802610188723, 0.1358626745059155, 0.18530973291490227, 0.09360585449030623, 0.11330507360980846, 0.16360020643332973, 0.19355677475687116, 0.11807663046056405, 0.08814895394607447, 0.1602531352546066, 0.0821869180072099, 0.16701217100489885, 0.11683314718538895, 0.09808956936467439, 0.20840477489400655, 0.16400651744334027, 0.17656381940469146, 0.20588052284438163, 0.1257613766938448, 0.12369438409223221, 0.12360011649434455, 0.12436858814908192, 0.18185531749622896, 0.07894102382124402, 0.17345671425573528, 0.11722204741090536, 0.12092032513464801, 0.1747080939821899, 0.11225767317228019, 0.11410240738769062, 0.10375565907452255, 0.12793855596100911, 0.10795522044645622, 0.19127864856272936, 0.10924202288151719, 0.15982117562089115, 0.07171023447881453, 0.12201370904222131, 0.11926863837288693, 0.23360773891909048, 0.1240345103724394, 0.13004350941628218, 0.08818477741442621, 0.1885673010838218, 0.11349155305651948, 0.12693665659753606, 0.279534375295043, 0.10922373636276461, 0.13709319988265634, 0.11949998064665124, 0.19262591376900673, 0.16341922630090266, 0.20995672442950308, 0.09917811446939595, 0.07183969471952878, 0.13777563435724005, 0.18026453879429027, 0.18166989932069555, 0.20814779883949086], [0.03764187487831805, 0.009028494587255409, 0.02332269577891566, 0.032624912055325694, 0.041693615276017226, 0.02729682979406789, 0.040762138305581175, 0.1123627983906772, 0.059677860990632325, 0.04911093972623348, 0.034398500283714384, 0.009294529481849167, 0.013671927063114708, 0.08310168923344463, 0.051558962077251635, 0.07120797119569033, 0.04414257644384634, 0.0401785356370965, 0.012323877035669284, 0.022352174419211224, 0.011823380991700105, 0.012653657777264016, 0.019894795441359747, 0.028455082974687684, 0.02236997854197398, 0.017538255779072642, 0.03800669241172727, 0.052586947931558825, 0.08390823306399398, 0.0844451917510014, 0.04577924955810886, 0.03954754683945794, 0.0862946905544959, 0.09943023687810637, 0.06959479447687045, 0.06530626444146037, 0.03905546211171895, 0.03179401464876719, 0.05124918221554253, 0.0792020520020742, 0.06282674905378371, 0.007619159396199393, 0.033178157173097134, 0.07200682637630962, 0.005221759865889908, 0.035270405060146004, 0.03769658229430206, 0.026579811237752438, 0.008230221064877696, 0.0467594633664703, 0.03729886535438709, 0.021348887239582837, 0.050442118881619535, 0.037262240366544574, 0.03630010898632463, 0.025761216784303542, 0.007874616367189446, 0.07618585994350724, 0.04235765562043525, 0.08232897249399684, 0.037400736255222, 0.017231110541615635, 0.03296757648058701, 0.03750520096218679, 0.026395036875328515, 0.04844165610847995, 0.017868945651571266, 0.09658314316766337, 0.0400910920870956, 0.02990475157275796, 0.07762795677990653, 0.042291708377888426, 0.03304268553620204, 0.04223206567985471, 0.05124314484419301, 0.01951840597030241, 0.02483012944139773, 0.08222737247706391, 0.07341977907344699, 0.061687723064096645, 0.043456334751681425, 0.12345384660875425, 0.0626040156930685, 0.07934624387416989, 0.08730798930628225, 0.04686374624725431, 0.079710111458553, 0.05666286750056315, 0.04933064141368959, 0.06461202981881797, 0.1543032334302552, 0.3572358121164143, 0.3487831656821072, 0.280384817160666, 0.10750198343885131, 0.17125103651778772, 0.22796556120738387, 0.10611596328089945, 0.053690981658292, 0.10951248375931755, 0.05327015423972625, 0.1473151263780892, 0.04994182600057684, 0.05583042271609884, 0.02714233320148196, 0.0471072671643924, 0.06796886766096577, 0.06420390054699965, 0.05637366739392746, 0.03495249868137762, 0.1046724192565307, 0.04080257051100489, 0.07762434994219802, 0.03266471343522426, 0.05535449083254207, 0.03685545809275936, 0.018700668697420042, 0.03661637892946601, 0.056794520787661895, 0.01958986551471753, 0.047854702643235214, 0.022987953780102544, 0.019761557668971363, 0.01630376176763093, 0.03148513649648521, 0.033571755193406716, 0.024643753895361442, 0.05438061496533919, 0.04899983650830109, 0.029678390965273138, 0.01452625871024793, 0.027264934142294805, 0.036666822707047686, 0.024540582380723208, 0.036835973005509004, 0.01380776142468676, 0.052286890204413794, 0.017870630326797254, 0.022828325236332603, 0.08506687401677482, 0.02558911273808917, 0.06845664422144182, 0.03200374558218755, 0.02159890194889158, 0.026208210474578664, 0.022942773684917483, 0.04505783748754766, 0.05172390068764798, 0.023573949874844402, 0.009068234739970649, 0.0344934655004181, 0.055776702356524765, 0.014193947245075833, 0.026111068909813184, 0.06804461125284433, 0.03778048208914697, 0.051579148494056426, 0.026201143373327795, 0.019596997553890105, 0.03461571206571534, 0.03403645096113905, 0.050060298744938336, 0.06979318539379165, 0.08203485194826499, 0.040620469735586084, 0.02813369777868502, 0.04971138543623965, 0.04724741062091198, 0.028309941153565887, 0.042415290809003636, 0.019208023113606032, 0.018613837419252377, 0.02812997961882502, 0.03992243902757764, 0.051564654349931516, 0.015289962993847439, 0.032498116124770604, 0.0385268971149344, 0.02624045493575977, 0.029385136876953766, 0.026802021384355612, 0.020694800950877834, 0.06167207488033455, 0.07704865114646964, 0.008373454638785915, 0.04503597010625526, 0.07089868115144782, 0.050353261540294625, 0.06731233414029703, 0.019637906589196064, 0.0309899811327341, 0.029707386674999725, 0.021340393359423615, 0.03927077028492931, 0.019689860637299716, 0.06794852539314888, 0.030878269353706855, 0.021636940728058107, 0.02546209787396947, 0.043668488797266036, 0.013683747620234499, 0.013170072888897266, 0.06516419511171989, 0.013205568884586683, 0.022326169564621523, 0.06118458775745239, 0.04786251374753192, 0.008876637257344555, 0.05813273921376094, 0.10782871395349503, 0.06063717220968101, 0.027407472880440764, 0.010812626878760057, 0.05462184635689482, 0.004814212716155453, 0.11164243274834007, 0.014008677499077749, 0.04421970785188023, 0.03150951233692467, 0.0942963338457048, 0.038089434456196614, 0.044926165646757, 0.057872505130944774, 0.04228067635267507, 0.06100450933445245, 0.05204642322496511, 0.015287400728993816, 0.031412394891958684, 0.04056061552546453, 0.03157305502099916, 0.048795771872391924, 0.028687406738754362, 0.04639362909074407, 0.03628429381933529, 0.08043591704335995, 0.022878820964251645, 0.029849203674530145, 0.04355967139417771, 0.07069116181810386, 0.04919599356071558, 0.008203229153878056, 0.06402502069249749, 0.0795341408229433, 0.06696685697534122, 0.07086540324962698, 0.03938781810575165, 0.05224171938607469, 0.0517790496814996, 0.06553756218636408, 0.06270625395700336, 0.008656384525238536, 0.05364351389289368, 0.08006893986021169, 0.08501084186718799, 0.12281657182029448, 0.032035149561124854, 0.06516103356261738, 0.03320001713291276, 0.04093193056178279, 0.08122268263832666, 0.15037206234410405, 0.10668740214896388, 0.08835458080284297, 0.1860526078962721, 0.08558316389098763, 0.05296287541568745, 0.07836605233023874, 0.029834939596184995, 0.22002480371156707, 0.045008855740888976, 0.03590907137549948, 0.06622401910135522, 0.15909617155557498, 0.07566500586108305, 0.06898227773490362, 0.07466544426279142, 0.07871213063481264, 0.06827513716416433, 0.07174628059146926, 0.018764398773782887, 0.12038709945045412, 0.09092038570088334, 0.12748261011438444, 0.06114274918218143, 0.046085533904260956, 0.049866943300003186, 0.09257129320758395, 0.08898254163796082, 0.04300753949792124, 0.038124987040646374, 0.016179403792193625, 0.046731146721867844, 0.049641248770058155, 0.013658454299729783, 0.033832701737992465, 0.03363170588272624, 0.03568413383618463, 0.026822163272299804, 0.06341270433040336, 0.06835914085968398, 0.015409262305183802, 0.05749988020397723, 0.014158738831611117, 0.04758417868288234, 0.02397650561761111, 0.015626019521732815, 0.0016833378526825982, 0.060207075366633944, 0.08022492445888929, 0.013148998677934287, 0.023722208716208115, 0.0205743225524202, 0.08368133625481278, 0.023763110330037307, 0.014478289067483274, 0.013281547180667985, 0.018209875306638423, 0.003408400639273168, 0.00969083634117851, 0.03276645074947737, 0.023404821840813383, 0.0237937647398212, 0.029374828445725143, 0.0418961288232822, 0.021375530341174453, 0.047213520447257906, 0.0958458120294381, 0.10005054617067799, 0.03933053543732967, 0.0475495723367203, 0.017841276530816685, 0.01994602775084786, 0.03392531805729959, 0.028252261436136905, 0.02829339497111505, 0.04231929771776777, 0.0345905569702154, 0.04874193647992797, 0.07736850195215084, 0.03808911904343404, 0.040568255935795605, 0.026172260841121897, 0.055852601799415424, 0.03881215270666871, 0.0201664307678584, 0.01069156682206085, 0.01705377064354252, 0.022648603044217452, 0.04391870759718586, 0.0246056520336424, 0.01813701124774525, 0.019690830995386932, 0.08656378588057123, 0.06355766061460599, 0.21982589329127222, 0.13154625456081703, 0.08230953564634547, 0.08678657861310057, 0.17432680819183588, 0.1604029006557539, 0.11304362982627936, 0.10149849113076925, 0.08855370644596405, 0.08032523313886486, 0.10333454221836291, 0.139178590325173, 0.21687710308469832, 0.10736808515503071, 0.07709927303949371, 0.14264618628658354, 0.15093901864020154, 0.14083225862123072, 0.06490745654446073, 0.10079981104354374, 0.21328377246391028, 0.10562201947323047, 0.05257194170553703, 0.10889397046412341, 0.11144251300720498, 0.16315367101924494, 0.14555996196577325, 0.15567639959044755, 0.16426187561592087, 0.13178246532334015, 0.13051882531726733, 0.2573577855946496, 0.14989477233029902, 0.10990687587764114, 0.09724475297844037, 0.34069785266183317, 0.1348815849632956, 0.14974435383919626, 0.12671987526118755, 0.16642076836433262, 0.1292247127275914, 0.2667603810550645, 0.14139176375465468, 0.11187544485437684, 0.11584869571379386, 0.16364979674108326, 0.17104044469306245, 0.13911584916058928, 0.12184321545646526, 0.14971319847973064, 0.18132103054085746, 0.19980298646260053, 0.10908297321293503, 0.10368794552050531, 0.1008633166202344, 0.12299885071115568, 0.17700533790048212, 0.13231299701146781, 0.12490912398789078, 0.1106918603181839, 0.16883519740076736, 0.08897684194380417, 0.08483400291879661, 0.22537087934324518, 0.23383626103168353, 0.23123766062781215, 0.13567250658525154, 0.13296700723003596, 0.1430208224337548, 0.15862244385061786, 0.18210784066468477, 0.2294279186753556, 0.3180714324116707, 0.11363046825863421, 0.3851285419659689, 0.31130509392824024, 0.3244480839930475, 0.23341960448306054, 0.17176084744278342, 0.19953049952164292, 0.1726120908278972, 0.3249420574866235, 0.1934014877770096, 0.13736317836446688, 0.24414660700131208, 0.3582696832017973, 0.1617185355280526, 0.11711502229445614, 0.19928265188355, 0.2812012389767915, 0.3942154871765524, 0.19716211332706735, 0.0915940702543594, 0.20686383883003145, 0.3452988713979721, 0.17680708057014272, 0.16482289473060519, 0.2421858231537044, 0.3145601536380127, 0.33855447079986334, 0.30462175724096596, 0.2935377520043403, 0.2753185905748978, 0.4013587179360911, 0.2633339149178937, 0.20365311502246186, 0.07793770695570856, 0.11811637246864848, 0.15880876744631678, 0.14237126510124654, 0.1261860187514685, 0.1451901052496396, 0.21157281036721542, 0.14347148418892175, 0.10453292517922819, 0.12086628936231136, 0.11471598540083505, 0.11463889110018499, 0.15755710570374504, 0.09867372122243978, 0.11951829685131088, 0.1522472468786873, 0.11543402812094428, 0.1446309415041469, 0.07514114608056843, 0.12081799781299196, 0.1562512671807781, 0.09290167508879676, 0.11311704307445325, 0.1603850000537932, 0.1383672744850628, 0.08349185111001134, 0.07583653103210963, 0.11712662206264213, 0.2232717294828035, 0.07867978783906437, 0.06975399257498793, 0.16247680265223607, 0.08854914223775268, 0.09304208942921832, 0.09017911375849508, 0.07919039286207408, 0.11114352397271432, 0.07738365660770796, 0.11673849367070943, 0.17152163840364665, 0.14043742121430114, 0.15332787326769903, 0.19888866052497178, 0.13341168727492914, 0.16296629357384518, 0.1238051125255879, 0.11931707835174166, 0.19308660936076194, 0.16059548797784373, 0.12422222178429365, 0.09244836386642419, 0.11025538842659444, 0.10972867137752473, 0.13664146943483502, 0.14892436971422285, 0.1885403017513454, 0.2319286743295379, 0.13593118957942352, 0.1622109505115077, 0.1673916311119683, 0.21577324747340754, 0.11837034282507375, 0.10637777813826688, 0.13368827087106183, 0.20488145848503336, 0.0997688714414835, 0.18794563366100192, 0.08927035392844118], [0.02265021907078335, 0.04851997124205809, 0.0854802576941438, 0.09022285594255663, 0.02199631831899751, 0.05534375937713776, 0.04015048616565764, 0.0022482709846372018, 0.028329318629403133, 0.012739471385430079, 0.04697871605458204, 0.015926639425742906, 0.03277926763985306, 0.10824194177985191, 0.042088816335308366, 0.04559040637104772, 0.02898819733673008, 0.040796061875880696, 0.03459495790593792, 0.03759141996852122, 0.03502079482132103, 0.056568058134871535, 0.037204174732323736, 0.07488860064768232, 0.05003592661523726, 0.07949915598146617, 0.02581683704192983, 0.0834959329222329, 0.008729873843549285, 0.007379781054623891, 0.06614010446355678, 0.06781567353755236, 0.05678544803231489, 0.026420292160764802, 0.058810694827116095, 0.060851715970784426, 0.008944374931161292, 0.011550729850569041, 0.054275352449622005, 0.011571830036700703, 0.024377578920393717, 0.05017544295697007, 0.057519903348293155, 0.056601703399792314, 0.06879711188958026, 0.020339584953035228, 0.06408518660464324, 0.07576896590762772, 0.03345553486724384, 0.0657343129569199, 0.06574882194399834, 0.043479411833686754, 0.032743306874181144, 0.03201564592018258, 0.017158697337436024, 0.027139965750393458, 0.010062186629511416, 0.0499085258343257, 0.041164697759086266, 0.03051326628337847, 0.022077305184211582, 0.044455369425122626, 0.06973710129386745, 0.044627514289459214, 0.07833765776013024, 0.014433125670620939, 0.042092753428732976, 0.06448541942518204, 0.045500153792090714, 0.06682106206426397, 0.030535675432474818, 0.03041377025510883, 0.04657891739043407, 0.06109752270276658, 0.05147047952050343, 0.057237920627812855, 0.06223310512723401, 0.04466233956918586, 0.025943245200323872, 0.0015575089173580636, 0.04454774454643484, 0.022989731223788112, 0.03040931922441814, 0.042861729743890464, 0.030496562394546345, 0.038334146520355716, 0.03008870771736838, 0.09235587000148371, 0.05460183063405566, 0.05661636823788285, 0.20941627764841542, 0.13922522688517347, 0.22057483904063702, 0.2626046212390065, 0.10161725702346303, 0.17206695367349312, 0.15459345770068467, 0.0548762137623271, 0.07026870167464949, 0.050085750699508935, 0.01918717061926145, 0.058911062878905796, 0.11626568622887135, 0.05984567542327568, 0.10103010688908398, 0.09528316018986516, 0.004425369079399388, 0.08375928402529098, 0.034347711407463066, 0.03692742044222541, 0.055311832184088416, 0.04655519835068844, 0.01866157977929106, 0.03654766347608529, 0.008979440481198253, 0.007009026339801494, 0.07161863119108602, 0.09295355863287114, 0.10477286894456483, 0.08241518778959289, 0.04883234119915869, 0.015656514369766228, 0.013518686555471504, 0.019124422033200972, 0.041004263985087164, 0.018485837354091927, 0.04289572752895765, 0.09127265351708047, 0.016241397242993116, 0.007281027637873194, 0.10299078683601692, 0.021573283011093736, 0.021988403314026073, 0.02345392418646952, 0.02816894237184897, 0.06897600658703595, 0.03041690397367347, 0.037549904227489606, 0.030564544977096375, 0.02959190107503673, 0.024665161145094316, 0.024499036953784525, 0.0279010957092396, 0.013113464647176443, 0.08858904751832597, 0.062088479098747484, 0.007554693202109775, 0.04311923272325657, 0.05856100295204669, 0.026170500095759053, 0.08596310639404692, 0.02927574430941604, 0.05203689404879697, 0.06378514372045174, 0.037027057478553616, 0.01743166667438345, 0.05150484466867056, 0.03316035676107276, 0.012538671271613566, 0.03478983846434858, 0.016786014894023538, 0.0445889411639655, 0.04580218934279401, 0.021771941101178527, 0.034378647833364084, 0.06482763856183738, 0.029236868758744095, 0.010004826963267988, 0.05042471551860217, 0.015157546222326346, 0.05271409638226032, 0.036192816696711816, 0.07217329010018148, 0.03795955119130667, 0.03497520097880624, 0.029564872056653257, 0.03140420529234689, 0.10797404131153598, 0.05092539060569834, 0.07625463476870209, 0.058405166782904416, 0.07100897171767429, 0.0018213040334558173, 0.004087965553480899, 0.029291954670043197, 0.07326910083065741, 0.011147797467856435, 0.05631831430946477, 0.055142218043329194, 0.043505954745342024, 0.04520401460467838, 0.016383741167373955, 0.022391339407477062, 0.061025296890875325, 0.04095196483831387, 0.04861625377088785, 0.057829701763694175, 0.040457401337334886, 0.020320016374171246, 0.030738274326722603, 0.01797400036593899, 0.024690299542271532, 0.02597769198473543, 0.12495973845943809, 0.025680382059363183, 0.045120111099095084, 0.02718830368394265, 0.023822537805244792, 0.06507193873403594, 0.029160039775888436, 0.052884296819684096, 0.04996943018340971, 0.025319013657281175, 0.040210225342889316, 0.07816308236215264, 0.06022025962010957, 0.033694959129206836, 0.03623645498009864, 0.014327433636935893, 0.08270423204521649, 0.10129956586752087, 0.023990855042939074, 0.02161183572752634, 0.05341483964002691, 0.05690931990102399, 0.04720830685982946, 0.025617716964916326, 0.00796456652096822, 0.014284474418673199, 0.017677631112746894, 0.029755208815913647, 0.02400995606876677, 0.01787279368727468, 0.03450561816862319, 0.01465924044168787, 0.04296167477150448, 0.018810185574693605, 0.04465725214686245, 0.07424544804962352, 0.06826609038398601, 0.09400766066391952, 0.030181554102455266, 0.0016542058892810019, 0.021355009957915172, 0.041827858658507466, 0.07322103934711777, 0.04874496073171031, 0.04485415505769197, 0.03558647462341469, 0.007739393349766033, 0.02598070139356423, 0.0734590386855416, 0.06447276580729522, 0.052022741292603314, 0.03732681834662799, 0.04372487346699927, 0.02302630240592407, 0.08647331065731123, 0.04318463077652268, 0.04719308912171982, 0.007821190083632246, 0.07661660245503299, 0.06561329835676588, 0.14956947416067123, 0.02671516969712684, 0.046344550864887424, 0.0854590100061614, 0.16772099625086412, 0.1997930119978264, 0.10647823524777777, 0.08046825983910821, 0.038710515582351945, 0.17326313245575875, 0.09072345681488514, 0.02906537141825538, 0.047168293967843056, 0.03554697010258678, 0.06986500302446075, 0.0311514335044194, 0.07205859117675573, 0.09925560210831463, 0.011908775286428863, 0.01713686520815827, 0.09403649310115725, 0.060562857252079993, 0.041910036670742556, 0.04574490296363365, 0.014165789234539261, 0.03153160978399683, 0.037144257439649664, 0.030005735607119277, 0.03664741925604176, 0.0284947841646499, 0.03923827905964572, 0.07989795645698905, 0.055734756169840693, 0.15012319054221734, 0.021909785755269695, 0.02824118117132457, 0.022868169289722573, 0.06753896377631463, 0.05004411992558744, 0.012325941133894958, 0.03169044051901437, 0.05263149905658793, 0.0788364774780348, 0.049462858733022586, 0.019400751443754416, 0.026133802748518065, 0.04856563558860216, 0.026683988362492528, 0.014420637180592166, 0.08412266179220751, 0.07556408119853586, 0.012749711167998612, 0.07316564544453286, 0.09061824253876694, 0.05300269534927793, 0.015303804975701496, 0.06873365826322697, 0.02630182498251088, 0.01918883488542633, 0.027622721681836993, 0.04023679422971327, 0.05026900922530331, 0.030153090883686673, 0.06378667254466563, 0.07338385170442052, 0.025201123498845845, 0.010844074458873365, 0.045313537048059516, 0.06795703782700002, 0.04404505452839658, 0.014094242487772135, 0.08192194902221672, 0.03793479685555212, 0.04994155511667486, 0.03368657286046073, 0.02756218469585292, 0.01796743606973905, 0.017010028459480964, 0.02805532141792355, 0.008975755717983702, 0.02665469393832609, 0.05167301162146032, 0.05237882003712002, 0.05688395700417459, 0.03737024511792697, 0.0580059989442816, 0.029821538264513947, 0.048231717373710126, 0.008798041963018477, 0.10035496030468494, 0.23949007561895996, 0.2608851244440302, 0.2269778962363489, 0.20889073319267482, 0.3082375304074958, 0.15307404391933233, 0.09110786704695784, 0.21436600189190358, 0.10478085445356555, 0.10616566491080448, 0.1087432996428106, 0.15492055186768994, 0.18531121721025556, 0.09317603966337629, 0.20507204200839624, 0.06739350283169188, 0.17926532600540668, 0.07904386322479695, 0.14686522161355242, 0.13745662959991023, 0.10996411030646414, 0.191237474209629, 0.166961986979004, 0.1264755305601284, 0.1938454998889938, 0.10305815158062615, 0.18495704949600622, 0.09827756279264577, 0.15628932451363653, 0.1238895021378994, 0.12921662331791595, 0.12621062836842611, 0.14081677742069587, 0.20076970802620053, 0.1428931433474645, 0.10719940983108245, 0.12510231987107545, 0.1175109061296098, 0.14470833266386762, 0.12644048634683713, 0.12888528406620026, 0.1362116026575677, 0.2692532551009208, 0.15067248372361064, 0.07642431199201383, 0.11067525847465731, 0.18561190576292574, 0.16128872812259942, 0.11969703569775447, 0.15378279495052993, 0.15112323453649879, 0.12390853822580539, 0.16975874081254005, 0.13901901373174042, 0.09073899738723412, 0.12367542964057066, 0.1501876238035038, 0.11484263290185481, 0.1132529006281402, 0.1383714156690985, 0.1307813823223114, 0.13266219233628362, 0.15456148597877473, 0.19531857396941632, 0.09439423796720803, 0.14563595788786188, 0.19159480347298086, 0.16440416016848758, 0.09006668580695987, 0.1768572349101305, 0.15872600313741714, 0.11293646370177157, 0.09165865936665796, 0.13921102217864245, 0.1663002881105058, 0.19593561039073393, 0.14325911120977253, 0.13587233726866543, 0.09512582488241605, 0.10119895290699787, 0.14356278319610283, 0.1316449898877181, 0.12990722141694278, 0.15007803827757016, 0.19982666097348556, 0.10140333295566961, 0.22585725324461237, 0.12684449669905007, 0.1709955299156718, 0.32683860103134066, 0.3197983803693205, 0.43943662312813103, 0.37693146150559187, 0.2780373743735254, 0.32464258605614305, 0.28675838140770793, 0.15150693972827867, 0.12265384109923616, 0.1721087217447348, 0.22624673234531656, 0.16859475639648736, 0.2410458991653286, 0.2561983134364709, 0.22544138337252662, 0.1630919985473156, 0.16000001836800948, 0.1786758826347068, 0.1369978190632537, 0.14090207987464964, 0.12410580107825808, 0.15442822594195604, 0.06688491645036265, 0.1314297373755835, 0.1558977525564842, 0.1696773717412725, 0.1971223935834132, 0.19417637900914997, 0.2790951426140964, 0.25453890091739595, 0.18880835064919665, 0.09559058744343929, 0.07997196342330426, 0.09225089321262203, 0.14102290151640773, 0.13114852277794853, 0.12909025041153654, 0.18804714462021366, 0.10741754187620245, 0.1469883439131081, 0.1418857224052772, 0.14745847962331027, 0.06762697506928816, 0.16984870395390317, 0.08870952035067603, 0.09438470879103988, 0.15377092058770359, 0.16321933624567464, 0.09500492160441354, 0.15332824434153736, 0.1565924027818255, 0.1383220183197409, 0.07499784478568472, 0.20264235441572964, 0.2922502445289865, 0.14243363519199193, 0.07127983335522003, 0.0882133946288377, 0.16769910289440304, 0.09142748036538251, 0.22038431488908827, 0.11543864427949302, 0.10892823542235419, 0.10376497302786447, 0.16792738751973957, 0.16879207862075418, 0.0961626719799824, 0.16541545512154698, 0.2102696435758844, 0.1293866938794963, 0.07859150195145048, 0.0949939526617527, 0.10640560867614113, 0.0783787653199397, 0.08103809566819109, 0.14259977237088606, 0.19912414398277178, 0.11934850088437088, 0.1547224132809788, 0.11193458660272881, 0.09328636733698659, 0.20913074375130236, 0.1319309839163907, 0.10388734575826675, 0.1417915290221572, 0.18840059987269342], [0.028384968572936486, 0.008473720645270078, 0.02792872957797954, 0.007472254046660964, 0.04696244817750994, 0.02655132018844597, 0.12342149639152922, 0.02272278998134425, 0.07662301461095922, 0.07854234951082617, 0.06024704001902137, 0.029992699783178978, 0.05294940543535631, 0.012368450425128685, 0.034561123393359594, 0.04401253361720592, 0.03331979605718516, 0.0375278179126326, 0.03568241576431319, 0.04911486568744294, 0.035632190920296125, 0.02713057016080711, 0.020910984858346637, 0.032908052526181564, 0.07069823448546231, 0.0189002414845163, 0.027775398157245945, 0.060769983247155324, 0.020760944862558972, 0.024457940526190214, 0.010852162940864218, 0.05836717253259849, 0.040361141072935425, 0.009556767363392282, 0.034617148121469654, 0.11184332470293157, 0.030941387158236466, 0.06785808727727272, 0.05849704466527328, 0.01883410499431193, 0.04277415260730777, 0.025239223505195696, 0.07348591927438974, 0.0966576102655381, 0.026182600813626777, 0.04296297724067699, 0.04723829333670437, 0.026912352768704295, 0.03875474758388009, 0.02585277739854064, 0.03061104980588425, 0.06385758475516923, 0.03453045414062217, 0.05615735732135363, 0.04249336845532525, 0.05133319704327732, 0.0161263587870053, 0.020558780124702025, 0.041618747418397106, 0.06466740145697258, 0.030301568658614997, 0.06131857509899419, 0.06656053112237714, 0.08798355149338022, 0.04689912071626168, 0.056364145639236085, 0.015557541555608623, 0.07976550536113791, 0.13113526802044362, 0.019854593301715795, 0.024112541286740452, 0.05652842373820022, 0.02844717168045463, 0.019296891587146092, 0.021927927555225324, 0.042026661467389204, 0.08725721156224608, 0.018449663220962975, 0.07682951720198616, 0.09721215785248205, 0.04854133025219198, 0.09457716994802468, 0.06289327517151833, 0.06458270756411366, 0.05346108286175877, 0.03828372500720434, 0.0527570147824008, 0.0637968399678357, 0.017945513027370907, 0.06744645506842062, 0.07093164735124446, 0.09646146063460037, 0.09438345456146635, 0.03570967855921481, 0.015685988764744252, 0.09445035175303929, 0.06614132900722325, 0.0560623958153883, 0.034731012128759176, 0.014018617639521835, 0.04890362819423899, 0.032453557578264736, 0.05897375209315214, 0.046976649173302576, 0.0075079156340507325, 0.09161088732071221, 0.052672454476123676, 0.007056011709209997, 0.013071593602944631, 0.02257703774375841, 0.05888999701710418, 0.06186174927279353, 0.02384591174632078, 0.03856567062030081, 0.04088143854460213, 0.05975281419523526, 0.08615160448243842, 0.03463293731329031, 0.04668082168791443, 0.03362713054229971, 0.0071731100888428045, 0.042844586132559925, 0.04892567369097378, 0.06569432604010217, 0.03605619102017954, 0.08738092757994309, 0.03858878480968997, 0.05830303984112106, 0.08847433375194669, 0.04595909049385227, 0.06727142696036026, 0.06411561465938576, 0.11281047671218403, 0.04628726077498868, 0.03953206934966147, 0.011000803988281405, 0.0352741454844363, 0.10627435243804939, 0.04167597813648172, 0.050068996715708636, 0.05007789506635163, 0.02708890227950178, 0.026377902540843934, 0.026067543803947046, 0.01801291487936396, 0.005837450680701295, 0.04847591364523396, 0.016998590108414646, 0.049159761911141686, 0.030786671632085927, 0.010324926388420863, 0.037930381076876074, 0.00760422321036458, 0.11173452585353516, 0.049290665629087016, 0.040798058253130876, 0.05213221178564709, 0.07331883956794627, 0.02784882624837337, 0.08429834299022332, 0.012452232404029928, 0.04915117897326127, 0.02171633197576739, 0.04646703862817958, 0.07008917615166865, 0.030103415228950325, 0.01931686649186304, 0.03574378766643349, 0.01806034368200926, 0.05020516226068139, 0.042961949366144836, 0.047108918442972936, 0.0002723483100908197, 0.03681193484226242, 0.02583781384601025, 0.09338937743450515, 0.019818062937702052, 0.021898364102526102, 0.014272434000304202, 0.06053476325178053, 0.024372218758799136, 0.012659585681831231, 0.11080593583756126, 0.0306047749472782, 0.04497988229559269, 0.06100410486396868, 0.0473638201947324, 0.047868165202089585, 0.0445915089949267, 0.031615791594958864, 0.023916094796732068, 0.05429029930382967, 0.07407091718050651, 0.003849282047667657, 0.025150935762212612, 0.034641546226339415, 0.05734557656978723, 0.02814885800034972, 0.011134718970424728, 0.09631705353967845, 0.047407781312358566, 0.01706166523945285, 0.045965369063196704, 0.04634567892935593, 0.026774025718623307, 0.025399128498975188, 0.03191551164491102, 0.02839869644958526, 0.03582327910407912, 0.0340707010764163, 0.012315866479184479, 0.05985314885037951, 0.051995385729242116, 0.03828917608188931, 0.1231171638937667, 0.01673929855314782, 0.05067950223747175, 0.08326445706188679, 0.04091728798812255, 0.053583236658596434, 0.0068237129926274065, 0.016492441682203207, 0.025461418808845337, 0.07277966185938567, 0.02528677290683845, 0.029430151844280772, 0.04236690278048627, 0.01223811908857897, 0.044098518847022206, 0.002360557464271551, 0.0688406611152459, 0.07692696119192988, 0.0689447473268956, 0.024433488615613896, 0.0737898658553604, 0.03783609121455811, 0.02561978755693417, 0.03572496680135373, 0.0403402755910065, 0.040126908133970574, 0.008316672920045676, 0.05258071018033661, 0.06571041580173187, 0.05976447704597376, 0.05185056303162128, 0.02918877016782062, 0.014275097382778767, 0.035260768272564746, 0.053364291961770505, 0.1142803076072596, 0.051258217863505706, 0.009156865726254182, 0.020710360076918732, 0.041193604411091655, 0.06252122911973856, 0.06456930437707342, 0.012327736203587847, 0.05406682379543781, 0.06641243555350229, 0.09488255629548803, 0.05436502615339123, 0.02336826735700015, 0.10012396684032865, 0.07709270503255539, 0.0730625908181537, 0.06876836851006374, 0.07473497607861646, 0.07906359693151899, 0.04905138608592097, 0.022068560829211492, 0.01779785718099447, 0.03802764324063901, 0.06126921114628203, 0.08917443876271136, 0.012811571959900903, 0.06116543292591814, 0.039297465336858295, 0.043589980705291964, 0.05923665048612747, 0.054592858068645, 0.05912135784456041, 0.08210425017750822, 0.00615631303844566, 0.03810183574387338, 0.00457738411569153, 0.016522990335943177, 0.057662674007588066, 0.08022867230465636, 0.03330347994051408, 0.06176412716740742, 0.08980907892691903, 0.0625620546634309, 0.05940312534221448, 0.04370049020508304, 0.0058146588617091766, 0.02927460696810158, 0.05222936633799691, 0.02471151754434686, 0.020087894845346455, 0.050073093370883726, 0.04749216721393168, 0.04800576680281665, 0.014850811021460686, 0.07287473839824088, 0.08417794437264092, 0.019035039622394834, 0.04557357075100299, 0.06632691045524552, 0.020840345387114212, 0.04993567359633744, 0.0524948845122708, 0.02004415451665409, 0.0820876557554584, 0.039508803019998595, 0.03287907537014689, 0.0049797571045928635, 0.03405679693969432, 0.01999271997192409, 0.03651036313385703, 0.042924192603095435, 0.02348692563828081, 0.039809031441109255, 0.018910299440904055, 0.014552534448739607, 0.07455230384948663, 0.03537985699949786, 0.05629450250125956, 0.007566213189420523, 0.017367947730235755, 0.04423592006787658, 0.03671908845717553, 0.03426142560783774, 0.03786743953241967, 0.0361761554813711, 0.008049719617702067, 0.03672389386338182, 0.04116440461075399, 0.0411702675773995, 0.02773243893898325, 0.002744329217421182, 0.04568285199638922, 0.08747204105020501, 0.024993628285301384, 0.017523119677207433, 0.05429555742011871, 0.031308230754802935, 0.03645149598014541, 0.013590191556431819, 0.00310916553644347, 0.03354933491209522, 0.050669167831074446, 0.04225874588883016, 0.13107654929626733, 0.07630413601873443, 0.1442936947569251, 0.16717887221602723, 0.11453145780251361, 0.07073939399560913, 0.21462756441906095, 0.22565304388990626, 0.11489259428344667, 0.17617045145016164, 0.19483206648146734, 0.12908400152809918, 0.13522154797101393, 0.10794997346238233, 0.12906114337965846, 0.15819541207747534, 0.1294067467097193, 0.06857391839730553, 0.09788671071873978, 0.1311734292539768, 0.2005749981617555, 0.09264262844226323, 0.07740342000033706, 0.3433439653599635, 0.16410535667091608, 0.0940419701510109, 0.08859230554662645, 0.1704680558759719, 0.09941074808011763, 0.11528144998010248, 0.10539173847064376, 0.1313640721491538, 0.23417004937073216, 0.0945454060274642, 0.08065125861321576, 0.18801616737619042, 0.12130490606068633, 0.12236801034305245, 0.2988971269223839, 0.11474757120595314, 0.12422041094396263, 0.16426925256382674, 0.2097153928480111, 0.17298044840572402, 0.15744101896416396, 0.16327239980455488, 0.08355425830814056, 0.1809074019547552, 0.19986630650237203, 0.1740536087891087, 0.13162030605599284, 0.18996752594830468, 0.1032236876199022, 0.06224941753316671, 0.14448412985075265, 0.1933954466949217, 0.14469256944721565, 0.15257834864314646, 0.17049560439772904, 0.18463771819369867, 0.16561071417527273, 0.11428142825025134, 0.1511093118460849, 0.1160787911794614, 0.137787107960321, 0.21982982667395845, 0.09719960071379319, 0.15701864787843078, 0.31171060341876, 0.10370402043918148, 0.1618119125487283, 0.14375176368048415, 0.12204368438688107, 0.22253906645346433, 0.12312028833548538, 0.13072048168396577, 0.205810152401682, 0.08188470063032582, 0.13324661878868937, 0.17371110763633624, 0.14116208389168605, 0.22773125034291297, 0.18686479947064072, 0.1698442510678433, 0.33070367644540966, 0.19809810997685418, 0.2150137780699879, 0.14484536281088367, 0.13731691287830472, 0.28062856814358383, 0.23464178811991587, 0.2802188729401678, 0.23075096018146724, 0.11383600605768152, 0.09344930585939437, 0.12198018623166718, 0.14990213443525136, 0.17184536322019994, 0.10654290599632077, 0.15625114843714982, 0.13112830667523667, 0.17360195255605504, 0.21101747610373423, 0.20638438174501061, 0.1587271608877927, 0.1567934505874291, 0.18058525049127638, 0.15035285556223243, 0.15282221836969256, 0.08426479791523889, 0.13966972881462425, 0.3052986552938819, 0.1599892572266981, 0.18070488469675183, 0.1874142262386158, 0.1606537465704605, 0.20288473984692246, 0.2034092156100087, 0.1107427196984645, 0.08727527543669567, 0.1664230541791767, 0.11659188239718787, 0.11250725743593648, 0.18373876955593005, 0.07995020365342498, 0.14844890538370237, 0.11674500972731039, 0.19880316511262208, 0.1434618659550324, 0.10284887335728854, 0.13965363905299455, 0.10243693686788902, 0.23208302620332688, 0.09622847821447067, 0.09829204209381714, 0.22897281887708232, 0.14121050160611048, 0.22970475460169837, 0.12007173121673986, 0.14478468481684104, 0.10097547739860602, 0.20058001508004963, 0.10653172925231047, 0.1665264501934871, 0.08640227228170261, 0.11867368826642632, 0.10656092534190975, 0.14114991266978905, 0.20295571885071695, 0.1401158337830566, 0.1068999977724161, 0.05493077645951416, 0.163265245500952, 0.17228826211066917, 0.08800796073046513, 0.14228511659894139, 0.17107646854128689, 0.16872423148015514, 0.10225698089925572, 0.13884002255508676, 0.07149415818275884, 0.09370107203722, 0.12162575134425424, 0.1480215767514892, 0.1697560987668112, 0.13646181032527238, 0.0770612528140191, 0.11331100336974487, 0.17378588643623516, 0.09563519794028252, 0.13716983405174688, 0.1478268817299977, 0.06601141605642624, 0.11111314786830917, 0.2276097607682459, 0.16806622850708663], [0.033793705588323064, 0.0220425986481132, 0.03571539680706337, 0.04325030713516753, 0.03245467451051809, 0.02300647036463488, 0.03836312367639039, 0.014063310700294096, 0.03570401226170361, 0.07036922557745129, 0.023921941065054853, 0.03730650947545655, 0.030198655040294398, 0.041304277183371596, 0.02343200299947057, 0.043915583155467175, 0.00838172865769593, 0.05339390736480709, 0.04688232591433916, 0.0482550282322336, 0.01034419718052959, 0.09293434442952275, 0.022158844949444756, 0.12228224033606239, 0.030739300345885567, 0.0345261088659754, 0.03029624560440425, 0.03164193003613036, 0.01414824115272495, 0.032053476897999644, 0.046065748247201554, 0.05630129686323926, 0.042570440491545014, 0.026136457781831268, 0.04151852408540435, 0.06656385594396852, 0.048138418278540485, 0.034512638885644265, 0.05207871407037601, 0.033922601796803065, 0.05032213215599768, 0.06214214750798419, 0.05014186448534019, 0.03594423062168062, 0.010664196415746119, 0.066601816797629, 0.026793161996465642, 0.06792017535190098, 0.057774148299358785, 0.04870799806667492, 0.03088981902692467, 0.02664082876435714, 0.013051536134298658, 0.011404444194340613, 0.044973176991334185, 0.020079148634977173, 0.015832663120818324, 0.13822941313264892, 0.014380512966454262, 0.025803393036767375, 0.0746080614044331, 0.06752214670996182, 0.042661617044359446, 0.08705123589606956, 0.04096729760931339, 0.049957503870246, 0.03747646500414703, 0.05522708634089213, 0.05203346903726924, 0.023038885519781616, 0.049266004061792046, 0.06332199161988683, 0.056406351577606983, 0.01843993552029133, 0.037853034446015954, 0.021102650061948225, 0.05817621051392052, 0.018730404699454084, 0.04712783578725066, 0.023855876934248954, 0.03969328980019782, 0.05061778152594343, 0.01582089636940509, 0.06110069538408425, 0.07801724292221479, 0.0803495236323215, 0.07812783776898868, 0.12660261592827737, 0.046737124721403234, 0.05471255906741135, 0.08721482008695602, 0.0879904386238195, 0.06508754609967582, 0.0716679469041992, 0.04537374748906586, 0.12397385464282706, 0.09506525078904815, 0.02531908972741803, 0.01098081331292633, 0.12361860339296982, 0.020665319134423044, 0.06696409618598409, 0.04614284625859, 0.04131016983592417, 0.06659828417468816, 0.037669193334295414, 0.04720149765489623, 0.02274081860377919, 0.08708034292794764, 0.075064222473884, 0.0692545271886047, 0.04613812991010491, 0.04250632264302112, 0.01309115197727806, 0.04151788954914082, 0.03711158438818529, 0.012871016133431112, 0.027959424805885646, 0.03127249263343401, 0.04712019537691958, 0.019815304003714118, 0.012963891276740469, 0.04032071999972686, 0.11663872675853781, 0.027964794244326185, 0.056553382164565846, 0.016228029307967518, 0.03358710651809815, 0.030058372431085445, 0.09834360651439056, 0.0019055447523896873, 0.05166366427147295, 0.012032085905957501, 0.017977905918087345, 0.07190948628704064, 0.012112800959585002, 0.04025705857202411, 0.061189882981125265, 0.06999507182626985, 0.10774206079076976, 0.03545989762642421, 0.022671819278912153, 0.0312084898178, 0.029381689600995742, 0.01994872360228328, 0.09353098663268611, 0.049576641104067676, 0.035484900581650436, 0.015311484348785598, 0.018052196755888872, 0.06713575494359247, 0.031212063258863054, 0.03696788604429457, 0.06242953677428886, 0.04176762595307082, 0.041837495446088724, 0.0166210298993974, 0.04034588251670357, 0.025940347113646567, 0.051166388220735826, 0.06723350321408361, 0.023360010964097455, 0.06987508138990961, 0.04194583045318723, 0.04091697257535998, 0.014710430077684578, 0.043858831122634, 0.09336723916931078, 0.01507246362962178, 0.014205635143298423, 0.036078540797461756, 0.04788338665093761, 0.04334750250563957, 0.007294232764252229, 0.04144754137087148, 0.0745497434400022, 0.04543083348835353, 0.03681305919599254, 0.03203528685844503, 0.026112516097782645, 0.01538061076644226, 0.08944397195591591, 0.05492734402650967, 0.019650202120828908, 0.051514377555577084, 0.013138359990989557, 0.032981647600536235, 0.053075240284670144, 0.02770907241938403, 0.051918347089667805, 0.025234380991605576, 0.035156990052200854, 0.07265660635312088, 0.014179381669237046, 0.05378303394536488, 0.03928524587536231, 0.05289069413265679, 0.07602854690048844, 0.0479711419029627, 0.01306762125750538, 0.09307602784247138, 0.012040636374877067, 0.04924891240079887, 0.046476018615067005, 0.027431342205090914, 0.03587151499232277, 0.017800499226723332, 0.03057846952287946, 0.05313490153639577, 0.01901296629512217, 0.03473596596450079, 0.07427591321174987, 0.04007515075500123, 0.010557624009379651, 0.04542082933767233, 0.021421723467938136, 0.04086381624802016, 0.038840729102957994, 0.02883740406105062, 0.0111800734703138, 0.022124772949609905, 0.04667486224207096, 0.1135293506376911, 0.12251307052792981, 0.024660177623445634, 0.04084088759555016, 0.019259682158008218, 0.05897332535823807, 0.03134656639304012, 0.07911801862064749, 0.05538319339393638, 0.034063420607708395, 0.04192251588392537, 0.00505338418406609, 0.03399413741135504, 0.030241078056860715, 0.022624770826951135, 0.06616563434363343, 0.014275514840846881, 0.014753536797798006, 0.015440900988323847, 0.05351515574147925, 0.03516053009661846, 0.05033424029534217, 0.03606723417760804, 0.019018766179215163, 0.06024210844771005, 0.019402870275371242, 0.07541188155300915, 0.06104363164922688, 0.011260086266702274, 0.008884848193702055, 0.012055144434270915, 0.025171099914587103, 0.13809232361381873, 0.014049472429178422, 0.06543565788888372, 0.04182955075521022, 0.039830089881434105, 0.1273688388755545, 0.07879047174355946, 0.029169370427553076, 0.040612012962810695, 0.06527105695568025, 0.09946845748345368, 0.034495194704504684, 0.10403263600892387, 0.11231837343075313, 0.018679395034268964, 0.045472865022020414, 0.09496926140855066, 0.05909798390348442, 0.06560067442478612, 0.07254374795593321, 0.0984054125729017, 0.11637226605671458, 0.019098845768894535, 0.04293629703170154, 0.06323977650026791, 0.09505949914455414, 0.03767146059544757, 0.02958044788101688, 0.08820616611046717, 0.13384839665377513, 0.014002124335092958, 0.018615292028698605, 0.05623213241051417, 0.02150175852875691, 0.03983329595939722, 0.0342684500355972, 0.013401237974903779, 0.01944383682712214, 0.03544859842804726, 0.016132804339576978, 0.04041180378408171, 0.06875419348943979, 0.11124134645797312, 0.020505048632912803, 0.046081207183306105, 0.07644083219929598, 0.021752281609224156, 0.06700352649204433, 0.0055095805055316305, 0.04969001158315223, 0.023055016099533532, 0.037335100714699365, 0.02910942344897194, 0.05029195272072684, 0.040815914326230995, 0.005770997386207455, 0.04031161384773441, 0.04684745610575192, 0.036779959409614094, 0.07230672825244255, 0.00896559107786743, 0.0677373843791429, 0.02242809427116299, 0.019750059946090914, 0.034196676933788694, 0.013685451776836999, 0.020872593559033703, 0.08429468420217745, 0.019247445998189505, 0.034518709653639235, 0.014287834492279217, 0.04466905229492113, 0.0388738808396738, 0.01903070733533241, 0.05889246836886741, 0.026431988408148754, 0.022599684380111285, 0.012269524922885466, 0.04826696196687408, 0.09560465856338851, 0.0324795921187615, 0.10601749512716196, 0.04572122845274862, 0.0419268908444792, 0.0627676815201994, 0.020173123084532563, 0.03309125910163857, 0.03556842930265702, 0.056004014768404886, 0.08353986806469038, 0.016336423686880153, 0.043159995184396394, 0.01949077210156247, 0.03424188485951163, 0.03386924508959055, 0.021543276125157718, 0.0441340194811346, 0.02959461919090245, 0.12428548987372778, 0.13391857413807884, 0.1326014252845198, 0.08498318944475614, 0.18421987420879304, 0.13325399573659524, 0.08892089885193855, 0.1647414662875235, 0.13717204565182328, 0.1339929224923253, 0.09171764526399784, 0.15816716593690217, 0.13998232141602784, 0.13583456195192412, 0.07143770300899632, 0.1373267685994506, 0.12646591232623905, 0.15117665432626382, 0.1655249367468059, 0.16730539355194196, 0.0851379643427208, 0.20035305147757754, 0.21418810909381136, 0.2343193397973664, 0.18019115523202345, 0.12314903171500191, 0.11988180078333244, 0.08242850191891193, 0.1334311909158714, 0.16201487509533763, 0.12493854272179306, 0.13145796867320314, 0.14687627961393446, 0.1360758044756949, 0.15404005302116275, 0.22152624267619103, 0.14654231315944344, 0.10555117405601777, 0.10978639562381431, 0.0979850378644187, 0.11941547229071148, 0.13886245025787503, 0.1427455004886724, 0.11540429768501781, 0.09470307530136779, 0.19176015397533774, 0.16727757785702124, 0.33636225562077016, 0.12729932932415977, 0.13120244722813368, 0.13695104891667143, 0.20733462763018906, 0.08378343351068906, 0.24331053311470896, 0.14447583263972774, 0.10221275631920435, 0.17917454650159925, 0.20413524383911863, 0.060579830169444904, 0.1173618457687553, 0.12359123298665509, 0.15736459259642288, 0.13567201676778495, 0.11823416614788584, 0.11607572610955685, 0.14994314551586285, 0.12414200304192491, 0.16298208647640422, 0.12976480327779427, 0.16145827918080613, 0.18889524129917845, 0.11562390660401434, 0.18645690026460215, 0.15106996317626908, 0.14246997074224055, 0.07848277731682174, 0.170471929886844, 0.10698419442633167, 0.22312775283353403, 0.22473574936157092, 0.15522832050919533, 0.15171748702414334, 0.1672658816096373, 0.2994396071881056, 0.20904113684082404, 0.14562317810487002, 0.14688663999550045, 0.21965637191897258, 0.197794942650944, 0.11301127960905433, 0.21600868640234694, 0.427730520023033, 0.2201881949440576, 0.19865941110765561, 0.25721475889440626, 0.17741350427968428, 0.23180209362180904, 0.1682626156252809, 0.2818584849592298, 0.39930427505169064, 0.11772406578529626, 0.1389204416773282, 0.11417375004384667, 0.18358643632382154, 0.1744126301491633, 0.15646833053324372, 0.15040783386211842, 0.18908285623183474, 0.1601468597073108, 0.16927489021327347, 0.1093830457830336, 0.16153513599419966, 0.24604221543995664, 0.09733082726597786, 0.11465800882433541, 0.15328122186474502, 0.3301857167389244, 0.16614427382592112, 0.13233684963779524, 0.16569681814871728, 0.17610635957680643, 0.07929225263069384, 0.15293944801669568, 0.2668328146683052, 0.1316160461283289, 0.19106119929347187, 0.17539992404635996, 0.1277733687311411, 0.10925126262009144, 0.22725974908098578, 0.1083810647833161, 0.1315457944292575, 0.16949495184235275, 0.1003910212602932, 0.1481543914997019, 0.13660069584148005, 0.10492004425032064, 0.16040897142374888, 0.109623442258453, 0.22638587019173428, 0.17677537602139637, 0.08921761691453867, 0.13024354790104553, 0.1878682425012812, 0.07621777971507981, 0.14751569920917973, 0.14930555160390213, 0.15480357455089688, 0.11176713582244702, 0.0960080826189369, 0.15639077610103413, 0.07313716181670316, 0.16937001870246604, 0.12575928383739665, 0.09315980147221126, 0.11206106340978295, 0.12948851654073223, 0.23512039915658534, 0.11819131454103626, 0.18434139346936718, 0.16066033684182912, 0.08897884574253112, 0.1213531827670522, 0.1409607837558724, 0.14872710686177015, 0.12659905361942947, 0.1382675743661821, 0.2752775646513328, 0.12280726528842933, 0.17367641965392977, 0.13215235172538087, 0.10911967983702198, 0.23969719419255853, 0.08549711186788045, 0.15351738809840754, 0.16403704939875752], [0.06837939406977966, 0.027556991517485585, 0.019885785768565256, 0.025707077111292165, 0.06226331053767353, 0.01902016141684726, 0.07558204117231071, 0.036632795236073434, 0.030094463072600774, 0.013320924608706264, 0.017147073449450545, 0.017563388610142283, 0.027129614645673428, 0.03349571103171911, 0.021137044896022417, 0.02550297536799917, 0.01575664122356102, 0.03502692125039175, 0.047767682117410004, 0.028148128840257414, 0.07941774238133803, 0.02598267179564573, 0.03499471575196367, 0.01896073023090139, 0.03218884092348162, 0.05111476442834828, 0.022958225199545268, 0.06413690687622875, 0.007683452577111893, 0.030896054922777694, 0.03723402762261685, 0.043238043144810945, 0.1038569473894313, 0.01633373711229069, 0.07378332753432915, 0.08282304246677086, 0.06039571817382239, 0.035620795242721215, 0.005125170273458934, 0.049902035752893426, 0.08337877748999745, 0.08955392855568789, 0.09248930815374479, 0.01294068802963011, 0.016866743862919975, 0.041910804793587886, 0.04256672975316178, 0.01104974306144868, 0.07708509801886976, 0.005856858306287904, 0.019836024766846094, 0.031174644173006527, 0.017605744833417702, 0.03188246009813156, 0.0343614040320972, 0.022679110879835207, 0.008708483292139135, 0.013903476210543886, 0.03313593268103432, 0.023498774025938474, 0.04144535574596375, 0.030253173208620865, 0.02343916472455021, 0.03502548148389906, 0.06136521536973305, 0.004914563141937833, 0.0016813978322716139, 0.030168553530529607, 0.01726951482851291, 0.047979628361645155, 0.04027056937047746, 0.06184224934258964, 0.0326116535870824, 0.045823095642845146, 0.050557611903059296, 0.06470231208368205, 0.08866768548614345, 0.050687951588770375, 0.10000926049542613, 0.03635182183643337, 0.04471121370443143, 0.03727455259650014, 0.02393808463239111, 0.06998163153184578, 0.0569585836637998, 0.0651165640738327, 0.055117200245149434, 0.034613637762959115, 0.04125134350033477, 0.05613701134279836, 0.08658694830955938, 0.028057712988811545, 0.07587292595417239, 0.038993930647848174, 0.07197227940196171, 0.04773009233758785, 0.06690725509542972, 0.01246144338438171, 0.07954513203003444, 0.038024173700250685, 0.024200482075684704, 0.016496363932674285, 0.03208522597560659, 0.08978297759313136, 0.012443851701391395, 0.050826647857320495, 0.07174824728281237, 0.07028514024568722, 0.031448095905943774, 0.04509160891757347, 0.05315874674124643, 0.01696368690318195, 0.037572432120214216, 0.044668083792203106, 0.05355030014470685, 0.05649825543514453, 0.0289708422133117, 0.059727299158112146, 0.020475386845646426, 0.04067923298862297, 0.054387561467592604, 0.016994638172036503, 0.09323952297563665, 0.03348157311847899, 0.04755450761877, 0.07225286317407154, 0.07163160393247381, 0.06904326000949368, 0.04522223061940167, 0.020085069118067622, 0.02792461065837415, 0.03583135738153942, 0.031180681544356048, 0.06167585983348545, 0.010702618328650715, 0.05484125860675704, 0.011240406365686795, 0.10564141921349801, 0.06497879920061678, 0.02928397287178086, 0.052881461815559305, 0.03707477015268523, 0.030979568800830748, 0.060837555793114007, 0.046450934023596346, 0.020238626893842593, 0.09466987903579138, 0.00431226345426694, 0.06349865987431258, 0.03381932452612091, 0.025717897624417674, 0.04110541871341411, 0.011236559257667977, 0.03960793910664506, 0.03570901804778259, 0.04434765040059574, 0.0220224140866776, 0.04778041737154126, 0.05483059023390524, 0.040903784611145966, 0.05273115464660805, 0.025770942629605997, 0.01817733584175585, 0.06076633930206299, 0.01117073168643401, 0.03124189388472587, 0.09126624136115424, 0.032908304856391624, 0.009473484478803584, 0.0395929922524374, 0.13751386402873322, 0.022273501199379098, 0.07712839491432533, 0.019238449312979355, 0.01012201950288727, 0.009526928388368106, 0.09763895213836804, 0.044983930711168796, 0.024074218636087608, 0.07360150877502747, 0.018200283047917765, 0.03452931123320013, 0.011460495825303951, 0.04292822617571801, 0.0420142898656195, 0.04017138504423201, 0.016240502955042757, 0.047112669999478385, 0.04474681452848017, 0.053796964057255536, 0.050710260547930375, 0.014701675518153934, 0.010599954257486388, 0.038630975905107334, 0.06778518611099571, 0.0377613309683511, 0.07149236960685812, 0.058733901096275076, 0.026646712140063755, 0.027179557473573368, 0.019039605685975403, 0.043686894059646875, 0.0320569612813415, 0.04180479641945567, 0.05225362714554649, 0.008941696705733193, 0.0999113786383532, 0.033034403168130666, 0.04601722292136401, 0.04819748952286318, 0.06100411599618383, 0.02452458538755309, 0.06726692954543978, 0.01655282838328276, 0.013264147528389003, 0.021315798585419543, 0.05148800162714906, 0.05336086695024278, 0.09303094979259185, 0.03467888367595151, 0.06115841220889706, 0.09346177394036204, 0.008674022592458641, 0.016863298442331143, 0.020535847761493642, 0.02049787392024882, 0.06398055862518959, 0.022471194497484248, 0.04063796215632465, 0.07078540715156123, 0.04772413660248276, 0.0019058039242736413, 0.039914572262205184, 0.024283431921503507, 0.08461296165478416, 0.010197383671766147, 0.014944597151043126, 0.03405995848879684, 0.018639578811416868, 0.06476158741861582, 0.05977833294309676, 0.03137800747936126, 0.03637399720901158, 0.05596237286226824, 0.03869421059789602, 0.048519563060835935, 0.03985028371971566, 0.046547316742362455, 0.015255823273037095, 0.02790549107885454, 0.04012368721305393, 0.06549165293108672, 0.023296724320971407, 0.028103870863560587, 0.07424148498103023, 0.027643692919809837, 0.019515997701091692, 0.041784869754337706, 0.003827520422419184, 0.0445890747505473, 0.12345150884357281, 0.03444558955379762, 0.051249230455141515, 0.012624395822058432, 0.013296543202159228, 0.05349660576030146, 0.028020334721077234, 0.03674269246403128, 0.02420543405605713, 0.10092968688695692, 0.04617639504431281, 0.04001399778644554, 0.05617300179437734, 0.0653425331984181, 0.07179722160799429, 0.008406644410570152, 0.024759143016126473, 0.015361092282546451, 0.02249916233267868, 0.027156671494594775, 0.037435787889990024, 0.05504570173798129, 0.0646940890874248, 0.05178126128157601, 0.023017674939183053, 0.09158126820693724, 0.05480171326780692, 0.028224583038536366, 0.03346750199852977, 0.03222444545826875, 0.04697820397268515, 0.02399637105554575, 0.008600915480201365, 0.039073930456652306, 0.01576941358507611, 0.02857137380487984, 0.07198187537142076, 0.03816184209426865, 0.02391971091128653, 0.053533100872300565, 0.053297791819204576, 0.0009739614461068413, 0.029063439978926908, 0.07332320339628495, 0.07613424357259646, 0.010589824869384756, 0.07014565358986147, 0.011191384728590492, 0.03816950476903003, 0.07206311827758327, 0.009271858725696802, 0.09966981699108146, 0.04235632346535567, 0.027362422661099117, 0.03468976356089115, 0.0546882685739547, 0.043443172762636095, 0.05175567574042361, 0.06066760768590029, 0.02404342136287596, 0.08204609548556618, 0.025204277626471594, 0.004348614311311394, 0.020093509192520287, 0.037265420469339006, 0.01196511264424771, 0.026672531457734294, 0.042602319444995373, 0.04282594338292256, 0.02549766344600357, 0.05000412929803133, 0.017141863572760485, 0.11413313972298056, 0.07360199859249406, 0.03049195551284356, 0.03964656047173776, 0.043166767281945795, 0.06541979819303378, 0.017589005692570936, 0.027087184207630344, 0.01925702155858744, 0.015572876181977335, 0.047037527547217906, 0.020663751347456127, 0.02613260232465109, 0.06970976799493656, 0.07329186992137693, 0.006379155865943176, 0.046848109195707366, 0.011639501844911138, 0.008638263134344015, 0.03611880601965822, 0.18555896094767377, 0.10379662562627345, 0.14143734646495432, 0.12190182285849005, 0.10054694648715667, 0.1189845813496504, 0.14698141225380823, 0.12179770696093328, 0.11659495488856919, 0.12595190084539354, 0.144585240050219, 0.11670422871247865, 0.1649204277782701, 0.1479672218556516, 0.10370577932917513, 0.11377896458725445, 0.11277561803581193, 0.1351302638067864, 0.08582896320149302, 0.07333344503422268, 0.1293530745897442, 0.10584413685137406, 0.10644397771102376, 0.05966605713183526, 0.11939675532630645, 0.255749462521635, 0.1205263115116395, 0.11237679529585876, 0.10836742410901934, 0.07268028828548267, 0.1841394996154122, 0.1754862506641075, 0.1942827584571205, 0.124015741457697, 0.14574171393178403, 0.19221120164729655, 0.13841132837114856, 0.1378940514405258, 0.0783020124072209, 0.11235880563617684, 0.15032503986731172, 0.13515689206542447, 0.2196098244166933, 0.13260546256788075, 0.19625584711320698, 0.14311020669993013, 0.11310843416140415, 0.12782689242158085, 0.1214696851093322, 0.15715140325482935, 0.2133291176869534, 0.13436623761663213, 0.1720635694800876, 0.1737017565756105, 0.14752525807125494, 0.11763128990423866, 0.08460182201815769, 0.12484388920711353, 0.21307166665792465, 0.11165781004820019, 0.12954114965396002, 0.11411181039875373, 0.14720111765200272, 0.1737215867615305, 0.18828706612112, 0.14445444394368678, 0.2004723739810288, 0.14544525562087074, 0.09060582640813664, 0.13668537489138544, 0.1353663409827277, 0.29314563085790724, 0.12097008613636717, 0.09479312007897533, 0.1423564666765742, 0.1427733458695002, 0.1628561143297702, 0.09316395007772371, 0.14461425802437589, 0.1744498117477633, 0.08757088027778082, 0.1212230471719522, 0.13858579244697466, 0.18820734461769462, 0.1988966905628331, 0.11870399015606381, 0.14877619250910357, 0.13118408649461344, 0.10641168686561286, 0.140181825554464, 0.15270656207576394, 0.19242817594204098, 0.16113149671582505, 0.21821596717927605, 0.11986856829025783, 0.2464340248843655, 0.17022372601786628, 0.40661146107595414, 0.22504598193336278, 0.1325699730659835, 0.12954426667420194, 0.18347465404076502, 0.18404434144031256, 0.2017201913986355, 0.14044329902390018, 0.15156825596932322, 0.17324998159892857, 0.25503768352791667, 0.17009775387123227, 0.1451371901202947, 0.16591877967584878, 0.16499397461302578, 0.13674632005859166, 0.12506568746175617, 0.16656452236929908, 0.1086601271526888, 0.10084593552164733, 0.15295109973521903, 0.3066785749979317, 0.11197240644833073, 0.17955902352696285, 0.15606262808432803, 0.15987955295713618, 0.14247494313167408, 0.17319430568022653, 0.1259516188292764, 0.11110724779427983, 0.2134185761678964, 0.11038470023777336, 0.2115130823221989, 0.18960393295856193, 0.1397871068911627, 0.15169197198702022, 0.17045187705662102, 0.061690728762187064, 0.1937542750965804, 0.12474034476326779, 0.2109943507821299, 0.15195451414911076, 0.19918483681976795, 0.10491010689293034, 0.12299735899432562, 0.09415717373485677, 0.1387931633507833, 0.14976483711507171, 0.11533702199812979, 0.12926345283631235, 0.10886625866987742, 0.14014218002557755, 0.1404093235032633, 0.14936170249711722, 0.08819924187264405, 0.14091162389377132, 0.08705141401151195, 0.18749654525890946, 0.10225427206023596, 0.14275001274654642, 0.21799893351271749, 0.2044143358943984, 0.1057272263278719, 0.2161523068207316, 0.17987053259275854, 0.1532654438051395, 0.12582152034156024, 0.10955471938359551, 0.1658725438755937, 0.15507603180594742, 0.07839046156732365, 0.1345320779364556, 0.10605271003441885, 0.23092552815796807, 0.10385261324699968, 0.12951505574164912, 0.10958194136037491, 0.13817551836837083, 0.12693046708591282], [0.013893758714402793, 0.06578652304597199, 0.018921591217804234, 0.07381860923487693, 0.02969430817756802, 0.016165091474249493, 0.06545808559167199, 0.003578475839276507, 0.008479537227685796, 0.05103798925119918, 0.026831794493773486, 0.039184740526252426, 0.05990619756630622, 0.013066274259472266, 0.016581825948378537, 0.07008818167378195, 0.05327131199010182, 0.020539538090815768, 0.047497198975179344, 0.061190558335511014, 0.0623561383690685, 0.047290681541198865, 0.02327493672055425, 0.03416714316699654, 0.01893517252028687, 0.03951150814827997, 0.023989227884158026, 0.03759099323360715, 0.020464779699977953, 0.017241116547666024, 0.037412425081129186, 0.042448134554433636, 0.02465683239279315, 0.01839085729443468, 0.013404281708062626, 0.05487843278388027, 0.10601353205856867, 0.03312749817268923, 0.03904725024767686, 0.008197822608053684, 0.012747754681186052, 0.04133414491661824, 0.04101007871213369, 0.01970423232705798, 0.030293816926132422, 0.028441653812478762, 0.010617464304232271, 0.02113215043209493, 0.022844324084871914, 0.05948417528998107, 0.06572597863851115, 0.0266434930745163, 0.04835581188672222, 0.06968172223423608, 0.021850881494174246, 0.06601524553843774, 0.03456091188127175, 0.04703866674390156, 0.07159281929489225, 0.025648961382103153, 0.07164881433709525, 0.032993685235851444, 0.018761209394142497, 0.035346363874850795, 0.033108272837125696, 0.02521114620321896, 0.06582506277482025, 0.06674446500255726, 0.009554313637636369, 0.025696620250528213, 0.03224860607588198, 0.049829817362478934, 0.07117955436115153, 0.017682427242107224, 0.030081757504376583, 0.047108150320127606, 0.028970528655918315, 0.056577101204311475, 0.03333862805448007, 0.002528453069317038, 0.040040622334345244, 0.025715543160913512, 0.04136761948757339, 0.01119197380830883, 0.08492945795296691, 0.040194606845034286, 0.046041134919505566, 0.09231563075445592, 0.09802980421227403, 0.0889522026409395, 0.03288743566372432, 0.024845673724485096, 0.06440172001020983, 0.0716267131792847, 0.07010012282989919, 0.051175924818380736, 0.03613533735915553, 0.02404310966085177, 0.056033080982160755, 0.027776854622061364, 0.05551589681999758, 0.08519225986674428, 0.05102290881040972, 0.011227660907024983, 0.024434084189124405, 0.04177291746600531, 0.05287173968099523, 0.07439164372044615, 0.042438011660124175, 0.03601315758714918, 0.02938128698588116, 0.037288853782229125, 0.026236523408442736, 0.03569151449482888, 0.06658859172603115, 0.05591297922364902, 0.0535442034015432, 0.0179225862302701, 0.020553176909743343, 0.027805748286482412, 0.03696020852657966, 0.07585553001263179, 0.06196771311806515, 0.02559241900598863, 0.025364767061546445, 0.014504780956485774, 0.033921696376637556, 0.026586130625219084, 0.01570935157360509, 0.010762283291114727, 0.027673059703374747, 0.018890825485868845, 0.03963934308558237, 0.04648435664421413, 0.007151329909902415, 0.03513547148031648, 0.04421885809279047, 0.05778737337095663, 0.011333353868394624, 0.015785338218847755, 0.025892695666698273, 0.011334000464557903, 0.023716954310657457, 0.07687240591621958, 0.028383391509123612, 0.020971558951714542, 0.06930704897968099, 0.05880824573978316, 0.02512326664145803, 0.004236789354763459, 0.03519864309055265, 0.04751105487230234, 0.01457494452552055, 0.0172253199343686, 0.04432553439983167, 0.013755135732935742, 0.04001663241069764, 0.04222484087222256, 0.029150000373192597, 0.051922146885772236, 0.03852383575576823, 0.028768339798261877, 0.010852677805814892, 0.047666397513239644, 0.0849384230969008, 0.03862772529828362, 0.07395004358841106, 0.025040481923497282, 0.029224415520729963, 0.028638796065934002, 0.02735960249992786, 0.02742889497312717, 0.03558851924026385, 0.028732820610457566, 0.014945673265174264, 0.0717693094338756, 0.05375585278670769, 0.033766049455152825, 0.0667990351212211, 0.06464898877311498, 0.04930690010951366, 0.038869223863002844, 0.02680620895262109, 0.011801615655713249, 0.014081129666010384, 0.017581602769496385, 0.02250771187391365, 0.06872107886010781, 0.01705612325167749, 0.029222109296824783, 0.00913047588255722, 0.013670776734215906, 0.027990340822725557, 0.010691540846892167, 0.021143822559679393, 0.04127275446080603, 0.1099864934803918, 0.0051883799187635304, 0.0365342046279693, 0.02164350873499643, 0.018694889222388156, 0.05168982497707475, 0.040210225342889316, 0.06146378371340688, 0.0546604491682956, 0.03440199208853301, 0.07395062988507561, 0.07098088142811321, 0.013774112449027598, 0.019272899808129296, 0.03990476849139668, 0.03846277184493374, 0.11887442437000573, 0.016886492412595544, 0.008607299805589719, 0.048770824578241445, 0.08937921214965172, 0.013961155000288272, 0.03051465224416461, 0.04687494154495653, 0.05410782374383416, 0.015766918113513384, 0.008392954568989808, 0.06745535341906361, 0.01568859184772009, 0.05650021099427249, 0.061589778124471195, 0.02458616509102285, 0.10349912088713609, 0.055216629480128177, 0.016321677212545183, 0.026787827810039744, 0.06217719172127545, 0.004678034647440654, 0.011878471541422186, 0.06581815337995067, 0.05987709424516652, 0.028756009014614392, 0.07280556281330064, 0.015092935773282079, 0.05368184582039248, 0.0470719223812921, 0.061333009871304967, 0.0284501885107602, 0.04674538111430593, 0.07112130319001153, 0.032776347288745455, 0.04771413245180156, 0.02935376629466191, 0.017313295975327492, 0.021015787242504302, 0.033558786162757315, 0.03388285978871863, 0.059415352225187235, 0.037334848384489305, 0.038962615726632066, 0.04137667368922848, 0.02971623864141293, 0.014821437744103605, 0.022430483986681793, 0.013418014223134378, 0.016450623515993357, 0.044994866257184185, 0.0092499264064827, 0.07259203950525261, 0.07944647833937779, 0.018904104363173246, 0.08400108315981925, 0.05640357223455794, 0.024391911647398956, 0.06428812688682228, 0.042044999936479144, 0.06038218140020035, 0.026529786773608066, 0.03046300247660838, 0.017665007180767134, 0.019610846029536333, 0.06889383599627763, 0.03456750957411714, 0.04620956533472054, 0.01797005214029923, 0.07460428387275897, 0.005132066680744174, 0.021721298799093347, 0.04259132452716585, 0.018920596739917528, 0.010177239928452764, 0.04428268650372047, 0.08033905192860402, 0.053701267825090326, 0.047816270525800064, 0.0498856417107163, 0.04270849851309322, 0.07500781925045885, 0.04180849231488537, 0.08493938046740368, 0.0451182483084267, 0.04006523195130285, 0.02790178776194807, 0.030626571824541315, 0.03839634591713548, 0.0692160839389544, 0.01603201326361159, 0.0597685625689337, 0.11592108479817398, 0.012553106043924345, 0.022700911467836704, 0.031652216202928685, 0.020284636339056306, 0.033124796755146235, 0.022049689869163558, 0.05258066565147601, 0.04192849388346076, 0.07206927810329944, 0.01453431936170091, 0.02321664844203042, 0.01722076685837237, 0.007282607948582154, 0.034577684418763965, 0.061296240164665505, 0.052410806601983495, 0.015425176734424895, 0.027241845928074326, 0.04825647170946468, 0.04506612356635742, 0.03454028017586097, 0.0477968967607012, 0.07894357680925168, 0.02211872073530685, 0.02265739192807814, 0.0379915043595247, 0.04273311555152759, 0.03662042734504212, 0.007709525616519386, 0.017222351343662012, 0.05377774243243039, 0.05018728021241259, 0.026635824833647348, 0.01599238814378623, 0.030318975732370745, 0.054680539105902426, 0.030384947094717063, 0.01732491800794378, 0.01835060877056094, 0.07301305246073753, 0.028608329048438463, 0.043416848784545437, 0.06815349915996194, 0.024611604058009107, 0.06917474631336518, 0.021581272230832838, 0.10932382239843719, 0.12388552422635257, 0.14194951741956174, 0.12163453095126897, 0.18564984435215592, 0.08631826858618297, 0.11371968925232068, 0.14250099251512438, 0.11423643925809301, 0.06493768421933055, 0.15031460527097806, 0.10322345755412243, 0.13451750215608627, 0.19686394807649776, 0.13838355720508844, 0.11867864581290632, 0.14051901292987168, 0.15646861254936084, 0.16922291019000113, 0.08518732458469458, 0.259176463005133, 0.20815847092308104, 0.13189990277169272, 0.09976565052056685, 0.11678182025207207, 0.10427988992887549, 0.1835741166723892, 0.10341464221710339, 0.08115856107906438, 0.10583054812741466, 0.08156207419233397, 0.14532823377521709, 0.10994488126016222, 0.1734606031095609, 0.09666173660662025, 0.10996468176017515, 0.1592673998675309, 0.21400968194939196, 0.12874619074864313, 0.09888391970889643, 0.1127013513178099, 0.1788013501209207, 0.08386098794289865, 0.09918147639837116, 0.12603090988704935, 0.10509988889680244, 0.1629315610625781, 0.07340888434555382, 0.12402783104334958, 0.09555822238326073, 0.1561047523864545, 0.13716382265556604, 0.07322665740502998, 0.17186433251481503, 0.15647827531211078, 0.1733702392084524, 0.13010470691369846, 0.11539592625922523, 0.10656979400664568, 0.1652252278290689, 0.1406991618569009, 0.1347483991412446, 0.11759233457269147, 0.19156416761688888, 0.1016927779710386, 0.13126783043844625, 0.11661643264233135, 0.09893529859255068, 0.16575191519223154, 0.22297665156656876, 0.11531077223480679, 0.13776598643744364, 0.14147719979519024, 0.13169269514037296, 0.10247297555906698, 0.11986905068624765, 0.1348108731326647, 0.12496748648118228, 0.19207584875402972, 0.14722586085554212, 0.11201659392099828, 0.12834599503548816, 0.09575568561558612, 0.10264939890475944, 0.09079378272872418, 0.12516909831902012, 0.15638590761227533, 0.14903839328326285, 0.16232633963227272, 0.13955218746559694, 0.14199841010849923, 0.22256242926232517, 0.19178828137228265, 0.27807697537355125, 0.14411308569833636, 0.15905033651506528, 0.20051745203090832, 0.14466846449067816, 0.08497193848597817, 0.14638294436736032, 0.13888855901313946, 0.09076405971427448, 0.19889710616553202, 0.1542786238132976, 0.18773967283777893, 0.12738608638755977, 0.1565542267053388, 0.097391393937869, 0.16179733676835895, 0.11958155009779148, 0.0954850392008666, 0.07745333685306832, 0.14225378312403336, 0.15193650964647532, 0.13772037404123694, 0.20099497953196988, 0.11639247473794967, 0.10653148434357718, 0.16163643915206194, 0.1058115268824622, 0.20462287939153612, 0.1589193771360442, 0.13256408041343093, 0.11683172226184979, 0.102603459963575, 0.17438030219636858, 0.15678469324484468, 0.16596130473772064, 0.09610779758077115, 0.26041525590699166, 0.0580487355182413, 0.08940249332226813, 0.10448634056956507, 0.09888460990623571, 0.16664976545143872, 0.12556513800518587, 0.13197413238231093, 0.1366808477905579, 0.14326668111607432, 0.07188518095063046, 0.11882573206094094, 0.08018141976208426, 0.12240284675499424, 0.1413266477175057, 0.22981321206316352, 0.17940361780347303, 0.11086047627031803, 0.1287099887849763, 0.23925196495838463, 0.139666908653453, 0.1261723632342182, 0.13466167176375166, 0.24374016240471974, 0.1265460642753169, 0.09466983450693078, 0.2633508655708283, 0.14425740373553708, 0.12540654104668647, 0.17422967590391636, 0.08395558208576404, 0.1995390045340173, 0.10097281308844686, 0.10434125069878064, 0.09826212612097152, 0.1542269258061424, 0.1938304046052508, 0.12536422378616408, 0.19976988667622209, 0.14282979362178594, 0.13517871120711789, 0.09418351997737773, 0.0986804896092508, 0.15182909119175747, 0.11568704852834344, 0.13453552150167525, 0.1196599579998292, 0.2240063072531484], [0.03219302663637791, 0.0896081276005134, 0.008756936258578207, 0.01624036936846096, 0.029380418673099484, 0.041363103518961, 0.028997210720262956, 0.018594200191728305, 0.04310449738113675, 0.07708527613431215, 0.03635786662925966, 0.06519658243632875, 0.039295283422688954, 0.008575279844080796, 0.046240227165981196, 0.0870135793229565, 0.03639452872448601, 0.031890107929939404, 0.05130679142894223, 0.04272264755854849, 0.02940789854619652, 0.04318731364037376, 0.05709467128326651, 0.04505153665377293, 0.018311015192011837, 0.05306351064064074, 0.04461021853785496, 0.04588525422150269, 0.07443243215675466, 0.015419627325172769, 0.0219443104651873, 0.040072423362289555, 0.0665262810070999, 0.034970098713529296, 0.05489556155225728, 0.014558513375959592, 0.0335084388643736, 0.03637788235209882, 0.06269988632993773, 0.053918030607746914, 0.05907435763219837, 0.03249702145694755, 0.0743006489938125, 0.05527967121452093, 0.039865401267888956, 0.018062002382066566, 0.09363920660689473, 0.031908665332593955, 0.056124342881958, 0.030486346731777303, 0.08893108111806214, 0.01606977002666099, 0.01901661766169127, 0.03131558914901689, 0.04097606237337459, 0.01850942280725576, 0.028392117310431786, 0.012330951558396919, 0.05831625749124214, 0.012239251791470451, 0.04043735592858866, 0.011117035446659429, 0.09181967572658323, 0.011871731912833638, 0.09489958858466707, 0.04645933513529599, 0.040512160703656264, 0.057555867824703455, 0.012097807721147547, 0.05403857765486464, 0.016474607873533387, 0.05389146914239973, 0.05736153274483513, 0.04161024611676112, 0.011285877753834939, 0.033132875032606535, 0.012199511638755212, 0.03763769658689853, 0.02731631488131825, 0.044389014001353644, 0.027859880538017023, 0.08046419286984019, 0.07619230178534053, 0.009799192685022717, 0.04226887620461639, 0.009147912642220035, 0.022868377091072034, 0.05036630478571169, 0.024535771408409346, 0.016300769057124853, 0.009644962337915786, 0.12762125814333558, 0.0662855950940866, 0.035766823930316605, 0.05123427989019547, 0.07498353617847897, 0.07606510509504005, 0.04665094653319102, 0.023649656359339133, 0.09370515384944156, 0.04967303124431055, 0.012479260494728805, 0.01904334425489651, 0.03481614388874732, 0.0699314549274277, 0.02098460590786999, 0.011006272688973695, 0.041188980831066146, 0.03820191806880757, 0.009264524451282341, 0.0425828158040531, 0.028219323066878133, 0.04925562141579576, 0.05400902904511895, 0.05235851858742535, 0.058053834072779864, 0.015424814009747934, 0.01849784530350007, 0.007842622380849207, 0.051025510038016364, 0.07309454027563334, 0.03622709649789613, 0.08008645454538055, 0.019695103910635225, 0.023621024301974103, 0.029756756193819456, 0.055116365329013206, 0.031636048515792936, 0.004859236032643821, 0.023078510639606975, 0.05376697015890386, 0.031753478542668745, 0.03773208292841446, 0.025935016637959052, 0.031316539098042995, 0.07164341892348602, 0.06509418832138181, 0.040501488620066084, 0.020501766484812833, 0.025447917287237942, 0.024657873254909646, 0.07291082903975621, 0.06805494194850326, 0.02091607042530086, 0.02600458185042953, 0.025455876821069978, 0.04787197241967078, 0.014357592663145624, 0.025182874087477103, 0.018728040959103964, 0.011522891891218023, 0.04412166272231843, 0.0735370532493107, 0.034507154414313845, 0.052565258665708825, 0.041053772656596266, 0.010653458466549637, 0.019669549910759088, 0.05886806655325927, 0.04700726276496425, 0.06405276959412731, 0.028025110441376455, 0.03785929446166847, 0.01275937671380234, 0.08557218010537326, 0.044772455730708316, 0.04980330042599235, 0.07840340462280437, 0.024108574507408775, 0.03707730458700098, 0.06066987494705245, 0.09658118389779702, 0.028248981143406127, 0.061426639222190715, 0.04254728919477202, 0.06170107430079952, 0.01331072471657535, 0.10987945352098905, 0.016245031911239494, 0.03367918478033971, 0.03600467854994349, 0.033208384847966954, 0.03350012681039516, 0.01184616028695018, 0.0222916708298726, 0.06507724508992396, 0.07331702130613849, 0.02381692345807096, 0.08869659213814884, 0.0470731395034818, 0.010791991462610895, 0.04167308747128118, 0.04108148074010387, 0.015458424022654071, 0.01680365574429743, 0.01350476200968842, 0.10198390766163357, 0.02656037253473187, 0.02250545017886907, 0.0346227810223354, 0.04334759898483753, 0.03292925197456498, 0.008072108357737307, 0.03469948198471684, 0.026838394041988067, 0.013158423025743105, 0.0743727560620755, 0.05617395545414183, 0.05403613227827009, 0.03682737151393667, 0.011155243992106989, 0.028049081811332144, 0.06763743935152888, 0.025395054108230397, 0.05421881935035344, 0.03379476685950067, 0.07758227016893215, 0.06737058531143703, 0.03780789331358392, 0.027948259194090497, 0.06079676364606712, 0.08382059284485877, 0.04574340382532682, 0.02850067310646409, 0.0408584950491786, 0.015434166925842874, 0.011180160672665806, 0.026250318078382406, 0.019115623872494325, 0.034194725085399114, 0.03086876244196901, 0.03552478730853181, 0.041279051583842374, 0.03812769216892775, 0.041470789146842435, 0.09027769323438406, 0.04470895015401766, 0.045554527241620235, 0.031190615191007964, 0.040177975315600634, 0.017003709072014317, 0.02221598660980817, 0.01684825139818713, 0.06915325371664949, 0.034443040276528336, 0.12433737341780216, 0.011946983831876423, 0.08374672688660212, 0.07250985407154076, 0.0686221728392411, 0.0635339786822442, 0.03256914707890246, 0.04129720080527477, 0.03561184123100247, 0.06434883456677198, 0.08423554245382547, 0.025080890009121504, 0.0412359105393989, 0.02774979962850921, 0.020493732736213133, 0.07830269518308342, 0.04581938490446191, 0.034637620265129954, 0.03474178069154732, 0.008294154304167023, 0.04206369092571549, 0.038374033247237094, 0.05545046165934764, 0.03223705083655659, 0.03139126223686617, 0.03340973693411797, 0.10762181802419946, 0.04245533709763549, 0.045504161389544606, 0.05359461378247943, 0.03230092748708557, 0.10006575277657248, 0.013146768524165964, 0.06998759839916602, 0.02092264770908514, 0.031536481983494014, 0.061398764155455865, 0.024161040637409315, 0.031476809599553235, 0.09441924834391102, 0.00795202422523289, 0.030289358473964967, 0.037587557089864276, 0.03461240579781588, 0.0487502745090751, 0.03378799847268965, 0.014525697461067466, 0.04000150744104758, 0.01848632160545094, 0.0139359627974045, 0.031205098202917725, 0.041397895402042195, 0.0060262836632318795, 0.03613490320276469, 0.010286170509061776, 0.043257839934085496, 0.07897083589341491, 0.04211124774883501, 0.050747097047860734, 0.047268016351154074, 0.029810691776219755, 0.02840909393853508, 0.03261057376221288, 0.051406057391432114, 0.029600064699479844, 0.0294895255137817, 0.05968028410279658, 0.03973568127548788, 0.045780633663525805, 0.03544988234352786, 0.04286098017473705, 0.017841929620772135, 0.07211413350887597, 0.016531860856048297, 0.0441669077554252, 0.04264567942300346, 0.0431659917376237, 0.03183491440722719, 0.04235890242853202, 0.05047609440225642, 0.07359812458162196, 0.04381346363516059, 0.06552668230142444, 0.04181278563919477, 0.06994903640588745, 0.010363060719100758, 0.026459470136614982, 0.023460549709852785, 0.024129987323249225, 0.10165253872401081, 0.0867371738422662, 0.051464664793456905, 0.092480053572217, 0.05598363910394255, 0.0067626671716425335, 0.04624737775884569, 0.07395684908260591, 0.05858574244484771, 0.05619761141133495, 0.13194854313042015, 0.02474959157552803, 0.03570464308722876, 0.01983382986509241, 0.05289639382681344, 0.03942457296943758, 0.04414060233102646, 0.04608719260431826, 0.11210084994672798, 0.2059035442653112, 0.06779743896913715, 0.07650833795196377, 0.1149548011017032, 0.1536786271026358, 0.16087894386146218, 0.16813872149214149, 0.10822001873748377, 0.26251499948557466, 0.21737232338637114, 0.13156889006495476, 0.27069239818956703, 0.11080676704295911, 0.10632979829097167, 0.28408014855813235, 0.21629702561767772, 0.11174862665939145, 0.13033775612711906, 0.07344257785007358, 0.19724750483874232, 0.12351016819593497, 0.14319259993499145, 0.14007408055476844, 0.12607350916368887, 0.1335032089264132, 0.10038675391115248, 0.28426794160623103, 0.11148412522743456, 0.093182785785757, 0.13794874772429466, 0.12486745981732383, 0.14278256334364414, 0.19319102953886613, 0.13164202129701152, 0.12563920434331521, 0.14372712437761948, 0.08120680067804642, 0.2748871356016025, 0.1306726725306362, 0.10338984706322663, 0.16911132086534053, 0.10688583017326891, 0.19834805047139525, 0.156030849320814, 0.14897109533194453, 0.1840427829301916, 0.1018870722327847, 0.13129379076417536, 0.1582837276509963, 0.10263678981573321, 0.14085088652791455, 0.10219881136436015, 0.2390809592907317, 0.14380899810930714, 0.08079329825704917, 0.15185058378847316, 0.14597834029700607, 0.16239390475675464, 0.10001809205277823, 0.10730539594078436, 0.0905515011982061, 0.2058020036201924, 0.13845012785168365, 0.1339396956609562, 0.11144269112264737, 0.1687212777324021, 0.2159929380286485, 0.11321972662699409, 0.16378543165046722, 0.11248785769566894, 0.2351544043631293, 0.1799776393454522, 0.17078256321838126, 0.20696914958534762, 0.10648523370036855, 0.06211425759829581, 0.16196860960917547, 0.16661224246490747, 0.1665045865229331, 0.1172836530895438, 0.17418547358829528, 0.13763198425294831, 0.10659047024091706, 0.1969125439063646, 0.13392443710472435, 0.13096510840114206, 0.12736077915178612, 0.16036613465985283, 0.17349664180073887, 0.14579869603039697, 0.2712655143113807, 0.35980667104013264, 0.1983000335167162, 0.08871804020600393, 0.17270793177885935, 0.17511121375719085, 0.09650708787376061, 0.09411363935214467, 0.31993882439564914, 0.17125887359725311, 0.0767278578132391, 0.17071219277568161, 0.13586651883088052, 0.24410394835285842, 0.1744105521356687, 0.06366063360474072, 0.1377575407968834, 0.18470534268999472, 0.09995458647608757, 0.11545260407729074, 0.10549005819484591, 0.16609042359050363, 0.22021645592758432, 0.07385020246147178, 0.21382512466516346, 0.17586723959539086, 0.1044978215941228, 0.07561336722574197, 0.13774183695204556, 0.11063777259550989, 0.11314119255985133, 0.1280962920282036, 0.07309629916562699, 0.13342130550881848, 0.26819314167369157, 0.11629186919890344, 0.1259369243052788, 0.11944356258027256, 0.08314241087646224, 0.11707055280567147, 0.14430019597057253, 0.11051144421799108, 0.13343724684091285, 0.16027195611968637, 0.24566567939473316, 0.18541824974818155, 0.12128674570703879, 0.27161874691955745, 0.08701616199687123, 0.09947237602318637, 0.2735125593608245, 0.08307751748361625, 0.2905913960421458, 0.07880328121245839, 0.11935849019209854, 0.1638341907528229, 0.11719171583536081, 0.1346205864683725, 0.1659176219254732, 0.11057782932766713, 0.10604654278722592, 0.11391298161470331, 0.09649528772570193, 0.14358731859829277, 0.15374576178146526, 0.08387065812712535, 0.16105645074276254, 0.21820928785018623, 0.1596853180672042, 0.14586614241125062, 0.10980925377225503, 0.19899658364010975, 0.16326284094247967, 0.2959442400606349, 0.1863977510947734, 0.12861974362749606, 0.20332729734946042, 0.3295011300360784, 0.1203010548488237, 0.1846462083631195, 0.24351542524527758, 0.11920455392100848, 0.21215575252426788, 0.19897785183275118, 0.20140495675150305], [0.022483972425106913, 0.06471269472967833, 0.023322107626881916, 0.1017952463007532, 0.014413683256861987, 0.10475544331711717, 0.020528736131382175, 0.05346196601749398, 0.026822385916602798, 0.02866467290004948, 0.038074057156336494, 0.08200011201552115, 0.0521545615629293, 0.041227134643122554, 0.028910603941767476, 0.056123155445675366, 0.04348044341895729, 0.06172190267534461, 0.04845655843382701, 0.05481984022480901, 0.011480620087240823, 0.021184301149332896, 0.08382276733755134, 0.01877182767202612, 0.04209386293950956, 0.02139298008842161, 0.02958013617899269, 0.02845650047675008, 0.0495000588853145, 0.032547532027820125, 0.03163037479680497, 0.0315593475534115, 0.014927489719411824, 0.02253050137369428, 0.018420652668282855, 0.05249341134913266, 0.013023051578784361, 0.05283917795168236, 0.0965931398968678, 0.1005164887465071, 0.01729306317429291, 0.09291741604101844, 0.020835126233578194, 0.036473615691647865, 0.034253102421644144, 0.016409851778007578, 0.034037267323583364, 0.03577242714527529, 0.04050642761285417, 0.10155148047488183, 0.021689397581212688, 0.0490260157675948, 0.03286879291408695, 0.046055788625380956, 0.052027962301508524, 0.04828966055356432, 0.033837280789157376, 0.04848307908105198, 0.04647094232495874, 0.02506366105080815, 0.07422415583278053, 0.05252403978374787, 0.07710544028668664, 0.04910400435619522, 0.051363550883252174, 0.029268597427289933, 0.017291510230279528, 0.032386790262535214, 0.029079138257657178, 0.03320591349620372, 0.03890406769642141, 0.03206138077075593, 0.04319512103393208, 0.017607733789191116, 0.06636668957071379, 0.05351286621589679, 0.038748788138036616, 0.049438998685218394, 0.051971881912322715, 0.050858356116805226, 0.02819280056428397, 0.011412706153350882, 0.04196891495666932, 0.08952083619078621, 0.1273637922713533, 0.07353702356340364, 0.08230002873460762, 0.12405548346578144, 0.0656039769819472, 0.039010673499433324, 0.03845412582450081, 0.03318454335385468, 0.11506705835927278, 0.017985917402256746, 0.0082896003004862, 0.04612992917827796, 0.035684174654306844, 0.05083520482003223, 0.05587835803453345, 0.11505042682983913, 0.05062649062892888, 0.06333511279080994, 0.06864494192996062, 0.05840277335664723, 0.014999375998741016, 0.05591746921709273, 0.03588403131288942, 0.047535438134218566, 0.1123341366474051, 0.03354636261065025, 0.029382094071479514, 0.05271296089631505, 0.022625394230999518, 0.042851584585150704, 0.020255484778317623, 0.056616405345266685, 0.035883222371921875, 0.05198858765652403, 0.015448944013769506, 0.03430637749261223, 0.019172613392584026, 0.020517670709523372, 0.06177969742566347, 0.033794143455452286, 0.05716900108382106, 0.0812868561479263, 0.024819359023240395, 0.04178510353085585, 0.10070177333545871, 0.03676642263599206, 0.06895701502799056, 0.020910571111016907, 0.012056563791702501, 0.029734655036008917, 0.04607905495504383, 0.04072364310559351, 0.05325951184204314, 0.036914410593453795, 0.012144457268732367, 0.055985698563745245, 0.013997995210957015, 0.002728666654547851, 0.055873133314889856, 0.004480810757740983, 0.019819226254185196, 0.006640180336034973, 0.018422519169689622, 0.010206259757978842, 0.04507777528488077, 0.07337907969485968, 0.04450671491213143, 0.05747681425418705, 0.022018315576133318, 0.07276055897818878, 0.03487454348942265, 0.12725435517495498, 0.02504557305655908, 0.06047728020348586, 0.04702592035755515, 0.032139970498974435, 0.027134813390148338, 0.035178805483155884, 0.013553164881159319, 0.003966609101553331, 0.05298977826896589, 0.04500964241742622, 0.022518285622936673, 0.03334117362101097, 0.011204118127352558, 0.04855862971453462, 0.03525248961523175, 0.05443658032163512, 0.014911163398210192, 0.04060968632984441, 0.01738056609610794, 0.04797939458512701, 0.0555926237575477, 0.00823756368845352, 0.018903918826254085, 0.044979522353969514, 0.04225587377732154, 0.007270580981639796, 0.021438926451082807, 0.11575288444873877, 0.06472471752204001, 0.0260020214409451, 0.02599780789751094, 0.02389193974522641, 0.10835182416485623, 0.025874357197608333, 0.023844703900977038, 0.06371973824570887, 0.09165930503513664, 0.031932926140143536, 0.014216610579751432, 0.07126918353606015, 0.03440055974351708, 0.062333591922651976, 0.0809263059636578, 0.06848169912700541, 0.03295212867669761, 0.030958681054471526, 0.023081093313521706, 0.02529038531065453, 0.05278224780340679, 0.002539343158787233, 0.014084909980738303, 0.07944569908431731, 0.011234824487473816, 0.08614389356807806, 0.06646984809776768, 0.03675310108519625, 0.013670825901499484, 0.04260301335307304, 0.06612860859604552, 0.017155728746729437, 0.042649360475479625, 0.06771683430997655, 0.047779192827874795, 0.0711349661287386, 0.02123990656400565, 0.018343463743804023, 0.024813451527734287, 0.023541599657619372, 0.07298592696315609, 0.014909881338098785, 0.03988935779489111, 0.06321363805909641, 0.030892817303538322, 0.08591175719629973, 0.0390642380079953, 0.016170588933164254, 0.005224257192821824, 0.04397503660584334, 0.028788912131858524, 0.020745981310028583, 0.0024028557072597323, 0.05721437599277124, 0.09554484146065079, 0.035663587477756664, 0.0832799234194681, 0.018187258356192615, 0.009350627497042296, 0.04996967880288139, 0.04696753188909497, 0.04768017177411821, 0.004916150874123559, 0.05670793070748914, 0.03817501892626751, 0.04040978885313962, 0.009946161117113661, 0.04866269366175402, 0.07957343012094498, 0.012934202586620813, 0.018123212867067195, 0.03725468159245793, 0.04302710993215442, 0.09813423181185499, 0.07069341794704087, 0.0544826194527559, 0.10571069869911298, 0.05352740117814392, 0.10091698874020949, 0.034022921608993784, 0.035300896197441034, 0.03949475045374129, 0.026331208464398514, 0.01590746789588593, 0.036440612384467386, 0.02490892326022731, 0.0621549161587609, 0.034502300768508576, 0.07297922536963597, 0.04115025556529872, 0.04805671524081845, 0.08662469394039363, 0.06473094414104708, 0.0201825205294881, 0.08170588756911457, 0.04195308494672645, 0.014634774615842616, 0.004349486334831454, 0.02695712653803639, 0.01700043063465273, 0.042146206615143456, 0.029220918149803765, 0.029162839527998585, 0.01775250639184378, 0.05579794633376878, 0.0291753410056117, 0.02363916239119135, 0.05445667768071871, 0.08348415503860451, 0.005381971459428314, 0.0163259445616859, 0.04624829060048796, 0.03452721837675199, 0.023832224687794223, 0.01842273439251585, 0.038515898486366495, 0.030984877012087964, 0.07218599566840567, 0.006250675260162097, 0.05050219944678247, 0.0576967497181613, 0.049008063215296715, 0.03947655299270991, 0.09124445932684466, 0.02988234984513838, 0.03510309528792277, 0.020392587284732144, 0.058038401111843996, 0.008972091363830259, 0.03195745783159509, 0.023516628243669402, 0.10814567780471407, 0.02333558502868982, 0.04866480507189408, 0.04357995429018047, 0.029839303424523678, 0.04555074228846934, 0.02781709386908915, 0.01586604121257551, 0.027260644528723788, 0.03202936451998539, 0.02423310317681171, 0.05920492367295083, 0.022042730379325803, 0.045248881142470054, 0.03356929126312025, 0.01692395788268186, 0.12109863353543915, 0.07796302903443575, 0.03896594054822344, 0.10974954057019204, 0.057992807269329205, 0.07102703559212387, 0.03638898859207984, 0.013129308572388254, 0.012808683150069555, 0.044502313976408914, 0.035946431089541875, 0.04219427552015986, 0.018893567721534055, 0.030802401452092454, 0.06908821931574494, 0.04765903540828731, 0.060859356381115504, 0.023472544671676587, 0.09051765184267424, 0.010660010702849831, 0.06182195160363335, 0.1430891890777275, 0.15777385735418648, 0.1402984169544652, 0.09920907687046565, 0.1595601177541539, 0.29692135169170797, 0.10788480547489598, 0.1619667245540768, 0.14321198483230546, 0.1717139288666658, 0.07329388114158064, 0.14804016012931243, 0.18482488783774897, 0.11844610868138261, 0.10198798205237836, 0.15102714125532657, 0.15842774882912636, 0.2205272822175175, 0.13012066308874637, 0.17474143125582486, 0.09947724451194517, 0.229480373673141, 0.20068186742719263, 0.1322153303772211, 0.14298938505817205, 0.12820338393794373, 0.19854598125675693, 0.09036863601068035, 0.1517680866527371, 0.10730166293797083, 0.1762239306117408, 0.23205390432849526, 0.11213078076252714, 0.12113231961848214, 0.17469814920332283, 0.11584055435378104, 0.11690652332617901, 0.21180186682613567, 0.12687229755101725, 0.14871103194309399, 0.1361844697385095, 0.17394831287674606, 0.11602142316405661, 0.16573920962400734, 0.12577483925269917, 0.20685107388999313, 0.06296667357673869, 0.11023844519513659, 0.131626911170315, 0.24344270961591974, 0.16268608829705045, 0.18235377356177196, 0.1262834033695981, 0.22073134314268827, 0.2080206837854348, 0.1247211973532103, 0.1737064469489269, 0.1178341411286965, 0.1573046122211963, 0.0903731185826473, 0.12342598638497293, 0.23049478564644232, 0.2271474472945556, 0.1393284002551809, 0.1743182141217403, 0.1386194265796803, 0.13725432014325634, 0.19948844943428412, 0.15287391637684777, 0.15930000983644277, 0.11269905066001229, 0.18619278474943712, 0.12939487234689295, 0.1354309672024101, 0.2616045030299574, 0.1305902941385284, 0.13186905911425129, 0.09639825191698037, 0.1441348306252621, 0.13789102347800508, 0.14334885170683265, 0.16640715737594292, 0.13666742976056412, 0.18327630765270442, 0.24278905562823638, 0.14199419470969588, 0.2127954689785838, 0.2027029581950046, 0.16389650147175416, 0.17547388648381457, 0.22073825995903462, 0.2041452331468463, 0.1560694706859067, 0.1676908798981458, 0.1681603179895319, 0.1159996930800844, 0.1375957377604209, 0.15074776718392968, 0.25720137055031955, 0.17357388453092426, 0.16600317670963705, 0.15032138850074261, 0.17336701828753576, 0.14477425022050738, 0.20164814370218664, 0.2262128607253544, 0.15301957027986646, 0.23284898197744042, 0.21345678193029016, 0.09382460251799785, 0.16148689639521763, 0.12300296963076107, 0.20017832022858784, 0.16251347959041595, 0.08994270261609927, 0.17162068543257192, 0.16190989088499919, 0.12882233510026708, 0.09329217835329473, 0.16222554113483056, 0.14046421274542809, 0.12640075176022947, 0.14354209211887792, 0.08427727341768332, 0.16484035004395992, 0.26105887605808675, 0.09617171876016073, 0.13893890631152317, 0.17003582906909287, 0.11422676907386631, 0.149950195918791, 0.2157276647631079, 0.1010864062118344, 0.1167076722776983, 0.09604107850464061, 0.17189934704219922, 0.12483122816774994, 0.08345423164428212, 0.15996549365809187, 0.16445360204670578, 0.09104615746764466, 0.15477755485335365, 0.1584460205049254, 0.10200603850535117, 0.15627228480298072, 0.08332466750289313, 0.15263773530023172, 0.07924871824798174, 0.11328079795930535, 0.1298336745821871, 0.1479369422304444, 0.09406174838659354, 0.1782147862832062, 0.20266307517886162, 0.13519211439415812, 0.33835919690318406, 0.19670763693284243, 0.13038111239438877, 0.15151586034335196, 0.10863233372219838, 0.1898390898713842, 0.1338913373183459, 0.05588298161455896, 0.10779534699395299, 0.18146767892176285, 0.1386807279777713, 0.07316978662856854, 0.1320552491233684, 0.13193065737141296, 0.0858188996789977, 0.16403080051532015, 0.2574124076636508, 0.1294382434571162, 0.16085405222838745, 0.09654123408836313, 0.17574193538166583], [0.009681016799731879, 0.016489291265315842, 0.04233792933518998, 0.004893785790045513, 0.05621931923087686, 0.04485103432671167, 0.09173795042443089, 0.02824356717610499, 0.05721644658478908, 0.046927107105148025, 0.021431052264233585, 0.01828094151278492, 0.04290088916604873, 0.028081894015485886, 0.030540902007487603, 0.0166439362874371, 0.07913903624285012, 0.0196805466839578, 0.029966576184961013, 0.022814076000940986, 0.00349864533291111, 0.020168890987406485, 0.05422611837275326, 0.05632353531836998, 0.023147396786953323, 0.025675073848105967, 0.03275419046985917, 0.05012144429201726, 0.025486867052677553, 0.022413561164285056, 0.035277533388580196, 0.09908908643410541, 0.00556972183403559, 0.017093685200961772, 0.06051466589269694, 0.0255142782771145, 0.03178399565513246, 0.029675463192688767, 0.08735010618693195, 0.05544393075979315, 0.0528201789711602, 0.03214841242879629, 0.07718557739281096, 0.04212197549350094, 0.05459019375848584, 0.019559647116693668, 0.012318986282480182, 0.013726104771194514, 0.034587243280839175, 0.0564819727151189, 0.054071462218416855, 0.01375640202240902, 0.06567115618963726, 0.05519691061635967, 0.06904446228872985, 0.07310393586521968, 0.023047149334161077, 0.020473618678806815, 0.026139354013139382, 0.0375755788263632, 0.03147073512081988, 0.030709599595866166, 0.03623492244514637, 0.02636588345922064, 0.04992487534764223, 0.02392613976553548, 0.02676274878467666, 0.019482951720419805, 0.014630939567723544, 0.05456980325106997, 0.007937715618027141, 0.0017650777658673178, 0.02579922216682462, 0.07561902981251478, 0.07268775429110974, 0.026293640949006658, 0.021497173911484424, 0.01973495167476358, 0.09497935461695306, 0.04356747507699765, 0.04466364574909676, 0.09383303331560455, 0.03969835124735255, 0.04395211908558849, 0.011206841809325852, 0.018677342995943036, 0.05245188076514751, 0.011249042181589175, 0.026411519975226838, 0.03498097117699217, 0.06493123495602049, 0.05917655878874939, 0.03760819621675182, 0.05221031911787577, 0.02627497036883142, 0.025985159845731687, 0.02988907555845799, 0.043136346648680046, 0.05523466366867069, 0.05710122815798968, 0.024777475919108838, 0.05499352133483626, 0.03210727147234138, 0.0036601102283384535, 0.03349820835865103, 0.049966895749093965, 0.01993862297240412, 0.04947900786646642, 0.051658398733707145, 0.03846024483209476, 0.10455582043505274, 0.05483352913870476, 0.11615284267463721, 0.04152706249442417, 0.02148439598386176, 0.03227966124541126, 0.02334632576094009, 0.07416289154207334, 0.02118812692060601, 0.02920021965110209, 0.046241889576776884, 0.003992812480646535, 0.1057879562722519, 0.04568884854961652, 0.029770311521133408, 0.04514241263677832, 0.029433905256155413, 0.019552919548004866, 0.017930182111740578, 0.023084225176717155, 0.03412482219573576, 0.03999403401394375, 0.07054521847749129, 0.05168124203919433, 0.040334631557925604, 0.07102147690602578, 0.0348855977790663, 0.010615006867737975, 0.03745682777662296, 0.011486727962619625, 0.04020674095954746, 0.05109611425723415, 0.027684219749062322, 0.09375453635584563, 0.04332665186666418, 0.06358530561556108, 0.019816209423879627, 0.015420944637298817, 0.04202880256343633, 0.023947741829033475, 0.012431066352291964, 0.02131672627001535, 0.011411690338718472, 0.014092217352299485, 0.010579082281765295, 0.08720064506633207, 0.034723093413049355, 0.04310421907575801, 0.08825222379527986, 0.018550515524111688, 0.04889998053840827, 0.008884179333108477, 0.017775401647668332, 0.01650893405894749, 0.06648216774920002, 0.0667416003125254, 0.013616126834676834, 0.023566125782963354, 0.022772001793782692, 0.01882393942651106, 0.02503668027202366, 0.04277946638467256, 0.04080814032931812, 0.06106315013312269, 0.09014857438160107, 0.031554248998872936, 0.052772280760109425, 0.03182069856848102, 0.038045024339226075, 0.024167976007447578, 0.05989070523355622, 0.1256110324175097, 0.03078215380810434, 0.05291489556839224, 0.04683388222474605, 0.03172488730342593, 0.03058372578379931, 0.02646544813615037, 0.01657035234529758, 0.029495006274373736, 0.015296638612198876, 0.03979015120421536, 0.057386509724892676, 0.07911726905149408, 0.03195880854036659, 0.021402997226687148, 0.023627497685083654, 0.06345381931168959, 0.04059659855556674, 0.014295035180111881, 0.021963708350085653, 0.009281617967644706, 0.024241795581474435, 0.02016576469031861, 0.05529130809009075, 0.027645058471534867, 0.019806934433290735, 0.03736214457603637, 0.029734649469901342, 0.01780762384441914, 0.06867724019684829, 0.031205498962663114, 0.02709113799937768, 0.031891681283013895, 0.06909877265570685, 0.08204211015254259, 0.02319143954082392, 0.027848785430251155, 0.053156201174715534, 0.06293244572589174, 0.031296204251702875, 0.04591231292579323, 0.02048708680376876, 0.003719710484801908, 0.0615157674474176, 0.016855409412528388, 0.02820863614033442, 0.03023080302227754, 0.022294123627943918, 0.02989847485878272, 0.029798822979500983, 0.040052697077044286, 0.05903991826926358, 0.020638154674088582, 0.03126672985672485, 0.020659031288232654, 0.008430548987234943, 0.08751300018047914, 0.022511019997182302, 0.028177104140922893, 0.05222223429882433, 0.046953824421507306, 0.034065773215843365, 0.011753478102036752, 0.03359227928740438, 0.012465484378481051, 0.020773952855961397, 0.048111782598425634, 0.02816438558511436, 0.07207073271274567, 0.05843150560394861, 0.017882508400361985, 0.011434932548581855, 0.020083095005247742, 0.08141274665831588, 0.058488354115979746, 0.028189583354105707, 0.055018405546434224, 0.06767770828446373, 0.01157584320026217, 0.04572155128698796, 0.04772582498844713, 0.03182239437592216, 0.07207134127384052, 0.011753024464269402, 0.009850799779087538, 0.0443695252033649, 0.022432664045481943, 0.036158640796202235, 0.025279820838477463, 0.031138111953623593, 0.060902746045030653, 0.03617426300479565, 0.07851026646676473, 0.04808187033631839, 0.032737766741774976, 0.03105664083705051, 0.017700229509500787, 0.007536064367741346, 0.02505756801838288, 0.07175765771535225, 0.033241124692722224, 0.07916647344245575, 0.03173544435412623, 0.021918049569649156, 0.09262938110623509, 0.030165048738126643, 0.031031700964376796, 0.024030871645663865, 0.025258395035052672, 0.03786615561693907, 0.06120003556134179, 0.015776801665197127, 0.03730264288606122, 0.028438423614716157, 0.018967687865369953, 0.049234755933866836, 0.01747340505971806, 0.05991888087010011, 0.0572826610004995, 0.012607384869625093, 0.05175054007850122, 0.035668352065840736, 0.041544762716512196, 0.02046084075118415, 0.05172097291506361, 0.039305944374063984, 0.03971838923462201, 0.062171703539206646, 0.025996887634391896, 0.05583292375376914, 0.060294051363598555, 0.02913062289735535, 0.023561077323392965, 0.023171839420683682, 0.0447165534569649, 0.014897876171744429, 0.004366627163108205, 0.027996224198432174, 0.028946800339326728, 0.06283119451836683, 0.044487912600743584, 0.016618762638245244, 0.05447207724500913, 0.03893964625603985, 0.032555610305280425, 0.06842681730631739, 0.0703972193878144, 0.04032510238175746, 0.016273519249807578, 0.06641262109042145, 0.055173340006149374, 0.04293192578188609, 0.07319014373933896, 0.036752073210664093, 0.03389301236893516, 0.016255845002888236, 0.030328085595101584, 0.05476377467857674, 0.02807310698699439, 0.034548614494269714, 0.02661079775862163, 0.05632953187159728, 0.03490789560601115, 0.05364359181839973, 0.018446859758114442, 0.048051869016489945, 0.04046411035233177, 0.015153179610933876, 0.04199238166620489, 0.024915422618505545, 0.03564611361071002, 0.088083281298168, 0.1082560871145688, 0.12428425048710778, 0.14607041113777086, 0.12110684168874286, 0.23571379075292498, 0.12667439645156264, 0.0937718951900024, 0.20690673496574163, 0.23681164981098846, 0.13762131216935813, 0.054276120572467335, 0.15379128511995077, 0.09290678848628886, 0.15472337807295844, 0.14751975133549422, 0.11930850654607639, 0.15298372454708442, 0.08500720534357242, 0.09238177095539868, 0.05329119783709757, 0.16708478273358196, 0.08194963113055564, 0.16231477697147056, 0.07491039752494544, 0.09964448006940074, 0.07061434953357093, 0.11273120049736463, 0.11952379616559483, 0.10008949408074841, 0.08922028122469783, 0.1589055435033515, 0.07534130330896005, 0.12259118157089688, 0.1699549943441525, 0.2075700368732214, 0.09515453857602552, 0.13729386177146807, 0.15569302369840443, 0.10702730578486808, 0.10324463844881393, 0.10170401408686303, 0.17447773134335876, 0.10514751993468963, 0.2163251381716691, 0.1105060859117657, 0.0898384308675304, 0.13651500747073442, 0.17536931787617505, 0.11920237200683914, 0.16141144966240972, 0.10254224762320518, 0.13720983581151813, 0.14474714698735625, 0.10171934685786255, 0.2850797917926684, 0.10881543639698066, 0.09402683775988407, 0.07274033545400016, 0.16358411667170003, 0.08345421680132858, 0.16145885805599391, 0.11501126369694248, 0.1060721765679773, 0.13433140120469034, 0.10799273601151071, 0.11864556829095818, 0.09454677900066599, 0.10443652019603178, 0.11826120258774608, 0.06047351380402688, 0.13712708634557202, 0.10098586746607907, 0.12338933913270012, 0.1653108568280004, 0.12211057415697724, 0.08278722641989589, 0.06062372820451856, 0.23033273027976975, 0.1254066004185006, 0.1515182203729637, 0.15776743035530671, 0.14502313686534762, 0.18648023338755593, 0.2144771459279582, 0.18023013282800093, 0.11881446625920944, 0.21543677255976945, 0.12837633403250948, 0.12942959001520649, 0.1150961357052438, 0.22103283321484923, 0.11548044945811853, 0.10454694434884004, 0.12597006862051785, 0.10352385666919872, 0.18327952857362106, 0.1485441526165232, 0.12222997087519616, 0.10959535939036869, 0.11126118406536989, 0.1572825704351999, 0.11191733166924678, 0.21836215542862192, 0.12535276502603665, 0.2592960081528872, 0.10250438324874267, 0.12108557173633017, 0.14265972306020558, 0.20689165452495217, 0.16855315159773454, 0.15332900133216754, 0.20053977583302185, 0.21122116595506668, 0.12813941080821678, 0.16040687856730074, 0.10518995593884028, 0.14476846146862954, 0.11669910047203302, 0.11541754502104595, 0.17261489614611492, 0.09123640702455305, 0.20373728941194713, 0.14800633303821087, 0.09980693619581871, 0.16964795300737023, 0.1182037009857595, 0.11651616849121638, 0.11957392081967555, 0.1843202274176292, 0.12315372950979508, 0.1604278219747357, 0.16377146443119273, 0.21306360693415627, 0.10395428747870028, 0.2136648801388219, 0.14115541940554976, 0.08276606778963469, 0.13370002649025992, 0.09139553090790287, 0.16914621664909646, 0.10739920340711251, 0.11458463268354535, 0.20079649955732748, 0.17280504922382534, 0.14891642873408273, 0.10623198322718963, 0.07752311357762665, 0.15805170260136947, 0.09444453331525438, 0.10421296305139549, 0.2017135120695457, 0.08624835085356608, 0.11768567448598333, 0.08801406860584393, 0.11584989057155326, 0.26554355572443455, 0.23903243767563254, 0.20478499413002282, 0.09591100228135474, 0.14230174070689827, 0.1427979109575972, 0.12954766571056098, 0.10560556605923921, 0.17284508066950366, 0.10988206588081084, 0.16626836091745645, 0.10352755998610519, 0.11896931537194178, 0.13220510358223692, 0.17519567016279325, 0.1378771453164518, 0.07231027571833692, 0.11044762693927623, 0.13683303259313107, 0.13908202206948772], [0.04113501556275878, 0.06781066404073499, 0.048507581086596474, 0.02072563347610412, 0.025699592551973183, 0.012521886674221605, 0.04683796032622922, 0.036742666488862596, 0.03211614384781569, 0.07081698553520255, 0.047162163828033954, 0.009731839072628645, 0.05316652444889769, 0.028158105160400737, 0.020496408178587444, 0.026615484421199653, 0.015506564359384356, 0.024034806883719284, 0.009359982268506428, 0.027983110448985826, 0.03384567076864187, 0.003912851634595427, 0.03433531383052468, 0.016967623996606562, 0.021307803799572866, 0.04173450761300046, 0.061843644580221735, 0.04487747333769221, 0.03447559829510283, 0.057123989827232435, 0.015615840966347605, 0.06106464184995275, 0.13114488625433296, 0.048889575627981685, 0.014074660921323812, 0.029562886811618228, 0.048129490241990425, 0.034211905804113485, 0.02003229128604289, 0.09732514241477475, 0.0732307466387283, 0.051920343466917984, 0.02086631127895089, 0.03389190656889696, 0.016034388136176858, 0.015176154647633666, 0.005567609032368637, 0.04822648152185138, 0.0613558865734376, 0.032789234683150426, 0.02314381406904431, 0.04857852298300713, 0.07069683924783021, 0.02997893108840799, 0.01651769140153192, 0.02388035110925557, 0.04068905531312339, 0.03578668009140529, 0.020619209499272984, 0.07883276673965156, 0.028604759318113793, 0.09452446262002923, 0.012432356761564733, 0.04286707320716232, 0.13739026675466448, 0.030892943468643352, 0.025742776269908063, 0.04682199301896617, 0.10835059962118976, 0.024371463623538148, 0.020433806166693103, 0.049087510124081746, 0.012540532206912758, 0.05338252281944733, 0.021012130309827626, 0.057949473266489804, 0.06461410783231258, 0.09371458654641174, 0.03063512507651467, 0.005529995596589288, 0.0630192324751988, 0.011476644031063188, 0.06819608359364793, 0.05004750411899295, 0.039601905446033925, 0.04114127928914968, 0.04228052421240136, 0.0214806685471558, 0.0447004859597655, 0.021191336709307507, 0.06423323022318073, 0.04331312251451891, 0.04568626587570179, 0.02478349288139725, 0.062193964258767664, 0.05220496081165038, 0.028915606017108075, 0.03500083475955762, 0.03104335453826934, 0.02281048957229359, 0.016501022764714435, 0.07396885703201406, 0.013079254422336817, 0.016848941595526412, 0.015258496860042214, 0.06184138102980796, 0.02475830253388267, 0.04665264976210892, 0.029247470338304993, 0.016362729111278895, 0.04076803466887213, 0.009405752371094422, 0.016273456167255063, 0.017385766695952043, 0.012785929829988163, 0.043245089837000705, 0.03454119301750325, 0.022230428803595714, 0.0021830229843544657, 0.071417724393541, 0.026558392855804414, 0.02887254289817065, 0.054118306579766795, 0.08117844321532175, 0.03662499897473026, 0.059098644414916635, 0.03810870060988236, 0.03241466904000845, 0.04791967396158725, 0.023372291652776767, 0.03473910895991139, 0.03845892751996871, 0.06357392107020132, 0.04664651962229982, 0.03160962063702755, 0.010288572284480324, 0.0458112658088794, 0.028212762481416576, 0.05455038495711051, 0.03988265620137099, 0.03897795962984674, 0.02592373228253564, 0.021456160975503735, 0.02966073156130733, 0.051921401027357206, 0.0737951796327252, 0.028740345987898763, 0.020457369355426636, 0.021587491428363137, 0.033376139908796176, 0.014097000494075473, 0.034155079556512646, 0.035241465011495166, 0.07197190090664662, 0.02125389604771044, 0.05509023059858009, 0.02213275289250305, 0.03793956515437458, 0.05195483106945176, 0.04286044211767148, 0.03563209073035978, 0.009650552565290127, 0.029954048732179217, 0.040446072453050874, 0.061166609229985625, 0.030159471498336643, 0.030489714226860087, 0.029687708629353438, 0.05497664118593093, 0.07131034304620698, 0.023775949484843295, 0.022181523127073888, 0.020280825410736725, 0.02626969184348127, 0.05504796528839506, 0.03030801050044829, 0.02996825900481781, 0.028599033648788463, 0.06097183999372646, 0.03213355834304821, 0.015315906621253816, 0.04329437586420681, 0.03710786251758691, 0.03357523586601019, 0.05245268599537667, 0.03739742256584577, 0.04272976475476753, 0.04310888718464412, 0.09582807469996624, 0.017815440514823422, 0.025939046499843244, 0.01962578546226723, 0.022917739188415, 0.08126566041028127, 0.02170058731280733, 0.012210284839966334, 0.024823500207276084, 0.043845064283232205, 0.02222541930677835, 0.03253126786148641, 0.010571684924798319, 0.04072286385053303, 0.12138476115069352, 0.03067362584260991, 0.04823831135581713, 0.059029249896411784, 0.05432479803857859, 0.03277505224104971, 0.07414575535221957, 0.026487243158044294, 0.026548743080638815, 0.028598612479981966, 0.046691968746017665, 0.012519164847617503, 0.04413360758917406, 0.048702417116146535, 0.08575384301366284, 0.029880340480303857, 0.009943746354110772, 0.03807446533755865, 0.04243732888426166, 0.007316413239095709, 0.013257606424303958, 0.06836981294327416, 0.03456611433648504, 0.037386650292319246, 0.04241037408064585, 0.03633313826867379, 0.06486440455773845, 0.04706225219706539, 0.022147061499708798, 0.047956365742720664, 0.026489176452741958, 0.04284445625671651, 0.0257565338324639, 0.07668603779166006, 0.020690566998382565, 0.050919119457830675, 0.06297026557149366, 0.038341178369591944, 0.026743306370917708, 0.044098459475208074, 0.052412758450373076, 0.06537634544656612, 0.012150860147812637, 0.018547391082393005, 0.019283286164863966, 0.03859072181512602, 0.0533906085183844, 0.01511771237346693, 0.01976008636120241, 0.012994477037864272, 0.0036936457945557777, 0.06606147391721606, 0.08549193909857422, 0.01883063916466199, 0.031382297092932276, 0.009811416784941684, 0.02200584192905808, 0.06637527621933259, 0.02965607087389799, 0.013523203451768495, 0.021925808723608498, 0.05411380174336955, 0.05732616198656615, 0.08310465040267445, 0.0127285998496518, 0.054197556819417514, 0.04200094976113178, 0.08105620407150127, 0.05118518682138529, 0.07045383783406578, 0.040159685086109675, 0.0458582511782879, 0.015511717647314072, 0.0787359758396633, 0.1100583333754912, 0.03938430032576434, 0.022647100195172243, 0.029279239824973047, 0.020858388852502685, 0.026985188997059595, 0.028980864917684812, 0.054746397290728055, 0.031082103923836257, 0.024048621962720063, 0.03814929608779494, 0.059220620096311904, 0.03391913225641474, 0.05586041290371213, 0.05579016862611752, 0.020871101842203643, 0.020297761220717803, 0.011188929147465387, 0.039228965106303804, 0.07239211234264076, 0.054226177744567394, 0.014854363125778036, 0.03441371431108564, 0.05779679864645004, 0.04056736535858363, 0.08727360560442321, 0.04865226277615875, 0.016924306692089885, 0.03115761930530425, 0.05244272637355607, 0.0674185057869181, 0.019129145803162828, 0.022968368502915837, 0.024310091721417848, 0.04178027214948088, 0.023038302933855448, 0.07172319979872555, 0.012317659693508176, 0.010709049965953454, 0.008914442259992938, 0.052553105997503735, 0.014358623320731567, 0.018797322300088126, 0.011869706777360989, 0.08589571196353063, 0.024426278650935274, 0.06996509648161009, 0.040104498984874226, 0.043683955154847354, 0.11814947967650369, 0.006931214011274278, 0.02222575512860203, 0.022364004253176972, 0.04478798888158053, 0.04550223922706209, 0.014013261188665638, 0.0786369139677845, 0.03495696641039103, 0.027318433712935075, 0.028921320554218255, 0.034163399031967856, 0.020951272344973404, 0.043245156630291604, 0.022148260068206582, 0.0346402882860275, 0.03487406109343283, 0.021490130930033047, 0.026301682119083125, 0.06290785837336443, 0.052251693850848824, 0.07702702496317215, 0.020424330796231516, 0.041441032735747285, 0.05467280963785015, 0.08663232321850955, 0.014581286177417496, 0.1838657955522649, 0.21182709984714165, 0.12686962581938133, 0.07900127879111096, 0.05329161343979649, 0.24056635302258655, 0.07429861550917849, 0.08391635215957649, 0.08232930646045133, 0.2233659228659235, 0.1519757098867558, 0.1156252647342626, 0.1226921433408279, 0.12032926388201304, 0.08426755870459601, 0.05978062989015598, 0.10279514928697608, 0.1631851529236883, 0.06677874480374157, 0.15597440156852826, 0.15351744747022167, 0.11597102391533554, 0.11097998431068845, 0.1047097789705731, 0.05257981218164787, 0.07904150319518521, 0.23873508878750727, 0.11955420937738381, 0.10318764892872423, 0.15830879739951342, 0.1714423473458737, 0.14528950850944966, 0.29154668853152543, 0.18154211633373052, 0.11526722300914116, 0.13215950602898374, 0.16812463552923873, 0.1460933286580257, 0.1039611449232325, 0.16050261561758816, 0.13649645377881825, 0.1980737823760137, 0.10348974756198004, 0.11080618074629456, 0.21660826751030982, 0.10184416867559776, 0.16771691443864256, 0.23989087989320979, 0.12132933756220154, 0.08621035289252177, 0.058562854610499926, 0.24258919525891542, 0.18704469606745988, 0.2134085274883546, 0.13206442206865177, 0.10067317838547751, 0.1383559641544707, 0.13633827242301777, 0.11942691620788537, 0.21965089486911893, 0.15729500883026049, 0.13540001964429393, 0.1813047329778783, 0.10925172275165096, 0.18482695100829005, 0.09377958383993246, 0.16978994070086628, 0.19421921577304602, 0.20873295259661973, 0.12800359778339043, 0.08122810773784295, 0.19310612784465775, 0.09072624729014933, 0.11802334425738081, 0.19636387412901968, 0.1387793742469512, 0.12481000274419785, 0.1999923528637737, 0.11109610815765336, 0.10928377610980533, 0.1539138433872722, 0.11809752191766165, 0.11948409126489423, 0.1548826281214133, 0.12093988072592765, 0.1473035488743335, 0.12076444443664514, 0.21919747232459486, 0.09756045517860912, 0.15406102611450478, 0.13281557941809297, 0.12196252311696298, 0.14968345320085064, 0.23366049077594653, 0.07860065263230354, 0.17542805144330487, 0.10372744261985645, 0.14209561661118641, 0.16009125800337642, 0.2266232980764471, 0.17839120962889865, 0.1211585322744213, 0.12164665764430538, 0.20757042279001325, 0.13198189524700865, 0.09567959321429953, 0.1954534073593095, 0.21150147513253614, 0.12736511329421774, 0.10674609860870987, 0.13492459984263405, 0.18631379934959114, 0.07115766842616722, 0.14653049816843122, 0.20065090502612293, 0.10614809085382149, 0.1962462140363641, 0.1019406552950386, 0.13341334968572482, 0.13283481588587165, 0.1473135084961541, 0.06239677837584168, 0.1699636923149228, 0.13542189815780148, 0.17663709906628355, 0.17038456426234916, 0.17148188897408545, 0.11486137955216691, 0.13133303553331643, 0.15623317362042144, 0.15888811787590384, 0.13753271457972005, 0.25388477195519954, 0.07812933690729551, 0.07361039228271693, 0.08923042638343759, 0.14729531103512272, 0.18199944257503375, 0.15303056890843436, 0.13552809949032962, 0.09369432591483928, 0.11242466382100247, 0.13546402245992795, 0.09880125187919475, 0.2949751733103767, 0.10029002238297835, 0.15877784957410768, 0.11029065528418869, 0.10856282417080365, 0.23209899722132832, 0.057183101889677346, 0.1372186525259167, 0.15750049467897043, 0.138233509787824, 0.13007663888856769, 0.17303649539826438, 0.13576567580457777, 0.12277317844564095, 0.1571196096483618, 0.1378665622905828, 0.1431767625035718, 0.09251321273040958, 0.08742455102037638, 0.07384277356322855, 0.12323061600909568, 0.08106647539534606, 0.09468634729273617, 0.13102859171340242, 0.21271531702950597, 0.16223922633798793, 0.15573165990645066, 0.12600532063515857, 0.09172003497951664, 0.16645449155475944, 0.1333016564603895, 0.06982572114793584], [0.016371924320992548, 0.010681132225727197, 0.014278854505391791, 0.033938335327547975, 0.0352525452763075, 0.01848614905611612, 0.06036577993654646, 0.018973968290083576, 0.043619462521746755, 0.02246591968287248, 0.059668417161446996, 0.05358192305720877, 0.05724851478589699, 0.06537607085192576, 0.059734286478487775, 0.043764860383816995, 0.01164399183835485, 0.041861722856992856, 0.05399938112532254, 0.019393576731090434, 0.03711576267960481, 0.05630171246593818, 0.03769253387872595, 0.054782213337603025, 0.03492952178930864, 0.04901014865026809, 0.04214916036289651, 0.033878202812047675, 0.007106488419594825, 0.08761727935052477, 0.01874167977803154, 0.028040591641911305, 0.03237456709030084, 0.037127458926988766, 0.007251141350934631, 0.08798216367722489, 0.02476019686582731, 0.08168749714968726, 0.04106444102944806, 0.060894645503140055, 0.08988065164885484, 0.04012894532934297, 0.03836123119981494, 0.06152722991828341, 0.022882607772771735, 0.037179832288529724, 0.01849699554441031, 0.01573216519318521, 0.027119261685584206, 0.03662898801849224, 0.05073785730928648, 0.011417678542784415, 0.019570593794924207, 0.03268980544817168, 0.010794509198603919, 0.03851104112982284, 0.027872550854226574, 0.053979061121935956, 0.11725175558240153, 0.020908263031742536, 0.05186818532820325, 0.0089844982176146, 0.06028746109222993, 0.011177950000273995, 0.08369557806872763, 0.047545661218464375, 0.0498056122160051, 0.09640419651987031, 0.036104441751376726, 0.03332039348606486, 0.018978684638568666, 0.01743775042996276, 0.012174950261396589, 0.024471336291753687, 0.012839142746088328, 0.07467743736924604, 0.050418559403624386, 0.030890780108165927, 0.026161807691096328, 0.05016776172851678, 0.02571305140008917, 0.03436305902141612, 0.029197343828855082, 0.04715579249022994, 0.0614817956375191, 0.0761623635480646, 0.03752656739379745, 0.09583859835402109, 0.025737829855643213, 0.028571685506904032, 0.04885439782810863, 0.0616814259410603, 0.02258178934425814, 0.06188944993482437, 0.05738279898650944, 0.02886651665903628, 0.02293273984832922, 0.015064945673657348, 0.009412201634404482, 0.04394267525640316, 0.06208526931004599, 0.04375215110485442, 0.027754319307859987, 0.023396034812321886, 0.01999780368350912, 0.0042360532370366855, 0.019018667844648007, 0.008549020803911844, 0.02033406708505936, 0.10183328136918135, 0.06138521996035706, 0.040034507037489675, 0.05067336838692427, 0.019135411384922918, 0.02003215213335352, 0.01666413383645704, 0.030879106125212274, 0.062335714465007186, 0.04030730568047147, 0.014070454799366416, 0.0374243291298626, 0.012469016073737293, 0.0498795338353375, 0.09209167285007425, 0.053382240803330205, 0.05272565162158571, 0.04414702932990622, 0.042947674155584536, 0.06997920470894314, 0.04784162971191108, 0.08057132930844091, 0.04063848908117507, 0.035658091874211095, 0.03162136512401048, 0.05520242477359716, 0.04944211941619869, 0.014082562011026312, 0.020195845791022293, 0.08343318433617242, 0.007767958613840165, 0.03231489099562168, 0.022392641876649577, 0.01338469179245294, 0.04202516603982076, 0.016056407657742966, 0.04209552163956687, 0.04762855540320743, 0.022697438216709998, 0.04703480015450623, 0.025285622577939648, 0.0219499099694076, 0.041337336151627824, 0.049955774666159414, 0.003296723880339414, 0.031762844446348026, 0.016404189191234764, 0.06128021348558832, 0.06647849411820062, 0.03941295464755967, 0.015724187105661258, 0.012168083540018415, 0.06396348180714995, 0.04263867354893591, 0.05648611760989297, 0.04034305122331716, 0.10941845364868641, 0.032802945861476474, 0.06661738705588505, 0.018176530611526687, 0.02645815839059651, 0.036734035311383195, 0.03470920040854253, 0.05158441774256062, 0.03082656578044407, 0.005489731302077416, 0.08699391983100213, 0.04813695253687911, 0.006502246624222607, 0.03878594005072955, 0.04164842590398621, 0.04231279279338196, 0.0508865354640875, 0.021571839533862658, 0.02292064284119988, 0.01770972528902348, 0.034715838919510134, 0.06224378834303934, 0.05358063914172817, 0.04166477170656435, 0.02002212015213445, 0.025665364701126236, 0.02477549438481219, 0.06665678025456145, 0.05905884303501807, 0.01550466909975512, 0.012311429363762727, 0.025347048285766505, 0.05019088705012109, 0.03323197030113079, 0.030242087377700955, 0.017496283617219888, 0.01589918367244536, 0.01669034278165782, 0.03499199578072876, 0.04524872900219634, 0.013131800333212595, 0.06127276603365317, 0.10178597687627189, 0.02268682550493395, 0.030732823252037633, 0.03583017736673355, 0.08851322971167974, 0.04950557304255199, 0.017712679036776535, 0.04085078042407986, 0.0428078090044437, 0.03910822139005177, 0.037618575152009726, 0.041860631899908185, 0.12232119566760957, 0.024267099106509704, 0.050863254291471094, 0.029585986158053856, 0.02511193775717402, 0.040576449246145785, 0.03826141604804434, 0.023721898869553115, 0.07117155400919728, 0.01651757822401123, 0.04172251450654585, 0.012961513621121412, 0.034778899207594804, 0.0056308103285118705, 0.026056597125716507, 0.08485735088470392, 0.025596947962185368, 0.032791127159725875, 0.028289199981372803, 0.03469631672487594, 0.03707574236614164, 0.0734194451069925, 0.024702431801415514, 0.033128652212326415, 0.01867344486527145, 0.05229892412899062, 0.04832380676816683, 0.032126496807904914, 0.04704163904534653, 0.051157745911041275, 0.04624357425200287, 0.03423009213292971, 0.06462075747549534, 0.02840661702066427, 0.01127030749557889, 0.035818165706587024, 0.05947485762590077, 0.022396437962015625, 0.06989906018134207, 0.07813732241629623, 0.017412554516340606, 0.06013287915266119, 0.07170865370426327, 0.009917341667460278, 0.0390759453875944, 0.019133455825794954, 0.06229507445823401, 0.0408063740178477, 0.0691624563478399, 0.023221027113322634, 0.030216807972465176, 0.0426417311973637, 0.01115691475206404, 0.03143529756926, 0.09438661611056887, 0.008738828782952623, 0.020863021709374152, 0.11156671884236857, 0.04672697585192509, 0.06367895723087713, 0.037358589688665234, 0.02238222583400784, 0.042154893453698605, 0.0038878702480360516, 0.030764002731302753, 0.045770121141686104, 0.04412541427882388, 0.056277915500686504, 0.006908563200340723, 0.01876488488051109, 0.056578774747322313, 0.026305053324904293, 0.019737910988624208, 0.039776658959453925, 0.05669734768162016, 0.04151869477936998, 0.0307591676391894, 0.04744351943372749, 0.018367795055382885, 0.06614737751078792, 0.042850267273024656, 0.0467402083449997, 0.033614328494877554, 0.052100882021477446, 0.015705844925832935, 0.11596677140914835, 0.027241638126724865, 0.03186117530276533, 0.05580361634201836, 0.053034856318845414, 0.06932063770364039, 0.08656112899188884, 0.02919572223618161, 0.03440608503296971, 0.03740018706594128, 0.028827576170442626, 0.01663359817030141, 0.012994362004974391, 0.019065219057665672, 0.04270269120752346, 0.052562609198503196, 0.05197236059757415, 0.018731831478362437, 0.03623700416937936, 0.020751139236381277, 0.011935925831494387, 0.1523048969102092, 0.019698213509400375, 0.0680782379640732, 0.03563661783118732, 0.015526563383900793, 0.04530996360699646, 0.05091620652819984, 0.04385847118101083, 0.06491329724667594, 0.023386839602608234, 0.005446240520541323, 0.014218706219253363, 0.09875432588160038, 0.029825655328750145, 0.03758416176424362, 0.0222993947318173, 0.11082163968239911, 0.060931964399060234, 0.1034465990960598, 0.028303673716436606, 0.0281417575024534, 0.03730672469828278, 0.0486411862220848, 0.016533753332623746, 0.018015211826423183, 0.021273607490002178, 0.05368465484934859, 0.1674213763908483, 0.04383563900773879, 0.09025883526192047, 0.1447523123351857, 0.11960451214690693, 0.10875812775339, 0.10642308625392616, 0.08746982202865183, 0.10051746838144027, 0.12114774886867963, 0.1764083097805269, 0.11136859509861097, 0.17497076973086223, 0.20064036652911454, 0.17858026432804763, 0.10022692498750985, 0.10825265097082593, 0.12734041461953893, 0.13554779608966783, 0.12708940543234348, 0.0786267762305215, 0.10652153214323334, 0.1610637831618078, 0.0971595618466381, 0.13202596397604793, 0.13689241925021634, 0.18856672220863402, 0.13353969290619716, 0.10514497436815873, 0.1561595080420375, 0.1313031863537617, 0.13803183857817203, 0.12363100468064658, 0.09906864768709056, 0.10341336572309956, 0.1389981000102125, 0.09823126762057655, 0.13793342979624867, 0.09455233768676408, 0.14840189774986356, 0.27951605909038335, 0.12247593345819041, 0.16659710265230387, 0.11631040804786608, 0.07901537217549048, 0.11687692647683434, 0.09556538410834037, 0.15873131691478193, 0.1467970627709292, 0.16431444935733452, 0.10148797489819117, 0.12292845800402574, 0.11357808747561648, 0.10556005014223047, 0.05768386603449471, 0.10396330457297154, 0.22845647705253214, 0.10732553040725179, 0.21496490022400394, 0.12400064617395401, 0.11639412230579183, 0.10265533608617261, 0.11962086166022345, 0.1075109931116458, 0.19757799804210663, 0.21580474422080442, 0.23762143682688475, 0.16397545114159584, 0.10033621365437284, 0.17852461809525266, 0.16019975999370217, 0.09193899080855772, 0.11423009389545768, 0.09596509742550552, 0.12853987369453534, 0.1512284710770473, 0.12127559122745879, 0.09270518406992778, 0.1556281154626049, 0.17322731640888378, 0.07607976993313059, 0.14081189408898354, 0.17418235656805336, 0.11048926142393611, 0.17323163570836186, 0.16863560420461, 0.08799011207884178, 0.2205213301931508, 0.07715043670032173, 0.19655355223221704, 0.19166416459484026, 0.14925517461961135, 0.11168098732014187, 0.17923279025126249, 0.13810292148264125, 0.1136865523585584, 0.146239249734208, 0.17195356835145503, 0.0712032882438507, 0.13629217020934448, 0.20792917697690427, 0.10405141234514304, 0.18984389898832887, 0.17440851865103468, 0.13507527066394687, 0.13504016707884148, 0.22091812686994672, 0.14377012441400439, 0.13953813118860126, 0.2191535520250909, 0.12586834985995665, 0.07353726847213693, 0.16490939946379513, 0.14133239194052294, 0.16756373515818268, 0.1080352313874755, 0.142349386587739, 0.10882445349125192, 0.1297955133486539, 0.13030283065745607, 0.13622580736409873, 0.09228382972651161, 0.1602190113044344, 0.24454229045659304, 0.19390329835005105, 0.1288616392412223, 0.13564154418418184, 0.10359204519772902, 0.17496726679382846, 0.0942603025760036, 0.270983527880162, 0.1114925263391342, 0.1731997827300802, 0.1344332387088798, 0.14702815271448344, 0.1285493138129823, 0.1576039203791879, 0.13708229031180963, 0.13705616671359167, 0.15306530141970143, 0.11919944052351639, 0.10837145397090353, 0.10963165783323348, 0.11221654334804043, 0.17476777749834582, 0.17069078923668712, 0.13137588714016601, 0.12741235841531307, 0.09324836937594227, 0.1905232312856242, 0.11691433071973734, 0.1462055859155953, 0.14670935575850308, 0.10871619640965946, 0.11449504803749733, 0.1394178142072633, 0.17697651288472116, 0.17669083055807278, 0.0985475858033169, 0.1878525980282575, 0.15526109375059605, 0.18016142479609698, 0.1094026310602203, 0.19833271770039573, 0.145123579131905, 0.21794083819258958, 0.15650419110897928, 0.22253496979828924, 0.143432833137922, 0.13394138775765896, 0.1783799586701207, 0.08601614026702009, 0.19424667523708194, 0.06072227799450047, 0.08500454103341326, 0.1611734280595556], [0.09224039182299748, 0.0024442489939247025, 0.04201840878522489, 0.052164387598168105, 0.019751095242099836, 0.03079532878473401, 0.04243513954861555, 0.028689564533124212, 0.02296490823937347, 0.05897218616155442, 0.047178324093692936, 0.09287143257097341, 0.041121764515992254, 0.019759963906835765, 0.05108480021590367, 0.02162345961551182, 0.047819691826589406, 0.018447221555106808, 0.014773121147300117, 0.05681655886291992, 0.0325768839684315, 0.0755699367437046, 0.026681578237912618, 0.012975581958016846, 0.01810586702049477, 0.04234457897837274, 0.1029258786002174, 0.03135803999612108, 0.0344964749092469, 0.021324375957192387, 0.0370195580762811, 0.009965339140762808, 0.05618913237412926, 0.022461823027697392, 0.024184392314055003, 0.009833315707510337, 0.01175655059341807, 0.028324338818492834, 0.04253514023730531, 0.025816363922785968, 0.02686821168026654, 0.03279052230936941, 0.046794058580417186, 0.020015457521367352, 0.03648555684776511, 0.048444569038110785, 0.02524812185583869, 0.010191393612331012, 0.0033571129006304545, 0.04920370818581432, 0.011027464715880342, 0.03769581046071835, 0.05834075949678663, 0.11197081083082594, 0.007509078950533876, 0.03017661325429799, 0.05288154716254212, 0.09523414875729941, 0.05217604302742984, 0.04104773899598513, 0.009097749953070888, 0.026451189623912796, 0.04650745227991138, 0.009681946339696879, 0.09933271125191823, 0.030630325236415956, 0.011131924784422154, 0.05091500424896367, 0.04561910522170365, 0.019587596398196183, 0.11232441451284103, 0.04680770667619072, 0.04313911485951394, 0.05302588004269637, 0.0217174581848667, 0.07196991937234998, 0.040549846962676384, 0.0686333495832514, 0.02685529088921612, 0.037817711927345954, 0.07984882628079504, 0.09131437705946155, 0.01964795712410705, 0.05348383339878637, 0.06205259254784323, 0.034565015957923606, 0.06967395936953835, 0.026696456443460193, 0.07000132813118398, 0.06369893584633246, 0.0383117522142129, 0.01034490129313781, 0.03800740116275847, 0.05036057540564798, 0.13682767428690568, 0.04949912748998031, 0.04491885920288041, 0.022046116428100504, 0.04916584752209019, 0.025835785927483812, 0.03065337263251422, 0.0060714155188179575, 0.05101313843624666, 0.011735782518371707, 0.04107063425180968, 0.016925490417634137, 0.015864076376601588, 0.039045617522788234, 0.07907175313448533, 0.06922018059412949, 0.025765996215341147, 0.06423830651328899, 0.06159244985610712, 0.011333037527947454, 0.033430305556976236, 0.04713109752628952, 0.04566909628920257, 0.04367448535049334, 0.04694811359513551, 0.07175044403993525, 0.01868869600002654, 0.07016357645625249, 0.019990074215456843, 0.11418687863624655, 0.01839900236518588, 0.09379660870763473, 0.005728659252781654, 0.025040051477844827, 0.036806446660193615, 0.025742950674612075, 0.023996217059902847, 0.03272789988841396, 0.04936957819154486, 0.02912442225351697, 0.06028989904734772, 0.035731089519686066, 0.021651661227224395, 0.029863222844142, 0.019741707073990256, 0.05849152679729741, 0.09306255786214024, 0.06357075209962204, 0.049755858635762706, 0.02338449441595003, 0.04386567743495107, 0.0011789485483859607, 0.120879648020491, 0.037271075634635054, 0.008004090523172636, 0.04991778783733025, 0.0427383365604328, 0.055236400294234045, 0.03126045128738042, 0.032547955051995814, 0.07705068463110365, 0.032336561707779765, 0.04644429180189036, 0.08308003336424008, 0.009010958565340843, 0.00806062547781039, 0.035845283782691695, 0.046850242870277725, 0.040562782596680336, 0.07109447455150075, 0.06573847640538588, 0.027601514811976813, 0.0215494545045658, 0.020733077217300888, 0.03593468660255894, 0.010745303879957646, 0.03316695445391815, 0.018301571362826508, 0.07726109091890976, 0.031097787359612994, 0.021647416142513976, 0.01866702899860684, 0.021327528229448944, 0.042258816392859444, 0.05518559286429081, 0.02285793136252323, 0.0532238442247035, 0.020530851252260618, 0.0283461022991105, 0.025052124365174677, 0.031106535425351467, 0.012353030451777158, 0.022134470964374486, 0.0310659158276394, 0.03317924441944342, 0.019666525658976752, 0.006072738860893878, 0.04267248579708394, 0.04717652809631545, 0.029359948384808376, 0.03575632996216882, 0.025442644327995367, 0.05855147377587855, 0.04570391414745245, 0.019321311956446152, 0.048891731566982344, 0.07697767956415191, 0.0014677146145913866, 0.12208568994537927, 0.01199270012875786, 0.012011994112981483, 0.049068655862356536, 0.026500856001803186, 0.048090438431245275, 0.019927704124711454, 0.024382434421568178, 0.034578890408738516, 0.035666697076521814, 0.06765530284610577, 0.011172696522407932, 0.07150993624236435, 0.047828033566474915, 0.039425649083568715, 0.03296241855423432, 0.026731200086942408, 0.06249491256312467, 0.03844849663437344, 0.058148109092144296, 0.034972840949194506, 0.06760312244296074, 0.04751868415041827, 0.049927717773243785, 0.04153394591412507, 0.052555436341208406, 0.06754476737114601, 0.04663568797695916, 0.08139034121995792, 0.029421012295642868, 0.05989442339341622, 0.022916290145076346, 0.061740742094116285, 0.05873915921256412, 0.009477451258135261, 0.04793529617018066, 0.05474901707202662, 0.014095842743699905, 0.03319242125144228, 0.09334941278211772, 0.04423819846124388, 0.011255213139520492, 0.0704852381022647, 0.008218697366828565, 0.07117168017430231, 0.02876236550946487, 0.02914031720138155, 0.059860314286197536, 0.016153723627212457, 0.020687976902991068, 0.02179997016355628, 0.07308145621209405, 0.061245013421284966, 0.019198800073354505, 0.034344152809353545, 0.11965715268161148, 0.07136952932341956, 0.02318472310435027, 0.06623825349379331, 0.045289116678759456, 0.09522674954496324, 0.06662970670731738, 0.00810528792499099, 0.043134658262715675, 0.04458440664166119, 0.04094499607163016, 0.025748795087565668, 0.05480786567204632, 0.17383517988491803, 0.0447892579541076, 0.07311452631256543, 0.021456776958075352, 0.03365058611962013, 0.04194840199488681, 0.05091149760119151, 0.05200237676035613, 0.05470295938721392, 0.03931689105229452, 0.022523291409015656, 0.0254485907862545, 0.021343695916584693, 0.04774354747496545, 0.06344543304294348, 0.06260512149310671, 0.007305321842068224, 0.01717799317702884, 0.036101710647926666, 0.02108327258611098, 0.012408319526002742, 0.020312292472226545, 0.015777154185343534, 0.040229881124105304, 0.027954463548667263, 0.09664340555900708, 0.07942793949041516, 0.05094806692795828, 0.027167525404365733, 0.08269332989584655, 0.013809727188345278, 0.05419321525550913, 0.008716986449144315, 0.0112747538878466, 0.030566014429496136, 0.010291479648003587, 0.04783752192452084, 0.0189743393639219, 0.09409622114617378, 0.024746853050601203, 0.0800387047638651, 0.05784814784419723, 0.05195979232667014, 0.042887103772955015, 0.05084908669232391, 0.028674445129581727, 0.049454413092462346, 0.08194111127522774, 0.0509330347267678, 0.06382235500495881, 0.012730245562124765, 0.0412309084640583, 0.06577130159712397, 0.025513513865007553, 0.008924393532652175, 0.07454566904925741, 0.02700445144000696, 0.06320893284282647, 0.03336422101710923, 0.05163616398931481, 0.06765971862478182, 0.06123595179815311, 0.019643621126306243, 0.07094175540260039, 0.010415614051453304, 0.05304002537741326, 0.03349669808812905, 0.034535638042143546, 0.01976593634026358, 0.05813765223138034, 0.047316022173617966, 0.031478828241233714, 0.02199650385591667, 0.06244158183108084, 0.027202836790820584, 0.038294634578051046, 0.02951996841147775, 0.06266655647777952, 0.06126363390649203, 0.05544935957004782, 0.009116305500356248, 0.04469399216759484, 0.30074085923843086, 0.11895378222106956, 0.1563452824484557, 0.13914642564486712, 0.13805506780045107, 0.07819328777259216, 0.12406245965394191, 0.10702886429498903, 0.1216373362694867, 0.09576279539032839, 0.13325500505743548, 0.13415925262961537, 0.1600517609040253, 0.11025604151654989, 0.10069533149362542, 0.15167904377449304, 0.16634878003969789, 0.12303940908168443, 0.11345069040544331, 0.12011962942779064, 0.13986699166707695, 0.19005953741725534, 0.1696806075051427, 0.12323710980126634, 0.18534038361394778, 0.17107594903791323, 0.2352819053339772, 0.07873159716837108, 0.16466742963530123, 0.122667288815137, 0.1270762991043739, 0.09536379453493282, 0.13257859682198614, 0.099302528105909, 0.18254076509037986, 0.1316564783337526, 0.13758570392383263, 0.06140575518656988, 0.16392007208196446, 0.09282992425141856, 0.1219992371625267, 0.13192023761803284, 0.2005313301924616, 0.12447680812329054, 0.18816196970874444, 0.12913544720504433, 0.12487902247812599, 0.1114328576659318, 0.1975514439982362, 0.198469168972224, 0.1034178037662059, 0.11957579845329747, 0.1947451164596714, 0.10499186930246651, 0.21612176002236083, 0.12190378954983316, 0.09664270794019103, 0.14520125230774283, 0.20611190964700654, 0.17599582410184667, 0.18079882574966177, 0.24574572744313627, 0.15987575316103175, 0.06983305356698111, 0.21230862010270357, 0.21051375078968704, 0.15951260545989498, 0.1303698614356108, 0.12479864788474515, 0.08004694260307588, 0.229225060029421, 0.13706530997296795, 0.09883997714496218, 0.25402260362170637, 0.11821761625469662, 0.13052802794845775, 0.13331186841242015, 0.13476631458615884, 0.15041944105178118, 0.10229745763354003, 0.09363754419609904, 0.2903082815464586, 0.14603714807890356, 0.11517641381942667, 0.23424508050084114, 0.16580876370426267, 0.10037286832812242, 0.09820184888667427, 0.1054436517006252, 0.12348734715487808, 0.13619926816318184, 0.12454461073502898, 0.16254194837529212, 0.1428884529741481, 0.2526260301237926, 0.17255454469705, 0.12204740254674107, 0.11499321466544643, 0.09887021966278553, 0.1252174863475375, 0.0886500817432534, 0.14796791947446764, 0.18830510030966252, 0.1923621544847265, 0.17247563955606893, 0.13323513034265488, 0.14676454185973853, 0.10919375359662808, 0.148650873452425, 0.1332481624558568, 0.08917693980038166, 0.15987455088179559, 0.13263250642921776, 0.13876551092835143, 0.22503122803755105, 0.10528655388043262, 0.07387970283161849, 0.19576605933252722, 0.16571405081776902, 0.2100475484621711, 0.13584380911197513, 0.1343875372549519, 0.08625876318546943, 0.19310816132929176, 0.11401401017792523, 0.23229241574881598, 0.17895531607791781, 0.03961829948821105, 0.1111915780347772, 0.12764093989972025, 0.13624551880639046, 0.2137021507951431, 0.15462811599718407, 0.07923649507574737, 0.33738256024662405, 0.14425189699977636, 0.18867724284064025, 0.07222345186164603, 0.13232098252046853, 0.24472864373819903, 0.1333959389012307, 0.13018092548009008, 0.11732891667634249, 0.16984377609333023, 0.11404562566895038, 0.1056904009601567, 0.17440057767089456, 0.10921202527242713, 0.12937887164298445, 0.20270963752409443, 0.13699136237846687, 0.17346489272313192, 0.2686199062736705, 0.23571738274767995, 0.24107827164698392, 0.18473262403858826, 0.18899574293754995, 0.23514110507676378, 0.10170652254601009, 0.13000177103094757, 0.0648291822290048, 0.12955845653777942, 0.0979228904179763, 0.12147907327744178, 0.24341539858141914, 0.09900551318423823, 0.09205004578689113, 0.1166912040207535, 0.09876329844701104, 0.14860497904010117, 0.20436217775568366, 0.15012157266028225, 0.1381705905077979, 0.12588697776664048, 0.15076259529450908, 0.05952714564045891], [0.047222377979778685, 0.02932227696874179, 0.03237019955122378, 0.03319833987916354, 0.013598021214420442, 0.027122944593429565, 0.026134606123378035, 0.03855721384752542, 0.07450657270965166, 0.028367004888423253, 0.024095800290524494, 0.014811940109211719, 0.01472257346904371, 0.03479506318399217, 0.014458673176704906, 0.02440311622194713, 0.020149084921285976, 0.012135879896959523, 0.018588062630442437, 0.007156471137932385, 0.0347536253684666, 0.022466958689619787, 0.012414108277880587, 0.0224822265226976, 0.039705602030153386, 0.041135650099022314, 0.08855590320308693, 0.023376963472401258, 0.0042550990656309295, 0.09553358308039606, 0.07459003463736735, 0.06159605298307724, 0.05482008513354231, 0.035103859700029716, 0.030160093047015835, 0.0940566646750085, 0.07296967392903753, 0.05030177504522726, 0.039591738022863865, 0.0514271084102802, 0.049864416287164204, 0.004890542604698567, 0.02194507858803263, 0.017164610399049707, 0.06800196744734421, 0.07873972368543036, 0.033996838828898035, 0.034457360015949234, 0.023050579911796376, 0.03788280570006464, 0.060403002353268676, 0.019356649318069685, 0.04033522156532854, 0.041265807958552614, 0.03138984844554216, 0.024240682359959465, 0.049121088595711626, 0.013976099999126745, 0.026603010774124414, 0.030798429106653202, 0.056450316405971535, 0.02418028081592638, 0.07552873270469718, 0.05990302117425017, 0.02595375401142519, 0.044040920765837654, 0.036020816551172175, 0.10643697925843298, 0.07028327745501883, 0.04374913427454885, 0.0345733391441172, 0.047532681055599824, 0.0192761522703222, 0.03682530463265721, 0.017874741824925877, 0.026091977160831448, 0.03255087540310342, 0.021991678040649276, 0.058740624954225495, 0.037956912856316194, 0.024138137960107997, 0.06346107751596719, 0.041337428920087405, 0.04980338577297516, 0.02974113212985685, 0.01997962848690804, 0.053965357365086675, 0.053625446307705715, 0.08043233247008175, 0.05557352087635081, 0.05066858895588666, 0.04144203834584914, 0.056676515596336685, 0.026999415968020912, 0.014055104402359575, 0.08308534714160487, 0.09227970338542946, 0.03493031959806103, 0.037280820033629425, 0.030580209859181195, 0.06882135043269955, 0.03087983528530458, 0.03420854016439989, 0.0602664657344576, 0.02548922893765848, 0.03207306959666312, 0.06578557309694588, 0.012376743925415212, 0.011406130724935792, 0.03802482307946775, 0.0461339924368076, 0.021597413942799903, 0.032713327818783, 0.007731647647233331, 0.04187535239907447, 0.04888819523330312, 0.07687907782383263, 0.09397660178365186, 0.010684622175176628, 0.0048932064510154305, 0.10142567902221344, 0.06993764443905093, 0.05698886699974537, 0.01434260128007736, 0.06535776206874289, 0.03583628153137397, 0.032402397628175095, 0.035781254991889, 0.050534371548565105, 0.023889052790764254, 0.030351735986187123, 0.038694897084496915, 0.05239810474449769, 0.026678307222027797, 0.05573306407313794, 0.07519648803281598, 0.02862009951059008, 0.009202842702507041, 0.052527412844938226, 0.013731546569033526, 0.02933701231086161, 0.037983247966622, 0.01644106650928734, 0.05552780086873099, 0.04214327142108232, 0.021102659338794183, 0.032580364641034976, 0.010494666694285115, 0.03752913522475865, 0.04389162662846502, 0.028691143452306278, 0.08120641476125456, 0.04843416783842258, 0.017235147824976593, 0.02600748364784522, 0.025972285438911058, 0.01843797625042498, 0.04768997554492671, 0.01620800801902078, 0.032630697096465155, 0.012226454382471275, 0.04443542791705113, 0.02593782752228435, 0.027765343911596574, 0.06621328764595091, 0.03803771047387272, 0.03601522075769026, 0.03388991390238516, 0.008268532583315391, 0.015040006728668232, 0.010990548435074743, 0.059232550120214, 0.02771139348624274, 0.046682409883942455, 0.06672129515209235, 0.06815674976678565, 0.033649535980657674, 0.005356720812415006, 0.019218988345528487, 0.046686944406246766, 0.039260936828213744, 0.009776097049325472, 0.08009406898054294, 0.09156583895673975, 0.02589287749287905, 0.019227834745834116, 0.024223894979513716, 0.02348637644900009, 0.020171152682451066, 0.019858636151184328, 0.013290978949953569, 0.008869197226886172, 0.04101201571756974, 0.024212439930124674, 0.05242698171059601, 0.02565182607213501, 0.014095358492340893, 0.018150650066672824, 0.046698247315362096, 0.03242612780013587, 0.05110394391522277, 0.055257688800338656, 0.017574949415575247, 0.04720251810795162, 0.022159793043101672, 0.03134341226541437, 0.035755992284975946, 0.03920935014321003, 0.03758924547582865, 0.04296123319363687, 0.036636227669077925, 0.05463952060381416, 0.06078367216105107, 0.052112596822553314, 0.05267368644126691, 0.029262285461300053, 0.01448865872589522, 0.03358801935974043, 0.04499325208598748, 0.04845176787057426, 0.07470015450962819, 0.0523584406619193, 0.045366634003585204, 0.09840430677286349, 0.06422439124435186, 0.05954967353318352, 0.10781059070723131, 0.00494505288770597, 0.044686318360618316, 0.030287109766504727, 0.09974711909308098, 0.027630458571366034, 0.04382055485621095, 0.043569222834776156, 0.06760508913430385, 0.030405239267565776, 0.08572548555093817, 0.028958385264559183, 0.15584811771987006, 0.046069306845311075, 0.021576450126303826, 0.025618774525355548, 0.01889266601210693, 0.011851969447889132, 0.07231646522996016, 0.04716492461739108, 0.04583686990372371, 0.026073519948113244, 0.0249595859713736, 0.01113308067942853, 0.033189931345987134, 0.04599102139764, 0.03887479739205446, 0.018600823859742377, 0.042749806452775374, 0.004738605030070175, 0.043512864140211605, 0.06581507346709259, 0.019145358019159175, 0.03231825292459689, 0.042156912095379084, 0.015598934842273593, 0.06497974914964288, 0.050982142638531514, 0.07306851315661334, 0.04822940558369737, 0.010786325165099697, 0.05179929547011852, 0.04249465979228262, 0.04919656872516498, 0.06046937261999119, 0.02360131657042075, 0.06816175926360302, 0.014672936777060386, 0.04802980496606324, 0.04695667797932401, 0.015036633667477872, 0.05115420586662367, 0.026665930054150522, 0.04502328309172299, 0.02407812233286677, 0.012162774401076604, 0.06706352171022445, 0.09389332539285533, 0.011428624293330358, 0.0063196945302479435, 0.05579743425187189, 0.006060172445359058, 0.009606939329387387, 0.023196462025225628, 0.09875837800791487, 0.025225007666449528, 0.07839849902666174, 0.019301977154100314, 0.04184626021014992, 0.034640433004824445, 0.06289764642133377, 0.05397085667937063, 0.02965225252410164, 0.07024933904176578, 0.05279076394799631, 0.09118226735154167, 0.01182122876343783, 0.01928727149788756, 0.026359977819083724, 0.025037663617695216, 0.021766530844615772, 0.014781728204980027, 0.04428157699294388, 0.017296363876084797, 0.039230330658028834, 0.014575779441656778, 0.1059394508774858, 0.03961366106523201, 0.049315761352772824, 0.04067769674293231, 0.06088543916121125, 0.02732545071921777, 0.06373660726239905, 0.05687468757969327, 0.03387694487173576, 0.02514914347557351, 0.06181015516631305, 0.04540231646387838, 0.026912490066024475, 0.021981621939630713, 0.09514023739029653, 0.05424967414001003, 0.06328757081064396, 0.08140810823533684, 0.06506846548290923, 0.022153818754304666, 0.07579635857837275, 0.07111016355338506, 0.055144526122603565, 0.028195776576467324, 0.013212701851443853, 0.0567429081274895, 0.027876834901690017, 0.06372753821779042, 0.04224642623739783, 0.03964198513131123, 0.0190951572949416, 0.023966122971614823, 0.054798841156298295, 0.05998087988700718, 0.004643423199013341, 0.006952488602109952, 0.037281899858498946, 0.0556811953720171, 0.07863762642955408, 0.022401375099434517, 0.13746176526183262, 0.12010679027298465, 0.14054368191864341, 0.15606049069901928, 0.09288140703574754, 0.0653015889110975, 0.13659279939020053, 0.12827626283979043, 0.17611041170312092, 0.10844758347957395, 0.09603040642105043, 0.11899063727469184, 0.11655703114229254, 0.1541187652037479, 0.1403340103570372, 0.07437274121912196, 0.19710737251443788, 0.14483100967481732, 0.10289481971994974, 0.1441500149667263, 0.07595659568323754, 0.09454063401790336, 0.19031445030122995, 0.08924895781092346, 0.08987343055196106, 0.2685753477271646, 0.16654999111779034, 0.09088220962439664, 0.18151118361856788, 0.2146134339272976, 0.26102740899659693, 0.11367463346687146, 0.1544804434524849, 0.1595373041345738, 0.19897504651453346, 0.18226254876935855, 0.16309616941725835, 0.10256507608573884, 0.1402116153622046, 0.15990551328286529, 0.13250770687591285, 0.10738669821876101, 0.13712661137105897, 0.17679416720056906, 0.17056434211554006, 0.176080028177239, 0.1744069007690996, 0.35554157802835107, 0.09566667242324911, 0.12762332131387666, 0.19625510496553034, 0.12458404846256599, 0.10448421802720986, 0.10791323715238832, 0.17290933581534773, 0.10013490609708242, 0.10834987231646664, 0.08528386315447278, 0.15045153151731938, 0.11308080400340259, 0.21207705518463627, 0.0953499460592866, 0.326601232518442, 0.14142685249680653, 0.17434772191336378, 0.12690726754954085, 0.07721259898971766, 0.12034366896841675, 0.21766878169728443, 0.14782281476072967, 0.13890801812522113, 0.16523407422937453, 0.12966773036168888, 0.13672056753421202, 0.10197843061177991, 0.09665242265327834, 0.11526475165737793, 0.09832964671659283, 0.24957298301160336, 0.12689303315710276, 0.14971631549997255, 0.25042734341695905, 0.1307154499227181, 0.19035492703551427, 0.10677596263121814, 0.1471417013090104, 0.18046895595034584, 0.1544074309640564, 0.18607855337904766, 0.1126600507996045, 0.21607310482067987, 0.13214625127147883, 0.21146030077943578, 0.14616865664720535, 0.14240875840187073, 0.12799173826351762, 0.13175260130083188, 0.15755459724459797, 0.11444165793363936, 0.0895412675163243, 0.09290548972785473, 0.12506537575973198, 0.2113589976215735, 0.16443015018012375, 0.13887261768104509, 0.062380332383327186, 0.1625231423531659, 0.15372006862889975, 0.06313741207122803, 0.09073919034563005, 0.17577966616954654, 0.10039127359050326, 0.14983222412411124, 0.14313122432213277, 0.1973149660625495, 0.08931267118896358, 0.1104575939825736, 0.24577925767516717, 0.12869783240603283, 0.12804879457689822, 0.18767185538308695, 0.19848046445986256, 0.15562161424895748, 0.12059491564286873, 0.2142916090087965, 0.17157753696665168, 0.12416644196491688, 0.10575140549917705, 0.12468425324186683, 0.1169825489341747, 0.08549693375243805, 0.0935746323375497, 0.14568519196473062, 0.10837031848495826, 0.16871002677362412, 0.1005522305786144, 0.20339968643384054, 0.09784596681129187, 0.1412284022080712, 0.05757885584898759, 0.18144731438951567, 0.12872201157733798, 0.09167132782749832, 0.10722177074057981, 0.12292786428588443, 0.06959244186873548, 0.13617523742141202, 0.13950598135124892, 0.14097524079261348, 0.15715423825895414, 0.12620464665815234, 0.1403880980797112, 0.1495982546475716, 0.15329048386774957, 0.12470265850424767, 0.14900784648489207, 0.22056422632886097, 0.12253441469511017, 0.09366547863464803, 0.07241266983328387, 0.13161151902750134, 0.1738848295644857, 0.12649556854739785, 0.13636757241329178, 0.1672057231189683, 0.10008905621361919, 0.12015416155918501, 0.15785948635311797, 0.18522178841521963, 0.1252666610525921, 0.10410144794150256, 0.18500365637009963, 0.1330209316802211, 0.14316701068310067, 0.21562661393545568, 0.1540119553101249], [0.028206975584907923, 0.059082565785502084, 0.041837796015897766, 0.06652022508205846, 0.03491393297736067, 0.14414407778531313, 0.016607057114015333, 0.02040840616245987, 0.0627565270406194, 0.06444661994464695, 0.05082953481178265, 0.06175585964228958, 0.03390489044249989, 0.020377334294607863, 0.014253993485908723, 0.03588990541175008, 0.024616389055154286, 0.02209034100815188, 0.03581470358767547, 0.01222151538968319, 0.05087689125502948, 0.04117172589758411, 0.029660729705938138, 0.04373069932626095, 0.04158908748649992, 0.0835540727712214, 0.032221562214544974, 0.0051311492006789194, 0.05760275300417561, 0.056691354839131236, 0.039688558608759195, 0.011036422438337468, 0.0418347123923013, 0.014038677891221596, 0.007324349116970552, 0.05204378117923625, 0.015246539005602244, 0.05317490329616703, 0.06938020989764482, 0.03155603386403527, 0.02042451818851987, 0.022490794617624488, 0.0032917825683398405, 0.04558168242510874, 0.04410343928611837, 0.037367473196354695, 0.03273232308856677, 0.10737886856077239, 0.05693756975233555, 0.019991797853435855, 0.04383362036605831, 0.004660886861529434, 0.05133425089297816, 0.00961110185016878, 0.03828881985100452, 0.03776457415369805, 0.03974048297095578, 0.05001017409085762, 0.022448082163464278, 0.03196508339897264, 0.07620659554959275, 0.01843766454840079, 0.04371133298263885, 0.04890595482720528, 0.057742670105653815, 0.01509563348008669, 0.04195999434159603, 0.04063300460984465, 0.03793019553995691, 0.028456079307943583, 0.056517851844546385, 0.039929459744598716, 0.00886755986357457, 0.06532573839649558, 0.021771423453174066, 0.060121030765003525, 0.041939344082493335, 0.06836676271632314, 0.036777721834369004, 0.04943040832586121, 0.04892134697001893, 0.04815817053895444, 0.026413549749122467, 0.045009108071099035, 0.012522588003776036, 0.01955765073944349, 0.1071034575579688, 0.019098329976259265, 0.03010521122632781, 0.05628128856187686, 0.04954812779033091, 0.05934977234574035, 0.03371530881850049, 0.045617528157890774, 0.04195784582407214, 0.0071465936161985155, 0.042113203307962976, 0.002259452598991629, 0.047261132931453176, 0.04647145440685563, 0.027530955121619627, 0.030986207311798353, 0.01474300108384341, 0.039244494546437636, 0.04856131628912408, 0.05725706432713196, 0.04849090502830222, 0.049353863214491867, 0.022398311884899158, 0.023914842422527727, 0.05466572583827656, 0.08538555965060368, 0.0487899126164848, 0.004079749051015824, 0.038864852613187395, 0.04841590729483869, 0.08919075116864406, 0.04049873896292411, 0.019418537012825254, 0.03130309880361892, 0.019485254233586602, 0.025436677460675128, 0.027207965031266212, 0.03707308918819763, 0.09657383663579822, 0.0639848705031909, 0.19462603144347668, 0.03606785387091804, 0.009780665895959828, 0.0243859484908171, 0.08060766485868953, 0.06529729187604971, 0.08656839461764321, 0.040092917770380154, 0.044196589951752685, 0.09560954931657761, 0.05984812079987023, 0.10349293879698962, 0.01683256239630282, 0.0029340332957872306, 0.08636717611807398, 0.021145772552699782, 0.03163440836942755, 0.059126979613211006, 0.040570664205006324, 0.08018004678888246, 0.035348096789675765, 0.05935875233262777, 0.03170152449456509, 0.0644349014328327, 0.02657911547430558, 0.057848396463668905, 0.02911414165282622, 0.053446217643795535, 0.017145097481261473, 0.035855210007866845, 0.010105962210218422, 0.018906119294115342, 0.09124601041548885, 0.044270860380493104, 0.02410661709291162, 0.08153950548148714, 0.01517407106803148, 0.006105773245508317, 0.047026098472997546, 0.09513103475910611, 0.02341459592571482, 0.021275153012538794, 0.002006082222578698, 0.02404109101917129, 0.05796094686957076, 0.0367215746518923, 0.03514479656587355, 0.05457875726278871, 0.05801193241495639, 0.010414130683784606, 0.05102121671370696, 0.01964496070286259, 0.02287142360728467, 0.05818399564304855, 0.038572839766857214, 0.07092472311342135, 0.02350671129534021, 0.07956871748319827, 0.07353812936344184, 0.06483200981165282, 0.03803847859671805, 0.0702360991272144, 0.02024237659497885, 0.0239012370002456, 0.01301537869949243, 0.025262044546252582, 0.02205510754720308, 0.011918098516616737, 0.027411467490310315, 0.038676718177157454, 0.05876491544768214, 0.10029564044089057, 0.02100296664139023, 0.006705650748699554, 0.037638357098330744, 0.007587566169604543, 0.04008170020824764, 0.031114528355828952, 0.06639987099333666, 0.06729480461217463, 0.010510796346352436, 0.022741488392057363, 0.048596690758131444, 0.04347960479208268, 0.052599271293729544, 0.020826116560783703, 0.0429683541005943, 0.04599993088049814, 0.03360658047313336, 0.01593158955074614, 0.011683402663038578, 0.02015046717133373, 0.023693437506153714, 0.011779189808294177, 0.024695273787074257, 0.02913409800385125, 0.03153789948555641, 0.04491171603149269, 0.07310760207474232, 0.035474250762490556, 0.029108167364029214, 0.019972383270214777, 0.010300782469130354, 0.02117066233040532, 0.015804763934283983, 0.027197929339308757, 0.026691066595958546, 0.07956540008308366, 0.02770443956251256, 0.04368304231320508, 0.05659069734974764, 0.026485009293537587, 0.01844490790972486, 0.07820858343620785, 0.028042293015460018, 0.036872215787298046, 0.032186276803258806, 0.03534265313646756, 0.01409513120961492, 0.013701941370527493, 0.04998336029530037, 0.010067361254186835, 0.00763409465434961, 0.031626292984583415, 0.06627787675824948, 0.048504059595870785, 0.040533827705075964, 0.041091113816946745, 0.050143897969974205, 0.07670331498957239, 0.07071660264045931, 0.03410583805816714, 0.04403587416163646, 0.04524645431956742, 0.11406207908294164, 0.041226997345802374, 0.1206977698893752, 0.0336089850316057, 0.02783732852549292, 0.03813789298874326, 0.02064104348391993, 0.02685307557840133, 0.09581810765666887, 0.04567261777992826, 0.00592096223954286, 0.05044764788181055, 0.04076978613738902, 0.009756032159202732, 0.028294289259065408, 0.10695318749640137, 0.061979713645996526, 0.029469480105035473, 0.039675084917689674, 0.04062736057676375, 0.040438257638015784, 0.0204425931951846, 0.07273335926583968, 0.015233557915053098, 0.05922747754084412, 0.023225747172546107, 0.027230652485741302, 0.025425005333090667, 0.0068326308246469125, 0.05357395610189997, 0.0362912848504493, 0.019989272695966065, 0.11199515327461995, 0.028804992616642267, 0.021246532087388914, 0.03756390855414793, 0.049191696525667794, 0.0324630385148339, 0.007365494248006144, 0.04396342941618059, 0.027678969054250047, 0.08005926967598498, 0.02191454106650781, 0.04302738823753316, 0.11974143839324825, 0.022182153952599037, 0.010530782383284532, 0.006329882826321409, 0.04146302628214471, 0.01319021199378767, 0.11079908581450582, 0.060277375305304304, 0.06232254134374671, 0.011599959289014805, 0.015744675947644282, 0.00540451373126416, 0.07765091140754521, 0.028956171809113584, 0.006530372629640624, 0.10320675923139788, 0.08063804838457145, 0.04623018219717778, 0.02216004351794254, 0.019666777989186812, 0.0036572824137692805, 0.05546256979869213, 0.021188234532019123, 0.06050392701581586, 0.027644540823530406, 0.06101435763412155, 0.0007432172969856765, 0.018937096538138576, 0.05212897602177691, 0.02659956535353558, 0.024259191523015033, 0.07709741024882533, 0.06477242277469486, 0.0763347718748264, 0.02925965269241715, 0.030842763153486885, 0.04053741598909255, 0.02567744129919447, 0.01961387399205705, 0.03264909493736923, 0.03714869177201763, 0.015727354220871348, 0.017737444504746236, 0.039637480294913985, 0.03437762366957031, 0.02404015034699114, 0.0309036229737103, 0.024291441550303716, 0.15592107083648443, 0.15734556392999366, 0.09006223292089999, 0.16763214633101597, 0.19459478702628985, 0.34500034991651773, 0.184174113383051, 0.18064309348119423, 0.2328976520220749, 0.14718915423145518, 0.25725415209308267, 0.18449095106916502, 0.16923919291002676, 0.13300187332788482, 0.17240758461412042, 0.11592459515668452, 0.1309562471578829, 0.10050947545096278, 0.09992708990466781, 0.18207312299637124, 0.14547621802194044, 0.16406643844675273, 0.11297230943455361, 0.17969865119084716, 0.13712362793739885, 0.1342150176060386, 0.09633562949602492, 0.12942262866999954, 0.12768965447321534, 0.20166521309874952, 0.12418597529176623, 0.1082994211174082, 0.17812914244132116, 0.0982627940538805, 0.10711895360145718, 0.14239286159863696, 0.10093692282680422, 0.10669788127415814, 0.08214764355216175, 0.12647996860323474, 0.10955460063996725, 0.11604225524934009, 0.08649822455481626, 0.17484914656961337, 0.1263386191567406, 0.10392789670731872, 0.12396976540912874, 0.1457990225753747, 0.1589615608099848, 0.08840981885441579, 0.1409537481958978, 0.07173247664468363, 0.14739507052581757, 0.10175393093959428, 0.1032667321851477, 0.15785605763085186, 0.10362853659898974, 0.1864711643429473, 0.11597272343351506, 0.16437331651104614, 0.23195150279207155, 0.09158247790765017, 0.09018482829560526, 0.16228213731665164, 0.09981030554627068, 0.13395998597843572, 0.13407947175437585, 0.16045180818764493, 0.11405689147068188, 0.18480197031749412, 0.2130191374453716, 0.11994505402981304, 0.09583972641848959, 0.14208972395863384, 0.11369592568371445, 0.19216121057979763, 0.12463933846447617, 0.18084522482240573, 0.09097215050132945, 0.12327820993959904, 0.17010234034387395, 0.1329941104631871, 0.09655425878008828, 0.14394843281479552, 0.18888862134190276, 0.17962203186471015, 0.2874230785528198, 0.12452820927137509, 0.12101522355806082, 0.11844702152302489, 0.16157025442225859, 0.1360580968321301, 0.13726503675570711, 0.1092565170256421, 0.16533752961549908, 0.1420032637543045, 0.1450057260808535, 0.13239580584922805, 0.10539260678342544, 0.23890192358521745, 0.147242484963499, 0.08748526612180285, 0.13205174618633464, 0.11902464248123579, 0.1054334026412107, 0.1500880572712049, 0.1456968139973469, 0.1408208443899639, 0.1253002358134836, 0.13636396557558328, 0.14499566255835816, 0.19518396322382614, 0.1341984825558029, 0.1150561858958099, 0.2213902515359223, 0.12492947367718443, 0.18804168241331354, 0.09441604968742467, 0.1468489388935268, 0.07443943060934544, 0.1327620557276532, 0.1357980482862331, 0.12572100386023521, 0.07764432113617659, 0.1311115935095586, 0.2263577131088823, 0.338072074810043, 0.11514437530422583, 0.15953561203787103, 0.08879696761141531, 0.1963224622886628, 0.11419545786338858, 0.20674512488767505, 0.11439608264481649, 0.23851925740018487, 0.14413245575269684, 0.18946155934827402, 0.17952294030692428, 0.08080348052317277, 0.1314280304359272, 0.13451879349304363, 0.1097993238363415, 0.12746493215672672, 0.21779815288027748, 0.16398204141296446, 0.25102450512349606, 0.20908818900352344, 0.19306122791022062, 0.05480177263962105, 0.13879580539651215, 0.13985937723191455, 0.19078330951742828, 0.11569251073524356, 0.09321095029008575, 0.08501965858158655, 0.10471456582308747, 0.10656575672328472, 0.09582356986356899, 0.1367689555627294, 0.16165772394742817, 0.1580362065578811, 0.19421212084125727, 0.14442474319366738, 0.13503041525837034, 0.25787037215195596, 0.175157479243353, 0.10347811068641022, 0.1721528943744488, 0.1048162326333113, 0.10739987876149826, 0.13070685585262254, 0.1371610173373483, 0.1837730419356376, 0.15981224016286433, 0.12090931908460334, 0.0916619025520049], [0.03923281314200722, 0.034469813253963366, 0.025917876737366896, 0.03086653414356988, 0.03665365329652559, 0.010473151833139127, 0.03430254801060073, 0.07242628824315034, 0.08015789368073456, 0.07814301468897611, 0.03424474212806672, 0.05075926455901936, 0.06400628146366216, 0.03899029041349422, 0.06659793536528014, 0.0873208581469953, 0.023686210843152367, 0.0047966827241907595, 0.018006409954978153, 0.0767747095960658, 0.09412937288288958, 0.04015840117062908, 0.008525788798579015, 0.02491942093911348, 0.02676094907656079, 0.07451493671396747, 0.034460183887858875, 0.047715490582049824, 0.05352205771487206, 0.08046729504712857, 0.028824761575378943, 0.024319414951605722, 0.10543054537265562, 0.07018609321676195, 0.017446376041334588, 0.04643374959414359, 0.037003887628088705, 0.04891411845164839, 0.06314438083791174, 0.07783319771988317, 0.017832784506026655, 0.05614975772914477, 0.026126550110348035, 0.028515365775092505, 0.04802132592885755, 0.059151630048290826, 0.02724421523453202, 0.05243625113507733, 0.029378631952567957, 0.08115783377434127, 0.055832678845035844, 0.05950053222477436, 0.03593310582800768, 0.015945081795507576, 0.06508760547148995, 0.011004549050994683, 0.06087577268772293, 0.044724668841809034, 0.04097707169421483, 0.055287972136284225, 0.01024287083055242, 0.07184357615187764, 0.033711746509652585, 0.08267952594906092, 0.008838826688588597, 0.026400204078527167, 0.05408366312622093, 0.04406770858622622, 0.037827905325684696, 0.10592080812784843, 0.06110613903729245, 0.07831432463717647, 0.021570529643213376, 0.04104313025891315, 0.01585183279530611, 0.09906018720357679, 0.05960091140877921, 0.01822662557970034, 0.02055164623016026, 0.017894854026963003, 0.05512318937689997, 0.12565611046738923, 0.05519973077753093, 0.043413301318651065, 0.028455762039811816, 0.02573480931459926, 0.07730519675533287, 0.04465437632461544, 0.03682570910314098, 0.05034219611843582, 0.035127890441799536, 0.022899469367985148, 0.08552161758416332, 0.021610737348964904, 0.026556500379228964, 0.03027963262866251, 0.03972945465648081, 0.1052363846974913, 0.02241697504359763, 0.020463924374780618, 0.10860469614272006, 0.03857281008095015, 0.11293209245195612, 0.03938447101972997, 0.04384837426187005, 0.0648167438339442, 0.010859641934075626, 0.05799283695523627, 0.024826414992276113, 0.04550506309897173, 0.06983626706642099, 0.0691108473984059, 0.03976046900788788, 0.06456954928580672, 0.012223905105201993, 0.051067972017335705, 0.038694700415362604, 0.018137187507818453, 0.011529695530043682, 0.03926101475371979, 0.037352107028709725, 0.04059505488839932, 0.029922522298875265, 0.039855853538028896, 0.00970570898061851, 0.030013997566129547, 0.05847585263836663, 0.03128864547761623, 0.02708071824599756, 0.04664407424570527, 0.00484128951029561, 0.07567080203443766, 0.03508380315906834, 0.04417888601892628, 0.015378686748590553, 0.08199694304494187, 0.07470402852050029, 0.1130964930052869, 0.03155590769893024, 0.04610759424394928, 0.0870024025789462, 0.055156897724373266, 0.063685094792163, 0.023615769896423444, 0.03905044519342482, 0.033186881119036116, 0.039395031781168655, 0.024842538150551263, 0.06575190927833319, 0.03810515314398799, 0.02253159233077895, 0.019364042964298278, 0.10351410484872758, 0.03196418911102228, 0.00909955337192514, 0.045701301787630655, 0.04765095713082701, 0.04156785835220944, 0.010791897766466718, 0.008244313521572622, 0.049637738411547616, 0.024901592696551234, 0.039940154092619196, 0.07053400462609716, 0.011084994148404803, 0.02807875473081367, 0.024354846937058028, 0.061495057816500776, 0.03960232104873285, 0.028255359902686905, 0.04450199856364634, 0.02933271898655221, 0.05971309816231951, 0.0265061642130604, 0.048821134769241326, 0.08362109612789936, 0.004107828208361752, 0.058989248136640526, 0.028584545070771128, 0.07454316059011035, 0.06873217396787368, 0.061006865653325804, 0.03151008750137407, 0.10338587657315657, 0.09988694713683799, 0.03501603765471373, 0.03957800458010752, 0.03664299234515056, 0.031104505651455838, 0.04067927751748357, 0.038137072915560566, 0.03263008482463192, 0.02426572984404629, 0.028236002835910767, 0.014908208722772542, 0.0329340499592945, 0.06164622958749533, 0.030223557805584278, 0.04896348611509893, 0.020020142328576185, 0.04714275295555126, 0.02298073268320877, 0.03550222230842337, 0.07497829661588185, 0.026765452057588845, 0.01680404722719686, 0.05037823852035217, 0.08527297584805638, 0.04603849658451509, 0.03897386297467165, 0.022472541495517362, 0.024761473359831143, 0.005129012743054773, 0.0211188121829764, 0.06860124427475967, 0.014118001417955384, 0.01970697641809238, 0.056649456892046146, 0.029256724919832777, 0.033978741557803005, 0.03290457927505486, 0.03472487456747331, 0.017763974428817164, 0.027441236888989806, 0.021472022526722867, 0.09274457726860419, 0.024147533549694344, 0.10422098566778004, 0.024300241566379555, 0.012331202033237787, 0.03136980674753431, 0.059210419276496395, 0.01531866555524175, 0.10302525959559716, 0.004312156770538422, 0.025338624909636565, 0.05897010072658304, 0.09523891334538348, 0.03808893721725326, 0.0054496479060617276, 0.04877794177446049, 0.03660107213363517, 0.029250398110889364, 0.07191224707639776, 0.017024709995894227, 0.0477827996655833, 0.07600309123517945, 0.043468750882311724, 0.06535351698403247, 0.09979521026252769, 0.044354069977998734, 0.06000049485010095, 0.05877519790374208, 0.07703184150159359, 0.024774514749879017, 0.02699430813663639, 0.03263670107116923, 0.061007555850665085, 0.06508786522317678, 0.02502978572010761, 0.01598384045792045, 0.018978875741595402, 0.04167951818089932, 0.06596342878765427, 0.05981503214570694, 0.043878412689082325, 0.008430828220298281, 0.03173544806486461, 0.04687190616095904, 0.04567756419419311, 0.08113047821098007, 0.016686817580193747, 0.03333440894493833, 0.10736330572399311, 0.0025019973600137746, 0.03050265171623323, 0.09312688722275198, 0.03497493751638103, 0.04807695731869899, 0.023752252709527966, 0.054509147521457635, 0.05856676201801747, 0.023298316227737814, 0.0775768153835088, 0.01002905437417212, 0.06432531590689905, 0.060323280849843286, 0.05463237001094967, 0.05123450253449846, 0.057725615552044474, 0.009808814629650442, 0.033422294072806835, 0.031156880868365988, 0.029210633838374633, 0.027824114586110227, 0.03276061746873893, 0.04651382732845377, 0.03537905548000708, 0.05633759530610405, 0.14781842124648392, 0.02582670575066004, 0.0275276191678131, 0.017653244140092283, 0.024188333118217997, 0.03472409531241283, 0.017224972980329767, 0.0076540690952242585, 0.05870828215847723, 0.007460817550963839, 0.006230745811990346, 0.026047244209621567, 0.052148160539218225, 0.047072367669898085, 0.0910360568377655, 0.038738516814191826, 0.05056218724348582, 0.10593264538329095, 0.029557419038610533, 0.034491450569476, 0.05145544731931295, 0.03444250593020115, 0.023552987913717516, 0.038896939367987216, 0.05907524820941035, 0.06668844769592397, 0.04425254046509508, 0.04432998728589155, 0.05264113955490757, 0.02248282024083892, 0.06124982253822964, 0.03359008624101989, 0.04270999394066166, 0.06953741161851212, 0.016127911731018685, 0.029353773716138676, 0.016107051815197337, 0.04458963136130478, 0.019100532299489714, 0.04280108885723166, 0.06704335013637319, 0.01054398890119046, 0.07718533990555443, 0.01710925360384863, 0.0787594796565827, 0.027535890403669327, 0.011066639908676734, 0.059496773246792145, 0.05132959762704559, 0.04312461329391226, 0.07090833649272099, 0.022871557193866465, 0.06127822081907652, 0.10775510032544844, 0.10045322807854973, 0.13018923753406852, 0.1258653961122036, 0.1541715022176504, 0.16563401761231944, 0.15784249117132276, 0.13679767667781562, 0.17644191422732547, 0.13113418448483571, 0.11317038122797385, 0.08738325792364776, 0.18339824251597747, 0.17062881990568712, 0.12334463215665892, 0.13825084635755047, 0.12997904646908864, 0.06003480804793071, 0.12698813196038827, 0.09056975060957484, 0.10931212615105323, 0.15734266955405474, 0.17243093258002773, 0.06038943218300119, 0.1123724685749039, 0.06618249593884684, 0.08860696296324022, 0.13673431210918352, 0.1270867485436611, 0.14166417648084462, 0.1395325650810264, 0.25211724336259067, 0.16418564220657572, 0.1557754911482334, 0.06587215204490349, 0.10731442045653239, 0.17585278255864978, 0.12341080204350874, 0.11358788382494822, 0.1568491116631776, 0.12448963985661976, 0.11757372893043794, 0.13806538365315646, 0.19526347692590207, 0.1435141428373754, 0.1738078540074639, 0.10916282088146545, 0.12606724543729797, 0.06034447287674993, 0.11519993990077637, 0.10945410642307252, 0.18712842516833916, 0.11529006631462835, 0.1616568333702162, 0.19514693005476147, 0.10625691938912496, 0.14098073268542066, 0.1861739787273109, 0.14223968231817707, 0.19083165301708505, 0.14154970762319863, 0.1391911177779548, 0.11024007792002521, 0.14370276709087193, 0.11103321114205755, 0.12100456631742418, 0.08932959957746789, 0.175624379189685, 0.18503501953091472, 0.1890785517753102, 0.22855184302898124, 0.16647498967358842, 0.09254356657038443, 0.160014905850403, 0.15210747078526765, 0.18713500059675425, 0.22011007647961378, 0.15230595075991005, 0.08084253975539468, 0.16503289283718914, 0.10986325985868461, 0.1817024647607468, 0.16787387867225334, 0.06475182075519115, 0.10028466407675296, 0.11295335498289205, 0.18882078904425725, 0.11817382954177447, 0.15105191414477304, 0.1024550898000598, 0.1422291438211687, 0.1638372929301113, 0.23539667105069384, 0.1509847052511759, 0.2804527385160327, 0.14279997412813827, 0.14811360306339338, 0.1695361261954531, 0.06495241585071199, 0.1414907959406264, 0.20465142239117995, 0.14616613334510475, 0.18254131427966058, 0.12505048827733845, 0.15195406886050478, 0.1313182371086441, 0.09086592690437101, 0.1994211069541052, 0.06521997493109666, 0.18770799797493964, 0.10490133470739238, 0.08666335983434692, 0.1432938437210396, 0.12582575058331713, 0.05590949484030716, 0.10479614269570448, 0.12798225361621007, 0.05428830292657949, 0.13723269395995885, 0.08626276336144656, 0.18644661409780383, 0.20217809651512653, 0.13138688576873392, 0.25606600334867835, 0.07891582790762186, 0.1337020006030798, 0.15010998031357303, 0.08769480409682728, 0.08608484087744728, 0.11346627550665289, 0.14957683626562357, 0.18755130091449246, 0.12039372682920657, 0.09816612931899726, 0.06830453363363631, 0.14256181893870234, 0.23173004592536017, 0.24807808978948742, 0.12314860126934946, 0.08400868275202811, 0.159286814450752, 0.12380820728139952, 0.18478680081898347, 0.1237260812195018, 0.16803410835564137, 0.0931208387191873, 0.1763530494645238, 0.11929030166356824, 0.17665646912064403, 0.12479563476517797, 0.15724515134934336, 0.20143588946666569, 0.15859143692068756, 0.1212714723078534, 0.14134150551399216, 0.15086113766301423, 0.13592109637102112, 0.13054582464974374, 0.12249282473931089, 0.09255661352653988, 0.20013106026453897, 0.11982805444858968, 0.13125372963258997, 0.17814213002566248, 0.19202153838705271, 0.12103860863135196, 0.06311655030003749, 0.12056916311848909, 0.1186434383271262, 0.08905907190637663, 0.10501151395146735, 0.10412618372356519, 0.11952424887567759, 0.1673460632446222, 0.16118800383992493, 0.18285300146089867], [0.015194031129794894, 0.10774859169032425, 0.023113938914320897, 0.03810081158007961, 0.017399275639036205, 0.020477793259487953, 0.049284925116808154, 0.1204758751555346, 0.03629213460953906, 0.04927246074657887, 0.025797233211051207, 0.07168088995967992, 0.015335882453655358, 0.0535484744614223, 0.03933098072593566, 0.03438036219449714, 0.06708108834573068, 0.01991162178455852, 0.05475585596286692, 0.031513382637058385, 0.04995310664526187, 0.04086243956407998, 0.04315955360652879, 0.022617700014961883, 0.036690827473648824, 0.056392443730146624, 0.08404578271438368, 0.04787567944731563, 0.07366271369392052, 0.0392396557435859, 0.04008409734524321, 0.04498657275689766, 0.030345117884280626, 0.010676991969376104, 0.07289339599083178, 0.028678651251539122, 0.007959905833558878, 0.028941562632098794, 0.07334710797294974, 0.008221269836212741, 0.02834822855220409, 0.0728217045252677, 0.0423577558103716, 0.058960374881280586, 0.044768989901058376, 0.03973816375946626, 0.019878397688444238, 0.03962311602663249, 0.0372432896256214, 0.07905354825197719, 0.028706463235721458, 0.03763046806852799, 0.07123376824893057, 0.04518763911619317, 0.059315856196917593, 0.03414152051846031, 0.0678251804492902, 0.07549229325377382, 0.05336939051630907, 0.026610805180098396, 0.05395765387220308, 0.05654640968714375, 0.03631880368629936, 0.10571458755293861, 0.06077733421989251, 0.04855091880017426, 0.05245227410341613, 0.08706915876246057, 0.07466953349648975, 0.03464010274910834, 0.01347163717582589, 0.018679727145354263, 0.05163116933545098, 0.006683736519335071, 0.013963191267976072, 0.028965090568817686, 0.027374896308174357, 0.029877332926844247, 0.05769900955783669, 0.0633714186551515, 0.035223813029006124, 0.014064404440432554, 0.03411703335586935, 0.06879186490550637, 0.022317063412629068, 0.024118109249684494, 0.03906640878994949, 0.0276934093926684, 0.014016692693985533, 0.02365033171372488, 0.030725446304131765, 0.0741509281215258, 0.05496462581504602, 0.04274784718290903, 0.041821042032097466, 0.021101640741107985, 0.009792503151402343, 0.0362306216993602, 0.009567058168613585, 0.03844991042569745, 0.045696641100221314, 0.01154088155089994, 0.04084853171661962, 0.014106896105658961, 0.04961757054843474, 0.044721960002789274, 0.017593252632650547, 0.038907370253582485, 0.07214676574221812, 0.04501580224314239, 0.015258334515237948, 0.05292430600093212, 0.10481416946277022, 0.01388000207953155, 0.03771900628635194, 0.019773456151597202, 0.03420297405682504, 0.052413444936973974, 0.03481501582427882, 0.027878027904080227, 0.030430448168772273, 0.10149962661671452, 0.10625767637975514, 0.0359554778697202, 0.0805480036069639, 0.0572647789522307, 0.04426015861099586, 0.01236019867064897, 0.05150347169546876, 0.06276652376982383, 0.014718330239702482, 0.06536130211316049, 0.021337224388844334, 0.01641616559936665, 0.03471599477052223, 0.057490870531182736, 0.017311282899754588, 0.02441452303173719, 0.0441304126434261, 0.03021009895746829, 0.0727846342488192, 0.04196121146378573, 0.040838865243131295, 0.045988000856596045, 0.039036990056047216, 0.04450726781215053, 0.032887880952330306, 0.015015501940069953, 0.014784574341319967, 0.04080433682247531, 0.03656254724774044, 0.03072420320677338, 0.1528231831616722, 0.06380676990374923, 0.04654707925510593, 0.03017657985765254, 0.08388400194235146, 0.060277045049588196, 0.0715970792225562, 0.06514705150038935, 0.03968827659264207, 0.026597081014188007, 0.03918248068657704, 0.07280289108166471, 0.07390578932245262, 0.024071417028608266, 0.008630862066638656, 0.07985489704879001, 0.029493579495465383, 0.030964438265073113, 0.0388087907776935, 0.11935953662032261, 0.018744256885838695, 0.04790089762536809, 0.018517647658882197, 0.03933510335627943, 0.03188319853506982, 0.0882741691020783, 0.015610163536621258, 0.0397379782225471, 0.008023420687095495, 0.02006273603910813, 0.03659154295746703, 0.08422339349635877, 0.035423836670815945, 0.06649022005149163, 0.0279353996302234, 0.01731873220705893, 0.033754954347386956, 0.11862800165545195, 0.022491790950880386, 0.026162846697843634, 0.04709330736659467, 0.07105381228029728, 0.0699088787951041, 0.07900745345978066, 0.04744126330479048, 0.03048907412448898, 0.09865971689578146, 0.013690020623471355, 0.017786823300411925, 0.05342296986782458, 0.08551079707103781, 0.006539330815940048, 0.01998826708586421, 0.005491464680744684, 0.02066525605187053, 0.019670164037961513, 0.03628282807767391, 0.06125151092419401, 0.018492642848286778, 0.02882165754272137, 0.03692300095281098, 0.008841936287353747, 0.01802009515813552, 0.05221736581006553, 0.012229807962285122, 0.039951664803083986, 0.03850521155982278, 0.059501593495951965, 0.009122738993028179, 0.030997016692708712, 0.01600649451575009, 0.051948597028967924, 0.03716836239618715, 0.07150183941121213, 0.014187813394528348, 0.0305912307521794, 0.02652660110470606, 0.05294914939440787, 0.02144138667063089, 0.060134894083603285, 0.07287216314580292, 0.03348187368828803, 0.043282464393996634, 0.05343525241187308, 0.06782636788557284, 0.0248234519676771, 0.008600001710874494, 0.07260420330567285, 0.0375718161376426, 0.0489609257056145, 0.021862904286535922, 0.09002980848890729, 0.05378886351536494, 0.04236320317431819, 0.03303890429378953, 0.020555679802782834, 0.040210199367720634, 0.0672723694879096, 0.06262225026148371, 0.027441134843684267, 0.08107057947199792, 0.03582917917810846, 0.05018831550842151, 0.005514318654604722, 0.03529760106175672, 0.03975924446422141, 0.05837009288370609, 0.0598609414009843, 0.0016047933490881405, 0.03909278100763913, 0.07032460023765452, 0.058501931707724, 0.08599983528256416, 0.035004582605324686, 0.041465809335932136, 0.04740850119560491, 0.049260805317317136, 0.018631786260812078, 0.08790021573076956, 0.06619876381591894, 0.024325949561898597, 0.05755804602813441, 0.020493962801992893, 0.04206648140097968, 0.012238166400493355, 0.0028430248858057894, 0.03164019712130539, 0.033277389738941565, 0.053672357462346554, 0.005933414549872396, 0.10536768546444364, 0.038761297037126496, 0.010896387520915596, 0.027221082491450943, 0.02974772982270224, 0.07994793268153444, 0.05553406459512189, 0.04573743695800658, 0.053968685897416435, 0.03624496741394978, 0.044195717928232625, 0.04698974807979539, 0.019707907813426573, 0.02892926710046595, 0.030315621224872302, 0.07387403282336891, 0.07446024785167538, 0.07279872021172196, 0.08838836336508393, 0.02299504129041452, 0.031192062378977425, 0.019941682476201095, 0.01209908607052057, 0.005965040245428099, 0.06259473142563365, 0.044064699177397415, 0.08325011876877397, 0.013083247176837176, 0.04856393235968426, 0.04935174809361342, 0.013140778464730829, 0.05016592862375546, 0.03572799476387445, 0.08324336522491649, 0.04469703126233071, 0.030557110512745567, 0.06191654203576036, 0.03746271300769877, 0.04440674019861035, 0.06986753374803811, 0.04814955791516695, 0.054610009101452306, 0.005625984513244475, 0.04982946855307091, 0.04593818048306275, 0.0185838212564704, 0.03581634744477924, 0.016162108040589374, 0.024535693482903298, 0.047054133101482876, 0.035603488358901814, 0.025440148856432643, 0.029918175168859307, 0.02539146582421381, 0.05362353527743835, 0.020413154052221216, 0.031579047863488086, 0.08365731293451972, 0.042579116197885014, 0.035430964999250136, 0.011185676685272483, 0.05293282956699841, 0.03997017767687794, 0.02328655875317054, 0.022132585909275804, 0.01622399202460656, 0.0151013192589744, 0.07927625192678533, 0.06858436041511595, 0.059945349566987716, 0.14629569748649374, 0.19567573996027932, 0.06702280006720684, 0.08517342415871099, 0.12070319498889148, 0.05581721619819291, 0.17555654689203948, 0.29345935152377933, 0.12387367212795652, 0.13547187438234687, 0.23782379081239924, 0.16631343896733597, 0.10180612618569285, 0.2508409571601078, 0.10951002725050785, 0.09582938087987714, 0.20667698088800535, 0.23143750615417957, 0.1225336131756194, 0.12764724815497175, 0.12878230365458876, 0.0869132780644577, 0.15729251521406695, 0.0857986687333323, 0.07032997338683344, 0.10002454873756506, 0.1591404777718708, 0.19808777928119525, 0.1351559569593519, 0.09948202394298278, 0.1252877528895624, 0.18471763265552, 0.16979016334516928, 0.17495341831818223, 0.222129920439329, 0.13979607203509659, 0.11651391978375614, 0.10133921139640734, 0.19542205904144794, 0.15990324231097475, 0.116767140571028, 0.16280417883535847, 0.14777233387576416, 0.17737161746481434, 0.1206221895699855, 0.1793472294230014, 0.05071316234534606, 0.12667037401115522, 0.10965265319100581, 0.2420715324115008, 0.12400869105476886, 0.13732737716054544, 0.1550572703126818, 0.12409331815433688, 0.18559240212198347, 0.10124014210305177, 0.16461371298646554, 0.12820394797017798, 0.11542496649781242, 0.14339479064801708, 0.14173218689393252, 0.2773220033850521, 0.15759139292640612, 0.1953606537426822, 0.13948171312222257, 0.23507438600063324, 0.24526101595256478, 0.20503355422988534, 0.13742136274231598, 0.10273154723108746, 0.1129725543432869, 0.1011386385653168, 0.13719223206862807, 0.17916865384904668, 0.13136730791302398, 0.13263044325867668, 0.12626657146029174, 0.12686161062447354, 0.15128187602385879, 0.08988877074443735, 0.1066395039379131, 0.11022093050996773, 0.17382269696099684, 0.1095466448168736, 0.0961988591006957, 0.09581307589542121, 0.18886830133851618, 0.11785322916693985, 0.10254062231979333, 0.16422365501057357, 0.1664551891735755, 0.16024878626922145, 0.16772573115304112, 0.1100211740413215, 0.16725951398257166, 0.1468535847379826, 0.15327564091421664, 0.1564070291351527, 0.12106520720408298, 0.19907375215552747, 0.16355627129087225, 0.11163990944623947, 0.10966316200210713, 0.09489059375482611, 0.16778857621829957, 0.11931367931538261, 0.13719091104576364, 0.19826020987238735, 0.13677268114406615, 0.0963923815288581, 0.08387433917960152, 0.14961400302127004, 0.194668764306698, 0.10665143767255358, 0.20499086589552462, 0.08669659320730716, 0.1579961454262957, 0.1714763673953712, 0.12053378493874334, 0.09704880372737534, 0.10841703668120317, 0.18659943714737892, 0.21527315868297592, 0.16372212645364925, 0.21480435883859172, 0.13988110731588677, 0.1198892890533898, 0.08821326104225591, 0.09100781069719233, 0.07914354107924737, 0.20040235976921394, 0.102714210661361, 0.2016535316943191, 0.08955699362559244, 0.11948210230912082, 0.18785087624564767, 0.09737301836139522, 0.10852601364604197, 0.12751651142025366, 0.15531172306509688, 0.193937080912292, 0.11313466166029684, 0.21097688062582165, 0.08970793162006885, 0.14862804498989135, 0.11676000853185542, 0.14485391235211864, 0.12177760218037292, 0.08447805405012332, 0.09853843512246385, 0.08967740708612837, 0.12249569685081951, 0.2657355641713366, 0.11971870640991256, 0.145542491809465, 0.20603082259185612, 0.11625118466326967, 0.1609152794117108, 0.13766417861916125, 0.16132999153342098, 0.15129000996239483, 0.1142718768096529, 0.19912720163119957, 0.22758473554858938, 0.20364992378745228, 0.12251361229573376, 0.14435176039114594, 0.14972299482906237, 0.14264204510254785, 0.20204885891871527, 0.13240288593806326, 0.1935444847913459, 0.13589911395683885, 0.1567200373392552, 0.15639041987014934, 0.10821192932780832], [0.05200833249546122, 0.037290334366844036, 0.0066705202607408864, 0.013370322885748465, 0.02629730344779091, 0.03670595615403727, 0.03308113991806749, 0.05433465375972446, 0.017827492993092164, 0.009394112712470815, 0.04482549331441987, 0.028986963516217656, 0.052819377451669425, 0.015627347966074012, 0.06922683023731224, 0.022825974483566824, 0.026380624367448036, 0.017219334513356443, 0.04588530988257844, 0.04045831417897716, 0.018769883245113306, 0.03201019484549761, 0.04927790068904869, 0.04851915859035216, 0.028609516484721098, 0.054511856360477395, 0.07727654985501431, 0.0552156721096253, 0.022434155762312002, 0.023489803315897007, 0.027429160290921573, 0.034972336288774386, 0.09640582924475893, 0.05430284531030338, 0.042093428783118725, 0.011354661855875747, 0.03383842369657941, 0.038329853196046315, 0.051789372955681756, 0.03870437802106608, 0.055573936479049735, 0.12499675678554922, 0.02955096606456209, 0.09345876082079485, 0.034617252022144385, 0.09268512381822802, 0.08687179943080992, 0.07455318700522184, 0.020356530039862264, 0.0658009726612363, 0.006673297748420737, 0.048411840325570665, 0.00941547543334309, 0.030250672170950565, 0.021517276836675592, 0.024206320922530722, 0.04398177159600891, 0.01549733668070985, 0.03457823731878307, 0.08978117417427711, 0.02470824467309285, 0.013207054107624572, 0.05463157962367404, 0.008516031412000302, 0.058524674823274836, 0.03415357670746744, 0.0060249524358368944, 0.04943185922456905, 0.024269763416668866, 0.037421353117679246, 0.04536260043096263, 0.023675475677009672, 0.016596787645539735, 0.07905056481831707, 0.057692256013979204, 0.025625002999731805, 0.05185387301025912, 0.030321727244881913, 0.05419821733084973, 0.0397614375106059, 0.04256082967913244, 0.013391865577432327, 0.0217791621980723, 0.018544357553764712, 0.03196111290890258, 0.0720247121353168, 0.05436215033114422, 0.07274207950104028, 0.052131625488982536, 0.06354232784360647, 0.020353847176011186, 0.05644917720928788, 0.0579992713755928, 0.023425444269378204, 0.05186062655411661, 0.04213154177705292, 0.024723351089050993, 0.034622231833054684, 0.04346733709098771, 0.02151148066332098, 0.04687530890805647, 0.02817744552885415, 0.04688436682044994, 0.04899127583485097, 0.05028508785471786, 0.052886040866724215, 0.03588665109418798, 0.025764814345166087, 0.08151151167112403, 0.009534003838780336, 0.01517097260148148, 0.07314971895539202, 0.021162418925086968, 0.032360202822019346, 0.03180638996127527, 0.03727198105480056, 0.03614617642597295, 0.016396188839280512, 0.08354655481525697, 0.018046087025140878, 0.0415942268591607, 0.06834901796537451, 0.0632510423019994, 0.05878768824914005, 0.04680080099205952, 0.06000436515023466, 0.031484772844123654, 0.019168524158885702, 0.01642666513362201, 0.01956358606548747, 0.05539160192711279, 0.045523208609665744, 0.05953355779638514, 0.0803077852469869, 0.026763824898807798, 0.034150430001318455, 0.04556769294140395, 0.05437296713353135, 0.01295972133448231, 0.02740097352216253, 0.01575869697262533, 0.017700901153148152, 0.018193752148363274, 0.07403007679386064, 0.032596061064396054, 0.01931074006279232, 0.055651227448834106, 0.026129071557079442, 0.01851881097536534, 0.035787871238426305, 0.014773053426324623, 0.04349831804574933, 0.0176135577930836, 0.016365760784537997, 0.03335971989145037, 0.029069646188872866, 0.07974370106239803, 0.012564775388455018, 0.021204300173849333, 0.014613495386583963, 0.039602109536645, 0.039047020181897096, 0.028447772820072714, 0.05820826016133651, 0.01865420283138519, 0.005244765980023658, 0.06114684583735652, 0.055565398070029914, 0.03773752658162266, 0.019351508090039715, 0.01959891971637262, 0.06286129602813162, 0.06423339349566959, 0.041685948890517466, 0.00750872179196449, 0.05892534180020448, 0.050115677804569714, 0.09258289297576994, 0.01656253938563168, 0.022109249075583648, 0.041578708551242016, 0.05134699727932457, 0.05695588595699519, 0.04144245765928645, 0.09100961411604658, 0.06237999099539593, 0.032190521887969226, 0.030248492112150416, 0.025304682785645127, 0.010047044033854036, 0.08790952968411148, 0.018356965265411418, 0.029057426727376878, 0.0830753355694469, 0.04949684167513624, 0.031851850217208266, 0.004657293939089868, 0.016137882485054433, 0.044866188982268795, 0.027174366150575224, 0.045899061879026704, 0.04284552494937088, 0.0827446419862099, 0.06345751520711929, 0.05331829364877194, 0.046171567373676226, 0.07939731847727671, 0.036118728094152175, 0.015053991573950043, 0.014260340703913243, 0.038099880184745416, 0.031124951819947455, 0.025070548181247432, 0.03281273107859306, 0.013489872671925696, 0.05053285385656636, 0.037196415578364395, 0.02622501826408552, 0.02856100043572951, 0.09049529093317688, 0.06624897010624409, 0.08939661551266909, 0.045353126915870234, 0.03401247588044498, 0.021840150038769934, 0.08684767220984213, 0.029862912997487, 0.029047164680378046, 0.019462418349576183, 0.0006724528202539659, 0.07862243466661312, 0.08565502605051734, 0.021601870539598167, 0.04501005430938676, 0.029656460501428228, 0.041513399555697106, 0.0606030259950785, 0.04338586782978382, 0.08451803354546428, 0.06367686437442899, 0.020280324461054988, 0.023840215762902517, 0.03014322959643323, 0.04354574499302544, 0.05691189886420034, 0.027198981333640404, 0.030250108138716314, 0.0173220143551589, 0.07153167374781333, 0.04031656768347602, 0.04153284753556363, 0.028412689644028433, 0.0653099083865527, 0.05675276755937375, 0.0364475588867208, 0.03391135825950187, 0.05518631645827554, 0.05225278851867188, 0.03687985248689074, 0.03329205086629372, 0.04878075822489336, 0.10141166727407835, 0.06411643102183007, 0.13081515004159883, 0.01644504998694174, 0.033961022782023065, 0.006729564602210303, 0.020889165716653224, 0.06267886128625832, 0.06390326394466683, 0.008183408244804014, 0.004352432197265443, 0.03290354026830755, 0.05670138125424273, 0.08311238358146511, 0.013544672856369289, 0.03346734243677929, 0.04505780780164059, 0.07786131769535132, 0.08308389253215864, 0.055255566257983446, 0.03627358462836128, 0.04486532066948712, 0.014057983935344964, 0.0799793477926869, 0.025663169799372554, 0.02663781193405157, 0.0639638899883721, 0.02405598592304159, 0.014988009079388576, 0.05646066565532237, 0.04392729795654304, 0.04661146056605503, 0.05245599597401451, 0.048240047981380485, 0.035285392732475884, 0.05812994873849675, 0.08651026961160824, 0.1148640364408493, 0.032249255455099046, 0.027166115323780105, 0.05557070442591794, 0.04461143194930628, 0.02861464658053592, 0.021559696142503526, 0.032830353375175036, 0.012698413920588791, 0.038481136289192364, 0.06377842728397809, 0.01152556826127693, 0.018145922585972585, 0.0445778757421067, 0.05335916001058649, 0.05940779345110059, 0.01296321592235472, 0.04314713747589849, 0.06487449034466408, 0.060318334435578436, 0.11563224092242308, 0.0181605039324495, 0.017922332044690847, 0.05779804916528519, 0.08851530772517435, 0.038354744829121046, 0.017843881469161715, 0.03674666666483972, 0.03641342751507182, 0.03720102060469799, 0.00473967511425144, 0.019169654078723397, 0.032419782437500544, 0.017647277272772044, 0.04533667721261736, 0.03425642353249714, 0.02906708949012682, 0.033504323655506596, 0.07915883674286306, 0.025482338096480817, 0.06553290892043151, 0.013847581358277239, 0.02930835798906628, 0.026717757937149145, 0.05282930738758296, 0.036824336129939184, 0.017177588706545066, 0.013316725908225635, 0.012283307532925392, 0.05267199805530254, 0.03755367062694859, 0.03210454036889132, 0.05372140229155775, 0.04956554599630181, 0.13542302622226998, 0.19850209064316005, 0.17983330646529794, 0.15979858464561403, 0.10076564256451093, 0.23847224976634607, 0.12885264441138133, 0.11678306706016883, 0.11169413075549528, 0.18952186626847833, 0.10017869281000458, 0.14031403174158186, 0.12164538115030155, 0.10226740807411261, 0.11676241309032775, 0.15336100273998454, 0.1002284834976308, 0.1377748476807028, 0.16616874985629693, 0.09348414969281293, 0.09915196118527092, 0.11794219783041626, 0.12725316773867235, 0.11004969477653503, 0.09822941225138493, 0.12767271866323426, 0.19001392502104864, 0.1252553952508606, 0.17801740468712524, 0.07037965275230817, 0.19975396018708125, 0.1368454413022846, 0.19515105639584363, 0.11268959569861181, 0.13875090546207502, 0.09171016441541724, 0.1351819618139416, 0.10151857364689931, 0.17516990279546008, 0.13090034859487787, 0.16195404867175967, 0.19283044966869056, 0.08685648150276393, 0.1500853558536619, 0.18186190776759759, 0.24716901825740933, 0.12389307928970084, 0.13818923325743526, 0.10519154413486831, 0.23617062717676163, 0.21113679860718548, 0.10825889243278652, 0.0808692273858469, 0.11340685174218379, 0.1410169791779481, 0.18344229640206322, 0.14177554316120222, 0.11611577239818871, 0.08086344605544582, 0.12690996896708384, 0.12530269974377006, 0.1025752435089089, 0.17046882770955563, 0.19440506439423189, 0.16403951332904398, 0.1151589659275487, 0.14054103987291455, 0.14957389736082405, 0.1113039169285912, 0.08345306647242978, 0.07852238573832437, 0.1049610627524089, 0.11861023464007303, 0.0984100138884969, 0.12590588768944144, 0.0762318359920755, 0.12749748275382444, 0.14159720507450402, 0.09247082125511952, 0.12081686974852346, 0.139002597425133, 0.10926198665401898, 0.12305961776291952, 0.10191426452365704, 0.07474596728570759, 0.20671327190939337, 0.11788781324867159, 0.2096189433359541, 0.0997328847006429, 0.1309825637144968, 0.18894609325798228, 0.214137242292054, 0.11685997582389973, 0.08954747929237783, 0.1528695525485091, 0.09912314359098673, 0.11031126472516917, 0.19568828225601465, 0.20480510633205995, 0.06573387508979067, 0.179793675779365, 0.14288184785982594, 0.18914635438704863, 0.20300471544032916, 0.09113425781833939, 0.14253321656724438, 0.11843333631986752, 0.18856281851185486, 0.21660544734913856, 0.0772853814123664, 0.13284844171721488, 0.2764442207990214, 0.07334897818509489, 0.11379103932995349, 0.10101912310346961, 0.11781739827711135, 0.10514297799090855, 0.12454379437258467, 0.17717917857225984, 0.10720107224187814, 0.14617598906625062, 0.14730291062733158, 0.15990315325325355, 0.15761358314193785, 0.13805627007968724, 0.14632493810495362, 0.0962445828190539, 0.11530082003446296, 0.060615946786128916, 0.18667575961444527, 0.16966729337582365, 0.1435008880798705, 0.17732547072228044, 0.18591453874250874, 0.08809568258584477, 0.1708481097011827, 0.18038720096228644, 0.12500714685302228, 0.10282413015374914, 0.08690932983881794, 0.10783829508000053, 0.12812983710318804, 0.21381341357482597, 0.2121679237461649, 0.12777065247064456, 0.17726646998198703, 0.24588672065874562, 0.07376113731879741, 0.15201232745312154, 0.09987290570279583, 0.18506783730117604, 0.21109267050633207, 0.17067029111785814, 0.16083202528534457, 0.191582246334292, 0.08038125044549815, 0.09947742262738757, 0.14447528345044702, 0.13913772767409682, 0.08893989041098393, 0.24237636214820668, 0.14548939856467769, 0.07413789600832388, 0.10732545619248413, 0.11836542238597758, 0.11715237458702177, 0.14314063475467265, 0.13052121503278613, 0.1690258551388979, 0.09509880328550935, 0.07108564299414866, 0.22695981751894578, 0.16070255020167679, 0.0962358625838533, 0.10400802639196627, 0.23517024179454893], [0.012497422703745542, 0.014365316565090325, 0.03637651308963541, 0.007298177279153606, 0.07626316204550676, 0.018085391166096088, 0.017092165653593838, 0.035857310285791755, 0.046281193717732094, 0.08709859976079315, 0.04551612109935377, 0.026669742837839294, 0.03521729326166678, 0.07101249691913836, 0.028388315658958163, 0.026397283727419563, 0.02547946041886462, 0.023719141790934373, 0.0610423885518685, 0.007338974528465769, 0.020646876764658373, 0.062006152656977065, 0.07182903005741537, 0.07328994033741765, 0.04344554392446298, 0.07975695581990294, 0.030290276881714817, 0.07571212481707335, 0.029824907614965923, 0.07234485980006866, 0.018491470254957676, 0.11366074046236463, 0.05513528267329093, 0.040698332159081474, 0.04920553015836049, 0.03427473231568001, 0.04951919516315684, 0.020758662758453283, 0.040939058890216984, 0.044187717576278374, 0.03541644859069493, 0.039637031295569614, 0.019095929128525313, 0.03468031973170582, 0.09085662779398263, 0.05748095172748435, 0.07238790436531417, 0.01969712811842328, 0.02718949668633286, 0.01482702055000118, 0.008318910495290766, 0.02466583278874168, 0.019133552304992918, 0.012995940924156457, 0.03665858486783691, 0.010482965808478184, 0.08699678452103399, 0.050719912178465165, 0.030575962919101585, 0.0670294497103896, 0.016424935929535422, 0.061765129066770896, 0.028765115166606847, 0.04343372522271238, 0.02920193030149676, 0.046214370740926825, 0.03215885073586833, 0.027392735682951752, 0.020912804975523613, 0.037579074341920204, 0.044827330129919574, 0.0032307650417351397, 0.02539326738769887, 0.06206355035828892, 0.013638372711284319, 0.047176969674183056, 0.028700145703624003, 0.08308785560075194, 0.004106209862584365, 0.02466853791702306, 0.03861960620270111, 0.08583906383137219, 0.04791721745277755, 0.014974922232795507, 0.04387947396025993, 0.03685802221298218, 0.07292987997061573, 0.04566849514958449, 0.0457765184546588, 0.025345224457851145, 0.015792787526152097, 0.07157086656661704, 0.03377517045009881, 0.0037269522226779372, 0.035959730375907384, 0.0624232656264212, 0.011456011397967814, 0.0313949507108191, 0.09158298998954706, 0.005501598707269295, 0.023008611460682005, 0.055181971183628775, 0.04639855324057862, 0.058707848002086394, 0.017929315654328093, 0.04430700668308418, 0.00960658031544881, 0.03249735171266366, 0.018792515038512647, 0.043125466763740405, 0.07052555156406015, 0.04797930552740581, 0.05942674419202376, 0.026776777231134474, 0.07018561082077213, 0.11227875016629696, 0.1029530783125665, 0.022204472188604996, 0.06335545505862683, 0.06537772584124468, 0.028274360738578252, 0.056014961446635425, 0.07202427426818758, 0.04959447862347588, 0.04415830255311448, 0.035267135899630375, 0.06052121163520496, 0.0671260550734587, 0.03509123947878834, 0.02268956774059916, 0.006540545155075961, 0.027003525610780343, 0.02128111431375146, 0.021419873664854094, 0.023901773201941978, 0.014087807139731012, 0.05757410610385705, 0.0438556658627931, 0.07180418295320123, 0.011524936508067185, 0.06044795423804317, 0.04168170751654543, 0.031172462258837186, 0.06020149441610556, 0.04112467373488471, 0.14300556387752295, 0.010393434968136717, 0.04032638629723806, 0.00896232006198261, 0.004618394732460729, 0.024964678959804587, 0.0761599293036852, 0.02952913950139191, 0.020480492821661755, 0.07441186724463478, 0.03221666775061749, 0.01971526249690214, 0.011733309311239282, 0.09620455137337558, 0.037512700364459306, 0.054187552668736316, 0.03589906722481828, 0.024053201013884973, 0.023461857745132875, 0.01987246607313864, 0.07284462946699932, 0.055861151340650395, 0.015214973609545268, 0.031108045695873443, 0.02599899162305519, 0.023247065364557784, 0.047997966830735095, 0.012874689764430514, 0.07909501946414821, 0.046729128080187365, 0.003222101163373736, 0.02899937222537119, 0.05006270330341067, 0.036300342762842774, 0.015798383319634013, 0.08166218249243684, 0.0412124735157704, 0.03889849045663141, 0.014930928646208486, 0.04287871008273214, 0.022677927154290956, 0.04871346027357504, 0.10775319300591946, 0.08032034238567576, 0.08174466478521936, 0.054698565872968175, 0.023796970817784313, 0.01979118605959229, 0.0413889525225386, 0.046094999997876585, 0.023843503477110062, 0.05402796494308859, 0.04530011901806574, 0.06790674247895367, 0.03298640847788192, 0.006507100270027877, 0.034900934260804206, 0.0333486693125451, 0.053266907343640924, 0.029138868158042897, 0.05289999695378356, 0.022236189724935684, 0.1242253981763497, 0.03247481639846228, 0.044695636024698615, 0.03382843438885175, 0.014571738447557436, 0.024517401398043148, 0.02734356097789714, 0.06611679360503331, 0.06227283971384168, 0.10302986091119237, 0.06608559371670708, 0.032954781854641624, 0.04026413866085932, 0.0643769174348563, 0.04511517581704538, 0.0477077499817824, 0.03718052990734577, 0.020365628770377953, 0.08331535354955122, 0.026100135219166987, 0.04580020409775898, 0.011091000906162662, 0.030540833358827513, 0.06787569844163954, 0.04182417018455453, 0.03229884576285258, 0.05185564674320631, 0.0077502880776592065, 0.027456432362669148, 0.032521367611479945, 0.06336102116620168, 0.030979713519627694, 0.06852951570181176, 0.00850085170895909, 0.020177104706817772, 0.015827534880372696, 0.022035705951566342, 0.05765519686974585, 0.04822153510758653, 0.04284504997485783, 0.013116070513206068, 0.007038621333776973, 0.01436819702576031, 0.015297978188755224, 0.05286189138132613, 0.02334825534489937, 0.031401678279507905, 0.0535293307621032, 0.02022247590502957, 0.10050255121313967, 0.06891814875416458, 0.06448098880355246, 0.0435291765461443, 0.04457612056285143, 0.021979406628815923, 0.014128192033240339, 0.011137493675050791, 0.028391918785928283, 0.03758497070521116, 0.05655682944052387, 0.0344889940606663, 0.049568091562832706, 0.012762517853843747, 0.03400004861759953, 0.016897867681109346, 0.052249719738028944, 0.05161581801075954, 0.045769019052386284, 0.06497009380836971, 0.023885360606072936, 0.03271198824222665, 0.04473550048714969, 0.05830586000229232, 0.041009418200701475, 0.031215759154292755, 0.0534102160600014, 0.0612587060459191, 0.1091462116164621, 0.022977663902565837, 0.02848103587894002, 0.08876605716068298, 0.04451497872651089, 0.029450547917804215, 0.010268041696690489, 0.06932071933988482, 0.08000674788490869, 0.011051264464185806, 0.04825825286388863, 0.06378086894983426, 0.050389845710014924, 0.045447023439919576, 0.06439403878175654, 0.028536951140267774, 0.07026853840216063, 0.028273535099287983, 0.03481128653220367, 0.02851648641808424, 0.05597767965809908, 0.018338988593313843, 0.05203450062253978, 0.06916642683790997, 0.018368919409113005, 0.04562706846627407, 0.04470241554372478, 0.020430115837370977, 0.0799889511836227, 0.08630549622466788, 0.10656355996616185, 0.03824202001851518, 0.08930898271501064, 0.018403073045192286, 0.033196796211996116, 0.08336391969351098, 0.0313131289294688, 0.09830098497332074, 0.07742509071249515, 0.049459700894658454, 0.0072920016827993095, 0.04106537613552064, 0.05217976118728984, 0.046820761053822935, 0.01454250803362811, 0.03586012673622463, 0.028662494696618523, 0.04437531024450436, 0.016673559111950453, 0.007782032516843174, 0.053843793575651944, 0.052915745327482, 0.06086382411012892, 0.013648810090671759, 0.06883003356051631, 0.09780507447430864, 0.08756210809224285, 0.015429820723511511, 0.06390978742274456, 0.04756644877488725, 0.01921592698636232, 0.0244615956034977, 0.09742669790284708, 0.025802730669965968, 0.04024175548693165, 0.03598279261495918, 0.025818978137976956, 0.01995956823520828, 0.10179534277995117, 0.2091769053367898, 0.1455408293986693, 0.06524623211589642, 0.1735871096025221, 0.08694575444678776, 0.16635164472972974, 0.11754151972127147, 0.09535577191854827, 0.22839798097265884, 0.21237617038423195, 0.1998754942906089, 0.2435412519844249, 0.10514041015994735, 0.29615676146931946, 0.08272197679616511, 0.15147673431783915, 0.11201827859622426, 0.0773537480563391, 0.1116611719771754, 0.15839389205211774, 0.1187341361946892, 0.229693993460387, 0.12888483877759427, 0.148876441817265, 0.20542318176012486, 0.09683909505838528, 0.1244260897510685, 0.21269710472552106, 0.14518765616230667, 0.11853009011247195, 0.18979229003889486, 0.16470327536808327, 0.1552649529185146, 0.12548676721053198, 0.12289360674913041, 0.08807874677586369, 0.1448676866129972, 0.1406376823433675, 0.12134812131989747, 0.15432710089953616, 0.11771752004278824, 0.14137236401438713, 0.13267409638501704, 0.19663990853587165, 0.21978932025376707, 0.1499033664003946, 0.19262610672740266, 0.14710826013470069, 0.1614019353291951, 0.10764938881038688, 0.07127351767849177, 0.15782585222041234, 0.10699779057176784, 0.18821488483808935, 0.11053715963498689, 0.13413562264759094, 0.16886179597349837, 0.08833419400616549, 0.1445415275520645, 0.11389989755116403, 0.12922717665787786, 0.15618359815562144, 0.16686043149093166, 0.11767301344661973, 0.11696682282490656, 0.139029418642167, 0.10329429554985836, 0.1336911800899543, 0.12741443642880768, 0.149866140272934, 0.12158413170254789, 0.1457913190824911, 0.1927489321678877, 0.10435827556648292, 0.11510648124385625, 0.11832107164082117, 0.21016488200984895, 0.11481667999760248, 0.12453512608772144, 0.19452444626949728, 0.16745728149544448, 0.10211057000560686, 0.13991935760714114, 0.2059328739414923, 0.06601580957067199, 0.24186843627830967, 0.2085427995189093, 0.09874559080344625, 0.10236752379569225, 0.11176841973792762, 0.17551479366375133, 0.13600196078186855, 0.1014845610188786, 0.11657558483420871, 0.1474673260236159, 0.1488304731901735, 0.13171795784728602, 0.12577213783515617, 0.11580129474168643, 0.1838693133322522, 0.126809986832086, 0.2287229971261695, 0.19277060288004577, 0.08866960764862597, 0.10336951963836327, 0.14733737596543506, 0.10727134620537981, 0.19176701141986996, 0.12621240952285007, 0.12259565672138706, 0.2248556210543029, 0.10601991452858783, 0.10174147028010339, 0.15789445635164157, 0.2682171872584149, 0.27639339852612466, 0.10168193519348279, 0.15239724976709113, 0.15043578314362094, 0.1114939438411966, 0.19603072403697297, 0.2693490218371153, 0.1317604977521114, 0.17052242561476305, 0.16645995376165956, 0.12416996716638096, 0.12261637748451903, 0.14371268218383193, 0.20910916209686548, 0.10399269362096675, 0.18135834572603926, 0.11176998566952534, 0.1466964720748365, 0.15039339166833088, 0.19121789635391906, 0.25052753335330635, 0.20757542486535385, 0.2154706887085922, 0.13970668776892126, 0.16562208387767896, 0.14489876775769517, 0.15650546760298312, 0.16556501272134483, 0.1716730513726361, 0.3408251458313316, 0.17200863570906222, 0.08674482538481243, 0.12162680519395508, 0.13375534617807716, 0.13044771272689104, 0.1321242837002501, 0.08060348656727001, 0.14299757836852223, 0.2925991133088246, 0.14342314068926498, 0.10962394691887312, 0.0837227406736929, 0.2242610717075877, 0.18214626907138154, 0.14394985773833469, 0.08405103711993434, 0.13295491022290662, 0.12549463397590443, 0.18297043890925124, 0.1766737611615099, 0.11929400498047471, 0.09063992067240179, 0.08064016350544989, 0.10662824555765837, 0.1312106108525768, 0.134237059392035, 0.10488266227184795, 0.1854286398156546, 0.10458935066708364, 0.17518112406833097], [0.02103921870002523, 0.03296331284218468, 0.006881551344122272, 0.05586308834608644, 0.06924735804204829, 0.0421679960709298, 0.037026196587248705, 0.03916760804713704, 0.07049724605167285, 0.07384053969872184, 0.035145368019584566, 0.030909387605788652, 0.029784827929688618, 0.05961326816759538, 0.019097517324553337, 0.03947497592889704, 0.027180702236364596, 0.02612380230857525, 0.04685030966356862, 0.0684934102173429, 0.042395512573421, 0.038446147736976855, 0.05820261612825561, 0.006119122626842, 0.04993560680304654, 0.031261709227692336, 0.04278157037333585, 0.07962995208799839, 0.008391071369260317, 0.007864858980610734, 0.07218423677841201, 0.010326245555916103, 0.023208713027997874, 0.05460003834741656, 0.047271745643229224, 0.03899897725204937, 0.09107026984565891, 0.03927107456547674, 0.017086803636630066, 0.06301506160525605, 0.06037212529918179, 0.016720752282708418, 0.041267210617661476, 0.03504497399262618, 0.018809669782058336, 0.019733664048544597, 0.032395224770880304, 0.015125267436815193, 0.04997909294615965, 0.02343687148822937, 0.037401018271339126, 0.05550778143515345, 0.1666034702793695, 0.023725188439129852, 0.017771666789485607, 0.029559728973254096, 0.06927214577444829, 0.04204924131045118, 0.05231797134911176, 0.04883787019934971, 0.02315563277079491, 0.046408186317421496, 0.06576030296855606, 0.03806295833783224, 0.027617962659860495, 0.1013428033911623, 0.027562203249544837, 0.05460428343212698, 0.035828826657962054, 0.012691783758782549, 0.031249645617208444, 0.04380542988656089, 0.028914776667079423, 0.05457330618810374, 0.010569410242169397, 0.03227363129553851, 0.14924200891982764, 0.011394332432246301, 0.017508477103547193, 0.0802133469551336, 0.031125352579692844, 0.06446883984608576, 0.016710202653484885, 0.038208419282455, 0.09756198400282301, 0.04780802526511252, 0.07650879808352329, 0.01670295743679162, 0.01834870701713953, 0.010017974109359784, 0.07336031820159405, 0.03999073145678267, 0.06268102093599737, 0.018451670730428305, 0.03133013153274078, 0.005228046784395701, 0.03537314427376259, 0.016449668000859674, 0.054071933482191525, 0.034635831689229235, 0.0337581975327339, 0.04160025680903345, 0.037862812241655774, 0.03576139140932355, 0.040182921729865484, 0.04087455141416285, 0.058770737596205436, 0.026094875247508753, 0.031594354659318924, 0.02061937648250023, 0.08628674957435578, 0.02148702504200628, 0.04557081367238425, 0.07005266248597763, 0.019460574112599716, 0.021583932830253616, 0.08777877068496309, 0.08565201293095015, 0.07095282824593596, 0.06807874262449332, 0.004785960081790108, 0.027563338735490106, 0.04303509173041675, 0.01833781599998474, 0.06377122845151462, 0.02927705234469613, 0.0410866089805495, 0.003185229179507587, 0.003393333649910346, 0.027338536638126243, 0.034719545947154984, 0.075371812999947, 0.057407486528973095, 0.06961624254472554, 0.08609605472884141, 0.05586813495028764, 0.025723651124280877, 0.03338479335070588, 0.023781105555826798, 0.01310883086262038, 0.06523405347252265, 0.0799468120385427, 0.08687905763508752, 0.07013702983385883, 0.022875653849041555, 0.027333573525538668, 0.061584865106851794, 0.06383905332768336, 0.03049903560167877, 0.0343221629736945, 0.03363455572980456, 0.02468328439135803, 0.03253218441386707, 0.04537627079116646, 0.04341631072747987, 0.03719401473063044, 0.03986197625636123, 0.02475751214660704, 0.03452508841292001, 0.05292122237733565, 0.068811865785392, 0.056251027490361594, 0.07439622277161106, 0.044234966408112086, 0.05837252341734711, 0.02418799173028674, 0.03695549588883296, 0.022558283671969548, 0.06100851322116796, 0.028944225086888764, 0.03532025140884798, 0.03405821444175672, 0.05103446776047349, 0.08018541251658462, 0.006888180578243919, 0.03236969860154204, 0.04712257767096162, 0.02858252828445984, 0.025837405664788093, 0.01283269069972448, 0.007243175323310425, 0.130486007547006, 0.05330923944711685, 0.03988101234426722, 0.03716978360898793, 0.025767259721760638, 0.0361315152986208, 0.015865497589402366, 0.027260460847173817, 0.057064959401031956, 0.019531779471435584, 0.06446512168622576, 0.014964573911129264, 0.07552007184131071, 0.024865127270459197, 0.08649087729281746, 0.04000162618467584, 0.031593953899573535, 0.012858909849455813, 0.03005494741955772, 0.07250169786857441, 0.054257210649666376, 0.03179791092406958, 0.10032477715867572, 0.032870195573195815, 0.029832355066901073, 0.022801826853537932, 0.05727156218199525, 0.008537318062735721, 0.028717547211272176, 0.01130993725382723, 0.02089985635393532, 0.12854943255661055, 0.021643597792717628, 0.02081575246847933, 0.03678352542920038, 0.06663368461886421, 0.07322431963984855, 0.037904814089415595, 0.00787482138548512, 0.07010199304204434, 0.031665389324189164, 0.04163479636190459, 0.025153748501907103, 0.010084075347549515, 0.11131598424981348, 0.01564876078191446, 0.019563782734621782, 0.04319636042055208, 0.010369628726039082, 0.028991772633162327, 0.03595288406359032, 0.016887455349205993, 0.04816983338969294, 0.08758364521781914, 0.07590805180370808, 0.05391673927078955, 0.028060859694960527, 0.002302459824932157, 0.05749079260567669, 0.04963620216585696, 0.0428119910066016, 0.025459674761805218, 0.02581525255664019, 0.05197396363655571, 0.025710259069455788, 0.059884686415898614, 0.1009280096332077, 0.04719200558611192, 0.04825518779398408, 0.042238299720338546, 0.040654541735420935, 0.07247302870382555, 0.025147993146674708, 0.01807197870220989, 0.03141177890938707, 0.05052549175161403, 0.023053401928336825, 0.14539023279212415, 0.012272847889107652, 0.047539820516249165, 0.04718413511000108, 0.06422351551009342, 0.043627025006571785, 0.03248997847549617, 0.12342017536866479, 0.0966462331416551, 0.07990825004526414, 0.023668087596888654, 0.0394094071816653, 0.04591583441651892, 0.03485508066660259, 0.04153007932472974, 0.035125170470564626, 0.0382213883131044, 0.04095283315109555, 0.0017046587117874878, 0.04090619659109507, 0.06996407231781632, 0.00318244658956246, 0.02745405934547307, 0.026837464502023067, 0.032712886240915395, 0.03521721904689912, 0.014384252463059966, 0.043732922058552504, 0.05470724900078494, 0.052031832601642236, 0.031657726649427786, 0.007598717402288457, 0.02108093296556035, 0.033167852452606894, 0.05117025109939277, 0.017131612657976802, 0.0033504794919281267, 0.05056081798102241, 0.021669715824828018, 0.0783615697582718, 0.045895874354755506, 0.03584979604056571, 0.04399829551402945, 0.029695259981963318, 0.005622824355668854, 0.02726017512031831, 0.05329994033672847, 0.03277970550698228, 0.06393355841282755, 0.03485637571429834, 0.05731390541768633, 0.04492987638514023, 0.0645889638690278, 0.030743933202757034, 0.029623748487210833, 0.049022705788956955, 0.004665699689212488, 0.021886226277274545, 0.05452891462482512, 0.03273186295700725, 0.10151834358111955, 0.03304503443359863, 0.025287073476647492, 0.06219269889697898, 0.055169989209389314, 0.013688067847397178, 0.0579533472773619, 0.12360635795630515, 0.03777473044465296, 0.043917683433392085, 0.05469892581459135, 0.09121998329646885, 0.03265280196501408, 0.06337147060548887, 0.08899643464246765, 0.0503301176649984, 0.05647648824378848, 0.03383351810043678, 0.045784296162310056, 0.012085294183634687, 0.04162624682066962, 0.04403637511131819, 0.0027472667306938092, 0.02350718070374569, 0.02349135811527958, 0.04225594057061244, 0.027672072646964807, 0.061115026255720295, 0.02584800353361061, 0.05205078705330379, 0.02417438259726623, 0.02539224507927429, 0.02187574158597272, 0.025230317733075935, 0.1667311048367992, 0.16872372681973502, 0.1521811808925122, 0.1660854957299307, 0.1846616153488867, 0.21221260103629902, 0.10184664002736099, 0.11242622975260019, 0.20010536711197346, 0.24724217917537317, 0.10024348230217583, 0.1522684723022394, 0.09102275755139999, 0.148921727668494, 0.07099472990375943, 0.12452400871552527, 0.13997209462104365, 0.1766226123436354, 0.14138199709123, 0.22756095713702962, 0.137075477396138, 0.11069180094636977, 0.19046428991714492, 0.08272181352367625, 0.1245973032200709, 0.1735218896646984, 0.15880808467045426, 0.19148216029861942, 0.10542279735091142, 0.1515532349003479, 0.21625611843774095, 0.08246587647590786, 0.10605152259813622, 0.08531777188181877, 0.3300032968400046, 0.11234226316446438, 0.25453358714003116, 0.1881969693931751, 0.12917629501316696, 0.11992933534202166, 0.09377503447467461, 0.1371889517758973, 0.13789198826998472, 0.16516125469934195, 0.13706664583878592, 0.09450940444367006, 0.075074137566844, 0.0917784494231455, 0.139634239312727, 0.1931498254998587, 0.17433779197745025, 0.1837558241095394, 0.24166688381228596, 0.10086494192364626, 0.05313638583174907, 0.09904351114528254, 0.1499153595068492, 0.1773758328636177, 0.2424050387344323, 0.11996524044661783, 0.1289579996955581, 0.1180735653906595, 0.19598762009991333, 0.12979542429093271, 0.1926843504770659, 0.1847313772304915, 0.11883917235536501, 0.12164126223069616, 0.2181665549869649, 0.13225086440797895, 0.12224482867168263, 0.1686163677368313, 0.07470983953680843, 0.12807076214812696, 0.16712807962903753, 0.08715478776139207, 0.3573232964845374, 0.22372700739651918, 0.06574622442713007, 0.11259568433160894, 0.10811766915139742, 0.1326168025843799, 0.22796686738729477, 0.10991818620823324, 0.17383541737217456, 0.19681919657159597, 0.1358049057307653, 0.17432670429116115, 0.07193789570010267, 0.1797722277115099, 0.17257985193282366, 0.25391591247171164, 0.10653644189005718, 0.16645038005663082, 0.17722618620609865, 0.16826654900796711, 0.11461931324447505, 0.12032161976094358, 0.1139617852459196, 0.11869674679473974, 0.09599020428140648, 0.14740687067387626, 0.15906513493973762, 0.11192632649908774, 0.11236063874093816, 0.10914993719779886, 0.12804008176317438, 0.15100242773769423, 0.16315781220328063, 0.07689375008339994, 0.14625035226345062, 0.10322747999452986, 0.17923308711033314, 0.12757392396451905, 0.19857943727402017, 0.09974023938411847, 0.11527600261615589, 0.156690425646957, 0.17797388514736667, 0.1778454490704462, 0.1019876406644471, 0.24789188493741676, 0.18335767672397196, 0.17824619397288188, 0.2246915767318569, 0.13508891133824363, 0.15164760639891028, 0.09598523189197294, 0.16424082830781117, 0.1166543118597474, 0.11120135211967863, 0.14672926015919074, 0.10569915830274113, 0.15934434573864564, 0.18926601827843115, 0.1380956484354101, 0.13256819191155955, 0.1537646123324521, 0.06826034616096877, 0.1515972294146195, 0.15586437075398862, 0.15756387409055606, 0.234419203188736, 0.159402871504426, 0.12866177887190133, 0.16412953584222123, 0.11564839005586691, 0.0738544252817519, 0.1247768139000982, 0.24592805828433484, 0.13722757314099, 0.13106093450915068, 0.10228766870568506, 0.17767335986718535, 0.1280086740734987, 0.21324590808944777, 0.22630708379438147, 0.09240097031579353, 0.1084516875562258, 0.1318212054320611, 0.1167088003421668, 0.09520755760604516, 0.14236526854801923, 0.12082192377420142, 0.17232251964742318, 0.10374492019764148, 0.13373046938795596, 0.16203011880861595, 0.19458464928902686, 0.1949378225253895, 0.11709200829500332, 0.12477694748668, 0.11148599543957971, 0.1553569347015582, 0.1264394770259969, 0.10613494741846807], [0.12296284170588478, 0.014271926556830294, 0.010741747137217317, 0.020446181479201186, 0.06760157135431655, 0.044680154824163765, 0.0629449138068594, 0.04376487893750891, 0.04327238231780939, 0.020949554273101967, 0.022415548264689278, 0.09987056051613763, 0.03802703467954416, 0.03733258483407553, 0.026036214039777406, 0.053096814517630264, 0.017366326137562282, 0.011122524556412827, 0.04018998697574716, 0.08570552177843638, 0.031119365303311497, 0.04365733060694765, 0.02157840754080098, 0.036090140565647744, 0.050711752264760435, 0.09552193878334947, 0.07152104619308375, 0.06318552550510503, 0.04122844824451022, 0.026610434106260072, 0.06330672564217821, 0.008888098800525768, 0.03848519212624524, 0.05659235604980495, 0.020547519889078103, 0.028468089112720918, 0.043935309440712444, 0.011740151912817964, 0.03440165441134013, 0.017980048869503662, 0.049019158323062584, 0.029861161528970115, 0.0383825308381347, 0.035919476285926066, 0.020274960588722024, 0.04709692904725671, 0.06919169696629979, 0.036141296804999, 0.021226286298769992, 0.07436001338646747, 0.01055906748661073, 0.05407263852248434, 0.015024146105133696, 0.03229730951716192, 0.039215435754158534, 0.03755052763153799, 0.023629622082808055, 0.03525974781950936, 0.006317602137642098, 0.03417727719352115, 0.014631158501288155, 0.04025476904644165, 0.016264016048808116, 0.040176268375944346, 0.08183819023543037, 0.008853756844473537, 0.14214274298865348, 0.027669966802932322, 0.022265773586696014, 0.05640071125526447, 0.04616154095856473, 0.008662012787681306, 0.020054858141520526, 0.04557676940748934, 0.08549631034838967, 0.05452025376143865, 0.06918650935404003, 0.049374231457477435, 0.06552284539793618, 0.051096615206915885, 0.04885655005637091, 0.01381090627546655, 0.02831491168763023, 0.06196731606905814, 0.05565727966313716, 0.049928222433663905, 0.0698988969088532, 0.05033104906033259, 0.06637396261794493, 0.03174458019202575, 0.023522559858975, 0.04380809419672005, 0.061570474863401614, 0.006875892468087841, 0.025207285179931205, 0.015073712293087738, 0.03232621987990569, 0.03576737311959732, 0.017873684264486656, 0.016612083309155423, 0.03961488189816009, 0.03237462275137659, 0.034625044572749175, 0.046808311526547186, 0.00828403604828054, 0.005911782336625038, 0.01968146323633846, 0.01776334916939959, 0.01757848574925447, 0.04109115463506896, 0.03671641301480122, 0.05331529537215829, 0.03057651025301311, 0.017559536863700487, 0.013886010692658601, 0.008272190443676664, 0.059622559856506996, 0.009518337101326324, 0.022598535906581674, 0.05654244661855046, 0.075484597182367, 0.02003684621740831, 0.042419821620569564, 0.01988646854442777, 0.017628489804337732, 0.03773081385588739, 0.05353031410777476, 0.03544438673998229, 0.04097556142369285, 0.040668887450010516, 0.012544914588943357, 0.028841676976298913, 0.07266845103004016, 0.04140680859563872, 0.012570377675729105, 0.026712459002737887, 0.013987005859235069, 0.0266965436458122, 0.015688766252424102, 0.020791794086107984, 0.06012125340930652, 0.005450928574646241, 0.028168031385575887, 0.034963912912644446, 0.05935962064540945, 0.008546810131520033, 0.05793804048153106, 0.028619923250516877, 0.01460070818211534, 0.011267855625192169, 0.03492443065624684, 0.035582741620601155, 0.05438348336610943, 0.04372741903353017, 0.019329648130224086, 0.028791613549401518, 0.08667688176501542, 0.02388311560935108, 0.054345915850717574, 0.001102970252304658, 0.028201953100506216, 0.06959104663110338, 0.029481634628609754, 0.014575487221009098, 0.026398042573418934, 0.05315738861099817, 0.040378262419835664, 0.06786582787754014, 0.02305005484231515, 0.020084156276425347, 0.08589016812038608, 0.054949541663518175, 0.06986129970755428, 0.04133690570597537, 0.04305486254452262, 0.038838825494167395, 0.0716156700218562, 0.02182472078857245, 0.015200422876660014, 0.029579009969893377, 0.032261281958199106, 0.01925337204738753, 0.02019452291278867, 0.05234734184341505, 0.08361161148059182, 0.026332676061429083, 0.02952676462882664, 0.03326593097881414, 0.07557402597740293, 0.07806759764207527, 0.034926341686514206, 0.05556959491514135, 0.02191522013163194, 0.02754626562818885, 0.017269210547965486, 0.018863651748688426, 0.025728781220095698, 0.015011550931376405, 0.04468465594982263, 0.05959067348157987, 0.03851394292723853, 0.056287489205715246, 0.0646443577716127, 0.04051027564855758, 0.030398235248867422, 0.010751908994279802, 0.02951018133899197, 0.04033436067402363, 0.02652770133863669, 0.015463248910236871, 0.0470382585626794, 0.06437768926844001, 0.02108971071720589, 0.0781753945921082, 0.05583653059147764, 0.034104606093023904, 0.03540470039297361, 0.05306647923134733, 0.07188266507000662, 0.06043074754416011, 0.04796156077645719, 0.09075659370864742, 0.06764131336240098, 0.07985887496033683, 0.013415354551398195, 0.010752313464763574, 0.07680343071115203, 0.06116897668107413, 0.07978345049195923, 0.014626274241891224, 0.014896927150402917, 0.02799756377498852, 0.08575851112254895, 0.041680635113152675, 0.03835210649413057, 0.026039735530503094, 0.031470004105358385, 0.026708187942858785, 0.013107544164085994, 0.017277368606301025, 0.059913170043728314, 0.026293062073818874, 0.04769418723299168, 0.038132746194605716, 0.06025516653608065, 0.04548931472527329, 0.09836244222242385, 0.049190241916221566, 0.039580995435244404, 0.09965552322682925, 0.05161850087461062, 0.009411718310730066, 0.022900456424395088, 0.04106453008716926, 0.03776762438064907, 0.014676557530037826, 0.022969871351961046, 0.021233872903394513, 0.035866550024366006, 0.02608932769362582, 0.08483536847052164, 0.03629774153523613, 0.07059650830342434, 0.029806580278091133, 0.03563855112588499, 0.06389534522895701, 0.020335723929747473, 0.021009799966122955, 0.017845796210167464, 0.057013855112018064, 0.027376822181395255, 0.037746918460470624, 0.05258970501017757, 0.039843619233579375, 0.03524140935041942, 0.07941452888189815, 0.04185002289887052, 0.028890211578982417, 0.009752441092132358, 0.09706576922326349, 0.041606238519307226, 0.003944954623875674, 0.07827335808542557, 0.03114742590696551, 0.03372081926499959, 0.03207186731742695, 0.012002544717688579, 0.012938154522998957, 0.06620876796660013, 0.09819692102610134, 0.0010869133075175341, 0.019036139856325462, 0.07775337231578305, 0.035691703742486425, 0.019827901960525196, 0.037070298712933436, 0.05560430516197812, 0.028404119693732355, 0.018843511716113426, 0.0199965902720578, 0.029502533507184125, 0.0638500000059139, 0.01574807127326494, 0.01634917007322656, 0.01808707955206046, 0.022738126463082153, 0.090457151964074, 0.03802241481025703, 0.027333853686286602, 0.007604955617352971, 0.04346174871898256, 0.06460114251240157, 0.09491512915701605, 0.03129864591755904, 0.01134907070081681, 0.02384673738561105, 0.014368383490364067, 0.046769968466833234, 0.01965960142115364, 0.015391268934763502, 0.027975961711490527, 0.03540648154739756, 0.038648579647997394, 0.031702055130153894, 0.009559550417179707, 0.030265754467109218, 0.06133588198281359, 0.04244364827172831, 0.08124897693051025, 0.04773742475663312, 0.029121913794369902, 0.027665782945405226, 0.07865436185966246, 0.07231910727568902, 0.042040146290673874, 0.055155736263259314, 0.07242590974783525, 0.04447536288353149, 0.02224236995971296, 0.008584565966884838, 0.040912527110776864, 0.023568615688418504, 0.04210468345263507, 0.05063105112640187, 0.04398902237880975, 0.02389332941675093, 0.0820974595262669, 0.02962039397971239, 0.07019426426268183, 0.06474633628386073, 0.01534234470454976, 0.061684646861976944, 0.17067952343495563, 0.12955735815921798, 0.11689525752444752, 0.135630352597218, 0.11702474002959207, 0.11959835974266753, 0.219695319829043, 0.12252159038325772, 0.1457268264493905, 0.12681145628448576, 0.08619825588539243, 0.23361520492471755, 0.1301801684894599, 0.20042085408931598, 0.18731553544057533, 0.20678006520029157, 0.06010627686919179, 0.13939115626271814, 0.08938953542383388, 0.153008779452648, 0.21556215098826215, 0.1100956040318124, 0.12159220626926981, 0.17822183668613434, 0.1562320307129994, 0.27156602474860847, 0.2111675383639522, 0.1782283972715959, 0.11567772715352476, 0.15258519124472514, 0.16044193762354553, 0.12901504116598517, 0.12921077519422397, 0.11086844693636522, 0.06156922063382808, 0.3060907940380275, 0.1511565866530873, 0.09701765578938648, 0.1196342203184031, 0.19209784601116553, 0.14276987261837348, 0.13620710524264723, 0.1409783578128554, 0.146630673261825, 0.139914785977453, 0.19846450828481466, 0.08553800420486368, 0.17597342608496547, 0.05539703073736746, 0.17076976859243587, 0.11516767131979577, 0.1139617852459196, 0.12875025771791115, 0.0815075560240075, 0.09076523230760358, 0.1223485215450637, 0.11632196328719147, 0.09715867126942612, 0.08314143124152906, 0.11200847482541576, 0.17883315857034177, 0.16117967694299296, 0.07563730890979059, 0.11364599398802966, 0.22804940905189142, 0.11638341311481781, 0.20181539410259575, 0.1459760990110226, 0.11452641861978918, 0.1493986911373213, 0.16286784026306123, 0.11331446919939481, 0.09756950195878744, 0.3038086602464318, 0.29202938138041645, 0.16605864482698962, 0.09626519968151115, 0.13016958546359092, 0.13234755140729249, 0.0911574276688043, 0.1740207613329403, 0.08568908320739865, 0.12074242491507903, 0.20004474848974496, 0.1192607196571771, 0.14212393696652725, 0.1774167103576474, 0.08839635629556142, 0.18601248739287257, 0.13341876736376435, 0.08554485422791913, 0.14520238037221134, 0.102809643431101, 0.2915522991679609, 0.09074778441572562, 0.09118131740251556, 0.07647356833331287, 0.15548887371551245, 0.19234220555517823, 0.15904172760201618, 0.13297922298079357, 0.08915762911783531, 0.15966961422236636, 0.21737083909101784, 0.10555270288023166, 0.12827957281842828, 0.06725791245116852, 0.19126745697576553, 0.08914271194953471, 0.09519017650745809, 0.2010638508363627, 0.12035810374072753, 0.17443336575524881, 0.13178133725887164, 0.08856959582772106, 0.10189545108005404, 0.2002835864550434, 0.1462874299613759, 0.09169955170364119, 0.1894720533164218, 0.16088226868305355, 0.13103236182359979, 0.15700922260293737, 0.10617301217280328, 0.16650065314024687, 0.12152568757301196, 0.13544294546591118, 0.12627261254237965, 0.19705512531800196, 0.07501377127482556, 0.20047605503350496, 0.11869362235302106, 0.2932067244546488, 0.16128034185385332, 0.10262156836688519, 0.20176941063255072, 0.12798467301763594, 0.272011996130459, 0.108990909793647, 0.11619089258601889, 0.12676286045461893, 0.13389844709308818, 0.17038870544638485, 0.09226929847500287, 0.133129493042361, 0.07679503702092916, 0.18078517023241147, 0.07939348157378845, 0.13866113527910784, 0.13848058559233323, 0.12317125903791748, 0.104683596000541, 0.20139422529609874, 0.11321723301080056, 0.10259597169351764, 0.15082422323757783, 0.16865427664015442, 0.1486883667530492, 0.19996219198219478, 0.14601353293983266, 0.15448407997610047, 0.1497952057980001, 0.10033020967966877, 0.17616144177736714, 0.1451357948826626, 0.13868728856323287, 0.18123739049769938, 0.1731066728825681, 0.10040777895483188, 0.0783232155663427, 0.22380515554687008, 0.08258176283561625, 0.15145984303671867, 0.2124871956766583, 0.10916867642663419, 0.135509560641367]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.06682918858132325, 0.07305794497369789, 0.012764828716171905, 0.01897421319881687, 0.04452971035789233, 0.0654463967657648, 0.07941852905787528, 0.04906169451714959, 0.05514866359590087, 0.06380574573995546, 0.04261285794200376, 0.057186441554222256, 0.029588119832624216, 0.034875905330409296, 0.026193107769358903, 0.017841415683506057, 0.021696332951250952, 0.010299288896931102, 0.022761196123610716, 0.008649696846987354, 0.042645790745154954, 0.023460939337383024, 0.029793464673275594, 0.09273009796743281, 0.024678401059645694, 0.027397847225074656, 0.020866686063527595, 0.028009477100567892, 0.049257120554102585, 0.05226791348832194, 0.022263836581259966, 0.017241806745005306, 0.044594418213819154, 0.06470090200309642, 0.04355094373750035, 0.01835787439631531, 0.021450906569953077, 0.02587641851278022, 0.05161550630873535, 0.09676224566646852, 0.021180213771003764, 0.04673019306210335, 0.028444731869967654, 0.03258539269154426, 0.06897490820847452, 0.009133184721576981, 0.016694574878783897, 0.029590208978333976, 0.033928743068827316, 0.07597428106237203, 0.021026772883487865, 0.029651107761310413, 0.023774769470037427, 0.01779860489477869, 0.02359438676649006, 0.016334507090505213, 0.029397404578048736, 0.055485079137724824, 0.03827356871624943, 0.020450539741432294, 0.030317641721921973, 0.03405143121199217, 0.02917140391218709, 0.029805576523358468, 0.0009956730923477153, 0.019775597247644328, 0.0673168092907872, 0.030627902124251705, 0.028568306879606098, 0.02791271217574831, 0.06967051580431871, 0.07101182898622938, 0.1271609336254187, 0.040386756299994886, 0.05653920343320351, 0.03808678869972937, 0.036542034285957925, 0.044819481918239035, 0.03147277231619228, 0.033510461216792464, 0.031545551028102636, 0.04551753489067778, 0.05104731062601786, 0.054380733708967455, 0.0261371591113857, 0.035499257428455167, 0.04666610861022491, 0.02771835854218807, 0.028339944328763522, 0.028081550772185437, 0.037598043636535294, 0.008958571288530948, 0.05548414774239063, 0.012084834979759762, 0.08469243824947625, 0.03689977173053194, 0.02304288569575874, 0.02061651921394514, 0.020968761054973584, 0.03659602181869559, 0.03167604285408743, 0.07449285782058723, 0.044820791808888316, 0.019500520211295225, 0.04450593936780933, 0.02485864832124207, 0.04627766480552964, 0.05701604444766417, 0.01911296883918112, 0.03262143138272222, 0.005252415667200694, 0.027040477143600583, 0.07356318426900543, 0.02325665576790925, 0.011720544371200958, 0.03114050909061916, 0.039400011592078954, 0.07092617772286758, 0.08092937103356235, 0.06272505997912958, 0.008511864252795931, 0.04117482065339573, 0.05670396021741908, 0.01756328099872917, 0.03859779077174608, 0.02200856190029299, 0.06532986473757774, 0.012130376871937187, 0.04807186247489881, 0.06108319554186892, 0.01658641984249698, 0.012809475392714376, 0.0160142833556165, 0.033678557665552944, 0.01350884103885619, 0.038326042267726734, 0.054427028881036676, 0.03947054530726746, 0.052247103667468764, 0.02634831496834522, 0.016418247323599644, 0.00552178419638949, 0.03961011359933764, 0.011399126706237439, 0.008590492943767458, 0.04877693245362025, 0.022368689060385805, 0.004256782349330024, 0.03297902410849929, 0.03552348855009768, 0.027623788519122172, 0.051353902963455766, 0.025615937665861566, 0.06823595176683739, 0.0579372352513019, 0.019496664754115045, 0.06959528429433703, 0.034196023843833245, 0.0219767998351017, 0.06672778152278624, 0.0226050593846594, 0.027835267210321035, 0.030913478694856167, 0.032219910935964435, 0.07918948744190857, 0.024688579615030903, 0.03145917617075611, 0.025254073880205397, 0.008056871138251154, 0.05003355174267199, 0.013781019060843391, 0.005067151951152482, 0.04745375736092683, 0.10002071183407679, 0.02575401980720926, 0.0069147318390605506, 0.08120959115331061, 0.049205318646272644, 0.07182644738350064, 0.04533107399765868, 0.03445277354330756, 0.026237074453092646, 0.08242918469477445, 0.03655721120594535, 0.006317018160189036, 0.05842215454322286, 0.012868417688878253, 0.028578596757142805, 0.042476651578908786, 0.01819940360292094, 0.03735396239790134, 0.013023451410845155, 0.030070797838561703, 0.03461534099187702, 0.03943210205761716, 0.02539984281611396, 0.05132332276843954, 0.04098275283467956, 0.024689097263035364, 0.042106234541279264, 0.023936962134030182, 0.033579488372197375, 0.07281217534909956, 0.005811155924675404, 0.03336437315738294, 0.07001238613156602, 0.008030447897908743, 0.024621585944260005, 0.04235008200339507, 0.03514074815029744, 0.06411749229300767, 0.0229306859546341, 0.037307971506379545, 0.054602929012617096, 0.016176258941413835, 0.033882102798088454, 0.05016284128942061, 0.005539843432416092, 0.006886486162329675, 0.05958493296930101, 0.01540668890811503, 0.02797409521008376, 0.03625992911111098, 0.05619012314127758, 0.022227317349461373, 0.06281343492446467, 0.07247271700180136, 0.0580134352640016, 0.031586792174493894, 0.026209718889731448, 0.03936265187803656, 0.02682271060621133, 0.09943365817889571, 0.04860669490881264, 0.04168746658251621, 0.08025915230973624, 0.04474169742024969, 0.0565917697531404, 0.020383887458592653, 0.08828328267554753, 0.03739441686775535, 0.04239101515850052, 0.028043270795024, 0.035015091416426, 0.03489736824121792, 0.05068692371423822, 0.06845182768302038, 0.10434015974169597, 0.04266969161108136, 0.052037257701158524, 0.023476509595639072, 0.06516110035590827, 0.01474050004617311, 0.03171864584146533, 0.010714007512433454, 0.013020878013776382, 0.007170590497480589, 0.03850260291073937, 0.05420100409537554, 0.02080323058180511, 0.026404655109217856, 0.05464572866912931, 0.024611869375803508, 0.01923267169331666, 0.017641555314185098, 0.019144202124152798, 0.038856084138387814, 0.0394330891140271, 0.016323374875355512, 0.01082125527318567, 0.02035352063103346, 0.0429731780604925, 0.05855721057741903, 0.09858765435637906, 0.04469078980037011, 0.043145961171831004, 0.023049733863445, 0.036079056590097025, 0.03990596334915608, 0.007715428937444813, 0.037380393987405114, 0.0356578247010475, 0.02873239016480511, 0.05648971702612471, 0.03126186136796605, 0.019990877590316813, 0.08029432268813252, 0.023147845786297694, 0.06994499170104973, 0.009777889335964574, 0.011881141417688923, 0.02061695708107436, 0.027297212000121363, 0.07629027270013466, 0.05979430025035981, 0.05309382737323176, 0.011191013654752169, 0.06542294489918277, 0.0304194866475882, 0.021415459741547238, 0.08521844283677638, 0.015820599510334432, 0.014953904610592872, 0.031220820601447485, 0.030121833478915505, 0.06636561345658265, 0.0809720742108766, 0.04189670769846998, 0.03539861107128672, 0.09846853965427727, 0.0043073290999018354, 0.024256798096757848, 0.019233447237638757, 0.06745933133061044, 0.05247900255199056, 0.01872872559033567, 0.07616381815751083, 0.08326911032781936, 0.05427864387456793, 0.03224872110877186, 0.04899051884422079, 0.020086703698325437, 0.016653057282383088, 0.028664238743658643, 0.060336030946928076, 0.01138929974331404, 0.03023304987436859, 0.013654992180818226, 0.05591128712694626, 0.009262076291634003, 0.05083737189124804, 0.051391956585575826, 0.011598772780416766, 0.014866498167975806, 0.009760809734871145, 0.07736617902992293, 0.037161976215429604, 0.03484964443487115, 0.07178894666139968, 0.02284040554513922, 0.031106433380045928, 0.019993849891761784, 0.02345073109609075, 0.04371520699351095, 0.017890223025460728, 0.052041551025467925, 0.01740942821925273, 0.12963086046511307, 0.04627871865523048, 0.04677639175497461, 0.04361331382824574, 0.013261645563034108, 0.1758641077321954, 0.14791015069931746, 0.11917032607016154, 0.10689792718039826, 0.12547277030535042, 0.10346402472350746, 0.15329101821407676, 0.1427716834587045, 0.17340555059490725, 0.2151324920123443, 0.07788426490151323, 0.16191271104617044, 0.21095146948937327, 0.10758572738268413, 0.1336481948965229, 0.09353532819659449, 0.09840491533395834, 0.07311581022804603, 0.16435299650765955, 0.09454126484342851, 0.14362680085469037, 0.08589292148826644, 0.1796758227283135, 0.19044527609366924, 0.07206902577308938, 0.1385833730455488, 0.221963619987946, 0.1065629959339276, 0.17186822136864066, 0.3852509963326156, 0.09321145495050587, 0.14038993860594928, 0.09705143093015067, 0.1282664664904587, 0.2151166248950176, 0.11668476217892021, 0.09672895292169414, 0.1815602692659013, 0.12339981825789437, 0.23896926606539637, 0.07094643835444003, 0.10053316480480134, 0.10822767770150676, 0.18281282158568501, 0.20239541219780222, 0.10946934271487407, 0.08445051294984296, 0.13616270996863022, 0.07493333730963059, 0.13675231661181897, 0.1329515260295011, 0.1345935426070355, 0.18806173524353653, 0.08634547572000884, 0.18108348391251639, 0.15702596545452252, 0.20964319672202691, 0.10626336123095825, 0.09816703473916277, 0.11513690929859877, 0.24065233825240284, 0.1622401614440605, 0.10687583344406448, 0.12903418857604265, 0.17940778867341578, 0.11863531181006692, 0.12936389510286972, 0.10025396884884685, 0.08928682960686274, 0.11576306671486236, 0.21575043385382742, 0.2353078211308457, 0.2075292929657735, 0.20208434842061251, 0.11053911890485324, 0.16517492505954579, 0.11073561734519899, 0.13060068420600146, 0.12263874581549317, 0.12016118969768286, 0.1356737533933483, 0.09978023372241296, 0.16761344420956448, 0.07372060121269897, 0.08636383645352907, 0.1371328454115428, 0.14228879765141755, 0.09330725879408419, 0.08178449585102499, 0.17545613431138918, 0.143938502878882, 0.11568635833100416, 0.13597128039691597, 0.1363572565605864, 0.1778984532575123, 0.1358229250763543, 0.0946818498778157, 0.18336356937652454, 0.1359345589298755, 0.08570403006160632, 0.18057735403999686, 0.17279630672419444, 0.07418539345962927, 0.12815670284908265, 0.12420172366546467, 0.10787184757646173, 0.1009820750914514, 0.15147930214880034, 0.11856876342790201, 0.12439416255801916, 0.2159788817516528, 0.07657588081201538, 0.19340953265782446, 0.060219929364393465, 0.1744254693039693, 0.12129947353969328, 0.12205182574689388, 0.17576795507920906, 0.19803030736511573, 0.15985402307705954, 0.1943640533136204, 0.13267369562527165, 0.14164195657940581, 0.09602455829735845, 0.1816572531242855, 0.08453942224150524, 0.12610122095793486, 0.09280664307880215, 0.11828034999780357, 0.1911601424217224, 0.15734090324258432, 0.15161766816163436, 0.10063647176139057, 0.209451470291242, 0.08206981452531181, 0.18646580603672192, 0.14086734736338258, 0.1284754107473418, 0.11524040921358392, 0.09771908924449235, 0.13110066909575835, 0.10254943903419189, 0.08204492289223708, 0.09207291135680862, 0.10521199030335993, 0.1172328827669844, 0.10912770245340653, 0.0928223023947794, 0.09769043492269702, 0.11963641707552597, 0.2390323337749578, 0.1053170338855125, 0.1655043347273022, 0.13096583570586517, 0.16039107082178816, 0.09251019218936563, 0.15665299171814695, 0.06562313923495822, 0.12480888952268288, 0.23295976978261024, 0.12894245912320912, 0.1708431966835633, 0.12730643909890205, 0.1971673232037574, 0.15910031273961067, 0.1251554724876769, 0.12515979178715497, 0.17121188080636784, 0.1891682477435097, 0.131998281867709, 0.08013532496988773, 0.30648101528640836, 0.11520051135448739, 0.15625619504135102, 0.12619844230357558, 0.08015985295060091], [0.05189551862713415, 0.03681983129354194, 0.03924472090147901, 0.038627951653325, 0.013436194058158435, 0.05120207439176738, 0.01649705969612114, 0.035649290002766065, 0.0948030425934121, 0.04993543610908091, 0.0660999988031108, 0.032911507223616354, 0.02980752837174805, 0.019134429894620553, 0.07564103449112736, 0.016552743036299944, 0.04561268193356227, 0.011234889425395522, 0.03533102739311289, 0.06628474162425846, 0.034681562829064205, 0.05003847960324492, 0.019106170766463038, 0.07653691805899143, 0.020632295418181457, 0.013221668850746937, 0.05464851172291674, 0.04694587230915204, 0.04858198139118031, 0.050985185444005765, 0.010964323719235836, 0.035991898766951635, 0.03682014670630451, 0.0620463807717897, 0.07319488606299274, 0.03610141378885601, 0.016538180243514944, 0.010288580633641686, 0.045763579109916463, 0.04154987611400429, 0.009429608708160231, 0.04221279581543058, 0.017213927967532072, 0.016666319461364765, 0.017436652051401325, 0.06773475717636757, 0.014438949674513424, 0.016183279658434913, 0.029317302723939065, 0.018905878096120432, 0.013306474993441952, 0.050711329240584746, 0.027652114440570585, 0.024873630427464377, 0.03484293913061265, 0.05954295338597149, 0.01723889567074366, 0.046147503235260956, 0.027544796175789088, 0.012095627662347397, 0.02941766520962119, 0.08130610745865852, 0.012587050023284974, 0.021806311815453228, 0.031003644071461167, 0.01539582201075973, 0.04125176652451046, 0.045041677221888676, 0.04756130940222647, 0.01509364359662868, 0.04708262415078934, 0.031005039309093263, 0.06176972296088934, 0.028945432932232507, 0.07044496916932985, 0.05681525268300902, 0.05100944254081696, 0.03558490498107858, 0.012658406594709959, 0.033408705348847434, 0.015590654329571407, 0.04269579665560741, 0.021464435922098346, 0.08539713715435937, 0.01982790567126358, 0.032049539804575033, 0.03743241853953805, 0.025695495896798093, 0.03924533317331225, 0.01577895203809021, 0.016539480857318267, 0.01119430229664431, 0.03551138783222996, 0.07648504193639383, 0.02613729640870588, 0.032853831216925755, 0.03611143278249074, 0.0037911825529590715, 0.053446781676029786, 0.027865470765391365, 0.07485548601835035, 0.018133152079826687, 0.03358001900778618, 0.06074347002140712, 0.033610495302127674, 0.02750919906247873, 0.02113323767844122, 0.02065639851934975, 0.031538708426523954, 0.031542864453513175, 0.03788731795793865, 0.11128085097880103, 0.03548144959495403, 0.052852291701128706, 0.03470101080893073, 0.044342663168208674, 0.0812511365802493, 0.04397286211315077, 0.06993262009928003, 0.021726356535509694, 0.04817416753212456, 0.05479984676640015, 0.05173969730094541, 0.051890356990043074, 0.044874337763758376, 0.019523333830875345, 0.029912954159954097, 0.03726245187863242, 0.014922008958819788, 0.02749140236119274, 0.026305971732654143, 0.06491631778771989, 0.0002455173813586953, 0.022149512442410924, 0.014733335538039682, 0.04982324935554061, 0.07484555608243681, 0.05856545583810657, 0.046234579422161914, 0.02129535612766631, 0.02541423491493333, 0.033204551655217074, 0.04000814966275357, 0.03452730001299642, 0.04711382032837719, 0.023711705471214373, 0.019197469773644116, 0.059354073091526516, 0.04442323814146221, 0.0456543275504373, 0.05208835456869565, 0.013995730732858647, 0.06986954496824183, 0.0544144754530862, 0.05548425906454213, 0.06588248274056241, 0.03167268092511222, 0.024630103944218718, 0.026045394406537525, 0.028157941887911875, 0.040658430589246564, 0.045005389911239035, 0.0605563708813861, 0.07999099208973348, 0.05071017520094756, 0.0808296338072978, 0.0356981492950581, 0.028147280936536845, 0.05491496871400159, 0.06216464200406335, 0.036664722429122776, 0.055200376446009614, 0.06474678157246672, 0.08850983809679747, 0.059895095037063584, 0.02416626906779129, 0.05024288191634696, 0.03789700669585727, 0.06573743739863858, 0.05809001377201639, 0.02611740870634094, 0.03298292409454007, 0.01924044940096792, 0.04769760853378102, 0.05221792984229978, 0.028393095089995768, 0.041763570116017945, 0.034364302118774503, 0.0656261523545254, 0.054506624219357036, 0.02207991754403338, 0.03326213118270971, 0.04856775813095737, 0.012620150737348013, 0.031040053836477455, 0.06781081247027032, 0.05613286644802429, 0.10136468932614662, 0.04779261456860695, 0.026014331815531477, 0.02550963243265869, 0.07533060896093957, 0.04765429679537192, 0.03312220665975474, 0.015264391367963981, 0.10242228687275201, 0.019868482595484238, 0.044924967078259215, 0.026332577726861928, 0.04134578179218806, 0.07113187137292698, 0.041658326153992675, 0.033737098274286836, 0.07627112529007718, 0.03535195595759433, 0.02934760461357655, 0.053054538075230084, 0.05805915527162142, 0.06339590210700408, 0.04548051656456664, 0.09651311411289498, 0.03804116517130751, 0.07027547006146051, 0.03601500182412565, 0.06185430924233515, 0.009591921043465845, 0.011553791209735209, 0.052786199739784934, 0.047521667584078386, 0.03300049815152306, 0.03431889752391726, 0.0358779048838187, 0.04470686842978466, 0.0356653278140584, 0.014685635851492407, 0.03449795920460019, 0.08666831738082692, 0.027214957917749416, 0.06801073221140541, 0.06720760968164541, 0.04956051423505414, 0.03370367194293067, 0.05851070389326196, 0.0349482313322369, 0.06053829587472137, 0.031494676804868504, 0.02312988024641527, 0.07969085272634402, 0.059413574781501666, 0.05324517725966871, 0.030001857885508798, 0.02733244917180855, 0.017614847274671774, 0.05710223376809154, 0.018101499481417704, 0.0576577535684919, 0.02105793380906107, 0.12706175300991163, 0.025650595962360967, 0.07377919377177022, 0.03660812995804008, 0.03329886378196534, 0.027052744844695553, 0.05338186972949188, 0.012975139452464646, 0.02998492207552772, 0.01622914438485168, 0.030370983586180955, 0.05787551082903519, 0.00674013324896805, 0.053619716927642, 0.03583415898901876, 0.020583569712471217, 0.05145712828380056, 0.038992323898128234, 0.04274916820577346, 0.013428524889604887, 0.025982434308389202, 0.0439172158803558, 0.16169156588148326, 0.0472188342246227, 0.05401575661380775, 0.04482335592911113, 0.03018286584847374, 0.008605817365605617, 0.0368379211431602, 0.015220692785078427, 0.16259979136520997, 0.05841211328515783, 0.02950570618850179, 0.03162599241477437, 0.012409978226060048, 0.0771332485601306, 0.07164411654230207, 0.017074923707696144, 0.0377148762345314, 0.009548331927362597, 0.029617187901749276, 0.023526491386292037, 0.028148151104687713, 0.013792741283396026, 0.08010769481188618, 0.018853092842618935, 0.059336584381526336, 0.060451097233453766, 0.02233685092505766, 0.02372235343500506, 0.055809842961025424, 0.023843275266699493, 0.07884881939389743, 0.024758076178841293, 0.022005426326359157, 0.0545364882418653, 0.007022965264695813, 0.07009577384451404, 0.038013145385775715, 0.06425911633414216, 0.050079679931513965, 0.04131153167691082, 0.03398850451048929, 0.023192877451947425, 0.01645904874749249, 0.025754312955541536, 0.020963998322258703, 0.048753013034001924, 0.02407121293799719, 0.06169301828776952, 0.05194919074710924, 0.056901842763181776, 0.05857469186594244, 0.02648785914061591, 0.06822487892350182, 0.018800847501552198, 0.040022662360570394, 0.04192265318124555, 0.018266117112943903, 0.030073464004090056, 0.027027901451219805, 0.039653317726333626, 0.06554495397722349, 0.021245754687697627, 0.022214613636606373, 0.06328669507638551, 0.04709811648353934, 0.05554441384447273, 0.10587311029667035, 0.0403738058230374, 0.04216451539832633, 0.08341534310602583, 0.056960550355142914, 0.01808767698094016, 0.030150383900036104, 0.1384366801357828, 0.10073527388158254, 0.10197273833910003, 0.10381394735304639, 0.12053594458848238, 0.19266278366558254, 0.11012722694431432, 0.11312557035125792, 0.13877475808840245, 0.11999512673355639, 0.13836248021107167, 0.0899031016160734, 0.150538110465277, 0.07562200582469814, 0.19353436189703643, 0.0846880002063699, 0.1471596909686923, 0.09965271048713475, 0.12736285716528073, 0.19440981413936242, 0.13720686722081155, 0.18209736153949052, 0.21493519947398454, 0.32985080033540726, 0.13194343715440482, 0.11059506199671887, 0.08171236651833169, 0.16365325514925644, 0.09225576170138083, 0.23550601908937097, 0.11220291009522043, 0.16401603177655488, 0.14498791453661397, 0.19269615062512457, 0.18125465285265818, 0.13947273313533515, 0.13369397056521848, 0.1508757728151977, 0.1359070697799325, 0.14915317384293303, 0.11653629553620704, 0.1687886647414416, 0.18387370684649795, 0.23871977085946128, 0.28053392947185785, 0.09896108822431415, 0.1627175702014938, 0.1175562736170832, 0.21296846360201016, 0.07567848326289095, 0.14316151879029348, 0.18597048183437437, 0.11697673049638979, 0.12901714886538684, 0.0975401648611296, 0.1461271260632202, 0.1450549898436293, 0.15967608575010672, 0.12959862157003954, 0.11846991677884944, 0.14154779288219288, 0.18183044070610777, 0.18308523431187496, 0.15028846682980657, 0.09413673498784192, 0.09464227856369689, 0.1380950101884082, 0.21753558103227988, 0.1707213805639185, 0.10637089842930436, 0.11868723246152513, 0.17631266178796068, 0.19877539394656196, 0.17058394965715706, 0.2353618643246591, 0.16325003147358075, 0.21211131272139028, 0.11181167952599935, 0.14717058569658548, 0.10455433613969944, 0.08757548901485279, 0.19840866909362376, 0.10690605369745754, 0.20294230082072318, 0.06689852001727559, 0.12342002693912946, 0.07349844672717154, 0.10740061348769814, 0.11470489771454595, 0.0714594850433059, 0.10368642411776818, 0.11770972749218345, 0.21225730801234022, 0.12215339607791975, 0.13828305556671694, 0.1468648505397141, 0.12090681804693304, 0.10351481731049716, 0.15505661722272635, 0.1334265450714156, 0.10051961318822578, 0.13827918155584484, 0.1291138952365145, 0.27570195437874645, 0.15548642462817952, 0.13625016465084627, 0.16473883908474818, 0.12186253356048837, 0.07495552010368556, 0.1342530600959435, 0.1121110247913748, 0.25814285909291357, 0.15163840376771986, 0.10768164254841395, 0.07156169362133369, 0.0790171607513912, 0.2161375232390128, 0.12593100196681917, 0.1511094899615273, 0.16343874478479847, 0.17355350515572354, 0.15249626711010933, 0.11910294648259878, 0.1177214460039977, 0.11506675407872535, 0.12534047506051138, 0.10972453761496581, 0.1109333848580718, 0.14761250495212153, 0.2015231957193464, 0.09890406159684062, 0.2296817331807688, 0.1463611252256669, 0.11434413230745122, 0.14371928729815409, 0.1187380324699916, 0.259328811080195, 0.11739240741007961, 0.16758930956711993, 0.1261305357911624, 0.1551038771867752, 0.13159686903236434, 0.2066875045420602, 0.09630534244934097, 0.19265748473117128, 0.10528160375542939, 0.13685924524907023, 0.10432627415866591, 0.15470430487766862, 0.08055749567574821, 0.1977057958720252, 0.1020522000908386, 0.17801271431380883, 0.13747619261266664, 0.15975549555150792, 0.14082108187722042, 0.12780574121279642, 0.0919967818481382, 0.12824500357965007, 0.10801045849802904, 0.19438043993432075, 0.16374957107473165, 0.06879287422634661, 0.13496014871634543, 0.11165151663590223, 0.2943459805101156, 0.1532583191874437, 0.0991302978945896, 0.20338972681201994, 0.19887993286829442, 0.12103132816264406, 0.12188315042294562, 0.15626026201061904, 0.1305789838079363, 0.10058894462417811, 0.12087654584320262], [0.005252343771644519, 0.06132228212663904, 0.09568330395268276, 0.03111484747932991, 0.02276421852002386, 0.04877496205153875, 0.030454495608864818, 0.02353317442612024, 0.01742919717798941, 0.045542994266725145, 0.07425013842293993, 0.04103341925656423, 0.0233096284136991, 0.01160723975772271, 0.048246174410451204, 0.03553059832483996, 0.023076211837178562, 0.008433859893557383, 0.038766139550716616, 0.039431077893823385, 0.04048138012876734, 0.033562882817932405, 0.04915638142847456, 0.03674848121590912, 0.05942481831880286, 0.06640607534791343, 0.0547664167243056, 0.04404609353514388, 0.04296031293051783, 0.026145339434151538, 0.06884823102154769, 0.026182745532423723, 0.026664820543373935, 0.05136549531016499, 0.02580700358521426, 0.03424094604270067, 0.04493765038205311, 0.01062916147930082, 0.009140930887951981, 0.005245840702627902, 0.0513216492254287, 0.060545646847458556, 0.03734942787559703, 0.01118294187108404, 0.002731455274442851, 0.025618700310587883, 0.023794161788828205, 0.05688146338798106, 0.059711669528041966, 0.07005954219494015, 0.050340444649918936, 0.0552342851733556, 0.041796862860792316, 0.031051763071445748, 0.04086457323865034, 0.024190926924347878, 0.0540357983118156, 0.04514357409789227, 0.043466847273521125, 0.06398988000000827, 0.04359345024568029, 0.013048290165897924, 0.009797563670872478, 0.016540970718779135, 0.033560841911821626, 0.022116748477856163, 0.020677035790868104, 0.06455616836319678, 0.028299382247496396, 0.05235362041275948, 0.03064702726987889, 0.046781813143752515, 0.02019251540332334, 0.03038006747374311, 0.04868528834776953, 0.09157141990726814, 0.028252524898562115, 0.038343749911291525, 0.016749966925999615, 0.04875012979027815, 0.044537625362863764, 0.03219875601644162, 0.05652926236507483, 0.046828520207782276, 0.015150603430811316, 0.01170814586657798, 0.030876994715072215, 0.043172459554625675, 0.029604081573779695, 0.058022367011290044, 0.10282099829055369, 0.027341314125806093, 0.03142222834867425, 0.060361690702848136, 0.02220918111561332, 0.08411130693275481, 0.06569365810719319, 0.014674064841528889, 0.03327385711600073, 0.08740262055653147, 0.030370170934475027, 0.07686500670388341, 0.01883783614175627, 0.03745782967598643, 0.03356867528054863, 0.06498199785710312, 0.09481168861384504, 0.04087656634510495, 0.03349021171743516, 0.009098589507630095, 0.01614082695596153, 0.031079827385838144, 0.04115552481380291, 0.0781458942219615, 0.05230761096754577, 0.04981902282452211, 0.038503938776557334, 0.05694722509360872, 0.08574040271923877, 0.06357190984999761, 0.038916446719667874, 0.027581411886785645, 0.06797556925448589, 0.04466055841476191, 0.06670769900665618, 0.024522548192180693, 0.03752276017621625, 0.07651140302186832, 0.047741692105773836, 0.018405689115752466, 0.05856719617440831, 0.05421168731118087, 0.05386328608437907, 0.03745357345906086, 0.028090007544960827, 0.028023321865475737, 0.05580225079029333, 0.024615409420221113, 0.043896372662857175, 0.037090815385454334, 0.024127797987603117, 0.031279806498787366, 0.02088568318868056, 0.01560874417918967, 0.06331191325443797, 0.028628227883018553, 0.04096487449714914, 0.0842346518766135, 0.01981381414225325, 0.07273080627783202, 0.03334744105814025, 0.02763641059573274, 0.048569168211543, 0.04875517639447935, 0.0117064148071222, 0.015610072623530868, 0.029788705651299097, 0.039198050944833085, 0.010936663875327213, 0.01221410133439349, 0.03912690866854973, 0.03072218085435452, 0.04320198218920268, 0.016815606177260634, 0.04347622802015394, 0.05469032061228063, 0.05245123880740721, 0.041176560989697464, 0.04212224266666453, 0.09311529487604275, 0.014793205518799368, 0.012888347137050005, 0.07842414765036665, 0.050922574155265465, 0.018616831985127646, 0.08307340598548763, 0.014221185920177959, 0.05606211008853279, 0.05239629761490505, 0.04603759487508796, 0.028817811362387147, 0.041204046428902075, 0.022738929837942123, 0.06749258696800098, 0.030210826262191404, 0.07335704533034004, 0.08775909635005519, 0.02383717852353584, 0.02548777989431983, 0.0723943387856707, 0.028566321634571068, 0.031320361158577725, 0.013695886373170651, 0.022829633271612693, 0.05265757812594529, 0.019990744003735017, 0.013814915728289634, 0.019709199150383938, 0.038806623706477694, 0.05597773160843644, 0.05461563829157967, 0.05579832853982225, 0.09424991993000731, 0.05656527508108411, 0.02822811009536963, 0.0268480363956769, 0.09717793742311187, 0.07565478648757562, 0.047374559071613476, 0.07186662725871429, 0.030299108439066913, 0.027714189527614508, 0.037804126914124936, 0.12093891593394801, 0.025214550805685576, 0.02462115549860755, 0.04799465314135887, 0.05047843587817624, 0.046569647965952754, 0.0533782146521844, 0.09110908416914754, 0.032261107553495094, 0.01897871432447573, 0.11566239438252524, 0.0212984564495855, 0.021672005350410473, 0.03549619978002738, 0.059592792313196696, 0.03268715227022767, 0.008197342067433055, 0.07850886380765587, 0.04538367000350263, 0.05025970640417654, 0.002227974405286659, 0.05016442206397187, 0.01701723100268282, 0.008266225431725616, 0.05008799569623079, 0.012132834308431484, 0.020634688844438642, 0.03794524629483931, 0.005315381331456592, 0.01834269005485112, 0.06484452984295785, 0.041655019886093214, 0.10089027884532697, 0.027669232076732442, 0.058315181377111, 0.019033688913623337, 0.03495163036859594, 0.022214500459085684, 0.12634820770472288, 0.03421607667405624, 0.05093935782497283, 0.01646394877752755, 0.015267877606675029, 0.041808418100117706, 0.04682328806666192, 0.08366725771338679, 0.05473705365147907, 0.006288103159022285, 0.024705220421310514, 0.05874028356629424, 0.045212066906969994, 0.04239980218699202, 0.04276990752259735, 0.04253628685546573, 0.02349171063542599, 0.026724895542429294, 0.041580370962037705, 0.018713893769017886, 0.01804541167075513, 0.11418368740123697, 0.0247978460174636, 0.042790008592419326, 0.09573923962307163, 0.05130065757839475, 0.015357550382759655, 0.03145304974168539, 0.018778132216539234, 0.014514607919409173, 0.025983185732911807, 0.054267274172161706, 0.030791809149377514, 0.05260879304842092, 0.06220592025783844, 0.01895184672321193, 0.027928608978982083, 0.024798484264465515, 0.05840178630023729, 0.09299042852944694, 0.027313936298014596, 0.05767212154751178, 0.0400087174057262, 0.07793483484419994, 0.10131430492037907, 0.09479536878643557, 0.055460313669755124, 0.02921669904026203, 0.008260462655016454, 0.033049045741790906, 0.019207024924980942, 0.005940353166806744, 0.0279810361462296, 0.03788236412219703, 0.03944736803532578, 0.04116820440685842, 0.0379189557133941, 0.043326740924385376, 0.0009765700951902545, 0.0865897536277771, 0.04572186298901215, 0.07477405757526867, 0.021351306641008705, 0.02106152765918523, 0.066295465658186, 0.029128012392902747, 0.026920121199509595, 0.0503840087185381, 0.02587579881947022, 0.06706114683765918, 0.04962742255884223, 0.045728338227490894, 0.01651092115935171, 0.0343835794046754, 0.023338850478467066, 0.04323685570852831, 0.02350972812564578, 0.052796645468333736, 0.06917169608641416, 0.025196624228556175, 0.018875553942052647, 0.022228861016628798, 0.037763835716759786, 0.03702288660861086, 0.03436898135987576, 0.016573092725593597, 0.017601616636966355, 0.08577746557421051, 0.00916277971555246, 0.10524357610847801, 0.022542503756994847, 0.029515144451579545, 0.06997386866714805, 0.05822973791509867, 0.015073424710863037, 0.022424693379434757, 0.040521240880480036, 0.08134420932037756, 0.08367919144802727, 0.01179709597636247, 0.08801872929325327, 0.14591432263841853, 0.12524303107056767, 0.19026077818125486, 0.14462356455624104, 0.1284772958024405, 0.13326207030331716, 0.11270026778220199, 0.14188213041052222, 0.11480801171273924, 0.2076265143114142, 0.1483622967498377, 0.08120544996927492, 0.14965306967496872, 0.1757458836073056, 0.12156375232734717, 0.12939126550918445, 0.10460164805408567, 0.07143598864786327, 0.16115353850182146, 0.16075423336587846, 0.1242415992601309, 0.10285301454132423, 0.1831329840933904, 0.08089411159744486, 0.16224847349803895, 0.15117607545107603, 0.17192941886605695, 0.14904489449691027, 0.11359401396475732, 0.1266552638844587, 0.16595030610915273, 0.22889220679644495, 0.1278258831007406, 0.2503977465676144, 0.0664680966292508, 0.13826833135681227, 0.0971259202924557, 0.27193395188078284, 0.12690106319496408, 0.07628851381014101, 0.168818365491461, 0.22830500471172854, 0.0671844843600411, 0.18630076723638922, 0.12131302515626885, 0.1581451835227199, 0.13516134495148435, 0.18236315430840477, 0.15951564826536924, 0.11424337833886966, 0.08604892092989758, 0.127674856048543, 0.12544994184281677, 0.12900818372145295, 0.1464038432459347, 0.0883496826281771, 0.17886518966406584, 0.14969932031817734, 0.14119255647528917, 0.11521062682732008, 0.1768995076417923, 0.1424849175964482, 0.161874876357615, 0.10094582859892398, 0.12748048757202923, 0.09436960608582012, 0.09688779478892684, 0.21507819648832083, 0.2334408595925197, 0.17314085620455444, 0.07524475731770508, 0.08120212514768355, 0.0938501101336442, 0.13597677228972316, 0.09195920691126958, 0.24913419561926275, 0.1321122163790278, 0.18951218866277486, 0.10023465074482374, 0.12995244789635763, 0.09151903170277365, 0.12268230246263556, 0.18507956323446706, 0.11148580990266055, 0.10229738341877237, 0.08813327236566693, 0.11719547852408141, 0.162305514968466, 0.15001339721493423, 0.1160665754287038, 0.11677641741698608, 0.1375600998289883, 0.12087572948075831, 0.2179697374231182, 0.12026133510516956, 0.1062690831895452, 0.258357577258721, 0.09153899547527544, 0.09584388986695558, 0.14817763556493446, 0.18980949302203953, 0.10174531460506842, 0.1775318619911559, 0.13949193991720676, 0.11693679552990943, 0.21334200137061998, 0.21837837877683342, 0.17893851385451853, 0.09899863347527571, 0.16021295537939295, 0.10027490483480506, 0.12676728365477175, 0.12778542120940983, 0.15069443645188585, 0.23094696138286963, 0.100320287165232, 0.11925376573344693, 0.11681758434860967, 0.1561836723703891, 0.2359191727009602, 0.17134180117864162, 0.1929702257621102, 0.2109464377281256, 0.1141764217754826, 0.1603112751035951, 0.16013931948691607, 0.08677385820192285, 0.18416998704196885, 0.24716355605050921, 0.1101500925142318, 0.18605867866426706, 0.22542372025782242, 0.1005434880789835, 0.1224479396478273, 0.19624480395577848, 0.13949225161923096, 0.26285525935236365, 0.07645739693543874, 0.16839430230902508, 0.12440585138392635, 0.12384976012981497, 0.11277154364506714, 0.11706388831953518, 0.11710694772773422, 0.17444878758396953, 0.13517737534129992, 0.10225206046015956, 0.18739919032668695, 0.08660500476253219, 0.13067929248791188, 0.12610007805051282, 0.1758233638247475, 0.12797964125638828, 0.12281423405511305, 0.1079637031944003, 0.11115818138932809, 0.16176524630282074, 0.14465483865933493, 0.08243580465205014, 0.1630041134194471, 0.08769942025537603, 0.18150468240492046, 0.19256863481132314, 0.1510557733126916, 0.1563489338150248, 0.10085919770062901, 0.13284731365274638, 0.1554252122878097, 0.15245509275700897, 0.17463666968978941, 0.11830078132334165, 0.16811519541079178, 0.1474223964032717, 0.19672556722071022, 0.2505139075219631, 0.21075563156045973], [0.05716683772334363, 0.061036944898660295, 0.031017861765576527, 0.020339948605396785, 0.01976798095711274, 0.048918344982666895, 0.05899007934203837, 0.056618231028551236, 0.09653868852183223, 0.03716079991136212, 0.037000603624619544, 0.011047691950807348, 0.007067027963785222, 0.06671840077615343, 0.028681601288553793, 0.06539889931445941, 0.07165488510509022, 0.015629706140316557, 0.036943421146133915, 0.019899868020729627, 0.04556395622785203, 0.04736963863251731, 0.048591080121695995, 0.08172683097654954, 0.068675755901495, 0.060909425374120474, 0.006674284340988379, 0.022582013843930326, 0.04940728671499528, 0.01736607195198303, 0.0571265873441007, 0.02769173584965756, 0.05292777183058206, 0.03956320615543518, 0.08864655654178932, 0.034415291374898516, 0.03947781464376021, 0.015311648548959056, 0.03425761096877977, 0.036390094392118044, 0.02487837275111815, 0.12465772888390347, 0.03672200138680637, 0.04861177862039767, 0.04415633957250975, 0.07893505695392378, 0.011111711464764085, 0.047190992554533295, 0.09216469275997952, 0.017929022505995817, 0.0034557132494228426, 0.029010224279772956, 0.017240879060409497, 0.06663844178547151, 0.019265266819274984, 0.07090759434504434, 0.018049903519568034, 0.028150967555120587, 0.027833519452542532, 0.013334263785509393, 0.016802459031168837, 0.04681514299591072, 0.026054381814901717, 0.03001844303071266, 0.020040182171214838, 0.06381252896972, 0.07432920683640987, 0.09246791945770383, 0.030370859276445117, 0.035999301690026186, 0.02055984139587963, 0.03950694022933021, 0.022617631366301794, 0.048441218241350725, 0.024135518178809434, 0.025130027606792282, 0.02789632555504795, 0.03346683777635917, 0.04840591056563426, 0.03473452990874648, 0.01694042428425746, 0.060608428830164485, 0.006822917966928799, 0.02403974958724575, 0.019400784840399865, 0.022127277698018588, 0.060135190942673944, 0.06134870258392766, 0.041355652356287464, 0.07471183591405861, 0.050149430680903606, 0.03431646327953786, 0.010545961158641148, 0.04493667445785832, 0.04899024796031881, 0.0811209341918584, 0.021067388770461548, 0.05228373978752643, 0.05326005360984709, 0.04071519746503327, 0.07141209891415201, 0.01940496869792696, 0.012488024331105407, 0.07113512197975069, 0.0865463528316468, 0.03858921154460404, 0.06183985962707084, 0.05239650170551613, 0.06249701284104958, 0.04824858267966192, 0.03456007325439714, 0.05030076201364864, 0.009682495528977597, 0.04558040222036652, 0.04505365177465137, 0.055213427112903446, 0.029444120918924455, 0.08930553172831424, 0.058505096967564896, 0.027903479858650826, 0.023506727993662935, 0.011289014255453367, 0.009020174184115604, 0.029812964603479486, 0.05397345048550051, 0.06416028452804312, 0.052476516357273795, 0.062175855855457485, 0.037626631165039726, 0.010165006551687839, 0.028463346789067145, 0.06318256433587521, 0.007135941477827146, 0.04036731945234351, 0.014250287385948468, 0.005011712128180079, 0.04129792068852112, 0.04631452728062868, 0.019521233552950434, 0.05804890621220693, 0.08264749485533684, 0.053351634633145295, 0.01470159666496329, 0.07642251599463634, 0.05581147568591405, 0.09728525197715499, 0.03213069365301635, 0.008881928770279046, 0.01436737138647004, 0.059190670726820827, 0.0525846955133602, 0.02928944621089613, 0.030758217690163292, 0.014791867797612213, 0.0653422660252545, 0.07221630497951992, 0.03286488921730779, 0.03697336680488661, 0.043621195436571725, 0.01827387070079567, 0.053175448774709366, 0.041915142646757886, 0.04738926472782623, 0.010786510702018859, 0.017246727184101474, 0.02386233176366659, 0.030946936567488592, 0.0684167463623453, 0.03585837526770774, 0.057330473864567466, 0.05073760497907642, 0.010711167869885685, 0.014643314880231628, 0.023755336333124433, 0.05031675529608037, 0.008132891180139268, 0.02883533903514035, 0.059103327366756275, 0.02787099791021319, 0.016949539713095874, 0.0161133674919256, 0.014622800990764517, 0.024511083865945693, 0.014976635666243965, 0.10132393057574518, 0.014620774927607272, 0.024561130594520364, 0.0091619299564627, 0.014557838021573843, 0.01783001443982357, 0.015652744259568863, 0.019338390629854985, 0.04033721794257872, 0.025923027242242824, 0.032211327998084016, 0.04512663828791119, 0.04134833849093411, 0.05757727878517471, 0.043713622508221306, 0.04371618662844412, 0.02334173557756003, 0.10002665643696673, 0.0032778162767499452, 0.03891882901370991, 0.06580046800081618, 0.007148654931370402, 0.04627911941497587, 0.019789414182014298, 0.07579708588309586, 0.046491933971992694, 0.028089870247640647, 0.03444073961873073, 0.014564846678695176, 0.03994901533587836, 0.06540161557495594, 0.035147249363944866, 0.018738957951427437, 0.061707208151347004, 0.06126265798229724, 0.04272770900570322, 0.0392576045851456, 0.034139308918383904, 0.03255552124755923, 0.06570643789018504, 0.052649421922978945, 0.07693546620430425, 0.043218068240094, 0.07152777005103417, 0.04963166022207588, 0.031139570273808204, 0.028339089003566187, 0.05101753195049241, 0.043233831456745975, 0.026745907598524354, 0.04274701597751118, 0.02748747639998328, 0.03323609664221294, 0.03960099631513003, 0.04492825850320514, 0.07322944045881741, 0.03284855825768318, 0.04284247101168148, 0.018431864664307795, 0.035341428592801094, 0.017656943746260367, 0.010223090739600593, 0.06443096805014648, 0.08631370437797159, 0.04126653897401411, 0.07871193767641671, 0.024532338975404855, 0.040249744706670754, 0.0759183602349367, 0.06692523733363487, 0.040747621897025965, 0.020562796999001876, 0.055653876916039735, 0.05257191944110673, 0.03806165586865973, 0.022945790515223052, 0.033130500160041265, 0.06839363588369451, 0.03578766714781523, 0.049871693045133725, 0.0366879108332796, 0.02193336193158757, 0.005772347167294356, 0.028721198577841278, 0.008734580915188417, 0.04043684384669177, 0.03736565122380853, 0.11605323903495446, 0.01160752733994741, 0.057783328666118905, 0.023476225724152755, 0.05168561328900978, 0.03607459999329876, 0.035027270059799775, 0.05226247354585212, 0.08135179406963289, 0.03475242308923043, 0.08154063354595564, 0.012549495495477458, 0.06655990771832876, 0.046715357530047186, 0.07587839558254927, 0.038877910701557994, 0.029370837546593975, 0.030958003844716586, 0.040004049296840094, 0.026132646853511687, 0.03147550713038072, 0.03716795050422661, 0.037377985718194395, 0.02231035254226299, 0.03456173566519283, 0.014597582812712062, 0.05283055790641811, 0.030871898015902843, 0.02352190305828117, 0.0355320269591175, 0.09363857578136958, 0.017252155994356144, 0.041713374957907945, 0.05147331081388984, 0.05265794177830685, 0.0505835276999278, 0.09409302248968743, 0.036323364183772355, 0.023926946851133835, 0.02788736041111406, 0.057478740127407946, 0.024557054348406382, 0.04970548165147193, 0.012085055768693564, 0.0545990772661753, 0.023180303614935838, 0.02781573944957927, 0.005439460537672858, 0.011881452192028519, 0.03211958741303533, 0.0492472908081254, 0.07396646731649525, 0.02681135945749702, 0.051460568138281815, 0.043467604264151305, 0.11329131419188343, 0.01982799658435397, 0.11640863871434703, 0.03905029676388949, 0.07086729572620243, 0.09137759319855832, 0.05744200752815232, 0.003988934295193758, 0.01578913244884461, 0.05230597824265715, 0.0634894275572151, 0.026357120550528634, 0.044018255575792864, 0.035215575189795345, 0.01538376211101422, 0.055812403370509855, 0.03604029792768415, 0.04451239976333454, 0.01945547370269196, 0.03270874505687971, 0.03544051643984858, 0.0813279785506893, 0.005025337959523313, 0.04856762825511396, 0.036712104847538285, 0.02955061168904649, 0.166061969648581, 0.18577416893094778, 0.08656645019073039, 0.0746231121593155, 0.06586498289834708, 0.17217012704350054, 0.23158951284131035, 0.10054265687358566, 0.20863283687504008, 0.147244963736739, 0.13290333095937967, 0.10189462729613297, 0.14406428206712008, 0.13401331671047956, 0.07399913665722124, 0.23247082805028185, 0.22691387857776135, 0.08812404004856944, 0.16711636853870004, 0.08382794752833433, 0.11638598094577901, 0.17647292115725577, 0.15435160661581904, 0.19483611860778183, 0.17403575271600857, 0.1785566343460232, 0.07921973738120869, 0.10853424406377599, 0.1482256525196135, 0.1579467480769381, 0.10874112515011802, 0.1811907094088383, 0.1600436566513963, 0.14808370935497805, 0.18987837916938588, 0.08025648799957708, 0.08438317046966404, 0.14540817792294547, 0.19416726543568075, 0.06989464440266602, 0.14480522746453062, 0.23649525741348043, 0.14655093691544607, 0.24958919151686132, 0.11591736663831398, 0.15031672781333327, 0.0777142982406076, 0.1268140389584005, 0.15658524847822264, 0.23195021145511419, 0.11555279401363805, 0.10904320151894353, 0.10652934695826843, 0.12067920877598226, 0.15126318874536082, 0.17860186082543805, 0.21263476432068273, 0.09019469885970466, 0.24242853512987494, 0.17418173316400498, 0.17599284066818655, 0.0787470412615221, 0.1890201002242975, 0.11467944947071373, 0.16279070143355057, 0.1361919505870901, 0.14781303325435147, 0.11468298209365457, 0.1965341079630889, 0.17176369728986174, 0.128228290413972, 0.23550471290946007, 0.13522678753361106, 0.15613964817021042, 0.09591876514605246, 0.11505061236675829, 0.12913001468405128, 0.1334863918600604, 0.1021303927700501, 0.13094581256154925, 0.14881524431984872, 0.1624433763208799, 0.10567543184151873, 0.19552671670680866, 0.1277619248139672, 0.11612535352469422, 0.15382719022454694, 0.17870015086373314, 0.1328993827337399, 0.14594576001400128, 0.1328215908142738, 0.1293264314881526, 0.0957589436438866, 0.10912422178080305, 0.1529345943708904, 0.29558970127254725, 0.06837878550868481, 0.1417965310974978, 0.14506315346807241, 0.22245290310820565, 0.18983775400556624, 0.12884544557891786, 0.1277582289185375, 0.21611374482745305, 0.2859998174244538, 0.23457425268134102, 0.13623538106912747, 0.2587109582964331, 0.1378893165383488, 0.26590842520818114, 0.09071371241589077, 0.15405470301629975, 0.12055330342263915, 0.1283297865302302, 0.15074785624165088, 0.30783341615460813, 0.12674647383391857, 0.20298694842495024, 0.13000690669286996, 0.11202811205293983, 0.1011013456445653, 0.14699827384902164, 0.10733009461546317, 0.14718063437612727, 0.1251329408842139, 0.1908582664327696, 0.10976399018545635, 0.1993429588037543, 0.10588318124064244, 0.13999765418702736, 0.08407641114899889, 0.14664480375358835, 0.10281476425006986, 0.08771101260208525, 0.12690186471445486, 0.1855907990830019, 0.11063278536312282, 0.13138670765329152, 0.11198939420864917, 0.08384809683775529, 0.1443665736587718, 0.16115181671921164, 0.10124623513547704, 0.14056416519451886, 0.15328214212786406, 0.19803832256002352, 0.15875772252911702, 0.12348725067568012, 0.2768797427415848, 0.13849045615643263, 0.20106111973291263, 0.06704303101287223, 0.20509859605226666, 0.15795379847986624, 0.13068350788671523, 0.2024852714384906, 0.1942677522310987, 0.07660721428692341, 0.0802941519941669, 0.16826136881718412, 0.2930360601749271, 0.12642620742553845, 0.14213827525964007, 0.1080219988944009, 0.10980654493323527, 0.08515786874340847, 0.09757795502082445, 0.12860279297456145, 0.10802908640471287, 0.11398724833270535, 0.2707000868394971, 0.1941676958813332, 0.12697554513579234, 0.1596160014742054, 0.14934378705220297, 0.09355091329780407], [0.05714427272323519, 0.06017359708494041, 0.026447347154316958, 0.022012903464201372, 0.026880859732045792, 0.048790265136631206, 0.02614915221784031, 0.02776085206278367, 0.06299872693489306, 0.04373942698293831, 0.036247223542886786, 0.11452526829089038, 0.037603873206535354, 0.046370763520826586, 0.06447158579248935, 0.046199486969271675, 0.061066059352015145, 0.02471158433763776, 0.039502387153333984, 0.0425312922016019, 0.015638018194295, 0.016641177353449166, 0.06940481209312566, 0.08168563435901888, 0.04685291831265204, 0.01654214516747743, 0.06538030851515941, 0.02956689440907212, 0.03185779110935982, 0.026923600016743876, 0.013029701221967116, 0.04551943107799161, 0.06490164552815259, 0.04412528440298047, 0.028376864320307504, 0.03128287156869192, 0.060518929531099275, 0.02869828476832481, 0.010949504885502392, 0.06651865915046073, 0.014280553095886717, 0.015287451751646586, 0.03212428520782851, 0.03732738608960062, 0.08417650460614823, 0.022179279985721223, 0.054128770862007514, 0.05426124051155057, 0.013638988693855936, 0.005821605827804888, 0.01682707978034159, 0.0295946080586873, 0.03636889494373463, 0.042329394636908546, 0.06910083582624793, 0.05394608750066254, 0.06345579342450947, 0.06833507301053032, 0.07042239303700626, 0.028338630727375858, 0.043050472741015255, 0.02922531908552628, 0.06457405412220396, 0.06188695631863084, 0.023064409833750688, 0.007946972054924117, 0.07653688837308437, 0.06043597968528047, 0.0740257278084755, 0.03385893294762354, 0.10540319723077118, 0.004506197774389875, 0.021338743936212268, 0.03979277469625231, 0.07818457495886832, 0.06380169361364096, 0.04055432953464333, 0.04084537758899387, 0.04549724828393664, 0.03425249386054929, 0.03811893111560494, 0.0459270148712676, 0.05155143669981044, 0.05713442442356609, 0.024117556349665392, 0.09140407302766107, 0.0067512413443182595, 0.056477894613635726, 0.03263447833887767, 0.04239251429680735, 0.020631054176192265, 0.035043036987190135, 0.0186702907376457, 0.010901239311351674, 0.02151583892555209, 0.023690891939622816, 0.03228202498576138, 0.04071881543495692, 0.035773733325186186, 0.01927194058225723, 0.08138067103573121, 0.01677963613474276, 0.05257879543933086, 0.01982961446628906, 0.021379124191298615, 0.04772409207362216, 0.04036440281197429, 0.03268297397880815, 0.024185577894968446, 0.03232810864574276, 0.026293371920473874, 0.020762748281413224, 0.05721829453250393, 0.012291511047806125, 0.04307360177335795, 0.031203632461256348, 0.02743932585872244, 0.08173558831913397, 0.017231110541615635, 0.03803799248998985, 0.024078448877844494, 0.009335812374047237, 0.04386530265037436, 0.0388746786484262, 0.021651160277542658, 0.02490802526153857, 0.08334358484717086, 0.09655556495999917, 0.05355875691748224, 0.04478031136386562, 0.01529567938632681, 0.020600761563400738, 0.05723474423575681, 0.029781276753055863, 0.015310590988519834, 0.03969854791648686, 0.046826579491607845, 0.1662490502349101, 0.030162304647092242, 0.031209847948048264, 0.03528176363033708, 0.09790973956114613, 0.018261296863784082, 0.04809194499102887, 0.045049388136249036, 0.06836234693764709, 0.013460427035170142, 0.029973207274451852, 0.009058260275196517, 0.02858039460988948, 0.07486336020519957, 0.07026392224361189, 0.07860844518290833, 0.031725904045742936, 0.03672504048154224, 0.01433189858289552, 0.03854096823488362, 0.10098426442709751, 0.06281816982664168, 0.023643695058126468, 0.05722539317503106, 0.037729489122284576, 0.03386388307262678, 0.028540222156152595, 0.04094540054211393, 0.043020612429245375, 0.02612311396660516, 0.032878548445296474, 0.025721593519847374, 0.033211175323231146, 0.04947924164298456, 0.025324175294372253, 0.03958463195885997, 0.04368260073533747, 0.05230477596342098, 0.17225482093635947, 0.02610603714856552, 0.02617661168187624, 0.12568403006298468, 0.04193205990304705, 0.07341586795519106, 0.010974649776471779, 0.028313761358731426, 0.052093879858148284, 0.013115015735820634, 0.021997090152581222, 0.06477541362983175, 0.032373079084209166, 0.017155494970211294, 0.02326371173694497, 0.052202396691427566, 0.06759291049093008, 0.0066785470517061185, 0.01811937225284055, 0.03610041560023092, 0.03905729892721865, 0.01701311022770824, 0.033999525403487496, 0.03447789524216205, 0.08912041783332825, 0.021779969283670653, 0.09056652226718143, 0.02301818887644913, 0.04343114997027442, 0.03254405135521665, 0.09936031172401272, 0.06249418525840156, 0.03442241228185594, 0.07743372931145132, 0.09303638973506168, 0.039855348877608776, 0.03978381697379518, 0.027195103612029925, 0.041820696933427826, 0.03330865642055869, 0.05465048583573662, 0.011896372143382905, 0.042368776703369804, 0.043548865724005736, 0.01894170341984136, 0.01653843999520177, 0.07298774522496387, 0.05354703469492961, 0.04516131884884089, 0.018228306544187944, 0.09153969309409149, 0.03382273098395672, 0.053421259217429906, 0.04294567777833436, 0.00793113184045069, 0.03122336245724, 0.021687891021429095, 0.07763199406326748, 0.017160947900265455, 0.026740298817458097, 0.01596099158632569, 0.0133507283317158, 0.03347116449731402, 0.01852879286161624, 0.019286677779746242, 0.07007325708400458, 0.026879381002800073, 0.022753219891455956, 0.060586476101889275, 0.02905992962041637, 0.04609998723026365, 0.07663028765819035, 0.08510980725986883, 0.08189062296878546, 0.04793072454049252, 0.0744704672251828, 0.026497605394979473, 0.03189341790857725, 0.0537388316297438, 0.061835013402742334, 0.04908680137305055, 0.05952835163043346, 0.003887878597197414, 0.04305881077016238, 0.05017855255573522, 0.0199544511269778, 0.012507235751400003, 0.04739569914818276, 0.010064862071885727, 0.0368931183766108, 0.06202306249178946, 0.012546789439511485, 0.033848583698272705, 0.04715485738415737, 0.06352617128868587, 0.015770040699862875, 0.015085990198713262, 0.02073605322948424, 0.040442550962325186, 0.046308219025377184, 0.03127093783405144, 0.11888654364156537, 0.026079625968122855, 0.023716021059954073, 0.013604711675725412, 0.044454345261328854, 0.029410356910375413, 0.04114968040084932, 0.041804711072472855, 0.032741863396950066, 0.012255652327439748, 0.04920460247376468, 0.04558331514999736, 0.021115504059707746, 0.07945595556520857, 0.05006043233152013, 0.020250389934517443, 0.01757016627379926, 0.07236287914565764, 0.04651657698559575, 0.0470605452574091, 0.0631261759554036, 0.02658126028109109, 0.013379620140767656, 0.03133766062092036, 0.010330062050343258, 0.06821559465606697, 0.0723138454486616, 0.009868856232060352, 0.005116800703035551, 0.03216052056814078, 0.0060312704317766475, 0.058806872766581364, 0.06923175809788518, 0.03545377490809187, 0.03193946075043641, 0.02765091401670361, 0.07893473783042282, 0.08033865116885863, 0.027178099153388757, 0.0012660510583373252, 0.0034100785887858365, 0.021644445696438197, 0.04086843611730728, 0.03280215918493923, 0.01659145716985222, 0.09031727196997963, 0.04235365915519651, 0.07573055234388448, 0.04060930783452932, 0.014897926266712602, 0.026892327769019175, 0.013958288454887224, 0.0190010084406822, 0.03626389960118104, 0.01594773682882078, 0.06154731243441347, 0.04139070770179387, 0.030002557359694038, 0.030258620572567452, 0.07905721446149983, 0.07429393997881562, 0.06335397076327354, 0.02293100693350425, 0.024780203311820515, 0.013358917931327596, 0.040986741878441535, 0.01926013115735259, 0.07941760137327947, 0.04339757520938292, 0.03606966471124906, 0.024698025299585424, 0.010988211597577902, 0.020158207771601155, 0.06927375623490661, 0.014319859092211118, 0.03424385155085474, 0.12910069985082373, 0.15526967297773808, 0.18056021042866632, 0.09237436432158574, 0.11951982567552477, 0.22346583078615367, 0.08550355370971374, 0.2067683541099541, 0.13361297256778926, 0.13080480450298637, 0.13686807680642232, 0.1998051386908628, 0.07596999887027778, 0.11986291312496178, 0.12608904973603785, 0.1909176679328084, 0.19558067084290087, 0.15266561036696658, 0.16821087308926508, 0.08404634674661793, 0.10671749623725191, 0.17471667320933193, 0.19543176633305848, 0.21474151377333328, 0.08407592875300907, 0.18863307021092623, 0.1902921561850235, 0.10030824210844003, 0.16499090212164447, 0.20995828293962404, 0.17647887318162248, 0.11732375874998979, 0.21010441181715578, 0.11594403942581266, 0.13681854587048292, 0.17865544388769194, 0.10601414061966352, 0.15537231200141832, 0.07603025384014472, 0.15443147654877976, 0.15741278766654432, 0.1162647659657523, 0.12239865362062119, 0.12761772552039474, 0.18312562198843807, 0.12456352065782994, 0.1619524456327781, 0.13063023652648553, 0.08576917578466237, 0.2986052550841123, 0.1298221861361526, 0.15711662621470168, 0.13455426815198734, 0.1295380326337181, 0.2192143042339012, 0.1559205661760643, 0.2169978801975958, 0.2295942191267386, 0.08049494004808366, 0.07489844894735143, 0.06491101885330863, 0.0876109414093662, 0.21315379271982238, 0.08601949477451853, 0.18313877284526825, 0.11893152521224692, 0.2146103317500092, 0.2731177071109414, 0.17819565371610224, 0.18274910078616813, 0.2442693879129365, 0.11253109521931037, 0.06967061228351668, 0.19193850690498948, 0.1616042893147096, 0.13295749289682135, 0.07992807280970737, 0.11504848982440308, 0.1826807192992419, 0.1541113288840279, 0.11458834342192858, 0.14184172789100558, 0.1749133423436433, 0.13000758946873248, 0.07707620708970353, 0.18323906668229029, 0.20536787691526115, 0.14682815875858068, 0.16215003503020853, 0.12452999042579904, 0.15911264723399654, 0.10278408386511728, 0.09684167773230001, 0.10535728797549382, 0.1541587818064727, 0.10820214039995335, 0.056616739311721176, 0.1390194144914858, 0.12939861277118325, 0.11003964609699324, 0.20505175169091672, 0.08044472633628175, 0.11091090520494618, 0.08656116609927267, 0.15449714177520946, 0.12293151565245353, 0.11855193894007243, 0.08947548354626633, 0.1088397491548676, 0.11920692879357375, 0.09447038974030875, 0.07591403351398185, 0.1519470036146231, 0.12723676627501845, 0.13976215588627383, 0.09265094791771844, 0.26738604123238474, 0.14343687042128295, 0.12537253584014252, 0.24807148467516527, 0.11818088736617938, 0.07940059877000749, 0.17179304180899635, 0.17408094950951636, 0.07646513753570616, 0.18797922326484695, 0.18771797243971378, 0.1696273806737736, 0.1408130073104985, 0.10161497120861895, 0.10048314405139536, 0.14183821011101827, 0.13597105775261298, 0.1694900685106404, 0.1168054724985268, 0.12611492100404575, 0.14068883116124198, 0.2726958703715354, 0.17085026192944497, 0.1044545766490046, 0.18525471008615568, 0.19245934614446014, 0.1572075393050909, 0.13542635104386136, 0.09337584066088311, 0.17049976042471826, 0.0804030399012845, 0.13048642314970493, 0.11604737606830895, 0.12584951415192336, 0.18442602799041197, 0.09596803633030504, 0.1587746583390981, 0.20304170408053324, 0.10414943521027453, 0.12281749950489029, 0.11620678938925266, 0.19631545641459525, 0.12589946069056168, 0.24696985550690442, 0.14533083129208535, 0.1551786411437206, 0.12414017735864036, 0.14022151561221108, 0.1327086953097023, 0.13591748953331262, 0.0878576684044674, 0.15617259952705353, 0.17248225951334462, 0.1533620714326389, 0.09435637359274551, 0.19510995625751093, 0.08100144099444151, 0.13388348539592698, 0.10854570282390341, 0.26205786620266736], [0.06546426026034169, 0.017941138066817075, 0.018041157309198752, 0.024514885517419316, 0.01386169236866408, 0.05259537501842715, 0.02349008162127575, 0.027837547459057532, 0.01277083640161436, 0.04467171660508029, 0.028228939445398282, 0.04215873035718687, 0.020745057336171158, 0.08974853451945819, 0.01772152172634378, 0.028020718782499898, 0.0933169512427412, 0.02102676731738029, 0.011340311502863187, 0.06175931433972437, 0.02371811577177141, 0.010975618279189803, 0.07658938789973035, 0.018123650734196417, 0.0301834280253388, 0.027980982340523042, 0.02272607398481341, 0.08207306513213553, 0.029524625388148706, 0.053065544125274755, 0.07054927802528255, 0.08114106123684905, 0.04516576802416239, 0.016661738554830663, 0.056214365395135246, 0.021191783853282686, 0.07072495180182159, 0.018484607244317885, 0.029992694217071403, 0.03279866366938222, 0.041618309551267885, 0.022937567518965807, 0.0382405988057144, 0.021946149136056192, 0.10081059444928542, 0.0699723992147483, 0.018465187094989233, 0.047450276688323356, 0.025644211636972614, 0.030701679024787154, 0.015119759773369879, 0.06941555097000673, 0.05276658477669116, 0.03240230114897713, 0.07646757178008556, 0.05140443579875864, 0.04359628524980508, 0.012310546208027517, 0.02968792756291805, 0.03347509788000025, 0.05356845307687763, 0.04766136575199198, 0.016774882678873837, 0.050507598571130075, 0.029563621537818108, 0.022767725167796016, 0.054057142478995956, 0.03441601125814486, 0.020398765664140228, 0.03286246610514354, 0.04016360362584237, 0.057764129305724055, 0.07445734605425969, 0.03964620424085297, 0.018846417224267498, 0.06881522029289044, 0.03700148678035475, 0.047543609180138446, 0.06977187833399512, 0.08367755872313865, 0.0885158717574086, 0.003329945193399908, 0.05109411787998397, 0.057405846382607706, 0.048353140155086294, 0.04691076130256988, 0.020524004939943552, 0.07033291971310973, 0.0470886095718015, 0.01353028910671128, 0.021550591845880263, 0.018027032383542974, 0.00823883183329599, 0.09436323103727773, 0.07621731216204353, 0.02646332188305678, 0.029617085856443737, 0.011245731275266735, 0.033468863839516416, 0.09174711594823748, 0.034993450390174985, 0.06519532820675522, 0.05497997713973746, 0.028883602753921878, 0.015676548646297306, 0.03328611739561893, 0.019596400125010405, 0.08293148508528247, 0.02498987116268836, 0.015973288973327726, 0.022423793525376823, 0.02633830710692564, 0.015734284024802037, 0.004459520860109478, 0.07391517006908543, 0.1329035684466362, 0.04946616500092205, 0.03670855367090553, 0.03054953875107458, 0.022401291607820895, 0.05869595137482975, 0.031445732165593654, 0.058629102422855794, 0.08976121782325208, 0.015771064863656648, 0.04217878318740986, 0.030365647544385865, 0.02068868936476065, 0.022427717631217092, 0.031278014212148264, 0.07339654242969118, 0.04896629514405504, 0.05091771308798343, 0.03056862307857955, 0.02543810423958348, 0.061940799132571556, 0.010355469476053258, 0.08577486063586548, 0.00419945700741664, 0.023461054370272905, 0.030794538397458382, 0.030686930695082992, 0.008068602637649747, 0.043036576025770046, 0.044600351684493944, 0.04824591465876438, 0.02219348469225224, 0.05295206603477709, 0.034276031074114144, 0.051111087086610496, 0.10096850121044554, 0.0728381505177822, 0.04156762828642968, 0.07809426300809719, 0.09117372523178346, 0.0373554763791617, 0.021034309393144213, 0.034348446133662947, 0.02149604399164673, 0.0527274030901026, 0.01785388190910453, 0.025487761340627912, 0.01876484962849645, 0.047430902923224494, 0.0660489835718181, 0.03813326569797937, 0.08121720558847301, 0.017146294194390066, 0.044424050793168135, 0.07659325448912568, 0.06042758970579598, 0.041121144822682254, 0.07207206857856363, 0.03917617243132554, 0.037471811738214456, 0.04175339527137112, 0.03795281249040272, 0.056268954067490995, 0.05247226385108661, 0.007519712999055628, 0.05705933021090459, 0.029214700807642657, 0.06449120817705989, 0.09263549640309066, 0.016179173726413865, 0.045125918404664844, 0.03234088100725785, 0.03709411794261541, 0.04969342175172642, 0.07952270432724617, 0.019110681168967858, 0.028735249288729392, 0.08955638506449759, 0.043284004350425676, 0.01180275949081988, 0.023956120676302817, 0.04527008059085347, 0.022746575814380776, 0.09112837258726358, 0.04931753879645839, 0.01373322753352113, 0.026654975954443216, 0.05241843216936104, 0.02959245026431745, 0.011090775478805881, 0.03463574263150804, 0.05133419152116403, 0.041955352207878605, 0.006752875460733776, 0.05154028593096882, 0.04674306561355479, 0.00229976350965444, 0.06438922966481186, 0.006272621494645136, 0.1033770153298974, 0.02761624644335825, 0.019321324944030493, 0.03276977557106875, 0.029394326520559844, 0.05191400181502104, 0.11649161082459614, 0.06255875210626982, 0.020879007570329122, 0.013314949392224662, 0.02020132655161433, 0.0452063783450285, 0.024702320479264017, 0.054882165786693804, 0.00969957420238643, 0.047326979984063655, 0.047846772795310244, 0.06391981383785605, 0.011494894370116526, 0.025632487559050787, 0.025951163916033693, 0.05641609226586297, 0.10695865712477826, 0.050731434021145105, 0.044103591426392086, 0.03586580787668936, 0.05687068740371615, 0.01905261739011621, 0.03481157596979756, 0.023382158506137785, 0.054517893731826916, 0.032221332148765214, 0.017391956207575276, 0.04585798771586269, 0.014820403375779279, 0.088513571099611, 0.002311304833710892, 0.055882039087009616, 0.09108082318562083, 0.03853373971651308, 0.012664205551118357, 0.04186927049886435, 0.028075043992430437, 0.020815110510739032, 0.018723361718002707, 0.042025492584798485, 0.03534980001859367, 0.014267960705183214, 0.058667478879215196, 0.031631525125703774, 0.04828722259844653, 0.05920483832596801, 0.008045980121096363, 0.010642355009622406, 0.06586952484212816, 0.04853262485994492, 0.033305127508356236, 0.08848541401675902, 0.020197469239064958, 0.04240080037561711, 0.0485959263460245, 0.016725502027838957, 0.032583819338469766, 0.021290313234203495, 0.06304989059572108, 0.08885403876774944, 0.028249669485376216, 0.10536749992752448, 0.029334331302379724, 0.028554788659675978, 0.007267972332556383, 0.09667196340160444, 0.04130037719733082, 0.05287137231789529, 0.04209813028865028, 0.02986862753459718, 0.026213722776446957, 0.031984152883524075, 0.007184299820437445, 0.006896952299939585, 0.05439791071694344, 0.04590672455378808, 0.07056997652398422, 0.04722419624158647, 0.0072448799437552225, 0.09614507565856911, 0.022764841924072243, 0.03519382655213121, 0.029030008081463166, 0.01192582427393063, 0.029581082417280413, 0.05041468910349067, 0.05950105172814801, 0.0718859008338768, 0.0434263519855449, 0.03561966346751433, 0.07222004540381022, 0.02726033653743798, 0.05368590536818374, 0.08184686594177037, 0.012883248582511442, 0.004176987094979268, 0.022473508142866194, 0.025258745699829888, 0.03364848584169522, 0.03362969837326091, 0.02174759309127694, 0.02538592198106926, 0.03192973861587234, 0.05128637494635768, 0.03746747017430607, 0.04763886383443605, 0.042368951108073816, 0.06876831655972637, 0.03608264116337523, 0.061061984961270355, 0.0739831656392198, 0.04888386851234827, 0.028353612833598163, 0.056033837972790934, 0.05404891577200033, 0.04737020266475156, 0.02561886914918432, 0.03426115472393576, 0.044052156881662086, 0.02508111450879369, 0.014388087511179037, 0.027360147978470195, 0.03471878153504804, 0.016506243773619644, 0.018975949824380223, 0.011041406887670746, 0.060464103371487, 0.05009189939300995, 0.06940587336430326, 0.026135361258639023, 0.014076292718527839, 0.05848343738762196, 0.14675876795081422, 0.1269985517137684, 0.14083252579439431, 0.08676979865413159, 0.11091960317571647, 0.15460024093044922, 0.09899021752062254, 0.11391514126444235, 0.11191619618330151, 0.1275600161170587, 0.10313227729056962, 0.09559959711623378, 0.09495410675299354, 0.25667830486781895, 0.13446877273963764, 0.07494713383493945, 0.3643219865625724, 0.09541670224280097, 0.08156861993484199, 0.20952428982127458, 0.20155494479695335, 0.09526481429929845, 0.2405103505589068, 0.11476604326162487, 0.1437932497356087, 0.10640515596605837, 0.11525125941261649, 0.21081666578538716, 0.07951711595524102, 0.12159418038208969, 0.15465009841136634, 0.15688580344431102, 0.15676737151807174, 0.11909848617506213, 0.19062487583141774, 0.1553648163098842, 0.168533306568861, 0.10106207118951716, 0.1933871940127574, 0.14716516801854596, 0.1819394325139001, 0.1015538108185865, 0.10572768645943142, 0.10246400299365632, 0.22822840022854507, 0.17088414839236066, 0.08944429107941687, 0.15940379176754504, 0.10265397053444758, 0.15117983071831986, 0.12341589317657053, 0.235177930444479, 0.1529887117794715, 0.08796334281214513, 0.10910916360444389, 0.25482958531938493, 0.08448912689345889, 0.17842217202996835, 0.11329792672768235, 0.15805395873030648, 0.1586059236433357, 0.2320610437891446, 0.08229179089539684, 0.0905723703908734, 0.12915950763272122, 0.08871500482200645, 0.10377980855992064, 0.13408879312919453, 0.11255352292209864, 0.12893757579149678, 0.1216000656131655, 0.16522873076610267, 0.15057107666507363, 0.10679781145881861, 0.08188781765056774, 0.14425240166019648, 0.13639972225064412, 0.10567198827629909, 0.11433093692176044, 0.2654430689290166, 0.12084089306881651, 0.14869191421894357, 0.11087656603194773, 0.15497869171667844, 0.15135508147068322, 0.14051919104531407, 0.1023371254268568, 0.14278495305916294, 0.11446288335719146, 0.14537044713506475, 0.09803429420571774, 0.16822446923470125, 0.11965651443460956, 0.2873073925729841, 0.20493829215411097, 0.16669476928655058, 0.10443107283208519, 0.12857637251727283, 0.12333442762610503, 0.13005369168240577, 0.10940338805085048, 0.12136845616623759, 0.18454054137691855, 0.15085953462403268, 0.15390196902444586, 0.2058595942799002, 0.20287776365876198, 0.15841563697904348, 0.25116542412433773, 0.2637523674638942, 0.1647740465705283, 0.12459011923056096, 0.11208410709514283, 0.1708486143616028, 0.1576963474508375, 0.20067172968992963, 0.14502696634735912, 0.047394274224643596, 0.15365407685749233, 0.11165730538778007, 0.13241689768619835, 0.14283797208918259, 0.11243039320106618, 0.3022537718061358, 0.1135589845944196, 0.13530444586649537, 0.11877056080265902, 0.1163378452474717, 0.1285690104123205, 0.18470635201083496, 0.1577281262143515, 0.0955764643731527, 0.13275751378387213, 0.12458965909900144, 0.1991706172702834, 0.13896681106416509, 0.11440838003181852, 0.21060748404124752, 0.11720371636329219, 0.15133531065657735, 0.14060882764169946, 0.1482460170518607, 0.11872327115270309, 0.15848053037188947, 0.10049013508250937, 0.1238484465284273, 0.12452653201762587, 0.16350795747712255, 0.17105807812185958, 0.28554063581395894, 0.17044530162820593, 0.2689932065550238, 0.1679772004717961, 0.14832174580078572, 0.1313480269163847, 0.1310567487962544, 0.20921423536492512, 0.19200635404558852, 0.1254415704170242, 0.13619144592666999, 0.19304800283862278, 0.17399549862602726, 0.14849122264422476, 0.15811484452569857, 0.13060938217677176, 0.12148750407504849, 0.11689936160109937, 0.1271685035317205, 0.10811260028276592, 0.18877103546401486, 0.17877979815239087, 0.10974891716614366, 0.12059151660650969, 0.15137552021769807, 0.08805214078165591, 0.1297790525131859], [0.011506883765832754, 0.06617713763262145, 0.02732516313699307, 0.03965661657275632, 0.033804414779297076, 0.03807802022492979, 0.018351350918237586, 0.04503780321101658, 0.03304981015389785, 0.03150585725961719, 0.04761279218655545, 0.02612486914586043, 0.007670542918276624, 0.03368024234077893, 0.05675584005075507, 0.04018258776341099, 0.043360260024201125, 0.05213407828705385, 0.07984962780028582, 0.07056134534650482, 0.03019645457243314, 0.04629102717444766, 0.08058419814915396, 0.011454864779807394, 0.009790822186914738, 0.09363041957840323, 0.06241865688934922, 0.07779931867844425, 0.03330737992655486, 0.008755835096962983, 0.023525478354713414, 0.027451307832961902, 0.01753448752424447, 0.0402809408842586, 0.01584159857884515, 0.005592623119810014, 0.07831715964130126, 0.06001319670758676, 0.05580131197348237, 0.02591105268948013, 0.04166302765952423, 0.1513890124624595, 0.08142177859554067, 0.03179008868755773, 0.017271782089665066, 0.09824955413932912, 0.048398207072750665, 0.05749487812863663, 0.03227115252229851, 0.03465409223281313, 0.02952666072815191, 0.026789425282913726, 0.05324460209521931, 0.06076180849049706, 0.08485465688863769, 0.037604641329380684, 0.030015685952093918, 0.018861191529140342, 0.04728165702545084, 0.025602050227462314, 0.02663189145096112, 0.08430428017163649, 0.021018408879172057, 0.012831673957407475, 0.06469342115451582, 0.03412714140722528, 0.0780306980595924, 0.04117292817682028, 0.00934888066694839, 0.03720422297192272, 0.03181039384799078, 0.02175515372073278, 0.019016775368072558, 0.013678422710654559, 0.04316833321354352, 0.0695261532382574, 0.05741302295064088, 0.014559534756699577, 0.032915032425080426, 0.10217571572866291, 0.050258047704119235, 0.04982804734027013, 0.02247460652142763, 0.02227881868748227, 0.03086622615228407, 0.039470289266319014, 0.03179127241310198, 0.00296902625450457, 0.028932059431099333, 0.023383824627671856, 0.0395396318344865, 0.0421953961631516, 0.019943437655456364, 0.032137090965989046, 0.013656819719471969, 0.017428534811188, 0.03708081494551152, 0.021978169097565114, 0.02899877665186068, 0.03522004662954714, 0.07401977578410879, 0.02860029158910038, 0.028691184270428494, 0.07916984279290773, 0.015505650590057485, 0.028435505118977744, 0.057224561969633214, 0.05295504946843721, 0.07343049568589777, 0.09341648808913305, 0.06471184868132696, 0.01988760217500385, 0.03037484460946871, 0.014820993383182213, 0.014316862670966657, 0.02568229494499974, 0.03887580300215632, 0.06118904806498904, 0.06324034795397893, 0.03309664338303264, 0.03153487894451246, 0.023022213172225747, 0.011117711728729773, 0.030665397280245088, 0.00856481277878629, 0.06797418885980733, 0.02734987108851783, 0.059192069675191306, 0.05346175821614452, 0.014532549339492107, 0.03357406327268109, 0.010951062467938755, 0.07529245514888316, 0.018317911599297076, 0.018056196931865998, 0.05865673258085735, 0.0551848210307071, 0.039535702162538655, 0.02556574621848995, 0.011219915668334579, 0.08684638087288477, 0.01948409462784184, 0.07259591351612471, 0.03093027164140949, 0.10027320531662554, 0.07504618086386472, 0.06967796696699224, 0.11093377819634043, 0.05118857472552918, 0.053686280152760446, 0.03384269475645851, 0.027958608443441335, 0.02910568488005083, 0.008520828469045227, 0.0393777360295644, 0.02854020360246068, 0.06201647222042084, 0.015930693407426588, 0.061516528148786165, 0.010441621689096792, 0.017588879527465906, 0.013164221982151503, 0.041143650450976565, 0.043862541861017235, 0.08561978145735338, 0.006539697251355392, 0.039016503069433384, 0.0808383540424984, 0.061096457720850594, 0.026675804328988306, 0.05446416966151446, 0.02689751909201732, 0.041214993107132614, 0.02419980115519138, 0.06743879610439762, 0.03349791521031875, 0.035711615564650856, 0.05588725267443806, 0.10720414473325945, 0.0066447199606045615, 0.01134460668254178, 0.029940604727016762, 0.05570481422182638, 0.016925030286074616, 0.0464371337875491, 0.06387869143509306, 0.043250759845250286, 0.01955642619577702, 0.03224664680601563, 0.023744736608932726, 0.049313868876197375, 0.0603921744186664, 0.022127557858766522, 0.06073810058296658, 0.04037639962916728, 0.09760568165802397, 0.04155128619458992, 0.05445647730084602, 0.1436006327276118, 0.05004345941415522, 0.0377249249140732, 0.0427339987072628, 0.05234270713117439, 0.06952293973881751, 0.02547390729887411, 0.032822512584971264, 0.054802262457087636, 0.056805664135026745, 0.05899337447772268, 0.07208581315353513, 0.06501832598587498, 0.051679319876711816, 0.012527030685305363, 0.04461686075956095, 0.025934113073162735, 0.03989748431195039, 0.049296506331302226, 0.07020458753686398, 0.026943035009026062, 0.03524877887684852, 0.007994801617314806, 0.027474392336443998, 0.02380365571298171, 0.0561232148174895, 0.03973819715611171, 0.0570819471613504, 0.053917273617116734, 0.023701743994024582, 0.05758309351222124, 0.06987888860749081, 0.024792474723653868, 0.020111686244490556, 0.10152175746043213, 0.040338546386919916, 0.04328985247411765, 0.013911979367549066, 0.07316617236938328, 0.08496849492075853, 0.03086799431912368, 0.028607891181309242, 0.006522173753182869, 0.02811505131830927, 0.10033999118604697, 0.04348611713794526, 0.025723215112520847, 0.05190687719732523, 0.08351172582479194, 0.04542248432699125, 0.09195913269650191, 0.07418254361255094, 0.0381123000261141, 0.01450945834221784, 0.05607793638773728, 0.04195310721115675, 0.0735321402316913, 0.04904116671241354, 0.05546318949200213, 0.10089637929922901, 0.04896187936537899, 0.03366642355103977, 0.032807584284455515, 0.0748128051054664, 0.04503728370764293, 0.031146787659963593, 0.05486123722221237, 0.12475809693569317, 0.04761815791425761, 0.05653731837810483, 0.015075641877047019, 0.045252220807014965, 0.03563101090549026, 0.02051832379947882, 0.033667024690657854, 0.044917311824974604, 0.035022954471060075, 0.01702991059573833, 0.027103524444100913, 0.00643344675154367, 0.01453489452615031, 0.05269831090117805, 0.023245979973580688, 0.019132103261654265, 0.013994817891216371, 0.018041502407868393, 0.02380799356615171, 0.03072959676501341, 0.012708811409538612, 0.024278322234749794, 0.036123592872172594, 0.015972711953509133, 0.021979308294248767, 0.036668934117187746, 0.051537398976506665, 0.06444863116485067, 0.04555571838864125, 0.007424054801958846, 0.048115856989170425, 0.013746417353104334, 0.03736661972652655, 0.08489571249810979, 0.008898488867998822, 0.02791483471810352, 0.022852196416351944, 0.05873895141121466, 0.03384451672900468, 0.024000577177503146, 0.017082193044188898, 0.022026447659300175, 0.1419969109701924, 0.04506286553805694, 0.040631642768858, 0.022707874668412842, 0.007270531814356218, 0.004966725919075543, 0.07575316558359191, 0.05484423461894039, 0.028694227075902745, 0.022138402491691522, 0.027308205062581692, 0.03169773583067581, 0.10571982711553574, 0.14660451997769997, 0.011614827290031826, 0.05406585529271979, 0.06456435425207019, 0.031095117483346257, 0.013462942915793974, 0.033434929137001745, 0.030602967817685567, 0.026083344127982855, 0.04502993273490574, 0.02631987772474531, 0.05406224103353452, 0.021378493365773465, 0.047239384293789044, 0.06252001199754886, 0.0780291469709482, 0.022216300167201553, 0.029837900765414815, 0.03179905754223, 0.13838559068972245, 0.01180727453174768, 0.0586975989426719, 0.006397073166226619, 0.03763375207199715, 0.03786087152548134, 0.07244805543450639, 0.002748396650531504, 0.022700106237607542, 0.043998507026117295, 0.03380081536306534, 0.010890117300732527, 0.11208661555428989, 0.15144599456107244, 0.13658137031598017, 0.2447952885995619, 0.10644110559951514, 0.22216886834939942, 0.0923400696774479, 0.096480444772169, 0.13734512933297083, 0.18093978927936405, 0.16520901932381094, 0.16213810129556805, 0.10818136026500724, 0.07110193313565105, 0.15781620430061594, 0.20065645629074425, 0.10641836619470268, 0.1854043419007212, 0.12182751903310418, 0.1455310924211517, 0.1515802342328243, 0.1404987819842063, 0.32748780213296413, 0.10426757027744316, 0.1078669865091797, 0.20111516292672604, 0.14424153661821038, 0.14438313839491457, 0.16610873979516327, 0.09600495817721821, 0.22671142069157213, 0.22033991961507127, 0.07434235027176328, 0.1760313581326045, 0.14710826013470069, 0.12015082931611687, 0.2533116261474788, 0.2531193208415061, 0.12703187414444983, 0.10439581339596771, 0.18362140632234514, 0.3006019291933626, 0.1804876877577044, 0.10430370544781908, 0.0753754198376555, 0.1623527007177472, 0.08418227851507254, 0.19145498285070062, 0.1092318628798239, 0.11394484943593852, 0.1106150628766045, 0.08838864538120106, 0.1777798283728771, 0.15828813600819558, 0.14107054739724845, 0.1309255964588374, 0.23587148229125887, 0.1855884984252043, 0.15621862752595916, 0.15836649195989594, 0.10748954504379071, 0.20805890439078212, 0.10820578434504569, 0.07545801345258951, 0.11273887430434115, 0.10727153916377574, 0.20027061371365562, 0.18664962117327377, 0.13030817412072793, 0.25297632382716984, 0.09898710050038062, 0.16652309568598866, 0.13813965779263526, 0.15713856410002336, 0.16719623847166076, 0.2122359341592528, 0.12229399595526047, 0.10497008726815693, 0.23014284437522292, 0.28821361425798386, 0.15023414161987603, 0.19525894982507452, 0.1282626370084472, 0.11229083975194953, 0.13336220086785033, 0.13832802971592173, 0.17734062537783757, 0.17388007981935516, 0.11651409789919853, 0.18727283226326108, 0.10465833329362795, 0.10420279562822543, 0.1263578110956587, 0.10537276917602867, 0.14391266129678115, 0.1448963928851299, 0.1612647419096902, 0.11399518931284547, 0.07694456493481994, 0.10916331069893204, 0.10111828887602314, 0.11779606895288453, 0.11331527071888559, 0.13089203654089943, 0.17227442847797647, 0.21661833103280514, 0.1533336768625304, 0.1091275985527318, 0.11476288913399912, 0.1714842490036972, 0.1076451363041997, 0.07989010453457013, 0.10236228423309512, 0.14133193180896342, 0.11639338757959194, 0.09107585821766406, 0.12157469158410095, 0.1437328537576832, 0.11551212432095781, 0.17892230534926057, 0.11885768893989734, 0.08207107617636211, 0.11424787575379014, 0.15987967170076445, 0.057693599301273935, 0.1278340764110908, 0.12444852487533353, 0.19312272226670757, 0.12592387734912336, 0.06672447896562517, 0.1591293455567211, 0.18889392027631402, 0.27957721205893904, 0.13754760206211358, 0.1426537413499318, 0.08359054190805182, 0.1214846245420631, 0.2051991570624523, 0.1062284060753882, 0.08328922252985649, 0.18687987991143018, 0.16416155209299177, 0.12731090682791546, 0.10326535179046914, 0.14656030281912535, 0.3791706101037562, 0.13834864657837898, 0.13073869398795068, 0.16979246400296688, 0.16677187843015417, 0.16613302286714315, 0.1402092256466858, 0.11264640270383097, 0.1202451488643419, 0.13139663758920506, 0.12229831525473855, 0.25877926556859165, 0.09958421025658026, 0.09702163370093331, 0.07201607353636064, 0.22529678331920877, 0.0751783128362149, 0.1936272787861526, 0.1343962797545828, 0.15179317124420777, 0.0677620607893914, 0.18425810965709388, 0.13576905999798328, 0.09494929763604887, 0.12240045703947544, 0.10585307973087765, 0.10807530736201443, 0.12474027054850012, 0.136300289304927, 0.12433156982297078, 0.13700071343919262], [0.041572660047677346, 0.035177005775040016, 0.03122659822111018, 0.011979648534179432, 0.02497235833288869, 0.03748280665604398, 0.10785009522805922, 0.03188956616213545, 0.05054283203207888, 0.017116205672209617, 0.05637710353767034, 0.03306999657070264, 0.04690497626143042, 0.07873050621128641, 0.06650268071098253, 0.02233952265669359, 0.01710785465547815, 0.02115842988132499, 0.024420083573204465, 0.01513655550297699, 0.07119313566363417, 0.01567697723658057, 0.04770225066749845, 0.01166240544989705, 0.021247658296488225, 0.04711464040155988, 0.04347172689449508, 0.03613530396251008, 0.09830398324993439, 0.016021908922994044, 0.03789062051509973, 0.0039469027615268715, 0.022856124232930597, 0.0741331314202398, 0.017796959182305727, 0.05605223952443339, 0.11927608953556046, 0.038269019350991584, 0.07973949308507144, 0.02659130153915612, 0.05846679472597316, 0.038306854039547034, 0.029956299295008648, 0.010074540605273796, 0.03365974793268833, 0.02569179629063001, 0.030542341773980297, 0.017632245071581565, 0.025711750786285847, 0.046252160900621675, 0.011767955547838937, 0.03633862274000421, 0.038658242410747334, 0.10583476352621801, 0.014126929454505444, 0.025572130543878302, 0.005319331876307842, 0.010084746063512284, 0.07191859986050986, 0.013603231091110501, 0.026210217984043993, 0.0072852625180530595, 0.018169734394177794, 0.055586927774129435, 0.02802313261781819, 0.0972688282490708, 0.016487870052515063, 0.04752734130306635, 0.013077005714876577, 0.024085838813334703, 0.016999610561470035, 0.0993559330527205, 0.022300257478491403, 0.02916595469287131, 0.05384268777561374, 0.008269585505331634, 0.030999256123322994, 0.04611485986970365, 0.04504044154600706, 0.011672143355099251, 0.057771187130128965, 0.01674991497566225, 0.06308695345069282, 0.02373705352511024, 0.032928584041655995, 0.03457458224147558, 0.05481719446834177, 0.022835457275505178, 0.06670394373941235, 0.015525328635703772, 0.016966607254289556, 0.005668334242727724, 0.04617165643139742, 0.034791578800650313, 0.046413221789407544, 0.02311530632141512, 0.042912143835565075, 0.009019217741297325, 0.04621727995981928, 0.007406612012346159, 0.0401780717947986, 0.015840823034523055, 0.06518901995150372, 0.019866066904796753, 0.07229264971101657, 0.06465951242716983, 0.0603303164098179, 0.03736073449545074, 0.0342856901261257, 0.07475240912754089, 0.06076167861465365, 0.09185729519231245, 0.04096603224752471, 0.04273642181942705, 0.065890408877749, 0.04824818191991653, 0.02399431716185063, 0.026575100455374923, 0.00908432450160035, 0.03384116593224462, 0.03365363634657115, 0.03631582025263924, 0.07143536524381489, 0.030314007053675596, 0.04703308208263479, 0.024415493389824405, 0.029151477247069124, 0.01853564659541007, 0.07192487842985429, 0.061215038076625206, 0.03854398877592757, 0.012950409236509586, 0.09575765230692923, 0.02621566534799058, 0.0728751985298004, 0.10027775468188338, 0.04554920604277868, 0.052006432597409, 0.049259324732702225, 0.056381036920356564, 0.03844717932224739, 0.028488867392297834, 0.013856850782758556, 0.044901889996253885, 0.025932033204298932, 0.04916971411148552, 0.011425794855313143, 0.03543847182299942, 0.02141911110811634, 0.03067085021029925, 0.06394391137291677, 0.033086950934375636, 0.05654698114085477, 0.02754108172666747, 0.0487514916312648, 0.04687621432822198, 0.021490327599167358, 0.04233605541230645, 0.048868461526581086, 0.036312692100182176, 0.05266230560664553, 0.020864953148702625, 0.038070936425356194, 0.08300592249725014, 0.023913738477858715, 0.05324343692336697, 0.012224033125676215, 0.03944490410503931, 0.032600859049125575, 0.04752426510094665, 0.042911628042929806, 0.031962545253918506, 0.04480954827158712, 0.032820286141941324, 0.049040265002986416, 0.07175675971666351, 0.011083519129897468, 0.048771399742690846, 0.01719300496915821, 0.07420978785376064, 0.03659958783828188, 0.03898928109265398, 0.10696400058805011, 0.020707437870441936, 0.05506512003194075, 0.053564645859296434, 0.08235210523707792, 0.029982126034155954, 0.05549777728447225, 0.06131469737738371, 0.05741643311921507, 0.04610614705597982, 0.0638932226866018, 0.02309677489392925, 0.027175672330486123, 0.058815607844735496, 0.0495020515518263, 0.09308760534622706, 0.05750698626798112, 0.07459150408976711, 0.030884395782777574, 0.01250991675988189, 0.045197561630629934, 0.07122112947399728, 0.07471667471691035, 0.02739467454375699, 0.05745482070778962, 0.023625263820576947, 0.0367624298814917, 0.01761118106514914, 0.020829849563597236, 0.07262974802870303, 0.04335069745138753, 0.05173794212169014, 0.04298529733205214, 0.036413219713722356, 0.03100527865171898, 0.03240025653212797, 0.0607937356835464, 0.08233822707552463, 0.08581796457292512, 0.035937091161031276, 0.02240243451524293, 0.05858389449713286, 0.01599801176780602, 0.018291999513166957, 0.02906769805122167, 0.04184670920949429, 0.02735860245593358, 0.048399550360045396, 0.035731308453250676, 0.06443954727728851, 0.015306979512388352, 0.04755119764013216, 0.029745520077995025, 0.029543973178078886, 0.002319496984455327, 0.056020720512606204, 0.02676910713489633, 0.05845622654305771, 0.011715083091985434, 0.0170047091160086, 0.0401810144103365, 0.029301142458280083, 0.03156267608574126, 0.07150855584768578, 0.04446486149390694, 0.022063423311919905, 0.03159550869895611, 0.02931368289864622, 0.04719186828879174, 0.013853215186827583, 0.03509533984470181, 0.041986166179412976, 0.017135045090981293, 0.0033613215737204882, 0.032322972983820364, 0.0356367996573681, 0.05946975536062382, 0.07955502485856414, 0.035351803817320615, 0.045883996281190775, 0.01430618780432269, 0.01383730539600947, 0.022637086767645087, 0.009665301822678884, 0.018932517486973666, 0.04067033834871836, 0.04977618977136444, 0.01672930367931258, 0.08240834518801421, 0.02421828805381665, 0.03949706966523081, 0.018430610434734263, 0.018461767649569083, 0.020626580881071277, 0.02940856462373631, 0.06786351979826577, 0.023358049838861916, 0.04288738207833376, 0.055884562389110215, 0.005718880529457238, 0.04214133812638465, 0.04251771460985765, 0.02061006067378912, 0.04837446576857474, 0.01804656199965393, 0.02739533876592759, 0.02483460273651872, 0.06466849241405725, 0.008345517417183146, 0.08378776765312068, 0.058885150792775676, 0.04249140547472052, 0.008489875344821485, 0.014796762261539698, 0.036089190616621636, 0.03171643053065054, 0.01354753847408574, 0.06021729474014137, 0.06886580507853068, 0.05223509200732224, 0.035389478944125585, 0.04069327442266513, 0.042359859799034894, 0.0355854986992199, 0.003519855217746226, 0.05127819276822265, 0.040132396316039376, 0.01979874668904813, 0.06306988405412994, 0.0141140142295626, 0.06491367574199103, 0.02113203539920505, 0.04177722934400663, 0.031017457295092754, 0.044930050789844245, 0.037146083122934215, 0.02102084683428984, 0.03590216569136828, 0.029367243696469814, 0.14502062840620056, 0.029527805490943138, 0.027978301332041156, 0.05804011547297705, 0.05783623637398705, 0.044740057273884304, 0.032042036691564135, 0.025389506554347463, 0.04406871790706646, 0.0246111847445718, 0.008024955077416962, 0.08295490726595744, 0.11924524587811902, 0.030278445192379877, 0.019451954067335464, 0.0450432208890561, 0.03673105558846146, 0.006585040619029314, 0.029516925606003497, 0.04058243466715794, 0.06798362897825427, 0.01569040268805111, 0.07235216253320687, 0.038089170993771404, 0.03416136925807223, 0.03512492185109295, 0.028268212045077235, 0.010058035240945173, 0.017436537018511444, 0.027885360323125497, 0.03419956017751247, 0.09349277344881557, 0.19026428111828864, 0.11029434375814162, 0.1086182329163421, 0.07361066687735729, 0.17770442616892979, 0.2572521928232163, 0.07845189655199647, 0.1891708155744709, 0.11030448891688138, 0.2127676087548025, 0.07018862394033931, 0.1920030589099042, 0.19378958648303524, 0.1712679277989082, 0.11093657609308138, 0.17113500915002078, 0.08898139873053879, 0.12032835846184753, 0.10682305932277814, 0.1381679781479761, 0.14997541409684345, 0.17912789509864524, 0.19663688057335094, 0.12786987761501223, 0.14383380068466067, 0.0989593515987508, 0.10941859465674497, 0.2273508402868174, 0.10345689268433489, 0.17074358562240377, 0.10776260343845934, 0.19256358820712194, 0.12940860207891092, 0.248606780951377, 0.20294795598601922, 0.22283031488768756, 0.13108453480526805, 0.17678489035461098, 0.11920199351152405, 0.1201097885495983, 0.11102198986918665, 0.17718584305839613, 0.1414748842944391, 0.2384805172914639, 0.12130710281780921, 0.09403186209965497, 0.12262062256922945, 0.0748509143886622, 0.13321610167622566, 0.09716972184833139, 0.19917564903153107, 0.15900205238722265, 0.17139372183009982, 0.11341649224050343, 0.24186107417335734, 0.08399305312195793, 0.14734417403815314, 0.12552838685223833, 0.1738627432496287, 0.08585347633925267, 0.12603456125361845, 0.13484360184520483, 0.14507943618809804, 0.10523202829062939, 0.13989896338898689, 0.09562140883645043, 0.2073302341159433, 0.21239763329504058, 0.1612018671585247, 0.11459190573077649, 0.13786237657768652, 0.08882052337867208, 0.11144715885166079, 0.16352670412743464, 0.10587075026705861, 0.08058661755057983, 0.24856783304130659, 0.17885986104374751, 0.10965142864733934, 0.11327351749059744, 0.11159337678691372, 0.12058448846801184, 0.1663704210659489, 0.12565936107421294, 0.11307260327157564, 0.1035182608757168, 0.1638967834878713, 0.1535930871614255, 0.12386101108859293, 0.062483119836542755, 0.11367827741196379, 0.1454613750684075, 0.09814010962145403, 0.14458529942203313, 0.08970432478236035, 0.16154047945747152, 0.14346269716043025, 0.19134412083076313, 0.1366292536840774, 0.13779939792584628, 0.1546397974016145, 0.15378552605398, 0.21159038442419842, 0.11943194796913303, 0.18758082354906946, 0.12875272164819762, 0.10377738915849477, 0.17235974577488378, 0.12451143673388287, 0.0949803862022236, 0.21283124049659818, 0.1370614062761888, 0.15433070773724467, 0.17875017161713913, 0.17200924427015707, 0.16328140947734937, 0.17372737551340833, 0.09936598915373906, 0.15099892480066046, 0.10470816851011477, 0.10626584000419825, 0.16100513865239918, 0.10982416351907887, 0.14531929831719026, 0.08700666992808692, 0.16003947093850002, 0.20958719425834715, 0.1343121350510046, 0.1699166401522234, 0.08370511466637254, 0.0831856632430572, 0.1852364235674031, 0.13803382753394544, 0.17201338545419276, 0.1631529288715683, 0.11822980974102393, 0.13967004051664844, 0.15264469664543867, 0.1993686519563198, 0.07938527342048474, 0.1569298721733503, 0.13132592575857416, 0.1719149321434088, 0.13973981724120677, 0.17711599211907014, 0.10576149870757945, 0.13071444060187787, 0.11421217845054343, 0.15522039437200874, 0.17244933784240857, 0.07340401585679501, 0.11754844395909458, 0.14008309022756293, 0.12404872250044718, 0.08421287726378068, 0.16719928127713501, 0.22201512503670529, 0.09210597403580323, 0.1625876795151271, 0.21885075577301905, 0.14315378561150283, 0.17886450688820332, 0.09949529354344122, 0.15347456617746502, 0.1626814276096411, 0.1371603790903464, 0.1637744330218993, 0.15196502296021208, 0.18320917297387496, 0.09517052443698049, 0.08871175421518274, 0.21496801724424586, 0.12650557269807905, 0.19435217895079404, 0.23887194081908092], [0.008243354295700556, 0.03914898385119159, 0.017046638604369946, 0.03208334092050791, 0.01813591101381462, 0.08812868589302525, 0.03406683819775935, 0.03723072506545577, 0.027884026312676724, 0.022346762307279278, 0.0333825743291527, 0.022834434967080597, 0.05334739696991164, 0.0551978123257868, 0.01292324570385972, 0.06122035556472838, 0.029392732758424245, 0.008122612434817711, 0.050605844080564566, 0.04392604372696951, 0.03173915509250946, 0.04576870363962371, 0.104824886075221, 0.05809352041978855, 0.03984689952631015, 0.08639870255137794, 0.014209839409886627, 0.0785674415237736, 0.01198216534248786, 0.08052755743847229, 0.050900851492770016, 0.08616884457296692, 0.025019842796609737, 0.07203729895991273, 0.053821670153411105, 0.05471195421705488, 0.020322862510511186, 0.010715761764004128, 0.021467337719514035, 0.03727201074070763, 0.06353357050102204, 0.08653821889311075, 0.04835866915527731, 0.0385002503026044, 0.02751349424215732, 0.024065631987468805, 0.014196735864970833, 0.02536047002649866, 0.017389314161846414, 0.01042115882228245, 0.04107631539227441, 0.037673679617000744, 0.008899997283151606, 0.05540742822631728, 0.07332848748774268, 0.04252993778209202, 0.04152598266955465, 0.039584680198458955, 0.08051006501773372, 0.03707076255523134, 0.01968982909602346, 0.061931284799356945, 0.0024130896917995415, 0.035110639219055884, 0.03377817614818923, 0.0591103592159925, 0.042872943595284596, 0.05212076415773481, 0.034545449234428816, 0.022227471345104277, 0.008991579234134406, 0.026241378909617197, 0.01937692108185729, 0.026727131262305193, 0.012716871133306995, 0.01836582650867058, 0.09093490953091532, 0.07987089775269851, 0.02940298738394631, 0.05837306147441268, 0.04186822407064028, 0.03257402669987641, 0.03313935027108528, 0.012038447966915555, 0.002100374404108152, 0.008835971275402699, 0.024536836390325334, 0.08917706596548669, 0.06332024757284671, 0.06891938814078458, 0.03373424471647013, 0.02892552482080646, 0.04534690029686317, 0.03347430749272462, 0.028819310500693973, 0.04770118939632084, 0.006380212034855504, 0.10857393412152305, 0.025452405425312463, 0.05776710531790741, 0.04625376022886485, 0.0073289420834043995, 0.016932553808146622, 0.020013854482385796, 0.03432097553741187, 0.03984413131547626, 0.027189157153770793, 0.021780522183689754, 0.03137936189887114, 0.016535243194084615, 0.04659410915337503, 0.00850323307531653, 0.010515807698538993, 0.10253249580273405, 0.011269277765677543, 0.03700979512359481, 0.015329381240007933, 0.022198206606844906, 0.04174398854956962, 0.01821549336455064, 0.045681185874855146, 0.03162642286042683, 0.023774008768668864, 0.022671316473861225, 0.016408124429290183, 0.06830316066043451, 0.0994922210520599, 0.0034691535438469145, 0.05579600932833273, 0.024335239395441022, 0.045208704977994785, 0.08878803957486525, 0.06109233137976844, 0.03441847147769295, 0.03324413039081264, 0.01058673660736531, 0.05013103655073792, 0.028429530830180738, 0.02928355726908194, 0.031279691465897486, 0.039398783337674104, 0.059434343784232624, 0.055666293046670035, 0.03830636793281883, 0.015035923061077483, 0.034343933875788935, 0.027721540500351693, 0.043377485271776095, 0.03799776437517721, 0.024560590682085603, 0.01970499117305735, 0.04893816032563336, 0.016896934430405963, 0.041574623028282076, 0.023470269989047665, 0.01141410974014434, 0.06990089328610338, 0.15533130092080683, 0.09069869134691544, 0.007965655622683698, 0.06358132028253749, 0.02940871305327164, 0.020957404340151697, 0.012291254079173086, 0.01662106700678123, 0.03217025012418162, 0.012177638691355241, 0.054079529363662004, 0.055165332232718356, 0.01843828424171079, 0.023592395955347456, 0.057942463681683876, 0.050662373469094746, 0.06337273225653917, 0.03310004613013007, 0.05811169932712801, 0.00964002148975851, 0.040676850694580935, 0.030121777817839757, 0.004315725573178497, 0.02419948945316719, 0.03805257940257434, 0.007427580931107514, 0.0643654735176824, 0.016621336035314016, 0.04741570373880677, 0.019193534535588697, 0.053889858681941405, 0.014576524372387212, 0.04423811682499945, 0.02263691792904865, 0.08436944073764607, 0.035286390921100974, 0.054076249070931226, 0.051998424823977984, 0.020435552069102414, 0.019160067386110313, 0.014412198033824097, 0.031587022240273654, 0.04262960450432729, 0.026332896850362886, 0.0240068947096006, 0.12055207887897268, 0.05156833540240768, 0.021877322360523976, 0.013871207629563287, 0.009216782091243658, 0.06867594143841416, 0.02219412479462335, 0.027119274673168547, 0.07473065677913837, 0.030492352561850566, 0.006830377014921396, 0.020475039891607594, 0.08362563065020368, 0.040105025909724645, 0.06004800343362149, 0.014845029691059608, 0.055259295550058596, 0.008256496803369373, 0.043136906970175914, 0.013655003313033376, 0.05946795194176957, 0.024810009817883838, 0.039604796111234464, 0.02174781016947236, 0.026534133903624024, 0.055512542312499136, 0.01407542255037697, 0.09387592202983797, 0.05698662200302351, 0.055980028555495664, 0.03725360918906517, 0.019524116796674207, 0.025942768370441627, 0.02231779999419814, 0.06530965605634265, 0.021135816641617566, 0.028829066031903494, 0.024694318271940574, 0.028241413092473522, 0.045637428847840056, 0.029470771441992838, 0.05339016694051679, 0.0447686076950049, 0.026136307496926747, 0.020014177316625137, 0.016063843977462966, 0.030355845628946554, 0.025046678856597282, 0.03100966103374958, 0.008726021169422893, 0.07672453299164772, 0.04123080085264519, 0.030110231855360325, 0.01462580576117034, 0.0073174921362806344, 0.06045003596227616, 0.03398374734388199, 0.029567946403403766, 0.05569728142290842, 0.04015662743768189, 0.03415752864384558, 0.03780472063226625, 0.041706881165737286, 0.052222490339772776, 0.03324691344460007, 0.030205826042219996, 0.023253455256053712, 0.021413793620013166, 0.04779028422490228, 0.06540154136018828, 0.07157301879487932, 0.051047384840785526, 0.040447942665196024, 0.03446717491897289, 0.0413592740369495, 0.0733165537531022, 0.04556702871923335, 0.03280486802395899, 0.05827970300742891, 0.03259491073549725, 0.028677712434728164, 0.022300270466075744, 0.0784853970981203, 0.01118183978178422, 0.0529294453735929, 0.026679053080442827, 0.034199237343273126, 0.08318571519339457, 0.0376505617168732, 0.023455167283827905, 0.015467411431018263, 0.04402763632242568, 0.0166039438045118, 0.04788667065440677, 0.045968538033775985, 0.017376211544615217, 0.07478685220121406, 0.04590402684698347, 0.015608669964422006, 0.03818421042524278, 0.06210538151208311, 0.05617820796032902, 0.044633792858803645, 0.02783329866360873, 0.08456366078462452, 0.15373044385341927, 0.055147038292489015, 0.032083945770864375, 0.01152557289969991, 0.05830807531310711, 0.021820690926688258, 0.041908656276063994, 0.01333175254330854, 0.014930821962479968, 0.024886089231586084, 0.016813377878861502, 0.03343822427268606, 0.02827920139679918, 0.011992008076049387, 0.027236957030254416, 0.060066074729547836, 0.015311615152313607, 0.003685259061967372, 0.044759267766494304, 0.017834324462455697, 0.050480506470194086, 0.08435438998276368, 0.018510472946218215, 0.0376330767176114, 0.0652631011325866, 0.05092615872854367, 0.06189080435433425, 0.02064966167381499, 0.004524824753389112, 0.04496633067901712, 0.028251124094822444, 0.03900078809238039, 0.033328686986351386, 0.01531136003904976, 0.05798079560918268, 0.04111767528229393, 0.04847542382776737, 0.04198566894046962, 0.03614564579038415, 0.020191854891891126, 0.01852476671047043, 0.05401718895882368, 0.03106606425717473, 0.06426212203223258, 0.06647441230597906, 0.06119287383626215, 0.1357162932981737, 0.07499932165956125, 0.0692443226580508, 0.06801317387726158, 0.08222300864872523, 0.08185295897419564, 0.12021224945783615, 0.13397496251855046, 0.15029554691864178, 0.12625092698726803, 0.1301331608556211, 0.10591832935460843, 0.15784559334861115, 0.1090335164917633, 0.1561345867230557, 0.08989348338218406, 0.14354939485201612, 0.1201160077471286, 0.1268759192316793, 0.06632443168200552, 0.1221502196858637, 0.17863849323475733, 0.1400926787755452, 0.13531890290323645, 0.22491923795314506, 0.13787407282507047, 0.15362967504188418, 0.111641163675813, 0.13491986494045705, 0.2169037313433364, 0.14949196425732225, 0.09849156107520685, 0.18447989306878299, 0.1801660261116922, 0.14957443170715123, 0.1617808165610768, 0.13650009030243382, 0.23897501028841361, 0.1711155500379391, 0.20387056429171935, 0.15788290853379294, 0.19588523340644315, 0.10245244033285417, 0.10162968057557009, 0.13237765291705728, 0.11976839319686405, 0.13717957102926448, 0.09777426050277427, 0.0923547419370152, 0.20536674885079265, 0.1257607087609358, 0.08899496519006789, 0.2495123347034678, 0.23209504899568856, 0.15237540093949065, 0.10068825882626697, 0.1576673294766806, 0.1658833643887192, 0.137787330604624, 0.14503979065921158, 0.11936813811189495, 0.0694836801267229, 0.11362804885720834, 0.12452323688194156, 0.14918107859557495, 0.15831808908842504, 0.15232480131089687, 0.11150761420140043, 0.11042062018532306, 0.1261898927623406, 0.13889296737033874, 0.1876943276147358, 0.18146796093787998, 0.1265664881793782, 0.1457900574314408, 0.15006168134277686, 0.10833537075086497, 0.1347587743657641, 0.1275043995701708, 0.15635387651855126, 0.14291430939920247, 0.10300982292392291, 0.12324488008744083, 0.1467446523020044, 0.12036111686029471, 0.12703331391094252, 0.13744154915912077, 0.21872384852031246, 0.2123958818265237, 0.11975137575063854, 0.11073924644733779, 0.23436504125129431, 0.1361792450188659, 0.11914039525436237, 0.10195987691986375, 0.13529838994145393, 0.2310204043169506, 0.11650597138213925, 0.15499283705139533, 0.08276659471448511, 0.12090297372196801, 0.16345955460565165, 0.05797282123239711, 0.15019461483461782, 0.14659923588624224, 0.10618714266456664, 0.11234590710955672, 0.15309970738599077, 0.09921761156874709, 0.14227782870875672, 0.06924752131453715, 0.11366310791345313, 0.19633982854429632, 0.11023615195881575, 0.12738130695652217, 0.0911849168187473, 0.11847270725411363, 0.1419188964064233, 0.11433832129114307, 0.1215679306187667, 0.21652119874488562, 0.1514388551004231, 0.13215643353760242, 0.07734419661574066, 0.16595553082879633, 0.2879278874024749, 0.16393490019254386, 0.27315030223689973, 0.21588173462077975, 0.20529680885374546, 0.3324338304810226, 0.17650931607931852, 0.15025863249320537, 0.11650648346403614, 0.1735924233798869, 0.10423432206152938, 0.18779678852297366, 0.12499148753704503, 0.07599322067108005, 0.1421379338717088, 0.0905290586524643, 0.138523526256904, 0.11389108083676547, 0.08723485807422549, 0.116195338050602, 0.16877215937711298, 0.12679152219789103, 0.08335852427990176, 0.1047136529814452, 0.07322739955270663, 0.131200339528732, 0.1878839315031655, 0.15670581778977066, 0.1580401844694279, 0.10556900044321083, 0.13898459292249754, 0.2731976512586698, 0.14848671038635075, 0.07788119241013192, 0.10448043307405896, 0.1158954510174226, 0.13290475588291883, 0.15799480956047773, 0.17632471426622942, 0.17500777321401983, 0.14568722544936463, 0.13796158687910065, 0.10255694956867956, 0.06194658417371102, 0.14151524228509516, 0.18691970355575904, 0.131750849832315, 0.13229129661340266, 0.12372996265185066, 0.19189314683899283], [0.052717462021973915, 0.02096460317261517, 0.06235940381884575, 0.06023734385962598, 0.053343968247645535, 0.04132681620831136, 0.014917926218913635, 0.025367611342517193, 0.04481991236389149, 0.02976984396809712, 0.06426588472095318, 0.08073483186308295, 0.016341312584700063, 0.0512876774155302, 0.06284358838456683, 0.04806326840480324, 0.008586470503360033, 0.04053905242471956, 0.09136427164776251, 0.03560557008313481, 0.0237999616729212, 0.030857999445288442, 0.07151396610424854, 0.04656049357436132, 0.031233418558258563, 0.0423473323462531, 0.02778530582872918, 0.0175054435749189, 0.01015895526506938, 0.007197145005193306, 0.06397962351911701, 0.0713590947270859, 0.07269090099725872, 0.054050496546551585, 0.021881472821405623, 0.0682220958697144, 0.05808185014757328, 0.030387231054191943, 0.14020135888131335, 0.02021674095885828, 0.008932435630413238, 0.03305506455944851, 0.07066984733683057, 0.07888292107963935, 0.034064659994328395, 0.038123977719806135, 0.049373715664842166, 0.02249351829959778, 0.06165182538097724, 0.037403459937195294, 0.061821691851946525, 0.074553595186444, 0.05231500275840517, 0.054636574277537875, 0.005303495372572797, 0.0038767252772231586, 0.043723467097152025, 0.027885004092240706, 0.04807335419172887, 0.06535814056405798, 0.021390449364844244, 0.025771677355805878, 0.07886771447374485, 0.03514556468871888, 0.05270419984299224, 0.057203436736017466, 0.07401145630865358, 0.022940513845242094, 0.007789499450154835, 0.031013904263090808, 0.04188128586974926, 0.03564963881217409, 0.03554612034349702, 0.0786132320354227, 0.027466174906294327, 0.017555688827997074, 0.04606125825375784, 0.06229967577382922, 0.034046529326587915, 0.0198103946968331, 0.0017315122818217787, 0.01940842339536175, 0.05139032014994882, 0.025894731006701477, 0.022799240468884818, 0.021176783193368465, 0.02366679625993129, 0.0713481406273786, 0.02824315528414445, 0.07382991214399226, 0.07349200488533825, 0.04642317770048976, 0.00933959176109056, 0.01264076296138228, 0.06815812273998745, 0.008290862879221095, 0.11072752051404677, 0.02845388626155909, 0.05129018587467726, 0.02508088444301393, 0.04437883915670682, 0.016041006238083355, 0.08345452108187601, 0.028009490088152234, 0.03503457279293798, 0.01882459251646651, 0.045556249024230056, 0.02661977217940148, 0.02846469378710026, 0.017364136801916175, 0.03501689112454187, 0.06511001833132468, 0.05025510508858133, 0.0801689962099772, 0.10760226985439658, 0.03361503724590875, 0.07972523642820306, 0.013236554477771278, 0.011394300890970044, 0.03157710343657527, 0.029439104000630323, 0.06117577104305383, 0.08357699029147625, 0.0355804520950187, 0.027075033394794445, 0.030936231087252963, 0.04216173605527729, 0.03384503252163995, 0.05142045876709744, 0.09622801808291115, 0.007623692990819109, 0.010638106214173604, 0.03530256602971349, 0.04596041893819347, 0.020352134670247324, 0.09534189375699498, 0.010378747865615878, 0.0429074015119113, 0.025145798244921025, 0.009646865946706384, 0.02668032957444666, 0.025867831864161417, 0.0761962500109803, 0.028295467418502085, 0.017902468462125398, 0.03055379682336934, 0.06110388661909383, 0.03786998138821218, 0.12142929743276909, 0.09003682920592837, 0.039898875838844106, 0.029974198041600175, 0.033926687319763005, 0.06174198890221305, 0.02351132559851976, 0.02217873636254808, 0.0383489115483826, 0.09077960028662346, 0.030087477607594337, 0.02218751411419362, 0.08497868460835889, 0.03589650681533385, 0.06269668025197461, 0.07221058302093297, 0.02423386016744189, 0.05052586653619073, 0.04589093536196742, 0.046940718093537726, 0.022856742070871405, 0.07556048178230412, 0.07470653697964735, 0.05160698274266906, 0.05022807607019786, 0.02782528903480852, 0.01689124030235689, 0.0460596960328985, 0.028777349471056368, 0.027691292416420765, 0.04514752603427041, 0.04068917034601327, 0.012381682918203296, 0.03596186405047774, 0.06160390861623455, 0.005552738248297828, 0.00991870443613152, 0.01679657380009303, 0.02166272850445239, 0.03056050954910461, 0.027199339419894386, 0.018409314507152885, 0.072106600709958, 0.005757386861660052, 0.027284124225843698, 0.027225090088904835, 0.09322551864897832, 0.021958134821034037, 0.07318682633922435, 0.031613520623068325, 0.04581269073241856, 0.060172257508384064, 0.04577177984174341, 0.07724482304183766, 0.00826112316644867, 0.017074682509701233, 0.01737342849082779, 0.04828256191103719, 0.061561112670460716, 0.03631589075666852, 0.012090845448256005, 0.03892565677233506, 0.04755950598337222, 0.009263516985811293, 0.02740946369158337, 0.03825090352620464, 0.08835320782964118, 0.011339579559717095, 0.03700503795698751, 0.09753425736562349, 0.056472911091987044, 0.016327219200320542, 0.01848410815000534, 0.07471622200682759, 0.06794600209104829, 0.02148837946151616, 0.042185555284959264, 0.045479488690034486, 0.053085363178979605, 0.10237299342406914, 0.020543909340631217, 0.0051379124852246605, 0.04846054747758899, 0.025712678470881656, 0.042133078022743575, 0.06261270624236204, 0.01617833138880087, 0.03684690855152439, 0.03869010281050578, 0.034162111405748874, 0.0825969545985572, 0.009956947305909125, 0.06402516912203282, 0.05138495813298505, 0.05797487698146142, 0.05261860424070619, 0.019322968801134266, 0.012418537044140976, 0.1096457066887524, 0.0375730555242626, 0.005763416347690509, 0.011064722384617198, 0.044504276957013644, 0.022946400931687094, 0.04521791131992359, 0.06219168586540036, 0.044805299476138316, 0.03217784971639048, 0.06488545928732492, 0.04164291916822549, 0.14206796418875456, 0.01457515696529299, 0.02494806412869366, 0.014936280458641704, 0.048560451687080786, 0.0800264890131075, 0.017447762002120726, 0.03292661735031288, 0.05875661452591885, 0.03050038816581946, 0.031313232830143534, 0.044100055092712864, 0.02760928138741292, 0.04592298129864503, 0.01319433091339306, 0.03906030091457069, 0.05891846951271873, 0.03978149405156728, 0.04871034325333312, 0.02137794788723113, 0.022060245064494666, 0.008972749092208687, 0.05171796350623481, 0.018045862525468692, 0.07861151025281288, 0.01732561933749821, 0.059768944774987176, 0.045833318727090955, 0.03226592038117815, 0.021271516488923226, 0.0862052988668438, 0.06816660548793152, 0.057594414975028485, 0.04174479377979878, 0.0361984421761008, 0.0707384069391992, 0.050791039611794986, 0.04033634962979704, 0.014917450316715986, 0.0037039887820355943, 0.031942770729074255, 0.038129462191136554, 0.043501446198206395, 0.06172025139676407, 0.05833785027789418, 0.06099036028899718, 0.011893644750671228, 0.02618247835926013, 0.0396716933028074, 0.03730157419340685, 0.05122476926771924, 0.0832155643729493, 0.031449027301277965, 0.046729358145967126, 0.04056961406604387, 0.07796624253387563, 0.0515994499437511, 0.024580652789154556, 0.03726827031641733, 0.020449550829653163, 0.05049519728345331, 0.08283782604848966, 0.04436588867974933, 0.01793908788386034, 0.02946609034552239, 0.034424664700054564, 0.02040266936091939, 0.08406867797020823, 0.053921210710541345, 0.06615462829358876, 0.0405549121205695, 0.03841917437966913, 0.02027796443144325, 0.020487788133323193, 0.03793968389800284, 0.053819903841940686, 0.039424962596967816, 0.022389085133909248, 0.04124351755308453, 0.05216719662712421, 0.02029378887527855, 0.042708105174824595, 0.050707436676020734, 0.01857875980931567, 0.010677581049094442, 0.052106321963947266, 0.05505757610080764, 0.11865266322274692, 0.04393187700770795, 0.011335796461935388, 0.04325322377553675, 0.02668109769729199, 0.01696583170996746, 0.10353146368288435, 0.12000580623862334, 0.10237582100671716, 0.08806357727735303, 0.15322462568292394, 0.1506603867164813, 0.1674962739343755, 0.22885993821546435, 0.08984652027720585, 0.15650625427952036, 0.23260353889781982, 0.17357505712425336, 0.08873371436493471, 0.09546118657453917, 0.16303590702591464, 0.12351673620287329, 0.1863397448323667, 0.12885144213214517, 0.17819695989601314, 0.1894503677613102, 0.1826138814794831, 0.13773975893855095, 0.1948255207389593, 0.20893560344120488, 0.24020581768127158, 0.13862067338777706, 0.17871586955152452, 0.15382506768219173, 0.09583551101968624, 0.12321814792812802, 0.13846172019839287, 0.17384797451086342, 0.24051078100455925, 0.10157552605960518, 0.09270244554500096, 0.11888439883477986, 0.18361929862294346, 0.17325281660305336, 0.13964379817480221, 0.2249260211829096, 0.15324923529988155, 0.13971823558676988, 0.17089099099393934, 0.24488703289534897, 0.1837456418434158, 0.10840688410098664, 0.2943989698542282, 0.14031879632966593, 0.11376052963896655, 0.21963590348605067, 0.10133803138160147, 0.20870167849352583, 0.13890346133848652, 0.20288004947360605, 0.18668233504286036, 0.11285720975138247, 0.09937790804542601, 0.09202577013638802, 0.19266346644144505, 0.13820189429679886, 0.24909129948355258, 0.1327032331028022, 0.20540017518214881, 0.2448806949541904, 0.1472876817570068, 0.09856469972874038, 0.1380232148221694, 0.11885087602422573, 0.2298252348555252, 0.11227555150981061, 0.08639205290819518, 0.1752254896564409, 0.11549975271918811, 0.113030961365439, 0.188638829276897, 0.22649003803962842, 0.11545592889888212, 0.11335404793499038, 0.11834568125777878, 0.14423328393604606, 0.14174386829836294, 0.12346733143203892, 0.1832240159274079, 0.16583445685682818, 0.1041098490532022, 0.07615512018674053, 0.07991446924279444, 0.09838741549174301, 0.21144229627680033, 0.09220911771990359, 0.12565201381221414, 0.26005050516687334, 0.07346453799982555, 0.12892589438706636, 0.12562458403408527, 0.16886483877897263, 0.07694931467995048, 0.24386175588006154, 0.1247274610796012, 0.11717049783328548, 0.15505409392062575, 0.14540992939146236, 0.13703384291147813, 0.1095525077835191, 0.16840393538586795, 0.10253731234115548, 0.20792095398064703, 0.22770680399844423, 0.10015393476351164, 0.09843598163570277, 0.12916618696181104, 0.08995588315883651, 0.12674142722971737, 0.17145916441222653, 0.2652974001830444, 0.14491686131805182, 0.11448057615780272, 0.11847434740047902, 0.1833242503926158, 0.1185570597590413, 0.09103545569814742, 0.12743600324029103, 0.15263432142091915, 0.26748908101581037, 0.08427604145254008, 0.11486350951599889, 0.12378917119349353, 0.11085364851169288, 0.2807847160147503, 0.1672657034941949, 0.17637341399677098, 0.09668281360063702, 0.08699088444700465, 0.16260330914519727, 0.16665828530676663, 0.10260925613692962, 0.24714400788070634, 0.09012266600620933, 0.18868365499656647, 0.1578818992129527, 0.09806156071135774, 0.15788173594046384, 0.09230579729774036, 0.17724224628182128, 0.2141127217328176, 0.1116451712732669, 0.10667503054719418, 0.15576603618683293, 0.1668959209928289, 0.20797594712348655, 0.18455882789567113, 0.17036672303220257, 0.1390026864828542, 0.13538480561692268, 0.12027657139697112, 0.16548385145142674, 0.099942496890435, 0.11531566298799589, 0.17398233292624354, 0.27208398445509374, 0.09987102064769715, 0.23537468863651156, 0.09436942054890096, 0.122865590674337, 0.1232847037317697, 0.13839042949257419, 0.09597896816558205, 0.19649150868644938, 0.21199344482738525, 0.16404453024733812, 0.3527016460429877, 0.10532658532611094, 0.15364373131887987, 0.07345327961957082, 0.07578369011753239, 0.09949917497579008, 0.17430684441933408], [0.05118881592352409, 0.021457500552060083, 0.04371958195406478, 0.0223242715219385, 0.05920184004935436, 0.02881938657083083, 0.08605139970313758, 0.0282019568112446, 0.05830134032294154, 0.035925131451222114, 0.06834093597717583, 0.023306852781388443, 0.06642985375947319, 0.02203794167144224, 0.02635997410834534, 0.033961011649807915, 0.044102429965278134, 0.030754219369555358, 0.020355047599878162, 0.06078780221287161, 0.04000719971372746, 0.042971348666469567, 0.05829300971527118, 0.058598073228495196, 0.03646090641268529, 0.011114471326436615, 0.01257623043784406, 0.028621815727092326, 0.02744131110375747, 0.05488086331752129, 0.013384385656536324, 0.03307152168417815, 0.025269642283092253, 0.05983024988381658, 0.08211993175791577, 0.033542904202477075, 0.007282844044311787, 0.01386711932354956, 0.09619928954634815, 0.03049532857403392, 0.054050233084126376, 0.10801223223097622, 0.051124809397151694, 0.07846486929338425, 0.03612368192989379, 0.057075687145697884, 0.025490160332992673, 0.033580453164177015, 0.025479031828581356, 0.035832418652717024, 0.016619501075183507, 0.05034025169152301, 0.033985224217758514, 0.07822592742741108, 0.02669287372555118, 0.07551206406787969, 0.04921038751490414, 0.021546372736338526, 0.05864044615009334, 0.09515359604847617, 0.029376264501479454, 0.012886455588159151, 0.04958120531227905, 0.051922261918662116, 0.07328104940825142, 0.02575747450464405, 0.01646607503062114, 0.04380128128104843, 0.06374920150847174, 0.07895470902440138, 0.007916422473499551, 0.04950061920681037, 0.01878096165455645, 0.04592883684381377, 0.03077196412050398, 0.010612400074023753, 0.02503688807337312, 0.00825248271212331, 0.009271497856389033, 0.03024893369001802, 0.02314364151970949, 0.03189707669662312, 0.0293618464274914, 0.02332610409212066, 0.03449524665484205, 0.07667081634281203, 0.035504326297086664, 0.025849411758827046, 0.03801575403485913, 0.0257048562343698, 0.015832345852686558, 0.029108009657647926, 0.017255838902201504, 0.02991868354001781, 0.061805705990991555, 0.034520995468483306, 0.09266138993552886, 0.03702300906297751, 0.06271193880820647, 0.04002148605650291, 0.09810673524043523, 0.03793808828049805, 0.016872883279575035, 0.023670627597311977, 0.02469385442964267, 0.015873445991019253, 0.04593129335262347, 0.0747023661097046, 0.016169271621038206, 0.030708992890140507, 0.048545797981205396, 0.018894324712164234, 0.05201677813602146, 0.025313065343652852, 0.06095729389926419, 0.03903351680492051, 0.023409896275552455, 0.03491097180813085, 0.08934988989494741, 0.02677653046703199, 0.008149204513756558, 0.029417334953905083, 0.01902051764773205, 0.04067223453603219, 0.026774864345497917, 0.05033290071878582, 0.035931569582317024, 0.05258428362139966, 0.038117276126286015, 0.020580150267051067, 0.03806753367825877, 0.03298259754956234, 0.052652806116384454, 0.04943549203744624, 0.027649275725707412, 0.02243338392872829, 0.042191340326098725, 0.03670816404337529, 0.04149828200752381, 0.014421323667193064, 0.018723178036452737, 0.08440009885816835, 0.021245120151434094, 0.03629441671364475, 0.05090743434266187, 0.01751882635289803, 0.06214057044417132, 0.04124390718061477, 0.022656143264612183, 0.05632415872241836, 0.02795734122628346, 0.03291288761829492, 0.030666861166537274, 0.04550302590359934, 0.07286837077117525, 0.05083560557977762, 0.030208054340619128, 0.05821751103212591, 0.030909842171240598, 0.09696019871626049, 0.03254757284594234, 0.04227529949275777, 0.07414013729430735, 0.012636627343454165, 0.024541855163988657, 0.022554285351361614, 0.04366878194559831, 0.03963684204791207, 0.03947162884287536, 0.05810379545437172, 0.11940002077608369, 0.020011123378935736, 0.029205835853645112, 0.07221391526400112, 0.0419381121173501, 0.02126252536982065, 0.06545332842506468, 0.015327072233048966, 0.0695260864449665, 0.04816900960577186, 0.03718544292496517, 0.03112845661235042, 0.03743320150533691, 0.05005741179047618, 0.014820510987192392, 0.0604714283690555, 0.06557017957675271, 0.010167046530114021, 0.04099643061636016, 0.050617031956790015, 0.011624295239016647, 0.09123193929553963, 0.053586772992275655, 0.045412205581669696, 0.0364308049029205, 0.03837330594251398, 0.05154295024112798, 0.018547572908573784, 0.033058248372981325, 0.005497701040440006, 0.025220641982741654, 0.05420285575382877, 0.042116576369153336, 0.022581794910365716, 0.009642724762670696, 0.08172279369318858, 0.024514210163033567, 0.059086974142701365, 0.022161060260259546, 0.026970557555614505, 0.05367075813410338, 0.03205184046237264, 0.04353797099611256, 0.04440693686774466, 0.05180199317692313, 0.012339974218775751, 0.04248620301950723, 0.009128952624450903, 0.05070049759524409, 0.09108762125833891, 0.0265709889572463, 0.048187236752710305, 0.03548602864611894, 0.027720429134205915, 0.03852968387946021, 0.023096902914403472, 0.02780173883365933, 0.038676651383866556, 0.07106229502824135, 0.062096754045342095, 0.07176673418143764, 0.0830892582598608, 0.014722451942361658, 0.01691946788923815, 0.023259711560967844, 0.10905031871516258, 0.05411963131336961, 0.053287372065824457, 0.07915951209724881, 0.07030258813756518, 0.03459286133875139, 0.026481714157853276, 0.061516917776316404, 0.05290007859002799, 0.12316476524574682, 0.02477802881912794, 0.0940716041077394, 0.0457065599039197, 0.034078430544468574, 0.024612787783553358, 0.030345459272211883, 0.0409322830819292, 0.010932672976196045, 0.009880743582471041, 0.048698780592530966, 0.048248712555505335, 0.013010837683395948, 0.04642248008167371, 0.016381741079385392, 0.05143855232745409, 0.028809085561078973, 0.03809209505561739, 0.041438219996052794, 0.03428563075431157, 0.015463863037439296, 0.017820227367337793, 0.04342919070040807, 0.0536154458677629, 0.06809206417528912, 0.014814424448559294, 0.04393191782583017, 0.09619888878660277, 0.06852764548966661, 0.04941823339322582, 0.06149331005872227, 0.014916691470716614, 0.021187032252782956, 0.03520829472108744, 0.02451688746077707, 0.03142499284876976, 0.04064909437147435, 0.06481520016677678, 0.09722248854814097, 0.03932763735065237, 0.032380181437474675, 0.021180755538807716, 0.0103688058698026, 0.01332045612798538, 0.07389778897049837, 0.06463200101279654, 0.09002504390082322, 0.013687599366676295, 0.06423141196137294, 0.026719791421783157, 0.040780191047815606, 0.07780148574966006, 0.026906226339633577, 0.038589170726481825, 0.014167744793667225, 0.03641710114607122, 0.03490802177111618, 0.038289780932245776, 0.02537599575589411, 0.023935505669214763, 0.05184129731787834, 0.0271276071362081, 0.04187307400570717, 0.04492800617299508, 0.029552856685768347, 0.05379633323173039, 0.06339436586131342, 0.00472740741315647, 0.04570071920170449, 0.03936408793379087, 0.025301148307335097, 0.031111533789953683, 0.017670148408797104, 0.004823233985007391, 0.025090046256082132, 0.06798811155022122, 0.040143376390915364, 0.029103747874614783, 0.03834377959719859, 0.03383241972187534, 0.05660455695760902, 0.03475216333754361, 0.043090797335025854, 0.017037721700035036, 0.03026440190296853, 0.025557454573572613, 0.014646922645624727, 0.018472489828127436, 0.06575671097380109, 0.07630749052623287, 0.05018500924052205, 0.010226234662695788, 0.04577382445859257, 0.022276091294770595, 0.08108708483632654, 0.024487080954713747, 0.015419778537761886, 0.040048656082944945, 0.01219517842400819, 0.0458347473613685, 0.028419762311386876, 0.09381945201312192, 0.04254915940691717, 0.09009404879179783, 0.043486035501700826, 0.06149815999378916, 0.04788163147168234, 0.04395146599563304, 0.1465720435953699, 0.11692748157656752, 0.19929997361032292, 0.09651154818129726, 0.10256527646561153, 0.11835140321636572, 0.21444176032673568, 0.15568195085506886, 0.13694517110707238, 0.15698878385592252, 0.10949256451567635, 0.14787562598939985, 0.09003173065138981, 0.0974832198699005, 0.07888962267315947, 0.15341077116318047, 0.1322802237700671, 0.1590794583898969, 0.11816343205282465, 0.1932538449182175, 0.1401313001406379, 0.07699470443185419, 0.12417847217875533, 0.1276005373802036, 0.132583940285258, 0.1262157195014879, 0.13046803273027763, 0.1271077067940496, 0.08614268386736512, 0.18027859507128596, 0.07762534442008473, 0.2595251239836216, 0.20709405303932726, 0.17686631879769266, 0.2135615880251862, 0.13038042961852625, 0.12414504584739916, 0.1335395741625689, 0.24217961879912764, 0.12029863544739783, 0.18218094221083447, 0.17083685874240473, 0.1339629990980029, 0.11475453997263685, 0.08935742269386537, 0.17405769060133025, 0.13483073300449178, 0.1481302865431644, 0.11399326715036295, 0.15871984331170097, 0.167145638843067, 0.13947754225227982, 0.19332917290739715, 0.2547161257825792, 0.17211774626048282, 0.13939835509518161, 0.08418071258347481, 0.11829405004391447, 0.13161453214706853, 0.15461072005564347, 0.17190209298860282, 0.11475066596176475, 0.19167093298165128, 0.15288847731426358, 0.09525227200356312, 0.14294261491158977, 0.16350917459931225, 0.15991576976375654, 0.2099491099943407, 0.1407855181605555, 0.2370668892399408, 0.07864484010497108, 0.16338407818693668, 0.08976958924904466, 0.13224167661974207, 0.12106876209145412, 0.12041672598570585, 0.11674794863210991, 0.20118921442190185, 0.12237762857694179, 0.14423466433072463, 0.1112335390644148, 0.13644984690472484, 0.11462671245681122, 0.05031321525166277, 0.14245184749597684, 0.1324773085070774, 0.12528913328424096, 0.11084309517173097, 0.10152630682568997, 0.1052490457368549, 0.13671440770849586, 0.21964703570120037, 0.0972576292406302, 0.2560328441904858, 0.12913816346554086, 0.2076268260134384, 0.1616724333143793, 0.14165622065775096, 0.07532763294875622, 0.14136972196865827, 0.15016521094366908, 0.0900111286318861, 0.15128414699574932, 0.11570627757464536, 0.10677548765670508, 0.32556382881011814, 0.16935903491685167, 0.0862089947622735, 0.09043640893651173, 0.1286160625750199, 0.15419721021316946, 0.1450567413121462, 0.19736676797037944, 0.14867576508549973, 0.1226100989151746, 0.08357342056115158, 0.20087200566194952, 0.11988547441433184, 0.18257794668897986, 0.1339521785848774, 0.13193322520237416, 0.10897766987909563, 0.12692268937826157, 0.10296265943907201, 0.16549533989746124, 0.1522174570709467, 0.08790716965449974, 0.07707680080784485, 0.09260559527319856, 0.11149064128403552, 0.13866872002836317, 0.1420828516711481, 0.13911684363847598, 0.14965902169933543, 0.10235351204755716, 0.17038506892276928, 0.12416072000632994, 0.1676149878767319, 0.1496077689807862, 0.11569547190447338, 0.17348018096527085, 0.07826650064089336, 0.16429479728685692, 0.10853070401935838, 0.11944580386625603, 0.16440595616586506, 0.24548088462324813, 0.09657273825723678, 0.15575049561448395, 0.12348478674539365, 0.14983284752815962, 0.11025285770301707, 0.13076829083729535, 0.1405739615438506, 0.14262494602007791, 0.10253257743897848, 0.2075909505947493, 0.09790147203602828, 0.26030785229522735, 0.08919368265196681, 0.20197379810269922, 0.2602276112884283, 0.11218046754947864, 0.0643890886567533, 0.07059011099045165, 0.1529062888585031, 0.16795159637695178, 0.10989051894284785, 0.20933933177730069, 0.1777902035973966, 0.13100657961331308, 0.07240345978061669, 0.30753186671063304, 0.16294569155434147, 0.1623666679370217], [0.04154818401730154, 0.10599507484585047, 0.011054688548028935, 0.04919230137602426, 0.034662786492845044, 0.03570174128981307, 0.04646970293833874, 0.059743307283497415, 0.024471139622619376, 0.0754214775224682, 0.06954075128305703, 0.014373998765222495, 0.02402510330284713, 0.04326966234657448, 0.06451788096455857, 0.09318412907305174, 0.030303299718070775, 0.017731312509567942, 0.020261006357031874, 0.058852373840636574, 0.022183847904670984, 0.06636882695602253, 0.04643759020837024, 0.04905418027192354, 0.044622775676543824, 0.04530656457063742, 0.035858698101947084, 0.06488153332611546, 0.057562053625588305, 0.02731766002398217, 0.05034129069827031, 0.0587740438641049, 0.031723651627544314, 0.036339602374937385, 0.06979688128922135, 0.0514005061268108, 0.04440990545845125, 0.04267562137101777, 0.03956037115131039, 0.030321886806632392, 0.06544288640725426, 0.022415141938836314, 0.04426145736942999, 0.01941968919709325, 0.016035601547628175, 0.05849153792951256, 0.04923667438561097, 0.0362795106775593, 0.02947234665043652, 0.018097009487973992, 0.037845037804800086, 0.03338448535942007, 0.039146950366557576, 0.02985407401865814, 0.016148315226018894, 0.019727279723156244, 0.06705429681460373, 0.05631304135022219, 0.038815321677247994, 0.02468823266099207, 0.042886884839390405, 0.030084436657489277, 0.021756604619440623, 0.0478032495448133, 0.05667028897732962, 0.018711791635723785, 0.06977038661716506, 0.07577203839900903, 0.018939573456009384, 0.07304014085093513, 0.040808912162901834, 0.008388234509766335, 0.0840125122340396, 0.016011980842449702, 0.05170057498617098, 0.017578517290530726, 0.06386813067365438, 0.08740441655390896, 0.08869918223354034, 0.04648017835279461, 0.03694879429531284, 0.046517883165506646, 0.040730741748120636, 0.02941199520137161, 0.025912405253620818, 0.039197453515953384, 0.01353310648482875, 0.0414585585531313, 0.03102775644947542, 0.030692749132867903, 0.015592175732308533, 0.07308949367143214, 0.060353482549544424, 0.013079279469820904, 0.01503229859736166, 0.05100858907098882, 0.0828510733845178, 0.03800640668487176, 0.07297788208234124, 0.07079350398271345, 0.02568265117588453, 0.02386129832302686, 0.02493062180292327, 0.035110134558635764, 0.013419322258414468, 0.10618490137858316, 0.0031915984300212585, 0.009680404527898645, 0.05320074858900625, 0.03234263618651312, 0.06542105984408408, 0.0348242481413763, 0.02725175174418837, 0.0625668118300382, 0.02340146547794575, 0.044341175162117, 0.03298870171420276, 0.07441666151862592, 0.029886455777159426, 0.033457605459261686, 0.03715658822329715, 0.020296946713642683, 0.027152953334734775, 0.05168241463252343, 0.028905358813062776, 0.038271431330940686, 0.09943039272911847, 0.018031635554507375, 0.029951371434435714, 0.02265891704155365, 0.06251304323086515, 0.029440502949000802, 0.05239614547463134, 0.03503538915538229, 0.06741316232364625, 0.07989912162884139, 0.01874437934020534, 0.0971915187255945, 0.024984640876937192, 0.09695587199530564, 0.013047947850282071, 0.031861913739703596, 0.05262630773358978, 0.009126947898039361, 0.019503791227180045, 0.0572679442120716, 0.07333595349336974, 0.02035675639490364, 0.07394860382191837, 0.02755656107183313, 0.03664735246275086, 0.01851295914093498, 0.038876697290106677, 0.017194988358824048, 0.044587787124328315, 0.013612990333058406, 0.07608955886098556, 0.10223316538031213, 0.048170976297114976, 0.06774568901164457, 0.07560687343357131, 0.07858548313379288, 0.017640430960454978, 0.016663990973029286, 0.033283505035797134, 0.02801771493977867, 0.011981938987446483, 0.043562231803662144, 0.03858799813315272, 0.03218715624825563, 0.05315459813573398, 0.04524738200416323, 0.021402054699137807, 0.023998278375074733, 0.05764344867202453, 0.02855496491974918, 0.02307192778971512, 0.06768708903109655, 0.04607921822753269, 0.04061281077156309, 0.032437764675705694, 0.039146375202108175, 0.009196806258842116, 0.01769985472492408, 0.11617196039878763, 0.04864179849391803, 0.013199852492107311, 0.030251065509219188, 0.030134355365589727, 0.03496978330076672, 0.07178962943726219, 0.0627578777493909, 0.015650762725272216, 0.040316638187505305, 0.05540266363823321, 0.04664205560402479, 0.02876105747418478, 0.05080315517261624, 0.03311541229777504, 0.03126568342850078, 0.02209530968684703, 0.01586521371791605, 0.046270302700577304, 0.05550347326789051, 0.02014483427046798, 0.016673089703544974, 0.04275306077033747, 0.05186002170376014, 0.02518973338737851, 0.06290411052759737, 0.011714290849340614, 0.0872378637723159, 0.03695324718137272, 0.031159092468442395, 0.010225172463833587, 0.04394864954520017, 0.031819258801988326, 0.0862537685316056, 0.0745499660843052, 0.05870953267731238, 0.016996525082504377, 0.041190598713001236, 0.05042503464210313, 0.029151579292374663, 0.07587075888295658, 0.02739177089097211, 0.0470692432281794, 0.014246169394027675, 0.045183045222074725, 0.028540804742078763, 0.03825883337412961, 0.0311955430515809, 0.04071493029186968, 0.039597292998223566, 0.023377251054625958, 0.03078671059483895, 0.051659868186106905, 0.0754235332715325, 0.013683114939340157, 0.02689163200557232, 0.10854807027499191, 0.012975903864571592, 0.022846507854410447, 0.09399557849974371, 0.026697306202549953, 0.028899080243718345, 0.006496027890534606, 0.03681909656734206, 0.06481536343926564, 0.0025440608987992164, 0.07275413197930902, 0.06897348328493536, 0.10582245871773921, 0.03915167413651943, 0.07096407178323716, 0.03376178581675049, 0.013990137722430518, 0.08096451914752834, 0.03510898422973696, 0.02945162217656616, 0.05861348021426238, 0.1278329483466223, 0.02041624509729445, 0.006590495404452668, 0.03044047643925296, 0.0204967495665187, 0.031097008104552515, 0.03854051923553925, 0.012891424266854301, 0.03788607857131865, 0.02851624522008933, 0.03801981729338877, 0.05158902276889421, 0.06472925204434432, 0.059078242775285617, 0.04801323280844372, 0.016135190344357397, 0.024147707954398356, 0.04664993721235078, 0.03405716430279426, 0.010914441190834623, 0.034619790167198516, 0.01825721876230091, 0.0425096919934731, 0.02058221900369972, 0.007730293691565748, 0.03542557700711768, 0.0041891731598298065, 0.04013485653558746, 0.05215379344008397, 0.041200639971066266, 0.04645177636120934, 0.049053608818212524, 0.0698157021543011, 0.013517229162971489, 0.009864675157587044, 0.008192598816094687, 0.02275058341183467, 0.05856264309841208, 0.0536793188075535, 0.029155069241824094, 0.012753616720146965, 0.007271915919773164, 0.05081761220935732, 0.07169358068495058, 0.03433348814724013, 0.02265547347633401, 0.022823384388175327, 0.00806223222753033, 0.05629738203424495, 0.09460772416787222, 0.053533880127361044, 0.035634198429761454, 0.046126363158691674, 0.02005448521231301, 0.040049413073575124, 0.08490784661262296, 0.038459447023342364, 0.025534731867082883, 0.06689004469080828, 0.025443959784752224, 0.105770983354887, 0.012009066340397112, 0.05175272570340894, 0.08625425092759542, 0.02199858001404209, 0.046721127728233114, 0.022950499442231376, 0.0296113620424876, 0.042887894160230644, 0.02581123568234034, 0.04055855606566183, 0.026593971415422857, 0.07500196370529011, 0.04567563832097221, 0.01023109201923944, 0.08246709359809756, 0.06378352583851665, 0.12677586288191378, 0.01901846375403693, 0.012682045853580348, 0.07763744884869084, 0.02002112381887855, 0.07113058003596961, 0.04740192576718982, 0.023562567184853833, 0.03179866791469976, 0.021859267762920354, 0.06922510103322566, 0.0170281906684977, 0.06117001568782143, 0.029914664810348768, 0.23377403937047347, 0.2605111710727215, 0.11017836834071204, 0.07056883361656219, 0.09364405283122323, 0.15031735121738166, 0.07820580038242042, 0.08695065262145363, 0.26357279741205275, 0.15605204505845904, 0.17962258105399087, 0.0823901551484596, 0.161140936834272, 0.1851559747592546, 0.12943864421686158, 0.21213645668467507, 0.21695085772080347, 0.10698366008000448, 0.15195559768471867, 0.1686528665595688, 0.10497370894881897, 0.17862678214441985, 0.09362559561850503, 0.08664188950206153, 0.112007228017319, 0.10382081221905537, 0.10610635988996364, 0.16558953328058124, 0.10591615486191586, 0.13841305015375838, 0.10547212790697813, 0.1606855253339745, 0.12797538132872432, 0.1549011521274224, 0.14075549086555839, 0.13250680145574734, 0.18812493653967977, 0.1227934613416437, 0.12158445082604885, 0.13714909844566137, 0.1701290428172797, 0.14271530992118642, 0.11520670086611062, 0.11466908166767098, 0.16466704371850938, 0.08553851628676057, 0.09433741914108396, 0.06542469636769965, 0.21704206767026335, 0.09412333922227845, 0.08227561207604595, 0.15647340682335198, 0.12852041458245367, 0.2051448615384288, 0.165496586705558, 0.1624264701968059, 0.1206106343306601, 0.10898906926740892, 0.2353451363160275, 0.16053513652877882, 0.08781131386058405, 0.1939776467042975, 0.12316805295995437, 0.13981449214043096, 0.1723466839757748, 0.15560267464024946, 0.14362972491653636, 0.16511714144144207, 0.19521087349858135, 0.21286616596626118, 0.12403857734170742, 0.13406709273112938, 0.23217718990053982, 0.08349695708602667, 0.18445053370669484, 0.14795166644034907, 0.22350278974045068, 0.12007895231363364, 0.13548420887673274, 0.17152880755020306, 0.08901924826204777, 0.16594751563388854, 0.1534068674664013, 0.10808145976625383, 0.09515873913187534, 0.24894088099244982, 0.1350518484832719, 0.05746939277742058, 0.10845424796571024, 0.1666135189589113, 0.1677912479499355, 0.19399799639359117, 0.2430972398724407, 0.1383487059501931, 0.06628135743085295, 0.17366267507895827, 0.1637139925151132, 0.21072034985991195, 0.1415384269785136, 0.15572164091281593, 0.10284194911946543, 0.19427852821536362, 0.1262221613433212, 0.23792691965354607, 0.19693988462677225, 0.2049072555382736, 0.11988597165327519, 0.1757579657714814, 0.11615918061579578, 0.12454415060346946, 0.26228929753415287, 0.09958371301763691, 0.10417650133604184, 0.1936796447262168, 0.12902311573270708, 0.19821544352453202, 0.11625493250903673, 0.1826343944412656, 0.12898347020382062, 0.13054692302830517, 0.0529416611243505, 0.08652870455989614, 0.14435113698709756, 0.22986793803283945, 0.2506705600535497, 0.12383202280034311, 0.14675139100290835, 0.09526543770334683, 0.11041870544431731, 0.12207509949803352, 0.1866257982328534, 0.13252149597974494, 0.14052496495423838, 0.1160270486434456, 0.24501530569978058, 0.22379763016942888, 0.09528508235234767, 0.12169728695880622, 0.15911886643152684, 0.1721412129700184, 0.13602789142169058, 0.1354839268606156, 0.15776839514728636, 0.09377009177114815, 0.26013938477262855, 0.13590034592198208, 0.1189693747437559, 0.09977618901757523, 0.21737061644671485, 0.11906523795914836, 0.09338316565845162, 0.09334224363556132, 0.14642184774857014, 0.09802358501474373, 0.10639245781931095, 0.09660884374170564, 0.16032950225053355, 0.1900757904513739, 0.09884287894237787, 0.21313188452040777, 0.1456070735002868, 0.12807485880330205, 0.16486539010656998, 0.1800966204609722, 0.1202996596111916, 0.14273318083724007, 0.08234428300056607, 0.1908006757730618, 0.12286170182051137, 0.16930922196479514, 0.17748605663655326, 0.1263735891552642, 0.21545250609051436, 0.08728553933906369, 0.1515367889078334, 0.13099967763992026], [0.02313842051080428, 0.06115670155850239, 0.05004707367334049, 0.0895857295836322, 0.06292198144365102, 0.048900971305556595, 0.05869881235412322, 0.024185171569115482, 0.036171160827507265, 0.03961073329264764, 0.03906821220880374, 0.02254175975394901, 0.06329997209832072, 0.061913966783322394, 0.17649062880082056, 0.07406920281937346, 0.021816898552060593, 0.06052629905752838, 0.0662373258091975, 0.0215867028964567, 0.05754528479883447, 0.04358132355264388, 0.0330865167779848, 0.02892503129260149, 0.03021206008270383, 0.01657681645156117, 0.040974952862598, 0.05881853561731987, 0.024204181681852788, 0.024344976372958627, 0.029155265910958406, 0.03448271549132187, 0.02566888990259031, 0.052772351264138706, 0.05386254022596404, 0.02656166016095085, 0.07822203857358545, 0.014020937778695952, 0.023223210882861167, 0.04843098402488977, 0.01978372376470361, 0.055789693651604466, 0.058904795441776514, 0.005093212002975633, 0.033949660501093604, 0.08140947378706187, 0.02676565243746154, 0.03494376360322349, 0.03573312671505846, 0.028111670835642144, 0.0294485812264611, 0.033761585436877795, 0.03264212245994713, 0.02134459762601182, 0.025901261906255968, 0.02573137873696396, 0.041346253055962734, 0.0019193598313904658, 0.04461051168618724, 0.005979276493235375, 0.02001383778406307, 0.011368239447619999, 0.0630441315297503, 0.07567964843474329, 0.018090771736751776, 0.02894176301197149, 0.028887784756079782, 0.06069614697480574, 0.023241052113007754, 0.02001298616960412, 0.034102461286238395, 0.0904682841792237, 0.02300711417774437, 0.010770972912723664, 0.048143754320335574, 0.0325576512113912, 0.045942878277855925, 0.0353630065364996, 0.028637569666898344, 0.09036456904141232, 0.03972078637161758, 0.034445151686668396, 0.029585258853330743, 0.027271305480098817, 0.07354334666160867, 0.04502134979702532, 0.04182474163826555, 0.05603046120086219, 0.030881829807185568, 0.012192827671242412, 0.12757503718603402, 0.0385908368480159, 0.024135564563039225, 0.014515030943584861, 0.04036720441945363, 0.06565978648723103, 0.01564781825436512, 0.03790398288401775, 0.03993758997239638, 0.013064700906397775, 0.07056600603391416, 0.058150528493570164, 0.01731028842186788, 0.010937557235592976, 0.027773824804171454, 0.015272483560693217, 0.030450564081547782, 0.08526815188815817, 0.06097944700741209, 0.02940951642813161, 0.030537913007719908, 0.08125194552121684, 0.02688913096790202, 0.0306665012249141, 0.01171055135273491, 0.03394894803932402, 0.02877964827348478, 0.031877691799309105, 0.014527661369356792, 0.024455689963360783, 0.011915474096895196, 0.039022288110572845, 0.05798881080409046, 0.017371788344462402, 0.06808113234001212, 0.10391974050435238, 0.04614203731762245, 0.01643558389332611, 0.05233549345575739, 0.040748850151430815, 0.013523413108487148, 0.05121977832459379, 0.047155462234513834, 0.01630622940865578, 0.017053881965694018, 0.025657466394477524, 0.041936048946809024, 0.09618173775379546, 0.022405171184800565, 0.03692955040605739, 0.01966747375263367, 0.044048290292266756, 0.06943740721908398, 0.08338178318808787, 0.014908987977833021, 0.057024668203666806, 0.006781779329685378, 0.049302506595267914, 0.045691512859775685, 0.0543213878700044, 0.04051448362588417, 0.025010988974827342, 0.09918440788169391, 0.06062819593353197, 0.006388816773323924, 0.033531898152432404, 0.09479873071541078, 0.06099663885834161, 0.06449212844017893, 0.012543226202978985, 0.050948760836035945, 0.0750519844586961, 0.05137660897162277, 0.09876562136923894, 0.039412141995853744, 0.02676509026059648, 0.024297705276694614, 0.03150621349050198, 0.02978783919388661, 0.024166356270143297, 0.019524560229911003, 0.06858698019641452, 0.025381968189321924, 0.008825432778394315, 0.03920072267646901, 0.02217389570432715, 0.06762221790268086, 0.015908792629488744, 0.13122122356435284, 0.05750452975917142, 0.05741563159972429, 0.04621201071131509, 0.006283288939812337, 0.012985563844267745, 0.07159033310017549, 0.04201171832391992, 0.020756644116772804, 0.06145938277768437, 0.02498816236766288, 0.04270245000952855, 0.1291356995352544, 0.024171137556550093, 0.09194854967063293, 0.009975761677196715, 0.10543971831793897, 0.01401041226927191, 0.007050578724374645, 0.030053715454414487, 0.01628689275094075, 0.02746382415352855, 0.041926686753868125, 0.029743297345703468, 0.0030550207611668156, 0.054564712118008174, 0.04870486620347947, 0.04957280420057941, 0.034420304582454264, 0.02656041891896166, 0.029690697629121132, 0.04147434032347519, 0.03732305936864577, 0.0440273431740934, 0.04922924177662935, 0.05338824848877266, 0.05697959757526405, 0.0473507843707921, 0.10655390462488867, 0.033848205202957615, 0.03973336948547512, 0.03720468310348224, 0.06719861485180445, 0.00869919995238888, 0.047149966630968265, 0.006358622495099553, 0.03599348696297966, 0.04402583661430981, 0.07416741122142412, 0.01116476481911377, 0.04550284407741856, 0.06499234339571558, 0.01751842188241426, 0.02080707490677014, 0.023401394973916467, 0.024482485205226112, 0.023854511382523924, 0.00944665491260821, 0.055991735935094766, 0.018638461879163515, 0.05813229763589334, 0.021667392902600113, 0.01541047757200431, 0.047407402817043476, 0.029975762117828708, 0.03134019876597449, 0.055158756804303266, 0.06484996978542767, 0.06028596937539987, 0.0821287558937911, 0.011022001581295626, 0.02614413901028456, 0.04317945429647807, 0.02369558045757003, 0.009416420743946219, 0.051835597623721696, 0.11564658663701266, 0.048099206906044856, 0.027423273204476573, 0.03001559689437272, 0.11692902524373494, 0.03239582962123677, 0.10771000743261538, 0.039162739558378235, 0.04043449866003357, 0.012391559976094868, 0.07163861722801812, 0.058355279616080225, 0.029384272274910472, 0.009141913305938942, 0.020863470708718523, 0.030145956989144906, 0.022886593105795328, 0.029472751120920293, 0.00989067444606917, 0.04405035717354622, 0.017372983202221803, 0.03325094701722264, 0.032484976400155574, 0.05508309113793075, 0.04463762976229191, 0.021962480095680803, 0.043274319323245436, 0.061043371897540055, 0.05732306723075453, 0.04521637507423293, 0.04152399371378124, 0.0621623079496203, 0.04068437607202213, 0.05762881723057944, 0.08219453986384906, 0.033923703886102885, 0.036585216148523614, 0.019559034844860435, 0.06535984750371426, 0.031814115718589164, 0.009567039614921669, 0.03208876230928581, 0.06230137529200874, 0.02649572033988079, 0.06534388390718959, 0.0642303135828115, 0.04744118166854605, 0.06973984724027105, 0.007360767231148202, 0.034906062501249835, 0.1043776456208434, 0.00798286046119756, 0.06606339607969858, 0.040822166920406744, 0.02091633759846445, 0.040501032199244946, 0.0317050645389827, 0.06355546385748312, 0.04204390155791771, 0.06120399120845832, 0.08195463320589624, 0.0854530579817947, 0.037137110557523556, 0.05216325582296122, 0.013032334918534616, 0.05451014199934434, 0.09015011062729172, 0.04394604831759352, 0.02180878316721646, 0.029344227841647808, 0.027212451313971542, 0.03599447773012798, 0.018236765172332525, 0.0215689748438308, 0.05988376244204119, 0.023472130924346857, 0.02710262644541217, 0.04589672782458365, 0.018450589050189592, 0.01266534474780201, 0.048189897352131084, 0.03405745745112654, 0.04761418000271078, 0.0362095521268202, 0.05380238544603344, 0.06136943819001317, 0.029913879989180714, 0.0024057452128545265, 0.027612834419414867, 0.03734454825462308, 0.02201874231104739, 0.04157500523433555, 0.015532584984612186, 0.06314028418273665, 0.05519470272702165, 0.06519972172100097, 0.09644880701671354, 0.038350336471921764, 0.12755989737343043, 0.16472390707349405, 0.3172708925558254, 0.16985409194603562, 0.20085980475414544, 0.17204332369146869, 0.16501055419212207, 0.10826860714587383, 0.1664116547908634, 0.10351682853070088, 0.17637850512983277, 0.17385570768965408, 0.12195648203487508, 0.13866876455722377, 0.22646780329523608, 0.10989648581016809, 0.19655469513963908, 0.1519172138068825, 0.18094551865942776, 0.10632019490003586, 0.0945070073066745, 0.11776270941481926, 0.1279693254036829, 0.1345519526512362, 0.12493026035372168, 0.12616011779755354, 0.14287356549175456, 0.12409912174916826, 0.10236291505862027, 0.1816055699600838, 0.10512264314456843, 0.09925408812705427, 0.1384804371627979, 0.14566456025931984, 0.07705950876697898, 0.1701166934799403, 0.15236466948408633, 0.1518296849098988, 0.09962362571968697, 0.17593376571312547, 0.21340990788303316, 0.14154810458421707, 0.17354134877678007, 0.04898453342320863, 0.18153157783672214, 0.13265766523545608, 0.10222381431958638, 0.08662864958751015, 0.18344505719142035, 0.1275136467302218, 0.1700069595244713, 0.14275416877353564, 0.13613167335279286, 0.1334671999211423, 0.11570528309675865, 0.09593832815880887, 0.11111054292996414, 0.09045251354109496, 0.1570344259380363, 0.08251868028310128, 0.10845360229723155, 0.07246076842420734, 0.23303950612898916, 0.13852219039108604, 0.11664101257338189, 0.1343728872598149, 0.17841374123236164, 0.12385119989630766, 0.12326433177804574, 0.16563547222176567, 0.1800624222960323, 0.22534117859322578, 0.14037433866178617, 0.1140347086766269, 0.14292309642769396, 0.07782178348861635, 0.10213549132458866, 0.12230131353135221, 0.32526845403481275, 0.161364026425872, 0.0938338645210024, 0.05985087416775059, 0.23938087600981817, 0.12189294677227736, 0.30500978173222393, 0.11891554677276872, 0.21626085333991796, 0.14718061953317374, 0.15327362227253616, 0.07982852112036198, 0.1456776517443359, 0.13355383824091405, 0.13184217852540314, 0.1612082644714974, 0.12194643335533328, 0.1972442987607792, 0.14528846950270236, 0.11059070558985695, 0.14598202134948224, 0.15720250754384324, 0.14944972121156752, 0.13488882832461968, 0.19864698755554855, 0.10060627377242781, 0.09664675264502876, 0.15945038379868492, 0.14363901660544798, 0.19295518985018134, 0.16621351620415226, 0.12156514756497927, 0.0764057063497603, 0.16613432904705405, 0.17320404265774414, 0.09136683205724694, 0.09142595896264538, 0.1757287696818821, 0.12690478877630085, 0.12082348970579915, 0.11403156939195469, 0.1418370078317821, 0.17476791108492762, 0.1105738959449809, 0.13819496263749897, 0.1506494771456346, 0.0937343796249479, 0.10780286494991742, 0.09846813889453188, 0.19163289049174637, 0.11392998421797529, 0.22632749285548925, 0.11012599497917108, 0.18540126940933987, 0.1375948471832089, 0.16758242243668064, 0.09273445437429473, 0.21991751884343103, 0.13885498425224796, 0.2863054338376969, 0.14504831051453948, 0.15688920248067006, 0.17167311074445024, 0.11283760963124223, 0.11953557404922321, 0.26868518558330834, 0.1255900741671212, 0.24901457625674084, 0.07922173375845887, 0.11451634767581709, 0.11731408114428632, 0.17811542755225673, 0.11539801911567338, 0.16921673552133143, 0.17932051210664213, 0.09295350668253377, 0.07629794650711119, 0.10911049947026186, 0.13727646582992747, 0.14702744025271386, 0.2222521076328121, 0.15637023345334455, 0.13553112745285034, 0.16224829538259655, 0.13910214911447838, 0.2262039401102811, 0.15645506093278527, 0.10192493660724722, 0.08551213293685578, 0.1000413361180108, 0.07730467725195922, 0.08355146783287637, 0.15924439328955486, 0.2105250462773256, 0.15171536448178813, 0.17595917684957385, 0.2260391239542514, 0.08231913903728127], [0.053155340283410624, 0.037798950434080325, 0.05048783517850097, 0.038684280661982484, 0.025485779806331266, 0.06110672162321862, 0.06263246221351437, 0.015531428161921212, 0.02544062754168408, 0.034716896479949355, 0.03255766976508312, 0.02134845679393038, 0.0550038928486174, 0.03753544719074853, 0.02614020006149076, 0.04696287120168563, 0.0793110512313433, 0.01258590897123213, 0.02228162771643838, 0.047565331842633896, 0.05839120698510669, 0.02860867043636972, 0.030684329467476346, 0.01467580425014603, 0.0718251931539271, 0.03397169115487486, 0.08798542170552537, 0.02450989642966306, 0.04691290982009377, 0.016775097901700065, 0.04158530253334902, 0.020953129569534212, 0.022896630653121974, 0.042024253198178485, 0.07690576545428485, 0.04240757247316651, 0.03957112116040662, 0.05605121536063962, 0.04514092091994826, 0.031469510577153414, 0.021027297952969093, 0.02549300275859423, 0.019676648553286213, 0.03205703920684755, 0.04959183657774702, 0.05169337244296912, 0.0034509836814322625, 0.03554970491677523, 0.11011701499228366, 0.05403926785220392, 0.030450899903371464, 0.014412731452466687, 0.006498592474599718, 0.06930790244950913, 0.02277599269291386, 0.03364044096088037, 0.024717686646908987, 0.020492242874752264, 0.006096192582845106, 0.03227278153644875, 0.03419931897951756, 0.017214421495737042, 0.015878095546213444, 0.03883516670612153, 0.08176243180059828, 0.01981777350010816, 0.025567002303432673, 0.07108580626663752, 0.08136311924317852, 0.04494027387409005, 0.050978643412236124, 0.08091234616586007, 0.02110485795128625, 0.018013501176028512, 0.05143061134731397, 0.10672917764168233, 0.044476368493633345, 0.03738485058420338, 0.015871772448008414, 0.04517667388427071, 0.03343089185364079, 0.014688545070384862, 0.020257058131392114, 0.06713578462949954, 0.04936270219332073, 0.025411347960471176, 0.03334618311782833, 0.04522468341747299, 0.020837137453781907, 0.040155358365154825, 0.025120320315181743, 0.023438893840648234, 0.03326655438286252, 0.04694661816756707, 0.10339155400288291, 0.04675407908507623, 0.023636288424313534, 0.03274097653047647, 0.028796392980439123, 0.026717114124039654, 0.10081782296765596, 0.07088756377925165, 0.011441886472312035, 0.0845405577274505, 0.015586051158607006, 0.10685581029974855, 0.019494898442644626, 0.021527800490730442, 0.07175897131673992, 0.03363965057360474, 0.028175118895887863, 0.026925559286610223, 0.047680431525805034, 0.03217659177607857, 0.06820218404754996, 0.013073347854515305, 0.013137816367816413, 0.01946404365298804, 0.12498940952355042, 0.03609881998272613, 0.04921170853776857, 0.045791765878675506, 0.0424024850508431, 0.09168769218376838, 0.02930656755779637, 0.05306435668899212, 0.015157870911934879, 0.027378104241506662, 0.0358791887992993, 0.09221288040862419, 0.028191815363243222, 0.07115138985682279, 0.033034139705705456, 0.03361984636285342, 0.07215042453026399, 0.03273285743489396, 0.039475888770539314, 0.09491450575296767, 0.0327319854113739, 0.01546777508337982, 0.02963733164506266, 0.023237725436047185, 0.08299402586999349, 0.03557136449671816, 0.035675673352670856, 0.07899387215729803, 0.03548170192516409, 0.022530620117322542, 0.02161674503440736, 0.04596294224029407, 0.02482793825038243, 0.020599024937837385, 0.06609444011701271, 0.05006662555388175, 0.061527890429715626, 0.028230755851836875, 0.050744135878630914, 0.05575942515861243, 0.03186781381373294, 0.022516428398375865, 0.028357091650832444, 0.010302520950062899, 0.0923514468013309, 0.034493061029934324, 0.026963900490954984, 0.03437195366132073, 0.011255139852437424, 0.028386977937771007, 0.036771743834833615, 0.05502796069777105, 0.029695371304114815, 0.026705293566919863, 0.0465958198037697, 0.02865395443222951, 0.00940142843319336, 0.012217627463542158, 0.03654817555798218, 0.0706923269899562, 0.04868511394306552, 0.040666052445885725, 0.037620994553435594, 0.010912588604696793, 0.011785575989051722, 0.008261476614279673, 0.054552789515582845, 0.08102369058178738, 0.02875694783142535, 0.026293433147657197, 0.038458036942756735, 0.055295534621109255, 0.05130492492753547, 0.02452691573125776, 0.03777608857490122, 0.017784622832550667, 0.07248408670420758, 0.08632971250335686, 0.03164098379784264, 0.038904858083697036, 0.036713629961013794, 0.0347425154177472, 0.031108377806958742, 0.02298058239830425, 0.024940175098890904, 0.031803810998098925, 0.07142684538848698, 0.04718400523415767, 0.02870412361517083, 0.04571682380628772, 0.027709358146239538, 0.06351707255817018, 0.056247435495606624, 0.03428060641454067, 0.1296655781334266, 0.050419728286215104, 0.024163623311324045, 0.029741770376858767, 0.044118441801401787, 0.03134106707875617, 0.020177340338705108, 0.09909348736982793, 0.0322459232120309, 0.04343568078184035, 0.02868337502150098, 0.029302684270078316, 0.05192497446842026, 0.01093656275770627, 0.016723288572393358, 0.04855112660152372, 0.023556440755783115, 0.02698558419069741, 0.050614026258699596, 0.042979219142580405, 0.03460083942627534, 0.046348821924766526, 0.014852321291982662, 0.04548497687210329, 0.01319497472650255, 0.042009540120488964, 0.048396106794825755, 0.06262677736231126, 0.03402158574317582, 0.028403555661498103, 0.01569051772094099, 0.10295865184161812, 0.012724845510092564, 0.036891734271193855, 0.05804353677376639, 0.027100752522528637, 0.028185427327116486, 0.06622001150390133, 0.050639775072340854, 0.05700172099750489, 0.044043904199497774, 0.04963251369190402, 0.011845943208754761, 0.022707811585860327, 0.020380260211823042, 0.011181051249877783, 0.012207737418066245, 0.054911532570258714, 0.06619356878218241, 0.008807244594208896, 0.030721141847607214, 0.04883859379333444, 0.019543690941645764, 0.06654916884144768, 0.054126822724356316, 0.04951718765369151, 0.02798691395582864, 0.04747555423818994, 0.0537375477142632, 0.03673321152746212, 0.02282094272231916, 0.06774503592168912, 0.0659236942010466, 0.029435884935082868, 0.028414493062882684, 0.09786681373952888, 0.031488353706663474, 0.0839120551245287, 0.007279995588760357, 0.03517090532113798, 0.037784341257065535, 0.04416846626554616, 0.033755870899767615, 0.027566795288294088, 0.04300349479308352, 0.020253803813830018, 0.07075176559737884, 0.033730244540493004, 0.02729416733927792, 0.022403688744816463, 0.07726541763986461, 0.04853954538702965, 0.08925519185140729, 0.00937776505452348, 0.03722849862242583, 0.03516264150675852, 0.054053917847340927, 0.010153821458516177, 0.021315831982064992, 0.0899751864199061, 0.018072945349558722, 0.058999426692025736, 0.022407944961742032, 0.0766323137213476, 0.09407377117895521, 0.046527130325557664, 0.022428543270507362, 0.010286956257914426, 0.038151106928125955, 0.015226515861286316, 0.03805424181337003, 0.04607432747434359, 0.03237168013583869, 0.05039392752223648, 0.07309134904062375, 0.00889302944415249, 0.03244271480070893, 0.03498643338389229, 0.04198385438940022, 0.08515926398104057, 0.06582605725270696, 0.03769313872908242, 0.036458765316638164, 0.031203814287437126, 0.012772108257195214, 0.014750172085769009, 0.014873239651933545, 0.02201046736445278, 0.08235172674176283, 0.023992803180590272, 0.04227590805385262, 0.023076998513715807, 0.09121279930695891, 0.019754021159315016, 0.01500259320891928, 0.05583103498793207, 0.12306907272432, 0.021941725935903378, 0.03509726571792271, 0.02892653599701589, 0.04310449738113675, 0.018450123352522496, 0.04168748884694651, 0.04814180618268438, 0.05004412363632582, 0.053427923703566194, 0.019857233492075466, 0.030189059070835356, 0.07112340346793644, 0.046398683116422035, 0.12583192525198683, 0.17722937744110823, 0.18898348265793175, 0.17003902030410245, 0.16643719951389357, 0.13432190171442926, 0.10097824560943991, 0.1633040004526265, 0.14396263752132654, 0.21341911051422358, 0.09089312661672011, 0.10909275471931323, 0.09919840478687547, 0.10266341065289453, 0.1413664416759275, 0.1725959565374069, 0.17916255339514464, 0.07113790503353812, 0.2032979973591864, 0.1818709322833456, 0.2277780501754023, 0.1237470617343206, 0.13654116075485945, 0.14216413168469444, 0.1070500080822967, 0.11995585227850825, 0.09349098487291485, 0.07575611933134496, 0.1884658049675636, 0.177882318967022, 0.12784869672032073, 0.1842770047369413, 0.14827191800577566, 0.09981246519600973, 0.16683509456925094, 0.11222815795917995, 0.34577728947624564, 0.1918002002639696, 0.12008206191239879, 0.30617489421274513, 0.12676164333242923, 0.16274612804409117, 0.08747389641939662, 0.3157381498022005, 0.10746256055426784, 0.18024871620582417, 0.08567234777729027, 0.25493369379546493, 0.17922533908858895, 0.16098195395898074, 0.08502599652274512, 0.14155880635371432, 0.11289831731119193, 0.2077138057211414, 0.10016710046329536, 0.09667945909313858, 0.10736628173617646, 0.11354742935509421, 0.1298100594431162, 0.10774217953439802, 0.0917387890513055, 0.08840020062052645, 0.16496516444021836, 0.15653991809813306, 0.10090487689012662, 0.11143948504468426, 0.17671943292953074, 0.2386738616041839, 0.14380874577909708, 0.1130297665076796, 0.107369792094687, 0.11938416108023375, 0.11194522157893516, 0.1559417470707558, 0.12632785801542923, 0.24564378603827208, 0.20055472268722951, 0.11946003825869411, 0.08189719839720055, 0.1140758756082505, 0.09719622394186445, 0.13893172232201323, 0.1127071697555948, 0.19012882432434708, 0.18178999365773052, 0.11487260824651457, 0.06910921467351727, 0.1770980321452953, 0.12715058808680624, 0.12762470170855522, 0.14467581175267696, 0.17227312229806557, 0.12720095022814348, 0.2541775640565902, 0.12780073913745582, 0.10739531455328688, 0.1690240591415204, 0.12488972424762323, 0.1848804746987298, 0.09113131891353987, 0.12740812817355618, 0.2644629590213299, 0.05455586200696416, 0.20603687851689756, 0.10904850045335479, 0.24408551340457052, 0.17334582254989073, 0.1318813639227301, 0.09927797786076553, 0.09840144208283164, 0.12705185275990516, 0.09377091555506922, 0.18221359670860693, 0.13448170095216483, 0.09248090704204515, 0.09132786188274622, 0.17752914573065937, 0.10527571852435358, 0.23701278667431325, 0.09701064249384217, 0.08918978637666442, 0.11858326499350369, 0.11095530047896318, 0.1806786423549056, 0.17444203404011205, 0.19269104464910924, 0.12480652949307114, 0.18019553390331566, 0.10785748701891862, 0.18434908211929724, 0.1805813764804043, 0.18473333650035784, 0.11342216967022978, 0.08144855528371409, 0.19620863167801872, 0.06309251955826767, 0.13165276759536937, 0.1370463555213064, 0.14904244540957734, 0.11538761420524679, 0.1589483060524799, 0.31681111722718924, 0.13338068034499884, 0.12189449786092155, 0.1238770637428388, 0.17426929174689576, 0.12832662498112768, 0.17736882698955014, 0.17736388428602368, 0.20238243945641443, 0.09672416606917977, 0.08842509967507794, 0.09328665677458048, 0.11975412169704214, 0.16010650171665475, 0.14386802853550762, 0.1710153601015918, 0.12018035937217064, 0.1647766144014895, 0.09581655656802468, 0.1861525306594558, 0.09416629472980276, 0.22516135621117428, 0.17155800363980234, 0.22380251350114122, 0.1023844002338592, 0.141242963145487, 0.09335310125607066, 0.16602170071564615, 0.09868483859463595, 0.15184319199761376, 0.1314782293047756, 0.14591113140340894, 0.08848031546222046, 0.16661981237120926, 0.15160658047534525], [0.05075380235211924, 0.033578775910427794, 0.036802190443268046, 0.0716705369995907, 0.049187495969817974, 0.0525734965049196, 0.01844669834099477, 0.04190667474176735, 0.01809007782867411, 0.04327421171183232, 0.032356826050090604, 0.03945160198782105, 0.07012796078925021, 0.02475235978636192, 0.1237877833773382, 0.020281367178540677, 0.04832976250327192, 0.01509152569269645, 0.04524779760686215, 0.05893156099773478, 0.04747251885419246, 0.01692953326710267, 0.05119291628943756, 0.04655854543671012, 0.029527547594625503, 0.04525125230429694, 0.01568704261444509, 0.020394874954945408, 0.024025613529374823, 0.07108449266524985, 0.041724863403942436, 0.032766673393780366, 0.06319360749330372, 0.07535248747444712, 0.03892386819643434, 0.017388909691362642, 0.10462679943884723, 0.016227036685450003, 0.049028019566321746, 0.05332042361260392, 0.055204636373673566, 0.03992095844296273, 0.02257970019854838, 0.030557874924852513, 0.010208875828539021, 0.03668687924800906, 0.011835994719149312, 0.006010126644468983, 0.0174676422830089, 0.018435647762089502, 0.08366881622350775, 0.00460414596091141, 0.010262511768814875, 0.026360118827142287, 0.021418966389319394, 0.04168419000052381, 0.0367839632963296, 0.037904264900134876, 0.04839961344259791, 0.036989267318858765, 0.00265336742359068, 0.00859373056300683, 0.01967807718756376, 0.0454338503186591, 0.023472164320992306, 0.026568333923933096, 0.022891420776431914, 0.06477271963376552, 0.027976128694717772, 0.02229891048045829, 0.04865314593189396, 0.023206521836982574, 0.03285872568085324, 0.0424191054480616, 0.03395586485567037, 0.0961492391070351, 0.04639613383915275, 0.05813362236949615, 0.030031243222765625, 0.04168364823271986, 0.07395130523946136, 0.03604974175686948, 0.030774543083680328, 0.09133311628829688, 0.03750430667423643, 0.04762418415339198, 0.028398189933795948, 0.028428645819076337, 0.053539605796686374, 0.060073889544582926, 0.005290588960633613, 0.048587317432975397, 0.046848591591697186, 0.05375558932428248, 0.032595845841569826, 0.08667897462146357, 0.05143597336427774, 0.07923017197754234, 0.08967800822574645, 0.0438891738303937, 0.07729646167717874, 0.04790108687302563, 0.010515728845348349, 0.027183435195183847, 0.041841365746222436, 0.037238291261019185, 0.08378531114431098, 0.05102491260913666, 0.04517000197665766, 0.042310722201364115, 0.047973086329875514, 0.035615229135146365, 0.03484726956230588, 0.022670975085929967, 0.053152816981310025, 0.017737730231601745, 0.0287374831532361, 0.03792703770159278, 0.0415922564570792, 0.03759004328458104, 0.030238276449381374, 0.013454141044348944, 0.013164886204322102, 0.02203215663030278, 0.027016361054847948, 0.05981586335110478, 0.03125606519461144, 0.03935573135095183, 0.014297194829850923, 0.05886915751034394, 0.050487323096604086, 0.03713023084856104, 0.037623154203174636, 0.034079439865308814, 0.03777515717956703, 0.05637817223032471, 0.009817434674914693, 0.020878599389106967, 0.01617463549337117, 0.0979168493358884, 0.0521565319650108, 0.034952665664604865, 0.14994378376286477, 0.03567550636944361, 0.03919301918358542, 0.0578479994146619, 0.035221634825575165, 0.04876866121776402, 0.02054998567473376, 0.011398807582736481, 0.10992816809448414, 0.0603821702679852, 0.036911004135617986, 0.13248155359178782, 0.03630410174082499, 0.052812263966188766, 0.057371752118342556, 0.051705714358831756, 0.06180943157232832, 0.01855554357462097, 0.023169911692093592, 0.010363957790104905, 0.06194135574332904, 0.07733920938335359, 0.06545568845467642, 0.02851082754204981, 0.056690675774007104, 0.014130198615021072, 0.07801149127772078, 0.0614539317029994, 0.10264120559440926, 0.06273510865867138, 0.05976147505862173, 0.03044199969735928, 0.0846648526203353, 0.022107434524514247, 0.06048930670658592, 0.039611980100744404, 0.03788973735936452, 0.01829722608817974, 0.08764229714870453, 0.004669247155106859, 0.025083947657549288, 0.018952917271235492, 0.03579260242986493, 0.012025697869830765, 0.03059480048250407, 0.02592250773886917, 0.024587734733358957, 0.045285569212865084, 0.022230707108974457, 0.025826893142948393, 0.027776236784120556, 0.0846607782295905, 0.00797129872808, 0.04775055705977138, 0.06592028774321079, 0.046637584164272994, 0.026296056639694143, 0.0849709143221844, 0.03010369538969826, 0.05591128712694626, 0.061047479684930295, 0.025679845857666805, 0.06839086767286062, 0.028300022349867504, 0.06684780906653032, 0.029064753580314573, 0.04155537913902663, 0.09712095532449894, 0.05418588283646386, 0.02326985115360003, 0.05659028174704872, 0.04765898716868833, 0.026590917477733456, 0.02614166951389052, 0.04853321486734785, 0.010061348002636805, 0.07115959058864973, 0.0626760559680406, 0.03049417082365835, 0.03717166866408661, 0.03200877734343521, 0.02909894617914688, 0.03945742784708273, 0.009696397810330382, 0.043624798563541844, 0.023259620647877455, 0.0583165766147431, 0.07042911689495668, 0.0416110031073913, 0.04411112793604843, 0.06421401601983234, 0.05101362825371325, 0.028082305907446425, 0.01609203445696039, 0.0283560173920705, 0.05242750863544643, 0.032521801767870784, 0.05153977755981032, 0.01450716325052781, 0.04162852521403693, 0.07700125759583898, 0.03151091128529515, 0.03819669334916398, 0.023294540551432874, 0.017588719965715427, 0.015781204456288833, 0.05839362638653256, 0.030169162091624457, 0.04396177813760005, 0.0695331665338017, 0.07290691792150028, 0.012279728525754763, 0.02072286712063942, 0.0661457002570387, 0.07665886034374125, 0.03451993048656732, 0.05191279582504649, 0.011508850457175868, 0.05457383311295416, 0.0404985200293595, 0.0033764152340154396, 0.033253496294491924, 0.018005853344220668, 0.030910241075616796, 0.03855384078633506, 0.10109440656378865, 0.0520183180924505, 0.047723283132654615, 0.03510475769871846, 0.06716660602251068, 0.07876100105931982, 0.029690215233131312, 0.021941918894299306, 0.01864382575149648, 0.04908253773464821, 0.06391301576513797, 0.010942047229036689, 0.08139126890455373, 0.027706658584065735, 0.04226628610922489, 0.15173762891208753, 0.018356536675128154, 0.03614217624999583, 0.07879079828853719, 0.012521676089818357, 0.03899437593645416, 0.080225696292473, 0.04972182374331169, 0.03198827551386785, 0.0433921352669131, 0.013503621885320172, 0.044701016595354304, 0.031887146760709584, 0.03719733955222182, 0.04409457433212083, 0.0235390039961203, 0.04694431379903108, 0.04789534265000839, 0.06838035144028254, 0.005696465814253315, 0.03124079179542605, 0.09719377485453151, 0.041546632928657345, 0.02428778461762704, 0.010290262525813887, 0.06794919332605787, 0.044511646483442746, 0.03771380383113865, 0.02396824365860084, 0.02324668130313512, 0.059387410365161486, 0.018117425970558543, 0.03349290942423977, 0.020758883547387086, 0.05082054740341846, 0.020572300200001337, 0.022604703153774608, 0.02646462991833687, 0.022630299827142153, 0.012423581792972982, 0.026398870068078395, 0.05322080512996763, 0.020979507353331428, 0.0412080466048792, 0.08910132237360813, 0.03834946815914009, 0.10163422994082794, 0.03443729234277271, 0.01776196320861345, 0.017015509220073, 0.05784511617093813, 0.023406463842547964, 0.0352588757959893, 0.028308918845141307, 0.042014401187771, 0.1076834014384076, 0.04572207821183838, 0.029912848403910175, 0.018982599467562977, 0.032656494149705395, 0.06468573250458576, 0.07182327841292135, 0.01741757514537312, 0.05412468162830919, 0.028915912153024692, 0.058128219534410164, 0.07238520294777118, 0.08893908889149316, 0.07134731684345752, 0.03191945987055078, 0.15441906783962622, 0.10014051673351787, 0.1221479412924964, 0.13828838418703526, 0.14141432504402474, 0.09724966599605978, 0.14580539020244032, 0.09594869596185163, 0.10603830494801514, 0.10850528546143323, 0.17551161727169529, 0.13846531219314784, 0.14630182762630284, 0.21370725677115843, 0.25250657403375953, 0.09750518001965247, 0.10773561894893646, 0.21919634426012635, 0.10461516998475417, 0.1509718067245558, 0.12659080093726516, 0.11581624901737086, 0.10875380845391192, 0.1913065236294642, 0.15198115725070238, 0.1394297182559967, 0.1923169131623581, 0.08588855765992776, 0.10232479093247093, 0.11416195731726475, 0.1673049185774289, 0.19930003298213705, 0.15340156853199005, 0.19669703906401992, 0.15018186473753303, 0.14806883671553805, 0.20011722663184628, 0.21740334515925497, 0.10021205234806985, 0.1111404737457633, 0.10818836613907479, 0.16251474124146625, 0.17694906826363876, 0.13435439293971285, 0.15096708666533232, 0.09436512351385318, 0.2085781257483177, 0.1318040321348235, 0.11949732375796884, 0.1663533368264325, 0.1113101138616912, 0.10039331449661404, 0.12539318238850683, 0.16417042817920446, 0.09737227621371858, 0.16613685234915465, 0.14900388341629878, 0.11014428891940042, 0.1645240021753125, 0.11657584458589554, 0.19196060806280002, 0.15795790997799486, 0.06785164543543942, 0.25488584011327475, 0.10831945910467766, 0.10717743483837694, 0.2578908554278314, 0.17338151985313743, 0.11909358800039627, 0.14306103199487552, 0.08063789253355935, 0.17745319433743134, 0.11300902348011732, 0.1254095244803466, 0.15273988450644538, 0.13992670486913994, 0.15286944864783436, 0.15358553209807724, 0.1583646662766114, 0.14304158772574738, 0.10883850234677084, 0.10245797675452195, 0.09678656584583223, 0.19470998318865895, 0.20020016905618832, 0.11668816121527925, 0.1329671556595713, 0.08462459853035398, 0.13048223743680865, 0.25116782868281007, 0.05771981937868986, 0.29182707192376256, 0.14954900572774932, 0.13717887341044843, 0.09564592939568684, 0.19454896682873368, 0.1343969625304453, 0.18347003788221627, 0.1652063030633144, 0.09196941886330023, 0.21934904856607318, 0.09660405688919127, 0.12956909893546253, 0.18105691502569243, 0.09528751659672707, 0.2104449537000619, 0.2077252496383153, 0.14546857390087098, 0.29312214930541813, 0.12163241583039053, 0.14931050915038213, 0.09991336017264985, 0.18377019208855927, 0.14330681646242738, 0.12414884564350359, 0.06578049680683762, 0.0934666943794582, 0.1503001037053764, 0.11792523975600488, 0.12729328824207187, 0.12251742693479173, 0.09224805078702047, 0.1765592923038639, 0.10968124071951024, 0.13120384246576577, 0.20008151448564604, 0.13433149026241153, 0.10692885247408412, 0.12262120144441724, 0.11622224090388045, 0.11155137864989229, 0.14528238389175385, 0.20668315555667505, 0.165248486737255, 0.14208322274498641, 0.11253721793764271, 0.1492121152114123, 0.11045556049793959, 0.17834678466897458, 0.17988159059314057, 0.20173286728095263, 0.09860415972070768, 0.26479383814148605, 0.10149316251045093, 0.11432672894443385, 0.08834878462948836, 0.10547999467235059, 0.1373384945327416, 0.11745505209546536, 0.1892605857574381, 0.2527413301868364, 0.12324093928327784, 0.13927799358498305, 0.24975103908218443, 0.13896296673920006, 0.18371024139923975, 0.10860161622986197, 0.1143323618452996, 0.16588330501690507, 0.08987717839772813, 0.13173707557143643, 0.2452246507164091, 0.17166787118185312, 0.19765150034800172, 0.09694746346212924, 0.16207393520744517, 0.15311392693547532, 0.13570143550168723, 0.15165398886892945, 0.1052577214431949, 0.11327393309329636, 0.1872215943876654, 0.21694575174478814, 0.16863260592799634, 0.1856623569619842, 0.18409068114124238], [0.021659318335878197, 0.03471143056231085, 0.0776946239056997, 0.031671541728428565, 0.042224540302413516, 0.014439834685617825, 0.030031176429474726, 0.049257695718551986, 0.018187902169302106, 0.04466159371077083, 0.04406221298268065, 0.022262437632889487, 0.030210061850084458, 0.03463058470515534, 0.01571995500853518, 0.016349706274922937, 0.03917567519238219, 0.021860497872694395, 0.03189043447491713, 0.0234314872068353, 0.07869555105571635, 0.04689158049586695, 0.029632761870743707, 0.06548602003022097, 0.028569195601448882, 0.04616810525476467, 0.07204428256954998, 0.11886577834957279, 0.0418339368479792, 0.02593484037788585, 0.031079395084816497, 0.04274033293768298, 0.07502483669668436, 0.0305425402984838, 0.052433045057114214, 0.07879945915192366, 0.025202145807270426, 0.04540318848739844, 0.005476115211422439, 0.0068986587757535744, 0.08666903726407327, 0.04432320776686538, 0.0380112677521538, 0.02739625531830825, 0.02915779663453577, 0.03829140252491925, 0.011538405560713727, 0.016610882885288447, 0.025476194969087373, 0.06666090659564361, 0.05381300186854787, 0.0541707578668138, 0.04798476773430593, 0.019076594326179475, 0.028849449117842596, 0.10503265031729825, 0.06894176389323547, 0.03836048905213829, 0.036946393447578885, 0.017428197133995127, 0.029755186551483348, 0.02913487911428092, 0.06277364838751964, 0.026219630271953065, 0.024910684005590156, 0.016759264181018807, 0.0078743612539256, 0.06665977110969834, 0.052212285809218884, 0.027806748330476694, 0.01590853473317111, 0.05139512555615511, 0.03286326020315755, 0.059257664397591725, 0.05501643885509111, 0.03980779947596602, 0.028323746955720708, 0.031884645723039284, 0.06785181612940505, 0.09528320471872576, 0.03067741450649919, 0.03258036093029659, 0.023800393973942846, 0.06335477228276432, 0.029961243853904307, 0.024518507198081352, 0.027870673220604658, 0.04957531637046486, 0.0019022517039957165, 0.09046543433214538, 0.02956254356831778, 0.03067834590183338, 0.026043568723252974, 0.01576780869072536, 0.08036895305849612, 0.03877603980072308, 0.03497440317005385, 0.03189500239386689, 0.03968993900343776, 0.03789322174270637, 0.02989635231642751, 0.05725141287257429, 0.03322509059216827, 0.041992934566223994, 0.05142030662682373, 0.040002227324293926, 0.04827934841159731, 0.014477743588940939, 0.054046240329626016, 0.01502050865383353, 0.019057111094298307, 0.08585476025473326, 0.03583707562938798, 0.019350016373209655, 0.03011253251315793, 0.027548594116524328, 0.04028431394544896, 0.04563502428936772, 0.04225705750286579, 0.03667357254016679, 0.0101280327544373, 0.029357580933719873, 0.09050294989719987, 0.05205213405133691, 0.023272712132893503, 0.0481340989790624, 0.06380832099239342, 0.05871445311640855, 0.015316334283852484, 0.04140904246014543, 0.024961213130154647, 0.033483265215181746, 0.017125966769526713, 0.04218525471515022, 0.03352483290655073, 0.033163640764541924, 0.06628047427511774, 0.04367724613985047, 0.0890562665881589, 0.06015207109157927, 0.09594120769179426, 0.024403808274655603, 0.09119183363509364, 0.04614164769009221, 0.059808386213262565, 0.019573413956095465, 0.0059323644109099405, 0.09867999237030745, 0.019560641594580375, 0.02721468517847825, 0.03853938374959398, 0.028275674339965917, 0.07421503483783454, 0.005464012174343225, 0.030533076060237363, 0.013652915095008211, 0.02915189656050643, 0.04420579629368149, 0.024815397810016293, 0.0296020889072679, 0.01370213247355423, 0.03705200106196571, 0.05483011525939219, 0.05480383581016213, 0.057355146564077586, 0.029525738609663676, 0.06749721796950325, 0.03149306634441018, 0.08768038416747004, 0.07428979879477993, 0.042333914316259325, 0.05711932542908471, 0.0006725873345203581, 0.07178562926128507, 0.012425424174580257, 0.03103938219283009, 0.02566460956586525, 0.012514159989223117, 0.032670401997165754, 0.08005728814168833, 0.023887998941063415, 0.03198244594386779, 0.04206768368021585, 0.021994203198119067, 0.054268650856101885, 0.0043185707818338415, 0.04423114063683897, 0.01183682499686256, 0.013105554280627985, 0.014627131422457751, 0.08329857359058224, 0.0232452248383197, 0.03436064704146702, 0.014607501616410445, 0.0341802532057045, 0.052981840999564156, 0.06864843002404086, 0.02251627440273296, 0.08651803989778273, 0.034948569009429775, 0.020571804816427175, 0.04721533870906569, 0.041053219756577164, 0.034769971171044745, 0.042108049092348665, 0.013456528904498555, 0.01585082532983506, 0.038775973007432185, 0.03116111853159964, 0.02978826036269311, 0.026789482799358666, 0.042189388477709144, 0.05673041407135315, 0.06519537273561582, 0.04237303292029537, 0.023448302417818923, 0.09153547769528814, 0.04473371562198736, 0.01883652810647618, 0.040217327696154825, 0.01546040277389693, 0.023131494417611975, 0.02212916089774808, 0.018232303009426687, 0.04374804331746418, 0.07523749911342748, 0.04345944063970819, 0.040902448745328, 0.026425789619679563, 0.05297052695823368, 0.01583588218636578, 0.02254265589726856, 0.02136496957973577, 0.05839585654030088, 0.02097508971928619, 0.029365776099439245, 0.052592031643143855, 0.025823690775723662, 0.018858718322007917, 0.03390132071217522, 0.046251611711340956, 0.009474625530856429, 0.03642181007307954, 0.03915726250852458, 0.006952265030122362, 0.010502789500606013, 0.03826144944468979, 0.018894844215537887, 0.005477939039337798, 0.013705142810067628, 0.05821718448714819, 0.031308312391047366, 0.01989700147532858, 0.036064699743292294, 0.012023376802972052, 0.07693988940445706, 0.042709355693659745, 0.005332574573913007, 0.06777510774554685, 0.02338598613278009, 0.00886353835085174, 0.040693741975701414, 0.036803901093662716, 0.05771177449787501, 0.05147797892277595, 0.04816738801309839, 0.05358176720619667, 0.011114669850940118, 0.012720938102575019, 0.02427855786663713, 0.048206091014435515, 0.0201119645498693, 0.015408587878482649, 0.06471449072705582, 0.048385067348135635, 0.08165822684532031, 0.04911691772576887, 0.019805526208074298, 0.06647130270721391, 0.11257618069066666, 0.10127206929610111, 0.07296259384020232, 0.054665354764438234, 0.05029262807511259, 0.06818625755840912, 0.016721859938115813, 0.024475445934513118, 0.039490486815338954, 0.02341738269024063, 0.05173382320208475, 0.02877846269257134, 0.0228305609562085, 0.05680345253495034, 0.008829753005556995, 0.014193667084327899, 0.03319345283671282, 0.017061396210920066, 0.03766659210668877, 0.062331031513167545, 0.06331324912025593, 0.03715328195539769, 0.056703184673096985, 0.037725585425505415, 0.07594227965455502, 0.028574123462021817, 0.04050758907396812, 0.01114038434025133, 0.023001551780907903, 0.029297377914190292, 0.04540561531030107, 0.059609601958072744, 0.014653269863629248, 0.08896915329387411, 0.046550300176022574, 0.04549471756035928, 0.063175706891343, 0.016429422212240752, 0.0535770916758338, 0.021702995582018048, 0.029499375668819994, 0.028953830333193764, 0.018119676533387974, 0.022653827763861045, 0.04446486149390694, 0.05105490650748834, 0.009686626508482732, 0.023728899177513085, 0.07232261763419956, 0.05453099263831973, 0.05953242231043987, 0.07728322918410413, 0.03610004081565421, 0.04155960567004513, 0.03254116069001611, 0.013260581508802716, 0.07284269246156327, 0.028976634675927926, 0.02366963311942527, 0.037588265840895474, 0.014212878504622495, 0.04006670140370261, 0.058569912434904836, 0.06717224634485319, 0.0077532654813694535, 0.06789700550143607, 0.07718672030023299, 0.070138232113095, 0.022460357286036015, 0.026513114426052198, 0.007806682951922994, 0.029448217574099544, 0.009133364692388568, 0.1418211407144554, 0.07018944030278362, 0.13799903565086424, 0.16210114234127104, 0.1440451791859232, 0.13026769738644361, 0.11275660421233624, 0.1299612646107562, 0.12006948250927962, 0.11976765847066417, 0.07403418829198927, 0.11307144552120008, 0.11193224141607061, 0.11564364773221314, 0.21259664761601016, 0.07172981233452447, 0.1722047259681858, 0.12678778177360073, 0.11553532385732979, 0.13851947413058951, 0.17827546427724883, 0.13560382823925465, 0.18010800500633195, 0.1712325867265463, 0.08530249106115662, 0.1449368696194142, 0.10627603711327538, 0.2005319090676494, 0.16099522355943918, 0.14354026643559337, 0.1341061742277816, 0.15140326169785112, 0.17269108502659947, 0.16798488912172616, 0.2049323104438372, 0.18436667101923376, 0.23565851559396833, 0.13356250652577728, 0.20666178170358762, 0.06548737816046923, 0.24242336978204548, 0.1280333282193169, 0.18415493628708646, 0.17376952950144187, 0.11583068378968164, 0.10151205759029835, 0.061667547779507004, 0.18786478409310803, 0.08473728623357601, 0.16064680006820709, 0.1881904384936206, 0.15984565165126696, 0.14724699722137302, 0.10255097527988255, 0.10812912049004808, 0.19929292320739478, 0.14194022573065013, 0.14661067980341613, 0.1764331865706481, 0.13618994678836316, 0.2173983133980073, 0.10933869503787719, 0.11862731145811267, 0.21396515308879316, 0.1471791649237275, 0.085291959985625, 0.12735795899061486, 0.10453299939399585, 0.21617274556774646, 0.10615996521664783, 0.07787380061927252, 0.15318046789616346, 0.12342895497567952, 0.1383536634966731, 0.19899377832189202, 0.20324330107541755, 0.10690155628253706, 0.11006832268321887, 0.13932298257714137, 0.1637208351166919, 0.1575382106238976, 0.10527542908675969, 0.19047580804908648, 0.13737529021454975, 0.19536023813998327, 0.11543503744178452, 0.13152390107279643, 0.14465037093032151, 0.164542259008158, 0.17612770374398679, 0.13972156040836126, 0.10996324199368246, 0.07019606026005931, 0.28211975062731653, 0.18656799977179617, 0.135719588433858, 0.13648278341861442, 0.1609756753896363, 0.0883770604559686, 0.15823952533537522, 0.13062046986306086, 0.15213763166684657, 0.22232391784200445, 0.27277240063995123, 0.22858498734422028, 0.18115360202500597, 0.1298855952336453, 0.09003987201140262, 0.17839869047747925, 0.19011677184607834, 0.08137643337249756, 0.14452272152993828, 0.17207854602020234, 0.1349294831743464, 0.1069767729495652, 0.08064404493779875, 0.13460390298860148, 0.16666091250954196, 0.10956664569675922, 0.11739844849216752, 0.12221420765854418, 0.0930481156683527, 0.2087849474628456, 0.13379600102780387, 0.14130539260804653, 0.1988937219721265, 0.11876280535943806, 0.22872391738928854, 0.13285869819810614, 0.11689226666931063, 0.21229070465778932, 0.10938135368633084, 0.09703039104351774, 0.1593620830681175, 0.19596608297433704, 0.11291834045550786, 0.18462444859324023, 0.15346478467108682, 0.17939339100848883, 0.1523677122895606, 0.17757861729478464, 0.13313307019416243, 0.18027388985501602, 0.16101732471724972, 0.1825501606799662, 0.09575639065587893, 0.12445164931705222, 0.20271311077522114, 0.10564504089416005, 0.09233651479007676, 0.09256125194951892, 0.16300026909448206, 0.13730904611293226, 0.16758395126089454, 0.2999282075325027, 0.13342247810214758, 0.13983772136271, 0.15052187227411196, 0.12381041888147593, 0.12915744446218014, 0.09299122262746096, 0.18454760662280023, 0.1128893150598742, 0.15344234212534502, 0.10493257170310244, 0.1318415254354477, 0.19147469429299235, 0.08780012227362022, 0.1731728872982785, 0.2022326592123136, 0.13002669234992936, 0.20374839194118977, 0.11775700229918584, 0.10353172343457118, 0.13830389507347718, 0.15062501595821232], [0.057021580869331956, 0.012816941398341442, 0.019062391475017648, 0.09386985868331976, 0.020156081518507563, 0.0328950315451948, 0.041526617205818184, 0.01169910465250723, 0.038457142654806376, 0.015299406823032768, 0.051474360952852294, 0.020769472139363643, 0.04397476572194137, 0.020396398213051725, 0.04818144429009408, 0.030558587386622094, 0.074737247050507, 0.07005446590483189, 0.044995485950494185, 0.06470112464739941, 0.05664840675308369, 0.0844377331668511, 0.05922271295276005, 0.025989126625063363, 0.020635633227357175, 0.058793859207071364, 0.038941004386288114, 0.046069559175521135, 0.02564799287938513, 0.02764050725090783, 0.02867666229576571, 0.024344191551790573, 0.020646808115998283, 0.051789762583211996, 0.036494147207122296, 0.01850027583714109, 0.06799660914111882, 0.044337627696222626, 0.060987050310359336, 0.06278780856519006, 0.042359874641988426, 0.061941808453411795, 0.08606852105003782, 0.04772877131472342, 0.0353066144452896, 0.08275262007373385, 0.05732014687964693, 0.05153051555680577, 0.040591848810436204, 0.013514037000277312, 0.025518992770230398, 0.03232021219446324, 0.025228788908862043, 0.04929790156893432, 0.015922025122563355, 0.05154972976015415, 0.05484450550284237, 0.05156521838216577, 0.035750151582760736, 0.020118719949095976, 0.050746477354550734, 0.10633180951117538, 0.05538916768273339, 0.07154223450925201, 0.017528309144836385, 0.01910559931275202, 0.04232668950862717, 0.0561696472868789, 0.04442239209311083, 0.0393308619823074, 0.06762647783034481, 0.05244562817097176, 0.057521176131558605, 0.026092661792063154, 0.07293150527402759, 0.03559941025741864, 0.02905602963437559, 0.0417107069370104, 0.04245360047207214, 0.046428313362412155, 0.09665981444413774, 0.09796966798603535, 0.025099180238612462, 0.022104710842540953, 0.04387628272525035, 0.02481303035892779, 0.04882834844465833, 0.013063936494290829, 0.03248400418669917, 0.053745047116535716, 0.006190570111357374, 0.016687685892975423, 0.02843463866156526, 0.03133097387035377, 0.0315232494904194, 0.0031860395120020257, 0.030277729019871913, 0.023534514002676588, 0.045485785813070834, 0.028567399604071397, 0.0402771114022471, 0.05902619595872238, 0.022326640828396194, 0.015702423625043593, 0.01688201355136698, 0.045835166674805805, 0.05630952357023489, 0.07869845285313204, 0.07986324621015228, 0.040581176726846024, 0.015548293467873009, 0.023447387720807455, 0.009641878714319319, 0.010559884776739636, 0.07227120164316148, 0.03904309793142602, 0.07339660922298208, 0.03842799851554446, 0.06057728831365239, 0.03809390589594841, 0.02670468129508663, 0.0509598151256796, 0.011071849785366794, 0.06863303788122721, 0.009534997388982447, 0.03439720152528025, 0.0899290174129419, 0.021131181929376908, 0.00504229835314618, 0.0345720329642063, 0.03255872361478396, 0.027426698216004297, 0.06940974737517536, 0.08010864476091228, 0.03528859138896223, 0.03683085960801691, 0.06342671607853845, 0.07051546577713452, 0.0360674865078181, 0.0275046459864825, 0.0167433525348315, 0.0034439882438164204, 0.07276740157976747, 0.08312692967592739, 0.03021239404915832, 0.03977141197538003, 0.04122466329135932, 0.019372876377019566, 0.02751146075752331, 0.014813402140134713, 0.01917079513077624, 0.08901387511286885, 0.013757271262875292, 0.02652518916875124, 0.01672777671046788, 0.054104673326946795, 0.04833341758057941, 0.01016747604808188, 0.09499096180661581, 0.029298839945113286, 0.044160614343127236, 0.016630208410788327, 0.07884648162871599, 0.05887564388103783, 0.01968422959180316, 0.020854288486589212, 0.04594785066728946, 0.042476098678889684, 0.06413784198230132, 0.024057212322077248, 0.07802674983395264, 0.04684106992499437, 0.021344569795473944, 0.0796640760381706, 0.037376675827545114, 0.05635842368064914, 0.012237902938068146, 0.015126029993552947, 0.0064820639181562, 0.021405047409643885, 0.022049250146665145, 0.01371721755276667, 0.04670351656386629, 0.007982471761351917, 0.03129541015368886, 0.03381911672477145, 0.033087039992096834, 0.03053705582715338, 0.07005100749665871, 0.03727942479599733, 0.03241436475946102, 0.06580978937563486, 0.042855202555074356, 0.008226291392929852, 0.059237307286821306, 0.06417131284251809, 0.09675125445937738, 0.021569659475062508, 0.05376460270781536, 0.027787747494585346, 0.009335035902040545, 0.024089939179248177, 0.03499029255181085, 0.024585628889326472, 0.05999184140819125, 0.08491176515235566, 0.0397244340274483, 0.05100614740513265, 0.04049477218359243, 0.05263016319076996, 0.08507573526003398, 0.03224777858122252, 0.038233366576605476, 0.048241057302220725, 0.004930071245325962, 0.042291994104743935, 0.07152987775043584, 0.017351752212562133, 0.009030902856466128, 0.030344795050041284, 0.03798680656473152, 0.03527207489241846, 0.0733076108735986, 0.03977490006946027, 0.0271923650871031, 0.05313862711773254, 0.06647374437307008, 0.004788230589838349, 0.04918111349979881, 0.023938811937114224, 0.05951954975898843, 0.014532142085954547, 0.010582425657048589, 0.022662342053081375, 0.02451598018524237, 0.03753925069759134, 0.028801649241358973, 0.07318968360777944, 0.04263327442458831, 0.04559934182907455, 0.01603866105142515, 0.06308092721155845, 0.06476739843492396, 0.10539737137150951, 0.0910717541410122, 0.024907229308155365, 0.028427758952602744, 0.018205335218226537, 0.06509202867164277, 0.02521941929444438, 0.038043109598220326, 0.045538344711530954, 0.033559350194991566, 0.015412648353958502, 0.05056789064838085, 0.12035712410579436, 0.04832343569432851, 0.028293738214415498, 0.08300156609038822, 0.020541139274428133, 0.06984769614064135, 0.018537409196142107, 0.042846374708460644, 0.0458575869561173, 0.013982037180539919, 0.049506177892908454, 0.02903159627749119, 0.026844370186154265, 0.06692179376841523, 0.03727394403540529, 0.06988002409343608, 0.015140423020056915, 0.03476835699984804, 0.04897271101071965, 0.06971943817916326, 0.10416750650620088, 0.04370170732727274, 0.08322852969286032, 0.04201913237920962, 0.013727925816056086, 0.03274985261668917, 0.028963882723473944, 0.009511152184131788, 0.029869581194361672, 0.005785406647191849, 0.01223920540724066, 0.060729224496753886, 0.05147350748302415, 0.07333805377129465, 0.010209003849013243, 0.08188789928681217, 0.06864895694889128, 0.01750458453898318, 0.051666443614521995, 0.005892394656257238, 0.012856838329753373, 0.03196165096596815, 0.016325011310982518, 0.06870108540169895, 0.024965868251456413, 0.03959518529882189, 0.05707288553821854, 0.03189178889442701, 0.019587997157941572, 0.03212539842934348, 0.017547001989441924, 0.07623012905241922, 0.0085734421008965, 0.07971625644131564, 0.06189143146912102, 0.03962604379921686, 0.021308826107997447, 0.07332820547162555, 0.05778648650448304, 0.0041512549796607345, 0.03334671746415552, 0.015260337386280298, 0.026007435408246238, 0.062074949746602215, 0.04711632507678587, 0.04091448638064321, 0.013672293498530053, 0.04431839864992071, 0.010401778563391417, 0.030244152403611224, 0.04040326537506189, 0.043091532061225735, 0.01754687025822932, 0.03722133689734619, 0.034840697844629176, 0.023871608609624673, 0.013404660203377716, 0.024802202424325515, 0.04439534081029706, 0.05324235338775907, 0.059389577436377294, 0.033793178663472645, 0.011966696201852756, 0.09756490064319223, 0.023105398649931885, 0.0661144929472357, 0.02658781158970669, 0.057755854359129444, 0.038284259353531525, 0.017551274904690217, 0.033081143628805876, 0.037943268471281044, 0.07555714211775921, 0.03325003417558037, 0.060855538031319156, 0.026272066716046538, 0.050289147402509116, 0.11749051191145554, 0.12756040203385055, 0.08862806964316405, 0.18369029246969149, 0.11715413347701542, 0.09215917118126526, 0.14579246198991314, 0.11119988266727887, 0.10594020786811598, 0.12845105346059427, 0.17823774833232164, 0.10401319173979573, 0.12328115626587532, 0.09507254610070959, 0.12148755602538586, 0.1525720552308485, 0.1843675022246316, 0.16383230569772422, 0.23869158409070224, 0.1810691159334965, 0.1591120832017623, 0.30780120694544166, 0.10668726856238209, 0.12568437145091593, 0.11187224619789049, 0.13000166713027284, 0.08882744761649519, 0.0887601199792698, 0.1447548356372863, 0.16486322303535417, 0.08159368968335912, 0.19031413859920576, 0.10243087352137081, 0.17901059123687446, 0.14911673439200968, 0.14870312064886093, 0.21045209316071123, 0.12246342084836215, 0.16680169792380184, 0.2135783457197249, 0.17162822565296665, 0.19462542288238183, 0.14385845483047888, 0.11908539469004609, 0.13408042170340195, 0.23074668541084975, 0.208227178954985, 0.16243162070168182, 0.111321624572156, 0.11238824663450941, 0.19270266668172553, 0.07201930187875405, 0.11127456498797983, 0.07423476854455657, 0.14424652385059744, 0.25579698965884745, 0.08792656939476728, 0.21029928495408967, 0.08714343290193938, 0.12029139208607376, 0.11244504319620319, 0.2343827934237197, 0.26636520226020366, 0.22917998197954148, 0.09453716818825342, 0.13039466401096433, 0.1985309601877816, 0.2526783070061356, 0.22259667195612565, 0.12026645592413843, 0.11825010747998022, 0.1290673774201423, 0.20544593600789085, 0.09024903149111196, 0.1519862632267177, 0.09441402362426743, 0.1474013045663014, 0.1534687032108195, 0.12646019778912887, 0.28184759023133665, 0.13005652668653056, 0.21912699798122048, 0.17992699518799782, 0.1731010474031791, 0.15566464397124946, 0.1422140040085651, 0.12162333194282837, 0.10306379932444543, 0.09642216391512193, 0.17184180091135204, 0.06364495202433318, 0.14156904799165204, 0.16270231164526194, 0.11423983829445206, 0.28976072499062866, 0.0789454767073039, 0.13711754232645035, 0.07901560224127024, 0.13980977208120748, 0.12687513255514205, 0.18043031974229962, 0.18609946710057557, 0.10293756000464782, 0.12330625570029952, 0.14858235837891698, 0.13797827035887167, 0.16606403281912208, 0.13640893972478807, 0.1757768014795147, 0.10522669967031106, 0.17288794711930677, 0.1253678899956867, 0.07738082160358317, 0.12790955282980576, 0.17154005850898102, 0.18145043140975758, 0.1675861034891568, 0.1577790078590624, 0.13753353094216436, 0.17895001714350656, 0.20135915139690042, 0.10000891910749488, 0.16987136914394796, 0.1619910669978708, 0.22655179956927896, 0.16190224676392972, 0.1978662481997162, 0.06443845632020384, 0.16657194384606555, 0.08415493779466487, 0.18703261390328407, 0.14794148417422548, 0.17235189385246485, 0.14224035025108606, 0.12477105483412743, 0.13432639912934974, 0.28759463340975344, 0.1469884329708293, 0.07714058097917587, 0.09588563567376696, 0.12268133767065592, 0.1194418482191395, 0.16537730873096734, 0.10689817951060832, 0.16091389901703224, 0.08088247472187504, 0.18961398163810372, 0.17324076412478462, 0.10841343726497144, 0.09057253366336226, 0.16329784062691033, 0.16728023474570364, 0.08554604166420177, 0.14989934395998716, 0.1907652011141181, 0.16314480977598578, 0.11340960511006415, 0.10568224475719035, 0.16489661968080327, 0.12235287053044885, 0.12863791140262038, 0.13244354078778997, 0.23756095179123804, 0.11301588092464954, 0.10279435518896207, 0.125654210569337, 0.1878550322726369, 0.16255358525086194, 0.20865198428509757, 0.14872678031679243, 0.1325082263792865, 0.1763590460177511, 0.05024112673709169, 0.15703021053923294, 0.07497929109376855, 0.11891585847479291], [0.02731091204623226, 0.020588326879078522, 0.027432694769231603, 0.03151369804982096, 0.01108978192860377, 0.0032791087733130553, 0.03424497219384648, 0.07678337788092904, 0.016274216868623625, 0.057243026603828184, 0.06685864442260936, 0.027092267919215374, 0.05984068076941185, 0.02404953851510072, 0.013212979229138, 0.011142180337628815, 0.017822665322455578, 0.06149887245555874, 0.02605539670184953, 0.062023136706557125, 0.027155589814356063, 0.05340386327588931, 0.04496989298786502, 0.03237341676140204, 0.029994833457749337, 0.02043886575847864, 0.06337888466077857, 0.0357006725971587, 0.005800824301331886, 0.09348818697617389, 0.07485040972824208, 0.022145966831885744, 0.10862086754059419, 0.04090045978955459, 0.06369692462612875, 0.06377019686624408, 0.06483442921307869, 0.060031817192793824, 0.03290558488515671, 0.05559245677432045, 0.11420293129049242, 0.09222173423040658, 0.032239214197034016, 0.06582422414794564, 0.04594488207658287, 0.06687863788101822, 0.051450192913762294, 0.05731703728088178, 0.021031583855801728, 0.030862316889397334, 0.015483974311791826, 0.0769521645270288, 0.02489642363798339, 0.0685775326564908, 0.027973460673820227, 0.019325516223034356, 0.02883615168684628, 0.02770686081930762, 0.037084792857058346, 0.031151080984272994, 0.027616346633294597, 0.06701224672724493, 0.060312976129353046, 0.0602329800312873, 0.06865122049930505, 0.055841918583610095, 0.1054732188640628, 0.06403384482837282, 0.005672757442880538, 0.050129370429203846, 0.018855284033634234, 0.05806923363707028, 0.035439970961306244, 0.02293324450874934, 0.00706818803337228, 0.022686029551550746, 0.0631323506240733, 0.050491349247749895, 0.013601430455310037, 0.05960708607744891, 0.0355258077615872, 0.04522706942225341, 0.07378634065389633, 0.007266196280397708, 0.04689080124080647, 0.02995792088768212, 0.04080215861904435, 0.014433985634241253, 0.03784552391152829, 0.032707973223295994, 0.0530798972613411, 0.07168331678258255, 0.07358022397966124, 0.032636088799335994, 0.09492281038546935, 0.028303202452661935, 0.054932557613938116, 0.027471739158499986, 0.0356176782224793, 0.033547197526786476, 0.037356641551014036, 0.015827892966626678, 0.0322329319169512, 0.014147838537610369, 0.00298924374874332, 0.07999400520930067, 0.052760116959689185, 0.03857251322187949, 0.048444201675010845, 0.010244331006106222, 0.022882036319060717, 0.05588546038779896, 0.057817675260594115, 0.05306650149577763, 0.02562879722972866, 0.00033499171991024923, 0.015768307785037905, 0.05467512884933967, 0.0362578214117093, 0.0475837890553521, 0.11120571594801731, 0.045274474105099216, 0.043232948301010765, 0.06594898659386672, 0.08979396137874573, 0.020017804563394748, 0.05120943649671972, 0.03262484897277318, 0.02572209261415992, 0.00716076585376868, 0.06379446509527043, 0.03084349231357919, 0.022689012985210866, 0.0826998904813081, 0.040963505234685726, 0.04873191377555486, 0.05642405551043339, 0.020497831246757414, 0.01314845598244574, 0.04207648555166088, 0.04596397753630299, 0.016923963448789436, 0.0427903017407516, 0.013114134435454616, 0.040770045889075845, 0.030907521104381885, 0.027913393096241634, 0.042723630904220045, 0.019519882844178937, 0.016730157149140723, 0.01570458884089021, 0.018843869802367408, 0.04294297636079136, 0.049431610605097376, 0.016808962100185454, 0.09164639908703975, 0.02385799391049659, 0.04945583059452474, 0.016265700724034104, 0.007762940304019139, 0.021167508202779572, 0.05731092198402621, 0.011824292905657785, 0.058764529530890286, 0.08895188351743855, 0.04381710386951454, 0.062090282517601736, 0.042579999353620224, 0.047542495958623476, 0.06304804264800623, 0.04064658591232728, 0.07959426962770522, 0.018911139923147857, 0.019368731482245494, 0.020758777791343164, 0.053140697709750384, 0.06733717382303439, 0.04148019586864393, 0.03687654992972966, 0.02537092317652423, 0.012820287556678522, 0.011010477883246494, 0.03213985175534617, 0.004491286636039149, 0.03577089089958463, 0.0564323749858886, 0.019727036669792142, 0.03148513278574683, 0.017917545192176476, 0.030063866179261822, 0.021036988546256907, 0.060451761455624364, 0.05104168885736726, 0.013214116570452461, 0.07551597518613562, 0.053332127281464636, 0.05960467780823819, 0.04880899694398977, 0.03995481521997135, 0.03988127580669243, 0.049823642693809234, 0.01262649424461415, 0.052866934274788946, 0.017535942133690696, 0.05032460350776091, 0.03314285691885743, 0.06565994233824313, 0.043612371300696395, 0.0757734410581179, 0.03791533032199368, 0.01662247708736686, 0.01658748667978216, 0.013222340494394302, 0.031070880795596167, 0.042882892084890045, 0.030943005040171556, 0.03653782630863134, 0.06511522820801474, 0.01923979816638166, 0.04736989096272737, 0.05767768765508663, 0.06464280668296851, 0.020366975768411066, 0.04588885734847281, 0.01649110396101605, 0.07204592271591537, 0.03162435597914737, 0.07271474620210938, 0.02439459080051165, 0.05018962539907079, 0.01311509644438047, 0.017848679453891236, 0.027654407676891424, 0.030620963043475058, 0.08405232103541493, 0.00333079680785886, 0.037204048567218706, 0.06895469952723943, 0.07187025636085309, 0.0381867522810353, 0.043672273750416934, 0.04909966650302522, 0.013080906628601952, 0.01452429109122022, 0.028319396114966366, 0.015334311883634655, 0.011032629136025207, 0.01701919398328755, 0.008807212125248043, 0.04689964393037371, 0.02843047335773008, 0.008089138791547157, 0.013529774241760606, 0.04770743827975821, 0.04063532382133417, 0.04976497591997031, 0.026404918571643066, 0.018316110035812017, 0.07268471148563549, 0.03070097583986353, 0.06756470145774074, 0.008460585559078027, 0.043979960755677894, 0.0041437156869506, 0.024439600201731082, 0.05944683784036897, 0.04388808287330903, 0.023829022320569493, 0.02492475883627776, 0.01851546017860528, 0.06458879317506216, 0.029456551892508287, 0.040337707760045305, 0.029560439579654485, 0.048706573143135756, 0.026439619541633874, 0.058785127839655615, 0.07737735577393323, 0.015120199495868292, 0.018592190826893784, 0.05962571769487113, 0.016874716384336352, 0.05304680860717781, 0.022531701797561254, 0.037773587537230924, 0.026046336934086867, 0.008042922472668579, 0.024630146617710125, 0.050255969690624624, 0.04901736603642348, 0.034567413094919175, 0.011295161093585193, 0.03925327044271398, 0.015160600160015747, 0.05393322237068787, 0.023825007301638834, 0.033534699759911746, 0.020544768376566935, 0.06672266812529415, 0.09204210480675101, 0.0175580729774083, 0.04313443561841268, 0.03228038112865761, 0.05504194647073746, 0.027246792342339177, 0.05985620278806891, 0.024054462664935272, 0.028777920924767386, 0.03171885364281479, 0.057562728979974054, 0.00876650996360695, 0.03592962144466583, 0.03546003492374439, 0.018194420081272256, 0.0795190678036306, 0.055598460749024525, 0.08823867217870429, 0.04501711584453005, 0.027308071475999895, 0.056912125219241716, 0.01661733585933689, 0.011119276732642902, 0.05192567579797469, 0.027440993835625704, 0.03460565967543516, 0.041587094819988124, 0.06888576885103248, 0.02871161745133577, 0.024654156950418837, 0.05917220238188747, 0.01877420254459139, 0.08590044686570764, 0.016463763240608387, 0.09849962079897523, 0.027748428510676604, 0.021516744345717598, 0.033126117778010666, 0.0599980272090761, 0.02141324814147083, 0.09433171202545054, 0.05064041703008115, 0.029187274740252178, 0.006706258845952107, 0.0028234157207407407, 0.024750942284299526, 0.01904263364849612, 0.03240987105527893, 0.046853664171067066, 0.05189531824726146, 0.026781436063174624, 0.009303784063376952, 0.08613209342001937, 0.11482224610517733, 0.13592160103144124, 0.15210993471555412, 0.11149990328704007, 0.09633980036596768, 0.12932558543980122, 0.12899059482151642, 0.15069562388816848, 0.10887372467550449, 0.18008691316936165, 0.1236342775519006, 0.12917846208438277, 0.07525076871388592, 0.10276676955982111, 0.17193292180309072, 0.14735245640622452, 0.13373268098803237, 0.2508326747920364, 0.21617808903101832, 0.13461755850585178, 0.18331892177229747, 0.11909584412933327, 0.1491455445648171, 0.17493737308541313, 0.103571643558098, 0.13222629931988195, 0.16797886288259178, 0.10383655317127705, 0.06377681682351977, 0.2457748047891073, 0.19040049490286037, 0.2767695486545563, 0.19191397150279954, 0.1157378930656705, 0.14681083703180775, 0.1619811964337714, 0.15230875607812777, 0.14728180394740775, 0.13959428208181635, 0.08984782645711675, 0.2330686428467743, 0.21488933474756777, 0.08550784332328476, 0.19906487606931478, 0.27363744797185063, 0.24031712498981506, 0.1271610672120005, 0.19813247141428292, 0.12421391715179197, 0.16819108743220568, 0.140137875569053, 0.22906874888576567, 0.1523225600249134, 0.13910637935623527, 0.12467855354771018, 0.07928131337394007, 0.2441316601471044, 0.1503191323718056, 0.20040059345774353, 0.15449236234417185, 0.11193529164302163, 0.22987825388554484, 0.204986977041699, 0.13211925193900242, 0.13488553318893537, 0.16298506991006434, 0.19114236056338996, 0.22320468386169523, 0.09718843139125966, 0.13736774999415502, 0.10422574283438735, 0.14400988264242187, 0.07860417041229084, 0.10450058980495669, 0.05877495670574717, 0.06667473280685954, 0.11997968264040537, 0.1125562540255487, 0.11309439272736199, 0.11756868232623674, 0.14418134844163433, 0.1527925769914873, 0.16559544077608734, 0.08437149648671038, 0.19052156887482852, 0.2061866142321378, 0.1669863739516586, 0.13594962452771142, 0.191862570354715, 0.17103360209148377, 0.21493303240276873, 0.239287959120702, 0.16032040352001786, 0.07124523443053477, 0.15515627281274647, 0.10022968577686697, 0.16488677880261093, 0.07801797764841467, 0.13337337761186063, 0.14253214787459, 0.08698340359842405, 0.12982487271074206, 0.102747451455798, 0.15409299783641472, 0.1280188118107617, 0.1279488272848539, 0.16635146661428735, 0.11995666864095256, 0.10813142114784569, 0.11795711499871686, 0.09269293863326311, 0.08966573310317472, 0.10092617652844638, 0.15688362153014168, 0.16472610383061692, 0.07210781041067094, 0.14477816876024008, 0.13123302371241152, 0.13758696557488292, 0.11408573132939637, 0.17373291193507612, 0.18889300001319498, 0.2187856991076842, 0.2226222908939235, 0.25986297929193825, 0.17151696287328377, 0.09806761663639918, 0.08244719661888666, 0.09766433358890936, 0.13663905003340915, 0.19067189830821007, 0.12394287739880383, 0.11671195446979254, 0.19216094340663403, 0.11519291176227853, 0.11292481940472499, 0.13376558781601489, 0.14764020190341398, 0.15770718280691653, 0.20996525912778452, 0.14276930858613923, 0.12270360210095532, 0.21361362742027268, 0.17451632302254438, 0.09503448134637438, 0.12008929043076932, 0.18226903514005244, 0.19554068392608315, 0.06492399901617318, 0.14607054472435266, 0.13964678160846233, 0.10649980205926113, 0.13065441569779068, 0.18290879612322897, 0.1417420426150784, 0.12782992038410157, 0.08792431326583028, 0.25554103776812553, 0.10618552478263155, 0.06744515630998649, 0.16890366794541478, 0.1628010766580701, 0.1517743058502674, 0.1265726628480479, 0.18776659795548767, 0.139512779423967, 0.14979574014432728, 0.2124326626653783, 0.08269192723673768, 0.1816667674575001, 0.10040345223387703, 0.14271397405536845, 0.07335329006309621, 0.07769355521304533, 0.13860206032404676, 0.19085422914940864], [0.06835036867414601, 0.047117913272813894, 0.01454835986805847, 0.061528866353910416, 0.015290353549062274, 0.025115746830124408, 0.07250102993566543, 0.028919739779666997, 0.01983233629289316, 0.06550970196258277, 0.025318577645521145, 0.0717486183566507, 0.028364795143716037, 0.03307867227704264, 0.08129350579110906, 0.045310186251299456, 0.03254003633628599, 0.03543575556250289, 0.041720213848748244, 0.03133427271677647, 0.026513513330428395, 0.012922739188070409, 0.020253469847375527, 0.043338203395251185, 0.05731470693717711, 0.02506137709133327, 0.057508815662004054, 0.07134282685001381, 0.0818233769678045, 0.03412818412471097, 0.11706264151143841, 0.05637694397591986, 0.02881226009776583, 0.05626352154649794, 0.024067572703643236, 0.022098938788985834, 0.051557756087277085, 0.02831298581440933, 0.029042734058748465, 0.024414953477389645, 0.011177564083482139, 0.04647869034670293, 0.03207478024705779, 0.03318226496048737, 0.020696858555311337, 0.06864043709356338, 0.012890242396679241, 0.0777803196979221, 0.03820528741925955, 0.06317625608062372, 0.00800922618509503, 0.06573164122528397, 0.039703557413304225, 0.044322536123218015, 0.053288804410840385, 0.07425177856930532, 0.0329023120139027, 0.018209289009973872, 0.026636036345735192, 0.05505682282091584, 0.02955188261694275, 0.08925698784878477, 0.03120584035059437, 0.02135657960025128, 0.021609325413010083, 0.015871175019128714, 0.02071819344564574, 0.041448112824582495, 0.10710252245189622, 0.03632059226220008, 0.008225841465900885, 0.048255128422169946, 0.026766279552248307, 0.06802250267355703, 0.029327368101803586, 0.07817117177182809, 0.07690834812819958, 0.0885471235960722, 0.07555901232990436, 0.053967309213476256, 0.026257244171574712, 0.03706215735292062, 0.043936674992437474, 0.0989905143796932, 0.01374812243739143, 0.019261103370808996, 0.06767550410586409, 0.0800661271205172, 0.06105503474827856, 0.029132405907148495, 0.043756678205681965, 0.03702645633893553, 0.027309331271681003, 0.04042362248583231, 0.01900756160466699, 0.061619282205356285, 0.044417887256713584, 0.08553234161809087, 0.06378824589774013, 0.027572910585149657, 0.05733701960707549, 0.06882124653202482, 0.02992690097016748, 0.024642495955049526, 0.049263959444942884, 0.08483265221002512, 0.061641580032301135, 0.010462524278409546, 0.011457152450020658, 0.05860585093614645, 0.009868961060419679, 0.02143097619409673, 0.04223045893013477, 0.056449318217346445, 0.029554470856965054, 0.020147890063526575, 0.018074450053973123, 0.054940086702117696, 0.06455655427998863, 0.009981697930925293, 0.019165253143000882, 0.05535418284125626, 0.044838944741059095, 0.04424071063112933, 0.07068193692248315, 0.03895414040016476, 0.10082933367812075, 0.04699108023487497, 0.04632759650121443, 0.06091146628023125, 0.006851536109024892, 0.03418365595280193, 0.04255067338817753, 0.02743497687333729, 0.009262223793484736, 0.07471755787264556, 0.048349744829465635, 0.08974449723609723, 0.04732368113764096, 0.022580581498914398, 0.05557931333896704, 0.028198099498695228, 0.04906272981315851, 0.026411549661133904, 0.0588495351257734, 0.053687163308495656, 0.0024354169727303088, 0.044392895433702506, 0.024246022112492938, 0.028608388420252595, 0.04417215473949909, 0.037721570406574756, 0.02218652891315287, 0.02333003005333012, 0.02686545645701699, 0.01666333231696626, 0.07777858307235874, 0.036275992897571996, 0.03681862901430577, 0.041859474149532616, 0.0036617503747038427, 0.07012321104411967, 0.05479335297422949, 0.023344303408521228, 0.018894918430305552, 0.08377560385270044, 0.045868663510191254, 0.05919425530009903, 0.04800067938049324, 0.04237330751493573, 0.03299797484942246, 0.05257326272840146, 0.03159678519295994, 0.003948413495891145, 0.06383759871823713, 0.0741891487268731, 0.02318363400263479, 0.04721052588138264, 0.010651486209098948, 0.03166671776853036, 0.01644043568376219, 0.011458625613158802, 0.052632838633144274, 0.057517721434123814, 0.0413455517264083, 0.027410400653025135, 0.05433732920209877, 0.05290887303999625, 0.036969103166484274, 0.01285645148527692, 0.06499195747892372, 0.01743034565151902, 0.049670671214698814, 0.0539271738671232, 0.051554817182477564, 0.004181590265943669, 0.009696624165371759, 0.04547877251752652, 0.04141389981668908, 0.053077500124345534, 0.035767755325650796, 0.034432987886248156, 0.043935138746746816, 0.058812427741941065, 0.052536329749273136, 0.05488017312018201, 0.054482868072227575, 0.061178212708909996, 0.03836251882603392, 0.040148152111214586, 0.04223666699544992, 0.045292708673514426, 0.05668467179930303, 0.039741748332744464, 0.0811453434289433, 0.03614112240029499, 0.032537216175114736, 0.016835308342706412, 0.0496786864096066, 0.04264645496732555, 0.02677899996342603, 0.015210979927360313, 0.02633896205225028, 0.024026626560953446, 0.03222392224415671, 0.05079833121271804, 0.033391090473742224, 0.02708224335947307, 0.011787950861616991, 0.06788961371057667, 0.025668717353255488, 0.02102457612636499, 0.06957060788408853, 0.05789693663245998, 0.02380898433330003, 0.008818624501145678, 0.0869556175894104, 0.0397391062870156, 0.04001979767053854, 0.07694428291870281, 0.024274902789329644, 0.018710585645749234, 0.02365139855101006, 0.047555439014104195, 0.04018387910036836, 0.05369238060666248, 0.016242002093349583, 0.027952942145930137, 0.06554046398377977, 0.026512643162277527, 0.03956544001994189, 0.027862696988449898, 0.049719868184183724, 0.01936877230036771, 0.007720965359112597, 0.02156562404707074, 0.06523508505779319, 0.04593783538439311, 0.04597930659656413, 0.05923727760091424, 0.05394857369537931, 0.0530873113166308, 0.09005815110867843, 0.047111523381317966, 0.08595302060712129, 0.04897711565718055, 0.09484010544838384, 0.014314890413515968, 0.061918271239846945, 0.06263443632633425, 0.012289314290683251, 0.013351437082746997, 0.01635986627661623, 0.02923594664025586, 0.057367366025573574, 0.020076261680515017, 0.02291288554260973, 0.11022798833437264, 0.021306519884092268, 0.05123870309034828, 0.06702877435600385, 0.009586324322299333, 0.018671296347747557, 0.057671531540108845, 0.04394135423353873, 0.0412235834664898, 0.08565119656850584, 0.012203431106172502, 0.017145882302429527, 0.016187598957912996, 0.03532104179612361, 0.01877631395473145, 0.03591112712456379, 0.04846157164138276, 0.026122648268938065, 0.030897559627192095, 0.06953941541723907, 0.032750412938185036, 0.05626141755783465, 0.01780179427441908, 0.028892458431073464, 0.031215940980473533, 0.0681647055898793, 0.0426050579699222, 0.04665507658501156, 0.06778005787055008, 0.08330842189025134, 0.038561273395316675, 0.04333252596552484, 0.055592987409909256, 0.017197556189785246, 0.09793728808290325, 0.04194934452243615, 0.0332587915181648, 0.0669946132984478, 0.04823581031814683, 0.01129720663811895, 0.0030995152974355733, 0.06545589625602588, 0.012372331857477548, 0.0956162360671442, 0.016200573554669973, 0.016322126211889554, 0.02412292578810593, 0.0020203456051604007, 0.040244571937364526, 0.04945929642417468, 0.03374552536115516, 0.0752081917016767, 0.04725400831375737, 0.037632906023645774, 0.05484300265379716, 0.05225030232395511, 0.05166698538232595, 0.08197414426831529, 0.041330233798362315, 0.059958845522487536, 0.04721579512988683, 0.036047370595042594, 0.02409022861684207, 0.0029094772526150336, 0.0819140748353675, 0.050364646085654385, 0.020919450907967985, 0.01528611403045943, 0.0286345250060549, 0.03575136870495044, 0.06519719841890037, 0.03333515480335336, 0.020203870262776036, 0.028205211128806695, 0.018825045226549264, 0.08719487857888453, 0.19164832716342062, 0.050951688608620316, 0.10751039197202772, 0.1365563302533701, 0.12549549486720935, 0.14388747280463576, 0.13068815373117104, 0.09037362324306741, 0.1233625179156661, 0.1008048650692217, 0.1636216396582313, 0.1693405257537961, 0.06902690307470039, 0.16124863730510697, 0.10193255846388638, 0.21691722358809784, 0.11723867151886225, 0.08642744593089446, 0.0901992036961019, 0.07931407177238725, 0.17367082386044785, 0.22481054300442338, 0.12982144398847595, 0.20014366193208843, 0.09174812526907772, 0.23603990528499708, 0.12954662670381367, 0.1604897913057357, 0.15636995143722743, 0.10957761463942006, 0.26268462475854903, 0.08348062983714044, 0.12436277713277377, 0.16626010823529214, 0.1289455613004975, 0.1231504492170643, 0.20720654778415337, 0.15260524407494813, 0.1409115199930966, 0.12908840988529846, 0.09845164095168002, 0.25225614372175187, 0.1147500128718093, 0.1286431954940781, 0.21889811963774264, 0.1334038353525102, 0.23341375635936856, 0.1552226801868528, 0.15356864081695676, 0.12634017766686156, 0.19306286063510925, 0.12369898540782742, 0.23826668970286846, 0.09200602900818922, 0.09283569816034287, 0.15373774658655748, 0.10969101480441168, 0.09156275904388167, 0.14400041283806786, 0.13419312424957752, 0.18087773089064285, 0.14625211857492104, 0.13119484763592482, 0.10435828298795968, 0.07882136735133827, 0.08850065773003735, 0.10813174769282341, 0.1785205808118917, 0.11988013837253675, 0.09223541943356395, 0.1192805275786668, 0.13832678290782496, 0.17239168781088665, 0.12490793655160815, 0.19222049333620816, 0.24153721577022225, 0.1065080621629022, 0.11973756438237615, 0.125453875225503, 0.1149164246453438, 0.12234391280799173, 0.12398146907798946, 0.13898631470510736, 0.16347438271623105, 0.1511490167467855, 0.16593193053267896, 0.181950653786771, 0.12270154635189101, 0.20677387568866834, 0.184729581233114, 0.08109799440717325, 0.10366554008214734, 0.15570871270028874, 0.1320542101166211, 0.1748750772094354, 0.17417334689525887, 0.13627446256577969, 0.17422082950361073, 0.09553046606015414, 0.09298138174926862, 0.14033601415576413, 0.1322588202310726, 0.166283025755547, 0.24120647023664787, 0.1950352665153332, 0.14021908136783168, 0.17037438199622557, 0.1295138237765059, 0.27797337155789137, 0.2051507541909814, 0.07857046948629431, 0.26721721747890115, 0.16973882156889886, 0.100134379172232, 0.18257352348882705, 0.14311069651739672, 0.11028269203961827, 0.1585323322797194, 0.12519272830104455, 0.1836541498778388, 0.22263547143666074, 0.15510363969951868, 0.0822338365833275, 0.12826253310777247, 0.12927152740303427, 0.24086577992420644, 0.17003729852149263, 0.21046698064310476, 0.20526256615994498, 0.19156329188263044, 0.12184770544990897, 0.15209488396067172, 0.13470706151565537, 0.1695973236928694, 0.12675358360866085, 0.11899961726157926, 0.1659386692335829, 0.11553581367479637, 0.12915550003526732, 0.14620582340285182, 0.11013448514859192, 0.15260904387105256, 0.14858131937216967, 0.17838387720985338, 0.10813513930770569, 0.1123007845308166, 0.10360445390688255, 0.09114303742535412, 0.16789569781394675, 0.11978810463915579, 0.11922955687623471, 0.17996675946051255, 0.1417182938894257, 0.1478572652558796, 0.12158217985415831, 0.11548116191988811, 0.15039950696518645, 0.21956330660032108, 0.06960722545045428, 0.07430323166772723, 0.14323405630420893, 0.14159906044369563, 0.08703027022420429, 0.09250873015844263, 0.14186929125571623, 0.12669232673943043, 0.17932155111338943, 0.2163742238190025, 0.12280506853130646, 0.07641968099051155, 0.21303490066202357, 0.13808687624987215, 0.09731994738103822, 0.12034610321279615, 0.13935808616224676], [0.0862104567931965, 0.007716172476648353, 0.037483986670849845, 0.059947127010673285, 0.04999868935556151, 0.03191875483025797, 0.03814325129496865, 0.06850279096397571, 0.036562369132298045, 0.042328544877818786, 0.02658820307260612, 0.062037745883571915, 0.05353358697902877, 0.06812960200477391, 0.02835980605595978, 0.021004003792768344, 0.04038707171275746, 0.02316659243660979, 0.028800604668504093, 0.038910298026166856, 0.026560205551504623, 0.05622210599540267, 0.038478772548842244, 0.009433237810299033, 0.023768665305397008, 0.030664903752040118, 0.07694412706769072, 0.04070465154654812, 0.055819906483520754, 0.04672684968682006, 0.026092687767231837, 0.013344328235689318, 0.07065717145451345, 0.028815447622037027, 0.020309780302341096, 0.04229735983244609, 0.03049358267162461, 0.07753576719551347, 0.025367386842845008, 0.007828522502677515, 0.046813807130092755, 0.058847371765295975, 0.0231342774713994, 0.06589126234757714, 0.07201335727586411, 0.01433556572010275, 0.04064143911818974, 0.09793466088012792, 0.03802916835411452, 0.041774988058023155, 0.07257197925355285, 0.026693280051404145, 0.033169333037221804, 0.029300057067302987, 0.0408293026703177, 0.00796536525740521, 0.03078160461882362, 0.13878963072784245, 0.004380083692012704, 0.08057271712459624, 0.050143816333729774, 0.034818548447219655, 0.026421268084959593, 0.04830068886803929, 0.0843199469090905, 0.09321208577603102, 0.04816513930563815, 0.03171023359755054, 0.018048964702757075, 0.035098130319966, 0.03456107515376061, 0.02221610164269805, 0.031447787914657965, 0.08644150962936692, 0.027092329146398697, 0.06637462312937714, 0.057183573153452016, 0.10110212489962578, 0.03861169490846805, 0.03217621699150186, 0.029950887183076702, 0.06144200910057407, 0.028537893667817116, 0.13399112649494782, 0.0566289736161707, 0.03946362849092111, 0.02716242684982717, 0.01963644641364226, 0.020147962422925048, 0.07029033527942374, 0.0331051075772848, 0.06849448633147404, 0.03143522706523072, 0.011251023715885822, 0.02972786624013679, 0.019272213321528398, 0.026378167858638335, 0.058607242463040166, 0.0872788748529274, 0.024161625078704674, 0.017969666223507375, 0.007752256624371512, 0.02935892051027622, 0.02799034453346394, 0.07279860888957046, 0.047570437818649225, 0.04805605472938623, 0.028176935302326456, 0.03414358368900139, 0.049066381179727614, 0.040439957156195305, 0.015289169823518023, 0.04330872528953478, 0.051289670082041994, 0.04291231824026909, 0.030145452328724787, 0.02608432561828522, 0.03495794233458582, 0.017728332786646206, 0.02071763312414987, 0.06687664150376804, 0.061984600688447244, 0.04757448252348695, 0.03750883006432559, 0.03499662307149265, 0.035026683763135225, 0.04168304709310178, 0.03554264338163193, 0.03614088120230008, 0.020546939158521127, 0.07884564300184138, 0.059172295150347054, 0.059201524636591785, 0.07239732221933082, 0.09051346612977795, 0.019531382422428578, 0.012827437221858418, 0.020947073644492775, 0.049572013813303784, 0.02393008428043686, 0.0741766435385216, 0.12287491947063245, 0.027822107076644897, 0.007708183720751549, 0.06468778825365007, 0.01956870317371795, 0.040552062273491174, 0.030270355782704428, 0.010279270391038153, 0.01686284758761758, 0.010269929534842959, 0.009221879718097625, 0.050136747377109714, 0.04004143127531279, 0.02556372757680947, 0.0594315829948755, 0.032251812153845094, 0.02592932065454079, 0.004036559303131071, 0.12851113773649558, 0.03526007436448708, 0.011691376112139551, 0.018225369494757615, 0.012971339656360215, 0.055477895148214884, 0.016957760853983928, 0.05953962114290334, 0.05541569204069674, 0.0434082027641125, 0.027075044527009595, 0.04391518981719855, 0.02926375120296143, 0.008306344079755945, 0.01171806095953798, 0.03578555944841355, 0.03403966074984055, 0.0005276764488826302, 0.03882342964061536, 0.017959823489945848, 0.05222906205744948, 0.039910854102345183, 0.0030238579802244203, 0.04039169900352135, 0.021269011740514543, 0.04813526044017635, 0.04061492960317992, 0.02655380823853193, 0.01599869083293015, 0.016941557914833538, 0.02284468588186428, 0.04140354685659986, 0.04602597655321006, 0.057275250655948184, 0.04642000130843371, 0.016034462350944523, 0.08075236139120534, 0.06186364174936898, 0.07893752830568701, 0.04277240113879088, 0.001385992211453413, 0.025164732287521474, 0.02225616462965263, 0.022058773756725714, 0.008353533539775526, 0.015765003372507636, 0.04179272167675663, 0.04304913687519729, 0.034996548856724985, 0.10544178890995681, 0.014129110440990189, 0.027793885055871215, 0.06557083266670816, 0.038882730950717814, 0.08557336012017913, 0.08077052916632965, 0.040830178404576145, 0.08559188412618823, 0.045526837711804546, 0.027557540706766304, 0.04154816546360962, 0.022089758422225714, 0.03969688179495279, 0.04204402772302274, 0.0545086911006365, 0.029337383384699933, 0.008972326068032999, 0.023468791259801947, 0.02389436100202147, 0.053774172702105716, 0.05976590939098969, 0.14291843574028462, 0.016823237310745753, 0.014026687567820773, 0.0651140630361624, 0.03933559317374602, 0.0363148554606596, 0.057500358889228664, 0.018652265825949144, 0.057375136311748065, 0.069993001234252, 0.054906738296267577, 0.040240300877485424, 0.020915575041726697, 0.08112705691019073, 0.026059669617097825, 0.016684279435139615, 0.03578335898055229, 0.004094765945410472, 0.02550021086790366, 0.011490694741951302, 0.017491114558652043, 0.04064386594109237, 0.016951465586316772, 0.03154150632326491, 0.0342230120440945, 0.06633099226746708, 0.057974732262664475, 0.0207462874459452, 0.06917516933754086, 0.06796686386223882, 0.06859624962089583, 0.023564517177874222, 0.019661638616526034, 0.09505708716460504, 0.039446384689654224, 0.03725313421455212, 0.0675562335527502, 0.14553597575286403, 0.027732090129575226, 0.019887989947164897, 0.005956758805041318, 0.04822353890631348, 0.041909053325071, 0.07449551470926963, 0.02279160005855374, 0.03036096088180784, 0.016387229261454195, 0.047214277437888086, 0.03585013371775858, 0.028185896735521965, 0.09809736933675595, 0.07476766768377274, 0.05257202705251984, 0.07184269299614243, 0.03890104344463907, 0.021126786559761968, 0.018436133868817706, 0.013592214836535277, 0.08767205727053806, 0.04079020633071195, 0.026369137776782736, 0.038888723793206736, 0.05065879631729331, 0.009656146503402852, 0.09022183177876286, 0.054848405488883145, 0.048930842749541625, 0.07286335385288112, 0.06194178247824311, 0.059876504237763584, 0.03591806620534044, 0.0591110011737328, 0.06847133874543943, 0.0790085963672027, 0.08097801139228977, 0.0659772549988702, 0.03729495423613116, 0.019678715434565675, 0.027180232827959117, 0.00886300493220915, 0.07296532494365238, 0.020751950032718014, 0.06386928100255318, 0.03808384237345308, 0.0362672726623714, 0.016401228022004943, 0.0482897978508845, 0.04000440923846327, 0.020211835362715647, 0.020503477135207504, 0.05562805017689243, 0.03288344661996234, 0.06886493676574901, 0.013388423867581878, 0.010413407089799875, 0.10876186075620353, 0.023889147414593026, 0.017443839751649648, 0.009430959416931728, 0.021227573924988974, 0.032111624168464914, 0.03127142023004126, 0.06734845446771942, 0.06526972108986229, 0.04072815165272914, 0.03615764631831553, 0.03462810222117696, 0.03208859161532018, 0.037046542565803975, 0.0439432652638061, 0.016028360041673295, 0.028995878565183375, 0.04931546820444055, 0.045118552588974126, 0.035843435834976844, 0.03227180932299234, 0.04086307038960513, 0.03734731275471859, 0.05188872426515445, 0.056934846070362255, 0.08950933290179819, 0.01404611977704917, 0.09711653212434612, 0.17005145869916305, 0.20229885878507048, 0.19158365641487762, 0.18071773869451135, 0.07562299288110808, 0.13840510917361826, 0.13717933354200795, 0.1513715274631977, 0.18184838583692908, 0.09754096638062038, 0.12193096699775197, 0.1012354220438283, 0.20862206089077517, 0.1432751861284487, 0.08342299464857206, 0.17387454339768738, 0.09998442081268877, 0.07104962656740099, 0.19703191093867645, 0.1414147109608166, 0.14176225871779025, 0.09605787330656312, 0.08082827567704953, 0.12113337346818298, 0.14586801262339577, 0.08645106106996536, 0.09600644247257151, 0.13616317010018975, 0.15802514855749905, 0.18899454065831378, 0.09601502169971354, 0.18801198166329414, 0.08811908992356621, 0.10506246238946915, 0.2284153620712459, 0.19011638592928648, 0.14403118228074163, 0.22599509975407273, 0.10052934274426661, 0.15662069345125929, 0.13568261463660747, 0.1326192813576199, 0.14447759895119816, 0.14655399456387386, 0.1477558581973426, 0.1391390635399148, 0.19658455916214734, 0.1525230734841898, 0.07965910364873707, 0.1743542676558718, 0.15686337574152276, 0.14196658681612462, 0.14959587977500632, 0.22830776550108567, 0.14588539372198284, 0.07144381088437513, 0.22960204136325046, 0.10826608384377323, 0.1822845608694479, 0.14402727858396247, 0.07122987939510494, 0.04227493212965783, 0.1394157955655828, 0.21097303630085662, 0.18524874321883544, 0.10298876819433644, 0.13222116365795955, 0.08311795711051673, 0.11888814668054692, 0.11419164322433062, 0.13336185947991908, 0.20679452223703265, 0.14523024059599265, 0.09874260736978613, 0.1355601305840537, 0.1852735606371425, 0.1456721598515287, 0.1324461679905653, 0.17407680832548067, 0.1545218107639812, 0.2150192848057486, 0.14261716831242666, 0.257022661389783, 0.1358076962060295, 0.12233602377818897, 0.10541069292230532, 0.22074461274314672, 0.09788928597117774, 0.14458724384894595, 0.2670800982741639, 0.2601263823453337, 0.11861914041219279, 0.07384390162769705, 0.19269574986537918, 0.11924234408070333, 0.2623834612313658, 0.2610082319006324, 0.12716238823486492, 0.10078987368615344, 0.18359972076723352, 0.09987855344661511, 0.12490820372477174, 0.09334568720078096, 0.27710223861504346, 0.20028409111546353, 0.1743190601700917, 0.1760414958698675, 0.09344414793304168, 0.1045647484716028, 0.05808084082673304, 0.09229636460077018, 0.17527917661936954, 0.11672318316414021, 0.11798049265053123, 0.1695350426598452, 0.13651255838340148, 0.14412371325306594, 0.1798026854521595, 0.1535220636287704, 0.11955209425650537, 0.1833690909552388, 0.22170072159497067, 0.10738672048319131, 0.15733236854430288, 0.20913032814860344, 0.15166782250162214, 0.14647274423623458, 0.1533058166387491, 0.16708049312001094, 0.13271724485093728, 0.17057042772648856, 0.12759406585246325, 0.14482660131761804, 0.18349917460000142, 0.06296547129750252, 0.1567863259697333, 0.10121576255187392, 0.19630543742096052, 0.10225160032860003, 0.2109417473548092, 0.36926299799233675, 0.09770540404133499, 0.09913406800478697, 0.13439978269161656, 0.06386291337548755, 0.13502459682058543, 0.10670862015103921, 0.1727928631589748, 0.17856715800007805, 0.10827746838913299, 0.14901991380611435, 0.2095206087687984, 0.17662200378254056, 0.1311336798244156, 0.1287985418457538, 0.18425428017508239, 0.12221058597788215, 0.11803930785390548, 0.17903854051837698, 0.2545995492255315, 0.07593236456159502, 0.13170667720260099, 0.13118822767864913, 0.14108856674283743, 0.1632568592322059, 0.2621327934321016, 0.225843122752849, 0.19682090351125225, 0.0896388450928498, 0.1002098259050399, 0.1681075364467688, 0.12951135984621942, 0.1734364387812093, 0.1752624337677844, 0.060911521941307], [0.11168528435518965, 0.018586261066957377, 0.05842650723934639, 0.024870966117305215, 0.018151280892197974, 0.04777056907187216, 0.028323459373496007, 0.024751471064519137, 0.13603063736809418, 0.013724403397645801, 0.0321933383384021, 0.014101630567893153, 0.011122902124043321, 0.040240163580165245, 0.07415457206661813, 0.019593578108469956, 0.04441447708813939, 0.11302524682832882, 0.04577561303449329, 0.03489654445729684, 0.024577496806159616, 0.021602959641313646, 0.036886709931422956, 0.03717657797096763, 0.022906297126610298, 0.027447534012026154, 0.1029717359051574, 0.02176547142880736, 0.0072924469714052975, 0.037447309732669964, 0.07474518803064711, 0.03806022723438218, 0.040822949886205606, 0.048030547113739885, 0.04608734845533036, 0.014155054068396566, 0.04531357786618173, 0.08146995882270858, 0.03707396492245607, 0.06559145695064217, 0.014420029547181912, 0.045155481857364066, 0.03814535528363194, 0.06697628225083463, 0.058811934213736095, 0.016140120060299523, 0.07663927506655455, 0.02800653819576837, 0.043048465231549926, 0.07123455492546782, 0.05903852674236987, 0.013498027947207447, 0.020021734235342592, 0.06441110817831941, 0.03827789543720428, 0.01408169926435221, 0.06891060111229308, 0.05074211352621205, 0.06550351245095953, 0.051401960736257024, 0.03442857210757211, 0.016319842252414674, 0.027248812839388847, 0.018389809010841418, 0.036689899789053015, 0.025318128646176774, 0.040157666444429196, 0.04960000020219013, 0.08553293533623219, 0.02871498123568017, 0.049802380162873305, 0.05359393100661691, 0.04519992166024167, 0.03590783198887948, 0.02525727995816851, 0.09729990939376876, 0.035671220466610976, 0.029565109543909784, 0.03302098142739851, 0.0558794749667868, 0.09760323257069103, 0.04275140949175693, 0.028198277614137623, 0.035939276785939, 0.09604369828593917, 0.05594518101133872, 0.05008100837585516, 0.038557039442821406, 0.025047209492186084, 0.036466602396103553, 0.09069527746760286, 0.008287602995551424, 0.0841402803780511, 0.06331498574581929, 0.037078492023283616, 0.019211012113373727, 0.02979013057483826, 0.03611512867792044, 0.08206980710383505, 0.07227845984743908, 0.07571353489765897, 0.03383675015356857, 0.005081826066088979, 0.039268350883503444, 0.022989024328126106, 0.03676040010759607, 0.09384609511471353, 0.05492870586749632, 0.01732970486045815, 0.04000518849352375, 0.009771119093784364, 0.08549755715648644, 0.02635172142618103, 0.016913302497414406, 0.025640578824095428, 0.07964894364704378, 0.03518845340295229, 0.08929494870244525, 0.04177106951829046, 0.015243834805005463, 0.07975032844115049, 0.052006996629643254, 0.035524501581676304, 0.04355052071332466, 0.06704979197820649, 0.026325679464207496, 0.04187971251667477, 0.10103544293087907, 0.03597734154027421, 0.03746371490706224, 0.02592812950751977, 0.030571072165912483, 0.016781252161308657, 0.010009818834078033, 0.014112768349150429, 0.015316579192585777, 0.05111867925734259, 0.06605097994906828, 0.02653740120877046, 0.0046242108510341495, 0.035016505207750015, 0.04630454539437778, 0.006734826429237728, 0.024426610762020573, 0.03960455120250117, 0.003780113420361886, 0.02470452836860204, 0.021457610018842388, 0.0876978988526389, 0.021497520865523256, 0.05203853790590074, 0.057875778002198786, 0.016624753625364974, 0.050089030992239714, 0.01894639564852696, 0.01347031151453848, 0.020504983694991097, 0.02358498561079614, 0.06443070087698288, 0.032867820700630546, 0.03621055402618367, 0.046013430546736345, 0.021640998420480173, 0.06325813723378815, 0.021337458165362477, 0.0425289470149437, 0.04049260140163824, 0.05810605900478549, 0.0368330303899711, 0.09252087911590934, 0.0053810011013410985, 0.0133161804296833, 0.04979357086995151, 0.10749657318228856, 0.027472366273286752, 0.027891128665942233, 0.01589672716363566, 0.028000842212350108, 0.05693015569704585, 0.01022661037495709, 0.038273138270596974, 0.022404896590160206, 0.006582805826838012, 0.06603888294193894, 0.03040641557163326, 0.04352231168013532, 0.027055052923969924, 0.04285565526515711, 0.015822315726836678, 0.02358072939387057, 0.09263632018701173, 0.03125095179711934, 0.07955316206789576, 0.06378135876730084, 0.02726563918258762, 0.04714507587777916, 0.00855190126458183, 0.024011147215787787, 0.011289480880805058, 0.023711017129244283, 0.004573569012791268, 0.010167903710680548, 0.02864261627109954, 0.05602427539997734, 0.011688086542562814, 0.024905346108425874, 0.05549672343477141, 0.03779493912588805, 0.020385703865031246, 0.050058127962984145, 0.03628013779234607, 0.03715826176630799, 0.06450317159760743, 0.04866621515247971, 0.016530057437194046, 0.03181802312610671, 0.06056465696019586, 0.02294288315169979, 0.04379816055006813, 0.036427943923627026, 0.07495671496144496, 0.03900240968505386, 0.02502132709196303, 0.034290228359168395, 0.03836025898635853, 0.030531608463206794, 0.015054702180350432, 0.05218826248892583, 0.027125102387799416, 0.06786705242120661, 0.04082176987139974, 0.04082448242115788, 0.038243441231315956, 0.021839611981704365, 0.03945813288737554, 0.03802243336394895, 0.09342002071207389, 0.032642126170685515, 0.04022793669719249, 0.03789316237089224, 0.021610408948617987, 0.0510748777014669, 0.07552695155027322, 0.02906019493821077, 0.08731230860576034, 0.04371937415271532, 0.06118001983850263, 0.030495606879412662, 0.04089919813850429, 0.05138588210684247, 0.04461034470295999, 0.03951753067667596, 0.038367391025531106, 0.01320607168963761, 0.04053564596688375, 0.02365794985962566, 0.024852408714650664, 0.10180869401665404, 0.043092804844491184, 0.017866817543108482, 0.08196054812287912, 0.05032574641518295, 0.038723584802937694, 0.06754709029337391, 0.023089633577910718, 0.050535677728476, 0.021112040085426997, 0.006083239786676131, 0.04823446332011372, 0.05615735732135363, 0.049128235477837734, 0.031283914286177605, 0.026722374095697887, 0.026467093848623335, 0.07368964623310603, 0.07705035066464916, 0.060238668593228795, 0.027323779031576123, 0.03852637019008398, 0.035656473992276005, 0.015511771453020629, 0.0557443595607765, 0.025972164839913603, 0.026333685382269323, 0.05187592592847068, 0.07013261405518278, 0.004610553942256956, 0.10691690389649011, 0.07426269556162879, 0.019796781853074208, 0.05634355104120914, 0.018743800465017557, 0.050124824774684384, 0.018724411856965162, 0.03629676561104134, 0.012160025671619223, 0.02728001829382265, 0.04008922929642722, 0.029021592126809992, 0.03256557363783941, 0.05669460544595495, 0.06266688302275725, 0.008666767171234824, 0.035226247273385525, 0.09978401125408709, 0.047056715775397606, 0.07842494174838066, 0.015375838756881421, 0.06312079538474791, 0.02651531860465184, 0.007838049823476467, 0.07611574183101766, 0.03433827871049289, 0.04095376454642974, 0.06511240804684348, 0.02569318596215453, 0.018491963783162646, 0.040670056332601234, 0.04130519744649064, 0.07313020789297298, 0.04009757474705111, 0.0357237125717802, 0.0799469010962639, 0.031213911206577905, 0.02657770168298157, 0.02145492715499131, 0.06482205761130899, 0.04547588185232598, 0.018351421422266867, 0.017671541791060008, 0.024199049730668776, 0.019904350592696574, 0.05094008884043433, 0.00914557673240779, 0.011476374074845808, 0.012504872011049883, 0.046737124721403234, 0.04401263009640388, 0.04840181762119755, 0.04028732335427776, 0.024099242000374943, 0.032279204824590124, 0.035202298167860135, 0.04782673480804078, 0.06712837057420984, 0.03084661304455949, 0.06592094825464301, 0.02339453752938425, 0.02836502706486499, 0.014058962642593542, 0.00226198656946508, 0.019288987714389805, 0.17117651004809886, 0.16572610329603776, 0.13997708185343072, 0.13882684201234952, 0.17785714531783015, 0.07887993764597923, 0.10993046133080497, 0.1978120268904604, 0.21093355404445902, 0.10281937298714183, 0.11278820486040786, 0.07504471883294173, 0.08603438967838883, 0.24490848096320406, 0.18575755966594443, 0.17348360968753695, 0.215019908209797, 0.2595405012834817, 0.1421714641037397, 0.21410672517959028, 0.11691062740283087, 0.10577866458334029, 0.1000204001320526, 0.15213878941722214, 0.11525525958859362, 0.08127731212880462, 0.19534382183337584, 0.13123547279974446, 0.06475014350144193, 0.10947640796075575, 0.1624080797773786, 0.06453197434893809, 0.1093853687052615, 0.16124348680023104, 0.12379726802464575, 0.07502891108742915, 0.1784017778118141, 0.15566779067739844, 0.09435103755095042, 0.16594189015449956, 0.2281210114597343, 0.17422673699911684, 0.10434027106384747, 0.15210380457574502, 0.1838485777261667, 0.0880943467200268, 0.13681176264071837, 0.16966472554486245, 0.14614149404224008, 0.1264643092872575, 0.09448676151805557, 0.11653598383418284, 0.09000234902487136, 0.14469325222307816, 0.10929970259894617, 0.11101885058451444, 0.16742081235861406, 0.096708269265946, 0.14099501160671934, 0.13415384979452938, 0.22520468279253691, 0.11656241171294823, 0.18068493576720357, 0.20326160243712366, 0.13339596858713776, 0.23033544654026628, 0.21737444592872635, 0.12224168938701041, 0.1891686039743945, 0.206392441468779, 0.1642533706035465, 0.1559580594766885, 0.10242454300168902, 0.11927328421734273, 0.12228881576447748, 0.19688314001541585, 0.11846971639897674, 0.09572099021170288, 0.1111705084622372, 0.1738119061337784, 0.12916388630401343, 0.18594956811284646, 0.16390185977797955, 0.25174189475364983, 0.23435907438397408, 0.12137744357460178, 0.17654962954111397, 0.13754718645941466, 0.10741394988144748, 0.18937391170766205, 0.17414664442185313, 0.06561743954080157, 0.14148476970149204, 0.15495917323278263, 0.13899152458179742, 0.1690049859462306, 0.12595926295034587, 0.15772022976307198, 0.1508645960711874, 0.11471421166788787, 0.15923772880341858, 0.12500597425969318, 0.11961460535530932, 0.16927983291679993, 0.09857911223662086, 0.11100122457719408, 0.17678604810498655, 0.10102471889695153, 0.12509893567766994, 0.14771866175578907, 0.11806744267232716, 0.18465150729753077, 0.11037005766411312, 0.1355641381815076, 0.1046897706692107, 0.18449777882779017, 0.13227507326519117, 0.2140654023969546, 0.19661019294289872, 0.07552853232482448, 0.12855401902925223, 0.10127851855941117, 0.12912585865706205, 0.13866937311831862, 0.1579549562302418, 0.21715423587011173, 0.07955423818202689, 0.20071526407264173, 0.1849219310679473, 0.07938721042592078, 0.23004655813565478, 0.0848868141474668, 0.0948242457525339, 0.07815975754056126, 0.14927062613423914, 0.16079736698884517, 0.1507349725579843, 0.14273390814196318, 0.11563768828636967, 0.08798414521152154, 0.16681283013895154, 0.32228974043391645, 0.0927440874511376, 0.23043928784318268, 0.09062113691470586, 0.1290471910033375, 0.11622772537521087, 0.1921105367364362, 0.17391208122717217, 0.2061043248977512, 0.2183128026081249, 0.16527668834896758, 0.19385084335226566, 0.0822834120481275, 0.0806994091544766, 0.12726624438073486, 0.1300589757738635, 0.12220894583151676, 0.1379228022415191, 0.08403166706557386, 0.09523101689410396, 0.1483066356740892, 0.09744921466335654, 0.1539750854135491, 0.15464928204892203, 0.20840913872234523, 0.11543376836925745, 0.19296660408144817, 0.1283588638762012, 0.0794992821465712, 0.15971202054060996, 0.13926015235483646, 0.14002328796777874, 0.11023357670637779, 0.12660712818615139, 0.13705955090699717], [0.09300602105213329, 0.022724027512595057, 0.024444043810945004, 0.03150815791741479, 0.016084638955362607, 0.005751364333264064, 0.061860595233156346, 0.02382432452577632, 0.057724342768779024, 0.042907356983050704, 0.016221413061430212, 0.03398773638764396, 0.042770556901814416, 0.052344707219162956, 0.02648188114108052, 0.04518396548519377, 0.01066975139110582, 0.029363573776208796, 0.030437034729402512, 0.013618038792628795, 0.006192560458657681, 0.024724354843783658, 0.012427185847627698, 0.027460855562821962, 0.046088183371466585, 0.0990064482903108, 0.01942279137438163, 0.09103032745770179, 0.04475339737837203, 0.025123227678705007, 0.061600268381880596, 0.02563341895438498, 0.002872282666430692, 0.07564260784420185, 0.05087822712084744, 0.04774632310727611, 0.01671685229666764, 0.07090023224009201, 0.035897119087167084, 0.02389179131569108, 0.05792367250251118, 0.09747841817443259, 0.04443141289812047, 0.051065148145426065, 0.048721397542976774, 0.018089612131007016, 0.005516097489817184, 0.0352217164618196, 0.011115206052636495, 0.03605419464292936, 0.0045974907516210806, 0.028945709382242057, 0.006482939188572345, 0.03337529757118318, 0.02673579398106085, 0.06391980641637929, 0.08174413043889217, 0.0684249322512187, 0.03235158648749348, 0.0475632055895403, 0.08441198064247146, 0.06603106812690385, 0.045777167833875865, 0.02769880480627762, 0.01278106134122936, 0.04065169930981938, 0.019725376114365645, 0.07940266936202534, 0.05484303976118099, 0.02302998531376943, 0.03560993020073511, 0.06963083316804841, 0.06227665435289964, 0.033615716311032884, 0.039966296244529076, 0.030886097156326286, 0.019648033194243908, 0.050372323603369296, 0.026341468656028155, 0.02075873882859014, 0.0646397787204478, 0.0862858367327135, 0.04427457111887634, 0.06745668928488158, 0.008638771505502518, 0.02834115959558403, 0.006150846656964859, 0.057616312042227946, 0.007632069982719258, 0.033634975043241866, 0.029349652941164095, 0.023315413454838563, 0.03132876969175413, 0.013895046340621775, 0.006354562947308295, 0.04404435690958053, 0.018347187469771598, 0.023310110809688922, 0.05867288542503957, 0.047744764597155154, 0.04888628791377414, 0.07365017881966196, 0.033167451692861505, 0.01689608281594701, 0.015916668671707157, 0.08431750524323434, 0.019479333750496153, 0.06429109547752887, 0.05173837627808098, 0.0349463722523069, 0.05381049712013919, 0.040927321824710816, 0.025885478280542884, 0.02022783606662415, 0.005702476282749558, 0.058250369620509446, 0.07161135072237812, 0.007860014611651422, 0.052955457649659365, 0.03041613399545895, 0.007505963321818854, 0.022962911862123292, 0.01279407953916234, 0.026571040907583665, 0.019331071198394056, 0.030779344779148232, 0.026748378950287588, 0.08094062199234031, 0.012605317060661037, 0.04400668549351394, 0.05241150051006116, 0.04111277339688968, 0.05311980996339116, 0.03371808445081115, 0.043578414333751425, 0.024299274919030722, 0.029151555172575172, 0.028604191575141158, 0.026809921546373516, 0.043677379726432264, 0.06981637750868686, 0.042469408217584714, 0.03874420537613332, 0.01819691555283498, 0.03692205100378487, 0.10538833201280795, 0.03161250388075132, 0.018404826369078364, 0.002573426754679531, 0.04291721270419657, 0.10224817160633393, 0.051975863534607925, 0.0256366677058395, 0.01958490796823753, 0.026074091401824262, 0.06341714979498647, 0.03152622179186437, 0.07723653325228952, 0.019000290412805043, 0.026896480085270014, 0.022981046240602154, 0.05632535358017776, 0.04956309690896887, 0.015949100525176618, 0.015360099660028936, 0.02455634003126761, 0.03649708611192182, 0.0658867129823193, 0.0061893775728094624, 0.07802126536262222, 0.051032912961090915, 0.03358072404807899, 0.06705894265905954, 0.027030322708014864, 0.06391881935996935, 0.026362352691648994, 0.04523354094999377, 0.06512333988212049, 0.06219174152647611, 0.023892785793577787, 0.049616416508797556, 0.045040808909107, 0.02146471608284628, 0.08777347175055183, 0.05661705101374537, 0.028288509784033522, 0.10734416573541239, 0.07248724083183333, 0.02539938453992363, 0.03811768430750817, 0.021355664903239813, 0.01903617325297091, 0.05497838152223267, 0.02741256401350256, 0.051193402396165766, 0.08937691891333088, 0.039780239821993746, 0.07299777164007537, 0.0009161384593880939, 0.02922063798905583, 0.023798362344678026, 0.029355719998420682, 0.02461837986629689, 0.013392864693742013, 0.05832913375343196, 0.012517150844360003, 0.04289821001293603, 0.04416057352500502, 0.0369656002294505, 0.013736527307628421, 0.024319932599610183, 0.05130852805450559, 0.03171819313138258, 0.014824257905274862, 0.06999047793215141, 0.025261706869059708, 0.024000916710065212, 0.04850663484830875, 0.045739826673525386, 0.004957168912369525, 0.010571187685854966, 0.025453579874010757, 0.015927088425087277, 0.03924856522644404, 0.049617733820923604, 0.07984832162037492, 0.07952503467095084, 0.064577453158563, 0.040592138248030096, 0.042645905778044835, 0.03741281099792104, 0.08707388624316081, 0.055579535983270034, 0.0030303496851047385, 0.04078376448887866, 0.021473623710335232, 0.018325457385799382, 0.07884930178988725, 0.06901847969857045, 0.08367764778085984, 0.07926013247924857, 0.0541224440530641, 0.03395019484742079, 0.031111407624848653, 0.02591488588223001, 0.028278988029342145, 0.01074367393812281, 0.059189371968386695, 0.026164444170717616, 0.03622052106948104, 0.06629790732404217, 0.04513115796726197, 0.008497127055306919, 0.050693977827904746, 0.018097458487318363, 0.025508892140351236, 0.035193930452805944, 0.15751826169434935, 0.020499027959886007, 0.027800505013146903, 0.028485963739512954, 0.0337534181016963, 0.015677567243983503, 0.090109901066171, 0.06791481704567559, 0.032170999693335034, 0.027268258963886183, 0.05647603182296734, 0.1171262509888038, 0.05549828565563075, 0.044947561764274724, 0.05292990550515242, 0.02893405395298032, 0.08804852652247064, 0.04233896834193729, 0.01663778573856689, 0.043099072281620465, 0.04922532694763504, 0.051277495149406604, 0.05603650970442686, 0.032647989137331024, 0.030768104952585418, 0.02467974063620204, 0.09155357867712155, 0.09427872268133797, 0.046980905390228145, 0.041673243322293274, 0.02095476600516122, 0.06957767312997021, 0.019143398749292828, 0.014763775652681943, 0.09002858394524083, 0.05401629096013494, 0.029531406762544066, 0.10755434195743874, 0.027768260551965795, 0.011101816780865192, 0.0323310438398039, 0.03928098223695997, 0.05007073334127199, 0.01757417201588396, 0.04141061210248154, 0.01592091746715596, 0.01005546648229938, 0.03377361936145462, 0.04008189316664357, 0.035353744533495046, 0.08186282211681828, 0.0825994333717972, 0.030323384089570027, 0.07574172908789478, 0.070942594029475, 0.02528869878005935, 0.035370613550185226, 0.01335950144493836, 0.050769524750649, 0.03930955492251087, 0.03466382549959235, 0.09072735309018753, 0.017690017557470128, 0.013081612596579362, 0.10158507750020362, 0.01887794365757145, 0.04167621933447663, 0.05140638393640984, 0.01993193251109915, 0.07753437195788138, 0.024685137905180454, 0.02218866258772323, 0.013718542286369484, 0.047889349807519466, 0.04444823738595005, 0.0088809871704143, 0.02606528581964085, 0.026362298885942437, 0.010016958294727374, 0.02207270201324718, 0.048471445916220546, 0.05877670817426406, 0.045159808578318916, 0.03684737610456068, 0.06994815325015225, 0.048839528899407014, 0.05286254447128158, 0.051648335211211815, 0.08480307020363398, 0.01721942357107764, 0.032291576426359825, 0.020914220622216817, 0.014638406501035206, 0.04094613155757543, 0.035452171869110316, 0.16482850536704063, 0.12456378783099353, 0.07946659796289168, 0.18129104777472094, 0.09548900226945989, 0.11327558066113852, 0.16035915847169235, 0.18177333986386657, 0.1252976679825224, 0.14160628896206617, 0.20720464788610116, 0.18550708482507616, 0.09295528783695772, 0.1659145049052313, 0.10960068058921024, 0.11650433865725063, 0.11030408073565923, 0.11759222325053997, 0.10063718422316015, 0.15145196142839268, 0.1228369066666346, 0.19266048300778493, 0.09382416465086862, 0.11348810949129984, 0.1357584324432537, 0.17830043012509122, 0.10807458005729131, 0.1625701054581441, 0.12037213775329292, 0.14335625834064558, 0.15500031789997593, 0.24376310961088166, 0.12081455424777232, 0.2015820925589651, 0.12002128001768142, 0.1656875413027592, 0.11289611313259229, 0.13968075712909922, 0.13195943785831332, 0.08290650439448655, 0.11966042555286549, 0.17175422748550773, 0.18242404010379687, 0.1320496533298865, 0.11764032926294021, 0.07039607648039237, 0.13948027335572988, 0.10726401378633454, 0.14997860533185303, 0.26368518825620413, 0.11301656370051205, 0.14430789946345612, 0.15757356653921306, 0.1578542764764279, 0.15876371908234432, 0.21583855646895245, 0.1728311282931827, 0.1968206066521816, 0.15249956224579364, 0.2372574430773966, 0.17958130280021578, 0.2221779225510545, 0.15097112394869328, 0.1213878187991213, 0.17697569652227685, 0.12241603471920826, 0.0911896739853546, 0.15266126138158143, 0.17342132865451276, 0.09722818824229762, 0.11707743993611075, 0.15894820215180516, 0.16158705664565787, 0.08134190124110319, 0.11991744613624178, 0.23319905303651467, 0.21004634618293494, 0.18541590456152335, 0.14997271267930046, 0.1518974281498231, 0.09959247036022134, 0.32414831570349634, 0.17682259145658463, 0.20258127566194162, 0.11132327213999815, 0.11352086046827026, 0.13412376312771812, 0.18513097922550514, 0.08853159044519998, 0.16443809116026387, 0.17666463274508715, 0.19196764362277463, 0.22172359458636492, 0.10577035252936184, 0.1276616903487593, 0.12683087086770684, 0.14523919089697301, 0.19809094083029777, 0.1794974401127547, 0.14590244827559218, 0.10376208607340232, 0.15231726109050214, 0.16289945575408638, 0.21448824845720083, 0.14406018541194499, 0.24373044027015567, 0.11106573947472498, 0.1630658601061441, 0.15814794431207702, 0.16356694337446243, 0.21164821257116273, 0.12377827646560036, 0.059397210425231606, 0.11312867995002307, 0.09827909161685966, 0.20636567962355912, 0.177476022799965, 0.10886904172366485, 0.16997209342662245, 0.12015521540888585, 0.12357964806142263, 0.15237805782817304, 0.11129148595500737, 0.09951407730113715, 0.1532755370135419, 0.20302697987062857, 0.17224123963387683, 0.20255663635907695, 0.11541594940354116, 0.11545819987077266, 0.1693037003860809, 0.19886136433342472, 0.25642276857979596, 0.07339097632211633, 0.3078548493795097, 0.12195260060252622, 0.08777070353971794, 0.11338240539771505, 0.16794021183159202, 0.18318085261853412, 0.08786437741946429, 0.11421505798352882, 0.15417089365655556, 0.14983430213760585, 0.11191357640200295, 0.25210127234458923, 0.15616376796970144, 0.14747409441042691, 0.16470244416268542, 0.12919251836137846, 0.13275228906422853, 0.07020825374638662, 0.1266111951554194, 0.10345964605221525, 0.08710865586181171, 0.14373413025168702, 0.17206610762514174, 0.11532714401255362, 0.16067376971477643, 0.09722818824229762, 0.12302360875764862, 0.09085345882340334, 0.18354818603256717, 0.09254406380932778, 0.10941639047814533, 0.14148125192150474, 0.16560508869588375, 0.15691645414335653, 0.1058762198954355, 0.17379157128743827, 0.2455064293462783, 0.11496663093566895, 0.12479213182814419, 0.07086704339599237, 0.14195175870554522, 0.07427431759424508], [0.025703184546728153, 0.02101857215166092, 0.07368273683823645, 0.08074551136814989, 0.04953623858455103, 0.010082413864438422, 0.06735397604643367, 0.029566831326519605, 0.013215799390309257, 0.042873296115431, 0.06019867054419592, 0.01914036150992615, 0.024070520885288715, 0.02404126171313692, 0.02573694298916962, 0.06931590280146338, 0.023533961102657486, 0.05295049639244098, 0.0688567286124453, 0.06350997762638144, 0.032836535465321504, 0.06586273419088684, 0.031240825192071497, 0.027568073637667112, 0.05550228954234626, 0.052250777298468165, 0.051742758660111576, 0.006402513108696439, 0.028162624839751516, 0.06725915183778852, 0.03021194690518314, 0.009758308697200846, 0.023721852485323325, 0.01103807278923341, 0.02888973474910017, 0.035820188059005886, 0.0278285693275393, 0.013065579423710005, 0.03304478952486534, 0.009067012979357969, 0.04851526231504977, 0.028196388848300558, 0.027377933547541033, 0.03126007279206533, 0.018916383196483366, 0.04522368893958628, 0.07331156652071513, 0.01850670283602085, 0.0738295039627701, 0.054892789630685, 0.044261817311053164, 0.039546912303194404, 0.034427833670633845, 0.019859320782416034, 0.07063415003358386, 0.10782751167425886, 0.06665721070021391, 0.09473946280195378, 0.017693169829726685, 0.031696329460828565, 0.02046902292931918, 0.045966081524966285, 0.0178952306669089, 0.07938795257359743, 0.060332242283038795, 0.018283813624293543, 0.0345243833726272, 0.04578714972012676, 0.013871433984604664, 0.03951965692976955, 0.036573924371623434, 0.03477134414424654, 0.05991836136672646, 0.04800993396202102, 0.004775248571604607, 0.03518296893162187, 0.06269676188821904, 0.05222768166277092, 0.04683866907726042, 0.03296766553830821, 0.08357203274499625, 0.05540634097997099, 0.038869661730132066, 0.0555411892128177, 0.007316166474993224, 0.02275625342008425, 0.03157882521918509, 0.09189570133457892, 0.02070499805995496, 0.037095613370183855, 0.044953576871193945, 0.02372804385231575, 0.07862731799832545, 0.013084131260256981, 0.05623020653729327, 0.03401146284886636, 0.0653288554167375, 0.030682563156005926, 0.06049600830010604, 0.019646387481770944, 0.06721371755702421, 0.009569269768689992, 0.09518752704025246, 0.004151822258791071, 0.012687094313150737, 0.051554783785832115, 0.126993638696149, 0.09857730139628984, 0.019990376640635077, 0.038743036493542604, 0.042384970365674235, 0.0420050612592604, 0.10717919372837059, 0.017989001025853213, 0.02651894770679064, 0.02615281471662456, 0.054769222042523324, 0.0489837207715027, 0.05706996518711094, 0.0373655027942732, 0.026312101872463245, 0.05930830113356933, 0.03982679103501141, 0.006725353377987631, 0.11361841578036547, 0.0922399020055309, 0.029520024072553497, 0.05051148000347894, 0.06144914485048503, 0.038692373782396317, 0.05320999203831889, 0.024247450746770483, 0.13897323806304485, 0.06299350221524946, 0.015199479421426076, 0.060579188211704604, 0.03733160519914236, 0.051381317898631096, 0.04977156248060055, 0.04990477056708187, 0.02470408122462686, 0.028048729291185737, 0.02300689709954895, 0.01665242831222713, 0.08242146635893732, 0.047857066383585334, 0.0365899992902996, 0.09178075008094311, 0.05024646277888678, 0.05496820667758584, 0.029225439684523735, 0.04683227918576449, 0.08356432183063589, 0.018911301340267528, 0.018115533493983094, 0.03252756083384156, 0.02499244270438794, 0.01915579447086202, 0.020612854859791696, 0.009402006380696548, 0.037108029500814155, 0.0356379722506972, 0.07481794818886556, 0.0160984948524856, 0.06450783228501678, 0.050732962845359, 0.023843080452934373, 0.04507164514507167, 0.07536534147220664, 0.07998746688826941, 0.029999466314620804, 0.06539607173181139, 0.02182751126383664, 0.03707690382725559, 0.019085446292592678, 0.023003869137028232, 0.05584667203947902, 0.06350680865580216, 0.027270606005913578, 0.05021429809858091, 0.0666871786233969, 0.08008926728507504, 0.07646815065527335, 0.05232557094132062, 0.0209365110276849, 0.06856370644527487, 0.03684907191200182, 0.030944723112042993, 0.038489181170007214, 0.04818772285943851, 0.011513521349115763, 0.040288521922775544, 0.011038492102670716, 0.01678776079643285, 0.09343770609120838, 0.032155429435078986, 0.023922436448629014, 0.051915649382863194, 0.011370613392500672, 0.04419450822751969, 0.00977121278992854, 0.021720447184634395, 0.014625567346229218, 0.0679489632602781, 0.03379087429493666, 0.031048499477037694, 0.01032212292557233, 0.009541649815218989, 0.030877076351316646, 0.03097166307270527, 0.04234669409925118, 0.02672011796676088, 0.05876338291272987, 0.02447176302666776, 0.049006248664227314, 0.07146988253225572, 0.07508820126531646, 0.06674050193396397, 0.015251248860295163, 0.04910690615361091, 0.019118581330985762, 0.013975673264212674, 0.09942736476659775, 0.014919269506208366, 0.030592794828407932, 0.022684515570290387, 0.057076514640357345, 0.008738928045204375, 0.0765803262765985, 0.0492830771690933, 0.031233028930728324, 0.05807852903672028, 0.05478863291500602, 0.053896846002317034, 0.0029782752699247794, 0.02282975758134853, 0.016196488031710032, 0.025634393023210578, 0.038952492832322605, 0.050815263311960734, 0.056593636254547164, 0.02404769984423183, 0.07203183675301261, 0.049260493615292944, 0.0029412367666736827, 0.022658850248262752, 0.03505397624394391, 0.025122721162915695, 0.007714410339758615, 0.12558866408653557, 0.02688821441552136, 0.02311706521140877, 0.01797552362404531, 0.041034781097550876, 0.02659708658029558, 0.05567889842495788, 0.05504577966348734, 0.01025833440507995, 0.048901672635111026, 0.04012933866761159, 0.05464239642606117, 0.07230776725918986, 0.03761658619623631, 0.053962177262292244, 0.021235301537672058, 0.05330459360266104, 0.027488179584906902, 0.1731530571123585, 0.10295152722392231, 0.04678350152971689, 0.03538660312187858, 0.052481013772194274, 0.07667355486773886, 0.033989402509178035, 0.05470170144690201, 0.02217597000708338, 0.013031569578743074, 0.045484353468054906, 0.023895789636299014, 0.07499239742173813, 0.03539703400747385, 0.04693368995503988, 0.08421709266258404, 0.03760421088372823, 0.049070433306042105, 0.04424697435752023, 0.055598323451704346, 0.07297026764717884, 0.028875724856334273, 0.01615442681213608, 0.06924688306753524, 0.020426707524165977, 0.030645221995655447, 0.02318100679985946, 0.04706784799054731, 0.046920828535803594, 0.03614182001911104, 0.05538382421946153, 0.01554042299176217, 0.029045786141068675, 0.060410405276343226, 0.09444176510442048, 0.056085639880620874, 0.023042188076942693, 0.046614829916507006, 0.026342858327552676, 0.012627601900021546, 0.058142335183219984, 0.011335495892126346, 0.058527736182441004, 0.042629585950635374, 0.05066296718723606, 0.00877408358064713, 0.030880980048095807, 0.044154692004667595, 0.014621329682995565, 0.01979869102797238, 0.013624675448227208, 0.018031817380688153, 0.028723421310132835, 0.04846125993935857, 0.043941035110037774, 0.011155826578033157, 0.00900202217962942, 0.05329903862730134, 0.021865119597350713, 0.051623213512357324, 0.031441980609088205, 0.03836328694887925, 0.027212284330744296, 0.02894151253713062, 0.04134478731430136, 0.003520098734952626, 0.02262485802930314, 0.019920518279832322, 0.01793323604942998, 0.08268717007013038, 0.05404065937909763, 0.09573214469128288, 0.054477461526403204, 0.027892848593182862, 0.015646528772776946, 0.038940488593652844, 0.01942203067301307, 0.07648764687473886, 0.060958381145610474, 0.04560900459182449, 0.011331326877552783, 0.022361566298059188, 0.04824037452635821, 0.0313931138953194, 0.06121313446783461, 0.13688099017599598, 0.07660807517822832, 0.19306922826217487, 0.13181831105612218, 0.12138811565819196, 0.21787674631923437, 0.1488305622478947, 0.2339721779571846, 0.14798576070461422, 0.13323597639100626, 0.15767604229040444, 0.1238200964871794, 0.14011233084602281, 0.07131910781026818, 0.12751790665788576, 0.15179180569248274, 0.14563995064236224, 0.1605185866355896, 0.18842908350052312, 0.18933367246063426, 0.12223412690218538, 0.16062262089690194, 0.1296418294077739, 0.10092454380355775, 0.1761718318448402, 0.13217800034908578, 0.1383016092586331, 0.12743891245918348, 0.12824435048969463, 0.18830418004654348, 0.15585920540615916, 0.09209556170389988, 0.1404455106239766, 0.17080960707971826, 0.06329666954115964, 0.1100025387131609, 0.12710904265986755, 0.1434834030806087, 0.19586841634009033, 0.1812153190257959, 0.12355906088487245, 0.18244188133394346, 0.1261059261742048, 0.09102549607632682, 0.18731237389147282, 0.1499037374742329, 0.22481572319520637, 0.09875889008981176, 0.13712934247450903, 0.10052270052256063, 0.193337217788212, 0.08481600583763793, 0.18483141873730347, 0.16114803176606074, 0.12819848576327786, 0.222873107122723, 0.1347691347473301, 0.10458781442139298, 0.05532284194487147, 0.11790327218477614, 0.07853110597352497, 0.04938574958941899, 0.13514034217223525, 0.12105439411243424, 0.09817291997023858, 0.18535032839281484, 0.21357243822421879, 0.12805980804841965, 0.09872806869680062, 0.19625976565293968, 0.0936838096822612, 0.12329752062214538, 0.1333184289978817, 0.19753131695324555, 0.06550642909132876, 0.16364708048058674, 0.16592860571108758, 0.13916481606429443, 0.1450698624830693, 0.1295182469766587, 0.12340957749984227, 0.14580616203602403, 0.12501692835940048, 0.11676643553073518, 0.17246005445485935, 0.12728322471957654, 0.19343813502928242, 0.17318387108389288, 0.1251930696889758, 0.2232549272594042, 0.15280169056495652, 0.27840105642098933, 0.21252412494504824, 0.1459577531204559, 0.1344158427673392, 0.11470733938040212, 0.21040091465692967, 0.09470959877944551, 0.18345041549764574, 0.07710851277806796, 0.17066239466657862, 0.14330516889458522, 0.2586490928661078, 0.12595391948707402, 0.0838613515952602, 0.18868282379116863, 0.25379874219652265, 0.22389905207091942, 0.09631137610995211, 0.18726361478911713, 0.2501436945749447, 0.26983610820025206, 0.15370930748758838, 0.12731996102957055, 0.15413817978696898, 0.1853051019134, 0.08572265054681338, 0.1095055892074015, 0.19305831869132817, 0.1127929323411081, 0.15854950557695702, 0.1341092912480235, 0.12733943498460576, 0.13978885835967958, 0.2107614796841517, 0.12424884262145497, 0.10289059689966962, 0.17251984187169, 0.2431111625628546, 0.09862252787570469, 0.14687813498312607, 0.1271388473105617, 0.2209866271005012, 0.15992046013707295, 0.13311736634932458, 0.13648587075294927, 0.13598126970464364, 0.13915956165874377, 0.1472743379417807, 0.1280384193523787, 0.10601943213259801, 0.14318853296572343, 0.10533156513702124, 0.09804288085433654, 0.18674751045182347, 0.14957020146539435, 0.07428789889672771, 0.29104232497047633, 0.08624873677035794, 0.10145307169295847, 0.10461919984663837, 0.08595276085543446, 0.09887041262118146, 0.1320202197530307, 0.1309376786230132, 0.11533484008396044, 0.15948838175972924, 0.15913961688056588, 0.14261077099945396, 0.08640216095955111, 0.15826590126380324, 0.19907229754608124, 0.15122479002457112, 0.11964513731072657, 0.12606432137545198, 0.07964763004565611, 0.10566776545601897, 0.11823188775451854, 0.1394348984467797, 0.16268041828880087, 0.0740974786458537, 0.08596899904659949, 0.11467823234852403, 0.11748775112209842, 0.06961946346564218, 0.2158229862106964], [0.01727391019812785, 0.06354594952426851, 0.029785304759570863, 0.03400332519959193, 0.030173028681019787, 0.07357873226283118, 0.047041026773513295, 0.01329520362560288, 0.06516799490782432, 0.026349641557317227, 0.017934482857526746, 0.04891526506980881, 0.026757830200949684, 0.01880481057014549, 0.04733611211122479, 0.0472819984133821, 0.046602491711382754, 0.02224758169177221, 0.023211676052596886, 0.02916826277214568, 0.025792121668928303, 0.052410795469768345, 0.028089716251997743, 0.020566620914905798, 0.044895978790009394, 0.0343613817676669, 0.1182444003643468, 0.029873212151869666, 0.05703793038264848, 0.015317746219807304, 0.02595320482214447, 0.002703487671169569, 0.01854585669207154, 0.047359708696603775, 0.05831023496284615, 0.0487812591745751, 0.019539713030098937, 0.02678903008927591, 0.02344288102904102, 0.06260840178583749, 0.02925590299128089, 0.024154055172402877, 0.03709389529831242, 0.035326351862750016, 0.03584215563023463, 0.056147438517655246, 0.02299386127560865, 0.0416759373183595, 0.11838120786705986, 0.0408127045375295, 0.028071644956071395, 0.010547792408033274, 0.0781274370092433, 0.025701972990646027, 0.024893390109355096, 0.05262206635961775, 0.04781219242431689, 0.05612840242974926, 0.018688061463763006, 0.041806466251728125, 0.02098520333674969, 0.07652654283447191, 0.06810883671278134, 0.03163883156958036, 0.06959872043807991, 0.05279963261273224, 0.022178075851115864, 0.05110956568387337, 0.04451405846339185, 0.04007032679510303, 0.052986787413829006, 0.04206665209494531, 0.025883977286866866, 0.034368331980658695, 0.06950808194233105, 0.011869966529047815, 0.029908005890320055, 0.0134619855452911, 0.058618259645299986, 0.014477914282906568, 0.05038979747041594, 0.01461687586925109, 0.12274944456294179, 0.02635458055010531, 0.024571346257289406, 0.08957266778452322, 0.060639688090304844, 0.013040106132393703, 0.016336037770088296, 0.05321712407749146, 0.05896433052839711, 0.038131473411340266, 0.07278660094016232, 0.01848454416176537, 0.022046611811674666, 0.11167065662448294, 0.027460111559776124, 0.04395697273139376, 0.011424485892348457, 0.03430085220315959, 0.04250384015904274, 0.06354217199259438, 0.0440020915993955, 0.04272580539691262, 0.03093375045864377, 0.030946020015107933, 0.06991204776568338, 0.035968855081591755, 0.020538688331726007, 0.07532002593507059, 0.0997154887591023, 0.02706157825741684, 0.052219644203432836, 0.029252947388158645, 0.049209968201466836, 0.048772327427286655, 0.05304500889906194, 0.09602854363038205, 0.011567122037376976, 0.04954686242854223, 0.005144843680682243, 0.032048612119979225, 0.060503826825879514, 0.05462668887048494, 0.04773950277012773, 0.03939424510463141, 0.01776657565642381, 0.02212132381828269, 0.023285651477635838, 0.0403366019600071, 0.0238429635646753, 0.03432332072407007, 0.06615094724111259, 0.03592506094719283, 0.025042389243026264, 0.02788550133118406, 0.03588367879274301, 0.053824033893761225, 0.032358596072299406, 0.0314067694125697, 0.01333979742412339, 0.03323505021398887, 0.010639395695761777, 0.013687652244698256, 0.012632680045499, 0.025623566943977494, 0.04584739726851694, 0.041953574764193036, 0.016103973757708445, 0.08125126274535432, 0.04776188223331701, 0.034589321294333786, 0.056608787199365906, 0.03033080185559811, 0.07350814659730531, 0.017879487859318033, 0.040965924636111595, 0.02206053821282694, 0.02341746247111587, 0.09548665708280168, 0.045069893676554784, 0.05257968972728122, 0.026330833679821808, 0.0024862292730176705, 0.012378017636365257, 0.04318893152230885, 0.047609523026039824, 0.061145506260800175, 0.056031370331766084, 0.04786508157849312, 0.056361228998866864, 0.017450248196837492, 0.04220737442665268, 0.0337607653636951, 0.04130145702220034, 0.020214429168845527, 0.043227096466580406, 0.017823880589276087, 0.014170262529660249, 0.0779784434416797, 0.0074079975092899986, 0.045328135092859156, 0.06867571879411116, 0.05482317246787716, 0.023574506485601887, 0.027480047501740046, 0.05217845129664056, 0.04560085209959652, 0.027057155057264026, 0.045537532059825025, 0.03552847578248475, 0.05318014656950254, 0.07182317451224662, 0.031081994457053952, 0.015331887843785807, 0.07832185743609443, 0.10687316171242855, 0.01853761699749157, 0.002169945878449653, 0.03537816861353349, 0.07343980963923968, 0.04689923574915156, 0.04120747515116818, 0.018956301464641, 0.023577532592753414, 0.08701197628397495, 0.021127999971213285, 0.018620379451022018, 0.030170039681252092, 0.0801987637532875, 0.05900494084926322, 0.015035883170639863, 0.013660896893270547, 0.022409406992665026, 0.10197699826676399, 0.07287483487743884, 0.03181667241733521, 0.02589345080195926, 0.005062069167252048, 0.03945231444959063, 0.0974076618149411, 0.027627788695099298, 0.04791251594724599, 0.0037735247724413057, 0.047767993819434196, 0.04271243560651783, 0.03979125329351518, 0.06256762077100575, 0.057123359001707286, 0.046266484350780956, 0.09910953260259703, 0.041430327255511656, 0.02247843785880832, 0.05260154226562008, 0.008919688316382235, 0.013972465330880368, 0.07008017390035093, 0.08225916608353145, 0.07559747784398496, 0.07139594235923141, 0.023289386335818563, 0.050231378627358936, 0.04666257598728407, 0.053539539003395475, 0.05591526503849309, 0.023236957313201856, 0.03218000565539114, 0.05077119458292145, 0.020819747078348882, 0.05984125593386125, 0.04091632319614291, 0.08846928714774549, 0.026336156734032556, 0.049278683654847555, 0.03416724706767127, 0.04342192878539208, 0.03660185138869565, 0.04826052754651755, 0.06138176526292227, 0.031262581251212396, 0.011301139093120582, 0.007186624134192243, 0.03803631152550224, 0.07484010871849023, 0.04533284401986748, 0.025982714469137136, 0.032551847616559826, 0.055358754470944405, 0.04565507340885233, 0.06622309883823618, 0.06539718495332636, 0.08557583889341913, 0.029421338840620592, 0.03409090975765139, 0.05002686128136702, 0.06266139855142683, 0.02258441469166428, 0.05715406536182854, 0.021880717686144635, 0.08315456725540571, 0.09803244625800289, 0.029539577808463946, 0.03843619553663302, 0.061984556159586646, 0.018614646360219922, 0.03104334340605419, 0.04751950051286258, 0.0020189761107758386, 0.04954533731506672, 0.05772092888946645, 0.0768776009499561, 0.11226235612411983, 0.03830618610663805, 0.03524588821164798, 0.06686270397040062, 0.0560728415439371, 0.03170898307871539, 0.12611171492608264, 0.05263448249024805, 0.041755721904337406, 0.007544238196715014, 0.031224390331772156, 0.03597501490730792, 0.02578046067355899, 0.055235665568034165, 0.03277431751484983, 0.0559484613040695, 0.035368902899790555, 0.054920531110838056, 0.05125253301230259, 0.01770773818861926, 0.013589777809102088, 0.044002774375258014, 0.01753217016812414, 0.06601701927138492, 0.08627768052974716, 0.018830247681762557, 0.06951934774406254, 0.10948932875180617, 0.02774819473415846, 0.023423663114954252, 0.0660243739548605, 0.014185241852828767, 0.046780195261817425, 0.05933904089033604, 0.05836313153849915, 0.046744954379391856, 0.018400636945443694, 0.034896733704954386, 0.02836618852597894, 0.031964048102963716, 0.057283915230073035, 0.009246448516933015, 0.035131296899635345, 0.017999515403062105, 0.015226052946673008, 0.05246782580798026, 0.05629678831610363, 0.0330039862456033, 0.028266586741665378, 0.04234630076098256, 0.061599567052326165, 0.02423360969260102, 0.007222618296509609, 0.040768977196421474, 0.04819342997507192, 0.015408721465064446, 0.0010371560165367555, 0.02723463039728813, 0.021190130719332956, 0.1285749624366872, 0.023731437322567217, 0.08373644814128056, 0.13502709043677896, 0.14369041775353253, 0.20242588478140533, 0.060972233331995085, 0.1897277677198872, 0.16130653966683894, 0.12516528367996216, 0.18564880534540862, 0.14332516235299408, 0.1496337738353759, 0.1417545255389996, 0.08834376028971747, 0.11185371477040462, 0.21576278319116682, 0.08366382899112068, 0.10953822886222042, 0.16467838373500854, 0.10131411196198314, 0.20369854930322617, 0.17745352088240907, 0.09246762259863317, 0.11941355012822896, 0.09606089384760708, 0.224559118214529, 0.12454888550564647, 0.2659418515395373, 0.11830983552499674, 0.10823762248037383, 0.15547734074061736, 0.14287314988905564, 0.08961738218204118, 0.1196982453984674, 0.17389260727213696, 0.1168264307489153, 0.1010046066949144, 0.10185946433921345, 0.11037864431273192, 0.25024311267770827, 0.12098867693566717, 0.15865187742747366, 0.19424430036451668, 0.09549471680657007, 0.1169331293203868, 0.12756329640978947, 0.1243395553319715, 0.17787048913305625, 0.1179430290358141, 0.18952551763504744, 0.16508346277987584, 0.0900974849355407, 0.1764956457191147, 0.1512012491002679, 0.13095572765450925, 0.20118390064453706, 0.11839090031571686, 0.14813527377555147, 0.15735227294499055, 0.17859305895399302, 0.22478201484773308, 0.15082860190887004, 0.2301564850495197, 0.22754182456992567, 0.2231778032728471, 0.14630341582233086, 0.19102459657005966, 0.08411011207499541, 0.19648420595331118, 0.11372167078661732, 0.20281122269807383, 0.17789659788832068, 0.12220494565553963, 0.1777959181345068, 0.11859761812957004, 0.08866593401762657, 0.19412940106121823, 0.1180945459054783, 0.1453152165049687, 0.09118935486185364, 0.16570469975704327, 0.14583866810426116, 0.11660325952107087, 0.17640624660998583, 0.12816667731385678, 0.08921131608076394, 0.27580119436606765, 0.19513544160872698, 0.13630824512802064, 0.10779590360471047, 0.12498037016484886, 0.1376760975108482, 0.15943341830279678, 0.1377495107590221, 0.15450214385055006, 0.09704635464004241, 0.16826574748847634, 0.15009443974122405, 0.15282003645552322, 0.15262856235494837, 0.1251029284321703, 0.10627162133459933, 0.17839946231106296, 0.0995900880661793, 0.14884289674228057, 0.2311356450081803, 0.09850460060988553, 0.19053933589020744, 0.14107595023233443, 0.18775559932691976, 0.1931385596981272, 0.18957822496304289, 0.10673869197489694, 0.10665864392649382, 0.07434514074702747, 0.23242137132911012, 0.23761477234074846, 0.20625063189072534, 0.1804077732958831, 0.14253689761972055, 0.17120931297540665, 0.09397983754752204, 0.2702351758489385, 0.16607241908786818, 0.11150486825499684, 0.18413648649584502, 0.1398583679110743, 0.08668991387821734, 0.1313426240812987, 0.19897056394256651, 0.11890701207448728, 0.09162915157503448, 0.10139822697965428, 0.13735301094129682, 0.11350715300068259, 0.14058917557122186, 0.1444359793094918, 0.12829984829295427, 0.11675288391415961, 0.1416026969673112, 0.10235933048534207, 0.16983688896289095, 0.17195088177686557, 0.11730392114259303, 0.10953364981105551, 0.10723999046604149, 0.15130421466892585, 0.16869277926161885, 0.11758854961954057, 0.16182696330361068, 0.18651837977813557, 0.13180870766518638, 0.08197067843866535, 0.09944490171619691, 0.09410799160832539, 0.16572230349993333, 0.1334943328402005, 0.14522492681862786, 0.13601634360384196, 0.08188710518879816, 0.21062848682049662, 0.22689382574753836, 0.17446772719267756, 0.15228629868943244, 0.13089221465634182, 0.14559652016032487, 0.14881157811032608, 0.14111849013715982, 0.06870109282317571, 0.1150887216499541, 0.1465148536954075, 0.13735541549976915, 0.09505311667453498, 0.1208215527003631, 0.0888185492658522, 0.25618584535550326, 0.13308707188116387], [0.04058673912368249, 0.017627721681492403, 0.08547627978259698, 0.06872565791127272, 0.015890363247308414, 0.05269382461847272, 0.06967276451177895, 0.02230586440418847, 0.0535981389839435, 0.01579407515237108, 0.03532061506120954, 0.04228279889503028, 0.053165774879744276, 0.024416350570390932, 0.042767699633259326, 0.01346476952676312, 0.017007800161081832, 0.02335437064175494, 0.013535030502680456, 0.0511872425704496, 0.048550399296800606, 0.009433153391000815, 0.09181884452118538, 0.053895172459306195, 0.011904729653906543, 0.0767190707847476, 0.033027512326953, 0.07756912673357874, 0.042722209691419266, 0.013389388659561519, 0.016830868444230873, 0.04512586645432748, 0.046885773190297186, 0.03156108046823647, 0.016131884076457936, 0.03957726985390764, 0.08404305161093362, 0.009349972551717656, 0.02804467159876367, 0.054082089773146436, 0.00998998679278884, 0.04580112436087802, 0.05008103806176223, 0.08691585331689566, 0.05679704037902411, 0.020914138985972386, 0.06616369733819738, 0.04507132231083233, 0.008606456540292129, 0.056339287402806804, 0.04331611708039418, 0.032038960489444435, 0.01921056868013693, 0.10503950776183046, 0.03767593945667613, 0.06741437944583595, 0.02729437328525819, 0.050236692404723726, 0.041730670709512196, 0.054808997447253205, 0.04934978140227031, 0.02627890746225603, 0.06436101321014576, 0.04370459799247328, 0.026125405347556807, 0.02697429241379723, 0.08131935479468666, 0.045220134052215144, 0.053900245038676076, 0.035276694761705585, 0.05202263739192858, 0.08522616859409027, 0.06098768855736125, 0.04634610566427, 0.048015121574280784, 0.05375996057409793, 0.04390160109323915, 0.051786363546852954, 0.07349816471105441, 0.10695222270442173, 0.08071946940617636, 0.09470622200751677, 0.014598921461583814, 0.15662121295463294, 0.08299837485537864, 0.04826736272661947, 0.06755739130312577, 0.05679848756699357, 0.03317025701107923, 0.038987373773125, 0.04920659885101486, 0.07391312174149789, 0.015977545190253295, 0.05208882583247032, 0.0905900112411473, 0.1028319746546913, 0.07252465991768986, 0.06263451054110192, 0.03810224763583392, 0.050387021838105284, 0.04375801407149993, 0.0432187324622646, 0.04603029585268814, 0.031221655517583713, 0.033378262451151386, 0.015310067774407798, 0.039083797310013324, 0.0432713173358934, 0.019390535780985374, 0.022314258094411343, 0.03550137626007199, 0.03978720116720069, 0.053019853803562, 0.08047484268900007, 0.06954323005629703, 0.04626976093277335, 0.040787556863506325, 0.03314961046271492, 0.038778440648457035, 0.026815827186510433, 0.04250539124768693, 0.07548280860646628, 0.024456393148284405, 0.07544895182945766, 0.04231409155181609, 0.03342790841998067, 0.05437897110823542, 0.019698387914104387, 0.015584383181703743, 0.01142207298471476, 0.043515584111446515, 0.026782285822264384, 0.026128268182219472, 0.032213554441113956, 0.024612782217445783, 0.029599368936032988, 0.029109592287568375, 0.0695234518207144, 0.050659768530749716, 0.03541669349942822, 0.0317136957164621, 0.0414950091362698, 0.036743983800988644, 0.04820780537556857, 0.009610682536731474, 0.0501229174551554, 0.027324079601385165, 0.045139184294384904, 0.0741121286409907, 0.059609958188957535, 0.04184367753623519, 0.02750485193246277, 0.040228964571724646, 0.09921085060341284, 0.018055137516057584, 0.03409646473301109, 0.033370058008586057, 0.03157502542308066, 0.04954371201165486, 0.04891848970146384, 0.03716078877914697, 0.04613407036231365, 0.015318927162297769, 0.05033945017203223, 0.0677571700362023, 0.0187991646816954, 0.03245432199037168, 0.009353750083391787, 0.027023394759453367, 0.03841042074782308, 0.06384706110111438, 0.036815775456489064, 0.02335660636163084, 0.030798045045230538, 0.025480169169895817, 0.009662671836849768, 0.11880492224008776, 0.015987642109394073, 0.052664491231553257, 0.0400422253733268, 0.014499782591883559, 0.031368341005872935, 0.04529035235464107, 0.03831224203167949, 0.0658407443552278, 0.014667022787762107, 0.07133069273550063, 0.026946250363835134, 0.05189960415009409, 0.010880150257435162, 0.018040871582343243, 0.019047869500354864, 0.01882821976323612, 0.029718656187469605, 0.02232429749710718, 0.0640431884676218, 0.006194101342771319, 0.12312015474890359, 0.04898342762317043, 0.022018807248969097, 0.004323408193158684, 0.031166870176093653, 0.034435500056133606, 0.0260305050687748, 0.03737047518370673, 0.058616099995560944, 0.02322140004253015, 0.06164307545986958, 0.08332834113389254, 0.01717941624519881, 0.036129218351561576, 0.05543892126297578, 0.030230188895075116, 0.02307715250935871, 0.045771876320941374, 0.09031069654156454, 0.03153739482513629, 0.036275143138482235, 0.005193722918193089, 0.03226952350814827, 0.043857907148776576, 0.03461170075752307, 0.030441424532909878, 0.026047426035802346, 0.027843807474710047, 0.03112700200290419, 0.0012322313887125347, 0.06807236015447415, 0.0690809240040835, 0.046489996966556646, 0.031245834688888863, 0.02622709627758013, 0.05621439137030393, 0.01429475223631016, 0.011461986614449415, 0.038587059316341765, 0.042987905981135555, 0.03461531872744672, 0.046441820450127125, 0.03627371079346631, 0.04775102832354605, 0.02466881436703261, 0.02245158510049805, 0.040220723021775484, 0.03315305402793456, 0.06224059710802976, 0.0764672526565846, 0.11665680547594093, 0.04327094626205508, 0.04858892047195695, 0.0576154363079695, 0.06921128966496326, 0.027151728791068308, 0.01882849435787648, 0.09168006290565245, 0.15875188924837857, 0.040004899055929855, 0.055684746548649855, 0.017536318773636594, 0.13793230173178017, 0.03804179599683266, 0.0424055835173931, 0.09561846251017414, 0.026281772152287886, 0.061306281422730535, 0.08897642634110525, 0.06777240632800385, 0.018554771741037257, 0.041956432032748125, 0.0538894616329344, 0.054938672910793684, 0.1267467113211751, 0.17309963732259348, 0.07699132765992545, 0.0938955221499782, 0.03144334245007485, 0.06084347813157365, 0.016743920277804136, 0.02558336294896435, 0.024804927961668, 0.02431241278827656, 0.03626859368523583, 0.02807869535899954, 0.05808968351630028, 0.04643666623451281, 0.05851510111824609, 0.051667211737367325, 0.08628191819298081, 0.007348576991716982, 0.041203827495337464, 0.043716019645216875, 0.043889578300877474, 0.0017288804406234703, 0.02305514040926937, 0.044293766768532805, 0.03666021388198715, 0.04878851366811432, 0.06466858147177845, 0.008833049996610498, 0.021788533667859156, 0.01704147882264806, 0.06235742970602587, 0.0073309560866618995, 0.020523938146652654, 0.06919551902683452, 0.02198925121774664, 0.04129605418711435, 0.0905192771460861, 0.026870434412558097, 0.026878822536673397, 0.13433897111099213, 0.03677284963487182, 0.05100731628772337, 0.025318219559267163, 0.022093879197200295, 0.06605972244869918, 0.09723793264129199, 0.024118005349009763, 0.05981480579066556, 0.007547985114797484, 0.008428746496065287, 0.052611691135098226, 0.013611958747787867, 0.02505604104953818, 0.027451599125924986, 0.02556188148446381, 0.03335491448524408, 0.06587368086911738, 0.044293236132944, 0.058757527367561124, 0.03365545460837893, 0.03685045972815715, 0.09137558939983137, 0.07227377689559944, 0.07424457973684184, 0.051509694603737444, 0.04462901713850442, 0.014802596469962737, 0.017708090708765667, 0.04826670221518725, 0.03460169660684187, 0.03640573886514176, 0.0385864989948459, 0.01633798034163192, 0.06556896987603977, 0.048121330328285694, 0.10459105018526316, 0.09836708806687966, 0.017206461961905006, 0.045313466544030234, 0.04925761779304594, 0.026363339748058934, 0.20428682008059695, 0.1100235860212706, 0.1808596373302862, 0.16811298381071538, 0.14413255965337157, 0.21635571465594694, 0.1722674077609554, 0.182064454711508, 0.20971089543309063, 0.07095627923263237, 0.12432149145752192, 0.12399390005157329, 0.16042715404182673, 0.18761831684969366, 0.0881864398252219, 0.0924912971095182, 0.11271240189671516, 0.08089939568890259, 0.07997159234946594, 0.18608633108669892, 0.11153545216075145, 0.1618771770154126, 0.17765125870937482, 0.08475385839119554, 0.15623952640453354, 0.20549948938423768, 0.14061572961509228, 0.21269930148264393, 0.12851464067352936, 0.12165009378804825, 0.07705674797762185, 0.11082285680458881, 0.2505335595924407, 0.10664375644410029, 0.15150698425713927, 0.15817693260032684, 0.2003095022519119, 0.13221062516095117, 0.15873554715653881, 0.1506251495447941, 0.07302831101696938, 0.10212121240328997, 0.13832881639245898, 0.1444839220494032, 0.13824381079757586, 0.14912696118699387, 0.07664352015126497, 0.12455198768293485, 0.18296061287401244, 0.186574679100886, 0.1717237549019046, 0.14867877820506692, 0.1973700779490173, 0.15698060538852587, 0.14056336367502809, 0.12639854016015306, 0.1514659880194813, 0.12947806710144505, 0.18866691214498132, 0.13899468613089994, 0.10245568351820111, 0.12370693380944431, 0.12469522218452767, 0.1529435149859637, 0.10017815104220062, 0.1233438603230752, 0.12839877657825127, 0.19955025549279526, 0.16307755635352805, 0.24254904506960884, 0.1762724225409329, 0.2541211014613509, 0.2107628749217838, 0.18882685981225222, 0.15253908903105184, 0.14967197959776968, 0.24180547246942297, 0.14153867930872366, 0.24135424668202177, 0.22010516346199438, 0.25564835232216865, 0.22882131685037166, 0.08288745346362703, 0.3041054599452764, 0.20445610396564007, 0.1850843575084582, 0.2608744672033936, 0.18994340614881366, 0.2403983159456402, 0.19169016944942996, 0.13660370896104723, 0.17874338838737458, 0.1867957055219449, 0.1532046915963292, 0.16157415811903775, 0.19822820846457034, 0.36675421230029315, 0.21017466351622716, 0.2042204572353512, 0.17812721285736188, 0.1137299531546887, 0.14501084689982235, 0.17590681090950966, 0.17259463551454246, 0.09103737786062993, 0.09269334681448527, 0.21547858515987173, 0.24071377323707566, 0.09382587159052491, 0.14265813486417755, 0.15184353338554502, 0.30376045033335686, 0.20715850114356726, 0.20020560157718137, 0.21360593877034262, 0.15617656259564683, 0.15665842423914, 0.12752676790114492, 0.15197076718322933, 0.14538202463882044, 0.15114250069018453, 0.16903474606806412, 0.09338792282505892, 0.17751318955561146, 0.09233567616320215, 0.20895509223919362, 0.12122691376134753, 0.18413455691188574, 0.22066756297135726, 0.049013892785296775, 0.07253037445480004, 0.19275301398010924, 0.08328761206939816, 0.1250163494842127, 0.2776726533193141, 0.11675539979478344, 0.09535065852105618, 0.18347398610785604, 0.13467817712808028, 0.21365484630223364, 0.16836746624903753, 0.1200478637474589, 0.12996732053579763, 0.18599966308102012, 0.1665396455791779, 0.14205858344212174, 0.08098209320451133, 0.10443729202961549, 0.13148312747944146, 0.1436565609765239, 0.13331543072126806, 0.13190255966037512, 0.09281537073547952, 0.19998849369585514, 0.08450788838672452, 0.25212638662196696, 0.14081924135098234, 0.1504842157009989, 0.21630146366078407, 0.2001140799256973, 0.1510194971342571, 0.11975965069723316, 0.16652772668749094, 0.17388298903824762, 0.12949099531397223, 0.12840625742683187, 0.13625541905639693, 0.048898284730967134, 0.09392536390805617, 0.2783499372890219, 0.21439424803247675, 0.2049756667111069, 0.06004402181133628, 0.07780276224366389, 0.1934945085668005, 0.14179323596181348], [0.011130176098959055, 0.027894023041881155, 0.05406654177932069, 0.13168447214411572, 0.07466607508831657, 0.01999679436266888, 0.030751336125831585, 0.01650538844842231, 0.03251862908655312, 0.03822344035143033, 0.01826107793021947, 0.08782001925283112, 0.028493036406871397, 0.07910045940661803, 0.010001631089835428, 0.016902585884963628, 0.021063377462269273, 0.048393101096735336, 0.02330313276615925, 0.10201791286817752, 0.03739709973160643, 0.06311381177511066, 0.03672753038699739, 0.05124262534081936, 0.023445608421752695, 0.018812940797943156, 0.04601583510520868, 0.02117891315720044, 0.0844873086316511, 0.03873674308124464, 0.046885357587598264, 0.05151720884896349, 0.033818252122728154, 0.07827685360098258, 0.08263052193797193, 0.05172411591047421, 0.05240819795290008, 0.02308324554178398, 0.01932271090481663, 0.04701664351159707, 0.0070587845584668685, 0.030156354478094727, 0.05286267805786338, 0.052691895034513436, 0.01921806066093268, 0.017189099417009857, 0.0582830686471425, 0.05226191693509463, 0.07666974765015766, 0.024313705980603117, 0.026575363917800132, 0.033336364504066296, 0.020712441801151726, 0.0037611517791447113, 0.0487502967735054, 0.021730672124249395, 0.042184156336588785, 0.018835836053767707, 0.034723609205684625, 0.016119098727358505, 0.05966664342849981, 0.06680284233880229, 0.0239359175611753, 0.05621278462058399, 0.08883764472557232, 0.0099085945294064, 0.013628177457576385, 0.06895864033140242, 0.0563164700724883, 0.08223483848269098, 0.03928012876713183, 0.06293847196502611, 0.02858469535567565, 0.14736609708052129, 0.02527944976463914, 0.026256986275257077, 0.06489245031843893, 0.01609179140359629, 0.020214338255755138, 0.03648767939012032, 0.03727659350261092, 0.05097237597510684, 0.04920233892335091, 0.06780477880965918, 0.03833169743302278, 0.019547097399481572, 0.06840194793767296, 0.056474150478607044, 0.12317873988649808, 0.24602337973192334, 0.15274114615749568, 0.041773403572733514, 0.036184163254802115, 0.05753573335823603, 0.030068864543864038, 0.04322666602092795, 0.030519424253725447, 0.030882562678016257, 0.039562887031934224, 0.0027832175237563206, 0.044795017020078376, 0.019730528474610765, 0.05804191518109292, 0.10140187834622338, 0.051873005577363074, 0.020581938842951786, 0.059342102249502204, 0.03782230953220278, 0.06491240666946396, 0.0040345763773075305, 0.07653550055692904, 0.045204114794614725, 0.028889311724924482, 0.06925843088538386, 0.06371812778525054, 0.03632326399383601, 0.01889967930765124, 0.018400870721961837, 0.009169947006739676, 0.020758892824233044, 0.023953641903062817, 0.043289281020406634, 0.056499216516385786, 0.08309875775012188, 0.017803128284867853, 0.033499718629173, 0.05480470783368219, 0.03801154605753254, 0.07171394521719776, 0.08212700442527421, 0.06870848461403511, 0.04771540152432863, 0.045313236478250474, 0.0436010164412437, 0.059775772533612326, 0.0535176679113647, 0.024394672436756082, 0.0580016388266813, 0.025149024731945246, 0.03532172828272451, 0.04825680567591917, 0.10427921457448974, 0.037280040778568946, 0.055922077954164706, 0.013471460915752687, 0.02742943117482355, 0.045291732749319635, 0.03925475844880566, 0.04619963168806862, 0.03962905320804566, 0.02895893259847071, 0.05178763261938002, 0.08204935351386666, 0.02102328850014601, 0.07408653938909993, 0.041469950519967824, 0.07156630977988243, 0.03851484834740404, 0.038314279227051884, 0.03956915075832512, 0.03745918038475793, 0.05084291573439259, 0.04456290291273035, 0.042768397252075374, 0.024247704932349734, 0.021675988828064874, 0.008964703283709241, 0.04071875606314279, 0.060700752001139335, 0.05152639663720038, 0.023976316369953565, 0.02393754471995635, 0.040134069859050214, 0.07682611074415036, 0.03315940310130827, 0.040496601577615365, 0.024025090315262787, 0.057044439017772675, 0.009630620334064588, 0.02426522518362617, 0.0958478232496418, 0.05051616295531858, 0.045332265144679695, 0.038077890349086374, 0.022531493996211793, 0.007548134935859707, 0.03493278723908588, 0.05185039233765565, 0.007635466699866811, 0.058683108509285375, 0.03757765683985781, 0.02093086328386562, 0.032841634019860066, 0.023315092475968413, 0.03268455475335941, 0.06634790581301786, 0.042997030686819926, 0.05378698588174302, 0.048115708559635095, 0.07220961822895333, 0.05394882602558937, 0.02850645443686517, 0.04033323632029351, 0.04788401747646276, 0.012951974240422715, 0.01619511876924662, 0.015480970469070598, 0.0703044880356174, 0.01536734023829922, 0.07385780947515741, 0.06506613513920456, 0.0838629249483347, 0.08412477691308595, 0.03419360444240738, 0.028728952165693045, 0.014014608186698752, 0.030249412375269458, 0.005228885411270312, 0.06441049219574779, 0.010487695144547615, 0.021037871701992117, 0.035508126093191095, 0.016571784690313507, 0.06165815961139742, 0.01939005895110313, 0.07143169903429225, 0.06533110412419774, 0.024294345203088596, 0.02907278361817589, 0.06389872942236252, 0.04735078808153048, 0.034365415340289474, 0.038629302362096496, 0.0805743424280081, 0.01805258638341911, 0.005186705448068096, 0.06175905087729916, 0.022051359701436013, 0.03392109523701947, 0.07589331275084987, 0.013845702796970727, 0.012641386365430662, 0.01988392112252768, 0.014708087674080161, 0.08601257053669542, 0.04399254758027382, 0.00996259876046679, 0.06209307670360431, 0.02445395519316662, 0.050132940159528516, 0.03521192382322624, 0.047642366771469824, 0.052172926007187925, 0.029060948218102567, 0.02913430394983152, 0.02328089245565934, 0.040880855958675966, 0.047862335632089525, 0.0525103323161602, 0.04237685127009172, 0.10252741951262578, 0.04142051977396477, 0.013088393970974721, 0.16880699578905478, 0.14648047741502523, 0.3891880897572264, 0.21739819465437904, 0.09849026973824948, 0.06056469035684131, 0.013920181954745203, 0.04258378430677112, 0.13082476827548817, 0.022663681629637722, 0.04522257200733293, 0.0841588934417814, 0.0438656700134743, 0.047495169201283716, 0.05316296585078817, 0.015295307384803891, 0.06086773893912323, 0.010771344914246583, 0.03462924883933738, 0.06309808566584252, 0.08547671022824943, 0.05260782825644128, 0.07110317994374782, 0.03109256078460021, 0.03412497433600947, 0.020168390037724748, 0.05313867535733152, 0.05554192393901758, 0.05910816616960801, 0.0215036194640561, 0.013328561308298958, 0.06652024734648876, 0.026481209497433156, 0.07589648914290592, 0.041458439809503034, 0.05666109005687758, 0.01711436329060234, 0.021888901719648857, 0.0369198097178014, 0.04072402531164698, 0.047129138256423175, 0.013664800590049708, 0.057084444488282315, 0.014272513781179441, 0.04983685663319193, 0.02788364225125406, 0.06756877584848553, 0.02803625935484888, 0.04999398413929157, 0.05722547852201387, 0.05251467759080697, 0.016428733870270662, 0.04886165232164785, 0.030881421625963412, 0.021374534007918555, 0.0723000786092598, 0.055936857825145125, 0.043583509177551605, 0.019311927499074955, 0.0591159364557825, 0.04531937403953634, 0.01466612571675796, 0.0627085026644636, 0.012393966389936395, 0.08043007634114474, 0.057762544820434414, 0.01413243897331995, 0.040839232606231235, 0.037819663775735535, 0.03607404709327966, 0.03170894968206994, 0.026853335330088157, 0.029615640523843467, 0.0345144905440975, 0.08884899958502501, 0.054942598872003146, 0.0037588951863654074, 0.036448037571972236, 0.04927065361698624, 0.051409352527116425, 0.038015245663700625, 0.04000636108685285, 0.059576357452897355, 0.047086056583793834, 0.02122642359609017, 0.02809192599670496, 0.026577193311823066, 0.037016763890278526, 0.01945930689544184, 0.13431896280962974, 0.16469762020278722, 0.1499064834206365, 0.22350560990162194, 0.1687668455997482, 0.14838383387541398, 0.10309914781828411, 0.14090205018874258, 0.135073296551127, 0.045083905424689874, 0.100063734134892, 0.1399952793144621, 0.08350829710252583, 0.24868878826964647, 0.10476849027327262, 0.08385012290091254, 0.1009155267092865, 0.10544218224822544, 0.19728894636500627, 0.12264290926395915, 0.07309737527975813, 0.1535357191460207, 0.12049854776705615, 0.13133447529980913, 0.17328553047263995, 0.16673450387315825, 0.24987898534163833, 0.11455134736024775, 0.1799708412727341, 0.11759395245462656, 0.11045807637856342, 0.20742941473145038, 0.07143905371776782, 0.14604326337575912, 0.1794463803526014, 0.29880922695156187, 0.20304355944972485, 0.11885366649948992, 0.1102594034455251, 0.13880327140213922, 0.09650643478380516, 0.11037166812457144, 0.270568904816173, 0.10052793266368099, 0.1510944837355055, 0.16767216293374076, 0.09595180556061678, 0.20939834736054763, 0.19846343959216028, 0.13491585734300315, 0.09828820519032888, 0.105919487104984, 0.11264640270383097, 0.1623741487856023, 0.18814662209479138, 0.08845260366797447, 0.12865352618973702, 0.10880016299779527, 0.16373214544728398, 0.09345862723421305, 0.1512566875317134, 0.14544770470820367, 0.1335476932581514, 0.11266671528574079, 0.2629954065196216, 0.08342595581780188, 0.09707819277537055, 0.15185444295639172, 0.1931661379057914, 0.14946520241210237, 0.16249030973995104, 0.15600558661390096, 0.127799239999149, 0.29098004393745214, 0.08274871637695469, 0.14607054472435266, 0.1502114615868777, 0.20549019769532606, 0.13495942141162232, 0.2294775386690162, 0.15580260922433808, 0.16850050364155322, 0.17032562289386988, 0.14419433602597564, 0.16345946554793045, 0.14277092646807432, 0.18235729134175926, 0.21775406930828467, 0.390580982202664, 0.5310049408581108, 0.3412532462971285, 0.2459750510752201, 0.2008889860007912, 0.13604914653114974, 0.14695099904201925, 0.2953765861457214, 0.17905543179949746, 0.1410488915280439, 0.25641276442911476, 0.09027588981552981, 0.10803886048961431, 0.16880086564924568, 0.18373443541349843, 0.2361480362014845, 0.1630259770900011, 0.22620840783929452, 0.24903522280510515, 0.2300350251607597, 0.16423324355855584, 0.2062744103022851, 0.14934494480257854, 0.10650903437635861, 0.17274273850489408, 0.1453429282992147, 0.18532364076236263, 0.09952066757250577, 0.17294331133598462, 0.19647068402264267, 0.16624934709398076, 0.08336731872987002, 0.1120950908807572, 0.09931542663252912, 0.18133332050638273, 0.09991284809075296, 0.07720342604443431, 0.10059879292384721, 0.12260993564268574, 0.14712553733261302, 0.1813547537312843, 0.14563085191184655, 0.16559572279220447, 0.147354252403602, 0.12169468944193795, 0.13747755816439167, 0.07766915339743719, 0.11537847836734727, 0.1752975076669827, 0.22997489635599777, 0.09943607758032158, 0.14458837191341445, 0.12516357674030587, 0.17273938399739563, 0.1962031694711186, 0.18176346929976717, 0.15441744995769113, 0.1100298720120918, 0.14427658083150163, 0.18765431101201102, 0.11510869284393266, 0.13805448892526329, 0.0911280386208091, 0.16182432125788182, 0.17991938075283542, 0.11078385694418103, 0.2014386947848834, 0.11378260111087002, 0.2572434354806319, 0.1534848375013098, 0.12981154373846948, 0.16699685307685286, 0.1513143375632353, 0.20858713542111218, 0.17903402826050296, 0.10318577871657908, 0.14710888353874907, 0.144495558924973, 0.23013362690107897, 0.1282393781002611, 0.16146028297953308, 0.15470941085368395, 0.11229119598283432, 0.1665779552422464, 0.11596411452046596, 0.13486890908097848, 0.1586134490207769, 0.14458743680734187], [0.06392816299921833, 0.09231779040419497, 0.029134526594134513, 0.0998570460069459, 0.02143061996321194, 0.037775402088300325, 0.02450264564686222, 0.014521162011078559, 0.06511954750749283, 0.03253382084949408, 0.05095827887998894, 0.08133367082336918, 0.08215766254579648, 0.02396552183199674, 0.04431323701282963, 0.041120217138086446, 0.019558704589144327, 0.06192971886775922, 0.04913694458082318, 0.018793509516399354, 0.016760351427365094, 0.02167258793633664, 0.026788276809384115, 0.05904510217078496, 0.08500634445226751, 0.02278363681398332, 0.008295927109429613, 0.03458704290096648, 0.049459886431577615, 0.046703928455826826, 0.06521130664623342, 0.03829678309557494, 0.05206443885981571, 0.01709961496089818, 0.017927306289493572, 0.03807600529398769, 0.019609428527473938, 0.05211702002270613, 0.03946971039113123, 0.03111855450697476, 0.031417170612257905, 0.06812592095229775, 0.03445528942393139, 0.01950058329384774, 0.055728904335410334, 0.018390818331681658, 0.005133363119966816, 0.04433032125234604, 0.04166299426287878, 0.05819448590045795, 0.012703908596449764, 0.022392406244762242, 0.012512653429439524, 0.047183956994558685, 0.023938667218317278, 0.018391573466942646, 0.037227882639854215, 0.0322473407140933, 0.007610097773067537, 0.06867060539661907, 0.034183963944087736, 0.09046407620189711, 0.030363467485585716, 0.05641229246975854, 0.0065021348382288124, 0.06995277683017775, 0.07100290094967932, 0.04675200107158162, 0.021397384734882507, 0.007716119598626392, 0.004396907252157689, 0.03146511335216928, 0.06511758081614971, 0.036007443050039, 0.07898517418652773, 0.022431797588069458, 0.34364420862402767, 0.12434495074558072, 0.17526319075841457, 0.14620088069932535, 0.17216337349964306, 0.20139689702773467, 0.3912483510794118, 0.958581391023472, 1.1148725263774395, 0.552318828413263, 0.1259730223682709, 0.8380846912041306, 2.2792331222444773, 4.257666785269976, 1.3787544728256762, 0.5610084277577698, 0.7500132545828819, 0.5673401348758489, 0.17611930263228714, 0.30072684749029577, 0.3375043615233153, 0.41698564658872783, 0.4055087186861783, 0.03087256965955021, 0.009594315397407627, 0.03930510574718937, 0.0733002413471695, 0.07298125143279321, 0.04268404474714771, 0.0914537301287055, 0.08678585872985423, 0.01656182877923129, 0.024475789177813567, 0.010228414721495938, 0.08855606647557579, 0.04298659609048627, 0.008212714728870196, 0.022676754560961854, 0.09223788336385041, 0.060831310620415024, 0.01296363430810743, 0.013008837595407385, 0.019367963359400164, 0.06935643148608506, 0.03759344974241685, 0.024502378473698627, 0.06828707832028158, 0.05063417185738217, 0.028920608092448674, 0.046446343840216286, 0.04428215586813167, 0.12295295629883185, 0.07968470774358138, 0.07923949335236102, 0.0675250262429472, 0.0547936609655153, 0.0209805537815555, 0.029844993841834366, 0.023745077996863984, 0.05277383927023038, 0.06785259538446553, 0.03720488719409332, 0.022039808172849007, 0.009998736713896506, 0.04439458381966688, 0.014609541594836628, 0.07258928613737226, 0.029651694057974964, 0.04225083459459711, 0.04069138565682806, 0.03739433152077254, 0.03754216362722218, 0.05856857656908687, 0.03301444310636725, 0.050356979700154625, 0.042949392227455974, 0.06424871884519234, 0.01846740055043483, 0.020801718455913942, 0.05187612259760499, 0.08001572045031935, 0.018341916365898214, 0.07845352185540833, 0.01688367781753186, 0.04425830324180424, 0.09035267983563244, 0.005090589438623283, 0.009002002698252909, 0.02778652295091888, 0.04643141925043892, 0.06505280616693199, 0.03428455092944205, 0.045662053307751194, 0.026631138171069324, 0.05045317688200157, 0.03770605952013284, 0.09788661423954181, 0.049299500897177495, 0.0218382761158864, 0.04492724176088814, 0.04625817229680251, 0.04931578732794151, 0.04545894975308329, 0.06553751023602672, 0.003382721401976596, 0.007224794180729077, 0.01503787119872868, 0.05225238775892649, 0.0634221667132806, 0.014863988781144144, 0.049758793829823844, 0.03722361900145188, 0.09756837389431894, 0.07300733050215058, 0.020684963783423882, 0.027489190761116333, 0.00807367892775801, 0.027187199739273638, 0.053251530043780804, 0.05042773605964612, 0.021057312260381877, 0.07579919358249754, 0.01599829749466153, 0.07978989975526929, 0.04593323035805952, 0.07446881223586388, 0.012446967793948716, 0.011294888354314025, 0.021310488518793136, 0.023250633239513263, 0.04135439441597555, 0.008476433195028221, 0.025101263818214647, 0.06264927927986719, 0.041039174611796625, 0.04697951386333443, 0.010065371370728826, 0.024277197881019674, 0.015598443169437815, 0.019748510712815914, 0.021867093710170593, 0.06652766882325523, 0.06130090456281323, 0.05113667262776289, 0.043728012751671486, 0.03576895389414858, 0.031274537250283174, 0.04940087084833067, 0.005235891285337857, 0.011228049606870627, 0.07754859150736593, 0.08046750284847803, 0.03314939152915031, 0.011137316487292992, 0.07289915505680256, 0.018084621187881567, 0.027144207124365494, 0.01411372200891492, 0.028769714626832865, 0.05582426289038267, 0.042733397567644715, 0.051119543859385885, 0.0357844202517299, 0.03685654162836727, 0.06138326811196748, 0.05454406185890548, 0.057999108103103936, 0.03101493770373054, 0.04869433141720947, 0.03903966549842153, 0.05427415388112422, 0.010767068288259907, 0.05738963416661136, 0.010766912437247811, 0.248713368200697, 0.09603977232472971, 0.37820679775904864, 0.1176443145959638, 0.04325530549976975, 0.05115825799293816, 0.16003975295461714, 0.4591962159611285, 0.7193227764219046, 2.169870240613818, 2.8486434929072857, 1.6953806765377522, 0.7757845404557884, 2.1467425441369414, 4.694554517045617, 8.812088146805763, 2.7685547154396772, 1.9175953650847077, 1.3439338537864387, 0.39866377192083746, 0.08751682224101387, 0.12433062729542144, 0.11153742627357133, 0.22984169569099322, 0.37663359311409295, 0.2553809416713193, 0.06909925505169667, 0.0329618693649536, 0.12622872192878276, 0.05004826110962313, 0.06273264472838491, 0.05713079903216567, 0.032452110390295275, 0.058062546886503696, 0.04602860746672377, 0.04831349833693821, 0.05159906031622086, 0.019756922956730705, 0.06203470678883605, 0.026569445290078875, 0.01942942246387247, 0.017958463504328392, 0.013943119884061161, 0.022087474462750833, 0.04164825521002058, 0.011845583267131587, 0.02207622535934206, 0.01892937820230145, 0.026616022478265222, 0.0277891742734937, 0.054476073710247874, 0.05907167476834729, 0.008307932275783969, 0.048165833213715814, 0.053990456799510866, 0.016332481027347967, 0.038498524809256196, 0.041888725900207646, 0.08136744596413337, 0.017884608678286895, 0.03918665155651979, 0.03000153876200784, 0.13931658526416868, 0.011642014942481183, 0.036670629924628884, 0.024374183594773058, 0.01177862484837533, 0.022023955898475833, 0.05872667628864292, 0.04676647295127623, 0.024380356408073567, 0.059634987119352445, 0.03219883765268605, 0.083102980570402, 0.01620438077225117, 0.032948622028925456, 0.022728719741280656, 0.031385417823912576, 0.05940455026575364, 0.023895802623883355, 0.06628727234783582, 0.08389399125007913, 0.03590788022847846, 0.06515386441606097, 0.05691654841939453, 0.04045611000037752, 0.03672594961244613, 0.007021132159934496, 0.029669756077055354, 0.01689357992290752, 0.04899052997643594, 0.027338367799529806, 0.018237820877402555, 0.04805261116416659, 0.03342809766763821, 0.01461812174966326, 0.057313478682772256, 0.047848943577264436, 0.030330683111969847, 0.02920741662819637, 0.02680642417544732, 0.010930696080322377, 0.12496601702878252, 0.18787938955938444, 0.12735984404571354, 0.17581108870217577, 0.09672993255662732, 0.11413722153520212, 0.13433281128527597, 0.19626006251201034, 0.19015233556274325, 0.205043766181916, 0.14262889424571767, 0.17098361102398485, 0.22649284335784614, 0.18486120854504406, 0.09052131063072011, 0.10032071761088446, 0.08437799027888104, 0.20498853555181995, 0.25593022000975907, 0.1602971149259247, 0.12314651583437808, 0.17885180131997913, 0.13105189515044913, 0.23558669054182246, 0.13793435005936772, 0.1601447371649556, 0.10626191404298879, 0.12903932423796505, 0.15565462497761473, 0.18743438296951354, 0.15375910559669137, 0.24927597551140934, 0.1487442950019613, 0.18280963035067543, 0.12396543868817389, 0.14618361834436655, 0.10222600365523249, 0.1883848663419485, 0.10132976385648362, 0.1111601926095318, 0.1583541723084636, 0.1454266277141869, 0.13693004613742232, 0.11855170887429267, 0.1281565395765938, 0.15294214943423867, 0.06606734430533834, 0.12659612955758348, 0.11697768786689267, 0.0958763959351927, 0.14436033961828798, 0.1402514093206264, 0.17033435055054724, 0.10460596735356376, 0.13123124255798757, 0.1546372740995139, 0.09860424135695212, 0.11696225861669518, 0.10239747687592171, 0.13118003436829895, 0.15401519107399508, 0.1425778493285179, 0.11579332407563925, 0.13013669347856194, 0.1872793334769085, 0.23752445296850055, 0.34412719833198935, 0.14426172303501517, 0.16802962578367442, 0.19112757698167115, 0.2829425549134612, 0.11472469079308212, 0.11906488172826357, 0.10934743753750809, 0.31355225772131234, 0.32593721814919263, 0.45053006848320365, 0.2363298475393094, 0.17931132431840524, 0.28125921555329114, 0.23536642111139372, 0.4135211231186986, 0.6614245113451034, 1.8450850434601307, 2.6838102377951145, 1.325623111333698, 0.5202479555737227, 2.0869651017710567, 4.839151008054614, 9.361224230378866, 2.869829018600285, 1.6277085640467703, 1.4796936814673245, 0.6357814685907215, 0.18719199753832072, 0.3647448029369116, 0.36577068851329386, 0.6432514521293342, 0.8282951696310192, 0.2846179681364447, 0.15729831880889833, 0.1428261274122633, 0.20769191236468032, 0.19365847867447883, 0.2457579135079868, 0.15047624503495172, 0.20676494023064151, 0.17937569820787758, 0.06657765246927738, 0.1969929481856525, 0.11116180306999013, 0.1511696187662892, 0.16240102937445045, 0.17143137840321288, 0.1329390876344405, 0.14915078412741423, 0.07453919752151705, 0.1541989468387328, 0.07404223317280412, 0.1730493493960239, 0.0641496866592206, 0.21428399457363412, 0.13446700642816722, 0.13017874356592074, 0.23383333696983755, 0.20247326348908246, 0.09495220685494132, 0.1499774178955704, 0.12748228356940672, 0.1283854476059787, 0.21779724746011198, 0.13263927481602877, 0.14688079187180847, 0.12676845624810085, 0.1197219718596898, 0.16020543000195175, 0.22765031171729788, 0.09546148343360983, 0.10429042100440711, 0.08526179910404608, 0.08241330273449421, 0.10524263358092867, 0.13068012369330972, 0.23958599078468978, 0.12587149656610563, 0.17993760789977387, 0.08331136821652763, 0.17517094180220738, 0.12489094136981294, 0.13985792262246832, 0.11743532581022009, 0.143667648662813, 0.180296866747085, 0.11202982641407289, 0.12229341708007269, 0.2280390783562325, 0.1525858443346806, 0.1446359435794875, 0.1440249927691184, 0.08683112973812968, 0.13842542917700484, 0.21063549269456416, 0.07542691746493801, 0.08718045122805052, 0.09139170142589137, 0.1464989420492202, 0.11107169892056845, 0.19535774452378973, 0.13237538194516674, 0.11672624823404476, 0.10930787364486605, 0.11733731778804213, 0.2062643616227433, 0.12462885933928192, 0.08208073151763529, 0.08183541460311972], [0.03929377686290536, 0.020753421340486966, 0.01715257461910369, 0.013684503683180083, 0.030654868060082663, 0.05086293887870852, 0.016377301180909853, 0.05805653549032286, 0.08663190761581063, 0.06767990504158661, 0.03714707760082092, 0.042938720143865794, 0.0209551018269849, 0.02492004248779267, 0.015426393856614595, 0.02714110494707711, 0.008549293543183012, 0.019190699531463906, 0.025793411150516476, 0.05538020996027626, 0.030663130019092932, 0.06164585109218024, 0.009771697041287553, 0.0023458508803742006, 0.017391609253536444, 0.022049079452699516, 0.09596336079994217, 0.039571666638948955, 0.006002723721394432, 0.07656952802790329, 0.08190056032617576, 0.09277663804823533, 0.04087778717803303, 0.038001541906851344, 0.029388168550212868, 0.035791429836535826, 0.027675063502101693, 0.05592204826825764, 0.06584023227333091, 0.02062409283098532, 0.0345466478029266, 0.04202517346129753, 0.042203904886264354, 0.03581648474209942, 0.02873533834645059, 0.01299906072745216, 0.004155455999352853, 0.018438532861182466, 0.02878347961086547, 0.03259970500948839, 0.016918417750275694, 0.02904834098444553, 0.06634453646256588, 0.04901769629213959, 0.03364002535818145, 0.016915746018639766, 0.05440266788355075, 0.011795941936725285, 0.004760082783832331, 0.047058263153303415, 0.015026702803879743, 0.08257109075202607, 0.06707616048515774, 0.03495227974781301, 0.035741932297241874, 0.06636051490204409, 0.03133223181066569, 0.015404954137920868, 0.3255656693363562, 0.2269626673660241, 0.09030613233335316, 0.05009055610571522, 0.10717446624767035, 1.25310329021886, 2.5190415792167187, 3.549885177053511, 12.312993239611387, 37.47993864119053, 33.04234676063061, 46.76480881869793, 55.17483294010162, 57.66974486410618, 67.47712880373001, 80.81026375293732, 86.25491559505463, 82.3961390554905, 75.27798861265182, 78.4080022573471, 96.15349844098091, 104.65230479836464, 95.77055498957634, 82.62216612696648, 67.25846573710442, 54.32619787752628, 45.30450917780399, 36.1885741353035, 36.565126329660416, 21.52423571795225, 11.73273777589202, 2.35467997379601, 0.4743205918930471, 0.31346492178272456, 0.37676578445825726, 0.3081843926338479, 0.23131264722906053, 0.016557578128413297, 0.03161793269100599, 0.03556755727913696, 0.013658935768035008, 0.07923611658043228, 0.045744702583760954, 0.04341593594290316, 0.023114410178095568, 0.163617453945335, 0.07157471089158207, 0.0476799528405536, 0.0168280297293677, 0.014230043452698737, 0.08190682405256666, 0.026186684481217526, 0.049083973790402524, 0.062381319439737126, 0.027452198410173878, 0.00961329953497625, 0.017068357556127012, 0.0817791820736602, 0.04413998263771646, 0.031564965611323714, 0.06079538325138856, 0.08001879294170067, 0.058646464967750944, 0.01691391476924764, 0.018354219319007825, 0.03449508338235319, 0.01863178997155046, 0.026711397731560282, 0.05285421386361122, 0.028949525876669213, 0.03959493667935021, 0.06431029483792372, 0.022572783382202033, 0.04086440254468471, 0.023154456466727424, 0.03538933422532864, 0.04179972755082417, 0.05087745528726373, 0.012428459558577742, 0.03836062634945847, 0.06105385844421107, 0.03257299140386749, 0.029890322366554756, 0.005948076604909147, 0.035606486635515466, 0.01947468233993277, 0.023851186560932547, 0.0710912758950144, 0.0077848703040217515, 0.053063959639985114, 0.06587011113879271, 0.013185388961574063, 0.03528736313455738, 0.07031351255136542, 0.03588862520700786, 0.03760640393011272, 0.024410728801740333, 0.03155829370371066, 0.04364847678516526, 0.035367708042031154, 0.031222460747812875, 0.041153290949296206, 0.03880647156620398, 0.011908534088433953, 0.08649118157336488, 0.027432871029304806, 0.04163382785918657, 0.06712365051498637, 0.049953674388234504, 0.04051106603583321, 0.016419740895798896, 0.025672493029560428, 0.03546225394529756, 0.047390808394993655, 0.038990052926237695, 0.022561508303624578, 0.04027639522973914, 0.06320819811662659, 0.010120089918927988, 0.027591944817686453, 0.04048689799674321, 0.06348326031002216, 0.017882072388601955, 0.01639371748751728, 0.03787797431868967, 0.045445242285495624, 0.023709846391284373, 0.03609908715588972, 0.04740268275782, 0.04805009528354276, 0.04827785669476725, 0.02509856796677923, 0.051952923749922775, 0.017220451445609797, 0.017574036573932972, 0.06760967560694553, 0.1300707462360151, 0.05423763650469482, 0.07076948808389716, 0.07291513349628076, 0.10776727896882221, 0.030641297889815178, 0.04736341201351024, 0.04373733412649017, 0.0249195934884483, 0.033771912421798334, 0.024693693012523, 0.04248914934578352, 0.038495619301102124, 0.04027859940833878, 0.08193794972612523, 0.029172797294449992, 0.06737324962159619, 0.036560625085257925, 0.050622965427464806, 0.026746538424049504, 0.02820588091708487, 0.0223647723760223, 0.015394426773127634, 0.02622696825710591, 0.03418354463065043, 0.04634826160327066, 0.029364481051743496, 0.012956189639226068, 0.031108223811315838, 0.027089792856713757, 0.027279977475700434, 0.04813008024939336, 0.024825739637890365, 0.06430223511415534, 0.022088359473855235, 0.017200355941895396, 0.021435540402308106, 0.03153669720632024, 0.008663748485560063, 0.06762493416317739, 0.27215146052185446, 0.1042794001114089, 0.12824279197957367, 0.08403602347243577, 0.21106139640323818, 3.3307309867814183, 4.922754596918821, 8.834722582250834, 22.073845826089382, 57.25698061287403, 50.906225591897964, 68.71509477496147, 77.55961418151855, 81.43121883273125, 94.41348820924759, 106.75699666142464, 114.66128692030907, 107.55398109555244, 100.25522634387016, 103.06627750396729, 120.038211196661, 130.82359045743942, 119.96247366070747, 106.66996613144875, 92.52994447946548, 83.04947599768639, 71.78836986422539, 60.82524374127388, 59.828709214925766, 40.72526849806309, 24.130358174443245, 5.335512198507786, 0.7199490303173661, 0.06630435658735223, 0.23646046553039923, 0.3883375885197893, 0.2597871911711991, 0.07660188566660509, 0.05077292378700804, 0.06527114601340145, 0.030105272453511134, 0.0834386094356887, 0.03902287069649901, 0.09422502087545581, 0.07611029446707107, 0.04984003673598636, 0.03789321803196799, 0.014205656480044127, 0.01982207610126352, 0.03446462935244199, 0.026451282392372377, 0.0561609715805389, 0.017523787610116415, 0.06901063519762829, 0.022819547484687064, 0.04969671317667235, 0.02083041730656987, 0.04875459380855318, 0.08467756561003625, 0.019764832395594567, 0.023697111137153115, 0.07899387215729803, 0.019574460384319536, 0.04114429611945525, 0.025386677116330247, 0.030221951055864338, 0.05389805570302997, 0.056774208205752075, 0.05597955358098261, 0.03153906094667036, 0.034481357361073606, 0.037955640073050745, 0.015836218008189462, 0.050014990629279055, 0.06823142466600984, 0.04414735587488394, 0.03903217722836416, 0.04804826960025821, 0.002028850385613623, 0.04558705186354928, 0.045575103285955265, 0.054522402278962545, 0.04636068144463934, 0.043666755882441066, 0.03223369632905815, 0.026031288034573663, 0.016441899570054375, 0.07714503386523575, 0.045361824886640534, 0.03284760830865707, 0.03856048671877943, 0.0038795628324805875, 0.027849254838656634, 0.12015676649753004, 0.03156214916089084, 0.0666003325022757, 0.03774452874495182, 0.03262371348682791, 0.040282866757479496, 0.033303954915027134, 0.03490394738037139, 0.012031712976749986, 0.06707059437758289, 0.03641047005658038, 0.046452217939076945, 0.00329423490256886, 0.04552684513328131, 0.048161038939724676, 0.12079251988325268, 0.09342529738205485, 0.1921587614924647, 0.11032844544388354, 0.1523447353974916, 0.19669729139422998, 0.12378408006043173, 0.1471983568626456, 0.1196404395159334, 0.12375274658552371, 0.10089986739330925, 0.12270697887288406, 0.11130134167615324, 0.09362327269627713, 0.11327202577376738, 0.10153588053071871, 0.11945332182222046, 0.11132102343253791, 0.13150591141311452, 0.09972334810299799, 0.12162924685981125, 0.16396112769143656, 0.15687756560510024, 0.10803159486385994, 0.13164243689971045, 0.12023767543723807, 0.14590203267289326, 0.23866863688454032, 0.18479923921404406, 0.15561367326881737, 0.14981349231675267, 0.19178057787939906, 0.20589827501680702, 0.09084185163374059, 0.15416758367791772, 0.1604017280624248, 0.10967746318783611, 0.19225567113608122, 0.09073232547962107, 0.11820926709333435, 0.07069286875776015, 0.14757683733478189, 0.15086772793438286, 0.12721810868242756, 0.18175995151977986, 0.12675647798459977, 0.10839342896360904, 0.14799454773310572, 0.14607961376896128, 0.10541814408497885, 0.15038729121442884, 0.13133877975633368, 0.13856490841135383, 0.14861330593703315, 0.12039838751661591, 0.13134729961166158, 0.12125224326155148, 0.16643587849102914, 0.1604056466021575, 0.2502474171342328, 0.19294387951958925, 0.16427352733444422, 0.14562495925929397, 0.10384672801592387, 0.09699088652268983, 0.24761776527157053, 0.15701418014941737, 0.0646617537131533, 0.5676087329629809, 0.5559832567814738, 0.2845200046431273, 0.1852725216303952, 0.2125209485529922, 3.2321324525400996, 5.183164123445749, 9.358925353735685, 22.413735687732697, 59.22275573015213, 55.348225235939026, 69.41988855600357, 81.27778306603432, 88.74755144119263, 102.56114020943642, 121.64936274290085, 125.76274082064629, 112.62919396162033, 108.83016541600227, 114.49746251106262, 132.72985696792603, 145.95968306064606, 134.7276073694229, 117.93116346001625, 103.43990385532379, 91.99138417840004, 75.24549275636673, 62.232942804694176, 62.38106265664101, 44.32779058814049, 25.25450125336647, 5.1424402836710215, 0.64937618910335, 0.3068150707986206, 0.5551468266639858, 0.5636568262707442, 0.4470808629412204, 0.17508170596556738, 0.17240899469470605, 0.13974511617561802, 0.06962499988730997, 0.37821184436324984, 0.13766236777883023, 0.16409965697675943, 0.16732946882257238, 0.32065155333839357, 0.11554523152881302, 0.09631053006160073, 0.09906911524012685, 0.1578865450574085, 0.19040214247070253, 0.08934307697927579, 0.09051495042513125, 0.25022206536959857, 0.08889529475709423, 0.19115267641609535, 0.14705705194501206, 0.29314221697859466, 0.12162214450654574, 0.12152286741184071, 0.11948620638577268, 0.1984261689358391, 0.10712401504861191, 0.14026322431163862, 0.10579766356386244, 0.2068871125811711, 0.14670052420115098, 0.25287839001975954, 0.13903522223699838, 0.10768933119834401, 0.10403784588561393, 0.2233059424906969, 0.10762727280962281, 0.12279497532290407, 0.10583336828858592, 0.08903209483833052, 0.14323298761155456, 0.1667917679878883, 0.19154546549543738, 0.07313866095500998, 0.13402205921011046, 0.15519510197918862, 0.08281861926661804, 0.08000775720574893, 0.17895778000820428, 0.07082853335305117, 0.07462035879143514, 0.2053390964283608, 0.0855139883060474, 0.12013919244054705, 0.13878084369935095, 0.09190124517772347, 0.0806581976939924, 0.34792729129549116, 0.13569561706390232, 0.1483395425020717, 0.09273418720113114, 0.1204486086498946, 0.13108846818795428, 0.1832182123325765, 0.14399734034668654, 0.10704945889301598, 0.16374597907997668, 0.12019723581033759, 0.20829011307796463, 0.10442337676067837, 0.12017454093438573, 0.1386822122731246], [0.01484437845647335, 0.06558120789122768, 0.03116489235253539, 0.026800318155437708, 0.024279125609609764, 0.03918617658200674, 0.054058519162936136, 0.007251094502862543, 0.014810264710831689, 0.028105954443162773, 0.03718216634297278, 0.04329394541855436, 0.05685217081918381, 0.06427725442335941, 0.041557512813596986, 0.008085224890237441, 0.035003435987164266, 0.0981946055253502, 0.06868825366836973, 0.06534644431667402, 0.037337282628868707, 0.04630816707503982, 0.027827613812405616, 0.020759236067533493, 0.01595657395228045, 0.06242962583201006, 0.10611093894112855, 0.06851613477920182, 0.03482324995275121, 0.04150334345467854, 0.12338423315668479, 0.005978224498903728, 0.08376165147637948, 0.034489847530494444, 0.00988296353170881, 0.022728532348992303, 0.019829504999506753, 0.064658013288863, 0.04934483869874384, 0.06033924815710634, 0.018997917395608965, 0.10522963857511058, 0.044907066476298496, 0.02130982615199173, 0.08904169080778956, 0.03209773487469647, 0.03349433063704055, 0.04077246157976333, 0.030866745655657724, 0.036757468624273315, 0.013518416599254124, 0.02781113998935325, 0.01667689321038779, 0.021384219035098795, 0.03405306764761917, 0.030099270334176254, 0.010991643102897797, 0.04450733460544143, 0.053936302283545956, 0.059936811157967895, 0.07274394971318543, 0.005448619567687274, 0.036104141181567684, 0.0866592483362183, 0.05497540551004931, 0.07718213382759131, 0.08338597632246092, 1.0067655961029232, 7.3216599225997925, 18.60210321843624, 29.19717349112034, 56.3162574917078, 61.2139742821455, 81.35522291064262, 79.5394067466259, 92.95161545276642, 114.89818900823593, 119.01787474751472, 119.25082504749298, 115.46716287732124, 113.83879825472832, 113.82188156247139, 113.99876967072487, 101.55995473265648, 101.43067806959152, 109.06911179423332, 114.04703468084335, 117.6249834895134, 108.93782883882523, 109.73790630698204, 120.73928877711296, 119.51836109161377, 119.37592193484306, 124.9378202855587, 125.15798807144165, 128.96804362535477, 127.97954946756363, 120.07721230387688, 109.22746449708939, 89.09143298864365, 59.98058706521988, 36.752133294939995, 23.282186686992645, 7.965399054810405, 2.9346666019409895, 0.9489223686978221, 0.530283513944596, 0.3133161657024175, 0.05105639451358002, 0.009739192828419618, 0.03957287633966189, 0.04974697883881163, 0.04533659928711131, 0.014406976097234292, 0.05611034968751483, 0.023395162788801827, 0.0805333536118269, 0.03166356364090461, 0.03591895307181403, 0.029811428357788827, 0.029517287402995862, 0.008855967516865348, 0.07998553730431013, 0.021311783566488884, 0.07550360358436592, 0.01967004714970244, 0.015801934496266767, 0.00942645736358827, 0.10078248189529404, 0.05880076118046418, 0.10183804595726542, 0.09145622374489903, 0.008128198023769073, 0.02838958658685442, 0.011744968451239401, 0.007820062946848338, 0.06642770895268768, 0.007871507696108893, 0.029738775810983498, 0.07659931041416712, 0.024300323202623986, 0.055537330044899136, 0.07676559602259658, 0.04028969822684303, 0.04897562765108887, 0.0413977395510301, 0.01314621376877767, 0.021546313364524394, 0.039175857018562965, 0.011197858111700043, 0.028928309729963075, 0.05486813919560518, 0.055086709107854404, 0.09300271107349545, 0.014102925615588902, 0.018588441125757527, 0.018909930222434923, 0.08527518744813278, 0.07896983399405144, 0.039449520263588056, 0.08760035096202046, 0.05000371369533241, 0.07249061760376208, 0.02107808497385122, 0.06653168384218588, 0.06093648407841101, 0.047135724817053415, 0.02171883672417607, 0.037903552438365296, 0.03652413739473559, 0.024076675144897308, 0.06083052394387778, 0.05277432908769697, 0.03188694638083689, 0.050260125717613846, 0.025964387132262345, 0.01754169748892309, 0.04350073002569843, 0.017443505785195157, 0.058972297483705916, 0.09299580910010263, 0.010590893562039128, 0.0080844595504459, 0.025568924465915188, 0.052878983042319305, 0.020662404349423014, 0.017900099155667704, 0.041552150796633214, 0.05384869175031781, 0.04514675048994832, 0.03335129651532043, 0.013138561298546847, 0.06349157978547737, 0.06331068128929473, 0.06023418973200023, 0.060001786187058315, 0.04586324212141335, 0.03245998086640611, 0.09321847566752695, 0.03415809267607983, 0.062043126454227604, 0.016096183062472846, 0.0486188772629248, 0.047809902898734435, 0.03894164263329003, 0.05789237984572537, 0.052448411224759184, 0.0311619905551197, 0.03737673891009763, 0.04075683937116992, 0.03074196651141392, 0.035478725912980735, 0.013135144636180485, 0.04539176312391646, 0.053212904967949726, 0.06822622221079655, 0.021091152339067776, 0.05974067265924532, 0.040462069446220994, 0.03246142434363719, 0.10864236013730988, 0.012396903439366724, 0.024724325157876592, 0.07524175161961466, 0.001302665957609861, 0.03355021064635366, 0.01417560042682453, 0.035177818426745944, 0.07944310156744905, 0.02870155392884044, 0.04853920028836001, 0.0805839680833742, 0.03270825523941312, 0.03441626358835492, 0.03199017170118168, 0.07493441342376173, 0.06762272998457775, 0.029930450291431043, 0.04818203058675863, 0.0660243071615696, 0.16220201505348086, 0.05994084473059047, 0.2074065714259632, 1.9304203893989325, 13.659585881978273, 31.367814615368843, 45.49223430454731, 77.6015031337738, 83.46972584724426, 102.77701422572136, 105.55604070425034, 120.29288113117218, 136.80611103773117, 135.48578828573227, 140.5610391497612, 131.53501868247986, 131.41059815883636, 134.5747947692871, 129.2008799314499, 116.36164247989655, 121.93585216999054, 128.03356736898422, 128.27079623937607, 135.3653347492218, 120.10612115263939, 121.38844594359398, 132.46621191501617, 135.67074716091156, 133.14996242523193, 140.76834082603455, 137.6622810959816, 143.06235373020172, 150.08805513381958, 138.87607276439667, 133.23813289403915, 114.86063942313194, 83.30309718847275, 57.265343964099884, 39.15940672159195, 16.35081522166729, 6.6063696797937155, 1.6200867667794228, 0.2338474229327403, 0.2994646324077621, 0.0700934138149023, 0.09554349075187929, 0.008515521185472608, 0.07413356928736903, 0.005209967139307992, 0.10921296779997647, 0.05142186513694469, 0.0368980759230908, 0.014165684406179935, 0.04971267677319702, 0.0037327695008571027, 0.012639861251955153, 0.02039546310697915, 0.019885483343387023, 0.05771506592282094, 0.01741872176353354, 0.10491937631741166, 0.08181396653526463, 0.0019511913569658645, 0.09746353811351582, 0.04603007691912353, 0.06188132341776509, 0.098366791207809, 0.0716617499710992, 0.006453360892919591, 0.02229586025350727, 0.021402668826340232, 0.0387947382114362, 0.07860769561375491, 0.03466764756012708, 0.046110195471555926, 0.05475388556078542, 0.0068558646853489336, 0.03180975931172725, 0.09215084428433329, 0.04055607358168345, 0.04772297885210719, 0.04520870868873317, 0.011872047325596213, 0.02586435861303471, 0.05026676422858145, 0.017263390254811384, 0.019135353868477978, 0.004815270740436972, 0.05596541195700411, 0.06253512212424539, 0.010246008259855444, 0.04815634856640827, 0.02739885097980732, 0.021814124775119126, 0.032791539051686414, 0.05284769409627188, 0.01950062782270834, 0.010803754503285745, 0.042124654646613635, 0.00996747003227938, 0.04194569686660543, 0.0610597844934091, 0.06281577268964611, 0.055246237461688, 0.03805730688327458, 0.005327093813320971, 0.042616320060915314, 0.037075645886943676, 0.02348997957597021, 0.018365043542871717, 0.04065886103489902, 0.053130623055039905, 0.16732681193388999, 0.18238402350107208, 0.08060314517933875, 0.13753335282672197, 0.213217394775711, 0.0992096854315605, 0.24986194563098252, 0.06047435614163987, 0.10156840886338614, 0.12984016095288098, 0.1452798309037462, 0.19023092900170013, 0.1509672647807747, 0.12005953030893579, 0.130501102830749, 0.0763820466818288, 0.15707280981587246, 0.36947783490177244, 0.20865202881395817, 0.23842064081691206, 0.10904377297265455, 0.1330924450303428, 0.19261167937656865, 0.08381864841794595, 0.14811507251579314, 0.14668079791590571, 0.238913441717159, 0.1437629701104015, 0.1061029608536046, 0.24020575830945745, 0.11661652912152931, 0.08284650175482966, 0.11932332723517902, 0.13383055542362854, 0.15104674879694358, 0.09306056148489006, 0.09677288064267486, 0.15438513684784994, 0.18682901310967281, 0.1780086473445408, 0.07917465933132917, 0.21806358941830695, 0.14235961338272318, 0.09632657529436983, 0.26588337030261755, 0.14062156289583072, 0.09227487942553125, 0.23401960119372234, 0.07654689994524233, 0.242047279025428, 0.21037642378360033, 0.21887235227040946, 0.20469028124352917, 0.11955392736126669, 0.06240861563128419, 0.21256713982438669, 0.08594303129939362, 0.14645916293375194, 0.0938796105037909, 0.2027838968206197, 0.16109670483274385, 0.13061365694738925, 0.18309412524104118, 0.24036364280618727, 0.24619968433398753, 0.17658207623753697, 0.22352128406055272, 2.1127087203785777, 13.508182056248188, 33.43505568802357, 48.40412825345993, 84.17321249842644, 88.75795528292656, 114.2409610748291, 116.90174549818039, 134.7238227725029, 152.0631131529808, 153.7698295712471, 154.47571009397507, 147.1229374408722, 146.68310344219208, 145.627079308033, 142.2734096646309, 132.4751642346382, 130.08278220891953, 138.35775017738342, 145.37791907787323, 148.1942367553711, 137.09986567497253, 135.3194636106491, 150.5301994085312, 148.557907640934, 152.3941969871521, 160.5214288830757, 159.65285629034042, 162.7159783244133, 167.0589780807495, 160.5450940132141, 153.51872384548187, 132.79013693332672, 92.98669517040253, 61.131047531962395, 39.410227462649345, 16.26281764358282, 6.824312685057521, 1.3836805522441864, 0.40668484463822097, 0.6390254851430655, 0.12053639729856513, 0.3486287099076435, 0.12408567403326742, 0.17723858007229865, 0.16703629080438986, 0.20896266214549541, 0.288982093334198, 0.1188070818898268, 0.1883658822043799, 0.14820448646787554, 0.11895637973793782, 0.15542822540737689, 0.11534747885889374, 0.13293108728248626, 0.20637525332858786, 0.17734196124365553, 0.23418882570695132, 0.19931622664444149, 0.08790285777649842, 0.28077103081159294, 0.17264443362364545, 0.11568935660761781, 0.1474216690985486, 0.22608570114243776, 0.09646071106544696, 0.16481436003232375, 0.1338307186961174, 0.19510603771777824, 0.16483859857544303, 0.12546333018690348, 0.15338932309532538, 0.14680138207040727, 0.14930586330592632, 0.1509395826724358, 0.15174556989222765, 0.20174589939415455, 0.14395487465662882, 0.14557122776750475, 0.22028011735528708, 0.10177359785302542, 0.1069667910633143, 0.11630389941274188, 0.10948748080409132, 0.09857267039478756, 0.22105307900346816, 0.18313292472157627, 0.15239040716551244, 0.0998939826968126, 0.164034110493958, 0.10065739290439524, 0.17505062482086942, 0.17772712104488164, 0.14555668167304248, 0.13400764670222998, 0.23030712618492544, 0.12790192355168983, 0.09841706429142505, 0.17866522539407015, 0.14931938523659483, 0.15025536704342812, 0.15807310614036396, 0.11597777003771625, 0.1642610740964301, 0.08791217172984034, 0.12242367884027772, 0.22324652614770457, 0.1484887587139383, 0.1502292137593031], [0.016285666351905093, 0.06338854742352851, 0.03717606588907074, 0.027520717194420286, 0.019979301941930316, 0.043973066203761846, 0.06290004355832934, 0.0495448549190769, 0.03665864795038942, 0.032616696480545215, 0.024465734932164196, 0.04044675893965177, 0.08905625174520537, 0.08471208289847709, 0.04830435136682354, 0.021409674700407777, 0.07078463531797752, 0.028444420167943463, 0.05845781844982412, 0.014118734288786072, 0.06568977667484432, 0.030000074875715654, 0.03060794206248829, 0.06909905467182398, 0.06045754278602544, 0.023901331624074373, 0.04311923272325657, 0.029995516233611852, 0.048263021162711084, 0.010099462851940189, 0.01814631963497959, 0.005478984076034976, 0.06565088813658804, 0.04265893418050837, 0.07325592770939693, 0.0345857330103172, 0.027962714375462383, 0.012044278464600211, 0.03923027870769147, 0.038495021872222424, 0.0620257973059779, 0.021833600585523527, 0.07639993244083598, 0.10428824651171453, 0.04535457039310131, 0.09786349633941427, 0.047704336102469824, 0.040471928878105246, 0.0802109795040451, 0.03239329518692102, 0.0854553809040226, 0.018872874788939953, 0.07015230323304422, 0.019077624056080822, 0.06024148875440005, 0.026297886033717077, 0.03715387196280062, 0.00884626022525481, 0.06957223318750039, 0.06362881773384288, 0.04439208278199658, 0.07547371729742736, 0.12219094132888131, 0.5806397774722427, 10.691863428801298, 25.159080773591995, 33.267982453107834, 67.67031043767929, 91.13514572381973, 107.32302188873291, 111.71911999583244, 101.27269014716148, 93.2232628762722, 95.4474127292633, 89.2393210530281, 86.69150456786156, 76.54463544487953, 80.87698057293892, 75.49999549984932, 80.3964051604271, 74.79026958346367, 71.63253262639046, 85.94266355037689, 92.98831388354301, 64.61650550365448, 66.51530161499977, 82.14513212442398, 77.91636943817139, 84.71964597702026, 84.87553641200066, 82.97335848212242, 94.12646681070328, 86.95283934473991, 83.94797578454018, 97.63775199651718, 92.03612297773361, 81.17067441344261, 85.81920057535172, 99.6440215408802, 95.97037866711617, 111.49066105484962, 117.768364995718, 113.66726785898209, 110.71771413087845, 85.31112983822823, 64.06406074762344, 31.715239472687244, 9.312711283564568, 0.8848095370922238, 0.35432056698482484, 0.343673211755231, 0.23214593064039946, 0.15768226148793474, 0.043002433521905914, 0.034688850719248876, 0.023728919586574193, 0.09277401826693676, 0.11993220745353028, 0.022478153987322003, 0.03637115107267164, 0.014618056811741553, 0.030038035729376134, 0.019084694868070073, 0.04814225889276713, 0.008061859298322815, 0.02850833578122547, 0.06605972244869918, 0.02080397644022014, 0.06671022973023355, 0.011470919289422454, 0.01803246675990522, 0.06941185507457703, 0.05314800415362697, 0.03687262025778182, 0.010338837946619606, 0.04719239892438054, 0.03799050617089961, 0.029154655494494364, 0.007825960237823892, 0.024213991018768866, 0.020664532457885798, 0.015274125562427798, 0.04688130175054539, 0.03212100862583611, 0.04485652250878047, 0.013770605801255442, 0.03254006602219306, 0.03279852637206204, 0.043075145440525375, 0.007054342804622138, 0.01175131381387473, 0.0252617087244289, 0.06040232699888293, 0.056988863289006986, 0.0416792139003519, 0.046337815874721855, 0.006927983813511673, 0.028439373563742265, 0.0869059975957498, 0.05397206638008356, 0.016983461428026203, 0.018069414581987076, 0.032880685830605216, 0.029364983856794424, 0.0604138859489467, 0.01915954788273666, 0.057445506754447706, 0.034965092927450314, 0.03075820284720976, 0.06776696638553403, 0.05947144374658819, 0.022109924429969396, 0.04308501600462478, 0.010626541698002256, 0.09923265490215272, 0.039540303478133865, 0.019689524815476034, 0.013615887492051115, 0.052876482004649006, 0.09403247808222659, 0.0276069399114931, 0.05363963246054482, 0.017841289518401027, 0.10665700378012843, 0.03620680989115499, 0.042940660860040225, 0.029772157613479067, 0.02087554916215595, 0.04893180383078288, 0.02781404178676894, 0.029063703441352118, 0.014251929387683049, 0.03471727868600283, 0.049918904769583605, 0.048544109595241025, 0.012396566689858446, 0.03619623057602439, 0.021394041359599214, 0.040619460414745845, 0.001464142681015801, 0.04940427730616648, 0.007490261332350201, 0.01996902319660876, 0.011433643066993682, 0.06896475562825799, 0.024735206898185425, 0.05157263243745547, 0.022021751719876193, 0.08737376585486345, 0.0037634410728060175, 0.08009867029613815, 0.027650695083139, 0.08484085294185206, 0.02084659798128996, 0.074181779200444, 0.021209617661952507, 0.06779377275961451, 0.021417908828880172, 0.02968383090774296, 0.021823169699928258, 0.03645508797490038, 0.05927203608734999, 0.041740986562217586, 0.06441524194087833, 0.07089841397828422, 0.02368707358982647, 0.045508462135330774, 0.06241041162866168, 0.05339887233276386, 0.047347774961963296, 0.04207096768368501, 0.03637463174527511, 0.009541997696942417, 0.016638407287246082, 0.09463478287216276, 0.08872990714735352, 0.07863852442824282, 0.12818310846341774, 0.3160878497874364, 2.3680609557777643, 17.973844930529594, 39.0896500647068, 49.411940574645996, 87.38964110612869, 113.56082037091255, 123.59988927841187, 124.77089524269104, 118.27677011489868, 111.54481574892998, 107.50104993581772, 104.69751477241516, 103.96616041660309, 96.86817169189453, 100.01558840274811, 96.5903913974762, 105.2816954255104, 101.8736506998539, 100.85387662053108, 113.83857026696205, 114.04906377196312, 90.07715329527855, 101.05791047215462, 114.43204522132874, 105.36013841629028, 107.41729483008385, 113.5251022875309, 116.96893349289894, 118.27094122767448, 103.8162812590599, 98.54411736130714, 120.24471491575241, 121.33654072880745, 96.15141615271568, 100.97661003470421, 110.13832122087479, 106.93857371807098, 126.97489857673645, 137.6424005627632, 130.8242592215538, 137.1829292178154, 113.93443912267685, 90.15009418129921, 50.63349522650242, 18.750259168446064, 2.493549222126603, 0.16433091019280255, 0.10213461559033021, 0.14749270747415721, 0.1303192914929241, 0.09424485848285258, 0.031223896803567186, 0.03865957085508853, 0.02787703157082433, 0.18028031685389578, 0.026399489761388395, 0.06058924802346155, 0.046786507227807306, 0.03490972871077247, 0.03071544400881976, 0.033459772530477494, 0.026603574806358665, 0.04559872584650293, 0.051750399070442654, 0.07301346806343645, 0.03973429717007093, 0.03264271988882683, 0.05502071733644698, 0.09192949131829664, 0.015319942049245583, 0.01589324834640138, 0.05549814464757219, 0.03039243536477443, 0.036615113567677327, 0.04813350897165947, 0.034891672257799655, 0.02386480126006063, 0.0657028830028139, 0.019842820984194987, 0.009679855338617926, 0.049660975055303425, 0.038196986497496255, 0.03858036514429841, 0.023061127685650717, 0.06648846116149798, 0.07136929183616303, 0.029848320518794935, 0.054727164533687755, 0.041964154079323635, 0.03116625790426042, 0.02630558767123148, 0.06272714541410096, 0.07900391341536306, 0.015257674931490328, 0.067294856562512, 0.05467385606607422, 0.05443343732622452, 0.03329236256831791, 0.06366842615534551, 0.05212292009673547, 0.05002002239052672, 0.012685556212090887, 0.03250139641750138, 0.03364614807651378, 0.03960360125347506, 0.019595151461544447, 0.030525756628776435, 0.024545821943320334, 0.05137655702128541, 0.05407168486271985, 0.04172127883066423, 0.07558576675364748, 0.0010397149185337184, 0.17209594196174294, 0.1482977150590159, 0.14962099405238405, 0.1293877774151042, 0.11708965568686835, 0.12429988011717796, 0.1030287476896774, 0.20974356477381662, 0.1684761166688986, 0.15557680337224156, 0.09140141613897868, 0.1433953843661584, 0.2385871045407839, 0.1445972776855342, 0.11015321695595048, 0.12340248256805353, 0.13690706924535334, 0.1537389785517007, 0.1237062287691515, 0.05479390958498698, 0.19855019665556028, 0.1180460539762862, 0.13679231837159023, 0.25609530333895236, 0.14570769388228655, 0.17562117311172187, 0.09622945784940384, 0.08672892858157866, 0.12352454359643161, 0.07316980147152208, 0.1377490209415555, 0.08557907465728931, 0.1305444590980187, 0.08289572098874487, 0.1743457032716833, 0.13035918935202062, 0.11154766791150905, 0.08185540064005181, 0.1162712300720159, 0.1325846230611205, 0.20041548094013706, 0.13346558203920722, 0.15431613195687532, 0.13817223807564005, 0.13493185804691166, 0.1638466291478835, 0.11198143096407875, 0.17032332223607227, 0.15161609480855986, 0.10370372358011082, 0.1135342413908802, 0.09030804707435891, 0.24729791446588933, 0.1570365930092521, 0.18821705190930516, 0.16940783854806796, 0.1865236638695933, 0.09258207661332563, 0.334981742198579, 0.2311201934935525, 0.1769730099476874, 0.2374753524782136, 0.2825405483599752, 1.8970332434400916, 18.150159269571304, 40.508064553141594, 53.66683065891266, 97.21374034881592, 124.50034976005554, 138.76245886087418, 142.85956621170044, 131.14259093999863, 120.0333246588707, 118.6978255212307, 114.06789556145668, 109.4604679942131, 101.85484170913696, 104.83335748314857, 101.6543872654438, 106.49308562278748, 102.62300848960876, 97.96665474772453, 112.78399005532265, 124.27978679537773, 93.06389942765236, 97.49655917286873, 113.04692834615707, 104.65211480855942, 116.02945670485497, 114.6356762945652, 115.24963974952698, 125.77515095472336, 118.01570132374763, 112.71218910813332, 125.59548139572144, 119.74486693739891, 108.90989273786545, 114.26903396844864, 125.72967499494553, 124.04654771089554, 144.923235476017, 155.25054931640625, 151.81158185005188, 153.40532273054123, 126.95912182331085, 99.53999072313309, 54.53377313911915, 17.398039028048515, 2.1844320092350245, 0.4376369743840769, 0.3616138600045815, 0.2929651999147609, 0.3023402171675116, 0.16077798209153116, 0.29975971032399684, 0.09993228493840434, 0.10852297826204449, 0.403435870539397, 0.07601904741022736, 0.21911396586801857, 0.23994878225494176, 0.18103622394846752, 0.14878830435918644, 0.10584224437479861, 0.06995765274041332, 0.15756043052533641, 0.13442473369650543, 0.23026287934044376, 0.10134899290278554, 0.15356362389866263, 0.10050487413536757, 0.2598986023804173, 0.09931491455063224, 0.09715804044390097, 0.11615097988396883, 0.12008525314740837, 0.0931060996663291, 0.1397219017962925, 0.10851843631826341, 0.0995395849167835, 0.13311188929947093, 0.0882658050977625, 0.11295316202449612, 0.14122112916084006, 0.12303609168156981, 0.14426157460547984, 0.09586254745954648, 0.16424001194536686, 0.1357432481017895, 0.10856430104468018, 0.11346955579938367, 0.09315646180766635, 0.16452987998491153, 0.15396218688692898, 0.07188352596131153, 0.16115303384140134, 0.1427740286453627, 0.2102506742812693, 0.22085145232267678, 0.10814393375767395, 0.1511202659457922, 0.09949717117706314, 0.13595388445537537, 0.11481345907668583, 0.17676201736321673, 0.11440042420872487, 0.19785609561949968, 0.08616865161457099, 0.05786530258774292, 0.10417824538308196, 0.2617101254872978, 0.07385651071672328, 0.14918576896889135, 0.09291442518588156, 0.22163467045174912, 0.11366027290932834], [0.03758581675356254, 0.0025046131986528053, 0.043173353842576034, 0.03848481734166853, 0.011306309079373023, 0.06596559585887007, 0.08757633506320417, 0.0031036390873850905, 0.04126312138396315, 0.04188037673884537, 0.022123637463664636, 0.05639942733978387, 0.054675329229212366, 0.01542132220492931, 0.026739846107375342, 0.04722343182947952, 0.048338211854570545, 0.051168269565096125, 0.058589293621480465, 0.05812985968077555, 0.06555634594406001, 0.07705478128627874, 0.016713379045540933, 0.02099520748743089, 0.023019363325147424, 0.016871896223165095, 0.10086748749017715, 0.06929890761966817, 0.016278909097309224, 0.03943030606023967, 0.0628606355166994, 0.020929265810991637, 0.007306552879526862, 0.02029337327257963, 0.12090227610315196, 0.05512551229912788, 0.029151215640013106, 0.03205340268323198, 0.06620126485358924, 0.01913445030368166, 0.023514958411396947, 0.016465909902763087, 0.04814831852854695, 0.04412832349771634, 0.09014155366457999, 0.06450249624322169, 0.020385407005960587, 0.04480413430428598, 0.04568750526232179, 0.040577265608590096, 0.05887284598429687, 0.040238731235149316, 0.03546343396010343, 0.03909489983925596, 0.09523089072899893, 0.024557553442718927, 0.025233373526134528, 0.054005971396691166, 0.12951061769854277, 0.03857507363136392, 2.7549697319045663, 15.625438895076513, 38.282520174980164, 68.40207517147064, 98.95957946777344, 105.13680160045624, 98.56186240911484, 89.53214094042778, 84.54382941126823, 78.15838605165482, 73.21209266781807, 96.9833967089653, 64.31380614638329, 81.23812079429626, 86.24450415372849, 61.31878025829792, 65.78473001718521, 72.99077734351158, 70.80461785197258, 66.98729708790779, 40.45992113649845, 42.465369924902916, 50.846542194485664, 54.489710703492165, 48.83585348725319, 33.4283946454525, 43.94930809736252, 60.18707938492298, 67.63891652226448, 58.10800574719906, 54.69501368701458, 71.57045915722847, 95.05907356739044, 76.67163223028183, 73.57593074440956, 70.34912869334221, 76.00498840212822, 74.80983853340149, 106.56321465969086, 102.50448524951935, 69.29770991206169, 87.41007640957832, 78.57739716768265, 92.08324044942856, 103.42260718345642, 111.44420474767685, 112.99116253852844, 97.14740350842476, 70.83728089928627, 31.916071996092796, 14.831532295793295, 6.8841941468417645, 1.4378466457128525, 0.40641565283294767, 0.16448670183308423, 0.1021697859687265, 0.07566962201963179, 0.024998288972710725, 0.014688228729937691, 0.043937135123996995, 0.043891990280826576, 0.04221872928610537, 0.04634760851331521, 0.02988256877870299, 0.051375451221247204, 0.07978376219398342, 0.039455657824873924, 0.058396145977894776, 0.04245347801770549, 0.008152991322276648, 0.005321720664142049, 0.017934436473296955, 0.04704251106886659, 0.05195235971768852, 0.034256304788868874, 0.0440653225814458, 0.08112629249808379, 0.007623903575222357, 0.07296857555047609, 0.0358934862742899, 0.030445966476690955, 0.056460439300280996, 0.04872896373854019, 0.028204203663335647, 0.04320798616390675, 0.06679106445517391, 0.05971800004772376, 0.06381574989063665, 0.02039851518929936, 0.022922269999980927, 0.0071581015436095186, 0.15354566392488778, 0.0404501394223189, 0.03655998683825601, 0.01627165089303162, 0.0741048259078525, 0.011456218271632679, 0.018131085198547225, 0.06609795047552325, 0.08036673403694294, 0.04059159276948776, 0.05693655301001854, 0.09874112307443283, 0.04950061549607199, 0.028550745810207445, 0.029092765944369603, 0.024527201458113268, 0.049768285898608156, 0.06009481810906436, 0.06979101832257584, 0.03264204824517947, 0.02902143070969032, 0.057121659483527765, 0.030157256187521853, 0.05476773774717003, 0.020329905491962563, 0.0572993481910089, 0.038008462433936074, 0.01107833986679907, 0.02195959685195703, 0.04391464433865622, 0.02174768585973652, 0.03316621972771827, 0.0645255770359654, 0.02817246571794385, 0.05648087062581908, 0.05277270378428511, 0.056760471052257344, 0.026920384661934804, 0.02763375927315792, 0.012402755273797084, 0.02868847357603954, 0.040692550828680396, 0.041727457210072316, 0.02892307016736595, 0.035294814297230914, 0.012998970742046367, 0.036278850166127086, 0.023038404979160987, 0.03391065321920905, 0.049425413671997376, 0.0334217040654039, 0.0667555452673696, 0.09521876403596252, 0.06000244298775215, 0.035142989436280914, 0.03685809642774984, 0.029428843809000682, 0.023819623020244762, 0.08201681775972247, 0.06730681256158277, 0.07201333501143381, 0.05667994431860279, 0.011653457931970479, 0.03340225237479899, 0.03451555923675187, 0.03822097642114386, 0.048030981270130724, 0.02285578470036853, 0.05568892112933099, 0.05842341619427316, 0.043259205485810526, 0.04161340766586363, 0.02794630177959334, 0.014428695048991358, 0.019625115673989058, 0.034441236857674085, 0.0683942592877429, 0.034455846034688875, 0.049319319950882345, 0.023129874680307694, 0.04136296622164082, 0.025474013054918032, 0.020183054875815287, 0.09550388975185342, 0.06813975458499044, 5.656770234927535, 27.113684490323067, 54.49678212404251, 90.05497768521309, 118.04625168442726, 123.38694110512733, 115.44212982058525, 102.95485228300095, 99.31066542863846, 102.94779986143112, 94.1287998855114, 117.53188088536263, 81.8977501988411, 114.66145411133766, 113.46279323101044, 97.47248366475105, 101.85263022780418, 103.32389608025551, 110.09089976549149, 94.10302966833115, 85.31772628426552, 69.19362589716911, 80.78102052211761, 89.93187949061394, 75.63785210251808, 57.21413791179657, 73.15555930137634, 92.55148932337761, 95.3081502020359, 91.24349310994148, 92.00922802090645, 99.4189140200615, 131.4090022444725, 118.10445696115494, 107.93448507785797, 102.30399280786514, 113.56813877820969, 104.61901858448982, 134.1722747683525, 127.34486192464828, 92.70158126950264, 107.64548018574715, 95.84227234125137, 102.74413838982582, 112.6027549803257, 128.17516297101974, 131.22580647468567, 121.22195407748222, 100.17798408865929, 56.55836530029774, 28.461892046034336, 16.920501552522182, 4.893428720533848, 0.17913073010277003, 0.2481763352989219, 0.16481633414514363, 0.05142198388057295, 0.101309317687992, 0.02070520400593523, 0.08420791971730068, 0.03472517884802073, 0.04596030019456521, 0.029985159562784247, 0.0817828557046596, 0.04982764658052474, 0.04375193588202819, 0.06051007570931688, 0.054866250429768115, 0.041584834980312735, 0.049294624986941926, 0.026427711782162078, 0.019607563881436363, 0.006310295229923213, 0.027410539805714507, 0.055757799855200574, 0.03931408944481518, 0.03322986631246749, 0.03904650438926183, 0.0669440656201914, 0.10572522995062172, 0.054828163411002606, 0.056651531194802374, 0.05834188385051675, 0.03493427895591594, 0.033079971035476774, 0.027797417678812053, 0.026872083835769445, 0.056372030958300456, 0.039652527339058, 0.038762811018386856, 0.03440589578531217, 0.04685320775024593, 0.08048783769481815, 0.036035414595971815, 0.013109419942338718, 0.0770151060714852, 0.06509878963697702, 0.00870453599418397, 0.04166979975707363, 0.02692123998713214, 0.052689323492813855, 0.013996759535075398, 0.06609553849557415, 0.019260311128164176, 0.016746970504755154, 0.08081617866992019, 0.01514383226094651, 0.038948923101997934, 0.031945995360729285, 0.026987419150827918, 0.012520396812760737, 0.018622648567543365, 0.058907619313686155, 0.024699246132513508, 0.04603399174811784, 0.039832338588894345, 0.18124414404155686, 0.07087182282702997, 0.10851886676391587, 0.16257549345027655, 0.10377907383372076, 0.13126962643582374, 0.16959085216512904, 0.13669453299371526, 0.13714277534745634, 0.1585770837846212, 0.21136146155185997, 0.19956183299655095, 0.1545958177302964, 0.08477395575027913, 0.1219046875485219, 0.27297070249915123, 0.1258426418644376, 0.0824483840551693, 0.10592367281788029, 0.14476282114628702, 0.11418031805078499, 0.10180191820836626, 0.11081154647399671, 0.1239961784449406, 0.13805681926896796, 0.07978961773915216, 0.2170240631676279, 0.21681348618585616, 0.14070658333366737, 0.1015265888418071, 0.11669579791487195, 0.15264748712070286, 0.12149710004450753, 0.15715149231255054, 0.1342192033189349, 0.17939299024874344, 0.1707266943412833, 0.07068946972140111, 0.1558865758124739, 0.15671295725042, 0.126519747718703, 0.14907085482263938, 0.05756612430559471, 0.14788905886234716, 0.25100102357100695, 0.2319934786646627, 0.14837222668575123, 0.177277053007856, 0.16763222054578364, 0.1573133992496878, 0.20254925941117108, 0.15366237406851724, 0.10915029342868365, 0.1158397008839529, 0.20429421187145635, 0.12458946614060551, 0.1631910604191944, 0.21490172861376777, 0.2127819025190547, 0.07640126830665395, 4.798847995698452, 27.025489322841167, 57.0430900901556, 95.18489241600037, 130.7140651345253, 135.23614168167114, 129.56588834524155, 114.26631331443787, 107.12949067354202, 102.63079807162285, 95.88553681969643, 122.75832563638687, 89.07031372189522, 109.37001004815102, 115.29529809951782, 87.67491459846497, 93.24614524841309, 99.79873403906822, 97.7007146179676, 95.43507099151611, 62.97674149274826, 65.96233248710632, 74.401064068079, 77.87156984210014, 71.94947361946106, 53.263356909155846, 66.42639398574829, 85.1251982152462, 90.98246991634369, 77.78853669762611, 75.2152007818222, 98.8352881371975, 122.58491814136505, 107.70750805735588, 97.2873044013977, 96.30651623010635, 109.65029060840607, 104.679024964571, 138.33101481199265, 135.31417429447174, 101.16229847073555, 114.04837220907211, 104.42028164863586, 115.59634074568748, 126.46773219108582, 141.60032898187637, 147.74470567703247, 135.87776005268097, 108.49785804748535, 58.372957929968834, 26.60800002515316, 16.01570550352335, 4.156708102673292, 0.5455007473938167, 0.34560428000986576, 0.3697375865885988, 0.1658348279306665, 0.1988934399560094, 0.07729227596428245, 0.1562100779847242, 0.14210291934432462, 0.19360891805263236, 0.15568333124974743, 0.2092782233376056, 0.19900887360563502, 0.21696252428228036, 0.16518746735528111, 0.1421993985422887, 0.16903740295674652, 0.18324666627449915, 0.1662079055677168, 0.10210331180132926, 0.132117930916138, 0.1956666709156707, 0.1183549729466904, 0.14526445360388607, 0.15924995939712971, 0.07286869731615297, 0.13510347227565944, 0.1789417050895281, 0.10008802462834865, 0.14004601252963766, 0.11443699724623002, 0.12649240699829534, 0.13271277712192386, 0.159100238524843, 0.22250846028327942, 0.18396491679595783, 0.0756619185267482, 0.16414875746704638, 0.11421033050282858, 0.42817625391762704, 0.10840067974640988, 0.21929061185801402, 0.1893838564865291, 0.164750475960318, 0.1025576694519259, 0.09821333733270876, 0.2311630451004021, 0.09992904175305739, 0.11776091341744177, 0.1809457561466843, 0.23696105898125097, 0.13193372986279428, 0.07009788896539249, 0.15354901843238622, 0.1016841467935592, 0.17573037272086367, 0.136245756293647, 0.11500837674248032, 0.1971156697254628, 0.13949608110124245, 0.09157433654763736, 0.1579070431762375, 0.27313079859595746, 0.07948282131110318], [0.03309397907287348, 0.018544146041676868, 0.03821614503976889, 0.009994855281547643, 0.019415805909375194, 0.017840035288827494, 0.039466136950068176, 0.045936017122585326, 0.02457185462844791, 0.012727143384836381, 0.05731419485528022, 0.08857322492985986, 0.047995959321269765, 0.07668122867471538, 0.031878519293968566, 0.06747604449628852, 0.04363174877653364, 0.01458876795368269, 0.002705379915823869, 0.03784506749070715, 0.018999846979568247, 0.020739491228596307, 0.04017397885036189, 0.020891989588562865, 0.04523062059888616, 0.02059693022602005, 0.05369572027120739, 0.011863317813549656, 0.03090863803663524, 0.04079421021742746, 0.012015244719805196, 0.06075128112570383, 0.032675096081220545, 0.03567676059901714, 0.07792603297275491, 0.039727714320179075, 0.004638593673007563, 0.043919197414652444, 0.0242325966610224, 0.05762598222645465, 0.04842034533794504, 0.04707587431767024, 0.006119599920566543, 0.06045073358109221, 0.08218400136684068, 0.03626653793617152, 0.032936513889580965, 0.03944772055547219, 0.046039995722821914, 0.02593408338725567, 0.021165754878893495, 0.044880831555929035, 0.02445708520099288, 0.09399642454809509, 0.22242677950998768, 0.022103820265328977, 0.013534096324292477, 0.04287650219339412, 9.901630282402039, 34.25086431205273, 66.89112424850464, 97.62168645858765, 93.188616335392, 84.83905076980591, 68.48277524113655, 68.49666729569435, 59.10650856792927, 72.934540361166, 63.81672441959381, 55.01462213695049, 79.81059059500694, 62.794712260365486, 61.99024982750416, 39.74918067455292, 57.23192855715752, 42.57738031446934, 31.898524537682533, 29.83076099306345, 29.77474059909582, 61.610084027051926, 29.638810493052006, 38.00087928771973, 33.0022095143795, 28.93373552709818, 38.95872429013252, 60.93458667397499, 56.43066555261612, 36.05804733932018, 33.279191851615906, 24.72496546804905, 40.24441950023174, 49.68129672110081, 30.79367682337761, 25.24310376495123, 61.42965070903301, 52.32202962040901, 29.129495322704315, 49.24433156847954, 63.650958314538, 75.61125352978706, 60.04167638719082, 75.67035555839539, 91.36037483811378, 103.47584992647171, 75.93103677034378, 84.19936269521713, 83.81245225667953, 94.17904078960419, 85.71420460939407, 101.56373932957649, 100.37849172949791, 105.62060683965683, 77.78796672821045, 37.475245893001556, 8.213763702660799, 0.6101239984855056, 0.31970424635801464, 0.3881744050886482, 0.04886269132839516, 0.025309423253929708, 0.05021263197704684, 0.0076982087921351194, 0.05945033335592598, 0.0042970118556695525, 0.05721657274989411, 0.07751281998935156, 0.00973006070125848, 0.035978621745016426, 0.06426089006708935, 0.04745612481201533, 0.028643365840252955, 0.0543212988122832, 0.024348314182134345, 0.07371053769020364, 0.019521176036505494, 0.03193446609657258, 0.039390567762893625, 0.018338689878873993, 0.06047502778528724, 0.029899562105129007, 0.02076846096315421, 0.060860688536195084, 0.02249857603601413, 0.0066632138168643, 0.03659924645035062, 0.02879961390135577, 0.022874664937262423, 0.03515773962135427, 0.05554449176997878, 0.025047920098586474, 0.025254658321500756, 0.06121628117398359, 0.05455113081552554, 0.00928185823795502, 0.10101043997565284, 0.014145566638035234, 0.0136871114045789, 0.02242485665192362, 0.04228187492117286, 0.024659500413690694, 0.049814647863968275, 0.03139713633572683, 0.02472168496751692, 0.051340748395887204, 0.014095886344875908, 0.03043400120077422, 0.05405304953455925, 0.041549950328771956, 0.045599134027725086, 0.11345316175720654, 0.032685927726561204, 0.04337084676080849, 0.07817155768861994, 0.02708537707803771, 0.015079973236424848, 0.041710666118888184, 0.04066946261445992, 0.07899218748207204, 0.13956156821222976, 0.038441694850916974, 0.06844308518338948, 0.04049945142469369, 0.03016840881173266, 0.015903803541732486, 0.029254700712044723, 0.010075397785840323, 0.022667848788842093, 0.06295495506492443, 0.022197367979970295, 0.06851641679531895, 0.05576778174145147, 0.032817981773405336, 0.030942220219003502, 0.04475325265957508, 0.08570710255298764, 0.03312116765300743, 0.04253531093127094, 0.09543297011987306, 0.05240088408754673, 0.030452497376245447, 0.06267271630349569, 0.01441531598175061, 0.05833199844346382, 0.02212731480540242, 0.06421750411391258, 0.010819116032507736, 0.045267861569300294, 0.06309167350991629, 0.020252230460755527, 0.007375967343250522, 0.026362788703409024, 0.04680179918068461, 0.03658601395727601, 0.022424745329772122, 0.01662843096710276, 0.08092097734333947, 0.061778899616911076, 0.04289982418413274, 0.016845971149450634, 0.06646232272032648, 0.08348053335794248, 0.06802103322115727, 0.022898868228367064, 0.07627398998010904, 0.03954862666432746, 0.03882363373122644, 0.015069046039570821, 0.01492306188083603, 0.03897793736541644, 0.09600839432096109, 0.12502936675446108, 0.10490171320270747, 0.05404639246989973, 0.30605448817368597, 17.62074887752533, 50.07438562810421, 86.91250830888748, 109.28160399198532, 109.48117688298225, 95.14573931694031, 86.31078779697418, 86.42181023955345, 83.67533281445503, 103.12446758151054, 83.05870190262794, 87.22682744264603, 100.80704793334007, 101.12993940711021, 79.06772285699844, 64.13598328828812, 77.6316811144352, 53.75862613320351, 41.46028585731983, 43.51441003382206, 37.240885868668556, 76.28260150551796, 29.501732848584652, 44.00294981896877, 43.852945268154144, 41.134362146258354, 43.36992658674717, 59.167046919465065, 59.86785091459751, 43.16358245909214, 49.58022214472294, 36.3431840389967, 46.01888604462147, 63.647135719656944, 58.88656497001648, 42.935537695884705, 72.71776959300041, 77.72304341197014, 46.991858035326004, 70.97778975963593, 107.20946118235588, 107.74269416928291, 90.33595740795135, 116.47579595446587, 136.10018491744995, 130.81624925136566, 107.8497876226902, 108.78438547253609, 103.2982474565506, 105.96751302480698, 103.76632913947105, 118.52052703499794, 121.45358964800835, 129.93931710720062, 102.89083331823349, 56.89164541661739, 16.21237725019455, 1.2170857354067266, 0.1394262004760094, 0.5510397220496088, 0.008479388798150467, 0.05623293393000495, 0.02455056983308168, 0.02366479060583515, 0.08675651421071962, 0.00977992838670616, 0.034086612722603604, 0.010147778521059081, 0.05437916777736973, 0.03860207296384033, 0.02778023510472849, 0.011374994846846676, 0.02981671987072332, 0.05577559284574818, 0.04391801368910819, 0.0971163169015199, 0.028295790252741426, 0.019829130214930046, 0.03088931251113536, 0.10123455373104662, 0.02328015587409027, 0.0336089405027451, 0.07819192222086713, 0.024768043222138658, 0.030973945176810957, 0.023403203958878294, 0.052483722611214034, 0.028826039924751967, 0.008024168400879717, 0.04261641654011328, 0.10711834504036233, 0.01323599879469839, 0.041072478488786146, 0.043275328644085675, 0.04214254782709759, 0.03328125261759851, 0.08831918035866693, 0.04120290723221842, 0.03299709911516402, 0.035240856450400315, 0.010463044709467795, 0.062214725840021856, 0.052430247160373256, 0.051371540102991275, 0.02962431808555266, 0.09419115667697042, 0.026793529359565582, 0.02952658094727667, 0.053586164431180805, 0.03080635524383979, 0.01698604039120255, 0.019813667568087112, 0.04474418732570484, 0.022390996164176613, 0.03831047943094745, 0.0223722977534635, 0.02750753479631385, 0.060372073348844424, 0.20193001138977706, 0.14693260862259194, 0.2166909130755812, 0.09642142918892205, 0.17171695682918653, 0.08646596339531243, 0.09958021008060314, 0.0893789969268255, 0.10198186675552279, 0.1333771922509186, 0.14166138600558043, 0.21596982754999772, 0.16048133082222193, 0.16331627557519823, 0.14058007684070617, 0.11604452622123063, 0.1161868404597044, 0.07869184773880988, 0.1258621009765193, 0.15138003247557208, 0.18698254862101749, 0.20018712210003287, 0.1791975530795753, 0.08853932362399064, 0.11521514650667086, 0.12821561453165486, 0.09903005600790493, 0.12707606161711738, 0.15611153561621904, 0.07703032009885646, 0.08239391041570343, 0.22384895710274577, 0.11031163579900749, 0.1446480702725239, 0.1651994456187822, 0.09587738299160264, 0.11163464019773528, 0.1489152412978001, 0.10171650443226099, 0.17103719408623874, 0.21705193823436275, 0.12682261818554252, 0.12630933400942013, 0.17593808501260355, 0.23736116563668475, 0.27938680665101856, 0.1210942622856237, 0.17828223266405985, 0.12153739124187268, 0.19948714325437322, 0.10248614868032746, 0.22867097257403657, 0.19121954392176121, 0.14219916105503216, 0.30712377454619855, 0.2137800317723304, 0.2644933870760724, 0.26967895100824535, 15.48277460038662, 53.918114975094795, 93.53217110037804, 128.80457639694214, 120.35127639770508, 109.20451372861862, 92.60342493653297, 89.48887646198273, 79.27670404314995, 96.99218943715096, 84.60474014282227, 76.75739362835884, 110.43861910700798, 87.00597569346428, 83.56899932026863, 50.99353350698948, 73.85916754603386, 56.18690483272076, 48.386759385466576, 44.29636627435684, 40.97234643995762, 86.42149865627289, 41.78128883242607, 57.16355882585049, 51.47051811218262, 46.63359045982361, 57.65575401484966, 88.17025601863861, 82.93305024504662, 54.378893449902534, 52.43354983627796, 41.21170699596405, 58.50703753530979, 71.08191937208176, 47.22781777381897, 40.413198843598366, 79.66619074344635, 80.01248136162758, 49.65211808681488, 73.7396639585495, 86.60711869597435, 101.35864153504372, 86.67302995920181, 105.06555542349815, 123.80060970783234, 136.5445026755333, 105.23372679948807, 114.23219874501228, 108.58429580926895, 115.692308396101, 111.50056332349777, 132.08302527666092, 135.58377742767334, 145.63869148492813, 114.32643368840218, 61.558957770466805, 14.61130941286683, 1.287135451566428, 0.5313803488388658, 0.5896390008274466, 0.10324420800316148, 0.15476370637770742, 0.17345245432807133, 0.0968074424599763, 0.21246999269351363, 0.08154306779033504, 0.09344652280560695, 0.2104180137393996, 0.14390463125891984, 0.1118125329958275, 0.11477702704723924, 0.14191751601174474, 0.1323481005965732, 0.13069256208837032, 0.05807341563922819, 0.1901195029495284, 0.08547521851141937, 0.13014689058763906, 0.08234740002080798, 0.19714643916813657, 0.1838047316414304, 0.07829862821381539, 0.15269609779352322, 0.09228831229847856, 0.16100691980682313, 0.09708271245472133, 0.15069736051373184, 0.1253997429739684, 0.10837034074938856, 0.1123886251298245, 0.21771525498479605, 0.17450755083700642, 0.14930151432054117, 0.13553203287301585, 0.12127634821808897, 0.1229697882081382, 0.41978621506132185, 0.11498882115120068, 0.06829225108958781, 0.15661336103221402, 0.11010409420123324, 0.1605372887570411, 0.1820460197632201, 0.1524150909972377, 0.12565364653710276, 0.22353323263814673, 0.13090155087411404, 0.2144802629482001, 0.1423624187009409, 0.16212385206017643, 0.08800971219898202, 0.2546406345209107, 0.16112159646581858, 0.15030991489766166, 0.17549554235301912, 0.10994121505063958, 0.11971740765147842, 0.10449132038047537], [0.017381935358571354, 0.039191646210383624, 0.03776307130465284, 0.10450028552440926, 0.036466364908847027, 0.01855919308582088, 0.01951478985574795, 0.061884796668891795, 0.028657425827987026, 0.0259933234701748, 0.06347740476485342, 0.05204882407269906, 0.025044582289410755, 0.032213669474003837, 0.024071027401078027, 0.06495481298770756, 0.016475674710818566, 0.04472262422495987, 0.03556756470061373, 0.07543798288679682, 0.0420565848617116, 0.015421766565850703, 0.02391890939179575, 0.025148573877231684, 0.02959229070256697, 0.009416144293936668, 0.04249934645486064, 0.03824847299256362, 0.010973415028274758, 0.04008404539490584, 0.027907131225219928, 0.03379175373993348, 0.0710355702904053, 0.047862632491160184, 0.10656871047103778, 0.06835170453996398, 0.061557921435451135, 0.04352981108240783, 0.021604011635645293, 0.03094206807872979, 0.03782193103688769, 0.12438283738447353, 0.05163610461750068, 0.02376935550273629, 0.04595614787831437, 0.03737944032764062, 0.032700607407605276, 0.0655681906209793, 0.037321330164559186, 0.08436905482085422, 0.04293824145861436, 0.067854836670449, 0.03905612633388955, 0.03761359905183781, 0.23265458381501958, 0.48739215766545385, 4.363107327371836, 34.15921323001385, 80.208870023489, 91.30166038870811, 85.20288124680519, 71.90593555569649, 58.82847748696804, 77.52198100090027, 70.47899052500725, 60.58184400200844, 66.08182847499847, 48.07407036423683, 55.075217485427856, 37.56785832345486, 34.512088894844055, 22.085794284939766, 19.627012722194195, 52.17567287385464, 39.52012896537781, 69.96669441461563, 56.61456808447838, 54.551400393247604, 68.59410166740417, 34.84256096184254, 101.08340710401535, 61.83186672627926, 68.7278088927269, 56.04265697300434, 60.602233707904816, 63.85138615965843, 77.70527556538582, 89.43022280931473, 48.855392038822174, 78.72539922595024, 85.11741623282433, 46.16641312837601, 44.89759661257267, 81.67730882763863, 48.63084688782692, 43.239399790763855, 69.6318031847477, 48.73082332313061, 27.44590636342764, 23.80358900874853, 31.26570649445057, 27.782454304397106, 32.76499204337597, 47.53951504826546, 50.392854139208794, 70.9730476140976, 68.10742378234863, 57.93469324707985, 61.23475916683674, 64.0895725786686, 69.53228652477264, 76.51054367423058, 80.96216440200806, 95.4367733001709, 90.05371615290642, 45.59540256857872, 19.430814050137997, 5.028621666133404, 0.18263586389366537, 0.18347091361647472, 0.04906767622742336, 0.055894637043820694, 0.007515187753597274, 0.005906645283175749, 0.008170336241164478, 0.05904316516534891, 0.035840786367771216, 0.10838620786671527, 0.035550231841625646, 0.033273259687121026, 0.02518365148716839, 0.05270749497867655, 0.060458715379354544, 0.05598566145636141, 0.07240197548526339, 0.06733802729286253, 0.04887820592557546, 0.026492213692108635, 0.01666400581598282, 0.03413274833292235, 0.05681076640030369, 0.010319344510207884, 0.03511970084218774, 0.05298789692460559, 0.05598113435553387, 0.057694860952324234, 0.03660446003777906, 0.07614084126544185, 0.015752490762679372, 0.032261293090414256, 0.028657010225288104, 0.04631032672477886, 0.05023865909606684, 0.029413609372568317, 0.0918379622453358, 0.04927004505589139, 0.06516702269436792, 0.05060978859546594, 0.02757824848231394, 0.03206716210115701, 0.08659192069899291, 0.017334842377749737, 0.03969776866142638, 0.06028701951436233, 0.03427540395932738, 0.021145316131878644, 0.022194139637576882, 0.0675908250559587, 0.008003669354366139, 0.04560232155199628, 0.07695358945056796, 0.06558897817740217, 0.020164196903351694, 0.05088581187010277, 0.04217901696392801, 0.032914973053266294, 0.06846767995739356, 0.0677745659777429, 0.017179746500914916, 0.030344080732902512, 0.03638119233073667, 0.02912104919232661, 0.02573940877482528, 0.007782004686305299, 0.08790894338744693, 0.03557479692972265, 0.01795468411728507, 0.05675067841366399, 0.0785501569043845, 0.02132906076440122, 0.05463355373649392, 0.032961531687760726, 0.06235583408852108, 0.02048284914053511, 0.019241638692619745, 0.021215823871898465, 0.10413327123387717, 0.034378213676973246, 0.09406825702171773, 0.02059869653749047, 0.038504617841681466, 0.06102580897277221, 0.039881591219455004, 0.04447651321243029, 0.023070428651408292, 0.047931429580785334, 0.0532721135095926, 0.07844829713576473, 0.06691402348224074, 0.033942431982723065, 0.031543576915282756, 0.06010976867401041, 0.012052749152644537, 0.08859256529831327, 0.034127282415283844, 0.0075617139191308524, 0.028289350266277324, 0.09381977113662288, 0.04151358509261627, 0.010727293811214622, 0.00886701531271683, 0.11025391897419468, 0.08411162605625577, 0.08390559843974188, 0.08860805392032489, 0.042965756583726034, 0.025827616736933123, 0.09070089552551508, 0.09318301585153677, 0.07799325670930557, 0.09141678601736203, 1.6359044867567718, 8.705822099000216, 50.94279482960701, 96.05891391634941, 109.56485599279404, 96.15115016698837, 91.3952949643135, 82.28994235396385, 106.66875779628754, 103.45968559384346, 91.49564757943153, 88.15555080771446, 67.38154113292694, 69.18477237224579, 29.514262676239014, 38.00835348665714, 17.018714882433414, 17.536913976073265, 32.379061952233315, 28.611263930797577, 31.30794122815132, 31.433554887771606, 25.264384523034096, 28.364683762192726, 27.01910376548767, 36.974900141358376, 30.016629919409752, 28.93608570098877, 22.057573199272156, 24.532482996582985, 34.05741289258003, 46.28666527569294, 35.81226892769337, 25.37274330854416, 23.23487352579832, 35.400211438536644, 30.876185595989227, 18.881260938942432, 36.7551389336586, 34.0780533850193, 30.770948342978954, 45.78628532588482, 36.55917964875698, 20.9192967787385, 28.482110761106014, 37.342785000801086, 32.21888154745102, 42.846219688653946, 59.04275558888912, 61.1146704107523, 98.808963149786, 112.32033133506775, 98.85262280702591, 91.31786271929741, 90.70403605699539, 87.86092221736908, 86.453667730093, 92.4008198082447, 109.32578802108765, 113.26126724481583, 68.12508523464203, 35.311930775642395, 12.998729143291712, 0.1519927495974116, 0.3438807459315285, 0.02681525202206103, 0.027848386525874957, 0.01606286063179141, 0.04569018812617287, 0.03532700124196708, 0.06577648920938373, 0.008044737951422576, 0.05656481866026297, 0.03718588821357116, 0.05991417194309179, 0.031409916118718684, 0.07305664621526375, 0.04470437481359113, 0.015001527299318695, 0.06051050986570772, 0.045101234572939575, 0.03948658311855979, 0.038095575728220865, 0.0636342576763127, 0.0460342218138976, 0.05499012229847722, 0.03081134618696524, 0.042829138328670524, 0.035573490749811754, 0.029722027393290773, 0.05461290347739123, 0.04441568307811394, 0.0775125008658506, 0.03679164081404451, 0.02083843992295442, 0.03567786639905535, 0.02489489666913869, 0.053573484838125296, 0.04262413116521202, 0.04361958126537502, 0.032887535853660665, 0.01969985922187334, 0.024401401860814076, 0.038392245551222004, 0.014621585723944008, 0.027204239449929446, 0.0396097239718074, 0.057695068753673695, 0.027473663176351693, 0.05165869930351619, 0.020656886481447145, 0.05034666755818762, 0.027985830420220736, 0.030719041569682304, 0.025972292860387824, 0.026696300592448097, 0.04003292626293842, 0.11062537130783312, 0.040238111541839316, 0.017524869290355127, 0.034622268940438516, 0.15808805299457163, 0.1321374494000338, 0.12171104637673125, 0.191894349118229, 0.2108679778757505, 0.15000037994468585, 0.039356681299977936, 0.06899243773659691, 0.18058977759210393, 0.04942066763760522, 0.1626357706845738, 0.17996947572100908, 0.16095495462650433, 0.09175784740364179, 0.21474614477483556, 0.22041539603378624, 0.2189294679556042, 0.10919241030933335, 0.15159181173657998, 0.10747120657470077, 0.12002629693597555, 0.10872954022488557, 0.17007376765832305, 0.11035852468921803, 0.10908796786679886, 0.15171744249528274, 0.13123501266818494, 0.15027588000521064, 0.11901748075615615, 0.1821118185762316, 0.12339851949946024, 0.19648370129289106, 0.13186350784962997, 0.12246467507793568, 0.21420139353722334, 0.21445418387884274, 0.17160772753413767, 0.09991477025323547, 0.10726526059443131, 0.08782828677794896, 0.10699874052079394, 0.15576513076666743, 0.12543811200885102, 0.10765044266008772, 0.14057577238418162, 0.23670023860177025, 0.14750622940482572, 0.15362755249952897, 0.19110728666419163, 0.1289726942195557, 0.0709105035639368, 0.212150854349602, 0.14861857518553734, 0.1681200638995506, 0.38023001106921583, 1.113853706046939, 8.719602059572935, 55.46009123325348, 107.48194456100464, 119.36690121889114, 105.74619770050049, 93.32749888300896, 79.76851165294647, 100.00864237546921, 93.46753656864166, 83.15820336341858, 87.57471397519112, 65.65024003386497, 74.41183269023895, 55.426482036709785, 52.39599645137787, 33.97485472261906, 29.69315517693758, 76.57966956496239, 61.532845571637154, 102.3710972070694, 84.76156532764435, 81.63219764828682, 101.79914429783821, 53.25259208679199, 148.05821925401688, 92.54113867878914, 102.43440181016922, 84.51688885688782, 88.43437984585762, 96.37051239609718, 108.60422194004059, 124.10514816641808, 70.02293899655342, 105.2905261516571, 114.0378999710083, 69.80593264102936, 65.76364874839783, 118.76371398568153, 72.22862184047699, 63.959573954343796, 99.32947441935539, 72.04451411962509, 42.79272995889187, 41.093176156282425, 46.77608661353588, 41.59061126410961, 47.62310676276684, 68.42765539884567, 68.26332181692123, 93.43006297945976, 94.56633120775223, 84.19853433966637, 87.69460514187813, 91.51359781622887, 90.77459827065468, 96.3060450553894, 103.14469769597054, 124.22068476676941, 124.5349583029747, 72.46005222201347, 35.398744717240334, 11.271065399050713, 0.20480203384067863, 0.3347147174645215, 0.19940715457778424, 0.1764751476002857, 0.11283982123131864, 0.23505802906583995, 0.22698071639752015, 0.18637904897332191, 0.21477697358932346, 0.216256370767951, 0.14938181469915435, 0.13757336942944676, 0.12825243989937007, 0.19620495062554255, 0.1308045521727763, 0.166715920495335, 0.23062688793288544, 0.17370990535710007, 0.17600567982299253, 0.12385399037157185, 0.20573114336002618, 0.20603107492206618, 0.17159086593892425, 0.1533517852658406, 0.11589953282964416, 0.11305019041174091, 0.1627445695339702, 0.09572217764798552, 0.09216472986736335, 0.2510449883993715, 0.08912084085750394, 0.08448163120192476, 0.16290332976495847, 0.1273625751491636, 0.17347756860544905, 0.15006315079517663, 0.21061046747490764, 0.12769516120897606, 0.13287820183904842, 0.2581552678020671, 0.1097598638443742, 0.1978295118897222, 0.20560183154884726, 0.08660621446324512, 0.09150263766059652, 0.1823034114204347, 0.12000684524537064, 0.12003720650682226, 0.0963873571890872, 0.11963948214543052, 0.13203359325416386, 0.12837879796279594, 0.17737327987561002, 0.17430331179639325, 0.2161615836666897, 0.09203539579175413, 0.21790984610561281, 0.10560015580267645], [0.007973220890562516, 0.05800123435619753, 0.08284167779493146, 0.032146879893844016, 0.036533507009153254, 0.011376108068361646, 0.054089422192191705, 0.025892155754263513, 0.032336424410459585, 0.02421939014311647, 0.0445822135952767, 0.04188790582702495, 0.08451359550235793, 0.04330774194386322, 0.01738494847813854, 0.041191010604961775, 0.04955238771799486, 0.03220559490728192, 0.07665479337447323, 0.04933724652801175, 0.03353874446474947, 0.005311580607667565, 0.009724994615680771, 0.021635061239067, 0.05807334142446052, 0.014840474759694189, 0.006077788248148863, 0.03998627114924602, 0.009864514668151969, 0.019566370974644087, 0.02767142141237855, 0.022456913720816374, 0.007438438551616855, 0.021825579824508168, 0.0762764761748258, 0.023732413246762007, 0.07776949176331982, 0.05280867939291056, 0.03625830009696074, 0.043345272351871245, 0.008814782959234435, 0.08382214393350296, 0.01872685537819052, 0.05609559208096471, 0.04633637610822916, 0.04810036094568204, 0.027106877096230164, 0.040076108125504106, 0.0394113775837468, 0.03483132451947313, 0.04304330359445885, 0.11744737828848884, 0.11193008918780833, 2.359791174530983, 28.844204731285572, 49.84704002737999, 80.21653801202774, 83.21991205215454, 86.86126425862312, 64.45560693740845, 73.90107169747353, 57.49883383512497, 67.01567396521568, 39.07782509922981, 39.87543649971485, 25.217802822589874, 30.06860353052616, 48.27306568622589, 27.570627070963383, 58.700135573744774, 35.43102018535137, 91.66131108999252, 51.94363832473755, 81.53351694345474, 63.39120805263519, 69.79118183255196, 74.64489698410034, 91.8444536626339, 71.33608773350716, 69.19699251651764, 64.059386998415, 69.2096534371376, 79.84520673751831, 74.22267884016037, 82.78127118945122, 77.08035349845886, 76.48006170988083, 91.99864938855171, 87.19993248581886, 88.58147755265236, 87.15825632214546, 74.73323464393616, 81.58849239349365, 74.0722981095314, 55.8918696641922, 86.69996291399002, 61.628828421235085, 88.28982040286064, 123.76000508666039, 60.44999487698078, 51.76868811249733, 61.27942197024822, 68.735271692276, 36.62680462002754, 32.033713683485985, 42.30004459619522, 22.886132039129734, 33.393216133117676, 36.34273186326027, 35.57230420410633, 64.82525110244751, 65.37016466259956, 56.37910231947899, 78.23030859231949, 81.80688947439194, 97.03581869602203, 95.63367873430252, 86.62241667509079, 30.563720762729645, 2.0926868822425604, 0.12968321156222373, 0.36211733298841864, 0.01785874668712495, 0.06603867514058948, 0.10510872045415454, 0.14732266659848392, 0.06038128711224999, 0.034611088485689834, 0.04886861737759318, 0.03687576325319242, 0.04292098281439394, 0.029436213335429784, 0.05836762524268124, 0.05943267395196017, 0.052636074397014454, 0.026108269157703035, 0.016062535942182876, 0.026289449670002796, 0.033700536368996836, 0.057791406943579204, 0.024912005028454587, 0.03592918728827499, 0.07655648107174784, 0.02629426249768585, 0.05765341942606028, 0.04756578826345503, 0.020978015636501368, 0.032144456781679764, 0.014572189302271, 0.04143610116443597, 0.017165172575914767, 0.009651546115492238, 0.07015329028945416, 0.018213103649031837, 0.05353146814741194, 0.02947568631498143, 0.032979628958855756, 0.027378415943530854, 0.08368748123757541, 0.05831686605233699, 0.08250325845438056, 0.025028794952959288, 0.009712644350656774, 0.019678281278174836, 0.06659377191681415, 0.04001871042419225, 0.051278690007166006, 0.041213983786292374, 0.0025095888349824236, 0.01760985076543875, 0.09847444714978337, 0.04341927560744807, 0.034579049970488995, 0.029904760849603917, 0.0266277131595416, 0.015016551151347812, 0.01118594293075148, 0.02723589575907681, 0.06820510068791918, 0.04265008778020274, 0.04622102038410958, 0.012993436175747775, 0.061317699364735745, 0.05566591826209333, 0.02364661355386488, 0.054251013716566376, 0.04163383899140172, 0.05144909824593924, 0.04132450070756022, 0.008604226386523806, 0.04052724485518411, 0.05701030393538531, 0.02783707248454448, 0.03157770086545497, 0.0683988828677684, 0.055205953685799614, 0.032984493736876175, 0.018031030704150908, 0.03645839053206146, 0.03697306994581595, 0.059087801637360826, 0.017552664576214738, 0.027786945975094568, 0.04016134378616698, 0.0356820595334284, 0.09842855273745954, 0.040339923070860095, 0.02481852781784255, 0.07526362271164544, 0.05310151231242344, 0.03226376444217749, 0.012673914698098088, 0.12823103636037558, 0.013670416792592732, 0.00953107050008839, 0.029764723149128258, 0.0436382870975649, 0.08431506357737817, 0.07538817735621706, 0.03368397163285408, 0.050590314640430734, 0.04463330675207544, 0.014633626142313005, 0.07915419089840725, 0.01840704724600073, 0.13323539751581848, 0.12674645899096504, 0.1278025351348333, 0.28494780824985355, 6.491001695394516, 43.55702094733715, 66.84386238455772, 98.59440386295319, 99.67638060450554, 98.99164974689484, 83.94099175930023, 100.26873841881752, 90.78081473708153, 76.4452251791954, 50.769391134381294, 50.677329674363136, 27.054058089852333, 32.213330045342445, 30.714629665017128, 26.363836526870728, 43.40530648827553, 28.60974971204996, 47.962793335318565, 34.67890374362469, 58.243293687701225, 48.100140765309334, 62.04212464392185, 58.310170099139214, 83.63473579287529, 62.67929345369339, 46.85182794928551, 56.195496171712875, 49.95402708649635, 63.17931242287159, 63.167791441082954, 68.47377732396126, 65.82969680428505, 66.02135092020035, 85.37918418645859, 69.43373501300812, 73.47090438008308, 65.45490771532059, 47.21864506602287, 47.279274612665176, 60.37466011941433, 36.62780396640301, 40.95683567225933, 48.93472038209438, 70.43610602617264, 76.75020441412926, 32.71877892315388, 24.078641049563885, 29.375516921281815, 34.80569913983345, 31.44129127264023, 20.75535837560892, 36.58682316541672, 25.26396084576845, 45.47288574278355, 54.9823884665966, 62.05771140754223, 98.72520804405212, 94.21573922038078, 86.94225311279297, 99.33670163154602, 92.44286075234413, 110.77835887670517, 110.8362677693367, 105.37845343351364, 50.24820730090141, 7.289503198117018, 0.3590070811333135, 0.2915039111394435, 0.022741913271602243, 0.01555677621581708, 0.09648374732933007, 0.130905810801778, 0.038316116042551585, 0.031595182153978385, 0.04948434761899989, 0.050109458607039414, 0.011022207527275896, 0.01070178712325287, 0.05093349485832732, 0.05605973521596752, 0.07419968722388148, 0.04114679715712555, 0.037294523790478706, 0.04250237070664298, 0.06574644707143307, 0.04912538192002103, 0.029974767639942, 0.0357453795731999, 0.008461001161776949, 0.04277298372471705, 0.05409952653280925, 0.026885364568443038, 0.05326132639311254, 0.10322349466150627, 0.025640107560320757, 0.01338635420324863, 0.05378071473387536, 0.06931578405783512, 0.07016028132056817, 0.03564554586773738, 0.02089923480525613, 0.03522603576129768, 0.018728623545030132, 0.08147594795445912, 0.05837498734763358, 0.039019249015836976, 0.060718574677594006, 0.028199917760503013, 0.027063795423600823, 0.06632670265389606, 0.041247206027037464, 0.03310684420284815, 0.01858603656728519, 0.021271366204018705, 0.030318574972625356, 0.046266770077636465, 0.03153904981445521, 0.02550003646319965, 0.05101323862618301, 0.025007712392834947, 0.051614285475807264, 0.048097140024765395, 0.12322793685598299, 0.13629874563775957, 0.10060289700049907, 0.14036233071237803, 0.18184669374022633, 0.11399864772101864, 0.18693804944632575, 0.1335703584481962, 0.09011539295897819, 0.1582856275490485, 0.15163417352596298, 0.2568445756332949, 0.2232718185405247, 0.10594705789117143, 0.13204953458625823, 0.11687533828080632, 0.07205922942375764, 0.11607110995100811, 0.1981853717006743, 0.10247109792544506, 0.2102767681935802, 0.17305283749010414, 0.15154202847043052, 0.07460122622433119, 0.13847963564330712, 0.11892965500010177, 0.21085528715047985, 0.08268485456937924, 0.11341215067659505, 0.2286437654402107, 0.1436575554544106, 0.14796745934290811, 0.2594861760735512, 0.14082915644394234, 0.13014245254453272, 0.11961863521719351, 0.2557068632449955, 0.15802123001776636, 0.22060197195969522, 0.13025711436057463, 0.1955732493661344, 0.19222585164243355, 0.1513047341722995, 0.1682179977069609, 0.16806803934741765, 0.32481066766195, 0.2000511606456712, 0.23561918176710606, 0.1408879939117469, 0.22891585162142292, 0.2772436325903982, 0.2595333766657859, 0.2842202363535762, 5.042363628745079, 44.013258665800095, 72.68227189779282, 109.90198150277138, 108.99243950843811, 106.80716156959534, 82.0125724375248, 97.81142547726631, 79.10690635442734, 91.96333408355713, 51.446514800190926, 56.404207572340965, 38.280738070607185, 44.96595114469528, 70.2083158493042, 44.11733888089657, 89.87409219145775, 52.69185617566109, 128.32248866558075, 69.51129645109177, 120.78256085515022, 95.35878628492355, 108.49242433905602, 104.56589743494987, 138.20384323596954, 104.90774989128113, 95.63601180911064, 96.67350053787231, 101.00083753466606, 116.99753075838089, 106.82121321558952, 119.3227931857109, 109.82593238353729, 106.74937427043915, 133.60472202301025, 124.27236199378967, 123.63607093691826, 124.19071957468987, 99.93902251124382, 112.36997187137604, 105.94837725162506, 78.05345088243484, 115.47515764832497, 88.71947854757309, 113.5504013299942, 155.49174517393112, 82.35401451587677, 70.96781149506569, 90.43466091156006, 99.15220633149147, 61.57903589308262, 50.45731768012047, 61.6988168656826, 33.863839879631996, 47.69838832318783, 52.367763966321945, 56.98971055448055, 91.20772942900658, 93.2878290116787, 84.89767402410507, 100.20316913723946, 102.42010697722435, 119.93610307574272, 124.39547538757324, 118.97127404808998, 48.52590411901474, 6.113308612257242, 0.27864831034094095, 0.6522274611052126, 0.14545238023856655, 0.1581350457854569, 0.25795108813326806, 0.3288458433235064, 0.17215498723089695, 0.1788667481741868, 0.1801682377117686, 0.19934560084948316, 0.1906884927302599, 0.03979864879511297, 0.22197012120159343, 0.18271531822392717, 0.1493092771852389, 0.14325703319627792, 0.0703897385392338, 0.12443405299563892, 0.14178502780850977, 0.20222443621605635, 0.08832329927827232, 0.1473578592413105, 0.1974502595840022, 0.17320727842161432, 0.15659657365176827, 0.1300004796939902, 0.17550520511576906, 0.14669023803435266, 0.0925220591307152, 0.1701243969728239, 0.22502947656903416, 0.09151476435363293, 0.13074218208203092, 0.24484036664944142, 0.12404516761307605, 0.08619592554168776, 0.10580547837889753, 0.15516335290158167, 0.2291742674424313, 0.16115521575557068, 0.215453470882494, 0.15525126771535724, 0.12568983365781605, 0.13938498159404844, 0.10255980683723465, 0.23832680366467685, 0.1639076040009968, 0.0807587661256548, 0.059926205867668614, 0.12445887041394599, 0.1759573066374287, 0.1742915710201487, 0.14216518553439528, 0.1284287148155272, 0.08153336792020127, 0.11748669727239758], [0.02755944246018771, 0.015105213678907603, 0.014320083591883304, 0.06671379203908145, 0.02661470145540079, 0.04587512019497808, 0.020590341810020618, 0.04154562731855549, 0.09622026263969019, 0.025593051686882973, 0.0457702547282679, 0.06259997098823078, 0.04975948773790151, 0.01887034777610097, 0.008422213741141604, 0.024550083726353478, 0.05398795576184057, 0.04524008298176341, 0.029301224094524514, 0.039376511485897936, 0.02143871122825658, 0.016877070847840514, 0.04438143667357508, 0.09463787762797438, 0.029118473939888645, 0.023763934113958385, 0.08099548154859804, 0.03671865430078469, 0.04864726812229492, 0.03560397446563002, 0.05593886162387207, 0.03353504856931977, 0.035083328184555285, 0.014213204121915624, 0.020738878956763074, 0.08661576590384357, 0.009729889079608256, 0.024742761961533688, 0.017670467532298062, 0.051003650078200735, 0.055231349979294464, 0.038354882126441225, 0.012431158193066949, 0.03516320553899277, 0.19351062801433727, 0.07445129755069502, 0.029930930832051672, 0.0024079477680061245, 0.052043881369172595, 0.0665324779401999, 0.23645426117582247, 2.914517233148217, 26.17197722196579, 73.67407187819481, 87.24737673997879, 87.98334404826164, 77.21159845590591, 67.96885281801224, 58.10786135494709, 61.01483836770058, 63.72126214206219, 32.15860158205032, 37.45883837342262, 54.37750652432442, 58.703464195132256, 81.96175396442413, 52.84158334136009, 62.65425659716129, 71.59176841378212, 58.56053106486797, 67.59910985827446, 58.07887651026249, 63.568571135401726, 60.455356389284134, 57.86065801978111, 46.78717061877251, 53.31214249134064, 38.292931616306305, 41.80365823209286, 47.24587060511112, 37.68141523003578, 36.68317459523678, 25.162135809659958, 21.695315837860107, 20.79527523368597, 19.90384116768837, 22.432823963463306, 17.529340982437134, 26.492824405431747, 31.938802376389503, 37.47529149055481, 53.107246086001396, 56.054797321558, 48.37873801589012, 68.17594170570374, 65.90945452451706, 57.078295201063156, 62.08793878555298, 79.07009392976761, 82.58161470293999, 84.1845814883709, 76.25137478113174, 76.09188213944435, 53.68909366428852, 58.808414563536644, 75.94531640410423, 83.92329230904579, 60.87257020175457, 56.65882050991058, 34.651127234101295, 24.2824013158679, 28.640332370996475, 33.17183621227741, 51.98096752166748, 86.01690396666527, 74.66239884495735, 73.31515073776245, 79.62924912571907, 94.70832958817482, 73.68591964244843, 35.53942456841469, 7.476777099072933, 0.34109092375729233, 0.24651101528434083, 0.024323420693690423, 0.10182483572862111, 0.045420732858474366, 0.07874580929637887, 0.01891735169920139, 0.039701056375633925, 0.05221584069659002, 0.011833199605462141, 0.016372698009945452, 0.0436171284673037, 0.09849689711700194, 0.030661959281133022, 0.028710461556329392, 0.016783120518084615, 0.01752329037117306, 0.031362878798972815, 0.024659856644575484, 0.03965213771152776, 0.0429770298069343, 0.02105896910506999, 0.0721415929729119, 0.07151044090278447, 0.06654499797150493, 0.023664413965889253, 0.024805840803310275, 0.07048402840155177, 0.024524423970433418, 0.018728614268184174, 0.007899382762843743, 0.018263376732647885, 0.08656703648739494, 0.018737289974524174, 0.02337503945454955, 0.015992937333066948, 0.021991459107084665, 0.02698573262023274, 0.013351487177715171, 0.05405213298217859, 0.020637477464333642, 0.04366970591945574, 0.05908325227210298, 0.03817996534053236, 0.04346112902567256, 0.00904561778952484, 0.03315309855679516, 0.024771379175945185, 0.022031932130630594, 0.006856062746010139, 0.028290702830418013, 0.058645526150939986, 0.05194245575694367, 0.07388345809886232, 0.030296405166154727, 0.010936985781881958, 0.015830267839191947, 0.03608819984947331, 0.04707833082647994, 0.04336253841756843, 0.021902605476498138, 0.013937513886048691, 0.048975872559822164, 0.03191616844560485, 0.03561920704669319, 0.08326593393576331, 0.03430209158977959, 0.03731227225216571, 0.04733754074550234, 0.022196852187335026, 0.04223295625706669, 0.0293994046660373, 0.054331032079062425, 0.07253973293700255, 0.01990371605643304, 0.024104457443172578, 0.04390799098473508, 0.017196713852172252, 0.029667108465218917, 0.046385543391807005, 0.03178731676598545, 0.03758810998988338, 0.08992353294161148, 0.016770947440818418, 0.06982243343372829, 0.03263014048570767, 0.053810356112080626, 0.01152284179624985, 0.0930319368490018, 0.014983740802563261, 0.039790073278709315, 0.009488886826147791, 0.03960777212341782, 0.08233869462856092, 0.0965324322169181, 0.06639270926825702, 0.05977693399472628, 0.03235966476495378, 0.1569523147190921, 0.03486766749119852, 0.05434483602584805, 0.05261045545921661, 0.05441492816316895, 0.026379559385532048, 0.2510852721752599, 6.985207926481962, 40.127233788371086, 90.34775957465172, 101.58517017960548, 101.15607440471649, 91.91671818494797, 88.9484390616417, 88.30971613526344, 82.09461763501167, 82.25588858127594, 45.89511148631573, 46.866274774074554, 35.96241407096386, 38.70139829814434, 49.10308554768562, 33.25623728334904, 53.42995136976242, 54.30135481059551, 57.7495101839304, 71.82631462812424, 63.01155522465706, 66.87190487980843, 62.31433443725109, 56.65819734334946, 52.52235867083073, 55.79090528190136, 42.08725221455097, 44.25099290907383, 52.66152240335941, 37.12802812457085, 33.50851334631443, 24.559818729758263, 21.30552515387535, 18.575044870376587, 19.248412437736988, 21.87434133142233, 19.163865074515343, 27.0697208493948, 29.95202388614416, 37.57171131670475, 49.826988503336906, 50.44718362390995, 51.44314058125019, 69.98898401856422, 62.40180194377899, 55.453031212091446, 64.70131695270538, 77.84499406814575, 75.66202640533447, 75.99223628640175, 73.9621040225029, 75.60740813612938, 51.96487918496132, 48.660067319869995, 57.42409564554691, 40.350840389728546, 35.53107641637325, 41.49675250053406, 24.496877007186413, 28.709832541644573, 44.829454869031906, 48.324476927518845, 78.23179811239243, 110.94701662659645, 94.25576627254486, 88.51982206106186, 94.42117899656296, 108.57926487922668, 98.71379345655441, 56.674266681075096, 16.44930023699999, 0.07816363155143335, 0.2821982401655987, 0.11928990090382285, 0.09191650373395532, 0.048448539528180845, 0.11244003369938582, 0.08177075869753025, 0.04666954846470617, 0.09628423576941714, 0.040599975327495486, 0.03221446728275623, 0.03497904159303289, 0.03829024477454368, 0.030091206899669487, 0.061831618077121675, 0.07318354604649357, 0.0813176404335536, 0.04200247487460729, 0.0679926757584326, 0.013010431357542984, 0.02391981481196126, 0.05544920371903572, 0.017600494138605427, 0.02544917893828824, 0.02096772204822628, 0.0335042123333551, 0.09350711916340515, 0.05076679364719894, 0.037252106340019964, 0.027217308670515195, 0.028894757233501878, 0.028200390879646875, 0.03279251868661959, 0.019717123432201333, 0.06174916175950784, 0.03856070194160566, 0.04533227998763323, 0.04601246946549509, 0.05111620790557936, 0.06988806155277416, 0.005163599607840297, 0.08352873584954068, 0.026842835795832798, 0.024283246384584345, 0.08891277975635603, 0.03494111784675624, 0.03908989776391536, 0.049319008248858154, 0.01224310075485846, 0.04507243924308568, 0.04393039271235466, 0.04458373870875221, 0.04147413252212573, 0.050449863192625344, 0.10145983265829273, 0.06273591017816216, 0.14904416719218716, 0.12980743224034086, 0.07022012810921296, 0.09576948956237175, 0.18860584823414683, 0.20820001635001972, 0.15705508732935414, 0.13594160933280364, 0.12579823174746707, 0.30830322531983256, 0.15340049983933568, 0.10329511933377944, 0.09575305099133402, 0.15189325727988034, 0.15493120910832658, 0.11707635640050285, 0.166853143600747, 0.1558108619065024, 0.2293823062791489, 0.1940017961896956, 0.1072059481521137, 0.18662564980331808, 0.12133131167502142, 0.09798534956644289, 0.14212174020940438, 0.1886303094215691, 0.1918426511110738, 0.12774576083756983, 0.20618149341316894, 0.11628369815298356, 0.13786748255370185, 0.14579336741007864, 0.2054004423553124, 0.20303220459027216, 0.14779599354369566, 0.09890035827993415, 0.10497166804270819, 0.2551397733623162, 0.20876649767160416, 0.14076102728722617, 0.08414196505327709, 0.07910248546977527, 0.32768165110610425, 0.2259518622304313, 0.2235562540590763, 0.1160517250536941, 0.19054934004088864, 0.1444787863874808, 0.3719290893059224, 6.233371244743466, 40.37478670477867, 99.1244526207447, 112.66231298446655, 112.0223893225193, 95.80167531967163, 89.65046659111977, 82.71330803632736, 79.69661191105843, 82.10062131285667, 45.272799879312515, 60.74150763452053, 77.6948793232441, 80.12155070900917, 113.0198509991169, 72.78289809823036, 93.81476193666458, 100.59104472398758, 81.34313195943832, 97.92674168944359, 86.69367045164108, 97.06152811646461, 85.47447547316551, 81.58563494682312, 69.61234822869301, 79.09707248210907, 57.63394318521023, 62.01801493763924, 75.9208533167839, 57.242131009697914, 53.65627482533455, 37.29127116501331, 33.9189825206995, 29.213966690003872, 32.20080591738224, 34.651366621255875, 28.95618662238121, 41.75122484564781, 46.35117821395397, 57.31178127229214, 82.7908618748188, 80.97045555710793, 73.34474354982376, 107.63750061392784, 98.89834195375443, 81.4673624932766, 91.34058550000191, 111.76493793725967, 119.12893518805504, 118.05144980549812, 109.89595502614975, 109.30520832538605, 80.35548895597458, 81.76857233047485, 109.79520723223686, 116.20097190141678, 82.83378437161446, 81.02542340755463, 54.11495961248875, 36.11805371940136, 41.755583211779594, 46.89695052802563, 71.98270663619041, 113.58079209923744, 96.01157605648041, 92.85342872142792, 99.50234234333038, 122.67547488212585, 106.20250001549721, 58.36395241320133, 15.101485010236502, 0.2764428552472964, 0.46233472879976034, 0.2019543686765246, 0.2641441026935354, 0.259468512958847, 0.1790393123519607, 0.14127163973171264, 0.11251403324422427, 0.2000616694567725, 0.18661199428606778, 0.20251219655619934, 0.12439313839422539, 0.10765842074761167, 0.15163993259193376, 0.15635265939636156, 0.14279712428105995, 0.13346053543500602, 0.10126980574568734, 0.10866944852750748, 0.11633396381512284, 0.07815015414962545, 0.1626692118588835, 0.17094328271923587, 0.17358001467073336, 0.17477629735367373, 0.09155219086096622, 0.21185308985877782, 0.13911722955526784, 0.148279502755031, 0.046238160284701735, 0.07202311651781201, 0.11766781099140644, 0.084881500370102, 0.13718046160647646, 0.12885886360891163, 0.12177426251582801, 0.15164327225647867, 0.13026217580772936, 0.1003351152758114, 0.13266376568935812, 0.11571957686101086, 0.1532345259329304, 0.18341798364417627, 0.11741625261493027, 0.1336276374058798, 0.11156881912029348, 0.09065872669452801, 0.08047080540563911, 0.076045816676924, 0.09718231609440409, 0.09266176843084395, 0.14901976537657902, 0.11776178915170021, 0.21383915125625208], [0.03413298953091726, 0.023001254921837244, 0.03332173677335959, 0.028420886665116996, 0.06437911419197917, 0.10746293904958293, 0.02437012219161261, 0.0371347765030805, 0.05729177086323034, 0.010336147661291761, 0.05024567239161115, 0.04740629701700527, 0.0038167365528352093, 0.018811232002917677, 0.010595572803140385, 0.057183996177627705, 0.05174828023882583, 0.049108338498626836, 0.05037367431214079, 0.04633459866454359, 0.044648320399574004, 0.08221120850066654, 0.03545907384250313, 0.03451423821388744, 0.0525191638735123, 0.05242297411314212, 0.024157027473847847, 0.02530601865146309, 0.0947918213205412, 0.007648702439837507, 0.046677107238792814, 0.06693987990729511, 0.04643567175662611, 0.03153561738145072, 0.06093035022786353, 0.017547534480399918, 0.08838622597977519, 0.06504239383502863, 0.04652739749872126, 0.04708090978965629, 0.032852120566531084, 0.08300561079522595, 0.07216983911348507, 0.06771163185476325, 0.08315611092257313, 0.03850181252346374, 0.06589694719878025, 0.07098792440956458, 0.07123967574443668, 0.2143537564552389, 16.42578899860382, 76.89972639083862, 99.36748757958412, 82.50830143690109, 72.25902020931244, 54.41514350473881, 59.058262556791306, 66.1922961473465, 26.093201749026775, 30.79903643578291, 39.68889310956001, 60.18051713705063, 27.507153376936913, 100.96430629491806, 87.07556515932083, 56.89778208732605, 84.69474971294403, 55.46300187706947, 66.69989570975304, 46.32621355354786, 27.980486378073692, 19.69315767288208, 15.695264898240566, 11.167038381099701, 14.702550116926432, 11.180377565324306, 5.136517351493239, 4.904480427503586, 3.820448233745992, 2.5947152310982347, 1.4556043990887702, 0.4927505529485643, 0.2633418410550803, 0.18778625002596527, 0.15911736729322, 0.25159218872431666, 0.22949787351535633, 0.5490583658684045, 0.7011838559992611, 0.7286388671491295, 1.813902254216373, 3.332057590596378, 3.580117542296648, 5.3526953514665365, 2.7492690877988935, 3.8086232682690024, 4.855998354032636, 8.430709261447191, 4.781378908082843, 9.235671367496252, 16.666971556842327, 24.48080576956272, 24.428784660995007, 40.4430728405714, 46.27417914569378, 60.12505531311035, 70.18359437584877, 69.39494669437408, 60.327835232019424, 88.4598308801651, 88.28768491744995, 47.59429670870304, 42.8723356872797, 34.59162622690201, 54.883988946676254, 79.53068241477013, 71.97133004665375, 60.61376228928566, 68.40016007423401, 77.16574251651764, 90.80118164420128, 71.32886812090874, 21.75474464893341, 5.410904427990317, 0.5842800415121019, 0.4660735500510782, 0.031445516942767426, 0.014070170000195503, 0.08345423164428212, 0.05331512467819266, 0.03577099480025936, 0.05782233223726507, 0.05196979647735134, 0.014810872344241943, 0.06919039820786566, 0.13805054069962353, 0.05237486067926511, 0.025063566426979378, 0.05817043660499621, 0.04201637901132926, 0.039005441358312964, 0.03907640551915392, 0.02570780441601528, 0.03165909962262958, 0.029909955883340444, 0.026967229023284744, 0.04688578061177395, 0.01711123884888366, 0.04945304011926055, 0.026361322961747646, 0.014241811131796567, 0.02243018156150356, 0.034890432871179655, 0.04174951012828387, 0.01686834319116315, 0.035499175792210735, 0.04768519982462749, 0.02279149615787901, 0.06413215713109821, 0.033657488093012944, 0.045533732263720594, 0.04971831338480115, 0.05434142214653548, 0.04542522656265646, 0.03730396390892565, 0.03924239797925111, 0.06748046027496457, 0.041650281273177825, 0.0726135766308289, 0.07102690200554207, 0.038093108087196015, 0.0633972899231594, 0.06304802038357593, 0.09440934809390455, 0.03267481406510342, 0.01531277197500458, 0.052724208144354634, 0.06332544260658324, 0.05688646175258327, 0.03574460031813942, 0.020407600932230707, 0.1599091646494344, 0.021717211420764215, 0.008394258893531514, 0.021489143873623107, 0.052397793042473495, 0.02137861210940173, 0.0613310320477467, 0.01590199455677066, 0.037247553264023736, 0.10584318690234795, 0.025084164735744707, 0.12369670701446012, 0.0471686168020824, 0.044564364943653345, 0.02437279577861773, 0.033656100276857615, 0.0387716759723844, 0.08451271976809949, 0.023183556077128742, 0.03301495889900252, 0.03534714684064966, 0.03319569783343468, 0.016336544285877608, 0.06600827677175403, 0.03892788692610338, 0.08460464217932895, 0.04100639394891914, 0.013954356927570188, 0.04815860098460689, 0.0373219684115611, 0.05232603849435691, 0.0204549202680937, 0.012108913961128565, 0.10901310000917874, 0.07658739894395694, 0.03346318640979007, 0.05751012184191495, 0.07542795647168532, 0.022377975183189847, 0.1333984622033313, 0.05812645693367813, 0.044787417427869514, 0.030153012958180625, 0.13526819937396795, 0.8585839380975813, 28.753894977271557, 98.17916214466095, 112.25435927510262, 94.70824599266052, 87.75892809033394, 81.90404266119003, 96.21105775237083, 94.23579454421997, 45.939287915825844, 29.136572442948818, 39.73079726099968, 31.832185797393322, 26.278555803000927, 100.88024720549583, 82.20513850450516, 62.8506338596344, 83.50330084562302, 60.18223084509373, 68.11300948262215, 51.19363836944103, 30.3864336758852, 20.333280824124813, 15.189424641430378, 11.426113229244947, 15.505265593528748, 10.771958380937576, 4.435536190867424, 4.599571488797665, 3.3266348065808415, 1.8638554424978793, 1.461469503119588, 0.20749821182107553, 0.16284409153740853, 0.21840413130121306, 0.032688569772290066, 0.3002424328587949, 0.1526339800329879, 0.5400090920738876, 0.5121083173435181, 1.1834168108180165, 1.4940116694197059, 2.1692755725234747, 3.6171220941469073, 4.980823080986738, 2.3941881163045764, 2.585513312369585, 4.050734639167786, 6.103127058595419, 3.4474360244348645, 7.420694958418608, 14.520038310438395, 23.821867927908897, 23.986999467015266, 38.507544100284576, 47.51913294196129, 64.26136896014214, 74.7163787484169, 52.37880617380142, 42.563100680708885, 66.85154557228088, 60.069962069392204, 27.296179197728634, 27.880870923399925, 33.380532413721085, 77.50645503401756, 112.78790384531021, 99.81271728873253, 85.15141680836678, 89.84930992126465, 89.80162248015404, 101.58564135432243, 90.64698591828346, 41.88701435923576, 13.255089987069368, 1.044872326310724, 0.425846207072027, 0.0524105616932502, 0.05089179358037654, 0.03223647938284557, 0.03067391342483461, 0.11351963592460379, 0.029929600532341283, 0.03180795218213461, 0.0434183182369452, 0.07445621798979118, 0.052246944105718285, 0.15913289302261546, 0.03061288476601476, 0.07311209206818603, 0.06133711394795682, 0.027510460713529028, 0.08992803777800873, 0.07234319738927297, 0.02409156262729084, 0.0679552937799599, 0.0399945089884568, 0.07324150778003968, 0.0919419816636946, 0.04673517287301365, 0.03403498893021606, 0.02053473268460948, 0.04844384915486444, 0.0518218085198896, 0.11783058624132536, 0.017948151362361386, 0.04219830167130567, 0.04040315776364878, 0.023933019474497996, 0.08216460162657313, 0.04857942840317264, 0.04906097463390324, 0.017154593260784168, 0.01349310750811128, 0.01520366606200696, 0.005090165486762999, 0.026732203841675073, 0.07424175215419382, 0.07967190569615923, 0.05045889141911175, 0.07398879111860879, 0.07049456689856015, 0.04143761885643471, 0.033471238712081686, 0.06622605258598924, 0.027715345422620885, 0.05190516654693056, 0.0897469166375231, 0.17003495333483443, 0.19945128267863765, 0.0724378286395222, 0.13193347753258422, 0.2458080678479746, 0.11261007457505912, 0.08465975406579673, 0.1442471324116923, 0.12166734872153029, 0.08275808228063397, 0.18996102473465726, 0.16693639772711322, 0.08092848787782714, 0.17909816466271877, 0.11369872358045541, 0.19909763446776196, 0.12255075678694993, 0.13786815048661083, 0.09110366649110802, 0.08838831883622333, 0.17594908364117146, 0.19469236460281536, 0.15371088084066287, 0.18507862812839448, 0.09958315640687943, 0.17046910972567275, 0.16697118961019441, 0.26845678221434355, 0.09066722428542562, 0.14013324456755072, 0.15339002071414143, 0.11417172398068942, 0.15822120913071558, 0.1340919843642041, 0.16733803320676088, 0.2255519782193005, 0.1533379961620085, 0.19109259214019403, 0.24388443591305986, 0.09798025101190433, 0.12047897733282298, 0.16074102313723415, 0.13586640008725226, 0.1832760256365873, 0.14724704175023362, 0.1899121914175339, 0.16300354938721284, 0.2654840057948604, 0.5765433004125953, 29.025943279266357, 106.99411153793335, 125.14511436223984, 105.16416013240814, 94.91603404283524, 73.16663190722466, 78.70551109313965, 85.79653859138489, 38.80224868655205, 46.38680510222912, 58.66126365959644, 92.5401583313942, 41.911454647779465, 133.26008051633835, 110.90912505984306, 81.05136081576347, 115.42015939950943, 79.71113473176956, 96.69933915138245, 69.38836544752121, 43.631466552615166, 33.768164813518524, 26.92002408206463, 22.41055715829134, 28.894576728343964, 20.894751995801926, 9.782191291451454, 10.521810203790665, 9.067181758582592, 4.654798675328493, 4.180333809927106, 1.0329723148606718, 1.1180163826793432, 0.5523764190729707, 0.648851104779169, 0.4777164221741259, 0.6577173946425319, 2.1508396742865443, 1.5964449103921652, 3.190541071817279, 4.555185595527291, 5.262617385014892, 8.960108254104853, 11.887036096304655, 6.152297370135784, 6.9242150243371725, 10.112946443259716, 13.995014782994986, 9.181903302669525, 16.72627877444029, 25.891643464565277, 39.575951769948006, 39.56602290272713, 64.63432654738426, 71.97139084339142, 88.5158322751522, 106.56759202480316, 98.67479234933853, 87.71398410201073, 111.92554771900177, 115.20921751856804, 68.18298652768135, 63.36962141096592, 49.167427495121956, 72.36767917871475, 103.51542100310326, 96.18527993559837, 83.1876289844513, 87.95418441295624, 97.28681042790413, 114.43643778562546, 103.77242401242256, 43.167298659682274, 11.802260745316744, 0.7693368208128959, 0.7956314692273736, 0.16329068632330745, 0.15876606426900253, 0.1821236780961044, 0.1279560409602709, 0.27456442010588944, 0.20500808372162282, 0.10329757584258914, 0.146999565185979, 0.15361572266556323, 0.2009491148055531, 0.22875032300362363, 0.1465403984184377, 0.10143193532712758, 0.219110329344403, 0.12775733834132552, 0.1611038888222538, 0.13804249581880867, 0.0990759875276126, 0.13169314042897895, 0.18094462808221579, 0.2920072653796524, 0.10738178520114161, 0.13717209018068388, 0.11619723052717745, 0.14177190663758665, 0.08482876335619949, 0.12013087296509184, 0.17366923566441983, 0.16060518042650074, 0.10091747113619931, 0.13865375833120197, 0.08245965727837756, 0.17669028136879206, 0.13951902830740437, 0.1038741206866689, 0.23597275576321408, 0.08187752406229265, 0.1132984017021954, 0.12346226998488419, 0.13654616283020005, 0.13458113389788195, 0.160340070433449, 0.11164422132424079, 0.14499462355161086, 0.22105073381680995, 0.1102863805135712, 0.11671926462440751, 0.21612989396089688, 0.10991395596647635, 0.12706650275504217], [0.038521316164406016, 0.0851020221307408, 0.05519503669347614, 0.07709389989031479, 0.0531474883609917, 0.032383877332904376, 0.021032602453487925, 0.0790207453246694, 0.013126931844453793, 0.038067069835960865, 0.05303544632624835, 0.03476357014733367, 0.07937783710076474, 0.056160337044275366, 0.08494093897752464, 0.04452535395103041, 0.05241884406132158, 0.03389949502889067, 0.05354230721422937, 0.0707666456582956, 0.0074252524427720346, 0.012911754474771442, 0.031069763863342814, 0.04125652740185615, 0.028896749900013674, 0.06037776191078592, 0.009187684336211532, 0.026856025615416, 0.044076566118746996, 0.049550038820598274, 0.04018967898446135, 0.06816691718995571, 0.04362791558378376, 0.0645227642962709, 0.06143588638224173, 0.05144648588611744, 0.07809157643350773, 0.007643431799806422, 0.043070210158475675, 0.03126157935184892, 0.04521469782048371, 0.05144326867593918, 0.06123467901488766, 0.030957701419538353, 0.0953213288448751, 0.01898765349324094, 0.11879416852025315, 0.08671156974742189, 7.93953194282949, 55.03419108688831, 90.06805658340454, 85.77153593301773, 67.6383389532566, 76.29810467362404, 57.05496445298195, 42.94244572520256, 33.37139390408993, 36.67166121304035, 35.91709390282631, 51.792402639985085, 44.92569610476494, 59.44313630461693, 57.673943638801575, 42.672880589962006, 46.28033481538296, 30.48258561640978, 20.247348435223103, 11.663111262023449, 8.13618041574955, 6.418285947293043, 2.1021160762757063, 0.11698706861352548, 0.12425959634128958, 0.08156504278304055, 0.01607390193385072, 0.11001138511346653, 0.04962977887771558, 0.07697538632783107, 0.10125920045538805, 0.279507331433706, 0.05629229090118315, 0.17663212667685002, 0.23888985626399517, 0.09188922980683856, 0.10814990062499419, 0.03970333105826285, 0.18777384131681174, 0.05508027468749788, 0.10782642813865095, 0.038558965316042304, 0.062188353622332215, 0.15002092259237543, 0.07478829938918352, 0.06035786122083664, 0.11967543177888729, 0.11639416683465242, 0.08896320126950741, 0.04278825712390244, 0.056562722093076445, 0.0886262216954492, 0.20292150584282354, 0.26022428646683693, 1.0672030155546963, 1.2927102274261415, 4.5309158228337765, 13.312065079808235, 25.95784731209278, 46.265223026275635, 59.35948759317398, 42.89264939725399, 85.4061171412468, 81.13841414451599, 49.2313514649868, 51.32783196866512, 43.65607023239136, 31.29689522087574, 34.17442761361599, 45.45887969434261, 53.95879939198494, 69.97806340456009, 59.12767343223095, 74.97455209493637, 83.21914449334145, 75.76251581311226, 48.343540504574776, 15.297441445291042, 0.8501164487097412, 0.20632103201933205, 0.06746137965819798, 0.014341765436256537, 0.06856741718365811, 0.05880179276573472, 0.05319824012985919, 0.05174358986550942, 0.03452029042819049, 0.08978494428447448, 0.11134757005493157, 0.02646642406034516, 0.02083590363326948, 0.11765362854930572, 0.035670496872626245, 0.02028641934884945, 0.08819166454486549, 0.07321015204070136, 0.01683667203906225, 0.03782640618737787, 0.07405126511002891, 0.06284869436058216, 0.0248932565227733, 0.03957361106586177, 0.07751688695861958, 0.007941284420667216, 0.07702953342231922, 0.013885007865610532, 0.08693003575899638, 0.02392509333731141, 0.04792680229002144, 0.041038417621166445, 0.0564986599056283, 0.03793643700191751, 0.04184745135717094, 0.0377200564253144, 0.051031135517405346, 0.04284081231162418, 0.0730671921337489, 0.032445620308863, 0.030944418831495568, 0.03122678375802934, 0.049931265239138156, 0.02666273696377175, 0.03684255585540086, 0.04717596777481958, 0.016092281221062876, 0.04044224297103938, 0.07367332640569657, 0.0251136242877692, 0.05901362768781837, 0.03194425502442755, 0.06601048095035367, 0.018805662184604444, 0.08564078423660249, 0.09150364698143676, 0.01935796106408816, 0.016420271531387698, 0.0437362209049752, 0.06901361863128841, 0.07919766590930521, 0.04160054995736573, 0.07413284198264591, 0.05618098359263968, 0.07882853649789467, 0.04837305939872749, 0.056759680664981715, 0.014680132826470071, 0.011769142056436976, 0.041837610478978604, 0.08625123038655147, 0.030809999188932125, 0.0752129043394234, 0.060030867243767716, 0.03505387605400756, 0.09381568932440132, 0.06497160778963007, 0.043118420071550645, 0.00646780215902254, 0.02618909831653582, 0.027578153858485166, 0.023291286233870778, 0.037004496189183556, 0.04030963602417614, 0.03733425466634799, 0.017619023710722104, 0.006213814176589949, 0.051740357812377624, 0.06595917628146708, 0.029282189861987717, 0.08554010448278859, 0.07793467899318784, 0.047758824584889226, 0.08214183253585361, 0.13308045192388818, 0.013322792965482222, 0.08623574918601662, 0.0814466924930457, 14.961102493107319, 72.87162333726883, 107.47660204768181, 92.49458357691765, 87.44253426790237, 92.266094237566, 81.56755551695824, 67.73412421345711, 47.243556529283524, 36.456889137625694, 24.4931798055768, 36.04070886969566, 28.336253687739372, 46.930795311927795, 47.398614808917046, 47.191875502467155, 43.457226902246475, 29.30189587175846, 17.24397249519825, 10.29013093560934, 5.962512753903866, 5.008245734497905, 1.4640264096669853, 0.05758557599619962, 0.10018152781412937, 0.062268305191537365, 0.15919061726890504, 0.15145849232794717, 0.08143026876496151, 0.02120531877153553, 0.10699911159463227, 0.3200385393574834, 0.06600426917430013, 0.15772702783579007, 0.22299723874311894, 0.12756390497088432, 0.11845586792333052, 0.17988424748182297, 0.21675236290320754, 0.011567346537049161, 0.11999274443951435, 0.022583225400012452, 0.16189513698918745, 0.061458232448785566, 0.03629078019002918, 0.023278580665646587, 0.28407338017132133, 0.0020262489260858274, 0.07308725238544866, 0.0590992047364125, 0.12311045487876981, 0.1196577463997528, 0.10910102966590784, 0.06307827774435282, 0.3317831450840458, 0.44313557620625943, 1.981078558601439, 9.025652837008238, 20.910941027104855, 42.15899236500263, 55.932880863547325, 44.71202217042446, 82.4778650701046, 76.26731112599373, 37.17935957014561, 39.94127556681633, 34.556174129247665, 37.12719216942787, 58.113732039928436, 65.59062123298645, 83.95850121974945, 96.59547552466393, 81.06242582201958, 86.43567949533463, 93.40304642915726, 94.59519445896149, 67.00375020503998, 25.975259877741337, 1.3698218646459281, 0.22043693315936252, 0.018889805032813456, 0.039663715215283446, 0.05277032520098146, 0.029181662248447537, 0.044262726441957057, 0.07182227651355788, 0.03244347179133911, 0.05112921404361259, 0.05401644310040865, 0.05587375671893824, 0.026579679506539833, 0.10001653354265727, 0.010555231510807062, 0.010359993793827016, 0.10135538279428147, 0.037617473062709905, 0.04945004555338528, 0.04264795410563238, 0.06848964010714553, 0.0424322525941534, 0.03838837154034991, 0.016022506351873744, 0.03822930702881422, 0.08216646441724151, 0.04154632493737154, 0.03682566457428038, 0.05254319461528212, 0.018060473557852674, 0.02446812650305219, 0.03155367754516192, 0.002742706465141964, 0.013287753390613943, 0.02629717913805507, 0.029555300206993707, 0.04543459988781251, 0.029562938761955593, 0.01101692807424115, 0.04890129413979594, 0.04284353228285909, 0.06750734828528948, 0.06711321591865271, 0.03204243374057114, 0.05394197229179554, 0.04582870999001898, 0.003391135501260578, 0.0576608297706116, 0.05869442626135424, 0.008214942099584732, 0.14769339904887602, 0.17439900431782007, 0.1831464614951983, 0.11555315024452284, 0.178058311867062, 0.1851039205212146, 0.09796076963539235, 0.23686612345045432, 0.10195252223638818, 0.10754275703220628, 0.2512802492128685, 0.12747417931677774, 0.1721092264051549, 0.16501233534654602, 0.2049314050236717, 0.15670797001803294, 0.1730803563259542, 0.10075860700453632, 0.13095532689476386, 0.23210825922433287, 0.13209311349783093, 0.13099693169351667, 0.14598803274566308, 0.1675348507706076, 0.14697572740260512, 0.13025321066379547, 0.16510234301676974, 0.13286000437801704, 0.07470281139831059, 0.1140599639620632, 0.18023194366833195, 0.12495764560298994, 0.12512339686509222, 0.16831290355185047, 0.13200542132835835, 0.08153089656843804, 0.17670175497187302, 0.11878792705829255, 0.15676842536777258, 0.07221439023851417, 0.1757486889255233, 0.14107820636127144, 0.1835037610726431, 0.20115139457629994, 0.1998941518831998, 0.0935659343667794, 0.2789437444880605, 0.19336564204422757, 14.240067433565855, 76.22465461492538, 118.09268519282341, 100.88691964745522, 85.68082720041275, 96.22035205364227, 74.12984222173691, 58.548500910401344, 44.19018097221851, 50.48103980720043, 56.489505395293236, 75.0544086098671, 65.58907091617584, 89.06480401754379, 81.94612920284271, 60.99175080657005, 66.88841119408607, 46.889487728476524, 31.420821771025658, 21.152564361691475, 13.138701282441616, 9.780092854052782, 4.379617916420102, 0.4951454041292891, 0.4013992688851431, 0.2757986116921529, 0.3780235763406381, 0.3746842680266127, 0.4627931979484856, 0.22097763227066025, 0.30655279580969363, 0.5520856159273535, 0.2911216754000634, 0.5123424797784537, 0.4093431879300624, 0.4690847994061187, 0.28201059554703534, 0.5118949944153428, 0.7345182204153389, 0.19101377605693415, 0.29466278851032257, 0.13176057196687907, 0.39430145756341517, 0.4567725397646427, 0.25815250701271, 0.1824430687702261, 0.6777458230499178, 0.2259602484991774, 0.22574501082999632, 0.10752283036708832, 0.3326807281700894, 0.29335277911741287, 0.5175253422930837, 1.086066272109747, 2.6556658605113626, 3.0224255053326488, 8.600572496652603, 21.78794726729393, 40.02479888498783, 73.69551792740822, 86.039307564497, 64.08705711364746, 114.28173288702965, 107.0125861465931, 70.75108632445335, 75.4310292005539, 62.64087751507759, 45.1593341678381, 47.29306787252426, 59.77178826928139, 72.48845189809799, 90.540432035923, 77.43245780467987, 93.05946126580238, 106.48352533578873, 105.3747296333313, 72.3500557243824, 26.326532028615475, 1.145208792295307, 0.34439805254805833, 0.2999475330580026, 0.1281406873022206, 0.18652053200639784, 0.1093952392693609, 0.1695558673236519, 0.13488496915670112, 0.12999645725358278, 0.19610418181400746, 0.20037984300870448, 0.11164590599946678, 0.07564484913018532, 0.2172219197382219, 0.20039228140376508, 0.058878827694570646, 0.20592907414538786, 0.1290821164730005, 0.12089105483028106, 0.1289568716310896, 0.18196571938460693, 0.10066973482025787, 0.12009936879621819, 0.08813619642751291, 0.23286906449357048, 0.1815664884634316, 0.196617525361944, 0.09835459030000493, 0.14992145996075124, 0.11100747346063145, 0.17171688261441886, 0.17839481646660715, 0.19431991036981344, 0.12036697982694022, 0.15266452683135867, 0.15097057475941256, 0.12058534935931675, 0.16299934883136302, 0.1521330006653443, 0.10900308843702078, 0.15942785219522193, 0.10991135102813132, 0.18803834274876863, 0.1286006555892527, 0.11553435164387338, 0.12933671765495092, 0.13519716099835932, 0.1715827320003882, 0.16488312743604183, 0.13055732793873176], [0.112676274147816, 0.0413369428133592, 0.046871531376382336, 0.03321535361465067, 0.05228009955317248, 0.03474413701042067, 0.012532828714029165, 0.05326707432686817, 0.01179496694021509, 0.051648001244757324, 0.05117247383168433, 0.06900499487528577, 0.06631920696236193, 0.06796340545406565, 0.025056402846530546, 0.02563609439675929, 0.0755611274507828, 0.05179175524972379, 0.06503842334495857, 0.022004452257533558, 0.03248397079005372, 0.0739472456916701, 0.024294105860462878, 0.020044655466335826, 0.04984299790521618, 0.034553160148789175, 0.03947645651351195, 0.0230115559315891, 0.02737729715590831, 0.054597544731223024, 0.1193995309586171, 0.0652382911357563, 0.02460322892147815, 0.0709576670487877, 0.030675948764837813, 0.04758944422064815, 0.014316462838905863, 0.04427885702170897, 0.06099968537455425, 0.06680499456706457, 0.006711752130286186, 0.024816809745971113, 0.07073956468957476, 0.05142464076925535, 0.2927546080900356, 0.04620506049832329, 2.071788003668189, 36.34876973927021, 84.09079492092133, 91.91827610135078, 63.95948275923729, 76.6686075925827, 59.157194048166275, 67.99209237098694, 51.97850905358791, 29.34901524335146, 56.137192100286484, 52.75778263807297, 63.57036463916302, 63.22752043604851, 56.13962396979332, 41.91507585346699, 36.066083908081055, 17.98563189804554, 12.445214744657278, 3.9323693281039596, 1.1474159988574684, 0.12441748825949617, 0.16128512128489092, 0.05849244706041645, 0.07185235575889237, 0.0043818388712679734, 0.2608875883743167, 0.2344526888919063, 0.6023315666243434, 0.21655130025465041, 0.15731095016235486, 0.3118603094480932, 0.23246213007951155, 0.09564597392454743, 0.07915789421531372, 0.1693130366038531, 0.09757934283697978, 0.13380731135839596, 0.13631973357405514, 0.09489244170254096, 0.07737002335488796, 0.06263543080422096, 0.13724829390412197, 0.05309756408678368, 0.06994128838414326, 0.15527056355495006, 0.11588304230826907, 0.05990123259834945, 0.0058292415997129865, 0.06082251617044676, 0.26550600305199623, 0.06237503344891593, 0.11891433707205579, 0.09524036795482971, 0.05687763019523118, 0.0275803153635934, 0.05632520515064243, 0.03363404735864606, 0.06686260006972589, 0.18554903101176023, 0.12010443024337292, 2.496606158092618, 13.926400914788246, 25.847516432404518, 37.27567300200462, 49.991922453045845, 48.02666410803795, 39.83186423778534, 55.13839289546013, 62.41896942257881, 38.297715559601784, 32.92738012969494, 26.92009247839451, 37.346592396497726, 57.56254881620407, 63.842411041259766, 56.56006380915642, 67.09811434149742, 77.6610915362835, 81.09536245465279, 46.119599640369415, 5.194610534235835, 0.3925988223636523, 0.05397327979153488, 0.017333647519990336, 0.05548699387873057, 0.028072513268853072, 0.02308741084561916, 0.011836648736789357, 0.05021192322601564, 0.03475508368865121, 0.02815326450217981, 0.1623691021814011, 0.04617403130396269, 0.0375197396351723, 0.09563018102198839, 0.028331051544228103, 0.044589668468688615, 0.039959984278539196, 0.016632703882351052, 0.05810417023894843, 0.03892507047567051, 0.06529057543957606, 0.021755680645583197, 0.060478029772639275, 0.019529792371031363, 0.08319540022057481, 0.011593087929213652, 0.01931364186020801, 0.03532916831318289, 0.02240136767795775, 0.05764055058534723, 0.025075225566979498, 0.03671518476039637, 0.024204664077842608, 0.009234629815182416, 0.019225812393415254, 0.040243963376269676, 0.048032576887635514, 0.018515695810492616, 0.01291575186769478, 0.06679242258542217, 0.029563411881099455, 0.04588844174577389, 0.011455451076471945, 0.04536154287052341, 0.032708284925320186, 0.020111385674681515, 0.023996178097149823, 0.06404045736417174, 0.07677166679059155, 0.10149459485546686, 0.012243160126672592, 0.027990648814011365, 0.04473670276638586, 0.013554777196986834, 0.030866127817716915, 0.037535410083364695, 0.024304097023559734, 0.024935852088674437, 0.03279883065260947, 0.03387597265827935, 0.030970772495493293, 0.02462518350512255, 0.02412804104096722, 0.01661110552959144, 0.05382336225011386, 0.022899959185451735, 0.07687970864935778, 0.09633322493755259, 0.04890531658020336, 0.08878578344592825, 0.047064081591088325, 0.019061918355873786, 0.01517724282166455, 0.05216300349275116, 0.030483318769256584, 0.0111566800478613, 0.08103933505481109, 0.09350114487460814, 0.031173015158856288, 0.013025748357904376, 0.020148799194430467, 0.05342177872080356, 0.04204875891446136, 0.0124317222253012, 0.05810099755763076, 0.09935296446201392, 0.07133734980016015, 0.1291090712766163, 0.058307244107709266, 0.013832362692483002, 0.06820150869316421, 0.07460398701368831, 0.35915096872486174, 0.04028750518045854, 6.244548344984651, 53.97211007773876, 103.71764615178108, 98.66785392165184, 77.50260204076767, 102.8996716439724, 87.40290999412537, 104.47404876351357, 64.83841359615326, 26.320266164839268, 29.082005470991135, 28.795645236968994, 37.477088794112206, 58.9427525550127, 54.97401371598244, 42.411568611860275, 34.49841342866421, 16.89281053841114, 9.535065852105618, 2.1353483805432916, 0.6738576223142445, 0.17501151363831013, 0.15873525029746816, 0.07330093896598555, 0.031003983604023233, 0.01864807269157609, 0.31787829590030015, 0.3233071358408779, 0.627487760502845, 0.15724501776276156, 0.19188011472579092, 0.3744948422536254, 0.10661949563655071, 0.120061652851291, 0.02256298146676272, 0.032808890464366414, 0.06103162369981874, 0.05073695931059774, 0.1571627432713285, 0.08038890940952115, 0.049321498154313304, 0.13323717867024243, 0.2985955774784088, 0.050874341977760196, 0.18118760723154992, 0.11325863742968068, 0.2156270740670152, 0.06932211457751691, 0.1599386872840114, 0.20963121845852584, 0.40273560967762023, 0.02719652111409232, 0.060332943612593226, 0.10049068427179009, 0.1296346602612175, 0.06544485309859738, 0.07260056678205729, 0.07326354956603609, 0.09826302411966026, 0.26677154295612127, 0.2877453784458339, 0.7166700437664986, 8.543253522366285, 18.004047609865665, 34.20578733086586, 50.7177709043026, 53.403405994176865, 37.452804297208786, 43.5377711802721, 37.73585870862007, 31.7582493647933, 39.42841328680515, 41.51732459664345, 66.82842761278152, 86.56602770090103, 93.43767777085304, 76.98396787047386, 81.64868116378784, 87.89740025997162, 97.34386056661606, 63.21989804506302, 10.797531958669424, 0.2185228155576624, 0.14225416904082522, 0.08215070120058954, 0.017975449409277644, 0.07345291596720926, 0.03843622893327847, 0.021762497271993198, 0.09388261620188132, 0.050477382028475404, 0.050211273846798576, 0.07276571690454148, 0.09013943112222478, 0.03407375872484408, 0.09868152119452134, 0.006952371250008582, 0.045158762150094844, 0.03304136080259923, 0.07354296074481681, 0.0711063266498968, 0.017717269220156595, 0.05239269077719655, 0.08933172954129986, 0.0237704817118356, 0.03914655331755057, 0.03808652894804254, 0.0775568293465767, 0.03736135418876074, 0.044011843419866636, 0.0009996267681344762, 0.06890405536978506, 0.026267441280651838, 0.00586571862186247, 0.022227643894439097, 0.03595178568502888, 0.027905350070795976, 0.029738831472059246, 0.06834854299086146, 0.012328288175922353, 0.004686612019213499, 0.09387057114508934, 0.06347115588141605, 0.04447504004929215, 0.038519019217346795, 0.01697626445093192, 0.09190415439661592, 0.059280604182276875, 0.026960022769344505, 0.041366060977452435, 0.13378486881265417, 0.19947369553847238, 0.08264823700301349, 0.07665454104426317, 0.2052163748885505, 0.1318412582622841, 0.17203554598381743, 0.13215739832958207, 0.10182090976741165, 0.19664355990244076, 0.1348247958230786, 0.1001057396933902, 0.2228612476028502, 0.18109875731170177, 0.18913415347924456, 0.08895710081560537, 0.19320594670716673, 0.1661919939215295, 0.17526522424304858, 0.22914388391654938, 0.1599887674092315, 0.1490389573154971, 0.1375607232330367, 0.17365991428960115, 0.10083691842737608, 0.11991739418590441, 0.15059951576404274, 0.12701701634796336, 0.28746965574100614, 0.1892239533481188, 0.1614677786710672, 0.14792214380577207, 0.09614679001970217, 0.13469925412209705, 0.19799996836809441, 0.08386101762880571, 0.17809029843192548, 0.2320270088966936, 0.14840143761830404, 0.34531056764535606, 0.10357963648857549, 0.17497094784630463, 0.13217289437307045, 0.206265578744933, 0.6757221941370517, 0.16194725059904158, 5.898718452081084, 58.155613392591476, 110.58617278933525, 113.99358674883842, 80.52485346794128, 99.02250409126282, 77.23875939846039, 88.70325341820717, 67.52194359898567, 43.65132428705692, 81.58110558986664, 79.8704145848751, 93.68594884872437, 84.70246329903603, 80.75889050960541, 57.59929284453392, 55.900688990950584, 30.257502794265747, 21.437759958207607, 6.46990617737174, 3.3330056397244334, 0.4950330429710448, 0.6152351398486644, 0.1680723438039422, 0.15378779702587053, 0.16009919898351654, 0.5667488509789109, 0.8000092499423772, 1.4548804191872478, 0.5029286630451679, 0.6569341022986919, 0.9459615556988865, 0.7099188747815788, 0.30266284360550344, 0.46843295625876635, 0.3870643302798271, 0.32183649600483477, 0.3534779918845743, 0.3872609103564173, 0.29390045441687107, 0.19929994392441586, 0.2231994442990981, 0.42413059913087636, 0.7016829354688525, 0.4296845057979226, 0.3098189877346158, 0.5863714136648923, 0.39269904198590666, 0.36974334565456957, 0.4778621799778193, 0.908773010596633, 0.4016424558358267, 0.41904798592440784, 0.377824324532412, 0.3875003568828106, 0.25024323142133653, 0.19417289091506973, 0.17816659121308476, 0.2842258766759187, 0.43243193649686873, 1.2222975119948387, 4.406255437061191, 22.566217705607414, 41.62099823355675, 59.65856574475765, 75.09440526366234, 74.31285560131073, 60.34928888082504, 81.60512790083885, 83.14958542585373, 50.60270167887211, 46.85905896127224, 39.20861788094044, 50.405674651265144, 76.20771512389183, 85.83198308944702, 74.33149740099907, 83.82838860154152, 99.67613741755486, 107.17978477478027, 69.61357176303864, 9.920897148549557, 0.3351748490240425, 0.21708039217628539, 0.2235756241134368, 0.19772638304857537, 0.14769702072953805, 0.13865870103472844, 0.15603874577209353, 0.11935393340536393, 0.09728085846290924, 0.13990414357976988, 0.330249986727722, 0.19297913153422996, 0.10385714034782723, 0.2218312950571999, 0.20333169086370617, 0.10615096296533011, 0.1700471542426385, 0.18681617395486683, 0.2242112735984847, 0.1044988606008701, 0.3676713880850002, 0.11507315139169805, 0.11985521705355495, 0.11062192032113671, 0.11934483467484824, 0.15797429659869522, 0.1207758067175746, 0.11855589458718896, 0.0890479025838431, 0.39439001062419266, 0.12900359724881127, 0.14095598948188126, 0.18783021485432982, 0.11322066173306666, 0.14403939043404534, 0.15229725278913975, 0.12880820460850373, 0.07897376737673767, 0.12619032320799306, 0.13977735507069156, 0.1420688844518736, 0.12124505185056478, 0.09843795574852265, 0.1454137291875668, 0.197100440855138, 0.09207602095557377, 0.1200245157815516, 0.19143118959618732], [0.004534027384579531, 0.051016526340390556, 0.01737461036100285, 0.037505479267565534, 0.04487164376769215, 0.07792807387886569, 0.05146522511495277, 0.021497715679288376, 0.012144476750108879, 0.03660149515781086, 0.05435350431071129, 0.025931027594197076, 0.02617913683934603, 0.019355096374056302, 0.01584835768881021, 0.018996917351614684, 0.04909939190838486, 0.041261310543632135, 0.03008481886354275, 0.032679971991456114, 0.08127726759994403, 0.03503692540107295, 0.040261693284264766, 0.05273447575746104, 0.02918732297985116, 0.016916358290473, 0.013195104602345964, 0.053602940679411404, 0.028638120711548254, 0.02982121914101299, 0.07438572880346328, 0.046415611504926346, 0.042897694220300764, 0.04463610835955478, 0.04910174451651983, 0.03819367651885841, 0.029106978072377387, 0.039043680517352186, 0.06706036016112193, 0.10178392112720758, 0.10985958622768521, 0.10162036662222818, 0.026007366759586148, 0.10083283661515452, 5.67238312214613, 23.513932451605797, 70.43634161353111, 92.45316579937935, 70.9811943769455, 68.31649616360664, 78.17658707499504, 38.791373670101166, 32.58180767297745, 20.645323880016804, 36.958367228507996, 65.22074908018112, 65.36423698067665, 62.1019334346056, 60.090336576104164, 41.84153079986572, 26.842971816658974, 14.118105378001928, 3.807862834073603, 1.163768540136516, 0.2932935260469094, 0.09297817567130551, 0.04398035038320813, 0.10317018619389273, 0.05428552358353045, 0.11208346884814091, 0.15012657473562285, 0.05279320932459086, 0.01875142417702591, 0.1343732138047926, 0.14379335363628343, 0.13516633218387142, 0.11503117551910691, 0.22206648165592924, 0.05058677830675151, 0.14823294040979818, 0.03164534762618132, 0.10614489219733514, 0.08075194578850642, 0.3788422839716077, 0.01447360704332823, 0.16542404919164255, 0.060437382344389334, 0.3316159243695438, 0.485418668249622, 0.17226904048584402, 0.04951165123202372, 0.11150958831422031, 0.09435625484911725, 0.04359625185315963, 0.18297211616300046, 0.0870819682313595, 0.041243168743676506, 0.07140579065890051, 0.010094269673572853, 0.05699314919183962, 0.1039101964852307, 0.08477808951283805, 0.16978115367237478, 0.0269223995928769, 0.13289092225022614, 0.15384333935799077, 0.048617289066896774, 0.08737358773942105, 0.18739120481768623, 0.08435944400844164, 2.1665651304647326, 14.292203485965729, 37.342936992645264, 55.2278058975935, 47.99354128539562, 53.864469453692436, 69.30866852402687, 53.74742813408375, 46.572033762931824, 23.378329128026962, 26.871702075004578, 28.63459847867489, 37.011978551745415, 55.15653312206268, 61.03530786931515, 72.40709066390991, 81.5966847538948, 74.92221370339394, 28.218980580568314, 1.27737270668149, 0.44699278485495597, 0.03575991824618541, 0.06203754550369922, 0.08696424134541303, 0.02143192799849203, 0.10940386302536353, 0.06629631170653738, 0.045060301417834125, 0.06419486860977486, 0.07079262082697824, 0.03754878358449787, 0.034797708940459415, 0.009732190665090457, 0.02968790715385694, 0.0394762672658544, 0.06363323351251893, 0.023933846969157457, 0.018183530919486657, 0.04703889680968132, 0.026119607318833005, 0.024788940245343838, 0.10934717778582126, 0.046389710551011376, 0.007005350853432901, 0.03793498981394805, 0.03176872596668545, 0.04728164589323569, 0.06424727165722288, 0.02417552921542665, 0.0038250815396168036, 0.012347454139671754, 0.030126330893835984, 0.0002617495135837089, 0.0523822339164326, 0.051796957704937086, 0.02440134805510752, 0.02587969138403423, 0.02592318494862411, 0.05159152751730289, 0.045044348953524604, 0.01937974309839774, 0.12289219666854478, 0.049862501546158455, 0.02349138965655584, 0.0908462970983237, 0.008004501487448579, 0.008591426194470841, 0.05925807257881388, 0.032784058203105815, 0.0503857787407469, 0.02252420239528874, 0.06252638704609126, 0.04221703718940262, 0.026215771104034502, 0.018166921654483303, 0.055645913671469316, 0.018613457068568096, 0.0036887529540763353, 0.043127967801410705, 0.10864253083127551, 0.039764068424119614, 0.017632840645092074, 0.09110228609642945, 0.02194590608269209, 0.07132960919989273, 0.06343003347865306, 0.014600131162296748, 0.036172608015476726, 0.012978905851923628, 0.027109413385915104, 0.015427469970745733, 0.0240220771956956, 0.05049797662650235, 0.012875295542471576, 0.05817113422381226, 0.0551568012451753, 0.04437358846189454, 0.034188505887868814, 0.0007410308023736434, 0.023317099985433742, 0.03271843379479833, 0.026943662123812828, 0.08994613875984214, 0.07770053882268257, 0.10399817809229717, 0.11796755701652728, 0.03243907085561659, 0.041538083387422375, 0.09390016057295725, 0.0344250988564454, 10.519021153450012, 39.64749053120613, 91.45705685019493, 106.28513798117638, 80.81189006567001, 95.40088802576065, 111.45439580082893, 60.790551602840424, 47.652353793382645, 23.64686831831932, 29.949379228055477, 34.22396935522556, 49.604392647743225, 57.934860438108444, 60.06737060844898, 41.66716955602169, 26.695832312107086, 12.847394663840532, 2.116703256033361, 0.6549593957606703, 0.23981230129720643, 0.03945992517401464, 0.06642502979957499, 0.1242848664696794, 0.10021487993071787, 0.12698930455371737, 0.20602745324140415, 0.025947657268261537, 0.0883360939042177, 0.006336731921692262, 0.12477466167183593, 0.1608208633842878, 0.08235580855398439, 0.2635818219278008, 0.11781142398831435, 0.004621929210770759, 0.22617710405029356, 0.3600837296107784, 0.21490284183528274, 0.8281633048318326, 0.34788389049936086, 0.7677885820157826, 0.5420575384050608, 0.48654397192876786, 0.16881330404430628, 0.8663929346948862, 0.19430085201747715, 0.2572737151058391, 0.17728478618664667, 0.10789005988044664, 0.5264827678911388, 0.06311940014711581, 0.09069404550245963, 0.06538922170875594, 0.11746249583666213, 0.16906705917790532, 0.03575449314666912, 0.11998599831713364, 0.19327472895383835, 0.057220695380237885, 0.1408966473536566, 0.11430064245359972, 0.03476704339846037, 0.11349996901117265, 0.3442886006087065, 0.3317952569341287, 1.2408849271014333, 11.185049414634705, 34.497767463326454, 51.9472823292017, 53.664786368608475, 52.42796413600445, 42.22544699907303, 33.65219123661518, 27.609901763498783, 27.895319648087025, 42.799869775772095, 51.36809840798378, 65.4185588657856, 83.69638368487358, 85.0034299492836, 88.11817601323128, 90.35107299685478, 93.34454476833344, 46.322865933179855, 3.9739405224099755, 0.25932910793926567, 0.05614497829810716, 0.039994100807234645, 0.04931307477818336, 0.03566510516975541, 0.09199570573400706, 0.07257587552885525, 0.05437989137135446, 0.09296148477005772, 0.11515631646034308, 0.05831846166984178, 0.08168493674020283, 0.025615440426918212, 0.039667121673119254, 0.07322627148823813, 0.10512119595659897, 0.05333810157026164, 0.042478187824599445, 0.011151385751873022, 0.012372594392218161, 0.042911590935545973, 0.023293792837648652, 0.09536388359265402, 0.02900224062614143, 0.036876483136438765, 0.010216837217740249, 0.0515739534603199, 0.036298609848017804, 0.02712742345465813, 0.020797254437638912, 0.01346388451565872, 0.030436593151534908, 0.01540834204206476, 0.014872892697894713, 0.05357089845347218, 0.013342077672859887, 0.08819836613838561, 0.026184263224422466, 0.056554287584731355, 0.06508266276796348, 0.04183447490504477, 0.03324545883515384, 0.04187753060250543, 0.035571898843045346, 0.04175681286142208, 0.042784026882145554, 0.10101699313963763, 0.18277146911714226, 0.11869663547258824, 0.09983209500205703, 0.10011681253672577, 0.17602222971618176, 0.1405628293287009, 0.11876071992446668, 0.11655521288048476, 0.1439218787709251, 0.11921135199372657, 0.09457669497351162, 0.09304608218371868, 0.2037461061263457, 0.1561429284629412, 0.10939766609226353, 0.159595993172843, 0.16875658911885694, 0.18816553201759234, 0.18959795124828815, 0.10379326369729824, 0.12283272837521508, 0.13133566273609176, 0.28641254059039056, 0.16926314943702891, 0.23468722240068018, 0.10929882686468773, 0.1460587148903869, 0.22528538393089548, 0.16489186993567273, 0.159350594622083, 0.09563517567585222, 0.1586570724612102, 0.1388067298103124, 0.10139721765881404, 0.15044218045659363, 0.11208501251530834, 0.17045186221366748, 0.22711019148118794, 0.26182192261330783, 0.28877233271487057, 0.16480529098771513, 0.2310918879811652, 0.15282830398064107, 9.389154631644487, 41.094669476151466, 103.80556583404541, 113.02013218402863, 89.16606098413467, 88.0565357208252, 100.95125779509544, 48.898876905441284, 43.32271032035351, 29.770878106355667, 57.1911833435297, 101.24932140111923, 97.83432304859161, 88.322544246912, 83.43276143074036, 64.15411591529846, 41.437863260507584, 26.177699714899063, 6.2786187417805195, 1.749499747529626, 0.42619599611498415, 0.17080130986869335, 0.15264563175151125, 0.3442310099489987, 0.23894930229289457, 0.3347182204015553, 0.536964921047911, 0.18971400830196217, 0.28487406845670193, 0.43688894889783114, 0.40719906392041594, 0.456082668970339, 0.297421173308976, 0.5487211339641362, 0.21994491893565282, 0.39461980923078954, 0.36414609756320715, 0.6697411369532347, 0.2566148363985121, 0.8326120348647237, 0.3295243444154039, 0.434049105970189, 0.43335142778232694, 0.8354507200419903, 1.064228843897581, 0.6343967991415411, 0.233340936829336, 0.39674083760473877, 0.20869306958047673, 0.19158931158017367, 0.724410762777552, 0.30240632768254727, 0.2441809535957873, 0.14747645444003865, 0.2521726966369897, 0.3638766979565844, 0.24635422916617244, 0.44878667453303933, 0.6430408009327948, 0.3461836598580703, 0.2396387723274529, 0.5068174574989825, 0.14132369396975264, 0.20256387972040102, 0.590343625517562, 0.6539717456325889, 4.228263013064861, 24.403802901506424, 58.46625432372093, 83.27529028058052, 73.44989150762558, 79.66190457344055, 98.93032863736153, 75.25099486112595, 62.65038460493088, 33.238708823919296, 38.32529067993164, 40.127875953912735, 51.69258199632168, 74.1230633854866, 81.01859897375107, 90.88805258274078, 101.47297739982605, 102.71791219711304, 49.601261615753174, 3.4504623245447874, 0.5463755317032337, 0.27775378490332514, 0.18109598167939112, 0.16447966627310961, 0.105676567327464, 0.32664475205820054, 0.10063212277600542, 0.13354123657336459, 0.20481377461692318, 0.23374990472802892, 0.2047164345276542, 0.21944831823930144, 0.1033138288767077, 0.15252062439685687, 0.18800496094627306, 0.1941566527239047, 0.1333816154510714, 0.1398984735715203, 0.24100650596665218, 0.150021635054145, 0.14389666059287265, 0.13004264852497727, 0.16507957392605022, 0.11647350984276272, 0.21242110000457615, 0.0628087148652412, 0.17780528403818607, 0.1460576758836396, 0.08782700286246836, 0.10542649324634112, 0.12174871037132107, 0.18895081331720576, 0.057779209746513516, 0.11950360232731327, 0.16030578321078792, 0.08075382342212833, 0.23467773775337264, 0.16071475110948086, 0.13596222619526088, 0.1757353451102972, 0.19796256412519142, 0.2069118557847105, 0.1117117864487227, 0.11268555841525085, 0.13945083977887407, 0.07212104290374555], [0.003681641787807166, 0.09219135070452467, 0.0400026985880686, 0.02609808689157944, 0.02968644883367233, 0.03549058914359193, 0.04822254442842677, 0.03862761026539374, 0.04532285100140143, 0.03819219964498188, 0.04686654785473365, 0.06318735860986635, 0.034090011758962646, 0.0596372766449349, 0.03836610711005051, 0.005276873143884586, 0.023161837125371676, 0.007279872206709115, 0.051203580951550975, 0.05908381630433723, 0.011964975346927531, 0.027520591029315256, 0.002382159063927247, 0.02469003422447713, 0.04453636000107508, 0.015916253069008235, 0.03258904776885174, 0.0323581322300015, 0.06994839815888554, 0.061776350339641795, 0.04605554371664766, 0.04053426928294357, 0.022738163570465986, 0.01739462422847282, 0.031623435716028325, 0.062027611857047305, 0.0872479792451486, 0.02108517990563996, 0.01627749345061602, 0.06550311911269091, 0.045812134121661074, 0.18640778493136168, 1.39804283156991, 23.87128997594118, 75.42999565601349, 99.40620750188828, 86.90133690834045, 67.69270643591881, 63.076345548033714, 46.37464575469494, 36.329291984438896, 31.07963427901268, 48.09185341000557, 57.56397373974323, 43.503310829401016, 47.3405235260725, 49.516146183013916, 36.99048690497875, 14.688542168587446, 3.9037499763071537, 0.6696873460896313, 0.16093341750092804, 0.03235982061596587, 0.10019925772212446, 0.1758493686793372, 0.08022516936762258, 0.09168666059849784, 0.00527546028024517, 0.18596743902890012, 0.10817519301781431, 0.05144915390701499, 0.008106665536615765, 0.10826273675775155, 0.03694785918924026, 0.10266480589052662, 0.02526799842598848, 0.06422337450203486, 0.04856519772147294, 0.04756087153509725, 0.0770921484217979, 0.043753486970672384, 0.12344146016403101, 0.1506112120114267, 0.10998408892191947, 0.19354199117515236, 0.05953490108367987, 0.2121687846374698, 0.43706887518055737, 0.24056149937678128, 0.174275703902822, 0.06536542103276588, 0.2187171098194085, 0.12110512732760981, 0.056864145371946506, 0.07345424441155046, 0.027556911736610346, 0.15642378682969138, 0.06621303531574085, 0.11103172684670426, 0.07130004945793189, 0.04994854243705049, 0.07714063292951323, 0.05354808112315368, 0.13363896257942542, 0.09500810541794635, 0.0525394579017302, 0.12238769209943712, 0.08903499663574621, 0.08349260067916475, 0.09126460121478885, 0.09974464031984098, 0.3026653965935111, 0.043444412149256095, 1.5021519013680518, 15.52918341010809, 33.340642154216766, 66.04296416044235, 61.55385084450245, 68.45252126455307, 69.61527407169342, 45.49155794084072, 29.72923994064331, 23.330501094460487, 30.912095569074154, 46.431657895445824, 55.374086648225784, 62.58223906159401, 70.78263223171234, 85.07137030363083, 58.26983906328678, 15.227816831320524, 1.5342523413710296, 0.4536206682678312, 0.05713630947866477, 0.06980212827329524, 0.05694159961421974, 0.036514905077638105, 0.05035216687247157, 0.051476576263667084, 0.021979102348268498, 0.10393151096650399, 0.029221298500488047, 0.0073557002178858966, 0.0559618941770168, 0.03389589561265893, 0.04132230766117573, 0.11695655150106177, 0.040974073417601176, 0.017781359238142613, 0.01719391038932372, 0.06581419031135738, 0.054236322903307155, 0.032187916949624196, 0.05701259717170615, 0.006576108871740871, 0.043836054610437714, 0.017286092552240007, 0.04977978176611941, 0.027329243093845434, 0.05367290294088889, 0.022649888815067243, 0.08609434778918512, 0.021843463728146162, 0.0175769958877936, 0.011968329854425974, 0.1232819355209358, 0.03803830790275242, 0.049691169333527796, 0.03070559941988904, 0.08025763832847588, 0.022821703423687723, 0.019580497755669057, 0.032492791215190664, 0.035964895723736845, 0.04048067508847453, 0.03152479686832521, 0.028812761047447566, 0.025235700159100816, 0.07109155791113153, 0.0479612268100027, 0.05942403164226562, 0.06939005077583715, 0.03615970577811822, 0.022109844649094157, 0.040960933692986146, 0.03436504797718953, 0.042667457746574655, 0.031924628929118626, 0.03214563679648563, 0.030525971851602662, 0.05229435621004086, 0.017064077219401952, 0.07525208973675035, 0.05972142876998987, 0.028322420366748702, 0.032390222695539705, 0.05742111236031633, 0.01397017209455953, 0.04413127724546939, 0.05009280110243708, 0.056662021452211775, 0.030891926726326346, 0.023536946391686797, 0.04681742510001641, 0.03301408687548246, 0.027593141530815046, 0.04145815037190914, 0.0512919930042699, 0.08200409734854475, 0.03407139498449396, 0.02252373298688326, 0.02382143200520659, 0.08681201201397926, 0.046306545482366346, 0.04298170533729717, 0.14488177257589996, 0.1304976295796223, 0.1126453340111766, 3.4542635455727577, 37.988769337534904, 95.0866448879242, 113.95511001348495, 103.02656203508377, 97.8105591237545, 97.69183069467545, 71.26732662320137, 52.189416736364365, 33.21364536881447, 23.66662535816431, 25.58286063373089, 29.26684845238924, 46.227073073387146, 51.582414507865906, 40.10823480784893, 14.240465462207794, 2.969866250641644, 0.08229285216657445, 0.19831477256957442, 0.03910467763489578, 0.06529069418320432, 0.3621775360079482, 0.11959761759499088, 0.14146626053843647, 0.04399709323479328, 0.28905120212584734, 0.1747354050166905, 0.15060137113323435, 0.46752572525292635, 0.7393450301606208, 0.654438289348036, 0.63135328120552, 0.6011690071318299, 0.33474217692855746, 0.4620918683940545, 0.7851253892295063, 0.895058655878529, 0.7141411013435572, 1.0541380103677511, 0.9863572474569082, 0.8041411719750613, 1.7240281705744565, 0.884507215814665, 0.7919481606222689, 1.0644391388632357, 2.5348226074129343, 1.9321625959128141, 1.8077433784492314, 1.6540567064657807, 1.005891642998904, 0.6825238291639835, 0.25488399958703667, 0.43959143513347954, 0.8241946552880108, 0.7634151354432106, 0.2528210071614012, 0.2150952213560231, 0.33514451002702117, 0.35769413283560425, 0.4609674552921206, 0.2710858848877251, 0.21495212044101208, 0.11210614145966247, 0.5167871131561697, 0.24468300165608525, 0.14815596485277638, 0.07470295982784592, 0.18031740939477459, 0.3566168312681839, 0.16369254444725811, 1.048911390826106, 11.669225133955479, 30.4470594227314, 57.59183004498482, 47.699353471398354, 35.74376620352268, 21.748161502182484, 20.31098172068596, 30.5289526283741, 33.8662451505661, 47.089349403977394, 72.65167593955994, 81.64725244045258, 87.84431710839272, 83.20133864879608, 98.48291024565697, 82.0551985502243, 29.38868321478367, 2.6195447612553835, 0.49466161290183663, 0.017294790523010306, 0.0009765180288923148, 0.10617661901051179, 0.009920610827975906, 0.04746178739878815, 0.02379969821049599, 0.013056540992693044, 0.03582030680263415, 0.047935997499735095, 0.021422293066279963, 0.05260048470518086, 0.028769495693268254, 0.0566771315789083, 0.03588398678402882, 0.09345068625407293, 0.029296476204763167, 0.025871763391478453, 0.011211847595404834, 0.07287221509614028, 0.036989898144383915, 0.04656328776036389, 0.06205796940776054, 0.023373996737063862, 0.029656126534973737, 0.03550483095750678, 0.011609409611992305, 0.008997078548418358, 0.11935976668610238, 0.036596556165022776, 0.05394815067120362, 0.0423012523970101, 0.056803482220857404, 0.0848516882979311, 0.01117373923989362, 0.025156720803352073, 0.10025021358160302, 0.0450134756101761, 0.025889678836392704, 0.03793425508774817, 0.05000425917387474, 0.04012688215880189, 0.05419788707513362, 0.028150054713478312, 0.14129589311778545, 0.2349936551763676, 0.15345372667070478, 0.1299364768783562, 0.13313163042766973, 0.17783832445275038, 0.10221392149105668, 0.08898498330381699, 0.07272415663464926, 0.15983667166437954, 0.11151795974001288, 0.11696253321133554, 0.07583565529785119, 0.14287870115367696, 0.12942976813064888, 0.08434535062406212, 0.11735353371477686, 0.2987399697303772, 0.09513707584119402, 0.15957803319906816, 0.13452296436298639, 0.08982815212220885, 0.11083765522926114, 0.1151135539112147, 0.15931071160594001, 0.10971240350045264, 0.08230554289184511, 0.1100148880505003, 0.16786843130830675, 0.12119091959903017, 0.10569607838988304, 0.13131145387887955, 0.12553217180538923, 0.08751769055379555, 0.15321488870540634, 0.17786354263080284, 0.25758859352208674, 0.1354251042357646, 0.134693376312498, 0.1471162456437014, 0.2269402248202823, 0.3985166782513261, 3.6605948489159346, 42.687775790691376, 107.3933333158493, 122.8370726108551, 106.45900145173073, 87.81262680888176, 86.82289391756058, 63.1278707832098, 49.039142578840256, 47.03677922487259, 70.24290159344673, 84.85717579722404, 66.04611039161682, 74.21272337436676, 70.0290946662426, 55.36699242889881, 24.453574530780315, 6.391136879101396, 1.6621741396375, 0.3329993173247203, 0.17284663917962462, 0.19808702229056507, 0.6659608148038387, 0.3819930867757648, 0.4894533095648512, 0.27618423162493855, 0.4752270213793963, 0.3246720047900453, 0.2113417352666147, 0.5025775381363928, 0.42950279836077243, 0.2828953246353194, 0.44462379009928554, 0.6514370441436768, 0.23560386383906007, 0.26078039256390184, 0.3189043595921248, 0.5526134313549846, 0.3462740534450859, 0.5960540659725666, 0.4509008751483634, 0.499480051221326, 1.2579479115083814, 0.7500687672290951, 0.6127986987121403, 1.391773286741227, 2.245793016627431, 0.664311406435445, 0.7618450478184968, 0.6280992901884019, 0.33531063236296177, 0.7163362554274499, 0.24538376717828214, 0.3573737625265494, 0.5957098875660449, 0.4726560437120497, 0.24520226754248142, 0.1744542201049626, 0.47677739756181836, 0.3282287920592353, 0.24155397346476093, 0.42922211810946465, 0.4495947842951864, 0.21071300259791315, 0.5890115594957024, 0.5035383522044867, 0.5936192872468382, 0.2272024255944416, 0.3059362492058426, 0.750287730479613, 0.39360766822937876, 3.007548116147518, 25.55443625897169, 52.952609583735466, 97.0991612970829, 90.27551785111427, 95.8832797408104, 90.60176834464073, 60.383984819054604, 41.565403416752815, 31.76119040697813, 42.11004339158535, 61.29307463765144, 73.47642928361893, 82.82114624977112, 87.99382388591766, 108.86634707450867, 91.11243814229965, 30.77798556536436, 2.57947092410177, 0.7232214859686792, 0.1917408432927914, 0.1280962920282036, 0.19775860710069537, 0.16146914422279224, 0.10569859427050687, 0.19561172230169177, 0.10957402264466509, 0.16590263054240495, 0.11018283606972545, 0.11853435746161267, 0.13244931469671428, 0.11829861425212584, 0.10361829496105202, 0.17148724728031084, 0.11587020315346308, 0.1319903854164295, 0.13777176034636796, 0.14540231495629996, 0.11901490550371818, 0.10416187360533513, 0.11986467201495543, 0.11863409468787722, 0.059553417668212205, 0.1479386936989613, 0.15314223244786263, 0.0953458494041115, 0.2567895973334089, 0.17107865045545623, 0.1418682374060154, 0.13280735642183572, 0.1016738754697144, 0.14582752104615793, 0.2116271949489601, 0.10901669942541048, 0.12866148201283067, 0.1944617644767277, 0.11546638575964607, 0.09009648303617723, 0.08104238528176211, 0.10400820450740866, 0.13137174595613033, 0.10290477934177034, 0.16123741603223607], [0.03295091155450791, 0.012849305530835409, 0.0803214407642372, 0.018439887280692346, 0.05230677605140954, 0.009862745573627762, 0.01852329725807067, 0.03686184798425529, 0.03244282241212204, 0.017462528885516804, 0.013512413552234648, 0.05917703376326244, 0.00767760167036613, 0.024901648357626982, 0.04550203513645101, 0.024460202221234795, 0.016574476831010543, 0.01941939233802259, 0.03288437430455815, 0.03144349830108695, 0.06676689270534553, 0.05708744647563435, 0.06565899238921702, 0.012615243285836186, 0.014301469600468408, 0.04068447626195848, 0.07574082366772927, 0.06948698268388398, 0.029521157703129575, 0.045690399638260715, 0.01852310244430555, 0.08049560055951588, 0.048436869255965576, 0.06028339412296191, 0.043873904141946696, 0.02744793291640235, 0.07749673022772186, 0.04053781303809956, 0.0455502636032179, 0.20933562103891745, 0.9525177476461977, 23.615814484655857, 62.03338511288166, 91.86276108026505, 94.16681304574013, 62.81088039278984, 68.21006387472153, 43.41879576444626, 26.98373146355152, 39.84779678285122, 39.0015821903944, 58.215517178177834, 68.31575140357018, 62.09168538451195, 65.39913430809975, 41.96734204888344, 19.773390367627144, 5.011295545846224, 0.8642502059228718, 0.10732161928899586, 0.022039392570150085, 0.08494152527418919, 0.014764556763111614, 0.12073302190401591, 0.04536841886874754, 0.018967836294905283, 0.1152473408728838, 0.08073979683103971, 0.013712293402932119, 0.03339227791002486, 0.21157845068955794, 0.0333677462185733, 0.05389973295677919, 0.169165616389364, 0.049062926482292823, 0.08606099567259662, 0.025782703814911656, 0.43232319701928645, 0.15920373843982816, 0.03133516700472683, 0.7298302813433111, 1.4171254076063633, 1.3885334855876863, 1.1314081703312695, 2.079397332854569, 3.4142970526590943, 1.906807862687856, 1.3934735767543316, 1.0524765495210886, 1.8212512973695993, 1.6065894160419703, 0.27971602336037904, 0.9298842027783394, 0.2607668557902798, 0.24830655253026634, 0.11320257559418678, 0.1555047556757927, 0.28319126344285905, 0.1296663351240568, 0.036304762252257206, 0.008259446840384044, 0.1226302630675491, 0.06809487691498362, 0.09859047451755032, 0.10560457900282927, 0.11632859808742069, 0.05036447168095037, 0.017906138382386416, 0.09684409713372588, 0.090090293524554, 0.10245233643217944, 0.19109119690256193, 0.07744166287011467, 0.02372512721194653, 0.1409038610290736, 1.495910498779267, 17.961016818881035, 47.13190332055092, 67.3323717713356, 77.24651098251343, 83.13855841755867, 57.6201157271862, 54.174213632941246, 37.145108208060265, 27.894538789987564, 36.96802631020546, 46.000327840447426, 54.21659275889397, 59.838740676641464, 78.65056604146957, 80.11138245463371, 51.670919358730316, 3.572113746777177, 0.4785174666903913, 0.031883061237749644, 0.07578553064377047, 0.10528686558245681, 0.014825441630819114, 0.0190459584700875, 0.0759520017891191, 0.06404105108231306, 0.04017837236460764, 0.05964255331491586, 0.09295906536863185, 0.09340036122011952, 0.05716026971640531, 0.05003222329833079, 0.031208760701701976, 0.05470815442095045, 0.04888534909696318, 0.0055954094204935245, 0.030106962694844697, 0.030312099734146614, 0.03805548119999003, 0.022152208293846343, 0.060671567043755203, 0.03740247659152374, 0.030960794319980778, 0.03516960656270385, 0.057298925166833214, 0.03415421124373097, 0.02781810690066777, 0.006349437489916454, 0.03428310745221097, 0.09362984812469222, 0.01000546149953152, 0.033593396219657734, 0.03933821295504458, 0.044600845212698914, 0.009291002425015904, 0.02668897188414121, 0.013876900829927763, 0.038276444538496435, 0.011871606675413204, 0.03057927475310862, 0.04211553365166765, 0.02122050125763053, 0.08217870985390618, 0.02210818223829847, 0.02150589229131583, 0.02908832047978649, 0.03232371142075863, 0.04036789832753129, 0.037362652947194874, 0.0245129633549368, 0.06142898440884892, 0.0285904822521843, 0.05992241720377933, 0.05792650750663597, 0.041448754782322794, 0.04349659626313951, 0.0559328799135983, 0.0606059018173255, 0.05105620526592247, 0.03412931961065624, 0.05573793998337351, 0.029164420302549843, 0.0466547574615106, 0.03780388200539164, 0.015952822395775, 0.04557925931294449, 0.015241762357618427, 0.09515700992778875, 0.035362086273380555, 0.04375198783236556, 0.05186880502151325, 0.05880589313164819, 0.017547417592140846, 0.03218474426830653, 0.038960745514486916, 0.07586782739963382, 0.050029907797579654, 0.050547797000035644, 0.05972732884401921, 0.03190331444784533, 0.20118663174798712, 3.451920971274376, 37.34598822891712, 80.73460221290588, 108.17405462265015, 106.03637292981148, 81.89323604106903, 88.90051603317261, 62.839644849300385, 39.14811372756958, 34.012799486517906, 25.414151586592197, 33.96292336285114, 54.869283735752106, 63.35483640432358, 72.57017031311989, 43.482404351234436, 19.705056734383106, 4.138362687081099, 0.6003550789318979, 0.2000032179057598, 0.029904645816714037, 0.06331621028948575, 0.15642421727534384, 0.14819080126471817, 0.08473889669403434, 0.02493343268724857, 0.0642725863144733, 0.22792125499108806, 0.18198014673544094, 0.24141807138221338, 1.1437246156856418, 1.4527144166640937, 1.0062522673979402, 1.0426569264382124, 1.546970852650702, 1.362681572791189, 0.8695093018468469, 1.6940121562220156, 2.37825533375144, 2.512598787434399, 3.327652676962316, 5.956645393744111, 7.543346676975489, 3.053788309916854, 5.2535211481153965, 5.200591888278723, 6.4107804000377655, 4.466728242114186, 4.260481484234333, 4.7294513694942, 5.993169983848929, 5.706985015422106, 4.367191633209586, 2.230294835753739, 2.6666292222216725, 1.6803973680362105, 0.8282210142351687, 1.5359548875130713, 1.6760792559944093, 1.6968717402778566, 1.6831605322659016, 1.0001493198797107, 0.8297923486679792, 0.559934985358268, 0.417021329049021, 0.37439337582327425, 0.42611623008269817, 0.13181442220229656, 0.4141278733732179, 0.2331909933127463, 0.22837908589281142, 0.38123143545817584, 0.10307319491403177, 0.03295717899163719, 0.21507283818209544, 0.5565814871806651, 13.125523589551449, 39.0579217672348, 66.34516954421997, 59.115920662879944, 44.97156344354153, 19.99571453779936, 26.85584742575884, 35.38228020071983, 38.40871900320053, 60.6239153444767, 73.66455718874931, 83.19643691182137, 82.10469469428062, 89.90240067243576, 92.86504849791527, 72.062449157238, 8.638378567993641, 0.33785518957301974, 0.08815241977572441, 0.08111723087495193, 0.19589943811297417, 0.029226413753349334, 0.05857483658473939, 0.055454877438023686, 0.074119809869444, 0.029627943476953078, 0.04310329881263897, 0.07151494573918171, 0.05032545326685067, 0.037234183473628946, 0.029846402067050803, 0.04904253968561534, 0.04762350879900623, 0.07623062629136257, 0.006149124410512741, 0.05861718353116885, 0.018989263953699265, 0.038570004762732424, 0.05076742447272409, 0.017913539450091776, 0.04367313835246023, 0.024520739207218867, 0.10951044285320677, 0.07772301105433144, 0.009271601757063763, 0.03455503407167271, 0.02201995943323709, 0.07481592212570831, 0.014700222764076898, 0.029241861557238735, 0.051222216279711574, 0.021858015388716012, 0.09449449469684623, 0.043307404266670346, 0.06407091510482132, 0.03350184117152821, 0.007427147702401271, 0.05843596962222364, 0.058237549019395374, 0.06480627213022672, 0.08924351786845364, 0.14769332483410835, 0.19934989046305418, 0.09308160137152299, 0.17284625326283276, 0.14783408056246117, 0.1037812112190295, 0.16143481247127056, 0.10032217222033069, 0.197844740760047, 0.21600950276479125, 0.14556533511495218, 0.13483978720614687, 0.1288788570673205, 0.1490365230711177, 0.15805210336111486, 0.13263502973131835, 0.10592527585686184, 0.13860844279406592, 0.12422223662724718, 0.19214295374695212, 0.12241839474881999, 0.18871144100558013, 0.07647703416296281, 0.11477407329948619, 0.11754402075894177, 0.2115696042892523, 0.13793773425277323, 0.15485822630580515, 0.1351509548840113, 0.21323536959243938, 0.16280254611046985, 0.183898969553411, 0.21839568566065282, 0.1373534562299028, 0.15984603756805882, 0.2192780250334181, 0.12672076583839953, 0.1093020848929882, 0.4199290042743087, 3.3655045833438635, 39.1875784099102, 93.33316057920456, 119.14953008294106, 113.27905789017677, 78.38806852698326, 86.91133797168732, 55.32363295555115, 38.01891312003136, 54.747523069381714, 58.208263367414474, 85.83579048514366, 99.23991322517395, 89.13301795721054, 93.89095544815063, 56.749951019883156, 30.014350041747093, 7.767520872876048, 1.2574592814780772, 0.3233347140485421, 0.12983452063053846, 0.4272991244215518, 0.619899983284995, 0.372106937575154, 0.1232571032596752, 0.12786677543772385, 0.24789063812932, 0.365344844176434, 0.2713235799456015, 0.25022616202477366, 0.7190065621398389, 0.501669505611062, 0.4162981506669894, 0.5077107064425945, 0.3627541253808886, 0.6123160652350634, 0.32766894553788006, 0.7804183918051422, 0.8658239746000618, 1.1549158464185894, 3.602706855162978, 4.888495160266757, 6.359201967716217, 3.4274773579090834, 7.855024952441454, 8.800231833010912, 7.669775867834687, 4.998687347397208, 4.674348151311278, 6.286293854936957, 6.059775184839964, 2.8108231723308563, 2.3912361497059464, 1.1813003243878484, 1.9607813539914787, 0.7019746291916817, 0.5101416853722185, 0.9090446366462857, 0.6830147746950388, 0.9519956319127232, 0.43135804880876094, 0.45302929531317204, 0.5002137087285519, 0.1922617419040762, 0.3966073103947565, 0.4693554755067453, 0.2589144551893696, 0.19101661106105894, 0.29128913360182196, 0.23467715887818485, 0.5334265984129161, 0.5792213254608214, 0.21251719328574836, 0.11627252883045003, 0.36179351911414415, 2.8734711231663823, 24.811483025550842, 65.10370776057243, 94.77454483509064, 111.30377188324928, 114.75587904453278, 76.26762270927429, 69.00500401854515, 50.630576983094215, 37.82269164919853, 49.42665718495846, 58.740679398179054, 75.47170981764793, 80.22663027048111, 97.15234324336052, 104.72167387604713, 79.99516189098358, 7.81633922830224, 0.5387681617867202, 0.22460303851403296, 0.18067049357341602, 0.27371032687369734, 0.2368000426213257, 0.2091689346707426, 0.1095724270271603, 0.15493300510570407, 0.09769935553777032, 0.22198183229193091, 0.2107253816211596, 0.1594615011708811, 0.10732432070653886, 0.23564978793729097, 0.12921456014737487, 0.13755150575889274, 0.14515280490741134, 0.14429081522393972, 0.19194453314412385, 0.08149876157403924, 0.18565883918199688, 0.1672025615698658, 0.13728897843975574, 0.1198334721266292, 0.1734665996627882, 0.17877455858979374, 0.13288114074384794, 0.07018238989985548, 0.07688984638662077, 0.0759022927377373, 0.129948113753926, 0.2826124179409817, 0.06508055506856181, 0.10465085986652412, 0.10079792598844506, 0.21562205714872107, 0.1475283454055898, 0.172746078169439, 0.12270772102056071, 0.14174085517879575, 0.12499304604716599, 0.17382636317051947, 0.16708067123545334], [0.008747712290642085, 0.04772097134264186, 0.044067248454666696, 0.054010112580726855, 0.013469234472722746, 0.02520017540518893, 0.024795998069748748, 0.05808775022160262, 0.021075611766718794, 0.02127406947693089, 0.049363752332283184, 0.06559205809026025, 0.024932833402999677, 0.018142855660698842, 0.04254572697391268, 0.02910192219133023, 0.025111588947765995, 0.03423340953304432, 0.05710385907150339, 0.06333985511446372, 0.13648487627506256, 0.027639594409265555, 0.05323029348801356, 0.08187859275494702, 0.04832710932532791, 0.10736330572399311, 0.03641172057541553, 0.06156833376735449, 0.11130207640235312, 0.019959943019784987, 0.01808805547625525, 0.06633413897361606, 0.0023304278920477373, 0.03302616532891989, 0.1667448048829101, 0.025217001748387702, 0.15168309590080753, 0.0011593362523854012, 0.17466274875914678, 13.332292344421148, 66.7664985358715, 87.43881046772003, 93.67547661066055, 70.76272889971733, 69.9623854458332, 61.26322343945503, 62.75085121393204, 81.20077639818192, 57.755631655454636, 60.312940031290054, 67.6373890042305, 72.46883735060692, 58.05641211569309, 49.67094607651234, 20.66763248294592, 5.31028582714498, 0.5863758071791381, 0.118060043459991, 0.06298338674241677, 0.06531117745907977, 0.09440922935027629, 0.07479264837456867, 0.11060102886403911, 0.04805600648978725, 0.038842714347993024, 0.09113444335525855, 0.2059387369081378, 0.14384362671989948, 0.43258188001345843, 0.20959653047611937, 0.31281453324481845, 0.5964596942067146, 2.537433304823935, 2.007042565383017, 1.0687593882903457, 1.5127438330091536, 0.7761887437663972, 1.5816178685054183, 5.254223635420203, 3.19854486733675, 2.548167728818953, 7.610925100743771, 7.486565848812461, 3.80854204762727, 4.49774170294404, 2.0927035063505173, 3.2177442871034145, 2.4198481393978, 4.828004306182265, 10.634890235960484, 6.037485580891371, 16.930365823209286, 6.476377230137587, 1.0309805092401803, 1.035309189464897, 1.2501268624328077, 1.6173657565377653, 2.2914499416947365, 1.6318555665202439, 2.2992293117567897, 0.9047071693930775, 2.0833536330610514, 2.5254741590470076, 0.5305942660197616, 0.36176769237499684, 0.21527571167098358, 1.4571955637075007, 2.0765073504298925, 0.31026513723190874, 0.13792490994092077, 0.13363004196435213, 0.01709200794721255, 0.06157602612802293, 0.09070447267731652, 0.11732611877960153, 0.03908717408194207, 0.5242813203949481, 0.6299954478163272, 10.662327613681555, 25.729141384363174, 48.45454014837742, 84.35009300708771, 85.69157302379608, 65.33199951052666, 43.79287049174309, 29.08309981226921, 23.945731781423092, 41.270767226815224, 44.20811600983143, 54.58280950784683, 60.148211270570755, 74.4623775780201, 60.90863026678562, 14.688654262572527, 0.47270220529753715, 0.20638049289118499, 0.0798117188969627, 0.03599584328185301, 0.02796248245431343, 0.11327269370667636, 0.06197948729095515, 0.08196921640774235, 0.062081443538772874, 0.09390162260388024, 0.07029282889561728, 0.08590501107391901, 0.003085244725298253, 0.14579256589058787, 0.007393963496724609, 0.07286329448106699, 0.044468015621532686, 0.03692274862260092, 0.006371527979354141, 0.020024007062602323, 0.04964477397152223, 0.0671113382850308, 0.09181270695989951, 0.015379849137389101, 0.024186184600694105, 0.058426095347385854, 0.07843871600925922, 0.012327183303568745, 0.058657908884924836, 0.016770531838119496, 0.05876289309526328, 0.026298962147848215, 0.0650610811135266, 0.04094212024938315, 0.03738099883776158, 0.025677415324025787, 0.09617220115615055, 0.055283003457589075, 0.02294266792887356, 0.0558634742628783, 0.012514533846115228, 0.011477399166324176, 0.015087651681824354, 0.05509843504114542, 0.11489485783386044, 0.03621378979005385, 0.04321401982451789, 0.025207787984982133, 0.03451243479503319, 0.03438319719862193, 0.02374900024733506, 0.05080941518826876, 0.04498856913414784, 0.02812235034070909, 0.04372079165477771, 0.06241309078177437, 0.03067459248995874, 0.09012334878207184, 0.007921024716779357, 0.02397029755229596, 0.05786230060039088, 0.033693671502987854, 0.08192735185730271, 0.018519976147217676, 0.033739013015292585, 0.03567869389371481, 0.08538726659025997, 0.11875867159687914, 0.12989070120966062, 0.025109950656769797, 0.03468173723376822, 0.028451329562813044, 0.021319505613064393, 0.0558974460727768, 0.03090139838604955, 0.04714680508186575, 0.10411414608824998, 0.054515585652552545, 0.11879695157404058, 0.1803674449911341, 0.3066719847265631, 24.295446015894413, 87.07985132932663, 99.15364265441895, 110.8815385401249, 83.85462239384651, 91.91933244466782, 95.52948832511902, 84.80021685361862, 74.97392892837524, 39.769878163933754, 45.81348806619644, 48.891186118125916, 66.38671651482582, 63.24607104063034, 52.666857317090034, 16.678315848112106, 3.8513308390975, 0.3673797834198922, 0.009781020271475427, 0.08596659448812716, 0.04548069839074742, 0.15890066017163917, 0.05715174615033902, 0.24853348644683138, 0.046897614156478085, 0.2988729625940323, 0.1774854480754584, 0.5910781142301857, 0.4176570230629295, 0.8604428102262318, 1.3012534752488136, 3.1099882442504168, 2.5452262116596103, 2.434336286969483, 6.152161527425051, 6.50505761615932, 7.744544930756092, 6.376847270876169, 6.648124689236283, 10.258588828146458, 6.516565773636103, 6.0981526505202055, 8.902511894702911, 13.871366567909718, 10.662604998797178, 7.375327292829752, 10.818351041525602, 7.3877056036144495, 6.202326910570264, 6.479102158918977, 5.015148539096117, 4.7871313244104385, 5.980174206197262, 2.3420299775898457, 4.426068998873234, 3.5009278915822506, 7.170354891568422, 5.0126853212714195, 4.161948971450329, 2.8303560242056847, 3.1873803539201617, 3.4183609345927835, 4.091455629095435, 1.7989829485304654, 1.5738599910400808, 0.12743028870318085, 0.3444655583007261, 0.46605472918599844, 4.712366536259651, 0.9902503760531545, 0.38207585108466446, 0.20469580282224342, 0.085465474112425, 0.055781611663405783, 0.07623661542311311, 0.037105079463799484, 0.07132416925742291, 0.5608673009555787, 0.18163969391025603, 7.786692269146442, 23.014574646949768, 51.016681864857674, 70.6814892590046, 59.66904558241367, 34.09215062856674, 18.362446278333664, 26.958369724452496, 31.886099204421043, 63.57606053352356, 69.8851127922535, 76.40643686056137, 74.20000925660133, 82.64877989888191, 77.23650991916656, 26.753636710345745, 0.7076134078670293, 0.4061007744167, 0.07909644438768737, 0.03809956477198284, 0.11552300420589745, 0.19256723957369104, 0.0837238464737311, 0.04885249050857965, 0.03844450387987308, 0.06235043125343509, 0.03720905806403607, 0.056501361323171295, 0.04507203477260191, 0.06280075162067078, 0.022588542888115626, 0.026190551070612855, 0.04483424323552754, 0.06257493092562072, 0.060609991051023826, 0.01767109835782321, 0.04216773260850459, 0.03807732260611374, 0.04675800504628569, 0.0756890737102367, 0.034318459656788036, 0.00786671434980235, 0.030676436726935208, 0.07135757332434878, 0.028753914302797057, 0.02529006618715357, 0.017251246863452252, 0.017779511290427763, 0.0161443298929953, 0.030026805179659277, 0.028589834728336427, 0.03920179879060015, 0.060745852315449156, 0.013115140045556473, 0.02089025296299951, 0.05555007272050716, 0.012707842906820588, 0.021038606428191997, 0.11655497539322823, 0.2041861551697366, 0.2173723530722782, 0.18417259940179065, 0.14828138781012967, 0.18231988709885627, 0.19856523256748915, 0.13623241247842088, 0.06907795541337691, 0.14197384502040222, 0.14765412459382787, 0.14424373337533325, 0.0974596269952599, 0.1402679443708621, 0.1326688568224199, 0.2592678362270817, 0.1257768430514261, 0.08265955475508235, 0.1262275196495466, 0.14926842937711626, 0.2662900375435129, 0.17939101613592356, 0.18911512481281534, 0.09761121065821499, 0.12810414395062253, 0.22679096407955512, 0.23198553768452257, 0.159767028526403, 0.15706209320342168, 0.08542032184777781, 0.0761961832176894, 0.15934750728774816, 0.14241276599932462, 0.08669243718031794, 0.26336413517128676, 0.1487620620173402, 0.30793509038630873, 0.36185057542752475, 0.32850941293872893, 26.068333983421326, 96.21160492300987, 114.19810697436333, 113.88435021042824, 88.69957521557808, 90.51096081733704, 81.58531576395035, 75.81847161054611, 96.9654768705368, 82.34696209430695, 83.64187940955162, 96.62715062499046, 100.33393532037735, 76.78524613380432, 66.47019803524017, 25.713098645210266, 7.719048773869872, 1.143653963226825, 0.3797874238807708, 0.16436908626928926, 0.2493160218000412, 0.3451435250462964, 0.15323373925639316, 0.3018292336491868, 0.11748108663596213, 0.46658916457090527, 0.330822805990465, 1.147665954194963, 0.6356346420943737, 1.009547165594995, 0.8393885556142777, 1.5411636955104768, 3.211704511195421, 7.871707007288933, 7.349617872387171, 6.261933837085962, 7.682034960016608, 7.160868225619197, 7.2784229926764965, 15.374210625886917, 8.162635546177626, 12.031221259385347, 19.960564523935318, 20.213608145713806, 16.21839612722397, 12.537693232297897, 13.012842535972595, 11.301902644336224, 10.261176489293575, 17.28197805583477, 26.943335831165314, 18.92332088202238, 35.07584944367409, 16.54915887862444, 7.006086381152272, 8.034672662615776, 6.85550426132977, 6.007912717759609, 7.321029156446457, 4.298318903893232, 5.372393494471908, 3.114031464792788, 7.801088746637106, 6.097440663725138, 2.3070747032761574, 0.736922660144046, 0.41897979739587754, 3.6284613981842995, 6.628867797553539, 1.2538467440754175, 0.31769154185894877, 0.22888153471285477, 0.2273432703805156, 0.28077625553123653, 0.4936814436223358, 0.2733562036883086, 0.22607103630434722, 0.6291912565939128, 1.1549451760947704, 14.885633792728186, 37.67811320722103, 72.29547545313835, 113.89322653412819, 115.7760939002037, 78.3217316865921, 57.04775623977184, 38.4811507165432, 32.83311478793621, 52.4922338873148, 58.81302371621132, 73.23492184281349, 75.52214831113815, 96.56703785061836, 86.56642287969589, 26.06181163340807, 0.60839265701361, 0.5099594732746482, 0.2719160512788221, 0.1071988012699876, 0.15155388799030334, 0.3395282872952521, 0.10453457274707034, 0.2302375721046701, 0.16918902372708544, 0.12143479674705304, 0.17819232889451087, 0.19247689051553607, 0.08319909611600451, 0.3025063098175451, 0.1195945599465631, 0.16481873870361596, 0.12690906354691833, 0.12060914261383004, 0.14155505108647048, 0.09534866956528276, 0.16201466729398817, 0.11154788313433528, 0.3062022943049669, 0.14504108199616894, 0.12973522127140313, 0.15667363826651126, 0.13403065328020602, 0.13572139927418903, 0.1384965714532882, 0.15183214884018525, 0.08330925309564918, 0.1271436712704599, 0.19912552437745035, 0.15143422409892082, 0.08312421341543086, 0.09632197397877462, 0.3760326612973586, 0.12352694815490395, 0.10815886576892808, 0.2376228172215633, 0.1074864280235488, 0.08641246196930297], [0.010559509064478334, 0.03148355943267234, 0.06549675890710205, 0.03250100307923276, 0.06284822680754587, 0.13565487315645441, 0.059208960956311785, 0.03488938644295558, 0.018814313771144953, 0.11339692180627026, 0.07248013847856782, 0.07609447187860496, 0.05504451059096027, 0.01696159775747219, 0.03829367720754817, 0.06803183889132924, 0.011591068359848578, 0.07140314861317165, 0.025441506986680906, 0.13473265076754615, 0.02285793136252323, 0.03135097103950102, 0.040743410208960995, 0.08503552569891326, 0.038695527910022065, 0.04341197658504825, 0.10846799254068173, 0.010340201642975444, 0.053319811340770684, 0.032580271872575395, 0.0175577853951836, 0.09750919503858313, 0.02647507379151648, 0.14113112149061635, 0.08821406998322345, 0.14311860781162977, 0.4423101892462, 4.13430355489254, 46.64900243282318, 94.9665941298008, 91.82083413004875, 86.19696110486984, 67.79677525162697, 72.38597899675369, 53.6757867783308, 31.135198697447777, 40.59189185500145, 56.13619655370712, 53.10336649417877, 49.61321957409382, 73.54703709483147, 66.53930112719536, 31.263842694461346, 4.5105930883437395, 0.06858146603917703, 0.175795191898942, 0.08743110418436117, 0.0556017633061856, 0.059738947165897116, 0.08688097237609327, 0.041519952719681896, 0.0714384599996265, 0.2150883193826303, 0.18793089460814372, 0.26792412798386067, 0.32305513217579573, 0.5821353534702212, 0.7082637667190284, 1.3836196367628872, 1.722288813907653, 2.9127861885353923, 8.665065485984087, 2.4290866311639547, 1.6517686354927719, 13.994057234376669, 5.603961143642664, 4.937831712886691, 5.411758907139301, 11.340511422604322, 5.645703328773379, 6.11859317868948, 7.7496428322046995, 7.96609346754849, 7.712109871208668, 2.6133762672543526, 6.76761070266366, 5.118870623409748, 4.259623205289245, 4.118360560387373, 4.711143001914024, 6.461084000766277, 12.263688035309315, 7.632256206125021, 4.679116420447826, 3.8884040247648954, 8.717800956219435, 5.180716579779983, 5.7657664362341166, 4.843670390546322, 4.3897828459739685, 7.004318051040173, 5.141701698303223, 4.037603493779898, 1.9259000569581985, 0.21004606416681781, 0.6206294253934175, 3.657055338844657, 2.686962643638253, 2.104147542268038, 0.19741589814657345, 0.14749534951988608, 0.26486873568501323, 0.03520612393913325, 0.06873947670101188, 0.04762010976264719, 0.11045974621083587, 0.300957239815034, 0.036775588159798644, 0.18528101179981604, 0.030141316710796673, 6.4302481804043055, 38.901092782616615, 63.712283223867416, 68.46287950873375, 73.70078444480896, 71.82667940855026, 54.37710754573345, 24.97449617832899, 30.242501199245453, 40.98191052675247, 62.63773888349533, 63.34617666900158, 72.62642249464989, 77.74610817432404, 46.96155086159706, 5.218679867684841, 0.82506860839203, 0.07910183237981983, 0.05683109011442866, 0.09752479498274624, 0.02933936306362739, 0.023735242684779223, 0.04350526454800274, 0.033067143012885936, 0.043051103566540405, 0.03360562681336887, 0.016705413945601322, 0.035138918756274506, 0.07361561700236052, 0.026629008207237348, 0.050556840069475584, 0.037460839084815234, 0.07006475207163021, 0.008604852573625976, 0.03318484392366372, 0.02684358536498621, 0.0340179603517754, 0.038936852070037276, 0.04552024372969754, 0.07633284229086712, 0.03676338354125619, 0.09589926892658696, 0.012593654209922533, 0.04237298096995801, 0.01734566845698282, 0.017017984282574616, 0.01898234899272211, 0.010472445865161717, 0.01433135403203778, 0.13011830305913463, 0.03695543280628044, 0.01653289800742641, 0.03219943137082737, 0.07586147461552173, 0.06287113690632395, 0.03960234702390153, 0.019879137980751693, 0.0681549463479314, 0.048748356057330966, 0.060037130970158614, 0.04040839361550752, 0.0608551966433879, 0.021423801481432747, 0.041677592307678424, 0.07140941233956255, 0.028901776095153764, 0.02812840812111972, 0.014379056501638843, 0.040914271157816984, 0.03172008931869641, 0.02809836412779987, 0.0348738903994672, 0.028925689948664512, 0.021434208247228526, 0.04998959804652259, 0.011192316123924684, 0.04037979866552632, 0.01389571798426914, 0.022120310786704067, 0.03269816945248749, 0.01311324849666562, 0.028019221499562263, 0.009966945890482748, 0.020994227852497716, 0.05817829223815352, 0.027759631229855586, 0.03131834622763563, 0.0396667134918971, 0.02109348824888002, 0.023423715065291617, 0.06082705069275107, 0.001306255285271618, 0.22093464707722887, 9.922513961791992, 66.61012932658195, 110.3391632437706, 103.65435674786568, 108.50050270557404, 93.93019214272499, 109.7952452301979, 81.36560395359993, 35.32554164528847, 32.98314593732357, 43.47334563732147, 42.26474829018116, 48.384160324931145, 77.39754527807236, 68.60705137252808, 29.571599699556828, 2.9885175498202443, 0.26865327323321253, 0.06612977376789786, 0.1776545390021056, 0.07522176558268256, 0.0527211393637117, 0.3666113637154922, 0.18361969938268885, 0.30543844623025507, 0.40184298413805664, 0.2593344514025375, 0.46536343346815556, 0.5779564683325589, 0.6118965439964086, 0.2641998528270051, 0.4970556922489777, 0.8479518117383122, 2.098063356243074, 4.105442678555846, 2.666051653213799, 5.506179565563798, 9.725053757429123, 10.169425662606955, 13.438146114349365, 10.36900045350194, 15.332581009715796, 14.553845096379519, 11.57981688156724, 10.218519978225231, 9.545097313821316, 15.942694321274757, 8.006779309362173, 10.721173156052828, 6.118997382000089, 2.6811088202521205, 4.274878911674023, 1.2325402186252177, 2.23932433873415, 3.627756298519671, 2.565314071252942, 2.0931110344827175, 0.7170694379601628, 2.1599435107782483, 4.3293860368430614, 3.9535470167174935, 4.016798185184598, 3.190413541160524, 1.7720053461380303, 1.2098998459987342, 1.3546776585280895, 3.5539830196648836, 1.4809987926855683, 1.5041807550005615, 2.893963186070323, 2.827509264461696, 1.4760182099416852, 0.5022533680312335, 0.18536929768742993, 0.3693772590486333, 0.11178559303516522, 0.08963613625383005, 0.1121358347882051, 0.16427334921900183, 0.24240082333562896, 0.045216853759484366, 0.34186314325779676, 0.2204393525607884, 4.316059676930308, 38.49565453827381, 63.18212427198887, 59.05239187180996, 40.337263718247414, 27.635008916258812, 20.271754525601864, 20.963414311408997, 44.71993714570999, 61.5205380320549, 89.57749530673027, 79.0539675951004, 84.95581090450287, 91.93162098526955, 66.50055840611458, 10.055687315762043, 0.535100883571431, 0.14713266195030883, 0.04663303850975353, 0.094520529237343, 0.1344332387088798, 0.019223736235289834, 0.050509227585280314, 0.02032683671131963, 0.05262812970613595, 0.04427738756930921, 0.01919855330925202, 0.034661535974009894, 0.027161319194419775, 0.05367454679799266, 0.020158404440735467, 0.024765887283138, 0.08499362404108979, 0.0218300215783529, 0.02617482496134471, 0.03283023463154677, 0.013823956014675787, 0.019751954278035555, 0.028219798041391186, 0.02448541854391806, 0.03729813062818721, 0.09010999754536897, 0.0370357591600623, 0.022259988545556553, 0.05783039567177184, 0.062412875558948144, 0.048088475450640544, 0.04058770020492375, 0.027978102807537653, 0.04527388409769628, 0.05055806461314205, 0.024645811499794945, 0.03155997837893665, 0.03795165474002715, 0.05136992593179457, 0.030577133657061495, 0.04422322934260592, 0.15468592930119485, 0.1154753212176729, 0.1595841336529702, 0.0985180186398793, 0.23129847220843658, 0.24805003660731018, 0.13063025136943907, 0.15671423374442384, 0.2083585984655656, 0.1030435090069659, 0.16768936591688544, 0.09068575571291149, 0.12995517899980769, 0.11382618002244271, 0.16973047982901335, 0.08029177712160163, 0.12094760648324154, 0.14022253977600485, 0.15155235916608945, 0.11100321353296749, 0.16973313671769574, 0.10753909082268365, 0.1635116830584593, 0.10131286515388638, 0.18247030558995903, 0.2613990171812475, 0.1281236475915648, 0.196413598023355, 0.09104413882596418, 0.15956406597979367, 0.25212686159648, 0.23601355904247612, 0.2719605207676068, 0.17915436008479446, 0.33412022748962045, 0.5384091997984797, 9.701197687536478, 71.7633368074894, 127.95963853597641, 113.5720145702362, 107.73232832551003, 89.24483835697174, 94.11043167114258, 69.1185799241066, 44.26012001931667, 53.59504871070385, 78.93234372138977, 81.44448012113571, 71.11232534050941, 98.86613488197327, 84.08972337841988, 43.00445079803467, 6.840091813355684, 1.4590517641045153, 0.33412690681871027, 0.3153535391902551, 0.26843903004191816, 0.25749291584361345, 0.26133373787160963, 0.2890319359721616, 0.3857464244356379, 0.6078494642861187, 0.4527312784921378, 1.0616737185046077, 2.796041965484619, 2.7043006382882595, 2.7976568788290024, 4.496974144130945, 7.028157496824861, 10.157804936170578, 15.360949337482452, 13.398893270641565, 20.19595619291067, 29.36090860515833, 16.015635207295418, 17.953588217496872, 14.86885579302907, 27.920096218585968, 25.765121653676033, 19.26373891532421, 18.503139428794384, 18.599849939346313, 22.385195419192314, 13.961994554847479, 19.72920063883066, 15.023481845855713, 12.003802880644798, 16.698810048401356, 17.69436612725258, 17.631872780621052, 32.27165311574936, 23.940733149647713, 20.173919275403023, 17.748087644577026, 19.07094296067953, 13.609434273093939, 13.405219931155443, 15.97270131111145, 17.785481438040733, 22.275476306676865, 15.96152801066637, 12.43809012696147, 9.6126139909029, 2.0118208089843392, 1.877028860617429, 7.849377980455756, 6.368650160729885, 4.835772989317775, 0.9397579729557037, 0.36990314489230514, 0.7211824203841388, 0.22783647204050794, 0.17671475739916787, 0.2265973822795786, 0.3760925674578175, 0.526218741433695, 0.10706052431487478, 0.520539233693853, 0.8458914910443127, 10.212856382131577, 53.03256869316101, 84.98270586133003, 94.53988462686539, 102.58416697382927, 94.4101519882679, 67.95001342892647, 35.10013774037361, 39.4330870360136, 51.363728642463684, 82.26362496614456, 81.80816620588303, 91.43632516264915, 104.99076783657074, 69.45598661899567, 9.600063264369965, 0.8836894878186285, 0.2585597976576537, 0.14070296165300533, 0.2083698642672971, 0.21534685394726694, 0.09261316517950036, 0.1739284084760584, 0.14044381852727383, 0.12299699534196407, 0.1423968988819979, 0.12661072018090636, 0.14757507102331147, 0.18251821864396334, 0.12370502648991533, 0.09552156028803438, 0.08782226796029136, 0.2208180705201812, 0.10374374760431238, 0.14105999405728653, 0.17822171794250607, 0.07655576118850149, 0.12564278149511665, 0.1291423788643442, 0.0918961020943243, 0.16612917854217812, 0.16562175733270124, 0.1708432857412845, 0.16519802069524303, 0.14361102279508486, 0.12207656895043328, 0.1119277736870572, 0.06672080533462577, 0.1348902829340659, 0.1687156522530131, 0.1479130599182099, 0.0900582475878764, 0.15736621047835797, 0.18130314478185028, 0.15636874915799126, 0.15276753692887723], [0.07025193655863404, 0.017512503254693, 0.08900286906282417, 0.030958057650423143, 0.010602858837955864, 0.011699750320985913, 0.07350001265876926, 0.016829285814310424, 0.05569898465182632, 0.09463649723329581, 0.01854480469773989, 0.025790583567868453, 0.02078157471260056, 0.034517470267019235, 0.02872324319469044, 0.005061890587967355, 0.022273222894000355, 0.0785959251516033, 0.019246677875344176, 0.020658869871112984, 0.029888941971876193, 0.06729170985636301, 0.03410363759030588, 0.0037702389136029524, 0.06526150551508181, 0.04466737504117191, 0.032281293970299885, 0.029506179307645652, 0.05423025955678895, 0.04532624632702209, 0.059280626446707174, 0.07624857884366065, 0.09359130097436719, 0.022571753652300686, 0.05177342420211062, 0.05329729458026122, 14.957885965704918, 76.71986684203148, 103.97762820124626, 85.13655960559845, 90.549346357584, 80.82283347845078, 57.44119472801685, 28.05087000131607, 29.085942059755325, 65.93631908297539, 73.52834209799767, 55.66094845533371, 65.88975638151169, 83.91963690519333, 44.54157091677189, 6.910697724670172, 0.3152910206699744, 0.11547992995474488, 0.014528791289194487, 0.14652006357209757, 0.11061224271543324, 0.13623190781800076, 0.0961725648085121, 0.14916622079908848, 0.014245528363971971, 0.08249804115621373, 0.9411652630660683, 0.14549687941325828, 1.4463646011427045, 5.244663348421454, 2.7177143935114145, 2.866544332355261, 1.7829659767448902, 3.397896895185113, 11.072642896324396, 1.8533932976424694, 1.793872460257262, 8.401591423898935, 8.011137675493956, 9.11486729979515, 7.5179098919034, 5.507738906890154, 7.1729083545506, 5.5644128657877445, 2.8594733867794275, 3.3524351846426725, 4.661661107093096, 6.969444947317243, 5.287655191496015, 7.169062485918403, 2.775244968943298, 4.504023240879178, 3.575749439187348, 0.9960020799189806, 1.2903297739103436, 2.3685539793223143, 0.6095059972722083, 5.32151042483747, 2.374812006019056, 8.435386810451746, 5.873640272766352, 2.0181260956451297, 4.1378425899893045, 2.5032508140429854, 8.187689501792192, 4.76526397280395, 6.365297315642238, 7.2095312643796206, 8.692026939243078, 9.79758521541953, 4.501985125243664, 0.8321609871927649, 0.7670703018084168, 1.1320261121727526, 0.35787061555311084, 0.16880102892173454, 0.046180068675312214, 0.09928410800057463, 0.04031749165733345, 0.025043289097084198, 0.1263006211956963, 0.030924551538191736, 0.1155807136092335, 0.061757369912811555, 0.2394675588584505, 0.10190521774347872, 9.890740066766739, 61.477759927511215, 76.25989392399788, 63.60556975007057, 85.8373712003231, 64.09213364124298, 50.91779977083206, 21.97469774633646, 29.149537347257137, 67.32106357812881, 58.509226217865944, 57.31481350958347, 87.37913846969604, 61.03796772658825, 17.22188238054514, 0.10027019961853512, 0.3324283682741225, 0.09791111253434792, 0.15378971176687628, 0.04635440287529491, 0.058944377888110466, 0.010223817116639111, 0.025539643029333092, 0.01981681984034367, 0.015924014078336768, 0.03299317315395456, 0.033815773349488154, 0.08322346082422882, 0.05930879095103592, 0.0002960547971042615, 0.038057407073210925, 0.06111651426181197, 0.05157878855243325, 0.07342273282120004, 0.0637954892590642, 0.07518001977587119, 0.005826986862302874, 0.026675824738049414, 0.06023313217156101, 0.03208887363143731, 0.003411575871723471, 0.015536988703388488, 0.05348351056454703, 0.04656031174818054, 0.02666426207724726, 0.01002610619252664, 0.012088341627531918, 0.01678242661000695, 0.07218647064291872, 0.062014646537136286, 0.01065913033016841, 0.052223785387468524, 0.03594375935790595, 0.030447536119027063, 0.07799957238603383, 0.029308287485037, 0.0664293862064369, 0.021715799484809395, 0.028475772196543403, 0.029490423512470443, 0.04746893057017587, 0.03971016252762638, 0.030268838090705685, 0.014137045855022734, 0.04464944104256574, 0.02581338234449504, 0.01602272899617674, 0.022797490855737124, 0.035815204537357204, 0.05540492718864698, 0.008117421111819567, 0.06946914145373739, 0.050854730725404806, 0.015034818188723875, 0.046259033188107423, 0.008063571804086678, 0.016211154725169763, 0.03159301879350096, 0.051983014127472416, 0.10978556441841647, 0.06395703996531665, 0.013223530713730725, 0.08584338313085027, 0.10472425085026771, 0.10287527897162363, 0.048847655416466296, 0.10286308548529632, 0.03303698955278378, 0.042291808567824773, 0.05044079414801672, 30.014807917177677, 102.26606324315071, 116.59824058413506, 102.55591168999672, 116.04430630803108, 109.7384762763977, 86.19980335235596, 45.88636435568333, 24.633084498345852, 36.22323587536812, 54.863682836294174, 47.62955881655216, 68.06230500340462, 87.25421637296677, 41.371347829699516, 4.2207289673388, 0.29301296453922987, 0.029956800244690385, 0.020805666681553703, 0.05961360584478825, 0.21493729233043268, 0.23395893804263324, 0.34377215488348156, 0.19630494760349393, 0.24134749313816428, 0.19155808200594038, 0.17226694762939587, 0.6191961304284632, 3.337428839877248, 8.842187281697989, 6.521285595372319, 5.91910483315587, 4.364527026191354, 3.6149711720645428, 3.5234556952491403, 2.525680297985673, 1.8385486816987395, 2.3712501721456647, 4.660924421623349, 9.1902638040483, 12.416334394365549, 9.378207419067621, 13.591124005615711, 11.259168237447739, 12.113764230161905, 7.861157348379493, 11.421312186866999, 11.084912437945604, 7.335225194692612, 2.261375980451703, 5.797104304656386, 3.5449687158688903, 0.4376414272701368, 0.9208321978803724, 0.3476336383027956, 0.3298290108796209, 0.6309379753656685, 0.26391252293251455, 0.850321875186637, 0.946346641285345, 1.9308507163077593, 1.1130651296116412, 0.7996052841190249, 1.4760349527932703, 3.5229586344212294, 6.199496537446976, 9.468609318137169, 12.05256661400199, 15.33966002985835, 13.810735121369362, 6.8143068719655275, 1.909326771274209, 0.7824854808859527, 0.6869452481623739, 0.19016839563846588, 0.10609140561427921, 0.08914929479942657, 0.15027837362140417, 0.014631431240559323, 0.04097174678463489, 0.12720144004561007, 0.09305022336775437, 0.1277780145755969, 0.10586329910438508, 0.1613135455409065, 0.362577642663382, 6.74868106842041, 60.64854942262173, 81.40515223145485, 55.80782197415829, 54.56290617585182, 31.799699440598488, 29.661345183849335, 27.705673724412918, 49.22516159713268, 94.73454058170319, 79.06304150819778, 74.2889852821827, 98.30588534474373, 78.54992464184761, 31.521301679313183, 0.14910937228705734, 0.38659855839796364, 0.1683799343300052, 0.2124952108715661, 0.05027775543567259, 0.09026418614666909, 0.02510968904971378, 0.05478705956193153, 0.02430959077173611, 0.019532380611053668, 0.026480383858142886, 0.037947687960695475, 0.04425638479006011, 0.03502259081869852, 0.06815915432525799, 0.09249785769497976, 0.042522898511379026, 0.10510221924050711, 0.11405787852709182, 0.07989580422872677, 0.04875603728578426, 0.032711509556975216, 0.02314099019713467, 0.05532021103135776, 0.044473993621068075, 0.022083578187448438, 0.04570384364342317, 0.027696248107531574, 0.060926387159270234, 0.025691547671158332, 0.04033824952784926, 0.07524343629484065, 0.04040639352751896, 0.12797777104424313, 0.07250389462569728, 0.013499278466042597, 0.02816736901877448, 0.05233010546362493, 0.040615144826006144, 0.1888944100937806, 0.1427341901580803, 0.15773585939314216, 0.09315359711763449, 0.062392013787757605, 0.11202264242456295, 0.22764027788070962, 0.09587713808286935, 0.1868690297123976, 0.17169871483929455, 0.14892805076669902, 0.09012907816213556, 0.11288943380350247, 0.08717138218344189, 0.1690669552772306, 0.14907990902429447, 0.07531244118581526, 0.22663441544864327, 0.20737572776852176, 0.09218856022926047, 0.14681664062663913, 0.13073965877993032, 0.1646921134670265, 0.15078214346431196, 0.19911416951799765, 0.42388082190882415, 0.19063458312302828, 0.1109387208998669, 0.2168650654493831, 0.18345430435147136, 0.15762021794216707, 0.14379880100023001, 0.20709187112515792, 0.12406369161908515, 0.18471405550371855, 0.1851867145160213, 30.6577106192708, 114.34580504894257, 130.19590973854065, 105.09822607040405, 114.61470142006874, 101.20575293898582, 74.20240312814713, 35.56560516357422, 41.82095490396023, 92.25535601377487, 109.85179379582405, 84.31408613920212, 90.71773052215576, 106.41262874007225, 56.46334379911423, 9.310800936073065, 0.7908884331118315, 0.23747496656142175, 0.10735483781900257, 0.47520211490336806, 0.2441492342040874, 0.263344869017601, 0.2440016804030165, 0.48976536781992763, 0.2780954696936533, 0.33201101410668343, 2.2811508318409324, 1.1599721875973046, 3.2569610327482224, 9.678803589195013, 5.1535979099571705, 5.695913834497333, 5.822908720001578, 10.498267617076635, 22.455162964761257, 8.927727341651917, 6.559541467577219, 19.277161695063114, 18.809513188898563, 22.429544739425182, 22.733722217381, 19.45950821042061, 22.408716157078743, 19.453871212899685, 13.286791685968637, 9.377205222845078, 13.379683401435614, 19.615924917161465, 17.97605261206627, 20.41026659309864, 15.814117770642042, 13.565849661827087, 9.716018792241812, 6.855667652562261, 5.990213742479682, 5.383633291348815, 2.781454548239708, 12.912097591906786, 9.860571585595608, 19.21953398734331, 17.07017932087183, 9.350478406995535, 11.728118173778057, 12.521297112107277, 14.548378139734268, 7.325407471507788, 8.168756067752838, 9.615507535636425, 13.000333607196808, 12.589398007839918, 5.3482970874756575, 1.34706761687994, 1.836546070408076, 3.410773929208517, 0.7619768532458693, 0.4468996304785833, 0.22518906800542027, 0.3812196204671636, 0.15509368007769808, 0.10061259687063284, 0.14962212211685255, 0.3829555929405615, 0.41547599947080016, 0.19221351714804769, 0.5866378149949014, 0.6343496579211205, 15.473586693406105, 80.23869082331657, 98.45463976264, 94.96598616242409, 121.23174235224724, 82.93554291129112, 64.48040440678596, 31.029019095003605, 36.7073754966259, 87.05124646425247, 75.4113082587719, 74.77087542414665, 107.92303249239922, 91.5282042324543, 32.28941336274147, 0.19083189050434157, 0.5068907816894352, 0.3146579983877018, 0.4407459497451782, 0.13205511553678662, 0.20700459455838427, 0.10391683128545992, 0.17426702077500522, 0.08232572188717313, 0.14027487603016198, 0.1348336273804307, 0.1769365111249499, 0.2265233307844028, 0.09639022930059582, 0.17024980508722365, 0.2244688879000023, 0.11348912623361684, 0.14862250856822357, 0.1769810399855487, 0.1424818896339275, 0.1969780310173519, 0.16287478676531464, 0.09657307964516804, 0.15870880015427247, 0.1349458549520932, 0.08859942274284549, 0.11905429128091782, 0.11890683395904489, 0.17505905561847612, 0.14946938812499866, 0.10688497670344077, 0.20639290160033852, 0.1351103000342846, 0.19372951705008745, 0.18425107409711927, 0.1486545248189941, 0.12315266081714071, 0.10462194579304196, 0.08195314148906618], [0.045868400047766045, 0.03339121292810887, 0.03634051521657966, 0.05901865202758927, 0.0721056062320713, 0.013215384715294931, 0.02951798502181191, 0.022028445891919546, 0.04574243903334718, 0.058086507124244235, 0.03283375612227246, 0.031348429183708504, 0.023070864663168322, 0.029239740870252717, 0.06072229654819239, 0.07283219849341549, 0.058516860008239746, 0.06680210761260241, 0.013883833416912239, 0.014226328075892525, 0.0824211620783899, 0.06276622691075318, 0.03304093777842354, 0.042921658168779686, 0.03749928604520392, 0.011275983069936046, 0.016540846409043297, 0.009070270079973852, 0.03184900779160671, 0.0291117333836155, 0.037682759793824516, 0.06790522107621655, 0.07809835224179551, 0.03457400707702618, 0.08697751094587147, 28.357238061726093, 102.22440987825394, 92.32043132185936, 82.23049834370613, 69.9810728430748, 59.55213725566864, 53.29286232590675, 36.023499593138695, 53.99654656648636, 84.39822882413864, 64.02099385857582, 66.14390954375267, 90.40999263525009, 66.562829464674, 17.43986338376999, 0.6254242337308824, 0.15269988274667412, 0.09956523354048841, 0.11564523592824116, 0.05236483055341523, 0.08203782796044834, 0.03907089507265482, 0.08722146230866201, 0.0967242254409939, 0.2508366230176762, 0.6445229589007795, 0.05098111476399936, 1.3453872757963836, 8.99291094392538, 25.807270891964436, 34.707474410533905, 40.96139542758465, 34.65386688709259, 31.035581342875957, 18.9929673448205, 15.305266175419092, 10.25302592664957, 5.182021334767342, 7.39272465929389, 5.459695709869266, 9.15772994980216, 14.038698188960552, 10.518323890864849, 7.884362228214741, 10.114692449569702, 7.795941922813654, 6.132183149456978, 4.861262021586299, 9.55026313662529, 6.3953309040516615, 6.70315096154809, 3.7184719182550907, 1.3761731050908566, 1.4329830254428089, 0.8406868390738964, 3.3561235992237926, 4.936022059991956, 4.847046034410596, 4.185909535735846, 0.6575588718988001, 1.1652840650640428, 3.010335979051888, 3.6063237860798836, 1.1294551938772202, 1.9037983054295182, 3.58669760171324, 11.118277497589588, 21.907239966094494, 31.100958734750748, 34.178994968533516, 31.133422292768955, 25.949506759643555, 19.31927103549242, 10.803489089012146, 2.974690804257989, 3.4505231212824583, 4.886700706556439, 1.0284663503989577, 0.08807146630715579, 0.13441695598885417, 0.05632475244055968, 0.10826980200363323, 0.06681303202640265, 0.0308328666142188, 0.026271545357303694, 0.09744127368321642, 0.08873461978510022, 0.2513951336732134, 0.5795373616274446, 25.70912215858698, 62.901729717850685, 56.66244551539421, 56.10357530415058, 70.93577161431313, 52.34690688550472, 39.54204618930817, 21.00775223225355, 44.011476561427116, 53.578185215592384, 53.629611656069756, 78.59043046832085, 74.16546911001205, 30.360555164515972, 1.7848329828120768, 0.2907886292086914, 0.15035233605885878, 0.08162048863596283, 0.04446770020877011, 0.05367857665987685, 0.05622963137284387, 0.06059594961698167, 0.013979474915686296, 0.03489397662633564, 0.027140431448060554, 0.04655072320019826, 0.08091087671346031, 0.019227847733418457, 0.016160896484507248, 0.010770150984171778, 0.03291608998551965, 0.010462852678756462, 0.02694018516194774, 0.05519279911823105, 0.02111339821567526, 0.05548939843720291, 0.056417324231006205, 0.10589556026388891, 0.03040711319044931, 0.0533638503839029, 0.022014751411916222, 0.031142564839683473, 0.0120679399879009, 0.04016644976218231, 0.02435368918668246, 0.0613533855357673, 0.02073749670671532, 0.02115549097652547, 0.011537142981978832, 0.036174741690047085, 0.0202737267682096, 0.07398030094918795, 0.04506419398239814, 0.06504811579361558, 0.01165617790320539, 0.09347767816507258, 0.037650316808139905, 0.01593683653482003, 0.06388163776136935, 0.02449004583468195, 0.02260261586343404, 0.07510710376664065, 0.03974699902755674, 0.02325228266272461, 0.030177802545949817, 0.04957500837917905, 0.008743486687308177, 0.04456939670490101, 0.07141300433431752, 0.0076934154458285775, 0.03974563347583171, 0.07135720225051045, 0.05805594177218154, 0.050410640687914565, 0.05679223497281782, 0.06864933544420637, 0.018005092642852105, 0.04809181140444707, 0.02505782034859294, 0.053289264542399906, 0.02576112401584396, 0.04929498121782672, 0.039662049093749374, 0.04107436354388483, 0.02928153862740146, 0.022342567317537032, 0.1024982456874568, 48.62816423177719, 122.37833082675934, 103.28104197978973, 109.09656152129173, 105.21133080124855, 97.6012359559536, 79.98543441295624, 35.77898271381855, 29.706897139549255, 50.2030885219574, 57.30555720627308, 69.10832807421684, 98.41832131147385, 66.5278485417366, 14.129475317895412, 0.23715925693977624, 0.1383642910514027, 0.1801416539819911, 0.21872748504392803, 0.2011086023412645, 0.07416042761178687, 0.02273237296321895, 0.1263881055638194, 0.23735470895189792, 0.16234027716564015, 0.23592430836288258, 0.25571838137693703, 3.4678174182772636, 14.71867360174656, 34.0639865398407, 46.391912028193474, 52.720924615859985, 48.108621910214424, 40.624011531472206, 27.157921716570854, 21.690235510468483, 13.995941933244467, 7.544428668916225, 8.542808946222067, 1.7937634536065161, 3.6455293698236346, 5.833375258371234, 7.681962763890624, 6.113536600023508, 11.871852111071348, 7.427499918267131, 8.896299228072166, 9.961875099688768, 15.28538279235363, 10.0675911270082, 2.4895665608346462, 4.84967976808548, 0.8620740508195013, 2.3938722582533956, 1.6406837990507483, 5.65183762460947, 7.366322726011276, 7.869230965152383, 7.745635472238064, 1.8503097631037235, 1.374652236700058, 1.4770012884400785, 4.164312919601798, 2.6362318033352494, 2.7583928732201457, 7.876459127292037, 16.560163088142872, 30.589186996221542, 39.67392951250076, 41.50405950844288, 39.721043184399605, 36.37641705572605, 26.88937872648239, 16.660734191536903, 7.313433364033699, 8.23244160041213, 7.797455666586757, 3.1839541252702475, 0.28673855122178793, 0.0490415526292054, 0.2550538326613605, 0.34864711517002434, 0.11150679783895612, 0.09822834355873056, 0.0922011470538564, 0.06988457345869392, 0.11523151828441769, 0.4765856562880799, 0.27931870718020946, 23.405851051211357, 72.01475411653519, 66.68189987540245, 48.2933945953846, 40.41223369538784, 21.364668980240822, 24.533871822059155, 40.11999897658825, 70.71263238787651, 81.20139956474304, 73.60147297382355, 89.75907996296883, 85.31798467040062, 48.550253212451935, 3.6281491024419665, 0.35331860824953765, 0.1806353751453571, 0.11824604793218896, 0.017946082625712734, 0.08156612631864846, 0.023759572140988894, 0.049652392117423005, 0.06658377518760972, 0.10170958761591464, 0.02672486771189142, 0.022380335212801583, 0.07563008039142005, 0.012305620202823775, 0.045160576701164246, 0.025181671808240935, 0.06446023835451342, 0.024908077211875934, 0.023860810360929463, 0.021263803719193675, 0.055891148949740455, 0.05436888161057141, 0.029777582712995354, 0.024702283371880185, 0.0030723000463694916, 0.01202048242703313, 0.018230820569442585, 0.039046741876518354, 0.030352656249306165, 0.052785661682719365, 0.030820969986962155, 0.0920424610376358, 0.03490798095299397, 0.0493203255609842, 0.0689844076987356, 0.021624105283990502, 0.058036805494339205, 0.015215824296319624, 0.14369785407325253, 0.1818676816765219, 0.14688888128148392, 0.1520967244869098, 0.12869477475760505, 0.07053868015646003, 0.12752872717101127, 0.15936631330987439, 0.11647985520539805, 0.11259733189945109, 0.0884020708326716, 0.10421715618576854, 0.2210604411084205, 0.08876512947608717, 0.12335031700786203, 0.19439958734437823, 0.1504016888793558, 0.148926462570671, 0.061513511318480596, 0.16579803224885836, 0.2936407027300447, 0.10889859404414892, 0.09972334810299799, 0.15846506401430815, 0.15516767220105976, 0.15398871124489233, 0.08883052752935328, 0.07780587926390581, 0.17997012881096452, 0.20589058636687696, 0.10087515387567692, 0.1500342070357874, 0.18567779363365844, 0.1581003874889575, 0.12666402122704312, 51.60978823900223, 136.74528390169144, 113.12588810920715, 105.40476322174072, 96.00390046834946, 76.47053942084312, 70.17260536551476, 48.39273266494274, 80.64503341913223, 115.15211418271065, 97.42247834801674, 87.2818560898304, 113.70531901717186, 84.99170377850533, 22.32813388109207, 1.3029410596936941, 0.30771502875722945, 0.2992816484766081, 0.5510964815039188, 0.36013986566103995, 0.15051476249936968, 0.18375601706793532, 0.3105489048175514, 0.574930643197149, 0.9980602632276714, 1.783129961695522, 3.5009822761639953, 3.1297293724492192, 10.455082934349775, 27.36602894961834, 39.26127165555954, 47.96930618584156, 42.03236036002636, 35.923538357019424, 22.498835921287537, 20.638746432960033, 14.261799417436123, 8.50284269079566, 14.369357395917177, 14.181476477533579, 20.377738438546658, 28.078956194221973, 24.436296857893467, 22.54088256508112, 25.29637310653925, 21.289748400449753, 18.035185039043427, 18.031674027442932, 24.63030304759741, 17.774950303137302, 16.87136258929968, 10.615096148103476, 5.467585511505604, 3.6243787547573447, 1.8369036074727774, 4.802124844864011, 7.474803579971194, 7.9109755251556635, 7.45250447653234, 1.0850257216952741, 4.18955591507256, 9.853895343840122, 12.15122926980257, 8.163218814879656, 4.786938484758139, 7.851271703839302, 16.32420524954796, 29.383808076381683, 40.54395742714405, 40.57734623551369, 37.41096094250679, 33.280932158231735, 24.59375660866499, 13.13546385616064, 5.857090735808015, 6.767701422795653, 6.812394624575973, 2.169290059246123, 0.3880758478771895, 0.27275360946077853, 0.4746153432643041, 0.42313606187235564, 0.23237595189129934, 0.29813057743012905, 0.30782219488173723, 0.1501210531569086, 0.15663694648537785, 0.8162679243832827, 1.3793809642083943, 36.34804777801037, 81.75234720110893, 71.86038359999657, 83.27134609222412, 105.38349956274033, 65.89107111096382, 52.7727310359478, 28.450367264449596, 56.52405694127083, 71.43466964364052, 72.5959025323391, 95.90475618839264, 99.6243841946125, 52.059117928147316, 2.765242005698383, 0.5200057185720652, 0.2306444916757755, 0.2066044879029505, 0.26674886292312294, 0.21847135503776371, 0.13446004508296028, 0.1382956127054058, 0.20175909477984533, 0.20133351761614904, 0.21729579311795533, 0.14484232000540942, 0.1284213675535284, 0.14127628557616845, 0.11433048421167769, 0.1286320632789284, 0.08901830573449843, 0.10209251355263405, 0.17874460550956428, 0.1585095631889999, 0.0950475134595763, 0.15194278821581975, 0.1394866855116561, 0.12154358817497268, 0.1612372527597472, 0.13063145364867523, 0.1553686012630351, 0.13456819084240124, 0.1599793866625987, 0.20299699710449204, 0.08181863464415073, 0.19476083514746279, 0.12319786503212526, 0.08619481974164955, 0.15952379704685882, 0.19698175659868866, 0.1223251735791564, 0.09866437016171403], [0.03005056318215793, 0.025267120836360846, 0.06140164739917964, 0.0468295332393609, 0.007626902779520606, 0.04939676677167881, 0.017819527893152554, 0.0056184642380685546, 0.017380057724949438, 0.047556711797369644, 0.021666134962288197, 0.0301353350005229, 0.06687791057629511, 0.03439782864006702, 0.04552778023935389, 0.008791439631750109, 0.009199322139465949, 0.020549642431433313, 0.04087740868271794, 0.03968795746914111, 0.10786983635625802, 0.10525642268476076, 0.05071437575679738, 0.03969745695940219, 0.04341762061812915, 0.009236902642442146, 0.09151264923275448, 0.0379264365619747, 0.05061508381913882, 0.039740657375659794, 0.047022161379572935, 0.05098377165268175, 0.031139637067099102, 0.21584572561550885, 41.04408659040928, 98.55372324585915, 84.9262484908104, 80.90008333325386, 60.17013229429722, 53.52950602769852, 33.35477739572525, 34.946747571229935, 64.21010211110115, 97.58941099047661, 69.37372863292694, 71.12652897834778, 85.70703819394112, 30.988948345184326, 3.166297422721982, 0.194725998735521, 0.06230199127458036, 0.08586132826167159, 0.05647744932502974, 0.04659142257878557, 0.02395068444457138, 0.10706568224122748, 0.15163479693001136, 0.32636867312248796, 0.2650518680457026, 0.7207354693673551, 2.472053300589323, 10.395037606358528, 35.80387897789478, 60.644989013671875, 79.69896778464317, 89.82072025537491, 91.05944618582726, 86.16973176598549, 78.72222259640694, 70.04145920276642, 53.40906389057636, 35.27364403009415, 21.04181170463562, 17.5376720353961, 9.500354714691639, 8.517368361353874, 8.656952921301126, 5.391542566940188, 9.226679150015116, 7.3140104580670595, 11.543950606137514, 5.580254690721631, 11.475492529571056, 7.765052430331707, 5.654119877144694, 5.495316423475742, 1.0504841501824558, 3.7448688643053174, 4.032812425866723, 11.085531804710627, 20.721300803124905, 24.615723229944706, 31.68126169592142, 38.92592445015907, 39.57407847046852, 26.471642442047596, 12.480309661477804, 4.201310584321618, 1.323352139443159, 10.450411085039377, 22.202383428812027, 37.36658692359924, 51.75935961306095, 58.226905167102814, 63.77165883779526, 66.13465324044228, 64.347343146801, 56.64921462535858, 51.28775551915169, 36.445903927087784, 26.130891926586628, 22.79054246842861, 18.95435381680727, 8.563517834991217, 0.12410863608238287, 0.2534251450560987, 0.5488801910541952, 0.0521969233523123, 0.13664756988873705, 0.00852078579555382, 0.11148788049467839, 0.010297945609636372, 0.2508435695199296, 0.1075680494250264, 0.1562118442961946, 9.560483638197184, 59.70207341015339, 78.47620099782944, 58.16063292324543, 72.6236030459404, 61.74145817756653, 35.11438697576523, 25.75015615671873, 22.980872355401516, 44.998101219534874, 45.80015078186989, 65.4881863296032, 75.94230696558952, 61.39294847846031, 7.505756244063377, 0.6752435385715216, 0.02886258142098086, 0.07251702321809717, 0.029280544149514753, 0.07487608803785406, 0.059914479934377596, 0.06878247673739679, 0.00965517521763104, 0.029211416804173496, 0.06824886513641104, 0.024743765716266353, 0.05962256356724538, 0.04534357176453341, 0.06803292242693715, 0.01975289123947732, 0.040855355764506385, 0.057298112515127286, 0.07408399382256903, 0.03744397377886344, 0.04934487951686606, 0.02796177184791304, 0.04790266764757689, 0.019914692420570645, 0.01561434368340997, 0.042620190361049026, 0.009047402654687176, 0.01988016585528385, 0.030001763261680026, 0.115227377100382, 0.06083666521590203, 0.08791680273134261, 0.014042673428775743, 0.02016691316384822, 0.04534489649813622, 0.03591870816308074, 0.013237865296105156, 0.030977004680607934, 0.05870825618330855, 0.04262951544660609, 0.022163000976433977, 0.03885671125317458, 0.031906394360703416, 0.021929883114353288, 0.08300974455778487, 0.04028907853353303, 0.03045161793124862, 0.026651298612705432, 0.029214962414698675, 0.02657048244145699, 0.03446969079959672, 0.03520997197483666, 0.031096052589418832, 0.03382444163435139, 0.0357718927989481, 0.042722265352495015, 0.09641776297939941, 0.016046457312768325, 0.06872361700516194, 0.05908694816753268, 0.09654680761741474, 0.07883865939220414, 0.049671580345602706, 0.06495981506304815, 0.08018509339308366, 0.04855632534599863, 0.03214172196749132, 0.06683436877210625, 0.049548684401088394, 0.03686782598379068, 1.0913017974235117, 68.46500739455223, 112.32756614685059, 96.60189718008041, 112.79337555170059, 88.49576935172081, 84.49232697486877, 48.389639630913734, 33.075435385107994, 41.020698845386505, 70.4973055422306, 73.09775680303574, 78.40657353401184, 91.90879940986633, 26.633120477199554, 1.5311352023854852, 0.2771393459988758, 0.06588935502804816, 0.08581322224927135, 0.1887905687908642, 0.1845467308885418, 0.045297343385755084, 0.1027005996729713, 0.23305841605179012, 0.22074718057410792, 1.8335577682591975, 2.164709880016744, 6.4246259070932865, 17.308650724589825, 47.45344206690788, 72.3619718849659, 91.42767682671547, 99.05682384967804, 101.09980702400208, 94.14184838533401, 88.16258043050766, 79.28127899765968, 62.16053009033203, 43.83376769721508, 28.432990796864033, 22.08549030125141, 12.636985704302788, 5.748702976852655, 1.905894367955625, 1.960864830762148, 2.1566837606951594, 4.423750648275018, 6.1484225280582905, 10.1974624581635, 11.62090027704835, 7.637144168838859, 1.2369780242443085, 3.7467887112870812, 1.6468005208298564, 4.10275099799037, 5.903279157355428, 16.239657886326313, 28.077441975474358, 32.0401581376791, 42.23789133131504, 50.80954737961292, 52.81283028423786, 39.77375775575638, 21.126634553074837, 8.785599768161774, 5.211283564567566, 12.407607212662697, 26.51414316147566, 41.55456259846687, 57.25406996905804, 63.01923081278801, 72.737657725811, 72.59712606668472, 72.22217738628387, 65.12222796678543, 62.47379668056965, 48.70227925479412, 35.30797518789768, 31.33190844208002, 23.77653256058693, 12.446992099285126, 0.5422031180933118, 0.30433223058935255, 0.870116378646344, 0.6315873842686415, 0.256987958564423, 0.0877512370061595, 0.03397291569854133, 0.09172589052468538, 0.1761468659969978, 0.04477602546103299, 0.3832615655846894, 5.614537876099348, 59.377798810601234, 86.90991684794426, 61.40176400542259, 56.120693385601044, 30.679031275212765, 13.79254074767232, 29.150323905050755, 41.36341005563736, 69.2060512304306, 76.87077954411507, 79.08523231744766, 85.59790804982185, 82.85715311765671, 14.104562904685736, 0.5041249457281083, 0.07703938172198832, 0.03339531700476073, 0.07039539370452985, 0.0784458257840015, 0.04403386665217113, 0.012114837227272801, 0.08431282971287146, 0.019958985649282113, 0.03561926270776894, 0.01574692279973533, 0.07252881594467908, 0.05094490908959415, 0.03862042256514542, 0.017529218275740277, 0.023730927096039522, 0.015488270419155015, 0.05437880412500817, 0.057694059432833456, 0.033894003136083484, 0.031638894652132876, 0.030519825013470836, 0.11090571759268641, 0.04719344164186623, 0.026348593273723964, 0.05268163113214541, 0.0580500416981522, 0.008020332425076049, 0.04682220453105401, 0.022823232247901615, 0.05555768344493117, 0.04397303651785478, 0.017906943612615578, 0.03462256208877079, 0.04511489751166664, 0.04307242918002885, 0.12339677545242012, 0.19132777873892337, 0.1744581980165094, 0.17801320413127542, 0.11046307845390402, 0.12790489214239642, 0.17017403180943802, 0.11349380918545648, 0.19682862184708938, 0.1787448429968208, 0.18199935351731256, 0.171748720749747, 0.2175500083831139, 0.13722027040785179, 0.12167609864263795, 0.1360336653306149, 0.10943008310277946, 0.07993890074430965, 0.16721308522392064, 0.16971593373455107, 0.22335998568451032, 0.3065828082617372, 0.26501894637476653, 0.17630670976359397, 0.14664069225545973, 0.0966378914017696, 0.1886222348548472, 0.1517879613675177, 0.20216202159645036, 0.23061649786541238, 0.16505907580722123, 0.15543710149358958, 0.1717225377797149, 0.7857401249930263, 70.46429291367531, 130.07816165685654, 102.94936537742615, 107.00808718800545, 77.76728823781013, 67.48399883508682, 44.240938648581505, 46.880440413951874, 88.2004263997078, 133.12708765268326, 95.76422452926636, 89.78807240724564, 104.51914474368095, 39.33390475809574, 4.09649558365345, 0.5392143409699202, 0.24946635123342276, 0.23543499555671588, 0.44155922485515475, 0.18906776094809175, 0.15157098707277328, 0.33322160539682955, 0.6445341208018363, 1.4169768593274057, 3.49081520922482, 1.8239685078151524, 4.724843166768551, 13.183024004101753, 41.070502772927284, 69.6915739774704, 92.3863197863102, 102.16198682785034, 103.44516277313232, 96.34444579482079, 89.83701378107071, 82.10608541965485, 60.39039887487888, 39.802594408392906, 28.471376337110996, 21.692593283951283, 14.261367190629244, 15.709513183683157, 16.735476180911064, 18.3581031113863, 21.34263016283512, 21.421798914670944, 30.101749151945114, 23.005721122026443, 27.64721006155014, 21.14657398313284, 16.598795615136623, 13.89237754046917, 3.821922317147255, 7.278244877234101, 7.035468779504299, 17.847496010363102, 27.831555269658566, 33.84182766079903, 44.93084102869034, 58.21083202958107, 60.05519986152649, 42.45269760489464, 15.061936732381582, 5.4818247724324465, 4.236805429682136, 12.757083959877491, 26.286168694496155, 43.669909089803696, 60.19326165318489, 67.8094969689846, 74.65239778161049, 76.6528308391571, 72.75239333510399, 65.65790802240372, 59.88173916935921, 46.47872976958752, 33.650633320212364, 28.77623587846756, 22.26026952266693, 10.015945248305798, 0.4666058480506763, 0.5260763084515929, 1.1452339659444988, 0.25323156325612217, 0.20806077460292727, 0.08906684219255112, 0.3450050699757412, 0.23767408478306606, 0.3498626343207434, 0.13642532634548843, 0.5343077355064452, 14.980928879231215, 77.63769999146461, 98.29266965389252, 78.67438316345215, 107.8790232539177, 85.0596821308136, 47.01148398220539, 31.28122106194496, 31.127811893820763, 59.79478843510151, 66.5698666870594, 82.22703292965889, 97.57925793528557, 89.71725180745125, 13.933972008526325, 0.6475592334754765, 0.1554626165307127, 0.11197495201486163, 0.15986868791515008, 0.31575673318002373, 0.16651457583066076, 0.1278791989898309, 0.16148254740983248, 0.13459351292112842, 0.22551530128112063, 0.15681754070101306, 0.12966793816303834, 0.1596200981293805, 0.17473448475357145, 0.11218720625038259, 0.15219847293337807, 0.1693273600540124, 0.1815096102654934, 0.12423698310158215, 0.14369561278726906, 0.10864826021133922, 0.24471276177791879, 0.1514621585374698, 0.25401254009921104, 0.08983931402326562, 0.13433686341159046, 0.10800406118505634, 0.07812578944140114, 0.14990829426096752, 0.13570694223744795, 0.16336699394742027, 0.1403187814867124, 0.13632065383717418, 0.2411530801327899, 0.22546091669937596, 0.12704658351140097], [0.02905448967794655, 0.03680546331452206, 0.010226164158666506, 0.09167969183181413, 0.032438109774375334, 0.03983145914389752, 0.048058318279800005, 0.056331828818656504, 0.007505781031795777, 0.013247442711872282, 0.014047369368199725, 0.015380764762085164, 0.05834558716742322, 0.01628201498533599, 0.009846000866673421, 0.031787353873369284, 0.02284309211972868, 0.052048081925022416, 0.06107083136157598, 0.07794572215061635, 0.01468247708544368, 0.06514756358228624, 0.06622050132136792, 0.08923847126425244, 0.09225014364346862, 0.13541435793740675, 0.061211453503347, 0.03249239787692204, 0.027791868269559927, 0.11227503200643696, 0.04550479592580814, 0.29466584615875036, 0.3881952149095014, 36.91577151417732, 114.4793450832367, 83.65853771567345, 83.19656610488892, 56.096674874424934, 45.98107047379017, 41.51100553572178, 58.795388862490654, 63.64165261387825, 59.659048318862915, 59.71742458641529, 71.1099998652935, 67.65156984329224, 13.291415087878704, 0.6349699746351689, 0.1669732527807355, 0.09473874291870743, 0.04106020336621441, 0.06587904659681953, 0.015147779558901675, 0.04007057912531309, 0.1752966467756778, 0.16853378154337406, 1.2532139592804015, 9.064529500901699, 23.25283896178007, 44.03525948524475, 58.05143438279629, 74.10049259662628, 88.3561572432518, 94.47138950228691, 92.72751107811928, 90.96523404121399, 91.15470707416534, 87.85300344228745, 85.34569278359413, 79.93048176169395, 77.0093809068203, 67.43658497929573, 45.9099230915308, 41.421664729714394, 20.199465304613113, 12.819458562880754, 5.461726700887084, 4.27750694565475, 1.6499562514945865, 4.740043301135302, 3.0202211486175656, 6.3036741223186255, 8.36730681359768, 10.887169148772955, 7.257882719859481, 0.592485285596922, 1.7469751392491162, 7.1634207386523485, 16.392510384321213, 24.71586875617504, 43.7993985414505, 49.31806281208992, 64.3155312538147, 67.08688214421272, 73.76756966114044, 76.86381831765175, 83.61381411552429, 83.77781331539154, 69.2954832315445, 47.79618747532368, 45.3897500038147, 55.99335841834545, 71.22986063361168, 86.48709073662758, 88.38678359985352, 90.41095778346062, 91.75461128354073, 95.48029616475105, 91.81488364934921, 81.72501906752586, 63.13942216336727, 49.37365382909775, 36.22487358748913, 28.648709021508694, 11.53199264779687, 0.3154984657885507, 0.587398367933929, 0.40386121021583676, 0.15295092161977664, 0.1769432646688074, 0.0879901937150862, 0.12739224621327594, 0.053191067272564396, 0.07756775376037695, 0.11192620775545947, 0.5837404110934585, 0.3814820438856259, 34.71894219517708, 85.27214393019676, 70.8854167163372, 56.1099361628294, 76.93773195147514, 60.9416238963604, 34.40412148833275, 25.07703747600317, 27.506444714963436, 39.97021101415157, 56.58841788768768, 75.33406600356102, 61.12004332244396, 18.285897485911846, 0.7164068485144526, 0.04101468744920567, 0.10199556680163369, 0.1581906178034842, 0.0464681407174794, 0.13157309062080458, 0.1422229246236384, 0.07625269034178928, 0.04663024432375096, 0.04501313051150646, 0.02825496470904909, 0.045505675370804965, 0.020746064801642206, 0.058148175885435194, 0.06430059496778995, 0.0670965101744514, 0.030044820814509876, 0.023416265757987276, 0.03778378835704643, 0.051624901898321696, 0.023377783545583952, 0.059294571401551366, 0.08499053670675494, 0.05116077387356199, 0.06239807713427581, 0.03514491159876343, 0.05873251699085813, 0.04790987390151713, 0.052053302933927625, 0.11803674002294429, 0.12318858818616718, 0.04952721777954139, 0.11188971635419875, 0.005673062187270261, 0.03975056504714303, 0.024872849317034706, 0.06255432890611701, 0.097842308023246, 0.08268553734524176, 0.0381357815786032, 0.043654647743096575, 0.023672243623877876, 0.05034291971242055, 0.047761566820554435, 0.036558721476467326, 0.020920313654642086, 0.023632306802028324, 0.03390610756468959, 0.07240493665449321, 0.04885283560724929, 0.06453347348724492, 0.062967489939183, 0.05872041256225202, 0.03204584019840695, 0.04964920459315181, 0.08436757052550092, 0.10479895543539897, 0.0359969527926296, 0.02314531506272033, 0.020611305626516696, 0.14213083893992007, 0.14011920313350856, 0.0316728182224324, 0.08138914636219852, 0.013869076738046715, 0.06305074406554922, 0.13959652336779982, 0.13213455502409488, 62.939503490924835, 125.78061506152153, 102.93904513120651, 110.61420768499374, 80.63520714640617, 73.81125211715698, 46.51100143790245, 28.995911590754986, 27.92383521795273, 48.404063656926155, 66.96030333638191, 84.12797212600708, 67.55828484892845, 9.383571781218052, 0.4722698894329369, 0.09306902196840383, 0.0333809156290954, 0.14006878162035719, 0.14304611482657492, 0.09847834342508577, 0.0986158856539987, 0.05726127972593531, 0.28496511513367295, 3.053081310354173, 14.572863075882196, 35.11315204203129, 57.185776233673096, 73.53545531630516, 88.49152877926826, 96.19956716895103, 100.46400234103203, 98.18113803863525, 95.54897367954254, 94.55775126814842, 91.80171355605125, 89.88060504198074, 87.5381751358509, 86.3669715821743, 76.92529141902924, 56.30310259759426, 50.122703835368156, 26.713299974799156, 17.482736483216286, 8.696623742580414, 2.776625482365489, 0.6096362590324134, 0.6101227516774088, 0.541125638410449, 0.23548986995592713, 3.5835917433723807, 3.2644884288311005, 2.530603646300733, 1.6214327258057892, 1.3817755482159555, 11.18119452148676, 21.61724902689457, 37.728924080729485, 52.621461153030396, 62.669782564044, 77.4570880830288, 79.61732536554337, 88.15435767173767, 95.37180438637733, 98.7438802421093, 102.27887615561485, 92.47500702738762, 77.99450844526291, 71.07563450932503, 74.7806940972805, 84.62237879633904, 91.56975880265236, 91.40891343355179, 92.90894374251366, 95.33835858106613, 98.5809525847435, 93.58989000320435, 87.94071793556213, 72.01303660869598, 57.60091915726662, 45.95101788640022, 35.31652092933655, 16.540622636675835, 1.3121721893548965, 0.6560277321841568, 0.7927980681415647, 0.5667232617270201, 0.7406689028721303, 0.1404180214740336, 0.06548575285705738, 0.16186781111173332, 0.14712829812197015, 0.17565370886586607, 0.7243113149888813, 0.5697021237574518, 28.628359213471413, 90.3430326282978, 78.50457027554512, 58.00189644098282, 52.00907081365585, 24.04328014701605, 17.67738103866577, 32.01822191476822, 47.96994835138321, 61.45412899553776, 76.38336449861526, 82.95788571238518, 77.34700798988342, 31.698451973497868, 1.3174346694722772, 0.23144329490605742, 0.044758889271179214, 0.10393868753453717, 0.07321637123823166, 0.048105426103575155, 0.03005062069860287, 0.09910110922646709, 0.07081507821567357, 0.053675997696700506, 0.027573170336836483, 0.01485761558797094, 0.0646866305032745, 0.06761942742741667, 0.05010239707189612, 0.06422548220143653, 0.07662430594791658, 0.025297842039435636, 0.040064296845230274, 0.04961011196428444, 0.11176781117683277, 0.050388617455610074, 0.040397439515800215, 0.031088345385796856, 0.03587180071917828, 0.034325654778513126, 0.009518024471617537, 0.028244505992915947, 0.042826763456105255, 0.03402709247893654, 0.07516243829741143, 0.10187092309934087, 0.11702613526722416, 0.05890899970836472, 0.009000312456919346, 0.10875446154386736, 0.15650200919480994, 0.22029969521099702, 0.13106822239933535, 0.11247241360251792, 0.1376432500546798, 0.16720219049602747, 0.13384403282543644, 0.20098077482543886, 0.10106607878697105, 0.15870617295149714, 0.12148603462264873, 0.10652905009919778, 0.1538509241072461, 0.2500041708117351, 0.2824189845705405, 0.2276175533188507, 0.2369037503376603, 0.16221485420828685, 0.20799822639673948, 0.14520791679387912, 0.2222479961346835, 0.09697479676106013, 0.1113299885764718, 0.14266573445638642, 0.25661177875008434, 0.21231167775113136, 0.1393680160981603, 0.2311763889156282, 0.10926574934273958, 0.13636044779559597, 0.24651436979183927, 0.2662767976289615, 68.32286462187767, 146.37977331876755, 102.23631083965302, 111.34244620800018, 68.36321845650673, 63.135633766651154, 55.977266281843185, 81.40642136335373, 89.79865103960037, 82.70681038498878, 86.73850044608116, 87.74359211325645, 86.14258602261543, 17.419580072164536, 1.8812290602363646, 0.29595445201266557, 0.16688306699506938, 0.22139933542348444, 0.1963021422852762, 0.13973242545034736, 0.3167256811866537, 1.041412849444896, 1.1215536366216838, 2.73070209659636, 11.83173006400466, 27.37534984946251, 50.06190709769726, 67.38141193985939, 87.46543943881989, 99.52504232525826, 105.57373255491257, 103.05936947464943, 103.45196440815926, 101.88473850488663, 100.40633663535118, 96.06798782944679, 92.9096657037735, 91.09293758869171, 78.2412900030613, 57.54304826259613, 50.48817202448845, 24.15354073047638, 18.017324097454548, 13.991729859262705, 11.547803599387407, 10.082473028451204, 15.690152272582054, 10.808356627821922, 17.9007026553154, 18.947903662919998, 24.951638504862785, 17.04114317893982, 2.2072573844343424, 3.206259165890515, 10.808541867882013, 23.571138381958008, 41.55131757259369, 59.131401032209396, 71.77595973014832, 82.73422971367836, 87.47832834720612, 97.08545923233032, 109.86421152949333, 122.0107689499855, 117.79570072889328, 100.85979670286179, 88.26398938894272, 86.11414834856987, 90.74451148509979, 99.94283750653267, 105.24776324629784, 104.72640082240105, 105.33617690205574, 107.2700147330761, 110.57724326848984, 105.11223211884499, 94.20736446976662, 78.82887527346611, 63.12393419444561, 48.26246805489063, 35.98229840397835, 13.353194072842598, 1.5265604853630066, 2.302793045528233, 1.415892611257732, 0.5551074631512165, 0.3842564293881878, 0.15294578595785424, 0.14653070596978068, 0.3521596407517791, 0.2097653245436959, 0.2354208947508596, 0.9649508586153388, 1.2208678387105465, 46.52588523924351, 105.80267786979675, 88.24097782373428, 78.7321400642395, 110.84517449140549, 85.07552728056908, 42.63161860406399, 29.63473331183195, 34.627982676029205, 57.29702286422253, 76.07663735747337, 94.91355657577515, 89.87689644098282, 33.09091195464134, 1.1855591833591461, 0.3095093637239188, 0.2032305658212863, 0.3749536973191425, 0.19424756581429392, 0.2501766459317878, 0.15979923773556948, 0.22977442742558196, 0.16748917900258675, 0.15049729234306142, 0.07613195775775239, 0.11686712270602584, 0.12933305144542828, 0.1796115527395159, 0.1474424047046341, 0.1687351707369089, 0.16363821923732758, 0.11246004200074822, 0.18204860243713483, 0.2462773723527789, 0.19826236210064963, 0.18849403626518324, 0.23443698504706845, 0.08538553738617338, 0.20912437612423673, 0.18538828182499856, 0.14647961652372032, 0.135714630887378, 0.15383847086923197, 0.1770097017288208, 0.3156495076837018, 0.20019111485453323, 0.26044874161016196, 0.11762143418309279, 0.11686769415973686], [0.06444673868827522, 0.01895839988719672, 0.044115617929492146, 0.038966664142208174, 0.017855920959846117, 0.02847322291927412, 0.051129388448316604, 0.06300638589891605, 0.04896241000096779, 0.048975022800732404, 0.021808360143040773, 0.05249532237940002, 0.022104473355284426, 0.013462520819302881, 0.04014863079646602, 0.09042896519531496, 0.05495931203768123, 0.08276590451714583, 0.027966057750745676, 0.0122065741015831, 0.06943780797882937, 0.03257454991398845, 0.081922861863859, 0.034611812079674564, 0.0773192233464215, 0.13387337734457105, 0.037302097407518886, 0.09525633897283114, 0.031232338733389042, 0.07094523607520387, 0.18049654900096357, 0.20639281254261732, 25.258057862520218, 90.32429203391075, 83.30609902739525, 78.06320875883102, 68.20254027843475, 56.33643060922623, 35.34302070736885, 66.10873103141785, 73.64134803414345, 81.25562265515327, 86.46696701645851, 99.17359158396721, 54.479892030358315, 3.693708647042513, 0.14561724092345685, 0.032797669191495515, 0.06653793272562325, 0.10049011281807907, 0.041897898845491, 0.05808484842418693, 0.4066103626973927, 0.823358700145036, 1.1429831804707646, 5.448355218395591, 25.420046970248222, 51.58667027950287, 78.12111005187035, 87.82319784164429, 96.4181238412857, 95.01291364431381, 87.62094989418983, 83.28896194696426, 80.18125310540199, 77.2836121916771, 77.76394441723824, 74.12684038281441, 79.94716286659241, 80.117978900671, 83.24807614088058, 80.961944013834, 68.19304838776588, 70.58799907565117, 49.660998210310936, 35.20386837422848, 22.300287075340748, 9.718300569802523, 3.4467373369261622, 1.0018744273111224, 1.8227013945579529, 6.113924654200673, 5.319506507366896, 2.8746348107233644, 0.24098293535644189, 1.6649203235283494, 4.582371711730957, 18.1244308501482, 29.677158035337925, 52.27913372218609, 66.05088293552399, 80.48136860132217, 93.86754870414734, 103.96976262331009, 96.71092852950096, 88.82398813962936, 81.47506088018417, 83.50656867027283, 88.74300688505173, 99.16308894753456, 91.6629146039486, 90.97933128476143, 93.96822050213814, 90.93246459960938, 97.53928408026695, 96.72043561935425, 93.49966004490852, 92.62698367238045, 99.35403630137444, 94.79979068040848, 91.01212352514267, 81.58276990056038, 67.43534624576569, 49.856847301125526, 32.83603683114052, 6.502184495329857, 1.0181729402393103, 1.6947472980245948, 1.544053084217012, 0.435073982225731, 0.1493633649079129, 0.24585954321082681, 0.15425867488374934, 0.11756881591281854, 0.022563912862096913, 0.2842017717193812, 0.18268377694766968, 0.5597687442786992, 11.619702391326427, 70.15830293297768, 82.23824232816696, 55.06266675889492, 84.24353912472725, 85.95292299985886, 50.30845686793327, 29.216943830251694, 21.018644347786903, 43.516104742884636, 50.68519905209541, 71.99860498309135, 75.61015158891678, 49.061128199100494, 2.6671253331005573, 0.12057822474162094, 0.0482860796910245, 0.16169720620382577, 0.03006319639098365, 0.05960990623862017, 0.06941327257663943, 0.031236839859047905, 0.09992291903472506, 0.06299711647443473, 0.10145097141503356, 0.07558224897366017, 0.14664100395748392, 0.08144862949848175, 0.04862777561356779, 0.011137040964968037, 0.030993430264061317, 0.026725105199147947, 0.01776712670107372, 0.13123620010446757, 0.029174164701544214, 0.035684749818756245, 0.016187140681722667, 0.032289004884660244, 0.029615685052704066, 0.025056113408936653, 0.03311639935418498, 0.06165916893223766, 0.004031036796732224, 0.0583463441580534, 0.10402453175629489, 0.05639446979330387, 0.051411293243290856, 0.009730869642226025, 0.06650325958617032, 0.02166621659853263, 0.05913191118452232, 0.030301409096864518, 0.021838591528648976, 0.05456411839986686, 0.07883108206442557, 0.01805954030714929, 0.024084844335447997, 0.027304165923851542, 0.0476208593318006, 0.04879049891314935, 0.01033775255564251, 0.008645414654893102, 0.06582216097740456, 0.07027501735137776, 0.04927686168230139, 0.05523179155716207, 0.0782958822674118, 0.11842706517199986, 0.05156268394785002, 0.05196783349674661, 0.1055227275355719, 0.01491135635660612, 0.07803785978467204, 0.14396156882867217, 0.0058886556234938325, 0.03277621741290204, 0.02557645540946396, 0.060022740726708435, 0.149454218626488, 0.25665942463092506, 47.82989166676998, 104.846580773592, 101.33217975497246, 105.25079548358917, 98.40640515089035, 86.2202462553978, 33.45306672155857, 21.226004920899868, 42.00464844703674, 74.45670828223228, 92.7847208082676, 112.1823987364769, 56.11552946269512, 1.5627965284511447, 0.15393843816127628, 0.06929908573511057, 0.032472296807100065, 0.11944892088649794, 0.09347124374471605, 0.12650701246457174, 0.4526568856090307, 0.8411885902751237, 1.6010438511148095, 8.409448452293873, 32.17437833547592, 63.694693967700005, 86.56819358468056, 94.62929382920265, 100.15962347388268, 96.90241545438766, 91.48563891649246, 88.44820350408554, 82.58020877838135, 82.87305146455765, 81.92703142762184, 83.201262652874, 86.76778927445412, 86.35516941547394, 91.02823466062546, 87.31473192572594, 81.16995245218277, 77.50415995717049, 60.23884020745754, 44.8240477591753, 29.850936010479927, 14.335437566041946, 5.23401346988976, 1.7350951954722404, 0.22373524523572996, 0.8448432816658169, 4.1534497775137424, 1.8303066864609718, 1.2531056650914252, 3.8635006360709667, 7.3577936086803675, 21.996240690350533, 39.15350183844566, 69.40367862582207, 76.8999695777893, 91.83807760477066, 105.21984994411469, 113.38689610362053, 104.2080782353878, 97.26700589060783, 92.01840832829475, 91.82906448841095, 98.71797323226929, 105.56662693619728, 99.43149894475937, 95.85146024823189, 99.24451857805252, 98.12759891152382, 101.12867027521133, 94.43972960114479, 96.29614278674126, 94.77133020758629, 100.74312016367912, 97.0062106847763, 93.30321818590164, 85.10738477110863, 73.1038136780262, 56.19914397597313, 41.5834866464138, 9.42585876211524, 1.5582987572997808, 1.3433068874292076, 0.44962622167076916, 0.8009176980704069, 0.9121545916423202, 0.405062391073443, 0.061598546599270776, 0.12069184012943879, 0.10864740674151108, 0.10901868095970713, 0.05855792674992699, 0.886647985316813, 7.41171651519835, 71.99868857860565, 94.33324411511421, 60.893419682979584, 77.42205396294594, 48.53985697031021, 14.998656827956438, 14.787689298391342, 39.12354804575443, 75.12205258011818, 76.25689968466759, 92.76148125529289, 87.08544462919235, 69.92811128497124, 4.2728441208601, 0.1783060556044802, 0.13077445066301152, 0.15260758926160634, 0.06011378740367945, 0.0706849574635271, 0.06243943702429533, 0.015813302343303803, 0.0863490231859032, 0.06693156785331666, 0.11587150933337398, 0.047698495400254615, 0.12638869928196073, 0.10371688185841776, 0.08810412080492824, 0.02726382463151822, 0.08753323112614453, 0.07664928663871251, 0.010568757152213948, 0.05742234432545956, 0.06438321084715426, 0.05401626127422787, 0.028765883289452177, 0.06548023869981989, 0.0013387185640567623, 0.018883455959439743, 0.03751729796931613, 0.06529306905576959, 0.09781983579159714, 0.09113091815379448, 0.07542783772805706, 0.08609594340668991, 0.06588754418771714, 0.05205400426348206, 0.16066232579760253, 0.15279602055670694, 0.25824106007348746, 0.19545216055121273, 0.20122986927162856, 0.09974343061912805, 0.16625221178401262, 0.15594191034324467, 0.13217513565905392, 0.1473585717030801, 0.17431808053515851, 0.12053716171067208, 0.08594418904976919, 0.1563292372156866, 0.16542320314329118, 0.1891677876119502, 0.11487118332297541, 0.13954837282653898, 0.12706666602753103, 0.18447754788212478, 0.17958133248612285, 0.16076788888312876, 0.1945809682365507, 0.2011591722839512, 0.1645309932064265, 0.27914041362237185, 0.13823401444824412, 0.2019162371288985, 0.14250120031647384, 0.1654554420383647, 0.28160538291558623, 0.3990715672262013, 46.77988640964031, 122.48175367712975, 104.69439134001732, 101.05361670255661, 83.02597805857658, 73.37858453392982, 49.39714036881924, 96.97667106986046, 108.54001298546791, 114.72184807062149, 114.30292055010796, 114.59162905812263, 72.71685004234314, 5.153510989621282, 0.2226181051810272, 0.12291112143429928, 0.17385799350449815, 0.1855678964057006, 0.15784672141307965, 0.1275771894142963, 1.3055586442351341, 2.26880363188684, 3.154121213592589, 6.211995491757989, 28.50871503353119, 60.065957084298134, 88.86770099401474, 100.52472308278084, 107.96585619449615, 107.3658911883831, 99.5747284591198, 97.2576279938221, 92.49677985906601, 89.886145144701, 90.7557512819767, 88.32328140735626, 95.37784606218338, 94.46774169802666, 99.7346542775631, 100.43289721012115, 91.15451708436012, 79.85032886266708, 63.21330539882183, 43.903110176324844, 27.76829246431589, 10.997403133660555, 6.059333933517337, 4.266288997605443, 5.163923855870962, 14.8388896510005, 12.849625144153833, 8.560405801981688, 1.7961445008404553, 5.024764398112893, 6.8634040374308825, 23.225172646343708, 43.047479689121246, 75.83849653601646, 84.65040609240532, 100.58972239494324, 110.7138079404831, 119.45068672299385, 108.48101735115051, 99.70667257905006, 92.73343876004219, 98.40496882796288, 107.28088214993477, 113.49434673786163, 107.06298664212227, 106.53567373752594, 108.10719341039658, 104.92937073111534, 111.27769008278847, 107.2032219171524, 104.38585549592972, 104.61920857429504, 113.4499803185463, 110.69350942969322, 105.6601171195507, 96.61189824342728, 83.37541490793228, 61.34631358087063, 41.488947719335556, 8.958789724856615, 3.411651919595897, 6.799893295392394, 3.5229505598545074, 0.6992328388150781, 0.5585715116467327, 0.31608149700332433, 0.16474180767545477, 0.258466643281281, 0.32773802464362234, 0.3028468962293118, 0.1593233726453036, 0.8761707600206137, 16.840515844523907, 91.1801353096962, 100.88555932044983, 72.03094884753227, 113.06914195418358, 119.74027678370476, 70.39308473467827, 39.51858624815941, 27.89290677756071, 58.61394479870796, 70.74669376015663, 91.6906227171421, 100.65352857112885, 77.04477220773697, 4.3525652680546045, 0.28181365923956037, 0.16288309881929308, 0.3334042034111917, 0.20627639925805852, 0.16862656484590843, 0.2389730213326402, 0.18341090355534106, 0.20491975330514833, 0.1403259061044082, 0.1800107688177377, 0.14884167962009087, 0.24942930322140455, 0.2437213118537329, 0.16211481270147488, 0.07360521209193394, 0.12668471230426803, 0.1750709893531166, 0.12879546935437247, 0.1752038041013293, 0.14806303312070668, 0.10456417701789178, 0.09400351947988383, 0.1618934894213453, 0.09201942477375269, 0.17837100836914033, 0.0585147894162219, 0.15909934794763103, 0.13101061689667404, 0.18920048663858324, 0.20288432424422354, 0.13531456876080483, 0.12669743271544576, 0.12237307179020718], [0.06317979612504132, 0.04819380847038701, 0.05430381752375979, 0.026164061964664143, 0.023654456199437845, 0.011673463450279087, 0.05591769557213411, 0.07322307283175178, 0.06665954846539535, 0.07697793189436197, 0.029055354279989842, 0.036828009760938585, 0.016361283778678626, 0.05463678578962572, 0.05131920755957253, 0.05550169953494333, 0.07032964684185572, 0.023019478358037304, 0.023759919095027726, 0.06670109389233403, 0.08521417548763566, 0.14112273522187024, 0.06203034667123575, 0.061037724153720774, 0.030354641494341195, 0.04632479489373509, 0.09586636209860444, 0.04384417741675861, 0.03681469192088116, 0.025261701302952133, 0.1344634292763658, 41.80989369750023, 94.2540791630745, 99.91262152791023, 81.75786450505257, 60.866950303316116, 36.119729429483414, 39.77544866502285, 77.82206609845161, 75.5298162996769, 72.59209513664246, 94.35722082853317, 104.26977932453156, 40.34406915307045, 2.154101086780429, 0.09310558016295545, 0.41338703187648207, 0.056384699419140816, 0.10326933712349273, 0.06804956879932433, 0.041960320886573754, 0.2825697889784351, 0.26773010089527816, 2.381126079708338, 10.767570566385984, 30.189858824014664, 59.230134934186935, 78.69392171502113, 80.3946116566658, 79.19647514820099, 78.19220423698425, 77.76030421257019, 81.3628377020359, 78.6246970295906, 79.3001563847065, 81.56113386154175, 84.7821906208992, 87.68049269914627, 89.09354567527771, 89.2517463862896, 87.55965158343315, 85.90961292386055, 83.26421767473221, 87.75636702775955, 82.47205898165703, 83.9703717827797, 74.50763314962387, 60.8014190196991, 32.01772794127464, 13.468344043940306, 3.7733856216073036, 1.8015479296445847, 1.3288678997196257, 1.4830327522940934, 11.796817537397146, 19.101879000663757, 21.933418661355972, 27.473376989364624, 52.68134593963623, 71.856469810009, 87.23707169294357, 102.7792789041996, 111.92910432815552, 116.72876358032227, 115.99105596542358, 121.21828347444534, 122.94624835252762, 111.08110383152962, 101.94342255592346, 98.52334767580032, 98.25705036520958, 90.47993168234825, 91.1502993106842, 91.65173560380936, 92.89116069674492, 91.24233797192574, 90.22423580288887, 87.5200805068016, 82.50474482774734, 80.98315447568893, 85.90615510940552, 81.72673657536507, 79.3434664607048, 67.29176715016365, 52.76240698993206, 24.027041718363762, 5.374950282275677, 1.2459502927958965, 0.5929103877861053, 2.9901861352846026, 0.7596710894722492, 0.19487243931507692, 0.12796245311619714, 0.04655566590372473, 0.05796942590677645, 0.255933782318607, 0.10409087975858711, 0.1806040565134026, 0.2222825653734617, 3.900486188940704, 60.30176103115082, 85.6979338824749, 62.24345684051514, 101.80414482951164, 157.57812201976776, 106.80169746279716, 31.71725906431675, 18.761768750846386, 25.227782987058163, 36.87464252114296, 52.49044418334961, 74.96854841709137, 54.759640619158745, 2.4711233004927635, 0.25184347992762923, 0.10988131631165743, 0.2275285846553743, 0.0708177722117398, 0.029421774852380622, 0.0422672583226813, 0.16926371346926317, 0.21930166985839605, 0.13634579780045897, 0.05730119242798537, 0.18986954761203378, 0.18097183521604165, 0.01267905778149725, 0.18931643979158252, 0.12951652519404888, 0.06640393054112792, 0.0023808213427400915, 0.035393575599300675, 0.01012027081742417, 0.025190277010551654, 0.008642816210340243, 0.015368062904599356, 0.01669334105827147, 0.06597482817596756, 0.058432685618754476, 0.03183992761478294, 0.046327856252901256, 0.057204642725992016, 0.030804583366261795, 0.048772119625937194, 0.047558203514199704, 0.045073648943798617, 0.05877690484339837, 0.03504906693706289, 0.04909122086246498, 0.028167877389932983, 0.03037287235201802, 0.035686070841620676, 0.056600590178277344, 0.019969214299635496, 0.006068126413083519, 0.07208095208625309, 0.05304725760652218, 0.034550852069514804, 0.03895594381901901, 0.05839939658471849, 0.06945877365069464, 0.0324016888771439, 0.08651442563859746, 0.051839508741977625, 0.09964906654204242, 0.1387079499545507, 0.08628713549114764, 0.1702587108593434, 0.04731886830995791, 0.07345916485064663, 0.07703547802520916, 0.08265101263532415, 0.021868976909900084, 0.05248580804618541, 0.03232178925827611, 0.008659799332235707, 0.6519469292834401, 66.70687213540077, 108.45791459083557, 115.2090123295784, 105.9723311662674, 88.04448276758194, 55.97546897828579, 25.709429942071438, 23.547891229391098, 57.85502292215824, 84.0056186914444, 106.71972066164017, 112.27172434329987, 34.532900378108025, 0.9461401461157948, 0.04823644114367198, 0.32836552534718066, 0.06504927354399115, 0.006697789085592376, 0.26032281399238855, 0.13266971771372482, 0.032894278265303, 0.936438791686669, 4.221629519015551, 15.78982187435031, 36.89458005130291, 67.19978928565979, 84.73479196429253, 86.4848792552948, 86.08830213546753, 84.34209823608398, 83.91698464751244, 84.25212666392326, 81.6946966946125, 84.0644471347332, 88.626619130373, 91.98135271668434, 96.31629690527916, 96.47131338715553, 96.75123676657677, 94.40479427576065, 95.49155876040459, 89.4542147219181, 91.28041952848434, 91.03294640779495, 89.43681925535202, 83.17353934049606, 70.49788311123848, 41.557522639632225, 18.97910188883543, 7.492532953619957, 3.5373451374471188, 1.3007336156442761, 2.393482541665435, 15.851655956357718, 29.290196299552917, 30.658424980938435, 36.69364683330059, 62.632761150598526, 83.14670518040657, 97.02702596783638, 108.59878823161125, 111.92388340830803, 119.494718760252, 118.17075580358505, 124.95203152298927, 126.98350131511688, 118.495022803545, 112.933838814497, 108.78107205033302, 106.8575468659401, 101.62524282932281, 99.13574561476707, 96.30634903907776, 97.61464163661003, 97.0282419025898, 94.04320567846298, 92.43429601192474, 88.12271296977997, 87.71534442901611, 90.37872031331062, 86.96698978543282, 84.83057722449303, 76.19849681854248, 57.53498889505863, 31.51865892112255, 10.166268032044172, 0.967714557191357, 1.0044136410579085, 1.4797733584418893, 1.587043502368033, 0.7848193868994713, 0.6039787782356143, 0.40151222376152873, 0.015235640566970687, 0.22279969387454912, 0.0591563055786537, 0.09159544322756119, 0.2078888041432947, 1.4319986407645047, 55.92538386583328, 95.21854341030121, 65.8546082675457, 98.17871376872063, 137.09951609373093, 60.283920988440514, 11.431673280894756, 23.155169002711773, 45.20361319184303, 64.78423610329628, 73.27785953879356, 82.47154220938683, 72.85430386662483, 4.70062374137342, 0.38490141509100795, 0.12908345233881846, 0.20385371753945947, 0.16033437073929235, 0.07032203982817009, 0.12558075279230252, 0.10984627951984294, 0.3386126254918054, 0.11012954986654222, 0.047014955125632696, 0.13627934589749202, 0.1811861080932431, 0.07279485362232663, 0.207336854073219, 0.29156458913348615, 0.03154027435812168, 0.045705799202551134, 0.01242799757164903, 0.05204794091696385, 0.025530831881042104, 0.037379384666564874, 0.03681984242575709, 0.04177846873062663, 0.03740221312909853, 0.0761945876001846, 0.08674299970152788, 0.13120215036906302, 0.10276956745656207, 0.023159738702815957, 0.015276615467882948, 0.034628291468834504, 0.04964576473867055, 0.11710360806318931, 0.17639327386859804, 0.14245603320887312, 0.1882547084824182, 0.08731316949706525, 0.11382409458747134, 0.14492719201371074, 0.1570364148938097, 0.1232398186402861, 0.23547386925201863, 0.138687125290744, 0.1873249904019758, 0.08561484617530368, 0.1689227856695652, 0.12060129069141112, 0.10512011984246783, 0.1576610657502897, 0.19658092263853177, 0.11058982985559851, 0.3455552982632071, 0.13002724153921008, 0.2607827971223742, 0.13574507378507406, 0.23824132309528068, 0.12138736608903855, 0.17161523806862533, 0.2231317455880344, 0.17390017717843875, 0.1329067745245993, 0.09771742683369666, 0.5076338793151081, 68.01036939024925, 127.89198696613312, 125.38600623607635, 109.70664158463478, 74.70596730709076, 46.502326503396034, 53.17153863608837, 109.30897012352943, 109.9612507224083, 102.68955811858177, 113.45785349607468, 121.22964486479759, 51.46571896970272, 3.22935551404953, 0.2109153862693347, 0.6417837808839977, 0.27203369652852416, 0.20328664249973372, 0.20543204300338402, 0.1862901248387061, 1.3918078411370516, 1.6638310882262886, 3.438274716027081, 14.062586557120085, 33.42422626912594, 68.2334554195404, 88.47396612167358, 91.54974907636642, 92.98612520098686, 93.15352901816368, 90.27405112981796, 94.20772165060043, 87.83523559570312, 90.88973969221115, 91.90624594688416, 96.15593791007996, 102.97099381685257, 103.5579939186573, 105.56871682405472, 106.86258539557457, 103.23425129055977, 94.505595266819, 97.81267940998077, 98.211620002985, 96.00681111216545, 87.76974231004715, 72.22239017486572, 41.571190506219864, 17.802694514393806, 6.323817316442728, 3.4218182740733027, 3.665986522100866, 3.0825883895158768, 15.239903032779694, 28.738372810184956, 25.659975595772266, 39.07665476202965, 66.11163407564163, 92.30461657047272, 101.39980092644691, 115.06163343787193, 119.50038805603981, 121.95637106895447, 120.36866426467896, 127.74365812540054, 133.85552376508713, 123.54214757680893, 114.10441920161247, 110.22385463118553, 111.94111168384552, 104.23278450965881, 105.30536815524101, 105.72292014956474, 104.2247973382473, 105.23645505309105, 99.87976089119911, 100.05719617009163, 92.91332870721817, 93.24480772018433, 100.5032466351986, 99.53620612621307, 100.78824654221535, 92.64016896486282, 66.41912877559662, 33.033314645290375, 9.273290298879147, 2.543203770183027, 5.708483560010791, 9.788833335042, 2.4129895074293017, 0.5357314716093242, 0.30566432629711926, 0.3430495999054983, 0.09058844530954957, 0.4205743462080136, 0.19544328446500003, 0.206650456530042, 0.34393913811072707, 5.936812832951546, 78.04956749081612, 105.40767386555672, 77.56632462143898, 113.18950429558754, 176.13862127065659, 135.5002275109291, 41.590212285518646, 24.874837026000023, 34.16443035006523, 53.26714530587196, 69.43137153983116, 93.99718254804611, 81.67277187108994, 4.907053364440799, 0.5722381907980889, 0.3203462634701282, 0.31286793819162995, 0.24407926452113315, 0.15859309933148324, 0.20251185516826808, 0.18067770724883303, 0.346387216122821, 0.1892060972750187, 0.12876648106612265, 0.24264301580842584, 0.34345460473559797, 0.12565331999212503, 0.27573544008191675, 0.349525788333267, 0.10020083107519895, 0.11511304925079457, 0.06856726875412278, 0.13457141176331788, 0.12628509546630085, 0.1765439595328644, 0.12925214250572026, 0.09650539577705786, 0.17843624314991757, 0.09477608036831953, 0.1305065501946956, 0.22043154516723007, 0.12390411502565257, 0.1575989628327079, 0.13291646697325632, 0.10050597251392901, 0.1469494850607589], [0.016929421944951173, 0.01747506747051375, 0.05140347471751738, 0.061053023528074846, 0.06673665760899894, 0.07705180527409539, 0.04894606790912803, 0.0115042398647347, 0.0741608432144858, 0.06490171974292025, 0.06734760099789128, 0.012297515022510197, 0.11733397812349722, 0.045003964987699874, 0.026140639783989172, 0.10723069877712987, 0.07382840558420867, 0.05201606567425188, 0.07423336588544771, 0.11481144043500535, 0.08558518253266811, 0.034915472933789715, 0.16053811996243894, 0.06182481629366521, 0.10030324003309943, 0.08541008763131686, 0.08415388394496404, 0.05328297113010194, 0.14131239848211408, 0.6900161365047097, 52.70708955824375, 106.83769673109055, 92.12897479534149, 79.27133873105049, 63.158538937568665, 38.36764320731163, 49.50381204485893, 93.57533678412437, 95.6443789601326, 77.46065989136696, 103.68621423840523, 101.63196846842766, 21.533909998834133, 0.3726723650470376, 0.08137240351061337, 0.3251695109065622, 0.03485479865048546, 0.058885321486741304, 0.02307965169165982, 0.04518363522947766, 0.14235094509785995, 1.183274199720472, 4.876150572672486, 18.00159864127636, 36.57281331717968, 60.570102632045746, 76.64289057254791, 83.66999790072441, 81.56414330005646, 82.7061340212822, 82.23763436079025, 85.37425205111504, 85.08684307336807, 91.5054814517498, 99.89932224154472, 104.73753422498703, 104.09998923540115, 101.26484736800194, 102.72216796875, 102.01604425907135, 100.27338936924934, 99.88588616251945, 98.41664180159569, 94.91999343037605, 95.27880817651749, 98.21866482496262, 91.8893064558506, 84.20488759875298, 80.73019444942474, 71.06457710266113, 57.3112379014492, 26.618922539055347, 9.273182954639196, 10.503731723874807, 17.142943516373634, 54.12180684506893, 60.366748943924904, 59.15909394621849, 70.39498463273048, 87.595886439085, 103.86871844530106, 112.64453753829002, 110.78288063406944, 111.99252292513847, 102.57400631904602, 98.92486453056335, 97.09828734397888, 100.27217343449593, 100.83350211381912, 101.12113147974014, 92.4941124022007, 93.96116808056831, 88.11818361282349, 88.82330417633057, 88.30022424459457, 88.25039371848106, 85.26091933250427, 85.55446118116379, 87.12566927075386, 88.91073748469353, 87.76265949010849, 89.62790340185165, 83.5985617339611, 86.64959281682968, 65.67954406142235, 42.929363027215004, 28.308498077094555, 7.611817577853799, 0.4542774095898494, 1.2207259400747716, 2.200833591632545, 0.15651052905013785, 0.3767064126441255, 0.05058493035903666, 0.17335443146293983, 0.031052944941620808, 0.026164102782786358, 0.23671140050282702, 0.026331577682867646, 0.2105059879249893, 0.6410711409989744, 39.547764882445335, 97.75467172265053, 71.34777590632439, 91.11769706010818, 147.11141645908356, 157.9209092259407, 63.224662989377975, 23.745480626821518, 22.30300012975931, 31.999466121196747, 60.41989669203758, 70.10373026132584, 50.73587313294411, 5.606497507542372, 0.3076426842017099, 0.052656041880254634, 0.0870857086556498, 0.3041606757324189, 0.08802416181424633, 0.1634026170358993, 0.1949553965823725, 0.1474098689504899, 0.006061516196496086, 0.07677759655052796, 0.01191651774206548, 0.058073515829164535, 0.0943927610933315, 0.08685008418979123, 0.027256690736976452, 0.04081773629877716, 0.07259345700731501, 0.015047405013319803, 0.04734109934361186, 0.052566832018783316, 0.08592606580350548, 0.05975555643090047, 0.02424001257168129, 0.13973040680866688, 0.0360874948091805, 0.05048324499512091, 0.07446962859830819, 0.07661170428036712, 0.032794604121590964, 0.07350780520937406, 0.04903698471025564, 0.03749929346668068, 0.026223580352962017, 0.025020802022481803, 0.05390109850850422, 0.04780982497322839, 0.07404820746160112, 0.08677828140207566, 0.02673375121958088, 0.03202658517693635, 0.05308355233864859, 0.011486586026876466, 0.005530897769858711, 0.011364002712070942, 0.011682993554131826, 0.0786985048034694, 0.04451334971236065, 0.01611957370187156, 0.13710290717426687, 0.12295703811105341, 0.18390630197245628, 0.0489757315517636, 0.0867162823851686, 0.14816524169873446, 0.015035141950647812, 0.010726717719080625, 0.07351562744588591, 0.07093171414453536, 0.03826911583018955, 0.1422023819759488, 3.3483979012817144, 81.33294090628624, 118.87772306799889, 106.66216894984245, 101.10750541090965, 100.63335165381432, 57.50679440796375, 23.344959318637848, 43.76425802707672, 89.68486234545708, 90.52986860275269, 117.47844815254211, 104.49226498603821, 15.849906150251627, 0.12603570416104048, 0.13309787755133584, 0.2069622476119548, 0.13965173915494233, 0.17594160279259086, 0.17961349716642871, 0.18823734222678468, 0.4906774376286194, 1.2888438161462545, 7.150996830314398, 22.836508601903915, 44.86334905028343, 69.35981377959251, 84.31208744645119, 87.94975385069847, 85.8426833152771, 87.71613478660583, 89.1094820201397, 90.8475923538208, 91.52218535542488, 98.18733170628548, 105.63029631972313, 110.020512342453, 108.89331802725792, 107.20085084438324, 106.75440520048141, 105.03295317292213, 100.94225987792015, 102.1336555480957, 98.62047806382179, 94.43730533123016, 94.26246151328087, 96.5433195233345, 94.30318772792816, 89.54746171832085, 90.87878867983818, 84.3835312128067, 71.07387140393257, 37.84828707575798, 17.178925685584545, 14.329166002571583, 26.96447979658842, 68.11191514134407, 72.20312520861626, 69.56019222736359, 78.25263619422913, 95.41600361466408, 106.1915186047554, 111.83391183614731, 113.20234000682831, 110.08896186947823, 103.81998226046562, 101.51843056082726, 100.17866045236588, 101.9444864988327, 103.703852891922, 105.84741666913033, 99.66507241129875, 98.65584656596184, 94.06125470995903, 96.36774614453316, 95.32914027571678, 93.63498598337173, 90.26392087340355, 90.10719448328018, 91.96470960974693, 94.1267403960228, 93.55873927474022, 95.22621139883995, 92.42059394717216, 90.57710006833076, 73.41861918568611, 48.617209419608116, 30.352643989026546, 10.233133044093847, 0.8550205011852086, 1.096961118746549, 0.8366851788014174, 1.5171090862713754, 0.9733443113509566, 0.2581823116634041, 0.3952845063759014, 0.06929337119800039, 0.10041068817372434, 0.20190733135677874, 0.043235805569565855, 0.08538255395251326, 0.12794994050636888, 37.086291164159775, 108.28372433781624, 79.43498075008392, 94.79083076119423, 139.2401084303856, 121.4800438284874, 26.949200816452503, 28.292160853743553, 40.45289531350136, 52.993727177381516, 81.40582099556923, 78.25524285435677, 69.52569767832756, 11.720298193395138, 0.2748216188047081, 0.0525295205443399, 0.01073130697477609, 0.3140698908828199, 0.09569636575179175, 0.2376502173137851, 0.17753278225427493, 0.19257434934843332, 0.12755056115565822, 0.05925400560954586, 0.11143339201225899, 0.12031141523038968, 0.07191641794634052, 0.03182881395332515, 0.04051130723382812, 0.017320129300060216, 0.12027650460368022, 0.022121514921309426, 0.05615317160845734, 0.009495352787780575, 0.06013943231664598, 0.07785857174894772, 0.04162058423389681, 0.06402237122529186, 0.061847707838751376, 0.04629312745237257, 0.11549773407750763, 0.045165567644289695, 0.04557115134957712, 0.09759767388459295, 0.006820119606345543, 0.08260019778390415, 0.1007876472431235, 0.13449451042106375, 0.11396699512260966, 0.19473005086183548, 0.18686396826524287, 0.3930679784389213, 0.09457584892516024, 0.32948222011327744, 0.1694975048303604, 0.08540685186744668, 0.06881056702695787, 0.1588633153005503, 0.1640853038406931, 0.12706497393082827, 0.20041785581270233, 0.16247778228716925, 0.36486173572484404, 0.23213546635815874, 0.23809368023648858, 0.1368071761680767, 0.1739202596945688, 0.23510671395342797, 0.1402503703138791, 0.11458867738838308, 0.1883634034311399, 0.34675549948588014, 0.1118943547771778, 0.30438631831202656, 2.677376470528543, 88.46567496657372, 140.1131647825241, 114.78614822030067, 104.33040887117386, 76.08316540718079, 53.93735334277153, 60.906635373830795, 133.08524429798126, 133.81412118673325, 97.29675829410553, 123.38307291269302, 123.30074653029442, 29.68707550317049, 1.2376161525025964, 0.2410484669962898, 0.44690443959552795, 0.4282417707145214, 0.175009198137559, 0.4182300204411149, 0.47419460490345955, 1.3377223745919764, 2.234675525687635, 6.783059723675251, 21.673448011279106, 43.265492990612984, 72.16362252831459, 89.13309395313263, 96.57725930213928, 95.32933786511421, 96.612688601017, 96.44055023789406, 96.39373674988747, 96.50068581104279, 103.08596044778824, 109.86558705568314, 116.05359300971031, 112.90920093655586, 110.31017079949379, 111.65081486105919, 111.25407055020332, 106.25628232955933, 107.85921111702919, 103.6748756468296, 105.33961951732635, 105.13560846447945, 108.43876361846924, 107.25955009460449, 101.42571553587914, 99.44905400276184, 88.86662945151329, 69.0822234749794, 36.29903040826321, 15.070410277694464, 12.976462338119745, 25.732855685055256, 61.9353199750185, 70.14238938689232, 73.2979528605938, 85.41444629430771, 100.83538681268692, 111.51180312037468, 116.44920498132706, 118.78371611237526, 115.11956512928009, 109.42313879728317, 105.10966345667839, 105.71852758526802, 107.07209095358849, 110.82901015877724, 113.15367221832275, 106.1975146830082, 107.66772419214249, 99.51431930065155, 100.14616459608078, 100.68337216973305, 99.45854589343071, 94.14120241999626, 95.58284506201744, 97.689049243927, 99.97487738728523, 98.0991992354393, 101.33507519960403, 101.53958782553673, 104.58562597632408, 96.2301479279995, 63.39568421244621, 32.12177015841007, 9.291966296732426, 1.711258718278259, 5.270418366417289, 8.16735489293933, 4.16620759293437, 1.0458347434177995, 0.1426544538117014, 0.34279073879588395, 0.2954396983841434, 0.21931545896222815, 0.3798772831214592, 0.18797539378283545, 0.247811540029943, 1.576238782145083, 52.73578181862831, 119.54146385192871, 85.98342016339302, 99.9207454919815, 150.7462254166603, 182.59804666042328, 76.92485064268112, 34.56098087131977, 29.910885393619537, 46.58512786030769, 79.28799703717232, 89.29671317338943, 83.77354994416237, 12.366416472941637, 0.5505668255500495, 0.18597529095131904, 0.27424538566265255, 0.3684586880262941, 0.17814800783526152, 0.2631500404095277, 0.1735176148940809, 0.18770718161249533, 0.17652200680458918, 0.15823964407900348, 0.17960671393666416, 0.1819814826012589, 0.2307574317092076, 0.13251071999548003, 0.13438495458103716, 0.14620119240134954, 0.21504193515283987, 0.13736795779550448, 0.19079001853242517, 0.12482867517974228, 0.1578642806271091, 0.21260988753056154, 0.15939411416184157, 0.2644864999456331, 0.16058742825407535, 0.17528702854178846, 0.18961650494020432, 0.21548245917074382, 0.20023859746288508, 0.17437708127545193, 0.10788119863718748], [0.03161532404192258, 0.01552875735796988, 0.011101681338914204, 0.03415932093048468, 0.04614571837009862, 0.06942355132196099, 0.03889726220222656, 0.07568121436634101, 0.0443472830374958, 0.03373028535861522, 0.024451997778669465, 0.024742114437685814, 0.028177080021123402, 0.05906966354814358, 0.1226376325939782, 0.06804039585404098, 0.026302184924134053, 0.07674621112528257, 0.03204607397492509, 0.02808722263580421, 0.015181293092609849, 0.10543136173509993, 0.015040211746963905, 0.04446588194696233, 0.05713650614779908, 0.04084773019712884, 0.15140560688450933, 0.16151033341884613, 2.403135923668742, 61.62128962576389, 101.56214341521263, 78.83474215865135, 95.06380811333656, 64.50007975101471, 28.428824320435524, 62.36859932541847, 92.07585364580154, 80.4155333340168, 88.14908355474472, 111.91484749317169, 72.72528558969498, 4.8134824354201555, 0.2903933316702023, 0.08705382599146105, 0.041635683228378184, 0.1880936327506788, 0.19566733884857967, 0.24916848284192383, 0.08326565191964619, 1.0090053384192288, 2.723536631092429, 13.674749918282032, 34.438274055719376, 54.435594007372856, 74.02896523475647, 83.62104132771492, 92.60203421115875, 93.3659528195858, 94.98111695051193, 95.44700995087624, 94.95738342404366, 100.1765401661396, 100.94800516963005, 104.31755796074867, 106.16821825504303, 109.68686744570732, 110.92016726732254, 109.6665309369564, 107.5843034684658, 102.86213725805283, 97.50032857060432, 92.80622765421867, 96.84505373239517, 91.55123859643936, 79.49278324842453, 80.90034931898117, 80.2486614882946, 76.78567931056023, 83.01222279667854, 91.86904594302177, 94.04100939631462, 82.81911715865135, 63.75057756900787, 46.1814983189106, 53.259059339761734, 79.50559616088867, 91.37697234749794, 83.58481407165527, 87.90585100650787, 95.21697789430618, 109.21716704964638, 109.71563950181007, 103.73865142464638, 98.83715763688087, 98.93500998616219, 102.70257622003555, 102.65186414122581, 97.78593644499779, 88.12066867947578, 87.20358788967133, 88.90867799520493, 83.20508524775505, 81.50640159845352, 85.33519014716148, 86.51090785861015, 81.58314228057861, 83.92627134919167, 87.68083468079567, 88.19478750228882, 91.76997765898705, 90.41250810027122, 91.73874333500862, 93.56826156377792, 83.29663753509521, 79.43728342652321, 67.094496935606, 35.17750158905983, 17.41223506629467, 5.525116799399257, 0.24442376947263256, 1.4802995114587247, 1.5508743119426072, 2.0961974188685417, 0.9548209584318101, 0.01455444826206076, 0.12084542759112082, 0.15476357279112563, 0.047935860202414915, 0.0789491503383033, 0.1241398582351394, 0.029143731080694124, 0.18522858648793772, 22.766491658985615, 93.42526763677597, 78.40248495340347, 56.18653245270252, 106.19953617453575, 148.21586519479752, 56.40666984021664, 33.156257048249245, 32.01569125056267, 42.52978026866913, 58.963583037257195, 83.68881449103355, 67.66699701547623, 10.389161221683025, 1.5245868475176394, 0.22912792774150148, 0.07558008190244436, 0.23060419305693358, 0.04528350975306239, 0.11516302547533996, 0.05709146520530339, 0.05827270455483813, 0.09760352200828493, 0.0852165132528171, 0.10314638551790267, 0.026766693299578037, 0.0656562093354296, 0.07154690261813812, 0.035589810577221215, 0.029708590809605084, 0.11276870121946558, 0.034438323928043246, 0.027162625374330673, 0.03313689747301396, 0.06374764299835078, 0.05406115378718823, 0.022556799376616254, 0.14418041333556175, 0.0873658768250607, 0.02392780217633117, 0.12578266148921102, 0.06690747773973271, 0.06406336004147306, 0.03622229480242822, 0.03931503197236452, 0.045931768327136524, 0.028683003947662655, 0.0502865164889954, 0.06781729884096421, 0.05067208818218205, 0.047471747020608746, 0.010311373844160698, 0.062463438080158085, 0.11979709204751998, 0.030311203590827063, 0.06615983074880205, 0.03589003528759349, 0.05519520738744177, 0.02593223543954082, 0.0290906860755058, 0.05404932766396087, 0.021240301757643465, 0.08705666841706261, 0.06847887154435739, 0.15062678226968274, 0.08017795393243432, 0.07903695382992737, 0.030865094377077185, 0.05324734062014613, 0.07012783462414518, 0.1876007576356642, 0.1439174555707723, 8.12279848381877, 90.72463095188141, 111.34996980428696, 102.91447564959526, 124.91506710648537, 105.18360748887062, 34.68113422393799, 24.282312020659447, 55.50558239221573, 82.32447490096092, 103.65116491913795, 123.80534425377846, 76.06790542602539, 3.264621184207499, 0.22966548014665022, 0.10217141869361512, 0.1418735066545196, 0.09544627682771534, 0.4441429674625397, 0.2606015943456441, 0.3769826696952805, 0.597075023688376, 4.270862527191639, 20.434218607842922, 45.611202120780945, 66.70370310544968, 83.63684087991714, 92.30832517147064, 99.8751175403595, 98.65977555513382, 101.21100425720215, 100.27990981936455, 100.40634423494339, 105.3191614151001, 106.30455493927002, 106.25388845801353, 109.25749808549881, 108.91447529196739, 109.96816635131836, 107.9639258980751, 106.49057015776634, 103.04782569408417, 96.7319718003273, 92.10612282156944, 98.35878610610962, 94.85977426171303, 83.91109496355057, 86.21380940079689, 85.09104564785957, 82.9704250395298, 88.05725768208504, 97.43078470230103, 101.20899796485901, 95.7535395026207, 78.20902973413467, 62.321215867996216, 65.55760860443115, 87.74374410510063, 97.84161105751991, 87.74536281824112, 93.46841052174568, 96.58364295959473, 108.23579370975494, 109.64087471365929, 103.67834106087685, 101.28347396850586, 102.65203133225441, 105.97314432263374, 104.98208910226822, 101.76734760403633, 96.46157830953598, 93.35786685347557, 98.46689030528069, 92.91046366095543, 90.14140024781227, 90.8655957877636, 91.08234375715256, 90.15902370214462, 92.24356904625893, 93.13231855630875, 93.92335250973701, 97.43342936038971, 96.48325234651566, 95.4035858809948, 95.77038019895554, 89.48133766651154, 88.21854382753372, 77.38318204879761, 54.57994446158409, 24.50109288096428, 6.836355663836002, 1.324459898751229, 0.899267642525956, 0.14942818408599123, 1.9212521938607097, 1.945821912959218, 0.1875597910839133, 0.5648807168472558, 0.2815615071449429, 0.1470467954641208, 0.03817221360804979, 0.12216389004606754, 0.0565087308496004, 0.32240055792499334, 19.492110460996628, 98.6859181523323, 91.33737087249756, 64.62299555540085, 109.37786802649498, 133.7145209312439, 31.00797962397337, 23.862077370285988, 48.2873947173357, 67.21049711108208, 82.67957344651222, 93.70250836014748, 87.740119099617, 20.176983810961246, 0.8352569304406643, 0.24305265164002776, 0.10367612310801633, 0.15975283866282552, 0.0971728833974339, 0.04302544752135873, 0.05260027319309302, 0.09729985002195463, 0.05863482438144274, 0.16313691332470626, 0.07582084203022532, 0.10577692053630017, 0.04141884623095393, 0.07385525648714975, 0.06598590101930313, 0.09099381379201077, 0.06227595673408359, 0.07733348742476664, 0.03578681738872547, 0.017210135592904408, 0.07121223112335429, 0.061642956716241315, 0.023852129088481888, 0.09848260335274972, 0.03926380893972237, 0.026554999385552946, 0.047278747806558385, 0.002954476449303911, 0.05040098534664139, 0.029385895722953137, 0.07885091967182234, 0.13575253979070112, 0.11402555057429709, 0.18638134963111952, 0.16449918475700542, 0.1270237995777279, 0.15271634358214214, 0.1566403900505975, 0.1595579952117987, 0.17660212906775996, 0.11976623354712501, 0.18815570598235354, 0.12534442328615114, 0.16201739839743823, 0.15726064739283174, 0.14690832555061206, 0.18070737831294537, 0.210933999333065, 0.12405510497046635, 0.13886644301237538, 0.25214980880264193, 0.16269978834316134, 0.1861079572699964, 0.12242323355167173, 0.16471762850414962, 0.08788577353698201, 0.3150063328212127, 0.4778709076344967, 7.714669508859515, 101.5119557082653, 130.58754712343216, 101.2481738626957, 120.05237683653831, 82.97218054533005, 35.71211390197277, 83.12790378928185, 140.2937614917755, 108.87560337781906, 112.70041733980179, 132.36269026994705, 96.47905737161636, 8.686018511652946, 0.5831105355173349, 0.30705374549143016, 0.3178089199354872, 0.37103886832483113, 0.4539784725056961, 0.44487433915492147, 0.7753967237658799, 2.643329822458327, 3.9016330149024725, 17.876448556780815, 42.29405611753464, 64.10193711519241, 85.23289203643799, 97.59178206324577, 106.4283598959446, 106.66899338364601, 107.6776796579361, 105.38772493600845, 107.51557275652885, 110.43728157877922, 110.85769861936569, 113.93725857138634, 113.21937829256058, 115.00519126653671, 115.06447568535805, 113.62186029553413, 107.99579858779907, 104.2867948114872, 100.74565842747688, 98.37706312537193, 102.96233788132668, 101.66322559118271, 91.67336404323578, 97.46770352125168, 93.0188338458538, 91.70867934823036, 98.61406400799751, 107.48931616544724, 107.13125377893448, 101.08878761529922, 77.79656946659088, 59.80282500386238, 62.89370454847813, 85.91370150446892, 94.92803379893303, 91.48930951952934, 97.65001013875008, 102.32321977615356, 113.67343112826347, 112.57212862372398, 109.59675908088684, 104.8855970799923, 108.1537789106369, 112.31276214122772, 111.11397206783295, 105.88551342487335, 103.19772765040398, 101.76450535655022, 106.09720006585121, 98.54823634028435, 99.45846229791641, 100.75003579258919, 98.53521063923836, 94.31277841329575, 95.79861268401146, 96.61158666014671, 99.20955285429955, 101.57104253768921, 101.93375587463379, 101.94590002298355, 104.62003692984581, 99.76138964295387, 95.42967528104782, 93.34758460521698, 73.91396820545197, 35.87771661579609, 6.696028718724847, 2.6112671429291368, 3.4427682124078274, 6.644068881869316, 7.39342144690454, 2.568403067998588, 0.13762095593847334, 0.31451333896256983, 0.3681052179308608, 0.16968571348115802, 0.1873133089975454, 0.27424592000897974, 0.194021359202452, 0.6201222713571042, 31.148596778512, 111.84578239917755, 96.52555167675018, 76.56709223985672, 122.09695592522621, 170.58701276779175, 74.73264187574387, 42.51445569097996, 40.9931693226099, 55.646041855216026, 80.162732899189, 101.38303622603416, 99.88979995250702, 23.165179565548897, 1.4354657172225416, 0.42763751407619566, 0.20507043896941468, 0.291868721251376, 0.13232973986305296, 0.2021484699798748, 0.10896702748141252, 0.22135376755613834, 0.10979426981066354, 0.12748847308102995, 0.196260582015384, 0.1408288744278252, 0.09044173755683005, 0.2490194744314067, 0.16768298344686627, 0.268829696578905, 0.18437961407471448, 0.22609747160458937, 0.1662390015553683, 0.1494668796658516, 0.2369398484006524, 0.2877213031752035, 0.09639671567128971, 0.2356596733443439, 0.18585090700071305, 0.18968000309541821, 0.23032210272504017, 0.12446517124772072, 0.20550244313199073, 0.06610980999539606], [0.008579969289712608, 0.06989036963204853, 0.08730170331546105, 0.02605935234896606, 0.058510433009359986, 0.004316900949561386, 0.034706016595009714, 0.03910293729859404, 0.03869430707709398, 0.04890432952379342, 0.02313662822416518, 0.08094561664620414, 0.049557716338313185, 0.05853267888596747, 0.017539317050250247, 0.05626727681374177, 0.06235885462956503, 0.022416735700971913, 0.11073946909164079, 0.0765395155758597, 0.08124821993988007, 0.026510286843404174, 0.07403462615911849, 0.04764219978824258, 0.05902450386201963, 0.20839180215261877, 0.41542808641679585, 8.0909039452672, 92.6801124215126, 92.00488865375519, 77.13352024555206, 66.6296298801899, 49.34786081314087, 30.514824986457825, 72.46242329478264, 101.08029887080193, 79.30713281035423, 107.66307324171066, 118.15670415759087, 63.375089317560196, 2.434945204295218, 0.20011661807075143, 0.16391303652198985, 0.18720954190939665, 0.1002658432116732, 0.11269264592556283, 0.26894095935858786, 0.8688909444026649, 1.0413674893788993, 8.25881028547883, 40.17267554998398, 75.91255456209183, 91.5770012140274, 102.92530506849289, 106.82973995804787, 104.2633804678917, 108.56155022978783, 103.75534772872925, 106.67391791939735, 105.38406193256378, 100.7906936109066, 103.0981881916523, 104.07817080616951, 105.07006198167801, 109.42767575383186, 105.0499914586544, 100.55411830544472, 101.02100685238838, 99.31379646062851, 98.80358263850212, 101.62573680281639, 95.37506461143494, 86.14978283643723, 84.48348864912987, 80.22564992308617, 78.41551825404167, 77.16848596930504, 71.97714373469353, 74.71015468239784, 79.9643911421299, 84.88122090697289, 90.34865632653236, 87.92566314339638, 86.57985135912895, 95.46384304761887, 93.6915573477745, 109.1814261674881, 97.53059014678001, 94.89667788147926, 98.11071261763573, 105.55362403392792, 102.75830402970314, 100.22397682070732, 96.25121399760246, 89.95701134204865, 86.94121956825256, 85.0821541249752, 83.06502476334572, 77.7014833688736, 67.75611743330956, 68.63732054829597, 74.89941492676735, 77.65875086188316, 71.82820692658424, 73.81850972771645, 75.9238475561142, 76.78318664431572, 80.96078127622604, 88.55378463864326, 91.25651881098747, 86.44558936357498, 87.33807027339935, 74.08751249313354, 78.09849366545677, 89.58080872893333, 71.89537212252617, 66.62977427244186, 45.64583346247673, 19.800268225371838, 1.5988835482858121, 0.873944970080629, 2.03629600815475, 2.5837611313909292, 1.4478973438963294, 0.5801196210086346, 0.13360926182940602, 0.1693657587748021, 0.2911020233295858, 0.06366716450429522, 0.07212352909846231, 0.07464728390914388, 0.07553832125267945, 0.24084608332486823, 11.915101390331984, 84.09185886383057, 92.00169682502747, 61.7831077426672, 37.930913642048836, 73.96891325712204, 77.6568129658699, 27.84926801919937, 31.280943676829338, 47.26133957505226, 53.049774169921875, 70.80098524689674, 73.26405107975006, 37.63625845313072, 6.581991612911224, 0.6310108839534223, 0.09597177675459534, 0.2459476955118589, 0.0612748403364094, 0.044818494861829095, 0.047680190327810124, 0.12386605027131736, 0.11084159603342414, 0.05520512619114015, 0.08434201095951721, 0.02872098149964586, 0.03726707916939631, 0.009503898618277162, 0.043552283314056695, 0.022772441516281106, 0.015922874881653115, 0.041681967268232256, 0.04055313838762231, 0.05001617806556169, 0.09179563014185987, 0.01634884723898722, 0.012592960301844869, 0.08599031352787279, 0.07239491766085848, 0.05467367795063183, 0.03896614092809614, 0.09417293695150875, 0.006971324773985543, 0.040791471692500636, 0.02621122359414585, 0.06227730002137832, 0.03225456181098707, 0.06025245398632251, 0.02749218161625322, 0.04904495166556444, 0.027211132146476302, 0.06402208178769797, 0.010474450591573259, 0.014368043030117406, 0.05752458258939441, 0.018839908589143306, 0.07193351702881046, 0.03975978252128698, 0.0716057994577568, 0.01421671076968778, 0.03972639700805303, 0.13435894972644746, 0.1077059330418706, 0.0560792388569098, 0.06210724059201311, 0.21330495335860178, 0.11871499620610848, 0.09023919061291963, 0.2472955989651382, 0.2925734349992126, 18.815267980098724, 122.34299272298813, 99.90672424435616, 101.10132694244385, 92.5084300339222, 89.24164652824402, 40.49044109880924, 23.563639484345913, 72.03249156475067, 83.96730154752731, 118.72195422649384, 126.96492791175842, 68.97674113512039, 1.6614340106025338, 0.11522420070832595, 0.28899925178848207, 0.11641383374808356, 0.06342694614431821, 0.1352340605808422, 0.5682845029514283, 0.9413281793240458, 1.332341863308102, 12.642607502639294, 49.3459153175354, 86.00300431251526, 97.80024647712708, 108.3294814825058, 108.82096990942955, 107.04960376024246, 106.39974743127823, 105.397277623415, 107.39860743284225, 107.45209336280823, 103.44615831971169, 102.8928168118, 104.87553521990776, 105.8287064731121, 109.23166707158089, 106.2808746099472, 102.91849583387375, 103.79528358578682, 99.53537777066231, 101.70942351222038, 103.529092669487, 96.41870141029358, 90.39222478866577, 92.56753966212273, 87.20225796103477, 86.25698268413544, 83.56858894228935, 80.04056945443153, 82.21133217215538, 84.64363485574722, 91.10765039920807, 95.37082403898239, 96.08698680996895, 93.04110825061798, 96.00512400269508, 100.70495501160622, 113.29719811677933, 101.49182438850403, 95.30975371599197, 100.0399298965931, 102.24977731704712, 104.23325568437576, 101.23183473944664, 100.21817073225975, 93.1412024796009, 90.62507629394531, 88.55411142110825, 88.4972208738327, 84.68212679028511, 77.09383517503738, 75.98510786890984, 83.50351363420486, 88.19333598017693, 81.90862521529198, 82.4885880947113, 83.15236687660217, 84.80622813105583, 89.45619061589241, 94.85644564032555, 93.97300064563751, 88.86060297489166, 89.43631768226624, 78.38749095797539, 83.08219224214554, 89.94044423103333, 77.02160105109215, 74.91417333483696, 66.87897250056267, 46.636478304862976, 10.138209387660027, 1.2525872304104269, 1.3789156079292297, 0.1827651757048443, 0.7908122590743005, 1.266127685084939, 0.644752134103328, 0.43162747810129076, 0.7344388402998447, 0.18056936853099614, 0.09870208610664122, 0.15814218524610624, 0.06623269480769522, 0.22000203462084755, 8.317562732845545, 83.41156616806984, 103.13020527362823, 64.98776838183403, 39.553073197603226, 59.72044162452221, 37.656849548220634, 27.765858694911003, 45.80137051641941, 68.03024232387543, 76.0782864689827, 78.90151977539062, 91.13119393587112, 55.61942048370838, 12.318848725408316, 0.7877971802372485, 0.09693080224678852, 0.2541885181562975, 0.021904848617850803, 0.061911031589261256, 0.0374385820759926, 0.11000520302332006, 0.11919466109247878, 0.019624432898126543, 0.08458841883111745, 0.035579160758061334, 0.026312639929528814, 0.12826366117224097, 0.08044932023040019, 0.047722893505124375, 0.01164478871942265, 0.008605372076999629, 0.050134728735429235, 0.06121828126197215, 0.03140945598715916, 0.009450092911720276, 0.08945770910941064, 0.05294504160701763, 0.05872633118997328, 0.00846389368234668, 0.01958243847184349, 0.03964468283811584, 0.05913112450798508, 0.2366385216009803, 0.15060744190122932, 0.19351218652445823, 0.15611624083248898, 0.17772523598978296, 0.06664673157501966, 0.08230155755882151, 0.09858982142759487, 0.11964231714955531, 0.11668560822727159, 0.10554308464634232, 0.10937209910480306, 0.18013890803558752, 0.14824874815531075, 0.13265247020171955, 0.17145386547781527, 0.09677323687355965, 0.09670365310739726, 0.16789793909993023, 0.20070003520231694, 0.16427722322987393, 0.16212324349908158, 0.35863737284671515, 0.16852110566105694, 0.1859073992818594, 0.44785898993723094, 0.5620240420103073, 19.590198397636414, 139.51565444469452, 117.57082119584084, 100.76810762286186, 88.16046014428139, 62.510194927453995, 37.929610311985016, 95.46007364988327, 145.48942029476166, 100.5464731156826, 130.1021459698677, 140.34673064947128, 86.84759259223938, 4.8575567454099655, 0.36256864783354104, 0.5738237744662911, 0.35950826830230653, 0.14436862198635936, 0.27722445549443364, 0.6655465182848275, 2.28750076610595, 2.7394758258014917, 9.862126652151346, 44.30002547800541, 81.91152065992355, 98.50786730647087, 112.0792418718338, 114.55367669463158, 113.19551557302475, 115.7501032948494, 113.45548242330551, 113.52247282862663, 112.67270922660828, 109.65135455131531, 108.93529057502747, 110.02226024866104, 110.06037220358849, 115.24141699075699, 111.50817051529884, 108.70091915130615, 108.54391917586327, 104.517982006073, 107.70807802677155, 109.00658994913101, 97.95850038528442, 95.42164251208305, 99.57904502749443, 96.07379391789436, 94.39220175147057, 94.18477088212967, 87.77251616120338, 93.15137073397636, 92.26039454340935, 96.69548615813255, 98.85960683226585, 96.91614791750908, 95.6544940173626, 100.97461894154549, 100.85269868373871, 112.44282156229019, 104.22484293580055, 100.90100929141045, 104.69046235084534, 107.12822914123535, 106.13684713840485, 105.12217238545418, 104.28123190999031, 98.68088722229004, 95.93890875577927, 95.39565950632095, 96.0284623503685, 91.41084372997284, 88.42915892601013, 92.10134267807007, 97.19771280884743, 97.29633271694183, 90.47239288687706, 90.36270037293434, 90.01602217555046, 92.2675609588623, 93.61322835087776, 101.13589748740196, 101.07717543840408, 96.40873834490776, 93.52914646267891, 88.69448348879814, 86.87884211540222, 96.44647032022476, 81.51001140475273, 86.18768960237503, 83.47508355975151, 62.85737469792366, 14.05184168368578, 1.8035470973700285, 7.719982098788023, 6.319687413051724, 4.895271146669984, 3.1601989874616265, 0.8384703111369163, 0.286007120157592, 0.7171455526258796, 0.6316018709912896, 0.22084144817199558, 0.3763646981678903, 0.15916600765194744, 0.4430355643853545, 17.841416336596012, 98.85046452283859, 106.643777936697, 84.38322722911835, 52.37145736813545, 102.36950129270554, 102.56158858537674, 36.485171020030975, 38.931996524333954, 58.99288326501846, 70.84512367844582, 85.43526157736778, 102.9344929754734, 64.65098485350609, 13.737534899264574, 0.7050199876539409, 0.20107216289034113, 0.2718258951790631, 0.11699055670760572, 0.14809999207500368, 0.1426275583798997, 0.25833273015450686, 0.29916706087533385, 0.1906550960848108, 0.21168671519262716, 0.17938631091965362, 0.09194690952426754, 0.2058815024793148, 0.1359561999561265, 0.2100589478504844, 0.20378371817059815, 0.12436453602276742, 0.17424404388293624, 0.18182488944148645, 0.22278496966464445, 0.06178477742651012, 0.12302537506911904, 0.1405623840400949, 0.15860285115195438, 0.1450213705538772, 0.09810121366172098, 0.1439025384024717, 0.19152484863298014], [0.029980613908264786, 0.02594741978100501, 0.05490487550559919, 0.11761016095988452, 0.028801712323911488, 0.02855806153092999, 0.0724885989620816, 0.045464304348570295, 0.004315947289796895, 0.025828639045357704, 0.006090724345995113, 0.04485870442294981, 0.03452668774116319, 0.03945872660551686, 0.04579332067805808, 0.034021466999547556, 0.018151809672417585, 0.05839246492541861, 0.04067159999976866, 0.020521142105280887, 0.060247897199587896, 0.047372354893013835, 0.0696534760936629, 0.07535878830822185, 0.22593075555050746, 0.7484883489087224, 20.267439857125282, 95.75498342514038, 89.85156700015068, 91.54986307024956, 54.65837985277176, 55.13602562248707, 33.565799072384834, 83.39671656489372, 111.92324504256248, 70.71184203028679, 115.54049894213676, 110.91135174036026, 49.598423168063164, 3.3162744250148535, 0.09248518181266263, 0.18431826814776286, 0.13647890940774232, 0.22385241551091895, 0.23880535532953218, 0.1402792101725936, 0.9286595997400582, 0.4149537649936974, 7.572422716766596, 52.10876986384392, 85.95717117190361, 94.73059639334679, 96.790541857481, 96.21182531118393, 97.76975691318512, 102.44609758257866, 100.63570752739906, 102.30093017220497, 102.46502056717873, 101.54350161552429, 102.83008977770805, 98.34758430719376, 98.23850736021996, 101.13355681300163, 97.93709233403206, 96.83653458952904, 91.32023379206657, 92.9040876030922, 87.0395278930664, 89.70719754695892, 92.89846390485764, 98.5261519253254, 94.1978345811367, 86.03135079145432, 78.8382987678051, 81.12691596150398, 76.49912148714066, 80.21963864564896, 75.80913931131363, 79.86120387911797, 85.65378785133362, 90.28731241822243, 89.96255904436111, 102.5051312148571, 90.01412227749825, 82.55497053265572, 99.17810574173927, 102.66016289591789, 102.34061524271965, 94.6117539703846, 105.48002198338509, 105.4842321574688, 99.34762984514236, 93.79558816552162, 85.81693589687347, 82.897370159626, 81.54838174581528, 74.45202693343163, 68.74878376722336, 63.08009214699268, 57.97937884926796, 50.36036968231201, 58.78427065908909, 66.21315702795982, 68.60010534524918, 70.66716402769089, 72.90817737579346, 80.69313123822212, 80.7577733695507, 77.7931572496891, 79.2178376019001, 79.9445866048336, 74.08887282013893, 88.15230578184128, 79.59647208452225, 84.09233003854752, 80.64709290862083, 67.34614983201027, 57.97732695937157, 47.60258786380291, 17.974403500556946, 1.0265802266076207, 1.0568206664174795, 2.2938305139541626, 1.1490222439169884, 0.7232676772400737, 0.5608192691579461, 0.20677504828199744, 0.26051684108097106, 0.11260293511440977, 0.11203207512153313, 0.11741358088329434, 0.0715871418651659, 0.4389426199486479, 3.2479757023975253, 59.88157957792282, 98.61738502979279, 86.8761670589447, 39.70419488847256, 64.08502042293549, 74.75120007991791, 36.58240020275116, 27.357931584119797, 40.116195380687714, 59.28428962826729, 60.151855275034904, 79.95141103863716, 70.32987892627716, 17.846642956137657, 0.4984180675819516, 0.23016939841909334, 0.14985904534114525, 0.2940951642813161, 0.13013192889047787, 0.15115894668269902, 0.07493644690839574, 0.02501339538866887, 0.08080560306552798, 0.03239411526010372, 0.09527161237201653, 0.0639712149859406, 0.030593132505600806, 0.04411156951391604, 0.065412005642429, 0.060826813205494545, 0.059762573437183164, 0.04887952694843989, 0.01578938477905467, 0.04948438472638372, 0.03041651434614323, 0.06180496755405329, 0.045479752152459696, 0.05529789093998261, 0.049554031575098634, 0.05608643768937327, 0.03347533907799516, 0.03299919197161216, 0.017731661318975966, 0.04742031618661713, 0.11081012897193432, 0.04823051880521234, 0.022310430467769038, 0.02566416427725926, 0.07301045494386926, 0.03496233213809319, 0.06343156972434372, 0.05117667809827253, 0.07526251691160724, 0.04820580157684162, 0.017087649684981443, 0.03895494191965554, 0.06732015637680888, 0.06855205472675152, 0.12453701114282012, 0.05069203340099193, 0.08724240571609698, 0.08017554195248522, 0.03536591575539205, 0.1013752500875853, 0.03296378781669773, 0.16770018643001094, 2.7402901696041226, 37.04344846308231, 117.45763286948204, 100.49886927008629, 121.23989671468735, 84.05085146427155, 76.69351905584335, 27.883906960487366, 30.379035472869873, 98.83097916841507, 81.28501787781715, 122.22013771533966, 121.04429081082344, 54.49300892651081, 2.1837060106918216, 0.23672250303206965, 0.12700736842816696, 0.06973360577831045, 0.1688815519446507, 0.3003294125664979, 0.3781788336345926, 1.454644831828773, 1.0309927398338914, 10.973475817590952, 59.535581544041634, 91.3620163500309, 100.35631611943245, 102.55198270082474, 99.89375174045563, 101.90277993679047, 101.77223414182663, 102.8158101439476, 103.2697793841362, 103.68324279785156, 102.08152234554291, 103.9762906730175, 99.9029852449894, 99.24617528915405, 99.81042981147766, 97.85517632961273, 98.17641869187355, 91.79089933633804, 91.8804757297039, 89.2677815258503, 92.48255342245102, 94.83243092894554, 100.55168643593788, 98.59138682484627, 94.20491740107536, 88.10011938214302, 87.89773464202881, 85.44139444828033, 86.4665262401104, 85.32359316945076, 85.09137243032455, 88.8800959289074, 98.00553426146507, 95.35291939973831, 106.86351254582405, 94.78046491742134, 81.99279829859734, 102.03294575214386, 101.95144772529602, 102.61173829436302, 96.82935297489166, 107.72294282913208, 110.13769045472145, 104.2349199950695, 97.04340308904648, 91.39578893780708, 90.9936261177063, 84.89553853869438, 79.72872778773308, 77.00725302100182, 74.84155163168907, 71.73955008387566, 64.18085888028145, 69.70937982201576, 75.64180389046669, 80.8644488453865, 80.399931371212, 82.82725632190704, 86.63364887237549, 85.34281253814697, 83.82436081767082, 84.56945523619652, 84.2549841105938, 79.31882098317146, 90.65574064850807, 82.61437654495239, 89.91123139858246, 88.8764101266861, 79.4189228117466, 71.54971987009048, 71.54136791825294, 33.80405008792877, 3.7287867022678256, 1.0908443969674408, 1.5462512662634254, 0.5487786652520299, 0.1264651701785624, 0.778585821390152, 0.22198747261427343, 0.8109561062883586, 0.29351560631766915, 0.22777104430133477, 0.060174394893692806, 0.075311083055567, 0.4239635565318167, 1.4034358109347522, 55.353875532746315, 106.35016769170761, 87.11103245615959, 37.352045103907585, 56.94041579961777, 23.920478336513042, 31.01315874606371, 47.36703850328922, 62.489710226655006, 87.18125268816948, 75.69367110729218, 88.91936302185059, 87.48991012573242, 28.269293680787086, 0.37111946556251496, 0.22477189195342362, 0.30288121313787997, 0.09887778956908733, 0.12602770380908623, 0.12434768927050754, 0.11191828903974965, 0.03910038431058638, 0.005832559463669895, 0.02435260194033617, 0.15121592878131196, 0.03628193007898517, 0.03890224572387524, 0.059322053130017594, 0.06268379656830803, 0.06597693587536924, 0.04428321713930927, 0.01968234639207367, 0.035340248577995226, 0.05460304033476859, 0.039256921809283085, 0.006473285238826065, 0.03505873341055121, 0.020451528653211426, 0.025438948432565667, 0.03444466557994019, 0.053619052705471404, 0.14494616130832583, 0.15992592234397307, 0.1976300819660537, 0.2232310301042162, 0.11268455651588738, 0.08000953836017288, 0.18769389716908336, 0.1643336412962526, 0.10096513928147033, 0.1539201071136631, 0.09124733885983005, 0.1692777845892124, 0.16157534555532038, 0.11337349962559529, 0.13701105897780508, 0.20137359359068796, 0.21478268812643364, 0.24944530392531306, 0.17903739761095494, 0.13639685756061226, 0.1906676235375926, 0.3081757540348917, 0.28316344774793833, 0.1252529164776206, 0.3994807874551043, 2.689809878356755, 39.36892367899418, 136.64202064275742, 109.10017132759094, 117.8115838766098, 78.3727477490902, 64.82452154159546, 44.08197417855263, 115.33701986074448, 157.8984448313713, 93.70248556137085, 137.2818759083748, 130.0867035984993, 71.73972487449646, 4.923288468271494, 0.41326564620248973, 0.2208813460310921, 0.3408110747113824, 0.44024016126058996, 0.5219562607817352, 0.48903521324973553, 2.8541251737624407, 4.030385306105018, 9.64516019448638, 55.90226210653782, 94.15162906050682, 105.72757869958878, 112.1393470466137, 106.21331423521042, 109.92230281233788, 110.5207858979702, 114.32023242115974, 112.29223564267159, 112.5315771996975, 108.05860161781311, 110.80327033996582, 105.22433370351791, 104.64790463447571, 105.81965535879135, 106.07126265764236, 103.61084908246994, 97.52051308751106, 98.82184445858002, 93.44333946704865, 96.839589625597, 103.59260246157646, 107.63468116521835, 98.12898203730583, 98.26310724020004, 94.1477532684803, 94.23107519745827, 91.54813796281815, 92.57639318704605, 85.82316756248474, 90.13928756117821, 96.85401365160942, 102.04800814390182, 98.88089329004288, 107.20749288797379, 102.24707946181297, 96.39232322573662, 106.2631219625473, 101.77880018949509, 104.04175356030464, 100.64421147108078, 106.54294654726982, 108.52051243185997, 100.85679486393929, 100.75569748878479, 96.77198365330696, 98.56734171509743, 93.54003667831421, 90.57572454214096, 86.72689586877823, 84.28428813815117, 81.41982704401016, 74.38280984759331, 83.95097762346268, 87.75611624121666, 88.17678406834602, 89.58297461271286, 89.1100899875164, 95.48969686031342, 90.06345123052597, 89.86482828855515, 91.41393676400185, 93.55351835489273, 86.38481542468071, 96.26092627644539, 89.94226053357124, 94.99071523547173, 93.39654117822647, 83.45879003405571, 79.97969672083855, 87.41673365235329, 42.40535594522953, 3.8942972710356116, 2.3723141150549054, 6.769715314731002, 5.31437773257494, 3.7047976395115256, 2.0283943321555853, 0.312908518826589, 0.9642999060451984, 0.6106508045922965, 0.37529731169342995, 0.53324717679061, 0.22510758019052446, 0.9669243183452636, 7.269798405468464, 77.7714604139328, 111.6201277077198, 107.8380386531353, 54.64265249669552, 92.04831272363663, 95.18413245677948, 47.93652154505253, 35.37469960749149, 49.914231821894646, 80.23727729916573, 73.694127202034, 96.08001798391342, 103.29071626067162, 34.47329677641392, 0.6455117964651436, 0.20153374905930832, 0.4680120397824794, 0.3384355193702504, 0.1720760078751482, 0.14921943278750405, 0.20035541150718927, 0.12877707893494517, 0.17300476116361097, 0.12030879544909112, 0.19061929488088936, 0.16785514686489478, 0.15957567316945642, 0.12755603820551187, 0.17637564043980092, 0.14104233094258234, 0.18754902994260192, 0.09548926944262348, 0.13384692720137537, 0.11134991524158977, 0.11817067541414872, 0.17427307670004666, 0.07043952922686003, 0.16969766205875203, 0.08203377583413385, 0.1495442708255723, 0.13271311850985512], [0.058799688777071424, 0.09401367206010036, 0.17748356302035972, 0.08532749401638284, 0.041207330432371236, 0.03134120808681473, 0.04296608683944214, 0.03879254145431332, 0.11224055924685672, 0.03979051485657692, 0.10463376820553094, 0.05240942620730493, 0.028359514762996696, 0.006163901034597075, 0.1787502013030462, 0.022688658609695267, 0.10357984428992495, 0.07740174274658784, 0.10576236702036113, 0.02958889537694631, 0.06524425800307654, 0.11776427534641698, 0.37813258299138397, 0.37862243014387786, 11.694396883249283, 62.0059771835804, 104.95010241866112, 93.9947658777237, 82.3580650985241, 52.7034455537796, 64.12914365530014, 48.80851775407791, 114.53454092144966, 148.79445254802704, 123.57458263635635, 113.16564917564392, 114.03312742710114, 44.38240125775337, 1.479759227950126, 0.06900241962284781, 0.20563099795253947, 0.305086876032874, 0.3942501900019124, 0.2899815287673846, 0.14087090967223048, 0.27715122036170214, 0.6450744636822492, 1.4987635519355536, 29.211639314889908, 79.28706228733063, 84.11721110343933, 87.761549949646, 86.73860684037209, 92.43069380521774, 96.27991765737534, 96.60097002983093, 92.73646339774132, 89.42432552576065, 88.3692741394043, 91.72641679644585, 86.86621159315109, 83.8874526321888, 84.35930371284485, 83.82895097136497, 78.46937656402588, 84.52386528253555, 77.9115740954876, 76.79482161998749, 78.27779844403267, 80.02688258886337, 86.89839586615562, 96.95173680782318, 95.54565265774727, 87.367784678936, 84.76545631885529, 85.36373421549797, 91.63668841123581, 87.8945580124855, 91.89178392291069, 78.52619871497154, 80.56480452418327, 83.44052821397781, 82.39824414253235, 103.3535572886467, 102.64827713370323, 73.33742514252663, 79.56946313381195, 90.37042155861855, 95.67312061786652, 108.88351455330849, 128.59364211559296, 117.76463359594345, 102.8076633810997, 85.38451910018921, 79.08530831336975, 75.92260882258415, 69.479940533638, 67.30334132909775, 63.477501422166824, 59.32868644595146, 58.22841748595238, 56.53420999646187, 46.988643407821655, 51.013535633683205, 58.698995634913445, 64.18197602033615, 71.2641803920269, 70.26267573237419, 70.26272132992744, 73.45888182520866, 74.40810889005661, 71.98598206043243, 71.37575760483742, 79.52994525432587, 85.60254380106926, 86.78996488451958, 78.85469108819962, 74.83624711632729, 65.29271721839905, 52.88992054760456, 47.49828726053238, 37.14596316218376, 19.676774851977825, 2.7750032069161534, 0.38338927435688674, 0.8384055364876986, 0.3631441981997341, 0.3559472953202203, 0.1895141924615018, 0.47897997312247753, 0.14079193031648174, 0.12925683287903666, 0.20041841984493658, 0.15492464852286503, 0.431026368169114, 1.5427993889898062, 42.756350710988045, 101.31642580032349, 118.0184979736805, 50.377582758665085, 66.86095386743546, 64.63596045970917, 28.024070039391518, 24.995355159044266, 29.06998671591282, 48.24116639792919, 55.77157951891422, 73.63635510206223, 75.37682130932808, 14.531462397426367, 0.599999085534364, 0.358201049384661, 0.16725469002267346, 0.17817600164562464, 0.08853539766278118, 0.07654525237740017, 0.03069374361075461, 0.07912597444374114, 0.05032485212723259, 0.18500073230825365, 0.20851361827226356, 0.05813703624880873, 0.0475433754036203, 0.07028834632365033, 0.09068981526070274, 0.060508728711283766, 0.08072012249613181, 0.07258835103129968, 0.08232637497712858, 0.08025461778743193, 0.023687997563683894, 0.15072168811457232, 0.06843495124485344, 0.06765126556274481, 0.02314436325832503, 0.04015687976789195, 0.09486401002504863, 0.05592511333816219, 0.11706241886713542, 0.04164507881796453, 0.035976636499981396, 0.052118140665697865, 0.060717183150700293, 0.033102810630225576, 0.05501719584572129, 0.06887280353112146, 0.09243927997886203, 0.020519828503893223, 0.049955444410443306, 0.06175610455102287, 0.035164255677955225, 0.03989257129433099, 0.012837966442020843, 0.10999116158927791, 0.1247856454574503, 0.02625594726850977, 0.034893267875304446, 0.07983937874087133, 0.587675099959597, 1.1711891856975853, 23.965000547468662, 81.41398295760155, 120.15494093298912, 109.23609003424644, 118.25213983654976, 71.11244693398476, 61.91046550869942, 32.812082916498184, 52.717048823833466, 141.050164103508, 132.57666438817978, 116.87602087855339, 127.62173026800156, 47.4513103812933, 1.440215699840337, 0.18576756381662562, 0.3237418265780434, 0.3968991822330281, 0.23737345560221002, 0.4818175599211827, 0.6946572905872017, 0.8889315440319479, 0.5565825558733195, 2.449853466823697, 34.41214665770531, 87.52625897526741, 92.0353402197361, 93.4228889644146, 91.13246306777, 96.23483687639236, 96.60473942756653, 98.83140474557877, 93.56054037809372, 91.39306828379631, 92.35997959971428, 92.80982986092567, 89.03868421912193, 87.21930384635925, 86.95851624011993, 87.62512966990471, 78.77529814839363, 82.85206899046898, 80.92176496982574, 81.15609839558601, 81.25009015202522, 85.35459950566292, 91.43846824765205, 100.22903054952621, 101.4263691008091, 91.43832385540009, 91.92852795124054, 93.36823269724846, 97.59880408644676, 93.79813402891159, 96.3615220785141, 83.68442952632904, 85.84828421473503, 90.14838427305222, 85.74330344796181, 104.64160457253456, 107.00629368424416, 84.55386847257614, 80.82488536834717, 92.48687759041786, 95.62262892723083, 117.19755202531815, 128.8622573018074, 121.33211776614189, 107.48426243662834, 92.07694798707962, 82.5358347594738, 81.45249009132385, 75.38977101445198, 75.5045248568058, 74.00808155536652, 69.91166576743126, 68.15127342939377, 69.29509565234184, 62.67197884619236, 65.66100865602493, 70.56259363889694, 76.05370178818703, 80.4577262699604, 77.6302295923233, 78.03065210580826, 79.74517330527306, 80.6013585627079, 78.67939889431, 80.76242431998253, 84.60555329918861, 87.5357736647129, 88.9847119152546, 85.88111445307732, 84.78571683168411, 76.11651241779327, 65.35316437482834, 63.3473964035511, 58.482635244727135, 34.2968038469553, 8.243274819105864, 0.9605822805315256, 0.8015107631217688, 0.7866888865828514, 0.6600625813007355, 0.6056919519323856, 1.009087865240872, 0.7103048509452492, 0.16390606033382937, 0.0900987911154516, 0.0851558055728674, 0.3581059060525149, 0.02704180373257259, 39.902631640434265, 105.52875056862831, 117.37383976578712, 47.038869112730026, 50.51433362066746, 20.190932862460613, 17.947434447705746, 34.422444105148315, 47.556036561727524, 76.47254571318626, 73.12274426221848, 80.90471908450127, 89.41636115312576, 23.43665599822998, 0.8131628972478211, 0.23321129847317934, 0.228364925715141, 0.08078601778834127, 0.028310351190157235, 0.07652342581423, 0.04695698225987144, 0.10166816835408099, 0.03036083471670281, 0.020267286781745497, 0.07737683627055958, 0.054427544673671946, 0.0020157050948910182, 0.030556509373127483, 0.05648598031257279, 0.030028120636416133, 0.00677784594699915, 0.01819898057874525, 0.06134813113021664, 0.06585721261217259, 0.04330664356530178, 0.15041947073768824, 0.07592238267534412, 0.12657543848035857, 0.05034299392718822, 0.032100002135848626, 0.26611821551341563, 0.18092752899974585, 0.3327258804347366, 0.16583742544753477, 0.16355248633772135, 0.17705375561490655, 0.1866458065342158, 0.1013973586668726, 0.22490881819976494, 0.13975936541100964, 0.1740510854870081, 0.12013807179755531, 0.08359708022908308, 0.1745170503272675, 0.14688030205434188, 0.14345701230922714, 0.2349279454210773, 0.20379954075906426, 0.2745590766426176, 0.23607552837347612, 0.2572899532970041, 0.198313006258104, 0.5606645462103188, 1.4208085974678397, 30.70789072662592, 96.65577068924904, 138.02833825349808, 114.66593027114868, 108.19600224494934, 70.9870232641697, 80.10389685630798, 68.056460916996, 153.47751885652542, 190.9046745300293, 136.18061900138855, 134.9874222278595, 136.9623738527298, 64.91435632109642, 2.5868228171020746, 0.21090320020448416, 0.3674629930173978, 0.6568896921817213, 0.5840377451386303, 0.7571892882697284, 0.41580138669814914, 1.8240233673714101, 2.1674929931759834, 2.413651621900499, 30.348031036555767, 90.34104913473129, 97.43304938077927, 99.9104480445385, 95.0433424115181, 104.07142236828804, 102.65310287475586, 107.92896777391434, 100.72334602475166, 96.82402566075325, 97.48617812991142, 99.70114767551422, 94.44938868284225, 92.28690952062607, 94.40447509288788, 95.50735831260681, 84.32414039969444, 89.3721467256546, 85.64310282468796, 86.34573832154274, 82.96431496739388, 89.53474760055542, 94.06447693705559, 107.51798942685127, 104.95396301150322, 94.1702176630497, 95.30401602387428, 98.28978180885315, 103.89451906085014, 98.7186723947525, 102.6543340086937, 87.61998474597931, 94.03174549341202, 96.25702768564224, 91.90147340297699, 108.36736544966698, 110.28645247220993, 94.36306491494179, 93.26025769114494, 98.10779437422752, 97.80094563961029, 109.23032194375992, 112.69530281424522, 105.60904785990715, 99.28817823529243, 94.18570563197136, 88.93822520971298, 89.64633241295815, 84.80505019426346, 83.93938064575195, 83.42894643545151, 79.5965176820755, 75.70017635822296, 74.59353893995285, 69.13437947630882, 76.29793748259544, 82.83792614936829, 84.91317719221115, 87.67902597784996, 82.78470620512962, 82.04314559698105, 86.58404633402824, 84.9341444671154, 84.8844887316227, 85.17163932323456, 89.675872027874, 95.54695218801498, 96.72741964459419, 91.85219764709473, 87.81723216176033, 78.78835424780846, 69.05732721090317, 72.98564001917839, 72.79812768101692, 40.73101378977299, 8.807072415947914, 1.1301065026782453, 5.177896656095982, 3.1248414097353816, 2.765089776366949, 0.9636042464990169, 1.1322697740979493, 1.3499489310197532, 0.3982870280742645, 0.6004507269244641, 0.24904608784709126, 0.9056682209484279, 2.7476104767993093, 59.91527996957302, 116.09147697687149, 140.41692048311234, 63.95626813173294, 101.85614123940468, 79.79150041937828, 33.75114932656288, 31.56072836369276, 34.24325332045555, 65.82449868321419, 72.89012834429741, 87.19880014657974, 103.02034556865692, 33.80802467465401, 1.507620164193213, 0.36403501289896667, 0.7074829679913819, 0.40287902229465544, 0.2333403579541482, 0.15912535280222073, 0.12415813733241521, 0.28295294498093426, 0.14863558521028608, 0.29775335860904306, 0.2949548978358507, 0.23023751273285598, 0.07695936335949227, 0.21872064244234934, 0.1860047987429425, 0.2664099389221519, 0.1257782828179188, 0.1787144149420783, 0.2063386802910827, 0.2434346647351049, 0.09554378761094995, 0.32355382572859526, 0.2273523245821707, 0.21137780364369974, 0.09679448456154205, 0.0751074451545719], [0.049590779017307796, 0.07109587721060961, 0.021922775194980204, 0.024629252329759765, 0.05226961300650146, 0.0396251940401271, 0.02115754487022059, 0.08170164248440415, 0.02690769764740253, 0.03678854234749451, 0.0539309365558438, 0.025479145006102044, 0.17973988491576165, 0.17477424902608618, 0.03369254343851935, 0.1834247520309873, 0.1263647575979121, 0.05178039296879433, 0.02909223345341161, 0.09996329186833464, 0.16199069592403248, 0.16322996380040422, 21.742260418832302, 60.9346816688776, 93.10519561171532, 107.38163754343987, 90.41886895895004, 74.03949066996574, 42.737271934747696, 50.522092804312706, 81.21133223176003, 122.11905553936958, 105.29238805174828, 91.16650924086571, 128.1193819642067, 109.12557676434517, 38.385741636157036, 1.8342426815070212, 0.05347227073798422, 0.33270646585151553, 0.08164347294950858, 0.06316436687484384, 0.18540793389547616, 0.6257496506441385, 1.1069491202943027, 2.5108534935861826, 0.9824580629356205, 4.411500580608845, 52.88021966814995, 93.54204297065735, 93.07686433196068, 91.8599796295166, 84.41351920366287, 82.17075794935226, 84.06543508172035, 77.57111996412277, 83.23321133852005, 75.76662719249725, 78.05026665329933, 75.15793025493622, 71.55560195446014, 75.23570448160172, 72.98143744468689, 71.56811848282814, 73.87058973312378, 85.24501338601112, 84.56125527620316, 89.25291672348976, 82.32297018170357, 78.95101591944695, 86.09517216682434, 95.04169330000877, 88.35935667157173, 97.86092922091484, 89.14307981729507, 87.33607158064842, 87.79848396778107, 93.2148577272892, 86.1875756084919, 64.5924223959446, 68.77098977565765, 73.3290883898735, 83.32221776247025, 81.80673748254776, 105.0100328028202, 101.2314623594284, 74.47445333003998, 62.92949482798576, 85.14075458049774, 120.90220883488655, 115.34769728779793, 98.53814408183098, 74.211385846138, 70.85161373019218, 74.8706504702568, 73.6816942691803, 75.14814957976341, 88.90148118138313, 74.86511796712875, 58.01630526781082, 51.38284161686897, 56.298208460211754, 64.83786642551422, 60.00701084733009, 58.49193334579468, 62.347506657242775, 62.635367810726166, 67.31593385338783, 69.14933547377586, 75.20535171031952, 75.78062564134598, 67.25661903619766, 68.16479310393333, 77.91023656725883, 81.8579663336277, 80.65048232674599, 75.16593262553215, 71.55639231204987, 65.16170784831047, 58.13596464693546, 53.243924751877785, 48.71353805065155, 53.455432802438736, 55.22985778748989, 31.686153933405876, 2.124541997909546, 0.7441127649508417, 0.30328149790875614, 0.6724683218635619, 0.14251328248064965, 0.2824709052219987, 0.1290161840734072, 0.07874223214457743, 0.03079003727179952, 0.3236043214565143, 0.22322869976051152, 1.283499759156257, 29.24917370080948, 82.47704431414604, 120.07966697216034, 55.903519839048386, 79.25842702388763, 82.36574068665504, 46.31170593202114, 24.966282919049263, 22.529141195118427, 43.14295716583729, 61.643921211361885, 72.552600055933, 72.10379093885422, 17.85013686865568, 0.42155371396802366, 0.9371640183962882, 0.024229548289440572, 0.05970317935862113, 0.18330033839447424, 0.3349956055171788, 0.1167085776978638, 0.044357112783472985, 0.05609361054666806, 0.21041296713519841, 0.11136331842863001, 0.051324569576536305, 0.1255066567682661, 0.03214544012735132, 0.055491632301709615, 0.06877814259496517, 0.13059127377346158, 0.06086048444558401, 0.1625710108783096, 0.08348278206540272, 0.21560167777352035, 0.03409029006434139, 0.043103569696540944, 0.04426198800501879, 0.0327964335156139, 0.0834608293371275, 0.13430919614620507, 0.062185919377952814, 0.054677726366207935, 0.006897361408846336, 0.08736414762097411, 0.023326074406213593, 0.027558184519875795, 0.028723671784973703, 0.07994684914592654, 0.042137219206779264, 0.05985239185974933, 0.16646829550154507, 0.10157333672395907, 0.05405234820500482, 0.1062491194170434, 0.14234901551390067, 0.08271058482932858, 0.038774536951677874, 0.11631992980255745, 0.17260640597669408, 0.8638857817277312, 30.974079743027687, 78.93216133117676, 111.20107859373093, 128.4863966703415, 113.9220517873764, 107.8496204316616, 76.7167130112648, 57.288857102394104, 59.36478450894356, 85.58637946844101, 106.77095711231232, 107.80998095870018, 126.79326832294464, 120.02399235963821, 38.30972671508789, 1.3316679932177067, 0.03457502753008157, 0.2514112531207502, 0.2583027770742774, 0.10682166408514604, 0.6584031984675676, 1.3293648418039083, 0.34213684732094407, 5.465654265135527, 1.884643177036196, 4.333629459142685, 58.303782641887665, 100.6690925359726, 98.15466865897179, 93.66607591509819, 90.09691223502159, 85.42085275053978, 86.9268487393856, 80.01669153571129, 83.78108873963356, 77.94583305716515, 80.17933800816536, 79.03831243515015, 75.0923989713192, 75.9177678823471, 78.15180480480194, 77.23665431141853, 78.28705474734306, 87.40865528583527, 92.05674067139626, 94.93043527007103, 88.82610082626343, 83.9307551085949, 88.19870129227638, 100.39565920829773, 93.18755239248276, 101.62940740585327, 93.49905207753181, 92.24396422505379, 90.99084466695786, 97.19071358442307, 87.28826254606247, 71.91901445388794, 78.94305914640427, 79.24721002578735, 87.30709433555603, 90.47246888279915, 109.23173546791077, 108.70281904935837, 80.52233040332794, 73.38587254285812, 89.10709574818611, 124.10492777824402, 116.18952691555023, 102.7672715485096, 78.45054477453232, 74.41854313015938, 80.07622674107552, 85.14854416251183, 85.38504347205162, 98.8165931403637, 87.53805354237556, 70.13307228684425, 67.30052188038826, 66.57317250967026, 74.24682274460793, 71.99454680085182, 71.54387578368187, 72.3104390501976, 71.17057621479034, 75.74821338057518, 78.24304550886154, 80.44251188635826, 82.99704641103745, 74.45705026388168, 76.89247637987137, 82.46246829628944, 84.95631247758865, 85.28016149997711, 82.30652466416359, 79.10008952021599, 76.59396439790726, 70.19506216049194, 65.01010358333588, 61.18384189903736, 71.27576977014542, 77.17921659350395, 48.25285077095032, 6.586999744176865, 1.0841371631249785, 0.6145094975363463, 0.37605854740832, 0.39081274007912725, 0.4733252234291285, 0.24849535489920527, 0.13992162857903168, 0.10562438692431897, 0.11389903665985912, 0.16998285456793383, 0.4942222614772618, 26.07780497521162, 87.7660109102726, 119.98288616538048, 62.584104761481285, 62.557042613625526, 28.402900211513042, 19.88429881632328, 30.5391151830554, 34.76343780755997, 59.10941161215305, 82.72644773125648, 82.42224365472794, 84.95891153812408, 27.65449807047844, 0.5413238808978349, 0.6877622043248266, 0.18628671095939353, 0.04051165975397453, 0.13369610795052722, 0.2741985413013026, 0.1307017053477466, 0.022674667270621285, 0.13497663923772052, 0.10046576295280829, 0.08006937030586414, 0.019697950046975166, 0.10516242226003669, 0.08288166471174918, 0.02709679687541211, 0.028990735481784213, 0.06203459917742293, 0.04307627350499388, 0.11547241199878044, 0.10681407191441394, 0.07055321140796877, 0.05804794142022729, 0.013028188168391353, 0.10470428707776591, 0.011013806415576255, 0.13452336512273178, 0.5818012089002877, 0.11344409271259792, 0.17936621356057003, 0.15245482558384538, 0.1418728832504712, 0.10304232899216004, 0.10802969496580772, 0.10382060441770591, 0.18893760308856145, 0.2013780316337943, 0.2385822360520251, 0.2679484704276547, 0.22456014237832278, 0.18227540276711807, 0.31952906982041895, 0.2318118157563731, 0.19290006312076002, 0.2808822045335546, 0.37000559095758945, 0.5584147700574249, 2.043289770372212, 39.45184662938118, 99.7489795088768, 133.0857002735138, 138.2501095533371, 111.74697250127792, 98.2492607831955, 54.615483954548836, 62.574278488755226, 98.58419001102448, 143.81491094827652, 135.0758358836174, 114.4792614877224, 139.68986749649048, 126.13913342356682, 56.26218259334564, 2.460927735082805, 0.1969087589532137, 0.5390567088034004, 0.2831278840312734, 0.13787612115265802, 0.577513970201835, 1.1481472221203148, 2.403880921192467, 9.140199590474367, 2.840980254113674, 5.418968070298433, 59.95485104620457, 105.9580971300602, 104.29110378026962, 103.25045362114906, 94.2047730088234, 92.76703655719757, 94.68008950352669, 87.80523240566254, 88.84251594543457, 81.53977140784264, 84.84434008598328, 84.40291777253151, 78.01572650671005, 80.20191639661789, 80.90184643864632, 80.16743704676628, 79.44118201732635, 92.92405933141708, 92.18359306454659, 96.77301719784737, 89.14857432246208, 85.23647904396057, 94.00263905525208, 103.54157119989395, 94.75968763232231, 105.83236947655678, 97.12775856256485, 96.54218718409538, 96.51599898934364, 100.55733293294907, 94.60359200835228, 79.30057436227798, 84.41536590456963, 86.44974634051323, 94.89081099629402, 96.75902634859085, 117.53115892410278, 111.97588741779327, 92.10841789841652, 82.42522269487381, 93.21606606245041, 103.07456865906715, 101.419597864151, 95.856703966856, 82.13493347167969, 78.70524510741234, 81.43938079476357, 86.33784234523773, 92.30680525302887, 103.36949363350868, 88.14199313521385, 78.54329779744148, 74.53319057822227, 77.05925703048706, 80.47724962234497, 77.71903082728386, 79.2105495929718, 83.68984803557396, 77.64495000243187, 82.09440484642982, 78.96455839276314, 86.23837888240814, 85.14008581638336, 78.2594758272171, 79.22314211726189, 86.18148073554039, 92.50795885920525, 89.8689092695713, 85.15305832028389, 82.04291760921478, 79.55558627843857, 76.23960301280022, 69.42605182528496, 64.60560008883476, 76.96371495723724, 89.75825160741806, 58.240816220641136, 7.670612772926688, 1.8764020130038261, 2.6407374115660787, 3.613465977832675, 2.3345574410632253, 1.6848338674753904, 0.8817004133015871, 0.3444158937782049, 0.24296507821418345, 0.46217694820370525, 0.41418869979679585, 1.8350331578403711, 42.93451935052872, 95.88224619626999, 140.1366475224495, 69.2615358531475, 114.766184091568, 104.61114540696144, 56.70554660260677, 34.39591772854328, 27.629898190498352, 56.79361827671528, 82.18163296580315, 89.31358426809311, 97.37976104021072, 40.9642718732357, 1.3692020229063928, 0.810570070752874, 0.2462790347635746, 0.1857725955778733, 0.3306643426185474, 0.5420377675909549, 0.3347036149352789, 0.160048020479735, 0.237306974013336, 0.37475717661436647, 0.19842026144033298, 0.2085393707966432, 0.2494784927694127, 0.1261587522458285, 0.13143589720129967, 0.14493998663965613, 0.21859018772374839, 0.16174669261090457, 0.19877214333973825, 0.19497957575367764, 0.3286124824080616, 0.16647631069645286, 0.12733596173347905, 0.258017762680538, 0.16292275919113308], [0.0741855196247343, 0.14870260114548728, 0.023266826901817694, 0.08266915814601816, 0.007523919121013023, 0.11189779834239744, 0.045286281674634665, 0.03400049390620552, 0.016174514894373715, 0.05098403140436858, 0.023860626679379493, 0.04056761026731692, 0.07632950262632221, 0.056813775809132494, 0.06865357310744002, 0.07151641519158147, 0.07595649920403957, 0.07490978154237382, 0.049293912525172345, 0.39784049266017973, 7.111505549401045, 65.51055952906609, 99.06689330935478, 91.66671440005302, 95.83765178918839, 67.50897109508514, 57.667666375637054, 44.52812723815441, 37.07868777215481, 64.37376692891121, 128.13950568437576, 100.85889995098114, 83.67898061871529, 113.87440234422684, 112.76768893003464, 36.27001516520977, 1.5828083921223879, 0.038215647800825536, 0.3513931209454313, 0.2488003479084, 0.211249471467454, 0.8426722325384617, 0.05982603819575161, 1.8052799231372774, 6.023271968588233, 4.237746354192495, 2.2656084783375263, 6.243779836222529, 65.17919450998306, 99.58183407783508, 100.94463095068932, 95.06921902298927, 89.80875849723816, 82.09029346704483, 80.02055212855339, 78.3374172449112, 79.8297643661499, 73.567905575037, 75.20788237452507, 68.87242153286934, 72.00143963098526, 74.91564765572548, 80.67009687423706, 81.46030247211456, 87.504121363163, 94.7249422967434, 100.0691731274128, 94.06940147280693, 94.67627450823784, 85.59251993894577, 84.14344489574432, 85.87272450327873, 85.84663510322571, 87.43680417537689, 81.10992327332497, 78.71846079826355, 82.74423837661743, 81.39478638768196, 86.77927225828171, 71.55060902237892, 61.186262369155884, 72.81266570091248, 78.72143223881721, 76.8335111439228, 85.28902262449265, 100.24188905954361, 94.05397430062294, 72.98089787364006, 76.89252957701683, 86.31418481469154, 71.47637620568275, 59.44663591682911, 58.86755459010601, 66.5495453774929, 64.17553156614304, 69.87258866429329, 71.12379312515259, 70.33178642392159, 73.52297678589821, 61.28905065357685, 58.458745926618576, 56.63919076323509, 59.304481744766235, 64.50721576809883, 66.85193315148354, 62.71881513297558, 61.067685931921005, 63.26212517917156, 71.45099356770515, 76.28102838993073, 80.81349357962608, 78.05399045348167, 71.74178436398506, 83.74692857265472, 82.46829718351364, 79.80948865413666, 76.34411260485649, 75.2191449701786, 72.41420388221741, 64.5026408135891, 59.679362028837204, 60.968530252575874, 57.4436341971159, 53.770116716623306, 55.37757106125355, 47.53901347517967, 12.299141082912683, 1.51793411700055, 0.7074430107604712, 0.8179506403394043, 0.7093210006132722, 0.12388352042762563, 0.0746774002618622, 0.01898679074656684, 0.0529999122954905, 0.42770169500727206, 0.32019946665968746, 0.23635416029719636, 18.809431493282318, 66.92824065685272, 105.81668391823769, 70.34236505627632, 76.10678493976593, 73.7008148431778, 41.612703278660774, 34.528458416461945, 26.82137567549944, 42.865461856126785, 61.88617341220379, 63.69030140340328, 74.22691941261292, 25.742919445037842, 0.5712324916385114, 0.1961137555190362, 0.05301333774696104, 0.18943570292321965, 0.13441404676996171, 0.10980580278555863, 0.04140531316807028, 0.1513199185137637, 0.10966656845994294, 0.0894038069236558, 0.10464588005561382, 0.048229732128675096, 0.037604414974339306, 0.05223603824560996, 0.11073491230490617, 0.08942521046265028, 0.11360266740666702, 0.0463516383751994, 0.047337525902548805, 0.05530419177375734, 0.11413670203182846, 0.03832508860796224, 0.08351718061021529, 0.03199088416295126, 0.03838305776298512, 0.0333454595238436, 0.030630297405878082, 0.06578699059900828, 0.0329053882160224, 0.07084186232532375, 0.06503590746433474, 0.007871127345424611, 0.024856147283571772, 0.10498058865778148, 0.04123948026972357, 0.0816227744508069, 0.018671042162168305, 0.1003885202226229, 0.037031566025689244, 0.04549150035018101, 0.06127802414994221, 0.04557802363706287, 0.045139622161514126, 0.4324481450021267, 8.466942217200994, 85.1111313700676, 112.89220064878464, 104.26515877246857, 115.26973307132721, 91.97664856910706, 93.24365258216858, 76.99895426630974, 46.03619031608105, 48.315763995051384, 129.9964964389801, 105.72475925087929, 91.91896006464958, 119.95457008481026, 119.5776379108429, 37.030046582221985, 1.2707071518525481, 0.015046879943838576, 0.39367048360873014, 0.5393643735442311, 0.2050875677377917, 1.0200045607052743, 0.21166799822822213, 3.38670055847615, 10.690850783139467, 5.877605360001326, 1.9036533194594085, 12.754087820649147, 72.33826115727425, 105.51259383559227, 101.00192427635193, 99.74625125527382, 92.59458661079407, 85.59604614973068, 82.49621048569679, 81.63124769926071, 80.53607806563377, 76.99408292770386, 77.08709433674812, 74.44546088576317, 76.11862510442734, 80.27594402432442, 84.43631798028946, 87.23815843462944, 92.4032972753048, 98.62155720591545, 103.16160678863525, 99.56918835639954, 96.81215509772301, 89.24833416938782, 89.20914307236671, 89.71475154161453, 92.48667240142822, 92.60931462049484, 86.40122294425964, 85.51299780607224, 88.14959272742271, 87.74492964148521, 91.34483367204666, 81.10640466213226, 69.70576241612434, 78.99979010224342, 84.35023739933968, 85.78102022409439, 93.01647797226906, 107.09828674793243, 103.86130884289742, 76.89984798431396, 80.55380031466484, 89.83335077762604, 76.15441158413887, 65.18201395869255, 61.07010260224342, 69.66581135988235, 69.36236724257469, 76.93491250276566, 74.66660141944885, 75.40047124028206, 80.28602108359337, 68.85531485080719, 69.58577245473862, 68.50181981921196, 68.65047544240952, 72.8177498281002, 76.5126183629036, 70.62433272600174, 70.21824851632118, 69.57325592637062, 78.43988254666328, 83.00792142748833, 85.69483324885368, 84.25471812486649, 80.27157425880432, 88.29119592905045, 87.69469633698463, 84.97781172394753, 81.38386577367783, 82.35217541456223, 80.51194176077843, 75.65951853990555, 73.98263052105904, 75.97223415970802, 71.0019488632679, 66.07716232538223, 69.60186079144478, 68.30527916550636, 25.670898109674454, 2.607005196623504, 0.16559466894250363, 0.23307538154767826, 0.762789297150448, 0.31216978502925485, 0.2147641938063316, 0.06853538608993404, 0.17119778000051156, 0.43424411269370466, 0.2654447016539052, 0.33719818107783794, 18.653548657894135, 74.54374641180038, 107.46434390544891, 80.35611972212791, 69.65688183903694, 45.86405195295811, 18.963955901563168, 35.87368123233318, 47.67930194735527, 60.2816791087389, 81.62645235657692, 70.2547113597393, 86.75022661685944, 34.183984100818634, 0.33791747060604393, 0.10254353153868578, 0.0894319343206007, 0.14268526778323576, 0.11791153228841722, 0.13223480433225632, 0.044697357807308435, 0.019653148447105195, 0.03937490844691638, 0.05479354593262542, 0.04021720524178818, 0.07362725387793034, 0.06709960493026301, 0.07875594703364186, 0.13065484614344314, 0.027098986211058218, 0.015291493673430523, 0.06915133155416697, 0.039071440551197156, 0.0835219377768226, 0.06911260628839955, 0.0517438384849811, 0.05986207317619119, 0.006906544558660244, 0.21176156820729375, 0.21531924605369568, 0.09370007013785653, 0.23067935777362436, 0.10355751306633465, 0.26117491826880723, 0.18699834152357653, 0.22269775246968493, 0.10648378651239909, 0.1425649062730372, 0.08846783995977603, 0.18216277443571016, 0.14022156014107168, 0.20962905138731003, 0.22468734649010003, 0.19935337855713442, 0.19331339484779164, 0.2235453444882296, 0.11588537265197374, 0.8089279057458043, 11.707890909165144, 101.80161416530609, 134.48025584220886, 113.82451102137566, 116.47407084703445, 88.73005717992783, 78.51017117500305, 53.69958110153675, 46.867346316576004, 79.65875074267387, 135.30982732772827, 121.93223476409912, 105.99902853369713, 138.0338403582573, 130.62606185674667, 54.177325665950775, 2.1448378963395953, 0.14769955887459219, 0.4696234205039218, 0.4239172168308869, 0.43716152489650995, 1.7306858883239329, 0.19360234262421727, 2.8786312462762, 19.266752153635025, 9.533922113478184, 3.5683963587507606, 11.769170220941305, 78.33732604980469, 110.90301498770714, 107.33821347355843, 102.81201794743538, 96.71297281980515, 90.71183323860168, 86.35487303137779, 84.92777600884438, 84.07874196767807, 80.36795988678932, 80.62192305922508, 76.08078673481941, 77.20776066184044, 83.04205879569054, 85.16963303089142, 88.73454853892326, 99.08275365829468, 104.39495980739594, 109.41553920507431, 104.39903318881989, 101.49481862783432, 93.15784558653831, 91.19047075510025, 96.20239421725273, 93.67193520069122, 93.79855200648308, 89.36155289411545, 85.42868033051491, 90.31955748796463, 91.37830227613449, 94.3025341629982, 80.16039222478867, 75.64016237854958, 84.01622772216797, 93.52271720767021, 89.24100816249847, 97.34066113829613, 114.41912591457367, 111.81430488824844, 89.05326783657074, 88.42067018151283, 87.82353982329369, 80.12169510126114, 69.8480723798275, 73.37638825178146, 75.85940301418304, 74.99980553984642, 82.35791310667992, 81.00365057587624, 87.26012125611305, 85.95745235681534, 78.83274346590042, 77.9123492538929, 75.95940604805946, 76.2590579688549, 80.07727548480034, 82.8110159933567, 76.45798489451408, 75.43447941541672, 77.02236860990524, 87.14368790388107, 90.41739463806152, 89.87385660409927, 87.30333253741264, 85.67664742469788, 92.75974854826927, 93.13256174325943, 88.12751591205597, 88.07534471154213, 86.70024409890175, 84.78937983512878, 80.15560448169708, 77.33300194144249, 80.48652112483978, 70.55956900119781, 68.51647183299065, 75.04065334796906, 81.26351863145828, 31.982192248106003, 2.274352521635592, 3.7924097757786512, 4.85371277667582, 2.0911429775878787, 0.4650317825144157, 0.3150912938872352, 0.2432296093320474, 0.3316749696386978, 0.6496020394843072, 0.6108163332100958, 0.7582467002794147, 31.220990493893623, 85.42932629585266, 127.77201980352402, 85.67679941654205, 104.76025700569153, 108.06984901428223, 51.98749177157879, 49.10359472036362, 37.384552359580994, 57.15274840593338, 78.45221668481827, 75.3411716222763, 99.62165594100952, 46.79006986320019, 1.2616039090789855, 0.22396504384232685, 0.23222007119329646, 0.3574766538804397, 0.2705963049083948, 0.26691323379054666, 0.2295447327196598, 0.1845730622881092, 0.20858572534052655, 0.11504382171551697, 0.22817241260781884, 0.14610410464229062, 0.17799579334678128, 0.17063581093680114, 0.34926001040730625, 0.10818380193086341, 0.2546373096993193, 0.17226688825758174, 0.09736996071296744, 0.16921062022447586, 0.2245812490582466, 0.17399658216163516, 0.29658043873496354, 0.13482414273312315], [0.08035838487558067, 0.018056401022477075, 0.07121031638234854, 0.0725070116459392, 0.023595472157467157, 0.11701016424922273, 0.055386421736329794, 0.039857816518633626, 0.013742574883508496, 0.0692219691700302, 0.056674010847928, 0.0031002639389043907, 0.012144958218414104, 0.08076187572441995, 0.04665640874009114, 0.0376820102246711, 0.029603942421090323, 0.027794057605206035, 0.1939344240236096, 5.457895556464791, 79.49559509754181, 94.50383976101875, 91.78019911050797, 73.44388782978058, 51.93937875330448, 70.9523843228817, 44.139263704419136, 37.324287593364716, 112.95378774404526, 161.04564875364304, 88.68846461176872, 84.75531086325645, 107.35771402716637, 114.35351863503456, 43.63419860601425, 1.322407415136695, 0.01857772822404513, 0.3468997433083132, 0.1448621353483759, 0.2665610401891172, 1.0346579994075, 0.07396260814857669, 0.16108089708723128, 2.3064270755276084, 2.2995708184316754, 0.4006475326605141, 14.240849241614342, 88.14161315560341, 109.05601009726524, 107.8232954442501, 104.84543323516846, 96.93808034062386, 93.93450111150742, 86.34823858737946, 78.92909869551659, 81.97835147380829, 76.44834101200104, 78.62810164690018, 80.38042321801186, 85.00327035784721, 84.6196885406971, 94.0304383635521, 90.50770059227943, 95.27167975902557, 98.93782943487167, 98.60793873667717, 95.49307867884636, 99.01615083217621, 90.88841736316681, 83.45506623387337, 82.1653850376606, 84.30933639407158, 92.57585361599922, 89.10119846463203, 79.883181899786, 81.65134862065315, 80.05738735198975, 77.61347249150276, 81.92100495100021, 75.2242062985897, 74.59841027855873, 77.71808847784996, 82.53460362553596, 77.63260826468468, 77.58651673793793, 87.40541025996208, 90.99477365612984, 77.5112883746624, 52.90774919092655, 65.59747606515884, 38.890639543533325, 45.41556961834431, 41.50559842586517, 58.20963129401207, 62.52290144562721, 63.19627471268177, 65.8813664317131, 55.24367764592171, 49.40618008375168, 50.813176184892654, 50.0843258947134, 63.47688965499401, 68.83412718772888, 63.34058336913586, 67.00688123703003, 74.34187844395638, 75.54056972265244, 71.28409132361412, 63.63198593258858, 64.58069622516632, 70.49662157893181, 73.50575610995293, 73.72422158718109, 80.9923879802227, 79.87717062234879, 79.07791391015053, 76.74728617072105, 76.1756144464016, 73.28821778297424, 74.32203590869904, 67.67319828271866, 66.67826727032661, 67.56534487009048, 64.68414947390556, 57.805975154042244, 52.402775287628174, 49.81095336377621, 24.747978933155537, 3.3890854055061936, 0.28979406226426363, 0.4957481171004474, 0.20265718252630904, 0.11437111679697409, 0.15293159609427676, 0.15085689257830381, 0.1279944842099212, 0.1899589764070697, 0.11624927734374069, 0.41810744733083993, 16.05780154466629, 54.53444190323353, 92.36650764942169, 79.42482769489288, 57.0223356038332, 76.65621265769005, 45.61138071119785, 20.373545363545418, 25.616103149950504, 44.672116711735725, 65.48453092575073, 59.236746579408646, 81.90137520432472, 22.166218869388103, 1.0934826429001987, 0.15274274919647723, 0.045832699033780955, 0.050806439176085405, 0.05554922667215578, 0.07238840902573429, 0.05848324071848765, 0.028314792944001965, 0.14999395294580609, 0.037189049762673676, 0.07897814604802988, 0.037936819207970984, 0.028594671675818972, 0.0512857738067396, 0.0691517694212962, 0.01962872251169756, 0.05915147419727873, 0.027920235697820317, 0.04085105501872022, 0.014484253151749726, 0.08353432422154583, 0.07470389493391849, 0.04132894617214333, 0.047708306592539884, 0.010651921293174382, 0.05473063778481446, 0.10624961665598676, 0.004725271883216919, 0.021011161807109602, 0.06327763345325366, 0.05113013059599325, 0.05795181103167124, 0.04339644714491442, 0.022071054445405025, 0.03877946481225081, 0.07054567118757404, 0.0284618958903593, 0.0671942213375587, 0.10976309218676761, 0.0740191301156301, 0.05234015785390511, 0.20238680328475311, 6.637873314321041, 97.18975603580475, 102.03210979700089, 108.51764738559723, 105.2221754193306, 83.8378044962883, 106.27577528357506, 65.89421734213829, 46.53085917234421, 64.53215762972832, 135.717591047287, 103.98960515856743, 94.19466555118561, 114.20011326670647, 124.57538813352585, 45.683447644114494, 0.9835582226514816, 0.1229808313655667, 0.4308461747132242, 0.14819471980445087, 0.320816250750795, 0.5767625605221838, 0.2212526128278114, 1.3223052956163883, 1.991606606170535, 1.4606401976197958, 0.3701168834231794, 23.45239855349064, 103.57833802700043, 111.8254990875721, 110.16745805740356, 106.45174384117126, 102.84618571400642, 96.00078463554382, 88.48811656236649, 82.32278779149055, 83.34059357643127, 81.40923321247101, 85.44679775834084, 83.22574093937874, 90.68469509482384, 91.38638824224472, 100.12224867939949, 93.04450526833534, 98.90762865543365, 102.09473043680191, 101.8282051384449, 99.06704530119896, 102.40618452429771, 94.50387015938759, 85.9323813021183, 85.63913583755493, 89.94630351662636, 95.02202555537224, 93.22419002652168, 85.4312489926815, 86.14301159977913, 83.07023048400879, 83.32071304321289, 84.50833171606064, 76.38649553060532, 81.43132522702217, 81.52768045663834, 87.3087890446186, 80.9364701807499, 78.8936997950077, 93.82657930254936, 97.90451288223267, 84.30418387055397, 68.89829814434052, 69.7461086511612, 50.96736431121826, 51.997340843081474, 53.784795328974724, 71.53791010379791, 71.69943943619728, 71.37364491820335, 74.84776049852371, 66.0637566447258, 63.19855839014053, 60.30719853937626, 60.143993496894836, 72.4683965742588, 76.7026461660862, 73.63990411162376, 76.34564012289047, 81.58532336354256, 80.33280417323112, 78.7877006828785, 72.57607519626617, 69.79406207799911, 74.66581106185913, 77.43077829480171, 79.06386226415634, 85.2854660153389, 86.07605159282684, 84.43314135074615, 81.39194414019585, 83.72300505638123, 81.810712069273, 81.42708465456963, 76.97634547948837, 77.22034558653831, 77.09849372506142, 78.636863976717, 74.95429918169975, 65.80682203173637, 66.35387107729912, 42.78660848736763, 6.882726475596428, 0.859642003197223, 0.3126517357304692, 0.2976191189372912, 0.31189225148409605, 0.2914268762106076, 0.10330401768442243, 0.21278809203067794, 0.03978771324909758, 0.05774731223937124, 0.5696144315879792, 16.80446907877922, 65.28414487838745, 101.77384525537491, 87.70301029086113, 58.97375129163265, 39.17194604873657, 26.265279315412045, 27.78281908482313, 48.78768727183342, 69.90502372384071, 86.79533019661903, 64.89046320319176, 94.23045203089714, 35.53839102387428, 0.996152765583247, 0.1588028302649036, 0.07533998228609562, 0.1458134499262087, 0.02048929840384517, 0.02086945798509987, 0.07023516402114183, 0.10862267095944844, 0.0662706111324951, 0.07435208724928088, 0.05663609081238974, 0.038013594385120086, 0.08065796020673588, 0.03770535819057841, 0.11198930515092798, 0.06293184458627366, 0.039553031310788356, 0.01958797303814208, 0.04399001685669646, 0.018096484418492764, 0.010126351789949695, 0.09573523202561773, 0.011073670830228366, 0.22338135953759775, 0.18541458353865892, 0.17677055206149817, 0.22541554179042578, 0.07883326397859491, 0.296258406015113, 0.2805316139711067, 0.12540593248559162, 0.15352276124758646, 0.14432219322770834, 0.14140239130938426, 0.13548852817621082, 0.19111402536509559, 0.2073794830357656, 0.19259109220001847, 0.1654777064686641, 0.2924601238919422, 0.1325203976011835, 0.6086772261187434, 10.5559703707695, 113.2012152671814, 118.0322228372097, 113.23892444372177, 96.64335295557976, 76.41664311289787, 90.29117301106453, 54.32564690709114, 47.572751864790916, 138.33644092082977, 179.32642221450806, 105.90148776769638, 113.00100401043892, 129.71864014863968, 135.04671424627304, 58.62961895763874, 1.644258457235992, 0.38940637023188174, 0.6093902816064656, 0.2558637532638386, 0.6340009672567248, 1.8643232923932374, 0.21534924366278574, 1.4337579463608563, 6.649358198046684, 3.6707493290305138, 1.511857530567795, 17.819791696965694, 100.74141025543213, 112.43013024330139, 114.0424445271492, 113.56157273054123, 109.90192830562592, 102.34610974788666, 94.55754607915878, 88.10608506202698, 90.11520445346832, 85.38378953933716, 87.91769117116928, 87.01972335577011, 92.43834659457207, 89.80256482958794, 101.4721642434597, 93.34861055016518, 102.25838005542755, 104.05541762709618, 107.75437474250793, 101.81522503495216, 107.29974433779716, 98.00905287265778, 88.56700792908669, 89.36438754200935, 93.49814772605896, 99.36066314578056, 94.50274541974068, 92.41815447807312, 91.13113313913345, 86.00860521197319, 87.01634153723717, 92.07988142967224, 88.58302026987076, 85.74077278375626, 91.90221816301346, 94.92142975330353, 89.73647877573967, 90.12595027685165, 102.54849448800087, 105.67061975598335, 100.97386658191681, 72.13407531380653, 72.08074137568474, 53.53623926639557, 59.31382544338703, 63.05895008146763, 78.59266474843025, 78.76237124204636, 80.46591863036156, 86.70581459999084, 76.70346692204475, 69.19141441583633, 68.42137053608894, 70.14959380030632, 78.70037376880646, 83.34513053297997, 76.50803580880165, 81.42421960830688, 87.36121863126755, 88.08678209781647, 82.45647221803665, 77.45015725493431, 76.1919155716896, 79.06291991472244, 83.00574794411659, 82.9709418118, 89.42969843745232, 91.10720202326775, 88.22542905807495, 87.61554658412933, 86.8084166944027, 88.25790971517563, 86.26101046800613, 77.89693728089333, 78.53412508964539, 82.81812161207199, 80.72712421417236, 73.80746752023697, 66.56012400984764, 79.09843280911446, 55.41296236217022, 6.425126055255532, 2.6280040573328733, 1.6215677373111248, 0.8347168250475079, 0.5917915259487927, 1.0321975126862526, 0.5049098411109298, 0.599349201656878, 0.41839409444946796, 0.16364572977181524, 2.2323011280968785, 32.37948752939701, 78.6843690276146, 115.82641839981079, 94.13427919149399, 76.43922910094261, 112.146817445755, 57.633889988064766, 28.816126137971878, 35.39538949728012, 52.92085848748684, 84.5443993806839, 73.38065922260284, 106.52856811881065, 50.91811515390873, 2.0708314049988985, 0.17192995321238413, 0.194747639761772, 0.2537133655278012, 0.1670043042395264, 0.10028749908087775, 0.19895048142643645, 0.34716581809334457, 0.22953809791943058, 0.1332643412752077, 0.17080427845939994, 0.11549315502634272, 0.19432091969065368, 0.1264364639064297, 0.23459950054530054, 0.1600079593481496, 0.12494750786572695, 0.11539226747117937, 0.09560690727084875, 0.14898892171913758, 0.16560241696424782, 0.20364701456855983, 0.11700073155225255], [0.06271138219744898, 0.07253986652358435, 0.02996712351887254, 0.05615629976091441, 0.08191961867851205, 0.038249831122811884, 0.06544149859109893, 0.03759728293516673, 0.09754009064636193, 0.007822861771273892, 0.0049501226840220625, 0.05634056018607225, 0.021665903041139245, 0.07426912256050855, 0.042552847880870104, 0.06078401725972071, 0.040712150948820636, 0.2237429635715671, 0.3645196947036311, 61.96789562702179, 100.4705759882927, 82.38303735852242, 78.96698266267776, 54.694143533706665, 53.3953770250082, 25.88089194148779, 52.24924832582474, 81.1280483007431, 122.94540479779243, 83.07971477508545, 67.41630926728249, 112.82372832298279, 116.73200860619545, 51.459050327539444, 0.9455508214887232, 0.004338868056947831, 0.28231959615368396, 0.08514606117387302, 0.34631938382517546, 0.8392993791494519, 0.5401647055987269, 0.7624344911891967, 3.360623507760465, 3.6552024632692337, 0.34768446057569236, 21.887957900762558, 109.96140271425247, 108.32573488354683, 105.26517391204834, 101.42608791589737, 101.91615521907806, 95.74258849024773, 93.0974668264389, 85.23363679647446, 76.44286170601845, 78.66390332579613, 80.10317489504814, 87.27668076753616, 88.25504466891289, 94.5088554918766, 94.06145229935646, 95.52755042910576, 98.82111489772797, 101.0261669754982, 102.97036305069923, 98.97612378001213, 96.1866782605648, 92.32151806354523, 82.75191396474838, 73.79279270768166, 75.94608396291733, 83.84901389479637, 80.43755695223808, 84.01768684387207, 72.38648056983948, 74.02831926941872, 69.75050121545792, 72.17689901590347, 71.04185432195663, 59.30860832333565, 70.8944146335125, 81.0181125998497, 73.00429701805115, 68.45378279685974, 61.41227424144745, 79.34412762522697, 85.51311939954758, 95.0442923605442, 61.20618090033531, 41.53185121715069, 33.920555636286736, 34.93483141064644, 60.77756009995937, 66.40896052122116, 68.99763241410255, 69.57036048173904, 70.47446116805077, 65.92414453625679, 60.694716945290565, 58.310333490371704, 60.597696751356125, 64.68321472406387, 65.27620330452919, 66.92896261811256, 66.61818489432335, 68.83139133453369, 70.49356654286385, 72.95962661504745, 73.23608458042145, 65.42840033769608, 67.63247206807137, 67.81933084130287, 65.03054648637772, 71.47030413150787, 80.56215986609459, 80.51910817623138, 75.3811226785183, 77.31056034564972, 79.28690269589424, 74.273132532835, 73.1471997499466, 73.9109055697918, 71.9283239543438, 69.34982791543007, 69.70035150647163, 69.78935793042183, 61.122953966259956, 52.903147637844086, 41.86875633895397, 6.747459908947349, 0.5711031798273325, 0.5926843592897058, 0.3938978776568547, 0.014465122440014966, 0.3997252805856988, 0.04476637754123658, 0.09763432113686576, 0.05964325835520867, 0.08004185147001408, 2.5117671070620418, 12.47191971167922, 43.07639613747597, 91.24731570482254, 89.14869591593742, 64.88065972924232, 71.92508652806282, 70.14270856976509, 25.70623241364956, 29.771945849061012, 30.387338027358055, 70.93061909079552, 64.49187219142914, 84.12632301449776, 35.73284178972244, 1.0312263085506856, 0.012724761090794345, 0.10586447911919095, 0.03838375167106278, 0.048111771466210485, 0.03351573788677342, 0.044632839199039154, 0.03218626567104366, 0.07035962960799225, 0.054790132053312846, 0.03579959346097894, 0.074411065725144, 0.024179859647119883, 0.04273659622413106, 0.030950459913583472, 0.06479958537966013, 0.04561106405162718, 0.04761489988595713, 0.03617304588260595, 0.06507063255412504, 0.06334530989988707, 0.0415830278507201, 0.05388313853472937, 0.07401868482702412, 0.03472077049082145, 0.039542058657389134, 0.072650914080441, 0.0879519285808783, 0.01824815342843067, 0.06226350349606946, 0.04715173665317707, 0.064744770352263, 0.051109228006680496, 0.07170229349867441, 0.011434098560130224, 0.039076947286957875, 0.029705952474614605, 0.019724082922039088, 0.051778251872747205, 0.07281664307811297, 0.2930357039440423, 79.14685741066933, 111.56759172677994, 95.94422087073326, 103.47411721944809, 81.19817733764648, 73.50055798888206, 28.98337036371231, 50.555929988622665, 35.33736661076546, 83.66043761372566, 92.84607991576195, 74.30772587656975, 119.57234859466553, 121.35392099618912, 55.90484216809273, 0.8882521523628384, 0.05624984005407896, 0.29516753798816353, 0.10280600690748543, 0.46369282936211675, 1.6342161898501217, 1.7988497181795537, 1.2432767800055444, 5.33792364411056, 2.668092381209135, 0.3970468993065879, 32.33699440956116, 118.25759634375572, 105.84204375743866, 104.94973003864288, 104.92929473519325, 105.63461288809776, 99.85383868217468, 93.74041512608528, 88.48043337464333, 78.88849407434464, 81.6949474811554, 85.13302579522133, 91.3563546538353, 94.26607891917229, 97.13759243488312, 97.39224717020988, 97.20976576209068, 100.59839352965355, 103.8684144616127, 104.30578619241714, 100.52259519696236, 97.64997214078903, 91.95719361305237, 84.25615444779396, 78.64075496792793, 81.52486860752106, 88.39520394802094, 89.22074005007744, 85.81453442573547, 80.04677832126617, 80.30527085065842, 74.41494852304459, 76.98824644088745, 79.44033086299896, 70.03840416669846, 73.35599854588509, 85.17914772033691, 77.70951613783836, 74.61623892188072, 71.43069505691528, 83.49364936351776, 94.3419000506401, 103.34229469299316, 74.16959568858147, 50.29914736747742, 44.68596696853638, 46.213481202721596, 69.02331903576851, 71.59018769860268, 75.72338551282883, 75.84273710846901, 78.62764567136765, 73.1337408721447, 71.10398858785629, 69.49561849236488, 68.5563924908638, 72.46687665581703, 71.11284971237183, 71.779805123806, 72.51775592565536, 74.89607110619545, 74.34966042637825, 75.93189552426338, 78.83484855294228, 76.34408220648766, 72.42552727460861, 74.25110891461372, 72.3702934384346, 76.33601143956184, 84.074045419693, 85.97015887498856, 81.86648547649384, 83.86021569371223, 84.89167034626007, 82.37228393554688, 80.1839129626751, 81.54332041740417, 79.16090905666351, 79.12075281143188, 80.94972386956215, 84.4286347925663, 74.71880301833153, 65.6700673699379, 62.76380091905594, 15.937059223651886, 0.8810038038063794, 0.4661978152580559, 0.6162049190606922, 0.05409424615208991, 0.5363786243833601, 0.09400458075106144, 0.08965989982243627, 0.011028705030184938, 0.1527281288872473, 2.214847239665687, 16.75162721425295, 52.45575964450836, 103.2794688642025, 97.29697108268738, 71.47303238511086, 35.410159304738045, 17.290111519396305, 21.22177194803953, 46.610236912965775, 44.286388009786606, 89.87450256943703, 70.05120187997818, 90.62415674328804, 50.89548356831074, 0.9369826968759298, 0.1081967078789603, 0.08363836590433493, 0.01296004231335246, 0.030921197030693293, 0.03111324072960997, 0.019437728951743338, 0.049662181045277975, 0.1515364326769486, 0.07089617269230075, 0.012350652796158101, 0.06893825353472494, 0.05275371964671649, 0.013869188060198212, 0.02632630286825588, 0.03164502850268036, 0.04673480550991371, 0.016255145528702997, 0.02884933965106029, 0.014702769258292392, 0.008333301666425541, 0.05928138714807574, 0.16329892416251823, 0.26240810053423047, 0.1031665199843701, 0.1343778448062949, 0.40780777344480157, 0.16061849455581978, 0.1472387445392087, 0.26138755842112005, 0.1849933702033013, 0.16127611161209643, 0.16538277093786746, 0.23974228708539158, 0.14603434276068583, 0.1362291321856901, 0.13345210463739932, 0.2396456743008457, 0.19762641575653106, 0.3886432939907536, 1.2031821627169847, 96.07956200838089, 125.65310910344124, 105.35228043794632, 102.83845692873001, 69.67051550745964, 65.183594673872, 37.73422859609127, 71.97607219219208, 109.98459666967392, 143.92667055130005, 99.85230356454849, 87.28838413953781, 133.92601758241653, 133.035968542099, 73.10078144073486, 1.3354992563836277, 0.1439092622604221, 0.46816967194899917, 0.18035834626061842, 0.7778356585185975, 2.760060983709991, 1.6413136152550578, 1.6546744108200073, 14.846773277968168, 12.514778561890125, 1.3741315458901227, 30.26146598160267, 122.84534856677055, 114.87480506300926, 112.17204049229622, 111.91053852438927, 109.07125487923622, 106.75433680415154, 99.05205890536308, 95.38663119077682, 81.74017265439034, 86.0630638897419, 86.40911892056465, 96.20936304330826, 94.60959568619728, 101.17270231246948, 97.86050364375114, 100.47492295503616, 103.45058128237724, 106.59976869821548, 108.61711844801903, 105.89026317000389, 100.94640925526619, 97.7940908074379, 88.80014061927795, 81.70829996466637, 84.07638609409332, 92.32103168964386, 91.5242600440979, 94.82200428843498, 86.16115942597389, 89.62550953030586, 85.562364757061, 85.02998292446136, 87.06758558750153, 77.36333951354027, 84.63576927781105, 92.89796233177185, 85.61757579445839, 80.76554775238037, 74.369335770607, 89.61458891630173, 103.47736224532127, 116.17752715945244, 75.36462396383286, 53.013698905706406, 48.006756976246834, 50.976335629820824, 81.25428512692451, 79.703618735075, 79.6953883767128, 81.34484186768532, 85.6334437429905, 81.78389310836792, 74.62225779891014, 72.09389626979828, 74.26634609699249, 79.57909181714058, 75.71799740195274, 77.72208586335182, 77.16771081089973, 81.43270835280418, 83.06179493665695, 85.86221426725388, 83.53129014372826, 77.26241692900658, 79.41624775528908, 79.18152675032616, 78.1687518954277, 79.72932815551758, 88.5303170979023, 87.20557138323784, 84.03092533349991, 85.51354497671127, 85.82635179162025, 84.29219171404839, 82.34481140971184, 84.34605002403259, 82.25948318839073, 77.6888832449913, 83.81771117448807, 85.784972012043, 74.04611751437187, 73.11638340353966, 77.31006637215614, 18.05782802402973, 1.5288880979642272, 2.168872319161892, 1.8794569303281605, 0.1379957256722264, 1.064763308968395, 0.39119536173529923, 0.2441809535957873, 0.15119078481802717, 0.33132791169919074, 5.991965923458338, 31.26871593296528, 69.96699839830399, 113.77322137355804, 109.38642516732216, 85.32892048358917, 105.9631660580635, 89.51762571930885, 31.60486489534378, 36.596398651599884, 38.07663582265377, 90.7332792878151, 79.59625169634819, 105.81885740160942, 68.61177071928978, 2.030095928348601, 0.11901417819899507, 0.32211049692705274, 0.10763433805550449, 0.15515927108936012, 0.12049526005284861, 0.10322771006030962, 0.34404081234242767, 0.1854710461338982, 0.2023027031100355, 0.24675598338944837, 0.12444480671547353, 0.16740671155275777, 0.11721815855707973, 0.11420201844885014, 0.20668422424932942, 0.1402577621047385, 0.09849871537880972, 0.12933919642819092, 0.1394524725037627, 0.18554530543042347, 0.16165405773790553], [0.03242370468797162, 0.04371026428998448, 0.02992188405187335, 0.05744092028180603, 0.039486894820583984, 0.026724101444415282, 0.03019865689566359, 0.024541383900213987, 0.06511984436656348, 0.0472435996925924, 0.030657244788017124, 0.07062133314320818, 0.060869868902955204, 0.03816574208030943, 0.135514072899241, 0.04464812373043969, 0.15983713179593906, 0.436356621212326, 18.639012537896633, 103.09135615825653, 95.45427516102791, 84.03041616082191, 67.01966375112534, 72.07540646195412, 59.16765108704567, 155.96588373184204, 123.15913572907448, 83.68005976080894, 77.0789247751236, 82.29623481631279, 119.40060541033745, 116.86666578054428, 56.086119040846825, 0.31887075514532626, 0.09319030374172144, 0.3179308696417138, 0.2143315810826607, 0.44588846911210567, 0.6706281518563628, 0.2598130772821605, 0.10623628026223741, 2.4708813009783626, 4.631157768890262, 1.6368106193840504, 8.036157432943583, 102.9452995955944, 95.96223950386047, 99.87327083945274, 98.43730509281158, 95.85179463028908, 91.46087184548378, 88.22055771946907, 80.23964837193489, 78.66680637001991, 77.50197127461433, 84.74860042333603, 89.31752845644951, 95.87647810578346, 94.63459834456444, 97.94743537902832, 97.65716135501862, 98.20047900080681, 95.84765285253525, 96.60062804818153, 92.92686358094215, 90.53717941045761, 84.68566060066223, 77.24454268813133, 72.96145811676979, 75.91566279530525, 77.04477220773697, 84.79778498411179, 87.30049788951874, 71.36843919754028, 67.81718015670776, 68.95012736320496, 64.4135507941246, 70.36354511976242, 70.4819543659687, 68.27223613858223, 59.72547635436058, 75.15708670020103, 70.40928706526756, 64.57831755280495, 73.39226379990578, 89.41543400287628, 82.89002135396004, 90.96905663609505, 78.26440796256065, 36.661245971918106, 35.547020360827446, 55.572766587138176, 63.445275351405144, 63.2102769613266, 74.83889177441597, 75.00036031007767, 77.34342098236084, 71.89113155007362, 66.04110985994339, 63.214775919914246, 64.28846150636673, 64.47199925780296, 70.64588516950607, 65.07194146513939, 70.58813586831093, 68.82286459207535, 70.2354995906353, 65.85055008530617, 69.63081523776054, 68.59527960419655, 63.73465642333031, 58.152577355504036, 60.414831563830376, 71.96043223142624, 73.95175337791443, 81.8200595676899, 81.42313286662102, 81.1022324860096, 79.8575484752655, 78.23379680514336, 75.58910071849823, 75.59932976961136, 71.94353073835373, 77.05351933836937, 70.94260364770889, 68.4277617931366, 72.75470361113548, 65.72125062346458, 53.53988327085972, 47.21106447279453, 7.762813400477171, 1.0156248207204044, 0.25372176663950086, 0.19245790637796745, 0.1383118360536173, 0.05573592505243141, 0.16776675707660615, 0.11433772757300176, 0.08429136680206284, 0.365556682809256, 6.8867328856140375, 11.933211218565702, 44.883563965559006, 86.54050067067146, 86.29688814282417, 74.98540431261063, 87.15938866138458, 91.25833511352539, 40.13728424906731, 29.176021926105022, 34.44012075662613, 55.405773147940636, 58.157790675759315, 72.7247004210949, 23.742915764451027, 1.2099390313960612, 0.08499380215653218, 0.04634242461179383, 0.10750797999207862, 0.04557485466648359, 0.05183273664442822, 0.05437826977868099, 0.019882550004695076, 0.0747482679435052, 0.018384936811344232, 0.05213632699451409, 0.019760294162551872, 0.05172253142518457, 0.05445693001092877, 0.09496609985944815, 0.08677713107317686, 0.02714233320148196, 0.02486047214915743, 0.03582928307878319, 0.034007407011813484, 0.09834779222728685, 0.04979887722583953, 0.028764250564563554, 0.026166854295297526, 0.05471900833072141, 0.027111010858789086, 0.04726049839518964, 0.0509381035953993, 0.05194863413635176, 0.01409407086612191, 0.015858601182117127, 0.04241257825924549, 0.02556091483711498, 0.009098104328586487, 0.02933440922788577, 0.016199050296563655, 0.06395347023499198, 0.12392953358357772, 0.7092334271874279, 26.141400262713432, 115.36778301000595, 111.86247870326042, 103.56516793370247, 82.53630593419075, 75.57044371962547, 56.282842084765434, 98.64652946591377, 62.64833651483059, 60.812009051442146, 77.72877350449562, 88.349978774786, 120.25351524353027, 125.90949654579163, 64.22752037644386, 0.22193506214534864, 0.1318649179302156, 0.36908019217662513, 0.3451039834180847, 0.3316729806829244, 0.545856918906793, 1.2840440799482167, 1.6372660011984408, 4.186619622632861, 6.1377232521772385, 1.037059233058244, 13.961291592568159, 112.14907452464104, 97.4096730351448, 105.08673548698425, 102.87158355116844, 100.34844294190407, 94.4277374446392, 92.14835375547409, 85.31566679477692, 81.89443677663803, 79.87513393163681, 89.18276488780975, 94.32921633124352, 101.14564776420593, 98.57659801840782, 100.1578451693058, 99.56130757927895, 98.6164502799511, 99.13794949650764, 97.32437521219254, 94.58742007613182, 92.13955342769623, 85.68051561713219, 77.76490956544876, 76.89197480678558, 80.04781946539879, 80.74550002813339, 89.02574211359024, 92.79989719390869, 80.9104111790657, 76.680006980896, 80.01159220933914, 75.05395263433456, 80.78754857182503, 76.70653715729713, 75.05057081580162, 69.30623665452003, 80.13737305998802, 77.39806205034256, 71.264438778162, 76.67021870613098, 92.05072939395905, 90.95609933137894, 96.22673571109772, 87.13795021176338, 47.646179124712944, 45.0080680847168, 64.71363589167595, 70.21790653467178, 71.23580351471901, 79.77344378829002, 79.78013142943382, 81.10979408025742, 74.96566817164421, 70.71954801678658, 71.047143638134, 67.7047061920166, 70.67297011613846, 75.78686490654945, 71.04588210582733, 76.05561688542366, 73.29630374908447, 75.76518326997757, 72.54104107618332, 74.31698217988014, 74.52842563390732, 73.22869777679443, 67.28169769048691, 67.61631533503532, 75.83437755703926, 77.66708001494408, 83.45649495720863, 84.52194258570671, 85.27215912938118, 83.66622850298882, 83.39673936367035, 80.94818115234375, 81.73179030418396, 78.39466497302055, 83.46312180161476, 80.99105805158615, 78.98431733250618, 86.05997085571289, 79.96925488114357, 64.91174206137657, 66.16525679826736, 15.223039537668228, 0.8659124979749322, 0.4747522546676919, 1.1243742727674544, 1.247394452802837, 0.08834948224830441, 0.15640386758605018, 0.0934966845670715, 0.08197446339181624, 0.21947536210063845, 8.237773664295673, 13.724058922380209, 53.78007598221302, 95.26163309812546, 96.16065725684166, 82.36400797963142, 68.49969193339348, 32.42198444902897, 29.800161235034466, 50.43047972023487, 55.858431458473206, 80.58616697788239, 68.93397063016891, 84.40225660800934, 33.866427540779114, 1.172307156957686, 0.11720456983312033, 0.0979241965978872, 0.07912964807474054, 0.012354896025499329, 0.0984471509582363, 0.0322862255416112, 0.05796587844088208, 0.032094847920234315, 0.011999730122624896, 0.017968677311728243, 0.08330965385539457, 0.07221418985864148, 0.10431849645101465, 0.08350146192242391, 0.04294546626624651, 0.012379244035400916, 0.05413311984739266, 0.03725527902133763, 0.018989607196999714, 0.061771255495841615, 0.19652241171570495, 0.1450724303140305, 0.14233040245017037, 0.15679585514590144, 0.10249199680401944, 0.10713531053625047, 0.11272676245425828, 0.2105119251064025, 0.1665159413823858, 0.1662476995261386, 0.1251307738129981, 0.15711088199168444, 0.19475014822091907, 0.19039890670683235, 0.3265871910843998, 0.16982182336505502, 0.2671865519369021, 0.9270420740358531, 37.126371413469315, 133.9335411787033, 118.12789410352707, 105.10815113782883, 83.0016441643238, 91.44143208861351, 76.13578498363495, 172.05704748630524, 136.43368542194366, 115.86736500263214, 99.36450093984604, 101.99151277542114, 140.1574096083641, 134.91276383399963, 82.11145833134651, 0.6567488622386009, 0.25059373292606324, 0.45840196951758116, 0.5667210649698973, 0.9239353251177818, 2.339137145318091, 0.7747522427234799, 1.1736286547966301, 6.410370497033, 10.586070455610752, 2.713982043787837, 12.770160008221865, 117.23981335759163, 102.475546002388, 110.81447213888168, 107.57208332419395, 103.64366412162781, 99.53385025262833, 98.85918885469437, 90.30166804790497, 87.79044359922409, 84.72342297434807, 92.65139356255531, 95.83753779530525, 103.22305709123611, 101.47907227277756, 101.09910026192665, 103.59401598572731, 100.8637560904026, 101.6750505566597, 101.00991904735565, 99.15879517793655, 99.37640190124512, 90.09036138653755, 82.14438736438751, 80.68894386291504, 84.30465504527092, 83.39053809642792, 94.52705651521683, 93.99164244532585, 84.36431184411049, 80.97203627228737, 81.62664234638214, 75.89483231306076, 85.47547861933708, 80.7148052752018, 81.89716503024101, 74.54357162117958, 87.63986527919769, 83.09149414300919, 80.51109820604324, 80.98911255598068, 99.64634701609612, 99.89746034145355, 109.42019015550613, 91.19053155183792, 47.957887798547745, 46.469260677695274, 68.83580669760704, 78.45162391662598, 75.77906012535095, 84.67432200908661, 86.89069747924805, 87.23403185606003, 83.14566403627396, 78.85497227311134, 71.03904247283936, 79.67113047838211, 75.90691566467285, 79.92759391665459, 75.85700154304504, 83.20657476782799, 78.08159977197647, 80.43935045599937, 78.05240213871002, 84.36738207936287, 80.49833849072456, 80.71344494819641, 76.22101441025734, 75.92979043722153, 84.13932591676712, 80.59830352663994, 90.21436393260956, 89.54278036952019, 87.98649027943611, 88.82861629128456, 87.36862063407898, 82.80980005860329, 84.42003965377808, 79.52706500887871, 88.00924345850945, 82.63938680291176, 81.3317933678627, 87.28690221905708, 80.86615115404129, 67.8926745057106, 81.63686379790306, 17.773646973073483, 1.8026938056573272, 1.4111245796084404, 0.6371430424042046, 0.4203109134687111, 0.3817089629592374, 0.40466172038577497, 0.27236944413743913, 0.11202727342606522, 0.7550999941304326, 15.741203483194113, 31.390111818909645, 69.54101845622063, 101.92806378006935, 105.54081112146378, 96.73894822597504, 126.48243740200996, 118.42912673950195, 49.76896561682224, 38.121898993849754, 44.74113240838051, 77.60224789381027, 75.15299811959267, 94.42208334803581, 55.24648189544678, 1.9588080723769963, 0.1684881839901209, 0.17374772520270199, 0.16452048439532518, 0.13301459373906255, 0.21894797711865976, 0.1311833443469368, 0.13872350536985323, 0.31403765198774636, 0.08128360554110259, 0.09954019347787835, 0.17261832486838102, 0.19140830176183954, 0.16555667098145932, 0.17864030407508835, 0.20365663280244917, 0.08361405314644799, 0.1556784033891745, 0.18439231964293867, 0.10253419532091357, 0.23095999349607155], [0.04617776801751461, 0.06485012563643977, 0.060304734579403885, 0.03206507666618563, 0.0755565483996179, 0.04995162977138534, 0.051913563947891816, 0.013081071756460005, 0.08341471228050068, 0.07826003653462976, 0.018176113153458573, 0.04659976802940946, 0.0866058211249765, 0.04969261652149726, 0.05312530556693673, 0.06491320818895474, 0.0637571795959957, 0.7799858087673783, 59.58626702427864, 96.47619992494583, 63.769941329956055, 75.03322094678879, 42.353161945939064, 44.61098179221153, 44.02760669589043, 93.44713926315308, 148.87712091207504, 65.29177486896515, 93.67316633462906, 115.14537334442139, 114.12002116441727, 51.901016011834145, 0.5375297251157463, 0.06164785489090718, 0.09414908432518132, 0.044294397594057955, 0.1560695597436279, 0.72805589530617, 0.2075286695617251, 0.9121832682285458, 1.9284288212656975, 2.80657927505672, 2.163756606169045, 1.5859980834648013, 74.78586181998253, 109.20173987746239, 100.06513014435768, 98.49766105413437, 83.97785738110542, 82.05677166581154, 77.07740485668182, 75.61867833137512, 76.95722490549088, 77.77826964855194, 84.52951937913895, 90.51923677325249, 96.33540228009224, 96.89290836453438, 95.85070788860321, 96.86447069048882, 95.676449239254, 92.76061490178108, 89.44224536418915, 88.27151298522949, 87.64899238944054, 79.0805433690548, 75.05239471793175, 71.35054215788841, 71.0298165678978, 73.94014120101929, 81.62924140691757, 83.96237701177597, 87.6710008084774, 81.35440215468407, 75.78548938035965, 83.34377780556679, 80.09170711040497, 84.2409248650074, 76.48669615387917, 75.43348386883736, 72.8048837184906, 71.97587460279465, 68.2486242055893, 61.30011186003685, 62.162137404084206, 70.98179474473, 69.86926764249802, 70.42727530002594, 66.36129587888718, 67.12175667285919, 53.69131654500961, 64.89820718765259, 71.71526178717613, 74.6525801718235, 79.07811149954796, 74.90785047411919, 76.32035627961159, 70.86561977863312, 64.41571667790413, 58.12838405370712, 52.77267023921013, 64.9421176314354, 68.33934813737869, 68.16189005970955, 69.07721534371376, 65.46081259846687, 70.3486879169941, 67.69232645630836, 67.34046533703804, 66.47621691226959, 63.4491815418005, 56.41004405915737, 51.31027311086655, 59.01211403310299, 73.34111854434013, 70.95527216792107, 77.4788761138916, 77.78122588992119, 78.61828297376633, 78.1284436583519, 77.6236179471016, 78.32403436303139, 76.97125375270844, 72.55592107772827, 70.75021237134933, 73.25547873973846, 71.2324520945549, 68.07007178664207, 63.52702036499977, 54.020321890711784, 36.32222056388855, 2.862160080112517, 1.3698314828798175, 0.6245426216628402, 0.2930859028128907, 0.16116177634103224, 0.26169857766944915, 0.12739459139993414, 0.06825765216490254, 0.1060832865186967, 2.40155853331089, 3.0088583333417773, 18.59938446432352, 44.017761424183846, 79.34563234448433, 89.4569505751133, 61.55369505286217, 71.94163084030151, 82.2656312584877, 23.500920049846172, 21.62291642278433, 24.187039732933044, 56.60037204623222, 66.15925312042236, 67.3723304271698, 21.540096066892147, 1.5020774491131306, 0.09129410900641233, 0.19754736218601465, 0.03939845679269638, 0.015365568360721227, 0.06622758141020313, 0.12374790778267197, 0.07148195727495477, 0.07915226873592474, 0.026008990207628813, 0.029573536630778108, 0.014870916729705641, 0.01987487619771855, 0.050685450551100075, 0.09562404346070252, 0.017146522404800635, 0.01641597078560153, 0.0487240692746127, 0.028391082014422864, 0.013086436556477565, 0.013395311925705755, 0.059190967585891485, 0.07903235993580893, 0.060523990978254005, 0.07809178423485719, 0.0115438779721444, 0.03256817486544605, 0.021867368304810952, 0.026618276751833037, 0.01927739351231139, 0.021848354481335264, 0.06208600403624587, 0.1051126018865034, 0.028420242852007505, 0.0071583441331313225, 0.10939272338873707, 0.20531257207039744, 1.1123637109994888, 74.01070341467857, 105.16753435134888, 82.95183643698692, 81.76100313663483, 63.07250015437603, 63.378509134054184, 46.45520523190498, 100.19141256809235, 123.26503604650497, 61.88669018447399, 100.93390792608261, 122.42195248603821, 123.7631057202816, 64.93896380066872, 0.22731150645995513, 0.18019813142018393, 0.1697741329553537, 0.16567111015319824, 0.09525675457553007, 1.3230038643814623, 0.7532183232251555, 1.806516875512898, 2.754438235424459, 3.0396122206002474, 1.102061157580465, 2.769807460717857, 85.31772628426552, 110.86034327745438, 105.31931340694427, 101.21818587183952, 84.6474726498127, 82.41986498236656, 81.47835150361061, 80.98909735679626, 80.27158185839653, 83.07475224137306, 88.34837526082993, 95.02786204218864, 100.30719235539436, 98.72217580676079, 97.73290649056435, 100.06186231970787, 97.02357575297356, 93.64686414599419, 89.8295433819294, 89.70763072371483, 90.5195939540863, 82.67376735806465, 77.61270493268967, 73.00531536340714, 72.87083297967911, 79.31674629449844, 84.77924957871437, 88.98132249712944, 91.87701031565666, 84.60904151201248, 82.4979355931282, 84.89333465695381, 82.2305591404438, 87.10989251732826, 80.75595706701279, 81.68939217925072, 79.47059243917465, 78.44124287366867, 74.22499671578407, 66.62179470062256, 71.42285227775574, 78.98326858878136, 81.10559150576591, 79.38509702682495, 70.8816397190094, 72.48054072260857, 60.38936913013458, 68.325714468956, 72.94734567403793, 77.88353160023689, 81.39335006475449, 81.44529327750206, 79.80414614081383, 75.39634466171265, 69.59848657250404, 67.15695038437843, 59.58542346954346, 72.36100673675537, 71.41125530004501, 73.75704422593117, 73.56930390000343, 70.84936425089836, 73.47841277718544, 71.3233508169651, 73.1488336622715, 74.53863188624382, 71.68878480792046, 66.60578235983849, 62.06680051982403, 63.543652072548866, 76.85847580432892, 75.99405258893967, 79.1486357152462, 81.3111224770546, 83.05091232061386, 82.66191959381104, 83.13426464796066, 81.72156885266304, 82.72834002971649, 79.9952606856823, 77.70545035600662, 80.64323991537094, 81.21264696121216, 81.64756402373314, 80.47343462705612, 63.82733345031738, 55.08043460547924, 5.231018280610442, 0.9588519483804703, 0.44371308584231883, 0.44637938495725393, 0.4406699538230896, 0.5025473178829998, 0.1381254827720113, 0.05261704201984685, 0.2860870643053204, 0.8979131933301687, 2.609393843449652, 19.23734363168478, 53.70743528008461, 87.6758037507534, 94.33075904846191, 71.9649387896061, 67.14948758482933, 34.590448290109634, 22.01603002846241, 38.489552065730095, 38.95625822246075, 70.94150170683861, 73.738372027874, 79.44398626685143, 30.448049269616604, 0.7181929901707917, 0.15469556237803772, 0.12486498104408383, 0.022948469668335747, 0.010326992342015728, 0.04960741425747983, 0.029200288299762178, 0.07667648635106161, 0.009742558468133211, 0.026445886978763156, 0.008358329669135856, 0.06734974580467679, 0.11546922818524763, 0.0486150032520527, 0.021320539053704124, 0.03667192126158625, 0.008941091855376726, 0.06637424463406205, 0.022792648342147004, 0.030424757751461584, 0.09597159121767618, 0.21593690587906167, 0.1568666411913, 0.12920964712975547, 0.15547156683169305, 0.1454513263888657, 0.22368166217347607, 0.33807599334977567, 0.1956590119516477, 0.1958904432831332, 0.06469307976658456, 0.16881098854355514, 0.3009169263532385, 0.1766293658874929, 0.15537761093582958, 0.2067197285941802, 0.5615298904012889, 1.9159384164959192, 91.77712127566338, 120.59703201055527, 86.28646150231361, 96.15223690867424, 62.96070255339146, 59.03557777404785, 58.785254806280136, 99.4452466070652, 169.26042795181274, 85.52076458930969, 116.18287727236748, 135.491381585598, 137.37770676612854, 78.63701596856117, 1.7961396323516965, 0.28693213302176446, 0.18252566980663687, 0.29477829637471586, 0.7650050532538444, 3.175663920119405, 1.13352928776294, 2.9150104941800237, 5.880518378689885, 9.339428599923849, 5.231431983411312, 3.3036909252405167, 87.25565269589424, 117.56946846842766, 113.83662477135658, 107.7735485136509, 91.91030412912369, 88.21849063038826, 85.71434140205383, 84.84321534633636, 84.46882903575897, 85.81334128975868, 94.08685013651848, 98.56327593326569, 105.6379035115242, 100.93088328838348, 104.0087865293026, 103.61413210630417, 100.04269614815712, 99.96508151292801, 94.11794006824493, 93.85278269648552, 94.36843782663345, 87.61984035372734, 82.04888328909874, 75.37047564983368, 75.43971553444862, 83.2987730205059, 89.02676805853844, 92.62528136372566, 96.56796500086784, 87.63500913977623, 87.62718915939331, 91.4595115184784, 88.37675973773003, 94.16512593626976, 84.54961270093918, 87.75277242064476, 87.03337222337723, 86.96408674120903, 83.06489557027817, 75.80204889178276, 81.32709681987762, 86.46751418709755, 89.69800963997841, 87.33775109052658, 81.04275047779083, 75.31525701284409, 63.61072227358818, 73.39458927512169, 79.82214197516441, 82.40604132413864, 82.50258654356003, 82.91155859827995, 83.29118862748146, 82.83430114388466, 75.91672673821449, 71.99808821082115, 64.45511296391487, 75.1043151319027, 79.05280485749245, 81.5417928993702, 81.3271576166153, 74.69908207654953, 79.55699980258942, 75.55855795741081, 77.77217477560043, 80.77837586402893, 79.92217540740967, 73.30185905098915, 70.10150358080864, 74.43551301956177, 83.75676244497299, 80.60011222958565, 84.07798200845718, 86.06288149952888, 87.22264766693115, 86.32287114858627, 89.18673947453499, 85.21372586488724, 83.24756696820259, 83.09385761618614, 80.00294387340546, 83.67851704359055, 79.96251404285431, 81.71729788184166, 80.8267092704773, 67.88578927516937, 68.91818627715111, 5.55963272228837, 2.788899536244571, 3.2458444917574525, 0.269517904962413, 0.678682888392359, 0.7305423868820071, 0.36982144927605987, 0.2109994864440523, 0.5205363244749606, 4.265567511320114, 9.876551628112793, 36.628248542547226, 73.76372426748276, 95.00371813774109, 106.42832949757576, 77.98569291830063, 103.45165282487869, 105.90499117970467, 30.10896496474743, 28.736417815089226, 34.01473358273506, 76.96072071790695, 83.9893327653408, 91.63999423384666, 50.67926377058029, 2.017533564940095, 0.18896605703048408, 0.3508089913520962, 0.10066775328596123, 0.08293394901556894, 0.12501357385190204, 0.2144951355876401, 0.17549184645758942, 0.18203634215751663, 0.09804360073758289, 0.20279645395930856, 0.19531743106199428, 0.21994061447912827, 0.1259855943499133, 0.19028072711080313, 0.122173790296074, 0.13567062153015286, 0.10525047808187082, 0.17075541545636952, 0.07915035399491899], [0.025863926312013064, 0.009579881552781444, 0.046841682196827605, 0.03227871500712354, 0.03412589088839013, 0.07129567078663968, 0.1423327624797821, 0.003658993528006249, 0.0649456845712848, 0.028425966665963642, 0.0240655002562562, 0.07240619830554351, 0.04234411884681322, 0.05033396570070181, 0.047222355715348385, 0.12483615602832288, 0.22061071445932612, 15.150418784469366, 102.33828216791153, 82.94017106294632, 86.44824162125587, 68.02391186356544, 85.30190393328667, 41.496399119496346, 29.424103014171124, 30.272561386227608, 47.21209041774273, 104.92669567465782, 112.09089204668999, 101.47224023938179, 51.24842382967472, 2.182117933407426, 0.1161321738618426, 0.18185850873123854, 0.11351709035807289, 0.048497944299015217, 0.3360736195463687, 0.21248158504022285, 0.42366025561932474, 2.4137713154777884, 2.7191687654703856, 1.5022261161357164, 1.1780906841158867, 26.53448347002268, 101.80326327681541, 103.4433464705944, 95.47735512256622, 82.85057947039604, 75.42414397001266, 80.39955139160156, 75.5355615913868, 79.20872569084167, 84.5441409945488, 89.96990025043488, 91.15111246705055, 94.24309775233269, 92.02392563223839, 96.41467362642288, 95.03750592470169, 93.65946426987648, 87.9918783903122, 82.26059272885323, 81.22766375541687, 77.91755497455597, 73.8663187623024, 71.31386652588844, 71.4614050090313, 72.45242223143578, 69.79385688900948, 79.33199107646942, 84.96047705411911, 86.5859006345272, 87.37118929624557, 76.50754183530807, 80.1219230890274, 78.64371120929718, 77.18832090497017, 79.31129738688469, 79.4380509853363, 75.978564620018, 68.40077564120293, 70.07200956344604, 67.79027000069618, 66.84991925954819, 61.50677517056465, 62.941809967160225, 64.02193620800972, 71.32543310523033, 48.9093529433012, 67.14995875954628, 80.6789579987526, 65.01264944672585, 63.070600256323814, 67.73169994354248, 79.59062039852142, 79.26984161138535, 79.84366402029991, 69.36387196183205, 69.40741762518883, 46.76211856305599, 46.26311033964157, 68.30086380243301, 61.82336278259754, 63.8208281993866, 66.63499519228935, 71.41117170453072, 71.72452569007874, 69.29448768496513, 67.21391692757607, 69.42580103874207, 65.58533951640129, 58.39372381567955, 51.80767402052879, 46.47562153637409, 59.40970949828625, 67.42752626538277, 69.5066075026989, 73.05255442857742, 74.2837643623352, 76.52406334877014, 73.54825302958488, 77.22494333982468, 76.79915338754654, 75.94432845711708, 69.49350580573082, 69.25476461648941, 75.952840000391, 75.73531687259674, 70.76498597860336, 59.05606247484684, 59.271244928240776, 17.2395571321249, 0.2380012086359784, 4.461291208863258, 9.98799204826355, 0.32372048241086304, 0.23663552332436666, 0.1040799479233101, 0.22216760669834912, 0.1204187743132934, 0.3702435235027224, 0.6517681607510895, 2.7442944422364235, 10.19638141617179, 32.202721014618874, 75.04860252141953, 89.55468133091927, 68.9204129576683, 78.70766177773476, 103.24279323220253, 36.57263092696667, 30.532250851392746, 36.44167475402355, 56.15823537111282, 64.17509838938713, 68.86720821261406, 27.497518993914127, 0.7897936168592423, 0.10426964829093777, 0.06422975697205402, 0.01863304976723157, 0.021091573507874273, 0.04362937019322999, 0.0151436133273819, 0.09027439809869975, 0.03850820241495967, 0.008166634779627202, 0.03254939481848851, 0.002854287208720052, 0.031737021417939104, 0.08863438531989232, 0.08318021587911062, 0.037000651864218526, 0.07328456718823873, 0.0486212001851527, 0.04109027890081052, 0.0020697448098871973, 0.04388880275655538, 0.04455480979231652, 0.033927997210412286, 0.04039227787870914, 0.01047065914463019, 0.057585290269344114, 0.011132198451377917, 0.02690916709980229, 0.06510177307063714, 0.03722974914126098, 0.06468455991125666, 0.03868309693643823, 0.12103983317501843, 0.08234371154685505, 0.1529674863559194, 0.6143371411599219, 20.56130848824978, 114.84736293554306, 92.29712337255478, 86.20383873581886, 80.72686582803726, 90.59508070349693, 49.76057946681976, 31.667641326785088, 24.036740697920322, 60.2344324439764, 108.32191228866577, 120.1854456961155, 111.69642761349678, 65.4816734790802, 1.9597067241556942, 0.14075857819989324, 0.17001414351398125, 0.25049351330380887, 0.281748587731272, 0.49431084422394633, 0.5036314472090453, 1.2682073609903455, 3.1967665627598763, 2.2089105332270265, 0.625279841478914, 1.3553008250892162, 35.189398750662804, 107.44078516960144, 105.56777447462082, 95.70679441094398, 86.88243672251701, 80.65378054976463, 82.28973716497421, 79.14200127124786, 83.02752077579498, 89.33223366737366, 91.82526469230652, 96.09321847558022, 97.49482646584511, 94.3477289378643, 97.15722978115082, 98.3753228187561, 96.52720838785172, 91.5108847618103, 86.70919641852379, 83.75075116753578, 80.1992717385292, 78.18294033408165, 74.59729313850403, 74.33328330516815, 76.16782486438751, 74.89634469151497, 83.58491286635399, 86.32785648107529, 93.22096019983292, 88.70141431689262, 81.97316855192184, 83.66699606180191, 82.33725741505623, 83.89733970165253, 87.08197921514511, 83.88812139630318, 81.72706335783005, 75.96562251448631, 75.96322864294052, 74.2722737789154, 74.21194061636925, 68.28341513872147, 68.24668630957603, 71.33408144116402, 77.02402532100677, 58.6100310087204, 70.9589047729969, 87.66489073634148, 68.1522385776043, 67.01964095234871, 72.16243699193001, 82.77486473321915, 82.15868979692459, 81.77246332168579, 74.83953014016151, 74.02535542845726, 54.46451045572758, 55.19898444414139, 72.42789834737778, 68.27269971370697, 71.59439027309418, 72.88423106074333, 75.92137768864632, 75.77512353658676, 73.1469413638115, 71.39420941472054, 73.5881432890892, 71.8074980378151, 67.70263150334358, 62.58165389299393, 57.19559110701084, 64.3842163681984, 72.68626168370247, 71.75036430358887, 76.98694691061974, 78.12247797846794, 77.65893325209618, 78.08751985430717, 82.29542165994644, 81.92924290895462, 81.16815894842148, 75.28461545705795, 75.53688392043114, 83.44523996114731, 86.89350172877312, 83.49293500185013, 73.047736287117, 70.50392478704453, 32.44160659611225, 0.44304129376541823, 1.7740281438454986, 5.360197573900223, 0.17669301247224212, 0.1960729670827277, 0.1663021434796974, 0.134058810363058, 0.044167293672217056, 0.3800081682857126, 0.35157450183760375, 1.839282161090523, 7.692887652665377, 38.441298454999924, 84.72504168748856, 96.10430628061295, 77.78438732028008, 61.61424480378628, 37.655873000621796, 29.57436215132475, 51.28364033997059, 57.10622750222683, 73.57265532016754, 72.37788543105125, 79.44766446948051, 32.785792127251625, 0.5344788450747728, 0.15243351110257208, 0.09201681241393089, 0.0425864226417616, 0.05699606583220884, 0.09866704931482673, 0.013052804279141128, 0.09589600347680971, 0.06519446731545031, 0.03424955495574977, 0.07761387081700377, 0.00948248209169833, 0.03916052795830183, 0.006521846280520549, 0.08846331285894848, 0.032883301901165396, 0.11513235993334092, 0.02462192547682207, 0.04343323911598418, 0.14404289337107912, 0.09935316484188661, 0.1333398325368762, 0.12379005434922874, 0.13971609820146114, 0.15607395325787365, 0.24591017252532765, 0.08941048625274561, 0.14997099089669064, 0.10738161450717598, 0.18143523222533986, 0.17192548548337072, 0.17489705962361768, 0.14961366163333878, 0.13146347540896386, 0.2745749882888049, 0.7867026014719158, 29.394263215363026, 133.69302928447723, 101.14377066493034, 109.50833022594452, 80.67946717143059, 97.40648880600929, 54.674035012722015, 41.13007977604866, 47.495369017124176, 70.8343094587326, 130.96631079912186, 135.10023057460785, 120.29809445142746, 89.2604099214077, 6.579929273575544, 0.29076574137434363, 0.29462090169545263, 0.3931862174067646, 0.5715226416941732, 1.8085675779730082, 0.8996263076551259, 1.1816370813176036, 6.544884704053402, 7.0464026927948, 4.671304514631629, 1.6840788954868913, 36.55574843287468, 114.22674983739853, 113.34474116563797, 104.21855047345161, 93.17765012383461, 82.8381997346878, 86.25625312328339, 82.97818422317505, 87.4883446097374, 93.54653432965279, 98.88035371899605, 101.5521651506424, 100.22984370589256, 96.52707919478416, 102.74001181125641, 102.09948018193245, 100.87330117821693, 97.17837944626808, 89.39207285642624, 89.1720874607563, 84.43906143307686, 81.33832141757011, 76.43473774194717, 77.43939623236656, 78.54835152626038, 78.14778462052345, 87.83722668886185, 91.40410289168358, 96.43242627382278, 91.38837933540344, 88.60143408179283, 88.31072688102722, 88.62470403313637, 86.07220619916916, 88.64372581243515, 87.63082936406136, 85.39794757962227, 84.70315486192703, 81.92515432834625, 85.21177276968956, 84.84244018793106, 81.03848710656166, 80.35388544201851, 80.55418789386749, 91.91747814416885, 72.44341671466827, 78.35477471351624, 92.11832776665688, 72.88683012127876, 72.59052202105522, 74.9973052740097, 86.23298317193985, 86.65117353200912, 87.39929258823395, 79.12580654025078, 78.81126701831818, 59.46245066821575, 57.975438460707664, 79.20209884643555, 74.01283130049706, 76.41573116183281, 79.12319228053093, 83.29193338751793, 84.76622387766838, 78.81391927599907, 75.3260788321495, 77.24398791790009, 77.69317701458931, 75.5061511695385, 69.27381679415703, 64.52556878328323, 74.97949942946434, 78.84671911597252, 78.19377735257149, 79.16721671819687, 83.42026010155678, 81.84396028518677, 84.72640961408615, 84.72564205527306, 84.9084198474884, 85.35633221268654, 76.84584528207779, 76.5568707883358, 87.31625184416771, 88.31375151872635, 83.3474712073803, 73.21611285209656, 78.67092534899712, 41.38601504266262, 0.288769364124164, 9.017513673752546, 23.626700900495052, 0.30732730112504214, 1.364369869697839, 0.3595555282663554, 0.5489411659073085, 0.17543538386235014, 0.6909888843074441, 1.0274468176066875, 6.626283461228013, 21.20589639991522, 58.349205404520035, 99.38506543636322, 110.68601623177528, 87.34593585133553, 110.94578549265862, 135.93373864889145, 44.90215636789799, 44.43855844438076, 49.37800079584122, 78.01827996969223, 80.66812857985497, 93.92483443021774, 52.72374406456947, 1.1003529117442667, 0.1715192338451743, 0.23533645318821073, 0.237470350402873, 0.08589861376094632, 0.18220865400508046, 0.09709038626169786, 0.17791696242056787, 0.1369086277554743, 0.18764730513794348, 0.17512856516987085, 0.10552335836109705, 0.14876946865115315, 0.14649791788542643, 0.3169062308734283, 0.13850807474227622, 0.2227059012511745, 0.1798610924743116, 0.15631390444468707], [0.04641168925445527, 0.11008401168510318, 0.0912217644508928, 0.03161987340718042, 0.008781057913438417, 0.04693333001341671, 0.020492209478106815, 0.04711243251222186, 0.06409597743186168, 0.04270698453183286, 0.06222710486326832, 0.02705830724153202, 0.03814651303400751, 0.035478336285450496, 0.055576485756319016, 0.0756247814570088, 0.22662279341602698, 50.69827415049076, 90.01536101102829, 73.80460247397423, 72.09375947713852, 51.57848931849003, 54.42967012524605, 81.88303738832474, 76.19669571518898, 86.2145085632801, 113.78057017922401, 107.71362572908401, 103.1860014796257, 60.414668172597885, 3.8795165391638875, 0.1389312621904537, 0.17650900437729433, 0.08752992856898345, 0.1360617927275598, 0.6481941556558013, 0.2840306027792394, 0.10502666118554771, 0.28272100898902863, 1.450526446569711, 1.3273055898025632, 0.6519382016267627, 8.569282125681639, 67.61656612157822, 106.64696976542473, 94.06859591603279, 90.72042837738991, 81.32860913872719, 79.03455823659897, 85.91399788856506, 85.61487793922424, 85.55484876036644, 88.20867195725441, 94.67989951372147, 92.1003395318985, 93.40946808457375, 96.44660711288452, 91.68224036693573, 90.10087922215462, 83.26646715402603, 81.76242426037788, 74.98826935887337, 72.35482826828957, 71.60800114274025, 72.43500396609306, 71.40243977308273, 71.20427280664444, 71.79654702544212, 78.71769323945045, 77.34379336237907, 83.5058619081974, 87.4783207476139, 88.15928980708122, 73.83549481630325, 81.28725975751877, 78.41033533215523, 84.83676329255104, 81.71855181455612, 79.1124464571476, 71.77238032221794, 75.82238540053368, 67.79501974582672, 69.36628103256226, 59.91510137915611, 49.64035391807556, 47.222566455602646, 51.084504425525665, 57.35321804881096, 40.72349779307842, 41.802009120583534, 68.59904140233994, 75.3977581858635, 66.51242896914482, 69.60349470376968, 81.27297252416611, 78.09694334864616, 79.01131868362427, 71.45515814423561, 69.0744186937809, 46.28824219107628, 43.74377712607384, 68.34725171327591, 67.02780291438103, 72.79660776257515, 68.26592847704887, 66.05062454938889, 69.52961906790733, 71.20480477809906, 67.42511719465256, 69.01846289634705, 70.11341974139214, 62.004506662487984, 55.82951880991459, 47.30986677110195, 46.34673625230789, 62.023596838116646, 64.75031912326813, 67.85197108983994, 70.0278027355671, 70.50225287675858, 71.76361799240112, 73.11164125800133, 76.89939200878143, 73.45107704401016, 71.05350449681282, 75.11149674654007, 77.24293917417526, 76.268230676651, 77.86182716488838, 65.05161255598068, 57.115244418382645, 53.293489292263985, 4.844682086259127, 1.7028515506535769, 3.3690982405096292, 3.5364602599292994, 0.5080258520320058, 0.18134342855773866, 0.04461589967831969, 0.3057647537207231, 0.11365348967956379, 0.2083268345450051, 0.2124719222774729, 2.0284515665844083, 2.2661530366167426, 27.13934451341629, 64.92183431982994, 91.25424653291702, 73.18371579051018, 74.10486996173859, 70.62501668930054, 25.697107203304768, 25.578287579119205, 36.369987800717354, 60.74633717536926, 61.71432763338089, 66.57317250967026, 13.591825067996979, 0.5722918035462499, 0.17475198459578678, 0.07896334762335755, 0.0625769273028709, 0.02051175764790969, 0.023793946566001978, 0.036031432973686606, 0.01973933776753256, 0.013414912045845995, 0.04354697324743029, 0.06320272106677294, 0.04319897278037388, 0.05544119223486632, 0.056430129989166744, 0.021087064960738644, 0.031297350869863294, 0.05528417605091818, 0.030923629419703502, 0.04793706990312785, 0.05721744477341417, 0.03065109980525449, 0.028109505619795527, 0.030602485421695746, 0.03516821132507175, 0.020324923825683072, 0.05193117140152026, 0.023466251259378623, 0.048921283887466416, 0.033217038289876655, 0.040137557953130454, 0.044069025898352265, 0.03234187919588294, 0.025330485404992942, 0.04778238777362276, 0.09634990099584684, 60.319954454898834, 102.65190973877907, 86.68136671185493, 96.62180811166763, 72.16831907629967, 73.41619491577148, 57.466467171907425, 26.892899237573147, 92.66270935535431, 120.44785961508751, 117.56361678242683, 114.70338866114616, 71.14449441432953, 3.580866102129221, 0.06275485720834695, 0.20593219116562977, 0.10915589664364234, 0.8185216190759093, 0.7630195410456508, 0.6985519628506154, 0.7259892218280584, 1.8668682058341801, 3.4949707612395287, 1.5375171974301338, 0.7149829342961311, 10.891377422958612, 72.39085793495178, 111.89001202583313, 98.76764416694641, 97.65027612447739, 85.01014038920403, 83.4317734837532, 88.5811659693718, 88.83126854896545, 92.29750335216522, 94.45772543549538, 97.44493514299393, 96.51960119605064, 96.7674694955349, 99.06388387084007, 93.89505922794342, 91.92396819591522, 85.51449492573738, 84.9485456943512, 78.97208958864212, 75.49819439649582, 73.76361027359962, 75.88682234287262, 74.84013810753822, 74.5266093313694, 75.27995690703392, 80.44405460357666, 82.20375537872314, 86.92972898483276, 92.3432756960392, 91.19302421808243, 80.07799744606018, 85.52708745002747, 82.13568583130836, 85.15843883156776, 85.36828637123108, 83.32743108272552, 74.34716776013374, 81.29453256726265, 73.41649889945984, 75.93014761805534, 63.78274664282799, 55.01740738749504, 53.28145153820515, 62.08704583346844, 60.055659636855125, 43.77339653670788, 47.518597170710564, 69.99495729804039, 76.53737023472786, 72.79488265514374, 75.89680820703506, 80.48090502619743, 83.47557753324509, 83.06953132152557, 76.59856975078583, 74.12209823727608, 56.444880589842796, 55.14770619571209, 74.95179891586304, 71.93859100341797, 76.45291596651077, 75.8254100382328, 70.54114758968353, 73.39373052120209, 74.46094125509262, 72.81434521079063, 74.02322754263878, 73.14485147595406, 68.25031131505966, 65.68152755498886, 59.3222039937973, 56.294214874506, 64.04677167534828, 70.33443868160248, 71.66826590895653, 73.3283968269825, 74.37852367758751, 76.91905975341797, 77.69693121314049, 82.28147640824318, 79.85165879130363, 74.93757247924805, 80.51805943250656, 82.79262498021126, 85.81423044204712, 85.45434415340424, 79.00754168629646, 65.87195053696632, 66.6786776483059, 10.160037316381931, 1.649302567820996, 0.7323302503209561, 6.032484574243426, 0.4775975301163271, 0.1721097607514821, 0.15549647330772132, 0.26614733738824725, 0.09970023020287044, 0.2900020417291671, 0.22799569240305573, 1.7991656949743629, 0.8378783147782087, 31.783694699406624, 77.77798846364021, 98.79202365875244, 88.19778934121132, 64.24775049090385, 36.90450131893158, 28.613826893270016, 42.53086321055889, 51.82998262345791, 73.91508534550667, 72.84789741039276, 79.58215445280075, 18.10523808002472, 0.6305053329560906, 0.12617607397260144, 0.07850062596844509, 0.018455811914463993, 0.03360711853019893, 0.0890627529588528, 0.0087176979832293, 0.09027236461406574, 0.029813489672960714, 0.06636787700699642, 0.029779118958686013, 0.05322736571542919, 0.02211552764492808, 0.06828712284914218, 0.0015783648905198788, 0.023496317517128773, 0.019979175776825286, 0.03605698140745517, 0.13697251182748005, 0.23695326643064618, 0.10540787276113406, 0.1465473894495517, 0.22478688333649188, 0.0830856068932917, 0.09769100637640804, 0.1742636365815997, 0.11733215244021267, 0.11645952035905793, 0.14688595721963793, 0.11249382456298918, 0.13360850483877584, 0.15336014184867963, 0.14603487710701302, 0.15522696980042383, 0.43548836780246347, 81.96706607937813, 114.9075897037983, 97.55361691117287, 92.5973528623581, 66.84863492846489, 64.16098594665527, 105.9144526720047, 106.85620933771133, 111.96695029735565, 135.24678111076355, 128.20019602775574, 123.29891502857208, 91.26257568597794, 10.171335060149431, 0.7192656013648957, 0.375797608285211, 0.22547745174961165, 0.42580904031638056, 1.2190581858158112, 0.952585490886122, 1.8219115119427443, 2.3353228624910116, 5.361730791628361, 5.535744829103351, 2.6854453375563025, 11.740081831812859, 78.73433634638786, 116.29115626215935, 103.53684425354004, 102.63123124837875, 87.09554448723793, 87.45188936591148, 93.84447634220123, 94.03914749622345, 93.24499011039734, 97.982317507267, 100.09113594889641, 97.44015499949455, 100.87649300694466, 101.49971276521683, 98.09774771332741, 98.63082870841026, 86.49145290255547, 90.3052930533886, 82.6212465763092, 78.8094811141491, 78.96325886249542, 79.01692718267441, 76.596320271492, 77.97446832060814, 78.11281129717827, 86.85411304235458, 86.55918806791306, 92.10948944091797, 94.98482555150986, 94.65020790696144, 84.1609999537468, 90.64789786934853, 87.47303143143654, 90.70706829428673, 89.50442522764206, 86.54823705554008, 83.98455262184143, 88.83258327841759, 77.5101788341999, 83.78662884235382, 73.49723696708679, 66.6959211230278, 63.61978858709335, 67.7252022922039, 74.25398156046867, 57.69093632698059, 63.565645292401314, 82.60696694254875, 83.85616511106491, 75.9746964275837, 79.02135014533997, 85.78407526016235, 82.82591879367828, 89.49507772922516, 81.86245769262314, 77.1100527048111, 63.93397092819214, 55.74286825954914, 77.30638816952705, 76.23809829354286, 79.61914926767349, 78.92488092184067, 74.63985845446587, 79.57032948732376, 83.12133774161339, 79.13112625479698, 79.04227182269096, 78.54677081108093, 74.31997641921043, 71.62642255425453, 64.89558532834053, 65.10851070284843, 75.62731146812439, 74.66893449425697, 75.74888974428177, 77.9416836798191, 78.69145944714546, 81.17642730474472, 82.87449538707733, 83.83028849959373, 82.76597321033478, 77.93428927659988, 84.56176444888115, 85.61113134026527, 86.112370043993, 88.46828922629356, 80.01887261867523, 69.20745715498924, 73.85528415441513, 14.235283490270376, 4.25335924141109, 9.56848505884409, 9.075397867709398, 1.6381519474089146, 0.6130478822160512, 0.2747686888324097, 0.6169483729172498, 0.3768144693458453, 0.5444563971832395, 0.47502453380730003, 3.6274328408762813, 5.7845735270529985, 48.062366992235184, 86.48898303508759, 114.1038416326046, 93.88304427266121, 105.15912160277367, 93.40927809476852, 31.405008919537067, 36.816000267863274, 49.699809327721596, 83.88730064034462, 80.29877319931984, 94.57863494753838, 33.15269283950329, 0.699536525644362, 0.2550819155294448, 0.20068268378963694, 0.17437617585528642, 0.11929094733204693, 0.19917999801691622, 0.12527773389592767, 0.219266714702826, 0.11804223933722824, 0.17164342483738437, 0.19395380892092362, 0.12701597734121606, 0.1653880105004646, 0.17905822227476165, 0.12865336291724816, 0.1287946678348817, 0.13905310799600556, 0.14069840486627072], [0.03680567111587152, 0.033911859209183604, 0.017060270001820754, 0.03154229671054054, 0.03946874930988997, 0.028324778540991247, 0.042210150058963336, 0.014841596330370521, 0.017016859928844497, 0.06311402699793689, 0.03326044279674534, 0.09582587794284336, 0.0809930101968348, 0.05155586732144002, 0.04424418759299442, 0.12120377359678969, 4.66373959556222, 89.86854448914528, 81.14292070269585, 71.89870074391365, 29.423588141798973, 30.96303753554821, 39.157970398664474, 67.57180452346802, 86.79423585534096, 85.29194086790085, 102.78667330741882, 96.94219172000885, 52.435438334941864, 5.945367123931646, 0.17638632736634463, 0.13957385817775503, 0.11008058296283707, 0.14321372145786881, 0.2262940219952725, 0.6445896334480494, 0.18758518737740815, 0.548026958713308, 0.4024567105807364, 1.9969640811905265, 0.45699387788772583, 2.6023582834750414, 33.7823760509491, 95.05045562982559, 101.0888560116291, 97.23050504922867, 87.10603192448616, 87.67756685614586, 87.56177946925163, 89.25916358828545, 93.87923687696457, 94.28973644971848, 93.30161467194557, 98.00356596708298, 96.06665790081024, 93.86673554778099, 94.12733316421509, 88.43866601586342, 79.81797739863396, 79.39612403512001, 73.14187243580818, 73.8818371295929, 74.71701711416245, 73.11414152383804, 74.43567261099815, 74.97885346412659, 71.40453726053238, 76.5844877064228, 75.23752838373184, 84.59589421749115, 82.73058950901031, 91.01247310638428, 81.0264265537262, 68.30514997243881, 84.1434296965599, 75.40970474481583, 81.2451808154583, 74.03059914708138, 76.25594973564148, 67.95319765806198, 70.86895599961281, 68.26810196042061, 66.38711169362068, 55.08446238934994, 44.316778779029846, 54.64184693992138, 57.02418230473995, 39.79765087366104, 32.55157269537449, 25.818214304745197, 37.00657144188881, 60.47567389905453, 74.29315745830536, 68.88365373015404, 73.07218417525291, 76.39980241656303, 78.50790649652481, 75.49874156713486, 65.6463186442852, 47.7909779548645, 61.51928409934044, 72.85413667559624, 75.19390672445297, 74.1228049993515, 76.37379661202431, 72.26823851466179, 74.59329575300217, 72.3624886572361, 68.0164946615696, 69.41278293728828, 70.83329111337662, 63.10131020843983, 58.59398066997528, 55.8846690505743, 48.10898669064045, 48.071045726537704, 62.166123390197754, 66.63634791970253, 70.51293030381203, 66.17594182491302, 69.37604650855064, 74.25440713763237, 74.79959428310394, 71.52652591466904, 71.51983827352524, 72.19836786389351, 78.92571687698364, 80.59899508953094, 68.7279000878334, 65.91871082782745, 57.93742150068283, 58.32351878285408, 22.207435257732868, 0.927496743388474, 0.9334016859065741, 2.0051566790789366, 0.1836710560019128, 0.03360890339536127, 0.09156495580100454, 0.13919398246798664, 0.11116486813989468, 0.19756137393414974, 0.3817710658768192, 1.3275188533589244, 0.3587036021053791, 0.906778295757249, 30.530031770467758, 67.88353219628334, 88.55350345373154, 67.63375639915466, 70.13383984565735, 75.69235637784004, 24.193263798952103, 28.77851765602827, 24.902495741844177, 63.79008784890175, 63.07151600718498, 52.19604358077049, 19.637920036911964, 0.8912659843917936, 0.07001597070484422, 0.04485904210014269, 0.042337747509009205, 0.02636342880578013, 0.04177721821179148, 0.06814967709942721, 0.059853163693333045, 0.03524522398947738, 0.021619654253299814, 0.06434652648749761, 0.020719787207781337, 0.040720240358496085, 0.02557184110628441, 0.03760261526622344, 0.07036377079202794, 0.017284120294789318, 0.05766647751443088, 0.07649837833014317, 0.09625176680856384, 0.0534574463381432, 0.03888850114890374, 0.02316321937541943, 0.05916500726016238, 0.005257482216620701, 0.024205842237279285, 0.011779029318859102, 0.017794304148992524, 0.03097391178016551, 0.033988853319897316, 0.04254122213751543, 0.09377338690683246, 0.03654010099126026, 7.038751803338528, 104.14003908634186, 89.44038346409798, 78.60400334000587, 45.56056223809719, 47.742332965135574, 32.43094436824322, 32.50194355845451, 82.05735683441162, 97.41640627384186, 110.94977527856827, 108.34448307752609, 63.94171491265297, 4.365668389946222, 0.12266362260561436, 0.30971953994594514, 0.0755999937246088, 0.2657604112755507, 0.17928062909049913, 0.47779351647477597, 0.36334837786853313, 0.5730316950939596, 1.2090983265079558, 2.4014680506661534, 0.6686121225357056, 2.847442519851029, 41.04079596698284, 100.47414779663086, 104.93356570601463, 99.77939307689667, 91.50585383176804, 92.29961603879929, 93.43893930315971, 93.74602362513542, 97.48687729239464, 99.68977108597755, 97.61989295482635, 100.56563928723335, 98.50253239274025, 95.75129002332687, 97.90093347430229, 92.83685401082039, 83.22787642478943, 80.82575932145119, 77.57849156856537, 78.26909691095352, 77.83291831612587, 77.64545917510986, 77.89899677038193, 77.9478469491005, 74.86823379993439, 80.31781017780304, 78.21457743644714, 87.45768025517464, 87.19592750072479, 93.34621667861938, 81.89786419272423, 73.50559651851654, 87.62098029255867, 81.2120009958744, 87.30707913637161, 77.41228088736534, 77.1923790872097, 74.32664886116982, 72.87818938493729, 71.64746582508087, 71.04782000184059, 63.59091393649578, 55.89214704930782, 61.13863952457905, 64.3136465549469, 51.85551345348358, 44.055630192160606, 34.65531460940838, 41.97720251977444, 67.37089410424232, 73.8398265838623, 68.27953174710274, 74.87451866269112, 77.37976983189583, 81.84656694531441, 79.02942851185799, 70.62146008014679, 59.109662398695946, 70.24976402521133, 75.30530914664268, 77.7235297858715, 76.53415560722351, 79.4729483127594, 75.21292090415955, 77.69084393978119, 76.34839877486229, 74.0712721645832, 71.36618211865425, 75.12050226330757, 69.13538262248039, 65.20582348108292, 65.22517204284668, 60.802634954452515, 59.38733249902725, 65.95042392611504, 71.1735400557518, 71.9452254474163, 69.88192096352577, 73.59090954065323, 77.8178483247757, 78.90031903982162, 75.02584174275398, 76.04577541351318, 77.36771687865257, 82.61401176452637, 84.54417899250984, 75.99976748228073, 78.632061034441, 71.37401729822159, 67.63957768678665, 32.396734803915024, 1.6974229482002556, 0.49033590126782656, 0.5718382028862834, 0.17563089524628595, 0.07233812109916471, 0.8108115359209478, 0.09289593086577952, 0.21906155539909378, 0.2720360120292753, 0.29100135841872543, 3.105703736655414, 0.7540033373516053, 0.7821898092515767, 37.53620222210884, 78.09339433908463, 91.01245030760765, 79.50314149260521, 48.32205265760422, 30.873664431273937, 34.398930966854095, 43.58829706907272, 43.47460716962814, 69.07805129885674, 73.83538842201233, 60.604711174964905, 22.937438786029816, 0.38780629984103143, 0.03925256540242117, 0.021379766149038915, 0.04201324343739543, 0.024684473683009855, 0.032834334997460246, 0.06436971860239282, 0.06057862417947035, 0.031155990291154012, 0.006017896466801176, 0.06452128742239438, 0.04720107091998216, 0.07290056513738818, 0.06120454410847742, 0.05061822310381103, 0.04676251359342132, 0.02861386918084463, 0.1209638372529298, 0.12180905439890921, 0.16311111627146602, 0.1308453851379454, 0.11910546236322261, 0.14066037721931934, 0.0945301994215697, 0.08784203135292046, 0.18944584066048265, 0.14739118167199194, 0.09003128536278382, 0.21062479092506692, 0.1492228763527237, 0.18242249643662944, 0.28476752573624253, 0.42127974273171276, 10.974745899438858, 124.33989956974983, 100.48415645956993, 96.45941242575645, 44.2174407094717, 38.548661693930626, 53.78999724984169, 93.30689638853073, 118.14025104045868, 101.68698951601982, 125.00091210007668, 118.08662831783295, 83.04570659995079, 9.894627258181572, 0.9012702538166195, 0.4647717933403328, 0.4455398378195241, 0.45769321848638356, 0.5018767726141959, 1.4459505421109498, 0.8083622704725713, 3.094609994441271, 2.9955189116299152, 7.918284432962537, 3.390621948055923, 3.3017264306545258, 40.86729347705841, 109.70401972532272, 112.94710010290146, 108.68471682071686, 96.17311298847198, 98.6848010122776, 95.25876805186272, 94.97642800211906, 100.00569373369217, 102.116928845644, 102.53914698958397, 104.58287492394447, 102.99677923321724, 98.87900859117508, 103.95647093653679, 96.34059280157089, 86.59673005342484, 85.87527796626091, 80.88155552744865, 81.51073336601257, 82.3990572988987, 80.04142820835114, 81.4117182791233, 80.59768795967102, 76.99981302022934, 83.66658568382263, 82.85580798983574, 90.98051682114601, 92.60470166802406, 94.59604561328888, 84.85151410102844, 77.71377950906754, 91.73824176192284, 84.50504869222641, 90.99970579147339, 79.92519244551659, 82.56015345454216, 78.24497580528259, 78.93842339515686, 81.43887162208557, 79.02808338403702, 68.08820441365242, 61.30801923573017, 69.50100660324097, 69.78935793042183, 58.005521446466446, 48.9911587536335, 42.27931670844555, 52.34070561826229, 76.80236801505089, 81.13552629947662, 74.08930599689484, 78.40690791606903, 80.52467107772827, 85.384002327919, 82.24837258458138, 77.902492582798, 66.45724073052406, 68.90439301729202, 80.61477944254875, 82.95229241251945, 82.7713081240654, 85.56792765855789, 81.39603272080421, 84.78923544287682, 82.71885573863983, 77.6824463903904, 78.38273361325264, 81.02518782019615, 75.3138054907322, 73.54053184390068, 71.48389980196953, 67.00346902012825, 68.39428558945656, 78.28355893492699, 77.79377281665802, 76.74436032772064, 71.62661254405975, 76.73322692513466, 85.01516371965408, 82.68509075045586, 79.93477553129196, 80.93143925070763, 82.47541040182114, 84.7851012647152, 89.67521846294403, 79.95033949613571, 82.7900031208992, 72.95347094535828, 74.28240403532982, 39.33319799602032, 1.7192456522025168, 1.2672797357663512, 3.629571651108563, 0.8898939611390233, 0.2041228796588257, 1.5154321887530386, 0.25342300767078996, 0.3534582507563755, 0.3129491291474551, 0.7795461604837328, 3.491527196019888, 1.1033521383069456, 2.5683748070150614, 54.2900276184082, 92.74704203009605, 105.57174146175385, 85.13058632612228, 103.16398546099663, 98.00558745861053, 33.94099473953247, 41.38349957764149, 39.54851724207401, 82.67764315009117, 82.07926645874977, 77.37292259931564, 41.0272990912199, 1.3140045222826302, 0.29784547397866845, 0.14373396697919816, 0.15223240392515436, 0.2296606413437985, 0.21065936016384512, 0.26229559094645083, 0.1612098081386648, 0.13872124924091622, 0.07253895368194208, 0.14299055765150115, 0.1881652945303358, 0.1717718312283978, 0.14110593299847096, 0.14147765992674977, 0.12344813207164407, 0.13950327993370593], [0.04127353742660489, 0.09952633758075535, 0.06810498496633954, 0.025962138424802106, 0.04803566793270875, 0.04694232113251928, 0.06731105022481643, 0.014687287130072946, 0.09423578943824396, 0.05592601504758932, 0.04772365791723132, 0.024200046063924674, 0.1046797219896689, 0.13232129422249272, 0.16690043325070292, 0.17746560304658487, 32.316996082663536, 86.27408176660538, 74.73654806613922, 63.74765172600746, 64.12906005978584, 49.57460604608059, 78.33997070789337, 74.72935125231743, 77.43909224867821, 116.26382052898407, 100.22852897644043, 47.633290216326714, 5.138347428292036, 0.5201906617730856, 0.17416067101294175, 0.13214908627560362, 0.13722034462261945, 0.462513497332111, 2.5543098617345095, 0.9227489575278014, 0.07136507643735968, 0.09399407193996012, 0.9572069335263222, 2.469113920815289, 0.7611939171329141, 5.470460532233119, 54.913232177495956, 103.68673861026764, 95.9615783393383, 90.7009506225586, 90.83580538630486, 91.25005915760994, 92.52303645014763, 93.49514588713646, 94.84927162528038, 94.300307482481, 95.09264096617699, 94.7366988658905, 90.76425522565842, 89.08327862620354, 84.92364943027496, 82.91111782193184, 76.00665271282196, 73.94008800387383, 70.97730338573456, 76.52953505516052, 76.51584818959236, 77.72520169615746, 79.3756203353405, 76.36676698923111, 76.9545042514801, 74.36841621994972, 80.17331153154373, 84.06349718570709, 82.16109126806259, 95.23613646626472, 70.51614493131638, 75.95809131860733, 79.31626752018929, 73.46766695380211, 73.08071091771126, 73.47103357315063, 70.63611969351768, 79.3568417429924, 67.3676110804081, 64.25623923540115, 66.80948182940483, 70.05417332053185, 62.06991255283356, 65.35685017704964, 76.67232379317284, 67.483641654253, 73.62054035067558, 52.43000462651253, 41.909877732396126, 51.24581336975098, 58.870320841670036, 64.1097266972065, 70.46869307756424, 77.08420649170876, 71.43061146140099, 80.32521978020668, 65.79859167337418, 62.480199337005615, 72.84378603100777, 68.86104494333267, 75.45981645584106, 69.35197100043297, 73.8004682958126, 70.74139684438705, 70.04838243126869, 71.53036370873451, 73.7346862256527, 64.36485260725021, 67.88734719157219, 64.32918772101402, 56.66580453515053, 62.07268260419369, 56.06759503483772, 50.687919706106186, 48.64659324288368, 61.390421614050865, 64.69529807567596, 65.60637518763542, 65.95885947346687, 67.33672633767128, 66.89488604664803, 68.94333332777023, 67.60114654898643, 73.32850322127342, 76.43988266587257, 74.91595923900604, 75.42049616575241, 64.67015102505684, 59.06195975840092, 52.898918464779854, 34.19828653335571, 1.0142557066865265, 0.7272309833206236, 0.15958676085574552, 0.1529410362127237, 0.04224695687298663, 0.3237756685120985, 0.18719276937190443, 0.08985170046798885, 0.15016933728475124, 0.0293584603787167, 1.1144328187219799, 1.2236662697978318, 0.16157444013515487, 1.140880943275988, 61.9004188477993, 77.78434932231903, 91.80421382188797, 77.61503800749779, 74.46009770035744, 46.48775428533554, 22.677964009344578, 23.740390799939632, 34.94425490498543, 66.02325081825256, 73.70363429188728, 69.86846208572388, 39.70746271312237, 1.2611351092346013, 0.03384195260878187, 0.0631905350019224, 0.04858011117903516, 0.06060668849386275, 0.03863638616167009, 0.0384145990392426, 0.0038738408738936414, 0.019956599644501694, 0.07818994068657048, 0.021196502057136968, 0.07506767346058041, 0.06885058362968266, 0.029187324835220352, 0.02956515221740119, 0.011838319496746408, 0.057250548270531, 0.03215146636648569, 0.005271444797472213, 0.08662021878990345, 0.037486580476979725, 0.02381375448749168, 0.09384374250657856, 0.04261130314262118, 0.06613783349166624, 0.041301672245026566, 0.05456313876493368, 0.015546346257906407, 0.04900755113339983, 0.002633894860082364, 0.07092960644513369, 0.34258080006111413, 37.58149579167366, 99.60274055600166, 83.02339419722557, 83.35591435432434, 70.55882424116135, 43.26129421591759, 26.002705805003643, 56.09705865383148, 90.25588050484657, 122.33977809548378, 112.6264201104641, 61.972804963588715, 4.371342910453677, 0.30237198108807206, 0.21350451686885208, 0.1267965094302781, 0.07228246744489297, 0.4746616829652339, 0.37873265391681343, 1.4914137963205576, 0.6920869066379964, 0.3855461336206645, 1.03122464613989, 2.2474243165925145, 0.7611736713442951, 5.196114778518677, 57.98428438603878, 106.90969526767731, 101.03733837604523, 98.92959907650948, 94.7607971727848, 96.14034354686737, 95.1794283092022, 99.95317295193672, 99.73574861884117, 98.59354510903358, 99.09395545721054, 97.40063712000847, 94.00320902466774, 92.04249903559685, 89.40452098846436, 86.2917660176754, 77.98447698354721, 78.14579352736473, 73.07487443089485, 79.02426838874817, 80.12598127126694, 82.81568974256516, 80.75191408395767, 78.37347730994225, 78.70529070496559, 78.71862038969994, 85.7829961180687, 85.93485116958618, 87.61348709464073, 94.4287557899952, 75.20930349826813, 79.09076482057571, 81.80271729826927, 79.18440699577332, 73.65979224443436, 74.44601565599442, 75.21051183342934, 80.24407133460045, 70.58755069971085, 70.09173810482025, 72.94144839048386, 73.04430887103081, 67.6605373620987, 71.78659155964851, 82.1335731446743, 74.87170681357384, 73.70392307639122, 59.619629234075546, 51.48162491619587, 57.6185692101717, 61.503142565488815, 66.82604894042015, 72.90450677275658, 78.5424542427063, 76.45411670207977, 81.96140438318253, 72.82312273979187, 74.30321931838989, 75.17030239105225, 73.14841568470001, 78.2605929672718, 74.26674127578735, 79.00803565979004, 74.67117637395859, 73.31555351614952, 74.15295258164406, 74.5478729903698, 70.50539150834084, 69.03959736227989, 69.1211561858654, 65.22546082735062, 68.5900890827179, 63.54152038693428, 63.06267008185387, 56.906096041202545, 64.86017122864723, 68.96795600652695, 69.27428796887398, 69.51799929141998, 71.87451124191284, 71.94154724478722, 73.12269106507301, 71.6065876185894, 79.89601761102676, 80.58862164616585, 79.82662573456764, 79.66467842459679, 74.69370916485786, 70.64235135912895, 66.85520857572556, 44.44051533937454, 2.9682503873482347, 1.3886357238516212, 0.09773108977242373, 0.17643554660025984, 0.1355576518108137, 0.19263391412096098, 0.2665959211299196, 0.06806911696912721, 0.08626651120721363, 0.043881466626771726, 1.2512615765444934, 1.5098736807703972, 0.2930772345280275, 1.9935471145436168, 71.85914486646652, 86.7797814309597, 99.7939994931221, 84.57128673791885, 47.57106475532055, 22.773623876273632, 34.67860735952854, 33.27169485390186, 51.482058092951775, 79.49853613972664, 83.86182680726051, 82.99308702349663, 44.99373145401478, 0.3350911050802097, 0.015676086659368593, 0.10519955190829933, 0.027508058010425884, 0.10065704409498721, 0.021563679620157927, 0.10132650582818314, 0.03193714153894689, 0.02934947668109089, 0.07051433771266602, 0.022298021758615505, 0.008740288958506426, 0.09340338918264024, 0.006984915817156434, 0.09945653859176673, 0.030677178874611855, 0.14541464945068583, 0.11443242561654188, 0.15684186830185354, 0.15420188574353233, 0.1764083097805269, 0.07725088638835587, 0.1131621582317166, 0.146630895906128, 0.20507070614257827, 0.13537876453483477, 0.1644754211883992, 0.17194175336044282, 0.1829768213792704, 0.2686552028171718, 0.20862658799160272, 0.42283644201233983, 52.3981699347496, 111.6568261384964, 96.07192441821098, 85.7780259847641, 88.71772304177284, 69.81387421488762, 103.78772959113121, 110.56910410523415, 93.92858862876892, 140.75914531946182, 123.91496077179909, 78.8182282447815, 8.276922013610601, 0.7755944319069386, 0.2107869798783213, 0.346207853872329, 0.16267661849269643, 1.6826282045803964, 9.952198918908834, 3.646673345938325, 1.7127402825281024, 2.366866869851947, 5.113995959982276, 7.112433649599552, 3.0136964237317443, 5.384558541700244, 62.841111570596695, 115.25637298822403, 107.48716548085213, 106.43766939640045, 97.95552134513855, 100.78908249735832, 100.75250566005707, 103.86710733175278, 100.95038384199142, 100.51629513502121, 101.70208990573883, 101.30859062075615, 95.06964460015297, 98.23667585849762, 91.02992936968803, 90.44090017676353, 83.46906468272209, 81.8176580965519, 76.60290151834488, 83.49235743284225, 84.12269800901413, 85.67995324730873, 84.78052631020546, 82.79934301972389, 82.5277715921402, 80.9791798889637, 87.77250096201897, 91.61106258630753, 89.94828701019287, 97.16199472546577, 77.45485380291939, 84.45537775754929, 87.22856014966965, 83.42852085828781, 78.46343368291855, 80.51745146512985, 79.8651784658432, 83.63521456718445, 78.64776939153671, 73.65539968013763, 77.07486659288406, 78.64614307880402, 73.34611147642136, 80.76768323779106, 91.83462738990784, 80.58672174811363, 80.36487445235252, 61.00981503725052, 53.810307160019875, 62.03472264111042, 65.90338245034218, 71.03674739599228, 75.67018836736679, 83.11404973268509, 80.57140856981277, 83.91662746667862, 81.47454410791397, 75.50279214978218, 74.94479969143867, 75.09247496724129, 81.72859847545624, 76.99915945529938, 82.34598934650421, 79.16948899626732, 76.68708980083466, 81.13719820976257, 82.47270494699478, 75.00783830881119, 77.27763131260872, 74.24529522657394, 70.1202517747879, 76.88199654221535, 70.35269290208817, 69.77199286222458, 66.85108199715614, 76.83718174695969, 73.1783276796341, 74.07143175601959, 72.95809149742126, 77.70619511604309, 77.67397284507751, 76.57619655132294, 76.51675254106522, 83.4707821905613, 84.1730909049511, 84.12459030747414, 84.86298948526382, 79.62813958525658, 73.34988847374916, 67.41114914417267, 51.450595781207085, 4.990194803103805, 2.001620256341994, 0.19867469934979454, 0.5010066193062812, 0.16976414364762604, 0.8008317276835442, 0.42731675785034895, 0.3034440876217559, 0.3889251023065299, 0.2905674692010507, 2.3199486499652267, 2.3454861296340823, 0.3345120814628899, 2.5592949567362666, 85.05072221159935, 97.77443066239357, 110.58391571044922, 102.82261177897453, 113.62096354365349, 58.08657869696617, 33.502403274178505, 34.86440598964691, 52.83397614955902, 85.32050773501396, 91.96959614753723, 92.44802087545395, 66.71321779489517, 1.7293558409437537, 0.19831389683531597, 0.2976770658278838, 0.13046818115981296, 0.23011112498352304, 0.0992900897108484, 0.2285401022527367, 0.1989936744212173, 0.11559381251572631, 0.3192512987880036, 0.17902893712744117, 0.14394113008165732, 0.2308278763666749, 0.07775060410494916, 0.20801439037313685, 0.09856801712885499], [0.038656624528812245, 0.05248918852885254, 0.05803735097288154, 0.004040275143779581, 0.013664431371580577, 0.17484133917605504, 0.037783435836900026, 0.03556787640263792, 0.027487147999636363, 0.07627162252902053, 0.0805793222389184, 0.056862275159801356, 0.08147482731146738, 0.07166885974584147, 0.23027552553685382, 1.6011533327400684, 55.85253797471523, 85.60554563999176, 67.47719720005989, 54.96269032359123, 32.26104028522968, 54.30426545441151, 57.38445997238159, 59.54520642757416, 108.82270261645317, 96.16802126169205, 61.606842800974846, 1.7880421481095254, 0.26815140328835696, 0.2364319225307554, 0.025111921058851294, 0.01329333805188071, 0.09292814007494599, 0.3363436722429469, 0.206789267831482, 0.2852561854524538, 0.2249206035048701, 0.2661212731618434, 0.6314714311156422, 0.8377216325607151, 0.6313619494903833, 10.988424215465784, 51.127928495407104, 102.78766125440598, 94.45596233010292, 96.86354354023933, 94.41987186670303, 90.38206413388252, 94.02216240763664, 97.7560244500637, 95.21555677056313, 93.31216290593147, 92.67696619033813, 91.4619205892086, 83.6853414773941, 81.2416698038578, 76.33364796638489, 74.96027246117592, 71.48484215140343, 68.41779112815857, 71.26008421182632, 78.54933947324753, 82.8781507909298, 84.26183894276619, 79.43983688950539, 79.70503225922585, 77.26142138242722, 80.63440158963203, 79.1497528553009, 87.23742127418518, 92.15001806616783, 75.74535593390465, 70.26427924633026, 74.15023192763329, 65.04123151302338, 74.73616808652878, 72.71783038973808, 74.09875988960266, 79.55446913838387, 73.4488807618618, 69.55585286021233, 68.38125228881836, 65.44587939977646, 65.20035177469254, 67.03065276145935, 63.225837126374245, 58.03904704749584, 61.80364564061165, 46.93140707910061, 66.11180126667023, 64.63646963238716, 59.15694706141949, 59.641573056578636, 59.798147454857826, 62.212275713682175, 68.63895446062088, 75.73389574885368, 75.26334419846535, 71.00223764777184, 82.49824717640877, 75.52134275436401, 76.14463850855827, 74.00330901145935, 78.97772088646889, 73.01207900047302, 78.54114711284637, 69.62884694337845, 68.76172587275505, 68.97968977689743, 70.11803269386292, 58.30547355115414, 65.87791621685028, 61.56595319509506, 64.28118109703064, 65.18305510282516, 53.12070116400719, 47.17020146548748, 51.551423370838165, 68.14268589019775, 67.89922535419464, 64.33481141924858, 64.08650994300842, 63.31151872873306, 63.96362453699112, 65.21599173545837, 71.2169261276722, 71.25889867544174, 74.90894481539726, 65.60685396194458, 68.21818023920059, 59.00627754628658, 55.30432999134064, 32.35810987651348, 3.820507605560124, 1.695437435992062, 0.567973869619891, 0.3351499425480142, 0.2775127947097644, 0.3489717305637896, 0.05944670796452556, 0.5749210249632597, 0.07773485573125072, 0.1464454480446875, 0.735544937197119, 0.6524754571728408, 0.3425863216398284, 0.5616676923818886, 6.0886693093925714, 64.55067783594131, 81.3393397629261, 84.09575745463371, 73.93910765647888, 80.21186426281929, 37.76727542281151, 22.268573977053165, 19.320296980440617, 43.736770302057266, 46.7950551956892, 58.60227182507515, 66.54795706272125, 41.58569432795048, 0.32722730829846114, 0.04506675439188257, 0.08880806271918118, 0.07887051237048581, 0.055885504916659556, 0.009772455887286924, 0.05802170649985783, 0.05859856304596178, 0.04459359071915969, 0.05106356737087481, 0.04801541843335144, 0.02097942757245619, 0.02352831892494578, 0.0457517084578285, 0.049024635372916237, 0.02428463976684725, 0.041825172083918005, 0.029905115225119516, 0.04371965987957083, 0.09815628101932816, 0.12921782559715211, 0.00552732386495336, 0.04380619429866783, 0.04571866062178742, 0.07360023228102364, 0.05539945384953171, 0.061813016145606525, 0.0655071044457145, 0.062368131475523114, 0.10705062406486832, 1.5786757576279342, 69.8301449418068, 89.44633394479752, 81.73391819000244, 74.23422262072563, 55.92746615409851, 54.01095159351826, 41.861848309636116, 68.91640797257423, 115.53775548934937, 105.0881490111351, 76.33319959044456, 2.487291907891631, 0.34002113272435963, 0.2924529102165252, 0.16648429620545357, 0.03874909984006081, 0.08909609023248777, 0.17784933792427182, 0.24570171808591112, 0.193917028082069, 0.31719397637061775, 0.38174022221937776, 0.4784327431116253, 1.1946912808343768, 0.5886288487818092, 10.906550008803606, 56.48119144141674, 105.66775470972061, 97.86001726984978, 103.00164297223091, 98.26816856861115, 96.39134287834167, 99.52706381678581, 101.86941772699356, 97.86797404289246, 96.54712691903114, 96.88341647386551, 95.9170751273632, 89.0084682404995, 82.92141526937485, 79.20064732432365, 76.41698509454727, 74.28473711013794, 74.27203819155693, 75.34506261348724, 79.40231010317802, 84.45557534694672, 86.95413887500763, 81.59226939082146, 82.20111832022667, 81.5260237455368, 82.14549690485, 83.11075910925865, 89.88094702363014, 93.89800786972046, 77.1982991695404, 76.08507290482521, 77.91367918252945, 69.39291000366211, 77.04701408743858, 76.05716720223427, 77.38177612423897, 82.29764834046364, 77.63750240206718, 75.45540109276772, 73.94397139549255, 70.246222615242, 70.05621001124382, 68.2237583398819, 68.93761083483696, 63.46020855009556, 64.41061735153198, 46.36099308729172, 66.30328819155693, 68.30882057547569, 66.8681126832962, 64.63985905051231, 62.94327288866043, 63.591096326708794, 70.48805683851242, 77.952741086483, 77.9489640891552, 81.45332604646683, 87.4593597650528, 77.49915182590485, 73.80856186151505, 75.43997392058372, 80.3488241136074, 78.15763369202614, 82.79991298913956, 74.49337631464005, 73.86744350194931, 74.04053181409836, 74.37713295221329, 67.50140190124512, 69.92614299058914, 67.87017211318016, 69.28254872560501, 70.50505712628365, 62.11993686854839, 59.0880985558033, 60.371517688035965, 71.16636604070663, 70.57646289467812, 69.09290090203285, 68.42945650219917, 66.68264463543892, 67.43257999420166, 70.19126996397972, 74.0797609090805, 75.32851830124855, 78.35325479507446, 71.81034788489342, 72.17174649238586, 70.78910708427429, 69.44913938641548, 45.04732757806778, 9.460118673741817, 4.1349248215556145, 0.6367433513514698, 0.29016335494816303, 0.45932330132927746, 0.4392900044331327, 0.07261152088176459, 0.23088270623702556, 0.104039337602444, 0.22815103875473142, 0.39620411640498787, 1.723131062462926, 0.49997325288131833, 0.8123008185066283, 8.897954039275646, 75.0792820751667, 86.7685416340828, 95.77696904540062, 74.73297625780106, 44.02065306901932, 32.28213295340538, 35.99028937518597, 34.17972072958946, 56.184218376874924, 60.794222205877304, 68.11224952340126, 82.33278125524521, 46.37854054570198, 0.07331478744163178, 0.00786911798059009, 0.06718185715726577, 0.06578553598956205, 0.03832721857179422, 0.007646028852832387, 0.05038596427766606, 0.02640256039740052, 0.06105775471951347, 0.05085752491140738, 0.011480876128189266, 0.03603676159400493, 0.006743726635249914, 0.03131223093078006, 0.08670141716720536, 0.10128843365237117, 0.10415842261863872, 0.2015172882238403, 0.1649490449926816, 0.14006547164171934, 0.22706683521391824, 0.11488993739476427, 0.11670030275126919, 0.15275766636477783, 0.23031150485621765, 0.10044127950095572, 0.17923540261108428, 0.20228143315762281, 0.12440954727935605, 0.28119824070017785, 3.3547815587371588, 87.75466471910477, 104.60343182086945, 88.83493155241013, 69.73502084612846, 45.04762016236782, 75.30593231320381, 84.04886037111282, 79.00703251361847, 132.5494882464409, 117.59558066725731, 90.25005161762238, 5.489141279831529, 0.7648726541083306, 0.645042818505317, 0.41219923936296254, 0.39939140318892896, 0.3475824894849211, 0.9958870173431933, 1.2863513873890042, 1.044194062706083, 1.3030888955108821, 1.2481127330102026, 4.7601807955652475, 3.9986460842192173, 1.7165792640298605, 11.298765912652016, 66.32038727402687, 114.88689601421356, 101.5452191233635, 109.15368005633354, 100.00363424420357, 101.02280035614967, 102.22820207476616, 107.21906706690788, 99.16589319705963, 101.76269665360451, 97.6575793325901, 101.29563331604004, 90.89610815048218, 88.2402254641056, 83.7181869149208, 82.99401417374611, 77.05142945051193, 76.40806317329407, 79.16442766785622, 85.5392087996006, 88.08133319020271, 90.87672159075737, 84.70376282930374, 86.07487365603447, 84.85978245735168, 86.6035544872284, 87.1519410610199, 92.64728218317032, 92.93652266263962, 85.7815369963646, 79.00878801941872, 83.77970561385155, 72.10302338004112, 80.28981328010559, 78.39253708720207, 81.17808401584625, 85.78725188970566, 81.73663884401321, 80.32368466258049, 75.75556978583336, 71.71647012233734, 70.70034384727478, 71.7859759926796, 70.43880388140678, 68.89968127012253, 68.7417009472847, 53.31565350294113, 69.66572776436806, 67.9451496899128, 65.56472942233086, 63.84079232811928, 63.861060440540314, 64.72378894686699, 73.62760037183762, 83.58525484800339, 83.18396598100662, 85.87864458560944, 85.58596149086952, 80.91707602143288, 78.93660709261894, 77.66734600067139, 87.29544416069984, 83.7787252664566, 85.99542751908302, 77.60197430849075, 76.7850561439991, 79.5704434812069, 77.49738112092018, 71.81581199169159, 77.71024569869041, 73.39778870344162, 75.6046874821186, 79.2704039812088, 70.47035738825798, 67.907425314188, 67.10365444421768, 79.25221055746078, 77.55252376198769, 74.42241132259369, 74.11461263895035, 74.82936948537827, 74.27551880478859, 78.43916058540344, 80.53067475557327, 83.01783889532089, 82.90659606456757, 77.71463826298714, 80.83260655403137, 76.23115986585617, 73.88986989855766, 51.37849844992161, 16.43460262566805, 4.454202214255929, 0.5953271174803376, 0.7301539171021432, 0.9233158989809453, 0.8541826461441815, 0.13995569315738976, 1.021945069078356, 0.22551539033884183, 1.4648590399883687, 1.3195377378724515, 3.4603688679635525, 1.5282842866145074, 0.8793147350661457, 10.034562349319458, 85.47981038689613, 99.71158191561699, 101.5113553404808, 99.5095543563366, 114.39514920115471, 48.48687261343002, 35.07075011730194, 31.762917414307594, 63.07183139026165, 68.10569867491722, 81.4423218369484, 88.77468198537827, 65.48443213105202, 0.4202800994971767, 0.16525669489055872, 0.27738823264371604, 0.14961789187509567, 0.22349934617523104, 0.10159261029912159, 0.151737391424831, 0.26693496387451887, 0.15541454020421952, 0.12019773304928094, 0.16543495876248926, 0.1677602410200052, 0.1642375034862198, 0.16135608544573188, 0.15565976063953713], [0.08291417077998631, 0.1443586772074923, 0.027470026652736124, 0.04778284048370551, 0.004334349769123946, 0.033671421915641986, 0.10814260531333275, 0.016022931231418625, 0.03501610815874301, 0.020788274450751487, 0.08848279423546046, 0.025788143757381476, 0.09263223837479018, 0.06892238641739823, 0.4258337983628735, 7.816850300878286, 74.77165058255196, 78.16821992397308, 60.044872015714645, 45.11487655341625, 53.774676471948624, 44.98563028872013, 45.86528308689594, 95.66007971763611, 102.14494854211807, 88.53257417678833, 3.516574976965785, 0.26086493802722543, 0.021758294860774186, 0.052895863191224635, 0.07799536440870725, 0.12998158461414278, 0.04452099383343011, 0.13017234625294805, 0.09047002822626382, 0.4382212524069473, 0.10824969722307287, 0.42116233496926725, 0.10688574853702448, 0.29755879717413336, 0.19215577805880457, 13.246678188443184, 59.22861881554127, 98.19062232971191, 104.43766951560974, 99.56082880496979, 97.23789945244789, 93.70937839150429, 94.60222408175468, 93.95090103149414, 95.33317565917969, 89.8421511054039, 85.80891832709312, 85.40914937853813, 78.42004001140594, 77.21954762935638, 71.10685363411903, 71.28665998578072, 69.08450335264206, 72.07065671682358, 71.16220146417618, 77.60717242956161, 81.92814856767654, 83.7126012146473, 78.00783053040504, 77.42566376924515, 77.005185931921, 79.41647574305534, 87.116359770298, 92.30953350663185, 75.12527480721474, 71.92641645669937, 72.96461954712868, 74.96047765016556, 78.06383952498436, 77.42724448442459, 82.09598556160927, 81.90983355045319, 78.7805038690567, 76.21294364333153, 81.9161032140255, 80.1507331430912, 78.09910923242569, 82.45279401540756, 71.78110465407372, 70.46764433383942, 68.45279484987259, 55.77865473926067, 48.071877881884575, 68.07329401373863, 75.21439522504807, 77.45155557990074, 73.08824211359024, 70.22321105003357, 71.43141701817513, 69.87505093216896, 65.8456939458847, 72.67521947622299, 89.95289996266365, 81.87344670295715, 69.31687608361244, 68.35657641291618, 64.670120626688, 67.00688123703003, 68.07752698659897, 71.76998645067215, 71.71561896800995, 72.6085938513279, 73.49679619073868, 72.90544912219048, 70.58547601103783, 62.454809099435806, 63.536645248532295, 62.83566266298294, 62.31182277202606, 62.189765721559525, 53.34747679531574, 52.95307315886021, 60.37526048719883, 64.11503881216049, 62.566979080438614, 60.662559270858765, 59.96022395789623, 60.420405864715576, 60.75802154839039, 68.60943004488945, 68.20716843008995, 72.49870374798775, 64.94493708014488, 62.01628603041172, 58.76988083124161, 55.472178384661674, 30.279879793524742, 8.654241766780615, 2.6190548250451684, 1.6269822092726827, 0.1244943228084594, 0.9116422128863633, 0.2818837179802358, 0.4284968913998455, 0.052133885328657925, 0.3521018719766289, 0.040444135447614826, 0.5246956762857735, 0.21181083197006956, 0.4572115349583328, 0.11684179320582189, 0.2501880453201011, 5.185555145144463, 61.040931567549706, 89.03835743665695, 75.6339231133461, 61.2262362241745, 61.353385001420975, 24.81880523264408, 25.302828960120678, 22.032756730914116, 52.02827878296375, 61.69851288199425, 48.86745259165764, 68.39189931750298, 23.91411367803812, 0.10278405417921022, 0.03230009999242611, 0.1021636780933477, 0.10759951648651622, 0.0007836742020117526, 0.06268091703532264, 0.07230941482703201, 0.07996342872502282, 0.04013146863144357, 0.05879081269085873, 0.049026227279682644, 0.0024365749550270266, 0.058951829050784, 0.03151393924781587, 0.026982168456015643, 0.0587465547141619, 0.04264608760422561, 0.06734621318173595, 0.043720988323912024, 0.046043587717576884, 0.1306153045152314, 0.05418156353698578, 0.03868519721436314, 0.04439928903593682, 0.02495807199011324, 0.02703109639696777, 0.02179300139687257, 0.1162525056861341, 0.5626130697783083, 9.62605006992817, 85.13019874691963, 87.13957652449608, 73.95500600337982, 53.05423513054848, 49.567629620432854, 30.625995621085167, 50.84050811827183, 100.65773874521255, 109.31817322969437, 101.94050431251526, 6.800343571230769, 0.4167173453606665, 0.11697484544129111, 0.1939089089864865, 0.02170983818359673, 0.24823251587804407, 0.1088364094903227, 0.1085571690055076, 0.17972041096072644, 0.26445108465850353, 0.2559197408845648, 0.5800018273293972, 0.2616267080884427, 0.28183438000269234, 0.8965655125211924, 12.622264344245195, 67.34085291624069, 104.08563360571861, 106.76952078938484, 103.78811717033386, 103.29737350344658, 100.22531434893608, 98.81288453936577, 99.03697371482849, 98.82529467344284, 94.94495049118996, 86.83513686060905, 87.90205121040344, 81.20386183261871, 79.54237058758736, 73.67895841598511, 75.10410234332085, 72.68246948719025, 75.7259313762188, 73.99322435259819, 80.50063356757164, 86.52774095535278, 86.88375145196915, 80.59280142188072, 81.19044095277786, 78.14120337367058, 83.25612410902977, 91.06366395950317, 92.27508455514908, 79.09877479076385, 75.82128345966339, 77.22535371780396, 80.19588232040405, 82.43159115314484, 80.0806725025177, 85.94381868839264, 82.13398352265358, 81.96743845939636, 81.21017709374428, 84.31623682379723, 83.95901799201965, 82.05264508724213, 83.55949983000755, 71.91936403512955, 73.21551248431206, 73.69029700756073, 64.0722531080246, 62.86381535232067, 72.62145236134529, 74.85116511583328, 78.85991960763931, 74.75226402282715, 74.1776816546917, 74.8183424770832, 72.24551573395729, 67.22679823637009, 74.84846726059914, 87.9358921945095, 79.0059381723404, 70.53232446312904, 69.57507982850075, 68.22855368256569, 66.60694509744644, 69.66076523065567, 73.01710233092308, 71.49852901697159, 74.3752558529377, 77.27709174156189, 76.46587327122688, 76.50729104876518, 69.51539263129234, 66.08454912900925, 69.14688840508461, 66.9013001024723, 67.49437227845192, 60.206728130578995, 62.930695563554764, 63.096146285533905, 68.34102004766464, 64.75677117705345, 64.13143113255501, 65.51727756857872, 65.5071473121643, 65.67594945430756, 74.98328402638435, 72.80064314603806, 76.37008801102638, 71.39182314276695, 71.41112610697746, 65.1790501177311, 70.3426918387413, 47.67070680856705, 14.644170049577951, 5.950490674003959, 2.300991229712963, 0.1306242251303047, 1.1380619695410132, 1.5711376746185124, 1.0470610088668764, 0.07015738694462925, 0.3568063164129853, 0.0997786084190011, 0.44077774335164577, 0.1586815930204466, 0.32312305353116244, 0.040284035640070215, 0.291224715183489, 9.383976459503174, 75.91603517532349, 94.3549257516861, 90.13397544622421, 57.129744440317154, 32.37713165581226, 29.96215984225273, 39.138865023851395, 40.88534250855446, 62.90102295577526, 75.87603092193604, 59.5855450630188, 85.8663560450077, 27.841799519956112, 0.12130552946473472, 0.10759943485027179, 0.03491475305054337, 0.02476080357155297, 0.04829512276046444, 0.037383184462669306, 0.04370238268165849, 0.02675052561244229, 0.05615365029370878, 0.05078369234979618, 0.011833096632472007, 0.11703015770763159, 0.037126071110833436, 0.028507653005362954, 0.12419348582625389, 0.2454945698264055, 0.12143194689997472, 0.23428439948474988, 0.07070103980368003, 0.2280114110908471, 0.2541619195835665, 0.17966284998692572, 0.18107448908267543, 0.16615114611340687, 0.19609480106737465, 0.10024804651038721, 0.1869929683743976, 0.3666559519479051, 0.9283829864580184, 14.278986845165491, 101.64496377110481, 97.28722840547562, 79.18751522898674, 61.9063351303339, 72.42652282118797, 62.99556948244572, 65.54722756147385, 119.66449365019798, 119.4506487250328, 113.67466226220131, 8.308020494878292, 0.6780101463664323, 0.24401487578870729, 0.7633374771103263, 0.19912994757760316, 0.8731747989077121, 0.24307743937242776, 0.375292383832857, 0.8660089771728963, 1.231670540291816, 0.444360357359983, 0.5973976501263678, 1.3283967250026762, 2.260822872631252, 1.2999635632149875, 15.741073340177536, 80.27070790529251, 107.87179604172707, 111.06341198086739, 110.41452080011368, 105.45634925365448, 103.3491799235344, 101.03771835565567, 102.49939352273941, 105.6965571641922, 99.600460678339, 89.94422882795334, 91.66353017091751, 84.50796693563461, 84.4738295674324, 75.74154853820801, 79.44411545991898, 75.24402603507042, 79.84721302986145, 77.74371430277824, 83.82044702768326, 88.37302833795547, 89.07032892107964, 86.01337015628815, 86.98496282100677, 82.42421194911003, 88.02445024251938, 89.16802927851677, 96.63619413971901, 85.89566767215729, 83.27396035194397, 80.66242128610611, 84.39675450325012, 84.17660191655159, 87.00015440583229, 91.70418798923492, 87.16973170638084, 87.78060972690582, 85.56627854704857, 87.58556619286537, 87.69740179181099, 83.80118206143379, 85.98127707839012, 74.76758480072021, 75.51337838172913, 75.85852146148682, 66.00070282816887, 60.0079569965601, 71.2066362798214, 77.41556391119957, 80.41135355830193, 77.29134857654572, 75.35212263464928, 75.27421161532402, 72.22055867314339, 71.34943261742592, 79.96906489133835, 89.20943185687065, 82.23556727170944, 72.41875603795052, 73.23860764503479, 68.8772700726986, 71.06447830796242, 72.03078165650368, 78.63687917590141, 77.20320090651512, 80.22840857505798, 81.27153620123863, 80.56000158190727, 77.34284341335297, 73.58213201165199, 70.99995017051697, 75.34637734293938, 72.62093558907509, 75.48787415027618, 68.04715901613235, 72.34570875763893, 77.16293066740036, 79.62014481425285, 74.96031045913696, 73.54582875967026, 71.52156338095665, 73.84905248880386, 72.01760396361351, 83.29913780093193, 80.14743492007256, 86.07183381915092, 75.06719872355461, 78.75796347856522, 73.28487396240234, 75.81003606319427, 55.30523054301739, 23.72250135987997, 7.968804147094488, 2.730597364716232, 0.22715124709066004, 2.7008744096383452, 3.498779581859708, 1.6635845764540136, 0.3159308707108721, 0.8641793753486127, 0.3187753743259236, 1.8139859684742987, 1.399476898368448, 0.7475858379621059, 0.3373359236866236, 0.5707340652588755, 12.865489292889833, 85.03812968730927, 108.4897492825985, 95.24493679404259, 88.33492398262024, 84.34784352779388, 33.40776175260544, 36.70886501669884, 35.444794446229935, 68.60426992177963, 80.1509003341198, 69.7381366789341, 94.2733745276928, 39.956166967749596, 0.14794791117310524, 0.29020613234024495, 0.12577287998283282, 0.17816344450693578, 0.17352178576402366, 0.16677668754709885, 0.3612483077449724, 0.15077245101565495, 0.17353449133224785, 0.1655454793944955, 0.20720654778415337, 0.23156913346610963, 0.1584606259712018, 0.11679356844979338], [0.019621900319179986, 0.035942048707511276, 0.033189738387591206, 0.01455351408367278, 0.03905322082573548, 0.0559930792223895, 0.03429472948482726, 0.053521957524935715, 0.04512218169111293, 0.040533783176215366, 0.029772005473205354, 0.06513858359539881, 0.038469651553896256, 0.11467633245047182, 0.18267644452862442, 28.13033513724804, 83.42810288071632, 66.11887648701668, 71.87235295772552, 48.15326191484928, 53.25043760240078, 42.39875569939613, 48.356197625398636, 93.18237707018852, 107.11400270462036, 13.132383171468973, 0.6232195801567286, 0.11284569904091768, 0.407340606325306, 0.17487145552877337, 0.24677211767993867, 0.10851043596630916, 0.4171157896053046, 0.18637262197444215, 0.19757535599637777, 0.3439755330327898, 0.07590331690153107, 0.5521923664491624, 0.045388278740574606, 0.47329892171546817, 1.096351370215416, 13.271743543446064, 80.9537060558796, 98.836580067873, 94.8884779214859, 91.10160112380981, 93.42905223369598, 92.40495398640633, 95.0460022687912, 91.10111474990845, 88.08404624462128, 84.0364046394825, 77.32976451516151, 74.56111147999763, 73.02006617188454, 68.17002922296524, 69.22014087438583, 67.34944805502892, 70.21811932325363, 71.93446442484856, 75.96800118684769, 80.05403593182564, 80.92094421386719, 78.37822705507278, 77.82189130783081, 74.96204316616058, 81.1746945977211, 89.15572553873062, 83.75987827777863, 73.71263220906258, 78.32946807146072, 76.1944006383419, 75.54021254181862, 75.24879857897758, 75.38157865405083, 74.7424453496933, 78.29482913017273, 74.9697795510292, 79.95348572731018, 79.27582249045372, 81.80755063891411, 79.6165806055069, 80.14548942446709, 80.04308491945267, 72.13605120778084, 79.19864103198051, 78.70551869273186, 73.05248603224754, 84.22109752893448, 74.75631460547447, 70.47445356845856, 76.23311296105385, 72.8720261156559, 77.2633820772171, 74.84122484922409, 78.6204868555069, 70.45693650841713, 71.61235570907593, 71.70292764902115, 73.12132313847542, 72.3381319642067, 73.03803160786629, 71.68709009885788, 67.47833713889122, 68.5960927605629, 67.88326621055603, 66.35959357023239, 61.54821954667568, 63.87685999274254, 68.4267358481884, 70.03184571862221, 66.05887770652771, 59.893203154206276, 59.160769656300545, 61.723515540361404, 61.51100434362888, 56.183978989720345, 53.6640378087759, 50.00199571251869, 51.959928050637245, 54.16722200810909, 53.66568312048912, 56.45761750638485, 57.190750166773796, 59.62670065462589, 61.24802805483341, 64.64403122663498, 67.56108909845352, 62.05637767910957, 61.729621812701225, 56.654310151934624, 56.040893867611885, 25.47370959073305, 13.304284047335386, 3.9496783493086696, 3.4630676731467247, 0.6044348131399602, 0.14608761412091553, 1.2715112837031484, 0.10995781689416617, 0.3784167958656326, 0.36547246389091015, 0.1008260904927738, 0.426767835742794, 0.3216328506823629, 0.027529298276931513, 0.04617533748387359, 0.16979915817501023, 0.31549769395496696, 7.360573159530759, 66.13835424184799, 89.00651514530182, 71.71281471848488, 81.04598790407181, 69.47456002235413, 27.51763131469488, 17.78585571795702, 26.905698850750923, 40.350950583815575, 55.22690914571285, 51.98346398770809, 62.82430127263069, 9.227093327790499, 0.4394886625232175, 0.20714969927212223, 0.09245640874723904, 0.012908338740089675, 0.06720915334881283, 0.043036976785515435, 0.053280726133380085, 0.018055352738883812, 0.04087628061824944, 0.04619016188371461, 0.06904572393978015, 0.0437106798926834, 0.007678854972255067, 0.06300292006926611, 0.045138805799069814, 0.018580587347969413, 0.03602676857553888, 0.08854563187924214, 0.04305948612454813, 0.04358894540928304, 0.04265488947567064, 0.018906191653513815, 0.061390017945086583, 0.04788898615515791, 0.05491860523761716, 0.027449111075839028, 0.1466872842865996, 0.1613164399168454, 31.59841474145651, 95.08147716522217, 75.35722196102142, 81.54889091849327, 61.739003509283066, 71.19199946522713, 39.58402633666992, 53.61125484108925, 100.98119258880615, 116.75267189741135, 19.59552951157093, 0.8951196307316422, 0.12205198159790598, 0.9573710372205824, 0.186442636186257, 0.32091816246975213, 0.40044736058916897, 0.4361309786327183, 0.22979596455115825, 0.18134071229724213, 0.3127977013355121, 0.1419830773374997, 0.8371954795438796, 0.35456746467389166, 0.11456984910182655, 0.9298138471785933, 19.40358281135559, 88.08540657162666, 101.0175110399723, 98.96926894783974, 96.18122175335884, 94.62683916091919, 96.70544162392616, 100.07969096302986, 96.6195510327816, 90.1726421713829, 86.2275418639183, 80.12639924883842, 77.94025495648384, 76.22265592217445, 72.47015208005905, 72.89388254284859, 71.56804248690605, 73.81087973713875, 74.90655094385147, 80.53067475557327, 83.37280064821243, 83.78749519586563, 82.11621567606926, 82.00618878006935, 79.40582871437073, 83.51845443248749, 93.59020918607712, 86.26826047897339, 79.51144024729729, 82.46935352683067, 83.28953951597214, 79.39728677272797, 80.05501627922058, 77.36132562160492, 78.46962735056877, 80.32635971903801, 80.25873094797134, 84.96631354093552, 81.56226620078087, 86.08798295259476, 82.17058315873146, 84.79292124509811, 82.14672803878784, 72.94667690992355, 82.01845452189445, 81.88007354736328, 76.1409755051136, 83.95242914557457, 76.95879802107811, 72.94545337557793, 77.54186153411865, 78.38960364460945, 76.61943063139915, 79.2450213432312, 78.78570199012756, 76.94313526153564, 78.39321345090866, 74.51900213956833, 72.94134199619293, 74.99681890010834, 74.66521069407463, 73.90066891908646, 71.11243933439255, 72.93389439582825, 71.37502804398537, 70.08558243513107, 65.29609143733978, 66.00147038698196, 72.01311260461807, 73.53798598051071, 69.82133701443672, 66.39151945710182, 65.39152711629868, 67.8370150923729, 66.35169759392738, 64.10548612475395, 58.545198887586594, 56.49727217853069, 58.318636044859886, 61.04544572532177, 59.26439769566059, 64.2726543545723, 64.47965204715729, 66.32861763238907, 68.28772410750389, 70.77589899301529, 73.04754629731178, 69.30024817585945, 67.85472214221954, 65.98249420523643, 64.27940279245377, 47.09607884287834, 28.320955708622932, 8.605009708553553, 4.788527749478817, 0.8467696001753211, 0.17527602991322055, 1.7608929611742496, 0.1295357319759205, 0.44860817317385226, 0.1573331849067472, 0.14140175306238234, 0.8551524253562093, 0.18770145223243162, 0.11962593795033172, 0.11948233237490058, 0.15230636636260897, 0.5740186921320856, 11.368986144661903, 78.93420562148094, 96.7896831035614, 81.0114249587059, 55.024323016405106, 31.341746114194393, 30.1974356174469, 31.375986076891422, 48.50990317761898, 52.71802917122841, 66.97856515645981, 59.134117886424065, 79.59159314632416, 9.46842122823, 0.4159424838144332, 0.2383992966497317, 0.06773397049983032, 0.046045309500186704, 0.0835228877258487, 0.03789556692936458, 0.0399467480747262, 0.04305799440771807, 0.06899583677295595, 0.013183236733311787, 0.05449658667203039, 0.053464348311536014, 0.06216554742422886, 0.13789924647426233, 0.23567677242681384, 0.148737853160128, 0.08135979442158714, 0.2628048526821658, 0.13049850531388074, 0.16332718514604494, 0.14119424857199192, 0.12759730161633343, 0.17868401657324284, 0.14404988440219313, 0.25354433397296816, 0.14888030098518357, 0.28480231761932373, 0.4452592763118446, 40.66000320017338, 111.6183190047741, 83.78586888313293, 91.62092685699463, 65.10459691286087, 69.27131652832031, 61.77323207259178, 71.67114615440369, 109.0195320546627, 131.6324758529663, 20.75033314526081, 1.0948074655607343, 0.5692554695997387, 1.331661343574524, 0.6902823597192764, 0.6448974763043225, 0.9336040844209492, 1.1709746159613132, 0.5747333506587893, 0.30816426558885723, 0.9908564435318112, 0.4475236579310149, 1.9284344022162259, 0.8137002121657133, 1.7181407427415252, 1.71992854680866, 25.090692043304443, 95.00748753547668, 103.58091428875923, 103.58179584145546, 97.4255333840847, 97.9024837911129, 100.63753142952919, 102.6772391796112, 100.07061704993248, 94.35017600655556, 91.29471436142921, 84.15745854377747, 80.49055650830269, 79.3095114827156, 76.5721383690834, 76.20721355080605, 73.46128329634666, 77.32351765036583, 77.72295221686363, 82.89756774902344, 86.05754658579826, 88.158408254385, 87.01200976967812, 85.6715252995491, 85.01359060406685, 86.02564349770546, 90.78864231705666, 92.9385669529438, 86.88322708010674, 87.78818652033806, 87.92255491018295, 83.59561309218407, 83.43452453613281, 84.1000360250473, 83.96030232310295, 86.81329563260078, 86.61936163902283, 88.16441193223, 84.1965888440609, 91.37808188796043, 87.43164405226707, 87.45354607701302, 85.80215469002724, 75.26557847857475, 85.82198202610016, 87.01545998454094, 78.07161390781403, 89.16044488549232, 79.01320338249207, 75.12289613485336, 83.63434821367264, 81.04661867022514, 82.65891015529633, 83.92956957221031, 83.93531486392021, 79.38146442174911, 78.82043972611427, 74.20740365982056, 77.07323268055916, 77.50351399183273, 77.0617724955082, 75.42311802506447, 73.82021963596344, 75.84800362586975, 71.50129526853561, 73.035037368536, 70.26146739721298, 69.97898295521736, 76.9033969938755, 79.84068498015404, 72.97411903738976, 73.28450158238411, 72.76316195726395, 73.25623869895935, 73.09762760996819, 74.42203134298325, 71.73052176833153, 68.09087187051773, 66.15815877914429, 69.731874614954, 65.87258130311966, 70.24157926440239, 67.84191682934761, 70.50652384757996, 72.55119413137436, 77.20097422599792, 78.27579215168953, 78.0259707570076, 74.8239053785801, 72.89015874266624, 72.7402263879776, 58.05233873426914, 37.07385063171387, 12.149885091930628, 6.601914893835783, 1.1979307257570326, 0.6239461724180728, 4.257763205096126, 1.13337610848248, 1.0589050920680165, 0.6874747853726149, 0.3729045978980139, 1.9166627526283264, 0.7246596494223922, 0.4058358573820442, 0.29721595463342965, 0.3665086504770443, 0.8936456660740077, 16.122323982417583, 89.01126489043236, 108.72859686613083, 94.53100070357323, 113.88295948505402, 91.88711777329445, 38.1466318666935, 26.224760189652443, 41.000727117061615, 56.687163189053535, 77.4019530415535, 68.98706138134003, 95.78169599175453, 15.419641938060522, 0.5915745813399553, 0.47948855208233, 0.2612970757763833, 0.26789085008203983, 0.18067861266899854, 0.15888082998571917, 0.18933392479084432, 0.15174190368270501, 0.13663842662936077, 0.12971083429874852, 0.12521873315563425, 0.20180967956548557, 0.16976797312963754], [0.06069745315471664, 0.07914000103482977, 0.07090028419042937, 0.10165324376430362, 0.08748039021156728, 0.025202696851920336, 0.03121755515167024, 0.050348122167633846, 0.010239712064503692, 0.007174739102993044, 0.016001865369617008, 0.1237417702213861, 0.05370826998841949, 0.05561958227190189, 0.1433608596562408, 52.63845004141331, 75.12631595134735, 74.03770476579666, 55.65106138586998, 44.65804986655712, 36.64157062768936, 37.659946382045746, 73.38553056120872, 116.28183156251907, 48.26867312192917, 0.278971025836654, 0.17816000094171613, 0.067278521892149, 0.20509392052190378, 0.10647029426763766, 0.14340666501084343, 0.17163337615784258, 0.42660827399231493, 0.5191363370977342, 0.0166904132856871, 0.13250623742351308, 0.05354250388336368, 0.19714908121386543, 0.0834043073700741, 0.17592816991964355, 0.6079357315320522, 50.09436875581741, 101.36688709259033, 80.83646714687347, 90.29120340943336, 89.44655433297157, 84.8401603102684, 90.32371446490288, 85.97923278808594, 87.16450318694115, 82.92666658759117, 78.94616737961769, 70.9857389330864, 71.56561821699142, 72.2941455245018, 74.51207131147385, 70.57536095380783, 72.0704135298729, 71.48898392915726, 73.87527868151665, 76.23969420790672, 77.3980164527893, 77.2327709197998, 76.35662913322449, 75.72340831160545, 80.60028702020645, 90.10295391082764, 78.52349326014519, 75.00247299671173, 82.16934442520142, 77.85156011581421, 77.30714812874794, 76.41798824071884, 72.10278779268265, 74.91123229265213, 76.41322329640388, 77.1318331360817, 82.73687437176704, 82.37743645906448, 81.46096363663673, 78.72666075825691, 81.37910842895508, 79.3826575577259, 78.33066120743752, 78.13532888889313, 79.66739147901535, 80.25949090719223, 74.89135935902596, 77.3114039003849, 74.59940582513809, 73.3536046743393, 74.09456491470337, 74.06640082597733, 72.93691903352737, 76.04889124631882, 73.27057152986526, 76.19867160916328, 76.63007006049156, 77.00992047786713, 71.76361039280891, 75.5455930531025, 74.09324258565903, 70.96289455890656, 75.359425842762, 75.56592956185341, 74.5467634499073, 71.20258569717407, 68.46914157271385, 65.14770939946175, 64.24499183893204, 61.3054733723402, 59.07237879931927, 51.14245131611824, 52.60466605424881, 57.72168807685375, 59.61901366710663, 57.9542887955904, 51.72905243933201, 51.55972592532635, 53.44393081963062, 55.3874771296978, 57.680726274847984, 60.794822573661804, 57.09243044257164, 57.55066305398941, 60.77098645269871, 61.744653806090355, 59.77489650249481, 64.20222133398056, 61.391432359814644, 64.55682590603828, 49.16424706578255, 37.53212124109268, 9.293009340763092, 7.631510496139526, 3.4922382328659296, 2.66404393594712, 0.2260778343770653, 1.2267165561206639, 0.9525822254363447, 0.09167231488390826, 0.34308905247598886, 0.1490286859916523, 0.39709439675789326, 0.2634549146750942, 0.27144549996592104, 0.11075494287069887, 0.07628316292539239, 0.11283789164735936, 0.32324586412869394, 14.408627338707447, 79.03902679681778, 83.39990839362144, 77.45657131075859, 90.29916778206825, 63.08077611029148, 37.005822882056236, 22.56155915558338, 26.514116562902927, 37.15402252972126, 61.67957469820976, 55.13583563268185, 50.2681790292263, 0.7495275931432843, 0.09012277732836083, 0.04462119861273095, 0.02749509825662244, 0.015425673973368248, 0.053696043105446734, 0.0394895034696674, 0.026817884790943936, 0.07511581658036448, 0.0149338026130863, 0.016472262686875183, 0.03916408655641135, 0.07437044056132436, 0.07284036953933537, 0.013521441778721055, 0.021746704369434156, 0.004547925027509336, 0.029448863242578227, 0.037201180166448466, 0.04716411196568515, 0.014375729824678274, 0.06431473288103007, 0.08765416409005411, 0.03947411874833051, 0.12064676207955927, 0.059947460977127776, 0.08047074603382498, 0.19430162385106087, 64.41416636109352, 82.49753281474113, 80.49010813236237, 70.76786622405052, 58.47335994243622, 38.681833148002625, 29.441963955760002, 83.19444581866264, 119.39117431640625, 60.77769689261913, 0.2886752597987652, 0.21846043062396348, 0.19470596074825153, 0.22296722629107535, 0.1509068688028492, 0.44033114856574684, 0.14729455404449254, 0.31880215101409703, 1.3539380044676363, 0.08579194487538189, 0.08135649186442606, 0.10059339751023799, 0.353196628857404, 0.16611083265161142, 0.39042596239596605, 1.1253700568340719, 59.12074640393257, 107.76455819606781, 89.41581398248672, 93.818379342556, 94.53643441200256, 91.68593376874924, 94.3591359257698, 92.950399518013, 90.587587505579, 84.68090325593948, 80.35437941551208, 73.50032240152359, 76.53549313545227, 76.41352728009224, 80.75578987598419, 77.1578997373581, 76.39835089445114, 76.79613634943962, 73.4388493001461, 79.56077679991722, 79.6570636332035, 80.09182870388031, 80.33685475587845, 79.86583203077316, 81.18698313832283, 97.44548231363297, 79.805498868227, 79.3414905667305, 85.06190121173859, 82.3389445245266, 82.70529806613922, 80.24479329586029, 77.64425843954086, 78.59414666891098, 81.21664434671402, 81.28665179014206, 86.53759762644768, 84.25992384552956, 85.03163203597069, 82.09516480565071, 83.67801547050476, 82.22314193844795, 81.52847081422806, 81.81530222296715, 81.41804113984108, 81.27981975674629, 76.7511011660099, 80.47385260462761, 78.59259635210037, 75.94918459653854, 77.59619101881981, 75.69965198636055, 77.17816784977913, 77.71396189928055, 76.49832352995872, 77.80119761824608, 76.77942484617233, 80.99548101425171, 76.995580047369, 78.67752179503441, 77.55503922700882, 74.7168955206871, 77.68659576773643, 77.21413671970367, 76.353809684515, 76.04352593421936, 71.98670402169228, 72.00532302260399, 66.28281489014626, 63.6522426456213, 60.551966205239296, 57.30805367231369, 57.45869278907776, 64.66536328196526, 66.22328728437424, 66.95972576737404, 60.78136369585991, 60.29005005955696, 61.11773684620857, 64.53696057200432, 63.10747727751732, 65.5392175912857, 64.37875226140022, 63.441684544086456, 65.53965076804161, 69.86635699868202, 67.64953315258026, 70.25457456707954, 66.9766728579998, 72.00166001915932, 56.9300651550293, 53.226054310798645, 36.34040258824825, 7.502891197800636, 9.021904338151217, 2.6954366639256477, 0.12878153182100505, 1.7495451075956225, 1.3135643396526575, 0.5313302983995527, 0.557738346979022, 0.24431587604340166, 0.5874560179654509, 0.8236598933581263, 0.015002286145318067, 0.04004804381111171, 0.23930228257086128, 0.10712924718973227, 0.1948892415384762, 23.464673794806004, 91.63602724671364, 93.44849199056625, 85.29264003038406, 59.43481095135212, 36.84583626687527, 34.15418229997158, 29.44691129028797, 37.069161683321, 53.950417041778564, 77.51027762889862, 67.24727153778076, 61.166036054492, 0.5824925343040377, 0.07655836612684652, 0.08386371162487194, 0.024623953395348508, 0.016538148702238686, 0.03075209868256934, 0.03952288898290135, 0.059661930790753104, 0.05843352795636747, 0.033410931791877374, 0.05324328478309326, 0.006925330635567661, 0.05213857199123595, 0.166398860164918, 0.18737033562501892, 0.12191810557851568, 0.2337285308749415, 0.1839186216238886, 0.08518057846231386, 0.13764106814051047, 0.07970678663696162, 0.16911678307224065, 0.15430158586241305, 0.16175617725821212, 0.26513391989283264, 0.11959227413171902, 0.2453134857933037, 0.3437888977350667, 79.40841257572174, 92.78220534324646, 94.49121683835983, 70.10553136467934, 59.845344722270966, 49.35207478702068, 50.920744612812996, 98.49362567067146, 134.0753799676895, 65.6469114124775, 0.6044646771624684, 0.6105720181949437, 0.24006374093005434, 0.5815023311879486, 1.1974570574238896, 0.4946165200090036, 0.9500002639833838, 1.570161720737815, 2.1550481859594584, 0.1749398815445602, 0.3961544221965596, 0.34712271415628493, 0.5009881546720862, 0.2878835366573185, 1.1430043168365955, 1.5893682651221752, 69.6009412407875, 109.98352512717247, 94.1639631986618, 102.89138048887253, 94.42139938473701, 93.26903522014618, 95.3080666065216, 95.87859079241753, 95.1128862798214, 90.20242497324944, 83.89743849635124, 75.71191012859344, 79.1314834356308, 79.32908043265343, 81.86795979738235, 78.7075325846672, 79.8415133357048, 78.49766984581947, 78.84146019816399, 84.59391832351685, 85.1124233007431, 86.05095773935318, 87.450962215662, 84.99696269631386, 86.87255725264549, 96.83905005455017, 89.95558261871338, 86.06808722019196, 88.39060619473457, 87.35919713973999, 85.46329647302628, 83.70324611663818, 82.0582763850689, 86.25586554408073, 86.10189780592918, 86.90293282270432, 90.1046334207058, 89.96278703212738, 89.02191951870918, 85.90732544660568, 87.95910134911537, 84.5606929063797, 83.68949845433235, 84.45274829864502, 85.24106159806252, 85.65570294857025, 80.95726266503334, 84.61072102189064, 81.11412584781647, 78.46680030226707, 79.27123993635178, 80.05396753549576, 79.46825176477432, 82.39062175154686, 79.08085495233536, 82.72720009088516, 80.85322424769402, 84.01279270648956, 80.68087309598923, 81.54938489198685, 77.63618767261505, 76.18160292506218, 84.18407991528511, 82.99809515476227, 80.61227917671204, 79.76588979363441, 73.20197761058807, 72.04310819506645, 71.0915556550026, 70.08437409996986, 67.92785301804543, 62.81746543943882, 65.38790211081505, 72.71444857120514, 72.19788908958435, 72.04768314957619, 66.54012188315392, 69.08387258648872, 69.62156653404236, 69.87081035971642, 68.36983770132065, 70.29682070016861, 67.22549870610237, 68.9173199236393, 71.34925782680511, 73.196080327034, 70.69429457187653, 77.63713002204895, 76.57502621412277, 79.06415104866028, 67.34221324324608, 60.963780507445335, 48.495980724692345, 15.237113982439041, 10.185746736824512, 3.1929073948413134, 0.4683927318546921, 3.6591504514217377, 1.8084395723417401, 1.0734997526742518, 1.081649602856487, 0.41119318397250026, 1.7624127608723938, 1.4278016472235322, 0.8944507478736341, 0.25299986475147307, 0.4413621994899586, 0.3215741319581866, 0.77399424277246, 31.93273790180683, 102.09019348025322, 100.73560416698456, 101.46714851260185, 127.71870106458664, 83.4435224533081, 50.712675377726555, 33.492721393704414, 42.43181012570858, 55.613386407494545, 85.84535837173462, 73.7360617518425, 76.52782514691353, 1.3632517796941102, 0.20317643356975168, 0.15792838734341785, 0.2084933131118305, 0.11653970199404284, 0.1658310429775156, 0.11209076415980235, 0.14911798120010644, 0.21892372373258695, 0.17315051896730438, 0.11456158899818547, 0.12896928034024313, 0.23648069647606462], [0.036411716864677146, 0.06882001456688158, 0.008669893468322698, 0.0589957382180728, 0.11098051123553887, 0.0543826929788338, 0.05626479061902501, 0.023669096917728893, 0.033474875235697255, 0.04394886105728801, 0.08184377118595876, 0.041695574545883574, 0.11747937969630584, 0.11255791643634439, 3.383352938108146, 62.31874220073223, 72.12845161557198, 66.70381709933281, 52.13805489242077, 48.61777178943157, 75.97843542695045, 68.5870872437954, 92.39461854100227, 92.07573965191841, 5.592195075005293, 0.453678258927539, 0.027764347578340676, 0.2656067570205778, 0.143409856245853, 0.23888185591204092, 0.040010223965509795, 0.25927902781404555, 0.7492085290141404, 0.4083330952562392, 0.15896967990556732, 0.03646256882348098, 0.20397525164298713, 0.9295158600434661, 0.14401763066416606, 0.33581971598323435, 17.67937023192644, 98.21158960461617, 81.05929479002953, 81.36640191078186, 86.5406146645546, 96.16464704275131, 96.03758946061134, 91.09173685312271, 87.07538276910782, 84.04185354709625, 75.19680216908455, 71.20549634099007, 71.18248477578163, 77.21688777208328, 79.19227257370949, 82.07213044166565, 78.9305730164051, 78.8383899629116, 80.0934474170208, 76.7664447426796, 73.6343564093113, 78.78122583031654, 72.82355591654778, 74.2393371462822, 78.28482046723366, 86.95676073431969, 79.29181963205338, 69.15035381913185, 86.49554148316383, 79.02963370084763, 79.36093792319298, 78.3110922574997, 75.57102888822556, 71.82686179876328, 71.92181870341301, 75.28350591659546, 77.98586010932922, 79.43502634763718, 80.81056773662567, 76.31614610552788, 78.84651392698288, 78.99717584252357, 75.85922822356224, 76.2796376645565, 79.48532044887543, 74.42350566387177, 66.77345216274261, 66.5822084248066, 77.16694325208664, 75.01190409064293, 74.92317125201225, 73.98967534303665, 76.05630084872246, 76.50359764695168, 74.75439950823784, 75.05540415644646, 73.09667006134987, 72.49434918165207, 75.43222233653069, 75.67653402686119, 75.63475906848907, 74.8799979686737, 77.56219804286957, 75.64951747655869, 69.81296986341476, 70.98698526620865, 70.00026181340218, 70.56991204619408, 70.35994291305542, 61.653937473893166, 56.30625642836094, 55.54967142641544, 49.75062020123005, 50.38030721247196, 51.016073897480965, 52.52959728240967, 61.02258615195751, 57.59968802332878, 54.254305735230446, 59.0396511554718, 62.20527268946171, 59.509685933589935, 58.11597391963005, 59.2591767758131, 58.386386409401894, 62.17321000993252, 65.01376658678055, 62.44393788278103, 57.929715514183044, 58.539514392614365, 62.71701402962208, 52.181098982691765, 44.43477764725685, 23.76281339675188, 11.543495580554008, 4.3137693498283625, 3.410900034941733, 0.6423953699413687, 0.2275546340388246, 0.37526670552324504, 0.4130960803013295, 0.11857268938911147, 0.3719389153411612, 1.3355152867734432, 0.5099238501861691, 0.05878778472833801, 0.1678355096373707, 0.06822458206443116, 0.04954561933118384, 0.09556745470035821, 0.8004692627582699, 27.76913031935692, 90.31027838587761, 79.58998963236809, 60.47540411353111, 71.31093308329582, 70.75324460864067, 36.63522496819496, 47.40996100008488, 48.01962688565254, 29.014623686671257, 52.73269638419151, 67.02233120799065, 11.55748737975955, 0.4623941006138921, 0.25849267782177776, 0.12545835779746994, 0.10183216814766638, 0.1282835952588357, 0.049619043711572886, 0.04859744032728486, 0.05809894923004322, 0.08784395351540297, 0.05502274711034261, 0.009257949950551847, 0.013874472151655937, 0.013522877834475366, 0.09741557310917415, 0.030013396426511463, 0.05611735185084399, 0.017235153391084168, 0.05401690323196817, 0.046483191472361796, 0.0042791706255229656, 0.033656489904387854, 0.04235729567881208, 0.06184921810927335, 0.0649295502807945, 0.05823787927511148, 0.15806981100467965, 3.721688208170235, 73.64658415317535, 80.91976627707481, 81.30005747079849, 53.78987945616245, 60.28286084532738, 41.72543942928314, 54.23501797020435, 100.55177763104439, 104.44257885217667, 9.41179571673274, 0.642261664615944, 0.056637107554706745, 0.5131297500338405, 0.09442677372135222, 0.6623101013246924, 0.05675006985256914, 0.3407760156551376, 0.9014867234509438, 1.1498809978365898, 0.27415911841671914, 0.10295635860529728, 0.5370142590254545, 1.6918669338338077, 0.12467453110730276, 0.393737128470093, 25.058560967445374, 104.83275711536407, 87.8919817507267, 89.79469925165176, 92.07870349287987, 100.88127315044403, 100.78661262989044, 97.73174375295639, 90.21703138947487, 86.25458881258965, 76.62457555532455, 75.04790335893631, 72.40631550550461, 82.30407759547234, 83.81159350275993, 87.64534458518028, 85.90966612100601, 83.7602810561657, 83.81581887602806, 79.58124250173569, 76.67920902371407, 82.97397404909134, 77.67369166016579, 79.24638167023659, 80.10355487465858, 90.05405813455582, 82.82709673047066, 74.84657496213913, 90.22052720189095, 83.75734001398087, 83.8744269311428, 81.05441585183144, 80.73731526732445, 79.32876124978065, 77.1216268837452, 80.98422601819038, 79.76275116205215, 83.54731008410454, 85.02423003315926, 81.38028636574745, 82.53762066364288, 79.03344869613647, 77.38591030240059, 79.171442091465, 82.11521252989769, 76.45553782582283, 68.70888590812683, 69.01007294654846, 75.9311355650425, 78.75185340642929, 78.13057154417038, 78.48867192864418, 75.60756772756577, 77.66846314072609, 78.8166855275631, 78.65322589874268, 75.85007831454277, 75.06142303347588, 78.8814340531826, 76.76504641771317, 77.19696164131165, 75.74983209371567, 75.89002177119255, 76.15299046039581, 73.39582040905952, 73.05755496025085, 74.25970405340195, 75.31754449009895, 73.23154762387276, 64.37729313969612, 63.797467052936554, 62.336179465055466, 58.6969019472599, 57.66366519033909, 58.30147996544838, 58.94268035888672, 63.39765250682831, 65.92862829566002, 63.112303018569946, 64.35659945011139, 68.24628353118896, 64.04877796769142, 63.49249541759491, 64.99530717730522, 66.41670450568199, 68.1609857082367, 71.33573055267334, 72.18406543135643, 67.0778538286686, 65.35909205675125, 69.46481734514236, 64.34900745749474, 58.36187772452831, 45.50665833055973, 14.639545697718859, 9.029282592236996, 6.260870844125748, 1.0238723969087005, 0.19041057326830924, 2.0040010660886765, 0.5649544566404074, 0.5380687024444342, 0.649082773597911, 1.324715910013765, 0.9094700356945395, 0.07590788853121921, 0.1349435542942956, 0.12070735843735747, 0.16111748496768996, 0.07262109458679333, 0.6208033848088235, 41.24973155558109, 97.52492845058441, 89.42931845784187, 65.89652761816978, 48.31438086926937, 33.91995906829834, 28.08422651141882, 49.389962553977966, 52.598324194550514, 51.369432136416435, 60.134619399905205, 83.09530913829803, 13.362298384308815, 0.4182234004838392, 0.21760326490039006, 0.10289749887306243, 0.07455843398929574, 0.13739767338847741, 0.06407490785932168, 0.02999572032422293, 0.07594989408971742, 0.043639062641886994, 0.019515749081620015, 0.016107209521578625, 0.04570891993353143, 0.13442011753795668, 0.25317477411590517, 0.10522762735490687, 0.1492617797339335, 0.15522569330642, 0.155490699398797, 0.10631019817083143, 0.1046838631737046, 0.16019992326619104, 0.11153896251926199, 0.16939286200795323, 0.1277901412686333, 0.25644259876571596, 0.2972821838920936, 5.378163484856486, 87.8713184595108, 92.06134602427483, 86.71355098485947, 64.96914178133011, 61.877019703388214, 99.36298862099648, 96.50355845689774, 106.57209098339081, 118.31295177340508, 10.152816753834486, 0.6640423333737999, 0.14737008983502164, 0.7467279746197164, 0.6865583220496774, 1.0384553018957376, 0.725071036722511, 0.786342570791021, 2.848362782970071, 1.5857189171947539, 0.97932287491858, 0.3486453933874145, 1.4740318665280938, 3.286830517463386, 0.44705880631227046, 0.4115780914435163, 30.305334627628326, 106.3206584751606, 92.65042081475258, 97.13193073868752, 95.37069484591484, 107.14341312646866, 103.71998682618141, 101.03243663907051, 93.41443821787834, 93.07408288121223, 80.27303338050842, 79.86810430884361, 74.88830432295799, 84.38287764787674, 85.31748309731483, 91.14173457026482, 87.83430844545364, 86.8277196586132, 87.5820703804493, 84.07571732997894, 80.79123437404633, 86.66088581085205, 84.26542595028877, 81.92679584026337, 87.36276134848595, 91.47810012102127, 87.75370717048645, 80.54925575852394, 92.66517162322998, 89.75521177053452, 89.64671239256859, 87.75689139962196, 84.82430756092072, 85.98566964268684, 83.58791470527649, 84.94634181261063, 83.694688975811, 85.68876877427101, 90.54806962609291, 85.25844186544418, 85.22031471133232, 83.3272410929203, 77.4909670650959, 81.57406076788902, 87.24946662783623, 81.5712109208107, 70.97702220082283, 69.87467855215073, 80.66633507609367, 81.90891399979591, 83.63848239183426, 81.26074478030205, 80.20893082022667, 81.67669326066971, 81.32580488920212, 84.20418843626976, 77.8877417743206, 76.82967334985733, 82.74543911218643, 78.62063884735107, 80.99377110600471, 79.24474015831947, 81.7738388478756, 81.44025474786758, 75.89433833956718, 78.28602120280266, 78.71915236115456, 79.6244689822197, 81.65375009179115, 71.88095569610596, 68.96286427974701, 67.5425460934639, 62.35977239906788, 65.49905374646187, 65.50286114215851, 68.85028392076492, 71.96154937148094, 71.7497943341732, 69.95591059327126, 73.1367427110672, 73.5481770336628, 69.19532060623169, 69.2159155011177, 69.76110264658928, 67.93106764554977, 71.29431277513504, 75.92079252004623, 75.42552709579468, 71.4543753862381, 73.22998970746994, 79.6309894323349, 72.46903494000435, 62.90982328355312, 54.71917279064655, 26.358965188264847, 9.623716995120049, 7.681715777143836, 1.1856712773442268, 1.9757754681631923, 6.674917051568627, 1.2265454465523362, 2.080340632237494, 1.9704907829873264, 2.59340335149318, 2.412598365917802, 0.23996185889700428, 0.46483261976391077, 0.15796214021975175, 0.31396085454616696, 0.13889724214095622, 1.690682228654623, 49.297589510679245, 111.79991886019707, 95.48351839184761, 84.01468500494957, 105.10927587747574, 91.34768351912498, 54.470768719911575, 64.68728050589561, 59.66755986213684, 46.22491858899593, 72.83303260803223, 93.54081943631172, 17.178298719227314, 0.6430445413570851, 0.31796735362149775, 0.2731235255487263, 0.25302640395238996, 0.3140530292876065, 0.1371439330978319, 0.13496280560502782, 0.21045954432338476, 0.18795924464939162, 0.1693998381961137, 0.0930316028825473, 0.0706144014839083], [0.03786486056924332, 0.08157981894328259, 0.02956878688564757, 0.020265141974959988, 0.04582213827234227, 0.04100144011317752, 0.085554932593368, 0.021725451115344185, 0.07177835621405393, 0.0415650567447301, 0.09483112546149641, 0.03825759769824799, 0.08654926205053926, 0.2320956130279228, 5.607108324766159, 69.26262259483337, 62.35057309269905, 74.52116042375565, 81.60561427474022, 50.0823538005352, 45.7565975189209, 68.17144274711609, 111.44612744450569, 34.357444792985916, 0.12307724377023987, 0.16343779483577237, 0.06746495680999942, 0.11052294750697911, 0.09112248735618778, 0.08242239404353313, 0.11781456327298656, 0.012917355834360933, 0.6257511349394917, 0.6002707709558308, 1.8533592182211578, 1.3737786398269236, 0.6044446094892919, 0.5263321415986866, 0.18991576856933534, 4.805593583732843, 87.40522786974907, 77.760479003191, 77.07398504018784, 80.3176961839199, 93.28136175870895, 89.53094020485878, 92.88003489375114, 91.31332576274872, 86.34079858660698, 76.24320521950722, 72.83125430345535, 70.52904903888702, 72.98372492194176, 79.1883435845375, 86.74046114087105, 86.77825391292572, 87.91095793247223, 85.12713611125946, 81.84877082705498, 80.60705065727234, 79.25203576683998, 78.08514878153801, 72.59901836514473, 78.10155630111694, 81.60104691982269, 82.11156472563744, 70.9661927819252, 83.01177442073822, 77.83205196261406, 77.4929429590702, 75.52765801548958, 73.14131006598473, 74.28605183959007, 75.50347611308098, 78.29603746533394, 74.70303386449814, 77.13172674179077, 82.01229885220528, 81.60461112856865, 80.41977390646935, 72.84119457006454, 73.79427462816238, 81.53284057974815, 73.81180688738823, 72.63802707195282, 65.07146269083023, 67.72857651114464, 68.68168696761131, 75.46281069517136, 72.22175180912018, 73.11629220843315, 72.44024008512497, 70.72843194007874, 72.49273806810379, 73.12802597880363, 73.79267871379852, 72.71358221769333, 74.80523318052292, 74.28420513868332, 72.06620335578918, 72.39522010087967, 74.84931841492653, 74.71512481570244, 74.03827473521233, 72.07325577735901, 71.54971987009048, 71.99981331825256, 68.75933960080147, 62.225935980677605, 60.01530580222607, 62.85865142941475, 60.25194190442562, 59.03398185968399, 51.49259492754936, 49.86415810883045, 44.93541978299618, 45.502546951174736, 51.19209945201874, 57.068552523851395, 61.122627183794975, 59.933883771300316, 58.14378842711449, 61.43880821764469, 59.56360504031181, 58.35002236068249, 62.022627890110016, 65.03562301397324, 65.93764901161194, 65.84238812327385, 59.11083273589611, 50.66954389214516, 57.61975474655628, 54.41080033779144, 35.35559803247452, 8.9803003706038, 8.910758402198553, 3.6955152126029134, 2.257449603639543, 0.29520951386075467, 1.2135366071015596, 0.3106300067156553, 0.09819923652685247, 0.1343176863156259, 0.13989531202241778, 0.5027291737496853, 0.10354580197599716, 0.006534840822496335, 0.16232644353294745, 0.13544162444304675, 0.05702447895600926, 0.08334578160429373, 2.717555514536798, 53.99698734283447, 85.42484253644943, 78.20147573947906, 56.42676696181297, 85.98231822252274, 51.38547867536545, 54.2957729101181, 55.75668051838875, 36.960270926356316, 57.71303214132786, 65.92504128813744, 25.73542434722185, 0.6245679734274745, 0.1704527231049724, 0.11365997605025768, 0.13946961611509323, 0.08671784831676632, 0.02531319893023465, 0.049460509835626, 0.051087824467686005, 0.03198187449015677, 0.03582854464184493, 0.14351386082125828, 0.02296710870723473, 0.04816493150428869, 0.09159702400211245, 0.04576965358864982, 0.027948864044446964, 0.04336797836003825, 0.015401958644361002, 0.07446725372574292, 0.03896383284882177, 0.06381154933478683, 0.05772961943875998, 0.08071719101280905, 0.013771931462542852, 0.22257327946135774, 0.2594673552084714, 8.321586716920137, 83.53119894862175, 69.54445347189903, 82.7802300453186, 73.8279864192009, 49.37396161258221, 37.585265189409256, 70.60565292835236, 118.14642190933228, 45.80799736082554, 0.020414851715031546, 0.2300987162743695, 0.27603577240370214, 0.23077522841049358, 0.3990729624638334, 0.156465302570723, 0.11076484312070534, 0.03831233851087745, 0.5065585963893682, 0.6960138771682978, 3.231959561817348, 2.3159655136987567, 2.621952169574797, 0.9339145990088582, 0.18495031079510227, 7.443775394931436, 97.5820241868496, 86.12253829836845, 83.8050426542759, 89.97583553195, 96.97404161095619, 93.41950714588165, 94.75673139095306, 93.76974195241928, 87.69040256738663, 81.07901573181152, 75.75269713997841, 73.04852664470673, 74.92340683937073, 82.76310816407204, 88.66401672363281, 90.5687253177166, 92.09581777453423, 89.08602967858315, 87.08190321922302, 85.4999341070652, 82.78220593929291, 81.16702660918236, 77.2846457362175, 82.39046216011047, 84.34566244482994, 87.12368577718735, 76.20556443929672, 85.58618947863579, 81.14624932408333, 81.592907756567, 79.87655505537987, 77.94110611081123, 74.81354713439941, 82.08845436573029, 84.62074488401413, 78.5200734436512, 80.81528708338737, 86.67359992861748, 82.95002773404121, 84.5443157851696, 74.63331520557404, 77.80939757823944, 85.08827939629555, 77.48956874012947, 74.70940992236137, 64.9278911948204, 68.77048820257187, 70.57973071932793, 79.2872066795826, 75.76068431138992, 76.36239722371101, 75.09649515151978, 73.61164882779121, 74.07564952969551, 74.12062391638756, 76.59115254878998, 75.61405777931213, 75.5170413851738, 76.34208351373672, 75.6445549428463, 73.41453060507774, 76.39721855521202, 75.84347426891327, 75.93776240944862, 73.7046830356121, 74.46968838572502, 75.90136036276817, 72.37214773893356, 68.19361075758934, 68.8003545999527, 68.80724743008614, 68.15906301140785, 64.8052641749382, 62.17672482132912, 58.72261516749859, 55.26827372610569, 54.21060808002949, 57.83995293080807, 61.364043429493904, 66.674315482378, 62.32735633850098, 63.931121081113815, 65.88456586003304, 63.893054723739624, 61.36182054877281, 67.72180527448654, 66.9510318338871, 73.62756237387657, 71.8477150797844, 67.79363662004471, 59.571067839860916, 64.53993961215019, 63.686668798327446, 53.978672325611115, 28.63562822341919, 8.160387966781855, 7.417152598500252, 3.1257937336340547, 0.17240561050130054, 1.7564913723617792, 0.8138435950968415, 0.2260987480985932, 0.1674525169073604, 0.6018967868294567, 0.7054564892314374, 0.04110659872821998, 0.08498805051203817, 0.03759480416192673, 0.043764322326751426, 0.04453859757632017, 0.060860183875774965, 4.180546598508954, 71.3410958647728, 93.71415853500366, 87.2274962067604, 60.2947124093771, 60.52115745842457, 26.69323705136776, 63.12769219279289, 61.651441007852554, 35.939942076802254, 65.04873231053352, 76.88617631793022, 32.72805042564869, 0.5736928596161306, 0.22957070788834244, 0.12261254800250754, 0.2456594750401564, 0.033857890230137855, 0.05212434502027463, 0.02085891021124553, 0.03125736395304557, 0.018409752374282107, 0.08072303171502426, 0.11173656675964594, 0.0750965578481555, 0.09208627743646502, 0.147956371656619, 0.0893128196184989, 0.09989857659093104, 0.21206230128882453, 0.13522181514417753, 0.20562439283821732, 0.18517532997066155, 0.16321360686561093, 0.08480633565341122, 0.20753983146278188, 0.1510126842185855, 0.21702130237827078, 0.6183593440800905, 10.378029718995094, 96.22891679406166, 79.5332358777523, 90.45885801315308, 94.11357790231705, 65.20236566662788, 65.87710306048393, 90.10190516710281, 124.74450185894966, 52.71610647439957, 0.3233930765418336, 0.5894804780837148, 0.4648522421484813, 0.4216733778594062, 1.1329324822872877, 0.5242415412794799, 0.2581560693215579, 0.22296753799309954, 1.3489468535408378, 1.2428212794475257, 5.7185278460383415, 3.8080183882266283, 6.612012851983309, 2.619568509981036, 0.3231118025723845, 10.66592887043953, 100.64962238073349, 87.27899104356766, 92.72952497005463, 94.15031433105469, 101.01173534989357, 98.49547997117043, 98.6557249724865, 98.78711432218552, 91.94330155849457, 86.04189142584801, 80.10523438453674, 77.22397819161415, 80.41129276156425, 86.87824174761772, 92.95445010066032, 94.50646162033081, 93.96093249320984, 90.92284351587296, 91.00397676229477, 89.03920099139214, 86.88589453697205, 84.83334347605705, 81.95318162441254, 88.45223888754845, 90.73507279157639, 89.04683098196983, 81.59219339489937, 90.97786456346512, 87.07601353526115, 86.46056815981865, 83.04783448576927, 82.13358834385872, 80.4606369137764, 85.88946640491486, 91.14140018820763, 82.13222801685333, 84.13505494594574, 88.05891439318657, 87.9589493572712, 88.3400309085846, 80.31089454889297, 80.15967786312103, 87.46040850877762, 82.2347617149353, 77.4142187833786, 66.94964110851288, 70.13591453433037, 71.95992305874825, 81.467195302248, 80.82569092512131, 79.29558143019676, 79.26614820957184, 78.22423651814461, 78.74073520302773, 78.57173547148705, 81.24696671962738, 78.81217136979103, 78.14358204603195, 76.35630995035172, 79.65710923075676, 77.75246903300285, 77.62006893754005, 78.35981324315071, 78.88088688254356, 75.75939238071442, 79.07283738255501, 79.07340735197067, 77.56986603140831, 73.33968982100487, 71.4473457634449, 70.73211014270782, 73.56908351182938, 70.0143514573574, 65.863606184721, 65.1300099492073, 63.06643567979336, 63.73698949813843, 68.97224977612495, 69.27383959293365, 73.91104996204376, 69.95280995965004, 68.82047832012177, 72.26021334528923, 71.95553809404373, 66.2246324121952, 73.71849909424782, 71.2465189397335, 76.9327238202095, 77.05878585577011, 73.24587285518646, 66.8566220998764, 73.75943049788475, 74.17436063289642, 58.53881523013115, 42.57200360298157, 10.735098458826542, 9.334060437977314, 3.572133220732212, 1.0345733352005482, 3.918488435447216, 1.356854229234159, 0.47947284823749214, 0.34152724721934646, 3.159857955761254, 1.383431546855718, 0.2137304117786698, 0.4040736722527072, 0.3900579165201634, 0.2699312218464911, 0.10791391250677407, 0.1669709966517985, 6.610909961163998, 79.67363074421883, 104.35294166207314, 99.44460824131966, 79.3197101354599, 116.60381868481636, 71.71243473887444, 66.96624621748924, 63.699094131588936, 56.273650377988815, 74.9461068212986, 88.98140609264374, 35.67709498107433, 0.672604045830667, 0.28065691818483174, 0.43015345407184213, 0.34279887273442, 0.21649826638167724, 0.1293723555863835, 0.12906167772598565, 0.2895121352048591, 0.13215638900874183, 0.22761013184208423, 0.3188360820058733, 0.18781779130222276], [0.034903813793789595, 0.06951182236662135, 0.05163804904441349, 0.027928232339036185, 0.049502771435072646, 0.06826875469414517, 0.06264039577217773, 0.09080576841370203, 0.08209610139601864, 0.07532683142926544, 0.07906738188466989, 0.05854931783687789, 0.06302614187006839, 0.014162229708745144, 4.5016037207096815, 64.56643179059029, 64.36522498726845, 70.83528220653534, 101.48242369294167, 68.12350451946259, 55.688538774847984, 95.4547767341137, 84.56879407167435, 3.8014186173677444, 0.17699971242109314, 0.0642789390985854, 0.04524053198110778, 0.12592176964972168, 0.028182640562590677, 0.07867509746574797, 0.04541593116300646, 0.06888833668199368, 0.19772377068875358, 0.14148490328807384, 2.6644574012607336, 0.8872944850008935, 1.2764987535774708, 0.17148135462775826, 1.2017447710968554, 55.88745430111885, 78.05923417210579, 58.9335760474205, 79.26545664668083, 94.03503611683846, 85.17160892486572, 92.70397514104843, 92.45439693331718, 89.54604059457779, 85.727519094944, 78.56428027153015, 72.87464037537575, 68.18275094032288, 71.2168425321579, 76.41739547252655, 83.36563423275948, 86.67258158326149, 86.62444576621056, 85.44863685965538, 85.51231384277344, 82.57551223039627, 80.30095428228378, 82.25664854049683, 71.77167356014252, 74.08315032720566, 87.0484422147274, 71.08496680855751, 78.30635771155357, 78.33232551813126, 76.5277111530304, 79.4630840420723, 77.23762705922127, 74.10928532481194, 76.41211375594139, 76.14866629242897, 71.17387443780899, 72.43045940995216, 78.77370223402977, 78.62071484327316, 75.15586316585541, 74.99805763363838, 73.99062529206276, 80.86089223623276, 73.4497395157814, 72.2498171031475, 66.29881963133812, 66.25947654247284, 72.27164313197136, 72.60805428028107, 74.46259796619415, 73.73818203806877, 71.67571350932121, 69.85343769192696, 70.54044842720032, 66.00679010152817, 67.2198598086834, 66.28292888402939, 68.8548892736435, 68.59473243355751, 72.79164522886276, 76.45717173814774, 72.30742961168289, 76.24846413731575, 74.90493223071098, 72.55661264061928, 73.87175247073174, 68.83149772882462, 71.42252549529076, 66.9734962284565, 68.24784144759178, 66.40842854976654, 66.03372305631638, 66.85647010803223, 65.44266477227211, 64.14076343178749, 58.34802746772766, 54.035004302859306, 48.50584499537945, 50.866008549928665, 54.70059558749199, 58.455082923173904, 57.951727733016014, 55.78410744667053, 56.75368241965771, 58.52372623980045, 58.09871904551983, 60.456386134028435, 61.62565179169178, 67.87915483117104, 63.214141353964806, 62.14588187634945, 58.51773776113987, 46.626967415213585, 50.3584735840559, 49.67658877372742, 17.68510602414608, 18.067171722650528, 4.415848022326827, 2.941683162935078, 0.9405672107823193, 0.5268043850082904, 1.4683712390251458, 0.3214618598576635, 0.10863617804716341, 0.12135274489992298, 0.14818980678683147, 0.05144725029822439, 0.050355454586679116, 0.19771813036641106, 0.057286876399302855, 0.03172664619341958, 0.015470302096218802, 0.18822692247340456, 12.623444180935621, 72.2703891992569, 81.47256821393967, 49.57758888602257, 30.491294749081135, 45.5315013974905, 26.800672486424446, 23.30686256289482, 71.34849026799202, 51.2296262383461, 66.59168511629105, 27.944857589900494, 0.1941965802689083, 0.08533121217624284, 0.019355562071723398, 0.041296013368992135, 0.05093044834211469, 0.11939921183511615, 0.02573288158600917, 0.04771953528688755, 0.011635850478342036, 0.022850717687106226, 0.062433440471068025, 0.043611933433567174, 0.027045056194765493, 0.05354580644052476, 0.04151934044784866, 0.04904835070192348, 0.02195506232965272, 0.08624910784419626, 0.06898162464494817, 0.03169877112668473, 0.08021156580070965, 0.060616555347223766, 0.08232062333263457, 0.06327951850835234, 0.08657712969579734, 0.316058816970326, 6.482698665931821, 75.60827448964119, 71.9916133582592, 77.86549776792526, 101.6753089427948, 52.50913918018341, 39.83558423817158, 103.90239223837852, 94.22302722930908, 7.039007339626551, 0.29790425207465887, 0.0404996035649674, 0.2850270102499053, 0.17204129020683467, 0.23439073440385982, 0.08488361549098045, 0.07439274952048436, 0.2313686942216009, 0.5685634911060333, 0.31428048270754516, 3.673024456948042, 1.611146202776581, 2.254885691218078, 0.0299720012844773, 1.4876134064979851, 65.63175022602081, 85.41257679462433, 68.67534130811691, 92.51836270093918, 96.4437648653984, 90.38449600338936, 94.80223014950752, 97.38786980509758, 94.38512653112411, 90.1271054148674, 81.76300942897797, 76.69823080301285, 70.8415974676609, 74.83789622783661, 80.70733487606049, 87.38789319992065, 91.14090621471405, 89.17883589863777, 87.23748207092285, 89.25069764256477, 84.82658743858337, 85.2361598610878, 87.85179510712624, 79.79402348399162, 79.24829676747322, 91.47574424743652, 76.53027221560478, 79.6410208940506, 80.42535960674286, 81.64174273610115, 83.00303488969803, 81.5640977025032, 79.81771901249886, 79.05943930149078, 78.35629463195801, 77.35380202531815, 78.51740598678589, 83.04737851023674, 81.40430107712746, 77.78092950582504, 76.89271196722984, 78.90487879514694, 83.30637261271477, 77.02315136790276, 74.69320759177208, 65.17195209860802, 68.58777120709419, 73.24646562337875, 75.01362919807434, 74.98219728469849, 75.30410841107368, 73.84389996528625, 75.07754176855087, 73.55444669723511, 69.42091450095177, 70.47919571399689, 68.84041965007782, 69.98448505997658, 72.89501488208771, 73.5450080037117, 76.36321038007736, 74.0634673833847, 74.73331823945045, 76.4104874432087, 74.40386071801186, 76.25670969486237, 71.80090919137001, 72.08384960889816, 74.42244932055473, 70.42227476835251, 71.47085890173912, 70.64784586429596, 70.92808082699776, 66.71918347477913, 67.78421312570572, 65.98586082458496, 62.12679170072079, 59.890801683068275, 59.959437400102615, 61.31439529359341, 63.92067924141884, 63.333945125341415, 61.11543416976929, 59.69924636185169, 63.53385999798775, 62.14593507349491, 65.96699863672256, 65.49117296934128, 71.27365708351135, 69.2510636150837, 67.57251128554344, 64.28567245602608, 59.607545882463455, 59.878573939204216, 64.44540828466415, 47.854084968566895, 13.694372065365314, 4.41353109665215, 5.4025330021977425, 1.5441077062860131, 1.0118562541902065, 1.6547690494917333, 0.3736982209375128, 0.17087870102841407, 0.16274599445750937, 0.10553681349847466, 0.08681754101417027, 0.0586678313993616, 0.08965063039795496, 0.10346487819333561, 0.10518260867684148, 0.04310070871724747, 0.33585058932658285, 19.013550840318203, 83.59597027301788, 93.14647659659386, 59.619112461805344, 37.962744534015656, 36.91075578331947, 22.478793896734715, 36.07573539018631, 70.64817264676094, 61.14885717630386, 75.66096246242523, 35.41615538299084, 0.1924396347021684, 0.12543610821012408, 0.021336619538487867, 0.02247588858153904, 0.010579983991192421, 0.11297174540231936, 0.028968441365577746, 0.0658937930711545, 0.0539607263635844, 0.047952076129149646, 0.06829697857028805, 0.10810292267706245, 0.10542626318056136, 0.19916882127290592, 0.14017805544426665, 0.13038697536103427, 0.12539865943836048, 0.30882741906680167, 0.26404456584714353, 0.1167745323618874, 0.20795102580450475, 0.2029128820868209, 0.1948457071557641, 0.42797688336577266, 0.35758150450419635, 0.5018136010039598, 8.595181535929441, 89.68578189611435, 83.03402602672577, 82.16316595673561, 111.77823722362518, 83.54790285229683, 77.27310955524445, 111.33410945534706, 106.76170080900192, 7.904264135286212, 0.4478038928937167, 0.17601059284061193, 0.2592015772825107, 0.4699429892934859, 0.6031570129562169, 0.3151331510161981, 0.16000044881366193, 0.5978719121776521, 1.5588367846794426, 1.1887812917120755, 7.042772937566042, 5.045374967157841, 4.013984436169267, 0.4714703588979319, 1.9971286598592997, 77.40982621908188, 89.16249677538872, 76.67227059602737, 98.32629024982452, 100.2590261399746, 95.05414143204689, 97.80102163553238, 99.67335596680641, 96.16085484623909, 96.24478474259377, 86.67811408638954, 80.82622289657593, 73.15298303961754, 79.91943195462227, 85.30691206455231, 89.93190988898277, 95.12083545327187, 94.5513904094696, 90.48121601343155, 91.64450079202652, 87.76183113455772, 90.89334189891815, 90.54629892110825, 85.01952588558197, 86.29703253507614, 92.53071963787079, 80.87673738598824, 87.45521798729897, 85.43871939182281, 86.63500919938087, 85.95002755522728, 85.07915988564491, 82.25230917334557, 83.8423490524292, 84.74106162786484, 83.93940344452858, 81.45084097981453, 84.23806741833687, 84.27543461322784, 79.68652725219727, 79.41709890961647, 79.56489577889442, 88.1223101913929, 81.53992339968681, 76.76991015672684, 67.88374498486519, 69.09296929836273, 77.05819308757782, 76.99440971016884, 79.82721090316772, 79.92725193500519, 77.61795625090599, 78.51440414786339, 77.5173756480217, 72.53653451800346, 74.82780396938324, 73.00052762031555, 74.79144752025604, 76.12307086586952, 77.67351686954498, 80.59837192296982, 77.1467587351799, 78.21516260504723, 78.81237655878067, 75.39698302745819, 81.08554378151894, 73.95717948675156, 77.86758005619049, 75.40627732872963, 74.47401255369186, 74.43110525608063, 78.18707451224327, 76.25988632440567, 73.71137827634811, 74.05446946620941, 71.06494948267937, 67.13956251740456, 65.60042470693588, 64.79533910751343, 69.68724980950356, 73.00856798887253, 69.42022293806076, 67.31012016534805, 68.61429378390312, 69.26370173692703, 69.8651334643364, 70.66372141242027, 73.51659312844276, 78.4335444867611, 74.02752131223679, 74.12713676691055, 68.8016465306282, 65.89178547263145, 71.81875303387642, 73.18786516785622, 53.23452025651932, 25.389614403247833, 4.248807560652494, 6.9665618520230055, 2.282993495464325, 3.210810609161854, 3.940413258969784, 1.1311732954345644, 0.20539627148536965, 0.3173147386405617, 0.4918114986503497, 0.7249877380672842, 0.1869725444703363, 0.8353535283822566, 0.20219093566993251, 0.16670855839038268, 0.1239490817533806, 0.5766540882177651, 25.874823667109013, 94.76375341415405, 97.04563736915588, 74.6572083234787, 58.61980028450489, 70.53147330880165, 39.19488541781902, 31.365304850041866, 92.01890990138054, 63.86628895998001, 89.91131499409676, 39.527929946780205, 0.23518581205280498, 0.34128815692383796, 0.11093437933595851, 0.11798977691796608, 0.14529933454468846, 0.24977389723062515, 0.19208334444556385, 0.12874515174189582, 0.1390803002868779, 0.1946891436818987, 0.18958101543830708, 0.16066536860307679], [0.05880490978597663, 0.01972355599718867, 0.029410189927148167, 0.024696110558579676, 0.07541487240814604, 0.07275422845850699, 0.09170847231871448, 0.03686026349896565, 0.02386600725003518, 0.010908914973697392, 0.006871041605336359, 0.06074366297980305, 0.02902328793425113, 0.06416921998606995, 1.7572153522633016, 56.268281266093254, 55.91496482491493, 64.69997942447662, 57.27849505841732, 43.72279465198517, 58.745843321084976, 99.04286339879036, 32.64245621860027, 0.2994779613800347, 0.07302258163690567, 0.21502019022591412, 0.4292933049146086, 0.4108866769820452, 0.07677706962567754, 0.04520027418038808, 0.13147635909263045, 0.07129673205781728, 0.44768354622647166, 1.3935927953571081, 0.9155641961842775, 0.2515317185316235, 0.3359190747141838, 0.8657065371517092, 27.972934283316135, 82.41720512509346, 57.18307837843895, 82.26927146315575, 98.65639373660088, 88.16305920481682, 83.25181514024734, 87.68220260739326, 92.33536452054977, 89.11734759807587, 87.26468861103058, 79.60641995072365, 73.33644479513168, 67.46815368533134, 68.20627927780151, 70.19617930054665, 76.90912708640099, 82.38280937075615, 84.59989160299301, 83.97829815745354, 83.85039702057838, 85.76223403215408, 81.31013453006744, 80.68621560931206, 72.96529591083527, 80.60720264911652, 73.26316192746162, 69.80285480618477, 75.40949195623398, 73.39632198214531, 81.211476624012, 80.08904725313187, 78.00362795591354, 74.80774864554405, 79.4257016479969, 72.46328204870224, 74.30402487516403, 81.91016793251038, 80.28723701834679, 73.0952337384224, 79.05986487865448, 77.29003384709358, 80.68836629390717, 72.06060245633125, 80.44740602374077, 71.412782818079, 66.40232607722282, 73.58098447322845, 71.98685601353645, 71.59503623843193, 70.7738547027111, 71.16446614265442, 73.55994120240211, 72.20460712909698, 67.33101904392242, 69.52832713723183, 68.3432999253273, 67.27811828255653, 67.61124640703201, 70.21293640136719, 67.3352900147438, 68.20923551917076, 69.73144143819809, 71.41010016202927, 70.14951780438423, 70.61626955866814, 70.80230757594109, 70.48414304852486, 66.93932086229324, 70.21210804581642, 68.00530046224594, 66.43690422177315, 68.45154851675034, 67.2881269454956, 68.20370301604271, 66.25872418284416, 67.20105841755867, 63.23576979339123, 60.2865694463253, 57.55642354488373, 56.63604453206062, 57.797041833400726, 61.00027374923229, 56.980435252189636, 55.20176209509373, 54.97658997774124, 57.55073145031929, 56.81336961686611, 62.37516537308693, 66.37375921010971, 62.13053449988365, 62.34080381691456, 56.11795753240585, 59.73755210638046, 43.351144194602966, 42.9905891418457, 46.922340765595436, 7.484701573848724, 13.6481180973351, 2.579593467526138, 2.1010773070156574, 0.21689911518478766, 0.21270877128699794, 0.5589156306814402, 0.683707999996841, 0.13606983760837466, 0.05325750804331619, 0.09287974462495185, 0.05938434900599532, 0.1420989414327778, 0.2977708139223978, 0.20208958798320964, 0.014073915062908782, 0.02685064318939112, 1.298063665162772, 38.553616628050804, 79.58549067378044, 84.08438086509705, 108.09647038578987, 42.57269896566868, 60.97708739340305, 35.70858009159565, 55.34023426473141, 41.165319085121155, 69.62180972099304, 23.18607274442911, 0.044567738004843704, 0.023797293652023654, 0.010371638090873603, 0.05982940012472682, 0.03654073552752379, 0.07547478599008173, 0.06094541953643784, 0.0155399517279875, 0.028190993434691336, 0.06724587481585331, 0.04646936526114587, 0.015815864608157426, 0.044815993824158795, 0.04502107149164658, 0.0526125594478799, 0.021973233815515414, 0.08782577089732513, 0.037657556458725594, 0.09732741338666528, 0.0315259286435321, 0.03432216668443289, 0.03159117084578611, 0.00950087158344104, 0.046776658928138204, 0.05684992953320034, 0.10851206869119778, 3.2969648111611605, 65.88493064045906, 63.01007330417633, 68.14694926142693, 72.70614221692085, 35.78975893557072, 51.915284246206284, 115.77356323599815, 43.08180324733257, 0.17334479838609695, 0.05159658154298086, 0.2522944088559598, 0.23604038025951013, 0.3210804850095883, 0.10655800128006376, 0.12775883747963235, 0.30149390164297074, 0.18037121510133147, 2.084029521793127, 4.716073237359524, 0.7694296189583838, 0.34827396331820637, 0.4581434646388516, 0.7891630881931633, 34.789607003331184, 88.15448686480522, 68.81221756339073, 92.86708518862724, 100.74169144034386, 92.17388078570366, 87.44739800691605, 92.62976512312889, 92.78852060437202, 92.46189013123512, 90.65631821751595, 85.7872062921524, 76.07723012566566, 72.26603463292122, 71.61693826317787, 74.55684810876846, 80.0270725786686, 84.95518013834953, 88.71207654476166, 88.05939316749573, 86.30889549851418, 88.58060359954834, 81.41718238592148, 81.6613344848156, 77.23530918359756, 83.33969682455063, 80.33549442887306, 75.5776709318161, 82.44805186986923, 76.5026780962944, 87.52268716692924, 83.4583568572998, 83.20038869976997, 77.69043356180191, 83.7074562907219, 75.6004849076271, 82.86010935902596, 85.52445039153099, 83.32657992839813, 76.38137340545654, 80.21837711334229, 79.3210780620575, 82.56282091140747, 74.18476447463036, 82.92863488197327, 75.29720798134804, 70.66081076860428, 73.11992481350899, 75.89510589838028, 74.88345578312874, 73.56510892510414, 73.81236165761948, 77.17878341674805, 72.8712585568428, 69.64006394147873, 73.84741857647896, 71.76681742072105, 73.51326450705528, 71.31018832325935, 71.63352817296982, 70.36790728569031, 71.72108307480812, 71.17536395788193, 73.50643247365952, 72.94289231300354, 71.85008615255356, 73.50116595625877, 73.59109953045845, 72.56362706422806, 73.64193320274353, 73.24627563357353, 68.92542108893394, 73.15684363245964, 68.73248264193535, 71.43960937857628, 69.29664596915245, 69.38618436455727, 67.20251753926277, 67.06618085503578, 64.95684564113617, 63.66638168692589, 67.08020210266113, 67.5207656621933, 66.37218609452248, 63.053691163659096, 60.285516902804375, 62.50961355865002, 61.435080617666245, 68.82060751318932, 70.12482672929764, 64.28150787949562, 69.51907843351364, 63.57629232108593, 66.58468589186668, 54.54279765486717, 54.53666478395462, 62.47344709932804, 44.134890139102936, 5.848945397883654, 4.065429400652647, 3.4198920149356127, 0.2351349897799082, 0.14595940068829805, 1.194486329331994, 2.7687815157696605, 0.5806736194062978, 0.048182783866650425, 0.017371951616951264, 0.10500926524400711, 0.14736891724169254, 0.18013893772149459, 0.15841502841794863, 0.06383244079188444, 0.044898253472638316, 1.2284227833151817, 50.81616282463074, 90.3167912364006, 87.32140436768532, 114.12020355463028, 50.44100135564804, 51.73940308392048, 35.7086256891489, 51.94937601685524, 49.545644000172615, 77.0401668548584, 29.156042598187923, 0.168240811326541, 0.08508332743076608, 0.05008114196243696, 0.035896028130082414, 0.013670738699147478, 0.021285778711899184, 0.08099727754597552, 0.026989007346855942, 0.014069115222810069, 0.042538895504549146, 0.03581353841582313, 0.02381217371294042, 0.12900453235488385, 0.12135371711337939, 0.10828437778400257, 0.05383390074712224, 0.12299619382247329, 0.15422271040733904, 0.1887246809201315, 0.1036573170858901, 0.11808425973867998, 0.07670727805816568, 0.103925091389101, 0.18124662281479686, 0.1253489058581181, 0.35916489141527563, 3.877043821848929, 80.40914967656136, 69.71235126256943, 80.76449900865555, 68.75189200043678, 60.979515463113785, 78.99867296218872, 120.87427273392677, 50.73577433824539, 0.432405456667766, 0.2283315735985525, 0.3399789787363261, 1.1460109055042267, 1.5614972356706858, 0.6413802900351584, 0.28412179788574576, 0.45342747238464653, 0.5318833468481898, 3.348991619423032, 6.497337380424142, 2.3986089415848255, 0.677035617409274, 1.6359711019322276, 1.0090409615077078, 45.47806106507778, 97.13171795010567, 72.78510957956314, 97.58369609713554, 106.10527843236923, 99.27978068590164, 89.84882354736328, 95.07467553019524, 97.2634568810463, 97.11268097162247, 97.39470183849335, 90.59666901826859, 78.45493733882904, 75.88497564196587, 73.63862738013268, 78.72806668281555, 84.03541669249535, 92.14359641075134, 92.56566256284714, 90.07149159908295, 90.64874142408371, 93.84594306349754, 84.50836971402168, 86.23919203877449, 84.53763574361801, 83.34329143166542, 82.04699859023094, 81.6280634701252, 84.05140623450279, 80.79066440463066, 90.22336944937706, 86.58221483230591, 87.34875530004501, 81.16437435150146, 87.88800716400146, 85.51637202501297, 84.57824036478996, 88.7522403895855, 84.05421808362007, 75.81328868865967, 82.05141395330429, 83.09623628854752, 87.25683823227882, 80.03723323345184, 87.07083821296692, 78.47357153892517, 69.64879587292671, 78.0799126625061, 75.86019337177277, 80.70670410990715, 78.06554183363914, 78.59672293066978, 81.52444303035736, 78.37328732013702, 73.43298241496086, 77.70861178636551, 75.32123789191246, 74.45868417620659, 73.69973570108414, 77.19544172286987, 74.7277021408081, 77.39195197820663, 75.89841172099113, 77.02116027474403, 74.85156789422035, 74.89875376224518, 76.06642350554466, 76.701620221138, 75.8592738211155, 77.31919348239899, 77.52195060253143, 71.33026644587517, 77.04442262649536, 74.56323936581612, 72.98579201102257, 73.36142465472221, 72.12158158421516, 70.44586390256882, 71.07393220067024, 70.22762641310692, 68.11802521348, 71.7275807261467, 72.53955915570259, 71.66440531611443, 66.68201386928558, 69.52109232544899, 66.980791836977, 70.38838058710098, 73.49120289087296, 75.62445402145386, 69.67103227972984, 75.9267657995224, 68.49177315831184, 72.34468281269073, 64.56684976816177, 68.65810543298721, 69.7352260351181, 49.869409427046776, 11.431240104138851, 3.565148483030498, 4.447889802977443, 0.4611986194504425, 0.355206246022135, 3.0942347645759583, 4.592665834352374, 0.6371682160533965, 0.15934183727949858, 0.2730477671138942, 0.2687550662085414, 0.2904516347916797, 0.6756465544458479, 0.4281151603208855, 0.18021171272266656, 0.09832946860115044, 2.1546332957223058, 62.101397663354874, 99.82641935348511, 104.11416247487068, 116.02609008550644, 75.31255915760994, 83.54621574282646, 48.96865636110306, 66.40878573060036, 55.79869106411934, 91.6683179140091, 35.28191238641739, 0.3322611178737134, 0.10227747159660794, 0.13777964195469394, 0.12598949804669246, 0.12952124525327235, 0.09919994103256613, 0.15624751191353425, 0.11612807720666751, 0.12189214525278658, 0.2007270642207004, 0.13590669870609418, 0.19237929809605703], [0.001589796631833451, 0.07330168853513896, 0.0409818808111595, 0.061531697647296824, 0.044206575548741966, 0.054494894575327635, 0.05706255113182124, 0.06761025448213331, 0.07605438106111251, 0.057905842404579744, 0.022093560073699336, 0.0490160784102045, 0.034471557301003486, 0.0757944215729367, 0.7285965944174677, 46.389358565211296, 67.5097006559372, 59.285923540592194, 30.993888080120087, 40.9131646156311, 65.22856146097183, 84.58948016166687, 2.7630027383565903, 0.02929783247964224, 0.04227610472298693, 0.11517794264364056, 0.4568611818831414, 0.15286161156836897, 0.06245594238862395, 0.06185570819070563, 0.25088118156418204, 0.6073517503682524, 3.13279343303293, 0.4322916705859825, 0.5130298272706568, 0.6231752294115722, 0.5303094594273716, 14.162784330546856, 83.11115428805351, 70.00772461295128, 90.59197247028351, 96.63307070732117, 93.3766758441925, 82.92569383978844, 78.40125381946564, 88.07667464017868, 87.87271678447723, 89.13038849830627, 84.62295636534691, 78.69622439146042, 72.08176732063293, 67.12190106511116, 69.67832028865814, 68.08375865221024, 72.74876073002815, 80.05884647369385, 83.8769119977951, 84.08080905675888, 82.25694492459297, 81.64179593324661, 78.87953415513039, 78.47139805555344, 60.71527384221554, 63.19806441664696, 70.58426007628441, 70.52839547395706, 74.93862122297287, 76.45682975649834, 78.39122235774994, 77.95115277171135, 77.86057323217392, 75.90343505144119, 73.57681229710579, 72.67647340893745, 79.1299407184124, 79.05114814639091, 73.14422830939293, 76.19757726788521, 75.18251493573189, 76.1288845539093, 69.91799622774124, 72.92473688721657, 77.4602647125721, 71.95098593831062, 71.83481097221375, 70.10655730962753, 70.91329202055931, 68.94220098853111, 68.09120625257492, 69.44545358419418, 71.7658294737339, 64.40467447042465, 67.34897688031197, 74.93074804544449, 69.02740761637688, 70.35575553774834, 73.18735599517822, 71.66261941194534, 69.71783056855202, 69.53351765871048, 67.27067828178406, 68.99609729647636, 71.4297603070736, 67.97437772154808, 69.27534431219101, 66.66774943470955, 69.48339074850082, 66.92731350660324, 65.65662369132042, 68.51410835981369, 68.33311647176743, 68.60145047307014, 68.31144243478775, 68.74918654561043, 66.88069000840187, 68.0182121694088, 67.50955626368523, 63.173605129122734, 66.58742934465408, 63.64707872271538, 66.9445949792862, 63.545973747968674, 60.61393328011036, 54.84498783946037, 52.63583578169346, 52.17963606119156, 66.50540694594383, 53.9844062179327, 51.53791889548302, 63.412828892469406, 62.915382385253906, 57.17265173792839, 52.31338508427143, 39.47991572320461, 35.93747600913048, 40.21943964064121, 10.074925683438778, 6.488795913755894, 2.7440158696845174, 1.1331069166772068, 0.18094663188094273, 0.5040291789919138, 1.4270401443354785, 0.4780556430341676, 0.05470559401146602, 0.2672718098619953, 0.038818078755866736, 0.07707239987212233, 0.39468102157115936, 0.2550436503952369, 0.020928874328092206, 0.07751580342301168, 0.06369836439262144, 8.268402870744467, 71.30969434976578, 73.63517716526985, 99.49408918619156, 68.7892135977745, 35.89939825236797, 50.926695093512535, 67.74720311164856, 47.33001708984375, 56.544754430651665, 9.766977857798338, 0.12088968927855603, 0.09463303882512264, 0.03716531216923613, 0.1338720414787531, 0.06151575260446407, 0.10090727402712218, 0.024509538343409076, 0.026119432914128993, 0.0031114376679397537, 0.020822253682126757, 0.04373093310277909, 0.029419978855003137, 0.04711668130767066, 0.037229155423119664, 0.01613980464753695, 0.02204512380558299, 0.014115216508798767, 0.03519632758980151, 0.08666717447340488, 0.020595069290720858, 0.048890722246142104, 0.037117989122634754, 0.041281337398686446, 0.04591250959492754, 0.024619693467684556, 0.0719626537465956, 0.99841115064919, 57.493555918335915, 74.10439878702164, 69.9570581316948, 41.899397894740105, 25.261399783194065, 69.75363224744797, 98.27042564749718, 5.37017441354692, 0.11426907149143517, 0.10239882016321644, 0.5577841820195317, 0.5762918014079332, 0.40010757569689304, 0.15914807736407965, 0.03620770417910535, 0.13090472726617008, 1.689961098600179, 6.731805223971605, 0.6334482750389725, 0.3560860769357532, 0.48135356919374317, 0.6162695749662817, 17.642381116747856, 91.54504492878914, 80.51596954464912, 100.66602990031242, 98.05809304118156, 96.14228144288063, 88.69638338685036, 83.81667003035545, 91.03887408971786, 91.00548908114433, 92.29373395442963, 89.93463054299355, 81.32533371448517, 76.25841200351715, 71.36679768562317, 72.28640913963318, 70.45435264706612, 74.39382925629616, 81.6513942182064, 87.2323827445507, 85.1259733736515, 85.31620636582375, 85.48412695527077, 82.10676178336143, 81.45593270659447, 64.94414672255516, 67.3426616191864, 71.97876244783401, 72.89438411593437, 76.23164623975754, 80.30574962496758, 80.40693819522858, 81.63349717855453, 78.729647397995, 77.87023991346359, 79.51793029904366, 76.60675451159477, 83.4284296631813, 80.6214290857315, 76.83357194066048, 82.63168081641197, 78.86581689119339, 78.17611590027809, 74.50044393539429, 76.93678960204124, 78.63273739814758, 74.79156151413918, 73.27929586172104, 73.04109424352646, 73.65928307175636, 75.30851617455482, 70.05496367812157, 72.914127856493, 73.77682596445084, 66.40860334038734, 70.74106246232986, 76.34890794754028, 72.42736637592316, 72.7769324183464, 76.3448877632618, 74.0833555161953, 72.82870084047318, 73.25419440865517, 70.68759173154831, 70.2589975297451, 74.94822710752487, 71.5505862236023, 69.54810127615929, 70.03178492188454, 72.88673132658005, 72.26684778928757, 70.23939058184624, 70.24988561868668, 72.10262060165405, 72.41750970482826, 70.64703270792961, 70.95145717263222, 70.94783216714859, 69.8729382455349, 72.23439753055573, 68.53395849466324, 68.82050111889839, 67.88163229823112, 70.36399349570274, 68.36033061146736, 66.97035759687424, 63.26180599629879, 60.30594080686569, 59.62676145136356, 69.00046706199646, 57.16904193162918, 53.26590657234192, 65.19893065094948, 67.65280857682228, 63.715497851371765, 60.93044489622116, 50.965137630701065, 50.30799709260464, 64.4896911084652, 37.09100291132927, 3.008073912933469, 4.495955323800445, 1.4182457537390292, 0.5643754627089947, 0.695853513898328, 4.8427066672593355, 0.732136401347816, 0.33133426448330283, 0.36487399600446224, 0.17864707246189937, 0.05680578287865501, 0.37292395310942084, 0.23450232372852042, 0.027970464252575766, 0.017338050311082043, 0.1455557020381093, 11.774519383907318, 85.00157564878464, 89.69287231564522, 108.7015575170517, 83.88795420527458, 38.979820758104324, 28.15753597766161, 59.396072030067444, 47.18842528760433, 69.68209728598595, 11.603833492845297, 0.15089854190591723, 0.04004939823062159, 0.0232337159832241, 0.08225347381085157, 0.09833542062551714, 0.07743662368739024, 0.048651535471435636, 0.02028866805630969, 0.024099357033264823, 0.09213704775902443, 0.03410498829907738, 0.06002439571602736, 0.11725554053555243, 0.14686112495837733, 0.1392242917791009, 0.1177758008998353, 0.15683659905334935, 0.22193212324054912, 0.18960402201628312, 0.23492025677114725, 0.18800653429934755, 0.10851993545657024, 0.12320754263782874, 0.14252330147428438, 0.1491167492349632, 0.13549597933888435, 1.6364331333898008, 68.4320479631424, 84.36638653278351, 76.82513639330864, 36.80889084935188, 60.93239799141884, 82.34774485230446, 111.13819196820259, 7.11482847109437, 0.27141617028973997, 0.2558177994797006, 0.44798604561947286, 1.457012223545462, 0.8325371670071036, 0.1768288848688826, 0.3555148310260847, 0.45479287568014115, 2.8154152259230614, 10.917781256139278, 4.820722946897149, 1.0413632146082819, 2.1136622317135334, 0.7767451170366257, 23.67354478687048, 98.29619586467743, 82.19092726707458, 106.43252447247505, 101.06102630496025, 99.90629106760025, 92.75176897644997, 87.94033035635948, 93.38749006390572, 95.04997685551643, 96.2280884385109, 94.58930477499962, 83.98528218269348, 79.80039954185486, 73.67442145943642, 76.93423613905907, 73.78383278846741, 77.96550840139389, 86.57627195119858, 94.23600733280182, 88.99438619613647, 92.7553103864193, 91.32635906338692, 84.86514776945114, 82.10691377520561, 68.90250831842422, 72.94859200716019, 79.54606398940086, 78.96534875035286, 82.09407046437263, 85.90572953224182, 86.51142463088036, 85.78328490257263, 82.88615316152573, 82.67302259802818, 84.96365368366241, 81.67687565088272, 87.17016488313675, 83.25007483363152, 76.38581156730652, 83.14413651823997, 80.53920909762383, 82.85102024674416, 77.89495378732681, 81.07701703906059, 83.52126628160477, 75.74186772108078, 78.72936621308327, 74.62649837136269, 77.12241724133492, 77.22501933574677, 74.36759546399117, 75.41180223226547, 78.38740736246109, 68.98476630449295, 72.09138080477715, 80.15935868024826, 73.85881796479225, 77.7607449889183, 80.67845642566681, 78.10686841607094, 77.44348481297493, 75.71438759565353, 75.47872424125671, 75.89048534631729, 79.89372253417969, 75.3919292986393, 75.15264853835106, 72.0061893761158, 76.18310004472733, 73.80477726459503, 73.48890781402588, 74.50026914477348, 77.63186350464821, 77.10159435868263, 75.31742289662361, 75.3372274339199, 73.71604442596436, 73.85651528835297, 74.57589268684387, 70.80833405256271, 76.35491162538528, 72.07927465438843, 76.06057941913605, 72.69276693463326, 72.27766200900078, 64.7960838675499, 64.66904908418655, 63.08093190193176, 76.70527562499046, 62.12670050561428, 58.5650984197855, 72.73358434438705, 74.20384705066681, 69.6617303788662, 69.14205506443977, 58.65534357726574, 62.567674443125725, 66.41870319843292, 42.523749992251396, 6.898518428206444, 5.108886659145355, 2.278383867815137, 0.9435805084649473, 1.1253824061714113, 11.06726048514247, 1.6688613058067858, 0.5026016430929303, 0.7889266102574766, 0.66017817822285, 0.19973580725491047, 1.326869206968695, 1.4870205195620656, 0.18090937606757507, 0.16562046599574387, 0.27344888309016824, 15.395574979484081, 94.43352833390236, 90.49947023391724, 114.35426339507103, 92.36878752708435, 53.23392368853092, 69.37673047184944, 83.6644198000431, 58.12801167368889, 83.74549984931946, 15.845468938350677, 0.3203450463479385, 0.3976587555371225, 0.13357794319745153, 0.20661288901465014, 0.25002411974128336, 0.23727228603092954, 0.25842564704362303, 0.16171467636013404, 0.13430719234747812, 0.1771446835482493, 0.12012544044409879, 0.21019345469539985], [0.04408665561641101, 0.04493931650358718, 0.023648018068342935, 0.018553738300397526, 0.0780096507514827, 0.06485836347565055, 0.040275371065945365, 0.02310638014023425, 0.06610696014831774, 0.06170501139422413, 0.0768614443950355, 0.08168877364369109, 0.09675637527834624, 0.08097869416815229, 1.2478349916636944, 47.769018933176994, 68.0188125371933, 44.80804301798344, 33.98562714457512, 54.837726429104805, 84.70284327864647, 38.105753660202026, 0.7872044714167714, 0.18632466439157724, 0.1704545339453034, 0.1880905602592975, 0.2196858054958284, 0.1144042462692596, 0.129509593534749, 0.07437605119775981, 0.24915010726545006, 2.636698465794325, 3.138316199183464, 0.2530136686982587, 0.26836205448489636, 0.40935532946605235, 6.053608115762472, 80.72190329432487, 84.03593346476555, 90.64125582575798, 90.96459567546844, 92.24717125296593, 87.97486290335655, 77.9825010895729, 82.57713854312897, 87.05506905913353, 88.28645378351212, 90.53570508956909, 82.90375381708145, 78.42032119631767, 72.28578597307205, 66.1213767528534, 66.72843217849731, 68.01408559083939, 68.80278646945953, 71.51981547474861, 75.3370450437069, 75.84078401327133, 76.99269220232964, 78.0124282836914, 80.63774541020393, 81.07185691595078, 73.46198245882988, 62.49080836772919, 68.63103568553925, 65.35350635647774, 68.90269070863724, 74.3353807926178, 77.8615003824234, 75.87144836783409, 73.73763486742973, 76.45463347434998, 77.17302292585373, 71.96171656250954, 78.4169165790081, 77.78036713600159, 80.97687721252441, 74.94869068264961, 75.6695120036602, 73.37525591254234, 75.55991068482399, 75.48782855272293, 78.69893744587898, 73.44903275370598, 70.08774071931839, 68.3579595386982, 67.16058298945427, 78.03236961364746, 72.4557812511921, 71.93953335285187, 68.93499657511711, 65.09507462382317, 76.54232516884804, 74.6784719824791, 71.59457266330719, 68.85023072361946, 68.3078782260418, 72.29001894593239, 69.64488208293915, 70.87567403912544, 72.23528668284416, 66.99610501527786, 65.58608427643776, 67.0432148873806, 68.9607971906662, 70.49087628722191, 64.78161424398422, 66.72407761216164, 69.6897728741169, 66.50647088885307, 67.16280207037926, 69.77130129933357, 69.41268414258957, 65.06180360913277, 70.32199054956436, 67.36565798521042, 69.96342658996582, 68.69199961423874, 66.36343136429787, 66.16956576704979, 65.60382932424545, 65.10283380746841, 66.69848218560219, 61.61495916545391, 59.338824301958084, 57.80854381620884, 48.1821745634079, 47.508565708994865, 52.079405039548874, 49.25636552274227, 48.63347254693508, 56.710718125104904, 54.064756706357, 54.05900001525879, 41.193669363856316, 28.79789661616087, 25.914390943944454, 16.547825150191784, 4.711130177602172, 1.881667342968285, 0.2097878561471589, 0.8399117400404066, 0.7168855040799826, 2.550979577936232, 1.8511851411312819, 0.4826585319824517, 0.03390858262719121, 0.16513759503141046, 0.040504635326215066, 0.146432148758322, 0.133636973623652, 0.0834213025518693, 0.04969467227056157, 0.8400260901544243, 39.53786641359329, 68.15783187747002, 81.76588967442513, 83.83893683552742, 27.717511989176273, 56.767737865448, 50.89821182191372, 56.06087699532509, 51.73047736287117, 3.6844207579270005, 0.20154796860879287, 0.1017708593280986, 0.05610122127109207, 0.14669188560219482, 0.025569896679371595, 0.07438359141815454, 0.045207432194729336, 0.08490857391734608, 0.008142989026964642, 0.011680973057082156, 0.04680989972257521, 0.039250060654012486, 0.10418056830530986, 0.08938657425460406, 0.04087028035428375, 0.07790729374391958, 0.02898194288718514, 0.0442003711941652, 0.02424977737973677, 0.0041201149269909365, 0.03996152794570662, 0.02849172095011454, 0.1083054844639264, 0.054105567614897154, 0.013445652730297297, 0.10170196575927548, 1.5961386705748737, 58.35567645728588, 73.18331301212311, 57.36394867300987, 32.85911679267883, 41.926007866859436, 99.35385391116142, 49.541802406311035, 0.9097967587877065, 0.09777025290532038, 0.21386864420492202, 0.6508070498239249, 0.23004804243100807, 0.24861402431270108, 0.1335961406584829, 0.05172663921257481, 0.37268625805154443, 4.105128720402718, 5.743064554408193, 0.6421451177448034, 0.24928425787948072, 0.5615516204852611, 7.464817715808749, 89.73292976617813, 94.34617102146149, 99.28837582468987, 94.3319445848465, 96.7995397746563, 90.65523147583008, 83.7752066552639, 87.29529976844788, 93.26097965240479, 91.2406812608242, 89.65653866529465, 85.46951293945312, 81.4336659014225, 75.94101503491402, 69.61906626820564, 71.27496421337128, 70.41684865951538, 72.09812924265862, 72.61947646737099, 77.84155145287514, 78.86306583881378, 80.40382236242294, 81.43575578927994, 84.20717507600784, 82.82241538167, 78.72138664126396, 71.0691824555397, 76.17894306778908, 73.30525606870651, 75.15177458524704, 77.99542039632797, 81.33440002799034, 78.52617591619492, 76.37320384383202, 80.71901544928551, 81.70676484704018, 73.80289256572723, 80.63901454210281, 82.19449907541275, 84.7181336581707, 77.2698949277401, 80.64909920096397, 75.38401052355766, 78.5074733197689, 79.58885729312897, 81.87267154455185, 74.0969055891037, 73.31844136118889, 70.01847043633461, 70.35384804010391, 77.80612215399742, 73.21343779563904, 75.53178459405899, 72.75595754384995, 69.37804520130157, 78.47224920988083, 74.91980463266373, 73.51680591702461, 72.58160009980202, 71.62798807024956, 75.74521154165268, 72.64776214957237, 74.09465610980988, 74.89459678530693, 71.83646768331528, 68.15277814865112, 69.40488696098328, 71.00053533911705, 74.15880426764488, 70.52008911967278, 71.31218701601028, 71.55266091227531, 68.23829635977745, 70.40350377559662, 72.29015573859215, 70.18487870693207, 68.82750794291496, 72.5532004237175, 71.69792711734772, 70.68558543920517, 72.49228209257126, 69.13121804594994, 68.70441734790802, 66.91849797964096, 68.01185131072998, 70.33781290054321, 67.10946053266525, 64.10186871886253, 63.84336858987808, 55.248176604509354, 51.39840178191662, 57.202145755290985, 56.174563094973564, 54.412457048892975, 58.56842704117298, 61.68268293142319, 58.36234509944916, 51.46734908223152, 46.68717138469219, 56.49794094264507, 26.12008150666952, 3.07097383774817, 3.1189035158604383, 0.23904186295112595, 1.0883453185670078, 1.2153793894685805, 5.596647961065173, 2.672677547670901, 0.32559286162722856, 0.07051343971397728, 0.25280295812990516, 0.05362059637263883, 0.1733038912061602, 0.2269096186500974, 0.04170731903286651, 0.08855137610225938, 0.5492840381339192, 48.076927810907364, 78.91811728477478, 93.55789572000504, 98.15044328570366, 39.77953344583511, 50.359070152044296, 56.525915041565895, 59.85340788960457, 60.846317410469055, 5.493215136229992, 0.1969228746020235, 0.12319643268710934, 0.01848520838393597, 0.10497730094357394, 0.020172930126136634, 0.020621973999368493, 0.07636527414433658, 0.0891516770934686, 0.06633517798036337, 0.05393509258283302, 0.0709342745540198, 0.040193467648350634, 0.23406678694300354, 0.22355285502271727, 0.10247793310554698, 0.11344206664944068, 0.13938299263827503, 0.12042885267874226, 0.1383390580303967, 0.10972255608066916, 0.18885013356339186, 0.1805275262449868, 0.3194991761120036, 0.16772478120401502, 0.1825988307246007, 0.30776303086895496, 2.1075208112597466, 69.9629782140255, 85.69889143109322, 55.86491011083126, 43.15693661570549, 77.82944530248642, 106.62067517638206, 60.78219585120678, 0.9512242733035237, 0.3164374904008582, 0.23375891440082341, 2.4114750511944294, 1.871104147285223, 0.45887721120379865, 0.3965519164921716, 0.24677530891494825, 0.659188034478575, 7.123880535364151, 10.323573891073465, 1.0687809996306896, 1.2438479368574917, 0.9729140438139439, 9.38859036192298, 97.90472567081451, 93.78233447670937, 107.26938396692276, 97.10784763097763, 101.32743000984192, 95.92383876442909, 87.15362817049026, 90.71060970425606, 97.00489595532417, 93.76044765114784, 95.26137471199036, 89.65064898133278, 85.28982058167458, 79.2929519712925, 71.56677335500717, 73.9096212387085, 74.5778837800026, 75.1960802078247, 77.36269354820251, 81.70621767640114, 83.71069371700287, 85.36027640104294, 84.16853114962578, 90.5809834599495, 85.49921214580536, 79.23809811472893, 76.15395560860634, 78.36309626698494, 75.85368812084198, 79.36826393008232, 83.66267189383507, 85.05617871880531, 84.35096696019173, 80.3410117328167, 85.60588002204895, 87.46635898947716, 79.68914911150932, 82.07798212766647, 84.24211040139198, 86.99980482459068, 81.07792139053345, 84.5181655883789, 78.94691973924637, 83.3746625483036, 82.69516780972481, 85.13950824737549, 78.73798415064812, 76.6102047264576, 74.06931146979332, 71.53998479247093, 84.2459785938263, 78.2562156021595, 78.47595021128654, 74.52487662434578, 69.5794951915741, 84.33519780635834, 79.99497950077057, 76.26053228974342, 75.64474493265152, 74.51360642910004, 77.60879874229431, 74.40332114696503, 76.77936404943466, 77.2751234471798, 74.47009116411209, 70.15136450529099, 73.94024759531021, 75.51068052649498, 75.97373887896538, 72.33698442578316, 74.02536302804947, 75.47788068652153, 71.0579426586628, 74.20225873589516, 75.82374572753906, 73.12931030988693, 70.90411931276321, 76.93307340145111, 74.59204941987991, 74.93121922016144, 74.58777084946632, 73.53482455015182, 73.47435459494591, 72.30448096990585, 72.71000280976295, 73.81501391530037, 74.03817594051361, 71.3998407125473, 68.28931242227554, 64.79938209056854, 57.58974775671959, 61.01401001214981, 58.849079981446266, 59.01231922209263, 67.38392740488052, 69.30317401885986, 68.51893410086632, 58.32952246069908, 56.524516716599464, 55.7352040708065, 29.52687229961157, 7.516185734421015, 3.7052792636677623, 0.574849956901744, 2.116324701346457, 3.33811660297215, 9.480760116130114, 5.5503730941563845, 0.8929441880900413, 0.18842555087758228, 0.45692245359532535, 0.14628361532231793, 2.450208510272205, 0.5010423017665744, 0.09538156897178851, 0.14380936918314546, 1.2571856961585581, 56.24746598303318, 86.40265926718712, 99.0046526491642, 99.51789110898972, 48.55546273291111, 74.94497448205948, 63.19263830780983, 68.17506015300751, 74.85972225666046, 7.547859409824014, 0.39326230238657445, 0.23460582364350557, 0.18055152730084956, 0.38115428178571165, 0.1296185259707272, 0.13531841308576986, 0.2540261362446472, 0.21466290549142286, 0.22852601628983393, 0.14587552315788344, 0.23187807470094413, 0.16896930348593742], [0.0916829721245449, 0.05249274712696206, 0.06517914196592756, 0.025919427826011088, 0.01947799974004738, 0.013824576635670383, 0.032235737235168926, 0.07247714762343094, 0.07819257531082258, 0.062106795303407125, 0.03431054836255498, 0.03141566405247431, 0.10659307517926209, 0.2628972055390477, 1.5184307028539479, 58.68519477546215, 61.38469152152538, 56.00067302584648, 57.18122407793999, 60.108457803726196, 92.4177061021328, 13.318949360400438, 0.12949573021614924, 0.032855471363291144, 0.14764748979359865, 0.9047018853016198, 0.10587317708996125, 0.1624184550018981, 0.07901886026957072, 0.21620875457301736, 0.0718945542757865, 1.0233698738738894, 0.5875847954303026, 1.061085700057447, 0.6108955945819616, 2.200788944028318, 59.22145999968052, 93.11623021960258, 89.03458803892136, 89.8170268535614, 91.1403514444828, 87.04404965043068, 78.35681900382042, 79.89993140101433, 85.89883670210838, 89.15678948163986, 86.37891054153442, 81.89712703227997, 82.4963852763176, 76.60176917910576, 71.65258795022964, 66.58056691288948, 65.00367432832718, 65.99843055009842, 70.53968846797943, 70.17903462052345, 75.91437846422195, 76.29097625613213, 74.95830416679382, 74.17500659823418, 78.35776895284653, 76.20796591043472, 81.50864347815514, 80.45272573828697, 75.55427178740501, 74.92485076189041, 72.24169313907623, 71.96047782897949, 74.15283858776093, 74.82347220182419, 77.20700830221176, 77.04997792840004, 68.6249940097332, 74.78037491440773, 79.56192433834076, 81.22385635972023, 77.37397894263268, 71.2503719329834, 71.68823763728142, 71.47430151700974, 75.91814026236534, 77.49699354171753, 70.408466309309, 67.92331606149673, 74.2785282433033, 64.38512071967125, 74.15274739265442, 63.93327176570892, 65.50646334886551, 68.71770903468132, 67.42491960525513, 67.92861297726631, 70.50409957766533, 70.83025127649307, 70.7895478606224, 73.63971412181854, 71.87109902501106, 73.79684329032898, 73.38425382971764, 71.33319988846779, 71.47807091474533, 76.53341084718704, 74.00925189256668, 63.475555926561356, 66.35957837104797, 70.2528190612793, 71.62653654813766, 70.24728655815125, 67.76774480938911, 70.0581707060337, 69.19123202562332, 64.48864996433258, 66.13268494606018, 68.9355817437172, 65.48108831048012, 67.71563440561295, 69.38249856233597, 64.24072086811066, 63.81927788257599, 68.0225819349289, 65.66908702254295, 64.4717788696289, 64.94138807058334, 58.7416635453701, 51.056378334760666, 45.744768753647804, 50.296126529574394, 56.4253344386816, 57.80817523598671, 61.13644324243069, 53.92682030797005, 46.51084564626217, 46.49523228406906, 50.22580750286579, 55.03924481570721, 49.947700425982475, 27.3666388168931, 13.254098240286112, 18.575411550700665, 3.2637303695082664, 0.7933005911763757, 0.1353172553353943, 1.1004993226379156, 0.5322866595815867, 0.30463256291113794, 0.11317310490994714, 0.18095720006385818, 0.11561794715817086, 0.11386891288566403, 0.11837776430184022, 0.07416142208967358, 0.1360734592890367, 0.04663367675675545, 0.0656672302284278, 6.505207708105445, 72.92984381318092, 58.42632606625557, 34.526759907603264, 26.44049171358347, 43.193901032209396, 44.75260019302368, 48.96919973194599, 30.64951255917549, 0.2831091819098219, 0.035852519722539, 0.052765156142413616, 0.09372899905429222, 0.04561886402370874, 0.10023506634752266, 0.05683663024683483, 0.03228670422686264, 0.061754523776471615, 0.028192312602186576, 0.0677878652641084, 0.08061160566285253, 0.030966117374191526, 0.06898824460222386, 0.007779062534609693, 0.04037169441289734, 0.03210537528502755, 0.01991055680264253, 0.01047711490173242, 0.05945918717770837, 0.009754714847076684, 0.025871561156236567, 0.03580827287805732, 0.014503187194350176, 0.03178782142640557, 0.09979539579944685, 0.24409386998740956, 2.1399556333199143, 68.32591205835342, 66.86003431677818, 57.34152227640152, 37.00792796909809, 60.52291676402092, 111.18581101298332, 18.424187265336514, 0.1445033069467172, 0.051992918088217266, 0.17327932611806318, 0.7978960289619863, 0.6978591531515121, 0.19384547020308673, 0.2923285262659192, 0.3199238033266738, 0.20265592087525874, 1.3111196458339691, 0.7550985692068934, 2.4238450499251485, 1.282821970526129, 3.2172543508931994, 68.0965031683445, 102.05813840031624, 94.44602966308594, 95.38410812616348, 95.36685705184937, 91.17431402206421, 82.73337855935097, 82.77037337422371, 90.09721621870995, 91.12076729536057, 90.72792917490005, 87.77756229043007, 85.89188307523727, 78.56839165091515, 75.85080787539482, 71.7558816075325, 69.36678260564804, 69.93957906961441, 72.86847710609436, 72.80204147100449, 76.1167100071907, 75.27006223797798, 77.60780319571495, 79.33482572436333, 81.58033803105354, 80.17385870218277, 81.9442293047905, 82.7871684730053, 79.86799791455269, 79.60572838783264, 78.45993027091026, 78.48891511559486, 78.38953524827957, 80.01118183135986, 81.07579350471497, 80.40557786822319, 72.46520474553108, 80.94991385936737, 81.6097104549408, 83.85228171944618, 79.78454679250717, 74.4133298099041, 76.09065860509872, 77.08787709474564, 77.9557429254055, 78.41011494398117, 70.93984499573708, 72.16819748282433, 75.59519559144974, 67.82246187329292, 76.65012538433075, 67.35930472612381, 69.71416756510735, 71.42478257417679, 71.0907880961895, 71.15117445588112, 70.82871615886688, 71.79020136594772, 74.27820906043053, 77.34685599803925, 74.3772241473198, 74.71327051520348, 72.8851506114006, 74.33402806520462, 73.83846625685692, 77.43203222751617, 78.30935955047607, 67.24071308970451, 69.86958682537079, 69.77751016616821, 71.97097286581993, 73.91954630613327, 69.43719282746315, 71.80266469717026, 73.63229691982269, 69.42367315292358, 69.36661541461945, 71.2132403254509, 68.34067046642303, 70.0194051861763, 71.94871366024017, 67.63070896267891, 68.6387112736702, 70.68122327327728, 68.0162438750267, 69.17857870459557, 64.75015953183174, 62.33235687017441, 57.4338611215353, 54.43701513111591, 58.09565640985966, 64.89623889327049, 63.115510046482086, 65.98369494080544, 60.59768155217171, 55.574936270713806, 49.93522569537163, 56.922131180763245, 58.90128158032894, 58.83046858012676, 46.2253175675869, 41.542034670710564, 20.631838403642178, 3.6657020123675466, 1.9880688772536814, 0.12248145503690466, 1.5175966476090252, 0.6324066559318453, 0.7905879523605108, 0.11599242745433003, 0.11833082346129231, 0.14849542320007458, 0.1796441775513813, 0.07076084948494099, 0.7669037044979632, 0.21706765692215413, 0.04738079682283569, 0.1836105709662661, 8.587982822209597, 82.50506401062012, 70.37641882896423, 49.71431314945221, 31.2653911113739, 43.825111761689186, 47.08459585905075, 56.80205762386322, 37.23761044442654, 0.5553260107990354, 0.027549761143745854, 0.04913835095067043, 0.10690919298212975, 0.022929381630092394, 0.09989076177589595, 0.04672458613640629, 0.04091325812623836, 0.09191064818878658, 0.04277098363672849, 0.028231479445821606, 0.006826371736678993, 0.1580081385327503, 0.20716016355436295, 0.1453961551305838, 0.11034550741896965, 0.18559825024567544, 0.09850207730778493, 0.21173379704123363, 0.21694643452065066, 0.10689691785955802, 0.17455674038501456, 0.1528824956039898, 0.09624833808629774, 0.18836082075722516, 0.30851746851112694, 0.6194016756489873, 2.667738050222397, 82.76041030883789, 78.58941212296486, 69.78509455919266, 78.39509814977646, 80.37175208330154, 117.72421896457672, 24.579304084181786, 0.3966154740191996, 0.33599462534766644, 0.2811945596477017, 3.014768441207707, 1.457510234322399, 1.5990608325228095, 1.2744404515251517, 0.674084066413343, 0.614932106109336, 2.805959670804441, 2.500348244793713, 4.103926559910178, 2.8216974763199687, 3.973220936022699, 76.73410847783089, 105.54028674960136, 98.93992692232132, 96.60371348261833, 97.70340487360954, 97.6049217581749, 85.8360792696476, 85.6105537712574, 93.38450342416763, 93.88134196400642, 94.06032755970955, 90.57239592075348, 86.00232034921646, 82.38879784941673, 78.76239404082298, 75.26365578174591, 72.5291933119297, 73.33964422345161, 77.33585178852081, 75.74559152126312, 80.07745027542114, 81.31582662463188, 80.33649757504463, 83.45742970705032, 86.71241864562035, 85.96030220389366, 88.71962293982506, 86.13494843244553, 82.02642649412155, 83.2743327319622, 80.58036088943481, 78.74869957566261, 82.22340792417526, 82.98765331506729, 84.67519596219063, 84.81388852000237, 77.19359502196312, 80.64350590109825, 83.0155286192894, 88.43440264463425, 84.31582644581795, 76.50270089507103, 80.72247326374054, 78.95491451025009, 81.41120910644531, 84.74568977952003, 77.55252376198769, 73.79989832639694, 81.38462573289871, 68.95841851830482, 80.8863964676857, 71.43746629357338, 73.12629327178001, 77.57629528641701, 74.78491947054863, 72.72248893976212, 74.70700085163116, 77.32578232884407, 76.50466158986092, 80.67144200205803, 74.26334425806999, 79.13408249616623, 76.88291609287262, 77.19723522663116, 73.24532568454742, 81.39472559094429, 79.09546136856079, 70.09707301855087, 73.93498107790947, 75.76149746775627, 77.04714328050613, 76.94058179855347, 72.6632197201252, 76.88692107796669, 77.53215685486794, 72.87911653518677, 73.11664938926697, 77.155422270298, 72.08073377609253, 74.71724510192871, 71.83654367923737, 71.87594756484032, 71.31382092833519, 77.4823947250843, 72.64658421278, 73.3216255903244, 74.14779245853424, 67.19925731420517, 60.94605065882206, 60.04862241446972, 62.87879414856434, 69.40532013773918, 68.40408146381378, 71.07440337538719, 65.22358372807503, 62.02128276228905, 57.84520424902439, 64.84330013394356, 67.98181772232056, 64.6428532898426, 50.15253983438015, 40.162640288472176, 24.493252001702785, 8.151880223304033, 2.562554944306612, 0.20811722235521302, 3.202728917822242, 1.304901516996324, 1.4018350280821323, 0.42401675367727876, 0.5350724444724619, 0.3283754998119548, 0.23209536069771275, 0.1494293418363668, 0.5741375545039773, 0.3344395291060209, 0.16030196857172996, 0.2893333073006943, 11.74199027940631, 93.47800880670547, 70.93108266592026, 52.984543070197105, 39.1586771607399, 53.468773886561394, 58.828086107969284, 63.77794370055199, 49.05920170247555, 1.0680972738191485, 0.0978104847308714, 0.1422884562634863, 0.15372895955806598, 0.14700250409077853, 0.19088957022177055, 0.1661463815253228, 0.12455235875677317, 0.14888831618009135, 0.09850307178567164, 0.30778983724303544, 0.08674387543578632, 0.3038381680380553], [0.0745708798058331, 0.01755298926582327, 0.01165997769930982, 0.029279330738063436, 0.06544304967974313, 0.04435221460880712, 0.04558768639981281, 0.060508060778374784, 0.0833060618606396, 0.05512505587830674, 0.0875105065642856, 0.09892113841488026, 0.034620844016899355, 0.44020973320584744, 5.2176600974053144, 59.51101966202259, 47.6720405369997, 41.79547347128391, 44.54039677977562, 79.55229565501213, 68.22278559207916, 2.5018261279910803, 0.15031387796625495, 0.16790920490166172, 0.02161784712370718, 0.5662750639021397, 0.16773582436144352, 0.2879327262053266, 0.09489377756835893, 0.3237411438021809, 0.5622605793178082, 0.9470813674852252, 0.9959374833852053, 1.253278199583292, 0.48682865977752954, 30.779216699302197, 70.69836795330048, 86.9868703186512, 90.71941763162613, 94.14557978510857, 83.93387854099274, 80.39012029767036, 78.83905112743378, 79.75760623812675, 85.03418549895287, 86.04861706495285, 87.38459497690201, 87.84358754754066, 82.00771629810333, 75.95622941851616, 74.24279496073723, 66.38119921088219, 66.5885616838932, 66.30569726228714, 67.40416511893272, 71.6013514995575, 72.65460938215256, 72.77696281671524, 73.41915875673294, 72.1265821158886, 74.86960172653198, 76.62981927394867, 73.3908274769783, 73.65976944565773, 78.2927468419075, 76.52126669883728, 78.91090527176857, 79.51236739754677, 73.87533187866211, 76.98938637971878, 78.85575503110886, 67.87923082709312, 72.4410380423069, 83.19582134485245, 77.54759162664413, 76.61669477820396, 71.64394721388817, 73.73426824808121, 73.06606650352478, 78.00224483013153, 74.0072076022625, 68.01260367035866, 69.82797145843506, 72.70181804895401, 68.52170795202255, 72.46576711535454, 65.29710218310356, 65.80257385969162, 66.39885306358337, 66.08514189720154, 63.917631804943085, 63.1432181596756, 63.693930208683014, 70.50787657499313, 67.18492448329926, 69.7753594815731, 73.88274148106575, 71.0682401061058, 69.56592231988907, 71.44569665193558, 68.03548604249954, 69.54482585191727, 74.57181930541992, 71.37682154774666, 68.07469993829727, 65.79361394047737, 65.41133165359497, 69.01603102684021, 70.2155202627182, 67.45241492986679, 66.4240837097168, 71.27114921808243, 65.9046819806099, 60.58342091739178, 61.85413733124733, 62.20308020710945, 65.78708589076996, 65.58590948581696, 66.19391486048698, 63.34341801702976, 64.72690477967262, 61.3155884295702, 60.30405230820179, 53.78487512469292, 58.951628878712654, 59.11062754690647, 60.622144639492035, 55.55098235607147, 60.000262409448624, 57.72621363401413, 63.91587629914284, 63.382506519556046, 52.02795960009098, 45.23334659636021, 49.47879798710346, 55.07842071354389, 62.033062130212784, 36.428402066230774, 20.92559304088354, 21.062385700643063, 1.5097853355109692, 0.30436972388997674, 0.2954344142926857, 0.3665635990910232, 1.0697596846148372, 0.2833447098964825, 0.07377704154350795, 0.17059238045476377, 0.7367814739700407, 0.06177121838845778, 0.7064972177613527, 0.15546871698461473, 0.05455412538140081, 0.020246504791430198, 0.5732722103130072, 36.15176931023598, 73.60620751976967, 26.217354387044907, 31.12773209810257, 41.53299115598202, 54.335579574108124, 54.207895025610924, 22.54733081907034, 0.03620046452851966, 0.06383766551152803, 0.06592235833522864, 0.030342039826791734, 0.015597686178807635, 0.10073013079818338, 0.11446726944996044, 0.060825711116194725, 0.016422781845903955, 0.015721567324362695, 0.04961634229402989, 0.0189885477811913, 0.10542203293880448, 0.004660705035348656, 0.09260272316168994, 0.027829704813484568, 0.020674952211265918, 0.030049410997889936, 0.05143552436493337, 0.03555105191480834, 0.019806029013125226, 0.057148914856952615, 0.10729827874456532, 0.04158260482654441, 0.09287868335377425, 0.07428733486449346, 0.4336392623372376, 7.05457747913897, 71.1367580294609, 54.8111392557621, 53.64756569266319, 37.16529652476311, 87.85842955112457, 84.0533821284771, 2.959097628481686, 0.08965565473772585, 0.08109371963655576, 0.3227271029027179, 0.5423869926016778, 0.3891247697174549, 0.06230619183043018, 0.23839945992222056, 0.3339169383980334, 0.9206982550676912, 1.3781142071820796, 2.740297056734562, 1.7467805184423923, 0.760201457887888, 39.21374760568142, 80.9140893816948, 95.84034964442253, 96.52831792831421, 98.49196135997772, 87.10566714406013, 84.0221706032753, 82.78609693050385, 83.65992844104767, 87.73705646395683, 89.33188408613205, 91.45107597112656, 88.88204142451286, 83.69844317436218, 80.71265459060669, 76.6594272851944, 70.66453456878662, 69.50744345784187, 70.11274337768555, 71.03727176785469, 75.08050560951233, 73.86573359370232, 76.94761142134666, 75.44425249099731, 76.95131242275238, 76.95594817399979, 81.16416156291962, 79.1040489077568, 77.84000873565674, 84.8226660490036, 79.1676726937294, 82.1050138771534, 82.76231780648232, 79.25858661532402, 80.02795413136482, 81.53194382786751, 72.15590134263039, 76.30294561386108, 83.75293985009193, 81.91929504275322, 74.95499074459076, 74.41969066858292, 77.65392512083054, 76.09122097492218, 81.00495770573616, 77.08189621567726, 69.28685769438744, 75.01846253871918, 74.45463359355927, 71.12464427947998, 74.49045807123184, 68.95884409546852, 69.48426470160484, 72.20953166484833, 70.52558362483978, 70.14662235975266, 66.09413221478462, 66.20359674096107, 73.49864289164543, 67.86573395133018, 70.77127084136009, 76.12054020166397, 72.79864445328712, 72.66654074192047, 75.71811899542809, 70.52406370639801, 73.01638036966324, 73.77565562725067, 74.52018767595291, 73.22226852178574, 70.11581361293793, 69.91882458329201, 72.24141955375671, 73.63589152693748, 70.78373417258263, 69.8039947450161, 73.61441507935524, 71.00636422634125, 64.67230170965195, 65.21492019295692, 64.98640045523643, 67.97116309404373, 69.16149482131004, 70.27701616287231, 66.85478299856186, 69.01725456118584, 63.18307802081108, 65.15745967626572, 59.47944335639477, 66.04532763361931, 64.35630306601524, 69.20299619436264, 63.525686636567116, 66.28265529870987, 62.806803211569786, 69.35258656740189, 68.75391349196434, 61.555853337049484, 52.84374922513962, 53.31913411617279, 57.477254793047905, 67.42562636733055, 58.25665757060051, 39.69697147607803, 25.402995385229588, 3.881561066955328, 0.6638792983721942, 0.5348454066552222, 0.6880322273354977, 2.831990411505103, 0.6253373727668077, 0.16720132960472256, 0.17480225767940283, 1.194794112816453, 0.026243694410368335, 0.4919264424825087, 0.1274466753238812, 0.09932837710948661, 0.07787421622197144, 0.7507589645683765, 43.56531210243702, 78.76536548137665, 29.432481564581394, 33.78433294594288, 47.63872392475605, 57.152117639780045, 62.544522285461426, 28.440024219453335, 0.05170909484149888, 0.05957491768640466, 0.01747029360558372, 0.06636142774368636, 0.015181531507550972, 0.07829054622561671, 0.09095125904423185, 0.036110831642872654, 0.010309806984878378, 0.04117040487471968, 0.04181383948889561, 0.018538529839133844, 0.16860744712175801, 0.16542201570700854, 0.14808687090408057, 0.08868794611771591, 0.16105466958833858, 0.1425941617344506, 0.18151502794353291, 0.13900650112191215, 0.11504278270876966, 0.13578157260781154, 0.2194426630740054, 0.2506225579418242, 0.17496842454420403, 0.23353046650299802, 0.7246170798316598, 9.442995842546225, 86.97778880596161, 59.998111724853516, 53.53050157427788, 68.88300016522408, 98.14551115036011, 94.08879563212395, 3.768604528158903, 0.2935198514023796, 0.3355643874965608, 1.0875105508603156, 4.0187242068350315, 0.5781591637060046, 0.5548107821960002, 0.4095922823762521, 1.3625050010159612, 2.2419362235814333, 3.2440120400860906, 5.707647129893303, 4.4243215676397085, 1.213160902261734, 46.35363668203354, 86.62235587835312, 97.60367542505264, 102.30725303292274, 102.0509871840477, 92.92725875973701, 87.89233133196831, 87.04976454377174, 87.43122607469559, 91.46936818957329, 91.55888378620148, 92.03277915716171, 92.49016061425209, 89.34837520122528, 84.48611810803413, 83.24889689683914, 73.58369752764702, 74.13737341761589, 75.16012653708458, 74.71804305911064, 79.26202163100243, 78.15756529569626, 79.70861926674843, 79.78485837578773, 79.18205112218857, 84.68061447143555, 84.37998220324516, 80.91193869709969, 83.19554775953293, 88.29292863607407, 85.18912598490715, 84.92240309715271, 88.48645985126495, 80.52873685956001, 82.88076505064964, 86.78491115570068, 76.3099904358387, 78.03667098283768, 87.60266527533531, 84.53173086047173, 82.07998842000961, 77.12649822235107, 80.41548013687134, 78.23944330215454, 83.15691903233528, 82.37121999263763, 73.61287236213684, 76.81587249040604, 78.23379680514336, 73.36697235703468, 77.11171701550484, 72.8604519367218, 70.1036162674427, 73.1346832215786, 72.59922355413437, 71.25838950276375, 67.73339465260506, 71.56697854399681, 75.97697630524635, 74.98825415968895, 75.39008259773254, 79.7323527932167, 78.8170275092125, 75.50628796219826, 78.38099330663681, 73.2073125243187, 75.27643829584122, 79.58943486213684, 76.86224520206451, 75.85167422890663, 73.3347424864769, 71.20899215340614, 76.38016507029533, 77.09336400032043, 72.37051382660866, 70.54826080799103, 78.40107142925262, 74.3164350092411, 68.69680255651474, 70.20504042506218, 66.94844037294388, 70.80843284726143, 74.20517697930336, 75.30910894274712, 70.98481178283691, 75.34681051969528, 68.73787835240364, 65.59971794486046, 62.93839395046234, 70.3281082212925, 71.21786087751389, 73.48090544342995, 69.56392362713814, 71.56537503004074, 67.65663117170334, 75.91936379671097, 74.00754198431969, 65.25111705064774, 57.183401361107826, 62.51536265015602, 65.94785526394844, 73.81062895059586, 56.49216905236244, 37.27310433983803, 32.61862009763718, 8.489823639392853, 1.1769577511586249, 1.1423563328571618, 1.891521045472473, 4.529014024883509, 1.4308316283859313, 0.3540283686015755, 0.571984495036304, 1.8632269324734807, 0.38962040562182665, 2.115965145640075, 0.4917197395116091, 0.23934513417771086, 0.16341309616109356, 1.2687172461301088, 53.598027750849724, 89.3182048201561, 36.90026834607124, 47.75732696056366, 52.005160823464394, 66.8853409588337, 71.75001472234726, 34.27159979939461, 0.15082045312738046, 0.2008418893092312, 0.10050678887637332, 0.08801039497484453, 0.1602035597898066, 0.15842173743294552, 0.18209341331385076, 0.15245592396240681, 0.14024998439708725, 0.13311341812368482, 0.1267514016944915, 0.164750475960318, 0.2699005859903991], [0.01642257033381611, 0.03047124217118835, 0.022642224284936674, 0.09032278612721711, 0.016749953938415274, 0.040092264680424705, 0.0585663130186731, 0.06342060820315965, 0.06350450057652779, 0.06377341778716072, 0.005532437726287753, 0.03177911232342012, 0.17061311606084928, 0.1754615074605681, 16.525258161127567, 64.4920925796032, 41.22985102236271, 44.68860402703285, 39.468083158135414, 93.54430004954338, 36.5210334956646, 0.20575262111378834, 0.06629695737501606, 0.02918476257036673, 0.07194565114332363, 0.5532855202909559, 0.1788315555313602, 0.07624244870385155, 0.027842184026667383, 0.08569274199544452, 0.7926359830889851, 0.694605577737093, 0.3497943567344919, 1.3576025515794754, 34.313367158174515, 82.38984659314156, 87.39741548895836, 96.08369618654251, 89.68181490898132, 86.88305988907814, 79.13022190332413, 77.0279011130333, 71.82332798838615, 79.42703157663345, 82.26466611027718, 88.8616593182087, 89.08688843250275, 82.84130796790123, 82.09033146500587, 75.86138650774956, 71.88737735152245, 66.42251819372177, 69.15945053100586, 68.57151567935944, 71.68083563446999, 74.0148375928402, 76.59099295735359, 75.88555321097374, 72.15303629636765, 71.92740440368652, 70.2144867181778, 66.26008450984955, 75.86156129837036, 76.83416470885277, 74.73818197846413, 75.83711341023445, 78.38391914963722, 72.0069645345211, 76.39040932059288, 76.85903057456017, 73.00315707921982, 74.55573856830597, 77.89292469620705, 77.8942622244358, 73.83598119020462, 71.9463349878788, 74.24398049712181, 73.7718254327774, 77.87194222211838, 70.7296022772789, 64.26231890916824, 72.71189510822296, 78.08367446064949, 67.53366217017174, 73.9864607155323, 63.75506892800331, 67.22593948245049, 71.76916569471359, 69.53339606523514, 72.36573368310928, 71.9441083073616, 68.37400987744331, 60.49038290977478, 68.47361013293266, 65.62988832592964, 61.209897100925446, 69.62025180459023, 68.82335096597672, 68.72173681855202, 73.15873593091965, 66.94549933075905, 68.41920465230942, 69.94185894727707, 68.12451526522636, 71.01261109113693, 70.0699120759964, 72.92754113674164, 66.81404158473015, 66.70287474989891, 70.61234056949615, 70.04014447331429, 64.45341065526009, 65.11506915092468, 68.31160962581635, 64.46710512042046, 62.51310937106609, 60.222516283392906, 62.56286770105362, 61.03530406951904, 60.28970807790756, 60.39387188851833, 64.3776199221611, 63.19948174059391, 61.875435188412666, 67.51733064651489, 62.22931019961834, 61.750570088624954, 61.36779762804508, 60.47272525727749, 61.37697033584118, 62.678320705890656, 63.73603194952011, 62.58145250380039, 53.98289389908314, 44.366290122270584, 40.421926975250244, 45.661899000406265, 44.11183297634125, 30.092109069228172, 25.407830625772476, 27.280881218612194, 0.7074499572627246, 0.5601545423269272, 0.23920681269373745, 3.1811175774782896, 3.9609304955229163, 0.17569736199220642, 0.21764124801848084, 0.7063319266308099, 0.44096138037275523, 1.6652624239213765, 0.4686387092806399, 0.05495337856700644, 0.07203925080830231, 0.0713110703509301, 8.630526289343834, 77.9610550403595, 40.28774097561836, 24.354643039405346, 28.82001142948866, 39.626055881381035, 53.58939081430435, 13.871984984725714, 0.10695880555431359, 0.058060687806573696, 0.06802386080380529, 0.043228621580055915, 0.02950399553810712, 0.02721344579185825, 0.02474040007655276, 0.03154316502332222, 0.018967927207995672, 0.028488791322160978, 0.0743835320463404, 0.03178463019139599, 0.05435502200271003, 0.0788585415284615, 0.004344687422417337, 0.025806790217757225, 0.05636467998556327, 0.05335504851245787, 0.07409675876260735, 0.03316116941277869, 0.06729971762979403, 0.0060203186512808315, 0.05533024115720764, 0.07791234034812078, 0.0472769740736112, 0.14516521361656487, 0.4995676246471703, 20.905248932540417, 75.65498918294907, 51.61416940391064, 39.93915148079395, 37.21611499786377, 104.50908288359642, 43.30524645745754, 0.4073983454145491, 0.049207533957087435, 0.09713137507787906, 0.10254206950776279, 0.29023804469034076, 0.16334079613443464, 0.09336926523246802, 0.06418256380129606, 0.26305056293495, 0.5631998414173722, 0.4165883897803724, 0.47922304132953286, 2.060386477969587, 41.24998614192009, 91.80477619171143, 94.04196694493294, 100.77639877796173, 93.8420444726944, 91.80368945002556, 82.38581880927086, 79.62717443704605, 77.47740179300308, 82.70345136523247, 87.10918575525284, 90.21207645535469, 93.22728306055069, 88.47700595855713, 84.76501554250717, 81.53866186738014, 74.30606916546822, 69.4153743982315, 72.12634652853012, 71.91655978560448, 75.46990871429443, 76.98006927967072, 80.5076251924038, 78.651272803545, 75.50935819745064, 76.64170503616333, 76.5181052684784, 69.15590912103653, 79.2398764193058, 78.83475735783577, 77.14428126811981, 79.9152597784996, 83.02171468734741, 77.32357084751129, 79.46869254112244, 78.59331831336021, 75.91735750436783, 80.56719839572906, 80.65977662801743, 79.44822683930397, 73.66207212209702, 75.14629527926445, 77.32451319694519, 79.0142597258091, 80.69333642721176, 73.61614778637886, 67.5087659060955, 77.62211322784424, 78.81605476140976, 72.36691921949387, 75.98734974861145, 65.21141678094864, 71.71644732356071, 75.16834169626236, 73.89825984835625, 76.59536272287369, 75.48362597823143, 72.91453823447227, 65.47796487808228, 67.59660959243774, 68.49183395504951, 64.2733459174633, 69.05264586210251, 69.88034784793854, 69.41616475582123, 75.64900830388069, 70.66066637635231, 70.73048382997513, 73.10652673244476, 70.11693835258484, 68.83767619729042, 71.58664628863335, 74.5916998386383, 69.20662119984627, 69.40509974956512, 72.46707424521446, 74.00093793869019, 68.58178272843361, 68.39538753032684, 72.05047219991684, 66.88385903835297, 66.26430988311768, 66.01154744625092, 66.13936498761177, 65.58992207050323, 64.91603583097458, 63.13751466572285, 70.5841688811779, 65.3742304444313, 64.6952448785305, 70.5873455107212, 66.47266790270805, 67.5551538169384, 68.46287190914154, 66.21873512864113, 67.04453721642494, 65.96629947423935, 66.87091693282127, 66.38562977313995, 58.817891255021095, 51.29575029015541, 49.09633710980415, 52.311295196413994, 58.60519386827946, 53.74356374144554, 38.27557794749737, 37.16395519673824, 4.295891309157014, 0.7102211366873235, 0.16430106101324782, 4.161702934652567, 6.628331551328301, 0.15936840616632253, 0.1257300580618903, 1.3422815361991525, 0.39190052077174187, 0.14733035524841398, 0.5043421871960163, 0.08763377729337662, 0.13205504132201895, 0.14882367511745542, 11.066814959049225, 85.3553594648838, 41.907271072268486, 27.717154808342457, 36.02220766246319, 43.55078928172588, 60.3886129707098, 18.817532658576965, 0.21647943067364395, 0.08311458033858798, 0.02336712073883973, 0.06517102287034504, 0.02545182840549387, 0.03422441099246498, 0.10318514046957716, 0.021505552758753765, 0.08571072423364967, 0.017620192593312822, 0.03313089349830989, 0.03402790884138085, 0.05712017518817447, 0.2112517721252516, 0.1004591429955326, 0.12632168334675953, 0.25341659551486373, 0.09499703257461078, 0.1487881559296511, 0.15434678265592083, 0.19935985008487478, 0.11802869514212944, 0.12834676686907187, 0.1204709621379152, 0.17510536563349888, 0.23070261668181047, 0.7840043900068849, 26.9902728125453, 88.25510546565056, 55.69655254483223, 59.70891684293747, 54.79602366685867, 114.2514257133007, 51.33628651499748, 0.8410956733860075, 0.2542051422642544, 0.23767803300870582, 0.2088726990041323, 1.942264235112816, 0.7958722219336778, 0.1839718929841183, 0.29775867238640785, 0.3997094579972327, 2.617688085883856, 1.2650560238398612, 2.1572340186685324, 2.3569665011018515, 44.744225442409515, 96.25679969787598, 99.23645541071892, 105.3915399312973, 96.84200629591942, 92.95668438076973, 87.40673258900642, 83.9918102324009, 80.54965853691101, 86.82655692100525, 90.06639987230301, 92.77089715003967, 96.11681520938873, 91.23998209834099, 87.69990965723991, 85.76723456382751, 78.37908580899239, 72.43351444602013, 76.69693887233734, 74.33543398976326, 79.95674595236778, 80.74800029397011, 83.79111260175705, 81.31938323378563, 78.65233674645424, 81.0476978123188, 82.24457278847694, 76.77617982029915, 85.49731984734535, 82.75271192193031, 82.30906292796135, 84.75180745124817, 83.91665786504745, 78.67860093712807, 81.9787846505642, 83.56577709317207, 82.13778331875801, 83.8041914999485, 83.5260920226574, 81.7865301668644, 78.2877767086029, 78.08641791343689, 80.82356303930283, 78.7504018843174, 82.88526400923729, 78.26232567429543, 70.00871255993843, 80.51628112792969, 83.57388585805893, 74.33404326438904, 79.34127017855644, 72.69731149077415, 72.53474101424217, 79.61757615208626, 74.58104521036148, 79.45332616567612, 78.00129488110542, 73.91687884926796, 67.16889694333076, 73.37459474802017, 72.25211977958679, 67.55413547158241, 74.15751993656158, 75.23255825042725, 76.15378841757774, 77.92309507727623, 70.87179824709892, 74.16452676057816, 75.38097828626633, 74.98434036970139, 74.67173874378204, 76.12367883324623, 78.67916330695152, 72.07389414310455, 73.89892861247063, 77.93837025761604, 75.94241335988045, 69.70456168055534, 72.52686023712158, 75.26072233915329, 72.93830215930939, 68.82605642080307, 67.67271190881729, 69.93020877242088, 70.08701115846634, 67.61609494686127, 71.58663868904114, 68.86739820241928, 69.45685297250748, 70.65085530281067, 75.70704638957977, 72.8420989215374, 72.42598325014114, 72.33208268880844, 71.9752286374569, 71.6495481133461, 71.75739392638206, 73.48256215453148, 70.68816170096397, 61.871095821261406, 57.38124914467335, 53.723842799663544, 59.751086980104446, 58.926717415452, 52.560318633913994, 38.157468885183334, 46.963526755571365, 8.292763363569975, 1.074303409550339, 0.7218996912706643, 7.65126658603549, 9.445056281983852, 0.6950793054420501, 0.41818474943283945, 1.9944654777646065, 0.9688129357527941, 3.7048845598474145, 0.848776011262089, 0.2577467600349337, 0.4102492018137127, 0.27567265438847244, 16.618256270885468, 93.81929129362106, 55.01296542584896, 34.964754804968834, 38.235984072089195, 53.68786633014679, 73.51950377225876, 26.04772388935089, 0.4103901208145544, 0.21569349628407508, 0.08688608577358536, 0.14479298202786595, 0.13299553538672626, 0.1343902832013555, 0.12168933855718933, 0.12164802319603041, 0.2657993294997141, 0.13025816821027547, 0.18135537713533267, 0.20456695114262402, 0.15538074279902503], [0.0741916720289737, 0.02564736390922917, 0.09353297558845952, 0.006219153465281124, 0.023114369359973352, 0.05184777626709547, 0.12017546119750477, 0.028725092997774482, 0.03493016374704894, 0.013894057428842643, 0.06549940837430768, 0.04123796628846321, 0.11777670632000081, 0.054736816164222546, 32.500229850411415, 60.5830979347229, 40.247516334056854, 61.08132719993591, 56.08007736504078, 93.95783945918083, 12.998003382235765, 0.2010216226335615, 0.07578529315651394, 0.07356359245022759, 0.018604352771944832, 0.15926843887427822, 0.16679040243616328, 0.07500431631342508, 0.03558218872058205, 0.19474112370517105, 0.22958289395319298, 0.40419660159386694, 6.080705411732197, 49.147831946611404, 94.87302795052528, 88.31446588039398, 92.53818243741989, 88.67348581552505, 86.63605034351349, 77.251807898283, 75.01765698194504, 70.81971824169159, 74.96686890721321, 77.40851908922195, 89.95023250579834, 88.14266949892044, 83.88800740242004, 83.236775547266, 80.80226138234138, 73.71761754155159, 68.76945465803146, 67.87138804793358, 69.42570984363556, 72.39914909005165, 76.3466964662075, 75.09733110666275, 76.9677047431469, 73.31056818366051, 73.6798931658268, 71.26551792025566, 69.80818971991539, 67.7491258084774, 68.00719276070595, 69.73252817988396, 72.99489632248878, 79.5937742292881, 75.67822113633156, 75.69190040230751, 76.63599774241447, 71.78904622793198, 70.52839547395706, 73.11862528324127, 76.31562173366547, 72.96863973140717, 69.73099306225777, 74.2731249332428, 74.33360248804092, 78.4037920832634, 71.81952819228172, 66.26535102725029, 76.79016306996346, 76.71102851629257, 69.65320363640785, 77.60597929358482, 61.771476566791534, 66.12811759114265, 78.80138754844666, 72.17448234558105, 70.47994807362556, 65.48659041523933, 66.28210812807083, 70.37834152579308, 71.69428691267967, 58.11225771903992, 70.80055207014084, 67.64525458216667, 62.82325252890587, 63.0187064409256, 65.00516384840012, 66.32686212658882, 68.64117354154587, 66.5501457452774, 67.4243876338005, 67.55667373538017, 64.30321991443634, 65.40743306279182, 67.7228008210659, 69.69496339559555, 66.25391364097595, 66.5354785323143, 69.63425025343895, 68.08121278882027, 68.09880584478378, 65.02503678202629, 66.29603818058968, 63.41199293732643, 66.5598352253437, 60.7687521725893, 64.71698731184006, 61.80298447608948, 62.38503344357014, 67.3794512450695, 58.28671395778656, 68.64194869995117, 63.47960650920868, 66.22374325990677, 65.28404608368874, 62.798622250556946, 60.02315238118172, 61.51318922638893, 61.94860406219959, 61.97789289057255, 58.322245851159096, 53.8585189729929, 55.38082368671894, 58.85962441563606, 49.62830476462841, 56.2923339754343, 50.66110834479332, 45.953780338168144, 39.03189696371555, 38.67008417844772, 2.065286790020764, 0.8771701657678932, 0.6463887181598693, 3.8279839418828487, 1.9246731977909803, 0.23833811399526894, 0.15436901740031317, 0.27737751603126526, 0.039411006509908475, 0.33538630174007267, 0.05939769653195981, 0.19908513670088723, 0.13098223716951907, 0.6833610311150551, 45.441902205348015, 50.365731194615364, 24.84341651201248, 48.38026933372021, 40.292494520545006, 48.80046598613262, 13.602803628891706, 0.329934959881939, 0.07536839912063442, 0.020261859826860018, 0.1714589714538306, 0.060239150989218615, 0.05230984854279086, 0.03609458603023086, 0.05255860531178769, 0.03054011718631955, 0.03775779463467188, 0.06350718715111725, 0.019737734728551004, 0.07134560990380123, 0.06189038133015856, 0.07376122637651861, 0.057453399494988844, 0.009806762591324514, 0.045394371772999875, 0.032751169928815216, 0.06350706098601222, 0.04197483358439058, 0.00800674091806286, 0.05062636817456223, 0.04461425211047754, 0.05076448185718618, 0.04553524253424257, 0.08266710239695385, 43.92310470342636, 64.94998320937157, 54.040430411696434, 51.87965735793114, 52.02136695384979, 109.75549176335335, 15.378075018525124, 0.3064500231994316, 0.07618093950441107, 0.1586769026471302, 0.06532054336275905, 0.1345486129866913, 0.12147663161158562, 0.06375868615577929, 0.18265983526362106, 0.6612203316763043, 0.3050140861887485, 0.47462392249144614, 9.431652501225471, 56.22517257928848, 101.90141201019287, 97.88259565830231, 97.07165077328682, 93.15553531050682, 92.7127830684185, 81.71884059906006, 78.25249180197716, 75.80416917800903, 77.45875999331474, 81.3876123726368, 90.3082948923111, 89.60648015141487, 89.26743194460869, 86.81643426418304, 81.30948856472969, 75.23828074336052, 72.26894527673721, 70.12563228607178, 74.02845606207848, 75.13162806630135, 81.30354568362236, 76.90709039568901, 78.32414835691452, 77.70175695419312, 76.40592768788338, 74.71134021878242, 75.64123392105103, 72.6595339179039, 71.56060248613358, 73.36928263306618, 76.19135320186615, 82.68356323242188, 78.90162616968155, 78.04981827735901, 80.36900103092194, 74.51265648007393, 75.02103120088577, 76.45179882645607, 79.74525690078735, 74.82697561383247, 74.4165900349617, 77.62829169631004, 77.88470193743706, 79.83484089374542, 71.3392947614193, 71.0793887078762, 79.65835556387901, 75.07110491394997, 74.88759756088257, 77.7424755692482, 61.55796222388744, 72.14940369129181, 79.45144146680832, 74.80028584599495, 73.01210939884186, 68.93718525767326, 66.26959919929504, 70.86650133132935, 75.26292622089386, 59.69736546278, 71.03365436196327, 71.7867511510849, 66.7211289703846, 67.78654620051384, 66.37043058872223, 66.87461793422699, 69.11702960729599, 69.81061398983002, 70.27368754148483, 70.6717237830162, 69.33854252099991, 65.01983106136322, 69.45209562778473, 72.21437260508537, 70.55095106363297, 67.40007653832436, 71.73262685537338, 70.64596116542816, 70.3720186650753, 68.55548053979874, 68.81449744105339, 68.90563935041428, 70.32409563660622, 64.5157653093338, 66.34899973869324, 65.80420777201653, 69.61566925048828, 71.04118555784225, 61.952335461974144, 69.90505412220955, 67.42766305804253, 69.65612947940826, 68.83278205990791, 66.61666497588158, 65.54441571235657, 65.21364346146584, 67.91087552905083, 68.90786603093147, 65.46570673584938, 59.29318115115166, 56.98208436369896, 61.40373229980469, 54.54122833907604, 61.71743206679821, 63.96762952208519, 64.86021682620049, 49.5046404004097, 55.22707253694534, 4.212193200364709, 0.8950105053372681, 0.6736044608987868, 4.290646640583873, 2.251784820109606, 0.6883529538754374, 0.16134686797158793, 0.08600802859291434, 0.1572593708988279, 0.241925819136668, 0.2321516303345561, 0.2435032688663341, 0.07820456099580042, 0.9813619998749346, 51.53465487062931, 54.501664862036705, 26.67270105332136, 50.09214207530022, 47.639765068888664, 57.004898339509964, 17.992549426853657, 0.3805529937380925, 0.0807429212727584, 0.09990234670112841, 0.07134216633858159, 0.052108054878772236, 0.022019399111741222, 0.019053381802223157, 0.04976242293196265, 0.02529900350054959, 0.020652246203098912, 0.06686124936095439, 0.06878223925014026, 0.06800965609727427, 0.12319359768298455, 0.18601230927743018, 0.20755157223902643, 0.051666432482306845, 0.12039832814480178, 0.14239936281228438, 0.18675209692446515, 0.23364757740637287, 0.10620890985592268, 0.07526870642323047, 0.1804023259319365, 0.09236523590516299, 0.27638253348413855, 0.20922303723637015, 53.64194959402084, 81.80113658308983, 53.338980451226234, 84.08359810709953, 74.55856561660767, 113.82580295205116, 21.86879362910986, 0.6088327208999544, 0.346236708573997, 0.2747359749628231, 0.21513808780582622, 0.8223536540754139, 0.612847680458799, 0.29831869702320546, 0.33916650514584035, 1.2091764598153532, 0.7999461377039552, 1.3081628107465804, 10.482134632766247, 57.11362950503826, 109.9495093524456, 100.6370298564434, 101.6335491836071, 95.48540309071541, 96.1521989107132, 84.55150499939919, 81.8722839653492, 78.79488229751587, 82.5672134757042, 85.74697405099869, 94.62043270468712, 95.11441379785538, 93.78263086080551, 88.70665803551674, 87.33186900615692, 80.04240095615387, 76.07344552874565, 73.37334081530571, 75.54511427879333, 77.50362038612366, 84.22693401575089, 80.1450714468956, 83.20871785283089, 82.62433961033821, 79.69862580299377, 78.69299456477165, 79.15577173233032, 77.0278251171112, 81.21820986270905, 77.93287575244904, 81.44041433930397, 87.58115842938423, 82.5281135737896, 82.15853780508041, 84.68238517642021, 79.09947395324707, 81.19334399700165, 80.67893519997597, 83.53380560874939, 79.80767995119095, 75.8397276699543, 80.0363440811634, 81.60981684923172, 80.79668328166008, 77.37552165985107, 74.69951525330544, 81.51617467403412, 80.70412784814835, 76.76433205604553, 84.02959540486336, 68.16112250089645, 72.6245453953743, 85.05312368273735, 79.57596838474274, 76.23391851782799, 72.60376811027527, 68.29981505870819, 74.86251130700111, 77.49830827116966, 62.58375898003578, 75.44950380921364, 71.90117061138153, 68.25778931379318, 70.52540123462677, 71.02358490228653, 72.26235643029213, 72.75313049554825, 73.19346606731415, 74.35160592198372, 71.01973950862885, 71.54049396514893, 67.77137741446495, 74.28635582327843, 74.16837975382805, 71.50973841547966, 72.51464769244194, 76.06853619217873, 72.4025385081768, 72.8894291818142, 71.91481947898865, 73.4491315484047, 72.81738504767418, 74.71610516309738, 67.72753536701202, 71.55991092324257, 69.19379308819771, 72.5354477763176, 73.37781697511673, 69.7368523478508, 74.27997976541519, 73.6359903216362, 73.71706277132034, 73.80901023745537, 72.45490729808807, 69.18313086032867, 69.69643771648407, 73.19595113396645, 71.6166190803051, 70.81976383924484, 63.891580402851105, 63.0272825807333, 65.85561901330948, 57.497355714440346, 64.11868661642075, 60.82643307745457, 59.89423669874668, 49.275987669825554, 69.24081936478615, 8.084211554378271, 1.3496643025428057, 1.470754542388022, 7.838104935362935, 3.5207314789295197, 1.0677827219478786, 0.3793971729464829, 0.5002946918830276, 0.2052239447948523, 0.7852362364064902, 0.4862615402089432, 0.3580754779977724, 0.2344750869087875, 1.753605070989579, 63.42277675867081, 61.84252895414829, 37.19371519982815, 61.6917834430933, 50.94277203083038, 69.6316359937191, 23.51811032742262, 0.42445607541594654, 0.1512475888011977, 0.16116850019898266, 0.24741469882428646, 0.11374136738595553, 0.13351897214306518, 0.13377499824855477, 0.131225127261132, 0.12746237916871905, 0.1246196567080915, 0.23205809004139155, 0.06426284191547893, 0.2124584894045256], [0.022954147098062094, 0.0817320631176699, 0.046004124014871195, 0.08480286240228452, 0.02013691369938897, 0.01968065058463253, 0.05302258490701206, 0.0478657940402627, 0.016597958383499645, 0.00554020894014684, 0.04516261018579826, 0.06184109901369084, 0.06898103092680685, 0.33058757486287504, 49.19397287070751, 59.44301851093769, 32.087678387761116, 36.73602215945721, 69.73157063126564, 74.0777014195919, 1.9415883463807404, 0.04938474026857875, 0.15464715950656682, 0.11995672801276669, 0.1428139116615057, 0.07947411591885611, 0.15770182450069115, 0.14279811875894666, 0.46465382154565305, 0.10587281343759969, 1.2526558642275631, 19.54196948558092, 69.11323741078377, 93.01659196615219, 89.3699124455452, 88.34823846817017, 88.02451863884926, 84.92498695850372, 81.0739316046238, 74.33557078242302, 71.50275439023972, 74.07061100006104, 73.44831079244614, 79.42849069833755, 83.36792171001434, 84.15145486593246, 85.89948266744614, 81.280427724123, 74.93403106927872, 72.99607425928116, 66.34545832872391, 70.04573777318001, 72.9444046318531, 72.73518785834312, 78.24246793985367, 79.5394903421402, 81.21398448944092, 80.860755443573, 77.37692758440971, 72.05899894237518, 61.995854526758194, 58.93456779420376, 55.20353280007839, 62.98297315835953, 73.70589897036552, 70.53863972425461, 70.24831250309944, 72.95651078224182, 74.9259603023529, 72.76876285672188, 70.37511169910431, 75.39174690842628, 70.85118815302849, 74.27969098091125, 78.98204505443573, 74.19095054268837, 78.44061210751534, 67.32194513082504, 69.15752023458481, 76.21697142720222, 71.97012171149254, 69.93371978402138, 79.32872325181961, 58.31333912909031, 65.1678179204464, 76.42143085598946, 62.287283688783646, 66.42153784632683, 64.92087677121162, 61.22661240398884, 63.40717099606991, 61.83303326368332, 68.5435339808464, 64.9873124063015, 60.88225968182087, 67.70240351557732, 72.27728202939034, 67.28039056062698, 64.59669336676598, 63.26589077711105, 61.32394798099995, 66.153963804245, 68.27210694551468, 72.25481003522873, 67.54166454076767, 62.9232631623745, 64.73955810070038, 68.07152330875397, 69.40690085291862, 69.83708336949348, 65.43779343366623, 66.80092468857765, 69.09467160701752, 66.9083297252655, 65.3382919728756, 62.784308418631554, 66.18405818939209, 66.70361950993538, 65.83161950111389, 65.05314767360687, 67.41801157593727, 61.40265315771103, 63.51164259016514, 66.96902766823769, 66.51047587394714, 64.0285174548626, 60.881047546863556, 60.442828461527824, 58.53389449417591, 60.87364934384823, 59.56903114914894, 63.72278206050396, 60.95718026161194, 62.22918480634689, 49.177417159080505, 55.80722160637379, 56.15296885371208, 61.645532324910164, 70.53233206272125, 61.884360909461975, 62.55744159221649, 55.25693133473396, 51.532815769314766, 3.813935383222997, 0.09715099004097283, 0.6603236391674727, 1.8925645644776523, 0.18174224387621507, 0.04604442263371311, 0.1365834186435677, 0.07400451722787693, 0.17396575334714726, 0.033577388094272465, 0.04976012969564181, 0.10305075236828998, 0.30441704322583973, 17.26657748222351, 60.791839733719826, 39.762255772948265, 40.21953843533993, 26.44060380756855, 49.76960778236389, 15.180136039853096, 0.2819160756189376, 0.0744297233177349, 0.02375073130679084, 0.07485499620088376, 0.08194774607545696, 0.07878307995270006, 0.08516039946698584, 0.08000264380825683, 0.021396490446932148, 0.02360629823670024, 0.036256559760659, 0.0686543746269308, 0.06846268530352972, 0.07453842568793334, 0.09705827353172936, 0.0371144602104323, 0.03418751512072049, 0.0284793363607605, 0.030557581776520237, 0.05346809615730308, 0.022831275273347273, 0.023401767903123982, 0.02542276961321477, 0.039556140909553505, 0.05738036103139166, 0.050640294575714506, 0.8441266044974327, 59.35663774609566, 69.7237354516983, 45.87153375148773, 35.299771428108215, 71.63494169712067, 85.17799258232117, 2.7971317945048213, 0.0928745792771224, 0.14987270085839555, 0.28824579378124326, 0.09724560644826852, 0.13631189649458975, 0.07175717531936243, 0.1192610981524922, 0.28793139033950865, 0.4313550208462402, 1.8860586010850966, 26.589531116187572, 77.52282455563545, 99.04774993658066, 96.37153074145317, 95.39614588022232, 95.1295217871666, 88.35908308625221, 84.05245497822762, 78.19923385977745, 76.94182053208351, 77.37212464213371, 77.19382300972939, 84.25015076994896, 85.06247118115425, 86.11118450760841, 88.32137390971184, 83.35342928767204, 77.59921565651894, 76.4001139998436, 71.15860685706139, 74.40901324152946, 76.41771465539932, 76.18824496865273, 81.265509724617, 84.73942771553993, 84.86752644181252, 84.79263246059418, 84.16115194559097, 78.08232173323631, 67.36359849572182, 64.8644270002842, 63.16790163516998, 65.62577694654465, 78.28067108988762, 74.7083991765976, 70.69674164056778, 76.6881537437439, 78.94381150603294, 78.1213228404522, 75.84292709827423, 76.91678747534752, 71.72854587435722, 75.65442681312561, 81.22672140598297, 78.86634886264801, 80.27808710932732, 68.52949753403664, 73.37672263383865, 78.08337807655334, 73.14217641949654, 73.41824680566788, 78.19580644369125, 59.07370112836361, 69.40262988209724, 76.97042539715767, 62.48832330107689, 67.10896655917168, 65.67138969898224, 66.9546340405941, 66.01163864135742, 64.55991894006729, 68.9730553328991, 71.00231364369392, 64.08606916666031, 68.35377976298332, 75.3212758898735, 71.95486173033714, 68.2792429625988, 68.57710137963295, 63.588121086359024, 69.01407793164253, 69.5858484506607, 71.67963489890099, 71.34668916463852, 66.63853660225868, 65.50245836377144, 69.26082909107208, 72.5811593234539, 71.56117245554924, 67.48447000980377, 68.41725155711174, 71.86711683869362, 70.29993653297424, 70.0163197517395, 66.73333391547203, 70.15302881598473, 68.27020704746246, 69.02895793318748, 66.46879971027374, 70.94413116574287, 67.16744542121887, 68.12362611293793, 69.02770400047302, 68.44256579875946, 67.12426453828812, 64.72540766000748, 65.33170312643051, 64.24088805913925, 65.47710612416267, 64.56338435411453, 68.20649966597557, 67.22697302699089, 69.71881851553917, 56.337175369262695, 58.49082760512829, 61.94983519613743, 65.12197718024254, 76.22735247015953, 73.50793719291687, 77.2134755551815, 63.06159853935242, 64.16827395558357, 6.206908039748669, 0.14144083455903456, 0.7480023906100541, 2.401939700357616, 0.033754894975572824, 0.136832557618618, 0.0852594910247717, 0.1148331185686402, 0.6335161963943392, 0.08755971837672405, 0.08433942086412571, 0.013200552893977147, 0.25178300973493606, 20.25623045861721, 73.5010139644146, 25.147519893944263, 35.489540845155716, 33.61062906682491, 57.34743855893612, 20.290065743029118, 0.30878446355927736, 0.08551734281354584, 0.00966571464232402, 0.014129181872704066, 0.05233535615843721, 0.04486666395678185, 0.08210456187953241, 0.034407992352498695, 0.013691966905753361, 0.05042456708906684, 0.008336343544215197, 0.0450285263650585, 0.04639427846996114, 0.2273169538239017, 0.22936299559660256, 0.1380637806141749, 0.18767515051877126, 0.09806363130337559, 0.10835546810994856, 0.12100285195629112, 0.08906137256417423, 0.10621522553265095, 0.1965120216482319, 0.10051744611700997, 0.18073621817165986, 0.2569552743807435, 1.5218836488202214, 72.4869167804718, 77.91882410645485, 41.4883017539978, 50.01056045293808, 88.96642729640007, 93.04107785224915, 3.5430904291570187, 0.4250322195002809, 0.32484516268596053, 0.22696544299833477, 0.328094374272041, 0.4760333796730265, 0.2865205082343891, 0.2971359807997942, 1.3107357476837933, 1.036153337918222, 2.4637310346588492, 27.109402120113373, 82.47355610132217, 103.89973238110542, 100.12813836336136, 100.46958804130554, 98.77830639481544, 93.58417510986328, 87.94827193021774, 82.43502616882324, 78.3546607196331, 82.28335350751877, 79.01595443487167, 86.80897146463394, 92.51282259821892, 91.30575656890869, 91.82002857327461, 89.41307812929153, 82.57439509034157, 80.42776867747307, 75.13165086507797, 78.8349549472332, 80.28143852949142, 79.07584682106972, 85.0605408847332, 87.12374657392502, 85.5846543610096, 86.23228400945663, 85.84661230444908, 84.67690587043762, 73.91585290431976, 73.41455340385437, 69.53347206115723, 73.00421342253685, 80.8511571586132, 76.47269010543823, 76.21922850608826, 79.59324225783348, 85.61165571212769, 82.85083785653114, 78.80275547504425, 80.55750131607056, 77.92377144098282, 79.82829004526138, 85.02730026841164, 78.63526806235313, 85.70047974586487, 74.44486051797867, 75.82449048757553, 81.77158936858177, 75.45354679226875, 74.01643350720406, 86.30661562085152, 64.42368865013123, 70.2529102563858, 82.22486704587936, 65.49579352140427, 69.15323406457901, 68.96529614925385, 68.68666470050812, 66.92982137203217, 65.25724992156029, 71.9330433011055, 71.39133676886559, 66.92514762282372, 72.96674743294716, 77.9800996184349, 73.97981107234955, 72.00660735368729, 71.48377060890198, 68.49485099315643, 73.38942915201187, 75.17141193151474, 75.48785135149956, 73.96129846572876, 70.97818493843079, 68.32935467362404, 73.91643807291985, 75.21993532776833, 74.67072799801826, 70.55332213640213, 73.95998373627663, 74.67177674174309, 74.04959812760353, 71.48855835199356, 71.59874483942986, 72.93038338422775, 73.9864607155323, 74.89332005381584, 71.97053968906403, 74.12107229232788, 68.63958522677422, 72.49971449375153, 76.3668505847454, 72.00945720076561, 71.01609170436859, 68.37555259466171, 69.26814749836922, 69.04477268457413, 70.61807066202164, 69.6738213300705, 72.51691997051239, 71.67271926999092, 71.86889514327049, 59.77515488862991, 65.10158747434616, 69.08572688698769, 68.65438163280487, 80.40391355752945, 73.5040158033371, 74.6349111199379, 62.75498919188976, 73.42634797096252, 8.602528441697359, 0.22152774181449786, 0.8180742524564266, 4.421734856441617, 0.7725726440548897, 0.3184449998661876, 0.5825587932486087, 0.5470400804188102, 0.8025025692768395, 0.3420431289123371, 0.1591528716380708, 0.16077792271971703, 0.5178274854552001, 28.196521885693073, 79.46593388915062, 53.74080128967762, 52.907992377877235, 34.21939060091972, 73.57114300131798, 24.417533464729786, 0.33535536902491003, 0.1635205146158114, 0.11747647047741339, 0.12957022699993104, 0.10938135368633084, 0.1655055518494919, 0.14426288078539073, 0.22038392897229642, 0.07077331756590866, 0.1447863323846832, 0.17169395025121048, 0.1342186689726077, 0.17901260987855494], [0.006739662912877975, 0.023148957152443472, 0.05367099933209829, 0.020549252803903073, 0.06522511801449582, 0.04135636110731866, 0.012205090733914403, 0.060015764538547955, 0.0672375330759678, 0.091249120014254, 0.03364723532286007, 0.05092178005725145, 0.08162727186572738, 4.431193973869085, 62.32945762574673, 37.99692749977112, 43.810763731598854, 38.002532199025154, 76.81145712733269, 44.3250585347414, 0.37815867690369487, 0.0937891130161006, 0.24768274772213772, 0.19635159900644794, 0.047506713308393955, 0.2402258408255875, 0.16536501876544207, 0.23804797878256068, 0.3342142724432051, 0.5648179014679044, 23.900877088308334, 82.52489894628525, 94.37596902251244, 93.80417570471764, 87.16796100139618, 83.76778945326805, 81.73948869109154, 77.71925121545792, 74.31793212890625, 72.27263107895851, 70.47627747058868, 71.8709546327591, 77.89138957858086, 80.56864991784096, 86.9082373380661, 86.57241895794868, 83.27178686857224, 79.15419101715088, 76.95014968514442, 69.78263229131699, 66.1088678240776, 68.53883743286133, 72.1703177690506, 78.65321069955826, 82.0238122344017, 80.28796657919884, 76.62654384970665, 77.64381766319275, 77.27620258927345, 75.47294095158577, 70.31523451209068, 59.18638028204441, 56.385041400790215, 51.56236298382282, 62.03826405107975, 63.46255302429199, 67.09182187914848, 78.75125303864479, 72.3523736000061, 73.16571235656738, 72.22239777445793, 71.92323222756386, 72.74500653147697, 77.70821660757065, 76.52412414550781, 76.78913712501526, 66.2801930308342, 68.67045477032661, 73.59132751822472, 70.53248405456543, 71.9627197086811, 79.68283385038376, 57.84523844718933, 63.832653164863586, 76.27023696899414, 60.631792321801186, 63.409405276179314, 71.5097764134407, 68.32565367221832, 69.28406864404678, 69.33497071266174, 68.9615723490715, 64.33098122477531, 69.1689120233059, 68.5456694662571, 61.67278066277504, 60.45631393790245, 70.01701891422272, 69.60088044404984, 64.73320484161377, 64.96489360928535, 60.74577860534191, 60.47102674841881, 61.99293628334999, 69.84063237905502, 63.910609781742096, 64.90999415516853, 70.10844960808754, 68.78362789750099, 69.39947605133057, 66.43474593758583, 66.87174528837204, 65.95021113753319, 67.03243866562843, 67.02689096331596, 66.25654309988022, 62.96939268708229, 62.01594404876232, 64.08686712384224, 64.47079092264175, 66.29387229681015, 60.9869896620512, 64.0262983739376, 64.92397740483284, 64.32911932468414, 60.56661441922188, 61.575817465782166, 61.07377700507641, 59.35650855302811, 59.348969757556915, 58.591412007808685, 62.602849155664444, 64.3265126645565, 62.3031098395586, 61.808212995529175, 57.20443323254585, 66.08366757631302, 65.91525301337242, 71.08412325382233, 63.550974279642105, 69.97639909386635, 70.5383813381195, 65.77098235487938, 56.95417486131191, 4.044814556837082, 0.1687753654550761, 0.49992723972536623, 0.2165417859214358, 0.5060629604849964, 0.18929899932118133, 0.05596711147518363, 0.3622452198760584, 0.11481388210086152, 0.20801836828468367, 0.07255697302753106, 0.03129051568976138, 1.977860250044614, 51.72350473701954, 45.54845608770847, 48.48129831254482, 30.552359372377396, 45.85856884717941, 21.219682060182095, 0.09644525955081917, 0.18275239592185244, 0.020489020098466426, 0.10191743349423632, 0.03160862244840246, 0.042697878379840404, 0.043452549798530526, 0.026666171252145432, 0.03528496599756181, 0.042682285857154056, 0.07915886642877012, 0.031513223075307906, 0.05879657546756789, 0.10341817484004423, 0.04018876985355746, 0.06414613177184947, 0.06156052266305778, 0.0747930639772676, 0.013391741267696489, 0.07604325626743957, 0.05093206622404978, 0.0814899374381639, 0.012444036310625961, 0.015717548594693653, 0.07287706874194555, 0.2692140103317797, 6.949911145493388, 72.27806478738785, 47.54605829715729, 46.987484470009804, 30.028207898139954, 91.09315797686577, 49.2743119597435, 0.1225717224588152, 0.11078942305175588, 0.10693461896153167, 0.6778438459150493, 0.11589298708713613, 0.1578436786076054, 0.47562255640514195, 0.47209144744556397, 0.8866309456061572, 1.477717193774879, 29.000860825181007, 87.20577657222748, 97.36260116100311, 97.55772829055786, 92.19986379146576, 89.07454669475555, 86.59816637635231, 81.63667380809784, 77.93131023645401, 76.74777254462242, 72.12880119681358, 75.18205136060715, 79.19706791639328, 80.82293227314949, 90.17293095588684, 87.61859402060509, 85.83782717585564, 84.3665537238121, 80.97173988819122, 73.09346303343773, 68.99088397622108, 72.60707393288612, 75.11877715587616, 79.57729831337929, 84.91704538464546, 80.65875068306923, 80.41215911507607, 78.30610692501068, 79.44506540894508, 79.39428493380547, 79.78716865181923, 67.36916899681091, 64.98959988355637, 60.919858664274216, 63.46200965344906, 65.97151279449463, 72.1240970492363, 81.96792483329773, 76.45230039954185, 76.6699831187725, 77.93419048190117, 76.74905687570572, 76.90250024199486, 79.36628803610802, 80.91302543878555, 77.1266882121563, 66.62678763270378, 75.25616258382797, 75.0923989713192, 71.96791782975197, 78.53749170899391, 80.34594386816025, 58.49250331521034, 68.35638642311096, 78.33374664187431, 65.32889887690544, 65.76536625623703, 71.6773322224617, 73.06979030370712, 73.78307282924652, 71.62095844745636, 70.54775163531303, 64.17315289378166, 70.42429625988007, 73.90982642769814, 66.1745434999466, 62.961276322603226, 68.92635583877563, 72.59811401367188, 67.58150920271873, 66.44756644964218, 65.78830182552338, 63.79109859466553, 62.60601818561554, 71.12456828355789, 68.21888700127602, 67.19750180840492, 70.61685472726822, 71.60154908895493, 69.41303372383118, 70.60041680932045, 67.5883412361145, 67.43736773729324, 70.59966444969177, 69.50602993369102, 68.35269302129745, 67.36586317420006, 65.75566157698631, 66.71257182955742, 67.4894705414772, 69.01983842253685, 63.77345994114876, 66.9932171702385, 69.04300197958946, 67.05681815743446, 62.778718918561935, 66.02467954158783, 64.35170531272888, 63.09414379298687, 63.178202882409096, 63.52570943534374, 66.61512985825539, 69.25170958042145, 66.6807371377945, 66.98640793561935, 60.41385881602764, 69.1804938018322, 70.25062277913094, 73.75178530812263, 70.78475251793861, 77.93359011411667, 80.87315037846565, 73.543890863657, 68.75238597393036, 5.910234684124589, 0.15237652900395915, 0.5614251585211605, 0.2752504911040887, 0.9758875623811036, 0.3183786221779883, 0.024384922471654136, 0.5097626557108015, 0.13971912616398185, 0.29825217090547085, 0.03558863798389211, 0.058365677105030045, 2.548111444339156, 62.13053449988365, 42.54988119006157, 40.74871703982353, 38.2638593763113, 54.031614884734154, 27.671540156006813, 0.13148421101504937, 0.2295001593302004, 0.08782280230661854, 0.08507537160767242, 0.039166138594737276, 0.03877750183164608, 0.012487862913985737, 0.02438748659187695, 0.024117188986565452, 0.04893626413831953, 0.12846018187701702, 0.039911818894324824, 0.07253313524415717, 0.16126776987221092, 0.14851749467197806, 0.1644595540710725, 0.13277707679662853, 0.22689517645630985, 0.0871053829905577, 0.23259245121153072, 0.15371132612926885, 0.22344009310472757, 0.30175691877957433, 0.08287607633974403, 0.11755920510040596, 0.5173124943394214, 9.836877956986427, 87.92170375585556, 51.56253397464752, 53.259693905711174, 55.41825167834759, 102.54347115755081, 56.56065657734871, 0.30825602472759783, 0.1827188953757286, 0.4792794742388651, 1.8530396791175008, 0.1900395588018, 0.6622753688134253, 0.7571964722592384, 1.7201928701251745, 1.8517691222950816, 1.798522223252803, 31.887687519192696, 93.66484478116035, 101.16243526339531, 105.14906734228134, 98.76813814043999, 94.74216297268867, 90.1129549741745, 86.75724104046822, 81.38716399669647, 79.69640672206879, 74.78010892868042, 79.11811575293541, 85.53679212927818, 85.73805212974548, 92.65545174479485, 91.58924415707588, 89.6173931658268, 85.19735634326935, 83.5243821144104, 76.90488651394844, 72.49836936593056, 75.85426568984985, 78.6024834215641, 84.36863601207733, 87.7713306248188, 82.93102115392685, 81.81010410189629, 82.26003035902977, 83.6272805929184, 82.95045331120491, 80.44827237725258, 74.58664610981941, 72.86603763699532, 69.84931871294975, 73.91094356775284, 72.11006060242653, 79.10941421985626, 87.06959947943687, 82.88461804389954, 80.58968558907509, 79.3729680776596, 77.96859383583069, 76.89741611480713, 82.62212812900543, 81.78194761276245, 82.47346490621567, 71.8350313603878, 77.349394261837, 78.99991169571877, 74.58917677402496, 79.45445850491524, 86.26813888549805, 64.21840086579323, 70.65030813217163, 83.33462029695511, 66.56551212072372, 65.51378935575485, 75.75304672122002, 75.2497561275959, 76.23922303318977, 73.81447434425354, 74.27425727248192, 67.4983848631382, 73.39360132813454, 74.91543486714363, 68.97294133901596, 67.8473125398159, 74.94793072342873, 74.54983368515968, 71.74424663186073, 69.9116961658001, 66.43518671393394, 66.06459259986877, 67.63175010681152, 75.06301134824753, 68.9680927991867, 70.2693709731102, 74.62301775813103, 74.58782404661179, 72.37720906734467, 71.9225786626339, 70.90176343917847, 71.66217863559723, 75.14260947704315, 73.16197335720062, 73.13493400812149, 71.12845927476883, 69.32938501238823, 69.01540026068687, 73.47915753722191, 71.36960193514824, 67.20602095127106, 72.99514710903168, 71.67658746242523, 72.54303216934204, 67.12952345609665, 69.74306121468544, 70.17601758241653, 65.48415094614029, 68.33187773823738, 65.34406766295433, 71.94271758198738, 72.68344983458519, 70.45388907194138, 69.64553564786911, 64.7362294793129, 72.15109840035439, 72.20690220594406, 76.5720547735691, 72.97402784228325, 79.07161384820938, 80.47160312533379, 73.95040825009346, 75.82603320479393, 7.588409883901477, 0.3250426036538556, 1.5213091671466827, 1.51476128725335, 1.33386617526412, 0.8182329533156008, 0.11161526272189803, 1.116569135338068, 0.29226752172689885, 0.5446402716916054, 0.28195466729812324, 0.1741340130683966, 5.1192007306963205, 70.41233450174332, 60.343733578920364, 65.87383523583412, 37.75478549301624, 65.49681946635246, 33.59364777803421, 0.1849640702130273, 0.3302502539008856, 0.12656194623559713, 0.19959151890361682, 0.14109149080468342, 0.1782862699474208, 0.11985427452600561, 0.10758976466604508, 0.12830741819925606, 0.08725643972866237, 0.2553421718766913, 0.17786421056371182, 0.18806099309585989], [0.022776781224820297, 0.030455866726697423, 0.017785435484256595, 0.09156668500509113, 0.035844652957166545, 0.05178314262593631, 0.07298885102500208, 0.03227182416594587, 0.027496035218064208, 0.1083837662008591, 0.0947049974638503, 0.08782922188402154, 0.2139361054287292, 20.081531032919884, 62.41998016834259, 33.34998965263367, 42.4008683860302, 36.542323753237724, 79.79231357574463, 15.174230206757784, 0.3955132362898439, 0.06905244779773057, 0.052080294844927266, 0.5256275762803853, 0.26509544695727527, 0.0815211002191063, 0.26574761664960533, 1.9091893848963082, 2.2471944289281964, 10.771398860961199, 64.23075780272484, 90.4176378250122, 91.67876735329628, 87.39113822579384, 81.06247901916504, 80.16406282782555, 79.09614533185959, 72.550890147686, 68.85919824242592, 67.03534170985222, 68.7540502846241, 71.2786728143692, 70.7826018333435, 74.85373377799988, 83.06352764368057, 82.56060943007469, 86.3967315852642, 82.63488784432411, 75.34102723002434, 68.69392231106758, 68.02031725645065, 64.1610923409462, 68.04928690195084, 73.81466433405876, 77.66473934054375, 76.78940311074257, 74.9726901948452, 71.32785737514496, 65.5882577598095, 64.97297957539558, 68.42429637908936, 66.4932855963707, 56.9467006623745, 57.26078420877457, 51.83788999915123, 64.28229063749313, 70.94703420996666, 70.08881226181984, 76.5506999194622, 73.01847025752068, 74.98500153422356, 78.65492060780525, 77.3764868080616, 75.8750581741333, 74.8247717320919, 63.497343957424164, 71.95057556033134, 75.6478987634182, 69.96142029762268, 78.15136402845383, 74.17980194091797, 57.09961585700512, 60.57635709643364, 73.0202941596508, 68.72741371393204, 69.58685159683228, 69.14603725075722, 67.58594736456871, 65.81062942743301, 65.50785407423973, 64.54807877540588, 65.74541732668877, 63.894848227500916, 64.10718083381653, 66.23486906290054, 67.01686710119247, 63.422894552350044, 55.81001065671444, 67.6694592833519, 68.48741099238396, 65.51703438162804, 68.4190982580185, 66.44899517297745, 59.30820554494858, 60.844482108950615, 65.403473675251, 65.5391263961792, 67.47184708714485, 67.26337507367134, 67.48229652643204, 63.164276629686356, 67.97063112258911, 64.85363557934761, 67.22432076931, 63.487878665328026, 66.75018221139908, 65.90538874268532, 62.37861558794975, 61.5079341083765, 62.995558083057404, 63.30833449959755, 59.45495367050171, 65.28818786144257, 64.04611051082611, 63.19257751107216, 60.314570143818855, 60.5366226285696, 58.15373629331589, 60.91776877641678, 57.77948297560215, 59.1401481628418, 58.035414442420006, 64.01455700397491, 63.543899059295654, 64.61542636156082, 60.59229724109173, 66.78272366523743, 69.47482600808144, 70.7850033044815, 71.53451308608055, 69.86173644661903, 71.76552549004555, 74.35595288872719, 64.47818532586098, 45.12879140675068, 1.8401482771150768, 0.116227562102722, 0.251604508375749, 0.09991917118895799, 0.24075622408417985, 0.2952349843690172, 0.5703054601326585, 0.2569875429617241, 0.22401548019843176, 0.09627199775422923, 0.10540066650719382, 0.5665087513625622, 30.337119922041893, 44.50493708252907, 31.79687239229679, 41.59030728042126, 47.4106677621603, 24.32426366955042, 0.029841247851436492, 0.06019142718287185, 0.018535080707806628, 0.05767235532402992, 0.023602990113431588, 0.07820413797162473, 0.04221609095111489, 0.11793525874963962, 0.018834787770174444, 0.020289343410695437, 0.04737485221994575, 0.04582674700941425, 0.017363147890137043, 0.04741609707707539, 0.020931822509737685, 0.026906382190645672, 0.07756297432933934, 0.0416182613116689, 0.06886568633490242, 0.03203261883754749, 0.028430757229216397, 0.03784741638810374, 0.057847869538818486, 0.055583072316949256, 0.2078186415019445, 0.34160944749601185, 24.918724671006203, 71.72470048069954, 41.07786297798157, 37.043201476335526, 31.935048177838326, 93.50354343652725, 18.561226911842823, 0.28754921397194266, 0.0511474931408884, 0.5081089131999761, 0.16747893736464903, 0.21047867689048871, 0.0080012434591481, 0.23503724893089384, 3.547712406143546, 3.8556355331093073, 14.518779627978802, 68.40564697980881, 94.98842015862465, 96.36396154761314, 91.05899021029472, 87.5227403640747, 85.87159216403961, 82.41853505373001, 75.11569172143936, 73.95834222435951, 71.03295519948006, 73.23967158794403, 74.70513135194778, 74.50452491641045, 78.61085057258606, 85.80757319927216, 85.34224256873131, 87.81448110938072, 88.01953330636024, 79.41408187150955, 72.27377101778984, 69.80599343776703, 68.50961700081825, 72.14238166809082, 77.04260632395744, 79.07246500253677, 82.00215339660645, 77.62351155281067, 73.74625280499458, 67.62035831809044, 68.58638808131218, 71.1331482231617, 75.36396279931068, 64.73533272743225, 70.66317424178123, 63.522711396217346, 68.04911971092224, 74.48216691613197, 75.1183819770813, 79.74386617541313, 78.86958628892899, 79.71439495682716, 81.47930905222893, 79.70554903149605, 78.71046602725983, 76.49374857544899, 66.38854801654816, 76.54448345303535, 75.68670228123665, 73.5937973856926, 81.22928246855736, 73.68175506591797, 59.11108732223511, 64.91222083568573, 73.74440610408783, 72.12462142109871, 72.23222404718399, 72.48756274580956, 67.47690841555595, 66.76885440945625, 67.50228345394135, 67.08611458539963, 69.46483254432678, 67.86828741431236, 67.47131511569023, 68.37584897875786, 69.7639524936676, 69.55636203289032, 57.893716245889664, 66.08282402157784, 70.19754722714424, 68.92650783061981, 69.69058603048325, 67.90234118700027, 63.833473920822144, 63.4077637642622, 66.57477602362633, 69.40084397792816, 68.68226453661919, 71.21970757842064, 69.33808654546738, 65.97922638058662, 70.56320160627365, 67.95341044664383, 68.24135899543762, 68.38296219706535, 67.52423867583275, 68.47237139940262, 66.34059458971024, 64.75177064538002, 64.04289588332176, 66.981301009655, 62.202388644218445, 68.03952902555466, 67.42784544825554, 68.05403664708138, 64.54036518931389, 61.83912053704262, 63.65175247192383, 62.96653524041176, 63.89241635799408, 63.745767027139664, 62.167616710066795, 67.25400477647781, 66.9536080956459, 67.85719960927963, 65.22417649626732, 69.9628946185112, 73.49026814103127, 73.58564302325249, 73.54072943329811, 75.60749173164368, 77.5206358730793, 81.96542456746101, 74.02259677648544, 57.45990492403507, 2.6748545933514833, 0.12799522635759786, 0.28332024870906025, 0.13264530105516315, 0.1821640954585746, 0.26468233787454665, 0.7073126302566379, 0.3436644247267395, 0.18459479237208143, 0.23472066357498989, 0.07560288067907095, 0.5199689674191177, 35.50936438143253, 51.745539754629135, 29.54476173967123, 46.43364518880844, 52.44081884622574, 33.32466021180153, 0.06918900297023356, 0.04564120637951419, 0.019844129019475076, 0.012516504248196725, 0.0073298136430821614, 0.05210008421272505, 0.05103762188809924, 0.07455084181856364, 0.0257023551966995, 0.021032730473962147, 0.04732873887405731, 0.06319640539004467, 0.024461565917590633, 0.10229802908725105, 0.16440034552942961, 0.23363617801805958, 0.19168461818480864, 0.115440774243325, 0.21506652992684394, 0.12307913624681532, 0.09217770260875113, 0.10254189881379716, 0.18311492021894082, 0.21775194676592946, 0.3760118514765054, 0.5323139706160873, 28.52449558675289, 85.28243377804756, 45.986245796084404, 58.82164925336838, 50.974382534623146, 105.53049087524414, 22.713873982429504, 0.41586853621993214, 0.3318921517347917, 0.5921982822474092, 1.7052468471229076, 0.6692783336620778, 0.2141975492122583, 0.6761322158854455, 6.2045882642269135, 5.822403347119689, 17.677742019295692, 73.3934037387371, 96.99953064322472, 101.12119227647781, 96.47715747356415, 91.37789189815521, 92.14314043521881, 87.02952682971954, 79.86610561609268, 77.11493164300919, 75.35929664969444, 77.8544707596302, 78.7115603685379, 78.35922807455063, 83.75540971755981, 90.03619149327278, 89.12018984556198, 91.4585691690445, 91.5439809858799, 84.10116076469421, 75.89943006634712, 75.24527236819267, 71.72479927539825, 73.80238339304924, 80.77355772256851, 81.85353577136993, 83.68850290775299, 80.09397178888321, 75.27907535433769, 70.80258876085281, 70.66603928804398, 75.48112571239471, 75.79815030097961, 69.46413338184357, 73.22444200515747, 71.47686257958412, 75.15048265457153, 80.47012880444527, 80.70868760347366, 84.66220825910568, 81.85358136892319, 80.97734838724136, 85.8486869931221, 83.46233904361725, 81.08951076865196, 81.72498866915703, 68.55902194976807, 77.79748141765594, 81.88851669430733, 74.2311903834343, 84.62753131985664, 80.6075294315815, 63.4491815418005, 64.94868367910385, 79.06934916973114, 73.8615994155407, 73.20472866296768, 77.32154175639153, 73.6937928199768, 71.61390602588654, 71.84065505862236, 69.72430542111397, 72.26390674710274, 69.4631378352642, 69.03194457292557, 70.04775926470757, 71.9270396232605, 69.16149482131004, 61.954641938209534, 73.09391140937805, 71.24873042106628, 71.57737478613853, 73.38600933551788, 72.6379206776619, 64.96968895196915, 66.64861366152763, 69.22737568616867, 72.29552865028381, 72.12329149246216, 73.1238842010498, 71.57707080245018, 68.89027297496796, 75.17708122730255, 71.40272095799446, 74.79258745908737, 69.82781186699867, 72.67424672842026, 72.11443036794662, 69.45672377943993, 67.63064056634903, 70.1946821808815, 67.67241552472115, 67.64378786087036, 71.24395027756691, 69.99199345707893, 72.55936369299889, 66.73316672444344, 66.98647633194923, 66.81575909256935, 68.42672064900398, 66.95243775844574, 66.97918072342873, 68.0688026547432, 73.0867449939251, 72.00501143932343, 71.95594847202301, 68.54902848601341, 73.58101487159729, 78.17781820893288, 78.94690454006195, 78.12895283102989, 77.10680767893791, 77.96882942318916, 81.92831575870514, 76.63510859012604, 69.10029530525208, 3.236519079655409, 0.15293549979105592, 0.6484354427084327, 0.29866364726331085, 0.3436746069928631, 0.7441082526929677, 1.5123858209699392, 0.6951427739113569, 0.501883541001007, 0.3705934016034007, 0.25581708701793104, 1.2635307619348168, 46.22847519814968, 55.779540091753006, 46.56322963535786, 52.75242492556572, 59.81677405536175, 40.8126600086689, 0.22933657513931394, 0.16830947482958436, 0.11140931674162857, 0.1492396043613553, 0.09548795584123582, 0.22548227570950985, 0.166715920495335, 0.21381028171163052, 0.10983488755300641, 0.08635396588942967, 0.12355761369690299, 0.13937073235865682, 0.16567520680837333], [0.03780522529268637, 0.019095185125479475, 0.0335333601833554, 0.09226204769220203, 0.02437021496007219, 0.03760182858968619, 0.022391814381990116, 0.11554608499864116, 0.049753149796742946, 0.020800388156203553, 0.0869953002256807, 0.10524223282118328, 0.03902548676705919, 38.43923516571522, 57.96079024672508, 40.20726129412651, 39.2452023178339, 38.507927879691124, 70.0178624689579, 2.1486381674185395, 0.02276297913340386, 0.07258131547132507, 0.3995342517737299, 0.31988402421120554, 0.09458319618715905, 1.0113140707835555, 0.05069010381703265, 0.43855085503309965, 1.4605761948041618, 36.11162066459656, 93.00307989120483, 94.84927922487259, 90.39869964122772, 83.6596928536892, 77.65498146414757, 76.89796328544617, 73.74325096607208, 70.74432268738747, 69.67601761221886, 66.1615177989006, 73.420070707798, 76.42323955893517, 78.6054852604866, 80.09213268756866, 84.08029228448868, 81.71831622719765, 83.04822206497192, 81.45590230822563, 75.63927322626114, 72.07031473517418, 64.1481502354145, 64.28640961647034, 67.72064253687859, 73.21159109473228, 76.53196692466736, 77.66017958521843, 77.62502387166023, 78.2772208750248, 71.07699483633041, 62.612128257751465, 62.71461635828018, 66.02331161499023, 62.409796714782715, 59.51754771173, 66.90436273813248, 70.84635481238365, 71.47965922951698, 73.1488336622715, 74.74320530891418, 75.76371654868126, 78.95649522542953, 71.83585971593857, 77.7364718914032, 75.45825093984604, 61.713662669062614, 72.88555338978767, 75.3267551958561, 66.97982668876648, 76.45401790738106, 70.16405582427979, 56.19638532400131, 66.17503747344017, 73.37842494249344, 66.35298192501068, 68.12410488724709, 66.86254978179932, 62.977687641978264, 62.722379341721535, 64.56520065665245, 66.38261273503304, 69.44825023412704, 66.9451193511486, 68.23447376489639, 66.45404890179634, 65.43657749891281, 61.26198470592499, 68.51492911577225, 65.72568118572235, 54.329062923789024, 61.94315515458584, 68.76235663890839, 66.01425290107727, 62.8984846919775, 66.80771872401237, 64.20032903552055, 60.64048245549202, 62.450640723109245, 65.371745377779, 66.90658181905746, 67.12172627449036, 63.072462156414986, 65.38418591022491, 66.41386985778809, 62.84243009984493, 65.87233051657677, 64.5080517232418, 63.805150240659714, 62.03250735998154, 63.9034129679203, 62.71060757339001, 59.35970038175583, 61.5082760900259, 66.80677637457848, 62.90675304830074, 64.43745911121368, 61.244292855262756, 59.198516830801964, 57.66249865293503, 58.726255372166634, 58.26798476278782, 59.27884452044964, 60.514131635427475, 60.68974681198597, 63.91801938414574, 65.92322498559952, 64.7953163087368, 67.49591499567032, 72.94212475419044, 69.78019282221794, 69.04624700546265, 70.14596119523048, 74.29253429174423, 75.52161633968353, 74.49444025754929, 59.75405842065811, 27.486718073487282, 0.03580193493689876, 0.09260802951757796, 0.3777618653839454, 0.36025938112288713, 0.008023160935408669, 0.18390688084764406, 0.2902674040524289, 0.0619111985724885, 0.011313565428281436, 0.0432261687819846, 0.13001726707443595, 11.624847315251827, 56.318677961826324, 46.0672764480114, 31.35643992573023, 41.1381733417511, 35.53281672298908, 0.045857097138650715, 0.08518439310137182, 0.022868195264891256, 0.022061738636693917, 0.019685943952936213, 0.015247655937855598, 0.011969508941547247, 0.017329868132947013, 0.027318815918988548, 0.020682891336036846, 0.0342837642529048, 0.0540065614040941, 0.008707173401489854, 0.04208441539958585, 0.05387291545048356, 0.05617466420517303, 0.041100431481027044, 0.037220468584564514, 0.04023273468192201, 0.033490345304016955, 0.047054155365913175, 0.013546410409617238, 0.014483266095339786, 0.028600937257579062, 0.04959911704645492, 0.040077677767840214, 44.812929555773735, 64.75154265761375, 57.55508601665497, 34.373609125614166, 41.329249888658524, 82.0766294002533, 2.8180743707343936, 0.03462635075266007, 0.15687030740082264, 0.2589356212411076, 0.31181014026515186, 0.028382269010762684, 1.028336682356894, 0.06017949715896975, 0.5284093238878995, 2.449358543381095, 40.61315931379795, 94.70191553235054, 99.63571518659592, 93.97278025746346, 86.71764716506004, 82.1510674059391, 81.72349914908409, 76.0565896332264, 75.97327530384064, 70.86900159716606, 70.00086978077888, 76.09489917755127, 79.08236727118492, 81.55752405524254, 83.10198917984962, 86.60568237304688, 84.84079107642174, 82.9915215075016, 83.37843954563141, 77.29782342910767, 74.33995574712753, 68.82638320326805, 67.31690660119057, 68.48871812224388, 74.70965310931206, 78.84123221039772, 82.08055838942528, 79.09340187907219, 79.94420662522316, 76.88688308000565, 66.46809294819832, 64.4281268119812, 71.16617605090141, 65.64874291419983, 64.83351185917854, 75.4517912864685, 79.93422076106071, 74.77190136909485, 76.1127582192421, 78.97667974233627, 78.81495282053947, 80.57806581258774, 75.30527114868164, 79.93276923894882, 76.40588209033012, 65.54486408829689, 79.7456368803978, 77.00345322489738, 70.47247767448425, 79.61128368973732, 69.6083128452301, 59.483368545770645, 73.800118714571, 73.28738942742348, 70.18873170018196, 70.36634936928749, 69.30882051587105, 66.71302020549774, 67.95011222362518, 69.61925625801086, 70.82767501473427, 72.09549978375435, 69.470334649086, 68.92712339758873, 68.77007022500038, 68.60463470220566, 62.761365249753, 68.78359749913216, 70.91089054942131, 60.15153609216213, 61.95091813802719, 71.46427765488625, 68.79558965563774, 64.65432107448578, 70.47516033053398, 68.31980958580971, 64.28151547908783, 65.83503171801567, 67.76557132601738, 68.36763381958008, 68.59293892979622, 63.68072971701622, 65.69443166255951, 69.64659199118614, 66.14000335335732, 67.83200696110725, 66.60983294248581, 65.59513539075851, 66.56331583857536, 66.2157940864563, 66.89609438180923, 64.67445239424706, 63.20083066821098, 67.37942084670067, 66.63530677556992, 67.86663070321083, 64.86568093299866, 64.89730283617973, 61.282081827521324, 62.39487111568451, 62.59725205600262, 62.4968234449625, 65.04574567079544, 64.59341034293175, 69.71722260117531, 69.59952011704445, 70.27418151497841, 71.61003783345222, 75.66611498594284, 72.38310635089874, 72.39534929394722, 72.79096886515617, 79.64367315173149, 79.3913970887661, 81.53401091694832, 69.83358755707741, 37.060334756970406, 0.16589831124292687, 0.056782230822136626, 0.24187153845559806, 0.38810606813058257, 0.09776769249583595, 0.45214857382234186, 0.15843999426579103, 0.08705236396053806, 0.0656942740897648, 0.17559978441568092, 0.1715994006372057, 13.102059848606586, 71.23290807008743, 37.85671882331371, 33.58984798192978, 51.42730303108692, 43.65481249988079, 0.1716402781312354, 0.05054529967310373, 0.014448956608248409, 0.03278223994129803, 0.017785962409107015, 0.030440752889262512, 0.025826561031863093, 0.01535187016997952, 0.049317071243422106, 0.01678195534623228, 0.05211658215557691, 0.11670874839182943, 0.053980437805876136, 0.10077666345750913, 0.182042813685257, 0.14659680164186284, 0.1962845236994326, 0.17164864955702797, 0.18647221819264814, 0.11472236787085421, 0.15204517490928993, 0.15308937669033185, 0.12337092644884251, 0.16997430502669886, 0.21737171482527629, 0.09656282316427678, 51.47539705038071, 76.5807943046093, 52.91238874197006, 53.76231953501701, 54.00555208325386, 92.66284614801407, 4.619403099641204, 0.13289196125697345, 0.21104925486724824, 0.895998333580792, 1.1559078306891024, 0.49475221429020166, 1.9696776266209781, 0.17244035785552114, 1.00800622953102, 3.8029019627720118, 44.21347752213478, 99.37867417931557, 106.05565309524536, 99.71691682934761, 92.80208587646484, 86.7597109079361, 87.14428827166557, 81.87244355678558, 80.25992408394814, 75.32146587967873, 72.63041988015175, 82.19695374369621, 83.3580270409584, 86.17146447300911, 87.5343905389309, 90.70426404476166, 85.82815289497375, 86.58667579293251, 88.42514634132385, 81.92492634057999, 79.17757496237755, 72.08095416426659, 72.07549765706062, 73.95337969064713, 80.08330196142197, 81.4827212691307, 85.83040997385979, 83.27794253826141, 85.24895757436752, 78.45930710434914, 66.59635126590729, 69.66554537415504, 74.83664989471436, 68.96024242043495, 69.55209866166115, 77.54569172859192, 83.05181667208672, 81.06019914150238, 81.89965009689331, 81.88834950327873, 83.66837158799171, 85.93703225255013, 76.75879195332527, 82.1307384967804, 81.97790309786797, 68.75475704669952, 78.54500010609627, 80.70130839943886, 71.44240602850914, 82.42003217339516, 76.84291183948517, 62.32041411101818, 75.41666597127914, 78.90040263533592, 71.1864897608757, 73.37441995739937, 74.49928879737854, 70.69379299879074, 70.15080213546753, 70.9043700993061, 72.65107557177544, 73.85398462414742, 73.094382584095, 74.13415879011154, 73.30654799938202, 69.44207936525345, 67.52086445689201, 72.67957404255867, 70.91844454407692, 62.18733385205269, 69.34621050953865, 73.13057944178581, 70.17520442605019, 68.04063856601715, 73.77108067274094, 70.8708406984806, 66.50590851902962, 69.64882627129555, 70.0213734805584, 70.92662930488586, 70.40195345878601, 64.97713655233383, 68.1501866877079, 72.04721197485924, 71.02600157260895, 70.9893487393856, 70.96826747059822, 70.0143438577652, 68.83154332637787, 70.29253453016281, 68.48833054304123, 64.13964629173279, 69.49188709259033, 71.2653811275959, 70.53765937685966, 71.79403156042099, 68.67820635437965, 68.72571140527725, 65.94671532511711, 67.03447535634041, 67.91303381323814, 66.45198941230774, 68.74096378684044, 67.99282193183899, 73.63514676690102, 73.29112082719803, 74.44793835282326, 73.5766451060772, 78.27275231480598, 74.67235431075096, 75.04224926233292, 75.87175995111465, 81.69425591826439, 82.63577699661255, 83.41991052031517, 77.73728504776955, 45.61952747404575, 0.2602329250657931, 0.16952370264334604, 0.6586820678785443, 1.2522581918165088, 0.3628820716403425, 0.939997835084796, 0.662935939617455, 0.20973645499907434, 0.6995799858123064, 0.2850247244350612, 0.3450869437074289, 19.723527543246746, 77.8364597260952, 60.13952113687992, 44.30254094302654, 54.13265146315098, 55.420368164777756, 0.16468101093778387, 0.19908332586055622, 0.1312346861232072, 0.10179253746173345, 0.1089875701291021, 0.15560406987788156, 0.08634881538455375, 0.11924631457077339, 0.13050122157437727, 0.14755961950868368, 0.11680309020448476, 0.2286341175204143, 0.1604904592386447], [0.0453319757070858, 0.04259081986674573, 0.09963829797925428, 0.05308977153617889, 0.04598293198796455, 0.0634084444027394, 0.08266683522379026, 0.13609092944534495, 0.02605604979180498, 0.10067739378428087, 0.04777041693159845, 0.07992841419763863, 1.4287183480337262, 58.827888518571854, 46.941590532660484, 33.793900832533836, 27.869978807866573, 49.757152050733566, 42.87513993680477, 0.23406413005432114, 0.006799530574426171, 0.10686967361834832, 0.36948026914615184, 0.17957117990590632, 0.486727905808948, 0.18230661749839783, 0.010939480325760087, 0.27614762890152633, 7.301735691726208, 74.6176828444004, 92.9578623175621, 90.4641929268837, 84.90810066461563, 80.29232114553452, 73.26600417494774, 71.85442551970482, 71.3447816669941, 69.6105395257473, 64.30878281593323, 70.13570174574852, 79.02023300528526, 81.62822306156158, 81.30422204732895, 83.03588032722473, 82.68553912639618, 83.64843785762787, 79.68395099043846, 81.34210601449013, 73.32141280174255, 68.8073918223381, 64.05336052179337, 61.39094598591328, 63.182686641812325, 67.41396099328995, 70.50200209021568, 72.73441269993782, 75.73721677064896, 72.14710861444473, 75.29830992221832, 73.58877405524254, 64.51305225491524, 64.67262849211693, 65.77045798301697, 58.092696368694305, 60.9767834097147, 67.43216961622238, 62.50750847160816, 64.27092164754868, 80.17470225691795, 75.58362141251564, 70.72115913033485, 77.43549764156342, 74.8233050107956, 60.79427160322666, 74.114491045475, 74.12142187356949, 68.60318318009377, 74.21169742941856, 67.88977146148682, 58.92385616898537, 71.48598209023476, 72.26922646164894, 68.1219770014286, 66.51333332061768, 67.53825232386589, 63.8678240776062, 66.9140750169754, 68.82332056760788, 66.09872996807098, 66.0590372979641, 64.45746883749962, 56.387469470500946, 53.61290015280247, 59.6128161996603, 64.06143128871918, 59.94926534593105, 58.947924077510834, 65.5892913043499, 68.44600841403008, 56.28228351473808, 59.35772068798542, 67.3088738322258, 65.7567635178566, 65.1557269692421, 67.00880393385887, 65.39028838276863, 64.25099551677704, 58.91800068318844, 64.43579480051994, 68.41039672493935, 64.21738252043724, 60.183009803295135, 62.84501016139984, 64.61759984493256, 61.9257140904665, 63.79190415143967, 63.418976962566376, 61.69840268790722, 61.8504249304533, 61.78170181810856, 58.919653594493866, 58.57309699058533, 65.55631667375565, 63.814900517463684, 63.84580805897713, 61.700663566589355, 59.4865869730711, 57.29685567319393, 58.19104269146919, 56.26193180680275, 59.91098240017891, 60.53976126015186, 61.10481753945351, 63.18278543651104, 66.56811878085136, 64.1215592622757, 65.98934903740883, 70.42720690369606, 70.15847772359848, 69.66278672218323, 68.08163076639175, 70.3685000538826, 72.26266041398048, 76.32721871137619, 64.76044178009033, 52.15195834636688, 10.631892196834087, 0.02852421774150571, 0.23710166628006846, 0.26324933976866305, 0.41976994718424976, 0.3023086313623935, 0.08450489753158763, 0.3400096145924181, 0.12103641929570585, 0.11060629069106653, 0.02417697640339611, 4.409377444535494, 44.63544487953186, 48.35257261991501, 32.15487398207188, 36.278568506240845, 44.632412642240524, 0.4065017419634387, 0.06478463852545246, 0.020342291936685797, 0.01582137876539491, 0.05230491697147954, 0.06654382537817582, 0.05398078290454578, 0.07631045911693946, 0.0483968489425024, 0.014973275592637947, 0.013467939425026998, 0.0779112939198967, 0.057905326611944474, 0.025736469870025758, 0.05825182051921729, 0.04933786993206013, 0.003083230026277306, 0.021078220415802207, 0.06850178906461224, 0.05646153767884243, 0.06380647304467857, 0.026416663058626, 0.06366211790009402, 0.07953734690090641, 0.11423360425396822, 2.011292399838567, 69.70187902450562, 54.38293643295765, 45.27365863323212, 32.165110632777214, 55.57485647499561, 51.50434009730816, 0.18101664609275758, 0.059530132784857415, 0.6407374714035541, 0.19500581809552386, 0.313124394742772, 0.44040316657628864, 0.06923680470208637, 0.08614367834525183, 0.43684946664143354, 8.60985729843378, 78.92308741807938, 95.31137242913246, 92.91513741016388, 89.69957515597343, 83.20737272500992, 75.49690246582031, 77.13634729385376, 74.22388717532158, 74.6193091571331, 68.02573576569557, 73.62932547926903, 82.5511783361435, 84.12939324975014, 85.44819608330727, 88.04104775190353, 85.14431118965149, 87.46218681335449, 84.29784581065178, 84.6104246377945, 77.33611777424812, 72.37277090549469, 67.85655364394188, 64.08102303743362, 66.79318830370903, 69.34978231787682, 74.05101925134659, 74.0656940639019, 77.93773949146271, 74.97202143073082, 78.07855233550072, 74.68649715185165, 67.11787328124046, 70.28293624520302, 72.58971646428108, 63.72557871043682, 65.59844121336937, 72.58395597338676, 70.6458243727684, 67.35576331615448, 81.28242641687393, 76.87744438648224, 75.87753564119339, 78.78664433956146, 72.55631625652313, 64.89718124270439, 78.1768986582756, 73.92880260944366, 72.57280737161636, 77.03509032726288, 69.86026212573051, 63.619746789336205, 75.98675698041916, 73.17664816975594, 69.24340322613716, 69.1058050096035, 71.35140851140022, 67.57679745554924, 70.94525590538979, 68.92208486795425, 67.4065437912941, 66.92039787769318, 65.52837297320366, 58.26218627393246, 54.63280722498894, 59.97394502162933, 64.7092205286026, 63.258697763085365, 61.245102211833, 67.99868881702423, 70.3447437286377, 61.18452966213226, 59.37434479594231, 66.85071721673012, 68.9904659986496, 66.7867286503315, 69.97997850179672, 67.20387026667595, 65.41903764009476, 63.778126090765, 64.72296059131622, 69.44081023335457, 68.17709684371948, 62.653511837124825, 63.283187448978424, 70.85564151406288, 65.53604856133461, 66.81861653923988, 65.1022182404995, 65.79179763793945, 63.278935477137566, 65.87258130311966, 62.413300126791, 61.990006640553474, 67.81280279159546, 67.06677362322807, 67.77991935610771, 66.14294439554214, 62.52958908677101, 61.72763451933861, 62.42402695119381, 58.736606016755104, 63.01003150641918, 62.98789009451866, 64.80613812804222, 65.95613121986389, 71.51932150125504, 67.65094667673111, 70.34048035740852, 73.0337530374527, 71.71127960085869, 71.3338078558445, 70.30378192663193, 72.54370853304863, 76.1623227596283, 81.05542659759521, 72.64005616307259, 64.25251543521881, 14.545391499996185, 0.06738939133356325, 0.0568550058233086, 0.1417544364812784, 0.606566914357245, 0.3942304488737136, 0.09226186957675964, 0.6739342713262886, 0.2890390605898574, 0.12635684630367905, 0.03182379332429264, 4.424537206068635, 53.459008410573006, 42.69661791622639, 36.35675311088562, 47.023054361343384, 50.57545714080334, 1.0476619703695178, 0.15782996371854097, 0.05293836598866619, 0.039948978228494525, 0.03371606580913067, 0.02068893056275556, 0.01567258372233482, 0.03079289454035461, 0.03841123339952901, 0.054629954320262186, 0.07509825736633502, 0.013253089528006967, 0.0666763803747017, 0.1389774089329876, 0.20959538756869733, 0.15743379044579342, 0.12635864230105653, 0.10344842477934435, 0.19330104551045224, 0.1132068874721881, 0.2223087483434938, 0.10443643855978735, 0.18027179699856788, 0.189797084312886, 0.24894530419260263, 2.399630374275148, 77.64058023691177, 63.57490539550781, 43.67364048957825, 42.78378523886204, 66.5877865254879, 59.6202751994133, 0.2881073683965951, 0.18113403901224956, 0.5186558410059661, 0.7433563086669892, 0.39950420963577926, 0.8856571291107684, 0.32428466307464987, 0.35818970936816186, 0.7834770495537668, 9.81458930298686, 82.92715296149254, 100.39075747132301, 98.89543130993843, 95.88160783052444, 89.2335757613182, 81.63970604538918, 81.23482257127762, 78.5684372484684, 77.78846070170403, 70.45078083872795, 79.479810744524, 86.65299743413925, 87.13772222399712, 88.31660136580467, 92.91784286499023, 89.51310396194458, 90.73587074875832, 86.32935360074043, 89.54897403717041, 79.83753874897957, 76.77634701132774, 71.20216771960258, 68.57357516884804, 72.48625561594963, 73.38721007108688, 76.97469636797905, 78.01021680235863, 82.92882487177849, 78.91524463891983, 84.53006654977798, 78.76693859696388, 69.73746791481972, 72.74883672595024, 75.56562557816505, 67.5435796380043, 69.2134228348732, 75.36507993936539, 73.44714045524597, 68.08391824364662, 84.7324512898922, 81.03455811738968, 76.8988524377346, 81.86823338270187, 78.21451663970947, 67.47176349163055, 79.52642664313316, 78.08374285697937, 74.77227374911308, 79.80101510882378, 76.4188089966774, 65.79701095819473, 77.81597882509232, 78.09554502367973, 71.57500371336937, 71.03704378008842, 74.1004166007042, 69.01458710432053, 73.94852355122566, 71.34751752018929, 71.20880976319313, 72.61833652853966, 68.5988438129425, 60.43660819530487, 56.876940205693245, 62.636241763830185, 67.72087812423706, 63.03581692278385, 61.13929308950901, 72.00679734349251, 73.72964009642601, 61.163102611899376, 62.64760695397854, 74.04404282569885, 69.26499366760254, 70.45078083872795, 72.68185392022133, 70.9016190469265, 67.31992363929749, 64.81578961014748, 69.71924409270287, 71.56059488654137, 70.83000048995018, 64.22928348183632, 68.39815378189087, 70.9361743927002, 69.57064926624298, 67.47246265411377, 67.89303168654442, 70.24597942829132, 71.18360951542854, 68.78845363855362, 65.18386825919151, 66.5062353014946, 70.55751711130142, 70.83861842751503, 71.23220890760422, 70.28941109776497, 65.41467547416687, 65.58068856596947, 66.24350219964981, 65.16375973820686, 67.25517511367798, 68.53731751441956, 69.16084125638008, 71.52986213564873, 75.05429461598396, 71.51267185807228, 72.62423381209373, 77.04176276922226, 74.23610731959343, 73.26098084449768, 71.7367534339428, 73.79550576210022, 78.79042133688927, 86.39854788780212, 77.93752670288086, 74.56070110201836, 15.947977937757969, 0.13088771724142134, 0.7726763072423637, 1.6531195817515254, 1.0949621885083616, 0.7857037300709635, 0.29718490317463875, 0.7490962569136173, 0.47940691583789885, 0.34306471003219485, 0.10609825563733466, 8.039658945053816, 61.508519276976585, 61.60790674388409, 44.6774098277092, 46.75600089132786, 63.658489510416985, 1.1345475143752992, 0.2226751614944078, 0.12170819652965292, 0.10884405361139216, 0.11581305778236128, 0.11871720038470812, 0.11388313985662535, 0.19020525069208816, 0.12429702284862287, 0.15978733368683606, 0.19390358036616817, 0.22090206679422408, 0.20269239001208916], [0.045078881084918976, 0.0869753587176092, 0.07555029209470376, 0.08484267120365985, 0.06221602830919437, 0.04439815726072993, 0.013963254350528587, 0.0384711469814647, 0.08082824599114247, 0.1378792233299464, 0.18831985420547426, 0.34646716027054936, 6.330888262018561, 67.03866273164749, 40.92623591423035, 37.72638961672783, 19.210161790251732, 72.76250079274178, 17.53732055425644, 0.21198749280301854, 0.0894034061639104, 0.35357076034415513, 0.14346568059409037, 0.19579341489588842, 0.08371831747354008, 0.13451153528876603, 0.20715772930998355, 0.12403736021951772, 21.210788637399673, 91.72700956463814, 89.10896524786949, 91.01216912269592, 79.5864026248455, 74.45242211222649, 68.3081366121769, 72.1331861615181, 69.52113032341003, 69.77431833744049, 64.3083268404007, 70.66125154495239, 80.26687771081924, 83.27584505081177, 84.8923771083355, 82.80558228492737, 79.94983792304993, 78.49149897694588, 82.87739083170891, 82.01973125338554, 76.41573876142502, 69.11028116941452, 63.10790665447712, 62.97055922448635, 61.17173194885254, 63.719844818115234, 66.53895154595375, 73.11772093176842, 71.78149983286858, 74.16701942682266, 71.83208271861076, 75.18195256590843, 72.69741028547287, 62.95534864068031, 66.83307096362114, 65.1792249083519, 69.68616306781769, 69.64956343173981, 72.92368054389954, 67.75540307164192, 72.03117683529854, 74.22258004546165, 76.42791330814362, 70.57943433523178, 65.31597957015038, 77.06171929836273, 71.67874574661255, 71.70710742473602, 77.35181093215942, 66.79536178708076, 59.49265144765377, 67.38629087805748, 72.96967327594757, 69.23212543129921, 71.58175975084305, 68.77294287085533, 67.57439598441124, 62.857918068766594, 60.00163413584232, 60.2501218020916, 58.639380633831024, 58.607420548796654, 61.502344608306885, 60.81396594643593, 62.310074865818024, 61.17688067257404, 65.24050801992416, 67.08922281861305, 66.12057879567146, 64.18995559215546, 60.89187316596508, 66.4075393974781, 61.91784091293812, 53.14683236181736, 63.03579032421112, 68.0837282538414, 65.1385746896267, 64.44250524044037, 65.23173809051514, 65.07527008652687, 61.390797793865204, 64.43197220563889, 64.72160026431084, 64.38933849334717, 61.79761156439781, 62.911145612597466, 63.29940117895603, 63.83149042725563, 60.638267174363136, 62.36578367650509, 58.38464230298996, 62.74145811796188, 55.291824862360954, 63.529691621661186, 63.92974555492401, 65.95881387591362, 60.9685530513525, 61.839238330721855, 58.17742422223091, 57.32953391969204, 54.188071489334106, 58.131800070405006, 56.9545092433691, 59.93648283183575, 61.882259622216225, 61.308452412486076, 67.34947085380554, 65.55282846093178, 70.44698864221573, 68.20486575365067, 69.21610549092293, 65.60803189873695, 71.51847034692764, 73.24236944317818, 69.02895033359528, 73.60126778483391, 66.9358478486538, 57.722068056464195, 39.200212731957436, 1.860647820867598, 0.08019668573979288, 0.36143431963864714, 0.07577774551464245, 0.03490286384476349, 0.10517628557863645, 0.745545644313097, 0.11686914876918308, 0.09027127365698107, 0.053032492578495294, 1.262340594548732, 32.20047913491726, 47.637994363904, 39.232548996806145, 31.882705986499786, 48.399929478764534, 1.9567102286964655, 0.08403753745369613, 0.07930492851301096, 0.051643641127157025, 0.012744916894007474, 0.04320349245972466, 0.017724451354297344, 0.027440962294349447, 0.04472562621231191, 0.0226285854660091, 0.03753053046239074, 0.06917166640050709, 0.01687163832684746, 0.05948591933702119, 0.0352505971386563, 0.05691482663678471, 0.037312045897124335, 0.08911143042496406, 0.039350677325273864, 0.06775207148166373, 0.017252237630600575, 0.01894692257337738, 0.025409292211406864, 0.14934025442926213, 0.2715255628572777, 7.929288642480969, 77.24282518029213, 45.93787059187889, 48.05904597043991, 23.113008365035057, 76.0664615035057, 23.34832213819027, 0.22404243500204757, 0.09174669292406179, 0.8637347992043942, 0.0264281719137216, 0.13624859129777178, 0.06640413834247738, 0.12840642069932073, 0.1454229763476178, 0.3030451090307906, 25.192264392971992, 92.75890499353409, 92.82173082232475, 96.01185724139214, 81.94306656718254, 77.60468736290932, 72.51900225877762, 74.81614619493484, 72.56257832050323, 74.02910202741623, 68.44043791294098, 73.5398630797863, 83.38241413235664, 87.65405371785164, 87.67673850059509, 85.00399231910706, 81.50971502065659, 80.8969447016716, 84.91498589515686, 85.09302154183388, 78.6909730732441, 72.3450019955635, 65.17838895320892, 66.75820738077164, 62.50471942126751, 67.07609072327614, 68.3235789835453, 73.8940116763115, 73.46000656485558, 79.59293827414513, 76.33519068360329, 80.00722244381905, 72.86704078316689, 67.18680158257484, 70.68918764591217, 68.7456451356411, 72.89308458566666, 73.16619113087654, 77.18256041407585, 75.37051364779472, 76.26426368951797, 76.06371805071831, 79.08461675047874, 71.83905154466629, 70.11986419558525, 79.5274905860424, 73.00890237092972, 74.95566710829735, 79.8025806248188, 66.77260860800743, 64.59115326404572, 73.32689210772514, 74.47889909148216, 71.59898042678833, 72.42039754986763, 71.35410636663437, 68.7539590895176, 64.21824887394905, 61.431565806269646, 59.746762812137604, 61.02144621312618, 61.942877769470215, 64.66707319021225, 64.87706512212753, 67.55130842328072, 64.2003746330738, 68.4632670879364, 69.77580785751343, 67.84732013940811, 65.90332165360451, 63.894057869911194, 69.67206582427025, 66.04473486542702, 58.42074416577816, 62.69302971661091, 70.01973956823349, 68.17970350384712, 69.39268201589584, 67.3899918794632, 67.80540838837624, 65.2252708375454, 66.50299787521362, 63.994653671979904, 66.39909625053406, 65.52878335118294, 64.84184101223946, 65.81306129693985, 66.8708485364914, 63.26938658952713, 65.16920864582062, 62.358928844332695, 66.50568813085556, 60.20290173590183, 65.14553591609001, 66.99474468827248, 67.85461574792862, 64.59393471479416, 64.74048525094986, 62.145140916109085, 62.2811584174633, 56.84412896633148, 60.994703248143196, 60.66888213157654, 63.39545242488384, 64.08535480499268, 66.71995863318443, 70.4907774925232, 68.37183639407158, 73.18662643432617, 71.86504974961281, 72.19468966126442, 67.01351568102837, 75.82237020134926, 75.4367744922638, 72.21788361668587, 78.21875721216202, 75.53835824131966, 69.75358664989471, 45.99282704293728, 2.520207166671753, 0.11062135628890246, 0.29351866396609694, 0.2950056310510263, 0.010657417824404547, 0.03128538744931575, 0.3061463066842407, 0.1204188411065843, 0.20983723865356296, 0.03490123483061325, 1.0448201978579164, 38.06777089834213, 50.210710912942886, 34.35698501765728, 36.67720891535282, 57.618823796510696, 3.33573080599308, 0.08238748341682367, 0.07533046795288101, 0.04224768417770974, 0.021014622070651967, 0.019478417198115494, 0.057495757573633455, 0.036755015826202, 0.05477982362208422, 0.06471179673098959, 0.04015197046101093, 0.09528920127195306, 0.009035968014359241, 0.20214242889778689, 0.15046661195810884, 0.12504876649472862, 0.1190239745483268, 0.15552045952063054, 0.1642608514521271, 0.11745773867005482, 0.14614864834584296, 0.16928151017054915, 0.20049079408636317, 0.395797656965442, 0.739731362555176, 9.831510744988918, 87.44745880365372, 54.8486964404583, 49.155602529644966, 26.42692644149065, 96.66216194629669, 27.919615544378757, 0.2442135487217456, 0.18269201478688046, 1.622437653131783, 0.19405405822908506, 1.02100046351552, 0.3025004320079461, 0.28084913443308324, 0.5891018046531826, 0.5886525381356478, 28.812434636056423, 99.61510509252548, 97.8712722659111, 103.31682085990906, 88.34939360618591, 83.29160660505295, 76.13210678100586, 80.02931445837021, 76.52648761868477, 79.97662648558617, 71.32306963205338, 76.25826001167297, 87.29574054479599, 90.97138211131096, 94.22143891453743, 89.02067318558693, 85.04935428500175, 82.9240371286869, 86.83278858661652, 86.86806589365005, 83.65110531449318, 75.1401624083519, 67.96369269490242, 69.33506950736046, 66.43552109599113, 70.63566371798515, 72.26888447999954, 77.93438047170639, 76.90604165196419, 83.19155037403107, 80.62651321291924, 85.46592593193054, 78.69088187813759, 70.03549352288246, 73.0003072321415, 72.1297587454319, 76.46135911345482, 76.64220660924911, 78.32589626312256, 74.7281277179718, 79.38885122537613, 78.6988614499569, 82.9843170940876, 76.83749333024025, 71.26817017793655, 81.63030534982681, 77.54066839814186, 75.70328459143639, 83.65699499845505, 71.69623240828514, 66.84729740023613, 73.85563373565674, 80.20408228039742, 74.22710180282593, 75.18379926681519, 75.55389940738678, 73.2750628888607, 66.80882066488266, 65.75071424245834, 63.60617391765118, 63.15562829375267, 65.1069375872612, 66.37256607413292, 66.62435576319695, 67.65501245856285, 66.25313088297844, 69.770298153162, 71.42120316624641, 71.85370355844498, 66.89183861017227, 66.35447144508362, 72.62140676379204, 68.94246697425842, 58.94151762127876, 69.31681528687477, 74.31570544838905, 69.46942269802094, 68.27459201216698, 70.79215452075005, 69.58295300602913, 67.19058617949486, 69.00498121976852, 68.91446247696877, 68.60087290406227, 68.4594976902008, 67.00859114527702, 67.50656202435493, 68.63815650343895, 66.57709389925003, 69.24021899700165, 66.61202922463417, 69.37622889876366, 63.01265336573124, 70.67361608147621, 69.96050834655762, 74.58270952105522, 67.25027337670326, 70.15919208526611, 66.553223580122, 67.29900196194649, 61.53649337589741, 64.71158400177956, 65.0198994576931, 66.70435667037964, 67.49931201338768, 70.49925863742828, 74.88225504755974, 73.41801881790161, 76.28197833895683, 76.44434362649918, 75.47647476196289, 69.81835037469864, 77.98916593194008, 78.16528648138046, 73.58020931482315, 81.25185325741768, 78.30947354435921, 80.85965350270271, 53.568522334098816, 3.131041252054274, 0.2073633932741359, 0.8619694376830012, 0.6942285667173564, 0.15676033595809713, 0.6938481715042144, 0.9685563901439309, 0.34160615236032754, 0.6091773742809892, 0.1497576679685153, 2.10038716904819, 51.30111560225487, 61.94768451154232, 51.546476036310196, 40.899967923760414, 68.2229071855545, 3.9624606259167194, 0.2539886726299301, 0.22700415342114866, 0.17951054644072428, 0.17057456891052425, 0.16926114563830197, 0.21025168360210955, 0.11921403856831603, 0.12182843187474646, 0.1347964457818307, 0.09677695503341965, 0.1779344177339226, 0.1246443553827703], [0.09047714542248286, 0.06242817122256383, 0.052975874132243916, 0.10588932622340508, 0.06622935514315031, 0.054726555972592905, 0.038954489209572785, 0.024678801819391083, 0.0744767309515737, 0.10845133132534102, 0.19479083275655285, 0.42045367299579084, 13.464851081371307, 64.82817694544792, 47.61516898870468, 50.23998074233532, 40.41209690272808, 68.10069054365158, 3.7239008769392967, 0.09868687207926996, 0.15272314165486023, 0.6622762593906373, 0.14805788261583075, 0.08574662933824584, 0.12306327655096538, 0.7298748102039099, 0.07005077743087895, 0.5917373788543046, 44.44863170385361, 95.73095351457596, 84.83997792005539, 85.60781031847, 73.89780387282372, 70.2782852947712, 73.69303286075592, 80.72842374444008, 80.70367187261581, 74.70381662249565, 62.52740420401096, 68.30169215798378, 78.57205465435982, 83.60677689313889, 77.39393547177315, 82.96246826648712, 85.47856405377388, 82.08540692925453, 81.05715170502663, 80.50512492656708, 78.56220558285713, 73.93727615475655, 67.98501715064049, 62.11619406938553, 61.50582142174244, 63.72997127473354, 66.28754183650017, 66.7172683775425, 69.21065658330917, 70.16860038042068, 72.4009121954441, 75.29710158705711, 75.352912992239, 65.49703225493431, 68.12260016798973, 70.25217309594154, 70.33595860004425, 75.68323686718941, 75.69739490747452, 74.82309982180595, 72.92508646845818, 74.47723478078842, 67.22143292427063, 67.11937800049782, 77.7360463142395, 69.203991740942, 70.46449810266495, 73.94106075167656, 64.08139541745186, 62.01136149466038, 68.80475476384163, 70.1132981479168, 67.46747732162476, 66.79595455527306, 65.60358613729477, 65.63854426145554, 62.38219119608402, 61.56605578958988, 63.000892996788025, 62.81935393810272, 62.198949828743935, 61.477201357483864, 62.90159672498703, 60.90289257466793, 65.23787096142769, 65.80805316567421, 65.45575127005577, 65.97438544034958, 63.89597296714783, 65.47077566385269, 66.1086854338646, 62.360000386834145, 66.1016634106636, 67.11595058441162, 55.54216302931309, 58.43228794634342, 65.69384649395943, 69.05782118439674, 63.15364100039005, 61.87067784368992, 66.23095527291298, 62.385656610131264, 61.19182147085667, 62.89954483509064, 69.06556516885757, 64.5909708738327, 61.82282701134682, 61.2210913002491, 63.60431581735611, 62.618337124586105, 60.9175293892622, 62.136686369776726, 58.57637241482735, 64.56732094287872, 64.46864783763885, 61.34762451052666, 61.423460841178894, 60.365814194083214, 58.45700182020664, 56.08157828450203, 55.29831871390343, 56.09972611069679, 56.76292732357979, 57.20554657280445, 61.41331158578396, 62.2844148427248, 64.3259958922863, 67.48206093907356, 68.6665789783001, 65.68170234560966, 65.17753779888153, 67.52357751131058, 75.18815383315086, 72.3097550868988, 71.69500887393951, 65.56947156786919, 74.00998905301094, 61.26932971179485, 60.05634739995003, 15.516280252486467, 0.033096647093771026, 0.25715369498357177, 0.1470789749873802, 0.15414141555083916, 0.15650954941520467, 0.9372507606167346, 0.16464912827359512, 0.21836533182067797, 0.012778348791471217, 0.17341874598059803, 18.6973375082016, 50.31306602060795, 45.837149396538734, 35.96833415329456, 54.07237149775028, 2.513118884526193, 0.09532434196444228, 0.07270231522852555, 0.0422609500674298, 0.04182695694908034, 0.023503341944888234, 0.04901714710285887, 0.0066147891448054, 0.024297419549839105, 0.056150158488890156, 0.06274989966186695, 0.02583398065326037, 0.013844663790223422, 0.04820365305931773, 0.043694456544471905, 0.09889795372146182, 0.05298908436088823, 0.09477032130234875, 0.05221703555434942, 0.04661735692934599, 0.07829471709555946, 0.2615968737518415, 0.16762511077104136, 0.22299260774161667, 0.679760011844337, 16.59473553299904, 71.47505387663841, 58.702966421842575, 53.92590455710888, 26.667352840304375, 81.89632907509804, 4.799360493198037, 0.10483336140168831, 0.1401889353292063, 0.16312821535393596, 0.15020576189272106, 0.1455405622255057, 0.1601073774509132, 1.3626729045063257, 0.04336435296863783, 0.40855419589206576, 48.58293145895004, 98.9608334004879, 90.41998609900475, 89.6139657497406, 78.5834464430809, 75.35090669989586, 79.0258339047432, 84.5943059027195, 84.45774123072624, 79.97101038694382, 65.78340008854866, 73.28119575977325, 81.5100722014904, 85.03435268998146, 82.62148216366768, 85.28935700654984, 86.97136715054512, 84.37420651316643, 81.74747586250305, 82.729122787714, 81.45113736391068, 77.16674566268921, 72.7282266318798, 63.89553219079971, 64.54283505678177, 65.7141450047493, 67.03740119934082, 70.20991176366806, 71.27671211957932, 71.89915671944618, 76.5521590411663, 78.68271231651306, 76.40302464365959, 70.03266647458076, 72.25155740976334, 72.88293153047562, 72.6454746723175, 78.88792410492897, 75.9132993221283, 75.46968072652817, 76.6711762547493, 75.24144977331161, 70.93935862183571, 71.83136075735092, 80.84417313337326, 69.24741581082344, 74.96310710906982, 73.88949751853943, 64.90033507347107, 66.73160120844841, 73.7372624874115, 71.57454773783684, 70.51253512501717, 69.46018159389496, 69.76507723331451, 70.38392722606659, 64.96992453932762, 66.72879695892334, 66.84474393725395, 67.24382132291794, 65.41783690452576, 64.45442900061607, 67.78288319706917, 65.26234164834023, 67.4213781952858, 68.69783610105515, 68.16037014126778, 68.6665789783001, 66.34499475359917, 67.90405109524727, 69.74202007055283, 64.52651113271713, 69.67426970601082, 69.57673653960228, 61.235089749097824, 60.36921501159668, 65.5206897854805, 71.02554559707642, 64.86287668347359, 62.01938286423683, 68.91454607248306, 65.31125262379646, 64.52975615859032, 64.71356749534607, 69.31464180350304, 67.90436267852783, 63.284456580877304, 65.43692708015442, 65.08153215050697, 64.98264625668526, 63.61199900507927, 66.44045323133469, 63.46492789685726, 67.70750284194946, 66.22962534427643, 65.6959667801857, 64.31275740265846, 63.98618772625923, 63.16777244210243, 60.479264706373215, 57.23930016160011, 58.758876621723175, 61.19566686451435, 61.81791007518768, 64.3056669831276, 66.91129356622696, 69.24533352255821, 70.61110943555832, 70.63186392188072, 69.0591511130333, 67.07097619771957, 69.2514055967331, 77.12472751736641, 75.69063127040863, 74.80690509080887, 68.771802932024, 80.73283150792122, 68.13667461276054, 68.94005790352821, 19.103197529911995, 0.0632687722099945, 0.1304911432089284, 0.4324001132044941, 0.3678642277373001, 0.13137440284481272, 0.3186823386931792, 0.01661439695453737, 0.17353590141283348, 0.03546747495420277, 0.030602446458942723, 22.392105348408222, 58.85790690779686, 37.28334479033947, 40.09017437696457, 64.38973367214203, 3.639250681735575, 0.1921707100700587, 0.062470599805237725, 0.09961863106582314, 0.04169078398263082, 0.029429405985865742, 0.05965692129393574, 0.017487487311882433, 0.07567611581180245, 0.06382310457411222, 0.07101671231794171, 0.005495272826010478, 0.034281678817933425, 0.160169480368495, 0.23507591482484713, 0.1877298319595866, 0.17761787690687925, 0.16386922012316063, 0.1436997836572118, 0.11603882652707398, 0.15682254277635366, 0.3054269577842206, 0.1867466644034721, 0.2992704272037372, 0.7607709523290396, 18.72566308826208, 86.45281657576561, 60.253180637955666, 61.80211052298546, 57.39470802247524, 94.57121014595032, 7.502508368343115, 0.1664038622402586, 0.4912793490802869, 1.444704921450466, 0.7741837576031685, 1.029729307629168, 0.45737923064734787, 2.7438681526109576, 0.23184068530099466, 0.9130612586159259, 52.28125400841236, 105.22754073143005, 97.14532881975174, 94.52679052948952, 82.27364882826805, 79.28519278764725, 83.11022713780403, 88.10273364186287, 88.85063230991364, 83.89304593205452, 68.28004091978073, 78.16106110811234, 84.81714114546776, 91.3980384171009, 87.67745286226273, 87.55792647600174, 90.2278684079647, 87.73261070251465, 85.15614375472069, 85.77613368630409, 84.51603770256042, 80.42744189500809, 75.47027349472046, 67.9461832344532, 69.22434344887733, 69.46789517998695, 71.90696910023689, 74.40180882811546, 72.935741096735, 75.87219312787056, 78.60841110348701, 81.35630205273628, 81.44280821084976, 72.43209332227707, 74.49585378170013, 77.57893994450569, 76.01152405142784, 82.24992290139198, 81.33142858743668, 80.37330999970436, 76.94715544581413, 78.83671045303345, 75.94449564814568, 73.63833859562874, 84.03459593653679, 71.51168391108513, 74.13543552160263, 79.12886917591095, 68.36514875292778, 70.86292192339897, 75.5804143846035, 76.15590870380402, 72.37811341881752, 74.69037294387817, 73.03078159689903, 72.54614800214767, 68.11910435557365, 67.4493370950222, 69.10211160779, 68.53809267282486, 68.43622013926506, 69.37458738684654, 71.01989150047302, 67.30777949094772, 71.63741156458855, 71.65856882929802, 71.17768183350563, 72.40813180804253, 70.46860188245773, 70.79942733049393, 70.51644131541252, 64.17940735816956, 72.27121755480766, 72.45666280388832, 63.2370313256979, 66.58520266413689, 71.49878740310669, 76.48098886013031, 64.84455406665802, 68.23366820812225, 73.15564289689064, 69.87087115645409, 66.32962837815285, 67.52932280302048, 72.77894631028175, 68.91918942332268, 65.34540519118309, 69.40691605210304, 67.97005355358124, 71.32303163409233, 69.24676224589348, 68.89743939042091, 67.14928239583969, 68.31273436546326, 70.52133545279503, 67.00131833553314, 68.31265836954117, 67.2422406077385, 65.98124027252197, 63.245706260204315, 63.850838989019394, 63.8460436463356, 66.14692658185959, 64.30457264184952, 68.99280667304993, 69.81512054800987, 72.08698824048042, 74.33994814753532, 73.54216575622559, 72.97127678990364, 71.57388657331467, 73.77367973327637, 80.244892090559, 76.01463228464127, 76.66709527373314, 73.1359751522541, 86.2998215854168, 77.1318331360817, 79.25035625696182, 20.825103633105755, 0.15098287956789136, 0.562532739713788, 1.0049543995410204, 0.8975822548381984, 0.4975339618977159, 1.7989714303985238, 0.2681397367268801, 0.6062345509417355, 0.13540724816266447, 0.2917825133772567, 31.939843520522118, 68.00721555948257, 59.80456531047821, 47.944425120949745, 74.9738909304142, 4.6580361016094685, 0.38812862941995263, 0.2276347266160883, 0.16500991594512016, 0.14955991529859602, 0.16737978643504903, 0.16686006041709334, 0.13028994697378948, 0.09688682257547043, 0.1803044811822474, 0.14460339298238978, 0.15201517730019987, 0.07245269385748543], [0.044384998982422985, 0.0080884652925306, 0.08012505364604294, 0.02560490192990983, 0.0676504269358702, 0.02991260349517688, 0.026844062194868457, 0.012394524856063072, 0.049935428687604144, 0.07844633044442162, 0.18461800675140694, 0.37078713183291256, 23.713683933019638, 70.0261764228344, 35.81215113401413, 51.963940635323524, 53.5037662088871, 48.24754625558853, 0.5618712783325464, 0.03791692965023685, 0.05104683565150481, 0.09586182015482336, 0.2154164228704758, 0.018655136082088575, 0.34478857065550983, 0.5792136071249843, 0.10313647042494267, 2.829687260091305, 59.02995407581329, 91.21368750929832, 84.61790263652802, 85.04186868667603, 71.23899534344673, 69.8706279695034, 79.94738325476646, 85.15880361199379, 82.92860448360443, 82.23494410514832, 66.73437505960464, 71.64683505892754, 77.33271315693855, 81.32223308086395, 87.81905606389046, 82.5299982726574, 81.76555529236794, 81.56730473041534, 82.06963017582893, 83.98275911808014, 82.65608310699463, 77.7290926873684, 71.30575016140938, 61.322884038090706, 64.12712976336479, 66.68384537100792, 65.7707391679287, 65.3479054570198, 69.8884566128254, 69.56850618124008, 72.88733169436455, 72.48662039637566, 72.06337630748749, 68.55379343032837, 69.04266759753227, 69.733075350523, 68.00563484430313, 73.39842706918716, 71.56272277235985, 69.59610790014267, 73.95146459341049, 68.76386895775795, 70.92232793569565, 73.37874412536621, 64.84456166625023, 74.91977423429489, 70.42399227619171, 62.4361103028059, 61.27508260309696, 70.8393631875515, 69.31714206933975, 66.78411439061165, 70.91758579015732, 71.7667718231678, 73.70807245373726, 68.20603609085083, 66.99504107236862, 68.3051423728466, 68.41089069843292, 69.4344113767147, 66.09195113182068, 65.04804074764252, 66.415686160326, 66.20897725224495, 60.32752364873886, 60.88885232806206, 65.23209527134895, 66.78592309355736, 67.79023200273514, 65.57079389691353, 62.13219881057739, 66.22389525175095, 63.24790634214878, 62.935027331113815, 66.69050261378288, 61.234413385391235, 59.35693792998791, 61.83468617498875, 68.60670939087868, 61.078842133283615, 62.282001972198486, 63.23293894529343, 62.89785772562027, 62.519439831376076, 61.252454817295074, 63.65276701748371, 66.34709984064102, 64.83185514807701, 62.11369760334492, 60.549743324518204, 62.91583836078644, 61.53272397816181, 58.94516922533512, 65.7638843357563, 62.145646288990974, 63.52691777050495, 59.139821380376816, 59.2737527936697, 57.784099727869034, 57.24826008081436, 56.224762201309204, 55.55279865860939, 57.000790759921074, 58.96145895123482, 61.495064198970795, 63.04178260266781, 64.72188144922256, 69.93874311447144, 69.10072848200798, 68.33934813737869, 61.210144087672234, 63.656483218073845, 73.96289438009262, 74.16183650493622, 76.10661014914513, 65.25885343551636, 69.14982944726944, 66.07171341776848, 65.26302561163902, 43.10587875545025, 1.0602372768335044, 0.22618624730966985, 0.06518218477140181, 0.5601445084903389, 0.08591899313614704, 0.06786181285860948, 0.04536014763289131, 0.029445614491123706, 0.035473263706080616, 0.13244699919596314, 11.54079107567668, 41.41466170549393, 49.83625240623951, 27.37970821559429, 52.10572622716427, 7.045679781585932, 0.15247443312546238, 0.09466757837799378, 0.023406419313687366, 0.05914434957958292, 0.03240700636524707, 0.04789359860296827, 0.04355373792350292, 0.03912042229785584, 0.08874564809957519, 0.06820739392424002, 0.0684402056504041, 0.023673015457461588, 0.09329506530775689, 0.10991369621478952, 0.06920405372511595, 0.007888137370173354, 0.024947349811554886, 0.0639625838084612, 0.03358982277859468, 0.03721184853930026, 0.06214450753759593, 0.08412092516664416, 0.26112774736247957, 0.3600912698311731, 29.205457046628, 75.87692007422447, 48.46856899559498, 40.839136987924576, 43.841352090239525, 62.58513070642948, 0.5308624485041946, 0.00848720083013177, 0.5366073246113956, 0.14425931847654283, 0.07725706847850233, 0.08306754301884212, 0.2865604654652998, 0.7676158100366592, 0.3003435430582613, 2.8746367106214166, 64.35314923524857, 92.71740362048149, 91.95794597268105, 92.08915293216705, 74.81263518333435, 74.52895000576973, 82.53787904977798, 88.18647354841232, 85.70414274930954, 85.17860814929008, 69.42745015025139, 72.655498534441, 81.52958035469055, 85.70610344409943, 89.03158619999886, 84.12829130887985, 83.45333352684975, 81.77155137062073, 82.77214407920837, 85.06092846393585, 86.03983953595161, 78.84537398815155, 76.41776785254478, 65.67125290632248, 64.12060931324959, 68.82217302918434, 68.55130076408386, 66.88122197985649, 71.41667380928993, 72.29387953877449, 74.86186534166336, 74.73668485879898, 76.39417111873627, 70.23496761918068, 72.95793190598488, 73.74426931142807, 72.71100595593452, 75.64362779259682, 74.09507408738136, 74.45831939578056, 76.29132583737373, 70.06632506847382, 74.51379641890526, 74.98150572180748, 67.8949847817421, 79.12620171904564, 71.19704559445381, 64.05357331037521, 65.86139470338821, 75.20589128136635, 69.48784410953522, 70.45667812228203, 75.15793025493622, 77.22045198082924, 73.21127191185951, 69.38307613134384, 71.95578888058662, 70.51825001835823, 70.98595172166824, 72.180957198143, 69.33418035507202, 67.16011181473732, 70.35337686538696, 68.68876218795776, 66.30296140909195, 63.84594485163689, 67.01050624251366, 65.97287312150002, 68.01216289401054, 67.96818405389786, 63.45579318702221, 69.13554221391678, 67.02531784772873, 65.11721223592758, 70.07518619298935, 64.07976150512695, 61.207271441817284, 63.633433654904366, 71.67289406061172, 66.40934810042381, 62.160131111741066, 66.32865563035011, 65.61667263507843, 65.95166265964508, 63.887241035699844, 66.48429527878761, 66.75590470433235, 66.87739178538322, 63.02816033363342, 63.167156875133514, 66.68705239892006, 65.6792476773262, 63.19011524319649, 67.66931489109993, 65.85827127099037, 66.59392699599266, 62.06166319549084, 62.10960142314434, 60.941065326333046, 59.80064392089844, 59.06150758266449, 58.623151704669, 59.634190052747726, 63.160803616046906, 64.67039421200752, 64.45904955267906, 67.95117616653442, 70.7814010977745, 72.36588567495346, 69.31125998497009, 66.02649584412575, 67.13109657168388, 77.48872518539429, 77.6274025440216, 78.0451749265194, 72.00218439102173, 73.53195950388908, 73.31746861338615, 73.62839832901955, 48.18190097808838, 1.474046353250742, 0.06952632393222302, 0.2973471663426608, 0.7637635292485356, 0.3136259678285569, 0.14336354623083025, 0.13368928019190207, 0.10674445846234448, 0.15369373722933233, 0.3170364035759121, 14.338516350835562, 50.661336332559586, 44.147725850343704, 32.429090067744255, 61.40594758093357, 9.326341152191162, 0.2760169515386224, 0.15249263058649376, 0.14452625415287912, 0.06161833225633018, 0.008023564478207845, 0.016730415045458358, 0.024351093525183387, 0.08612202989752404, 0.039982797898119316, 0.03561180412361864, 0.03262231453845743, 0.03088911769737024, 0.18457560043316334, 0.1756837361608632, 0.2003050345228985, 0.08706920329132117, 0.07788751550833695, 0.16594717424595729, 0.13728698948398232, 0.1559989814995788, 0.18944959592772648, 0.13110672502079979, 0.3098448441596702, 0.5372826789971441, 32.67570823431015, 91.07599049806595, 47.2063185274601, 69.75060760974884, 70.93632638454437, 70.31079635024071, 2.2069610003381968, 0.11082425946369767, 0.5313093401491642, 0.7573189563117921, 0.6283728161361068, 0.17869875562610105, 1.0153540852479637, 2.221865225583315, 0.5649362888652831, 3.517554374411702, 68.77388522028923, 99.6152874827385, 96.66511818766594, 97.78437092900276, 79.6137535572052, 77.82237768173218, 88.29086914658546, 91.7460085451603, 90.02335578203201, 88.92021417617798, 74.11078244447708, 77.41956129670143, 87.01452523469925, 88.22496548295021, 93.84646743535995, 87.60847896337509, 88.6153869330883, 85.59002727270126, 89.28405225276947, 88.61911833286285, 90.4077735543251, 83.328175842762, 78.42293545603752, 68.05304110050201, 68.47359493374825, 73.51289972662926, 72.55407437682152, 71.8508917093277, 75.51788493990898, 75.22191122174263, 79.6202664077282, 77.4618150293827, 79.29039850831032, 72.0600476861, 75.60714974999428, 77.41531312465668, 75.17908751964569, 78.6281244456768, 76.3977125287056, 76.89252957701683, 81.43566459417343, 74.9921527504921, 75.48408195376396, 80.10154098272324, 70.36402389407158, 80.58424428105354, 75.51239803433418, 67.53025755286217, 66.31227850914001, 75.98162725567818, 72.23288521170616, 72.7935603260994, 76.50545954704285, 77.30464786291122, 76.95850923657417, 74.25667941570282, 74.23961073160172, 75.91248616576195, 75.66130444407463, 77.03696742653847, 71.64107456803322, 70.30625179409981, 73.5156811773777, 70.53385958075523, 67.6027424633503, 65.30792400240898, 70.8938218653202, 71.95509731769562, 72.92453929781914, 69.88404124975204, 67.07045942544937, 71.90167218446732, 69.77002456784248, 68.24858620762825, 72.51183584332466, 64.89352583885193, 65.39633005857468, 67.91267663240433, 75.22083207964897, 65.98158225417137, 65.63890904188156, 69.78477537631989, 67.49105885624886, 67.50535368919373, 66.4537601172924, 70.87513446807861, 71.15434348583221, 69.88021105527878, 64.75677877664566, 67.69737258553505, 70.53816094994545, 65.10628402233124, 67.52365350723267, 69.77380156517029, 67.79986828565598, 70.84168866276741, 65.26739537715912, 65.97864881157875, 65.78559637069702, 65.48140749335289, 64.16162431240082, 62.01663561165333, 63.35723787546158, 66.56764760613441, 67.33285054564476, 69.05644565820694, 71.91463708877563, 74.28413674235344, 75.83763778209686, 73.55649098753929, 68.02722528576851, 68.51262643933296, 81.48330643773079, 81.22122690081596, 82.70488008856773, 73.08813571929932, 75.9200781583786, 80.69275885820389, 82.83405035734177, 52.840025424957275, 2.108521107584238, 0.34259104169905186, 0.8961620216723531, 0.824345281580463, 0.724125481210649, 0.22352581116138026, 0.2513842092594132, 0.11359493422787637, 0.2571223466657102, 0.4884612065507099, 21.674038879573345, 59.471269994974136, 63.216850608587265, 38.95233303308487, 68.12748670578003, 10.928194597363472, 0.6030905758962035, 0.3402497438946739, 0.2594131190562621, 0.29640588560141623, 0.13667871040524915, 0.12298305038711987, 0.1439042601850815, 0.2196980657754466, 0.14559629751602188, 0.2480364849907346, 0.38083091320004314, 0.20265277416910976], [0.009425656771782087, 0.02473322907462716, 0.1239747303770855, 0.016219902790908236, 0.06915697187650949, 0.06539552254253067, 0.03623232863901649, 0.025320032254967373, 0.057870612654369324, 0.019511309183144476, 0.005791142521047732, 0.06423242128221318, 43.300960287451744, 53.10085862874985, 35.97926236689091, 41.814787834882736, 49.14469711482525, 33.69372680783272, 0.4115259333048016, 0.06371956755174324, 0.394719167961739, 0.24338123010238633, 0.23691434820648283, 1.6202895808964968, 0.21115423907758668, 0.1361844697385095, 0.21032104472396895, 5.783135304227471, 71.66210263967514, 90.24271041154861, 86.75582751631737, 79.44517180323601, 69.8832280933857, 72.3931834101677, 81.77128538489342, 83.37442696094513, 82.01187327504158, 83.63178715109825, 68.40308591723442, 69.26737993955612, 76.21213048696518, 81.39993891119957, 82.88198858499527, 79.76873204112053, 78.64195570349693, 76.40261426568031, 77.17542439699173, 78.06482747197151, 79.78660628199577, 78.5863570868969, 75.93060359358788, 66.59873753786087, 63.42433087527752, 63.08040753006935, 66.30921587347984, 65.51690518856049, 65.12738808989525, 71.22485250234604, 68.69390711188316, 72.93932050466537, 76.02713361382484, 64.97371673583984, 66.28871977329254, 71.41771495342255, 71.34000152349472, 70.41133895516396, 72.21504136919975, 67.60730221867561, 71.05075344443321, 71.76345080137253, 73.58502745628357, 68.74912574887276, 70.92193275690079, 67.46386751532555, 58.98964963853359, 66.9754721224308, 71.95627525448799, 69.57009449601173, 67.90898323059082, 75.22430509328842, 68.63114207983017, 63.64814266562462, 53.3219725638628, 50.90964160859585, 60.41209191083908, 63.31919051706791, 60.10677449405193, 62.8098164498806, 64.63561087846756, 65.87586432695389, 63.016988933086395, 62.74487793445587, 63.522494807839394, 61.17097198963165, 49.254412427544594, 51.1256068199873, 52.98038989305496, 63.58708754181862, 65.69320052862167, 64.56321716308594, 64.13393899798393, 63.11372794210911, 62.49400019645691, 66.58959522843361, 63.98160517215729, 59.01155166327953, 58.4099755436182, 64.7271479666233, 63.97418797016144, 60.72586767375469, 63.67597617208958, 61.093110367655754, 60.75381517410278, 62.32418730854988, 61.82650901377201, 63.43509189784527, 59.32707913219929, 61.46226815879345, 61.629618778824806, 58.80960009992123, 61.761711090803146, 62.14923709630966, 62.25673332810402, 61.856664195656776, 60.562134459614754, 59.284278228878975, 57.223496809601784, 56.06826759874821, 55.223911106586456, 53.87459971010685, 55.809167101979256, 59.36051353812218, 61.057525277137756, 62.722337543964386, 65.45053035020828, 64.99345287680626, 69.36572626233101, 65.32931685447693, 61.61023981869221, 67.36502721905708, 74.23018723726273, 74.90867123007774, 75.65460160374641, 68.27554196119308, 67.97234863042831, 67.80413165688515, 64.26260009407997, 63.0166507512331, 8.530933633446693, 0.17174823093228042, 0.5232942046131939, 0.1537675512372516, 0.1750291173812002, 0.05908270308282226, 0.2743883233051747, 0.08235089553636499, 0.3037443902576342, 0.2666332956869155, 6.14882530644536, 33.0143878608942, 58.77586551010609, 28.509799875319004, 49.37021881341934, 12.185205146670341, 0.4834951995871961, 0.23518576752394438, 0.13871746428776532, 0.094130122452043, 0.09050861248397268, 0.07320814824197441, 0.04067563728312962, 0.028700622533506248, 0.030253126824391074, 0.0078106608634698205, 0.0511449921032181, 0.01836610295868013, 0.06761210985132493, 0.015775617939652875, 0.09468867021496408, 0.05604394231340848, 0.05932059480983298, 0.020638045207306277, 0.01699370677670231, 0.08160998724633828, 0.06858952576294541, 0.07915077701909468, 0.014735017430211883, 0.026553941825113725, 50.56797534227371, 59.0524260699749, 47.45240092277527, 33.75061735510826, 49.962200447916985, 43.46238322556019, 0.32364873157348484, 0.055474982218584046, 1.1276770080439746, 0.2145436720456928, 0.38380778627470136, 1.8599016359075904, 0.6558485480491072, 0.32852781820110977, 0.30564155720639974, 6.827694978564978, 74.01555195450783, 95.18562957644463, 89.83931645751, 85.25131344795227, 74.6489779651165, 77.06828534603119, 87.97926306724548, 86.14796653389931, 85.3326290845871, 88.73014837503433, 73.13825502991676, 72.27756321430206, 80.74459567666054, 86.11960485577583, 83.5854372382164, 82.06613436341286, 79.78755623102188, 81.18183061480522, 81.69696137309074, 81.87439665198326, 83.15644785761833, 80.71739673614502, 78.01787719130516, 70.14609798789024, 67.17220276594162, 64.27732810378075, 66.24404177069664, 68.41840669512749, 69.46651205420494, 73.53067517280579, 72.02907934784889, 75.99165111780167, 78.00662979483604, 68.14048960804939, 69.15033102035522, 75.22092327475548, 72.30312064290047, 72.9071894288063, 74.46728691458702, 70.65606862306595, 75.0823675096035, 74.18148145079613, 74.51509594917297, 70.57752683758736, 75.00406131148338, 68.43492820858955, 62.89389833807945, 71.97865605354309, 72.77473613619804, 71.07102915644646, 72.53978714346886, 77.75993183255196, 67.56838470697403, 61.965627148747444, 55.07425993680954, 52.148496732115746, 60.56415595114231, 67.08884283900261, 64.89465057849884, 64.25879269838333, 63.85940372943878, 68.69070008397102, 67.88139671087265, 65.55572390556335, 67.25079774856567, 63.18395957350731, 52.136603370308876, 52.14102253317833, 53.67751568555832, 64.1642689704895, 68.48437875509262, 66.32715851068497, 66.89669474959373, 64.95262026786804, 64.36786964535713, 68.54831412434578, 67.40443870425224, 61.7876522988081, 61.824814304709435, 66.12802639603615, 67.8420840203762, 65.77930390834808, 64.76506233215332, 64.27152961492538, 63.91853615641594, 64.030751734972, 63.726578056812286, 66.74819111824036, 61.63132108747959, 63.336080610752106, 64.34833869338036, 62.38116145133972, 65.31853303313255, 65.99443316459656, 65.9060651063919, 63.87018755078316, 64.32965129613876, 62.430376410484314, 60.88173530995846, 60.32998211681843, 56.578884199261665, 58.354186937212944, 59.76812146604061, 62.05824337899685, 65.68706005811691, 66.7534652352333, 68.98525267839432, 68.0746391415596, 70.51769524812698, 69.24246087670326, 65.0161224603653, 70.5918900668621, 76.7741659283638, 76.98926478624344, 78.5524933040142, 70.58537721633911, 71.95083394646645, 75.0025337934494, 73.7858010828495, 68.15411567687988, 10.00109564512968, 0.17358212237013504, 0.39155037549789995, 0.06471539614722133, 0.09429393670870923, 0.2764509594999254, 0.10319483291823417, 0.04165235557593405, 0.1784444067743607, 0.13435154309263453, 6.01404226385057, 42.46138393878937, 58.33489157259464, 28.545405864715576, 63.36923763155937, 14.245613235980272, 0.41414547711610794, 0.21369789086747915, 0.10579659487120807, 0.1325092653860338, 0.14066983218071982, 0.05041803618951235, 0.04493874133913778, 0.03293109250080306, 0.12640962784644216, 0.06619439998758025, 0.024321257333212998, 0.028530076997412834, 0.15142586751608178, 0.11836837613373064, 0.22755926504032686, 0.13203344482462853, 0.1458232759614475, 0.17045321292243898, 0.19357682758709416, 0.12042752423440106, 0.2410699299070984, 0.1899896567920223, 0.07822597937774844, 0.1905048853950575, 55.401296988129616, 70.34926548600197, 48.35079051554203, 57.97466330230236, 65.52361562848091, 50.38499616086483, 0.5850731302052736, 0.1511879201279953, 1.528610831592232, 0.7043381023686379, 0.7046070566866547, 3.114400519989431, 1.5428591170348227, 0.8822364814113826, 0.39668283134233207, 8.582379072904587, 79.3065020442009, 99.94187235832214, 99.72799703478813, 89.09049063920975, 82.19092726707458, 81.56573921442032, 90.57476699352264, 87.52562820911407, 90.18322080373764, 92.46927693486214, 76.89328193664551, 76.24410957098007, 83.9144691824913, 89.18809220194817, 89.38196539878845, 86.86643958091736, 85.07738158106804, 83.87669160962105, 86.85792043805122, 85.27568534016609, 84.89100158214569, 84.92766201496124, 81.15752711892128, 74.16658625006676, 71.88572064042091, 68.86973887681961, 71.59688293933868, 71.98708400130272, 71.49844542145729, 78.38377475738525, 75.17851755023003, 80.07738947868347, 84.30951118469238, 72.78109699487686, 74.02046129107475, 78.60055312514305, 76.73066586256027, 73.53217229247093, 78.89173910021782, 73.9416155219078, 77.94452592730522, 77.83226475119591, 77.08657756447792, 71.88681498169899, 75.63638538122177, 72.59665489196777, 64.9332869052887, 75.56003987789154, 76.83731094002724, 74.45377483963966, 72.02636629343033, 83.73891100287437, 74.42268490791321, 69.69075322151184, 59.47218954563141, 56.38333149254322, 67.00663805007935, 68.46303150057793, 66.32817685604095, 67.67907276749611, 69.53578233718872, 73.56330782175064, 71.70688703656197, 69.3128103017807, 69.86636459827423, 66.21118113398552, 56.17053531110287, 55.10653920471668, 59.92281876504421, 68.74240770936012, 71.69737994670868, 69.94530156254768, 70.09553030133247, 66.13451644778252, 66.95897340774536, 73.8271352648735, 70.28430417180061, 64.8074908554554, 64.7462685406208, 70.25047078728676, 70.19908234477043, 68.01102295517921, 69.96863231062889, 67.95828178524971, 64.70710024237633, 68.57330918312073, 67.65508085489273, 69.73944380879402, 63.22072260081768, 67.61478781700134, 66.5023747086525, 64.76017579436302, 70.1308836042881, 67.70411342382431, 70.12342840433121, 68.09994578361511, 67.64263272285461, 67.17889040708542, 64.42031443119049, 64.38518151640892, 61.514762341976166, 62.84166254103184, 63.63972991704941, 65.02891257405281, 69.56519275903702, 69.28354427218437, 71.46578997373581, 70.49859747290611, 75.13181805610657, 72.00137123465538, 68.34479704499245, 74.51437398791313, 80.3975223004818, 77.83981874585152, 81.48541152477264, 74.55161198973656, 76.58714756369591, 80.10467201471329, 83.225277364254, 73.08060452342033, 11.760669127106667, 0.23270221485290676, 1.1944429879076779, 0.3280820546206087, 0.5297276156488806, 0.2462081002886407, 0.4280615475727245, 0.22423197951866314, 0.502651515416801, 0.49131045991089195, 10.99320150911808, 50.248484686017036, 73.93374234437943, 38.6056662350893, 68.44343215227127, 17.91915826499462, 0.7082026731222868, 0.370470501948148, 0.3010274766711518, 0.2843595523154363, 0.2809781493851915, 0.19494230509735644, 0.1041210925905034, 0.11251999269006774, 0.28230368450749665, 0.23013331519905478, 0.14431380695896223, 0.0704023327853065], [0.05168064089957625, 0.04759589719469659, 0.008417101271334104, 0.012885170744993957, 0.091733942826977, 0.030751115336897783, 0.042039378167828545, 0.060194510806468315, 0.04221135604893789, 0.06773983346647583, 0.05623825141810812, 0.327808617730625, 50.78850410878658, 49.09044362604618, 32.924469485878944, 27.90857143700123, 59.354141280055046, 17.121277078986168, 0.06456658069510013, 0.1884331356268376, 0.7178649015258998, 0.18665109062567353, 0.05690346435585525, 1.2115440890192986, 0.23544179362943396, 0.3106575255515054, 0.3103042929433286, 15.818085707724094, 91.52204856276512, 84.08266335725784, 85.70415034890175, 78.41138407588005, 70.21275401115417, 74.37283918261528, 84.53079611063004, 88.0823515355587, 82.78603613376617, 83.70520681142807, 78.9487436413765, 70.66027119755745, 76.78382501006126, 77.0931588113308, 78.56794327497482, 74.73214030265808, 71.10449776053429, 74.92533713579178, 73.7500374019146, 78.3917847275734, 79.47881519794464, 79.41064685583115, 76.80843248963356, 72.19440087676048, 64.65464025735855, 61.42413340508938, 63.15594367682934, 64.70465317368507, 68.18972736597061, 70.86979195475578, 69.24392759799957, 73.39089587330818, 68.7061196565628, 65.3058797121048, 61.21998555958271, 68.34681853652, 70.84998741745949, 70.58316573500633, 72.19611078500748, 70.59080332517624, 74.82604086399078, 69.45641219615936, 71.56809568405151, 72.23896488547325, 68.12364131212234, 60.73303408920765, 69.23633560538292, 72.76278957724571, 66.6067323088646, 71.03361636400223, 70.65250441431999, 61.48157872259617, 54.22362998127937, 54.090990498661995, 61.39905855059624, 57.88042455911636, 50.864902809262276, 60.26760086417198, 67.22108334302902, 63.439119681715965, 63.612219393253326, 64.10167872905731, 65.59226274490356, 65.338816344738, 59.00988355278969, 50.4477383941412, 53.439165875315666, 57.706545889377594, 55.614416152238846, 51.417495757341385, 52.423032000660896, 62.58281663060188, 64.76070016622543, 64.28487449884415, 61.75470046699047, 57.66437575221062, 64.28374215960503, 62.80832692980766, 61.91874146461487, 58.51752497255802, 62.02863536775112, 62.223663702607155, 62.779893055558205, 61.21905080974102, 62.03254535794258, 59.72033903002739, 58.98161306977272, 60.95612771809101, 62.05318585038185, 58.45789097249508, 60.96723072230816, 56.29961438477039, 59.439754486083984, 62.09071263670921, 61.889745220541954, 63.80844846367836, 60.24333916604519, 57.76878274977207, 56.92769408226013, 55.19260458648205, 52.861137092113495, 53.52641299366951, 57.29290768504143, 60.48555716872215, 59.77237343788147, 63.72323803603649, 66.13136261701584, 65.7933783531189, 68.55573892593384, 65.67862451076508, 62.29205623269081, 64.46784988045692, 72.64634862542152, 73.95144939422607, 76.87965586781502, 72.87788540124893, 62.91955076158047, 70.94383478164673, 63.50259527564049, 73.64064127206802, 23.406696505844593, 0.05862663107109256, 0.27726132539100945, 0.17722303949994966, 0.13211373036028817, 0.09648674560594372, 0.31042662856634706, 0.06915953228599392, 0.2572608314221725, 0.05132402409799397, 2.2564326832070947, 18.296863697469234, 53.49801331758499, 34.16639864444733, 38.23786497116089, 27.390549033880234, 0.22734040569048375, 0.30058717529755086, 0.07959353490150534, 0.07084437820594758, 0.05317203489539679, 0.03379647008841857, 0.0740094821958337, 0.04671373593737371, 0.06046787719242275, 0.015802134876139462, 0.029632574478455354, 0.021965675041428767, 0.03179982195433695, 0.06113999210356269, 0.03663029790914152, 0.023509032362198923, 0.062260408740257844, 0.07756695224088617, 0.01470222749048844, 0.04333178010710981, 0.04034699573821854, 0.03753676821361296, 0.10941323635051958, 0.6925755366683006, 61.39455199241638, 55.590405240654945, 41.668913662433624, 27.042398415505886, 64.48605090379715, 21.49496018886566, 0.03512864001095295, 0.10856794498977251, 0.46728072746191174, 0.22787745343521237, 0.13518639985704795, 1.488578673452139, 0.359763567103073, 0.32197079504840076, 0.5066839896608144, 16.430696435272694, 92.4712148308754, 89.53726306557655, 91.79792135953903, 83.96281018853188, 73.47626969218254, 79.2617404460907, 90.09242847561836, 91.58384084701538, 87.67746046185493, 87.45920777320862, 81.72198683023453, 74.22528550028801, 78.28987419605255, 77.4387426674366, 84.3466503918171, 76.67047709226608, 73.57002586126328, 77.06390038132668, 79.08748179674149, 81.54732540249825, 81.32719561457634, 80.09518772363663, 79.75452080368996, 75.53627595305443, 65.64930528402328, 64.03829053044319, 64.38673943281174, 65.11202931404114, 71.74714967608452, 72.89491608738899, 73.42138543725014, 74.05121684074402, 70.92020764946938, 68.05537417531013, 64.1926458477974, 70.7052531838417, 73.12278226017952, 73.63102778792381, 72.43352964520454, 75.62820822000504, 74.47411134839058, 69.88101661205292, 74.8098537325859, 73.40991765260696, 68.7445355951786, 65.2579414844513, 74.33637633919716, 74.69078332185745, 68.72294515371323, 73.78870412707329, 71.31824389100075, 62.95232020318508, 57.69658662378788, 60.61605356633663, 69.57900881767273, 61.47590942680836, 53.957260474562645, 60.686965361237526, 69.67265099287033, 66.992616802454, 67.65245899558067, 67.26593613624573, 71.22016355395317, 70.89997753500938, 60.70997312664986, 52.05382481217384, 57.33942098915577, 62.78121538460255, 60.53082033991814, 57.48181834816933, 55.11218950152397, 62.89627321064472, 68.4453472495079, 68.34709972143173, 64.6425873041153, 60.41324704885483, 66.48304894566536, 67.99792125821114, 65.8565005660057, 61.16353198885918, 64.63165909051895, 64.9096217751503, 66.15473136305809, 64.42805841565132, 64.6507416665554, 63.15320022404194, 62.457723543047905, 65.3350393474102, 65.01437455415726, 59.97512295842171, 65.25272816419601, 61.85522027313709, 64.74328950047493, 63.807209730148315, 64.8158048093319, 64.31506767868996, 61.731259524822235, 61.47223882377148, 59.744482934474945, 59.19921599328518, 58.22968281805515, 56.22472420334816, 59.06971514225006, 63.55363793671131, 63.85990530252457, 66.87981605529785, 69.28727567195892, 70.99887102842331, 68.06036710739136, 66.55038893222809, 64.30229276418686, 68.17193672060966, 74.32984828948975, 75.31731650233269, 77.92782202363014, 74.03219506144524, 68.77705425024033, 75.11275067925453, 72.33319982886314, 77.9902982711792, 26.037874817848206, 0.11273467374849133, 0.192100087297149, 0.24344971548998728, 0.4151694034226239, 0.06578157292096876, 0.08081733642029576, 0.05109656325657852, 0.3435108595294878, 0.07975704487762414, 1.7936010123230517, 21.303368769586086, 58.13735917210579, 33.515128791332245, 48.03992159664631, 33.879574835300446, 0.17134070280008018, 0.17656470998190343, 0.06343043423839845, 0.07808339054463431, 0.07582517617265694, 0.043908996594836935, 0.013805194521410158, 0.06032238656189293, 0.043003936370951124, 0.022057215246604756, 0.043279239762341604, 0.12141147104557604, 0.21474997425684705, 0.15013959200587124, 0.13392749475315213, 0.10957705802866258, 0.2140567044261843, 0.15159703645622358, 0.09517393831629306, 0.16409370495239273, 0.14958078449126333, 0.2163961171754636, 0.22429412696510553, 0.9150991961359978, 69.28693369030952, 64.11662712693214, 41.807712614536285, 38.67751657962799, 81.93456262350082, 28.820032328367233, 0.1692639509565197, 0.27694481424987316, 1.9002946559339762, 0.5182405351661146, 0.3313509776489809, 2.871719654649496, 0.6602418841794133, 0.5103474680799991, 0.8607422222848982, 18.432461321353912, 97.6959040760994, 93.83902743458748, 98.66665318608284, 89.83824491500854, 79.4362422823906, 85.0937283039093, 94.77582156658173, 95.34286513924599, 91.8402586877346, 91.41037255525589, 86.29683494567871, 77.18151167035103, 81.04968890547752, 81.63583785295486, 88.8283123075962, 78.8948929309845, 77.10040122270584, 81.428262591362, 83.66592451930046, 83.81725519895554, 84.08410727977753, 81.61791801452637, 83.04051607847214, 79.4389933347702, 68.26305583119392, 67.00853034853935, 68.47564682364464, 70.39599537849426, 75.15727669000626, 75.6745657324791, 76.71481311321259, 79.09063562750816, 75.29178187251091, 71.09280958771706, 67.47269824147224, 73.68887588381767, 78.6474958062172, 77.98082157969475, 76.25517457723618, 77.847258746624, 79.81427639722824, 72.22286134958267, 75.3903865814209, 76.39141246676445, 75.97065344452858, 67.43752732872963, 76.95631295442581, 77.73313567042351, 71.55285850167274, 77.42404505610466, 76.38586476445198, 67.75785773992538, 63.24714258313179, 59.88416723906994, 68.75470384955406, 62.8279110789299, 58.40395666658878, 66.00962474942207, 71.75113186240196, 67.74379089474678, 68.66008892655373, 70.27720615267754, 72.85960078239441, 72.610744535923, 65.3732880949974, 56.48591458797455, 58.095329627394676, 65.67763656377792, 61.489858478307724, 59.79680612683296, 59.27825555205345, 68.86464715003967, 71.72613680362701, 71.53641298413277, 68.44657838344574, 60.80918200314045, 71.07634127140045, 70.74933841824532, 66.51368290185928, 64.46800947189331, 68.28833967447281, 66.59141913056374, 67.40787371993065, 66.97508454322815, 67.28548988699913, 66.61922603845596, 65.55604308843613, 67.10835859179497, 69.17788714170456, 66.21220707893372, 64.94552984833717, 63.50409239530563, 68.38093310594559, 68.26335981488228, 67.46225640177727, 68.94749790430069, 66.3735844194889, 62.89057731628418, 63.95922437310219, 62.26478509604931, 61.1759839206934, 60.041672587394714, 65.4530382156372, 67.20445543527603, 65.51959544420242, 69.72334027290344, 71.98785915970802, 72.83373937010765, 71.46071344614029, 70.67469522356987, 67.8647156059742, 71.92752599716187, 78.78012388944626, 78.83748561143875, 82.40100279450417, 76.2445579469204, 72.37163096666336, 80.03171592950821, 79.70443949103355, 84.15485188364983, 29.89093266427517, 0.3777901263674721, 0.7762222294695675, 0.6687106203753501, 0.6640907807741314, 0.2776057709706947, 0.5978616408538073, 0.1406361980480142, 0.4982476111035794, 0.26142879214603454, 3.698604921810329, 29.32780858129263, 69.72410023212433, 45.55549331009388, 54.64869797229767, 40.59861369431019, 0.6536055996548384, 0.44660384010057896, 0.2873212855774909, 0.295068594859913, 0.2061267229146324, 0.11001277292962186, 0.1711798200267367, 0.16215996496612206, 0.21362006926210597, 0.12259057300980203, 0.14110857504419982, 0.13582552259322256], [0.10174791954341345, 0.1022121922869701, 0.05969468918920029, 0.06729364686179906, 0.07937210772070102, 0.11802089517004788, 0.02670771296834573, 0.07027768908301368, 0.04231292266922537, 0.22835273965029046, 0.34071987960487604, 4.18436586856842, 58.79265680909157, 39.06072981655598, 40.91457433998585, 47.64498598873615, 50.74906222522259, 9.47080560028553, 0.061000887653790414, 0.15922215854516253, 0.46462511527352035, 0.10498263698536903, 0.13827772694639862, 0.3013494500191882, 0.3306906740181148, 0.17691126326099038, 0.1761509181233123, 32.094871401786804, 95.38680598139763, 84.73341643810272, 87.46685296297073, 76.28171235322952, 72.54280418157578, 72.87834137678146, 87.15361297130585, 85.99263846874237, 88.32017317414284, 85.14261648058891, 78.93118098378181, 74.3848617374897, 74.58572655916214, 73.91175672411919, 72.24325865507126, 65.25643676519394, 62.75211274623871, 67.61780485510826, 74.08680573105812, 76.44053623080254, 80.07746547460556, 79.80150148272514, 76.6607116162777, 70.51738366484642, 61.55353546142578, 59.95267376303673, 58.23588028550148, 62.01743356883526, 66.99159845709801, 69.94493678212166, 73.05597424507141, 74.8456934094429, 65.04609525203705, 60.9526889026165, 63.295312598347664, 70.31831234693527, 70.87456449866295, 70.12922689318657, 70.06097495555878, 74.2447480559349, 62.34151817858219, 70.20006269216537, 73.91208350658417, 65.31164780259132, 63.144878670573235, 72.20743417739868, 71.01486057043076, 66.92310333251953, 70.64400047063828, 66.96018934249878, 55.349862948060036, 54.86650228500366, 65.87539315223694, 72.5125502049923, 69.414774030447, 62.03696832060814, 52.95584701001644, 47.47440554201603, 55.56230954825878, 62.50330209732056, 66.63673549890518, 65.78973054885864, 62.31183037161827, 55.67075192928314, 48.624505028128624, 52.425011694431305, 60.454809218645096, 65.08698105812073, 64.30895000696182, 63.72377760708332, 56.13602176308632, 50.09874992072582, 54.991127997636795, 67.21704035997391, 64.7039084136486, 65.53254514932632, 60.783058404922485, 64.57387179136276, 64.58988413214684, 60.84268480539322, 58.32370117306709, 63.312506675720215, 62.97961413860321, 64.40280497074127, 60.24294778704643, 64.32578310370445, 60.97342438995838, 58.21371227502823, 57.32463598251343, 62.74149611592293, 60.62215603888035, 53.24410334229469, 64.17009025812149, 60.01232676208019, 63.479834496974945, 60.46702176332474, 59.83721315860748, 58.75607617199421, 55.896307826042175, 51.29261925816536, 54.83059421181679, 54.90202657878399, 56.86407029628754, 59.12258930504322, 63.280341401696205, 65.58325722813606, 65.92846110463142, 66.88776522874832, 67.11588218808174, 62.82321073114872, 60.87463729083538, 68.34884002804756, 68.82717356085777, 73.4394496679306, 75.74198171496391, 71.53135925531387, 62.291623055934906, 67.47444614768028, 65.40823101997375, 74.55230355262756, 45.79641558229923, 0.9526842855848372, 0.14535759313730523, 0.13743111456278712, 0.04539032335742377, 0.027863735995197203, 0.1581939129391685, 0.08008435426745564, 0.058600125266821124, 0.19519945926731452, 0.9187158895656466, 10.575051996856928, 47.59051211178303, 36.08716897666454, 38.699327409267426, 39.68162029981613, 0.034654214687179774, 0.013521669061447028, 0.088524725579191, 0.08954654418630525, 0.011407875699660508, 0.06593662241357379, 0.017793413571780547, 0.02062526356894523, 0.028362952762108762, 0.05759657462476753, 0.09233788776327856, 0.04669853675295599, 0.042077602483914234, 0.08399268946959637, 0.029216409602668136, 0.04125412284338381, 0.005183279508855776, 0.01336257115326589, 0.08198342111427337, 0.05438777669041883, 0.05306300969095901, 0.3156335069797933, 0.3784137382172048, 5.818893760442734, 66.04453727602959, 49.86027091741562, 46.54255114495754, 33.94457034766674, 64.25231784582138, 11.073378156870604, 0.00733886598936806, 0.10801872602314688, 0.0613379154674476, 0.06112776893132832, 0.2532622287981212, 0.5371689226012677, 0.3300553362350911, 0.251983538037166, 0.19649587251478806, 34.30224895477295, 98.41835930943489, 88.77817019820213, 94.53701958060265, 80.4472616314888, 75.99238827824593, 75.54895967245102, 90.60094758868217, 89.13801848888397, 92.00977519154549, 86.51381850242615, 80.72383359074593, 75.98583742976189, 76.9349505007267, 76.19120880961418, 76.48988038301468, 68.24621513485909, 66.360634714365, 70.63149154186249, 76.75528094172478, 79.2409099638462, 80.46402633190155, 80.8311702311039, 80.40243163704872, 73.61857205629349, 64.81322854757309, 63.14556643366814, 61.499840542674065, 65.6360287964344, 70.27036651968956, 73.14691096544266, 74.77901458740234, 76.84157431125641, 65.3582713007927, 65.9334160387516, 66.59834235906601, 71.76321521401405, 73.941440731287, 71.23407080769539, 72.33097314834595, 74.66249763965607, 65.21852239966393, 75.57643219828606, 73.11655059456825, 63.99122625589371, 67.65574961900711, 74.19288843870163, 72.24905714392662, 69.88099381327629, 74.40494745969772, 70.07545217871666, 55.888256058096886, 62.49289445579052, 71.97770610451698, 75.78229755163193, 71.6474050283432, 63.23864243924618, 54.990227445960045, 50.3037641197443, 58.05072382092476, 62.19117924571037, 64.9499300122261, 64.75781232118607, 64.07846197485924, 57.4085658788681, 50.45152299106121, 57.4471528083086, 62.8540650755167, 68.49131718277931, 67.62459129095078, 68.56568679213524, 61.201476752758026, 53.31221468746662, 56.89335152506828, 67.79318824410439, 66.46254524588585, 71.45768880844116, 63.59992325305939, 64.22285422682762, 66.55900686979294, 66.18443816900253, 60.992096588015556, 63.64576019346714, 64.61259171366692, 66.37628987431526, 63.62921968102455, 66.75623908638954, 62.52215288579464, 61.037302762269974, 59.95457366108894, 66.44592493772507, 63.158736526966095, 57.11192339658737, 66.87217846512794, 62.73630939424038, 65.50789967179298, 62.528665736317635, 62.19983518123627, 63.08521427214146, 60.15809454023838, 56.777469143271446, 56.898507848381996, 56.9255205988884, 60.36570779979229, 64.00234445929527, 66.17637500166893, 68.91636997461319, 67.68493965268135, 70.64355969429016, 70.21427392959595, 63.768869787454605, 64.81528043746948, 71.22637242078781, 69.94539275765419, 76.06195494532585, 76.21080055832863, 74.20197755098343, 67.0216928422451, 72.8427828848362, 72.86213144659996, 80.24059072136879, 50.303536131978035, 1.0948743182234466, 0.023985793595784344, 0.048230429747491144, 0.06526051845867187, 0.1171350825461559, 0.11687967242323793, 0.02322675834875554, 0.07782842571032234, 0.1010999058780726, 1.5933546074666083, 8.668939378112555, 55.16261279582977, 32.81364843249321, 46.44336886703968, 46.85315787792206, 0.0025131430265901145, 0.05904457524593454, 0.1173146377550438, 0.07532745483331382, 0.09184731330606155, 0.05111124293762259, 0.05365417484426871, 0.0025208931356246467, 0.03175278463459108, 0.07281158163095824, 0.036938649136573076, 0.010804761968756793, 0.14613745675887913, 0.22741030115867034, 0.1017408023471944, 0.13396103982813656, 0.15848661598283798, 0.19701610319316387, 0.10908318101428449, 0.12984537082957104, 0.15191436395980418, 0.37576854578219354, 0.42440275952685624, 5.668713944032788, 81.31534025073051, 52.62605130672455, 54.5475360006094, 63.77119526267052, 71.40786588191986, 16.726514361798763, 0.1857857167487964, 0.3397829330060631, 0.92976278741844, 0.17342610808555037, 0.3899005812127143, 1.68723676353693, 0.815694808261469, 0.4460020473925397, 0.3195909352507442, 38.562656342983246, 102.41385251283646, 95.31650215387344, 98.89534011483192, 88.87039124965668, 83.9467142522335, 83.06074619293213, 94.65206980705261, 94.1026496887207, 95.55494695901871, 89.10059049725533, 86.15346863865852, 82.2020910680294, 81.20005443692207, 78.81058305501938, 79.3830831348896, 71.31986260414124, 69.98035848140717, 74.97788831591606, 79.90362480282784, 81.95142611861229, 84.53062132000923, 82.32892826199532, 85.28578519821167, 77.2408264875412, 67.01068103313446, 65.6093542277813, 64.61323007941246, 68.01231488585472, 72.43874296545982, 77.15667620301247, 77.54724204540253, 82.31209516525269, 70.3643810749054, 69.2673647403717, 69.85292851924896, 78.63351255655289, 77.39264354109764, 73.95822063088417, 74.07779261469841, 79.47300910949707, 69.68867093324661, 75.7254146039486, 78.92320901155472, 68.96848797798157, 68.81025686860085, 77.10012003779411, 76.12349644303322, 71.02838784456253, 75.94524800777435, 73.61682415008545, 62.67282620072365, 62.39917628467083, 73.40500831604004, 80.63462197780609, 76.22061923146248, 67.65680596232414, 58.830145597457886, 52.907760590314865, 65.31837344169617, 68.53672474622726, 71.21115043759346, 71.72601521015167, 69.24650385975838, 61.427070647478104, 55.550993755459785, 59.45263959467411, 65.95354735851288, 71.81119903922081, 70.60507535934448, 70.10017365217209, 62.88838483393192, 54.98882532119751, 61.924099177122116, 70.37530168890953, 68.39993208646774, 72.2514434158802, 64.51600089669228, 68.34569379687309, 69.67688396573067, 67.01144859194756, 63.89427065849304, 67.50675201416016, 67.68776670098305, 68.70716080069542, 66.18607968091965, 69.20447051525116, 66.43348440527916, 65.5790926516056, 62.25719690322876, 67.98029020428658, 65.58549910783768, 61.706477254629135, 68.33003863692284, 67.09360018372536, 68.48664343357086, 67.36682072281837, 64.92996588349342, 67.6399576663971, 64.6085487306118, 59.8593507707119, 59.841544926166534, 62.81734384596348, 64.44346278905869, 65.65748244524002, 69.64960142970085, 70.62636941671371, 70.46523526310921, 73.74876067042351, 73.60498398542404, 67.40331396460533, 67.6224710047245, 75.65421402454376, 72.56112679839134, 78.4150242805481, 79.69083622097969, 78.3678688108921, 69.59533274173737, 77.41957649588585, 80.04863262176514, 84.35371801257133, 55.64754277467728, 2.013211059384048, 0.37755020486656576, 0.3609707741998136, 0.15177877357928082, 1.0069432365708053, 0.3595525003038347, 0.2417074199183844, 0.16140431020176038, 0.3556256782030687, 2.743856990709901, 14.084866661578417, 65.83472773432732, 45.164726078510284, 53.67094583809376, 53.23273815214634, 0.10818051421665587, 0.16482103936141357, 0.24329114821739495, 0.1597466936800629, 0.16746578650781885, 0.14119972562184557, 0.15466411015950143, 0.09354205947602168, 0.17672902147751302, 0.13821666303556412, 0.1279938459629193, 0.1471061079064384], [0.026068046608997975, 0.04020117856271099, 0.047242393702617846, 0.006497859139926732, 0.02997214785864344, 0.059435022849356756, 0.0739549046556931, 0.010215715647063917, 0.0620128950686194, 0.04444216661795508, 0.435895569389686, 8.75330625101924, 64.72226902842522, 39.686776623129845, 40.15084572136402, 44.68585677444935, 46.25869497656822, 5.0175675842911005, 0.04275284554751124, 0.16195473144762218, 0.2124901642673649, 0.04661958708311431, 0.0676603865576908, 0.1548697889666073, 0.13419616705505177, 0.28272759926039726, 1.6002374631352723, 65.84193214774132, 93.4628476202488, 83.13160479068756, 81.78330793976784, 75.27150616049767, 69.77083012461662, 70.18021255731583, 83.30020174384117, 83.77839088439941, 85.94440385699272, 83.96749153733253, 78.0725410580635, 71.92328542470932, 67.41456896066666, 68.97105664014816, 64.48237270116806, 61.104866936802864, 61.32981486618519, 65.32194525003433, 72.2332575917244, 78.25009793043137, 81.8423643708229, 76.76820784807205, 73.2139241695404, 72.158143222332, 63.468370512127876, 59.170554131269455, 59.197240099310875, 61.48713782429695, 71.19803354144096, 70.8331847190857, 75.397157818079, 66.18557810783386, 60.976342633366585, 67.45059102773666, 64.06199365854263, 67.84710735082626, 65.50058886408806, 72.1686078608036, 72.9470644891262, 68.46202075481415, 70.11319175362587, 70.46195223927498, 64.27569419145584, 66.62560969591141, 75.35998821258545, 69.07189562916756, 66.08460232615471, 72.47058525681496, 64.75813910365105, 52.851584404706955, 57.89883077144623, 72.11619347333908, 67.29570373892784, 61.64348803460598, 61.81681573390961, 59.48486566543579, 50.26828542351723, 50.00888854265213, 47.65516184270382, 45.110590383410454, 50.18886208534241, 48.44806909561157, 48.111931532621384, 48.03731493651867, 46.24876610934734, 54.40776810050011, 59.08450394868851, 63.006501495838165, 63.3052908629179, 63.86716291308403, 67.93153122067451, 64.04769882559776, 52.21228010952473, 51.4669045060873, 62.372212931513786, 63.16214494407177, 63.804534673690796, 57.763820216059685, 61.503613740205765, 63.40147890150547, 66.32325991988182, 60.17621196806431, 58.77111956477165, 62.50229135155678, 63.46961684525013, 63.5179578512907, 63.281481340527534, 59.98582698404789, 59.41504441201687, 59.2909886687994, 48.363759219646454, 56.070813462138176, 58.22959542274475, 60.68251579999924, 60.2360587567091, 60.91002859175205, 57.79345862567425, 55.75576476752758, 53.8930781185627, 53.47061678767204, 51.44365355372429, 54.39193814992905, 56.248507127165794, 60.81948325037956, 63.519743755459785, 63.488976806402206, 65.21757245063782, 67.22520992159843, 67.72569626569748, 63.65022495388985, 62.63670153915882, 64.8418790102005, 68.80411639809608, 75.29702559113503, 76.24923929572105, 71.04481816291809, 63.43585945665836, 65.3396674990654, 68.79365175962448, 72.22421407699585, 61.58112198114395, 3.5629070783033967, 0.07461532703018747, 0.15002399508375674, 0.021924586035311222, 0.11353879817761481, 0.06799469440011308, 0.16333769395714626, 0.06998186159762554, 0.377924841013737, 0.18767262721667066, 1.8111843313090503, 40.69681942462921, 41.74462080001831, 34.03194285929203, 44.91017773747444, 0.4731889354297891, 0.05936944296990987, 0.09920462398440577, 0.046464578408631496, 0.07865808001952246, 0.01802778566343477, 0.02301898111909395, 0.007783142955304356, 0.03746794885955751, 0.026033629510493483, 0.010042546618933557, 0.016444333814433776, 0.06179002441058401, 0.049501658213557675, 0.022587221865251195, 0.005437645522761159, 0.06349147588480264, 0.04351723910076544, 0.10919411724898964, 0.09954388195183128, 0.08599351218435913, 0.06801338167861104, 0.5173720442689955, 12.36040709540248, 74.3929173052311, 46.59518972039223, 35.43087959289551, 45.34680850803852, 57.14493602514267, 6.616690875962377, 0.06555646468768828, 0.02851142311556032, 0.06875475752167404, 0.03463128974544816, 0.13320492493221536, 0.1877668799716048, 0.2026047423714772, 0.13485136470990255, 2.184225395321846, 66.65123552083969, 95.77319964766502, 87.1667830646038, 86.79067924618721, 78.98642241954803, 73.06463778018951, 74.39692988991737, 85.84041103720665, 86.57498002052307, 88.37012529373169, 87.40108609199524, 81.60240724682808, 75.90503856539726, 69.5042972266674, 72.34519198536873, 66.26430988311768, 63.86454865336418, 63.50005321204662, 66.50897115468979, 76.28005564212799, 80.04013627767563, 82.87071838974953, 79.51755791902542, 75.04879251122475, 73.54777425527573, 67.36497402191162, 62.047778740525246, 63.11974301934242, 65.77962309122086, 73.24638962745667, 71.6145671904087, 78.82495388388634, 69.29432809352875, 69.1147269308567, 70.07232114672661, 68.46372306346893, 69.48364913463593, 68.83190050721169, 74.95980128645897, 73.09540092945099, 70.08247420191765, 73.09230789542198, 70.12852773070335, 65.48523768782616, 70.07355988025665, 76.53565272688866, 71.43881902098656, 71.1991734802723, 75.17123714089394, 64.25895988941193, 56.4240463078022, 65.18908157944679, 74.06045794487, 68.1013897061348, 64.85270082950592, 64.17743146419525, 63.16984713077545, 53.39229919016361, 52.78202533721924, 48.5928413271904, 48.11060160398483, 51.953145414590836, 50.93869484961033, 51.81868962943554, 51.56821466982365, 51.52704007923603, 57.83777564764023, 60.17969638109207, 64.18558582663536, 66.18946149945259, 66.25003784894943, 69.34424981474876, 70.47283485531807, 56.76317811012268, 54.38479073345661, 63.5044951736927, 64.3035238981247, 68.7430688738823, 60.18810912966728, 64.1736088693142, 66.29327192902565, 65.55923491716385, 64.9520654976368, 61.395942717790604, 63.42691853642464, 66.15813598036766, 64.50992122292519, 65.94476982951164, 63.97376239299774, 62.32210122048855, 62.09285192191601, 54.87084545195103, 60.649807155132294, 61.56331613659859, 64.96662631630898, 64.70013901591301, 65.80535531044006, 60.494460090994835, 59.66048464179039, 56.17244280874729, 56.07857644557953, 55.44969119131565, 55.85143983364105, 59.23537105321884, 62.409333139657974, 65.20963087677956, 65.11863335967064, 67.43352994322777, 71.10883712768555, 68.95190566778183, 65.70042014122009, 65.12568578124046, 67.59907945990562, 72.46518954634666, 77.18069851398468, 77.61617794632912, 73.57132539153099, 65.43911576271057, 70.9802520275116, 74.54715862870216, 76.55469730496407, 64.78829428553581, 4.409631555899978, 0.058545213760226034, 0.18411230732453987, 0.012075085014657816, 0.10809553830767982, 0.09510437681456096, 0.06832205574028194, 0.10889142489759251, 0.4102762753609568, 0.6787228456232697, 1.159564065746963, 46.18045337498188, 38.847413063049316, 41.736265048384666, 56.260864064097404, 0.8400889055337757, 0.05124193514348008, 0.12750362773658708, 0.039104295428842306, 0.020349073311081156, 0.03598100032832008, 0.06621241191169247, 0.008099261685856618, 0.07223617227282375, 0.035531136381905526, 0.021718849711760413, 0.028789990101358853, 0.1300214824732393, 0.1391667456482537, 0.25044856884051114, 0.13992667518323287, 0.17580334068043157, 0.3180690575391054, 0.18320029688766226, 0.16268923500319943, 0.11918373667867854, 0.22350700513925403, 0.6735607632435858, 13.36588729172945, 88.53717193007469, 49.239741414785385, 54.99959774315357, 57.03825294971466, 69.01548385620117, 10.943008102476597, 0.11849385846289806, 0.3834910673322156, 0.4275003354996443, 0.21655806864146143, 0.4521275562001392, 0.995697621256113, 0.330656950827688, 0.5298650613985956, 2.928864313289523, 72.75560036301613, 102.39791616797447, 91.88179045915604, 93.12883034348488, 87.33363971114159, 78.62552538514137, 78.8663412630558, 90.71998000144958, 91.49807944893837, 92.07140788435936, 93.76046285033226, 84.77295711636543, 79.73687455058098, 72.47947677969933, 76.61522045731544, 70.14128744602203, 67.3111081123352, 66.36519446969032, 70.50058856606483, 78.81629034876823, 83.93599882721901, 85.27810961008072, 83.82707387208939, 79.97098758816719, 77.93989017605782, 69.4404074549675, 64.48695525527, 65.74350222945213, 69.029231518507, 75.61033397912979, 76.52965664863586, 82.86696419119835, 73.40923368930817, 72.40053221583366, 72.9993648827076, 72.43815779685974, 71.70395359396935, 72.40142896771431, 77.3974160850048, 76.12675666809082, 71.92643165588379, 74.92773100733757, 74.42208454012871, 70.4895767569542, 71.64197891950607, 80.84916606545448, 75.15483722090721, 71.7015977203846, 77.99392327666283, 70.55678755044937, 58.941133841872215, 65.17740100622177, 76.52657881379128, 74.23798441886902, 68.14783081412315, 67.94533967971802, 65.81231653690338, 56.68110251426697, 54.98953588306904, 52.60952219367027, 51.01563312113285, 55.60671776533127, 53.84191766381264, 55.64356058835983, 53.773707523941994, 52.87151053547859, 62.22512662410736, 62.27060258388519, 68.50042909383774, 69.75765243172646, 68.93337786197662, 74.43976119160652, 70.73126658797264, 57.546095699071884, 57.51678787171841, 68.30464839935303, 66.9241900742054, 71.76843613386154, 62.59050741791725, 66.36970862746239, 69.56447839736938, 71.37853905558586, 66.30879029631615, 64.76614907383919, 66.90649062395096, 69.34188634157181, 69.55545768141747, 67.56508648395538, 66.87552988529205, 65.11377722024918, 64.52448964118958, 59.39117029309273, 64.08521041274071, 63.884968757629395, 68.92779976129532, 67.30948179960251, 66.9859367609024, 63.22817400097847, 64.16179910302162, 60.664565563201904, 61.04470856487751, 58.46030004322529, 61.00834831595421, 63.41208793222904, 66.67212679982185, 68.59521880745888, 68.67845714092255, 70.96757590770721, 74.9323059618473, 72.9670438170433, 70.25234788656235, 69.28061082959175, 72.17714980244637, 74.74156379699707, 81.55965954065323, 80.39505243301392, 77.78186425566673, 69.56947892904282, 77.26948454976082, 80.36187261343002, 83.72833237051964, 69.54488664865494, 5.996441133320332, 0.14147144072921947, 0.5859082541428506, 0.11483535985462368, 0.43963890289887786, 0.20169464667560533, 0.5849608581047505, 0.15164624084718525, 1.1681639542803168, 2.501177075318992, 3.2947393180802464, 54.767426401376724, 56.7774273455143, 47.864735797047615, 61.88826709985733, 0.697717551374808, 0.1597529574064538, 0.24964814772829413, 0.22993816004600376, 0.18738151236902922, 0.08659441431518644, 0.1789157892926596, 0.09264594584237784, 0.1989542366936803, 0.16792389942565933, 0.13001505547435954, 0.10993305884767324], [0.09255866185412742, 0.0352309228037484, 0.00649776869067864, 0.08654304285300896, 0.04501674477069173, 0.06819111862569116, 0.006864626666356344, 0.07189142241259106, 0.050836184454965405, 0.23330411146162078, 0.6850562745239586, 20.429476462304592, 55.73716476559639, 40.21171845495701, 50.954619795084, 45.90178772807121, 34.24068085849285, 4.585097590461373, 0.16284379467833787, 0.08598315180279315, 0.08712796654435806, 0.09132675608270802, 0.07701495764194988, 0.9793755377177149, 2.552281483076513, 0.25093342876061797, 19.34321355074644, 81.90614774823189, 91.44713938236237, 82.07958564162254, 82.884162068367, 71.73680663108826, 66.75590470433235, 70.216204226017, 79.0736885368824, 82.36014738678932, 82.39676982164383, 80.00884115695953, 81.68908819556236, 76.99203863739967, 73.03514376282692, 68.59401047229767, 65.09202718734741, 62.478569224476814, 60.50832934677601, 62.97721266746521, 71.08456403017044, 75.49789801239967, 76.29008710384369, 74.07514035701752, 78.27100440859795, 72.8663720190525, 64.01880517601967, 58.71749684214592, 61.28121927380562, 63.72884653508663, 68.08412343263626, 68.51007297635078, 73.84082213044167, 63.31872694194317, 68.37240636348724, 63.75975787639618, 63.90658959746361, 67.79890313744545, 68.31531822681427, 72.39218026399612, 67.34414353966713, 69.65665385127068, 69.43427458405495, 62.64012135565281, 68.15795347094536, 71.88765093684196, 67.26495578885078, 68.59625235199928, 70.09086415171623, 62.19372510910034, 52.684461772441864, 61.063509956002235, 69.83859568834305, 64.06673580408096, 66.20956242084503, 67.88690641522408, 62.444758638739586, 53.96578721702099, 49.070502296090126, 45.77433876693249, 50.57084798812866, 54.845367819070816, 57.84768931567669, 53.9285796135664, 51.09641298651695, 45.998021364212036, 48.36108036339283, 48.52504916489124, 55.64717419445515, 60.2388060092926, 60.437478348612785, 61.91938363015652, 60.9895621240139, 61.654777228832245, 67.58572697639465, 52.41787947714329, 49.647850915789604, 59.264899268746376, 61.59064806997776, 63.26326511800289, 62.91535198688507, 62.72848941385746, 61.92662604153156, 63.93552124500275, 59.42105948925018, 59.558444917201996, 61.83965250849724, 60.762520506978035, 60.16714185476303, 63.27877588570118, 56.9972113519907, 52.124922797083855, 55.654925778508186, 57.354243993759155, 58.463092893362045, 59.64386813342571, 60.826953649520874, 62.00053967535496, 58.14725384116173, 55.341457799077034, 54.263961017131805, 54.067682549357414, 51.63679338991642, 54.3530510365963, 54.39467780292034, 57.59390473365784, 63.30045372247696, 63.08768413960934, 64.12269160151482, 67.106504291296, 63.889969289302826, 60.53388677537441, 62.07110568881035, 62.90620967745781, 68.32953706383705, 71.31800830364227, 74.67157155275345, 70.99765509366989, 66.63227453827858, 65.58006539940834, 72.04493969678879, 70.0302954018116, 70.92639371752739, 8.830700498074293, 0.025186180355376564, 0.04773888678755611, 0.15109954518266022, 0.11453570288722403, 0.062426464282907546, 0.06529364793095738, 0.04897059960057959, 0.3989603341324255, 0.6026037270203233, 0.23974019422894344, 31.09305325895548, 39.94276888668537, 31.130135469138622, 46.83096706867218, 4.426276087760925, 0.4622937919339165, 0.14446398796280846, 0.054986322502372786, 0.09000638630823232, 0.07211692398414016, 0.12030898840748705, 0.038998624731902964, 0.06046398833859712, 0.02238144286820898, 0.07314479109481908, 0.03380452239071019, 0.029385311281657778, 0.07267007633345202, 0.06213810651388485, 0.06178262519824784, 0.05588841042481363, 0.03638915928604547, 0.11132368774269708, 0.10548193167778663, 0.06499454015283845, 0.3120779665187001, 0.5525653401855379, 29.625005833804607, 64.68259915709496, 47.724230736494064, 41.843711882829666, 48.686460703611374, 41.4927589148283, 5.691049620509148, 0.14060241548577324, 0.0383812023937935, 0.055420334174414165, 0.19282854977063835, 0.3376174351433292, 0.6425313313957304, 2.974967476911843, 0.30040573503356427, 22.9553035274148, 86.71830072999, 92.25480124354362, 88.95155489444733, 87.46445909142494, 77.25936189293861, 71.52153298258781, 74.25370037555695, 82.6407927274704, 84.71766248345375, 85.56993395090103, 85.28203099966049, 83.99357333779335, 79.05264526605606, 76.5241165459156, 71.73147931694984, 68.60275760293007, 66.50239750742912, 61.63789093494415, 64.81523483991623, 74.45793941617012, 79.18138235807419, 78.48555609583855, 75.55283546447754, 80.39184540510178, 75.38620680570602, 67.56906867027283, 61.502283811569214, 62.294735088944435, 65.66182181239128, 72.13189423084259, 74.24976378679276, 75.05684807896614, 67.67312988638878, 70.76509237289429, 63.965197652578354, 69.66270312666893, 70.81675440073013, 70.0972630083561, 72.99870371818542, 70.73591753840446, 71.53920203447342, 69.5735827088356, 64.56144645810127, 73.03414061665535, 73.66601631045341, 69.18072938919067, 70.46682357788086, 72.7327711880207, 60.95101699233055, 56.35363608598709, 66.82392105460167, 71.97818487882614, 66.51936739683151, 70.9259757399559, 70.67349448800087, 65.06498023867607, 57.64947295188904, 53.99057328701019, 49.29649516940117, 54.113063514232635, 59.664436429739, 63.07870902121067, 59.81250688433647, 55.767722725868225, 49.33569386601448, 51.73784136772156, 51.47723615169525, 56.57356448471546, 62.995987460017204, 63.15774478018284, 65.17618507146835, 62.89503447711468, 63.011372834444046, 68.77620309591293, 57.40658238530159, 50.935218036174774, 61.123371943831444, 63.467648550868034, 67.37379714846611, 66.7086124420166, 64.1361428797245, 64.93582516908646, 65.62884718179703, 62.1449813246727, 61.82449512183666, 63.58640357851982, 63.287758603692055, 60.764131620526314, 65.68290308117867, 62.08492174744606, 55.7651274651289, 58.936425894498825, 61.73685282468796, 62.6933640986681, 64.38009738922119, 64.41504031419754, 64.339629560709, 61.23793199658394, 58.46638731658459, 55.91886341571808, 56.42017811536789, 56.212158277630806, 57.34291300177574, 58.10129530727863, 61.9946613907814, 65.92940345406532, 66.0765315592289, 68.0266173183918, 68.45291644334793, 65.39250746369362, 63.64862523972988, 64.69989582896233, 64.8134945333004, 70.06900012493134, 74.91736516356468, 75.54237842559814, 73.27709957957268, 68.70747998356819, 69.54695373773575, 76.19043365120888, 75.15097662806511, 74.09976303577423, 10.255055967718363, 0.09709343648864888, 0.013848618509655353, 0.12254665271029808, 0.16439982602605596, 0.11852387091494165, 0.08873148792190477, 0.07215395715320483, 0.8432607259601355, 1.0095026367343962, 0.26919919706415385, 35.621864944696426, 42.82895341515541, 34.02330592274666, 61.953992173075676, 6.952289817854762, 0.4567068151663989, 0.09121073613641784, 0.10276147804688662, 0.02388391898421105, 0.044386446170392446, 0.03384734060091432, 0.02676823325600708, 0.034083469727193005, 0.03615510075178463, 0.08877381260390393, 0.03787992987781763, 0.25374655437190086, 0.16762411629315466, 0.2318942832062021, 0.27431357419118285, 0.15383378049591556, 0.2610176720190793, 0.1835696934722364, 0.18559627613285556, 0.14483461651252583, 0.5782635393552482, 0.7316043111495674, 32.724170833826065, 77.33012169599533, 52.62991949915886, 72.7555775642395, 58.5109893232584, 54.482266902923584, 10.984350834041834, 0.3905452403705567, 0.19318233156809583, 0.2544015442254022, 0.15014456439530477, 0.5735486454796046, 1.7614337196573615, 5.329151814803481, 0.9385130053851753, 25.6763831153512, 93.74023273587227, 96.47562235593796, 93.11391234397888, 94.21229660511017, 81.07120335102081, 76.48625537753105, 80.51458641886711, 86.65871992707253, 88.139378875494, 88.52651730179787, 89.12456721067429, 86.74880549311638, 85.84778264164925, 79.78553473949432, 75.23627445101738, 72.19266816973686, 69.27386239171028, 65.593151897192, 69.62870255112648, 77.75564566254616, 79.79303553700447, 80.36627277731895, 79.06272992491722, 83.51433545351028, 79.60448205471039, 72.74834275245667, 65.8635301887989, 68.08736845850945, 70.97952246665955, 76.04902043938637, 78.18220317363739, 78.9707824587822, 71.29036858677864, 73.34217488765717, 67.20849081873894, 73.70754048228264, 74.36457842588425, 75.18417164683342, 77.52403289079666, 73.2685424387455, 74.41610366106033, 75.14375701546669, 67.06680402159691, 73.5569317638874, 76.43541410565376, 73.52164685726166, 73.06679606437683, 76.23291537165642, 68.54877009987831, 61.46965876221657, 66.58645659685135, 75.82014352083206, 70.10132119059563, 72.69288092851639, 72.07558125257492, 67.89741665124893, 61.305287182331085, 57.297133058309555, 51.39696545898914, 56.37034758925438, 60.721007734537125, 64.08778667449951, 61.53063029050827, 59.145076498389244, 50.83804965019226, 55.22656336426735, 54.07900594174862, 60.36920741200447, 67.97649800777435, 66.77491888403893, 67.35382542014122, 65.55709183216095, 67.5562709569931, 72.75546357035637, 57.136546075344086, 53.790662214159966, 64.31240782141685, 66.50750443339348, 69.03164818882942, 68.3296662569046, 65.3905999660492, 66.8606498837471, 69.7057244181633, 64.48791280388832, 65.59119120240211, 66.43030777573586, 66.079191416502, 64.29229170084, 67.54107177257538, 64.97810170054436, 60.52623778581619, 63.95661011338234, 64.36995193362236, 66.28860577940941, 68.04605707526207, 66.07798308134079, 69.14443373680115, 65.28537601232529, 61.95793256163597, 60.79827658832073, 60.12967586517334, 60.2758464217186, 62.38947920501232, 59.28804762661457, 66.84863492846489, 70.59618383646011, 69.6467287838459, 70.28485134243965, 72.07070991396904, 70.66847115755081, 67.5482077896595, 69.29169863462448, 66.77621841430664, 72.5788414478302, 76.13452345132828, 78.73949646949768, 76.90306261181831, 72.0331147313118, 77.9602798819542, 82.72192597389221, 80.62155067920685, 79.32530343532562, 13.100754618644714, 0.2454985774238594, 0.31125697307288647, 0.48326397605706006, 0.32966440252494067, 0.26556261407677084, 0.38361313578207046, 0.12834707857109606, 2.082018004730344, 2.341248169541359, 0.6993565103039145, 40.22487714886665, 57.622646391391754, 41.32575027644634, 69.35803547501564, 8.640713542699814, 0.695340185193345, 0.2783316804561764, 0.17091137036914006, 0.15770195808727294, 0.19186780991731212, 0.16421933571109548, 0.14286929072113708, 0.16927432618103921, 0.15051154157845303, 0.2024430432356894, 0.12361976114334539], [0.015805480106791947, 0.06032594516000245, 0.05995323859679047, 0.0494690296909539, 0.02627235429827124, 0.0579775153164519, 0.037126045135664754, 0.0056729504012764664, 0.027381117361073848, 0.058297510840930045, 0.0892423749610316, 37.2662191092968, 55.70464611053467, 25.059465318918228, 43.22068199515343, 55.08810259401798, 15.817418843507767, 4.034282946959138, 0.17229776160093024, 0.09276179509470239, 0.06637279002461582, 0.09193035220960155, 0.313688219175674, 11.376694031059742, 24.440755918622017, 7.04346165060997, 68.12018349766731, 90.35450041294098, 87.31340199708939, 83.51001128554344, 78.96883696317673, 70.0908337533474, 70.25724962353706, 75.50388649106026, 77.51822680234909, 81.40114724636078, 77.65438869595528, 83.81992265582085, 79.76376190781593, 77.95089438557625, 75.71066379547119, 74.9884669482708, 74.6898865699768, 65.1713365316391, 61.59913681447506, 59.96929407119751, 66.91649168729782, 78.98646041750908, 74.22189608216286, 75.10772734880447, 72.7358490228653, 72.55552589893341, 63.86644095182419, 57.79880873858929, 58.155886977910995, 64.67366203665733, 69.25525858998299, 70.98812520503998, 69.65654745697975, 70.08305937051773, 65.60343414545059, 62.31634832918644, 66.76207557320595, 68.34212958812714, 68.07025417685509, 71.38347879052162, 69.2308335006237, 66.82756125926971, 66.68594285845757, 71.15926042199135, 70.9898579120636, 70.58498203754425, 70.12467473745346, 71.82623863220215, 61.29695802927017, 53.05730916559696, 66.42461568117142, 70.3568422794342, 64.84706953167915, 68.80880534648895, 68.25204402208328, 65.15911638736725, 53.847351372241974, 49.264189302921295, 47.04224333167076, 50.52479445934296, 62.03205518424511, 64.80879038572311, 66.63716107606888, 64.52850222587585, 63.58862645924091, 54.13352161645889, 43.014531657099724, 49.56971950829029, 49.88927476108074, 57.29769542813301, 62.54976600408554, 64.75165665149689, 62.762227803468704, 63.550970479846, 60.87890066206455, 66.20724454522133, 54.034369736909866, 54.16117273271084, 58.506551161408424, 58.40981975197792, 61.08728148043156, 61.823450177907944, 63.39427828788757, 59.25014466047287, 60.76411262154579, 62.85438805818558, 61.08831502497196, 58.442194014787674, 58.468211218714714, 57.12538227438927, 57.202248349785805, 56.5020789206028, 49.936681017279625, 53.633126467466354, 56.3121385127306, 61.2429591268301, 61.82244323194027, 61.594664454460144, 57.229534685611725, 53.03462818264961, 52.64816991984844, 53.55034410953522, 51.50897964835167, 53.04288133978844, 56.37162812054157, 60.38464218378067, 59.50853459537029, 64.92836236953735, 64.30256634950638, 66.85311108827591, 61.84006288647652, 62.08339422941208, 61.4355593919754, 62.20317140221596, 68.71395483613014, 71.35437235236168, 74.7628578543663, 67.91551887989044, 65.4951399564743, 63.235990181565285, 72.00888723134995, 68.0412845313549, 75.27541235089302, 15.580548103898764, 0.14220005163224414, 0.06628365808865055, 0.0908375545986928, 0.04540351132163778, 0.08537712143152021, 0.14190724468789995, 0.11969411163590848, 0.2991729386849329, 0.47990632185246795, 0.5420898960437626, 25.08925002068281, 43.70461642742157, 32.31956474483013, 48.54080691933632, 10.527094770222902, 0.6852372398134321, 0.10924619375145994, 0.09469955752138048, 0.08918327032006346, 0.0865796381549444, 0.04337591934017837, 0.08382237399928272, 0.0007044426320135244, 0.08320570865180343, 0.05859074452018831, 0.02138790750905173, 0.035206038592150435, 0.04129844390263315, 0.04512594437983353, 0.03506277069391217, 0.03688997167046182, 0.08745313112740405, 0.018899041060649324, 0.057098396864603274, 0.018481924380466808, 0.04443111603904981, 0.350827841903083, 46.969606429338455, 67.63989686965942, 35.36702021956444, 43.03009942173958, 62.20330819487572, 20.98925292491913, 5.350352777168155, 0.09837791600148194, 0.10354227677453309, 0.17811504163546488, 0.0995653671270702, 0.441141989431344, 12.192072328180075, 31.919081434607506, 6.6030125599354506, 72.58840933442116, 90.91195330023766, 94.66546788811684, 84.92209151387215, 83.99620279669762, 73.75240087509155, 74.8238217830658, 78.45315903425217, 81.36474519968033, 83.35964575409889, 81.3353879749775, 86.96002095937729, 82.96192869544029, 80.20586058497429, 78.95205706357956, 80.81541627645493, 78.89477133750916, 69.70262378454208, 64.05213698744774, 64.0351291000843, 68.09866905212402, 81.72647818922997, 76.54668733477592, 75.51340878009796, 74.36227574944496, 76.04975759983063, 66.39053151011467, 60.89503839612007, 60.39497382938862, 67.29856118559837, 70.04316911101341, 75.03698274493217, 70.96286416053772, 72.42924347519875, 65.72871342301369, 69.36584025621414, 68.39349523186684, 72.17378318309784, 71.30587175488472, 71.56432628631592, 71.32001459598541, 69.47664991021156, 69.78831678628922, 73.81359279155731, 72.64438793063164, 71.21290594339371, 72.75484800338745, 72.28775426745415, 62.051593735814095, 58.256858959794044, 69.40783560276031, 70.27302637696266, 67.6925240457058, 72.01967865228653, 69.15856897830963, 62.995979860424995, 55.15739947557449, 52.175395488739014, 49.872289672493935, 54.53008733689785, 63.978816121816635, 68.86868253350258, 69.18037220835686, 67.42710828781128, 66.51510402560234, 60.7689193636179, 48.01852114498615, 52.10379213094711, 51.890425980091095, 59.327789694070816, 63.675827980041504, 65.6858441233635, 65.87195813655853, 67.90095806121826, 63.92995834350586, 66.79122000932693, 59.2105545848608, 56.18236027657986, 59.049352034926414, 59.91596773266792, 63.03737483918667, 65.14514073729515, 64.79538470506668, 61.98433734476566, 60.73885537683964, 62.975202575325966, 60.41594870388508, 60.59901908040047, 59.6014092117548, 61.394434198737144, 60.01655213534832, 56.773874536156654, 52.80479371547699, 56.00718967616558, 58.703437596559525, 63.446168303489685, 63.89842003583908, 63.261209428310394, 59.257824048399925, 58.74385982751846, 57.33318172395229, 57.53473810851574, 55.81122279167175, 57.71355651319027, 60.42991675436497, 63.563536405563354, 64.7351123392582, 68.54752376675606, 67.16273367404938, 70.00751942396164, 66.32609456777573, 64.73109975457191, 63.8095124065876, 64.3803633749485, 69.74916368722916, 74.57829415798187, 77.13342905044556, 72.47870162129402, 68.05959954857826, 67.8822934627533, 76.26807868480682, 74.20424222946167, 78.38496789336205, 17.54438627511263, 0.060137005493743345, 0.09321434932644479, 0.1681962379370816, 0.042500014387769625, 0.062120257862261496, 0.1016244113270659, 0.09366863276227377, 0.5762264924123883, 0.3927162301260978, 0.8635622647125274, 26.260162889957428, 53.715380653738976, 26.441525258123875, 61.07621647417545, 15.178244691342115, 0.5127096350770444, 0.14968300791224465, 0.05794351382064633, 0.11321947429678403, 0.061394953227136284, 0.004803379215445602, 0.05360376446333248, 0.026922345787170343, 0.07740792483673431, 0.04628901595424395, 0.09123962794546969, 0.1477224170230329, 0.20010909269331023, 0.12608815915882587, 0.1961148835835047, 0.13590275048045442, 0.16612439911114052, 0.12781973811797798, 0.07515779987443238, 0.18845917016733438, 0.10044847091194242, 0.26890993758570403, 54.82977345585823, 74.82831314206123, 37.48659208416939, 57.46409609913826, 76.17445930838585, 29.438236355781555, 13.177573196589947, 0.5389623669907451, 0.4755294614005834, 0.40608569397591054, 0.177575173729565, 0.5115375760942698, 16.44430920481682, 34.234578385949135, 8.267880398780107, 76.19119361042976, 95.5157558619976, 100.36032870411873, 90.86494222283363, 92.03771889209747, 80.04329770803452, 78.98601964116096, 82.61420175433159, 86.36093750596046, 87.60268807411194, 83.33232522010803, 91.60578846931458, 87.2426649928093, 84.39509019255638, 82.53368407487869, 83.52644920349121, 82.31230035424232, 73.2897301018238, 67.94499769806862, 67.31558427214622, 71.92548170685768, 85.47503784298897, 80.13422682881355, 78.56525301933289, 79.38837245106697, 78.61925572156906, 69.53420162200928, 64.20882537961006, 65.85018530488014, 69.07202482223511, 73.8724972307682, 77.11818426847458, 74.97814670205116, 73.74848708510399, 70.20781427621841, 71.83489456772804, 74.31182965636253, 75.90765282511711, 75.60132846236229, 75.15554398298264, 74.16828095912933, 72.04176306724548, 71.205785125494, 76.01512625813484, 75.0516727566719, 74.7583968937397, 76.14187985658646, 77.45354667305946, 67.54545673727989, 58.78851503133774, 72.2665286064148, 74.51878175139427, 70.65257281064987, 73.17530304193497, 72.12860360741615, 72.37065061926842, 58.734394535422325, 54.73210729658604, 53.366430178284645, 56.337148770689964, 65.61830654740334, 72.76631578803062, 72.13470607995987, 70.1137313246727, 69.2609278857708, 61.87724009156227, 49.017396345734596, 56.26844085752964, 54.53841648995876, 64.30367588996887, 67.97937825322151, 70.8361941576004, 68.99413660168648, 68.89981046319008, 67.27726712822914, 71.71830162405968, 59.3607035279274, 60.510924607515335, 61.72389551997185, 62.3737670481205, 67.15852349996567, 67.06536009907722, 68.5226882994175, 64.42903876304626, 62.98151023685932, 66.575528383255, 64.57242026925087, 62.436072304844856, 61.233942210674286, 64.27714571356773, 65.12276753783226, 60.72796516120434, 55.017547979950905, 59.17690359055996, 61.349003836512566, 67.06904590129852, 67.45073541998863, 67.72979244589806, 63.30421932041645, 62.96976126730442, 59.88866239786148, 61.67321003973484, 61.56471826136112, 60.68155065178871, 63.53041358292103, 65.90926453471184, 68.00542965531349, 71.2920480966568, 71.92243427038193, 73.59287783503532, 68.96758362650871, 67.90340512990952, 67.86488279700279, 68.03446769714355, 74.29768681526184, 76.52733117341995, 79.06989634037018, 73.93379554152489, 70.5154837667942, 72.5041526556015, 83.28524574637413, 79.1712749004364, 83.75602528452873, 21.42287615686655, 0.342922366107814, 0.24300346209201962, 0.3256859566317871, 0.20087228767806664, 0.3217275784118101, 0.26732435391750187, 0.13657193019753322, 1.309412349946797, 0.9951755055226386, 1.0601602122187614, 31.292420960962772, 64.0898385643959, 41.507289335131645, 72.36067995429039, 16.169247664511204, 0.7168032741174102, 0.22968713601585478, 0.2020573936169967, 0.18688927550101653, 0.14188530680257827, 0.07412987339193933, 0.19321373925777152, 0.11951789609156549, 0.16686825372744352, 0.15174598549492657, 0.13132876076269895], [0.044379399478202686, 0.018994959937117528, 0.059732022928074, 0.026934797169815283, 0.14897893241140991, 0.040789141348795965, 0.03210659240721725, 0.004743744402730954, 0.0810216274112463, 0.14224170095985755, 4.902038108557463, 62.6625819504261, 33.4609816968441, 23.11256378889084, 53.06632608175278, 41.27885699272156, 3.4688141522929072, 0.30947653111070395, 0.6218540284316987, 0.09015068208100274, 0.14657903462648392, 0.09097989852307364, 0.1214934783638455, 0.6522366043645889, 2.4282549507915974, 31.632787697017193, 86.89829707145691, 87.35885515809059, 82.75248393416405, 77.31700479984283, 74.10999208688736, 72.85587698221207, 74.9000608921051, 76.17212623357773, 78.42371061444283, 81.03721797466278, 80.39451286196709, 79.63051065802574, 80.55243238806725, 82.1876822412014, 78.92463773488998, 79.95466366410255, 78.05915057659149, 78.77298787236214, 66.46148890256882, 57.409295439720154, 64.89698365330696, 75.29602244496346, 75.26005357503891, 76.00146979093552, 70.70676550269127, 72.51167625188828, 63.20207700133324, 56.695507541298866, 57.22764998674393, 65.48737317323685, 67.50213906168938, 70.62658980488777, 68.64861354231834, 67.1341136097908, 63.47322665154934, 65.15685930848122, 64.81491565704346, 66.04067668318748, 69.00043666362762, 69.15769502520561, 61.80485777556896, 68.58272507786751, 71.88156366348267, 68.21824103593826, 68.51472392678261, 71.38144209980965, 66.52477070689201, 61.39351084828377, 54.347225949168205, 69.3785011768341, 66.62728920578957, 63.189461678266525, 70.11598080396652, 63.145669028162956, 60.862918719649315, 55.86916968226433, 52.2691098600626, 49.64863747358322, 51.70838534832001, 63.63959692418575, 63.64127643406391, 61.90601594746113, 63.822044134140015, 64.57148551940918, 62.190947458148, 64.37592521309853, 56.9220057874918, 48.02651211619377, 46.212193071842194, 50.24591222405434, 54.239752516150475, 60.92386744916439, 60.45307271182537, 63.42407628893852, 63.30933004617691, 60.179168209433556, 62.32317276299, 54.69824731349945, 60.070984214544296, 56.41225554049015, 56.1412350833416, 63.70469503104687, 61.17753803730011, 61.52360066771507, 59.1752240806818, 61.622003987431526, 59.504138231277466, 61.513603404164314, 59.77529548108578, 58.93745183944702, 56.482471972703934, 55.829541608691216, 51.34931221604347, 48.23156051337719, 53.05914826691151, 61.06145426630974, 60.95591492950916, 60.71367412805557, 56.75061598420143, 51.8486662209034, 52.40499436855316, 51.08812563121319, 49.83051471412182, 53.71951103210449, 57.28764496743679, 56.448858976364136, 59.83844809234142, 62.166320979595184, 63.24117690324783, 63.677883669734, 62.64781594276428, 58.90839859843254, 60.18539987504482, 61.90617933869362, 66.03259071707726, 72.04814672470093, 72.4340084195137, 67.83711388707161, 67.39620074629784, 63.540445044636726, 72.52229288220406, 71.2797063589096, 74.81858566403389, 19.296020083129406, 0.3568825498223305, 0.05084552067273762, 0.10224236059002578, 0.11768819778808393, 0.05422750618890859, 0.09083906857995316, 0.31896940141450614, 0.12784609920345247, 0.6674534222111106, 0.3420529549475759, 18.11033360660076, 46.79800383746624, 27.21164893358946, 35.537501871585846, 18.205281011760235, 0.46698734164237976, 0.09400210197782144, 0.0922844086016994, 0.030001123159308918, 0.0413897725957213, 0.03420898545300588, 0.04632684322132263, 0.015424807515955763, 0.02885008550947532, 0.060166268376633525, 0.02826453655870864, 0.008723443133931141, 0.02584205893072067, 0.024340658928849734, 0.01222542186951614, 0.019107053922198247, 0.05051618893048726, 0.036767843848792836, 0.03722591223777272, 0.18363080191193148, 0.09301002122811042, 10.335296262055635, 71.31972581148148, 43.55901584029198, 30.425565876066685, 48.20482514798641, 47.6404794305563, 4.069551229476929, 1.3968419772572815, 0.5166431958787143, 0.2511351741850376, 0.19343035732163116, 0.2245380709064193, 0.3595660667633638, 0.8880884048994631, 3.309521237388253, 34.78381231427193, 86.40019699931145, 90.38675308227539, 87.7318887412548, 81.83756902813911, 79.2605397105217, 77.18709737062454, 75.71043580770493, 78.17901894450188, 82.67954304814339, 83.62622424960136, 82.21111178398132, 81.07320964336395, 82.67341017723083, 86.87108293175697, 81.74098581075668, 82.88019508123398, 79.53801602125168, 80.68096429109573, 68.87252792716026, 60.686870366334915, 66.85729086399078, 76.79916098713875, 77.56595984101295, 78.34204539656639, 76.09832659363747, 74.78277638554573, 65.62920436263084, 60.50246246159077, 59.5654783397913, 67.91699320077896, 69.8996964097023, 72.47159600257874, 71.666609197855, 70.17240777611732, 67.06566408276558, 66.9934831559658, 67.69145250320435, 68.02486941218376, 69.64230582118034, 70.39912641048431, 65.90617150068283, 71.0189263522625, 74.39037144184113, 69.72996711730957, 71.99543595314026, 73.45635116100311, 68.51519510149956, 61.94687895476818, 59.04753193259239, 74.7477650642395, 68.17391261458397, 67.84098207950592, 72.4774856865406, 65.34117221832275, 64.89988669753075, 58.14423680305481, 54.22151729464531, 52.250008285045624, 55.808866918087006, 67.08481505513191, 65.32621622085571, 65.63209220767021, 63.77446308732033, 64.62539702653885, 63.60591173171997, 68.81420105695724, 63.22633109986782, 53.42544101178646, 48.733471781015396, 50.7403264939785, 56.204748675227165, 63.27801592648029, 63.92789885401726, 64.42240431904793, 66.41500979661942, 61.36646769940853, 65.37562876939774, 57.37790532410145, 64.08129662275314, 59.564832374453545, 56.845804676413536, 63.17248418927193, 64.08327251672745, 63.67116943001747, 60.328606590628624, 64.43831026554108, 61.09631359577179, 63.95413264632225, 60.56634843349457, 61.2276915460825, 60.528187081217766, 58.83942469954491, 53.812982216477394, 49.96867910027504, 53.83738070726395, 64.99911457300186, 62.27291285991669, 63.335419446229935, 60.49027271568775, 57.005988880991936, 57.05035910010338, 54.246253967285156, 54.24340412020683, 57.23353587090969, 59.91924695670605, 60.50372779369354, 62.40743324160576, 65.6553165614605, 67.06998825073242, 67.02328875660896, 66.05909809470177, 62.275397926568985, 63.87883588671684, 65.4050163924694, 69.09409403800964, 72.71881833672523, 75.32252222299576, 70.88947489857674, 70.52360773086548, 67.66164690256119, 77.48785123229027, 75.61683923006058, 77.45635852217674, 22.46783148497343, 0.31476676755119115, 0.07747733048745431, 0.12273325832211412, 0.09122211326030083, 0.07552960843895562, 0.2975125762168318, 0.23244868236361071, 0.3233700105920434, 0.5081484548281878, 0.3389829571824521, 19.45561531931162, 58.63461568951607, 27.36651722341776, 42.62062579393387, 28.09335172176361, 0.41491048294119537, 0.11556589292013086, 0.041228385161957704, 0.08561580354580656, 0.06744885962689295, 0.033802232865127735, 0.07364787074038759, 0.04969491717929486, 0.045519034028984606, 0.013431657680484932, 0.06042869921657257, 0.15639433840988204, 0.24798411905067042, 0.2167835331056267, 0.14325295138405636, 0.21582595480140299, 0.16371792589779943, 0.1331234074314125, 0.1081606543448288, 0.35192812036257237, 0.22661949828034267, 9.963169880211353, 89.5092585682869, 45.37116900086403, 37.04122558236122, 66.42793670296669, 62.43659287691116, 10.096148494631052, 4.408920044079423, 3.2400828134268522, 0.5522640876006335, 0.45889496337622404, 0.28213477169629186, 0.8956098044291139, 2.1695581823587418, 3.600192340090871, 38.73862870037556, 94.292411506176, 96.89043089747429, 93.42311695218086, 89.48982641100883, 84.52448844909668, 83.65894809365273, 81.46954357624054, 83.60803842544556, 87.32131317257881, 89.07194763422012, 86.46119132637978, 83.5700024664402, 86.44433543086052, 90.2424368262291, 84.51931312680244, 89.0459494292736, 83.72865155339241, 84.22974586486816, 74.36829462647438, 64.70483556389809, 71.54533490538597, 80.76421782374382, 81.30053624510765, 83.07844564318657, 76.36039853096008, 77.59271040558815, 68.0162438750267, 64.06568706035614, 62.35397011041641, 71.25693038105965, 74.59704995155334, 76.04712814092636, 74.6401396393776, 73.9533568918705, 72.05896094441414, 72.55086734890938, 68.95661741495132, 72.012709826231, 72.30866834521294, 76.10626056790352, 66.48725911974907, 74.25180047750473, 78.09247478842735, 73.12787398695946, 73.74134346842766, 75.42564108967781, 72.86494329571724, 67.7705566585064, 60.92652350664139, 76.12019822001457, 72.09249794483185, 69.14298221468925, 74.2511773109436, 68.87730807065964, 68.71627271175385, 61.56738571822643, 58.81587356328964, 58.47690895199776, 57.56408013403416, 68.69674935936928, 69.99045833945274, 67.56189465522766, 68.57009455561638, 69.99982863664627, 68.84216755628586, 71.83197632431984, 62.99747318029404, 54.21349972486496, 52.8836964815855, 55.33420018851757, 59.62650306522846, 68.1829485297203, 66.35958597064018, 69.92574781179428, 68.0556933581829, 63.004692792892456, 67.25908890366554, 59.6274796128273, 65.38233920931816, 61.84910640120506, 61.37391909956932, 66.89488604664803, 67.09570527076721, 66.17445230484009, 62.92554683983326, 66.63419723510742, 62.89413012564182, 67.93724611401558, 64.51330304145813, 63.84231224656105, 65.59883639216423, 63.57706367969513, 56.8409713357687, 52.53910817205906, 57.132936269044876, 68.3828254044056, 66.17140486836433, 67.60559231042862, 66.61939322948456, 59.727615639567375, 61.338763386011124, 58.34038607776165, 56.83000512421131, 61.17350645363331, 63.40512290596962, 62.50555917620659, 66.34907573461533, 69.64555844664574, 71.48668125271797, 68.71292129158974, 70.93622758984566, 66.52676180005074, 67.68074467778206, 68.86280804872513, 71.45297706127167, 76.15933611989021, 77.50602185726166, 74.97169464826584, 74.88468691706657, 71.08017906546593, 83.48693892359734, 81.63854330778122, 84.66286942362785, 27.28205155581236, 0.6612363620661199, 0.20402239286340773, 0.4245951835764572, 0.375496533815749, 0.24752796540269628, 0.46895818901248276, 0.39481635962147266, 0.9433408244512975, 0.9653330349829048, 0.5591490806546062, 22.49542560428381, 69.07976120710373, 35.73415271937847, 59.9405600130558, 35.23183487355709, 0.569456621306017, 0.18383201299002394, 0.20487032626988366, 0.16765867068897933, 0.14010480546858162, 0.10344564172555692, 0.17553639016114175, 0.2295242642867379, 0.21941710350802168, 0.13872392097255215, 0.13217794097727165], [0.039924706288729794, 0.04221409457386471, 0.011155869251524564, 0.00935305895836791, 0.052776919183088467, 0.06796805129852146, 0.04917156576993875, 0.10356975108152255, 0.08653264536405914, 0.6000564980786294, 32.28889279067516, 50.54141476750374, 24.978993237018585, 33.47355142235756, 65.81308409571648, 21.762260645627975, 0.37838396325241774, 0.33897776214871556, 0.678442195057869, 0.1088299231196288, 0.16738888516556472, 0.221385843178723, 0.37697881052736193, 0.39052947715390474, 3.571527390740812, 50.09252205491066, 84.36385586857796, 79.74226266145706, 79.88522619009018, 75.21115779876709, 75.57061851024628, 76.53249889612198, 79.51638758182526, 80.8872552216053, 79.08619746565819, 82.48706817626953, 76.86304315924644, 82.99801155924797, 79.49230447411537, 80.8587795495987, 78.75272735953331, 77.85868853330612, 78.29504191875458, 77.9222059249878, 71.56487345695496, 60.328135415911674, 57.10960932075977, 67.52122923731804, 72.6801136136055, 74.57903891801834, 74.40204441547394, 68.66960361599922, 61.25607222318649, 56.348475962877274, 58.516206443309784, 66.33270621299744, 68.06585401296616, 68.55361104011536, 70.10990113019943, 65.8510972559452, 64.97737973928452, 67.28783816099167, 69.06264692544937, 69.18645948171616, 67.75652781128883, 67.96801686286926, 66.32810086011887, 69.77795854210854, 68.58036920428276, 68.54311600327492, 71.80207192897797, 59.975145757198334, 61.856208220124245, 57.285505682229996, 68.4087324142456, 68.68391364812851, 66.86769470572472, 70.4409621655941, 62.14932829141617, 61.196681410074234, 60.50771377980709, 51.8540695309639, 48.92989084124565, 50.540700405836105, 63.387393057346344, 65.19829988479614, 61.48448936641216, 62.77212247252464, 61.85114689171314, 61.60183846950531, 63.030280619859695, 58.48016917705536, 60.966721549630165, 58.911145851016045, 49.46500472724438, 45.820977464318275, 47.432512789964676, 50.558829233050346, 61.822002455592155, 61.412658020853996, 59.985883980989456, 60.22175632417202, 60.472307279706, 59.90080274641514, 55.71421019732952, 65.16023352742195, 54.11118641495705, 54.043690636754036, 59.961519688367844, 60.01552999019623, 61.65282033383846, 63.011980801820755, 61.74436882138252, 60.900282114744186, 58.38086910545826, 56.424057707190514, 57.613127902150154, 58.26807975769043, 56.52031794190407, 50.27917183935642, 55.95139726996422, 60.67272752523422, 57.0345139503479, 61.31346434354782, 55.16131706535816, 51.73995405435562, 52.60702572762966, 52.23623402416706, 50.87545104324818, 54.54166531562805, 53.973759189248085, 60.877247750759125, 60.33803008496761, 61.99987851083279, 61.90400205552578, 61.51725880801678, 61.03796772658825, 57.38019660115242, 58.79970543086529, 62.24707804620266, 67.94235303997993, 70.8938218653202, 72.03528061509132, 68.18617075681686, 65.0107191503048, 66.46959006786346, 73.4060038626194, 73.09931471943855, 71.63588404655457, 20.926995165646076, 1.028552558273077, 0.10116608318639919, 0.3070758021203801, 0.17214578459970653, 0.1518677719286643, 0.19735532405320555, 0.6322089477907866, 0.5011187132913619, 0.3051586862420663, 0.46650227392092347, 14.892893303185701, 64.1671796143055, 26.041296534240246, 20.891448073089123, 17.050693966448307, 2.751149511896074, 0.05713883278076537, 0.090416474849917, 0.041772772747208364, 0.07285024752491154, 0.048402144166175276, 0.1411449848092161, 0.008519469411112368, 0.0849054049467668, 0.04371588976937346, 0.08172984409611672, 0.06984141757129692, 0.019316044563311152, 0.029332346057344694, 0.016053409381129313, 0.020178164122626185, 0.05544245017517824, 0.06959356251172721, 0.04590411590470467, 0.09501514097792096, 1.1964973714202642, 46.64400950074196, 60.968822836875916, 38.217547461390495, 23.855480924248695, 62.86439672112465, 28.933045864105225, 0.5852194223552942, 0.21093757648486644, 0.3114004747476429, 0.13860596402082592, 0.2659369236789644, 0.05437079264083877, 0.39974617946427315, 0.34609092108439654, 3.33285269793123, 54.114366844296455, 87.82684564590454, 85.70627063512802, 85.38843289017677, 79.72398564219475, 79.01021674275398, 80.94625845551491, 81.86922892928123, 84.07322466373444, 82.66331031918526, 84.98699963092804, 79.3731352686882, 85.79419031739235, 79.23899486660957, 81.66284680366516, 80.80577239394188, 78.07996585965157, 79.02946650981903, 79.60538640618324, 75.62323048710823, 64.51150953769684, 58.922507241368294, 68.50194901227951, 74.59074229001999, 75.8889502286911, 74.15731474757195, 69.33109492063522, 62.1082790941, 59.29674915969372, 61.55667029321194, 68.17178472876549, 70.05325376987457, 71.06102049350739, 73.03940713405609, 70.64998894929886, 68.46762165427208, 68.87711808085442, 70.52888184785843, 72.78922855854034, 70.82446798682213, 69.69849720597267, 69.34108078479767, 70.2444139122963, 70.37176787853241, 71.49456202983856, 72.51415371894836, 63.85033741593361, 63.20017330348492, 60.61915799975395, 71.19383096694946, 70.95042362809181, 68.3570247888565, 72.17921689152718, 66.02622985839844, 67.36471563577652, 61.54080994427204, 57.51852057874203, 51.81872382760048, 53.550727888941765, 64.84188660979271, 64.52303811907768, 64.811260253191, 65.89418694376945, 64.75747033953667, 63.33055570721626, 66.73195078969002, 63.456997722387314, 64.0076793730259, 63.47750522196293, 54.580377638339996, 47.83603213727474, 49.32594358921051, 55.40351986885071, 63.782898634672165, 62.88306511938572, 63.10040205717087, 61.24641694128513, 62.61898688971996, 62.449079006910324, 58.12844105064869, 65.97918078303337, 56.7057403922081, 57.73517355322838, 61.47077590227127, 61.76200367510319, 63.564471155405045, 65.96689984202385, 62.32691556215286, 62.75156557559967, 60.7086393982172, 59.35225658118725, 60.59871129691601, 59.85086962580681, 59.671112671494484, 54.53299418091774, 59.316975474357605, 64.673722833395, 60.42854502797127, 63.983033895492554, 57.58141100406647, 54.720768705010414, 54.606375843286514, 57.19775699079037, 54.91686478257179, 56.43378898501396, 58.01644966006279, 62.307133823633194, 63.93109068274498, 65.13532966375351, 65.76484948396683, 66.21473014354706, 64.75404292345047, 61.35208547115326, 62.68001161515713, 66.21270105242729, 71.42575532197952, 72.17642784118652, 72.2393448650837, 70.42238876223564, 67.94692799448967, 69.08392578363419, 76.88879817724228, 75.26452973484993, 75.27528315782547, 24.582545310258865, 0.9653094050008804, 0.05447597723104991, 0.2723331976449117, 0.06101227590988856, 0.18408214644296095, 0.1197047985624522, 0.9989197296090424, 0.9882368997205049, 0.23777727299602702, 0.5366124305874109, 15.97663789987564, 74.19047936797142, 30.155217982828617, 29.79623794555664, 33.35943594574928, 2.4537019478157163, 0.028838478319812566, 0.09534439479466528, 0.03398873086553067, 0.07523498323280364, 0.04621243373549078, 0.028972044492547866, 0.01501220494901645, 0.043898138974327594, 0.012762174610543298, 0.03987454452726524, 0.16812763380585238, 0.16088559350464493, 0.18850755819585174, 0.09141071524936706, 0.17601394734811038, 0.14294234773842618, 0.2153367904247716, 0.19324556255014613, 0.2611945109674707, 1.426434670574963, 56.000718623399734, 74.47332099080086, 39.11510489881039, 45.74978448450565, 85.45530930161476, 34.03041914105415, 1.462931118439883, 0.9680893714539707, 2.2450834047049284, 0.273022890323773, 0.8044887939468026, 0.5662205012049526, 1.560738820116967, 0.868314087856561, 3.9527915697544813, 58.775143548846245, 94.40741613507271, 92.80584007501602, 92.6011374592781, 86.93650022149086, 83.53170052170753, 86.41119360923767, 87.57972970604897, 89.29872706532478, 86.27640724182129, 90.24039253592491, 83.03072780370712, 89.90757599473, 84.55698430538177, 85.42868033051491, 82.16689735651016, 80.98187014460564, 82.86875009536743, 82.63162761926651, 75.67309141159058, 67.90874764323235, 61.02291293442249, 73.09793159365654, 79.25347968935966, 79.11360159516335, 79.98424887657166, 73.9993268251419, 65.44328033924103, 63.657512962818146, 64.54138353466988, 72.62753963470459, 72.7690364420414, 73.6743226647377, 74.22275483608246, 74.6745277941227, 71.68069884181023, 73.00997391343117, 76.48649096488953, 75.85032910108566, 73.17226320505142, 71.81551560759544, 72.04390615224838, 76.60787165164948, 72.55562469363213, 73.07393208146095, 75.91317772865295, 66.0840855538845, 65.87967172265053, 63.945020735263824, 72.34693229198456, 75.10415554046631, 71.52654871344566, 75.844447016716, 68.2237659394741, 70.49862787127495, 66.31315246224403, 60.861486196517944, 55.55207669734955, 57.207549065351486, 67.95555353164673, 70.72159230709076, 67.10707426071167, 69.96558487415314, 66.676534563303, 66.97643727064133, 68.34828525781631, 65.02565994858742, 66.37172251939774, 65.9050315618515, 56.03729926049709, 50.33783309161663, 53.28669525682926, 59.9421027302742, 70.05905225872993, 66.39633759856224, 65.48948585987091, 65.42123392224312, 65.14746621251106, 67.37462550401688, 63.67415226995945, 68.14704045653343, 59.06068682670593, 62.061146423220634, 64.32398959994316, 63.20876844227314, 67.59002074599266, 68.95476311445236, 66.01476207375526, 65.35358995199203, 63.55712614953518, 63.86744409799576, 63.382985293865204, 63.118321895599365, 64.32591989636421, 55.53732588887215, 61.92270465195179, 69.72357586026192, 64.33690890669823, 68.51101532578468, 61.730263978242874, 58.784122467041016, 60.2786772698164, 60.58602377772331, 57.9586585611105, 61.50429390370846, 61.22505448758602, 68.80350083112717, 68.5077702999115, 69.22656252980232, 69.03069823980331, 70.51491379737854, 68.70858192443848, 65.39666444063187, 64.49743509292603, 70.03896653652191, 74.10889774560928, 75.16192764043808, 75.07060334086418, 73.07781547307968, 70.48256233334541, 73.3859333395958, 82.13192403316498, 79.96332719922066, 82.86830931901932, 29.607260785996914, 1.6883268300443888, 0.42672226787544787, 0.9634210844524205, 0.2821352466708049, 0.3500732558313757, 0.2466804179130122, 1.4339247811585665, 1.3376898388378322, 0.4390651930589229, 0.6915195495821536, 18.856301978230476, 86.24369859695435, 39.89667735993862, 36.65993884205818, 50.5272301286459, 4.010181315243244, 0.14888362580677494, 0.2146093818009831, 0.08779768802924082, 0.18340910755796358, 0.09692026374978013, 0.2800865034805611, 0.15891323215328157, 0.12698180886218324, 0.09139307439909317, 0.17418916948372498], [1.2219454371370375, 0.1813431762275286, 0.0330881977424724, 0.041305950726382434, 0.005978038961984566, 0.030079408606979996, 0.06423875180189498, 0.051499389883247204, 0.0878431074670516, 13.12202587723732, 51.513178423047066, 34.07132774591446, 24.827998839318752, 44.396517500281334, 61.683898866176605, 6.597714694216847, 0.0835104048019275, 0.28769716853275895, 0.467088392470032, 0.2393079228932038, 0.21019465697463602, 0.38213020598050207, 0.11848113063024357, 0.1049053126189392, 5.5290011409670115, 56.177967712283134, 79.94623571634293, 79.54445287585258, 78.45803797245026, 78.94286915659904, 81.8687653541565, 79.06064763665199, 77.9223883152008, 79.72666829824448, 79.78475198149681, 81.32224828004837, 80.04144340753555, 79.98441606760025, 78.38547706604004, 78.06005492806435, 75.11929392814636, 76.7359171807766, 75.15436604619026, 76.58656999468803, 74.94219303131104, 67.80395686626434, 56.06881856918335, 55.90861916542053, 63.76958414912224, 67.24354773759842, 69.25838202238083, 65.91316312551498, 58.53970058262348, 57.31580525636673, 61.339185163378716, 66.63132458925247, 67.63469874858856, 69.1205558180809, 69.7576068341732, 68.12941700220108, 63.981703966856, 67.78181165456772, 65.17018139362335, 68.68529677391052, 66.17751494050026, 69.45328876376152, 65.63031390309334, 62.59780302643776, 68.10261324048042, 68.86920690536499, 64.07009482383728, 60.56962005794048, 61.33507378399372, 63.51962976157665, 67.17197477817535, 62.7274102717638, 68.86890292167664, 64.41379398107529, 62.20988564193249, 64.09623742103577, 53.98790962994099, 48.82421091198921, 53.09900052845478, 63.58017951250076, 60.237555876374245, 58.64049017429352, 66.98941737413406, 65.36571890115738, 65.19675716757774, 63.671180829405785, 62.73247919976711, 63.58099266886711, 63.71283419430256, 63.0797653645277, 61.118189021945, 50.509667471051216, 50.53622044622898, 54.808479398489, 51.50554843246937, 61.89594268798828, 60.70285990834236, 59.56636369228363, 59.54114444553852, 62.93909311294556, 54.44668561220169, 57.283533588051796, 63.23897682130337, 57.34436832368374, 54.80915956199169, 57.69356198608875, 60.099513083696365, 59.02225948870182, 63.07912319898605, 61.43132641911507, 58.68921495974064, 55.876336097717285, 54.19357359409332, 56.394825875759125, 54.559041783213615, 53.72875213623047, 59.12441700696945, 59.96393635869026, 58.377768471837044, 57.57411539554596, 53.80159802734852, 53.27676258981228, 52.300302386283875, 52.37309128046036, 51.89867153763771, 53.36831107735634, 51.82064272463322, 54.66993123292923, 58.31439547240734, 63.33926483988762, 59.90631625056267, 58.23367640376091, 58.23436416685581, 55.3784754127264, 59.41770426928997, 64.57859873771667, 68.1910040974617, 70.35010904073715, 68.39049339294434, 67.57037580013275, 64.28147748112679, 67.1681597828865, 74.09936025738716, 73.52071210741997, 63.327899649739265, 17.468080669641495, 2.567500378936529, 0.41047401318792254, 0.3972711763344705, 0.0877972278976813, 0.08004850111319683, 0.1036450345418416, 1.209011406172067, 0.19193350482964888, 0.445618653902784, 0.28169800294563174, 10.988226626068354, 65.26464432477951, 38.24880078434944, 17.028292268514633, 14.667741134762764, 14.683298449963331, 2.746373168192804, 0.18464013759512454, 0.07840923048206605, 0.08788192921201698, 0.07369923478108831, 0.05317035764164757, 0.27047667070291936, 1.1098325718194246, 1.1459932127036154, 2.0578904869034886, 0.3315877524437383, 0.021308913310349453, 0.0828214839566499, 0.00397965837692027, 0.03100386671576416, 0.03836405507172458, 0.06273490827879868, 0.03505967222736217, 0.17454425746109337, 21.19234822690487, 65.97050204873085, 46.062131524086, 34.89722102880478, 35.95251940190792, 71.62028968334198, 8.531331662088633, 0.12808205763576552, 0.5394710053224117, 0.40055912802927196, 0.36275816266424954, 0.09775778482435271, 0.07176624436397105, 0.08484274541842751, 0.06305826202151366, 5.722548980265856, 58.38524267077446, 85.05871698260307, 87.80231416225433, 85.01872032880783, 83.29691872000694, 84.03707340359688, 81.38969466090202, 83.00156056880951, 82.88614556193352, 82.54602581262589, 85.46010464429855, 81.81820526719093, 82.42285162210464, 78.81344050168991, 79.77360337972641, 77.02116027474403, 78.27416583895683, 77.94318079948425, 77.06318601965904, 76.52907907962799, 71.23611509799957, 59.11758877336979, 58.80233108997345, 64.52093303203583, 69.8065634071827, 70.4834134876728, 67.02721774578094, 58.361664935946465, 59.588216319680214, 63.50399740040302, 69.60543259978294, 69.81937631964684, 73.6575199663639, 70.94685181975365, 70.85896253585815, 66.09624490141869, 69.99121069908142, 68.1864595413208, 71.97826847434044, 65.32481789588928, 69.4892880320549, 67.61703729629517, 64.99123379588127, 70.25493934750557, 70.89841201901436, 64.88697499036789, 64.4254669547081, 65.15888839960098, 67.28165969252586, 70.85486635565758, 65.97562417387962, 69.93995904922485, 66.95336490869522, 68.31502184271812, 65.47125443816185, 55.778707936406136, 53.74742433428764, 57.03518271446228, 67.67445981502533, 65.06469905376434, 62.613929361104965, 68.36102217435837, 69.34469819068909, 67.85812675952911, 67.03045517206192, 65.41539743542671, 65.55086776614189, 64.9456362426281, 65.8594112098217, 65.14249607920647, 55.00635378062725, 51.34440667927265, 58.219917342066765, 54.986651837825775, 64.38407957553864, 63.897257298231125, 61.799123883247375, 62.99355939030647, 65.74152633547783, 58.73211845755577, 60.57434320449829, 66.51337131857872, 61.18136823177338, 57.23316729068756, 59.68224987387657, 62.55439035594463, 62.97309368848801, 64.35687303543091, 61.133019626140594, 61.9682452082634, 58.28870505094528, 58.29161189496517, 60.57944253087044, 58.531170040369034, 56.96014054119587, 61.76744498312473, 63.61566960811615, 61.42052739858627, 59.400096014142036, 56.24034136533737, 56.787124425172806, 55.28912700712681, 55.42952947318554, 55.79086348414421, 56.340177208185196, 54.4926555454731, 57.99872361123562, 61.572823226451874, 64.18737173080444, 63.377000615000725, 60.9375087171793, 60.1214949041605, 59.40542712807655, 61.87315911054611, 66.21301263570786, 69.68386799097061, 70.34554168581963, 72.94441223144531, 68.70296582579613, 68.24385166168213, 68.56030628085136, 76.77677258849144, 73.74020352959633, 69.45342555642128, 25.156002938747406, 3.519919035024941, 0.3887120762374252, 0.510077029466629, 0.016216334915952757, 0.10794555768370628, 0.07405454540275969, 2.074882462620735, 0.24845798034220934, 0.2680498478002846, 0.38561975467018783, 12.53066835924983, 76.50444880127907, 42.86443971097469, 24.29720152169466, 34.1798385232687, 17.424312718212605, 3.6506531573832035, 0.13259740284411237, 0.03168831426592078, 0.06858313587144949, 0.08877911895979196, 0.06809314028942026, 0.16907736018765718, 0.6579472229350358, 0.840515848249197, 1.2027443549595773, 1.676160714123398, 0.26601461169775575, 0.2252279268577695, 0.1607942202826962, 0.2084435150027275, 0.09407593082869425, 0.15926398598821834, 0.146194631815888, 0.3455700521590188, 23.32479950040579, 82.07565665245056, 53.21679040789604, 40.41552051901817, 59.5632516592741, 86.0464359819889, 11.247947439551353, 0.163019624305889, 0.9198421728797257, 1.0385051742196083, 0.9063002339098603, 0.4443184705451131, 0.4341209458652884, 0.2111538383178413, 0.4860929539427161, 6.884165173396468, 63.46571825444698, 93.6591374874115, 98.55270490050316, 89.83778893947601, 92.28903740644455, 88.93058761954308, 87.22175851464272, 87.40629181265831, 86.05428636074066, 87.88183629512787, 87.8762049973011, 86.79474502801895, 86.46609306335449, 82.5438143312931, 86.09142556786537, 81.38309061527252, 81.22292920947075, 79.90175530314445, 81.06977462768555, 78.26117813587189, 73.42591479420662, 61.541961282491684, 60.31207747757435, 68.35632562637329, 71.17135137319565, 76.11161068081856, 72.53214955329895, 61.16505570709705, 64.20069381594658, 65.84506317973137, 72.00148522853851, 71.24690651893616, 77.26401284337044, 73.60995411872864, 73.94565090537071, 70.29839381575584, 74.95712623000145, 71.0685820877552, 76.09607711434364, 67.28333160281181, 75.88894262909889, 70.20979017019272, 68.86323362588882, 71.86956390738487, 73.11964362859726, 68.2277937233448, 65.13861268758774, 66.51888862252235, 69.62628588080406, 71.85726016759872, 69.24359321594238, 73.32859441637993, 73.03069040179253, 68.12450006604195, 70.16093999147415, 62.333777993917465, 56.7177477478981, 58.987764939665794, 69.85380247235298, 67.56053432822227, 63.55733133852482, 73.31825137138367, 70.98554894328117, 71.8628154695034, 68.78289073705673, 67.98515394330025, 70.06678864359856, 69.94500517845154, 70.62900647521019, 65.99783018231392, 56.34327784180641, 55.57254999876022, 60.73895797133446, 58.1612104922533, 66.67067527770996, 65.39439216256142, 64.82937768101692, 66.22037664055824, 68.17251428961754, 61.13292843103409, 63.78545209765434, 66.7244803905487, 64.22185108065605, 60.32552495598793, 64.21713933348656, 66.8378359079361, 66.41913637518883, 67.80865341424942, 64.48348224163055, 64.93914619088173, 61.38837732374668, 60.63164792954922, 64.13162872195244, 61.73416256904602, 59.344056621193886, 64.68899041414261, 65.63089147210121, 66.72844737768173, 64.84221339225769, 60.948414131999016, 61.490580439567566, 57.87532143294811, 60.73926195502281, 59.90348160266876, 61.59247577190399, 58.677693977952, 61.48655265569687, 64.72606122493744, 70.8617439866066, 69.02317464351654, 65.65460979938507, 64.43354532122612, 62.56882578134537, 65.16857787966728, 71.08636513352394, 72.9435458779335, 74.85965386033058, 76.12652108073235, 73.09078797698021, 72.13374093174934, 71.98053315281868, 84.50448632240295, 80.01653954386711, 82.60812968015671, 32.004113271832466, 5.751104447990656, 1.2082795891910791, 1.0772011103108525, 0.16291515959892422, 0.2955570467747748, 0.18948159733554348, 3.0078872479498386, 0.3777815471403301, 0.5043101857881993, 0.6127113034017384, 15.099522415548563, 85.88632017374039, 54.354814141988754, 34.790636748075485, 46.05472572147846, 29.84087985008955, 4.829200766980648, 0.3155971714295447, 0.2771148848114535, 0.29176835319958627, 0.2995785075472668, 0.1474352800869383, 0.7107424805872142, 2.295680777169764, 2.8427804075181484, 3.9633029932156205], [7.725402507930994, 3.470409116707742, 0.08519372931914404, 0.04429299122421071, 0.09633457564632408, 0.05579668468271848, 0.051169371654395945, 0.1638814655598253, 0.8745368476957083, 33.73268611729145, 57.27875344455242, 27.64822080731392, 24.76502101868391, 49.067097678780556, 47.50631242990494, 3.8270548917353153, 0.22782011510571465, 0.5332274653483182, 0.26297608099412173, 0.6696055911015719, 0.07088868442224339, 0.1532170854625292, 0.1397743122652173, 0.1481613380019553, 4.742163112387061, 58.504810854792595, 85.19796431064606, 73.72198730707169, 85.15230596065521, 80.44120475649834, 82.56025984883308, 80.27793511748314, 77.23049864172935, 77.35729783773422, 77.68874645233154, 81.01495876908302, 79.22197937965393, 76.56083777546883, 73.30055192112923, 78.19131508469582, 75.3438238799572, 77.02511966228485, 75.45010417699814, 75.38518086075783, 75.3657791018486, 70.30369073152542, 57.69361898303032, 57.37845629453659, 55.25919981300831, 58.246014341712, 56.08496390283108, 54.55211095511913, 57.35940791666508, 58.98634381592274, 61.45803518593311, 68.34963038563728, 70.02803072333336, 70.25507614016533, 68.75227198004723, 70.01899480819702, 65.24929314851761, 68.7417009472847, 66.67571380734444, 66.85963913798332, 66.68636083602905, 68.30587953329086, 70.06698623299599, 68.07710140943527, 70.59226244688034, 61.432378962635994, 61.917419135570526, 67.40031212568283, 61.168152540922165, 67.28374198079109, 62.54370532929897, 66.14700257778168, 62.723040506243706, 64.8750588297844, 67.95319005846977, 54.960642233490944, 44.83612731099129, 55.06151542067528, 62.64595024287701, 64.07824918627739, 61.88393533229828, 61.45254448056221, 60.94533629715443, 62.126027941703796, 61.970027312636375, 64.71707090735435, 59.059968665242195, 57.97576904296875, 55.5657559633255, 59.06791403889656, 60.43422192335129, 55.464331805706024, 43.484821021556854, 54.3074344843626, 55.57265639305115, 53.472170904278755, 62.7547612041235, 59.68524031341076, 57.659048438072205, 59.95678134262562, 58.907296657562256, 54.19170789420605, 59.267384335398674, 64.02439087629318, 60.13270050287247, 55.15065483748913, 60.25261826813221, 59.809052869677544, 57.703604847192764, 59.29832607507706, 58.515222296118736, 57.18142166733742, 54.99680869281292, 53.95889438688755, 56.50043360888958, 55.32580263912678, 59.34357404708862, 57.393123507499695, 56.58741474151611, 56.82582914829254, 51.84914119541645, 50.48645071685314, 50.46724654734135, 50.78853450715542, 52.267510145902634, 54.231392964720726, 49.35225337743759, 49.61494468152523, 53.5264889895916, 51.12107366323471, 50.50323061645031, 51.279221177101135, 54.24941159784794, 59.2753829061985, 61.823503375053406, 64.44905608892441, 68.28201681375504, 69.63682651519775, 67.11443826556206, 65.11469677090645, 63.71577523648739, 68.32534968852997, 72.6461586356163, 71.05230376124382, 39.12186473608017, 8.966082483530045, 1.6046207654289901, 0.5531373876146972, 0.23568348144181073, 0.08826512974337675, 0.07431029691360891, 0.10249392638797872, 0.9984237374737859, 0.1264172571245581, 0.36839106352999806, 0.18813744914950803, 7.491583479568362, 67.52430707216263, 43.556089997291565, 38.72603617608547, 12.78967671096325, 17.26990420371294, 17.06704068928957, 0.04916774370940402, 0.055763859490980394, 0.06034504433046095, 0.021255955507513136, 1.502979900687933, 6.570084951817989, 10.272527430206537, 11.569034960120916, 10.433825924992561, 5.680376468226314, 1.6195359150879085, 0.07539045574958436, 0.013860390827176161, 0.016344342402589973, 0.04265126779500861, 0.007705057423663675, 0.0820664971251972, 1.4533101534470916, 46.13294832408428, 67.96636015176773, 42.43673086166382, 29.48354322463274, 50.71577601134777, 58.49352166056633, 4.254656871780753, 0.10658460727427155, 1.287591545842588, 0.9081542969215661, 1.1592383519746363, 0.11153536310303025, 0.09290289963246323, 0.12764462095219642, 0.07829108799342066, 4.122545085847378, 62.10242360830307, 93.34722742438316, 81.93602174520493, 89.07035171985626, 85.78624114394188, 84.6866637468338, 85.17149493098259, 80.5118277668953, 81.29986748099327, 83.33601862192154, 83.38008105754852, 80.9988172352314, 79.50586214661598, 74.50365856289864, 77.93142423033714, 77.38160893321037, 79.70962241292, 78.33586692810059, 77.01904758810997, 78.0632695555687, 73.00612092018127, 60.78501150012016, 59.076896756887436, 57.23902277648449, 60.849756225943565, 57.455352768301964, 58.16802352666855, 58.554280400276184, 61.872843727469444, 64.79990646243095, 67.86722347140312, 70.60561493039131, 70.07873520255089, 72.03677773475647, 73.17354753613472, 68.87249752879143, 71.3582481443882, 71.00548267364502, 69.691231995821, 68.82381454110146, 69.8708027601242, 70.62595143914223, 70.29875099658966, 70.88937610387802, 63.93390253186226, 65.81154137849808, 67.96280354261398, 63.529467433691025, 71.41837611794472, 64.98488053679466, 68.03944543004036, 65.85483625531197, 68.63922044634819, 70.65249681472778, 57.07913875579834, 49.62547391653061, 59.7064545750618, 66.3532555103302, 67.91775315999985, 63.55815589427948, 65.42920589447021, 62.87041559815407, 66.96107089519501, 64.99658390879631, 65.62763124704361, 61.11979253590107, 60.522605180740356, 56.026333048939705, 61.45919792354107, 59.476715102791786, 58.7513530254364, 47.32623629271984, 55.47541581094265, 60.28136372566223, 54.20423962175846, 64.02802348136902, 63.647926077246666, 62.203623577952385, 60.63917152583599, 64.48607370257378, 57.3100333660841, 61.50363273918629, 64.75723475217819, 64.38493832945824, 59.79639574885368, 61.938994377851486, 59.59296226501465, 61.1193061619997, 61.62785567343235, 61.919828206300735, 60.19203431904316, 58.185255602002144, 59.72655929625034, 57.81640939414501, 56.05744577944279, 62.71256826817989, 60.29389925301075, 60.074369832873344, 59.704839661717415, 54.20142777264118, 53.52016232907772, 53.204205483198166, 54.963868260383606, 57.26555295288563, 56.72269508242607, 52.687695398926735, 52.76396490633488, 54.99810442328453, 52.53326028585434, 53.53594668209553, 54.73889373242855, 57.14231416583061, 60.96259117126465, 63.068867549300194, 67.11858004331589, 69.99541327357292, 70.89568376541138, 68.2852466404438, 68.59629034996033, 64.36014086008072, 71.70032858848572, 75.93706324696541, 75.76027393341064, 60.47612227499485, 20.140416473150253, 2.47613784391433, 0.29107328737154603, 0.4392039153026417, 0.08647777096484788, 0.12393109951517545, 0.189881807891652, 1.602049965877086, 0.20953220111550763, 0.38487437122967094, 0.28812532837036997, 9.035218823701143, 76.38434484601021, 50.00538893043995, 43.94494593143463, 20.47548819333315, 29.843309819698334, 21.28465287387371, 0.05190774179936852, 0.04389551548229065, 0.08448708598734811, 0.07525582273956388, 0.7592987094540149, 3.5796214314177632, 5.919931763783097, 7.1895951591432095, 8.25320178642869, 13.72174484655261, 4.689004914835095, 0.2270175120793283, 0.122275642643217, 0.22740765911294147, 0.24017595365876332, 0.06469996689702384, 0.22539744823006913, 2.2856177296489477, 58.413167372345924, 84.53740015625954, 44.770003259181976, 39.08156409859657, 65.36592409014702, 68.00451770424843, 5.959712779149413, 0.34829017182346433, 3.5193445533514023, 2.332541411742568, 2.732137944549322, 0.5399345804471523, 0.3080866963136941, 0.31010569422505796, 0.2812722773524001, 4.671975653618574, 69.8791091144085, 101.5394814312458, 89.16690453886986, 93.53006601333618, 90.75765118002892, 90.20354211330414, 92.91512221097946, 85.260508954525, 86.63874819874763, 85.38894206285477, 87.87796810269356, 86.70035809278488, 83.14292818307877, 79.17689099907875, 82.34104961156845, 82.77467474341393, 82.23550647497177, 82.43776962161064, 79.30571928620338, 81.10477074980736, 75.49364224076271, 65.70440992712975, 60.57902455329895, 60.01666232943535, 63.344037383794785, 61.58961832523346, 61.125895008444786, 61.6074013710022, 65.0484511256218, 66.49792894721031, 72.58566588163376, 73.83126184344292, 72.63833105564117, 74.08546060323715, 76.77728936076164, 73.10173138976097, 74.91068512201309, 73.71814951300621, 72.75373846292496, 72.17129811644554, 72.35317915678024, 73.61294835805893, 74.3402749300003, 75.96582010388374, 67.59586483240128, 68.67500692605972, 71.77231952548027, 66.80685997009277, 74.46515902876854, 66.22779384255409, 69.35314893722534, 68.70986625552177, 71.90616354346275, 72.60083466768265, 61.048451364040375, 50.74814647436142, 61.26960709691048, 68.19454550743103, 72.00009450316429, 65.37054464221, 69.84855115413666, 67.11639136075974, 70.4051148891449, 67.70266950130463, 71.65401667356491, 65.91513141989708, 65.49285247921944, 62.59434901177883, 66.16183698177338, 66.40859574079514, 60.630154609680176, 50.10977692902088, 60.62352776527405, 61.708988919854164, 59.634532034397125, 66.58175244927406, 66.09384343028069, 62.719814479351044, 63.57696868479252, 66.80016472935677, 58.786455541849136, 65.55093616247177, 68.97790387272835, 65.61323761940002, 61.982589438557625, 65.82258358597755, 64.67889055609703, 63.251151368021965, 63.73446263372898, 64.87759709358215, 64.96837422251701, 60.62274880707264, 61.788507252931595, 63.253286853432655, 60.23095183074474, 65.38688376545906, 64.80079561471939, 63.55125166475773, 64.89869356155396, 58.1425990909338, 57.62440949678421, 55.6985018402338, 57.379524037241936, 60.734831392765045, 61.04153573513031, 55.202738642692566, 54.859902039170265, 60.17527721822262, 57.91387416422367, 58.92879210412502, 58.83229248225689, 61.166780814528465, 66.11113250255585, 68.1972661614418, 70.14546722173691, 74.08432826399803, 75.61842754483223, 70.79104498028755, 70.68373113870621, 68.24852541089058, 75.15702590346336, 83.55509206652641, 85.3310863673687, 75.3122627735138, 29.007582664489746, 1.9283079402521253, 0.9596564364619553, 0.916959255700931, 0.2837085700593889, 0.35784155305009335, 0.7714914239477366, 3.255855767056346, 0.36342900479212403, 0.8754669665358961, 0.44581431371625513, 11.900243237614632, 86.51132583618164, 62.33205668628216, 54.99175876379013, 29.805230163037777, 48.261191323399544, 24.608649909496307, 0.15397609473438933, 0.2152233012020588, 0.20055117522133514, 0.15172358747804537, 2.2663684375584126, 10.007701590657234, 15.32985845580697, 16.241329796612263, 17.90854923427105], [15.9408875182271, 13.858615402132273, 2.068419009447098, 0.04731877925223671, 0.6119550846051425, 0.4247150255832821, 0.6003006943501532, 0.19708460342371836, 7.023995295166969, 50.38150794804096, 36.214279755949974, 16.281581036746502, 27.46540691703558, 46.31237089633942, 46.30094490945339, 5.105423144996166, 0.3799271851312369, 0.6144405668601394, 0.13746105280006304, 0.1741695767850615, 0.18002475087996572, 0.06820744587457739, 0.08949413371738046, 0.15834783436730504, 4.543004874140024, 59.629694893956184, 69.75723445415497, 80.93377992510796, 83.61627638339996, 85.05603432655334, 83.56884732842445, 81.67909473180771, 77.58707910776138, 77.10391983389854, 74.55367907881737, 81.20870277285576, 78.54351058602333, 80.8761978149414, 72.74884432554245, 68.37989956140518, 70.016920119524, 75.41329175233841, 75.95841810107231, 76.98532059788704, 73.72635707259178, 70.35415202379227, 61.11530497670174, 58.07815074920654, 58.717664033174515, 59.8860215395689, 56.33204564452171, 55.62006264925003, 59.25081342458725, 59.99910347163677, 65.4073266685009, 67.8282755613327, 68.88890504837036, 67.50596925616264, 68.03634479641914, 67.30036228895187, 65.33348143100739, 66.51483803987503, 68.46863240003586, 65.849888920784, 65.62509298324585, 67.41059437394142, 67.68402010202408, 66.59872233867645, 61.985127702355385, 59.37267288565636, 67.24722594022751, 61.00395195186138, 62.80299201607704, 63.98227393627167, 62.4538591504097, 64.88688379526138, 66.0736133158207, 68.19969803094864, 56.18061996996403, 45.91710850596428, 54.31117348372936, 64.768907725811, 64.37601640820503, 60.7033234834671, 55.103282779455185, 54.11970175802708, 51.48358181118965, 54.84673194587231, 57.0879390835762, 55.44709973037243, 52.71161511540413, 50.39202578365803, 50.50252005457878, 54.29828457534313, 53.576247319579124, 59.09838080406189, 48.572626411914825, 42.64950044453144, 58.82084749639034, 54.2176529020071, 58.53933200240135, 60.0785306096077, 60.16700126230717, 57.358195781707764, 58.88291336596012, 57.06896290183067, 52.348153218626976, 59.36186246573925, 60.607317835092545, 59.86007273197174, 58.24425123631954, 59.65039998292923, 58.46749305725098, 57.77957037091255, 56.421785429120064, 55.45746937394142, 56.6398861259222, 54.687995463609695, 54.36544977128506, 56.112341433763504, 59.692706912755966, 57.07992531359196, 58.277738839387894, 53.931380063295364, 52.38774709403515, 52.9403780400753, 51.196666806936264, 52.81476438045502, 52.68347382545471, 51.43812105059624, 51.37552320957184, 48.91922861337662, 47.94201225042343, 47.730337008833885, 47.202929109334946, 51.690906286239624, 55.711238756775856, 60.73304168879986, 63.76350447535515, 67.16168493032455, 65.8819591999054, 69.20841470360756, 64.42064881324768, 63.98259311914444, 64.71188798546791, 68.57048213481903, 70.92054203152657, 50.141414031386375, 15.999638065695763, 7.6395047921687365, 5.983642945066094, 1.9815819128416479, 0.2344192922464572, 0.025782542397791985, 0.06730862340191379, 0.41023136058356613, 0.2868687832960859, 0.09636576811317354, 0.21822215669089928, 0.09254002652596682, 7.586260624229908, 78.67057576775551, 37.01683849096298, 35.88493622839451, 36.29814885556698, 21.51084143668413, 42.67894506454468, 1.848732135258615, 0.24946955731138587, 0.058181171771138906, 0.21406762883998454, 10.248014945536852, 21.15658074617386, 25.31908828765154, 38.02402384579182, 24.83864016830921, 16.604506708681583, 10.55213637650013, 1.42132073873654, 0.06116764823673293, 0.3998882562154904, 0.013775552215520293, 0.3062217979459092, 0.5851935956161469, 11.100004278123379, 62.594318613409996, 50.68136125802994, 26.68514348566532, 35.160562098026276, 59.8486353456974, 53.19275289773941, 5.996120050549507, 0.4568889085203409, 0.9588312869891524, 0.1888248263276182, 0.3727355960290879, 0.06011145705997478, 0.1136979517468717, 0.07087647609296255, 0.14025513490196317, 4.547780742868781, 65.39212748408318, 86.20620220899582, 84.37368974089622, 89.6811081469059, 87.28979006409645, 86.82193636894226, 85.13071551918983, 81.67837277054787, 81.62378489971161, 80.65279260277748, 83.94954890012741, 82.08273947238922, 81.63797333836555, 73.71491968631744, 72.29796811938286, 71.87657833099365, 77.11252257227898, 76.90734878182411, 79.12836000323296, 74.89888295531273, 72.97326788306236, 60.66200070083141, 60.17647035419941, 60.722147673368454, 64.17828261852264, 59.70181122422218, 57.8663919121027, 59.61974322795868, 63.27175386250019, 66.5967008471489, 69.59711864590645, 69.81052279472351, 70.30253559350967, 69.73124384880066, 70.58310493826866, 68.7716281414032, 67.02215641736984, 69.66274872422218, 67.94434413313866, 66.35552018880844, 68.21866661310196, 70.60776561498642, 70.0954619050026, 64.84060987830162, 63.95667091012001, 72.18319907784462, 64.5510122179985, 67.06653043627739, 66.69201493263245, 64.37647238373756, 66.84286683797836, 67.56491929292679, 67.4970169365406, 58.73510129749775, 50.18861509859562, 57.92040601372719, 71.07056558132172, 67.20721408724785, 61.51879012584686, 58.41425031423569, 57.12659440934658, 55.12315571308136, 58.068282678723335, 60.724085569381714, 57.070216834545135, 56.09828218817711, 52.92114347219467, 54.544925540685654, 57.63515152037144, 56.21784657239914, 60.32709427177906, 53.899378180503845, 46.702925339341164, 59.68289203941822, 59.293823316693306, 58.97601597011089, 63.101728186011314, 63.48532900214195, 60.76461419463158, 59.99841570854187, 58.47956120967865, 56.621700301766396, 62.10705175995827, 61.41726337373257, 62.52098634839058, 59.873968586325645, 61.02141961455345, 60.455219596624374, 60.30062109231949, 57.13618129491806, 58.341830000281334, 59.66757506132126, 59.34554234147072, 57.5991902500391, 59.84896592795849, 61.84401847422123, 60.91144971549511, 59.88251432776451, 57.11475044488907, 55.03482185304165, 56.15387700498104, 53.90486888587475, 57.38420158624649, 56.270504146814346, 53.43325339257717, 54.19511251151562, 52.35053949058056, 50.43331056833267, 49.5223056524992, 50.50350800156593, 53.841993659734726, 59.83155146241188, 62.189560532569885, 66.79406225681305, 68.07126492261887, 64.35384079813957, 70.49895465373993, 68.6779023706913, 64.6011771261692, 66.9391156733036, 72.64133289456367, 73.85422021150589, 66.55028253793716, 39.23653498291969, 14.738098159432411, 8.540481571108103, 2.2431564331054688, 0.28208347444888204, 0.01775255277607357, 0.04632915501133539, 0.5568243772722781, 0.5950744904112071, 0.302531038178131, 0.2562008664244786, 0.16169472743058577, 9.286261852830648, 87.63888493180275, 42.22174219787121, 45.27583971619606, 43.984102830290794, 34.91966262459755, 53.571429178118706, 1.8115481617860496, 0.09221782311215065, 0.029716303579334635, 0.19341161067131907, 6.501721395179629, 22.152929082512856, 22.789001651108265, 23.480974920094013, 20.38484215736389, 28.297925144433975, 22.623254545032978, 4.850166141986847, 0.3993957373313606, 0.9530468692537397, 0.5182158364914358, 1.3257589540444314, 0.7867006422020495, 13.30162514001131, 78.61630707979202, 58.68748985230923, 28.575141169130802, 44.706390872597694, 64.50321838259697, 64.79304403066635, 7.441311227157712, 0.5306897358968854, 2.075686831958592, 0.8596256759483367, 1.1607886687852442, 0.30661513621453196, 0.4058373119914904, 0.12961450353031978, 0.4369252547621727, 5.804766593500972, 71.51862233877182, 88.34139123558998, 88.470379114151, 92.3567421734333, 93.95135700702667, 92.42516130208969, 90.31746000051498, 88.01894053816795, 85.54782673716545, 85.07206946611404, 87.59025514125824, 87.09796875715256, 87.34876289963722, 77.63315543532372, 76.29941940307617, 73.69299486279488, 80.50640165805817, 81.6459073126316, 82.70119428634644, 77.61329770088196, 74.9970468878746, 65.40676429867744, 64.2701768875122, 64.21428188681602, 66.59274145960808, 62.28401966392994, 60.65818190574646, 62.040661722421646, 65.89275062084198, 68.84779125452042, 73.83878543972969, 75.16570463776588, 73.5591584444046, 70.2697965502739, 74.9528780579567, 72.19480365514755, 72.40041822195053, 73.84038135409355, 71.66739195585251, 68.30271810293198, 69.34180274605751, 72.60970339179039, 72.9077897965908, 67.93920680880547, 65.1823103427887, 73.99111166596413, 67.8883883357048, 68.16002815961838, 69.25359427928925, 64.55428764224052, 69.23758193850517, 69.67075109481812, 73.09179112315178, 64.3124458193779, 53.07033106684685, 60.25770619511604, 72.92263180017471, 71.72842428088188, 67.41234987974167, 61.50368593633175, 61.724872067570686, 57.92973831295967, 60.34975625574589, 63.23920860886574, 60.4568725079298, 59.63795565068722, 56.85322567820549, 57.19919711351395, 61.39270909130573, 59.127206057310104, 66.03174716234207, 55.03810487687588, 50.44883273541927, 63.896246552467346, 59.72399063408375, 66.36501207947731, 66.52525708079338, 65.61091974377632, 60.013219714164734, 61.49647392332554, 62.78110899031162, 58.294625133275986, 63.97249326109886, 67.73867636919022, 63.860118091106415, 64.30683732032776, 65.17075136303902, 63.243844360113144, 63.9114685356617, 61.117189675569534, 62.20413655042648, 62.26181745529175, 64.68125402927399, 59.64009493589401, 61.32360979914665, 65.36171391606331, 64.90195378661156, 64.1464327275753, 60.36258816719055, 59.857599064707756, 61.141261383891106, 57.22782477736473, 60.00417619943619, 59.52244184911251, 59.391227290034294, 58.11365984380245, 55.68137615919113, 53.937083557248116, 53.20335432887077, 54.13044758141041, 57.3183549195528, 62.13742733001709, 65.60671716928482, 70.92171236872673, 74.00374978780746, 68.09078067541122, 74.611846357584, 71.27423465251923, 70.20762428641319, 70.37175267934799, 77.83160358667374, 82.73439690470695, 78.50048929452896, 57.98634007573128, 24.337355867028236, 7.540453132241964, 2.0478283893316984, 0.5879610939882696, 0.12943362729856744, 0.4273094848031178, 0.9747357491869479, 1.6894399328157306, 0.35464340122416615, 0.6384010124020278, 0.40339695231523365, 12.178615350276232, 97.45191156864166, 53.877544552087784, 55.97508519887924, 57.37566724419594, 49.3533743172884, 61.06189124286175, 2.157799950800836, 0.2651845937361941, 0.12427579000359401, 0.48757107462733984, 13.69611332193017, 36.793079897761345, 38.8551190495491, 47.37906485795975, 36.37437276542187], [21.723048649728298, 23.281755410134792, 5.754155684262514, 0.8982890762854367, 3.8210405269637704, 2.794620841741562, 2.3088057478889823, 0.4131363640772179, 14.421208463609219, 61.2884046882391, 26.20296075940132, 16.349295303225517, 30.594755597412586, 32.20334418118, 46.95376127958298, 4.171038558706641, 0.11966219928581268, 0.07834070056560449, 0.18130088865291327, 0.16330542537616566, 0.3084735927404836, 0.1324275103979744, 0.4410691699013114, 0.04503985896008089, 6.582741122692823, 58.037789314985275, 60.1475615054369, 87.57837697863579, 77.93742030858994, 84.57408338785172, 76.47196814417839, 83.20750191807747, 74.35771599411964, 76.36477589607239, 73.78524631261826, 80.96334993839264, 75.58093875646591, 79.21237349510193, 71.5971565246582, 68.10349479317665, 67.30568960309029, 76.3234493136406, 76.31510496139526, 74.59693595767021, 75.02164676785469, 68.84475901722908, 61.8898706138134, 54.3396757543087, 56.56830556690693, 58.70354779064655, 58.191886246204376, 55.39837494492531, 59.59773100912571, 65.94729289412498, 66.24303102493286, 67.56323218345642, 68.40725049376488, 68.89878451824188, 67.56656840443611, 66.34644627571106, 66.04340493679047, 64.79447275400162, 62.0321349799633, 66.61126166582108, 63.17936182022095, 63.57251152396202, 64.6506504714489, 63.25404681265354, 62.35521264374256, 67.1888230741024, 64.20730546116829, 59.892234206199646, 66.15489095449448, 61.0265227407217, 65.61817735433578, 65.77200829982758, 66.13143101334572, 58.13079312443733, 48.30075100064278, 52.512889578938484, 60.810223147273064, 65.66308334469795, 61.25820770859718, 56.09161354601383, 51.88643999397755, 54.29540053009987, 54.775694757699966, 57.410454377532005, 56.52705878019333, 58.65435943007469, 58.286607563495636, 54.68357250094414, 57.07686647772789, 57.19061717391014, 55.91093324124813, 57.768379971385, 58.47375892102718, 48.98294359445572, 49.07947361469269, 62.74757578969002, 53.84647361934185, 56.747044175863266, 62.03044407069683, 56.91254049539566, 56.32441185414791, 61.66754454374313, 53.51409785449505, 58.97819325327873, 58.15586797893047, 58.42109754681587, 61.34431108832359, 57.611243203282356, 60.23488461971283, 58.53095345199108, 55.95091089606285, 55.49253769218922, 55.59391625225544, 52.42864429950714, 51.31868585944176, 57.14561618864536, 60.25694243609905, 59.65358801186085, 56.60187676548958, 53.05199705064297, 50.84659159183502, 50.75188547372818, 54.04052160680294, 54.0999124199152, 50.29408983886242, 50.716657564044, 48.60495887696743, 52.261149287223816, 48.77002961933613, 46.50982350111008, 50.53327180445194, 54.376955553889275, 57.315778657794, 62.859437987208366, 66.06222152709961, 64.71388667821884, 67.68386051058769, 65.00001132488251, 65.06105124950409, 62.5667092949152, 64.68957558274269, 65.55459916591644, 59.792846739292145, 29.309428967535496, 8.423700537532568, 9.763922821730375, 13.352865390479565, 4.786380864679813, 0.3015965851955116, 0.04837738240894396, 0.11462116861366667, 0.06255741624045186, 0.3403354767942801, 0.11948426195885986, 0.3438242239644751, 0.28460443136282265, 10.22961063310504, 76.83023571968079, 46.86277136206627, 27.34575893729925, 58.03336255252361, 32.82073125243187, 56.276728212833405, 7.71063887514174, 0.3724919934757054, 0.08801512245554477, 1.6613121796399355, 18.815587162971497, 38.721415624022484, 35.0593127310276, 48.2274529337883, 37.649698331952095, 26.63808111101389, 23.837925866246223, 6.853772504255176, 1.2090422795154154, 1.102955297101289, 1.474748128093779, 1.13065391080454, 0.31336716609075665, 22.4257867410779, 76.48195400834084, 35.24034261703491, 23.097349405288696, 33.379168286919594, 38.3017585426569, 53.442414700984955, 4.106219261884689, 0.1247658152715303, 0.06596172926947474, 0.12381822627503425, 0.2443021017825231, 0.6716225109994411, 0.15545233036391437, 0.2892319002421573, 0.008431224341620691, 5.356194488704205, 68.65610674023628, 71.98754757642746, 90.37213146686554, 83.19884598255157, 85.42355060577393, 80.58244317770004, 86.71713799238205, 78.67835015058517, 79.44208636879921, 78.14132496714592, 83.35843741893768, 77.88587987422943, 80.7637694478035, 72.70084530115128, 70.91306403279305, 67.97420293092728, 78.71736645698547, 77.5498715043068, 76.59028619527817, 75.05144476890564, 73.54803264141083, 64.78403091430664, 58.477497920393944, 58.90247091650963, 58.94686013460159, 60.132784098386765, 56.36197283864021, 62.922438606619835, 67.93011769652367, 65.8142240345478, 69.63587656617165, 69.91033583879471, 70.32107099890709, 69.79706391692162, 69.08406257629395, 68.27589154243469, 65.6779633462429, 65.52363082766533, 68.77033621072769, 67.10385963320732, 66.78264766931534, 68.56456965208054, 66.2379164993763, 66.12483456730843, 69.15032342076302, 66.98624834418297, 63.45533721148968, 68.19902926683426, 63.15208688378334, 68.96748483181, 66.73936799168587, 69.06054183840752, 58.34263935685158, 53.85180473327637, 57.83155158162117, 62.9946119338274, 68.71191814541817, 63.668881952762604, 59.43673364818096, 55.17814256250858, 59.039122983813286, 59.09815661609173, 60.5858413875103, 59.8601259291172, 61.67108595371246, 59.23734314739704, 60.51538176834583, 61.04975089430809, 58.62834982573986, 57.20697909593582, 58.451507315039635, 60.8997767418623, 52.84418240189552, 51.97043068706989, 63.36817368865013, 58.17789539694786, 58.49508337676525, 65.6486289203167, 59.108024686574936, 58.60969662666321, 64.840769469738, 57.42800943553448, 60.9756700694561, 60.06064496934414, 59.64090049266815, 63.23531001806259, 59.67819169163704, 61.96884177625179, 60.29965214431286, 62.4441734701395, 59.78151574730873, 59.181052967906, 54.90952357649803, 54.75304037332535, 59.65005800127983, 61.41219824552536, 62.22726210951805, 58.73600944876671, 56.01067788898945, 54.48062539100647, 54.92670625448227, 56.79169178009033, 56.35972335934639, 54.262589290738106, 53.258743956685066, 52.05680005252361, 53.57691988348961, 50.777040123939514, 50.53508050739765, 51.718853786587715, 56.609103977680206, 59.39885728061199, 64.9753886461258, 67.80742228031158, 66.60994693636894, 68.29832553863525, 66.87484592199326, 66.37806057929993, 64.46477204561234, 66.36758834123611, 67.87159323692322, 67.88535609841347, 47.80397325754166, 18.473702408373356, 12.459866758435965, 15.474650636315346, 5.249957889318466, 0.1844008988700807, 0.06227972684428096, 0.36820285487920046, 0.2814846206456423, 0.6029586517252028, 0.07895249742432497, 0.5144867522176355, 0.35547956416849047, 12.048880811780691, 83.34928750991821, 55.00515304505825, 36.33488528430462, 74.3359811604023, 44.67984549701214, 69.9736100435257, 9.765662178397179, 0.39776915742550045, 0.22089782170951366, 1.8166118650697172, 18.95822960883379, 40.09791076183319, 43.06551732122898, 49.0439835190773, 40.540393218398094, 41.7212900519371, 36.486132368445396, 16.501646228134632, 4.3405883107334375, 6.095994366332889, 4.1307825688272715, 4.5083103608340025, 0.2943571127252653, 28.28313823789358, 93.61165523529053, 44.975807815790176, 27.410416267812252, 45.40421582758427, 48.98649640381336, 68.08207154273987, 5.682958429679275, 0.16959582455456257, 0.23887844203272834, 0.3779283439507708, 1.1289487523026764, 1.1738871596753597, 0.4450475861085579, 0.6799703661818057, 0.15562916931230575, 7.053418541327119, 75.12822344899178, 78.41129288077354, 92.88081765174866, 89.03357729315758, 91.32186010479927, 85.79983681440353, 92.82461866736412, 85.15938118100166, 84.4255493581295, 82.57294356822968, 88.9628478884697, 85.61464995145798, 85.41076809167862, 77.68386751413345, 73.67733210325241, 70.86130321025848, 83.8608768582344, 83.06065499782562, 81.54545590281487, 78.97407308220863, 77.0653747022152, 66.31379082798958, 62.5288937240839, 59.26855847239494, 64.88691419363022, 62.030858248472214, 59.674483090639114, 66.33467450737953, 71.05020627379417, 69.09553036093712, 72.84869536757469, 72.22551360726357, 73.19507718086243, 71.08346208930016, 73.11988681554794, 69.89717334508896, 69.15683627128601, 68.28571021556854, 71.30086362361908, 68.84496420621872, 71.29396319389343, 71.48454576730728, 69.37514975667, 67.22429797053337, 72.58619785308838, 69.01600062847137, 64.93768706917763, 71.99549674987793, 66.06156796216965, 69.67869266867638, 70.74810728430748, 71.8412934243679, 65.0482003390789, 56.923168525099754, 60.969088822603226, 66.16505920886993, 71.26209050416946, 65.95755234360695, 62.98129744827747, 58.06093767285347, 62.690582647919655, 60.232676938176155, 63.739482164382935, 60.879478231072426, 64.27487343549728, 63.43260683119297, 62.65031240880489, 63.17849166691303, 62.62308306992054, 61.49063363671303, 61.29193849861622, 64.79494392871857, 55.98522685468197, 55.966957435011864, 67.45072782039642, 59.99241963028908, 64.0710599720478, 69.46925550699234, 61.045046746730804, 61.78021229803562, 67.28060334920883, 60.2865694463253, 64.28892508149147, 64.10953670740128, 62.73105427622795, 66.80471688508987, 63.27649600803852, 68.20789039134979, 63.316906839609146, 65.68621650338173, 64.01106879115105, 62.13142745196819, 60.66488474607468, 57.08990357816219, 62.0707219094038, 64.73894253373146, 68.25307756662369, 64.11466643214226, 59.15474697947502, 58.587802201509476, 58.77427339553833, 60.56325539946556, 61.28422871232033, 56.895103231072426, 56.98950156569481, 55.58989606797695, 57.9999965429306, 53.87371055781841, 53.015310019254684, 56.84635564684868, 59.458251893520355, 62.44458384811878, 66.83923423290253, 73.43076333403587, 69.64494287967682, 70.49135506153107, 71.02043867111206, 70.5974605679512, 68.493961840868, 72.28978335857391, 72.63493403792381, 78.11016663908958, 62.06369988620281, 35.36143071949482, 21.596770025789738, 17.67645388841629, 5.974768046289682, 0.8888291870243847, 0.09358877025078982, 1.0370000987313688, 0.559907021233812, 1.176129395607859, 0.21794545435113832, 0.6162623316049576, 0.48617467924486846, 15.468075089156628, 94.39457282423973, 66.92277655005455, 46.55110828578472, 76.63656011223793, 54.44761276245117, 81.33715108036995, 12.361168004572392, 0.6565745465923101, 0.3757670318009332, 5.918768076226115, 26.674445159733295, 59.974796175956726, 63.13276872038841, 72.61041775345802, 65.17335802316666], [25.8849311247468, 29.326254464685917, 7.559660151600838, 3.7744172662496567, 6.662136912345886, 6.907560518011451, 2.4368562642484903, 0.4942717478843406, 33.91196429729462, 56.7426136136055, 30.99454164505005, 24.03257232159376, 51.654831022024155, 46.00070782005787, 45.75980834662914, 6.793742850422859, 0.5957316176500171, 0.564235404599458, 0.1231657226162497, 0.8088823081925511, 0.26848219335079193, 0.4868299956433475, 0.20287981198634952, 0.28025197272654623, 7.052202606573701, 60.458495020866394, 66.09046921133995, 86.86097547411919, 77.38047659397125, 83.57097521424294, 76.37578770518303, 84.23524796962738, 77.3246043920517, 77.09192767739296, 70.2475905418396, 77.9537746310234, 74.76513013243675, 77.68658816814423, 71.66090950369835, 63.49013574421406, 66.08040735125542, 74.59460288286209, 71.56323954463005, 76.36055052280426, 72.30850875377655, 71.35105893015862, 61.89846195280552, 55.654401406645775, 59.694420620799065, 54.98907990753651, 53.80179941654205, 59.343300461769104, 67.13561072945595, 66.58031612634659, 67.95312166213989, 64.75687757134438, 67.55964517593384, 69.787617623806, 69.84002441167831, 65.52227810025215, 64.41233485937119, 63.96668717265129, 62.65295326709747, 57.007968574762344, 64.79649424552917, 61.636272221803665, 65.06141602993011, 64.40972819924355, 66.54112502932549, 64.38341841101646, 61.370620876550674, 64.95632126927376, 65.28533801436424, 61.92464254796505, 65.41517704725266, 64.93017107248306, 66.30606964230537, 54.40755531191826, 54.53504227101803, 55.488498508930206, 63.598342537879944, 62.73705415427685, 58.646258264780045, 58.64935129880905, 57.211656644940376, 60.22733062505722, 62.10417911410332, 63.0995737016201, 62.787910625338554, 61.54106833040714, 61.25610262155533, 58.555534332990646, 59.82082463800907, 58.32376576960087, 56.15348942577839, 57.06914909183979, 63.05203825235367, 57.65937902033329, 48.32750916481018, 49.63838942348957, 63.82977291941643, 55.98011612892151, 59.03694190084934, 58.06946441531181, 56.43499352037907, 56.86879724264145, 58.59324350953102, 54.41180348396301, 59.40943971276283, 58.705744072794914, 59.61315058171749, 57.62290857732296, 55.993499010801315, 55.74416019022465, 56.752170100808144, 55.67134469747543, 52.079028859734535, 49.655492305755615, 54.582623317837715, 57.11707592010498, 58.63802790641785, 58.638430684804916, 54.72927264869213, 51.084177643060684, 50.5741386115551, 53.08231942355633, 54.41413655877113, 52.66357809305191, 50.05213022232056, 52.23421633243561, 48.53509962558746, 49.73650775849819, 48.34383688867092, 51.49639092385769, 50.20278453826904, 57.01233074069023, 60.31592667102814, 63.17364692687988, 64.02708873152733, 67.68911942839622, 66.59795477986336, 62.534209638834, 64.37536284327507, 59.86187383532524, 65.4467761516571, 63.68018254637718, 46.47038921713829, 18.70063193142414, 5.292738368734717, 7.699630865827203, 12.759254593402147, 9.067429695278406, 1.8304840894415975, 0.12656289618462324, 0.4516765975859016, 0.23084841901436448, 0.3816824534442276, 0.09397856847499497, 0.583037092583254, 0.4823104350361973, 15.361716896295547, 71.15213200449944, 56.87165088951588, 34.20690447092056, 46.541867181658745, 23.831838592886925, 65.42080834507942, 15.561417080461979, 0.6244567700196058, 0.07938944429042749, 4.828598024323583, 33.39189000427723, 27.01644580811262, 26.908548697829247, 31.516654528677464, 33.119649812579155, 40.012616738677025, 34.21617977321148, 16.80489845573902, 6.48824161849916, 4.943837765604258, 5.555529892444611, 2.1981571102514863, 0.9494518465362489, 49.85606074333191, 63.35013225674629, 44.058217853307724, 27.924201898276806, 49.4427265226841, 48.619455099105835, 55.69092884659767, 6.9731810968369246, 0.6113963364623487, 0.4647567425854504, 0.02311986496351892, 1.133541518356651, 0.5720206524711102, 0.33031018974725157, 0.1007879589451477, 0.024982314243970904, 8.146064635366201, 64.97791931033134, 71.11277371644974, 91.32468715310097, 81.17055281996727, 87.62414932250977, 77.64621153473854, 85.51197186112404, 82.42935687303543, 81.59168422222137, 72.94438183307648, 82.55956068634987, 78.01232948899269, 80.64713850617409, 72.4074174463749, 66.63671270012856, 66.88458859920502, 77.15801373124123, 72.82145082950592, 78.88741493225098, 74.56238061189651, 72.42882549762726, 64.92210790514946, 58.43943916261196, 60.43677158653736, 56.68946586549282, 56.654971316456795, 61.98011577129364, 69.78473737835884, 67.47833713889122, 69.79206338524818, 66.64544463157654, 69.88453522324562, 69.93663042783737, 70.42608216404915, 67.83769905567169, 68.11389103531837, 67.40773692727089, 65.01220107078552, 61.824916899204254, 67.30448886752129, 64.41768497228622, 67.15959504246712, 67.806236743927, 68.84744167327881, 65.4968574643135, 63.55175703763962, 67.3809863626957, 66.41972914338112, 63.72296445071697, 67.78938084840775, 66.75923332571983, 68.38764354586601, 58.12384329736233, 59.83298018574715, 59.14923347532749, 67.10647389292717, 64.39533457159996, 61.751702427864075, 62.06073224544525, 61.471953839063644, 62.00249657034874, 65.29705658555031, 66.25222653150558, 66.37350842356682, 63.0932280421257, 62.95828968286514, 62.594633996486664, 61.46930158138275, 60.1256138831377, 59.66998413205147, 60.65017193555832, 62.93419897556305, 61.36251591145992, 51.24938517808914, 51.389548256993294, 66.17912605404854, 58.89256104826927, 60.903907120227814, 62.411537021398544, 60.66026419401169, 59.16452005505562, 60.49473747611046, 55.79068869352341, 60.84937244653702, 62.499262914061546, 61.31540983915329, 59.678282886743546, 60.12323521077633, 59.850216060876846, 59.93547968566418, 59.48468707501888, 52.565885335206985, 52.48614281415939, 57.506342232227325, 61.072025299072266, 59.74145449697971, 61.45221009850502, 56.67848065495491, 54.7348203510046, 54.688371643424034, 55.61413116753101, 57.9000923037529, 55.37875659763813, 52.74930529296398, 52.72966034710407, 51.81294433772564, 51.344049498438835, 50.409269258379936, 53.53471554815769, 50.77074006199837, 59.146835803985596, 62.45745375752449, 65.28343811631203, 66.29807487130165, 68.76466691493988, 66.47698447108269, 62.746466249227524, 64.35612827539444, 61.53437688946724, 67.28210046887398, 64.82885330915451, 61.93288430571556, 32.697785049676895, 10.929887406527996, 9.497844949364662, 14.430242478847504, 9.983502589166164, 1.6793071827851236, 0.02146333754353691, 0.6372948561329395, 0.33378468768205494, 0.5538684327621013, 0.0847577398235444, 0.5387033277656883, 0.4256973322480917, 17.558027543127537, 80.35334587097168, 64.30578857660294, 41.28981180489063, 56.39293737709522, 35.89517667889595, 75.05233392119408, 20.761662237346172, 0.9274548862595111, 0.2010713316849433, 5.3472136706113815, 34.09075990319252, 49.41703610122204, 48.829633221030235, 47.8426855802536, 52.05100156366825, 53.48891280591488, 48.56910780072212, 31.119617633521557, 20.200743936002254, 9.831839427351952, 9.307401068508625, 5.394433261826634, 0.47184178896714, 62.88863182067871, 77.020613104105, 59.17608663439751, 36.52723476290703, 78.07482853531837, 70.13068601489067, 68.4359085559845, 8.911438565701246, 0.772895923582837, 0.8282376383431256, 0.20958823326509446, 2.2982871998101473, 1.7926176963374019, 1.0851950501091778, 0.301073519513011, 0.4243247746489942, 9.365017376840115, 72.40811660885811, 80.47826036810875, 97.38022461533546, 86.7306500673294, 93.5769023001194, 83.49991902709007, 91.66419133543968, 88.18194419145584, 85.52878215909004, 77.69986465573311, 85.58532312512398, 81.2019619345665, 82.71866574883461, 78.54874670505524, 70.15949606895447, 69.73784789443016, 80.39624556899071, 73.67110043764114, 82.39241525530815, 75.7063852250576, 78.75178501009941, 67.15873628854752, 61.59290134906769, 64.51494455337524, 60.47760799527168, 58.64596948027611, 65.421993881464, 71.6367655992508, 72.18426302075386, 70.86975395679474, 68.67523491382599, 71.57565727829933, 76.5693037211895, 74.1836017370224, 71.63058713078499, 70.83709090948105, 71.01494416594505, 69.46379899978638, 63.93965542316437, 72.12175637483597, 66.92306533455849, 70.58637276291847, 69.42371875047684, 68.91986578702927, 70.74075847864151, 66.45914822816849, 72.25031867623329, 70.69239467382431, 67.19562470912933, 69.24582749605179, 70.29221534729004, 71.00986003875732, 62.716033682227135, 62.22100004553795, 63.21452893316746, 70.10230153799057, 69.24353241920471, 64.15365993976593, 65.03660336136818, 62.732729986310005, 66.34942531585693, 69.09583434462547, 70.85525393486023, 69.98231157660484, 68.90967473387718, 65.83158910274506, 66.2667341530323, 66.04009911417961, 65.58081775903702, 63.124735951423645, 65.70169687271118, 65.78318729996681, 65.79313516616821, 53.05412873625755, 56.64615198969841, 69.95069727301598, 61.3503223657608, 64.66324299573898, 62.59861618280411, 63.25391761958599, 61.86682105064392, 62.073742747306824, 60.06795957684517, 63.93297538161278, 64.76962968707085, 63.781158328056335, 63.075179010629654, 62.4373110383749, 62.991313710808754, 63.01774889230728, 61.77329666912556, 56.80705055594444, 56.487035527825356, 60.582174584269524, 63.42749610543251, 66.16655632853508, 66.21352180838585, 60.21751955151558, 58.31028409302235, 58.49636770784855, 61.57186567783356, 62.47138760983944, 59.96716618537903, 57.07547955214977, 57.639574483036995, 54.84319053590298, 54.10643666982651, 54.35453675687313, 57.698950096964836, 55.20783416926861, 62.91036665439606, 66.70917481184006, 69.73103106021881, 71.44868329167366, 73.38550016283989, 69.88951295614243, 65.25514483451843, 69.28739726543427, 66.9295933842659, 72.24627569317818, 72.58469313383102, 72.98793509602547, 49.52651962637901, 22.078339084982872, 22.02473346143961, 19.293989092111588, 10.466688461601734, 3.4698187233880162, 0.21346064109820873, 1.1924153217114508, 0.7445486728101969, 0.6922631221823394, 0.3675277973525226, 0.833610431291163, 0.6793432217091322, 22.10373692214489, 93.03072720766068, 74.35076236724854, 53.58160123229027, 63.575817346572876, 43.08548144996166, 88.79862830042839, 25.296061523258686, 1.2653443333692849, 0.24928752332925797, 12.924867756664753, 45.373505875468254, 64.92895513772964, 61.04152053594589, 46.90568245947361, 70.20804226398468], [30.89424602687359, 41.07513852417469, 22.777748554944992, 9.479074906557798, 9.224634859710932, 8.018718268722296, 2.1148418309167027, 6.055745026096702, 50.80595277249813, 43.796263709664345, 17.44569607079029, 28.265364691615105, 84.75240021944046, 39.38117802143097, 42.503683269023895, 10.10391527786851, 0.46025603252928704, 0.6516311306040734, 0.21705322957132012, 1.233486367855221, 0.26272208837326616, 0.6885918066836894, 0.15185373049462214, 0.36291442927904427, 8.741236198693514, 72.15478420257568, 79.75578233599663, 87.66938209533691, 78.90503078699112, 82.71043539047241, 78.57107430696487, 79.49763178825378, 75.98541185259819, 77.28638604283333, 71.59632816910744, 73.77157464623451, 76.38246774673462, 77.68651217222214, 73.21789115667343, 60.559615194797516, 65.08898735046387, 72.42352098226547, 74.50315698981285, 74.52268034219742, 74.22248885035515, 71.99086099863052, 65.29308959841728, 55.455877259373665, 52.80818313360214, 53.711170479655266, 52.412544563412666, 61.6843206435442, 69.07255679368973, 67.80719429254532, 69.87490653991699, 68.54937046766281, 66.3204176723957, 65.82146644592285, 63.927655667066574, 64.07798320055008, 62.091734781861305, 65.0557391345501, 64.11189258098602, 61.09044671058655, 60.486115738749504, 61.75101846456528, 65.10536447167397, 65.05544275045395, 66.1062839627266, 62.40440100431442, 63.469388857483864, 63.83590579032898, 61.032287031412125, 58.65749046206474, 63.09036299586296, 64.46882262825966, 58.81947576999664, 57.51208372414112, 53.8867362588644, 55.208765119314194, 64.19581487774849, 58.12311753630638, 59.872004091739655, 58.27497638761997, 61.20306886732578, 60.440958961844444, 61.46880000829697, 61.94803029298782, 60.735329166054726, 60.034091994166374, 60.15964485704899, 58.89697641134262, 60.49287177622318, 60.649833753705025, 56.515161618590355, 59.96756136417389, 57.50799894332886, 59.2503422498703, 54.725503250956535, 47.319723442196846, 52.17096112668514, 61.79044894874096, 53.229322135448456, 56.812138482928276, 57.45159476995468, 51.68257333338261, 57.351432144641876, 57.37299218773842, 55.18308989703655, 59.27361220121384, 56.84202007949352, 55.57259179651737, 58.19889307022095, 55.83964146673679, 55.986989960074425, 53.35628852248192, 53.25147494673729, 54.886314421892166, 60.164546594023705, 55.95988601446152, 56.88161015510559, 55.12347869575024, 52.80567146837711, 51.8978051841259, 52.86056712269783, 53.24023514986038, 52.34868139028549, 51.741842553019524, 50.07791943848133, 48.229550421237946, 48.68760444223881, 52.61059373617172, 51.862736865878105, 53.46197225153446, 56.10588937997818, 60.36122024059296, 59.59113836288452, 63.65092411637306, 66.225825548172, 65.19038110971451, 64.64091539382935, 63.329947739839554, 63.44261169433594, 55.79751692712307, 61.45805038511753, 54.44555327296257, 39.34601470828056, 16.468316316604614, 6.227782694622874, 6.519915293902159, 14.878347683697939, 15.473022423684597, 3.813069029711187, 0.38608445785939693, 0.26483809982892126, 0.04134223432629369, 0.1451194379478693, 0.210993935179431, 0.911320298910141, 0.38268574804533273, 15.993043519556522, 73.6575123667717, 61.111600175499916, 39.16366629302502, 39.334790110588074, 30.418988429009914, 56.75835236907005, 18.42298462986946, 1.0517238336615264, 0.10671590061974712, 16.395966298878193, 33.515162989497185, 15.310081467032433, 10.881357360631227, 11.892025228589773, 22.120731510221958, 48.910591676831245, 43.79174195230007, 25.723903365433216, 16.790913306176662, 7.4238302651792765, 10.094566829502583, 1.3165843463502824, 11.204332429915667, 65.69628596305847, 50.98689146339893, 35.104488506913185, 35.11151812970638, 93.16488280892372, 50.88647425174713, 54.1258954256773, 11.295289099216461, 0.47478018910624087, 0.6716615182813257, 0.12579794973134995, 1.8793121818453074, 0.8506144001148641, 0.690726104658097, 0.20732926932396367, 0.21818545006681234, 10.301392581313848, 77.40184664726257, 80.51308929920197, 91.51470735669136, 81.11633732914925, 86.22098341584206, 81.68157979846, 85.62156558036804, 80.97522050142288, 81.33568435907364, 74.47639882564545, 76.03581994771957, 77.0988205075264, 80.20223557949066, 74.0704894065857, 63.02588805556297, 66.17724895477295, 75.62708348035812, 75.13581544160843, 76.13125562667847, 74.76516053080559, 72.899719029665, 67.80652552843094, 57.8309740126133, 56.31939612329006, 56.191320195794106, 54.750087931752205, 63.79723146557808, 69.66701209545135, 68.40784326195717, 71.69258460402489, 69.0759690105915, 67.21482887864113, 68.90495538711548, 66.47904396057129, 63.13190996646881, 63.98238033056259, 66.53276547789574, 65.87259650230408, 64.14414525032043, 64.45206552743912, 65.10465011000633, 66.57036066055298, 67.1319629251957, 67.9148805141449, 62.755308374762535, 64.44201126694679, 66.62415817379951, 64.01213273406029, 60.3482211381197, 65.5459888279438, 67.7060741186142, 60.71179322898388, 61.42963171005249, 57.05380171537399, 60.86042605340481, 68.47275897860527, 60.90546503663063, 65.47734931111336, 61.908618807792664, 62.35513664782047, 64.11261454224586, 64.83728885650635, 65.17740860581398, 63.406749218702316, 62.16017670929432, 61.859373450279236, 61.745820343494415, 62.57372371852398, 63.51882420480251, 60.30684895813465, 62.88458123803139, 60.333382934331894, 61.27433784306049, 54.95000660419464, 52.609104216098785, 51.78256116807461, 63.20692554116249, 59.91899237036705, 59.07101087272167, 60.14101065695286, 55.63612058758736, 61.92052736878395, 60.11141784489155, 56.33754014968872, 62.875720113515854, 59.89138305187225, 58.89546029269695, 60.72242505848408, 60.07957935333252, 58.145407140254974, 58.166906386613846, 56.66043542325497, 58.388480097055435, 60.176595747470856, 58.91686454415321, 57.56016634404659, 58.779824897646904, 53.08944024145603, 55.8904143422842, 54.541368931531906, 58.49015884101391, 56.53938151896, 53.57384964823723, 51.58372163772583, 52.39526309072971, 53.201682418584824, 55.73141947388649, 54.041433557868004, 56.60492800176144, 56.41794763505459, 61.24320611357689, 61.34838826954365, 66.90994083881378, 67.59213343262672, 65.59759005904198, 65.85987478494644, 64.5836828649044, 63.751694709062576, 60.98127096891403, 66.97604969143867, 63.71153846383095, 55.376659110188484, 27.56074760109186, 13.400265946984291, 7.655396489426494, 16.479012742638588, 17.077980302274227, 3.762452658265829, 0.07433310311171226, 0.258089424460195, 0.13465739699313417, 0.35504974192008376, 0.5318112100940198, 1.1112481146119535, 0.32174161984585226, 20.366346649825573, 80.87299078702927, 71.47151246666908, 46.48357070982456, 49.44492280483246, 36.36197403073311, 69.15095418691635, 26.2823498994112, 0.996075700968504, 0.15015320299426094, 9.599902722984552, 52.52706281840801, 48.93201872706413, 41.50407090783119, 22.003988474607468, 49.01384353637695, 65.3081975877285, 61.72897584736347, 46.364222913980484, 39.45671036839485, 13.603895120322704, 15.046918038278818, 5.038045635446906, 10.977327860891819, 86.17753654718399, 64.63378697633743, 45.631550028920174, 47.42949575185776, 109.27841976284981, 57.19945549964905, 67.86143258213997, 12.283082194626331, 0.46658014005515724, 0.8803477452602237, 0.25651280593592674, 3.6498373886570334, 2.0938840555027127, 1.386583240237087, 0.6518020620569587, 0.3164133260725066, 12.181780580431223, 85.88226199150085, 88.62243935465813, 97.08007112145424, 85.47672495245934, 92.95771792531013, 84.80112120509148, 87.16783180832863, 86.27059355378151, 87.70422622561455, 78.91297996044159, 82.15134859085083, 81.62262216210365, 84.50443312525749, 79.28197056055069, 66.71760275959969, 70.50808936357498, 78.81241455674171, 79.04991701245308, 81.00795954465866, 81.04162573814392, 77.72325620055199, 70.06395399570465, 61.1725565046072, 58.7908823043108, 60.77059507369995, 56.02044336497784, 65.70031374692917, 71.61313846707344, 70.65133407711983, 72.76908963918686, 73.31654146313667, 69.33170288801193, 71.0021236538887, 68.33361804485321, 67.1909661591053, 67.26225793361664, 71.464414447546, 71.30548417568207, 66.8033641576767, 66.6703636944294, 66.13453924655914, 68.80810618400574, 70.09828895330429, 71.11778184771538, 66.02331161499023, 67.40938603878021, 69.28115800023079, 66.4544440805912, 63.444093614816666, 67.68446087837219, 71.81914821267128, 65.14687344431877, 64.83396783471107, 59.421352073550224, 62.68441177904606, 70.93013271689415, 63.49828630685806, 69.07418310642242, 65.91182559728622, 65.37176817655563, 67.93352991342545, 67.97871708869934, 67.97090470790863, 66.33114069700241, 65.38661777973175, 66.07707113027573, 64.49873462319374, 66.21034517884254, 67.33301013708115, 61.22473530471325, 65.06896242499352, 63.07545259594917, 64.13536012172699, 59.55569766461849, 53.901312276721, 55.62967233359814, 67.12772235274315, 61.36459819972515, 62.87804178893566, 62.0745787024498, 58.008557483553886, 62.07308538258076, 63.68243582546711, 58.75047907233238, 64.13012400269508, 60.49811169505119, 62.674418315291405, 63.47146354615688, 61.16705819964409, 61.45833916962147, 60.286143869161606, 57.97200724482536, 61.25888407230377, 63.29343169927597, 61.53264798223972, 59.79676432907581, 62.9970970004797, 56.99676297605038, 58.09589199721813, 57.09695599973202, 61.72347754240036, 58.846978694200516, 57.549302726984024, 55.30893914401531, 55.808239951729774, 55.02731345593929, 58.693071752786636, 56.01084887981415, 60.48674650490284, 60.680661499500275, 64.34480488300323, 65.08512675762177, 70.64253374934196, 71.72047510743141, 69.2408649623394, 70.37114471197128, 66.57968536019325, 70.1153576374054, 66.62308663129807, 75.74214890599251, 71.86385661363602, 70.4288712143898, 43.4408687800169, 26.150322183966637, 18.71332325041294, 24.705407917499542, 19.17903196066618, 3.519107778556645, 0.7099419110454619, 0.9846252528950572, 0.24523342290194705, 0.885200381744653, 0.4002959030913189, 1.4030707930214703, 0.5745111813303083, 26.537831090390682, 94.25670862197876, 79.98392209410667, 56.324947625398636, 58.318343460559845, 44.98207747936249, 86.67032450437546, 33.6414910107851, 1.2967040506191552, 0.2122296259040013, 22.201919853687286, 61.17742024362087, 62.63278014957905, 44.75530944764614, 15.084889400750399, 52.73777291178703], [24.27651733160019, 32.8986194729805, 34.1768404841423, 12.793470807373524, 8.855654709041119, 7.824713978916407, 0.526622113538906, 13.311139829456806, 49.373547434806824, 34.70916531980038, 19.205636233091354, 24.422129318118095, 45.6392902135849, 33.06445397436619, 51.52297429740429, 14.674652963876724, 0.35500850819516927, 0.7028025691397488, 0.11438593748607673, 0.6486662209499627, 0.16003285098122433, 0.6947834556922317, 0.4060144181130454, 0.36112371599301696, 21.62447813898325, 88.87465462088585, 82.0427580177784, 79.49028298258781, 75.85257858037949, 78.09275597333908, 77.96287894248962, 77.25653484463692, 77.09100052714348, 77.57061079144478, 75.07517069578171, 73.17622259259224, 72.93506473302841, 74.17341068387032, 63.64809326827526, 56.369838416576385, 65.13140067458153, 72.99561068415642, 74.38092514872551, 72.32432350516319, 72.62747123837471, 71.88908725976944, 70.18747016787529, 60.05157485604286, 55.70478670299053, 54.065497666597366, 53.6579505354166, 65.4801307618618, 68.4190982580185, 66.63748785853386, 65.74949830770493, 62.41136983036995, 64.6968711912632, 67.16059058904648, 64.66868430376053, 59.16649594902992, 61.997013464570045, 60.80662094056606, 64.05617997050285, 62.27408319711685, 67.48190134763718, 64.27435666322708, 63.36835987865925, 65.47904402017593, 61.91690996289253, 62.85246156156063, 62.34008565545082, 63.40717479586601, 64.07801359891891, 58.16843010485172, 64.37158584594727, 59.007900059223175, 59.50111359357834, 60.05627520382404, 53.59395056962967, 61.85892887413502, 59.89729933440685, 61.30241073668003, 59.21730302274227, 61.951966881752014, 61.08625553548336, 60.805268213152885, 56.68264523148537, 60.733459666371346, 58.36218170821667, 58.86719360947609, 58.31354811787605, 57.982692271471024, 56.78337022662163, 58.341830000281334, 59.64892566204071, 57.263064086437225, 58.89135271310806, 58.80007781088352, 56.051415503025055, 54.84402649104595, 54.59337294101715, 52.81061880290508, 60.29861479997635, 54.57302123308182, 57.29106478393078, 57.0129919052124, 55.820091515779495, 59.87515792250633, 55.957036167383194, 57.97873668372631, 57.86830700933933, 57.13549353182316, 58.312537372112274, 55.33033959567547, 55.21000385284424, 57.22396798431873, 56.32466644048691, 58.97284314036369, 55.75443483889103, 56.43567368388176, 54.71926398575306, 53.636367693543434, 51.042125299572945, 51.47373653948307, 50.289602279663086, 54.41915988922119, 50.663582012057304, 50.78367456793785, 49.435993283987045, 51.720894277095795, 52.82313533127308, 56.88784562051296, 59.184419587254524, 59.34470638632774, 60.88070936501026, 61.42520114779472, 61.033651158213615, 65.61780497431755, 68.29637244343758, 68.49795162677765, 63.730966821312904, 61.09471768140793, 57.8121954202652, 48.06696854531765, 47.29686386883259, 44.66601423919201, 35.05036801099777, 16.175226643681526, 8.010861240327358, 8.086898010224104, 16.540143862366676, 17.222623340785503, 5.895505249500275, 1.1227040248923004, 0.39182105159852654, 0.12616737600183114, 0.09035557421157137, 0.18671757221454754, 0.3567993105389178, 0.212808842479717, 19.121468849480152, 71.93330928683281, 65.59283271431923, 40.61828903853893, 42.806017845869064, 40.528104677796364, 44.16169010102749, 22.283607870340347, 1.1858146009035408, 1.1230302136391401, 16.171993017196655, 23.67389626801014, 7.164585376158357, 1.3027795683592558, 3.317937310785055, 18.950645215809345, 50.83593316376209, 56.29774868488312, 40.78816272318363, 30.646472722291946, 11.678693275898695, 11.421368233859539, 2.9943841975182295, 20.64026065170765, 63.98466020822525, 45.90043120086193, 33.499891608953476, 32.85954996943474, 58.013907596468925, 39.04966861009598, 61.81624576449394, 16.582219004631042, 0.3357476682867855, 0.8187425415962934, 0.09659802322858013, 0.9121344052255154, 1.2311547179706395, 1.1619289638474584, 0.25190748274326324, 0.33973828540183604, 18.06707862764597, 90.30081689357758, 84.00464594364166, 87.29422822594643, 77.36143961548805, 81.89875334501266, 81.99292749166489, 80.32097160816193, 79.02363762259483, 81.58334746956825, 77.19602689146996, 78.53826686739922, 74.63818654417992, 76.71924367547035, 67.79944270849228, 58.52497637271881, 66.571234613657, 74.94245141744614, 76.0096849501133, 73.22337046265602, 74.68368530273438, 72.2902013361454, 71.92042797803879, 60.46802870929241, 56.13466523587704, 55.8994996547699, 56.74164466559887, 67.11028128862381, 70.04189997911453, 68.44277858734131, 69.1015188395977, 65.92644721269608, 66.52394995093346, 68.62946256995201, 66.0688179731369, 60.30861586332321, 62.64604903757572, 66.06955513358116, 64.7791139781475, 64.64519396424294, 68.82671758532524, 67.52489224076271, 64.42635610699654, 67.33533561229706, 64.42182675004005, 66.4336059987545, 64.87774148583412, 64.74132880568504, 65.41019171476364, 61.349140629172325, 68.31496864557266, 60.86553677916527, 63.815288096666336, 61.182618364691734, 56.362489610910416, 64.81565281748772, 63.5410226136446, 61.65048345923424, 61.6842370480299, 63.598129749298096, 62.424262538552284, 64.72042232751846, 61.792022064328194, 62.82352611422539, 62.794693261384964, 61.925976276397705, 61.05956956744194, 60.2781642973423, 58.20368081331253, 59.65036578476429, 61.291995495557785, 59.23483528196812, 60.26441663503647, 61.351002529263496, 58.894278556108475, 54.94646519422531, 58.53548280894756, 55.49620449542999, 62.7417279034853, 60.158972293138504, 60.655347257852554, 61.0818325728178, 59.59681525826454, 62.101485058665276, 60.00822678208351, 60.52825927734375, 59.611816853284836, 60.73293909430504, 60.688815861940384, 57.621430456638336, 58.75739850103855, 60.66901132464409, 60.51703467965126, 62.083382830023766, 59.91043522953987, 58.27650770545006, 57.082573771476746, 54.17015165090561, 54.84844945371151, 55.42864792048931, 53.23007449507713, 56.117642149329185, 52.97601632773876, 54.418825507164, 51.205003559589386, 55.83376318216324, 56.40290804207325, 57.85780057311058, 59.827284291386604, 60.13863958418369, 60.716273188591, 61.57874710857868, 63.33680637180805, 64.39835920929909, 67.54310846328735, 66.69911295175552, 65.47785088419914, 61.548892110586166, 60.28461255133152, 56.02308802306652, 59.47028964757919, 58.75334411859512, 51.68387286365032, 27.576655447483063, 15.249972492456436, 10.379524938762188, 19.0260673686862, 21.15287594497204, 7.454969119280577, 0.8176175644621253, 0.7184365927241743, 0.09000855337944813, 0.2821345638949424, 0.09710807164083235, 1.077819170895964, 0.2823287987848744, 24.7767186909914, 80.03558412194252, 75.5895034968853, 49.718424528837204, 50.82238309085369, 43.9167096465826, 62.70416311919689, 29.342238306999207, 0.8464028604794294, 0.6209805503021926, 19.689344577491283, 51.92881532013416, 42.2054410725832, 28.392217084765434, 10.208149384707212, 39.11732017993927, 59.55285541713238, 69.88552317023277, 62.05840677022934, 55.10386414825916, 18.77821046859026, 14.798772353678942, 3.9349356153979897, 25.826777145266533, 83.47851857542992, 60.35295568406582, 41.662328615784645, 40.20822264254093, 69.89818409085274, 45.84249950945377, 75.11459738016129, 18.00814189016819, 0.3378856473136693, 0.9774536720942706, 0.26773419755045325, 1.3795726164244115, 3.1049665762111545, 2.2838731482625008, 0.5671910522505641, 0.5792219785507768, 23.68886176496744, 98.55884537100792, 88.26572969555855, 93.02748218178749, 80.37346959114075, 87.2669304907322, 88.12286496162415, 84.31885108351707, 83.9866729080677, 87.87451788783073, 82.36349880695343, 82.09641873836517, 77.94717818498611, 81.236692070961, 72.145626693964, 62.55002059042454, 70.99995017051697, 79.5323695242405, 79.58276242017746, 76.04240119457245, 78.02548438310623, 77.62644499540329, 74.36027705669403, 65.43570354580879, 60.62676899135113, 59.744490534067154, 59.870427176356316, 70.82230970263481, 72.46648147702217, 71.26059338450432, 70.69677963852882, 67.12817832827568, 70.47531232237816, 72.61136010289192, 70.04576057195663, 63.27640101313591, 66.81034818291664, 67.81999960541725, 65.90142175555229, 69.83337476849556, 72.14153811335564, 68.52258190512657, 66.88531816005707, 68.46538737416267, 67.63646185398102, 68.12044188380241, 68.45530271530151, 69.3246428668499, 69.43546772003174, 60.56143529713154, 70.82877695560455, 66.05601266026497, 65.51870629191399, 65.98747193813324, 58.95318679511547, 67.28330120444298, 67.15793073177338, 66.3361868262291, 65.21034523844719, 68.19852009415627, 66.13320931792259, 69.7137039899826, 64.08327251672745, 67.09242224693298, 65.89777395129204, 64.71382588148117, 63.86150121688843, 63.595994263887405, 61.311040073633194, 64.2856116592884, 65.16660958528519, 63.21809694170952, 63.46555486321449, 66.38424664735794, 62.34472520649433, 60.20540960133076, 61.212176978588104, 59.1410069167614, 64.34965342283249, 62.28917978703976, 64.13071677088737, 64.78697955608368, 62.89393253624439, 66.28532275557518, 61.57075613737106, 65.97949236631393, 62.5105407088995, 62.48564824461937, 63.88046979904175, 61.029714569449425, 60.390015095472336, 63.454159274697304, 65.42491212487221, 67.09762796759605, 62.71244667470455, 61.26522593200207, 61.150589883327484, 58.153211921453476, 56.692752689123154, 57.654811665415764, 55.81832081079483, 60.63750721514225, 57.49510623514652, 58.214909210801125, 54.3264676630497, 60.58915860950947, 58.148872554302216, 63.15469354391098, 64.0146254003048, 63.47957991063595, 63.587254732847214, 66.15108355879784, 66.79002687335014, 69.02392700314522, 72.16787829995155, 71.12725093960762, 70.84298059344292, 64.86231431365013, 66.95924699306488, 61.87609255313873, 71.94691255688667, 68.82974222302437, 68.1313244998455, 48.25039230287075, 31.077726781368256, 27.253843769431114, 25.48291079699993, 19.20981790870428, 6.085423808544874, 1.1947342660278082, 1.4185559120960534, 0.33059374953154474, 0.5286810686811805, 0.6128343218006194, 2.1945579908788204, 0.563252029241994, 31.190033555030823, 91.4095290005207, 85.80497413873672, 59.562594294548035, 67.18104109168053, 54.14020545780659, 79.7687092423439, 39.072767570614815, 0.641170113813132, 0.5311715381685644, 31.13318480551243, 58.318617045879364, 42.468489557504654, 30.496285781264305, 7.148048188537359, 41.75992637872696], [11.571036502718925, 25.785878039896488, 30.772124379873276, 9.88205373287201, 9.345397129654884, 8.197899553924799, 0.9498014871496707, 19.944973960518837, 52.41225577890873, 30.543245561420918, 15.623055472970009, 24.101295433938503, 41.3104484975338, 38.33917133510113, 52.67388314008713, 26.493766754865646, 0.40181801829021424, 0.621933052316308, 0.043306736333761364, 0.13291931682033464, 0.1088424728368409, 0.43245912878774107, 0.8600409817881882, 0.042776145273819566, 24.061904847621918, 66.602453738451, 77.88230806589127, 71.34758591651917, 74.88648802042007, 73.54351848363876, 77.28444814682007, 77.4577796459198, 75.28307273983955, 78.06754812598228, 75.35450130701065, 72.74894312024117, 70.31363099813461, 66.2913416326046, 57.08958059549332, 57.57266007363796, 57.086578756570816, 71.60800114274025, 73.03369984030724, 71.0873530805111, 73.99102807044983, 71.41199246048927, 69.42912206053734, 63.04099224507809, 56.56401939690113, 51.96775943040848, 51.55423142015934, 60.8087982237339, 67.7908855676651, 66.2651838362217, 63.17694894969463, 65.73596343398094, 69.11851912736893, 64.99504119157791, 60.74898183345795, 57.03090414404869, 59.88316789269447, 60.596522614359856, 62.678191512823105, 63.21699500083923, 60.73405623435974, 65.24125277996063, 60.63080057501793, 59.939207285642624, 63.539491295814514, 63.419945910573006, 63.21282662451267, 63.98105040192604, 63.2448361068964, 62.2186403721571, 58.82983781397343, 62.03817665576935, 66.80993020534515, 49.837859719991684, 55.74639067053795, 61.726483181118965, 61.63504868745804, 54.487301632761955, 58.92065294086933, 56.393746733665466, 62.03344210982323, 59.41786386072636, 58.66372972726822, 58.568225651979446, 58.82911205291748, 56.977201625704765, 58.12545821070671, 56.45622678101063, 59.879105910658836, 59.343361258506775, 59.05385859310627, 58.34718771278858, 57.38676264882088, 57.76353523135185, 59.69447001814842, 52.155108377337456, 56.46253824234009, 55.36193490028381, 53.3769366145134, 60.98630949854851, 54.70393940806389, 60.31464233994484, 57.6387233287096, 56.635694950819016, 58.08122478425503, 59.75137956440449, 57.5297299772501, 55.895901247859, 52.40109957754612, 55.44526822865009, 55.23640103638172, 57.385132536292076, 56.858161613345146, 54.581354185938835, 56.148032918572426, 53.16809222102165, 49.83919344842434, 54.14766065776348, 52.32225760817528, 54.52609375119209, 49.75961431860924, 50.3607002645731, 48.02960515022278, 48.02359387278557, 49.340937584638596, 54.03171367943287, 56.36825390160084, 60.41936472058296, 58.0831740796566, 63.182679042220116, 60.08870646357536, 62.121190801262856, 65.85098326206207, 65.79653978347778, 66.4456969499588, 64.18054729700089, 62.63327032327652, 57.581597194075584, 51.74963593482971, 44.15030211210251, 42.95556642115116, 41.60306319594383, 41.3460373878479, 22.88030505180359, 12.216689307242632, 9.243767783045769, 14.286129511892796, 20.797061137855053, 16.479396522045135, 3.9871108531951904, 0.35850562679115683, 0.04082647879840806, 0.18344211828662083, 0.7552799500990659, 1.2845128797926009, 0.5222130438778549, 19.253775849938393, 66.2411767244339, 72.64002576470375, 41.38049393892288, 56.99248820543289, 54.85216185450554, 39.92233358323574, 24.159375317394733, 0.8996201923582703, 1.341447124723345, 12.799476385116577, 10.762191955000162, 2.727339039556682, 1.1272025085054338, 1.8343277019448578, 7.856920100748539, 41.67693883180618, 57.75721237063408, 52.18462139368057, 35.10103449225426, 14.327706880867481, 12.327270973473787, 1.1331170098856091, 32.587902545928955, 61.62870682775974, 43.01177680492401, 28.947000615298748, 30.120561942458153, 46.75510793924332, 43.76007825136185, 60.52334614098072, 29.787443317472935, 0.3420069714775309, 0.596093013882637, 0.0737575527455192, 0.14661290624644607, 0.6224484590347856, 0.9299686888698488, 0.8243544248398393, 0.03634596629126463, 31.560112796723843, 84.06015336513519, 72.31777265667915, 80.1449802517891, 76.4679479598999, 78.49019944667816, 79.96689140796661, 82.24643468856812, 78.23264166712761, 81.18005231022835, 78.81859302520752, 76.11384496092796, 74.65261057019234, 68.9126917719841, 60.6940633803606, 58.647622391581535, 63.35195995867252, 74.07964691519737, 77.14929699897766, 71.25973463058472, 74.44731518626213, 75.18754586577415, 72.08564311265945, 67.5251430273056, 57.682683169841766, 55.556465461850166, 53.73476341366768, 64.4000007212162, 69.85561117529869, 67.70336866378784, 65.75631514191628, 66.19731947779655, 67.09351658821106, 65.88605538010597, 62.1234554797411, 60.06801277399063, 63.14642898738384, 63.014226481318474, 65.15751287341118, 65.59863120317459, 62.655347138643265, 67.74369969964027, 63.84144589304924, 64.76682543754578, 67.32591211795807, 65.37147179245949, 66.18345782160759, 65.13982102274895, 63.684335723519325, 64.25073713064194, 62.05823577940464, 65.55836096405983, 67.78479069471359, 52.07753174006939, 60.13771243393421, 65.31893581151962, 64.11199137568474, 57.32336685061455, 62.325125858187675, 59.1455552726984, 63.225400149822235, 61.60198666155338, 61.40578418970108, 61.839565113186836, 63.315645307302475, 60.09552329778671, 60.54724305868149, 56.94950111210346, 61.62611536681652, 61.37461066246033, 59.98774208128452, 59.64953362941742, 58.216144144535065, 60.59911787509918, 62.4163893610239, 56.11793473362923, 57.957260236144066, 61.503039970993996, 58.64072576165199, 62.57343113422394, 59.777985736727715, 60.824852362275124, 60.52095226943493, 59.60311912000179, 59.72576513886452, 64.65565860271454, 59.855094999074936, 58.182109370827675, 55.90223550796509, 59.940400421619415, 59.94276009500027, 58.022327944636345, 57.30186000466347, 56.41232393682003, 57.04487979412079, 58.878919780254364, 51.883153170347214, 56.356820315122604, 55.24145096540451, 57.165717110037804, 54.10287246108055, 53.87756735086441, 50.45878440141678, 49.932881221175194, 52.55503311753273, 57.86584094166756, 58.93562413752079, 62.50984914600849, 60.14508783817291, 62.045153081417084, 60.92244632542133, 63.74510586261749, 65.37119060754776, 65.99619626998901, 66.23789370059967, 65.4905954003334, 64.02740031480789, 58.5548085719347, 58.38366195559502, 53.25392581522465, 54.27650034427643, 53.797722235322, 54.85274322330952, 36.56420677900314, 23.62193025648594, 14.662700705230236, 17.937015406787395, 25.19716802984476, 18.903706334531307, 3.859820533543825, 0.25858514942228794, 0.04923664098896552, 0.5214242893271148, 4.671015255153179, 0.22097406996181235, 0.5376197921577841, 26.686465814709663, 78.06426510214806, 80.08235961198807, 49.12145376205444, 67.80869901180267, 62.2807290405035, 52.562651708722115, 33.29869620501995, 0.6036585860420018, 0.46499057847540826, 20.386637561023235, 39.55610163509846, 28.39068576693535, 13.547992520034313, 5.125322202220559, 20.77454164624214, 50.18829211592674, 68.36909294128418, 65.69481164216995, 51.86785139143467, 22.031151317059994, 14.743180386722088, 3.7791233137249947, 41.10632725059986, 82.21521556377411, 58.12350131571293, 36.27975784242153, 40.34764476120472, 58.05745325982571, 54.34056490659714, 73.68528887629509, 34.639834240078926, 0.42847691278439015, 0.6707610853482038, 0.276111887069419, 0.20286223792936653, 1.2790433107875288, 1.0984734375961125, 1.6309301974251866, 0.09437260436243378, 41.886132806539536, 98.85751694440842, 77.75536447763443, 84.6516752243042, 80.22349923849106, 80.92734307050705, 86.88010364770889, 88.06447729468346, 82.6060625910759, 86.85655251145363, 84.93746548891068, 80.56720599532127, 80.28549671173096, 72.63771548867226, 63.59464153647423, 62.61559747159481, 66.29514142870903, 78.82658019661903, 81.20871797204018, 74.53556165099144, 77.75640562176704, 79.86163705587387, 73.95967215299606, 71.22954905033112, 61.208361983299255, 58.88755291700363, 55.836685225367546, 67.20120280981064, 71.28899306058884, 70.0645163655281, 67.03718841075897, 70.43846189975739, 72.34264612197876, 71.01810559630394, 66.61695376038551, 63.50881174206734, 65.88833525776863, 65.82580581307411, 69.75927874445915, 68.48682582378387, 68.4445720911026, 68.0742135643959, 64.77751806378365, 67.26304069161415, 69.562608897686, 71.27481982111931, 69.25423264503479, 67.89667949080467, 66.41073882579803, 68.0428196489811, 65.18899038434029, 67.11193040013313, 73.16188976168633, 56.97765380144119, 61.757576912641525, 70.0344143807888, 66.29645615816116, 60.79849697649479, 64.804747402668, 62.239391058683395, 68.21111261844635, 65.90373203158379, 63.432679027318954, 64.82140570878983, 65.65271750092506, 61.43096923828125, 61.85257941484451, 61.59107364714146, 65.02417042851448, 64.1911107301712, 62.76724353432655, 62.2783237695694, 60.57113237679005, 63.0720479786396, 63.51471662521362, 58.30927334725857, 63.07471163570881, 62.417909279465675, 61.54250845313072, 66.1651200056076, 63.195001780986786, 65.6181089580059, 63.65004636347294, 63.28735202550888, 62.939476892352104, 66.34633228182793, 64.39087361097336, 61.16935707628727, 58.318822234869, 62.99229025840759, 62.45241142809391, 65.07485970854759, 60.926014333963394, 63.37736539542675, 62.27984368801117, 63.450986444950104, 54.333926662802696, 62.0090664178133, 57.34461531043053, 61.07915371656418, 56.16151079535484, 58.63380253314972, 53.88546332716942, 55.96641406416893, 55.00498965382576, 60.23181438446045, 61.37143403291702, 66.01743713021278, 62.4937342107296, 66.28249570727348, 64.42725285887718, 67.41788238286972, 71.16293102502823, 70.01783967018127, 70.94521030783653, 68.71282249689102, 68.44497486948967, 63.56278784573078, 66.96450591087341, 60.862626135349274, 69.77291241288185, 65.29938206076622, 72.02562913298607, 57.02805429697037, 48.76479730010033, 38.854074105620384, 37.99643352627754, 25.49551662057638, 18.817547857761383, 4.795810533687472, 0.641350841615349, 0.12388379502226599, 0.6489184324163944, 5.681254221126437, 6.972230197861791, 1.3323926855809987, 33.95790383219719, 86.70665055513382, 92.68361583352089, 57.4390022456646, 80.99695533514023, 64.97114047408104, 70.07513299584389, 41.33970692753792, 0.6220949592534453, 1.0628775414079428, 34.306747913360596, 39.104222282767296, 29.19553577899933, 14.001373741775751, 6.6845424100756645, 21.228670477867126], [6.595174055546522, 21.807675808668137, 32.978346794843674, 0.8215871639549732, 10.811145678162575, 12.759005706757307, 1.5344604989513755, 32.96512730419636, 48.87879878282547, 27.59252529591322, 26.610490791499615, 34.025293216109276, 62.03973837196827, 46.84743158519268, 42.355453222990036, 38.87200154364109, 0.2980686823138967, 0.48743312421720475, 0.11707124300301075, 0.18228640139568597, 0.12491678295191377, 0.15012264135293663, 0.5829668557271361, 0.21891882555792108, 16.019055023789406, 42.06322990357876, 72.65831038355827, 72.75967374444008, 67.6891878247261, 72.84025982022285, 74.34493348002434, 78.13130870461464, 75.14732122421265, 78.36999669671059, 74.45386603474617, 73.89365449547768, 65.73230803012848, 60.35515196621418, 56.89767949283123, 60.338546857237816, 59.039103984832764, 66.31502196192741, 74.12225782871246, 71.3227504491806, 72.3773230612278, 73.30502048134804, 68.27390804886818, 65.79313516616821, 60.13868138194084, 50.33265396952629, 52.55850613117218, 58.678826317191124, 65.26715219020844, 66.52263522148132, 66.23538583517075, 63.88254448771477, 62.57620498538017, 58.82013313472271, 56.51898041367531, 55.76586842536926, 55.88815726339817, 61.15203000605106, 60.1081196218729, 60.135177969932556, 59.287340864539146, 59.98434506356716, 63.331433460116386, 63.74868527054787, 61.26980468630791, 59.738198071718216, 62.411339432001114, 61.978337466716766, 61.8152692168951, 58.457115814089775, 60.31846113502979, 64.64348405599594, 52.92574122548103, 53.59426595270634, 58.37841063737869, 64.14967775344849, 64.26758542656898, 58.36424119770527, 57.654804065823555, 53.380288034677505, 52.235029488801956, 55.25626257061958, 59.45745773613453, 60.35761423408985, 58.53959038853645, 59.74183827638626, 58.35775874555111, 58.48662503063679, 52.766510769724846, 52.78877377510071, 56.499023884534836, 55.54942063987255, 58.25099967420101, 57.79109515249729, 59.7735133767128, 55.389772206544876, 52.08528332412243, 58.34350571036339, 56.285475343465805, 58.40246334671974, 59.85895179212093, 58.59739288687706, 59.676884561777115, 57.80537098646164, 58.53364750742912, 58.80847156047821, 52.1325907856226, 53.76173056662083, 53.95998872816563, 55.329100862145424, 55.61687462031841, 56.764082461595535, 55.58318182826042, 53.750213384628296, 51.624732837080956, 54.17642891407013, 51.38150788843632, 53.50721262395382, 55.29076851904392, 55.41481666266918, 51.14866018295288, 52.7007021009922, 44.62166681885719, 51.00112929940224, 54.342544600367546, 58.714981377124786, 57.92027302086353, 61.154184490442276, 61.111949756741524, 63.42155322432518, 63.54665771126747, 60.55206499993801, 61.39939673244953, 61.564197689294815, 65.90930253267288, 65.06377190351486, 60.8550151437521, 53.83518062531948, 50.372076854109764, 43.97428795695305, 46.068036407232285, 46.8646864593029, 47.79576949775219, 39.128267392516136, 28.253410533070564, 12.973016873002052, 9.513069782406092, 26.609272956848145, 26.499563343822956, 7.48335549607873, 1.6530972579494119, 0.21121772238984704, 0.24270476249512285, 0.9112348628696054, 0.35186717519536614, 0.45397407899145037, 27.409502416849136, 67.82305464148521, 70.67775025963783, 47.431878224015236, 38.21107640862465, 41.79140008985996, 48.85740593075752, 21.837532706558704, 0.449399451026693, 0.8342400100082159, 6.9456131011247635, 5.195745248347521, 2.5177047634497285, 1.655802356544882, 0.48168314213398844, 4.047940839082003, 31.817719973623753, 59.72755864262581, 56.35000728070736, 31.68009325861931, 16.282631680369377, 10.346380267292261, 2.3689408460631967, 44.01649609208107, 60.60743182897568, 39.76316012442112, 32.992729023098946, 28.20299483835697, 67.28165969252586, 52.96534650027752, 49.70026150345802, 46.11711077392101, 0.2580423722974956, 0.8513292961288244, 0.07261540231411345, 0.24716235377127305, 0.04164035133726429, 0.29765299055725336, 0.7826017308980227, 0.16576652065850794, 28.410678394138813, 59.68969747424126, 74.91145268082619, 69.68916490674019, 73.41931074857712, 71.8225072324276, 77.27817848324776, 80.62729597091675, 82.04391315579414, 79.30382698774338, 78.7035883963108, 76.2351268529892, 71.75731033086777, 62.0765545964241, 60.52243798971176, 60.883627608418465, 61.05528339743614, 71.35707780718803, 75.76035752892494, 75.35646960139275, 71.2422327697277, 75.70027515292168, 67.99356669187546, 68.985495865345, 61.016962453722954, 54.92327883839607, 53.9408453553915, 61.8163787573576, 67.7921774983406, 68.3275155723095, 68.23675364255905, 67.09566727280617, 63.744345903396606, 59.297740906476974, 59.34684567153454, 59.40322704613209, 58.90852779150009, 63.203900903463364, 63.099311515688896, 62.87583410739899, 62.21257969737053, 62.80448153614998, 67.0631942152977, 66.22508078813553, 64.93346929550171, 61.89307764172554, 63.145881816744804, 62.8234501183033, 62.51419611275196, 61.60566486418247, 65.98430290818214, 65.20532950758934, 57.556206956505775, 57.29655168950558, 60.31234726309776, 63.61208260059357, 66.74760594964027, 61.36449560523033, 59.81233969330788, 58.09844546020031, 51.95323280990124, 56.45080827176571, 62.21207432448864, 61.44098550081253, 61.74504138529301, 62.26215183734894, 61.54033496975899, 60.62544286251068, 54.220149368047714, 50.92253051698208, 56.91055700182915, 59.38529200851917, 59.79991056025028, 58.64423677325249, 60.16316346824169, 59.60263654589653, 54.68012988567352, 59.75582532584667, 59.08112213015556, 59.504951387643814, 60.91588407754898, 61.35287582874298, 60.73879837989807, 60.62692478299141, 60.84537886083126, 61.68362148106098, 54.63763676583767, 57.84472547471523, 56.4544902741909, 58.33778701722622, 58.21515239775181, 59.944534599781036, 58.882119208574295, 57.45262451469898, 54.96764525771141, 57.19002440571785, 55.93661606311798, 57.629892602562904, 56.8952514231205, 59.57773648202419, 55.47413907945156, 55.134916082024574, 47.0313873142004, 53.41533735394478, 56.81140512228012, 60.38799740374088, 60.75406976044178, 63.11013713479042, 62.48945564031601, 65.11110216379166, 62.86657400429249, 61.48883253335953, 61.94962240755558, 61.73017278313637, 66.82829082012177, 66.6939528286457, 63.324905410408974, 57.438504472374916, 55.81912636756897, 51.65267653763294, 59.69212934374809, 56.90128169953823, 60.183439180254936, 51.431661397218704, 38.55554312467575, 24.42332625389099, 22.614463716745377, 29.021839499473572, 26.568240858614445, 8.511457778513432, 2.3245238419622183, 0.23687817592872307, 0.2168007509317249, 1.063548680394888, 0.912793135503307, 0.5771542363800108, 33.32799643278122, 77.0710363984108, 79.876669049263, 54.67121936380863, 48.86772237718105, 51.013425439596176, 61.62253215909004, 29.506108313798904, 0.4327312298119068, 0.2591586811468005, 16.77352923899889, 22.912610918283463, 14.06143331900239, 7.9770478047430515, 4.193079750984907, 12.604574393481016, 39.08091813325882, 71.3664785027504, 85.40539517998695, 41.40510901808739, 25.182337425649166, 19.969264157116413, 2.9043342545628548, 54.164007380604744, 76.8556335568428, 53.548497408628464, 44.26658347249031, 49.5531789958477, 80.62585964798927, 64.90529000759125, 61.152930557727814, 56.96137547492981, 0.4359036439564079, 1.0046543343923986, 0.17825078044552356, 0.5180272122379392, 0.16194825991988182, 0.43716084212064743, 1.133620364125818, 0.5386121920309961, 36.3337529450655, 74.69687819480896, 86.0314191877842, 74.78312596678734, 79.42776873707771, 76.26414969563484, 82.04063773155212, 84.18421670794487, 85.21341428160667, 85.43061822652817, 86.32848724722862, 82.83429354429245, 76.00181937217712, 65.3820352256298, 64.9233390390873, 65.53613215684891, 64.02198940515518, 74.37348514795303, 79.84731942415237, 77.20632433891296, 77.24118366837502, 77.96693712472916, 72.37970933318138, 72.05989569425583, 64.99339208006859, 57.01499059796333, 56.863477528095245, 64.83326867222786, 67.7378936111927, 72.61780455708504, 69.96379896998405, 69.47400525212288, 67.63454675674438, 62.75151617825031, 62.589918449521065, 62.237692549824715, 61.12809509038925, 69.24155652523041, 64.69246342778206, 67.16479316353798, 64.09315198659897, 67.0035982131958, 69.42697137594223, 69.6362717449665, 67.03332781791687, 64.33350428938866, 67.51839458942413, 65.26617184281349, 64.89596530795097, 63.6934058368206, 65.55586069822311, 69.86711695790291, 60.720699951052666, 60.73537856340408, 62.16040089726448, 67.46733292937279, 70.30017212033272, 66.4127679169178, 62.128376215696335, 60.470217391848564, 55.42816534638405, 60.2170217782259, 64.3131297826767, 64.5172244310379, 65.38911804556847, 65.5396431684494, 64.06881809234619, 65.46623110771179, 59.65442396700382, 56.61666177213192, 60.27000613510609, 59.85440343618393, 63.805066645145416, 62.42774695158005, 65.41451588273048, 61.95912949740887, 58.87049563229084, 62.5018809735775, 62.0077782869339, 62.586384639143944, 65.44131204485893, 65.69360330700874, 64.07577931880951, 63.96040990948677, 62.124242037534714, 65.53438425064087, 59.371076971292496, 61.69753633439541, 61.18362911045551, 64.32455196976662, 63.85064899921417, 63.68331357836723, 62.749426290392876, 62.245109751820564, 58.857766315340996, 61.12445868551731, 59.472007155418396, 59.26650658249855, 59.17526587843895, 63.10697190463543, 58.56190279126167, 60.269979536533356, 50.42118541896343, 57.881788685917854, 60.96189200878143, 64.8793525993824, 64.10217270255089, 66.86847746372223, 63.66628289222717, 70.03195211291313, 66.51799947023392, 64.03759896755219, 67.08735331892967, 65.98440930247307, 71.66725516319275, 72.74647325277328, 69.29400131106377, 61.55188634991646, 62.90606528520584, 60.260358452796936, 70.9259681403637, 64.06096771359444, 73.34655225276947, 65.67858651280403, 66.52606263756752, 52.984311282634735, 51.93928375840187, 35.63045248389244, 30.4903656989336, 10.08724082261324, 2.511727921664715, 0.21772561536636204, 0.305089132161811, 1.8276912393048406, 1.4889219612814486, 0.9423034207429737, 39.73952539265156, 85.49297288060188, 86.47498458623886, 64.8708638548851, 60.45238874852657, 56.651866883039474, 79.17617663741112, 37.02181622385979, 0.36888554168399423, 1.4861668716184795, 29.53303936868906, 22.956549860537052, 13.701719921082258, 8.75911708921194, 4.781415006145835, 15.254400204867125], [4.268199345096946, 23.07684190571308, 34.40363131463528, 4.963711174204946, 11.607003472745419, 11.520861145108938, 1.5354485646821558, 38.80042478442192, 46.80717274546623, 27.202360332012177, 22.704758271574974, 39.1950374096632, 47.88936607539654, 40.52310414612293, 41.58795140683651, 42.19626076519489, 0.3793052356922999, 0.31039376626722515, 0.24943102500401437, 0.30606303771492094, 0.1673594961175695, 0.11076481343479827, 0.1855122798588127, 0.17287907103309408, 13.28106064349413, 29.073256440460682, 64.27572458982468, 73.6198715865612, 63.968799859285355, 65.06428107619286, 66.6616241633892, 74.49409067630768, 75.47351852059364, 75.82392811775208, 74.81704294681549, 75.16006574034691, 63.59117612242699, 56.88756823539734, 59.49605606496334, 57.130132019519806, 57.1099779009819, 59.21396680176258, 70.99705472588539, 71.00682780146599, 68.91927301883698, 67.05674216151237, 72.73227721452713, 65.3713122010231, 61.67867034673691, 55.74539892375469, 49.656487852334976, 53.6678072065115, 61.40730790793896, 64.29968610405922, 61.650532856583595, 64.04375463724136, 62.88001008331776, 58.45054216682911, 52.648610696196556, 55.37252113223076, 58.287378922104836, 58.882521986961365, 59.467511996626854, 62.21663787961006, 61.288419887423515, 61.09455808997154, 55.22247478365898, 58.548991084098816, 60.496397987008095, 64.96343448758125, 64.33941677212715, 62.36662723124027, 59.02102455496788, 63.03816519677639, 64.22587886452675, 56.4280740916729, 59.433864802122116, 57.19094015657902, 57.22641125321388, 60.25860294699669, 58.69456507265568, 59.44007366895676, 56.59418597817421, 54.45692606270313, 48.94197799265385, 47.90915921330452, 54.905761778354645, 57.537014186382294, 60.50329081714153, 58.39782379567623, 59.52661782503128, 52.884350046515465, 44.653585106134415, 45.67279301583767, 52.456945180892944, 57.29741424322128, 58.26893091201782, 57.17097982764244, 59.703407138586044, 58.149438723921776, 54.24162581562996, 54.94862727820873, 55.028859972953796, 53.933473750948906, 56.155518516898155, 58.60250361263752, 56.204851269721985, 60.44536292552948, 55.78316889703274, 48.813898265361786, 51.245615780353546, 53.72605808079243, 53.42753849923611, 56.30524568259716, 55.56133300065994, 54.5062056183815, 55.7597279548645, 56.11639961600304, 53.531561717391014, 55.664596259593964, 55.99521651864052, 57.60417178273201, 56.12179532647133, 56.23632498085499, 51.54894970357418, 48.362843468785286, 44.01153355836868, 51.59066006541252, 53.86358790099621, 56.757797598838806, 60.32585933804512, 61.50614060461521, 63.07511441409588, 64.48690205812454, 63.25275108218193, 63.827044665813446, 64.7571511566639, 66.16686031222343, 67.01453402638435, 62.38332733511925, 59.75034601986408, 52.752850502729416, 49.78895254433155, 48.05836580693722, 51.47568963468075, 53.63024242222309, 56.10553219914436, 53.73942956328392, 46.86041168868542, 34.23753082752228, 11.659463457763195, 22.000160180032253, 26.973386518657207, 15.33060796558857, 6.92879187874496, 0.5606912635266781, 0.19949278357671574, 4.568238370120525, 0.12613204977242276, 0.1909448008518666, 24.201273769140244, 70.85116535425186, 70.89234754443169, 52.83837631344795, 44.3576417863369, 37.38251566886902, 63.695526123046875, 23.15108612179756, 0.24891952198231593, 0.677105913637206, 6.642628284171224, 3.7763231014832854, 1.50024559115991, 1.2440650002099574, 0.3727275808341801, 3.538074460811913, 21.672864742577076, 58.05360026657581, 66.21371939778328, 22.570916153490543, 17.13655035942793, 13.362088445574045, 2.266821563243866, 52.25130021572113, 57.91207306087017, 37.84330174326897, 35.19020810723305, 34.75151024758816, 62.43425980210304, 48.96728463470936, 50.07546856999397, 51.16241164505482, 0.19838077918393537, 0.372020848444663, 0.13844557106494904, 0.20437399274669588, 0.07459027212462388, 0.07518484373576939, 0.2732019260292873, 0.06366923509631306, 19.852669313549995, 48.488795310258865, 80.0297400355339, 69.90804076194763, 69.33927208185196, 66.81699022650719, 69.95287075638771, 78.48977386951447, 78.80424499511719, 81.19187727570534, 76.99759393930435, 79.76900562644005, 65.81513598561287, 62.85495042800903, 59.69944775104523, 57.19364181160927, 56.90156668424606, 62.35700234770775, 69.84222069382668, 74.49442505836487, 70.66321983933449, 67.68151223659515, 75.2368976175785, 66.72482997179031, 66.72143295407295, 57.53441892564297, 51.365119367837906, 55.41404150426388, 65.56437984108925, 66.41953155398369, 65.83264544606209, 66.24031037092209, 64.39300149679184, 57.25931368768215, 57.30409808456898, 55.874303206801414, 60.868637412786484, 62.49341882765293, 62.135751619935036, 61.987255588173866, 63.35225634276867, 64.33269113302231, 60.21034933626652, 61.98148749768734, 63.388559594750404, 65.72831064462662, 67.4065513908863, 64.3294309079647, 63.67420166730881, 63.21758396923542, 66.0517492890358, 62.11022838950157, 62.19010390341282, 58.46626952290535, 61.69740714132786, 64.02627557516098, 60.355885326862335, 61.035752445459366, 59.85641732811928, 57.24063389003277, 51.53982259333134, 48.3897840231657, 59.51948940753937, 61.29703402519226, 62.22725830972195, 60.51627852022648, 60.601538345217705, 53.224082216620445, 45.550823360681534, 46.44816800951958, 56.06652349233627, 59.1818243265152, 59.70665216445923, 57.359430715441704, 60.26340588927269, 61.771442368626595, 54.674300998449326, 57.02861666679382, 58.69482725858688, 58.20393919944763, 60.023657754063606, 62.128110229969025, 58.84803123772144, 62.8937691450119, 59.29495945572853, 51.96620911359787, 53.35797943174839, 57.58662432432175, 56.476692482829094, 59.36590924859047, 58.91118384897709, 57.18411572277546, 58.38138967752457, 58.49972292780876, 57.387841790914536, 60.20243436098099, 59.22211356461048, 60.366870537400246, 57.858875915408134, 60.201685801148415, 55.39770998060703, 50.725229904055595, 46.79945155978203, 54.487130641937256, 57.402041628956795, 58.84718008339405, 62.62567453086376, 62.59111538529396, 63.50588209927082, 64.67241570353508, 62.29831449687481, 64.17685389518738, 65.07416054606438, 65.7210910320282, 67.92012423276901, 64.46344211697578, 63.439666852355, 58.395323529839516, 56.20058409869671, 56.236845552921295, 60.204045474529266, 61.1723817139864, 66.6498675942421, 63.65082532167435, 59.78335864841938, 47.24491685628891, 29.78155553340912, 25.395517386496067, 33.647392094135284, 15.624144114553928, 6.877995254471898, 0.5937909311614931, 0.13124431920005009, 2.4072278290987015, 0.8797107450664043, 0.30136717250570655, 31.194538213312626, 76.02777197957039, 79.48927223682404, 61.82475730776787, 51.47275999188423, 43.451010435819626, 74.58948835730553, 27.616222724318504, 0.13534119701944292, 0.8636033500079066, 12.000149376690388, 14.309956133365631, 8.363305628299713, 4.27133085206151, 3.091521947644651, 7.479307763278484, 28.20649065077305, 85.86168989539146, 95.02583295106888, 37.861548364162445, 23.015701286494732, 17.99546007066965, 3.121786848641932, 58.96705985069275, 74.95629027485847, 52.35259138047695, 37.47807294130325, 53.294595032930374, 66.04130744934082, 56.730853244662285, 61.27924717962742, 61.424410790205, 0.49842620152048767, 0.44714866555295885, 0.32388197374530137, 0.3740871953777969, 0.23342015367234126, 0.3145836351905018, 0.31811955326702446, 0.2865661948453635, 29.57706570625305, 66.64519384503365, 91.25993102788925, 71.52708068490028, 77.18128368258476, 66.61784291267395, 74.48684066534042, 80.41640728712082, 86.44077882170677, 83.67661714553833, 82.9748784005642, 84.3159632384777, 74.12501648068428, 64.6872653067112, 64.34190943837166, 60.76019883155823, 63.09310644865036, 65.03549382090569, 74.33477282524109, 77.28418976068497, 73.00213873386383, 69.35785308480263, 76.9583648443222, 69.1692616045475, 68.03310737013817, 59.67795990407467, 55.008588060736656, 59.204512909054756, 67.71982938051224, 71.31916344165802, 67.07954853773117, 70.20304933190346, 68.29818114638329, 63.44464458525181, 59.03667971491814, 61.140524223446846, 64.8108422756195, 64.79999005794525, 63.96487846970558, 64.33359548449516, 65.89641362428665, 64.96384486556053, 64.69522967934608, 66.5550246834755, 64.42020043730736, 68.08459460735321, 67.63157531619072, 69.26306337118149, 64.52748388051987, 67.44359940290451, 68.79511088132858, 65.60818389058113, 63.10484781861305, 63.09075437486172, 63.35681229829788, 67.40111008286476, 64.82828333973885, 64.17055383324623, 63.47801059484482, 60.034050196409225, 53.99839326739311, 53.449326530098915, 62.70544745028019, 64.04218912124634, 66.4109668135643, 63.553888723254204, 64.13363501429558, 56.84606686234474, 47.70767122507095, 48.006620183587074, 58.81914138793945, 61.97041489183903, 62.5686851888895, 61.95374138653278, 63.94043818116188, 64.69494849443436, 58.66129785776138, 59.82158459722996, 60.27883306145668, 59.977839812636375, 60.82389861345291, 65.35835489630699, 61.6128084808588, 67.63253286480904, 61.60669460892677, 54.289043471217155, 54.689572378993034, 63.324529230594635, 58.27201634645462, 62.63065606355667, 61.49930477142334, 61.71471521258354, 60.966782346367836, 64.2526750266552, 61.29498593509197, 64.55212935805321, 62.825152426958084, 65.15231475234032, 61.11894518136978, 64.28705558180809, 58.70081573724747, 55.68921893835068, 48.47397990524769, 59.98006269335747, 60.9663225710392, 60.879717618227005, 67.36869782209396, 63.6360327154398, 67.35683485865593, 67.6818998157978, 67.14125722646713, 67.34452351927757, 68.84013086557388, 69.73951980471611, 71.42095997929573, 68.50456327199936, 68.2805272936821, 64.1077584028244, 62.24705524742603, 62.018090933561325, 66.86455607414246, 65.79798370599747, 72.36577928066254, 71.98891550302505, 74.08608376979828, 70.87048351764679, 55.46832539141178, 33.55012871325016, 40.233924463391304, 20.028879158198833, 8.654158171266317, 0.4669457516865805, 0.1897978116176091, 7.837630435824394, 1.008179357741028, 0.4477506363764405, 38.590482249855995, 82.66761928796768, 86.36410653591156, 72.37195774912834, 65.92120349407196, 51.64230689406395, 88.13093572854996, 33.69995467364788, 0.27664231485687196, 2.7244773181155324, 27.469098418951035, 15.161071512848139, 9.641066864132881, 6.1422972567379475, 2.445969837717712, 9.672486428171396], [3.5802709590643644, 44.71875920891762, 41.57807193696499, 12.087127659469843, 11.05813717469573, 9.658726416528225, 1.0673938365653157, 34.42329905927181, 40.86641572415829, 20.490164905786514, 15.743011236190796, 35.55840454995632, 34.80597272515297, 34.83300447463989, 47.24824167788029, 45.05535274744034, 2.0138157019391656, 0.05605157530226279, 0.40550862962845713, 0.1070908633118961, 0.31555302848573774, 0.1331070950254798, 1.0509436880238354, 2.254137843847275, 13.665210530161858, 43.76680389046669, 63.59233506023884, 71.89939990639687, 60.10767124593258, 62.44976297020912, 58.565197214484215, 65.84017664194107, 71.49602875113487, 74.05510023236275, 73.09603929519653, 70.33108726143837, 60.18055893480778, 56.9142922013998, 56.609111577272415, 55.35872407257557, 57.91583485901356, 53.09228628873825, 63.25788460671902, 71.75281897187233, 71.72665357589722, 65.37657871842384, 65.30224710702896, 67.85280704498291, 64.01486858725548, 57.364165261387825, 49.16558839380741, 52.2138874232769, 54.97753992676735, 61.580628007650375, 61.661681458353996, 62.24939592182636, 57.16651126742363, 54.46426346898079, 53.642481565475464, 54.2764737457037, 55.9162263572216, 61.109137907624245, 57.892344519495964, 61.97351172566414, 63.27355116605759, 62.78335466980934, 58.00969362258911, 53.41102458536625, 52.58140750229359, 57.49572940170765, 59.89921823143959, 61.236146092414856, 62.74965047836304, 62.74410657584667, 58.36877815425396, 59.19029787182808, 59.10924822092056, 56.531987115740776, 60.77454686164856, 61.37705773115158, 57.365141808986664, 59.11698080599308, 53.241120502352715, 48.635277450084686, 46.993590742349625, 43.54974053800106, 47.76803858578205, 52.43367902934551, 54.319768622517586, 54.2691895365715, 52.378844171762466, 45.98147325217724, 44.907187297940254, 46.33317478001118, 48.34962397813797, 52.259158194065094, 57.35086217522621, 57.6543252915144, 58.31808887422085, 58.11875157058239, 52.60724611580372, 53.95948715507984, 55.66586159169674, 53.88248048722744, 55.973527282476425, 55.12905299663544, 59.140858724713326, 55.27266249060631, 52.96819254755974, 50.92436581850052, 54.59067888557911, 52.989619597792625, 52.83483870327473, 54.448995888233185, 54.89625848829746, 52.75199554860592, 52.9848812520504, 54.57117833197117, 55.81939235329628, 57.18970142304897, 57.06021197140217, 55.0547631829977, 56.60468481481075, 55.22231139242649, 52.840025424957275, 48.133499175310135, 44.8670918494463, 52.56321407854557, 54.28122729063034, 60.189484655857086, 59.082246869802475, 64.31365415453911, 62.88086123764515, 62.38034449517727, 63.684179931879044, 64.08326491713524, 64.96563836932182, 65.62056362628937, 64.7649559378624, 63.5032032430172, 54.94368374347687, 52.627670019865036, 50.67474581301212, 49.533511251211166, 55.16482427716255, 57.28118151426315, 62.16482765972614, 60.95357425510883, 57.767164036631584, 44.883195385336876, 14.860497191548347, 12.632248308509588, 14.698018860071898, 14.062751848250628, 11.215102951973677, 6.403528964146972, 0.39049833663739264, 0.420710188918747, 0.6677729019429535, 0.08654267177917063, 25.956393890082836, 67.11316913366318, 70.64797505736351, 59.82330970466137, 37.00725920498371, 34.92060877382755, 60.19432559609413, 19.43062786012888, 0.2631643193308264, 1.00487852236256, 5.859393887221813, 4.5096326898783445, 0.5136544187553227, 0.7860575267113745, 0.6649326730985194, 2.6082529546692967, 13.02763894200325, 61.391854137182236, 71.11441522836685, 17.695407271385193, 16.177533119916916, 14.118567053228617, 2.234027897939086, 48.27736705541611, 52.26404093205929, 28.64466603845358, 23.12577947974205, 40.522712767124176, 37.37980641424656, 41.64592109620571, 56.1031611263752, 53.176482170820236, 2.8256818000227213, 0.07446128685842268, 0.5395974079146981, 0.06841738460934721, 0.16417627630289644, 0.23601680964929983, 0.6957467633765191, 1.0015571443364024, 18.920176550745964, 52.8834342956543, 76.52024075388908, 71.2276491522789, 67.5189645588398, 64.36182796955109, 63.57054702937603, 71.07403859496117, 76.25929355621338, 78.27282831072807, 77.63704642653465, 75.25714293122292, 63.15448075532913, 62.677891328930855, 60.17616257071495, 57.78727635741234, 59.06591534614563, 56.222489923238754, 65.34975215792656, 74.28150728344917, 72.37865298986435, 70.12641504406929, 65.03225639462471, 68.69028210639954, 66.7340786755085, 60.57643309235573, 53.11447709798813, 53.41927394270897, 57.03982226550579, 62.538689598441124, 66.47769883275032, 62.17521250247955, 61.25420652329922, 54.98430736362934, 54.963978454470634, 55.24163335561752, 58.87436382472515, 62.84219831228256, 61.197600960731506, 64.93793785572052, 65.79049810767174, 64.78869706392288, 60.30475527048111, 56.696012914180756, 55.287607088685036, 59.82240915298462, 62.91857421398163, 61.648021191358566, 65.86984544992447, 64.69992622733116, 62.648762091994286, 61.891607120633125, 61.331631168723106, 58.059535548090935, 63.70745748281479, 64.16635885834694, 60.98703905940056, 61.59974478185177, 56.22915096580982, 52.46979609131813, 48.58159773051739, 43.99130344390869, 49.21290725469589, 53.37962307035923, 54.849809780716896, 54.90580357611179, 52.604164481163025, 46.0691649466753, 45.70743955671787, 48.86007718741894, 48.564274460077286, 51.72164283692837, 60.41581951081753, 58.3022703230381, 61.19774155318737, 61.60333178937435, 57.165542319417, 55.72261914610863, 60.087053552269936, 57.6095674932003, 60.031511932611465, 59.01075750589371, 61.13100193440914, 57.33175680041313, 55.70597603917122, 54.318833872675896, 57.63241566717625, 54.465726390480995, 58.457355201244354, 58.3971132338047, 56.886185109615326, 57.77859002351761, 56.1673928797245, 57.67863258719444, 59.02612768113613, 58.369716703891754, 60.460425317287445, 58.69583800435066, 60.720175579190254, 58.86906310915947, 56.02807715535164, 51.54703460633755, 48.48343379795551, 56.46568067371845, 58.390923365950584, 61.96676328778267, 60.71782350540161, 64.46224138140678, 62.64304719865322, 62.16678075492382, 63.59437935054302, 65.51536247134209, 65.02559155225754, 67.16724023222923, 65.87087139487267, 65.42348340153694, 59.931584894657135, 57.13781140744686, 56.954425647854805, 55.87822459638119, 63.14754992723465, 64.69734996557236, 68.09543922543526, 70.2421872317791, 67.748783826828, 59.86800670623779, 29.245258010923862, 20.503390096127987, 30.673800855875015, 20.39147850126028, 15.320099629461765, 6.781373089179397, 0.7411640044301748, 1.3875574129633605, 0.33904405077919364, 0.05870146182132885, 36.75057917833328, 76.54028847813606, 78.19696918129921, 69.43649366497993, 45.564141646027565, 44.14903298020363, 72.305978089571, 23.498535677790642, 0.3334719763370231, 1.954071270301938, 10.516254901885986, 10.514717884361744, 5.070981793105602, 2.738399296067655, 1.5230273874476552, 3.968272414058447, 20.68159483373165, 101.12303897738457, 93.44600692391396, 28.475628308951855, 19.431902691721916, 15.946703106164932, 1.6710078343749046, 62.89483688771725, 66.12793520092964, 42.25126661360264, 25.049029178917408, 46.27391315996647, 48.80295105278492, 51.91128306090832, 66.4573547244072, 69.20765474438667, 3.094292711466551, 0.1759105216478929, 0.6053750251885504, 0.15411432716064155, 0.30277841084171087, 0.2832712372764945, 1.2257284903898835, 2.729562157765031, 27.72462710738182, 82.99853593111038, 79.86105188727379, 73.86396288871765, 76.9297143816948, 63.79743665456772, 70.35173535346985, 70.49187943339348, 82.91326090693474, 80.28573989868164, 83.46116870641708, 80.22862136363983, 69.03864741325378, 66.05025216937065, 63.22677567601204, 61.52701288461685, 65.75361728668213, 59.28356006741524, 71.502655595541, 79.20723617076874, 77.48424142599106, 72.11374640464783, 68.54753896594048, 71.08674511313438, 71.06542065739632, 63.40391457080841, 55.00834867358208, 56.45021550357342, 60.8222609013319, 66.6561296582222, 67.89613232016563, 66.35622695088387, 64.4013686478138, 58.80860075354576, 57.67231732606888, 59.9183464050293, 62.2353632748127, 67.9619599878788, 63.509222120046616, 67.89424762129784, 66.81915611028671, 68.00409972667694, 63.086198419332504, 60.0719303637743, 58.51026736199856, 62.408261597156525, 67.0116613805294, 63.311127349734306, 67.88345620036125, 67.5108177959919, 64.39050883054733, 65.86579486727715, 65.52713423967361, 60.0643003731966, 66.9308853149414, 68.02696689963341, 64.81148824095726, 66.45103946328163, 59.17023114860058, 55.59396184980869, 52.19850204885006, 45.49595050513744, 50.56059613823891, 56.06616251170635, 57.81085789203644, 58.835556507110596, 57.61293411254883, 47.86988452076912, 49.78159613907337, 50.74177421629429, 51.17807060480118, 56.59073196351528, 62.8038127720356, 62.91162818670273, 63.725685104727745, 65.31293973326683, 59.85982574522495, 60.15948906540871, 62.2854445874691, 59.97242510318756, 63.63686107099056, 62.86889187991619, 62.966995015740395, 62.31713108718395, 59.97089758515358, 56.622163876891136, 60.746546164155006, 57.82601147890091, 61.78743191063404, 62.23284400999546, 60.38833178579807, 60.743141546845436, 60.07403165102005, 61.11937455832958, 61.51651784777641, 65.59008926153183, 63.168213218450546, 60.73592193424702, 63.138069435954094, 62.641747668385506, 60.11990278959274, 55.004248693585396, 52.15450040996075, 59.493160620331764, 60.997256711125374, 65.88486984372139, 63.757979571819305, 69.46895152330399, 69.75834399461746, 65.73777973651886, 69.00090023875237, 69.92805048823357, 71.11940816044807, 71.15748211741447, 70.33312395215034, 70.93265578150749, 61.022597551345825, 62.50749707221985, 60.34078873693943, 60.31412936747074, 66.97946950793266, 69.6037682890892, 69.86116647720337, 76.29853025078773, 73.57499599456787, 71.51923790574074, 50.218777880072594, 30.136308297514915, 41.69123746454716, 28.375342190265656, 21.13494660705328, 7.718572849407792, 0.5888690077699721, 1.8279804987832904, 0.8849841495975852, 0.14656552753876895, 48.92154648900032, 80.02426072955132, 87.17632815241814, 76.60265073180199, 59.32667255401611, 48.719492331147194, 86.50243431329727, 29.29499924182892, 0.36483816511463374, 3.502655611373484, 24.712245650589466, 14.62992936372757, 8.168926108628511, 4.696677653118968, 1.8245742190629244, 6.788511481136084], [7.939742831513286, 48.34832824766636, 37.931487411260605, 14.640942122787237, 13.605615478008986, 8.361736312508583, 0.052863156743114814, 37.86198154091835, 36.40948288142681, 18.474946841597557, 23.159382976591587, 32.88866400718689, 46.9079053401947, 43.85970890522003, 48.72233837842941, 38.17867934703827, 4.6612531039863825, 0.021768987353425473, 0.4964250448392704, 0.09467228359426372, 0.2410832143505104, 0.08694818869116716, 0.37671223108191043, 1.8441831856034696, 18.453952968120575, 49.98826704919338, 63.692524284124374, 66.04701474308968, 61.11513018608093, 67.00670644640923, 57.413927391171455, 58.636614382267, 61.20923973619938, 67.22638785839081, 64.03105571866035, 61.649092733860016, 55.58661304414272, 56.62037417292595, 55.9387743473053, 54.68605376780033, 57.18470849096775, 53.95838141441345, 55.1067253947258, 62.295464649796486, 72.23821252584457, 69.08630445599556, 67.71744310855865, 61.14308908581734, 64.74123001098633, 57.92875416576862, 49.18082557618618, 50.768122002482414, 53.357553854584694, 54.23920154571533, 56.19036644697189, 58.62691730260849, 56.33821651339531, 52.517365738749504, 53.31772059202194, 54.05059486627579, 56.200367510318756, 59.42862868309021, 59.520705342292786, 62.74240806698799, 60.92734046280384, 66.79611414670944, 59.64053951203823, 52.498450353741646, 53.451272025704384, 57.40669257938862, 49.76091384887695, 54.120822697877884, 59.66357387602329, 60.38694866001606, 57.38909192383289, 59.29708354175091, 57.819620221853256, 58.23944829404354, 59.45268139243126, 57.09404535591602, 60.55827006697655, 54.56667557358742, 48.42035338282585, 44.029312804341316, 45.095018818974495, 45.019368678331375, 46.421197056770325, 44.008687511086464, 41.019171327352524, 41.05048544704914, 42.37806960940361, 46.440739408135414, 43.63682806491852, 42.471958771348, 44.34307336807251, 47.63449855148792, 46.68092831969261, 55.64148209989071, 59.52614285051823, 56.29365250468254, 56.46234445273876, 53.81374977529049, 56.26666635274887, 56.992928981781006, 54.99572195112705, 56.27780355513096, 59.387678280472755, 51.58380903303623, 50.65445490181446, 52.24991329014301, 53.51483881473541, 54.00996744632721, 55.64832553267479, 53.84596824645996, 53.53417977690697, 52.399819046258926, 54.15176823735237, 52.8321598470211, 54.87294673919678, 54.66289021074772, 55.0420718640089, 54.123129174113274, 56.401163935661316, 53.222444504499435, 52.50214375555515, 45.66001810133457, 45.652190521359444, 52.88524679839611, 59.38457004725933, 56.79382726550102, 59.1145945340395, 62.55336821079254, 61.68942756950855, 60.45247234404087, 59.686471447348595, 61.971304044127464, 58.975366204977036, 64.64333206415176, 59.5006500184536, 60.22367142140865, 56.162240356206894, 54.51307184994221, 52.111220732331276, 52.77794435620308, 58.59610095620155, 59.516810551285744, 65.14371201395988, 63.5859552025795, 65.77586129307747, 48.599312379956245, 19.029116705060005, 6.379348011687398, 5.158882001414895, 6.250779060646892, 11.433291044086218, 17.746689319610596, 2.5620702328160405, 0.6140193832106888, 0.4064217087579891, 0.8041053113993257, 46.363683342933655, 65.85180401802063, 70.49672037363052, 63.11411552131176, 36.27962484955788, 30.13211902230978, 56.27493090927601, 20.546804666519165, 0.3861460561165586, 1.74958358053118, 5.232853582128882, 4.185483008623123, 1.2327669002115726, 0.22800588951213285, 0.5927329254336655, 2.1682515274733305, 15.830662082880735, 70.55987298488617, 48.56724590063095, 18.32170106470585, 15.65417105332017, 12.896595373749733, 0.7284243567846715, 53.77469167113304, 46.91556192934513, 26.589025743305683, 24.58545595407486, 36.75107695162296, 56.17807410657406, 47.586127147078514, 59.323913902044296, 51.19719497859478, 6.057799765840173, 0.20522897655609995, 0.3971912618726492, 0.11234617428272031, 0.15763243369292468, 0.23788982711266726, 0.5990108416881412, 4.04753758572042, 20.079372748732567, 66.04930222034454, 77.03486233949661, 67.44151711463928, 70.15766456723213, 68.87555256485939, 63.19308668375015, 64.0925744175911, 68.17195951938629, 71.10494613647461, 70.47501593828201, 66.68592005968094, 60.07035344839096, 60.34074313938618, 60.381602346897125, 57.68374711275101, 57.548770755529404, 58.827854320406914, 55.752424746751785, 66.2320040166378, 72.14436516165733, 72.20595985651016, 69.09990772604942, 63.30369494855404, 65.92874988913536, 61.47173345088959, 52.77154929935932, 52.37960413098335, 54.319776222109795, 57.46696874499321, 58.80611948668957, 62.98524163663387, 57.560880705714226, 53.93761172890663, 54.53702196478844, 55.42432755231857, 59.58111070096493, 60.39996296167374, 62.84489616751671, 64.65786248445511, 63.593585193157196, 69.07677456736565, 62.81044341623783, 54.486332684755325, 56.20897024869919, 59.05480094254017, 51.84856362640858, 57.001144140958786, 63.37203048169613, 60.14686234295368, 60.867885053157806, 60.92619672417641, 58.754332065582275, 58.44596341252327, 62.243928015232086, 59.3096836656332, 63.496925979852676, 56.94877915084362, 51.657601073384285, 45.09804725646973, 46.909349262714386, 46.6987531632185, 49.57186259329319, 42.573717311024666, 39.79654513299465, 41.10237546265125, 42.700432911515236, 47.21619039773941, 46.746136620640755, 42.08883672952652, 47.74625435471535, 51.959088295698166, 50.457967445254326, 54.154808074235916, 61.268740743398666, 58.527149856090546, 61.215547397732735, 57.37995721399784, 57.63054616749287, 57.43762291967869, 58.65929156541824, 59.68331001698971, 61.73556849360466, 53.45414087176323, 54.662757217884064, 55.44220559298992, 57.11121283471584, 57.021381855010986, 58.00411932170391, 57.20440663397312, 57.65585660934448, 56.155320927500725, 57.114309668540955, 55.26452712714672, 58.25042970478535, 58.90095479786396, 57.60130673646927, 56.38018146157265, 57.52528801560402, 58.33980850875378, 54.899279326200485, 48.98616202175617, 48.89322280883789, 57.05428808927536, 60.74078567326069, 61.13726779818535, 59.985333010554314, 64.22014877200127, 64.35152292251587, 60.54611071944237, 60.22137254476547, 62.51995660364628, 61.15334093570709, 68.3336940407753, 64.62735772132874, 65.32089650630951, 63.63338805735111, 59.878178760409355, 56.85235172510147, 58.81062984466553, 62.96004518866539, 66.17302358150482, 70.81821352243423, 71.34468287229538, 71.03512868285179, 62.400107234716415, 32.3803348839283, 16.569442190229893, 19.851177893579006, 16.271232292056084, 21.172615885734558, 18.423529900610447, 2.8478303365409374, 1.2428076239302754, 0.14541505021043122, 1.1412712535820901, 57.73257449269295, 75.92511668801308, 80.55756211280823, 71.9712008535862, 46.19276851415634, 37.028519064188, 64.91701617836952, 24.71248123794794, 0.5247640132438391, 1.8037287751212716, 8.778753485530615, 10.204483531415462, 3.603762248530984, 2.9301025718450546, 0.5888069642242044, 2.873014435172081, 32.75041602551937, 125.12206479907036, 66.36488288640976, 23.924367427825928, 19.356955513358116, 12.721188236027956, 0.6116336456034333, 71.25842750072479, 60.72980806231499, 41.56780108809471, 39.466540440917015, 45.20278483629227, 58.31939600408077, 63.80898043513298, 64.96617034077644, 68.04101094603539, 7.551456391811371, 0.2681763394502923, 0.5930876720231026, 0.1802712181233801, 0.24545257911086082, 0.2253196859965101, 0.4935606219805777, 3.509363913908601, 35.06286934018135, 75.24784103035927, 73.48405927419662, 72.42704719305038, 74.47984904050827, 69.61497768759727, 67.7847146987915, 66.15024760365486, 74.10328164696693, 73.7178835272789, 74.18987140059471, 69.4335526227951, 66.3766622543335, 66.17170125246048, 65.895334482193, 62.02242270112038, 62.55906030535698, 60.35655029118061, 59.83763873577118, 68.91687914729118, 80.24997621774673, 76.1556351184845, 73.34769979119301, 66.99976041913033, 69.23955023288727, 65.42995065450668, 54.270477667450905, 57.155890837311745, 57.012197747826576, 59.99909967184067, 59.689841866493225, 65.724176466465, 62.182314321398735, 56.85279630124569, 57.33776807785034, 56.787595599889755, 63.89968916773796, 64.55060943961143, 65.51651760935783, 69.74473312497139, 66.07663795351982, 68.6450569331646, 65.41698575019836, 57.49196380376816, 58.36374342441559, 62.908683344721794, 55.21575294435024, 58.690936267375946, 60.457415878772736, 67.29731485247612, 65.01426056027412, 63.925436586141586, 64.37292337417603, 64.29790019989014, 67.47237145900726, 62.09666691720486, 65.07749676704407, 60.88661804795265, 53.13215754926205, 48.60123127698898, 50.60901314020157, 49.08907949924469, 50.955292358994484, 45.97369506955147, 41.75706893205643, 44.14628192782402, 44.78174462914467, 49.67821508646011, 48.72557960450649, 45.72593316435814, 50.551822409033775, 54.397561848163605, 52.259545773267746, 59.235424250364304, 63.808288872241974, 60.47964848577976, 63.73575076460838, 61.13459274172783, 61.82105630636215, 61.787177324295044, 60.047915652394295, 60.70072442293167, 65.50694972276688, 57.79837176203728, 55.57047910988331, 60.188147127628326, 59.96701039373875, 61.37496404349804, 60.80038547515869, 60.99138222634792, 61.67186491191387, 59.949310943484306, 59.347366243600845, 58.93696926534176, 60.92935435473919, 59.958270862698555, 61.84765487909317, 60.26669271290302, 62.857078313827515, 60.4848276078701, 57.1642541885376, 51.911632642149925, 52.86354996263981, 61.60059593617916, 62.21577152609825, 63.55940982699394, 63.899066001176834, 67.67968073487282, 69.17059913277626, 63.44826199114323, 66.00310429930687, 68.00393253564835, 65.12252435088158, 73.54876220226288, 68.60231682658195, 68.32733318209648, 68.38236942887306, 65.54159626364708, 61.46692670881748, 64.12991881370544, 65.48290461301804, 68.97025108337402, 70.56276842951775, 77.32899695634842, 76.25400424003601, 74.81804609298706, 56.15241788327694, 28.124344758689404, 28.83220687508583, 30.37242002785206, 30.422923117876053, 22.64956623315811, 5.111809652298689, 1.801706689875573, 1.107719885185361, 1.09570148633793, 72.69335970282555, 80.09231507778168, 88.14258590340614, 78.3256758749485, 60.10922156274319, 43.00359584391117, 78.40870901942253, 30.80030746757984, 0.4789431329118088, 3.8363679545000196, 19.785671308636665, 14.798673558980227, 7.967484667897224, 6.0660733468830585, 0.9478293335996568, 7.032279800623655], [13.918492589145899, 30.87928432971239, 19.24108263105154, 12.184365391731262, 10.955051556229591, 5.45122928917408, 3.6906460113823414, 41.95326380431652, 33.771774619817734, 16.05719167739153, 33.45308192074299, 44.510868564248085, 43.876921981573105, 42.00204558670521, 55.44564440846443, 38.76667499542236, 10.095645971596241, 0.08333727659191936, 0.3015682054683566, 0.027743619393731933, 0.3798573341919109, 0.3410525101935491, 1.185705594252795, 2.8476215852424502, 19.0507223457098, 38.07611905038357, 56.65505491197109, 59.67269718647003, 63.40691640973091, 63.42690333724022, 60.171431824564934, 59.774178341031075, 55.30008941888809, 58.28886464238167, 52.46755041182041, 55.299827232956886, 53.31369660794735, 55.57528965175152, 57.09351718425751, 56.80222861468792, 57.389889881014824, 54.71160739660263, 52.03210137784481, 56.678921431303024, 61.83271788060665, 66.82414904236794, 70.32815381884575, 63.99488925933838, 62.23713777959347, 55.87305307388306, 53.70127961039543, 50.37075832486153, 50.34639783203602, 54.15471687912941, 53.412555903196335, 53.349562883377075, 52.216239497065544, 53.22293467819691, 53.364002108573914, 56.30348637700081, 56.617524325847626, 60.21544486284256, 61.44846349954605, 64.63795155286789, 59.55092512071133, 67.02999159693718, 62.85886041820049, 50.07119759917259, 53.25352683663368, 52.11036957800388, 52.76196241378784, 51.133263409137726, 54.99770924448967, 58.653633669018745, 54.91852529346943, 57.734466791152954, 54.549926072359085, 54.93988014757633, 57.29467459022999, 61.08042284846306, 59.78613629937172, 49.21721242368221, 43.348640128970146, 42.05206610262394, 48.37883681058884, 51.24347269535065, 41.97350911796093, 36.00537836551666, 33.815738260746, 36.32644973695278, 36.98116600513458, 45.975047796964645, 48.883115351200104, 42.74672582745552, 46.75276346504688, 51.45448297262192, 43.44932712614536, 44.5719350874424, 54.21531222760677, 57.19080336391926, 58.150673657655716, 52.38258317112923, 55.32089330255985, 55.713982209563255, 53.480127677321434, 58.87887418270111, 53.222923278808594, 49.3786695599556, 49.75741043686867, 54.458179995417595, 55.47383889555931, 53.77211920917034, 52.94877178966999, 54.3044326454401, 54.24009449779987, 50.628912672400475, 52.39023216068745, 52.0185437053442, 54.01253990828991, 57.75760754942894, 56.23306095600128, 52.82937079668045, 51.195238083601, 50.750783532857895, 52.09785304963589, 45.39548009634018, 45.44561080634594, 54.85156148672104, 58.840374648571014, 60.5821517854929, 61.060181334614754, 58.39935511350632, 58.98487709462643, 56.77324377000332, 52.18350425362587, 52.59910695254803, 53.6660972982645, 57.8065375238657, 56.731582805514336, 59.22359548509121, 55.23052655160427, 53.3110823482275, 51.92170970141888, 55.713252648711205, 57.919254675507545, 63.6123675853014, 63.93628880381584, 67.5910010933876, 62.8785015642643, 51.59111604094505, 27.907967269420624, 8.410542793571949, 10.183325316756964, 6.572259860113263, 10.963937379419804, 23.085186257958412, 12.710855640470982, 0.7185685762669891, 0.5856001144275069, 0.21143760590348393, 29.269419014453888, 75.64768597483635, 67.57666066288948, 63.284088000655174, 35.209104493260384, 40.33432647585869, 54.85912688076496, 26.347436606884003, 0.8082147315144539, 0.9849903301801533, 4.222048921510577, 4.452916933223605, 1.3292818400077522, 1.9596042484045029, 0.6375782971736044, 4.285288453102112, 17.74045005440712, 73.56071636080742, 19.67815227806568, 18.488553911447525, 13.040856532752514, 10.575897451490164, 3.9358915016055107, 57.387275621294975, 44.136930629611015, 26.463596373796463, 28.149284720420837, 47.46115565299988, 45.20441114902496, 47.89193093776703, 63.94438996911049, 51.175710931420326, 13.388844709843397, 0.34798808803316206, 0.2521882520522922, 0.049621188518358395, 0.16491165559273213, 0.4264327709097415, 0.47366203973069787, 4.056748766452074, 25.871823728084564, 59.680418372154236, 68.46059203147888, 64.12131607532501, 70.11644437909126, 62.542147412896156, 67.73779481649399, 61.40510022640228, 59.47855420410633, 58.33894595503807, 59.92758750915527, 56.67167901992798, 58.56457404792309, 57.326133102178574, 60.36579139530659, 60.54137997329235, 59.53415662050247, 56.57850421965122, 53.83087545633316, 59.94606591761112, 62.966900020837784, 68.89046296477318, 72.20646142959595, 70.14463886618614, 62.25853443145752, 59.41219076514244, 55.37018045783043, 53.27936924993992, 52.59847238659859, 56.06352165341377, 54.39137578010559, 55.17268605530262, 54.30894300341606, 56.11351557075977, 55.71663446724415, 55.298394709825516, 59.3885712325573, 61.941779628396034, 63.08023273944855, 65.52226290106773, 64.36863720417023, 67.715854793787, 61.484181582927704, 52.41239257156849, 54.917544946074486, 55.081680938601494, 54.66063693165779, 53.656571209430695, 58.14058139920235, 61.55109219253063, 58.85962441563606, 59.815881103277206, 57.56262481212616, 58.84733207523823, 62.064980417490005, 61.47206403315067, 57.97724336385727, 51.446514800190926, 45.055546537041664, 45.80355539917946, 49.66594934463501, 54.815379828214645, 41.89070016145706, 34.67574991285801, 34.84346531331539, 35.672603622078896, 37.76045858860016, 45.82183621823788, 54.06525067985058, 44.38377298414707, 49.19717609882355, 49.758728966116905, 43.07212516665459, 45.15595234930515, 55.612409859895706, 59.89129565656185, 60.40362596511841, 53.21900188922882, 58.09996917843819, 59.11816634237766, 59.596655666828156, 60.79417660832405, 56.23702794313431, 51.370161697268486, 52.800484746694565, 57.891409769654274, 58.59342209994793, 58.29247824847698, 57.16618448495865, 56.1138803511858, 56.089086681604385, 54.37674656510353, 54.50897566974163, 54.39693868160248, 56.60315349698067, 57.45999991893768, 58.12591418623924, 54.05971817672253, 56.101272627711296, 51.76299221813679, 54.85457092523575, 48.41844588518143, 48.53569999337196, 56.90936766564846, 60.4850821942091, 62.26207584142685, 63.22696566581726, 60.06736300885677, 60.29933676123619, 57.53263682126999, 56.045043244957924, 56.57373547554016, 57.1121209859848, 59.44380506873131, 60.81984803080559, 61.88243821263313, 58.76168467104435, 59.120218232274055, 57.70794801414013, 59.35500003397465, 63.34875673055649, 66.5853850543499, 70.22457897663116, 72.30304464697838, 71.13448575139046, 62.81784541904926, 42.8347747027874, 17.165592201054096, 11.185383796691895, 8.106276020407677, 19.42029431462288, 28.750503659248352, 13.841832652688026, 1.3459421647712588, 0.2678726229351014, 0.3112966928165406, 40.68815588951111, 82.49330744147301, 75.81531777977943, 73.88987749814987, 45.95549404621124, 40.83450123667717, 66.96390554308891, 32.17854671180248, 0.9592275938484818, 2.2163400845602155, 10.361444558948278, 10.401561856269836, 4.600092060863972, 1.4829137711785734, 0.6951550045050681, 4.476571613922715, 40.174328461289406, 105.18080323934555, 26.677889674901962, 21.25628549605608, 15.355653371661901, 9.070681370794773, 5.8000842947512865, 77.01699569821358, 55.81369265913963, 40.24203322827816, 44.167689979076385, 59.22782085835934, 53.748180493712425, 61.87341749668121, 69.4893716275692, 68.09481605887413, 19.037261568009853, 0.7988367753569037, 0.4785854771034792, 0.24534239986678585, 0.4129204584751278, 0.5914742429740727, 1.1475752340629697, 8.232776932418346, 42.94984012842178, 64.5691828429699, 67.83385366201401, 74.80503559112549, 70.65347716212273, 66.58038452267647, 69.9358020722866, 66.44023284316063, 62.683131247758865, 62.903933599591255, 62.61814333498478, 60.28379179537296, 63.37832294404507, 61.71091541647911, 66.71716198325157, 62.86107949912548, 65.30530974268913, 58.972896337509155, 57.40935243666172, 62.73937202990055, 68.04660424590111, 70.32704427838326, 76.5749654173851, 72.28922858834267, 66.53578251600266, 62.43547573685646, 58.437436670064926, 55.725712180137634, 56.40383139252663, 59.61530886590481, 56.98663271963596, 60.168448984622955, 56.88913755118847, 55.636926144361496, 56.15237608551979, 60.329833924770355, 61.10381059348583, 66.28742784261703, 66.20656058192253, 68.74417841434479, 64.89587411284447, 74.57691103219986, 60.790973380208015, 52.63473004102707, 58.968659564852715, 58.17210450768471, 56.492910012602806, 54.105995893478394, 60.38583151996136, 62.003632709383965, 62.66273394227028, 61.45467236638069, 60.07096141576767, 60.63696764409542, 64.88509029150009, 65.49979850649834, 63.38760584592819, 55.938960537314415, 49.41140480339527, 47.47209906578064, 52.49278485774994, 56.48708872497082, 44.07667726278305, 37.06519089639187, 35.74900232255459, 37.23663009703159, 39.55890968441963, 48.668426871299744, 55.999605283141136, 46.55553124845028, 51.196351423859596, 50.35479158163071, 43.248086124658585, 50.937653705477715, 57.386143282055855, 63.391090258955956, 63.502412885427475, 57.355615720152855, 61.200515404343605, 61.07939310371876, 60.416210889816284, 62.4919331073761, 60.415842309594154, 54.912324026227, 56.41121819615364, 60.54851979017258, 62.11717061698437, 62.15180955827236, 59.07322235405445, 59.965551272034645, 60.29381565749645, 55.55638566613197, 59.22919258475304, 57.89927154779434, 62.2831305116415, 62.325999811291695, 63.50536532700062, 61.321158930659294, 60.465102866292, 56.16342969238758, 60.1698587089777, 54.28902067244053, 53.01079586148262, 60.98272629082203, 63.673479706048965, 65.09125202894211, 66.66027143597603, 63.2500684261322, 64.57903951406479, 60.03700263798237, 59.17545586824417, 61.86475396156311, 63.409397676587105, 66.49168208241463, 65.55760860443115, 69.10009011626244, 64.08935979008675, 63.696023896336555, 61.64594650268555, 64.94373634457588, 65.87942853569984, 71.10295504331589, 73.40277403593063, 77.06339120864868, 76.8609456717968, 72.07310378551483, 61.690020337700844, 37.55403846502304, 24.08779475837946, 22.62973129749298, 32.59089678525925, 37.35376641154289, 17.266317196190357, 5.531781641766429, 1.0170187521725893, 0.5817895720247179, 53.541475385427475, 85.43117299675941, 83.01256477832794, 79.58101451396942, 59.30059835314751, 55.972926914691925, 79.53718766570091, 42.30430796742439, 1.021027893293649, 6.9719295389950275, 21.337874718010426, 17.729683332145214, 10.86323518306017, 3.7780650705099106, 0.8479667140636593, 7.048216620460153], [9.919426627457142, 12.304665986448526, 8.812511824071407, 10.853753741830587, 7.776059964671731, 2.1061659464612603, 4.251103587448597, 44.30774666368961, 35.469249933958054, 15.396164897829294, 29.971380047500134, 33.278823271393776, 71.05021387338638, 47.90423847734928, 58.32987584173679, 52.27199010550976, 19.059334583580494, 0.168268300476484, 0.3140375926159322, 0.1009734216495417, 0.12549947277875617, 0.13198704575188458, 2.741046091541648, 7.478994280099869, 15.647346619516611, 29.51167121529579, 48.16681198775768, 54.398720785975456, 67.52435266971588, 62.4910743534565, 63.73334549367428, 58.291117921471596, 58.55182193219662, 56.06700986623764, 53.32361027598381, 53.81936967372894, 52.14050196111202, 53.63186873495579, 56.57720848917961, 58.58861915767193, 58.754066079854965, 56.71453692018986, 51.67403519153595, 54.56431210041046, 52.236169427633286, 60.515571758151054, 58.587414622306824, 64.05473604798317, 58.301571160554886, 55.509575977921486, 51.00453391671181, 51.37525722384453, 47.19920910894871, 47.25095473229885, 50.08463367819786, 50.231719985604286, 52.59884476661682, 53.23762468993664, 57.67565354704857, 57.11676433682442, 59.02564890682697, 55.29969424009323, 61.56411029398441, 60.36320373415947, 64.76166531443596, 56.49171307682991, 56.268490254879, 56.16302311420441, 52.75320768356323, 51.16276502609253, 49.398983269929886, 49.6923541277647, 51.926759630441666, 62.8911966830492, 59.66622233390808, 55.73029473423958, 51.79144889116287, 55.71743242442608, 57.32569992542267, 48.51680360734463, 42.70312316715717, 42.76437968015671, 39.54985477030277, 42.306770235300064, 49.304698929190636, 59.21357162296772, 47.4329649657011, 33.85027460753918, 32.305779084563255, 32.93316341936588, 35.15870779752731, 52.07457169890404, 52.625329345464706, 47.70914934575558, 46.58764712512493, 42.983893901109695, 47.25955367088318, 39.39201503992081, 47.54130095243454, 54.84863184392452, 56.880018040537834, 53.37000958621502, 51.06598421931267, 57.62077309191227, 59.39934745430946, 54.61410082876682, 52.485766634345055, 51.6412353515625, 50.60433939099312, 50.96836745738983, 53.1659035384655, 56.18229188024998, 56.61907844245434, 56.128163784742355, 52.72842161357403, 48.564377054572105, 48.670889139175415, 53.000878393650055, 50.60697644948959, 48.27739745378494, 48.47695134580135, 47.6897019892931, 47.47511990368366, 50.723789781332016, 47.60856494307518, 43.70804384350777, 45.01645803451538, 56.158630549907684, 57.806738913059235, 62.342137545347214, 63.66163574159145, 61.72069229185581, 60.203650295734406, 53.38922135531902, 50.43628580868244, 46.712326034903526, 46.49945765733719, 49.55471411347389, 50.16892455518246, 52.1866200864315, 51.59016229212284, 53.34541730582714, 52.13064529001713, 55.95441810786724, 59.10393610596657, 62.30255126953125, 64.12586063146591, 66.67119964957237, 63.031010180711746, 56.43155090510845, 38.02340067923069, 13.97402185946703, 10.010375697165728, 9.26742721349001, 13.947527781128883, 27.988551445305347, 22.985542304813862, 1.13612704211846, 0.22165053756907582, 0.09944234872818924, 53.795206770300865, 76.08726918697357, 64.91449311375618, 66.1494192481041, 31.168277822434902, 37.54488855600357, 47.02554702758789, 15.288137644529343, 0.2810902433702722, 1.5733668487519026, 7.902813563123345, 7.3413485661149025, 2.5765845039859414, 3.1103036273270845, 0.6142426212318242, 7.610936500132084, 20.31808353960514, 56.98927357792854, 12.688629683107138, 14.83003992587328, 11.727218572050333, 5.547846229746938, 8.78605479374528, 55.780524238944054, 45.36413177847862, 24.190142266452312, 29.058743119239807, 39.93749096989632, 67.67562255263329, 59.14402015507221, 66.26847445964813, 65.3826279938221, 24.409992769360542, 0.2009451962658204, 0.21369726746343076, 0.19748849503230304, 0.04579824482789263, 0.29761089594103396, 1.7888018698431551, 8.304662425071001, 23.35646130144596, 44.06091570854187, 61.934989392757416, 62.08155892789364, 73.02134290337563, 64.73540112376213, 69.04685497283936, 61.322257071733475, 63.27436812222004, 58.18111762404442, 59.4007533788681, 57.170656844973564, 57.49707832932472, 58.61828416585922, 61.746933683753014, 61.10327482223511, 64.11686271429062, 59.83196943998337, 53.67813505232334, 56.29127383232117, 55.05279488861561, 62.189389541745186, 62.93531231582165, 65.60819908976555, 60.007637813687325, 59.255646765232086, 53.00799161195755, 52.06971935927868, 50.233030915260315, 51.16996943950653, 52.373646050691605, 55.219491943717, 53.957971036434174, 57.892234325408936, 58.758542239665985, 60.20540580153465, 59.351713210344315, 58.27916756272316, 63.12241807579994, 62.99449034035206, 67.90958359837532, 59.57943499088287, 55.17788417637348, 58.39427478611469, 54.150312915444374, 55.233805775642395, 53.10302451252937, 51.62031747400761, 52.8870403021574, 64.73012700676918, 63.28301265835762, 58.33516135811806, 55.293188989162445, 57.721243500709534, 59.193132519721985, 52.098400220274925, 45.19436828792095, 47.756620198488235, 42.91734427213669, 46.343137845396996, 51.53679035604, 61.260628178715706, 52.80885189771652, 35.13094648718834, 32.34687387943268, 32.60184399783611, 36.77090808749199, 54.780083522200584, 55.57665757834911, 48.79513867199421, 48.00091668963432, 44.72316317260265, 48.27498458325863, 41.90000206232071, 47.6603789627552, 57.81938083469868, 59.392462223768234, 56.46161109209061, 54.53496627509594, 59.304857924580574, 61.952730640769005, 61.21794506907463, 54.65922720730305, 53.64573039114475, 54.62913282215595, 55.27910314500332, 56.166116148233414, 58.80681864917278, 59.39465470612049, 58.58458757400513, 54.21787329018116, 50.87133586406708, 50.88526971638203, 54.42522436380386, 53.0099219083786, 50.85066497325897, 50.88568389415741, 50.64619414508343, 51.90095901489258, 51.35437734425068, 49.01366874575615, 46.038804575800896, 47.07533195614815, 57.80207276344299, 59.2074653506279, 60.83651393651962, 62.89046712219715, 63.510704040527344, 60.51622152328491, 56.851686760783195, 54.594687670469284, 51.069704219698906, 50.717390924692154, 54.56731773912907, 56.190370246768, 56.15484595298767, 57.18777112662792, 58.76117929816246, 55.74179291725159, 61.48893512785435, 62.73630179464817, 66.53511375188828, 66.22345447540283, 72.66087144613266, 71.89309224486351, 66.24148070812225, 51.76576606929302, 25.01584555953741, 17.312220633029938, 12.588912583887577, 20.674679204821587, 38.36531013250351, 27.833379171788692, 2.0167220709845424, 0.4085307440254837, 0.30788272444624454, 60.20052306354046, 84.9054180085659, 70.9203976392746, 77.50118851661682, 41.231374740600586, 39.639073982834816, 59.101789221167564, 29.195020906627178, 0.7715880812611431, 4.2270665522664785, 11.273929495364428, 11.414859183132648, 4.115395769476891, 3.801591033115983, 0.17729090148350224, 3.8931209966540337, 28.51894598454237, 48.20200189948082, 13.081150520592928, 15.905713755637407, 10.862187389284372, 4.20913246460259, 11.316477712243795, 76.59952729940414, 57.85477973520756, 39.455049857497215, 42.85155840218067, 48.218994587659836, 80.36115065217018, 70.59827372431755, 71.39009043574333, 78.86975347995758, 33.31886552274227, 0.24981857452075928, 0.7387133734300733, 0.2547807223163545, 0.28039989760145545, 0.2960404223995283, 3.2759742625057697, 15.785301066935062, 33.329691141843796, 50.04524499177933, 65.17787978053093, 70.07071763277054, 73.39110866189003, 68.21743547916412, 70.21936565637589, 68.17914873361588, 66.72676786780357, 65.05759343504906, 63.07891421020031, 62.24749222397804, 61.30198895931244, 62.42631822824478, 65.2481684088707, 65.17440676689148, 67.65793830156326, 63.592787235975266, 56.8992830067873, 62.06917159259319, 60.245763435959816, 65.46736344695091, 67.13184133172035, 69.65441957116127, 64.346833974123, 62.122133150696754, 57.45292469859123, 55.625469759106636, 52.953551933169365, 52.36500911414623, 55.30478596687317, 57.964875027537346, 56.087996140122414, 60.47481894493103, 61.61825358867645, 63.703064918518066, 62.99723759293556, 60.667989179492, 66.34180292487144, 64.94438990950584, 70.73364526033401, 62.24997729063034, 59.686566442251205, 61.57975785434246, 55.9079048037529, 53.739896938204765, 55.75356848537922, 53.51914018392563, 56.80227041244507, 69.89682376384735, 65.23862332105637, 61.377506107091904, 58.345869183540344, 61.4283511787653, 63.54289971292019, 52.6018276065588, 46.77336595952511, 49.30412515997887, 44.675984904170036, 48.6484095454216, 53.8636638969183, 65.18105641007423, 50.40990762412548, 34.55082781612873, 32.913681864738464, 34.732119888067245, 35.49419939517975, 56.27008996903896, 58.64598087966442, 51.5552269667387, 52.09044724702835, 48.42231787741184, 49.703650921583176, 39.11656402051449, 51.8873405456543, 61.5063039958477, 63.88341084122658, 60.31181529164314, 57.08707273006439, 60.72844013571739, 64.70645427703857, 63.98510858416557, 58.427557200193405, 56.62317842245102, 56.757299825549126, 58.29056315124035, 58.66497606039047, 62.372684106230736, 63.950036466121674, 62.14497372508049, 59.039559960365295, 56.06412962079048, 53.9057732373476, 57.62387752532959, 57.16114595532417, 56.79825782775879, 56.238844245672226, 56.77675098180771, 56.631887555122375, 57.32114776968956, 53.79495598375797, 49.52548988163471, 50.72991505265236, 64.952073097229, 61.99422061443329, 67.38863155245781, 66.75167933106422, 68.05595934391022, 64.84900742769241, 61.525059789419174, 58.79793852567673, 56.12584210932255, 56.001892760396004, 59.3119141459465, 59.034783616662025, 59.24963168799877, 62.37109199166298, 62.11424097418785, 59.87920470535755, 63.89043286442757, 65.37063583731651, 68.46631452441216, 71.331497579813, 75.20226627588272, 78.13817873597145, 74.73492935299873, 67.37958043813705, 50.75054794549942, 38.544896095991135, 32.37463518977165, 41.5678770840168, 51.32301762700081, 33.606103509664536, 4.350759414955974, 1.247684305999428, 0.600405604345724, 68.40724289417267, 87.28487312793732, 79.80153948068619, 83.40478733181953, 55.63119985163212, 54.447065591812134, 71.09638139605522, 43.249682039022446, 1.5281746862456203, 10.418192613869905, 27.241416536271572, 20.386439971625805, 12.173977699130774, 10.46812478452921, 0.5642437166534364, 10.785680394619703], [9.924841336905956, 1.0103617468848825, 7.409391514956951, 7.205108301714063, 4.935609307140112, 1.1583319818601012, 9.504965767264366, 43.188634514808655, 32.74010717868805, 16.379767768085003, 29.6627739071846, 46.56523212790489, 57.16378301382065, 44.94441010057926, 67.92779982089996, 56.63678929209709, 29.63601004332304, 0.17790229758247733, 0.08566148273530416, 0.04721199904452078, 0.1484567573061213, 0.1813985701301135, 4.570424677804112, 14.83330775052309, 20.755763053894043, 32.576282769441605, 48.195618242025375, 61.54302902519703, 67.78469949960709, 67.21460849046707, 66.99000254273415, 60.65340556204319, 59.19109582901001, 55.317036509513855, 57.47989945113659, 53.426577150821686, 54.01602432131767, 53.029844239354134, 54.968583807349205, 58.64139072597027, 60.01306392252445, 57.300511077046394, 55.64840152859688, 53.67333211004734, 53.94925810396671, 52.69839182496071, 56.3082817196846, 57.5406239926815, 55.74268966913223, 54.024361073970795, 49.343251660466194, 49.830195531249046, 49.13681633770466, 51.27631053328514, 48.232430666685104, 51.507501527667046, 53.391512632369995, 57.148105055093765, 57.69999124109745, 58.170626387000084, 56.947738006711006, 60.383042469620705, 61.61037661135197, 61.00930966436863, 61.33888877928257, 63.95540177822113, 53.52472588419914, 52.10363633930683, 53.83207619190216, 55.210866406559944, 55.23334600031376, 49.116738215088844, 47.51406021416187, 55.89900568127632, 59.83885087072849, 57.045065984129906, 55.905670523643494, 54.101949110627174, 60.75918808579445, 57.60726101696491, 47.862961292266846, 42.61792793869972, 41.88085488975048, 45.424100160598755, 50.071345791220665, 60.645847767591476, 62.66184478998184, 53.139582350850105, 34.59068387746811, 38.25306795537472, 52.60469265282154, 59.497689977288246, 53.310922756791115, 47.70367383956909, 41.90170057117939, 42.5401347130537, 44.94612380862236, 44.79066275060177, 44.256742000579834, 54.64950352907181, 50.53068794310093, 56.33169986307621, 54.632917419075966, 56.892804354429245, 54.309212788939476, 50.75007677078247, 49.131386429071426, 49.98124122619629, 48.24960194528103, 53.24138268828392, 51.948616057634354, 55.95183044672012, 56.867121532559395, 53.3121082931757, 50.71285016834736, 49.834018126130104, 49.14767235517502, 47.849574610590935, 48.31960178911686, 46.98170877993107, 43.96749772131443, 43.842663019895554, 43.31718161702156, 42.72173456847668, 44.7275747358799, 41.74197994172573, 44.97679576277733, 54.58282470703125, 60.28201349079609, 58.33557553589344, 60.349049493670464, 62.79068447649479, 64.00138691067696, 56.33166566491127, 53.86054806411266, 47.178447023034096, 44.70994368195534, 47.762878462672234, 47.40882106125355, 48.77975709736347, 48.50763849914074, 52.95724533498287, 54.381887689232826, 59.08806815743446, 60.98644249141216, 66.47561654448509, 62.91273772716522, 67.3550109565258, 61.21199458837509, 56.57881200313568, 44.70246948301792, 27.258356027305126, 17.910597324371338, 14.528892785310745, 25.262104645371437, 48.895472288131714, 44.47215624153614, 1.9332682178355753, 0.31469537294469774, 1.6289056185632944, 53.72190870344639, 69.0850505232811, 65.55531352758408, 60.337885692715645, 26.829442642629147, 32.209161669015884, 37.853401601314545, 9.958173148334026, 0.8687778410967439, 5.174242677167058, 15.528564043343067, 10.960229728370905, 6.934060771018267, 0.30705974204465747, 3.177402801811695, 9.559167008846998, 28.06843265891075, 31.453205533325672, 10.74531801044941, 12.246021833270788, 8.398909717798233, 2.6653104554861784, 15.293073579668999, 57.857067212462425, 40.98828658461571, 22.43219129741192, 26.977448500692844, 45.85100345313549, 64.24862444400787, 54.45881076157093, 75.03121465444565, 70.31256705522537, 39.303688779473305, 0.19884221692336723, 0.13166149525204673, 0.07126948781660758, 0.25773156085051596, 0.1804582541808486, 5.036747055128217, 13.60679341480136, 21.721870712935925, 41.356220841407776, 57.31168247759342, 66.58584102988243, 72.5054369866848, 69.32528883218765, 72.43448719382286, 63.40069614350796, 63.9373679459095, 60.7940474152565, 62.24672466516495, 58.23717601597309, 59.246911033988, 55.772499069571495, 60.5784659832716, 62.25135661661625, 64.53383713960648, 60.71503445506096, 60.05828529596329, 54.775550365448, 56.23418189585209, 55.8895517885685, 59.013242572546005, 60.69911330938339, 58.95500309765339, 56.77515886723995, 50.980006232857704, 51.323143020272255, 51.12427309155464, 52.97955013811588, 51.692202016711235, 56.965220868587494, 57.18273639678955, 59.190886840224266, 58.9995177090168, 59.825304597616196, 60.486640110611916, 65.10733276605606, 64.04342025518417, 61.47855408489704, 63.804200291633606, 67.56602883338928, 56.90687119960785, 57.8664793074131, 56.70294754207134, 58.78638714551926, 57.21539944410324, 50.21368235349655, 49.74812373518944, 60.76795041561127, 63.49861688911915, 59.18898694217205, 57.97578804194927, 58.947574496269226, 62.1643602848053, 59.37709204852581, 50.129459872841835, 45.57339034974575, 45.18663950264454, 47.31340438127518, 52.99769036471844, 64.38531070947647, 64.42765563726425, 58.67990545928478, 36.9021188467741, 40.9578388184309, 57.085890993475914, 60.98774202167988, 57.555108815431595, 49.81485955417156, 44.46751669049263, 42.52804756164551, 45.41859045624733, 46.468223333358765, 45.98139725625515, 56.78728021681309, 55.681611746549606, 60.840469524264336, 57.77989715337753, 59.94832679629326, 56.56705543398857, 52.687095031142235, 51.89358741044998, 52.943030297756195, 50.001079961657524, 54.831954538822174, 54.591678231954575, 59.690886810421944, 60.910115987062454, 55.38926683366299, 53.77632938325405, 53.1322031468153, 52.25872881710529, 50.84958203136921, 49.32672254741192, 47.56526246666908, 49.46883112192154, 44.88521307706833, 48.323747366666794, 45.607497319579124, 49.3889632076025, 44.332958310842514, 46.942251697182655, 55.94341389834881, 62.45036333799362, 59.950963854789734, 62.154951989650726, 62.65839457511902, 67.04755425453186, 62.685832902789116, 58.70764397084713, 52.49666824936867, 50.95266290009022, 53.676482141017914, 51.44141927361488, 52.007083520293236, 54.524482637643814, 57.02414430677891, 62.015510872006416, 64.47627022862434, 64.10174712538719, 70.92739686369896, 67.61174038052559, 75.00906184315681, 69.30623665452003, 68.57304319739342, 57.20271572470665, 40.12846492230892, 25.514420606195927, 21.372853741049767, 33.54620352387428, 58.709844052791595, 49.92759570479393, 2.9348568292334676, 0.5842614581342787, 2.644612016156316, 65.4383634030819, 76.70209139585495, 72.79103726148605, 73.03122997283936, 35.717125833034515, 35.96729300916195, 47.04814061522484, 21.816867515444756, 1.662001961376518, 6.203922349959612, 16.952697224915028, 16.089455746114254, 8.062671460211277, 1.1689870851114392, 1.8098183046095073, 7.940815798938274, 35.94048544764519, 19.62369929999113, 11.102233808487654, 11.580951120704412, 7.269236035645008, 2.1595324203372, 20.79795029014349, 78.02809864282608, 51.49835541844368, 37.14368708431721, 41.771112978458405, 63.1430471688509, 70.76858818531036, 64.89456698298454, 83.40059995651245, 82.05188512802124, 48.02711248397827, 0.32195924723055214, 0.15244768612319604, 0.18399461754597723, 0.47932812944054604, 0.27138007222674787, 6.354372426867485, 26.965382248163223, 38.156689926981926, 51.75209440290928, 66.25303208827972, 69.5860992372036, 74.43782329559326, 73.27401414513588, 73.73669251799583, 67.40424111485481, 68.47802549600601, 63.01439367234707, 65.84755584597588, 64.2929756641388, 62.38992378115654, 60.19380882382393, 63.21857951581478, 67.69586026668549, 69.14677441120148, 62.46035300195217, 63.80544662475586, 58.36296446621418, 61.32997825741768, 59.69866119325161, 62.491363137960434, 65.69317772984505, 63.272228837013245, 59.73284035921097, 55.39046756923199, 53.35333228111267, 53.264059871435165, 55.348525419831276, 53.817948549985886, 57.766787856817245, 60.4360344260931, 60.344497337937355, 63.18821534514427, 61.01203791797161, 61.48168131709099, 66.90125450491905, 66.53342664241791, 65.1689350605011, 64.32481035590172, 67.16451197862625, 59.47555236518383, 61.4509941637516, 60.665355920791626, 61.58663168549538, 59.2984476685524, 54.220339357852936, 53.40033955872059, 63.88418599963188, 66.52745336294174, 62.84296587109566, 61.23176872730255, 61.80144555866718, 64.01603892445564, 59.990694522857666, 51.643804013729095, 47.6668918132782, 48.1356156617403, 49.925395622849464, 53.7954917550087, 67.08144083619118, 69.30119812488556, 57.340412735939026, 35.3723019361496, 39.817558005452156, 54.99150037765503, 65.41618019342422, 59.17292520403862, 53.00240211188793, 45.799512416124344, 47.44602106511593, 50.41462317109108, 48.835747092962265, 46.33451230823994, 59.86836388707161, 55.95281079411507, 63.179282024502754, 61.32691562175751, 63.16427282989025, 60.373497381806374, 55.6975556910038, 55.05205012857914, 56.496022045612335, 53.006589487195015, 59.26016852259636, 58.18883880972862, 60.90977780520916, 62.85264775156975, 59.33834172785282, 57.3932147026062, 55.805564895272255, 56.01404070854187, 55.55759780108929, 54.5017446577549, 52.10122346878052, 52.84598730504513, 48.87808062136173, 52.20249943435192, 49.53391782939434, 51.659075394272804, 46.439489275217056, 50.62235802412033, 60.851789116859436, 65.8823923766613, 64.78404611349106, 65.45616924762726, 67.70340666174889, 72.54598081111908, 69.17030274868011, 63.74730974435806, 57.50745937228203, 55.86240604519844, 57.974237725138664, 55.787599459290504, 55.540384724736214, 57.64242812991142, 59.96861770749092, 65.98856627941132, 68.52134317159653, 70.09739220142365, 74.71196338534355, 70.97813934087753, 76.0780280828476, 72.47112482786179, 71.57805114984512, 68.77096697688103, 61.438743621110916, 51.454471573233604, 48.091815412044525, 57.878805845975876, 69.366235435009, 56.39290697872639, 5.494856173172593, 1.4142545429058373, 2.8056687489151955, 75.18348008394241, 82.20831513404846, 82.17375218868256, 82.97499999403954, 48.78229156136513, 52.73230880498886, 62.86194205284119, 41.82119429111481, 3.729425542987883, 18.70729297399521, 38.64849753677845, 31.280531398952007, 21.667100451886654, 3.279591193422675, 6.683849897235632, 25.624909177422523], [16.83010060340166, 0.36728659935761243, 3.2903374917805195, 2.567626484669745, 2.9786418797448277, 0.07687008299399167, 15.595524050295353, 44.062994197010994, 34.30916078388691, 21.035162061452866, 36.24348498880863, 49.26875285804272, 58.338151797652245, 54.99078221619129, 65.30316665768623, 67.5677539408207, 45.71294546127319, 4.3653002846986055, 0.08953616154030897, 0.3383207833394408, 0.05897026770981029, 0.6190168275497854, 15.790362395346165, 31.476969458162785, 44.11880560219288, 53.667514622211456, 53.980412632226944, 65.33658966422081, 65.81195175647736, 68.69877845048904, 65.99402278661728, 63.589048236608505, 57.484793588519096, 53.66942211985588, 54.77957434952259, 52.41432286798954, 51.72031290829182, 52.661172822117805, 56.31526954472065, 57.72463671863079, 61.61103397607803, 62.46495075523853, 56.68064273893833, 52.40194693207741, 51.55690647661686, 54.72796931862831, 52.30978287756443, 53.493841141462326, 52.95531123876572, 52.47592136263847, 48.413392156362534, 50.25673024356365, 48.556633070111275, 50.872388407588005, 54.801822155714035, 57.214578688144684, 58.346959725022316, 60.386876463890076, 58.90147157013416, 60.407516956329346, 58.832015097141266, 60.87706916034222, 61.01219370961189, 60.94075374305248, 58.67152310907841, 58.983349576592445, 58.24675910174847, 58.51986564695835, 52.387967482209206, 55.60599200427532, 50.173716098070145, 48.48085753619671, 45.592389330267906, 54.9734665453434, 60.55945560336113, 54.869830906391144, 58.64062696695328, 61.92866273224354, 55.42312301695347, 52.46377341449261, 45.074078142642975, 41.847397685050964, 39.03277851641178, 45.46349264681339, 47.61500559747219, 53.80427308380604, 57.14917279779911, 59.784228801727295, 56.5266066044569, 57.85768277943134, 59.8139888048172, 54.39557075500488, 53.42558540403843, 47.75102689862251, 42.88297891616821, 40.59723436832428, 41.88932843506336, 46.05348318815231, 42.353112548589706, 51.350497752428055, 58.615369722247124, 54.48843017220497, 56.55201584100723, 56.477080062031746, 50.210357531905174, 47.420266047120094, 48.984809294342995, 47.54755161702633, 45.48152267932892, 47.340740114450455, 54.94003973901272, 57.12574325501919, 57.10016302764416, 53.73724848031998, 50.951682552695274, 49.47255112230778, 47.66927048563957, 47.2055471688509, 44.003876969218254, 42.75923855602741, 42.79968358576298, 42.140027582645416, 44.68256235122681, 43.21987263858318, 43.46173346042633, 43.83912920951843, 45.053832828998566, 49.17756535112858, 61.19822032749653, 59.606052562594414, 63.663524240255356, 61.05763167142868, 59.559626653790474, 53.86722810566425, 52.20413334667683, 51.48424677550793, 43.162822499871254, 44.84043627977371, 45.97978614270687, 48.980701714754105, 50.23200877010822, 52.983642518520355, 55.017255395650864, 59.425091072916985, 64.24722611904144, 65.51103830337524, 62.519242241978645, 66.82802483439445, 63.70774246752262, 58.375625386834145, 54.8944877833128, 39.116457626223564, 31.425852701067924, 29.102843552827835, 44.66436132788658, 65.9306725859642, 59.850265458226204, 8.378882892429829, 0.5462596379220486, 5.1301484182477, 67.08618298172951, 62.913254499435425, 59.14509929716587, 62.350345104932785, 25.895903035998344, 27.97849528491497, 26.31251648068428, 7.888608975335956, 0.592622256372124, 4.391099950298667, 26.488331146538258, 18.098647333681583, 4.13257559761405, 7.233830010518432, 6.705408515408635, 23.91336891800165, 18.024762198328972, 7.81069035641849, 7.311523491516709, 6.81927178055048, 5.855384152382612, 0.4382436949526891, 25.015609972178936, 57.98801578581333, 41.83185271918774, 25.49088466912508, 36.279529854655266, 49.22404445707798, 66.77829310297966, 58.43229554593563, 76.59565150737762, 73.8848465681076, 58.62516559660435, 3.9038449712097645, 0.06620700165512972, 1.1437304341234267, 0.14477669930784032, 0.774704507784918, 12.699428703635931, 30.296175219118595, 48.81303571164608, 54.54506993293762, 64.2044860124588, 69.1776591539383, 70.33155083656311, 73.0819420516491, 69.9279060959816, 68.9926926791668, 60.29215134680271, 60.93306675553322, 59.59287866950035, 59.09608952701092, 54.897702410817146, 58.348912820219994, 61.55505158007145, 64.04139116406441, 66.15669965744019, 65.20408317446709, 58.6674003303051, 54.649552926421165, 53.76896917819977, 53.736560717225075, 55.525713711977005, 55.82710213959217, 56.965137273073196, 52.6715462654829, 52.03234076499939, 51.69981300830841, 50.68035431206226, 53.27620021998882, 56.022962629795074, 60.59902288019657, 59.71136771142483, 63.249813839793205, 62.0379638671875, 61.85091510415077, 62.610216960310936, 63.70726369321346, 62.91412465274334, 63.772008419036865, 62.103920727968216, 61.547721773386, 60.95263950526714, 62.29543425142765, 57.07433581352234, 60.013880878686905, 51.97164662182331, 50.379718244075775, 48.893902972340584, 59.84072037041187, 61.88922844827175, 58.31832446157932, 59.14934366941452, 63.262280970811844, 52.9131942987442, 53.260355070233345, 46.867870688438416, 43.29918958246708, 42.05167852342129, 46.71278581023216, 50.11902943253517, 56.599551290273666, 58.233182430267334, 60.22154353559017, 59.53681267797947, 58.808099180459976, 58.446689173579216, 57.6774812489748, 55.434438809752464, 51.17669887840748, 44.12665978074074, 41.39750562608242, 42.46666945517063, 48.4653277695179, 43.67677912116051, 51.914934664964676, 62.71489754319191, 58.178165182471275, 57.756000235676765, 56.79511159658432, 54.263052865862846, 50.07987633347511, 51.26534812152386, 51.001600474119186, 46.761221811175346, 50.783685967326164, 61.00005716085434, 59.5948925614357, 58.828310295939445, 55.83183668553829, 54.36209075152874, 52.532355934381485, 51.74163356423378, 49.427211955189705, 48.91905002295971, 46.7634978890419, 46.707017719745636, 47.0827529579401, 46.96198023855686, 45.682144314050674, 46.097424030303955, 46.73694871366024, 47.166922241449356, 49.87747639417648, 61.29304803907871, 61.604441329836845, 65.30608490109444, 62.82078266143799, 63.36444988846779, 60.438523292541504, 60.223698019981384, 60.264815613627434, 49.59276907145977, 49.40117955207825, 49.244844540953636, 54.34282198548317, 54.527210891246796, 57.38149993121624, 59.65705342590809, 66.22519478201866, 69.30686742067337, 73.35416704416275, 68.85760992765427, 75.01525551080704, 70.4475662112236, 67.42221415042877, 65.999616086483, 52.617619559168816, 43.20264436304569, 40.91132551431656, 58.99952530860901, 76.92589178681374, 65.93713223934174, 11.988552398979664, 0.6668506201822311, 5.592595478519797, 77.63278305530548, 72.561005204916, 68.85859787464142, 73.37594747543335, 37.47175768017769, 34.41365137696266, 36.99709855020046, 17.786874063313007, 0.6465289543848485, 9.882956184446812, 28.330346904695034, 21.42044808715582, 8.417574316263199, 4.443025588989258, 0.6530061818193644, 16.397005543112755, 54.57919590175152, 3.397684581577778, 5.42512041516602, 4.972395608201623, 4.243221860378981, 0.31542579468805343, 34.51596848666668, 72.68395900726318, 56.562864258885384, 40.58924339711666, 51.93027824163437, 64.16616886854172, 75.12124702334404, 69.9231031537056, 80.84552586078644, 80.95452681183815, 72.72149339318275, 6.070766095072031, 0.29549506260082126, 0.9969805274158716, 0.25190163461957127, 1.5040114265866578, 20.271993912756443, 52.9081329703331, 73.13424244523048, 67.83554077148438, 71.27797365188599, 70.67803144454956, 74.74894300103188, 74.91613402962685, 72.79324114322662, 73.24328139424324, 64.59643498063087, 64.5469768345356, 62.01945886015892, 62.772707641124725, 58.637564331293106, 60.99352911114693, 65.9867499768734, 69.48463708162308, 69.70055669546127, 70.69526731967926, 62.31936536729336, 59.20859768986702, 54.60418716073036, 57.84867726266384, 57.918483316898346, 61.31876885890961, 58.35880368947983, 57.843216955661774, 54.53030772507191, 53.765013590455055, 52.14944668114185, 54.35745880007744, 58.074369952082634, 61.02501042187214, 62.37259291112423, 63.588181883096695, 63.694298788905144, 65.06863564252853, 64.77406024932861, 65.47407388687134, 65.00938162207603, 65.15809044241905, 63.60386364161968, 64.28615882992744, 63.484181463718414, 63.730058670043945, 57.64047123491764, 61.03164106607437, 53.827945813536644, 53.63537214696407, 55.123999267816544, 62.042546421289444, 66.47019043564796, 61.1698130518198, 63.516810312867165, 66.20797410607338, 57.1024315059185, 57.411294132471085, 49.409417510032654, 46.99329815804958, 44.23727944493294, 50.1741074770689, 52.79156282544136, 60.55709592998028, 61.14843539893627, 64.8165875673294, 59.62132394313812, 61.0017366707325, 62.42883749306202, 60.77896222472191, 59.89232920110226, 54.17600333690643, 48.95602963864803, 45.93054838478565, 45.86361117660999, 51.9796983897686, 44.47732776403427, 54.6223995834589, 64.60087314248085, 58.75108323991299, 62.75370866060257, 59.917529448866844, 57.35941171646118, 54.67914953827858, 55.424114763736725, 53.98178815841675, 49.12705086171627, 54.2299984395504, 62.80982784926891, 64.92805078625679, 65.32751575112343, 59.20273080468178, 55.88894762098789, 56.72961451113224, 54.74936977028847, 52.83441312611103, 52.67293319106102, 50.96353031694889, 51.11502818763256, 50.8161286264658, 49.89462107419968, 48.78786586225033, 50.630516186356544, 50.763303861021996, 50.42257994413376, 56.01817488670349, 66.0418014228344, 65.51699638366699, 68.61672565340996, 66.34858936071396, 67.64411464333534, 66.17653459310532, 65.42700201272964, 67.28257924318314, 55.47282434999943, 52.77588486671448, 54.872695952653885, 56.68823093175888, 58.25197622179985, 59.400335401296616, 62.923346757888794, 68.1603017449379, 72.59583413600922, 73.7291157245636, 72.73867607116699, 76.34707644581795, 74.27137702703476, 73.33630800247192, 74.87415388226509, 65.14623507857323, 62.7468728274107, 64.44854691624641, 74.58216995000839, 77.31871470808983, 68.6265367269516, 13.324873242527246, 1.1433557979762554, 6.988191241398454, 89.48291078209877, 78.28080028295517, 81.34673416614532, 82.71720662713051, 49.8984132707119, 46.156799644231796, 56.69329605996609, 39.74023215472698, 3.6913235625252128, 23.50475024431944, 55.2909205108881, 51.28055490553379, 27.459538131952286, 12.619862873107195, 26.431843377649784, 57.073621451854706], [27.57402788847685, 0.31388396804686636, 1.9979878887534142, 1.4288991945795715, 1.458668578416109, 0.18805916741257533, 22.20964103937149, 45.27351424098015, 28.28510843217373, 19.009599052369595, 31.28985609859228, 53.91214169561863, 50.28394058346748, 47.72677280008793, 68.53914901614189, 64.43363651633263, 64.83357265591621, 16.66024971753359, 0.2186431473819539, 1.2847118941135705, 0.13286172616062686, 1.6813825839199126, 2.8555348981171846, 25.411945804953575, 56.24118871986866, 70.54654330015182, 67.63637065887451, 64.60885271430016, 67.49106645584106, 68.45197409391403, 69.32733312249184, 64.82393637299538, 58.70975665748119, 54.021762013435364, 53.40526409447193, 50.82039199769497, 52.60802887380123, 52.78343886137009, 55.64494751393795, 56.83332234621048, 60.1172961294651, 58.549933433532715, 59.916913881897926, 53.7513343244791, 51.25853128731251, 51.59539461135864, 49.930703938007355, 53.1051903963089, 49.441567584872246, 50.563757568597794, 48.48324000835419, 49.71225365996361, 49.809228256344795, 53.99321794509888, 57.15674579143524, 59.47382725775242, 63.02883669734001, 60.53399696946144, 62.93517932295799, 61.278711408376694, 62.70666718482971, 63.38964253664017, 62.62994550168514, 63.00673708319664, 60.61215117573738, 60.53510271012783, 59.71433915197849, 56.462732031941414, 58.15821625292301, 53.84323239326477, 53.623307794332504, 49.53115537762642, 43.84376496076584, 51.15964539349079, 56.04602739214897, 55.6840094178915, 58.8261292129755, 53.43902908265591, 46.45960159599781, 45.48328198492527, 43.44836577773094, 43.62908788025379, 40.25950849056244, 45.761620849370956, 46.37399598956108, 49.089854657649994, 53.3417809009552, 47.6832727342844, 51.53428629040718, 52.43999809026718, 47.409983798861504, 55.31224116683006, 46.58853627741337, 46.44463039934635, 42.95107886195183, 39.63490180671215, 40.72616145014763, 46.763072311878204, 47.406632378697395, 45.445717200636864, 57.932458966970444, 55.65101578831673, 56.72805659472942, 54.60433915257454, 49.26177643239498, 45.355430245399475, 45.738335698843, 43.0282299220562, 39.27304722368717, 43.3868470788002, 51.61358803510666, 55.98603621125221, 54.57231447100639, 53.48656453192234, 52.20027655363083, 51.30404904484749, 47.7069378644228, 48.11196573078632, 45.13862147927284, 45.01687601208687, 46.13163739442825, 43.85074518620968, 44.25478510558605, 42.972198128700256, 46.50891155004501, 45.1857503503561, 46.58569023013115, 44.907153099775314, 54.34244580566883, 61.72153204679489, 63.07295233011246, 59.93259944021702, 57.1846666932106, 53.15032057464123, 51.82927966117859, 51.122946962714195, 47.493438720703125, 41.58576652407646, 45.9516828507185, 48.09025749564171, 49.921622425317764, 54.68153201043606, 57.68752031028271, 62.98446647822857, 63.879215866327286, 68.44978541135788, 65.11627748608589, 66.91791281104088, 63.82828339934349, 63.708225041627884, 57.444318160414696, 48.354730904102325, 43.11146065592766, 49.37038980424404, 61.93607233464718, 72.2438970208168, 73.15936669707298, 20.335484705865383, 0.5148220842238516, 8.494056612253189, 65.0180071592331, 63.706613928079605, 52.22867622971535, 60.51160857081413, 20.807620771229267, 24.75131895393133, 21.655311584472656, 2.5581203447654843, 1.3788479240611196, 0.7944962801411748, 34.69876907765865, 33.217733949422836, 24.24126472324133, 14.871407356113195, 18.139329850673676, 54.22089032828808, 18.794509693980217, 1.7336224182508886, 4.17939811013639, 2.8813262516632676, 2.722536097280681, 0.1603089744457975, 33.15975286066532, 60.40660500526428, 37.441397309303284, 26.594284661114216, 37.496657744050026, 52.4798883497715, 56.01755551993847, 55.17842374742031, 76.53862416744232, 72.43182733654976, 79.7085964679718, 16.82617161422968, 0.137393428303767, 2.283329777419567, 0.09277123521314934, 1.143316375091672, 10.60823941603303, 40.44983647763729, 76.6107214987278, 73.4740050137043, 71.56441748142242, 70.71023851633072, 66.96145087480545, 76.06257051229477, 71.37719392776489, 71.5376365184784, 60.8001346886158, 61.05220176279545, 57.83383905887604, 56.4231001585722, 56.10009469091892, 57.24201321601868, 57.38607868552208, 62.747666984796524, 63.435912653803825, 63.19041922688484, 61.73341020941734, 53.97267624735832, 54.37210701406002, 52.95580141246319, 52.31357887387276, 54.981180131435394, 53.29263053834438, 52.74755738675594, 51.62659093737602, 52.00600817799568, 55.59873819351196, 54.664208739995956, 61.57047875225544, 61.90523698925972, 65.59144198894501, 63.01574259996414, 65.22194981575012, 63.382643312215805, 66.45348653197289, 63.176606968045235, 63.51712189614773, 62.229777574539185, 62.33275964856148, 63.686600401997566, 61.45920172333717, 59.88523878157139, 63.0716148018837, 57.61924937367439, 57.60506473481655, 52.87063278257847, 49.373505637049675, 55.215308368206024, 58.18716689944267, 58.00340496003628, 61.50525905191898, 52.731685638427734, 49.485257640480995, 49.17079031467438, 45.886208564043045, 46.285494938492775, 42.38917641341686, 47.64604613184929, 49.70353312790394, 51.03292979300022, 56.15407079458237, 47.5846566259861, 52.28721968829632, 54.94741894304752, 50.145821794867516, 56.619325429201126, 49.90531750023365, 50.152498036623, 45.83045035600662, 40.59616282582283, 42.32347413897514, 47.61382766067982, 50.075624361634254, 47.41586208343506, 59.24758739769459, 56.99091888964176, 59.245277121663094, 57.07647129893303, 53.80291275680065, 48.14310126006603, 49.54591378569603, 44.16316442191601, 42.082031294703484, 43.79311367869377, 51.919281631708145, 59.78336624801159, 57.007873579859734, 56.2141227722168, 53.48943717777729, 53.64356070756912, 50.10535776615143, 50.10240152478218, 48.37436445057392, 48.27082760632038, 48.671953082084656, 47.40855887532234, 45.558996722102165, 45.284419655799866, 47.3524434864521, 47.311139702796936, 48.60142506659031, 47.875918596982956, 56.05510130524635, 61.513364017009735, 63.663668632507324, 63.53618927299976, 63.33276338875294, 61.59174241125584, 62.28172458708286, 60.70108160376549, 54.23117637634277, 49.40998747944832, 53.31635646522045, 53.119002655148506, 54.9823884665966, 61.065687239170074, 60.693884789943695, 67.6650895178318, 69.58278581500053, 73.62099632620811, 71.19991824030876, 71.61651268601418, 70.58612957596779, 72.93919891119003, 67.89107099175453, 59.00737568736076, 56.4860437810421, 64.11424085497856, 75.80394119024277, 80.03508254885674, 80.89955896139145, 25.414001494646072, 0.9155108209233731, 11.335693281143904, 76.15037620067596, 72.00436547398567, 62.89588563144207, 71.32593467831612, 33.44302386045456, 32.81437039375305, 33.74416910111904, 3.5436910344287753, 0.41276187635958195, 11.321768928319216, 42.84963570535183, 34.03160087764263, 14.849811214953661, 7.974789775907993, 12.218399215489626, 24.640545397996902, 38.570571318268776, 0.5507439316716045, 3.190232813358307, 2.085010106675327, 2.1323282551020384, 0.1975383228273131, 41.600768119096756, 76.70849785208702, 50.98541334271431, 35.53505100309849, 46.179780811071396, 70.19668087363243, 65.73968723416328, 61.13353259861469, 86.16654753684998, 73.46253722906113, 89.31356146931648, 20.61823133379221, 0.3242809820221737, 4.241820210590959, 0.25100390310399234, 1.871717101894319, 10.257067009806633, 51.17142856121063, 89.72573295235634, 74.09747555851936, 77.59594023227692, 71.12051010131836, 71.86340063810349, 78.72546762228012, 75.32514408230782, 74.50274661183357, 65.44815167784691, 64.9802827835083, 60.73474019765854, 60.69602407515049, 57.569969817996025, 60.78596904873848, 60.76553374528885, 66.44001245498657, 66.10675513744354, 67.10491597652435, 63.4060500562191, 58.76320078969002, 56.41693688929081, 55.713682025671005, 55.03315754234791, 59.593011662364006, 55.96335522830486, 54.94615361094475, 53.95186856389046, 56.08980104327202, 58.183507695794106, 56.38833202421665, 62.7925805747509, 64.00801375508308, 66.99940323829651, 64.42583933472633, 67.44729280471802, 64.24977198243141, 69.03664872050285, 65.83527490496635, 65.95068231225014, 66.12288907170296, 66.6082826256752, 66.33231103420258, 63.22342045605183, 62.65576131641865, 64.98161271214485, 58.83602388203144, 60.615396201610565, 58.283537328243256, 54.50679838657379, 58.61456796526909, 60.97739137709141, 62.891816049814224, 65.21808922290802, 57.51581132411957, 50.1705888658762, 50.957830622792244, 50.111323446035385, 48.416052013635635, 45.22945940494537, 52.161454036831856, 52.67512187361717, 53.11554864048958, 59.10376891493797, 50.6823568046093, 54.7698924690485, 59.26499806344509, 51.77000664174557, 60.28251886367798, 51.81611716747284, 51.27504900097847, 46.974021792411804, 44.57824654877186, 45.47871083021164, 51.39679066836834, 50.05707375705242, 50.584056079387665, 62.32551723718643, 59.433777406811714, 61.51491813361645, 60.12111492455006, 58.23099374771118, 54.552224949002266, 50.34572146832943, 46.99938163161278, 43.125177919864655, 44.18730452656746, 57.2132221609354, 63.790581822395325, 59.21155013144016, 58.7860793620348, 57.4093372374773, 55.97467862069607, 53.07862602174282, 54.32050958275795, 51.507064551115036, 53.19174215197563, 52.53158837556839, 49.92536902427673, 49.8964411765337, 49.878935515880585, 51.68879359960556, 52.7036127448082, 52.04731956124306, 50.90840667486191, 60.211375281214714, 66.45520403981209, 67.8204707801342, 68.214410841465, 66.1346684396267, 66.54864862561226, 69.62773740291595, 66.81692183017731, 60.716368183493614, 52.61299140751362, 57.35343463718891, 55.78059263527393, 58.86470854282379, 62.9118599742651, 64.527088701725, 69.74590346217155, 72.45711877942085, 76.01679816842079, 75.18884539604187, 73.2238720357418, 73.12094315886497, 77.3353274166584, 75.41357293725014, 65.68706005811691, 67.42496520280838, 71.46513640880585, 80.25202810764313, 77.84485727548599, 81.40300154685974, 27.89102017879486, 0.9624708979390562, 12.054290771484375, 84.79924410581589, 75.92545107007027, 76.29347652196884, 80.58698013424873, 48.959863632917404, 40.78938625752926, 55.13676658272743, 21.376666836440563, 4.527370613068342, 21.31560031324625, 66.08155488967896, 68.18541839718819, 41.25925004482269, 44.3970912694931, 59.78922553360462, 94.81521025300026], [10.217368640005589, 0.2959006908349693, 0.2625257457839325, 0.3780654037836939, 0.3224106808193028, 0.18272716290084645, 27.702293805778027, 48.53196859359741, 30.64495090395212, 22.054637856781483, 26.015440821647644, 59.70038630068302, 64.87330332398415, 44.94029492139816, 67.20440223813057, 66.72989130020142, 60.8782546967268, 13.493402749300003, 0.19083485909504816, 1.3239121343940496, 0.06907079368829727, 1.2336742202751338, 1.0857899556867778, 23.88828456401825, 55.70920206606388, 72.05981969833374, 67.7073584496975, 69.18053179979324, 67.6571099460125, 69.03806984424591, 70.00909253954887, 65.60664877295494, 60.351906940340996, 55.50168000161648, 53.890125676989555, 51.584891974925995, 49.90818254649639, 50.30175782740116, 52.484345510602, 54.57130752503872, 59.042835384607315, 60.041193813085556, 59.52621504664421, 54.33816723525524, 51.044389978051186, 51.80584251880646, 49.28604573011398, 51.267840787768364, 47.96705670654774, 50.10569214820862, 50.19242249429226, 50.10520197451115, 50.99758788943291, 58.12890462577343, 60.08139945566654, 63.86034607887268, 63.08457210659981, 63.89093443751335, 60.11385731399059, 60.90845927596092, 60.989360734820366, 61.49890199303627, 60.351238176226616, 63.17696034908295, 60.96135623753071, 60.281299129128456, 61.4021971821785, 60.5855830013752, 57.601903304457664, 56.41672030091286, 53.78313481807709, 52.35607199370861, 45.09394347667694, 45.574526488780975, 56.318807154893875, 56.528590098023415, 56.938903480768204, 49.12847578525543, 47.204798609018326, 48.81876960396767, 47.5224881619215, 41.803278252482414, 40.5230737477541, 44.084193259477615, 45.207336992025375, 47.08570919930935, 52.55100913345814, 47.04118698835373, 51.51452735066414, 49.673997312784195, 48.448354080319405, 50.357785820961, 48.136713802814484, 45.9059789031744, 43.31978067755699, 42.06853821873665, 43.52680876851082, 42.71449975669384, 48.660743683576584, 43.5874193161726, 51.3405878841877, 60.44494114816189, 52.93589808046818, 55.69372549653053, 46.97306804358959, 45.07626682519913, 45.81034943461418, 39.37814198434353, 43.08278739452362, 44.85313519835472, 42.96999804675579, 53.87937605381012, 52.893971130251884, 52.275159135460854, 50.80370709300041, 51.029365584254265, 51.095162853598595, 50.53627364337444, 49.59121495485306, 48.48227486014366, 47.54791259765625, 47.640836611390114, 43.554186299443245, 43.38105618953705, 45.08690245449543, 47.90917821228504, 49.83211062848568, 48.21648672223091, 47.176087349653244, 54.080427065491676, 58.751569613814354, 57.274049296975136, 57.50479571521282, 54.284601509571075, 53.93968261778355, 53.47805678844452, 46.454468071460724, 43.16018924117088, 46.89004249870777, 48.70153449475765, 52.79790088534355, 56.27893589437008, 63.18063475191593, 67.5498417019844, 68.49169716238976, 67.46489346027374, 66.90864130854607, 65.49020782113075, 65.90406641364098, 63.19552235305309, 61.80858537554741, 56.777552738785744, 54.45385962724686, 58.95786054432392, 71.06241881847382, 74.07246530056, 75.94585597515106, 36.03353105485439, 0.15769845515023917, 12.217346671968699, 71.72968581318855, 56.13209657371044, 51.79388076066971, 58.22448089718819, 18.45397386699915, 17.189027443528175, 9.433184769004583, 2.731391522102058, 1.435097730718553, 6.7295509949326515, 31.046900935471058, 54.17466960847378, 44.6184977889061, 47.10895635187626, 37.83898137509823, 51.07128493487835, 15.99453303962946, 0.9794284380041063, 1.381204747594893, 1.1955353105440736, 1.3042589952237904, 0.4545993829378858, 38.65151457488537, 63.42861704528332, 42.658980935812, 28.483043611049652, 32.82909460365772, 61.8196389824152, 70.54581373929977, 54.75525565445423, 76.28925874829292, 73.15566569566727, 74.53952103853226, 16.92486371845007, 0.10044782524346374, 1.0681780194863677, 0.14202022925019264, 1.6083417157642543, 2.4523473205044866, 30.630965754389763, 70.69522932171822, 78.32050055265427, 70.67399606108665, 75.16754373908043, 70.17420887947083, 75.797800719738, 73.01189661026001, 71.9585931301117, 64.07172873616219, 62.53459721803665, 58.10047835111618, 57.979082465171814, 52.89113648235798, 54.693809151649475, 55.72843283414841, 61.11573055386543, 64.10788759589195, 62.30863094329834, 63.29913139343262, 59.31138217449188, 54.5321050286293, 52.48403772711754, 50.81636801362038, 53.828272596001625, 52.58093252778053, 51.64371281862259, 53.20742771029472, 49.91824820637703, 55.73336876928806, 58.4602240473032, 63.565398305654526, 66.72239050269127, 63.17538343369961, 65.44780969619751, 62.94543117284775, 64.50188845396042, 63.12866114079952, 62.417882680892944, 63.314505368471146, 65.10679319500923, 62.44088664650917, 61.49855621159077, 63.847099989652634, 63.81184548139572, 60.193729028105736, 59.86920744180679, 55.88190279901028, 53.27923245728016, 48.97662453353405, 50.3014500439167, 61.7040453851223, 58.97850103676319, 61.3730413466692, 49.257653653621674, 49.81251887977123, 52.16971859335899, 53.099365308880806, 44.29762400686741, 43.77893663942814, 45.0252241641283, 47.22585707902908, 51.37178801000118, 55.25622457265854, 50.36343611776829, 53.805162236094475, 52.52708941698074, 50.65557584166527, 54.750224724411964, 50.66813036799431, 48.21033865213394, 45.256403759121895, 43.04002448916435, 46.07956498861313, 46.73097163438797, 50.4433686286211, 44.097887724637985, 55.12302652001381, 65.72344690561295, 54.02825206518173, 56.25398263335228, 48.61413158476353, 50.22569350898266, 47.87757150828838, 41.53624378144741, 48.19691777229309, 50.17181620001793, 45.47914780676365, 56.69078439474106, 55.929415449500084, 54.919087663292885, 55.678085535764694, 53.96418370306492, 52.72777184844017, 54.0048149228096, 53.76537077128887, 50.862106159329414, 50.94736598432064, 49.592028111219406, 43.72972548007965, 47.32027821242809, 46.71797253191471, 50.436528995633125, 52.701895236968994, 51.1092334985733, 50.26093661785126, 55.177819579839706, 59.120962992310524, 61.08075723052025, 61.81507162749767, 61.95528030395508, 62.07908906042576, 63.14511425793171, 56.38490080833435, 50.70881858468056, 53.17438468337059, 51.16024196147919, 57.87675015628338, 61.139494478702545, 67.4995020031929, 70.5889642238617, 72.58602306246758, 71.83892235159874, 72.53912597894669, 72.29690417647362, 73.95559877157211, 70.3210861980915, 70.97775176167488, 67.49149203300476, 65.57720795273781, 72.34251692891121, 79.81660947203636, 80.12419536709785, 79.84803378582001, 42.40148775279522, 0.0992581105674617, 14.620230384171009, 81.84076085686684, 63.92352148890495, 64.46394369006157, 69.04961362481117, 30.930431485176086, 27.62214470654726, 17.445150800049305, 7.709473762661219, 0.572601486928761, 8.468385189771652, 49.65499833226204, 45.1065967977047, 28.285157829523087, 21.519575268030167, 15.723314043134451, 44.37130965292454, 11.242138501256704, 0.5163660482503474, 0.7912069035228342, 0.6428469519596547, 1.0130446404218674, 0.4498219408560544, 52.21377722918987, 80.78330799937248, 54.87564459443092, 37.14098922908306, 41.41253001987934, 74.06400695443153, 83.12120094895363, 60.71233280003071, 84.51805159449577, 78.16698879003525, 84.50330838561058, 21.78309492766857, 0.2952027751598507, 3.906753952614963, 0.19436154485447332, 2.6899504708126187, 14.44223653525114, 50.95808520913124, 80.69867894053459, 78.12028929591179, 76.21191769838333, 75.33848896622658, 72.39294782280922, 76.52936026453972, 76.04113206267357, 72.75244653224945, 67.11581379175186, 64.6095822751522, 60.04761926829815, 60.98754063248634, 56.582896783947945, 58.393161445856094, 58.78641374409199, 63.88914853334427, 66.14083170890808, 66.77905306220055, 67.80268773436546, 61.75110965967178, 54.615122973918915, 57.36331790685654, 53.47551852464676, 58.390152007341385, 53.6126683652401, 55.1176156103611, 55.29810592532158, 53.377954959869385, 58.94196979701519, 60.90032771229744, 65.77164351940155, 70.06186410784721, 67.48067021369934, 68.38355496525764, 64.00941967964172, 65.84341406822205, 65.60368493199348, 67.3518343269825, 64.72219303250313, 67.28155329823494, 64.98101994395256, 63.84184867143631, 67.63488873839378, 63.99522364139557, 63.50209750235081, 60.81751875579357, 60.95385164022446, 58.60232502222061, 56.02156810462475, 52.2812844067812, 60.842251628637314, 61.30681470036507, 64.0330696105957, 53.910241797566414, 51.30832001566887, 55.46425960958004, 56.58252440392971, 47.2144690901041, 45.763627141714096, 51.14861078560352, 49.149572253227234, 53.553668931126595, 58.02519679069519, 50.72216346859932, 58.33493337035179, 54.49983336031437, 51.16198606789112, 57.561830654740334, 54.14609134197235, 49.959251806139946, 47.54970230162144, 46.39943942427635, 49.55211505293846, 47.77818024158478, 53.25716704130173, 44.645730927586555, 54.31249961256981, 64.12020653486252, 60.86081363260746, 59.44888159632683, 54.08557578921318, 52.662742137908936, 52.14594326913357, 41.909421756863594, 48.10701459646225, 51.21027007699013, 49.19219456613064, 60.872471407055855, 58.733493983745575, 58.61524052917957, 58.58973249793053, 58.44310596585274, 58.90726625919342, 57.5349584966898, 56.037952825427055, 54.37537483870983, 53.251828327775, 53.337798714637756, 46.6407036781311, 50.27242720127106, 50.89310109615326, 53.52678157389164, 55.34822143614292, 53.50478075444698, 54.21398229897022, 58.705375492572784, 64.30602416396141, 65.06265476346016, 65.27145355939865, 67.75842010974884, 69.99732837080956, 69.56304207444191, 61.80057540535927, 53.351124599575996, 54.26384322345257, 55.8535411208868, 60.15038475394249, 65.5061137676239, 70.80796927213669, 74.0373095870018, 74.26166474819183, 73.4713527560234, 72.88057565689087, 74.63150650262833, 75.67420855164528, 72.77008518576622, 75.59367567300797, 70.41289687156677, 70.0782260298729, 76.58076390624046, 82.09736108779907, 79.30421456694603, 79.36047434806824, 45.97853600978851, 0.15795584680745378, 17.36713908612728, 88.95906329154968, 71.95181429386139, 75.12700751423836, 77.94584065675735, 42.642607614398, 37.830557227134705, 39.75663587450981, 24.313432350754738, 4.28645309060812, 17.2890342772007, 57.60504573583603, 77.67407163977623, 74.09040793776512, 86.7814153432846, 70.46652719378471, 79.75743904709816], [0.3733334701973945, 0.02733832698140759, 0.06747421881300397, 0.04091159200470429, 0.17615449527511373, 0.4608613281743601, 27.838923074305058, 50.82481496036053, 36.688266322016716, 24.257676042616367, 38.83156031370163, 30.17165780067444, 40.97502529621124, 48.08839559555054, 67.72695019841194, 65.84000945091248, 71.9309838116169, 12.612626161426306, 0.30071218265220523, 1.810174654237926, 0.36250731674954295, 1.1094806157052517, 2.936173458583653, 24.754531681537628, 63.54650191962719, 73.96384432911873, 65.54687798023224, 69.7657459974289, 67.31199726462364, 70.75981065630913, 64.88211885094643, 64.6483401954174, 59.94008123874664, 55.77193669974804, 52.84758321940899, 48.126408755779266, 50.599962025880814, 49.758763164281845, 49.39821571111679, 55.836385041475296, 57.25509591400623, 56.551468670368195, 59.48842607438564, 56.781018152832985, 53.26104283332825, 49.85587455332279, 48.184872418642044, 51.19273401796818, 49.81639087200165, 47.454490810632706, 50.51637411117554, 49.96226504445076, 54.90479663014412, 58.44567842781544, 62.42734037339687, 62.047349363565445, 59.614731296896935, 61.33967913687229, 60.655742436647415, 61.93914636969566, 59.256391525268555, 58.866813629865646, 64.9467533826828, 63.254590183496475, 60.8466973900795, 60.04153199493885, 59.756034314632416, 61.21213138103485, 59.00074504315853, 58.1606937199831, 50.73448620736599, 51.137207597494125, 44.521314203739166, 42.26461909711361, 58.250779286026955, 61.22287340462208, 55.401031002402306, 48.82907085120678, 45.725499987602234, 48.709031492471695, 47.323880419135094, 46.3655224442482, 37.871728017926216, 42.72626772522926, 47.248127683997154, 50.98699405789375, 51.84177339076996, 51.6900285333395, 54.67563472688198, 54.438215866684914, 52.32533164322376, 49.30245324969292, 48.15117582678795, 43.822254315018654, 40.647266283631325, 38.975507989525795, 45.66080465912819, 47.86665849387646, 48.9836997538805, 44.04997229576111, 44.33473661541939, 56.70678913593292, 54.05005909502506, 46.76320530474186, 42.26672798395157, 46.71358376741409, 43.67714770138264, 50.28048276901245, 50.94172328710556, 57.94973663985729, 46.313621029257774, 51.454676762223244, 54.11563217639923, 56.310960575938225, 53.87631721794605, 57.378718480467796, 52.208848893642426, 53.05820591747761, 51.74203634262085, 52.22865343093872, 48.44031371176243, 48.03924523293972, 45.612532049417496, 44.99720826745033, 46.338429898023605, 50.543067678809166, 54.663908556103706, 55.76070450246334, 55.60591980814934, 52.206979393959045, 54.21788088977337, 58.200743570923805, 58.773388043046, 55.943771079182625, 56.791042014956474, 55.10841250419617, 52.79001630842686, 47.39993713796139, 45.25140322744846, 50.22039279341698, 53.44106197357178, 60.48801563680172, 65.05837619304657, 65.66786348819733, 67.95670107007027, 67.32797920703888, 67.32403501868248, 66.70486584305763, 66.5016907453537, 65.65237551927567, 64.80924636125565, 59.04063530266285, 58.080544620752335, 63.55781011283398, 74.72767934203148, 72.96310722827911, 77.29232892394066, 45.29198504984379, 0.10136192853678949, 15.566723495721817, 71.30249753594398, 56.92665673792362, 54.97936002910137, 48.99845816195011, 21.07149761170149, 15.432746484875679, 6.843304065987468, 1.0879800631664693, 1.3566121109761298, 5.077747330069542, 11.89559418708086, 54.391086995601654, 51.687357276678085, 43.86989235877991, 49.61318917572498, 26.288336478173733, 3.8213205244392157, 0.13945474347565323, 0.2865742100402713, 0.3329501871485263, 0.4100890166591853, 0.44192572706378996, 39.39529426395893, 62.12241813540459, 49.51820567250252, 30.412171594798565, 39.61629040539265, 35.72163239121437, 49.32926081120968, 55.49708604812622, 78.24872240424156, 71.0571750998497, 82.830820530653, 14.114711210131645, 0.16928326163906604, 1.8746657436713576, 0.7491865614429116, 1.8284839717671275, 4.64695162139833, 37.093674167990685, 78.92766997218132, 80.46078130602837, 68.93147796392441, 75.043525993824, 69.034034460783, 75.65319567918777, 69.07067209482193, 71.35579347610474, 65.3684851527214, 62.483706548810005, 56.4327098429203, 55.546646788716316, 55.28666093945503, 55.19074648618698, 53.16794402897358, 59.772548228502274, 62.86656640470028, 60.60422100126743, 61.328507736325264, 58.710915595293045, 56.228801384568214, 52.922860980033875, 52.85517141222954, 54.42184254527092, 52.31842741370201, 50.49004912376404, 53.56677822768688, 51.009086072444916, 58.59923958778381, 59.61186625063419, 63.10390166938305, 63.213909566402435, 61.94320075213909, 61.70989327132702, 63.80463346838951, 63.317719995975494, 62.94032044708729, 61.91792070865631, 65.14699503779411, 64.62486505508423, 63.76033544540405, 63.55374813079834, 63.41023363173008, 62.00121223926544, 62.30274125933647, 60.075407177209854, 55.53981855511665, 54.79092054069042, 48.52271988987923, 47.15918965637684, 60.49618899822235, 63.97010698914528, 59.80988122522831, 49.0814571082592, 50.441673919558525, 50.01202717423439, 49.05079275369644, 49.51674275100231, 42.293607741594315, 43.85524034500122, 47.65151783823967, 52.83380515873432, 56.70528061687946, 55.336818248033524, 57.93072246015072, 56.49784974753857, 53.631891533732414, 51.43338270485401, 49.73433427512646, 46.67635716497898, 43.92392545938492, 41.72517344355583, 47.36399866640568, 49.241052344441414, 50.88546730577946, 43.58362331986427, 44.84674394130707, 55.892929807305336, 57.760871574282646, 47.75867968797684, 46.0527004301548, 50.36039248108864, 47.32535853981972, 53.88843096792698, 54.987278804183006, 60.51044963300228, 56.18881992995739, 56.12378641963005, 57.30415128171444, 58.26934888958931, 57.191031351685524, 59.69232313334942, 56.23592220246792, 56.12160153687, 54.394928589463234, 53.92204776406288, 52.624238803982735, 50.18221244215965, 46.9319124519825, 47.69402235746384, 48.26224386692047, 53.40315900743008, 57.89008364081383, 58.72203379869461, 56.70192539691925, 54.74393606185913, 56.35597676038742, 64.66517329216003, 63.91276806592941, 63.56634825468063, 63.209509402513504, 62.667806670069695, 57.90085606276989, 52.61114090681076, 51.287633925676346, 54.58948194980621, 59.87622946500778, 65.73377475142479, 70.81341058015823, 69.2388054728508, 71.98241025209427, 75.36578670144081, 73.41477379202843, 73.7667565047741, 72.36340060830116, 75.48465192317963, 74.04215812683105, 67.41781398653984, 68.35840031504631, 73.09226229786873, 81.66491389274597, 79.17168527841568, 80.1134343445301, 50.149465799331665, 0.028724118928948883, 18.538673222064972, 80.10096341371536, 69.16363030672073, 65.30993789434433, 60.23709610104561, 27.84096546471119, 24.076705053448677, 14.251702409237623, 0.3626401908695698, 1.4787326892837882, 1.9265957758761942, 42.14535489678383, 59.696985483169556, 52.663608491420746, 38.70897129178047, 37.70978830754757, 50.750414952635765, 0.7158168114256114, 0.26839815254788846, 0.3162601467920467, 0.26182085392065346, 0.47845272172708064, 0.40965088235680014, 52.57242098450661, 78.83560851216316, 60.32153896987438, 41.13123491406441, 58.908865973353386, 44.9592787027359, 56.21555909514427, 60.93537703156471, 85.3674428164959, 74.62285816669464, 92.26068332791328, 18.76195304095745, 0.5169529386330396, 6.0798613820225, 1.628167626913637, 4.451999757438898, 29.465477094054222, 57.410583570599556, 89.66545298695564, 81.07935771346092, 72.1280412375927, 71.81510522961617, 71.29077896475792, 78.71788322925568, 69.18845817446709, 71.40180140733719, 66.85831680893898, 63.847031593322754, 60.76149456202984, 58.193204775452614, 58.421656116843224, 57.835130989551544, 55.92691898345947, 63.535170927643776, 66.12285107374191, 64.65427547693253, 66.39268219470978, 62.619906440377235, 58.37321251630783, 56.86514563858509, 54.58842180669308, 58.13610523939133, 54.585256576538086, 52.65297286212444, 55.104517713189125, 54.349266439676285, 59.49651584029198, 60.556339770555496, 65.64594626426697, 67.34206885099411, 63.65065433084965, 64.72642600536346, 65.60707435011864, 67.0324918627739, 66.29055887460709, 64.7672738134861, 67.84215241670609, 67.06370338797569, 66.00575655698776, 64.68423306941986, 66.15513414144516, 66.86533123254776, 64.4880647957325, 62.26562485098839, 58.05618032813072, 60.64019747078419, 55.15064723789692, 49.93329539895058, 64.31580483913422, 65.31464964151382, 59.37173813581467, 53.320148661732674, 52.003542110323906, 55.62181055545807, 52.33014218509197, 51.61934852600098, 43.35294529795647, 47.3902552574873, 52.283796072006226, 55.13537585735321, 59.68398258090019, 56.98327749967575, 59.96750816702843, 61.42780780792236, 55.693033933639526, 54.8115686327219, 54.10713203251362, 50.088684260845184, 44.80683088302612, 44.25023674964905, 51.83762401342392, 51.504758074879646, 53.67085464298725, 46.35220795869827, 45.323093980550766, 57.027598321437836, 60.26275232434273, 49.74840871989727, 50.6086977571249, 55.25324173271656, 50.319700464606285, 53.58464486896992, 58.46360206604004, 62.8556913882494, 56.262999549508095, 57.61115200817585, 59.18900594115257, 61.50140605866909, 61.89059637486935, 63.9791277050972, 59.199683368206024, 59.34947893023491, 58.54400955140591, 57.454778999090195, 56.28896355628967, 52.94944815337658, 52.488893866539, 50.54185554385185, 53.241394087672234, 59.0273854136467, 59.572671353816986, 61.56408749520779, 59.82371628284454, 57.43625119328499, 57.61039584875107, 67.81277999281883, 68.22437390685081, 67.52309873700142, 68.40719729661942, 66.32499262690544, 63.47987249493599, 55.96969708800316, 52.05153353512287, 57.61904798448086, 62.19041168689728, 67.26817801594734, 71.15170642733574, 71.61508396267891, 73.35345268249512, 75.91203019022942, 75.10031014680862, 74.20454621315002, 73.53580489754677, 77.07960113883018, 78.03809210658073, 68.69245558977127, 69.69091281294823, 76.3806514441967, 82.7538138628006, 80.14253318309784, 81.03109270334244, 55.3109872341156, 0.20004853344289586, 20.56610193103552, 87.99010008573532, 75.45059815049171, 75.37867560982704, 70.2743411064148, 44.262513890862465, 37.52020888030529, 36.043737307190895, 14.803042374551296, 4.635753147304058, 8.718515317887068, 44.54057916998863, 80.2890457212925, 82.27222010493279, 63.36439289152622, 71.09055250883102, 38.02579455077648], [0.2072957094060257, 0.0581008788140025, 0.10538151167565957, 0.09209400319377892, 0.20870673994068056, 0.33486065338365734, 31.21000338345766, 55.969187915325165, 40.782326236367226, 26.983689665794373, 40.542350113391876, 20.115560106933117, 40.16621209681034, 45.50434045493603, 71.47737175226212, 64.8093831539154, 78.11606392264366, 17.238008715212345, 0.2797036443371326, 1.5295024774968624, 1.209040735848248, 6.072143521159887, 17.192663848400116, 36.14780232310295, 70.48621013760567, 71.41580745577812, 67.77637034654617, 69.12962973117828, 66.9630315899849, 67.00599208474159, 64.69064712524414, 63.5219020396471, 59.01347056031227, 57.759317457675934, 53.66574391722679, 52.44546599686146, 51.12755611538887, 49.87982466816902, 46.49605683982372, 54.117608070373535, 55.23152209818363, 55.35267859697342, 56.02498412132263, 55.629387348890305, 54.73014660179615, 52.586962804198265, 47.58660592138767, 50.92300929129124, 49.63130280375481, 51.81756108999252, 48.226168602705, 49.64024372398853, 54.97228480875492, 60.59785254299641, 59.74415235221386, 59.753803834319115, 59.33923847973347, 59.011175483465195, 60.36204479634762, 60.6890894472599, 61.53245039284229, 61.5887101739645, 58.67369279265404, 63.56087654829025, 61.45837336778641, 58.35210084915161, 57.026868760585785, 55.43253891170025, 55.58340221643448, 58.411769047379494, 56.40461415052414, 53.605832532048225, 42.25236475467682, 50.33665515482426, 53.58359232544899, 55.87242230772972, 57.78086230158806, 44.45193752646446, 45.50720930099487, 43.0072208493948, 45.40328107774258, 44.504180923104286, 41.1897099763155, 42.74340480566025, 43.55764031410217, 48.816846907138824, 49.56645928323269, 53.470867574214935, 59.53361704945564, 57.234550416469574, 49.81750041246414, 51.076821237802505, 50.106376111507416, 42.02759921550751, 43.24184685945511, 43.41846518218517, 44.22857791185379, 45.53247034549713, 46.12757921218872, 49.47676509618759, 36.90540187060833, 35.22617697715759, 48.83189409971237, 44.5014488697052, 41.73364318907261, 42.851930782198906, 51.76355458796024, 50.99014408886433, 53.255920708179474, 56.2381374835968, 56.241055727005005, 54.587992429733276, 53.0095761269331, 58.299682661890984, 51.19838431477547, 56.03245452046394, 54.70274247229099, 56.76057144999504, 52.722364738583565, 54.47751335799694, 50.732939690351486, 49.30488511919975, 46.93521827459335, 47.00187049806118, 44.98434975743294, 48.56210097670555, 58.24445642530918, 60.61266414821148, 60.199516117572784, 62.26526767015457, 58.848582208156586, 59.6455742418766, 59.79911260306835, 57.47169569134712, 57.09748037159443, 57.00858794152737, 51.310280710458755, 45.84948733448982, 47.28253483772278, 51.364097222685814, 59.98571678996086, 63.36150884628296, 71.5717662870884, 68.1086853146553, 64.05624076724052, 68.2585720717907, 64.8508009314537, 66.31481677293777, 68.24515879154205, 66.69169574975967, 65.2486015856266, 62.731058076024055, 64.51957270503044, 66.24387457966805, 73.59170749783516, 74.06404495239258, 76.27738058567047, 48.33842217922211, 0.18236215983051807, 16.524439305067062, 79.02065858244896, 57.18617141246796, 46.52795232832432, 44.394906386733055, 23.872441314160824, 12.878468446433544, 5.892596505582333, 4.670466659590602, 3.687434233725071, 1.9888567412272096, 2.260678242892027, 31.27579305320978, 46.53396740555763, 44.875785782933235, 34.21478524804115, 2.330386689864099, 0.6630778382532299, 0.08112935756798834, 0.054049980753916316, 0.12720436410745606, 0.20141234854236245, 0.3065593563951552, 38.93145315349102, 69.79698792099953, 50.34383676946163, 29.767353795468807, 41.194243133068085, 25.453859455883503, 48.475572019815445, 50.5342635512352, 81.51325643062592, 70.3652474284172, 87.08371952176094, 20.788503997027874, 0.8867216657381505, 3.229414173401892, 1.566172291059047, 7.709248149767518, 18.56711469590664, 44.35577228665352, 79.77247104048729, 79.6002946794033, 73.68693798780441, 74.24541682004929, 71.24670132994652, 72.4034732580185, 67.82902032136917, 68.42849135398865, 64.81167823076248, 65.1885724067688, 55.1215635985136, 58.460091054439545, 54.432728961110115, 54.2203963547945, 52.89464749395847, 56.73241876065731, 58.529558926820755, 58.82438510656357, 61.11426763236523, 60.11843226850033, 58.30159775912762, 54.86904054880142, 51.00681759417057, 52.94007405638695, 48.8310619443655, 52.8390146791935, 51.41630262136459, 52.21619389951229, 56.62646524608135, 61.9926892966032, 60.946217849850655, 61.214905232191086, 64.00424435734749, 62.090826630592346, 62.53900118172169, 65.12729689478874, 65.57963222265244, 61.41524948179722, 59.8199088871479, 65.00782370567322, 61.82659260928631, 58.90617951750755, 58.54896828532219, 56.57663471996784, 57.99693010747433, 60.22966369986534, 59.2826709151268, 55.58830015361309, 48.509865179657936, 56.04171082377434, 55.42363978922367, 58.56841564178467, 59.05166611075401, 46.39051750302315, 47.29108817875385, 45.107333958148956, 48.54873709380627, 46.23409129679203, 46.21750898659229, 45.05237750709057, 47.88845792412758, 50.087578520178795, 51.99157655239105, 54.6141692250967, 62.905647307634354, 57.396889105439186, 52.41979457437992, 51.54079154133797, 51.883274763822556, 45.11815957725048, 43.997516110539436, 44.905515387654305, 46.58205762505531, 46.04837626218796, 47.28031575679779, 48.37809965014458, 37.23366245627403, 36.16824522614479, 48.21016006171703, 47.77461603283882, 45.19279137253761, 48.13357897102833, 56.18990287184715, 52.33713001012802, 57.53773234784603, 56.933158189058304, 58.91998417675495, 58.28128404915333, 57.25516811013222, 59.35165621340275, 53.744449093937874, 58.41145746409893, 57.762741073966026, 58.49114678800106, 57.32605330646038, 56.65980465710163, 53.85379962623119, 50.41351743042469, 49.743567779660225, 47.85968966782093, 46.740999296307564, 50.03519833087921, 59.71347279846668, 60.66101275384426, 62.198478654026985, 63.07196818292141, 61.007744148373604, 64.73362281918526, 63.91004741191864, 64.27947118878365, 62.68628887832165, 62.476099357008934, 57.341894656419754, 52.35285736620426, 51.71728067100048, 57.403911128640175, 63.77016171813011, 68.33975091576576, 73.62370938062668, 72.86883428692818, 69.22274753451347, 72.05519154667854, 70.74198201298714, 72.35113486647606, 73.20605099201202, 75.81360787153244, 71.54220387339592, 71.28677397966385, 69.72160756587982, 75.50909221172333, 79.04148146510124, 81.25570625066757, 81.29567250609398, 55.50440825521946, 0.2176128831342794, 19.163490794599056, 86.21472135186195, 66.04932501912117, 55.48050373792648, 54.64890316128731, 32.88938596844673, 22.991616278886795, 10.183610301464796, 7.313219625502825, 4.599308827891946, 2.19932958483696, 22.548529654741287, 56.88173174858093, 56.50441959500313, 51.47389993071556, 52.07142546772957, 12.618961371481419, 0.26045233360491693, 0.2673324878560379, 0.315070009091869, 0.12953950208611786, 0.2902420819737017, 0.43087464349810034, 46.28772921860218, 85.9456729888916, 62.543800324201584, 49.05468374490738, 61.85786113142967, 33.684033527970314, 57.2076478600502, 60.45959696173668, 86.65789917111397, 79.29950281977654, 92.92700797319412, 25.683661624789238, 1.4387564593926072, 8.804935980588198, 2.4689013697206974, 11.59046296030283, 50.19833877682686, 61.97178281843662, 83.0815538764, 77.19505414366722, 74.12173345685005, 73.14941123127937, 74.70899194478989, 71.53169363737106, 71.07883393764496, 68.37930679321289, 66.16610795259476, 64.9015586078167, 60.34780316054821, 62.141504511237144, 57.523904889822006, 56.36439710855484, 54.47045333683491, 58.6998999863863, 61.665101274847984, 60.384216606616974, 63.56567569077015, 64.92806598544121, 61.28757633268833, 56.758105382323265, 52.13761791586876, 57.975009083747864, 53.187680169939995, 56.889905110001564, 53.73762086033821, 54.75905925035477, 58.85998919606209, 65.06925120949745, 63.60615871846676, 61.36066161096096, 64.11588996648788, 63.32488641142845, 64.35574069619179, 66.64870485663414, 66.75101056694984, 65.1906318962574, 61.72600440680981, 67.61022046208382, 65.38034051656723, 62.89827190339565, 61.775945127010345, 59.608412235975266, 60.12085273861885, 64.58241373300552, 60.96128784120083, 59.73985478281975, 54.72906745970249, 57.77420125901699, 57.73998789489269, 63.33680257201195, 59.67349134385586, 47.99139440059662, 47.8102733194828, 50.085804015398026, 50.5952350795269, 48.95713157951832, 46.21597766876221, 49.4258364289999, 48.911070451140404, 55.91335371136665, 55.979470163583755, 59.59518514573574, 64.71954077482224, 62.060082480311394, 54.513919204473495, 54.13501113653183, 56.42933942377567, 46.93041153252125, 49.299063831567764, 45.678998082876205, 49.70274277031422, 48.888921439647675, 51.28277398645878, 51.002037450671196, 39.32760089635849, 38.24326068162918, 51.94058708846569, 51.56275436282158, 49.394370317459106, 49.676569774746895, 55.507406294345856, 57.120518535375595, 59.59287106990814, 62.87124015390873, 59.97352324426174, 59.96412254869938, 58.82043331861496, 62.371422573924065, 54.28381875157356, 62.12150238454342, 59.552038460969925, 62.471786588430405, 59.65942829847336, 61.09452769160271, 58.155620992183685, 54.962196350097656, 52.84154534339905, 53.80807287991047, 50.7921177148819, 51.49549037218094, 64.4481973350048, 63.79087820649147, 65.31851023435593, 66.56869634985924, 64.63463053107262, 66.29445746541023, 66.55505508184433, 66.86454847455025, 65.17582029104233, 67.05977439880371, 60.602480694651604, 54.4644458591938, 53.38439181447029, 59.42293658852577, 65.4092113673687, 70.13073921203613, 74.7135517001152, 73.68292540311813, 70.43119668960571, 76.16727009415627, 72.51713275909424, 73.79614412784576, 74.47517529129982, 76.93701758980751, 72.90534272789955, 72.64209285378456, 72.34063223004341, 76.06086060404778, 79.71266984939575, 79.56196993589401, 81.0731640458107, 57.31993943452835, 0.3530537209007889, 20.04125129431486, 95.0875036418438, 72.05468997359276, 70.4818631708622, 67.06900030374527, 50.85776299238205, 34.60293062031269, 28.785670772194862, 17.865740731358528, 8.473844546824694, 4.577673738822341, 26.83878254145384, 62.41855524480343, 64.6797189116478, 65.34688711166382, 46.791164204478264, 3.965652692131698], [0.03797633486101404, 0.14472054841462523, 0.0581522465654416, 0.015219418146443786, 0.10110985065693967, 0.33155987737700343, 17.83550765365362, 52.654526978731155, 50.05604401230812, 23.876721784472466, 42.47116461396217, 22.808627597987652, 39.34312306344509, 49.688033759593964, 63.22844758629799, 70.27693256735802, 72.23705738782883, 30.20079843699932, 0.06916568469023332, 2.3703797813504934, 1.3425737642683089, 19.297743290662766, 45.06096504628658, 55.70909947156906, 73.4320704638958, 71.45821318030357, 71.6599291563034, 65.5726557970047, 65.62165796756744, 65.80004319548607, 62.92165204882622, 60.83798065781593, 60.33649116754532, 58.04238706827164, 51.84107422828674, 52.51855127513409, 50.599019676446915, 48.849380761384964, 49.98572498559952, 50.762300714850426, 52.67778553068638, 54.94399532675743, 55.56347228586674, 56.24067574739456, 54.38994325697422, 53.238084465265274, 49.93432134389877, 47.8028105199337, 47.316018640995026, 47.19846814870834, 49.76065546274185, 49.3541494756937, 55.46574532985687, 58.77662166953087, 59.93594706058502, 61.08136519789696, 61.53308115899563, 60.60134455561638, 60.70771984755993, 63.28489735722542, 61.21168300509453, 59.43804457783699, 55.85975758731365, 60.76349325478077, 57.25336700677872, 56.64496265351772, 52.48190984129906, 52.34934635460377, 54.958404153585434, 58.24489340186119, 56.008325815200806, 52.41881042718887, 44.591287449002266, 55.6720856577158, 58.485344499349594, 51.28170244395733, 42.650970965623856, 46.607227474451065, 44.50331076979637, 43.53358380496502, 43.39221999049187, 44.63529288768768, 43.670817241072655, 42.64688238501549, 42.924715876579285, 42.6089908182621, 44.16857533156872, 44.90867681801319, 52.77044355869293, 52.41563379764557, 44.910998493433, 45.384396091103554, 45.16418270766735, 41.71419583261013, 40.45620493590832, 43.10738727450371, 43.51265072822571, 43.79781782627106, 41.54341779649258, 46.50286987423897, 40.67026644945145, 31.021660789847374, 38.39221648871899, 41.623080521821976, 42.3735174536705, 47.47404836118221, 45.586127266287804, 49.97270688414574, 59.1681906580925, 54.519235119223595, 55.967310816049576, 57.25623965263367, 53.56941528618336, 54.990493431687355, 58.183568492531776, 54.63053874671459, 55.58411657810211, 56.20162524282932, 54.94111888110638, 54.3699449300766, 56.23372212052345, 49.2759420722723, 50.830043479800224, 46.399751007556915, 46.49270921945572, 49.358473643660545, 54.703738018870354, 58.68501998484135, 61.86473876237869, 59.11615625023842, 60.711025670170784, 59.88191395998001, 64.84172701835632, 57.16770060360432, 58.93382303416729, 58.91499504446983, 54.10543732345104, 49.60581377148628, 48.68613392114639, 54.04190093278885, 58.97622115910053, 65.1563349366188, 66.05693221092224, 64.09971043467522, 65.50779327750206, 68.0734384059906, 66.71127989888191, 65.41102007031441, 66.58472388982773, 66.82945355772972, 66.80052191019058, 63.701871782541275, 64.87546920776367, 69.22327190637589, 74.4801378250122, 78.49468320608139, 78.70344400405884, 47.15767353773117, 0.25330108765047044, 22.27150171995163, 72.936941832304, 62.24871575832367, 38.03610719740391, 40.24956822395325, 23.461048789322376, 13.831372763961554, 4.315553829073906, 6.146764392033219, 1.7005380685441196, 0.9679125028196722, 2.9411117685958743, 15.955055058002472, 26.050575636327267, 30.44001840054989, 6.1250233836472034, 0.037046635334263556, 0.10129167683771811, 0.13895456562750041, 0.012414757657097653, 0.03233992734749336, 0.12019797795801423, 0.1721639375318773, 23.840201944112778, 67.20440223813057, 55.886154770851135, 28.216273225843906, 42.754112631082535, 27.780744396150112, 51.030676513910294, 53.74259099364281, 74.45947453379631, 76.23388051986694, 79.16198819875717, 36.77144005894661, 0.2283513592556119, 2.1798468427732587, 1.4195275912061334, 21.707560680806637, 50.32562434673309, 64.99707788228989, 87.26981833577156, 79.79638695716858, 76.01772531867027, 71.73417717218399, 71.13105073571205, 71.1113753914833, 66.92340731620789, 65.06972998380661, 65.42819514870644, 62.80866511166096, 57.05493405461311, 57.53124989569187, 54.69163566827774, 53.706325739622116, 53.74512165784836, 54.565653428435326, 58.21118921041489, 57.76343643665314, 58.59463043510914, 58.3152162283659, 56.792432740330696, 57.12286300957203, 53.505194932222366, 51.65116801857948, 51.13087333738804, 50.00882014632225, 51.151897609233856, 50.96571519970894, 57.42495819926262, 59.65825416147709, 62.010939717292786, 62.898632884025574, 62.40608051419258, 62.946810498833656, 60.95224432647228, 64.85871970653534, 61.65301412343979, 60.71657337248325, 57.24217280745506, 61.707043424248695, 60.2896548807621, 57.035076320171356, 55.198646262288094, 54.11568157374859, 58.499331548810005, 60.56966945528984, 58.928450122475624, 56.38780005276203, 48.416564986109734, 57.7798667550087, 59.73044268786907, 53.345523700118065, 45.066797733306885, 50.309513211250305, 48.584322184324265, 48.342818543314934, 46.61045730113983, 47.291939333081245, 44.468576833605766, 46.33301138877869, 45.559125915169716, 46.692164316773415, 45.13454049825668, 46.53459057211876, 53.473713621497154, 51.50224260985851, 47.90139622986317, 46.548976600170135, 46.462367847561836, 45.76726354658604, 42.422854006290436, 46.091420352458954, 47.11455725133419, 47.35353022813797, 43.6676824092865, 49.56222251057625, 42.33716860413551, 35.231238305568695, 39.14305239915848, 44.0415595471859, 46.811291724443436, 51.865643709897995, 52.784654796123505, 53.15532870590687, 60.867926850914955, 58.44977840781212, 57.34169326722622, 59.59389701485634, 55.90350084006786, 55.00568501651287, 59.74714279174805, 58.86262245476246, 57.77434945106506, 58.847088888287544, 57.044070437550545, 57.21633419394493, 57.70731344819069, 53.46845470368862, 55.510491728782654, 49.38188798725605, 50.9834336489439, 51.81561939418316, 55.09105883538723, 60.93945801258087, 64.84723672270775, 62.878756150603294, 63.57732966542244, 63.84658321738243, 68.16748335957527, 63.108461424708366, 65.26402875781059, 63.9224499464035, 59.22461003065109, 53.67922179400921, 53.62871490418911, 57.984588369727135, 62.81252570450306, 69.14909988641739, 71.68072164058685, 67.67647370696068, 70.06719902157784, 74.6575579047203, 72.84749463200569, 71.66003555059433, 73.68459731340408, 74.64992791414261, 72.40172535181046, 71.77570134401321, 72.47544139623642, 77.71652296185493, 79.13883224129677, 84.98693883419037, 81.71723708510399, 51.54640004038811, 0.25637215410824865, 27.230005748569965, 80.3150287270546, 71.4156174659729, 49.681783095002174, 50.514743998646736, 36.63264490664005, 20.650394707918167, 9.704019036144018, 6.086416030302644, 4.213748266920447, 3.2389115262776613, 8.940675146877766, 40.65010093152523, 48.01897332072258, 47.59916804730892, 18.877884820103645, 0.14468342618783936, 0.16483407147461548, 0.31289195409044623, 0.18945568153867498, 0.07679452493903227, 0.18262345518451184, 0.3418598778080195, 28.541074097156525, 79.41415026783943, 68.21691110730171, 49.17092330753803, 68.65381926298141, 35.712794065475464, 54.55779165029526, 64.61693868041039, 79.11899730563164, 83.6196506023407, 82.57709294557571, 45.42213186621666, 0.7943890546448529, 7.204960584640503, 1.3739416748285294, 24.756631068885326, 69.22381147742271, 73.08302119374275, 81.78400710225105, 79.35836166143417, 75.79750433564186, 72.09546938538551, 71.89913392066956, 72.45524168014526, 68.53018149733543, 67.45921656489372, 68.30374404788017, 64.97174084186554, 61.13350220024586, 62.79376231133938, 56.97073437273502, 56.73453524708748, 56.90106511116028, 59.158421382308006, 62.96669103205204, 62.27941431105137, 63.18365179002285, 61.9083946198225, 60.60347244143486, 59.693124890327454, 55.72776027023792, 54.609753862023354, 54.13808897137642, 53.246770799160004, 54.60570327937603, 54.39396344125271, 59.20056492090225, 63.8727106153965, 63.159747272729874, 65.40857300162315, 63.49372275173664, 64.04487177729607, 62.327405735850334, 68.53432327508926, 63.30390773713589, 64.19667363166809, 60.369743183255196, 65.12111842632294, 62.64672540128231, 57.97795012593269, 58.20884473621845, 57.16518513858318, 60.919805467128754, 63.165218979120255, 63.475187346339226, 60.08140705525875, 55.99101014435291, 61.81891322135925, 63.46663020551205, 58.56474503874779, 47.283431589603424, 52.309957668185234, 51.70230947434902, 49.50210973620415, 48.08173455297947, 50.18076851963997, 47.06615924835205, 50.958096608519554, 51.209745705127716, 50.76804220676422, 49.641060680150986, 47.972072437405586, 58.555370941758156, 57.48020723462105, 50.59966184198856, 50.25815136730671, 51.35648623108864, 48.49728025496006, 46.04011930525303, 47.97597482800484, 48.50120164453983, 49.20834369957447, 44.92382660508156, 49.779377058148384, 44.26725223660469, 33.8562098890543, 37.2776222974062, 47.021469846367836, 53.05613122880459, 53.01258556544781, 55.822466388344765, 58.771970719099045, 62.79181681573391, 63.14172863960266, 59.86219681799412, 62.79828406870365, 56.813244223594666, 60.25751240551472, 62.40132696926594, 59.78367783129215, 59.876085072755814, 62.59787902235985, 59.42898206412792, 62.40928754210472, 64.04651328921318, 56.638567596673965, 57.31167867779732, 53.410815596580505, 54.69390034675598, 55.85835926234722, 57.55221337080002, 62.393058612942696, 67.33025908470154, 64.36634212732315, 65.53594216704369, 63.6843167245388, 68.46879959106445, 65.03990158438683, 64.99111220240593, 65.4536309838295, 61.48946709930897, 55.22045709192753, 54.106828048825264, 59.00835603475571, 64.91988882422447, 71.53031811118126, 71.09501346945763, 67.68208980560303, 71.4224722981453, 74.28378716111183, 73.88746842741966, 72.37847059965134, 74.01850819587708, 75.53909540176392, 74.55136120319366, 72.91032806038857, 72.83367097377777, 76.48753210902214, 80.67974835634232, 86.60957336425781, 84.6383835375309, 55.29731176793575, 0.5645031714811921, 29.536799266934395, 87.99551099538803, 77.36605256795883, 59.94379743933678, 62.400639206171036, 54.957803785800934, 32.91121579706669, 27.932270765304565, 26.34625107049942, 1.8831727746874094, 3.818358820863068, 16.152602657675743, 46.993556544184685, 44.38216187059879, 49.550112560391426, 8.709463253617287, 0.19065680302446708], [0.036162128890282474, 0.03349754784721881, 0.104487550270278, 0.1272750017233193, 0.158879850350786, 0.7558804366271943, 12.324020247906446, 42.40287847816944, 35.80968126654625, 21.865531504154205, 44.715362191200256, 23.118607364594936, 43.200752064585686, 47.43881665170193, 60.184020549058914, 69.9648629128933, 70.1350785791874, 41.968265399336815, 0.2609637624118477, 0.4397436050930992, 1.2593896966427565, 34.85972084105015, 72.19489485025406, 67.49250277876854, 77.4159362912178, 69.66698169708252, 71.1449807882309, 63.91504034399986, 65.6437499821186, 61.18502363562584, 63.17885644733906, 59.46587808430195, 59.61248941719532, 54.81100246310234, 54.93329510092735, 51.749157160520554, 49.45184603333473, 51.300256848335266, 49.45573702454567, 48.220168724656105, 52.608743235468864, 51.48304603993893, 51.86630107462406, 53.950280249118805, 52.94203095138073, 52.07861088216305, 49.86302196979523, 49.14550267159939, 45.92899426817894, 45.82443907856941, 47.33232356607914, 48.199828416109085, 53.342464864254, 58.93473878502846, 60.03584370017052, 59.17624622583389, 62.187820225954056, 64.90788146853447, 59.396159425377846, 58.11244770884514, 60.7192712277174, 57.985196337103844, 56.13146960735321, 56.37873753905296, 56.1709912866354, 52.82851964235306, 49.68149431049824, 50.61541959643364, 52.44914799928665, 52.99190707504749, 56.10036447644234, 50.25309383869171, 40.8599978685379, 51.97047248482704, 57.460858672857285, 45.87317906320095, 41.278442814946175, 49.74695719778538, 51.899173110723495, 46.93361476063728, 45.3161745518446, 45.06220757961273, 45.46532414853573, 44.822474643588066, 42.57033169269562, 42.34080880880356, 42.75921195745468, 42.43426859378815, 43.583813309669495, 42.56410002708435, 43.849643245339394, 42.55808115005493, 41.64815157651901, 41.45557031035423, 42.82291553914547, 42.33714200556278, 46.578132435679436, 42.48769752681255, 42.4690405279398, 46.8002001196146, 47.50975884497166, 38.33044320344925, 38.79803091287613, 36.82715266942978, 40.3877592086792, 43.76044683158398, 53.514747619628906, 56.618295684456825, 52.37971432507038, 55.76880186796188, 54.86880876123905, 54.8865158110857, 56.9473048299551, 52.640368938446045, 49.09578233957291, 54.32052098214626, 54.67319905757904, 55.75813204050064, 54.65324252843857, 56.81544430553913, 54.23864297568798, 55.874842777848244, 51.28491707146168, 51.13612085580826, 43.911925703287125, 46.203567534685135, 53.736287131905556, 58.07481452822685, 59.06853340566158, 60.989805310964584, 63.72659705579281, 59.798060059547424, 58.31870064139366, 58.93077179789543, 60.749297216534615, 58.53495083749294, 55.048041343688965, 48.47307935357094, 50.05058370530605, 51.524874195456505, 60.99935419857502, 64.868203997612, 67.37872168421745, 66.15017160773277, 69.01015654206276, 69.61644440889359, 68.75946119427681, 68.63809570670128, 68.07933568954468, 68.13055694103241, 66.36384934186935, 67.23733887076378, 63.39665316045284, 71.91729694604874, 73.8092914223671, 73.88467937707901, 72.91896119713783, 40.44271565973759, 0.041533493204042315, 27.119832560420036, 75.55367901921272, 55.09905360639095, 35.24728484451771, 37.52336271107197, 21.81780606508255, 13.167935963720083, 2.489061187952757, 5.675765415653586, 4.286903841421008, 1.3789475499652326, 1.2506534904241562, 11.501077506691217, 16.245570369064808, 3.219657721929252, 0.13609325978904963, 0.1100337014941033, 0.007710832260272582, 0.07413190687657334, 0.1220735335664358, 0.08634459256427363, 0.16569230589084327, 0.5659954820293933, 14.913610741496086, 59.80475530028343, 49.021253138780594, 24.704562462866306, 65.27435660362244, 27.72644530981779, 50.324435010552406, 53.30993480980396, 68.93054321408272, 76.91855818033218, 78.56310993432999, 52.06335090100765, 0.22102892951807007, 0.8061867684591562, 1.2650564988143742, 39.78741802275181, 82.99934148788452, 80.00022321939468, 87.25515112280846, 76.228097230196, 74.27447766065598, 69.60838884115219, 69.71254885196686, 67.26751685142517, 67.06083834171295, 63.502154499292374, 62.10182324051857, 60.80748729407787, 58.721600621938705, 55.77391259372234, 53.536372259259224, 56.853366270661354, 55.21793782711029, 54.89231050014496, 56.42079368233681, 56.68925687670708, 57.927735820412636, 56.63754925131798, 55.03880403935909, 55.44051468372345, 52.52926290035248, 51.70255646109581, 48.745897114276886, 47.930403873324394, 49.86834928393364, 51.104536950588226, 54.044693782925606, 58.78658093512058, 61.34925462305546, 59.54991057515144, 62.04046033322811, 66.09468698501587, 61.24259814620018, 60.078409016132355, 62.890505120158195, 60.09869612753391, 56.99391312897205, 57.202514335513115, 58.29253524541855, 54.02380630373955, 53.91716502606869, 53.08296158909798, 54.33343268930912, 56.57052844762802, 58.065220043063164, 54.0956262499094, 45.14583729207516, 55.34363508224487, 59.62710343301296, 46.60080961883068, 47.006137669086456, 53.16651150584221, 52.03455984592438, 50.71567341685295, 47.45545595884323, 48.40589515864849, 47.177375480532646, 47.912731021642685, 45.615514889359474, 44.49777066707611, 45.25051027536392, 45.55776558816433, 47.06986404955387, 46.871009320020676, 45.210251435637474, 45.417644307017326, 43.25065478682518, 45.08281767368317, 47.47657522559166, 44.50643800199032, 47.91715398430824, 46.356224343180656, 45.38633018732071, 49.1959373652935, 47.652843967080116, 41.73010937869549, 39.783831015229225, 37.77920298278332, 45.36836855113506, 47.57772579789162, 53.75386878848076, 58.92425514757633, 55.391649305820465, 57.08215579390526, 56.543853878974915, 57.44443215429783, 57.89068780839443, 56.90997563302517, 54.0414297580719, 55.334811955690384, 57.43734933435917, 57.30460345745087, 56.87552288174629, 60.04742927849293, 57.65760451555252, 58.44742253422737, 54.97656337916851, 53.96680176258087, 48.48947927355766, 47.66538329422474, 53.839052617549896, 60.92968113720417, 61.421610340476036, 63.88735502958298, 65.04287302494049, 62.85612836480141, 59.48068968951702, 63.33886206150055, 63.61582539975643, 63.64192619919777, 58.76051053404808, 51.54689401388168, 52.595307156443596, 56.08552247285843, 64.88135889172554, 67.06384018063545, 72.08609908819199, 70.82550913095474, 72.56051123142242, 71.29686623811722, 73.8867312669754, 74.21123385429382, 73.13225135207176, 73.34318563342094, 73.21346819400787, 72.40199893712997, 69.8937763273716, 76.61012873053551, 79.13526803255081, 80.95467880368233, 79.26844328641891, 42.890646904706955, 0.09058379946509376, 32.65049658715725, 84.37856867909431, 64.590362906456, 44.02036428451538, 45.94545118510723, 35.620945394039154, 19.461607597768307, 10.041521675884724, 5.151304733008146, 9.452418386936188, 2.0796436071395874, 3.439509649761021, 19.74551886320114, 22.93055545538664, 12.214037049561739, 0.726961613399908, 0.0982391566503793, 0.15659143798984587, 0.16594427987001836, 0.17929594701854512, 0.19924760767025873, 0.3371410060208291, 0.7188007794320583, 16.992690078914165, 73.47447618842125, 60.60278467833996, 44.7020211070776, 74.51874375343323, 37.78991460800171, 61.431273221969604, 63.43926027417183, 74.2533127963543, 84.34659719467163, 82.96655684709549, 58.92004877328873, 0.646339023951441, 7.570645837113261, 1.5187083254568279, 37.00420416891575, 79.85235795378685, 77.24299997091293, 81.14465340971947, 75.63241079449654, 72.13874906301498, 69.5081502199173, 70.96994698047638, 68.71715426445007, 71.11629232764244, 67.34372556209564, 64.49842303991318, 62.8102458268404, 62.81921334564686, 59.39377695322037, 57.65605039894581, 59.7711993008852, 56.20506025850773, 56.71874329447746, 59.35308873653412, 59.43250447511673, 59.73011590540409, 61.01016081869602, 58.87643851339817, 57.36537739634514, 56.285080164670944, 54.76503632962704, 51.36624790728092, 49.77567605674267, 54.443387389183044, 54.30796265602112, 59.25466261804104, 62.049416452646255, 64.39573734998703, 60.88982507586479, 65.61558589339256, 67.56993502378464, 63.801069259643555, 62.21543334424496, 65.16322776675224, 62.25278154015541, 59.28997412323952, 58.59273053705692, 61.550237238407135, 58.32757696509361, 57.17319130897522, 55.97961075603962, 58.11544954776764, 59.55448932945728, 61.96483299136162, 57.026629373431206, 50.78218124806881, 57.48051881790161, 63.036291897296906, 47.45151937007904, 47.439398020505905, 56.63533017039299, 56.325445398688316, 54.27032567560673, 49.84102874994278, 54.24584358930588, 51.209650710225105, 52.116646841168404, 49.70286436378956, 48.19594882428646, 49.749278873205185, 49.70871604979038, 50.01192457973957, 50.61146020889282, 48.80513973534107, 49.949045553803444, 45.97472481429577, 46.36761613190174, 49.41913738846779, 46.46968625485897, 51.883685141801834, 47.90103904902935, 47.25178688764572, 51.48181490600109, 49.113823771476746, 42.66963176429272, 36.71931065618992, 39.06929835677147, 50.633594021201134, 53.17151963710785, 56.53189592063427, 61.26927271485329, 58.28770950436592, 60.16923554241657, 60.79638808965683, 59.56388242542744, 62.660020887851715, 57.788028717041016, 53.815212696790695, 58.452502861618996, 59.58243303000927, 59.727786630392075, 59.79894541203976, 63.327899649739265, 61.30771905183792, 60.80568619072437, 57.1630534529686, 58.17837797105312, 50.3151673078537, 51.175083965063095, 55.67103311419487, 62.70482428371906, 63.69032800197601, 65.48248663544655, 64.2526750266552, 64.53841969370842, 60.36427527666092, 64.64650109410286, 65.37144139409065, 66.92095264792442, 61.32179729640484, 54.296958446502686, 53.59920188784599, 56.47322706878185, 66.91937193274498, 66.8379195034504, 70.83899080753326, 69.34966072440147, 72.08037659525871, 73.64830926060677, 72.92148426175117, 75.03298535943031, 72.42950946092606, 74.9390771985054, 71.73682183027267, 72.58362159132957, 68.71725305914879, 79.67390432953835, 81.06419652700424, 81.05658933520317, 79.02760460972786, 46.393800526857376, 0.26230402174405754, 37.13530473411083, 94.62072148919106, 70.78536048531532, 54.36096601188183, 59.90082174539566, 52.298828065395355, 36.62271983921528, 26.81659173220396, 33.0540007352829, 7.078485796228051, 2.090205140411854, 10.179154090583324, 25.53393255919218, 21.87587644904852, 5.958310654386878, 0.27795956761110574, 0.18808494962286204], [0.033364525297656655, 0.07771227959892713, 0.053017311947769485, 0.17377911804942414, 0.21897217113291845, 0.8397096977569163, 6.54135849326849, 31.096571870148182, 37.253208607435226, 22.760617174208164, 18.009409122169018, 35.80328240990639, 45.210388228297234, 40.19274987280369, 56.478915363550186, 67.03829035162926, 70.23964136838913, 42.61390395462513, 0.45003354200161994, 0.5557713587768376, 1.75494046183303, 46.53332144021988, 76.69983431696892, 72.87698864936829, 74.62551042437553, 68.09314414858818, 68.22517186403275, 63.23363050818443, 63.36104527115822, 59.755870923399925, 61.13313741981983, 58.64554390311241, 58.84226314723492, 56.873159408569336, 55.9137336909771, 54.22823153436184, 50.10631911456585, 50.316801220178604, 51.10900551080704, 50.871351063251495, 49.976366087794304, 49.95104804635048, 50.74794888496399, 52.84885995090008, 51.41524247825146, 52.8618248552084, 50.030699372291565, 48.712265118956566, 45.75513079762459, 45.57105727493763, 48.9386797696352, 47.42211274802685, 50.721490904688835, 58.068761453032494, 58.112531304359436, 58.61678704619408, 60.032917857170105, 59.80295039713383, 61.67924031615257, 59.130413085222244, 58.20467635989189, 59.47903297841549, 55.73775373399258, 55.37619173526764, 53.81269343197346, 51.55158296227455, 47.82777898013592, 47.111654207110405, 51.824199333786964, 53.5430409014225, 53.80554981529713, 54.47326898574829, 40.23285672068596, 53.84475231170654, 51.81438826024532, 43.358208015561104, 49.96543787419796, 49.476734697818756, 46.83215260505676, 45.099050402641296, 43.94667483866215, 44.55002546310425, 44.76660244166851, 42.552054673433304, 43.1359351426363, 41.00556045770645, 41.66704796254635, 41.851307675242424, 40.877830311656, 43.276482000947, 41.0638303309679, 40.871268063783646, 42.122328132390976, 41.24250054359436, 42.556549832224846, 42.83887468278408, 43.178017884492874, 43.85285787284374, 43.028689697384834, 43.57651390135288, 47.41568349301815, 39.63555157184601, 42.24733002483845, 35.810809805989265, 38.42397138476372, 51.84311471879482, 57.39995934069157, 56.21256485581398, 52.61316999793053, 52.77417875826359, 51.259488835930824, 55.41544362902641, 53.901582062244415, 57.37279459834099, 55.508477836847305, 51.801510751247406, 52.36878991127014, 54.99438062310219, 55.21855339407921, 58.35275061428547, 58.58152873814106, 55.51531746983528, 54.40362632274628, 54.76051077246666, 45.533074513077736, 45.492040514945984, 50.418263375759125, 59.74657282233238, 59.869655817747116, 55.93585230410099, 54.891596138477325, 55.670934319496155, 60.1485950499773, 62.48063251376152, 60.51902957260609, 53.751619309186935, 51.8092243373394, 48.92414554953575, 49.53220412135124, 55.98437190055847, 60.39645954966545, 64.22641843557358, 66.37219369411469, 70.00349164009094, 66.23906403779984, 68.78938838839531, 71.16765037178993, 70.18148928880692, 71.53273478150368, 67.19392240047455, 66.63197055459023, 65.20592987537384, 67.16445878148079, 69.98448505997658, 76.2825559079647, 75.04835933446884, 72.14434996247292, 27.68253106623888, 0.04729521977424156, 37.94236242771149, 71.31342574954033, 54.45927053689957, 33.02445352077484, 31.10607896000147, 27.623957209289074, 15.699722059071064, 7.32430980540812, 4.59734195843339, 11.522877886891365, 1.4942324138246477, 0.9731009462848306, 2.254352057352662, 1.0728374007157981, 0.16053770435974002, 0.021241554131847806, 0.07862202648539096, 0.09309556116932072, 0.12792111549060792, 0.05778054561233148, 0.038441579818027094, 0.0781098184233997, 0.9071672998834401, 7.315837210044265, 49.81081277132034, 52.83634342253208, 20.94055663794279, 32.31444261968136, 33.28155152499676, 52.239889428019524, 46.7166768014431, 62.773847579956055, 74.5259253680706, 80.23834124207497, 49.88314189016819, 0.5012157268356532, 2.5153712136670947, 1.441993173211813, 52.317675054073334, 84.22158390283585, 79.33501571416855, 80.1696865260601, 74.82640564441681, 74.62701514363289, 68.61048638820648, 65.79444229602814, 64.43254977464676, 66.54326811432838, 63.09084936976433, 63.02336499094963, 62.430866584181786, 59.13953639566898, 59.134820848703384, 54.927029237151146, 55.50999395549297, 55.1906780898571, 54.78107146918774, 54.53787311911583, 55.20249545574188, 54.5489115267992, 57.151175290346146, 55.253218933939934, 54.3624859303236, 52.50657431781292, 51.877392679452896, 49.14086312055588, 49.01632480323315, 49.559175074100494, 48.5548547655344, 52.42139428853989, 59.849494099617004, 59.70539063215256, 61.66779913008213, 60.93324914574623, 61.64764501154423, 63.65024775266647, 61.30737707018852, 60.056757777929306, 62.027503028512, 58.052562922239304, 57.8202585875988, 54.33198496699333, 54.28998962044716, 50.25726981461048, 49.379380121827126, 52.998347729444504, 56.65638484060764, 54.4160820543766, 56.09967291355133, 45.86240664124489, 57.293831035494804, 50.21977722644806, 45.06239756941795, 52.670964896678925, 52.8378139436245, 48.58119875192642, 47.99367807805538, 46.51890121400356, 49.10715512931347, 46.59732140600681, 46.45407669246197, 46.4764004945755, 45.24478778243065, 44.07842896878719, 43.84013615548611, 44.91281099617481, 45.82381971180439, 41.30846880376339, 41.876021549105644, 43.2779411226511, 45.086469277739525, 43.70386406779289, 45.308909341692924, 45.901814326643944, 45.25425307452679, 46.06775522232056, 47.408380284905434, 50.602063313126564, 41.700797751545906, 42.789845913648605, 37.98578269779682, 39.70352232456207, 56.133840680122375, 59.71480272710323, 58.222584798932076, 55.033712312579155, 54.78254958987236, 52.721920162439346, 58.46962094306946, 56.107926070690155, 58.41975621879101, 59.21879634261131, 57.53437712788582, 56.29693552851677, 59.00017507374287, 57.26030543446541, 57.93481484055519, 60.04795745015144, 57.25623585283756, 55.612409859895706, 55.92390954494476, 49.12497617304325, 48.33561412990093, 52.51827009022236, 59.23546984791756, 62.593725845217705, 58.30386623740196, 55.833459198474884, 55.26080712676048, 63.519888147711754, 66.4131098985672, 63.769675344228745, 55.44927321374416, 56.09672047197819, 52.90129713714123, 52.191312834620476, 59.240724965929985, 62.79066927731037, 67.34361156821251, 71.3266034424305, 71.74137398600578, 70.6504525244236, 72.17129051685333, 75.75991675257683, 74.88000556826591, 75.15811264514923, 73.54047864675522, 71.47776693105698, 68.70187148451805, 72.13981300592422, 75.60841128230095, 81.93922117352486, 81.79397016763687, 79.27184790372849, 27.654106691479683, 0.062046087623457424, 42.65518493950367, 79.77735757827759, 61.66253641247749, 43.236888125538826, 41.77971191704273, 44.94918644428253, 22.559949941933155, 14.464800674468279, 4.8118513729423285, 18.126279450953007, 2.4398994259536266, 1.27909520175308, 7.210021913051605, 5.368878683075309, 0.5970326915849, 0.027486231447255705, 0.09565196305629797, 0.11104162709671073, 0.23930027877213433, 0.1510842124116607, 0.3630071086809039, 0.2795428060926497, 1.0678949346765876, 7.4041064735502005, 63.181744292378426, 67.89892137050629, 42.123612463474274, 42.380630671978, 50.478410348296165, 66.3116629421711, 54.370431303977966, 72.03975677490234, 80.39672434329987, 84.62892204523087, 55.95259800553322, 0.6114673451520503, 3.3756365021690726, 3.16363756544888, 51.13757997751236, 77.3216101527214, 76.8979024887085, 76.80926084518433, 73.76044124364853, 70.79422920942307, 70.19037321209908, 66.84780657291412, 66.08920767903328, 67.83921137452126, 64.98444736003876, 65.0690384209156, 65.39175510406494, 63.41132417321205, 63.25222671031952, 57.16251768171787, 59.272495061159134, 58.67734059691429, 57.92692266404629, 58.90807181596756, 58.762376233935356, 56.924908831715584, 61.343497931957245, 57.84988559782505, 57.31970764696598, 55.862751826643944, 54.63454373180866, 51.887348145246506, 51.06879606842995, 55.44964179396629, 50.293151289224625, 56.24962046742439, 62.98583060503006, 62.28777766227722, 64.07905474305153, 64.22336339950562, 64.84012350440025, 65.30989989638329, 63.65038834512234, 63.59945587813854, 66.77428811788559, 61.07024319469929, 59.82405446469784, 59.34137776494026, 56.72142595052719, 53.97010378539562, 52.23113849759102, 57.941764667630196, 61.955474093556404, 57.51574672758579, 60.024539306759834, 50.61299532651901, 61.74783043563366, 53.258846551179886, 46.42243579030037, 54.66319799423218, 57.24506825208664, 55.09739689528942, 51.39438159763813, 51.73314481973648, 51.581187173724174, 49.70579780638218, 50.08576221764088, 49.91021163761616, 46.74650140106678, 48.45509871840477, 46.45834766328335, 47.55570597946644, 50.627970322966576, 47.26756364107132, 46.82169556617737, 47.4018370360136, 47.000407576560974, 46.38351067900658, 48.079363480210304, 45.8928582072258, 48.94908741116524, 47.93989576399326, 49.77024994790554, 52.725393176078796, 42.78673008084297, 42.01673939824104, 40.77937379479408, 47.29469798505306, 57.56569504737854, 62.06269674003124, 59.01929184794426, 57.03973487019539, 58.58091317117214, 57.38889813423157, 62.30741120874882, 59.42922905087471, 59.68296803534031, 59.51341733336449, 57.656605169177055, 60.748096480965614, 61.47142566740513, 60.653606951236725, 61.71675190329552, 63.42300854623318, 59.50332507491112, 61.09635919332504, 59.684506952762604, 50.94438314437866, 51.697973906993866, 57.20360487699509, 61.90824642777443, 66.54426366090775, 58.63604061305523, 56.71846590936184, 58.02463062107563, 63.527229353785515, 69.32459726929665, 64.75005313754082, 58.19998741149902, 58.793169781565666, 55.277051255106926, 52.89324536919594, 60.1231250166893, 64.15308997035027, 68.68576794862747, 72.21613571047783, 74.37393352389336, 70.15851572155952, 76.97178572416306, 76.62463635206223, 75.15492081642151, 75.92133209109306, 75.23619085550308, 69.47022065520287, 70.07718488574028, 73.5263966023922, 77.5920644402504, 83.94398599863052, 80.75540989637375, 79.7676756978035, 30.91785416007042, 0.17875061690574512, 46.15437537431717, 86.05026617646217, 69.40066918730736, 53.694534972310066, 55.40690928697586, 62.69274853169918, 43.65759775042534, 33.768062219023705, 36.50421939790249, 28.121227025985718, 2.3587602423503995, 2.5008355686441064, 4.284315705299377, 1.6659473371692002, 0.2843877242412418, 0.11510032141814008, 0.2057093835901469], [0.04962489183526486, 0.01966524916497292, 0.07311618130188435, 0.045690180704696104, 0.08833041647449136, 0.5169104877859354, 2.407302400097251, 24.161290414631367, 28.852524384856224, 29.87657893449068, 31.31884664297104, 28.218923583626747, 50.81644020974636, 47.4168386310339, 46.883639842271805, 65.8334282040596, 68.94250497221947, 52.26590283215046, 1.1478306516073644, 1.0239525488577783, 2.598764388822019, 49.68693181872368, 64.18461307883263, 75.67606285214424, 70.96398130059242, 69.5085833966732, 65.37359207868576, 63.931599855422974, 63.32388326525688, 60.69104254245758, 60.20941458642483, 57.12834611535072, 58.32797594368458, 58.07615965604782, 55.20957827568054, 53.27339597046375, 49.454566687345505, 52.12012745440006, 50.25779418647289, 51.4998297393322, 51.0889083892107, 49.47967194020748, 49.13628816604614, 48.91778849065304, 51.35120831429958, 52.504564225673676, 46.46719738841057, 48.39507333934307, 46.85968592762947, 47.864032834768295, 47.925893515348434, 46.82831101119518, 51.25555984675884, 56.529893428087234, 59.860840290784836, 59.574119076132774, 61.61706045269966, 60.50354540348053, 57.92447939515114, 55.878213196992874, 56.517604887485504, 56.513523906469345, 56.09884075820446, 51.408543437719345, 49.01528745889664, 47.50651761889458, 46.187308207154274, 46.24357558786869, 47.06290282309055, 49.956918731331825, 53.18631984293461, 51.40783667564392, 45.47040067613125, 42.40184873342514, 40.496900752186775, 47.4162420630455, 48.6919742077589, 41.82694338262081, 43.93605060875416, 45.52811577916145, 46.44562214612961, 44.11060184240341, 41.903573870658875, 42.35574960708618, 42.16825246810913, 42.355468422174454, 41.55935414135456, 42.3152893781662, 42.965293899178505, 42.58991204202175, 42.493401020765305, 40.48238933086395, 42.00927659869194, 42.24631927907467, 44.66105170547962, 42.938402742147446, 44.292235895991325, 43.37746158242226, 46.276987195014954, 44.27175119519234, 44.50166165828705, 43.108249828219414, 48.988255709409714, 46.53850816190243, 34.82437513768673, 51.98298141360283, 54.73243407905102, 54.4039911031723, 51.657342687249184, 48.13609443604946, 49.425984621047974, 49.549561589956284, 49.593209847807884, 54.649157747626305, 55.80674283206463, 57.11196519434452, 57.16491535305977, 58.78907360136509, 58.648633137345314, 51.953719183802605, 55.104141533374786, 56.37760519981384, 54.63430054485798, 57.676808685064316, 50.12266963720322, 43.863029927015305, 46.12376421689987, 54.82922248542309, 59.97354984283447, 58.916754350066185, 54.810337498784065, 61.56968079507351, 59.799218997359276, 59.01697017252445, 55.19991919398308, 52.60822646319866, 50.26368387043476, 45.905887708067894, 49.36782494187355, 53.20884883403778, 58.12868423759937, 65.31483203172684, 65.54159626364708, 67.05950081348419, 70.35771623253822, 66.74027234315872, 71.07678964734077, 70.72499692440033, 69.38762068748474, 70.44285446405411, 69.56235811114311, 68.9487898349762, 66.00954115390778, 70.40197625756264, 72.31048464775085, 76.18003740906715, 70.54974272847176, 16.871231496334076, 0.5737192207016051, 40.52947640419006, 67.35009402036667, 58.67762938141823, 35.03001630306244, 27.045525647699833, 34.2968874424696, 18.12199518084526, 7.190707074478269, 0.6166274088900536, 19.179879315197468, 2.9693509032949805, 0.24536809301935136, 0.07022570905974135, 0.043158529442735016, 0.07501371190301143, 0.038248398777795956, 0.06375288998242468, 0.09169523982563987, 0.03548256652720738, 0.034011848765658215, 0.04646697925636545, 0.06016257619194221, 0.4515827604336664, 2.8732300736010075, 41.11008904874325, 45.10631941258907, 27.79292844235897, 27.3911627009511, 34.343260154128075, 58.902702704072, 57.140216678380966, 55.93245528638363, 73.95127460360527, 77.76354923844337, 59.20517787337303, 2.061891909688711, 0.896285871276632, 3.917106972075999, 55.44869564473629, 71.95937588810921, 82.33550950884819, 77.83493980765343, 72.72868260741234, 68.86627346277237, 68.23135033249855, 67.03274264931679, 63.701674193143845, 65.83443135023117, 62.68008001148701, 62.897614538669586, 61.342452988028526, 57.826247066259384, 56.859103962779045, 53.802057802677155, 54.68959517776966, 53.60266350209713, 54.91224803030491, 54.484231397509575, 52.4004840105772, 52.013805359601974, 51.84745788574219, 55.21080940961838, 54.716129153966904, 51.00689738988876, 52.59020783007145, 50.74130304157734, 49.12718765437603, 49.248496145009995, 48.39523293077946, 54.069707840681076, 58.18760387599468, 63.02192486822605, 62.26363755762577, 62.87136174738407, 64.01157796382904, 60.77129423618317, 58.07986065745354, 57.959369122982025, 57.36317731440067, 57.35896714031696, 53.103685677051544, 50.35922214388847, 50.28778217732906, 49.53252710402012, 48.988438099622726, 47.61033944785595, 52.22782887518406, 53.323211297392845, 56.583101972937584, 51.115693151950836, 45.61431035399437, 41.21813625097275, 50.906320586800575, 51.56606398522854, 45.86728557944298, 45.191495642066, 48.32637682557106, 48.186434134840965, 44.99347306787968, 46.460711136460304, 46.228418201208115, 45.56857980787754, 45.81289529800415, 44.02711272239685, 46.22686788439751, 45.31061924993992, 44.88884948194027, 45.76805770397186, 43.30378733575344, 44.030650332570076, 45.791426450014114, 45.92928305268288, 44.88939665257931, 47.10040681064129, 45.70620462298393, 48.742690086364746, 46.570798829197884, 45.58654144406319, 45.375394374132156, 48.73110070824623, 47.511943727731705, 38.57191264629364, 54.705394729971886, 57.298744171857834, 57.900723069906235, 54.067245572805405, 50.42193777859211, 50.271104872226715, 51.78742490708828, 53.433933556079865, 56.16239234805107, 56.16008587181568, 58.695290833711624, 58.439708948135376, 60.90120166540146, 61.95865072309971, 56.68000057339668, 56.116012036800385, 58.11143696308136, 58.23803476989269, 58.448155894875526, 52.51276418566704, 47.661393508315086, 48.37315231561661, 57.70967312157154, 62.242092713713646, 61.51664324104786, 59.78333204984665, 63.44742603600025, 62.41762049496174, 62.720304653048515, 56.16706229746342, 55.96432417631149, 54.10393640398979, 50.256844237446785, 51.65691711008549, 58.21313090622425, 63.266285955905914, 68.38422372937202, 70.08684396743774, 70.83373188972473, 73.14854487776756, 70.0645163655281, 76.21058017015457, 73.89193698763847, 73.61090406775475, 74.78125646710396, 77.18695297837257, 74.40567702054977, 69.93830993771553, 76.24325081706047, 77.54237830638885, 79.92274537682533, 76.59481555223465, 18.313284516334534, 0.4683436016784981, 46.523320376873016, 79.07132506370544, 66.53623849153519, 43.71429830789566, 37.5665207952261, 50.566930398344994, 23.90180803835392, 12.463376820087433, 15.441203881055117, 29.902983717620373, 4.062712071463466, 0.3196452307747677, 0.13899766956456006, 0.36097463336773217, 0.13344541046535596, 0.017305692672380246, 0.10357084203860722, 0.13711681502172723, 0.12817341601476073, 0.15402881690533832, 0.13224929105490446, 0.17532480385852978, 0.4700589127605781, 2.3437614971771836, 52.206284031271935, 58.13326299190521, 50.18411234021187, 66.91198512911797, 44.106847643852234, 71.90497040748596, 66.40008419752121, 63.98337587714195, 80.49910604953766, 83.25247630476952, 66.13794386386871, 2.3783709900453687, 2.031404720619321, 5.186366876587272, 57.9458874464035, 72.2201406955719, 80.87710976600647, 77.0224142074585, 72.64239683747292, 67.82705962657928, 70.40143668651581, 69.17213425040245, 67.32519015669823, 67.67060682177544, 64.1956552863121, 65.23800015449524, 64.7465269267559, 59.94658648967743, 60.678981989622116, 55.7956550270319, 56.50839418172836, 55.55304944515228, 58.84277231991291, 59.720445424318314, 55.886223167181015, 57.31420934200287, 54.26288187503815, 58.5576394200325, 57.929612919688225, 53.17385271191597, 53.647713884711266, 53.71597722172737, 51.60271681845188, 53.35003785789013, 52.77595706284046, 56.075323820114136, 58.170360401272774, 66.16277173161507, 64.51676085591316, 65.09478583931923, 67.08148643374443, 62.047322764992714, 60.123455598950386, 62.539384961128235, 60.8901746571064, 63.014082089066505, 54.93926838040352, 54.75362554192543, 53.94361540675163, 51.54231145977974, 53.923123106360435, 51.34308435022831, 55.01194708049297, 56.32529720664024, 59.963442385196686, 54.21068787574768, 46.38468101620674, 44.89851236343384, 51.63921386003494, 54.55024525523186, 47.95755721628666, 48.729842975735664, 52.314392030239105, 50.76000563800335, 48.165322467684746, 48.68690527975559, 48.74976150691509, 48.13260242342949, 49.81345362961292, 46.84059575200081, 49.719093292951584, 48.256468176841736, 47.3672740906477, 48.514690920710564, 44.97244879603386, 44.46946978569031, 49.67815048992634, 50.45443743467331, 46.84301242232323, 50.257288813591, 49.32709492743015, 52.47996434569359, 49.855927750468254, 48.766579404473305, 48.73436853289604, 52.34275370836258, 48.5424180328846, 42.11065895855427, 58.17875415086746, 62.298078909516335, 59.77761335670948, 57.331297025084496, 54.300165474414825, 55.358986258506775, 54.46785807609558, 54.660150557756424, 58.59481282532215, 59.497002214193344, 59.212142899632454, 59.39793772995472, 62.034418657422066, 64.37370613217354, 59.31268930435181, 61.21186539530754, 60.697760581970215, 60.340047776699066, 62.39425554871559, 55.65307527780533, 48.21668051183224, 51.182406172156334, 60.38946412503719, 63.64639475941658, 62.31793664395809, 59.29895304143429, 64.42501097917557, 62.568301409482956, 65.0921867787838, 59.53408442437649, 57.50701479613781, 55.22383511066437, 50.28321862220764, 52.78830640017986, 57.94201925396919, 62.86886528134346, 69.43583250045776, 69.68041777610779, 70.95498338341713, 73.42682674527168, 69.0152558684349, 75.66638857126236, 74.89206612110138, 73.52886646986008, 75.96624568104744, 76.68743938207626, 74.37540784478188, 72.90532752871513, 76.54791846871376, 79.36316460371017, 81.02040007710457, 81.17317467927933, 22.527038007974625, 0.3827526600798592, 51.433823481202126, 85.46660229563713, 77.59268760681152, 55.24130277335644, 49.98501442372799, 69.44673791527748, 44.841348230838776, 34.01754543185234, 45.0411719083786, 58.723333328962326, 4.664903758093715, 0.3181506640976295, 0.1603825212805532, 0.30567275709472597, 0.13502563582733274, 0.06450343877077103, 0.11034991577616893], [0.022689207798975985, 0.04933027405058965, 0.07404022937407717, 0.05312809604220092, 0.1089314637647476, 0.17614070617128164, 0.3257825248874724, 19.00339398533106, 21.44491497427225, 21.83403879404068, 30.554587952792645, 33.64981256425381, 50.26430703699589, 54.50122028589249, 35.97761705517769, 65.078294724226, 64.37308296561241, 59.44361127912998, 3.0716988863423467, 1.4136170083656907, 3.4912462485954165, 54.02267396450043, 74.04018223285675, 73.94333302974701, 72.95979380607605, 66.06957793235779, 66.59714922308922, 61.920189186930656, 62.42730997502804, 60.683997720479965, 60.37638522684574, 60.37184067070484, 58.67184229195118, 55.32073751091957, 55.741576328873634, 54.72088269889355, 53.66954371333122, 49.39578004181385, 49.132799953222275, 50.069312900304794, 48.3391897380352, 47.012996301054955, 47.256635427474976, 49.296559765934944, 49.43267606198788, 48.94831985235214, 48.57650600373745, 46.417929232120514, 44.642402306199074, 44.509557634592056, 46.62256345152855, 47.12311439216137, 53.60405422747135, 60.17682373523712, 60.205098018050194, 58.846325129270554, 59.57550220191479, 57.80401825904846, 56.078333258628845, 55.74270486831665, 52.084884345531464, 54.18936342000961, 50.61650633811951, 49.625291526317596, 47.404933869838715, 48.6090512573719, 45.34077063202858, 46.54685251414776, 44.22638922929764, 48.051613569259644, 51.42937012016773, 53.58909823000431, 45.47733910381794, 42.284279242157936, 46.34533032774925, 49.4316653162241, 47.10090458393097, 44.12024952471256, 43.06377321481705, 44.06244322657585, 45.71647547185421, 46.13811984658241, 40.6866055727005, 44.569248631596565, 45.18130838871002, 45.08544333279133, 41.784267872571945, 43.27221482992172, 45.54781012237072, 43.77325974404812, 43.495798632502556, 41.93320848047733, 43.59825253486633, 42.428675293922424, 43.718478083610535, 42.08671644330025, 44.255457669496536, 44.95040237903595, 42.47298091650009, 44.24440786242485, 43.58196660876274, 41.82844050228596, 41.36469058692455, 47.064061760902405, 40.19187971949577, 56.08587205410004, 53.37411716580391, 52.10968181490898, 50.28657004237175, 45.43183654546738, 46.481857001781464, 47.53780134022236, 46.885577738285065, 50.956664085388184, 50.582745149731636, 53.77703234553337, 55.12784466147423, 54.555800557136536, 57.493495121598244, 59.60509121417999, 54.13202829658985, 54.17994372546673, 55.10020114481449, 59.625347927212715, 52.97748304903507, 45.29809892177582, 44.31240901350975, 47.10446119308472, 57.59795531630516, 60.54952673614025, 60.64264073967934, 59.83150966465473, 59.170417338609695, 55.373976454138756, 50.97167328000069, 50.18412373960018, 48.31056207418442, 48.38761433959007, 52.009500190615654, 56.44113779067993, 60.29364846646786, 63.43127690255642, 68.14456298947334, 66.59145712852478, 64.62454587221146, 65.5706875026226, 63.89808565378189, 68.55377823114395, 70.1870445907116, 68.89480233192444, 70.76024383306503, 69.94816660881042, 66.53632208704948, 67.99825564026833, 76.89716532826424, 69.76382330060005, 57.00888812541962, 11.89778856933117, 0.34559133695438504, 43.239202201366425, 69.2349524796009, 55.75904779136181, 34.071323946118355, 33.06512653827667, 32.43451617658138, 16.984628811478615, 9.428290631622076, 11.574151385575533, 9.410908464342356, 2.602592445909977, 0.08923381799831986, 0.08815641253022477, 0.09438841210794635, 0.06391598435584456, 0.10505590180400759, 0.036295077225076966, 0.0970282759226393, 0.04272140075045172, 0.04982671518519055, 0.06312465455266647, 0.17684323800494894, 0.29697232239414006, 0.3676862607244402, 32.96368718147278, 34.3151530623436, 25.2741651982069, 42.27210469543934, 47.59852208197117, 61.95671662688255, 64.85629543662071, 44.66259062290192, 72.30334863066673, 70.21704018115997, 66.71112790703773, 3.391543161123991, 0.9547705517616123, 4.294568980112672, 60.84053032100201, 81.57826334238052, 78.4338028728962, 76.01240560412407, 69.97496277093887, 69.05706882476807, 65.4307334125042, 67.34490349888802, 63.54345828294754, 64.17066022753716, 63.08720536530018, 61.92172430455685, 58.811777383089066, 58.90530176460743, 56.670542880892754, 55.89364796876907, 54.197263196110725, 53.663456439971924, 54.26932632923126, 52.47032046318054, 49.1561459004879, 51.5996427834034, 52.40806460380554, 53.17059248685837, 51.83673106133938, 53.32805223762989, 49.75431740283966, 48.17747041583061, 47.32853516936302, 48.73089551925659, 51.30334608256817, 54.74644012749195, 62.447160109877586, 62.84961171448231, 59.257181882858276, 61.65647193789482, 62.01122850179672, 57.93814726173878, 56.64445348083973, 53.63868556916714, 55.95744654536247, 52.713986188173294, 53.004643991589546, 51.15391530096531, 52.815345749258995, 49.67227980494499, 48.321167305111885, 47.2618867456913, 50.78610643744469, 52.6676020771265, 58.68775203824043, 50.75357258319855, 43.42462845146656, 49.13516342639923, 52.7564413100481, 48.63609440624714, 48.82324196398258, 46.233118548989296, 48.19539785385132, 48.62718008458614, 48.30792501568794, 43.07606175541878, 47.524825036525726, 45.94873420894146, 48.739361464977264, 46.14323817193508, 46.87638223171234, 48.256004601716995, 45.982556194067, 44.22822833061218, 44.1850246489048, 45.65883256494999, 44.276911318302155, 45.578941851854324, 44.620887860655785, 46.088198125362396, 48.10228005051613, 46.744396314024925, 45.88148161768913, 46.71512648463249, 44.63356778025627, 41.77550554275513, 46.14654399454594, 39.97452758252621, 59.70814548432827, 56.80364213883877, 54.28869768977165, 53.059722036123276, 47.46403969824314, 47.111821398139, 49.35348071157932, 50.34126430749893, 52.583216205239296, 53.69774580001831, 54.43342052400112, 56.34007081389427, 55.209160298109055, 57.52927780151367, 62.07740195095539, 59.97100777924061, 56.32976196706295, 58.94244857132435, 61.568905636668205, 55.375853553414345, 47.71681733429432, 48.30869257450104, 50.24721175432205, 58.35084691643715, 62.25236356258392, 61.17179274559021, 61.33818581700325, 60.18236383795738, 56.82626612484455, 54.37026031315327, 54.97722454369068, 52.29191243648529, 52.253732085227966, 55.63391670584679, 58.46842020750046, 63.71754594147205, 67.45920896530151, 72.40199133753777, 70.04756927490234, 69.17493090033531, 68.1531049311161, 65.64085453748703, 70.98225831985474, 75.17499893903732, 74.21596840023994, 76.11795634031296, 74.46859404444695, 72.83486410975456, 72.9598394036293, 81.17053762078285, 75.29911547899246, 60.56888669729233, 13.738766983151436, 0.18551018700236455, 48.697970286011696, 79.36477571725845, 68.33613350987434, 40.89578814804554, 38.581932708621025, 50.6552604585886, 23.12814485281706, 14.176080767065287, 31.884138509631157, 21.215152703225613, 3.2701684115454555, 0.2217453098273836, 0.08925165922846645, 0.10758800577605143, 0.008245833996625151, 0.02072594146738993, 0.00926422573684249, 0.17232395941391587, 0.1063481367600616, 0.19075810618232936, 0.21928942442173138, 0.2533875626977533, 0.2753155922982842, 0.21001248940592632, 42.354157492518425, 51.29915110766888, 45.08237309753895, 60.27578942477703, 48.32755096256733, 67.8245821595192, 72.32237040996552, 54.567598924040794, 77.9269252717495, 76.990777105093, 73.018918633461, 5.048826606944203, 3.3380771800875664, 6.693084826692939, 61.58204533159733, 81.09423771500587, 77.4691866338253, 76.2214095890522, 69.96680840849876, 69.5994821190834, 69.11979585886002, 68.64723801612854, 67.37771853804588, 65.36244347691536, 64.905244410038, 63.75238627195358, 61.854570508003235, 61.110167652368546, 59.59374122321606, 57.95610509812832, 57.03527390956879, 54.32793438434601, 56.442247331142426, 56.4461725205183, 52.08655245602131, 52.14771017432213, 54.73541311919689, 56.65102332830429, 55.137788727879524, 54.89141754806042, 53.47781740128994, 50.615210607647896, 49.72394563257694, 52.668924406170845, 52.60098785161972, 58.80116455256939, 64.92441058158875, 64.77921277284622, 59.909838661551476, 64.2596286535263, 64.01967912912369, 60.62784433364868, 59.36231084167957, 58.74300107359886, 58.222455605864525, 56.46564267575741, 55.20507551729679, 52.72483080625534, 54.52075123786926, 52.03639134764671, 51.13970786333084, 48.66305775940418, 55.5871944129467, 56.8913110345602, 60.732935294508934, 49.72705766558647, 45.8675629645586, 49.35324512422085, 53.61202999949455, 51.24293312430382, 51.12556882202625, 49.33604344725609, 48.64933289587498, 51.29112593829632, 51.54927648603916, 46.60586714744568, 50.37050373852253, 50.88814236223698, 51.22274100780487, 47.43352733552456, 50.28478033840656, 50.819316655397415, 51.831016167998314, 48.31132583320141, 47.876819148659706, 50.94735458493233, 46.90382815897465, 49.852120354771614, 49.58444371819496, 49.08495292067528, 51.59362390637398, 47.08921641111374, 48.784974217414856, 49.300503954291344, 45.93956910073757, 46.17376573383808, 54.417624771595, 42.81070299446583, 61.38875350356102, 58.880686685442924, 55.60818828642368, 56.86867184937, 50.8957077562809, 51.53649017214775, 51.32239446043968, 54.516791850328445, 56.44219033420086, 54.8859990388155, 59.6906778216362, 60.144506469368935, 57.267984822392464, 60.61647914350033, 63.252728283405304, 61.11307069659233, 59.69830021262169, 60.82179732620716, 64.72450330853462, 56.9277510792017, 48.7706033885479, 50.983737632632256, 50.86659751832485, 62.17917948961258, 65.03655776381493, 61.37172281742096, 62.315409779548645, 62.95683816075325, 59.52911429107189, 54.96088922023773, 55.69683752954006, 53.09618107974529, 52.3288806527853, 56.98994234204292, 60.789130479097366, 65.04265263676643, 68.0957356095314, 72.18696847558022, 71.00705578923225, 70.5175356566906, 67.99496501684189, 65.82033410668373, 70.5994364619255, 74.73441258072853, 73.5810224711895, 76.73357650637627, 75.93783840537071, 72.3072624206543, 73.09442058205605, 84.64920535683632, 75.8420379459858, 67.9693391919136, 17.252715826034546, 0.2675271680345759, 55.12693651020527, 83.90998542308807, 75.62884658575058, 54.7933030128479, 54.64645229279995, 65.44064328074455, 38.78411985933781, 37.285320684313774, 59.32812787592411, 44.69029113650322, 4.517163885757327, 0.23546589858597144, 0.1280764618422836, 0.15525714552495629, 0.16441324405604973, 0.14765802829060704, 0.13225834525655955], [0.09627157473005354, 0.04533272156550083, 0.025394247022632044, 0.06888038085890003, 0.00886614328919677, 0.12996414414374158, 0.3078782418742776, 8.282445017248392, 17.35932670533657, 23.82713634520769, 14.734204318374395, 27.213328443467617, 37.28685200214386, 58.348570838570595, 34.48694184422493, 61.48538991808891, 63.746583983302116, 63.04647535085678, 4.908109232783318, 0.4486101324437186, 3.1032110704109073, 60.221212953329086, 73.20567101240158, 70.80864563584328, 69.06041264533997, 65.28395488858223, 64.72277820110321, 62.617409974336624, 60.98597511649132, 61.00230284035206, 59.980248883366585, 59.44906398653984, 57.65515744686127, 56.677549704909325, 54.84184540808201, 53.17222259938717, 48.50473925471306, 50.14471985399723, 49.599426314234734, 47.6127827167511, 49.86331835389137, 47.768308371305466, 48.31522062420845, 46.85188874602318, 46.40701241791248, 47.03932128846645, 46.627978160977364, 47.10385322570801, 45.666606947779655, 43.21363337337971, 44.402247592806816, 45.065596997737885, 55.75240194797516, 59.91818681359291, 59.33616444468498, 56.77684597671032, 60.06245747208595, 60.305747017264366, 54.375925809144974, 54.81022350490093, 53.33729714155197, 53.16852919757366, 51.763402596116066, 47.225617691874504, 49.66051183640957, 49.71935547888279, 45.83589546382427, 48.09657275676727, 47.26584233343601, 46.5686671435833, 52.962067276239395, 55.51238402724266, 48.752542957663536, 36.949224919080734, 43.74543383717537, 48.66952121257782, 44.84451726078987, 47.726358622312546, 44.265584126114845, 46.08057953417301, 47.856117859482765, 44.945664033293724, 43.216916397213936, 43.17544922232628, 45.6582397967577, 45.165497437119484, 44.746300131082535, 45.08060619235039, 44.60653603076935, 45.09232096374035, 47.01591074466705, 41.488294154405594, 44.9500185996294, 45.74340082705021, 45.07746756076813, 43.18214066326618, 42.66063764691353, 43.51380966603756, 42.854750230908394, 43.629604652523994, 43.54705788195133, 39.639913737773895, 36.54309131205082, 38.13954144716263, 36.7889229208231, 52.78909295797348, 53.59542489051819, 51.51591047644615, 43.05832430720329, 47.69983224570751, 43.92285391688347, 45.010047778487206, 45.83212226629257, 46.535821706056595, 46.511905789375305, 53.21766056120396, 53.48101682960987, 52.723231092095375, 55.274152010679245, 53.3491525053978, 60.02707377076149, 55.11361822485924, 55.2778872102499, 58.094265684485435, 52.5573243945837, 46.70704431831837, 44.25233043730259, 45.6224001199007, 53.235614597797394, 56.034255623817444, 59.12208393216133, 58.83900672197342, 56.17637559771538, 50.71899823844433, 49.49628844857216, 48.642858043313026, 48.71851198375225, 47.71101124584675, 50.56236304342747, 56.908463314175606, 64.34141546487808, 66.7263650894165, 66.78346082568169, 69.14124950766563, 70.83858042955399, 64.9176013469696, 68.66274878382683, 65.8901971578598, 71.52500599622726, 75.44521003961563, 73.10299292206764, 71.12155884504318, 67.89376884698868, 66.40055537223816, 74.67310667037964, 70.93079388141632, 49.33372937142849, 8.064258825033903, 0.28150917089078575, 45.14326103031635, 72.51771032810211, 50.87537884712219, 35.865758657455444, 34.07878674566746, 36.23775489628315, 23.024005740880966, 11.580913122743368, 16.968397982418537, 0.86318667861633, 0.5752597411628813, 0.18206457345513627, 0.12153284187661484, 0.07141011737985536, 0.020409736462170258, 0.11903308070031926, 0.04677261422330048, 0.07135741005185992, 0.027722585073206574, 0.08166450541466475, 0.05940232011198532, 0.034625241241883487, 0.09170229765004478, 0.41798481484875083, 15.513488352298737, 26.330656707286835, 31.90699428319931, 18.804463259875774, 33.62446032464504, 47.79933750629425, 66.95275694131851, 44.303855672478676, 69.00294452905655, 72.546596378088, 70.34086793661118, 6.744186859577894, 0.5952685174997896, 4.323461204767227, 68.24968054890633, 79.73813608288765, 76.11232504248619, 75.89244604110718, 70.2032545208931, 68.57055053114891, 67.02652618288994, 64.8313307762146, 64.75111708045006, 65.86234465241432, 61.45429238677025, 62.8203646838665, 60.45423924922943, 56.95131741464138, 57.18258440494537, 53.23724091053009, 54.375925809144974, 54.63364318013191, 53.49977262318134, 53.7550201267004, 50.83187498152256, 51.155773401260376, 49.433489218354225, 50.49966260790825, 49.96033474802971, 49.82491761445999, 49.53984171152115, 49.11637723445892, 47.24226079881191, 46.49416074156761, 48.40518079698086, 59.83207583427429, 63.30467149615288, 61.16717979311943, 62.13560722768307, 60.80967217683792, 60.96818067133427, 57.66748018562794, 56.82501599192619, 57.25218906998634, 56.68093912303448, 55.458647310733795, 52.09039784967899, 51.96761503815651, 51.81221857666969, 47.24279657006264, 49.086176455020905, 49.094049632549286, 52.7617534250021, 54.21904742717743, 55.40924236178398, 57.1075726300478, 38.737313970923424, 45.76263539493084, 49.68610346317291, 48.58954310417175, 50.75397156178951, 49.18335624039173, 48.97096663713455, 49.82461743056774, 48.674464747309685, 45.76357014477253, 47.55602516233921, 48.15806485712528, 48.14039200544357, 49.003367498517036, 48.50849725306034, 49.45552423596382, 49.01398412883282, 48.673693388700485, 45.030851662158966, 47.68540441989899, 47.705212756991386, 46.932733207941055, 45.30694104731083, 45.77470734715462, 46.6747422516346, 45.28984576463699, 45.3428491204977, 43.61724391579628, 44.27840083837509, 39.94286768138409, 39.8916008323431, 38.43580015003681, 53.803893104195595, 59.518972635269165, 55.72244055569172, 47.21420310437679, 48.222106620669365, 47.857831567525864, 44.85596224665642, 47.27336212992668, 47.98157572746277, 49.78326424956322, 55.052612498402596, 56.07266776263714, 54.17441122233868, 54.28483709692955, 52.76149123907089, 58.41450110077858, 59.07607600092888, 57.046034932136536, 60.619340389966965, 55.54319277405739, 48.37360069155693, 47.10592791438103, 49.72835339605808, 55.23496091365814, 57.61209435760975, 60.033518224954605, 61.48842215538025, 58.81514020264149, 53.28788459300995, 50.90880565345287, 51.29349701106548, 51.96188114583492, 50.50427936017513, 52.46912732720375, 60.174745246768, 66.8178641796112, 70.32484039664268, 71.55826181173325, 74.35796678066254, 72.1142327785492, 70.85345283150673, 70.10300070047379, 68.8632184267044, 72.32271999120712, 77.01479181647301, 75.96125274896622, 74.30109143257141, 71.77763924002647, 70.56666702032089, 78.1941269338131, 77.66419976949692, 59.71212387084961, 10.96199568361044, 0.33820880809798837, 51.852112635970116, 81.0225659608841, 61.1800155043602, 43.318564742803574, 36.19582034647465, 53.5306915640831, 28.327859938144684, 18.309355527162552, 38.31240937113762, 8.31852313131094, 1.149767953902483, 0.10762401478132233, 0.14466315071331337, 0.06116821969044395, 0.13365065882680938, 0.06009508899296634, 0.07620133372256532, 0.1937975868349895, 0.15915227791992947, 0.16992297809338197, 0.18220967816887423, 0.08720695332158357, 0.23998847231268883, 0.7211463816929609, 20.11898562312126, 46.34128354489803, 49.30620364844799, 34.22272302210331, 43.05662199854851, 53.604236617684364, 76.71693339943886, 52.69523799419403, 77.17917859554291, 77.52284735441208, 77.20975175499916, 8.445660509169102, 0.9863259585108608, 5.524874087423086, 70.73865339159966, 82.11540251970291, 76.76459044218063, 77.01877400279045, 70.72580248117447, 71.42206951975822, 68.99880275130272, 66.07812747359276, 65.38541704416275, 66.72524034976959, 64.74117681384087, 64.87571239471436, 63.01794648170471, 59.998541101813316, 58.66775371134281, 53.856022506952286, 55.97312830388546, 57.09027215838432, 54.04157035052776, 55.88153801858425, 53.2943594455719, 53.86296093463898, 51.05897359549999, 53.45481723546982, 53.04004669189453, 53.18969786167145, 53.56524311006069, 50.32505817711353, 47.30406068265438, 48.69201600551605, 51.582551300525665, 60.97235284745693, 65.94046086072922, 64.63622644543648, 63.032123520970345, 64.16679963469505, 64.3119290471077, 60.84255561232567, 60.61802186071873, 60.054166316986084, 58.275424763560295, 58.48752938210964, 51.74742445349693, 54.63613584637642, 57.13307686150074, 49.87882912158966, 52.694348841905594, 52.23648481070995, 53.45603697001934, 58.955136090517044, 58.162662014365196, 52.64445751905441, 40.64370967447758, 46.467710360884666, 51.23566411435604, 52.03691191971302, 53.79540055990219, 51.28929823637009, 52.34393164515495, 53.24834771454334, 52.151798754930496, 48.37422765791416, 49.67504985630512, 50.66827096045017, 51.40347830951214, 51.63004495203495, 51.40191279351711, 52.01745316386223, 51.165394484996796, 52.93771058320999, 46.87894329428673, 50.66111974418163, 52.337133809924126, 49.53464359045029, 47.7108820527792, 48.26404497027397, 49.510115906596184, 48.36156293749809, 48.93492177128792, 47.25514590740204, 45.174571350216866, 42.10407391190529, 43.21769155561924, 41.85155466198921, 53.23286734521389, 61.20366543531418, 58.6390196532011, 49.517251923680305, 52.28335149586201, 52.162251994013786, 50.09544789791107, 50.70331268012524, 51.259010061621666, 52.3460329324007, 59.990162551403046, 60.28659604489803, 58.25867146253586, 57.66319401562214, 55.11095076799393, 62.080544382333755, 60.58915860950947, 61.424148604273796, 63.831064850091934, 58.28295595943928, 51.715319976210594, 47.997892051935196, 50.74408829212189, 57.22206428647041, 59.647721126675606, 60.17528481781483, 61.30429543554783, 59.63995814323425, 55.437235459685326, 53.12801957130432, 52.03270934522152, 51.91480927169323, 50.370644330978394, 54.30660232901573, 60.97542308270931, 68.60857129096985, 73.49539026618004, 69.74404156208038, 74.20557975769043, 74.16785538196564, 70.90255379676819, 70.7835365831852, 68.59886661171913, 71.43124982714653, 77.63538971543312, 76.68329000473022, 76.59497514367104, 73.20643097162247, 71.64309605956078, 80.2114386856556, 78.69499325752258, 61.845538392663, 13.550423439592123, 0.4027322551701218, 56.03589713573456, 86.89522683620453, 69.98612657189369, 56.81443355977535, 53.660568594932556, 64.02965739369392, 43.7495756149292, 37.82012678682804, 70.3828176856041, 21.574516519904137, 1.3683356693945825, 0.23287774762138724, 0.38145669212099165, 0.1970361263374798, 0.2934772818116471, 0.1453455406590365, 0.14186673826770857], [0.052066498319618404, 0.015781712827447336, 0.08175432012649253, 0.027076076112280134, 0.0005892838669296907, 0.07501844680518843, 0.18198600970208645, 1.488715228624642, 13.160444665700197, 20.845145657658577, 31.84846982359886, 32.02505014836788, 38.412530198693275, 55.65546154975891, 37.28606164455414, 56.56821057200432, 66.80578842759132, 68.70389297604561, 5.9553629625588655, 0.49996802816167474, 5.484937280416489, 66.40748620033264, 68.83864134550095, 70.61129942536354, 65.47212079167366, 63.735579773783684, 64.46933180093765, 62.09470622241497, 60.50612546503544, 59.718123748898506, 59.71484832465649, 57.83501699566841, 57.57999747991562, 54.95557330548763, 54.35668744146824, 51.62820965051651, 50.27496926486492, 49.21370141208172, 48.33457678556442, 52.29089789092541, 49.08732399344444, 47.05776929855347, 48.72174181044102, 48.277853429317474, 45.83796255290508, 45.292144641280174, 45.77981807291508, 45.83095572888851, 45.05652688443661, 45.16383692622185, 43.09318743646145, 46.876393631100655, 57.135843113064766, 61.37039288878441, 56.85475319623947, 59.82001148164272, 59.453312158584595, 55.457910150289536, 54.14265252649784, 57.0682979375124, 53.486705124378204, 53.35740186274052, 53.42886462807655, 51.337506249547005, 50.600486397743225, 53.124462962150574, 44.98945668339729, 48.3710890263319, 48.08067440986633, 50.13257950544357, 53.55103947222233, 58.4743744879961, 47.95168653130531, 52.025390937924385, 54.311621859669685, 44.0827227383852, 45.25193139910698, 44.370158314704895, 42.64422632753849, 42.926148399710655, 41.96023643016815, 43.4529635310173, 43.91363561153412, 44.08401846885681, 46.4088249206543, 44.41173568367958, 45.26475951075554, 47.46962159872055, 47.577406615018845, 49.45048190653324, 46.03009544312954, 44.5637047290802, 43.16948354244232, 43.991417437791824, 43.28221969306469, 42.96862252056599, 43.18997584283352, 41.25689037144184, 39.48559641838074, 42.41158381104469, 42.36415095627308, 40.30285656452179, 38.374866619706154, 38.51482070982456, 37.657818496227264, 52.38774709403515, 64.98060196638107, 50.97409375011921, 46.97814077138901, 44.58626791834831, 43.581970408558846, 43.519953936338425, 46.973208636045456, 44.745433777570724, 47.85083994269371, 47.146160155534744, 51.20503395795822, 51.64236769080162, 52.9250268638134, 52.77923248708248, 53.61809067428112, 57.74451345205307, 53.854760974645615, 55.9289138764143, 53.838459849357605, 47.258083149790764, 43.485257998108864, 44.03140649199486, 50.218599289655685, 55.92210844159126, 55.46137556433678, 55.49122676253319, 55.04240624606609, 49.1445717215538, 47.674871385097504, 46.179085448384285, 49.13438446819782, 50.59243842959404, 50.960121899843216, 58.022457137703896, 65.31590357422829, 67.00691163539886, 66.30570486187935, 67.63420477509499, 67.92579352855682, 67.86679029464722, 70.9705625474453, 70.7866296172142, 68.4567542374134, 69.34424221515656, 77.3990423977375, 73.87818172574043, 71.47379994392395, 66.44713327288628, 75.13229683041573, 72.18397423624992, 63.38834300637245, 11.06120740994811, 0.7872084493283182, 46.09509855508804, 71.31043151021004, 53.37138131260872, 30.301158651709557, 37.40149185061455, 35.52858754992485, 19.801353067159653, 21.587749309837818, 11.846660412847996, 1.1718534375540912, 0.23486806894652545, 0.09311978486948647, 0.03655849883216433, 0.039806459899409674, 0.06640600113314576, 0.04187078076938633, 0.07635727379238233, 0.0474102749285521, 0.029900881272624247, 0.0442765266780043, 0.013694299104827223, 0.09498085375525989, 0.07775835954817012, 0.3143001941498369, 3.2438457990065217, 19.339090771973133, 37.492386773228645, 30.122864618897438, 28.846401013433933, 48.15748728811741, 65.97772926092148, 44.277709275484085, 68.17287907004356, 74.25598785281181, 75.77244848012924, 8.435477055609226, 0.6446947809308767, 6.484485045075417, 74.48906734585762, 75.23984625935555, 76.17087230086327, 71.44067332148552, 68.47893744707108, 68.34953159093857, 64.99945655465126, 64.74278792738914, 64.82436195015907, 62.98781029880047, 61.251307278871536, 61.14136777818203, 59.93070714175701, 56.75291106104851, 57.19467155635357, 54.43778268992901, 52.69439443945885, 52.086206674575806, 54.0417755395174, 52.40047261118889, 52.722965106368065, 51.557366251945496, 52.26561024785042, 48.195652440190315, 47.942392230033875, 49.372612684965134, 48.29515390098095, 47.32014141976833, 47.457473650574684, 46.81158050894737, 49.39926065504551, 58.32527428865433, 62.223887890577316, 59.19110722839832, 61.08093202114105, 60.85246168076992, 57.03610606491566, 57.7660620957613, 57.07772143185139, 56.45793668925762, 58.714156821370125, 56.23812608420849, 54.35602247714996, 54.287652745842934, 52.47923478484154, 49.602283760905266, 51.7138646543026, 49.30439494550228, 52.39243224263191, 54.69473250210285, 59.348354190588, 59.2698922008276, 55.48200465738773, 53.62018436193466, 48.53947699069977, 48.11199612915516, 46.56402379274368, 45.944862216711044, 46.09109356999397, 44.14994113147259, 46.37976408004761, 45.79485006630421, 47.10034221410751, 48.0959115922451, 47.14965216815472, 49.561922326684, 52.43590950965881, 52.55860112607479, 52.03343130648136, 48.00810970366001, 47.021982818841934, 46.78286164999008, 47.51304566860199, 44.96340908110142, 44.42668028175831, 47.2004060447216, 44.56626579165459, 44.2495983839035, 43.71617540717125, 45.623684450984, 41.204122602939606, 42.56243571639061, 40.72574347257614, 39.45326395332813, 50.82111015915871, 69.39713537693024, 55.916724130511284, 49.36792753636837, 45.582939237356186, 45.507270097732544, 45.28027407824993, 47.41773538291454, 49.514842852950096, 49.20392453670502, 49.54523742198944, 53.56133311986923, 53.88069838285446, 52.962907031178474, 54.757805317640305, 52.23686099052429, 61.088634207844734, 58.674642741680145, 55.60160703957081, 56.3954908400774, 48.743134662508965, 46.640661880373955, 44.96997892856598, 52.5822738558054, 56.81374579668045, 58.66135485470295, 59.13124144077301, 55.80212228000164, 52.86120928823948, 50.44958509504795, 49.57800306379795, 51.2583526968956, 51.42964370548725, 54.47706878185272, 62.84762442111969, 67.97330617904663, 71.07975348830223, 70.33295676112175, 71.91161245107651, 70.92013165354729, 71.02477803826332, 73.07013988494873, 73.4300945699215, 74.00218427181244, 72.18391343951225, 76.99243381619453, 77.4894167482853, 74.59280177950859, 72.39547088742256, 78.16897988319397, 76.7800784111023, 68.2818116247654, 12.982949540019035, 0.6045347359031439, 53.03491696715355, 80.09331062436104, 67.18629240989685, 36.11599422991276, 41.46131940186024, 49.00564357638359, 18.58039118349552, 33.777238726615906, 25.73213752359152, 4.01777520775795, 0.3174375492380932, 0.03408535478229169, 0.03898495437169913, 0.032295765849994496, 0.07287082727998495, 0.08219213530537672, 0.05980412628559861, 0.21639256970956922, 0.1543073746142909, 0.23459905525669456, 0.11358216186636128, 0.18313458713237196, 0.1880606813938357, 0.6881602923385799, 4.063438782468438, 38.10981564223766, 52.956682965159416, 55.553095042705536, 52.81177394092083, 53.9471872150898, 75.41121706366539, 55.62008924782276, 71.22111350297928, 78.17137375473976, 82.68732503056526, 8.761760797351599, 0.8911638054996729, 8.914701640605927, 79.73090887069702, 76.61965861916542, 79.67667818069458, 70.4344417154789, 69.0317165851593, 70.38260489702225, 67.62039631605148, 66.2314036488533, 66.86491325497627, 65.2809302508831, 62.781686559319496, 63.40141050517559, 61.064239516854286, 60.939830392599106, 59.17005255818367, 56.93653620779514, 53.3685352653265, 53.74182343482971, 57.2245379537344, 55.778639540076256, 54.83347065746784, 53.039355129003525, 53.885793909430504, 52.63230577111244, 51.89105674624443, 52.90097415447235, 50.73532976210117, 51.65908299386501, 49.61569704115391, 48.34583938121796, 52.28044845163822, 62.08062417805195, 64.32185411453247, 60.35247690975666, 61.37148343026638, 63.624986708164215, 61.18848904967308, 61.82789973914623, 59.92586240172386, 57.994004264473915, 60.972725227475166, 57.94222064316273, 56.337836533784866, 56.84073194861412, 58.299032896757126, 52.429256066679955, 55.4006852209568, 52.447726875543594, 56.962067037820816, 58.85924443602562, 62.82265976071358, 52.761434242129326, 58.02555397152901, 55.336578860878944, 51.94903403520584, 51.923765391111374, 49.248230159282684, 48.125979378819466, 48.3837803453207, 48.370963633060455, 48.876366913318634, 47.78472729027271, 50.762745290994644, 52.01956205070019, 48.24148938059807, 50.44084556400776, 54.81095686554909, 54.92291785776615, 55.32460570335388, 51.895434111356735, 51.22915506362915, 50.325411558151245, 49.645400047302246, 48.21243613958359, 46.63544476032257, 48.16215343773365, 46.19005545973778, 46.65393076837063, 46.363185569643974, 47.24935121834278, 44.04649928212166, 44.02204379439354, 45.318728014826775, 43.224504590034485, 51.55576653778553, 65.34959256649017, 58.66725213825703, 51.716589108109474, 48.5146377235651, 48.164368718862534, 46.452967151999474, 51.8857142329216, 51.550215035676956, 52.98624537885189, 52.628578171133995, 58.435574769973755, 56.568001583218575, 57.28521689772606, 57.38884873688221, 56.41207315027714, 61.83477357029915, 60.976179242134094, 59.369085878133774, 59.28022384643555, 51.37341432273388, 48.17047879099846, 47.03406997025013, 53.14601920545101, 57.92450599372387, 60.2857106924057, 60.71775510907173, 59.68866012990475, 54.576304256916046, 50.0214696675539, 49.739133417606354, 52.697806656360626, 54.26691725850105, 56.14823430776596, 64.97516825795174, 69.52016517519951, 72.21751123666763, 70.37136510014534, 73.1106761097908, 74.46618497371674, 71.83072239160538, 76.87588647007942, 77.02518045902252, 74.76644486188889, 74.41009998321533, 79.43977609276772, 78.77723604440689, 77.5500538945198, 72.12870240211487, 81.46784886717796, 79.7139997780323, 74.76324543356895, 14.124831017106771, 0.49549308547284454, 58.51969465613365, 83.68433073163033, 74.26271349191666, 46.40109993517399, 56.8245942145586, 54.51202690601349, 33.60437460243702, 58.53535741567612, 56.989094987511635, 5.97937292419374, 0.47052643611095846, 0.12134608783526346, 0.15556348924292251, 0.14285664452472702, 0.23179544397862628, 0.11983776916167699, 0.1960668369429186], [0.10477288378751837, 0.03958623870857991, 0.03985343784734141, 0.060775597594329156, 0.06278699220274575, 0.08747851999942213, 0.06858247536001727, 0.07189846539404243, 7.296316707506776, 21.74285888671875, 42.809878438711166, 40.82827717065811, 33.793178871273994, 61.5718998759985, 45.652441307902336, 57.84093327820301, 66.52350917458534, 70.02808392047882, 8.16944858059287, 0.677443026797846, 7.323160842061043, 70.68971201777458, 68.61981868743896, 67.95607030391693, 68.99947911500931, 66.49197086691856, 64.97310876846313, 61.33880138397217, 62.08868354558945, 57.80998393893242, 59.095975533127785, 59.00102622807026, 56.378285363316536, 54.45821039378643, 54.313232973217964, 51.28441169857979, 50.8181919157505, 50.6543143093586, 49.82597775757313, 48.7904991209507, 49.94860477745533, 47.583547085523605, 47.67273969948292, 46.73338830471039, 46.66251450777054, 43.016632944345474, 42.5870355963707, 42.921516448259354, 42.800006568431854, 45.97429923713207, 43.20772469043732, 45.08842617273331, 59.72123958170414, 60.01603916287422, 57.45446361601353, 55.964582562446594, 57.611851170659065, 57.39563137292862, 51.634927690029144, 54.452142119407654, 53.15327301621437, 52.824066281318665, 55.26729337871075, 52.40066260099411, 51.90480440855026, 48.1049133092165, 49.196427538990974, 48.09169381856918, 46.7609254270792, 51.710095256567, 56.05255924165249, 54.10360962152481, 49.50230352580547, 54.616699889302254, 46.23945660889149, 43.291494995355606, 43.199919909238815, 43.559665605425835, 40.973999351263046, 40.409433245658875, 40.34324839711189, 44.94889385998249, 45.30904993414879, 46.33580423891544, 45.09996995329857, 47.75381974875927, 45.389841198921204, 48.40852081775665, 51.19516968727112, 51.48347541689873, 48.27440321445465, 47.1818820387125, 42.718440145254135, 45.03865644335747, 44.62069407105446, 47.84377992153168, 42.650583386421204, 40.627594739198685, 40.02787671983242, 43.360069915652275, 41.196507811546326, 40.75062073767185, 41.65828563272953, 39.25556056201458, 38.464032635092735, 59.50233332812786, 69.82143580913544, 49.92834806442261, 47.623395547270775, 43.61392289400101, 45.333513021469116, 43.349780067801476, 45.952511206269264, 47.50635802745819, 48.439865335822105, 50.398352444171906, 52.92527385056019, 52.8808618336916, 50.433329567313194, 52.820319682359695, 52.40533635020256, 52.65515774488449, 54.626408368349075, 51.928131356835365, 50.38261368870735, 43.63142475485802, 47.90909841656685, 42.85263754427433, 48.00527885556221, 53.286509066820145, 55.19863486289978, 53.378179147839546, 50.7847461104393, 47.34559245407581, 47.75026313960552, 48.399724289774895, 48.31750430166721, 48.25264558196068, 48.72577339410782, 58.354247733950615, 62.8854475915432, 65.25468125939369, 65.53482502698898, 65.2038323879242, 67.44685962796211, 64.36871320009232, 64.27040487527847, 65.19085228443146, 73.07730630040169, 66.66756704449654, 71.90278932452202, 74.54189971089363, 71.062570810318, 66.35640934109688, 74.99588415026665, 69.44518759846687, 59.725404158234596, 12.837254907935858, 1.0848675551824272, 42.08571709692478, 72.5706946849823, 45.7125236839056, 28.15386537462473, 38.62857520580292, 34.39948193728924, 21.57969754189253, 23.58370430767536, 5.586353838443756, 0.5586912645958364, 0.03833974231383763, 0.021662561521225143, 0.07111414888640866, 0.06160365628602449, 0.028870067835669033, 0.03575109411031008, 0.09407282865140587, 0.04102273233002052, 0.0629747036146, 0.08215123554691672, 0.13382947188802063, 0.05257191944110673, 0.11718315145117231, 0.2172668938874267, 0.07270874222740531, 16.161967255175114, 36.320913434028625, 47.300154492259026, 41.925741881132126, 41.72350913286209, 69.527278393507, 51.912035420536995, 66.4745981991291, 73.30486088991165, 78.53513583540916, 10.18813205882907, 0.7946979068219662, 9.218521937727928, 77.80658572912216, 73.9910888671875, 75.50183460116386, 72.43027701973915, 72.86969304084778, 67.71287575364113, 65.35220682621002, 63.58849346637726, 62.43916153907776, 63.470418602228165, 63.57289910316467, 59.85582835972309, 59.14048254489899, 56.502109318971634, 55.69565959274769, 55.48080392181873, 52.047232165932655, 53.759610280394554, 51.932014748454094, 52.36256204545498, 48.900533616542816, 50.90240679681301, 49.749320670962334, 46.98225595057011, 46.26172721385956, 47.195853888988495, 46.367429941892624, 45.614333152770996, 48.45778897404671, 45.7647442817688, 49.33138109743595, 60.544461607933044, 61.10818795859814, 60.45409865677357, 59.28789563477039, 57.30841085314751, 58.01591008901596, 56.30092911422253, 55.04063934087753, 56.67632237076759, 57.93363310396671, 58.56760248541832, 56.19701988995075, 54.35223028063774, 50.75312040746212, 53.2709489017725, 49.88806262612343, 52.56463900208473, 53.97671163082123, 58.90869498252869, 51.11580714583397, 69.21868175268173, 58.83338302373886, 41.46193116903305, 48.99381101131439, 43.418313190340996, 47.416682839393616, 43.12669023871422, 46.45328253507614, 42.74648644030094, 45.89435912668705, 46.66422821581364, 49.498876109719276, 46.74009494483471, 49.16661813855171, 49.69889357686043, 52.29714095592499, 54.735397920012474, 53.78972366452217, 51.01169653236866, 48.34349110722542, 45.678492709994316, 47.541065365076065, 46.776200607419014, 49.80076611042023, 46.09636768698692, 43.417610228061676, 41.189405992627144, 45.37561856210232, 42.12624952197075, 45.70182725787163, 44.29623708128929, 41.28312796354294, 40.324959978461266, 56.0179278999567, 69.87006559967995, 52.73564502596855, 50.93662016093731, 46.730093881487846, 47.08755970001221, 46.584424898028374, 47.5740247964859, 51.99505336582661, 50.03212429583073, 55.33600889146328, 52.67477609217167, 53.30652639269829, 54.49002608656883, 52.08584949374199, 54.02701333165169, 54.77656111121178, 58.11681367456913, 51.784290075302124, 53.411218374967575, 47.60724261403084, 47.75772973895073, 46.851098388433456, 52.39419914782047, 56.659705862402916, 54.29687865078449, 56.39747053384781, 52.20379896461964, 51.054482236504555, 50.352929681539536, 50.17700292170048, 48.97273354232311, 50.760036036372185, 50.44873774051666, 61.52545116841793, 66.3895283639431, 69.546999335289, 71.5217837691307, 70.1761543750763, 68.88600200414658, 70.28542131185532, 68.85479047894478, 69.44209456443787, 74.59917023777962, 70.67451283335686, 74.06104311347008, 76.95640414953232, 73.49519267678261, 72.47215837240219, 76.58977702260017, 73.38872238993645, 67.4819165468216, 15.77248815447092, 0.7215315860230476, 50.87708495557308, 80.9940978884697, 53.83710712194443, 31.749287545681, 49.82596255838871, 44.65497203171253, 20.78451421111822, 44.65135842561722, 10.305984634906054, 1.3176510203629732, 0.035728184011531994, 0.010585281070234487, 0.07811760355252773, 0.06856913154479116, 0.023781077725288924, 0.07234942400828004, 0.056569137959741056, 0.2635166613617912, 0.12847744423197582, 0.17160763847641647, 0.3306013788096607, 0.0983893005468417, 0.2151197419152595, 0.37234956049360335, 0.17182207462610677, 33.24067331850529, 53.71165305376053, 63.717667534947395, 62.15828061103821, 47.046559900045395, 78.65529298782349, 60.99619656801224, 73.1223414838314, 76.95734649896622, 83.70541200041771, 11.776032652705908, 1.128841289319098, 11.049157306551933, 83.08629602193832, 76.53836578130722, 78.29516351222992, 72.82489344477654, 73.74376773834229, 70.2350664138794, 67.28922888636589, 67.56938025355339, 64.51711803674698, 64.13885593414307, 65.64890250563622, 63.55492226779461, 61.966029927134514, 62.13058389723301, 58.1222739815712, 55.29611863195896, 54.50094670057297, 55.569962337613106, 54.066284224390984, 55.33877894282341, 50.89388765394688, 54.179803133010864, 52.23900027573109, 51.843072921037674, 48.33374843001366, 50.38047820329666, 49.610460922122, 48.27328987419605, 50.08202701807022, 48.09194080531597, 49.0000806748867, 64.93006467819214, 65.24331986904144, 60.84789052605629, 60.46300157904625, 61.67366221547127, 62.07039512693882, 57.73395761847496, 59.41316731274128, 57.20637872815132, 59.00201417505741, 60.8478981256485, 58.66976760327816, 57.47014917433262, 53.37132051587105, 55.167700722813606, 53.42154622077942, 53.4240996837616, 59.4953341037035, 63.902326226234436, 56.92504942417145, 63.122258484363556, 56.851960346102715, 46.978197768330574, 49.61628220975399, 47.8154144436121, 49.08584587275982, 44.62714992463589, 46.765644773840904, 46.59268945455551, 50.353993624448776, 50.94995744526386, 51.11581094563007, 50.408744886517525, 53.22527915239334, 52.698912397027016, 54.81850706040859, 57.63862073421478, 56.38958215713501, 55.628110617399216, 52.550765946507454, 48.551412150263786, 50.60614429414272, 49.818951934576035, 52.15344026684761, 49.773221388459206, 47.12539806962013, 45.13311177492142, 49.011890441179276, 44.02185000479221, 47.63783097267151, 47.101827934384346, 44.432980343699455, 45.72819784283638, 53.16419743001461, 67.87150204181671, 55.006718561053276, 53.23106624186039, 49.33583065867424, 49.531554356217384, 48.844125643372536, 50.41623428463936, 55.07394455373287, 53.11663158237934, 58.57449911534786, 57.29223512113094, 57.37195864319801, 55.88542141020298, 55.21319568157196, 59.737502709031105, 56.42409950494766, 59.532237723469734, 55.69319352507591, 55.88610157370567, 50.08197762072086, 51.48504853248596, 49.01054531335831, 54.83804561197758, 57.5808410346508, 58.46213534474373, 57.32336685061455, 54.764853939414024, 52.58010417222977, 52.002375572919846, 51.635984033346176, 51.369173750281334, 52.876708656549454, 51.60261042416096, 63.40252764523029, 67.03409537672997, 70.97063854336739, 71.92280665040016, 69.94492158293724, 72.68183872103691, 72.00875043869019, 71.54166430234909, 70.68910405039787, 77.29422122240067, 69.97197613120079, 77.86026164889336, 78.8432765007019, 75.53306892514229, 75.42826294898987, 81.6372361779213, 75.7724180817604, 72.62535095214844, 17.067669555544853, 1.0130062862299383, 55.48841491341591, 88.11910316348076, 61.004221737384796, 43.8754590600729, 62.42939606308937, 53.9567930996418, 42.736044600605965, 69.69051003456116, 34.655037224292755, 1.7234580824151635, 0.12897788925329223, 0.17549987649545074, 0.21742295270087197, 0.2886689663864672, 0.12310570513363928, 0.16437840764410794, 0.2136007437366061], [0.06757629380444996, 0.03262529797211755, 0.05657555382640567, 0.04823409595701378, 0.032738512600190006, 0.0261297227916657, 0.06909728093887679, 0.3150343266315758, 3.6955567728728056, 28.915095627307892, 40.81886127591133, 24.241255223751068, 30.049619749188423, 59.33536268770695, 47.646901085972786, 52.5266220420599, 66.4034204185009, 72.16790109872818, 9.830381255596876, 0.737248077057302, 7.445823960006237, 68.06266978383064, 66.97060078382492, 70.23136541247368, 68.46363946795464, 67.18370094895363, 65.85522383451462, 64.04857277870178, 62.86619782447815, 60.44361121952534, 59.277590587735176, 56.199045181274414, 53.62231224775314, 51.325654685497284, 53.48487742245197, 52.56648190319538, 51.78937800228596, 50.28966687619686, 49.05452035367489, 50.95158375799656, 49.27916429936886, 49.06349167227745, 47.84447528421879, 48.794055730104446, 46.41890957951546, 41.81035727262497, 41.8985391408205, 44.46486823260784, 44.713895469903946, 44.563408344984055, 44.683048725128174, 47.390639036893845, 54.02343392372131, 60.543116480112076, 56.61607660353184, 54.31533046066761, 53.61276336014271, 50.45694150030613, 53.087205961346626, 51.73295482993126, 55.2292650192976, 53.2424808293581, 53.597659170627594, 56.758147180080414, 52.50984214246273, 52.44895800948143, 47.82294563949108, 48.88922542333603, 49.90290842950344, 53.65861929953098, 52.84005582332611, 48.907247856259346, 43.29424984753132, 42.76040509343147, 40.84196023643017, 40.19669026136398, 45.32294578850269, 44.02511402964592, 42.49001160264015, 44.48997348546982, 43.29392686486244, 42.78098478913307, 43.86292353272438, 47.546449676156044, 46.04526802897453, 46.54839903116226, 46.013729721307755, 48.963336646556854, 49.844505563378334, 51.32726199924946, 48.57978142797947, 47.668844908475876, 45.07550686597824, 45.91308072209358, 47.72544667124748, 49.66867759823799, 42.88762606680393, 41.47448189556599, 43.66564951837063, 41.82938665151596, 40.32247491180897, 39.22035165131092, 38.84475700557232, 39.860708490014076, 38.2521104067564, 66.27447053790092, 59.964358136057854, 48.713036477565765, 50.496991351246834, 46.52571424841881, 45.29152527451515, 43.205167427659035, 45.577904507517815, 48.9207599312067, 53.3260041475296, 51.8009939789772, 52.67534226179123, 50.50414636731148, 51.83107316493988, 51.44413232803345, 50.70917196571827, 50.687292739748955, 50.051735043525696, 49.048771262168884, 49.30448614060879, 41.823420971632004, 44.73583169281483, 43.172633573412895, 46.95079743862152, 53.4445121884346, 51.38536088168621, 48.57565484941006, 49.79638874530792, 47.64291130006313, 46.21794976294041, 47.26097859442234, 47.117604687809944, 48.94999176263809, 48.268627524375916, 53.990934267640114, 65.21913036704063, 63.54321889579296, 63.39308135211468, 61.923411414027214, 61.523790657520294, 59.64896745979786, 61.3982567936182, 67.20129400491714, 69.550601541996, 71.0043503344059, 71.48432537913322, 72.26048693060875, 72.11075976490974, 71.4756466448307, 75.08713245391846, 71.42845317721367, 64.70542833209038, 14.147336259484291, 0.6090616586152464, 43.554444685578346, 70.40123909711838, 36.67429827153683, 35.08509814739227, 41.28650978207588, 36.78681023418903, 27.824867628514767, 34.65693712234497, 3.7638070480898023, 0.1571344822878018, 0.01066361846824293, 0.07455956205376424, 0.012609602963493671, 0.15446116245584562, 0.09541415667627007, 0.023067823713063262, 0.025486527520115487, 0.03051389710890362, 0.04929373440972995, 0.036623318010242656, 0.03518262012221385, 0.06382087813108228, 0.009891296922432957, 0.16335180960595608, 0.43460438086185604, 8.740732725709677, 43.92576456069946, 47.52597637474537, 18.5780581086874, 38.36962670087814, 68.71907696127892, 50.597210973501205, 59.141193106770515, 71.42467617988586, 82.20898389816284, 11.55181523412466, 0.7736151537392288, 9.47068115696311, 72.1467362344265, 74.3459290266037, 74.7736568748951, 73.4884138405323, 71.10274225473404, 69.55815553665161, 66.67554661631584, 65.06138563156128, 65.74266627430916, 61.15276336669922, 59.03804764151573, 58.24451722204685, 57.447259202599525, 57.46761851012707, 57.42887578904629, 56.704733446240425, 53.139624148607254, 52.376279309391975, 52.97187454998493, 50.93890763819218, 52.278111577034, 51.221551671624184, 52.01026014983654, 48.53400148451328, 43.88170212507248, 45.35943143069744, 45.66080845892429, 47.05049268901348, 46.83564841747284, 46.65326960384846, 51.27813063561916, 56.094497591257095, 59.368785694241524, 59.4973061978817, 58.5482045263052, 55.82731492817402, 54.2931966483593, 55.32332517206669, 55.54216682910919, 58.541691675782204, 55.67488990724087, 57.61653631925583, 58.26639264822006, 56.11335597932339, 55.731928646564484, 54.7087537497282, 54.01532515883446, 52.89923384785652, 57.61546477675438, 56.082638427615166, 49.209248051047325, 53.93199183046818, 58.74477557837963, 46.197324469685555, 45.59224113821983, 46.006312519311905, 46.440697610378265, 46.83706574141979, 46.49212785065174, 46.96094289422035, 44.90274913609028, 44.46335971355438, 48.38123448193073, 50.755833461880684, 48.16769354045391, 50.06379559636116, 51.909257769584656, 54.44418154656887, 53.739630952477455, 51.47402912378311, 47.49778188765049, 48.38167145848274, 48.96538473665714, 47.320323809981346, 50.40942125022411, 45.344315841794014, 44.54423077404499, 45.17249286174774, 43.62811133265495, 43.490532115101814, 42.068792805075645, 41.7161413282156, 42.21136495471001, 39.96566645801067, 63.474184200167656, 69.5819878578186, 51.750050112605095, 52.60666474699974, 48.517479971051216, 45.608690455555916, 46.40333041548729, 47.91505269706249, 51.17254950106144, 54.677542224526405, 53.23425427079201, 53.64305153489113, 53.28168332576752, 52.957298532128334, 52.15593293309212, 51.27857141196728, 52.51103147864342, 51.36089399456978, 52.31848061084747, 50.812534019351006, 47.11926519870758, 46.613272950053215, 45.68843297660351, 51.50948882102966, 55.11530913412571, 52.404466196894646, 51.818754225969315, 50.94497591257095, 49.899872392416, 50.268505811691284, 49.70347233116627, 49.48263958096504, 51.098936051130295, 50.6123835593462, 57.984546571969986, 66.29045248031616, 66.54677152633667, 69.19917359948158, 66.36650919914246, 67.36484482884407, 61.92012459039688, 66.51771068572998, 71.50039851665497, 73.5095863044262, 73.5529799759388, 72.98056349158287, 77.05914303660393, 75.11523574590683, 74.37024772167206, 75.54724216461182, 74.41456094384193, 70.25471895933151, 16.284886859357357, 0.45344469021074474, 51.4396333694458, 78.40914219617844, 42.77465432882309, 35.92856168746948, 54.940396919846535, 48.54606203734875, 29.835733026266098, 58.2834879308939, 6.977656306698918, 0.29329679149668664, 0.1045413559768349, 0.0806597710470669, 0.030624376922787633, 0.09528289301670156, 0.060712641206919216, 0.0744233705336228, 0.09202496119542047, 0.11428399608121254, 0.16149736067745835, 0.24017050629481673, 0.14653288788395002, 0.20149926887825131, 0.19893749384209514, 0.2770582737866789, 0.6940960488282144, 17.637758664786816, 63.74833568930626, 58.86954188346863, 39.0025245398283, 42.816634476184845, 77.71231278777122, 62.659549713134766, 69.08818915486336, 78.47004532814026, 87.98867896199226, 14.14044912904501, 1.0506084747612476, 11.335846222937107, 77.4608650803566, 75.54956763982773, 79.90380719304085, 76.73582598567009, 74.2348761856556, 71.40611037611961, 68.5638476908207, 67.47611805796623, 66.9073037803173, 64.52167019248009, 63.17952521145344, 60.11261098086834, 60.92075541615486, 58.94132383167744, 57.61620953679085, 57.293264865875244, 55.91142721474171, 53.75641845166683, 55.93855395913124, 53.274452313780785, 55.41492685675621, 53.654762506484985, 55.835089311003685, 52.96117812395096, 48.819316774606705, 48.91979098320007, 49.54727791249752, 50.20025387406349, 49.693273678421974, 49.54832285642624, 54.87052246928215, 58.31609398126602, 64.98014599084854, 62.233508974313736, 60.04742167890072, 58.492111936211586, 57.121316492557526, 57.577782198786736, 58.90393763780594, 60.97369037568569, 56.265701204538345, 60.44554531574249, 63.42458166182041, 56.929582580924034, 58.66695575416088, 52.890764102339745, 57.37108089029789, 53.865385204553604, 62.21963591873646, 59.515936598181725, 54.335176795721054, 50.46079829335213, 44.73488934338093, 48.71595472097397, 46.48468405008316, 52.510438710451126, 47.79888913035393, 48.60230661928654, 49.75208692252636, 50.12321300804615, 48.42839375138283, 49.78405840694904, 52.60679014027119, 53.85207071900368, 50.87027572095394, 50.80705091357231, 53.918517753481865, 56.10943078994751, 56.93183206021786, 53.714514300227165, 51.97856605052948, 53.30180324614048, 51.92022018134594, 52.82619036734104, 56.0400503128767, 48.18385027348995, 48.94266575574875, 49.413715079426765, 47.912225648760796, 46.608067229390144, 42.68118314445019, 43.86920839548111, 46.79180637001991, 43.84716957807541, 59.47539657354355, 67.92023822665215, 53.47069278359413, 54.66927006840706, 52.646353617310524, 48.90586093068123, 50.014166459441185, 51.53122365474701, 52.8543696552515, 59.00533139705658, 55.62558755278587, 56.97691664099693, 55.76600141823292, 56.59844934940338, 56.211668103933334, 54.8604492098093, 54.366057738661766, 52.10744373500347, 55.618633925914764, 56.36091649532318, 48.6264581233263, 49.36095871031284, 46.42261438071728, 53.882415890693665, 58.89512591063976, 55.39225347340107, 53.03903974592686, 54.342776387929916, 53.46060812473297, 51.828401908278465, 50.96284635365009, 52.87555731832981, 53.1113650649786, 52.45468430221081, 57.568031921982765, 70.01196518540382, 67.78818771243095, 68.49114239215851, 67.0672219991684, 70.11804789304733, 63.62699680030346, 69.17477890849113, 73.73907878994942, 75.31916320323944, 75.1275622844696, 74.35157552361488, 79.66773346066475, 78.94043728709221, 76.46363899111748, 80.91377779841423, 78.02101582288742, 75.2456371486187, 17.20241792500019, 0.47924705722834915, 55.40623292326927, 82.06473603844643, 51.545187905430794, 51.893340423703194, 65.40855020284653, 56.91599451005459, 46.294002681970596, 78.12671855092049, 15.616441927850246, 0.7140013994649053, 0.3557096002623439, 0.2831819123821333, 0.16678301064530388, 0.21876083716051653, 0.17288410279434174, 0.1843182384618558, 0.13999110844451934], [0.10370966076152399, 0.07390086888335645, 0.040670330927241594, 0.09113822830840945, 0.06842989721917547, 0.0443409970466746, 0.08210573447286151, 0.15581017913063988, 0.22924300516024232, 26.007485948503017, 42.02305465936661, 40.194512978196144, 19.943087361752987, 53.604441806674004, 53.57375085353851, 43.95712807774544, 60.67181557416916, 72.83162668347359, 16.02420374751091, 0.9163511695805937, 9.47688052430749, 67.65331014990807, 69.80787053704262, 71.62657454609871, 70.7251489162445, 68.81449744105339, 66.72496676445007, 61.75480306148529, 61.35710880160332, 62.32413411140442, 58.79107989370823, 56.191491186618805, 53.718029111623764, 51.63918346166611, 52.62877196073532, 53.69168132543564, 50.195386335253716, 48.077262192964554, 47.469686195254326, 49.99614782631397, 52.28152759373188, 50.28393678367138, 48.81471522152424, 48.45896691083908, 46.068139001727104, 41.40085704624653, 41.2468209117651, 44.91203963756561, 46.95905439555645, 46.92635715007782, 43.59499990940094, 45.89137248694897, 51.79755516350269, 57.61510379612446, 55.002645179629326, 55.55086076259613, 54.44670461118221, 54.04548034071922, 51.4313118159771, 52.51881346106529, 52.36109912395477, 54.239923506975174, 52.49254547059536, 54.20767843723297, 52.51748353242874, 53.838159665465355, 48.57855409383774, 52.553501799702644, 50.88341161608696, 53.79517637193203, 50.84090329706669, 52.215631529688835, 27.116897217929363, 39.502581506967545, 51.97854325175285, 39.867901504039764, 44.855540469288826, 39.599206522107124, 43.281908109784126, 43.95031124353409, 45.05397342145443, 43.70860241353512, 43.1018927693367, 43.53690102696419, 47.30985537171364, 45.03217779099941, 45.00726252794266, 47.491842806339264, 47.794899344444275, 51.75554841756821, 49.79224316775799, 47.26489618420601, 46.47474378347397, 46.91674746572971, 46.27794474363327, 44.38905090093613, 44.044454991817474, 40.57610750198364, 42.410333678126335, 41.77953712642193, 42.144503742456436, 38.7802554666996, 38.64730820059776, 34.75337594747543, 44.71906699240208, 71.73730820417404, 56.489110216498375, 48.93988810479641, 50.30866585671902, 47.82394878566265, 46.90654121339321, 44.59596499800682, 46.669414937496185, 52.60899782180786, 53.58293876051903, 53.98613892495632, 52.677466347813606, 55.410728082060814, 53.36478866636753, 51.13686561584473, 50.211926847696304, 48.409782350063324, 49.71129611134529, 48.3150078356266, 46.01490005850792, 40.12847252190113, 43.76773864030838, 44.297209829092026, 46.12244948744774, 48.47416989505291, 49.18883554637432, 45.668886825442314, 45.92605322599411, 45.62121458351612, 45.498815551400185, 46.545108407735825, 47.35484875738621, 46.13658092916012, 47.44002878665924, 51.59538321197033, 60.203950479626656, 61.34406790137291, 61.21280014514923, 58.54498229920864, 56.534893959760666, 53.97985406219959, 59.19392667710781, 66.25723466277122, 71.29818856716156, 69.23493728041649, 72.98056349158287, 73.08111369609833, 71.06406792998314, 69.9874185025692, 73.15642565488815, 75.36035299301147, 65.02497598528862, 13.432932794094086, 0.5081066570710391, 46.4552166312933, 68.53068307042122, 36.171497851610184, 39.15875695645809, 39.855073392391205, 33.018187656998634, 34.74453002214432, 41.32090173661709, 2.9130972968414426, 0.18021083698840812, 0.1635814449400641, 0.029845299977750983, 0.04006807066616602, 0.09907282597851008, 0.0490514231933048, 0.06905933492816985, 0.04604114234098233, 0.04858199994487222, 0.049415602479712106, 0.04328705828811508, 0.06724447957822122, 0.021569999007624574, 0.025827906174527016, 0.14403802488232031, 0.06323219175101258, 0.6555220030713826, 34.40832406282425, 57.36060485243797, 26.870938315987587, 26.06662217527628, 75.33015981316566, 55.162289813160896, 51.094418093562126, 68.19325357675552, 83.54867801070213, 18.875175565481186, 1.2189641408622265, 11.19500108063221, 71.59997597336769, 72.5775495171547, 79.3511800467968, 73.07545959949493, 75.56222856044769, 69.65460956096649, 66.59410938620567, 65.19778311252594, 64.7086201608181, 62.8821075707674, 58.978314846754074, 57.94664740562439, 55.6811785697937, 57.38888293504715, 58.83089415729046, 54.79595527052879, 51.85311958193779, 51.889232844114304, 51.43865682184696, 53.31037178635597, 52.856892719864845, 51.048041582107544, 50.5309197306633, 48.13975743949413, 45.67464731633663, 44.46666553616524, 46.53774060308933, 49.047133550047874, 50.23602515459061, 45.81321448087692, 50.40374055504799, 53.68975102901459, 57.60544091463089, 57.86696948111057, 57.53234803676605, 56.18022859096527, 57.95296646654606, 54.16126772761345, 55.53896740078926, 55.82348093390465, 58.37732009589672, 56.84205427765846, 58.67132171988487, 58.3609239757061, 57.54291146993637, 52.83067412674427, 56.475210562348366, 56.04076087474823, 55.25693133473396, 56.245858669281006, 51.6491237282753, 32.97429621219635, 58.89153130352497, 56.306860595941544, 43.578204810619354, 46.64098106324673, 42.20615163445473, 48.09270836412907, 46.54882460832596, 47.51021862030029, 45.2982547134161, 46.09346844255924, 45.12980595231056, 51.068013310432434, 46.59732520580292, 48.89576107263565, 51.997496634721756, 49.3388856947422, 52.67222262918949, 51.183093935251236, 48.93204912543297, 47.28567726910114, 49.372510090470314, 45.74118174612522, 47.561173886060715, 47.47034355998039, 43.920843824744225, 43.603940829634666, 43.94270785152912, 43.23990136384964, 41.844920217990875, 39.70252677798271, 37.880319356918335, 45.13797551393509, 70.16891956329346, 59.66488100588322, 55.26491850614548, 53.282025307416916, 52.38601438701153, 48.493913635611534, 47.43610359728336, 50.24597682058811, 55.27150735259056, 54.30703930556774, 55.53321070969105, 53.15440535545349, 56.10089644789696, 54.98997665941715, 54.74025025963783, 52.464423179626465, 51.105855479836464, 51.6366907954216, 50.403136387467384, 48.370097279548645, 45.972311943769455, 46.302765011787415, 47.62956641614437, 47.50578425824642, 50.93445047736168, 50.636500865221024, 48.91658775508404, 50.54044961929321, 48.572778403759, 48.60872447490692, 50.86443543434143, 49.45178143680096, 49.22631673514843, 50.98896995186806, 52.662802934646606, 61.25193424522877, 64.1787537932396, 64.2580783367157, 61.632100045681, 60.96434287726879, 58.708137944340706, 61.1754709482193, 69.96513649821281, 74.62405890226364, 71.83302506804466, 72.68192991614342, 76.35107383131981, 76.3749897480011, 74.0644021332264, 75.07101371884346, 78.64357441663742, 70.11824548244476, 15.70530965924263, 0.466544427908957, 53.13650071620941, 74.66571226716042, 45.98299317061901, 41.13407716155052, 52.680783569812775, 40.20270153880119, 38.75158600509167, 60.44269546866417, 3.2264405954629183, 0.28384411591105163, 0.14561060612322763, 0.1762460614554584, 0.08050751945120282, 0.04797172819962725, 0.07929429353680462, 0.019383470535103697, 0.0661681428027805, 0.18565901729743928, 0.17772780382074416, 0.16651830141199753, 0.24222934269346297, 0.20157661550911143, 0.21518752968404442, 0.39218589139636606, 0.2950947778299451, 2.2747750114649534, 58.90749804675579, 64.3301148712635, 60.376799404621124, 29.016593880951405, 73.37988406419754, 72.10988581180573, 57.54299506545067, 74.00135591626167, 87.41774439811707, 21.917085237801075, 1.1494735884480178, 13.486688509583473, 75.36661505699158, 74.459717720747, 84.69208225607872, 75.5511711537838, 78.15873563289642, 70.73709547519684, 67.47284263372421, 65.9115520119667, 67.8878715634346, 64.88368436694145, 62.12598234415054, 61.22621342539787, 58.717971816658974, 58.520314022898674, 60.44309064745903, 56.09911434352398, 55.18243633210659, 53.56097973883152, 54.68582198023796, 57.50337079167366, 56.47774122655392, 54.03137169778347, 53.980937004089355, 51.6107951849699, 51.03545665740967, 46.007213070988655, 50.01971796154976, 51.06820710003376, 54.799454882740974, 48.0089570581913, 52.160355895757675, 57.362253963947296, 63.332675993442535, 60.0079607963562, 59.13112744688988, 58.91600959002972, 58.48325461149216, 56.023684591054916, 57.99904279410839, 57.36452244222164, 58.89265984296799, 58.08301828801632, 58.99312645196915, 59.36795353889465, 61.06455110013485, 54.130401983857155, 56.6600326448679, 58.23925070464611, 57.882913425564766, 59.19829644262791, 56.37304924428463, 32.5457514077425, 46.56229108572006, 54.27496522665024, 45.98672837018967, 50.31359799206257, 44.869740307331085, 49.22736927866936, 49.82387267053127, 48.90225872397423, 48.88115085661411, 48.922743424773216, 47.969043999910355, 54.53403912484646, 49.91971492767334, 49.688223749399185, 52.47614935040474, 50.04865720868111, 55.144571363925934, 53.49734455347061, 53.73645432293415, 52.16668255627155, 53.05568665266037, 49.103499725461006, 51.050298660993576, 48.31698752939701, 44.37458507716656, 47.44116872549057, 47.631002739071846, 47.807719856500626, 44.60446894168854, 42.14613005518913, 41.25557944178581, 47.11929939687252, 65.10577484965324, 62.97091640532017, 55.31695291399956, 55.617364794015884, 54.93825003504753, 52.100699096918106, 50.26713788509369, 53.755924478173256, 59.39060412347317, 59.447361677885056, 59.27207708358765, 57.008595541119576, 60.252948850393295, 56.704091280698776, 59.33666601777077, 54.38433475792408, 53.47035460174084, 55.941096022725105, 53.337498530745506, 50.89687429368496, 46.60536177456379, 48.93686726689339, 49.63471122086048, 48.9924430847168, 54.19557988643646, 54.79223147034645, 49.74682800471783, 53.733878061175346, 50.94489611685276, 50.037671998143196, 52.21595451235771, 52.97040022909641, 51.09020411968231, 53.56938488781452, 56.92251116037369, 67.25138291716576, 66.8988910317421, 66.5555414557457, 62.839173674583435, 63.13767425715923, 61.82815432548523, 65.53810805082321, 72.61453673243523, 77.7943579852581, 74.55633893609047, 78.00354436039925, 80.18971905112267, 79.45746794342995, 74.32974949479103, 80.28620347380638, 81.02054446935654, 76.03441402316093, 17.460619769990444, 0.5926670820917934, 58.01175691187382, 82.0952408015728, 54.60840493440628, 54.75306697189808, 61.61581791937351, 46.98971875011921, 52.73864686489105, 77.43879586458206, 8.48793514072895, 0.5922845494933426, 0.3020165517227724, 0.3257973678410053, 0.19960032077506185, 0.18555170274339616, 0.19442879827693105, 0.09980384886148386, 0.20219089114107192], [0.04291289340471849, 0.05164875452464912, 0.013564954824687447, 0.09135233049164526, 0.09223054352332838, 0.056060863280436024, 0.11110989726148546, 0.13997308909893036, 0.5247509514447302, 9.662743750959635, 51.35706380009651, 53.20907302200794, 24.07315034419298, 32.81537353992462, 65.00029250979424, 40.03324583172798, 57.73584611713886, 71.42463058233261, 19.97857555747032, 0.9838646405842155, 13.246143367141485, 65.7006025314331, 63.34123693406582, 72.070671916008, 69.86980721354485, 67.90216639637947, 66.88493818044662, 64.50665339827538, 61.46026946604252, 63.05368356406689, 58.44373673200607, 53.95588494837284, 53.44978630542755, 52.564916387200356, 50.30328914523125, 51.02731369435787, 49.45102907717228, 46.01243019104004, 49.58133928477764, 49.07726973295212, 48.94724451005459, 48.755662590265274, 46.917408630251884, 50.474963933229446, 45.83743438124657, 41.609283462166786, 42.152597308158875, 44.71432864665985, 44.47629801928997, 46.98478281497955, 48.77294406294823, 46.75127774477005, 50.76220192015171, 55.89606083929539, 57.09091052412987, 56.084086149930954, 51.68012246489525, 51.9377638399601, 51.09000273048878, 51.460646241903305, 54.97640758752823, 55.2289192378521, 53.96703355014324, 55.174817740917206, 54.52356308698654, 57.49050848186016, 54.075821712613106, 50.115792006254196, 53.433591574430466, 56.21973127126694, 55.25217019021511, 50.467991307377815, 27.681092843413353, 27.08888702094555, 52.17895209789276, 40.41952170431614, 43.05106669664383, 39.03939016163349, 42.79991157352924, 44.5334317535162, 45.45697219669819, 43.49399372935295, 43.403915762901306, 43.2899484783411, 44.525368586182594, 46.535855904221535, 46.154766753315926, 46.47267669439316, 47.060626745224, 50.211919248104095, 47.69144989550114, 45.26670500636101, 47.436001002788544, 46.28133796155453, 44.8037226498127, 42.6291411370039, 45.006076991558075, 41.509630009531975, 43.684238120913506, 38.33101697266102, 41.50693215429783, 37.93214097619057, 42.79614597558975, 36.480478271842, 45.434116423130035, 68.95524948835373, 45.21522156894207, 52.66960836946964, 47.48530335724354, 50.70550516247749, 50.24585522711277, 45.79711094498634, 47.315908446908, 55.33052958548069, 53.64053227007389, 53.76312889158726, 52.66649633646011, 54.37083028256893, 51.97323493659496, 53.44997629523277, 50.423940271139145, 52.3288768529892, 52.79738791286945, 48.63967381417751, 45.1539346575737, 44.0716615319252, 41.625497192144394, 44.6638597548008, 45.7836976647377, 44.49696131050587, 45.610476359725, 42.575997188687325, 43.7359419465065, 44.66936185956001, 45.188075825572014, 46.107645481824875, 47.630067989230156, 49.839455634355545, 47.11329571902752, 47.15699337422848, 51.857333555817604, 52.926573380827904, 55.724332854151726, 53.87698218226433, 52.2283760458231, 49.92296375334263, 57.96143241226673, 66.8045648932457, 66.83139905333519, 69.62311685085297, 71.78618878126144, 72.33851954340935, 70.23452684283257, 74.03295502066612, 69.75266709923744, 77.65647858381271, 69.8635071516037, 13.017616979777813, 0.3773904650006443, 53.78075234591961, 60.0090741366148, 35.21644189953804, 39.438687935471535, 49.83836129307747, 37.94813811779022, 39.33503709733486, 45.8943135291338, 1.0425540944561362, 0.044525966222863644, 0.05755341502663214, 0.10489686697837897, 0.08508892322424799, 0.07080972733092494, 0.04060507388203405, 0.07046735234325752, 0.04282913090719376, 0.07226655579870567, 0.129522210045252, 0.015819406507944223, 0.017081901751225814, 0.04916579186101444, 0.046979654871392995, 0.0418023102247389, 0.18321359617402777, 0.6284956564195454, 10.469113681465387, 67.68239378929138, 47.207181081175804, 18.674856014549732, 50.22576190531254, 67.82863274216652, 46.739414781332016, 65.58546870946884, 79.54110905528069, 22.951414436101913, 1.1806910508312285, 16.6689645498991, 70.07467702031136, 66.53074398636818, 75.93248829245567, 73.91026720404625, 71.07625767588615, 72.9649767279625, 67.25681662559509, 65.9118103981018, 66.10785707831383, 63.17290596663952, 57.86849319934845, 57.25981906056404, 54.63575966656208, 54.55979034304619, 55.541080087423325, 53.50455276668072, 51.034236922860146, 53.179191425442696, 52.84611649811268, 52.52905771136284, 51.49223394691944, 50.139818117022514, 52.244357988238335, 47.03337840735912, 43.20862904191017, 45.00711053609848, 47.370838299393654, 48.70009817183018, 47.177280485630035, 51.47473208606243, 49.104202687740326, 52.815319150686264, 56.9881222397089, 59.849254712462425, 57.72379696369171, 54.16157551109791, 56.03777423501015, 55.256023183465004, 54.27578218281269, 59.473078697919846, 59.72858838737011, 57.41265445947647, 58.81673991680145, 56.45509824156761, 59.736043587327, 56.12106196582317, 55.46107538044453, 55.74499994516373, 58.671101331710815, 58.79459850490093, 51.04565151035786, 30.242607593536377, 47.99237474799156, 59.55542407929897, 41.16663381457329, 47.02757611870766, 42.029259726405144, 44.952507466077805, 44.88748915493488, 48.19479748606682, 46.1303074657917, 44.28168386220932, 45.349392369389534, 48.00311677157879, 49.16305772960186, 48.51149909198284, 48.64278204739094, 50.44566750526428, 51.336442306637764, 49.97183293104172, 48.2539527118206, 48.13864789903164, 46.28383442759514, 45.21575354039669, 44.7524444013834, 46.27127230167389, 45.14589048922062, 45.0195586681366, 41.1004451662302, 42.73207761347294, 40.76741203665733, 42.59768262505531, 40.851140543818474, 46.94285586476326, 68.26087474822998, 50.746033787727356, 55.40523737668991, 52.11089015007019, 54.61977772414684, 52.85787306725979, 48.953571170568466, 51.101842895150185, 55.58757059276104, 55.47389209270477, 56.04954980313778, 55.12578137218952, 54.82425235211849, 53.37893910706043, 54.52143520116806, 53.55785630643368, 51.81898221373558, 54.3238116055727, 51.53511464595795, 46.91925913095474, 46.54110722243786, 47.763129249215126, 47.91638642549515, 45.498317778110504, 47.7063374966383, 47.96879701316357, 45.06399728357792, 48.85098047554493, 48.71937833726406, 48.9434789121151, 48.41711215674877, 49.82882380485535, 52.788591384887695, 51.51690982282162, 49.5914201438427, 55.77702082693577, 57.92468838393688, 59.773870557546616, 56.688162535429, 53.956618309020996, 53.90589863061905, 61.68524779379368, 72.65005722641945, 71.2176176905632, 72.37244412302971, 76.10730171203613, 74.7355829179287, 75.78950956463814, 78.09274077415466, 75.15093103051186, 79.65726122260094, 75.12260735034943, 13.200474567711353, 0.28943803918082267, 61.25493608415127, 65.60351014137268, 41.860423386096954, 44.5955166220665, 62.684107795357704, 38.32394555211067, 47.036631032824516, 56.86390310525894, 0.559850677382201, 0.04113881535886321, 0.04469830775633454, 0.06787160178646445, 0.08619026295491494, 0.029470376248355024, 0.05544452076719608, 0.014986931109888246, 0.02851743822247954, 0.15944447630317882, 0.22656067565549165, 0.1297216399689205, 0.22403896175092086, 0.19266352581325918, 0.3772181976819411, 0.3183628589613363, 0.22968599310843274, 0.6797572807408869, 24.0684062987566, 77.65306636691093, 69.67122226953506, 36.589239835739136, 48.463481068611145, 84.77913558483124, 54.01869177818298, 68.76166507601738, 84.16378140449524, 25.688684955239296, 1.1230298574082553, 19.004220440983772, 72.69883140921593, 68.3736526966095, 76.33259922266006, 76.04376912117004, 73.74959662556648, 74.38747599720955, 68.64582449197769, 67.25252285599709, 69.34207633137703, 65.00243559479713, 60.00758841633797, 59.39167566597462, 59.104430079460144, 55.734949484467506, 58.01981247961521, 55.18696948885918, 52.998305931687355, 54.587365463376045, 55.25886543095112, 54.994859397411346, 52.8844678401947, 52.04820491373539, 55.76016113162041, 49.964104145765305, 46.765071004629135, 48.76189045608044, 49.97270308434963, 50.5939469486475, 51.218964010477066, 54.12904165685177, 52.36752077937126, 55.73219083249569, 60.27379833161831, 63.606618493795395, 62.34586514532566, 55.819688737392426, 57.08268016576767, 56.45246498286724, 54.726248010993004, 60.83690531551838, 59.92259077727795, 58.346222564578056, 61.0478699952364, 59.16920520365238, 63.10027666389942, 60.49663357436657, 58.18383447825909, 58.11993710696697, 62.16684155166149, 60.87795831263065, 54.332604333758354, 31.007460951805115, 34.817630499601364, 58.57478030025959, 45.26976004242897, 47.84781910479069, 43.83091785013676, 45.56213915348053, 48.21135699748993, 50.34306541085243, 50.539970844984055, 49.870815351605415, 49.303042218089104, 49.064559414982796, 52.39339739084244, 50.122137665748596, 48.72889682650566, 51.374018490314484, 53.82521755993366, 54.468469843268394, 53.030368611216545, 53.68141807615757, 48.79754774272442, 49.41664472222328, 47.963367104530334, 50.150058567523956, 47.02992059290409, 48.04740719497204, 43.444072008132935, 47.40888565778732, 42.19442926347256, 47.10338585078716, 42.976776883006096, 45.96440076828003, 71.74766644835472, 55.76665498316288, 55.933918207883835, 53.58220539987087, 57.09883689880371, 56.90088652074337, 50.31189948320389, 53.24013255536556, 58.52324366569519, 58.17352183163166, 58.73546987771988, 58.716353103518486, 56.12130515277386, 57.68764190375805, 59.81045879423618, 57.16801218688488, 55.398800522089005, 58.35951805114746, 52.834758907556534, 49.1649766266346, 48.72388869524002, 48.64723540842533, 49.881663769483566, 50.79260028898716, 51.037956923246384, 51.30365006625652, 46.139005199074745, 49.99202124774456, 50.58320492506027, 49.490094780921936, 50.42731449007988, 53.68364475667477, 56.30097471177578, 52.00880862772465, 51.654823422431946, 57.727136984467506, 61.098171696066856, 62.2868163138628, 59.80338357388973, 54.42793741822243, 55.9639023989439, 65.73644980788231, 74.31028693914413, 74.66223925352097, 74.9093171954155, 78.0260619521141, 78.4645888209343, 78.87987613677979, 81.63161247968674, 80.10122939944267, 81.80073380470276, 80.65545246005058, 16.369614712893963, 0.30659156560432166, 66.76200717687607, 72.37916976213455, 50.90098187327385, 55.90440519154072, 67.45964974164963, 50.138685777783394, 57.9204174131155, 76.27752497792244, 1.6889488091692328, 0.16672864090651274, 0.1870887351105921, 0.19832347054034472, 0.1754291052930057, 0.19942607934353873, 0.20987761148717254, 0.12155703589087352, 0.1675707261892967], [0.1629099645651877, 0.01874848527222639, 0.04207851532555651, 0.03438922714849468, 0.01376013131448417, 0.06109934096457437, 0.06652037351159379, 0.020861108823737595, 0.15808113617822528, 0.9147746104281396, 47.315813452005386, 53.67582857608795, 44.80078920722008, 25.436429791152477, 55.66421627998352, 50.35502336919308, 53.09254087507725, 75.46763643622398, 26.125547513365746, 0.510485329432413, 24.155070148408413, 73.36495846509933, 69.19314712285995, 69.28860560059547, 69.71365079283714, 71.26730382442474, 68.81335750222206, 62.63289034366608, 63.82341206073761, 62.05904133617878, 55.565520375967026, 53.35859879851341, 50.81941545009613, 53.0750048160553, 49.49830614030361, 49.384654238820076, 49.05251406133175, 47.696841806173325, 50.22518813610077, 49.40709963440895, 48.19063290953636, 47.822580859065056, 47.928329184651375, 48.78079444169998, 46.50296866893768, 40.7391719520092, 41.794797107577324, 44.57898750901222, 47.06416815519333, 48.24322208762169, 49.27713140845299, 47.82877452671528, 48.9499993622303, 55.43168395757675, 55.337752997875214, 52.539533749222755, 55.35450629889965, 55.93370161950588, 50.51846779882908, 51.76573187112808, 51.51564069092274, 56.44682988524437, 55.868816301226616, 53.74808929860592, 53.40452313423157, 54.74329389631748, 53.444591984152794, 54.881313890218735, 54.65410888195038, 59.893066361546516, 56.59179590642452, 50.82300245761871, 34.793011620640755, 20.8156231418252, 46.217201203107834, 41.66608281433582, 43.9717610925436, 40.56708678603172, 44.088996201753616, 41.710855811834335, 41.79333798587322, 43.173868507146835, 43.78450334072113, 42.335960268974304, 39.40286725759506, 44.961847364902496, 45.61497911810875, 42.83578544855118, 45.57877466082573, 47.406176403164864, 47.93565899133682, 45.350980684161186, 46.42369732260704, 44.26709644496441, 44.1000422090292, 40.177174508571625, 44.12846468389034, 40.967361107468605, 42.01342597603798, 39.453849121928215, 43.200064301490784, 37.63698421418667, 42.93763518333435, 37.84743592143059, 54.413897171616554, 50.78286901116371, 42.292672991752625, 48.94455425441265, 45.58282904326916, 52.84411780536175, 48.42085875570774, 49.086134657263756, 49.0703085064888, 56.28216952085495, 54.71313111484051, 53.939587622880936, 53.130569234490395, 55.34719929099083, 53.527188152074814, 54.300610050559044, 52.9796489328146, 52.50742167234421, 53.27758714556694, 48.11385802924633, 45.20381838083267, 43.58297735452652, 43.696424067020416, 43.99424068629742, 45.036809742450714, 42.082513868808746, 43.58036309480667, 41.64231888949871, 42.21613749861717, 45.127442479133606, 43.79032842814922, 45.48318699002266, 48.49216192960739, 48.59301991760731, 46.75941690802574, 46.9109033793211, 48.20904292166233, 50.55092565715313, 50.483589470386505, 51.083037704229355, 51.7085487395525, 50.21304778754711, 58.29464793205261, 66.66040822863579, 69.93539929389954, 72.39521250128746, 69.50622752308846, 70.12373998761177, 73.3409133553505, 75.51202565431595, 69.25387546420097, 73.79519417881966, 71.31312176585197, 9.55129288136959, 0.6830021284986287, 59.64966282248497, 49.145825654268265, 31.22929684817791, 37.568937465548515, 42.75780603289604, 49.77865129709244, 53.760545030236244, 31.082890704274178, 0.1017668962595053, 0.11396119152777828, 0.007178786127042258, 0.05349377817765344, 0.027718009732780047, 0.03920055940398015, 0.06862060690764338, 0.01486943428972154, 0.02414820519334171, 0.15773710620123893, 0.04428234140505083, 0.0470129401946906, 0.03786797016800847, 0.04108670174900908, 0.07886403342126869, 0.008683451578690438, 0.07534890290116891, 0.07322140299947932, 0.7608308584894985, 53.22274088859558, 62.1906016767025, 25.02819299697876, 38.767054975032806, 68.87741446495056, 55.451427698135376, 63.121202141046524, 80.01723870635033, 31.98438473045826, 0.5527467210777104, 29.889701530337334, 78.1529675424099, 75.05128517746925, 75.0828006863594, 74.69017535448074, 73.70997995138168, 74.04880777001381, 66.5634298324585, 69.82322171330452, 63.52470628917217, 59.99512128531933, 55.122893527150154, 56.41744986176491, 57.41608187556267, 53.99094946682453, 54.15688656270504, 52.46055878698826, 51.84944897890091, 54.09635581076145, 53.44604730606079, 51.135645881295204, 50.900172516703606, 49.80855569243431, 50.796745866537094, 48.639958798885345, 43.11089068651199, 45.08628688752651, 49.22185957431793, 48.93500916659832, 51.77690327167511, 51.3238649815321, 51.41584664583206, 51.52059182524681, 57.217819914221764, 58.675938472151756, 56.18248946964741, 56.73339530825615, 57.371308878064156, 54.64614450931549, 55.50217017531395, 57.878547459840775, 59.73478965461254, 58.41439850628376, 58.01993027329445, 55.81665650010109, 59.231936037540436, 54.31187264621258, 57.86394864320755, 57.834215238690376, 63.45778048038483, 57.34589584171772, 56.64670675992966, 36.94072097539902, 38.95227983593941, 60.51118679344654, 41.59612096846104, 46.013060957193375, 42.096953094005585, 45.91715790331364, 42.92149364948273, 45.12021146714687, 44.846466556191444, 46.40741139650345, 45.00553362071514, 45.21245151758194, 46.60669930279255, 48.90432581305504, 48.119428530335426, 47.48627610504627, 49.43091295659542, 49.33067813515663, 46.658722311258316, 48.438125029206276, 46.678127869963646, 47.194858342409134, 41.599745973944664, 44.701675325632095, 44.20305848121643, 43.74724254012108, 41.089805737137794, 43.49988341331482, 41.421193554997444, 44.36011925339699, 40.51919035613537, 53.95669810473919, 57.1880105137825, 45.20310401916504, 49.3717273324728, 48.7494271248579, 54.523950666189194, 52.33274884521961, 52.23729036748409, 53.95918697118759, 58.83159711956978, 57.012539729475975, 55.972668528556824, 56.29003889858723, 58.99286046624184, 56.09639368951321, 55.40009245276451, 56.14197604358196, 56.055857464671135, 52.75902517139912, 52.587528973817825, 47.411237731575966, 46.78178250789642, 48.15709970891476, 47.72665120661259, 47.1016151458025, 46.23477526009083, 46.127085238695145, 44.333060905337334, 46.98346808552742, 47.433025762438774, 47.766412273049355, 50.15942886471748, 49.654128178954124, 49.19582337141037, 50.9545361995697, 51.6853129863739, 51.08457662165165, 53.783055022358894, 54.135068133473396, 52.76171162724495, 55.39355680346489, 55.380458906292915, 62.20146909356117, 70.42378708720207, 73.9766800403595, 74.2668628692627, 73.57466161251068, 74.18020471930504, 76.66987672448158, 76.24736979603767, 75.83398997783661, 75.973070114851, 77.3042830824852, 10.01624258235097, 0.8832077449187636, 65.84596753120422, 53.0166931450367, 38.34217697381973, 45.719986483454704, 60.26035085320473, 51.81649714708328, 57.961899787187576, 29.624599255621433, 0.24770746123977005, 0.05657402871293016, 0.027036176397814415, 0.14448065659962595, 0.028019718738505617, 0.021111247842782177, 0.0739821043680422, 0.060683192787109874, 0.03605133737437427, 0.28455164982005954, 0.14933405007468536, 0.12657019891776145, 0.1786176982568577, 0.06864019960630685, 0.1641068558092229, 0.11590449779760092, 0.20263393846107647, 0.2601307164877653, 2.108224011026323, 71.25630721449852, 69.26244780421257, 63.264804035425186, 39.09044802188873, 73.35051164031029, 66.72692745923996, 66.2445205450058, 87.63207569718361, 33.34415316581726, 0.7733776071108878, 31.10360339283943, 80.28955489397049, 78.32023456692696, 76.15618228912354, 77.71010130643845, 76.68293282389641, 76.59325763583183, 67.64119639992714, 71.55525997281075, 66.93131849169731, 60.98783701658249, 58.02437223494053, 57.27754890918732, 60.49797870218754, 55.60934342443943, 57.160556986927986, 55.807510390877724, 53.58222059905529, 56.43521010875702, 54.35535371303558, 52.451587468385696, 51.60915367305279, 51.13785736262798, 52.541847825050354, 51.495349779725075, 46.22058682143688, 47.36203037202358, 50.33931501209736, 50.97396455705166, 53.2242152094841, 53.46571125090122, 54.002500846982, 54.833318665623665, 59.228162840008736, 61.8931270390749, 58.02808463573456, 60.243635550141335, 59.619929417967796, 54.926231279969215, 55.964711755514145, 57.45745025575161, 60.93277417123318, 61.52069382369518, 59.134391471743584, 59.7684520483017, 62.696464732289314, 59.67797130346298, 60.69696642458439, 60.39525881409645, 67.14368909597397, 61.693983525037766, 59.28248472511768, 38.10193486511707, 30.676151029765606, 53.023749366402626, 44.666777998209, 47.94299639761448, 45.07837571203709, 47.320331409573555, 46.36975921690464, 46.207716912031174, 50.92916116118431, 48.692962154746056, 50.509982854127884, 45.898736491799355, 50.591062903404236, 50.52782669663429, 49.00401346385479, 47.548721954226494, 50.12518510222435, 52.41830125451088, 52.48154126107693, 51.05799324810505, 48.55514355003834, 49.553919956088066, 45.158346220850945, 48.16684998571873, 47.597439140081406, 46.24479532241821, 44.04033221304417, 46.35016366839409, 42.748393937945366, 47.999974340200424, 44.795135110616684, 53.100444450974464, 67.49469146132469, 52.418126463890076, 48.33526834845543, 52.137150540947914, 57.996979504823685, 56.42417170107365, 54.362189546227455, 55.53756147623062, 61.64099916815758, 60.20834684371948, 59.06213454902172, 58.57459411025047, 59.9148353934288, 58.090792670845985, 59.42123048007488, 59.797288700938225, 57.43965961039066, 56.518866419792175, 53.06037180125713, 50.474834740161896, 48.02716568112373, 49.472703114151955, 49.263718128204346, 49.098225608468056, 49.652783051133156, 49.70181941986084, 47.85560488700867, 47.809760347008705, 50.0560250133276, 49.44310650229454, 52.191586419939995, 53.60788822174072, 51.544074565172195, 52.3463749140501, 54.06822971999645, 54.447582364082336, 56.296616345644, 55.863283798098564, 56.068746373057365, 58.43635752797127, 55.86293041706085, 62.8327102214098, 72.36717760562897, 76.42904564738274, 78.90918016433716, 75.482919216156, 77.70983532071114, 78.4666483104229, 80.58392509818077, 77.47749298810959, 78.65934357047081, 81.10346361994743, 13.317056111991405, 1.000489757861942, 70.73847100138664, 58.5500930249691, 49.96946945786476, 53.99042509496212, 60.64793385565281, 64.55434083938599, 74.5661424100399, 46.94659486413002, 0.25219415954779834, 0.2706652652705088, 0.16230907727731392, 0.2614331559743732, 0.18235187366371974, 0.24335366673767567, 0.10780279073514976, 0.1408991261268966, 0.11912840956938453], [0.09658110968302935, 0.04223639611154795, 0.06891702068969607, 0.0251591272171936, 0.25038863299414515, 0.062202688204706647, 0.045383836986729875, 0.12931005971040577, 0.06773184053599834, 0.5083881388418376, 18.01721390336752, 60.819194465875626, 41.508387476205826, 24.165145307779312, 42.679807618260384, 54.30416285991669, 48.555922508239746, 77.13017642498016, 33.96439768373966, 0.06193030145368539, 43.87253701686859, 76.77959963679314, 66.40490233898163, 69.79441165924072, 68.96616250276566, 71.60304620862007, 68.81975635886192, 66.57944217324257, 61.419687643647194, 59.287622049450874, 55.76710715889931, 51.3619427382946, 50.80035947263241, 55.04367537796497, 49.201667457818985, 49.4510480761528, 48.204004392027855, 47.145913168787956, 49.22553017735481, 51.558164209127426, 49.41536799073219, 48.057522252202034, 45.946226343512535, 48.91036368906498, 47.41445615887642, 41.51686482131481, 43.7863652408123, 43.076350539922714, 47.255244702100754, 47.67043702304363, 49.610514119267464, 50.143625512719154, 46.515952572226524, 56.09952092170715, 53.70697930455208, 53.106649518013, 53.848571106791496, 51.66759453713894, 52.05787539482117, 52.210030630230904, 53.814182952046394, 55.782678723335266, 55.91405667364597, 53.59613545238972, 53.53747799992561, 51.01812198758125, 52.471437603235245, 52.69622214138508, 58.10381077229977, 58.121080845594406, 58.52087639272213, 53.324548825621605, 52.133472338318825, 16.334654688835144, 39.35169920325279, 47.145525589585304, 40.5024978518486, 41.43611915409565, 40.079785734415054, 41.06193423271179, 37.70623169839382, 42.00540840625763, 42.19957418739796, 44.33688350021839, 42.62517794966698, 43.7695587426424, 44.25514228641987, 42.209229469299316, 44.54316683113575, 46.07600457966328, 45.74481055140495, 43.81778195500374, 47.43629738688469, 42.10560142993927, 44.57106493413448, 42.49275125563145, 43.483551889657974, 40.47013118863106, 40.530601143836975, 40.359097346663475, 42.077874317765236, 40.11400669813156, 40.27935482561588, 42.68910571932793, 51.61960691213608, 39.683398604393005, 38.85806009173393, 46.24072194099426, 48.473333939909935, 50.42128041386604, 52.03090064227581, 48.92357178032398, 47.63604886829853, 55.46865217387676, 52.97213673591614, 51.95776976644993, 52.371202781796455, 53.25118996202946, 53.76603953540325, 56.49862490594387, 56.473983228206635, 60.01880161464214, 55.16322836279869, 51.98819853365421, 45.25171861052513, 47.2882117331028, 43.191507160663605, 42.98027649521828, 44.48626488447189, 40.607459619641304, 42.98057287931442, 42.01654180884361, 41.97513923048973, 45.59004485607147, 47.389772683382034, 42.949969321489334, 47.20153458416462, 46.25438220798969, 46.711664870381355, 45.96385359764099, 48.20285305380821, 48.076927810907364, 50.5907741189003, 50.831346809864044, 50.43098509311676, 51.59189499914646, 59.10308115184307, 69.24863934516907, 69.09270331263542, 68.56483563780785, 73.7975500524044, 71.94927603006363, 75.66495224833488, 72.43071779608727, 73.1707812845707, 70.43905466794968, 77.87483006715775, 6.793284500017762, 1.0984563385136425, 61.47750914096832, 47.79808357357979, 33.36094446480274, 33.36505204439163, 31.57106000930071, 26.539178118109703, 54.659234806895256, 14.723297003656626, 0.24578847514931113, 0.1613803388318047, 0.08259063892182894, 0.021554384220507927, 0.03290774082415737, 0.04242551018251106, 0.06197078189870808, 0.04290030286938418, 0.033111783195636235, 0.05554779803787824, 0.09271965594962239, 0.0974170870904345, 0.051031662442255765, 0.032927207357715815, 0.054508230969076976, 0.02739306408329867, 0.07881249868660234, 0.07750162840238772, 0.6061657390091568, 15.916796810925007, 71.56841486692429, 35.31054005026817, 25.86643371731043, 57.92274668812752, 57.16004021465778, 57.398036643862724, 83.02380457520485, 38.3195111900568, 0.13796535698929802, 51.11144497990608, 82.66186639666557, 74.17661011219025, 73.62916588783264, 73.3773609995842, 74.04453679919243, 74.74809944629669, 68.53274255990982, 66.03533416986465, 62.128744795918465, 59.36801053583622, 53.67913439869881, 52.55969546735287, 55.70246122777462, 52.28406585752964, 53.231199234724045, 51.02574057877064, 49.68003898859024, 52.592742294073105, 53.28892193734646, 51.249088793992996, 51.46831803023815, 47.49755010008812, 50.545818731188774, 49.239106848835945, 44.85141769051552, 45.579200237989426, 46.55475229024887, 49.91037502884865, 50.50715960562229, 51.99726864695549, 51.926037669181824, 49.413859471678734, 57.168198376894, 55.24921394884586, 54.83913615345955, 56.70083865523338, 56.15619868040085, 55.085009559988976, 55.39045237004757, 57.23703548312187, 59.69906397163868, 56.72876715660095, 56.599163711071014, 54.45522755384445, 55.59588074684143, 55.624234825372696, 57.60895572602749, 59.46996286511421, 61.5957397967577, 61.22962944209576, 57.114644050598145, 52.37873777747154, 31.02897349745035, 59.202985391020775, 46.579675152897835, 44.55846481025219, 43.62470291554928, 42.72996872663498, 43.30308057367802, 42.0728699862957, 43.04930739104748, 42.66085423529148, 42.32902944087982, 48.32265302538872, 48.06709013879299, 47.95818418264389, 44.69501048326492, 45.822254195809364, 47.846101596951485, 46.82290770113468, 47.52422086894512, 48.64497072994709, 43.26244555413723, 44.17633071541786, 43.62530328333378, 45.76609320938587, 41.41285680234432, 42.48109728097916, 42.870211601257324, 44.058920815587044, 39.17237162590027, 42.63311192393303, 44.77894797921181, 50.31213887035847, 46.230717077851295, 42.845395132899284, 47.54278287291527, 52.793128341436386, 53.56571428477764, 54.52879920601845, 50.09533770382404, 51.159451603889465, 56.72489516437054, 56.36602342128754, 53.858731761574745, 55.78842021524906, 57.81663358211517, 56.52881808578968, 58.530451878905296, 59.35716591775417, 60.835290402173996, 56.807061955332756, 55.667351111769676, 47.29299187660217, 49.500787407159805, 48.18394146859646, 47.05906882882118, 46.51377908885479, 44.06993642449379, 46.25855438411236, 44.3369746953249, 46.93014554679394, 50.0003731995821, 49.364123940467834, 47.437855303287506, 50.7562742382288, 48.65314029157162, 50.171485617756844, 50.285707488656044, 50.44292025268078, 54.1639693826437, 55.27181513607502, 52.33624845743179, 54.10803258419037, 55.29511168599129, 63.486978113651276, 70.81862390041351, 71.8575869500637, 72.15127319097519, 78.69154304265976, 74.0174974501133, 78.0051326751709, 77.18313798308372, 77.64982894062996, 74.670500010252, 82.621930539608, 7.130884034559131, 1.4192113769240677, 68.4661853313446, 54.32876653969288, 43.56903210282326, 39.66849200427532, 43.7085872143507, 25.90255457907915, 70.0101412832737, 18.61436326056719, 0.5221632309257984, 0.13072011061012745, 0.0820891177863814, 0.06984526189626195, 0.009829848950175801, 0.07420800669933669, 0.052823885998805054, 0.02398193442786578, 0.03675745378131978, 0.234721836168319, 0.2824939414858818, 0.266303604003042, 0.2081411491963081, 0.2629421203164384, 0.18103772308677435, 0.18451971671311185, 0.3587876132223755, 0.17837903840700164, 0.8239219605457038, 31.24490261077881, 74.49011608958244, 56.98002107441425, 33.288554549217224, 58.8136088848114, 70.25234028697014, 59.416568130254745, 89.87321063876152, 40.1912147551775, 0.2888728491961956, 51.560333892703056, 86.8211156129837, 76.04797929525375, 78.27022165060043, 75.38780272006989, 78.8371816277504, 74.844059497118, 71.9328761100769, 65.73962643742561, 66.81652665138245, 60.68702235817909, 56.936752796173096, 54.73467595875263, 61.61414220929146, 52.711208537220955, 56.52719937264919, 54.73564490675926, 52.181638553738594, 53.177717104554176, 57.442824840545654, 54.26900714635849, 52.44885541498661, 48.32359157502651, 53.823025077581406, 51.3180360943079, 47.529092207551, 48.04961487650871, 48.67433175444603, 52.412251979112625, 52.83523388206959, 55.09012408554554, 54.241390228271484, 53.52517805993557, 61.496565118432045, 58.36755461990833, 57.78259880840778, 59.11710239946842, 57.63426996767521, 56.69401042163372, 56.859738528728485, 58.86028178036213, 64.69208344817162, 60.567974746227264, 60.01811005175114, 57.49216519296169, 59.817184433341026, 57.16358542442322, 57.9527422785759, 63.239805176854134, 65.39484053850174, 63.787245601415634, 59.45510946214199, 58.5982820391655, 23.822183310985565, 47.42822661995888, 51.54269143939018, 46.58203482627869, 47.150799706578255, 44.7888008505106, 45.94580836594105, 43.70503820478916, 48.55240769684315, 47.94320538640022, 49.53350365161896, 50.01585356891155, 50.68577662110329, 49.194782227277756, 45.09363189339638, 49.39898706972599, 51.3194116204977, 51.87742307782173, 52.02935792505741, 53.168643191456795, 45.64562447369099, 48.831871300935745, 48.62564876675606, 47.36717149615288, 46.46789275109768, 44.24588218331337, 44.880999103188515, 46.81343100965023, 43.58199700713158, 45.46609550714493, 47.35047519207001, 56.607979238033295, 54.298664554953575, 47.99765266478062, 48.10038015246391, 54.59293216466904, 56.13719969987869, 56.569760888814926, 52.82000809907913, 55.23273043334484, 59.39608342945576, 60.48862740397453, 58.3384557813406, 57.36986115574837, 59.48071248829365, 58.33114497363567, 61.19831532239914, 60.37627123296261, 63.76013785600662, 58.026762306690216, 55.688067600131035, 49.511179849505424, 50.13918735086918, 50.35372003912926, 48.26704300940037, 50.89774824678898, 47.49302454292774, 50.16933873295784, 48.308270797133446, 47.772286757826805, 54.21900562942028, 53.35639871656895, 47.25214026868343, 52.005658596754074, 50.76108478009701, 52.09821783006191, 52.00527101755142, 52.101212069392204, 55.885562002658844, 59.58899147808552, 55.96025459468365, 55.97949296236038, 56.403709799051285, 67.3216563463211, 73.90420272946358, 75.84086760878563, 73.32080483436584, 81.17156356573105, 79.16442766785622, 81.7040365934372, 80.05410432815552, 80.19734904170036, 79.10535603761673, 86.44528537988663, 10.22356515750289, 1.4284917851909995, 77.44461715221405, 61.10387519001961, 53.518330827355385, 45.20939268171787, 45.77710881829262, 35.00918582081795, 78.05326849222183, 23.776127882301807, 0.700737142469734, 0.330903046997264, 0.22916997782886028, 0.20861259108642116, 0.11149242243845947, 0.19362828810699284, 0.23215670662466437, 0.16830739681608975, 0.11745251395041123], [0.030662527024105657, 0.07360812131082639, 0.02549171698774444, 0.05185923873796128, 0.07730800949502736, 0.032907410568441264, 0.15251719567459077, 0.07384158612694591, 0.1252997014671564, 0.3293252410367131, 3.5570159694179893, 57.86286190152168, 44.65276814997196, 31.283632032573223, 26.35897658765316, 56.31307326257229, 46.395685225725174, 78.86379539966583, 36.51691071689129, 1.0665062279440463, 59.3405532091856, 69.48845967650414, 72.73718655109406, 67.34734296798706, 67.34130129218102, 68.58352303504944, 65.86291462182999, 59.37849037349224, 55.021894946694374, 52.96572647988796, 55.78434303402901, 52.07887686789036, 51.84345670044422, 48.65598253905773, 52.33574688434601, 47.00723581016064, 48.39145213365555, 46.46193087100983, 51.2344291806221, 48.935449942946434, 48.647812977433205, 47.6579736918211, 47.45591193437576, 45.662506967782974, 50.179985761642456, 43.146240189671516, 42.612767815589905, 42.87607088685036, 48.805246129631996, 48.24015185236931, 49.90404836833477, 48.764265328645706, 50.42111702263355, 55.8046605437994, 52.45751515030861, 51.76515810191631, 54.57261845469475, 53.051411882042885, 57.890699207782745, 54.69019554555416, 56.60736367106438, 54.060968309640884, 57.47763477265835, 48.69879104197025, 51.13806635141373, 52.45160646736622, 58.06452468037605, 56.83219760656357, 60.643309503793716, 52.75145597755909, 62.719309106469154, 50.886356458067894, 56.15650646388531, 19.415293782949448, 31.333945132791996, 52.9390025138855, 37.6436984539032, 43.885102942585945, 39.60205256938934, 42.316759899258614, 36.40757918357849, 38.260868936777115, 40.25537811219692, 40.69884471595287, 40.92883117496967, 42.98124544322491, 44.64470498263836, 41.34662255644798, 43.35741765797138, 47.002980038523674, 46.83644637465477, 42.33442135155201, 44.79174569249153, 42.19863563776016, 44.22545447945595, 41.2790621817112, 41.85161925852299, 40.229980275034904, 41.53508484363556, 41.59053526818752, 40.69132871925831, 39.610784500837326, 39.5715706050396, 40.934287682175636, 46.16998113691807, 39.86341394484043, 43.57516497373581, 48.92869010567665, 52.17974245548248, 53.421329632401466, 51.16892449557781, 53.9104887843132, 46.103530302643776, 52.142363861203194, 52.49526232481003, 51.28498926758766, 54.2949103564024, 53.89734148979187, 53.79665449261665, 53.94014239311218, 55.94461463391781, 59.223720878362656, 58.555678725242615, 52.94287450611591, 44.37237359583378, 45.74447236955166, 45.223398730158806, 41.776045113801956, 43.7981978058815, 40.231807976961136, 40.940633341670036, 41.73904649913311, 44.06815432012081, 42.51980200409889, 44.19941067695618, 45.28182439506054, 46.65537849068642, 46.67965918779373, 47.38932430744171, 46.65520370006561, 46.501213163137436, 48.21223095059395, 49.654686748981476, 49.12440240383148, 52.40097418427467, 49.78913493454456, 58.258618265390396, 67.3442955315113, 69.51948121190071, 69.90519851446152, 70.98933354020119, 68.99028360843658, 75.17645806074142, 73.40803295373917, 74.71159860491753, 68.04862573742867, 75.53574398159981, 4.215658139437437, 1.584105072543025, 65.56333109736443, 43.21005016565323, 31.794740706682205, 33.80560800433159, 29.61927194148302, 37.721677869558334, 66.65988385677338, 11.769944429397583, 0.448033869615756, 0.04850824159802869, 0.053094484173925593, 0.06613731398829259, 0.03905628218490165, 0.040195671826950274, 0.06445356644690037, 0.007891189452493563, 0.05577927760896273, 0.018230774185212795, 0.1004814296902623, 0.03420050641580019, 0.033758613135432824, 0.06612889803363942, 0.08294574174215086, 0.025144193350570276, 0.036926826724084094, 0.05906790836888831, 0.22226457571377978, 2.1252846205607057, 62.29655899107456, 47.93481923639774, 27.50230673700571, 37.26881816983223, 62.06789866089821, 51.66013553738594, 86.94604530930519, 39.98761028051376, 1.2998818675987422, 63.85713145136833, 77.21115007996559, 75.7206192612648, 70.72902470827103, 71.22843191027641, 72.72405445575714, 68.12047988176346, 63.84665161371231, 58.72154362499714, 57.19256266951561, 58.83190110325813, 54.13425497710705, 55.12517720460892, 50.92628091573715, 54.90882821381092, 51.42559312283993, 52.075229063630104, 50.89749366044998, 52.61828072369099, 50.64416125416756, 51.98941446840763, 50.83257034420967, 48.29420015215874, 47.52488203346729, 49.26190942525864, 45.83633244037628, 45.00420369207859, 44.692422822117805, 48.93180973827839, 50.75654782354832, 53.99798668920994, 49.95231717824936, 54.16070155799389, 56.74493908882141, 56.82756565511227, 56.530759781599045, 57.72662781178951, 55.20890571177006, 60.081274062395096, 57.22115993499756, 57.600721567869186, 58.17841596901417, 58.482437655329704, 55.17264425754547, 51.19299240410328, 56.767882257699966, 58.60826790332794, 59.39227223396301, 63.93275499343872, 57.49256417155266, 63.23467165231705, 55.028506591916084, 59.81002941727638, 31.974281072616577, 49.69194754958153, 53.53414557874203, 41.11125558614731, 43.65323178470135, 44.17140617966652, 42.958347871899605, 40.90588420629501, 40.66021218895912, 42.368057146668434, 43.10779005289078, 44.85857270658016, 46.8369897454977, 47.64745205640793, 43.992044404149055, 44.43784788250923, 50.19423119723797, 49.16444465517998, 43.38861018419266, 45.5591145157814, 43.63684706389904, 45.588787123560905, 45.556321665644646, 42.88897879421711, 42.55255624651909, 42.53967113792896, 40.737503841519356, 43.40186007320881, 41.214522644877434, 42.37141616642475, 43.20976138114929, 46.8150345236063, 44.12669397890568, 44.734380170702934, 51.60447232425213, 53.98459240794182, 56.277731359004974, 52.53761865198612, 56.353639885783195, 50.860761031508446, 53.70428144931793, 55.1124706864357, 54.38491992652416, 55.573769733309746, 57.98461116850376, 55.598893985152245, 58.18671092391014, 58.203008249402046, 59.049618020653725, 59.413456097245216, 56.474207416176796, 48.58787499368191, 46.9721332937479, 50.55667854845524, 44.321604520082474, 46.94226689636707, 44.185902401804924, 45.164828673005104, 42.948760986328125, 46.5252772718668, 47.34576344490051, 48.988806679844856, 48.26885171234608, 49.57248575985432, 48.56964357197285, 50.956949070096016, 50.04733107984066, 51.427006646990776, 50.999309197068214, 52.99793355166912, 52.92484827339649, 55.61002358794212, 53.26138101518154, 62.283715680241585, 69.06230494379997, 72.85448625683784, 72.48387694358826, 76.06003224849701, 71.94772571325302, 77.67582714557648, 77.27304875850677, 80.40040254592896, 70.16293868422508, 77.68775850534439, 4.575496930629015, 1.790277378167957, 74.89322885870934, 50.49077868461609, 37.18609660863876, 43.58426168560982, 38.61456535756588, 35.52737921476364, 71.43291413784027, 9.967408552765846, 0.4843769600847736, 0.06323818088276312, 0.07156559731811285, 0.04861367109697312, 0.05247251989203505, 0.08431829191977158, 0.06805106793763116, 0.0033271677057200577, 0.06740696539054625, 0.20183476415695623, 0.15431731939315796, 0.1754723279736936, 0.1360572804696858, 0.13091232685837895, 0.1848164718830958, 0.242711367609445, 0.14301053626695648, 0.2814738149754703, 0.9240195737220347, 7.046247376129031, 79.20011535286903, 61.23196251690388, 46.71662740409374, 39.39310938119888, 75.90778201818466, 56.67566120624542, 92.8804224729538, 43.55256758630276, 1.7876008967868984, 66.65075674653053, 80.63279807567596, 79.26621660590172, 74.46997717022896, 72.51899465918541, 75.01929849386215, 69.57231357693672, 65.73847889900208, 59.023464024066925, 57.32371263206005, 61.77216432988644, 58.08953493833542, 58.10884550213814, 54.58288550376892, 59.645988419651985, 52.62331545352936, 53.80125604569912, 52.395890057086945, 56.66368044912815, 53.39223459362984, 52.70768232643604, 52.61733837425709, 50.713017359375954, 49.5829313993454, 54.294891357421875, 47.5391236692667, 46.19059503078461, 48.00550304353237, 51.76659822463989, 53.92256073653698, 55.489250868558884, 53.576513305306435, 56.21216967701912, 61.19946666061878, 57.3317302018404, 58.058000430464745, 60.44576570391655, 57.693109810352325, 63.06828998029232, 56.36974722146988, 58.61076436936855, 59.76698152720928, 61.36008024215698, 56.14544905722141, 55.60468107461929, 60.38909554481506, 62.28799805045128, 61.37285515666008, 68.11550974845886, 59.24829415977001, 66.86918422579765, 56.41699768602848, 64.26880896091461, 25.219837613403797, 38.641616106033325, 57.6213164627552, 41.975906789302826, 48.534689247608185, 46.56720422208309, 47.401487454771996, 42.5845505297184, 43.84711258113384, 46.05979464948177, 46.58831208944321, 46.762232556939125, 50.23265093564987, 49.14449952542782, 46.05235084891319, 46.8645116686821, 52.0739371329546, 51.56700253486633, 46.63275070488453, 49.515621811151505, 48.024422228336334, 49.26712654531002, 47.695667669177055, 46.117722541093826, 45.71198791265488, 44.17175196111202, 46.87841132283211, 45.29553785920143, 45.63479885458946, 43.39801847934723, 44.79777976870537, 47.70658828318119, 50.57415001094341, 48.19348655641079, 54.00870971381664, 57.407676726579666, 57.38500714302063, 56.311519145965576, 59.69715267419815, 52.96894110739231, 59.22091282904148, 58.39006081223488, 56.41103580594063, 57.99870081245899, 60.76209492981434, 58.221581652760506, 61.71188436448574, 60.608776956796646, 62.509955540299416, 62.585005313158035, 57.614431232213974, 48.14340144395828, 49.09029923379421, 49.998697489500046, 48.116939663887024, 48.80359701812267, 48.16085770726204, 48.82343955338001, 48.343076929450035, 48.875766545534134, 47.66052335500717, 49.46036897599697, 50.506270453333855, 52.40692086517811, 51.53309315443039, 53.84479030966759, 53.118212297558784, 53.31192210316658, 53.674673438072205, 54.98892791569233, 55.94157859683037, 57.3486202955246, 54.86770682036877, 64.41747218370438, 72.22049787640572, 76.74053773283958, 75.95302239060402, 75.84446981549263, 75.96050038933754, 80.53861632943153, 80.08552864193916, 81.91915065050125, 73.18380698561668, 84.87606078386307, 6.924402164295316, 1.9034323375672102, 80.48120900988579, 54.79669623076916, 50.92787683010101, 48.698441460728645, 42.96921528875828, 49.93936747312546, 87.99288153648376, 18.403789959847927, 0.8513600507285446, 0.31966310169082135, 0.18590820080135018, 0.18834134680218995, 0.16372239362681285, 0.21031871438026428, 0.18617644265759736, 0.18099556909874082, 0.1855380175402388], [0.0720584204827901, 0.06308665659162216, 0.0179182706415304, 0.025911188131431118, 0.0689691342995502, 0.0856871907308232, 0.04175092763034627, 0.048215052447631024, 0.0920598347147461, 0.07899258824181743, 0.09522015185211785, 37.843719720840454, 50.693269819021225, 35.033287927508354, 26.537559404969215, 52.06650473177433, 43.834637850522995, 68.74244570732117, 44.3997473269701, 2.426366452127695, 64.35194090008736, 68.60028773546219, 68.75265195965767, 62.153131887316704, 62.78902396559715, 58.0711705237627, 59.80696678161621, 53.52819509804249, 54.519725292921066, 49.33505170047283, 53.12203489243984, 50.678572207689285, 52.72937536239624, 52.29338675737381, 50.8674942702055, 47.69042395055294, 49.044553488492966, 48.7964192032814, 50.995862782001495, 50.50977386534214, 49.705691412091255, 48.08610051870346, 47.16770879924297, 46.28104917705059, 49.63823363184929, 43.26814144849777, 44.44632522761822, 41.90501019358635, 45.96060857176781, 49.337669759988785, 50.651346668601036, 51.2121357768774, 51.11924596130848, 55.44670835137367, 53.66029500961304, 52.715623900294304, 52.86283180117607, 53.68398293852806, 57.42043264210224, 52.19664394855499, 54.67655047774315, 54.92332063615322, 55.03174401819706, 53.41978311538696, 53.63644368946552, 55.77031418681145, 60.381704941391945, 55.91371089220047, 59.911784157156944, 54.648754969239235, 56.103921085596085, 50.916173458099365, 59.55489210784435, 23.01386408507824, 24.014711380004883, 52.099969536066055, 38.0916678160429, 39.90705080330372, 38.761393278837204, 43.105738162994385, 37.16942310333252, 40.24349994957447, 42.85945437848568, 41.63983382284641, 39.516439363360405, 41.55028022825718, 46.77735194563866, 43.76708887517452, 41.82263821363449, 47.04314008355141, 44.723987728357315, 40.80763667821884, 40.88772118091583, 41.757908686995506, 41.73302382230759, 43.18472072482109, 40.673720464110374, 40.55029548704624, 38.96124355494976, 39.77704077959061, 39.28169175982475, 39.34506095945835, 43.760857209563255, 46.28236770629883, 52.84382902085781, 32.14622564613819, 46.04948580265045, 53.4334509819746, 53.70187997817993, 55.6441305577755, 52.66115002334118, 54.25924926996231, 50.81584744155407, 53.25181692838669, 53.57743665575981, 53.716752380132675, 53.83172281086445, 55.407220870256424, 53.47431778907776, 54.17172096669674, 53.80378670990467, 57.58604675531387, 56.65556788444519, 53.593635186553, 46.415588557720184, 48.68994891643524, 46.11574664711952, 43.74712094664574, 43.16981412470341, 39.62333902716637, 41.15504823625088, 42.7576844394207, 43.87467250227928, 42.88184277713299, 44.28999021649361, 42.12598353624344, 45.40118359029293, 46.929431185126305, 45.691233426332474, 44.8502891510725, 48.3098591119051, 47.35658526420593, 50.18963344395161, 49.80205424129963, 53.11070390045643, 49.31420981884003, 55.066614747047424, 65.89332059025764, 69.20765474438667, 66.18747040629387, 69.84390780329704, 68.31983238458633, 74.84707653522491, 72.98338294029236, 74.79829475283623, 65.36602288484573, 69.23338696360588, 2.011658842675388, 3.5926670813933015, 72.4170233309269, 37.76180371642113, 37.63415336608887, 30.45476920902729, 39.794918820261955, 42.263053581118584, 50.09750738739967, 4.875155501067638, 0.33082256850320846, 0.12188338048872538, 0.03393485094420612, 0.1313058877713047, 0.03320903051644564, 0.043414128813310526, 0.04625469904567581, 0.045841649334761314, 0.07085462726536207, 0.03159368301567156, 0.030080002325121313, 0.034065554282278754, 0.02352229639654979, 0.024047694278124254, 0.07352955755777657, 0.07291285510291345, 0.007905368183855899, 0.017849813084467314, 0.09612920111976564, 0.1345287382719107, 42.180313020944595, 57.22809076309204, 34.1549688577652, 38.87165956199169, 61.02953217923641, 46.692437902092934, 72.9246836900711, 50.36306753754616, 3.6535714007914066, 66.34672746062279, 73.68030354380608, 74.4110955297947, 67.6249560713768, 68.86375799775124, 62.37850159406662, 62.26567044854164, 58.57766434550285, 57.019390761852264, 55.18753185868263, 56.54403246939182, 56.759777292609215, 55.44788248836994, 55.759131386876106, 52.79048748314381, 50.97318559885025, 52.91812643408775, 50.286710634827614, 53.65196965634823, 51.982745826244354, 51.11284710466862, 51.53648257255554, 48.86271044611931, 48.77139374613762, 51.48354761302471, 46.28413841128349, 46.647334322333336, 45.73677018284798, 51.38113930821419, 51.62285573780537, 53.44073139131069, 53.1123948097229, 53.784761130809784, 57.692380249500275, 56.59368060529232, 55.79667717218399, 57.15080291032791, 57.32257269322872, 60.20855963230133, 56.6200777888298, 58.28579820692539, 57.8942634165287, 59.47048723697662, 55.30528374016285, 55.16035571694374, 59.09472920000553, 62.16151803731918, 58.63836608827114, 60.41649967432022, 59.22888480126858, 57.057301327586174, 55.03181241452694, 61.42517074942589, 31.921148523688316, 42.68948569893837, 53.96403171122074, 40.70431262254715, 42.671018689870834, 41.49051323533058, 42.975576147437096, 41.482172682881355, 42.60114423930645, 42.13815048336983, 41.42120495438576, 42.22068965435028, 45.82514964044094, 49.12012003362179, 43.311044946312904, 41.61123275756836, 48.75385008752346, 48.421907499432564, 42.91106320917606, 43.97034376859665, 41.84417545795441, 43.776318579912186, 43.75356540083885, 42.631101831793785, 40.684971660375595, 41.64932191371918, 41.745627745985985, 42.99357958137989, 39.85304810106754, 46.749370247125626, 46.553889736533165, 52.94529117643833, 39.54374089837074, 47.10969351232052, 54.95532251894474, 56.7969810962677, 57.40903705358505, 55.63138984143734, 56.52851030230522, 54.29888874292374, 55.216946080327034, 55.366737842559814, 57.531656473875046, 55.82759611308575, 58.30608531832695, 55.36942429840565, 58.945875987410545, 54.94095169007778, 58.99340383708477, 57.34908767044544, 58.28070268034935, 46.80110067129135, 51.827193573117256, 48.98143507540226, 46.88122317194939, 46.591724306344986, 43.0870545655489, 44.261244758963585, 45.26084192097187, 46.789648085832596, 46.76147639751434, 48.10392916202545, 45.7262409478426, 49.47640411555767, 48.723128736019135, 48.2734152674675, 48.33307586610317, 51.43454164266586, 51.15215219557285, 52.93584868311882, 50.93182481825352, 54.217208325862885, 53.15079174935818, 59.57176700234413, 67.43174403905869, 71.21162921190262, 70.26306331157684, 74.19858053326607, 73.07558879256248, 77.4955952167511, 77.29884937405586, 77.09528669714928, 69.56829339265823, 73.58165323734283, 2.5882978504523635, 4.98565262183547, 79.4124099612236, 42.77644403278828, 44.65253636240959, 41.11268810927868, 45.5428209900856, 44.9592749029398, 63.487149104475975, 6.515399711206555, 0.36653103365097195, 0.17195082240505144, 0.07240423903567716, 0.035604545919341035, 0.08805588862742297, 0.05625395155220758, 0.01184223432574072, 0.0785253469075542, 0.014282144074968528, 0.19310805742861703, 0.10953970573609695, 0.250528275500983, 0.16081592068076134, 0.13636870047776029, 0.23140166042139754, 0.1895278034498915, 0.1391277977381833, 0.2029213574132882, 0.19042274449020624, 0.3210092388326302, 60.687299743294716, 66.62625566124916, 52.16021530330181, 39.26806569099426, 70.66164672374725, 56.69633209705353, 79.73167642951012, 52.662381157279015, 3.8532623229548335, 71.28292858600616, 75.8073990046978, 79.0171779692173, 70.57388663291931, 71.15008771419525, 65.72046786546707, 67.28603705763817, 59.60868962109089, 59.241617918014526, 55.40783263742924, 58.73721018433571, 59.233486354351044, 57.28256084024906, 60.11475786566734, 57.27730192244053, 53.540909215807915, 56.5993233025074, 53.47961090505123, 56.02480933070183, 55.06622716784477, 53.58078047633171, 54.819058030843735, 51.862375885248184, 49.44071643054485, 54.09000255167484, 48.36872175335884, 48.88527363538742, 47.81823769211769, 52.56764464080334, 55.162836983799934, 56.14603042602539, 56.29520662128925, 55.244285613298416, 60.722850635647774, 57.14343510568142, 58.24102520942688, 57.88347579538822, 59.59287106990814, 61.15731172263622, 56.455778405070305, 59.9544482678175, 60.815326273441315, 61.81059546768665, 57.918661907315254, 58.33353504538536, 63.0302008241415, 66.34599030017853, 62.96670623123646, 64.8196730017662, 61.30069322884083, 60.618234649300575, 57.07156576216221, 69.28431183099747, 26.44622180610895, 33.04375268518925, 57.56867788732052, 42.7351326495409, 45.3512504696846, 42.87219889461994, 46.69656068086624, 43.22845637798309, 47.46106445789337, 47.73448258638382, 45.726256147027016, 44.63405415415764, 47.17659652233124, 51.7709755897522, 46.099088340997696, 44.20979931950569, 50.01750648021698, 49.08306062221527, 45.76039731502533, 45.40565215051174, 45.288690626621246, 47.88810454308987, 46.19900397956371, 44.93906378746033, 44.421919137239456, 44.67384181916714, 43.89978915452957, 45.06480664014816, 44.28270600736141, 47.728904485702515, 48.63731034100056, 53.531451523303986, 42.84356743097305, 48.449984192848206, 57.419174909591675, 57.222740650177, 62.51313216984272, 57.958297580480576, 58.890444561839104, 57.617235481739044, 59.46046717464924, 58.227805718779564, 61.67249567806721, 58.451541513204575, 63.04981917142868, 56.70131742954254, 61.16886310279369, 57.296464294195175, 63.69480796158314, 60.2447184920311, 58.55704665184021, 50.15857771039009, 54.51013080775738, 50.2722904086113, 49.268794655799866, 50.1122809946537, 45.43800361454487, 48.25040750205517, 48.82391072809696, 48.11415821313858, 48.91694873571396, 50.17238236963749, 46.76585756242275, 50.454958006739616, 52.518026903271675, 51.82744815945625, 49.99470770359039, 52.41937279701233, 54.767145216464996, 56.36124327778816, 54.45387102663517, 58.39552491903305, 55.89913487434387, 61.41987383365631, 70.85575550794601, 74.46350991725922, 73.0195190012455, 73.35848361253738, 74.75751534104347, 81.23658567667007, 78.86269345879555, 81.59481525421143, 70.00456318259239, 77.89299309253693, 4.149780124425888, 4.59055932238698, 85.10961905121803, 49.396710991859436, 55.976734310388565, 44.624968841671944, 54.985124319791794, 57.24249579012394, 73.56475174427032, 10.43808264657855, 0.4895715188467875, 0.4060386714991182, 0.22915486770216376, 0.239340236003045, 0.20323415781604126, 0.16094391146907583, 0.1585711317602545, 0.27307947166264057, 0.2690203988458961], [0.08808005295577459, 0.044625428854487836, 0.05634454922983423, 0.040868643918656744, 0.03397853746719193, 0.10640380525728688, 0.051706723679671995, 0.07744813439785503, 0.07384893338894472, 0.04748595543787815, 0.01949126562976744, 18.860913030803204, 56.647314727306366, 45.5983018130064, 27.34224982559681, 41.49890698492527, 50.11323094367981, 62.811252772808075, 54.826741218566895, 3.8899291679263115, 55.997484996914864, 71.58305928111076, 70.07076323032379, 64.86767962574959, 61.727030351758, 56.06401562690735, 54.47230763733387, 52.82104164361954, 53.74761052429676, 49.98614676296711, 54.78593520820141, 53.43485310673714, 51.412126645445824, 49.08529870212078, 49.700117111206055, 48.45157250761986, 49.2529571056366, 54.0593533962965, 57.18380033969879, 53.669167533516884, 52.971293181180954, 47.62638978660107, 47.32075698673725, 45.09710110723972, 48.9729805290699, 46.576931700110435, 41.97137363255024, 39.60836783051491, 45.20476832985878, 50.726567432284355, 49.996630400419235, 49.85429383814335, 54.05479744076729, 54.34527665376663, 54.32928331196308, 52.079123854637146, 55.85597299039364, 55.58685623109341, 56.17913044989109, 54.19448174536228, 55.64213186502457, 53.27859789133072, 57.44301103055477, 54.49216537177563, 55.444462671875954, 55.69168120622635, 59.49892111122608, 57.59762853384018, 56.14116668701172, 55.562244951725006, 55.33657506108284, 50.76474778354168, 58.329894840717316, 30.344335734844208, 18.425245508551598, 52.0258355140686, 38.58925111591816, 40.833840072155, 37.40906484425068, 41.43703490495682, 39.68902230262756, 41.49064242839813, 40.41454017162323, 39.20261800289154, 39.77379195392132, 43.55971500277519, 42.96058215200901, 40.84169425070286, 37.97301158308983, 43.373266607522964, 45.81786923110485, 44.891691729426384, 45.996186062693596, 41.16877689957619, 38.18683750927448, 36.97398439049721, 42.115921676158905, 42.04162806272507, 38.13086271286011, 40.40297359228134, 37.54334583878517, 48.00673417747021, 43.68923865258694, 47.46682494878769, 43.306637182831764, 35.953457951545715, 54.07586731016636, 52.457872331142426, 56.93312779068947, 52.22332611680031, 56.039297953248024, 53.73700149357319, 54.207553043961525, 50.45652352273464, 53.07031586766243, 53.824138417840004, 54.30249474942684, 52.95161023736, 54.01595592498779, 53.236800134181976, 56.590040400624275, 54.68627795577049, 58.357462361454964, 52.06975355744362, 41.48269705474377, 47.70504556596279, 48.34333911538124, 42.20434673130512, 44.42356064915657, 39.60483402013779, 40.1492840051651, 42.983103543519974, 44.279005005955696, 42.03058585524559, 43.24701838195324, 42.9072330147028, 44.98437635600567, 43.14432509243488, 44.226951599121094, 44.68192398548126, 47.18138046562672, 47.65428029000759, 49.41873840987682, 48.89398656785488, 51.77132897078991, 50.408144518733025, 53.47505874931812, 59.766753539443016, 70.48022165894508, 67.58136481046677, 65.75475722551346, 72.17779576778412, 74.51350763440132, 69.84443977475166, 73.41716766357422, 64.8633174598217, 65.35376474261284, 0.6418183946516365, 10.284369494765997, 70.32203614711761, 36.32839523255825, 41.35661222040653, 32.17104971408844, 42.66669072210789, 41.3095897436142, 55.25486424565315, 3.145443666726351, 0.2393495276919566, 0.11559852515347302, 0.04083043815626297, 0.04914539764286019, 0.034462491967133246, 0.036774226318812, 0.0563457069802098, 0.03527674300130457, 0.024466768372803926, 0.023756880000291858, 0.08779253010288812, 0.10115451310412027, 0.027880653251486365, 0.015497861750191078, 0.06559553876286373, 0.02956691667350242, 0.05464958412630949, 0.08342827131855302, 0.05213314318098128, 0.08538296213373542, 21.62531029433012, 66.76826164126396, 44.895628318190575, 37.39291951060295, 53.80256697535515, 52.61744096875191, 66.85415983200073, 63.4934301674366, 4.210254829376936, 59.11855772137642, 77.5292158126831, 74.85682681202888, 70.36546781659126, 65.28802827000618, 61.84626415371895, 58.5120190680027, 57.91816793382168, 57.577823996543884, 56.12036280333996, 57.98608548939228, 58.47663536667824, 54.619203954935074, 55.0307484716177, 53.05786773562431, 50.674130246043205, 52.958636060357094, 56.26424968242645, 58.26141111552715, 56.25424101948738, 54.935954958200455, 51.47996060550213, 49.03961755335331, 48.53724651038647, 50.3831722587347, 49.40402939915657, 45.15283651649952, 43.40961165726185, 48.485166504979134, 51.54649503529072, 53.15212547779083, 50.75041875243187, 57.49033749103546, 57.12570145726204, 56.35289892554283, 55.88288314640522, 57.5225255638361, 57.41449736058712, 59.12037782371044, 59.22798044979572, 57.56287939846516, 56.46435834467411, 60.944382548332214, 56.95557698607445, 58.4708558768034, 59.49305422604084, 62.45537906885147, 58.178807348012924, 58.911001458764076, 58.6033471673727, 59.12605471909046, 54.4382044672966, 62.02379062771797, 38.65124858915806, 34.50539365410805, 53.50352302193642, 42.16086566448212, 43.05306538939476, 40.46408951282501, 42.90459595620632, 40.267788246273994, 42.87610128521919, 43.005837723612785, 40.9390564262867, 42.34533816576004, 45.597602650523186, 43.96150544285774, 42.25368328392506, 39.18343283236027, 44.85381916165352, 46.29139982163906, 47.74541459977627, 46.55154146254063, 43.56078274548054, 41.49033464491367, 39.559418857097626, 42.36599385738373, 42.25388087332249, 40.07509298622608, 41.818705424666405, 38.33399221301079, 48.259922191500664, 43.10404345393181, 46.50090157985687, 48.523833230137825, 41.9969766587019, 54.68621715903282, 56.32754288613796, 58.97312052547932, 55.13680078089237, 58.50483365356922, 58.017217218875885, 57.05402970314026, 53.62361557781696, 54.20870818197727, 57.80289351940155, 56.539214327931404, 57.03293703496456, 57.502937614917755, 56.3602477312088, 58.51581126451492, 58.56674373149872, 61.02828584611416, 53.20322893559933, 44.61553394794464, 51.43794625997543, 50.561401695013046, 47.26554594933987, 46.96900986135006, 42.651468738913536, 42.99995943903923, 45.59700608253479, 47.78146706521511, 45.26591844856739, 47.195185124874115, 47.04410523176193, 48.12856324017048, 47.27135203778744, 48.30330066382885, 47.76566371321678, 48.64802956581116, 51.062294617295265, 52.1430554240942, 51.0306803137064, 54.67101037502289, 52.01127469539642, 55.74350282549858, 63.646869733929634, 73.39486286044121, 72.62013003230095, 70.72663083672523, 74.36738267540932, 75.23871392011642, 74.33519840240479, 77.63773798942566, 69.21188771724701, 68.70072394609451, 0.4775423143291846, 13.251059353351593, 79.59235310554504, 39.52248103916645, 52.70754173398018, 35.83427354693413, 42.71973967552185, 48.991215750575066, 64.59502905607224, 2.627142216078937, 0.1619809737894684, 0.02599849995021941, 0.01838197378674522, 0.12400778563460335, 0.0494951458676951, 0.05322098695614841, 0.10277297391439788, 0.041846768581308424, 0.01767164754710393, 0.1572604989632964, 0.15703092300100252, 0.3316248598275706, 0.14915727049810812, 0.10881326932576485, 0.18005354620981961, 0.13355238363146782, 0.16496789554366842, 0.28018090466503054, 0.26736914995126426, 0.4403150291182101, 33.3765160292387, 78.41759294271469, 61.96172475814819, 38.861989080905914, 59.361163303256035, 65.19677236676216, 75.80106094479561, 65.34055665135384, 5.182534782215953, 65.58467075228691, 78.97363230586052, 79.64106649160385, 73.31679224967957, 67.32279628515244, 62.463795617222786, 59.46394398808479, 59.793686494231224, 58.134851306676865, 56.46959066390991, 59.92344193160534, 61.378030478954315, 57.437953501939774, 57.69953526556492, 55.99384859204292, 53.3157104998827, 55.454136952757835, 59.3397818505764, 60.8716506510973, 58.532104790210724, 57.81470328569412, 54.57679063081741, 50.56658461689949, 49.556226432323456, 53.256213292479515, 50.08729353547096, 47.73794800043106, 45.04497930407524, 50.12264683842659, 54.97994899749756, 56.75560511648655, 54.98455435037613, 58.32414574921131, 58.613663613796234, 58.76443192362785, 58.25932502746582, 59.80261221528053, 59.711648896336555, 61.144707798957825, 59.478352814912796, 59.25980754196644, 59.11455653607845, 63.880629390478134, 58.30170035362244, 62.007561698555946, 60.52960820496082, 68.86708661913872, 61.81860163807869, 60.406745597720146, 59.71182368695736, 61.61631189286709, 55.4730561375618, 67.43106007575989, 35.73363594710827, 25.790430195629597, 58.049272298812866, 43.428979218006134, 47.58780665695667, 41.71101160347462, 48.34306173026562, 44.105973690748215, 47.530885711312294, 44.526896104216576, 43.57621371746063, 45.35620920360088, 47.39159278571606, 45.921451672911644, 42.40063659846783, 38.771614730358124, 46.21646024286747, 48.58702003955841, 48.33285927772522, 48.622217550873756, 46.430905535817146, 44.0723492950201, 44.334846809506416, 45.405937135219574, 45.641524493694305, 42.96690881252289, 45.77139012515545, 41.702579855918884, 50.72284743189812, 47.95786499977112, 50.355809926986694, 48.59973415732384, 42.75629371404648, 56.83227740228176, 58.95412154495716, 61.354688331484795, 57.76911713182926, 61.8512798845768, 61.25700317323208, 57.11771048605442, 57.97774873673916, 59.104620069265366, 60.043097510933876, 58.763413578271866, 60.455348789691925, 60.981616750359535, 58.52722205221653, 61.492396742105484, 61.13377958536148, 63.98565575480461, 56.93962924182415, 43.711087480187416, 52.869420647621155, 52.64723137021065, 50.911970883607864, 51.26010820269585, 44.1430900990963, 45.728406831622124, 48.32562446594238, 49.674134105443954, 46.13060764968395, 49.1526310890913, 48.8968326151371, 51.993936225771904, 50.1627878844738, 49.83009293675423, 50.29013805091381, 52.29701556265354, 55.511358082294464, 56.72997549176216, 54.930080473423004, 59.228341430425644, 53.23308773338795, 58.52121837437153, 66.29961758852005, 77.72409975528717, 74.16380479931831, 72.93330162763596, 76.543670296669, 77.71741971373558, 77.14754149317741, 79.18129876255989, 70.15150889754295, 72.43217691779137, 1.436397973448038, 12.814413383603096, 85.42617246508598, 48.432550728321075, 61.917297542095184, 47.379741221666336, 61.96771323680878, 54.695617854595184, 81.5106725692749, 5.446761203929782, 0.40987293294165283, 0.2290415862808004, 0.0673665851354599, 0.18414227524772286, 0.24112447776133195, 0.2146207366604358, 0.14603412011638284, 0.10850974576896988, 0.15214463754091412], [0.06180203978146892, 0.015200486886897124, 0.045928087274660356, 0.018137719998776447, 0.03467257170996163, 0.029852695479348768, 0.07783479333738796, 0.053864725850871764, 0.04747670085635036, 0.08910235395887867, 0.1697607000824064, 9.094813875854015, 60.74064888060093, 36.195767149329185, 38.535867780447006, 31.777350939810276, 43.638222590088844, 48.37175019085407, 71.69486448168755, 6.95628815330565, 42.929860800504684, 76.9968643784523, 61.40950419008732, 70.50593867897987, 63.983353078365326, 62.80753657221794, 59.19144921004772, 56.239854991436005, 54.78254199028015, 54.15520705282688, 55.33776819705963, 53.130842819809914, 54.528008848428726, 51.96345426142216, 51.68092042207718, 51.431687995791435, 53.38230572640896, 57.9589207470417, 59.26505886018276, 57.84562222659588, 54.793401807546616, 49.43484954535961, 46.51039347052574, 45.518642887473106, 49.16644714772701, 47.739220932126045, 43.695272728800774, 40.706607699394226, 44.089843556284904, 48.74568432569504, 48.36548052728176, 50.44766999781132, 50.840584114193916, 51.693246960639954, 54.31191064417362, 49.833212569355965, 52.40395322442055, 53.20533022284508, 53.7125688046217, 54.775196984410286, 55.45167848467827, 55.74168652296066, 58.23471374809742, 54.278529435396194, 54.43397909402847, 57.062404453754425, 60.282636657357216, 58.03574502468109, 57.05287456512451, 54.280889108777046, 54.24911521375179, 50.96731871366501, 55.32245121896267, 35.471241027116776, 19.124953262507915, 46.424670070409775, 43.93784411251545, 40.488514602184296, 40.81938564777374, 40.53045675158501, 37.37860567867756, 39.398334100842476, 40.29951274394989, 40.31311981379986, 38.904026225209236, 39.34842377901077, 39.74313519895077, 42.074177116155624, 41.47467568516731, 44.49649013578892, 44.867141246795654, 45.59809662401676, 42.03716330230236, 41.72065168619156, 39.01694856584072, 42.036695927381516, 37.41095334291458, 42.41175480186939, 41.00555285811424, 43.516636714339256, 45.496611669659615, 42.73792549967766, 35.87124176323414, 51.79247483611107, 45.2670431882143, 42.0375394821167, 55.315828174352646, 53.2596331089735, 52.72768825292587, 55.362520068883896, 54.18461747467518, 56.3575004786253, 55.943026319146156, 53.20002570748329, 52.04781353473663, 54.622103199362755, 55.19283637404442, 55.074769109487534, 52.27765180170536, 56.12590290606022, 56.78768299520016, 57.28686220943928, 57.82498553395271, 46.3696376234293, 42.138766050338745, 48.24694588780403, 47.804022654891014, 41.78279735147953, 41.94606699049473, 39.50587213039398, 39.76290933787823, 43.94130952656269, 45.31599596142769, 44.20632630586624, 43.39137643575668, 44.19664062559605, 45.01137010753155, 44.735668301582336, 46.069100350141525, 43.949262499809265, 45.8961184322834, 46.51076965034008, 47.62801989912987, 50.05610480904579, 50.374873504042625, 50.74526622891426, 49.70657676458359, 58.612926453351974, 69.54981118440628, 67.90372431278229, 69.06352087855339, 68.83209809660912, 77.2094401717186, 69.95230078697205, 76.74540907144547, 67.22733780741692, 61.108142361044884, 0.09729542682180181, 22.102885767817497, 71.01752042770386, 40.38195312023163, 33.39478924870491, 50.680878683924675, 57.43881605565548, 43.425806388258934, 43.596143648028374, 0.474778437637724, 0.15468227793462574, 0.07255255724885501, 0.06603255242225714, 0.03542907252267469, 0.05721651337807998, 0.05785293098597322, 0.02165537382097682, 0.019686797422764357, 0.117421314062085, 0.11836582314572297, 0.05504781685885973, 0.07947569669340737, 0.06180011390824802, 0.03129805962089449, 0.01869122301286552, 0.06718109274515882, 0.026764244212245103, 0.018977367326442618, 0.020343737269286066, 0.3680368512868881, 11.315768100321293, 72.26652100682259, 36.33766293525696, 40.08421629667282, 38.93913634121418, 50.642512142658234, 53.78212407231331, 81.40904322266579, 9.601608831435442, 41.968865767121315, 83.58125746250153, 67.14669853448868, 77.98682525753975, 68.29934388399124, 68.77808779478073, 62.22331032156944, 60.689081847667694, 59.7978700697422, 60.58255456387997, 58.2198641449213, 56.53931312263012, 56.8885637819767, 54.6253976225853, 54.20156076550484, 54.790897741913795, 57.12691739201546, 60.7849545031786, 61.26208730041981, 61.11334428191185, 56.53668366372585, 54.31392453610897, 51.08354687690735, 48.35818871855736, 50.32713286578655, 50.136113315820694, 47.0502495020628, 43.328109830617905, 45.34895159304142, 50.71049049496651, 50.71179762482643, 54.0981151163578, 54.7524856030941, 54.939959943294525, 56.53970070183277, 52.91662931442261, 54.486762061715126, 55.72392247617245, 57.22741819918156, 58.32467392086983, 56.36140666902065, 59.59034040570259, 58.86699602007866, 56.88109718263149, 56.88039802014828, 58.88719193637371, 62.58589066565037, 59.919930920004845, 59.213499426841736, 57.07253850996494, 57.754472717642784, 52.29036211967468, 60.333838909864426, 43.059209659695625, 33.101110607385635, 51.60745516419411, 44.1325456649065, 43.32958035171032, 42.42842450737953, 43.97068195044994, 40.1509103178978, 40.83480142056942, 42.33170069754124, 42.19032168388367, 43.74127306044102, 42.07245580852032, 40.307602509856224, 40.47090254724026, 40.815760642290115, 46.667914018034935, 44.90773066878319, 44.7750835865736, 47.244738265872, 43.817880749702454, 39.97161313891411, 44.004777520895004, 38.239825665950775, 41.1162219196558, 44.44500669836998, 46.900001764297485, 47.922488898038864, 41.42164193093777, 36.60770684480667, 54.699964821338654, 56.43974706530571, 46.82627812027931, 57.17987135052681, 56.07878543436527, 55.13636380434036, 57.67710506916046, 60.758310332894325, 58.29533949494362, 56.32273234426975, 55.995110124349594, 56.283503249287605, 56.53424419462681, 59.6729251742363, 58.261422514915466, 57.9614894092083, 59.218104779720306, 57.610547840595245, 61.04055158793926, 61.62483863532543, 47.65022970736027, 42.92230300605297, 51.63052752614021, 49.45409931242466, 45.68956531584263, 47.58619174361229, 40.8538194000721, 43.876329213380814, 48.13481770455837, 48.4614709764719, 48.747363835573196, 46.85710206627846, 48.70463512837887, 49.399598836898804, 48.62523838877678, 48.82742553949356, 47.08588398993015, 50.83473242819309, 50.23110821843147, 50.672655925154686, 52.19413608312607, 53.92618954181671, 52.64013335108757, 54.66396555304527, 58.89118932187557, 72.38416269421577, 72.51055911183357, 74.44670721888542, 71.29103735089302, 78.47183883190155, 73.47850397229195, 79.31640431284904, 70.70607393980026, 63.59168529510498, 0.12539293005829677, 26.39615949243307, 76.91237211227417, 47.421603575348854, 42.739722803235054, 47.9313538223505, 60.18547207117081, 48.91552001237869, 55.670892521739006, 2.414506101049483, 0.1312227820744738, 0.06953942283871584, 0.0626140643726103, 0.043576714815571904, 0.02095380306855077, 0.05625300531391986, 0.04500658476899844, 0.13197000604122877, 0.027018205291824415, 0.28763280948624015, 0.13100128067890182, 0.2873589569935575, 0.19191686587873846, 0.10549777653068304, 0.11623669794062153, 0.15163409931119531, 0.202969032980036, 0.12740900390781462, 0.27425755688454956, 0.8199480862822384, 16.47909063845873, 82.77140691876411, 50.17397068440914, 53.03671047091484, 44.09851089119911, 58.00346955657005, 59.7851787507534, 85.61024218797684, 10.290242079645395, 48.960653990507126, 84.31574285030365, 69.18595030903816, 78.41127768158913, 70.87609201669693, 69.65355321764946, 64.9854277074337, 61.055268198251724, 62.09295071661472, 60.84362335503101, 59.825448989868164, 57.83139958977699, 59.55174967646599, 57.85082794725895, 57.30380170047283, 55.312320962548256, 58.18498581647873, 61.72138765454292, 63.39864805340767, 64.12969082593918, 57.745110020041466, 55.55969528853893, 52.093091905117035, 50.559847578406334, 52.331061735749245, 52.43407040834427, 49.66550476849079, 45.84302008152008, 49.71289202570915, 54.629083424806595, 52.58985444903374, 57.3286409676075, 58.566500544548035, 56.40763878822327, 58.50453346967697, 54.788127690553665, 58.0645664781332, 58.04848954081535, 59.101644828915596, 59.06775824725628, 58.88751871883869, 62.342498525977135, 63.325669169425964, 59.129603728652, 59.597168639302254, 61.15263417363167, 66.4601057767868, 63.81258264183998, 62.6162738353014, 61.20004042983055, 61.137856766581535, 54.92875814437866, 66.20210722088814, 41.40293553471565, 25.490041114389896, 54.370446503162384, 45.333281233906746, 44.64989550411701, 45.86939066648483, 46.85115538537502, 42.554592937231064, 44.24580618739128, 45.80994285643101, 45.61131231486797, 46.0231988132, 41.91287197172642, 42.72274151444435, 41.08842261135578, 41.87768965959549, 48.25423389673233, 47.95322924852371, 46.19566775858402, 49.13477584719658, 47.737488225102425, 44.40029829740524, 47.028586864471436, 40.34024275839329, 46.80506005883217, 47.62628719210625, 48.449425622820854, 52.92658098042011, 47.652809768915176, 39.712315052747726, 50.837076902389526, 48.61457236111164, 48.33228550851345, 60.24501487612724, 58.44687916338444, 56.561511531472206, 59.425718039274216, 62.3323530703783, 62.371962144970894, 61.51978187263012, 59.10792589187622, 60.646284744143486, 59.54033888876438, 61.39868997037411, 57.84815289080143, 58.78172479569912, 62.434605583548546, 62.633927688002586, 64.77371826767921, 63.352792114019394, 48.77624988555908, 41.861814111471176, 55.229439809918404, 51.568864434957504, 48.40944416821003, 49.51056808233261, 43.29122520983219, 47.15785212814808, 50.48033684492111, 51.60467371344566, 51.32906690239906, 48.5312732309103, 49.917248860001564, 51.73972226679325, 51.73593007028103, 50.59056133031845, 48.57767254114151, 53.9838932454586, 52.76234619319439, 54.987852573394775, 57.54904814064503, 57.85408057272434, 56.32609136402607, 56.97579190135002, 63.1400453299284, 77.13888555765152, 75.83267524838448, 76.78675085306168, 76.71138569712639, 81.70473575592041, 75.74270367622375, 83.66461738944054, 70.11072188615799, 69.83711376786232, 0.5112613784149289, 25.733993723988533, 87.15479850769043, 53.39166462421417, 47.95499235391617, 68.59224736690521, 74.89869296550751, 56.97073817253113, 73.48825424909592, 2.8386868396773934, 0.3546754323178902, 0.2137044514529407, 0.10401150706456974, 0.109102899878053, 0.03819065597781446, 0.14318786503281444, 0.12199007163872011, 0.22070888575399294, 0.14126073016086593], [0.015179618621914415, 0.06778976516216062, 0.051653890186571516, 0.04904184948827606, 0.06234965199837461, 0.05295327944622841, 0.028621134806599002, 0.03224020496418234, 0.04724631224235054, 0.10176577561651357, 0.15164451906457543, 5.906394990161061, 58.46585914492607, 42.04086810350418, 38.7122543156147, 28.432540521025658, 45.36447376012802, 45.99409997463226, 84.77015286684036, 15.288536623120308, 21.27612993121147, 82.50555038452148, 65.74768960475922, 72.7397096157074, 67.39071384072304, 67.28359758853912, 61.704299971461296, 61.244429647922516, 56.299367398023605, 57.58348189294338, 57.663714587688446, 54.27667513489723, 51.265192329883575, 51.9441094994545, 52.923966720700264, 51.757942289114, 57.50585585832596, 60.6793999671936, 57.82832935452461, 60.35272389650345, 55.2291776239872, 49.195990562438965, 45.32483048737049, 43.776265382766724, 48.2085869461298, 49.46293003857136, 44.50987681746483, 42.634609043598175, 43.842518627643585, 48.28743651509285, 50.2933032810688, 47.763706818223, 50.054341703653336, 55.56538738310337, 51.08802683651447, 51.219913959503174, 50.06742440164089, 54.805990532040596, 53.882518485188484, 54.8871123790741, 56.355080008506775, 55.822363793849945, 56.632556319236755, 55.945040211081505, 56.27908028662205, 58.15379709005356, 60.38615070283413, 56.40641525387764, 55.351063683629036, 53.44728223979473, 53.58546182513237, 50.37075452506542, 53.18319261074066, 41.35258063673973, 22.70544223487377, 43.05702477693558, 45.582441464066505, 43.32700029015541, 37.21579201519489, 38.25439788401127, 37.886904403567314, 40.42133800685406, 39.7837208211422, 39.80261340737343, 40.704438015818596, 41.71944335103035, 38.63491706550121, 41.32858872413635, 44.95175130665302, 37.97947123646736, 45.68683706223965, 42.57798448204994, 49.129524528980255, 45.5127190053463, 36.991243064403534, 40.71602739393711, 39.665965139865875, 44.145179986953735, 42.04428791999817, 48.26402597129345, 39.77507248520851, 39.3010251224041, 41.75689034163952, 54.276291355490685, 34.762974232435226, 47.54617229104042, 56.69551134109497, 55.46015202999115, 54.59596820175648, 53.98336127400398, 57.300074100494385, 59.925615414977074, 57.219716012477875, 54.02189500629902, 50.87706595659256, 54.8929450660944, 52.35686235129833, 53.62129770219326, 53.14831428229809, 56.35463543236256, 56.12876795232296, 54.76628266274929, 54.75537724792957, 48.28942760825157, 44.73783418536186, 49.32278595864773, 48.64817775785923, 42.151594161987305, 40.486987084150314, 40.30310355126858, 41.74647130072117, 41.28999799489975, 43.8141455501318, 44.19803135097027, 44.55869659781456, 45.60819648206234, 44.0515948086977, 43.33379812538624, 47.29411281645298, 46.94524213671684, 48.559437319636345, 48.90135817229748, 47.902338579297066, 49.091089591383934, 49.375907108187675, 48.1742861866951, 51.6923464089632, 54.53704476356506, 66.75724223256111, 66.26847445964813, 71.93468481302261, 69.1368417441845, 70.80664694309235, 73.45251336693764, 70.26829943060875, 75.49266189336777, 44.63097631931305, 0.17553846817463636, 34.221149906516075, 67.30753630399704, 39.79904539883137, 34.425514340400696, 68.83043378591537, 41.41633741557598, 34.57997985184193, 53.41007463634014, 2.7291731536388397, 0.0357607383193681, 0.1392890515853651, 0.22072602936532348, 0.09646937935031019, 0.11560085549717769, 0.05933211294177454, 0.04063745007442776, 0.03616932772274595, 0.19783602794632316, 0.0713119089778047, 0.06774787834729068, 0.021302937166183256, 0.047675165988039225, 0.07453990256180987, 0.04600278443831485, 0.014905043462931644, 0.04391172027681023, 0.04092328825208824, 0.008862787854013732, 0.07054017187329009, 5.66846220754087, 68.86009499430656, 43.7433173507452, 40.58697111904621, 32.692400738596916, 50.24678237736225, 52.09104001522064, 91.74331828951836, 19.704329073429108, 20.300587378442287, 85.8761215209961, 69.36729937791824, 78.06554943323135, 72.27640807628632, 72.10306897759438, 66.05426475405693, 64.18265238404274, 59.809885025024414, 59.14228364825249, 57.77306132018566, 58.831543922424316, 55.647094398736954, 54.07335564494133, 54.12892386317253, 54.844911843538284, 59.20126408338547, 64.54911231994629, 61.109764873981476, 63.37661683559418, 58.74653868377209, 52.816519886255264, 50.39196118712425, 45.870747193694115, 50.141585022211075, 50.87190203368664, 47.78873607516289, 44.87998075783253, 46.43539309501648, 48.40228535234928, 53.13051603734493, 51.92163750529289, 53.82818140089512, 55.36491014063358, 53.83275255560875, 52.568499594926834, 52.37522296607494, 58.216702714562416, 56.636800691485405, 58.177640810608864, 56.3194265216589, 59.136880338191986, 60.459653958678246, 56.98748007416725, 60.85375361144543, 59.212674871087074, 60.65345115959644, 58.94852064549923, 58.41369554400444, 56.59342981874943, 58.616794645786285, 53.39129984378815, 60.30991159379482, 46.29904121160507, 33.45677152276039, 49.822915121912956, 44.62787568569183, 46.89604237675667, 41.197415962815285, 41.777245849370956, 39.719378873705864, 41.86327703297138, 41.79253242909908, 44.11038525402546, 40.922914892435074, 43.89099642634392, 40.2602456510067, 39.08161349594593, 44.73275005817413, 40.51579333841801, 46.462941616773605, 43.74812409281731, 45.80445975065231, 48.63731034100056, 41.80164813995361, 40.78272141516209, 40.35139515995979, 46.793721467256546, 42.3832069337368, 50.280649960041046, 38.58523093163967, 42.53729246556759, 40.26268132030964, 63.83604258298874, 46.44730545580387, 46.301324889063835, 57.6918026804924, 56.976396068930626, 55.9759097546339, 56.41784884035587, 61.78117744624615, 57.99492001533508, 59.871027544140816, 57.068544924259186, 56.19391165673733, 56.67751170694828, 58.27224053442478, 57.76856616139412, 58.212534338235855, 55.53408086299896, 59.43524792790413, 56.56885273754597, 59.7313242405653, 49.26467567682266, 46.65080353617668, 51.49628832936287, 50.39858043193817, 46.692000925540924, 43.60702246427536, 43.0656199157238, 45.251559019088745, 47.11994156241417, 47.0939015597105, 45.78684389591217, 47.91457772254944, 48.7067212164402, 49.27453234791756, 49.472326934337616, 49.464746341109276, 49.814544171094894, 49.19434905052185, 53.02292101085186, 50.260412245988846, 51.486997827887535, 52.77937687933445, 51.59199379384518, 54.08358469605446, 56.64284996688366, 69.96447533369064, 71.17147296667099, 72.35119566321373, 72.46243089437485, 76.06421962380409, 74.13307964801788, 75.22391751408577, 76.65110573172569, 48.86768817901611, 0.30811127624474466, 40.59384874999523, 71.59419268369675, 48.23597967624664, 37.703431248664856, 72.22064226865768, 51.8835711479187, 43.25158953666687, 68.21846902370453, 3.352693095803261, 0.16954169230302796, 0.021014570120314602, 0.07237558471388184, 0.02816592183080502, 0.0886835451819934, 0.019546102921594866, 0.019347409579495434, 0.06655388147919439, 0.12629938923055306, 0.11677767164655961, 0.36888221686240286, 0.10838790738489479, 0.14237298688385636, 0.26187799929175526, 0.19405711587751284, 0.16563844081247225, 0.16111436794744805, 0.14471596194198355, 0.21667127584805712, 0.3495010599726811, 10.331871695816517, 82.11689963936806, 56.81343801319599, 57.52137042582035, 41.19813792407513, 59.49792556464672, 57.912042662501335, 98.10962587594986, 18.774387873709202, 27.577136121690273, 89.93734359741211, 72.783612459898, 80.15818074345589, 74.01619791984558, 73.80464807152748, 67.36560478806496, 66.07067987322807, 63.64814266562462, 61.58616431057453, 62.273418232798576, 61.01550333201885, 57.506418228149414, 57.88773916661739, 57.46449887752533, 57.02579341828823, 60.43835610151291, 68.07811975479126, 63.62132750451565, 64.8504589498043, 59.81222189962864, 53.638039603829384, 51.0655852407217, 46.760887429118156, 52.143120020627975, 53.00793841481209, 52.61158548295498, 49.14075292646885, 49.05972607433796, 52.34153397381306, 54.8217710852623, 54.731043353676796, 56.445822939276695, 59.08056356012821, 55.547862723469734, 54.81070227921009, 55.52303485572338, 59.86309736967087, 58.56886401772499, 60.480267852544785, 59.84617307782173, 61.79958365857601, 64.15533944964409, 58.90711046755314, 63.0410910397768, 60.89773245155811, 66.33664280176163, 63.369875997304916, 62.082208693027496, 59.23045791685581, 59.36017535626888, 54.43579539656639, 62.586882412433624, 47.35842436552048, 27.789903804659843, 50.988749563694, 47.54556432366371, 51.072789654135704, 44.35372419655323, 45.20533449947834, 42.975978925824165, 45.31393647193909, 45.802875235676765, 46.25751703977585, 44.284089133143425, 45.773658603429794, 39.35937099158764, 40.923602655529976, 43.97752918303013, 38.8421693444252, 46.45142063498497, 44.424757584929466, 48.20926330983639, 47.2786058485508, 42.60503143072128, 46.22759744524956, 45.25296114385128, 49.54901061952114, 45.121541395783424, 51.144932582974434, 44.36972513794899, 44.40865784883499, 43.542737513780594, 51.09727934002876, 43.28580290079117, 48.97080324590206, 61.65812864899635, 60.84749534726143, 59.21121194958687, 59.65632386505604, 64.42105919122696, 63.62834572792053, 62.11271345615387, 59.59003262221813, 56.07175201177597, 58.7218552082777, 59.11602705717087, 58.1534019112587, 58.86576108634472, 58.797189965844154, 62.12773784995079, 60.48942916095257, 61.553068086504936, 50.331088453531265, 47.11805306375027, 55.85678234696388, 54.7745206207037, 47.66115792095661, 46.38611353933811, 47.71636515855789, 47.28278562426567, 48.99226449429989, 50.48220254480839, 47.77929738163948, 51.15756310522556, 50.3032511472702, 52.57172182202339, 50.863246098160744, 53.30642379820347, 51.884372904896736, 52.770033180713654, 54.82066534459591, 53.17420229315758, 56.544857025146484, 55.77886752784252, 55.865214094519615, 56.40273705124855, 60.19948571920395, 75.76883867383003, 73.93490508198738, 75.64748838543892, 74.47493210434914, 82.33629986643791, 76.26254618167877, 77.63884752988815, 77.4101074039936, 53.20796348154545, 0.43463106849230826, 39.46179449558258, 80.71636319160461, 53.41678887605667, 48.97021807730198, 80.84367915987968, 53.841093108057976, 49.52439174056053, 80.41078358888626, 4.700365355238318, 0.42691902606748044, 0.21991370420437306, 0.19403630605665967, 0.1071926488657482, 0.16925957228522748, 0.12291141829336993, 0.15818454703548923, 0.15291004412574694, 0.30642639321740717], [0.040144088852684945, 0.04784455006301869, 0.04856431085499935, 0.09313894712249748, 0.09532469819532707, 0.11304057217785157, 0.01786133121640887, 0.0113666456854844, 0.14536376780597493, 0.05496833284269087, 0.05218255166255403, 2.318585948087275, 49.9324594438076, 49.6944136172533, 36.74814350903034, 35.58251425623894, 38.512772619724274, 34.63239423930645, 74.91836071014404, 31.028897501528263, 6.459449138492346, 69.43213149905205, 62.800206765532494, 74.47716638445854, 70.76243251562119, 68.91174182295799, 62.057468220591545, 61.94540463387966, 58.43888059258461, 59.13985937833786, 54.33110721409321, 53.63892875611782, 52.331266924738884, 50.20757608115673, 52.24531553685665, 57.79390700161457, 59.16221737861633, 56.55441351234913, 59.612383022904396, 59.32130344212055, 51.64512634277344, 45.79153284430504, 42.31294870376587, 44.65681493282318, 46.8543966114521, 49.20017033815384, 46.314692571759224, 43.97562928497791, 43.02078612148762, 44.26165513694286, 45.69049246609211, 48.11076119542122, 50.05608581006527, 52.175387889146805, 49.78944271802902, 51.15634337067604, 49.24924850463867, 50.5412969738245, 56.15363381803036, 55.08085638284683, 57.05514304339886, 56.23433008790016, 59.800187945365906, 56.49052754044533, 54.61513817310333, 59.2612324655056, 57.666355445981026, 56.62606246769428, 53.131864964962006, 50.02023093402386, 51.23016960918903, 52.061063423752785, 52.15938314795494, 47.49900162220001, 29.75712474435568, 43.75714100897312, 41.030483320355415, 42.307028621435165, 40.02031892538071, 39.69075880944729, 38.13298299908638, 40.56087791919708, 38.33686105906963, 40.49424469470978, 44.97897304594517, 36.29779167473316, 36.78950048983097, 47.398580610752106, 49.681038334965706, 55.96259526908398, 59.67376872897148, 60.558087676763535, 38.456683829426765, 38.06349232792854, 53.64573039114475, 47.953670024871826, 47.656385377049446, 40.440048202872276, 40.15407934784889, 42.72127479314804, 46.08936466276646, 36.423386335372925, 56.4418825507164, 51.68405145406723, 28.510176055133343, 54.34725634753704, 51.79442033171654, 54.89814318716526, 52.226658537983894, 52.002622559666634, 57.94720597565174, 58.69761250913143, 55.509910359978676, 53.59791375696659, 54.75238300859928, 53.494585901498795, 53.679886758327484, 54.3154064565897, 52.77591146528721, 52.44825504720211, 51.67124234139919, 55.12366108596325, 56.234615072607994, 49.2998655885458, 49.669384360313416, 48.27894017100334, 42.78674528002739, 43.24119329452515, 41.460966020822525, 41.02689631283283, 43.06833676993847, 43.67506921291351, 42.69061043858528, 44.30791765451431, 44.421702548861504, 45.028313398361206, 44.34116207063198, 45.30529573559761, 45.30617728829384, 48.60900565981865, 49.34251829981804, 49.73256357014179, 49.17102590203285, 51.10446095466614, 49.47830021381378, 48.64162690937519, 53.41611251235008, 53.55542063713074, 56.9897523522377, 64.1081003844738, 68.0550853908062, 71.60268142819405, 68.22107568383217, 70.5074129998684, 71.09587982296944, 74.14307311177254, 38.36068198084831, 0.23850955010857433, 52.97202654182911, 57.89024703204632, 36.343959197402, 35.9257498383522, 78.32424715161324, 48.57962183654308, 43.652319833636284, 49.90687161684036, 1.8389984825626016, 0.09929785257554613, 0.062226062145782635, 0.17066395317669958, 0.04383415842312388, 0.14540727250277996, 0.017727609192661475, 0.029524501078412868, 0.08447956060990691, 0.11360453019733541, 0.08365841131308116, 0.14983706292696297, 0.03960794652812183, 0.03747241658857092, 0.023034124642435927, 0.11945248319534585, 0.06268747019930743, 0.04633938551705796, 0.15409703511977568, 0.06260619018576108, 0.07077952192048542, 1.846400247886777, 62.080612778663635, 49.79138821363449, 37.82719440758228, 43.82924593985081, 48.64485293626785, 39.7221565246582, 80.10702028870583, 36.696318089962006, 5.062702987343073, 72.3448196053505, 69.68326762318611, 77.11603358387947, 73.00827920436859, 73.153545409441, 66.71002596616745, 66.15368261933327, 59.87399518489838, 61.71381086111069, 58.99422079324722, 58.7676427513361, 54.422078132629395, 50.829340517520905, 55.21076001226902, 60.311097130179405, 59.082615450024605, 60.279764011502266, 62.87946291267872, 62.46368542313576, 55.65877877175808, 51.804227605462074, 47.64652490615845, 48.925084099173546, 49.74890649318695, 51.47765792906284, 49.885813146829605, 46.00952334702015, 42.77847692370415, 48.62939536571503, 52.04693578183651, 50.623372569680214, 50.32272510230541, 56.20645858347416, 54.72047992050648, 51.120442897081375, 53.14568102359772, 52.43216671049595, 60.19054479897022, 57.264777794480324, 58.98982062935829, 59.46102574467659, 61.11934036016464, 56.21509172022343, 56.15496754646301, 58.390022814273834, 62.511722445487976, 58.57233703136444, 56.44020304083824, 54.308851808309555, 56.90826192498207, 52.29790471494198, 59.52417075634003, 49.134669452905655, 38.03648337721825, 49.257011488080025, 42.23868928849697, 46.89337112009525, 42.66460083425045, 43.75142991542816, 38.804570361971855, 43.86427246034145, 41.47294297814369, 42.42812052369118, 44.16172809898853, 36.37106694281101, 35.98526604473591, 43.79993051290512, 48.98791752755642, 53.864537850022316, 58.702924624085426, 65.01052916049957, 47.51576252281666, 37.52503462135792, 50.80614656209946, 47.88274683058262, 49.80085350573063, 40.734304413199425, 43.827889412641525, 44.304231852293015, 44.7630800306797, 32.338483929634094, 59.7093690186739, 70.72275504469872, 30.17751518636942, 59.07315395772457, 52.4193499982357, 57.31772035360336, 54.75009933114052, 57.05386631190777, 56.05539008975029, 59.40205670893192, 58.62312510609627, 56.25762663781643, 56.730252876877785, 58.093638718128204, 56.81266285479069, 58.69734652340412, 53.90123248100281, 55.54429851472378, 57.29976251721382, 58.4849189221859, 58.3152162283659, 51.83415859937668, 50.6848418712616, 50.46029672026634, 49.02643986046314, 46.81653544306755, 44.10485275089741, 45.36074236035347, 48.12366530299187, 48.565756380558014, 44.483874812722206, 47.72911347448826, 47.72060193121433, 48.72027888894081, 48.944086879491806, 49.32635776698589, 46.90819412469864, 48.67886111140251, 51.498727798461914, 54.3917253613472, 53.06609809398651, 54.248207062482834, 52.43065819144249, 53.16937655210495, 54.74226415157318, 59.41508240997791, 63.41062121093273, 66.90598145127296, 68.11618611216545, 74.98283565044403, 71.98146030306816, 74.09692078828812, 71.22692719101906, 81.96786403656006, 38.73089611530304, 0.532571644289419, 61.17125317454338, 61.5770447999239, 46.67702592909336, 35.0227814912796, 87.63184010982513, 60.905263647437096, 47.5849150121212, 55.79110287129879, 1.884636408649385, 0.018476515979273245, 0.10511252025025897, 0.15467485645785928, 0.05197970043809619, 0.08764307640376501, 0.025969535781769082, 0.06231966181076132, 0.020150209275016095, 0.0411156009795377, 0.22969792684307322, 0.2404596915584989, 0.13037857424933463, 0.2599599928362295, 0.2530047035543248, 0.210550234769471, 0.20112233207328245, 0.1450437240418978, 0.23430485307471827, 0.2044235830544494, 0.2804066363023594, 3.755903234705329, 69.51266437768936, 63.18100333213806, 48.8794257491827, 49.11091312766075, 56.4337357878685, 47.582749128341675, 89.09108340740204, 36.80973820388317, 8.90739368274808, 77.64599114656448, 72.40874737501144, 80.69564670324326, 76.10434547066689, 77.10398823022842, 67.9675380885601, 67.79789999127388, 61.17991290986538, 65.0258119404316, 60.996006578207016, 58.22323076426983, 57.405446246266365, 53.7027121335268, 59.05635125935078, 62.04579524695873, 62.72498980164528, 63.13222534954548, 63.41279089450836, 65.98010033369064, 56.52469150722027, 52.113527208566666, 46.79057903587818, 49.73105505108833, 51.364731788635254, 55.84662929177284, 51.17304727435112, 47.83552296459675, 48.27447921037674, 51.81519381701946, 53.1232014298439, 53.52346435189247, 54.3014308065176, 58.87212574481964, 54.137572199106216, 53.37895430624485, 55.00702254474163, 54.88687299191952, 61.4666835218668, 59.91803482174873, 60.38376443088055, 63.39062288403511, 65.1509316265583, 59.44447383284569, 59.29091267287731, 61.247070506215096, 65.77056437730789, 63.312936052680016, 59.35493923723698, 56.465065106749535, 58.21238614618778, 58.479470014572144, 61.76395297050476, 51.927340999245644, 35.572539791464806, 48.244692608714104, 45.84055781364441, 46.223410069942474, 45.022704899311066, 45.251258835196495, 41.50850526988506, 47.68997557461262, 45.80089554190636, 46.80667117238045, 46.387093886733055, 36.89337931573391, 36.50021821260452, 46.41533397138119, 48.147125244140625, 52.16237358748913, 60.19785560667515, 66.91667407751083, 54.8921775072813, 45.33529132604599, 58.170113414525986, 49.349384531378746, 51.18913561105728, 43.17509204149246, 43.8354130089283, 45.99950708448887, 44.73621927201748, 39.27691921591759, 52.756889685988426, 59.092057943344116, 31.157207116484642, 64.05997216701508, 56.88990890979767, 59.420770704746246, 56.46424435079098, 60.51457621157169, 60.31836614012718, 64.57045957446098, 63.06550852954388, 58.628714606165886, 59.237723127007484, 60.487035289406776, 58.56600657105446, 62.10172064602375, 58.292789831757545, 55.795153453946114, 60.299484953284264, 61.53310775756836, 61.59421607851982, 54.070615991950035, 52.4146344512701, 53.856657072901726, 50.9586475789547, 48.97939458489418, 46.93807192146778, 47.94435292482376, 50.20362809300423, 51.17769442498684, 45.513969138264656, 49.6230648458004, 49.96826112270355, 50.65523386001587, 50.294025242328644, 51.711512580513954, 51.322250068187714, 52.0537868142128, 54.88924406468868, 57.410298585891724, 56.521104499697685, 58.5089298337698, 55.60363233089447, 54.67270888388157, 57.416944429278374, 62.12639272212982, 67.34919726848602, 69.03345689177513, 71.31647318601608, 76.9261121749878, 74.01035383343697, 74.80220094323158, 75.13807252049446, 79.43722262978554, 45.641551092267036, 1.3189658685587347, 59.45659898221493, 71.72514885663986, 48.66729833185673, 49.85350728034973, 84.11133661866188, 62.64740936458111, 59.31737445294857, 74.95381280779839, 3.249073368497193, 0.1507604430662468, 0.17398733500158414, 0.37472781725227833, 0.10775762362754904, 0.3477777336956933, 0.1599966490175575, 0.1536427516839467, 0.11697791051119566, 0.24260320700705051], [0.022916612979315687, 0.07441539244609885, 0.023644784159841947, 0.04125639381527435, 0.07002080208621919, 0.09513064884231426, 0.02645647186000133, 0.0575294547888916, 0.03609343941207044, 0.04886048714979552, 0.0364092046947917, 0.39614866313058883, 44.47919346392155, 53.317158222198486, 29.099324941635132, 32.977165058255196, 35.237549766898155, 28.46725355833769, 61.138791516423225, 52.315995544195175, 0.7225222641136497, 41.8950205296278, 70.5634143948555, 71.4529238641262, 73.35787564516068, 65.55088296532631, 65.403291285038, 59.310827404260635, 57.499156817793846, 55.58495633304119, 58.33242550492287, 52.81235910952091, 50.10017104446888, 48.47178362309933, 53.13704788684845, 57.64087401330471, 57.16007441282272, 59.278190955519676, 57.12150648236275, 54.9597492814064, 48.47749851644039, 42.36842952668667, 43.7685289978981, 44.36929576098919, 46.3791561126709, 51.39870956540108, 50.314958319067955, 45.26229344308376, 42.24947690963745, 46.71574965119362, 44.62122604250908, 46.966562792658806, 49.8192673176527, 51.542478650808334, 51.168935894966125, 46.87818333506584, 43.237230107188225, 50.20016647875309, 55.31739369034767, 55.685521736741066, 54.55827422440052, 58.43069203197956, 55.72330690920353, 52.845170348882675, 56.320444867014885, 59.117421582341194, 59.44288171827793, 57.245870009064674, 51.98265463113785, 49.05848354101181, 51.5160358697176, 52.02558472752571, 49.38487082719803, 51.56169421970844, 37.77068383991718, 49.20049712061882, 46.507737413048744, 42.6823914796114, 44.864390194416046, 37.80054643750191, 41.79538607597351, 39.825514778494835, 40.40451630949974, 39.896886348724365, 40.01162499189377, 41.55795581638813, 41.38115890324116, 38.66793729364872, 35.10826550424099, 43.62797453999519, 47.08504043519497, 60.385348945856094, 53.0476500838995, 36.69171653687954, 33.32436762750149, 40.82383520901203, 42.21552573144436, 41.86005860567093, 36.85129277408123, 41.99522875249386, 40.91031476855278, 57.61893779039383, 63.077648878097534, 23.430107049643993, 35.47423906624317, 57.253819182515144, 55.11199951171875, 51.60325638949871, 52.333455607295036, 51.54317021369934, 51.6547854244709, 52.908068373799324, 52.36387677490711, 51.84092603623867, 53.05897727608681, 53.90934504568577, 53.897200897336006, 51.80410221219063, 55.82397110760212, 53.42396669089794, 52.64677919447422, 52.76282496750355, 54.575548097491264, 50.31700260937214, 49.03615593910217, 46.4085703343153, 44.45534974336624, 41.120770275592804, 38.45541849732399, 43.066395074129105, 45.734444707632065, 44.14513818919659, 44.07422259449959, 45.76767012476921, 41.433311104774475, 44.49256494641304, 46.41389384865761, 45.997496992349625, 44.13092315196991, 48.00602741539478, 48.214252442121506, 51.2882836908102, 50.39261855185032, 50.97135789692402, 49.65010039508343, 54.753150567412376, 48.82716715335846, 51.38417534530163, 56.274824514985085, 62.15086720883846, 62.16242618858814, 71.0558831691742, 68.42779219150543, 75.75224876403809, 64.12788212299347, 84.69325259327888, 24.305196292698383, 1.7388645932078362, 70.46758353710175, 51.905613765120506, 44.404690861701965, 31.59630585461855, 36.42016410827637, 37.97149546444416, 56.44856259226799, 33.01187999546528, 0.5931162298657, 0.060822761079180054, 0.19927818415453658, 0.12896902801003307, 0.04316004713473376, 0.00852064200444147, 0.08587571850512177, 0.056584559788461775, 0.06419091296265833, 0.06286669144174084, 0.01720597214443842, 0.08173634530976415, 0.021039613893663045, 0.06315232923952863, 0.04092699527973309, 0.06732430498232134, 0.018528388391132466, 0.04977829747076612, 0.010390650986664696, 0.01750045263179345, 0.03255856776377186, 0.45310555840842426, 49.51902262866497, 58.228930458426476, 30.56622102856636, 43.09536851942539, 48.224603086709976, 35.8358770608902, 66.46957486867905, 61.56371511518955, 1.0861034388653934, 38.75846363604069, 74.39433842897415, 73.17102447152138, 76.47535756230354, 68.66758212447166, 68.82734075188637, 62.994581535458565, 60.0063306838274, 58.316473960876465, 61.62158600986004, 57.095641270279884, 52.79347412288189, 53.484923020005226, 55.33243328332901, 58.83454196155071, 59.63620774447918, 63.01095865666866, 58.87726686894894, 59.053649604320526, 52.04445831477642, 44.993891045451164, 47.95826397836208, 48.50404769182205, 49.43367160856724, 52.10330195724964, 49.87249866127968, 48.53857643902302, 46.03734165430069, 48.65814462304115, 48.37647333741188, 49.08940248191357, 50.83535939455032, 55.753591284155846, 52.209981232881546, 49.36530947685242, 44.95289884507656, 53.102184757590294, 56.779277846217155, 58.98782193660736, 57.670968398451805, 62.366543635725975, 57.89385303854942, 57.528270855546, 55.82284636795521, 57.75489829480648, 62.04652860760689, 61.67168252170086, 56.56569130718708, 50.98992370069027, 53.2676050812006, 54.450789391994476, 50.05901165306568, 56.347636207938194, 41.460373252630234, 54.46568079292774, 50.24680517613888, 44.2774660885334, 45.82897983491421, 40.281372517347336, 42.28072643280029, 43.72690223157406, 44.05308052897453, 39.69246871769428, 40.6775164604187, 45.92130348086357, 42.756574898958206, 40.05876146256924, 36.59113593399525, 42.00079545378685, 44.369926527142525, 60.48223614692688, 65.66261976957321, 54.19250205159187, 37.97996900975704, 42.331005334854126, 40.90848706662655, 42.66693390905857, 37.57212169468403, 40.04185616970062, 37.14478902518749, 57.003184631466866, 82.36737459897995, 33.732260540127754, 37.033177614212036, 58.68713267147541, 56.188120767474174, 53.306051418185234, 54.58137698471546, 52.14676022529602, 53.63797880709171, 56.51788227260113, 57.87455387413502, 54.64747063815594, 58.253986313939095, 57.92775101959705, 57.469203025102615, 51.10286124050617, 55.831342712044716, 58.17196011543274, 56.68162688612938, 58.09968039393425, 55.839831456542015, 51.70911490917206, 50.77440306544304, 49.50104579329491, 48.51039335131645, 45.32277099788189, 42.06897899508476, 45.73929324746132, 49.77494649589062, 46.62759818136692, 46.474903374910355, 47.69691780209541, 46.8621139973402, 48.84144678711891, 48.18194657564163, 48.73620003461838, 47.67620891332626, 50.29833421111107, 51.4422894269228, 53.7425871938467, 53.50845895707607, 54.25022095441818, 53.87118749320507, 55.302483290433884, 53.82758863270283, 57.684567868709564, 57.84783750772476, 64.85612064599991, 64.74750727415085, 71.69513806700706, 67.68020510673523, 76.56538233160973, 65.38312196731567, 85.96571311354637, 26.245712265372276, 3.3168626809492707, 78.573407381773, 58.2246632874012, 50.38409560918808, 30.99992785602808, 51.92501172423363, 41.16085812449455, 56.54505841434002, 46.32771447300911, 0.7545296684838831, 0.08274382562376559, 0.1651327413856052, 0.1555022769025527, 0.02751014344539726, 0.048925736773526296, 0.018032668995147105, 0.030489022174151614, 0.07635873582330532, 0.051235252103651874, 0.15731623425381258, 0.1383127414737828, 0.09178496547974646, 0.14367830590344965, 0.1563004418858327, 0.27434913790784776, 0.14966740796808153, 0.13858528778655455, 0.10608111944748089, 0.1818710658699274, 0.19456710491795093, 1.0251817828975618, 61.74806982278824, 66.96536466479301, 37.469310611486435, 47.21570782363415, 50.8484610915184, 41.62720710039139, 73.85836198925972, 63.21164108812809, 1.6383876535110176, 47.614770010113716, 75.43901637196541, 76.94305166602135, 80.74652597308159, 71.68117001652718, 71.1402690410614, 63.1373056769371, 60.97031235694885, 59.93562027812004, 64.06289041042328, 58.04396018385887, 53.57229173183441, 54.566056206822395, 56.501364558935165, 61.59099765121937, 62.40948133170605, 67.422586530447, 60.89522458612919, 62.341058403253555, 55.69522261619568, 46.04629397392273, 47.43508145213127, 47.140680849552155, 53.42685453593731, 58.054785802960396, 54.630892127752304, 52.6529386639595, 48.971122428774834, 50.89985333383083, 49.560231417417526, 51.53968200087547, 53.001604154706, 58.74135576188564, 55.28880022466183, 51.0805906355381, 45.71703404188156, 54.69790153205395, 58.46642151474953, 59.91953954100609, 59.6842447668314, 66.55138447880745, 65.2197003364563, 59.26973260939121, 58.958628103137016, 64.32409599423409, 67.4680244922638, 63.97370159626007, 59.03463922441006, 51.91576302051544, 56.19805343449116, 58.06794449687004, 52.84321345388889, 58.97886961698532, 43.16853739321232, 54.666952192783356, 52.483349964022636, 47.43223540484905, 46.17320716381073, 41.81872442364693, 45.683979615569115, 44.93969455361366, 45.20127631723881, 40.05234740674496, 42.91416384279728, 50.68460628390312, 44.202290922403336, 42.594126015901566, 37.370086535811424, 44.071828722953796, 46.053099408745766, 63.44247870147228, 60.46341195702553, 56.10798306763172, 47.35285386443138, 51.967303454875946, 45.5044886469841, 43.00726644694805, 38.11933793127537, 42.56819240748882, 43.238970413804054, 51.350334361195564, 64.67304646968842, 38.53806786239147, 38.62589254975319, 62.59768143296242, 58.032822981476784, 55.420212373137474, 57.48425781726837, 54.55434903502464, 54.847621098160744, 59.455189257860184, 59.17726457118988, 56.27419374883175, 58.6378189176321, 58.95952105522156, 60.65733075141907, 54.88547846674919, 60.44135794043541, 59.204178526997566, 60.8413852751255, 60.528814047575, 58.735929653048515, 55.360487177968025, 53.073047921061516, 52.969689667224884, 51.85570724308491, 47.248488664627075, 44.54701602458954, 49.71196107566357, 56.19460701942444, 50.29357306659222, 47.932736948132515, 50.026215612888336, 48.40150639414787, 53.28037239611149, 51.688865795731544, 49.36980463564396, 49.98497262597084, 52.911928966641426, 54.845109432935715, 55.6030547618866, 57.529418393969536, 59.212796464562416, 57.325361743569374, 58.091700822114944, 55.45399636030197, 61.46340809762478, 61.599440798163414, 66.83060109615326, 67.89496198296547, 76.7256273329258, 72.00397789478302, 78.02345529198647, 66.51465564966202, 84.16355341672897, 31.316435672342777, 5.143522275611758, 79.85884800553322, 65.60265138745308, 55.792212411761284, 41.673013642430305, 46.681232303380966, 51.307005286216736, 70.31081914901733, 54.948551282286644, 1.4890928333625197, 0.17654789291555062, 0.26097382593434304, 0.459563757176511, 0.21624042943585664, 0.26812147989403456, 0.11904226106707938, 0.21668384782969952, 0.20330573053797707, 0.1366155536379665], [0.02381949499977054, 0.09872492199065164, 0.03983755217632279, 0.026984856885974295, 0.06123229301010724, 0.06373771306243725, 0.06253640603972599, 0.055556035877089016, 0.1129341110936366, 0.043785080197267234, 0.021886239264858887, 0.03928016216377728, 42.753333672881126, 56.5936616063118, 38.23855273425579, 30.07809542119503, 24.752711579203606, 36.79934196174145, 47.94844530522823, 72.21495017409325, 2.1281287679448724, 19.59432877600193, 78.27308669686317, 65.77231988310814, 70.33956080675125, 66.29816606640816, 64.61341246962547, 60.91256685554981, 60.36952279508114, 59.36063513159752, 57.07919955253601, 54.832247123122215, 57.888039350509644, 55.98637819290161, 55.344733223319054, 56.40208728611469, 57.14028887450695, 56.506783068180084, 55.01726679503918, 52.88306191563606, 47.68814027309418, 46.465848460793495, 45.213553458452225, 44.97102007269859, 47.38105595111847, 44.203491657972336, 45.3143734484911, 46.569316908717155, 43.06212790310383, 42.58570186793804, 46.27069853246212, 47.387405410408974, 46.33701637387276, 48.58754441142082, 52.67435051500797, 47.969233989715576, 41.769714653491974, 42.557389587163925, 51.585716530680656, 57.733790427446365, 53.29440504312515, 55.463233664631844, 56.6878205537796, 61.24469943344593, 57.01893858611584, 56.143769547343254, 54.5321012288332, 59.43318843841553, 52.80485451221466, 51.02678932249546, 52.623330652713776, 51.47407092154026, 48.1988100707531, 52.83676519989967, 46.302970200777054, 46.52141287922859, 58.456146866083145, 45.02098359167576, 46.82838700711727, 42.66629934310913, 39.818466156721115, 40.06853833794594, 42.23060332238674, 37.486170306801796, 63.42172421514988, 57.71423667669296, 24.51313443481922, 33.90490047633648, 36.33079670369625, 36.86019189655781, 40.16938112676144, 42.15798541903496, 67.44872912764549, 94.0457971394062, 70.29479920864105, 48.49486358463764, 41.87569476664066, 49.38740149140358, 48.86084854602814, 46.28686286509037, 53.10901679098606, 46.938178315758705, 18.431931249797344, 22.618164718151093, 49.94045801460743, 51.32739499211311, 53.18630464375019, 52.06055425107479, 55.92159166932106, 54.51019540429115, 54.46503862738609, 53.587737902998924, 50.481351390480995, 49.71722759306431, 52.24483676254749, 54.346709176898, 50.63174732029438, 51.06642119586468, 53.295024409890175, 51.997169852256775, 49.54842545092106, 52.44178779423237, 45.0402257591486, 46.63651630282402, 48.00819329917431, 45.1754567027092, 44.457128047943115, 39.65160571038723, 40.69429636001587, 42.4080765992403, 42.72722527384758, 42.912298142910004, 46.138610020279884, 42.98206239938736, 44.25777554512024, 47.10311986505985, 49.940556809306145, 54.93932157754898, 57.13271588087082, 53.72399099171162, 52.02727183699608, 49.19869601726532, 48.2158787548542, 48.159364387393, 48.82825009524822, 50.1424665749073, 50.23090682923794, 53.50941650569439, 52.283195704221725, 57.599733620882034, 58.893514797091484, 67.77509361505508, 63.54683630168438, 75.74741542339325, 65.2163565158844, 79.91630852222443, 17.566028013825417, 7.3816857766360044, 76.91165015101433, 47.17473082244396, 49.107314720749855, 28.286191374063492, 19.227977134287357, 33.18703159689903, 53.81511390209198, 46.209954991936684, 0.6170738255605102, 0.13905963889556006, 0.13123698678100482, 0.05776685669843573, 0.08419563717325218, 0.051532600991777144, 0.18949660356156528, 0.024385748110944405, 0.0782648753374815, 0.0346272747265175, 0.06065315807063598, 0.08556087719625793, 0.023803408948879223, 0.04033403041830752, 0.05764912610175088, 0.01848056068411097, 0.03711374774866272, 0.026366154343122616, 0.07836927325115539, 0.045572049348265864, 0.07821686580427922, 0.03928678954252973, 49.91503357887268, 60.30636638402939, 41.34274676442146, 37.70699545741081, 29.790865033864975, 47.71709091961384, 50.54640009999275, 83.71374875307083, 3.7021769676357508, 19.38722848892212, 82.11629927158356, 70.50001099705696, 76.25908836722374, 68.3931228518486, 65.70466831326485, 64.12976682186127, 65.4599766433239, 62.58273683488369, 59.832748398184776, 57.03652024269104, 60.35852998495102, 57.37724795937538, 58.907767832279205, 58.25786590576172, 60.62043473124504, 58.46055842936039, 60.13702467083931, 56.71681299805641, 49.90695521235466, 49.8834952712059, 48.659835532307625, 48.541506081819534, 49.895365834236145, 48.14546853303909, 47.9385582357645, 48.68029743432999, 46.9719623029232, 45.578539073467255, 48.92807833850384, 52.20087692141533, 50.45768246054649, 50.78562766313553, 54.761844500899315, 51.53821907937527, 43.559091836214066, 46.58648058772087, 53.79358045756817, 59.67211201786995, 55.40964134037495, 56.12049959599972, 57.834789007902145, 61.52737006545067, 58.40327650308609, 59.59924332797527, 57.38707423210144, 63.182808235287666, 55.711006969213486, 54.628448858857155, 54.63391676545143, 53.78387197852135, 51.16758316755295, 57.32586331665516, 49.91071701049805, 50.42661152780056, 59.04027812182903, 46.41987092792988, 45.32962962985039, 42.25982755422592, 41.48433856666088, 42.5049751996994, 43.099863678216934, 40.45170597732067, 68.83548751473427, 58.84656071662903, 28.06758150458336, 35.90308405458927, 37.70898275077343, 38.054490610957146, 41.53959900140762, 39.68672722578049, 55.8895555883646, 89.90096434950829, 83.26702192425728, 57.74254135787487, 45.07019095122814, 50.07233753800392, 49.02626506984234, 45.973676070570946, 54.9145583063364, 62.4196457862854, 28.922414034605026, 26.90071351826191, 52.876393273472786, 53.60571473836899, 54.68333691358566, 53.05529907345772, 55.50489462912083, 55.134083926677704, 59.79115583002567, 58.521849140524864, 54.62403729557991, 53.17573741078377, 56.338623091578484, 55.53035706281662, 51.717953234910965, 52.98851765692234, 57.47859612107277, 54.80035923421383, 52.405298352241516, 53.93133066594601, 47.52827525138855, 46.49135269224644, 49.42382253706455, 48.98628741502762, 45.317724868655205, 42.88110561668873, 44.59378391504288, 46.970180198550224, 44.458241388201714, 46.68513089418411, 47.522396966814995, 47.20349907875061, 48.23795937001705, 51.31598800420761, 53.81962426006794, 58.31688053905964, 60.69809876382351, 58.936228305101395, 55.98480887711048, 54.000144973397255, 52.54459887742996, 54.41795915365219, 51.82192325592041, 53.20750750601292, 55.10682038962841, 56.59922070801258, 53.20379510521889, 60.89528538286686, 61.8541145324707, 70.06000980734825, 64.38277244567871, 78.04499253630638, 66.41412064433098, 82.8688108921051, 18.97253394126892, 11.93513011559844, 88.26477974653244, 49.65163551270962, 53.191118985414505, 30.468931049108505, 25.03815606236458, 41.234623566269875, 58.82231421768665, 57.06481732428074, 0.7230252621229738, 0.1739516673842445, 0.13078924908768386, 0.053329522343119606, 0.009885829149425263, 0.05408737757534254, 0.09077189679373987, 0.04605420042935293, 0.03954804036766291, 0.048263091666740365, 0.20312541833845899, 0.3216105268802494, 0.1990432944148779, 0.1364949397975579, 0.1708476198837161, 0.23922879510791972, 0.15456528577487916, 0.27843878720887005, 0.2526562800630927, 0.08264595860964619, 0.22780648927437142, 0.17419087642338127, 60.07626213133335, 71.58527836203575, 52.59806960821152, 43.84086951613426, 32.982841953635216, 51.89837135374546, 57.747321501374245, 86.92101985216141, 3.654054212383926, 23.564496338367462, 83.77928763628006, 71.67385920882225, 77.07072481513023, 69.83839049935341, 67.03896671533585, 67.49964639544487, 68.07285323739052, 63.4954858571291, 62.659952491521835, 57.565862238407135, 63.22146736085415, 56.89646735787392, 57.7848444879055, 59.37544673681259, 61.9456098228693, 60.225989297032356, 60.70053443312645, 59.128030613064766, 50.474173575639725, 49.31284189224243, 49.54611897468567, 48.84612813591957, 52.01679199934006, 48.095349222421646, 51.00511908531189, 51.30796283483505, 50.93294195830822, 49.6300108730793, 51.673089042305946, 53.69282506406307, 54.48194392025471, 52.40252450108528, 58.54797653853893, 52.561082392930984, 46.373631209135056, 46.448073014616966, 57.489843517541885, 62.00352631509304, 58.83096635341644, 59.479819536209106, 61.75508424639702, 65.14366641640663, 64.6262937784195, 64.12452310323715, 64.46415647864342, 67.60757580399513, 59.429130256175995, 57.17769406735897, 55.82315415143967, 58.083641454577446, 52.496607452631, 58.27387444674969, 53.59947167336941, 54.65328812599182, 64.36472341418266, 49.06561955809593, 45.19860126078129, 43.75101573765278, 43.16627651453018, 43.836248964071274, 43.09300124645233, 46.26249097287655, 72.5588621199131, 58.987601548433304, 29.82929427176714, 35.938441157341, 38.45135271549225, 39.648189693689346, 43.178671449422836, 42.144511342048645, 53.15088674426079, 74.46391269564629, 73.08308959007263, 59.91106979548931, 51.28636099398136, 55.36495953798294, 49.97995309531689, 46.878426522016525, 49.88324448466301, 54.67885695397854, 39.88964393734932, 27.730060815811157, 54.623174741864204, 54.35919530689716, 56.69694006443024, 54.14452962577343, 58.27841520309448, 57.847514525055885, 63.348600938916206, 58.34528401494026, 53.04622136056423, 54.77938815951347, 59.41996514797211, 57.8540425747633, 54.32282745838165, 53.9808914065361, 61.406483352184296, 59.72833000123501, 56.5285786986351, 56.2564031034708, 49.83393833041191, 49.020835161209106, 53.93144465982914, 50.82463636994362, 47.3704469203949, 44.99571114778519, 47.3967719078064, 49.95961278676987, 49.120579808950424, 48.69307614862919, 52.83188246190548, 48.9042916148901, 51.08507439494133, 50.8233330398798, 52.5008100271225, 57.97619082033634, 60.110600888729095, 60.69787837564945, 57.006030678749084, 54.63564567267895, 55.27337685227394, 58.229340836405754, 53.38930495083332, 56.40764258801937, 57.61173717677593, 59.90665823221207, 56.19865380227566, 66.38690650463104, 64.01323467493057, 73.33614841103554, 66.28804340958595, 81.78560301661491, 70.96522003412247, 86.65673643350601, 28.168861269950867, 11.566770281642675, 91.50066331028938, 58.232969641685486, 60.803527906537056, 35.22988557815552, 24.949237033724785, 43.29391926527023, 68.80677625536919, 69.4789145886898, 1.237707466352731, 0.38023443426936865, 0.24978770117741078, 0.11850314273033291, 0.29847674479242414, 0.17315047443844378, 0.24349924642592669, 0.2698549290653318, 0.14272099477238953, 0.12164293948444538], [0.04896025035122875, 0.07458115112967789, 0.02895543337217532, 0.09275524935219437, 0.033522031299071386, 0.021911817384534515, 0.05485345209308434, 0.07458174484781921, 0.016696534148650244, 0.026952425032504834, 0.051703981444006786, 0.1304198376601562, 36.70611396431923, 52.07540765404701, 37.39027485251427, 45.83131670951843, 39.267579317092896, 34.74011845886707, 48.104609325528145, 78.26459035277367, 16.37304212898016, 10.115540754050016, 87.27824628353119, 71.99759423732758, 73.73334869742393, 61.16819813847542, 61.429867297410965, 60.79720124602318, 64.13406819105148, 60.22713303565979, 53.51161278784275, 53.88915292918682, 58.62926937639713, 58.76396834850311, 58.12795847654343, 60.00137194991112, 60.865722969174385, 57.83416964113712, 54.59529563784599, 50.02716176211834, 49.11719039082527, 50.813632160425186, 51.811466217041016, 50.858393758535385, 50.59544786810875, 48.03700715303421, 46.32370948791504, 42.64855809509754, 44.345083460211754, 39.63147059082985, 40.402692407369614, 43.758311346173286, 46.70423246920109, 47.728794291615486, 50.095029920339584, 52.23368816077709, 45.36287784576416, 44.503116980195045, 52.854749634861946, 55.90724363923073, 55.07624723017216, 56.05499491095543, 56.11735336482525, 52.96039916574955, 51.77043981850147, 59.13139723241329, 60.04736848175526, 53.7656519562006, 50.18249362707138, 52.24723443388939, 54.26459938287735, 52.77591526508331, 52.21601150929928, 49.35095004737377, 54.133609011769295, 47.860525622963905, 55.18479600548744, 51.75943560898304, 40.869569554924965, 40.031524524092674, 41.69088028371334, 39.87091854214668, 38.53016048669815, 43.64832244813442, 67.06993505358696, 50.83206497132778, 40.31586326658726, 45.36001659929752, 39.207869321107864, 39.89345133304596, 34.857136979699135, 35.27189612388611, 37.51339964568615, 66.54433965682983, 63.292303159832954, 61.557654440402985, 62.60035268962383, 57.43054009974003, 51.070448979735374, 49.44217175245285, 37.64300689101219, 21.524239517748356, 26.853341460227966, 48.710300624370575, 52.6651968061924, 50.56418314576149, 53.16963113844395, 54.5192427188158, 58.873261883854866, 55.172442868351936, 57.94018015265465, 54.03849631547928, 53.94726701080799, 55.863808169960976, 51.874888613820076, 49.588665291666985, 48.96310105919838, 48.67120452225208, 54.9137869477272, 48.462930098176, 44.6283620595932, 44.31414172053337, 40.7717590034008, 46.53074137866497, 42.97168895602226, 42.61416994035244, 44.22274902462959, 42.298144698143005, 39.315110966563225, 43.790476620197296, 42.39253543317318, 42.54668936133385, 42.48947203159332, 45.339258313179016, 50.944462940096855, 58.53538401424885, 62.38383270800114, 64.68353390693665, 65.41326954960823, 65.89172467589378, 61.976407170295715, 56.82231813669205, 50.94144970178604, 51.13215006887913, 50.83823204040527, 49.595850706100464, 50.818389505147934, 53.10265973210335, 50.41392020881176, 56.214894130825996, 57.65992999076843, 64.38401117920876, 61.90471641719341, 71.69504687190056, 59.874200373888016, 72.14332401752472, 5.501828324049711, 21.020850129425526, 76.29373490810394, 39.471917152404785, 30.57613469660282, 24.273846074938774, 47.3718186467886, 34.2684193700552, 53.656366020441055, 39.60631974041462, 0.3766034619184211, 0.13230863318312913, 0.06649993476457894, 0.1504772246698849, 0.06137980970379431, 0.05965945572825149, 0.13422883639577776, 0.010952607062790776, 0.09992697858251631, 0.03979288230766542, 0.041239265046897344, 0.020430973017937504, 0.041851462665363215, 0.03262395097408444, 0.1170915036345832, 0.03968929704569746, 0.016203850136662368, 0.08147686079610139, 0.007897009745647665, 0.0366029905853793, 0.050901345020974986, 0.08603994836448692, 46.09452098608017, 56.123429238796234, 42.50872179865837, 46.84647023677826, 36.750898361206055, 46.50325745344162, 51.66539065539837, 86.39177665114403, 21.131925769150257, 10.300028454512358, 88.3216854929924, 74.28639382123947, 74.81572061777115, 62.14963987469673, 66.34067058563232, 66.44644170999527, 67.74739310145378, 63.53215008974075, 57.812020629644394, 57.35268987715244, 59.711451306939125, 61.00152388215065, 61.96545235812664, 60.97135350108147, 63.5527677834034, 60.791615545749664, 56.719860434532166, 53.15896891057491, 51.64723142981529, 52.11129292845726, 55.382191613316536, 52.13351413607597, 51.79895728826523, 49.818343967199326, 51.31728753447533, 46.32117502391338, 46.913730427622795, 44.595034047961235, 44.38880391418934, 46.69913314282894, 49.425684437155724, 49.71738338470459, 52.26097829639912, 54.33375187218189, 45.79548463225365, 47.007611989974976, 56.611760035157204, 57.07809001207352, 58.1752697378397, 57.308255061507225, 57.417461201548576, 53.25989909470081, 55.619568675756454, 60.06021939218044, 62.71326743066311, 56.71547546982765, 54.287447556853294, 53.91367681324482, 55.532720535993576, 54.83551874756813, 54.14718948304653, 54.34459649026394, 57.280197367072105, 51.247090101242065, 56.790228858590126, 51.70564569532871, 43.26657973229885, 42.1334957331419, 41.02497361600399, 40.95188453793526, 37.343871742486954, 50.18605023622513, 79.1455426812172, 58.037025555968285, 41.78960278630257, 45.018734112381935, 39.95572239160538, 38.43427263200283, 34.31465908885002, 37.42054782807827, 35.83713099360466, 53.593707382678986, 53.92123840749264, 58.996116891503334, 62.31813043355942, 57.39354528486729, 52.08033598959446, 52.37251751124859, 48.10683220624924, 28.92726257443428, 31.78014189004898, 50.87887465953827, 52.525615096092224, 53.18264544010162, 54.95244987308979, 54.134475365281105, 58.40687870979309, 57.8848285228014, 60.37308320403099, 54.25764575600624, 55.86166508495808, 57.810983285307884, 54.13094915449619, 51.944322288036346, 52.66849122941494, 53.40229645371437, 58.114245012402534, 52.15911716222763, 48.792630806565285, 46.008379608392715, 45.871415957808495, 51.97290055453777, 47.07038842141628, 44.872088581323624, 46.60123899579048, 45.52846156060696, 44.43082205951214, 46.82904437184334, 44.23298567533493, 46.06550574302673, 45.33253267407417, 47.592370212078094, 52.05611988902092, 62.456917986273766, 64.42918315529823, 67.39512160420418, 65.09597137570381, 66.952483355999, 64.908337444067, 63.380481228232384, 54.260556399822235, 53.73849481344223, 54.47857730090618, 52.73415170609951, 51.828128322958946, 57.18275539577007, 55.22010751068592, 58.16531427204609, 59.21909652650356, 65.99813416600227, 64.44980844855309, 74.9433633685112, 66.04093506932259, 76.22392505407333, 5.659551210701466, 28.01280364394188, 83.05233344435692, 45.683782026171684, 34.793877974152565, 28.391060046851635, 44.51853275299072, 38.79136607050896, 58.222113624215126, 49.09650430083275, 0.5739397276192904, 0.036318774000392295, 0.009653401484683855, 0.08605741109931841, 0.1330117290490307, 0.1584555793670006, 0.06672657182207331, 0.009901228713715682, 0.10339260785258375, 0.017226921117980964, 0.10407139096059836, 0.1652994574396871, 0.0994103102129884, 0.18105963128618896, 0.36201556969899684, 0.12554404616821557, 0.08082250176812522, 0.3504377690842375, 0.11475848819827661, 0.14013357111252844, 0.26439539389684796, 0.3372124896850437, 54.412764832377434, 66.71956345438957, 51.45027279853821, 65.45755997300148, 52.65888914465904, 50.09322501718998, 59.62967589497566, 92.95050591230392, 20.96283294260502, 13.228472415357828, 93.49291160702705, 73.02036255598068, 75.23887351155281, 60.75917288661003, 67.2454172372818, 67.40490987896919, 68.09965699911118, 64.63602885603905, 62.442835941910744, 57.752793207764626, 62.81900815665722, 60.86191937327385, 62.767802104353905, 64.2647735774517, 65.74438378214836, 61.69505886733532, 60.68383052945137, 54.21234078705311, 52.840720787644386, 55.55181831121445, 57.98523433506489, 53.8022667914629, 52.768661454319954, 52.00627036392689, 53.9874080568552, 49.89502765238285, 52.40041181445122, 48.37960056960583, 46.75029739737511, 52.437410429120064, 55.375116392970085, 52.7159620821476, 54.41113851964474, 57.48010464012623, 48.3965552598238, 47.57545731961727, 57.56422072649002, 60.38486257195473, 61.49984434247017, 57.1546521037817, 58.60887587070465, 56.96998581290245, 59.960242956876755, 66.5598352253437, 67.1188460290432, 60.60622349381447, 57.50582925975323, 58.59763227403164, 59.59653027355671, 57.8259164839983, 57.300716266036034, 57.52840384840965, 58.552179113030434, 54.874968230724335, 60.27767792344093, 53.15922349691391, 45.055546537041664, 43.18413555622101, 43.3632655441761, 41.062090024352074, 42.44077384471893, 56.91088378429413, 80.77180221676826, 56.51570878922939, 39.45995919406414, 47.69645422697067, 40.43356575071812, 39.388815611600876, 34.17728126049042, 36.20122745633125, 36.780688762664795, 59.211759120225906, 51.96339726448059, 51.567572504282, 58.50981518626213, 59.84371840953827, 54.32122774422169, 55.564730018377304, 51.39113277196884, 34.10065837204456, 33.432456627488136, 54.22122851014137, 57.778981402516365, 55.677777752280235, 56.9485055655241, 56.34957790374756, 61.343668922781944, 61.426257491111755, 62.19327673316002, 59.081106930971146, 58.539119213819504, 61.06640160083771, 55.422378256917, 54.02154162526131, 54.52209636569023, 56.9550222158432, 62.65457957983017, 53.854631781578064, 50.20298212766647, 51.575080901384354, 48.426642045378685, 54.661419689655304, 48.71964052319527, 47.72443972527981, 48.12066726386547, 47.99015186727047, 44.38561208546162, 50.80959677696228, 47.60106034576893, 50.377746149897575, 50.305876806378365, 53.025865852832794, 54.37298096716404, 64.78852987289429, 68.95047694444656, 70.0419607758522, 69.42509427666664, 69.44799944758415, 66.49415194988251, 64.5179083943367, 53.393621519207954, 54.448121935129166, 56.47693566977978, 55.080704391002655, 54.27375689148903, 61.848129853606224, 57.43796490132809, 62.86633841693401, 60.87460309267044, 68.57399314641953, 64.57007199525833, 80.61390548944473, 67.06058755517006, 90.16940474510193, 14.886831678450108, 25.576898753643036, 94.40161004662514, 53.1079338490963, 39.264645874500275, 33.90816830098629, 67.74583518505096, 47.674461007118225, 70.42052686214447, 60.456720516085625, 1.0107740247622132, 0.2619837108068168, 0.30061962199397385, 0.23420690442435443, 0.29498244635760784, 0.28416163637302816, 0.23375968623440713, 0.17440017691114917, 0.2185957389883697, 0.21399322111392394], [0.030825988760625478, 0.02742062930337852, 0.05809396199765615, 0.051933253125753254, 0.015271084612322738, 0.05961856339126825, 0.03649572427093517, 0.025268807366956025, 0.07167454459704459, 0.07551988630439155, 0.07678275447688065, 0.10022466143709607, 36.11376374959946, 67.44033917784691, 30.514876283705235, 65.25629997253418, 51.6833370923996, 22.747893556952477, 44.899025335907936, 68.59365329146385, 36.819157898426056, 3.402219875715673, 59.36155088245869, 71.51426777243614, 78.1794673204422, 70.90921103954315, 68.5165174305439, 65.98336815834045, 66.17452070116997, 57.826041877269745, 55.630417093634605, 54.56064149737358, 56.953129917383194, 56.66418582201004, 56.70875363051891, 57.28948786854744, 56.81942269206047, 52.366023659706116, 49.485291838645935, 48.15367989242077, 50.286900624632835, 55.232844427227974, 57.07118958234787, 56.048466861248016, 51.72421529889107, 46.20769791305065, 47.155165672302246, 46.23611278831959, 42.892987579107285, 39.43015359342098, 42.07431010901928, 43.38253431022167, 44.31386433541775, 43.14342454075813, 47.98622287809849, 51.16080433130264, 45.18543116748333, 46.13659992814064, 57.80607394874096, 59.145239889621735, 54.928735345602036, 56.436346247792244, 57.005149126052856, 44.721415266394615, 46.64651736617088, 53.23073945939541, 53.181600496172905, 54.371776431798935, 54.13368120789528, 50.58227397501469, 51.21237516403198, 53.86131562292576, 54.46289174258709, 53.48794385790825, 56.09494596719742, 54.86940532922745, 50.989585518836975, 53.49042132496834, 41.21604636311531, 41.255727633833885, 39.969226866960526, 37.41475693881512, 40.5935637652874, 56.25123918056488, 57.57522493600845, 46.793257892131805, 47.10745923221111, 41.40439085662365, 38.57540845870972, 40.99904380738735, 43.46168406307697, 42.69661031663418, 41.87653832137585, 36.45704112946987, 43.12971867620945, 38.24966713786125, 36.790610030293465, 37.84560441970825, 41.368851363658905, 43.68778333067894, 46.04900322854519, 51.19785234332085, 50.537759363651276, 50.27551643550396, 52.70922124385834, 51.477513536810875, 52.74559289216995, 53.42515602707863, 54.274380058050156, 55.99158391356468, 54.361991956830025, 48.02467301487923, 54.0475170314312, 52.361889481544495, 52.02424339950085, 50.76509356498718, 51.03516787290573, 52.83751755952835, 55.28404287993908, 50.88859833776951, 43.08420471847057, 44.858926087617874, 44.83732044696808, 44.49111342430115, 42.90744960308075, 43.7808783352375, 44.85537327826023, 42.22013108432293, 41.73697181046009, 45.36517672240734, 45.0243654102087, 42.87292845547199, 43.6581639200449, 50.162784084677696, 59.023969396948814, 59.911107793450356, 63.54347728192806, 62.78234392404556, 61.97900243103504, 60.45322850346565, 61.42250709235668, 61.45157553255558, 60.40937125682831, 54.971053674817085, 50.78785054385662, 50.371434688568115, 49.08623345196247, 55.02981752157211, 53.85307386517525, 57.11171440780163, 57.610684633255005, 65.38616180419922, 67.22262606024742, 68.9651669561863, 65.92373415827751, 49.89014871418476, 0.5735164659563452, 37.23427042365074, 68.92144650220871, 37.55826383829117, 22.16770078986883, 24.494726322591305, 40.75553387403488, 35.249306336045265, 48.27732525765896, 49.220404252409935, 0.6637231505010277, 0.055356587399728596, 0.011583392697502859, 0.04888582778221462, 0.04099208163097501, 0.05646352292387746, 0.03492664225632325, 0.0563716895703692, 0.02058810794551391, 0.02270628832775401, 0.04536022184765898, 0.06004496062814724, 0.04291893448680639, 0.09346539562102407, 0.016004752324079163, 0.07035683913272806, 0.02861704742826987, 0.08467286781524308, 0.030121694326226134, 0.11750301709980704, 0.05603400495601818, 0.32789675518870354, 47.54345923662186, 74.41329181194305, 33.451945781707764, 64.94429871439934, 45.21528236567974, 29.54667303711176, 53.13311129808426, 72.26656660437584, 44.4697205722332, 3.0710272723808885, 56.99030712246895, 75.43161436915398, 80.8841697871685, 73.5649873316288, 72.69795745611191, 69.18843537569046, 68.49574014544487, 61.28036431968212, 59.67780791223049, 57.24170543253422, 61.40121303498745, 59.26041550934315, 62.871509939432144, 58.64568829536438, 60.385888516902924, 55.71373522281647, 51.45636387169361, 51.156639754772186, 53.654257133603096, 59.481601640582085, 60.52808068692684, 59.138483852148056, 58.108131140470505, 49.26982440054417, 48.998959735035896, 48.44786010682583, 46.224078834056854, 41.45707502961159, 45.47614596784115, 45.14289245009422, 45.174236968159676, 42.91588135063648, 50.36045327782631, 52.87527233362198, 48.72103124856949, 46.100691854953766, 58.881811425089836, 62.62481577694416, 58.18152420222759, 58.09640496969223, 56.661677956581116, 46.20596520602703, 48.749651312828064, 55.84309548139572, 54.90869902074337, 56.9009967148304, 57.82251566648483, 56.49272382259369, 55.712739676237106, 55.802057683467865, 57.454212829470634, 56.08286261558533, 56.96249261498451, 58.38237762451172, 55.08890055119991, 56.73934958875179, 40.940735936164856, 40.270763486623764, 41.28697715699673, 38.23729120194912, 41.64220109581947, 62.71952569484711, 60.863123908638954, 48.173245042562485, 44.23504136502743, 39.056827425956726, 38.59610594809055, 40.349476262927055, 41.06626600027084, 40.59173986315727, 38.622142150998116, 38.60667698085308, 39.68635104596615, 35.865295082330704, 35.73274679481983, 39.96269501745701, 43.24283480644226, 46.80205062031746, 47.80112341046333, 52.03574538230896, 53.761635571718216, 52.87531033158302, 54.423176273703575, 53.82929094135761, 54.743981659412384, 55.89689299464226, 57.22136132419109, 56.862310990691185, 55.35702556371689, 51.045761704444885, 57.70665608346462, 57.62412451207638, 58.69727812707424, 54.59506385028362, 53.187687769532204, 54.829347878694534, 58.492856696248055, 52.06989035010338, 43.22901114821434, 45.91829404234886, 46.963655948638916, 47.52327471971512, 46.92635715007782, 48.985599651932716, 48.014424964785576, 45.64351938664913, 45.19083447754383, 47.6975903660059, 49.26200821995735, 46.491170302033424, 47.97041952610016, 52.8286412358284, 62.6602678745985, 63.487073108553886, 66.31979450583458, 65.53769007325172, 63.222234919667244, 65.1222051680088, 65.25046348571777, 65.2148973941803, 62.28708989918232, 59.339527264237404, 53.79961833357811, 52.49783478677273, 51.63747355341911, 56.9094892591238, 57.418935522437096, 59.73543182015419, 60.97331419587135, 68.2578957080841, 69.64753434062004, 72.55411997437477, 70.72023198008537, 51.589265540242195, 2.009186362847686, 45.079625844955444, 78.01004201173782, 43.90156365931034, 26.842783726751804, 32.17483431100845, 38.38312357664108, 37.14929558336735, 56.117915734648705, 64.00231406092644, 1.8232523649930954, 0.08363490749616176, 0.03251607238780707, 0.053441363997990265, 0.07728521071840078, 0.06066408248443622, 0.04675885851611383, 0.02781129027425777, 0.037634193649864756, 0.05171371842152439, 0.20629683800507337, 0.13428259757347405, 0.14576889137970284, 0.2053274743957445, 0.17317587073193863, 0.20182251872029155, 0.07792802192852832, 0.1945773168699816, 0.15302155923563987, 0.277317016152665, 0.3153911215486005, 0.4799548879964277, 52.11882412433624, 85.37153139710426, 41.909243166446686, 83.7457962334156, 64.15446549654007, 34.25340637564659, 59.44411285221577, 80.9464180469513, 45.04666641354561, 4.720623968169093, 65.65169915556908, 74.1313849389553, 81.02599337697029, 72.05114096403122, 73.3611586689949, 71.05060905218124, 73.49856689572334, 62.58004657924175, 61.72226540744305, 59.702609181404114, 63.48666653037071, 62.17518210411072, 64.14718508720398, 60.29701508581638, 63.36034990847111, 57.23561815917492, 55.065474808216095, 54.89064238965511, 55.12252114713192, 61.97409689426422, 62.247769609093666, 62.73409031331539, 59.53719265758991, 51.77081599831581, 52.64141388237476, 51.38624623417854, 50.35826079547405, 44.77884158492088, 49.93986904621124, 47.68729291856289, 47.449995651841164, 45.7676587253809, 54.39667649567127, 58.01666624844074, 50.96308574080467, 49.71204087138176, 62.31301970779896, 65.6867940723896, 60.32235972583294, 60.01271054148674, 62.32235960662365, 48.38683918118477, 52.671360075473785, 57.70404942333698, 59.32174041867256, 60.6535879522562, 62.80651442706585, 58.54109890758991, 57.568073719739914, 60.45954756438732, 62.96290263533592, 58.74319486320019, 63.453182727098465, 62.14478373527527, 57.988464161753654, 58.259594812989235, 42.20348797738552, 41.66540265083313, 42.31497399508953, 39.91676688194275, 45.65963812172413, 53.62331919372082, 51.46530479192734, 46.882560700178146, 45.73111228644848, 39.497140198946, 37.342868596315384, 41.3408924639225, 42.860693112015724, 42.77273543179035, 40.82945890724659, 39.44702848792076, 41.20073698461056, 38.24892617762089, 36.640578880906105, 40.15170447528362, 44.70230609178543, 50.27960501611233, 50.674096047878265, 55.814517214894295, 57.86961793899536, 54.95781518518925, 57.92461238801479, 56.370685771107674, 58.045396506786346, 59.82792645692825, 58.730260357260704, 60.98823979496956, 60.15054054558277, 52.150666415691376, 61.54704540967941, 60.09895831346512, 60.235883966088295, 56.59635566174984, 57.27303475141525, 56.587304547429085, 61.98321260511875, 56.922655552625656, 47.98501454293728, 50.230200067162514, 50.86533598601818, 49.40933771431446, 50.24679757654667, 52.162962555885315, 50.78710198402405, 49.665155187249184, 48.08176875114441, 50.6724089384079, 50.34330479800701, 48.8161401450634, 50.16213431954384, 56.11370176076889, 66.50646328926086, 66.24358579516411, 69.02312904596329, 68.16530227661133, 68.35723757743835, 65.81193655729294, 69.34218272566795, 66.8585067987442, 63.51588316261768, 60.02866588532925, 55.865024104714394, 56.02454334497452, 52.84792900085449, 62.01022155582905, 59.04964841902256, 61.72744832932949, 61.493529081344604, 72.51730754971504, 69.03585076332092, 75.60386672616005, 72.11781978607178, 67.07885697484016, 5.48095129430294, 45.05475997924805, 84.83035683631897, 52.44197018444538, 29.445982240140438, 35.77723480761051, 61.23138874769211, 48.63028831779957, 64.433613717556, 70.94306722283363, 2.4953472381457686, 0.33278575690928847, 0.17077760567190126, 0.24856536911102012, 0.21048752329079434, 0.17432351305615157, 0.16914125910261646, 0.11773738733609207, 0.20627400954253972, 0.17853748693596572], [0.03792795425397344, 0.06488009355962276, 0.09851850845734589, 0.04522803421423305, 0.03233941526559647, 0.022524046544276644, 0.01665635427343659, 0.0698496331460774, 0.006574254894076148, 0.05966960088699125, 0.07707034412305802, 0.36066788889002055, 52.056750655174255, 62.53051623702049, 39.92212079465389, 48.16380634903908, 58.8040903955698, 24.2995497956872, 39.39316637814045, 64.81819868087769, 61.33251652121544, 2.8527874080464244, 26.803748421370983, 81.60941407084465, 72.20921248197556, 75.37226155400276, 64.39761444926262, 65.76961442828178, 62.34998792409897, 61.23774200677872, 53.9336409419775, 57.02087268233299, 57.399529963731766, 56.74206264317036, 59.42497327923775, 54.939857348799706, 54.01912875473499, 52.8232379257679, 50.62594883143902, 50.98282568156719, 56.89211279153824, 58.474910259246826, 57.16882914304733, 58.45935009419918, 56.52369976043701, 48.149929493665695, 44.321433529257774, 46.459468603134155, 45.42442314326763, 43.88162612915039, 42.34413743019104, 42.69575536251068, 41.59936599433422, 41.21028587222099, 48.34195598959923, 48.60190764069557, 46.24534249305725, 47.56173625588417, 49.16862063109875, 56.46565407514572, 57.05267317593098, 54.650856256484985, 52.025356739759445, 51.639875024557114, 49.42742474377155, 54.749248176813126, 51.101132333278656, 51.89135693013668, 54.10601109266281, 53.371309116482735, 52.22248636186123, 54.68257695436478, 55.35944603383541, 54.621537029743195, 51.17014043033123, 54.146505519747734, 54.425490349531174, 61.0697378218174, 49.08492632210255, 42.04020693898201, 43.505617305636406, 42.52003379166126, 54.16969567537308, 57.49519743025303, 46.57692030072212, 43.214226141572, 38.5834526270628, 46.23293235898018, 49.34310346841812, 40.81029653549194, 42.38142102956772, 42.73913383483887, 41.49889938533306, 43.199061155319214, 43.01692932844162, 36.63647510111332, 33.57342146337032, 32.93562188744545, 49.05423156917095, 55.38639798760414, 53.66205431520939, 50.04356548190117, 48.01894672214985, 50.422937124967575, 54.736085683107376, 51.73160970211029, 50.62662519514561, 51.503538340330124, 51.25777132809162, 52.61847831308842, 51.76917068660259, 50.75092792510986, 52.69360028207302, 54.10159192979336, 53.6654095351696, 49.6343008428812, 48.56883801519871, 51.51627525687218, 49.46010299026966, 44.73578229546547, 44.186487570405006, 41.37749969959259, 43.442324101924896, 43.57861518859863, 42.5824948400259, 41.231177151203156, 44.45953331887722, 41.779696717858315, 45.47848284244537, 45.7034307718277, 44.83633629977703, 45.22391930222511, 43.35883118212223, 50.539328679442406, 53.79242531955242, 61.12226240336895, 61.378133073449135, 61.83614529669285, 61.67913392186165, 64.18848887085915, 63.22281628847122, 59.23717215657234, 61.31390132009983, 62.061138823628426, 56.812009289860725, 51.2427469342947, 50.732852295041084, 51.232590079307556, 55.25727331638336, 59.710953533649445, 60.22715583443642, 66.27866551280022, 68.09388890862465, 67.14324072003365, 63.82543355226517, 29.22714438289404, 1.2322504841722548, 53.13628412783146, 57.907095327973366, 31.947595104575157, 26.717227064073086, 26.241583786904812, 31.08472030609846, 55.46220391988754, 49.22623313963413, 52.75307849049568, 2.9516583401709795, 0.12076281171175651, 0.07836856821086258, 0.0839630035625305, 0.0355140335886972, 0.07102508374373429, 0.04852700309129432, 0.06784546334529296, 0.08719876743271016, 0.054858643416082487, 0.010099346891365713, 0.05291221270454116, 0.05088741490908433, 0.028883381964988075, 0.0060537009176186984, 0.03693379920150619, 0.082785697595682, 0.0639563868753612, 0.04867689094680827, 0.10590353835141286, 0.03588331142964307, 1.3921454292722046, 61.340959668159485, 69.64755713939667, 41.745319962501526, 53.79790082573891, 61.84035167098045, 26.587534323334694, 51.37634016573429, 67.16913253068924, 72.71925151348114, 3.3450859040021896, 24.98068794608116, 85.09400188922882, 76.63530617952347, 78.6204944550991, 66.38278752565384, 69.86392512917519, 65.50011768937111, 64.72470849752426, 57.53498889505863, 58.41321296989918, 60.01875601708889, 57.647516056895256, 60.1070860773325, 60.07114000618458, 56.69563293457031, 56.062947884202, 53.40615324676037, 55.54115608334541, 60.53936988115311, 60.818989276885986, 59.63144659996033, 62.275500521063805, 59.113382399082184, 51.92369319498539, 48.41278798878193, 49.388837814331055, 50.45378006994724, 47.62828968465328, 44.58099000155926, 45.97331888973713, 44.9728287756443, 44.81123864650726, 48.193524554371834, 49.48254458606243, 46.77914544939995, 48.86986926198006, 51.65876001119614, 58.67483273148537, 58.618139773607254, 56.45252197980881, 54.88425113260746, 54.3034029006958, 51.58209152519703, 58.065983802080154, 55.861801877617836, 52.59725645184517, 56.3262889534235, 56.63401164114475, 55.86766116321087, 56.50607630610466, 56.950052082538605, 58.159428387880325, 51.401236429810524, 54.51552651822567, 55.42131811380386, 61.741446778178215, 52.85707511007786, 42.691788375377655, 44.22904908657074, 44.89825777709484, 52.94771544635296, 58.26482713222504, 41.928348541259766, 39.94500316679478, 36.09196051955223, 44.34892125427723, 49.02429677546024, 41.39471277594566, 40.1120650023222, 41.590854451060295, 38.59530419111252, 42.89511926472187, 44.436160773038864, 37.94403433799744, 32.52590887248516, 34.33551996946335, 48.45917969942093, 56.78071416914463, 56.799713149666786, 51.28057390451431, 51.80573612451553, 53.58695134520531, 55.818624794483185, 54.14491720497608, 51.804683580994606, 53.19526456296444, 52.90738821029663, 54.860734194517136, 54.000486955046654, 53.66085737943649, 52.217242643237114, 56.0914159566164, 56.262965351343155, 51.498651802539825, 49.854711815714836, 52.50756986439228, 52.68875554203987, 43.37814934551716, 46.07332192361355, 45.979155376553535, 48.6953180283308, 47.598313093185425, 44.841283634305, 43.50755900144577, 47.08443246781826, 45.41441448032856, 48.56986775994301, 47.36109182238579, 46.69128656387329, 48.86007338762283, 46.516089364886284, 53.47983129322529, 56.18695802986622, 63.06620769202709, 65.14626547694206, 63.587136939167976, 64.81294736266136, 65.42215347290039, 66.27326220273972, 65.2754357457161, 63.63771602511406, 63.33829969167709, 60.19941732287407, 52.745376303792, 54.27247256040573, 54.42646309733391, 57.580567449331284, 61.79431714117527, 63.10903899371624, 70.43471530079842, 73.93467709422112, 69.89021971821785, 69.05617967247963, 32.675351053476334, 1.8074973416514695, 67.91476652026176, 61.04142174124718, 35.795340836048126, 32.09487520158291, 28.86148050427437, 39.37549352645874, 56.59978307783604, 51.89339742064476, 61.348669454455376, 5.169176599010825, 0.3322729031788185, 0.057492017149343155, 0.05358311420422979, 0.07105709257302806, 0.01941318427270744, 0.020489474663918372, 0.04598519182763994, 0.07196856124210171, 0.06842297298135236, 0.08999950659926981, 0.24350224470254034, 0.14920126501237974, 0.22112729377113283, 0.08108801994239911, 0.11076201553805731, 0.1462658037780784, 0.25798614718951285, 0.15808922558790073, 0.19306913920445368, 0.30931946297641844, 1.6728180809877813, 73.02068933844566, 77.5123219192028, 57.550659254193306, 56.69035501778126, 71.70856654644012, 34.20747444033623, 54.33077283203602, 73.74854028224945, 72.89631441235542, 3.660810012370348, 30.570852980017662, 86.43576309084892, 77.39693731069565, 81.01619750261307, 66.4434626698494, 71.20171934366226, 65.98785951733589, 69.57894802093506, 58.69328834116459, 57.9624355584383, 62.34010465443134, 58.35491269826889, 63.01576919853687, 64.43517923355103, 57.30637036263943, 60.02063691616058, 55.512387827038765, 56.5169133245945, 62.403040677309036, 64.81227859854698, 61.296034678816795, 64.05963018536568, 61.60061493515968, 55.420307368040085, 50.92974252998829, 52.29590602219105, 53.024323135614395, 50.26825122535229, 46.58083789050579, 50.29486119747162, 47.32369042932987, 47.238172218203545, 51.229322254657745, 52.655503526329994, 48.87231633067131, 51.13379158079624, 53.059551045298576, 60.7100111246109, 62.97522537410259, 59.89968940615654, 57.55248315632343, 57.5208992511034, 54.74367007613182, 63.41145716607571, 58.42219188809395, 54.26691725850105, 60.09352460503578, 59.753872230648994, 57.64984913170338, 60.15998303890228, 59.671371057629585, 61.498598009347916, 55.446221977472305, 57.205987349152565, 57.77727149426937, 65.07860630750656, 53.45199018716812, 43.91149252653122, 44.38667982816696, 47.1197097748518, 50.21081730723381, 53.420060500502586, 44.99879278242588, 41.82143747806549, 35.37353307008743, 44.86120216548443, 54.082311764359474, 40.98678186535835, 41.36372163891792, 41.73355579376221, 43.201489225029945, 45.125519782304764, 47.9328091442585, 37.94876888394356, 32.316369116306305, 34.653999879956245, 52.468230575323105, 58.37940998375416, 60.71724973618984, 55.71088917553425, 54.17757265269756, 56.43702641129494, 56.74868568778038, 56.916518881917, 56.26847505569458, 55.80713041126728, 53.738927990198135, 56.4847594499588, 57.178134843707085, 57.09620364010334, 54.23261269927025, 57.87512384355068, 58.52950192987919, 54.83315147459507, 51.762673035264015, 54.96833302080631, 56.111741065979004, 45.767149552702904, 50.18917366862297, 51.73563748598099, 50.731678158044815, 50.85141733288765, 48.652855306863785, 46.375044733285904, 51.02604456245899, 48.44839207828045, 52.30630226433277, 51.2364012748003, 52.32440069317818, 50.767787620425224, 50.68382352590561, 56.137716472148895, 59.40082557499409, 66.38257473707199, 67.90637657046318, 67.26395264267921, 66.72122776508331, 70.69945469498634, 66.63656830787659, 67.22360640764236, 68.37315872311592, 64.8007196187973, 61.087023094296455, 55.33369101583958, 56.01283237338066, 55.903048664331436, 61.44397974014282, 64.80562135577202, 65.00048249959946, 71.00097611546516, 76.21973007917404, 72.38507464528084, 71.74648091197014, 46.57247453927994, 2.3235753178596497, 67.73198112845421, 69.64599922299385, 42.37800881266594, 34.55006405711174, 43.24808232486248, 43.77747371792793, 73.94621327519417, 63.12431037425995, 77.61231735348701, 6.5527331829071045, 0.372432324802503, 0.2744769654236734, 0.13473089929902926, 0.24706311378395185, 0.0929241547419224, 0.10597558604786173, 0.27852820116095245, 0.1610703585902229, 0.17236949759535491], [0.08378793834708631, 0.16210081579629332, 0.12297924316953868, 0.009859779765974963, 0.09371560328872874, 0.10749839144409634, 0.08727185413590632, 0.06586018862435594, 0.031600321526639163, 0.055716584683978, 0.04360687940788921, 0.7315701129846275, 52.62656427919865, 50.78973904252052, 38.00860807299614, 27.83225253224373, 35.87928593158722, 30.789975821971893, 23.28779138624668, 51.861862912774086, 73.34227368235588, 12.931735888123512, 9.29087195545435, 81.68698310852051, 63.30698937177658, 73.00409182906151, 65.04174828529358, 70.30571982264519, 63.75455975532532, 60.65499767661095, 54.23764742910862, 58.85936602950096, 58.24846900999546, 57.854521349072456, 55.19731633365154, 52.57081367075443, 52.866152822971344, 52.45395474135876, 52.901209741830826, 57.73478217422962, 57.964008674025536, 60.45813784003258, 58.61837536096573, 60.41422739624977, 59.34872277081013, 51.918210089206696, 46.938744485378265, 45.85345432162285, 42.43110716342926, 43.69911432266235, 42.913320288062096, 44.12907265126705, 43.47652226686478, 43.48804324865341, 42.7139525860548, 47.34937325119972, 47.26092539727688, 48.661963418126106, 47.89029702544212, 52.36425295472145, 55.26634342968464, 54.92960549890995, 55.089991092681885, 55.14126554131508, 54.1055741161108, 54.76584568619728, 54.00892250239849, 53.62602844834328, 52.724200040102005, 52.81210072338581, 54.16650004684925, 53.87911006808281, 55.73278360068798, 55.45174688100815, 52.837589755654335, 55.59539437294006, 56.88612051308155, 57.068723514676094, 47.06353738903999, 41.35155089199543, 44.276869520545006, 44.29096296429634, 49.65114153921604, 44.18131224811077, 41.63628861308098, 42.39845551550388, 52.44294673204422, 39.435670897364616, 61.91220581531525, 59.82232555747032, 47.27947220206261, 51.95369638502598, 44.560638293623924, 38.078767508268356, 37.30450205504894, 43.70776645839214, 42.05607108771801, 44.320096001029015, 49.11731578409672, 57.90597438812256, 52.02199772000313, 53.44373323023319, 53.416929468512535, 51.6308581084013, 51.66236601769924, 50.84475629031658, 48.15328851342201, 49.67118926346302, 47.90689833462238, 47.48557314276695, 53.16159076988697, 51.66188724339008, 52.62298107147217, 53.73533338308334, 51.53134144842625, 50.2363595366478, 49.152129516005516, 47.876021191477776, 45.062921941280365, 44.06857989728451, 46.229816526174545, 43.90608921647072, 46.63436181843281, 43.36148723959923, 44.142907708883286, 42.443768084049225, 44.88301299512386, 44.346911162137985, 47.302555963397026, 44.34853367507458, 42.643895745277405, 45.107368156313896, 44.41705159842968, 47.51513935625553, 53.87722536921501, 55.24867817759514, 59.033043310046196, 57.04633891582489, 62.86764554679394, 52.854457050561905, 54.9588031321764, 63.713765144348145, 62.0751790702343, 63.43111731112003, 63.580928072333336, 53.83158981800079, 51.39414981007576, 51.05750307440758, 54.92126874625683, 57.79884673655033, 62.9123767465353, 62.74623066186905, 73.3978570997715, 61.21067225933075, 63.333318158984184, 10.917476322501898, 3.180835205130279, 58.66069369018078, 40.444273576140404, 32.36685700714588, 30.328194200992584, 31.14630740135908, 18.880525678396225, 28.136118426918983, 42.12547816336155, 51.44881747663021, 5.034034950658679, 0.05959378308034502, 0.05162688343261834, 0.03582697499950882, 0.16691782919224352, 0.009696008182800142, 0.14845552534097806, 0.19742949429200962, 0.11316735326545313, 0.2005526446737349, 0.12063283196766861, 0.16229957778705284, 0.17828816984547302, 0.025449082459090278, 0.10841282870387658, 0.015400083793792874, 0.04782764764968306, 0.040981461497722194, 0.06348230293951929, 0.1208886131644249, 0.1309244683943689, 1.5444783051498234, 61.884326711297035, 54.493920877575874, 44.82049494981766, 32.48064570128918, 43.61944779753685, 32.67074950039387, 26.875547468662262, 51.85764133930206, 78.63428771495819, 18.043210208415985, 8.662532921880484, 83.51802125573158, 70.0204311311245, 75.73833391070366, 69.27994966506958, 72.70777612924576, 63.19225832819939, 65.79753533005714, 55.33498674631119, 58.44567082822323, 60.29969774186611, 58.69522623717785, 58.550868183374405, 58.48979786038399, 54.23235051333904, 56.74632601439953, 55.958160907030106, 60.24638280272484, 58.25220040977001, 63.80483105778694, 60.38162514567375, 62.90658585727215, 62.38452807068825, 56.76429145038128, 48.599525168538094, 50.519391149282455, 44.994962587952614, 49.58496809005737, 46.419696137309074, 49.87618066370487, 48.226822167634964, 44.86814819276333, 43.00608851015568, 47.566318809986115, 49.279890060424805, 50.96093125641346, 49.70499984920025, 53.88639807701111, 57.83685989677906, 59.574119076132774, 62.67795592546463, 59.367448166012764, 56.59022659063339, 59.53919894993305, 55.10824531316757, 54.67681646347046, 56.28162994980812, 55.49411080777645, 55.96096895635128, 60.689401030540466, 57.68810547888279, 60.275227054953575, 55.448570251464844, 56.78237088024616, 61.856903582811356, 59.89609479904175, 48.827421739697456, 40.3792704641819, 45.0887643545866, 43.846162632107735, 48.31365890800953, 40.342769622802734, 39.75318185985088, 40.76484337449074, 51.48371860384941, 40.06228767335415, 60.769835114479065, 59.14482191205025, 46.87149189412594, 49.338441118597984, 47.58516199886799, 37.55356729030609, 34.97067868709564, 40.75192026793957, 40.31526289880276, 45.49049399793148, 50.383233055472374, 59.46550190448761, 52.848008796572685, 56.35618954896927, 55.03516003489494, 54.12260100245476, 52.12253652513027, 53.79695847630501, 49.93336379528046, 52.427318170666695, 47.92926773428917, 48.31473805010319, 52.67645180225372, 52.00991436839104, 52.5206183642149, 58.23559530079365, 54.4037327170372, 53.19833479821682, 51.52097560465336, 46.56293325126171, 45.12200117111206, 40.931833013892174, 47.89067700505257, 46.85779742896557, 48.11915874481201, 44.93415825068951, 46.87794774770737, 47.1053883433342, 45.88927119970322, 47.1061635017395, 46.90635122358799, 45.26990823447704, 46.6985821723938, 46.58154085278511, 50.83779886364937, 48.977802470326424, 55.41797049343586, 58.45709301531315, 64.23455759882927, 58.12788628041744, 66.08303681015968, 58.33524875342846, 63.14739413559437, 67.7368676662445, 66.70729771256447, 65.28528481721878, 69.71544429659843, 57.85360939800739, 53.48323971033096, 53.82590912282467, 60.34431874752045, 62.32098028063774, 69.74412515759468, 71.20062500238419, 77.82801657915115, 64.50903967022896, 72.36741319298744, 9.484598860144615, 4.913120213896036, 68.75082805752754, 41.48727960884571, 40.780293345451355, 35.106228813529015, 41.113140285015106, 26.07617676258087, 41.37694492936134, 53.1207999587059, 62.5230610370636, 7.946296529844403, 0.13563789281761274, 0.13435915752779692, 0.015619134246662725, 0.10995599863235839, 0.07242893771035597, 0.09371877225930803, 0.16710961499484256, 0.17985019774641842, 0.2904418087564409, 0.16386482660891488, 0.33194733783602715, 0.17338567588012666, 0.13586656335974112, 0.2667734131682664, 0.1536057036719285, 0.23826985125197098, 0.17594633769476786, 0.16702070570318028, 0.226852874038741, 0.2576448780018836, 1.7649539932608604, 73.14999639987946, 63.60032603144646, 48.79492208361626, 32.434029802680016, 48.29499050974846, 39.03457202017307, 35.10396793484688, 60.42275033891201, 85.97069084644318, 16.278847083449364, 14.083821717649698, 89.57342192530632, 73.15753519535065, 76.32691472768784, 71.06807291507721, 78.5019864141941, 64.36940476298332, 69.29654717445374, 56.9671967625618, 56.3692494481802, 61.436589136719704, 60.062940046191216, 60.001618936657906, 63.413129076361656, 57.874105498194695, 59.149605855345726, 60.73963053524494, 62.05650307238102, 59.902421459555626, 66.50685086846352, 62.33966767787933, 65.86379617452621, 63.148488476872444, 59.092373326420784, 50.33040069043636, 51.80983230471611, 45.61334900557995, 49.59428519010544, 49.549709782004356, 50.974519327282906, 53.019041419029236, 49.44191336631775, 47.65806868672371, 50.88563069701195, 48.978136852383614, 51.635828241705894, 50.97085252404213, 55.269238874316216, 60.05158245563507, 63.93661558628082, 66.88572093844414, 64.23546195030212, 60.30468687415123, 59.54648315906525, 60.363671109080315, 57.24315695464611, 61.71310029923916, 58.95116150379181, 61.3111312687397, 64.3610680103302, 63.51447343826294, 61.39675207436085, 60.01306392252445, 62.91152939200401, 66.93387195467949, 63.291034027934074, 50.85785038769245, 40.069393292069435, 48.528936356306076, 43.558689057826996, 49.362942203879356, 41.410424932837486, 40.303179547190666, 39.79758247733116, 54.10893693566322, 39.8490659147501, 57.936121970415115, 64.4272680580616, 52.01666280627251, 53.42366650700569, 51.81602217257023, 36.5992446988821, 38.06155823171139, 41.48659564554691, 42.692723125219345, 47.72119089961052, 52.37864278256893, 63.737236484885216, 56.84656083583832, 61.437086910009384, 62.04649440944195, 56.8968815356493, 53.802848160266876, 56.98315590620041, 55.15443943440914, 56.58069670200348, 49.20799791812897, 50.57769522070885, 53.56701381504536, 56.51788987219334, 52.97120958566666, 59.174688309431076, 57.131066769361496, 55.858739241957664, 58.027928844094276, 49.24031898379326, 49.64346595108509, 41.642022505402565, 47.650852873921394, 49.32365231215954, 49.065828546881676, 47.486048117280006, 48.20769019424915, 50.575096160173416, 47.357873395085335, 51.8972922116518, 50.96908941864967, 48.76378655433655, 48.44919003546238, 48.210950419306755, 54.843764305114746, 52.7002727240324, 56.523213386535645, 56.58905245363712, 67.62404412031174, 58.44850167632103, 64.66324299573898, 59.83463689684868, 67.89552435278893, 70.77103525400162, 71.29017099738121, 68.49029883742332, 69.65025499463081, 60.44153273105621, 55.94983175396919, 54.2779366672039, 59.89969700574875, 66.11331358551979, 71.83639168739319, 70.72524771094322, 82.8827865421772, 65.6589187681675, 76.90899029374123, 17.066009044647217, 4.215418277308345, 70.11166423559189, 50.57460218667984, 45.899732038378716, 38.683197274804115, 47.84615859389305, 29.713159203529358, 43.26200097799301, 56.960163339972496, 75.27477398514748, 9.443244729191065, 0.17015187127981335, 0.27283117873594165, 0.10830221901414916, 0.2686597447609529, 0.2217593661043793, 0.20731270458782092, 0.2642721380107105, 0.18876135785831138, 0.5721259186975658], [0.040082349587464705, 0.09093946631764993, 0.046523137571057305, 0.055661209335085005, 0.09629435124224983, 0.04001819463155698, 0.0602316961158067, 0.044122226754552685, 0.021265662799123675, 0.05812266455905046, 0.05678276516846381, 2.2923645051196218, 49.28060062229633, 49.62586909532547, 40.88560089468956, 34.41993623971939, 38.541662469506264, 29.77408893406391, 21.312507279217243, 36.338217705488205, 71.07049718499184, 37.621408849954605, 3.6495671281591058, 62.45402634143829, 70.96322134137154, 69.75604891777039, 70.60907274484634, 66.14820331335068, 64.41094413399696, 54.51533652842045, 58.34842264652252, 57.38922491669655, 58.03184263408184, 55.7440309971571, 53.454163670539856, 52.60496623814106, 55.13282619416714, 53.55000972747803, 58.466710299253464, 59.45317916572094, 57.529562786221504, 58.297873958945274, 60.228998735547066, 56.445393562316895, 59.82751987874508, 52.22112983465195, 43.815935254096985, 44.998352006077766, 45.134859681129456, 47.190484777092934, 46.315661519765854, 43.88098396360874, 44.55797463655472, 42.76509404182434, 41.322725638747215, 45.52263647317886, 46.32945477962494, 47.1372040361166, 54.383438006043434, 55.94970256090164, 54.119504168629646, 54.9633476883173, 56.240953132510185, 53.49413752555847, 55.2435028553009, 52.211250364780426, 54.59591120481491, 53.40897649526596, 51.47054851055145, 52.35607959330082, 53.27890187501907, 52.96812415122986, 56.38983674347401, 54.98251385986805, 53.89879681169987, 54.26795840263367, 53.558137491345406, 58.32807093858719, 48.993795812129974, 41.776489689946175, 40.96367910504341, 40.555220022797585, 42.67959102988243, 41.41234003007412, 47.61378586292267, 47.72067032754421, 55.46427480876446, 52.75039963424206, 45.25004290044308, 55.38455508649349, 52.56397023797035, 49.98224817216396, 42.53308989107609, 44.15530264377594, 38.708226531744, 38.50152142345905, 41.284514889121056, 39.50592912733555, 53.45061466097832, 60.25169491767883, 53.62675420939922, 48.029833137989044, 48.95159527659416, 49.45049710571766, 48.90239551663399, 52.85157300531864, 49.095292165875435, 48.13505709171295, 51.35814294219017, 50.7844877243042, 51.837749406695366, 55.15538938343525, 54.65068906545639, 53.65137308835983, 54.380154982209206, 50.63486695289612, 52.92106367647648, 52.38863244652748, 48.69979418814182, 47.64264911413193, 46.33918225765228, 44.07549932599068, 44.29192811250687, 40.7049585878849, 45.8123367279768, 45.62718786299229, 45.26042774319649, 45.385992005467415, 45.321729853749275, 44.76426176726818, 45.716110691428185, 44.72947843372822, 44.202933087944984, 45.19408330321312, 52.744832932949066, 56.03963613510132, 60.13284109532833, 60.50014838576317, 61.955930069088936, 63.823640048503876, 58.91312174499035, 57.018019035458565, 63.9011786878109, 60.7157564163208, 63.05158227682114, 56.50248929858208, 51.62879101932049, 50.647239089012146, 57.31208525598049, 57.13914133608341, 68.4244179725647, 65.50107523798943, 72.5643490254879, 64.18906643986702, 55.21730326116085, 1.5113107161596417, 12.265494838356972, 50.422199964523315, 50.203077122569084, 25.11434007436037, 24.549112804234028, 24.804151318967342, 32.46050678193569, 39.85603854060173, 34.880315735936165, 54.60958667099476, 8.60652107745409, 0.09412788858753629, 0.16288845712551847, 0.10224467609077692, 0.03882456512656063, 0.07960395465488546, 0.07671668849070556, 0.026458082320459653, 0.04334111261414364, 0.0628037795831915, 0.01248370132088894, 0.05605651058431249, 0.04205237688438501, 0.09198743820888922, 0.007577437709187507, 0.07783177279634401, 0.0395673844468547, 0.03839192271698266, 0.00882938657014165, 0.06095695251133293, 0.11117817484773695, 3.259091293439269, 58.43027025461197, 52.842803075909615, 46.45053908228874, 44.68815565109253, 45.35812430083752, 32.910026460886, 28.273908533155918, 41.13121971487999, 76.2957563996315, 47.996398732066154, 4.800242995843291, 64.53193724155426, 75.89953646063805, 72.64669060707092, 74.2967064678669, 67.76393741369247, 67.80602395534515, 58.19863848388195, 61.98816753923893, 62.12403304874897, 61.475084871053696, 61.27572476863861, 57.358153983950615, 55.148173570632935, 57.23966494202614, 58.4276407957077, 61.53305076062679, 64.06900808215141, 60.57365924119949, 60.73515437543392, 61.10055036842823, 60.59241883456707, 62.20507889986038, 53.543781861662865, 44.888503700494766, 47.00492173433304, 47.574328780174255, 48.06244298815727, 48.76730516552925, 46.02871611714363, 46.922108978033066, 43.642725348472595, 43.378008753061295, 47.452955693006516, 47.23986692726612, 50.18363356590271, 56.38375326991081, 57.55472503602505, 57.469339817762375, 59.999019876122475, 59.18895274400711, 58.95768575370312, 58.36706064641476, 55.697510093450546, 55.34615434706211, 54.89839017391205, 55.21272450685501, 55.18973954021931, 56.772571206092834, 57.6656486839056, 61.56391650438309, 59.71611745655537, 58.56851443648338, 57.95076638460159, 54.73023019731045, 61.284209713339806, 48.727407306432724, 41.451044753193855, 40.49247018992901, 39.14030134677887, 41.951827481389046, 39.7587675601244, 44.51039358973503, 44.91154566407204, 53.60660009086132, 50.4013504832983, 44.979151636362076, 56.76889680325985, 53.875059485435486, 48.41092988848686, 39.75771501660347, 41.36459559202194, 39.61524926126003, 39.025133326649666, 40.13550594449043, 37.92987249791622, 56.20322495698929, 64.14744347333908, 56.350432857871056, 51.34524263441563, 51.729470416903496, 50.03906652331352, 48.65316689014435, 55.07233344018459, 49.78725403547287, 49.26377892494202, 50.454433634877205, 52.692695930600166, 54.52225215733051, 55.80333061516285, 55.37696309387684, 57.63765938580036, 55.6939534842968, 53.17918382585049, 53.58011931180954, 52.25815884768963, 48.98645840585232, 51.43738768994808, 46.79427623748779, 44.128989055752754, 44.84638296067715, 44.31889146566391, 49.16519321501255, 46.924620643258095, 46.500320211052895, 47.95262508094311, 48.05156037211418, 47.7604503929615, 46.105141416192055, 48.439040780067444, 47.20373846590519, 51.25522166490555, 52.45696797966957, 58.24400044977665, 62.4073800444603, 61.19618363678455, 60.51117919385433, 66.36438891291618, 64.08174499869347, 56.18381939828396, 69.84197750687599, 66.44759684801102, 65.3858046233654, 61.00541107356548, 53.32604594528675, 52.235508263111115, 60.179346799850464, 61.15020230412483, 71.2180432677269, 70.4079419374466, 76.3821105659008, 68.2138940691948, 55.35940803587437, 1.206962128635496, 17.546837143599987, 54.29798439145088, 54.147330075502396, 35.319708958268166, 29.00237124413252, 29.741881862282753, 37.22439855337143, 41.594703644514084, 45.76832368969917, 66.55147567391396, 15.08881364017725, 0.25836152548436075, 0.10557044763118029, 0.05819182901177555, 0.037704218993894756, 0.06911567877978086, 0.014724551292601973, 0.02329372233361937, 0.031712990676169284, 0.027976063756796066, 0.08997443685075268, 0.15559658902930096, 0.15419152536196634, 0.158476032956969, 0.24448587239021435, 0.17473329731728882, 0.16262101678876206, 0.1817592539009638, 0.07629860701854341, 0.257984870695509, 0.1811362209264189, 4.535425705835223, 70.2212655544281, 61.99733264744282, 52.59772762656212, 44.442669823765755, 53.13288331031799, 38.800633773207664, 38.163343369960785, 47.98616588115692, 86.8646764755249, 45.749442502856255, 6.748956553637981, 69.81217950582504, 74.80768784880638, 75.35208463668823, 73.78319442272186, 71.02240696549416, 68.0859625339508, 58.630230724811554, 64.65628176927567, 65.8676415681839, 63.56384798884392, 64.6902747452259, 60.90847447514534, 58.519200682640076, 61.25083610415459, 61.01890794932842, 64.51429098844528, 65.54256901144981, 61.66407912969589, 62.213005274534225, 62.685198336839676, 61.72747492790222, 60.83077624440193, 53.22206452488899, 44.51296225190163, 50.15852831304073, 47.08302654325962, 49.3876750767231, 48.783807680010796, 48.73552367091179, 49.0985181927681, 46.85312747955322, 46.65160529315472, 48.296677619218826, 49.95318353176117, 51.0782765597105, 60.677891448140144, 62.89641760289669, 60.14560081064701, 63.25413040816784, 62.52379819750786, 60.09601727128029, 64.60452854633331, 57.091028317809105, 60.25880813598633, 57.40714855492115, 59.01980102062225, 59.98092524707317, 62.42968864738941, 62.036132365465164, 66.31476357579231, 63.54637272655964, 62.53672130405903, 59.95487384498119, 58.018288761377335, 63.74931983649731, 51.73099413514137, 42.80439153313637, 39.855897948145866, 40.056960359215736, 41.86280965805054, 41.54099352657795, 46.82111419737339, 46.69353224337101, 53.902551010251045, 53.75638045370579, 45.99722720682621, 55.85397809743881, 57.21882306039333, 48.015967682003975, 42.12450921535492, 44.36406724154949, 41.33811101317406, 38.801705315709114, 42.65616908669472, 37.52061165869236, 59.995546862483025, 66.84405237436295, 61.83711424469948, 55.657103061676025, 55.90985789895058, 54.74106341600418, 54.27411027252674, 56.78615167737007, 53.38878057897091, 50.936977341771126, 54.05867703258991, 55.429749861359596, 57.20140479505062, 55.31403847038746, 57.31573686003685, 58.683887645602226, 57.89986051619053, 54.0595243871212, 57.144373655319214, 54.75862607359886, 50.173408314585686, 54.65702332556248, 48.2880824804306, 46.705756187438965, 47.13022381067276, 43.53234127163887, 51.27197116613388, 48.98656480014324, 49.11080673336983, 50.5542466789484, 53.31403099000454, 48.93585652112961, 49.51716832816601, 50.389905497431755, 49.27541770040989, 51.10970467329025, 53.7138569355011, 60.282549262046814, 63.518904000520706, 65.70296600461006, 63.75466614961624, 63.72073017060757, 60.63181512057781, 60.31398497521877, 68.22198763489723, 66.69228091835976, 68.04905131459236, 62.66144581139088, 57.240253910422325, 52.96726159751415, 62.206967398524284, 62.01969064772129, 72.94511899352074, 71.48875594139099, 76.79170578718185, 70.28491973876953, 67.04979613423347, 2.566012521274388, 14.119355510920286, 63.78337740898132, 62.49277666211128, 38.46219353377819, 31.905307173728943, 34.406948536634445, 46.57119780778885, 53.67606796324253, 48.65448161959648, 80.27422651648521, 17.34569303691387, 0.43580297904554754, 0.2796342090005055, 0.15769092977279797, 0.08293269478599541, 0.20130305987549946, 0.16293832944938913, 0.1365127068129368, 0.09822366802836768, 0.14609896898036823], [0.016924089613894466, 0.03150760130665731, 0.07646187950740568, 0.010625249433360295, 0.09875991425360553, 0.16940446919761598, 0.019495026463118847, 0.09178086882457137, 0.03991862067778129, 0.14315860957140103, 0.18788749381201342, 2.480841279029846, 41.805516332387924, 59.712351858615875, 34.36521917581558, 31.183391511440277, 46.411773562431335, 37.213983312249184, 28.643698990345, 31.07671793550253, 61.91517345607281, 57.20807723701, 5.017349096015096, 30.787483155727386, 83.99947822093964, 62.70405672490597, 75.57802811264992, 62.923031374812126, 65.95495328307152, 50.95757603645325, 61.49287931621075, 54.46851924061775, 59.59369942545891, 54.548364356160164, 55.39277024567127, 50.39029687643051, 55.1069799810648, 55.93604989349842, 62.65924192965031, 56.88030302524567, 60.34360058605671, 56.78125374019146, 58.93065020442009, 58.88841927051544, 61.877088099718094, 47.37774632871151, 48.23998846113682, 46.12922452390194, 45.041722878813744, 43.25028620660305, 47.70973451435566, 46.57309390604496, 44.41262483596802, 44.888218715786934, 42.319446355104446, 42.71841734647751, 45.3250926733017, 44.16957467794418, 52.65951611101627, 57.310956716537476, 55.75330249965191, 52.231161296367645, 53.419133350253105, 55.92457450926304, 53.82078319787979, 52.969055101275444, 53.79743345081806, 52.14255765080452, 52.68135353922844, 51.87588416039944, 54.21358332037926, 53.32675650715828, 50.84894746541977, 50.65719835460186, 50.56306600570679, 54.18304055929184, 54.17701408267021, 51.79076112806797, 45.35597361624241, 36.662317514419556, 38.716407492756844, 39.74769875407219, 40.924218222498894, 41.45918011665344, 45.03594718873501, 49.3981359153986, 44.6454269438982, 45.150218456983566, 51.49707868695259, 48.99518273770809, 45.67093871533871, 41.08127139508724, 40.45137919485569, 41.011180356144905, 39.84708622097969, 40.32344006001949, 38.94433066248894, 39.98925939202309, 49.59778480231762, 56.576380133628845, 54.77737806737423, 55.764576494693756, 49.58521127700806, 50.56647062301636, 49.875823482871056, 52.55061775445938, 50.99615916609764, 50.185609459877014, 51.507262140512466, 53.86726230382919, 52.322238609194756, 53.668901547789574, 53.88020060956478, 53.13493140041828, 52.89551764726639, 53.37168529629707, 51.788295060396194, 52.45417132973671, 52.3315405100584, 49.5105604827404, 46.50805279612541, 44.56094607710838, 41.85141786932945, 46.117388159036636, 46.837650910019875, 45.39898730814457, 46.45027309656143, 46.29565939307213, 43.638043999671936, 45.334386974573135, 43.91849935054779, 45.394233763217926, 46.10221937298775, 46.13677091896534, 47.34683498740196, 53.1559594720602, 56.84375278651714, 59.94745284318924, 56.72002002596855, 65.28679713606834, 63.7242715805769, 51.90267272293568, 60.98972171545029, 67.00369700789452, 60.91934949159622, 63.388947173953056, 53.74008312821388, 51.418164521455765, 54.71583656966686, 61.51769198477268, 62.86431312561035, 72.53686130046844, 66.23177602887154, 72.8613942861557, 24.430581964552402, 0.4469052411150187, 30.872649885714054, 61.34859345853329, 42.0141289383173, 21.808076687157154, 37.30111263692379, 25.40088649839163, 37.419309094548225, 37.151351273059845, 39.84062276780605, 56.42905443906784, 21.632438711822033, 0.2622700313804671, 0.09697769855847582, 0.04494244836678263, 0.08286575306556188, 0.011534313543961616, 0.04292416291718837, 0.0072107866071746685, 0.05399752204539254, 0.033918208282557316, 0.07321231911191717, 0.10278311907313764, 0.07535106997238472, 0.04185601574135944, 0.0417845394986216, 0.13140410359483212, 0.09902022997266613, 0.07550917711341754, 0.026332379202358425, 0.14492842397885397, 0.34170138475019485, 3.120712931267917, 52.20120370388031, 64.76355761289597, 41.53309755027294, 35.29837690293789, 53.39492104947567, 43.65578144788742, 39.55189526081085, 39.31813560426235, 65.77456936240196, 66.7998531460762, 7.075643548741937, 31.01670205593109, 89.09047544002533, 66.62722080945969, 81.2191142141819, 65.22476926445961, 67.80714869499207, 56.09190613031387, 65.12404426932335, 57.28108651936054, 63.53927470743656, 58.22133086621761, 59.5234639942646, 54.09857489168644, 58.08561734855175, 58.53575639426708, 62.79818147420883, 57.58811004459858, 62.22440466284752, 60.51608853042126, 61.331277787685394, 59.17560026049614, 62.80503250658512, 49.69079241156578, 50.227927789092064, 46.966228410601616, 46.357561871409416, 46.33203104138374, 49.47299189865589, 47.87367671728134, 46.5396822988987, 46.95857182145119, 46.542991921305656, 44.44848731160164, 48.450789749622345, 47.73183412849903, 55.242416113615036, 61.28666438162327, 59.66874159872532, 57.177990451455116, 56.5826003998518, 57.86655530333519, 55.85089646279812, 53.243084996938705, 56.77578963339329, 54.107789397239685, 54.303577691316605, 53.72715622186661, 56.11074931919575, 57.547091245651245, 57.867117673158646, 54.395221173763275, 55.687562227249146, 59.513922706246376, 57.552262768149376, 56.06352545320988, 44.488882943987846, 36.04977898299694, 38.17880854010582, 38.714488595724106, 39.30237405002117, 39.76221777498722, 43.88090796768665, 48.82250100374222, 45.859214812517166, 45.812891498208046, 50.38664527237415, 49.38224136829376, 45.452252849936485, 42.588544115424156, 43.53994846343994, 41.50676876306534, 38.89321580529213, 38.10545727610588, 39.51279915869236, 40.35759262740612, 49.8196928948164, 59.933120012283325, 55.10591223835945, 58.32894869148731, 51.57414235174656, 51.87907978892326, 54.10399720072746, 52.09331229329109, 54.126594588160515, 50.93513064086437, 54.88081231713295, 53.91415558755398, 55.17521291971207, 56.07728831470013, 56.3722512871027, 54.91556525230408, 56.51016488671303, 53.81040595471859, 52.24854536354542, 52.2287218272686, 52.57573060691357, 50.00032000243664, 46.90046913921833, 45.552548468112946, 42.99229525029659, 47.6207584887743, 48.55123355984688, 48.31994377076626, 49.744802713394165, 49.46466654539108, 49.61398333311081, 48.2047301530838, 46.83899983763695, 50.2757216244936, 50.748116075992584, 49.106953740119934, 49.99118149280548, 55.93610309064388, 58.382533416152, 62.213339656591415, 60.80664373934269, 64.58768025040627, 61.47093169391155, 52.87562571465969, 62.72405505180359, 70.01668453216553, 64.17116180062294, 65.84741145372391, 53.62849071621895, 53.067876398563385, 57.77081944048405, 66.03376865386963, 68.27943295240402, 76.98316231369972, 67.90034249424934, 74.66366797685623, 20.405011475086212, 0.6627384689636528, 38.39545391499996, 63.90595883131027, 48.45672123134136, 33.32138478755951, 45.37212274968624, 38.16839709877968, 42.00700432062149, 38.59042905271053, 47.82420337200165, 67.6882378757, 33.090965151786804, 0.26047207473311573, 0.09939900730387308, 0.06582462490769103, 0.0637370599724818, 0.03360709255503025, 0.02233430164778838, 0.07121083588572219, 0.056342961033806205, 0.10397793230367824, 0.22657678026007488, 0.23691823706030846, 0.12404058114043437, 0.23242493363795802, 0.22149902069941163, 0.2554102713475004, 0.2325698602362536, 0.19153396220644936, 0.14661151100881398, 0.26196732418611646, 0.666173662757501, 3.892743866890669, 61.02789826691151, 76.43881112337112, 47.924111410975456, 41.63465090095997, 64.77394625544548, 48.576441407203674, 46.40372559428215, 45.3664268553257, 72.97146677970886, 70.7283179461956, 7.744906861335039, 41.11784063279629, 91.72731354832649, 69.20169666409492, 83.78178790211678, 67.6977601647377, 70.38145735859871, 58.20917151868343, 67.34479710459709, 61.47879347205162, 66.98226615786552, 61.97377011179924, 63.47454138100147, 58.40928018093109, 63.048246055841446, 60.12193948030472, 67.50520929694176, 60.17119623720646, 62.30931870639324, 60.74527323246002, 61.82696118950844, 62.56835080683231, 63.87851670384407, 51.037854328751564, 52.421865463256836, 49.03280071914196, 48.701021522283554, 47.84189522266388, 52.19948619604111, 47.32572712004185, 48.33942912518978, 50.968637242913246, 47.76103936135769, 45.98054990172386, 49.31849978864193, 48.950276747345924, 57.95589230954647, 62.98173822462559, 61.69010013341904, 58.91156002879143, 59.30231586098671, 63.17205861210823, 60.40449611842632, 57.55627155303955, 59.09787543118, 58.05378645658493, 58.42571049928665, 58.46169076859951, 63.0714476108551, 62.45599463582039, 62.02679626643658, 58.52173514664173, 59.42682757973671, 63.91681104898453, 61.1457185447216, 57.153284177184105, 48.454897329211235, 37.12703637778759, 40.209092795848846, 39.725314155220985, 41.24959096312523, 39.74769115447998, 43.76962713897228, 48.10743257403374, 47.57184371352196, 45.390658155083656, 52.500464245676994, 52.54786290228367, 47.82136112451553, 43.73612053692341, 45.97275651991367, 43.74457888305187, 42.51044690608978, 40.91884911060333, 41.34891763329506, 42.23736695945263, 53.61467085778713, 61.92266285419464, 59.03704069554806, 62.402919083833694, 56.32641054689884, 55.130508318543434, 57.06391677260399, 56.21007598936558, 54.47856590151787, 54.54833395779133, 56.75971269607544, 58.42675544321537, 56.35925978422165, 59.70575161278248, 58.36560532450676, 57.43511125445366, 57.377251759171486, 59.62938331067562, 53.712052032351494, 53.967215940356255, 52.85628095269203, 50.49580581486225, 48.17104496061802, 47.495274022221565, 45.001239851117134, 50.56312680244446, 53.47927272319794, 49.3174434453249, 52.626381888985634, 52.081730514764786, 52.25716330111027, 50.65811790525913, 49.1918183863163, 54.230089634656906, 53.60840119421482, 51.537333726882935, 53.45460444688797, 59.181383550167084, 62.86076031625271, 65.84590673446655, 61.9024783372879, 69.70302656292915, 63.519074991345406, 52.2890055924654, 64.81611639261246, 70.89336588978767, 66.96047052741051, 68.49600613117218, 57.80426524579525, 55.910412669181824, 62.607215121388435, 67.82164111733437, 70.66492974758148, 79.12766844034195, 72.74988546967506, 77.37009555101395, 31.334328912198544, 0.7298330718185753, 36.823075488209724, 73.85136276483536, 56.611452251672745, 35.5265698581934, 45.91640554368496, 40.1117268204689, 52.51358114182949, 51.399788707494736, 55.403911247849464, 74.64030683040619, 38.687783628702164, 0.5055580625776201, 0.23726548795821145, 0.24276803800603375, 0.1454415448824875, 0.07229233800899237, 0.180071075737942, 0.14417226455407217, 0.17012726166285574, 0.18392647354630753], [0.06893446858157404, 0.03147689494653605, 0.08890987795894034, 0.072821949434001, 0.16687885159626603, 0.05992814287310466, 0.07904928832431324, 0.05706959040253423, 0.07835074924514629, 0.27298557513859123, 0.42612946999724954, 5.048499349504709, 53.96986439824104, 54.98273424804211, 45.40636271238327, 40.0956878811121, 36.35362587869167, 32.94431582093239, 16.74244500696659, 29.972856268286705, 57.02683076262474, 57.87933021783829, 10.14325076714158, 8.854757007211447, 85.2705480158329, 64.07939672470093, 76.56036660075188, 60.18313139677048, 64.72518727183342, 51.659709960222244, 60.70502199232578, 52.707796320319176, 59.247336611151695, 51.29602387547493, 56.211599707603455, 53.472246900200844, 58.07217366993427, 58.853692933917046, 62.740242183208466, 56.04388810694218, 63.238133266568184, 58.48952807486057, 61.230298206210136, 57.77519680559635, 57.44365319609642, 46.5127569437027, 44.73896272480488, 45.11497534811497, 48.85253459215164, 47.914737313985825, 49.85075622797012, 47.9817771166563, 50.387830808758736, 46.9695608317852, 47.098867893218994, 43.89927618205547, 42.11316682398319, 44.82780575752258, 50.682645589113235, 51.956994608044624, 55.28219997882843, 55.60622379183769, 54.0869627147913, 53.48163619637489, 54.062925204634666, 51.97425328195095, 54.01288568973541, 50.61449244618416, 51.86275586485863, 51.66600622236729, 51.704456359148026, 51.34275756776333, 52.15697407722473, 52.31455162167549, 50.60459017753601, 53.53685863316059, 54.194656535983086, 51.445758640766144, 39.452838376164436, 38.54207284748554, 34.380802139639854, 39.50266130268574, 40.12443333864212, 42.62138195335865, 45.498378574848175, 44.06264081597328, 45.29741495847702, 43.86169619858265, 41.79586865007877, 41.19775414466858, 40.02221882343292, 42.25602015852928, 38.93026381731033, 40.022469609975815, 39.17992182075977, 37.89789341390133, 40.76726384460926, 36.56480334699154, 45.409600138664246, 59.61514167487621, 55.70241943001747, 54.62192080914974, 53.39679814875126, 50.02792552113533, 51.32816635072231, 53.32060843706131, 51.28855347633362, 53.365856409072876, 52.51637779176235, 51.02751888334751, 50.209920555353165, 49.89969380199909, 52.53034584224224, 50.70785343647003, 52.038055658340454, 55.009256824851036, 54.427413046360016, 52.65320844948292, 52.25259214639664, 47.78210923075676, 44.87135902047157, 43.45120422542095, 43.75313602387905, 45.1843748241663, 47.5288338214159, 47.80012026429176, 45.158167630434036, 45.47448545694351, 46.050036773085594, 47.37569063901901, 46.035339161753654, 46.53800658881664, 44.41079333424568, 46.58019572496414, 48.2323432713747, 51.227958127856255, 51.764002963900566, 58.61571930348873, 61.361273378133774, 62.265776842832565, 59.78352203965187, 56.79096221923828, 52.40556053817272, 65.15918478369713, 58.573112189769745, 64.61801022291183, 57.7503727376461, 52.63108603656292, 51.90379746258259, 64.28348377346992, 64.68199878931046, 74.78278398513794, 67.58334070444107, 65.75026586651802, 3.814026340842247, 4.344662642106414, 46.30627982318401, 61.447205767035484, 27.81259998679161, 26.30459200590849, 26.43384587019682, 25.972324535250664, 41.500077322125435, 45.59569135308266, 47.85944648087025, 47.21477307379246, 36.65045075118542, 0.867860249709338, 0.3104896517470479, 0.14371416647918522, 0.046173378214007244, 0.05283108483126853, 0.054045950892032124, 0.07446660063578747, 0.11226399627048522, 0.0429161662759725, 0.10374010365922004, 0.005620019965135725, 0.1861982766422443, 0.08946565751102753, 0.08463573816698045, 0.07685837190365419, 0.0208612628193805, 0.06333006618660875, 0.16317543078912422, 0.21709300868678838, 0.5022379907313734, 8.434844389557838, 64.17230933904648, 64.07398581504822, 49.267327934503555, 38.58361601829529, 44.09397013485432, 40.431213676929474, 23.984776586294174, 34.15096007287502, 64.08272534608841, 65.99221408367157, 13.906212598085403, 9.311724286526442, 89.88774105906487, 65.5809697508812, 81.91052511334419, 65.57587042450905, 68.70805755257607, 53.87605883181095, 64.85461592674255, 55.9399750828743, 64.04157355427742, 54.80399563908577, 58.848126232624054, 57.509617656469345, 62.85399287939072, 59.59053039550781, 64.90758508443832, 59.43897932767868, 66.649609208107, 59.57905501127243, 63.22350785136223, 59.1452930867672, 60.992438569664955, 47.93592117726803, 47.33265794813633, 46.88348785042763, 50.07881999015808, 51.11620992422104, 53.75076435506344, 48.85636858642101, 53.84854830801487, 50.34905768930912, 49.804193526506424, 47.089349403977394, 45.51308758556843, 47.17250034213066, 54.95960868895054, 55.28489403426647, 58.88472966849804, 58.94479684531689, 56.808475479483604, 54.73548151552677, 58.15620236098766, 56.25104919075966, 57.683933302760124, 52.934678345918655, 56.16727128624916, 53.720054402947426, 55.644841119647026, 55.11748641729355, 56.534190997481346, 55.54292678833008, 53.82622070610523, 54.7957044839859, 56.33544646203518, 52.542216405272484, 40.86904518306255, 38.29475171864033, 33.405504673719406, 38.78738388419151, 37.58398085832596, 42.990144565701485, 45.49295246601105, 42.83144988119602, 44.66425113379955, 41.604172736406326, 41.98858290910721, 42.427611351013184, 41.24474622309208, 44.46837544441223, 40.61655633151531, 41.507220938801765, 38.6748643219471, 39.184314385056496, 38.74640308320522, 34.612753093242645, 45.43076120316982, 59.392086043953896, 56.619709208607674, 55.08226230740547, 54.02969978749752, 53.8533740490675, 52.556161656975746, 54.36753585934639, 50.23482821881771, 53.812913820147514, 52.494384571909904, 52.58324280381203, 52.88733288645744, 52.19343692064285, 55.22544622421265, 53.373839780688286, 56.88498817384243, 55.752356350421906, 56.4460813254118, 53.96773651242256, 52.55605526268482, 49.80339176952839, 48.41699056327343, 43.2157726585865, 46.626598834991455, 50.01087583601475, 51.26494534313679, 50.756753012537956, 48.401061818003654, 47.436320185661316, 47.313814759254456, 49.12771962583065, 46.70183099806309, 47.892964482307434, 46.76533319056034, 48.157878667116165, 50.738985165953636, 53.03827978670597, 54.88563425838947, 60.822701677680016, 60.659557431936264, 64.49358209967613, 66.09761282801628, 58.04525971412659, 54.68638435006142, 65.57031512260437, 64.59235399961472, 68.33207532763481, 58.95350597798824, 54.808399602770805, 55.10190725326538, 66.87978565692902, 65.76761573553085, 77.7180352807045, 70.45830443501472, 70.35994291305542, 3.4528338722884655, 5.450879707932472, 56.708704233169556, 62.79390290379524, 35.00047288835049, 35.60062028467655, 19.827174581587315, 25.579545311629772, 46.67899802327156, 46.97439417243004, 58.915561214089394, 56.69787481427193, 51.76757477223873, 1.2222285219468176, 0.17657967167906463, 0.11649696913082153, 0.05659018155711237, 0.05154903956281487, 0.0923972818418406, 0.0958321565121878, 0.11258920538239181, 0.10617974345223047, 0.169237500813324, 0.24204929766710848, 0.28500539890956134, 0.1946944574592635, 0.35789572983048856, 0.31041715876199305, 0.34810692071914673, 0.31315921631176025, 0.28318657306954265, 0.3969209420029074, 0.8631033799611032, 9.680551495403051, 77.15693458914757, 72.7940770983696, 57.63147711753845, 52.51038171350956, 50.30181102454662, 43.98114278912544, 25.394459143280983, 40.588688626885414, 70.43396294116974, 73.18052396178246, 13.742867913097143, 15.309880077838898, 93.03041562438011, 67.56044313311577, 85.23629665374756, 67.8542585670948, 72.18050882220268, 57.40037351846695, 69.1866646707058, 60.72301782667637, 67.35146194696426, 56.238278076052666, 62.07249641418457, 60.14414928853512, 64.19780597090721, 61.719005182385445, 67.60347962379456, 59.974514991045, 69.30098533630371, 61.49109721183777, 66.6986645758152, 61.018892750144005, 63.213977962732315, 50.92868618667126, 49.17667239904404, 49.793671891093254, 53.086928576231, 52.13121145963669, 53.528252094984055, 49.906214252114296, 56.252914890646935, 52.48523846268654, 52.75731146335602, 47.150328531861305, 46.736773923039436, 48.98784153163433, 54.21417608857155, 54.41169708967209, 59.57533121109009, 61.49721868336201, 59.01436731219292, 58.98797772824764, 62.17442214488983, 59.88630272448063, 61.43012948334217, 57.83476620912552, 60.80114163458347, 59.99600663781166, 60.68919584155083, 62.02236570417881, 61.945374235510826, 59.46322962641716, 56.17520526051521, 58.347191512584686, 59.136561155319214, 56.09245330095291, 39.63298670947552, 38.71580712497234, 34.70367841422558, 40.789306461811066, 39.23657298088074, 43.73447522521019, 45.61027877032757, 44.405720606446266, 43.19832019507885, 43.788607120513916, 43.94008219242096, 44.09153066575527, 43.130957409739494, 47.57047198712826, 41.12776570022106, 44.691298082470894, 40.68641558289528, 39.872309267520905, 40.629232451319695, 34.243770092725754, 45.51912546157837, 63.8369545340538, 59.44263853132725, 56.99998140335083, 57.169372513890266, 56.1095067858696, 56.25441201031208, 57.55950517952442, 53.504833951592445, 57.73284427821636, 57.10931673645973, 55.69073125720024, 57.176538929343224, 53.715920224785805, 58.61490994691849, 58.125591203570366, 58.90472039580345, 61.08288511633873, 59.73421208560467, 55.73498748242855, 55.60342334210873, 50.87971821427345, 49.711831882596016, 46.292114183306694, 49.531710147857666, 51.10263705253601, 52.6387008279562, 51.44422732293606, 52.40449279546738, 49.87773858010769, 50.927329659461975, 52.48836949467659, 50.55421248078346, 53.34558829665184, 49.23113487660885, 51.266959235072136, 52.6179501414299, 54.62433747947216, 58.032473400235176, 65.18902838230133, 65.304686576128, 68.61935511231422, 67.24471807479858, 58.753499910235405, 54.35012899339199, 69.38711151480675, 66.08539268374443, 74.04119297862053, 63.37013058364391, 57.1804641187191, 57.01879419386387, 69.64268580079079, 68.80413919687271, 81.588796377182, 73.47904354333878, 75.94030067324638, 6.77725980989635, 4.072134140878916, 58.452571257948875, 71.53179243206978, 43.42451445758343, 34.99796882271767, 35.80344200134277, 38.36001701653004, 55.6485041230917, 58.39957930147648, 62.12018005549908, 64.24974918365479, 59.66160178184509, 2.1351073309779167, 0.3672203700989485, 0.17462046118453145, 0.13788072246825323, 0.16341449139872566, 0.25654471828602254, 0.15340093028498814, 0.24117540393490344, 0.2053080449695699], [0.05716226980439387, 0.029605424861074425, 0.03606057711294852, 0.13833721750415862, 0.018649903940968215, 0.07972150342538953, 0.06977425320656039, 0.11631029672571458, 0.088808767759474, 0.29273884487338364, 0.4683897632639855, 12.162589710205793, 62.19662055373192, 54.32897552847862, 56.09399601817131, 50.63086576759815, 40.22632107138634, 23.98748204112053, 33.01311492919922, 26.371052339673042, 59.285471364855766, 59.99548986554146, 28.731179796159267, 0.8147980563808233, 63.35705168545246, 70.78754156827927, 72.88376748561859, 66.01014152169228, 61.589888110756874, 52.82625496387482, 57.068818509578705, 51.23912572860718, 57.158995270729065, 55.737632140517235, 59.107937291264534, 56.05894289910793, 60.27338795363903, 55.986416190862656, 61.48610807955265, 59.293564930558205, 63.69073458015919, 60.08931063115597, 62.304124385118484, 55.96197210252285, 52.437699213624, 45.10210543870926, 45.287470892071724, 45.71589410305023, 47.06691920757294, 48.80437597632408, 52.20507189631462, 51.425703316926956, 50.95376864075661, 50.306613966822624, 50.82058198750019, 46.75069637596607, 47.09871590137482, 47.59338855743408, 52.04232282936573, 53.404865115880966, 52.21600390970707, 53.213663175702095, 55.76155185699463, 52.07769513130188, 50.52737072110176, 53.18959906697273, 52.96517550945282, 50.22680304944515, 52.08848275244236, 52.58356958627701, 52.722896710038185, 50.802852138876915, 51.68072663247585, 50.52453227341175, 51.18669994175434, 51.65070824325085, 51.883213967084885, 44.67028521001339, 35.182901099324226, 35.608341470360756, 35.987519323825836, 36.10468603670597, 40.22041238844395, 44.22999523580074, 41.69505625963211, 42.225633189082146, 42.35900603234768, 42.4602098017931, 42.9431638866663, 39.97115336358547, 35.390985533595085, 37.93587237596512, 37.733529433608055, 36.103660091757774, 36.24984584748745, 38.4891264885664, 37.95142874121666, 40.85767239332199, 38.44795569777489, 48.35945025086403, 54.05439466238022, 55.65552994608879, 53.66195552051067, 53.15189749002457, 53.39376591145992, 52.075058072805405, 52.723804861307144, 53.5489571839571, 52.69371807575226, 48.992192298173904, 49.14226904511452, 50.59130609035492, 51.25743314623833, 50.14946959912777, 53.059121668338776, 51.026922315359116, 53.84583905339241, 50.620458126068115, 52.84760221838951, 50.12121431529522, 48.950911313295364, 48.61515372991562, 47.96935558319092, 48.679738864302635, 47.93830364942551, 47.84215360879898, 48.386132419109344, 49.868740662932396, 48.18961836397648, 48.08618791401386, 46.749643832445145, 45.61815194785595, 47.14964456856251, 47.37789452075958, 50.36359190940857, 50.005651116371155, 54.081737995147705, 56.02192908525467, 57.394993007183075, 59.792512357234955, 64.41600546240807, 62.671811655163765, 52.70434230566025, 62.29213982820511, 63.34757499396801, 61.99458919465542, 63.13214935362339, 54.445093497633934, 54.55317109823227, 61.4388994127512, 65.85001051425934, 68.39322164654732, 69.86893326044083, 50.117007941007614, 0.5955125950276852, 11.957074888050556, 61.080704033374786, 48.70522029697895, 18.275364451110363, 24.58002794533968, 65.93861415982246, 40.462797582149506, 50.87385132908821, 36.10156260430813, 55.16667477786541, 59.577987268567085, 53.770888075232506, 10.41114304214716, 0.19888958078809083, 0.25225614372175187, 0.02639118698425591, 0.07942726413602941, 0.014885486016282812, 0.06256357606616803, 0.03236028445826378, 0.018222968647023663, 0.058303006444475614, 0.10984720720443875, 0.043733820057241246, 0.1024798552680295, 0.09488587369560264, 0.060033576082787476, 0.04101688420632854, 0.19928274094127119, 0.17497483670013025, 0.2891527576139197, 0.6375899934209883, 16.102732233703136, 75.53705111145973, 62.58474312722683, 59.500201642513275, 52.23073951900005, 49.04462568461895, 32.99147129058838, 40.50615705549717, 32.090216651558876, 64.11356449127197, 65.67986324429512, 38.633864521980286, 1.2606641720049083, 62.62616470456123, 74.4662381708622, 76.06412082910538, 71.10369980335236, 65.77527612447739, 57.94001296162605, 59.0448834747076, 56.33836470544338, 59.50166076421738, 59.261399656534195, 61.37130863964558, 59.314532205462456, 63.244110345840454, 59.439917877316475, 63.7299332767725, 60.08827708661556, 63.671302422881126, 61.77495338022709, 63.50367061793804, 60.27548164129257, 54.45481717586517, 48.58197011053562, 49.66485880315304, 46.44695207476616, 51.05724848806858, 51.769155487418175, 54.8286297172308, 55.148044377565384, 54.165679290890694, 53.856159299612045, 57.27028749883175, 49.54742230474949, 51.143731847405434, 50.580446273088455, 52.51878306269646, 55.65057121217251, 56.435609087347984, 55.614689737558365, 56.93818911910057, 56.43527090549469, 55.24180814623833, 55.32295659184456, 54.40412789583206, 52.58653722703457, 55.31871221959591, 57.26066641509533, 56.27825953066349, 54.95844215154648, 55.704874098300934, 53.07161919772625, 54.310782104730606, 55.025531351566315, 55.046662017703056, 45.642371848225594, 35.444684252142906, 33.15349079668522, 36.426600962877274, 35.13157345354557, 38.79059091210365, 43.42751629650593, 43.386353105306625, 42.557537779212, 42.387686893343925, 43.741356655955315, 44.007015600800514, 40.2322943508625, 35.928717479109764, 37.685610204935074, 38.882682770490646, 37.290818989276886, 34.85914707183838, 39.297206327319145, 39.822471141815186, 39.04345974326134, 36.86720632016659, 47.91117690503597, 55.2272093296051, 55.90649887919426, 56.45097926259041, 52.84119576215744, 53.61888863146305, 52.37489238381386, 54.48134735226631, 55.59574395418167, 55.0800584256649, 52.15140737593174, 50.43928764760494, 54.27560359239578, 54.50093150138855, 53.12453515827656, 54.56354074180126, 52.20656901597977, 55.60677096247673, 54.11679111421108, 52.95003332197666, 52.15356186032295, 50.58205358684063, 50.48542857170105, 49.98101703822613, 50.770394280552864, 51.12747251987457, 51.497261077165604, 48.963234052062035, 49.93179067969322, 49.15454998612404, 50.92163376510143, 52.20286801457405, 47.99602635204792, 47.781307473778725, 49.43787418305874, 52.574229687452316, 53.28680545091629, 57.72122450172901, 57.966759726405144, 61.42727963626385, 63.36738333106041, 65.72243615984917, 65.891914665699, 54.379330426454544, 62.40979291498661, 68.37526381015778, 63.770534098148346, 66.50071039795876, 57.735504135489464, 58.22347775101662, 64.35659185051918, 70.04750847816467, 72.54075989127159, 74.89496156573296, 49.46864493191242, 0.314997456735, 16.81000728160143, 69.50765624642372, 49.77818012237549, 25.149868167936802, 26.605913937091827, 51.67515993118286, 34.51873853802681, 55.96758060157299, 35.07423833012581, 58.7427768856287, 68.00042152404785, 69.7191832959652, 19.757208935916424, 0.3122588724363595, 0.1756413743714802, 0.1383836759487167, 0.023775042209308594, 0.04959924321155995, 0.07204498018836603, 0.06225976307177916, 0.08812888627289794, 0.11991420295089483, 0.19709022890310735, 0.14857149333693087, 0.2551061095437035, 0.15512725483858958, 0.2322774095227942, 0.16624131705611944, 0.2781974704703316, 0.29033954080659896, 0.5589811771642417, 1.1037071817554533, 20.355224646627903, 84.38530191779137, 70.29963254928589, 70.13975992798805, 68.7447027862072, 53.60711686313152, 32.2590833902359, 43.94195929169655, 38.80578249692917, 69.96346458792686, 75.74501395225525, 36.6763349622488, 3.148179044947028, 74.70629408955574, 71.12055569887161, 82.98725053668022, 71.95297703146935, 68.59210297465324, 58.252606987953186, 63.69351223111153, 56.36939764022827, 64.99700948596, 60.21053932607174, 63.333337157964706, 59.865692630410194, 67.15277820825577, 59.86933283507824, 65.77004000544548, 60.37496030330658, 64.03232485055923, 62.79199920594692, 67.15226143598557, 60.913649797439575, 57.81721115112305, 52.40796200931072, 51.606596410274506, 50.84693357348442, 54.063335582613945, 52.181304171681404, 56.48264676332474, 55.59212654829025, 57.724271938204765, 55.69947458803654, 60.4316608607769, 52.816975861787796, 53.77488546073437, 52.52092234790325, 58.694648668169975, 58.23373720049858, 59.87305663526058, 58.56399267911911, 63.76117900013924, 59.15106877684593, 57.599604427814484, 60.49615100026131, 59.505509957671165, 54.62955839931965, 60.29083661735058, 61.25794172286987, 60.56842312216759, 58.135041296482086, 63.12690943479538, 57.1621984988451, 60.03614008426666, 62.1689048409462, 59.460326582193375, 46.53251588344574, 36.58042810857296, 35.49902893602848, 36.365272253751755, 36.24193847179413, 41.34265936911106, 44.14007306098938, 42.05063357949257, 41.92175209522247, 42.95055828988552, 44.02839705348015, 43.72945949435234, 41.10604226589203, 35.300273001194, 38.98441471159458, 40.293676257133484, 37.73959390819073, 36.91400080919266, 40.90958520770073, 40.02995900809765, 40.91010957956314, 38.411724641919136, 48.00929144024849, 58.14717024564743, 60.11554442346096, 60.66918611526489, 55.91409847140312, 55.393621399998665, 54.775295779109, 56.588547080755234, 58.90187054872513, 56.38111241161823, 54.452195316553116, 53.62181827425957, 57.26225093007088, 56.580548509955406, 57.542520090937614, 57.912084460258484, 56.06537215411663, 57.95190252363682, 54.63867411017418, 55.83103112876415, 55.400301441550255, 51.83507815003395, 53.07404346764088, 53.735625967383385, 55.09910300374031, 52.200033366680145, 52.426941990852356, 51.603526175022125, 53.80599819123745, 51.20306946337223, 54.99003745615482, 52.554204761981964, 49.45909224450588, 50.262213349342346, 51.82244382798672, 54.9958511441946, 54.950755164027214, 60.647451281547546, 60.851401537656784, 64.01725485920906, 64.86581772565842, 70.63660606741905, 63.97490233182907, 55.905526131391525, 65.134037733078, 68.31848725676537, 67.68389090895653, 68.67456614971161, 63.21339659392834, 61.192007660865784, 66.42764791846275, 70.86840882897377, 76.21248006820679, 75.49792841076851, 61.85074031352997, 1.246320060454309, 14.77543780580163, 73.6678022146225, 58.27975653111935, 32.61381335556507, 29.91048451513052, 81.35679602622986, 54.01584953069687, 70.0473564863205, 48.43277111649513, 62.22208298742771, 72.95154824852943, 77.58021667599678, 20.722482539713383, 0.3963540302356705, 0.32192680053412914, 0.2740316471317783, 0.11681177333230153, 0.16517237207153812, 0.20219589321641251, 0.18546975479694083, 0.23221808223752305], [0.053619984100805596, 0.06537664972711354, 0.0804082200920675, 0.028295235497353133, 0.09609000087948516, 0.07206259135273285, 0.03300715521618258, 0.07277035532752052, 0.020013155008200556, 0.1279003353556618, 0.49038330966141075, 10.969520229846239, 65.56371107697487, 52.26051092147827, 38.15163619816303, 23.99473775178194, 47.32443518936634, 17.42577563971281, 35.93600168824196, 17.908245250582695, 57.35592730343342, 53.506779447197914, 67.78438791632652, 1.8516190303489566, 18.21698248386383, 86.49453073740005, 62.45837330818176, 73.0794569849968, 61.294157579541206, 59.0186382830143, 53.55790190398693, 56.68978124856949, 57.307286113500595, 59.17938485741615, 58.44807609915733, 59.363093599677086, 59.34844918549061, 62.43930973112583, 57.78692677617073, 60.70681169629097, 57.39901319146156, 59.34052661061287, 60.150947123765945, 58.66153724491596, 49.572029784321785, 44.45653907954693, 44.83688727021217, 51.95502631366253, 53.25554832816124, 57.504206746816635, 52.094190046191216, 50.93426428735256, 51.80507875978947, 48.82187783718109, 51.41267381608486, 50.35539194941521, 48.5178105533123, 53.53342741727829, 52.330590561032295, 50.83767347037792, 52.63474144041538, 53.43999043107033, 52.243560031056404, 54.53503467142582, 52.272381484508514, 51.21334791183472, 52.677036970853806, 49.05012018978596, 52.794834449887276, 51.716520711779594, 53.186369240283966, 51.60460151731968, 50.538496524095535, 52.82841704785824, 48.18893060088158, 54.5405937731266, 50.39818525314331, 42.3571403324604, 41.25366434454918, 34.943035170435905, 32.98845425248146, 34.394230619072914, 34.90327790379524, 38.22688736021519, 37.38082475960255, 40.46473167836666, 43.05017374455929, 44.84959378838539, 39.84433516860008, 37.82928429543972, 40.795146748423576, 40.885441303253174, 40.416269078850746, 37.789549827575684, 31.83903682976961, 34.217513501644135, 35.87400421500206, 39.08686101436615, 42.784666791558266, 40.05327455699444, 51.12499125301838, 53.39341253042221, 53.55051130056381, 52.86719776690006, 53.53882312774658, 52.80820973217487, 53.78815434873104, 51.385440677404404, 53.30323576927185, 50.78725017607212, 48.656970486044884, 51.154116690158844, 51.30201235413551, 49.76860083639622, 52.38704793155193, 53.952723518013954, 50.995938777923584, 51.14372804760933, 50.77944919466972, 50.26013106107712, 51.49373486638069, 49.335021302103996, 49.46266405284405, 50.9489618986845, 52.394894510507584, 47.66064114868641, 48.71180534362793, 48.78636114299297, 50.01751787960529, 51.80611610412598, 51.84939578175545, 47.686532959342, 46.511210426688194, 45.99487513303757, 49.07821588218212, 53.60702946782112, 52.92788051068783, 52.32603460550308, 58.369150534272194, 59.790703654289246, 57.905328422784805, 64.47394475340843, 60.44318564236164, 52.7940858900547, 66.6481500864029, 59.40399460494518, 64.86365184187889, 53.846606612205505, 53.80019210278988, 60.18710218369961, 70.18751576542854, 64.21234399080276, 75.91706871986389, 23.131657764315605, 0.19293023884529248, 25.023561045527458, 58.98037053644657, 34.412420243024826, 10.697757862508297, 67.21955582499504, 153.2533460855484, 88.13734218478203, 48.83510112762451, 55.41181482374668, 19.032768309116364, 48.36374022066593, 54.1292392462492, 34.632132053375244, 0.36864677793346345, 0.0892781613219995, 0.050366698123980314, 0.03395883344637696, 0.06160894779895898, 0.03133030222670641, 0.0478080512402812, 0.09820241291890852, 0.02067793750029523, 0.07469158270396292, 0.05539939818845596, 0.10400108731118962, 0.039837938093114644, 0.027438965917099267, 0.07301734207430854, 0.041398641260457225, 0.040616328551550396, 0.1606386067578569, 0.4529005178483203, 14.096047561615705, 75.06731271743774, 55.39713241159916, 42.52077095210552, 27.560941390693188, 56.06976091861725, 23.46009884029627, 46.485390812158585, 22.3548274487257, 62.66882881522179, 58.81333529949188, 76.40063837170601, 4.94940304197371, 15.749811921268702, 90.7150174677372, 67.44799196720123, 78.29424396157265, 66.5732029080391, 62.059782296419144, 56.85587793588638, 60.27545504271984, 60.613268315792084, 62.6048668473959, 61.4709734916687, 64.36968594789505, 62.785604149103165, 63.401817083358765, 59.80358116328716, 61.89679764211178, 59.64047111570835, 64.80691328644753, 63.419987708330154, 59.17914927005768, 51.59805826842785, 49.37436819076538, 46.174084916710854, 54.115601778030396, 55.84366925060749, 58.5592695325613, 54.75066930055618, 54.03763756155968, 55.81681229174137, 51.90917797386646, 55.06949499249458, 54.05726730823517, 52.9692716896534, 57.42152698338032, 54.9989365786314, 51.8653055280447, 54.330221861600876, 55.797057151794434, 55.57842068374157, 55.112801268696785, 56.200409308075905, 56.249563470482826, 56.216402649879456, 51.47619880735874, 53.95984813570976, 55.50240196287632, 55.13603702187538, 53.22205312550068, 54.80832740664482, 56.53752721846104, 52.86331817507744, 55.75948476791382, 51.69192083179951, 43.71905945241451, 42.779666259884834, 33.21476250886917, 33.08694116771221, 34.377184733748436, 34.64363023638725, 37.24471226334572, 38.25504004955292, 39.1122854501009, 41.02813884615898, 42.99928307533264, 39.69225972890854, 39.31018263101578, 40.37757955491543, 41.62742368876934, 41.272670924663544, 39.94606710970402, 33.76147337257862, 33.16058501601219, 35.967547595500946, 39.49283882975578, 44.13019739091396, 40.74034608900547, 51.797574162483215, 52.86232642829418, 53.20776209235191, 53.72522972524166, 55.35768672823906, 54.583599865436554, 55.20794056355953, 52.879307717084885, 54.479797035455704, 52.47983135282993, 51.58781781792641, 55.12372948229313, 54.444512128829956, 52.508132234215736, 54.07345063984394, 54.092723205685616, 52.7955412119627, 51.784153282642365, 53.21234464645386, 53.5836037248373, 53.68301399052143, 53.196590691804886, 52.66482062637806, 55.069221407175064, 52.782040536403656, 51.098597869277, 51.5780371427536, 51.336495503783226, 52.00072266161442, 55.08467897772789, 53.07433985173702, 50.184127539396286, 47.64695808291435, 48.72154802083969, 51.97933740913868, 56.4567169547081, 57.585773169994354, 55.99317602813244, 61.586673483252525, 63.98918196558952, 62.31258273124695, 67.11180120706558, 64.85103651881218, 55.703270584344864, 68.57785373926163, 67.05111846327782, 68.72784689068794, 57.91602864861488, 58.537344709038734, 64.48559492826462, 73.59486892819405, 66.78951010107994, 81.07536792755127, 21.061587743461132, 0.21127005864400417, 32.6844971626997, 61.34219840168953, 38.6529128998518, 12.56181813776493, 71.39714285731316, 148.03485810756683, 93.14189404249191, 60.66444776952267, 53.45742009580135, 22.71122172474861, 58.267133608460426, 59.50654350221157, 51.974633261561394, 1.2681836122646928, 0.06378871345077641, 0.05487326743605081, 0.02794554293359397, 0.05009081956814043, 0.024833211209625006, 0.04765988516737707, 0.06453785215853713, 0.1758607680676505, 0.22051291423849761, 0.2298081951448694, 0.38291821838356555, 0.21100833284435794, 0.16331814578734338, 0.2508056606166065, 0.1574774138862267, 0.20107299409573898, 0.2086814772337675, 0.611499227816239, 19.10569589585066, 86.5430161356926, 66.00473821163177, 50.74052408337593, 32.73598439991474, 62.99202047288418, 25.917273089289665, 45.20784616470337, 29.639557152986526, 72.16542363166809, 64.4241826236248, 81.87670692801476, 4.245017739012837, 25.975216180086136, 92.55343481898308, 68.79668399691582, 82.41216659545898, 69.19397547841072, 61.795753464102745, 62.0179845392704, 63.73195096850395, 63.8372965157032, 63.99703234434128, 63.937063962221146, 65.7373009622097, 63.96587401628494, 66.43144771456718, 61.86377741396427, 60.19692085683346, 63.53435017168522, 66.85676649212837, 66.35635614395142, 62.83231504261494, 56.30016915500164, 50.920520424842834, 51.26484654843807, 58.33759322762489, 58.36617909371853, 60.28097614645958, 54.668160527944565, 57.520146891474724, 58.57757315039635, 55.9649283438921, 57.95469157397747, 57.83983513712883, 55.1209632307291, 60.79573452472687, 57.74759888648987, 56.38032965362072, 57.76878274977207, 60.025869235396385, 60.54136477410793, 59.68856133520603, 58.50500464439392, 61.18172161281109, 59.615202471613884, 56.01002812385559, 57.1070596575737, 59.97836418449879, 62.400073036551476, 60.479796677827835, 60.42182318866253, 63.70212636888027, 56.68989144265652, 60.39237856864929, 54.718728214502335, 45.49030780792236, 44.18329954147339, 33.70475761592388, 34.06978502869606, 34.76821035146713, 33.56501631438732, 37.5149005651474, 38.186890706419945, 41.551074385643005, 44.29876774549484, 45.97853980958462, 42.58348658680916, 42.07171104848385, 45.45704819262028, 43.35262231528759, 44.39890377223492, 44.048330783843994, 35.036890134215355, 34.45919573307037, 37.11704671382904, 40.23542158305645, 45.169289633631706, 40.28052896261215, 53.12717221677303, 55.366027280688286, 57.169190123677254, 54.89816978573799, 56.08931466937065, 58.93761903047562, 58.203110843896866, 55.7275702804327, 58.16038213670254, 53.388032019138336, 53.63397002220154, 57.141322419047356, 58.12522642314434, 57.78676338493824, 56.53533473610878, 58.36039200425148, 54.75578762590885, 54.767863377928734, 54.43188160657883, 55.241051986813545, 55.6395898014307, 56.986222341656685, 54.25854250788689, 58.012045696377754, 56.87019556760788, 53.098730742931366, 54.145399779081345, 53.56664523482323, 53.300427719950676, 56.66310288012028, 57.61519119143486, 52.9648145288229, 50.91241165995598, 51.599384397268295, 54.61961433291435, 58.80145713686943, 57.46011771261692, 58.546392023563385, 65.87083339691162, 67.9513281583786, 63.966922760009766, 72.1553997695446, 58.78115862607956, 57.294302210211754, 74.10506755113602, 68.71509477496147, 69.53504517674446, 58.143400847911835, 61.11859939992428, 69.54773649573326, 77.46376052498817, 68.7103146314621, 82.08428218960762, 31.55048031359911, 0.34443483338691294, 31.80847316980362, 70.24541705846786, 49.645441845059395, 21.73298891633749, 78.26139852404594, 158.357475399971, 94.79626446962357, 62.642921805381775, 73.89544799923897, 29.837068654596806, 63.344234973192215, 71.58511117100716, 56.22071161866188, 1.1745354998856783, 0.1691814389778301, 0.1845390273956582, 0.12458079785574228, 0.1924831690848805, 0.11966170946834609, 0.15124297264264897, 0.16970009630313143], [0.07987430421053432, 0.10751683381386101, 0.06129917164798826, 0.026712475701060612, 0.10115241282619536, 0.062396971334237605, 0.042919865882140584, 0.03772613090404775, 0.039557562122354284, 0.192524402809795, 0.08007186392205767, 14.056084156036377, 62.46148534119129, 48.61304484307766, 46.99697636067867, 33.88829916715622, 53.50258447229862, 18.943237513303757, 27.925824411213398, 15.159179214388132, 37.8687983751297, 63.94337922334671, 60.01717910170555, 30.396512635052204, 1.1870644963346422, 60.250437185168266, 71.16568207740784, 68.2039462029934, 64.6787841618061, 60.602028518915176, 57.25442335009575, 59.998453706502914, 58.52340325713158, 63.98889318108559, 59.3409825861454, 60.98282128572464, 60.8581879734993, 59.724237620830536, 57.791467532515526, 57.78254561126232, 54.46184299886227, 61.79887689650059, 55.97368307411671, 54.8551294952631, 50.756384432315826, 47.23588474094868, 48.95032614469528, 49.95404228568077, 52.082904651761055, 53.6824744194746, 54.744240045547485, 53.06923292577267, 51.525364369153976, 51.34775809943676, 50.07130779325962, 55.63495025038719, 50.12880630791187, 50.804687440395355, 50.85441157221794, 50.6955610960722, 49.011065885424614, 52.549918591976166, 52.892956584692, 49.5007000118494, 49.83296558260918, 50.55041268467903, 52.194725051522255, 49.459438025951385, 50.4800708591938, 50.20887941122055, 51.027591079473495, 49.60413046181202, 45.63399329781532, 48.75703811645508, 49.66935396194458, 49.14535827934742, 43.09994727373123, 38.88501584529877, 38.14807578921318, 33.491323068737984, 33.02693858742714, 32.646119222044945, 36.57327689230442, 39.67252738773823, 41.117521449923515, 43.47494915127754, 42.79922381043434, 40.3796124458313, 38.675297498703, 38.77504974603653, 40.47939129173756, 38.56410026550293, 40.41441857814789, 39.00246374309063, 39.92373950779438, 33.44654627144337, 34.660748317837715, 40.49434348940849, 41.44578203558922, 40.261681973934174, 45.38069128990173, 52.656499072909355, 51.65282852947712, 52.05990448594093, 51.814080476760864, 51.59087285399437, 52.46672585606575, 51.30868099629879, 53.443007469177246, 54.15855847299099, 48.4246813505888, 50.69589167833328, 52.417670488357544, 51.25788152217865, 50.95455899834633, 50.202469155192375, 50.799420922994614, 50.057848915457726, 53.881576135754585, 50.74179321527481, 50.71524403989315, 49.917917624115944, 51.927333399653435, 51.76108852028847, 49.192578345537186, 47.697966545820236, 51.095292046666145, 51.66655719280243, 54.37246799468994, 53.515784963965416, 53.690427392721176, 49.77042853832245, 49.16782267391682, 48.313750103116035, 50.3803376108408, 51.30780704319477, 54.45797100663185, 52.452168837189674, 57.84156024456024, 57.83737286925316, 64.00217726826668, 57.38264746963978, 65.77533692121506, 56.850923001766205, 61.36500097811222, 65.13267740607262, 64.37987700104713, 60.41919752955437, 56.80391572415829, 57.76313245296478, 67.00690403580666, 63.206929340958595, 71.6706445813179, 6.467938832938671, 0.8621263573877513, 41.19653061032295, 56.132947728037834, 26.618286073207855, 8.148799538612366, 34.87947218120098, 39.76521581411362, 16.128179468214512, 30.77070325613022, 76.86780050396919, 46.09072878956795, 31.141287870705128, 49.59221050143242, 61.853232979774475, 9.459429010748863, 0.3648921044077724, 0.1306229189503938, 0.05873264315596316, 0.031011367973405868, 0.012145584405516274, 0.04311002267058939, 0.026881100930040702, 0.03924244250811171, 0.059286630421411246, 0.09461222900426947, 0.011661065873340704, 0.11833336160634644, 0.059942043299088255, 0.02909738766902592, 0.07158210268244147, 0.045666736259590834, 0.1951622182969004, 0.16405021509854123, 19.1442334279418, 69.51970160007477, 55.93570791184902, 47.081761211156845, 33.41665707528591, 60.83804525434971, 20.121335797011852, 29.726464189589024, 15.097490474581718, 40.043934658169746, 68.66296917200089, 64.91934165358543, 38.823383152484894, 0.6191805156413466, 57.83296890556812, 75.838443338871, 71.29624307155609, 71.5519617497921, 65.77393859624863, 60.309322625398636, 62.855064421892166, 62.82176300883293, 65.83863392472267, 63.13857480883598, 63.878425508737564, 61.881685853004456, 58.585761711001396, 59.305484890937805, 60.208658427000046, 58.960934579372406, 64.43254977464676, 58.0273512750864, 59.82603035867214, 54.09474849700928, 49.44441743195057, 51.51070475578308, 53.88295166194439, 56.28122717142105, 56.48183360695839, 55.58671183884144, 54.650358483195305, 52.40136556327343, 53.94002079963684, 53.85948412120342, 57.15715616941452, 53.649427592754364, 53.74941162765026, 54.29625928401947, 53.06915692985058, 53.80273036658764, 54.282002449035645, 56.10758028924465, 55.265473276376724, 52.98135504126549, 56.29741430282593, 53.59270803630352, 54.618003219366074, 52.757900431752205, 53.79595912992954, 51.99791081249714, 52.92254559695721, 49.33383196592331, 54.811416640877724, 50.87356634438038, 52.100870087742805, 45.54686017334461, 37.247531712055206, 34.80408422648907, 33.04116502404213, 33.97405296564102, 31.836363673210144, 37.743382304906845, 37.67866037786007, 40.76403021812439, 39.76076625287533, 42.79778368771076, 43.96277457475662, 43.287934586405754, 42.14461773633957, 42.08704702556133, 41.87482461333275, 43.048722222447395, 39.53174874186516, 37.269414737820625, 31.45394079387188, 34.52042184770107, 42.595505341887474, 39.18051078915596, 39.678588062524796, 44.204194620251656, 54.889624044299126, 54.00197647511959, 53.74503046274185, 54.367532059550285, 55.34120701253414, 57.19855114817619, 54.42666828632355, 55.524668768048286, 57.020283713936806, 51.53675615787506, 52.439545914530754, 53.139924332499504, 52.56181575357914, 52.97687128186226, 53.08834969997406, 54.49117362499237, 54.02427367866039, 54.01269190013409, 53.57392944395542, 52.858230248093605, 52.12209194898605, 53.617528304457664, 54.515898898243904, 52.00594738125801, 49.04745653271675, 52.94602073729038, 55.677074790000916, 58.50540742278099, 55.97589835524559, 56.168012246489525, 53.28710563480854, 50.6021811068058, 49.681406915187836, 53.50361801683903, 52.94306829571724, 57.91776515543461, 54.97100427746773, 60.78991323709488, 60.059603825211525, 66.66391924023628, 60.42948357760906, 68.18158820271492, 59.480237513780594, 62.38308034837246, 64.97017532587051, 67.4531976878643, 63.54748986661434, 60.30398391187191, 63.0388567596674, 71.29674464464188, 66.14003375172615, 74.95895773172379, 5.522325849160552, 1.9687781436368823, 50.23014307022095, 58.79977002739906, 31.19838360697031, 8.867723811417818, 38.68349365890026, 49.95709352195263, 32.73067608475685, 44.60817754268646, 75.88156342506409, 43.63762982189655, 38.02619352936745, 53.57492119073868, 76.22061163187027, 15.618972592055798, 0.33290212566498667, 0.03952961284085177, 0.08070242969552055, 0.08965927641838789, 0.03018363582668826, 0.021971441528876312, 0.03938410365663003, 0.18951926875161007, 0.16160998900886625, 0.196545195649378, 0.07727547374088317, 0.1679865366895683, 0.12076878600055352, 0.16076158062787727, 0.1253235837793909, 0.1684677749290131, 0.3435818088473752, 0.32123440643772483, 22.07777861505747, 79.5912891626358, 62.62941353023052, 59.34211492538452, 44.085941165685654, 72.02580392360687, 26.706422343850136, 35.68912133574486, 24.310299418866634, 51.51331141591072, 71.2737786769867, 75.32692238688469, 35.388310477137566, 2.3091926146298647, 73.26538860797882, 74.16418477892876, 76.94859176874161, 73.72773259878159, 67.34659060835838, 62.0614580065012, 66.48839145898819, 65.83065435290337, 71.21514022350311, 64.01119038462639, 65.81724867224693, 65.37543877959251, 60.70051163434982, 54.78991739451885, 63.11973161995411, 60.10474920272827, 66.82341948151588, 61.93934015929699, 64.13624927401543, 57.22147911787033, 53.432903811335564, 54.99522037804127, 56.72619089484215, 57.96416826546192, 58.77856716513634, 57.08376690745354, 55.45963145792484, 55.966915637254715, 57.34161727130413, 55.488232523202896, 61.673487424850464, 55.681079775094986, 56.9112903624773, 57.80858941376209, 58.04508872330189, 54.82644863426685, 56.39355294406414, 58.48057575523853, 58.95618483424187, 56.23640477657318, 59.08590987324715, 60.37868410348892, 58.73552307486534, 57.3799230158329, 57.39064984023571, 56.2617152184248, 58.31119604408741, 53.42377670109272, 56.913471445441246, 54.982783645391464, 54.640095233917236, 47.55624935030937, 36.52384154498577, 35.738264098763466, 37.99873240292072, 34.45468157529831, 31.730381660163403, 38.85239079594612, 38.0869522690773, 41.54825493693352, 42.81433179974556, 44.21774089336395, 45.453229397535324, 43.42561259865761, 44.222091659903526, 47.09614343941212, 43.57038103044033, 45.51690638065338, 41.72520004212856, 39.25225093960762, 32.926863357424736, 35.886064767837524, 42.96446934342384, 39.844783544540405, 39.556861594319344, 47.28623203933239, 57.6135116815567, 58.25196482241154, 55.87760902941227, 56.05421595275402, 60.61675652861595, 59.07176323235035, 57.21913844347, 58.84232774376869, 61.83381602168083, 54.409508407115936, 55.296525210142136, 58.679358288645744, 56.61392591893673, 56.592346876859665, 56.45031049847603, 57.43848167359829, 54.91255961358547, 59.48930382728577, 57.04525597393513, 55.040358155965805, 56.325418800115585, 57.94596344232559, 57.779547572135925, 56.70914500951767, 51.23284846544266, 56.707777082920074, 59.22947756946087, 60.50903230905533, 59.06830541789532, 57.954558581113815, 53.86660873889923, 53.67962837219238, 52.43694685399532, 56.50813199579716, 56.80895045399666, 59.92558501660824, 57.747279703617096, 62.641789466142654, 64.4656839966774, 70.59078812599182, 63.81186068058014, 73.69551792740822, 54.81026530265808, 64.95371460914612, 70.76829940080643, 70.49966141581535, 67.32215791940689, 64.10422459244728, 66.03720366954803, 74.2603500187397, 66.91652968525887, 76.95306032896042, 10.766333732753992, 1.1814043438062072, 53.85099537670612, 67.27953940629959, 42.829633578658104, 16.408908404409885, 43.61253596842289, 48.10653202235699, 23.040648847818375, 39.23790290951729, 98.35864931344986, 61.05287432670593, 40.632207691669464, 61.15293815732002, 84.07086879014969, 18.839761465787888, 0.6513548141811043, 0.22494240780360997, 0.2779664844274521, 0.1401400426402688, 0.15620789607055485, 0.0949867167219054, 0.11970080580795184], [0.051997886766912416, 0.07175710110459477, 0.05401511094532907, 0.0019455950996416504, 0.10794193600304425, 0.08277650980744511, 0.07218478596769273, 0.06980111153097823, 0.14427690737647936, 0.3029688756214455, 0.29371147393248975, 17.36573316156864, 71.74460381269455, 52.8229795396328, 36.01754151284695, 32.061805576086044, 50.44540151953697, 28.22013381868601, 25.115706101059914, 13.161079231649637, 33.83055366575718, 66.86042189598083, 53.08993801474571, 72.837645560503, 2.7144040586426854, 7.82116686925292, 79.47354108095169, 62.06435725092888, 69.2217443883419, 59.403344839811325, 61.457495614886284, 60.121852084994316, 64.84864264726639, 53.156989216804504, 61.120183914899826, 58.59591856598854, 58.893978372216225, 59.47350427508354, 55.38922883570194, 54.121989235281944, 61.18260696530342, 58.48231226205826, 58.83283965289593, 58.279300555586815, 51.425376534461975, 44.354594349861145, 46.55103228986263, 49.63751547038555, 59.878573939204216, 54.83166955411434, 57.03574888408184, 51.9058645516634, 54.769466891884804, 50.16949072480202, 49.784917160868645, 48.51848691701889, 54.705067947506905, 51.53915762901306, 54.761346727609634, 48.28521363437176, 50.01335330307484, 51.59859783947468, 52.10356414318085, 56.187341809272766, 53.21474991738796, 48.28487545251846, 45.03275156021118, 50.11276736855507, 51.402942538261414, 46.08030214905739, 45.635000243783, 46.26623757183552, 50.50945468246937, 48.61356921494007, 51.341013461351395, 49.28036503493786, 46.13181598484516, 67.67636731266975, 89.39116850495338, 75.68655028939247, 43.42184700071812, 37.15027213096619, 39.537741020321846, 44.13518652319908, 43.601144179701805, 44.24311973154545, 47.46687054634094, 43.86124402284622, 37.60636165738106, 34.472016245126724, 38.71359184384346, 39.729516729712486, 37.3472535610199, 40.46956121921539, 40.620314329862595, 36.70060805976391, 29.322388172149658, 34.41173627972603, 46.98472201824188, 44.83512796461582, 41.66222222149372, 43.48120741546154, 49.80732835829258, 50.13772442936897, 48.98346796631813, 48.50981578230858, 50.07999412715435, 52.66183018684387, 53.34455855190754, 50.6951355189085, 49.318427592515945, 48.11912454664707, 49.600079879164696, 47.87083826959133, 50.12710399925709, 53.27142767608166, 55.59951335191727, 55.51820911467075, 51.81021608412266, 52.26167745888233, 52.78620511293411, 49.71328720450401, 49.942718893289566, 51.314935460686684, 48.741831332445145, 47.02019691467285, 48.70135970413685, 53.62029455602169, 56.679958775639534, 55.0187449157238, 54.814513474702835, 50.59752255678177, 45.767005160450935, 46.3054970651865, 53.2824394851923, 52.2657660394907, 51.871218010783195, 54.01753284037113, 55.24681627750397, 56.07703372836113, 55.407608449459076, 57.73011602461338, 51.86301805078983, 48.37436065077782, 53.353301882743835, 58.938192799687386, 65.30625209212303, 58.58391121029854, 56.530193611979485, 60.096803829073906, 65.81540957093239, 66.03783443570137, 69.91551876068115, 0.4682779364520684, 9.711801018565893, 57.279065027832985, 55.57286538183689, 25.281876884400845, 5.844369018450379, 20.961613208055496, 10.57594209909439, 17.064213640987873, 32.617153376340866, 51.08174577355385, 45.72336070239544, 29.434058479964733, 44.19663302600384, 68.75000730156898, 27.023591324687004, 0.29609614284709096, 0.15164408861892298, 0.04540397887467407, 0.1400956473662518, 0.14845816738670692, 0.029121459228917956, 0.06745761696947739, 0.05145929164427798, 0.019980608121841215, 0.0655321148224175, 0.02945220661786152, 0.1389071423909627, 0.06160565637401305, 0.020255109993740916, 0.027046655523008667, 0.08836975030135363, 0.2562941098585725, 0.5402258585672826, 25.05004182457924, 79.14165928959846, 60.01453064382076, 41.71720527112484, 34.25256662070751, 62.32826068997383, 30.581302419304848, 25.650350712239742, 15.136036556214094, 46.06414921581745, 73.2848359644413, 59.87914390861988, 79.15142476558685, 5.083124991506338, 4.770563263446093, 83.3106891810894, 68.81611615419388, 75.57336956262589, 67.4098952114582, 68.503058552742, 60.04470482468605, 66.35824084281921, 58.488407135009766, 65.85754171013832, 61.22019074857235, 63.0971722304821, 60.013443902134895, 58.49062241613865, 54.296753257513046, 60.7436241209507, 58.91379430890083, 58.230712562799454, 57.22343981266022, 52.551149725914, 48.086780682206154, 54.00084413588047, 53.385964930057526, 61.73605866730213, 55.68103417754173, 58.495524153113365, 55.767164155840874, 57.23683789372444, 53.238221257925034, 53.425239622592926, 53.264496847987175, 59.98610056936741, 54.02798227965832, 59.002325758337975, 51.10808975994587, 53.58082227408886, 52.47022166848183, 53.15284363925457, 56.439306288957596, 56.11478470265865, 52.61242523789406, 51.145517751574516, 51.83044619858265, 53.977034613490105, 51.46345429122448, 50.788230523467064, 48.85090447962284, 54.99237433075905, 51.805325746536255, 55.167913511395454, 48.403330296278, 45.84643229842186, 62.78405763208866, 71.82632982730865, 53.231526017189026, 36.721263751387596, 38.37468422949314, 39.51859004795551, 44.16249565780163, 42.107201144099236, 43.34264025092125, 44.32946629822254, 42.17004977166653, 35.460521802306175, 37.851558700203896, 40.708089619874954, 40.944524332880974, 37.16970428824425, 43.463401570916176, 39.76728290319443, 33.59459772706032, 28.601506054401398, 34.55031104385853, 50.17725370824337, 41.83946371078491, 40.38702204823494, 43.17232958972454, 53.22064720094204, 53.05437572300434, 53.157023414969444, 49.59902733564377, 50.994627848267555, 54.218811839818954, 53.70440684258938, 53.582995757460594, 54.64759223163128, 51.62247195839882, 53.81973825395107, 51.57610684633255, 50.07025144994259, 50.97774535417557, 53.47489535808563, 54.970897883176804, 56.821390986442566, 54.77356307208538, 53.156415447592735, 51.00030094385147, 51.558874770998955, 53.94542030990124, 55.07160767912865, 50.13461619615555, 51.797881945967674, 57.50638023018837, 56.66925475001335, 56.9724290817976, 58.263326212763786, 52.534491419792175, 48.78851182758808, 49.5891934633255, 53.523631542921066, 55.330062210559845, 58.77272307872772, 55.289921164512634, 59.18893374502659, 64.91986602544785, 64.01790842413902, 61.98095552623272, 58.273125886917114, 53.16597953438759, 56.569160521030426, 61.31377972662449, 65.62763124704361, 61.974545270204544, 58.54806773364544, 63.6887738853693, 70.12275964021683, 68.40926438570023, 63.26300673186779, 0.48416853533126414, 16.247616559267044, 65.27650728821754, 59.51640397310257, 32.52147451043129, 5.859126001596451, 21.18131171911955, 17.92590670287609, 29.919225946068764, 42.732392996549606, 63.46371956169605, 42.245414927601814, 28.79764772951603, 45.6203406304121, 70.3816169500351, 37.20256872475147, 0.26714006380643696, 0.21577099134447053, 0.09182160531054251, 0.0696174225595314, 0.036084563325857744, 0.0173830318817636, 0.11276788485702127, 0.1876351042301394, 0.19212205486837775, 0.16998678795062006, 0.1551759842550382, 0.2296551049221307, 0.1348823419539258, 0.21381553611718118, 0.13411111693130806, 0.20230727473972365, 0.28706791636068374, 0.6705843354575336, 31.29515301436186, 89.54904243350029, 68.08704927563667, 51.31255678832531, 47.39082522690296, 71.48702323436737, 42.98223339021206, 35.960669964551926, 22.431982308626175, 46.584219709038734, 79.89806190133095, 63.648929223418236, 85.40909618139267, 3.1621839059516788, 12.434728257358074, 85.85687175393105, 67.63632506132126, 78.58352243900299, 66.67642816901207, 74.0451067686081, 64.1953057050705, 70.50428196787834, 60.9353656321764, 68.60328197479248, 66.84173449873924, 64.40401330590248, 59.23709616065025, 63.91931131482124, 58.87178376317024, 64.92641687393188, 60.98937973380089, 60.896953493356705, 58.624778017401695, 57.60849975049496, 52.22187079489231, 56.53692305088043, 55.164801478385925, 63.95782604813576, 56.752470284700394, 59.90792736411095, 57.619241774082184, 59.60172459483147, 56.58353894948959, 55.78908897936344, 56.106227561831474, 62.172590643167496, 54.91568684577942, 61.97606518864632, 54.97615300118923, 56.82582154870033, 56.18904411792755, 57.00123533606529, 60.8365823328495, 58.73331919312477, 54.70160633325577, 54.10448357462883, 57.09938786923885, 59.30312141776085, 56.31682746112347, 53.82008783519268, 52.83608503639698, 59.57646355032921, 56.79135739803314, 59.64446850121021, 52.100664898753166, 46.35432444512844, 61.4251821488142, 60.56077793240547, 44.46616016328335, 37.05468066036701, 38.02779324352741, 39.64725874364376, 46.66240431368351, 43.63485597074032, 43.40703159570694, 44.808529391884804, 44.822174459695816, 40.04282891750336, 41.50503985583782, 41.36944033205509, 42.22743049263954, 37.98588149249554, 45.53143300116062, 39.20598842203617, 34.29154872894287, 30.51382564008236, 35.988701060414314, 51.18774488568306, 43.091203942894936, 39.61794711649418, 42.20505349338055, 57.213773131370544, 53.27958583831787, 55.83881691098213, 54.36436302959919, 54.97610740363598, 56.351941376924515, 58.111577555537224, 54.453377053141594, 56.46045595407486, 51.16141229867935, 56.09128676354885, 54.81150023639202, 54.35738280415535, 53.649249002337456, 57.945374473929405, 57.77405306696892, 60.381131172180176, 58.75193439424038, 58.200777769088745, 54.887119978666306, 53.009025156497955, 56.92588537931442, 57.073226273059845, 51.48297004401684, 53.511445596814156, 60.22140294313431, 63.2811089605093, 60.25626227259636, 60.540980994701385, 57.64079421758652, 53.244551718235016, 52.203745767474174, 55.904401391744614, 58.247230276465416, 62.973477467894554, 59.011844247579575, 63.662065118551254, 67.56487369537354, 66.53051599860191, 63.7956203520298, 62.90061257779598, 57.77741588652134, 57.28501170873642, 66.64817288517952, 68.47465887665749, 64.4429612159729, 61.6902407258749, 67.45425403118134, 74.10227850079536, 69.40077558159828, 74.16570469737053, 1.5891383774578571, 11.818244587630033, 71.29996687173843, 64.63417455554008, 39.78513054549694, 11.456010974943638, 28.139414750039577, 17.034290246665478, 25.452968403697014, 40.69073215126991, 63.10575217008591, 69.8978953063488, 43.0164847522974, 54.403109550476074, 82.75579735636711, 45.0283095985651, 0.5405547784175724, 0.3821906464872882, 0.20626608340535313, 0.2031603141222149, 0.19687028601765633, 0.3048495075199753, 0.1610628777416423], [0.08184322199667804, 0.008241708583227592, 0.007320025179069489, 0.06803040654631332, 0.2256951978779398, 0.12271070445422083, 0.2612751378910616, 0.07721650268649682, 0.1239315744896885, 0.0931247127300594, 0.15792850608704612, 26.768134832382202, 70.32179296016693, 49.47953134775162, 48.21563936769962, 36.249302476644516, 50.17189979553223, 29.36089340597391, 23.76760683953762, 5.302870525047183, 33.77552881836891, 71.09050691127777, 51.04574270546436, 62.71385259926319, 49.61276739835739, 0.19135954265948385, 29.162044376134872, 76.59343242645264, 66.00971594452858, 66.08600065112114, 65.82997798919678, 58.3786728233099, 59.07359853386879, 60.853905603289604, 56.83732733130455, 58.27891297638416, 62.328393682837486, 55.40543496608734, 50.71829527616501, 53.11148285865784, 52.501786574721336, 61.064205318689346, 57.0010719448328, 53.966908156871796, 50.42215816676617, 49.196495935320854, 48.2572091370821, 52.17971585690975, 55.96533492207527, 48.29822413623333, 56.70578598976135, 60.62423452734947, 53.61272156238556, 56.11214004456997, 50.29075361788273, 49.176148027181625, 49.16341491043568, 49.5954517275095, 52.772571444511414, 53.61083306372166, 49.061291590332985, 52.421143501996994, 54.175258576869965, 52.47563257813454, 52.049101665616035, 48.13472270965576, 51.4678468555212, 47.513539642095566, 46.99966661632061, 47.92245090007782, 44.85536187887192, 48.435130789875984, 46.610100120306015, 46.380945816636086, 48.081137984991074, 42.96013757586479, 58.06787610054016, 89.14008557796478, 109.56527397036552, 147.8894779086113, 100.5352409183979, 45.78169137239456, 41.839475110173225, 47.316489815711975, 49.272001683712006, 46.663137674331665, 43.960247710347176, 42.71899871528149, 45.960787162184715, 42.44083844125271, 36.91676706075668, 36.17918103933334, 31.77521925419569, 33.777641505002975, 36.92615255713463, 36.89202278852463, 37.55764067173004, 34.110891222953796, 47.02997758984566, 62.464129999279976, 59.969324469566345, 45.720723643898964, 46.27330519258976, 46.31065718829632, 43.64421866834164, 44.99201014637947, 47.570680975914, 49.82611455023289, 50.993453711271286, 50.81918366253376, 52.57149763405323, 48.47228139638901, 47.91401915252209, 46.72261208295822, 47.38222248852253, 50.81209324300289, 50.45273892581463, 52.53591254353523, 54.05036687850952, 54.71161499619484, 51.50141425430775, 49.170246943831444, 48.91502603888512, 50.647451877593994, 51.10663443803787, 47.52819165587425, 48.470522090792656, 54.59673576056957, 58.12401808798313, 55.561644583940506, 55.26619903743267, 53.18264164030552, 50.6158983707428, 50.84843449294567, 48.76702778041363, 51.432083174586296, 54.9554593116045, 50.98268888890743, 53.62335339188576, 58.96996669471264, 61.06350235641003, 59.748556315898895, 61.44835710525513, 46.896270364522934, 47.775657176971436, 57.53452531993389, 61.88711196184158, 64.18890684843063, 54.256353825330734, 60.501406118273735, 63.67641694843769, 76.16676092147827, 39.04319375753403, 0.1364689794718288, 34.880144745111465, 46.61257378757, 69.73862305283546, 25.677654147148132, 5.827073296532035, 36.17951542139053, 30.718247070908546, 23.004565984010696, 40.30521243810654, 45.74361361563206, 32.76806987822056, 33.37742418050766, 42.91037544608116, 59.24067936837673, 42.74375818669796, 1.4771962654776871, 0.2880105923395604, 0.0918972969520837, 0.03757968661375344, 0.09448604163480923, 0.01864409292466007, 0.05896515431231819, 0.04503365831624251, 0.10040546345408075, 0.003684362918647821, 0.0582546295481734, 0.07185803318861872, 0.09492162294918671, 0.16467231296701357, 0.08013791506527923, 0.13052465859800577, 0.24188131996197626, 0.628529260866344, 31.564195677638054, 76.24174609780312, 54.66246843338013, 52.230766117572784, 43.38683947920799, 63.86641055345535, 27.461010552942753, 27.637824565172195, 14.751567486673594, 35.126458927989006, 79.59698885679245, 62.581558898091316, 63.30936424434185, 61.07365541160107, 0.6864627928007394, 22.238720878958702, 84.97955963015556, 70.72040677070618, 74.65208619832993, 71.10232427716255, 65.74995428323746, 60.8021941781044, 66.21003359556198, 61.49940736591816, 60.48164337873459, 60.96328653395176, 61.827926337718964, 58.05543556809425, 58.782431557774544, 56.202647387981415, 58.89390617609024, 55.553368628025055, 54.692847803235054, 49.91250291466713, 52.01212204992771, 55.68785481154919, 60.13973392546177, 60.28246566653252, 54.20077420771122, 59.40807178616524, 61.949592009186745, 53.12432236969471, 55.27794800698757, 52.42975763976574, 56.14258401095867, 54.44436393678188, 52.878201976418495, 54.59767431020737, 54.631826877593994, 53.983612060546875, 52.73232780396938, 52.40435220301151, 53.77706654369831, 52.690336257219315, 57.40709535777569, 53.45197878777981, 52.32134185731411, 52.323070764541626, 53.58688294887543, 51.210395470261574, 50.02141647040844, 49.04340974986553, 51.0576930642128, 50.69031357765198, 46.950261667370796, 56.78692303597927, 81.93567976355553, 106.87858253717422, 133.07580560445786, 70.71830928325653, 39.44486640393734, 44.864192605018616, 42.998188734054565, 46.30579724907875, 44.58988532423973, 43.87479029595852, 43.242040649056435, 48.77947211265564, 42.29092888534069, 37.33607456088066, 39.679564610123634, 36.4817626029253, 33.27818490564823, 35.12140139937401, 37.020201310515404, 36.93088710308075, 35.26436872780323, 33.52519445121288, 50.05075849592686, 59.34298887848854, 47.88660742342472, 49.776223227381706, 51.49153858423233, 50.41026100516319, 50.78737936913967, 49.591906517744064, 50.76945573091507, 53.32293011248112, 50.79315885901451, 55.34575916826725, 54.52702470123768, 52.323439344763756, 50.30927762389183, 49.23505626618862, 49.82514940202236, 50.02650439739227, 51.15833446383476, 55.62446281313896, 57.8760851919651, 55.079074278473854, 50.32693147659302, 51.126796156167984, 53.80599819123745, 55.55492654442787, 55.64641423523426, 52.65668906271458, 57.748358845710754, 61.471072286367416, 56.710942313075066, 56.398967653512955, 56.39176324009895, 53.48471023142338, 53.43538507819176, 50.89453361928463, 53.814380541443825, 58.48627544939518, 55.98929263651371, 56.5732529014349, 63.75873953104019, 66.28203213214874, 68.24925497174263, 67.28317201137543, 59.85709369182587, 53.08993421494961, 63.00696887075901, 65.88495343923569, 66.83969780802727, 61.230700984597206, 65.62141478061676, 62.08877474069595, 75.72084724903107, 29.92292694747448, 0.08010434030438773, 42.5618277490139, 50.2324153482914, 72.11256086826324, 26.018037982285023, 5.508040515705943, 25.938677340745926, 34.36835780739784, 27.01153077185154, 52.38883763551712, 50.705284774303436, 42.296009212732315, 33.35341326892376, 52.49628446996212, 61.27266213297844, 55.851253643631935, 1.8422748567536473, 0.19227655517170206, 0.04669151232519653, 0.036561497108777985, 0.09266534558264539, 0.07914232395705767, 0.1488237938610837, 0.232519794953987, 0.18789709720294923, 0.11651123320916668, 0.10989594404236414, 0.28693302359897643, 0.18553948699263856, 0.31032216385938227, 0.17347007291391492, 0.21021806431235746, 0.24614727386506274, 0.5720287270378321, 35.184417217969894, 89.09414604306221, 66.49691060185432, 61.83742582798004, 50.31778536736965, 71.45147234201431, 42.45482549071312, 32.97395043075085, 15.076815783977509, 48.993051052093506, 82.46471017599106, 67.90911242365837, 71.6799920797348, 61.72327995300293, 0.6382572732400149, 37.79866173863411, 83.72874274849892, 70.0540441274643, 77.08319574594498, 72.9886494576931, 67.05639258027077, 64.66338738799095, 67.54211291670799, 65.40720507502556, 60.860844030976295, 62.31265872716904, 67.75905847549438, 59.53843519091606, 61.62657514214516, 58.11722785234451, 65.90269088745117, 60.59289000928402, 61.15731172263622, 55.03461666405201, 54.36714828014374, 57.15513467788696, 59.32083606719971, 61.56351372599602, 57.02398471534252, 63.54519858956337, 60.69296143949032, 58.16914826631546, 61.06149606406689, 58.32789994776249, 59.41763587296009, 56.931683868169785, 56.63745045661926, 60.982380509376526, 58.40771846473217, 59.06545177102089, 57.64288790524006, 57.61494040489197, 60.336658358573914, 55.453775972127914, 59.005635380744934, 56.871829479932785, 56.603339686989784, 58.35714317858219, 56.813707798719406, 53.71817730367184, 55.33424958586693, 55.31037926673889, 53.33030931651592, 57.00061596930027, 50.01425005495548, 61.00948825478554, 86.16448804736137, 107.45247334241867, 115.6368313729763, 57.02898524701595, 38.19218002259731, 44.932740926742554, 43.57207953929901, 46.239969581365585, 44.126838371157646, 43.42736430466175, 41.61689445376396, 50.676702708005905, 47.32444278895855, 41.4233024418354, 39.466179460287094, 35.538820400834084, 35.81934034824371, 35.10154366493225, 35.74036158621311, 36.263202130794525, 38.142976462841034, 37.86969132721424, 47.425498366355896, 56.40465974807739, 48.29500950872898, 52.650924772024155, 54.77854460477829, 52.25448064506054, 52.04676479101181, 54.98532950878143, 55.51667399704456, 54.43009190261364, 54.14036884903908, 57.567138969898224, 57.10248090326786, 55.39834074676037, 51.44974082708359, 52.72294610738754, 55.17313063144684, 53.09162512421608, 56.8130998313427, 59.407315626740456, 62.65327624976635, 59.4317065179348, 52.3964524269104, 55.7242226600647, 56.53109796345234, 56.471866741776466, 56.78750820457935, 53.91198590397835, 59.89907383918762, 61.951100528240204, 61.63879908621311, 57.605798095464706, 58.21095362305641, 56.13993175327778, 57.6654776930809, 55.678773298859596, 56.82535797357559, 60.723367407917976, 57.21155405044556, 56.50503136217594, 65.12998715043068, 68.3312925696373, 69.7783613204956, 69.72755804657936, 57.94450432062149, 54.03723858296871, 62.34716087579727, 69.27918210625648, 70.44923052191734, 63.318578749895096, 66.18350341916084, 68.93607571721077, 76.853057295084, 45.38437329232693, 0.2782452054088935, 41.91730633378029, 58.16645801067352, 78.78061786293983, 34.8691975325346, 13.236203100532293, 45.38494326174259, 42.76434928178787, 34.744115844368935, 59.60178919136524, 51.0583770275116, 47.63303942978382, 46.32823504507542, 60.226563066244125, 71.71837002038956, 65.62909796833992, 2.3349193716421723, 0.40813924628309906, 0.1218330480332952, 0.12609892030013725, 0.2339610902708955, 0.2246675014612265, 0.17076118936529383], [0.04956334552844055, 0.0677927782817278, 0.008129266716423444, 0.15125653910217807, 0.08275639018393122, 0.057094300209428184, 0.1662630174541846, 0.04174522793618962, 0.03682653659780044, 0.28022222744766623, 0.22036659240256995, 26.18778057396412, 74.98377040028572, 41.272028759121895, 35.62459699809551, 21.60763744264841, 47.15930365025997, 37.218854650855064, 29.40728511661291, 11.89667807891965, 8.185026794672012, 41.99049800634384, 70.24316757917404, 47.091116309165955, 67.73399502038956, 22.522542849183083, 0.5656164523679763, 44.25247102975845, 72.82216519117355, 68.94417688250542, 62.531272396445274, 62.0998777449131, 60.988460183143616, 53.08612681925297, 54.89458277821541, 64.10777360200882, 54.77414444088936, 58.041828498244286, 57.93089725077152, 55.55873014032841, 57.07122378051281, 55.99421337246895, 52.00667694211006, 50.81300899386406, 47.16314144432545, 45.69222517311573, 51.09140865504742, 58.203316032886505, 60.229804292321205, 57.41680383682251, 53.978501334786415, 63.539449498057365, 59.14866350591183, 49.36524488031864, 52.1193864941597, 51.87013506889343, 52.95107826590538, 53.58592540025711, 54.7752083837986, 51.30203515291214, 52.45309218764305, 50.962933748960495, 51.671990901231766, 54.8287209123373, 49.30128291249275, 55.32825730741024, 51.05356268584728, 48.71433600783348, 48.21172557771206, 49.56324465572834, 47.78150886297226, 45.10456770658493, 42.1906066685915, 42.64934845268726, 40.74562780559063, 34.99646410346031, 45.41678175330162, 54.75907064974308, 65.59111520648003, 55.92338137328625, 104.31823432445526, 78.25288698077202, 42.24546432495117, 45.13643279671669, 39.34093818068504, 41.557917818427086, 40.97609303891659, 47.237100675702095, 42.64211744070053, 38.372396752238274, 46.26868084073067, 36.998413279652596, 30.92528086155653, 27.214846462011337, 35.900059416890144, 36.882690489292145, 38.256050795316696, 58.87228533625603, 92.10641160607338, 80.58839365839958, 58.06477166712284, 49.732077196240425, 45.33242627978325, 40.27555122971535, 42.91519358754158, 47.259405478835106, 43.61358091235161, 43.4921508282423, 47.01238453388214, 47.327011451125145, 50.86953476071358, 48.25754351913929, 48.49527396261692, 47.97207623720169, 50.474500358104706, 46.22367985546589, 50.10328687727451, 51.29192389547825, 54.801024198532104, 53.873634561896324, 52.153409868478775, 49.52480211853981, 53.32030825316906, 52.15283989906311, 48.570164144039154, 46.67392909526825, 54.28082451224327, 59.07601520419121, 58.969354927539825, 56.56120374798775, 56.56214989721775, 56.007459461688995, 49.9108500033617, 50.19416660070419, 44.39536236226559, 50.38827918469906, 50.14254257082939, 56.483057141304016, 56.56304284930229, 56.1875393986702, 58.93423341214657, 61.856610998511314, 59.39502328634262, 63.08809831738472, 52.40352004766464, 58.575984835624695, 61.89440757036209, 61.94671556353569, 60.17609417438507, 68.42333883047104, 58.79236422479153, 74.3202044069767, 8.401291240006685, 1.2580231949687004, 45.05950592458248, 47.529445588588715, 69.1547691822052, 15.268690288066864, 9.326772429049015, 25.177842266857624, 22.452031932771206, 35.327160358428955, 42.8270573168993, 53.65204565227032, 35.94640552997589, 31.737057901918888, 41.957777962088585, 55.32112509012222, 54.58771124482155, 2.9163729585707188, 0.2847945992834866, 0.013596312419394962, 0.0714063250052277, 0.1279389567207545, 0.06828068842878565, 0.04376393640995957, 0.02671584876225097, 0.04254250234225765, 0.047927047198754735, 0.054741565909353085, 0.05405863048508763, 0.06790870917029679, 0.1835989489336498, 0.07682215509703383, 0.07156845458666794, 0.28566353546921164, 0.19795738393440843, 30.519637428224087, 87.77240976691246, 46.25287368893623, 45.10432831943035, 30.074675604701042, 56.022765040397644, 42.44827464222908, 29.04889404773712, 26.494787000119686, 14.674818255007267, 35.587913766503334, 77.08508044481277, 55.55873014032841, 71.4474369585514, 32.21545033156872, 0.046435567855951376, 40.60496315360069, 76.9803960621357, 74.24761310219765, 65.42357459664345, 65.13509407639503, 64.79568108916283, 56.66550815105438, 59.49252985417843, 65.78191056847572, 58.824510499835014, 61.16545468568802, 65.74458137154579, 65.73559105396271, 64.83807161450386, 55.70434972643852, 53.08545045554638, 52.72413544356823, 50.3444105386734, 50.983608439564705, 61.837634816765785, 63.4269755333662, 67.44680643081665, 66.23401030898094, 56.321121230721474, 58.967493027448654, 60.96292555332184, 51.30382105708122, 49.99998182058334, 54.065710455179214, 56.93636901676655, 55.807939767837524, 53.57203334569931, 52.19513542950153, 55.27911454439163, 54.874907433986664, 54.77286770939827, 54.76610787212849, 49.323599115014076, 57.191726714372635, 53.63259069621563, 52.25400947034359, 55.63254497945309, 51.74517497420311, 49.92886483669281, 46.713044196367264, 46.49291820824146, 48.688417598605156, 46.65610045194626, 34.39836099743843, 46.570757031440735, 63.54687809944153, 76.03159457445145, 77.63422697782516, 111.20299369096756, 61.89743220806122, 41.12286016345024, 45.202226266264915, 39.348305985331535, 41.119854524731636, 39.244879335165024, 46.22520737349987, 46.26972958445549, 44.31282319128513, 45.983931720256805, 36.554939076304436, 30.976481214165688, 29.08699080348015, 34.21581119298935, 35.60848966240883, 39.060600623488426, 38.72407928109169, 66.06451660394669, 78.87179017066956, 64.46949139237404, 49.772697016596794, 49.56896334886551, 49.32639956474304, 52.30534851551056, 51.18278995156288, 46.91503755748272, 50.75615644454956, 49.866605177521706, 51.18651755154133, 50.62757134437561, 50.93072287738323, 51.81372709572315, 51.36669248342514, 51.7485985904932, 53.5591596364975, 55.124265253543854, 56.69774182140827, 56.322941333055496, 53.71158845722675, 58.727577701210976, 53.630717396736145, 52.52320222556591, 53.9136616140604, 51.041927710175514, 49.92254577577114, 54.98644284904003, 60.8821152895689, 60.662551671266556, 62.85685792565346, 59.927948489785194, 59.5170309394598, 54.73877213895321, 51.92294463515282, 48.648139759898186, 53.27699817717075, 54.55564096570015, 59.56491976976395, 60.254278779029846, 59.939123690128326, 62.00582139194012, 68.20982828736305, 67.1022181212902, 71.11567676067352, 61.470213532447815, 66.04671075940132, 66.23091727495193, 64.26598951220512, 60.28661884367466, 70.29008746147156, 58.58529053628445, 76.1048774421215, 5.294822556897998, 2.824497213587165, 48.84744666516781, 47.97489948570728, 67.6803494989872, 13.509416989982128, 9.380663987249136, 26.39487326145172, 25.11915821582079, 30.57801939547062, 54.27644334733486, 56.79311290383339, 44.36359986662865, 40.96036568284035, 51.26544691622257, 62.67588883638382, 63.15901771187782, 2.6725345803424716, 0.2634554490214214, 0.12640054395888, 0.0275418498495128, 0.1242363968049176, 0.06349606977892108, 0.11743341849069111, 0.08721218546270393, 0.18053625390166417, 0.14557545800926164, 0.1629856339422986, 0.14296939159976318, 0.16663140471791849, 0.16956219042185694, 0.18290561973117292, 0.1635515215457417, 0.5871315510012209, 0.43206487025599927, 39.66099500656128, 96.81445777416229, 57.87996098399162, 52.79411628842354, 29.21092115342617, 69.70738872885704, 51.830537393689156, 38.42723160982132, 17.99913067370653, 17.251748777925968, 50.15089072287083, 83.82749184966087, 59.0862974524498, 81.856340020895, 28.87389823794365, 0.6549282849300653, 57.6825425773859, 74.14271593093872, 71.92512452602386, 69.36796054244041, 70.38240730762482, 70.48667371273041, 61.18662714958191, 56.82622812688351, 64.1512280702591, 64.90232616662979, 62.09319390356541, 68.43261793255806, 65.31764388084412, 64.39927875995636, 60.311636701226234, 58.65442782640457, 55.268577709794044, 55.51136188209057, 54.34048131108284, 59.23888586461544, 65.29495909810066, 67.58495181798935, 63.67099083960056, 57.323914021253586, 65.87996050715446, 61.402907744050026, 55.04893809556961, 56.02603666484356, 56.312837675213814, 59.850660637021065, 58.103115409612656, 60.04722408950329, 57.833785861730576, 56.853734850883484, 59.13004830479622, 57.352701276540756, 58.68565835058689, 58.74113157391548, 58.77442538738251, 57.15976282954216, 57.26230792701244, 58.707020804286, 55.06617397069931, 52.85738289356232, 51.10386058688164, 52.60477624833584, 55.513615161180496, 52.979576736688614, 41.25843308866024, 53.226080909371376, 74.14146199822426, 83.0968214571476, 91.83598011732101, 108.20946872234344, 53.53123493492603, 40.12538328766823, 45.276675671339035, 39.766363352537155, 42.22525700926781, 39.2349124699831, 47.51203112304211, 53.64452585577965, 47.814270704984665, 49.15886275470257, 38.870979398489, 31.069407127797604, 31.085909642279148, 34.951789900660515, 34.59417589008808, 40.143310725688934, 35.66023908555508, 59.756600484251976, 76.9837474822998, 63.056639805436134, 50.137450844049454, 50.9066853672266, 51.89762659370899, 54.87212598323822, 55.54048351943493, 51.231594532728195, 54.86753582954407, 52.138146087527275, 53.176147788763046, 57.077128663659096, 56.0501691699028, 54.11551058292389, 51.9946201890707, 56.53201751410961, 55.44926941394806, 59.040422514081, 62.098749205470085, 60.398127660155296, 59.25425224006176, 61.61414220929146, 56.69031322002411, 56.37046538293362, 59.37928073108196, 54.0036977827549, 53.713579550385475, 58.527328446507454, 63.024501129984856, 62.922867983579636, 61.07546031475067, 60.06115794181824, 61.72546483576298, 53.38037922978401, 54.286368414759636, 50.40415093302727, 56.61537364125252, 56.65325380861759, 61.77641250193119, 62.049055472016335, 60.51430642604828, 63.78023877739906, 69.57202479243279, 70.03215730190277, 73.75212728977203, 58.577888533473015, 66.59995347261429, 69.34694766998291, 69.60457384586334, 64.06960844993591, 74.09207224845886, 61.62576958537102, 78.59779447317123, 11.771271508187056, 2.063207351602614, 57.53752335906029, 54.63437274098396, 75.13280600309372, 23.701112307608128, 15.96221387386322, 31.68915007263422, 35.49878194928169, 48.10506150126457, 62.65000082552433, 64.33516100049019, 51.54143750667572, 42.8484957665205, 59.86915424466133, 68.9585629105568, 81.16111412644386, 5.913705797865987, 0.6366414099466056, 0.20077831693924963, 0.13836518162861466, 0.2793979982379824, 0.17007151152938604, 0.31819243216887116], [0.02103109403833514, 0.16517991229193285, 0.024950208935479168, 0.07704327799729072, 0.27039111591875553, 0.22226810833672062, 0.21950813534203917, 0.0915219854505267, 0.09237480961019173, 0.19914081261958927, 0.31413211254402995, 22.238215506076813, 65.54472729563713, 54.08239535987377, 31.536303274333477, 25.268285013735294, 51.88364714384079, 31.371399722993374, 44.09830950200558, 18.10044653713703, 10.274680014699697, 7.77354639954865, 44.51127514243126, 66.66560634970665, 55.6492754817009, 63.64436186850071, 3.20200078189373, 0.5121961876284331, 51.03801392018795, 61.10952168703079, 63.31046998500824, 52.572230994701385, 55.43808661401272, 51.97693973779678, 63.5194131731987, 53.64038027822971, 58.32153528928757, 58.76269921660423, 58.627589866518974, 62.91972555220127, 61.70123353600502, 54.7320768982172, 54.9923325330019, 52.867516949772835, 48.122943341732025, 53.86394128203392, 58.400863632559776, 55.92414133250713, 55.88772028684616, 52.13470347225666, 53.07819664478302, 58.541710674762726, 56.4312507212162, 55.43645650148392, 47.80244953930378, 47.95095317065716, 51.71185456216335, 52.101736441254616, 52.14702621102333, 52.8946702927351, 54.49033387005329, 53.485401794314384, 54.19434115290642, 51.055116802453995, 50.82086317241192, 50.59015095233917, 46.9719585031271, 49.91777703166008, 49.5232480019331, 46.28480717539787, 47.25897990167141, 44.22257803380489, 39.93915148079395, 38.464777395129204, 33.163461461663246, 26.39229889959097, 31.3640908151865, 28.88305764645338, 26.0467017441988, 33.96025210618973, 31.08583554625511, 61.69403672218323, 51.83179132640362, 41.881132274866104, 42.851672396063805, 38.69383670389652, 41.672747656702995, 45.55786058306694, 43.21160048246384, 42.26597562432289, 42.21278987824917, 40.35206772387028, 36.60079501569271, 29.689984247088432, 35.3493245691061, 36.87679700553417, 70.02448171377182, 107.80954778194427, 76.32721871137619, 50.76874136924744, 45.42926788330078, 34.73077096045017, 27.712239772081375, 33.175028041005135, 37.92466677725315, 38.67931768298149, 40.37488169968128, 42.73600660264492, 43.94410617649555, 48.854681476950645, 45.48266261816025, 49.04978200793266, 50.841990038752556, 51.48553870618343, 50.15581525862217, 51.02900080382824, 50.68477347493172, 50.94824753701687, 50.93834146857262, 51.602857410907745, 51.49072922766209, 51.08105041086674, 50.350125432014465, 47.9698571562767, 48.0598097294569, 48.53516422212124, 53.46067652106285, 58.396471068263054, 57.9132129997015, 65.09526461362839, 57.91894689202309, 54.88527327775955, 57.25179389119148, 49.11685600876808, 45.92412672936916, 49.00259993970394, 48.71440440416336, 56.13016627728939, 54.971285462379456, 56.391653046011925, 54.51711483299732, 61.61943532526493, 62.7103453874588, 61.709357500076294, 58.090055510401726, 59.04785491526127, 64.23584192991257, 59.44200396537781, 62.21265949308872, 62.19502083957195, 66.02404117584229, 54.086856320500374, 0.6523751188069582, 13.598766345530748, 60.0166205316782, 57.098403722047806, 52.68230348825455, 5.9031803626567125, 10.200608689337969, 27.898262590169907, 29.947253242135048, 35.112376883625984, 33.05651620030403, 52.58046135306358, 35.881322622299194, 18.44547752290964, 26.362605392932892, 59.31963533163071, 50.42246215045452, 1.475231652148068, 0.14185360225383192, 0.0970939634134993, 0.05183137109270319, 0.0790025330206845, 0.07868634842452593, 0.018725424888543785, 0.02621206036565127, 0.1560972270090133, 0.0727436899614986, 0.024270292196888477, 0.16018110240111127, 0.27185742161236703, 0.21399952936917543, 0.026096127621713094, 0.09122255854890682, 0.46280379581730813, 0.2499156177509576, 29.70236588269472, 74.2276793718338, 59.36041094362736, 35.048536509275436, 25.248681865632534, 59.104783460497856, 15.332529712468386, 34.18513543903828, 17.205596454441547, 17.511799223721027, 10.468306224793196, 42.48338855803013, 75.21087661385536, 62.589789256453514, 70.20844504237175, 8.010345418006182, 0.5728970991913229, 45.42238265275955, 60.64085863530636, 66.65070354938507, 53.50467436015606, 61.90331049263477, 60.32727286219597, 65.88219478726387, 57.24578261375427, 64.5997104048729, 63.96737113595009, 67.31026455760002, 70.01857683062553, 64.55012306571007, 60.29576875269413, 57.71505743265152, 51.271503791213036, 52.39098072052002, 58.87832321226597, 64.79790017008781, 63.53514812886715, 64.34358134865761, 59.23271119594574, 56.66711926460266, 59.44210655987263, 55.3064388781786, 54.69372935593128, 50.23946776986122, 48.53654354810715, 56.46848872303963, 51.128889843821526, 51.3137499243021, 55.81374205648899, 55.85301294922829, 56.830841079354286, 57.52549700438976, 52.92621619999409, 53.78991365432739, 46.411936953663826, 50.97668521106243, 51.84407226741314, 53.64606857299805, 51.90814822912216, 50.86404025554657, 47.960821241140366, 46.34859435260296, 44.75365653634071, 36.02951467037201, 29.8001042380929, 37.89928413927555, 38.166311010718346, 40.827046036720276, 44.636854603886604, 39.75057899951935, 70.47028139233589, 47.56944224238396, 42.01223284006119, 41.57920427620411, 36.005104780197144, 38.5139125585556, 45.50851263105869, 47.80900038778782, 45.30307665467262, 42.941309586167336, 37.717004120349884, 33.08926664292812, 27.05376360565424, 33.82085658609867, 33.87568384408951, 47.167188227176666, 90.9662751853466, 91.33657291531563, 60.889870673418045, 53.13973434269428, 49.494133964180946, 38.65988552570343, 40.74179381132126, 41.63401633501053, 48.37241515517235, 47.44232006371021, 50.14755830168724, 49.236902967095375, 48.97423826158047, 48.14349643886089, 52.76456147432327, 52.86149047315121, 54.653763100504875, 55.45397736132145, 56.11491769552231, 56.64209000766277, 51.45990148186684, 52.986515164375305, 54.146258533000946, 51.66174665093422, 53.93071509897709, 51.751988008618355, 48.83048057556152, 49.6164608001709, 50.098502933979034, 54.06830191612244, 59.85187277197838, 61.94781370460987, 66.76667332649231, 62.716333866119385, 57.9000923037529, 59.80485409498215, 56.879109889268875, 51.86308264732361, 49.7490356862545, 53.998465463519096, 57.79716722667217, 57.42707468569279, 60.720775946974754, 58.8699446618557, 63.922966718673706, 70.33705294132233, 71.86286106705666, 69.32385250926018, 64.62577700614929, 66.34505555033684, 61.218583434820175, 61.757284328341484, 60.94829633831978, 71.24373748898506, 46.54855862259865, 0.4186929721618071, 19.758668057620525, 66.66791662573814, 57.146509140729904, 52.60238617658615, 4.083138350397348, 18.45391307026148, 31.836589761078358, 31.663788333535194, 29.859065674245358, 43.125873282551765, 58.473941311240196, 41.451318338513374, 28.211211897432804, 35.56383065879345, 69.26022112369537, 63.157167211174965, 2.900120043195784, 0.40314830315764993, 0.16069518809672445, 0.04977357741154265, 0.1482942418078892, 0.00910358137844014, 0.13607360771857202, 0.08581708141718991, 0.3214721311815083, 0.19470452098175883, 0.22778202808694914, 0.4482734645716846, 0.39107237302232534, 0.4466358118224889, 0.18046428041998297, 0.3858778439462185, 0.3563765832222998, 0.5256348790135235, 36.613790318369865, 85.61392039060593, 71.33272871375084, 44.30131360888481, 31.25173844397068, 77.28452414274216, 45.18908657133579, 54.68258835375309, 26.193248480558395, 16.81591596454382, 18.332389891147614, 54.6272899210453, 80.33565402030945, 69.26541924476624, 79.23930644989014, 5.326742744073272, 1.552235351409763, 63.71356375515461, 61.90164238214493, 64.64744344353676, 53.47946651279926, 63.9566633105278, 58.759948164224625, 65.11969730257988, 62.94424183666706, 62.456378415226936, 65.88996917009354, 65.928955078125, 69.28624212741852, 70.40027394890785, 63.72218169271946, 59.87905651330948, 57.52509042620659, 56.90361477434635, 57.0088729262352, 66.66688308119774, 63.18006858229637, 65.33858835697174, 60.75315020978451, 61.78805507719517, 61.19554527103901, 57.480522617697716, 56.61120146512985, 52.449098601937294, 54.22697000205517, 59.1857685148716, 58.32486771047115, 57.3970752954483, 57.828184962272644, 60.33422268927097, 62.333443611860275, 61.320911943912506, 61.19323119521141, 57.00634606182575, 52.564118430018425, 54.6912594884634, 57.636325657367706, 59.73530262708664, 55.41147284209728, 54.83503617346287, 51.13005258142948, 52.00346991419792, 49.38186138868332, 42.53956854343414, 33.77368591725826, 43.606855273246765, 49.16581258177757, 54.64759223163128, 53.91749560832977, 55.65045341849327, 74.5615902543068, 42.38153122365475, 45.651506558060646, 44.293565824627876, 39.25116799771786, 39.75184053182602, 46.54610775411129, 49.8784339427948, 51.29837594926357, 44.47771914303303, 39.502950087189674, 34.41906988620758, 30.192767567932606, 34.09352995455265, 37.083855494856834, 45.185187980532646, 80.80277055501938, 90.71603581309319, 60.06812296807766, 52.72748306393623, 54.34834308922291, 43.346709832549095, 42.734380289912224, 44.40974839031696, 53.9180313795805, 51.757664903998375, 54.64089319109917, 53.1789368391037, 54.701716527342796, 52.553691789507866, 56.27674341201782, 55.2724839001894, 57.06998124718666, 57.16191351413727, 57.59029112756252, 60.966421365737915, 57.15226203203201, 58.562085181474686, 60.11118985712528, 55.97313970327377, 56.322785541415215, 55.8338163793087, 52.36468233168125, 52.77308441698551, 52.41786427795887, 59.24782678484917, 61.635345071554184, 61.53578281402588, 71.53419390320778, 64.18345794081688, 59.40903693437576, 62.27425418794155, 56.985226795077324, 54.40775290131569, 56.26570500433445, 54.85227204859257, 59.85304690897465, 59.00550618767738, 61.747895032167435, 61.384315341711044, 67.71875783801079, 70.49923583865166, 73.76980394124985, 67.07986012101173, 66.08402475714684, 69.88036304712296, 65.89892908930779, 67.52129003405571, 68.53362411260605, 70.41111096739769, 64.20323967933655, 0.7241659727878869, 17.670106329023838, 74.88283261656761, 63.35191436111927, 60.86934417486191, 10.83568001165986, 19.362795799970627, 32.44900479912758, 42.613831758499146, 44.85199145972729, 50.66869653761387, 67.04400524497032, 54.97597821056843, 25.989174731075764, 43.62545907497406, 77.16584131121635, 79.11941528320312, 4.618931449949741, 0.9014144679531455, 0.3086994431214407, 0.23439603333827108, 0.1954043810837902, 0.18159590719733387, 0.16042179573560134], [0.09557440120261163, 0.058603902798495255, 0.05762761124060489, 0.15353546681581065, 0.07350997228058986, 0.09558005636790767, 0.0800844952755142, 0.09855416865320876, 0.06431379777495749, 0.31411661650054157, 0.1644663669867441, 23.88912621885538, 67.27716833353043, 36.0115834325552, 46.77245780825615, 27.103202752768993, 46.328850612044334, 59.56036001443863, 104.40673157572746, 65.11255368590355, 15.835325382649899, 7.603360656648874, 18.723069727420807, 65.19403651356697, 54.86055180430412, 62.518144100904465, 42.25992634892464, 0.14810420747380704, 1.8859196710400283, 30.873852521181107, 47.365925163030624, 51.420307606458664, 56.27871930599213, 61.50489427149296, 54.44843351840973, 55.39060056209564, 61.53999298810959, 60.18222324550152, 63.175003454089165, 62.99910329282284, 59.445362985134125, 55.238274335861206, 53.85816939175129, 47.70091898739338, 52.57024750113487, 53.14910463988781, 52.49402359127998, 71.65686652064323, 78.39450538158417, 72.57963940501213, 54.69720236957073, 55.38887545466423, 60.97088232636452, 52.982639372348785, 54.478683695197105, 51.965783536434174, 51.791270300745964, 50.95928594470024, 51.414125338196754, 51.51261605322361, 50.26317849755287, 52.94671609997749, 50.211292281746864, 48.623064905405045, 51.56227558851242, 47.327938601374626, 47.20074042677879, 44.73004460334778, 46.76674671471119, 44.58263151347637, 42.53616772592068, 39.09308888018131, 37.65866205096245, 33.10422644019127, 23.532201871275902, 25.32506726682186, 27.906658239662647, 29.201244972646236, 11.960289515554905, 11.613559070974588, 22.489446625113487, 29.78297095745802, 48.42967048287392, 47.588768005371094, 43.95991712808609, 43.24102230370045, 44.165999069809914, 41.84119261801243, 46.8394710123539, 45.47583058476448, 44.40117225050926, 41.3799961656332, 43.42224977910519, 42.56463959813118, 41.99743263423443, 48.978600427508354, 74.35557290911674, 45.723330304026604, 36.896840929985046, 24.66042023152113, 25.220734365284443, 21.91872864961624, 20.26753105223179, 20.84639959037304, 29.68277793377638, 34.00223225355148, 35.91011367738247, 38.28987658023834, 41.8846432864666, 42.76611618697643, 45.24712845683098, 49.14470091462135, 47.06527389585972, 51.70382559299469, 53.25631968677044, 50.53962126374245, 50.07242873311043, 52.186483293771744, 52.41684213280678, 51.479554027318954, 50.232791528105736, 49.20846529304981, 49.95194859802723, 49.21373941004276, 48.373931273818016, 48.41637119650841, 55.28939679265022, 57.02553503215313, 61.373288333415985, 56.79229974746704, 59.67188403010368, 58.443550541996956, 71.1229495704174, 60.56596465408802, 45.78803703188896, 47.589026391506195, 52.326843962073326, 54.20814201235771, 55.504096671938896, 54.524174854159355, 56.97687864303589, 60.33910162746906, 59.08823914825916, 59.52013537287712, 62.269189059734344, 59.64353375136852, 58.226726576685905, 60.75892969965935, 61.60573326051235, 60.09018458425999, 75.25005251169205, 10.185502599924803, 0.14288036356447265, 46.355099603533745, 53.28988328576088, 57.946472615003586, 27.04274419695139, 0.96637376351282, 11.163515020161867, 21.7483913898468, 24.919841811060905, 36.87168247997761, 33.32166217267513, 46.66757583618164, 40.04185616970062, 27.688578441739082, 28.35075180977583, 57.92213872075081, 53.84877249598503, 2.453983132727444, 0.14463177270954475, 0.1571035198867321, 0.06474315989180468, 0.04326125010265969, 0.05263067527266685, 0.10138952158740722, 0.06523639123770408, 0.02836178016877966, 0.121673078101594, 0.17001107102259994, 0.0670503856963478, 0.08820880815619603, 0.029024852010479663, 0.04612814060237724, 0.026122626004507765, 0.3404351620702073, 0.10582698581856675, 30.43414581567049, 76.59553751349449, 44.893698021769524, 47.572022303938866, 27.946149520576, 54.776165932416916, 51.1643685400486, 104.18524146080017, 63.14140945672989, 15.248319581151009, 9.674823302775621, 22.187999300658703, 70.0105744600296, 64.23562154173851, 66.4096748828888, 51.71406224370003, 0.2101569261867553, 1.245246499311179, 23.4369732812047, 41.70737139880657, 54.22886610031128, 59.43139873445034, 63.725084736943245, 61.25310078263283, 61.35928228497505, 65.56912958621979, 66.220513433218, 70.96912622451782, 68.53587359189987, 65.02612352371216, 56.47342465817928, 55.20560368895531, 48.35574924945831, 54.89582911133766, 56.18768759071827, 62.524850741028786, 83.42813327908516, 83.05426374077797, 74.88205745816231, 55.576915964484215, 50.90731993317604, 62.4288184940815, 55.56890219449997, 56.070745065808296, 55.36597028374672, 52.278719544410706, 52.20406875014305, 53.61385390162468, 53.776367381215096, 55.121092423796654, 58.93634989857674, 52.375283762812614, 52.51796990633011, 53.282025307416916, 49.789419919252396, 50.454657822847366, 51.63270100951195, 50.61782106757164, 51.86236068606377, 45.18448121845722, 43.637390434741974, 47.36138440668583, 42.1050238609314, 29.35345910489559, 29.072513580322266, 29.180047810077667, 35.07109209895134, 17.005267404019833, 19.751763828098774, 26.34462285786867, 30.9571972489357, 53.22162754833698, 44.71821203827858, 42.402076721191406, 40.172740146517754, 43.59058074653149, 43.74033451080322, 45.006369575858116, 42.21216291189194, 40.59197545051575, 38.59562337398529, 40.4230061173439, 38.19704756140709, 38.043797984719276, 41.64233408868313, 70.30867606401443, 63.34271505475044, 48.153444305062294, 42.18616470694542, 43.663365840911865, 29.680902734398842, 24.318968653678894, 24.458639658987522, 38.63228760659695, 42.013061195611954, 44.35759998857975, 43.33323955535889, 49.00133080780506, 46.34506434202194, 50.689428225159645, 52.34387464821339, 52.44228936731815, 55.482665821909904, 58.862052485346794, 55.722307562828064, 53.965243846178055, 52.6898954808712, 54.06508348882198, 53.01157481968403, 53.45402307808399, 52.02620029449463, 50.693003833293915, 50.42499661445618, 49.34460438787937, 51.47224321961403, 54.115362390875816, 57.51317426562309, 64.23899576067924, 59.007007107138634, 63.86023208498955, 61.08898378908634, 66.3995598256588, 67.24692195653915, 52.7445213496685, 51.1283540725708, 51.93513438105583, 57.89178974926472, 62.06132881343365, 58.68972413241863, 60.422822535037994, 62.264739498496056, 62.84172333776951, 67.42827102541924, 70.75088873505592, 64.76985767483711, 61.01376302540302, 62.629227340221405, 61.4086302369833, 61.61299467086792, 68.93432781100273, 3.0124232545495033, 0.24956559122074395, 58.038689866662025, 56.762144565582275, 63.32615174353123, 24.555899240076542, 2.9205771954730153, 17.220370061695576, 13.484591022133827, 28.557853996753693, 37.082707956433296, 36.659642457962036, 51.98511689901352, 42.71755859255791, 30.097540877759457, 38.53255435824394, 64.69434812664986, 61.836460679769516, 3.410352151840925, 0.35167190129868686, 0.08577986271120608, 0.052699776642839424, 0.08210355998016894, 0.07685945543926209, 0.1972186501370743, 0.13902839447837323, 0.16402573906816542, 0.1868033644859679, 0.34470809216145426, 0.1893703345558606, 0.2788176090689376, 0.19467955513391644, 0.15999442257452756, 0.16193214047234505, 0.4667669237824157, 0.1612967878463678, 36.34831376373768, 89.76121544837952, 53.65543507039547, 63.691676929593086, 37.95084357261658, 65.09010449051857, 69.90188509225845, 109.47736948728561, 72.9846140742302, 24.0610308945179, 13.859163522720337, 29.04957041144371, 74.90985676646233, 68.01547631621361, 74.14308831095695, 52.69203096628189, 0.12900902976980433, 3.8756419345736504, 41.40836164355278, 49.83400672674179, 57.79429838061333, 59.16923180222511, 67.08942040801048, 64.36281591653824, 62.64327518641949, 67.44568929076195, 65.5899752676487, 66.51549160480499, 72.8005899488926, 64.32263687252998, 58.686699494719505, 58.39892193675041, 53.85085478425026, 59.500938802957535, 59.12867657840252, 63.91554191708565, 83.03347885608673, 76.90578326582909, 67.29151636362076, 52.89414592087269, 60.728580728173256, 65.15850082039833, 58.57542626559734, 60.799918100237846, 57.10456319153309, 55.073697566986084, 53.55846047401428, 58.344660848379135, 57.37353175878525, 58.895752876996994, 64.75666478276253, 59.424346312880516, 55.73214903473854, 56.27300061285496, 53.452096581459045, 56.47013783454895, 59.24876533448696, 55.79696215689182, 57.08799608051777, 52.88546338677406, 49.286543503403664, 56.40057496726513, 48.79474349319935, 35.89128948748112, 37.0218276232481, 36.82158216834068, 38.550299406051636, 23.746531270444393, 32.280335649847984, 38.97432245314121, 41.97265036404133, 55.80831974744797, 45.94939537346363, 47.57872894406319, 45.21796502172947, 47.29176454246044, 43.85388761758804, 45.789043977856636, 40.39388068020344, 45.26896208524704, 40.54667808115482, 44.31438110768795, 41.895392909646034, 42.482579201459885, 38.473995700478554, 64.26795020699501, 62.86240942776203, 51.17574132978916, 43.68565544486046, 54.01668168604374, 38.60140286386013, 32.10771471261978, 30.359761007130146, 47.71777108311653, 50.44448956847191, 52.79739931225777, 47.966532334685326, 51.95256784558296, 52.14029297232628, 54.052471965551376, 56.02091073989868, 54.55741547048092, 54.770394042134285, 59.926816150546074, 58.13323639333248, 55.765416249632835, 58.62304911017418, 59.112808629870415, 57.61486440896988, 57.09575906395912, 53.644978031516075, 55.631154254078865, 52.17234805226326, 51.75563581287861, 51.701583713293076, 56.996914967894554, 60.77700912952423, 65.62454581260681, 59.453638941049576, 63.862853944301605, 63.9341077208519, 62.25398227572441, 65.699652582407, 56.00164957344532, 53.356904089450836, 56.80347874760628, 58.57400894165039, 64.9067947268486, 59.44344028830528, 62.884372249245644, 65.18477261066437, 67.18572244048119, 67.24544003605843, 73.49545866250992, 64.67926293611526, 65.24218752980232, 64.85352918505669, 68.3760617673397, 64.52250614762306, 78.97895202040672, 13.735112529248, 0.1775239358539693, 59.263010770082474, 63.34685303270817, 67.83488720655441, 36.41209714114666, 5.647550029680133, 20.137057453393936, 28.203840292990208, 35.64271442592144, 49.759561121463776, 48.663042560219765, 59.44891199469566, 56.85866318643093, 37.70742863416672, 47.264763191342354, 70.80014169216156, 78.21258634328842, 5.748004289343953, 0.9070069366134703, 0.30933596834074706, 0.1516433316282928, 0.15893787145614624, 0.11350967630278319, 0.21423453785246238], [0.09860693535301834, 0.07863509570597671, 0.13183867558836937, 0.041441307330387644, 0.12245317921042442, 0.07814529308234341, 0.0351979900005972, 0.08546465774998069, 0.06387277651811019, 0.3072640404570848, 0.38471225649118423, 19.906159043312073, 63.9143867790699, 44.38909649848938, 46.68015696108341, 24.02056496590376, 42.79396489262581, 17.596346586942673, 73.4242656826973, 69.17893588542938, 13.012417908757925, 6.991616282612085, 22.606531642377377, 42.91845001280308, 58.081315979361534, 53.0533117800951, 64.82297122478485, 10.957418829202652, 0.7160658168140799, 1.4479139680042863, 15.280956029891968, 32.53866098821163, 47.30286754667759, 48.95518608391285, 50.73846839368343, 56.09658747911453, 57.84543223679066, 59.007626473903656, 60.80575078725815, 63.573252484202385, 60.516711696982384, 56.70286014676094, 53.7445554882288, 51.52247652411461, 54.53888766467571, 62.18569613993168, 74.06318619847298, 65.54835230112076, 65.4070682823658, 74.45487678050995, 82.30581790208817, 64.02358531951904, 56.51375949382782, 61.9309464097023, 57.801517993211746, 54.27510201931, 50.665056332945824, 51.303410679101944, 53.04214037954807, 54.36762325465679, 49.940488412976265, 54.15781371295452, 51.640501990914345, 49.71150889992714, 45.77356740832329, 41.33646570146084, 33.2337386906147, 41.03022113442421, 46.12332344055176, 41.54005877673626, 38.103918358683586, 34.500339925289154, 30.301154851913452, 28.54827281087637, 32.2392750531435, 35.7460992783308, 35.30700623989105, 30.78356746584177, 24.312427304685116, 16.205083541572094, 20.78574914485216, 27.516810558736324, 33.55735972523689, 39.70682434737682, 46.19267351925373, 43.309597223997116, 45.50060525536537, 44.78052109479904, 40.93903362751007, 42.510363310575485, 39.673272147774696, 44.38093453645706, 45.84892116487026, 44.41708579659462, 42.77820333838463, 45.23537568747997, 33.03423039615154, 30.985748916864395, 17.575597800314426, 8.91543310135603, 20.411246940493584, 24.473211877048016, 24.532995969057083, 19.435449801385403, 19.456743858754635, 21.227110661566257, 27.316641099750996, 32.20558986067772, 35.18949754536152, 39.80117328464985, 45.81678628921509, 44.833775237202644, 53.099973276257515, 54.616152718663216, 53.492845594882965, 54.029069021344185, 52.48801231384277, 51.68990693986416, 50.85417598485947, 51.969712525606155, 52.11162731051445, 52.590546011924744, 46.215521693229675, 49.15101997554302, 47.8585459291935, 52.41460405290127, 54.59082327783108, 59.135352820158005, 59.236917570233345, 59.436437264084816, 55.381857231259346, 70.75007557868958, 103.842264264822, 63.225134164094925, 56.179442033171654, 46.303802356123924, 47.7558184415102, 55.8971855789423, 55.95136307179928, 57.89582513272762, 58.49793702363968, 55.76012313365936, 57.76572771370411, 60.501337721943855, 60.60489736497402, 61.22882768511772, 57.61444263160229, 61.73702381551266, 59.838972464203835, 67.51534715294838, 30.905157141387463, 0.7083769887685776, 7.197258872911334, 56.189055517315865, 50.15996463596821, 56.383069306612015, 8.822816871106625, 2.8618173860013485, 17.18482866883278, 30.59254791587591, 21.95699069648981, 26.73011977225542, 37.299136742949486, 42.354662865400314, 28.72950218617916, 36.893709897994995, 40.37784934043884, 56.775512248277664, 45.36408618092537, 1.455241043586284, 0.05062640157120768, 0.09104383454541676, 0.041095934066106565, 0.09776359584066086, 0.01659379864577204, 0.04400155354232993, 0.05041909003921319, 0.06730740627972409, 0.09335761351394467, 0.03709974713274278, 0.17838936910266057, 0.03221411847334821, 0.0070161843541427515, 0.05320193602528889, 0.10856033055461012, 0.20625143341021612, 0.17088447493733838, 23.88100605458021, 78.04215028882027, 51.94298855960369, 50.41711203753948, 31.948062479496002, 48.40936817228794, 30.217413045465946, 98.18339511752129, 84.45735365152359, 14.287984762340784, 8.671160358935595, 28.941842392086983, 46.282553896307945, 67.26798802614212, 58.15167300403118, 71.6456039249897, 13.797972556203604, 0.5557349044829607, 0.11357212802977301, 14.938231520354748, 32.8880750387907, 50.49134865403175, 53.96632298827171, 59.23072390258312, 61.53052769601345, 64.80516538023949, 64.85828652977943, 66.28846138715744, 66.9325040280819, 62.08696983754635, 61.973800510168076, 56.52265101671219, 51.77033722400665, 58.72112184762955, 69.24657225608826, 82.66093924641609, 64.66710358858109, 62.361440509557724, 69.15489837527275, 80.4656146466732, 65.06971478462219, 53.113831132650375, 63.97940129041672, 61.38394296169281, 55.884080082178116, 53.744107112288475, 52.924035117030144, 55.461759343743324, 56.72131575644016, 51.505092456936836, 54.515651911497116, 54.987054616212845, 52.3084719479084, 51.81085824966431, 43.06278146803379, 37.29664407670498, 42.75986172258854, 49.35670293867588, 45.362752452492714, 43.79184454679489, 41.10126972198486, 39.02478374540806, 34.28990721702576, 31.022435948252678, 33.05440731346607, 33.43963444232941, 32.24824257194996, 30.78948374837637, 17.987282909452915, 21.55865427106619, 27.033607587218285, 35.53291171789169, 43.93508546054363, 43.22789400815964, 41.54946707189083, 43.71369794011116, 42.33750678598881, 39.746752604842186, 42.88818843662739, 40.061744302511215, 42.20678620040417, 41.65082283318043, 43.18888150155544, 41.48128353059292, 47.901609018445015, 33.950216844677925, 33.252787068486214, 32.516101598739624, 19.724272303283215, 24.954311661422253, 26.133249700069427, 27.76231348514557, 20.619901344180107, 24.5237909629941, 33.552431389689445, 35.998512133955956, 41.30098320543766, 39.974432587623596, 47.69799314439297, 51.819559782743454, 51.94640077650547, 54.21738691627979, 55.735033079981804, 54.605593085289, 54.18419189751148, 55.342882722616196, 54.51122134923935, 52.792159393429756, 52.293614745140076, 52.37276829779148, 53.548497408628464, 52.15381644666195, 51.308008432388306, 51.997105255723, 53.18255044519901, 58.734352737665176, 61.99289828538895, 60.56007117033005, 60.406529009342194, 60.62317058444023, 64.6145524084568, 97.46611520648003, 66.34925052523613, 57.98261247575283, 50.444956943392754, 50.59955544769764, 57.15220883488655, 60.391789600253105, 62.45029874145985, 62.4283055216074, 60.610129684209824, 62.617136389017105, 67.00524732470512, 63.846431225538254, 66.9529165327549, 60.84524966776371, 60.440727174282074, 60.504571348428726, 63.976209461688995, 17.191882990300655, 0.8563585043884814, 11.981989201158285, 62.185091972351074, 56.89503103494644, 61.844417452812195, 12.5828443095088, 6.0936494171619415, 11.169116869568825, 22.303404808044434, 24.244082272052765, 24.595449417829514, 27.34560314565897, 47.55521200597286, 35.79995758831501, 27.727399058640003, 40.58080404996872, 68.32330539822578, 55.96553631126881, 2.5949009461328387, 0.043640153598971665, 0.06062817366910167, 0.24255118245491758, 0.04667448745749425, 0.05616255606582854, 0.06445434570196085, 0.16590475308476016, 0.14196646807249635, 0.21457352122524753, 0.1730687788221985, 0.3972622408764437, 0.16341777169145644, 0.1209490091423504, 0.20182741689495742, 0.19053862342843786, 0.3904870856786147, 0.45993394043762237, 30.496973544359207, 85.64241126179695, 61.04765720665455, 62.09371827542782, 37.172565534710884, 59.79937098920345, 22.508994676172733, 84.64050382375717, 71.98162749409676, 22.597645819187164, 13.135688994079828, 33.34788836538792, 53.03082838654518, 72.87847056984901, 62.96878471970558, 79.35242637991905, 12.935198452323675, 0.8824033755809069, 3.4820269932970405, 29.158497266471386, 39.158072993159294, 55.33714883029461, 55.15349328517914, 63.756573647260666, 64.33479622006416, 66.21292144060135, 66.20991960167885, 69.41613435745239, 67.99380227923393, 64.63972225785255, 64.7890542447567, 61.62304513156414, 57.66326621174812, 58.88086527585983, 65.61278164386749, 80.44286906719208, 69.34064760804176, 74.33443084359169, 74.04994010925293, 69.07403111457825, 56.07504643499851, 62.59531795978546, 65.07097631692886, 60.999813973903656, 59.30621065199375, 54.013539254665375, 56.9898397475481, 60.571535155177116, 58.19397613406181, 57.61194236576557, 60.36426767706871, 58.27423542737961, 54.193824380636215, 54.01639670133591, 48.73790614306927, 45.10809391736984, 48.01004000008106, 56.01849406957626, 53.87122169137001, 48.51823233067989, 50.149002224206924, 48.086111918091774, 40.74851185083389, 37.8028529137373, 41.6291867941618, 38.12612056732178, 37.474360540509224, 37.486348897218704, 23.49797710776329, 35.26464231312275, 36.87332019209862, 37.778849601745605, 47.60367840528488, 48.12008589506149, 44.354020580649376, 47.216194197535515, 45.21313168108463, 42.48807370662689, 46.41857139766216, 40.69260165095329, 47.39778645336628, 43.82451519370079, 43.18170748651028, 43.226032108068466, 49.20276939868927, 43.12121473252773, 43.81827972829342, 39.36934545636177, 28.319903165102005, 34.38389137387276, 36.52683578431606, 36.57897278666496, 26.445969119668007, 32.6440217345953, 44.353093430399895, 44.39568914473057, 49.84263226389885, 47.32652507722378, 50.60212790966034, 59.41382087767124, 53.870993703603745, 57.81929723918438, 57.47249364852905, 56.30222484469414, 56.49655781686306, 56.95174299180508, 55.55686444044113, 59.567328840494156, 56.534928157925606, 56.951792389154434, 57.275147438049316, 53.72515752911568, 53.31450596451759, 54.050712659955025, 57.31411054730415, 60.3790108859539, 60.72967126965523, 64.04167234897614, 63.159139305353165, 63.37167710065842, 58.656909093260765, 103.63937795162201, 74.91865709424019, 59.46720041334629, 54.00366738438606, 53.15543130040169, 61.704436764121056, 64.09744575619698, 67.00802877545357, 64.5315420627594, 63.06137055158615, 61.62162780761719, 67.84453868865967, 67.29606091976166, 69.59220930933952, 64.53809291124344, 67.93188080191612, 64.44895729422569, 69.27675783634186, 37.234384417533875, 0.8705409464892, 10.19242487847805, 69.09675389528275, 62.06710450351238, 67.50485971570015, 18.531603701412678, 9.073326028883457, 26.41124278306961, 38.25872205197811, 31.501092463731766, 40.304456278681755, 57.07559734582901, 57.76189751923084, 44.536893367767334, 47.86884717643261, 57.969693168997765, 71.62728890776634, 70.53615465760231, 4.220541352406144, 0.47384974372107536, 0.21875936770811677, 0.2058906457386911, 0.16657943953759968, 0.14076230378123, 0.1344629839877598], [0.04260660905856639, 0.04674385600083042, 0.08962380175944418, 0.04314098878239747, 0.03131280609522946, 0.07501239830162376, 0.05436061408545356, 0.08392963660298847, 0.16303302749292925, 0.1075320849486161, 0.25829951162450016, 19.426757767796516, 69.98641535639763, 53.085815235972404, 41.021341010928154, 14.310226868838072, 42.41206258535385, 11.175264939665794, 23.678746707737446, 22.912846505641937, 9.082065559923649, 5.58819436468184, 43.43569725751877, 55.71466237306595, 54.0193073451519, 55.6301549077034, 62.0233840495348, 15.695492886006832, 0.026373060027253814, 0.12736560311168432, 2.3226194316521287, 19.972009509801865, 39.37672846019268, 57.04665809869766, 53.90655219554901, 58.14082458615303, 53.905226066708565, 56.41243793070316, 61.52129799127579, 62.037488892674446, 58.61911632120609, 56.80518865585327, 51.41676999628544, 50.698046162724495, 55.49738623201847, 69.3304793536663, 62.1161712706089, 54.43912021815777, 42.491653114557266, 30.98143044859171, 42.87709683179855, 67.05464467406273, 69.5426295697689, 52.66097143292427, 58.847810849547386, 55.83493731915951, 54.52585816383362, 56.38749226927757, 57.90924981236458, 54.35148172080517, 53.048805221915245, 48.10769096016884, 47.26618051528931, 46.71287700533867, 44.366677701473236, 38.777413219213486, 12.771876566112041, 19.12307046353817, 39.38893720507622, 36.029769256711006, 33.541009202599525, 26.345886290073395, 25.78753475099802, 35.400667414069176, 43.29778365790844, 37.961585596203804, 36.90979443490505, 35.442221984267235, 27.66383606940508, 26.545989252626896, 27.20932725816965, 25.10764103382826, 23.419203534722328, 34.84228357672691, 40.9016702324152, 36.01245738565922, 38.23892131447792, 36.82721346616745, 38.3810792863369, 42.202659621834755, 42.37465359270573, 40.720514953136444, 40.782523825764656, 42.67487548291683, 43.51464182138443, 37.591310665011406, 26.300309635698795, 22.127795331180096, 10.012004859745502, 15.236407220363617, 27.222003377974033, 25.546646676957607, 20.162840969860554, 17.22813304513693, 16.933453157544136, 17.889225371181965, 19.744485318660736, 25.673001296818256, 31.773610040545464, 37.47287482023239, 39.64696615934372, 44.48593430221081, 43.89915458858013, 47.85063475370407, 49.89311635494232, 49.43408578634262, 56.0526542365551, 53.87017674744129, 57.16627188026905, 51.868276968598366, 53.596287444233894, 52.75131158530712, 52.06028066575527, 50.49042910337448, 52.69211836159229, 51.84521980583668, 56.71351097524166, 54.0203370898962, 55.59531457722187, 54.84802767634392, 62.20096752047539, 87.19572231173515, 58.92352178692818, 56.13503381609917, 55.16213022172451, 44.72315937280655, 51.152042001485825, 53.11966001987457, 58.684959188103676, 57.17337369918823, 59.72259610891342, 56.22625932097435, 58.41347135603428, 57.31937326490879, 61.28382593393326, 58.809007331728935, 59.350067898631096, 52.20983304083347, 65.01024797558784, 35.046135038137436, 0.7798776333220303, 0.05498970298503991, 25.706243813037872, 54.67798300087452, 50.21193824708462, 43.157567381858826, 17.493474707007408, 6.774775693193078, 6.076772622764111, 18.683225065469742, 31.172419600188732, 59.34512436389923, 44.77192975580692, 42.42821931838989, 30.527617000043392, 46.2248045951128, 38.95908147096634, 61.888605281710625, 44.97220180928707, 1.6418483178131282, 0.12088779680198058, 0.03773797187022865, 0.0878402947273571, 0.02945510841527721, 0.09813290336751379, 0.06515445071272552, 0.04317919083405286, 0.031214430709951557, 0.04738474133773707, 0.05815022792376112, 0.08330670752911828, 0.2796920668333769, 0.049149030455737375, 0.10701439983677119, 0.08565334879676811, 0.2892643172526732, 0.24955926812253892, 20.999101996421814, 84.7491703927517, 60.2746494859457, 40.36243736743927, 21.386143527925014, 52.10971221327782, 18.649087697267532, 36.793003901839256, 30.363061130046844, 14.425392039120197, 7.198420185595751, 47.04044222831726, 58.622403144836426, 57.21140965819359, 59.637609869241714, 69.46558490395546, 19.230728186666965, 0.03295039576187264, 0.014910259833413875, 1.293219281360507, 25.51660928875208, 43.35514537990093, 57.79171831905842, 58.635641634464264, 62.95435309410095, 60.36855384707451, 61.96513317525387, 67.19025179743767, 66.61791130900383, 61.93679429590702, 57.00714021921158, 52.35536903142929, 51.283355355262756, 57.99331270158291, 68.97968217730522, 56.49215005338192, 56.013846918940544, 47.088365256786346, 37.45405063033104, 43.266549333930016, 68.8995748758316, 75.16148686408997, 53.313924595713615, 58.61720882356167, 60.261266604065895, 57.00598128139973, 59.1540440171957, 61.624447256326675, 59.331072717905045, 53.644453659653664, 48.65171916782856, 48.89935947954655, 48.610742166638374, 46.851748153567314, 38.01202788949013, 19.75683845579624, 22.65282265841961, 39.832460805773735, 40.326263308525085, 34.8941545933485, 33.78040015697479, 31.245749965310097, 36.99723154306412, 46.27864770591259, 42.825750187039375, 44.13968548178673, 34.92446556687355, 31.08237773180008, 31.856206208467484, 26.134458035230637, 26.80708274245262, 29.770249240100384, 37.608451545238495, 40.61965696513653, 36.58722214400768, 39.734608456492424, 37.294326201081276, 40.22931911051273, 37.73781180381775, 38.75475503504276, 41.89813636243343, 43.731640577316284, 40.789819434285164, 40.84577143192291, 37.00988106429577, 27.06738967448473, 26.375340409576893, 10.735770072788, 18.585418313741684, 27.763573117554188, 28.008582070469856, 25.783818550407887, 25.618001148104668, 18.76702956855297, 23.821771033108234, 29.45143684744835, 32.84284986555576, 40.34609444439411, 42.75436721742153, 47.405268251895905, 49.086115658283234, 52.27300085127354, 53.172450587153435, 54.57963287830353, 53.40949326753616, 57.784726694226265, 57.72899508476257, 60.14338552951813, 53.492572009563446, 57.313160598278046, 55.37499859929085, 51.88128747045994, 53.335199654102325, 56.139422580599785, 56.25172935426235, 59.789502918720245, 55.689507722854614, 58.00474248826504, 57.93628916144371, 61.90395265817642, 78.65279272198677, 63.36345434188843, 58.65392245352268, 61.24631814658642, 50.480914413928986, 54.5798646658659, 56.1131089925766, 61.468534022569656, 63.016859740018845, 64.13903832435608, 59.04394872486591, 62.49355562031269, 60.631689727306366, 65.2552056312561, 59.93963286280632, 63.919159322977066, 52.787732630968094, 64.88730937242508, 22.816793359816074, 0.5216576205566525, 0.03460534426267259, 34.012833684682846, 62.49738961458206, 56.44275650382042, 49.92693834006786, 27.708584368228912, 10.789410844445229, 6.354148713871837, 17.619019970297813, 33.38445760309696, 55.70464991033077, 44.40955840051174, 48.100760132074356, 35.617806762456894, 34.72705475986004, 40.528800040483475, 69.83698457479477, 52.737286537885666, 1.9335775449872017, 0.20006132806884125, 0.0437751947902143, 0.07748435120447539, 0.012251111311343266, 0.1258278582827188, 0.0820626453787554, 0.10492326517123729, 0.1805475345463492, 0.19102510123047978, 0.15587063448037952, 0.1877196942223236, 0.3660939383553341, 0.32266241731122136, 0.2294121406157501, 0.19644129497464746, 0.43232652184087783, 0.5126412387471646, 28.71173433959484, 97.55765989422798, 70.64715430140495, 57.544587180018425, 19.61984060704708, 64.1560310125351, 18.7931227684021, 30.56374356150627, 26.051362194120884, 18.11318725347519, 13.557359017431736, 53.499920815229416, 61.499745547771454, 65.190799087286, 65.49130976200104, 78.74450460076332, 20.369565077126026, 0.0753170796087943, 0.19770898710703477, 5.301095070317388, 35.95698036253452, 46.54186338186264, 61.18962898850441, 62.25072205066681, 65.4598018527031, 63.2645608484745, 62.80018016695976, 71.03078931570053, 68.75677093863487, 63.68231423199177, 60.47965228557587, 55.727205500006676, 52.09419384598732, 58.669231832027435, 66.59149512648582, 57.125089690089226, 57.185654640197754, 46.72169633209705, 45.04845231771469, 60.72160430252552, 66.4854048192501, 63.227277249097824, 60.27473308146, 64.6652264893055, 59.27084594964981, 60.739383548498154, 59.62287425994873, 61.23082257807255, 59.76306013762951, 59.24574829638004, 54.740835428237915, 54.46858003735542, 53.74383732676506, 52.6899790763855, 41.90966114401817, 26.781884394586086, 35.73457829654217, 47.28257663547993, 49.488438069820404, 40.76614290475845, 39.892478585243225, 37.405109256505966, 42.99259923398495, 57.52119943499565, 51.637697741389275, 52.07632340490818, 42.99669921398163, 36.8127666413784, 38.89137290418148, 34.53701935708523, 32.34784662723541, 35.9738514572382, 42.085059732198715, 43.018031269311905, 40.05586601793766, 43.17106805741787, 40.83795145153999, 42.96290002763271, 41.36602431535721, 43.7576349824667, 43.69745001196861, 45.62683068215847, 44.00780975818634, 44.35302123427391, 43.0211167037487, 37.08632916212082, 40.44996187090874, 21.442750990390778, 25.5271328240633, 39.26906503736973, 31.143670342862606, 33.112464398145676, 34.22128289937973, 26.56226947903633, 35.213375464081764, 41.43713369965553, 41.1909981071949, 47.79602408409119, 46.81648604571819, 50.01070484519005, 52.48430371284485, 50.84320217370987, 55.67272022366524, 58.50919961929321, 53.32498960196972, 59.961941465735435, 59.08798076212406, 59.83550705015659, 54.65402148663998, 58.1510042399168, 59.00965176522732, 56.088828295469284, 58.517794758081436, 58.252143412828445, 55.89506149291992, 60.607583820819855, 58.8872679322958, 58.71166415512562, 61.56505644321442, 58.779045939445496, 83.74076530337334, 84.9533486366272, 59.373322650790215, 64.00508791208267, 51.521230190992355, 60.43418012559414, 58.879744336009026, 66.49842292070389, 65.8420005440712, 67.26529777050018, 61.810587868094444, 64.01662409305573, 63.88712704181671, 68.01867574453354, 65.29311239719391, 65.89898988604546, 56.29967898130417, 66.49079293012619, 41.49820402264595, 1.1751928646117449, 0.2773479191819206, 33.1558770686388, 68.21745067834854, 64.47522908449173, 57.12279461324215, 29.6736204251647, 13.237181548029184, 13.143344633281231, 25.37865199148655, 45.74881553649902, 75.27614951133728, 61.775781735777855, 54.96906258165836, 48.863660395145416, 58.903531059622765, 55.7275664806366, 75.55084437131882, 70.38349404931068, 3.6710181646049023, 0.4681840696139261, 0.21524081588722765, 0.21640221762936562, 0.18492996110580862, 0.256335343583487, 0.3111743868794292], [0.060741065462934785, 0.05711615645850543, 0.07293891190784052, 0.10689805334550329, 0.05133413586008828, 0.03999168511654716, 0.13215526094427332, 0.0344432703423081, 0.1658624506671913, 0.14435248769586906, 0.32206118863541633, 11.224007774144411, 68.90838280320168, 50.317059606313705, 47.736777663230896, 29.739241003990173, 43.4386382997036, 30.247192047536373, 19.977086037397385, 28.417951203882694, 10.741370022296906, 3.0666596442461014, 27.654708959162235, 68.95045414566994, 63.16974073648453, 46.028180345892906, 58.614529967308044, 36.23473025858402, 0.5012201203498989, 0.32397218921687454, 0.15462171868421137, 8.595107439905405, 40.008011385798454, 51.602025255560875, 52.14177869260311, 55.13139367103577, 54.95300084352493, 58.046031072735786, 55.23344859480858, 60.38765162229538, 61.10677823424339, 57.48691767454147, 48.697472512722015, 49.92917262017727, 54.2949103564024, 67.05186322331429, 88.09422969818115, 57.71423287689686, 57.900156900286674, 55.27228631079197, 37.009508684277534, 29.809772819280624, 56.9864047318697, 69.01046812534332, 54.80425402522087, 50.24796411395073, 50.83477422595024, 49.369569048285484, 55.76156325638294, 52.83268041908741, 49.09456640481949, 48.77190291881561, 46.921242624521255, 45.84495037794113, 49.38276194036007, 43.627222180366516, 50.81160306930542, 48.21255773305893, 33.281559124588966, 35.978643000125885, 26.72271776944399, 21.402469351887703, 28.249639235436916, 39.992603212594986, 32.40766301751137, 20.83599004894495, 22.940336130559444, 30.506036058068275, 33.05796392261982, 21.55511476099491, 28.26761607080698, 25.66545680165291, 32.53114879131317, 35.82531362771988, 33.449160531163216, 40.65429590642452, 41.85478448867798, 39.92105685174465, 45.44308394193649, 46.01953960955143, 42.32355773448944, 44.222897216677666, 40.374163538217545, 40.72421595454216, 34.89472076296806, 28.0477237701416, 22.270804457366467, 20.44439446181059, 17.201488874852657, 21.40385627746582, 22.427456751465797, 13.183940704911947, 7.615698119625449, 11.734054405242205, 18.248849473893642, 15.613732673227787, 15.984131097793579, 19.651270620524883, 29.89889893680811, 31.875220388174057, 38.83843794465065, 39.79475922882557, 42.75419242680073, 42.86337196826935, 46.55605562031269, 49.87047716975212, 48.36627088487148, 50.34207746386528, 52.73347154259682, 45.98382152616978, 51.29979707300663, 55.44272616505623, 57.401167675852776, 55.744714960455894, 53.866407349705696, 58.27693708240986, 58.559459522366524, 57.13746562600136, 51.88831329345703, 48.860324174165726, 67.6172348856926, 37.13452957570553, 37.72192485630512, 59.46742080152035, 56.13761007785797, 51.73408716917038, 42.464632764458656, 50.851774513721466, 53.52072849869728, 62.19904862344265, 60.343938767910004, 56.76063984632492, 58.147782012820244, 60.949288085103035, 60.88753379881382, 59.073499739170074, 59.51301835477352, 60.24422451853752, 47.4941872805357, 1.0527538158930838, 0.5231109238229692, 1.0703228856436908, 28.949612975120544, 53.104149252176285, 52.907699793577194, 47.91175827383995, 44.09582823514938, 13.809246551245451, 3.52992651052773, 16.00834719836712, 23.799234442412853, 45.53095422685146, 27.740230970084667, 36.34695343673229, 28.947048112750053, 43.17372791469097, 38.764094933867455, 66.27529889345169, 40.81448391079903, 0.8549086446873844, 0.12396677455399185, 0.04461147647816688, 0.04410997389641125, 0.10616898973239586, 0.04881647779257037, 0.09178516585961916, 0.01880361571238609, 0.02012445118452888, 0.0726558048336301, 0.06534044034196995, 0.03551002599124331, 0.1144550388562493, 0.17968612373806536, 0.03561936289770529, 0.1756184420082718, 0.24325175501871854, 0.4351784469326958, 12.08900760859251, 81.24275654554367, 59.24815356731415, 54.75471988320351, 34.4667649269104, 52.857519686222076, 32.48247340321541, 30.15907857567072, 28.22100207209587, 17.579276002943516, 4.375392543151975, 28.201170936226845, 69.15151655673981, 65.04695400595665, 50.6437698751688, 66.6722483932972, 45.54847128689289, 1.0178354708477855, 0.08306504940264858, 0.24796470446744934, 7.991597224026918, 44.33043144643307, 53.198038414120674, 55.72321571409702, 60.34640483558178, 62.22872123122215, 65.66402569413185, 57.79526732861996, 63.05698178708553, 63.80543142557144, 59.179198667407036, 49.795465394854546, 53.17219980061054, 56.63701727986336, 69.39888328313828, 90.19667208194733, 58.947479501366615, 57.984880954027176, 55.4421865940094, 43.09486694633961, 35.480227544903755, 58.8960986584425, 79.51903223991394, 60.516875088214874, 52.00574979186058, 54.237848818302155, 50.69137752056122, 56.52995802462101, 53.12417417764664, 50.264896005392075, 50.0127187371254, 49.85336288809776, 46.83334954082966, 47.48063340783119, 41.12192541360855, 50.59971123933792, 62.238634899258614, 38.24999772012234, 39.85796503722668, 30.545698329806328, 28.916030377149582, 29.586114920675755, 45.56111320853233, 40.06159611046314, 25.374842695891857, 29.1297822073102, 36.95617854595184, 34.443187192082405, 27.885105796158314, 33.75839553773403, 28.175754100084305, 31.169679947197437, 34.04496096074581, 35.71016080677509, 37.24191561341286, 39.12050440907478, 37.71364890038967, 38.19649659097195, 37.704605385661125, 37.07667388021946, 37.78875567018986, 37.026512771844864, 39.54637035727501, 36.837773099541664, 28.857000544667244, 21.95767465978861, 19.401162341237068, 17.693024799227715, 20.861898958683014, 26.149178445339203, 15.889785960316658, 10.454398971050978, 16.706696525216103, 21.579146571457386, 18.018327243626118, 22.402777075767517, 31.481016241014004, 35.96606567502022, 44.66318339109421, 46.64545342326164, 45.98832808434963, 47.06184647977352, 49.50697347521782, 48.395772501826286, 52.56771683692932, 50.47522231936455, 52.11991086602211, 52.56494678556919, 49.26336854696274, 55.2210308611393, 59.559626653790474, 56.92352570593357, 56.487069725990295, 57.26233072578907, 60.40894567966461, 60.44414699077606, 57.44159750640392, 50.649184584617615, 53.13699848949909, 65.50450265407562, 41.851197481155396, 45.75635053217411, 63.73698949813843, 60.40378175675869, 58.04460234940052, 47.96715170145035, 53.93364854156971, 56.11795753240585, 65.84247931838036, 64.5187671482563, 62.77453154325485, 60.692391470074654, 64.68418747186661, 62.1123942732811, 64.29954931139946, 59.293599128723145, 62.50884599983692, 35.371089801192284, 0.4862852889345959, 0.20473574521020055, 1.562701533548534, 36.654641926288605, 55.76176464557648, 60.15043795108795, 56.78109034895897, 52.03702971339226, 18.974768221378326, 6.527064610272646, 20.51170215010643, 26.532602570950985, 43.81302461028099, 29.86621119081974, 42.721947357058525, 35.30930131673813, 37.009972259402275, 43.88485215604305, 73.57685789465904, 49.407829195261, 0.7613578427117318, 0.12125754219596274, 0.07800881954608485, 0.08595194449299015, 0.1633394305827096, 0.1400682027451694, 0.04661662220314611, 0.13260572974104434, 0.14340448309667408, 0.12404484848957509, 0.2409238604013808, 0.19706468418007717, 0.16612321167485788, 0.3270001517375931, 0.12508510204497725, 0.24425445590168238, 0.469819555291906, 0.6355807324871421, 18.17538421601057, 93.25923934578896, 66.22830301523209, 68.95502150058746, 40.86507439613342, 67.9096519947052, 40.012506544589996, 29.97310895472765, 36.66891776025295, 19.391290470957756, 7.868906082585454, 34.857710748910904, 78.10811474919319, 73.79504978656769, 58.019531294703484, 71.24156400561333, 47.59224861860275, 0.7094870042055845, 0.4170414264081046, 0.1870808980311267, 17.09429282695055, 53.641178235411644, 58.00461709499359, 59.950329288840294, 62.911016419529915, 65.1372067630291, 65.61060056090355, 61.80742643773556, 64.73819017410278, 66.23343273997307, 60.7350517809391, 51.3681174069643, 54.79271024465561, 58.13278801739216, 73.03791001439095, 80.7584573328495, 54.95680823922157, 58.87179896235466, 50.99471524357796, 43.677257895469666, 45.03066927194595, 63.689146265387535, 62.868055924773216, 61.47825010120869, 59.56617370247841, 58.95250283181667, 55.68244010210037, 64.21438068151474, 54.60992485284805, 54.38087694346905, 54.675133153796196, 55.79510785639286, 50.24691917002201, 50.98987430334091, 41.64129674434662, 54.62191320955753, 65.30078798532486, 42.06637613475323, 43.399678990244865, 36.19265891611576, 34.7396244853735, 35.66270895302296, 55.90846337378025, 44.55359727144241, 30.15844400972128, 36.25026002526283, 45.196910351514816, 42.78298728168011, 34.969531148672104, 38.3890550583601, 36.07553020119667, 40.119094625115395, 41.581643745303154, 40.9230250865221, 43.54005105793476, 44.97549623250961, 41.726282984018326, 42.135885804891586, 45.88512942194939, 42.337050810456276, 44.51137773692608, 40.01144640147686, 41.013479232788086, 40.103960037231445, 36.73745468258858, 33.1694233417511, 32.778040543198586, 27.677296847105026, 26.786202862858772, 29.981926381587982, 16.634642891585827, 10.002606064081192, 23.148025386035442, 30.265303775668144, 25.06496362388134, 33.027337566018105, 40.97575105726719, 46.813408210873604, 52.079500034451485, 52.90835715830326, 50.62755234539509, 51.514584347605705, 52.22537040710449, 52.72624433040619, 54.835720136761665, 54.18107606470585, 58.508823439478874, 56.019489616155624, 52.536436915397644, 62.03537620604038, 62.12605454027653, 61.215178817510605, 62.46737502515316, 60.69579988718033, 62.37187094986439, 63.95740047097206, 60.40706478059292, 55.49154594540596, 54.28753115236759, 68.42222169041634, 57.47426435351372, 47.10125036537647, 62.89709776639938, 64.02122184634209, 59.30679202079773, 51.512646451592445, 57.54844397306442, 59.53311547636986, 68.0942764878273, 68.7176862359047, 63.851302564144135, 63.543994054198265, 67.56773114204407, 71.27109602093697, 66.09834238886833, 66.7930819094181, 63.34631726145744, 57.50706039369106, 2.2730890894308686, 0.5847770429681987, 1.4670044998638332, 39.55706678330898, 65.77197790145874, 63.34966488182545, 61.35002218186855, 55.797114148736, 20.713019147515297, 12.526096254587173, 25.55174980312586, 31.336756981909275, 55.969461500644684, 37.54236929118633, 48.78476522862911, 42.629000544548035, 55.914402455091476, 54.82892990112305, 79.57907661795616, 64.46987137198448, 1.8479909375309944, 0.18755705998046324, 0.22125019342638552, 0.10731635746196844, 0.34173044725321233, 0.32841955369804054, 0.20845924853347242], [0.022802427993156016, 0.3078465966973454, 0.016967041410680395, 0.0556310447427677, 0.179094216437079, 0.12339420019998215, 0.07988701720023528, 0.07230041257571429, 0.17785526026273146, 0.15994799381587654, 0.42504908109549433, 6.716231759637594, 65.87099298834801, 56.90564766526222, 45.56073322892189, 29.80150256305933, 43.277283757925034, 36.26912221312523, 26.901192292571068, 33.76302748918533, 19.840082488954067, 2.1882375050336123, 24.820765927433968, 62.141968086361885, 58.99671345949173, 57.182747796177864, 44.487431421875954, 44.502558410167694, 9.94572976604104, 0.20972082536900416, 0.21248134755296633, 0.8039167465176433, 27.56026692688465, 49.68633525073528, 52.496124878525734, 56.65024437010288, 58.044161573052406, 56.06533035635948, 54.055781587958336, 56.24546729028225, 59.405024349689484, 55.79573482275009, 51.415333673357964, 45.16247659921646, 54.358853325247765, 58.74006003141403, 63.47243629395962, 84.38391879200935, 51.95170149207115, 51.0236506909132, 54.41586546599865, 43.623346388339996, 29.941000677645206, 47.45351426303387, 68.74889776110649, 55.01189388334751, 43.78483012318611, 44.284586906433105, 44.68773767352104, 44.68957297503948, 48.5812633484602, 42.259721159935, 50.04160478711128, 48.370929434895515, 48.76565985381603, 36.791571378707886, 58.900179639458656, 60.038826540112495, 26.843984462320805, 29.721077978610992, 23.302798680961132, 26.611708626151085, 37.45441161096096, 33.4362830221653, 15.061026681214571, 6.407226165756583, 8.629316054284573, 23.447629809379578, 32.141358107328415, 26.525510251522064, 22.621006965637207, 29.08627074211836, 36.53279006481171, 34.6622758358717, 42.5252965092659, 43.64114463329315, 45.88772088289261, 48.1578254699707, 44.313605949282646, 36.454582661390305, 33.40626463294029, 39.28703427314758, 42.83348277211189, 43.08814890682697, 36.866765543818474, 30.35545203834772, 22.80801773071289, 19.973759315907955, 17.019908018410206, 19.454319588840008, 15.18346656113863, 5.342089645564556, 1.637696090620011, 3.830044618807733, 11.689017321914434, 14.376149531453848, 11.694968752563, 11.829351391643286, 19.9911205843091, 28.74976459890604, 31.87794104218483, 36.41805522143841, 35.56938216090202, 41.89777538180351, 40.543421655893326, 40.620477721095085, 39.66577894985676, 43.92067663371563, 32.03224316239357, 32.07384333014488, 52.6056881994009, 52.75039583444595, 53.75546470284462, 58.27056102454662, 56.605311781167984, 57.902231588959694, 58.9959155023098, 55.49777001142502, 47.07774482667446, 58.115384951233864, 44.3266012519598, 38.528697565197945, 55.881237834692, 59.06766325235367, 60.17778128385544, 55.096139162778854, 48.55368822813034, 46.77526205778122, 54.05554220080376, 58.05648431181908, 59.20203164219856, 61.58280149102211, 56.613063365221024, 60.329130962491035, 62.44848623871803, 63.67818005383015, 60.98089098930359, 60.09364999830723, 3.6296842200681567, 0.09998353023547679, 0.3741903539048508, 5.070474995300174, 53.549819737672806, 53.81175868213177, 59.66290891170502, 51.86399459838867, 53.726673647761345, 13.58926210552454, 3.871741918846965, 16.475005857646465, 32.72014304995537, 50.72601646184921, 37.627317532896996, 37.59089648723602, 29.311676546931267, 33.90333116054535, 41.79859310388565, 70.0203475356102, 36.482366770505905, 0.546330587239936, 0.2848422451643273, 0.10484888713108376, 0.1281119216582738, 0.026946827383653726, 0.07104227188392542, 0.03479122999124229, 0.10652701661456376, 0.04256717504176777, 0.0344109349680366, 0.11805173140601255, 0.1444096033810638, 0.030823608321952634, 0.037027502767159604, 0.08331620701937936, 0.25973625015467405, 0.48550490580964833, 0.5530993302818388, 8.198750708252192, 78.23019459843636, 61.0711095482111, 47.18660518527031, 21.05984553694725, 53.58541242778301, 36.1651673913002, 13.504987377673388, 24.295364320278168, 23.838830217719078, 5.688921734690666, 22.16555580496788, 68.02115321159363, 63.899134397506714, 65.93831017613411, 49.13257956504822, 50.9010274708271, 13.109767735004425, 0.13041502854321152, 0.13746471900958568, 0.14082008739933372, 30.54605171084404, 58.65373246371746, 55.519592240452766, 60.15791594982147, 61.06298178434372, 60.75258404016495, 57.796585857868195, 59.54142563045025, 64.29577991366386, 58.80372941493988, 50.47754019498825, 47.422967702150345, 57.580259665846825, 61.76899150013924, 67.36895620822906, 87.8166925907135, 52.01101630926132, 50.72792015969753, 54.39633451402187, 48.461919352412224, 30.40500707924366, 49.74282681941986, 79.86117348074913, 63.47948871552944, 43.75790096819401, 52.39454112946987, 50.52588500082493, 48.94270375370979, 50.44373720884323, 47.07039222121239, 48.985067680478096, 49.334154948592186, 47.011214196681976, 43.120264783501625, 52.094790413975716, 69.10625338554382, 34.3789554387331, 35.34231394529343, 30.517743229866028, 29.766588136553764, 43.651506677269936, 39.852903708815575, 20.637752786278725, 12.513745967298746, 11.869158055633307, 29.323816895484924, 36.88634589314461, 29.463569596409798, 30.58471843600273, 31.105319000780582, 36.23713552951813, 38.405625969171524, 38.55561152100563, 38.38599622249603, 41.03706456720829, 41.74457520246506, 41.04670464992523, 43.39476205408573, 39.97499495744705, 38.28165762126446, 35.61129771173, 38.45400497317314, 35.1600681245327, 32.72923596203327, 22.46294304728508, 21.31155163049698, 17.088587433099747, 21.242786720395088, 18.5816603153944, 8.125365246087313, 2.334593776613474, 6.61699628457427, 16.961159370839596, 19.511901699006557, 14.513106532394886, 19.22111090272665, 26.577791646122932, 32.93857432901859, 40.8993561565876, 40.58145001530647, 38.87282229959965, 46.082863211631775, 47.20384865999222, 43.4406103938818, 41.08817182481289, 46.72514274716377, 32.85033166408539, 29.968317411839962, 55.41284836828709, 57.46509924530983, 55.15516139566898, 58.456652238965034, 60.40338657796383, 56.52390494942665, 61.29731900990009, 57.235572561621666, 50.36342091858387, 58.11244010925293, 47.07892656326294, 42.67341636121273, 56.12063258886337, 58.21709789335728, 65.36004960536957, 58.840006068348885, 50.88133692741394, 48.888792246580124, 56.70845724642277, 59.62429158389568, 61.90881259739399, 65.0844655930996, 61.10425516963005, 61.02081164717674, 63.49063731729984, 63.53403098881245, 61.94934502243996, 55.771891102194786, 1.7409059149213135, 0.19810602127108723, 0.0787259716889821, 7.054757494479418, 62.17500351369381, 56.136876717209816, 65.63320934772491, 56.382358744740486, 63.476920053362846, 15.775047317147255, 6.38849507085979, 22.516594268381596, 33.62332798540592, 47.987773194909096, 37.09777794778347, 43.90413612127304, 34.02030408382416, 35.65593011677265, 48.53280834853649, 76.70131623744965, 36.807443127036095, 0.4520200635306537, 0.279239623923786, 0.1406127164955251, 0.1582391542615369, 0.061835900269215927, 0.07982251714565791, 0.03668699799163733, 0.16408704046625644, 0.26423295261338353, 0.11422073541325517, 0.17756830144207925, 0.34481629729270935, 0.1741626302828081, 0.11623169586528093, 0.2706475427839905, 0.3117836604360491, 0.6969739787746221, 0.7205142499879003, 10.84988459944725, 89.58382576704025, 71.22441932559013, 61.4948970079422, 36.42774470150471, 67.91066274046898, 50.59576325118542, 41.84650853276253, 45.490756183862686, 27.659116722643375, 8.71926387771964, 32.37391322851181, 75.30333325266838, 69.13777649402618, 65.51008835434914, 56.3551902025938, 59.498066157102585, 12.744010761380196, 0.3107857092982158, 0.17024952307110652, 2.454268829897046, 41.994943767786026, 64.06757175922394, 61.457761600613594, 62.34400324523449, 67.39304691553116, 61.811154037714005, 59.81312245130539, 62.34945975244045, 65.6202444434166, 61.410290747880936, 56.08025215566158, 49.55774635076523, 60.48658311367035, 65.23790135979652, 78.87558236718178, 78.60206544399261, 51.10201768577099, 56.971566528081894, 56.038192212581635, 47.68934480845928, 40.98264768719673, 59.191494807600975, 64.04912754893303, 54.60963226854801, 48.83060596883297, 54.81831707060337, 54.31179665029049, 51.62208817899227, 52.36448474228382, 47.99449123442173, 50.93582600355148, 51.06197163462639, 52.565953731536865, 45.49087017774582, 55.385227650403976, 70.70038184523582, 40.86632452905178, 41.20500795543194, 40.25130853056908, 38.86111132800579, 53.17647457122803, 48.15251715481281, 25.036026276648045, 15.494886450469494, 14.281298071146011, 36.246695816516876, 44.73082736134529, 37.73474916815758, 37.82962627708912, 38.77220369875431, 44.18130844831467, 44.972213208675385, 47.664444744586945, 45.192605182528496, 47.13512174785137, 51.206109300255775, 52.14021697640419, 50.8099539577961, 46.495980843901634, 45.539617761969566, 43.70135240256786, 41.38071812689304, 39.56675626337528, 39.72115337848663, 31.352125257253647, 32.22789466381073, 23.89534268528223, 25.964546352624893, 19.250525124371052, 7.694559087976813, 2.3160163359716535, 6.153245894238353, 21.073862984776497, 26.29470493644476, 23.23313321918249, 28.76898966729641, 33.50477434694767, 42.120937407016754, 46.51307612657547, 44.07505854964256, 41.426699459552765, 48.86520691215992, 47.03862592577934, 44.461911991238594, 43.30912604928017, 48.161378279328346, 40.98988629877567, 37.37825609743595, 58.482456654310226, 60.653401762247086, 57.91795514523983, 62.24073238670826, 61.72169163823128, 61.88591502606869, 64.29174453020096, 59.68953788280487, 51.73724479973316, 56.63224473595619, 53.84565286338329, 44.74605694413185, 59.174996092915535, 62.517201751470566, 65.09664013981819, 61.271525993943214, 52.44509741663933, 52.72886618971825, 61.8170665204525, 66.63885578513145, 63.433450385928154, 70.07555857300758, 64.91559505462646, 68.13496470451355, 65.61868652701378, 68.29043716192245, 61.28710895776749, 65.30197352170944, 6.818969696760178, 0.41298956726677716, 0.5828864069189876, 6.004510000348091, 67.51087859272957, 65.34266173839569, 70.12029737234116, 61.70054577291012, 63.93748193979263, 22.074286602437496, 10.709060356020927, 23.77182461321354, 47.027617916464806, 60.814881697297096, 50.21936684846878, 53.08597482740879, 41.71825401484966, 47.380280792713165, 56.44538216292858, 88.69885325431824, 52.28638373315334, 0.8140593522693962, 0.386209316784516, 0.26883527752943337, 0.27138695935718715, 0.16112220502691343, 0.21649596572387964, 0.11819431281764992], [0.06755923925084062, 0.1801920309662819, 0.1181516022188589, 0.10792056214995682, 0.18419081170577556, 0.13114622212015092, 0.09124738338869065, 0.006056408828953863, 0.12148887704825029, 0.04755240734084509, 0.08838209221721627, 2.224019472487271, 65.72582557797432, 44.18372891843319, 60.52380971610546, 47.4003741145134, 49.23157185316086, 35.34705989062786, 87.19425559043884, 89.63101163506508, 31.67259056121111, 8.678778000175953, 2.856790255755186, 49.7044412791729, 60.96284195780754, 58.3826170116663, 58.525356352329254, 59.88333508372307, 21.89587477594614, 0.10696379278670065, 0.10064974136184901, 0.12211982131702825, 13.035912998020649, 54.09660279750824, 48.07250864803791, 54.93703030049801, 54.16570208966732, 56.20301216840744, 53.93644519150257, 60.553098544478416, 56.05309881269932, 56.55607022345066, 46.298957616090775, 49.86365273594856, 50.734987780451775, 63.591449707746506, 40.23534178733826, 45.603811517357826, 79.48771432042122, 60.79160034656525, 53.847412168979645, 52.782238125801086, 47.85370118916035, 28.715125657618046, 33.841379284858704, 58.15666973590851, 61.50837868452072, 47.64353446662426, 49.29721713066101, 47.287782356143, 38.08363504707813, 41.77337005734444, 42.926216796040535, 48.0141893774271, 46.952773332595825, 41.48727960884571, 39.08495731651783, 31.28184612840414, 29.320406578481197, 24.60798304527998, 28.054061830043793, 35.415194034576416, 35.17751678824425, 16.32193487137556, 3.3431928930804133, 2.9834186984226108, 2.4351071706041694, 14.742721561342478, 30.43223261833191, 29.9868718162179, 23.40348567813635, 30.472504757344723, 33.507445603609085, 42.722608521580696, 46.126785054802895, 46.82670749723911, 42.8345201164484, 36.534530371427536, 24.01227381080389, 13.959039263427258, 14.883874487131834, 26.038490384817123, 31.413212679326534, 42.74243965744972, 39.84237067401409, 38.1683325022459, 32.05466955900192, 15.497183427214622, 17.219539806246758, 19.05549678951502, 8.592903558164835, 2.2614878369495273, 0.5269991839304566, 1.4166838000528514, 6.102650184184313, 9.369317796081305, 11.34383149445057, 11.468522753566504, 10.495984889566898, 19.46204837411642, 27.482551597058773, 33.42192739248276, 31.985365077853203, 37.51949071884155, 39.578102454543114, 39.77340817451477, 35.28614915907383, 45.89310519397259, 30.57111706584692, 18.712523393332958, 43.43196965754032, 54.32804077863693, 52.587597370147705, 52.75577634572983, 55.1007217168808, 57.09681160748005, 55.817587450146675, 52.651027366518974, 54.620902463793755, 48.287542909383774, 45.07131949067116, 51.64915032684803, 54.43768389523029, 60.817659348249435, 60.59533327817917, 55.02728685736656, 50.177428498864174, 42.76753731071949, 46.453852504491806, 51.13061875104904, 57.2747028619051, 58.1882194429636, 60.98627530038357, 58.23398418724537, 64.23717945814133, 57.654762268066406, 65.9629936516285, 32.22110442817211, 0.11553919044672512, 0.04547292810457293, 0.06291084922850132, 17.910405434668064, 51.88915304839611, 53.71270939707756, 56.684925109148026, 54.60977666079998, 58.73178407549858, 6.104466961696744, 7.370268814265728, 24.430414773523808, 23.444684967398643, 47.662172466516495, 36.85798041522503, 33.274252116680145, 24.312495701014996, 26.36017732322216, 49.75198432803154, 65.6744447350502, 22.029606699943542, 0.35588629078119993, 0.33532802830450237, 0.09926557657308877, 0.1201409513305407, 0.053870351330260746, 0.06128316352260299, 0.03786407760344446, 0.07571526410174556, 0.02080116555589484, 0.07441645371727645, 0.09117605557548814, 0.10715393102145754, 0.09709812686196528, 0.02393230144662084, 0.028617216266866308, 0.035361180853215046, 0.11347947089234367, 0.0896462591481395, 2.5477464264258742, 72.18212753534317, 51.36413902044296, 59.69303369522095, 38.79235781729221, 61.33340947329998, 34.55634132027626, 82.30909332633018, 86.60297691822052, 32.25008927285671, 10.824747998267412, 4.615014810115099, 47.6056694984436, 69.1038367152214, 65.60085028409958, 64.16508212685585, 64.65460985898972, 26.265822686254978, 0.09019587145303376, 0.2565705747110769, 0.1632049385807477, 14.899425152689219, 58.92554707825184, 53.45211938023567, 58.17723423242569, 56.45507924258709, 58.215243592858315, 60.058866664767265, 66.41538217663765, 59.446263536810875, 58.606417402625084, 49.38016667962074, 53.90725515782833, 51.43130801618099, 65.3984123468399, 41.99657388031483, 53.83923500776291, 80.34217447042465, 59.79483023285866, 52.813974022865295, 48.70494291186333, 50.033898800611496, 31.18312742561102, 35.85062026977539, 67.20573976635933, 68.06870386004448, 45.19154503941536, 49.54525262117386, 49.3586940318346, 42.0153296738863, 46.88745863735676, 49.24620106816292, 52.4323832988739, 50.02599522471428, 46.62851393222809, 41.54054135084152, 42.928378880023956, 34.05109383165836, 35.453404784202576, 28.781247809529305, 40.44310703873634, 45.43467499315739, 27.753735445439816, 10.173102915287018, 7.630281262099743, 4.041527258232236, 21.060278713703156, 32.71844454109669, 30.335020534694195, 28.007233142852783, 33.68523806333542, 35.94827122986317, 39.87123392522335, 43.84029194712639, 47.57742181420326, 45.485276877880096, 42.5803479552269, 37.90898881852627, 29.294265881180763, 28.372226357460022, 36.79972194135189, 45.34732908010483, 41.742249727249146, 38.92093151807785, 34.343054965138435, 30.51306188106537, 24.42452698945999, 18.436126224696636, 20.553072430193424, 14.818736482411623, 2.994793625548482, 1.7627516551874578, 1.9092846172861755, 7.9374852776527405, 15.653174556791782, 16.11395303159952, 15.012697074562311, 19.85291440039873, 24.681296311318874, 34.41962465643883, 38.96768040955067, 37.45424062013626, 41.936195120215416, 44.08976376056671, 46.55129447579384, 39.20370854437351, 43.89544978737831, 34.13984186947346, 16.020012572407722, 41.67468935251236, 58.73137749731541, 54.63758356869221, 55.71023181080818, 58.462929502129555, 55.14126554131508, 52.47215196490288, 52.440146282315254, 55.171078741550446, 47.244654670357704, 45.01192107796669, 52.84323625266552, 54.885379672050476, 60.378858894109726, 64.04535815119743, 58.65386925637722, 53.56215387582779, 46.61085247993469, 48.818940594792366, 55.26886649429798, 59.31265130639076, 60.765100568532944, 62.3614215105772, 63.31649646162987, 65.21985232830048, 59.55672360956669, 66.4892578125, 31.954427137970924, 0.11406107718357816, 0.1275854866253212, 0.10096087935380638, 23.87638170272112, 51.90767705440521, 56.69542774558067, 60.50074875354767, 63.350740224123, 67.88105472922325, 5.965117989107966, 13.571603503078222, 26.627717167139053, 23.89277782291174, 43.50296884775162, 34.85294960439205, 42.99531228840351, 29.29602138698101, 26.5020864084363, 55.80408677458763, 73.08381155133247, 23.700948916375637, 0.4066841915482655, 0.42579027882311493, 0.03459022300376091, 0.1829273349721916, 0.08688595218700357, 0.15389123756904155, 0.01732716671540402, 0.18640512804267928, 0.27021967980545014, 0.1972117184777744, 0.18527090374846011, 0.2107646263903007, 0.23563571681734174, 0.2182644887943752, 0.09514246383332647, 0.37141902605071664, 0.38760197174269706, 0.4395250871311873, 5.102999350056052, 90.87424412369728, 56.228869780898094, 81.2052221596241, 60.38408361375332, 75.33194571733475, 47.36497141420841, 102.8384417295456, 100.0166143476963, 40.86837641894817, 14.990434069186449, 8.924540262669325, 57.14418366551399, 74.36221495270729, 70.4830715060234, 68.8667294383049, 74.77565556764603, 28.921830765902996, 0.19457066722679883, 0.3758657968137413, 0.3594084642827511, 22.557590268552303, 67.92399242520332, 57.431900426745415, 62.92187623679638, 59.719142094254494, 61.35629564523697, 59.58478130400181, 68.59491482377052, 63.66978630423546, 60.16733564436436, 53.29044185578823, 56.67465806007385, 55.67828692495823, 66.61289557814598, 44.477829337120056, 64.818464666605, 69.30154770612717, 55.7832220941782, 51.85814291238785, 52.33615346252918, 49.181163758039474, 37.39688649773598, 47.584823817014694, 57.40449629724026, 55.93597389757633, 49.332198053598404, 52.63289473950863, 50.69589547812939, 42.724212035536766, 49.49472673237324, 51.53493605554104, 58.54239843785763, 52.665812373161316, 52.3708987981081, 44.839573726058006, 46.83116465806961, 42.908885926008224, 44.237131252884865, 37.88226865231991, 50.85223808884621, 55.326957777142525, 32.42399454116821, 13.245233315974474, 12.990734372287989, 7.815919825807214, 28.246367610991, 40.247542932629585, 37.56681717932224, 38.00989620387554, 40.458997786045074, 38.01265485584736, 46.19964614510536, 51.56469225883484, 60.41768901050091, 52.9762177169323, 50.51676549017429, 40.2403499186039, 27.30769257992506, 28.70615243911743, 43.25000502169132, 50.079253166913986, 49.36071552336216, 44.38240505754948, 42.35400170087814, 39.25136178731918, 31.89451575279236, 25.458176024258137, 24.06029373407364, 17.360464744269848, 2.913167830556631, 3.066020328551531, 1.362056031357497, 9.387465622276068, 21.37783907353878, 23.44598449766636, 25.12558177113533, 29.737046621739864, 31.862637363374233, 38.68434481322765, 42.23043613135815, 39.499511271715164, 44.682098776102066, 47.26838819682598, 47.2944699972868, 40.04463002085686, 45.52487455308437, 42.324864864349365, 27.028572857379913, 48.18530559539795, 59.99051593244076, 59.48260858654976, 61.840952038764954, 62.579062432050705, 61.09106607735157, 55.504377856850624, 51.84520460665226, 57.87722893059254, 50.31349919736385, 44.02982957661152, 55.41912943124771, 57.798884734511375, 65.38298517465591, 64.2818270623684, 63.24910327792168, 58.496424704790115, 50.693277418613434, 53.05258981883526, 56.77460789680481, 62.967185005545616, 64.47737976908684, 68.1684485077858, 67.47226506471634, 72.57559642195702, 61.84689112007618, 68.38271901011467, 37.426794692873955, 0.16743731772294268, 0.19264339876826853, 0.25117245968431234, 24.158812947571278, 66.3830915093422, 62.57484845817089, 68.86369720101357, 66.71665281057358, 72.05237969756126, 14.063617251813412, 13.654364962130785, 32.02968589961529, 32.08875373005867, 59.543823301792145, 47.95083537697792, 47.63597287237644, 36.145963221788406, 37.85261124372482, 65.40771424770355, 82.227473706007, 36.57945916056633, 0.7879682304337621, 0.8052555215544999, 0.27802532189525664, 0.31417934282217175, 0.21360328188166022, 0.3416742221452296, 0.18661065842024982], [0.031177590499282815, 0.20413346268469468, 0.12819590308936313, 0.1219592205598019, 0.2862712653586641, 0.10466530948178843, 0.01894298733532196, 0.04218170353851747, 0.31104635156225413, 0.10326765986974351, 0.14290384511696175, 0.453717919299379, 50.112790167331696, 54.19337220489979, 43.86192038655281, 27.412561252713203, 41.155903190374374, 37.48946093022823, 21.473884619772434, 39.11532148718834, 18.650058545172215, 16.05134569108486, 12.980094943195581, 31.9935954362154, 62.34961934387684, 61.47785112261772, 49.58026014268398, 61.29547230899334, 29.639454558491707, 0.13620021811220795, 0.07780681436997838, 0.2513743832241744, 4.092055046930909, 48.69744971394539, 51.63901247084141, 55.049078688025475, 54.69274900853634, 57.06673622131348, 58.24172057211399, 58.49827900528908, 57.336920723319054, 47.74034567177296, 46.03994071483612, 48.554987758398056, 51.30681909620762, 56.88649669289589, 61.75535023212433, 39.54945959150791, 47.21866026520729, 73.64170521497726, 63.68833310902119, 58.138658702373505, 52.23144628107548, 43.958507403731346, 26.669558621942997, 28.457603976130486, 65.23809894919395, 79.05249327421188, 47.900898456573486, 41.42054758965969, 45.33165492117405, 51.759143024683, 47.707595229148865, 48.25859226286411, 47.154470309615135, 45.68752862513065, 38.611498922109604, 31.36032521724701, 32.61241503059864, 28.312700651586056, 38.552415892481804, 40.11139243841171, 28.3293304592371, 6.380173517391086, 2.26255367975682, 4.84989445656538, 1.7184627754613757, 16.459200605750084, 32.55640983581543, 33.69446016848087, 27.986617349088192, 36.5832095593214, 39.73370410501957, 44.108606949448586, 37.37874247133732, 30.032590962946415, 27.958134077489376, 22.146640419960022, 10.13430604711175, 3.238903689198196, 3.9715734869241714, 8.39395098388195, 18.288289457559586, 28.590152263641357, 32.33877271413803, 43.813301995396614, 37.39019125699997, 21.93393163383007, 15.039575882256031, 20.096677020192146, 12.208065669983625, 1.3294572243466973, 1.1552849016152322, 0.914137550862506, 2.7720662020146847, 6.248239371925592, 12.563462499529123, 12.95302139595151, 11.044787541031837, 13.215948287397623, 23.34705490618944, 29.18339543044567, 35.13448029756546, 39.442898109555244, 42.90597528219223, 44.57080274820328, 39.44841541349888, 38.41588541865349, 62.204223945736885, 20.76629798859358, 24.093773737549782, 46.85560114681721, 51.93104200065136, 51.108427941799164, 53.14307056367397, 49.25015285611153, 51.630288138985634, 45.482985600829124, 49.68091294169426, 45.877282842993736, 47.065897062420845, 49.403535425662994, 55.787899643182755, 59.500828608870506, 60.94046875834465, 55.73816791176796, 51.47585302591324, 45.23613944649696, 49.59925912320614, 47.05589599907398, 48.98723356425762, 52.497413009405136, 56.83345153927803, 58.980055153369904, 61.824609115719795, 59.475153386592865, 61.899590492248535, 16.66557513177395, 0.13999245915329084, 0.034993520894204266, 0.48536164162214845, 16.01550031453371, 47.040609419345856, 56.63175456225872, 55.63462346792221, 54.88800913095474, 23.583597913384438, 1.8964566243812442, 24.46592766791582, 21.91811878234148, 27.070045731961727, 28.077052496373653, 25.456365421414375, 38.28463286161423, 33.39390009641647, 35.69620035588741, 44.551849365234375, 71.96527317166328, 12.645772732794285, 0.17351745162159204, 0.16485051746712998, 0.06043635446985718, 0.13977324357256293, 0.052158261169097386, 0.06126629079517443, 0.18183588807005435, 0.010788118379423395, 0.04786097750184126, 0.35164651984814554, 0.025238750386051834, 0.11515371152199805, 0.03070469214435434, 0.0067708855294768, 0.04418935401190538, 0.2143693415564485, 0.1128486379457172, 0.05574598486418836, 0.5205310403835028, 60.82394801080227, 63.579829931259155, 43.610423281788826, 24.87805165350437, 57.658980041742325, 33.78749057650566, 31.072724349796772, 42.65763960778713, 21.744019724428654, 15.577701106667519, 19.26133554428816, 40.7178170979023, 63.55124406516552, 68.86137172579765, 56.28441900014877, 68.98812532424927, 35.537399277091026, 0.4853003699099645, 0.2840346994344145, 0.4107415722683072, 4.195818454027176, 55.432622507214546, 55.36201849579811, 56.9788583368063, 58.37212197482586, 62.12321229279041, 61.41116850078106, 62.48770013451576, 61.95171229541302, 50.87140426039696, 48.75463284552097, 51.46389126777649, 52.623630836606026, 57.25620165467262, 62.23552666604519, 41.542087867856026, 51.99531555175781, 74.2913031578064, 68.29252704977989, 60.885557904839516, 50.574271604418755, 46.78775958716869, 35.20232565701008, 33.161272779107094, 69.90446895360947, 76.56515434384346, 45.52691124379635, 40.94623804092407, 46.574237644672394, 52.63026148080826, 52.56549395620823, 53.714890480041504, 52.95644737780094, 47.94200085103512, 44.77925956249237, 41.10288463532925, 38.9228580147028, 34.02625076472759, 41.07208348810673, 51.51059076189995, 38.44637878239155, 15.195692405104637, 2.9674576548859477, 5.770139526575804, 4.829030726104975, 20.524680353701115, 34.622408375144005, 36.04388169944286, 30.70416882634163, 35.68398401141167, 39.957512095570564, 44.7880332916975, 50.4114655405283, 50.81266701221466, 43.41101758182049, 41.71873278915882, 23.345658481121063, 10.272576827555895, 12.989001665264368, 23.301979824900627, 35.88203698396683, 49.21881973743439, 43.17841686308384, 39.364436119794846, 34.079402312636375, 26.20610699057579, 19.969467446208, 24.113851860165596, 16.83771539479494, 2.438877043314278, 1.6425795410759747, 0.9610982809681445, 5.160060413181782, 12.093134187161922, 17.498566433787346, 12.595688570290804, 16.52433291077614, 24.10394199192524, 27.833417169749737, 36.07467144727707, 40.91854512691498, 46.12882934510708, 46.361103281378746, 45.77047437429428, 40.95439240336418, 43.24846990406513, 67.46017411351204, 32.23136767745018, 22.08971757441759, 45.06376929581165, 52.53621272742748, 54.72720555961132, 52.71273225545883, 51.276124343276024, 50.461877435445786, 48.651483580470085, 51.06993220746517, 47.94863909482956, 46.124676167964935, 49.020147398114204, 52.78050921857357, 61.880545914173126, 62.95335754752159, 58.86126972734928, 54.13302384316921, 48.24167177081108, 51.32475033402443, 47.73656867444515, 51.40954278409481, 54.38997745513916, 58.89945387840271, 61.09573222696781, 64.65153962373734, 63.282039910554886, 63.84146109223366, 18.9965695515275, 0.16167164663784206, 0.35334853164386004, 0.8086916652973741, 18.02686158567667, 51.89354941248894, 59.78213131427765, 60.74708193540573, 61.00766435265541, 22.39917676895857, 3.4051395440474153, 27.198003865778446, 26.61458697170019, 30.97236603498459, 32.15533755719662, 28.98337796330452, 47.77321010828018, 35.298905074596405, 35.39903350174427, 47.421535179018974, 77.58456364274025, 14.303667470812798, 0.03664012023364194, 0.18670044344617054, 0.09331209017545916, 0.14742466737516224, 0.02668223689397564, 0.1350562271545641, 0.17400740267476067, 0.19872874254360795, 0.32149590959306806, 0.45681617804802954, 0.15387085819384083, 0.39137347717769444, 0.14162767765810713, 0.1660406996961683, 0.13888670364394784, 0.5042834091000259, 0.26346102997194976, 0.40417475276626647, 1.0449249297380447, 76.13607376813889, 70.10407224297523, 63.12005080282688, 34.87034127116203, 69.78466138243675, 47.417017221450806, 27.189986295998096, 45.040472745895386, 26.439940743148327, 24.253258779644966, 19.42736003547907, 43.0781402438879, 68.98102730512619, 72.51439690589905, 63.26437845826149, 74.76000040769577, 38.30981411039829, 0.6183772743679583, 0.29783371835947037, 0.48953999241348356, 8.776779491454363, 63.5002925992012, 58.10734458267689, 60.25570370256901, 59.74879950284958, 64.10772800445557, 63.26242536306381, 64.97409671545029, 62.18670308589935, 54.5211236178875, 50.04775285720825, 55.43771043419838, 54.22993764281273, 61.60489730536938, 63.61384570598602, 44.39462900161743, 64.65575739741325, 76.41980454325676, 67.75705218315125, 59.67602580785751, 55.62448561191559, 49.49780836701393, 42.53953814506531, 46.981492191553116, 71.60600244998932, 63.702111169695854, 42.98015110194683, 45.63152343034744, 50.046597719192505, 54.95926670730114, 55.79850487411022, 54.545826092362404, 56.60757265985012, 50.653592348098755, 51.330415830016136, 50.05987040698528, 47.296415492892265, 41.11607372760773, 48.27872358262539, 63.64371210336685, 50.97019515931606, 20.457982532680035, 7.696762019768357, 10.567686092108488, 13.787109889090061, 32.57635876536369, 44.78508085012436, 43.58974099159241, 40.31441934406757, 44.11061704158783, 46.164422035217285, 51.35153889656067, 56.335913836956024, 58.64708662033081, 48.68109539151192, 52.61467471718788, 24.26511224359274, 8.422810435295105, 12.023861054331064, 21.065834015607834, 39.80191804468632, 53.35197955369949, 51.505905613303185, 51.53813548386097, 43.25170353055, 38.51046994328499, 25.355306044220924, 31.256484389305115, 24.17029783129692, 4.819439090788364, 2.7072556922212243, 1.0830717952921987, 5.704084821045399, 15.244983360171318, 23.956025429069996, 21.051573380827904, 27.71599017083645, 35.75697809457779, 36.49542286992073, 42.21164993941784, 46.81174390017986, 51.665223464369774, 51.43343210220337, 49.13628816604614, 42.06495501101017, 44.157734513282776, 66.04083627462387, 44.63111311197281, 33.487500473856926, 50.27222961187363, 52.95668676495552, 55.37893518805504, 55.74139013886452, 53.19163955748081, 49.32076446712017, 47.788751274347305, 51.36299908161163, 45.81117399036884, 46.610058322548866, 50.2021499723196, 54.56459328532219, 64.69409734010696, 66.19253173470497, 63.8494710624218, 58.81878800690174, 51.37152202427387, 53.92462022602558, 51.34433828294277, 54.84539441764355, 57.06501491367817, 64.8778934776783, 67.13181853294373, 68.82576763629913, 67.22060456871986, 67.11003810167313, 24.05659083276987, 0.25133772112894803, 0.5498573323711753, 1.0377999558113515, 22.12770413607359, 59.82304371893406, 68.40683251619339, 67.43305116891861, 66.07152342796326, 34.89055618643761, 7.300790017470717, 32.73574881255627, 32.880247458815575, 38.841245993971825, 41.15055687725544, 39.09142076969147, 58.3466861397028, 46.45715832710266, 50.95546334981918, 58.186441138386726, 90.47175452113152, 20.035990476608276, 0.33661111257970333, 0.5789964250288904, 0.18540079443482682, 0.25924319692421705, 0.089828560303431, 0.1835933086113073, 0.23123397957533598], [0.05009566950320732, 0.019790740770986304, 0.09847432098467834, 0.08174731425242499, 0.12788887659553438, 0.08752422145335004, 0.027770143751695286, 0.06475196176324971, 0.008692150477145333, 0.06165977749333251, 0.20253826078260317, 0.0735806544253137, 49.52371537685394, 53.65771494805813, 60.72899490594864, 35.76235480606556, 36.944809556007385, 48.04062455892563, 32.430959567427635, 19.73138552159071, 32.178934291005135, 7.491618627682328, 13.923872150480747, 59.8896237462759, 60.43219283223152, 64.97500866651535, 51.60707898437977, 54.665348678827286, 35.433311462402344, 1.9706066767685115, 0.16253880166914314, 0.5448717623949051, 0.5959674424957484, 37.7137590944767, 55.77090695500374, 56.285517141222954, 59.94549214839935, 58.88260178267956, 58.09494584798813, 58.35015155375004, 54.56279598176479, 47.531444281339645, 48.7152973562479, 50.20604856312275, 48.83959248661995, 49.48546662926674, 55.18434002995491, 61.9731355458498, 48.21787364780903, 45.85575319826603, 52.15456880629063, 51.33220933377743, 54.56998899579048, 53.55424650013447, 60.06895512342453, 41.05626493692398, 29.16295062750578, 44.822645634412766, 82.7475593984127, 63.06496895849705, 44.34835888445377, 44.24058146774769, 51.22610382735729, 48.81472662091255, 48.44610460102558, 46.30118429660797, 45.41862465441227, 41.66196383535862, 31.69778510928154, 38.95780473947525, 41.17491357028484, 37.330143079161644, 15.425704512745142, 2.937691477127373, 2.5986627442762256, 2.4359198519960046, 1.9514262559823692, 23.853126950562, 41.773514449596405, 38.53538140654564, 36.49494789540768, 40.16753062605858, 42.25529059767723, 38.516804203391075, 22.89869986474514, 12.265703827142715, 11.168930679559708, 8.935222439467907, 1.7534882272593677, 0.049130647457786836, 0.2301066424115561, 1.565295250620693, 4.760575024411082, 11.826293505728245, 22.474984601140022, 34.064233526587486, 38.08397322893143, 39.112334847450256, 26.121857911348343, 28.415276147425175, 21.14143095910549, 3.6035772459581494, 1.9788465346209705, 0.7697602605912834, 2.428649179637432, 4.7462032455950975, 9.313496891409159, 13.915450852364302, 13.544624950736761, 17.12008774280548, 19.548427239060402, 29.25702027976513, 35.77550210058689, 45.1997260004282, 42.434317991137505, 46.32621355354786, 47.084326073527336, 45.98191402852535, 76.03989332914352, 67.47151270508766, 25.547482632100582, 36.33757933974266, 44.680974036455154, 52.786885276436806, 49.74098011851311, 52.700360119342804, 46.27549767494202, 54.72766913473606, 51.03809751570225, 43.721419125795364, 45.4179672896862, 51.17143236100674, 53.65737296640873, 58.26231926679611, 57.91846051812172, 55.0971233099699, 50.271131470799446, 46.71618662774563, 49.18584890663624, 50.00893794000149, 49.78374682366848, 48.65116439759731, 55.350341722369194, 55.50862602889538, 63.28173212707043, 57.77263954281807, 65.05399882793427, 12.449917942285538, 0.24761711218161508, 0.1004432536137756, 0.42665167478844523, 18.71438719332218, 58.19538585841656, 52.780247032642365, 55.4631956666708, 40.91207407414913, 30.738408789038658, 3.098117681220174, 27.421515472233295, 15.292420964688063, 22.32001941651106, 29.756547175347805, 34.07591789960861, 39.64598961174488, 28.277714028954506, 28.4479258954525, 44.65462625026703, 66.47669568657875, 10.072102434933186, 0.5161461944226176, 0.19706634659087285, 0.09068463506991975, 0.14254041539970785, 0.085489245102508, 0.02439434774714755, 0.08867262076819316, 0.1094772169017233, 0.10555374930845574, 0.14072409801883623, 0.03348152858961839, 0.17335647979052737, 0.13526483002351597, 0.08553072373615578, 0.0675511424196884, 0.07927374346763827, 0.07001097605098039, 0.30665322323329747, 0.06139542078017257, 56.28111317753792, 62.08785519003868, 60.55613078176975, 31.84343509376049, 55.028533190488815, 40.45341208577156, 36.974831745028496, 23.611629009246826, 40.12592285871506, 14.0864597260952, 11.299718711525202, 68.98201525211334, 66.56033679842949, 70.32180055975914, 57.47422255575657, 65.31860142946243, 43.07947017252445, 3.0316350236535072, 0.17390045919455588, 0.7359246199484915, 0.606658406322822, 40.4870592802763, 59.65720921754837, 58.993031457066536, 62.473329305648804, 62.831156104803085, 62.655552327632904, 63.38003285229206, 56.19408264756203, 51.53340473771095, 51.723603531718254, 52.22744129598141, 49.516446366906166, 53.505339324474335, 56.61279737949371, 66.5446588397026, 53.72208349406719, 54.80801962316036, 56.86943180859089, 59.94455359876156, 58.39894473552704, 56.716885194182396, 57.7442816644907, 44.85688179731369, 32.7771931886673, 50.71027770638466, 78.87084782123566, 60.63276506960392, 46.55425451695919, 48.36706884205341, 52.00588658452034, 55.769736617803574, 53.42539921402931, 55.41279897093773, 50.122145265340805, 47.79797337949276, 42.76905342936516, 38.39525252580643, 54.618956968188286, 56.30778394639492, 31.15115024149418, 6.659281365573406, 1.1254247976467013, 3.218698985874653, 5.5796149000525475, 28.022344931960106, 40.979520455002785, 36.39376312494278, 39.766173362731934, 42.0407123118639, 45.530612245202065, 49.75820079445839, 42.675684839487076, 29.75359283387661, 25.709447041153908, 34.91803631186485, 11.218442022800446, 2.116880896501243, 3.4251775313168764, 7.310235360637307, 18.121740594506264, 31.776250898838043, 43.40765096247196, 47.721050307154655, 39.456345587968826, 34.65966537594795, 24.380563348531723, 30.620753802359104, 19.553634859621525, 4.248917754739523, 1.294736706186086, 0.7564596680458635, 2.7669189032167196, 8.318662773817778, 16.30712516605854, 19.012213312089443, 13.404566366225481, 23.962646573781967, 27.881676480174065, 34.759706407785416, 45.24098038673401, 47.724523320794106, 48.77621568739414, 50.70641331374645, 53.685366064310074, 49.07563962042332, 65.07333979010582, 72.46423959732056, 34.9969656765461, 33.919130712747574, 46.28581032156944, 50.3901144862175, 49.52545188367367, 52.19049587845802, 48.95729877054691, 52.62402981519699, 50.33328473567963, 42.945417165756226, 43.67503501474857, 52.525983676314354, 57.036345452070236, 60.12668922543526, 58.37223596870899, 57.23288230597973, 54.96899038553238, 48.69608938694, 53.31932790577412, 53.01310993731022, 54.662639424204826, 50.287242606282234, 57.06517830491066, 59.680118188261986, 65.38634419441223, 60.726642832159996, 68.26497092843056, 13.589636385440826, 0.32143487536814064, 0.2344265059218742, 0.2793513023061678, 25.391278713941574, 63.6041372269392, 55.98555363714695, 58.68014484643936, 45.55686503648758, 34.12595361471176, 4.192045256495476, 33.10180976986885, 21.798653192818165, 28.69159162044525, 31.701149828732014, 36.389150172472, 46.5384815633297, 30.301954708993435, 27.118263244628906, 51.38010956346989, 67.88011237978935, 7.849810207262635, 0.43217473779805005, 0.20153496618149802, 0.037702816334785894, 0.12247551785549149, 0.05215012723056134, 0.09613119007553905, 0.10500580683583394, 0.2074539352906868, 0.17567929811775684, 0.1573017772170715, 0.249685492599383, 0.1463858239003457, 0.2103751472895965, 0.16747598361689597, 0.16032075975090265, 0.14233723020879552, 0.14909684483427554, 0.44911384291481227, 0.27299468871206045, 67.70301148295403, 67.0511032640934, 81.50868147611618, 46.95560038089752, 58.34278754889965, 67.29590892791748, 40.10444641113281, 26.329982243478298, 41.45563490688801, 16.296709924936295, 19.932322539389133, 69.92026090621948, 73.32278832793236, 74.73093196749687, 61.884592697024345, 69.22625094652176, 46.329021602869034, 3.8612335827201605, 0.29959358798805624, 1.4045179216191173, 1.291428746189922, 50.79005442559719, 61.72743313014507, 65.06173521280289, 64.9791732430458, 67.65356853604317, 65.8605207502842, 64.32209730148315, 57.314239740371704, 52.74777777493, 53.37244525551796, 56.03595793247223, 56.27750717103481, 55.81442601978779, 57.63703241944313, 69.60622295737267, 59.542322382330894, 63.59302282333374, 62.44122862815857, 65.55565550923347, 61.387754157185555, 57.68602319061756, 61.22864909470081, 45.17305143177509, 45.15469841659069, 65.06263956427574, 71.69487208127975, 54.62963059544563, 48.283066749572754, 49.87110413610935, 56.550328731536865, 58.64657744765282, 57.92778521776199, 57.60856434702873, 55.58559089899063, 51.654333248734474, 51.95089593529701, 49.865180253982544, 60.47777898609638, 68.96665647625923, 40.64112201333046, 11.507307272404432, 8.187245875597, 7.755411872640252, 25.325107164680958, 43.43042314052582, 49.65121753513813, 49.71443094313145, 48.16659539937973, 52.46869035065174, 52.061302810907364, 57.55912519991398, 48.80991227924824, 28.112029619514942, 23.70476011186838, 41.326267048716545, 13.385520838201046, 2.154857008717954, 3.449697853066027, 6.2507757358253, 17.738732546567917, 31.36948272585869, 50.414448380470276, 52.52429276704788, 47.64090120792389, 47.040575221180916, 34.30102922022343, 37.42035023868084, 30.772542357444763, 15.058245230466127, 2.7094108890742064, 2.1261547738686204, 3.838490378111601, 10.976259168237448, 23.108781091868877, 27.658221870660782, 23.58127623796463, 36.75447776913643, 35.76951362192631, 44.28838670253754, 46.700406074523926, 56.49043254554272, 52.16692574322224, 55.976099744439125, 54.84943740069866, 50.015940964221954, 63.01203779876232, 77.27759331464767, 52.3144756257534, 40.8264646679163, 49.264797270298004, 52.57962919771671, 49.37328524887562, 54.143420085310936, 50.43493688106537, 52.187471240758896, 48.279722929000854, 49.26979020237923, 42.53306709229946, 53.02901588380337, 58.600774705410004, 64.52920898795128, 62.89277359843254, 60.544317215681076, 56.773806139826775, 52.72955775260925, 56.292858347296715, 54.87524561583996, 56.21948428452015, 53.93660478293896, 60.581566616892815, 64.47056293487549, 69.3522597849369, 62.799135223031044, 70.30108407139778, 18.373904563486576, 0.2972169342683628, 0.41351263294927776, 0.29489947424735874, 26.602718308568, 73.3736751973629, 60.103920847177505, 63.015951588749886, 52.42660380899906, 38.688137009739876, 7.521591419354081, 39.1275530308485, 22.175478972494602, 34.64510075747967, 43.87620382010937, 48.77308465540409, 58.07280823588371, 41.36338345706463, 41.20404660701752, 54.767350405454636, 86.31652548909187, 16.61358442157507, 0.8553601673338562, 0.31117088394239545, 0.20836391224293038, 0.2538456756155938, 0.1763319576275535, 0.21855536615476012, 0.19713699904968962], [0.11899439996341243, 0.06357806967571378, 0.11076569659053348, 0.02352965293539455, 0.07519005361245945, 0.10566900484263897, 0.16518035758053884, 0.027421358463470824, 0.06617156410356984, 0.042585910559864715, 0.309014143422246, 0.20274380600312725, 36.34577549993992, 58.7242528796196, 51.53698414564133, 28.09936299920082, 26.730811335146427, 46.05894349515438, 33.391354233026505, 27.38705512136221, 32.183703035116196, 33.1682226061821, 3.1134327594190836, 32.396332025527954, 64.96420204639435, 65.85806608200073, 55.65431401133537, 61.79897949099541, 41.32829234004021, 2.5260695395991206, 0.14485242805676535, 0.5676757637411356, 0.09523754037218168, 24.24874272197485, 58.75376209616661, 53.486526533961296, 62.32349954545498, 60.10414123535156, 63.01910921931267, 55.85191860795021, 47.79701203107834, 49.537128657102585, 60.8605020493269, 58.98263141512871, 53.22580352425575, 48.63763712346554, 55.35862147808075, 57.96313852071762, 59.986662939190865, 57.96750828623772, 58.53543721139431, 57.94342517852783, 53.98662529885769, 51.57308600842953, 48.14236789941788, 46.85470439493656, 42.30314143002033, 27.073433250188828, 33.34810495376587, 63.19527916610241, 67.37769573926926, 54.54870253801346, 51.1644521355629, 48.972281366586685, 48.79219003021717, 44.778621196746826, 43.00836078822613, 37.34290659427643, 38.95798712968826, 46.68494090437889, 46.35675251483917, 32.203355580568314, 8.865683320909739, 0.854316707700491, 4.18242322281003, 2.2451791120693088, 11.4322461001575, 36.06446139514446, 47.2492790222168, 44.87085744738579, 48.55413660407066, 37.71521061658859, 33.74549522995949, 21.09746541827917, 6.470201136544347, 1.4552877098321915, 1.0283973603509367, 7.6656098663806915, 4.043415756896138, 1.0112338000908494, 0.9865751420147717, 0.3257681569084525, 1.0820688866078854, 3.071068595163524, 8.464882727712393, 23.406440019607544, 35.30940391123295, 43.089779019355774, 38.81373167037964, 41.075415909290314, 30.914092361927032, 15.274486877024174, 3.8015100499615073, 0.5415446253027767, 0.36459186114370823, 4.014806617051363, 7.751847188919783, 12.969891540706158, 16.546803005039692, 17.83453680574894, 20.272090807557106, 30.666974522173405, 38.39306004345417, 42.58899249136448, 46.561941504478455, 50.58927699923515, 53.31452876329422, 45.30166693031788, 41.480979546904564, 90.42727410793304, 61.13136291503906, 30.946346931159496, 36.940359994769096, 46.180723160505295, 46.873015612363815, 48.22400651872158, 44.9311488121748, 45.94159819185734, 44.21321913599968, 58.31982158124447, 59.866824969649315, 51.98173128068447, 60.31807355582714, 55.43246291577816, 55.09968437254429, 51.64542272686958, 51.008732691407204, 49.7527214884758, 58.145065158605576, 57.60699883103371, 58.671245723962784, 55.39794936776161, 51.51735819876194, 56.925133019685745, 56.244194358587265, 58.53596918284893, 63.01735371351242, 7.2262351680547, 0.14036816399311647, 0.2698263118509203, 2.9921190440654755, 38.83472554385662, 48.09971898794174, 60.8230322599411, 41.76114611327648, 64.62023690342903, 23.434455916285515, 4.912758283317089, 32.1243692189455, 14.802538901567459, 39.66788403689861, 27.693081200122833, 28.637594617903233, 40.05196362733841, 30.600576885044575, 36.77612140774727, 56.757007241249084, 50.45944556593895, 2.503014039248228, 0.22981724934652448, 0.12706387555226684, 0.07587833621073514, 0.06939828119357117, 0.10112906486028805, 0.16280214535072446, 0.07385642165900208, 0.070277266058838, 0.08791793821728788, 0.2008763694902882, 0.06683365631033666, 0.05706015399482567, 0.22090963670052588, 0.33920738263987005, 0.0353225706203375, 0.051712530985241756, 0.07558293917099945, 0.27813367545604706, 0.08713725081179291, 41.066148206591606, 66.45211100578308, 56.32410787045956, 24.657712876796722, 40.011871978640556, 47.31547147035599, 33.95320348441601, 28.566660024225712, 31.21120221912861, 45.747170224785805, 4.094833647832274, 32.57007010281086, 70.89932397007942, 70.17205819487572, 61.07500433921814, 66.38106241822243, 47.52350650727749, 3.7243613647297025, 0.14996426703874022, 0.7246908196248114, 0.07521786930738017, 28.22692595422268, 61.7742770165205, 57.81952902674675, 64.6412193775177, 62.32972361147404, 66.37926131486893, 59.61097709834576, 50.2796696126461, 55.604475885629654, 62.63111583888531, 62.003435119986534, 56.45759090781212, 54.45834718644619, 58.302437514066696, 60.6440694630146, 63.0791649967432, 60.22267207503319, 61.39321066439152, 62.20137029886246, 55.05991190671921, 52.86253921687603, 46.86102345585823, 46.88744343817234, 42.22344450652599, 34.50330376625061, 35.88624335825443, 60.282678455114365, 61.96499638259411, 57.600873559713364, 53.77478666603565, 53.962739780545235, 49.34451699256897, 53.53829115629196, 48.66820648312569, 47.973246574401855, 43.093681409955025, 47.313309386372566, 57.50399395823479, 46.81947648525238, 14.664643350988626, 3.0789353605359793, 2.86517474334687, 4.121639784425497, 13.493664935231209, 37.50485010445118, 51.32927589118481, 43.93184043467045, 44.95226047933102, 41.7708545923233, 47.36243695020676, 41.3999754935503, 24.58393793553114, 10.471591148525476, 9.874578583985567, 21.20345503091812, 7.213122071698308, 1.0494763730093837, 2.114589619450271, 1.717091880273074, 5.773563142865896, 13.24159026145935, 29.688107147812843, 44.75494846701622, 43.631637543439865, 47.6571149379015, 38.75559858977795, 40.38071058690548, 28.70528418570757, 12.535314559936523, 4.9824294447898865, 0.9667444217484444, 0.5048257706221193, 5.863682432100177, 13.858868088573217, 20.038141161203384, 17.814964056015015, 20.206576623022556, 32.74102672934532, 35.68070098757744, 46.89703792333603, 46.9996590167284, 50.077794045209885, 55.83625204861164, 54.83166575431824, 46.5665240585804, 40.129411071538925, 70.47759979963303, 78.25757592916489, 38.83176930248737, 38.6893567442894, 42.3200049251318, 45.41502624750137, 44.68265734612942, 45.44860504567623, 47.67595812678337, 50.79682186245918, 52.461774721741676, 59.517061337828636, 57.716698944568634, 63.02740417420864, 58.406487330794334, 60.07422924041748, 52.433055862784386, 53.58559101819992, 53.35535377264023, 62.509955540299416, 59.53753083944321, 63.515567779541016, 58.93660448491573, 58.958635702729225, 58.70112732052803, 61.457754001021385, 61.52080021798611, 64.91490349173546, 5.821793954819441, 0.12092779856175184, 0.2866799512412399, 4.97988548129797, 46.65428414940834, 51.65919318795204, 68.1997512280941, 46.9499196857214, 69.62789699435234, 19.689621962606907, 7.370990300551057, 39.85811322927475, 18.87103758752346, 39.578607827425, 28.051189184188843, 31.2158265709877, 45.93332223594189, 32.63821564614773, 40.078003630042076, 60.853331834077835, 59.494087770581245, 3.0719731841236353, 0.24994925188366324, 0.11634069509455003, 0.04040876840008423, 0.15699212352046743, 0.1661339876591228, 0.14902898285072297, 0.19200072856619954, 0.2801477158209309, 0.2858328935690224, 0.30029494722839445, 0.13813235505949706, 0.36611988383810967, 0.14786452346015722, 0.33958225627429783, 0.2096451708348468, 0.17226193071110174, 0.20432882563909516, 0.5912844906561077, 0.2722720743622631, 56.93866029381752, 72.74060636758804, 68.6187319457531, 37.490578070282936, 45.23784935474396, 65.63934221863747, 42.73746192455292, 36.989897936582565, 40.466243997216225, 43.88370081782341, 6.173519706353545, 42.563461661338806, 73.4829269349575, 77.57396221160889, 66.56165152788162, 71.72816589474678, 50.72172649204731, 4.293297473341227, 0.3229186066891998, 1.4728037011809647, 0.1640551578020677, 34.026699140667915, 63.36080588400364, 61.54445394873619, 70.47348842024803, 68.76066192984581, 69.2587848007679, 64.8948709666729, 52.2409001737833, 57.15203404426575, 63.41679587960243, 65.6098710000515, 58.6471626162529, 58.59978295862675, 58.619408905506134, 63.38904216885567, 67.30079546570778, 62.70045831799507, 63.792253732681274, 63.52193623781204, 58.11615630984306, 54.90091323852539, 48.85520964860916, 49.19238455593586, 44.502782598137856, 41.909250766038895, 57.478326335549355, 70.24080410599709, 60.34423515200615, 60.81256002187729, 55.54305978119373, 59.572637155652046, 54.61229972541332, 59.48503665626049, 55.41838087141514, 52.820688262581825, 51.80067479610443, 54.19013857841492, 69.39328998327255, 62.68476516008377, 23.321856558322906, 8.439877219498158, 10.55385958403349, 16.603545360267162, 41.69357433915138, 56.23268097639084, 59.437516406178474, 52.392846420407295, 55.532530546188354, 51.56424768269062, 54.51188251376152, 48.632344007492065, 29.899710193276405, 12.51985888928175, 10.438433177769184, 26.43808264285326, 13.452382050454617, 2.501221722923219, 3.578244005329907, 2.297943555749953, 7.272066883742809, 16.266227960586548, 35.73865167796612, 47.79087916016579, 51.49187296628952, 54.40219759941101, 51.52157597243786, 48.98896247148514, 42.99735277891159, 27.63291522860527, 11.579231712967157, 8.829103633761406, 1.2358202738687396, 7.977663371711969, 17.804355025291443, 26.498883180320263, 23.994954340159893, 32.10390351712704, 42.31034964323044, 44.185423627495766, 51.4626981317997, 50.76280988752842, 53.52697916328907, 57.44982786476612, 58.05742286145687, 44.215145632624626, 41.97532162070274, 63.628235533833504, 74.37125086784363, 53.00663508474827, 42.702439203858376, 47.85954147577286, 46.77338495850563, 48.73049654066563, 46.12262427806854, 46.56794138252735, 45.68475857377052, 42.078113704919815, 55.37672370672226, 57.607572600245476, 64.39689248800278, 62.765769213438034, 60.92859819531441, 56.63792543113232, 55.834830924868584, 54.938561618328094, 63.73103141784668, 64.1006375849247, 66.34595990180969, 62.161039263010025, 59.78012502193451, 61.11457921564579, 63.010274693369865, 62.60274276137352, 67.17540979385376, 10.621127374470234, 0.2569781325291842, 0.5919606168754399, 4.447569670155644, 48.661807626485825, 59.8578080534935, 71.05303332209587, 54.237670227885246, 71.86444938182831, 31.656061448156834, 10.079535786062479, 43.59832473099232, 23.270067237317562, 53.47215950489044, 40.306086391210556, 40.12288302183151, 61.15259997546673, 40.497501119971275, 52.036512941122055, 66.92978337407112, 73.48037347197533, 7.159806182608008, 0.34283259592484683, 0.3350125561701134, 0.18950064084492624, 0.24584035127190873, 0.22086531564127654, 0.2398113365052268, 0.2847452909918502], [0.11399158247513697, 0.09810580013436265, 0.17606140027055517, 0.07383099567960016, 0.06773501692805439, 0.07692415587371215, 0.13503393303835765, 0.04641386003640946, 0.03282862417108845, 0.20026016427436844, 0.19401724770432338, 0.5942236923146993, 15.636608395725489, 60.592312440276146, 51.55456580221653, 48.26949007809162, 36.94061458110809, 43.48248794674873, 41.629870757460594, 28.554605171084404, 37.1829541772604, 54.647436439991, 3.79705217666924, 18.746793754398823, 60.98433740437031, 66.76299512386322, 58.532458171248436, 58.36036540567875, 42.4565239995718, 4.351219665259123, 0.20221275481162593, 0.04885018614004366, 0.0652206725499127, 14.735116269439459, 69.75647449493408, 57.498959228396416, 62.11145952343941, 56.01507045328617, 58.12207259237766, 50.255841091275215, 50.23285232484341, 59.54988777637482, 62.614890709519386, 63.046289160847664, 58.16591463983059, 51.98333479464054, 49.12101298570633, 54.3040906637907, 56.274493932724, 57.14732609689236, 59.91786003112793, 61.248252242803574, 62.95101687312126, 52.45629541575909, 47.13014401495457, 41.41040973365307, 47.413038834929466, 49.774258732795715, 33.687977716326714, 25.81799391657114, 45.902414694428444, 56.21946528553963, 52.963963374495506, 50.61037726700306, 47.50736117362976, 47.462018206715584, 44.18079927563667, 34.9583825469017, 43.04776467382908, 52.72165037691593, 42.01808452606201, 22.076102904975414, 5.024451389908791, 3.6968123679980636, 4.00004155933857, 8.691563364118338, 34.2502411454916, 44.66685399413109, 51.49638332426548, 47.04343646764755, 41.71392224729061, 28.61327212303877, 18.823302648961544, 6.920307409018278, 1.6090383846312761, 2.0714989816769958, 2.4655497120693326, 11.203667465597391, 1.8975451472215354, 1.0449162614531815, 1.6586721525527537, 1.8723202007822692, 1.0021210578270257, 1.8779745348729193, 1.1221385677345097, 7.57881729863584, 22.87110384553671, 36.88648648560047, 40.08893944323063, 44.4317340105772, 39.5065750926733, 28.733845353126526, 21.69565971940756, 7.7215642388910055, 1.6895842063240707, 2.091967058368027, 7.578611634671688, 12.874830141663551, 17.54988458007574, 17.537514343857765, 21.42345942556858, 29.532813280820847, 39.590683579444885, 39.621887505054474, 42.8316892683506, 44.77682389318943, 47.723185792565346, 48.3258942514658, 43.859625309705734, 60.386823266744614, 92.94792205095291, 61.298417150974274, 47.475507482886314, 37.67766863107681, 46.2876608222723, 49.458332285284996, 63.54297570884228, 73.0152328312397, 89.62161853909492, 87.16153174638748, 60.77553480863571, 58.963678032159805, 59.81873854994774, 55.70384055376053, 55.837730169296265, 45.816535502672195, 47.19750680029392, 57.823743000626564, 58.98770414292812, 57.30309873819351, 59.07614819705486, 55.63724532723427, 61.763698384165764, 60.54941654205322, 61.615897715091705, 61.9817116856575, 55.957663133740425, 1.6552133881486952, 0.10585831187199801, 0.524708084994927, 15.460790880024433, 64.0481624007225, 49.55457732081413, 39.46242146193981, 51.46771386265755, 61.216474547982216, 4.1715871542692184, 12.487468477338552, 36.67201839387417, 17.597952000796795, 40.07619112730026, 32.60934479534626, 35.234882310032845, 34.474246725440025, 35.01042075455189, 37.295697927474976, 54.59125265479088, 41.687547862529755, 1.0352888843044639, 0.10978051781421527, 0.043319887190591544, 0.12479849945520982, 0.22818664700025693, 0.07996997446753085, 0.023953090858412907, 0.04046179114084225, 0.05648937563819345, 0.0738594050926622, 0.06407993219909258, 0.11364126650732942, 0.11234852689085528, 0.04969854257069528, 0.13170445075957105, 0.07178287589340471, 0.06663444903097115, 0.22845828789286315, 0.27011696656700224, 0.7638972345739603, 18.866417035460472, 71.8394011259079, 56.41137398779392, 40.90704694390297, 45.50690911710262, 49.345455542206764, 35.64154788851738, 34.74467061460018, 31.247435174882412, 59.198045656085014, 6.864209119230509, 20.439433827996254, 69.48458388447762, 75.45987725257874, 62.58074954152107, 62.99208126962185, 47.050766274333, 5.616254433989525, 0.2545967884361744, 0.8435840054880828, 0.06419227851438336, 16.916534565389156, 73.40090453624725, 61.509864404797554, 65.08591711521149, 59.93997864425182, 61.56491965055466, 51.30896598100662, 52.82365970313549, 63.04201819002628, 63.566777631640434, 65.25480285286903, 62.18016743659973, 55.55167391896248, 52.7718722820282, 58.09950940310955, 59.91489619016647, 58.69526043534279, 61.61942392587662, 62.944872602820396, 61.931318789720535, 53.585070446133614, 50.712777972221375, 44.128312692046165, 46.93277880549431, 50.161419957876205, 39.69390124082565, 31.305448561906815, 45.617145001888275, 56.661248579621315, 55.14606848359108, 52.942490726709366, 49.698547795414925, 50.9285493940115, 46.546240746974945, 45.48119209706783, 42.584668323397636, 59.53322947025299, 59.36500109732151, 33.89098182320595, 9.753694720566273, 2.7555503882467747, 7.639665808528662, 7.4050583224743605, 30.701070092618465, 46.02665662765503, 50.653250366449356, 50.206405743956566, 49.20777752995491, 41.05823703110218, 39.23923283815384, 27.517942897975445, 13.876738529652357, 5.172345153987408, 5.674656825140119, 12.750466614961624, 4.915558733046055, 1.3106117793358862, 1.802133929450065, 0.5995264265220612, 1.9110908266156912, 3.80915405228734, 15.062079224735498, 28.22036560624838, 39.79811064898968, 45.75604274868965, 45.232529640197754, 44.909520372748375, 42.80859790742397, 26.40625935047865, 9.702689107507467, 4.572120336815715, 0.811139268334955, 2.332485602237284, 11.160545479506254, 17.783049568533897, 23.55537112802267, 19.192468039691448, 29.234276600182056, 37.684360072016716, 45.920801907777786, 45.483988747000694, 46.606851294636726, 48.03470067679882, 52.57829926908016, 53.546380922198296, 46.64180941879749, 47.91151128709316, 75.98449230194092, 73.56578528881073, 55.17387919127941, 46.61230780184269, 48.77327084541321, 49.698574393987656, 58.49233612418175, 69.81818318367004, 73.91542732715607, 83.99469047784805, 67.67662569880486, 61.44315518438816, 61.48886293172836, 60.3059446066618, 58.33776421844959, 48.884213492274284, 51.45522013306618, 61.79961785674095, 60.170660465955734, 62.711325734853745, 63.130017668008804, 59.108032286167145, 64.06215324997902, 62.825642600655556, 65.54937824606895, 61.55855879187584, 54.61449220776558, 1.4392063790000975, 0.2238342328928411, 0.3552300838055089, 18.13891377300024, 68.76767635345459, 53.43583345413208, 44.00809094309807, 57.21696496009827, 57.74386368691921, 6.726106004789472, 16.356798000633717, 41.23873494565487, 23.258825540542603, 39.05186489224434, 30.27847956866026, 37.03299142420292, 47.2941280156374, 32.26048171520233, 38.05495798587799, 59.28759925067425, 41.80265888571739, 1.0441490588709712, 0.049224221147596836, 0.05193341268750373, 0.06631968193687499, 0.136252969969064, 0.03942694042052608, 0.08845913456752896, 0.023952191004354972, 0.12077496809069999, 0.24413878476480022, 0.3016761731123552, 0.11724132840754464, 0.21736850874731317, 0.17078756529372185, 0.2308530648588203, 0.1800619621644728, 0.15232073434162885, 0.1924050209345296, 0.7500641362275928, 0.6240856368094683, 31.142538003623486, 83.65349918603897, 66.10448285937309, 63.64960938692093, 50.30665196478367, 69.13111925125122, 51.204444989562035, 42.61463351547718, 42.195303216576576, 68.97000789642334, 7.332396721467376, 25.38585640490055, 71.5447649359703, 78.28221380710602, 67.98667386174202, 70.86465463042259, 52.8597691655159, 6.530410330742598, 0.34497927292250097, 1.7212295019999146, 0.23976674827281386, 21.73028726130724, 72.89634481072426, 64.11232575774193, 66.35501861572266, 64.37544643878937, 65.21818041801453, 58.081779554486275, 55.25646016001701, 66.11814692616463, 67.94663920998573, 69.20583084225655, 64.85371917486191, 61.858951672911644, 56.80545464158058, 60.84525726735592, 59.68635365366936, 62.084727957844734, 64.49667513370514, 64.09008175134659, 61.5428314357996, 57.18482628464699, 49.566945657134056, 44.31307777762413, 47.62552723288536, 50.122555643320084, 39.54272635281086, 40.07961854338646, 57.45385944843292, 58.6033433675766, 56.922321170568466, 57.84164384007454, 53.976932018995285, 58.52312967181206, 52.53076381981373, 52.961903885006905, 49.103936702013016, 62.84705825150013, 65.81200495362282, 45.85419528186321, 19.75483976304531, 9.65200837701559, 16.687912233173847, 33.50289344787598, 51.39244370162487, 55.85028849542141, 55.9909113496542, 59.25323009490967, 55.218636989593506, 48.23855593800545, 45.14600448310375, 34.2939767986536, 18.49244300276041, 10.852036233991385, 10.988397616893053, 31.16019945591688, 19.751440845429897, 2.541510723531246, 3.468834813684225, 3.242422300390899, 3.817190146073699, 8.817982580512762, 24.12763562053442, 35.463831424713135, 43.275399059057236, 51.89839035272598, 48.100570142269135, 50.759359672665596, 48.24463181197643, 39.64411251246929, 33.70348088443279, 16.887103244662285, 6.308181155472994, 2.765361461788416, 14.858524147421122, 26.68769884854555, 32.30256825685501, 27.593522742390633, 40.25277145206928, 44.15204621851444, 51.56164102256298, 49.50830340385437, 51.28881946206093, 53.01659055054188, 54.02029149234295, 55.54283179342747, 46.47942893207073, 48.41949462890625, 61.387788355350494, 63.16657170653343, 60.20854443311691, 49.33749496936798, 51.15890443325043, 50.97377076745033, 55.9383487701416, 64.79109853506088, 66.90938606858253, 82.68117696046829, 75.13239562511444, 63.3488555252552, 65.80850154161453, 62.470156475901604, 61.2673120200634, 50.287816375494, 55.32964423298836, 63.267642483115196, 63.17362032830715, 62.34930396080017, 69.57176640629768, 62.76695854961872, 65.17174690961838, 64.41156730055809, 68.92637863755226, 65.23566707968712, 62.38993898034096, 2.8760188864544034, 0.372656779945828, 0.6221603869926184, 18.392612859606743, 79.77051794528961, 58.90386924147606, 49.740702733397484, 58.59253294765949, 65.82341954112053, 11.058197971433401, 19.812573865056038, 46.61305636167526, 25.095939561724663, 53.488867208361626, 44.6317894756794, 54.91720296442509, 56.304451525211334, 42.545161843299866, 50.15556447207928, 66.85666769742966, 59.75981891155243, 2.340342393144965, 0.3477877378463745, 0.1610104672727175, 0.18789683002978563, 0.2380485279718414, 0.13939381315140054, 0.11288319976301864, 0.11736760483472608], [0.02872395380109083, 0.04018276958959177, 0.03545549297996331, 0.1163171764346771, 0.07762009743601084, 0.07698006927967072, 0.121779665350914, 0.088270651322091, 0.08412611277890392, 0.2316735388012603, 0.2907368273008615, 0.4346145037561655, 6.92397041246295, 62.148750722408295, 50.75500510632992, 36.70098803937435, 24.128636866807938, 44.946898967027664, 47.78601162135601, 32.43876054883003, 31.563107036054134, 93.55876207351685, 16.469961628317833, 4.673006348311901, 50.95047801733017, 62.74313002824783, 61.34859725832939, 52.234178334474564, 49.64900225400925, 5.746950795874, 0.03934178268536925, 0.11949560197535902, 0.05963956245977897, 7.8345834743231535, 65.34368768334389, 60.80662474036217, 64.32139813899994, 58.559683710336685, 59.350265488028526, 48.52965831756592, 55.69419287145138, 59.284673407673836, 62.77357779443264, 62.83829212188721, 61.88762493431568, 57.878403067588806, 51.407015919685364, 50.799911096692085, 55.8634851872921, 62.96289123594761, 59.47076082229614, 59.5351255685091, 59.362500831484795, 57.48739644885063, 51.4587539434433, 47.45843879878521, 43.63903194665909, 45.74383780360222, 51.55333086848259, 49.119310677051544, 44.94653798639774, 47.63257585465908, 50.63196770846844, 51.677075028419495, 50.67153878509998, 42.508888989686966, 42.11002059280872, 37.23107859492302, 47.83983953297138, 50.3432933986187, 39.19838882982731, 16.655013598501682, 6.455345833674073, 8.107008431106806, 3.9843954239040613, 19.195910654962063, 42.025152146816254, 47.42219254374504, 53.220814391970634, 43.48930858075619, 30.730184130370617, 22.59919423609972, 8.371203504502773, 7.025655331090093, 4.30641389451921, 2.8730322467163205, 3.0654928693547845, 13.51196475327015, 5.710633294656873, 1.1872530612163246, 0.34375469957012683, 0.7592634425964206, 1.1265498935244977, 0.814395040506497, 2.7204338600859046, 5.537579655647278, 11.609717477113008, 24.731890596449375, 33.62955205142498, 39.42096568644047, 43.58383230865002, 36.382869109511375, 32.49372839927673, 21.66614670306444, 4.328208100050688, 1.1285482300445437, 4.59084858186543, 8.643048517405987, 16.275014989078045, 17.77184396982193, 17.575586400926113, 28.502855747938156, 41.09122306108475, 41.66869327425957, 43.32419604063034, 45.273768827319145, 48.23312222957611, 47.241234853863716, 48.423237428069115, 41.45918391644955, 57.2825076431036, 77.24696695804596, 68.74112337827682, 63.33199962973595, 56.64145924150944, 61.752310395240784, 66.39462769031525, 63.15998665988445, 49.722988083958626, 42.040545120835304, 53.32773305475712, 60.904936864972115, 55.59506379067898, 59.288796186447144, 51.71916536986828, 48.5764642059803, 51.90511979162693, 59.454615488648415, 57.90999457240105, 58.95604804158211, 55.047064796090126, 61.62990376353264, 52.83416993916035, 61.541482508182526, 57.301115244627, 64.19566288590431, 29.160098880529404, 0.7180250273086131, 0.301076695905067, 0.21774979453766719, 21.93890556693077, 59.03815783560276, 37.556451335549355, 44.86028641462326, 60.003993809223175, 40.29194355010986, 4.292049715295434, 12.843947298824787, 21.05669930577278, 16.469726040959358, 40.1382227987051, 31.11094269901514, 44.38458614051342, 35.85897222161293, 28.30924093723297, 34.83554273843765, 61.4951553940773, 21.110888198018074, 0.5128601426258683, 0.09288398970966227, 0.01745278263115324, 0.10067924915347248, 0.09678910399088636, 0.030839959690638352, 0.091049801412737, 0.08566612857975997, 0.053571933749481104, 0.08550832571927458, 0.03891735213983338, 0.037532734640990384, 0.061638158731511794, 0.0592369325022446, 0.09847383116721176, 0.24708203854970634, 0.0674357458774466, 0.1892773582949303, 0.2505969983758405, 0.4765714070526883, 7.849449226632714, 68.67148071527481, 58.641352728009224, 36.51275373995304, 31.136646419763565, 54.12805750966072, 35.666428953409195, 40.167716816067696, 36.36992320418358, 97.99079865217209, 18.67950316518545, 5.058370744809508, 48.48264344036579, 69.7390866279602, 65.04380017518997, 59.09524217247963, 54.40186321735382, 6.663645431399345, 0.04815759166376665, 1.2440372142009437, 0.05145090908627026, 8.744910601526499, 67.23391905426979, 65.68809360265732, 68.64374220371246, 61.33164256811142, 62.32594281435013, 51.54070034623146, 59.89770971238613, 60.428336039185524, 63.612492978572845, 64.34943303465843, 63.97517591714859, 60.697255209088326, 55.71554772555828, 52.835993841290474, 59.29571181535721, 62.90572710335255, 62.51486487686634, 60.41555352509022, 62.05632448196411, 57.10793361067772, 55.435126572847366, 47.84220300614834, 45.49881175160408, 45.93071177601814, 55.895802453160286, 51.27663731575012, 48.77938091754913, 49.4247230887413, 56.455143839120865, 52.04498648643494, 53.2353638112545, 47.096527218818665, 45.30540972948074, 43.26251395046711, 48.89797255396843, 62.96653524041176, 51.23894713819027, 24.598905332386494, 7.549932198598981, 7.713148640468717, 9.665772188454866, 23.829264231026173, 48.1280692666769, 56.45984038710594, 54.24029968678951, 50.22116795182228, 46.243852972984314, 36.44423581659794, 31.37348961085081, 19.61364883929491, 7.291580261662602, 5.0683133862912655, 5.136754838749766, 13.513659462332726, 7.231602855026722, 0.7069038553163409, 1.3299515540711582, 1.761713360901922, 1.3782259449362755, 1.9041509740054607, 7.56284580565989, 21.618031784892082, 31.7114282771945, 38.17566230893135, 45.75396046042442, 45.37254452705383, 47.357899993658066, 37.74944297969341, 33.10649111866951, 16.71471979469061, 3.3304260531440377, 1.576436252798885, 5.394874038174748, 14.456961695104837, 24.23391591757536, 20.770743750035763, 23.187980242073536, 39.71302181482315, 43.18263463675976, 46.948107182979584, 45.805086717009544, 50.02165585756302, 49.64117847383022, 51.23224049806595, 53.27597603201866, 43.32174137234688, 42.92368233203888, 64.97801810503006, 66.85328587889671, 65.25378450751305, 54.705702513456345, 58.85612480342388, 62.710554376244545, 57.520078495144844, 54.87183719873428, 52.32629679143429, 57.16301545500755, 64.84913662075996, 59.402417689561844, 60.66498354077339, 52.5600678473711, 51.90291590988636, 55.01424975693226, 62.7432706207037, 60.92389024794102, 62.84386642277241, 60.98213732242584, 63.045464605093, 55.15953116118908, 64.34383973479271, 56.758979335427284, 66.6910345852375, 27.929956689476967, 0.6423291703686118, 0.5098893551621586, 0.444770468166098, 26.71661339700222, 61.307517662644386, 40.537847355008125, 42.68334522843361, 62.98152543604374, 42.84971170127392, 5.879748919978738, 16.41242701560259, 30.789778232574463, 17.3454175516963, 43.08520406484604, 26.63016613572836, 49.415155202150345, 46.29595957696438, 27.75517176836729, 42.20533847808838, 71.35101333260536, 24.002099856734276, 0.13948428095318377, 0.16275671106996015, 0.047340717137558386, 0.10911216930253431, 0.08069003582932055, 0.03294607646239456, 0.02051409726846032, 0.11157126820762642, 0.22493488242616877, 0.18941429938422516, 0.09741074172779918, 0.17124866164522246, 0.17906426335684955, 0.27733013732358813, 0.1996080539538525, 0.3715637745335698, 0.2686639007879421, 0.3659389482345432, 0.5019066960085183, 0.5100349348504096, 14.282991830259562, 87.90048569440842, 65.73977842926979, 51.329093500971794, 33.76631811261177, 73.44628930091858, 61.40135742723942, 42.72554196417332, 37.628886848688126, 101.1308665573597, 19.420125223696232, 10.395562928169966, 56.92856803536415, 74.50469970703125, 68.51859211921692, 65.02895817160606, 60.8387254178524, 9.197490066289902, 0.2192776688025333, 2.1957993367686868, 0.09268998488551006, 12.283294033259153, 70.57093039155006, 67.31107011437416, 71.98099672794342, 66.03053122758865, 66.59176111221313, 55.6268110871315, 61.62310212850571, 63.52994620800018, 65.87480038404465, 67.06244185566902, 67.86327168345451, 63.892370760440826, 57.93596237897873, 56.00803703069687, 60.23307591676712, 67.14284554123878, 65.63470646739006, 64.74925518035889, 66.15844756364822, 60.780159160494804, 56.1566736549139, 49.40858535468578, 43.88479895889759, 46.71025514602661, 55.17872013151646, 48.71129237115383, 50.26621073484421, 54.63124930858612, 56.968427896499634, 53.87114569544792, 59.84865814447403, 53.70514780282974, 52.18820460140705, 51.30928136408329, 52.37077720463276, 62.69865341484547, 63.98097440600395, 35.79320915043354, 15.383059401065111, 16.80385921150446, 30.817368552088737, 47.40284778177738, 54.2837655544281, 59.93879310786724, 60.987457036972046, 57.84737393260002, 53.693478628993034, 47.87770450115204, 39.31408882141113, 26.79082151502371, 14.803257063031197, 10.911311153322458, 17.61218223720789, 37.168150171637535, 26.694859564304352, 6.852498147636652, 3.659468684345484, 4.046117886900902, 4.7495071683079, 8.124175909906626, 18.78902468830347, 30.666813030838966, 42.50271052122116, 46.8362981826067, 54.016685485839844, 50.59227503836155, 47.941655069589615, 44.219500198960304, 41.57623663544655, 32.11996145546436, 17.318655587732792, 3.8344029849395156, 9.743944443762302, 21.38666409999132, 31.95683240890503, 26.881980523467064, 37.434907257556915, 47.35041059553623, 49.84612427651882, 53.341853097081184, 51.76191307604313, 54.65272195637226, 53.24319139122963, 55.24718105792999, 56.66399963200092, 43.60563933849335, 46.968474090099335, 56.19824722409248, 57.39882320165634, 58.5345708578825, 51.99476458132267, 57.87582680583, 68.31942960619926, 68.88271898031235, 73.06990429759026, 71.60490050911903, 61.68878920376301, 65.74025720357895, 62.3633898049593, 65.60158744454384, 57.858731523156166, 54.60791856050491, 59.959410801529884, 66.31593391299248, 62.37393043935299, 64.0453353524208, 62.330236583948135, 67.33799546957016, 58.820421919226646, 66.79814323782921, 60.20697131752968, 69.38335731625557, 35.07166586816311, 1.3805213780142367, 0.6589684181381017, 0.5477149598300457, 27.17450972646475, 72.52444356679916, 45.09521260857582, 51.41317918896675, 68.15837904810905, 51.38772055506706, 9.792754724621773, 20.53637232631445, 31.327424682676792, 22.550296559929848, 54.94912125170231, 43.05996581912041, 66.90286561846733, 50.011669993400574, 38.36839556694031, 48.576794788241386, 80.52150204777718, 38.993671014904976, 0.9305319492705166, 0.16646059200866148, 0.1183671219041571, 0.15494861989282072, 0.19151787244481966, 0.19429326726822183, 0.20989573473343626, 0.17721874988637865], [0.022273315662459936, 0.06754216985427774, 0.027429279034549836, 0.0008913696285617334, 0.0929018235183321, 0.07264035331900232, 0.026263912368449382, 0.051913218849222176, 0.036155816924292594, 0.08503656470566057, 0.15009326714789495, 0.0754249730380252, 1.3419061875902116, 49.60053585469723, 54.62580420076847, 42.36409395933151, 31.79953034967184, 39.04775731265545, 51.10862173140049, 29.18695203959942, 22.658205069601536, 68.6250852048397, 48.46495918929577, 5.550222052261233, 31.047412008047104, 51.58389262855053, 64.87833425402641, 55.21204814314842, 57.38643206655979, 12.285345923155546, 0.3287132363766432, 0.5113990616519004, 0.09040013275807723, 3.9268064266070724, 58.14464718103409, 66.75648227334023, 65.55161252617836, 61.59361571073532, 55.80755598843098, 51.96788862347603, 57.308760434389114, 64.90243256092072, 65.11938571929932, 64.43397849798203, 59.99174326658249, 57.85260625183582, 49.71976585686207, 51.15059047937393, 55.10780833661556, 55.59612773358822, 58.91132444143295, 59.25363287329674, 59.12040062248707, 58.24655011296272, 55.96967428922653, 50.35652428865433, 51.624527648091316, 56.84868112206459, 56.776078417897224, 55.54024413228035, 60.080217719078064, 55.176957026124, 50.68320795893669, 51.20279207825661, 49.39344696700573, 44.6205610781908, 39.92345072329044, 38.11037801206112, 46.90024875104427, 52.92472667992115, 37.47584246098995, 18.051940239965916, 8.247572388499975, 11.9021450355649, 24.722611494362354, 35.1959989964962, 45.647870153188705, 49.38989795744419, 49.50354985892773, 38.36786739528179, 27.33605805784464, 16.87893558293581, 8.208986409008503, 3.869937965646386, 3.8338071294128895, 4.169217506423593, 0.9623393299989402, 17.694295831024647, 12.52524795010686, 1.7643650248646736, 3.7903749849647284, 1.8150642793625593, 0.6301692884881049, 1.5965231624431908, 1.1130615673027933, 5.240390952676535, 14.057786464691162, 24.80810310691595, 36.467900946736336, 41.88311956822872, 46.42879284918308, 43.30204702913761, 36.21094733476639, 33.609755113720894, 20.424213744699955, 1.8306942656636238, 2.733444361947477, 6.8445090763270855, 14.575544781982899, 19.53630778938532, 21.614397279918194, 27.389443293213844, 40.28593227267265, 42.94615812599659, 42.0499724149704, 45.07470890879631, 46.618976444005966, 49.96087431907654, 51.75778269767761, 50.89892998337746, 39.3637939542532, 48.49910415709019, 58.34173880517483, 53.89406606554985, 53.36431369185448, 43.27691897749901, 40.55533401668072, 35.584775134921074, 38.68291608989239, 52.61144869029522, 51.09819509088993, 60.96016690135002, 58.51718679070473, 54.49796766042709, 48.61320063471794, 51.77162155508995, 55.562499538064, 60.41736602783203, 59.784965962171555, 55.75860321521759, 59.944637194275856, 60.374922305345535, 59.237046763300896, 62.51765392720699, 57.46090807020664, 59.66603994369507, 10.510780345648527, 0.2521922893356532, 0.9135414578486234, 2.168680429458618, 46.13946117460728, 38.604837879538536, 40.72618044912815, 62.86069571971893, 51.90896138548851, 32.499800473451614, 2.3830824997276068, 20.85572239011526, 17.092185840010643, 26.66384942829609, 32.088552340865135, 35.565190985798836, 41.408570632338524, 31.10518030822277, 32.47338809072971, 40.400154143571854, 60.53321801126003, 14.178988561034203, 0.38254022772889584, 0.166760983702261, 0.07442370450007729, 0.16375071398215368, 0.10070691641885787, 0.014797973817621823, 0.02749476614553714, 0.021337905309337657, 0.07794120989274234, 0.13524646928999573, 0.012741975206154166, 0.028539693375932984, 0.05018280506192241, 0.030898478034941945, 0.03194874501787126, 0.07540570688433945, 0.12323771836236119, 0.09444712341064587, 0.06187428785779048, 0.11897891876287758, 0.9576272859703749, 56.9497898966074, 64.31332737207413, 45.006703957915306, 39.76421266794205, 53.725765496492386, 37.153159976005554, 35.30797898769379, 38.52489396929741, 81.75252959132195, 47.00449615716934, 7.00335337780416, 32.88598895072937, 55.85823006927967, 70.61104863882065, 61.647633612155914, 64.44607704877853, 15.633731950074434, 0.24678112735273317, 1.5050750132650137, 0.33101609093137085, 5.4691871255636215, 59.98756729066372, 69.85396206378937, 66.97008401155472, 65.1484389603138, 56.21768698096275, 55.081065371632576, 59.39356416463852, 66.71286821365356, 67.64704048633575, 65.93953371047974, 63.68156187236309, 59.279536083340645, 55.64128831028938, 53.784248158335686, 58.53719271719456, 59.45756033062935, 61.13133251667023, 63.465376272797585, 61.43709070980549, 57.70469158887863, 56.84982866048813, 51.07079096138477, 53.50886553525925, 60.30313275754452, 59.06419023871422, 57.4191977083683, 61.34331174194813, 55.56376487016678, 53.92865560948849, 55.22423028945923, 52.48287878930569, 48.6417219042778, 43.7146782875061, 43.81628103554249, 49.672017619013786, 59.07468527555466, 48.58142673969269, 20.81987701356411, 10.76111376285553, 11.309327445924282, 20.8884709328413, 41.1102220416069, 50.22789739072323, 57.18739494681358, 54.974724277853966, 48.14760781824589, 43.64515721797943, 35.24484917521477, 24.788655750453472, 11.970707606524229, 5.505390157923102, 5.000651367008686, 4.342417437583208, 19.27324790507555, 10.019078180193901, 3.6743363365530968, 2.8119806852191687, 1.3541315565817058, 2.7238004794344306, 1.2793767428956926, 4.508030125871301, 15.055946353822947, 27.27381929755211, 35.79957760870457, 44.96187776327133, 46.55567944049835, 48.793770745396614, 47.69818693399429, 44.3166533857584, 36.075636595487595, 15.009590741246939, 2.365105664357543, 3.48206190392375, 12.77314379811287, 20.063292011618614, 26.36536404490471, 25.52446536719799, 36.32705770432949, 45.91925539076328, 44.83362704515457, 45.807795971632004, 48.693357333540916, 49.4704270362854, 52.4018519371748, 56.580848693847656, 53.73120680451393, 43.52272018790245, 43.93207602202892, 53.8589483499527, 49.12007823586464, 53.06622348725796, 44.95985247194767, 44.84865143895149, 42.05107055604458, 46.08043894171715, 52.26337596774101, 55.046909004449844, 62.56101340055466, 63.14130686223507, 56.399233639240265, 50.77060326933861, 51.97224318981171, 58.6179193854332, 62.788203209638596, 61.759909987449646, 57.805435582995415, 59.22795385122299, 64.5143973827362, 64.59883645176888, 64.6518512070179, 60.01222796738148, 58.900890201330185, 10.731439255177975, 0.3839834377868101, 1.4859900623559952, 3.759822486899793, 53.51962275803089, 43.421630412340164, 46.903843358159065, 63.090230002999306, 54.94261600077152, 33.9312444627285, 4.28359754383564, 25.911157317459583, 23.47078386694193, 27.934115566313267, 33.11731293797493, 26.314906552433968, 50.4747511446476, 38.32106530666351, 31.609882526099682, 44.65029828250408, 68.70185628533363, 17.201013900339603, 0.21316401951480657, 0.08999095705803484, 0.10218203882686794, 0.11142367729917169, 0.05757279992394615, 0.034072534181177616, 0.007042513434498687, 0.11826437897980213, 0.16991027252515778, 0.28010645241010934, 0.07718453838606365, 0.15182904666289687, 0.3168546367669478, 0.18290943437023088, 0.15592729003401473, 0.1754486237769015, 0.25362991844303906, 0.202666622644756, 0.24640267656650394, 0.30191624304279685, 3.4028753405436873, 76.26809388399124, 70.71156844496727, 60.21430492401123, 38.41609060764313, 63.31924371421337, 66.22542276978493, 38.575913831591606, 31.807017847895622, 80.27766153216362, 49.031193405389786, 10.927403289824724, 38.4009750187397, 63.91708463430405, 77.80460223555565, 67.46790289878845, 71.10729441046715, 16.845092698931694, 0.7349477161187679, 1.8676177156157792, 0.26951520354487, 7.368288170546293, 65.84466800093651, 72.51866027712822, 72.60498404502869, 70.53839653730392, 60.36147102713585, 59.56538714468479, 62.37336806952953, 69.75858718156815, 70.0889490544796, 69.09847140312195, 65.64681261777878, 62.090241461992264, 56.03572994470596, 56.65479652583599, 60.185213685035706, 62.79133424162865, 65.23786336183548, 65.01636564731598, 64.1255946457386, 60.55750630795956, 57.39208236336708, 50.42171359062195, 53.84452052414417, 59.82058145105839, 60.370841324329376, 61.4636854827404, 65.22001951932907, 57.07738324999809, 57.00949229300022, 59.068028032779694, 58.7788787484169, 54.8469827324152, 47.34840050339699, 47.260838001966476, 50.83280213177204, 59.929244220256805, 55.516119226813316, 36.3192643225193, 27.33908459544182, 33.32633972167969, 46.477597430348396, 51.85186944901943, 53.26240696012974, 58.03390592336655, 60.24016633629799, 55.83749458193779, 54.401430040597916, 50.07852740585804, 38.474546670913696, 25.903552025556564, 15.609796084463596, 14.904633723199368, 26.155594401061535, 40.356619879603386, 38.21934476494789, 18.711208663880825, 9.960288684815168, 7.846486335620284, 9.143141582608223, 10.896036922931671, 17.78733193874359, 29.516852237284184, 41.66425131261349, 46.40247546136379, 53.691567331552505, 55.67170187830925, 51.721924021840096, 52.771089524030685, 46.03835619986057, 41.470913887023926, 30.86230494081974, 10.021882429718971, 4.412433905526996, 14.898498952388763, 26.54790624976158, 35.430336222052574, 35.48949904739857, 45.947480276227, 51.35397456586361, 49.800720512866974, 48.41168984770775, 54.405039846897125, 55.60085467994213, 56.44692488014698, 58.73941786587238, 54.893697425723076, 45.4601526260376, 48.45490112900734, 54.70701344311237, 49.41916398704052, 50.64730368554592, 46.11534006893635, 48.839596286416054, 48.056055530905724, 47.32078738510609, 52.61094331741333, 55.902353301644325, 66.78061857819557, 64.75282698869705, 61.77896596491337, 55.37637412548065, 56.43183968961239, 62.242434695363045, 65.5889493227005, 64.76002380251884, 60.284152776002884, 62.48508967459202, 66.08638823032379, 66.09510496258736, 67.77952417731285, 63.44330705702305, 63.869799971580505, 17.331685088574886, 0.34284518274944276, 2.4480856116861105, 3.752194158732891, 54.41663682460785, 49.185776710510254, 49.749544858932495, 71.79201006889343, 59.610323533415794, 43.37087653577328, 7.387446267530322, 27.813454940915108, 24.112369939684868, 38.48206266760826, 43.82747523486614, 47.10615210235119, 64.40245538949966, 43.45194138586521, 45.58977127075195, 52.186578288674355, 82.47857183218002, 28.84227253496647, 0.8562121528666466, 0.25026347720995545, 0.20576976472511888, 0.16330880956957117, 0.17684454418485984, 0.15006402652943507, 0.1703309069853276, 0.1987340414780192], [0.05637622038193513, 0.0361338382208487, 0.08995856973342597, 0.047226255701389164, 0.1369061489822343, 0.04263804272341076, 0.0668670010054484, 0.024218121070589405, 0.1271137478761375, 0.04693594979471527, 0.04630365481716581, 0.11577057724935003, 0.13489788252627477, 35.75944796204567, 60.77216438949108, 43.82199212908745, 27.84237328916788, 36.49557866156101, 46.405454501509666, 44.599468410015106, 18.96413829177618, 34.929519295692444, 28.47154162824154, 7.119886949658394, 44.19683821499348, 61.47685557603836, 56.82458661496639, 53.690674379467964, 56.02691061794758, 21.649623289704323, 0.5013372609391809, 0.13331397611182183, 0.015825660957489163, 1.899354918859899, 41.151651218533516, 64.24637496471405, 63.55934523046017, 62.47563578188419, 56.70211918652058, 54.7437384724617, 60.03669485449791, 62.118128165602684, 65.35691097378731, 61.66397653520107, 60.21257981657982, 57.024870067834854, 53.44560272991657, 52.7151945233345, 56.90898008644581, 59.386279955506325, 60.56294001638889, 61.81752249598503, 60.823970809578896, 58.96858736872673, 54.75324176251888, 54.56908464431763, 56.90742217004299, 58.6345548927784, 58.36224250495434, 54.15640018880367, 54.74075183272362, 55.36017179489136, 56.72552213072777, 50.5192581564188, 49.112167060375214, 40.75475111603737, 36.48291394114494, 35.87323285639286, 42.145883068442345, 51.22026354074478, 48.021678775548935, 33.63852337002754, 23.62712647765875, 32.007251903414726, 42.782367914915085, 47.53234103322029, 49.354571253061295, 49.69320148229599, 48.4789652377367, 38.03209841251373, 26.07678283005953, 15.311413295567036, 5.937149114906788, 4.165113726630807, 4.8305705934762955, 4.7721753269433975, 9.975446071475744, 25.20948126912117, 22.85599395632744, 5.908240266144276, 3.0121890921145678, 1.428396434057504, 2.5001803413033485, 1.648803607095033, 2.724646646529436, 1.7470539850182831, 13.300200216472149, 26.209830790758133, 34.51300844550133, 41.662697196006775, 48.98582763969898, 44.19078513979912, 40.05976460874081, 35.35649858415127, 31.451879404485226, 11.614748407155275, 3.6723910784348845, 7.10475948639214, 14.14876688271761, 22.79228277504444, 22.734641768038273, 23.68756603449583, 38.97589936852455, 40.504412949085236, 41.31071828305721, 43.66818778216839, 47.27822206914425, 47.94290520250797, 49.37461897730827, 56.955531388521194, 57.8794252127409, 39.98935058712959, 48.440241515636444, 57.98476316034794, 51.338030621409416, 51.20412200689316, 48.855589628219604, 55.25203339755535, 50.58714911341667, 50.53751237690449, 53.943824395537376, 57.10678227245808, 57.61578015983105, 55.38150765001774, 48.72566320002079, 50.92564254999161, 57.35990189015865, 61.02919779717922, 59.549200013279915, 55.12206897139549, 51.20909593999386, 59.664561823010445, 57.93416127562523, 62.474530041217804, 54.842966347932816, 33.170415088534355, 1.2307095481082797, 0.5013061501085758, 0.5525675369426608, 10.711928252130747, 54.99030344188213, 57.01731227338314, 62.40774862468243, 49.387329295277596, 57.084648460149765, 22.96561237424612, 4.0002514980733395, 25.555579997599125, 15.20488316193223, 28.473371230065823, 32.3803386837244, 36.4574933052063, 29.756932854652405, 31.680114157497883, 35.385308638215065, 45.217729434370995, 59.22110661864281, 6.75521339289844, 0.2787301840726286, 0.09513462675386108, 0.08135011681588367, 0.06357212507282384, 0.08220723058911972, 0.04442872632353101, 0.07145201903767884, 0.024441188397759106, 0.08946236237534322, 0.07218974351417273, 0.04036306694615632, 0.07320702759898268, 0.11321446479996666, 0.05997274594847113, 0.03951118160330225, 0.028518937360786367, 0.024250938840850722, 0.13399620278505608, 0.0270305360754719, 0.05440013715997338, 0.33837015100289136, 40.46849727630615, 72.47803285717964, 39.03000466525555, 24.38555248081684, 52.053216844797134, 42.8063940256834, 39.49224606156349, 28.861805386841297, 47.75036573410034, 33.3068011701107, 8.102088645100594, 47.835819348692894, 67.19241008162498, 66.66600152850151, 63.53720001876354, 62.537181079387665, 26.47379692643881, 0.44901843240950257, 0.9596969280391932, 0.13576151977758855, 2.816702644340694, 43.92950735986233, 67.40720495581627, 66.07140943408012, 66.69443160295486, 58.635368049144745, 56.12567491829395, 64.00537669658661, 64.46581318974495, 66.06561854481697, 63.80499824881554, 65.66109985113144, 61.07769459486008, 56.28579832613468, 56.564099192619324, 57.65224300324917, 62.592927888035774, 62.091529592871666, 63.77543583512306, 62.80605845153332, 61.25980742275715, 57.342016249895096, 57.93954938650131, 60.38509055972099, 60.1531396061182, 59.03196796774864, 56.291418224573135, 56.48691013455391, 57.400643303990364, 55.87792061269283, 54.256327226758, 54.37115326523781, 45.83491891622543, 42.71047957241535, 42.65079237520695, 46.96950763463974, 56.45205080509186, 53.51413585245609, 34.134978130459785, 19.392865486443043, 28.319211602211, 41.98050834238529, 51.53840146958828, 52.359222024679184, 53.7877781689167, 52.08060957491398, 49.13601458072662, 41.2619972974062, 29.41121980547905, 20.38340963423252, 9.979328513145447, 4.941717954352498, 6.84395763091743, 8.16055515781045, 30.042599625885487, 18.517143577337265, 4.216262781992555, 6.041577961295843, 4.934819899499416, 4.013156080618501, 3.0211684852838516, 4.258410595357418, 11.662826277315617, 24.143298380076885, 34.33251813054085, 43.74791130423546, 49.60230275988579, 49.68787416815758, 51.189576387405396, 45.479805171489716, 45.818936973810196, 29.53563652932644, 6.78590577095747, 2.5842344434931874, 8.500346224755049, 18.96467976272106, 28.506509251892567, 25.99774707108736, 31.9449732452631, 45.59585854411125, 44.81992118060589, 45.65648429095745, 45.07666200399399, 52.61043794453144, 50.02441830933094, 57.33211398124695, 55.58863453567028, 60.247948318719864, 44.156404584646225, 47.20770165324211, 56.836259588599205, 53.58095906674862, 50.30085347592831, 51.49311549961567, 54.13123793900013, 52.429153472185135, 50.49178563058376, 59.390816912055016, 59.07885365188122, 59.81577090919018, 57.51321226358414, 52.59963132441044, 53.803266137838364, 59.08231906592846, 60.82908533513546, 62.05502115190029, 57.11125083267689, 53.534631952643394, 59.955774396657944, 58.45386318862438, 61.02565258741379, 53.808205872774124, 30.493437834084034, 1.012495569884777, 1.4112607785500586, 0.7967438001651317, 15.363923627883196, 61.8022321164608, 58.12502883374691, 64.16816756129265, 53.484227657318115, 62.83424153923988, 23.800009600818157, 5.37381081841886, 32.20608003437519, 20.840331315994263, 30.76130636036396, 30.559767074882984, 28.038034290075302, 42.25750207901001, 37.06586346030235, 33.35295349359512, 54.53574523329735, 68.85311096906662, 9.432159774005413, 0.14434337412239984, 0.27355922560673207, 0.04181570970104076, 0.11278698773821816, 0.061701252416241914, 0.04336949234129861, 0.05556755029829219, 0.032789865508675575, 0.19761883100727573, 0.15874835662543774, 0.12283177842618898, 0.13130925712175667, 0.3489730367437005, 0.11364096964825876, 0.18539231910835952, 0.1333659264491871, 0.2663453127024695, 0.20898341259453446, 0.24724673596210778, 0.270812715170905, 0.44861348695121706, 57.17222236096859, 79.70388472080231, 60.862413346767426, 34.92935590445995, 57.37067811191082, 66.32047846913338, 56.1909706145525, 27.30544500052929, 46.90754435956478, 36.55334696173668, 12.108600307255983, 50.694580748677254, 71.55568554997444, 68.95766615867615, 68.17360863089561, 66.93599224090576, 31.075161918997765, 1.5004866407252848, 1.7001215158961713, 0.2131769180414267, 3.672363292425871, 51.657806262373924, 68.60997721552849, 73.6053715646267, 69.71143931150436, 63.427397310733795, 59.468480944633484, 65.72948858141899, 66.53180032968521, 69.17420893907547, 64.44837972521782, 67.88352459669113, 65.11339724063873, 59.26515765488148, 55.63224099576473, 62.08535112440586, 65.27756363153458, 65.68731844425201, 68.19585263729095, 64.6665108203888, 63.14201362431049, 59.72259230911732, 58.256463780999184, 62.784300819039345, 63.502754867076874, 64.83891516923904, 56.33963763713837, 59.48328875005245, 61.82279661297798, 61.80756703019142, 55.87968751788139, 57.76814438402653, 51.120469495654106, 46.272058859467506, 49.278594329953194, 48.10576066374779, 53.51076543331146, 54.781052470207214, 46.61404810845852, 40.413103848695755, 47.63544850051403, 50.724105164408684, 51.563848704099655, 54.4476355612278, 57.690579146146774, 58.60221862792969, 54.8721107840538, 50.33279836177826, 44.436392560601234, 35.98395511507988, 29.98003788292408, 24.285695739090443, 23.101637475192547, 35.27002662420273, 47.30875343084335, 46.61759331822395, 31.760854125022888, 18.478355258703232, 13.59988633543253, 14.435871876776218, 18.522544987499714, 23.514057844877243, 31.215055212378502, 39.7711168974638, 48.586081489920616, 54.14615213871002, 54.53589342534542, 52.50367507338524, 52.70257920026779, 49.43093955516815, 43.75586047768593, 40.433736741542816, 25.473565198481083, 9.009269066154957, 15.564748551696539, 28.604418598115444, 37.06704139709473, 32.864048928022385, 41.74828760325909, 48.14859576523304, 49.329059422016144, 48.971475809812546, 48.71811680495739, 54.54166151583195, 53.46299059689045, 58.743989020586014, 62.18954913318157, 61.52200475335121, 48.607090562582016, 47.7457831799984, 54.92988668382168, 51.52809262275696, 50.64212076365948, 50.23631773889065, 56.59039378166199, 53.869279995560646, 56.59670144319534, 59.15888495743275, 62.22769148647785, 63.885561525821686, 60.654636695981026, 54.66054193675518, 56.35573737323284, 60.56520849466324, 64.47492510080338, 64.48620289564133, 60.23773066699505, 53.97506631910801, 62.53700628876686, 59.45158705115318, 65.44026330113411, 55.77432297170162, 42.390293553471565, 2.3904664535075426, 1.1978415492922068, 0.9961695084348321, 15.283526591956615, 65.7333491742611, 67.25813135504723, 70.97177848219872, 58.689245358109474, 66.06966152787209, 30.324681289494038, 7.81113350763917, 33.27443830668926, 23.210727721452713, 37.539576441049576, 41.83363102376461, 48.630345314741135, 49.76589158177376, 41.78426407277584, 48.181331008672714, 57.7806381136179, 83.28259348869324, 17.258797399699688, 0.4321506031556055, 0.41910337982699275, 0.1806946430588141, 0.19473756139632314, 0.15908877976471558, 0.1895813865121454, 0.1878830706118606, 0.1516212898422964], [0.035548565720091574, 0.04234850865032058, 0.1017374404182192, 0.11830310424556956, 0.028291439411987085, 0.030933982379792724, 0.041879475029418245, 0.07885293831350282, 0.1834985363529995, 0.11381663600332104, 0.09800570667721331, 0.26610550994519144, 0.38509303762111813, 26.829955615103245, 60.03997787833214, 50.357584431767464, 44.54686403274536, 34.23773981630802, 38.43863859772682, 50.060360580682755, 29.697384350001812, 27.963225804269314, 33.97145390510559, 3.742959941737354, 27.514093704521656, 63.52182984352112, 51.12178422510624, 47.89665788412094, 62.69001267850399, 34.81090486049652, 0.30940748169086874, 0.5711296596564353, 1.127471225336194, 0.8934142941143364, 35.03227338194847, 77.0052619278431, 64.49485123157501, 62.63689912855625, 57.54641108214855, 56.94486156105995, 58.63765932619572, 64.04273629188538, 65.86843952536583, 63.864396661520004, 61.91757872700691, 54.48375262320042, 52.08856634795666, 55.37899598479271, 58.511722683906555, 58.640581369400024, 62.15927995741367, 60.771111845970154, 62.40882396697998, 58.44658277928829, 56.89038008451462, 59.63711589574814, 56.59088395535946, 58.24683129787445, 55.75476922094822, 53.34668643772602, 56.8678966909647, 53.353028297424316, 55.910541862249374, 52.08429157733917, 47.62792490422726, 42.92729213833809, 37.3471699655056, 34.69621941447258, 35.628586784005165, 45.25363750755787, 53.17565381526947, 48.88856425881386, 43.38502697646618, 47.83221714198589, 49.02330882847309, 46.92691572010517, 47.12309919297695, 48.84484760463238, 46.62624925374985, 36.667340844869614, 24.32231057435274, 14.117383416742086, 8.069595638662577, 5.120969535782933, 3.913288414478302, 3.364978786557913, 9.636874739080667, 28.11403401196003, 39.5767193287611, 15.277946591377258, 1.7626709095202386, 2.9653912782669067, 2.6427731523290277, 3.933317377232015, 2.8358272556215525, 6.014916691929102, 12.587481960654259, 24.180002510547638, 34.384480342268944, 44.98245745897293, 47.51430720090866, 47.59044751524925, 42.166591957211494, 33.953347876667976, 31.008241809904575, 27.873845100402832, 14.80462783947587, 19.755597822368145, 25.91979805380106, 26.133160404860973, 21.174774169921875, 22.125994227826595, 33.39000150561333, 38.17071497440338, 42.03922659158707, 42.586245238780975, 45.93686744570732, 45.26324339210987, 50.79236090183258, 51.06208182871342, 58.18601556122303, 56.286033913493156, 49.66487780213356, 45.40257051587105, 46.83351673185825, 51.752561777830124, 52.134965658187866, 53.8071571290493, 51.552855893969536, 57.7344173938036, 58.178301975131035, 60.514629408717155, 54.36020605266094, 53.22423420846462, 48.597135096788406, 51.61296486854553, 57.33225837349892, 59.48501765727997, 58.222558200359344, 51.8878573179245, 56.95205457508564, 56.166298538446426, 56.28899395465851, 52.52047397196293, 40.593198984861374, 8.545859232544899, 0.06148293483420275, 0.2930210391059518, 0.9475237468723208, 26.45276315510273, 57.661620900034904, 47.59021952748299, 52.872851863503456, 51.3140045106411, 56.01794309914112, 13.359707873314619, 9.042780417948961, 29.30627703666687, 10.489979311823845, 31.70493822544813, 33.66067998111248, 40.291362181305885, 28.992316983640194, 23.62303599715233, 30.36895651370287, 55.169604420661926, 55.162293612957, 4.628141205757856, 0.012982803982595215, 0.09271959657780826, 0.06697525808704086, 0.03165874339174479, 0.08491952801705338, 0.0015637414503544278, 0.048737476172391325, 0.08197027767891996, 0.010318110689695459, 0.11842254549264908, 0.05140868088346906, 0.04034193800180219, 0.044937887869309634, 0.011669374216580763, 0.1394696458010003, 0.043715366555261426, 0.12369997988571413, 0.10081250919029117, 0.11791254903073423, 0.23014467005850747, 0.24383220355957747, 33.74742552638054, 69.469825476408, 57.522704154253006, 32.7500132471323, 43.490334525704384, 36.81535430252552, 42.9988195002079, 37.19571769237518, 33.62620823085308, 43.183782175183296, 4.547614976763725, 27.934387251734734, 65.70127129554749, 55.36163091659546, 52.96463593840599, 70.70668950676918, 42.891574054956436, 0.5319712171331048, 1.1013828939758241, 2.700958955101669, 0.6587734411004931, 38.6162144690752, 78.80350023508072, 68.23570489883423, 66.13262414932251, 60.77129043638706, 59.82098042964935, 62.672848999500275, 67.4332943558693, 67.87464827299118, 65.08632749319077, 64.96437683701515, 59.52505610883236, 56.939230263233185, 59.026268273591995, 61.532435193657875, 60.443884804844856, 62.58712559938431, 62.332653254270554, 62.63254076242447, 58.69189761579037, 58.14766801893711, 61.78541801869869, 58.78777787089348, 60.02711936831474, 57.938968017697334, 56.5024209022522, 55.578922256827354, 55.66089145839214, 58.034890070557594, 56.64223060011864, 52.1502598375082, 49.54671174287796, 40.52934721112251, 41.093639731407166, 42.742287665605545, 49.51660975813866, 57.88966566324234, 53.133681267499924, 42.41451345384121, 50.1160503923893, 53.08209143579006, 51.030368730425835, 50.29610753059387, 52.01860070228577, 52.22249776124954, 46.22649550437927, 39.248071163892746, 29.69812721014023, 20.582539848983288, 11.603620704263449, 5.980610232800245, 5.736390687525272, 17.865773029625416, 39.13465864956379, 33.392247185111046, 10.486271660774946, 3.6933790147304535, 2.904724208638072, 4.310460677370429, 1.5227339719422162, 6.493917088955641, 11.97984516620636, 22.624745965003967, 35.473889485001564, 42.34932795166969, 51.024950221180916, 52.65287026762962, 54.78049390017986, 47.1217692643404, 42.08977907896042, 38.403646275401115, 26.0936938226223, 11.213687527924776, 18.879171051084995, 31.91851146519184, 32.58138969540596, 26.161529682576656, 28.991737514734268, 38.820339515805244, 41.69457748532295, 44.97035130858421, 45.1578788459301, 49.27142031490803, 48.7847538292408, 54.07769501209259, 54.51273746788502, 59.15677987039089, 59.041437059640884, 51.715285778045654, 46.20188042521477, 47.994331642985344, 52.315763756632805, 53.977703377604485, 56.48061767220497, 57.624268904328346, 61.070019006729126, 61.74300089478493, 59.58454191684723, 56.30860470235348, 54.68644134700298, 51.417795941233635, 53.57428282499313, 59.82266753911972, 61.25582903623581, 60.53492791950703, 54.746485725045204, 56.66746124625206, 54.3786046653986, 56.7970684915781, 50.272905975580215, 40.355726927518845, 8.222003560513258, 0.02079528960166499, 0.4656851099571213, 2.323254947550595, 34.31486427783966, 64.60701361298561, 52.1152713149786, 57.89814680814743, 56.41995012760162, 59.2879032343626, 13.597554210573435, 12.994628213346004, 39.96363736689091, 13.41406300663948, 32.94539876282215, 28.949937857687473, 35.35372093319893, 46.051761880517006, 22.526466138660908, 33.9369897544384, 58.89536529779434, 60.61210177838802, 4.598104292526841, 0.08969921880634502, 0.07332731489441358, 0.038146676306496374, 0.0405219347885577, 0.16215417621424422, 0.15899019286734983, 0.03337847767397761, 0.11740358415408991, 0.1364033142453991, 0.18951313861180097, 0.24146596959326416, 0.23071875097230077, 0.19334863201947883, 0.15217006352031603, 0.30073964211624116, 0.17863092332845554, 0.2353525726357475, 0.36921368970070034, 0.2521735872142017, 0.36582053115125746, 0.4376384289935231, 45.21456800401211, 79.14867371320724, 71.18174761533737, 55.874766781926155, 51.27843461930752, 60.008067190647125, 62.400844395160675, 40.144701451063156, 39.0872447937727, 43.59631843864918, 7.273146500810981, 35.577521324157715, 70.92816442251205, 60.29434762895107, 58.7176488339901, 75.71699425578117, 45.48806592822075, 0.9407764370553195, 2.2839244455099106, 3.547579413279891, 1.3793860701844096, 45.476373955607414, 78.27789723873138, 71.3723985850811, 70.00599190592766, 63.91718342900276, 61.85947984457016, 65.90386882424355, 70.06572470068932, 71.41897648572922, 68.91064748167992, 67.74059906601906, 61.250250935554504, 58.94479684531689, 59.160727858543396, 62.6802434027195, 62.01543107628822, 67.05943241715431, 67.20190197229385, 66.55155166983604, 62.781823351979256, 59.184453785419464, 67.46218040585518, 61.754369884729385, 62.15250492095947, 60.57032682001591, 60.55534802377224, 59.55602444708347, 57.21629999577999, 62.579431012272835, 59.99753035604954, 56.290217489004135, 53.90196204185486, 46.88060000538826, 47.135243341326714, 43.964552879333496, 48.46646770834923, 53.33211801946163, 53.76457281410694, 51.78038768470287, 52.358785048127174, 53.202499374747276, 51.51426516473293, 52.35584020614624, 55.830715745687485, 57.83495619893074, 55.61117112636566, 52.259587571024895, 44.74452942609787, 42.56389103829861, 29.126204699277878, 23.395232520997524, 23.29064693301916, 38.769730031490326, 49.9199353158474, 52.95678175985813, 35.73593482375145, 26.48481633514166, 20.451154299080372, 21.175393536686897, 22.63190098106861, 27.265549041330814, 33.85608829557896, 43.29722888767719, 52.101599648594856, 51.96441940963268, 56.07840545475483, 54.45085398852825, 55.40269531309605, 48.40791665017605, 43.29101622104645, 38.860609754920006, 40.0309469550848, 25.344902202486992, 27.938445433974266, 39.60319630801678, 42.34833620488644, 36.77542984485626, 38.46401743590832, 44.02604877948761, 47.49655455350876, 48.337194845080376, 48.90757463872433, 54.22594025731087, 51.1474784463644, 56.454148292541504, 58.1210770457983, 60.55699333548546, 57.12615743279457, 52.816554084420204, 51.869511902332306, 51.136899814009666, 53.08081090450287, 54.61671508848667, 59.974640384316444, 59.388487637043, 61.543864980340004, 63.21446433663368, 63.351291194558144, 58.51449653506279, 60.159933641552925, 55.57679437100887, 55.9305439889431, 62.51480408012867, 65.59841081500053, 64.30895760655403, 55.20712360739708, 60.4533538967371, 57.29944333434105, 58.47776010632515, 50.126895010471344, 49.9418905377388, 15.003913845866919, 0.153948679799214, 1.269580393563956, 3.28082375228405, 34.748721197247505, 69.71251845359802, 57.29035422205925, 62.36850053071976, 60.725278705358505, 67.68842026591301, 21.074607744812965, 13.08823049068451, 39.28745985031128, 14.877782464027405, 44.083832278847694, 43.73021185398102, 57.991697788238525, 48.485227301716805, 31.763529181480408, 45.727430284023285, 65.63130185008049, 79.61414873600006, 8.42192793264985, 0.2439697235240601, 0.21543150331126526, 0.13457242108415812, 0.45338632771745324, 0.16968954296316952, 0.3651503421133384, 0.2592602069489658, 0.14331965561723337], [0.06832845305325463, 0.048195797426160425, 0.04651878487493377, 0.07122243565390818, 0.019284664704173338, 0.022719338994647842, 0.061579747998621315, 0.08738310949411243, 0.08883904738468118, 0.09208278934238479, 0.10676054080249742, 0.21123617218108848, 0.14693814504425973, 14.171925690025091, 68.64569529891014, 45.83651103079319, 43.17041829228401, 39.13731090724468, 49.34872716665268, 42.197488099336624, 36.038026213645935, 26.24801494181156, 41.80322885513306, 7.313842317089438, 10.43352859094739, 60.76128177344799, 74.75190684199333, 63.25275108218193, 44.271705597639084, 57.010164856910706, 9.622282572090626, 0.13151210092473775, 0.5542425345629454, 0.05803424137411639, 14.54019907861948, 69.72746685147285, 59.49526950716972, 62.8583550453186, 56.90841771662235, 60.60404621064663, 61.08600094914436, 59.98868443071842, 60.666298270225525, 62.97134958207607, 58.48021477460861, 59.67724934220314, 57.360316067934036, 59.09243032336235, 59.79783587157726, 63.25845077633858, 60.671838372945786, 59.522343054413795, 58.37519980967045, 61.08829602599144, 59.55854371190071, 59.33067373931408, 56.45921342074871, 55.19035130739212, 52.90045738220215, 53.6738982796669, 54.87103924155235, 53.652026653289795, 54.57281984388828, 53.12290504574776, 48.09735931456089, 40.46369433403015, 34.86738882958889, 36.03201113641262, 39.65606287121773, 43.09456676244736, 46.606585308909416, 49.09494638442993, 46.568081974983215, 48.05610492825508, 51.10445715487003, 50.74825666844845, 47.72350497543812, 51.99492037296295, 44.95718501508236, 34.17578034102917, 21.653362289071083, 13.090323228389025, 8.031170200556517, 7.7254238817840815, 4.922129530459642, 4.7098249476403, 9.879499319940805, 25.07648080587387, 38.37624594569206, 22.31856219470501, 5.242787674069405, 4.200110323727131, 5.558048207312822, 5.767125338315964, 4.637938505038619, 6.972257271409035, 12.61310588568449, 22.013666555285454, 32.106164395809174, 41.25440530478954, 46.85624711215496, 49.47201915085316, 44.44812253117561, 36.35603494942188, 29.1163195297122, 32.61672019958496, 31.000438928604126, 28.409699946641922, 28.81844401359558, 26.05470221489668, 23.865974061191082, 24.920525774359703, 32.74865671992302, 35.97883298993111, 42.67470449209213, 43.88456717133522, 45.8027308434248, 47.190408781170845, 50.21391414105892, 51.94592960178852, 54.12304937839508, 58.841601982712746, 46.618691459298134, 44.90906059741974, 58.916351571679115, 57.63270065188408, 60.336950942873955, 58.65271031856537, 59.12641569972038, 56.126533672213554, 57.161123156547546, 54.574803337454796, 55.19043110311031, 50.215358063578606, 52.61035814881325, 52.87904553115368, 60.15505090355873, 54.888620898127556, 62.69640013575554, 55.11792339384556, 50.32269090414047, 51.376043781638145, 55.785327181220055, 47.37067490816116, 19.818074069917202, 1.2690559029579163, 0.2033952929195948, 1.646471838466823, 6.008812794461846, 54.46313872933388, 51.4619305729866, 55.06254896521568, 55.87513156235218, 51.11135758459568, 46.97913631796837, 5.316072441637516, 14.822206646203995, 16.773196756839752, 18.91126222908497, 34.586545899510384, 34.534108713269234, 40.155736058950424, 22.907114513218403, 39.13670673966408, 40.63114374876022, 56.43190048635006, 48.01820196211338, 1.4392916369251907, 0.097352972952649, 0.07582122794701718, 0.012816697417292744, 0.02258773394714808, 0.030788525145908352, 0.02145356160326628, 0.058369680991745554, 0.025209951345459558, 0.0461260477459291, 0.08315864906762727, 0.04236904758727178, 0.04513278698141221, 0.016916345302888658, 0.024196732374548446, 0.08197844872483984, 0.09152675746008754, 0.11122772062662989, 0.02381730195338605, 0.05664471085765399, 0.15803717134986073, 0.04021739820018411, 15.036711785942316, 78.58298286795616, 52.70336575806141, 35.16855686903, 49.908896908164024, 51.73266604542732, 30.02015992999077, 41.94969579577446, 32.62239709496498, 57.02385552227497, 11.669066492468119, 12.228215988725424, 67.95105457305908, 77.49804988503456, 65.02262771129608, 48.76552306115627, 63.08635041117668, 14.629523735493422, 0.36440112919081, 1.3287032023072243, 0.14645263203419745, 15.700163785368204, 70.60233950614929, 63.90809431672096, 65.4699245095253, 61.79647922515869, 62.37321227788925, 66.86674475669861, 64.14029225707054, 62.92344555258751, 65.39503812789917, 63.911141753196716, 61.47857308387756, 59.52951326966286, 61.639840230345726, 61.206287294626236, 62.64692299067974, 62.70628720521927, 61.47168405354023, 59.91679988801479, 63.415066972374916, 60.489942133426666, 61.63373775780201, 59.349554926157, 57.963921278715134, 55.04571966826916, 56.23880244791508, 56.6069570928812, 55.55251747369766, 57.196066081523895, 57.26054102182388, 51.34490065276623, 44.76025678217411, 41.46945856511593, 39.554984495043755, 43.90382453799248, 47.16467276215553, 54.8693673312664, 56.73608556389809, 54.27238516509533, 54.05991196632385, 54.980108588933945, 53.04437845945358, 50.56075192987919, 54.71026986837387, 51.83747962117195, 48.904382809996605, 38.154117465019226, 29.412988610565662, 20.15530027449131, 11.607508845627308, 6.508681196719408, 7.807821035385132, 23.711100071668625, 40.8512507379055, 47.425874546170235, 25.506596826016903, 6.598125072196126, 6.557065425440669, 3.8430631952360272, 5.429303990676999, 8.241450916975737, 16.677312701940536, 24.6019546687603, 35.99764198064804, 46.15408279001713, 50.38825258612633, 54.31173965334892, 53.888066187500954, 50.325787737965584, 45.49167573451996, 37.22095213830471, 38.6666339635849, 30.843304060399532, 32.60216698050499, 36.97298884391785, 33.4136476367712, 33.18925827741623, 34.23282288014889, 36.58796690404415, 41.45675204694271, 45.68416580557823, 48.38542565703392, 50.156009048223495, 50.97263462841511, 52.468169778585434, 56.84220626950264, 54.734060391783714, 59.72914315760136, 50.58498702943325, 48.40838022530079, 59.68671843409538, 57.25044496357441, 61.143404468894005, 60.89990973472595, 60.89824542403221, 59.08581867814064, 59.157957807183266, 57.132309302687645, 58.66947501897812, 54.781386852264404, 54.4693323969841, 54.476008638739586, 62.13344134390354, 57.11697332561016, 65.09825125336647, 58.25681336224079, 53.84567566215992, 52.467637807130814, 54.5941025018692, 45.522150099277496, 20.471316017210484, 0.9974252223037183, 0.12930893164593726, 2.3781817127019167, 9.803978372365236, 62.09863901138306, 54.24484424293041, 64.56545904278755, 58.79996761679649, 57.87606619298458, 48.07774096727371, 5.89933686889708, 18.77631437033415, 22.559657357633114, 22.628030888736248, 35.873605236411095, 26.82071641087532, 40.87979480624199, 37.08275355398655, 34.69091109931469, 45.67612923681736, 63.35154578089714, 55.25489844381809, 1.1913795210421085, 0.03922397045243997, 0.04650137037970126, 0.047004349835333414, 0.0613720208639279, 0.08608008371083997, 0.037873395267524756, 0.1368106048903428, 0.027105658118671272, 0.14044224517419934, 0.16895493550691754, 0.13363413861952722, 0.13968175160698593, 0.2272504722350277, 0.13290898612467572, 0.2791616093600169, 0.19254745391663164, 0.24649998696986586, 0.13070238812360913, 0.22220560465939343, 0.3348756447667256, 0.2656778844539076, 27.249470204114914, 92.60999098420143, 63.36273618042469, 57.407479137182236, 52.05936871469021, 74.63763937354088, 55.911605805158615, 46.070601269602776, 34.857729747891426, 54.91803511977196, 11.550199370831251, 17.605505995452404, 68.46715047955513, 88.58724564313889, 69.08792316913605, 56.46522469818592, 66.53996989130974, 15.055931154638529, 1.0776307247579098, 3.3680573338642716, 0.11019260273315012, 22.273221127688885, 76.1982536315918, 63.280048817396164, 71.63340657949448, 64.46813866496086, 67.12393775582314, 70.46809270977974, 68.18297892808914, 65.46909615397453, 68.46586614847183, 65.48583805561066, 65.38711175322533, 62.94237993657589, 62.92619280517101, 64.04074519872665, 67.0624266564846, 66.63868859410286, 63.864449858665466, 62.772004678845406, 64.08650234341621, 63.26912820339203, 65.06173521280289, 62.693584486842155, 59.57167200744152, 59.0896450728178, 56.82392165064812, 58.93604211509228, 59.93157349526882, 61.15366771817207, 62.077705934643745, 54.810964465141296, 50.27986720204353, 47.21325695514679, 46.07201099395752, 49.21217009425163, 46.27131789922714, 53.40844452381134, 53.404675126075745, 52.206515818834305, 53.410059437155724, 55.278669968247414, 54.32871334254742, 49.4090261310339, 59.956032782793045, 58.77496875822544, 57.48056821525097, 49.11268763244152, 42.51395411789417, 36.7750308662653, 28.48311960697174, 22.447958551347256, 24.288047812879086, 38.012248277664185, 49.06848460435867, 56.748244911432266, 45.64350798726082, 38.96483056247234, 35.11683024466038, 34.50240321457386, 35.722601339221, 32.791066244244576, 36.96756653487682, 42.046111822128296, 52.079355642199516, 57.269041165709496, 56.10088884830475, 56.420835480093956, 57.24146984517574, 53.63053120672703, 45.21831460297108, 39.73560780286789, 39.18921232223511, 40.10680228471756, 35.21822400391102, 41.63937404751778, 40.550538673996925, 43.37496131658554, 43.321368992328644, 45.57678356766701, 46.99471928179264, 48.51934567093849, 52.05114595592022, 52.038526833057404, 53.242287039756775, 55.68688966333866, 57.58595936000347, 56.87533289194107, 59.06067542731762, 51.35978825390339, 48.640232384204865, 61.10954448580742, 60.33430628478527, 63.08393374085426, 62.0744951069355, 65.94885841012001, 64.5159325003624, 64.03395876288414, 59.72256191074848, 61.400035098195076, 57.96095363795757, 59.85495060682297, 58.719028159976006, 66.73369869589806, 59.33468632400036, 67.77633234858513, 59.234508499503136, 52.289001792669296, 51.714848801493645, 57.466843351721764, 49.05150331556797, 31.385025791823864, 2.40516216494143, 0.24640582327265292, 4.016026351600885, 7.491376865655184, 64.64212372899055, 62.66604736447334, 65.83356499671936, 66.35048925876617, 60.91904930770397, 54.5544858276844, 10.167289227247238, 19.250690415501595, 27.312421426177025, 28.478603549301624, 47.58800804615021, 45.36820136010647, 60.70659890770912, 38.148755952715874, 49.36269901692867, 53.51570896804333, 68.00597682595253, 72.06629455089569, 3.556263134814799, 0.30054683214984834, 0.1728401379659772, 0.12415397388394922, 0.1442071158089675, 0.12326928190304898, 0.11871826907736249, 0.2953041228465736, 0.14512381661916152], [0.03950105128751602, 0.036627540830522776, 0.024607538944110274, 0.02892208311095601, 0.1099269361293409, 0.05711545883968938, 0.06296416511759162, 0.11472440135548823, 0.10067751252790913, 0.07872629823395982, 0.050035670574288815, 0.12364294583676383, 0.16639100824249908, 3.448193846270442, 61.806909665465355, 49.547684490680695, 35.17157770693302, 36.739647164940834, 49.89655137062073, 46.70456305146217, 42.02957130968571, 30.710628479719162, 21.58098567277193, 15.392477195709944, 5.5970673635602, 34.29029479622841, 66.13744229078293, 89.05153512954712, 66.61658138036728, 57.89574533700943, 43.913521617650986, 1.5303080342710018, 3.762614862062037, 0.5982628755737096, 3.103629997931421, 35.605750009417534, 66.34037420153618, 63.42554681003094, 60.63354782760143, 60.36035008728504, 59.36078332364559, 62.274333983659744, 61.09642758965492, 61.04519493877888, 61.007478162646294, 59.60112802684307, 58.43234494328499, 61.34648457169533, 62.52364240586758, 61.14166796207428, 61.15581840276718, 61.68184317648411, 61.5191663056612, 58.85968521237373, 58.10238964855671, 55.51557585597038, 56.54945857822895, 52.60366290807724, 50.266997292637825, 50.418487563729286, 55.21512217819691, 52.81511016190052, 53.1557010859251, 46.79580755531788, 44.97236520051956, 39.53114077448845, 36.56552530825138, 38.43071222305298, 37.66295962035656, 42.597941011190414, 45.59176616370678, 41.98770135641098, 41.80799759924412, 48.144928961992264, 51.38321399688721, 52.59892076253891, 49.33242604136467, 48.75965237617493, 38.30761022865772, 26.072990633547306, 16.08613282442093, 10.812539253383875, 10.266418308019638, 6.813955390825868, 5.574110895395279, 7.644444527104497, 13.630987666547298, 28.972903825342655, 39.16743189096451, 28.621422685682774, 13.48048534244299, 13.119438216090202, 14.83903119340539, 14.825858250260353, 10.906470213085413, 11.644766796380281, 13.517754692584276, 20.449945963919163, 27.554447539150715, 37.71948538720608, 46.38976514339447, 48.46993692219257, 48.545682057738304, 38.27623911201954, 37.45820380747318, 33.19332405924797, 31.52255181223154, 27.788003906607628, 21.41815111041069, 26.434208750724792, 29.352140575647354, 30.89191485196352, 34.159255027770996, 38.408954590559006, 42.32323095202446, 40.88012918829918, 46.943486630916595, 48.01428437232971, 52.01344817876816, 51.62793606519699, 56.50218911468983, 48.05068641901016, 53.15888911485672, 58.157327100634575, 57.45328187942505, 55.23665942251682, 51.349752992391586, 52.66704350709915, 53.345189318060875, 55.191255658864975, 54.941795244812965, 56.16604395210743, 56.52114249765873, 51.05626814067364, 49.007216691970825, 52.67157286405563, 55.7092210650444, 61.60239703953266, 59.29002732038498, 56.14814691245556, 54.9426805973053, 53.14053609967232, 53.273639157414436, 28.8374125957489, 7.31944321654737, 0.13217537314631045, 4.4897502567619085, 19.16882000863552, 44.86674606800079, 50.36144882440567, 50.065060928463936, 52.70640179514885, 46.27264402806759, 61.56621538102627, 23.04628014564514, 2.583945896476507, 23.093925788998604, 15.751081053167582, 23.458824008703232, 25.621563456952572, 33.639667108654976, 35.7084508985281, 33.34240525960922, 29.57618035376072, 28.817879743874073, 62.35454007983208, 31.52642760425806, 0.3020804951665923, 0.15394059038953856, 0.03326311081764288, 0.09066497557796538, 0.022558215023309458, 0.012684397534030722, 0.048771807923913, 0.10780926226289012, 0.04999490069167223, 0.013541053031076444, 0.060802979132859036, 0.043623581441352144, 0.03422462992602959, 0.05557893113291357, 0.01193443782540271, 0.04985913219570648, 0.15879984683124349, 0.12012852777843364, 0.036896576784783974, 0.03208617963537108, 0.1625629808404483, 0.273286530864425, 5.480020344257355, 68.81695210933685, 59.78595770895481, 35.10668858885765, 42.463405430316925, 60.97240224480629, 31.948571652173996, 44.9770313501358, 32.959036231040955, 36.91560432314873, 25.39123311638832, 5.981497960165143, 38.41810829937458, 67.89598032832146, 87.15979143977165, 72.87239849567413, 62.43505395948887, 53.55991579592228, 3.4254979016259313, 0.46946866787038743, 0.6951680069323629, 1.8838212336413562, 41.47554583847523, 67.31992363929749, 68.50427448749542, 62.37884737551212, 63.55488806962967, 62.980442494153976, 65.64663022756577, 64.88154888153076, 65.75759187340736, 66.15930631756783, 62.91009686887264, 61.12644977867603, 62.61441953480244, 63.59735459089279, 61.73751778900623, 61.97414629161358, 62.84156754612923, 63.188621923327446, 62.276408672332764, 60.81269681453705, 58.832186087965965, 56.68427534401417, 54.7398816794157, 53.474237993359566, 53.31896312534809, 57.35212370753288, 56.132966727018356, 56.34672425687313, 52.504864409565926, 48.98175045847893, 44.13128413259983, 40.15669360756874, 43.64034287631512, 42.531999349594116, 49.05129432678223, 51.962166130542755, 50.33936060965061, 49.07149784266949, 53.70227515697479, 55.200774148106575, 50.768809765577316, 50.63854515552521, 53.53167191147804, 49.95303153991699, 47.645065784454346, 36.564921140670776, 25.38052909076214, 19.369139559566975, 10.574476327747107, 9.659201391041279, 9.423184655606747, 23.32048673182726, 39.95314233005047, 48.73011656105518, 35.096702724695206, 9.296879433095455, 12.983798794448376, 9.644132349640131, 12.854027207940817, 12.6942134834826, 15.526573900133371, 24.846334755420685, 33.93349014222622, 43.395803198218346, 48.94538640975952, 54.18593980371952, 55.60540683567524, 52.52429656684399, 44.29532893002033, 42.51815289258957, 43.00973631441593, 41.04369141161442, 33.53756658732891, 31.200756579637527, 36.32546938955784, 37.81187742948532, 36.33963502943516, 39.36231583356857, 43.40380556881428, 46.278256326913834, 45.64088612794876, 51.13923288881779, 54.366665706038475, 53.33808749914169, 54.77499559521675, 58.14908914268017, 50.423681885004044, 51.824765503406525, 57.98784479498863, 57.56995841860771, 57.76407100260258, 54.73860874772072, 55.960604175925255, 56.88086159527302, 59.744714722037315, 57.76013821363449, 58.41004014015198, 57.26917415857315, 55.82594320178032, 50.9991268068552, 56.08195826411247, 56.63651190698147, 63.90082910656929, 58.981316685676575, 61.73514671623707, 55.128072649240494, 56.980811432003975, 50.02246521413326, 31.46575815975666, 5.587341785430908, 0.12363758753053844, 8.89650346711278, 27.656014189124107, 55.25399029254913, 57.24882625043392, 59.01219762861729, 58.69680695235729, 52.61333718895912, 67.08286955952644, 17.355342619121075, 5.282797152176499, 29.229547753930092, 19.831987023353577, 26.737726964056492, 28.18261083215475, 25.980469398200512, 41.468607410788536, 42.35434748232365, 27.32664216309786, 36.2068397551775, 68.71500357985497, 35.52847735583782, 0.299520026310347, 0.1348774289363064, 0.039058805487002246, 0.08112146111670882, 0.05364909113268368, 0.02160143638320733, 0.03240302474296186, 0.0584751958376728, 0.07304247861611657, 0.13049703586148098, 0.09337336188764311, 0.17892968229716644, 0.14814789028605446, 0.16458843543659896, 0.19014341494766995, 0.20182205858873203, 0.31149885384365916, 0.22394084982806817, 0.25964882515836507, 0.10008605051552877, 0.49827498150989413, 0.3339826926821843, 11.798341255635023, 86.150793582201, 65.52063658833504, 50.762342512607574, 45.47317452728748, 79.76972758769989, 62.32024312019348, 53.05993102490902, 35.39422295987606, 35.30889093875885, 21.731298007071018, 9.332236535847187, 42.526596039533615, 71.95098593831062, 91.02482244372368, 74.65184301137924, 65.73991522192955, 54.71299432218075, 2.470686323940754, 13.519967123866081, 1.1002507922239602, 5.400774171575904, 50.90315155684948, 71.29438117146492, 72.96525031328201, 64.85327079892159, 67.97436252236366, 67.49119564890862, 67.77884781360626, 67.19960689544678, 69.41326171159744, 68.65463241934776, 65.27776882052422, 64.86729204654694, 66.90547987818718, 66.02758258581161, 66.0898308455944, 65.33534333109856, 68.08254271745682, 66.00597694516182, 64.40425649285316, 63.53203609585762, 60.565824061632156, 59.70662176609039, 55.52901193499565, 55.78721188008785, 56.20942622423172, 60.065056532621384, 59.317002072930336, 59.46475714445114, 55.27430400252342, 53.24247322976589, 46.62379078567028, 44.79550749063492, 49.236834570765495, 45.37187196314335, 51.84461943805218, 55.09299673140049, 53.9999283850193, 51.25545345246792, 57.89618991315365, 56.533461436629295, 54.62564080953598, 54.761981293559074, 58.12283635139465, 56.939872428774834, 55.6978140771389, 47.50903308391571, 40.261545181274414, 35.440713465213776, 27.48187143355608, 27.319202162325382, 31.877089887857437, 42.34705567359924, 51.745680347085, 51.229854226112366, 48.43147158622742, 33.79225172102451, 38.114086613059044, 43.55970740318298, 39.500001445412636, 39.86170403659344, 35.973566472530365, 41.672147288918495, 48.64122033119202, 50.77474884688854, 56.33480429649353, 58.437185883522034, 61.642325296998024, 55.94839923083782, 48.279586136341095, 47.5942625105381, 47.199231907725334, 40.80992795526981, 35.45776315033436, 37.819959595799446, 43.26800845563412, 45.89418053627014, 44.81030769646168, 44.872270971536636, 48.33176113665104, 49.7919087857008, 48.02574075758457, 53.17570701241493, 55.483790561556816, 57.22046837210655, 57.711451426148415, 60.31264744699001, 53.86175639927387, 53.82224231958389, 57.42978014051914, 59.903424605727196, 58.09523843228817, 57.76458017528057, 58.41444030404091, 59.6318493783474, 60.3976146876812, 59.616737589240074, 61.44099310040474, 60.95721445977688, 59.91396903991699, 54.21970099210739, 58.79907466471195, 58.9091357588768, 68.3180844783783, 64.89272028207779, 60.30111886560917, 56.98231615126133, 55.4008562117815, 53.78481052815914, 38.036756962537766, 11.52957882732153, 0.2882698690518737, 5.73789588175714, 22.55114771425724, 54.382294267416, 62.21485197544098, 61.12499065697193, 62.67352156341076, 57.07196094095707, 72.90211290121078, 32.122982293367386, 5.264911036938429, 33.83002549409866, 26.899459585547447, 34.43833485245705, 34.78597439825535, 47.02042110264301, 56.0232400149107, 45.54121367633343, 37.952960059046745, 46.68026715517044, 76.77759334445, 54.2342846095562, 0.8474684657994658, 0.1782662616460584, 0.07243724976433441, 0.1665190584026277, 0.16329332836903632, 0.1331990322796628, 0.25327098614070565, 0.2691038459306583, 0.21854824153706431], [0.012904438754048897, 0.01865689868282061, 0.050272783046239056, 0.004493397582336911, 0.01588452811120078, 0.0047737341265019495, 0.005067636666353792, 0.10904009192017838, 0.07780473635648377, 0.10809186467668042, 0.09772329722181894, 0.0676679341995623, 0.15762033668579534, 1.7180223553441465, 50.58360010385513, 63.122558668255806, 42.77998924255371, 40.07541596889496, 41.385281682014465, 49.455372244119644, 40.63775919377804, 34.42917354404926, 21.598278544843197, 10.659247878938913, 4.787640022113919, 18.1721505895257, 63.78594607114792, 70.46464249491692, 80.85505574941635, 47.31598064303398, 54.48689505457878, 35.08242689073086, 0.8541435794904828, 0.7600675744470209, 0.4812320350902155, 10.27972424402833, 55.935324132442474, 69.96798634529114, 66.56496495008469, 63.42029549181461, 63.147348538041115, 57.968655824661255, 56.46885730326176, 60.28598427772522, 62.033020332455635, 62.52290524542332, 63.63109678030014, 62.979883924126625, 61.41935706138611, 64.92127195000648, 63.827789425849915, 63.526533991098404, 61.876077353954315, 57.6029634475708, 60.081103071570396, 60.16330026090145, 51.73285223543644, 51.6105367988348, 48.99490535259247, 53.00189673900604, 51.190381944179535, 54.08452324569225, 51.28492847084999, 47.031467109918594, 46.00179836153984, 40.079854130744934, 38.78482282161713, 40.18129728734493, 43.47804978489876, 45.342446342110634, 42.74678662419319, 40.247843116521835, 43.06660786271095, 52.181399166584015, 53.0854694545269, 50.650848895311356, 48.081704154610634, 41.22285179793835, 28.85627668350935, 18.02343986928463, 14.845665637403727, 10.726711358875036, 9.155265782028437, 8.871568255126476, 7.464862363412976, 10.02727149054408, 17.679723612964153, 30.09409636259079, 45.5267820507288, 35.0189208984375, 28.818634003400803, 19.653550498187542, 26.020861230790615, 20.751727670431137, 21.130782030522823, 17.726330012083054, 15.42787704616785, 19.000851921737194, 20.83722498267889, 29.5329025760293, 39.4580364972353, 47.01639711856842, 47.67506517469883, 43.58736231923103, 41.73623085021973, 39.70629617571831, 27.241562828421593, 22.115229405462742, 21.210165470838547, 27.57372960448265, 36.08383655548096, 37.706140503287315, 37.79272645711899, 41.608990877866745, 44.89012621343136, 42.66931638121605, 46.219492480158806, 47.40816369652748, 49.79574277997017, 54.74737107753754, 53.521393463015556, 53.062765672802925, 53.36498245596886, 53.17814268171787, 53.223523646593094, 56.674350276589394, 57.87261977791786, 57.08029389381409, 55.094303861260414, 53.893796280026436, 53.074453845620155, 54.10504214465618, 53.93752433359623, 52.85630755126476, 52.51605100929737, 56.23756371438503, 57.62402191758156, 58.34908381104469, 59.66247573494911, 63.38707387447357, 46.783800199627876, 54.939591363072395, 31.30755364894867, 16.747878715395927, 0.5435879062861204, 7.6803981978446245, 40.15956625342369, 53.69402579963207, 54.41193267703056, 56.93871349096298, 54.15790870785713, 46.00726626813412, 55.800693556666374, 31.699874997138977, 1.266130416188389, 25.91257844120264, 40.852873250842094, 12.887779846787453, 27.979709319770336, 28.497589230537415, 40.109207555651665, 38.95697258412838, 31.11963853240013, 25.657925605773926, 34.458709359169006, 63.7940776348114, 16.886020302772522, 0.24862681893864647, 0.09838563433731906, 0.05001023717341013, 0.05623493401799351, 0.04389430207083933, 0.04747282313473988, 0.049512593759573065, 0.04843794165935833, 0.03599445546569768, 0.0379065841116244, 0.04639342128939461, 0.07055669208057225, 0.0025703651635922142, 0.09274547526729293, 0.08658539722091518, 0.07640971394721419, 0.1242699493013788, 0.04003146052127704, 0.060012309841113165, 0.05688996097887866, 0.09862156308372505, 0.10464969469467178, 2.2319501219317317, 56.02437235414982, 70.62262281775475, 43.11102747917175, 37.92501635849476, 59.73742291331291, 35.91568037867546, 33.18095192313194, 40.86466021835804, 22.33017437160015, 20.410675071179867, 6.20028262026608, 16.13469421863556, 72.27898433804512, 75.76159626245499, 81.18110105395317, 50.27194082736969, 62.82135643064976, 44.064529314637184, 4.0461326111108065, 1.423846771940589, 0.27568292571231723, 9.598131068050861, 57.58926898241043, 70.5111975967884, 68.83869454264641, 66.17196723818779, 67.71260976791382, 61.04245528578758, 62.22357630729675, 64.53490108251572, 66.02412477135658, 64.0358054637909, 64.30730849504471, 64.16774958372116, 63.244471326470375, 67.1020357310772, 63.78232106566429, 62.85416007041931, 63.7102959305048, 60.67655012011528, 59.4938787817955, 60.40313579142094, 56.02095253765583, 53.78745138645172, 53.01445126533508, 53.234714046120644, 55.629577338695526, 58.394954949617386, 53.66653047502041, 51.58946692943573, 50.761947333812714, 44.63329419493675, 42.863953337073326, 43.65055292844772, 47.5067076086998, 49.494741931557655, 49.67448368668556, 48.15803825855255, 50.971893668174744, 54.88286800682545, 56.16706229746342, 49.249962866306305, 48.955440670251846, 50.50901010632515, 47.855483293533325, 38.45429755747318, 31.606521606445312, 23.99090375751257, 16.702404655516148, 14.331071600317955, 12.389571480453014, 14.425497483462095, 25.88534340262413, 40.265002995729446, 50.40801152586937, 38.46342846751213, 21.840378753840923, 20.9230699762702, 24.70875173807144, 22.12034583091736, 23.361490331590176, 22.094678208231926, 23.94398007541895, 31.790597029030323, 39.24449935555458, 45.905279740691185, 50.753253400325775, 55.475548803806305, 53.575844541192055, 46.62132851779461, 46.124778762459755, 44.44453552365303, 37.767264023423195, 30.964608751237392, 29.485861100256443, 35.634837448596954, 42.32695855200291, 42.906921431422234, 41.25523366034031, 45.06250016391277, 48.00694316625595, 46.703457310795784, 50.1612413674593, 51.417237371206284, 51.46971635520458, 55.59059143066406, 54.54681023955345, 53.56813855469227, 54.7361046820879, 52.66181118786335, 54.43250857293606, 56.64753511548042, 60.338691249489784, 59.14682440459728, 57.40070030093193, 56.78975008428097, 58.94313633441925, 58.498594388365746, 57.24498085677624, 55.028704181313515, 55.879714116454124, 58.09739671647549, 61.49377226829529, 60.33017970621586, 63.856979459524155, 64.24100205302238, 50.653926730155945, 54.4069891422987, 33.94699841737747, 15.685154590755701, 0.6534763472154737, 12.64774102717638, 46.71596243977547, 55.68381182849407, 59.503040090203285, 65.42649284005165, 57.04294569790363, 52.539172768592834, 57.43175223469734, 23.353482261300087, 3.5237843776121736, 37.47417435050011, 43.808784037828445, 19.579112492501736, 30.49060508608818, 29.046076498925686, 29.34362333267927, 54.85050514340401, 32.32398770749569, 23.967115134000778, 41.77621230483055, 70.91948568820953, 19.700141698122025, 0.2747109200572595, 0.029939404303149786, 0.057773951630224474, 0.07497920945752412, 0.016818259355204646, 0.06472232780652121, 0.077946464298293, 0.04943954416376073, 0.06603256726521067, 0.15929888177197427, 0.183549907815177, 0.17242882488062605, 0.15139475668547675, 0.23683778825215995, 0.24195523787057027, 0.2745646279072389, 0.19583233312005177, 0.11893421920831315, 0.20583973440807313, 0.20966452604625374, 0.25158821081276983, 0.24786714173387736, 4.2234876193106174, 78.71829360723495, 77.05811709165573, 60.37624083459377, 50.64545698463917, 65.64029976725578, 70.74192121624947, 51.23221009969711, 41.925107315182686, 28.015541397035122, 18.143127746880054, 9.629994258284569, 27.67865527421236, 75.80395638942719, 80.44613689184189, 82.0201264321804, 57.76292346417904, 74.16545391082764, 47.46381551027298, 2.1502385940402746, 2.7315152529627085, 0.43687885568942875, 20.416266471147537, 70.28818756341934, 71.49247214198112, 74.69514548778534, 68.63753333687782, 69.06063303351402, 63.35422843694687, 65.02885177731514, 65.09053766727448, 68.28253358602524, 66.14345356822014, 69.4536991417408, 66.69790461659431, 66.94533213973045, 70.59213325381279, 66.00194156169891, 66.50869756937027, 68.60555425286293, 62.79049068689346, 65.53735569119453, 63.224233612418175, 59.00156959891319, 55.13792932033539, 54.84967678785324, 56.41922816634178, 57.855668887495995, 61.86958730220795, 56.595109328627586, 53.58151763677597, 53.86335611343384, 47.811500653624535, 47.99009867012501, 47.6676631718874, 51.45989768207073, 54.388738721609116, 51.447278559207916, 52.03191518783569, 53.98312948644161, 59.95611257851124, 57.60237067937851, 51.2756759673357, 54.79639604687691, 55.49686186015606, 54.02570620179176, 45.98390892148018, 41.26368820667267, 38.3629846572876, 33.38004603981972, 33.05413372814655, 32.99907088279724, 38.171558529138565, 44.82583366334438, 50.36931060254574, 56.67428947985172, 46.28106437623501, 39.80145446956158, 33.95380765199661, 49.87423896789551, 43.72010059654713, 46.27271242439747, 39.943012073636055, 38.85294556617737, 45.46489857137203, 48.821889236569405, 53.30225922167301, 55.45260563492775, 60.069715082645416, 55.765321254730225, 49.29809108376503, 50.236838310956955, 52.38019309937954, 45.39694681763649, 39.69322107732296, 40.01561097800732, 43.124680146574974, 49.35062326490879, 48.58499474823475, 48.84805843234062, 49.83520366251469, 51.457002237439156, 47.44240365922451, 52.35542222857475, 53.84105511009693, 55.794066712260246, 56.93697698414326, 58.07807855308056, 53.88984069228172, 55.98368413746357, 55.82296036183834, 57.5727778673172, 59.45523105561733, 62.30390779674053, 62.91178397834301, 58.84858600795269, 62.211580350995064, 63.00912715494633, 62.03501522541046, 61.89608708024025, 57.409014254808426, 57.64476880431175, 61.948056891560555, 65.03408029675484, 63.73645752668381, 62.80424974858761, 65.77755600214005, 48.13462011516094, 56.764492839574814, 38.206167072057724, 26.32378287613392, 0.7998956122901291, 8.723937626928091, 46.29669673740864, 60.38120336830616, 65.08484557271004, 65.61508432030678, 64.47857290506363, 60.271556451916695, 65.32805532217026, 40.51000624895096, 4.082570755854249, 32.01384074985981, 54.517760798335075, 20.64851000905037, 41.444391310214996, 37.47513189911842, 55.035452619194984, 64.12351995706558, 40.82973249256611, 36.90568685531616, 50.13571433722973, 80.49066290259361, 33.09555910527706, 0.5170209787320346, 0.21039013867266476, 0.24995156738441437, 0.2396890305681154, 0.09920574462739751, 0.2079472556943074, 0.09417105189641006, 0.2168979574344121, 0.10458656019181944], [0.008505808327754494, 0.028306968852120917, 0.06212950131157413, 0.052914524494553916, 0.029193660921009723, 0.023341136293311138, 0.108688499458367, 0.03468857612460852, 0.09077979324501939, 0.06783480610465631, 0.10133970863535069, 0.015376063256553607, 0.07082963915308937, 0.43796758633106947, 32.89309076964855, 73.84131610393524, 34.32182550430298, 33.23703691363335, 31.134433038532734, 48.24146278202534, 54.6705088019371, 29.531988725066185, 32.08000659942627, 39.20625060796738, 12.533362414687872, 5.194971514865756, 36.560494378209114, 62.6806765794754, 66.19406685233116, 41.96621350944042, 49.63398925960064, 65.84776103496552, 59.019983410835266, 31.537861190736294, 2.8489166032522917, 0.06791169260395691, 14.62306598201394, 55.80015018582344, 61.97103425860405, 63.1432219594717, 56.76066644489765, 59.612827599048615, 58.65280531346798, 63.615863397717476, 61.95060275495052, 63.17010551691055, 59.79914680123329, 63.41422341763973, 62.550677955150604, 63.46042513847351, 62.37774923443794, 61.59307613968849, 58.62486161291599, 55.77522732317448, 57.19261586666107, 54.93592455983162, 52.333231419324875, 47.62417830526829, 46.277203783392906, 48.12236197292805, 51.67524352669716, 48.8266845792532, 46.50420360267162, 47.325784116983414, 44.05386708676815, 40.61155579984188, 42.46802978217602, 42.62601390480995, 44.61557574570179, 47.700117230415344, 42.014657109975815, 39.951466619968414, 45.69765128195286, 51.40401788055897, 54.51100096106529, 50.28259165585041, 41.11456520855427, 31.255346350371838, 20.28316531330347, 14.126519076526165, 11.336936764419079, 12.162944041192532, 11.425908040255308, 9.334738701581955, 10.909419804811478, 16.353486478328705, 27.669699154794216, 37.743279710412025, 45.13328276574612, 40.88656224310398, 31.709594875574112, 27.101224958896637, 29.747150279581547, 28.331190459430218, 24.6189758554101, 18.257210925221443, 17.045547142624855, 17.36777175217867, 19.003228694200516, 22.737806998193264, 31.64374440908432, 40.61882100999355, 45.68946652114391, 44.04134675860405, 44.59687314927578, 42.318226620554924, 37.31427513062954, 30.102752298116684, 21.810613051056862, 25.668927915394306, 35.4129521548748, 39.37662586569786, 44.98735919594765, 46.838072687387466, 46.1808143556118, 46.0135131329298, 46.60620152950287, 48.52411441504955, 46.65567867457867, 43.88244688510895, 45.11193931102753, 49.29293856024742, 50.543880835175514, 54.7862733900547, 52.80644662678242, 56.55889347195625, 53.268106654286385, 53.746713772416115, 54.73426178097725, 52.664653435349464, 56.82445742189884, 57.65220120549202, 55.18665410578251, 52.19360411167145, 55.922366827726364, 52.31792204082012, 59.399830028414726, 60.88178850710392, 64.3987163901329, 56.04394510388374, 60.39531961083412, 32.05491654574871, 27.92228490114212, 1.8200697982683778, 5.768110910430551, 45.758858397603035, 49.47388105094433, 57.656209990382195, 53.371833488345146, 53.532181084156036, 42.901476323604584, 55.31550519168377, 29.093477055430412, 1.2170270760543644, 14.316071905195713, 67.12972864508629, 23.23138151317835, 13.53720584884286, 29.238367080688477, 31.988541707396507, 42.69033685326576, 33.61037828028202, 31.29931379109621, 34.491190016269684, 38.67466673254967, 63.78486692905426, 7.195645859465003, 0.2773831266677007, 0.061827384124626406, 0.04846082207222935, 0.024635838890390005, 0.04281447720131837, 0.08639819789095782, 0.08141711048665456, 0.024962910792964976, 0.05858969809196424, 0.03042369833565317, 0.04961997881764546, 0.04792211562744342, 0.05192678530875128, 0.015054433151817648, 0.05068981809017714, 0.08296937172417529, 0.05565228872001171, 0.07274783114553429, 0.04319049374316819, 0.12448696070350707, 0.03187661568517797, 0.08488688836223446, 0.38479175535030663, 40.04558376967907, 80.35554215312004, 41.25705376267433, 29.408632144331932, 44.34105567634106, 51.110384836792946, 35.59791103005409, 33.85607689619064, 31.46603934466839, 41.44038252532482, 24.163057319819927, 7.417949605733156, 34.20125797390938, 65.86571127176285, 72.4063915014267, 49.783587232232094, 54.025356620550156, 70.21672859787941, 66.90838292241096, 40.435416251420975, 5.364726455882192, 0.1648333144839853, 13.96227478981018, 56.59369960427284, 64.44959565997124, 66.06688007712364, 57.694310545921326, 62.05104656517506, 59.461724907159805, 69.74267363548279, 65.07123470306396, 66.66406363248825, 63.053535372018814, 64.9771137535572, 63.77225920557976, 65.4156482219696, 63.25482577085495, 62.89875067770481, 58.82962502539158, 58.709372878074646, 60.049450770020485, 57.873060554265976, 55.47402508556843, 51.970613077282906, 51.21658533811569, 50.839451774954796, 55.935384929180145, 51.92655824124813, 50.62941424548626, 50.99519781768322, 48.61752100288868, 44.00806054472923, 44.73916791379452, 47.44507871568203, 48.03655877709389, 50.657038763165474, 49.64442349970341, 46.35568097233772, 50.94944067299366, 54.617163464426994, 52.815345749258995, 50.068978518247604, 48.6579280346632, 49.05565269291401, 40.05415230989456, 31.839253418147564, 26.582708582282066, 20.342328138649464, 18.799903504550457, 16.159924864768982, 16.21095422655344, 20.007801689207554, 33.50035138428211, 40.65706595778465, 53.71416851878166, 41.543356999754906, 37.23402343690395, 31.51229426264763, 34.133348017930984, 34.68083783984184, 31.631737053394318, 27.80244503170252, 25.390309765934944, 29.316604882478714, 33.4716135263443, 39.174974486231804, 46.40878692269325, 53.39093506336212, 52.27097935974598, 47.45339646935463, 47.88593865931034, 49.16064105927944, 41.30472220480442, 35.9747976064682, 28.400306850671768, 34.03887748718262, 41.30773164331913, 44.213960096240044, 48.320403546094894, 50.37764735519886, 49.47872959077358, 50.11136904358864, 51.18133082985878, 53.77855226397514, 51.097959503531456, 46.60898678004742, 46.9967407733202, 51.491208001971245, 50.73168195784092, 55.21615192294121, 53.93028572201729, 55.78529678285122, 53.74720014631748, 53.475514724850655, 58.09910662472248, 54.308148846030235, 60.73121778666973, 59.00478422641754, 59.2162998765707, 55.5215073376894, 57.99067564308643, 55.853028148412704, 62.70466089248657, 62.87649907171726, 66.49330839514732, 58.78004148602486, 58.823568150401115, 34.07977469265461, 29.417381174862385, 1.7171695386059582, 9.848291594535112, 52.29714095592499, 54.14351508021355, 66.38926237821579, 61.4777447283268, 57.306111976504326, 51.05470262467861, 61.926052272319794, 25.7238045707345, 1.0659994301386178, 24.198773503303528, 68.53974938392639, 31.433100812137127, 20.439604818820953, 33.73630352318287, 28.003391548991203, 38.0755490809679, 46.955114006996155, 29.046034701168537, 35.07636621594429, 46.703920885920525, 71.80730044841766, 9.83720663934946, 0.2954750246135518, 0.038264336399151944, 0.11563617430510931, 0.08788465289399028, 0.044452441652538255, 0.03243531558837276, 0.07108833699021488, 0.06136462165159173, 0.01000511640086188, 0.16301442927215248, 0.1666168586234562, 0.10767592801130377, 0.16252933186478913, 0.09319928372860886, 0.1616884785471484, 0.2992880903184414, 0.16138554870849475, 0.14861277159070596, 0.26591017667669803, 0.22807308356277645, 0.07318304880755022, 0.17648801644099876, 0.5852131289429963, 58.53516362607479, 90.88287726044655, 53.59178468585014, 44.08664032816887, 48.837677389383316, 78.7227089703083, 71.28053471446037, 38.39027099311352, 40.80930098891258, 48.55209231376648, 21.253213360905647, 8.365280572324991, 49.09184955060482, 72.57157623767853, 78.53940680623055, 50.89840181171894, 60.85995867848396, 79.32098686695099, 76.51609137654305, 35.59891037642956, 3.301727855578065, 0.14337025524582714, 26.064729876816273, 64.41426515579224, 65.37582635879517, 67.26022884249687, 60.71480266749859, 62.06768587231636, 62.062286362051964, 73.45170021057129, 68.83695423603058, 68.52660968899727, 63.07049386203289, 67.53612443804741, 67.17528820037842, 67.45523437857628, 65.52305325865746, 66.36185824871063, 63.02832372486591, 60.5035188049078, 63.95746126770973, 59.566975459456444, 58.57937425374985, 53.3811391890049, 51.832741275429726, 54.29794259369373, 59.23295818269253, 55.41156783699989, 55.40673069655895, 56.1211721599102, 53.49397413432598, 48.03161904215813, 46.79015725851059, 51.67456716299057, 51.47606961429119, 55.53329810500145, 52.269569635391235, 53.26327331364155, 55.38034871220589, 58.567332699894905, 56.01299576461315, 54.962545931339264, 53.85927893221378, 53.945606499910355, 47.749081403017044, 41.86390399932861, 37.37897805869579, 37.057340517640114, 35.81969752907753, 34.39880557358265, 39.69971492886543, 43.962227404117584, 52.88363568484783, 50.74389450252056, 57.68891483545303, 50.84474869072437, 43.50952349603176, 37.36835762858391, 43.958739191293716, 52.52223327755928, 46.53558611869812, 44.4283863902092, 38.55519354343414, 41.24286912381649, 44.18812908232212, 44.90682631731033, 53.53303983807564, 59.80079211294651, 56.58595561981201, 52.10775911808014, 53.35889518260956, 53.813369795680046, 49.286706894636154, 40.878822058439255, 36.35309390723705, 38.91150042414665, 47.38344222307205, 47.45206654071808, 51.40171520411968, 52.76409409940243, 51.89766079187393, 51.877932250499725, 53.17837446928024, 55.743411630392075, 53.231157436966896, 48.950029760599136, 49.95832845568657, 55.6131736189127, 53.85691925883293, 55.1898193359375, 55.461512356996536, 59.86062750220299, 56.941966116428375, 57.38884113729, 59.83269900083542, 55.43144837021828, 63.5826113820076, 61.98536328971386, 61.02884441614151, 59.2743531614542, 61.84881001710892, 58.32848511636257, 64.54237148165703, 68.74407202005386, 66.19861900806427, 59.78230610489845, 64.38693702220917, 40.84940403699875, 39.95033048093319, 3.1666645780205727, 7.043751385062933, 52.35238239169121, 60.08294977247715, 67.81626060605049, 64.67074379324913, 65.1266585290432, 55.54537005722523, 65.81445962190628, 37.3995653539896, 3.470549234189093, 21.657494567334652, 77.49257817864418, 36.747014969587326, 21.764422729611397, 41.42597749829292, 41.64347402751446, 60.171450823545456, 55.49164094030857, 40.48362046480179, 50.36904461681843, 54.84703212976456, 86.44787684082985, 18.0800549313426, 0.4990488931071013, 0.22825390042271465, 0.14058399538043886, 0.3157828567782417, 0.07625887243193574, 0.18442023923853412, 0.1534578381688334, 0.14885245560435578, 0.1193031037109904], [0.06323624387732707, 0.07110792968887836, 0.0327790598385036, 0.0268028433129075, 0.026251830204273574, 0.021735087902925443, 0.009894289632939035, 0.031252079861587845, 0.03952463674067985, 0.075546566513367, 0.030834063327347394, 0.14479400619165972, 0.16639066685456783, 0.09390099919983186, 9.773481208831072, 67.44497492909431, 48.940914049744606, 51.358310133218765, 28.029385954141617, 29.170253835618496, 47.655929401516914, 40.529058426618576, 17.36640192568302, 27.1836444362998, 42.10201062262058, 7.974488642066717, 3.211498372256756, 25.70711776614189, 58.10894809663296, 65.10084271430969, 44.98902730643749, 46.98602914810181, 57.83618353307247, 68.30069661140442, 43.55423949658871, 2.534172129817307, 0.09680680421297438, 13.464510049670935, 46.59666404128075, 51.11084081232548, 52.09281072020531, 49.944432601332664, 44.04729723930359, 55.88924400508404, 61.59281775355339, 67.2840079665184, 65.78933537006378, 67.84253999590874, 63.442163318395615, 62.638548240065575, 61.30731627345085, 62.35281117260456, 58.451431319117546, 54.48002502322197, 56.15754380822182, 53.61749790608883, 49.61704596877098, 51.406905725598335, 47.29004703462124, 48.66526544094086, 49.72239151597023, 55.75817383825779, 47.636755630373955, 50.32853879034519, 42.61753275990486, 41.224592104554176, 44.1324582695961, 46.12779580056667, 46.5564925968647, 42.86026753485203, 42.2425726801157, 45.42478032410145, 50.87371453642845, 55.9018175303936, 54.93177518248558, 43.6290080845356, 30.160309709608555, 20.823593214154243, 17.257501669228077, 14.364859387278557, 13.739498443901539, 12.492558304220438, 12.226385436952114, 12.28528892621398, 16.201832816004753, 23.380751498043537, 32.8622630238533, 41.20407700538635, 48.25031630694866, 48.531790003180504, 39.111852273344994, 33.219037279486656, 34.95895251631737, 31.888192892074585, 28.75828944146633, 23.26291412115097, 18.431460075080395, 17.189207933843136, 17.68635045737028, 20.071199387311935, 25.44278685003519, 34.62182320654392, 44.31075990200043, 43.4418985247612, 46.034807190299034, 49.4048235565424, 42.39882029592991, 40.17418786883354, 28.673297502100468, 17.795360907912254, 27.227319292724133, 35.38986459374428, 41.31698414683342, 47.319225668907166, 43.88419099152088, 45.21564334630966, 43.196986466646194, 46.97297304868698, 43.66956330835819, 41.03494428098202, 35.181605368852615, 31.664774380624294, 32.57475145161152, 41.68513499200344, 45.14711022377014, 49.60090823471546, 56.18148252367973, 57.604802548885345, 57.69438274204731, 55.10530427098274, 52.044598907232285, 56.18841715157032, 52.699246779084206, 56.70052707195282, 52.970058247447014, 58.97641874849796, 56.45195960998535, 58.78263294696808, 60.68337835371494, 56.342757269740105, 30.036195069551468, 37.00645364820957, 7.03495723195374, 4.335509408265352, 38.72096344828606, 53.94405618309975, 52.916918098926544, 49.0469853579998, 46.55139707028866, 51.1353874951601, 56.24478332698345, 56.86045669019222, 6.8451346177607775, 4.950778568163514, 62.14545249938965, 57.122148647904396, 16.47252269089222, 15.870967470109463, 26.664238907396793, 36.82021804153919, 40.40763974189758, 26.176373586058617, 25.834266543388367, 29.617026261985302, 50.26813343167305, 53.74813489615917, 3.4780096588656306, 0.09775757702300325, 0.04473143722862005, 0.036118052739766426, 0.045747159092570655, 0.029005756550759543, 0.05150829936610535, 0.07085065677529201, 0.12493082438595593, 0.037076506778248586, 0.0337364637380233, 0.11142787043354474, 0.013505389124475187, 0.0780258295708336, 0.09037448413437232, 0.1695178693626076, 0.0539836772804847, 0.016173375697690062, 0.04317758408433292, 0.05891066954063717, 0.06279217239352874, 0.04968138411641121, 0.22885290265548974, 0.06693227289360948, 9.934745505452156, 75.6087988615036, 58.749829307198524, 45.32191224396229, 31.967008262872696, 40.80653473734856, 32.666717916727066, 40.67862220108509, 26.264304667711258, 28.54123178869486, 49.21735681593418, 14.293908644467592, 4.62084274739027, 26.376421451568604, 63.674414455890656, 70.76225772500038, 58.006387799978256, 59.530231431126595, 64.59183722734451, 71.83845117688179, 52.3079589754343, 5.507864775136113, 0.4746641468955204, 13.584024086594582, 50.66963128745556, 51.717189475893974, 54.23217572271824, 54.82622064650059, 46.78640305995941, 57.27944880723953, 62.80706539750099, 69.10819888114929, 66.78291365504265, 69.32629197835922, 63.64533841609955, 63.824909180402756, 62.51652538776398, 63.67370769381523, 58.90454560518265, 57.1090317517519, 57.10205152630806, 56.684898510575294, 54.37776491045952, 54.551305398344994, 50.87510526180267, 50.27585841715336, 55.01026377081871, 60.468100905418396, 51.726768761873245, 52.547790706157684, 45.34635633230209, 44.92958329617977, 47.28772155940533, 49.91129457950592, 50.55936500430107, 51.40144921839237, 49.56611730158329, 48.318553045392036, 55.704668909311295, 56.02643944323063, 55.949474573135376, 49.40154813230038, 45.705657452344894, 40.17725810408592, 31.94150023162365, 26.54658392071724, 23.832402862608433, 22.50245902687311, 21.862943843007088, 19.974678866565228, 22.45671898126602, 29.782402887940407, 39.11705419421196, 45.508189648389816, 54.903025925159454, 49.757596626877785, 39.25169616937637, 43.99129584431648, 39.33153748512268, 40.79320885241032, 36.81370139122009, 31.261158138513565, 27.52642024308443, 27.68609907478094, 30.55920660495758, 32.72599473595619, 39.89143744111061, 49.47728946805, 52.447358295321465, 47.222840040922165, 50.01929618418217, 49.20061491429806, 47.17215456068516, 44.554311633110046, 34.648588970303535, 22.932329960167408, 32.98777028918266, 41.49385705590248, 45.09635254740715, 49.911993741989136, 47.39212095737457, 48.39008040726185, 47.435548827052116, 48.469553142786026, 47.68972098827362, 43.90258960425854, 36.96273319423199, 35.46746402978897, 37.27194160223007, 46.30625702440739, 46.75115615129471, 52.23329298198223, 58.64215828478336, 58.84006306529045, 59.22842122614384, 58.35227183997631, 55.76316297054291, 57.89410762488842, 55.88417127728462, 59.343893229961395, 57.93538860976696, 61.386021450161934, 57.80495300889015, 61.39027342200279, 64.6769830584526, 57.68355332314968, 33.96255098283291, 46.78280085325241, 5.807493422180414, 7.036792058497667, 45.52304305136204, 58.65629352629185, 58.97625535726547, 56.226418912410736, 53.624371737241745, 61.50408111512661, 63.51504720747471, 57.1838915348053, 7.192641170695424, 8.607004601508379, 67.55937919020653, 61.26793898642063, 26.617636308073997, 20.62660228461027, 30.600704178214073, 26.166794300079346, 45.362820848822594, 37.355825901031494, 23.405735157430172, 35.67978523671627, 58.86566609144211, 63.71275819838047, 4.780062278732657, 0.32313635281752795, 0.08768365703872405, 0.04538509121630341, 0.035607206518761814, 0.03005578419106314, 0.054860892123542726, 0.06658917060121894, 0.07589202883536927, 0.05034179164795205, 0.07866708969231695, 0.17840575572336093, 0.09247354493709281, 0.14041267801076174, 0.1850230264244601, 0.2370741029153578, 0.19875293655786663, 0.17308488342678174, 0.13568454422056675, 0.19850911136018112, 0.2110206228098832, 0.18040382507024333, 0.4372406378388405, 0.24450677126878873, 22.24539902061224, 94.80225294828415, 65.62244832515717, 67.58392587304115, 40.5942515283823, 55.32477289438248, 68.4704715013504, 49.495205506682396, 24.966535605490208, 33.569116294384, 51.602659821510315, 15.162693075835705, 7.58633092045784, 35.73808170855045, 69.08013358712196, 76.88776463270187, 59.532872289419174, 62.59431481361389, 73.0415578186512, 80.80926820635796, 51.76806874573231, 4.418826587498188, 0.228109612071421, 24.67850536108017, 62.33537770807743, 54.304375648498535, 58.78264054656029, 62.84234270453453, 53.1203705817461, 58.70771996676922, 65.09620696306229, 73.98485720157623, 69.903724193573, 73.2591949403286, 65.4223358631134, 66.80470928549767, 68.47348093986511, 68.91401410102844, 62.86566965281963, 58.9204515516758, 60.74106685817242, 57.79376640915871, 56.34934991598129, 57.224363163113594, 55.380964279174805, 54.50490988790989, 59.65352721512318, 62.400802597403526, 55.66279135644436, 58.106288239359856, 47.58452743291855, 48.24847340583801, 51.97621397674084, 54.47579964995384, 54.268805757164955, 54.659345000982285, 53.51723648607731, 54.14103761315346, 59.9018818885088, 60.07571116089821, 57.80755586922169, 51.36567413806915, 49.526873007416725, 47.52941519021988, 43.86462204158306, 39.462106078863144, 38.36578510701656, 39.26121085882187, 39.030449241399765, 39.46031257510185, 44.35029678046703, 47.9907788336277, 49.51637417078018, 51.22804932296276, 55.51208384335041, 56.1899408698082, 46.298718228936195, 44.78239819407463, 49.59333524107933, 52.345451563596725, 47.45420962572098, 44.13912691175938, 42.45162606239319, 42.74682082235813, 46.07947759330273, 44.388157948851585, 47.464472874999046, 56.83430649340153, 60.63865475356579, 51.54803775250912, 54.65208739042282, 58.08957293629646, 53.988688588142395, 50.00144474208355, 42.27044798433781, 30.710835568606853, 38.303856030106544, 44.321821108460426, 51.78166441619396, 52.85584777593613, 50.96505023539066, 50.128627717494965, 47.20655411481857, 49.31663788855076, 49.39897187054157, 45.353518947958946, 39.20279659330845, 38.50606977939606, 42.134434282779694, 52.54015691578388, 49.94380943477154, 56.25008024275303, 60.97218185663223, 61.20863176882267, 62.71263666450977, 63.673692494630814, 58.4764301776886, 61.931926757097244, 60.215585455298424, 62.596032321453094, 61.736662834882736, 64.39712807536125, 62.612489238381386, 62.009868174791336, 64.22243624925613, 62.6631785184145, 36.36398792266846, 51.49773605167866, 12.143895663321018, 5.989303691312671, 44.17424462735653, 64.4060043990612, 61.63248762488365, 59.43111754953861, 55.72996415197849, 64.73366841673851, 67.43075609207153, 66.79446503520012, 11.234142780303955, 8.722179271280766, 70.29764905571938, 70.44969409704208, 28.285900689661503, 27.189729809761047, 35.70050932466984, 46.49967424571514, 59.309695065021515, 41.93380504846573, 34.656116366386414, 48.34758348762989, 67.01806023716927, 78.91492545604706, 8.212847951799631, 0.5217079678550363, 0.21787313948152587, 0.09887470223475248, 0.18593021290143952, 0.10097264239448123, 0.16151845251442865, 0.13808746996801347, 0.3658018884016201, 0.23879395594121888], [0.057942211351473816, 0.022540067657246254, 0.03180192594300024, 0.06508940146886744, 0.08368011171114631, 0.04888911920716055, 0.03073514988500392, 0.032693364046281204, 0.10295306346961297, 0.031242097975336947, 0.04666389329941012, 0.05111715414386708, 0.01812041682569543, 0.13968048995593563, 1.0318651492707431, 46.874455735087395, 63.051331490278244, 41.907974034547806, 30.458992682397366, 26.859229244291782, 44.27700251340866, 30.592584013938904, 20.938010774552822, 12.705719266086817, 47.6042103767395, 47.344942688941956, 7.316765310242772, 10.871283151209354, 45.35737194120884, 68.70466813445091, 51.33096680045128, 53.69288206100464, 62.64901287853718, 53.000380620360374, 58.71179334819317, 27.946867682039738, 1.7205137154087424, 0.35460201906971633, 8.623737953603268, 35.67683279514313, 35.07975183427334, 62.80890449881554, 60.18676780164242, 66.16217136383057, 59.75709825754166, 59.811283349990845, 58.72154742479324, 61.79513029754162, 61.59537501633167, 59.75272849202156, 58.73032495379448, 59.132335782051086, 58.55186752974987, 57.067507579922676, 54.08519580960274, 53.93034651875496, 51.393237859010696, 51.07033498585224, 46.09100617468357, 46.91799379885197, 48.919209614396095, 54.87703911960125, 53.137275874614716, 47.40576222538948, 46.083094999194145, 45.00687874853611, 47.20017045736313, 44.86573152244091, 46.24762997031212, 41.83121435344219, 42.98946440219879, 49.41213816404343, 55.347092896699905, 59.46691922843456, 47.255495488643646, 34.43886302411556, 23.454068563878536, 18.98836199194193, 14.506353344768286, 13.273446802049875, 15.064805578440428, 14.892217889428139, 15.527661591768265, 16.637832820415497, 23.444892056286335, 30.230301953852177, 38.44568341970444, 43.08979421854019, 47.70382583141327, 46.12883694469929, 43.13651651144028, 37.70042560994625, 34.80417922139168, 34.213842898607254, 28.173491321504116, 22.465504109859467, 18.760676309466362, 19.607301279902458, 18.910325579345226, 19.848867617547512, 21.9083172082901, 29.897173829376698, 39.73599538207054, 42.9741208255291, 43.212721422314644, 47.26398803293705, 47.801647782325745, 45.07282800972462, 40.85500493645668, 25.339193008840084, 17.465660199522972, 26.991574242711067, 33.64145301282406, 42.4038702249527, 41.035438254475594, 46.21041476726532, 43.918400555849075, 40.65241500735283, 37.4886629730463, 38.29607404768467, 36.28049120306969, 32.83994302153587, 33.14478546380997, 30.628077909350395, 37.93711490929127, 44.704547971487045, 46.89748629927635, 50.433226972818375, 53.99667575955391, 51.210182681679726, 54.924232587218285, 51.526667699217796, 55.63633717596531, 53.83716031908989, 56.500524803996086, 54.50250841677189, 57.83597074449062, 64.03470352292061, 53.37755598127842, 33.33793289959431, 48.869713470339775, 27.53328837454319, 1.3723482540808618, 31.851918138563633, 55.72755128145218, 55.68403981626034, 52.42560066282749, 28.14435638487339, 49.7213351726532, 57.115578800439835, 52.7165662497282, 30.331771709024906, 2.899791360832751, 23.20819515734911, 53.18706840276718, 28.225943706929684, 7.82117779366672, 25.01743197441101, 31.311039961874485, 47.46499344706535, 32.157796025276184, 23.259000331163406, 32.42473930120468, 30.876181796193123, 53.765355572104454, 28.3313462510705, 0.8533440786413848, 0.07294134615221992, 0.07670416103792377, 0.09501209817244671, 0.017497439512226265, 0.04243781870172825, 0.10366837508627214, 0.06908802635734901, 0.05545772357436363, 0.04725499537016731, 0.12469366367440671, 0.03221552113245707, 0.026595264607749414, 0.043315872171660885, 0.03902140124409925, 0.18550735199823976, 0.021957904755254276, 0.046756543015362695, 0.06331567594315857, 0.03462294800556265, 0.19112938782200217, 0.009309679498983314, 0.022784085813327692, 0.13280438783112913, 1.029060899745673, 56.720495000481606, 70.94739899039268, 45.57644158601761, 30.00330973416567, 45.35775192081928, 44.581305384635925, 30.660108290612698, 32.29128286242485, 19.236756563186646, 51.06584742665291, 53.096268475055695, 9.05595526099205, 11.389375850558281, 52.13745452463627, 75.14955550432205, 56.2584587931633, 62.07801751792431, 71.79964765906334, 59.19235356152058, 63.4447205811739, 36.20093107223511, 2.6133546559140086, 0.5442537018097937, 8.743779212236404, 40.22496074438095, 41.71831861138344, 65.70921286940575, 63.68497408926487, 66.6903430223465, 61.20654948055744, 60.885094329714775, 60.31809635460377, 60.05562923848629, 60.888730734586716, 60.249570831656456, 60.86745947599411, 62.239159271121025, 60.98657928407192, 61.28916844725609, 57.02427729964256, 55.24206653237343, 55.206519439816475, 55.69426886737347, 49.36850130558014, 51.77777722477913, 54.013094678521156, 59.61825370788574, 56.61102667450905, 51.712808310985565, 46.203841120004654, 46.99280798435211, 50.93123584985733, 51.06884926557541, 52.51182563602924, 48.64304043352604, 48.77590790390968, 50.90740732848644, 56.39079049229622, 57.40502066910267, 52.40767702460289, 43.794249817728996, 37.57600888609886, 32.896301597356796, 27.684695050120354, 24.14324328303337, 24.04639407992363, 22.726808488368988, 24.336025938391685, 23.633466437458992, 28.44900693744421, 35.60874044895172, 42.82314732670784, 50.67634552717209, 52.70501486957073, 52.47451923787594, 46.267366111278534, 48.41316416859627, 47.36526399850845, 43.324397429823875, 39.01397332549095, 35.546917766332626, 29.246715232729912, 29.233201257884502, 29.75144784897566, 30.852822549641132, 34.43832345306873, 42.294850274920464, 50.334724858403206, 48.79452310502529, 45.83749517798424, 49.526831209659576, 45.804151967167854, 48.5782615095377, 46.837856099009514, 30.577458925545216, 24.87167179584503, 35.014482736587524, 38.9477314800024, 47.33766607940197, 45.042186453938484, 50.14737971127033, 48.805417120456696, 45.19619219005108, 41.83716483414173, 40.19486255943775, 40.46153225004673, 35.56454502046108, 35.14098934829235, 33.81931386888027, 41.82605043053627, 46.80295117199421, 49.275345504283905, 53.09077776968479, 56.31922893226147, 54.29076857864857, 58.9497821778059, 53.63306567072868, 59.02700923383236, 56.472611501812935, 59.592316299676895, 56.53451398015022, 60.2404361218214, 65.34943297505379, 53.686661794781685, 36.04580819606781, 58.029410764575005, 22.280680127441883, 3.600898627191782, 40.97092531621456, 60.03134474158287, 61.83735743165016, 58.50652076303959, 34.408320263028145, 57.489174753427505, 60.6442404538393, 59.19067025184631, 33.210324347019196, 2.5194909051060677, 31.48657914251089, 59.465152323246, 37.325488328933716, 16.62946566939354, 30.93774039298296, 30.751164704561234, 34.72319796681404, 41.899603083729744, 31.790120154619217, 29.254428818821907, 36.139066591858864, 64.74546298384666, 32.889499962329865, 1.2570692086592317, 0.03188026705174707, 0.2379207152989693, 0.11324385384796187, 0.06300942128291354, 0.044959302540519275, 0.0590199730504537, 0.03672328530228697, 0.04698050834122114, 0.03797103592660278, 0.24451462319120765, 0.1495257468195632, 0.09331283974461257, 0.23134349088650197, 0.1729194587096572, 0.24257352109998465, 0.19110272987745702, 0.11206495968508534, 0.3415782476076856, 0.23824501899071038, 0.321334982290864, 0.17632735631195828, 0.32082379097118974, 0.24305263679707423, 2.8107388643547893, 79.91807922720909, 76.95253595709801, 60.62161646783352, 43.05767834186554, 47.07854278385639, 68.07027697563171, 37.59788051247597, 27.775895856320858, 18.37167028337717, 56.886990666389465, 56.47112958133221, 12.600953187793493, 17.32460416853428, 57.258819714188576, 78.52754384279251, 64.18160364031792, 66.28531515598297, 75.30844017863274, 64.46382969617844, 70.06490394473076, 35.813450664281845, 2.950574210844934, 0.5139161297120154, 19.45090927183628, 52.16326653957367, 46.430578753352165, 67.29631170630455, 67.30926901102066, 67.45996132493019, 61.83342084288597, 62.64124609529972, 61.442634612321854, 64.06585425138474, 64.16250586509705, 64.01537016034126, 63.524546697735786, 64.68256115913391, 62.9057727009058, 62.34939135611057, 59.879474490880966, 57.97274060547352, 56.2910420447588, 60.10457441210747, 54.0121029317379, 55.498332381248474, 57.35604889690876, 61.30720987915993, 61.43963277339935, 55.14247387647629, 50.216934978961945, 50.431254878640175, 56.08650662004948, 53.67124602198601, 55.90533994138241, 51.94487705826759, 53.30727115273476, 55.71657367050648, 61.4387284219265, 60.0914841145277, 55.209091901779175, 49.72050301730633, 46.86270296573639, 43.265458792448044, 40.27889505028725, 38.92274782061577, 41.35618284344673, 39.74971644580364, 43.86713370680809, 44.1128209233284, 45.059509724378586, 45.5364715307951, 48.70322920382023, 52.06784226000309, 54.74424384534359, 51.65935277938843, 48.103864565491676, 52.24189952015877, 51.501653641462326, 50.64633093774319, 47.478311732411385, 46.100760251283646, 42.602941542863846, 43.77249978482723, 45.28778627514839, 44.089338183403015, 43.780999928712845, 52.86510027945042, 55.83489932119846, 55.45028015971184, 49.61569704115391, 55.21690808236599, 52.43774101138115, 53.4245290607214, 52.06307351589203, 35.35299137234688, 29.25357386469841, 38.46799202263355, 41.099160835146904, 50.058757066726685, 46.14330276846886, 52.28515639901161, 49.879098907113075, 46.827463656663895, 44.932623133063316, 43.47844496369362, 44.681076630949974, 40.983552038669586, 37.53893427550793, 37.0039913803339, 46.27836652100086, 53.441669940948486, 52.937079817056656, 56.35437324643135, 59.45780731737614, 57.05043129622936, 59.35570679605007, 60.11903263628483, 60.25477655231953, 59.9275229126215, 61.49794064462185, 61.64755381643772, 62.41963818669319, 65.01362979412079, 56.17024652659893, 38.73966224491596, 63.76744106411934, 35.56805223226547, 2.931374553591013, 37.84887604415417, 63.362869173288345, 64.6698546409607, 61.24875761568546, 36.98787644505501, 61.25494748353958, 66.45176142454147, 64.50275480747223, 42.65231989324093, 5.712988693267107, 29.66039903461933, 63.676728531718254, 39.64139185845852, 16.36276938021183, 39.69721846282482, 41.709328293800354, 64.81600999832153, 50.79834558069706, 34.18007791042328, 45.284119471907616, 47.58530259132385, 78.48325341939926, 49.608610421419144, 2.0565170980989933, 0.25802963704336435, 0.2871378563577309, 0.19456254813121632, 0.20419276028405875, 0.16929290955886245, 0.19343660620506853, 0.15734476241050288, 0.19262857065768912, 0.1383475778857246], [0.02624724744237028, 0.08613961879746057, 0.024181774388125632, 0.09317629199358635, 0.028811419615522027, 0.09057366172783077, 0.03606055484851822, 0.07332797540584579, 0.04301385888538789, 0.057140651042573154, 0.03122444228210952, 0.07830150032532401, 0.02028112969128415, 0.1635567907942459, 0.038484969481942244, 19.833354949951172, 69.5088417828083, 42.74176709353924, 30.384833961725235, 48.47755931317806, 55.009640604257584, 42.25090563297272, 32.45917305350304, 15.641050357371569, 26.628887504339218, 47.82447315752506, 13.523309044539928, 2.996513033285737, 19.117226377129555, 58.85341934859753, 60.5176692456007, 38.98995101451874, 48.90244111418724, 58.69977839291096, 58.94316293299198, 46.73673212528229, 10.000039301812649, 1.0282497620210052, 0.45807008107658476, 11.865724939852953, 42.73640178143978, 29.02805596590042, 35.817995220422745, 42.661663591861725, 49.986819326877594, 53.825593739748, 54.719586968421936, 50.44306464493275, 56.3890577852726, 53.519102185964584, 49.918544590473175, 51.10460914671421, 52.246656864881516, 53.476039096713066, 55.779616087675095, 55.94663992524147, 52.592700496315956, 52.00879342854023, 45.417686104774475, 49.34115417301655, 51.07442356646061, 53.499062061309814, 50.33642716705799, 49.155849516391754, 43.14908243715763, 47.773624286055565, 47.565479055047035, 46.12270787358284, 38.26083093881607, 40.68748712539673, 48.4138785302639, 53.593680784106255, 56.56015120446682, 53.9916068315506, 42.050990760326385, 29.52697679400444, 21.443248763680458, 18.288511745631695, 16.40586096793413, 14.161120019853115, 16.250660195946693, 15.823291428387165, 20.756597109138966, 23.401872664690018, 27.8040599450469, 32.237941324710846, 39.289367347955704, 46.196560710668564, 49.83510106801987, 50.25317743420601, 47.99552857875824, 42.61668540537357, 39.83753353357315, 35.20370878279209, 30.766215696930885, 26.22505847364664, 21.498057022690773, 21.949567794799805, 22.7895887196064, 22.652782760560513, 23.419477120041847, 31.18127502501011, 38.21398325264454, 42.60005749762058, 44.60069194436073, 46.556891575455666, 47.24702574312687, 47.516188099980354, 43.603074476122856, 46.47182933986187, 31.508897244930267, 13.045357391238213, 17.192451059818268, 27.55615744739771, 30.132189318537712, 33.79519656300545, 45.29667019844055, 45.19130565226078, 43.412533700466156, 40.792958065867424, 39.03492160141468, 40.32681427896023, 40.03934070467949, 37.235007584095, 39.361039102077484, 43.284993544220924, 47.21585601568222, 49.35029648244381, 50.983376652002335, 48.924783915281296, 50.38198672235012, 46.79851680994034, 43.981119990348816, 55.0998667627573, 54.62265037000179, 56.614093109965324, 60.73604352772236, 48.042243272066116, 38.46046082675457, 42.20213904976845, 23.653037287294865, 2.0259919110685587, 12.57747519761324, 54.825544282794, 45.325100272893906, 57.35415659844875, 45.6719608604908, 55.29031254351139, 63.94384279847145, 56.149982213974, 55.51300719380379, 9.6355733089149, 6.098756343126297, 36.42587140202522, 32.77410015463829, 12.008640971034765, 14.407023824751377, 22.93622475117445, 35.06896801292896, 43.83526861667633, 26.541906371712685, 24.13189709186554, 21.921903379261494, 36.52303218841553, 51.02176979184151, 11.806233432143927, 0.3079006844200194, 0.08080764397163875, 0.07194423364126123, 0.048509566331631504, 0.1638940375414677, 0.10426759254187346, 0.021160606229386758, 0.06969150374061428, 0.04045148270961363, 0.07720454668742605, 0.0485401316836942, 0.013813347941322718, 0.018463595188222826, 0.10287357945344411, 0.06301993751549162, 0.05789282142359298, 0.10165329571464099, 0.015333553037635284, 0.057832744569168426, 0.05578283249633387, 0.034232459584018216, 0.04245056137733627, 0.07491226773709059, 0.3002498543355614, 0.030183975359250326, 23.74794479459524, 80.58903962373734, 50.19626788794994, 31.33934274315834, 61.58285088837147, 65.41746452450752, 29.276665225625038, 37.100893780589104, 23.859263621270657, 34.75959241390228, 56.113196387887, 25.508270636200905, 4.516528844833374, 15.298070311546326, 63.563931584358215, 71.74252152442932, 48.31718511879444, 53.45700591802597, 65.12636974453926, 64.39971193671227, 55.444781854748726, 13.21994187310338, 2.8910439927130938, 1.1343023087829351, 12.15711135417223, 50.4231271147728, 32.63217777013779, 42.075944021344185, 46.060850992798805, 52.335640490055084, 55.03790728747845, 57.98399560153484, 53.7533900141716, 59.746481627225876, 57.004700750112534, 55.87767742574215, 54.3703743070364, 56.98505200445652, 56.67115464806557, 57.54404380917549, 61.30884379148483, 58.463719859719276, 56.84299282729626, 51.08203835785389, 50.56792214512825, 54.26621049642563, 54.57689322531223, 53.483824878931046, 50.590401738882065, 47.330750450491905, 47.476529628038406, 53.55466827750206, 54.38911870121956, 47.53378115594387, 45.915227606892586, 50.92568814754486, 54.96068023145199, 57.418882325291634, 57.58857361972332, 48.89544188976288, 39.79602076113224, 31.909152567386627, 29.769042804837227, 27.62305475771427, 25.203827172517776, 25.209597162902355, 26.006927378475666, 28.569525070488453, 31.48564249277115, 34.57899950444698, 39.210734367370605, 46.24357558786869, 52.098905593156815, 56.26982018351555, 53.80928881466389, 49.561568945646286, 49.79170359671116, 48.106976598501205, 45.421159118413925, 40.067584589123726, 35.266181230545044, 28.65520477294922, 31.16861030459404, 31.452428475022316, 31.905626356601715, 34.85705338418484, 43.48249554634094, 48.05806942284107, 47.21063889563084, 47.091477289795876, 45.94061404466629, 50.56446813046932, 49.59445238113403, 47.32880875468254, 49.55995783209801, 35.983350947499275, 20.430850088596344, 21.753279827535152, 31.69872745871544, 35.98669096827507, 38.76622661948204, 50.30800089240074, 48.96748602390289, 44.7014207392931, 43.29887039959431, 40.521975606679916, 42.233650758862495, 42.698734402656555, 39.907734766602516, 42.25152499973774, 43.995756804943085, 49.773829355835915, 52.43600070476532, 54.80518117547035, 53.767962232232094, 55.002379193902016, 52.703867331147194, 47.657738104462624, 57.62179523706436, 59.392386227846146, 59.23619940876961, 59.65606167912483, 49.63875040411949, 41.83352082967758, 43.20074826478958, 16.67518101632595, 4.32018150575459, 18.871128782629967, 58.99319484829903, 50.48434183001518, 62.049192264676094, 52.01181806623936, 59.1303750872612, 70.55533602833748, 64.14473041892052, 57.74144321680069, 8.050010539591312, 10.643156692385674, 47.530106753110886, 31.55644789338112, 18.02449621260166, 22.765496112406254, 29.23800989985466, 30.089777894318104, 37.964192256331444, 39.93063993752003, 28.483628779649734, 20.684993751347065, 43.879821226000786, 60.861915573477745, 15.670383833348751, 0.29368730960413814, 0.10236033238470554, 0.12853772146627307, 0.09771646204171702, 0.08868776800227351, 0.0705954767181538, 0.02520346868550405, 0.018477402845746838, 0.029518304145312868, 0.06343112443573773, 0.08119110425468534, 0.19402364501729608, 0.20790275651961565, 0.18460458872141317, 0.1796349452342838, 0.23923706263303757, 0.21201697090873495, 0.17596833495190367, 0.14084763592109084, 0.18141221080441028, 0.11738122324459255, 0.23489205515943468, 0.11820875501143746, 0.4405248787952587, 0.08306792893563397, 40.16810059547424, 94.35786679387093, 58.73932667076588, 44.451109170913696, 60.65859228372574, 81.79563447833061, 54.62575100362301, 41.188866421580315, 21.211632192134857, 35.12518219649792, 55.649385675787926, 20.336953327059746, 5.358760775998235, 26.51103302836418, 73.35589215159416, 73.95845621824265, 56.86459846794605, 62.19402149319649, 70.84668159484863, 69.36375796794891, 57.50008776783943, 12.299277875572443, 2.599238413386047, 0.49289818096440285, 20.646471418440342, 60.244809687137604, 40.21620601415634, 46.44062541425228, 50.94538249075413, 56.49525448679924, 59.02376040816307, 64.01135757565498, 57.34384395182133, 66.00011765956879, 61.50404691696167, 58.088862374424934, 59.16138902306557, 60.9219865500927, 59.89239759743214, 59.63243454694748, 61.60601444542408, 61.668566688895226, 59.65609587728977, 52.42894068360329, 56.10425926744938, 58.78181219100952, 59.313707649707794, 59.75459039211273, 54.172815307974815, 51.92889131605625, 50.47477774322033, 57.814756482839584, 57.635193318128586, 51.96345806121826, 52.65187472105026, 54.3426775932312, 56.430327370762825, 60.20547799766064, 58.56091484427452, 50.35145916044712, 46.61501705646515, 42.02619709074497, 44.31550584733486, 43.04707311093807, 42.02816538512707, 44.28059712052345, 43.09562310576439, 46.56223028898239, 46.765732169151306, 45.03618277609348, 44.95047837495804, 50.06815776228905, 51.89807876944542, 55.062241181731224, 55.70006735622883, 54.32641066610813, 52.36410476267338, 54.31201323866844, 50.848267301917076, 47.84407250583172, 46.611627638339996, 41.39033921062946, 43.54962274432182, 48.79407852888107, 45.65743423998356, 48.34445245563984, 54.320410788059235, 54.55682270228863, 55.07254622876644, 51.73443295061588, 52.92936623096466, 55.64036875963211, 55.401673167943954, 53.93245540559292, 53.75955708324909, 40.18481209874153, 26.52161356061697, 26.556904166936874, 33.054357916116714, 37.38051317632198, 39.65805396437645, 53.90641540288925, 51.51624485850334, 49.19212616980076, 46.66613571345806, 45.012380853295326, 47.21071109175682, 47.89084039628506, 46.665504947304726, 45.095326602458954, 48.91570620238781, 54.33035485446453, 55.71937412023544, 57.45712347328663, 56.97640746831894, 57.99737848341465, 56.46067634224892, 52.865620851516724, 58.21273572742939, 62.82901681959629, 60.82616329193115, 60.383213460445404, 52.327159345149994, 47.48288668692112, 53.38869318366051, 29.15858656167984, 3.938914001919329, 18.500775955617428, 60.8534762263298, 54.240713864564896, 65.89189946651459, 55.985584035515785, 64.59756731987, 73.1443803012371, 68.40390667319298, 64.9770225584507, 16.018315963447094, 8.578242044895887, 44.41516689956188, 40.20481042563915, 20.25404367595911, 25.70077020674944, 35.79254038631916, 48.824522495269775, 60.44154033064842, 42.31178216636181, 33.62096831202507, 34.63019795715809, 57.22160451114178, 78.67810696363449, 24.395933523774147, 0.52077672095038, 0.10585765878204256, 0.27131241804454476, 0.22341322735883296, 0.2329999941866845, 0.20929334830725566, 0.10674935663701035, 0.09473967060330324, 0.09765101203811355, 0.17709344567265362], [0.05436962746898644, 0.015855844103498384, 0.12022342620184645, 0.03632254411058966, 0.022632092113781255, 0.06780951371183619, 0.1351054760743864, 0.07335619928198867, 0.01979308966838289, 0.07104819422238506, 0.040696016658330336, 0.07610729619045742, 0.048760761055746116, 0.10226604252238758, 0.16926491574849933, 3.565952852368355, 58.969218134880066, 63.313004449009895, 25.44956188648939, 37.798099368810654, 41.838350370526314, 46.17427110671997, 44.4738395512104, 26.83867234736681, 20.313189402222633, 52.67040632665157, 42.35954560339451, 3.4823212400078773, 0.4599775787210092, 12.02653706073761, 38.58787178993225, 46.54008127748966, 53.51574696600437, 60.03230608999729, 60.683439150452614, 55.67070633172989, 24.995816834270954, 6.660656416788697, 2.026026346720755, 1.3320847833529115, 20.856239162385464, 40.338320061564445, 32.99625903367996, 28.746261186897755, 29.060002751648426, 38.894515335559845, 34.265808910131454, 38.19484367966652, 34.71139200031757, 39.42694276571274, 40.86113020777702, 46.91086158156395, 48.97893860936165, 56.692019328475, 51.49476081132889, 56.35180078446865, 53.700819835066795, 54.58129718899727, 49.6011970192194, 48.711166977882385, 48.24514098465443, 49.8726012557745, 50.020922496914864, 46.0424979776144, 47.69646182656288, 49.851880967617035, 49.6069423109293, 42.63964757323265, 37.91206665337086, 46.929662972688675, 53.7899174541235, 54.86700385808945, 53.69248308241367, 51.030095145106316, 38.3005578070879, 27.315406166017056, 23.494654186069965, 20.190152004361153, 18.737284764647484, 18.91932349652052, 19.680977426469326, 23.67047645151615, 26.00474439561367, 30.12891959398985, 34.33406084775925, 34.991794154047966, 37.97202743589878, 46.87398076057434, 48.71344305574894, 50.23248754441738, 48.66378352046013, 46.85049422085285, 40.99299073219299, 34.7719569504261, 31.008885875344276, 28.140567988157272, 26.947692297399044, 31.09219830483198, 27.996962293982506, 25.20118821412325, 25.756385922431946, 32.43111915886402, 41.99331745505333, 44.597203731536865, 44.83081139624119, 43.878327906131744, 45.1021396368742, 49.24166791141033, 49.603955671191216, 47.46073767542839, 44.38215047121048, 28.81419014185667, 13.595111891627312, 18.941546604037285, 30.978185422718525, 26.818282641470432, 31.935135573148727, 42.91407264769077, 48.22695516049862, 46.441400572657585, 42.2575818747282, 35.59079401195049, 35.22924341261387, 43.515116795897484, 44.97195102274418, 42.66931638121605, 41.872814521193504, 44.72863867878914, 45.78547976911068, 50.43961443006992, 49.74333979189396, 62.201111912727356, 48.97299952805042, 46.09410300850868, 53.177397921681404, 47.96467423439026, 43.929701149463654, 38.851733431220055, 20.129906237125397, 3.925046408548951, 1.427628993988037, 3.372183437459171, 41.45276606082916, 48.98391254246235, 53.946738839149475, 55.33560611307621, 59.250638633966446, 50.81697218120098, 53.80885563790798, 53.31516332924366, 15.071395374834538, 1.2644509063102305, 17.149228379130363, 58.1972249597311, 33.33768591284752, 12.404293790459633, 17.138254567980766, 29.618709571659565, 42.91638672351837, 28.09486024081707, 24.731717705726624, 25.923645347356796, 24.914620891213417, 47.2691785544157, 35.174625143408775, 4.987808531150222, 0.22268675384111702, 0.04695489682490006, 0.11765316099626943, 0.06802033560234122, 0.0923312381200958, 0.029647964765899815, 0.022289314510999247, 0.03155775193590671, 0.03402267298952211, 0.05186364709516056, 0.036176968133077025, 0.044054691315977834, 0.03227189838071354, 0.0960845460940618, 0.07504849636461586, 0.14445825858274475, 0.12187389584141783, 0.135853887477424, 0.046881951129762456, 0.09381222349475138, 0.048546117104706354, 0.05923413460550364, 0.044185079241287895, 0.13852889940608293, 0.14101916109211743, 3.873967411927879, 66.24802395701408, 68.3988605439663, 29.352252669632435, 37.4999787658453, 52.74228326976299, 32.32496425509453, 39.06368985772133, 32.114200964570045, 24.21490553766489, 57.706880271434784, 53.3245450258255, 15.135763920843601, 1.2359393737278879, 9.294993784278631, 41.29917450249195, 54.983418211340904, 62.040464133024216, 66.02575108408928, 67.58492141962051, 60.88167071342468, 32.11840733885765, 7.434645909816027, 3.1631694780662656, 1.8942818348295987, 25.12462042272091, 54.06074792146683, 43.934074714779854, 39.52120430767536, 39.74803313612938, 43.444508984684944, 38.32027494907379, 43.1258200854063, 42.14525230228901, 46.153995394706726, 47.364355847239494, 52.119983062148094, 54.02286775410175, 58.200823366642, 55.21035723388195, 59.91246432065964, 56.92197538912296, 59.50299069285393, 54.821117520332336, 51.89507693052292, 53.0004870146513, 52.01509729027748, 52.26843349635601, 48.03282357752323, 50.18609583377838, 54.24249216914177, 54.19647663831711, 51.858834475278854, 43.116199001669884, 49.74842011928558, 54.862010926008224, 55.16264319419861, 56.708445847034454, 51.40038527548313, 45.180050656199455, 37.888192534446716, 29.536884762346745, 29.716370031237602, 27.993335388600826, 26.30461100488901, 29.064957685768604, 32.669639959931374, 33.954590409994125, 36.82154797017574, 40.823033452034, 42.4677561968565, 47.7607087790966, 54.15728934109211, 55.47458365559578, 53.50649446249008, 52.35035330057144, 53.49136747419834, 49.7825612872839, 45.6858529150486, 39.75746043026447, 36.04405269026756, 35.15160217881203, 38.65829721093178, 38.09646315872669, 33.40570606291294, 36.16881139576435, 42.90068216621876, 50.394108071923256, 50.40925405919552, 46.730428263545036, 46.22656770050526, 48.47089447081089, 52.23395794630051, 55.54510407149792, 49.6923541277647, 48.55723723769188, 31.47396571934223, 20.13339065015316, 24.345039054751396, 34.92388799786568, 31.636912375688553, 38.36131654679775, 47.62450888752937, 51.2200203537941, 47.24303215742111, 43.221932128071785, 37.51912593841553, 37.812489196658134, 44.886881187558174, 46.709365993738174, 45.95038712024689, 43.16210813820362, 47.17095002532005, 48.639734610915184, 53.10451403260231, 54.13593448698521, 63.31517793238163, 54.26879055798054, 48.3354165405035, 54.89444598555565, 49.9921390414238, 46.74047112464905, 40.0787977874279, 13.488645404577255, 3.2437802525237203, 3.06888893712312, 7.297748755663633, 47.73440279066563, 53.15548449754715, 58.38238142430782, 60.87505906820297, 64.48153674602509, 54.305515587329865, 63.352073952555656, 58.49277690052986, 10.845514833927155, 3.3082003332674503, 30.52199900150299, 58.51511210203171, 32.524369955062866, 19.671799018979073, 22.528523728251457, 32.762784361839294, 32.93198548257351, 29.053881280124187, 36.39632798731327, 23.91974687576294, 22.746204547584057, 59.8133010417223, 44.77794483304024, 7.17714037746191, 0.11861764869536273, 0.11815551333711483, 0.14517296163830906, 0.09912732188240625, 0.12077284554834478, 0.051121161741320975, 0.05768952119979076, 0.027370087191229686, 0.025780818759812973, 0.016397754770878237, 0.15510634111706167, 0.12267623169464059, 0.18558978976216167, 0.13593369803857058, 0.12804395577404648, 0.2672648336738348, 0.23663025407586247, 0.24391786224441603, 0.11259785140282474, 0.17769926082110032, 0.12972658267244697, 0.24702821800019592, 0.18104573828168213, 0.29859257920179516, 0.2203237111098133, 8.211092445999384, 84.21501025557518, 79.49328482151031, 43.67211677134037, 46.309908628463745, 64.03139770030975, 65.09332671761513, 55.45893609523773, 35.01256763935089, 25.820528380572796, 62.11536191403866, 49.51624497771263, 9.068932514637709, 1.255415347404778, 17.82499361783266, 50.68018712103367, 59.323963299393654, 67.5178474187851, 72.21661448478699, 71.47391393780708, 68.1481271982193, 32.02810898423195, 9.014770220965147, 4.054568158462644, 1.086583281867206, 33.1620517373085, 62.21484437584877, 52.287071496248245, 51.671132147312164, 49.11236084997654, 53.25272127985954, 45.85880443453789, 53.62030975520611, 49.375082552433014, 53.89392547309399, 51.977771893143654, 54.956500455737114, 58.05935315787792, 60.76119817793369, 57.12400294840336, 62.15513817965984, 61.73524171113968, 60.65212123095989, 56.43473133444786, 57.15841770172119, 55.47470524907112, 57.283130809664726, 57.54934832453728, 52.97300688922405, 54.573849588632584, 56.929848566651344, 57.87056788802147, 57.51034341752529, 49.70124565064907, 55.123254507780075, 59.37280587852001, 60.40838710963726, 57.87167742848396, 52.782245725393295, 50.098366141319275, 48.40828903019428, 44.670281410217285, 42.1268916875124, 43.92907418310642, 44.060440734028816, 46.26414008438587, 52.20669060945511, 49.678234085440636, 48.09594579041004, 46.540905833244324, 45.86003176867962, 47.14176379144192, 54.23272669315338, 55.34000247716904, 53.038815557956696, 55.06484404206276, 57.9379116743803, 51.74789562821388, 51.01151794195175, 44.74417224526405, 47.02116206288338, 45.837852358818054, 52.36837953329086, 47.2049468010664, 43.720940351486206, 47.064251750707626, 51.69526845216751, 58.97963337600231, 57.60137893259525, 53.46392534673214, 47.76445917785168, 49.85565036535263, 56.79212495684624, 58.70035596191883, 55.004617273807526, 52.864138931035995, 35.66872023046017, 25.140539668500423, 29.836612679064274, 37.61779144406319, 34.733183830976486, 40.492853969335556, 49.780080020427704, 56.18374340236187, 51.78353011608124, 47.65736572444439, 41.218219846487045, 41.11850179731846, 48.12622256577015, 51.04562871158123, 51.08364187180996, 47.79120594263077, 48.81457842886448, 51.22299179434776, 54.190659150481224, 54.71398986876011, 62.78062641620636, 57.52897761762142, 52.84834697842598, 56.061747148633, 50.10717786848545, 52.28195697069168, 50.6917916983366, 27.660974822938442, 4.516560668125749, 1.7241691192612052, 7.842078097164631, 49.08019557595253, 58.04825395345688, 65.2365942299366, 63.03998909890652, 69.51670736074448, 61.34016551077366, 64.06048133969307, 65.23070454597473, 22.399680241942406, 3.5289418883621693, 22.56838358938694, 66.10022708773613, 38.796457797288895, 21.46389115601778, 28.187058493494987, 42.105939611792564, 53.33387732505798, 42.86724776029587, 35.761081874370575, 36.39107666909695, 36.17464788258076, 70.90795710682869, 65.54253861308098, 11.896067261695862, 0.2771568309981376, 0.42472473287489265, 0.2423136358265765, 0.20745104091474786, 0.23078802303643897, 0.1727403636323288, 0.17506640288047493, 0.07358248753007501, 0.1920815632911399, 0.135001189482864], [0.10799864350701682, 0.05060547300672624, 0.06360501705785282, 0.0686419807607308, 0.05618151793896686, 0.057524103904142976, 0.013981725478515727, 0.034023326079477556, 0.06782428987207823, 0.04102223880181555, 0.03719724678376224, 0.10897311309236102, 0.0598820777668152, 0.09561292608850636, 0.22822935017757118, 0.1968925801338628, 28.924872502684593, 55.539837554097176, 37.857870161533356, 46.570954620838165, 68.77710744738579, 46.43402896821499, 45.91436505317688, 32.31715947389603, 20.822498872876167, 26.316164284944534, 72.75738626718521, 45.372324138879776, 4.991678623482585, 4.813099605962634, 35.37871979176998, 52.39039175212383, 64.68292593955994, 54.08552259206772, 50.45393966138363, 61.328492537140846, 45.59776224195957, 16.033631041646004, 3.3425863506272435, 1.4670946262776852, 3.121592584066093, 11.041987091302872, 11.165663804858923, 7.042809510603547, 12.128379195928574, 18.511371687054634, 19.485094137489796, 18.164763785898685, 23.41038230806589, 35.20106412470341, 39.60402086377144, 46.233460530638695, 46.64046049118042, 49.3674373626709, 53.22108417749405, 53.914615362882614, 57.97547645866871, 55.95225602388382, 52.046460807323456, 50.068499743938446, 49.76844124495983, 51.136584430933, 50.25457575917244, 49.46002699434757, 50.45953296124935, 47.620093524456024, 41.84831723570824, 41.48087315261364, 47.67228752374649, 54.63462732732296, 52.63042487204075, 54.48057979345322, 50.76601691544056, 47.83809922635555, 37.32563652098179, 29.943341352045536, 25.37470780313015, 24.379782490432262, 20.48527456820011, 23.598344922065735, 25.618728809058666, 29.912335015833378, 33.695858493447304, 36.13094262778759, 36.34053938090801, 37.161211743950844, 43.405697867274284, 50.20018547773361, 50.279593616724014, 47.475739270448685, 49.36990723013878, 47.23841920495033, 42.30263605713844, 37.48490497469902, 33.9260159432888, 31.913864314556122, 30.78462190926075, 33.1893190741539, 34.062310829758644, 28.842798806726933, 27.729612439870834, 38.79787512123585, 46.4145702123642, 45.472798347473145, 43.776462972164154, 45.81558555364609, 45.32381974160671, 45.21343946456909, 48.78685511648655, 52.36274443566799, 48.919897377491, 39.9602897465229, 26.222052834928036, 18.17128423601389, 26.403462700545788, 32.255606576800346, 31.141054183244705, 34.06857289373875, 43.44207711517811, 46.5581227093935, 46.68269522488117, 39.3729704618454, 38.0980134755373, 38.31362150609493, 38.109963834285736, 39.14964124560356, 38.91002610325813, 38.059814125299454, 37.313173189759254, 39.820130467414856, 39.70026209950447, 40.95068380236626, 50.193516835570335, 46.68374016880989, 41.723075956106186, 34.38110612332821, 27.100989371538162, 8.114786613732576, 0.3194386762334034, 0.8355343749281019, 0.5440597340930253, 12.315711993724108, 51.72035850584507, 55.90751342475414, 58.194029331207275, 45.24846598505974, 43.11137706041336, 32.52121612429619, 42.68826216459274, 17.171284295618534, 2.374255573377013, 5.534371677786112, 47.95884154736996, 60.912373065948486, 18.55858415365219, 12.016026824712753, 26.31062038242817, 34.21565160155296, 40.65572842955589, 23.88534352183342, 30.457387268543243, 30.092426352202892, 30.842663794755936, 54.31829810142517, 15.442190878093243, 1.5560784889385104, 0.10359159248764627, 0.10197576630162075, 0.059430499459267594, 0.0626710538927, 0.04119342258491088, 0.035472632880555466, 0.05566878666286357, 0.03966564479924273, 0.024094104483083356, 0.04860221604758408, 0.016549529536860064, 0.0253645778138889, 0.03891921864124015, 0.024599703720014077, 0.03235045100154821, 0.044141782345832326, 0.09219082377967425, 0.012161178783571813, 0.06830682686995715, 0.035240077195339836, 0.08423178718658164, 0.07723753515165299, 0.03874575275403913, 0.07223178618005477, 0.20726522197946906, 0.15578506485326216, 31.669944003224373, 68.703543394804, 42.72748365998268, 38.70970845222473, 74.48539674282074, 39.72974851727486, 32.40856736898422, 36.6233392059803, 26.82081900537014, 37.66905449330807, 64.5524637401104, 47.07418441772461, 10.76310770586133, 7.1172574907541275, 35.97084201872349, 52.6477937400341, 69.74076613783836, 62.786177918314934, 57.63024978339672, 64.28009435534477, 50.91102473437786, 20.701114386320114, 2.3960949014872313, 3.7120279390364885, 3.59924737829715, 9.78500884026289, 12.750729750841856, 7.003849251195788, 14.917452335357666, 25.936602652072906, 28.026836290955544, 24.044347889721394, 29.460096582770348, 39.58749175071716, 43.81334379315376, 50.22644206881523, 50.609028339385986, 54.69430312514305, 57.23664790391922, 57.09300421178341, 62.293902933597565, 60.49438029527664, 57.05476686358452, 52.113561406731606, 50.903257951140404, 52.986978739500046, 51.998002007603645, 52.06870101392269, 54.850581139326096, 52.45601423084736, 47.49780088663101, 46.01932302117348, 52.24305085837841, 55.10508008301258, 54.52787205576897, 55.86436294019222, 53.30940663814545, 51.48238867521286, 44.61730845272541, 36.17748253047466, 32.95232579112053, 31.997467428445816, 28.622832410037518, 30.012286752462387, 32.952580377459526, 36.8667883425951, 42.093404084444046, 44.55749586224556, 42.154425010085106, 44.13649745285511, 48.959419056773186, 56.08255863189697, 57.41227068006992, 54.48748402297497, 55.13625741004944, 56.21298283338547, 49.769584983587265, 44.54693242907524, 42.18030922114849, 39.65920150279999, 38.901221975684166, 41.264816746115685, 42.54555702209473, 40.14230377972126, 39.441723972558975, 47.72555686533451, 51.957184597849846, 49.93070773780346, 45.467980206012726, 46.372840851545334, 47.251961678266525, 48.59036386013031, 51.85491308569908, 54.73606288433075, 51.5815519541502, 42.58303441107273, 30.122518837451935, 23.781774379312992, 30.512898489832878, 37.41626925766468, 36.46277882158756, 37.60519132018089, 45.69748409092426, 47.36388087272644, 47.84925542771816, 42.18667007982731, 41.617008447647095, 40.531699284911156, 39.927379712462425, 42.37714245915413, 43.24344277381897, 40.230006873607635, 40.62458150088787, 39.053696393966675, 42.22710371017456, 39.33252163231373, 52.56040222942829, 50.53376577794552, 44.94639739394188, 37.501202300190926, 23.833354711532593, 6.371882362291217, 1.5613095019944012, 2.1758860303089023, 0.8360409352462739, 14.842348415404558, 56.754734963178635, 60.52136644721031, 63.244771510362625, 52.19969138503075, 45.96732281148434, 35.00981278717518, 45.93529812991619, 17.958716042339802, 4.550173664465547, 15.566424261778593, 49.345474541187286, 55.594383627176285, 22.74179108440876, 16.75456825643778, 30.02311997115612, 35.225132033228874, 27.13259417563677, 27.798833325505257, 34.9355723708868, 24.674487076699734, 31.400589756667614, 67.27739632129669, 25.32867517322302, 3.2824992248788476, 0.047721379523864016, 0.16598313872236758, 0.06768867722712457, 0.0586827485676622, 0.03818091157882009, 0.03794233707594685, 0.0191987128710025, 0.03741241023817565, 0.045746747200610116, 0.03486119967419654, 0.15198834124021232, 0.10476966286660172, 0.13646794046508148, 0.15069606917677447, 0.09841992155998014, 0.11746924195904285, 0.13742063543759286, 0.11958773960941471, 0.16241366072790697, 0.07738375308690593, 0.10053639314719476, 0.18040639290120453, 0.1964401372242719, 0.1586518922704272, 0.4616173094836995, 0.31740246049594134, 53.16118039190769, 81.21523082256317, 54.36912037432194, 58.805070742964745, 83.61062988638878, 69.85179618000984, 57.69847132265568, 42.68613427877426, 24.930295050144196, 37.297772616147995, 76.41334488987923, 53.53934749960899, 10.402640048414469, 8.78287436440587, 46.140950694680214, 62.12137699127197, 76.2724256515503, 66.53842717409134, 63.67578238248825, 70.94354599714279, 57.89292588829994, 21.63325946778059, 6.654705936089158, 5.391210084781051, 3.356053065508604, 14.001907613128424, 14.41059373319149, 9.636702798306942, 20.958865955471992, 36.57683730125427, 41.23257927596569, 30.153029300272465, 31.85194283723831, 40.89503578841686, 43.711722046136856, 51.90610773861408, 54.612774699926376, 57.814558893442154, 59.91471379995346, 61.487973779439926, 65.64549788832664, 63.80626738071442, 59.871369525790215, 55.55548891425133, 54.6992352604866, 56.77764393389225, 58.897075206041336, 58.06920982897282, 58.26533630490303, 54.39290709793568, 52.76241838932037, 55.270849987864494, 61.16815634071827, 61.50459788739681, 58.75933639705181, 59.03766006231308, 53.60662288963795, 52.41419367492199, 48.7318454682827, 46.042748764157295, 45.79499065876007, 47.47425734996796, 43.608424589037895, 47.732282504439354, 49.599779695272446, 50.75142949819565, 52.48100928962231, 51.70259825885296, 47.370796501636505, 46.73646993935108, 53.23545880615711, 56.84137411415577, 58.107169792056084, 52.481951639056206, 55.74537232518196, 60.20729050040245, 54.07525174319744, 48.82713295519352, 47.54243329167366, 47.40413211286068, 46.83332674205303, 52.43379682302475, 52.537561655044556, 47.69974485039711, 46.463275998830795, 56.74503028392792, 57.390893027186394, 54.89563912153244, 51.47371754050255, 51.86206430196762, 51.345113441348076, 51.90806083381176, 56.70365050435066, 56.71334758400917, 56.290354281663895, 46.300758719444275, 34.097367748618126, 30.003949999809265, 36.50920853018761, 40.4621896147728, 38.19091469049454, 40.202196165919304, 48.39813217520714, 50.9146573394537, 53.07568497955799, 46.19232773780823, 45.5971846729517, 46.63519397377968, 44.60965946316719, 45.85891842842102, 47.472756430506706, 45.74933610856533, 43.41757982969284, 43.29696290194988, 44.79680322110653, 43.73115420341492, 55.263432785868645, 52.6076602935791, 49.44464161992073, 48.31409588456154, 35.24809040129185, 11.513403095304966, 0.9255273803137243, 1.2161252181977034, 2.795803528279066, 15.186084620654583, 60.330407693982124, 65.55895373225212, 68.44676077365875, 55.41758671402931, 54.528480023145676, 39.56121236085892, 56.896106377243996, 24.739514887332916, 5.947212874889374, 8.895465172827244, 53.588399067521095, 63.95480141043663, 25.851597413420677, 17.97463908791542, 36.27160347998142, 44.822489842772484, 53.18181328475475, 36.76925517618656, 39.49528589844704, 41.32063575088978, 46.02226786315441, 80.34576907753944, 41.12819887697697, 5.79172664321959, 0.2532088535372168, 0.294167686952278, 0.17203784664161503, 0.10976370074786246, 0.24820789141813293, 0.10287881159456447, 0.17826612805947661, 0.07482940694899298, 0.12294438449316658, 0.11447035678429529], [0.07641476055141538, 0.039060412236722186, 0.060636233392870054, 0.04010563818155788, 0.03757390899409074, 0.10901081419433467, 0.026582983919070102, 0.07089753082254902, 0.05559705808991566, 0.12143780244514346, 0.08953364565968513, 0.01432935116099543, 0.04050372990604956, 0.018479477148503065, 0.06626399859669618, 0.16501937090652063, 5.553031051531434, 52.01819412410259, 46.007452458143234, 39.13174420595169, 40.42069964110851, 45.70457451045513, 50.574298202991486, 36.15640886127949, 21.736201643943787, 16.86512902379036, 43.551245257258415, 89.90696802735329, 17.287660650908947, 2.4186364794149995, 20.704264417290688, 58.767999932169914, 62.551646903157234, 58.506722152233124, 50.11014170944691, 58.16771574318409, 48.64477314054966, 30.110173299908638, 4.268309064209461, 1.0792793612927198, 2.1246080193668604, 1.9064250332303345, 12.001988478004932, 18.71597930788994, 4.052563291043043, 8.634469527751207, 14.303119350224733, 16.185921169817448, 27.445438988506794, 36.854195818305016, 39.90888990461826, 41.94995418190956, 50.7432447373867, 46.677227318286896, 49.58588384091854, 51.30992352962494, 52.76978999376297, 51.6905453056097, 52.06802845001221, 50.58607757091522, 50.61614155769348, 50.35837098956108, 53.19834619760513, 59.468499943614006, 52.04962983727455, 44.88654300570488, 42.34571434557438, 51.2433473020792, 53.295582979917526, 54.9809293448925, 53.31478714942932, 49.5977658033371, 50.18138408660889, 50.2512813359499, 40.049421563744545, 33.546085730195045, 29.394888281822205, 27.952139899134636, 24.758492968976498, 29.558912180364132, 30.594533309340477, 34.86227810382843, 37.847458720207214, 41.34802088141441, 38.98180045187473, 36.95258013904095, 44.938839599490166, 48.76813352108002, 52.93750539422035, 47.95941911637783, 50.82054778933525, 50.25616027414799, 45.45408055186272, 38.24458681046963, 34.7909065335989, 33.80206659436226, 35.069879963994026, 35.43952792882919, 35.31554818153381, 33.57382424175739, 31.51184018701315, 39.62523892521858, 45.34813083708286, 45.10081350803375, 44.32147532701492, 42.4939139932394, 46.2320052087307, 46.049994975328445, 45.357941910624504, 45.70607163012028, 50.09692221879959, 44.92408499121666, 40.59601843357086, 27.343414463102818, 23.876655288040638, 32.375478744506836, 39.89062808454037, 36.67843244969845, 37.88859151303768, 45.17318442463875, 47.33596757054329, 46.98172777891159, 44.91899326443672, 39.18883994221687, 38.55099476873875, 34.24935579299927, 31.08259242027998, 27.686446756124496, 24.38145250082016, 23.712823279201984, 31.141037084162235, 32.81400181353092, 35.081951916217804, 23.011441715061665, 12.818411719053984, 10.669315438717604, 2.3816371522843838, 0.3957526234444231, 0.2064396717469208, 1.0373875591903925, 7.975736875087023, 28.62693428993225, 55.636223182082176, 58.939195945858955, 57.31390155851841, 46.49652421474457, 33.28627087175846, 62.906471863389015, 50.71581020951271, 17.990096658468246, 3.8212286168709397, 25.799946784973145, 61.42654627561569, 28.049053698778152, 11.67947318404913, 22.982766553759575, 30.811245180666447, 35.9571323543787, 39.07816328108311, 20.970014557242393, 31.807012148201466, 25.137969106435776, 30.200367160141468, 50.863265097141266, 13.741207402199507, 0.700598806142807, 0.12092891920474358, 0.12477532960474491, 0.029565937038569245, 0.05265343323117122, 0.040546911768615246, 0.058668339770520106, 0.03905109828338027, 0.08034449929255061, 0.0505184153735172, 0.05341584525012877, 0.04566060240904335, 0.08499255534843542, 0.073134274862241, 0.06191529151692521, 0.03641855946625583, 0.022039451941964217, 0.033755240074242465, 0.035347799930605106, 0.08747070518438704, 0.007821233684808249, 0.12475714698666707, 0.03673310762678739, 0.09476175691816024, 0.04142069417866878, 0.19356326112756506, 0.1715043612057343, 7.450406989082694, 65.35143166780472, 57.88031816482544, 36.14970602095127, 44.18283976614475, 47.81983740627766, 32.15077020227909, 36.02682061493397, 30.124253444373608, 24.62215058505535, 50.578569173812866, 84.5645534992218, 19.88970022648573, 4.698666846379638, 18.692298978567123, 59.669904336333275, 69.78337705135345, 64.65730011463165, 54.16107773780823, 65.29978483915329, 52.48472549021244, 32.956437170505524, 6.289688972756267, 2.7954525221139193, 1.2178522255271673, 0.7097523962147534, 18.592242747545242, 20.40505327284336, 6.717668082565069, 10.180574264377356, 20.390298664569855, 18.094748742878437, 30.51566284149885, 41.334611400961876, 44.098822474479675, 45.04082232713699, 53.53735260665417, 50.44906072318554, 54.38578248023987, 56.29511922597885, 57.46249258518219, 55.8412753790617, 56.57860301434994, 54.35158811509609, 54.93883140385151, 51.91844567656517, 54.69497188925743, 56.51452325284481, 54.58785563707352, 47.78875507414341, 47.66382917761803, 51.06912285089493, 53.00867177546024, 55.564524829387665, 53.59499171376228, 53.38323287665844, 50.27428150177002, 51.83611549437046, 45.330613777041435, 39.53766122460365, 35.78476220369339, 35.890377536416054, 34.929580092430115, 38.658217415213585, 40.33960439264774, 43.39614897966385, 45.811227187514305, 47.35513374209404, 47.772484347224236, 42.985865995287895, 50.183226987719536, 55.84141597151756, 59.05598647892475, 54.57887291908264, 54.589542746543884, 55.42785756289959, 52.182067930698395, 46.26524202525616, 42.9218964278698, 42.084786146879196, 42.24131874740124, 43.945189118385315, 46.16653472185135, 42.77750797569752, 42.56188094615936, 51.77846498787403, 53.96422930061817, 49.799504578113556, 47.11055986583233, 47.529369592666626, 47.3215701431036, 49.19200077652931, 52.034977823495865, 50.16770862042904, 53.087042570114136, 47.9801432043314, 42.40021102130413, 32.68190570175648, 27.796114571392536, 35.4937282204628, 43.19596812129021, 39.97034780681133, 42.440724447369576, 48.44416670501232, 49.916511699557304, 50.57690866291523, 46.42386831343174, 43.10920737683773, 42.05084256827831, 37.19337701797485, 35.29613122344017, 31.13283522427082, 28.894922509789467, 27.06006556749344, 34.77412283420563, 36.22563734650612, 35.08150354027748, 24.469328485429287, 11.930213179439306, 8.824917208403349, 2.9344927612692118, 1.8195080221630633, 0.339225847274065, 1.3637002743780613, 9.849069602787495, 34.91661138832569, 62.54959501326084, 59.99724917113781, 62.83106870949268, 49.28956054151058, 39.890540689229965, 67.01723948121071, 52.99661122262478, 16.724473871290684, 7.192096849903464, 29.726849868893623, 52.23551206290722, 25.604812055826187, 16.39407780021429, 27.22789116203785, 31.492875404655933, 32.41338171064854, 28.08957662433386, 31.404005773365498, 30.733790136873722, 21.486536040902138, 35.26558466255665, 66.52828931808472, 19.474152624607086, 0.8904052118305117, 0.04633225718862377, 0.13790864206384867, 0.02447383176331641, 0.10197361407335848, 0.04234911721141543, 0.04928079135424923, 0.03964733601605985, 0.049790260891313665, 0.010133187897736207, 0.009038410607900005, 0.15267451613908634, 0.18327951373066753, 0.14423025597352535, 0.14567947742762044, 0.16614397696685046, 0.11490999022498727, 0.18148264061892405, 0.14976246224250644, 0.26855542848352343, 0.206823302723933, 0.27893192949704826, 0.1271014875965193, 0.1316325069637969, 0.09499105828581378, 0.317283330950886, 0.22320999763906002, 12.107862196862698, 84.67811420559883, 71.26784339547157, 54.062229841947556, 48.10982644557953, 66.56022280454636, 69.0848833322525, 45.06301313638687, 30.70720486342907, 21.43296841531992, 56.259826719760895, 97.40330457687378, 22.323908507823944, 6.130033414810896, 26.036556288599968, 66.32940798997879, 76.98548778891563, 69.3737818300724, 64.11310091614723, 68.75356391072273, 61.16948626935482, 35.28646074235439, 9.239056035876274, 3.7016927311196923, 3.318295441567898, 2.2677399264648557, 20.30473865568638, 23.050537817180157, 8.318344540894032, 10.425499621778727, 26.720568984746933, 27.084302566945553, 33.95893357694149, 47.91201665997505, 49.906221851706505, 49.298326671123505, 55.65177954733372, 53.685221672058105, 56.23465687036514, 58.432443737983704, 58.66653397679329, 58.31056907773018, 59.5464413613081, 58.64166051149368, 59.554044753313065, 56.51979736983776, 58.857511729002, 62.51962222158909, 59.37494896352291, 52.88962036371231, 52.80629463493824, 61.066356003284454, 59.68167990446091, 60.131317377090454, 59.6376858651638, 56.01485386490822, 52.71027758717537, 53.852127715945244, 47.879467606544495, 50.132127329707146, 50.553235933184624, 48.185062408447266, 49.550549536943436, 53.90204183757305, 51.7473978549242, 54.52208876609802, 53.18139910697937, 52.299804612994194, 49.396608397364616, 45.420429557561874, 52.204509526491165, 54.52664092183113, 58.98445911705494, 52.61904448270798, 56.279437467455864, 58.62362667918205, 54.83417361974716, 49.127484038472176, 45.6541284173727, 45.82394890487194, 45.834972113370895, 50.44268846511841, 51.00013755261898, 49.743506982922554, 46.82113319635391, 56.14233322441578, 56.5003652125597, 52.663684487342834, 51.107451394200325, 48.87420482933521, 49.309551268815994, 50.41026100516319, 54.61052522063255, 51.792273446917534, 54.91176165640354, 52.07360655069351, 46.929887160658836, 35.895309671759605, 31.264733746647835, 39.01773512363434, 49.28110599517822, 43.75663183629513, 43.9848779886961, 51.533731520175934, 53.56716960668564, 53.410447016358376, 49.836317002773285, 46.36510826647282, 45.99363259971142, 41.15938000380993, 39.83802750706673, 33.97073954343796, 30.646453723311424, 29.011422358453274, 37.47894309461117, 40.75886629521847, 38.51323239505291, 34.63012956082821, 22.800416238605976, 13.435319066047668, 3.0265423469245434, 1.8422836437821388, 0.8769953751470894, 5.645821122452617, 11.624777968972921, 34.11625653505325, 64.11753907799721, 64.59761291742325, 66.64353713393211, 54.743605479598045, 42.66686551272869, 71.88501387834549, 58.065881207585335, 23.965716809034348, 7.927092360332608, 30.816437602043152, 66.23056009411812, 32.44867421686649, 18.04821453988552, 31.04225378483534, 41.21385768055916, 47.0485357940197, 54.3210681527853, 31.559497229754925, 42.80524268746376, 38.82999859750271, 45.10310098528862, 80.28583869338036, 30.624937377870083, 1.4614464668557048, 0.3633858117973432, 0.26971392100676894, 0.10835060704266652, 0.22241426690015942, 0.1082384907931555, 0.14030177146196365, 0.1382919613388367, 0.22215666744159535, 0.1918208468123339, 0.0861506990622729], [0.03562924459401984, 0.0844128118478693, 0.020242992577550467, 0.06384923559380695, 0.10399187725852244, 0.06268562225159258, 0.10458303499035537, 0.11588189940084703, 0.016235866387432907, 0.06896523802424781, 0.03350771527038887, 0.027641180749924388, 0.037719399624620564, 0.04346635003457777, 0.0653483739006333, 0.052908936122548766, 1.1058383923955262, 34.20241691172123, 51.33151397109032, 33.95040683448315, 30.93103565275669, 41.83812998235226, 45.40721006691456, 45.701447278261185, 26.047231815755367, 24.155001752078533, 20.571174658834934, 54.31534186005592, 46.325248405337334, 6.999906012788415, 10.44856058433652, 41.57934866845608, 62.1191731095314, 66.35281473398209, 61.10921390354633, 56.15770719945431, 54.66226324439049, 33.95427882671356, 6.913698138669133, 3.0360689107328653, 2.0117020653560758, 2.9156125243753195, 16.54154408723116, 30.82116834819317, 11.171991415321827, 4.3890775088220835, 21.55309896916151, 18.910447172820568, 33.29163998365402, 35.68018801510334, 49.01135466992855, 49.802358224987984, 51.65908299386501, 49.12998050451279, 49.19931918382645, 46.32255434989929, 53.90410892665386, 52.642075046896935, 54.537895917892456, 49.66487780213356, 51.87037445604801, 55.62378644943237, 57.31133669614792, 55.41156403720379, 52.24958270788193, 45.94742327928543, 52.35838986933231, 59.93408516049385, 57.613986656069756, 52.842624485492706, 48.49093459546566, 50.819377452135086, 48.09056907892227, 47.46386870741844, 44.173511266708374, 39.060805812478065, 33.77859145402908, 34.284450709819794, 29.899913482367992, 31.855596341192722, 34.40308794379234, 39.8376589268446, 43.541365787386894, 44.061212092638016, 41.47300377488136, 38.433436676859856, 48.762137442827225, 50.989346131682396, 54.238483384251595, 49.490128979086876, 50.65118707716465, 52.3971363902092, 49.08983565866947, 41.91271997988224, 37.065840661525726, 38.61357741057873, 38.80142033100128, 38.81029665470123, 37.57383540272713, 36.08019255101681, 34.022986739873886, 42.809593454003334, 48.14510755240917, 47.0096030831337, 45.46253889799118, 45.819252356886864, 46.164653822779655, 44.76056456565857, 43.994985446333885, 46.21711000800133, 47.38981828093529, 43.923640474677086, 39.69193674623966, 34.59352992475033, 26.980199553072453, 29.652744345366955, 41.45772859454155, 44.02556240558624, 38.611620515584946, 35.42283162474632, 35.446895733475685, 39.78381961584091, 41.07263445854187, 40.259367898106575, 41.144515201449394, 40.14633536338806, 37.17818923294544, 34.64411661028862, 28.294891007244587, 24.496164545416832, 18.07981364428997, 13.800345528870821, 6.477274456992745, 1.3884300598874688, 1.4084898959845304, 1.9878003979101777, 16.555534936487675, 6.222827760502696, 3.4637093637138605, 6.807391243055463, 10.576292630285025, 48.27500358223915, 56.09650768339634, 53.97539310157299, 54.44035895168781, 58.926014453172684, 67.03320622444153, 57.778305038809776, 50.57501636445522, 17.311815954744816, 7.8232581820338964, 73.10249894857407, 72.87074938416481, 40.607117637991905, 17.75318317115307, 25.351918525993824, 29.64770771563053, 41.44820250570774, 28.18171977996826, 14.967734087258577, 33.14950481057167, 24.59528222680092, 49.67292957007885, 50.5159143358469, 4.699329910799861, 0.17879790655570105, 0.06389034315361641, 0.1314940518932417, 0.09379097580676898, 0.13789534277748317, 0.10113112803082913, 0.07831684793927707, 0.07569186418550089, 0.12256070898729376, 0.022037552043912, 0.06228822443517856, 0.0406526455481071, 0.053982319150236435, 0.06624825022299774, 0.02575142414571019, 0.03831752241239883, 0.07592646448756568, 0.018841695309674833, 0.004799405942321755, 0.13312872120877728, 0.03257430129451677, 0.07638253649929538, 0.027176709481864236, 0.028413739782990888, 0.07167964315158315, 0.055993134883465245, 0.09902177363983355, 1.12591722747311, 40.784530118107796, 68.41285899281502, 37.53966763615608, 31.158210262656212, 50.35064220428467, 30.37438452243805, 38.41563083231449, 30.71517303586006, 28.371696285903454, 27.24137093871832, 55.38557343184948, 42.33107753098011, 8.744393829256296, 11.936646234244108, 45.21037682890892, 64.44568946957588, 71.46639034152031, 66.2081640958786, 59.79583717882633, 56.095595732331276, 39.38132241368294, 9.098508227616549, 5.670810481533408, 4.016545973718166, 2.6670132391154766, 17.90382608771324, 40.296807289123535, 21.112862192094326, 7.235417850315571, 24.81155712157488, 22.328314371407032, 37.04740025103092, 35.8513118326664, 51.1358966678381, 51.456067487597466, 56.90366417169571, 52.144294157624245, 52.85242795944214, 52.11817055940628, 58.65796163678169, 56.37059077620506, 57.01844461262226, 51.54299542307854, 55.327721536159515, 56.73868082463741, 58.00816610455513, 55.4924350976944, 52.730013728141785, 48.35867129266262, 52.764219492673874, 58.04625146090984, 56.8707275390625, 55.98227061331272, 52.4038278311491, 53.44520375132561, 51.40230417251587, 50.999172404408455, 46.14486828446388, 43.00475858151913, 41.46161198616028, 41.17164954543114, 39.36427652835846, 41.32476232945919, 45.31109042465687, 50.0856976211071, 50.37827052175999, 49.264550283551216, 47.45430842041969, 44.023601710796356, 51.43541939556599, 57.08364151418209, 59.5724281668663, 53.03366303443909, 57.42669850587845, 56.744015738368034, 55.18406264483929, 47.49412648379803, 42.686719447374344, 44.45083938539028, 45.701337084174156, 47.18898385763168, 47.41184189915657, 43.66551652550697, 45.20601466298103, 51.77836239337921, 54.13726061582565, 52.549094036221504, 46.404793336987495, 49.60047885775566, 48.80256347358227, 49.50293429195881, 48.96580271422863, 49.32105325162411, 49.471939355134964, 46.4086539298296, 42.67336696386337, 37.00005479156971, 29.55268431454897, 30.886173360049725, 44.28721636533737, 45.90480476617813, 39.80635620653629, 37.59258359670639, 38.93094778060913, 44.306804314255714, 45.86188606917858, 43.78614105284214, 44.253234788775444, 46.24083213508129, 43.203537315130234, 36.10945478081703, 30.642378441989422, 27.435073144733906, 19.195211492478848, 13.86761236935854, 8.782016560435295, 0.6503684702329338, 1.7956849629990757, 3.527929955162108, 23.133175782859325, 6.316517908126116, 6.142687210813165, 7.181358626112342, 14.056362491101027, 50.582984536886215, 59.298272877931595, 56.746109426021576, 60.844018533825874, 60.87219022214413, 68.71705546975136, 58.848513811826706, 57.47953847050667, 19.903905764222145, 11.586685962975025, 64.5539228618145, 70.93539163470268, 41.63123868405819, 23.41983240097761, 26.72370381653309, 29.72248200327158, 27.302648350596428, 29.09485638141632, 19.194155149161816, 28.90410851687193, 26.495548859238625, 55.801518112421036, 61.51475854218006, 6.663322923704982, 0.12674755736952648, 0.15446775272721425, 0.07372461623162962, 0.08221579497330822, 0.05354136097594164, 0.020356923378130887, 0.04250331323419232, 0.08516418442013673, 0.06510466002509929, 0.03130386692646425, 0.03819555415248033, 0.08110385737381876, 0.17545849434100091, 0.13582763029262424, 0.19354208023287356, 0.1101401328924112, 0.13639108365168795, 0.21008275594795123, 0.2225045269005932, 0.2054737220169045, 0.26739429391454905, 0.14325825031846762, 0.09104237251449376, 0.11644116704701446, 0.16279402625514194, 0.13295911077875644, 0.3285102144582197, 1.9892908679321408, 57.37447030842304, 79.08257246017456, 52.29559823870659, 39.64169584214687, 60.486100539565086, 64.37177583575249, 56.90543107688427, 36.330929696559906, 31.45618077367544, 28.275690637528896, 61.39572232961655, 51.55700907111168, 12.674980815500021, 14.42660702392459, 52.72920437157154, 71.12585261464119, 80.61351031064987, 71.47177085280418, 66.89275816082954, 60.343855172395706, 46.35053604841232, 10.144383106380701, 8.917167708277702, 4.843124644830823, 5.447116009891033, 26.339694522321224, 54.80019964277744, 32.95376591384411, 8.358413390815258, 27.69903928041458, 26.42257757484913, 41.01637467741966, 38.47007431089878, 55.0031353533268, 56.494547724723816, 60.12411296367645, 55.51024854183197, 59.632670134305954, 56.10498122870922, 61.55937574803829, 59.95832026004791, 61.88648879528046, 55.64409255981445, 60.96473045647144, 61.18124283850193, 62.61821553111076, 58.65799203515053, 58.406924307346344, 54.0468330681324, 58.78039866685867, 65.25963619351387, 63.825714737176895, 59.929217621684074, 56.07497803866863, 57.79502034187317, 51.210551261901855, 50.94414375722408, 49.85654331743717, 50.32932534813881, 51.77350625395775, 55.230427756905556, 52.35675975680351, 54.08539719879627, 52.65741862356663, 58.11715945601463, 57.451169192790985, 54.77952115237713, 50.02426251769066, 45.914805829524994, 52.88200557231903, 55.35389833152294, 60.71053549647331, 52.44249455630779, 57.53934346139431, 58.83317403495312, 58.07147070765495, 48.68215933442116, 46.04359991848469, 50.40768854320049, 52.19644255936146, 51.43250115215778, 53.79081040620804, 50.098700523376465, 50.6440244615078, 55.59099420905113, 58.0725384503603, 53.36755491793156, 50.31683161854744, 53.47192391753197, 55.13089209794998, 53.00402842462063, 53.23929280042648, 52.813107669353485, 52.159497141838074, 51.730568557977676, 47.67397463321686, 43.0652741342783, 33.60523335635662, 36.19311489164829, 49.23069790005684, 49.31879997253418, 44.757224544882774, 41.526189520955086, 41.72393091022968, 46.56989447772503, 47.54437878727913, 47.87393510341644, 46.24155409634113, 51.70123033225536, 47.33427286148071, 43.41829039156437, 36.26383289694786, 32.32479326426983, 23.710355311632156, 18.97137690335512, 12.347467839717865, 2.6895313058048487, 2.2670376766473055, 5.852740919217467, 26.466657109558582, 12.593472339212894, 11.118791420012712, 15.145738385617733, 13.60117256641388, 51.74409583210945, 63.50086256861687, 64.06922087073326, 60.668604746460915, 69.00207817554474, 73.95132020115852, 69.40777480602264, 60.7865846157074, 23.904874473810196, 9.820831418037415, 81.25658020377159, 78.05147498846054, 49.6386706084013, 24.636293426156044, 34.42339405417442, 37.82853573560715, 52.400092631578445, 42.00565919280052, 22.164531759917736, 45.41738972067833, 38.02418723702431, 68.19639220833778, 82.73198023438454, 12.316638194024563, 0.5513979122042656, 0.3319890465354547, 0.267261776025407, 0.14535918133333325, 0.21798538189614192, 0.14254234498366714, 0.23588265903526917, 0.25253780360799283, 0.27195393049623817, 0.14889995305566117, 0.1422855322016403], [0.0844638716080226, 0.13713483436731622, 0.04200961804599501, 0.03211882300092839, 0.04025329959404189, 0.13700549287023023, 0.11413198939408176, 0.03311355321784504, 0.061039939464535564, 0.052826331375399604, 0.09607569969375618, 0.05635351437376812, 0.040669826266821474, 0.04951326540322043, 0.03230805952625815, 0.29076678038109094, 0.19561451277695596, 19.615231454372406, 70.82718104124069, 42.66701750457287, 32.23125368356705, 35.143823996186256, 48.545708656311035, 46.788242161273956, 36.6910819709301, 27.343418262898922, 21.158712431788445, 48.16441431641579, 74.91708397865295, 29.068098217248917, 8.955452553927898, 36.216278448700905, 66.54240936040878, 65.60151904821396, 55.85840865969658, 56.902459636330605, 62.910545244812965, 40.94554267823696, 16.348848827183247, 6.079206867143512, 1.2786204647272825, 0.3936363151296973, 0.7650953577831388, 2.2954893624410033, 3.74426350928843, 14.1848174482584, 22.43742361664772, 27.859861850738525, 46.68871410191059, 43.60623590648174, 54.73642386496067, 55.065809190273285, 60.170888453722, 51.99721924960613, 49.62586149573326, 50.68041890859604, 54.44022595882416, 53.23542460799217, 51.06518626213074, 51.37458845973015, 55.28390608727932, 56.318567767739296, 57.985378727316856, 55.8439352363348, 47.61864960193634, 48.61071556806564, 56.62880212068558, 58.76640781760216, 52.5233618170023, 51.531090661883354, 47.69106611609459, 47.690188363194466, 48.562078177928925, 48.28107185661793, 46.52972683310509, 41.547643169760704, 37.5618926435709, 37.520813047885895, 35.062907338142395, 35.571544244885445, 38.011537715792656, 43.22231970727444, 43.59264023602009, 45.049185678362846, 40.855840891599655, 41.17355704307556, 48.66986319422722, 54.609206691384315, 52.350957468152046, 50.95120757818222, 51.895810291171074, 54.94504787027836, 50.09780757129192, 45.23141250014305, 40.17691612243652, 42.5638834387064, 41.372153386473656, 41.43147960305214, 39.53820839524269, 37.11711511015892, 35.30894033610821, 43.47256287932396, 47.76682265102863, 47.24006451666355, 46.18275225162506, 46.37273445725441, 47.199634686112404, 49.802392423152924, 46.80990859866142, 47.89059340953827, 44.399724528193474, 42.120363637804985, 40.38700304925442, 37.710008695721626, 29.669467248022556, 23.028231114149094, 27.708268985152245, 41.46714448928833, 44.83472138643265, 38.36910992860794, 29.926736243069172, 32.26523905992508, 36.14999480545521, 37.3724652081728, 35.724440440535545, 26.45392019301653, 18.73400554060936, 13.22328569367528, 12.38871082663536, 9.186947531998158, 12.453637942671776, 9.841454811394215, 28.01708411425352, 6.42875581048429, 3.6154618207365274, 6.6321389470249414, 2.1073291590437293, 0.2551220211898908, 1.1431764950975776, 4.55981707200408, 21.327506974339485, 46.47705405950546, 56.06509856879711, 47.85355679690838, 54.23058360815048, 59.15017582476139, 54.99381065368652, 59.23072770237923, 49.8876940459013, 9.951494056731462, 16.48004438728094, 68.3039416372776, 44.52246934175491, 21.570899114012718, 9.567973986268044, 28.466930575668812, 31.662160120904446, 39.70283456146717, 16.598333939909935, 33.063739612698555, 29.237035252153873, 23.280452080070972, 56.989592760801315, 22.455292157828808, 1.8754935055039823, 0.03216306613467168, 0.025759914315131027, 0.013833920274919365, 0.04259975903551094, 0.04790546554431785, 0.039628837985219434, 0.08356349804671481, 0.06166988554468844, 0.05855846480699256, 0.029862937117286492, 0.05911634834774304, 0.031052815065777395, 0.050902584407594986, 0.044263758027227595, 0.02676076539501082, 0.060146953983348794, 0.02228996017947793, 0.03221418897737749, 0.06469933607149869, 0.06660603219643235, 0.046105442015687004, 0.07006498955888674, 0.07113490675692447, 0.06977773387916386, 0.06138024014944676, 0.04736542694445234, 0.22831555805169046, 0.12921919114887714, 22.32163242995739, 84.99726668000221, 49.83871087431908, 25.494847856462002, 43.39223138988018, 46.417982429265976, 30.93467205762863, 40.453423485159874, 32.04947903752327, 26.999804601073265, 42.21975490450859, 66.61807850003242, 29.778724685311317, 12.154858075082302, 39.7789216786623, 73.05454552173615, 71.52857020497322, 61.684943810105324, 60.11814348399639, 66.14871248602867, 44.62437987327576, 20.13395681977272, 5.7989210821688175, 0.1418890175409615, 0.5862548074219376, 1.2001828174106777, 1.5583971957676113, 3.3742574136704206, 15.350191164761782, 25.46568252146244, 31.97111204266548, 47.955873906612396, 45.86421154439449, 56.591609716415405, 54.60978806018829, 60.69152511656284, 54.59183782339096, 54.33580756187439, 54.79246325790882, 57.62819789350033, 56.48165121674538, 54.586723297834396, 53.783757984638214, 55.7072489708662, 54.56249199807644, 55.63021570444107, 57.22494833171368, 50.76546594500542, 50.690260380506516, 56.429632008075714, 58.0516167730093, 54.30789425969124, 53.73117260634899, 49.74083952605724, 50.83336070179939, 51.50798410177231, 49.614640697836876, 48.93094338476658, 47.12542466819286, 44.53071489930153, 44.296704456210136, 44.96052123606205, 44.53633859753609, 46.22151777148247, 50.887310206890106, 52.81108617782593, 51.255681440234184, 48.25388051569462, 43.52444909512997, 54.29456077516079, 59.05790537595749, 57.28001497685909, 55.84092579782009, 56.73330791294575, 58.92111271619797, 52.710171192884445, 50.423947870731354, 44.28133428096771, 45.613379403948784, 48.381724655628204, 48.99495095014572, 48.608291298151016, 44.65059086680412, 46.0449830442667, 52.42511808872223, 55.255647003650665, 51.40504762530327, 46.37329302728176, 49.03166078031063, 48.97450044751167, 52.271446734666824, 48.686616495251656, 49.4790867716074, 45.99848113954067, 46.31022401154041, 44.364808201789856, 42.092716321349144, 31.744055226445198, 24.045729115605354, 29.16054915636778, 42.23661080002785, 46.0682187974453, 40.52854165434837, 34.109466299414635, 33.16001884639263, 39.73088465631008, 39.7405057400465, 39.11389276385307, 30.388897843658924, 21.88681036233902, 14.676155783236027, 15.369481779634953, 9.917698670178652, 14.510424826294184, 13.338201977312565, 34.588536992669106, 13.220158461481333, 6.122323628515005, 8.911499362438917, 2.0287420134991407, 1.8498319387435913, 3.087864168919623, 7.64686357229948, 26.06316816061735, 51.56458966434002, 61.316606774926186, 51.840827241539955, 57.1084313839674, 63.84140029549599, 59.26688276231289, 66.65310502052307, 53.4355104714632, 11.252112966030836, 22.008515931665897, 60.61057426035404, 42.90846034884453, 29.05648984014988, 16.145510338246822, 30.147603191435337, 28.3439102768898, 27.818520069122314, 23.50538671016693, 32.53382384777069, 29.831748940050602, 24.90441083908081, 67.05680295825005, 30.916068255901337, 2.2597130946815014, 0.05311190237989649, 0.007910009389888728, 0.06966617424041033, 0.06805076365708373, 0.1036798486893531, 0.042551897931843996, 0.028192071404191665, 0.008854187290125992, 0.026464568691153545, 0.08125161897623911, 0.08801296280580573, 0.12167638808023185, 0.12215468741487712, 0.14709887938806787, 0.1912073726998642, 0.15662470104871318, 0.1586947141913697, 0.1937075940077193, 0.19164932164130732, 0.20116506493650377, 0.19626507943030447, 0.16811918816529214, 0.11955751193454489, 0.15466728655155748, 0.16860922827618197, 0.15273639641236514, 0.745365807088092, 0.20656414475524798, 36.447070464491844, 96.77187725901604, 61.260928362607956, 44.835507944226265, 49.72767323255539, 73.5692735016346, 58.65218214690685, 49.56737123429775, 35.07150247693062, 27.677807919681072, 53.70423965156078, 82.57568702101707, 37.13094636797905, 14.992807041853666, 43.723725602030754, 77.18229442834854, 78.02995294332504, 67.01461002230644, 67.93368190526962, 71.80357664823532, 52.67484828829765, 22.13866274803877, 8.652722798287868, 1.485701990313828, 0.8062158606480807, 1.696515390649438, 4.187342058867216, 6.152982283383608, 18.34715399891138, 31.53917782008648, 37.6764564961195, 54.911336079239845, 51.97183661162853, 63.63525375723839, 60.9870732575655, 65.96707463264465, 58.61780159175396, 57.48088739812374, 57.714951038360596, 61.87176838517189, 61.86322644352913, 60.54028943181038, 58.17734822630882, 60.85985228419304, 59.21822637319565, 62.38669015467167, 59.95206959545612, 55.286748334765434, 54.78857606649399, 62.473724484443665, 62.70941063761711, 56.58092848956585, 56.81022338569164, 51.980534344911575, 51.342563778162, 53.526576384902, 51.153482124209404, 51.39885775744915, 50.804087072610855, 52.63516701757908, 53.42279255390167, 55.97635053098202, 55.61680622398853, 53.44798520207405, 58.781626001000404, 56.446818485856056, 54.459509924054146, 48.665588423609734, 46.51500642299652, 54.09366175532341, 57.97801472246647, 56.58936783671379, 54.847803488373756, 57.18712516129017, 59.62282486259937, 53.645019829273224, 52.66693711280823, 47.40052230656147, 49.3457443267107, 51.23181492090225, 52.587528973817825, 51.819913163781166, 53.19027543067932, 53.77498425543308, 58.061370849609375, 58.14283087849617, 55.46333245933056, 49.876226261258125, 52.156290113925934, 51.6270849108696, 55.4938980191946, 53.48989315330982, 53.50249707698822, 48.77803958952427, 49.83507826924324, 46.65334939956665, 46.52517467737198, 36.32194697856903, 30.730645805597305, 34.14951995015144, 47.07358404994011, 52.72926516830921, 46.20952941477299, 39.78138014674187, 36.15320183336735, 42.87255607545376, 41.69173143804073, 41.69790990650654, 32.40395821630955, 24.122137315571308, 16.542790420353413, 17.690330743789673, 12.612575814127922, 17.37561073154211, 15.816402398049831, 33.36114585399628, 17.579363398253918, 7.347854766994715, 11.737225335091352, 4.603444430977106, 1.8760448321700096, 5.493682036176324, 9.853618908673525, 25.445853285491467, 57.217135950922966, 65.43011784553528, 56.83246359229088, 63.93254220485687, 69.9700078368187, 64.43920701742172, 70.47794938087463, 58.34472544491291, 15.037708282470703, 21.41682118177414, 79.03091803193092, 51.3481342792511, 30.1643792912364, 14.353102818131447, 40.036190673708916, 41.57290801405907, 53.48210737109184, 26.644578762352467, 41.85131147503853, 41.1958846449852, 35.11677324771881, 79.63586077094078, 52.55568668246269, 2.7961664088070393, 0.14373985963175073, 0.12302085538976826, 0.17180304595967755, 0.08317086481838487, 0.1831005373969674, 0.1353255970752798, 0.19025932357180864, 0.16379286797018722, 0.19618914288002998, 0.17098272044677287, 0.14167182060191408], [0.11570920163649134, 0.06730696841259487, 0.09055298549355939, 0.03784577624173835, 0.046003585957805626, 0.10921223307377659, 0.0603846490412252, 0.04996708870748989, 0.0675936377956532, 0.03605715581215918, 0.061368191381916404, 0.05819529855216388, 0.03259966048062779, 0.012533563440229045, 0.10198922143899836, 0.0939553021453321, 0.030090435066085774, 4.188314331695437, 70.35007104277611, 52.74970047175884, 37.5884760171175, 37.717391699552536, 36.352854520082474, 51.53280436992645, 37.130308002233505, 28.042282462120056, 26.63661628961563, 47.36678011715412, 70.37472411990166, 46.641820818185806, 14.81900341808796, 15.743987783789635, 45.17704501748085, 59.44994933903217, 55.5936274677515, 55.80087974667549, 58.726437762379646, 36.67443126440048, 14.083418939262629, 7.057818230241537, 1.8515847134403884, 0.21797093970235437, 0.8700328425038606, 2.0930844359099865, 1.6410637786611915, 9.797621313482523, 22.686141170561314, 28.34197048097849, 38.56264114379883, 42.57214419543743, 50.89497059583664, 55.39100334048271, 55.41264697909355, 57.29172594845295, 57.12670840322971, 51.75264157354832, 49.50719766318798, 48.80479395389557, 48.34722250699997, 51.3768645375967, 57.3262432962656, 57.29357644915581, 54.45238530635834, 48.91514763236046, 45.7036891579628, 51.425349935889244, 56.33973263204098, 57.846450582146645, 55.00941641628742, 54.57117073237896, 49.78165313601494, 48.7357896566391, 48.848970383405685, 46.06395162642002, 47.09757596254349, 44.3133931607008, 40.777420699596405, 38.12079705297947, 36.66542574763298, 38.98630701005459, 41.70608326792717, 43.49846608936787, 43.225868716835976, 43.153220415115356, 41.58653028309345, 41.72856666147709, 51.86827316880226, 55.19808009266853, 53.33719454705715, 49.49751578271389, 51.90584555268288, 54.63060714304447, 51.76476292312145, 47.719222605228424, 44.76404897868633, 42.47295431792736, 45.635718405246735, 43.13359446823597, 40.127138793468475, 37.872172594070435, 35.49922272562981, 44.65655654668808, 46.37765899300575, 47.85197988152504, 44.868136793375015, 48.81641373038292, 48.957112580537796, 48.757600486278534, 47.82657824456692, 47.29408621788025, 43.871913850307465, 42.50505119562149, 39.72980931401253, 39.531000182032585, 27.78010793030262, 20.939173512160778, 18.832032680511475, 23.617699183523655, 35.312223359942436, 40.22981308400631, 35.81300608813763, 29.39719095826149, 30.49767840653658, 38.62899698317051, 27.66974665224552, 26.312888860702515, 24.50460199266672, 17.69705258309841, 23.07611044496298, 21.386453211307526, 51.62907600402832, 30.40872137993574, 47.740721851587296, 10.34236578270793, 10.3053605183959, 2.825964172370732, 1.1831535561941564, 0.8450504299253225, 0.44966466492041945, 5.010603982955217, 37.9525762796402, 54.87753689289093, 57.69553408026695, 57.829712480306625, 60.77923581004143, 57.81907305121422, 62.050529792904854, 58.520374819636345, 30.509849153459072, 5.15274248085916, 35.89837610721588, 54.54921551048756, 19.469304084777832, 7.631015572696924, 16.7136824503541, 32.82352030277252, 31.942055001854897, 35.69506801664829, 20.56549396365881, 34.7762431204319, 25.866422317922115, 35.84875077009201, 59.72900256514549, 10.997650120407343, 0.6013956293463707, 0.10955884572467767, 0.29386818583589047, 0.06724304723320529, 0.0387897584005259, 0.0373245362425223, 0.021958819452265743, 0.0638030369009357, 0.12075069244019687, 0.029063204347039573, 0.02770411487290403, 0.023821229769964702, 0.05894543544854969, 0.02492165851435857, 0.14718946593347937, 0.03569201173377223, 0.05746031631133519, 0.02602360866148956, 0.025401590573892463, 0.06391884904587641, 0.16621059214230627, 0.04142112833505962, 0.0308416091138497, 0.01609113831364084, 0.07865265492000617, 0.030559589285985567, 0.10776056253234856, 0.18909508682554588, 0.08401915445574559, 6.027660733088851, 82.7838322520256, 63.134178444743156, 37.178405821323395, 39.507426247000694, 42.001597210764885, 36.802640184760094, 35.545439645648, 32.88422964513302, 29.994070529937744, 42.790849059820175, 70.70890098810196, 58.46017464995384, 20.87891634553671, 16.48404937237501, 49.132431373000145, 66.55741095542908, 65.56837722659111, 63.115346655249596, 63.3946468681097, 43.11112627387047, 18.499626517295837, 8.516650199890137, 2.751669608987868, 0.20854952337685972, 0.5340277380309999, 3.41476917732507, 2.8563699033111334, 11.774626728147268, 26.86245147138834, 34.008764103055, 42.94240012764931, 46.318663358688354, 54.34846468269825, 60.31031057238579, 57.618565410375595, 58.283776715397835, 58.947555497288704, 53.33482727408409, 51.40946298837662, 51.611767932772636, 51.56324453651905, 52.81101398169994, 56.618801057338715, 57.765526324510574, 55.60492046177387, 52.14955687522888, 49.32097725570202, 51.97553761303425, 56.909200474619865, 58.45587708055973, 59.05985467135906, 54.432789757847786, 53.52744273841381, 52.895662039518356, 51.40034347772598, 51.41335777938366, 48.88986378908157, 48.27195234596729, 49.667780846357346, 45.9991043061018, 46.71918086707592, 46.81805156171322, 47.306294962763786, 54.025322422385216, 51.89038798213005, 50.55605538189411, 46.099669709801674, 45.44389709830284, 56.04877084493637, 58.406358137726784, 57.08606578409672, 52.726035341620445, 57.480967193841934, 58.857344537973404, 55.481833666563034, 48.49319167435169, 49.187904596328735, 46.296609342098236, 47.74712830781937, 49.77738216519356, 49.14180546998978, 46.461448296904564, 44.73938450217247, 51.41692578792572, 52.11253546178341, 51.053452491760254, 49.05566789209843, 51.343825310468674, 51.60471171140671, 50.16464218497276, 49.46433216333389, 51.688953191041946, 47.46934421360493, 45.37110060453415, 43.5320220887661, 43.38677108287811, 32.49896451830864, 22.671468257904053, 20.62350545078516, 25.45878019183874, 36.447138860821724, 42.57709912955761, 39.26630638539791, 31.90249152481556, 31.75311964005232, 43.395366221666336, 31.159741580486298, 30.477881468832493, 28.138305209577084, 22.135313227772713, 25.380715280771255, 26.127449311316013, 56.751098558306694, 36.48667573928833, 51.72144144773483, 18.75786256045103, 9.089632853865623, 2.4018219066783786, 2.1677715657278895, 2.995460727252066, 0.9616038913372904, 8.89464346691966, 39.31825339794159, 59.244000390172005, 61.184658855199814, 62.619534060359, 63.34749899804592, 61.779528334736824, 65.1234818994999, 63.61471205949783, 34.34578321874142, 7.2940396796911955, 34.00456912815571, 65.23328080773354, 24.097548834979534, 17.40329224616289, 20.185113474726677, 35.58078534901142, 26.66765682399273, 32.83372275531292, 26.965123862028122, 34.8290640860796, 31.15938249975443, 39.24605347216129, 75.95687538385391, 16.005172468721867, 0.7764197594951838, 0.10756100644357502, 0.14721202722284943, 0.03665326366899535, 0.03242794606194366, 0.06720085613778792, 0.01498838200859609, 0.050700608917395584, 0.01527534917840967, 0.021403980572358705, 0.05509420108865015, 0.030435153385042213, 0.1689663645811379, 0.23438451520632952, 0.17832652403740212, 0.13840692001394928, 0.12426698071067221, 0.29085530375596136, 0.1973642298253253, 0.29732389259152114, 0.29174071562010795, 0.16528425825526938, 0.17434790002880618, 0.1840092081693001, 0.13419052673270926, 0.34009870199952275, 0.21830679121194407, 0.716520604910329, 0.19960734149208292, 10.463789217174053, 103.49152028560638, 70.77770009636879, 52.30357401072979, 50.92463560402393, 57.65771470963955, 66.80723235011101, 46.7325409501791, 36.14193543791771, 35.18181435763836, 54.821501299738884, 77.04958274960518, 56.618029698729515, 21.38224683701992, 21.289184130728245, 55.39782017469406, 70.66758960485458, 67.96602576971054, 66.07322573661804, 69.08678323030472, 45.47413967549801, 21.560719460248947, 12.598529867827892, 3.953999192453921, 0.4274923796765506, 2.6257384289056063, 7.428477415814996, 4.042629199102521, 15.00131668522954, 30.058359280228615, 38.08031402528286, 46.466190442442894, 48.444212302565575, 57.09756016731262, 65.50871282815933, 62.79730752110481, 61.969905719161034, 62.50100702047348, 58.14090818166733, 55.28919160366058, 56.78937390446663, 55.3409144282341, 55.95751114189625, 60.859377309679985, 61.761623695492744, 62.173156812787056, 56.82017125189304, 53.79632771015167, 54.03195686638355, 62.831961661577225, 62.492719665169716, 62.59567894041538, 57.84515865147114, 55.43999031186104, 53.202043399214745, 52.067401483654976, 50.51567114889622, 50.37688359618187, 52.631826996803284, 55.389977395534515, 52.93022878468037, 56.36684037744999, 57.49732531607151, 54.70810018479824, 58.40062044560909, 52.93264165520668, 51.06277719140053, 47.05173522233963, 47.08859704434872, 56.65396437048912, 60.50679802894592, 57.44545429944992, 53.51367607712746, 57.023122161626816, 58.945173025131226, 55.99329002201557, 50.5886310338974, 52.66019247472286, 49.67136025428772, 52.90774539113045, 54.57238286733627, 54.66016195714474, 53.29647593200207, 51.931767761707306, 57.507755756378174, 56.56477175652981, 54.15509685873985, 51.69357754290104, 56.50114417076111, 55.77276885509491, 55.52237369120121, 54.066079035401344, 54.47566285729408, 51.464324444532394, 48.735177889466286, 47.37987041473389, 47.43803009390831, 38.28076086938381, 25.76824888586998, 25.49186311662197, 29.55061912536621, 42.852341160178185, 46.91140495240688, 44.45178173482418, 37.21781350672245, 36.39144524931908, 46.35862201452255, 36.23126104474068, 33.71462568640709, 31.943871304392815, 23.90713345259428, 30.798588059842587, 29.926002882421017, 60.664926543831825, 40.570939779281616, 58.30929234623909, 25.78904327005148, 10.594880282878876, 3.5280031012371182, 3.7413426535204053, 3.533495469018817, 1.6425394057296216, 8.809751272201538, 43.552977964282036, 61.68323390185833, 66.3723836839199, 66.0523496568203, 69.24496874213219, 65.89580565690994, 70.65667659044266, 69.25779685378075, 36.764182448387146, 7.123945606872439, 41.48939609527588, 72.86631882190704, 29.69307728111744, 13.891217652708292, 24.13023468106985, 44.92855355143547, 40.68004712462425, 49.535593539476395, 29.08282432705164, 44.04347084462643, 40.739483535289764, 52.51947082579136, 91.29998087882996, 27.957556508481503, 1.249460473190993, 0.3237173950765282, 0.42136010248214006, 0.14421453728573397, 0.17050164547981694, 0.16056403575930744, 0.2990195219172165, 0.11073350222432055, 0.16548625600989908, 0.09200921282172203, 0.19220605114242062, 0.12016199121717364], [0.08173835652996786, 0.021671331851393916, 0.07916717848274857, 0.08855130188749172, 0.040903688131948, 0.05950332270003855, 0.03595123278500978, 0.055569164469488896, 0.08380082945222966, 0.04855654427956324, 0.10184448779909872, 0.08118489247863181, 0.05680121495970525, 0.03006045415531844, 0.05282018639263697, 0.1001741063373629, 0.11680846335366368, 1.4218940329737961, 59.02367681264877, 61.83108016848564, 43.640684857964516, 46.466441228985786, 34.57707680761814, 43.20529282093048, 50.327425450086594, 31.6547030210495, 26.471024975180626, 35.45251563191414, 55.40006585419178, 61.381701081991196, 22.67834398895502, 5.790387690067291, 19.13780227303505, 58.211633786559105, 45.350216925144196, 43.25891554355621, 57.33105003833771, 46.265386417508125, 25.332634560763836, 14.293246529996395, 0.7274245354346931, 0.16293576161842793, 0.9776421182323247, 0.8075842028483748, 2.205580249428749, 8.263154402375221, 17.377212345600128, 25.78594073653221, 33.75564068555832, 44.560167118906975, 50.93899503350258, 56.289712116122246, 59.3311221152544, 59.37913253903389, 54.88043613731861, 55.562552735209465, 50.794492587447166, 47.65714913606644, 50.95250330865383, 58.49534556269646, 58.832752257585526, 53.23430746793747, 49.4420425593853, 41.06223821640015, 35.3019031137228, 50.540297627449036, 53.126651644706726, 55.0301519036293, 53.63241970539093, 53.15214067697525, 50.41881434619427, 50.34939207136631, 49.60457883775234, 49.33097451925278, 45.29668539762497, 40.03130413591862, 40.697404593229294, 39.831062480807304, 38.25432948768139, 38.31157721579075, 42.63441905379295, 45.580013394355774, 45.265648663043976, 43.094589561223984, 42.159167155623436, 44.11360748112202, 53.38418282568455, 55.34945257008076, 53.011392429471016, 50.58397248387337, 53.52064490318298, 55.197171941399574, 50.75390316545963, 50.061766505241394, 44.48693364858627, 42.37073980271816, 42.704137712717056, 40.51016204059124, 41.215776577591896, 42.30207368731499, 36.40091434121132, 43.04554559290409, 47.65777990221977, 45.501828789711, 45.34715808928013, 48.76779153943062, 52.40310586988926, 52.89651699364185, 40.896426513791084, 37.17887319624424, 43.757984563708305, 42.17475771903992, 42.35142923891544, 39.165011420845985, 33.06514173746109, 22.575855888426304, 17.12112508714199, 12.10860600695014, 17.783855125308037, 24.45548202842474, 34.534340500831604, 31.855976320803165, 21.686950586736202, 24.374227188527584, 24.2431266233325, 28.50974477827549, 31.554259210824966, 31.048234663903713, 29.827882647514343, 25.638263560831547, 36.205886006355286, 24.69087939709425, 29.53334715217352, 2.223870805464685, 4.076439309865236, 0.26347599166911095, 1.0934581817127764, 3.441852699033916, 2.5664882082492113, 13.022957593202591, 41.43051065504551, 51.912962570786476, 60.88154152035713, 55.32300978899002, 55.479785576462746, 55.76450049877167, 59.52482432126999, 57.56524287164211, 31.35533608496189, 7.723821792751551, 31.204174496233463, 38.93935672938824, 46.6729449480772, 15.721454992890358, 27.43019800633192, 30.354787074029446, 35.66993996500969, 27.145205698907375, 28.264053761959076, 26.64038948714733, 25.50100352615118, 46.245285496115685, 46.75503194332123, 4.966077972203493, 0.15379722230136395, 0.024463990885124076, 0.16073483362561092, 0.010478196581971133, 0.06243124371394515, 0.02874937421438517, 0.06923251508851536, 0.08983458654256538, 0.09936946240486577, 0.014789231317990925, 0.07452341946191154, 0.0477176428103121, 0.10705502500059083, 0.04098005883861333, 0.036352534298202954, 0.055603199361939915, 0.10120761377038434, 0.048057950916700065, 0.04143997146456968, 0.028981811155972537, 0.0866703137580771, 0.06037445193214808, 0.07607516119605862, 0.022235067226574756, 0.11546084191650152, 0.04967095323081594, 0.028054221183992922, 0.07519432838307694, 0.24330303742317483, 0.9608933294657618, 66.07057347893715, 72.55661264061928, 48.00914324820042, 47.45432361960411, 41.31651297211647, 37.4644772708416, 39.58870768547058, 36.9492819160223, 28.576890975236893, 41.49642571806908, 58.20066757500172, 72.45147988200188, 35.30023880302906, 9.116860292851925, 20.286803618073463, 63.01233418285847, 51.05656452476978, 49.044397696852684, 61.46520160138607, 51.75036169588566, 31.599790267646313, 15.731692593544722, 3.386865137144923, 0.18453225900884718, 1.0532335401512682, 1.2438529240898788, 2.405127016827464, 9.38798239454627, 19.61073439568281, 29.528633505105972, 36.340995356440544, 48.477946892380714, 52.635653391480446, 60.40663920342922, 59.78023521602154, 59.46226067841053, 56.98452763259411, 58.23347881436348, 51.79402135312557, 49.82842482626438, 54.57166850566864, 58.823628947138786, 60.719062238931656, 54.834245815873146, 52.74809315800667, 42.782094329595566, 38.04792836308479, 50.54881677031517, 56.51124022901058, 57.51439020037651, 56.77930064499378, 55.222341790795326, 55.7985732704401, 53.75608786940575, 51.373266130685806, 53.81550908088684, 47.7950931340456, 46.248560920357704, 47.965460792183876, 47.5415213406086, 48.72571639716625, 46.57847821712494, 50.73939174413681, 53.556473180651665, 52.05466836690903, 48.350064754486084, 47.10883095860481, 47.76107355952263, 54.29056338965893, 56.65327660739422, 56.389878541231155, 53.31952929496765, 57.79941290616989, 58.89709800481796, 54.78039510548115, 51.66516646742821, 46.626127660274506, 46.388397216796875, 48.64482253789902, 48.921508491039276, 49.73209619522095, 50.08846387267113, 44.997854232788086, 51.75445407629013, 54.280296340584755, 48.84735926985741, 44.970548897981644, 49.90226246416569, 57.206716910004616, 55.70939965546131, 45.18198475241661, 44.35319222509861, 47.90309853851795, 42.85161539912224, 45.76386272907257, 41.86621807515621, 36.73250734806061, 27.297680117189884, 20.08286666125059, 13.981514107435942, 20.593549758195877, 27.20194425433874, 36.897885873913765, 35.3083361685276, 22.64478988945484, 26.957134790718555, 27.919286862015724, 30.60736332088709, 37.02940061688423, 34.87104043364525, 32.35900282859802, 28.852746672928333, 39.793459698557854, 28.87527946382761, 33.12300123274326, 5.605218401178718, 3.224967224523425, 0.40505859127733856, 2.938738320954144, 2.605887344107032, 2.5945366406813264, 17.739733792841434, 43.319347500801086, 59.76633936166763, 61.931926757097244, 58.66231620311737, 58.04942429065704, 60.82816958427429, 62.26636961102486, 66.42089948058128, 36.12991288304329, 10.286171548068523, 30.991564504802227, 48.97138461470604, 50.91979466378689, 22.66940876841545, 28.255606815218925, 32.126789689064026, 25.961194932460785, 30.27983419597149, 32.438574358820915, 24.311346262693405, 26.5874108299613, 55.21617852151394, 55.70149227976799, 5.677894251421094, 0.11228145158383995, 0.029141918384993915, 0.05249263209407218, 0.025649495728430338, 0.08674288095789962, 0.07503006141632795, 0.07904337340733036, 0.08604354035924189, 0.00654053866128379, 0.05971792954369448, 0.02899122344388161, 0.01528431710539735, 0.2155736691202037, 0.19436034257523715, 0.11381246513337828, 0.10582061819150113, 0.14577460591681302, 0.14018469024449587, 0.09611294066417031, 0.14927234791684896, 0.2341647504363209, 0.23434228700352833, 0.14041524584172294, 0.11875347656314261, 0.20794179348740727, 0.11419786242186092, 0.10267293982906267, 0.2939699194394052, 0.27391869225539267, 1.707424249034375, 80.50013199448586, 82.95847088098526, 57.55221337080002, 56.34697124361992, 54.73374500870705, 62.18186214566231, 64.6681447327137, 42.33103573322296, 31.71551115810871, 42.457667738199234, 59.96840491890907, 66.77668958902359, 32.40696385502815, 9.368767775595188, 27.609088607132435, 68.12370210886002, 56.072253584861755, 53.19912135601044, 68.65403965115547, 57.213043570518494, 36.83029890060425, 20.324793979525566, 3.13438531011343, 0.27598034881521016, 1.4150443067774177, 2.1209326665848494, 3.5551106091588736, 11.387464553117752, 24.933792762458324, 34.053829684853554, 40.36061726510525, 51.70236647129059, 54.45774681866169, 62.95801229774952, 63.406129851937294, 63.219681456685066, 60.58225817978382, 61.71146638691425, 56.836620569229126, 55.129375979304314, 59.39758434891701, 64.06141608953476, 66.49464592337608, 62.46479116380215, 56.223158687353134, 44.30553898215294, 40.38603030145168, 53.69522653520107, 58.16066712141037, 59.62774179875851, 59.091617166996, 57.51322366297245, 56.96676358580589, 55.03540702164173, 52.73424670100212, 55.67889489233494, 50.575206354260445, 48.82640719413757, 53.5565871745348, 56.232179403305054, 58.44241440296173, 55.924392119050026, 59.08140331506729, 58.64558570086956, 55.919486582279205, 49.00954596698284, 49.10104885697365, 49.507733434438705, 56.78894832730293, 57.12195485830307, 54.68069605529308, 52.89234481751919, 56.84202007949352, 57.87810668349266, 53.22854697704315, 53.19708466529846, 48.91032949090004, 46.261476427316666, 50.59102110564709, 50.73627591133118, 54.667552560567856, 58.26561748981476, 50.64879320561886, 55.91086104512215, 58.9166821539402, 51.23590350151062, 48.803942799568176, 56.41287490725517, 59.84184890985489, 58.856462985277176, 50.26186376810074, 45.45367017388344, 50.42502321302891, 46.28535054624081, 48.235500901937485, 46.47488817572594, 42.99304760992527, 33.72711181640625, 22.229299284517765, 16.683869250118732, 24.331920258700848, 31.99472777545452, 41.12573280930519, 41.30254112184048, 26.673379316926003, 30.2968667820096, 32.758213207125664, 36.134712025523186, 39.8407481610775, 37.52205178141594, 35.64673461019993, 32.74767257273197, 46.17376573383808, 33.59976924955845, 35.92642240226269, 8.885443210601807, 4.718488482758403, 0.6009796704165637, 4.168081842362881, 6.6512642707675695, 7.224532384425402, 16.52271419763565, 47.14684411883354, 63.16865399479866, 69.11907389760017, 64.96985614299774, 65.58874413371086, 64.83782842755318, 69.04525145888329, 67.04617112874985, 37.507023587822914, 9.512941539287567, 38.038421273231506, 52.735561430454254, 59.03344228863716, 19.29932400584221, 36.166440322995186, 38.09773229062557, 44.785582423210144, 39.15260128676891, 35.755644366145134, 36.2504880130291, 37.48155735433102, 63.26856963336468, 76.74096331000328, 9.661367274820805, 0.41414182574953884, 0.20452015131013468, 0.2880405751056969, 0.13083535130135715, 0.19271820725407451, 0.1568157595465891, 0.13497727748472244, 0.15908205590676516, 0.2247768346569501, 0.12520656193373725, 0.17086808831663802, 0.10665250636520796], [0.08351458309334703, 0.03186158348398749, 0.10620223052683286, 0.047687927217339166, 0.013568445701821474, 0.038826661693747155, 0.033573187538422644, 0.014894700707372976, 0.17902884806971997, 0.06403549981769174, 0.06752095927367918, 0.012186271724203834, 0.14968615461839363, 0.059441149278427474, 0.3149002947611734, 0.0563630806573201, 0.6779530900530517, 0.025658407066657674, 28.874289616942406, 70.36697253584862, 49.000038877129555, 54.14653591811657, 42.427493557333946, 42.13194161653519, 52.81011343002319, 39.323797300457954, 25.092749632894993, 24.639143273234367, 48.10853451490402, 67.86967054009438, 42.080678567290306, 22.491407319903374, 18.70490290224552, 48.51029835641384, 64.99096781015396, 62.90288485586643, 57.891033589839935, 54.01785582304001, 36.200748682022095, 17.428156211972237, 6.639720015227795, 0.9919949574396014, 0.3296319558285177, 2.0916566625237465, 3.9590935315936804, 10.600059404969215, 15.048797987401485, 23.462494611740112, 30.7751452177763, 47.76689104735851, 51.2461743503809, 55.09184919297695, 57.468165680766106, 60.47997146844864, 60.574046820402145, 58.74909594655037, 53.280919566750526, 51.90892718732357, 57.39471182227135, 58.589200526475906, 54.244065284729004, 46.868212670087814, 43.33648458123207, 34.58618111908436, 33.23741689324379, 52.086275070905685, 53.55561822652817, 56.401840299367905, 55.39267525076866, 53.93221601843834, 51.50945842266083, 52.438200786709785, 51.2908523529768, 48.59171278774738, 43.68656739592552, 38.35573084652424, 41.12457387149334, 40.834368243813515, 39.81069937348366, 41.37591138482094, 44.95519392192364, 44.471723064780235, 48.20559270679951, 46.354826018214226, 43.53636525571346, 44.51167032122612, 53.49923685193062, 57.62075029313564, 51.97333753108978, 49.10816587507725, 55.918893814086914, 56.51491843163967, 52.29347035288811, 50.11521823704243, 47.823857590556145, 43.00837978720665, 46.04225479066372, 44.433390721678734, 44.2634030431509, 38.895757868885994, 36.41221113502979, 40.242132022976875, 44.36031684279442, 44.32876713573933, 44.773510470986366, 50.47794297337532, 56.30887448787689, 54.54335242509842, 39.44685369729996, 34.00198146700859, 38.342822939157486, 37.2324313223362, 38.02828721702099, 40.78997902572155, 34.34888005256653, 24.312913678586483, 20.906899943947792, 13.157427627593279, 8.733014389872551, 20.104677490890026, 22.907433696091175, 31.413571760058403, 21.776076704263687, 19.655689783394337, 16.17858376353979, 26.761414892971516, 13.305158000439405, 8.888217061758041, 7.449657954275608, 14.328266400843859, 16.17614809423685, 7.6129076443612576, 3.4361530048772693, 1.3775557558983564, 2.1824644273146987, 0.6915251305326819, 2.7355948090553284, 5.116229290142655, 1.7294140253216028, 14.663706701248884, 42.427159175276756, 55.25689333677292, 56.74902766942978, 57.91680760681629, 58.00549104809761, 57.46722713112831, 61.72695815563202, 44.72444750368595, 19.25029333680868, 12.421029042452574, 45.69765888154507, 36.089878231287, 21.03687956929207, 14.965379163622856, 31.408246345818043, 29.57961156964302, 41.753447726368904, 27.45161935687065, 25.855427607893944, 28.251539133489132, 34.08553898334503, 60.04969395697117, 32.9151713848114, 1.4539126586169004, 0.12122231244575232, 0.3628934413427487, 0.007458282652805792, 0.03369111851498019, 0.013433695803541923, 0.07255499149323441, 0.06333353201625869, 0.04834042345464695, 0.029225523176137358, 0.04906835158180911, 0.03842375343083404, 0.03963268973166123, 0.10160199846723117, 0.005166019009266165, 0.08065893242019229, 0.07211731732240878, 0.054890258907107636, 0.04310001480916981, 0.06276202635490336, 0.04628408438293263, 0.13611363916425034, 0.056424727154080756, 0.0907821161672473, 0.0523194445122499, 0.10673580502043478, 0.04504505399381742, 0.18163654720410705, 0.06999634089879692, 0.7794873823877424, 0.15589678776450455, 32.008460238575935, 81.07254847884178, 55.42990185320377, 55.17553590238094, 48.33972170948982, 40.68839907646179, 39.437574595212936, 37.77224175632, 32.077696323394775, 29.517574198544025, 51.138218343257904, 67.37391874194145, 39.68795835971832, 26.985500268638134, 21.387902833521366, 52.05160193145275, 68.62685590982437, 68.05607333779335, 63.653002604842186, 57.687330320477486, 41.13433554768562, 20.83663411438465, 7.90260124951601, 1.9324904470704496, 1.6247360548004508, 3.0827019084244967, 5.052166152745485, 12.511127907782793, 18.139871321618557, 25.60018390417099, 32.9766558855772, 47.94237323105335, 53.77498425543308, 58.49905416369438, 60.25106035172939, 61.85945704579353, 61.214073076844215, 58.680551424622536, 55.909975692629814, 54.587365463376045, 57.93538860976696, 57.79757380485535, 57.06135950982571, 49.63457062840462, 44.98305782675743, 36.917755007743835, 36.41468480229378, 52.76873365044594, 55.13793312013149, 58.14074479043484, 58.27349826693535, 57.681326642632484, 54.03275862336159, 54.859628453850746, 53.91932711005211, 53.475146144628525, 47.608124166727066, 46.29804566502571, 49.691301584243774, 50.02431571483612, 49.263512939214706, 50.75080253183842, 51.41089171171188, 52.0716268569231, 51.72526404261589, 50.19890494644642, 45.62013544142246, 46.69504836201668, 58.367041647434235, 60.71893684566021, 56.616460382938385, 51.81368909776211, 58.4456442296505, 58.82804811000824, 56.04892663657665, 52.19133943319321, 50.00609569251537, 48.32986883819103, 49.42458249628544, 50.03251567482948, 50.67120440304279, 49.60243575274944, 47.892432510852814, 49.51284036040306, 52.332433462142944, 49.833812937140465, 46.590667963027954, 52.30836175382137, 56.256946474313736, 56.16342969238758, 44.13521312177181, 39.07458767294884, 42.704206109046936, 39.061877354979515, 39.875079318881035, 42.3390457034111, 38.87068681418896, 29.984014369547367, 25.399271585047245, 15.723476484417915, 12.347341496497393, 22.7447397261858, 23.4890228882432, 35.61211846768856, 23.668557554483414, 22.645718939602375, 19.426252394914627, 30.63765339553356, 14.449174012988806, 8.916148412972689, 8.738553542643785, 16.769334264099598, 20.481383576989174, 8.265792410820723, 4.532679878175259, 1.5810493240132928, 2.6563381869345903, 0.42202278098557144, 0.6026205886155367, 2.26801588665694, 2.8881031880155206, 15.277044139802456, 45.202697440981865, 58.321113511919975, 59.95043568313122, 62.75735646486282, 61.54893010854721, 61.675478518009186, 66.36458650231361, 48.9986215531826, 18.640940934419632, 15.333447363227606, 46.955455988645554, 40.15148028731346, 34.11683790385723, 19.054801426827908, 32.303309217095375, 26.57951295375824, 30.42359758168459, 31.489972360432148, 25.763844922184944, 28.913608007133007, 36.150610372424126, 72.04903587698936, 38.98404233157635, 1.4970919978804886, 0.09109124293900095, 0.23585278016980737, 0.01899886548926588, 0.04381003862363286, 0.054920954135013744, 0.05953845968178939, 0.037837620038772, 0.02765910918242298, 0.0405617064825492, 0.08386089146370068, 0.04585281123581808, 0.014094040252530249, 0.15049018256831914, 0.16014788387110457, 0.1787691260688007, 0.17968689557164907, 0.2168578072451055, 0.08112598821753636, 0.16208819928579032, 0.1033238998206798, 0.23646384972380474, 0.10389086353825405, 0.15200137335341424, 0.12988522415980697, 0.26999195921234787, 0.11504561771289445, 0.40911745629273355, 0.20915323082590476, 0.9076657262630761, 0.20897345297271386, 43.87939564883709, 93.58729094266891, 61.83180212974548, 64.83592852950096, 57.01349347829819, 62.60051988065243, 70.15860691666603, 48.284088894724846, 30.123271197080612, 31.280899979174137, 56.01434089243412, 75.96357062458992, 49.14845511317253, 36.41937755048275, 26.328616216778755, 61.91728614270687, 76.13387748599052, 76.71634063124657, 73.89515921473503, 64.52650353312492, 47.823823392391205, 25.549536421895027, 10.027917455881834, 3.578399084508419, 3.149230876006186, 4.237297028303146, 5.999889448285103, 15.344934146851301, 21.248938590288162, 30.467052049934864, 36.94349102675915, 50.333634316921234, 56.56083136796951, 60.86569257080555, 60.44481575489044, 64.61732625961304, 66.24828234314919, 63.517916053533554, 61.406361758708954, 60.115548223257065, 64.60730999708176, 64.38253685832024, 62.76768811047077, 53.89984555542469, 51.07429817318916, 41.22646540403366, 40.69859392940998, 57.39814303815365, 58.95832411944866, 60.39832524955273, 59.69409763813019, 59.193759486079216, 56.38696409761906, 57.01820522546768, 55.19485406577587, 54.36282031238079, 50.40548086166382, 49.28043343126774, 55.12997254729271, 57.0550062507391, 58.791942447423935, 57.21371233463287, 58.11757743358612, 56.230910271406174, 57.17036046087742, 51.819962561130524, 48.90089079737663, 47.00252026319504, 59.8250538110733, 61.56803548336029, 54.57830294966698, 52.17390596866608, 56.93764194846153, 58.40613394975662, 54.430688470602036, 52.82028168439865, 51.61504715681076, 49.17973503470421, 53.908896669745445, 53.961094468832016, 57.514257207512856, 54.0302849560976, 55.780106261372566, 53.464031741023064, 56.931452080607414, 53.697122633457184, 50.46762652695179, 57.12261222302914, 62.520579770207405, 62.35693395137787, 48.776671662926674, 43.916531056165695, 44.38519790768623, 41.81706391274929, 44.95960548520088, 46.03779762983322, 41.12917922437191, 35.873761028051376, 28.261813782155514, 20.020217522978783, 13.60837697982788, 26.24704599380493, 28.946063965559006, 40.39205677807331, 28.616133369505405, 26.194576509296894, 23.875973224639893, 34.22713838517666, 16.581457145512104, 11.677116360515356, 9.931240193545818, 20.078265108168125, 24.751482345163822, 9.634212031960487, 6.02966227568686, 2.719097281806171, 3.8050868455320597, 1.4139604149386287, 4.308837689459324, 10.120235402137041, 2.950423168949783, 17.094467617571354, 48.995631113648415, 62.715991884469986, 64.649016559124, 67.05593660473824, 65.98463729023933, 65.87513476610184, 71.32089614868164, 50.382617488503456, 24.007945843040943, 15.964284762740135, 49.51656796038151, 44.2576539516449, 34.11327749490738, 20.34200895577669, 42.663206309080124, 37.897357642650604, 55.01035496592522, 39.03574235737324, 33.96291956305504, 40.71721293032169, 46.196047738194466, 83.49798873066902, 56.133171916007996, 1.877711161505431, 0.292581272078678, 0.40484028111677617, 0.141245441918727, 0.14606570592150092, 0.14234684844268486, 0.16169178852578625, 0.1852053275797516, 0.15658426884328946, 0.16611887753242627, 0.16693187062628567, 0.21741211734479293, 0.0871885332162492], [0.014520520981022855, 0.06621541760978289, 0.050708297567325644, 0.09840980608714744, 0.006432600703192293, 0.03523954284901265, 0.10573868508799933, 0.03151296703435946, 0.06409795154468156, 0.05359415365091991, 0.0992309999128338, 0.03552765570930205, 0.07534625343396328, 0.0837869883980602, 0.1401864565559663, 0.10102895656018518, 0.28128171747084707, 0.04297853265597951, 10.151316784322262, 60.847027972340584, 62.77531050145626, 40.941412299871445, 36.56700722873211, 37.937893867492676, 45.70863649249077, 53.738730400800705, 22.271144539117813, 23.257628604769707, 49.02113534510136, 88.41446131467819, 82.3175896704197, 30.558475144207478, 18.254976645112038, 52.22938299179077, 64.62692454457283, 62.544222101569176, 54.22583006322384, 61.282503604888916, 39.75847877562046, 24.682928323745728, 13.999579288065434, 1.72190883429721, 1.3133345707319677, 2.112366263754666, 6.519954241812229, 14.514044132083654, 20.006329268217087, 23.87110758572817, 35.545150861144066, 45.73177345097065, 49.13211598992348, 52.83039294183254, 58.94209139049053, 59.71337400376797, 59.60840463638306, 57.418840527534485, 54.621229246258736, 55.71607209742069, 59.28679749369621, 54.37954321503639, 42.06283092498779, 33.0506607145071, 28.623111695051193, 25.23482970893383, 38.475865200161934, 51.12229339778423, 51.59868523478508, 54.56382192671299, 55.21948054432869, 54.62475165724754, 52.61515349149704, 51.14324547350407, 51.66890166699886, 49.03265632688999, 41.69900044798851, 34.47957403957844, 40.36261595785618, 39.99720476567745, 38.022933304309845, 41.95188447833061, 47.14213237166405, 47.06506870687008, 46.46513409912586, 44.687775671482086, 42.49023199081421, 46.34985588490963, 55.17637945711613, 56.564091593027115, 50.90732753276825, 53.28436978161335, 56.18183210492134, 53.978569731116295, 53.91128674149513, 49.26826648414135, 45.7367055863142, 44.988685324788094, 43.17391410470009, 45.13166405260563, 44.231488555669785, 40.57561352849007, 36.04196660220623, 41.9728859513998, 43.85086677968502, 44.32269886136055, 43.26567158102989, 46.781930699944496, 54.04398702085018, 55.99635265767574, 41.99935533106327, 29.068122915923595, 31.985205486416817, 33.97852912545204, 36.305828243494034, 40.07294990122318, 37.47194766998291, 33.5779470205307, 21.681431382894516, 23.498630672693253, 8.760473616421223, 8.472426272928715, 20.430964082479477, 22.28209365159273, 20.921876840293407, 14.32357270270586, 10.812593400478363, 16.37567348778248, 7.901169201359153, 2.914250772446394, 3.4634402906522155, 5.494684707373381, 6.084778318181634, 2.890668287873268, 1.0474099963903427, 1.3327422668226063, 2.9403128614649177, 1.2831798638217151, 3.237649518996477, 2.0425545098260045, 3.635498145595193, 20.15878278762102, 40.55056907236576, 55.32700337469578, 55.44806867837906, 58.00087429583073, 53.24583984911442, 61.601834669709206, 50.968618243932724, 26.736759915947914, 14.334979690611362, 31.12089816480875, 74.33783546090126, 59.21814277768135, 11.04350795969367, 26.073116026818752, 29.475348964333534, 33.35946634411812, 36.24476931989193, 22.187718115746975, 27.038974799215794, 28.54263011366129, 43.510367050766945, 51.166466027498245, 9.199123028665781, 0.22553222224814817, 0.13251474243588746, 0.30386654776521027, 0.061694253963651136, 0.10014134793891571, 0.040831106089171953, 0.028905739163747057, 0.009126746590482071, 0.06122765829786658, 0.04929554525006097, 0.03906699508661404, 0.040620814834255725, 0.032010558497859165, 0.07409681813442148, 0.06885561539093032, 0.04448657302418724, 0.018224772065877914, 0.031807299092179164, 0.04815899061213713, 0.060842706297989935, 0.05014074013161007, 0.036957674092263915, 0.03953737941628788, 0.08154116789228283, 0.04424406884936616, 0.0686173488793429, 0.029690873889194336, 0.07963907308294438, 0.0980569222883787, 0.3260469372617081, 0.046102035557851195, 10.505051203072071, 69.76725831627846, 72.39675521850586, 42.24602289497852, 39.500704407691956, 43.77705954015255, 32.53481179475784, 43.6629668623209, 28.483708575367928, 27.581160105764866, 53.049432188272476, 81.50589242577553, 77.72136390209198, 32.12043642997742, 20.842183716595173, 61.18522122502327, 69.69287350773811, 70.34630164504051, 61.51623286306858, 62.28548638522625, 46.63605272769928, 29.867708310484886, 16.525455750524998, 2.8960464242845774, 1.0110277798958123, 2.3474746104329824, 7.2281179670244455, 15.469622556120157, 22.75149766355753, 26.551897935569286, 40.068663731217384, 47.99437344074249, 50.01215636730194, 56.19350507855415, 61.657991856336594, 60.98678447306156, 59.4239891320467, 58.560584262013435, 55.658337995409966, 56.72547273337841, 58.61093156039715, 54.166211262345314, 46.26362331211567, 39.59253408014774, 33.99099625647068, 28.52952651679516, 39.47580814361572, 53.061469942331314, 52.832650020718575, 57.295468747615814, 57.14575298130512, 56.52415953576565, 54.98693682253361, 52.74962827563286, 51.982643231749535, 51.8626456707716, 46.97858154773712, 42.91897438466549, 48.915231227874756, 49.05003659427166, 47.025877609848976, 51.296426653862, 54.92200970649719, 53.00240211188793, 52.56625771522522, 48.13922166824341, 45.742591470479965, 48.09993177652359, 56.340245604515076, 58.62118721008301, 54.65140342712402, 55.56677430868149, 59.45187583565712, 56.90184406936169, 56.52529567480087, 52.02645108103752, 47.75718256831169, 47.37346775829792, 48.305671736598015, 51.41816072165966, 49.82514180243015, 49.87043157219887, 47.790088802576065, 50.47084115445614, 50.38244649767876, 49.53667648136616, 46.31344623863697, 51.37648455798626, 57.2402311116457, 59.697832837700844, 46.990847289562225, 38.114086613059044, 35.60021370649338, 37.825385704636574, 36.90963864326477, 43.23816865682602, 38.31560119986534, 37.2677656263113, 24.893951900303364, 26.48559909313917, 9.971811566501856, 13.341814633458853, 21.083218082785606, 24.011757038533688, 23.1639389321208, 17.18688815832138, 15.66366009414196, 23.742379993200302, 7.749745901674032, 3.5168262384831905, 3.6158477375283837, 6.367536820471287, 8.994888737797737, 3.4490732615813613, 2.5734819704666734, 1.771993946749717, 3.710898687131703, 0.8055734576191753, 1.3929628604091704, 1.0559984855353832, 4.725494356825948, 23.68285808712244, 46.920402869582176, 57.66978286206722, 58.13813433051109, 59.97763842344284, 59.02471035718918, 62.922199219465256, 56.722474694252014, 25.850789956748486, 17.115400694310665, 33.585231229662895, 68.51015657186508, 51.633221581578255, 19.7756265476346, 25.472647547721863, 32.15870037674904, 20.479705967009068, 32.31011085212231, 25.768851153552532, 24.7684845328331, 31.19917206466198, 49.21791158616543, 62.19174161553383, 11.13468311727047, 0.206974730535876, 0.2585345646366477, 0.09224615088896826, 0.1300269298371859, 0.007000618734309683, 0.04267670490662567, 0.03486609042738564, 0.02605042802315438, 0.01044618775267736, 0.08675629156641662, 0.06038276398612652, 0.03291240151156671, 0.04338926686614286, 0.20663132396293804, 0.10639407570124604, 0.18491572671337053, 0.1642085300409235, 0.09479212560108863, 0.11654997331788763, 0.1650314382277429, 0.142711510125082, 0.164619546267204, 0.19651510898256674, 0.2099235207424499, 0.1203903797431849, 0.27227878337725997, 0.1602239243220538, 0.3144764096941799, 0.15189349476713687, 0.7036342495121062, 0.09931431341101415, 16.875481568276882, 92.52423718571663, 78.99226650595665, 54.6960624307394, 45.3732892870903, 55.089493319392204, 63.98399144411087, 67.82796397805214, 28.605731427669525, 27.478823997080326, 61.95895850658417, 93.16097661852837, 95.83375319838524, 37.86646530032158, 23.686859272420406, 64.4010266661644, 74.94226902723312, 78.34345892071724, 67.8697769343853, 71.43298253417015, 51.79634302854538, 33.252403289079666, 18.304900266230106, 4.1440638061612844, 2.027073665522039, 4.000592054799199, 8.160307221114635, 18.00639398396015, 26.651349999010563, 29.07142873853445, 45.355893820524216, 52.29574643075466, 52.74585887789726, 58.50449547171593, 64.33943957090378, 61.675717905163765, 62.861854657530785, 65.0072917342186, 61.6401594132185, 62.126233130693436, 63.382609114050865, 59.68864493072033, 51.138784512877464, 46.480519473552704, 37.43125945329666, 30.795403830707073, 42.88976155221462, 56.7944960296154, 55.56756466627121, 58.43617133796215, 59.70069408416748, 59.35062646865845, 56.94978229701519, 56.11328758299351, 55.1599757373333, 54.37451608479023, 48.723702505230904, 45.72327710688114, 54.89583671092987, 56.30714938044548, 54.37279857695103, 58.437068089842796, 62.55597487092018, 56.41116879880428, 54.82792295515537, 50.1783100515604, 47.18872927129269, 50.12106992304325, 57.60309264063835, 57.481601759791374, 54.86961051821709, 57.254723533988, 58.6266665160656, 55.87678827345371, 55.49096837639809, 50.77779248356819, 49.84228268265724, 50.8327679336071, 52.30358920991421, 56.36475808918476, 55.677640959620476, 55.03492444753647, 55.65499037504196, 58.05071622133255, 55.148678943514824, 54.87140402197838, 51.742024943232536, 56.43087074160576, 58.82837489247322, 63.16734306514263, 50.17078645527363, 41.63832530379295, 38.080344423651695, 40.51786042749882, 41.301526576280594, 50.74312314391136, 42.99583666026592, 44.2734345048666, 29.247541688382626, 30.94015136361122, 13.321131393313408, 13.040340710431337, 26.048432551324368, 30.44320072978735, 29.31894175708294, 22.81342104077339, 19.899684190750122, 28.512940406799316, 11.020333003252745, 5.382392657920718, 5.8397432416677475, 9.03949074447155, 12.555139996111393, 5.819750614464283, 4.35344017110765, 2.883693049661815, 6.521271346136928, 2.6063981791958213, 6.143562588840723, 4.920659959316254, 4.861559355631471, 24.880259335041046, 47.924658581614494, 64.57128033041954, 64.4421936571598, 68.31703573465347, 63.77382472157478, 70.05483448505402, 59.0519092977047, 31.535169035196304, 17.69922036677599, 36.17778271436691, 81.3216707110405, 67.25281164050102, 16.59187998622656, 33.71947042644024, 38.69346432387829, 40.92883877456188, 49.50958773493767, 30.46393431723118, 37.91506849229336, 41.97612337768078, 57.510313019156456, 80.55459067225456, 19.016640074551105, 0.5120931181591004, 0.29808361432515085, 0.362530768616125, 0.22761077008908615, 0.23539638903457671, 0.13213152706157416, 0.2054796295124106, 0.1503108351607807, 0.11924565405934118, 0.16392494057072327, 0.16585489560384303, 0.17354595009237528, 0.12080475789844058], [0.0031620750996808056, 0.06669946858892217, 0.07734096085187048, 0.048251180196530186, 0.026380334929854143, 0.053798511435161345, 0.05518766716704704, 0.0359820801531896, 0.027632009660010226, 0.05304173602780793, 0.09334836635389365, 0.18831366469385102, 0.04686971311457455, 0.05089947480882984, 0.03605100711865816, 0.07826871224096976, 0.020275374336051755, 0.229304380773101, 0.5182616121601313, 21.328597515821457, 71.01929873228073, 57.167278826236725, 36.13363668322563, 37.13925652205944, 43.26235055923462, 48.94873023033142, 38.78739148378372, 20.646644309163094, 35.21358445286751, 76.52838751673698, 63.929578363895416, 27.259034290909767, 24.47874628007412, 46.62371098995209, 64.53095689415932, 52.97730825841427, 53.86884681880474, 52.3486053943634, 53.67124982178211, 39.31775942444801, 16.587107442319393, 4.6901866514235735, 1.2924290425144136, 2.3875522473827004, 8.66046393290162, 14.146655146032572, 22.3201847076416, 20.69563128054142, 33.56943927705288, 40.011997371912, 44.98043596744537, 48.12135122716427, 52.50101141631603, 60.98736584186554, 58.56551259756088, 58.55763182044029, 57.2349151968956, 54.732156693935394, 46.12377941608429, 33.72874192893505, 18.229533210396767, 18.76390613615513, 16.030631102621555, 26.76987513899803, 37.045849934220314, 44.96587514877319, 50.952712297439575, 52.71979607641697, 55.62071241438389, 55.57739853858948, 54.2545223236084, 54.515917897224426, 50.764968171715736, 45.86466372013092, 43.72185230255127, 37.8739432990551, 38.27251151204109, 41.36402942240238, 36.80387891829014, 41.09192982316017, 45.85714392364025, 48.047559186816216, 47.43248999118805, 44.210787266492844, 42.77944967150688, 45.69515481591225, 54.802122339606285, 55.182508528232574, 53.48458103835583, 54.53204423189163, 54.945610240101814, 57.1267843991518, 52.66119182109833, 48.40391926467419, 46.668856367468834, 44.33788284659386, 44.85244743525982, 44.415417686104774, 43.99029649794102, 40.803396105766296, 34.0524123609066, 37.85167269408703, 43.600414618849754, 40.974614918231964, 41.00858889520168, 48.113158866763115, 55.0090554356575, 58.95747296512127, 43.404789716005325, 25.6743236258626, 24.215640798211098, 27.211341150105, 26.726103387773037, 32.26757973432541, 34.47843410074711, 33.509976267814636, 26.019504703581333, 20.925233960151672, 21.20482675731182, 4.144191574305296, 13.63646887242794, 20.886208154261112, 21.517551876604557, 7.677365485578775, 2.119721481576562, 2.4609149107709527, 2.4322174256667495, 1.155512414406985, 1.9769455678761005, 3.847713195718825, 3.734368127770722, 2.4438716378062963, 2.010830487124622, 0.771878290688619, 0.6573932839091867, 0.07168103096773848, 0.2633794234134257, 1.0992778069339693, 5.530871115624905, 22.98684373497963, 47.46646396815777, 54.76416237652302, 54.58885498344898, 56.08827352523804, 58.883954510092735, 54.971353858709335, 49.25337128341198, 29.45325694978237, 21.15115273743868, 64.24746170639992, 68.14960911870003, 33.256176486611366, 11.823816988617182, 32.10243679583073, 29.972734674811363, 42.86516547203064, 27.067000195384026, 27.04971492290497, 36.037228256464005, 30.625053271651268, 56.215065121650696, 35.091960579156876, 3.2181249791756272, 0.06666733359452337, 0.11184379967744462, 0.03538470693456475, 0.06096838529629167, 0.04109135872568004, 0.035580515177571215, 0.07904644589871168, 0.07458459469489753, 0.0450109300436452, 0.06282559872488491, 0.03487829875666648, 0.05264909537800122, 0.022282239988271613, 0.010481390600034501, 0.01593839504494099, 0.04115648218430579, 0.09047523068147711, 0.014071692330617225, 0.059605345741147175, 0.061573161437991075, 0.04512477549724281, 0.013762252929154783, 0.02906760899350047, 0.06846314543508925, 0.13142662035534158, 0.03599593233957421, 0.05983778268273454, 0.0557413946808083, 0.08240558439865708, 0.04124304628930986, 0.23511563456850126, 0.7431708904914558, 25.299876518547535, 83.58960941433907, 59.502344727516174, 31.83498054742813, 42.93721340596676, 37.80078202486038, 37.270710468292236, 41.21897600591183, 26.31279196590185, 43.79080720245838, 74.28071692585945, 68.1185419857502, 33.020281344652176, 28.438840582966805, 54.32515673339367, 74.05201479792595, 61.3074416667223, 61.40199959278107, 58.42890612781048, 57.5397652387619, 42.804912105202675, 16.720461286604404, 6.5307342633605, 2.1933741169050336, 3.3062458131462336, 9.651578050106764, 15.33848874270916, 23.356267511844635, 21.81101582944393, 37.03247085213661, 42.938847318291664, 47.496113777160645, 50.14389909803867, 53.151946887373924, 58.1153317540884, 57.284312546253204, 58.121457025408745, 57.12230823934078, 58.817883655428886, 48.52491237223148, 40.026216208934784, 27.569369338452816, 24.88684818148613, 18.905241452157497, 30.00154472887516, 39.851600378751755, 46.81637205183506, 51.611904725432396, 55.22006191313267, 60.06640926003456, 59.02945630252361, 57.708818167448044, 56.92936219274998, 54.26210671663284, 51.34841926395893, 48.259238228201866, 43.14391851425171, 47.60854214429855, 49.16328191757202, 49.75259989500046, 50.647588670253754, 52.7267687022686, 52.47071944177151, 50.21705277264118, 47.29209892451763, 45.999621078372, 50.16568332910538, 59.21270526945591, 60.93738712370396, 53.878300711512566, 54.591077864170074, 56.103886887431145, 57.76481956243515, 55.8714609593153, 52.01170787215233, 49.08855892717838, 48.34245756268501, 46.76477462053299, 51.08542397618294, 50.61767667531967, 50.778069868683815, 45.70565365254879, 48.99645946919918, 51.70586608350277, 47.816466987133026, 45.23436114192009, 50.20082004368305, 59.67376492917538, 60.57150095701218, 48.0893075466156, 30.817265957593918, 30.861432887613773, 29.383295103907585, 30.28359219431877, 30.7502356544137, 34.61774982511997, 38.170152604579926, 29.37459547072649, 23.98562204092741, 19.65353149920702, 5.754955066367984, 18.074150048196316, 20.04336018115282, 22.749272882938385, 7.79750601388514, 4.391989102587104, 6.80890878662467, 3.5827735997736454, 2.9944112710654736, 2.1308175986632705, 5.730126723647118, 5.845343191176653, 4.065552894026041, 2.62540927156806, 1.4313893672078848, 0.910818250849843, 1.2152100610546768, 0.4446029505925253, 0.994692575186491, 5.530135855078697, 24.425754323601723, 52.36252784729004, 57.58625574409962, 56.61120526492596, 61.47323437035084, 62.11099214851856, 59.52478252351284, 51.01617269217968, 28.359428644180298, 24.2970647290349, 58.460493832826614, 68.56073945760727, 36.57067023217678, 17.96182617545128, 29.8148550465703, 29.38018687069416, 29.493363797664642, 31.24864351004362, 25.072297230362892, 36.13777846097946, 32.62765221297741, 67.08624377846718, 44.659854769706726, 2.9543357715010643, 0.05759779174695723, 0.12081462846253999, 0.10770558423246257, 0.06435629315092228, 0.06310868353466503, 0.05143219212186523, 0.02811778242175933, 0.06748237501597032, 0.03628459438914433, 0.014743190331500955, 0.06526025128550828, 0.027011666970793158, 0.01614617598534096, 0.08770363565417938, 0.12288041136343963, 0.15709416882600635, 0.16033468244131655, 0.11235438985750079, 0.15569303854135796, 0.2485866390634328, 0.1670651455060579, 0.06032486162439454, 0.1258952304488048, 0.21492749598110095, 0.2764668414602056, 0.2331508876523003, 0.09940752715920098, 0.16171841678442433, 0.17030735121807083, 0.1879716236726381, 0.34056138654705137, 1.5091911423951387, 46.18525251746178, 94.14437144994736, 73.53632926940918, 47.723983749747276, 52.65273727476597, 62.7718298882246, 63.50576810538769, 50.60717783868313, 26.662261113524437, 46.21676802635193, 81.17329627275467, 77.65162244439125, 33.205889984965324, 31.68769285082817, 57.31503389775753, 77.19995588064194, 65.12395307421684, 67.3314294219017, 66.6788524389267, 65.40176376700401, 48.84171277284622, 22.319705933332443, 8.604733273386955, 3.3150725020095706, 4.559837970882654, 10.914036557078362, 18.94358329474926, 28.496764674782753, 24.799623861908913, 39.465769082307816, 47.67350725829601, 48.528541177511215, 52.56360165774822, 56.264561265707016, 64.61554035544395, 63.84309500455856, 65.09788647294044, 64.23135057091713, 62.613458186388016, 56.57922998070717, 47.06303581595421, 33.19270469248295, 28.5671653971076, 20.855389907956123, 32.33637124300003, 43.41966971755028, 50.89063122868538, 56.43790416419506, 53.99584360420704, 63.07928279042244, 61.35874271392822, 59.263877123594284, 58.06099846959114, 56.01937562227249, 54.18760031461716, 50.998864620923996, 47.50908628106117, 50.91752618551254, 57.56470710039139, 57.27282956242561, 56.33668899536133, 58.920398354530334, 56.58951982855797, 53.36797669529915, 49.98953238129616, 46.87536008656025, 50.93355372548103, 58.66016931831837, 59.027298018336296, 56.45788349211216, 53.36654797196388, 56.325984969735146, 58.901129588484764, 55.28485983610153, 52.58112631738186, 49.76598657667637, 50.68897984921932, 51.527180671691895, 55.941027626395226, 56.59338042140007, 57.58711449801922, 49.087882563471794, 55.20903870463371, 58.34280654788017, 50.115157440304756, 46.98369987308979, 54.2805927246809, 62.98643857240677, 64.9696509540081, 52.930981144309044, 34.01032201945782, 32.46879793703556, 33.17600458860397, 33.32521118223667, 36.632253527641296, 44.03601184487343, 41.13924488425255, 34.7294220328331, 29.996893778443336, 25.82311224192381, 8.873064424842596, 20.20176988095045, 27.165323719382286, 27.587513364851475, 11.549951434135437, 6.581090586259961, 12.148716654628515, 3.828053050674498, 4.169054590165615, 3.153762607835233, 6.922855172306299, 7.3596089612692595, 5.881357658654451, 4.011054318398237, 2.79627304058522, 1.323728438001126, 2.2201714664697647, 1.0653955000452697, 1.7951214057393372, 6.539383549243212, 26.30572434514761, 54.27901580929756, 64.7273987531662, 64.74675491452217, 68.28882604837418, 66.68068394064903, 65.4181332886219, 56.664147824048996, 35.03290794789791, 25.37469830363989, 72.40633830428123, 76.68776616454124, 43.65623362362385, 16.254708878695965, 42.744328156113625, 37.06942766904831, 54.44564066827297, 39.30314160883427, 34.33502219617367, 48.880166709423065, 42.25110702216625, 75.93683525919914, 63.473352044820786, 4.361680028960109, 0.1224316940351855, 0.20212316274410114, 0.1702300936449319, 0.12269853323232383, 0.13092806038912386, 0.2702193532604724, 0.21587505529168993, 0.10867509627132677, 0.15065710642375052, 0.10770530221634544, 0.21697067306376994, 0.1640884653897956, 0.1781355100683868], [0.04037811770103872, 0.040649365255376324, 0.02141732253221562, 0.0698780277161859, 0.0236229724396253, 0.02728276052948786, 0.01839308373746462, 0.022920397932466585, 0.049610560963628814, 0.06865874587674625, 0.12763795646606013, 0.16192416980629787, 0.07517033474869095, 0.054502100829267874, 0.03887822982505895, 0.15756908396724612, 0.0515824733156478, 0.24397732311626896, 0.04400488207465969, 7.192787462845445, 71.74420103430748, 63.25520195066929, 78.28135505318642, 41.235182136297226, 42.37287528812885, 43.98544415831566, 44.94429990649223, 17.26197972893715, 22.805053889751434, 60.904971063137054, 78.1407929956913, 38.725052028894424, 17.463948391377926, 28.053014986217022, 48.669817596673965, 56.005863547325134, 56.3715635240078, 50.25252006947994, 51.80522695183754, 42.59875416755676, 19.941911324858665, 11.169877778738737, 2.7142048068344593, 1.8593598087318242, 7.165852133184671, 18.915985375642776, 24.290627874433994, 20.087078735232353, 26.273804157972336, 28.653546161949635, 31.521104089915752, 34.90173518657684, 42.39060513675213, 43.35916556417942, 44.59301635622978, 39.67510744929314, 35.01428134739399, 25.61802014708519, 15.536493267863989, 5.50530418753624, 10.707630682736635, 11.489778812974691, 15.227379854768515, 30.426382832229137, 33.24462130665779, 41.80036760866642, 47.29049161076546, 49.372498691082, 56.47586792707443, 57.18717075884342, 55.8968435972929, 57.45386324822903, 54.88595724105835, 49.26250219345093, 42.94373765587807, 37.09142468869686, 35.42308621108532, 40.50681062042713, 38.56848903000355, 41.32949687540531, 45.796563774347305, 49.76114943623543, 48.7557689845562, 46.01206921041012, 42.836047634482384, 47.02715054154396, 55.172423869371414, 57.07682467997074, 52.254666835069656, 54.08118702471256, 53.807571306824684, 56.38044744729996, 52.35635317862034, 49.39088970422745, 45.34143939614296, 44.203594252467155, 44.523662477731705, 43.726883232593536, 42.41499602794647, 40.241634249687195, 36.91774740815163, 39.209963008761406, 44.33367647230625, 42.11529850959778, 40.533367395401, 47.69841492176056, 52.154808193445206, 56.315136551856995, 41.04712262749672, 22.97723975032568, 19.711617082357407, 21.868637837469578, 21.815288700163364, 21.189393885433674, 26.23345412313938, 28.7351106852293, 33.021189495921135, 23.32319598644972, 25.895310267806053, 14.798270780593157, 4.9588108621537685, 16.978608034551144, 16.688322611153126, 11.7737328261137, 1.1950112949125469, 2.9733903240412474, 2.0706038922071457, 3.4501395793631673, 3.6144301760941744, 2.968004113063216, 1.525455575902015, 1.1980343889445066, 0.3765243786619976, 0.3845369612099603, 1.7204750049859285, 0.4931844718521461, 0.7062352099455893, 1.1347643402405083, 7.407430820167065, 20.198636949062347, 43.42602297663689, 49.90618385374546, 57.16942951083183, 53.54174517095089, 56.64841286838055, 54.496048763394356, 59.40221630036831, 32.50602453947067, 59.7369859367609, 70.55597439408302, 46.94317504763603, 13.021004498004913, 18.464594297111034, 36.19231693446636, 27.91588604450226, 32.94673629105091, 20.899055264890194, 43.389970511198044, 30.415686406195164, 37.007475793361664, 59.59807679057121, 9.457902442663908, 0.8420294732786715, 0.04966626285749953, 0.22396302520064637, 0.04195883659122046, 0.08092875505099073, 0.041733780308277346, 0.06444762184401043, 0.013177235541661503, 0.12390577743644826, 0.07077873524394818, 0.0172342386940727, 0.05036866852606181, 0.0074489371581876185, 0.050475467287469655, 0.03513410592859145, 0.03700333843880799, 0.03753856050025206, 0.0643405744631309, 0.026988263343810104, 0.015238298383337678, 0.05128814867930487, 0.07150394711061381, 0.07153387792641297, 0.04072676754731219, 0.08857100590830669, 0.14466246793745086, 0.032801101624500006, 0.17121516109909862, 0.02455925481626764, 0.22151997894980013, 0.05613949382677674, 0.36699425254482776, 0.10264686818118207, 9.657782167196274, 84.66947346925735, 68.31790208816528, 77.43555843830109, 39.82786305248737, 44.69245322048664, 32.776178643107414, 42.89896085858345, 25.053645931184292, 33.484928011894226, 64.24202039837837, 81.79482132196426, 45.210148841142654, 23.384401202201843, 33.05590823292732, 57.24194101989269, 63.81479412317276, 61.53143584728241, 57.32591651380062, 59.81359742581844, 46.855323761701584, 23.87566354125738, 12.243508268147707, 3.7296285945922136, 1.8716672295704484, 8.64959366619587, 22.921521440148354, 27.830715514719486, 22.752058133482933, 27.725362367928028, 30.859572887420654, 33.62392075359821, 35.26444852352142, 43.810927122831345, 45.51634021103382, 47.250563353300095, 44.01485078036785, 38.439892530441284, 33.12066435813904, 22.10977479815483, 12.557765655219555, 11.634349655359983, 13.417465724050999, 19.41418044269085, 31.668281592428684, 36.29234276711941, 43.70974615216255, 48.4939706325531, 52.93424516916275, 58.10814253985882, 58.8956730812788, 58.618793338537216, 60.28137132525444, 56.459680795669556, 50.630755573511124, 46.728934943675995, 42.43824318051338, 43.16507197916508, 49.17487509548664, 48.73591884970665, 49.22964535653591, 53.64019028842449, 55.12069724500179, 49.67764511704445, 49.700641483068466, 46.68266482651234, 49.695975333452225, 58.09538662433624, 61.089287772774696, 53.54805663228035, 55.71440778672695, 55.46510696411133, 59.036550521850586, 56.27810753881931, 53.888788148760796, 48.578044921159744, 47.82878592610359, 48.78739468753338, 49.422040432691574, 51.06192983686924, 49.680437967181206, 45.61783276498318, 49.459479823708534, 50.04526399075985, 48.324913904070854, 45.30351363122463, 52.12824381887913, 58.017346411943436, 59.39190365374088, 44.32676464319229, 26.402172669768333, 24.12730883806944, 25.123467184603214, 25.191992707550526, 23.523295149207115, 25.970867313444614, 30.92095859348774, 38.44481326639652, 28.67360908538103, 25.842738188803196, 13.84993951767683, 7.884591640904546, 20.68645667284727, 15.807965900748968, 13.466777577996254, 1.6285360883921385, 3.45551747828722, 3.7542629102244973, 4.892161963507533, 3.3453469024971128, 4.762485371902585, 2.132800854742527, 2.31818625703454, 0.6932379479985684, 1.4813209441490471, 2.0623067999258637, 0.7023855415172875, 0.49976640148088336, 1.596264538820833, 9.461682289838791, 21.770595498383045, 45.58305323123932, 54.85458992421627, 59.442748725414276, 57.50534288585186, 59.33689780533314, 60.92663750052452, 60.64354509115219, 36.68621823191643, 57.850694954395294, 69.97691586613655, 47.342541217803955, 22.019337750971317, 19.811304733157158, 36.36524185538292, 25.154602713882923, 30.6054862216115, 24.382835626602173, 36.58803530037403, 33.19186873733997, 40.714864656329155, 71.50079369544983, 13.539276737719774, 0.6327255419455469, 0.08557052511605434, 0.16573307948419824, 0.02954325329483254, 0.060135766107123345, 0.053573299301206134, 0.024255167227238417, 0.07593621630803682, 0.0395612543070456, 0.05230954797298182, 0.005050179961472168, 0.023906990500108805, 0.07066380625474267, 0.03359899201313965, 0.09873990595224313, 0.20444292342290282, 0.08658750492031686, 0.11976346533629112, 0.17163250042358413, 0.09508732226095162, 0.14777067146496847, 0.11725145872333087, 0.32558624166995287, 0.1676111138658598, 0.21187297941651195, 0.12290344020584598, 0.18005477817496285, 0.23599175474373624, 0.12232716253492981, 0.23844042647397146, 0.16601304727373645, 0.4946758324513212, 0.24210849136579782, 16.36740133166313, 105.65314829349518, 75.83455234766006, 90.56180968880653, 53.842730820178986, 61.72116346657276, 62.6196214556694, 56.97060137987137, 21.962259113788605, 31.69921763241291, 67.69966006278992, 91.44970044493675, 49.77469950914383, 25.099133290350437, 38.64534750580788, 62.307924181222916, 69.48015332221985, 68.14110517501831, 63.23036268353462, 67.13715344667435, 53.68429832160473, 25.968397445976734, 16.092784367501736, 5.621654894202948, 2.5569986924529076, 11.5948317758739, 27.399997226893902, 35.22543981671333, 28.10690939426422, 30.92459499835968, 35.85906341671944, 36.37614727020264, 38.125527799129486, 47.346014231443405, 51.399933099746704, 51.1131776869297, 46.06369324028492, 42.79489204287529, 37.0983175188303, 27.656690552830696, 14.5339560136199, 17.226740419864655, 14.694228563457727, 22.66788125038147, 36.71504728496075, 40.432140827178955, 47.24703334271908, 50.48938035964966, 55.31264774501324, 58.79719376564026, 62.14582867920399, 60.84216423332691, 63.10370787978172, 59.857880249619484, 54.41174268722534, 50.839132592082024, 44.598499462008476, 47.35424838960171, 54.28134888410568, 56.076805740594864, 57.44563288986683, 57.541456148028374, 59.56584312021732, 53.68270620703697, 51.36769562959671, 47.53897167742252, 49.761643409729004, 59.336373433470726, 60.461626052856445, 52.11000859737396, 55.42020857334137, 54.88976463675499, 59.03653532266617, 54.67265188694, 54.456549882888794, 48.94616536796093, 50.52207760512829, 51.23937651515007, 55.992408469319344, 55.577645525336266, 56.238707453012466, 54.39687788486481, 56.22836820781231, 55.8313313126564, 52.63726070523262, 47.03427895903587, 55.59600614011288, 60.591978058218956, 62.92913004755974, 48.00514966249466, 27.95213419944048, 26.191380880773067, 27.82726150006056, 29.082007370889187, 26.694054007530212, 32.52010278403759, 38.68917055428028, 43.44031020998955, 31.9141037017107, 31.772086322307587, 19.947073347866535, 9.563131146132946, 23.293692469596863, 25.13082168996334, 19.588053412735462, 4.1029514372348785, 6.556409010663629, 5.381634598597884, 5.978784430772066, 5.493550943210721, 7.084140367805958, 4.875615751370788, 2.647375180386007, 1.2885701120831072, 2.8315163869410753, 3.4587102569639683, 1.7742073279805481, 1.674589142203331, 2.207821416668594, 10.692869424819946, 24.16369568556547, 51.48582749068737, 61.9050469994545, 66.92533761262894, 63.61635737121105, 64.82340440154076, 63.379504680633545, 67.43409991264343, 40.61347849667072, 65.42933508753777, 77.84715235233307, 54.6002771705389, 20.398625917732716, 24.55036673694849, 47.28168748319149, 36.17107227444649, 45.44779188930988, 29.933625273406506, 51.451332941651344, 44.699881821870804, 48.921010717749596, 85.10914787650108, 23.224374689161777, 1.0169305256567895, 0.2640480687841773, 0.3002462029689923, 0.09482063149334863, 0.1738493103766814, 0.18739648890914395, 0.18050346581730992, 0.14859221410006285, 0.17933128809090704, 0.23709498695097864, 0.08460107244900428, 0.15110533393453807, 0.11874091200297698, 0.21298244566423818], [0.08319756729179062, 0.037889058294240385, 0.02702702571696136, 0.023237437853822485, 0.06453736976254731, 0.05816989854793064, 0.035516757270670496, 0.021702257145079784, 0.06937327823834494, 0.0996770900383126, 0.04295619030017406, 0.08786857797531411, 0.07878805976361036, 0.0542593072168529, 0.0324345326225739, 0.11259994425927289, 0.15278435399523005, 0.29306595388334244, 0.3245765052270144, 3.1317057413980365, 67.77448564767838, 65.48117190599442, 62.10093028843403, 41.92001558840275, 52.411248832941055, 43.35155837237835, 53.04825805127621, 26.843467690050602, 12.986729387193918, 41.52096480131149, 66.9447773694992, 61.527100279927254, 36.85028202831745, 30.392184667289257, 54.79299522936344, 57.942406833171844, 61.191665679216385, 48.312420174479485, 44.90509741008282, 43.49426731467247, 19.272119365632534, 8.669319357722998, 1.9418903114274144, 3.133096704259515, 9.549120347946882, 14.257138017565012, 19.2624431848526, 19.51100304722786, 19.853138588368893, 22.711679600179195, 22.611879855394363, 18.129547275602818, 18.369103521108627, 19.362294226884842, 17.017044872045517, 16.607537046074867, 12.878060918301344, 10.07730720564723, 5.831406963989139, 7.97124931588769, 9.484874345362186, 6.126390835270286, 19.266681857407093, 32.34606832265854, 32.79696352779865, 42.253098115324974, 42.90445156395435, 46.80559203028679, 52.83383555710316, 58.16865809261799, 59.237491339445114, 59.485982805490494, 56.110540330410004, 57.218207493424416, 49.393116384744644, 39.19604815542698, 35.53074203431606, 38.968356773257256, 41.77817679941654, 40.754773914813995, 47.11729310452938, 48.35966683924198, 47.01143838465214, 44.62425448000431, 44.41805474460125, 47.381257340312004, 57.587300688028336, 57.770070880651474, 55.17617046833038, 53.17940801382065, 55.707343965768814, 58.44568222761154, 53.93742173910141, 48.55737403035164, 44.495768174529076, 45.067337304353714, 44.391501769423485, 44.9260076880455, 44.159809201955795, 41.65580056607723, 34.13536190986633, 38.47877964377403, 43.29549238085747, 42.24820397794247, 41.45444177091122, 49.93415795266628, 56.67182341217995, 57.291319370269775, 40.18388494849205, 14.939038027077913, 9.566171932965517, 11.290659997612238, 11.481536105275154, 13.63101901486516, 12.190822195261717, 25.282992124557495, 33.696648851037025, 32.26813070476055, 21.439847946166992, 23.335851207375526, 8.057734575122595, 8.039715941995382, 15.4406101629138, 11.279221661388874, 2.1727086883038282, 1.426786151714623, 3.6917025921866298, 4.910809462890029, 3.4233586164191365, 5.581213664263487, 1.3300125882960856, 1.0714058275334537, 1.2516149575822055, 0.5257797462400049, 1.1200567544437945, 0.7649429503362626, 0.6315634574275464, 1.2741628289222717, 11.754152476787567, 32.19221457839012, 50.506821423769, 48.24904337525368, 52.498894929885864, 56.03006824851036, 56.63154557347298, 58.35420213639736, 60.91645024716854, 63.06401140987873, 68.69105726480484, 51.08442083001137, 30.879470519721508, 5.780719108879566, 29.345675222575665, 24.7344858571887, 40.167819410562515, 20.65437499433756, 34.232667088508606, 53.377210199832916, 28.193316757678986, 49.11287382245064, 51.14440821111202, 1.9666659319773316, 0.696855413261801, 0.05791595045593567, 0.2428318775491789, 0.07248909620102495, 0.09269107584259473, 0.007652542590221856, 0.043603970188996755, 0.09806024710997008, 0.16221978206885979, 0.0233201854643994, 0.0470104836858809, 0.005534297733902349, 0.01635198281292105, 0.09794056837563403, 0.026522346743149683, 0.069767432869412, 0.04202733311103657, 0.05327705621311907, 0.03684369505208451, 0.027088505230494775, 0.09448547018109821, 0.008291990943689598, 0.008296420637634583, 0.08825477678328753, 0.014148857135296566, 0.08999130586744286, 0.05931421976129059, 0.06296944178757258, 0.053972827081452124, 0.09167030366370454, 0.07770306954625994, 0.3135274106170982, 0.30410347098950297, 4.886464169248939, 80.40107890963554, 70.5187439918518, 64.66845631599426, 38.80195990204811, 51.357382982969284, 35.59366285800934, 40.56951105594635, 32.03196197748184, 21.852950379252434, 51.72502465546131, 71.30959555506706, 61.90228834748268, 39.980356469750404, 35.392665043473244, 57.548763155937195, 64.09081131219864, 65.93111336231232, 53.465319871902466, 50.88165991008282, 49.801974445581436, 22.60655254125595, 10.599666126072407, 1.8784748017787933, 3.3825288573279977, 10.684236288070679, 16.027980744838715, 21.476320289075375, 20.896526500582695, 21.666978858411312, 23.40101581066847, 24.665164276957512, 18.71562782675028, 19.458030089735985, 23.222537487745285, 21.419541835784912, 20.628783367574215, 16.537527702748775, 11.298301387578249, 7.413203185424209, 8.211403079330921, 10.564256776124239, 10.61257878318429, 21.70963916927576, 34.110598638653755, 36.61136984825134, 46.025520488619804, 44.29610788822174, 50.72019897401333, 57.9676678776741, 60.678491815924644, 60.370624735951424, 62.597103863954544, 58.82734514772892, 59.36200685799122, 51.10243186354637, 42.846022099256516, 42.78175614774227, 46.71696558594704, 52.18597412109375, 50.39756968617439, 54.87671993672848, 53.4189585596323, 50.70368506014347, 46.67128063738346, 47.106311693787575, 50.943957567214966, 59.95602898299694, 59.39895607531071, 56.001208797097206, 54.344919472932816, 58.57756555080414, 60.108499601483345, 57.194169983267784, 52.04168826341629, 51.541836485266685, 47.61274851858616, 49.375143349170685, 49.896703362464905, 50.65947063267231, 50.47472074627876, 46.00092440843582, 47.13862515985966, 52.602697759866714, 46.982073560357094, 46.744164526462555, 53.48728649318218, 60.976076647639275, 61.638407707214355, 46.68095871806145, 19.215851984918118, 13.697303608059883, 15.45665005221963, 16.237626895308495, 16.57967884093523, 12.766403909772635, 24.64901514351368, 36.679553389549255, 36.88466638326645, 26.206008195877075, 21.922211162745953, 10.879513509571552, 11.282721273601055, 16.977834776043892, 15.25895331054926, 4.811988165602088, 4.784343698993325, 7.111955350264907, 8.95395828410983, 5.2520667761564255, 8.40473860502243, 1.6955096321180463, 0.8924116822890937, 0.9558420348912477, 0.3213573060929775, 1.5469051874242723, 1.1796552501618862, 0.9735952166374773, 1.7556942463852465, 13.4643523581326, 35.10625921189785, 53.38655009865761, 53.231130838394165, 57.082847356796265, 61.29386119544506, 60.91417036950588, 63.80398750305176, 63.91559511423111, 65.33120155334473, 68.77498716115952, 56.13285273313522, 35.56937836110592, 12.432708665728569, 28.823007568717003, 27.406105399131775, 26.742383614182472, 24.742944203317165, 31.178991347551346, 54.314186722040176, 31.12618938088417, 55.25857664644718, 61.38953246176243, 2.4747855914756656, 0.6239631527569145, 0.0512602773233084, 0.14323951851110905, 0.020091440455871634, 0.10460843128385022, 0.027847136007039808, 0.046744609280722216, 0.10123718835529871, 0.07233673328300938, 0.03498545374895912, 0.031245801292243414, 0.04828990546229761, 0.017879246661323123, 0.07846352600608952, 0.15729346516309306, 0.18362660135608166, 0.34511357196606696, 0.1244200486689806, 0.14289136219304055, 0.151905948005151, 0.2047773203230463, 0.10894267761614174, 0.09831076647969894, 0.18987021554494277, 0.06935190438525751, 0.13553702010540292, 0.1657821799744852, 0.19431471533607692, 0.1685483573237434, 0.28379468887578696, 0.13919402699684724, 0.6125420343596488, 0.2841008099494502, 10.30800137668848, 102.29296579957008, 72.88769647479057, 85.39461895823479, 53.74579042196274, 71.88524186611176, 63.404594734311104, 68.32261383533478, 34.29503694176674, 17.91450921446085, 50.931205451488495, 78.58194932341576, 70.91623306274414, 46.78231067955494, 41.40067085623741, 66.25385284423828, 69.99068632721901, 72.77294263243675, 60.26698909699917, 57.94656381011009, 58.50583299994469, 27.22849152982235, 13.063149936497211, 4.034452037885785, 5.586020406335592, 15.235683359205723, 17.302287966012955, 27.249133922159672, 25.720890127122402, 26.567359305918217, 27.24222019314766, 28.256045691668987, 20.943794064223766, 21.98893368244171, 25.99302962422371, 23.52331794798374, 23.632474690675735, 19.062706902623177, 15.118111968040466, 11.519356425851583, 11.547279227524996, 14.886107817292213, 13.735184725373983, 26.281295455992222, 39.87874232232571, 40.6402974575758, 50.97351238131523, 45.8758769184351, 52.32710614800453, 59.211705923080444, 63.094542771577835, 62.145406901836395, 66.1513039469719, 59.69009645283222, 62.67443351447582, 53.73026825487614, 45.42906269431114, 46.016089394688606, 51.987658962607384, 61.14059641957283, 56.22003525495529, 59.99787613749504, 57.00667284429073, 55.7238844782114, 49.489870592951775, 50.17764128744602, 50.85027739405632, 62.78136357665062, 59.6190744638443, 56.66347146034241, 51.79698899388313, 58.682751506567, 62.1280874311924, 57.6497807353735, 52.04980082809925, 50.8506041765213, 49.99270521104336, 51.77802421152592, 56.99298977851868, 59.14638362824917, 57.262558713555336, 53.20126824080944, 54.75468948483467, 58.894673734903336, 49.75334085524082, 50.60812398791313, 57.19879053533077, 65.69199219346046, 65.47551780939102, 49.80310678482056, 20.469961389899254, 14.446559753268957, 15.802121814340353, 18.382934778928757, 21.02294571697712, 16.951990462839603, 31.613135151565075, 44.001999869942665, 40.96160061657429, 28.833696395158768, 30.854498259723186, 16.046633943915367, 13.34573982283473, 19.860481694340706, 19.559201560914516, 6.341521991416812, 5.389304012060165, 8.123606890439987, 10.107806269079447, 5.7890853099524975, 10.249068439006805, 2.3878198955208063, 2.9303892189636827, 2.1175914583727717, 1.155425375327468, 3.955893865786493, 1.7720844293944538, 1.910339891910553, 2.557853884063661, 15.683175846934319, 37.56625100970268, 62.07497388124466, 61.521776765584946, 63.83315473794937, 66.73820525407791, 66.05440154671669, 68.09476286172867, 70.89886799454689, 70.44754341244698, 77.62497067451477, 60.398374646902084, 39.56273227930069, 9.880394171923399, 40.66171310842037, 33.38831439614296, 48.288838639855385, 31.848849803209305, 43.47385101020336, 69.83980402350426, 40.528594851493835, 63.68933625519276, 79.62934792041779, 5.712008345872164, 1.030035784933716, 0.08218486225814559, 0.346151510020718, 0.15126419806620106, 0.13168433855753392, 0.06105484550062101, 0.23032605095067993, 0.19070725422352552, 0.24532883340725675, 0.17240908375242725, 0.16616297594737262, 0.13168542209314182, 0.11256188692641445, 0.20483974978560582], [0.02398268028628081, 0.0696013105334714, 0.10934875856037252, 0.043305842045811005, 0.03790918904996943, 0.05212093856243882, 0.07644193799933419, 0.07018849777523428, 0.033247529427171685, 0.05848229076946154, 0.0974000028509181, 0.11992362822638825, 0.019423596604610793, 0.053989113512216136, 0.1644755993038416, 0.09491565608186647, 0.04089004374691285, 0.1605682066292502, 0.7510533893946558, 0.5856403091456741, 39.39934864640236, 72.44821965694427, 33.52231800556183, 42.09483280777931, 45.61282843351364, 44.21510383486748, 45.762931779026985, 42.21935212612152, 15.964480452239513, 22.605499997735023, 40.70627711713314, 61.70797057449818, 71.92794397473335, 40.09465053677559, 56.6072116792202, 58.95560346543789, 56.78158052265644, 56.3324636220932, 48.394271582365036, 44.75937902927399, 24.38815914094448, 9.044722113758326, 1.314305893611163, 3.282523211091757, 8.441038057208061, 15.950789786875248, 21.614524573087692, 17.080490067601204, 16.040364280343056, 11.10727233812213, 5.841916725039482, 4.473397359251976, 9.230532143265009, 6.728745913133025, 6.090819519013166, 8.245006576180458, 7.416314743459225, 3.870280422270298, 3.1662736739963293, 8.489833138883114, 5.3181651793420315, 12.8504753485322, 28.0438631772995, 28.424942828714848, 33.68554964661598, 40.44790618121624, 40.59123449027538, 41.584569588303566, 50.041152611374855, 53.850679993629456, 55.00058948993683, 57.02831268310547, 59.321615025401115, 56.46819993853569, 54.1439026594162, 43.87927785515785, 32.303685396909714, 35.256818532943726, 40.555881187319756, 43.62773135304451, 45.5044886469841, 49.04685616493225, 49.63270492851734, 43.852439895272255, 44.565844014286995, 52.93145231902599, 56.2845253944397, 58.14777061343193, 53.09289425611496, 52.47836083173752, 55.757577270269394, 56.90457992255688, 52.667655274271965, 50.15993043780327, 46.897927075624466, 43.6323557049036, 42.34528876841068, 42.681361734867096, 42.35266037285328, 39.460187181830406, 36.60676829516888, 39.9527395516634, 45.945823565125465, 40.24585962295532, 42.813822627067566, 50.20572178065777, 55.74102535843849, 53.97288143634796, 34.596261978149414, 10.163406785577536, 6.129820151254535, 12.317162565886974, 10.938968919217587, 11.790536474436522, 9.542833585292101, 16.41189504414797, 31.652958914637566, 39.567436426877975, 33.072596937417984, 26.370970644056797, 23.459126092493534, 12.73871099576354, 7.461816826835275, 9.393074121326208, 3.2664693100377917, 3.1108467606827617, 2.7369332872331142, 3.448941456153989, 3.8477590307593346, 7.151141697540879, 1.0135703184641898, 0.27611533063463867, 0.6528668361715972, 0.2334884015726857, 0.8635836385656148, 0.46356078644748777, 0.3631063783541322, 0.8322350832168013, 8.551746066659689, 34.49126221239567, 50.429848954081535, 45.42459413409233, 51.83763541281223, 45.11292725801468, 52.52095654606819, 61.10842354595661, 61.27189837396145, 58.561416417360306, 49.98920559883118, 53.819122686982155, 19.395356252789497, 12.200236190110445, 33.734232634305954, 28.3527847006917, 43.004302605986595, 21.80713053792715, 57.71895982325077, 43.112057223916054, 33.13989132642746, 67.8273332118988, 26.902041547000408, 0.42252236511558294, 0.13685773126780987, 0.14306998229585588, 0.09683195559773594, 0.05557277501793578, 0.06271892983932048, 0.0537089972931426, 0.05736849780078046, 0.03250699592172168, 0.013803183301206445, 0.03403897055250127, 0.07825934633729048, 0.024828891910146922, 0.05476947808347177, 0.0691107583406847, 0.04420581113663502, 0.033154508637380786, 0.04536401422228664, 0.1217274107330013, 0.04388515881146304, 0.06361387830111198, 0.08648737435578369, 0.015954642512951978, 0.06718959775753319, 0.038079267033026554, 0.1253977243322879, 0.05260843681753613, 0.1262116525322199, 0.044675405079033226, 0.10408087560790591, 0.12416167737683281, 0.08321675180923194, 0.10240529911243357, 0.7159465982113034, 0.6626400898676366, 47.21136845648289, 81.61079719662666, 43.365351632237434, 42.55634464323521, 49.29265737533569, 44.60785835981369, 34.706813246011734, 43.52417550981045, 22.504484318196774, 34.00994583964348, 48.051005601882935, 65.26208326220512, 66.0971948504448, 46.711657270789146, 60.92479459941387, 63.11613321304321, 62.55795456469059, 61.463123112916946, 55.44772669672966, 51.07290364801884, 31.281361654400826, 12.307291645556688, 1.7121887183748186, 4.080525990575552, 8.921747412532568, 16.11065100878477, 21.82236772030592, 18.9821208268404, 17.25397925823927, 12.561901733279228, 8.139595482498407, 5.4675655625760555, 11.691382694989443, 8.91717055812478, 8.53823684155941, 9.480327889323235, 11.082609761506319, 7.03358693048358, 5.421515358611941, 9.989476818591356, 6.524359155446291, 17.586926892399788, 32.31039583683014, 32.04694077372551, 35.01863591372967, 43.63442279398441, 43.81881929934025, 44.03424873948097, 50.157278180122375, 57.517300844192505, 58.645958080887794, 61.083325892686844, 62.12619513273239, 60.875439047813416, 55.931269749999046, 48.018942922353745, 41.17119736969471, 44.11618374288082, 48.482354655861855, 51.01906053721905, 55.7898261398077, 54.26006242632866, 53.999681398272514, 49.88181576132774, 47.202191948890686, 53.67267854511738, 58.21838982403278, 60.34506730735302, 55.470943450927734, 51.80748023092747, 56.581798642873764, 59.32146683335304, 57.47009217739105, 52.551366314291954, 49.447860047221184, 47.19176150858402, 47.72258922457695, 49.66564916074276, 51.15016110241413, 49.32956859469414, 47.744468450546265, 50.45876920223236, 53.19072760641575, 47.94835790991783, 47.8776703029871, 54.0350840985775, 61.66224382817745, 60.83096623420715, 41.80132135748863, 15.161512289196253, 6.939031854271889, 14.516632743179798, 14.10171590745449, 15.08126724511385, 12.12284479290247, 18.334950953722, 34.84400488436222, 43.53470094501972, 38.20714361965656, 30.239182077348232, 23.095117025077343, 16.314073093235493, 14.508095551282167, 17.743885070085526, 7.857931321486831, 5.69054757244885, 5.689868358895183, 7.453279159963131, 7.986318357288837, 10.354186948388815, 4.868277395144105, 0.8719985245261341, 1.2874079681932926, 1.1825220775790513, 1.4228528877720237, 1.3306413358077407, 1.2237968877889216, 1.4289658097550273, 11.365051455795765, 37.77736768126488, 55.40254332125187, 50.6678681820631, 58.24299730360508, 48.84481720626354, 58.18422965705395, 62.33610346913338, 67.66401037573814, 61.9986891746521, 56.353940069675446, 54.013562053442, 25.349220670759678, 15.498500056564808, 32.39574685692787, 23.52107796818018, 29.6232408285141, 22.59411010891199, 47.54719443619251, 50.554121285676956, 36.34586289525032, 75.10626822710037, 30.821232944726944, 0.43896066898014396, 0.12076304919901304, 0.20655445230659097, 0.0786649523070082, 0.057459392337477766, 0.03261503778048791, 0.04546236734313425, 0.028397375426720828, 0.059702452053898014, 0.12627510615857318, 0.04476104149944149, 0.07600047887535766, 0.07941516712890007, 0.01229320963830105, 0.0555287285533268, 0.16286322410451248, 0.2160248058498837, 0.15902765648206696, 0.22374970227247104, 0.10489380190847442, 0.14658693107776344, 0.2362287967116572, 0.20391181285958737, 0.11106159829068929, 0.09586989472154528, 0.24264717183541507, 0.13872954645194113, 0.11525231326231733, 0.13252142176497728, 0.21883463632548228, 0.2333281422033906, 0.13298318604938686, 0.3695319523103535, 0.6866638257633895, 1.2909928383305669, 65.74601769447327, 92.56072282791138, 55.717557817697525, 60.204961225390434, 61.93487159907818, 66.83169543743134, 59.85454022884369, 54.064099341630936, 21.819428578019142, 32.67521806061268, 48.2160497456789, 77.17692151665688, 79.7526741027832, 53.67785006761551, 69.85325530171394, 70.5803994834423, 73.49591463804245, 67.1247661113739, 62.90845535695553, 57.69817873835564, 33.60902555286884, 14.510485623031855, 3.2440683245658875, 5.864996686577797, 11.13499565050006, 18.013197518885136, 25.831889770925045, 27.479568757116795, 19.69211272895336, 16.771674938499928, 12.226143199950457, 7.199482703581452, 13.157712612301111, 10.498258117586374, 10.969614274799824, 12.123708296567202, 14.05663512647152, 9.91783071309328, 7.685842830687761, 16.600169241428375, 9.598677288740873, 22.40240089595318, 38.28295715153217, 37.571517527103424, 40.86986593902111, 47.91237384080887, 46.093643233180046, 47.62802369892597, 53.25564332306385, 60.203255116939545, 60.57697266340256, 63.828594982624054, 66.09312906861305, 63.04244376718998, 58.74605990946293, 52.668358236551285, 45.450991317629814, 48.00515726208687, 55.12069724500179, 58.256490379571915, 59.81429658830166, 58.287823498249054, 57.307149320840836, 51.24794505536556, 50.12749917805195, 54.8742500692606, 59.230408519506454, 59.42089229822159, 54.747944846749306, 51.915132254362106, 55.95394693315029, 61.58282049000263, 57.15349696576595, 52.98094466328621, 51.6825657337904, 49.06849220395088, 49.18051019310951, 52.313430681824684, 58.105748668313026, 55.65872557461262, 56.58201143145561, 58.60301658511162, 59.62214469909668, 52.03697271645069, 50.578740164637566, 55.46884976327419, 61.89313463866711, 62.078682482242584, 45.08582331240177, 18.447780199348927, 9.153951052576303, 20.11535681784153, 20.48099409788847, 18.524824865162373, 15.535447373986244, 24.2590344697237, 41.02041766047478, 48.73898148536682, 41.05992034077644, 33.93343314528465, 32.633435502648354, 19.734974429011345, 14.754451531916857, 17.213528528809547, 9.778656531125307, 8.391145784407854, 5.583269353955984, 9.116292223334312, 8.40660810470581, 12.40386251360178, 4.410675074905157, 2.589734885841608, 2.2372320760041475, 2.3254626290872693, 2.402892499230802, 2.648411337286234, 1.9491669209674, 3.062246418558061, 13.056616187095642, 41.409121602773666, 60.7546017318964, 56.199835538864136, 63.10412585735321, 56.28683567047119, 63.24205465614796, 68.33943173289299, 74.00546729564667, 67.65619799494743, 59.898089691996574, 62.516806572675705, 25.73838248848915, 17.43582610040903, 46.069727316498756, 36.227358654141426, 55.223413333296776, 31.398668959736824, 67.08476185798645, 62.42574445903301, 41.735208705067635, 87.13408201932907, 44.805785939097404, 0.7547190051991493, 0.21488324913661927, 0.3636255254969001, 0.1758691543363966, 0.155389069695957, 0.14738576399395242, 0.10087732094689272, 0.08428344066487625, 0.13774585939245299, 0.20762367930728942, 0.10729749948950484, 0.21668896864866838, 0.17607572372071445, 0.12161616279627196, 0.2845534012885764], [0.038067207133281045, 0.10993478805175982, 0.08140235659084283, 0.006277255743043497, 0.08395345212193206, 0.007259179737957311, 0.11154032064951025, 0.03935897082556039, 0.06922167231095955, 0.07228922841022722, 0.02938345405709697, 0.04705335755716078, 0.11346439787303098, 0.04590656128129922, 0.07096586035913788, 0.16979859414277598, 0.09035195253090933, 0.015540343210886931, 0.7309149450156838, 0.0889673869824037, 14.06010054051876, 72.60266616940498, 47.689751386642456, 35.452880412340164, 42.23904266953468, 39.514767453074455, 44.18935261666775, 46.41782283782959, 28.376316837966442, 12.057696338742971, 26.38381965458393, 55.35623140633106, 70.28127193450928, 66.99925124645233, 53.18381577730179, 51.724162101745605, 51.10987946391106, 60.859206318855286, 46.47318586707115, 45.17195329070091, 26.931064389646053, 9.511053990572691, 2.3818411538377404, 4.532313197851181, 11.086774338036776, 16.375475898385048, 18.194141909480095, 18.814350329339504, 14.787231422960758, 7.876059198752046, 7.973159663379192, 3.6228847224265337, 2.200775882229209, 1.4053699071519077, 3.085651262663305, 3.221364305354655, 3.80518801510334, 2.0350036025047302, 14.43754568696022, 17.22264613956213, 11.335494741797447, 22.72534366697073, 30.197441317141056, 24.92114134132862, 26.657794453203678, 31.620366163551807, 34.432597160339355, 36.16840101778507, 48.07965226471424, 45.998389944434166, 48.80278766155243, 50.61372108757496, 58.23944449424744, 60.19921973347664, 56.28082439303398, 48.16513627767563, 35.619129091501236, 35.09364768862724, 40.97956605255604, 43.94296243786812, 47.83214494585991, 49.36671160161495, 48.236291259527206, 45.1781165599823, 46.62325881421566, 51.76079213619232, 58.86760398745537, 59.272358268499374, 56.81340381503105, 54.36046443879604, 57.7667460590601, 55.92542566359043, 55.553292632102966, 48.60217742621899, 45.45781955122948, 47.42455221712589, 44.851938262581825, 44.378400072455406, 42.79516942799091, 38.45993645489216, 33.20333272218704, 38.89306381344795, 41.2146632373333, 40.77186919748783, 43.635049760341644, 52.636356353759766, 57.493529319763184, 60.908941850066185, 27.134638465940952, 5.588912526145577, 5.134064108133316, 9.02884941548109, 12.932773232460022, 12.013076283037663, 9.900287054479122, 12.96198321506381, 26.515972763299942, 34.724307507276535, 40.04603214561939, 29.292073398828506, 31.966031715273857, 36.599495485424995, 9.329377189278603, 7.809641612693667, 6.958109680563211, 6.771192010492086, 10.19678894430399, 6.254093432798982, 1.5912604448385537, 6.15726132877171, 4.076788891106844, 1.8748645205050707, 0.26635870104655623, 0.8631723106373101, 1.7854211200028658, 3.215962420217693, 2.781349578872323, 1.138856008183211, 8.299645744264126, 33.68367254734039, 48.32748256623745, 52.53394044935703, 44.638226330280304, 53.93212482333183, 51.14142157137394, 60.51869139075279, 59.76928040385246, 54.483289048075676, 54.954083785414696, 45.75176037847996, 8.956223912537098, 24.088630713522434, 32.498660534620285, 38.929089680314064, 28.196284398436546, 31.400682851672173, 60.672849118709564, 30.899681635200977, 47.406864166259766, 58.21852661669254, 5.103951198980212, 0.6738706247415394, 0.045868630113545805, 0.34174730884842575, 0.018726539965427946, 0.11191556535777636, 0.08185866608982906, 0.12814669869840145, 0.039991451340029016, 0.06858687629573978, 0.03321348340250552, 0.06509864862891845, 0.04107378095795866, 0.05410857702372596, 0.017180642644234467, 0.04460627773369197, 0.03164953704981599, 0.013824573852616595, 0.038880767970113084, 0.008909080243029166, 0.1272252481430769, 0.0446783328516176, 0.07244729102239944, 0.01870925163530046, 0.02001449272938771, 0.022812029528722633, 0.008343104509549448, 0.02754013734374894, 0.12006883684080094, 0.05420059591415338, 0.10823345903190784, 0.02939814487035619, 0.035272275272291154, 0.018112594589183573, 0.7387690048199147, 0.07537849232903682, 17.3189614713192, 85.56198477745056, 56.337844133377075, 38.932049721479416, 41.80488936603069, 47.314544320106506, 37.549410313367844, 37.673621848225594, 35.059495121240616, 23.591254502534866, 32.95447267591953, 64.61199134588242, 77.63883993029594, 70.54753124713898, 59.25603814423084, 56.97201490402222, 62.676040828228, 70.30546143651009, 54.14804443717003, 50.77976077795029, 32.46247887611389, 12.254990302026272, 3.7954318011179566, 3.9343383349478245, 11.593675687909126, 15.826151724904776, 19.30677730590105, 21.640104800462723, 16.903033889830112, 11.899470929056406, 10.729889888316393, 5.972502892836928, 5.194972464814782, 4.618698237463832, 6.631551403552294, 8.059442583471537, 7.72977227345109, 5.528655359521508, 14.189659338444471, 21.34126603603363, 15.879325121641159, 27.851519398391247, 36.14882826805115, 28.262518644332886, 28.96748911589384, 35.248439982533455, 35.92848189175129, 40.06779357790947, 52.317272275686264, 50.41560351848602, 54.67528514564037, 56.21914990246296, 62.07219623029232, 62.61328339576721, 60.83828464150429, 52.693809270858765, 41.57343998551369, 43.344042375683784, 50.38518615067005, 52.62674666941166, 53.92426684498787, 54.42622750997543, 52.89845108985901, 48.40266913175583, 50.34332759678364, 53.392891958355904, 60.59540167450905, 60.22977389395237, 58.576543405652046, 52.390076369047165, 60.89922197163105, 57.59872667491436, 59.56855997443199, 51.47589482367039, 48.289431408047676, 48.536095172166824, 49.58103150129318, 49.52047035098076, 53.59684981405735, 48.342107981443405, 47.92373523116112, 48.926668614149094, 51.08242213726044, 45.69527640938759, 49.136512354016304, 55.74037939310074, 61.73280604183674, 61.85785353183746, 35.05526214838028, 8.890609983354807, 6.149170137941837, 10.397901702672243, 15.379080064594746, 14.402230381965637, 13.309819400310516, 13.92572645097971, 29.505519345402718, 38.740247413516045, 43.736382722854614, 35.414369478821754, 33.47822517156601, 34.620075300335884, 14.487011432647705, 18.087113052606583, 12.952744010835886, 12.614945936948061, 15.022062622010708, 9.92597272619605, 5.747673707082868, 10.199843030422926, 7.586559858173132, 3.3418976375833154, 1.2807667558081448, 1.9775772839784622, 3.9805034827440977, 3.516147737391293, 6.007709428668022, 1.9890288007445633, 11.394144594669342, 38.3303140103817, 54.05816026031971, 56.10817305743694, 51.457336619496346, 61.746796891093254, 58.31392429769039, 64.08847063779831, 66.27147629857063, 58.37423466145992, 60.71691155433655, 51.060732901096344, 14.760778192430735, 23.59313540160656, 33.573543056845665, 24.891200847923756, 25.12213535606861, 27.60981246829033, 62.246002703905106, 35.839365273714066, 52.67343856394291, 67.4447013437748, 6.1012461595237255, 0.3934683225816116, 0.13743555260589346, 0.2527477126568556, 0.023343793181993533, 0.04442800644028466, 0.06186373080709018, 0.08115379649098031, 0.06305348259047605, 0.061739306038361974, 0.0038469813898700522, 0.08555936321499757, 0.009860449554253137, 0.027752697715186514, 0.05507516871148255, 0.017464629163441714, 0.1722921954933554, 0.17678315372904763, 0.20037567213876173, 0.10520115494728088, 0.20096976135391742, 0.2013854234246537, 0.18129079544451088, 0.1593966077780351, 0.18433268065564334, 0.16191118222195655, 0.1558097338420339, 0.1479467237368226, 0.35261021344922483, 0.13475446990923956, 0.16536495939362794, 0.29197268129792064, 0.15073755523189902, 0.18788549001328647, 0.962899443693459, 0.1603775192052126, 24.23410590738058, 103.0368746817112, 67.12795794010162, 56.3202852755785, 55.52308425307274, 64.93772506713867, 64.01911675930023, 59.43983048200607, 38.617365807294846, 19.03027944266796, 34.04095217585564, 70.94324961304665, 85.13038113713264, 78.34886983036995, 65.19753992557526, 63.1499969959259, 72.56677329540253, 77.78305739164352, 61.860813573002815, 56.01823568344116, 38.1314554810524, 17.703563533723354, 4.911767011508346, 4.708512118086219, 15.086903292685747, 19.19059284031391, 21.86801467090845, 26.078735925257206, 22.89406791329384, 15.997614674270153, 12.922805417329073, 7.689489684998989, 7.422014437615871, 6.462412029504776, 9.978015683591366, 11.356507614254951, 10.328984800726175, 6.955683985725045, 18.7791034206748, 25.808825008571148, 19.701247438788414, 34.27869401872158, 43.305197060108185, 35.78819341957569, 34.015440344810486, 40.02664178609848, 38.23966607451439, 43.085397854447365, 53.37760157883167, 52.28668011724949, 52.092765122652054, 53.98475959897041, 61.32137931883335, 63.66439439356327, 62.607712894678116, 56.08716398477554, 45.113979801535606, 48.0060426145792, 56.60098761320114, 59.647686928510666, 60.95436081290245, 57.6997746527195, 55.74761800467968, 51.22603163123131, 52.746083065867424, 53.805462419986725, 61.489858478307724, 60.13668268918991, 58.56232076883316, 52.577246725559235, 60.59523828327656, 58.567708879709244, 59.09037083387375, 51.32123552262783, 48.91949459910393, 51.094399094581604, 53.41299667954445, 54.145023599267006, 61.43166460096836, 57.29918114840984, 54.558973386883736, 56.67302794754505, 57.982718870043755, 49.200322329998016, 52.46080957353115, 54.83594432473183, 61.48004740476608, 64.68591257929802, 36.229235753417015, 10.81834439188242, 8.427843265235424, 14.953547548502684, 19.865875504910946, 19.208189696073532, 18.411533944308758, 18.777074329555035, 37.083015739917755, 43.24910447001457, 49.42889526486397, 37.292464300990105, 40.6004223972559, 42.44519300758839, 16.075350902974606, 18.113356344401836, 14.001254048198462, 11.453986633569002, 14.616629127413034, 10.100824143737555, 5.130794383585453, 11.955485623329878, 7.636823561042547, 4.822371108457446, 0.8303382724989206, 2.005318170413375, 4.654483767226338, 6.177406422793865, 7.971869632601738, 2.7418058132752776, 13.571581654250622, 41.35217405855656, 59.613728150725365, 61.92993946373463, 53.48459243774414, 62.52125233411789, 61.0910926759243, 73.30565124750137, 70.10227113962173, 66.87420755624771, 65.55015340447426, 58.33155535161495, 12.453685440123081, 32.67319276928902, 45.09661853313446, 46.596432253718376, 40.04761666059494, 38.745084553956985, 76.02913230657578, 45.31140200793743, 58.76578465104103, 83.84608045220375, 10.74305048212409, 0.8451337285805494, 0.1932429798762314, 0.5198945151641965, 0.0731975726375822, 0.20998612832045183, 0.23767200676957145, 0.16801988880615681, 0.12561321433167905, 0.22805466345744208, 0.06911660646437667, 0.28660953626967967, 0.19887549482518807, 0.15924121689749882, 0.2549812209326774, 0.10603872055071406], [0.09462949135922827, 0.06317522449535318, 0.06020136825100053, 0.09237640522769652, 0.05096381530165672, 0.09296165546402335, 0.027659316983772442, 0.026815556302608456, 0.026217555969196837, 0.009519120067125186, 0.024633328575873747, 0.062409595266217366, 0.1410021065385081, 0.102504754322581, 0.09746543801156804, 0.05844732448167633, 0.11536201753187925, 0.09670659943367355, 0.2800531958928332, 0.2875539637170732, 1.8603056017309427, 54.48784880340099, 54.100250601768494, 35.48135608434677, 38.15034046769142, 38.898030146956444, 41.169768646359444, 49.5985409617424, 40.598199516534805, 13.867721613496542, 37.382074892520905, 62.67526566982269, 58.03641378879547, 61.05835743248463, 64.75573763251305, 68.95923927426338, 61.60243883728981, 55.09421266615391, 46.724116802215576, 32.07727454602718, 25.036807134747505, 12.30455769225955, 2.398479273542762, 4.316720366477966, 9.621670804917812, 17.13043838739395, 17.536431401968002, 15.114812795072794, 10.683883856981993, 6.1207676120102406, 2.295028637163341, 1.3833395205438137, 1.4342301897704601, 1.1743250861763954, 1.5379063202999532, 1.3021417963318527, 1.1853517382405698, 5.4302240163087845, 20.254758037626743, 18.761453367769718, 20.150330141186714, 30.235258787870407, 28.093927390873432, 20.2330270037055, 20.268743187189102, 28.533983677625656, 26.85060180723667, 35.11048838496208, 35.0140305608511, 35.18576994538307, 19.997090063989162, 33.563124015927315, 57.66066715121269, 60.18797993659973, 58.052821308374405, 49.12880636751652, 38.496840074658394, 34.35563988983631, 41.37415207922459, 45.35968601703644, 47.758086919784546, 49.1301628947258, 48.8982917368412, 47.99780085682869, 45.09820684790611, 51.951241716742516, 58.545031696558, 56.990535110235214, 54.73234288394451, 58.09952460229397, 59.31330867111683, 56.16623394191265, 56.34149953722954, 48.70761036872864, 44.5999775826931, 45.32092049717903, 46.415941938757896, 46.11139588057995, 42.22018428146839, 36.771136075258255, 34.0490647405386, 39.95388329029083, 39.7684570401907, 38.40284451842308, 46.32093943655491, 57.76990368962288, 56.24346859753132, 50.35447999835014, 12.675694227218628, 1.5315179130993783, 0.39963746967259794, 1.8494137236848474, 6.372819487005472, 11.4917585067451, 9.283469002693892, 10.372343324124813, 21.625424288213253, 34.83046621084213, 36.26101344823837, 37.532562017440796, 27.562883086502552, 46.137470081448555, 29.396330304443836, 12.416744772344828, 15.200701486319304, 8.109218962490559, 10.875360332429409, 13.618208952248096, 9.735247660428286, 4.671389535069466, 5.401254845783114, 2.8140290128067136, 3.046999736689031, 1.4078149572014809, 1.354547159280628, 2.0827872259542346, 9.814668148756027, 2.485273741185665, 6.76681749522686, 36.55112408101559, 46.87396556138992, 58.951218500733376, 43.78743298351765, 45.61274863779545, 63.1590823084116, 61.84560298919678, 57.4253685772419, 55.686790868639946, 56.75872474908829, 27.485097460448742, 10.332892891019583, 45.11481195688248, 31.508218981325626, 37.07635469734669, 24.6092863753438, 48.87267351150513, 42.94776163995266, 31.44791431725025, 61.48707702755928, 40.692354664206505, 1.375649208202958, 0.19376408628886566, 0.01690281595074339, 0.1384208575473167, 0.03335436158522498, 0.025186384445987642, 0.05958623543847352, 0.11296249082079157, 0.01380748033625423, 0.052434251047088765, 0.0369794115977129, 0.062360902957152575, 0.055561624249094166, 0.06127263244707137, 0.005956916511422605, 0.020233834475220647, 0.06753654437488876, 0.016764846986916382, 0.06157433774205856, 0.05366365578083787, 0.05851727932167705, 0.05194227022002451, 0.022995184153842274, 0.035650863355840556, 0.043482773762661964, 0.11471143603557721, 0.031595812979503535, 0.03982109876233153, 0.07451493671396747, 0.01317680231295526, 0.081798700557556, 0.13784584152745083, 0.1170927875500638, 0.11753193859476596, 0.2958848385605961, 0.2812499238643795, 2.3897098191082478, 66.00539937615395, 69.23063591122627, 45.361475721001625, 44.32176411151886, 43.29970255494118, 43.736082538962364, 37.311493679881096, 42.842959463596344, 21.49232693016529, 42.73342274129391, 67.57156893610954, 69.00043666362762, 68.59706550836563, 72.82269716262817, 74.75455150008202, 68.39754581451416, 61.360863000154495, 56.18242867290974, 37.7771320939064, 29.395967423915863, 13.514545764774084, 3.188130338676274, 5.073919510468841, 8.850503135472536, 15.685075744986534, 18.772512674331665, 15.812464859336615, 14.96232982724905, 7.9012105241417885, 7.544933566823602, 4.415592961013317, 3.8432512851431966, 4.389219526201487, 5.660452712327242, 5.497299917042255, 4.941274803131819, 7.8126035537570715, 23.665122538805008, 24.036964885890484, 25.185920633375645, 35.65424680709839, 28.480378054082394, 19.461784288287163, 22.37260479480028, 30.90891133993864, 30.18879108130932, 39.36288200318813, 37.58857861161232, 40.517301857471466, 28.147574812173843, 42.64962583780289, 62.14445695281029, 62.84302666783333, 62.022874876856804, 52.413692101836205, 44.45420980453491, 41.816440746188164, 50.509709268808365, 53.769550547003746, 54.13479074835777, 54.7073820233345, 53.843209594488144, 50.50598926842213, 46.83389291167259, 53.647979870438576, 61.9422660022974, 58.09467226266861, 56.72363743185997, 57.06462353467941, 62.73382432758808, 57.72143729031086, 58.1772418320179, 51.302684918046, 49.57666173577309, 48.1578216701746, 51.989391669631004, 51.172443106770515, 51.03739075362682, 49.09302368760109, 45.82009591162205, 51.666887775063515, 47.58366487920284, 47.552780136466026, 51.40519201755524, 63.144570887088776, 62.77719900012016, 56.31596490740776, 22.382381670176983, 3.080969201400876, 1.1147555639036, 2.6702594524249434, 8.014943171292543, 15.208616461604834, 11.25459423288703, 12.616448756307364, 20.888168849051, 35.5823090672493, 41.992378905415535, 42.64928385615349, 33.0864167958498, 48.344422057271004, 25.82746110856533, 19.092100225389004, 19.99731805175543, 8.549777772277594, 15.617729108780622, 17.20415823161602, 12.832806296646595, 8.125559035688639, 9.483503568917513, 6.097505735233426, 3.8534390134736896, 1.4346311870031059, 1.814090700354427, 1.8491193582303822, 11.556321792304516, 4.298842325806618, 8.147875238209963, 44.75708395242691, 53.021477088332176, 63.296615928411484, 48.230971544981, 52.12553836405277, 68.54945406317711, 69.34690967202187, 62.474317252635956, 61.7050751298666, 61.332273334264755, 35.399345085024834, 13.058208301663399, 39.630258455872536, 31.313374936580658, 28.674040362238884, 25.379761531949043, 39.759371727705, 49.2500464618206, 33.92077602446079, 65.7016284763813, 47.87503704428673, 1.629891071934253, 0.19557195802917704, 0.008801790736470139, 0.09193816702463664, 0.05700779176549986, 0.04143670230405405, 0.042520902134128846, 0.03022440756467404, 0.020556607487378642, 0.022499225415231194, 0.09836684315814637, 0.04661694874812383, 0.095597778854426, 0.031731054550618865, 0.054083340291981585, 0.12158062876551412, 0.27242596610449255, 0.19265120616182685, 0.1561950272298418, 0.15788565448019654, 0.17226440948434174, 0.1464134466368705, 0.08832727718981914, 0.12036954765790142, 0.1541297193034552, 0.13300344668095931, 0.12380375439533964, 0.1580156193813309, 0.2568370947847143, 0.19330157985677943, 0.19340611877851188, 0.22935685061383992, 0.1680920404032804, 0.21305864938767627, 0.49291869392618537, 0.4066492215497419, 2.835903726518154, 83.04216518998146, 78.27527537941933, 60.41570171713829, 57.54009962081909, 59.21900913119316, 65.00872805714607, 63.78520131111145, 54.96494360268116, 18.148265071213245, 43.09747740626335, 73.50048959255219, 72.60266616940498, 74.7470811009407, 76.16963356733322, 83.10047686100006, 72.39561527967453, 68.14942672848701, 62.375891134142876, 42.66659192740917, 33.258190378546715, 17.62894693762064, 4.623036179691553, 5.614372109994292, 11.122276782989502, 18.71736243367195, 21.901502273976803, 18.43153227120638, 19.152579680085182, 11.70052595436573, 12.921313047409058, 6.974481102079153, 5.22339541465044, 6.239606710150838, 7.563717383891344, 7.530044540762901, 6.371082980185747, 10.391902774572372, 30.23948986083269, 25.47873482108116, 29.311786741018295, 40.04279091954231, 39.616434797644615, 27.227323092520237, 29.23407521098852, 35.11255547404289, 33.884316980838776, 42.94309929013252, 37.806075140833855, 38.9972922205925, 25.73014073073864, 39.04670096933842, 62.70813770592213, 64.62374031543732, 64.37199622392654, 54.24343451857567, 48.39633867144585, 46.553597152233124, 55.66464565694332, 59.05805356800556, 59.06446002423763, 58.628851398825645, 55.51231563091278, 53.325517773628235, 48.41214582324028, 55.01358859241009, 61.50305137038231, 60.55880203843117, 56.15345902740955, 56.06021203100681, 60.87441690266132, 57.82010659575462, 58.98440971970558, 52.66923598945141, 50.13815760612488, 48.79833810031414, 52.78465859591961, 57.03018218278885, 56.350311264395714, 57.15018354356289, 56.372255086898804, 60.58081425726414, 54.13474515080452, 50.69966107606888, 55.352032631635666, 63.8140569627285, 61.01961091160774, 55.781656578183174, 21.67490143328905, 4.249618342146277, 1.9798988406546414, 3.7234893115237355, 10.597086064517498, 20.66919419914484, 18.582025095820427, 19.33523777872324, 30.183212980628014, 43.751433715224266, 47.284324541687965, 48.88613998889923, 35.836287438869476, 53.80910262465477, 37.25212186574936, 18.975847363471985, 23.8334459066391, 11.274848096072674, 14.378915783017874, 17.781626544892788, 13.317473139613867, 8.465689234435558, 9.83436344191432, 5.786116719245911, 4.983843443915248, 3.4162392234429717, 3.712018202058971, 4.90972557105124, 14.078941829502583, 6.068265829235315, 11.279902774840593, 48.17221149802208, 57.28015176951885, 69.99739676713943, 50.46395592391491, 55.157684460282326, 72.34374806284904, 74.46753770112991, 68.66562902927399, 66.95264294743538, 67.89490878582001, 37.655846402049065, 13.846362959593534, 57.47961446642876, 39.75829258561134, 46.648979634046555, 36.67372070252895, 57.15402513742447, 62.71861754357815, 40.603507831692696, 76.34505495429039, 63.421762213110924, 2.5999774737283587, 0.29106954694725573, 0.1226215205679182, 0.2513086883118376, 0.14035603730008006, 0.11754561637644656, 0.24677579873241484, 0.22148119431221858, 0.07911230408353731, 0.2320505349780433, 0.19406177656492218, 0.17853502300567925, 0.15706676873378456, 0.12098660634364933, 0.09226101610693149, 0.14130292867776006], [0.0393641918344656, 0.07783506793202832, 0.04945583059452474, 0.033608087032916956, 0.026188977717538364, 0.027654233272187412, 0.027000334375770763, 0.12563209456857294, 0.08887979129212908, 0.0676826509879902, 0.06613316538278013, 0.07801391810062341, 0.15027237706817687, 0.09184949522023089, 0.03425499489821959, 0.20108642696868628, 0.06802262141718529, 0.19106483581708744, 0.027802571894426364, 0.6383861100766808, 0.11068385996622965, 14.626659639179707, 61.58483438193798, 45.40028303861618, 36.58859007060528, 43.27424392104149, 39.963283985853195, 40.36281354725361, 48.1119467318058, 23.029200062155724, 20.869008377194405, 67.91022956371307, 62.49898552894592, 62.33559049665928, 57.501265704631805, 69.20884788036346, 64.8603992164135, 68.82713556289673, 53.33795830607414, 31.991995722055435, 31.196990981698036, 17.364365234971046, 3.9939956087619066, 3.6597284954041243, 10.792273990809917, 13.810041658580303, 16.703884676098824, 10.647356417030096, 8.052682746201754, 7.705581821501255, 3.8843218563124537, 1.115798489190638, 1.6241681040264666, 2.5430617528036237, 2.0798915438354015, 2.104695187881589, 1.7562125623226166, 19.691291972994804, 28.56984995305538, 19.740187749266624, 30.878790356218815, 34.76856753230095, 23.871360272169113, 15.826876536011696, 16.183863580226898, 21.127506606280804, 28.259630799293518, 20.17184268683195, 21.81580927222967, 18.833389207720757, 12.77360262349248, 38.6592623591423, 63.29459823668003, 60.88130973279476, 56.25459440052509, 48.33729363977909, 38.998644948005676, 36.34694203734398, 40.70039503276348, 44.779126569628716, 48.07556748390198, 50.180369541049004, 48.5276710242033, 48.51874150335789, 45.51204264163971, 51.128350272774696, 54.956458657979965, 60.831559002399445, 55.32854609191418, 53.0155836045742, 56.84813015162945, 58.19809891283512, 53.639076948165894, 46.1491696536541, 45.554752349853516, 46.455763801932335, 47.08073526620865, 46.13719269633293, 43.89675311744213, 37.744746431708336, 35.42023256421089, 38.01922470331192, 36.94825977087021, 40.109576135873795, 53.164372220635414, 58.366631269454956, 57.017943039536476, 41.38589344918728, 2.5838765501976013, 0.22768716677092016, 0.7267956691794097, 2.4881456745788455, 1.9608173333108425, 10.994650181382895, 11.39106011018157, 15.899731926620007, 19.13692072033882, 29.61982101202011, 32.10444688796997, 37.483141869306564, 34.165805876255035, 39.15366902947426, 44.51186791062355, 10.461212955415249, 11.895529590547085, 16.773616634309292, 17.172038555145264, 14.018599167466164, 14.147924277931452, 9.965530503541231, 8.226484470069408, 5.076394602656364, 7.831559786573052, 1.8684155540540814, 0.9200053266249597, 0.09281615741201676, 5.444655641913414, 3.782585640437901, 5.899401465430856, 33.061227947473526, 48.321372494101524, 55.352906584739685, 53.15431796014309, 57.545795515179634, 62.3870625346899, 57.81403832137585, 54.713815078139305, 53.39767590165138, 60.56548587977886, 19.012448899447918, 20.323549546301365, 46.028427332639694, 31.56970728188753, 30.188042521476746, 22.28487130254507, 47.342214435338974, 42.86675378680229, 40.44654965400696, 62.793021351099014, 13.169835861772299, 0.6340311281383038, 0.07668417500099167, 0.23140008706832305, 0.03145546914311126, 0.10442420054459944, 0.04738146846648306, 0.12882858398370445, 0.048413101976620965, 0.1037899759830907, 0.0666688104683999, 0.07222604937851429, 0.06497514041257091, 0.0745793773967307, 0.06153673311928287, 0.009312963502452476, 0.030892097420291975, 0.07340230149566196, 0.029174409610277507, 0.0660292424436193, 0.08429933004663326, 0.05777320948254783, 0.01561667217174545, 0.09017381482408382, 0.03732569399289787, 0.03287430707132444, 0.09220228996127844, 0.09127774465014227, 0.08873617087374441, 0.04815056352526881, 0.10828137208591215, 0.040414341929135844, 0.24232506490079686, 0.0601231607288355, 0.2160019031725824, 0.07783526831190102, 0.6892504775896668, 0.0361735876504099, 18.758434429764748, 78.38552266359329, 56.607268676161766, 45.3677149862051, 47.338331043720245, 46.22459940612316, 34.62692253291607, 43.67758087813854, 30.160402804613113, 30.031401626765728, 66.77396893501282, 73.71466130018234, 72.12567016482353, 66.11525908112526, 74.17749926447868, 69.93985265493393, 72.19832226634026, 59.62206490337849, 38.620914816856384, 35.51292099058628, 21.95096231997013, 4.4755698926746845, 3.5392583347857, 11.28686685115099, 15.407114010304213, 17.75197483599186, 10.537361819297075, 10.2733738347888, 11.96521120145917, 5.601133145391941, 3.640114185400307, 4.119777409359813, 5.017491588369012, 4.292401671409607, 4.715651934966445, 2.530250265263021, 15.488780178129673, 30.178611427545547, 24.597294218838215, 38.79797771573067, 39.36993822455406, 24.894996844232082, 18.236857317388058, 18.83457664400339, 28.05723085999489, 29.816880337893963, 22.85091932862997, 25.681754127144814, 25.87224170565605, 16.674156971275806, 37.890240624547005, 65.62210634350777, 63.263500705361366, 60.60880735516548, 53.57029303908348, 43.08904565870762, 40.98174713551998, 47.96148240566254, 52.84252189099789, 55.03265216946602, 56.50308586657047, 53.51691350340843, 51.47120587527752, 49.01378653943539, 54.020074903964996, 56.92756488919258, 60.61220057308674, 57.8466709703207, 53.17998558282852, 59.67913784086704, 60.677747055888176, 57.61280111968517, 51.24276973307133, 45.617152601480484, 49.4861201941967, 52.48007833957672, 53.66596810519695, 50.958757773041725, 50.42524740099907, 46.93017594516277, 50.649184584617615, 44.92645226418972, 45.711455941200256, 58.37486922740936, 67.05320075154305, 62.34826661646366, 49.99990202486515, 6.886052722111344, 0.9822746040299535, 0.7789190753828734, 2.2647076891735196, 3.366223694756627, 11.878837086260319, 10.896982122212648, 13.021127991378307, 20.305130034685135, 28.299047984182835, 34.46778707206249, 41.02745868265629, 36.77719295024872, 44.87878002226353, 41.988476514816284, 11.144888419657946, 18.431689962744713, 14.255099426954985, 17.17607583850622, 16.57083671540022, 17.49221697449684, 12.86555863916874, 12.044931873679161, 10.948776192963123, 14.395781178027391, 3.7338546803221107, 1.366178928874433, 0.3167242562631145, 6.4708775002509356, 5.203267419710755, 6.524308333173394, 40.90508624911308, 55.625013783574104, 60.699896067380905, 57.09811493754387, 65.41193962097168, 67.48448520898819, 63.88205051422119, 57.979819625616074, 60.895957946777344, 63.301513865590096, 26.999728605151176, 15.530715677887201, 45.3753449767828, 29.28983721882105, 28.741672933101654, 23.752261362969875, 44.08419705927372, 47.34732136130333, 44.137496799230576, 71.70124813914299, 20.838773399591446, 0.7543410442303866, 0.13708329963264987, 0.1734319858951494, 0.012381066007947084, 0.07314110262086615, 0.07130746351322159, 0.09007504981127568, 0.055840827626525424, 0.037263123522279784, 0.027326098243065644, 0.11100207062554546, 0.07228555477922782, 0.08215927300625481, 0.049475686755613424, 0.029644478527188767, 0.029665978545381222, 0.1040824712254107, 0.17387188650900498, 0.0985888863215223, 0.1349982208921574, 0.06479164439952001, 0.15026483684778214, 0.16237070522038266, 0.22423206857638434, 0.20151538832578808, 0.1616172175272368, 0.1589257299201563, 0.1733000617241487, 0.4173412243835628, 0.2841974375769496, 0.11250218114582822, 0.35106013412587345, 0.2269600995350629, 0.3800853813299909, 0.22632633510511369, 0.9968107240274549, 0.22564295068150386, 26.1107150092721, 98.65146920084953, 69.08523291349411, 61.72886185348034, 60.122855231165886, 67.53173187375069, 56.62292383611202, 64.37502846121788, 31.95445753633976, 29.25243392586708, 72.70139247179031, 78.8840027153492, 75.74722543358803, 73.30020233988762, 81.80339366197586, 78.20143014192581, 78.93684267997742, 64.89922553300858, 41.15578159689903, 42.968732714653015, 26.72176592051983, 6.4379954896867275, 4.3019690830260515, 12.39713117480278, 15.991219617426395, 18.8625393435359, 13.100383188575506, 15.373099185526371, 14.933206290006638, 9.790987819433212, 5.714565133675933, 4.538109311833978, 7.477942211553454, 7.115269722416997, 6.870619375258684, 5.206673936918378, 24.412977509200573, 38.39510053396225, 27.821349017322063, 42.318956181406975, 47.950143814086914, 33.16226452589035, 25.94484630972147, 24.51766189187765, 30.285360999405384, 35.1445459574461, 24.019187539815903, 26.35436173528433, 25.708109512925148, 22.14710969477892, 44.83035922050476, 68.3057427406311, 65.34468322992325, 59.98264655470848, 55.65346285700798, 45.652319714426994, 45.54584942758083, 52.6718844473362, 60.16115717589855, 61.33431762456894, 61.561488434672356, 56.853085085749626, 53.7039090692997, 49.96383436024189, 55.12981295585632, 56.53291046619415, 61.43034607172012, 58.7492061406374, 54.21553261578083, 56.774064525961876, 62.734006717801094, 56.49534948170185, 50.24753473699093, 46.9357730448246, 50.99070645868778, 54.21400889754295, 57.06974186003208, 53.5273477435112, 58.374949023127556, 56.94432958960533, 56.676314771175385, 50.22553771734238, 50.3324905782938, 60.53958646953106, 66.68013677001, 65.01331061124802, 48.38904306292534, 7.258371468633413, 2.6862713182345033, 3.761716685257852, 3.537426358088851, 4.358449727296829, 17.1364838629961, 19.839533418416977, 22.98919390887022, 28.0133356153965, 41.21337890625, 43.40885929763317, 49.305812269449234, 42.21435159444809, 49.65218648314476, 55.060390681028366, 16.352200247347355, 21.916015595197678, 26.065828017890453, 22.81499795615673, 20.20039815455675, 19.095119163393974, 14.520983509719372, 10.610444247722626, 8.528397269546986, 13.183251991868019, 4.635270098224282, 3.263301942497492, 1.293759208638221, 10.506269987672567, 6.05213331989944, 9.290719013661146, 45.05074359476566, 59.67289857566357, 67.51302167773247, 60.916454046964645, 67.88065195083618, 73.54662671685219, 68.63638579845428, 66.33331418037415, 64.01719406247139, 72.72660031914711, 26.992043517529964, 26.200450994074345, 59.087125808000565, 40.61010807752609, 42.379901111125946, 33.36987018585205, 57.609681487083435, 58.64708662033081, 47.69813373684883, 90.2737395465374, 30.061997584998608, 1.4656148431822658, 0.18731206218944862, 0.33124259440228343, 0.1054400225984864, 0.2025357968523167, 0.13769738230621442, 0.21380192512879148, 0.18399534485070035, 0.163590410083998, 0.23064486274961382, 0.2091102159465663, 0.23567898402689025, 0.17713536217343062, 0.13685893354704604, 0.21703719918150455, 0.17901670653373003], [0.09255970086087473, 0.04038649654830806, 0.050677910330705345, 0.06247197277843952, 0.029934936574136373, 0.0863718219625298, 0.03367342200363055, 0.04233631887473166, 0.09639442985644564, 0.026024981634691358, 0.08144008737872355, 0.06543849289300852, 0.09897115174680948, 0.10596210864605382, 0.1424269113340415, 0.12278023627004586, 0.07265336316777393, 0.06629395167692564, 0.24652991036418825, 0.16058220353443176, 0.5738130875397474, 1.3085576333105564, 36.784762144088745, 51.24226815998554, 43.49341996014118, 43.24956804513931, 32.10499785840511, 48.61893452703953, 47.98395819962025, 41.722946763038635, 13.475000336766243, 52.02442578971386, 65.06427347660065, 54.73615027964115, 62.10082769393921, 65.55669665336609, 66.64121925830841, 64.55478921532631, 56.56028799712658, 43.40568266808987, 49.19273793697357, 25.234147645533085, 1.8086402490735054, 2.177329477854073, 7.1015705075114965, 11.18173599243164, 12.860524859279394, 8.720483612269163, 6.714345160871744, 7.209624834358692, 2.5262915901839733, 1.3067361060529947, 4.587365118786693, 5.105273053050041, 6.416691932827234, 6.886511547490954, 7.024894896894693, 23.316806629300117, 23.85054688900709, 30.99586397409439, 41.03906325995922, 32.546879947185516, 18.15533459186554, 15.503907166421413, 12.483909968286753, 21.426907740533352, 14.444148782640696, 8.640244267880917, 13.382270112633705, 10.232222992926836, 28.211838863790035, 54.844364672899246, 58.02461922168732, 60.2207075804472, 53.25239069759846, 48.712607100605965, 40.22390820086002, 36.16887219250202, 39.26124505698681, 43.067895993590355, 47.49005690217018, 48.18317390978336, 50.332228392362595, 47.209419161081314, 47.57438197731972, 53.290274664759636, 59.000524654984474, 58.62886659801006, 58.146239295601845, 53.55397291481495, 57.55933038890362, 57.0978831499815, 53.03652808070183, 46.0874267667532, 46.612045615911484, 45.007938891649246, 49.85397465527058, 47.28380776941776, 42.462839260697365, 34.940899685025215, 35.891973450779915, 36.76653452217579, 32.629088535904884, 42.68031679093838, 56.02385178208351, 56.961174085736275, 51.29066236317158, 20.469317324459553, 4.537464771419764, 2.5212300242856145, 1.7464074259623885, 2.0356455305591226, 3.1069013848900795, 5.044955564662814, 14.356765821576118, 14.834155105054379, 24.332913905382156, 23.88577289879322, 32.41516761481762, 31.545629873871803, 40.70554755628109, 38.47280256450176, 33.48777025938034, 19.439840465784073, 7.9864428006112576, 13.000684138387442, 19.77740105241537, 21.801579035818577, 19.979352615773678, 16.14730004221201, 12.794935628771782, 6.626497199758887, 4.526101481169462, 3.9699006266891956, 1.328814821317792, 1.4170942967757583, 0.3589906945126131, 3.4648338658735156, 2.8764722496271133, 32.798578441143036, 56.06708586215973, 44.161686301231384, 36.89488023519516, 59.7934091091156, 64.77360427379608, 57.50654362142086, 54.3971286714077, 49.71925288438797, 63.06866616010666, 15.323334205895662, 29.0195919200778, 38.803901597857475, 32.63162299990654, 23.57784692198038, 31.68317299336195, 50.84506407380104, 52.58284002542496, 48.642128482460976, 47.63716220855713, 4.791179532185197, 0.3417162870755419, 0.20946089556673542, 0.18057630019029602, 0.04069536356837489, 0.050520267031970434, 0.03420066226681229, 0.08029441916733049, 0.006461397424573079, 0.022597504321311135, 0.06612039302126504, 0.01999297415750334, 0.0868536316556856, 0.028991013787162956, 0.06970364527660422, 0.06481186050223187, 0.02855453818483511, 0.02430326767353108, 0.04266298630682286, 0.034980644632014446, 0.03543314691341948, 0.017236936400877312, 0.04354033473646268, 0.029924873051641043, 0.05581156103289686, 0.07792077856720425, 0.08330551267135888, 0.15684881480410695, 0.024855301235220395, 0.1104611117625609, 0.1987085264408961, 0.15831483848160133, 0.11259607766987756, 0.1385031468817033, 0.12274075401364826, 0.14767291577300057, 0.19169689330738038, 0.4489896073937416, 2.2252555936574936, 53.13061863183975, 68.30877497792244, 48.610263392329216, 44.00183267891407, 39.87761378288269, 41.379897370934486, 37.6088847219944, 43.67584057152271, 20.94576235860586, 60.17429307103157, 67.30932980775833, 63.898131251335144, 68.81293952465057, 73.85114997625351, 73.00852999091148, 73.34221288561821, 62.12782144546509, 43.23975317180157, 53.94972927868366, 27.63287343084812, 2.2777063166722655, 2.744085928425193, 6.067640287801623, 10.681938361376524, 12.040842343121767, 9.927596189081669, 8.964802902191877, 9.632527772337198, 4.500317489728332, 5.265678595751524, 5.0248028710484505, 7.5244678650051355, 8.48803298547864, 8.863353095948696, 4.973864704370499, 20.603938400745392, 29.273900873959064, 35.925932228565216, 46.61769211292267, 32.809081077575684, 20.499364212155342, 18.029796928167343, 17.87988357245922, 24.677240028977394, 17.23892256617546, 10.554372556507587, 14.188860431313515, 13.213856499642134, 29.283979833126068, 56.76874481141567, 62.879348918795586, 63.79676029086113, 55.30856296420097, 49.95693773031235, 42.67393693327904, 40.33598318696022, 47.79918931424618, 53.19043882191181, 54.65060546994209, 56.61205641925335, 55.44144183397293, 50.43454550206661, 50.387469828128815, 54.111338406801224, 59.92857165634632, 61.550906002521515, 58.99882234632969, 53.801320642232895, 59.274364560842514, 58.880154713988304, 55.036550760269165, 49.37505975365639, 49.54483464360237, 49.89933282136917, 53.40970225632191, 53.737119287252426, 52.355646416544914, 45.911598801612854, 47.85389497876167, 49.602154567837715, 42.99226865172386, 49.52732898294926, 61.43251955509186, 66.89938500523567, 58.85809309780598, 30.162479393184185, 6.337312292307615, 3.6642628395929933, 2.3234518244862556, 1.8806377169676125, 4.084771312773228, 6.549879061058164, 14.786755498498678, 15.070136692374945, 22.25809793919325, 23.006015606224537, 29.68753717839718, 35.23222245275974, 43.139267563819885, 42.02224910259247, 39.78742942214012, 12.091470826417208, 12.765554655343294, 13.867999948561192, 17.868258096277714, 23.60915534198284, 19.804062321782112, 19.105143025517464, 15.046079233288765, 10.97954124212265, 10.382672119885683, 9.607558362185955, 3.498808555305004, 1.4575939485803246, 1.2417790666222572, 5.087732244282961, 3.2024710066616535, 37.32020281255245, 63.8428670167923, 52.78373904526234, 42.9234429448843, 62.62552633881569, 69.15573433041573, 64.28833231329918, 61.489524096250534, 57.51981630921364, 66.76420345902443, 20.68855606019497, 28.088888861238956, 47.91476011276245, 30.938908830285072, 25.11441607028246, 30.620770901441574, 54.6927186101675, 53.570399433374405, 52.57731132209301, 58.5729905962944, 7.700646836310625, 0.21074856631457806, 0.1725394939421676, 0.21453691850183532, 0.022128821365186013, 0.06384128719219007, 0.017933653507498093, 0.027527949423529208, 0.0704504684836138, 0.053582457403535955, 0.016974271784420125, 0.09198804676998407, 0.04605353249644395, 0.08773693582043052, 0.04983083410479594, 0.029566050216089934, 0.02998292569827754, 0.14271195541368797, 0.09121164155658334, 0.17379908182192594, 0.11161904025357217, 0.06865352115710266, 0.1672604342456907, 0.21092748327646405, 0.19396476302063093, 0.21806732984259725, 0.24770582851488143, 0.24746454146225005, 0.09437798493308946, 0.16190888156415895, 0.42890726937912405, 0.2950784208951518, 0.2420662483200431, 0.2747612079838291, 0.19709992135176435, 0.40580762608442456, 0.2815535513218492, 0.6426837982144207, 2.393614584580064, 73.07888701558113, 81.52210235595703, 70.84646120667458, 57.13694505393505, 53.63044001162052, 65.9509938955307, 59.7482181340456, 55.933481231331825, 16.197831630706787, 61.76378957927227, 73.1730155646801, 68.36369723081589, 72.3911315202713, 79.10043150186539, 79.43543672561646, 79.91095080971718, 71.15059688687325, 50.94096712768078, 61.34015031158924, 31.52483928948641, 4.167831055819988, 2.9153154278174043, 8.149730488657951, 11.658913437277079, 16.9056823477149, 11.906029377132654, 10.900608077645302, 15.123752765357494, 6.629934590309858, 6.607616012915969, 6.186291296035051, 10.974664203822613, 11.308597885072231, 11.69789744541049, 10.848404578864574, 31.66541464626789, 34.118281826376915, 40.312371253967285, 51.271682381629944, 45.68472817540169, 26.362478099763393, 24.308329224586487, 20.652809478342533, 32.10943602025509, 22.36498810350895, 14.10495238378644, 15.764955058693886, 14.39356779679656, 36.53736121952534, 59.57412287592888, 66.28558114171028, 64.77092921733856, 57.03693822026253, 51.590910851955414, 46.55290178954601, 44.80596072971821, 52.01152168214321, 58.38354796171188, 59.39999721944332, 57.10738644003868, 58.50394830107689, 52.06316851079464, 50.560903921723366, 56.155028343200684, 62.9160625487566, 61.954265758395195, 59.71971586346626, 52.901053950190544, 60.5659456551075, 57.180612310767174, 54.684632644057274, 51.33823961019516, 51.877366080880165, 52.25960277020931, 55.28041027486324, 56.91169694066048, 58.59100162982941, 53.22350464761257, 57.84742712974548, 58.164143934845924, 46.2292655557394, 54.30461123585701, 64.10479456186295, 67.71150782704353, 56.02000638842583, 27.21836317330599, 9.354373198002577, 6.459097657352686, 4.061349844560027, 3.2362074963748455, 4.695971366018057, 8.684408348053694, 22.04422641545534, 23.105784952640533, 33.02139848470688, 32.340482622385025, 46.18464075028896, 45.666941329836845, 52.46134914457798, 45.67808613181114, 46.3437420129776, 26.962131522595882, 16.42235778272152, 21.623043715953827, 26.69534593820572, 29.160573855042458, 25.819432139396667, 23.200660161674023, 17.22801335155964, 9.65934008359909, 8.132832795381546, 7.256332403048873, 3.8988111913204193, 3.643681718967855, 1.8741310411132872, 6.957553960382938, 5.124584091827273, 42.88260653614998, 69.42442551255226, 54.94060590863228, 45.054167211055756, 69.34696286916733, 75.99380180239677, 68.08134198188782, 65.03873124718666, 60.58608837425709, 76.3397504389286, 20.123558677732944, 40.384772568941116, 49.68979686498642, 42.66093783080578, 34.832081124186516, 41.898455545306206, 68.68006065487862, 60.803174525499344, 60.634569972753525, 76.33276641368866, 10.621267016977072, 0.5872778431512415, 0.2973434259183705, 0.2849576936569065, 0.1534359299694188, 0.28107421298045665, 0.19442749209702015, 0.1581061168690212, 0.08430734524154104, 0.1671698922291398, 0.14186276035616174, 0.2835185208823532, 0.15990913496352732, 0.19610430055763572, 0.15812588768312708, 0.16545870748814195, 0.11959505718550645], [0.034601633524289355, 0.030403513774217572, 0.023969303074409254, 0.061621371351066045, 0.020340852170193102, 0.0604287363239564, 0.1001181112951599, 0.04516632834565826, 0.043145846138941124, 0.01880194959085202, 0.12348241187282838, 0.04770498177094851, 0.08818169008009136, 0.07027803047094494, 0.1350208415533416, 0.1744920399505645, 0.24341293465113267, 0.09278336932766251, 0.07861660880735144, 0.17329016147414222, 0.30511353397741914, 0.1600953991874121, 6.8036166206002235, 44.77895177900791, 48.79972122609615, 58.10245044529438, 69.31919395923615, 49.174924492836, 42.79266156256199, 50.60985289514065, 17.189834900200367, 29.066048227250576, 67.35990509390831, 73.98846700787544, 68.12472805380821, 64.40971300005913, 65.42700201272964, 63.267178907990456, 68.03864747285843, 60.76804921030998, 54.18713293969631, 24.686690121889114, 2.8777990909293294, 1.3821704895235598, 4.460749737918377, 8.88154461979866, 7.710406137630343, 9.461975824087858, 4.957137051969767, 2.7111668698489666, 1.3277546782046556, 4.323688242584467, 8.361786659806967, 7.614306444302201, 8.496342189610004, 8.074758611619473, 8.362182788550854, 23.847678042948246, 25.687567815184593, 43.443566635251045, 41.82079531252384, 24.115360379219055, 17.05014679580927, 12.940550465136766, 9.052986670285463, 14.801761843264103, 4.641682729125023, 4.382171854376793, 4.320377195253968, 9.90073163062334, 35.99218927323818, 52.04948544502258, 63.08537006378174, 54.82036896049976, 50.61059005558491, 47.57128894329071, 39.319408535957336, 37.95212410390377, 39.79860462248325, 42.38660015165806, 47.10501976311207, 48.55664446949959, 46.66655749082565, 47.289306074380875, 50.09746178984642, 56.27179987728596, 59.59209591150284, 62.14071795344353, 57.212162017822266, 46.9485517591238, 60.96305854618549, 58.47073808312416, 51.89443476498127, 47.79454216361046, 46.82901777327061, 51.047270223498344, 49.897166937589645, 52.16686874628067, 40.830082073807716, 34.895552918314934, 37.06726558506489, 35.77830255031586, 34.439174607396126, 49.556705206632614, 55.46196073293686, 61.064338311553, 51.6145683825016, 19.90199826657772, 16.306237913668156, 11.244657766073942, 4.219750519841909, 1.8204361223615706, 3.094448265619576, 3.3167840726673603, 6.950089260935783, 10.88937683030963, 18.132119737565517, 22.19501182436943, 25.34407004714012, 33.35088640451431, 39.596223682165146, 46.23487025499344, 25.69976706057787, 15.09248424321413, 12.395877242088318, 14.70085445791483, 25.552846044301987, 19.888892769813538, 22.951705120503902, 21.652729623019695, 20.684545375406742, 14.615809321403503, 9.594390168786049, 4.909514682367444, 3.831407558172941, 0.7718952116556466, 3.2857701368629932, 6.2483989633619785, 1.1748887621797621, 26.94291215389967, 64.50088530778885, 41.27508759498596, 52.56442241370678, 64.55934137105942, 58.597096502780914, 58.37240315973759, 53.103841468691826, 61.17942273616791, 48.36068518459797, 11.89725374802947, 36.20559722185135, 36.960365921258926, 30.82115314900875, 22.473605275154114, 40.82228869199753, 54.996512308716774, 57.53541827201843, 51.914547085762024, 43.871803656220436, 2.5135921966284513, 0.06058121427486185, 0.12310422083828598, 0.12447812914615497, 0.0510842398944078, 0.07882105564931408, 0.01795622407371411, 0.0980320900271181, 0.05332458335033152, 0.05434032005723566, 0.03440093823883217, 0.045238702587084845, 0.011516064132592874, 0.051251297336420976, 0.07643021206604317, 0.14444901142269373, 0.07155309955123812, 0.04429124717717059, 0.04847710479225498, 0.009377865244459826, 0.037204631153144874, 0.03126392824924551, 0.03886861159116961, 0.08046077899052761, 0.012876959808636457, 0.03719432272191625, 0.02961170714115724, 0.07373723274213262, 0.03724506706930697, 0.1450068986741826, 0.031834335532039404, 0.12245560603332706, 0.11363051278749481, 0.15740262024337426, 0.06627460388699546, 0.21585477981716394, 0.1669853794737719, 0.20410407363669947, 0.11223013207199983, 12.401256803423166, 63.015624806284904, 65.4107540845871, 55.8701728284359, 53.15402917563915, 36.35439343750477, 28.69128953665495, 49.83918584883213, 22.93787006288767, 43.544504418969154, 66.34548112750053, 74.11593496799469, 79.57998096942902, 74.3718284368515, 73.61373111605644, 72.1354128420353, 70.956761687994, 60.821576938033104, 57.844668477773666, 31.572380438447, 2.972380528226495, 1.8588584731332958, 3.758583515882492, 10.127036087214947, 7.012081034481525, 11.3916433788836, 8.73952154070139, 4.316118098795414, 4.0391704346984625, 5.958683984354138, 9.102494213730097, 9.67964144423604, 11.131103709340096, 9.987823907285929, 7.132215863093734, 25.336132273077965, 31.358930692076683, 48.416865170001984, 45.46570412814617, 25.302232392132282, 19.061031192541122, 17.726709991693497, 13.229780495166779, 17.316041328012943, 5.832708869129419, 4.512504860758781, 5.088841309770942, 11.890445463359356, 36.8156810849905, 54.39480319619179, 64.51217070221901, 55.72381988167763, 52.78714366257191, 48.087365850806236, 43.33703175187111, 40.635836496949196, 45.008607655763626, 49.649146646261215, 54.630713537335396, 54.797619581222534, 52.04432912170887, 51.90531738102436, 49.13585118949413, 56.61918103694916, 61.333903446793556, 60.966197177767754, 59.76246736943722, 50.52242338657379, 62.17845372855663, 61.16222105920315, 56.85295209288597, 48.37566398084164, 49.265956208109856, 53.77501845359802, 56.24202847480774, 56.69983170926571, 51.82581804692745, 47.40614980459213, 48.53200279176235, 47.4652024358511, 42.904033586382866, 56.55531786382198, 61.482878252863884, 66.20950162410736, 58.667035549879074, 24.185785800218582, 16.38271640986204, 11.391632929444313, 5.649830857291818, 2.313184062950313, 2.5593954138457775, 6.048924867063761, 8.847798630595207, 13.528662957251072, 21.49197354912758, 25.82317303866148, 25.46079408377409, 33.77370871603489, 42.79578499495983, 45.33045418560505, 31.13144639879465, 10.688746646046638, 11.98575384914875, 18.12894120812416, 16.15945938974619, 20.82046788185835, 23.402721919119358, 22.00984586030245, 21.355403177440166, 18.019626773893833, 13.853059150278568, 12.322926856577396, 8.080674894154072, 2.650552047416568, 1.5506680542603135, 7.571449493989348, 0.980347276199609, 29.447118379175663, 70.577732026577, 50.2752922475338, 57.1632282435894, 69.30417716503143, 65.45316740870476, 68.14238950610161, 61.162912622094154, 66.26108005642891, 56.66173495352268, 15.626236852258444, 38.49697306752205, 40.789716839790344, 28.92438802868128, 23.2312124222517, 41.202424094080925, 60.37348598241806, 59.72081780433655, 54.481917321681976, 57.87098966538906, 3.6524172127246857, 0.07766779526718892, 0.1519787823781371, 0.1386690465733409, 0.08145001731463708, 0.0876345342840068, 0.022751956385036465, 0.07104221993358806, 0.024174492064048536, 0.04219577465846669, 0.02598442883027019, 0.033291928411927074, 0.05104572614072822, 0.07855834279325791, 0.04406673266203143, 0.071855227870401, 0.0680000007560011, 0.1442555186804384, 0.13512940291548148, 0.1533300700248219, 0.1134176722553093, 0.147718632069882, 0.08920278880395927, 0.1746111546526663, 0.15859793813433498, 0.09046450664754957, 0.08843378280289471, 0.29729049594607204, 0.2106217184336856, 0.1706444940646179, 0.08696217817487195, 0.21037385595263913, 0.2183437650091946, 0.3269101440673694, 0.23894001060398296, 0.20020306343212724, 0.29357554216403514, 0.4961597715737298, 0.22674303618259728, 21.173790022730827, 89.09607633948326, 82.54433870315552, 76.75439178943634, 80.92383965849876, 79.70384672284126, 54.550328850746155, 70.77901482582092, 20.393695682287216, 41.03869087994099, 74.93690371513367, 82.37843200564384, 78.9641784131527, 77.96458125114441, 80.26154279708862, 78.24752926826477, 78.02637353539467, 70.34161269664764, 68.49457740783691, 35.72726368904114, 4.7983497474342585, 2.0268471026793122, 5.1500726491212845, 12.12058961391449, 10.871551986783743, 12.249512895941734, 12.278521489351988, 8.335235584527254, 6.365714818239212, 6.924768844619393, 13.07280046865344, 11.737774405628443, 10.783219076693058, 12.194442451000214, 16.215683072805405, 34.75722894072533, 35.05137875676155, 53.48093703389168, 53.63519735634327, 33.91965128481388, 25.833673775196075, 25.027406439185143, 18.36189340800047, 24.22178316861391, 9.505336247384548, 9.032333828508854, 5.9274691343307495, 15.443734545260668, 43.509595692157745, 59.87180270254612, 69.2202776670456, 58.52109678089619, 53.77317935228348, 49.51911382377148, 45.553817600011826, 43.969701603055, 51.182903945446014, 54.52683091163635, 59.48605500161648, 59.7005420923233, 52.633886486291885, 51.399986296892166, 52.64517568051815, 57.523775696754456, 59.236780777573586, 62.8969419747591, 61.326357051730156, 49.191187620162964, 63.592684641480446, 61.431869789958, 57.48695187270641, 49.948977157473564, 52.73406431078911, 54.11330670118332, 60.46794891357422, 59.09230872988701, 57.641451582312584, 55.88819906115532, 58.31123784184456, 54.377426728606224, 49.19306091964245, 59.94297668337822, 64.51925352215767, 63.67976076900959, 55.708278715610504, 25.018704906105995, 20.573642626404762, 13.972126711159945, 8.948436230421066, 4.4288509245961905, 5.139894420281053, 6.747261369600892, 12.132940851151943, 18.739564642310143, 26.938156709074974, 31.79464191198349, 33.284009993076324, 44.49517920613289, 51.83967210352421, 52.679077461361885, 35.07503628730774, 23.353145979344845, 20.06722290068865, 25.22999446839094, 35.54951682686806, 28.14294096082449, 29.934620819985867, 28.987800925970078, 27.046616189181805, 19.047424122691154, 14.213101230561733, 10.400915890932083, 6.637146128341556, 2.444706168025732, 5.771665619686246, 11.459128707647324, 2.6043310901150107, 35.13763412833214, 74.32832077145576, 52.14319981634617, 62.41437166929245, 77.03195929527283, 68.52496817708015, 70.02046912908554, 62.819091752171516, 72.86883428692818, 61.03825271129608, 16.016904339194298, 48.02437663078308, 45.87686866521835, 40.62312237918377, 34.850988909602165, 57.23380945622921, 71.27623334527016, 64.60068315267563, 65.22032350301743, 71.25031113624573, 5.406337073072791, 0.23842542024794966, 0.24331053311470896, 0.24468435236485675, 0.12708542752079666, 0.17428235354600474, 0.15227892174152657, 0.23684471991145983, 0.09828139227465726, 0.22756480146199465, 0.15333315735915676, 0.27652455086354166, 0.13436077540973201, 0.17834546364611015, 0.11136085449834354, 0.18904361146269366, 0.10173614908126183], [0.03231345122912899, 0.08861117094056681, 0.02354149575694464, 0.04702109639765695, 0.12890870624687523, 0.10690530412830412, 0.08387408684939146, 0.0551933631504653, 0.06833994149928913, 0.04084248321305495, 0.13602703053038567, 0.06985507308854721, 0.035984128480777144, 0.05868308253411669, 0.07493691446143202, 0.1446252121240832, 0.21563863672781736, 0.34831294091418386, 0.1397260429803282, 0.2377641963539645, 0.14513695263303816, 0.8238049980718642, 0.15801766770891845, 24.46644064038992, 47.08094425499439, 45.02426661550999, 136.4530947804451, 104.64596673846245, 47.34199404716492, 46.802046820521355, 37.33490042388439, 14.014221802353859, 53.91862414777279, 76.73144862055779, 49.36076112091541, 51.55936874449253, 62.78175115585327, 67.40712895989418, 66.36967062950134, 52.883981466293335, 49.31406542658806, 30.767851509153843, 1.292694672010839, 0.34539066022261977, 1.859910066705197, 7.4557870253920555, 7.160787954926491, 10.349438153207302, 4.730093060061336, 1.9344417611137033, 5.378796150907874, 10.059103332459927, 13.632878065109253, 11.970889996737242, 14.558797180652618, 11.257146745920181, 13.005981054157019, 21.241907067596912, 28.90506986528635, 47.79116414487362, 31.81402277201414, 21.248015239834785, 16.636641584336758, 8.363754954189062, 13.116835355758667, 5.925020640715957, 3.972386405803263, 1.6057120193727314, 1.8383924150839448, 5.921426033601165, 34.234817773103714, 53.0721739679575, 57.01692469418049, 54.68754708766937, 50.7384417951107, 46.73447884619236, 40.049645751714706, 36.31382681429386, 37.813511341810226, 43.552719578146935, 44.054307863116264, 48.64285424351692, 47.983038648962975, 52.392048463225365, 56.81936949491501, 60.72723560035229, 60.96217319369316, 63.56179989874363, 50.43457210063934, 52.86120928823948, 61.514196172356606, 56.62466414272785, 52.62462638318539, 44.07221630215645, 48.656867891550064, 49.97963771224022, 50.57473137974739, 48.01857054233551, 38.58618848025799, 35.600692480802536, 37.79977507889271, 34.57356199622154, 35.618228539824486, 49.62621867656708, 57.42175117135048, 60.29992192983627, 48.519398868083954, 33.60883556306362, 33.50948229432106, 20.627375543117523, 7.299956437200308, 1.8463812489062548, 5.275618387386203, 7.0998520497232676, 6.443920321762562, 7.131158569827676, 9.272623434662819, 18.95932774990797, 20.5282274633646, 24.849249199032784, 39.77974243462086, 39.599130526185036, 27.444566935300827, 16.185222007334232, 13.8259894028306, 11.30952313542366, 22.275208421051502, 25.296215415000916, 27.76763129979372, 22.664790116250515, 22.910393737256527, 18.666952438652515, 14.853390622884035, 11.09927186742425, 6.096620857715607, 2.7198876393958926, 4.825020041316748, 9.757912494242191, 0.24370964529225603, 20.830556340515614, 60.86941637098789, 45.17088934779167, 53.659504652023315, 61.60651981830597, 51.27727568149567, 44.72674638032913, 60.89925616979599, 69.72435861825943, 31.42698124051094, 15.976385213434696, 54.87001709640026, 28.383006379008293, 29.556841291487217, 32.52663843333721, 49.06684309244156, 44.936738312244415, 63.13639372587204, 64.3285721540451, 24.004258140921593, 0.9282484499271959, 0.23942855157656595, 0.07036429029540159, 0.0435699649824528, 0.12073406833223999, 0.06599036132683977, 0.03983814218372572, 0.07063820215989836, 0.021931523260718677, 0.025536603934597224, 0.0342850481683854, 0.020394125385791995, 0.05974564504867885, 0.06316360246273689, 0.07922853925265372, 0.05070230472483672, 0.09509435782092623, 0.023457781499018893, 0.01245244669917156, 0.02252574235171778, 0.018855148591683246, 0.04381603517686017, 0.03939792615710758, 0.015984178135113325, 0.08387692185351625, 0.029905940864409786, 0.04126185602217447, 0.02864543828763999, 0.09498221930698492, 0.054371668375097215, 0.05426022376923356, 0.04421757417730987, 0.12902422895422205, 0.09120179325691424, 0.39040586503688246, 0.15699087671237066, 0.2531623950926587, 0.1948683278169483, 0.9125313651748002, 0.7098722679074854, 35.82788988947868, 65.9738838672638, 52.99067594110966, 118.3437605202198, 105.1915642619133, 36.11621081829071, 37.56965182721615, 37.3699801415205, 25.819669626653194, 60.631203353405, 80.24939864873886, 59.060310646891594, 55.85343852639198, 71.82936206459999, 72.61096492409706, 73.63899976015091, 58.228694871068, 58.17558512091637, 35.970564633607864, 2.20510290004313, 0.56728022871539, 2.853858475573361, 7.288163769990206, 8.206274304538965, 12.712839134037495, 8.21204049512744, 3.4730931976810098, 9.42942962050438, 10.580020230263472, 14.7532450966537, 14.182491973042488, 15.424673818051815, 11.733388490974903, 14.161173216998577, 25.564182735979557, 35.78233793377876, 52.74313062429428, 32.732720375061035, 21.884490586817265, 19.30238664150238, 12.128416243940592, 14.755611419677734, 6.330819865688682, 4.233654448762536, 2.766500450670719, 3.3490992011502385, 8.506359402090311, 37.74275153875351, 58.761053904891014, 60.19809119403362, 57.12557226419449, 54.00544948875904, 47.77283392846584, 42.72819422185421, 39.180803373456, 45.74611768126488, 50.864131450653076, 50.12854412198067, 54.72515366971493, 48.81729908287525, 50.65895766019821, 56.71579845249653, 64.32114735245705, 60.891610980033875, 66.53192952275276, 50.48765145242214, 52.236264422535896, 61.410393342375755, 57.98493795096874, 55.467892214655876, 46.54674232006073, 51.35331720113754, 51.794332936406136, 54.37996119260788, 56.461497098207474, 49.503599256277084, 48.37584637105465, 48.299189284443855, 45.498952344059944, 45.2388297021389, 56.64334014058113, 65.15866041183472, 69.94334846735, 54.912605211138725, 35.762575194239616, 32.97488518059254, 21.26098394393921, 8.689719513058662, 0.6794337637256831, 4.981370726600289, 8.51233173161745, 12.228201739490032, 14.173443708568811, 16.71008214354515, 23.084321804344654, 26.07000019401312, 27.62112256139517, 40.83635173738003, 41.80252209305763, 30.606787651777267, 14.245353899896145, 10.093419291079044, 16.1298418790102, 22.574793845415115, 21.53497014194727, 23.33671186119318, 21.18452064692974, 23.500724360346794, 19.28045991808176, 19.397043362259865, 17.84601029008627, 11.619415506720543, 4.467138145118952, 6.5815964341163635, 11.213328447192907, 0.2432126141502522, 21.813897974789143, 68.91887784004211, 52.177952751517296, 55.1801298558712, 65.00333234667778, 58.65371726453304, 49.5539503544569, 66.65920749306679, 71.46468043327332, 45.303164049983025, 17.461522221565247, 49.17170986533165, 35.831628888845444, 28.259011432528496, 28.84139098227024, 51.020618453621864, 49.08274903893471, 68.52318987250328, 72.39625364542007, 39.166075363755226, 2.417133185081184, 0.18491344089852646, 0.39781463623512536, 0.02221050213847775, 0.1261216151760891, 0.05559102814004291, 0.07540377730038017, 0.0518231146998005, 0.089283452834934, 0.05497539066709578, 0.053090561923454516, 0.11486723509733565, 0.022927500285732094, 0.04264449940819759, 0.011706725581461797, 0.06428149208659306, 0.09855514086666517, 0.14968490781029686, 0.12752451177220792, 0.13888106332160532, 0.12251764957909472, 0.25207410973962396, 0.14841262920526788, 0.11982890791841783, 0.21274544822517782, 0.3262391535099596, 0.12222633435158059, 0.24092170817311853, 0.20790671958820894, 0.19185903773177415, 0.2094974389183335, 0.17529140721308067, 0.22516949014971033, 0.2365541987819597, 0.4402291477890685, 0.18395497201709077, 0.4276527726324275, 0.31066999363247305, 1.1878758715465665, 0.8382570475805551, 56.16923198103905, 84.72058832645416, 68.14994350075722, 137.19873636960983, 129.48879808187485, 65.36121994256973, 62.935464307665825, 46.93435952067375, 20.193393230438232, 65.76497107744217, 84.17366847395897, 60.65348155796528, 60.86817003786564, 77.52480804920197, 80.38932994008064, 80.73894158005714, 63.14268618822098, 63.29149380326271, 39.41083922982216, 3.492792290635407, 0.45393459673505276, 3.181675672531128, 10.720439795404673, 9.013748075813055, 15.064057968556881, 10.876057595014572, 5.401604901999235, 10.916559621691704, 12.4708092212677, 19.732607156038284, 16.174016408622265, 17.875789292156696, 17.24500223994255, 23.779247514903545, 31.065804921090603, 38.187225088477135, 59.18603830039501, 41.209575310349464, 29.70190990716219, 27.266329899430275, 18.493130765855312, 23.75181868672371, 13.465586341917515, 7.885069465264678, 4.652661764994264, 4.322831863537431, 13.832534551620483, 40.26836581528187, 62.536778301000595, 62.0891585201025, 61.505844220519066, 53.985318168997765, 52.884711027145386, 45.310170873999596, 43.59192967414856, 48.29899549484253, 57.815991416573524, 55.16282178461552, 58.53925600647926, 50.11928401887417, 53.62249083817005, 58.24915297329426, 64.4671431183815, 59.97437819838524, 65.70898488163948, 49.813533425331116, 52.69557237625122, 62.85345710813999, 57.245535627007484, 56.06553174555302, 45.4155620187521, 52.90117174386978, 55.26981644332409, 56.67473405599594, 59.29806008934975, 57.94783674180508, 57.18436270952225, 59.185954704880714, 52.37963832914829, 50.393842086195946, 61.45336523652077, 66.76368668675423, 68.13181087374687, 53.51211816072464, 41.397612020373344, 35.5860860645771, 25.091381706297398, 12.1517688408494, 3.7387355184182525, 7.5719083193689585, 9.204699229449034, 14.714691415429115, 17.811515741050243, 18.939935490489006, 28.4308610111475, 30.850424878299236, 33.60636569559574, 49.326144978404045, 48.36385041475296, 35.153855457901955, 25.88618505746126, 24.192562736570835, 19.93625532835722, 33.735923543572426, 34.2127675563097, 38.13395194709301, 30.610739439725876, 32.85715229809284, 24.75820418447256, 22.997378669679165, 16.800462193787098, 10.009383000433445, 3.4080266766250134, 8.267548866569996, 13.301538694649935, 0.363593939691782, 29.17861718684435, 74.75439950823784, 55.13092629611492, 59.46572229266167, 73.77504765987396, 60.30016511678696, 54.819719195365906, 70.19374743103981, 82.5817134976387, 43.4243206679821, 20.50596635788679, 65.25118544697762, 39.14935626089573, 41.43072724342346, 48.58442857861519, 65.2837572991848, 59.51717533171177, 75.79021632671356, 87.66255766153336, 45.84295928478241, 3.2357776444405317, 0.4848125413991511, 0.5849702982231975, 0.09008067529066466, 0.3802782209822908, 0.15464824304217473, 0.19256308354670182, 0.09354731388157234, 0.18847239523893222, 0.17648996086791158, 0.1654548483202234, 0.1736863050609827, 0.13521685759769753, 0.2291024275473319, 0.11923900441615842, 0.26412255072500557, 0.2729797567008063], [0.055365352163789794, 0.11569932365091518, 0.07547124594566412, 0.08576222928240895, 0.051597646524896845, 0.11370698368409649, 0.06879680760903284, 0.0912159237486776, 0.022616458772972692, 0.06481323347543366, 0.047590026806574315, 0.030812325821898412, 0.03754427132662386, 0.0867358899267856, 0.053746883932035416, 0.05521772043721285, 0.18530207395087928, 0.19299247534945607, 0.14076524268602952, 0.13931360183050856, 0.1018450221454259, 0.5410554609261453, 0.14642630063463002, 16.782116778194904, 65.48179507255554, 39.618072509765625, 49.944330006837845, 58.364640176296234, 39.70624677836895, 43.887470215559006, 55.39600387215614, 17.293808721005917, 32.63359509408474, 66.108009070158, 67.0451831817627, 66.63146898150444, 57.980036213994026, 69.55165028572083, 65.62521457672119, 55.169216841459274, 51.23460777103901, 34.04016561806202, 0.42788182909134775, 1.2978367460891604, 1.6839951812289655, 3.1159736355766654, 2.860894510522485, 5.182256922125816, 2.054661847651005, 6.300062891095877, 7.64505629427731, 13.212085794657469, 17.38038707524538, 16.04545220732689, 18.835872374475002, 14.383845068514347, 14.212138932198286, 17.700981572270393, 41.034317314624786, 40.19081577658653, 26.868040971457958, 19.871018528938293, 10.151226539164782, 10.599942561239004, 13.062340579926968, 4.848642898723483, 7.594000333920121, 1.9276197021827102, 2.460010559298098, 7.301659220829606, 32.1203338354826, 52.17544488608837, 54.34222161769867, 56.222087144851685, 53.216562420129776, 48.949034214019775, 43.93242560327053, 39.199543967843056, 38.175229132175446, 41.288295686244965, 45.38600720465183, 48.190705105662346, 47.964560240507126, 53.91793638467789, 55.76285898685455, 59.190294072031975, 60.51959194242954, 62.00517162680626, 53.727676793932915, 58.52808840572834, 57.135387137532234, 59.12967212498188, 51.90610013902187, 44.411541894078255, 50.97113750874996, 53.46791513264179, 53.10641013085842, 44.992853701114655, 38.48239324986935, 39.035879150033, 38.14391501247883, 33.57556834816933, 42.178648710250854, 53.57298709452152, 58.99384841322899, 56.64603039622307, 46.22352786362171, 42.13100306689739, 37.74561658501625, 28.921418488025665, 10.93281514942646, 1.036556710023433, 6.900706635788083, 7.855441505089402, 8.999103661626577, 6.374894650653005, 9.700798708945513, 13.935184143483639, 20.868005231022835, 19.92209918797016, 32.649463042616844, 34.21644575893879, 27.981782108545303, 16.53845865279436, 16.12411368638277, 17.298661060631275, 11.599414329975843, 20.51100868731737, 25.155763551592827, 25.757326371967793, 23.635079450905323, 27.607671283185482, 21.681817062199116, 16.76032304763794, 11.041019093245268, 6.12789080478251, 3.341239560395479, 7.506684819236398, 0.3326847357675433, 7.3702730890363455, 52.62148395180702, 53.806765750050545, 61.49273492395878, 60.83793506026268, 42.427938133478165, 64.95192870497704, 64.00327160954475, 60.21481789648533, 17.024059295654297, 28.79692006856203, 50.30645817518234, 20.85371419787407, 34.42361444234848, 46.1642624437809, 51.54837593436241, 54.64806720614433, 53.4033489972353, 43.14313195645809, 11.395151540637016, 0.3621502249734476, 0.13593144190963358, 0.19209545629564673, 0.08271278158645146, 0.061036269544274546, 0.06925296125700697, 0.0748624028346967, 0.01609091010323027, 0.008505064324708655, 0.028285713742661756, 0.019206050856155343, 0.028797049781132955, 0.018723063003562856, 0.071390012599295, 0.13201894325902686, 0.029562725394498557, 0.13179056957596913, 0.04493319007451646, 0.07198089573648758, 0.01704449936369201, 0.038036523037590086, 0.024002491918508895, 0.12699487066129223, 0.06816839406383224, 0.09065690843272023, 0.04088175766810309, 0.10586626769509166, 0.046960811741882935, 0.04260040841472801, 0.024982750255730934, 0.025005613970279228, 0.08780502044828609, 0.024985260570247192, 0.06834012703620829, 0.17211917118402198, 0.1244942782795988, 0.13600028352811933, 0.13104358309647068, 0.9243384597357363, 0.07108548714313656, 23.163838237524033, 85.05761504173279, 53.97979326546192, 64.84715312719345, 67.32350304722786, 40.20303592085838, 33.48974995315075, 48.94270375370979, 20.273922309279442, 42.729569748044014, 69.5151874423027, 68.13674300909042, 66.81496873497963, 68.49266231060028, 76.68975725769997, 74.70863476395607, 60.209027007222176, 59.03069503605366, 38.25836107134819, 1.2732613272964954, 1.5637720073573291, 3.323157518170774, 3.0589470081031322, 4.0674166940152645, 9.711151253432035, 4.74888970144093, 9.472118429839611, 10.514904074370861, 11.06178592890501, 17.397153675556183, 15.90946415439248, 18.974031060934067, 12.947934418916702, 18.6629094555974, 23.409135974943638, 44.26644667983055, 45.36817856132984, 27.095299176871777, 23.058982864022255, 12.92908363044262, 12.563418801873922, 14.033977892249823, 5.373134929686785, 8.518811333924532, 2.4734668247401714, 3.285320335999131, 7.302433429285884, 34.14701968431473, 56.66707746684551, 60.94536289572716, 60.052384212613106, 57.079210951924324, 51.204669177532196, 45.05252189934254, 41.26109294593334, 41.80593051016331, 48.9685233682394, 52.15261951088905, 53.05884048342705, 52.80513569712639, 54.1451071947813, 59.66177277266979, 60.52694454789162, 62.70235061645508, 61.71926736831665, 56.50674507021904, 60.37930727005005, 59.637670665979385, 60.837665274739265, 54.43136103451252, 46.60337448120117, 52.44231216609478, 56.36537745594978, 58.91236558556557, 55.59552736580372, 50.787880942225456, 47.88884550333023, 49.623737409710884, 43.787277191877365, 48.398291766643524, 59.013071581721306, 68.34526062011719, 62.734299302101135, 55.84421642124653, 49.97140735387802, 42.52660743892193, 29.11970514804125, 11.392898261547089, 1.730583650059998, 7.609057500958443, 10.241717733442783, 15.69875406101346, 14.354531541466713, 14.779263250529766, 18.532603047788143, 24.29657455533743, 25.841569751501083, 35.85257716476917, 37.43760511279106, 29.486444368958473, 17.480834685266018, 6.818532245233655, 14.642008915543556, 13.960508834570646, 23.279019556939602, 26.107181198894978, 21.08904507011175, 20.208050943911076, 21.044895239174366, 18.550082109868526, 19.455678015947342, 18.360088504850864, 9.725145902484655, 7.082711169496179, 8.790085427463055, 0.7216174376662821, 6.710207182914019, 59.58864949643612, 60.29680609703064, 65.99088415503502, 65.31345650553703, 50.21171025931835, 65.453030616045, 68.80778700113297, 66.2482063472271, 27.73123685270548, 20.202269554138184, 53.92639473080635, 24.78166602551937, 25.473413206636906, 40.91377638280392, 59.32195320725441, 63.618306666612625, 63.278171718120575, 63.433116003870964, 18.791585750877857, 0.16054488834924996, 0.2697878092294559, 0.1251229367335327, 0.13496550702257082, 0.034954584116349, 0.05134033279318828, 0.02023785506025888, 0.04645443696063012, 0.014284550488810055, 0.018671233265195042, 0.035967856892966665, 0.08283723233034834, 0.10045247850939631, 0.0565774277492892, 0.049908863511518575, 0.01914687756652711, 0.06323760200757533, 0.10352997938753106, 0.16818031144794077, 0.19904832617612556, 0.17484365467680618, 0.1912340009585023, 0.20407269563293085, 0.1522640639450401, 0.1835381967248395, 0.1431614742614329, 0.16801340243546292, 0.15976318420143798, 0.1150921058433596, 0.23862790782004595, 0.17482750554336235, 0.10730089852586389, 0.1056914844957646, 0.19416763650951907, 0.3029298089677468, 0.1650641520973295, 0.23601813067216426, 0.23246002238010988, 0.9577556478325278, 0.22809080604929477, 32.44960516691208, 104.7466841340065, 64.00037616491318, 76.56229689717293, 73.81990805268288, 57.814954072237015, 60.261908769607544, 73.87649461627007, 22.681820802390575, 42.51544363796711, 76.06111899018288, 75.86729139089584, 76.19846642017365, 73.17973360419273, 82.54726454615593, 79.3634381890297, 66.08403995633125, 63.92976835370064, 44.722589403390884, 1.9147144071757793, 1.3295481819659472, 4.909970182925463, 4.413547720760107, 4.903071178123355, 9.992815889418125, 4.652393404394388, 11.078226696699858, 13.009155783802271, 18.74693624675274, 27.60586068034172, 22.237727232277393, 26.858870163559914, 22.815738916397095, 29.22869849950075, 28.616938926279545, 52.99466572701931, 49.314927980303764, 36.002463921904564, 28.444107100367546, 19.484165087342262, 20.762910470366478, 25.08779849857092, 10.217843614518642, 9.555196221917868, 4.235611818730831, 5.634628348052502, 12.368047535419464, 36.20614059269428, 57.834325432777405, 64.89260628819466, 62.72172577679157, 58.571147695183754, 55.37608154118061, 49.433553814888, 46.10456384718418, 45.68269908428192, 54.15855087339878, 57.160127609968185, 58.55502136051655, 55.12904539704323, 55.26931867003441, 59.68491733074188, 59.74834732711315, 61.977436915040016, 61.8992143124342, 54.38993565738201, 57.839265167713165, 61.2228088080883, 61.8797517567873, 53.17237079143524, 46.891193836927414, 51.96722365915775, 59.2166418582201, 59.37386602163315, 58.159660175442696, 56.47316247224808, 57.199641689658165, 56.108055263757706, 50.28980366885662, 53.66012401878834, 63.81986305117607, 69.0527294576168, 63.849288672208786, 58.69605079293251, 52.528575137257576, 43.86056385934353, 32.14336059987545, 15.195594560354948, 5.7680401392281055, 9.50051050633192, 10.89031158015132, 13.91111433506012, 19.580666609108448, 23.737871535122395, 26.165432073175907, 30.446757338941097, 34.2188586294651, 44.5209988206625, 43.92693489789963, 35.523214638233185, 25.663121826946735, 26.3285269215703, 25.76414130628109, 20.1756139844656, 28.95139317959547, 36.5258364379406, 34.92084816098213, 34.095608443021774, 35.62653489410877, 32.276733443140984, 24.5737848803401, 15.337478946894407, 8.530436810106039, 6.183187337592244, 10.562566816806793, 0.3318373515503481, 9.783770106732845, 67.46020451188087, 62.87529073655605, 70.09027138352394, 71.95759758353233, 52.576783150434494, 73.08812811970711, 75.21462321281433, 76.81252107024193, 23.715293146669865, 33.77010650932789, 60.22301785647869, 26.77400551736355, 49.66366566717625, 62.30466775596142, 75.7741279900074, 64.71670612692833, 73.44432860612869, 74.85711559653282, 23.288148567080498, 0.3850217320723459, 0.42705852014478296, 0.2394668315537274, 0.18063984287437052, 0.17798630869947374, 0.150683912797831, 0.18774798489175737, 0.1375234080478549, 0.18634293606737629, 0.13232689001597464, 0.07562610247987323, 0.17696686496492475, 0.2187602434423752, 0.20577481132932007, 0.20449787203688174, 0.1296154980082065, 0.2022026912891306], [0.08624003879958764, 0.07424884708598256, 0.03594054956920445, 0.12240634969202802, 0.051047763336100616, 0.04777022397320252, 0.09705218792078085, 0.01684818274952704, 0.08415112315560691, 0.04975279727659654, 0.02814749244862469, 0.008905245194910094, 0.0664455427613575, 0.017709660351101775, 0.047645799204474315, 0.033731346629792824, 0.12352477366221137, 0.17630013433517888, 0.12709808856016025, 0.1621390215586871, 0.2737275150138885, 0.2804912708234042, 0.1728139104670845, 4.712688094004989, 53.872889801859856, 48.36758941411972, 38.83011259138584, 75.06919741630554, 47.511043176054955, 32.96942487359047, 55.31382568180561, 32.262438610196114, 16.651871167123318, 51.4163938164711, 73.83155822753906, 62.51693956553936, 59.696145728230476, 67.77063265442848, 63.97731900215149, 47.29855477809906, 57.90492944419384, 22.151067182421684, 0.10179586228332482, 1.7534474981948733, 1.5546611649915576, 1.524282863829285, 3.0413487274199724, 4.446721840649843, 4.659388829022646, 7.526421435177326, 14.004238788038492, 16.75477534532547, 13.312977030873299, 18.07040724903345, 20.45308269560337, 17.696353420615196, 15.721805524080992, 21.393872313201427, 40.3970193117857, 31.74735724925995, 27.416822724044323, 14.910243172198534, 8.767494689673185, 9.543619193136692, 9.644543677568436, 8.192461095750332, 5.182775119319558, 4.624356608837843, 1.874422081746161, 4.747364083305001, 23.203703798353672, 47.3950581997633, 51.681114211678505, 57.04525977373123, 55.123486295342445, 53.75420317053795, 46.41329728066921, 39.68204587697983, 36.883549243211746, 39.5874347537756, 44.84221838414669, 46.893029138445854, 50.78987583518028, 53.92617054283619, 54.40893843770027, 60.0591554492712, 61.099714413285255, 59.50857639312744, 57.81308837234974, 56.09652668237686, 61.117790043354034, 58.70092213153839, 52.092730924487114, 45.58643124997616, 52.775360494852066, 54.275390803813934, 51.63105949759483, 44.4011190533638, 41.13854952156544, 43.31881932914257, 38.21310929954052, 38.15698251128197, 47.31147788465023, 53.75751279294491, 57.9471717774868, 54.52977955341339, 46.005385369062424, 42.93477773666382, 37.11235396564007, 27.995126992464066, 11.698988936841488, 1.4890263369306922, 7.668223176151514, 15.26959653943777, 12.929918635636568, 12.173126544803381, 13.87735789641738, 16.7033926025033, 18.79443369805813, 25.010402351617813, 24.254905991256237, 31.863017342984676, 22.203382775187492, 19.215661995112896, 15.950221717357635, 16.694316789507866, 19.73282754421234, 22.189973294734955, 15.263641308993101, 20.074755996465683, 17.67769642174244, 25.159035176038742, 34.258091524243355, 25.436992160975933, 11.438520513474941, 7.567500555887818, 4.522179616615176, 3.821286326274276, 0.8164155820850283, 1.0817569470964372, 37.191902697086334, 46.61390371620655, 66.82623893022537, 69.25448343157768, 42.114025577902794, 63.12771499156952, 58.08898016810417, 39.33643162250519, 12.990571931004524, 38.490547612309456, 24.518803730607033, 26.48298293352127, 43.746965155005455, 57.62871466577053, 59.75801020860672, 54.88835871219635, 33.21578845381737, 34.593723714351654, 3.4447721298784018, 0.11630496810539626, 0.11757555461372249, 0.23081984632881358, 0.08966073102783412, 0.01863759542175103, 0.04157265633693896, 0.024537454228266142, 0.04068974551046267, 0.0781682254455518, 0.10133790521649644, 0.023027879469736945, 0.05050591760664247, 0.06726120758685283, 0.08209242034354247, 0.07483213063096628, 0.1848488295217976, 0.04042237196699716, 0.040415766852675006, 0.06737396208336577, 0.08157499498338439, 0.04366936453152448, 0.044903793605044484, 0.018497938071959652, 0.08842157447361387, 0.02306477905221982, 0.14262188837165013, 0.0484856432012748, 0.04844691793550737, 0.02254675440781284, 0.0256766601887648, 0.05626676473184489, 0.09396141744218767, 0.05050682302680798, 0.1061040666536428, 0.09757750973221846, 0.11296660974039696, 0.1844016113318503, 0.13778280350379646, 0.28812743606977165, 0.22948657802771777, 7.948220651596785, 74.1756297647953, 60.679529160261154, 50.16395062208176, 73.27844470739365, 42.316984087228775, 33.24060492217541, 50.53587846457958, 28.86967096477747, 24.816107377409935, 60.35021983087063, 77.37234503030777, 69.0506699681282, 65.77787518501282, 74.40031170845032, 73.32857921719551, 52.77157209813595, 64.37162384390831, 25.718836337327957, 0.11984118304098956, 2.648276682011783, 2.146347602829337, 2.6567217288538814, 5.25323711335659, 8.827786054462194, 5.971039496362209, 8.645425289869308, 12.205850388854742, 17.019537538290024, 16.705567985773087, 17.701754830777645, 20.89754294604063, 15.813994277268648, 19.935229383409023, 24.807935915887356, 46.88709765672684, 33.08040551841259, 27.54241358488798, 17.206922583281994, 11.741535253822803, 10.435392390936613, 10.955436285585165, 10.370431076735258, 8.770450931042433, 4.682146282866597, 2.6947857113555074, 5.303944917395711, 27.376373894512653, 50.60490556061268, 57.09092952311039, 61.913284957408905, 60.4999165982008, 55.10530047118664, 49.143484979867935, 42.251855581998825, 42.1589619666338, 46.661241576075554, 51.89089335501194, 51.18487983942032, 53.81773576140404, 57.66116112470627, 58.00053231418133, 62.99482852220535, 64.79461714625359, 61.098711267113686, 61.920162588357925, 57.307791486382484, 61.91080369055271, 61.521142199635506, 51.78833685815334, 48.00726234912872, 54.01921235024929, 55.420668348670006, 57.7676086127758, 51.23564511537552, 50.61050646007061, 49.71379637718201, 52.014964297413826, 45.00916622579098, 52.196123376488686, 59.289062172174454, 63.06644707918167, 60.6785374134779, 50.81198304891586, 47.42562755942345, 41.50334894657135, 31.090220510959625, 12.317757233977318, 2.3752318834885955, 8.411856573075056, 13.873565699905157, 18.248509392142296, 22.121535167098045, 16.61773379892111, 20.512743294239044, 22.25489091128111, 26.464525423943996, 28.972219862043858, 33.67512300610542, 24.319234639406204, 22.346616089344025, 13.186027742922306, 9.783325530588627, 16.45909421145916, 17.761367931962013, 17.127902023494244, 21.863483414053917, 17.601115331053734, 26.252527199685574, 32.34480679035187, 19.710672833025455, 19.617252945899963, 10.87573366239667, 8.84914280846715, 4.800749318674207, 2.937292973510921, 0.6497773644514382, 40.157092586159706, 54.29454557597637, 68.04253846406937, 77.05290377140045, 49.340781792998314, 66.043860912323, 63.102784529328346, 50.40648780763149, 18.329787030816078, 27.557869255542755, 36.12385220825672, 26.809961088001728, 34.48769420385361, 58.19204583764076, 66.80884346365929, 70.40206745266914, 46.84726059436798, 51.237810999155045, 5.8692757319658995, 0.051700641779461876, 0.10581079957773909, 0.11776417886721902, 0.12910399498650804, 0.026673173415474594, 0.07784824847476557, 0.06472584558650851, 0.04187938968243543, 0.06731181463692337, 0.013724254968110472, 0.09848587622400373, 0.025007482327055186, 0.08471226843539625, 0.03989029661170207, 0.04876115810475312, 0.059186974831391126, 0.10514216162846424, 0.15427241945872083, 0.1322092892951332, 0.12911383586470038, 0.14953986246837303, 0.2778343524551019, 0.11251199233811349, 0.21553093625698239, 0.09334963542642072, 0.22940485272556543, 0.13939805823611096, 0.08428741857642308, 0.2160080778412521, 0.1282944157719612, 0.1377497927751392, 0.22874719114042819, 0.14632382488343865, 0.27372561511583626, 0.19593722827266902, 0.2582076040562242, 0.3589373786235228, 0.4275710176443681, 0.3812822577310726, 0.39591503504198045, 12.586909141391516, 95.29032155871391, 72.7373917400837, 63.749198243021965, 89.57890883088112, 66.46534189581871, 46.41846880316734, 76.59053698182106, 42.82956898212433, 27.090281546115875, 59.8429736495018, 83.69047120213509, 77.74383589625359, 71.91541224718094, 84.37669157981873, 77.89497658610344, 57.20625713467598, 70.16877517104149, 29.15729273110628, 0.28807682159822434, 2.5397338438779116, 3.936260319314897, 3.4827337553724647, 5.8377245999872684, 8.353074677288532, 8.52259498089552, 13.154033459722996, 19.846177361905575, 25.15100810676813, 23.248512893915176, 26.353749968111515, 28.442059010267258, 27.164862044155598, 28.191190771758556, 35.05580551922321, 52.65947051346302, 43.075784370303154, 36.81356839835644, 25.207476876676083, 19.976016394793987, 19.308686703443527, 18.20766158401966, 11.378753520548344, 8.912769444286823, 7.946949619799852, 6.500047584995627, 7.234602319076657, 28.390461578965187, 52.059562504291534, 60.087566524744034, 64.74917158484459, 63.647591695189476, 59.61942784488201, 51.618162989616394, 45.94007067382336, 45.98775431513786, 49.48311075568199, 55.81817641854286, 52.95214980840683, 56.14510327577591, 58.19363795220852, 59.48182202875614, 61.75629638135433, 65.53161799907684, 61.11362166702747, 57.295092567801476, 56.28796800971031, 63.00827980041504, 59.98477444052696, 52.40080699324608, 48.26216787099838, 55.299869030714035, 56.21796436607838, 61.60526588559151, 56.19000166654587, 58.78118522465229, 59.91760924458504, 60.163684040308, 49.405834302306175, 56.395126059651375, 59.21539932489395, 62.57461667060852, 61.83995269238949, 55.28265215456486, 48.215099796652794, 43.88906612992287, 33.07268053293228, 16.19427502155304, 5.556488865986466, 10.892809946089983, 19.361819252371788, 18.420448265969753, 23.450715243816376, 26.869562789797783, 28.17088846117258, 32.65143133699894, 37.24249318242073, 36.898417845368385, 42.70514465868473, 29.66412663459778, 27.35259287059307, 25.038376450538635, 27.18639548867941, 30.855396911501884, 31.249677054584026, 23.306978456676006, 28.95913526415825, 29.37572591006756, 34.783192947506905, 46.172044426202774, 35.84966652095318, 20.882632546126842, 10.566793140023947, 8.444288782775402, 7.499285191297531, 2.5408148858696222, 1.097169395070523, 48.14664267003536, 56.09086498618126, 74.84665855765343, 74.52718690037727, 53.20436127483845, 71.20171934366226, 71.2289334833622, 50.2716064453125, 19.947460927069187, 42.79200039803982, 32.076024413108826, 33.727655187249184, 63.55011932551861, 75.73405534029007, 75.45596346259117, 76.0120864212513, 59.460653364658356, 57.266415506601334, 4.628037661314011, 0.18433971621561795, 0.2987145882798359, 0.39069568854756653, 0.2717802382539958, 0.23051544703776017, 0.15834559308132157, 0.19135408045258373, 0.25419769110158086, 0.2418621873948723, 0.17273411474889144, 0.15986055397661403, 0.1545648553292267, 0.13798037805827335, 0.15486128395423293, 0.34451451036147773, 0.18329529179027304, 0.22418047446990386], [0.06664059401373379, 0.10910318931564689, 0.02427516068564728, 0.07456807448761538, 0.051759590569417924, 0.038931927920202725, 0.017934761162905488, 0.044573085178853944, 0.09382179719978012, 0.08674083263031207, 0.14130205294350162, 0.09977689405786805, 0.07795384866767563, 0.032036021584644914, 0.07641003307071514, 0.05091710823762696, 0.06710675181238912, 0.05121802314533852, 0.1415976948919706, 0.08891242352547124, 0.19337934209033847, 0.03304343139461707, 0.6036995525937527, 0.4095039964886382, 28.28606028109789, 67.07599192857742, 38.303958624601364, 57.9584039747715, 81.84921160340309, 33.704708218574524, 35.999720469117165, 33.566167652606964, 12.86625400185585, 29.25624892115593, 66.28349885344505, 66.69277489185333, 73.86453285813332, 64.0455025434494, 65.39521291851997, 72.4908609688282, 58.905598148703575, 17.20490489155054, 0.22996980522293597, 2.0564995240420103, 3.559995722025633, 2.4572583194822073, 2.9974356712773442, 4.916272144764662, 11.553361751139164, 19.0117896348238, 16.133449785411358, 10.717552900314331, 12.374953664839268, 22.319430448114872, 21.805099546909332, 17.803235985338688, 15.985569320619106, 31.114480309188366, 33.766914680600166, 27.73960590362549, 22.9661101475358, 12.502355128526688, 8.287176713347435, 9.930634126067162, 5.533358557149768, 10.522046741098166, 6.446638125926256, 4.310440253466368, 3.7646052427589893, 4.057189542800188, 15.684534274041653, 36.445998921990395, 44.41728338599205, 47.49275855720043, 53.22500936686993, 53.96359093487263, 50.380394607782364, 45.119535103440285, 38.13131868839264, 37.543091252446175, 45.33259727060795, 48.43220874667168, 50.60009501874447, 52.07227282226086, 55.51234222948551, 54.693706557154655, 60.40766514837742, 61.54441215097904, 53.83710712194443, 52.942566722631454, 61.86127334833145, 57.29710265994072, 51.772970482707024, 47.76605509221554, 56.68774075806141, 54.42257210612297, 51.74400843679905, 50.210745111107826, 44.15782950818539, 43.485843166708946, 39.35080625116825, 38.30860197544098, 45.723220109939575, 56.66634790599346, 64.02168542146683, 50.97953125834465, 36.11215643584728, 25.988388173282146, 28.63210391253233, 25.46951651573181, 11.664931364357471, 1.457190695218742, 6.579705560579896, 22.032359652221203, 19.31087538599968, 15.91929042711854, 14.611464254558086, 19.188026078045368, 15.855234414339066, 22.82574947923422, 24.063384868204594, 28.698400855064392, 25.08144523948431, 16.082063242793083, 17.292417995631695, 16.268051862716675, 17.17663060873747, 18.55661205947399, 21.754013188183308, 17.46057227253914, 21.472024619579315, 24.363800548017025, 19.75505445152521, 25.27340143918991, 23.686635084450245, 9.378821086138487, 8.221545685082674, 2.25534712895751, 3.4065319318324327, 0.2366509154671803, 23.62272821366787, 45.13444170355797, 58.31257916986942, 72.073764950037, 50.6560318171978, 53.842464834451675, 62.08249367773533, 24.488409161567688, 17.352194488048553, 23.554360382258892, 15.689493007957935, 33.262795731425285, 53.695006147027016, 63.830122500658035, 64.01021003723145, 36.416330114006996, 58.671298921108246, 16.83672744780779, 1.174981500953436, 0.06536132437759079, 0.05331446787749883, 0.040216581837739795, 0.01692381872999249, 0.027671219177136663, 0.06477609640569426, 0.06138106393336784, 0.026109324862773065, 0.10501762924832292, 0.017297178383159917, 0.02850116292393068, 0.025770298816496506, 0.015613156247127336, 0.03598095579945948, 0.013353403774090111, 0.07461378336302005, 0.06421718499041162, 0.028575474170793314, 0.037083516363054514, 0.013961842414573766, 0.04434090056747664, 0.0260094577606651, 0.022985842369962484, 0.05176598788239062, 0.03190370036463719, 0.03406718329642899, 0.07245794084155932, 0.04833862745726947, 0.06595004044356756, 0.07502227628719993, 0.019862124245264567, 0.03577780029445421, 0.06129879686341155, 0.11157040731632151, 0.009401971128681907, 0.11655510155833326, 0.03909419108822476, 0.17919562349561602, 0.13025180058320984, 0.6082730821799487, 1.2613683217205107, 40.25444716215134, 82.5391785800457, 45.26839591562748, 74.62500885128975, 73.49856689572334, 26.203384436666965, 41.8223912268877, 29.341544844210148, 22.909639477729797, 39.828250631690025, 73.57310369610786, 69.6481043100357, 78.55417281389236, 73.53890553116798, 68.67614686489105, 74.74651873111725, 63.476103097200394, 23.14105086028576, 0.3232170984847471, 2.332610283046961, 4.168227184563875, 2.3801908548921347, 7.632774878293276, 8.009989187121391, 9.579225182533264, 13.403023649007082, 16.462907306849957, 12.650920506566763, 13.481708876788616, 19.260423593223095, 19.29950639605522, 16.599251590669155, 22.090221047401428, 34.3826412409544, 37.890745997428894, 26.19121938943863, 23.200576566159725, 13.492621891200542, 9.107548892498016, 11.69926442205906, 12.953554317355156, 14.55571649596095, 12.621846366673708, 7.98452390357852, 4.7715022880584, 4.89687561057508, 17.837407551705837, 39.013084173202515, 51.67526252567768, 59.023961797356606, 60.10813482105732, 55.21561615169048, 52.68159292638302, 48.83527211844921, 43.817675560712814, 46.129262521862984, 51.898907124996185, 52.942771911621094, 55.05735084414482, 56.01507805287838, 58.229162245988846, 60.345192700624466, 61.77511677145958, 64.03723418712616, 55.99461995065212, 56.72042280435562, 62.78718486428261, 61.977854892611504, 53.12600947916508, 47.79493734240532, 60.67650072276592, 59.108856841921806, 55.2186331897974, 55.799245834350586, 54.90276373922825, 53.34743119776249, 45.48985943198204, 47.05215319991112, 50.927303060889244, 61.27163238823414, 64.47083652019501, 60.07738307118416, 50.86875960230827, 40.08273437619209, 38.74832198023796, 29.338172525167465, 11.309988610446453, 1.5339483576826751, 8.309753201901913, 21.703160516917706, 19.85143058001995, 23.63032590597868, 18.63418109714985, 19.358790814876556, 19.117946438491344, 23.83557379245758, 25.902318991720676, 31.152578964829445, 27.817765809595585, 20.69212406873703, 16.75360880792141, 11.651995908468962, 14.666311461478472, 13.667629100382328, 16.478944346308708, 16.83861594647169, 19.07669585198164, 23.207674585282803, 29.10738430917263, 28.351578265428543, 19.967539049685, 13.578674923628569, 11.409847252070904, 3.8373554265126586, 3.5093506146222353, 0.1861491464660503, 22.82593946903944, 53.171671628952026, 57.75342397391796, 74.52243715524673, 56.625971272587776, 62.8961706161499, 67.87283197045326, 34.58763264119625, 18.22928812354803, 25.876797661185265, 23.18312220275402, 23.919281400740147, 51.875728368759155, 72.34043464064598, 75.85709273815155, 48.800177201628685, 68.3444094657898, 22.90385238826275, 1.444790179375559, 0.06798729518777691, 0.0734998271218501, 0.09049488275195472, 0.09262996740289964, 0.053970133085385896, 0.12413890828611329, 0.032527542280149646, 0.06420354431611486, 0.06082865373173263, 0.017722835327731445, 0.05468729264975991, 0.04640890248992946, 0.009846772700257134, 0.02293565648869844, 0.06092821655329317, 0.024579276105214376, 0.021694076822313946, 0.06547908837092109, 0.135516774316784, 0.10775399452541023, 0.14480006211670116, 0.19154617795720696, 0.1137252850458026, 0.22409506811527535, 0.1439534645760432, 0.2108015853445977, 0.1009585490101017, 0.15368560329079628, 0.378044712706469, 0.2240544874803163, 0.12550978863146156, 0.09614016264094971, 0.15884845750406384, 0.2605242922436446, 0.14952458906918764, 0.27440221630968153, 0.1772224309388548, 0.24479448708007112, 0.2688904042588547, 0.8826647896785289, 1.2669403664767742, 54.20473359525204, 95.09326413273811, 61.074065789580345, 76.68806254863739, 101.9432781636715, 46.34711243212223, 53.18161189556122, 46.08241483569145, 23.070446848869324, 40.69447115063667, 74.90303233265877, 82.16111406683922, 84.59984600543976, 81.3616369664669, 77.32970371842384, 81.60325080156326, 68.28527703881264, 26.1012839153409, 0.44440732046496123, 3.925235685892403, 6.394415628165007, 4.403854440897703, 6.707282764837146, 8.956235311925411, 17.26553823798895, 28.875427655875683, 24.610027335584164, 17.78364233672619, 21.592191271483898, 32.1824187040329, 30.160079821944237, 29.69069480895996, 30.359599515795708, 43.71318116784096, 45.408262610435486, 36.96852408349514, 34.19385977089405, 24.362936094403267, 19.06810451298952, 23.701142705976963, 14.470530766993761, 14.254405964165926, 11.276771742850542, 8.459325525909662, 8.343467842787504, 9.297600444406271, 18.540573120117188, 40.04616133868694, 53.02622303366661, 60.84663659334183, 62.74758718907833, 58.24834741652012, 54.681676402688026, 53.4427946805954, 45.32572343945503, 48.63993979990482, 56.73998795449734, 56.21585927903652, 57.488334998488426, 57.30076186358929, 60.569878444075584, 58.026340529322624, 61.35099492967129, 61.8661142885685, 54.301974177360535, 56.299196407198906, 61.928856521844864, 61.38887129724026, 52.762669175863266, 49.448247626423836, 59.70218740403652, 59.12963032722473, 60.167909413576126, 61.130268573760986, 60.715657621622086, 60.632263496518135, 52.00612597167492, 49.22495640814304, 56.17650859057903, 64.84088346362114, 66.17785692214966, 59.682097882032394, 55.85965499281883, 44.858686700463295, 41.63542225956917, 31.77284438163042, 14.643034860491753, 8.590574283152819, 10.215821173042059, 27.122864797711372, 25.64235784113407, 22.474410831928253, 25.54179433733225, 31.561547219753265, 29.209726117551327, 32.74918869137764, 36.52410753071308, 36.00773423910141, 34.30465802550316, 23.51342137902975, 26.025061905384064, 25.552517361938953, 29.242292270064354, 28.341239020228386, 34.0164814889431, 27.503294683992863, 29.508562982082367, 31.870639733970165, 29.23579651862383, 38.55647027492523, 33.397924080491066, 14.820500537753105, 13.519367706030607, 4.692353960126638, 8.18752896040678, 0.33203229890204966, 28.5212429612875, 55.60359053313732, 65.87701186537743, 77.84719035029411, 59.36732277274132, 70.4490253329277, 73.1088750064373, 32.73227959871292, 24.427642822265625, 25.768203288316727, 19.916116409003735, 45.306139290332794, 76.75423979759216, 81.87249675393105, 78.80317345261574, 59.56300467252731, 78.73417675495148, 23.93703404814005, 1.6228898288682103, 0.12580425798660144, 0.41683012212160975, 0.10664171553798951, 0.23628591239685193, 0.1854961455683224, 0.22221296676434577, 0.12852963205659762, 0.15035493357572705, 0.21742379874922335, 0.07135407780879177, 0.09968405138351955, 0.08302665068185888, 0.09968246318749152, 0.09666274592746049, 0.13948750187410042, 0.17811710480600595, 0.1880392333259806], [0.03109710643911967, 0.027155228017363697, 0.02815691401337972, 0.08702328661456704, 0.024746554336161353, 0.0687377029680647, 0.03744766967429314, 0.03886692691594362, 0.050750150985550135, 0.07844380714232102, 0.058336035726824775, 0.03189109869708773, 0.07750797376502305, 0.059868529860978015, 0.048095340316649526, 0.12248286511749029, 0.152275285217911, 0.017120233678724617, 0.015367135220003547, 0.07773831413942389, 0.20538077544188127, 0.09332651010481641, 0.44887222931720316, 0.4089674534043297, 12.802764158695936, 69.13550421595573, 54.38739739358425, 36.31627768278122, 67.3730979859829, 66.86598479747772, 25.181623063981533, 32.80504189431667, 11.848262026906013, 20.176356844604015, 65.24351745843887, 62.687238827347755, 76.14408373832703, 57.89925254881382, 84.13760080933571, 73.0517640709877, 58.9490982145071, 21.299749463796616, 0.08713100192835554, 3.7205936294049025, 2.8089320613071322, 4.218385918065906, 4.420030172914267, 13.638449516147375, 15.508434623479843, 8.203186020255089, 11.644935887306929, 16.61041349172592, 13.649482224136591, 20.180971696972847, 18.845941834151745, 20.248737260699272, 23.53003788739443, 31.40410266816616, 28.1927277892828, 27.05660205334425, 14.916792120784521, 6.796928979456425, 8.684279154986143, 7.793014654889703, 9.46194352582097, 14.746902287006378, 11.494288221001625, 4.193881507962942, 2.885215342976153, 4.607214778661728, 2.481519067659974, 21.20187621563673, 34.642653688788414, 38.944475054740906, 49.98532220721245, 54.81840066611767, 55.66820226609707, 52.754298225045204, 40.80568738281727, 37.32889674603939, 43.01806926727295, 45.10051712393761, 49.55411374568939, 52.866350412368774, 53.97864192724228, 55.9746216237545, 55.01177988946438, 64.6570873260498, 49.36848230659962, 49.19542819261551, 64.00029256939888, 57.642678916454315, 50.177189111709595, 50.23377187550068, 56.27626843750477, 56.0441654920578, 54.28265981376171, 51.935016587376595, 50.36278635263443, 45.44504463672638, 37.61540897190571, 40.04855901002884, 48.79610762000084, 54.816854149103165, 57.0893070101738, 40.40768153965473, 22.576689943671227, 13.050630558282137, 10.549782402813435, 15.01754941418767, 6.533632082864642, 3.646234469488263, 12.745667472481728, 17.358703538775444, 28.47111415117979, 14.652787037193775, 19.223799258470535, 16.939323842525482, 22.056799940764904, 15.92059375718236, 24.790259264409542, 21.044619753956795, 28.179451301693916, 17.449731454253197, 19.496105946600437, 12.234478052705526, 11.374096870422363, 14.417348820716143, 16.667841710150242, 19.54323671758175, 21.61736112087965, 34.25621062517166, 28.305454440414906, 19.64738342911005, 23.412322103977203, 12.662320844829082, 10.065767224878073, 4.80558218434453, 3.3453229162842035, 0.44569034536834806, 8.97798154503107, 50.986120104789734, 48.16251061856747, 65.42697921395302, 59.24248047173023, 49.72525656223297, 66.20672017335892, 21.524984277784824, 16.389709934592247, 13.678852748125792, 23.444396182894707, 47.22182169556618, 65.265062302351, 53.21257643401623, 40.77649734914303, 56.23769670724869, 45.80999605357647, 2.0439801458269358, 0.05152689387614373, 0.15572349628200755, 0.13972665154142305, 0.09519796163658611, 0.06872178390040062, 0.09809885363210924, 0.09740754307131283, 0.09987539931898937, 0.11454021514509805, 0.07641418909770437, 0.03449752875894774, 0.03856184484902769, 0.08525422177626751, 0.07858415468945168, 0.00947916005316074, 0.08249769976828247, 0.023879492073319852, 0.08301412322907709, 0.025346723596157972, 0.04618534163455479, 0.043328373649274, 0.04056468249473255, 0.02561189110565465, 0.02907892303483095, 0.08379887018236332, 0.00035181104749426595, 0.022905534569872543, 0.04319498002587352, 0.11093037173850462, 0.04038536477310117, 0.1163626329798717, 0.023129518449422903, 0.08869894474628381, 0.008486223978252383, 0.14696541154989973, 0.005299400572766899, 0.08644429268315434, 0.09101832692977041, 0.23425582679919899, 0.15113380271941423, 0.6255886342842132, 0.33691726333927363, 17.854073457419872, 86.20010733604431, 65.21765604615211, 48.08892376720905, 78.76620903611183, 41.61681465804577, 32.36216425895691, 36.137919053435326, 18.34045495837927, 33.548449203372, 67.57896333932877, 74.00031477212906, 81.76851153373718, 69.90557849407196, 86.12706765532494, 79.36137109994888, 66.09559893608093, 23.398819528520107, 0.11497252358822152, 4.448368577286601, 1.7015434708446264, 6.75167340785265, 9.89576244726777, 14.416417870670557, 16.906544901430607, 14.284771084785461, 13.761449865996838, 12.716582883149385, 14.627649486064911, 20.182753801345825, 13.504655845463276, 20.184915885329247, 26.3816062733531, 38.00866886973381, 33.9787495136261, 27.106031700968742, 19.908229932188988, 11.141884680837393, 10.66797411069274, 16.195310465991497, 16.82888276875019, 20.26272051036358, 14.246907066553831, 10.348628796637058, 6.5869721956551075, 3.587364465929568, 4.627394545823336, 26.807806603610516, 41.6360492259264, 50.37684939801693, 61.39858737587929, 59.958897829055786, 55.136040821671486, 53.845740258693695, 45.111114755272865, 44.12131726741791, 49.42936263978481, 54.112102165818214, 52.4858084321022, 60.896961092948914, 58.90769563615322, 60.18439292907715, 60.53419075906277, 67.51908615231514, 51.64201430976391, 52.871666327118874, 63.75719681382179, 57.356611266732216, 53.89225356280804, 52.32469327747822, 55.8198369294405, 58.208597749471664, 55.9746178239584, 54.521628990769386, 56.411092802882195, 53.662856072187424, 45.62563754618168, 47.11360730230808, 56.318043395876884, 61.276990100741386, 63.305355459451675, 49.89893764257431, 26.709481179714203, 19.726280495524406, 17.520580552518368, 21.493704356253147, 7.775251083076, 3.266662862151861, 12.813078705221415, 20.283133015036583, 27.134024798870087, 21.404848024249077, 26.747275851666927, 16.908915974199772, 22.86206603050232, 19.671320244669914, 25.820885561406612, 25.41044868528843, 30.924469605088234, 21.074326559901237, 22.820009887218475, 14.674337580800056, 13.716793712228537, 14.46092203259468, 13.595155589282513, 15.607975982129574, 23.30517165362835, 30.56083671748638, 31.277041286230087, 22.994779609143734, 20.942397639155388, 13.357832673937082, 12.894304096698761, 7.113670008257031, 5.217906609177589, 0.36637144221458584, 7.897311458364129, 53.214073553681374, 52.399089485406876, 70.7657839357853, 62.36299842596054, 53.79838339984417, 69.87264186143875, 27.844544872641563, 21.36313196271658, 18.401282094419003, 24.32262785732746, 36.73341549932957, 70.4497092962265, 63.2973188906908, 51.45840436220169, 65.53386747837067, 57.933849692344666, 2.8199027851223946, 0.09950531253707595, 0.1765488280216232, 0.10300653520971537, 0.10730828289524652, 0.05120366629853379, 0.15863514941884205, 0.0197134126938181, 0.07394411382847466, 0.02360213293286506, 0.10796426722663455, 0.04178322218649555, 0.0050721368643280584, 0.02311319676664425, 0.032068809668999165, 0.014184873562044231, 0.09374900735565461, 0.10939543222775683, 0.008585255236539524, 0.15234454243909568, 0.1209259060851764, 0.17850122560048476, 0.22741536260582507, 0.17175997170852497, 0.1561455853516236, 0.160617470392026, 0.15930649620713666, 0.1328022059169598, 0.2053354005329311, 0.16119361447636038, 0.10628604868543334, 0.14143124601105228, 0.11592109964112751, 0.20429471653187647, 0.11971051309956238, 0.24537411925848573, 0.15266207774402574, 0.18661083653569221, 0.1575670504826121, 0.4063813656102866, 0.30452999810222536, 0.8228999935090542, 0.5650059913750738, 25.475734882056713, 105.54464131593704, 81.00153788924217, 58.38915266096592, 90.42507022619247, 82.83861011266708, 39.36468690633774, 50.0237837433815, 18.271197974681854, 29.802868589758873, 73.32447543740273, 77.78134748339653, 88.00181105732918, 78.52207213640213, 92.20361799001694, 83.2768101990223, 71.74195915460587, 28.170650973916054, 0.6200799986254424, 8.018514979630709, 4.243867825716734, 7.887023985385895, 9.82546716928482, 19.306148439645767, 26.012155897915363, 16.8463846296072, 19.38248824328184, 24.342122711241245, 26.58701565116644, 30.98492246121168, 28.47517803311348, 33.0736380815506, 38.55182312428951, 43.093920797109604, 41.40997275710106, 35.48284940421581, 28.03308505564928, 20.01815803349018, 23.02271381020546, 22.809752337634563, 16.999077536165714, 20.21412681788206, 14.129356574267149, 8.37582690641284, 7.923579923808575, 7.862245989963412, 5.537218675017357, 26.05953935533762, 44.364078640937805, 55.00593580305576, 65.06027609109879, 60.7642038166523, 58.624477833509445, 57.14457504451275, 48.556735664606094, 47.38246567547321, 52.17633783817291, 56.8190199136734, 56.25761143863201, 62.11359120905399, 60.505487099289894, 60.79349264502525, 60.88791377842426, 66.8036225438118, 51.33972533047199, 52.45977222919464, 64.84489604830742, 57.98998408019543, 53.58598239719868, 52.70525045692921, 58.56986716389656, 60.72408176958561, 57.93457545340061, 61.06735534965992, 63.07603396475315, 58.54903668165207, 50.29359586536884, 52.189390137791634, 61.02121442556381, 63.788111954927444, 63.755236119031906, 56.47380083799362, 36.998154893517494, 33.411360159516335, 26.343796402215958, 26.007791832089424, 12.11310401558876, 8.215026184916496, 18.861388005316257, 24.570015482604504, 38.275395557284355, 23.033206947147846, 28.957280963659286, 28.52632898837328, 35.76369993388653, 28.016685135662556, 36.17592841386795, 30.893195383250713, 35.41408449411392, 27.231409773230553, 26.01456306874752, 23.394820243120193, 21.492467522621155, 26.133618280291557, 28.01994726061821, 29.693791642785072, 33.76750744879246, 48.02968494594097, 36.45846225321293, 29.15575571358204, 33.355476558208466, 17.567378841340542, 15.47164499759674, 9.444979336112738, 10.543272402137518, 0.48151856346521527, 10.453742556273937, 58.82069170475006, 55.03977678716183, 79.29010212421417, 62.84842997789383, 62.766540572047234, 77.08843186497688, 29.680536054074764, 20.768549367785454, 14.610003232955933, 35.05273148417473, 58.764587715268135, 88.54413315653801, 69.90222707390785, 58.16095590591431, 75.75862482190132, 64.76086735725403, 2.8808082919567823, 0.1102023471321445, 0.2732181048486382, 0.2248097414849326, 0.16258756077149883, 0.13788988057058305, 0.23492778214858845, 0.2619021339341998, 0.2119966212194413, 0.23589166870806366, 0.10890546633163467, 0.12477001582738012, 0.13910550362197682, 0.16502416518051177, 0.18022548698354512, 0.13538286119000986, 0.2746302040759474, 0.18675577797694132, 0.16360056266421452], [0.05291406807373278, 0.03340660878166091, 0.06812131221522577, 0.021275770850479603, 0.05819271216751076, 0.06417202530428767, 0.0741752483008895, 0.05173767123778816, 0.052206894106348045, 0.03649239202786703, 0.022515439486596733, 0.033943649104912765, 0.05644960765494034, 0.07585881772683933, 0.07406569246086292, 0.038529427838511765, 0.04706830070063006, 0.042773069071699865, 0.05198192688112613, 0.19901225779904053, 0.11040234108804725, 0.31177778262645006, 0.07331216023885645, 0.1223027978267055, 2.1995727717876434, 61.14253431558609, 54.84883703291416, 77.42484301328659, 62.68579490482807, 71.9369874894619, 49.6959525346756, 14.349569007754326, 33.60523335635662, 13.151857126504183, 51.47899925708771, 66.42523124814034, 72.53693729639053, 55.48598304390907, 69.40232589840889, 54.92517873644829, 49.904112964868546, 8.087634220719337, 0.6061842036433518, 7.775014545768499, 1.6752884234301746, 3.975546886213124, 8.555688355118036, 16.090358197689056, 13.079745545983315, 16.676974520087242, 16.81590646505356, 13.301095068454742, 13.019945304840803, 16.965181455016136, 19.59862444549799, 21.02221805602312, 29.069006368517876, 30.129706151783466, 31.561057046055794, 22.180188819766045, 9.421012122184038, 5.295162163674831, 10.620594453066587, 8.603508789092302, 16.83636836707592, 18.401814065873623, 20.034396462142467, 7.435812447220087, 4.954229258000851, 6.336193727329373, 1.9677555235102773, 5.033039404079318, 24.580656811594963, 20.98423909395933, 31.36102057993412, 52.88354068994522, 59.40839856863022, 54.14959095418453, 46.09971150755882, 40.69891691207886, 39.56592030823231, 46.66645869612694, 50.20186498761177, 53.39578740298748, 53.09742361307144, 59.224629029631615, 56.70499563217163, 63.535839691758156, 43.08205023407936, 45.605852007865906, 63.900471925735474, 59.026260673999786, 50.492978766560555, 49.98573638498783, 58.997633010149, 59.09361965954304, 55.25336712598801, 55.98879486322403, 49.078090488910675, 44.60055135190487, 37.27484844624996, 46.35294511914253, 48.88955980539322, 62.48864248394966, 58.943903893232346, 40.63259907066822, 25.091115720570087, 16.739199981093407, 6.58873007632792, 5.4377685114741325, 1.8799663404934108, 8.215645551681519, 15.786763038486242, 15.695149004459381, 28.553077653050423, 23.186034746468067, 13.366249222308397, 17.484915666282177, 18.00320405513048, 16.64197649806738, 19.708681739866734, 22.927293330430984, 24.12159014493227, 24.028569236397743, 13.515616357326508, 20.046817995607853, 8.581259083002806, 8.682843782007694, 11.687291264533997, 13.943007923662663, 15.339853819459677, 24.074865952134132, 33.226918056607246, 26.88588861376047, 23.594254441559315, 13.730613570660353, 10.705229211598635, 9.25131132826209, 2.4144968390464783, 0.3592904331162572, 0.6821568519808352, 43.013023138046265, 51.83635488152504, 53.73203136026859, 55.69700852036476, 49.77670960128307, 63.969255834817886, 23.965454623103142, 17.20523737370968, 27.467306815087795, 32.696857899427414, 59.79645274579525, 53.25140655040741, 39.07576560974121, 44.5352366566658, 64.64315727353096, 9.139953553676605, 0.6139386375434697, 0.15351848647696897, 0.18975677085109055, 0.03254065231885761, 0.07730175319011323, 0.09528604714432731, 0.22884816775331274, 0.016534632777620573, 0.05219486018177122, 0.035915516928071156, 0.07850636276998557, 0.01063249001163058, 0.0358896567922784, 0.09349312967970036, 0.012301069909881335, 0.05268612483632751, 0.11215675593120977, 0.03689860284794122, 0.12284917436772957, 0.013122345371812116, 0.04448659157787915, 0.07899692980572581, 0.07426432828651741, 0.03814309173321817, 0.015235172086249804, 0.02075146392598981, 0.026794826262630522, 0.040650445080245845, 0.031957851169863716, 0.04340619154390879, 0.10486661703907885, 0.028519599727587774, 0.09441277681617066, 0.04273789869330358, 0.07457491708919406, 0.02989609813084826, 0.04311478725867346, 0.03721249791851733, 0.011662424003588967, 0.025236848632630426, 0.12267174912267365, 0.33375615952536464, 0.09415548905963078, 3.4668945427984, 75.94653233885765, 68.97003069519997, 76.29530042409897, 76.92767009139061, 63.383407071232796, 33.19632589817047, 26.991673037409782, 28.278435990214348, 26.184298060834408, 65.55234968662262, 70.79059660434723, 78.12858805060387, 66.64115086197853, 76.9270621240139, 66.20366513729095, 59.89041410386562, 9.60115760564804, 1.0929478215985, 7.753865355625749, 3.5029586451128125, 7.517464840784669, 10.41526772081852, 17.233285568654537, 19.19684160500765, 18.49690966308117, 17.00788926333189, 13.596955742686987, 13.240551967173815, 15.745115373283625, 15.270178858190775, 22.36401155591011, 32.829140201210976, 35.22414788603783, 34.289219453930855, 27.468796335160732, 10.490402039140463, 10.983041804283857, 16.216239742934704, 17.39559195935726, 21.048831827938557, 21.764500625431538, 20.60736771672964, 11.271706614643335, 9.410012662410736, 6.843308815732598, 2.463393802754581, 6.950384695082903, 30.280328169465065, 32.65185311436653, 43.73114660382271, 57.28478752076626, 58.954288735985756, 53.54968674480915, 48.480545952916145, 43.075734972953796, 45.98393552005291, 50.48536017537117, 56.24906189739704, 57.495888993144035, 58.49723406136036, 61.40147902071476, 61.28062270581722, 67.39676311612129, 46.35774806141853, 46.812671050429344, 68.37354630231857, 59.684997126460075, 53.11549164354801, 53.135132789611816, 60.07404305040836, 61.36213593184948, 60.27614660561085, 59.22236055135727, 57.49153822660446, 50.86565136909485, 43.67249675095081, 52.175558879971504, 58.7509236484766, 62.94670410454273, 61.494634822010994, 41.20886094868183, 28.477095030248165, 19.186186976730824, 9.397090505808592, 8.596729002892971, 3.9783022133633494, 7.277200883254409, 13.349331580102444, 19.481396935880184, 29.704442471265793, 24.790344759821892, 21.250958181917667, 18.35671618580818, 17.247080728411674, 17.92659256607294, 22.300969138741493, 23.858309872448444, 27.851129919290543, 26.606390811502934, 18.628536500036716, 21.582659482955933, 11.759668830782175, 12.574531305581331, 14.596977531909943, 13.537648525089025, 17.707604616880417, 26.340074501931667, 32.24495954811573, 28.96604899317026, 20.701724253594875, 15.924921724945307, 12.317444700747728, 11.911293994635344, 3.348016496747732, 0.5245166702661663, 0.6698715768288821, 38.451915085315704, 59.698049426078796, 62.423757165670395, 55.394556149840355, 54.34015452861786, 68.99311825633049, 31.058193929493427, 21.93993531167507, 22.704175002872944, 28.40155128389597, 53.559079840779305, 64.54722762107849, 48.179248720407486, 50.60300566256046, 78.52987691760063, 12.760891355574131, 0.6984496058430523, 0.08177238400094211, 0.2676910045556724, 0.061659024213440716, 0.14835156529443339, 0.07376777211902663, 0.1685435333638452, 0.01862925182649633, 0.05121033449540846, 0.04562975504086353, 0.01976314772036858, 0.057617688726168126, 0.014804168895352632, 0.08812547239358537, 0.056332437379751354, 0.06736000970704481, 0.009624543072277447, 0.02637792109453585, 0.08463374178973027, 0.12559648632304743, 0.0938683001731988, 0.26547144865617156, 0.13447171164443716, 0.17171854502521455, 0.07488369505153969, 0.19274201535154134, 0.18974528240505606, 0.13849263807060197, 0.04506480254349299, 0.2254630986135453, 0.13785422779619694, 0.14956402679672465, 0.13668868487002328, 0.2419682699837722, 0.17587363690836355, 0.1945498277200386, 0.2065369821502827, 0.16099314554594457, 0.26781506196130067, 0.25487087841611356, 0.3279145073611289, 0.3139598452253267, 0.20056493463926017, 4.10949326120317, 93.65417495369911, 85.11180773377419, 89.06424924731255, 83.63038122653961, 97.55708992481232, 64.38765898346901, 29.45177122950554, 45.1591669768095, 21.72431208193302, 66.79177477955818, 77.88785576820374, 85.1919074356556, 72.93124973773956, 83.92070844769478, 70.78948706388474, 62.51946642994881, 11.959689147770405, 1.4627326978370547, 11.825932525098324, 5.224818913266063, 8.23359103873372, 13.002814874053001, 23.662270791828632, 22.47582245618105, 24.094410203397274, 29.834000319242477, 21.722301989793777, 25.476781725883484, 27.134193889796734, 30.473431907594204, 36.99825368821621, 42.47694790363312, 41.421254351735115, 41.93521097302437, 33.18387396633625, 19.06639650464058, 21.46160937845707, 26.066962257027626, 22.431030459702015, 24.027668684720993, 24.94373682886362, 23.287210017442703, 11.73191512003541, 8.601467348635197, 12.841065153479576, 3.109530368819833, 7.982763648033142, 32.12718866765499, 40.98741263151169, 52.18579553067684, 62.97893017530441, 63.04670333862305, 55.01339480280876, 51.048603951931, 47.79982008039951, 48.536756336688995, 53.80073167383671, 61.432542353868484, 61.4107771217823, 59.662863314151764, 64.40314695239067, 61.475453451275826, 67.4265231192112, 47.0952694863081, 49.33370277285576, 67.0714245736599, 62.929719015955925, 52.53372386097908, 52.458814680576324, 64.60629925131798, 60.03056958317757, 61.72502785921097, 63.558193892240524, 61.54273264110088, 51.1274079233408, 52.64525547623634, 61.519341096282005, 67.79467016458511, 70.65599262714386, 63.8264063000679, 53.2120368629694, 35.76119966804981, 24.36763644218445, 13.389347232878208, 12.482837475836277, 7.198063004761934, 13.910220433026552, 22.867243252694607, 24.597816690802574, 36.137725263834, 31.238957829773426, 23.4354305639863, 28.59064433723688, 28.656616397202015, 27.5497604906559, 26.67754579335451, 34.0911740809679, 30.13267759233713, 33.20759989321232, 21.828956566751003, 31.530100107192993, 20.029386430978775, 19.778466895222664, 24.659001007676125, 25.11846475303173, 26.266177967190742, 35.16835168004036, 46.531011164188385, 37.754606902599335, 32.82652594149113, 22.49184049665928, 15.824529211968184, 14.310489054769278, 5.395557526499033, 0.5384283768944442, 0.600967617938295, 50.57598531246185, 61.39272429049015, 68.09941381216049, 60.25399759411812, 62.834860906004906, 77.34462931752205, 30.776961520314217, 18.667944185435772, 36.1474185436964, 46.5296546369791, 75.59429883956909, 75.69323793053627, 58.249570950865746, 62.8275652974844, 87.61667132377625, 16.734235547482967, 1.0104274121113122, 0.24988542718347162, 0.4195214167702943, 0.18404343602014706, 0.36296436097472906, 0.30042185448110104, 0.3529403207357973, 0.10876595741137862, 0.1992116728797555, 0.1160440438252408, 0.2006124024046585, 0.1514008126105182, 0.13979437993839383, 0.21425481332698837, 0.19617186568211764, 0.20192751777358353, 0.17935494775883853, 0.10452220856677741, 0.2474911994067952], [0.03361173097800929, 0.08447084037470631, 0.059296682811691426, 0.05011960005504079, 0.018660403475223575, 0.08876188629074022, 0.11547172180144116, 0.07860512036131695, 0.03090935235377401, 0.12545559700811282, 0.053535913611995056, 0.07604609869304113, 0.02762532476481283, 0.14562963478965685, 0.03297546922112815, 0.12313971776166, 0.08936254351283424, 0.049955500071519054, 0.054852721077622846, 0.10093031771248206, 0.081642760487739, 0.29110769333783537, 0.14767537970328704, 0.3927084227325395, 0.18549472064478323, 27.793234325945377, 83.62360998988152, 52.808578312397, 62.42412954568863, 62.986358776688576, 75.23267224431038, 25.265338271856308, 33.38074520230293, 22.752875089645386, 30.691610500216484, 79.2407351732254, 68.69528263807297, 58.491158187389374, 61.35862112045288, 62.4657829105854, 34.4488450884819, 2.0473980624228716, 1.1445998749695718, 4.385528974235058, 3.152529811486602, 6.627100417390466, 12.916814088821411, 17.393251284956932, 19.184986241161823, 27.60873332619667, 18.871875442564487, 15.960557162761688, 15.702521558851004, 15.419389251619577, 14.81244022026658, 26.264715045690536, 26.682496927678585, 28.305169455707073, 30.39668932557106, 15.721886269748211, 7.525512333959341, 6.751737054437399, 8.539581969380379, 13.73109519481659, 24.5546206086874, 26.431647688150406, 20.454526618123055, 12.868271693587303, 7.621991531923413, 4.967290107160807, 2.66973246820271, 0.755209238268435, 6.943659530952573, 22.18201082199812, 38.9876027405262, 47.19026438891888, 59.17977623641491, 55.076133236289024, 48.0648672580719, 42.90502153337002, 40.367251709103584, 45.7108935713768, 48.60847748816013, 53.24372336268425, 52.447316497564316, 57.405548840761185, 57.5336741656065, 59.46930930018425, 44.83287088572979, 49.59707424044609, 61.504350900650024, 54.01523016393185, 52.986480966210365, 50.57844378054142, 61.014048010110855, 57.93257296085358, 56.69533275067806, 56.911506950855255, 49.264025911688805, 40.72027176618576, 43.99045988917351, 47.08217538893223, 53.66777300834656, 63.28249208629131, 51.42750062048435, 30.293085984885693, 16.261164732277393, 7.384856231510639, 3.3698090398684144, 1.8205035687424242, 1.570941035170108, 14.413855858147144, 15.871279053390026, 19.29080106317997, 21.66214931756258, 28.548662289977074, 13.19915508851409, 17.716385945677757, 14.004808757454157, 18.006849959492683, 15.238423012197018, 17.95163132250309, 25.06911300122738, 24.63676080107689, 21.306368708610535, 18.594283238053322, 18.024002239108086, 9.573291800916195, 7.995281126350164, 12.054163478314877, 11.932112127542496, 21.744553595781326, 35.51694117486477, 27.623476535081863, 21.199263855814934, 11.55945472419262, 11.128725036978722, 10.98203295841813, 3.560056993737817, 1.0240971785970032, 0.49276747391559184, 23.47939420491457, 50.186578407883644, 47.51097097992897, 64.43325653672218, 53.54880519211292, 60.9347652643919, 17.695321775972843, 34.73451755940914, 33.88140633702278, 37.000221982598305, 69.19110283255577, 37.6269755512476, 36.61497965455055, 63.27614262700081, 25.96361730247736, 1.2595248268917203, 0.05523052990611177, 0.17395263217622414, 0.029175764029787388, 0.06131918366008904, 0.053528280623140745, 0.07853224145947024, 0.031445056811207905, 0.11517697043018416, 0.04373281073640101, 0.0813239932176657, 0.10746489831944928, 0.027668228321999777, 0.05854501338035334, 0.041216852187062614, 0.025915088117471896, 0.02581866086984519, 0.05756366779678501, 0.11681483098072931, 0.04638730228180066, 0.07520824365201406, 0.012108553091820795, 0.0780169980134815, 0.039088606426957995, 0.00930920916289324, 0.060789791168645024, 0.008281372665805975, 0.02144404912542086, 0.026999336187145673, 0.07059520954499021, 0.10389242946985178, 0.08376727695576847, 0.05746110298787244, 0.1331407588440925, 0.13502446323400363, 0.12329377277637832, 0.041744589689187706, 0.0818188201810699, 0.033836486691143364, 0.07405946584185585, 0.02480092407495249, 0.23230555176269263, 0.22330723382765427, 0.3782892058370635, 0.14575361798051745, 35.805201306939125, 96.2341833114624, 63.50007601082325, 71.65745928883553, 76.64045110344887, 48.848275020718575, 26.941709518432617, 31.011897213757038, 27.393180392682552, 45.53093142807484, 82.25720331072807, 76.48934841156006, 67.97729596495628, 70.48703849315643, 69.59265768527985, 41.203282848000526, 1.7383410525508225, 1.0573503817431629, 6.169964522123337, 7.1487117279320955, 9.561536181718111, 12.934163957834244, 19.340261109173298, 22.18791000545025, 30.29379654675722, 20.902621373534203, 12.628808543086052, 13.511926755309105, 16.62945616990328, 16.218513920903206, 26.550402715802193, 31.979653984308243, 34.09023553133011, 34.93687950074673, 17.899792604148388, 11.397912092506886, 11.329854894429445, 14.607564713805914, 19.673406332731247, 27.715813480317593, 28.34558218717575, 25.315799564123154, 16.589691303670406, 13.774249479174614, 8.054818231612444, 2.7869747020304203, 0.8691238600295037, 10.151009950786829, 26.257090754806995, 45.99386438727379, 52.98898883163929, 60.84536746144295, 55.337684601545334, 51.35512210428715, 44.47376735508442, 43.3242492377758, 50.294378623366356, 53.450466468930244, 58.547531962394714, 61.02198578417301, 64.34789031744003, 62.90781319141388, 64.17905017733574, 49.58191305398941, 51.87780685722828, 63.66495296359062, 56.306245028972626, 54.72047232091427, 53.020842522382736, 62.30043098330498, 58.27290929853916, 57.41131693124771, 60.26974014937878, 54.21755410730839, 46.562241688370705, 50.047327280044556, 57.92168274521828, 62.802300453186035, 69.62694704532623, 56.46581366658211, 41.0920400172472, 29.61860317736864, 20.51884386688471, 8.298325315117836, 1.934273976366967, 1.9968750234693289, 9.823076147586107, 14.75657656788826, 20.32833158969879, 27.31705527752638, 29.697543941438198, 18.81335288286209, 24.795860163867474, 16.20229259133339, 18.082638792693615, 19.25468400120735, 21.318657249212265, 28.384834080934525, 30.60050468891859, 23.908337987959385, 25.548335686326027, 16.96790400892496, 7.012815345078707, 11.484918873757124, 13.295696508139372, 14.51334211975336, 26.446544788777828, 35.2303833514452, 30.167692713439465, 22.20888677984476, 16.219765953719616, 15.075401309877634, 16.384553611278534, 5.6305991392582655, 2.2042847564443946, 0.27098590275272727, 16.904588006436825, 58.52898135781288, 55.039328411221504, 71.42501056194305, 59.30000938475132, 68.04410398006439, 28.042966425418854, 24.67456117272377, 28.80471345037222, 35.44575199484825, 69.4209448993206, 50.98971851170063, 41.24586336314678, 74.02894243597984, 36.075492203235626, 1.4470226783305407, 0.07206519629107788, 0.25033225945662707, 0.022749110248696525, 0.08190768494387157, 0.06620710555580445, 0.1411652602837421, 0.041575424547772855, 0.03164561479934491, 0.007316984228964429, 0.03953814382839482, 0.11314285497064702, 0.022358989190252032, 0.026599055127007887, 0.04711337875050958, 0.05351771615096368, 0.11642440193099901, 0.0915097251709085, 0.05876307492144406, 0.04675562275224365, 0.20238822820829228, 0.16206559346755967, 0.14092646684730425, 0.12116201294702478, 0.12368458032142371, 0.12419370104908012, 0.1835302112158388, 0.27403960295487195, 0.12185919389594346, 0.20989289972931147, 0.15390486340038478, 0.10145661173737608, 0.16115439939312637, 0.2945033158175647, 0.23669988237088546, 0.2661861665546894, 0.12719716527499259, 0.18601088435389102, 0.25870994897559285, 0.12650849675992504, 0.17817675863625482, 0.37114389706403017, 0.45195374521426857, 0.5014793376903981, 0.4496896604541689, 43.43583784997463, 109.92911964654922, 74.85861271619797, 74.23557534813881, 89.78260070085526, 97.8959633409977, 38.84095720946789, 43.474299386143684, 35.18679589033127, 42.80040554702282, 94.21817108988762, 81.97180822491646, 74.54885333776474, 75.762470215559, 76.30421474575996, 43.17096546292305, 3.54683346580714, 1.2359766592271626, 9.684662874788046, 9.4476486928761, 11.302081234753132, 20.530761927366257, 25.680690184235573, 30.772654451429844, 36.939801424741745, 30.799395516514778, 25.132824182510376, 29.33154948055744, 28.864151760935783, 28.282425776124, 40.26683449745178, 39.97290886938572, 39.380729645490646, 43.65817151963711, 26.446482092142105, 21.290367767214775, 23.609864003956318, 24.175617545843124, 26.44317626953125, 32.67485328018665, 33.86462263762951, 30.46842947602272, 21.746738478541374, 13.844527658075094, 8.597979135811329, 5.815776027739048, 1.9272472034208477, 11.8416902795434, 33.66910792887211, 55.50799526274204, 59.19869542121887, 62.26853549480438, 58.188652619719505, 53.94994206726551, 48.5063199698925, 48.012821450829506, 54.894331991672516, 58.08743745088577, 61.922442466020584, 61.02922059595585, 67.47964426875114, 63.31182651221752, 64.59828168153763, 51.44822470843792, 54.520496651530266, 64.75708276033401, 58.02365027368069, 57.21418730914593, 54.2560688406229, 64.2278091609478, 56.25526316463947, 60.7257878780365, 62.041277289390564, 58.134851306676865, 47.81126506626606, 56.75034239888191, 66.59375980496407, 69.0116460621357, 75.10177686810493, 57.53754995763302, 46.791791170835495, 37.17818543314934, 27.50727877020836, 8.934987802058458, 1.4286680007353425, 2.4269822565838695, 17.961898371577263, 21.089666336774826, 30.411022156476974, 35.037832483649254, 38.97709630429745, 20.31874280422926, 30.655689127743244, 24.546924121677876, 27.905360609292984, 24.52823292464018, 28.12120422720909, 33.582324385643005, 34.95313502848148, 31.757926382124424, 29.828752800822258, 29.634357132017612, 17.954017594456673, 17.38576378673315, 21.1558872833848, 27.87963978946209, 35.818656384944916, 46.4451889693737, 37.02564261853695, 34.04079258441925, 20.67276980727911, 19.486403167247772, 17.441898174583912, 8.406027685850859, 4.809048548340797, 0.29870660277083516, 24.589459039270878, 63.7409944832325, 55.89669920504093, 81.26486375927925, 59.32448387145996, 79.99846771359444, 19.913241863250732, 41.54645003378391, 49.062328934669495, 48.97944398224354, 89.75481659173965, 61.04552172124386, 52.98586539924145, 86.71070873737335, 47.13611729443073, 1.5861364197917283, 0.18743635708233342, 0.3239667566958815, 0.14287458965554833, 0.12521612079581246, 0.17571800854057074, 0.18881908210460097, 0.15431108535267413, 0.14601302827941254, 0.1482137484708801, 0.13845829147612676, 0.21774158638436347, 0.13869891059584916, 0.11754039907827973, 0.1649935293244198, 0.15788179531227797, 0.12211358727654442, 0.2064329182030633, 0.13425807701423764, 0.13833570352289826], [0.003800994441007788, 0.043694352643797174, 0.0385554920649156, 0.08652883814647794, 0.07861782592954114, 0.08959944447269663, 0.0523059225815814, 0.05943037700490095, 0.01759648097504396, 0.04590527736581862, 0.03841838028165512, 0.05166772010852583, 0.10648204988683574, 0.024702034752408508, 0.09929075764375739, 0.06332869321340695, 0.029520560274249874, 0.08139007404679433, 0.11870340385939926, 0.09975112669053487, 0.06465766447945498, 0.07274700736161321, 0.03808416520769242, 0.2689977188128978, 0.060807684349128976, 2.3482160456478596, 85.27408182621002, 59.07778210937977, 32.85501301288605, 55.934887155890465, 63.94338682293892, 42.31625072658062, 24.23754282295704, 27.33099862933159, 22.95027069747448, 75.12967497110367, 79.83335137367249, 71.07976108789444, 57.2858514636755, 62.338664531707764, 33.68559144437313, 0.5494216619990766, 2.0358447823673487, 3.189038489945233, 6.0745772905647755, 7.4998480360955, 17.266142405569553, 22.897153347730637, 22.802036851644516, 20.640418343245983, 19.079777486622334, 11.426242422312498, 11.679650824517012, 9.026994165033102, 20.596401505172253, 35.759014785289764, 34.3094115704298, 30.40946613997221, 22.833299674093723, 12.467620242387056, 4.213913083076477, 4.234964903444052, 5.678765354678035, 21.742621399462223, 38.33029501140118, 30.786565504968166, 25.78697808086872, 18.585228323936462, 14.405086878687143, 9.821048956364393, 4.2434408236294985, 0.2697408164385706, 0.3320087579777464, 13.042896073311567, 37.21609979867935, 46.85489438474178, 55.93854255974293, 55.61879351735115, 52.46002681553364, 45.473767295479774, 41.88845068216324, 43.13854180276394, 48.86541590094566, 54.758398085832596, 54.19760897755623, 57.86209434270859, 57.62068189680576, 57.33429506421089, 41.048182770609856, 50.02770133316517, 57.90305234491825, 53.81488971412182, 49.064662009477615, 50.70416383445263, 58.05471360683441, 56.43857292830944, 59.536713883280754, 60.70184536278248, 47.62838467955589, 45.86598224937916, 46.82191215455532, 47.26385124027729, 51.62565618753433, 53.3319166302681, 42.97656029462814, 19.32603657245636, 8.677156437188387, 3.598723243921995, 0.3803747892379761, 0.28328887070529163, 2.928961683064699, 14.645599722862244, 16.493765451014042, 17.776472121477127, 20.669363290071487, 29.72103238105774, 21.105767972767353, 11.062481291592121, 13.150335308164358, 13.361707516014576, 16.155315712094307, 12.17486685141921, 21.21144600212574, 24.826176837086678, 23.645682781934738, 25.262325033545494, 21.411267779767513, 16.853651739656925, 8.082408551126719, 10.33727215602994, 14.482486825436354, 16.717852726578712, 26.14149335771799, 33.77566561102867, 19.870478957891464, 18.446682058274746, 10.333132278174162, 13.617321699857712, 4.272600458934903, 0.5192612553946674, 0.2621957572409883, 4.0951689798384905, 47.33004368841648, 55.856432765722275, 58.46760705113411, 61.98910228908062, 47.2429371625185, 20.28121791779995, 55.88962398469448, 23.207190111279488, 63.2141375541687, 55.52439518272877, 27.81602170318365, 46.04747571051121, 48.846242129802704, 5.732684461399913, 0.08177100360626355, 0.12420872211805545, 0.17943207174539566, 0.06730774766765535, 0.13338036864297464, 0.07286504594958387, 0.12829636019887403, 0.014832051383564249, 0.10055134742287919, 0.03749536750547122, 0.0462430584593676, 0.012971671767445514, 0.026361616110079922, 0.012541564719867893, 0.07164592738263309, 0.031382055894937366, 0.012382912100292742, 0.00910716873477213, 0.010976126650348306, 0.05439812593976967, 0.036453729844652116, 0.03993983496911824, 0.07847945249523036, 0.023456145063391887, 0.10183631675317883, 0.0932748343620915, 0.03726449649548158, 0.03489304152026307, 0.01541663925308967, 0.04351461560872849, 0.05214418633840978, 0.03305146143247839, 0.03847067571769003, 0.050056706750183366, 0.06498253220343031, 0.027698628546204418, 0.05237849720288068, 0.06482254742877558, 0.10337297804653645, 0.07310238477657549, 0.032442596057080664, 0.11883286410011351, 0.018628405778144952, 0.4286802315618843, 0.03894235138432123, 4.720639167353511, 96.31342425942421, 67.89753824472427, 36.65108531713486, 70.55453047156334, 58.684469014406204, 39.16171319782734, 29.89523023366928, 27.286938093602657, 41.60396754741669, 83.22700247168541, 84.12161886692047, 76.94967091083527, 63.68235222995281, 68.21703270077705, 29.45067308843136, 0.38938547135330737, 3.9075267361477017, 4.849624196067452, 9.416460916399956, 9.84326446428895, 15.490110106766224, 20.555808283388615, 26.352017261087894, 23.390600569546223, 19.403706304728985, 13.361724615097046, 13.414166551083326, 9.606635961681604, 21.454152278602123, 35.67983463406563, 37.971335873007774, 36.48303173482418, 25.53682990372181, 18.65191664546728, 10.583823826164007, 6.646207217127085, 13.639823142439127, 27.020815573632717, 36.38816602528095, 32.48599201440811, 29.072640873491764, 20.811253376305103, 19.71420094370842, 11.596133206039667, 4.012646907940507, 0.439591642934829, 1.0489537823013961, 16.65532138198614, 39.51348692178726, 49.87061396241188, 58.921789079904556, 60.341058522462845, 56.46811634302139, 47.05077767372131, 45.407103672623634, 46.730975434184074, 54.24883782863617, 58.87735806405544, 57.38493114709854, 61.476327404379845, 62.303455621004105, 63.37607726454735, 45.420060977339745, 53.72040018439293, 61.1424545198679, 57.173126712441444, 49.01248320937157, 52.489376440644264, 62.3530163615942, 58.942676559090614, 62.52440996468067, 62.78753064572811, 51.937657445669174, 48.530239686369896, 54.39864858984947, 57.839591950178146, 61.689617559313774, 57.84080408513546, 47.395578771829605, 22.96106591820717, 10.972712058573961, 7.382598202675581, 1.7561968881636858, 0.7283466390799731, 1.3760071014985442, 13.143954500555992, 18.458949699997902, 17.159719616174698, 26.40813834965229, 28.032496087253094, 26.00736055523157, 18.711493648588657, 19.114167541265488, 13.61268974840641, 16.770909279584885, 15.148399192839861, 22.442298755049706, 27.20512468367815, 27.84963469952345, 30.05746442824602, 23.743223547935486, 10.516874268651009, 3.8006182853132486, 14.251675810664892, 17.89451278746128, 23.537897765636444, 30.39637204259634, 33.58867384493351, 27.52963487058878, 24.02883142232895, 15.289680361747742, 13.914034478366375, 6.823880458250642, 1.745879848022014, 0.14999784179963171, 2.8674446465447545, 48.92375037074089, 61.530470699071884, 66.00812003016472, 66.12031280994415, 62.363575994968414, 22.714181765913963, 31.30119848996401, 27.75828380137682, 54.36052143573761, 68.39350283145905, 33.00526835024357, 53.0331614613533, 62.33016438782215, 7.400200758129358, 0.0862674463132862, 0.09572594033670612, 0.13011426577577367, 0.03092149203439476, 0.1276486730785109, 0.02642950406880118, 0.030313120187202003, 0.044343709596432745, 0.04244326235493645, 0.03480264051177073, 0.016644320348859765, 0.04693633942224551, 0.04526872617134359, 0.08271991362562403, 0.0944461883045733, 0.06350743205985054, 0.009975372049666476, 0.013380241689446848, 0.02652475315699121, 0.02427642233669758, 0.15759020549012348, 0.10313261867850088, 0.16681232547853142, 0.18791088630678132, 0.17694477865006775, 0.263930750079453, 0.12944683752721176, 0.19174140732502565, 0.09463712805882096, 0.24065817153314129, 0.15464745636563748, 0.16208637360250577, 0.12927304138429463, 0.10059658874524757, 0.12790496635716408, 0.1825093722436577, 0.14143132022581995, 0.19417081290157512, 0.1880751532735303, 0.3813080250984058, 0.12991636467631906, 0.1914817892247811, 0.14563025819370523, 0.4967935656895861, 0.09892939851852134, 5.999078191816807, 113.83179143071175, 81.48078337311745, 50.26279091835022, 72.42044314742088, 83.29803586006165, 58.91956239938736, 35.87771661579609, 39.289884120225906, 34.29256707429886, 95.47878384590149, 90.14721393585205, 84.24740731716156, 75.40383785963058, 75.40553256869316, 40.88124632835388, 0.569868542952463, 5.543732950463891, 9.4626759365201, 12.382067833095789, 11.31695743650198, 23.321446180343628, 32.838297709822655, 29.741180799901485, 31.677287109196186, 31.843043714761734, 22.50172756612301, 25.58305062353611, 20.579954087734222, 35.93994967639446, 50.864815413951874, 47.86303348839283, 43.35164576768875, 35.84949932992458, 27.0516300201416, 20.116734243929386, 17.16213058680296, 23.703082501888275, 34.731321930885315, 46.10360249876976, 39.468702524900436, 37.03209847211838, 29.12538204342127, 25.225926786661148, 17.35508043318987, 7.84673617221415, 4.383159801363945, 3.180626453831792, 21.218980997800827, 51.528047025203705, 57.498237267136574, 61.68011046946049, 63.689017072319984, 58.29384237527847, 52.3204755038023, 48.771116361021996, 50.71410030126572, 55.72763867676258, 65.90088978409767, 60.902630388736725, 62.95538663864136, 64.78601440787315, 63.19037362933159, 47.25505091249943, 55.906571075320244, 61.70499533414841, 57.172362953424454, 49.06634911894798, 53.96971620619297, 60.67025385797024, 61.868667751550674, 64.62620258331299, 65.4750694334507, 51.55094839632511, 51.35183148086071, 57.715859189629555, 67.48991891741753, 70.70814102888107, 60.71390211582184, 51.407221108675, 22.170917317271233, 12.030499298125505, 8.03189406171441, 2.3271587630733848, 0.34788771998137236, 3.3836350729689, 21.460038162767887, 26.152007393538952, 25.675991736352444, 32.331803888082504, 41.019600704312325, 30.516722984611988, 19.86645307391882, 24.03325818479061, 20.711096450686455, 25.68020761013031, 21.255004964768887, 30.39602056145668, 34.318177700042725, 34.78646457195282, 36.915748715400696, 33.57119098305702, 30.51488198339939, 18.788859397172928, 21.443925127387047, 25.397590175271034, 28.73462811112404, 38.598328828811646, 43.75465214252472, 31.02840732783079, 28.65973223000765, 18.44903413206339, 18.517616651952267, 7.162108384072781, 1.7620546300895512, 0.16980975604383275, 3.9712020568549633, 59.11896429955959, 64.26515355706215, 71.15232959389687, 71.19864150881767, 67.2293820977211, 21.91498015075922, 72.87195771932602, 34.39157836139202, 77.6601567864418, 78.62575337290764, 44.7005657851696, 66.31179213523865, 82.32295498251915, 10.205190293490887, 0.17206665681442246, 0.2522738365223631, 0.22962101065786555, 0.16022156429244205, 0.22961127368034795, 0.20141623739618808, 0.27838181995321065, 0.09280803089495748, 0.14952798810554668, 0.1344621230964549, 0.10395684046670794, 0.1394331024494022, 0.11012721952283755, 0.14804642385570332, 0.17153714929008856, 0.25285541312769055, 0.06838557615992613, 0.16857853304827586, 0.14339888730319217, 0.14094781101448461], [0.08507508217007853, 0.06942830848856829, 0.0526051676570205, 0.033253496294491924, 0.04593997648044024, 0.018335287131776568, 0.047505414549959823, 0.05559424535022117, 0.02072774488624418, 0.07417253946186975, 0.08795719040790573, 0.02915317119914107, 0.009863747472991236, 0.047573859119438566, 0.09324346377979964, 0.04030737989523914, 0.07959804715937935, 0.01929155368998181, 0.06356553480145521, 0.028767178337147925, 0.03758287784876302, 0.07921989323222078, 0.1679254579357803, 0.1005844546307344, 0.26147706143092364, 0.04309004776587244, 25.14485813677311, 97.1009624004364, 43.11787091195583, 43.07815924286842, 66.9596041738987, 51.219476982951164, 30.504979714751244, 35.332502871751785, 22.813217751681805, 60.12279063463211, 81.04385241866112, 67.41336822509766, 59.00743268430233, 66.80427610874176, 20.734560191631317, 0.9775150031782687, 3.0862428434193134, 3.604965596459806, 5.7747904770076275, 10.604498516768217, 15.257960613816977, 24.44367416203022, 28.648729920387268, 25.855326913297176, 16.98850080370903, 11.051411535590887, 14.34946071356535, 9.420420303940773, 28.877116665244102, 41.54132030904293, 34.184542670845985, 29.105923287570477, 20.497479513287544, 8.756436333060265, 4.750469941645861, 3.5333833750337362, 9.006597809493542, 34.94818389415741, 48.49933974444866, 35.64378596842289, 27.562398612499237, 20.233682468533516, 21.982762813568115, 16.35903038084507, 4.081932390108705, 1.4337738580070436, 0.8167199220042676, 4.4952761102467775, 26.12444367259741, 40.99641814827919, 58.63638259470463, 58.448095098137856, 54.695610255002975, 49.62034799158573, 46.82637691497803, 43.206565752625465, 45.396874621510506, 50.76526455581188, 52.31381066143513, 56.81008279323578, 58.82383793592453, 56.523418575525284, 35.42776755988598, 50.697472393512726, 56.4251596480608, 51.992051526904106, 48.646099269390106, 51.85593523085117, 55.99302023649216, 57.70074360072613, 62.60569140315056, 56.5478702634573, 47.491877004504204, 48.98233562707901, 48.469758331775665, 48.81775885820389, 43.81484091281891, 43.775513023138046, 27.739045433700085, 13.647506330162287, 4.754112996160984, 0.8370193233713508, 0.7265076565090567, 0.18704496324062347, 1.9506563222967088, 8.670889623463154, 14.75136799737811, 17.671041078865528, 21.267796978354454, 35.504702031612396, 39.32112604379654, 11.210170816630125, 5.2840582095086575, 7.360970713198185, 12.007562778890133, 9.824542868882418, 9.959962852299213, 24.426290094852448, 23.921945057809353, 31.982063055038452, 22.47851651161909, 18.5530174523592, 17.27666024118662, 11.09692644327879, 7.991820462048054, 18.492458201944828, 29.70268316566944, 24.158959239721298, 19.969824627041817, 28.627171777188778, 21.34832225739956, 13.53377653285861, 8.106906786561012, 0.8142022602260113, 0.9625372756272554, 0.7067047222517431, 32.124095633625984, 63.98526817560196, 62.77332700788975, 78.54183107614517, 26.259851306676865, 40.68414710462093, 34.89596709609032, 31.51039246469736, 67.22129613161087, 36.39681056141853, 31.36198002845049, 41.537687703967094, 8.106556255370378, 0.09363716570078395, 0.10495972688659094, 0.11372539636795409, 0.013771501944574993, 0.07925674828584306, 0.051194010957260616, 0.17436649824958295, 0.017400988144800067, 0.09300757956225425, 0.0844763545319438, 0.012317172659095377, 0.059559740766417235, 0.05264360719593242, 0.017847384406195488, 0.06346193098579533, 0.0545191590936156, 0.05194509409193415, 0.06177728544571437, 0.04172948327322956, 0.043818751437356696, 0.09200393615174107, 0.08919301471905783, 0.03799434307438787, 0.048603622417431325, 0.014859120292385342, 0.05193859287828673, 0.03830302084679715, 0.05948675054241903, 0.03177982107445132, 0.021120942146808375, 0.03568368483684026, 0.08709808767889626, 0.07339415271417238, 0.13942357327323407, 0.07615639668074436, 0.04912227603199426, 0.01563242982228985, 0.18400862929411232, 0.06402701706974767, 0.08073036413406953, 0.01802758899430046, 0.12599401030456647, 0.05675765831256285, 0.23291412770049646, 0.11364309219061397, 0.31616687367204577, 0.12697873637080193, 34.0627858042717, 107.4831148982048, 46.2851719558239, 50.52832446992397, 76.19126200675964, 36.893504709005356, 33.563826978206635, 27.25565057247877, 30.562214143574238, 81.90917238593102, 83.51108282804489, 74.57966208457947, 65.6276236474514, 75.77127054333687, 16.70813474804163, 0.6128856784198433, 4.2127004731446505, 3.426490598358214, 8.663296680897474, 11.790961101651192, 19.11132339388132, 24.53199092298746, 27.155212461948395, 27.903398014605045, 19.662430621683598, 12.651496175676584, 17.94767763465643, 8.302074763923883, 29.626102074980736, 42.46800698339939, 39.38829503953457, 34.67204511165619, 21.73510730266571, 15.814966075122356, 8.97566081956029, 8.144472520798445, 15.214807279407978, 34.42794241011143, 39.0497750043869, 33.47850255668163, 30.93647126108408, 23.208569437265396, 25.944276340305805, 12.783652134239674, 6.0689987149089575, 1.4472672902047634, 0.8240778115577996, 5.4711606446653605, 29.909903146326542, 47.14351549744606, 64.14194136857986, 61.90207555890083, 56.977843791246414, 52.60205179452896, 49.24953728914261, 48.773525431752205, 50.11997178196907, 54.640813395380974, 57.04690508544445, 64.33942437171936, 61.53269737958908, 61.623185724020004, 39.737671092152596, 58.75007629394531, 61.12401030957699, 56.4771294593811, 51.688702404499054, 56.5305469930172, 59.792554154992104, 59.31944154202938, 63.38278770446777, 59.254145845770836, 49.912962689995766, 51.46610274910927, 55.67531928420067, 57.86858819425106, 59.145213291049004, 52.295062467455864, 36.10980436205864, 16.79789163172245, 5.898046363145113, 2.3323518969118595, 0.7776030397508293, 0.5485824414063245, 1.5178733202628791, 7.695702351629734, 15.364382453262806, 16.960205622017384, 23.88010360300541, 32.244321182370186, 34.77722726762295, 20.196668654680252, 11.687266565859318, 8.505420852452517, 14.573649633675814, 11.053430177271366, 10.319735147058964, 24.000874422490597, 29.150779880583286, 35.138899460434914, 29.024451859295368, 19.74832121282816, 9.80233496055007, 6.654133116826415, 10.263075437396765, 22.65773769468069, 29.447162076830864, 25.777636282145977, 28.32974273711443, 28.53974226862192, 26.260392777621746, 15.047195423394442, 9.476531893014908, 1.7360019218176603, 1.8398773041553795, 0.5751196236815304, 30.15605203807354, 68.24765905737877, 69.08736079931259, 75.581523925066, 45.13633020222187, 24.565668515861034, 33.73832121491432, 28.301867432892323, 69.11102592945099, 49.19591836631298, 37.90007449686527, 56.161290407180786, 18.08706745505333, 0.2580491703702137, 0.24565022788010538, 0.2648795710410923, 0.08591746431193314, 0.07910069689387456, 0.048626825664541684, 0.09691434883279726, 0.03801778751949314, 0.035483624087646604, 0.097717352618929, 0.02958400462375721, 0.05163281319255475, 0.08996408389066346, 0.05368368263589218, 0.06804950200603344, 0.07939053524751216, 0.05165437629329972, 0.07196051636128686, 0.06781031523132697, 0.037452508477144875, 0.13730794773437083, 0.1333557441830635, 0.15995111083611846, 0.12964536203071475, 0.12971377320354804, 0.14908783516148105, 0.10644229303579777, 0.20782091247383505, 0.15775279520312324, 0.12427984955138527, 0.0935806956840679, 0.17967539228266105, 0.07550175563665107, 0.32959763891994953, 0.121577867976157, 0.16282953059999272, 0.1702511854819022, 0.18990760494489223, 0.1959047222044319, 0.13813348312396556, 0.10669011840946041, 0.12829318380681798, 0.146860976528842, 0.30605623964220285, 0.25247065408620983, 0.5664322210941464, 0.3375342255458236, 41.124098896980286, 126.51370972394943, 62.42255263030529, 63.97769898176193, 86.8350076675415, 69.68915730714798, 40.797468423843384, 46.78091995418072, 27.091921158134937, 79.88026365637779, 91.57406777143478, 83.76381486654282, 71.56347513198853, 81.92175731062889, 25.642224848270416, 0.7537565287202597, 6.779863620176911, 8.931078761816025, 8.755854964256287, 14.461963176727295, 25.317080095410347, 35.61674281954765, 39.354590848088264, 38.47390450537205, 27.539185658097267, 21.254136711359024, 25.54223321378231, 22.404230497777462, 46.37846454977989, 57.17070244252682, 45.19409470260143, 43.75636205077171, 32.68911771476269, 25.532716624438763, 22.35258936882019, 18.531436510384083, 25.087192431092262, 42.33165889978409, 56.91487357020378, 47.516659274697304, 40.10378144681454, 33.97222526371479, 35.07717937231064, 27.027280926704407, 10.0626171939075, 3.4121884033083916, 1.3976799510419369, 5.559162022545934, 30.631706714630127, 52.33794316649437, 65.52876055240631, 68.08373585343361, 61.75062708556652, 55.43535076081753, 50.9217781573534, 54.007683768868446, 51.306678503751755, 57.318081334233284, 58.15751329064369, 66.06853678822517, 62.49162532389164, 64.9915985763073, 41.927816569805145, 59.25916537642479, 60.174201875925064, 56.019892394542694, 52.471095621585846, 55.46273209154606, 56.19237273931503, 61.560238301754, 63.79106059670448, 56.455383226275444, 51.936217322945595, 54.55790564417839, 57.253914177417755, 66.55902966856956, 67.96645134687424, 54.6725644916296, 45.21251231431961, 26.067870408296585, 8.553714361041784, 1.4854367170482874, 1.205046793911606, 1.1411913391202688, 3.539559468626976, 13.68524780496955, 22.236547395586967, 28.82851917296648, 35.110826566815376, 47.42277771234512, 48.57580304145813, 21.967681422829628, 15.70525836199522, 16.283925510942936, 24.950534664094448, 21.075548194348812, 16.81224536150694, 35.74017159640789, 35.991702899336815, 44.813864305615425, 33.81201446056366, 31.99734203517437, 29.85836461186409, 23.22599720209837, 17.173505276441574, 29.881169088184834, 40.74995197355747, 36.667101457715034, 30.825416520237923, 38.14088277518749, 29.630327448248863, 20.296683087944984, 11.17854131385684, 2.8687133034691215, 2.672574953176081, 0.5395665939431638, 35.09668752551079, 76.41464442014694, 69.57283794879913, 91.35899931192398, 38.144538179039955, 48.30852918326855, 49.51635517179966, 43.91801297664642, 87.2513285279274, 62.3430684953928, 50.81572584807873, 80.44296786189079, 28.161495365202427, 0.7286396983545274, 0.5764070420991629, 0.2576961455633864, 0.19919582060538232, 0.25033080484718084, 0.12518717703642324, 0.3147342021111399, 0.1788215959095396, 0.16458315134514123, 0.15704122401075438, 0.14306506927823648, 0.1958134231972508, 0.19908062444301322, 0.15443380689248443, 0.2525666286237538, 0.15339010977186263, 0.1948062248993665, 0.21637211611960083, 0.23046576767228544, 0.0788847690273542, 0.2742534305434674], [0.0329419501213124, 0.0731526875460986, 0.03466538772045169, 0.049132873900816776, 0.09326529776444659, 0.03931779276172165, 0.06880721994093619, 0.04950706847012043, 0.040313654753845185, 0.08530418315785937, 0.08532574996934272, 0.053338379875640385, 0.04417339041538071, 0.03017326060216874, 0.08840252354275435, 0.044789105813833885, 0.08395032768021338, 0.0567323733412195, 0.03820321311650332, 0.058430952703929506, 0.0645860175427515, 0.06539979731314816, 0.12838402268243954, 0.039525074607809074, 0.16412309400038794, 0.1074414316099137, 1.3900952017866075, 49.30736258625984, 71.92757919430733, 40.32749444246292, 66.37113735079765, 68.9427861571312, 45.90991169214249, 42.13314235210419, 32.23954863846302, 38.84675569832325, 72.59236872196198, 65.82645937800407, 68.62340569496155, 56.27435714006424, 2.475617746822536, 0.21697140036849305, 2.7461553923785686, 3.921778346411884, 9.799743499606848, 12.866519037634134, 18.088779263198376, 21.380561627447605, 28.036366179585457, 27.591107971966267, 17.08364959806204, 13.727572783827782, 8.76493077725172, 13.727188054472208, 42.263045981526375, 39.33937646448612, 30.759919434785843, 25.867562256753445, 15.964284762740135, 8.5108089633286, 4.184515960514545, 7.68114865757525, 16.030460111796856, 42.09340028464794, 62.45646961033344, 42.096474319696426, 30.267256870865822, 21.675896979868412, 20.65693035721779, 26.96402382105589, 4.331257911399007, 1.3087391923181713, 2.4487408390268683, 2.07859652582556, 5.703038452193141, 31.83609388768673, 48.05121839046478, 58.9839993417263, 57.849118039011955, 53.96091967821121, 48.896323442459106, 47.469298616051674, 47.75098890066147, 53.05419333279133, 54.431030452251434, 58.179510310292244, 58.931588754057884, 57.891941741108894, 37.19642825424671, 48.78581777215004, 58.5091046243906, 52.22175680100918, 48.82915824651718, 52.15152896940708, 54.261852130293846, 58.857568725943565, 59.00938577950001, 54.74544458091259, 45.87559953331947, 47.307434901595116, 50.118413865566254, 48.31399708986282, 45.38367412984371, 39.358972012996674, 35.243827030062675, 26.58133875578642, 11.775264143943787, 1.5748531627468765, 0.3915290907025337, 0.6325952208135277, 1.8311963137239218, 7.477868115529418, 19.194772616028786, 16.685172580182552, 29.68511290848255, 38.246498107910156, 45.66766329109669, 23.142842464149, 9.244846925139427, 2.0549185713753104, 8.235182203352451, 4.570579994469881, 5.499214539304376, 13.359336443245411, 23.948119953274727, 27.369277775287628, 25.72730988264084, 19.141398780047894, 13.459230232983828, 20.058475770056248, 18.51647861301899, 19.575134105980396, 31.456555053591728, 21.254946067929268, 24.826663210988045, 38.846048936247826, 23.008244186639786, 14.520643427968025, 7.783907493576407, 3.0158197972923517, 0.9136063512414694, 0.07101265277015045, 14.177518039941788, 63.07568818330765, 72.31876820325851, 67.18282699584961, 24.778130315244198, 43.87267380952835, 22.14562777429819, 54.44248303771019, 52.66619615256786, 20.540383011102676, 24.397956915199757, 30.33920980989933, 1.058256751857698, 0.10082206063088961, 0.017948715394595638, 0.04980890364095103, 0.08124177067657001, 0.06789039296563715, 0.01788251582183875, 0.04973952396539971, 0.0454195083148079, 0.03177479673468042, 0.03503560437820852, 0.055128621897893026, 0.1132749424141366, 0.01413903202774236, 0.048587625424261205, 0.016297832007694524, 0.03098495308222482, 0.045337909177760594, 0.04837987231439911, 0.04106225540454034, 0.06517554997117259, 0.014070311008254066, 0.07211754738818854, 0.026944907076540403, 0.04338377868407406, 0.08121013292111456, 0.030609806708525866, 0.08168586442479864, 0.05011891356843989, 0.03782908162975218, 0.024157320622180123, 0.06342330962070264, 0.18683361442526802, 0.026985255790350493, 0.12921372894197702, 0.012969028794032056, 0.18009273160714656, 0.045998053246876225, 0.04101317717868369, 0.10651446689735167, 0.04619447747245431, 0.04792777821421623, 0.06575992447324097, 0.04784572636708617, 0.0898227418656461, 0.06998453332926147, 0.14102873479714617, 0.1387726207030937, 2.328257141634822, 68.72603058815002, 81.12460568547249, 41.814658641815186, 73.51077944040298, 61.454710364341736, 40.156165435910225, 30.265552662312984, 30.531390197575092, 59.62420038878918, 82.81210273504257, 74.29402381181717, 75.32134428620338, 61.349911987781525, 1.5994832036085427, 0.01478761250837124, 3.3656912483274937, 5.998355755582452, 11.703548692166805, 17.15985830873251, 19.239089637994766, 24.45466887205839, 28.41077148914337, 26.899809166789055, 18.19038201123476, 18.155716471374035, 11.825214363634586, 12.323741912841797, 40.90110406279564, 47.02951021492481, 39.99264121055603, 28.5094540938735, 20.397389084100723, 14.142534267157316, 8.74956725165248, 12.747467625886202, 18.908693566918373, 38.650636821985245, 47.15421572327614, 37.5726992636919, 34.04604010283947, 24.251748360693455, 24.695710837841034, 15.461583137512207, 2.7591647068038583, 2.0161718130111694, 2.9356345999985933, 1.2976430752314627, 13.453505840152502, 39.98554319143295, 55.54934844374657, 65.32781973481178, 61.28433510661125, 55.71422539651394, 53.02105151116848, 52.44930379092693, 51.73424296081066, 54.58253212273121, 57.719024419784546, 61.446442008018494, 61.69132746756077, 62.452810406684875, 41.295731887221336, 55.12117221951485, 62.09455423057079, 57.53799453377724, 53.759131506085396, 56.64363272488117, 58.80642727017403, 63.75367060303688, 63.89155000448227, 58.04862253367901, 49.18224669992924, 53.29236835241318, 58.2235499471426, 53.52215342223644, 56.08080692589283, 49.817880392074585, 37.54523813724518, 24.99939054250717, 8.865292891860008, 2.4226322025060654, 0.5435990681871772, 0.5617713555693626, 1.83529854984954, 8.961458131670952, 21.653320491313934, 16.190146543085575, 28.473587818443775, 32.74035416543484, 36.32311351597309, 25.105809532105923, 13.101885057985783, 6.465006340295076, 9.311601743102074, 6.023450084030628, 6.96440689265728, 15.617158189415932, 27.91908547282219, 30.68517554551363, 31.135060004889965, 25.822568871080875, 15.133054666221142, 11.873998045921326, 10.191738065332174, 17.816791757941246, 27.005054019391537, 27.46310044080019, 30.976015739142895, 40.684637278318405, 23.580578975379467, 19.009057581424713, 8.246563542634249, 2.7172493934631348, 2.8612647531554103, 0.03326168218336534, 13.481804821640253, 66.82123079895973, 73.25025781989098, 76.7893423140049, 35.99290743470192, 29.46012318134308, 23.506995923817158, 48.27091120183468, 66.95502921938896, 29.84003819525242, 33.74774090945721, 48.56082044541836, 2.8384163416922092, 0.049351588531862944, 0.04787333797139581, 0.023352242533292156, 0.04995405659428798, 0.022694740509905387, 0.014698925861011958, 0.008094091699604178, 0.0909713638247922, 0.09800594416446984, 0.057503390562487766, 0.07628678460605443, 0.09357317030662671, 0.05338463422958739, 0.0245753093258827, 0.021151585424377117, 0.021225865129963495, 0.044234205706743523, 0.10659067804226652, 0.02331699422938982, 0.05260164616629481, 0.06059340033971239, 0.12763299891958013, 0.18188101064879447, 0.1794780552154407, 0.17541130859171972, 0.21008127165259793, 0.17298865655902773, 0.1256803935393691, 0.1803909710724838, 0.17325764056295156, 0.17558366496814415, 0.22087615099735558, 0.07298699565581046, 0.2717607346130535, 0.11474884769995697, 0.18022413627477363, 0.14113683602772653, 0.12351962315733545, 0.17063474224414676, 0.16016771405702457, 0.15343162551289424, 0.19723404227988794, 0.20820093661313877, 0.25329298339784145, 0.2893617463996634, 0.33410066447686404, 0.3664835065137595, 3.312472254037857, 89.58087712526321, 96.40314504504204, 57.79336743056774, 86.85983553528786, 91.92791238427162, 64.85652342438698, 55.142086297273636, 42.13147044181824, 51.17360584437847, 86.69636070728302, 80.71027591824532, 83.87780115008354, 73.34788978099823, 4.176436644047499, 0.29165931686293334, 8.304348941892385, 7.791816769167781, 16.00221622735262, 21.273395977914333, 20.61908058822155, 31.35089412331581, 38.75610776245594, 37.126310616731644, 29.403774105012417, 25.73768712580204, 18.12453344464302, 28.56001228094101, 60.20309932529926, 54.60615925490856, 44.89641487598419, 39.527922347187996, 30.872754380106926, 25.695592984557152, 20.202930718660355, 24.059062600135803, 29.131906293332577, 51.6387464851141, 71.20000183582306, 51.729633808135986, 49.7730427980423, 34.258399307727814, 34.478498697280884, 37.93961517512798, 13.598722647875547, 5.391467520967126, 3.8603731663897634, 1.4301847130991518, 13.499319981783628, 43.79494518041611, 57.492191791534424, 67.88499891757965, 64.18029651045799, 58.99678185582161, 53.050374537706375, 55.49731403589249, 55.39150111377239, 58.66535224020481, 59.043796733021736, 65.6160494685173, 65.20450875163078, 62.47515320777893, 43.903832137584686, 53.45238916575909, 62.82158441841602, 55.45806594192982, 54.08506661653519, 54.57158111035824, 57.48938374221325, 63.98942515254021, 60.67998133599758, 55.15493720769882, 48.53346951305866, 54.937524273991585, 57.56966583430767, 56.49900868535042, 64.49807345867157, 62.175470888614655, 51.934784799814224, 36.97253666818142, 15.38227379322052, 2.800115584395826, 0.952629188541323, 1.0982504370622337, 2.851980901323259, 15.99130131304264, 31.560300886631012, 25.671952553093433, 40.571289360523224, 49.33024875819683, 56.7225506901741, 31.714067235589027, 20.027345940470695, 13.921426981687546, 18.940750546753407, 15.485416408628225, 15.81388408318162, 24.216915629804134, 34.958409145474434, 39.059133902192116, 37.67848938703537, 33.752319663763046, 27.159973606467247, 34.273955672979355, 31.04754500091076, 30.50749707967043, 45.114416778087616, 33.6937952041626, 35.11438697576523, 48.47952760756016, 30.302064903080463, 19.00922667235136, 11.321859173476696, 5.147773772478104, 2.5318162562325597, 0.16524200036656111, 17.67799660563469, 72.84943252801895, 80.11894404888153, 80.01717790961266, 33.04328911006451, 53.41083839535713, 37.25797735154629, 67.51650989055634, 85.1870208978653, 37.6308361440897, 49.583246782422066, 67.34265401959419, 5.385597310960293, 0.2131602048757486, 0.13360518001718447, 0.18092128011630848, 0.29432220209855586, 0.15541154192760587, 0.19397893804125488, 0.13280290353577584, 0.2849301748210564, 0.1772538386285305, 0.2712935081217438, 0.3007621440337971, 0.16531936184037477, 0.1767378975637257, 0.14744172192877159, 0.10518757364479825, 0.25566295778844506, 0.1628080676891841, 0.1641305154771544, 0.06869438380817883, 0.10563953415839933, 0.1406831166241318], [0.04325390655139927, 0.07069326209602877, 0.04746121594507713, 0.022444451205956284, 0.025558560373610817, 0.04488299120566808, 0.03582759098208044, 0.055535515493829735, 0.05089323705760762, 0.036181613977532834, 0.09746790936333127, 0.061598865722771734, 0.12330716112046503, 0.04504932134295814, 0.09033738417201675, 0.059009913238696754, 0.027644435067486484, 0.09754818747751415, 0.039125376133597456, 0.006572597585545736, 0.039931430146680214, 0.03667388795292936, 0.07435341569362208, 0.18092122074449435, 0.009503933870291803, 0.2016648420249112, 0.1276797245373018, 6.498795552179217, 65.95780313014984, 45.800747349858284, 46.26342572271824, 72.58382678031921, 56.280752196908, 46.15725561976433, 37.22621105611324, 30.4302529245615, 61.908216029405594, 60.83605036139488, 82.82638996839523, 31.415496356785297, 0.049064143604482524, 0.09691191458841786, 1.1164394672960043, 4.294470185413957, 11.282620579004288, 17.67175354063511, 21.777625121176243, 25.365808680653572, 25.361199527978897, 36.388956382870674, 17.74800404906273, 14.919080547988415, 10.706911571323872, 23.44511814415455, 41.01381741464138, 39.216855838894844, 27.47083492577076, 19.69838999211788, 8.732779752463102, 7.974401246756315, 3.520319676026702, 9.670067857950926, 15.994831323623657, 40.599229261279106, 62.08780199289322, 49.872118681669235, 31.112394221127033, 24.57467593252659, 27.917195074260235, 24.91018082946539, 4.613887695595622, 1.6158757614903152, 3.799095517024398, 1.6779216821305454, 2.0829373179003596, 11.131721176207066, 41.474626287817955, 57.30103924870491, 57.24104046821594, 55.9114234149456, 54.50622841715813, 50.62314458191395, 50.27784951031208, 53.28195311129093, 57.746918722987175, 57.26872578263283, 56.63654610514641, 64.4005934894085, 29.556856490671635, 38.23496572673321, 64.03370797634125, 53.61723572015762, 54.031280502676964, 49.81632247567177, 54.21347692608833, 58.14691185951233, 58.3590354770422, 53.74826028943062, 45.699011608958244, 50.04245974123478, 49.18807178735733, 50.5659082531929, 50.755130499601364, 50.72210267186165, 48.621016815304756, 30.07286500185728, 10.290192682296038, 0.9890086145605892, 1.1082302452996373, 0.5041033937595785, 2.1214698627591133, 10.265415161848068, 18.56701210141182, 16.14092778414488, 31.328817307949066, 40.881953090429306, 43.931753039360046, 26.2968822196126, 13.875916823744774, 5.858933161944151, 2.753465725108981, 1.8108545802533627, 3.76848507206887, 8.185655660927296, 19.377734698355198, 24.453067258000374, 32.24607668817043, 20.284166559576988, 9.403467513620853, 12.650684919208288, 19.51084155589342, 33.99055168032646, 29.82809353619814, 17.67326395958662, 31.36800840497017, 29.43044677376747, 26.072819642722607, 8.164486046880484, 3.5526492912322283, 2.1166607458144426, 1.8350102403201163, 0.12892273283796385, 6.210266584530473, 50.203506499528885, 84.92407500743866, 46.913601234555244, 23.516227528452873, 30.133640840649605, 42.84979909658432, 58.66848327219486, 33.60145255923271, 15.03468269482255, 29.98716440051794, 8.249627128243446, 0.16145427158335224, 0.12911984726088122, 0.009182653502648463, 0.10386101435869932, 0.0281031379927299, 0.08697784491232596, 0.04068004935106728, 0.023230656479427125, 0.08555681764846668, 0.005873044547115569, 0.014278908311098348, 0.029990916773385834, 0.02655332955328049, 0.04596397753630299, 0.01700078686553752, 0.042223334312438965, 0.05709032600861974, 0.043798850747407414, 0.04120487021282315, 0.052091070829192176, 0.05754827565397136, 0.05392525912611745, 0.11030849651433527, 0.047812634002184495, 0.06296574589214288, 0.01933346276928205, 0.01776708959368989, 0.11312336617265828, 0.04820189788006246, 0.0931383014540188, 0.07017209631158039, 0.11505270522320643, 0.054963460643193685, 0.021290240874805022, 0.13518442574422807, 0.10466638559591956, 0.13687980273971334, 0.05247011533356272, 0.03347239275171887, 0.044483255624072626, 0.01620571107196156, 0.034995298337889835, 0.05642830430588219, 0.03354221771587618, 0.07005983905401081, 0.1156908631674014, 0.08654423028929159, 0.30857016099616885, 0.17635018477449194, 10.850350074470043, 89.82030227780342, 51.15199640393257, 59.49037156999111, 66.6139443218708, 51.03138327598572, 37.272819355130196, 27.665230594575405, 50.14222338795662, 72.45572805404663, 69.25449103116989, 87.73091599345207, 33.264897018671036, 0.18371286860201508, 0.6215248117223382, 1.1532438173890114, 6.701600169762969, 12.608405537903309, 20.801404304802418, 24.125606529414654, 29.264929555356503, 30.31806204468012, 33.78711819648743, 20.59784922748804, 15.100757349282503, 8.472831901162863, 26.150082796812057, 46.53380401432514, 49.467482194304466, 35.16965501010418, 22.34500877559185, 13.99190180003643, 10.605870243161917, 7.7743548061698675, 13.823648728430271, 20.354643277823925, 33.40128690004349, 50.50752058625221, 42.19464585185051, 32.419339790940285, 29.422923177480698, 28.562651239335537, 12.238885816186666, 2.2470975341275334, 2.8702187351882458, 3.927358346991241, 3.8407899672165513, 0.6076695676892996, 15.94688169658184, 46.500491201877594, 60.70472560822964, 60.73331907391548, 60.677161887288094, 55.79243279993534, 52.05686844885349, 53.1239727884531, 57.322242110967636, 61.05865761637688, 62.25472703576088, 59.00248534977436, 70.8388464152813, 33.78026716411114, 44.81595039367676, 67.63197049498558, 57.8729959577322, 55.35248480737209, 53.12016539275646, 58.40597815811634, 61.84724070131779, 62.978212013840675, 57.269983515143394, 50.241014286875725, 53.77272717654705, 56.90945126116276, 57.185004875063896, 57.525816187262535, 57.14988335967064, 52.53020524978638, 32.52790756523609, 14.494081903249025, 2.022749735042453, 1.3969686767086387, 0.11184866816620342, 1.8708266434259713, 15.331685207784176, 21.02544028311968, 16.105682775378227, 30.1714089140296, 31.193896047770977, 34.481698125600815, 27.312372028827667, 18.039146326482296, 7.29659884236753, 6.282455110922456, 4.707285258919001, 5.021958248689771, 12.279070559889078, 23.5925255343318, 28.06783989071846, 34.607452377676964, 28.199157044291496, 14.362302124500275, 14.38121085986495, 16.75017759203911, 22.746624425053596, 24.663290977478027, 23.55227429419756, 32.923629730939865, 30.79658556729555, 20.715737901628017, 9.627691581845284, 4.837269634008408, 4.481065822765231, 2.499397345818579, 0.10112894611665979, 4.42620056681335, 50.650126934051514, 82.12684750556946, 67.13469877839088, 26.644502766430378, 22.98395399004221, 34.395936727523804, 60.68833328783512, 48.235295712947845, 25.80114372074604, 43.34769397974014, 21.874005049467087, 0.45994510233867913, 0.18811834626831114, 0.11135937762446702, 0.16214063944062218, 0.003449520027061226, 0.043783829678432085, 0.07336733149713837, 0.10684331995435059, 0.04287948933779262, 0.036756355402758345, 0.10184191254666075, 0.05306303566612769, 0.049797559913713485, 0.031771163921803236, 0.10156898031709716, 0.038927222703932784, 0.07763810193864629, 0.05958611669484526, 0.05155672821274493, 0.06904746798682027, 0.02095992207614472, 0.07223793858429417, 0.1519989687949419, 0.16748294496210292, 0.12829965533455834, 0.0898967488319613, 0.1114775869064033, 0.2058923675213009, 0.13570186594733968, 0.19772228639340028, 0.1729095881455578, 0.21264653478283435, 0.14233488502213731, 0.13343261583941057, 0.20431411627214402, 0.17149135877843946, 0.2140176823013462, 0.15892084658844396, 0.1037526830623392, 0.1912161151994951, 0.2938009472563863, 0.13355986448004842, 0.16981259104795754, 0.18765552813420072, 0.1556164340581745, 0.44236878922674805, 0.09855432450422086, 0.8568965911399573, 0.4559467372018844, 20.666393749415874, 115.63404232263565, 71.89670205116272, 71.6403678059578, 91.89974829554558, 79.05798017978668, 62.385253831744194, 46.43771097064018, 41.330047845840454, 76.08620524406433, 77.8408294916153, 96.26575961709023, 39.02554750442505, 0.22768183815060183, 0.991744170896709, 7.155150957405567, 9.935702104121447, 15.615918505936861, 23.294072449207306, 31.920016184449196, 35.1144477725029, 35.245164558291435, 51.07628546655178, 31.249857544898987, 22.181271761655807, 23.967308923602104, 40.23713909089565, 59.30838033556938, 55.89449152350426, 42.536851689219475, 32.98588939011097, 23.535705283284187, 23.370005674660206, 18.629212863743305, 22.62263137847185, 27.834042236208916, 48.60019013285637, 68.5726860165596, 61.578895300626755, 44.39182475209236, 38.07222805917263, 41.17786601185799, 41.66037552058697, 11.41703076660633, 4.864406827837229, 5.195159604772925, 3.9508586609736085, 1.4216128480620682, 18.37647132575512, 47.47271083295345, 63.27388174831867, 64.26737263798714, 61.49063363671303, 56.56895913183689, 56.02488152682781, 57.587566673755646, 58.51831533014774, 61.390831992030144, 63.22237931191921, 59.44425344467163, 71.43042147159576, 35.47865442931652, 45.58428056538105, 66.1924709379673, 58.41602861881256, 56.33565545082092, 53.24723817408085, 57.136709466576576, 61.21950298547745, 60.671211406588554, 55.32962143421173, 50.414687767624855, 55.04448473453522, 55.50659313797951, 58.95308420062065, 65.03452107310295, 67.00238987803459, 60.39206698536873, 38.625048995018005, 19.435569494962692, 1.7578847100958228, 2.7599089918658137, 0.5926728411577642, 2.07622236572206, 18.157922253012657, 27.085849083960056, 23.04682731628418, 40.25348201394081, 48.7988206744194, 53.3445243537426, 35.49633488059044, 25.873393043875694, 18.48120130598545, 14.859352502971888, 14.000173956155777, 13.370691183954477, 21.248547211289406, 32.882116958498955, 38.623274490237236, 43.956482112407684, 34.94507186114788, 22.075453139841557, 26.790726520121098, 36.5536205470562, 49.691122993826866, 46.04008890688419, 27.069701850414276, 39.158160388469696, 35.48425532877445, 31.540477350354195, 11.50756660848856, 5.174122508615255, 5.249285325407982, 5.435167076066136, 0.2816155651817098, 7.213716264814138, 61.52531437575817, 98.83307665586472, 60.299401357769966, 27.6516767218709, 41.12005591392517, 61.368743777275085, 78.11316847801208, 61.526108533144, 32.503102496266365, 67.99991235136986, 28.457852862775326, 0.4466239077737555, 0.3316572174662724, 0.14483835693681613, 0.29428123554680496, 0.175737734825816, 0.13330006826436147, 0.23581626650411636, 0.18826422281563282, 0.14749895635759458, 0.17610281211091205, 0.17565618763910607, 0.12369800577289425, 0.14350955636473373, 0.10866541124414653, 0.24638704693643376, 0.11716740307747386, 0.17740232753567398, 0.11783958849264309, 0.22315562790026888, 0.20923186879372224, 0.13890690490370616, 0.08591662568505853], [0.09761265784618445, 0.06610692304093391, 0.07955201173899695, 0.01169000870504533, 0.02285484402818838, 0.01827024530939525, 0.08453675050986931, 0.024011937603063416, 0.10312826227163896, 0.0449725981161464, 0.0397181257721968, 0.08607447307440452, 0.06969471724005416, 0.06260814945562743, 0.044750855522579513, 0.046386393150896765, 0.04965893043845426, 0.007595237193527282, 0.024824279462336563, 0.1080998798715882, 0.047453315783059224, 0.013110956188029377, 0.005187543611100409, 0.11472918078652583, 0.07558892830274999, 0.08402948515140451, 0.20694546023150906, 0.17530956014525145, 18.7150027602911, 52.19969518482685, 42.26672038435936, 72.57074028253555, 71.81980177760124, 44.61158215999603, 53.74486327171326, 25.94455372542143, 58.21031145751476, 70.09705021977425, 81.05295673012733, 8.739407546818256, 0.20906727528199553, 0.13071703811874613, 1.280399956740439, 4.949899865314364, 7.1414232440292835, 22.81250908970833, 29.84944649040699, 27.828067056834698, 28.112077116966248, 26.288490369915962, 15.97924456000328, 18.15083183348179, 15.340886414051056, 28.11869066208601, 40.15387795865536, 38.03896464407444, 28.25140804052353, 12.470995411276817, 7.874129377305508, 4.404693720862269, 0.7620907877571881, 8.039702642709017, 12.908077407628298, 42.25086763501167, 64.6805852651596, 50.19320905208588, 29.45487756282091, 26.592532955110073, 28.259784691035748, 18.62477470189333, 1.8566726404242218, 2.548334919847548, 6.3191853649914265, 1.0207838751375675, 1.3354240916669369, 2.7861401718109846, 16.40681281685829, 41.69411391019821, 57.54613369703293, 61.266571059823036, 61.01699285209179, 54.303372502326965, 52.91469521820545, 52.814942970871925, 59.22981955111027, 58.15801486372948, 56.64984539151192, 65.8134412765503, 34.65586178004742, 23.57071090489626, 65.5187214910984, 54.22458752989769, 58.423491418361664, 49.55320939421654, 51.52247652411461, 53.810778334736824, 55.18487960100174, 53.85231010615826, 46.876823008060455, 52.17868611216545, 56.29407428205013, 58.92702139914036, 59.696590304374695, 60.91109253466129, 53.92204016447067, 23.145756907761097, 6.772115360945463, 0.3368407330708578, 0.33883687283378094, 0.23414303519530222, 2.5049260491505265, 16.99298456311226, 17.13866114616394, 18.24047852307558, 30.821825712919235, 43.56823414564133, 38.392737060785294, 29.77615412324667, 11.708639468997717, 6.391378166154027, 2.025278974324465, 2.067182413302362, 1.6532587492838502, 3.1557164154946804, 12.49369254335761, 16.70773196965456, 27.58678190410137, 28.24689768254757, 13.088022451847792, 10.123196393251419, 9.43486712872982, 22.145975455641747, 37.901928797364235, 32.05175131559372, 35.59321068227291, 33.99773329496384, 23.688751570880413, 10.099308975040913, 1.932277895975858, 1.6343886055983603, 4.602152975276113, 0.08461231598630548, 1.528711763676256, 38.61592188477516, 80.69914251565933, 34.34033811092377, 25.75559936463833, 42.67473869025707, 52.38558501005173, 52.45443731546402, 17.146813608705997, 18.50372649729252, 23.599847741425037, 2.5623585423454642, 0.16254034533631057, 0.0253323982906295, 0.10934961203020066, 0.013110014588164631, 0.041728707728907466, 0.05608762883639429, 0.0486893441848224, 0.07133776540285908, 0.1586199353914708, 0.03535189287504181, 0.03595914407924283, 0.023461855889763683, 0.025658972954261117, 0.054946580494288355, 0.05042144264734816, 0.014746452998224413, 0.07157469604862854, 0.11864286687341519, 0.07622172051924281, 0.034592579322634265, 0.047718188288854435, 0.04102536695427261, 0.07812569296220317, 0.14660262007964775, 0.04470795567613095, 0.006358380833262345, 0.0334211734298151, 0.011756796429835958, 0.09714655199786648, 0.03057358248042874, 0.012657000224862713, 0.06172160952701233, 0.044532196552609093, 0.07599313161335886, 0.04695394687587395, 0.04889435876975767, 0.016421382897533476, 0.02783701867883792, 0.04697620759543497, 0.013231350167188793, 0.03275008639320731, 0.0491197007795563, 0.007336125145229744, 0.027088577589893248, 0.07917753886431456, 0.15876867662882432, 0.08891739591490477, 0.1218814731691964, 0.3905000287340954, 0.9437899722252041, 38.77238228917122, 71.00865170359612, 55.76331876218319, 86.04244619607925, 65.73762774467468, 47.01268471777439, 30.193506628274918, 36.28803379833698, 74.61486339569092, 71.54751598834991, 88.88128906488419, 10.14948908239603, 0.32463204755913466, 1.0754596162587404, 0.7188041636254638, 6.415752908214927, 10.262125488370657, 24.207870215177536, 31.871659979224205, 31.895385906100273, 27.88283921778202, 30.2444713935256, 17.91478469967842, 18.600123524665833, 17.09190845489502, 36.17181323468685, 48.04649904370308, 49.35602657496929, 31.891418918967247, 14.622989986091852, 11.718975864350796, 9.243105668574572, 6.425131279975176, 11.113303564488888, 16.0664289817214, 33.27831789851189, 55.92166766524315, 42.72684909403324, 33.93878325819969, 27.076811268925667, 22.990871518850327, 7.291401196271181, 2.6411596639081836, 4.496801253408194, 9.140886403620243, 0.4965295986039564, 2.478321776725352, 2.9472892871126533, 19.526992589235306, 49.40895773470402, 61.65462903678417, 62.35869325697422, 60.17779268324375, 55.1017514616251, 53.39807488024235, 54.87728230655193, 58.32879289984703, 61.16922028362751, 58.84081922471523, 70.76490238308907, 34.9722746014595, 28.959374651312828, 69.72774043679237, 57.67711266875267, 64.12135407328606, 52.57014490664005, 54.223975762724876, 58.07272844016552, 61.120020523667336, 58.05768124759197, 51.08165457844734, 57.424825206398964, 59.266818165779114, 64.24749210476875, 64.9934908747673, 69.24278765916824, 59.95263196527958, 31.195797845721245, 11.21676156297326, 0.524901874596253, 0.7756691810209304, 0.4979349294444546, 2.937809033319354, 25.33850334584713, 20.272615179419518, 19.013604037463665, 26.83290045708418, 31.01218029856682, 28.127863369882107, 26.235847994685173, 17.793516106903553, 7.954497439786792, 4.8069786094129086, 3.2824355782940984, 5.537104681134224, 6.514380890876055, 15.9923804551363, 19.802909083664417, 30.592312328517437, 30.533132404088974, 19.178283400833607, 14.38214085996151, 13.192656487226486, 23.169355541467667, 41.18730090558529, 30.1409250497818, 33.013145327568054, 30.925626643002033, 19.235040955245495, 6.605255864560604, 2.5415009865537286, 4.718465683981776, 6.057734219357371, 0.18557448667706922, 1.600102570373565, 42.56625831127167, 86.5783466398716, 58.403785675764084, 18.01144201308489, 36.38622432947159, 55.1024354249239, 63.7267604470253, 31.021449901163578, 30.346081741154194, 45.761301666498184, 6.949299853295088, 0.5332044290844351, 0.07934700086480007, 0.11998587957350537, 0.04267156182322651, 0.07237271260237321, 0.0018505832667869981, 0.0991799178882502, 0.046255660126917064, 0.05539753539778758, 0.08777508963248692, 0.09522177715552971, 0.08243287316872738, 0.09108984027989209, 0.06021440407494083, 0.031011605460662395, 0.024526015877199825, 0.04189701568975579, 0.11388716971850954, 0.08740402321564034, 0.03818906036030967, 0.08323817761265673, 0.03954010309826117, 0.20290678163291886, 0.32656908268108964, 0.35966827534139156, 0.1332504631136544, 0.1644407628918998, 0.18097055872203782, 0.19386837288038805, 0.07442797184921801, 0.18722548324149102, 0.11143482435727492, 0.10296076696249656, 0.1289490790804848, 0.21974933333694935, 0.16407288028858602, 0.11855475910124369, 0.12022753769997507, 0.27152333641424775, 0.12463246617699042, 0.22732251993147656, 0.22199170285603032, 0.14438064477872103, 0.08490846259519458, 0.1686957330093719, 0.28027334657963365, 0.25929580035153776, 0.2985926088877022, 0.5255575769115239, 1.6007517417892814, 62.57332094013691, 93.26294034719467, 68.27935695648193, 100.05731016397476, 96.15393921732903, 67.12386935949326, 69.26886186003685, 31.638458892703056, 74.89882975816727, 81.5217299759388, 94.97468769550323, 12.753908280283213, 0.24789967748802155, 2.75523001793772, 5.414908463135362, 8.652378916740417, 13.718566317111254, 32.43774600327015, 37.94034853577614, 37.565122470259666, 36.45813167095184, 39.610028341412544, 29.31430220603943, 36.755032539367676, 35.54110407829285, 46.18340961635113, 59.885766953229904, 53.04752089083195, 43.77554342150688, 22.498948015272617, 23.766738586127758, 20.56682389229536, 17.656368166208267, 19.183365628123283, 22.968669310212135, 47.74058885872364, 70.32969653606415, 58.305386155843735, 44.79076914489269, 36.41582474112511, 42.87200130522251, 36.77299037575722, 10.063819829374552, 5.587821984663606, 9.346698559820652, 1.0535917896777391, 4.863287312909961, 5.248762853443623, 19.794160053133965, 51.39225371181965, 64.09795492887497, 64.8115262389183, 62.12201915681362, 58.34591098129749, 54.589679539203644, 54.84430007636547, 57.85673663020134, 63.46365496516228, 59.78108637034893, 68.2106414437294, 37.15298518538475, 30.755042396485806, 68.50754231214523, 58.5175933688879, 62.60220319032669, 53.568659126758575, 54.94306057691574, 56.62023738026619, 59.96766395866871, 55.608480870723724, 50.403668358922005, 55.01287043094635, 60.57036101818085, 67.14752689003944, 66.57205536961555, 70.15538468956947, 59.12581533193588, 31.678176261484623, 13.507391698658466, 0.32793597027193755, 0.6901940144598484, 0.3571529290638864, 4.73260092549026, 25.733256563544273, 26.454528160393238, 27.50686079263687, 37.59029231965542, 51.89393699169159, 46.158737540245056, 35.7549262046814, 25.16832947731018, 19.006407223641872, 14.600116163492203, 12.73641211912036, 14.97603664174676, 16.026761010289192, 25.60751561075449, 29.782754369080067, 42.371317371726036, 42.49731861054897, 28.01379919052124, 24.008213728666306, 22.900470569729805, 37.720743119716644, 53.86527881026268, 46.2909210473299, 42.63813905417919, 45.16533404588699, 30.399789959192276, 13.628820832818747, 3.4011865686625242, 6.047506118193269, 7.775843376293778, 0.20948462944943458, 2.701845970004797, 51.1985819041729, 96.19734048843384, 48.809190317988396, 31.91288396716118, 61.54748238623142, 70.85734382271767, 82.21172735095024, 40.437722727656364, 44.46808286011219, 67.63384759426117, 10.560823660343885, 0.5960511567536741, 0.19484693912090734, 0.24062461161520332, 0.20382462535053492, 0.16930392303038388, 0.12144860069383867, 0.12092848875909112, 0.1883927479502745, 0.37764413107652217, 0.35732798685785383, 0.21972034504869953, 0.1569274379289709, 0.16299102193443105, 0.16020266921259463, 0.1337686157785356, 0.09214144127327017, 0.13881431455956772, 0.2838851121487096, 0.1370649685850367, 0.15742501826025546, 0.17046888708136976, 0.12007937533780932], [0.05789884024125058, 0.06206624806509353, 0.07721314075752161, 0.056744611356407404, 0.06641886255238205, 0.037047511068522, 0.005074807668279391, 0.05382646071666386, 0.07952096028020605, 0.04271046149369795, 0.08671014482388273, 0.1299274226767011, 0.03350741470057983, 0.0936071680916939, 0.024361721079912968, 0.02604559478641022, 0.06493904234957881, 0.08327195275342092, 0.03212239644199144, 0.025126361397269648, 0.0706974849163089, 0.01202742521854816, 0.06395962263923138, 0.05015874092350714, 0.009037864201673074, 0.06805697543313727, 0.44343700690660626, 0.32227059302385896, 0.8541005942970514, 38.42427156865597, 39.45941582322121, 32.09447242319584, 80.77193140983582, 57.730685994029045, 48.44257839024067, 40.53688980638981, 30.612453147768974, 69.7765602171421, 63.06096397340298, 1.6149875591509044, 0.414931945852004, 1.3247813377529383, 0.7822577899787575, 7.0608803909271955, 10.244597978889942, 25.063080824911594, 30.18303819000721, 28.548498898744583, 30.0262339040637, 28.844221830368042, 25.81127017736435, 9.569122474640608, 9.140914902091026, 33.52319575846195, 42.62722223997116, 35.262932404875755, 19.344416186213493, 4.845355125144124, 3.8732100650668144, 2.44679463095963, 0.705077697057277, 5.903780730441213, 11.146516632288694, 36.78291544318199, 58.52840378880501, 43.44246469438076, 24.866201989352703, 32.13855005800724, 37.74370528757572, 8.994483109563589, 1.6104059549979866, 1.2842206517234445, 4.0689945593476295, 0.6386013922747225, 1.3494481891393661, 0.6769654992967844, 2.534663015976548, 19.57540199160576, 42.57524862885475, 56.14228002727032, 64.29927572607994, 58.45205448567867, 54.12278339266777, 54.20383684337139, 54.7921858727932, 56.35583616793156, 56.6471703350544, 61.21806666254997, 32.34518676996231, 13.061756361275911, 61.812860146164894, 52.5154734402895, 57.53275841474533, 53.12053397297859, 52.899914011359215, 52.1011246740818, 53.203639313578606, 50.41235089302063, 50.21041452884674, 59.18936312198639, 61.64457477629185, 65.77178031206131, 63.595359697937965, 68.2636334002018, 42.505989745259285, 18.227232433855534, 3.360441830009222, 1.4408490783534944, 1.4121523057110608, 0.25518364913295954, 1.7676044697873294, 12.90907010436058, 16.57547626644373, 17.49138291925192, 31.814427450299263, 39.592655673623085, 33.99529002606869, 23.388408087193966, 13.543960936367512, 5.6134843826293945, 1.7337932903319597, 0.9787763573694974, 1.801118552684784, 0.6934382091276348, 6.230089645832777, 8.45906239002943, 19.485248029232025, 29.686264246702194, 14.949545413255692, 13.305879011750221, 14.3791095726192, 11.897662226110697, 21.89416866749525, 43.31080935895443, 36.84519790112972, 29.844637848436832, 21.196119524538517, 7.420723931863904, 1.8203501519747078, 5.165695510804653, 3.7012754660099745, 0.1938537525711581, 0.21312723867595196, 29.45865835994482, 71.06330797076225, 22.16595098376274, 43.94429236650467, 44.51172731816769, 49.35887262225151, 33.63233730196953, 14.357549529522657, 30.03012679517269, 12.314350716769695, 1.1993972095660865, 0.31497827963903546, 0.17465390235884115, 0.1230241208395455, 0.0564019877492683, 0.05235656302829739, 0.15278459148248658, 0.04895288453553803, 0.03902625488990452, 0.03197931779141072, 0.01706809223833261, 0.0820864163688384, 0.05491920266649686, 0.06563994887983426, 0.03824199033260811, 0.006526808465423528, 0.025562022492522374, 0.04983747632650193, 0.04610164221958257, 0.029141656777937897, 0.03010221666045254, 0.09273495903471485, 0.02355341835936997, 0.01415840393747203, 0.041131475518341176, 0.040591217984911054, 0.020114229955652263, 0.04907022921543103, 0.009650918073020875, 0.07348642393480986, 0.07628060993738472, 0.044492458255263045, 0.03315048248623498, 0.043671527892001905, 0.0047543636082991725, 0.10297748754965141, 0.03371747960045468, 0.07137974127545021, 0.043547533568926156, 0.04494148357480299, 0.01809207420592429, 0.09113868843996897, 0.08525553537765518, 0.06942968146177009, 0.08005273135495372, 0.04470279032830149, 0.09693295447505079, 0.04228159290505573, 0.005393940446083434, 0.4283158964244649, 0.17599825834622607, 11.223361808806658, 76.20317816734314, 48.709742054343224, 52.877472415566444, 84.44729939103127, 57.14536540210247, 34.081818982958794, 30.373915247619152, 53.54903317987919, 71.1005687713623, 72.98956900835037, 0.8761923713609576, 0.3425004403106868, 1.7329899896867573, 1.3141149538569152, 7.0385390147566795, 12.009396180510521, 25.94378426671028, 32.79632896184921, 32.64320857822895, 27.262936681509018, 32.152985483407974, 28.051990941166878, 15.056369081139565, 20.1433727145195, 37.75154046714306, 50.77534161508083, 43.0691347271204, 24.14050552994013, 8.702029902487993, 9.668271504342556, 5.041446927934885, 3.0163099709898233, 9.307081885635853, 12.69660260528326, 30.007962584495544, 52.126484513282776, 38.05324427783489, 27.781774140894413, 25.432593896985054, 29.01533044874668, 6.597784515470266, 2.342345123179257, 4.125498477369547, 4.667002195492387, 2.714508790522814, 2.0168621884658933, 0.18260231881868094, 2.1389460749924183, 20.670147947967052, 46.75607308745384, 59.63225595653057, 63.265419602394104, 59.2114969342947, 54.220107570290565, 58.125496208667755, 59.25722748041153, 62.114423364400864, 60.44639267027378, 68.21370407938957, 38.28851245343685, 16.10683411359787, 68.70400696992874, 60.33800348639488, 65.43565034866333, 57.812408208847046, 58.74384842813015, 57.06919848918915, 58.349478989839554, 54.00353439152241, 53.285703510046005, 64.37716394662857, 65.84619551897049, 70.48321589827538, 69.1183215379715, 69.66776445508003, 52.04521827399731, 28.633344545960426, 7.212997628375888, 0.7399376202374697, 0.9597465035039932, 0.5818130238913, 2.242169911041856, 15.76387021690607, 14.006370473653078, 16.04811206459999, 26.712346225976944, 31.942609772086143, 26.05455782264471, 21.698918044567108, 14.028794970363379, 4.129023738205433, 4.559504063799977, 1.7083681421354413, 2.944523273035884, 3.98842035792768, 10.134228151291609, 12.115293648093939, 24.23287097364664, 30.490002818405628, 21.067397631704807, 18.494464494287968, 21.784497052431107, 20.5106059089303, 34.93482381105423, 45.657301247119904, 36.424423679709435, 24.86361812800169, 15.085942894220352, 4.352553868666291, 3.411767575889826, 5.353969233110547, 5.684356279671192, 0.5061971407849342, 0.48661729611922055, 29.471737258136272, 98.3535347878933, 26.039398536086082, 30.94145469367504, 50.039112120866776, 59.56988610327244, 49.74720038473606, 25.918663814663887, 41.54135450720787, 28.526879958808422, 1.1276779579930007, 0.28050946828443557, 0.1939796208171174, 0.0766685008420609, 0.09634714762796648, 0.033039772606571205, 0.09365868056192994, 0.09397428628290072, 0.025360816980537493, 0.0456375290377764, 0.01102358328353148, 0.04128701853915118, 0.03636688372353092, 0.039977873748284765, 0.05801366532978136, 0.0351880526432069, 0.025311727622465696, 0.06751289212843403, 0.01323702110312297, 0.023737573028483894, 0.09091693471418694, 0.12402518157614395, 0.016671360499458387, 0.15849914343561977, 0.13797559862723574, 0.14718097576405853, 0.11253871707594953, 0.11349530832376331, 0.13866083842003718, 0.17333099443931133, 0.1673886922071688, 0.14822890312643722, 0.13044619874563068, 0.17313005053438246, 0.22502474166685715, 0.20587247796356678, 0.2041053501307033, 0.1710783684393391, 0.10861924223718233, 0.11301114602247253, 0.195920767437201, 0.18262007099110633, 0.26727157237473875, 0.20629513106541708, 0.19173365930328146, 0.18712128570768982, 0.2175485240877606, 0.21377341181505471, 0.1579115109052509, 0.9360597026534379, 0.5579416360706091, 25.78923135995865, 105.95524728298187, 66.79989874362946, 58.181440606713295, 108.2237559556961, 80.71023792028427, 64.39135998487473, 48.62611994147301, 45.54045371711254, 84.16128873825073, 75.0994361937046, 2.30930233374238, 0.6457098014652729, 4.401578838005662, 2.141863605938852, 12.395236976444721, 15.641371440142393, 36.579633951187134, 40.42067304253578, 40.626230612397194, 40.66434256732464, 43.48997354507446, 41.95174388587475, 29.298707842826843, 29.332127049565315, 50.52010931074619, 60.34627564251423, 50.259975269436836, 36.576221734285355, 19.071708619594574, 21.576367020606995, 14.003560524433851, 13.787090890109539, 18.391484320163727, 24.90370597690344, 42.89489887654781, 66.55773773789406, 49.16213057935238, 39.29866544902325, 37.20777444541454, 54.49396647512913, 23.41441959142685, 6.204570215195417, 6.738336598500609, 7.444637473672628, 1.643827180378139, 2.721472391858697, 0.8512946229893714, 1.8611447629518807, 19.877968356013298, 48.2353413105011, 58.64370860159397, 68.33385363221169, 61.9789682328701, 55.023832842707634, 59.00171019136906, 59.692482724785805, 64.62451547384262, 62.48342916369438, 67.89832100272179, 39.28288109600544, 17.921440042555332, 66.12462177872658, 60.24263620376587, 65.36689683794975, 56.761886179447174, 59.100425094366074, 55.60564622282982, 57.797022834420204, 52.14256525039673, 52.651198357343674, 63.02195906639099, 63.10033746063709, 69.10935401916504, 68.03102508187294, 69.11735638976097, 50.59975303709507, 33.2707829028368, 9.09613810479641, 1.2713863654062152, 2.3464439157396555, 0.4554053256288171, 4.098810609430075, 22.902835942804813, 21.06912273913622, 27.657332718372345, 36.8474093824625, 48.88843506574631, 41.888070702552795, 34.865557327866554, 23.814997896552086, 15.895956829190254, 13.89997523277998, 9.994413703680038, 13.423133119940758, 13.067150171846151, 19.467062205076218, 22.25877620279789, 32.96055614948273, 43.85263368487358, 27.077639624476433, 26.99573501944542, 30.808154046535492, 28.73510878533125, 38.479228019714355, 56.08402535319328, 48.481214717030525, 38.955106884241104, 27.083852291107178, 11.724192034453154, 4.164375616237521, 9.873773027211428, 7.127233380451798, 0.7590803399216384, 0.6282094842754304, 36.2121594697237, 92.40961253643036, 25.49696434289217, 54.48437198996544, 67.69060894846916, 73.91639247536659, 66.72278568148613, 32.717088013887405, 63.210197165608406, 41.848598420619965, 1.1348283430561423, 0.3789390600286424, 0.25044595648068935, 0.3006740065757185, 0.2746730705257505, 0.15653999231290072, 0.21940770791843534, 0.14875095948809758, 0.11847160145407543, 0.11493201716803014, 0.23128177388571203, 0.11016757009201683, 0.2046335514751263, 0.10398050013463944, 0.1584576870664023, 0.09956625028280541, 0.12063581540132873, 0.1872884767362848, 0.13844512577634305, 0.06185404949064832, 0.12606276286533102, 0.13969655003165826, 0.18387986667221412], [0.0015818046290405618, 0.023287278636416886, 0.022830223279015627, 0.07262194805662148, 0.005768489390902687, 0.040177162663894705, 0.02052191579423379, 0.039280091659747995, 0.03023712612048257, 0.03997487547167111, 0.09914126683725044, 0.049207674965146, 0.04155801376327872, 0.052640816720668226, 0.02992344627273269, 0.03505777975078672, 0.04099766258150339, 0.04675512922403868, 0.07139995737816207, 0.028970313433092088, 0.056041608258965425, 0.013341016401682282, 0.07702738119405694, 0.0547179470595438, 0.04182142423815094, 0.05385830256273039, 0.10679225277272053, 0.22664136195089668, 1.573129955213517, 30.83058424293995, 44.500115141272545, 35.226556956768036, 65.13023033738136, 74.49907600879669, 42.63161480426788, 52.58377477526665, 27.5854329764843, 65.99137052893639, 45.868406519293785, 0.10436082113301381, 0.01886129171907669, 0.1727098910487257, 0.5407210194971412, 5.105388471856713, 11.574962642043829, 25.111361034214497, 36.120451390743256, 26.443358659744263, 32.53047242760658, 34.16933208703995, 15.56572699919343, 9.43073010072112, 17.189842499792576, 32.98346132040024, 39.341196566820145, 27.39285171031952, 13.355955574661493, 3.1258298316970468, 1.5253304201178253, 3.6824396392330527, 0.24723273905692622, 5.046122577041388, 7.413435922935605, 35.72152219712734, 45.89781314134598, 33.826142102479935, 28.33731573075056, 31.011568531394005, 25.469014942646027, 5.843855096027255, 4.628179203718901, 4.01188837364316, 2.0349387684836984, 0.6868299480993301, 0.27787398314103484, 0.07153336584451608, 0.7755097676999867, 7.218450335785747, 25.50126761198044, 48.6771360039711, 65.13526126742363, 62.85968117415905, 59.71283443272114, 55.376548916101456, 55.882313176989555, 55.75127720832825, 54.77858640253544, 58.71582493185997, 34.779909923672676, 12.048771567642689, 57.16354742646217, 54.280699118971825, 58.40236835181713, 51.29888512194157, 50.7806309312582, 46.12950190901756, 46.05685740709305, 48.66786830127239, 55.49015522003174, 63.12807597219944, 64.25778955221176, 67.47579127550125, 66.13200098276138, 56.697814017534256, 31.838808842003345, 18.553735613822937, 4.918207190930843, 3.645784668624401, 2.3463871562853456, 0.34259668202139437, 1.696118786931038, 8.888165764510632, 20.997747369110584, 18.52611869573593, 25.737316645681858, 30.828068777918816, 34.80894796550274, 23.39031558483839, 13.512822557240725, 8.191184364259243, 3.3744894387200475, 1.9981700414791703, 1.268683997914195, 2.525609051808715, 0.7414096256252378, 7.812350392341614, 12.174238935112953, 15.597269106656313, 9.332194738090038, 10.149302892386913, 13.102428428828716, 10.548699460923672, 18.10668770223856, 29.88641280680895, 31.637881323695183, 28.790226727724075, 14.08274257555604, 3.329629758372903, 0.6755630776751786, 5.805024979636073, 2.838028287515044, 1.105277684982866, 0.04395730298710987, 24.514834843575954, 31.432927921414375, 33.74977000057697, 43.760720416903496, 47.42368206381798, 45.421227514743805, 21.83796588331461, 16.91442757844925, 33.42844024300575, 12.562754787504673, 0.30642900557722896, 0.21805490629049018, 0.11781614404753782, 0.06210411615029443, 0.11041474979720078, 0.02575211434304947, 0.025988069064624142, 0.042261881462763995, 0.07090723811415955, 0.0756171670218464, 0.029051376368443016, 0.038499337460962124, 0.046020926238270476, 0.05447561357868835, 0.030259114100772422, 0.06427906526369043, 0.08713753282791004, 0.018843738071154803, 0.018815152398019563, 0.028004675405099988, 0.14970743941375986, 0.055285504495259374, 0.044771457542083226, 0.019427188599365763, 0.06701500009512529, 0.0431976406252943, 0.04165133512287866, 0.1370045280782506, 0.03255295712733641, 0.05396616630605422, 0.059105093678226694, 0.03981261972512584, 0.029456204938469455, 0.1149893703404814, 0.08344842062797397, 0.062413632549578324, 0.06696530588669702, 0.058145159055129625, 0.02276443559821928, 0.09654621389927343, 0.034617838318808936, 0.07781418389640749, 0.014958108877181076, 0.07231629453599453, 0.012264647157280706, 0.044022893998771906, 0.08297855951241218, 0.03658365392766427, 0.05474345467519015, 0.1449885082547553, 0.38793917396105826, 1.4798410423099995, 45.95270499587059, 62.640854716300964, 48.591036424040794, 81.43760249018669, 78.24507459998131, 40.86374066770077, 30.520213097333908, 37.09187686443329, 75.31776487827301, 46.14022493362427, 0.13528132054489106, 0.04218836431391537, 2.2264967020601034, 1.071624078322202, 7.355029257014394, 10.721911266446114, 23.38295727968216, 35.38143664598465, 32.07818269729614, 31.931172385811806, 34.74560156464577, 24.593973197042942, 15.506353285163641, 23.25229749083519, 38.80164071917534, 48.25046829879284, 29.79275543242693, 17.457122057676315, 6.209666216745973, 5.310562262311578, 5.941354539245367, 1.8163203494623303, 8.078677151352167, 7.5118739157915115, 26.538264267146587, 41.52840480208397, 33.159688264131546, 33.13886158168316, 27.959188520908356, 23.89640662819147, 5.7040648721158504, 1.7455204110592604, 4.04356537386775, 3.2759835245087743, 1.0743547067977488, 0.46175475523341447, 0.08984686908661388, 1.1255613528192043, 8.20943858474493, 27.858212739229202, 48.819411769509315, 63.74385192990303, 63.510096073150635, 60.48510879278183, 57.18874767422676, 58.882248401641846, 59.48882505297661, 57.006631046533585, 64.46230977773666, 38.11930753290653, 15.395049657672644, 64.27494183182716, 57.72275201976299, 65.17798617482185, 55.45811913907528, 55.73930785059929, 49.55071672797203, 51.7902747541666, 50.3670497238636, 59.4329072535038, 68.79858389496803, 70.93748152256012, 71.14055022597313, 70.21051213145256, 65.31259015202522, 37.81485266983509, 23.871844746172428, 2.7347994642332196, 5.429505854845047, 1.5333785070106387, 0.3208190412260592, 1.8829047703184187, 11.322374045848846, 20.038390047848225, 17.229096293449402, 23.268663212656975, 28.179173916578293, 22.418331541121006, 20.33766008913517, 15.326331295073032, 9.14269795641303, 3.6890272982418537, 1.3066477607935667, 2.6681147050112486, 2.633061110973358, 3.9906114153563976, 9.07626612111926, 15.26544051244855, 20.59582583606243, 13.329157512634993, 15.302457176148891, 21.394404284656048, 23.00468947738409, 30.200680643320084, 35.001001060009, 30.207552574574947, 20.606985837221146, 5.756929535418749, 1.7560619954019785, 1.3488425966352224, 7.957661719992757, 6.3329520262777805, 0.8451273757964373, 0.14652836078312248, 29.110640734434128, 51.23971849679947, 18.543683253228664, 44.99631531536579, 57.09922447800636, 58.61546851694584, 40.08494205772877, 25.294600501656532, 53.200888261199, 18.398975618183613, 0.3485165862366557, 0.06350878276862204, 0.07889662112575024, 0.17697018978651613, 0.062223995264503174, 0.13711850711843, 0.062187054863898084, 0.019700747943716124, 0.013447103629005142, 0.02320681684068404, 0.06983222236158326, 0.021774059932795353, 0.045199123851489276, 0.017044228479790036, 0.04670622911362443, 0.15882338775554672, 0.0644945478416048, 0.008024943945201812, 0.07528528600232676, 0.06187694474647287, 0.1495958204031922, 0.07344000259763561, 0.0379858825908741, 0.14984844747232273, 0.2301266061840579, 0.133074737386778, 0.12043896073009819, 0.2583421109011397, 0.13064240774838254, 0.11380227544577792, 0.16884045180631801, 0.2216103725368157, 0.12167235079687089, 0.23967540473677218, 0.17931947309989482, 0.10830129875103012, 0.17177374596940354, 0.14081689616432413, 0.12507163948612288, 0.11139428825117648, 0.14705061010317877, 0.1359760301420465, 0.0801328090892639, 0.2139597650966607, 0.08271815473563038, 0.13838082610163838, 0.22069343423936516, 0.18935350264655426, 0.2084020883194171, 0.1563218899536878, 0.7164205040317029, 3.071509846486151, 65.53296312689781, 89.63918879628181, 70.17483964562416, 96.34191513061523, 102.50731229782104, 61.36725805699825, 63.11610661447048, 35.8700942248106, 85.00762492418289, 53.47171872854233, 0.24628940998809412, 0.268670609802939, 2.379145435988903, 2.351511656306684, 7.750203777104616, 16.90556265413761, 35.319993942976, 48.14775601029396, 37.621701434254646, 43.37069034576416, 49.983065128326416, 32.22774267196655, 29.630829021334648, 36.57920837402344, 52.99296721816063, 58.63145425915718, 45.94498001039028, 28.070606142282486, 17.218304872512817, 16.510326862335205, 16.686831191182137, 15.564978439360857, 20.49295585602522, 22.381370924413204, 41.60593204200268, 53.11814770102501, 42.44468383491039, 44.60767976939678, 36.8499780446291, 45.18467120826244, 14.898211117833853, 8.299619145691395, 11.076263152062893, 5.618690103292465, 2.2995275957509875, 0.9474723308812827, 0.4991079680621624, 0.9059172263368964, 7.787801334634423, 28.573644049465656, 48.19982461631298, 68.23718681931496, 65.3564777970314, 63.34455415606499, 58.3788438141346, 61.47644519805908, 63.36841307580471, 59.353084936738014, 65.28379529714584, 43.70276212692261, 19.114910401403904, 65.98833829164505, 58.524011224508286, 66.46049335598946, 54.97641138732433, 57.965756580233574, 49.841632917523384, 51.40204958617687, 50.308639258146286, 59.516673758625984, 65.81331968307495, 66.9748717546463, 69.19041886925697, 68.18672552704811, 64.1142788529396, 37.55845382809639, 29.768879413604736, 4.59358443506062, 6.940205041319132, 5.053356438875198, 0.2647748094750568, 3.3046432491391897, 19.656706228852272, 30.70811491459608, 28.44526033848524, 32.85709910094738, 40.086636766791344, 43.05869668722153, 33.184512332081795, 23.360857665538788, 20.424171946942806, 14.301683977246284, 10.265132077038288, 14.191507939249277, 13.879576977342367, 11.353033650666475, 19.83457088470459, 28.65062601864338, 28.34967076778412, 26.032667197287083, 25.250154286623, 27.72763654589653, 27.59639348834753, 35.356342792510986, 39.276497438549995, 42.60476924479008, 38.21778304874897, 19.328897818922997, 4.519074708223343, 2.391259898431599, 11.701610796153545, 8.326598647981882, 2.599796033464372, 0.14090015029069036, 33.6832469701767, 48.11003163456917, 41.63352236151695, 67.30298414826393, 70.86472302675247, 83.39202761650085, 48.63489747047424, 42.35815867781639, 69.88796263933182, 22.349483035504818, 0.3558869438711554, 0.3750963677885011, 0.18762254709145054, 0.4741893504979089, 0.5271144839935005, 0.17486280208686367, 0.22678634792100638, 0.07882176068960689, 0.18869600433390588, 0.17856509482953697, 0.1487778697628528, 0.10387239890405908, 0.332607968011871, 0.16722224332625046, 0.1026906177867204, 0.231116586655844, 0.23083036998286843, 0.09185156581224874, 0.18574090587208048, 0.18504935782402754, 0.20276230032322928, 0.19931110582547262, 0.1419819047441706], [0.054691600817022845, 0.04439730379090179, 0.02590101328678429, 0.07324328893446364, 0.03552900641807355, 0.05370395811041817, 0.04211971565382555, 0.025592066485842224, 0.06013449703459628, 0.042395712953293696, 0.08131447146297432, 0.02330729621462524, 0.09107694175327197, 0.07489071576856077, 0.06154575392429251, 0.03048447095352458, 0.02638832786033163, 0.032997139933286235, 0.08499504896462895, 0.0827991304686293, 0.0269004004803719, 0.12004968200926669, 0.025182838835462462, 0.08962021718616597, 0.09830085880821571, 0.10129901667824015, 0.23271627112990245, 0.3791224892484024, 1.1109795165248215, 6.082981964573264, 27.007590383291245, 49.61633920669556, 33.45027767121792, 78.77819359302521, 61.708954721689224, 52.69624873995781, 35.7542460411787, 59.89600360393524, 36.61665536463261, 0.16416463942732662, 0.7744465372525156, 0.9938083507586271, 0.7627295691054314, 2.234934149309993, 10.45365896075964, 30.510080941021442, 37.924465388059616, 29.19074233621359, 34.076161086559296, 27.547919489443302, 20.60337793081999, 15.461625885218382, 11.919306814670563, 21.07135321944952, 30.848749168217182, 25.887695476412773, 15.78976297751069, 1.7184642003849149, 2.3029189137741923, 3.152402280829847, 2.8067752020433545, 5.68742461502552, 9.771638307720423, 28.94512541592121, 24.840055592358112, 21.33568223565817, 31.73633974045515, 27.969632260501385, 26.172469295561314, 8.852478079497814, 4.719691593199968, 7.186023350805044, 2.43711203802377, 1.2771459063515067, 0.371512031997554, 0.35511288384441286, 0.10663405657396652, 1.700648262631148, 12.533910535275936, 36.427588909864426, 56.65391877293587, 61.607640758156776, 59.78105217218399, 57.24029190838337, 58.35239723324776, 55.91037467122078, 55.00539243221283, 56.315831914544106, 30.1268620043993, 15.561141595244408, 55.76430290937424, 51.26016899943352, 56.75924152135849, 51.319628208875656, 47.371370270848274, 43.02545987069607, 45.43060161173344, 53.405978456139565, 56.30172707140446, 62.49430038034916, 59.31904636323452, 63.723618015646935, 58.34326632320881, 44.584907591342926, 34.376120790839195, 16.35646741837263, 8.352181725203991, 9.042956158518791, 4.297453025355935, 1.114076825324446, 1.4251496270298958, 11.398153379559517, 17.173469178378582, 23.641882985830307, 24.47281289845705, 22.228774912655354, 30.32674267888069, 21.23184710741043, 13.61427616328001, 9.505542386323214, 8.056741878390312, 2.178103686310351, 3.2066415203735232, 2.083479738794267, 2.170242858119309, 4.668555362150073, 8.50112708285451, 8.3920862339437, 7.154896846041083, 12.287387363612652, 18.316991217434406, 11.468539852648973, 17.617178969085217, 27.913085594773293, 32.585561871528625, 23.628659695386887, 10.963176470249891, 1.4487431547604501, 2.980553889647126, 4.306017765775323, 3.787087923847139, 0.49908920656889677, 0.11679739793180488, 8.970231860876083, 33.05943824350834, 53.04813265800476, 46.94609709084034, 47.673552855849266, 33.467433750629425, 13.993644006550312, 35.0073467195034, 30.471058934926987, 1.5357778407633305, 0.3294813592219725, 0.03957746652304195, 0.05661340335791465, 0.22037141636246815, 0.07351551612373441, 0.05772469528892543, 0.025252576597267762, 0.06059059131075628, 0.02621255389385624, 0.022684790164930746, 0.020853624264418613, 0.032986297155730426, 0.021156813854759093, 0.04268707270966843, 0.07884150181780569, 0.11072720139054582, 0.036691747736767866, 0.0748681990080513, 0.09352855238830671, 0.031092024582903832, 0.14192327507771552, 0.030403656637645327, 0.05001519100915175, 0.02848383563105017, 0.005864881850357051, 0.07226993999211118, 0.05720172979636118, 0.04256504136719741, 0.03166632443026174, 0.10670418210793287, 0.05743235218687914, 0.07805809073033743, 0.058186964233755134, 0.010612553141982062, 0.07761808621580712, 0.09808753588004038, 0.062486526294378564, 0.0026667286329029594, 0.021940493970760144, 0.0658888577891048, 0.05761990032624453, 0.1284317279350944, 0.15705584431998432, 0.049998006579698995, 0.04569364282360766, 0.14339097600895911, 0.03234627642086707, 0.06398415061994456, 0.058573330024955794, 0.048274060609401204, 0.3864607267314568, 1.874878650996834, 20.003010146319866, 65.2321408689022, 66.6511519253254, 54.81500744819641, 86.52603104710579, 64.36506539583206, 35.432505905628204, 34.121013879776, 83.48018288612366, 34.060038551688194, 0.276116844615899, 0.5154707212932408, 2.8266963455826044, 2.3910010373219848, 2.384207951836288, 10.762513987720013, 30.311942473053932, 38.61125573515892, 28.870628513395786, 38.500347286462784, 33.12821455299854, 27.648302502930164, 23.85413959622383, 20.82805797457695, 31.86014659702778, 40.21835669875145, 30.88062945753336, 20.27708563953638, 3.688515513204038, 1.707293156068772, 4.508623844012618, 3.316859118640423, 8.691065590828657, 5.693726101890206, 24.504586793482304, 23.138354904949665, 23.94962467253208, 35.67545346915722, 21.090042516589165, 28.488300628960133, 10.137310735881329, 3.3828698890283704, 4.838973842561245, 3.931355495005846, 2.29640725068748, 0.18954089493490756, 0.3650229302002117, 0.29169437591917813, 3.9645469514653087, 16.24269962310791, 39.25032064318657, 58.36712144315243, 62.196316570043564, 60.956568494439125, 61.261167749762535, 59.48575481772423, 62.58493311703205, 60.24177744984627, 65.26408955454826, 38.70519049465656, 21.721973307430744, 61.9558996707201, 60.03300525248051, 66.60157978534698, 57.25477673113346, 53.21668401360512, 50.05990840494633, 50.09544409811497, 60.721934884786606, 63.73792424798012, 68.85618880391121, 68.69095847010612, 70.18402755260468, 64.12384673953056, 51.457104831933975, 38.9898332208395, 21.173487938940525, 7.632782477885485, 11.508707497268915, 6.678158277645707, 0.6464771821629256, 0.762209709500894, 9.495809208601713, 16.383445970714092, 17.420649714767933, 22.010341733694077, 20.17862532287836, 25.4993487149477, 6.394707737490535, 8.134991079568863, 10.457308664917946, 8.887303210794926, 2.543397559784353, 1.0339075396768749, 4.292677631601691, 6.136184334754944, 8.21509363129735, 12.854676973074675, 14.733496606349945, 14.158960785716772, 22.469955570995808, 30.26150017976761, 23.139806427061558, 24.1239308193326, 31.964135617017746, 27.105380035936832, 15.149394739419222, 2.741301152855158, 1.852132596541196, 3.243851736187935, 6.726582879200578, 0.8828820905182511, 1.0992351779714227, 0.18938902183435857, 12.7701685577631, 23.405727557837963, 39.728391990065575, 54.33311730623245, 58.916461765766144, 52.12548516690731, 34.08343389630318, 47.126317620277405, 42.28935196995735, 4.676699750125408, 0.5177855689544231, 0.15322922699851915, 0.1320454230881296, 0.22207230009371415, 0.08701037324499339, 0.11678223585477099, 0.019166702186339535, 0.049662982564768754, 0.05288731736072805, 0.04675261334341485, 0.1621912093833089, 0.05488978393259458, 0.012351118493825197, 0.03882909222738817, 0.11846112975035794, 0.03491231880616397, 0.015480228321393952, 0.040084472129819915, 0.012517374416347593, 0.08210704065277241, 0.08998468591016717, 0.1610419640201144, 0.05455655962578021, 0.18379980378085747, 0.19910348259145394, 0.12338151689618826, 0.12965469824848697, 0.14375131839187816, 0.10684936845791526, 0.16586194600677118, 0.1059159470605664, 0.104953782283701, 0.19936221011448652, 0.1473358174553141, 0.10881114678340964, 0.16699698666343465, 0.18425006477627903, 0.16203044535359368, 0.083675354544539, 0.17606778274057433, 0.10727139073424041, 0.18154462479287758, 0.36946833541151136, 0.18140973203117028, 0.16419333085650578, 0.18664179893676192, 0.35874860594049096, 0.1687898818636313, 0.3137146990047768, 0.6731909955851734, 0.505778391379863, 1.6551410732790828, 38.14242169260979, 89.48488667607307, 96.76212698221207, 66.58943563699722, 114.11264196038246, 88.10079574584961, 68.79359096288681, 41.909345760941505, 80.52466347813606, 40.955372750759125, 0.6077371328137815, 1.250412322115153, 3.382029659114778, 3.3610562095418572, 4.607747225090861, 15.240741837769747, 43.56458254158497, 51.98783755302429, 40.51138937473297, 48.74761842191219, 42.02495075762272, 36.41576774418354, 34.4012488424778, 29.780772775411606, 39.23478327691555, 48.139100074768066, 40.06153531372547, 30.103892236948013, 11.944692302495241, 15.540819335728884, 18.582367077469826, 18.677489273250103, 22.607132010161877, 25.042637921869755, 40.719245821237564, 34.78007331490517, 28.824983462691307, 45.68394161760807, 32.74616405367851, 45.32969042658806, 18.2046502456069, 8.047923501580954, 15.361164975911379, 6.418496361002326, 3.020756207406521, 0.539481514133513, 0.5602547619491816, 0.14931655023247004, 3.4763595974072814, 15.493067298084497, 39.02435816824436, 58.63869287073612, 63.82299408316612, 60.64687751233578, 64.22787755727768, 63.56765538454056, 66.44780203700066, 62.26671539247036, 69.1527932882309, 41.16413354873657, 27.23440781235695, 64.7111964225769, 60.80671213567257, 69.07007932662964, 57.438588067889214, 54.642006531357765, 50.174609050154686, 51.9991609454155, 59.83915865421295, 63.33484187722206, 67.05413550138474, 66.03334307670593, 67.09445893764496, 63.06871555745602, 54.59020011126995, 39.530958384275436, 23.663448728621006, 8.854738008230925, 16.1048449203372, 10.150403883308172, 1.107097549829632, 5.02680916339159, 18.71548343449831, 25.590342432260513, 28.970264866948128, 32.36473672091961, 32.51856006681919, 46.09520874917507, 30.157463662326336, 23.93344324082136, 21.32099412381649, 19.776642993092537, 13.363298680633307, 10.064593087881804, 13.227838799357414, 17.061160504817963, 16.620311960577965, 22.38734420388937, 22.79624216258526, 23.352980688214302, 30.067963264882565, 36.77726894617081, 29.78734452277422, 33.46359595656395, 40.53288482129574, 43.24068032205105, 32.11406037211418, 14.131928086280823, 2.5915910862386227, 6.297809137031436, 6.803812310099602, 9.30615283548832, 1.6224388405680656, 0.2868574729654938, 14.71318194642663, 48.48767437040806, 66.0613551735878, 72.73976281285286, 76.2500524520874, 69.45496827363968, 44.764436557888985, 64.01581853628159, 56.76458403468132, 4.007193725556135, 0.6656479253433645, 0.1693953704671003, 0.21853900921996683, 0.3651696676388383, 0.25409343419596553, 0.19860887085087597, 0.10071758108097129, 0.19739404931897298, 0.2399363587028347, 0.12704198219580576, 0.16126993694342673, 0.11894192270119675, 0.11165026982780546, 0.14067245938349515, 0.17365323496051133, 0.16729809081880376, 0.17708125960780308, 0.1680574266356416, 0.27476898569148034, 0.14605901174945757, 0.2680239320034161, 0.2862381062004715, 0.1912683920818381], [0.07181509252404794, 0.01849989919719519, 0.004560708057397278, 0.044964649714529514, 0.06222698983037844, 0.013642932281072717, 0.03210953873349354, 0.08472556772176176, 0.035749472517636605, 0.06839008099632338, 0.10136246288311668, 0.03604085824918002, 0.026681496601668186, 0.02724695561482804, 0.06117495468060952, 0.053321844825404696, 0.08546915516490117, 0.05813968200527597, 0.0661157991271466, 0.07132759055821225, 0.04915638884995133, 0.07858307857532054, 0.09714525323943235, 0.06349110481096432, 0.06303341491729952, 0.06588637159438804, 0.1788081630365923, 0.07167143499827944, 0.5762988072820008, 3.336120047606528, 24.513934291899204, 34.743317887187004, 16.35401464998722, 56.24949507415295, 76.74362316727638, 56.347723603248596, 42.42848910391331, 43.489084392786026, 29.016842767596245, 0.08271334561868571, 0.4405103623867035, 5.051399068906903, 0.8697343210224062, 0.250030710012652, 6.714447755366564, 19.726949259638786, 34.90856721997261, 35.88153541088104, 37.65305355191231, 29.971845522522926, 23.25399409979582, 7.60298210196197, 8.973999358713627, 15.517853368073702, 22.419156096875668, 17.745444886386395, 12.299423217773438, 2.3491745442152023, 3.520171958953142, 1.7336260993033648, 2.8745343536138535, 5.495566735044122, 8.54794342070818, 27.36970715224743, 14.624507054686546, 23.727933168411255, 29.28075570613146, 31.449468433856964, 23.6528529971838, 15.614865962415934, 4.825568161904812, 4.347705328837037, 2.471608486957848, 0.9386740811169147, 0.48552663589362055, 0.49858478363603354, 0.7477239961735904, 0.7131242996547371, 8.221428841352463, 25.67677639424801, 50.097970962524414, 61.477098762989044, 63.199580535292625, 58.21512959897518, 60.53843893110752, 60.89079402387142, 58.04054036736488, 55.13740494847298, 41.889237239956856, 29.511836506426334, 46.084998697042465, 48.71826119720936, 50.678416416049004, 44.74839001893997, 39.57818605005741, 44.337126687169075, 51.00756615400314, 53.056461811065674, 55.231069922447205, 60.89666090905666, 52.490782365202904, 55.86199566721916, 51.21605336666107, 39.51728671789169, 28.159384578466415, 9.208290986716747, 10.678101517260075, 10.880405511707067, 3.383808913640678, 2.8973682783544064, 2.346273399889469, 10.21320691332221, 14.888191055506468, 22.302538454532623, 21.913355737924576, 15.838442165404558, 27.12483499199152, 36.40533350408077, 7.966697635129094, 3.512709871865809, 10.679324101656675, 2.0007344288751483, 2.0505157951265574, 1.6280465084128082, 2.2672188794240355, 1.0412709508091211, 3.802087143994868, 9.432905483990908, 13.438449148088694, 16.653847061097622, 12.623227592557669, 16.52053691446781, 30.636813640594482, 32.108155488967896, 30.87457448244095, 18.186143338680267, 3.321474683471024, 0.4938160098390654, 1.3735365215688944, 6.268076682463288, 4.184326445683837, 0.2365939482115209, 0.06636361707933247, 2.3503451189026237, 24.681226015090942, 29.114222042262554, 34.17858459055424, 40.84821470081806, 17.58669700473547, 18.167607933282852, 53.5994678735733, 20.741534717381, 0.3920905105769634, 0.1009350897220429, 0.3239920490887016, 0.038379324760171585, 0.29098298284225166, 0.047637364696129225, 0.054614024120382965, 0.03630084371252451, 0.026691246566770133, 0.08616132661700249, 0.05803712832857855, 0.040741595657891594, 0.04687092652602587, 0.012697264519374585, 0.06862257359898649, 0.03206870947906282, 0.02387328029726632, 0.011230958825763082, 0.08228664039052092, 0.0290386318374658, 0.021637168938468676, 0.02026326063059969, 0.04689097564551048, 0.05621411677566357, 0.048639301166986115, 0.027930169344472233, 0.01935246546054259, 0.033227721505681984, 0.044679100974462926, 0.054395309489336796, 0.008139124292938504, 0.012644097059819615, 0.06313514109933749, 0.012909770157421008, 0.11851712479256094, 0.04830003948882222, 0.050350552701274864, 0.1780476694693789, 0.034787942277034745, 0.006477636079580407, 0.048214306589215994, 0.043556977398111485, 0.03321166142995935, 0.08472678484395146, 0.07227452646475285, 0.03335056178912055, 0.09714635903947055, 0.0752043844840955, 0.04415963099745568, 0.022996987572696526, 0.15929797635180876, 0.05158687425137032, 0.9970225626602769, 9.854800645262003, 47.86735385656357, 62.696567326784134, 42.72352047264576, 75.25822207331657, 84.31873708963394, 51.49667210876942, 25.354682877659798, 56.37669324874878, 36.26740090548992, 0.06949027781956829, 0.02129076594428625, 1.7844439786858857, 2.828878853470087, 1.591462071519345, 8.239141590893269, 14.051106423139572, 33.70894879102707, 34.38799515366554, 38.305330350995064, 35.675278678536415, 35.872594490647316, 23.480344153940678, 21.123072244226933, 26.928186044096947, 32.341143786907196, 29.232750982046127, 18.581647016108036, 8.384107612073421, 4.9523236602544785, 3.920479053631425, 6.546099688857794, 10.21749023348093, 5.345559334382415, 24.77406643331051, 13.205101769417524, 21.742355413734913, 27.631032429635525, 22.261483557522297, 23.487261682748795, 15.141655504703522, 3.514718064107001, 0.7380201481282711, 2.8327453834936023, 0.8419128670357168, 0.598379778675735, 0.769399042474106, 1.0392776015214622, 0.8422680292278528, 10.236121583729982, 33.387315049767494, 57.00100734829903, 63.037268444895744, 64.21176642179489, 62.89457470178604, 61.75933621823788, 63.88562232255936, 63.083181381225586, 61.939628943800926, 49.31137517094612, 38.09303194284439, 57.68621318042278, 59.45008233189583, 59.26952362060547, 52.55838833749294, 48.98094870150089, 47.510013431310654, 55.462599098682404, 60.89801363646984, 61.33275970816612, 66.89419448375702, 62.13449388742447, 63.49949084222317, 58.35904307663441, 47.81083568930626, 32.821533009409904, 12.239166051149368, 13.859395310282707, 11.043818593025208, 5.464997375383973, 2.239356874488294, 1.890870330389589, 4.169163359329104, 9.862619675695896, 18.297293074429035, 16.90510667860508, 11.411411818116903, 26.93183194845915, 22.86120157688856, 7.647411217913032, 10.67118588835001, 14.430519863963127, 6.789739290252328, 3.9914658945053816, 3.5216066194698215, 5.111046368256211, 7.022630218416452, 8.408564999699593, 18.396114371716976, 22.68124133348465, 28.598654307425022, 22.725527957081795, 26.3530508056283, 37.89746783673763, 34.14958454668522, 20.31709559261799, 9.454304985702038, 0.6157026335131377, 0.8023004082497209, 2.80594399664551, 3.7514007138088346, 1.7140983534045517, 0.32440061622764915, 0.16609655373031273, 2.2016481729224324, 18.74644797295332, 40.02132587134838, 52.17286482453346, 55.680521205067635, 36.5037140250206, 26.22705716639757, 62.79533542692661, 29.971476942300797, 0.5703466047998518, 0.1783851982327178, 0.062072701039141975, 0.039125903058447875, 0.22601037315325812, 0.06006604504364077, 0.10288376914104447, 0.03613148561271373, 0.08564127405406907, 0.035343851704965346, 0.019787759192695376, 0.0063757243606232805, 0.03895603287674021, 0.027519360919541214, 0.004522533836279763, 0.041387657474842854, 0.07520218772697262, 0.019690630615514237, 0.0650571848382242, 0.10004783733165823, 0.11833265656605363, 0.1921101359766908, 0.047834608994890004, 0.021363160594773944, 0.12943747162353247, 0.11270274655544199, 0.2224942110478878, 0.19162048178259283, 0.1788463836419396, 0.21223741845460609, 0.1451430085580796, 0.18723541317740455, 0.09065339807420969, 0.15563840162940323, 0.16440640145447105, 0.17436335154343396, 0.151437237218488, 0.24067492922767997, 0.1729283347958699, 0.09017478703754023, 0.2618931094184518, 0.12369037649477832, 0.2641214820323512, 0.20421503955731168, 0.14696933008963242, 0.15020697901491076, 0.15308720961911604, 0.18573188135633245, 0.16270084219286218, 0.14228574000298977, 0.4409862571628764, 0.11716546607203782, 1.3165248557925224, 11.185586135834455, 64.92672845721245, 90.71773812174797, 61.836700066924095, 93.3310478925705, 111.02066427469254, 78.232292085886, 53.653535172343254, 56.68463632464409, 41.56422547996044, 0.2823064156109467, 1.0076441802084446, 9.958308041095734, 6.468005329370499, 2.066923789680004, 9.696546737104654, 28.595734164118767, 45.25868743658066, 47.56079010665417, 50.483315885066986, 45.27012102305889, 42.13490165770054, 28.6865321919322, 28.573573753237724, 33.038596361875534, 42.47426524758339, 37.09148548543453, 27.463902197778225, 18.101947456598282, 18.921204395592213, 20.699347481131554, 19.89581409841776, 25.924680791795254, 22.871461026370525, 36.31779760122299, 24.531014375388622, 34.68741528689861, 45.55333502590656, 37.08230517804623, 40.51227852702141, 23.97145640105009, 9.637328814715147, 7.132611991837621, 6.379477204754949, 2.852575806900859, 1.8569013406522572, 2.8739584470167756, 0.6786805135197937, 0.5557072965893894, 10.538003984838724, 36.84878870844841, 57.536106035113335, 65.33535093069077, 67.15391054749489, 63.9380519092083, 64.8129777610302, 68.40072244405746, 65.67643582820892, 65.54728835821152, 55.13344556093216, 45.204608738422394, 59.39074091613293, 64.38994646072388, 59.96408075094223, 56.34051539003849, 48.96795719861984, 49.34854477643967, 59.015256464481354, 63.74647378921509, 63.191760554909706, 69.25772845745087, 65.03898963332176, 65.22734552621841, 59.89307016134262, 49.21229928731918, 37.67226532101631, 12.110101226717234, 14.885497000068426, 12.865301202982664, 10.008018873631954, 2.8723133727908134, 7.918066419661045, 17.45121907442808, 23.10723267495632, 33.65337677299976, 30.527672097086906, 22.6082244515419, 40.077840238809586, 48.22852447628975, 23.91252726316452, 18.665829598903656, 23.434368520975113, 16.582819372415543, 12.950013857334852, 12.7297149784863, 15.74408657848835, 16.741092279553413, 16.655781157314777, 26.620033979415894, 30.965108424425125, 33.648258447647095, 30.726268440485, 36.00010044872761, 44.74278911948204, 43.825753927230835, 38.268757313489914, 23.785027004778385, 3.7325912481173873, 0.9037214785348624, 2.647889577783644, 14.31544303894043, 7.136780843138695, 1.2712045689113438, 0.2653622638899833, 7.552852341905236, 29.311839938163757, 52.47252434492111, 70.92732846736908, 80.77742591500282, 47.27532662451267, 40.364679247140884, 83.02946627140045, 32.74039976298809, 0.541610587388277, 0.2737499278737232, 0.4720852430909872, 0.10624575006659143, 0.4972536675632, 0.15602661907905713, 0.23568821634398773, 0.07375359709840268, 0.15584099310217425, 0.1356530177872628, 0.16056359047070146, 0.1603487684042193, 0.25382857653312385, 0.12187066749902442, 0.18930253194412217, 0.18269750667968765, 0.2511932101333514, 0.13585436245193705, 0.2524879906559363, 0.20885175559669733, 0.23239172995090485, 0.3542956308228895, 0.1371587166795507, 0.0981509598204866], [0.0663937556964811, 0.011605253585003084, 0.03046616959181847, 0.06942614141735248, 0.07507640853873454, 0.029214580208645202, 0.04630478659237269, 0.029712175382883288, 0.053747893252875656, 0.10825892211869359, 0.052970111355534755, 0.03776426245167386, 0.036844270216533914, 0.05069991500931792, 0.03940802678698674, 0.08845564647344872, 0.027354939957149327, 0.023273886581591796, 0.0317422238731524, 0.04770844760059845, 0.06870481098303571, 0.040008157084230334, 0.004137091091251932, 0.08775807960773818, 0.07736809377092868, 0.047978619040804915, 0.32984421006403863, 0.12071480217855424, 0.7451653678435832, 4.874350894242525, 16.04398548603058, 35.38786970078945, 17.56643269211054, 30.61249304562807, 64.17430803179741, 62.25777067244053, 63.98868799209595, 57.96943098306656, 7.696052882820368, 0.21464369870955124, 0.4787162732100114, 0.7687208976130933, 2.887059194035828, 0.6707241560798138, 1.9955462822690606, 16.141661144793034, 33.61383609473705, 35.1554361730814, 39.527888149023056, 34.39076520502567, 20.443706698715687, 18.579783216118813, 11.226201206445694, 7.887615328654647, 18.950449526309967, 15.821448527276516, 13.791805487126112, 5.096511198207736, 1.0246498114429414, 1.1384121445007622, 4.559956714510918, 3.801884804852307, 11.280715931206942, 22.315083481371403, 15.25763288140297, 22.083029933273792, 29.751094467937946, 27.065884955227375, 15.638424698263407, 8.319480679929256, 2.4230974400416017, 2.258049021475017, 0.17408397747203708, 1.0852458723820746, 0.8041079831309617, 0.7908963295631111, 1.168755297549069, 1.1085362476296723, 6.614789078012109, 20.26392314583063, 40.10266050696373, 56.14439271390438, 60.90427570044994, 61.45431898534298, 62.51422271132469, 63.1353297829628, 60.90556003153324, 53.38822200894356, 40.33689133822918, 29.2381713911891, 43.408741503953934, 45.82841366529465, 42.09289491176605, 36.89700432121754, 36.011382043361664, 46.0411224514246, 49.09306928515434, 50.974656119942665, 51.741268783807755, 50.8753864467144, 50.228991732001305, 44.65784467756748, 43.431620076298714, 39.062922298908234, 20.369211696088314, 5.449499431997538, 10.40051881223917, 12.733452077955008, 5.500874575227499, 3.878728081472218, 0.2597659360617399, 11.027241982519627, 18.683422654867172, 23.132172636687756, 26.835376024246216, 13.832825236022472, 5.204570749774575, 21.649256609380245, 6.867040917277336, 4.924130123108625, 9.000030811876059, 5.364926420152187, 1.492096334695816, 4.210495641455054, 2.907027122564614, 4.314737347885966, 2.8073641704395413, 7.1849950309842825, 6.573173711076379, 16.563425213098526, 21.058228723704815, 25.426548421382904, 23.22768811136484, 29.034912697970867, 23.327865935862064, 10.204949006438255, 0.7292675552889705, 1.0877621686086059, 2.775783115066588, 5.1488215662539005, 0.3537495882483199, 0.152265815413557, 0.1840070410980843, 1.3257912523113191, 5.276537938043475, 9.796417728066444, 31.34755600243807, 29.918139204382896, 12.411410808563232, 22.138976231217384, 45.94470642507076, 2.5488350680097938, 0.21915389341302216, 0.16861339914612472, 0.06507961996248923, 0.1418235304299742, 0.12227849249029532, 0.1279277799767442, 0.05930246785283089, 0.08644342437037267, 0.20249796216376126, 0.07216061421786435, 0.17823026748374104, 0.07740677450783551, 0.12562922987854108, 0.044590874458663166, 0.013848146318196086, 0.03296359856904019, 0.08676429933984764, 0.10533030348597094, 0.0459692653384991, 0.11231607277295552, 0.022831839305581525, 0.020152482102275826, 0.09863641345873475, 0.06228266574908048, 0.021207150020927656, 0.02419308842945611, 0.04459743504412472, 0.04771028441609815, 0.07549483139882796, 0.017802541988203302, 0.060606317420024425, 0.07664153119549155, 0.0136491774537717, 0.00991582304777694, 0.0802083894086536, 0.0424440267670434, 0.02675595627806615, 0.03998877218691632, 0.08746075298404321, 0.05383026793424506, 0.02797201719658915, 0.04638224083464593, 0.04755450019729324, 0.02427193605399225, 0.055324111017398536, 0.09310157256550156, 0.06753070367267355, 0.15854818455409259, 0.07560770463896915, 0.10447552747791633, 0.2668076707050204, 0.10948610783088952, 0.5573939310852438, 4.886846048757434, 34.27129581570625, 64.85391676425934, 43.071961775422096, 53.36969040334225, 77.15647861361504, 71.3205997645855, 48.65258552134037, 48.21250073611736, 10.840055476874113, 0.17569255287526175, 0.3267153451452032, 0.369837746839039, 1.624226407147944, 0.28291886555962265, 2.6216075755655766, 6.040663635358214, 20.738065503537655, 29.015987813472748, 43.05956304073334, 36.974607557058334, 31.33140306919813, 30.630163997411728, 28.007071651518345, 24.95123952627182, 31.249849945306778, 26.69201921671629, 18.433198481798172, 14.015850014984608, 8.334468975663185, 6.736461399123073, 12.04714335501194, 8.798527624458075, 12.046220004558563, 25.454682111740112, 8.590125907212496, 19.29307334125042, 22.68199749290943, 16.468859687447548, 9.181602168828249, 6.104040434584022, 1.2934776674956083, 0.48607980308588594, 0.6562646850943565, 1.22850222280249, 0.8320752542931587, 0.9044506831560284, 1.0955835739150643, 2.5245296722278, 6.860082540661097, 27.504710108041763, 46.20322935283184, 59.89068388938904, 66.17783412337303, 64.68784287571907, 63.671617805957794, 68.91463726758957, 66.91443219780922, 61.59516982734203, 50.961337834596634, 36.46094352006912, 56.09479017555714, 55.85264816880226, 51.413680762052536, 46.64383850991726, 47.26193234324455, 54.96278151869774, 57.95781500637531, 58.53699132800102, 61.83462917804718, 60.17227537930012, 57.632001489400864, 58.82476508617401, 48.38371194899082, 44.96875539422035, 27.239110060036182, 9.287418890744448, 14.380913525819778, 14.318499024957418, 7.235030746087432, 4.162668082863092, 2.3054255917668343, 6.09308609738946, 6.978944912552834, 9.65831508859992, 12.22488546743989, 4.259808920323849, 11.850958932191133, 30.744564458727837, 8.416300434619188, 7.59569076821208, 12.805857192724943, 10.863849800080061, 8.421416860073805, 8.865557927638292, 6.400617370381951, 10.642654169350863, 9.67786693945527, 12.516540717333555, 15.539910234510899, 29.768328443169594, 36.59448355436325, 37.33803145587444, 30.797624811530113, 22.946529798209667, 9.943333994597197, 3.2377181528136134, 0.7653740490786731, 2.778590926900506, 6.161453453823924, 3.410921646282077, 0.3074462525546551, 0.08010986188310198, 0.12647082534385845, 1.0519285476766527, 14.92981307208538, 36.8963735550642, 46.90630562603474, 50.162689089775085, 29.709167517721653, 33.88526313006878, 60.38936533033848, 5.339570855721831, 0.27940117463003844, 0.1553813662030734, 0.03571887005819008, 0.11541554864379577, 0.1339117463794537, 0.09797335645998828, 0.11072374298237264, 0.12292323328438215, 0.01495120504841907, 0.13843899563653395, 0.039196663128677756, 0.07255867254571058, 0.04823578434297815, 0.07069428625982255, 0.044102248139097355, 0.016188322551897727, 0.012404371300362982, 0.07587343061459251, 0.030126687124720775, 0.03645413431513589, 0.02831161840731511, 0.05617901690129656, 0.09096087727812119, 0.0456897391268285, 0.15557910403003916, 0.08950550341978669, 0.12265361845493317, 0.10992827199515887, 0.16213934810366482, 0.08213359469664283, 0.13801963767036796, 0.21252039936371148, 0.17702242213999853, 0.1441206259187311, 0.25678312580566853, 0.11350696004228666, 0.09811837211600505, 0.13913081085775048, 0.20096327498322353, 0.30970867490395904, 0.12310786478337832, 0.17227567528607324, 0.11092303189798258, 0.1380064125987701, 0.18980272463522851, 0.3132049029227346, 0.10891250189160928, 0.20307302271248773, 0.1249974247184582, 0.20153631689026952, 0.5291429813951254, 0.3742433135630563, 0.702881533652544, 3.8586758449673653, 46.81325241923332, 88.65593835711479, 68.36414560675621, 74.68354851007462, 99.53863799571991, 101.68895021080971, 79.6237014234066, 80.82544773817062, 11.235163975507021, 0.2343702214420773, 0.9717358101624995, 4.251383822411299, 7.8657114040106535, 2.964578834362328, 4.207079149782658, 21.69863685965538, 41.650442853569984, 46.30127929151058, 53.758968114852905, 46.009382754564285, 35.09210877120495, 36.92088603973389, 32.86953963339329, 30.308148376643658, 41.19523108005524, 35.77421776950359, 28.618690632283688, 21.190151944756508, 19.012994170188904, 18.575229160487652, 21.796109229326248, 22.843494527041912, 25.610587745904922, 38.286525160074234, 22.835866436362267, 34.32110354304314, 40.64539298415184, 33.80171321332455, 23.4507779404521, 16.721549928188324, 6.889353320002556, 2.7201187144964933, 1.691264072433114, 2.0481335604563355, 1.2282744725234807, 1.224614200182259, 0.7498197024688125, 1.7173102498054504, 11.880057770758867, 30.254937931895256, 49.87599067389965, 61.78515203297138, 69.06539037823677, 67.09306061267853, 62.62439399957657, 69.49384778738022, 68.4522932767868, 64.13393139839172, 59.01820130646229, 46.82397924363613, 61.259564235806465, 61.4670255035162, 58.00115928053856, 50.47035478055477, 51.2934248149395, 57.51333765685558, 62.228200659155846, 65.0025799870491, 64.99362006783485, 64.84374850988388, 63.70853662490845, 65.52741542458534, 49.88837420940399, 51.52614712715149, 33.84581744670868, 9.828312266618013, 17.927409522235394, 15.95252439379692, 14.66271685436368, 6.362285502254963, 4.704108629375696, 18.02835300564766, 26.95545718073845, 32.85453423857689, 36.22344106435776, 17.989144809544086, 16.26368209719658, 40.39209857583046, 17.28112120181322, 11.675417851656675, 17.39478450268507, 15.757335517555475, 15.770944487303495, 14.457858446985483, 16.26526851207018, 20.694941617548466, 17.825742177665234, 22.273950688540936, 22.73573610931635, 35.17380818724632, 41.83405660092831, 42.4131303280592, 35.339475497603416, 36.71677999198437, 31.064273603260517, 11.472442243248224, 1.4030991727486253, 3.1673829769715667, 7.377122221514583, 9.769103843718767, 0.6527100945822895, 0.2945214242208749, 0.6275151309091598, 1.3079040683805943, 20.448222756385803, 49.41366948187351, 74.93396267294884, 72.17303842306137, 36.12018160521984, 51.38882249593735, 68.58516454696655, 2.9913975577801466, 0.44603713613469154, 0.2718008105875924, 0.16266107792034745, 0.37746367044746876, 0.3530554723693058, 0.3384854510659352, 0.1643909202539362, 0.24778489692835137, 0.2196954979444854, 0.28309071727562696, 0.2830607641953975, 0.18333900428842753, 0.28410832048393786, 0.12741785030812025, 0.14132314478047192, 0.12169564681244083, 0.1651648318511434, 0.238688318640925, 0.1627625443506986, 0.21116045827511698, 0.1274168855161406, 0.16015349450754002, 0.28545531851705164, 0.2201418997719884], [0.037138197803869843, 0.04976095719030127, 0.0727562842075713, 0.03889352548867464, 0.049976855370914564, 0.040069165333989076, 0.033124006367870606, 0.051141852818545885, 0.06012311248923652, 0.07974402018589899, 0.052010395666002296, 0.07654985369299538, 0.04560834036965389, 0.1353792691952549, 0.029353922145674005, 0.048556640758761205, 0.024702561677258927, 0.02057937286735978, 0.08007244279724546, 0.015800168184796348, 0.04786855854035821, 0.0353059279586887, 0.09445326097193174, 0.07343975026742555, 0.04905772031634115, 0.04197781330731232, 0.0529028430901235, 0.10380887106293812, 0.04432771631400101, 1.1670419457368553, 7.585899643599987, 18.03772710263729, 19.343183152377605, 29.861174561083317, 53.50404739379883, 66.41022965312004, 34.97422009706497, 33.41674827039242, 4.1826212871819735, 0.13481664704158902, 0.12605525233084336, 0.5115360917989165, 0.6297373585402966, 1.1777693638578057, 0.8925667020957917, 5.6372440326958895, 28.022111244499683, 38.01427736878395, 41.12696394324303, 36.15407198667526, 33.5720269382, 24.427247643470764, 17.336934506893158, 5.612081782892346, 22.87602648139, 15.43207012116909, 15.675611402839422, 16.746163107454777, 4.926688335835934, 1.3518907455727458, 6.741528427228332, 5.832678470760584, 12.841899208724499, 26.979017816483974, 13.47176481038332, 21.013940200209618, 24.563823714852333, 31.62050485610962, 20.719860680401325, 2.735458491370082, 0.9401708445511758, 1.2564893835224211, 0.3372687741648406, 0.836334825726226, 0.5776923825033009, 0.32853556622285396, 1.0091980593279004, 0.9598786057904363, 7.151504103094339, 20.58642514050007, 42.22073145210743, 53.73387046158314, 63.40219706296921, 65.67350998520851, 66.8669119477272, 63.70809964835644, 67.1417436003685, 52.969279289245605, 32.58232444524765, 25.3978618606925, 37.68000170588493, 35.76827108860016, 31.604104936122894, 29.731728807091713, 33.19938853383064, 39.43338721990585, 41.56818866729736, 49.91815321147442, 46.17629639804363, 44.47946324944496, 42.259477972984314, 34.04525354504585, 42.94292449951172, 37.41620846092701, 12.517218980938196, 5.936860805377364, 10.843690931797028, 8.003549482673407, 9.766934160143137, 3.9774337224662304, 0.22428995609516278, 8.59084976837039, 14.973116498440504, 20.99872011691332, 21.126530058681965, 12.574476208537817, 2.8100192779675126, 23.5240114107728, 10.098295379430056, 6.575327720493078, 12.028883434832096, 12.390676271170378, 7.054271120578051, 6.125269420444965, 4.675090536475182, 4.108754675835371, 2.151128933764994, 0.44965632318053395, 5.730920881032944, 16.260385774075985, 14.801220372319221, 21.153086833655834, 28.598732203245163, 30.872125513851643, 11.474609076976776, 1.2815818120725453, 0.22380117763532326, 1.3383409101516008, 2.326243962161243, 0.19914896140107885, 0.10723318497184664, 0.49914121627807617, 0.6908365362323821, 9.721253961324692, 13.100708071142435, 13.4706761687994, 41.53285436332226, 18.358101211488247, 13.167297597974539, 41.9605328142643, 16.525761634111404, 0.3207541775191203, 0.10480979079147801, 0.13500286673661321, 0.13790597033221275, 0.11983992138993926, 0.08270242862636223, 0.046990189657662995, 0.09269786649383605, 0.15425247052917257, 0.09267464469303377, 0.027556937711779028, 0.011176236566825537, 0.08490354957757518, 0.05915636123972945, 0.05743481240642723, 0.10234080647933297, 0.037775550517835654, 0.03113689112069551, 0.05890763415663969, 0.08478886549710296, 0.028574446296261158, 0.032614904193906114, 0.07887259780545719, 0.1333097310271114, 0.035073940016445704, 0.02742081298492849, 0.04276103514712304, 0.03772771167859901, 0.021162700941204093, 0.07676898021600209, 0.10469541099155322, 0.060241355167818256, 0.039583258985658176, 0.03826074069365859, 0.05303365032887086, 0.09860324687906541, 0.02308706389158033, 0.018788390552799683, 0.07406690958305262, 0.027322884743625764, 0.03916080997441895, 0.0740303291240707, 0.05087205987365451, 0.10383290180470794, 0.08115449410979636, 0.0745100830681622, 0.05941032046393957, 0.08458616270218045, 0.07316509625525214, 0.09296878008171916, 0.1082835540000815, 0.02650416412507184, 0.06959238991839811, 0.04733426416350994, 1.611349848099053, 18.701329194009304, 41.44428111612797, 45.48786073923111, 57.225419506430626, 74.82467293739319, 78.68999272584915, 49.17842410504818, 35.70718936622143, 4.811568288132548, 0.12591350212460384, 0.0821260099473875, 0.08384295375435613, 1.260240375995636, 0.40323863737285137, 1.346168965101242, 3.81603239569813, 11.443136315792799, 24.397886618971825, 36.111601665616035, 37.64853939414024, 35.07698938250542, 38.38164925575256, 32.62302406132221, 22.071921229362488, 37.502513229846954, 32.7083370834589, 26.663587242364883, 25.465505830943584, 13.996970728039742, 7.965226639062166, 16.401595696806908, 14.892591219395399, 15.984737165272236, 31.483125127851963, 9.735174514353275, 13.365901540964842, 11.724607162177563, 11.976060569286346, 14.581772647798061, 5.495373420417309, 1.8987752124667168, 0.7178214413579553, 0.47926374070812017, 0.04583687361446209, 0.6559091072995216, 0.8266161347273737, 1.3758017937652767, 2.6988738169893622, 10.580802038311958, 24.34852536767721, 47.71246276795864, 59.579719975590706, 69.1997891664505, 65.23895770311356, 69.33234125375748, 66.62194669246674, 73.91209870576859, 61.74039423465729, 41.62029527127743, 37.51802779734135, 54.33783285319805, 46.86498664319515, 45.39992965757847, 39.6082766354084, 47.55020007491112, 49.183933809399605, 52.22870662808418, 55.99911890923977, 57.13479056954384, 51.73745758831501, 53.604202419519424, 46.68690159916878, 48.94505962729454, 43.28632727265358, 17.52904649823904, 9.469954445958138, 12.85918353125453, 11.383522264659405, 8.950672410428524, 3.7570400862023234, 3.798132506199181, 4.497383097186685, 7.554984027519822, 7.855507526546717, 4.854412414133549, 2.4427164997905493, 5.329109067097306, 19.893925599753857, 11.456277910619974, 5.642139120027423, 8.765134066343307, 10.281301159411669, 8.889763578772545, 9.759903587400913, 11.759198606014252, 9.583401158452034, 7.760506924241781, 12.336011454463005, 23.683996126055717, 34.17899116873741, 25.728634111583233, 28.500579670071602, 25.625929422676563, 15.879718400537968, 5.367286568507552, 1.4959480217657983, 2.0596060948446393, 3.2993515580892563, 2.6016755076125264, 0.2782966510858387, 0.16040396934840828, 0.5289113125763834, 0.49352084286510944, 17.852749228477478, 37.340398728847504, 32.96731598675251, 58.402474746108055, 43.33740033209324, 24.237160943448544, 49.0420114248991, 28.379362374544144, 0.29501931625418365, 0.11099662326159887, 0.020355416818347294, 0.044594269784283824, 0.028624205442611128, 0.08723801220185123, 0.03236111195292324, 0.08500418480252847, 0.16383168229367584, 0.09832232171902433, 0.030183125600160565, 0.029786603518004995, 0.04290550532459747, 0.04563959962979425, 0.06492428845376708, 0.054362888768082485, 0.06141828635009006, 0.030012552233529277, 0.05644902877975255, 0.06059569357603323, 0.04362948893685825, 0.01740310326567851, 0.02426508788630599, 0.05406539516116027, 0.0670081797579769, 0.07284391700522974, 0.17535929888254032, 0.16158140148036182, 0.18503589526517317, 0.15242712863255292, 0.1985920686274767, 0.21385763073340058, 0.10609388438751921, 0.15655437513487414, 0.13517746439902112, 0.14686663169413805, 0.16688818781403825, 0.15938834025291726, 0.22326726175379008, 0.11480697270599194, 0.153785080765374, 0.15328565990785137, 0.15935222734697163, 0.23328376177232713, 0.19805779651505873, 0.14822915545664728, 0.14570779778296128, 0.2804509870475158, 0.2051655823015608, 0.1866807765327394, 0.17998875671764836, 0.1854849688243121, 0.24924284603912383, 0.1677574060158804, 1.9913071347400546, 18.000194616615772, 61.469981744885445, 76.71255603432655, 80.60179933905602, 95.97136661410332, 107.09064915776253, 57.488145008683205, 45.49829877912998, 10.120851919054985, 0.30793871206697077, 0.5654020013753325, 0.9265192458406091, 3.3196023339405656, 2.467726282775402, 2.9312679218128324, 5.944258533418179, 35.49280866980553, 47.56265200674534, 50.57089738547802, 47.7575359493494, 47.33893521130085, 40.11347092688084, 37.68787108361721, 26.849952042102814, 43.50233808159828, 34.86151434481144, 32.26078949868679, 34.73780818283558, 19.461246617138386, 15.31536128371954, 26.70466683804989, 25.054508484899998, 26.741416566073895, 45.091872587800026, 23.007366433739662, 28.90183623880148, 33.68678078055382, 33.155158907175064, 26.86262246221304, 8.391463067382574, 3.3152955025434494, 2.048045927658677, 0.695394747890532, 2.354656462557614, 0.6455755024217069, 1.512286551296711, 1.5939974854700267, 5.5785837303847075, 13.683179765939713, 26.35225474834442, 50.45153819024563, 61.11275911331177, 71.16701200604439, 68.38606283068657, 68.12165781855583, 68.7906651198864, 73.04229497909546, 67.52499863505363, 48.471844419837, 45.02759903669357, 64.15251240134239, 55.7467782497406, 55.545582845807076, 45.917807668447495, 54.33391906321049, 53.57992172241211, 58.42579409480095, 64.04861077666283, 60.96406929194927, 63.84832352399826, 61.31032571196556, 53.880743980407715, 53.50585229694843, 48.30436460673809, 26.34263176470995, 11.95291981101036, 16.381800659000874, 11.620987672358751, 12.025771401822567, 5.746191311627626, 5.524505032226443, 14.528741743415594, 25.343703366816044, 28.290114663541317, 33.034454584121704, 26.17108426988125, 6.877332190051675, 21.061711236834526, 9.336549304425716, 4.302790313959122, 7.666415423154831, 11.011472828686237, 10.725636966526508, 12.5903251580894, 19.270922429859638, 16.515876464545727, 18.073842264711857, 19.22135788947344, 26.930866800248623, 34.17227692902088, 27.37724594771862, 34.53245960175991, 39.76915240287781, 37.213048562407494, 13.948377035558224, 1.7265215492807329, 2.2762745060026646, 3.604639288969338, 7.389216972514987, 2.9721162049099803, 0.8716142107732594, 0.9432480856776237, 1.0974744474515319, 23.43902327120304, 48.24083961546421, 48.49113218486309, 92.52488315105438, 48.49693067371845, 36.16736367344856, 69.46369260549545, 27.126280814409256, 0.3262772405287251, 0.24089359561912715, 0.15239509753882885, 0.2141807766747661, 0.23141163488617167, 0.15610423288308084, 0.21688758220989257, 0.17623728926992044, 0.38327498361468315, 0.20482201245613396, 0.10500299409613945, 0.18900981405749917, 0.2526293252594769, 0.14065579074667767, 0.11265193912549876, 0.10403999811387621, 0.2513196424115449, 0.12351902943919413, 0.19091677735559642, 0.17370059882523492, 0.17867050948552787, 0.14186627813614905, 0.15572777105262503, 0.25532551808282733, 0.22950902057345957], [0.11450441394117661, 0.04629872324585449, 0.04747805156512186, 0.02609923165437067, 0.02033095563092502, 0.0698396289953962, 0.04458470350073185, 0.034147112601203844, 0.031865483470028266, 0.04156850030994974, 0.02996676543261856, 0.031899277164484374, 0.07298250566236675, 0.09043481331900693, 0.055872591547085904, 0.04670147936849389, 0.04800917697139084, 0.0025156361789413495, 0.06518161331769079, 0.12779456446878612, 0.02169095052522607, 0.02629796766996151, 0.06646969224675559, 0.029858536181563977, 0.050281184157938696, 0.04796118970261887, 0.09075392939848825, 0.06289458877290599, 0.07604727128637023, 0.4319303634110838, 3.3172371983528137, 13.352077882736921, 24.61478468030691, 23.59143689274788, 41.707758978009224, 56.617592722177505, 44.52198676764965, 17.360854223370552, 2.4351095454767346, 0.3191766090458259, 0.22715935134328902, 0.22944843163713813, 0.2732913399813697, 0.5857136927079409, 0.38172030297573656, 0.704599100863561, 12.890752237290144, 28.14349003136158, 43.864656239748, 40.11658675968647, 41.37311473488808, 30.033962689340115, 24.609635956585407, 18.4981369972229, 22.311285585165024, 9.451037161052227, 12.215926498174667, 30.55016689002514, 8.43196414411068, 4.336875909939408, 12.07574537023902, 5.086226100102067, 6.822780417278409, 21.577569656074047, 6.2221528217196465, 15.50652427598834, 17.342966683208942, 15.248760357499123, 9.269546549767256, 1.0022463323548436, 2.175745200365782, 0.862903653178364, 0.7281119422987103, 0.3569379140390083, 0.5926318152341992, 0.6071275030262768, 2.2713791811838746, 3.3221090119332075, 6.9397348165512085, 18.400818519294262, 35.55602207779884, 52.60925240814686, 58.013014644384384, 61.667563542723656, 63.286010697484016, 68.6267951130867, 59.90819714963436, 52.299873009324074, 31.900591626763344, 26.330366022884846, 31.01352922618389, 28.672541342675686, 18.498604372143745, 23.25054958462715, 22.70249169319868, 28.921836465597153, 35.527451410889626, 38.18276412785053, 46.51058346033096, 41.71397924423218, 42.70152345299721, 41.859386041760445, 36.46942086517811, 26.162910908460617, 6.624927883967757, 9.947446323931217, 8.349648211151361, 7.706574993208051, 4.8776239436119795, 2.4265483673661947, 1.5940682566724718, 7.481712084263563, 11.06901504099369, 9.01253879070282, 5.035861227661371, 3.10819782782346, 2.686581714078784, 21.60161666572094, 14.092343710362911, 5.827865554019809, 15.115305818617344, 15.07095554843545, 8.1505217961967, 9.377827439457178, 9.78710537776351, 5.300071025267243, 0.39932416460942477, 1.470701820217073, 6.027025692164898, 12.495465148240328, 21.395029351115227, 35.40954373776913, 25.610621944069862, 15.879935938864946, 1.4061331911943853, 0.917890858836472, 0.12172779664979316, 3.488993919454515, 6.302838167175651, 0.8494286262430251, 0.9256230283062905, 1.3998023746535182, 8.06338107213378, 20.851688906550407, 10.475484989583492, 41.63174785673618, 27.975242659449577, 5.051870243623853, 31.968402788043022, 40.77631875872612, 0.7551784836687148, 0.038634452866972424, 0.060782803848269396, 0.07822315921657719, 0.024439130793325603, 0.021268577584123705, 0.09959796225302853, 0.13725011958740652, 0.051634082265081815, 0.07481040796847083, 0.021388525346992537, 0.028738490618707146, 0.004392703449411783, 0.056544728722656146, 0.03847158113785554, 0.06072128722735215, 0.027951782540185377, 0.04995940005755983, 0.05058841474237852, 0.01949146044353256, 0.09743219721713103, 0.07463984016794711, 0.04420497250976041, 0.018594981302157976, 0.029312818296602927, 0.03489150527457241, 0.13936083210865036, 0.006939407321624458, 0.03387792079593055, 0.01703396457742201, 0.027713831441360526, 0.019057830977544654, 0.06455564885982312, 0.0696621963288635, 0.03797546283749398, 0.030917926014808472, 0.02298938612511847, 0.07902337252744474, 0.060047320657758974, 0.051518934342311695, 0.043833394011016935, 0.043513921700650826, 0.0209979497230961, 0.08153122311341576, 0.09170916251605377, 0.16409133007982746, 0.053204032592475414, 0.0889769458444789, 0.004254452933309949, 0.018197050994785968, 0.12944443296873942, 0.08522457297658548, 0.047274755052058026, 0.03612535547290463, 0.1104180449328851, 0.5315161915495992, 5.826625870540738, 28.815197087824345, 55.051719546318054, 52.146368846297264, 70.49221381545067, 76.69652089476585, 59.147341176867485, 29.441291391849518, 3.1978397676721215, 0.23972894327016547, 0.2114655848708935, 0.333295731106773, 0.8183446910697967, 0.5653304583393037, 1.0433383961208165, 1.224137325771153, 6.169598791748285, 9.784766603261232, 26.785133220255375, 38.678455129265785, 41.78302153944969, 38.70898649096489, 39.24594707787037, 38.793782740831375, 40.60452617704868, 24.17408622801304, 28.699880875647068, 41.19986683130264, 17.694227434694767, 13.09542065486312, 18.068953827023506, 13.346986155956984, 13.586353361606598, 24.80089869350195, 7.881995430216193, 8.132201079279184, 15.0245001912117, 14.781043455004692, 12.259440813213587, 5.595310907810926, 2.810658593662083, 1.628583229612559, 1.5157448407262564, 0.5458394635934383, 0.7346516288816929, 0.46892541577108204, 2.016276544891298, 4.89265451207757, 9.551174137741327, 19.700871258974075, 40.48947975039482, 57.88274243474007, 64.011539965868, 66.55977442860603, 68.35748076438904, 76.94272488355637, 68.11951473355293, 62.79808267951012, 44.08317111432552, 37.93664373457432, 44.38350319862366, 42.249609902501106, 33.778705447912216, 37.16914191842079, 38.07385437190533, 41.76963485777378, 47.15247541666031, 48.81657712161541, 54.68841344118118, 51.75043769180775, 50.898747593164444, 44.41405735909939, 41.36071979999542, 30.559683479368687, 11.87342332676053, 11.73697454854846, 10.48625836148858, 8.353107925504446, 6.20969851501286, 2.561055924743414, 2.001187317073345, 2.854700842872262, 4.606368849053979, 4.902086555957794, 3.3937743538990617, 4.116225549951196, 3.961130459792912, 28.602892979979515, 25.727334581315517, 13.033114448189735, 17.216954044997692, 19.556883685290813, 12.295850459486246, 16.01576440036297, 12.74605980142951, 9.238087087869644, 12.68792387098074, 15.539459008723497, 20.010900422930717, 24.516784138977528, 28.904583491384983, 29.125507436692715, 16.960325315594673, 8.320505674928427, 2.146324091590941, 1.1574919894337654, 1.3998738583177328, 3.6902337335050106, 1.0102553525939584, 0.8299716515466571, 1.0952267493121326, 1.5799104538746178, 11.859431527554989, 43.389035761356354, 28.73537477105856, 54.986815229058266, 55.75315050780773, 19.906537123024464, 40.45742467045784, 48.590360060334206, 2.924255635589361, 0.33871910884045064, 0.06611116812564433, 0.09504824818577617, 0.06101542632677592, 0.060541984348674305, 0.05203942106163595, 0.0451363530009985, 0.05878879033843987, 0.030757508939132094, 0.036867050439468585, 0.044011015925207175, 0.02170313473470742, 0.0704211239644792, 0.037391411169664934, 0.05242164566880092, 0.048860483439057134, 0.03490580274956301, 0.040912070689955726, 0.04089130168722477, 0.04060319253767375, 0.08570248639443889, 0.05542194463487249, 0.06510310151497833, 0.06947572430362925, 0.06420498408260755, 0.30124400567729026, 0.12857566005550325, 0.10404194254078902, 0.10545317345531657, 0.1550115243298933, 0.1700301590608433, 0.13598456484032795, 0.21540297515457496, 0.15797972911968827, 0.12787885760189965, 0.12020603026030585, 0.11941984354052693, 0.17726157180732116, 0.189836967329029, 0.15440533810760826, 0.12132921139709651, 0.18365738564170897, 0.13627098931465298, 0.21344726759707555, 0.2849961962783709, 0.12051729441736825, 0.17050434689735994, 0.19725354592083022, 0.14097245031734928, 0.19865460199071094, 0.1415445125894621, 0.21250174177112058, 0.19872369593940675, 0.21046142937848344, 0.42495850939303637, 5.559093626216054, 39.45881925523281, 84.9171669781208, 80.1135103404522, 90.36143884062767, 104.5693476498127, 87.82220229506493, 40.866028144955635, 4.191898489370942, 0.24371343024540693, 0.293354204040952, 1.2900101160630584, 0.9816809452604502, 2.3988533159717917, 2.326553645543754, 1.366277129855007, 15.820213593542576, 35.66149681806564, 55.86626663804054, 49.31720785796642, 57.209562957286835, 44.5727064460516, 40.16367383301258, 39.7779755294323, 41.13810494542122, 27.453148774802685, 26.1382008343935, 50.78743636608124, 23.49683526903391, 18.02997551858425, 30.32856658101082, 24.248566031455994, 21.6893482580781, 34.18512403964996, 17.415335699915886, 23.119572512805462, 28.850801177322865, 23.8037770986557, 20.512416511774063, 10.82385504618287, 3.7542975833639503, 2.2956962138414383, 1.6615082253701985, 1.4697415404953063, 0.8553777413908392, 1.8062409153208137, 4.319846648722887, 8.02233187481761, 8.779869675636292, 19.90015536546707, 39.88323748111725, 58.00658918917179, 64.54818516969681, 65.43996691703796, 65.20727500319481, 75.80056697130203, 68.69741812348366, 68.22619020938873, 55.71570351719856, 48.40505160391331, 58.031253665685654, 55.71793779730797, 49.234098717570305, 52.01136589050293, 52.913737669587135, 52.6459926366806, 57.3236670345068, 56.56453236937523, 63.97611826658249, 58.44505526125431, 55.03913462162018, 51.844266057014465, 41.23287945985794, 33.792536705732346, 16.008504889905453, 11.584692019969225, 10.364818777889013, 7.689512483775616, 5.150766586884856, 5.0948321633040905, 3.5644533578306437, 10.109973102807999, 16.694917157292366, 18.83154820650816, 16.001680456101894, 13.438466247171164, 1.9082659156993032, 28.993190936744213, 25.35316675901413, 6.549899959936738, 10.757888685911894, 13.85187266394496, 8.252709712833166, 16.596496738493443, 12.635223548859358, 14.116732701659203, 19.023663997650146, 19.215019829571247, 21.389128267765045, 28.581367135047913, 37.29358144104481, 46.67601898312569, 32.49560169875622, 19.110751524567604, 2.0112363528460264, 1.8422933807596564, 1.1955817393027246, 5.826167520135641, 14.201517552137375, 4.6536919847130775, 1.3485587993636727, 2.7035953011363745, 16.301376074552536, 55.91070145368576, 32.277884781360626, 92.78991892933846, 64.78523164987564, 28.63477896898985, 64.61056262254715, 60.647253692150116, 1.6911625466309488, 0.45137000153772533, 0.1800637730048038, 0.1614821911789477, 0.17840554792201146, 0.22382847382687032, 0.15782036032760516, 0.23957755998708308, 0.275497151305899, 0.08529613827704452, 0.1344295873423107, 0.14986165770096704, 0.09948324848664925, 0.18909274163888767, 0.08493682005791925, 0.16936638217885047, 0.13800526969134808, 0.20975903113139793, 0.1421155803836882, 0.17481895600212738, 0.22892088338267058, 0.19675121584441513, 0.17310849856585264, 0.1321685453876853, 0.24429629818769172, 0.18289395316969603], [0.08405619504628703, 0.03331123538373504, 0.02275888247822877, 0.040487673541065305, 0.0524918528390117, 0.05178854175028391, 0.0583401249605231, 0.047333625916508026, 0.06033540383214131, 0.04376010321720969, 0.09736103267641738, 0.09225824047462083, 0.03148711803078186, 0.06154270740807988, 0.04416594667418394, 0.10903359070653096, 0.04078678502992261, 0.03636393368651625, 0.05965543328784406, 0.06673904732451774, 0.11328393724397756, 0.09598265663953498, 0.029969262759550475, 0.04682683924329467, 0.022677329725411255, 0.016455139484605752, 0.0921605812618509, 0.07535728916991502, 0.08274772932054475, 0.11928738502319902, 1.1384246125817299, 14.192087408155203, 26.55953172594309, 27.68070336431265, 33.74917343258858, 44.420296624302864, 50.521500036120415, 36.84304341673851, 22.133229039609432, 0.4802602669224143, 0.31258292379789054, 0.357542140991427, 0.2140713098924607, 0.2535530616296455, 1.5214490471407771, 0.23717405536444858, 0.7957237923983485, 13.655946627259254, 28.197992406785488, 37.89901055395603, 36.62415236234665, 34.23436939716339, 29.029900766909122, 27.686015479266644, 22.02567581087351, 24.40553180873394, 8.399978410452604, 29.727543331682682, 27.462676763534546, 13.9994434453547, 24.274085462093353, 18.095115423202515, 3.4621381480246782, 24.479806423187256, 9.74681043997407, 8.857541307806969, 8.793755080550909, 6.105744643136859, 2.715764860622585, 0.2841818821616471, 0.2627817273605615, 0.23937151010613889, 0.6011195504106581, 0.5076661775819957, 0.0918667353107594, 0.21955012605758384, 2.122717145830393, 1.9711606157943606, 4.843936376273632, 13.254517167806625, 27.981827706098557, 44.54341761767864, 62.44461804628372, 65.08348524570465, 62.69366428256035, 64.38784897327423, 52.83431813120842, 35.064184069633484, 22.59732473641634, 13.606980554759502, 18.975159600377083, 16.40001118183136, 16.361570544540882, 16.333453953266144, 17.494937628507614, 27.04310517758131, 33.13893377780914, 38.008767664432526, 38.40135499835014, 30.49442958086729, 35.58160610496998, 28.498592376708984, 22.43293795734644, 16.3050751760602, 5.640123328194022, 6.5680150128901005, 5.5634961649775505, 5.758496951311827, 2.113761738874018, 3.061446798965335, 1.859870406333357, 5.102474978193641, 4.607057562097907, 4.79377431795001, 3.135125320404768, 2.464259206317365, 0.131165414059069, 26.795953139662743, 13.320415131747723, 1.6462182020768523, 10.235528815537691, 8.679567407816648, 9.106057472527027, 10.982506033033133, 3.570286757312715, 5.584258725866675, 1.2675381219014525, 4.837680486962199, 18.29135589301586, 28.058720380067825, 32.70362913608551, 21.517660170793533, 10.065163057297468, 3.8006721949204803, 0.6817602482624352, 0.7174776785541326, 3.10095707885921, 4.358305810019374, 0.3731623903149739, 0.5983938497956842, 1.36147596873343, 8.5796251706779, 27.961827479302883, 15.059263575822115, 35.95911584794521, 45.04827372729778, 9.133022725582123, 21.88982930034399, 58.53180840611458, 17.385594695806503, 0.19776328263105825, 0.0615561143058585, 0.08330113400006667, 0.03790482151089236, 0.04305356749682687, 0.028301606835157145, 0.05031779430282768, 0.18876012589316815, 0.06981482642004266, 0.018606250814627856, 0.022913698194315657, 0.04556326231977437, 0.07054057263303548, 0.006617883436774719, 0.02078504239761969, 0.04979927427484654, 0.048297887260559946, 0.05306991908582859, 0.08530594946932979, 0.04574378232064191, 0.11216044440516271, 0.09173092970740981, 0.05918392831517849, 0.038714771799277514, 0.03318579387268983, 0.04201872790872585, 0.11168749595526606, 0.041627248720033094, 0.05475897669384722, 0.03718786974786781, 0.040248186196549796, 0.009202273104165215, 0.03893909706675913, 0.018047452576865908, 0.05860727214894723, 0.08677756894030608, 0.08718086683074944, 0.1394642874947749, 0.041612628410803154, 0.059629387615132146, 0.02619814138597576, 0.04034262819914147, 0.03534229319484439, 0.07960745759191923, 0.11124794415081851, 0.06587687210412696, 0.044530200175358914, 0.025892836674756836, 0.04695424373494461, 0.023052852739056107, 0.04758754061185755, 0.03447853719990235, 0.0497276199166663, 0.1439408925944008, 0.06833160718088038, 0.11309457826428115, 1.69549775775522, 17.23472949117422, 39.354085475206375, 54.55949015915394, 63.44644568860531, 72.29178965091705, 72.55879372358322, 61.703999787569046, 27.26495247334242, 0.6274595588911325, 0.3704700863454491, 0.11790908320108429, 0.5238749796990305, 1.7683897214010358, 0.02734600264375331, 0.23150167224230245, 0.9230539505369961, 5.421971809118986, 11.399971581995487, 23.898452818393707, 31.17481157183647, 38.18476662039757, 36.85905575752258, 39.82465222477913, 39.64224301278591, 32.49918110668659, 23.876619189977646, 44.54254746437073, 33.976234048604965, 27.956901043653488, 38.67351159453392, 24.62792057543993, 10.375740341842175, 26.251664645969868, 15.673867296427488, 11.03518545627594, 13.35046961903572, 12.026086784899235, 7.193954950198531, 1.0879243724048138, 1.0631942306645215, 1.3444057409651577, 0.9090071136597544, 0.3396746685029939, 0.41992823244072497, 0.814199885353446, 3.172349310480058, 4.5647230837494135, 7.898905947804451, 16.69119905680418, 35.29037073254585, 49.22282852232456, 68.32908108830452, 70.39410308003426, 69.94929894804955, 76.38158619403839, 66.87519550323486, 47.10160754621029, 35.31023986637592, 19.104495160281658, 31.852117627859116, 33.0671252310276, 27.728841081261635, 28.35418112576008, 29.868481568992138, 38.57415072619915, 44.18818987905979, 48.58162432909012, 45.75877100229263, 37.06455633044243, 38.473250940442085, 31.4959779381752, 26.743614748120308, 19.446307718753815, 9.97419498860836, 5.538559053093195, 6.895978264510632, 5.992375826463103, 2.2514611249789596, 2.035057037137449, 2.019010023213923, 1.9831962324678898, 1.9505091989412904, 5.24714176543057, 2.9363377997651696, 3.248700750991702, 0.9675921325106174, 38.823265358805656, 26.720559485256672, 7.654613256454468, 21.70125111937523, 21.502124704420567, 19.848751723766327, 29.372140802443027, 8.624903541058302, 13.157125543802977, 13.022102639079094, 20.37002295255661, 26.26877322793007, 30.311868377029896, 26.50814328342676, 12.364395931363106, 4.937458857893944, 4.302976978942752, 1.7385587096214294, 2.9389066994190216, 3.206827947869897, 3.680812851525843, 1.626260841730982, 1.0271713323891163, 2.0950116449967027, 10.085482466965914, 48.591739386320114, 31.040456481277943, 46.0360649228096, 67.4255883693695, 27.979671321809292, 26.703103221952915, 67.89021983742714, 27.412775941193104, 0.5805509572383016, 0.02748216262261849, 0.06551079291966744, 0.06738314987160265, 0.11175435603945516, 0.025147221313090995, 0.012108820264984388, 0.13592553441412747, 0.04281119319784921, 0.02812121485476382, 0.050322562601650134, 0.02531392252421938, 0.050237208197358996, 0.043311018525855616, 0.04938007958116941, 0.0488301704172045, 0.06439219825551845, 0.10207806393736973, 0.04200600378680974, 0.09424090283573605, 0.06830192127381451, 0.02340948994969949, 0.05489740207849536, 0.04162469573202543, 0.015159424783632858, 0.05052602609794121, 0.18177777790697291, 0.19348520203493536, 0.11652598710497841, 0.08404461012105457, 0.14680087740998715, 0.135378185659647, 0.2248188402154483, 0.09545811408315785, 0.19692103407578543, 0.24741639092098922, 0.19065638742176816, 0.2710433449828997, 0.2935576712479815, 0.17829677875852212, 0.08518909831764176, 0.2683937887195498, 0.08145638494170271, 0.11763980975956656, 0.16449640912469476, 0.14289988204836845, 0.13022019993513823, 0.2540924842469394, 0.1244758878601715, 0.1937404414638877, 0.20193965930957347, 0.16477584256790578, 0.20268799649784341, 0.33337807981297374, 0.280786823714152, 0.19028322072699666, 1.2046193168498576, 20.902725867927074, 62.15661630034447, 78.95893469452858, 90.89455023407936, 93.906359821558, 103.54528740048409, 78.13271462917328, 44.17260691523552, 1.2262544059194624, 0.28323110193014145, 0.6078621698543429, 1.5142622077837586, 2.8443592227995396, 3.0126987397670746, 0.7079557457473129, 1.7298240470699966, 19.602125957608223, 35.2290990203619, 48.57128508388996, 49.56376142799854, 53.152273669838905, 42.62052319943905, 43.94570589065552, 37.787767723202705, 43.073899671435356, 25.579805597662926, 46.21731519699097, 42.78134196996689, 27.049975208938122, 43.58117625117302, 35.80892130732536, 14.089820645749569, 26.711023896932602, 15.72766100987792, 18.429712168872356, 14.794755019247532, 10.190281793475151, 5.326273944228888, 0.40642672567628324, 0.6379459868185222, 1.106720301322639, 1.1973460321314633, 0.4594638047274202, 0.7658812031149864, 0.7276743720285594, 2.6893847761675715, 5.261147813871503, 7.096962779760361, 15.318224430084229, 30.771341621875763, 48.35319198668003, 69.0403801202774, 69.20674279332161, 67.48615711927414, 72.75955215096474, 73.95210295915604, 57.705295756459236, 54.41183768212795, 32.562356516718864, 45.061189234256744, 47.69084572792053, 42.15464159846306, 45.34990154206753, 44.695774242281914, 51.9309888035059, 50.20700231194496, 57.46478386223316, 48.960319608449936, 43.09033378958702, 44.34532664716244, 32.347926422953606, 28.338030092418194, 19.113601371645927, 13.933528382331133, 5.733356075361371, 5.4679707158356905, 5.084466794505715, 1.2091159005649388, 3.9940749295055866, 3.4870918840169907, 8.160104881972075, 9.419980477541685, 17.653605714440346, 8.20396687835455, 2.9433256248012185, 0.29027500364463776, 37.566475197672844, 23.386587984859943, 2.620195713825524, 13.514518216252327, 13.016403894871473, 11.979800518602133, 23.86668462306261, 3.6097702011466026, 10.718553196638823, 12.573065534234047, 19.50548194348812, 32.124893590807915, 39.94369223713875, 40.705543756484985, 30.042985305190086, 15.068522728979588, 5.391124114394188, 0.9842514479532838, 3.753219391219318, 6.0535938665270805, 12.792481910437346, 3.187315994873643, 0.9740418114233762, 3.3522827178239822, 16.662345305085182, 59.97967891395092, 36.760785430669785, 78.7598329782486, 87.5491489470005, 31.60476990044117, 44.75674197077751, 93.5080423951149, 26.375522799789906, 0.46668095339555293, 0.1667051890399307, 0.15717705187853426, 0.18721399479545653, 0.22897427348652855, 0.25003272865433246, 0.1621781030553393, 0.37450843839906156, 0.17540534172439948, 0.1629604899790138, 0.14914386731106788, 0.191799710446503, 0.24889644118957222, 0.09358784998767078, 0.12440622987924144, 0.13804614718537778, 0.132646132260561, 0.1364987692795694, 0.2246610150905326, 0.15967486862791702, 0.1959896387415938, 0.2070992480730638, 0.11313920360407792, 0.11541750791366212, 0.2796247391961515, 0.15046494954731315], [0.021627598944178317, 0.0938868687080685, 0.1029579468013253, 0.021906744805164635, 0.10827192454598844, 0.029848468948330265, 0.08174692091415636, 0.03338423673994839, 0.02146349896065658, 0.042825579730561, 0.0273395422482281, 0.074136938637821, 0.06069034709071275, 0.10608492666506208, 0.04750152198539581, 0.07285674873855896, 0.03065498123760335, 0.08062200315180235, 0.07185071561252698, 0.055600702035008, 0.008994358577183448, 0.06873957318020985, 0.05039802046667319, 0.16655333078233525, 0.008769633477641037, 0.11178337401361205, 0.04209818966046441, 0.20075667591299862, 0.10827209523995407, 0.28155108739156276, 0.7622692594304681, 3.7112793792039156, 23.70604634284973, 28.444981053471565, 35.58920569717884, 36.827954426407814, 46.352466344833374, 45.471229031682014, 41.20544873178005, 31.751744113862514, 0.16698594350600615, 0.2972139063058421, 1.0362375271506608, 0.53661830839701, 0.3485093725612387, 0.601439030142501, 0.15794738632394, 0.25716372882016003, 6.358453882858157, 24.77035403251648, 33.90502966940403, 39.82627093791962, 33.78061294555664, 40.14512702822685, 29.07457496970892, 33.425578996539116, 29.343800023198128, 13.691471870988607, 35.417705699801445, 25.230623334646225, 11.372978780418634, 11.459432691335678, 5.393968736752868, 19.26360972225666, 29.949137941002846, 5.360596077516675, 8.050065636634827, 8.389852903783321, 3.676156676374376, 0.7314275612588972, 0.7128170505166054, 1.0767724458128214, 0.5167826602701098, 0.44345962756779045, 0.938719738041982, 0.8416456345003098, 1.94016128545627, 2.6803265372291207, 3.224410079419613, 6.093547297641635, 15.855579245835543, 43.36629398167133, 45.673860758543015, 60.69370999932289, 58.85646678507328, 55.10489009320736, 34.70864474773407, 19.070969559252262, 10.550308674573898, 4.744215002283454, 6.956842923536897, 16.084132231771946, 10.841070972383022, 6.584621071815491, 15.420409496873617, 20.04733856767416, 33.93924683332443, 31.248637810349464, 26.350387148559093, 18.7299245595932, 18.45304861664772, 16.14463448524475, 6.9591147266328335, 2.861357373185456, 1.4124944061040878, 1.7718638037331402, 4.657824262976646, 1.3549936353228986, 0.7198481576051563, 0.7171396154444665, 2.317955894395709, 2.196731949225068, 2.0204938435927033, 0.37922143237665296, 0.15764340263558552, 0.11382121505448595, 2.9934359109029174, 18.570171631872654, 6.971817445009947, 0.25191113410983235, 1.3736997940577567, 1.163547202013433, 7.465938655659556, 6.41239863820374, 0.5208162032067776, 1.2625397276133299, 7.048736242577434, 19.905361086130142, 25.339324101805687, 24.82306480407715, 15.210840292274952, 6.429714309051633, 2.261345819570124, 1.1618172260932624, 2.0359784876927733, 0.4198262613499537, 2.3677040124312043, 1.5600698185153306, 0.4482193768490106, 0.9358820621855557, 10.15503203496337, 38.23777377605438, 18.17265786230564, 33.813709169626236, 60.22246688604355, 23.266174346208572, 16.89261294901371, 38.42014878988266, 31.670831255614758, 0.7297872367780656, 0.06449362757848576, 0.0078060901614662725, 0.0734589718922507, 0.04077234283613507, 0.1901283790357411, 0.012659615367738297, 0.07960537215694785, 0.0802119294530712, 0.044030408243997954, 0.11477126798126847, 0.026314845963497646, 0.05274082854157314, 0.004716347557405243, 0.05555430667300243, 0.09379077542689629, 0.04693067312473431, 0.010698617224988993, 0.03578542957257014, 0.08092367876088247, 0.07670104401768185, 0.04701070633018389, 0.05342012373148464, 0.0676244888745714, 0.07629321160493419, 0.0857469039328862, 0.117193266924005, 0.03299706942925695, 0.030260976891440805, 0.010315400922991103, 0.027934991449001245, 0.05660353279381525, 0.05301642508129589, 0.034180531511083245, 0.04172164248302579, 0.06871701189083979, 0.11541270621819422, 0.030201465924619697, 0.11294332114630379, 0.04298710817238316, 0.06341878994135186, 0.03335897774377372, 0.07272872084286064, 0.07550896189059131, 0.07904508776846342, 0.06118079167208634, 0.0835691457905341, 0.015378973403130658, 0.035357644519535825, 0.04369183305243496, 0.17226415715413168, 0.1442934721126221, 0.23347219306742772, 0.030681451789860148, 0.15670436318032444, 0.13057105767074972, 0.2952593861846253, 0.9229081927333027, 6.335070412606001, 42.252600342035294, 62.02912554144859, 68.20505574345589, 64.44224685430527, 76.38394206762314, 70.06507113575935, 69.74143490195274, 31.985262483358383, 0.11977635644143447, 0.24927927064709365, 0.6001624767668545, 0.8816359948832542, 0.19357231532922015, 1.1329892417415977, 0.26349730615038425, 0.889502641512081, 4.7695396933704615, 13.106867540627718, 16.872905306518078, 23.03405050188303, 32.841196954250336, 39.90905709564686, 37.74649053812027, 44.896236285567284, 36.631960943341255, 30.471621304750443, 52.94481240212917, 29.631750471889973, 28.771799616515636, 23.66757530719042, 17.59830918163061, 27.62472476810217, 36.97348661720753, 15.520245339721441, 11.080164592713118, 12.592843472957611, 7.636586548760533, 3.5476098116487265, 4.539586482569575, 3.2101154839619994, 0.192348187265452, 0.38178448390681297, 0.38413551868870854, 0.8816279796883464, 3.219953393563628, 2.1806557243689895, 3.983556143939495, 9.045325331389904, 20.141712203621864, 48.667511120438576, 52.01796233654022, 69.61780473589897, 68.51974725723267, 67.04571515321732, 48.43262292444706, 28.59545487910509, 24.67014390975237, 8.773325476795435, 9.149150010198355, 33.497060760855675, 20.020971782505512, 20.370431430637836, 27.217398025095463, 36.598070561885834, 48.2504341006279, 35.32087929546833, 29.76127602159977, 20.000842362642288, 20.682286396622658, 16.835817396640778, 8.25427332893014, 2.967006666585803, 1.9640439539216459, 2.127547161653638, 4.254424134269357, 0.9285546897444874, 0.5537047446705401, 0.5720805586315691, 1.742210432421416, 1.1166076082736254, 0.3830967494286597, 0.3852998890215531, 1.1966120777651668, 0.35542200319468975, 9.801844786852598, 26.438054144382477, 14.544281009584665, 0.5225610814522952, 6.579023972153664, 5.350498119369149, 21.981100402772427, 24.090010039508343, 12.701817825436592, 16.31063997745514, 21.547862850129604, 28.857844099402428, 23.136565200984478, 17.901608906686306, 9.165762718766928, 4.730822145938873, 2.340865577571094, 2.4570106202736497, 1.8137583369389176, 1.5484685660339892, 2.476537059992552, 0.4883563856128603, 0.45105607307050377, 1.0948512819595635, 9.640494044870138, 65.13186424970627, 32.849822491407394, 41.424993351101875, 72.08801418542862, 45.820411294698715, 26.096870452165604, 50.80073185265064, 53.36470887064934, 1.7677747481502593, 0.11972926717135124, 0.035030587459914386, 0.05633852670143824, 0.012468257227737922, 0.19550850440282375, 0.06299750239122659, 0.14907579752616584, 0.07139705558074638, 0.09106336045078933, 0.028962435535504483, 0.14025666372617707, 0.048355481631006114, 0.09395409244461916, 0.005126345185999526, 0.07906991260824725, 0.024389479258388747, 0.03949678022763692, 0.04497313617321197, 0.03443238674663007, 0.1161906254128553, 0.07400384187349118, 0.06763717959984206, 0.10186456289375201, 0.14504348655464128, 0.03653404506621882, 0.13847546477336437, 0.12066270341165364, 0.15779453358845785, 0.21304278227034956, 0.1124532958783675, 0.1142652345879469, 0.1759224256966263, 0.22326877573505044, 0.06517835528939031, 0.18761422019451857, 0.28018672310281545, 0.12628478376427665, 0.20651770115364343, 0.22647025238256902, 0.2878457464976236, 0.12872593011707067, 0.36256274033803493, 0.1158213549933862, 0.18761659506708384, 0.14300416863989085, 0.19131482084048912, 0.06774589681299403, 0.223062384466175, 0.10636196297127753, 0.26167405711021274, 0.18055320455459878, 0.20672812970587984, 0.12692705320660025, 0.3023107984336093, 0.2913870970951393, 0.5839536746498197, 0.6818102393299341, 3.283482897095382, 52.27586969733238, 88.54905009269714, 93.7327167391777, 88.1519865989685, 96.5567784011364, 88.35520729422569, 77.11975738406181, 57.41953209042549, 0.2729956089751795, 0.20270334411179647, 4.297514297068119, 2.0019612880423665, 0.8309632795862854, 3.1821287982165813, 0.2981621929211542, 1.1107857269234955, 12.215955946594477, 34.49095442891121, 44.07864935696125, 56.40365280210972, 48.71900215744972, 55.25551401078701, 40.743256732821465, 48.91384810209274, 46.39334075152874, 26.02726388722658, 53.90587203204632, 34.37739372253418, 29.364539310336113, 26.408242844045162, 14.327135011553764, 18.360639475286007, 25.766075402498245, 10.82964213564992, 7.770725525915623, 8.225093744695187, 3.470098958350718, 1.703178333118558, 3.2988117495551705, 3.5688532842323184, 1.1633747862651944, 0.5008368159178644, 0.9910246438812464, 2.2406229190528393, 4.064867505803704, 5.2097550965845585, 5.743654947727919, 10.644345078617334, 19.165573082864285, 47.473698779940605, 49.93352718651295, 67.024345099926, 70.27542784810066, 71.9234374165535, 63.211181312799454, 48.41342635452747, 45.73909945785999, 11.581609435379505, 17.51282326877117, 52.502170354127884, 35.12306571006775, 38.961942717432976, 42.98597998917103, 50.74235558509827, 59.59781840443611, 42.8011617064476, 36.935325264930725, 26.101604998111725, 25.955622531473637, 18.455163203179836, 9.822522327303886, 3.270951407030225, 2.8459235513582826, 2.494701985269785, 5.730996876955032, 1.5709877014160156, 0.6918171211145818, 0.3671479067998007, 4.538905369117856, 3.6274150293320417, 2.855905615724623, 0.7092283805832267, 0.7124724565073848, 0.12732212810078636, 5.74400975368917, 23.39256316423416, 9.872127715498209, 0.09569592788466252, 2.871686168946326, 1.3334265863522887, 17.8448798507452, 15.301742814481258, 6.459574056789279, 9.62137347087264, 19.629879668354988, 32.65072077512741, 33.95963653922081, 29.414791613817215, 23.279255144298077, 13.250720221549273, 3.260724018327892, 2.3999353079125285, 5.58200117200613, 1.6976829967461526, 7.602794487029314, 6.886476399376988, 2.2258865972980857, 1.3156054238788784, 16.618503257632256, 75.42259365320206, 38.42623986303806, 68.40908199548721, 99.68933030962944, 54.38080094754696, 39.431004747748375, 72.50016286969185, 55.42901650071144, 0.8172474999446422, 0.17800732632167637, 0.1303943819948472, 0.16203791135922074, 0.10548879654379562, 0.2897183335153386, 0.12101704924134538, 0.40161995391827077, 0.21247273863991722, 0.19211941282264888, 0.27095983852632344, 0.1710845431080088, 0.09832886004005559, 0.2018095608218573, 0.18541036813985556, 0.20395724714035168, 0.1801261876244098, 0.10199229393037967, 0.21520214999327436, 0.10947231130558066, 0.2341917052399367, 0.1480150903807953, 0.39048257342074066, 0.15195638436125591, 0.24368711368879303, 0.18912034953245893, 0.34833398822229356], [0.07345380654442124, 0.01734992467390839, 0.02197828041971661, 0.05465527268825099, 0.045610711531480774, 0.07530044065788388, 0.02181658499466721, 0.025196909955411684, 0.029876967419113498, 0.04245301788614597, 0.04949670437781606, 0.022740310232620686, 0.027897657710127532, 0.03486717767373193, 0.038403366634156555, 0.12839944451116025, 0.12184439547127113, 0.11658365940093063, 0.07276916789123788, 0.12738194520352408, 0.01125792476159404, 0.08128035493427888, 0.06167174091388006, 0.05229509093624074, 0.06197055925440509, 0.024253556766780093, 0.006186730888657621, 0.14988585171522573, 0.11465337782283314, 0.1587360369740054, 0.18089579476509243, 0.9129534394014627, 5.322152590379119, 34.135981276631355, 28.181848973035812, 31.044109985232353, 41.290389373898506, 56.605235785245895, 40.189455449581146, 41.30077041685581, 30.818660482764244, 1.1765078315511346, 0.21114994946401566, 2.1072301268577576, 0.24678697547642514, 0.3892720415024087, 0.9565981349442154, 0.07828385947505012, 0.1310846980777569, 3.311095302924514, 16.391288749873638, 29.456752762198448, 30.002046301960945, 31.99335604906082, 36.982849314808846, 22.774228043854237, 33.942001685500145, 19.730944745242596, 20.79632967710495, 50.167001858353615, 21.143266260623932, 7.755985641852021, 1.6438586474396288, 7.19692544080317, 29.611944034695625, 21.730249263346195, 10.385351926088333, 13.538610823452473, 6.772806448861957, 2.557953391224146, 1.6891935397870839, 0.2397973692859523, 1.537040916737169, 0.18287805636646226, 0.2736444241600111, 0.38568322313949466, 1.1953522078692913, 2.1638556383550167, 2.402816265821457, 3.7950216606259346, 12.763308975845575, 21.679164804518223, 37.45480678975582, 49.55590344965458, 44.65126343071461, 37.09113210439682, 19.174120724201202, 9.0618297457695, 7.2626566886901855, 5.127575006335974, 1.1151824472472072, 7.630582870915532, 10.280964877456427, 8.145024441182613, 12.616270165890455, 27.17475101351738, 34.23024281859398, 18.748264275491238, 11.327240634709597, 7.91224418208003, 3.2528755394741893, 1.9413469405844808, 0.2493035834049806, 0.35553795634768903, 0.3772048093378544, 0.15269260969944298, 0.335459922789596, 0.6866028509102762, 1.609530933201313, 0.8400830277241766, 0.23485450248699635, 0.32364404120016843, 0.32708196609746665, 0.680555950384587, 0.8362866751849651, 0.8063139428850263, 8.037635553628206, 18.790588304400444, 4.287213049829006, 1.0763302445411682, 3.258880879729986, 1.5286525106057525, 1.699817175976932, 9.183817449957132, 13.452597688883543, 12.33575876802206, 13.386871665716171, 18.18032395094633, 20.12340858578682, 16.129828579723835, 7.3625001311302185, 1.8485040287487209, 0.18229658366180956, 4.023485351353884, 1.4377879863604903, 3.8694076566025615, 1.6643340862356126, 0.86807481944561, 0.836536274291575, 15.53875794634223, 33.078745007514954, 17.830144241452217, 35.049478858709335, 68.4358249604702, 33.45698431134224, 18.727948665618896, 39.29505184292793, 38.57286639511585, 1.4710719441063702, 0.3333355992799625, 0.044023009031661786, 0.20404246053658426, 0.005340232610251405, 0.08974625612609088, 0.03867891864501871, 0.15121122356504202, 0.024578021875640843, 0.040473613553331234, 0.00995691762000206, 0.008986016837297939, 0.02963752645882778, 0.019554696991690435, 0.056966773263411596, 0.04237916677084286, 0.04882065608398989, 0.06759267300367355, 0.12557986221509054, 0.04508072532189544, 0.09135265703662299, 0.05938027832598891, 0.02221749131422257, 0.07295872725080699, 0.03834651070064865, 0.028085302328690886, 0.0754932951531373, 0.07418648441671394, 0.07244476029882208, 0.06060004627215676, 0.09294170653447509, 0.04398168995976448, 0.09616958137485199, 0.04293568847060669, 0.01222459623022587, 0.03538895573001355, 0.03853957670798991, 0.01069586478479323, 0.07418170498567633, 0.08003706461749971, 0.0646471705113072, 0.06437481715693139, 0.024761410277278628, 0.02729228785028681, 0.09077333656023256, 0.033189107562066056, 0.09551105147693306, 0.048909038450801745, 0.013731562339671655, 0.03383395967830438, 0.02814382252836367, 0.04870399417995941, 0.03863174773869105, 0.018759129525278695, 0.022620904237555806, 0.03746912145288661, 0.09129606827627867, 0.07151632613386028, 0.13683767843758687, 0.4485123173799366, 14.028699025511742, 59.45548564195633, 60.38764402270317, 64.81844186782837, 68.12781348824501, 76.27650663256645, 59.56310346722603, 74.4810801744461, 32.53382004797459, 0.4904574353713542, 0.1909980722120963, 0.7628413068596274, 0.3946265479316935, 0.05099007619719487, 1.4313476881943643, 0.35455122648272663, 0.40012348734308034, 2.3273086175322533, 13.194063361734152, 13.882526569068432, 12.277994267642498, 19.586107917129993, 30.26188585907221, 29.633133597671986, 42.3231815546751, 26.983332484960556, 39.96527127921581, 47.11657114326954, 29.890852868556976, 26.489083506166935, 14.470468070358038, 23.416471481323242, 45.31029626727104, 36.82215973734856, 16.750192791223526, 10.133391246199608, 9.102445766329765, 3.0187753261998296, 1.6041752393357456, 2.381595354527235, 1.9623884302563965, 0.4942026094067842, 0.3869986056815833, 0.4337248468073085, 2.6324008964002132, 2.7095578936859965, 3.0145775014534593, 5.2051635179668665, 16.75141252577305, 27.097345367074013, 42.907214015722275, 57.41678483784199, 55.30705064535141, 55.18665790557861, 38.122104182839394, 25.476707629859447, 16.520023941993713, 10.043413024395704, 1.2976784608326852, 12.490698304027319, 21.37876622378826, 20.843583941459656, 30.21180834621191, 35.92836029827595, 36.5930700302124, 18.889193013310432, 12.411385159939528, 8.821571487933397, 4.930310491472483, 2.6199824502691627, 0.6690965371672064, 0.24677418085047975, 0.36434971319977194, 0.500043430365622, 0.49788965843617916, 1.287818227428943, 1.7357155121862888, 0.37036565132439137, 0.3310353570850566, 0.03742569468158763, 0.1187614472291898, 0.335154811036773, 2.081752731464803, 6.360581768676639, 19.977093636989594, 22.0090327039361, 3.940767589956522, 0.8875424216967076, 4.280413314700127, 7.047146502882242, 12.31436401605606, 16.859235540032387, 24.593616016209126, 18.71726553887129, 17.050785161554813, 11.545797307044268, 10.007937178015709, 6.750054694712162, 4.6307773143053055, 2.6741395192220807, 0.5911219900008291, 0.5977050773799419, 0.7381970167625695, 1.3203677558340132, 0.8386307931505144, 0.5945448344573379, 1.5359991788864136, 11.868034265935421, 62.07918405532837, 33.9569690823555, 39.877575784921646, 70.51491379737854, 56.031246185302734, 36.75982408225536, 46.572865918278694, 56.51518441736698, 6.919907005503774, 0.43781853339169174, 0.07670472507015802, 0.1686771199456416, 0.03675722000480164, 0.09533804943202995, 0.03364499774761498, 0.13177369313780218, 0.04169104744505603, 0.061937333302921616, 0.0715588586172089, 0.008030344924918609, 0.020618704838852864, 0.08866346266586334, 0.012155544027336873, 0.10712172181229107, 0.005805380624224199, 0.0646620208863169, 0.06706896165269427, 0.06961415710975416, 0.03426834613492247, 0.04158447132795118, 0.012830367777496576, 0.07452684076270089, 0.01795469524950022, 0.06412492861272767, 0.034360862264293246, 0.08902502959244885, 0.2501105354167521, 0.12458826386136934, 0.23121940379496664, 0.10928987656370737, 0.16750169161241502, 0.14398421917576343, 0.09912226785672829, 0.11468658893136308, 0.1533493510214612, 0.09896872492390685, 0.20531819754978642, 0.23510110331699252, 0.11464135503047146, 0.14028062025317922, 0.14111014839727432, 0.19004828645847738, 0.36704774654936045, 0.21223759657004848, 0.22225158812943846, 0.29543002077843994, 0.12865376367699355, 0.1527192973298952, 0.13967121310997754, 0.11828970848000608, 0.08306493065902032, 0.12588056561071426, 0.20517950499197468, 0.21803448238642886, 0.2510745852487162, 0.20076029759366065, 0.312794495257549, 1.0081037180498242, 11.733271647244692, 79.915601760149, 81.72006413340569, 85.21689489483833, 90.38842499256134, 104.52816545963287, 79.91696208715439, 81.29189550876617, 60.533905774354935, 1.4406904368661344, 0.229351477464661, 4.164200350642204, 2.046394203789532, 0.5636282090563327, 2.0467737084254622, 0.40386376320384443, 0.6133261579088867, 4.375802921131253, 23.790171928703785, 40.9845057874918, 41.11740745604038, 43.036057502031326, 50.6242161244154, 34.246942922472954, 50.03095395863056, 28.500410579144955, 35.590178444981575, 60.727182403206825, 36.10430985689163, 22.9355388879776, 11.70338625088334, 15.589469075202942, 30.07195495069027, 30.902048908174038, 17.46716681867838, 13.199959695339203, 7.744641350582242, 2.261649565771222, 3.317437400110066, 3.746358146890998, 2.350490936078131, 0.7426762639079243, 1.7689235927537084, 2.115535531193018, 5.137420753017068, 5.00710959546268, 4.192296992987394, 6.393563048914075, 17.997223176062107, 26.18122022598982, 44.26169693470001, 58.46962854266167, 62.55923509597778, 63.80715653300285, 56.68004997074604, 38.116643875837326, 33.548221215605736, 13.002267703413963, 1.689186890143901, 19.80480708181858, 34.8242649435997, 33.893501088023186, 41.73549368977547, 49.30965006351471, 44.8453114181757, 23.10840681195259, 15.246950704604387, 11.490922551602125, 6.8934305012226105, 3.8020510459318757, 0.9890207857824862, 0.5972923245280981, 0.9734222665429115, 0.9916487010195851, 0.5205718881916255, 1.2414520466700196, 2.9725522315129638, 0.7281755295116454, 0.41770012699998915, 0.5621449823956937, 0.6457862129900604, 0.8854420843999833, 2.197476946748793, 2.8480390878394246, 19.76093463599682, 22.090792916715145, 3.645991045050323, 0.39863447193056345, 2.8012609854340553, 6.812190860509872, 17.972471304237843, 14.474455006420612, 24.071997106075287, 18.02519727498293, 22.81926892697811, 22.880916818976402, 24.898713044822216, 22.100928872823715, 11.040046345442533, 3.290599202737212, 1.8444832507520914, 8.098032362759113, 4.532270450145006, 10.813835933804512, 6.497820904478431, 1.8537251860834658, 2.2967896051704884, 26.952958814799786, 69.0167909860611, 37.106433883309364, 59.91833120584488, 102.91518241167068, 60.421112626791, 46.09490096569061, 69.24757540225983, 71.97446867823601, 5.091652683913708, 0.5487243400420994, 0.17594520963029936, 0.2986787573900074, 0.11189468132215552, 0.1868919175467454, 0.07729922988801263, 0.22945500706555322, 0.10874492494622245, 0.1814606730476953, 0.14266601647250354, 0.23453928268281743, 0.11069001237046905, 0.14181075064698234, 0.14343534159706905, 0.14479143836069852, 0.13016627548495308, 0.1447454994195141, 0.2573312760796398, 0.2212619935744442, 0.1731588607071899, 0.14583424490410835, 0.19038066471694037, 0.22174582933075726, 0.09547532448777929, 0.0941376478294842, 0.27667583024594933, 0.20578720519552007], [0.016001459043764044, 0.09709390404168516, 0.03772126241528895, 0.06792401967686601, 0.02749687570030801, 0.03550431145413313, 0.07202592183602974, 0.0985131946799811, 0.00894293887540698, 0.05165463233424816, 0.039230286129168235, 0.017337558638246264, 0.05575650851824321, 0.016374573788198177, 0.05471906028105877, 0.11206383162061684, 0.05835290103277657, 0.12654468388063833, 0.021908820963290054, 0.05593472786131315, 0.05112166269100271, 0.10694005148252472, 0.025404154694115277, 0.07318828837014735, 0.04969747387804091, 0.0723721411486622, 0.10615158636937849, 0.03636076100519858, 0.048827008868101984, 0.09579445541021414, 0.16333819861756638, 0.03401590460271109, 1.2201879126951098, 25.626241005957127, 43.89347389340401, 28.809484094381332, 27.549287416040897, 48.11887376010418, 53.38862858712673, 28.832442462444305, 42.179454267024994, 42.50979334115982, 2.6232376880943775, 0.1753619112423621, 0.7129154296126217, 0.6843854323960841, 0.730307511985302, 0.07192922741523944, 0.4878443037159741, 0.11905122621101327, 0.9811394743155688, 4.6495673060417175, 16.44795510917902, 20.76736383140087, 27.85784985870123, 20.598305203020573, 24.81524482369423, 30.281658098101616, 14.161023125052452, 31.723112650215626, 28.84320918470621, 11.228151451796293, 4.83105031773448, 12.29369217529893, 23.452301658689976, 32.24402479827404, 29.525504373013973, 15.26719031855464, 5.248244181275368, 0.31606617907527834, 0.2709830232197419, 0.9065969742368907, 0.6755704991519451, 0.3616985835833475, 0.45823350199498236, 0.749088479205966, 1.2064377567730844, 1.7468003486283123, 2.100314497947693, 1.3864262611605227, 1.344550489448011, 1.1568507738411427, 9.63303029537201, 20.098174139857292, 28.64831954240799, 34.04228210449219, 23.725163117051125, 12.456174306571484, 8.10731716454029, 2.626866730861366, 0.2772763167740777, 3.1400280073285103, 12.404806762933731, 11.88569476827979, 19.345094449818134, 28.983940333127975, 19.682915322482586, 10.454091187566519, 3.146417601965368, 0.9570120752323419, 0.6575537659227848, 0.12222461256897077, 0.018330878774577286, 0.0468975881813094, 0.0820358241617214, 0.22791427880292758, 0.10170858571655117, 0.44048293260857463, 1.5994510240852833, 0.7145640661474317, 0.2181851680506952, 0.48731215414591134, 0.22447613126132637, 0.10701768755097874, 0.29553306056186557, 0.7662760256789625, 8.066093176603317, 6.753501584753394, 3.5509980423375964, 4.5864474680274725, 6.632638145238161, 5.720171257853508, 5.971840303391218, 7.497703526169062, 12.19067020341754, 16.014088690280914, 13.610103987157345, 13.653205074369907, 9.749931022524834, 4.280484560877085, 0.8565135835669935, 0.4817591974278912, 2.0448066014796495, 1.182059096172452, 0.7549230067525059, 0.3492986020864919, 0.6142858439125121, 0.59620700776577, 17.822861932218075, 32.576848939061165, 13.850544635206461, 34.207892417907715, 72.43672147393227, 41.69724494218826, 18.576228506863117, 36.06372803449631, 60.71539543569088, 8.554736506193876, 0.23156531882705167, 0.0517684035730781, 0.025746368264663033, 0.11592113674851134, 0.08721007034182549, 0.039164850968518294, 0.06308106079814024, 0.06269659861573018, 0.05102976254420355, 0.06067056514439173, 0.04211187486362178, 0.06457072187913582, 0.028648930092458613, 0.049738228917703964, 0.04966782136762049, 0.01799735204258468, 0.040301902845385484, 0.0324170476233121, 0.03222167353669647, 0.0725119914568495, 0.020124191432842053, 0.05797863967018202, 0.0458291701215785, 0.011465020143077709, 0.01979974487767322, 0.07284887455170974, 0.05644555181788746, 0.004311040765969665, 0.06810649152612314, 0.025646256253821775, 0.05982425333058927, 0.08834696636768058, 0.10486402694368735, 0.1150017419422511, 0.04434753536770586, 0.049988161990768276, 0.024599423559266143, 0.032188447585213, 0.04249563571647741, 0.025474133653915487, 0.021697401643905323, 0.082438669342082, 0.06363687745761126, 0.08471052438835613, 0.014883032290526899, 0.04217159548716154, 0.05316241295076907, 0.05204519868129864, 0.030889718836988322, 0.020980444314773194, 0.01857752042269567, 0.04996188996301498, 0.06220755669346545, 0.03697850617754739, 0.057014222475118004, 0.028307505053817295, 0.04571538775053341, 0.07305877617909573, 0.13393763249041513, 0.13686074438737705, 2.4109361926093698, 37.43220180273056, 58.185308799147606, 51.28853067755699, 61.84350170195103, 75.1686304807663, 73.31303045153618, 48.13972324132919, 75.43514057993889, 44.81308534741402, 1.6005148482508957, 0.27264035772532225, 0.6190538755618036, 0.9650174144189805, 0.6899865693412721, 0.2707350271521136, 0.9679477696772665, 0.6243487726897001, 0.9226366854272783, 4.867548309266567, 11.528334394097328, 12.40108486264944, 12.331945672631264, 12.263326104730368, 21.144425198435783, 23.159595765173435, 20.262184739112854, 42.53108739852905, 25.69461453706026, 24.14280630648136, 20.311534591019154, 21.646150276064873, 37.10918873548508, 45.16806609928608, 24.703745506703854, 9.134363103657961, 3.305790312588215, 0.330749363056384, 0.25936835270840675, 0.7041015650611371, 0.18916527915280312, 0.1244360493728891, 0.4324513510800898, 0.9499870240688324, 1.2453052774071693, 2.14252358302474, 3.187370616942644, 1.6698340536095202, 1.3023410481400788, 0.36077716271393, 7.816281756386161, 20.353759825229645, 30.388504564762115, 42.805888652801514, 31.65205456316471, 20.74592348188162, 14.631328638643026, 3.868838637135923, 0.13525196118280292, 4.048792943358421, 16.837238520383835, 17.57045477628708, 29.641048572957516, 30.225960686802864, 19.991698153316975, 11.335079614073038, 3.5373377753421664, 1.733640229795128, 0.6639019784051925, 0.14023785770405084, 0.01878059429145651, 0.12895887542981654, 0.1576787733938545, 0.032160672708414495, 0.136448570410721, 0.6450296379625797, 0.7949556992389262, 0.5552805913612247, 0.3095556440530345, 0.21288241900037974, 0.3385985246859491, 0.4823892511194572, 2.221923409961164, 9.08314660191536, 17.20176436007023, 8.152782674878836, 0.9613268624525517, 3.7475415458902717, 5.786685738712549, 6.92847459577024, 10.53063428029418, 8.89533692970872, 10.594542101025581, 11.16426832973957, 5.648889932781458, 4.177947537973523, 6.702807554975152, 3.026855355128646, 1.7552944365888834, 1.3991093868389726, 1.1889146408066154, 0.7920809753704816, 1.0397680127061903, 0.9438361634965986, 0.46037875406909734, 0.9490073891356587, 16.130831725895405, 62.76701174676418, 30.534323640167713, 31.950688138604164, 70.80976277589798, 66.9620968401432, 40.625048875808716, 40.84279239177704, 76.48417308926582, 22.123704850673676, 0.21138849057024345, 0.48139073594938964, 0.07120402297005057, 0.10570875427220017, 0.07245603352203034, 0.11035198636818677, 0.14913628256181255, 0.06898293082485907, 0.032867946865735576, 0.07183430672739632, 0.07032428853563033, 0.06304049500613473, 0.05069896506029181, 0.03956209293392021, 0.027317745370964985, 0.05935771332588047, 0.013507489402400097, 0.07440456451149657, 0.041190357515006326, 0.0921762257348746, 0.02990669228893239, 0.08357771759619936, 0.03188050082826521, 0.0663300571613945, 0.006290804112722981, 0.11393488239264116, 0.03959573448810261, 0.023479773190047126, 0.1774264028063044, 0.21602244582027197, 0.20765879773534834, 0.08563010473153554, 0.29723890183959156, 0.21287345385644585, 0.14105275069596246, 0.1258468275773339, 0.1256432564696297, 0.12695525481831282, 0.22597926232265308, 0.12778138392604887, 0.1285679714055732, 0.14680362335639074, 0.17615455464692786, 0.2714050083886832, 0.15771524253068492, 0.26603651989717036, 0.21626036352245137, 0.16731355717638507, 0.11855599106638692, 0.28290832706261426, 0.20897005393635482, 0.16427186492364854, 0.09133560248301364, 0.14757705997908488, 0.1839360620942898, 0.12807427992811427, 0.16776022617705166, 0.2979152952320874, 0.36785380798392, 0.185250346257817, 1.463087503798306, 42.652787268161774, 90.90677037835121, 75.34608095884323, 71.18209719657898, 92.10619121789932, 108.51569429039955, 64.48281347751617, 78.67398038506508, 78.52514997124672, 3.717989819124341, 0.3045104054035619, 1.2901741010136902, 3.088493272662163, 1.138716721907258, 0.34992126398719847, 0.8474056504201144, 0.5260884203016758, 1.3122845208272338, 8.44022300094366, 24.363749250769615, 36.086089834570885, 39.195383191108704, 34.16411116719246, 34.731998294591904, 41.30062982439995, 24.190393052995205, 42.63315752148628, 40.5217058211565, 25.2125097066164, 16.175467930734158, 29.29058577865362, 35.41418328881264, 49.02492754161358, 43.48941497504711, 20.555397905409336, 5.748427016660571, 0.27404162159655243, 0.29850420425646007, 1.742063071578741, 0.7762718049343675, 0.34245056798681617, 0.8151577308308333, 2.3212194442749023, 2.044964055530727, 2.3071328876540065, 3.116753068752587, 3.2558253686875105, 1.9686390948481858, 1.9656256190501153, 10.87873075157404, 25.830476246774197, 35.88151641190052, 50.81912286579609, 40.84503427147865, 33.34500811994076, 22.706775963306427, 7.029203390702605, 0.2539783122483641, 6.9353199284523726, 22.089001312851906, 30.02106048166752, 41.200991570949554, 36.742014437913895, 24.04600840061903, 14.292480871081352, 4.312346326187253, 1.9898564438335598, 0.9989810013212264, 0.27276005130261183, 0.30701669747941196, 0.23597320105182007, 0.2433475514408201, 0.25439949589781463, 0.15792518126545474, 1.814122167415917, 4.6090087573975325, 2.2358755487948656, 0.7620620517991483, 1.6091150930151343, 0.7581847161054611, 0.5404343130066991, 1.1010855599306524, 7.467775382101536, 18.247335255146027, 6.148840980604291, 2.2311569144949317, 4.106395952403545, 7.432989673689008, 16.329665556550026, 19.490221962332726, 19.677441716194153, 21.01469825953245, 22.99090761691332, 20.192196294665337, 18.25276516377926, 13.262239303439856, 6.066953474655747, 2.928091767244041, 1.4871662179939449, 4.145767064765096, 3.3782377000898123, 2.9675505124032497, 1.9649466429837048, 1.9232692918740213, 0.8233848831150681, 35.96152111887932, 64.8273029923439, 29.206971265375614, 54.10427838563919, 102.83619225025177, 68.56364250183105, 42.95301675796509, 57.59934984147549, 100.23924440145493, 20.113806501030922, 0.29896249528974295, 0.4802633245708421, 0.18105379800545052, 0.30413879721891135, 0.12634069717023522, 0.17477099841926247, 0.23602627945365384, 0.16647013602778316, 0.10848616031580605, 0.16196687298361212, 0.12200337092508562, 0.12306674980209209, 0.23873434663983062, 0.10929240728728473, 0.11038012118660845, 0.15058612741995603, 0.16752695431932807, 0.19721165910596028, 0.10986387584125623, 0.16838419425766915, 0.13204270682763308, 0.24868760083336383, 0.1611522026360035, 0.21289234893629327, 0.09778161518624984, 0.20906110061332583, 0.13773582555586472, 0.06264081879635341], [0.07441128836944699, 0.0743714276177343, 0.0808168391813524, 0.02388421584328171, 0.02183368593250634, 0.08189402942662127, 0.0909280075575225, 0.047303316605393775, 0.0361730570148211, 0.10364181362092495, 0.04187036516668741, 0.055996853043325245, 0.05123617978824768, 0.06878633590531535, 0.014603755626012571, 0.041144210772472434, 0.062065253587206826, 0.03415767707338091, 0.009846602006291505, 0.04788922735315282, 0.020162853616056964, 0.061543738993350416, 0.04005365815828554, 0.0600179019238567, 0.029576967208413407, 0.0036983582003813353, 0.06675595344859175, 0.062222711349022575, 0.05933045053097885, 0.08273001425550319, 0.1091808921773918, 0.19753910950385034, 0.7642670616041869, 4.0720695443451405, 40.94844192266464, 47.59424351155758, 33.55116605758667, 28.429153002798557, 52.97730825841427, 64.05560240149498, 27.607021518051624, 41.89473934471607, 49.006779715418816, 8.489565253257751, 0.2624572307104245, 0.0597959403967252, 0.6005567056126893, 0.3134227084228769, 0.5573940498288721, 0.14363036316353828, 0.0575028525054222, 0.6136388098821044, 0.85728446720168, 5.699222031980753, 17.47928436845541, 19.54934298992157, 14.797324631363153, 24.572840631008148, 17.620068714022636, 7.3217397183179855, 16.591251119971275, 16.230112798511982, 10.884374398738146, 14.93118479847908, 24.195556975901127, 20.32707765698433, 22.550258561968803, 15.848053749650717, 5.755962487310171, 0.5321607913356274, 0.11044559345464222, 0.31294880260247737, 0.2155281457817182, 0.04286887291527819, 0.11974855558946729, 0.18337436020374298, 0.4127961042104289, 0.7887327612843364, 1.7640796839259565, 2.044004132039845, 2.852655602619052, 0.7852711470331997, 0.3032655268907547, 0.7157151668798178, 5.0197439175099134, 19.568930938839912, 16.63727805018425, 7.103831861168146, 4.473355561494827, 0.13275102741317824, 0.33436765952501446, 0.5671260401140898, 2.7681011147797108, 7.338274531066418, 15.477911811321974, 13.930925521999598, 6.5469779167324305, 1.9403097149915993, 0.23171039385488257, 0.10055541439214721, 0.0369073267938802, 0.05781387917522807, 0.08148579625412822, 0.019584145411499776, 0.05023523037380073, 0.033508958367747255, 0.03979242959758267, 0.1219569866952952, 0.10700717873987742, 0.05959403912129346, 0.04806703109352384, 0.08289346485980786, 0.23063270637067035, 0.11956638802075759, 0.2299857317120768, 0.40329118142835796, 3.1260946299880743, 2.287224093452096, 1.7141153337433934, 5.59603619389236, 3.20176899433136, 6.344504356384277, 4.336817488074303, 4.15910292416811, 9.623626749962568, 6.494952058419585, 5.6913740281015635, 3.324368940666318, 1.1351248458959162, 0.34571266325656325, 0.34810882061719894, 1.1059110634960234, 0.8178988087456673, 0.20382544171297923, 0.2628542500315234, 1.7128578387200832, 0.20182882697554305, 23.472015000879765, 29.3287281319499, 13.348096646368504, 34.61594112217426, 76.1755308508873, 53.3339799195528, 20.667193606495857, 32.65477895736694, 65.49318686127663, 20.08686024695635, 0.26339373202063143, 0.19327653979416937, 0.10604885086650029, 0.09931705193594098, 0.03002116300194757, 0.20346336270449683, 0.029347016461542808, 0.018632814135344233, 0.04994609706045594, 0.0111225969158113, 0.011964750847255345, 0.08803852979326621, 0.01271998165975674, 0.04239459231030196, 0.03292128872999456, 0.0036326243252915447, 0.051218772714491934, 0.04942606305121444, 0.041368895981577225, 0.015519885910180165, 0.07941332660266198, 0.06273130144109018, 0.10317235326510854, 0.06487736987764947, 0.029496106508304365, 0.01524068809885648, 0.03892093671311159, 0.010581410770100774, 0.06779781004297547, 0.09766740608029068, 0.05093816667795181, 0.06885160037199967, 0.08044436268392019, 0.03076469849474961, 0.14128229697234929, 0.01996652401430765, 0.06230864833923988, 0.017374773633491714, 0.0695831427583471, 0.06755817797966301, 0.037814053139300086, 0.06364688902976923, 0.05539517536817584, 0.01938499935931759, 0.06545738055137917, 0.08986639499198645, 0.029432934898068197, 0.05555857773288153, 0.009830951039475622, 0.06713024820783176, 0.013512929344869917, 0.08187438477762043, 0.14778558863326907, 0.07901466713519767, 0.03759001359867398, 0.04206228826660663, 0.16311252635205165, 0.06758131072274409, 0.13947589468443766, 0.07170244192820974, 0.16498849756317213, 1.1213014251552522, 8.91119347885251, 62.892803996801376, 60.37706159055233, 48.52064900100231, 61.0510466247797, 76.84117153286934, 71.95681482553482, 48.89634244143963, 79.45357695221901, 56.055789068341255, 4.14327297359705, 0.29392298602033406, 0.09908805484883487, 0.9137790638487786, 0.6262850656639785, 0.8740628825034946, 0.16644534829538316, 1.2002754374407232, 0.2455791598185897, 0.8166756306309253, 5.354523053392768, 11.273398473858833, 8.736611846834421, 5.770063530653715, 13.208948113024235, 9.675965141505003, 15.659040492027998, 22.10575081408024, 8.867895752191544, 9.130598455667496, 14.059981796890497, 22.457655631005764, 28.325599059462547, 25.10144166648388, 8.062132839113474, 0.19012613774975762, 1.2343562836758792, 1.0134062147699296, 0.7295288506429642, 0.33860630239360034, 0.12449882764485665, 0.1478305330965668, 0.24212032119976357, 0.5016454600263387, 0.8643236488569528, 1.8213838152587414, 2.3242284078150988, 3.01997606176883, 1.7784151271916926, 0.6922325456980616, 1.6666766605339944, 5.95133850350976, 19.697335548698902, 16.01279865950346, 6.196737885475159, 4.719614647328854, 0.49760960158891976, 0.5449309560935944, 0.7015040481928736, 4.024591566994786, 7.042638519778848, 14.525062590837479, 15.359074138104916, 8.66005165502429, 2.8887322917580605, 0.7341648393776268, 0.19553694350179285, 0.15151315892580897, 0.04167798564594705, 0.06623109176871367, 0.024517991405446082, 0.10717183162341826, 0.015484654304600554, 0.040535516091040336, 0.0518800374265993, 0.022439883287006523, 0.11279753365670331, 0.03069264337682398, 0.2083896944532171, 0.3523679467616603, 1.0484978067688644, 0.8523824927397072, 2.5423877639696, 4.808668093755841, 1.6755604650825262, 3.1747182458639145, 7.014638772234321, 5.124437799677253, 8.789365366101265, 9.187973476946354, 5.601152144372463, 6.090761572122574, 3.52098582778126, 4.531800700351596, 2.868664381094277, 2.1079782117158175, 0.9435758180916309, 1.145040295086801, 2.643355233594775, 0.6941507896408439, 0.43872368638403714, 0.16942377988016233, 0.13585543114459142, 0.6540791492443532, 22.28075612336397, 58.59940677881241, 28.390205092728138, 25.66633265465498, 68.44041511416435, 77.91893810033798, 38.29320900142193, 34.446686804294586, 74.65621277689934, 48.99643287062645, 1.2319183582440019, 0.549412399996072, 0.09470856719417498, 0.23079971928382292, 0.03636776687926613, 0.04878051331616007, 0.008275967975350795, 0.057250221725553274, 0.10402379703009501, 0.014449047521338798, 0.037415052283904515, 0.06728134205332026, 0.06329552663373761, 0.037225886262604035, 0.046351300698006526, 0.018965131166623905, 0.019594093901105225, 0.054955174564383924, 0.012576617282320512, 0.019653916569950525, 0.040991710557136685, 0.08300944769871421, 0.08238757989602163, 0.049394647940061986, 0.03573728274204768, 0.06779338684282266, 0.030198753374861553, 0.012191120731586125, 0.01890864259621594, 0.26622238336130977, 0.3049689339241013, 0.2641656546620652, 0.23959713784279302, 0.10769299740786664, 0.3051199164474383, 0.163255330407992, 0.17527752905152738, 0.070473089144798, 0.17937373893801123, 0.1430167703074403, 0.0955688944668509, 0.14205119165126234, 0.1454167571500875, 0.11920657256268896, 0.10635576603817753, 0.13585765758762136, 0.19730154803255573, 0.1754029223229736, 0.20740824867971241, 0.1388115537702106, 0.13456784945446998, 0.24340665608178824, 0.24136865918990225, 0.19473160937195644, 0.12236288210260682, 0.1952780081774108, 0.3233280940912664, 0.276425993652083, 0.30992469924967736, 0.15564637229545042, 0.570412032539025, 0.7894075219519436, 4.561207797378302, 77.62134566903114, 90.9087386727333, 78.59234556555748, 70.16071200370789, 94.99396786093712, 112.81160697340965, 59.481730833649635, 76.03261291980743, 89.30360600352287, 11.806410122662783, 0.3830254735657945, 0.30152379535138607, 2.616798458620906, 0.8586222329176962, 1.2850243085995317, 0.24002240330446512, 1.2576280161738396, 0.8199059322942048, 0.9926973260007799, 7.025180831551552, 24.75610289722681, 28.19348204880953, 25.535515174269676, 34.05910760164261, 27.462976947426796, 17.125285863876343, 29.062024243175983, 25.432705990970135, 17.327404618263245, 24.408966824412346, 39.2744417488575, 36.33947543799877, 32.899816408753395, 18.663369230926037, 9.959987550973892, 1.325251325033605, 1.717736420687288, 1.574096290860325, 0.47595975862350315, 0.1780339248944074, 0.3138989594299346, 0.4929224046645686, 0.70286710630171, 0.8766091614961624, 2.5998687045648694, 3.7026821030303836, 5.570580884814262, 2.944996585138142, 1.6258163843303919, 2.3646542010828853, 7.287110276520252, 23.097742684185505, 20.55358350276947, 10.954896714538336, 7.804084410890937, 0.6757322873454541, 0.8643993479199708, 2.4458325700834394, 5.801751455292106, 7.262093368917704, 20.53968384861946, 19.6463118866086, 10.28207441791892, 2.9958803672343493, 1.0105180134996772, 0.24109079909976572, 0.3316201694542542, 0.17412394954590127, 0.12644348462345079, 0.11972194217378274, 0.14351335616083816, 0.09947264319634996, 0.13120796880684793, 0.26490091520827264, 0.31297510431613773, 0.41799662983976305, 0.1679598490591161, 0.5586142593529075, 0.4309161443961784, 1.5255256346426904, 0.27447117667179555, 0.7425040262751281, 2.7236850606277585, 2.9250687919557095, 2.385039869695902, 8.457025699317455, 5.828712908551097, 14.84592117369175, 15.812952183187008, 13.591371942311525, 16.453823894262314, 8.49635548889637, 7.713717184960842, 4.148434521630406, 2.356133395805955, 0.9049849107395858, 1.0726521606557071, 3.2499912567436695, 2.038656393997371, 0.7190343481488526, 1.048706795554608, 3.419336532242596, 0.36356754892040044, 48.9138139039278, 50.90333014726639, 26.812812834978104, 49.997865334153175, 102.58232787251472, 81.94451048970222, 40.49744412302971, 52.40453839302063, 95.32774955034256, 46.86573900282383, 0.8917197631672025, 0.5194920930080116, 0.28579581587109715, 0.559716853313148, 0.27099097904283553, 0.31348929391242564, 0.15838198800338432, 0.19100828416412696, 0.14995444100350142, 0.16211267531616613, 0.08277391971205361, 0.2556078607449308, 0.19317930360557511, 0.12368188632535748, 0.14646458061179146, 0.07084906857926399, 0.12927330855745822, 0.22273120848694816, 0.12939028587425128, 0.1144712844688911, 0.105299793794984, 0.15236637642374262, 0.24561907252063975, 0.18749096430838108, 0.14804928854573518, 0.16449431626824662, 0.16141281521413475, 0.14961906446842477, 0.15414030232932419], [0.08733127790037543, 0.025070850606425665, 0.08858165572746657, 0.04506950775976293, 0.031436588906217366, 0.06281268535531126, 0.05113057588459924, 0.03760320527362637, 0.043661453237291425, 0.00595132721173286, 0.019453091408649925, 0.03143153116980102, 0.09478511972702108, 0.05125701558426954, 0.0571902599040186, 0.10191185254370794, 0.04491476254770532, 0.059082992520416155, 0.0884047054569237, 0.06290439996519126, 0.10054984828457236, 0.03373105719219893, 0.01131662957050139, 0.03130703218630515, 0.06106901681050658, 0.044578135493793525, 0.034337380711804144, 0.019795570296992082, 0.06096485267335083, 0.044795005887863226, 0.02734436435275711, 0.10325275754439645, 0.1379226241260767, 1.3137354492209852, 7.9930876940488815, 41.82974763214588, 47.008949518203735, 25.010645538568497, 22.734128795564175, 66.26924961805344, 76.05322301387787, 34.182012006640434, 38.39306764304638, 61.62121742963791, 15.026891212910414, 0.6643802777398378, 0.10951303294859827, 0.7113883271813393, 0.38080158352386206, 0.05518513273273129, 0.49798227846622467, 0.7045871671289206, 0.4449369467329234, 0.47969635343179107, 0.6989957671612501, 6.212816247716546, 8.231306411325932, 7.013617577031255, 11.745823323726654, 6.448760787025094, 7.767033074051142, 21.381427980959415, 22.2142368927598, 9.824496321380138, 11.213135607540607, 12.626704405993223, 4.246924286708236, 0.9821422642562538, 1.9385543279349804, 0.5690136482007802, 0.2938602300127968, 0.039695375235169195, 0.28574362804647535, 0.0573509831156116, 0.04728031373815611, 0.09268814435927197, 0.03553905138687696, 0.07213536635390483, 0.2876045781886205, 0.7053736061789095, 1.4211991452611983, 1.5838396805338562, 0.980421194108203, 1.3274778868071735, 0.4806908610044047, 1.9126613298431039, 2.8157059103250504, 0.3575437737163156, 0.7879630057141185, 0.03782705927733332, 0.374703771667555, 0.19688481726916507, 0.42825809796340764, 1.4973298413679004, 1.8384377751499414, 1.3375063799321651, 1.6978265577927232, 0.48263769247569144, 0.12106261710869148, 0.39534545154310763, 0.05635836801957339, 0.04448686617251951, 0.01887418096885085, 0.021866197566851042, 0.06043020206561778, 0.018223259939986747, 0.04056585508806165, 0.04184967780020088, 0.047550240269629285, 0.005211572497501038, 0.07075567671563476, 0.1869326169253327, 0.12986529007321224, 0.1778378791641444, 0.07209077070001513, 0.5195762822404504, 0.7154514372814447, 0.9456956293433905, 1.5034370636567473, 2.857666821219027, 2.6497443532571197, 2.035084585659206, 4.99072439968586, 4.0449693985283375, 2.4990928871557117, 3.0040838895365596, 1.4160136110149324, 0.49297542369458824, 0.5566079076379538, 0.3388601465849206, 0.08082168540568091, 1.3863647519610822, 0.5837299022823572, 0.7958394486922771, 2.060372941195965, 2.5522449100390077, 30.926821678876877, 23.849222660064697, 14.454779662191868, 46.11757814884186, 77.14578598737717, 55.690279081463814, 21.34297214448452, 28.197148852050304, 71.77197754383087, 41.42239809036255, 0.34299809485673904, 0.26769139047246426, 0.08735369076021016, 0.029513712106563617, 0.0713779304351192, 0.033880462651723064, 0.11124228898552246, 0.028667916085396428, 0.04038242586830165, 0.04744851408759132, 0.06251667233300395, 0.038105947242002, 0.06123377359472215, 0.01124042955780169, 0.07913316585472785, 0.028406390665622894, 0.05661181145114824, 0.07568188972072676, 0.03579235009965487, 0.04646187328035012, 0.05200377570872661, 0.04768245758896228, 0.04405519968713634, 0.019275478771305643, 0.06265902367886156, 0.06897380240843631, 0.05663239491696004, 0.06279037639615126, 0.09548722111503594, 0.04700918863818515, 0.03411554163903929, 0.04896177546470426, 0.07025009603239596, 0.015786564617883414, 0.034934431096189655, 0.048303015501005575, 0.01173638829641277, 0.026682231327868067, 0.12690474424744025, 0.008357619990420062, 0.07405375130474567, 0.026546961926214863, 0.03876158647472039, 0.008770862659730483, 0.011368438899808098, 0.04890846699709073, 0.03280522796558216, 0.07036691749817692, 0.07855220523197204, 0.03734552417881787, 0.04381159713375382, 0.0644561491208151, 0.03248447916121222, 0.052648182536358945, 0.08532414693036117, 0.06646829700912349, 0.019162800344929565, 0.06875378530821763, 0.07684090916882269, 0.015832546232559253, 0.018342285584367346, 0.2425180678255856, 0.28410719241946936, 1.7381182895042002, 17.529331482946873, 68.51210966706276, 67.01782464981079, 49.8898409307003, 57.89857618510723, 92.74378940463066, 71.65371268987656, 47.09817633032799, 71.905008405447, 71.3734245300293, 9.284474048763514, 0.3830467286752537, 0.07656211397261359, 0.4639611305901781, 0.4707797459559515, 0.19931802264181897, 0.6458461785223335, 0.5529506038874388, 0.2249692883924581, 0.7369105482939631, 0.6550406164024025, 3.591984543018043, 3.7976824678480625, 2.8770645428448915, 1.7750016041100025, 4.863908579573035, 10.175807420164347, 15.918187536299229, 0.8640039316378534, 1.157642318867147, 5.606934959068894, 9.063131175935268, 9.001983907073736, 5.306407185271382, 1.7298108665272593, 0.5229496106039733, 0.6861830921843648, 1.092054513283074, 0.5760514049325138, 0.1106300245737657, 0.05843482300406322, 0.026699109621404205, 0.04945801993017085, 0.04928787144308444, 0.2374579120078124, 1.2744520884007215, 1.5276579139754176, 1.546567480545491, 1.1339878756552935, 1.332784064579755, 0.6772706704214215, 2.3772491002455354, 3.0484745325520635, 1.026335614733398, 0.7042808085680008, 0.23856472136685625, 0.15780208865180612, 0.10891006022575311, 0.4859904188197106, 1.5642197895795107, 2.505204859189689, 3.589601358398795, 2.1625976683571935, 0.4735684400657192, 0.27238568232860416, 0.3835789969889447, 0.07474729573004879, 0.05909495223022532, 0.029768894019071013, 0.024682456896698568, 0.04674116942624096, 0.013107789072819287, 0.050064220995409414, 0.007201932321549975, 0.016446986992377788, 0.0460355502582388, 0.09494701924268156, 0.2184429159387946, 0.23818701272830367, 0.8465005864854902, 0.48535424983128905, 1.0562235047109425, 1.4086404629051685, 4.449442019686103, 6.949460869655013, 4.812934789806604, 2.9875170160084963, 6.360119143500924, 8.257113676518202, 4.220457281917334, 2.6226689061149955, 2.0554191945120692, 1.4770039007999003, 0.6278731429483742, 0.18526082538301125, 2.050393489189446, 2.528492147102952, 0.6854569748975337, 0.224601702648215, 0.18825338745955378, 1.2595560564659536, 2.9483430180698633, 35.157184079289436, 59.301103726029396, 26.678860522806644, 27.59866576641798, 67.01402485370636, 79.60991576313972, 42.67976202070713, 37.32154034078121, 72.15953394770622, 68.34130883216858, 3.007485419511795, 0.3138903802027926, 0.19017618818907067, 0.09804301444091834, 0.05254120194877032, 0.07029850632534362, 0.15398813236970454, 0.03148244621115737, 0.04948867062921636, 0.03364028139912989, 0.09728509612614289, 0.055421206197934225, 0.09738233231473714, 0.026439107459736988, 0.05842868173203897, 0.016103699163068086, 0.003128129496872134, 0.05411677404481452, 0.06668388348771259, 0.06822007722803392, 0.027322760433889925, 0.043906699647777714, 0.029262643547554035, 0.040115319497999735, 0.031432032119482756, 0.10049486998468637, 0.07905975260655396, 0.013778663669654634, 0.08347544964635745, 0.07360993215115741, 0.2983732597203925, 0.14635615283623338, 0.21103638602653518, 0.22488646471174434, 0.17317471298156306, 0.284713645814918, 0.1002420499571599, 0.14739642123458907, 0.2948828204534948, 0.12236021037097089, 0.12411251751473173, 0.11084268699050881, 0.1779799410724081, 0.10049662887468003, 0.13697545073227957, 0.18912400089902803, 0.0951587688177824, 0.18816851545125246, 0.19143479643389583, 0.141067415534053, 0.1353493903297931, 0.12358017498627305, 0.17215008905623108, 0.09207202077959664, 0.1456226734444499, 0.17389524931786582, 0.10673716315068305, 0.25343075569253415, 0.2193349477602169, 0.26123743678908795, 0.15325704269343987, 0.31993264972697943, 0.26022888778243214, 1.8617216194979846, 11.055523864924908, 86.68601766228676, 96.02319583296776, 72.95466408133507, 63.55966441333294, 110.29394567012787, 116.00396007299423, 59.32551361620426, 65.95972582697868, 103.0668930709362, 27.834325321018696, 0.5698239547200501, 0.25473031564615667, 1.5291919629089534, 1.3802349683828652, 0.2920206537237391, 0.4556701536057517, 0.7801598869264126, 0.8558727835770696, 0.8119740954134613, 1.3177971937693655, 6.980869984254241, 10.735971461981535, 12.253148350864649, 17.466912232339382, 12.225489635020494, 15.295961424708366, 34.1861841827631, 29.85483270138502, 15.961353220045567, 23.03525123745203, 23.287588097155094, 18.05427711457014, 10.436113402247429, 5.20949243567884, 0.9137214138172567, 0.8864024234935641, 1.3702127686701715, 0.7224578456953168, 0.15837649611057714, 0.2339603184373118, 0.19528397504473105, 0.1471106498502195, 0.20389167097164318, 0.5603959481231868, 1.6474253498017788, 1.658699344843626, 2.1239176439121366, 1.3424340030178428, 1.7895564856007695, 1.3645856268703938, 3.310109730809927, 5.376042248681188, 2.060171077027917, 1.4143493003211915, 0.26602523925248533, 0.58162736822851, 0.3931656153872609, 1.317208344116807, 1.9400238990783691, 3.118141181766987, 5.0893153343349695, 3.2025885628536344, 1.3201506924815476, 0.8250535873230547, 0.787024931050837, 0.2990188094554469, 0.2506895293481648, 0.09710486556286924, 0.0971916077833157, 0.18602203141199425, 0.13853431708412245, 0.08131700960802846, 0.18430433061439544, 0.11179556007846259, 0.16628035402391106, 0.19089696201262996, 0.3910390060627833, 0.4551100102253258, 1.1002093506976962, 0.29340879642404616, 0.6120839808136225, 1.0012080380693078, 2.5847771018743515, 9.246442839503288, 3.5678781615570188, 4.866446843370795, 8.767187856137753, 12.426059022545815, 7.592384945601225, 3.482949393801391, 3.747045435011387, 2.273122575134039, 1.3929576356895268, 1.2669688649475574, 2.1286322409287095, 2.636003578081727, 5.395671995356679, 1.2623012904077768, 2.8613851591944695, 2.626187279820442, 6.535784667357802, 58.9001340419054, 42.989981174468994, 27.01344396919012, 61.862185299396515, 99.86554965376854, 79.58995923399925, 43.45243535935879, 49.64082129299641, 97.21113368868828, 73.29083204269409, 1.7903608549386263, 0.5081137223169208, 0.2953772392356768, 0.3012643998954445, 0.0918751215795055, 0.1485699793556705, 0.19999977434054017, 0.11347427585860714, 0.11959313502302393, 0.10554297332419083, 0.19866631308104843, 0.11803964182035998, 0.1640175754437223, 0.1164634463202674, 0.2367872925242409, 0.09274733805796131, 0.1281866559293121, 0.2821288938866928, 0.13179266243241727, 0.18593821325339377, 0.11344179947627708, 0.13670254818862304, 0.12191477333544753, 0.14612087717978284, 0.14429559465497732, 0.25879971915856004, 0.16889753780560568, 0.13363357458729297, 0.2017747689387761, 0.13418749877018854], [0.12606147152837366, 0.02462976070091827, 0.02916306402767077, 0.03973954786488321, 0.01951663965883199, 0.07822721134289168, 0.059608247538562864, 0.10760462988400832, 0.010376492664363468, 0.0357236012496287, 0.06991066737100482, 0.04976215946953744, 0.0389860898576444, 0.036717600451083854, 0.009208127721649362, 0.03645139207947068, 0.028882775259262417, 0.05225813569268212, 0.10365469730459154, 0.022808912508480716, 0.015261159314832184, 0.04200103139737621, 0.03544332917954307, 0.038487863857881166, 0.08339450359926559, 0.03831909205473494, 0.0668522842170205, 0.07983476258232258, 0.11680284529575147, 0.11333642192767002, 0.05248881003353745, 0.06193723311298527, 0.10318145199562423, 0.225410228013061, 1.3026626058854163, 18.080822490155697, 56.64869025349617, 41.234916150569916, 26.81604266166687, 32.44934298098087, 68.46805483102798, 80.35115718841553, 40.15985503792763, 39.90176148712635, 69.25186917185783, 28.15839283168316, 0.24788116832496598, 0.49588253488764167, 1.3707386841997504, 0.2486254830728285, 0.1427494190284051, 0.2769887790782377, 0.2811052050674334, 0.6841569696553051, 0.15241800021613017, 0.24575095216277987, 0.24961786810308695, 4.371893405914307, 3.5004123067483306, 5.318805444985628, 3.4035650035366416, 5.070606088265777, 10.147406794130802, 10.23084556683898, 4.924356685951352, 3.4623860847204924, 4.1101335268467665, 2.0252260146662593, 1.1669190460816026, 0.40341182495467365, 0.19671520683914423, 0.2114332272321917, 0.12684253742918372, 0.10487901090527885, 0.05616221467789728, 0.000781231318569553, 0.04031090880744159, 0.04376276752736885, 0.037430177253554575, 0.014782068665226689, 0.002895290867854783, 0.06741495832102373, 0.007948896072775824, 0.0674135927692987, 0.2546652441378683, 0.1705068108276464, 0.7198350364342332, 0.27582737733609974, 0.22362111776601523, 0.038839033295516856, 0.09212807519361377, 0.07768929528538138, 0.35049375670496374, 0.20477255573496222, 0.9417876577936113, 0.3783959860447794, 0.2504534076433629, 0.09304787818109617, 0.06762632197933272, 0.029878249479224905, 0.019309402341605164, 0.05676114269590471, 0.0066615439845918445, 0.011273181462456705, 0.07572420698124915, 0.04038577295432333, 0.05858468859514687, 0.026668676000554115, 0.03310190521006007, 0.016249110012722667, 0.18370682751992717, 0.01821309437218588, 0.11992477113381028, 0.2239210790139623, 0.8490044740028679, 0.3843221836723387, 0.48274070257321, 1.1780143319629133, 1.1235702596604824, 0.09834392563789152, 0.4732635658001527, 0.8645882096607238, 1.8472749134525657, 0.6252336502075195, 0.631814778316766, 0.3207081346772611, 0.41132522688712925, 0.7335362699814141, 0.45505666465032846, 1.8026127037592232, 2.051112363114953, 0.6909052887931466, 1.5787517535500228, 0.12906222691526636, 13.462921734899282, 33.61326612532139, 16.0188365355134, 18.6750441044569, 57.15443931519985, 87.81391873955727, 66.59427657723427, 20.08634727448225, 26.711179688572884, 64.99095261096954, 50.97467891871929, 1.0051436768844724, 0.8764505793806165, 0.08987251028884202, 0.1268914746469818, 0.1182978943688795, 0.07818968835636042, 0.1242933195317164, 0.09125550248427317, 0.07318673728150316, 0.051640256933751516, 0.046256821588031016, 0.07591750676510856, 0.03348453057697043, 0.02100163448631065, 0.0328886119677918, 0.05563665537920315, 0.08911565324524418, 0.02538970878958935, 0.027830480357806664, 0.01677310709055746, 0.0491004234936554, 0.021472547596204095, 0.02250187302706763, 0.04088943147507962, 0.03445574955549091, 0.08885864008334465, 0.05129997480253223, 0.08719204357475974, 0.016228678687184583, 0.01776524535671342, 0.049076389041147195, 0.08820103787002154, 0.05461591288622003, 0.015341228699981002, 0.13507090683560818, 0.04235551452438813, 0.008439763678325107, 0.04570644116029143, 0.01445149939172552, 0.024372823609155603, 0.05730283628508914, 0.00774536949393223, 0.027876771819137502, 0.007503642254960141, 0.051070417393930256, 0.019083320039499085, 0.019538393862603698, 0.05484094319399446, 0.08922728709876537, 0.07287798158358783, 0.056464788285666145, 0.04201955540338531, 0.09128614576184191, 0.051258355160825886, 0.031086092967598233, 0.060954848522669636, 0.02508460445824312, 0.18678084772545844, 0.09523831962724216, 0.08972915704362094, 0.08981393999420106, 0.19034725322853774, 0.03241136648284737, 0.17379332275595516, 0.5417868623044342, 2.2502689389511943, 29.239512719213963, 67.89876937866211, 56.82626232504845, 47.747033312916756, 64.9517235159874, 92.10758954286575, 72.55725100636482, 46.55578963458538, 72.84424960613251, 79.831223487854, 16.072915233671665, 0.05240566722932272, 0.49371026863809675, 0.3025641676504165, 0.31234650523401797, 0.6632975139655173, 0.38306667760480195, 0.262810344574973, 0.19183748576324433, 0.30725676740985364, 0.19951720023527741, 0.907577796606347, 2.3362777987495065, 2.2687444975599647, 0.7799423485994339, 3.7923337798565626, 10.095539577305317, 7.450231248512864, 4.017722010612488, 1.277493943925947, 2.385140801779926, 2.167832124978304, 1.2298842798918486, 1.4483039220795035, 0.4552736092591658, 0.4229291807860136, 0.2937192813260481, 0.050331171514699236, 0.015675765680498444, 0.05344799879821949, 0.0016118333155645814, 0.04207870828395244, 0.045923667785245925, 0.09819740342209116, 0.061314129634411074, 0.08020373614272103, 0.021436558999994304, 0.04227754820021801, 0.20339950831839815, 0.2731700730510056, 0.3140457265544683, 0.7232293824199587, 0.447383095161058, 0.37509215238969773, 0.05122480266436469, 0.17135084053734317, 0.13313112576724961, 0.5691689054947346, 0.5442703259177506, 0.6186754396185279, 0.17413830268196762, 0.49342056387104094, 0.283964165719226, 0.07987592209246941, 0.020733878736791667, 0.03269498192821629, 0.008342827131855302, 0.06226391909876838, 0.07501063199015334, 0.0753568735672161, 0.09125582160777412, 0.11126176294055767, 0.037428926734719425, 0.026361413874838036, 0.03086490698478883, 0.09471746554481797, 0.061064074106980115, 0.14312007726402953, 0.609009173931554, 0.7249140576459467, 1.729774174746126, 3.301601274870336, 3.8582830410450697, 1.930596367456019, 0.5694807856343687, 1.0306791379116476, 2.0989342220127583, 4.803227260708809, 2.223444515839219, 0.6176012253854424, 0.40589243872091174, 0.7274095143657178, 0.22865716862725094, 0.8447041735053062, 0.40735150105319917, 0.41185238922480494, 0.37966220872476697, 0.8993128244765103, 0.41149535682052374, 7.099100640043616, 51.20869696140289, 46.83147244155407, 22.37907774746418, 32.284811809659004, 71.82423233985901, 84.58234414458275, 43.37521210312843, 34.74171817302704, 57.55265414714813, 78.22312697768211, 9.621306974440813, 0.26585884974338114, 0.1346988236764446, 0.12457469740184024, 0.09461703069973737, 0.09124615884502418, 0.0985996400413569, 0.07657506444957107, 0.09011903690407053, 0.034129096966353245, 0.042976406402885914, 0.09885585168376565, 0.024101286617224105, 0.031186073247226886, 0.03297374372777995, 0.08796768437605351, 0.04681740283558611, 0.0392128976091044, 0.018978901716764085, 0.006677717237835168, 0.027237059075559955, 0.02695508377655642, 0.07078740352881141, 0.024286758598464075, 0.06029122007021215, 0.033841663171187975, 0.05089388643682469, 0.07275566080352291, 0.0201419751465437, 0.035982005938421935, 0.04758830873470288, 0.2534223842667416, 0.13182595517719164, 0.1539182072156109, 0.23776896094204858, 0.2031073544640094, 0.12154620053479448, 0.15097360272193328, 0.16540151758817956, 0.19339629274327308, 0.20088536432012916, 0.17617120844079182, 0.14441971143241972, 0.10202074045082554, 0.10171620757319033, 0.09750248602358624, 0.1330350324860774, 0.11257149031735025, 0.14908724144333974, 0.24526775465346873, 0.1562376116635278, 0.13500463304808363, 0.21873943362152204, 0.1385469632805325, 0.09151728023425676, 0.20213723386405036, 0.12853113119490445, 0.2626659523230046, 0.2300371477031149, 0.25214544497430325, 0.24354773835511878, 0.2503563940990716, 0.17873786680866033, 0.29472100257407874, 0.3611033514607698, 1.2399283284321427, 24.0341492369771, 93.26129123568535, 86.57738909125328, 70.757477581501, 71.05203777551651, 106.71351179480553, 121.29803359508514, 69.13885563611984, 63.9536614716053, 106.50041922926903, 55.37148378789425, 0.2636354643618688, 0.7699659245554358, 1.6794589371420443, 0.9322945796884596, 3.190781408920884, 0.42459061194676906, 0.4831782728433609, 1.2142722238786519, 0.25830393482465297, 0.5416283395607024, 0.8471960085444152, 7.238170802593231, 6.48727742023766, 7.868953580036759, 7.952351029962301, 9.291015397757292, 17.39250272512436, 16.360595896840096, 9.973126295953989, 7.638566717505455, 6.682316204532981, 4.432719117030501, 4.354994762688875, 1.5457960031926632, 0.5962700012605637, 0.5327539751306176, 0.5018884094897658, 0.1594547476270236, 0.1747044426156208, 0.25057283404748887, 0.13954497379017994, 0.17168605379993096, 0.218859973247163, 0.21547048090724275, 0.1371887736604549, 0.10539175331359729, 0.09726089469040744, 0.2682183450087905, 0.5626480397768319, 0.7104319659993052, 1.063536093570292, 0.5429729330353439, 0.6624282512348145, 0.21789111429825425, 0.23114351177355275, 0.21409278764622286, 1.7849645507521927, 1.13850393332541, 1.0912165394984186, 0.5306505504995584, 1.3981548068113625, 0.9090384026058018, 0.36545776936691254, 0.11478735774289817, 0.13226144743384793, 0.16913110652239993, 0.11413449043175206, 0.14757832163013518, 0.25418646982870996, 0.16154421988176182, 0.2711974148405716, 0.07559815319837071, 0.10079100175062194, 0.17785796168027446, 0.39789386792108417, 0.22332605469273403, 0.3034327772911638, 0.8125197817571461, 1.1385381314903498, 1.637526999693364, 2.1344167180359364, 3.9233749732375145, 1.297924853861332, 0.6816161528695375, 0.8674526622053236, 3.380134510807693, 8.00967950373888, 2.341261706314981, 1.8918094737455249, 1.5964687778614461, 1.6883502225391567, 2.145200539380312, 2.0538306422531605, 4.1100765299052, 6.023110477253795, 5.221418095752597, 4.433955950662494, 0.20166478265309706, 24.113758765161037, 56.216041669249535, 30.45126959681511, 32.19765208661556, 71.32731780409813, 109.36694741249084, 86.55561625957489, 40.6975793838501, 49.44559156894684, 85.03461107611656, 86.75949051976204, 6.504588341340423, 0.980393229983747, 0.22712285252055153, 0.1628940529190004, 0.43119973386637866, 0.11745968309696764, 0.18248974985908717, 0.16011361149139702, 0.22280147502897307, 0.2102229476440698, 0.1519102227757685, 0.22936590481549501, 0.125061783764977, 0.10179529825109057, 0.12666173541219905, 0.11459143075626343, 0.1766414925805293, 0.11420562528655864, 0.09568725959979929, 0.10282134709996171, 0.14004961936734617, 0.10592145379632711, 0.1371556441881694, 0.10691073664929718, 0.16840772033901885, 0.21811687562149018, 0.24996385734993964, 0.2248878896352835, 0.11714021078660153, 0.11058337317081168, 0.1181280984019395], [0.03350856131874025, 0.042805281991604716, 0.0488983366813045, 0.038716022318112664, 0.05371087492676452, 0.03128493102849461, 0.015015438857517438, 0.03531651840603445, 0.027123380605189595, 0.050063452872564085, 0.08632387180114165, 0.04752543769427575, 0.026367876125732437, 0.015619820733263623, 0.02533524442696944, 0.0378265546169132, 0.039157633582362905, 0.01991666096728295, 0.043535458826227114, 0.02396846073679626, 0.03356782552145887, 0.061928564828122035, 0.08655787838506512, 0.03656351946119685, 0.0647126576222945, 0.10616679297527298, 0.04782497220730875, 0.09235103119863197, 0.06223368029168341, 0.09081002834136598, 0.043326878221705556, 0.08906152841518633, 0.07346819678787142, 0.5759147903881967, 0.3530852770199999, 0.8137641556095332, 31.33494447916746, 59.56588491797447, 51.176429092884064, 28.919873870909214, 42.127446457743645, 69.70190182328224, 92.14705422520638, 54.799489080905914, 28.53703111410141, 63.63376043736935, 53.9838020503521, 7.0635145995765924, 0.36779268470127136, 0.3358162724180147, 1.8049188237637281, 1.2558586173690856, 0.46913102036342025, 0.607533190632239, 0.49705845303833485, 1.0499809146858752, 0.683718390064314, 0.8645097794942558, 0.33786038460675627, 0.7215562846977264, 0.6691947381477803, 0.9427611180581152, 2.643336709588766, 1.0917916148900986, 1.190001976210624, 2.129008420743048, 2.799397185444832, 0.148524456017185, 0.11306397951557301, 0.2689076220849529, 0.14584534743335098, 0.13844702567439526, 0.21872301731491461, 0.009966131383407628, 0.04198132737656124, 0.007051035609038081, 0.07974658801686019, 0.1172293427225668, 0.008357896440429613, 0.0789975754742045, 0.03894548695825506, 0.02029556446359493, 0.055511095124529675, 0.028998589259572327, 0.09494900819845498, 0.027862214592460077, 0.03525060827087145, 0.04915170960885007, 0.03460908468696289, 0.08962907100794837, 0.12869879719801247, 0.0873407105973456, 0.14751372509635985, 0.33728427020832896, 0.15547800867352635, 0.11875536903971806, 0.3777491895016283, 0.05568875414610375, 0.09912486537359655, 0.06327707684249617, 0.05963751413219143, 0.10011860111262649, 0.05167829571291804, 0.059165478523937054, 0.037184229513513856, 0.051896487129852176, 0.03707667376147583, 0.053426020094775595, 0.017542988825880457, 0.05322078286553733, 0.0507210105570266, 0.040254943451145664, 0.07534539254265837, 0.11440572314313613, 0.13521737710107118, 0.05065434343123343, 0.21239116176730022, 0.4249034420354292, 0.8682706870604306, 0.8753226930275559, 0.057286475639557466, 0.2069261495489627, 0.3877197951078415, 0.6992676900699735, 0.3874205908505246, 0.6664457044098526, 0.893949531018734, 0.25692158087622374, 1.7883949354290962, 1.1199938203208148, 2.437757053412497, 0.3815664112335071, 6.12998734228313, 24.115499071776867, 26.86115574091673, 16.820346526801586, 32.37001843750477, 74.76874753832817, 88.54594185948372, 59.574814438819885, 26.84430554509163, 27.534238323569298, 60.34754857420921, 60.31101733446121, 3.362578502856195, 0.6641265819780529, 0.15866823436226696, 0.09801985943340696, 0.17662325059063733, 0.09293071532738395, 0.04319871302868705, 0.21433664252981544, 0.04784447213751264, 0.06737232935847715, 0.05590098982793279, 0.013048951605014736, 0.028732759383274242, 0.041500063161947764, 0.027856770939251874, 0.040288395757670514, 0.014448121692112181, 0.03695082777994685, 0.054793850213172846, 0.01502702007201151, 0.002236814543721266, 0.021867093710170593, 0.042434968854649924, 0.055448817802243866, 0.038942588871577755, 0.10477047180756927, 0.02858586609363556, 0.04010882199509069, 0.06534044034196995, 0.03619685026933439, 0.03606097787269391, 0.052274923073127866, 0.005513344121936825, 0.02692794158065226, 0.035216562246205285, 0.03933364132535644, 0.020977073108952027, 0.03588514453440439, 0.021658026998920832, 0.08216644957428798, 0.07823833613656461, 0.026888164320553187, 0.0181193833850557, 0.04946983121044468, 0.10364067813497968, 0.0431189395749243, 0.019387656247999985, 0.038618674807366915, 0.025391265444341116, 0.05743752124544699, 0.02165896581573179, 0.016054992011049762, 0.07978345049195923, 0.026023547434306238, 0.04335918391006999, 0.016875211767910514, 0.09055346788954921, 0.11603584309341386, 0.06280159766902216, 0.14914230880094692, 0.07685984135605395, 0.20615459798136726, 0.038899889405001886, 0.09358022070955485, 0.1755715679610148, 0.39665180956944823, 0.8843857410829514, 1.8943342007696629, 51.40731230378151, 75.50464645028114, 61.67716942727566, 56.91192492842674, 72.48516127467155, 96.49193108081818, 81.2981727719307, 56.1534970253706, 61.646083295345306, 85.24536296725273, 31.942279189825058, 2.5616475054994226, 0.1893023241427727, 0.7411900686565787, 0.772718817461282, 0.6582596967928112, 0.3862879250664264, 0.6970910006202757, 0.6342268770094961, 0.7968991168309003, 0.7935259665828198, 0.60121686081402, 0.8778347144834697, 0.36510655540041625, 0.39650435966905206, 1.862273896113038, 4.304829379543662, 1.2224530661478639, 1.7196186259388924, 1.810835343785584, 1.816969639621675, 0.3928744560107589, 0.1728062960319221, 0.24096871580695733, 0.24888554646167904, 0.5391270644031465, 0.5671215278562158, 0.1711532214540057, 0.034601770821609534, 0.03250385292631108, 0.04707378517196048, 0.04840165805944707, 0.060798708072979935, 0.05412389124103356, 0.06896964638144709, 0.054443174303742126, 0.026427294324093964, 0.0348316399322357, 0.029023508723184932, 0.10604872470139526, 0.034871278039645404, 0.043805956811411306, 0.0504230716614984, 0.03371902697836049, 0.04318460851209238, 0.138768924807664, 0.27754120412282646, 0.3861176170175895, 0.47688584018033, 0.3798231953987852, 0.20056622597621754, 0.16714841447537765, 0.09006405860418454, 0.11952097600442357, 0.02195607165049296, 0.04062861480633728, 0.02243099792394787, 0.024275602263514884, 0.02557242554757977, 0.025128422712441534, 0.029513354020309635, 0.014428033609874547, 0.03180068655638024, 0.06053341625374742, 0.13290211383718997, 0.09850224800175056, 0.08301211943035014, 0.10455154566443525, 0.11663932047667913, 0.14113815705059096, 0.07666894613066688, 0.5810692731756717, 0.9657856856938452, 0.12717237754259259, 0.07237692800117657, 0.4067254549590871, 2.0171618973836303, 1.578950174152851, 0.2118365844944492, 0.4422167973825708, 0.650943664368242, 0.6213735323399305, 0.2714164968347177, 0.439710178761743, 1.1728301038965583, 0.711193943861872, 3.6428500385954976, 26.72816287726164, 53.38578253984451, 41.47179923951626, 22.358277663588524, 41.327004209160805, 78.7603497505188, 83.60844880342484, 52.11176410317421, 35.12591935694218, 57.383597418665886, 84.29871216416359, 19.662447720766068, 0.520950680365786, 0.5557311046868563, 0.16256048722425476, 0.21922125073615462, 0.06601295972359367, 0.09518841019598767, 0.08341932101757266, 0.08009714147192426, 0.04123354679904878, 0.08069277435424738, 0.061534027991001494, 0.05864470607775729, 0.038149615211295895, 0.02972312391648302, 0.04229610560287256, 0.06079622187826317, 0.018031225517916027, 0.02698915206565289, 0.05212989628489595, 0.02940486687293742, 0.003818196032625565, 0.023872528872743715, 0.03415960294660181, 0.0765925642917864, 0.046877004715497606, 0.06523473624838516, 0.059620159008773044, 0.030223511421354488, 0.04475371650187299, 0.03974516221205704, 0.06283844530116767, 0.08122306855511852, 0.13474240258801728, 0.1508164158440195, 0.21423232625238597, 0.21920814440818503, 0.11869131427374668, 0.12149745627539232, 0.17527133953990415, 0.17103725345805287, 0.13742489536525682, 0.17906758817844093, 0.12104043431463651, 0.1244609929563012, 0.08275380008853972, 0.15009785362053663, 0.15649764536647126, 0.176762136106845, 0.1553758594673127, 0.29632015270181, 0.20614918030332774, 0.14525591890560463, 0.13286540721310303, 0.14930926234228536, 0.14397887571249157, 0.10784120429889299, 0.16162036423338577, 0.16333291452610865, 0.33300347335170954, 0.1343477878253907, 0.26080325071234256, 0.1524382905336097, 0.16566965554375201, 0.3442848304985091, 0.7575950352475047, 0.777834530454129, 0.43589230393990874, 48.310242891311646, 103.38967055082321, 92.98553243279457, 75.11016681790352, 86.89895063638687, 113.44799682497978, 125.75046747922897, 89.60587218403816, 46.456801146268845, 88.97157981991768, 87.65977621078491, 14.854479264467955, 0.38132316491100937, 1.7806272022426128, 2.600144427269697, 1.673761736601591, 1.0986193735152483, 0.8917491522151977, 0.8961322763934731, 1.3222684850916266, 0.8841322234366089, 0.8864175633061677, 0.8394395560026169, 1.797075925860554, 1.342428659554571, 1.5255694510415196, 4.944488480687141, 1.9823609897866845, 4.236199837177992, 3.097038301639259, 3.782993406057358, 0.35231240442954004, 0.18454658245900646, 0.4096575023140758, 0.41450782329775393, 0.8311986294575036, 1.2633835198357701, 0.30230545497033745, 0.12668141716858372, 0.052551740445778705, 0.23781032825354487, 0.17288098577409983, 0.14975322992540896, 0.1445739297196269, 0.16716474172426388, 0.22486207773908973, 0.13875564036425203, 0.15698271308792755, 0.20082234113942832, 0.1608053079689853, 0.15021131315734237, 0.16520786157343537, 0.14784930943278596, 0.11304408995783888, 0.42501123156398535, 0.2985757769783959, 0.48214089882094413, 0.41685591917485, 0.6825044145807624, 0.8970994432456791, 0.9383356024045497, 0.6012239854317158, 0.22962993127293885, 0.21808016899740323, 0.11953034932957962, 0.1842323868186213, 0.16126981819979846, 0.21142788376891986, 0.1240086168400012, 0.09770182688953355, 0.16189834306715056, 0.16732964693801478, 0.13218034553574398, 0.09178444597637281, 0.19762579235248268, 0.3275230393046513, 0.2078294471721165, 0.3377159923547879, 0.2231256154482253, 0.22028367966413498, 0.5334097368177027, 0.4536335222655907, 1.2958538462407887, 1.979992410633713, 0.11813383520347998, 1.2950419960543513, 2.9719649255275726, 4.048009235411882, 0.4526979709044099, 1.0601470316760242, 2.6091430569067597, 1.8476109579205513, 2.4330823542550206, 7.731370087713003, 9.828456658869982, 0.5387076619081199, 9.087942894548178, 42.319856733083725, 43.21846291422844, 31.09966490417719, 50.81651620566845, 93.30645561218262, 107.94647723436356, 76.55411213636398, 47.040909603238106, 48.227981105446815, 82.57595300674438, 97.15517789125443, 14.724437892436981, 0.7488731376361102, 0.3260049020173028, 0.29351388453505933, 0.32153079053387046, 0.1387530131614767, 0.1611907794722356, 0.3496224159607664, 0.3483584790956229, 0.1873823584173806, 0.24037395865889266, 0.19032828393392265, 0.1784442731877789, 0.16071394958999008, 0.24708240962354466, 0.12286622892133892, 0.17894163087476045, 0.15261143358657137, 0.1551565548288636, 0.10857410481548868, 0.1323855048394762, 0.14214569673640653, 0.13480364461429417, 0.09776836042874493, 0.14483553677564487, 0.23208584636449814, 0.1424713511369191, 0.14200158650055528, 0.12895415537059307, 0.13713259308133274, 0.13387968559982255, 0.07688416895689443], [0.02981504818308167, 0.03816927470325027, 0.026536777804722078, 0.02573417663370492, 0.03129757351416629, 0.038178751929081045, 0.0200853177375393, 0.03115286584943533, 0.0594917600392364, 0.07805471395840868, 0.08656691774376668, 0.012859871858381666, 0.03080880062043434, 0.04421870966325514, 0.03940498769225087, 0.04734621645184234, 0.03650214755907655, 0.022862261794216465, 0.039205086504807696, 0.06955266275326721, 0.015832332865102217, 0.06633941564359702, 0.08722845333977602, 0.027886699899681844, 0.036167086436762474, 0.050915675892611034, 0.07054762303596362, 0.06204111523402389, 0.18123826623195782, 0.1466933253686875, 0.20281432487536222, 0.11493960191728547, 0.07318782823858783, 0.11756975101889111, 0.4650207987288013, 0.7766355760395527, 1.6674370947293937, 28.212747015058994, 56.86150163412094, 43.91775839030743, 38.75265374779701, 52.83168487250805, 80.80591678619385, 107.51651510596275, 81.75724133849144, 31.09988149255514, 40.179815366864204, 61.558281406760216, 37.064183950424194, 3.770301374606788, 0.26972024410497397, 0.3377357037970796, 0.5543510662391782, 0.9156924393028021, 0.8260626113042235, 0.12609924684511498, 0.5828321410808712, 1.0225448431447148, 0.6415625021327287, 0.3489035717211664, 1.0598078998737037, 0.6659404502715915, 0.42821321287192404, 0.6172180990688503, 0.8089898899197578, 0.6428533641155809, 0.2188515424495563, 0.6420658563729376, 0.16012110718293115, 0.18611628416692838, 0.1312906143721193, 0.49853301141411066, 0.2515959885204211, 0.10123542946530506, 0.06337581216939725, 0.05242302606347948, 0.07832012823200785, 0.04226755518175196, 0.03208707392332144, 0.015594442993460689, 0.04738715331768617, 0.04384547988593113, 0.08081652005785145, 0.075729995733127, 0.057194876062567346, 0.04475678528251592, 0.0322231281461427, 0.020506102482613642, 0.09150374346063472, 0.047456035754294135, 0.14517456467729062, 0.11821075138868764, 0.0766743192798458, 0.061109252346795984, 0.07186134316725656, 0.12717252597212791, 0.08992450515506789, 0.1113030560372863, 0.06571768142748624, 0.12564528995426372, 0.04243358474923298, 0.019698543765116483, 0.04215861903503537, 0.016687667339283507, 0.035167009045835584, 0.0417535770975519, 0.05194016623136122, 0.041457385959802195, 0.06378961144946516, 0.03598606177547481, 0.09524024178972468, 0.21101247402839363, 0.09320494631538168, 0.03495873272186145, 0.062354787660297006, 0.08103492669761181, 0.2209267209400423, 0.21919362799962983, 0.545042100129649, 0.22981582442298532, 0.3800208738539368, 0.0898363528540358, 0.12418960439390503, 1.3019448006525636, 1.3960708561353385, 1.4527351967990398, 0.823743132641539, 1.4997308375313878, 0.7313195045571774, 0.4717085586162284, 6.559381876140833, 20.088218674063683, 28.351186886429787, 25.826015286147594, 28.885892294347286, 51.449858620762825, 83.73478442430496, 89.66847002506256, 47.56292559206486, 26.248678006231785, 35.33588849008083, 59.104920253157616, 67.49558821320534, 7.978401482105255, 0.7741575746331364, 0.4936155112227425, 0.24275821197079495, 0.17481471091741696, 0.058796490120585077, 0.03156942591886036, 0.17113183275796473, 0.04177480994258076, 0.044702497179969214, 0.036047211033292115, 0.02723486046306789, 0.09090782114071772, 0.0521429209766211, 0.014396342976397136, 0.04405691404826939, 0.0422834816708928, 0.040579696142231114, 0.08623566754977219, 0.0805740307259839, 0.04246306656568777, 0.08934229030273855, 0.06286370058660395, 0.028872160692117177, 0.06117926284787245, 0.060813640084234066, 0.0886352313682437, 0.06744040656485595, 0.04690655703598168, 0.07010925124632195, 0.04789894577697851, 0.020112283673370257, 0.11030435533029959, 0.03601120944949798, 0.11045497420127504, 0.03348110185470432, 0.02362661081861006, 0.03268429500167258, 0.04166488673945423, 0.01626330729777692, 0.03439725347561762, 0.03777838181122206, 0.04001389388577081, 0.0642217714630533, 0.049766920346883126, 0.04168166298768483, 0.029446839034790173, 0.003135866618322325, 0.02589775154774543, 0.008598996100772638, 0.03484017834125552, 0.05848377877555322, 0.024475776190229226, 0.023945610009832308, 0.05006034698453732, 0.02062953277345514, 0.0630071948398836, 0.07325008700718172, 0.08640887739602476, 0.05581235513091087, 0.0946652702987194, 0.22875110968016088, 0.08947293055825867, 0.12704570777714252, 0.09449368575587869, 0.08215120586100966, 0.33801869954913855, 0.41314532922115177, 1.2194306845776737, 4.462903272360563, 55.70606343448162, 79.52370598912239, 57.58000507950783, 67.7337746322155, 77.01643332839012, 105.10745957493782, 97.12182328104973, 52.82399408519268, 54.9445690959692, 76.00013226270676, 60.821569338440895, 13.441638126969337, 1.2893238966353238, 0.26341023738496006, 0.8179311663843691, 0.4866590048186481, 0.5791858211159706, 0.43868592591024935, 0.18306322221178561, 0.9256589482538402, 1.3390412600710988, 0.16454718686873093, 0.1453795755514875, 0.3377479047048837, 0.3996536781778559, 1.1895372136496007, 0.9110553818754852, 0.9077274135779589, 1.1836317367851734, 0.16480993683217093, 1.2079277518205345, 0.6629510794300586, 0.21529028745135292, 0.3902883979026228, 0.24847881984896958, 0.20036807254655287, 0.07313906913623214, 0.0875490166072268, 0.012626507232198492, 0.03609984785725828, 0.016344696778105572, 0.03278353498899378, 0.07370979554252699, 0.02024555484240409, 0.07429063000017777, 0.042298903499613516, 0.05796692115836777, 0.10481296718353406, 0.02283579124195967, 0.03286696352006402, 0.031211803507176228, 0.04767117694427725, 0.03471559401077684, 0.1804902555886656, 0.21216407942119986, 0.08065422720392235, 0.09121875133132562, 0.13573757809353992, 0.01786038868885953, 0.12622835085494444, 0.029137465498934034, 0.0764264419558458, 0.010508877894608304, 0.025195147354679648, 0.07213885444798507, 0.07240489954710938, 0.022157959938340355, 0.012950336877111113, 0.07308728207135573, 0.01538526959848241, 0.0696115150640253, 0.024446478055324405, 0.059812527397298254, 0.032382693607360125, 0.2835439913906157, 0.1744906001840718, 0.11957890805206262, 0.2304300109972246, 0.2087833295809105, 0.772182036889717, 0.7381321233697236, 0.6699469196610153, 0.2695931290509179, 0.47142464260105044, 0.28076752787455916, 0.3525459731463343, 1.842664573341608, 1.1699926061555743, 1.0524887801147997, 0.7024757273029536, 0.7160186162218451, 0.8996893605217338, 0.4733670805580914, 6.044431133195758, 21.91318854689598, 43.85722763836384, 47.80388206243515, 35.350776091217995, 28.53472463786602, 53.32840941846371, 90.56203007698059, 75.80592468380928, 44.96889218688011, 36.95378467440605, 53.809098824858665, 85.50536021590233, 26.801977716386318, 0.4967464244691655, 0.6767714722082019, 0.34274428035132587, 0.32936585135757923, 0.05561163758102339, 0.05683007708285004, 0.11825997804407962, 0.1614640382467769, 0.08290152458357625, 0.04742267992696725, 0.022287603860604577, 0.03973888735345099, 0.0462202188646188, 0.07482821209123358, 0.027912821642530616, 0.06604043403058313, 0.07373784130322747, 0.017496728905825876, 0.03727720948518254, 0.017194815809489228, 0.00975668339378899, 0.0380342409334844, 0.030130781924526673, 0.06091703980928287, 0.04759073184686713, 0.01992192836041795, 0.08273680490674451, 0.05644900651532225, 0.050117458958993666, 0.04174618901743088, 0.022567423220607452, 0.06492270025773905, 0.1900225190911442, 0.2153606282081455, 0.17507492273580283, 0.21267439500661567, 0.11817624152172357, 0.07878984833951108, 0.15124953322811052, 0.102657198876841, 0.14730040216818452, 0.18994060083059594, 0.15606322180246934, 0.11122896743472666, 0.13863030646461993, 0.19861540175043046, 0.1275180550874211, 0.10791112945298664, 0.11415994609706104, 0.22006041195709258, 0.1361041545169428, 0.20840392884565517, 0.11907306019566022, 0.19290896889287978, 0.23175287438789383, 0.09173066995572299, 0.12609728757524863, 0.1870092807803303, 0.11542325213667937, 0.15945584600558504, 0.3335659916047007, 0.2809776150388643, 0.4086391272721812, 0.21469674742547795, 0.19031606818316504, 0.2871187386335805, 0.4109269904438406, 1.1931869178079069, 1.1597634362988174, 51.57668821513653, 102.29736596345901, 83.28888595104218, 88.44655439257622, 91.38599306344986, 117.39547580480576, 132.71318346261978, 103.94708544015884, 50.17960578203201, 55.542170628905296, 87.86434963345528, 58.16402994096279, 7.911175489425659, 0.44063373701646924, 1.3599290954880416, 1.3510589464567602, 1.177574386820197, 1.1084330594167113, 0.2468532937928103, 1.1324126226827502, 1.4389608171768486, 0.9194977569859475, 0.4009464103728533, 1.428934105206281, 0.7113512197975069, 2.277524401433766, 0.8063786581624299, 1.3750047865323722, 0.7546553586144, 0.5467512959148735, 1.2625543330796063, 0.8737055829260498, 1.562790828756988, 2.272671111859381, 0.9704479167703539, 0.3932248684577644, 0.2141357134678401, 0.1336335003725253, 0.16882253636140376, 0.12303893410717137, 0.13120076997438446, 0.11637583578703925, 0.10331689394661225, 0.12224678794154897, 0.13998010981595144, 0.23371508315904066, 0.33840277581475675, 0.16675048973411322, 0.09442206850508228, 0.14975947880884632, 0.10285671043675393, 0.2156510899658315, 0.121356811869191, 0.3876120352651924, 0.3076775948284194, 0.2584268938517198, 0.11098229981143959, 0.22286599734798074, 0.26777427352499217, 0.2503134385915473, 0.22195229481440037, 0.1385113995638676, 0.18414396734442562, 0.13826782669639215, 0.13090825988911092, 0.1908529081265442, 0.12327544172876514, 0.17993456509429961, 0.13688581413589418, 0.09710649828775786, 0.20900417788652703, 0.09994222229579464, 0.1633288772427477, 0.19120335025945678, 0.5481598922051489, 0.4779454489471391, 0.16204997868044302, 0.656652501784265, 0.4125637229299173, 1.1144837597385049, 0.6516242434736341, 2.811334007419646, 2.8113294951617718, 2.3488441994413733, 0.2816704544238746, 0.32583046762738377, 4.587194127961993, 1.2784691853448749, 4.2536143027246, 3.5786548582836986, 2.671259273774922, 1.496922669466585, 0.45664117962587625, 11.34394833818078, 32.711152732372284, 47.02395871281624, 42.03115962445736, 41.878472417593, 66.95234656333923, 96.68178409337997, 103.10666173696518, 61.50787711143494, 45.53859181702137, 56.84956647455692, 74.40627738833427, 105.2479836344719, 18.92911557108164, 0.7780882262159139, 0.6929616909474134, 0.5413389613386244, 0.2697701461147517, 0.1358922861982137, 0.15405921527417377, 0.3605931397760287, 0.21951260307105258, 0.1764639263274148, 0.110849418269936, 0.2495971176540479, 0.20397882879478857, 0.16342633607564494, 0.21597986138658598, 0.08749693268327974, 0.15381975390482694, 0.1960790972225368, 0.13214525679359213, 0.36613086762372404, 0.09279351448640227, 0.14102448971243575, 0.16227854532189667, 0.15760069945827127, 0.1533877052133903, 0.1019576059479732, 0.2088538187672384, 0.20541795704048127, 0.12194589158752933, 0.14156355609884486, 0.18113862548489124, 0.1555020987871103, 0.24197468213969842], [0.011426809742260957, 0.0618751895672176, 0.05129363686137367, 0.09971589694032446, 0.05116782798722852, 0.08264447431429289, 0.05185875634197146, 0.09006397696794011, 0.014898248173267348, 0.06062096370442305, 0.06503098702523857, 0.008501407392031979, 0.03457909078861121, 0.025117151344602462, 0.010862278413696913, 0.06135591625934467, 0.06609609510633163, 0.040775749293970875, 0.05404534975241404, 0.04384989937534556, 0.08002029950148426, 0.022852999791211914, 0.04604201065376401, 0.022095361637184396, 0.01424579646482016, 0.01947850254509831, 0.08238996961154044, 0.07178748463047668, 0.0946937984554097, 0.22276690579019487, 0.18947021279018372, 0.19857804203638807, 0.07687847668421455, 0.16372632700949907, 0.1871941942954436, 0.4573051049374044, 1.5237753535620868, 2.117486489005387, 32.65070557594299, 54.79847073554993, 56.80780291557312, 41.42049439251423, 43.728137165308, 95.6063961982727, 112.0178447663784, 108.65570917725563, 48.597408682107925, 24.096826873719692, 34.59642916917801, 49.468382745981216, 24.618517979979515, 4.631068948656321, 0.5101764772552997, 0.30155633110553026, 2.164638633839786, 1.4273038739338517, 0.1787616452202201, 0.7474085537251085, 0.6742120126727968, 0.06824056050390936, 0.12439157246262766, 0.37378742708824575, 0.09401761286426336, 0.28887255233712494, 1.8057893333025277, 0.6924128578975797, 0.181150010030251, 1.427116496488452, 0.9103454137220979, 0.1049229312047828, 0.14074115257244557, 0.09850198082858697, 0.012434642576408805, 0.061887746705906466, 0.1570425005047582, 0.02061149301880505, 0.057662466206238605, 0.0835403281962499, 0.016323078016284853, 0.08629857940832153, 0.0802121743618045, 0.03454956073255744, 0.01689353539404692, 0.07224381639389321, 0.024199266808864195, 0.01885220412077615, 0.03199580460204743, 0.048596037668175995, 0.07438030370394699, 0.033768851062632166, 0.1982967829098925, 0.01193697411508765, 0.08605639435700141, 0.11703280717483722, 0.057472554326523095, 0.028621214587474242, 0.051438489244901575, 0.05885239239432849, 0.033742708910722286, 0.1023447843908798, 0.037598284834530205, 0.024485509457008447, 0.06982972874538973, 0.039424984861398116, 0.03411345249332953, 0.04111930800718255, 0.05172436452994589, 0.02607291695312597, 0.06231056308024563, 0.03657428431324661, 0.007699356801822432, 0.04449566433322616, 0.028258849852136336, 0.06418297940399498, 0.04173821464064531, 0.09453367267269641, 0.2977416920475662, 0.25719095079693943, 0.3004157985560596, 0.9551319479942322, 0.05868871543498244, 0.05885642967768945, 0.2848992421058938, 2.7147560147568583, 6.759405517950654, 0.4681849601911381, 0.44010737619828433, 2.579341256059706, 9.732986781746149, 20.2737570181489, 24.839166440069675, 21.955174393951893, 25.229310505092144, 44.16460074484348, 71.63972944021225, 96.69237792491913, 84.52351570129395, 36.298110857605934, 27.40472037345171, 49.428750872612, 62.56949834525585, 73.92399206757545, 7.995532862842083, 0.8514866908080876, 0.44438754965085536, 0.3175873146392405, 0.20264849939849228, 0.04351272313215304, 0.17262874462176114, 0.09178781532682478, 0.18932717124698684, 0.05730056160246022, 0.011975985107710585, 0.09833745411015116, 0.03785610693739727, 0.06964569096453488, 0.036189844395266846, 0.06387328860000707, 0.0913694295741152, 0.039660364418523386, 0.04517877045145724, 0.08648612754768692, 0.03152239602059126, 0.03719025946338661, 0.06419253826607019, 0.031740843478473835, 0.014654721690021688, 0.06619252235395834, 0.01371596703393152, 0.046969706381787546, 0.027966285961156245, 0.07042795172310434, 0.019053502401220612, 0.034195782645838335, 0.02955601637950167, 0.1279460368095897, 0.024640707379148807, 0.026175622770097107, 0.06736263690982014, 0.02853219582902966, 0.041373085405211896, 0.03771190022234805, 0.01076343362001353, 0.027206300765101332, 0.02572622637671884, 0.031966916503733955, 0.06078067388443742, 0.04316959486459382, 0.050106245107599534, 0.01716410944936797, 0.023949875503603835, 0.045794782708981074, 0.05354164670279715, 0.03924828321032692, 0.06024239417456556, 0.008345615751750302, 0.06689134344924241, 0.01634655400266638, 0.01464623801439302, 0.014180412326822989, 0.032059569930424914, 0.03373851206561085, 0.08161862584529445, 0.051843720430042595, 0.1484500482911244, 0.1005447497300338, 0.16228636755840853, 0.12443210856872611, 0.13001888495637104, 0.05730497738113627, 0.12617963628144935, 0.6033507431857288, 1.633336537051946, 4.474289361387491, 59.713552594184875, 78.75817626714706, 68.70425775647163, 73.51042985916138, 76.89059928059578, 114.81233641505241, 107.20455944538116, 65.0998243689537, 42.643519565463066, 57.521606013178825, 72.37844780087471, 45.24701826274395, 12.756867371499538, 1.9818520545959473, 0.20183063781587407, 0.5943765747360885, 1.6496863472275436, 0.8047908777371049, 0.14537752722389996, 0.8266616729088128, 0.7775556016713381, 0.17988898238399997, 0.2074422687292099, 0.11471855323179625, 0.7389816152863204, 0.49118836177513003, 3.803928382694721, 0.6300398579332978, 0.5897389235906303, 0.7611724839080125, 0.387333789258264, 0.23075967299519107, 0.11922079953365028, 0.05197645354201086, 0.03669516161608044, 0.024901696597225964, 0.06722824880853295, 0.04102266553672962, 0.05069575156085193, 0.05220671599090565, 0.09577501856256276, 0.02163617631595116, 0.0681092671584338, 0.0077195784706418635, 0.0643915896944236, 0.04889603231276851, 0.026697352586779743, 0.017298126476816833, 0.06778708600904793, 0.05268143075227272, 0.05016926457756199, 0.033552429667906836, 0.27237665781285614, 0.11356213130056858, 0.031196730487863533, 0.03113084632786922, 0.09710553349577822, 0.06573649487108923, 0.03594127316318918, 0.06652298587141559, 0.0034599650598465814, 0.0444364743452752, 0.04479424518649466, 0.05304520185745787, 0.05965959673631005, 0.07103375945007429, 0.02891852451284649, 0.028593983333848882, 0.03134051417873707, 0.005973370853098459, 0.027569422491069417, 0.10366314294515178, 0.08323745030793361, 0.06796462999773212, 0.0012220989856359665, 0.22206156863830984, 0.15417435206472874, 0.19357773300725967, 0.18788774614222348, 0.7657898892648518, 0.6848114251624793, 0.9850764193106443, 0.19089195993728936, 0.045411081227939576, 0.43919073475990444, 3.7260487116873264, 7.747612791135907, 0.7966508832760155, 0.30692668980918825, 1.80323587032035, 9.012691732496023, 26.873185895383358, 37.27177061140537, 41.783960089087486, 41.295112520456314, 42.48898945748806, 45.293919146060944, 67.68465086817741, 92.33192190527916, 64.1035558283329, 40.37368096411228, 46.05110451579094, 59.05060216784477, 87.10587993264198, 29.400692470371723, 0.9299639984965324, 1.1740529257804155, 0.2307188103441149, 0.36292158358264714, 0.06215570283529814, 0.12302890769205987, 0.05000744298740756, 0.14076641527935863, 0.1143324509030208, 0.04145946026255842, 0.08475525362882763, 0.02639940255903639, 0.07865783511078916, 0.03677332460938487, 0.010067323219118407, 0.12642598478123546, 0.04992436326574534, 0.08506849189870991, 0.0812237587524578, 0.04846531206567306, 0.042583364993333817, 0.0457795723923482, 0.0694105785805732, 0.07569839508505538, 0.004513348831096664, 0.08632548226159997, 0.10395774588687345, 0.028450437130231876, 0.10179311633692123, 0.05552565606194548, 0.009344863792648539, 0.07137057575164363, 0.0062883220925868955, 0.10581894835922867, 0.263860899140127, 0.17269918927922845, 0.2330049517331645, 0.13106471946230158, 0.11289327070699073, 0.09261743252864107, 0.11405623838072643, 0.1680144265992567, 0.13828879978973418, 0.20598437899025157, 0.09190566837787628, 0.1004543858289253, 0.0850068565341644, 0.10892525941017084, 0.19131344044581056, 0.21361221733968705, 0.21391207468695939, 0.15134338522329926, 0.16531055996892974, 0.1964007440255955, 0.1578177182818763, 0.11346825704094954, 0.18292041815584525, 0.08326496914378367, 0.10016365689807571, 0.2066584420390427, 0.23980713594937697, 0.20848832587944344, 0.2909252734389156, 0.25038750492967665, 0.4557103483239189, 0.3604805708164349, 0.20962734444765374, 0.19392870948649943, 0.47518317529466003, 1.6820287867449224, 1.2634075060486794, 62.97612592577934, 104.93485763669014, 92.71766200661659, 86.87758818268776, 77.53998443484306, 134.86824542284012, 140.6027913093567, 126.61013334989548, 69.92403030395508, 40.109165757894516, 60.18789254128933, 77.89689168334007, 44.3597012758255, 7.8091048914939165, 0.5118018994107842, 1.264241561293602, 3.668323396705091, 2.288258350454271, 0.5845764849800617, 1.1825098469853401, 1.2175318552181125, 0.2921021415386349, 0.8577471517492086, 0.44147981505375355, 1.400702332612127, 0.510753927519545, 5.214670607820153, 0.8963406714610755, 0.9487794013693929, 3.682299521751702, 3.5444243950769305, 0.6981868261937052, 0.2829877665499225, 0.1525848646997474, 0.14117749087745324, 0.15561169915599748, 0.2535923063987866, 0.08149968183715828, 0.1233266870258376, 0.23713335598586127, 0.08341140230186284, 0.1454855690826662, 0.20363459101645276, 0.13310311711393297, 0.1234604739875067, 0.16624330601189286, 0.20309827057644725, 0.10493353649508208, 0.21058382437331602, 0.1706841544364579, 0.2588589722290635, 0.22092706232797354, 0.28217992396093905, 0.15419441973790526, 0.15783364477101713, 0.19831321405945346, 0.13930395391071215, 0.22402860136935487, 0.09498072016867809, 0.21981517667882144, 0.0906168992514722, 0.16305400058627129, 0.20976378087652847, 0.18211165530374274, 0.14026675693457946, 0.2888289437396452, 0.07529135677032173, 0.1385150954592973, 0.0917626936279703, 0.2098683940130286, 0.20446431211894378, 0.14995268953498453, 0.1432119106175378, 0.11000551472534426, 0.19489543105009943, 0.4507353762164712, 0.5571918888017535, 0.6411878066137433, 1.9514382490888238, 2.803222155198455, 2.0189931616187096, 2.532923184335232, 1.0265707271173596, 0.19807088800007477, 0.8229754550848156, 3.931788196787238, 9.068864118307829, 0.4443496110616252, 0.6988579651806504, 3.208831390365958, 16.327017098665237, 35.527048632502556, 37.834657207131386, 36.38468161225319, 42.432174906134605, 63.24934646487236, 86.94307386875153, 105.34208178520203, 98.66037592291832, 49.067029282450676, 51.20068319141865, 69.235028475523, 81.16527110338211, 109.20455932617188, 19.703363925218582, 0.7392115623224527, 1.1933047114871442, 0.28804915433283895, 0.29702139319851995, 0.17926148168044165, 0.14907588658388704, 0.10952435070066713, 0.3082863934105262, 0.20900915027596056, 0.2914368803612888, 0.190367647446692, 0.22527328692376614, 0.1969940317212604, 0.12486521853134036, 0.11565736262127757, 0.1931683495058678, 0.16376718966057524, 0.1478389638941735, 0.25332970486488193, 0.14417330356081948, 0.14536057657096535, 0.14897637942340225, 0.1418690092395991, 0.1345881397719495, 0.13568442547693849, 0.16252173227258027, 0.1485445533762686, 0.09984933509258553, 0.14195082359947264, 0.17261589062400162, 0.10794913483550772, 0.17169395025121048, 0.21183011296670884], [0.030318973877001554, 0.026550064103503246, 0.03761679028684739, 0.0232126464106841, 0.005162534625924309, 0.03111154306679964, 0.0671162067737896, 0.10043005822808482, 0.016852184780873358, 0.04789302714925725, 0.0600792515615467, 0.029526530852308497, 0.020000848344352562, 0.07945038945763372, 0.030538376850017812, 0.054284866782836616, 0.02256804105854826, 0.032342253980459645, 0.03268313725129701, 0.03985226525401231, 0.05603539648291189, 0.06902282126247883, 0.0336628760851454, 0.11714576947269961, 0.04637748366803862, 0.052456905104918405, 0.013074408198008314, 0.025331969700346235, 0.132353191729635, 0.16257498878985643, 0.12534596695331857, 0.18872088112402707, 0.12425586333847605, 0.02528867651562905, 0.026928418410534505, 0.14370719029102474, 0.805814447812736, 1.0715126967988908, 2.1235863491892815, 18.59800323843956, 77.28912949562073, 63.50461296737194, 51.30996912717819, 53.23265455663204, 62.28390946984291, 107.1102637052536, 121.32990628480911, 93.30460131168365, 42.0416546612978, 25.280678048729897, 37.89108417928219, 43.71927984058857, 24.39974281936884, 6.400281088426709, 2.2533643478527665, 0.3738901996985078, 0.7981386221945286, 0.7819678180385381, 0.6600520724896342, 0.09567485831212252, 0.30224032409023494, 0.21368542278651148, 1.3715676334686577, 1.2475318391807377, 0.29657292820047587, 0.8246498589869589, 0.4589240258792415, 0.8789389114826918, 0.6773115776013583, 0.17429664731025696, 0.1301984253223054, 0.1718781067756936, 0.03600162090151571, 0.03390487931028474, 0.06760077725630254, 0.03936002838599961, 0.01432043425666052, 0.024015290255192667, 0.0030383075954887317, 0.02695480732654687, 0.128689119592309, 0.02825791289069457, 0.06517533474834636, 0.03521327082125936, 0.058802100757020526, 0.002834907877513615, 0.029793570429319516, 0.03463228051259648, 0.04671100483392365, 0.05768025548604783, 0.24911463260650635, 0.08263703057309613, 0.07238397098262794, 0.030958851748437155, 0.04996912590286229, 0.054000598247512244, 0.11679782837745734, 0.017234884362551384, 0.006978388164498028, 0.03178222934366204, 0.12813133624149486, 0.06456750095821917, 0.061884841197752394, 0.029657733284693677, 0.11912304384168237, 0.06700036494294181, 0.07277889744727872, 0.0625533566926606, 0.05828647881571669, 0.09119665017351508, 0.06745385428075679, 0.08067338945693336, 0.026757694758998696, 0.13028015062445775, 0.06784955257899128, 0.21402623184258118, 0.12021983420709148, 0.5231967754662037, 0.23420160548994318, 0.2737355005228892, 0.2031061818706803, 0.33289482293184847, 0.5756307556293905, 1.2399380654096603, 9.0683026984334, 6.0942920576781034, 7.617195714265108, 27.002745643258095, 28.91666304320097, 30.095868967473507, 34.95284624397755, 42.55714260041714, 58.276925683021545, 78.32547828555107, 86.77577644586563, 71.1839134991169, 33.1775739043951, 36.98530778288841, 63.55553403496742, 76.80647179484367, 58.41429591178894, 4.068301571533084, 0.6965035165194422, 0.5044911510776728, 0.6088864523917437, 0.45940567972138524, 0.15250267926603556, 0.252061047940515, 0.10799020528793335, 0.19992282846942544, 0.07594663606141694, 0.030352602443599608, 0.15171163890045136, 0.13192574435379356, 0.035421094435150735, 0.10183442427660339, 0.027709122514352202, 0.08792091422947124, 0.009635173410060816, 0.04784946679137647, 0.0054296382131724386, 0.05171116914425511, 0.043481912871357054, 0.07745993454591371, 0.07396810004138388, 0.09794965968467295, 0.026461822744749952, 0.014562095166184008, 0.016246224913629703, 0.035293689943500794, 0.05963264935417101, 0.02053405733022373, 0.010541588053456508, 0.021689590539608616, 0.0413332691823598, 0.06765734375221655, 0.029368757677730173, 0.01360941967504914, 0.05779505459940992, 0.06797790701966733, 0.025063549728656653, 0.01787023327779025, 0.011968475500907516, 0.0165953348914627, 0.041241550861741416, 0.01746402802382363, 0.04650441689591389, 0.024269279165309854, 0.03339505354233552, 0.04686937914812006, 0.10878188390051946, 0.0682217396388296, 0.06854563514934853, 0.02643097352120094, 0.017031545175996143, 0.06754724614438601, 0.03588311476050876, 0.03929617399990093, 0.012127298814448295, 0.09719781955936924, 0.10056797895231284, 0.06005547686072532, 0.023169670494098682, 0.08695981072378345, 0.08755205941270106, 0.2056371874641627, 0.1986366420169361, 0.13278068363433704, 0.0369073267938802, 0.07479331630747765, 0.114423015184002, 0.2653651137370616, 1.1243622796609998, 1.5663500502705574, 6.292344080284238, 48.96592430770397, 85.33104076981544, 67.14080885052681, 66.5083859860897, 89.0532298386097, 100.36188662052155, 120.22130817174911, 80.4000073671341, 44.08308371901512, 41.224170327186584, 59.363872557878494, 64.25583645701408, 43.24729196727276, 18.95245771855116, 5.50244864076376, 1.0513889766298234, 0.5043290066532791, 0.5661928339395672, 0.38393157650716603, 0.36138091469183564, 0.20429844211321324, 0.17350894660921767, 0.06519181042676792, 1.3854260835796595, 1.9399325852282345, 6.719930386170745, 0.5709973792545497, 0.10062686837045476, 0.9609528200235218, 0.40487240126822144, 0.20732877950649709, 0.06345178582705557, 0.1034912170143798, 0.035375099832890555, 0.0721314107067883, 0.02554023674747441, 0.06493414417491294, 0.03635136912635062, 0.05767789916717447, 0.0505785701534478, 0.01914961980219232, 0.034920808975584805, 0.03331415202410426, 0.08267717334092595, 0.050237597824889235, 0.0564651964668883, 0.02296959861268988, 0.0408195879572304, 0.019036139856325462, 0.019636737706605345, 0.019343483618285973, 1.1975033674389124, 0.124531326291617, 0.0386372247885447, 0.03817003911535721, 0.05183737135666888, 0.09742283873492852, 0.02890604158892529, 0.020395284991536755, 0.10444808285683393, 0.10786614046082832, 0.05107808377943002, 0.042511480569373816, 0.060326987877488136, 0.021261760957713705, 0.06044628069503233, 0.039655302971368656, 0.017561384811415337, 0.03596403854317032, 0.013761216705461266, 0.10815877671120688, 0.4002286941977218, 0.17626795481191948, 0.09159281602478586, 0.1354583227657713, 0.06672090181382373, 0.4838603065581992, 0.6211370544042438, 0.6417878775391728, 0.6550439412239939, 0.8001623104792088, 0.05621836557111237, 0.3021772118518129, 0.15701944939792156, 1.2967475107870996, 7.23296033218503, 9.275457132607698, 12.157418187707663, 33.70141379535198, 41.589311733841896, 40.247938111424446, 38.977582678198814, 35.92871367931366, 45.18022924661636, 58.63208122551441, 81.07494994997978, 93.28144535422325, 63.76117900013924, 39.554281532764435, 57.978174313902855, 71.74733966588974, 82.69761487841606, 26.031067483127117, 0.6848187278956175, 0.7611145370174199, 0.35717409511562437, 0.470588865573518, 0.07959879672853276, 0.19354864081833512, 0.12174945251899771, 0.12733058858430013, 0.10890981531701982, 0.031804349055164494, 0.07968379490193911, 0.02182136999181239, 0.05030939319112804, 0.08753216243349016, 0.07396268236334436, 0.09624041937058792, 0.057320258201798424, 0.0951053416065406, 0.027060628308390733, 0.054460124956676736, 0.05688285491487477, 0.0406601263966877, 0.023303379530261736, 0.024804302702250425, 0.048540539864916354, 0.02734457957558334, 0.013361340115807252, 0.051253809506306425, 0.17315817793132737, 0.038087508582975715, 0.019610467534221243, 0.03321400661661755, 0.03949194884626195, 0.01949468693055678, 0.16619845060631633, 0.2038594172336161, 0.2817877137567848, 0.1255404987023212, 0.17784366791602224, 0.06740878365235403, 0.21958288445603102, 0.17073797498596832, 0.08331239980179816, 0.19849037955282256, 0.0862685075844638, 0.08055917292949744, 0.13557886239141226, 0.2087291528005153, 0.3550329396966845, 0.21499909838894382, 0.0997277045098599, 0.11821550113381818, 0.16440797480754554, 0.11919785974896513, 0.15848640818148851, 0.11289232075796463, 0.2052755092154257, 0.23730875516775995, 0.25165595405269414, 0.15901533683063462, 0.07242990992381237, 0.09403611460584216, 0.20718514424515888, 0.29528268962167203, 0.22839744662633166, 0.2751438890118152, 0.24196224374463782, 0.20589175896020606, 0.2327715462888591, 0.3756295860512182, 0.9149539133068174, 1.642711227759719, 2.0742573961615562, 44.69825550913811, 113.379235714674, 90.86004808545113, 89.48728814721107, 87.95982331037521, 98.09434309601784, 135.98389595746994, 136.18204772472382, 112.24323347210884, 58.83192390203476, 46.470693200826645, 63.56044337153435, 72.87772580981255, 48.17493975162506, 13.471307884901762, 4.616055954247713, 1.820994217414409, 1.7527078441344202, 0.6842430587857962, 1.0452555119991302, 0.4882602032739669, 0.29293138766661286, 0.4033531359164044, 3.705881768837571, 2.481389637105167, 10.114761795848608, 1.0439469572156668, 0.1970820504357107, 3.474624752998352, 1.7345959972590208, 0.9428498195484281, 0.32746423152275383, 0.27628685580566525, 0.09751106525072828, 0.3013833810109645, 0.10710780654335395, 0.25683400745037943, 0.12857340392656624, 0.1833689128397964, 0.2555871399817988, 0.1379551598802209, 0.16060176654718816, 0.11550343377166428, 0.13286519941175357, 0.1535360308480449, 0.19783896685112268, 0.14397139486391097, 0.155790408316534, 0.14130282477708533, 0.22777742677135393, 0.17042294814018533, 1.213207805994898, 0.17194068466778845, 0.13426926860120147, 0.1396122420555912, 0.22360404836945236, 0.150698785437271, 0.18399170832708478, 0.1448974764207378, 0.2508472208864987, 0.18777005636366084, 0.1873316548881121, 0.1997184261563234, 0.14208708191290498, 0.1670564920641482, 0.1560922249336727, 0.1858859066851437, 0.17018020647810772, 0.12026379903545603, 0.17493360297521576, 0.23543504008557647, 0.1636307087028399, 0.429672512691468, 0.17773469095118344, 0.3285389207303524, 0.21294541249517351, 1.070288687478751, 1.2653987179510295, 1.9365595537237823, 0.52275255555287, 0.7810536108445376, 0.28760724992025644, 0.8702638582326472, 1.538971688132733, 0.842289284337312, 14.170382022857666, 17.08806686103344, 25.51489368081093, 46.26023389399052, 41.21983855962753, 41.31972000002861, 52.11040757596493, 62.44540460407734, 77.14542120695114, 91.74442782998085, 102.15428844094276, 84.81539323925972, 52.208480313420296, 59.02614288032055, 83.72780799865723, 99.03247475624084, 94.0965624153614, 13.974081706255674, 0.538879424566403, 0.6823588348925114, 0.5059058626648039, 0.5733705300372094, 0.19810692669125274, 0.20695004670415074, 0.21898520324612036, 0.2887590928003192, 0.15534397680312395, 0.10784202808281407, 0.32087066501844674, 0.2986981126014143, 0.1295706129167229, 0.18377431842964143, 0.20938439498422667, 0.12218457370181568, 0.19929737609345466, 0.2093653366318904, 0.08649871437228285, 0.09655994363129139, 0.1776656266883947, 0.1272127652191557, 0.17683972022496164, 0.12179580706288107, 0.09609857268515043, 0.08650612100609578, 0.12211839639348909, 0.20656862732721493, 0.34689125313889235, 0.08829459300613962, 0.18364298797678202, 0.08124555562972091, 0.17425115365767851, 0.1328505197307095], [0.04575603888952173, 0.05144143186043948, 0.06836118176579475, 0.04672621515055653, 0.045032470879959874, 0.05834307499753777, 0.035120647080475464, 0.10281923197908327, 0.03347486781422049, 0.04644718617782928, 0.05233559735643212, 0.04705853032646701, 0.005024285501349368, 0.07047636943752877, 0.08581919653806835, 0.06602745386771858, 0.061560630274470896, 0.017609281167096924, 0.0673628892400302, 0.0449545824812958, 0.05612795343040489, 0.044541298993863165, 0.16554314905079082, 0.01765797904226929, 0.13034127390710637, 0.03296810340543743, 0.074583117821021, 0.07728649463388138, 0.07172616096795537, 0.16713587217964232, 0.10665908179362305, 0.22077438770793378, 0.14876569854095578, 0.1152557494060602, 0.14766592474188656, 0.13381488126469776, 0.1249643843038939, 0.48654928570613265, 1.2279106420464814, 2.4995165644213557, 63.28284926712513, 82.18569114804268, 73.35199356079102, 53.76339107751846, 45.38025811314583, 59.84338782727718, 86.51504963636398, 112.00430229306221, 112.85088166594505, 82.63480424880981, 43.449353724718094, 29.972472488880157, 32.24974349141121, 35.883826687932014, 30.519413240253925, 15.916158445179462, 5.5824177246540785, 0.9080802008975297, 0.6207774393260479, 0.3783821820979938, 0.4459732520626858, 1.1470626178197563, 3.517769775353372, 1.5800319286063313, 1.3321835780516267, 1.365935504436493, 2.066674428060651, 0.39799539372324944, 0.3634548018453643, 0.31264885619748384, 0.0579346451559104, 0.0935895940347109, 0.04773849716002587, 0.105792052927427, 0.10682002393878065, 0.08664736655191518, 0.05487612841534428, 0.0429267455911031, 0.015359473472926766, 0.011426843138906406, 0.0022809964502812363, 0.05677133238350507, 0.06060515595891047, 0.037419148939079605, 0.13348550128284842, 0.029113336422597058, 0.01913468036946142, 0.04420581113663502, 0.08382560234167613, 0.06019487074809149, 0.5690069985575974, 0.4074295156169683, 0.02842626166966511, 0.09431680227862671, 0.07564706073026173, 0.1429187474423088, 0.15877787926001474, 0.029111740805092268, 0.06335988568025641, 0.08914914636989124, 0.09739560933667235, 0.09112937448662706, 0.11693649867083877, 0.06399936464731582, 0.06097245968703646, 0.057298479878227226, 0.07509705508709885, 0.03678765177028254, 0.05747845440055244, 0.13074166257865727, 0.4394148336723447, 0.03736692771781236, 0.05903042991121765, 0.014413588633033214, 0.11029552377294749, 0.07878349555539899, 0.20044525590492412, 0.34309401002246886, 0.7854104333091527, 1.77661485504359, 0.7032538542989641, 1.4937487710267305, 2.9086206620559096, 2.1262139081954956, 2.7405939158052206, 7.920559085905552, 40.28584107756615, 55.12554958462715, 49.12983611226082, 61.460455656051636, 68.53468805551529, 72.47061565518379, 84.46116864681244, 80.56595206260681, 41.01924732327461, 24.89803098142147, 41.926574036478996, 55.37664771080017, 79.76174041628838, 67.65373572707176, 2.5089106103405356, 2.2063803439959884, 0.9071859426330775, 0.6300113594625145, 0.4655486735282466, 0.12878303095931187, 0.3298938152147457, 0.3559698862954974, 0.30797359300777316, 0.2574519196059555, 0.1172109300387092, 0.05486330410349183, 0.061042844972689636, 0.04746993989101611, 0.024854254806996323, 0.1406631973804906, 0.11189367942279205, 0.09719960071379319, 0.0549101633077953, 0.01289630667088204, 0.015640511810488533, 0.10538122965954244, 0.09746264011482708, 0.08381764651858248, 0.10845640019397251, 0.1059928780887276, 0.10599089655443095, 0.02342253505048575, 0.10866233875276521, 0.06261105125304312, 0.0705041628680192, 0.0784010074858088, 0.07245914312079549, 0.03249998262617737, 0.06865656396257691, 0.039468018294428475, 0.02961271646199748, 0.01582822693308117, 0.03504212785628624, 0.029976031146361493, 0.045257041056174785, 0.021391211921582, 0.05795110970211681, 0.06622967426665127, 0.017175601606140845, 0.12097206024918705, 0.047573087285854854, 0.07117434448446147, 0.03366807854035869, 0.04309099029342178, 0.09189788324874826, 0.027553342006285675, 0.03341462026583031, 0.03470193849352654, 0.035530898894649, 0.02874886769859586, 0.04469434839847963, 0.006176187289383961, 0.05789685128547717, 0.04488695427426137, 0.09454672705032863, 0.030418571950576734, 0.027339319603925105, 0.04055709774547722, 0.11326793654006906, 0.06777946415240876, 0.13338673627004027, 0.24193122197175398, 0.03201976483978797, 0.05847671352967154, 0.23141874466091394, 0.09208658913848922, 0.5081524921115488, 0.7344863971229643, 3.6122773541137576, 4.9343007523566484, 80.24229303002357, 87.50877231359482, 77.59821251034737, 66.36067271232605, 69.47812423110008, 94.79292824864388, 119.44045007228851, 110.03454118967056, 76.08044475317001, 46.55697897076607, 48.5154926776886, 56.0389369726181, 56.767616271972656, 47.641102597117424, 34.638238325715065, 14.483311381191015, 5.5712429992854595, 0.9057594160549343, 0.07943910881294869, 0.16635200096061453, 0.3996141068637371, 0.9581398428417742, 3.023385191336274, 3.488686610944569, 4.526974484324455, 2.0181486569344997, 1.745850162114948, 0.3240502631524578, 0.1774993707658723, 0.19539014669135213, 0.20249589899322018, 0.08458078213152476, 0.018934673425974324, 0.05671702201652806, 0.03795225959038362, 0.02849412921932526, 0.04032451608509291, 0.05721393441490363, 0.024259286146843806, 0.06084983833716251, 0.06998583950917237, 0.030948669482313562, 0.0870151081471704, 0.00999462799882167, 0.06564608644112013, 0.05391031227190979, 0.07698489323956892, 0.05392966006183997, 0.05988573655486107, 0.040375690878136083, 1.2125062686391175, 0.18915230641141534, 0.038778496309532784, 0.04871910801739432, 0.0921010461752303, 0.20610974257579073, 0.15402089076815173, 0.051214449704275467, 0.07735619714367203, 0.03605010540923104, 0.06142273181467317, 0.09103573771426454, 0.0901757889369037, 0.04175507252512034, 0.0769211130682379, 0.03614754197769798, 0.05307034953148104, 0.03104421357420506, 0.03722881403518841, 0.14074210252147168, 0.3876469162059948, 0.2505936735542491, 0.06655031174886972, 0.012896325224573957, 0.07908348648925312, 0.0832133750373032, 0.18502267019357532, 0.4669607727555558, 1.3625066634267569, 0.7301992771681398, 0.4490258835721761, 0.8635867852717638, 2.4058943381533027, 2.7269281866028905, 4.163415217772126, 26.661223769187927, 53.40413175523281, 61.2829215824604, 46.23064488172531, 53.28826077282429, 57.75543786585331, 64.90064665675163, 74.63985845446587, 88.44786912202835, 71.3065405189991, 51.13271623849869, 41.835804507136345, 52.68841356039047, 82.76188462972641, 95.42504712939262, 15.203500986099243, 0.34967314917594194, 1.1286539118736982, 0.5051092710345984, 0.555746778845787, 0.0789875713235233, 0.25215405388735235, 0.25986090127844363, 0.23151213652454317, 0.16690778051270172, 0.1274596035364084, 0.06500527160824277, 0.12716952769551426, 0.07259081496158615, 0.16182356426725164, 0.14153762545902282, 0.06224129843758419, 0.07110923586878926, 0.07525316585088149, 0.10835242530447431, 0.08719381730770692, 0.08670085313497111, 0.0555032320698956, 0.115277969307499, 0.09127241602982394, 0.08880412191501819, 0.10392590775154531, 0.10755501731182449, 0.04349818074842915, 0.06488895480288193, 0.02333499873202527, 0.031133087613852695, 0.05677087596268393, 0.03648585741757415, 0.056251936621265486, 0.01861441629444016, 0.1444161491235718, 0.08466030325507745, 0.2008939880761318, 0.17759175330866128, 0.1009353123663459, 0.11173992868862115, 0.16547749866731465, 0.15596509503666312, 0.10879867870244198, 0.2222601673565805, 0.1325585291488096, 0.24059262505033985, 0.10918566418695264, 0.15745143871754408, 0.21031607233453542, 0.12013091007247567, 0.18214335985248908, 0.1302810263587162, 0.14900152338668704, 0.19008451810805127, 0.20430580421816558, 0.11420296839787625, 0.21551175916101784, 0.10069046300486661, 0.1917421049438417, 0.12821758864447474, 0.16120581538416445, 0.15943389327730983, 0.2578084770357236, 0.15526845585554838, 0.2149110203026794, 0.41239938174840063, 0.2139899111352861, 0.24008861772017553, 0.6784430856350809, 0.13844518514815718, 0.5054081487469375, 0.5796183447819203, 3.3967329701408744, 1.9900761195458472, 83.74666258692741, 108.04865375161171, 106.13582879304886, 91.47284880280495, 76.34092077612877, 88.63243281841278, 119.85015168786049, 132.1987822651863, 129.1302189230919, 98.70828375220299, 63.31391640007496, 48.700071573257446, 53.504738956689835, 59.63263213634491, 53.175330832600594, 29.871487207710743, 13.099445588886738, 3.090170882642269, 1.2331401114352047, 0.2985492080915719, 0.7531759911216795, 1.657785375136882, 3.911030860617757, 3.822283297777176, 6.038454053923488, 2.3468319699168205, 3.458681758493185, 2.783835120499134, 0.42294087703339756, 0.7882677612360567, 0.41880088043399155, 0.273814732208848, 0.07366312929661945, 0.1941913555492647, 0.10418959282105789, 0.16976690443698317, 0.1320669156848453, 0.18762033549137414, 0.12320512323640287, 0.1197195376153104, 0.21965319552691653, 0.23361312691122293, 0.16390803444664925, 0.1375084463506937, 0.19467707636067644, 0.12905541399959475, 0.18200512742623687, 0.16216612479183823, 0.13467704906361178, 0.10924030852038413, 2.2321595856919885, 0.7642370194662362, 0.1225072298257146, 0.2360248693730682, 0.22347678488586098, 0.3837656322866678, 0.5017567228060216, 0.12930657161632553, 0.2704026340506971, 0.19970405817730352, 0.15110759006347507, 0.24508285598130897, 0.22302269440842792, 0.21154949208721519, 0.26371873333118856, 0.15865696856053546, 0.23368866270175204, 0.12420274782925844, 0.22399622888769954, 0.2643882395932451, 1.0025298921391368, 0.15882965148193762, 0.20716804516268894, 0.16487595828948542, 0.18844321399228647, 0.17158540373202413, 0.34837008628528565, 0.9727631800342351, 1.631876821629703, 2.352853696793318, 1.3521435507573187, 3.119244547560811, 2.347130016423762, 2.5515542970970273, 13.568203635513783, 40.701230987906456, 62.4066998809576, 68.15058186650276, 61.67221449315548, 80.67309111356735, 84.65198680758476, 86.94512575864792, 99.02016341686249, 93.57079222798347, 54.59626458585262, 49.20412592589855, 66.33263781666756, 73.98314729332924, 111.11381247639656, 97.54800841212273, 7.849194640293717, 2.3617095965892076, 0.9969120123423636, 0.46852156869135797, 0.6471687450539321, 0.1476174031267874, 0.3109063528245315, 0.2813317975960672, 0.5071671574842185, 0.2571514091687277, 0.24097932851873338, 0.19405135681154206, 0.275599448941648, 0.13957311603007838, 0.19698426505783573, 0.24563640909036621, 0.1340588994207792, 0.14331970014609396, 0.1844581778277643, 0.15751511498820037, 0.24472816876368597, 0.13662877870956436, 0.10922260087681934, 0.17872156924568117, 0.17984314734349027, 0.34323178231716156, 0.31937948253471404, 0.34250815864652395, 0.1906741692801006, 0.1411709896638058, 0.12269774655578658, 0.1379140597418882, 0.12740795005811378, 0.13172404345823452, 0.14448169560637325, 0.08640667321742512], [0.02677994063560618, 0.0457467509113485, 0.014630599107476883, 0.05084530544991139, 0.08142504404531792, 0.12763837206875905, 0.06330990945571102, 0.046377279577427544, 0.010046256429632194, 0.010545539062150056, 0.08232492036768235, 0.029736399083049037, 0.0402683689026162, 0.03978398766776081, 0.05752943623519968, 0.005459319481815328, 0.039403421760653146, 0.03854158421745524, 0.03416199266212061, 0.03045860710699344, 0.053944862956996076, 0.00419983550273173, 0.09633985973778181, 0.040360922139370814, 0.06771308646420948, 0.11283175408607349, 0.043172530058654957, 0.03356417786562815, 0.04582232751999982, 0.08097188125248067, 0.09750781464390457, 0.1297757276915945, 0.21592264180071652, 0.48418931546621025, 0.2343819770612754, 0.12387289287289605, 0.12973339558811858, 0.1959776901639998, 0.2570564142661169, 0.9831051563378423, 3.80805519875139, 43.2462964206934, 75.41586801409721, 78.66479247808456, 76.776392608881, 53.69158253073692, 38.50475884974003, 70.47790378332138, 100.77609479427338, 98.53446587920189, 97.10439741611481, 80.1877811551094, 64.73173052072525, 53.19546215236187, 47.91391275823116, 52.806127443909645, 46.92012928426266, 29.037439562380314, 17.961394898593426, 8.868269082158804, 4.890797361731529, 6.2233079597353935, 5.679001891985536, 1.7754232627339661, 1.9747076067142189, 1.585900119971484, 2.3644302505999804, 0.5347635329235345, 0.28612954483833164, 0.04539580782875419, 0.0633886142168194, 0.15835675498237833, 0.1261465364950709, 0.030284143031167332, 0.05990129568090197, 0.10460140314535238, 0.1319902518298477, 0.07433984923409298, 0.0914054831082467, 0.035398714971961454, 0.07661563766305335, 0.007691337896176265, 0.13067440915619954, 0.031158068304648623, 0.07048989136819728, 0.04044526722282171, 0.057880954482243396, 0.06831005521235056, 0.07262361788889393, 0.030138199690554757, 1.1459685140289366, 0.40415049938019365, 0.04631104660802521, 0.02018853007029975, 0.029585975025838707, 0.03772642034164164, 0.1011470025696326, 0.0447365172294667, 0.016420935753558297, 0.045752127771265805, 0.009634131620259723, 0.05699882662156597, 0.05195845275011379, 0.09732632242958061, 0.0536154013389023, 0.13106011814670637, 0.06985270563745871, 0.00841954572024406, 0.07974522246513516, 0.335432878928259, 2.923856656998396, 0.6083905790001154, 0.14680209453217685, 0.10272800718666986, 0.11590214518946595, 0.16729948605643585, 0.41509714792482555, 1.2069789902307093, 1.3259864668361843, 0.5095775343943387, 2.353591569699347, 4.270769907161593, 2.2640189761295915, 7.57397873327136, 10.043755006045103, 23.694559559226036, 52.24824517965317, 62.585271298885345, 68.8108192384243, 67.4987344443798, 65.6488037109375, 71.49115741252899, 51.227528750896454, 24.67511974275112, 31.632704101502895, 48.03098067641258, 71.3381852209568, 76.38534039258957, 27.708261385560036, 2.4173516733571887, 1.3341595907695591, 0.9734809258952737, 0.7206797786056995, 0.7058783259708434, 0.24606326274806634, 0.45303903229068965, 0.2522008982487023, 0.2744813292520121, 0.11958833332755603, 0.18924482254078612, 0.10577333596302196, 0.07210591793409549, 0.03466389229288325, 0.036215697109582834, 0.09342173507320695, 0.13219134416431189, 0.07666505727684125, 0.08548994272132404, 0.053939701319905, 0.08032988640479743, 0.06244625736144371, 0.055221193688339554, 0.013140602204657625, 0.09685486569651403, 0.08168515196302906, 0.08080934348981827, 0.034984281155630015, 0.010116545236087404, 0.021974241280986462, 0.04738368748803623, 0.04575282167934347, 0.09974911547033116, 0.011757949541788548, 0.0456891639623791, 0.018568828018032946, 0.0625102230696939, 0.07813941527274437, 0.10866481752600521, 0.033378986045136116, 0.017118612086051144, 0.10048946714960039, 0.013458370358421234, 0.051045581421931274, 0.046689857335877605, 0.023873684767750092, 0.01655650386965135, 0.06945040964637883, 0.06217703215952497, 0.09808181392145343, 0.04376896446046885, 0.05242790197371505, 0.04664464569941629, 0.01879207160527585, 0.01620361079403665, 0.1217151281889528, 0.027753287722589448, 0.10850743768969551, 0.06729162079864182, 0.09513723911368288, 0.017919721540238243, 0.04056190686242189, 0.07174275539000519, 0.055468117352575064, 0.05533942523470614, 0.07388327998341992, 0.15876570803811774, 0.14900636218953878, 0.12326619456871413, 0.183492896030657, 0.2992719114990905, 0.12521417636889964, 0.08893688471289352, 0.42526691628154367, 0.48300846945494413, 0.7888247875962406, 3.64328820258379, 14.11302600055933, 72.6188836991787, 93.47328945994377, 82.09434404969215, 75.45851692557335, 72.06019207835197, 69.6251991391182, 100.70332869887352, 110.13014405965805, 100.22748783230782, 70.68867087364197, 56.17099888622761, 58.3201065659523, 61.046327278018, 61.677921786904335, 60.95318667590618, 47.16885633766651, 31.092808172106743, 17.380166687071323, 5.823514312505722, 3.68066537193954, 5.036328602582216, 6.159495608881116, 4.018691433593631, 2.864661058411002, 1.9780555833131075, 3.96365518681705, 1.5029752696864307, 0.14189035340677947, 0.21498875285033137, 0.06167993793496862, 0.27212901797611266, 0.048999524806276895, 0.06938406164408661, 0.07182169021689333, 0.08460749202640727, 0.08467937645036727, 0.03442238630668726, 0.07169711330789141, 0.07705274780164473, 0.03035702378838323, 0.022090175880293828, 0.035317891379236244, 0.04005749877251219, 0.09953333603334613, 0.03207524408935569, 0.06216594447323587, 0.046729161476832815, 0.05879348813323304, 0.03795906508457847, 1.4210035745054483, 0.49242923269048333, 0.01718510851787869, 0.05779695449746214, 0.019103870108665433, 0.09346002989332192, 0.057871610842994414, 0.06636392878135666, 0.0447457013069652, 0.026670202969398815, 0.03760634826903697, 0.011593512808758533, 0.0682999545824714, 0.0921080817352049, 0.07909967273008078, 0.03068720528972335, 0.13621345802675933, 0.044612919955397956, 0.01889849558210699, 0.030850932344037574, 0.7328847830649465, 0.3963327454403043, 0.2759696915745735, 0.23146499530412257, 0.22654333908576518, 0.586872868007049, 0.5414912500418723, 0.9103087813127786, 1.6805659839883447, 0.4422736162086949, 1.6327165765687823, 3.7716954248026013, 5.136144496500492, 11.009206250309944, 22.06638492643833, 41.88303217291832, 59.50196094810963, 67.22724661231041, 70.02578884363174, 71.7176328599453, 76.97811618447304, 83.1390143930912, 80.08605301380157, 55.1016640663147, 41.47176504135132, 44.551043808460236, 65.2285386621952, 84.55914258956909, 60.07688149809837, 8.951651807874441, 0.6920834037009627, 1.2699006451293826, 0.6675076286774129, 0.4902046301867813, 0.18482519953977317, 0.3211297042435035, 0.26358618575613946, 0.21846673887921497, 0.1707489142427221, 0.13684698496945202, 0.08569779602112249, 0.055936078570084646, 0.0702610649750568, 0.06637169906753115, 0.08700222446350381, 0.03477920719888061, 0.06634972407482564, 0.09870086156297475, 0.09708189609227702, 0.0810094784537796, 0.03689687364385463, 0.031253285851562396, 0.0733126352133695, 0.09203122492181137, 0.07220431187306531, 0.1034080222598277, 0.051679687239811756, 0.057906911097234115, 0.02925554490502691, 0.03184409848472569, 0.017142839496955276, 0.07600790035212412, 0.03708326032210607, 0.01055206903401995, 0.017417541748727672, 0.03310356019937899, 0.22114750987384468, 0.19085278938291594, 0.14200905250618234, 0.25855739309918135, 0.12412335287081078, 0.179218377743382, 0.11619487049756572, 0.11876551419845782, 0.08448871871223673, 0.12645617534872144, 0.14870389248244464, 0.19525669369613752, 0.16341619833838195, 0.20622300915420055, 0.15825514012249187, 0.19872090546414256, 0.22033793065929785, 0.21172193752136081, 0.2232269334490411, 0.16990296979201958, 0.18596457433886826, 0.16147977177752182, 0.18960589222842827, 0.23729600507067516, 0.21076364675536752, 0.23679241334320977, 0.1830094461911358, 0.18654542363947257, 0.18860175157897174, 0.25836241606157273, 0.25839198322501034, 0.2805002359673381, 0.2519158838549629, 0.43375073291826993, 0.20262666541384533, 0.23833136045141146, 0.498349730623886, 0.5709765991196036, 0.6082904781214893, 2.923327060416341, 4.168795254081488, 65.66591799259186, 111.13310024142265, 101.70004561543465, 101.93507820367813, 84.42304909229279, 61.00932486355305, 98.74470859766006, 128.02092164754868, 122.79546484351158, 117.63325184583664, 102.92725056409836, 85.15284553170204, 70.7251413166523, 66.3219527900219, 76.63929596543312, 69.20152187347412, 50.43321557343006, 32.915885746479034, 13.605320043861866, 5.523963086307049, 7.717864662408829, 8.534058015793562, 6.151337921619415, 3.1933892564848065, 2.744196359999478, 4.530926272273064, 1.9601919106207788, 0.5628304893616587, 0.29113102646078914, 0.11093441644334234, 0.4175530927022919, 0.1969732961151749, 0.1333063023048453, 0.16432081698440015, 0.22905196150531992, 0.3689433401450515, 0.15947573556331918, 0.1777733420021832, 0.1687594538088888, 0.17489746038336307, 0.34157049958594143, 0.15364169783424586, 0.10211772430920973, 0.12797336268704385, 0.1524971131584607, 0.2667913434561342, 0.12717789912130684, 0.18387056014034897, 0.08251158535131253, 2.3959089489653707, 1.0164971114136279, 0.1614639491890557, 0.12760482699377462, 0.15084265818586573, 0.14780053548747674, 0.33201612008269876, 0.15145541983656585, 0.1734226051485166, 0.20364094380056486, 0.17855657497420907, 0.13884538086131215, 0.20387472031870857, 0.24540021317079663, 0.2154676607460715, 0.20411572535522282, 0.267207688302733, 0.11995040491456166, 0.27084275730885565, 0.48665087088011205, 5.405814126133919, 1.112737397197634, 0.25898193125613034, 0.17106260522268713, 0.4815374140162021, 0.8371863362845033, 1.4898178819566965, 2.420611660927534, 3.620221302844584, 2.1427508583292365, 4.377447757869959, 4.912166940048337, 2.5400798628106713, 12.767046075314283, 37.44842313230038, 54.9100137501955, 74.62601199746132, 84.29307326674461, 86.15972310304642, 82.51454830169678, 90.35988852381706, 88.8257360458374, 68.41074630618095, 42.798669040203094, 57.01937176287174, 69.08481493592262, 89.09248933196068, 106.54938340187073, 49.11658622324467, 3.0260507483035326, 1.3422351074405015, 0.8505042060278356, 0.5726182891521603, 0.6358217226807028, 0.2105271242908202, 0.6503803445957601, 0.294303796836175, 0.30605947540607303, 0.20646321267122403, 0.1501562903285958, 0.2888451225589961, 0.15934615657897666, 0.19583795859944075, 0.16828250518301502, 0.10334865786717273, 0.16123388340929523, 0.16737227590056136, 0.18218327255453914, 0.1422582656960003, 0.23146918101701885, 0.16813878086395562, 0.15848752140300348, 0.093950411392143, 0.2776576025644317, 0.18937238288344815, 0.1883941431879066, 0.15321341925300658, 0.2104948557098396, 0.10047714749816805, 0.16724311251891777, 0.1176604711508844, 0.12195851551950909, 0.0951920764055103, 0.14933700382243842, 0.06574165279744193, 0.14056073647225276], [0.04013630372355692, 0.024155190658348147, 0.048975631361827254, 0.09908787673339248, 0.028881968173664063, 0.05891647313546855, 0.0636862005922012, 0.1362114690709859, 0.01828134227253031, 0.026984250180248637, 0.06642258071224205, 0.051764180752797984, 0.019597170103224926, 0.022049775216146372, 0.07839909274480306, 0.01721483153232839, 0.09124266332946718, 0.0996275813668035, 0.012851497649535304, 0.06365709356032312, 0.020789209556824062, 0.0672898767516017, 0.02572363257058896, 0.034226570642204024, 0.03193581309460569, 0.14383688801899552, 0.07658316128072329, 0.11294502808596008, 0.07535697004641406, 0.11835415658424608, 0.02107552827510517, 0.14578869187971577, 0.14151313458569348, 0.4382832662668079, 0.3919088328257203, 0.35421132284682244, 0.1481189316837117, 0.3272947546793148, 0.20157594757620245, 0.8849837339948863, 0.3469048492843285, 3.5385843459516764, 24.513789899647236, 86.50147676467896, 83.34672644734383, 72.9062394797802, 55.596218928694725, 49.50080260634422, 63.7325095385313, 84.752347022295, 98.21244835853577, 94.08782288432121, 99.12037163972855, 101.26239269971848, 83.85755583643913, 79.53322067856789, 68.38804632425308, 58.60041372478008, 55.97381606698036, 33.83613936603069, 25.48501208424568, 9.472288470715284, 5.774471769109368, 4.849687367677689, 4.056659946218133, 2.837659944780171, 0.8745096554048359, 0.2768155321246013, 0.11198443666216917, 0.022070618433644995, 0.13902460952522233, 0.12500646407715976, 0.07065614729071967, 0.15458826266694814, 0.16148452152265236, 0.08839867921778932, 0.028246110887266695, 0.04251851984008681, 0.07179855005233549, 0.040667440262041055, 0.05577139228989836, 0.057857829160639085, 0.006397295346687315, 0.05701092362869531, 0.0343153686117148, 0.06260889902478084, 0.04985583706002217, 0.06543109368067235, 0.07961074530612677, 0.0064834127715585055, 0.22797494195401669, 0.45396618254017085, 0.10894500053836964, 0.09489789648796432, 0.07998339991900139, 0.032893205861910246, 0.08317035273648798, 0.08547643563360907, 0.00414333719163551, 0.06189152794831898, 0.011238312581554055, 0.05221410778176505, 0.06604534704820253, 0.11604847444687039, 0.07870171830290928, 0.10252479230985045, 0.0766548675892409, 0.08798467213637196, 0.019046134730160702, 0.08329536009114236, 0.34026743669528514, 0.7484906050376594, 0.20302323944633827, 0.07413265644572675, 0.10469685817952268, 0.17590949748409912, 0.29890386562328786, 0.8254977478645742, 1.1079289927147329, 2.7409102488309145, 2.6388614997267723, 2.5103820813819766, 8.291602525860071, 11.710214484483004, 18.254093192517757, 45.63857585191727, 61.79645262658596, 68.44872146844864, 61.40605017542839, 61.59111924469471, 40.219287648797035, 22.991376891732216, 23.49195823073387, 51.264994740486145, 69.54155802726746, 75.36352202296257, 67.58774846792221, 8.939808793365955, 1.745257987640798, 2.049107733182609, 1.1315504251979291, 0.9297550097107887, 0.6386469898279756, 0.5314860900398344, 0.45683903619647026, 0.18911080551333725, 0.2468272889382206, 0.24787373200524598, 0.25237515452317894, 0.13719040638534352, 0.050423643115209416, 0.11228788600419648, 0.11481131426990032, 0.16901752824196592, 0.061419169505825266, 0.08104159860522486, 0.03855877977912314, 0.09133376195677556, 0.056412481717416085, 0.0925956504943315, 0.1592090819031, 0.0573318171518622, 0.12584518000949174, 0.07655602094018832, 0.07111224156687967, 0.0474673089775024, 0.13721424416871741, 0.048383367829956114, 0.017002167260216083, 0.02884356574213598, 0.08033269172301516, 0.05656259221723303, 0.09513718716334552, 0.013197517509979662, 0.037030178209533915, 0.07091776918969117, 0.044532864485518076, 0.06972906383452937, 0.029494830014300533, 0.09080268107936718, 0.03185000969097018, 0.09328097934485413, 0.051658250304171816, 0.04148224419623148, 0.06925116525962949, 0.02800331356411334, 0.04162248042121064, 0.07413568440824747, 0.04267793687176891, 0.021519438341783825, 0.09532639029202983, 0.08052570949075744, 0.05086674238555133, 0.054902226038393565, 0.013359384556679288, 0.1211102184606716, 0.0391868259612238, 0.06006783733027987, 0.03157712570100557, 0.09085119527298957, 0.10144838131964207, 0.11044379003578797, 0.13488551834598184, 0.12872723629698157, 0.07774597310344689, 0.06842928123660386, 0.045884972205385566, 0.13676243950612843, 0.08600164612289518, 0.4399187519447878, 0.28863859770353884, 0.21725962084019557, 0.22520601865835488, 0.3105683787725866, 0.3713973850244656, 1.5399653348140419, 3.319017165340483, 8.700224049389362, 49.46035377681255, 100.4328516125679, 91.3748748600483, 75.69221198558807, 59.90204907953739, 73.60122218728065, 93.06722044944763, 105.40452003479004, 109.13338914513588, 91.91098809242249, 85.19753873348236, 82.84778282046318, 72.04590484499931, 79.37222331762314, 76.18917971849442, 68.23043078184128, 65.00641778111458, 48.684815391898155, 27.96639673411846, 12.06088151782751, 9.069989807903767, 4.509585192427039, 3.0452822288498282, 2.2783434949815273, 2.1101661818102, 0.3401958936592564, 0.06732126959832385, 0.009479775108047761, 0.08642351254820824, 0.10922481989837252, 0.020981340458092745, 0.036443525314098224, 0.12296293076360598, 0.018466075816832017, 0.0085657181989518, 0.058738179577630945, 0.05476780454046093, 0.024887135659810156, 0.13559036568040028, 0.029910208213550504, 0.05303074110997841, 0.08092031683190726, 0.05223184882197529, 0.028245917928870767, 0.04184312463621609, 0.05095704320410732, 0.05505421417183243, 0.16843019257066771, 1.1312482226639986, 1.126434593461454, 0.056866531376726925, 0.04667968620196916, 0.06346186419250444, 0.17157284659333527, 0.036404313941602595, 0.07026590377790853, 0.03791497780184727, 0.07076366964611225, 0.04237650617142208, 0.04707823805802036, 0.06331302647595294, 0.02916478581028059, 0.004158838801231468, 0.01343323381661321, 0.04533561223070137, 0.05443973815999925, 0.06937505939276889, 0.08707893284736201, 0.10335171551560052, 0.4635650018462911, 0.6021008477546275, 0.35587043850682676, 0.21966603468172252, 0.18114307837095112, 0.5112689780071378, 0.5126852332614362, 1.5563609800301492, 1.7629772680811584, 2.7112960629165173, 5.534631013870239, 9.95895305648446, 10.22432416677475, 32.90279924869537, 55.7688132673502, 70.564523935318, 79.58808973431587, 70.79945012927055, 75.79472288489342, 70.16738444566727, 58.94362650811672, 45.95686197280884, 42.192662358284, 55.4018821567297, 71.6793917119503, 87.5442624092102, 28.932139612734318, 2.159998370334506, 2.237023087218404, 1.4842477370984852, 0.8279936795588583, 0.5396077979821712, 0.25447854946833104, 0.554281126242131, 0.16033198102377355, 0.3160098352236673, 0.21207416080869734, 0.3316472430014983, 0.12066106326528825, 0.10690244685974903, 0.0873385880549904, 0.06649419054156169, 0.14186884596711025, 0.030505425493174698, 0.03981970723543782, 0.10805074227391742, 0.033697137332637794, 0.06741531455190852, 0.014402792239707196, 0.06708813132718205, 0.04454379632079508, 0.07751823024591431, 0.12395049183396623, 0.12896194792119786, 0.11899413279024884, 0.05717899039154872, 0.014165843967930414, 0.04643060659873299, 0.011369951025699265, 0.0944337944383733, 0.02874989186238963, 0.03380395835847594, 0.017318234968115576, 0.0742623838596046, 0.009459742686885875, 0.12604935967829078, 0.14907057280652225, 0.22006124316249043, 0.1541522509069182, 0.053062779625179246, 0.17450201441533864, 0.15583495202008635, 0.2096566147520207, 0.16694704012479633, 0.15365777275292203, 0.1505100424401462, 0.2905816293787211, 0.16548155079362914, 0.1388375586248003, 0.1665618654806167, 0.1649170435848646, 0.1462812998215668, 0.16402461100369692, 0.2619420614792034, 0.2990974474232644, 0.1554081280482933, 0.25088780152145773, 0.21683753177057952, 0.2267419229610823, 0.22641315154032782, 0.2781420765677467, 0.21664442494511604, 0.21634881268255413, 0.16704034293070436, 0.15680418204283342, 0.10721466096583754, 0.14424915105337277, 0.2334148992667906, 0.414517768076621, 0.5378911213483661, 0.3565684729255736, 0.4139073961414397, 0.43589248205535114, 0.4567063698777929, 1.39209650689736, 1.8585325218737125, 2.6911051338538527, 37.54678465425968, 117.32145577669144, 103.9442203938961, 95.61637446284294, 78.84676471352577, 72.99985885620117, 86.44232913851738, 111.70118495821953, 124.73173454403877, 115.21712869405746, 114.95386362075806, 120.80674275755882, 104.59905445575714, 102.65969932079315, 86.45202621817589, 79.66127380728722, 79.83253061771393, 58.4075702726841, 45.60527063906193, 22.769715785980225, 11.939530279487371, 9.407656788825989, 5.262081138789654, 4.193584648892283, 3.5175225511193275, 0.45628031773958355, 0.17678545438684523, 0.07549241941887885, 0.31118373794015497, 0.17121761018643156, 0.2206345077138394, 0.16508085042005405, 0.35677630396094173, 0.19491915008984506, 0.12464138679206371, 0.13589013396995142, 0.2618465025443584, 0.0997094254125841, 0.17346557549899444, 0.12766510422807187, 0.312721497612074, 0.09210277537931688, 0.19598591316025704, 0.12151761300629005, 0.11639122050837614, 0.12368001611321233, 0.17508210672531277, 0.22308132407488301, 1.3997858692891896, 1.5649163397029042, 0.1848213403718546, 0.14022688876139, 0.15497469896217808, 0.14519825403112918, 0.25013413571286947, 0.1949321525171399, 0.09948312232154422, 0.13464108458720148, 0.13169808313250542, 0.1883508314494975, 0.2198576572118327, 0.15628166554961354, 0.16754651733208448, 0.21611341828247532, 0.2195562413544394, 0.23320378793869168, 0.12407129863277078, 0.298819646704942, 0.6950002815574408, 2.903528935275972, 0.5767129256855696, 0.3474375035148114, 0.18152374075725675, 0.4338186245877296, 0.6521264102775604, 1.2070215004496276, 1.72417220659554, 2.8062897780910134, 2.982316045090556, 4.757046438753605, 8.63460537046194, 32.87628427147865, 59.35754969716072, 83.00013944506645, 90.34443855285645, 87.32984751462936, 81.39026463031769, 87.68401131033897, 58.33469398319721, 42.68310584127903, 46.61618359386921, 74.89917173981667, 86.28923535346985, 97.7760797739029, 94.0532599389553, 16.898799017071724, 1.028559801634401, 2.3892360320314765, 1.1117648868821561, 0.7667040370870382, 0.48771656525786966, 0.47235960024408996, 0.6155362143181264, 0.23492291365982965, 0.4608981090132147, 0.2221355607616715, 0.40816997119691223, 0.16010282066417858, 0.17009837727528065, 0.1311007878393866, 0.1468523230869323, 0.2817120443796739, 0.1899087181664072, 0.1237579267763067, 0.15805600705789402, 0.11014880117727444, 0.2018662163754925, 0.15342877566581592, 0.14694887649966404, 0.16941784269874915, 0.1568458165274933, 0.1858870347496122, 0.21656730095855892, 0.2506469894433394, 0.18749739130726084, 0.22968761099036783, 0.14563928270945325, 0.11832462652819231, 0.2685825020307675, 0.19450059364316985, 0.12759137927787378, 0.18050667189527303, 0.125584804918617, 0.15495279076276347], [0.04481953015783802, 0.043189109637751244, 0.094443687266903, 0.03856465016724542, 0.09837401972617954, 0.06500182804302312, 0.012204634313093266, 0.01980485085368855, 0.10452575603267178, 0.029712552022829186, 0.04273095590178855, 0.061333881894825026, 0.01691921555902809, 0.0653324399900157, 0.062329101929208264, 0.054731064519728534, 0.10438502256874926, 0.03485693232505582, 0.02575535010691965, 0.11083944380516186, 0.03245291190978605, 0.021023292210884392, 0.061034614554955624, 0.15417221467942, 0.09010351859615184, 0.058121324982494116, 0.04752434673719108, 0.0519570575124817, 0.02655663396581076, 0.08363050656043924, 0.10053576232166961, 0.09273040224798024, 0.12001672323094681, 0.13276391109684482, 0.2689930284395814, 0.5109074036590755, 0.5953125120140612, 0.5827099538873881, 0.4967416450381279, 0.29023501672782004, 0.7990670786239207, 0.8418470830656588, 2.1133784344419837, 10.820387732237577, 67.39312291145325, 94.94748875498772, 80.97899749875069, 77.06464514136314, 56.70662194490433, 40.40109649300575, 56.0602842271328, 74.14916038513184, 84.29423600435257, 88.49848240613937, 86.04927822947502, 91.31514966487885, 97.1911695599556, 88.5211443901062, 68.68635311722755, 52.952712178230286, 37.18971401453018, 39.077844098210335, 29.761821292340755, 19.66839250177145, 9.881349820643663, 3.869016277603805, 0.4146434285212308, 0.5993933149147779, 0.4150284844217822, 0.22320757823763415, 0.41498728038277477, 0.27444327191915363, 0.1469689590157941, 0.06763175450032577, 0.054983186928438954, 0.07181699242210016, 0.13713596243178472, 0.12234670328325592, 0.05798033547762316, 0.03727572147909086, 0.07571819558506832, 0.06444207057938911, 0.04018307015940081, 0.04062780957610812, 0.04800752940354869, 0.06019518987159245, 0.087537951185368, 0.04289477757993154, 0.056549868095316924, 0.0222024795220932, 1.16056056227535, 0.5076243204530329, 0.0329550304741133, 0.01747930327837821, 0.06437118805479258, 0.10642226247000508, 0.15636558760888875, 0.07075917223119177, 0.08027642950764857, 0.09153472812613472, 0.04848214768571779, 0.05216810946876649, 0.10428463967400603, 0.07030633598333225, 0.05419318928034045, 0.04241687900503166, 0.09635338908992708, 0.014216851777746342, 0.08911443612305447, 0.14496879681246355, 0.07831723385606892, 0.22228416841244325, 1.067817157600075, 0.7873028505127877, 0.26368245715275407, 0.08516212867107242, 0.2374605688964948, 0.4852200101595372, 0.4989734315313399, 0.1620720056234859, 3.090545875020325, 6.467728419229388, 3.3095461735501885, 18.029207959771156, 43.69077377021313, 43.7455478310585, 41.06998600065708, 49.37494195997715, 41.87953636050224, 22.027098834514618, 14.815508555620909, 41.62347570061684, 70.36163002252579, 75.6452389061451, 80.33061549067497, 35.57336814701557, 4.462357526645064, 1.8136506364680827, 1.7356423661112785, 0.47680672723799944, 0.4506052628858015, 0.3701083338819444, 0.46314767736475915, 0.23556402535177767, 0.2517364325467497, 0.14945666771382093, 0.07020219039986841, 0.2107307844562456, 0.07851983275031671, 0.13156019209418446, 0.12788003019522876, 0.11404505421523936, 0.09328408152214251, 0.04342548367276322, 0.06609620642848313, 0.07689602105529048, 0.04038913488329854, 0.060506146037369035, 0.062304707535076886, 0.12427319248672575, 0.09062488476047292, 0.07017558440566063, 0.021321806270861998, 0.02431675991829252, 0.06621228574658744, 0.04875357335549779, 0.03073487529036356, 0.09743460177560337, 0.012995090237382101, 0.12130185583373532, 0.05082356423372403, 0.0515132012515096, 0.01643486029934138, 0.07627021986991167, 0.05441085377242416, 0.008755049348110333, 0.03239860896428581, 0.058670725775300525, 0.036601168612833135, 0.03663645031338092, 0.06908447146997787, 0.027087458802270703, 0.06317574399872683, 0.0384616957308026, 0.024533541254641023, 0.03500243037706241, 0.04480367046198808, 0.03730272452230565, 0.012781068762706127, 0.08759844364249147, 0.05883086640096735, 0.10976435383781791, 0.06552619248395786, 0.06016934828949161, 0.03880405958625488, 0.06526944649522193, 0.06823123912909068, 0.05341208256140817, 0.0246449580299668, 0.114969807327725, 0.09890133049339056, 0.10185717110289261, 0.19678217824548483, 0.0314408970734803, 0.1242650585481897, 0.012905010207759915, 0.05435442828456871, 0.037479637685464695, 0.13402706128545105, 0.16709260497009382, 0.2576997078722343, 0.48794487956911325, 0.23120660916902125, 0.30413550208322704, 0.37910687446128577, 0.6684251013211906, 1.1005943175405264, 2.1247711731120944, 6.896926313638687, 36.828022822737694, 91.41208246350288, 99.80972304940224, 77.06304162740707, 72.94467821717262, 71.60540208220482, 76.01764932274818, 89.50009346008301, 98.8842599093914, 98.20440798997879, 95.80511033535004, 89.1469556093216, 93.45628917217255, 90.68442910909653, 89.6548743546009, 80.2887113392353, 64.91912126541138, 59.70034450292587, 46.39405131340027, 31.583586037158966, 18.229582607746124, 9.245513789355755, 3.017959319986403, 1.6661009914241731, 0.7880946923978627, 0.43530137627385557, 0.13053421746008098, 0.38047794776502997, 0.29131478222552687, 0.07206352645880543, 0.24456783517962322, 0.07327876359340735, 0.010052342040580697, 0.13187070668209344, 0.0511034949158784, 0.0655843026470393, 0.02814526600559475, 0.08864150251611136, 0.057583776288083754, 0.047290911606978625, 0.0823815907642711, 0.050175238866358995, 0.07070863197441213, 0.048817015849635936, 0.0919258473732043, 0.06714534349157475, 0.026090734063473064, 1.0002394462935627, 1.4080355828627944, 0.03405097479117103, 0.027948483693762682, 0.03707166055392008, 0.09159162858850323, 0.1277196075534448, 0.07263293926371261, 0.05873869165952783, 0.051424329067231156, 0.058626026220736094, 0.012874481963081053, 0.04235221567796543, 0.05232388255535625, 0.048864260970731266, 0.05526458706299309, 0.04345344779721927, 0.043743664646171965, 0.06025333714205772, 0.11046941639506258, 0.11437507244409062, 0.1926790366997011, 0.5439866473898292, 0.7285273668821901, 0.7214123080484569, 0.057497950620017946, 0.43860556615982205, 1.5961713250726461, 1.8620453146286309, 3.3679739758372307, 9.981256909668446, 11.618768591433764, 8.670580890029669, 34.98001478612423, 65.3628158569336, 77.41362601518631, 73.09396460652351, 71.50071769952774, 63.93130347132683, 55.346028953790665, 38.85459087789059, 36.698221787810326, 46.85870558023453, 69.47134539484978, 84.31575044989586, 59.89667236804962, 11.723413076251745, 1.139110594522208, 2.0103417383506894, 0.8393525169230998, 0.4758637840859592, 0.39260823279619217, 0.4269335127901286, 0.20621125353500247, 0.20308320497861132, 0.2417607803363353, 0.09188889584038407, 0.25422734732273966, 0.19965237501310185, 0.10357323175412603, 0.023624582900083624, 0.14157554920529947, 0.04928643538733013, 0.049029314614017494, 0.12822348129702732, 0.15499429166084155, 0.09579460383974947, 0.06144831364508718, 0.12469565263018012, 0.1117516694648657, 0.09401316739968024, 0.08599132284871303, 0.06770043284632266, 0.01975808998395223, 0.06315974329481833, 0.1274540671147406, 0.012252921223989688, 0.12768266344210133, 0.0489280819601845, 0.07822495521395467, 0.021581797300314065, 0.06525528631755151, 0.0185844409497804, 0.02348576603253605, 0.02653915638802573, 0.036535573890432715, 0.09562314546201378, 0.15082426776643842, 0.2959758852375671, 0.1435177496750839, 0.2559086086694151, 0.16355883912183344, 0.2016691761673428, 0.1321794104296714, 0.2795774198602885, 0.18744686589343473, 0.12881043105153367, 0.23162084631621838, 0.11163219853187911, 0.14484745566733181, 0.12230599648319185, 0.3247925592586398, 0.19072625320404768, 0.13060627999948338, 0.13795544189633802, 0.2799259324092418, 0.29548835358582437, 0.23210157989524305, 0.1081183148198761, 0.2423330652527511, 0.1804109793738462, 0.12914254213683307, 0.22875559225212783, 0.18830728222383186, 0.20114392857067287, 0.36623218562453985, 0.11073231478803791, 0.16705304849892855, 0.15432643296662718, 0.2072578005027026, 0.2713461412349716, 0.5804350040853024, 0.6085198908112943, 0.5228659557178617, 0.46338127576746047, 0.5387600872199982, 0.7156870246399194, 0.7394821790512651, 2.434051064774394, 17.14525569230318, 95.0862269103527, 121.59991979598999, 93.33677798509598, 96.62268206477165, 81.6668289899826, 63.46551686525345, 74.33755427598953, 99.21104237437248, 109.19650375843048, 108.96528616547585, 101.98448315262794, 113.20861726999283, 118.25756594538689, 115.13583585619926, 90.46918585896492, 78.06831568479538, 71.935353577137, 67.01928377151489, 49.118641912937164, 29.20712325721979, 14.927637688815594, 8.169604372233152, 3.6680711852386594, 1.3627617247402668, 0.9799292986281216, 0.5600065877661109, 1.5462288237176836, 0.64199935994111, 0.1626149905496277, 0.370182518963702, 0.18841701617930084, 0.16515827126568183, 0.21717970637837425, 0.1530079630902037, 0.21723861806094646, 0.12892932310933247, 0.1380932141910307, 0.09496696817222983, 0.12780629040207714, 0.29089288611430675, 0.17628348054131493, 0.2817731676623225, 0.2035242336569354, 0.14204840117599815, 0.22679458576021716, 0.14385361602762714, 1.8028191989287734, 1.6658113757148385, 0.1272473344579339, 0.15090958506334573, 0.13188203185563907, 0.16993652970995754, 0.3221233806107193, 0.34751278697513044, 0.22041918098693714, 0.1840773521689698, 0.14342940441565588, 0.11185234179720283, 0.18378951761405915, 0.2134782003122382, 0.20167342125205323, 0.08884891794878058, 0.17399630014551803, 0.17597057623788714, 0.16748033260228112, 0.4284551233286038, 1.194107299670577, 1.519968907814473, 5.270084934309125, 2.644888451322913, 1.3252249639481306, 0.36036345991306007, 0.3627643670188263, 1.4651469932869077, 1.3510584714822471, 3.925256347283721, 13.899948634207249, 25.16694825142622, 44.83675427734852, 70.43557405471802, 87.7500669658184, 73.80554482340813, 70.28204709291458, 78.34360331296921, 60.42781546711922, 39.28142577409744, 37.174100652337074, 67.45161697268486, 87.73091599345207, 94.01704788208008, 106.43512353301048, 49.37483936548233, 4.566329447552562, 1.8673041136935353, 1.7030757386237383, 0.4001825622981414, 0.4788266750983894, 0.30087073508184403, 0.4981344484258443, 0.3010446351254359, 0.3098101116484031, 0.3488722530892119, 0.13384412188315764, 0.20182052976451814, 0.20137755665928125, 0.21598714927677065, 0.23471097112633288, 0.22127656935481355, 0.19661889091366902, 0.1326623556087725, 0.3175051440484822, 0.20816552132600918, 0.26840260543394834, 0.14131505537079647, 0.18771236180327833, 0.2142167411511764, 0.14528563449857756, 0.18039031798252836, 0.14025489741470665, 0.11166184733156115, 0.16319631482474506, 0.22776237601647153, 0.14975458063418046, 0.15905904932878911, 0.11508766780025326, 0.2822744142031297, 0.10056055005406961, 0.12455462972866371, 0.09517363403574564, 0.13128307415172458, 0.1120208167412784, 0.12318427630816586], [0.054189549045986496, 0.020102420530747622, 0.06732481706421822, 0.10120639664819464, 0.0582334931823425, 0.04132929127081297, 0.08541884497390129, 0.05930349572736304, 0.06805628523579799, 0.06856909443740733, 0.03001968056196347, 0.05231223454757128, 0.10012175524025224, 0.08169347885996103, 0.024699081004655454, 0.11261517312959768, 0.027168696142325643, 0.05035451576986816, 0.05110769176098984, 0.06617621736950241, 0.05547251086682081, 0.052241964294807985, 0.034817409250536, 0.07845114698284306, 0.08075605728663504, 0.03619955539761577, 0.0747665693052113, 0.02671103778993711, 0.11359757627360523, 0.1348636843613349, 0.10973437107168138, 0.049562295389478095, 0.013517862771550426, 0.034658129516174085, 0.08071843782090582, 0.24274627823615447, 0.5732805817387998, 0.6777642283122987, 0.6407061230856925, 0.6280752446036786, 0.31679517589509487, 0.6196255667600781, 0.441785579896532, 2.092094589024782, 2.376059526577592, 19.46235615760088, 80.91149032115936, 94.44819554686546, 75.5963659286499, 67.30077266693115, 46.812063083052635, 30.285621285438538, 42.155059576034546, 64.3439157307148, 79.9202299118042, 87.26603373885155, 86.75075858831406, 93.88239070773125, 83.56366440653801, 63.17793309688568, 45.41048549115658, 27.26157635450363, 31.8307950720191, 32.99208305776119, 17.22751557826996, 5.895304810255766, 0.878239570884034, 1.0068937204778194, 0.6163569702766836, 0.1995797929703258, 0.23445340135367587, 0.7892426464240998, 0.5706547445151955, 0.30031338217668235, 0.23048770555760711, 0.20841969206230715, 0.01559521297167521, 0.10706302535254508, 0.03232790455513168, 0.15405381243908778, 0.1557588076684624, 0.05387369841628242, 0.10379622486652806, 0.08489018349791877, 0.06381474799127318, 0.09173911559628323, 0.02275798819027841, 0.04425376871949993, 0.08826123346807435, 0.19943451014114544, 0.786626486806199, 0.9737101010978222, 0.14342628739541396, 0.06032190787664149, 0.02595812526124064, 0.08393414886086248, 0.10750783898402005, 0.1193614439398516, 0.03187743575836066, 0.040481131509295665, 0.06266426324145868, 0.01659898440266261, 0.0619991727580782, 0.0539134738210123, 0.11083026343840174, 0.05533360679692123, 0.04242752882419154, 0.2692153461975977, 0.0930838352360297, 0.07998065397259779, 0.18214677373180166, 0.24445761140668765, 0.4315067455172539, 0.21875463280593976, 1.9518861500546336, 1.5968409203924239, 1.7456944892182946, 2.389611261896789, 6.0125071462243795, 9.482741709798574, 8.454220499843359, 12.760309036821127, 15.538937486708164, 18.508765026926994, 15.643726363778114, 28.068643547594547, 38.15245695412159, 25.260020457208157, 14.593777153640985, 29.04939942061901, 66.07735991477966, 68.56118783354759, 68.54639902710915, 43.63041780889034, 8.501493763178587, 0.9254508500453085, 0.9837476187385619, 0.9046231582760811, 0.28829617076553404, 0.7206870813388377, 0.8054963930044323, 0.3930923208827153, 0.35805603372864425, 0.12437509678420611, 0.21993213915266097, 0.10074087709654123, 0.18712913763010874, 0.15312219446059316, 0.010037240263045533, 0.04226136195939034, 0.15639272052794695, 0.0856130501779262, 0.04856681560340803, 0.047611463742214255, 0.11124277138151228, 0.05652522879245225, 0.16822163423057646, 0.06379954138537869, 0.08266958859167062, 0.1323965034680441, 0.17844934947788715, 0.0845182710327208, 0.11667773404042237, 0.04059506973135285, 0.12452460243366659, 0.07122938215616159, 0.027696034740074538, 0.01945234926097328, 0.06447745618061163, 0.024587237494415604, 0.07817636680556461, 0.03472950556897558, 0.03527300257701427, 0.01633421579754213, 0.10174404553254135, 0.016511681860720273, 0.08684298183652572, 0.05644607874273788, 0.06510778446681798, 0.07868173226597719, 0.00817232519693789, 0.017512022714072373, 0.11502352397656068, 0.06031656070263125, 0.04124731363845058, 0.042317138068028726, 0.06880526067106985, 0.0287452293196111, 0.050659928092500195, 0.03262472280766815, 0.06604070120374672, 0.014149072358122794, 0.033778157594497316, 0.025855387902993243, 0.061686873305006884, 0.056584789854241535, 0.09762400528416038, 0.018596894187794533, 0.046911867102608085, 0.025481462362222373, 0.03719333195476793, 0.0409774984291289, 0.039059837072272785, 0.07249438771395944, 0.037498057790799066, 0.09072800618014298, 0.04002464760560542, 0.052215684845577925, 0.054039824462961406, 0.06076871788536664, 0.12108892624382861, 0.2409249884658493, 0.5601123289670795, 0.46316542953718454, 0.48000262293498963, 0.3312628105049953, 0.445690760971047, 0.8104596985504031, 0.9520822553895414, 4.715725556015968, 9.767205845564604, 57.42621973156929, 100.59301301836967, 95.18488481640816, 73.92249494791031, 62.43528574705124, 63.30852068960667, 65.49433439970016, 82.63399869203568, 94.42726626992226, 95.44948741793633, 98.43633994460106, 98.19081991910934, 96.82292371988297, 89.87428218126297, 74.27764669060707, 60.69333761930466, 57.19308324158192, 45.02970412373543, 37.86643870174885, 24.78270146995783, 9.057723116129637, 1.864143752027303, 0.6034148053731769, 0.6094240047968924, 1.1145655740983784, 0.4459885699907318, 0.6248119322117418, 0.4390441457508132, 0.25072043237742037, 0.18700947373872623, 0.19934485870180652, 0.03132463592919521, 0.05977596178126987, 0.09401549032190815, 0.08322896013851278, 0.11408665159251541, 0.08732474700082093, 0.03506140514218714, 0.019515355743351392, 0.03339756942295935, 0.1642153726425022, 0.01538009961222997, 0.1102704688673839, 0.05598605850536842, 0.07638126000529155, 0.9322867426089942, 2.754279593937099, 0.05906921454879921, 0.07254149924847297, 0.006612356291952892, 0.22545310930581763, 0.1526275827200152, 0.11093699169578031, 0.016512587280885782, 0.05772426484327298, 0.028272943236515857, 0.0731913979689125, 0.1339325265143998, 0.04909713949018624, 0.0568457549525192, 0.16873609100002795, 0.06346815018332563, 0.03602493918151595, 0.08969376402092166, 0.1642122259363532, 0.017346742715744767, 0.06268252749578096, 0.4117389296879992, 0.2567876974353567, 2.15790088288486, 1.379495789296925, 2.022694875486195, 0.91843256726861, 3.361260211095214, 5.250361142680049, 2.5598426023498178, 17.490773051977158, 39.52860631048679, 51.62862382829189, 56.15595169365406, 48.89413855969906, 51.42100676894188, 51.36757403612137, 41.85367874801159, 36.225599348545074, 43.42479184269905, 65.71861356496811, 83.68727177381516, 70.13839960098267, 26.061942726373672, 2.4912021355703473, 1.4666565810330212, 1.478429774288088, 0.4892868606839329, 0.5278189899399877, 0.6214499438647181, 0.3651269496185705, 0.3441987413680181, 0.11900670477189124, 0.29367582115810364, 0.09815991012146696, 0.2233300029183738, 0.03419588283577468, 0.033770880836527795, 0.03338356138556264, 0.18699399253819138, 0.09825202549109235, 0.0809249997837469, 0.06318710627965629, 0.11592108479817398, 0.10072145509184338, 0.06141147343441844, 0.09885091640171595, 0.06623554465477355, 0.06333821496809833, 0.17885799083160236, 0.0641636984073557, 0.052783379578613676, 0.05725241106119938, 0.03296060400316492, 0.028812883501814213, 0.058960374881280586, 0.04144961938436609, 0.0027260510478299693, 0.02265185921714874, 0.023984177569218446, 0.04234854204696603, 0.040700558602111414, 0.09122374598518945, 0.07735599676379934, 0.023866617666499224, 0.10539834358496591, 0.182257799024228, 0.19314452656544745, 0.1731774292420596, 0.16174641059478745, 0.20477846323046833, 0.2944143768399954, 0.16170967428479344, 0.12078357700374909, 0.1511230118921958, 0.1486424426548183, 0.12084378002327867, 0.13782886118860915, 0.16054110339609906, 0.12213943628012203, 0.1349233085056767, 0.13419459370197728, 0.19801849237410352, 0.15778485598275438, 0.14307808654848486, 0.13724716583965346, 0.16113820573082194, 0.2188627191935666, 0.15604248619638383, 0.17703365825582296, 0.13012747600441799, 0.2103176011587493, 0.11596306067076512, 0.141122171189636, 0.17551795521285385, 0.20674249768489972, 0.1300563634140417, 0.14848626509774476, 0.17242845380678773, 0.11803051340393722, 0.31238007999490947, 0.5525342293549329, 0.5401810922194272, 0.43179751897696406, 0.5698312574531883, 0.4641847842140123, 0.7956802728585899, 0.28601952886674553, 3.7380726914852858, 2.107419641688466, 38.73431593179703, 116.140615940094, 120.30708476901054, 89.54790249466896, 85.56842163205147, 70.30601620674133, 53.04312452673912, 67.77114182710648, 91.3661277294159, 105.21212115883827, 107.83728629350662, 101.46623656153679, 112.0786415040493, 115.02088442444801, 93.05676341056824, 84.51389461755753, 83.50797459483147, 70.6668372452259, 63.18977326154709, 43.22668947279453, 18.765076473355293, 7.352748904377222, 1.6894052596762776, 1.2620982388034463, 0.9772013418842107, 0.3781641094246879, 1.1152564245276153, 1.4704479463398457, 0.6037146330345422, 0.21752701664809138, 0.2239110303344205, 0.2099733633804135, 0.17841225693700835, 0.15143116645049304, 0.19745028926990926, 0.30399850162211806, 0.2162410379969515, 0.24847537628374994, 0.16112824610900134, 0.13735207583522424, 0.2450807037530467, 0.14039120025699958, 0.3542734554503113, 0.15108949650311843, 0.23617392231244594, 1.5854436694644392, 4.05008677393198, 0.12807278078980744, 0.2157483558403328, 0.1710362292942591, 0.32625752908643335, 0.2781074628001079, 0.20299672993132845, 0.17932346585439518, 0.23103389656171203, 0.18746335641480982, 0.24316208873642609, 0.31786992447450757, 0.20419704989762977, 0.17605184140847996, 0.1862963440362364, 0.18606050434755161, 0.6795715063344687, 0.5296150466892868, 0.9115997620392591, 0.6849732727278024, 0.3872169752139598, 0.6783667928539217, 0.9852914046496153, 5.200683558359742, 5.450222343206406, 7.059602709487081, 5.8800106309354305, 12.989520337432623, 24.492661133408546, 37.412423864006996, 45.59919096529484, 47.1540143340826, 52.870062813162804, 51.48738160729408, 58.975544795393944, 56.24157249927521, 41.69883705675602, 33.86173479259014, 57.10700646042824, 87.53213346004486, 91.87225297093391, 99.21956911683083, 66.07517123222351, 13.105733301490545, 0.8509471791330725, 1.2839921889826655, 1.1629391158930957, 0.3135244717122987, 0.5981098744086921, 0.6010629096999764, 0.45376761350780725, 0.33237552735954523, 0.13575403892900795, 0.4766857868526131, 0.13325628155143932, 0.3770323045318946, 0.17293436103500426, 0.15560203639324754, 0.10187908672378398, 0.25010136247146875, 0.2564786374568939, 0.14939361484721303, 0.19030196737730876, 0.3433105390286073, 0.23288177006179467, 0.23783263721270487, 0.19362416176591069, 0.16947164840530604, 0.23339541046880186, 0.22124783339677379, 0.2537654642947018, 0.23582533554872498, 0.1440597846521996, 0.23952557996381074, 0.1925634843064472, 0.16097045066999272, 0.11463160321000032, 0.10374739897088148, 0.11067788567743264, 0.1147788304660935, 0.1974820828763768, 0.09681326089776121, 0.23739436932373792, 0.21217564208200201, 0.1136459420376923], [0.02946123855508631, 0.06802407602663152, 0.08363743821973912, 0.06863232541945763, 0.09190714525175281, 0.1356747924000956, 0.03338517926749773, 0.0368131334107602, 0.01867196428065654, 0.025029939715750515, 0.06643654793151654, 0.08394380420213565, 0.08496554117300548, 0.06407841079635546, 0.04888361247139983, 0.06509139042464085, 0.039957275439519435, 0.029439976024150383, 0.025420058918825816, 0.03010601274581859, 0.036251824858481996, 0.11494519771076739, 0.06545597047079355, 0.12966249079909176, 0.10198588177445345, 0.07726892057689838, 0.06748520259861834, 0.04095448814041447, 0.062372391403187066, 0.11175165462191217, 0.0916742518893443, 0.13688205886865035, 0.10372975812060758, 0.16671755322022364, 0.08156019655871205, 0.08739424170926213, 0.10709351277910173, 0.4515449405880645, 0.6875422911252826, 0.8592940249945968, 1.0186702385544777, 0.5110719823278487, 0.7586183084640652, 0.3435475513106212, 0.5342183809261769, 3.5233155777677894, 0.596413443563506, 35.968360751867294, 90.07118001580238, 89.12307769060135, 84.06628623604774, 72.40601152181625, 50.6312495470047, 43.975253105163574, 37.63131871819496, 40.43382793664932, 50.455075800418854, 58.08592893183231, 66.54673352837563, 62.77390077710152, 50.304900258779526, 41.1125323176384, 33.6075322329998, 22.873742803931236, 11.372263468801975, 3.418615758419037, 4.183609234169126, 0.7051328534726053, 2.476520435884595, 2.373157669790089, 0.7044287631288171, 0.1053928813780658, 0.8757482701912522, 0.6262322841212153, 0.41302418103441596, 0.8629367232788354, 0.3467926662415266, 0.4865878476994112, 0.36844951508101076, 0.22893946676049381, 0.0992035107628908, 0.16996452352032065, 0.21132517053047195, 0.14319479669211432, 0.13126432750141248, 0.041293293397757225, 0.04199381030048244, 0.07674483815208077, 0.06744503014488146, 0.06784603479900397, 0.4988424573093653, 1.712642794009298, 0.02088739383907523, 0.11811611271696165, 0.02046004850853933, 0.031537561808363535, 0.0088458641039324, 0.019357096462044865, 0.0564249164017383, 0.10376305828685872, 0.046728530651307665, 0.07387369885691442, 0.11780084096244536, 0.056778764992486686, 0.09852964809397236, 0.02605507572297938, 0.024244699234259315, 0.15006646077381447, 0.21244116767775267, 0.08487195635098033, 0.15144121513003483, 0.23293174628634006, 0.4462929395958781, 0.6428788346238434, 0.8420208643656224, 3.1383515847846866, 7.339958790689707, 10.868891179561615, 11.744581740349531, 5.759440725669265, 3.201899849809706, 3.745441446080804, 2.4939425010234118, 15.830833073705435, 40.43806850910187, 38.529172539711, 14.840938691049814, 19.189498499035835, 52.12617293000221, 59.05718721449375, 66.77966862916946, 55.52673205733299, 11.425921339541674, 0.8119846042245626, 0.7137447944842279, 1.0781389474868774, 0.38492376857902855, 0.3800868656253442, 0.6307600974105299, 0.49913462600670755, 0.494184055714868, 0.2895628090482205, 0.07837475030100904, 0.10555185683188029, 0.09084455305128358, 0.008465067203360377, 0.07188223462435417, 0.08053079320234247, 0.15019044396467507, 0.1460540690459311, 0.081127969751833, 0.08516808069543913, 0.038352162155206315, 0.06124256433395203, 0.05684614086931106, 0.12854689441155642, 0.1961041075992398, 0.06786294092307799, 0.05685703188646585, 0.03383242343261372, 0.051085816958220676, 0.08252048370195553, 0.05378668902267236, 0.02199482474679826, 0.05345708268578164, 0.033719999191816896, 0.005420540874183644, 0.05394028761656955, 0.022026859551260713, 0.001974080350919394, 0.08300256056827493, 0.05868326064955909, 0.033496037576696835, 0.02774346725345822, 0.09741266389028169, 0.04440096628968604, 0.03860645905660931, 0.06627161303185858, 0.09156720450846478, 0.032063347462099046, 0.04384107523947023, 0.05480730163981207, 0.009282246010116069, 0.05987392156384885, 0.05126577292685397, 0.04403994855238125, 0.031386493938043714, 0.10037173284217715, 0.04851735146075953, 0.015675192371418234, 0.04910317686153576, 0.03377364904736169, 0.08974933603894897, 0.06577156134881079, 0.008694861171534285, 0.02594802648673067, 0.05325549682311248, 0.06441864097723737, 0.07397503170068376, 0.12982010812265798, 0.13421673938864842, 0.08458850046736188, 0.07906396058388054, 0.10137785502593033, 0.06644400651566684, 0.043169832351850346, 0.12730758200632408, 0.038044245084165595, 0.1013206057541538, 0.03551176632754505, 0.10018718297942542, 0.18101933266734704, 0.33798797463532537, 0.6104805856011808, 0.48333183804061264, 0.7272124593146145, 0.41620858828537166, 0.38667681044898927, 0.5037845077458769, 0.6093105452600867, 2.8964855382218957, 7.1883436013013124, 17.50044923275709, 77.03392758965492, 102.21960693597794, 85.36766320466995, 73.69500115513802, 54.61690127849579, 52.754134833812714, 68.1394636631012, 78.89027997851372, 84.91614863276482, 84.984050989151, 91.38046815991402, 89.75904956459999, 78.43264013528824, 83.07168960571289, 73.6853800714016, 46.45346872508526, 33.99442367255688, 23.18622473627329, 6.672343639656901, 2.158802621997893, 2.427096012979746, 2.606655852869153, 1.3071862631477416, 1.170227718539536, 0.4225937300361693, 0.4510745970765129, 0.8061685413122177, 1.0992626077495515, 0.8980030822567642, 0.14655801700428128, 0.19498019915772602, 0.5806418554857373, 0.16587812482612208, 0.08563118826714344, 0.06470709151471965, 0.10225727775832638, 0.15670140943257138, 0.11792945515480824, 0.07080966053763404, 0.006713586626574397, 0.06518068563309498, 0.08613676152890548, 0.15489563054870814, 0.4890319477999583, 1.577766656409949, 0.057718216339708306, 0.08339644060470164, 0.08558381698094308, 0.11919229364139028, 0.11400848859921098, 0.051705966689041816, 0.18872426531743258, 0.15678102703532204, 0.1349385076900944, 0.08888240365195088, 0.03847875770588871, 0.043398083580541424, 0.07449061653460376, 0.04187647675280459, 0.047836319645284675, 0.12730085814837366, 0.20646840770496055, 0.040950250477180816, 0.3994638071162626, 0.24785081448499113, 0.5323468032293022, 2.001803359016776, 3.3919549640268087, 1.7850247537717223, 2.3161303298547864, 6.5521427895873785, 1.8350089341402054, 17.656812742352486, 31.481386721134186, 29.93252143263817, 27.212194204330444, 30.5660405382514, 40.087100341916084, 49.36600483953953, 43.8407327234745, 38.15377928316593, 37.01194815337658, 54.80360426008701, 78.58895614743233, 74.26039561629295, 31.623316705226898, 2.9814278427511454, 0.735071268863976, 0.8819632523227483, 0.7910057518165559, 0.2516089315759018, 0.20697501255199313, 0.3080554667394608, 0.27106020657811314, 0.26320864039007574, 0.1529611335718073, 0.19407261192100123, 0.060773827572120354, 0.13358457799768075, 0.050530219232314266, 0.059566787458606996, 0.10420474005513825, 0.07202717606560327, 0.11073783636675216, 0.08160984623827972, 0.0891360548848752, 0.047080560980248265, 0.16709248622646555, 0.12681154534220695, 0.10825311110238545, 0.09407946345163509, 0.09998478446505032, 0.029356343402469065, 0.013320265024958644, 0.09949325263733044, 0.02053174739558017, 0.08313078142236918, 0.06563027127413079, 0.010539792983763618, 0.060216129568289034, 0.056137627325369976, 0.034864509652834386, 0.021979658959025983, 0.010507341648917645, 0.047280951985158026, 0.025031466684595216, 0.053478590125450864, 0.07769164047203958, 0.03400677247554995, 0.13150807848433033, 0.21921510575339198, 0.20266479696147144, 0.12324532537604682, 0.1340451548458077, 0.2826991898473352, 0.11264372355071828, 0.107041131996084, 0.11054434362449683, 0.113623165525496, 0.10480714874574915, 0.2152696409029886, 0.2084838878363371, 0.16852760687470436, 0.2915391483111307, 0.23062893626047298, 0.10927491486654617, 0.10635106824338436, 0.14171299495501444, 0.14519617601763457, 0.3146055730758235, 0.3494555811630562, 0.23595660662977025, 0.30866373097524047, 0.21352709300117567, 0.30371045926585793, 0.24740049411775544, 0.13637480093166232, 0.12562511838041246, 0.12074535639840178, 0.33753936120774597, 0.30849814298562706, 0.2817745925858617, 0.22020475968020037, 0.15390616958029568, 0.18451652547810227, 0.2936001814668998, 0.637820593547076, 0.41458494728431106, 0.6149750319309533, 0.4668386449338868, 0.3293403808493167, 0.8106619189493358, 0.40174519876018167, 1.7930848337709904, 5.476045282557607, 5.303046740591526, 66.33718237280846, 129.64399695396423, 112.61473953723907, 101.30127981305122, 90.12954488396645, 69.6456952393055, 63.16943675279617, 60.89610993862152, 69.11055475473404, 75.51955685019493, 86.04433089494705, 90.81454172730446, 83.48367109894753, 90.58869704604149, 109.08627167344093, 78.7665282189846, 58.71074080467224, 57.073955833911896, 34.52687010169029, 20.683449134230614, 12.431758716702461, 7.724379887804389, 7.428808473050594, 2.833685833029449, 0.14684292749734595, 1.2746300850994885, 2.522247894667089, 1.6116692684590816, 2.2141210036352277, 0.3415840066736564, 1.0738362721167505, 1.4101696433499455, 0.7210024644155055, 0.08800419804174453, 0.21541149500990286, 0.21748778672190383, 0.2102933923015371, 0.20780915685463697, 0.13391781714744866, 0.14010824903380126, 0.3123433288419619, 0.16743379994295537, 0.1844469565548934, 1.3037511287257075, 5.2239886578172445, 0.1325091763283126, 0.22429565578931943, 0.1746620362973772, 0.24797787016723305, 0.2733527304371819, 0.20182076725177467, 0.3543676488334313, 0.18600052397232503, 0.16050994803663343, 0.14235747599741444, 0.20281805045669898, 0.13797543535474688, 0.14722866617375985, 0.08151071015163325, 0.1685782807180658, 0.2891522232675925, 0.40803098178002983, 0.6539563089609146, 0.49898797762580216, 0.38505311007611454, 0.9862689021974802, 3.9709564950317144, 9.571303557604551, 16.126486659049988, 20.821355134248734, 32.5700207054615, 37.72569805383682, 48.29164668917656, 42.892284616827965, 27.597761414945126, 28.09230487793684, 46.22090220451355, 68.91768470406532, 50.30115365982056, 36.050417348742485, 47.7684223651886, 76.68692260980606, 79.89294737577438, 95.50355091691017, 78.72754991054535, 20.278763249516487, 0.609563528560102, 0.9462581772822887, 1.1805759882554412, 0.48817251110449433, 0.3256063093431294, 0.4330084071261808, 0.2844575751805678, 0.4092214460251853, 0.4894162912387401, 0.2267935615964234, 0.518326802412048, 0.23886716138804331, 0.2106616014498286, 0.1870461952057667, 0.15508446260355413, 0.2173733030213043, 0.2907915384275839, 0.20999300060793757, 0.28216914797667414, 0.16877499438123778, 0.20683256472693756, 0.22521237144246697, 0.2223993348889053, 0.3904586168937385, 0.2632219099905342, 0.25808728707488626, 0.18603662203531712, 0.18425971269607544, 0.14090552343986928, 0.09678485148469917, 0.20416035811649635, 0.17680426040897146, 0.10087778849992901, 0.14445080742007121, 0.13456599408527836, 0.1406642809160985, 0.10918504820438102, 0.2105383900925517, 0.11781097127823159, 0.1139630691614002, 0.18953774822875857, 0.30259379418566823, 0.1350762354559265], [0.04483485179662239, 0.04095742333447561, 0.016016220361052547, 0.08245761637226678, 0.08896647414076142, 0.06933678683708422, 0.0034794334487742162, 0.04047353933856357, 0.012540223287942354, 0.027624825670500286, 0.06442059282562695, 0.0785448431270197, 0.03920716822904069, 0.0663573904603254, 0.06444694648962468, 0.0398989871609956, 0.025836056811385788, 0.05321299402567092, 0.05863772617885843, 0.025535882195981685, 0.05706587224267423, 0.08723908831598237, 0.027428201065049507, 0.08319367101648822, 0.14371801080415025, 0.04407201675348915, 0.040057606383925304, 0.01417207058693748, 0.022657442023046315, 0.05428334166936111, 0.10343908856157213, 0.02847322291927412, 0.016626673932478298, 0.12987760972464457, 0.19838477193843573, 0.15376735827885568, 0.017935534851858392, 0.07526610148488544, 0.005190877245695447, 0.4811562172835693, 0.7461637642700225, 1.3002708717249334, 0.6096285406965762, 0.8625582279637456, 0.36481604911386967, 0.14704725559568033, 1.5040039457380772, 2.1180374594405293, 4.5512395072728395, 46.91556952893734, 92.87315726280212, 90.97002178430557, 88.56886982917786, 88.86796697974205, 56.3733684271574, 34.722198620438576, 22.173894457519054, 33.9119490981102, 48.3633678406477, 58.430224657058716, 53.24759915471077, 24.565963000059128, 16.331681348383427, 21.571472883224487, 15.173642188310623, 6.377444313839078, 6.966665871441364, 8.43767998740077, 2.457207259722054, 2.760405815206468, 3.7129280157387257, 4.903110601007938, 1.1348871211521327, 1.1528297583572567, 2.2036086302250624, 1.7091276263818145, 3.7620287435129285, 2.2484058514237404, 1.1539680347777903, 0.3422726009739563, 0.09023513848660514, 0.13413459848379716, 0.06078073325625155, 0.14855644258204848, 0.08482547564199194, 0.08604452741565183, 0.08929506002459675, 0.04072010677191429, 0.04531427919573616, 0.3112294542370364, 0.9411746438127011, 0.30670906242448837, 0.08025499628274702, 0.08382490472286008, 0.14608375495299697, 0.18673910934012383, 0.16462272265926003, 0.16536112991161644, 0.016036911438277457, 0.03991627549112309, 0.09350576103315689, 0.1434600551147014, 0.10698647281969897, 0.0701903754088562, 0.035119110834784806, 0.05678463538060896, 0.037554242080659606, 0.04410248562635388, 0.14567601901944727, 0.14364156959345564, 0.4913503577699885, 0.48148020927328616, 2.409316054545343, 1.6087748925201595, 4.755716985091567, 8.168366588652134, 8.906248044222593, 2.7146097226068377, 6.062633581459522, 7.685640966519713, 5.97868706099689, 6.6236521024256945, 27.955185435712337, 28.33029940724373, 9.246426690369844, 21.52979861944914, 38.99850055575371, 53.808437660336494, 51.58561773598194, 60.32873958349228, 22.763824202120304, 1.519593559205532, 0.7523884833790362, 0.5902033299207687, 0.6957696215249598, 0.1187093039334286, 0.27021133806556463, 0.5197913269512355, 0.3421092394273728, 0.25307485135272145, 0.18992078548762947, 0.11831661133328453, 0.17698706622468308, 0.036824658964178525, 0.1578257483197376, 0.052693431280204095, 0.1638931766501628, 0.11590161826461554, 0.057156258408213034, 0.04821076654479839, 0.07611127410200424, 0.01781617338565411, 0.0879866314062383, 0.06022404086252209, 0.1286247605457902, 0.1622646374744363, 0.07364998586126603, 0.047851329582044855, 0.1471122825751081, 0.08816593428491615, 0.05707918266125489, 0.11158108682138845, 0.020053179032402113, 0.07090728264302015, 0.10307099073543213, 0.07776587750413455, 0.047438213077839464, 0.04969549976522103, 0.027816273795906454, 0.0547447051940253, 0.01764798416843405, 0.01836138475482585, 0.04020062566269189, 0.04134587084990926, 0.0794745389430318, 0.03939611902751494, 0.05142077417986002, 0.04061171981447842, 0.053612362244166434, 0.023933605771162547, 0.04588447125570383, 0.08028048905543983, 0.027954730721830856, 0.11901068268343806, 0.033197679367731325, 0.0632340916490648, 0.07565296080429107, 0.03320268515381031, 0.036119139986112714, 0.0792479315714445, 0.02890000421757577, 0.05138163331139367, 0.030926468134566676, 0.058685231051640585, 0.016062233517004643, 0.038909778522793204, 0.06917200036696158, 0.024081983356154524, 0.08860000161803328, 0.06903220200911164, 0.07911312786745839, 0.08815328808850609, 0.0916969393438194, 0.02353984076762572, 0.07445456300047226, 0.11192335790838115, 0.06794917848310433, 0.11621726109297015, 0.025738913391251117, 0.1003301354649011, 0.08437275813776068, 0.0193855058751069, 0.07061036420054734, 0.1635590023943223, 0.24396552296821028, 0.4451965796761215, 0.913543535862118, 0.6604760466143489, 0.539819517871365, 0.4177698591956869, 0.28137861227151006, 1.2479291553609073, 2.5389301870018244, 6.596250822767615, 33.25035899877548, 83.73483002185822, 105.12115404009819, 94.691853672266, 75.27433320879936, 70.15596985816956, 52.22799986600876, 54.20463100075722, 52.133035361766815, 63.287792801856995, 75.28505623340607, 84.38101574778557, 72.96825975179672, 66.73796966671944, 61.49094521999359, 52.93529011309147, 40.00133514404297, 18.29499989748001, 4.195924373343587, 8.732869047671556, 7.575928503647447, 6.463769506663084, 4.304034747183323, 8.442797362804413, 4.935163781046867, 3.089675959199667, 0.5268683878239244, 1.883515587542206, 2.4992942763492465, 2.7640659688040614, 0.9159629372879863, 0.30772809055633843, 0.23684782208874822, 0.08414001320488751, 0.09503598790615797, 0.1969603679026477, 0.11599897319683805, 0.14032562408829108, 0.08317374435137026, 0.06219376758963335, 0.0794409864465706, 0.15768871817272156, 1.0771051654592156, 0.5671762686688453, 0.19182429037755355, 0.10119678583578207, 0.1532835967373103, 0.267607884015888, 0.31269475060980767, 0.12612056132638827, 0.10511104337638244, 0.031492713824263774, 0.03120175482763443, 0.023996677191462368, 0.15231077471980825, 0.11940118594793603, 0.050321475355303846, 0.03805177046160679, 0.021052055999462027, 0.03388572818948887, 0.022135120343591552, 0.12384037196170539, 0.5540488637052476, 0.7092736219055951, 1.2261465867049992, 1.151633297558874, 4.0119287464767694, 5.0519215408712626, 6.183786755427718, 20.82868304103613, 35.09174019098282, 37.33887501060963, 30.176903419196606, 26.121267043054104, 34.32640805840492, 48.755449801683426, 49.381857588887215, 51.366156712174416, 38.38957563042641, 51.20669826865196, 69.9761027097702, 73.9706839621067, 45.95186524093151, 7.737764194607735, 1.5140665182843804, 0.9241476387251168, 0.9240288357250392, 0.17324664193438366, 0.30231735901907086, 0.5795175314415246, 0.3006834170082584, 0.09856053628027439, 0.3153717960231006, 0.20566439459798858, 0.20867194805759937, 0.12223028999869712, 0.08386210858589038, 0.05155996397661511, 0.040696510186535306, 0.05702059010218363, 0.04100590413145255, 0.13153112959116697, 0.029003730487602297, 0.14957976032746956, 0.0688974057266023, 0.0413028819457395, 0.0356039113830775, 0.08829972124658525, 0.08371141550014727, 0.1178578898543492, 0.051336677715880796, 0.09708433033665642, 0.03204035201633815, 0.0530005542532308, 0.033122741006081924, 0.02427146850095596, 0.12424493892467581, 0.07533598953159526, 0.04697362492152024, 0.003923860931536183, 0.04754252193379216, 0.04540952271781862, 0.046586643147747964, 0.02589346007880522, 0.05113993065606337, 0.03473987337201834, 0.014755724278074922, 0.008220411727961618, 0.31285591539926827, 0.17823075730120763, 0.16261050797766075, 0.1507073052925989, 0.11960882402490824, 0.19238995533669367, 0.1830250906641595, 0.22526626620674506, 0.11746945718186907, 0.11476266648969613, 0.11733593739336357, 0.22751359327230603, 0.20023886463604867, 0.18973328929860145, 0.12781259865732864, 0.13416358677204698, 0.12395810626912862, 0.18079296278301626, 0.16326336044585332, 0.1459048528340645, 0.2297497881227173, 0.20131678960751742, 0.17074245755793527, 0.1837462800904177, 0.15738687186967582, 0.2397077772184275, 0.21031089214375243, 0.11496176244691014, 0.11529653042089194, 0.1964401372242719, 0.21932550764176995, 0.25711893278639764, 0.23973384144483134, 0.281781034427695, 0.22782226733397692, 0.2653654699679464, 0.19644919142592698, 0.14044117648154497, 0.21589651820249856, 0.270207003923133, 0.511494887759909, 0.8873340266291052, 0.5010140407830477, 1.2332660984247923, 0.3124764404492453, 0.4421454027760774, 3.1923364754766226, 2.290814663283527, 15.041730366647243, 83.76917257905006, 138.27783286571503, 122.14867115020752, 112.6621001958847, 109.36925008893013, 75.91516882181168, 58.74364323914051, 41.842389553785324, 55.0670213252306, 74.30058225989342, 91.08032986521721, 83.48170280456543, 72.06177279353142, 65.7586482167244, 75.200966745615, 70.6632274389267, 50.54041542112827, 34.54129792749882, 23.093422316014767, 16.95249393582344, 12.86029877141118, 13.725575041025877, 16.146213300526142, 4.376826491206884, 2.2808309365063906, 3.300547543913126, 4.890995901077986, 6.470414875075221, 5.373356267809868, 1.1084484960883856, 0.7968719839118421, 0.33441168372519314, 0.456621230696328, 0.19211634033126757, 0.3369920718250796, 0.20433223951840773, 0.20357054367195815, 0.18530801113229245, 0.09226631504134275, 0.18052813480608165, 0.3659615688957274, 1.7587849055416882, 4.092519097030163, 0.3750704519916326, 0.1539802210754715, 0.1554439589381218, 0.3335510002216324, 0.3474803105928004, 0.3998080448945984, 0.10763341037090868, 0.1501084366464056, 0.2911921200575307, 0.3598881885409355, 0.2245656936429441, 0.2608948020497337, 0.16364470560802147, 0.2059769575134851, 0.18554628506535664, 0.15536391088971868, 0.1948954607360065, 0.4260940250242129, 0.785498897312209, 0.8662138693034649, 8.714578729122877, 15.633090734481812, 20.444246269762516, 24.944762773811817, 41.205228343605995, 54.03248503804207, 59.938489124178886, 45.96721261739731, 38.650241643190384, 51.62159040570259, 69.2407813668251, 50.72718299925327, 34.468106254935265, 53.964943662285805, 64.45705845952034, 78.74885156750679, 86.14801213145256, 86.45255818963051, 32.859443575143814, 2.0965258637443185, 1.2551946029998362, 1.098286178894341, 1.0918672545813024, 0.2294175879796967, 0.46516017406247556, 0.5853461811784655, 0.4033893230371177, 0.2947760105598718, 0.31047967728227377, 0.213329162215814, 0.44118194666225463, 0.22121154237538576, 0.2774759248131886, 0.16454605880426243, 0.17261823581065983, 0.13557985686929896, 0.15521505090873688, 0.13362644996959716, 0.44040361186489463, 0.24837419186951593, 0.1692613831255585, 0.1394511217949912, 0.15894906304311007, 0.30743749521207064, 0.13535353151382878, 0.23748890409478918, 0.338517808704637, 0.3199100884376094, 0.2885772072477266, 0.2993208932457492, 0.13726707024034113, 0.14509751490550116, 0.41747302981093526, 0.1983758810092695, 0.14120128413196653, 0.06749359628884122, 0.1340955912019126, 0.1793972501764074, 0.1936460254364647, 0.11148252960992977, 0.1303637312958017, 0.13875077187549323, 0.16712764918338507, 0.12323189992457628], [0.060001352030667476, 0.010462170830578543, 0.0941684989084024, 0.08876178239006549, 0.0940653849102091, 0.06356747180689126, 0.07823282197932713, 0.030162597795424517, 0.10179382137721404, 0.07024837424978614, 0.12834501540055498, 0.08035349412239157, 0.05927322352363262, 0.029778879616060294, 0.03266578583861701, 0.030143532021611463, 0.08411459464696236, 0.054596513145952486, 0.06039438601874281, 0.057258518936578184, 0.04442292272869963, 0.05604566780675668, 0.028940544034412596, 0.05445692630019039, 0.016405829337600153, 0.05666459670464974, 0.0758449692511931, 0.07754056146950461, 0.015360634934040718, 0.06842709932243451, 0.03780884697334841, 0.07392258412437513, 0.04513161438808311, 0.05752860874054022, 0.06806749166571535, 0.27625473565422, 0.12653788580792025, 0.13614099472761154, 0.015270962157956092, 0.07534232005127706, 0.26228324160911143, 0.19716729351785034, 0.7673066016286612, 0.6562325055710971, 0.4983205196913332, 0.1933323938283138, 0.10410765971755609, 0.3849328524665907, 2.197563392110169, 0.5218214867636561, 2.305674240924418, 44.02978017926216, 98.89089435338974, 101.76135912537575, 85.95933705568314, 74.22801375389099, 58.748423382639885, 34.59847345948219, 19.229981526732445, 25.308374762535095, 49.75643768906593, 58.73029835522175, 35.152422934770584, 9.392494652420282, 10.254296958446503, 21.370222382247448, 18.1757090985775, 9.881408717483282, 7.98554889857769, 8.311699647456408, 3.335988004691899, 1.7043493827804923, 2.7792216930538416, 3.1199852703139186, 1.1879370245151222, 2.0802750857546926, 2.5676889438182116, 1.9139532605186105, 1.2510530627332628, 0.5582712090108544, 0.5827403522562236, 0.027883432594535407, 0.145411116827745, 0.14143237407552078, 0.17335492128040642, 0.09794892495847307, 0.026359660550951958, 0.022204895212780684, 0.2216810843674466, 0.2696878864662722, 0.3667991567635909, 1.0840655607171357, 0.1972046383889392, 0.04927362591843121, 0.05542433063965291, 0.04495640445384197, 0.08493068249663338, 0.07288431210326962, 0.05216493307671044, 0.10259116257657297, 0.10971902345772833, 0.20636158296838403, 0.26260147453285754, 0.20702644338598475, 0.17900818667840213, 0.31093048746697605, 0.17142229451565072, 0.14486672182101756, 0.19521451002219692, 0.3198141139000654, 0.737995330709964, 2.275037197396159, 2.234150441363454, 4.359914073720574, 7.0667586755007505, 4.251802749931812, 13.924348074942827, 12.820429410785437, 5.164127619937062, 6.848548734560609, 25.3786101937294, 29.640282914042473, 15.256246905773878, 13.889610338956118, 32.05817677080631, 46.06348805129528, 53.86686332523823, 63.9575220644474, 31.1398933455348, 4.007052183151245, 0.3486799477832392, 0.32013335614465177, 0.5439190228935331, 0.170310809626244, 0.21722116274759173, 0.49195850326213986, 0.41955600085202605, 0.19062328763538972, 0.3647070424631238, 0.07250180919072591, 0.06354618701152503, 0.04840584748308174, 0.20832499401876703, 0.1549166184850037, 0.13982356118503958, 0.12367970441118814, 0.07446396601153538, 0.15645345789380372, 0.07592459427542053, 0.14440074213780463, 0.11324288163450547, 0.051437787915347144, 0.07829010093701072, 0.05023990961490199, 0.17433302738936618, 0.13497007865225896, 0.048310659622075036, 0.011273867021373007, 0.041966035423683934, 0.08577338376198895, 0.06919139268575236, 0.09735819767229259, 0.1475735570420511, 0.10852338644326665, 0.055577220482518896, 0.06565643197973259, 0.06724312886944972, 0.07048723447951488, 0.02876223748899065, 0.0305762913194485, 0.03951317798055243, 0.02876998365536565, 0.04986063875549007, 0.060038863884983584, 0.03803847859671805, 0.04475555702811107, 0.03369758262124378, 0.08242852418334223, 0.12290085753193125, 0.030687472462886944, 0.08588183380197734, 0.08413646573899314, 0.11548837559530511, 0.03543373321008403, 0.06217326947080437, 0.04474976456549484, 0.11051960042095743, 0.060028125008102506, 0.09197068051435053, 0.04976062693458516, 0.02421928809781093, 0.0588409484771546, 0.0705000884772744, 0.0764875058666803, 0.06453833455452695, 0.03776251840463374, 0.07612437300849706, 0.009073993805941427, 0.0833359184616711, 0.04489401209866628, 0.08396044315304607, 0.05820982980367262, 0.13614136580144987, 0.10643660818459466, 0.009709280566312373, 0.01861783388449112, 0.017649312612775248, 0.027281077709631063, 0.04957983233907726, 0.13371985667617992, 0.11733055682270788, 0.23647674825042486, 0.1368394892779179, 0.040019267034949735, 0.015658447664463893, 0.07867944645113312, 0.32848652510438114, 0.31036366475746036, 0.6970043177716434, 0.7613744668196887, 0.6951926462352276, 0.20655218133470044, 0.466488084057346, 0.9779545920901, 2.4737826827913523, 3.049383396282792, 37.25445494055748, 85.03265038132668, 115.78941598534584, 108.62223297357559, 78.94134923815727, 60.982722491025925, 48.524338603019714, 50.91315641999245, 49.98903460800648, 62.050248607993126, 73.58793810009956, 63.46181586384773, 51.35533109307289, 47.508641704916954, 46.63496218621731, 51.98877610266209, 42.53742925822735, 21.485812179744244, 12.09997572004795, 11.53451381251216, 8.535968363285065, 3.0902029434219003, 3.8111900305375457, 3.0942511511966586, 1.4774542953819036, 2.806388810276985, 5.628578597679734, 2.8247121395543218, 2.6260305382311344, 1.4526101597584784, 0.46994370175525546, 0.11038072232622653, 0.31169332622084767, 0.13992007006891072, 0.06248193982173689, 0.33461841638199985, 0.026514110759308096, 0.039550010769744404, 0.0901783345034346, 0.3368095925543457, 0.3787231247406453, 0.33950786339119077, 0.40883505425881594, 0.09556581455399282, 0.21502574149053544, 0.15963047335390002, 0.24750436510657892, 0.05461829146952368, 0.21190631669014692, 0.14760120946448296, 0.3486999263986945, 0.37515511619858444, 0.24488519236911088, 0.2543310105102137, 0.22609837702475488, 0.061158267490100116, 0.3362427104730159, 0.4317323287250474, 0.37601998541504145, 0.019818446999124717, 0.3519600030267611, 0.7651258748956025, 1.9051808374933898, 4.266257649287581, 6.323950784280896, 21.15661684423685, 35.937354415655136, 36.78860753774643, 32.998310923576355, 28.92478510737419, 33.528181090950966, 46.18313603103161, 51.26513533294201, 44.82671141624451, 33.93987379968166, 47.54456877708435, 63.602237328886986, 77.623450756073, 50.79844817519188, 14.89361621439457, 1.737138892058283, 0.11172757192980498, 0.6556333845946938, 0.2951654006028548, 0.21192757179960608, 0.2134034808841534, 0.4173107666429132, 0.12834311550250277, 0.12193749789730646, 0.15803760179551318, 0.10662312473868951, 0.25567863194737583, 0.15436116547789425, 0.17304771667113528, 0.09671854058979079, 0.03678501343529206, 0.046095630823401734, 0.05133419523190241, 0.0822787216748111, 0.12924112903419882, 0.0895462918560952, 0.04394650102767628, 0.14999662467744201, 0.09452493759454228, 0.12141318540670909, 0.08825608296319842, 0.02382554164796602, 0.08614575635874644, 0.04086509645276237, 0.01166310492408229, 0.06267991513595916, 0.033834275091066957, 0.01604361859790515, 0.06944536304217763, 0.07941383868455887, 0.03291960034403019, 0.054250427419901825, 0.08653728378703818, 0.09414633095730096, 0.038038552811485715, 0.0399473677680362, 0.08537222325685434, 0.04266031086444855, 0.058064736222149804, 0.06027781688317191, 0.047779044398339465, 0.11899302699021064, 0.13826049427734688, 0.23970905371243134, 0.21050816983915865, 0.259526667650789, 0.16118395171361044, 0.1809035724727437, 0.21524172130739316, 0.25106573884841055, 0.31612584774848074, 0.2884306776104495, 0.24427832337096334, 0.19651114591397345, 0.08624959766166285, 0.09534432800137438, 0.19862120534526184, 0.21924082859186456, 0.19267596420831978, 0.15287872549379244, 0.14972191129345447, 0.15771024045534432, 0.1892161014256999, 0.26319908152800053, 0.16264283593045548, 0.11377388087566942, 0.12272402600501664, 0.14064667717320845, 0.1288355453289114, 0.18680297856917605, 0.19554109952878207, 0.14240758580854163, 0.1644267511437647, 0.19069263391429558, 0.29899387329351157, 0.1464962851605378, 0.36144577839877456, 0.2122401792439632, 0.19620351085904986, 0.1168498009792529, 0.1916957800858654, 0.23370206588879228, 0.20358709356514737, 0.7632267486769706, 0.7843118766322732, 0.7862523256335407, 0.6871165952179581, 0.2766060980502516, 0.448893781285733, 3.7273855274543166, 0.341780319577083, 17.50990502536297, 82.91565477848053, 153.9107260107994, 147.9103919863701, 118.98116871714592, 101.19028776884079, 82.83104091882706, 58.911541029810905, 39.69620771706104, 46.894796043634415, 79.20633181929588, 96.69352546334267, 85.9659942984581, 60.700101256370544, 58.48498731851578, 67.02462628483772, 68.02855521440506, 57.35096096992493, 39.01026472449303, 26.489203199744225, 15.164023004472256, 8.001746479421854, 4.00292512960732, 2.724258592352271, 2.719312207773328, 4.275720566511154, 5.593316489830613, 5.054755713790655, 3.53109922260046, 2.362223519012332, 1.3625821843743324, 0.1311350750620477, 0.420176584739238, 0.33109149313531816, 0.15570641204249114, 0.2937037555966526, 0.07810832670656964, 0.09706238502985798, 0.2636137936497107, 0.4623969504609704, 0.5234771291725338, 2.3533106222748756, 0.3622404404450208, 0.2043593575945124, 0.1759138613124378, 0.2567523415200412, 0.35350934020243585, 0.23992043221369386, 0.1762357901316136, 0.22153237281600013, 0.4288602765882388, 0.5441394110675901, 0.28344193124212325, 0.23150281514972448, 0.244607629138045, 0.366081262473017, 0.6978649715892971, 0.35411989025305957, 0.3054554562550038, 0.3149562526959926, 2.2283284412696958, 8.289334047585726, 14.540758598595858, 18.441183753311634, 38.80950249731541, 62.25706771016121, 59.60349529981613, 45.3873485326767, 53.39887663722038, 64.68981876969337, 71.24336510896683, 60.475860089063644, 41.936673894524574, 44.099859818816185, 55.32152406871319, 71.31359294056892, 80.37726938724518, 95.79231262207031, 44.20458599925041, 5.071938391774893, 0.5122540157753974, 0.6396144535392523, 0.9231617697514594, 0.28951433196198195, 0.3245049621909857, 0.6127113034017384, 0.5523913213983178, 0.16340767848305404, 0.3909476625267416, 0.1736817037453875, 0.19054699485423043, 0.3055656800279394, 0.3056399244815111, 0.42675655509810895, 0.32839494408108294, 0.26624455873388797, 0.17202848073793575, 0.2548153360839933, 0.20422093220986426, 0.16269542451482266, 0.20453158038435504, 0.12407852715114132, 0.3027133393334225, 0.22846113773994148, 0.2453362400410697, 0.16544189042178914, 0.16486395034007728, 0.1217647481826134, 0.22510303824674338, 0.1818477624328807, 0.1517910635448061, 0.2125887363217771, 0.3902525966987014, 0.35125285503454506, 0.22014727292116731, 0.21689442481147125, 0.3172854089643806, 0.2725625509629026, 0.20935030071996152, 0.1171378062281292, 0.14392469893209636, 0.15431786858243868, 0.1302040508016944, 0.17978077725274488, 0.218034541758243, 0.15640823141438887], [0.03826048836344853, 0.022341630356095266, 0.018248576452606358, 0.035313553526066244, 0.05309728949214332, 0.05250145994068589, 0.03641191353381146, 0.08922060776967555, 0.025859992929326836, 0.09735154802910984, 0.06187889288412407, 0.08087207723292522, 0.012274141081434209, 0.05432962941995356, 0.03236780241422821, 0.01281182243474177, 0.06218981936399359, 0.028134874082752503, 0.02788338064419804, 0.0563054269150598, 0.046362993234652095, 0.03671619779197499, 0.043561649217735976, 0.06454593414673582, 0.030424681681324728, 0.03655787913885433, 0.12122319560148753, 0.0656882552721072, 0.08742477366467938, 0.022442423287429847, 0.1063258500653319, 0.052663066308014095, 0.039750620708218776, 0.010006409593188437, 0.04864954651566222, 0.04390002402942628, 0.1374302982003428, 0.262831985601224, 0.18416566774249077, 0.014063916478335159, 0.07496594727854244, 0.18292236258275807, 0.167881389206741, 0.4509356076596305, 0.3733470366569236, 0.30932875466533005, 0.1115075548295863, 0.04869475815212354, 0.3434485784964636, 0.36879891820717603, 1.7660530842840672, 1.0484942444600165, 1.6184809966944158, 31.08211364597082, 69.85676631331444, 80.4556591808796, 71.23059019446373, 64.15262639522552, 54.27380628883839, 30.205153003335, 15.639975015074015, 24.636981189250946, 41.632743403315544, 38.933824226260185, 19.987854659557343, 11.746096909046173, 14.241998679935932, 14.327938668429852, 7.189777549356222, 2.623203252442181, 10.612841919064522, 9.084658920764923, 6.824351157993078, 4.7431539092212915, 4.089610353112221, 5.281136641278863, 4.020568057894707, 1.3564794743433595, 0.7812521501909941, 0.1638695615110919, 0.5703631695359945, 0.18714910140261054, 0.34304654225707054, 0.3873146418482065, 0.20835123636061326, 0.09146554511971772, 0.019576386257540435, 0.2270959719317034, 0.7735868927557021, 0.5287125951144844, 0.3669885528506711, 0.38652330462355167, 0.39156628714408726, 0.07972473176778294, 0.13787433999823406, 0.11057116484153084, 0.022890248183102813, 0.2046170164248906, 0.08589091768953949, 0.13787981704808772, 0.07709240075200796, 0.49493905738927424, 0.8721470728050917, 0.5742396146524698, 0.379122756421566, 0.5161510035395622, 0.5681611283216625, 0.7733357499819249, 1.1613627942278981, 1.2152382032945752, 3.1121595902368426, 1.2189522664994001, 3.0940098641440272, 7.327632252126932, 12.083138823509216, 20.81944953650236, 8.418674357235432, 10.549592413008213, 25.386728458106518, 26.924456544220448, 16.256337091326714, 12.424735743552446, 18.569913245737553, 35.088692754507065, 44.8265328258276, 71.32218047976494, 50.58016128838062, 8.330020364373922, 0.3581454179948196, 0.26515704521443695, 0.1705589541234076, 0.3324710566084832, 0.17612201889278367, 0.15799877262907103, 0.33680635679047555, 0.16634980420349166, 0.2520626212935895, 0.2419195999391377, 0.1722711927141063, 0.09082426273380406, 0.17038460879120976, 0.11996848363196477, 0.12737551820464432, 0.16332200495526195, 0.28111847466789186, 0.048630669989506714, 0.11484684830065817, 0.04879746767983306, 0.05759857842349447, 0.153031756344717, 0.07722441398072988, 0.06169702588522341, 0.05526819390070159, 0.050602088813320734, 0.10083915971335955, 0.11277507626800798, 0.08835679982439615, 0.10539453636738472, 0.06620087151532061, 0.11106484147603624, 0.03652288687590044, 0.1419537773472257, 0.15991578460671008, 0.05644687655149028, 0.036156677815597504, 0.05794212229375262, 0.07807111542206258, 0.12125353459850885, 0.10199446100159548, 0.04919887309370097, 0.005254771522231749, 0.023463358738808893, 0.06465008715167642, 0.01808299402910052, 0.03760513856832404, 0.016377097090298776, 0.0580748071661219, 0.07217921986011788, 0.0044551862538355635, 0.05149378666828852, 0.028680534451268613, 0.0381128751905635, 0.07664798788027838, 0.09430702819372527, 0.08390041082748212, 0.06938567210454494, 0.09074737623450346, 0.15692659188061953, 0.06963325256947428, 0.14925137482350692, 0.019657888915389776, 0.035242578233010136, 0.05146391151356511, 0.0990463535708841, 0.08885986462701112, 0.01088166238332633, 0.05171433811483439, 0.05159622902283445, 0.012517592422227608, 0.02215212665760191, 0.05743139852711465, 0.08787104932707734, 0.01620017093955539, 0.05946705394308083, 0.04795267726876773, 0.06155078568554018, 0.04201515817840118, 0.09350576103315689, 0.026739920322143007, 0.06881056702695787, 0.04626449168426916, 0.15055212221341208, 0.23573535756440833, 0.2460160621558316, 0.14156640594592318, 0.08957940648542717, 0.09351278175017796, 0.24188563926145434, 0.3654591942904517, 0.5465780489612371, 0.5625385581515729, 0.4951815021922812, 0.23419421369908378, 0.19215616397559643, 0.7697346713393927, 0.6246546562761068, 3.3377703465521336, 5.17428494989872, 32.860807701945305, 79.05083656311035, 102.37036764621735, 105.9520098567009, 84.46154102683067, 59.26013432443142, 45.88011749088764, 39.65184889733791, 60.402387231588364, 70.81800073385239, 72.59243711829185, 51.901084408164024, 40.95763362944126, 38.635468035936356, 42.736447378993034, 48.56644794344902, 38.05314168334007, 32.8474248200655, 24.674848057329655, 17.70039450377226, 15.6990029476583, 11.111559458076954, 5.844252174720168, 4.683139929547906, 3.5467543825507164, 0.5380972602870315, 0.46054149221163243, 0.722658938029781, 0.5050643265713006, 0.0607150346331764, 0.15834050194825977, 0.7225973694585264, 0.4037319280905649, 0.5458814394660294, 0.6744837574660778, 0.6488742004148662, 2.3763228999450803, 1.6754448087885976, 1.0599895776249468, 0.6877679040189832, 0.36794491403270513, 0.25169404107145965, 0.28513019846286625, 0.7731625624001026, 0.5157152737956494, 0.5484292027540505, 0.2413805335527286, 0.2327190912910737, 0.40277429041452706, 0.8008295309264213, 1.682284560520202, 1.4440498128533363, 0.5288093711715192, 0.03835486728348769, 0.3219239803729579, 0.5838033452164382, 0.764140005921945, 4.302764190360904, 5.035432325676084, 3.369012982584536, 8.144448772072792, 16.611443236470222, 30.845861323177814, 42.063260301947594, 36.62753418087959, 30.637776888906956, 43.22684146463871, 48.98739315569401, 52.77134791016579, 48.71417261660099, 30.965133123099804, 40.93410149216652, 57.59191744029522, 78.68864759802818, 75.64514011144638, 26.724163591861725, 1.7859071376733482, 0.5544062820263207, 0.34929560380987823, 0.503473577555269, 0.21750117506599054, 0.17283411172684282, 0.42049627227243036, 0.14160223683575168, 0.2638111455598846, 0.18672794743906707, 0.037134412850718945, 0.05934589462412987, 0.15905815875157714, 0.08934450932429172, 0.1698895072331652, 0.10486354454769753, 0.25137076154351234, 0.05658940601279028, 0.03868153100484051, 0.03887106438924093, 0.05660259768774267, 0.05878532821952831, 0.05251860726275481, 0.11038144220947288, 0.08418805984547362, 0.08410875394474715, 0.09726200791192241, 0.023807655888958834, 0.025231555264326744, 0.08852316706907004, 0.14427095535211265, 0.14808543113758788, 0.03870551721774973, 0.033531887020217255, 0.04480169263842981, 0.07622844437719323, 0.017028943948389497, 0.09183486748952419, 0.09710298792924732, 0.08265119817224331, 0.05011948131141253, 0.04451410670299083, 0.03665140458906535, 0.08544022624846548, 0.08879436267307028, 0.047801605687709525, 0.05743668261857238, 0.03681197194964625, 0.07545741231297143, 0.13050977111561224, 0.07814619108103216, 0.1897284504957497, 0.21746743703261018, 0.08022435300517827, 0.16637950495351106, 0.1440018229186535, 0.22303391568129882, 0.24157337320502847, 0.18342202092753723, 0.2301891247043386, 0.3092950611608103, 0.32344006933271885, 0.11772995101637207, 0.12783722311723977, 0.2281851033330895, 0.20287040155380964, 0.1436718789045699, 0.11649161082459614, 0.13350758759770542, 0.13192313199397177, 0.17998577328398824, 0.2120630137505941, 0.18294474575668573, 0.15950772212818265, 0.2566410490544513, 0.3152910206699744, 0.24232123541878536, 0.20029820676427335, 0.22117029380751774, 0.27631861972622573, 0.14886976248817518, 0.11853613861603662, 0.21513661835342646, 0.1893268001731485, 0.24023483565542847, 0.31319941102992743, 0.2647443814203143, 0.1437502496992238, 0.18567090650321916, 0.3405412001302466, 0.25769207859411836, 0.6454811012372375, 0.49253699253313243, 0.7567138387821615, 0.5101877578999847, 0.2827893162611872, 0.49602407729253173, 0.5644079984631389, 3.0113462498411536, 0.8022506546694785, 12.520486805588007, 65.67085012793541, 121.66781455278397, 139.05024021863937, 112.6362843811512, 95.01678943634033, 82.68832817673683, 52.50572316348553, 45.59201315045357, 55.92120409011841, 80.25548592209816, 79.35146883130074, 77.065040320158, 59.64105628430843, 50.27513265609741, 64.44009616971016, 60.83422265946865, 66.34731262922287, 56.207989901304245, 35.92127367854118, 26.34474255144596, 19.098654873669147, 11.56331341713667, 7.165847858414054, 5.151997720822692, 3.2310331240296364, 2.7788015780970454, 2.7381760580465198, 1.7624766449443996, 0.2750191785162315, 0.33805687562562525, 0.4696643870556727, 0.4194480332080275, 0.3360710071865469, 0.7176249800249934, 0.8474673971068114, 1.159803809132427, 1.785412689205259, 2.1786325704306364, 1.0821341956034303, 1.286979541182518, 0.2110069227637723, 0.21585144015261903, 0.800777580589056, 0.4677253926638514, 0.4861879488453269, 0.25570932717528194, 0.10151547146961093, 0.22486633766675368, 1.053609719965607, 1.7057461640797555, 0.9280936676077545, 0.45065234473440796, 0.44037149171344936, 0.6566162256058306, 1.0611684643663466, 2.6489677699282765, 8.355257660150528, 13.439246155321598, 28.066173680126667, 36.91430479288101, 52.222672551870346, 60.86953416466713, 51.48807317018509, 54.45091478526592, 66.88109278678894, 72.32854127883911, 57.82649025321007, 50.782150849699974, 50.02082370221615, 47.11635075509548, 68.66613060235977, 72.7412523329258, 104.73713144659996, 75.89223325252533, 11.669991742819548, 0.3330890875076875, 0.5035578855313361, 0.8031203330028802, 0.4669792077038437, 0.2535764838103205, 0.28510852775070816, 0.6292515189852566, 0.24981625902000815, 0.3000084782252088, 0.3553511726204306, 0.2773740724660456, 0.21725846308982, 0.41877591458614916, 0.2195953080081381, 0.27516220521647483, 0.21412091504316777, 0.5587340123020113, 0.24938694143202156, 0.18656488275155425, 0.13394741399679333, 0.17005135479848832, 0.21043466753326356, 0.1808565648389049, 0.20613078988390043, 0.1426760948379524, 0.1574690276174806, 0.19269248441560194, 0.22799506899900734, 0.25176335766445845, 0.1885857805609703, 0.22296056180493906, 0.2779816836118698, 0.162826725281775, 0.2443098052754067, 0.20236099138855934, 0.1896206015953794, 0.22725787886884063, 0.1714026869740337, 0.16289954481180757, 0.294536801520735, 0.15237872576108202, 0.13565276545705274, 0.17027284135110676, 0.13455676176818088, 0.16650739184115082, 0.12698240258032456, 0.13820167165249586, 0.14791748311836272], [0.02550396056903992, 0.013944968759460608, 0.05852252259501256, 0.03122309899481479, 0.051997070404468104, 0.0053364068389782915, 0.03522909712046385, 0.044218130788067356, 0.028761326502717566, 0.028890545545436908, 0.0837587051501032, 0.029883676434110384, 0.01598014641785994, 0.029200733588368166, 0.049912054746528156, 0.011708826787071303, 0.05760143198131118, 0.005733240159315756, 0.04962740029441193, 0.03512984229018912, 0.05823325198434759, 0.021550753262999933, 0.035905980330426246, 0.03584711688745301, 0.04640533647034317, 0.011082539494964294, 0.17072329530492425, 0.06457547904574312, 0.047999940943554975, 0.05384831325500272, 0.05075506029243115, 0.05043850091169588, 0.033453382638981566, 0.049514371203258634, 0.08563158902688883, 0.024326328057213686, 0.032130949693964794, 0.05589895634329878, 0.08991853828774765, 0.3273763315519318, 0.0736573628091719, 0.11470633748103864, 0.03958014196541626, 0.015412627017212799, 0.13263139320770279, 0.344116214546375, 0.33198361401446164, 0.17498326749773696, 0.07748584292130545, 0.038528040022356436, 0.18536885239882395, 0.16760581493144855, 1.280348184518516, 1.0954015399329364, 1.1096963728778064, 14.424279648810625, 53.19501377642155, 79.9829949438572, 67.87422269582748, 42.57788568735123, 36.26854084432125, 26.671538315713406, 20.403219871222973, 22.77151118963957, 30.78845400363207, 34.94726054370403, 30.621413066983223, 20.544942766427994, 24.73565049469471, 25.458840988576412, 18.979483768343925, 8.260881174355745, 4.88063195720315, 9.368596784770489, 8.533270508050919, 12.268123347312212, 12.048016358166933, 8.650541715323925, 1.756473204586655, 0.4057566850678995, 0.21554435428697616, 0.21088895096909255, 0.36293574376031756, 0.07712227961746976, 0.07852277165511623, 0.0949492902145721, 0.2674705273238942, 1.6378217213787138, 8.481769021600485, 4.245011089369655, 0.3942298551555723, 0.19659527577459812, 0.7501473755110055, 0.6543496472295374, 0.46315679093822837, 0.691446759738028, 0.13465494790580124, 0.3912243648665026, 0.14299466914962977, 0.04874653779552318, 0.09164141185465269, 0.4422810079995543, 2.1338607603684068, 5.727780349552631, 2.8046359168365598, 0.2308741566957906, 1.0929465154185891, 3.1044509913772345, 2.1452774852514267, 1.5364052820950747, 2.132664774544537, 6.474375212565064, 13.771047201007605, 21.963894926011562, 17.771617881953716, 18.416999951004982, 25.84099978208542, 25.3601298853755, 17.405241541564465, 21.302458718419075, 41.59097604453564, 38.858318477869034, 34.95832934975624, 60.98666287958622, 59.42991681396961, 18.3946343511343, 0.8175631205085665, 0.3695688518928364, 0.06825236065196805, 0.05186516107642092, 0.026686383644118905, 0.054003077020752244, 0.2655377076007426, 0.1556015168898739, 0.15937967196805403, 0.05279329838231206, 0.05912304994126316, 0.11709331447491422, 0.04243005212629214, 0.012094290868844837, 0.09843912834185176, 0.051605231274152175, 0.05658647452946752, 0.10956110927509144, 0.04021740562166087, 0.02704316928429762, 0.019961844773206394, 0.02068509922537487, 0.0632959719223436, 0.09204118454363197, 0.05937782181717921, 0.12787544372258708, 0.11360208853147924, 0.07390213053440675, 0.03448675648542121, 0.047702614319860004, 0.031228613152052276, 0.0521986043167999, 0.06153615795483347, 0.027989513328066096, 0.05290660948958248, 0.08542778785340488, 0.14052256039576605, 0.005373106041588471, 0.08153140865033492, 0.029328768905543257, 0.00888724625838222, 0.04586905684845988, 0.01859146352217067, 0.03691073325171601, 0.06121462247392628, 0.06126552638306748, 0.06018251027853694, 0.13185173738747835, 0.04370110989839304, 0.04319136947742663, 0.04436542854818981, 0.05585574479482602, 0.06782375552575104, 0.06301901725237258, 0.07655734938452952, 0.0359815495176008, 0.040972258866531774, 0.09918428913806565, 0.07347909893724136, 0.06580726607353427, 0.05486522255523596, 0.054329655395122245, 0.08005919546121731, 0.09395443383255042, 0.0036610383767765597, 0.06046973998309113, 0.05146983385202475, 0.11450013917055912, 0.07017832293058746, 0.06805259676184505, 0.11584036139538512, 0.08224686127505265, 0.07230986753711477, 0.0773266596661415, 0.05790137467556633, 0.0882782434928231, 0.0480511713976739, 0.07919426687294617, 0.07111316182999872, 0.0040377476670983015, 0.025650913230492733, 0.07363406679360196, 0.024872081194189377, 0.020989210934203584, 0.06433100817957893, 0.07936213325592689, 0.0865006736421492, 0.05763610141002573, 0.12967944145202637, 0.07398423433187418, 0.011865475607919507, 0.06813325337134302, 0.13782715424895287, 0.10045937306131236, 0.3080684691667557, 0.3459111135452986, 0.41093340259976685, 0.3391947067575529, 0.19374493887880817, 0.04205003540846519, 0.5462975171394646, 0.28777117549907416, 2.24608916323632, 4.878211487084627, 18.27941693365574, 57.45799362659454, 90.50633266568184, 101.11144959926605, 85.13620242476463, 56.21322602033615, 34.10055197775364, 45.99090054631233, 61.211413219571114, 63.38511697947979, 60.90225040912628, 53.86736869812012, 45.617787167429924, 48.12199719250202, 54.3229528516531, 54.91101689636707, 48.29707279801369, 33.336036801338196, 19.781736619770527, 13.686857018619776, 11.27627206966281, 11.047028470784426, 18.92671599984169, 15.116025879979134, 6.031630095094442, 2.0759582798928022, 1.1883180728182197, 0.32819201122038066, 0.14945724658900872, 0.14307943725725636, 0.02614983870444121, 0.14663295907666907, 0.883228168822825, 3.1164486100897193, 5.022246083244681, 2.165837944485247, 0.8160253905225545, 0.4676647443557158, 1.0657100519165397, 0.7373178389389068, 1.1000406160019338, 1.2286973185837269, 1.116876087617129, 0.7848119060508907, 0.32552704797126353, 0.05095993386930786, 0.6071675196290016, 1.0241041844710708, 1.878751830663532, 1.1918231472373009, 2.369901482015848, 2.96417320612818, 6.32313477806747, 10.696542877703905, 9.457649756222963, 6.221814164891839, 7.3740448616445065, 17.654747553169727, 32.29575902223587, 50.975917652249336, 47.07668088376522, 35.3715305775404, 44.19586546719074, 49.31811220943928, 50.68757392466068, 54.03214305639267, 48.248192220926285, 40.48983693122864, 46.178827062249184, 70.39008289575577, 77.96150341629982, 45.78850440680981, 4.603224992752075, 1.026985023636371, 0.16745811270084232, 0.26035784336272627, 0.03775702651182655, 0.18638626264873892, 0.3763211489422247, 0.24535448203096166, 0.06029289732396137, 0.06710665533319116, 0.01669611854595132, 0.15484758390812203, 0.11966219186433591, 0.007077431946527213, 0.043799563209176995, 0.10771365137770772, 0.06719851095112972, 0.10404234330053441, 0.08185439874068834, 0.03523894913087133, 0.01899997500004247, 0.07894710943219252, 0.013733298037550412, 0.029562254130723886, 0.030026695712876972, 0.1933754829224199, 0.06617499282583594, 0.06602623674552888, 0.06088912021368742, 0.030481426292681135, 0.028088011167710647, 0.026352734457759652, 0.027659604565997142, 0.03218665900931228, 0.038413567453972064, 0.03087575161771383, 0.07623581390362233, 0.1104413483699318, 0.05780097322713118, 0.03913427448424045, 0.032859638522495516, 0.011912521276826737, 0.013729127167607658, 0.1716672774637118, 0.07116184671758674, 0.04646573986974545, 0.0890416165930219, 0.03131183017103467, 0.06269961173529737, 0.045677237649215385, 0.09672687490819953, 0.14391859847819433, 0.1967075775610283, 0.11695074048475362, 0.18267240724526346, 0.17048800480552018, 0.1743954123230651, 0.2574447949882597, 0.1121286656416487, 0.16712361190002412, 0.31295064312871546, 0.11696467801812105, 0.28177687840070575, 0.30270386952906847, 0.25668154063168913, 0.21426232386147603, 0.2403424767544493, 0.2837121917400509, 0.16282881813822314, 0.19447084836428985, 0.17244117421796545, 0.20511280075879768, 0.13127945247106254, 0.0959546331432648, 0.29184915823861957, 0.17641595390159637, 0.2887402125634253, 0.20887262478936464, 0.21812389633851126, 0.17082108068279922, 0.1584880705922842, 0.2271959837526083, 0.15931739093502983, 0.13670395826920867, 0.18530223722336814, 0.1372635376174003, 0.16176692355656996, 0.17461257957620546, 0.2303943136939779, 0.3569903690367937, 0.1467903982847929, 0.11812181983259507, 0.21816446213051677, 0.11265986526268534, 0.2754636062309146, 0.5656219145748764, 0.584171034861356, 0.4058143054135144, 0.36675097653642297, 0.11055965413106605, 0.32072532281745225, 0.2673470933223143, 1.486660132650286, 0.9626788180321455, 5.066353166475892, 42.36298441886902, 104.08732071518898, 132.88756370544434, 119.57259178161621, 82.01105251908302, 66.19029745459557, 63.05117189884186, 60.6396958976984, 60.30379392206669, 63.483736887574196, 72.94065803289413, 75.59831142425537, 63.2843653857708, 70.52981659770012, 74.70279067754745, 68.64862874150276, 68.89174729585648, 61.93426363170147, 53.236009776592255, 42.50242933630943, 36.20405450463295, 25.147470496594906, 13.669727537781, 4.635921763256192, 1.2335291155613959, 0.8702730608638376, 0.5211554537527263, 0.32022799481637776, 0.19103319064015523, 0.1468241956899874, 0.19115411618258804, 0.4130506905494258, 2.366369809024036, 9.429815299808979, 8.467889316380024, 1.0354290017858148, 0.3505888406652957, 1.3047089148312807, 0.9059346816502512, 0.7478284905664623, 1.1947627644985914, 0.957186984596774, 0.7985186018049717, 0.21622744185151532, 0.13399970572208986, 0.7656497717835009, 3.192565175704658, 6.279548741877079, 12.308310940861702, 8.456941153854132, 3.5326478770002723, 7.522975970059633, 16.104877218604088, 25.354403592646122, 27.115713581442833, 36.90685339272022, 43.82880136370659, 57.64861039817333, 78.95309820771217, 78.33411902189255, 76.52378976345062, 68.67431536316872, 50.16789101064205, 44.47919346392155, 64.61057022213936, 80.07899299263954, 70.4438728094101, 68.61806318163872, 101.25303000211716, 90.9919998049736, 25.450371243059635, 0.647227760637179, 0.3709663456538692, 0.1984779560007155, 0.2981676848139614, 0.1514635983039625, 0.16062181937741116, 0.5644797789864242, 0.32717903901357204, 0.2639523317338899, 0.2448893483961001, 0.349396001547575, 0.3182045737048611, 0.2801629446912557, 0.08892466154065914, 0.17969906679354608, 0.15744051430374384, 0.11969866100116633, 0.10793320834636688, 0.09288193396059796, 0.14377352345036343, 0.26842023886274546, 0.27309280063491315, 0.10840948903933167, 0.1931552283349447, 0.13361196324694902, 0.43150840792804956, 0.12472891568904743, 0.17136796930572018, 0.16737430938519537, 0.08931637450587004, 0.09541300634737127, 0.16118760308017954, 0.14358136657392606, 0.1552466070279479, 0.2620773104717955, 0.16485966072650626, 0.28149753401521593, 0.29753846232779324, 0.1625765472999774, 0.130967112199869, 0.0963908304402139, 0.16063106653746217, 0.12711818591924384, 0.13724854623433203, 0.21437648101709783, 0.12006335979094729, 0.15939775068545714, 0.36289833951741457, 0.21161634474992752, 0.21348489448428154], [0.014501562818622915, 0.05010031534766313, 0.06457815077737905, 0.0558572105364874, 0.06892882083775476, 0.07212320255348459, 0.004231998791510705, 0.053712028966401704, 0.10675798781448975, 0.003216369464098534, 0.05957404195214622, 0.09515439014649019, 0.0823406242125202, 0.09652781605836935, 0.0740909700107295, 0.05126401403686032, 0.07871823851019144, 0.07379215909168124, 0.049628821507212706, 0.08894292579498142, 0.10171872345381416, 0.08632625409518369, 0.060622681776294485, 0.04813929401279893, 0.01448916802473832, 0.06467705679824576, 0.041793820055318065, 0.02114997125318041, 0.015563680044579087, 0.060442948451964185, 0.07716354302829131, 0.03041467567527434, 0.0722082972060889, 0.05205921042943373, 0.0382517310208641, 0.1466415383038111, 0.02950003618025221, 0.041916838454199024, 0.017908734043885488, 0.037247401123750024, 0.06705839346977882, 0.04993486094463151, 0.0873036848497577, 0.09970472019631416, 0.074590999429347, 0.1544314468628727, 0.15007677662651986, 0.05957542976830155, 0.2358701018965803, 0.11835028999485075, 0.04750665764731821, 0.08044979520491324, 0.05439803688204847, 0.11185707669937983, 0.20544675237033516, 1.148340180516243, 1.1382887698709965, 11.862112283706665, 48.559566512703896, 79.43609029054642, 53.261658400297165, 41.18460305035114, 41.78529381752014, 33.55553962290287, 20.77330481261015, 13.505162168294191, 19.115417674183846, 24.230089522898197, 23.22807379066944, 28.77414219081402, 25.267272368073463, 29.651423916220665, 27.676859870553017, 16.037506833672523, 22.965519279241562, 18.945751078426838, 9.716437719762325, 27.090887613594532, 45.371313393116, 19.200115129351616, 3.8479442708194256, 1.7479879036545753, 0.4936267324956134, 0.7707248744554818, 0.8599427214358002, 2.7491536689922214, 4.357820386067033, 2.394320396706462, 0.27525725949089974, 0.1956515311030671, 0.17949194821994752, 0.15698856121161953, 0.07429148347000591, 0.5276972777210176, 0.8807867404539138, 0.8772241941187531, 0.8104186726268381, 0.807814565487206, 1.557546160183847, 1.4296175935305655, 0.5810749134980142, 0.6657535478007048, 1.295940054114908, 5.347377536818385, 8.254309426993132, 10.32237695530057, 8.313722088932991, 6.592866154387593, 5.253793308511376, 10.509457066655159, 15.961269624531269, 23.059001863002777, 20.851928293704987, 18.44357382506132, 27.321236953139305, 29.910222329199314, 18.956082724034786, 22.52240415662527, 24.222393035888672, 34.6338077634573, 45.706652998924255, 48.61378200352192, 65.80965667963028, 32.73539923131466, 2.9625198198482394, 0.056427562158205546, 0.22137171268695965, 0.08722466096514836, 0.07324452089960687, 0.13024697662331164, 0.11021649246686138, 0.13543558336095884, 0.025286856398452073, 0.151430023543071, 0.14147003064863384, 0.1431426830822602, 0.07352137909037992, 0.06785692952689715, 0.05711760364647489, 0.05474506884638686, 0.04325840396631975, 0.0939404072414618, 0.1671107579022646, 0.031154008756857365, 0.05059050388808828, 0.062156715866876766, 0.027516973059391603, 0.036511613652692176, 0.056971534140757285, 0.05152257457666565, 0.02193425621953793, 0.031163393214228563, 0.024708920027478598, 0.031319823101512156, 0.07609173335367814, 0.021105427549628075, 0.016194805211853236, 0.05249763788015116, 0.05570767891185824, 0.07480617772671394, 0.014672361612610985, 0.037487096269614995, 0.027868841971212532, 0.03093630715738982, 0.044103981053922325, 0.09322470228653401, 0.0664344550750684, 0.022203757871466223, 0.10780238997540437, 0.13079330121399835, 0.042296721585444175, 0.0694687184295617, 0.02913858614192577, 0.048590367659926414, 0.055783530115149915, 0.01998128162085777, 0.03148983058054, 0.036538612985168584, 0.09033046735567041, 0.02042110059846891, 0.10758338961750269, 0.029666798618563917, 0.03529090688971337, 0.06854752762592398, 0.0288695000926964, 0.04826244599826168, 0.06521684306790121, 0.09872355643892661, 0.07230629038531333, 0.20808772940654308, 0.08049411626416259, 0.020099832290725317, 0.03691887832246721, 0.10662788190529682, 0.2841725607868284, 0.1453272986691445, 0.051480932670529, 0.05970250771497376, 0.03384244613698684, 0.10454167510033585, 0.1510789431631565, 0.017174365930259228, 0.03151000586512964, 0.10301210873876698, 0.0406445672706468, 0.06725635394104756, 0.0073266131312266225, 0.0773957981436979, 0.052809358458034694, 0.04013470439531375, 0.07561661783256568, 0.12465214793337509, 0.06334818201139569, 0.08208830142393708, 0.015813922036613803, 0.06563557763001882, 0.08266468299552798, 0.047754037732374854, 0.07271539929206483, 0.09612056252080947, 0.052919203735655174, 0.2797333005582914, 0.20475799479754642, 0.15276885795174167, 0.35606535617262125, 0.14197155920555815, 0.29822165379300714, 0.060107627577963285, 0.18746549380011857, 0.17960140015929937, 1.2723756185732782, 3.761449037119746, 6.51756227016449, 46.66047781705856, 83.17954301834106, 92.40040943026543, 72.40281969308853, 49.105582013726234, 46.841116324067116, 50.21183185279369, 48.02081622183323, 52.50250093638897, 59.40068118274212, 49.44064423441887, 58.50700333714485, 61.348642855882645, 60.57356044650078, 64.68862563371658, 67.94610723853111, 49.32362571358681, 35.592458322644234, 26.85509506613016, 34.949312433600426, 61.93309709429741, 76.91981211304665, 46.178143098950386, 16.48355159908533, 4.450917290523648, 0.8453028195071965, 2.662993292324245, 4.320215228945017, 7.084558820351958, 10.594079475849867, 11.03713570162654, 4.931076150387526, 0.9450727596413344, 0.8748096018098295, 1.5262725320644677, 2.546612424775958, 3.4839817509055138, 4.912361204624176, 5.421954710036516, 4.699453404173255, 4.725316716358066, 4.9062843807041645, 4.472122052684426, 4.421745780855417, 3.401397932320833, 4.807025631889701, 15.275614466518164, 22.836774587631226, 24.086599722504616, 22.48410791158676, 19.236148595809937, 23.7376606464386, 28.08201503008604, 42.421721667051315, 53.25153574347496, 48.37911419570446, 47.565384060144424, 50.0562833994627, 55.71515254676342, 47.82551430165768, 48.90579633414745, 40.63715122640133, 45.495103150606155, 67.19500914216042, 75.93553572893143, 79.60001349449158, 60.009009540081024, 14.335815645754337, 0.6096322811208665, 0.17278293322306126, 0.09362952900119126, 0.05799682599899825, 0.23487617319915444, 0.16565074562095106, 0.3120516351191327, 0.25658847531303763, 0.12506264465628192, 0.1487289325450547, 0.0920733343809843, 0.10238096409011632, 0.09891660389257595, 0.047461097201448865, 0.030835163561278023, 0.12324016002821736, 0.14179224148392677, 0.07527353038312867, 0.059322880624677055, 0.05675366926880088, 0.017744125689205248, 0.06976142147323117, 0.02078245972370496, 0.08504537399858236, 0.04208146907330956, 0.04143725149333477, 0.11411284940550104, 0.09569491114234552, 0.06938889302546158, 0.11366281847585924, 0.09061199365532957, 0.037546416133409366, 0.09531807081657462, 0.036100367360631935, 0.06169352294818964, 0.03805479471338913, 0.11163184230099432, 0.06353514385409653, 0.10435937394504435, 0.04466992802917957, 0.09972752639441751, 0.036041552157257684, 0.04131899026106112, 0.11224315676372498, 0.10501500946702436, 0.0545679590140935, 0.08675221717567183, 0.05463566514663398, 0.08134241332300007, 0.047066857223398983, 0.06929081078851596, 0.1880478422390297, 0.1951024605659768, 0.16325452888850123, 0.13855156459612772, 0.25492229440715164, 0.20614787412341684, 0.10564630254521035, 0.13566958252340555, 0.179391891870182, 0.1590965871582739, 0.11474473620182835, 0.21763597876997665, 0.22386439377442002, 0.356384331244044, 0.10956896119751036, 0.15821546490769833, 0.1780948106897995, 0.29792060900945216, 0.3439646086189896, 0.4298133426345885, 0.24677701585460454, 0.2681193721946329, 0.12147637185989879, 0.13883834530133754, 0.21579625405138358, 0.24131800018949434, 0.15785279218107462, 0.20290816202759743, 0.13271210918901488, 0.17133567103883252, 0.16834150592330843, 0.1891599950613454, 0.2278753457358107, 0.1784529711585492, 0.22849646396934986, 0.27039310487452894, 0.14539317169692367, 0.13658770825713873, 0.0770973508770112, 0.2007135868188925, 0.24041225347900763, 0.16266656981315464, 0.17164502787636593, 0.22184270928846672, 0.15301875391742215, 0.2872880076756701, 0.35834461043123156, 0.3617518104147166, 0.5112873238977045, 0.4893090360565111, 0.8641672634985298, 0.3499891853425652, 0.17780519498046488, 0.20170389383565634, 0.9647558815777302, 1.0349199478514493, 0.8785138686653227, 28.412053920328617, 84.98525932431221, 143.77200365066528, 108.38646322488785, 83.36884886026382, 77.43337735533714, 77.22302824258804, 55.778571143746376, 48.556633070111275, 58.466273322701454, 62.46067218482494, 71.6067624092102, 68.535987585783, 70.16405582427979, 76.82802423834801, 89.72281470894814, 78.41560184955597, 63.797520250082016, 57.68105685710907, 61.304010450839996, 73.488330245018, 73.58226880431175, 39.543357118964195, 11.673049628734589, 1.9726146315224469, 0.25700360303744674, 1.2545593245886266, 2.81976907979697, 6.373104946687818, 8.93426014110446, 8.077241778373718, 1.8855419475585222, 0.1645175158046186, 0.18679319706279784, 0.3181819530436769, 0.8593727520201355, 1.8703406257554889, 2.907215212471783, 3.4229168901219964, 3.2293372275307775, 3.935303958132863, 5.338176805526018, 5.459610689431429, 3.8147730007767677, 1.7820796743035316, 1.4764681295491755, 8.659443687647581, 16.376957818865776, 26.15571789443493, 33.556136190891266, 37.51681566238403, 41.11151397228241, 53.14546823501587, 72.36555889248848, 89.64813351631165, 76.62369400262833, 69.26672637462616, 59.21791099011898, 54.580480232834816, 45.18718287348747, 60.961105450987816, 58.54784734547138, 61.66410192847252, 86.45455688238144, 101.12015873193741, 111.10625088214874, 45.22903002798557, 4.235056098550558, 0.12651425582589582, 0.1849771913839504, 0.20773342810571194, 0.21374206349719316, 0.2610507421195507, 0.21229695354122669, 0.32282830215990543, 0.2147417512605898, 0.23955470183864236, 0.30754715495277196, 0.4739867144962773, 0.3182450059102848, 0.28166965290438384, 0.156287053541746, 0.40460834512487054, 0.16352009901311249, 0.18925656331703067, 0.15403027151478454, 0.1250179673661478, 0.18262305442476645, 0.12323516537435353, 0.16617458313703537, 0.20397318847244605, 0.22514878422953188, 0.1580335496691987, 0.18756332370685413, 0.13647905783727765, 0.1288093178300187, 0.22789772890973836, 0.2501490677241236, 0.17667134176008403, 0.19905720226233825, 0.18061305134324357, 0.12453064351575449, 0.13289308932144195, 0.13134734414052218, 0.3502224572002888, 0.18451256240950897, 0.14426157460547984, 0.14209580956958234, 0.1859992029494606, 0.12627238989807665, 0.1982822219724767, 0.21081359329400584, 0.2692864736309275, 0.08608648102381267, 0.12372569530270994, 0.210351042333059, 0.11487953248433769, 0.11037842166842893, 0.14381634537130594], [0.08480782737024128, 0.06964200249058194, 0.08051383512793109, 0.02104407049046131, 0.0733623442647513, 0.1298676649457775, 0.05595921873464249, 0.07115523418178782, 0.07914435002021492, 0.12093101948266849, 0.02958162789582275, 0.11254315511905588, 0.046305157666211016, 0.017351572241750546, 0.043733474958571605, 0.019921132407034747, 0.05967554920061957, 0.0749476978671737, 0.039542826780234464, 0.07857806907850318, 0.07037664705421776, 0.017770629638107494, 0.03710130935360212, 0.04997799085685983, 0.0413697197654983, 0.05243326027994044, 0.05849780165590346, 0.07195797821623273, 0.09141751332208514, 0.0239143396174768, 0.05352940868760925, 0.09435134183149785, 0.044020919885952026, 0.008008361583051737, 0.032627116233925335, 0.05128658645844553, 0.04080896782397758, 0.10883171911700629, 0.08936217986047268, 0.05968215431494173, 0.07874973525758833, 0.04010422810097225, 0.013176277243474033, 0.15330566820921376, 0.19043415872147307, 0.07677722547668964, 0.060902619879925624, 0.036415282884263434, 0.1757099191308953, 0.13460365065839142, 0.13124831195455045, 0.06769661820726469, 0.0847153557697311, 0.08720270823687315, 0.11876981865498237, 0.06223044081707485, 0.04938677004247438, 1.1534999473951757, 0.3512793348636478, 5.774844624102116, 38.12349870800972, 68.89523550868034, 55.93020960688591, 44.434857442975044, 28.710776790976524, 38.20604547858238, 42.629893496632576, 28.63754142075777, 26.981470584869385, 32.53163516521454, 42.42163427174091, 36.30506448447704, 43.53769138455391, 35.20055875182152, 21.117097064852715, 21.52662768959999, 30.8936133608222, 41.66722275316715, 65.61068415641785, 82.84081399440765, 71.49542838335037, 46.86602018773556, 27.78015162795782, 20.847758017480373, 19.16265483945608, 21.583938114345074, 22.846412770450115, 26.485773883759975, 25.347134582698345, 25.368875116109848, 26.701475009322166, 22.18209631741047, 17.72082980722189, 13.508161157369614, 12.261769138276577, 9.280767347663641, 9.793197400867939, 12.49309977516532, 13.00180982798338, 18.161486461758614, 25.07112879306078, 32.85387687385082, 35.131132677197456, 34.939425364136696, 20.882431156933308, 8.553241286426783, 5.161572732031345, 12.245090883225203, 19.982609041035175, 31.976914331316948, 33.42354230582714, 23.421800695359707, 22.926683463156223, 37.76187591254711, 28.227524422109127, 29.04233369976282, 35.44070966541767, 38.72513182461262, 42.67035752534866, 45.58966487646103, 61.83335244655609, 40.1690923422575, 4.868761394172907, 0.23323705099755898, 0.018763777225103695, 0.21618859784211963, 0.14864685101201758, 0.05488808441441506, 0.1024662665440701, 0.21066305605927482, 0.049018642530427314, 0.11070839536841959, 0.038438585252151825, 0.03516502009006217, 0.06732666501193307, 0.10527528065722436, 0.20738497492857277, 0.08910535223549232, 0.14461253624176607, 0.06811436571297236, 0.047535000267089345, 0.08152953843818977, 0.023004125177976675, 0.03614586101321038, 0.10544639022555202, 0.08716960102901794, 0.1159587710571941, 0.10891473575611599, 0.07461298926500604, 0.010176535815844545, 0.018014801789831836, 0.06529159960336983, 0.13105329038808122, 0.07044194120680913, 0.04092403411050327, 0.048693247881601565, 0.08997373923193663, 0.02569579090049956, 0.08364795445231721, 0.1252236610162072, 0.01950036621565232, 0.02549524218920851, 0.10106362969963811, 0.10618736530886963, 0.11009063164237887, 0.029951811156934127, 0.06551273734658025, 0.13784431270323694, 0.11360671211150475, 0.161592518852558, 0.031143852465902455, 0.06289372788160108, 0.09157251086435281, 0.04800094655365683, 0.04902062035398558, 0.1018003596982453, 0.028016798387398012, 0.038379154066205956, 0.040583633235655725, 0.15379711840068921, 0.12736769596813247, 0.15997502283426002, 0.10344724476453848, 0.06927644280949607, 0.13530438649468124, 0.007187104674812872, 0.11377953604096547, 0.15840263455174863, 0.024687787372386083, 0.09262666484573856, 0.09097094822209328, 0.04849035212828312, 0.08824167787679471, 0.16704538953490555, 0.1612562220543623, 0.13017099554417655, 0.09659647213993594, 0.14073137106606737, 0.034583365559228696, 0.01958722717972705, 0.04013335739728063, 0.071528823900735, 0.04285386668925639, 0.10983512504026294, 0.14124538254691288, 0.10944825087790377, 0.09067228573258035, 0.09587036227458157, 0.19447029917500913, 0.03194071498000994, 0.02986504667205736, 0.03821006685029715, 0.030825580579403322, 0.006941760857444024, 0.06537124689202756, 0.06485221107141115, 0.05225232096563559, 0.05680450638465118, 0.057403044775128365, 0.09194305035634898, 0.06274315353948623, 0.06527541336254217, 0.20784384483704343, 0.1314656573231332, 0.23770617524860427, 0.12275803863303736, 0.2755249373149127, 0.14000863797264174, 0.20914298918796703, 0.13481360423611477, 0.11896157477167435, 0.12438318619388156, 0.11264079948887229, 4.1388642601668835, 3.8879425870254636, 32.49465174973011, 74.43659976124763, 93.11680778861046, 83.28079998493195, 61.306563913822174, 43.640616461634636, 43.240129351615906, 57.101945132017136, 60.92478320002556, 49.08869192004204, 52.99409955739975, 58.06655757129192, 62.25270554423332, 68.41091349720955, 70.47488674521446, 59.15142975747585, 66.65495172142982, 72.0412614941597, 72.10475608706474, 89.64155226945877, 104.25040036439896, 98.80843117833138, 84.15352195501328, 63.904879689216614, 57.86464400589466, 50.66704362630844, 54.717888459563255, 56.78444176912308, 63.36319215595722, 55.25218918919563, 49.67852286994457, 49.53844338655472, 42.39188186824322, 36.93892367184162, 35.891775861382484, 40.5716959387064, 33.85845176875591, 33.62225644290447, 32.53131218254566, 33.855727314949036, 37.91299380362034, 48.93987290561199, 55.522335693240166, 64.46689993143082, 56.94703884422779, 50.03103755414486, 42.727951034903526, 49.67104487121105, 49.80947524309158, 52.59746924042702, 65.88742330670357, 59.80188265442848, 50.02126067876816, 55.438417196273804, 61.16806134581566, 48.62519659101963, 42.67423331737518, 42.02911153435707, 48.000411316752434, 51.82961404323578, 68.84137719869614, 87.262993901968, 68.54470431804657, 26.01039659231901, 2.385692009702325, 0.2406056274776347, 0.25902524299453944, 0.1622934773331508, 0.026222938395221718, 0.13050913286861032, 0.15890401467913762, 0.16272819775622338, 0.23119209276046604, 0.07612723769852892, 0.13499507418600842, 0.11499032771098427, 0.09369549850816838, 0.0626006982929539, 0.07898372699855827, 0.029617635045724455, 0.046818490081932396, 0.07926359088742174, 0.11230209813220426, 0.0815497842268087, 0.04820586837013252, 0.10361288470448926, 0.04292448946216609, 0.011929360607609851, 0.021929727263341192, 0.018194225267507136, 0.031790407811058685, 0.07707181357545778, 0.09527326736133546, 0.1655782526358962, 0.0488345750636654, 0.09972224230295978, 0.028728137658617925, 0.10451279071276076, 0.18570529762655497, 0.07514262295444496, 0.05912830434681382, 0.062109251812216826, 0.03760563209652901, 0.078502948890673, 0.06017511106620077, 0.10129555827006698, 0.07333029090659693, 0.1302556597511284, 0.07934498964459635, 0.042697054595919326, 0.04437021540070418, 0.04585101894917898, 0.08561641952837817, 0.056920374190667644, 0.04554586637823377, 0.022710160483256914, 0.01815611969504971, 0.21533273829845712, 0.17276697704801336, 0.1672651691478677, 0.40457126742694527, 0.23661171522689983, 0.2939578966470435, 0.2323926947428845, 0.22861168981762603, 0.255730077624321, 0.18143405963201076, 0.23859457054641098, 0.2769423503195867, 0.12065715956850909, 0.21470507432240993, 0.23475219000829384, 0.1643467030953616, 0.25777582253795117, 0.1667972153518349, 0.24646452715387568, 0.32884519023355097, 0.1637576604844071, 0.297433344530873, 0.11742368893465027, 0.11838013175292872, 0.10323157664970495, 0.21893819561228156, 0.14058939821552485, 0.17925787484273314, 0.2736321935663, 0.20338031637948006, 0.10917833918938413, 0.26828614762052894, 0.32448498357553035, 0.12536852824268863, 0.10614287355565466, 0.17413907451555133, 0.09810721763642505, 0.20626321871532127, 0.21384918509284034, 0.19037971476791427, 0.23887758114142343, 0.20074172905879095, 0.13521054934244603, 0.37376777501776814, 0.3065593563951552, 0.15481997601455078, 0.3380702045978978, 0.17006627196678892, 0.3636756946798414, 0.2055856675724499, 0.39725315698888153, 0.3333561716135591, 0.2906075748614967, 0.2974895399529487, 0.15319375233957544, 0.16524716571439058, 0.22366791759850457, 1.6185102076269686, 0.5509655072819442, 14.212973937392235, 76.56193971633911, 137.32558876276016, 117.67270132899284, 89.89686816930771, 64.11280453205109, 74.45208013057709, 91.85456871986389, 75.44631958007812, 61.734835132956505, 67.34430313110352, 72.96016618609428, 71.2035584449768, 81.20846718549728, 77.98615649342537, 72.06569418311119, 87.51890257000923, 94.3741375207901, 97.99323812127113, 109.55591887235641, 116.38545960187912, 105.992401689291, 84.75161746144295, 56.87404856085777, 51.083543077111244, 43.36985059082508, 47.37625300884247, 51.69792450964451, 59.85579416155815, 53.36700014770031, 42.46025539934635, 45.06249636411667, 36.01241558790207, 29.781962111592293, 27.56709896028042, 33.278504088521004, 26.733664982020855, 24.964584410190582, 24.57746498286724, 25.862537026405334, 30.80545999109745, 44.40439447760582, 57.03831374645233, 74.94888827204704, 75.40370866656303, 65.6982010602951, 62.45834290981293, 76.64654597640038, 71.56076967716217, 83.86965438723564, 94.06676441431046, 76.51331752538681, 48.35243582725525, 53.55552703142166, 75.26120111346245, 61.65068864822388, 58.89573007822037, 65.95309138298035, 67.60898172855377, 84.73530113697052, 102.20239385962486, 121.65657475590706, 65.48656761646271, 10.316766556352377, 0.39672744926065207, 0.21433864632854238, 0.5708903912454844, 0.2878537913784385, 0.2740024361992255, 0.4606992728076875, 0.3134469024371356, 0.19981217425083742, 0.31689720635768026, 0.31157618563156575, 0.22611657448578626, 0.29478919110260904, 0.33412022748962045, 0.3644363663624972, 0.22638543974608183, 0.6404974311590195, 0.22151181532535702, 0.15162917145062238, 0.21698343800380826, 0.15824504691408947, 0.18955967127112672, 0.2639569924212992, 0.279398265411146, 0.27519168332219124, 0.10912129771895707, 0.14012049447046593, 0.18908929807366803, 0.178231825993862, 0.2279667931725271, 0.39396045554894954, 0.19362052524229512, 0.2219487918773666, 0.1445060083642602, 0.23845206334954128, 0.24067130754701793, 0.214100060693454, 0.2234163592220284, 0.19799370464170352, 0.18418684863718227, 0.30533000361174345, 0.30421455565374345, 0.3652516007423401, 0.2516069129342213, 0.4832606215495616, 0.2257893022033386, 0.17214394407346845, 0.21681439160602167, 0.1120194660325069, 0.16092825215309858, 0.13466585747664794, 0.1212429886800237, 0.16289083199808374, 0.1745397600461729], [0.09227559188730083, 0.08505670659360476, 0.13175785570638254, 0.1164643740048632, 0.18592423119116575, 0.0983269972493872, 0.06225474986422341, 0.02124097154592164, 0.12949767464306206, 0.06385207059793174, 0.036347231653053313, 0.1856536589912139, 0.23753214161843061, 0.2406163144041784, 0.12363107147393748, 0.144379056582693, 0.01902018739201594, 0.08908212301321328, 0.08558130852179602, 0.09703252842882648, 0.11135298773297109, 0.11879738201969303, 0.0689481315203011, 0.047282258165068924, 0.11710238351952285, 0.07793536176905036, 0.02741239146416774, 0.045334651149460115, 0.030873415707901586, 0.08294781975564547, 0.04106617394427303, 0.056217842357000336, 0.11504464549943805, 0.10057140025310218, 0.0938769536151085, 0.055193789885379374, 0.15451386978384107, 0.033461542552686296, 0.08204980622394942, 0.012914788931084331, 0.057655167183838785, 0.13689059356693178, 0.08180004384485073, 0.07668606005609035, 0.10328817283152603, 0.12820753996493295, 0.07144384799175896, 0.10803575831232592, 0.3678896091878414, 0.09926122758770362, 0.041048124912776984, 0.03554514070856385, 0.12711233779555187, 0.1505858008749783, 0.14704519242513925, 0.15795863728271797, 0.034127271283068694, 0.09246893620002083, 0.11335289018461481, 0.6590515980497003, 0.202329509484116, 5.701533732935786, 20.349916331470013, 39.82870660722256, 53.319909274578094, 51.15472085773945, 50.13274669647217, 59.34318266808987, 51.86311684548855, 54.006517231464386, 53.56995865702629, 57.097066193819046, 59.826246947050095, 39.27763357758522, 47.052278593182564, 42.39664301276207, 43.46991442143917, 60.89282311499119, 81.57603666186333, 101.04825139045715, 114.25120532512665, 105.57227343320847, 99.12548616528511, 84.91147488355637, 71.2055267393589, 68.56548920273781, 64.38261285424232, 76.38748347759247, 88.75664055347443, 91.65875002741814, 92.24954232573509, 63.475023955106735, 46.8146887421608, 62.60717332363129, 43.301192075014114, 27.756026722490788, 45.17542250454426, 54.457613825798035, 64.47802573442459, 71.3450400531292, 68.69960680603981, 76.54631495475769, 68.41065511107445, 70.31916350126266, 39.55314539372921, 32.734289690852165, 30.190654881298542, 33.33814188838005, 30.26411633938551, 33.567626774311066, 40.412674471735954, 24.444151036441326, 23.43006145209074, 38.02688509225845, 40.32033942639828, 49.477969631552696, 58.176132291555405, 66.42724514007568, 47.717353105545044, 27.97140296548605, 7.131081623956561, 0.2485944316140376, 0.2616838534595445, 0.14063676208024845, 0.1320470409700647, 0.02683648115635151, 0.056417658197460696, 0.08587313583120704, 0.1745031276368536, 0.07242213221616112, 0.14818093070061877, 0.16965035756584257, 0.025436042924411595, 0.05173728903173469, 0.13254543766379356, 0.13441609509754926, 0.23031156422803178, 0.2840562514029443, 0.09654149384004995, 0.022143159658298828, 0.06051052470866125, 0.072255549748661, 0.11634526672423817, 0.0565539907256607, 0.23627777845831588, 0.04201429728709627, 0.01984293972782325, 0.34375075134448707, 0.11587896791752428, 0.07531848968937993, 0.009845776367001235, 0.13244263536762446, 0.11981928968452848, 0.06472209774074145, 0.1348637288901955, 0.029812805041729007, 0.1752511679660529, 0.05044061232183594, 0.080714014620753, 0.258666755980812, 0.17926750791957602, 0.13544486020691693, 0.1147439717897214, 0.06759413503459655, 0.2188966650282964, 0.10777355753816664, 0.12725575041258708, 0.037919434398645535, 0.06302755195065401, 0.03849184919090476, 0.1233080962265376, 0.07810316878021695, 0.11474220547825098, 0.07534508826211095, 0.06229127466212958, 0.041820834230748005, 0.0216871377415373, 0.05864199723873753, 0.07453881902620196, 0.05429444419860374, 0.24174868332920596, 0.12782769394107163, 0.0365404460899299, 0.10660546162398532, 0.045039714241283946, 0.08070601426879875, 0.010757435211417032, 0.15031919174361974, 0.13865298649761826, 0.1397372197243385, 0.010572780520305969, 0.132462703040801, 0.15864938381128013, 0.0949530306388624, 0.16865389072336257, 0.15365815866971388, 0.1540696350275539, 0.07447492011124268, 0.07233474432723597, 0.05798646561743226, 0.04365717475593556, 0.03680068017274607, 0.05079414549982175, 0.018164457724196836, 0.03934817257686518, 0.11790365068009123, 0.05445479262562003, 0.078909467702033, 0.10930184740573168, 0.22282056306721643, 0.16645376425003633, 0.08370069888769649, 0.06555482454132289, 0.09898913398501463, 0.07200469641247764, 0.04862114081333857, 0.037909504462732, 0.03736604827281553, 0.05422949143394362, 0.041351615072926506, 0.17566258495207876, 0.057012203833437525, 0.16805528925033286, 0.13083457946777344, 0.37101589143276215, 0.21466105012223125, 0.066450388985686, 0.15737493813503534, 0.15852566779358312, 0.045729095218121074, 0.22559888195246458, 0.4001393396174535, 0.06110397938755341, 0.4383191268425435, 0.18695155653404072, 2.1428180672228336, 0.8815797697752714, 26.931073889136314, 63.587649911642075, 78.51953387260437, 79.39221024513245, 72.36691161990166, 70.04327550530434, 66.02994605898857, 59.94414322078228, 59.02307264506817, 65.86090072989464, 66.57830223441124, 75.32301619648933, 65.77625647187233, 79.08456355333328, 79.51100707054138, 81.27291932702065, 93.8985550403595, 110.84951385855675, 118.11212494969368, 134.2629835009575, 132.58750140666962, 144.1414350271225, 138.21759849786758, 117.58617237210274, 104.8296108841896, 86.64817169308662, 97.53475472331047, 107.31948807835579, 118.33002045750618, 122.0838238298893, 100.22032141685486, 86.9680005311966, 109.26781833171844, 87.87742853164673, 75.64059555530548, 106.90296962857246, 115.4715022444725, 115.68058222532272, 118.31179663538933, 109.70732554793358, 106.7525888979435, 112.44975239038467, 114.5203448832035, 82.35367253422737, 75.60964241623878, 75.48136129975319, 70.36454826593399, 74.00143951177597, 72.49475955963135, 62.59760543704033, 32.39827372133732, 32.59851157665253, 56.19888558983803, 47.83382825553417, 54.576988220214844, 65.13083830475807, 78.64525392651558, 84.86191034317017, 61.77015423774719, 28.130821511149406, 2.1169167570769787, 0.44946437410544604, 0.11384945377358235, 0.15652428846806288, 0.032847920010681264, 0.1375437280512415, 0.16512330126715824, 0.05141386849572882, 0.05267937129247002, 0.11705656332196668, 0.1439103903248906, 0.1131446732324548, 0.07787586378981359, 0.118103199347388, 0.02224686923000263, 0.07135257124900818, 0.13205481867771596, 0.0980605291260872, 0.12698649923549965, 0.008712245053175138, 0.08661165440571494, 0.08539105154341087, 0.04703980222984683, 0.11755051455111243, 0.09179886590573005, 0.20422177825821564, 0.13028273329837248, 0.07052491331705824, 0.039541728401673026, 0.053367494328995235, 0.09758166575920768, 0.15943056845571846, 0.1425531951826997, 0.11508487732498907, 0.07724944662186317, 0.10817277361638844, 0.09983553856727667, 0.17099777120165527, 0.08023776361369528, 0.12575811124406755, 0.05724615104554687, 0.053247503892634995, 0.07497923914343119, 0.06718118922435679, 0.14686171867651865, 0.1125411364773754, 0.058658714115154, 0.08583250324591063, 0.053528510688920505, 0.06474779831478372, 0.02255305153084919, 0.0591675936448155, 0.030494564161926974, 0.1396480729454197, 0.09762019064510241, 0.20960666821338236, 0.3336623520590365, 0.24380312621360645, 0.2093444822821766, 0.3645490243798122, 0.3770985931623727, 0.29207192128524184, 0.26226314425002784, 0.2067875163629651, 0.2926915552234277, 0.23585606046253815, 0.30645685095805675, 0.3157930390443653, 0.39654315914958715, 0.20661731221480295, 0.3190533531596884, 0.2789752115495503, 0.25068356248084456, 0.3983320912811905, 0.3185015812050551, 0.21919603255810216, 0.23745890648569912, 0.36398398282472044, 0.1643152063479647, 0.2032026759115979, 0.1612099862541072, 0.20471901720156893, 0.17754758067894727, 0.23767303093336523, 0.24526330176740885, 0.18468767957529053, 0.21674105257261544, 0.16703341127140447, 0.3120443917578086, 0.14081811328651384, 0.28160060348454863, 0.33221540157683194, 0.30580429534893483, 0.2837065514177084, 0.12081508117262274, 0.14446573943132535, 0.20391288155224174, 0.20803931169211864, 0.2697072416776791, 0.2933193527860567, 0.5267721461132169, 0.2872319903690368, 0.1779112478834577, 0.7039951113983989, 0.19244784285547212, 0.11319925819407217, 0.20581041957484558, 0.36515090614557266, 0.2690220612566918, 0.29685099609196186, 0.6236763868946582, 0.12320744615863077, 0.21341893239878118, 0.3102903999388218, 0.8993059967178851, 0.19495745975291356, 11.060943324118853, 64.47583705186844, 106.25925377011299, 123.39300557971, 111.27240836620331, 97.32116058468819, 106.66691109538078, 90.27738735079765, 89.09324929118156, 95.25464907288551, 99.1122704744339, 102.01545149087906, 74.39607873558998, 92.92468249797821, 84.05373930931091, 83.78425016999245, 100.2650298178196, 115.3166301548481, 119.31561917066574, 140.36129146814346, 139.78179216384888, 148.6878302693367, 144.70801502466202, 129.71584349870682, 110.89932158589363, 99.73587781190872, 117.06642106175423, 125.55106177926064, 138.24451625347137, 138.21969598531723, 107.13622391223907, 88.7465862929821, 126.64723455905914, 123.41724067926407, 102.29240342974663, 123.7785404920578, 132.92042434215546, 127.09651485085487, 128.34382832050323, 123.47278609871864, 129.0516847372055, 128.50066870450974, 119.02270048856735, 81.82943746447563, 79.19604957103729, 75.73763474822044, 77.09039255976677, 76.33183166384697, 89.902263879776, 84.79185730218887, 53.27284500002861, 53.39667655527592, 75.32206624746323, 67.34304919838905, 82.18584313988686, 99.87841576337814, 122.24788382649422, 109.69519659876823, 59.05862733721733, 13.799361381679773, 0.3347050992306322, 0.27358454768545926, 0.5322829191572964, 0.35562864679377526, 0.09803944471059367, 0.3402953711338341, 0.28484934009611607, 0.26868987595662475, 0.23488176899263635, 0.3738697461085394, 0.30897243472281843, 0.2000270111602731, 0.32804684713482857, 0.2866185607854277, 0.2144035545643419, 0.32220014836639166, 0.4998589027673006, 0.37468082446139306, 0.44402460975106806, 0.3659483586670831, 0.15376857540104538, 0.3127751697320491, 0.2606881584506482, 0.5387676868122071, 0.3957751550478861, 0.5411612021271139, 0.3963657561689615, 0.2753446251153946, 0.18668660981347784, 0.35355621424969286, 0.46924896247219294, 0.5097017996013165, 0.41093435254879296, 0.3047451318707317, 0.32649828179273754, 0.2906422480009496, 0.2402722992701456, 0.2509836870012805, 0.4983665922190994, 0.389799025724642, 0.3456424264004454, 0.29941173212137073, 0.2690405258908868, 0.2665610401891172, 0.34084310580510646, 0.34405927697662264, 0.5457548587583005, 0.28591105656232685, 0.21764452831121162, 0.3217606188263744, 0.28220705687999725, 0.13115949172060937, 0.21876778366276994, 0.28407572535797954, 0.2898754016496241], [0.08641839172923937, 0.06896502280142158, 0.1518889082944952, 0.1593645618413575, 0.20092178892809898, 0.14532241533743218, 0.03164910289342515, 0.04269611577910837, 0.054872528999112546, 0.1649186317808926, 0.200871322886087, 0.15759998699650168, 0.15972558700013906, 0.1958354946691543, 0.15733797918073833, 0.06583379785297439, 0.031118834667722695, 0.040216006673290394, 0.051184530020691454, 0.05557186588703189, 0.03324339566461276, 0.08919320025597699, 0.09616527691832744, 0.15700379008194432, 0.035155364748789, 0.07514177690609358, 0.01196224888190045, 0.08402754814596847, 0.031086887065612245, 0.13966575090307742, 0.04275347266229801, 0.08324027046910487, 0.0722987279004883, 0.05809748348838184, 0.12774703733157367, 0.11810778582002968, 0.11498639432829805, 0.14778264972846955, 0.007848835084587336, 0.08561840106267482, 0.02068030124064535, 0.1505767912021838, 0.03860265926050488, 0.1460260307067074, 0.1795224504894577, 0.19336147117428482, 0.21720888762502, 0.21623588749207556, 0.1275237844674848, 0.20592442830093205, 0.06025136673997622, 0.08219707800890319, 0.055401765639544465, 0.01888894970761612, 0.12603515497175977, 0.07806976471329108, 0.031920142646413296, 0.398156083538197, 0.16904038639040664, 0.2846651687286794, 0.0990646771970205, 0.48798418371006846, 0.1751890205196105, 1.5993853588588536, 6.147922379896045, 29.621958397328854, 49.5160473883152, 64.67141255736351, 81.17955073714256, 69.71865132451057, 65.83002358675003, 65.76339036226273, 66.97775959968567, 65.17697542905807, 71.79964005947113, 74.76018279790878, 74.34803411364555, 69.41664353013039, 73.9320932328701, 69.60340350866318, 76.97090417146683, 75.9728117287159, 60.860604643821716, 50.09805075824261, 67.80552998185158, 82.28198558092117, 91.51938870549202, 84.34635400772095, 90.22221431136131, 82.47430846095085, 74.06014636158943, 42.150857001543045, 62.61449173092842, 73.3693054318428, 108.33044663071632, 92.64511629939079, 37.974140122532845, 62.5811181217432, 49.15633209049702, 53.687767535448074, 61.34535603225231, 74.56003993749619, 66.20594501495361, 43.97758238017559, 45.759869143366814, 63.04636135697365, 54.57589767873287, 50.55263176560402, 49.137610495090485, 48.98887127637863, 49.94466818869114, 45.63056208193302, 47.258333936333656, 57.07571513950825, 67.68888384103775, 69.76644515991211, 44.703681617975235, 19.039706736803055, 3.0063768289983273, 0.1056978372798767, 0.09636122616939247, 0.26897592935711145, 0.0934074042015709, 0.03763012296985835, 0.13412377797067165, 0.15047346940264106, 0.07371343206614256, 0.08548695186618716, 0.18259845965076238, 0.1364911103155464, 0.1346607960294932, 0.04689068620791659, 0.19827094132779166, 0.03361990944540594, 0.06474675188655965, 0.052304839045973495, 0.06925026726094075, 0.05431393670733087, 0.1081656786845997, 0.09215782047249377, 0.11810757059720345, 0.12964139896212146, 0.2093943249201402, 0.07700461210333742, 0.0830803376447875, 0.17884041677461937, 0.22077944915508851, 0.13614819356007501, 0.07203870904049836, 0.07875365379732102, 0.2381065787631087, 0.06487160339020193, 0.16227980697294697, 0.117269092152128, 0.10904867114732042, 0.14141166815534234, 0.05227791021752637, 0.06542865201481618, 0.1269509206758812, 0.06242676856345497, 0.19147252722177655, 0.08284562602057122, 0.19283410103525966, 0.27817725436761975, 0.2109683459275402, 0.10195220311288722, 0.04636957237380557, 0.076490756473504, 0.07684010022785515, 0.05132134123414289, 0.0752404602826573, 0.022354283973982092, 0.33900139213074, 0.09549751470331103, 0.08021907633519731, 0.10148153305635788, 0.10960378276649863, 0.08924146211938933, 0.15528994845226407, 0.17603321350179613, 0.22077180503401905, 0.07113596802810207, 0.08159190852893516, 0.06993875023908913, 0.05595558963250369, 0.00997528020889149, 0.10456173535203561, 0.06492201748187654, 0.1059730479028076, 0.0747345678973943, 0.07300578683498316, 0.13968938088510185, 0.10473487840499729, 0.1039497900637798, 0.11626585692283697, 0.17193078441778198, 0.10918757892795838, 0.045816631536581554, 0.08660500476253219, 0.048706009110901505, 0.014259990966820624, 0.0655603980703745, 0.022911790874786675, 0.09299265497247688, 0.051117792390869, 0.16926214011618868, 0.019575213664211333, 0.04086293309228495, 0.08601887879194692, 0.08420167825534008, 0.1001258815813344, 0.07557501303381287, 0.05186280846828595, 0.08634635145426728, 0.03005523500178242, 0.06838417350081727, 0.058598885880201124, 0.06463240177254193, 0.0995061437424738, 0.20019359362777323, 0.10175595700275153, 0.12051213649101555, 0.1824178357492201, 0.1563414529664442, 0.16501085105119273, 0.12265771511010826, 0.1330047083320096, 0.19252041005529463, 0.1065776236646343, 0.05265268366201781, 0.15121429605642334, 0.14778505428694189, 0.033086041803471744, 0.3392947482643649, 0.011884462528541917, 0.3766388475196436, 0.2086517319548875, 1.4148436300456524, 1.5362817887216806, 12.995934393256903, 43.750172182917595, 80.6544417142868, 95.75442105531693, 98.9243933558464, 91.03412434458733, 81.85266181826591, 77.19139873981476, 83.3275830745697, 85.96152573823929, 78.45091715455055, 90.4117101430893, 85.42144551873207, 93.74731555581093, 84.16335582733154, 91.35776817798615, 92.80048236250877, 93.57742667198181, 85.91312393546104, 66.70643895864487, 57.76783660054207, 70.90321496129036, 75.8442722260952, 81.67537093162537, 75.47831386327744, 87.65673637390137, 74.53125268220901, 68.57402354478836, 46.39715954661369, 63.711219280958176, 78.33413422107697, 151.16035759449005, 140.48127382993698, 57.66119912266731, 74.7140684723854, 53.47696624696255, 52.91591875255108, 68.49586933851242, 88.50398451089859, 80.771065056324, 62.25146681070328, 61.63770094513893, 79.45019513368607, 65.53506061434746, 66.27791315317154, 59.976646676659584, 59.32937040925026, 63.902341425418854, 56.44581153988838, 62.49509073793888, 72.94461742043495, 82.79254138469696, 90.58804348111153, 79.63054865598679, 49.2547582089901, 14.730077739804983, 1.0625925567001104, 0.35789418616332114, 0.30863921041600406, 0.22799665719503537, 0.117311008652905, 0.18624985590577126, 0.22412764839828014, 0.08302145564812236, 0.12411629504640587, 0.11050832719774917, 0.0707370117015671, 0.07192579869297333, 0.04469867883017287, 0.11256848461925983, 0.04916884208796546, 0.018882518997997977, 0.09510550487902947, 0.10115139608387835, 0.042367344358353876, 0.05081977928057313, 0.10275377455400303, 0.10715633557992987, 0.15719814371550456, 0.18545930535765365, 0.10304902316420339, 0.09243277134373784, 0.09165619543637149, 0.1276345129008405, 0.10744319049990736, 0.16341263602953404, 0.0656351397628896, 0.14855961897410452, 0.06809642058215104, 0.07921498763607815, 0.06342011838569306, 0.11590638285269961, 0.07521493782405742, 0.12400150706525892, 0.021489819228008855, 0.04606629001500551, 0.035069958394160494, 0.1360705352271907, 0.11423696618294343, 0.15516553481575102, 0.1559038381674327, 0.19357277546077967, 0.13295191194629297, 0.23469600942917168, 0.1601676843711175, 0.09147264005150646, 0.03311309308628552, 0.0966796297871042, 0.045169976001488976, 0.04750260181026533, 0.0147943270894757, 0.03548270382452756, 0.024883578917069826, 0.16832795430673286, 0.25267711956985295, 0.26137832610402256, 0.26732566009741277, 0.27378118713386357, 0.2950692776357755, 0.10504489575396292, 0.19553767080651596, 0.2269357570912689, 0.23704189370619133, 0.2537247055443004, 0.2363175427308306, 0.15964855207130313, 0.19729331019334495, 0.15477797045605257, 0.2420113590778783, 0.16126867529237643, 0.14788804954150692, 0.14396571001270786, 0.40020916087087244, 0.11649618245428428, 0.21574430371401832, 0.22613414854276925, 0.14871452003717422, 0.24034994276007637, 0.10983065731124952, 0.19381768419407308, 0.1743088333751075, 0.10104062312166207, 0.21382962208008394, 0.07420589899993502, 0.18760596751235425, 0.14544314792146906, 0.1642519753659144, 0.2053138634073548, 0.2200113856815733, 0.10537213092902675, 0.2765804494265467, 0.11047697145841084, 0.1598679309245199, 0.14694685785798356, 0.1683307596249506, 0.20578060008119792, 0.3013841825304553, 0.2463798926328309, 0.33912717131897807, 0.34860882034990937, 0.3126560995588079, 0.14809537591645494, 0.21533941762754694, 0.21633625554386526, 0.2140780189074576, 0.12350249438895844, 0.145839944598265, 0.20851243083598092, 0.2550176752265543, 0.13165772514184937, 0.5136173707433045, 0.16014426219044253, 0.31703628483228385, 0.23766966158291325, 0.42922464141156524, 0.25219282368198037, 4.3183704279363155, 29.756060801446438, 92.27884635329247, 126.92787989974022, 143.7639480829239, 133.59692484140396, 120.78481793403625, 107.75901809334755, 106.78953811526299, 114.45127978920937, 100.62396615743637, 117.6430781185627, 111.56690016388893, 115.84716528654099, 102.70540326833725, 108.2864373922348, 101.9004924595356, 105.91922521591187, 100.66372722387314, 82.98874005675316, 75.35491168498993, 96.14836871623993, 101.69316038489342, 104.38416078686714, 103.40268865227699, 118.79659742116928, 108.2896976172924, 98.89752119779587, 63.213035613298416, 75.8218002319336, 99.85234156250954, 167.2504422068596, 144.0260124206543, 67.22002699971199, 102.91645914316177, 81.23958751559258, 84.85419675707817, 93.19300889968872, 114.45578634738922, 99.50649172067642, 83.80647137761116, 80.02452671527863, 105.67738339304924, 91.07428818941116, 87.81230762600899, 79.51332494616508, 77.49880224466324, 83.78431856632233, 81.82601004838943, 87.09883511066437, 108.41262102127075, 123.68339359760284, 115.68551436066628, 78.30615252256393, 32.40290567278862, 5.634312490001321, 0.22598862822633237, 0.19003069755854085, 0.2981875149998814, 0.313441232428886, 0.21256483916658908, 0.22500969091197476, 0.26721784088294953, 0.2441245800582692, 0.14873478066874668, 0.2059532978455536, 0.2660665917210281, 0.2201679491554387, 0.16398869105614722, 0.3286016173660755, 0.11718919995473698, 0.14392012730240822, 0.14501534431474283, 0.2630429930286482, 0.11719881076714955, 0.2897490584291518, 0.18777574121486396, 0.17891985626192763, 0.3650187444873154, 0.3792461013654247, 0.13237606472102925, 0.2856522845104337, 0.26690420927479863, 0.23459274700144306, 0.23039965715724975, 0.15192968188785017, 0.13835854682838544, 0.38980564568191767, 0.17230187309905887, 0.5253012094181031, 0.24580931465607136, 0.20021394331706688, 0.1588534892653115, 0.16420507163275033, 0.11584286985453218, 0.17579593404661864, 0.08283169590868056, 0.2494233363540843, 0.17018586164340377, 0.1884841063292697, 0.39013468427583575, 0.36707514664158225, 0.21220298280240968, 0.21929976996034384, 0.2771158644463867, 0.14492147747660056, 0.24058852839516476, 0.26235689234454185, 0.07277730182977393, 0.3125068388180807, 0.13073238573269919, 0.14296643785201013, 0.18428586598020047], [0.029086374197504483, 0.05318213552527595, 0.041905409379978664, 0.11084399317041971, 0.05528120746021159, 0.10359069448895752, 0.2249441741150804, 0.14821656863205135, 0.09654459601733834, 0.07168874188209884, 0.04378177392936777, 0.04388348155771382, 0.0060451314311649185, 0.06807489829952829, 0.03921627067029476, 0.053782514441991225, 0.03865187107294332, 0.06381189072271809, 0.06040669082722161, 0.1231865472800564, 0.06462314719101414, 0.13945858780061826, 0.06865053772344254, 0.13478299806592986, 0.08028521653614007, 0.013707249581784708, 0.04019635460281279, 0.01007791273877956, 0.13458263303618878, 0.09749392163939774, 0.08708384586498141, 0.048220251192105934, 0.1079250150360167, 0.09404118347447366, 0.08119829566567205, 0.09874979878077284, 0.08438832839601673, 0.13692479173187166, 0.07846412714570761, 0.09303106853622012, 0.09445139818126336, 0.04006220027804375, 0.0805367600696627, 0.14212816720828414, 0.17468309844844043, 0.1227873757306952, 0.10340748049202375, 0.08408453766605817, 0.011651596068986692, 0.0487775632791454, 0.048255907677230425, 0.09433738203370012, 0.16057487111538649, 0.08554118059691973, 0.09057111616129987, 0.07416685461066663, 0.023787783029547427, 0.07915199414128438, 0.11469682314782403, 0.18980034976266325, 0.03592303488403559, 0.08883351838449016, 0.08800721858278848, 0.05610722153505776, 0.15107598941540346, 0.1407027686946094, 2.554367808625102, 10.73072299361229, 30.04068072885275, 62.340621426701546, 86.95680633187294, 95.5798964202404, 92.49460637569427, 87.93881043791771, 81.97423249483109, 75.28497263789177, 79.71072435379028, 81.75044730305672, 74.25613984465599, 79.28955495357513, 75.51166087388992, 91.52518719434738, 103.57015326619148, 71.12370193004608, 84.26918774843216, 82.23365977406502, 94.72745016217232, 86.8029297888279, 78.6821499466896, 73.66571232676506, 70.72112873196602, 72.46645107865334, 67.98243328928947, 63.35771664977074, 64.27469864487648, 70.26635393500328, 57.65263058245182, 69.82545599341393, 63.9522023499012, 70.15304401516914, 64.88815292716026, 74.43789929151535, 72.08620548248291, 65.31160980463028, 68.02926957607269, 59.55742657184601, 64.7213114798069, 74.29751202464104, 72.3282752931118, 77.52598598599434, 91.2583427131176, 80.31913250684738, 52.96283483505249, 38.805505111813545, 23.82210921496153, 6.404728274792433, 0.19450722844339907, 0.3346865752246231, 0.22910167055670172, 0.056524520041421056, 0.2214290213305503, 0.07717843051068485, 0.0724684348097071, 0.17344669526210055, 0.12486449122661725, 0.12887670483905822, 0.14437451463891193, 0.1210362114943564, 0.1295044578728266, 0.0897442374844104, 0.04955803546181414, 0.05891071035875939, 0.03442587811150588, 0.0576131133857416, 0.023899643238110002, 0.04940365019137971, 0.0456159288296476, 0.17589288821909577, 0.13737929781200364, 0.08841433853376657, 0.08634842204628512, 0.05446029936138075, 0.12716313038254157, 0.026176196079177316, 0.017638915123825427, 0.06807010402553715, 0.10904131646384485, 0.09693480242276564, 0.0786430218431633, 0.06847137585282326, 0.20332207262981683, 0.10641257002134807, 0.20832785870879889, 0.06916457889019512, 0.13966782891657203, 0.10117994650499895, 0.10811312720761634, 0.13089552463497967, 0.038224323507165536, 0.12331904290476814, 0.1475165007286705, 0.15047976281493902, 0.031520659395027906, 0.054955245068413205, 0.062271496426546946, 0.19105978921288624, 0.052842042641714215, 0.15010638831881806, 0.09481579269049689, 0.11024010760593228, 0.09448132157558575, 0.10559858244960196, 0.057110230409307405, 0.08935557474615052, 0.06987591259530745, 0.0526677789457608, 0.06163646663480904, 0.09835577773628756, 0.08649163428344764, 0.16893598105525598, 0.08502989279804751, 0.19539479253580794, 0.1729716020054184, 0.16783178405603394, 0.08956313860835508, 0.10001766902860254, 0.08575698971981183, 0.15674785303417593, 0.19007374212378636, 0.26016449905000627, 0.12951818760484457, 0.142892460571602, 0.07252419236465357, 0.05209902665228583, 0.2428911454626359, 0.14657774328952655, 0.19197369954781607, 0.1593871379736811, 0.08243196032708511, 0.07891063287388533, 0.10067696333862841, 0.048257547823595814, 0.044723971222992986, 0.05730159318773076, 0.09592844275175594, 0.1037888256541919, 0.13622116151964292, 0.1577480899868533, 0.25087666930630803, 0.2508459740784019, 0.05900061412830837, 0.10602905036648735, 0.09584983446984552, 0.16805672901682556, 0.11727923731086776, 0.18555051530711353, 0.19432194385444745, 0.02981205176183721, 0.08636706479592249, 0.10296408436261117, 0.09651676547946408, 0.05771248324890621, 0.23213588196085766, 0.10689317001379095, 0.18514640105422586, 0.1418787462171167, 0.1118878238776233, 0.1275991421425715, 0.180302269582171, 0.013708894366573077, 0.14004596800077707, 0.0478484871564433, 0.07823013540473767, 0.1579118226072751, 0.01511341441073455, 0.07544835068983957, 0.08319518499774858, 0.3362607001326978, 0.19819331268081442, 0.07587507818243466, 1.1796433757990599, 3.838046039454639, 23.53392317891121, 49.366996586322784, 79.15779322385788, 102.78806403279305, 112.24409982562065, 112.81133338809013, 111.7442974448204, 102.10742175579071, 94.49480384588242, 93.16941976547241, 90.31572729349136, 95.73074832558632, 82.58018597960472, 84.80553656816483, 80.46138927340508, 94.68710392713547, 94.61434543132782, 72.79166042804718, 80.8913742005825, 85.86148470640182, 100.11011213064194, 91.9474433362484, 86.71434134244919, 81.09608441591263, 70.26449963450432, 69.16948959231377, 64.95649605989456, 58.75361770391464, 55.345721170306206, 54.33144919574261, 52.69629813730717, 71.33205235004425, 77.71419748663902, 90.44922173023224, 82.61252224445343, 89.33772817254066, 87.69891411066055, 78.38720217347145, 82.48605743050575, 75.98051011562347, 84.32282567024231, 83.55637639760971, 86.84617146849632, 89.86156046390533, 97.63364061713219, 99.12895157933235, 82.08679005503654, 68.21644753217697, 48.45389038324356, 20.797596909105778, 1.0761321801692247, 1.1763635580427945, 0.2940799650968984, 0.11134532876894809, 0.22246525244554505, 0.11194915496162139, 0.22114890511147678, 0.1920881832484156, 0.08620002219686285, 0.11047530904761516, 0.26904601778369397, 0.10850381600903347, 0.10931246011750773, 0.06924043380422518, 0.02977574033138808, 0.07279375524376519, 0.15713878674432635, 0.08693902316736057, 0.12353656638879329, 0.10983136235154234, 0.12911877856822684, 0.11141652299556881, 0.0658319573267363, 0.037699283711845055, 0.13650510722072795, 0.14628048345912248, 0.21243787254206836, 0.14849459199467674, 0.14114243182120845, 0.101817911490798, 0.12646082119317725, 0.12010134290903807, 0.15937006857711822, 0.2811966376611963, 0.3535044123418629, 0.18992028082720935, 0.1612512645078823, 0.029296724824234843, 0.0943359051598236, 0.06469618194387294, 0.1332989105139859, 0.1888120168587193, 0.06416939810151234, 0.07642310971277766, 0.13072367291897535, 0.12757104443153366, 0.18921429058536887, 0.2172121827607043, 0.18976241117343307, 0.2538896701298654, 0.19318651728099212, 0.21114634262630716, 0.2085407215054147, 0.20714408863568678, 0.08774452056968585, 0.1483506747172214, 0.0608736761205364, 0.07396248198347166, 0.10128383233677596, 0.045261033810675144, 0.11781949855503626, 0.10852625855477527, 0.16921507311053574, 0.18694604979828, 0.2889141719788313, 0.20005966565804556, 0.26646773738320917, 0.22081471601268277, 0.11758675362216309, 0.15647555905161425, 0.19037778518395498, 0.2979022928047925, 0.2409120899392292, 0.29721212515141815, 0.20023181423312053, 0.22827496257377788, 0.11202716952539049, 0.12173331080703065, 0.21365733991842717, 0.1963967809570022, 0.20726428687339649, 0.22584831778658554, 0.18435381702147424, 0.18980466906214133, 0.20592177141224965, 0.11619708209764212, 0.06309208169113845, 0.20225937652867287, 0.14012297324370593, 0.18654637358849868, 0.1703689049463719, 0.24947225872892886, 0.315422885469161, 0.28234735247679055, 0.17519120243377984, 0.19329289672896266, 0.2209768010652624, 0.19350583374034613, 0.12357364408671856, 0.2307457651477307, 0.26311426889151335, 0.14816110051469877, 0.22931392479222268, 0.168437079701107, 0.17903506726725027, 0.2182031873962842, 0.2545176161220297, 0.16433653567219153, 0.37085490475874394, 0.1487184237339534, 0.13591308117611334, 0.15256907179718837, 0.30546394642442465, 0.29168060165829957, 0.15995673631550744, 0.10716964970924892, 0.17331445938907564, 0.20279569696867839, 0.13658212730661035, 0.30393815017305315, 0.20239602075889707, 0.2407632299582474, 0.14554697438143194, 0.20761318533914164, 0.420510076219216, 0.6500581931322813, 11.46370841190219, 37.44220666587353, 76.7824874818325, 120.05282521247864, 151.5679693222046, 154.56091672182083, 147.1333944797516, 132.31485843658447, 115.87482020258904, 107.93910562992096, 101.58577054738998, 113.61878246068954, 93.49709138274193, 100.01470685005188, 90.3084696829319, 106.9369626045227, 113.58861207962036, 78.26857253909111, 95.66945761442184, 98.09172883629799, 123.80602061748505, 110.05886748433113, 101.3348776102066, 96.05777397751808, 90.020262748003, 85.07387816905975, 88.08983713388443, 79.96775016188622, 76.57200157642365, 82.21561834216118, 60.888369753956795, 81.28292039036751, 81.77086740732193, 97.07352787256241, 91.03007376194, 101.61872997879982, 97.23235934972763, 82.9648469388485, 91.99725106358528, 93.06328386068344, 101.82431414723396, 110.70399686694145, 115.59568718075752, 128.41167747974396, 134.38402980566025, 125.4898926615715, 93.91262948513031, 64.5201426744461, 31.575171388685703, 8.268774300813675, 0.17520404158858582, 0.33724081004038453, 0.20787039888091385, 0.26185713009908795, 0.2592446218477562, 0.114543235686142, 0.2872011763975024, 0.20113653677981347, 0.1721945288591087, 0.20122406567679718, 0.24535252276109532, 0.13437615270959213, 0.1339223887771368, 0.2109432761790231, 0.19323451939271763, 0.10746713218395598, 0.16164871427463368, 0.2167473459849134, 0.18503659288398921, 0.201806265686173, 0.2401683243806474, 0.29805143480189145, 0.364190656109713, 0.15908597444649786, 0.1594114804174751, 0.23771460604621097, 0.22288011299679056, 0.21337655576644465, 0.1681550932698883, 0.16325346019584686, 0.1678823391557671, 0.19534820050466806, 0.1885774833499454, 0.27478566917125136, 0.3713447815971449, 0.19496661785524338, 0.24429650598904118, 0.11492436562548392, 0.18129480304196477, 0.16865331184817478, 0.2554162679007277, 0.25619296997319907, 0.13088121602777392, 0.24930399900767952, 0.19949953712057322, 0.31226415652781725, 0.25910934316925704, 0.35181949962861836, 0.25608749594539404, 0.3367463615722954, 0.23958367528393865, 0.27604524220805615, 0.26653064182028174, 0.18655103427590802, 0.23419856268446892, 0.21425237908260897, 0.08899544016458094, 0.22170422453200445, 0.15579493541736156, 0.1721618595183827], [0.05823765663080849, 0.02857369301636936, 0.07476730403141119, 0.05065743447630666, 0.040728674866841175, 0.017507298944110516, 0.04566947107377928, 0.03462905217020307, 0.05462492255901452, 0.05395805092121009, 0.050612419508979656, 0.06701769409119152, 0.12167126726126298, 0.015230386161420029, 0.04577118241286371, 0.05550946239964105, 0.02184160093747778, 0.06921946071088314, 0.007914318484836258, 0.04540757086942904, 0.06786910817027092, 0.035112865662085824, 0.01060240148945013, 0.015012174335424788, 0.024025021666602697, 0.03169454830640461, 0.05214456483372487, 0.009908078736771131, 0.08393125448492356, 0.010151194255740847, 0.026208716990367975, 0.026035510854853783, 0.044041128567187116, 0.008331617918884149, 0.0791400158777833, 0.08540878145140596, 0.04283976217266172, 0.047476463369093835, 0.1072854247468058, 0.0711770384805277, 0.07759542102576233, 0.07702709917793982, 0.0672749373188708, 0.08574993189540692, 0.02142574590834556, 0.16257622075499967, 0.03057076974073425, 0.08480491072987206, 0.048648552037775517, 0.04895211270195432, 0.018769421258184593, 0.0744049355853349, 0.09855982381850481, 0.016096260987978894, 0.0660005361714866, 0.015969153355399612, 0.043807882684632204, 0.0665149484120775, 0.08368244947632775, 0.05305471990141086, 0.04695124545833096, 0.04372662122477777, 0.03204267122782767, 0.10555155255133286, 0.13841117994161323, 0.13020520855206996, 0.24912724911700934, 0.4173099354375154, 0.12512761226389557, 2.285539833828807, 10.128726996481419, 23.823881819844246, 37.64106139540672, 62.634474858641624, 94.77217376232147, 111.14693909883499, 116.19005888700485, 117.07845121622086, 117.480408847332, 116.18875935673714, 112.8310239315033, 112.74618208408356, 117.37674281001091, 104.0242213010788, 120.46458631753922, 120.92810824513435, 69.05368700623512, 92.0395427942276, 99.10766512155533, 115.37636294960976, 100.83880662918091, 91.9038824737072, 86.5136893093586, 80.01723870635033, 87.73297548294067, 83.64722952246666, 94.66057375073433, 97.54005163908005, 103.41391324996948, 85.04069074988365, 84.58863660693169, 96.07749491930008, 113.70073646306992, 111.1252498626709, 110.54622173309326, 101.58888638019562, 94.7104574739933, 77.49466806650162, 66.28942653536797, 43.256901651620865, 20.873110257089138, 5.433134185150266, 0.26449656346812844, 0.24816269462462515, 0.27693029784131795, 0.2148589215357788, 0.04212781619571615, 0.09836610101046972, 0.08736807358218357, 0.08342824163264595, 0.060479822059278376, 0.10782651719637215, 0.02563338741310872, 0.07571997673949227, 0.08516884510754608, 0.08233808606746607, 0.07468517796951346, 0.11695655892253853, 0.08406926426687278, 0.023451300694432575, 0.06256534979911521, 0.0367165725765517, 0.12143023996031843, 0.01745752309943782, 0.06087127898354083, 0.06521202652947977, 0.09514495744952, 0.058878104100585915, 0.042738629708765075, 0.07985499352798797, 0.039139306245488115, 0.013916180851083482, 0.030013171926839277, 0.025902597772073932, 0.05288705389830284, 0.045616210845764726, 0.016515479801455513, 0.04090960675966926, 0.057448534716968425, 0.06436810072045773, 0.07368837716057897, 0.020823285267397296, 0.12752592185279354, 0.08281416638055816, 0.11447835713624954, 0.01877038233942585, 0.04367715337139089, 0.03034383767953841, 0.021726447448600084, 0.059005794319091365, 0.044210646228748374, 0.07878133590565994, 0.08815086126560345, 0.017704346573736984, 0.024492520897183567, 0.09912375957355835, 0.01886692647531163, 0.0596683503681561, 0.0671172903093975, 0.061188573090475984, 0.05008185071346816, 0.1115795505756978, 0.06373922704369761, 0.08518089016433805, 0.11141894981847145, 0.0190176733667613, 0.044498183924588375, 0.052831288921879604, 0.03919571317965165, 0.036424225763767026, 0.026093463311553933, 0.06473824687418528, 0.0871785958588589, 0.10577686116448604, 0.09351085958769545, 0.12135498618590645, 0.02957939217594685, 0.07378022535704076, 0.06165789243823383, 0.08185913364286534, 0.060671912142424844, 0.06168245381559245, 0.08588123266235925, 0.0943058036500588, 0.028840517370554153, 0.10758095537312329, 0.03800004276854452, 0.0770461130014155, 0.05839432400534861, 0.03642379160737619, 0.03121764792012982, 0.025153444221359678, 0.03838988923234865, 0.01710840570012806, 0.03781780840654392, 0.03421809531573672, 0.09105904115131125, 0.08505901467287913, 0.013800258311675861, 0.020665358097176068, 0.08186889288481325, 0.07028804946457967, 0.017215857551491354, 0.040374406962655485, 0.12031089572701603, 0.087623468862148, 0.11901266421773471, 0.05595683272986207, 0.06108939247496892, 0.0028389184899424436, 0.06422507402021438, 0.12685249705100432, 0.04210369639622513, 0.07330667576752603, 0.12542423384729773, 0.15473747887881473, 0.04130375767999794, 0.052504666018649004, 0.08449579880107194, 0.13022128347074613, 0.058257253040210344, 0.017372717884427402, 0.018920372240245342, 0.09187659103190526, 0.018232162001368124, 0.03670675025205128, 0.003563757891242858, 0.06309885749942623, 0.05924016084463801, 0.15035021351650357, 0.32401464006397873, 0.0698332316824235, 0.2511635242262855, 1.3478617742657661, 0.9093677974306047, 12.951098699122667, 32.82492242753506, 56.64591260254383, 79.21640127897263, 100.89088663458824, 123.32024708390236, 132.45529890060425, 135.92249125242233, 133.03984433412552, 133.22217375040054, 123.48082646727562, 122.88124144077301, 126.29225000739098, 139.60134744644165, 128.91110748052597, 141.79059237241745, 144.35069739818573, 91.51838555932045, 116.2887167930603, 125.88427349925041, 142.42907971143723, 125.60620442032814, 118.07712882757187, 111.5471488237381, 105.61939090490341, 117.2962935268879, 114.80390846729279, 118.45298185944557, 116.77594184875488, 132.236248254776, 126.9419239461422, 122.77174651622772, 128.41821312904358, 132.85549342632294, 130.54679811000824, 131.56673938035965, 124.80828523635864, 120.36077588796616, 107.31671422719955, 99.35869485139847, 76.1637818813324, 49.12023022770882, 21.01586289703846, 4.193141497671604, 1.3426729151979089, 0.746622352162376, 0.09755703387781978, 0.12445124855730683, 0.10895563551457599, 0.041801679399213754, 0.08564170449972153, 0.03903606237145141, 0.05898557079490274, 0.06163109348563012, 0.09353198853204958, 0.08951302879722789, 0.06589391923625953, 0.08179744632798247, 0.0794533580483403, 0.04875227459706366, 0.06525746823172085, 0.04258038527041208, 0.058611624845070764, 0.08207078673876822, 0.07065768353641033, 0.108010554977227, 0.062401528120972216, 0.08712226685020141, 0.007878202795836842, 0.061147480373620056, 0.06939513448742218, 0.015117970269784564, 0.07543007159256376, 0.06716528499964625, 0.04978179669706151, 0.06907644885359332, 0.038217529145185836, 0.08328976429766044, 0.05558453805861063, 0.04179237657808699, 0.04522234194155317, 0.04490230559895281, 0.13584070693468675, 0.06731803383445367, 0.06428438646253198, 0.033423830318497494, 0.04066801171575207, 0.046511203836416826, 0.05846436048159376, 0.030905222301953472, 0.13075496186502278, 0.017855139849416446, 0.057897660226444714, 0.06480931493570097, 0.06835485866758972, 0.03278656666225288, 0.08402322142501362, 0.07996556611033157, 0.11426843324443325, 0.058434474194655195, 0.08689125112141483, 0.04840957306441851, 0.07431031917803921, 0.04202881369565148, 0.07521720879594795, 0.10488889631233178, 0.04785819815879222, 0.1788656201097183, 0.20349754602648318, 0.19019676052266732, 0.19733625085791573, 0.21634918375639245, 0.22171155695104972, 0.1561637085978873, 0.15952517744153738, 0.19798478402663022, 0.3082351852208376, 0.14346381038194522, 0.29141645645722747, 0.2516856696456671, 0.237689373025205, 0.11425064396462403, 0.12322781069087796, 0.28970331244636327, 0.1746777698281221, 0.09022592843393795, 0.3228647861396894, 0.12344113361905329, 0.2440569258760661, 0.21765211306046695, 0.14084471185924485, 0.17050905211362988, 0.13670697138877586, 0.313808981445618, 0.1755676048924215, 0.23793114989530295, 0.1736086467280984, 0.12677209277171642, 0.3029028244782239, 0.1419041128247045, 0.12281014482141472, 0.18438451224938035, 0.25952969561330974, 0.23955330660101026, 0.1295533950906247, 0.20099123910767958, 0.18578608782263473, 0.2538963791448623, 0.1882014371221885, 0.33122849359642714, 0.18314374523470178, 0.31156244105659425, 0.24123986688209698, 0.16225645900703967, 0.23599208128871396, 0.31173171009868383, 0.3490694862557575, 0.13219918124377728, 0.1654174440773204, 0.2772134420229122, 0.24961935239844024, 0.21989097964251414, 0.1199140322569292, 0.16909045167267323, 0.21684841165551916, 0.13740384805714712, 0.2513536624610424, 0.14593571133445948, 0.3395726380404085, 0.13244870613561943, 0.18536143092205748, 0.22043767530703917, 0.20735441328724846, 0.5066925392020494, 0.47374937566928566, 0.16675518010742962, 3.905328791588545, 16.303158178925514, 36.79545857012272, 68.2799269258976, 95.98251521587372, 132.91980117559433, 150.41951894760132, 159.61291283369064, 156.29508286714554, 157.35334128141403, 152.68597573041916, 154.06937509775162, 155.24361848831177, 173.86643439531326, 157.3451793193817, 168.78920763731003, 168.1079649925232, 104.46857705712318, 137.76445001363754, 145.95811754465103, 168.84383350610733, 152.36455857753754, 135.74817180633545, 129.22650575637817, 117.44891613721848, 128.631412088871, 121.6445142030716, 136.60569459199905, 143.04899364709854, 160.5264750123024, 158.69237422943115, 148.78037810325623, 149.36241567134857, 164.79416280984879, 154.63794618844986, 156.14970266819, 142.43816882371902, 135.25245040655136, 110.51396146416664, 96.32363811135292, 66.31592631340027, 32.47401885688305, 10.673317573964596, 1.1411175993271172, 0.3389671049080789, 0.38103580533061177, 0.4411599790910259, 0.26352182670962065, 0.35495964519213885, 0.32327837019693106, 0.536561964545399, 0.2756406826665625, 0.1522398105589673, 0.17034273681929335, 0.35564117424655706, 0.2564843965228647, 0.1267964649014175, 0.24842790851835161, 0.23742070072330534, 0.24144830647855997, 0.14482792234048247, 0.20292668603360653, 0.221607121929992, 0.20377692009788007, 0.19495058746542782, 0.27114101161714643, 0.14423223008634523, 0.20380025322083384, 0.19947989989304915, 0.21886102709686384, 0.1669943000888452, 0.209493609436322, 0.1974390828399919, 0.27896915562450886, 0.11641850927844644, 0.19282804511021823, 0.18085604533553123, 0.14594702166505158, 0.15834581572562456, 0.21641447790898383, 0.1417253294494003, 0.2644899731967598, 0.14419455867027864, 0.23794382577762008, 0.12161816659499891, 0.21167859609704465, 0.18193236726801842, 0.18558797892183065, 0.23687090288149193, 0.13413764128927141, 0.25061492866370827, 0.20412636775290594, 0.29925404058303684, 0.22151562996441498, 0.22490323724923655, 0.14596772758523002, 0.2850621583638713, 0.33314255182631314, 0.2396471140673384, 0.17025265493430197, 0.14351479592733085, 0.08766676575760357, 0.31196094467304647, 0.14870320970658213, 0.17547710740473121, 0.29017899942118675, 0.09637796902097762], [0.3786517301341519, 0.31103189452551305, 0.39933452499099076, 0.35657580534461886, 0.33036472275853157, 0.28588009416125715, 0.2816391654778272, 0.4429959930712357, 0.3502780885901302, 0.2772064658347517, 0.32466962991748005, 0.29178951925132424, 0.30166314099915326, 0.20612313091987744, 0.40579622669611126, 0.35454148950520903, 0.23891174962045625, 0.2603344211820513, 0.20679824781836942, 0.17560494976351038, 0.3954638389404863, 0.2567108109360561, 0.4263913887552917, 0.3715884732082486, 0.41061751486267895, 0.5054469779133797, 0.33823125064373016, 0.3500829037511721, 0.19691900059115142, 0.3014614252606407, 0.37994725280441344, 0.3381973196519539, 0.4323933448176831, 0.3534087643492967, 0.39735604834277183, 0.2548199670854956, 0.19424891652306542, 0.14606242562877014, 0.34218870860058814, 0.5167792167048901, 0.2178631947026588, 0.3095596516504884, 0.2532694424735382, 0.4022093676030636, 0.4564840521197766, 0.24677075212821364, 0.2319921279558912, 0.35553724388591945, 0.3791391133563593, 0.34889481437858194, 0.3307256440166384, 0.2844660059781745, 0.38162281445693225, 0.4079235187964514, 0.3844420553650707, 0.23456663824617863, 0.35724376793950796, 0.5009386979509145, 0.38961874321103096, 0.33866074634715915, 0.2869439183268696, 0.44659992156084627, 0.20604921301128343, 0.2959456649841741, 0.11771041026804596, 0.37290566659066826, 0.34760689130052924, 0.39690906764008105, 0.2795222634449601, 0.1285835268208757, 0.06462395613198169, 0.04576240280584898, 0.15182367351371795, 0.9776826098095626, 3.2017666194587946, 4.230405623093247, 14.14670929312706, 15.289041046053171, 22.348529286682606, 31.686391420662403, 31.262100487947464, 40.22732801735401, 36.43548108637333, 26.01392850279808, 18.33344243466854, 3.174498095177114, 1.860742459539324, 1.2210263614542782, 2.9666855838149786, 22.181604243814945, 42.20344617962837, 49.822124764323235, 67.79153913259506, 79.89075869321823, 94.75451990962029, 79.12701487541199, 55.50265654921532, 37.95332483947277, 18.707444965839386, 5.702344514429569, 2.089411220513284, 9.0160165540874, 12.235607542097569, 13.346999455243349, 10.247268285602331, 4.858905673027039, 1.7009591334499419, 0.35909409052692354, 0.37856148497667164, 1.1770603456534445, 1.6994897997938097, 0.7248887058813125, 0.15350469737313688, 0.2941860625287518, 0.13467960205161944, 0.4360071290284395, 0.5493215611204505, 0.41964974894654006, 0.39673641440458596, 0.15869343769736588, 0.2535408904077485, 0.3633252822328359, 0.4001880541909486, 0.3551723447162658, 0.26757962303236127, 0.3891148546244949, 0.31586517579853535, 0.461613480001688, 0.40646157693117857, 0.35136821446940303, 0.3713897260604426, 0.4158047412056476, 0.31009456200990826, 0.17126861057477072, 0.3185582812875509, 0.5630020145326853, 0.21630281436955556, 0.3087688487721607, 0.3539016394643113, 0.40564096940215677, 0.25395025906618685, 0.3646319964900613, 0.5200265580788255, 0.44105129898525774, 0.3526112821418792, 0.46604021277744323, 0.32690016960259527, 0.3753522306215018, 0.31097935047000647, 0.4335058241849765, 0.30557693098671734, 0.3901184757705778, 0.2885446714935824, 0.48175403208006173, 0.29933935787994415, 0.3012211772147566, 0.28581713035237044, 0.30806650989688933, 0.3143653250299394, 0.4802383290370926, 0.2145538543118164, 0.20990450691897422, 0.27326996612828225, 0.3113068453967571, 0.3202197124483064, 0.3411208471516147, 0.48348629381507635, 0.20354283187771216, 0.26584902370814234, 0.35965675720945, 0.4004782042466104, 0.3068406303646043, 0.21967499982565641, 0.22867753315949813, 0.22756732476409525, 0.22797474899562076, 0.2950344263808802, 0.2041887675295584, 0.4130629211431369, 0.39950961247086525, 0.21911634074058384, 0.2583680266980082, 0.2883746603038162, 0.16508355183759704, 0.2804430015385151, 0.212094733142294, 0.2881891530705616, 0.17319607199169695, 0.1856795302592218, 0.22337554109981284, 0.26663213793653995, 0.24490263283951208, 0.25076505029574037, 0.24602530931588262, 0.28515881567727774, 0.20408798387506977, 0.31857671623583883, 0.2198661770671606, 0.3200247947825119, 0.34580608480609953, 0.5480890022590756, 0.42804943572264165, 0.4329578223405406, 0.3605633944971487, 0.3650335577549413, 0.17281005129916593, 0.28660448966547847, 0.18331310333451256, 0.32537787628825754, 0.3113500087056309, 0.2557564980816096, 0.252838046872057, 0.21051164309028536, 0.17200541478814557, 0.2353779540862888, 0.4531706002308056, 0.23823871073545888, 0.26131058286409825, 0.21290040866006166, 0.4198580252705142, 0.423782947473228, 0.24737990694120526, 0.42380325263366103, 0.3347895556362346, 0.10584323143120855, 0.2427339437417686, 0.5112816242035478, 0.3636017470853403, 0.27615855331532657, 0.3846983931725845, 0.28196927276439965, 0.193109615938738, 0.2517994260415435, 0.5166869529057294, 0.2094953163759783, 0.2823947905562818, 0.229465946322307, 0.3989485785132274, 0.34443388343788683, 0.27843077201396227, 0.11961046417127363, 0.48383053159341216, 0.25100161728914827, 0.5662136734463274, 0.1966460535186343, 0.050874156440841034, 0.2332383274915628, 0.5341101461090147, 0.3367428883211687, 4.715890372171998, 12.245772946625948, 19.56089247018099, 33.54507118463516, 35.121131613850594, 45.930464789271355, 58.03295977413654, 54.808475598692894, 64.5902869105339, 63.40600445866585, 43.51054184138775, 30.546817369759083, 7.534537799656391, 2.0321618299931288, 3.191189649514854, 7.480962574481964, 31.803504936397076, 56.59385919570923, 75.54343476891518, 101.29404500126839, 113.88386383652687, 132.04692721366882, 117.40574285387993, 88.41971263289452, 68.25220361351967, 44.564274698495865, 18.445999994874, 8.399926163256168, 18.949761763215065, 24.21707332134247, 27.274431064724922, 23.44823207706213, 12.265559434890747, 6.8540099915117025, 1.8558235047385097, 1.3683057460002601, 1.3076030532829463, 0.358457476249896, 0.5395781714469194, 0.42042520421091467, 0.5381101439706981, 0.3453387989429757, 0.4365481249988079, 0.4536911426112056, 0.5741618375759572, 0.33694585086777806, 0.2681967930402607, 0.3012083232169971, 0.4003008012659848, 0.34117448958568275, 0.3392119245836511, 0.24706379655981436, 0.36167670506983995, 0.31070618075318635, 0.4644183232448995, 0.41119250119663775, 0.4957856400869787, 0.4410963918780908, 0.30561187129933387, 0.275886541348882, 0.12714235024759546, 0.32828430470544845, 0.43927545833867043, 0.33783099555876106, 0.33598479931242764, 0.333539986750111, 0.3336294600740075, 0.38899715000297874, 0.25086414185352623, 0.3674772719386965, 0.3482235566480085, 0.34609525522682816, 0.41539590689353645, 0.27566063159611076, 0.3139263595221564, 0.2907375991344452, 0.22435663064243272, 0.3822136530652642, 0.39209989132359624, 0.31686746107880026, 0.32870367751456797, 0.26814594108145684, 0.16954745136899874, 0.19214224128518254, 0.24959705828223377, 0.35171966592315584, 0.30480518646072596, 0.22153047291794792, 0.35832955967634916, 0.4339187848381698, 0.350258614635095, 0.293174812104553, 0.41181786451488733, 0.3268107259646058, 0.2724045922514051, 0.21815166750457138, 0.2726342127425596, 0.359823948238045, 0.28995285218115896, 0.24328371189767495, 0.25243271549697965, 0.1703694392926991, 0.2999104553600773, 0.6668020540382713, 0.5789239914156497, 0.6351900659501553, 0.6534610886592418, 0.6233265087939799, 0.4065160802565515, 0.5480448296293616, 0.6217634270433336, 0.5673755798488855, 0.5696970771532506, 0.5299100058618933, 0.3768321918323636, 0.43635813519358635, 0.4517642897553742, 0.599636739352718, 0.4922548873582855, 0.326573743368499, 0.4662743752123788, 0.46416335098911077, 0.42063440079800785, 0.5565653974190354, 0.574968463042751, 0.782524369424209, 0.6723950570449233, 0.9076828847173601, 0.9069444180931896, 0.5853534839116037, 0.7043107913341373, 0.5578496097587049, 0.42580583423841745, 0.48681515268981457, 0.3747752553317696, 0.8189569332171232, 0.5867963971104473, 0.6336104194633663, 0.49508143099956214, 0.4519654711475596, 0.5139417189639062, 0.5664496764075011, 0.8401573612354696, 0.37769712042063475, 0.5505745438858867, 0.5397268384695053, 0.6210245448164642, 0.7115174608770758, 0.6207538093440235, 0.6540352734737098, 0.8760045783128589, 0.6724955141544342, 0.5695191398262978, 0.6736283877398819, 0.5177474522497505, 0.5737370322458446, 0.8030953968409449, 0.5510140734259039, 0.4487426800187677, 0.5958070792257786, 0.9850353933870792, 0.5071874626446515, 0.47384974372107536, 0.5398514005355537, 0.5306142149493098, 0.8036083693150431, 0.4042661556741223, 0.17759543436113745, 0.7447789167053998, 0.5139774607960135, 1.2738183536566794, 0.4555480554699898, 0.18780985032208264, 0.2822381380246952, 0.2386483910959214, 0.15683790523326024, 1.7062014271505177, 5.0869000889360905, 9.349344167858362, 19.59512673318386, 23.557459115982056, 34.81921121478081, 47.13727243244648, 46.14006534218788, 56.98084183037281, 59.18359883129597, 38.84167157113552, 27.298922650516033, 6.793188080191612, 2.3116425331681967, 3.398017776198685, 8.942373655736446, 35.84414541721344, 64.76034298539162, 93.29432666301727, 126.60184219479561, 141.1229833960533, 151.27833366394043, 138.25418293476105, 95.48322960734367, 64.58277091383934, 40.39283573627472, 14.90557987242937, 5.613540904596448, 14.767548479139805, 17.03950546681881, 18.414693474769592, 15.181621760129929, 7.013210523873568, 2.8616226464509964, 0.5601636262144893, 0.4776311048772186, 1.3274699309840798, 2.165775722824037, 1.1339433467946947, 0.30089089181274176, 0.5624608998186886, 0.3506233950611204, 0.6402982980944216, 1.020473123062402, 1.3583940966054797, 0.9620380774140358, 0.4776730213779956, 0.3820479166461155, 0.6264175835531205, 0.7313544151838869, 0.6436749512795359, 0.394101730780676, 0.6440540996845812, 0.6259704544208944, 0.8303050836548209, 0.5774014606140554, 0.8240118494722992, 0.7526704994961619, 0.8101178356446326, 0.7712989998981357, 0.5338407761882991, 0.5138460709713399, 1.0007778299041092, 0.6392245588358492, 0.8021823177114129, 0.6591761601157486, 0.6703973142430186, 0.620073942700401, 0.6105802115052938, 0.8782000292558223, 0.7529924134723842, 0.6213119043968618, 0.7377289887517691, 0.47767073556315154, 0.6451313418801874, 0.6704658886883408, 0.5149616673588753, 0.5792440648656338, 0.6166183250024915, 0.6157261447515339, 0.525519757065922, 0.6220658670645207, 0.4466632119147107, 0.5464733764529228, 0.4612058331258595, 0.7434844330418855, 0.7877150690183043, 0.6649979227222502, 0.655298646306619, 0.7855221710633487, 0.6449821405112743, 0.6299887981731445, 0.7026857847813517, 0.5451120401266962, 0.5231492780148983, 0.44189155858475715, 0.48683367669582367, 0.5646375298965722, 0.5995033902581781, 0.4958630015607923, 0.5098415608517826, 0.42264057439751923, 0.6565018754918128], [0.020433761637832504, 0.06683994972263463, 0.09743938862811774, 0.07158007661928423, 0.053416220034705475, 0.0958544877357781, 0.11613495691563003, 0.07681449613301083, 0.109202050807653, 0.13585356093244627, 0.1182519034773577, 0.09953596323612146, 0.0435693898180034, 0.10246075238683261, 0.10213496439973824, 0.11443821436841972, 0.061100992243154906, 0.1367317739641294, 0.14616889413446188, 0.145460024359636, 0.0559750635875389, 0.046198099153116345, 0.08391995157580823, 0.09310497902333736, 0.0526586393971229, 0.15694337926106527, 0.05379469679610338, 0.05784406603197567, 0.07366529636783525, 0.1745352626312524, 0.13406013138592243, 0.07386025856249034, 0.07387654128251597, 0.0957166041189339, 0.18032362859230489, 0.14233644353225827, 0.04033949262520764, 0.08733784590731375, 0.04407597611134406, 0.015488251865463099, 0.1595995554816909, 0.1525294262683019, 0.09128737030550838, 0.13186016818508506, 0.034272806442459114, 0.060051821783417836, 0.14585882483515888, 0.1686736912233755, 0.152587388001848, 0.10140631638932973, 0.18150503863580525, 0.14028630510438234, 0.0782351300586015, 0.07690530532272533, 0.1516398138483055, 0.2306454416248016, 0.09082737233256921, 0.03413077050936408, 0.05837562188389711, 0.2823385951342061, 0.12510724773164839, 0.023582707217428833, 0.15759973466629162, 0.08452062364085577, 0.1958699303213507, 0.08589163757278584, 0.1095426149549894, 0.1190539647359401, 0.0369023692474002, 0.021702077174268197, 0.18764130858471617, 0.22286347404588014, 0.32536917831748724, 0.04569210286717862, 0.04320180778449867, 0.11593093309784308, 0.10488057683687657, 0.11067645333241671, 0.11527641079737805, 0.30902120866812766, 0.385117320693098, 0.37717188766691834, 0.47779972082935274, 0.3474443609593436, 0.4800598870497197, 0.11641634220723063, 0.034997135153389536, 0.03799444326432422, 0.11606750311329961, 0.43984747608192265, 0.440931071061641, 0.42217732581775635, 0.18856402079109102, 0.7683925714809448, 0.5407613923307508, 0.06447875493904576, 0.37291923305019736, 0.44643581786658615, 0.6455026532057673, 0.7014034723397344, 0.16201005113543943, 0.03134374623186886, 0.3262897382955998, 0.5637707014102489, 0.4328830138547346, 0.3511223557870835, 0.1624555920716375, 0.2495916554471478, 0.05119350258610211, 0.09405230826814659, 0.07214158555143513, 0.10343903661123477, 0.18453081924235448, 0.15801233908860013, 0.278402718831785, 0.3655638371128589, 0.16139010549522936, 0.0939416911569424, 0.1794215480913408, 0.09674340995843522, 0.12278641093871556, 0.09025563660543412, 0.06424566119676456, 0.1584360163542442, 0.18058991117868572, 0.0779538783535827, 0.05582566554949153, 0.13155830703908578, 0.09121216848143376, 0.03909898907295428, 0.13314123381860554, 0.02910517836426152, 0.12426880639395677, 0.16579867049586028, 0.11431409759097733, 0.0766683449910488, 0.13231224002083763, 0.13823330198647454, 0.14056588697712868, 0.1047790732991416, 0.07804306223988533, 0.0768839314696379, 0.11257256643148139, 0.09169334734906442, 0.03225947111786809, 0.11958180242800154, 0.20759607141371816, 0.09699769943836145, 0.09756802508491091, 0.08201232034480199, 0.19677831907756627, 0.03957432352763135, 0.04444220001460053, 0.1883354689925909, 0.07261631515575573, 0.10182888043345883, 0.1869140038616024, 0.077881570905447, 0.060368381164153107, 0.1136840513208881, 0.07459989035851322, 0.10330834440537728, 0.06672745497780852, 0.14413156517548487, 0.055220633366843686, 0.10575421823887154, 0.08055353260715492, 0.1863481756299734, 0.10609478980768472, 0.13898569130105898, 0.12577599700307474, 0.06119288125773892, 0.07665255950996652, 0.11045292587368749, 0.12525371799711138, 0.09290130401495844, 0.12929215910844505, 0.16756596160121262, 0.17342312465189025, 0.17044409934896976, 0.24875538860214874, 0.21882837259909138, 0.19299585954286158, 0.11360134638380259, 0.2526085451245308, 0.23607386596268043, 0.16669692151481286, 0.1569029173697345, 0.12233673623995855, 0.2571296493988484, 0.19451227504760027, 0.316070988192223, 0.15615596057614312, 0.2602035063318908, 0.1509211031952873, 0.24712711659958586, 0.17384770733769983, 0.1329044738668017, 0.362624516710639, 0.2204058223287575, 0.14777270494960248, 0.22974592895479873, 0.2269781634095125, 0.17611010000109673, 0.3016648627817631, 0.19761883100727573, 0.19524422561516985, 0.2671825740253553, 0.1722085554501973, 0.17635506810620427, 0.22339590563206002, 0.2769272995647043, 0.09944219287717715, 0.2664061984978616, 0.22483657754492015, 0.10746002983069047, 0.2191686473088339, 0.27177860552910715, 0.2894989843480289, 0.2148274247883819, 0.16032255574828014, 0.1808412914397195, 0.17670231900410727, 0.048867415098357014, 0.35046712844632566, 0.2512492868117988, 0.23596791696036234, 0.1553188031539321, 0.22950388491153717, 0.27593071397859603, 0.1966269061085768, 0.3988263022620231, 0.17583267035661265, 0.12017385073704645, 0.1357821811689064, 0.49216707644518465, 0.23499280912801623, 0.16424041270511225, 0.17923277540830895, 0.36844657617621124, 0.31288732308894396, 0.1267223688773811, 0.08091090639936738, 0.09407331846887246, 0.21020788204623386, 0.1991942324093543, 0.35291591892018914, 0.14686067966977134, 0.09473166282987222, 0.12020274996757507, 0.04201229719910771, 0.016569372710364405, 0.026665796467568725, 0.1710124805686064, 0.21208291815128177, 0.15305595035897568, 0.44279436639044434, 0.29710498871281743, 0.5503131297882646, 0.2950343966949731, 0.27704874461051077, 0.2600894827628508, 0.15347953856689855, 0.12884951254818588, 0.07720219407929108, 0.35094115301035345, 0.2760725829284638, 0.4925472044851631, 0.37588901119306684, 1.3171525346115232, 1.2420121603645384, 0.09045309241628274, 0.4329064954072237, 0.24957776244264096, 0.13021156133618206, 0.16745100292610005, 0.16584633121965453, 0.05028540326748043, 0.20089657075004652, 0.20591130713000894, 0.3165813483064994, 0.4115208570146933, 0.2853095013415441, 0.4885859467322007, 0.31605347350705415, 0.24220936407800764, 0.13768531498499215, 0.18237262411275879, 0.28746962605509907, 0.22297023941064253, 0.24856161384377629, 0.13981321564642712, 0.10303596136509441, 0.09943988479790278, 0.2162651577964425, 0.339351121801883, 0.20583835401339456, 0.3353685198817402, 0.16740513819968328, 0.3030762792332098, 0.36495340580586344, 0.19618273072410375, 0.12931893579661846, 0.1571800501551479, 0.15436852758284658, 0.13341520505491644, 0.18437778839142993, 0.24109108111588284, 0.28245101566426456, 0.21323667577235028, 0.3793201973894611, 0.12476808624342084, 0.21268686308758333, 0.1925778522854671, 0.19925027940189466, 0.2413741807686165, 0.19148744439007714, 0.20829214656259865, 0.11618944539804943, 0.14030874765012413, 0.32101574004627764, 0.17764739954145625, 0.3019500256050378, 0.24897248164052144, 0.21746721438830718, 0.2608176483772695, 0.2439461083849892, 0.27518438058905303, 0.2622735343175009, 0.282797331456095, 0.16578053240664303, 0.2244800646440126, 0.23341430554864928, 0.13091222295770422, 0.2098249932168983, 0.19100301491562277, 0.20181166852125898, 0.24066256504738703, 0.14228956948500127, 0.3148956340737641, 0.14870840474031866, 0.15226044226437807, 0.22842495061922818, 0.2738946466706693, 0.2039554956718348, 0.26405845885165036, 0.19022557069547474, 0.192085659946315, 0.2559295966057107, 0.26773731457069516, 0.23624659341294318, 0.24372235086048022, 0.2008436556207016, 0.2569546806626022, 0.31833308399654925, 0.2029748514178209, 0.2745546237565577, 0.293987404438667, 0.29538192960899323, 0.18451720825396478, 0.33047657925635576, 0.21488341240910813, 0.28822100604884326, 0.33625390205997974, 0.17075051728170365, 0.2861844637664035, 0.24135216866852716, 0.31445773725863546, 0.1618013295228593, 0.24002983962418512, 0.25062843575142324, 0.21542679809499532, 0.18199868558440357, 0.21510227175895125, 0.3712342312792316, 0.2692323859082535, 0.27151567745022476, 0.3673983667977154, 0.19710410706466064, 0.34992381697520614, 0.2574097359320149, 0.23708535387413576, 0.4062184493523091, 0.4011032113339752, 0.21152231463929638, 0.255216748919338, 0.3884940332500264, 0.3292998002143577, 0.1412409741897136, 0.25908793963026255, 0.3155761834932491, 0.2142414843547158, 0.30050613277126104, 0.33512720314320177, 0.26307775522582233, 0.26444968942087144, 0.2157768839970231, 0.2576774137560278, 0.26591127505525947, 0.27945238281972706, 0.4085773212136701, 0.2841516915941611, 0.3968609467847273, 0.22559251432539895, 0.32225278147961944, 0.33638077962677926, 0.40686349442694336, 0.43399145593866706, 0.42357389931567013, 0.16497298667673022, 0.2691655035596341, 0.7175494590774179, 0.4020277492236346, 0.23588237701915205, 0.2680029737530276, 0.3700999030843377, 0.3722327167633921, 0.22411259764339775, 0.09986835633753799, 0.30528119998052716, 0.16904786723898724, 0.2804085658863187, 0.5634162516798824, 0.7142810407094657, 0.7864312722813338, 0.29977030819281936, 0.1449237929773517, 0.12381426320644096, 0.2122674902784638, 0.36569991731084883, 0.4140714998356998, 0.4325089120538905, 0.7934909372124821, 0.3308514232048765, 0.5318346619606018, 0.4075433313846588, 0.46286536438856274, 0.3962950740242377, 0.6196907570119947, 0.2471242073806934, 0.12393467666697688, 0.29489329957868904, 0.2880643238313496, 0.2884534763870761, 0.20815314230276272, 0.5919748661108315, 0.43007496453356, 0.09478451116592623, 0.5100597522687167, 0.500491390703246, 0.7307669310830534, 0.6546215107664466, 0.33066591597162187, 0.16856361587997526, 0.363826499087736, 0.5386037612333894, 0.5228897638153285, 0.42772814515046775, 0.29265961318742484, 0.5519574915524572, 0.26982827112078667, 0.26872398506384343, 0.20745473681017756, 0.2223917204537429, 0.3706577012781054, 0.40993423433974385, 0.8597774896770716, 0.8220483048353344, 0.27510636602528393, 0.18255393079016358, 0.3225407050922513, 0.3091878059785813, 0.2783377660671249, 0.4373860690975562, 0.188699210411869, 0.4419544036500156, 0.46875083295162767, 0.3070954838767648, 0.1445144836907275, 0.30046543339267373, 0.16256531118415296, 0.21977642172714695, 0.348875904455781, 0.3332174790557474, 0.297359871910885, 0.28142412076704204, 0.3178981557721272, 0.1618857859284617, 0.2201474955654703, 0.23099784302758053, 0.23383314401144162, 0.250273629790172, 0.18574224173789844, 0.24239347607363015, 0.18566275772172958, 0.25521015864796937, 0.5521588807459921, 0.23442620906280354, 0.40321361215319484, 0.27458686265163124, 0.26419433124829084, 0.2329795405967161, 0.3693321958417073, 0.36662522703409195, 0.24237749021267518, 0.30692511645611376, 0.1783059220178984, 0.23034944344544783, 0.3411040746141225, 0.14772360445931554, 0.26185897062532604, 0.24635412526549771, 0.27160360710695386, 0.21249356330372393, 0.2580763923469931, 0.4108753666514531, 0.23731764609692618, 0.17448164988309145, 0.2951887040399015, 0.3352767904289067, 0.2510389918461442, 0.3524040448246524, 0.23476004193071276, 0.14689061790704727, 0.42196756519842893, 0.2949408860877156, 0.31929588702041656, 0.3508221125230193], [0.020255876261217054, 0.09438746958039701, 0.026739354434539564, 0.08679132093675435, 0.025031295990629587, 0.024803347187116742, 0.014687385464640101, 0.06163788042613305, 0.03594046793296002, 0.006058675626263721, 0.017919871825142764, 0.06117282100603916, 0.07112907347618602, 0.12683875247603282, 0.06097900914028287, 0.08861382040777244, 0.04013287129055243, 0.047823087152210064, 0.03389173958566971, 0.0417707726592198, 0.08222599950386211, 0.03481845938949846, 0.02171988871850772, 0.05913225999393035, 0.016157855534402188, 0.028911381341458764, 0.0513966321159387, 0.02328727307030931, 0.031967959221219644, 0.04415049887029454, 0.03886588790919632, 0.030058346455916762, 0.05166891496628523, 0.03153240017127246, 0.11546073801582679, 0.05130914774781559, 0.0669613057107199, 0.042797637870535254, 0.02622743766551139, 0.02050464230705984, 0.13970294734463096, 0.034472002589609474, 0.084141809202265, 0.04165070058661513, 0.03773797558096703, 0.07978842288139276, 0.06765205223928206, 0.008151181409630226, 0.04931956485961564, 0.0408666178554995, 0.002877827437259839, 0.011371633845556062, 0.06081412990170065, 0.025457227529841475, 0.019978001328126993, 0.013330359161045635, 0.008833084320940543, 0.04130894158151932, 0.07451708894222975, 0.060019423326593824, 0.028951525964657776, 0.012584400556079345, 0.0512645483831875, 0.015109976411622483, 0.044737122079823166, 0.008544210759282578, 0.07696885542827658, 0.04032899123558309, 0.0426962196797831, 0.0696917634923011, 0.16558404138777405, 0.2871494635473937, 0.12487599451560527, 0.008126694247039268, 0.05537684803130105, 0.09348276929813437, 0.03605036145017948, 0.09813567157834768, 0.07695614243857563, 0.05874720780411735, 0.1486876988201402, 0.22914940549526364, 0.2952091576298699, 0.09985043347114697, 0.04976708733011037, 0.05393371589889284, 0.23208039900055155, 0.09198298532282934, 0.062473457073792815, 0.06944992725038901, 0.1736234748386778, 0.2547853236319497, 0.19860508589772508, 0.11019052471965551, 0.121330784750171, 0.292893597506918, 0.15562759595923126, 0.23902935034129769, 0.11885461644851603, 0.16400926338974386, 0.07131346748792566, 0.03255149509641342, 0.06041509193892125, 0.1335990647203289, 0.08245733435614966, 0.010953775945381494, 0.07261482343892567, 0.10949741816148162, 0.1266080781351775, 0.12337129010120407, 0.0535163617314538, 0.03395389074285049, 0.03287981009634677, 0.024017757896217518, 0.12299496927880682, 0.1079860344179906, 0.05509945549420081, 0.024522329258616082, 0.050717960330075584, 0.040459030351485126, 0.08195513786631636, 0.028374290923238732, 0.02730559641349828, 0.05728508040192537, 0.04793664316821378, 0.04700585639511701, 0.05708074117137585, 0.027253454973106273, 0.0020136398370596, 0.03331273081130348, 0.002593198032627697, 0.007364669072558172, 0.013958044473838527, 0.030060485696594696, 0.030016368727956433, 0.013580967588495696, 0.055326348592643626, 0.059945267930743285, 0.05296484952850733, 0.019540605462680105, 0.05709150602342561, 0.009972098250727868, 0.03708308591740206, 0.05495774981682189, 0.04981443635188043, 0.0058925096891471185, 0.03762124317290727, 0.048633850092301145, 0.0023008122570900014, 0.04970658745151013, 0.03557857817213517, 0.07286163949174806, 0.017686950632196385, 0.01721517477562884, 0.006569112274519284, 0.07340285810641944, 0.021806311815453228, 0.07833796204067767, 0.054336115790647455, 0.0373721858341014, 0.018464511740603484, 0.048279511684086174, 0.046398430786211975, 0.025466637962381355, 0.016787977874628268, 0.028716910819639452, 0.012957762992300559, 0.0370696864411002, 0.02515785443392815, 0.061763095582136884, 0.008759272168390453, 0.07123566814698279, 0.01850260618084576, 0.014070575398363871, 0.023537577217211947, 0.010964100147248246, 0.03474856763205025, 0.04489262428251095, 0.04310382944822777, 0.028634691989282146, 0.03054852943023434, 0.007681835159019101, 0.06813294166931883, 0.0855705770663917, 0.03008477433468215, 0.037561552235274576, 0.013168828863854287, 0.07677284680539742, 0.03113242710242048, 0.015439942690136377, 0.03826435495284386, 0.04373403156932909, 0.026391229657747317, 0.026839295751415193, 0.024984377414511982, 0.06176606046210509, 0.07048605446470901, 0.04893945166259073, 0.038529346202267334, 0.012924406237289077, 0.08964480453869328, 0.08630461306893267, 0.02551697412854992, 0.05044015961175319, 0.0902824429795146, 0.019230458237871062, 0.017371157518937252, 0.05699249610188417, 0.0867361125710886, 0.03107313321379479, 0.023640602157684043, 0.0818062036705669, 0.04402150989335496, 0.05181551139685325, 0.03425061622692738, 0.08144408755470067, 0.08833037936710753, 0.048853644548216835, 0.07700118338107131, 0.034262030458194204, 0.04620467087079305, 0.03708035852469038, 0.08137776181683876, 0.039102436348912306, 0.03116892221441958, 0.02227908029453829, 0.06059948223992251, 0.007361759389823419, 0.04559516724839341, 0.05646589408570435, 0.08861859983881004, 0.07727386328042485, 0.03946234457544051, 0.035753135016420856, 0.029672845266759396, 0.041357017908012494, 0.03677893153508194, 0.05136084204423241, 0.024233440854004584, 0.026229755021631718, 0.023077681289578322, 0.02785076325380942, 0.05294258509820793, 0.052602451396523975, 0.005801965817227028, 0.0717534868454095, 0.08191275381250307, 0.11501484827022068, 0.04303062400140334, 0.04771372798131779, 0.04982441081665456, 0.014026142089278437, 0.03244834399083629, 0.08118127079796977, 0.047215297890943475, 0.08052763907471672, 0.09278722107410431, 0.03912230364221614, 0.10103947279276326, 0.036352961033117026, 0.02975609382701805, 0.04759406037919689, 0.32791213248856366, 0.18657077540410683, 0.07420647045364603, 0.02679111552424729, 0.14238480187486857, 0.03782483283430338, 0.11118604903458618, 0.109124763548607, 0.12996648933039978, 0.1791864653932862, 0.22214897879166529, 0.136171393096447, 0.10826973521034233, 0.11677292190142907, 0.1365865653497167, 0.04010392010968644, 0.007273585288203321, 0.06149643821117934, 0.014839349478279473, 0.04864447393629234, 0.022721786226611584, 0.04997088479285594, 0.07504480789066292, 0.10777446295833215, 0.03432044861256145, 0.06734690337907523, 0.042301267239963636, 0.10399785896879621, 0.012831501408072654, 0.020492597250267863, 0.0615987840865273, 0.010052010857179994, 0.05596485163550824, 0.048411766110803, 0.04964719708368648, 0.04804947559023276, 0.05858010954398196, 0.0364221959898714, 0.01959416997124208, 0.0706277007702738, 0.0750083832826931, 0.028005463937006425, 0.036355083575472236, 0.007870770186855225, 0.03232089497032575, 0.03649305253929924, 0.06937701124115847, 0.01127051993535133, 0.056273451482411474, 0.058167423485429026, 0.03439355015871115, 0.04558314445603173, 0.052199287092662416, 0.07248229812830687, 0.04342788452049717, 0.046706600187462755, 0.013757972592429724, 0.04048816335853189, 0.02891915719374083, 0.07715068160905503, 0.05864306222065352, 0.008910534852475394, 0.042300499117118306, 0.014663426154584158, 0.005920387075093458, 0.05291682144161314, 0.06965283042518422, 0.06316177677945234, 0.010796941587614128, 0.06515566041343845, 0.01741427073284285, 0.05220258222834673, 0.04360228180303238, 0.05794575139589142, 0.009695788321550936, 0.023991970119823236, 0.03477322548860684, 0.015261616663337918, 0.052052968967473134, 0.02189343809732236, 0.03064681946852943, 0.05081445808173157, 0.03227477049222216, 0.18474973796401173, 0.008470736283925362, 0.027875417399627622, 0.03295972084742971, 0.057505501972627826, 0.04168681720329914, 0.06234001892153174, 0.12527843151474372, 0.19703553261933848, 0.12766378320520744, 0.1376366597833112, 0.08794884124654345, 0.13630054163513705, 0.1498571306001395, 0.1442800392396748, 0.08369569681235589, 0.1586906917509623, 0.1532002238673158, 0.15068597596837208, 0.16864292178070173, 0.19648655113996938, 0.10236537156742997, 0.2239607839146629, 0.19956425239797682, 0.18295941059477627, 0.18135123595129699, 0.15079299366334453, 0.26750051009003073, 0.08647685070172884, 0.09584217550582252, 0.15313731943024322, 0.13351017027162015, 0.1664940925547853, 0.07945234872750007, 0.1414567610481754, 0.18021036201389506, 0.07317645111470483, 0.1287567292456515, 0.12340632689301856, 0.1477476500440389, 0.09879619785351679, 0.151134826883208, 0.1560726173920557, 0.09594687770004384, 0.14692241151351482, 0.14404954301426187, 0.19265083508798853, 0.27506103564519435, 0.08353715180419385, 0.14752223010873422, 0.21838511747773737, 0.09286856788094155, 0.21384323306847364, 0.21534452360356227, 0.15769146411912516, 0.09273211660911329, 0.08943692897446454, 0.17866924783447757, 0.08518074915627949, 0.19543224130757153, 0.2022823237348348, 0.25092265277635306, 0.2158339403104037, 0.11965586876613088, 0.11884176987223327, 0.1436348308925517, 0.2509678644128144, 0.21459688403410837, 0.07954634173074737, 0.15511800767853856, 0.130476537742652, 0.22367461177054793, 0.08442831531283446, 0.1599793866625987, 0.14432106516323984, 0.14062185975490138, 0.19183739670552313, 0.27644386456813663, 0.38753458473365754, 0.36559328553266823, 0.35866406047716737, 0.09634547779569402, 0.20244362211087719, 0.10740734476712532, 0.33369657990988344, 0.23736221948638558, 0.17581812426215038, 0.20679392851889133, 0.35757610166911036, 0.23352069983957335, 0.16310865234117955, 0.1051956630544737, 0.1638829943840392, 0.6311789061874151, 0.40811540849972516, 0.1349269153433852, 0.19123082456644624, 0.21289243799401447, 0.30355422233697027, 0.19582480774261057, 0.22058016766095534, 0.20808878325624391, 0.57528170873411, 0.4410364560317248, 0.4809454473434016, 0.24196148675400764, 0.20887817605398595, 0.22128166048787534, 0.09358369396068156, 0.05957380075415131, 0.21136346535058692, 0.14495920826448128, 0.11816309808637016, 0.1528880320256576, 0.38050597126130015, 0.24956891604233533, 0.3827280207769945, 0.20443860412342474, 0.17705299862427637, 0.12402167121763341, 0.13700840208912268, 0.2156058486434631, 0.1982981781475246, 0.12852667830884457, 0.06205781355674844, 0.19164679833920673, 0.179189077753108, 0.16422217071522027, 0.18076324719004333, 0.15901425329502672, 0.22216351004317403, 0.2013435959815979, 0.21155934780836105, 0.19855933991493657, 0.10526523197768256, 0.16579383169300854, 0.13857106823707, 0.0867956253932789, 0.11153971950989217, 0.2757496596314013, 0.12194888986414298, 0.08602221103501506, 0.14331125450553373, 0.1388811820652336, 0.16759297577664256, 0.13863634754670784, 0.13956849987152964, 0.22398407250875607, 0.0937777358922176, 0.12298892077524215, 0.14130729250609875, 0.11787673298385926, 0.20292263390729204, 0.1645536583964713, 0.18333147891098633, 0.16010633844416589, 0.11762432855903171, 0.2035061697824858, 0.29375401383731514, 0.14068418531678617, 0.13739224086748436, 0.12849944148911163, 0.2494985010707751, 0.0802245236991439, 0.16586314828600734, 0.15432500804308802, 0.13333741313545033, 0.06539406793308444, 0.16017869784263894, 0.11962768199737184, 0.12574374326504767, 0.09634069836465642, 0.10741334132035263, 0.09066675673238933, 0.17776967579266056, 0.08259654641733505, 0.20001338532892987, 0.08451997797237709, 0.15357806609245017, 0.16037266555940732, 0.10126372013473883, 0.11053189780795947, 0.17345484404359013], [0.08792154505499639, 0.008707957294973312, 0.022475747573480476, 0.03482159867417067, 0.03930730621505063, 0.07110738049959764, 0.03466152855253313, 0.05854645685758442, 0.013525104277505307, 0.05267621345410589, 0.008177501676982502, 0.02251645808428293, 0.03558991076715756, 0.09402127165230922, 0.08071258969721384, 0.025879568929667585, 0.019033583157579415, 0.06361951120197773, 0.07596759431180544, 0.0642030248127412, 0.0075946110064251116, 0.004081430479345727, 0.0702500218176283, 0.056261391582665965, 0.06438148164306767, 0.015181819089775672, 0.05730020166083705, 0.03872397814120632, 0.02559612603363348, 0.033290540595771745, 0.04514939253567718, 0.07261579565238208, 0.032246097616734914, 0.03790719267271925, 0.033682758221402764, 0.03145950642647222, 0.010563645610091044, 0.034988722909474745, 0.033421433181501925, 0.015457531590072904, 0.07110684615327045, 0.04030975476780441, 0.03942122959415428, 0.021333322547434364, 0.02514244188205339, 0.05779584498668555, 0.0400409414578462, 0.019380303419893607, 0.1015933153394144, 0.04477266724279616, 0.03078813180763973, 0.023001657536951825, 0.03762843829463236, 0.06912966084200889, 0.031962304055923596, 0.03253449249314144, 0.06551829603267834, 0.08661504602059722, 0.04108890221687034, 0.030436912275035866, 0.08781397074926645, 0.01726812701235758, 0.014395358703040984, 0.1072904045577161, 0.040673603798495606, 0.06203725606610533, 0.024481911896145903, 0.02486510871676728, 0.1012536566122435, 0.03720851629623212, 0.0303204025112791, 0.09333522291854024, 0.03240227517380845, 0.03666729026008397, 0.02594703015347477, 0.04675015683460515, 0.1075505421613343, 0.024805827815725934, 0.06156342446047347, 0.16230615321546793, 0.08884966009645723, 0.2979210839839652, 0.1825497896061279, 0.09477486324612983, 0.1305199385387823, 0.04964178311638534, 0.07693202263908461, 0.02743226803431753, 0.06735424321959727, 0.16860332078067586, 0.19465743913315237, 0.2603938226820901, 0.181147308612708, 0.13194220518926159, 0.1763630981440656, 0.17331016977550462, 0.08499850737280212, 0.16274949739454314, 0.07623842626344413, 0.03280040400568396, 0.011523910488904221, 0.03826843676506542, 0.059203142518526874, 0.13981318596052006, 0.09374554152600467, 0.01899425118608633, 0.045174885308369994, 0.06399366495315917, 0.023593130681547336, 0.020846729712502565, 0.04634307770174928, 0.07267529363161884, 0.031683019042247906, 0.054952580758254044, 0.07550067952251993, 0.0967229860543739, 0.02085219748551026, 0.01774297907104483, 0.06911649514222518, 0.04474066212424077, 0.05058042181190103, 0.06740198557963595, 0.04147565763560124, 0.015352791360783158, 0.028943603538209572, 0.08344130343175493, 0.13477110886014998, 0.12870730221038684, 0.05417543710791506, 0.07115758678992279, 0.03824644321866799, 0.05469334857480135, 0.05767867842223495, 0.03643653428298421, 0.02539564411563333, 0.0469106017408194, 0.06920181986060925, 0.08388951609958895, 0.02225643922429299, 0.03392453880223911, 0.04263441362127196, 0.017882981519505847, 0.003417105103835638, 0.039231262053363025, 0.05557874188525602, 0.019526682772266213, 0.023130229055823293, 0.03753802244318649, 0.030696220528625418, 0.04245031646860298, 0.0671497147413902, 0.042971081493305974, 0.014009331516717793, 0.07263688748935238, 0.04770055857079569, 0.026403896263218485, 0.007920395746623399, 0.07235326833324507, 0.03443650195549708, 0.04729845553811174, 0.04265116760507226, 0.04394723946461454, 0.031345872484962456, 0.0351764565857593, 0.03720892818819266, 0.04510327176831197, 0.015598766003677156, 0.03652879808214493, 0.01496959639553097, 0.07072435808368027, 0.05498374353919644, 0.029547439007728826, 0.0387127828435041, 0.04927443485939875, 0.013053579823463224, 0.020236905111232772, 0.06009099604852963, 0.018396412269794382, 0.057416626077611, 0.05134199891472235, 0.027982936044281814, 0.0350679657276487, 0.05244185435003601, 0.0475688273581909, 0.05712407517421525, 0.04995166316803079, 0.07944247816340066, 0.01363349030725658, 0.03716619161423296, 0.07853002985939384, 0.023971188129507937, 0.03443896217504516, 0.018078103275911417, 0.010410021041025175, 0.04761659569339827, 0.06069988739909604, 0.01858255775005091, 0.04150974076765124, 0.06824496143963188, 0.03850557521218434, 0.032883691528695635, 0.013865403107047314, 0.048873430205276236, 0.06450658547692001, 0.02026740367000457, 0.02677068048797082, 0.04678895631514024, 0.09069889172678813, 0.04316817365179304, 0.028163010756543372, 0.04131352063268423, 0.013572110055974917, 0.05381212984502781, 0.03520838377880864, 0.06040006715920754, 0.07125888994778506, 0.016630872632958926, 0.01169973547803238, 0.027244185548624955, 0.010387034872110235, 0.027562973227759358, 0.05432227844721638, 0.03744818917766679, 0.0362870360550005, 0.05578982352744788, 0.014981212862039683, 0.031342610745923594, 0.046986263696453534, 0.015673945563321467, 0.029821397256455384, 0.05924226112256292, 0.04005632617918309, 0.03957989334594458, 0.021524876428884454, 0.03522747923852876, 0.03801224738708697, 0.12135224766097963, 0.06856399588286877, 0.05337339811376296, 0.10951569725875743, 0.04132704627409112, 0.05980808935419191, 0.007238817524921615, 0.028988718695472926, 0.10243759737932123, 0.03820799625827931, 0.04829693731153384, 0.04603075598424766, 0.0179853960435139, 0.040343893560930155, 0.014358142780110938, 0.04388210487377364, 0.06669155729468912, 0.018527540487411898, 0.06794295928557403, 0.10755839408375323, 0.30083986173849553, 0.08843130402965471, 0.1324966488755308, 0.015337972527049715, 0.06532784609589726, 0.033287156402366236, 0.17727982864016667, 0.11513140998431481, 0.04053173484862782, 0.04791701336216647, 0.05735594437282998, 0.13750509184319526, 0.0687980766815599, 0.0358734779729275, 0.13024721411056817, 0.26180494227446616, 0.251488228677772, 0.21816052874783054, 0.14160532417008653, 0.09492154131294228, 0.055290899908868596, 0.06130773603217676, 0.0847341914777644, 0.0706589080800768, 0.07032607711153105, 0.05276055853755679, 0.05180782645766158, 0.07693680949159898, 0.060914980349480174, 0.02514772040740354, 0.00926890683331294, 0.0208782375921146, 0.05820404847327154, 0.042015933722723275, 0.0662471963732969, 0.012567361773108132, 0.08755718765314668, 0.01524131892438163, 0.04513798572588712, 0.0317781660851324, 0.04761374213558156, 0.05138102475029882, 0.025793388886086177, 0.03688343334943056, 0.010912144243775401, 0.08613921803771518, 0.055892766831675544, 0.07694905492826365, 0.09675085369963199, 0.007174406991907745, 0.039827692744438536, 0.016332145205524284, 0.029101521431584843, 0.10854720196221024, 0.02752740208961768, 0.016575354420638178, 0.035870976935257204, 0.10940588908852078, 0.04309731339162681, 0.07653314794879407, 0.028914587419421878, 0.0062777914808975765, 0.04460190648387652, 0.016878009664651472, 0.04024485024274327, 0.06979398691328242, 0.01972072470380226, 0.04110165602469351, 0.010639843767421553, 0.00661141840282653, 0.04462644559680484, 0.029305623174877837, 0.02545360584917944, 0.03715504826686811, 0.019016691876458935, 0.011318102733639535, 0.020135976737947203, 0.030718035959580448, 0.0415104124112986, 0.013391242173383944, 0.01268851459826692, 0.06394581127096899, 0.027878488035639748, 0.010143450872419635, 0.02886902140744496, 0.025682760642666835, 0.024761313798080664, 0.041824700820143335, 0.02006172300752951, 0.03439467451244127, 0.07455373619450256, 0.044626234084717, 0.014442515694099711, 0.04044147855893243, 0.03178203267452773, 0.017512853919470217, 0.22473626886494458, 0.15228227624902502, 0.15334954397985712, 0.11039861550671048, 0.13225375878391787, 0.24405808362644166, 0.12541506090201437, 0.19667072250740603, 0.1546451260219328, 0.12775833281921223, 0.15099552576430142, 0.09519139362964779, 0.11644791316939518, 0.15972900087945163, 0.2443669061176479, 0.15877250611083582, 0.1812287964276038, 0.14844304241705686, 0.20315612840931863, 0.13736365333897993, 0.11328750697430223, 0.138171540456824, 0.17764009680831805, 0.1198633955209516, 0.13964543089969084, 0.18574739224277437, 0.1011631368601229, 0.09430503923795186, 0.10131898045074195, 0.10699931939598173, 0.13927005260484293, 0.15591624687658623, 0.11173774677445181, 0.11430682454374619, 0.0752193239168264, 0.1412367439479567, 0.09331404202384874, 0.14169703877996653, 0.13111911888699979, 0.09083871977054514, 0.184483960038051, 0.16630429570795968, 0.15529342170339078, 0.12228591396706179, 0.12559933617012575, 0.194422920467332, 0.11154890729812905, 0.17180227412609383, 0.20627515244996175, 0.15548679570201784, 0.22287509607849643, 0.14941648783860728, 0.13270114024635404, 0.0998705456731841, 0.23923578613903373, 0.0703239397262223, 0.15284408204024658, 0.15713924687588587, 0.14046574156964198, 0.16272395267151296, 0.2648158650845289, 0.15934032329823822, 0.17132096167188138, 0.23220420407596976, 0.19668322027428076, 0.15191255311947316, 0.10858143723453395, 0.22159670217661187, 0.19501076079905033, 0.16853070905199274, 0.2849163708742708, 0.1175790278648492, 0.222310870885849, 0.1354945544153452, 0.10931116878055036, 0.15062195830978453, 0.1697357787634246, 0.24424658913630992, 0.19491603306960315, 0.1964868776849471, 0.3600051807006821, 0.39157192746642977, 0.296406687120907, 0.14098606130573899, 0.14942723413696513, 0.15598206053255126, 0.29703294101636857, 0.33178730111103505, 0.08013233411475085, 0.20424914866453037, 0.22577359835850075, 0.48867408419027925, 0.23380184022244066, 0.15798594831721857, 0.2899341203738004, 0.42926804220769554, 0.3898419812321663, 0.552084962837398, 0.24410436395555735, 0.1708232774399221, 0.12223673926200718, 0.20314091438194737, 0.16703881410649046, 0.35832148510962725, 0.19535743282176554, 0.11128143727546558, 0.17713662382448092, 0.14487000211374834, 0.11144924428663217, 0.1233774796128273, 0.12126925328630023, 0.19240248278947547, 0.23585254268255085, 0.15973048517480493, 0.30982139229308814, 0.2577483333880082, 0.1642005890607834, 0.1021326043701265, 0.15134206420043483, 0.15425242600031197, 0.0972699785779696, 0.19252523401519284, 0.09479392901994288, 0.14718910970259458, 0.118714216951048, 0.35883202333934605, 0.29640057182405144, 0.17161462950753048, 0.22812947194324806, 0.18417405401123688, 0.1031604343734216, 0.113813014322659, 0.09443502640351653, 0.21807124838232994, 0.16250644403044134, 0.1078295154729858, 0.13456842832965776, 0.2209295707871206, 0.13937095500295982, 0.1767130207736045, 0.13771304162219167, 0.07048722705803812, 0.0877128382853698, 0.1366010372294113, 0.17361332225846127, 0.207800829957705, 0.14308463229099289, 0.07601449804496951, 0.06996051743044518, 0.07430918369209394, 0.15879171289270744, 0.10341901346691884, 0.20319178118370473, 0.18257150484714657, 0.12379138279356994, 0.08239729460910894, 0.08748505832045339, 0.15786383533850312, 0.08674072130816057, 0.10394292519777082, 0.14278740214649588, 0.09541737759718671, 0.16958478139713407, 0.173823899240233, 0.15429325896548107, 0.1737634142045863, 0.1329013568465598, 0.13400760217336938, 0.15219437627820298, 0.1969209747039713, 0.19166935962857679, 0.12112578129745089, 0.13039723184192553, 0.18799451150698587, 0.116729513683822, 0.14548784005455673], [0.027190227701794356, 0.03993819853349123, 0.01176379209937295, 0.012172653314337367, 0.0452050499006873, 0.02669088662514696, 0.07619340758537874, 0.08634952042484656, 0.07065026205964386, 0.02800237289193319, 0.06164197708130814, 0.04293446763767861, 0.06286047966568731, 0.03357995221449528, 0.03713304358825553, 0.046079759995336644, 0.014091094853938557, 0.049828062183223665, 0.054192165116546676, 0.01869510258984519, 0.009060443117050454, 0.008409089787164703, 0.02125031332980143, 0.004252983017067891, 0.032905117332120426, 0.02379933270276524, 0.03667809964099433, 0.02350141050555976, 0.03458471626800019, 0.12123376378440298, 0.03904571771272458, 0.06801689203712158, 0.024010102642932907, 0.02021937929384876, 0.047266776964534074, 0.052949052915209904, 0.04064850065333303, 0.044981188475503586, 0.024062513111857697, 0.02608223832794465, 0.06341381013044156, 0.07235778801259585, 0.0440646806237055, 0.04171295564447064, 0.013512688146875007, 0.03743310131540056, 0.03715465863933787, 0.018891181716753636, 0.018361360635026358, 0.05045503225119319, 0.06491890788311139, 0.07348698796704412, 0.09969734324840829, 0.019203794727218337, 0.022579223368666135, 0.03723176778294146, 0.03545154846506193, 0.057665301210363396, 0.03386680342373438, 0.03605138190323487, 0.03791363451455254, 0.013441115424939198, 0.047117534777498804, 0.0158335314336, 0.005374927550292341, 0.06763367666280828, 0.012324835333856754, 0.0055843518839537865, 0.05626531383313704, 0.0598101933428552, 0.05282230893499218, 0.11445443029515445, 0.09652570835896768, 0.08565328942495398, 0.03557192481821403, 0.0487173639703542, 0.029666588961845264, 0.052072454054723494, 0.05175210229936056, 0.057706924562808126, 0.14060998539207503, 0.09995031170547009, 0.15865116496570408, 0.034135601890739053, 0.05895318718103226, 0.005837332400915329, 0.10909549324424006, 0.019677576237882022, 0.011392630131012993, 0.051092013891320676, 0.1129577039682772, 0.03759416220418643, 0.0925755531352479, 0.0593237786233658, 0.076395546348067, 0.10079552885144949, 0.12814010842703283, 0.07092837447999045, 0.09728775301482528, 0.09253768876078539, 0.024751055461820215, 0.04432019093655981, 0.035099302913295105, 0.018218573277408723, 0.036144799742032774, 0.010938689010799862, 0.1131783815799281, 0.006608284684261889, 0.0138559778315539, 0.04230712278513238, 0.02268338193971431, 0.0839630926202517, 0.03014236870512832, 0.07567077234853059, 0.04711173860414419, 0.03390749167010654, 0.010358520630688872, 0.021375925534812268, 0.026727971744548995, 0.013537170671042986, 0.06535819251439534, 0.07886770705226809, 0.03190064642694779, 0.017970608751056716, 0.03133642494503874, 0.029880982438044157, 0.015990968786354642, 0.03597513736167457, 0.031041708825796377, 0.026703953990363516, 0.04663536514271982, 0.04817912878934294, 0.03367732198967133, 0.00388831321743055, 0.06896024337038398, 0.059857408778043464, 0.05970080819679424, 0.03752016265934799, 0.03900089199305512, 0.01153480614448199, 0.049680345109663904, 0.02905825607740553, 0.06386948138242587, 0.007214394372567767, 0.05542338440136518, 0.05474971098010428, 0.043812049843836576, 0.008123165334836813, 0.02818549968651496, 0.07503973902203143, 0.03697603853652254, 0.05346599216863979, 0.030273070187831763, 0.002161899142265611, 0.06824631956988014, 0.059180915195611306, 0.05235679309407715, 0.042899211912299506, 0.09182149398839101, 0.024960669506981503, 0.04133038593863603, 0.082537597627379, 0.02135316015483113, 0.05422997382993344, 0.018190393930126447, 0.07659547351067886, 0.05571426547248848, 0.0074528394634398865, 0.016686260969436262, 0.061188699255581014, 0.014843345943518216, 0.09364920333609916, 0.02144884525478119, 0.026324085702071898, 0.06508818434667774, 0.04233163592289202, 0.03646921104518697, 0.05000287877919618, 0.014487770004052436, 0.011882585822604597, 0.0390370160312159, 0.04544379138678778, 0.020388642769830767, 0.056680842317291535, 0.06073273114452604, 0.055789441321394406, 0.06984606341575272, 0.030065474784350954, 0.025445234423386864, 0.010734261650213739, 0.011298063818685478, 0.019385238701943308, 0.01948337103385711, 0.03816643598838709, 0.041537255892762914, 0.055574567304574884, 0.01059101694409037, 0.03604158184316475, 0.02289016654685838, 0.04489589715376496, 0.02730610478465678, 0.06744456259184517, 0.010773422000056598, 0.015704831894254312, 0.008379204427910736, 0.05877541312656831, 0.018695494072744623, 0.07832864066585898, 0.06202219788974617, 0.0065943350909947185, 0.07298027921933681, 0.01174721530333045, 0.05962218878266867, 0.0543448694224935, 0.07760333974147215, 0.09368044775328599, 0.06169696651340928, 0.010891121983149787, 0.025098785044974647, 0.10785845181089826, 0.02366443437495036, 0.019573154204408638, 0.06323116016574204, 0.08517301597748883, 0.05097792352898978, 0.07846351858461276, 0.031572702500852756, 0.02478960817825282, 0.03507442983391229, 0.007236555829877034, 0.044480454016593285, 0.021995865608914755, 0.03963366565585602, 0.029151338094379753, 0.009843207608355442, 0.029735263597103767, 0.03903474877006374, 0.02819494722643867, 0.016209857822104823, 0.024139167690009344, 0.03079467569477856, 0.02372352417296497, 0.051421193493297324, 0.031481032419833355, 0.026948640079353936, 0.005954285597908893, 0.11824002911453135, 0.03882213088218123, 0.005092857163617737, 0.03500863102090079, 0.043345673111616634, 0.017217445747519378, 0.057720257245819084, 0.056629177706781775, 0.0779141957173124, 0.05727112431486603, 0.03131271332676988, 0.05905520280066412, 0.007381632713077124, 0.057388739878661, 0.040977390817715786, 0.03027469734661281, 0.08921007669414394, 0.04082665320311207, 0.028038168529747054, 0.015075179890118307, 0.03983062422776129, 0.06267549935728312, 0.016746738583606202, 0.045739448178210296, 0.011844463551824447, 0.14187384804245085, 0.1764418400125578, 0.09597356533049606, 0.0953573155857157, 0.09391495899762958, 0.05522321233002003, 0.08117979392409325, 0.0594099159934558, 0.06608433948713355, 0.025725781088112853, 0.03588556013710331, 0.03924561518942937, 0.0422796967177419, 0.0730154050688725, 0.03524371000821702, 0.014321515009214636, 0.05342207557987422, 0.029477836687874515, 0.07693324718275107, 0.06126148909970652, 0.07369778759311885, 0.014813428115303395, 0.05741761684475932, 0.023785727280483115, 0.020554316106426995, 0.014437519184866687, 0.03867640647513326, 0.032154190048458986, 0.04632777832739521, 0.029384424415184185, 0.054550963832298294, 0.03299931442597881, 0.022308545412670355, 0.013260749419714557, 0.03162836728733964, 0.008596046991442563, 0.04665087231842335, 0.08209572290070355, 0.017733826534822583, 0.021566260438703466, 0.06871440695249476, 0.02813334525853861, 0.011752868613257306, 0.015367270661954535, 0.042178612493444234, 0.03270127905125264, 0.015577739104628563, 0.07720810899627395, 0.014479470937658334, 0.023362888641713653, 0.024935254659794737, 0.04200411502097268, 0.02637468347529648, 0.03030102132470347, 0.04077691075508483, 0.0321928077028133, 0.010812708515004488, 0.04852162623137701, 0.04052036143548321, 0.021037606384197716, 0.020229737820045557, 0.058847086038440466, 0.06734089940437116, 0.0326111674803542, 0.029045272203802597, 0.05089983475045301, 0.04695007286500186, 0.018559727432148065, 0.03344793527503498, 0.02123778216628125, 0.02510046229872387, 0.0092941240836808, 0.035340753238415346, 0.05654970111208968, 0.0036203914123689174, 0.11738414730643854, 0.019353287389094476, 0.0547049780288944, 0.03707960895553697, 0.07709385536145419, 0.13281128980452195, 0.1690514592337422, 0.1368965901201591, 0.0788895261939615, 0.17349984787870198, 0.15345010499004275, 0.09097379064769484, 0.18254998256452382, 0.138992237043567, 0.13983879005536437, 0.1081707920820918, 0.20452225900953636, 0.14596468477975577, 0.18351956881815568, 0.12841823569033295, 0.21045308763859794, 0.11519602878252044, 0.12952452554600313, 0.14530729036778212, 0.23268003948032856, 0.1500913078780286, 0.08573059894843027, 0.13919298799009994, 0.10905013317824341, 0.08712779585039243, 0.12608532415470108, 0.1798401342239231, 0.15278386417776346, 0.08623571207863279, 0.09893733949866146, 0.24082527350401506, 0.0812992945429869, 0.22837927885120735, 0.13815095328027382, 0.10784951635287143, 0.1902485772734508, 0.15117916278541088, 0.2342488506110385, 0.14175017655361444, 0.1781530395965092, 0.1957704676897265, 0.15487400436541066, 0.13518843334168196, 0.15729045204352587, 0.14707728289067745, 0.11907021777005866, 0.18030810286290944, 0.16191532340599224, 0.19211187260225415, 0.11240193183766678, 0.19103224069112912, 0.23340096173342317, 0.13978629052871838, 0.13171956088626757, 0.1411319972248748, 0.1201820737333037, 0.16421345790149644, 0.0748818767897319, 0.15966378094162792, 0.17427374463295564, 0.2192375631420873, 0.1555893011391163, 0.06658161553787068, 0.15016987163107842, 0.17542420711833984, 0.10627701674820855, 0.26230541698168963, 0.0804166731541045, 0.1941152408835478, 0.08926138136303052, 0.169515123416204, 0.2536392101319507, 0.27391768293455243, 0.26914537651464343, 0.20146260678302497, 0.17143290722742677, 0.13136131135979667, 0.13380190852330998, 0.14033074490725994, 0.23446153529221192, 0.23773639550199732, 0.29065700189676136, 0.13880631420761347, 0.1826662474195473, 0.12830217863665894, 0.27278786699753255, 0.1458565835491754, 0.1761485729366541, 0.1407919154735282, 0.15127920429222286, 0.17618498270167038, 0.17024199769366533, 0.13932676753029227, 0.2369920807541348, 0.13889180961996317, 0.26480307045858353, 0.2576354081975296, 0.29708670219406486, 0.20549564505927265, 0.25296073872596025, 0.09109619306400418, 0.08393421565415338, 0.1604940660763532, 0.09094734050449915, 0.09397709160111845, 0.1329132608952932, 0.09131754603004083, 0.21289485739544034, 0.11436005137511529, 0.18893209635280073, 0.14892333070747554, 0.11588255249080248, 0.10991613045916893, 0.10075782774947584, 0.1983125164406374, 0.18413190002320334, 0.31461151025723666, 0.18025113560725003, 0.10655273203155957, 0.12377447666949593, 0.15174228959949687, 0.11191072655492462, 0.19808087730780244, 0.12633038131752983, 0.14180453144945204, 0.18427832575980574, 0.1448533483198844, 0.08705719534191303, 0.07825828506611288, 0.11139971335069276, 0.19420959753915668, 0.11703145646606572, 0.12271510538994335, 0.1858316853758879, 0.07001246776781045, 0.18262369267176837, 0.21437562012579292, 0.10033859594841488, 0.12376008642604575, 0.09908176143653691, 0.13678434770554304, 0.12474690534872934, 0.1052413867728319, 0.16491462418343872, 0.0888356335053686, 0.09594902250682935, 0.10458524659043178, 0.144729454186745, 0.11048345040762797, 0.06871942387078889, 0.2235022108652629, 0.1840989338234067, 0.14490759931504726, 0.09120492512010969, 0.16022300405893475, 0.18647717573912814, 0.17924669809872285, 0.10488413914572448, 0.09289649489801377, 0.1560130823054351, 0.15075766743393615, 0.18207205430371687, 0.09179152606520802, 0.10501955141080543, 0.10261281844577752, 0.1202724821632728, 0.20855219510849565, 0.10986456603859551, 0.09110518789384514, 0.16242713812971488, 0.1678036863449961, 0.2540531801059842, 0.12555264023831114, 0.14942413195967674, 0.1115296856733039, 0.1727712815045379, 0.25074435921851546], [0.09219143976224586, 0.01981624653126346, 0.012614873139682459, 0.04576986510073766, 0.05489431474416051, 0.04225339871481992, 0.0410773803741904, 0.013243364610389108, 0.027713452946045436, 0.05756211670814082, 0.020873925714113284, 0.003875962488564255, 0.02013479115703376, 0.02431052031170111, 0.03175275123794563, 0.04551454032480251, 0.05007988402212504, 0.05072675849078223, 0.054027567894081585, 0.06373282230924815, 0.0690586818382144, 0.04495287183090113, 0.07400378250167705, 0.00789064582932042, 0.019550373981473967, 0.04086560111318249, 0.020140101223660167, 0.0137240054209542, 0.058083798285224475, 0.05299512173223775, 0.029408395785139874, 0.04671465248975437, 0.0757695225183852, 0.013033871164225275, 0.020670141238952056, 0.043724706483772025, 0.07381481686024927, 0.04149832282564603, 0.05111026330268942, 0.04394620416860562, 0.023831150429032277, 0.03189739953086246, 0.018205398300779052, 0.014303005846159067, 0.014351530244312016, 0.018784030435199384, 0.017907884284795728, 0.03084434021729976, 0.02791615203022957, 0.07377336791250855, 0.09731401762110181, 0.0063632238106947625, 0.024453049773001112, 0.01665720032178797, 0.05530519367312081, 0.052358088141772896, 0.028797279846912716, 0.029058298750896938, 0.055419428754248656, 0.03883348203089554, 0.049365496379323304, 0.017778168003133032, 0.0334495457354933, 0.0541646945202956, 0.019911686722480226, 0.01944296480360208, 0.08943986787926406, 0.026040915545308962, 0.02796479795506457, 0.0825576727220323, 0.03471665899269283, 0.08732347792829387, 0.07698556859395467, 0.02549861339502968, 0.05076066721812822, 0.027397079102229327, 0.007848802615626482, 0.02485787648765836, 0.024442717221972998, 0.03287388775788713, 0.040855274128261954, 0.03972986654844135, 0.07544211664935574, 0.07622257398907095, 0.04909759220026899, 0.051847932118107565, 0.08717426913790405, 0.029996093253430445, 0.028069234831491485, 0.060370158607838675, 0.06459176918724552, 0.04751071348437108, 0.0134954267196008, 0.05827389941259753, 0.018264167119923513, 0.06618950181291439, 0.09674530985648744, 0.03156629405566491, 0.02493003736162791, 0.04517281842709053, 0.05287468600727152, 0.007342162516579265, 0.06345039801090024, 0.12424067157553509, 0.038939375372137874, 0.044036675681127235, 0.06776286973035894, 0.07554610638180748, 0.049045957275666296, 0.03885799887939356, 0.03733297075086739, 0.018475951947038993, 0.06331853321171366, 0.019559530228434596, 0.07500755207729526, 0.0040692991478863405, 0.03972805570811033, 0.049065394123317674, 0.026866244988923427, 0.03973747356212698, 0.041006457031471655, 0.014355585153680295, 0.0170914661794086, 0.034430943269398995, 0.07240662875119597, 0.08258148081949912, 0.08240611874498427, 0.012536904032458551, 0.048285812517860904, 0.011239991690672468, 0.01094188766728621, 0.03719670872669667, 0.05479466657561716, 0.03566685292753391, 0.027963981592620257, 0.03025049220013898, 0.01678072709182743, 0.06525883378344588, 0.026824204178410582, 0.07799055529176258, 0.09011639485834166, 0.05912848988373298, 0.07752827150397934, 0.09716733955428936, 0.023504924574808683, 0.037508225213969126, 0.0333933094952954, 0.04715340277471114, 0.0630308322433848, 0.0829493634228129, 0.04826827185752336, 0.016857795417308807, 0.016530259672435932, 0.045751864308840595, 0.03853716843877919, 0.029956982070871163, 0.09088751598028466, 0.03643637101049535, 0.07032273002550937, 0.015602723506162874, 0.027934830031881575, 0.05540329817449674, 0.014839222385489848, 0.036975058901589364, 0.025359349383506924, 0.027476182767713908, 0.06419561817892827, 0.02345124688872602, 0.013200353441789048, 0.06339781684800982, 0.06550069228978828, 0.027058507621404715, 0.06010011704347562, 0.07362428528722376, 0.05739038373576477, 0.06619321997277439, 0.07086310259182937, 0.0761156453518197, 0.015765235293656588, 0.005405400133895455, 0.01818083877878962, 0.010537910711718723, 0.023191031359601766, 0.023926811409182847, 0.036245616793166846, 0.06714984090649523, 0.01127063311287202, 0.030092557608440984, 0.02673622999282088, 0.02171730975533137, 0.05611109554592986, 0.04386182197777089, 0.030379035888472572, 0.08516554997186176, 0.01936284996190807, 0.07073865926940925, 0.08876235384377651, 0.04921389787341468, 0.030396038491744548, 0.06777034315746278, 0.06001261041092221, 0.03163911729643587, 0.02237172629975248, 0.02621125884616049, 0.08259002293925732, 0.14284258824773133, 0.013789648382953601, 0.008935108289733762, 0.0660516404605005, 0.08339935724507086, 0.011628021748038009, 0.03579148920834996, 0.07665745768463239, 0.03942150047805626, 0.04875108345004264, 0.001225705939305044, 0.016480379927088507, 0.04712527537776623, 0.05947149940766394, 0.024527769201085903, 0.04614421552105341, 0.030651884626422543, 0.032972663902910426, 0.013594907904916909, 0.01791275277355453, 0.010212298984697554, 0.030055231291044038, 0.028564410604303703, 0.04981583530025091, 0.04880671855062246, 0.07967834753799252, 0.10033496684627607, 0.03562351150321774, 0.012872746265202295, 0.027160252357134596, 0.031402758104377426, 0.054998382402118295, 0.015106551400094759, 0.025913195640896447, 0.025556679029250517, 0.023622770204383414, 0.015456180881301407, 0.020318340975791216, 0.15653445589123294, 0.04524335585301742, 0.04148861924477387, 0.031342106085503474, 0.043725259383791126, 0.040424498220090754, 0.022616167480009608, 0.04888989475148264, 0.07503699307562783, 0.021636131787090562, 0.043270359965390526, 0.05187434515391942, 0.021813174826093018, 0.11905313353054225, 0.028031674737576395, 0.03773528900637757, 0.05246130232990254, 0.052069793455302715, 0.02284340196638368, 0.11363538869773038, 0.03415334293094929, 0.05449986696476117, 0.036877310631098226, 0.01301625536143547, 0.08860210931743495, 0.02377800894464599, 0.01959981400432298, 0.04738737225125078, 0.0519544674170902, 0.2201816937304102, 0.10370780539233238, 0.06587379961274564, 0.0460938904871, 0.05982236827549059, 0.05118972505442798, 0.0446571742213564, 0.06823111296398565, 0.07743897629552521, 0.10399818551377393, 0.06559350527822971, 0.05267161955998745, 0.026116842818737496, 0.024548827641410753, 0.07649612220120616, 0.01127462772274157, 0.07116424385458231, 0.017022550346155185, 0.0104824973277573, 0.04428135805937927, 0.037287016966729425, 0.02448292863846291, 0.020777277677552775, 0.04124161394429393, 0.11214158643269911, 0.058983303533750586, 0.01929637208377244, 0.004453523843039875, 0.08882910260581411, 0.03878386574797332, 0.1147711047087796, 0.04073377342137974, 0.03752185104531236, 0.05832446193380747, 0.013237556377134752, 0.05425986753834877, 0.014494273073069053, 0.05246946224360727, 0.018704158646869473, 0.024545695778215304, 0.033309120262856595, 0.08282638213131577, 0.04238316694681998, 0.05595839495072141, 0.042839190718950704, 0.019778866408159956, 0.054514505827683024, 0.029486017010640353, 0.01908201757032657, 0.03336819150717929, 0.04205496697977651, 0.0741258286871016, 0.05058660761278588, 0.023045308807922993, 0.01783075844286941, 0.011632695423031691, 0.0750445036101155, 0.08767691091634333, 0.03132865094812587, 0.03365996315551456, 0.05039377909270115, 0.03579752657969948, 0.0263831550910254, 0.031527416649623774, 0.044569816018338315, 0.03521885919326451, 0.023163646110333502, 0.0909415962814819, 0.03922393334505614, 0.013577072240877897, 0.041072534149861895, 0.036570310112438165, 0.04739776602946222, 0.10961433610646054, 0.012338724627625197, 0.022491764975711703, 0.04088520123332273, 0.010915030270552961, 0.0477262517233612, 0.03119727596640587, 0.3149878088152036, 0.11190682285814546, 0.22689107980113477, 0.18174936849391088, 0.18711291428189725, 0.06013544698362239, 0.1829403077135794, 0.15470923273824155, 0.08906715389457531, 0.1618836188572459, 0.08207859413232654, 0.16716039273887873, 0.1057334677898325, 0.11586543856537901, 0.10984243519487791, 0.2024692262057215, 0.11570563190616667, 0.1467499215505086, 0.14736097626155242, 0.24277876946143806, 0.14424305059947073, 0.13892624527215958, 0.14609815261792392, 0.13762799149844795, 0.14657863386673853, 0.08741219426156022, 0.14917092601535842, 0.09681103445473127, 0.17856153252068907, 0.19958115852205083, 0.17862357606645674, 0.10982129140757024, 0.22450572811067104, 0.13928358937846497, 0.11351705325068906, 0.11661885204375722, 0.1472714138799347, 0.1358931916183792, 0.16095577098894864, 0.12245204372447915, 0.1287959740147926, 0.19972222595242783, 0.08871500482200645, 0.12666998809436336, 0.16820021584862843, 0.11017374476068653, 0.16005481855245307, 0.09829532238654792, 0.1332353678299114, 0.09999621353927068, 0.23451862129149958, 0.15298379876185209, 0.10762870515463874, 0.10307649004971609, 0.19096203352091834, 0.18893853819463402, 0.08632874771137722, 0.10101793566718698, 0.10353895937441848, 0.16432362230261788, 0.16993701952742413, 0.07928695369628258, 0.18233857437735423, 0.10419350393931381, 0.12092366479919292, 0.10202926030615345, 0.11656419286737218, 0.26789904339239, 0.12771678739227355, 0.23136088682804257, 0.3131888131611049, 0.2410992595832795, 0.26055460155475885, 0.17476792592788115, 0.12323604853008874, 0.15670633729314432, 0.17510328762000427, 0.1719553049770184, 0.15277831291314214, 0.10003121322370134, 0.2354688078048639, 0.1287501835031435, 0.21744814119301736, 0.1567455820622854, 0.14463735366007313, 0.1405677868751809, 0.38826375966891646, 0.18287787825101987, 0.08711607733857818, 0.20747023285366595, 0.10818939030286856, 0.2817360305925831, 0.0869416948989965, 0.14682409178931266, 0.18031807732768357, 0.21094680880196393, 0.25968789181206375, 0.2389374130871147, 0.18136410479201004, 0.1905047072796151, 0.1792109859525226, 0.09061128119355999, 0.1374729271628894, 0.23686921078478917, 0.15789513912750408, 0.15855142031796277, 0.18827188177965581, 0.152989171911031, 0.10414055170258507, 0.1274359438684769, 0.1344806916313246, 0.08599222826887853, 0.2811033051693812, 0.15440781688084826, 0.28259193466510624, 0.2862615877529606, 0.07232390897115692, 0.09356562266475521, 0.09718541827169247, 0.17768195393728092, 0.15736885252408683, 0.10264548778650351, 0.1441745355259627, 0.10069010677398182, 0.2514890895690769, 0.2109652734361589, 0.1499324882752262, 0.11184529881575145, 0.1420566241722554, 0.130837993347086, 0.11111516650998965, 0.17001757223624736, 0.08188888634322211, 0.07809680857462808, 0.09099511997192167, 0.12126647765398957, 0.09025401872349903, 0.15118225011974573, 0.17360266501782462, 0.19926274748286232, 0.2274068130645901, 0.09226883092196658, 0.1273935375502333, 0.2530151233077049, 0.1540830679005012, 0.09238593440386467, 0.17563297325978056, 0.21181439427891746, 0.13616852840641513, 0.19327830610563979, 0.19410905137192458, 0.07644463199540041, 0.12994606542633846, 0.18542240577517077, 0.12316283566178754, 0.07846892141969875, 0.12080669490387663, 0.11971553001785651, 0.13637849682709202, 0.08606535207945853, 0.10123005631612614, 0.18239810946397483, 0.11566007146029733, 0.16311215527821332, 0.1443707148428075, 0.10056305109173991, 0.11806267066276632, 0.1699818897759542, 0.18034831242403015, 0.20585043617757037, 0.08862400267389603, 0.11794634643592872, 0.13440238020848483, 0.14002808224176988, 0.1082599388610106, 0.10956228928989731], [0.07888534048106521, 0.07229056427604519, 0.03646801247668918, 0.008577662138122832, 0.14444628031924367, 0.013387896942731459, 0.021887795919610653, 0.024055099056567997, 0.014644493039668305, 0.01844023609010037, 0.035131148470100015, 0.00937162099944544, 0.0480406143469736, 0.030565346496587154, 0.045119124042685144, 0.038876270555192605, 0.013450369078782387, 0.031108724760997575, 0.03292116256488953, 0.018380602668912616, 0.019429967942414805, 0.11856364260893315, 0.01112925212510163, 0.0364661942148814, 0.05895810762012843, 0.01177225072751753, 0.03172734381223563, 0.036561623273883015, 0.018335682325414382, 0.06328302144538611, 0.08374948767595924, 0.014836035788903246, 0.031712831114418805, 0.025215819878212642, 0.0308759798281244, 0.06001281821227167, 0.01719579358905321, 0.020951526530552655, 0.017904023261507973, 0.08588598240748979, 0.06695618489175104, 0.03755208985239733, 0.05360917843063362, 0.045455283543560654, 0.041046440237550996, 0.029813207656843588, 0.04309325013309717, 0.08988689311081544, 0.020904418706777506, 0.04042036445753183, 0.02082597555272514, 0.013804621212329948, 0.07740992121398449, 0.03928122343495488, 0.052899284492013976, 0.02907710848376155, 0.02626561745273648, 0.06546480202814564, 0.04143649450270459, 0.04007860174169764, 0.017663951475697104, 0.005977005057502538, 0.009438052493351279, 0.15573639480862767, 0.05354452623578254, 0.004146664332438377, 0.026819855193025433, 0.009270551618101308, 0.05346173595171422, 0.0686211115680635, 0.05052259366493672, 0.06905793226906098, 0.0533923340117326, 0.06649398274021223, 0.09473032696405426, 0.062047386381891556, 0.06061574640625622, 0.03971068203100003, 0.016238413809332997, 0.0945318173035048, 0.06979540441534482, 0.04893028242804576, 0.059016696468461305, 0.023357888421742246, 0.04558997963613365, 0.0653757517284248, 0.03237154283851851, 0.02329498212930048, 0.04569680066197179, 0.08231296436861157, 0.046284006457426585, 0.06387409011949785, 0.0557463522272883, 0.07085812278091908, 0.04051992727909237, 0.0444507495558355, 0.0195808205899084, 0.14558768860297278, 0.020757440070156008, 0.09555218130117282, 0.042755372560350224, 0.020514123243629, 0.06150109147711191, 0.03757086618861649, 0.0770971950259991, 0.05794670134491753, 0.068771188671235, 0.05027526924095582, 0.05726946190407034, 0.05031021326431073, 0.06408460772945546, 0.04238697416440118, 0.1054114944417961, 0.041931414234568365, 0.06278766013565473, 0.06339222105452791, 0.005623380966426339, 0.08174451635568403, 0.048419091108371504, 0.03634908331150655, 0.022610389860346913, 0.08280343492515385, 0.06474290014011785, 0.024266559194074944, 0.03227594308555126, 0.026216516962449532, 0.03924768578144722, 0.021245520911179483, 0.0920031568966806, 0.05788103611848783, 0.02517175114917336, 0.011966697129537351, 0.043573664588620886, 0.012426056855474599, 0.012905266248708358, 0.02138659019692568, 0.035582752752816305, 0.0310254149735556, 0.0641659322718624, 0.04074503551237285, 0.02301398832059931, 0.020996558196202386, 0.061625846501556225, 0.08206955477362499, 0.041171844641212374, 0.03794187694438733, 0.020857926865573972, 0.03546721891325433, 0.02665176616574172, 0.025512387655908242, 0.07657752837985754, 0.03208125548553653, 0.06448537489632145, 0.0888236849277746, 0.01791275462892372, 0.033484894229331985, 0.023331640513788443, 0.018026308789558243, 0.042684798027039506, 0.007407146822515642, 0.0207059628519346, 0.035223976301494986, 0.02494362608558731, 0.023863122150942218, 0.06546143267769367, 0.015186643049673876, 0.03644518401415553, 0.03030788433534326, 0.029312721817404963, 0.09367681122967042, 0.05919953197007999, 0.03524276748066768, 0.012721417715511052, 0.02143123965652194, 0.051311440984136425, 0.025196024944307283, 0.04029900846944656, 0.0579699454101501, 0.03488247333734762, 0.05705130017304327, 0.056391159814666025, 0.016312875341100153, 0.058508366128080525, 0.027106923480459955, 0.015173816882452229, 0.016539248936169315, 0.039971962542040274, 0.05549260451516602, 0.07695825755945407, 0.037697446896345355, 0.02184956789278658, 0.0324308367271442, 0.030063662088650744, 0.011451048285380239, 0.055129560714703985, 0.004808250023415894, 0.007316743030969519, 0.06488160011940636, 0.05179937339562457, 0.03329653343826067, 0.05834213246998843, 0.036660878104157746, 0.018666656069399323, 0.025613262223487254, 0.03388493409147486, 0.04663697189243976, 0.029846710058336612, 0.04146868144744076, 0.04047438167617656, 0.03430862991081085, 0.05222397463512607, 0.11193422295036726, 0.010709195612434996, 0.04026972332212608, 0.03452990866207983, 0.024469054187648, 0.07540458624134772, 0.037171238218434155, 0.03595570051402319, 0.03635401117207948, 0.07614663743879646, 0.016049945406848565, 0.07604753845953383, 0.05111689810291864, 0.039578806099598296, 0.06654014432569966, 0.06781696487450972, 0.054448614246211946, 0.030796319551882334, 0.061851908394601196, 0.07401990937069058, 0.019134120047965553, 0.07921526965219527, 0.04402435974043328, 0.029795362715958618, 0.03604250210628379, 0.0052583240903913975, 0.03576562536181882, 0.02361855295021087, 0.024001503006729763, 0.05357863163226284, 0.051299266051501036, 0.07216853293357417, 0.017778913861548062, 0.07040116761345416, 0.07528530826675706, 0.03971711645135656, 0.006010718971083406, 0.016629277015454136, 0.04595596605213359, 0.06386448672856204, 0.04426160208822694, 0.022530117312271614, 0.05648543483403046, 0.03659084533865098, 0.06743790552718565, 0.025174215079459827, 0.02525963071093429, 0.006497658296211739, 0.03355541681230534, 0.06740786338923499, 0.08014809733140282, 0.06815069384174421, 0.11241621818044223, 0.058289914959459566, 0.0422456581145525, 0.07241160856210627, 0.04637968784663826, 0.039326958285528235, 0.01632051575143123, 0.04093733339686878, 0.10192539673880674, 0.14603940420784056, 0.1049131942272652, 0.0474957035476109, 0.04969434201484546, 0.030857600540912244, 0.06223668227903545, 0.1156007441750262, 0.06161699639051221, 0.031371094373753294, 0.05476434242154937, 0.020347887730167713, 0.041619894036557525, 0.05403762770583853, 0.06102807994466275, 0.08297291919006966, 0.05225706328928936, 0.04970993824827019, 0.022674563369946554, 0.036429469037102535, 0.02441173626721138, 0.01866314014478121, 0.055823453949415125, 0.018376758343947586, 0.02436981234495761, 0.06550479636644013, 0.05938202237302903, 0.06807624158682302, 0.036107491978327744, 0.02159191462851595, 0.10859357134904712, 0.05564340892306063, 0.055233131133718416, 0.04345231602201238, 0.05449948846944608, 0.04930615425109863, 0.06301034154603258, 0.020996433886466548, 0.06847556898719631, 0.028779499843949452, 0.022100868372945115, 0.06595926533918828, 0.040672316172276624, 0.046860733127687126, 0.035146421869285405, 0.03511502160108648, 0.03667008815682493, 0.03515660784614738, 0.02408769418252632, 0.01872929704404669, 0.07160642286180519, 0.018495741314836778, 0.027925486392632592, 0.0795479076623451, 0.0055001250802888535, 0.036469107144512236, 0.017284597124671564, 0.03661592993012164, 0.06180882301123347, 0.05077792957308702, 0.00694073483828106, 0.06962930434383452, 0.028481078552431427, 0.07496203616028652, 0.028431790669856127, 0.044137693112134, 0.04347901849541813, 0.03560351804480888, 0.027536218804016244, 0.040515674772905186, 0.04657559999031946, 0.0748944933002349, 0.07687586432439275, 0.044269242498558015, 0.03181153675541282, 0.03831829424598254, 0.023677143653912935, 0.02869088184525026, 0.0239818193949759, 0.04697518714237958, 0.014540340034727706, 0.18002452823566273, 0.21598768362309784, 0.1491554151289165, 0.12621105881407857, 0.31396477308589965, 0.12966513284482062, 0.17405979830073193, 0.13041649799561128, 0.09088858467293903, 0.16207298525841907, 0.16279251227388158, 0.10152324917726219, 0.1695343598839827, 0.08449319386272691, 0.08840008187689818, 0.11634235750534572, 0.08943473221734166, 0.10090754120028578, 0.12817708222428337, 0.11078931915108114, 0.0936627846385818, 0.21255810046568513, 0.1682170180720277, 0.1367684657452628, 0.14408467628527433, 0.08907497613108717, 0.12936637387610972, 0.2089641019119881, 0.10641306726029143, 0.16746262495871633, 0.12792084831744432, 0.12663945613894612, 0.11797849627328105, 0.11272602030658163, 0.13919327000621706, 0.20403984817676246, 0.1395017807953991, 0.13758931076154113, 0.15760236186906695, 0.17214796651387587, 0.16744168155128136, 0.15540127060376108, 0.3196671389741823, 0.12476152565795928, 0.18759415252134204, 0.11363575235009193, 0.25278496847022325, 0.12960311898496002, 0.14821854274487123, 0.20583636505762115, 0.19541006593499333, 0.23853451595641673, 0.15523617243161425, 0.1973030620138161, 0.33710380957927555, 0.14939110638806596, 0.1821473822928965, 0.1933671411825344, 0.09264691805583425, 0.20483142288867384, 0.1559335834463127, 0.10412480332888663, 0.11509828793350607, 0.19346957240486518, 0.11599285047850572, 0.14188115077558905, 0.17747603764291853, 0.09978956994018517, 0.14875179069349542, 0.1791104843141511, 0.23840153793571517, 0.25830393482465297, 0.2285655727609992, 0.15400720556499436, 0.13377660128753632, 0.09839739737799391, 0.1717145077418536, 0.25468537118285894, 0.15656377072446048, 0.25078752252738923, 0.1289354680920951, 0.1670932729030028, 0.10110113042173907, 0.16918293811613694, 0.08531633953680284, 0.2336279401788488, 0.2950806770240888, 0.18173142336308956, 0.1128908438840881, 0.1443002701853402, 0.20671701233368367, 0.18326743156649172, 0.1162450916308444, 0.11432119252276607, 0.16102838271763176, 0.18295532878255472, 0.43419435911346227, 0.26154516090173274, 0.13290042174048722, 0.19420676253503188, 0.20193869451759383, 0.14164615713525563, 0.2070952404756099, 0.16003625001758337, 0.13357592455577105, 0.08601623674621806, 0.11615176656050608, 0.14589915313990787, 0.14525489474181086, 0.13645781757077202, 0.1724813986220397, 0.1297006371896714, 0.2890851628035307, 0.1513965378399007, 0.2312409260775894, 0.14334442850667983, 0.12787859042873606, 0.17360726633341983, 0.11279305108473636, 0.10212685272563249, 0.20132386969635263, 0.14033444080268964, 0.22904416895471513, 0.13286775239976123, 0.11712202816852368, 0.12694134697085246, 0.17095110495574772, 0.21866930066607893, 0.14759363955818117, 0.09036200863192789, 0.16739350132411346, 0.1635245667421259, 0.11033934759325348, 0.11271796058281325, 0.1987254770938307, 0.10922627450781874, 0.18047361663775519, 0.10176929339650087, 0.14200188335962594, 0.20315554953413084, 0.1149002680904232, 0.08309916593134403, 0.09806228059460409, 0.1354690542211756, 0.21155970403924584, 0.25395355420187116, 0.1326024642912671, 0.1902599321329035, 0.18833653768524528, 0.2057104671257548, 0.14273696579039097, 0.09803292123251595, 0.13722236326429993, 0.13805095630232245, 0.057735519512789324, 0.08650440664496273, 0.13420315808616579, 0.15798905049450696, 0.1367423718329519, 0.09021260688314214, 0.10440846701385453, 0.11871677736053243, 0.08996314136311412, 0.09670162704424001, 0.1382285077124834, 0.08172700909199193, 0.17453503998694941, 0.15203199436655268, 0.1530306282802485, 0.2363623832934536, 0.10451149195432663, 0.15427302801981568, 0.0887736419099383, 0.08597599749919027, 0.16211537673370913, 0.07421976231853478], [0.0408938398322789, 0.04620378771505784, 0.04587877898302395, 0.047594041825504974, 0.036479204063653015, 0.06705285704811104, 0.03515480442729313, 0.06043528577720281, 0.0925806442683097, 0.037709670068579726, 0.038120764220366254, 0.04306837705371436, 0.07398508038022555, 0.03376292501343414, 0.016380570341425482, 0.03588977182516828, 0.03763020460610278, 0.023950452523422427, 0.0193443407988525, 0.033458087855251506, 0.026299477940483484, 0.015551584892818937, 0.06262944167247042, 0.0493724020634545, 0.009209827239828883, 0.00519554860147764, 0.08149908811901696, 0.030252004326030146, 0.044098322177887894, 0.009890006513160188, 0.02014482128288364, 0.04933852302201558, 0.028326106985332444, 0.028913082715007477, 0.026274447154719383, 0.04394914307340514, 0.03953132349124644, 0.006923299470145139, 0.04144431673921645, 0.022088108999014366, 0.05192927521420643, 0.09970709506887943, 0.028124317032052204, 0.04793657637492288, 0.028270724214962684, 0.013212499616201967, 0.034522346177254803, 0.0451783140306361, 0.03649572056019679, 0.04334548386395909, 0.01087721135263564, 0.07183717141742818, 0.03882287674059626, 0.032990152612910606, 0.044589486642507836, 0.042852987244259566, 0.02189697257563239, 0.019952857364842203, 0.010430416186864022, 0.05399131769081578, 0.011646956718323054, 0.04272666628821753, 0.045766518014715984, 0.02247305543278344, 0.0566388441802701, 0.05259011319139972, 0.042000148241641, 0.08426632673945278, 0.021510363731067628, 0.10518615614273585, 0.07319792886846699, 0.07202933571534231, 0.06467465966125019, 0.10742506725364365, 0.09061478413059376, 0.007557787957921391, 0.030062988589634188, 0.0645913758489769, 0.032970274187391624, 0.05487778711540159, 0.08186099643353373, 0.04147040323005058, 0.08868186050676741, 0.024629512081446592, 0.12024120063870214, 0.017372836628055666, 0.025286097552452702, 0.029551810257544275, 0.062324396712938324, 0.013687772843695711, 0.03851832902000751, 0.03864916965540033, 0.07247314002597705, 0.01657802986301249, 0.03594670197344385, 0.06786547164665535, 0.009514897246845067, 0.12687884329352528, 0.02613947832287522, 0.021599467836495023, 0.032353568021790124, 0.06239670416107401, 0.025090979506785516, 0.10888625954976305, 0.014485032406810205, 0.027673846379911993, 0.04993824513803702, 0.015141485218919115, 0.010199119369644905, 0.04791797444340773, 0.05317811308486853, 0.016385290400648955, 0.04042652799398638, 0.04312935190682765, 0.06392969924490899, 0.03483200358459726, 0.07242731240694411, 0.016855390858836472, 0.06465336002293043, 0.0698905106401071, 0.011706219993357081, 0.04715036367997527, 0.03595236827095505, 0.08955907163908705, 0.029037596541456878, 0.05805807915749028, 0.026060129748657346, 0.036700675773317926, 0.05944721262494568, 0.018555695714894682, 0.03458103892626241, 0.029173060756875202, 0.0754433857218828, 0.026004583705798723, 0.03971413672843482, 0.04170369735220447, 0.026303290724172257, 0.03440261549258139, 0.047469876808463596, 0.10067785391584039, 0.0425653308047913, 0.09385317520354874, 0.03837097559880931, 0.07895700226072222, 0.04102441329450812, 0.05905770383833442, 0.03898760012816638, 0.04898493418295402, 0.015649610541004222, 0.03267449494160246, 0.03461505526502151, 0.022323097073240206, 0.02301979377079988, 0.05384768985095434, 0.02218107969383709, 0.04463304328965023, 0.027729817302315496, 0.018500394580769353, 0.0596311019762652, 0.02700197266676696, 0.04263387556420639, 0.013318207420525141, 0.02242138154542772, 0.025067197384487372, 0.046858254354447126, 0.01628125613933662, 0.05667707962857094, 0.05523153922695201, 0.03541978825523984, 0.058700344889075495, 0.014154247910482809, 0.036414618662092835, 0.05046597150794696, 0.019958872471761424, 0.07169715783675201, 0.026779209620144684, 0.010819091912708245, 0.06004589573421981, 0.01873542718385579, 0.023258807996171527, 0.039320980285992846, 0.04111125570489094, 0.06949204413103871, 0.03529306282871403, 0.03572810979676433, 0.011131725332234055, 0.05867387619218789, 0.05060989620687906, 0.05993850325467065, 0.038362537379725836, 0.00750653523937217, 0.05162665336683858, 0.03304039972135797, 0.04183732846286148, 0.02214698357420275, 0.08340827043866739, 0.09127840516157448, 0.012324432718742173, 0.030977039932622574, 0.04292791447369382, 0.029371746677497867, 0.030990888408268802, 0.021320702326192986, 0.04214854438032489, 0.04638382531993557, 0.04200682385999244, 0.027475286624394357, 0.056541066223871894, 0.029953343691886403, 0.0817653261765372, 0.0458520765096182, 0.03989451943198219, 0.06363783482811414, 0.04729533851786982, 0.04320701023971196, 0.06846062213298865, 0.06752335641067475, 0.052326643344713375, 0.026685318662202917, 0.02609169328934513, 0.051288824033690616, 0.04863280737481546, 0.07743846421362832, 0.025326116010546684, 0.03250720372307114, 0.056897263712016866, 0.034460781316738576, 0.08768727129790932, 0.0450904511671979, 0.0363557774835499, 0.016492048343934584, 0.04263598326360807, 0.03543722130416427, 0.01686451370915165, 0.05298375945130829, 0.024632141139591113, 0.03503034255118109, 0.03558015523594804, 0.029985756991663948, 0.02202659237809712, 0.05450261291116476, 0.024581354118708987, 0.024208536233345512, 0.15457300411071628, 0.05418014603492338, 0.010792394077725476, 0.024752261451794766, 0.0362565374962287, 0.0029778399539281963, 0.06000801280606538, 0.05337976574082859, 0.016567964485147968, 0.028608132379304152, 0.041859474149532616, 0.04853675120102707, 0.05331026732164901, 0.039867238083388656, 0.037970008052070625, 0.09665944337029941, 0.07750172488158569, 0.05447818883112632, 0.04141122066357639, 0.08127646608045325, 0.01988903637538897, 0.019258930733485613, 0.0038256495145105873, 0.04897163118585013, 0.025900339787767734, 0.010351811615691986, 0.018709769283304922, 0.07568634260678664, 0.043714999192161486, 0.055342746345559135, 0.09956161928130314, 0.030705183817190118, 0.03056340206967434, 0.000883404876503846, 0.11517607243149541, 0.0249216956217424, 0.07927464888780378, 0.07638347902684473, 0.08959029379184358, 0.02801435115543427, 0.04248753146384843, 0.033397977604181506, 0.0218261920963414, 0.03146600764011964, 0.016238591924775392, 0.032170049744308926, 0.12371301199891604, 0.10413277399493381, 0.06142588594229892, 0.03266644635004923, 0.018018842783931177, 0.0569864698627498, 0.028606560881598853, 0.03444893292908091, 0.0027532778949534986, 0.06750368949724361, 0.0724984027328901, 0.041786910660448484, 0.030876343480485957, 0.037923070922261104, 0.06938956095837057, 0.056817126605892554, 0.045610013912664726, 0.06806032994063571, 0.06537585562909953, 0.02605245779705001, 0.03443094698013738, 0.018405067567073274, 0.08431105597992428, 0.017750150072970428, 0.0020436961222003447, 0.05858530457771849, 0.07238762977067381, 0.08390827759285457, 0.06535540203913115, 0.040337663231184706, 0.024402138442383148, 0.0430617719393922, 0.061916401027701795, 0.07921970027382486, 0.019973184789705556, 0.0074959183530154405, 0.011176616917509818, 0.07118331704987213, 0.008306551881105406, 0.05422830399766099, 0.049342753263772465, 0.012048745265929028, 0.04106861189939082, 0.02882131615479011, 0.024921977637859527, 0.031163931271294132, 0.07454271530150436, 0.0024835482645357843, 0.02723869551118696, 0.0391901693365071, 0.06704585859552026, 0.04858863845583983, 0.045016095391474664, 0.02969010947708739, 0.03733405428647529, 0.06895297032315284, 0.02112403690261999, 0.04067786372615956, 0.04003216927230824, 0.05661782284732908, 0.024298465978063177, 0.03657481494883541, 0.032514469348825514, 0.09730903038871475, 0.19671980815473944, 0.08886888914275914, 0.2216813960694708, 0.15710142703028396, 0.1425775227835402, 0.20983826281735674, 0.09937938491930254, 0.1349428715184331, 0.08216992282541469, 0.14659819687949494, 0.15334559575421736, 0.16365484334528446, 0.12588733399752527, 0.13667209044797346, 0.10014761166530661, 0.13336712872842327, 0.11712582054315135, 0.08916083519579843, 0.20637697511119768, 0.17351461661746725, 0.11721350529114716, 0.2524914935929701, 0.20618389797164127, 0.12563375697936863, 0.12698416889179498, 0.1269816604326479, 0.10139087971765548, 0.09842916129855439, 0.10360124782891944, 0.09750808923854493, 0.24247843713965267, 0.10115794182638638, 0.1508503913646564, 0.13219627202488482, 0.10136441473150626, 0.18954295810544863, 0.11719155256287195, 0.17131487606093287, 0.11379428251530044, 0.20512323535513133, 0.20360831898869947, 0.13123894605087116, 0.13429335871478543, 0.11018665813026018, 0.1033781433943659, 0.17979426949750632, 0.22098394052591175, 0.12540554656879976, 0.12394453238812275, 0.21328277798602358, 0.20557398616801947, 0.11761114801629446, 0.08392778865527362, 0.1283146912464872, 0.06995182688115165, 0.07332758948905393, 0.16537340503418818, 0.1415770928724669, 0.2346965586184524, 0.20278829033486545, 0.132099911570549, 0.19244713039370254, 0.11189995057065971, 0.1969258431927301, 0.13839099352480844, 0.15227981231873855, 0.21943047700915486, 0.11300299724098295, 0.19548039184883237, 0.20436587365111336, 0.20974294136976823, 0.17668167245574296, 0.18261312448885292, 0.20888565690256655, 0.1031042389513459, 0.0812172501173336, 0.14418675127672032, 0.17789928446291015, 0.20879750460153446, 0.16248058760538697, 0.14844669378362596, 0.18131173885194585, 0.14928135758964345, 0.20456692145671695, 0.1892873624456115, 0.15716510330094025, 0.11821286650956608, 0.14582734293071553, 0.09905193452141248, 0.08589381948695518, 0.13101040909532458, 0.23622680775588378, 0.09534535216516815, 0.21867321920581162, 0.21728118765167892, 0.1639971960685216, 0.2889990439871326, 0.10501795579330064, 0.12599047768162563, 0.13743389019509777, 0.17064734391169623, 0.0834994061733596, 0.23906249465653673, 0.20807376218726858, 0.08468223371892236, 0.13413859123829752, 0.08083543740212917, 0.14930712495697662, 0.11244815279496834, 0.1578228984726593, 0.129925804794766, 0.11453755083493888, 0.18984496768098325, 0.20851315814070404, 0.10332716527045704, 0.13178421679185703, 0.07030108899925835, 0.11938036128412932, 0.13303795654792339, 0.11715396278304979, 0.05188463503145613, 0.21403580554760993, 0.17887975060148165, 0.18968623713590205, 0.15810901124496013, 0.12714585318462923, 0.1690596080152318, 0.12960105581441894, 0.1446884876349941, 0.1011457409185823, 0.16520793578820303, 0.16388378106057644, 0.1367997843772173, 0.07629295927472413, 0.20001077296910807, 0.0989694893360138, 0.13190416269935668, 0.20391473692143336, 0.1547727160505019, 0.2682461903896183, 0.17414563510101289, 0.07345218866248615, 0.1544086926151067, 0.2549605001695454, 0.1305284138652496, 0.12204751386889257, 0.10536587462411262, 0.17319138161838055, 0.16355140280211344, 0.1820004964247346, 0.13844340399373323, 0.141387622570619, 0.11553867836482823, 0.0784581528569106, 0.136381866177544, 0.10545705488766544, 0.10414749820483848, 0.13312392693478614, 0.12406814450514503, 0.08644852292491123, 0.11368341307388619, 0.09358898547361605, 0.24101144867017865, 0.2615873148897663, 0.22393543215002865, 0.1248140400275588, 0.19269000564236194, 0.09519722691038623, 0.14696465455926955, 0.08724956001969986, 0.13806820381432772, 0.189670666877646, 0.11090530941146426, 0.14330775156849995, 0.1310359241324477], [0.04083702471689321, 0.01825521125283558, 0.04094304422324058, 0.0661606842186302, 0.0060806241799582494, 0.028258857273613103, 0.017973625581362285, 0.06879658496472985, 0.048080694032250904, 0.01697129391686758, 0.03533294584485702, 0.014402309843717376, 0.0445760611910373, 0.09074569155927747, 0.04717394171166234, 0.03036334503121907, 0.0452695425337879, 0.01313457039941568, 0.034183663374278694, 0.026850793474295642, 0.030153790357871912, 0.03510296541207936, 0.03977720072725788, 0.03069696824240964, 0.052519906021188945, 0.042566826232359745, 0.07491243843105622, 0.05571122637775261, 0.06927078022272326, 0.010733243052527541, 0.05250401663943194, 0.008991298145701876, 0.035842678844346665, 0.011480150678835344, 0.041310841479571536, 0.03312907894724049, 0.026703300900408067, 0.05817459634272382, 0.03748217954125721, 0.1185632566921413, 0.019963076738349628, 0.02301308104506461, 0.033019025868270546, 0.044639529660344124, 0.0742423978226725, 0.03427007904974744, 0.06120750156696886, 0.03099894256592961, 0.07785644178511575, 0.02734937941568205, 0.04004514201369602, 0.048511403147131205, 0.008781062551861396, 0.06073542514059227, 0.01997785846469924, 0.018872949003707618, 0.04462078672077041, 0.016346836018783506, 0.02522912844142411, 0.06883605979965068, 0.04727122242911719, 0.04628317154129036, 0.09914578651660122, 0.035955670828116126, 0.028061681623512413, 0.04346587506006472, 0.04706034858827479, 0.012315063104324508, 0.08550704180379398, 0.021242526345304213, 0.0009073310798157763, 0.08161388352164067, 0.026650981344573665, 0.04554686456685886, 0.021118782497069333, 0.06303535192273557, 0.09088082180824131, 0.05255935117020272, 0.03200763814675156, 0.022217934747459367, 0.10056757819256745, 0.08312293692142703, 0.05549789231736213, 0.061913358222227544, 0.10087446367833763, 0.04149452674027998, 0.08114739917800762, 0.048816841444931924, 0.05695567073416896, 0.024389212085225154, 0.09913242043694481, 0.04615053490852006, 0.04929522612656001, 0.031067678428371437, 0.029016968546784483, 0.06598914420465007, 0.014431384406634606, 0.04247200944519136, 0.040089889807859436, 0.03414981772948522, 0.0591105818602955, 0.020169063536741305, 0.11066830455092713, 0.07845730680855922, 0.06904059569933452, 0.026323046695324592, 0.0851579058507923, 0.020672573627962265, 0.10349354735808447, 0.06621342123253271, 0.023207612794067245, 0.03230832669942174, 0.01504927800851874, 0.06523124073282816, 0.057199076618417166, 0.07029721498838626, 0.06128973895101808, 0.03513344912789762, 0.050006374294753186, 0.0632723567832727, 0.013650987366418121, 0.030027551038074307, 0.0551067619380774, 0.047506609407719225, 0.05587339306657668, 0.07614463364006951, 0.06369908427586779, 0.041863708102027886, 0.02424510556011228, 0.03904285673343111, 0.03889126193826087, 0.013364467340579722, 0.040999042976181954, 0.02348396632442018, 0.07305925115360878, 0.03958437962864991, 0.037685732095269486, 0.023193922024802305, 0.027928241615882143, 0.012137370686104987, 0.016544048776268028, 0.03727419636561535, 0.054958881592028774, 0.062061338758212514, 0.0286769517333596, 0.01981407760467846, 0.05542294653423596, 0.03416091654798947, 0.047230756827048026, 0.009294853243773105, 0.04985850137018133, 0.01501721351814922, 0.0788884649227839, 0.03879959185724147, 0.0011637046031864884, 0.040576783212600276, 0.013523095840355381, 0.0414615234330995, 0.04024816022138111, 0.027254983797320165, 0.011123632211820222, 0.038950210728216916, 0.03405966162972618, 0.04758792281791102, 0.044021309513482265, 0.029511233333323617, 0.018545964303484652, 0.09551172683131881, 0.0572200497117592, 0.03347704972838983, 0.07743630456388928, 0.08474548696540296, 0.06527488643769175, 0.04063340536959004, 0.11764952447265387, 0.04527483775746077, 0.028935404661751818, 0.05114643929118756, 0.08200904747354798, 0.03047624424652895, 0.02188620772358263, 0.07162087989854626, 0.052592491774703376, 0.07919601091998629, 0.04781133895448875, 0.017148259030363988, 0.06043560861144215, 0.042209426464978606, 0.036273569785407744, 0.09535402787150815, 0.02779753085633274, 0.055877081540529616, 0.04454452733625658, 0.06796304922318086, 0.03149579373712186, 0.06238467394723557, 0.018539563279773574, 0.022545401843672153, 0.04293416335713118, 0.0326810369733721, 0.03792587995121721, 0.028560249011206906, 0.02398104941676138, 0.05404477829870302, 0.07795454628649168, 0.03996829633251764, 0.04174735047854483, 0.030378442170331255, 0.09469680415350012, 0.023673388386669103, 0.011660931359074311, 0.014320081736514112, 0.0227757848915644, 0.01493473864684347, 0.01906206121930154, 0.03300732219940983, 0.030644657963421196, 0.01814285380532965, 0.03423567679419648, 0.011029632714780746, 0.011517870334500913, 0.03655229076684918, 0.08998148725368083, 0.013178295885154512, 0.008335066122526769, 0.03170599593431689, 0.021099072910146788, 0.016986170267045964, 0.0392799580731662, 0.021765245073765982, 0.047895661773509346, 0.08193783840397373, 0.04004467074992135, 0.02413443278783234, 0.034296161829843186, 0.045777052800985985, 0.06687753208098002, 0.028650139793171547, 0.06637227794271894, 0.04273849612218328, 0.033093663660110906, 0.03173427547153551, 0.021493596759682987, 0.039737262050039135, 0.04605231908499263, 0.051803451497107744, 0.05539984347706195, 0.07483351102564484, 0.024890694257919677, 0.04378932157123927, 0.09208388772094622, 0.11777202336816117, 0.043312888738000765, 0.10172610040172003, 0.026077586917381268, 0.028912487141496968, 0.00887030209923978, 0.053069432979100384, 0.016294117558572907, 0.03225855827622581, 0.012737174438370857, 0.028487320014392026, 0.08503250515786931, 0.023282961192307994, 0.03151430290017743, 0.0373616733122617, 0.0660399961634539, 0.0050348188960924745, 0.043488547671586275, 0.03560066077625379, 0.08143939718138427, 0.03960841037041973, 0.032960715325316414, 0.09116957662627101, 0.06873381411423907, 0.062356954731512815, 0.07096542991348542, 0.04319332874729298, 0.026702564318838995, 0.03654078005638439, 0.04606947382853832, 0.06352212658384815, 0.07568240180262364, 0.02567441333667375, 0.04091696144314483, 0.05457766259496566, 0.04945474705891684, 0.03062813775613904, 0.04732000750664156, 0.033271686334046535, 0.05530760194233153, 0.05714877013815567, 0.03402140020625666, 0.06089766604418401, 0.0165754824411124, 0.0455292162951082, 0.04904546003672294, 0.028992674342589453, 0.05519208294572309, 0.0031798101099411724, 0.03119913504633587, 0.0948887161212042, 0.00395904244214762, 0.04097900498891249, 0.025710747031553183, 0.019659814788610674, 0.050110352894989774, 0.03287508632638492, 0.006258863932089298, 0.015723860560683534, 0.0364611921395408, 0.037914476852165535, 0.027621554654615466, 0.09130656966590323, 0.05684318341081962, 0.08159176009939983, 0.019236254411225673, 0.08408978465013206, 0.1070225857256446, 0.13579781079897657, 0.03707462914462667, 0.07785896508721635, 0.012501328255893895, 0.026715683634392917, 0.008335851871379418, 0.028691746447293554, 0.009931542663252912, 0.01959774897841271, 0.07171969686169177, 0.035642621805891395, 0.03644656440883409, 0.04738644085591659, 0.047045490791788325, 0.04543501549051143, 0.019066198692598846, 0.06880528293550014, 0.036918507248628885, 0.015387976582132978, 0.03463732711679768, 0.038791120241512544, 0.061241477087605745, 0.008777707116678357, 0.021509155885723885, 0.017603844935365487, 0.0642366886313539, 0.043420841539045796, 0.04261936657712795, 0.025617288374633063, 0.011444290103099775, 0.042084523010998964, 0.05785171015304513, 0.030107600941846613, 0.12050626610289328, 0.09934575078659691, 0.1316505263093859, 0.20968698343494907, 0.07826828921679407, 0.10608747965306975, 0.22766328445868567, 0.24991199607029557, 0.17460877978010103, 0.29806945414748043, 0.1963098457781598, 0.1380439504282549, 0.16275037312880158, 0.3326302324421704, 0.14676644175779074, 0.19158101436914876, 0.18973118159919977, 0.11297911492874846, 0.11149781043059193, 0.13948996580438688, 0.15987085498636588, 0.09725219671963714, 0.08383640801184811, 0.0873175852757413, 0.10446789077832364, 0.10460789693752304, 0.10936753489659168, 0.11843147352919914, 0.1533241625293158, 0.08456891519017518, 0.1343350377283059, 0.08287226912216283, 0.10392271651653573, 0.13218564447015524, 0.14079084678087384, 0.14115644356934354, 0.11077196031692438, 0.13018506666412577, 0.13179572008084506, 0.12647317053051665, 0.09959037008229643, 0.09599778160918504, 0.10202134159044363, 0.17263019923120737, 0.12166599059128202, 0.11010273607098497, 0.12453291448764503, 0.1820796835818328, 0.14355352119309828, 0.14834965055342764, 0.10601415546261705, 0.15205825155135244, 0.1468770662904717, 0.10455495954374783, 0.1104600950202439, 0.22595692367758602, 0.17028738744556904, 0.10807354105054401, 0.11115026267361827, 0.11620057761319913, 0.11945883597945794, 0.1297566544963047, 0.13349636632483453, 0.17002857086481526, 0.06584233255125582, 0.10304666313459165, 0.08699804617208429, 0.1532834631507285, 0.1927736753714271, 0.11208570271264762, 0.13392574328463525, 0.34563334251288325, 0.17710710118990391, 0.15508186508668587, 0.22549769753823057, 0.21473023312864825, 0.2443590245093219, 0.1526832437957637, 0.11332278125337325, 0.15040078345919028, 0.21908240974880755, 0.23004240210866556, 0.136141647817567, 0.13592918578069657, 0.1816627153311856, 0.12792748311767355, 0.2308920572977513, 0.09954540335456841, 0.24599877011496574, 0.2190689620329067, 0.198128909105435, 0.15686855593230575, 0.11959028517594561, 0.1776566170156002, 0.2172125835204497, 0.1587720014504157, 0.20188227645121515, 0.26166203431785107, 0.12336622123257257, 0.13316597702214494, 0.16648864519083872, 0.1271494006505236, 0.19434802292380482, 0.14227689360268414, 0.11740313144400716, 0.152039579115808, 0.15268520306563005, 0.14193869690643623, 0.15502936556003988, 0.15002941276179627, 0.1459996250923723, 0.2042625518515706, 0.09165857773041353, 0.19390717236092314, 0.12433289084583521, 0.187997272296343, 0.1768636767519638, 0.2456889086170122, 0.14917932712705806, 0.1707538272603415, 0.13565560046117753, 0.12507643376011401, 0.18762066203635186, 0.16577088448684663, 0.125813519989606, 0.16093589627416804, 0.1890550702228211, 0.20114513084990904, 0.1392534581827931, 0.08838459325488657, 0.18760114355245605, 0.0922308255394455, 0.11247677000937983, 0.09840340877417475, 0.21853988495422527, 0.15460724680451676, 0.11268610760453157, 0.11538437101989985, 0.13418789952993393, 0.2388884758693166, 0.09217391023412347, 0.1531427667941898, 0.16034982225392014, 0.2447682892670855, 0.12545948586193845, 0.12797535164281726, 0.16994610341498628, 0.1648958626901731, 0.11384885263396427, 0.13256112666567788, 0.13112315617036074, 0.1344510354101658, 0.1897360204020515, 0.11625323299085721, 0.129212140745949, 0.1363875955576077, 0.1135776644514408, 0.15014542528660968, 0.08067639515502378, 0.16249265492660925, 0.14007932011736557, 0.086899667076068, 0.18604710116051137, 0.14205237908754498, 0.13743584946496412, 0.13409406237769872, 0.12948461284395307, 0.12201356061268598, 0.14340014895424247, 0.13281786523293704, 0.22448430972872302, 0.13242583314422518, 0.18749943963484839, 0.1820265903370455, 0.21467515092808753, 0.2063606181764044], [0.06272771686781198, 0.05049187246186193, 0.017675313756626565, 0.03166916314512491, 0.06280177578446455, 0.07653356355149299, 0.021228939476714004, 0.032826112001203, 0.023883147150627337, 0.044127507135272026, 0.009795573787414469, 0.0349173357244581, 0.08800403476925567, 0.04591557466483209, 0.019695962946570944, 0.09271653892938048, 0.06502609627204947, 0.005833006143802777, 0.0378512087627314, 0.05129725483129732, 0.03731032040377613, 0.038931389863137156, 0.04359730941359885, 0.03218210222257767, 0.11807154674897902, 0.03810409929428715, 0.047549653972964734, 0.09946262420271523, 0.034597937628859654, 0.04832984042877797, 0.046931615652283654, 0.060795138342655264, 0.039371702368953265, 0.02790550592180807, 0.06342312408378348, 0.09472430072491989, 0.01237001171830343, 0.03312496373837348, 0.05412860387878027, 0.03363462252309546, 0.01659915880736662, 0.026241375198878814, 0.055066259228624403, 0.08479947820887901, 0.026065749661938753, 0.040032544056884944, 0.03889122112013865, 0.034914623174699955, 0.033169470334541984, 0.027228097642364446, 0.0476804166828515, 0.05628610138955992, 0.07766887138132006, 0.008122383296722546, 0.033166075008921325, 0.06306965398835018, 0.07178755142376758, 0.05053637163655367, 0.04166623002674896, 0.03484559230855666, 0.026202516346529592, 0.06750195287168026, 0.03694129118230194, 0.02740681236900855, 0.050982855100301094, 0.08066785303526558, 0.036900673439959064, 0.04243462375598028, 0.05705990537535399, 0.027670885210682172, 0.053758691501570866, 0.0656586658442393, 0.06173054869577754, 0.04841860129090492, 0.06343473127344623, 0.03679233843286056, 0.05902278579014819, 0.04151960391027387, 0.015557201095361961, 0.022427227813750505, 0.01787648958270438, 0.0636106648016721, 0.04555727689876221, 0.040351352145080455, 0.02392880036495626, 0.04491548614169005, 0.02633687105117133, 0.07606937986565754, 0.048738140394561924, 0.010961303178191883, 0.04567786105326377, 0.02683027123566717, 0.040792915169731714, 0.028026876752846874, 0.053238048931234516, 0.06656868732534349, 0.05602214914688375, 0.006316619255812839, 0.026019198448921088, 0.10910700395470485, 0.07987482371390797, 0.02396795793174533, 0.06894514066516422, 0.010037090905825607, 0.06510112740215845, 0.02688866155949654, 0.04230133032251615, 0.08207492050132714, 0.0388554013625253, 0.04714817805506755, 0.046024930124985985, 0.032268959475914016, 0.0602453961619176, 0.037857316638110206, 0.013496531591954408, 0.027014414772565942, 0.010102821070177015, 0.0664332824817393, 0.023776856760377996, 0.05101236289192457, 0.08277545595774427, 0.01591473166627111, 0.06117174118116964, 0.05789283997728489, 0.10844775417353958, 0.05517212659469806, 0.049255387639277615, 0.01184681337690563, 0.05913721011893358, 0.0394441100070253, 0.03722738540091086, 0.02866221453587059, 0.05711145124223549, 0.038158621173352, 0.021586046095762867, 0.02071518774755532, 0.020610938263416756, 0.04611585434759036, 0.02905397574068047, 0.05539033285458572, 0.0254739314186736, 0.037495771975954995, 0.052306353027233854, 0.012512623743532458, 0.02851078115782002, 0.02572713179688435, 0.03068147590965964, 0.020060262831975706, 0.0185491184311104, 0.05960420654446352, 0.049722762560122646, 0.030996135392342694, 0.04289464770408813, 0.01869100407930091, 0.02052208648819942, 0.08278294422780164, 0.05222862047958188, 0.057711707704584114, 0.03167217997543048, 0.03639047659817152, 0.0348211942036869, 0.023454068905266467, 0.02309062248968985, 0.016137641287059523, 0.09213244644342922, 0.0826353755837772, 0.005814713595100329, 0.013462105216603959, 0.04079999896930531, 0.019720418567885645, 0.0427395759470528, 0.0644796084088739, 0.03344432472658809, 0.03234767536923755, 0.04450888569408562, 0.007096078406902961, 0.04670219925174024, 0.0646493821113836, 0.057885785863618366, 0.052796712261624634, 0.04087036941200495, 0.041372406340087764, 0.06376906880177557, 0.05282695849018637, 0.012953922378073912, 0.06645286033744924, 0.037205629341769964, 0.026246197303407826, 0.0772945024073124, 0.0492279912577942, 0.04467432154342532, 0.06658494035946205, 0.049361870987922885, 0.01152464985352708, 0.0851569781661965, 0.019146667909808457, 0.05877916468307376, 0.039333281383733265, 0.033631383048486896, 0.15116345894057304, 0.02316295405762503, 0.004346075238572666, 0.03381069334864151, 0.07259098565555178, 0.038001360080670565, 0.032759396635810845, 0.0470501217932906, 0.011764155751734506, 0.10905725037446246, 0.031120224339247216, 0.08171186927938834, 0.03453056175203528, 0.023649919821764342, 0.025944703520508483, 0.01381258816763875, 0.06145494473457802, 0.07531283452408388, 0.03499454876873642, 0.024703044073248748, 0.05403009861765895, 0.038708771535311826, 0.01927356959640747, 0.07665227007237263, 0.10824335928191431, 0.0339511225320166, 0.02868383700842969, 0.04095528965990525, 0.027793517692771275, 0.012139449627284193, 0.049114969588117674, 0.03335360830533318, 0.05097270252008457, 0.0243348683216027, 0.06990268928348087, 0.04884138055786025, 0.050391842087265104, 0.020806633328902535, 0.05312914989190176, 0.13407433609245345, 0.05239362217253074, 0.11511172080645338, 0.02974626037030248, 0.02781050730845891, 0.06911867705639452, 0.02030070940236328, 0.12474599992856383, 0.04176059039309621, 0.03542574770108331, 0.03060701252252329, 0.08586344338255003, 0.03909535254933871, 0.030855628283461556, 0.02288232575665461, 0.057976557945949025, 0.035622231298475526, 0.06954543423489667, 0.0930863140092697, 0.07105261742253788, 0.05594186732196249, 0.04672827461035922, 0.040056185171124525, 0.012711948838841636, 0.0794497066817712, 0.018087949720211327, 0.10380590247223154, 0.05645739278406836, 0.05547699343878776, 0.03806870627158787, 0.06636025515035726, 0.06892292818520218, 0.013381858643697342, 0.04158263822318986, 0.08432799921138212, 0.08274431544123217, 0.02558836687967414, 0.04784902521350887, 0.09663860386353917, 0.04674006733694114, 0.06024862450431101, 0.03826510081125889, 0.014738666941411793, 0.05110112004331313, 0.029921418354206253, 0.05037434966652654, 0.010960244690068066, 0.0407097909192089, 0.017712962908262853, 0.028265262008062564, 0.02175779391109245, 0.013322790182428434, 0.006051607597328257, 0.00493714947879198, 0.02649149566423148, 0.046843574673403054, 0.040181248186854646, 0.026055346606881358, 0.05911568412557244, 0.01727636485156836, 0.03007487965078326, 0.043687825454981066, 0.008715684907656396, 0.09308280365075916, 0.07763170462567359, 0.04676384945923928, 0.03929649683414027, 0.06446276907809079, 0.03052910185942892, 0.022354204193106852, 0.09184614813420922, 0.009312511720054317, 0.04877778221271001, 0.006794336004531942, 0.04318969964515418, 0.041814314463408664, 0.0076165090013091685, 0.035002723525394686, 0.04922567204630468, 0.060558875629794784, 0.03039718882064335, 0.03383215254871175, 0.021064724460302386, 0.0205318512962549, 0.014995586407167139, 0.013533263263525441, 0.05686628646799363, 0.052771375339943916, 0.02210755326814251, 0.030293464405986015, 0.01925660781125771, 0.05588946056377608, 0.03286049570306204, 0.06151944849989377, 0.1186012546531856, 0.06813147221691906, 0.010976905905408785, 0.010863371226150775, 0.02073406798444921, 0.017137022914539557, 0.12778548058122396, 0.01750998737406917, 0.05506003260961734, 0.03798106605245266, 0.029358842584770173, 0.011465139814390568, 0.036637604353018105, 0.02182698062824784, 0.04059020495333243, 0.04333633689384442, 0.02995049570017727, 0.021903668603044935, 0.03277671094110701, 0.006509716804430354, 0.12410088063916191, 0.08993119190563448, 0.18434339726809412, 0.14539752068230882, 0.08413082541665062, 0.15945445076795295, 0.1647314176079817, 0.13108698389260098, 0.10613943741191179, 0.16822678473545238, 0.0945390087144915, 0.15735328226583079, 0.16017889080103487, 0.15559445164399222, 0.10040891444077715, 0.29537192545831203, 0.1308485318440944, 0.0684137555072084, 0.1874320229399018, 0.13262735592434183, 0.19360678066732362, 0.14590126083930954, 0.16201385093154386, 0.24430560471955687, 0.1339977464522235, 0.14842876349575818, 0.13315998046891764, 0.22430729266488925, 0.20229330752044916, 0.1099222457560245, 0.13664710975717753, 0.09054182359250262, 0.1369454531231895, 0.08110831025987864, 0.13164231815608218, 0.15915628551738337, 0.10421187951578759, 0.14189980836817995, 0.11575974189327098, 0.08675490375026129, 0.09917125702486373, 0.10748561908258125, 0.16356465755961835, 0.14742598839802667, 0.08847027420415543, 0.15445541823282838, 0.11225561742321588, 0.17141531832749024, 0.11326208841637708, 0.13715444190893322, 0.12414682700182311, 0.11863341933349147, 0.18962061643833295, 0.10818741619004868, 0.15956323477439582, 0.14307476172689348, 0.11830509320134297, 0.26069160201586783, 0.0820592611853499, 0.13596528384368867, 0.15579339175019413, 0.17660693818470463, 0.23121193778933957, 0.08102503386908211, 0.20055473753018305, 0.15116279100766405, 0.10168723412789404, 0.15212743455776945, 0.15436121000675485, 0.27735673589631915, 0.14865516306599602, 0.22923734999494627, 0.21488629194209352, 0.15493940241867676, 0.10475968840182759, 0.09261635641450994, 0.10666639194823802, 0.13838815852068365, 0.12278419933863916, 0.14801411074586213, 0.2300930314231664, 0.2559119038050994, 0.15199141373159364, 0.16752199677284807, 0.12397300859447569, 0.21427580126328394, 0.2444236952578649, 0.15864466375205666, 0.19920831837225705, 0.1937244407599792, 0.1780117049929686, 0.12683174660196528, 0.11024557723430917, 0.12707095564110205, 0.15238942753057927, 0.1377131009940058, 0.1315090135904029, 0.1570740417810157, 0.15078077791258693, 0.22056882764445618, 0.23821355192922056, 0.14016269298736006, 0.17440321971662343, 0.13905480009270832, 0.19063205982092768, 0.12071229371940717, 0.1492047679494135, 0.13718595349928364, 0.11061803146731108, 0.1393021282274276, 0.0969636942318175, 0.1420215651160106, 0.15049726265715435, 0.1587868295609951, 0.17697902134386823, 0.1070373693073634, 0.09366947881062515, 0.22185918496688828, 0.13273033633595333, 0.14068133546970785, 0.1808125406387262, 0.09569664776790887, 0.11597964767133817, 0.1691743143601343, 0.1779798965435475, 0.17459356575272977, 0.27189343061763793, 0.12085583250154741, 0.11336594456224702, 0.1520589936990291, 0.12986006535356864, 0.08865451236488298, 0.1673557556932792, 0.1526061346521601, 0.22765731759136543, 0.10031856538262218, 0.15562636399408802, 0.17770626669516787, 0.08721245263586752, 0.19950572663219646, 0.18417809129459783, 0.1392571986070834, 0.10151586480787955, 0.09857340512098745, 0.13792520679999143, 0.11967596612521447, 0.11835516590508632, 0.054843974867253564, 0.15747422265121713, 0.17960853961994871, 0.15038478275528178, 0.08588478754973039, 0.2989610703662038, 0.18246678780997172, 0.1932478928938508, 0.14202578051481396, 0.2374102215981111, 0.13292765856022015, 0.12213188863825053, 0.10503017154405825, 0.12430529037374072, 0.16175516793737188, 0.22758647217415273, 0.09444129012990743, 0.19165252771927044, 0.19123961159493774, 0.10520641677430831, 0.08289388788398355, 0.05677571847627405, 0.19138513191137463, 0.20144908485235646, 0.1408731658011675, 0.09530413328320719, 0.22994332539383322, 0.1018054730957374, 0.15973594738170505], [0.049786290401243605, 0.039756413170835, 0.07661885858397, 0.0581715238513425, 0.027090711264463607, 0.021433093170344364, 0.020161604952591006, 0.027840760958497413, 0.031927475065458566, 0.07740909743006341, 0.027519776522240136, 0.024853991344571114, 0.04516879598668311, 0.03607409162214026, 0.0034844429455915815, 0.12605924508534372, 0.0352246590773575, 0.03410944489587564, 0.02442318575049285, 0.020746866321132984, 0.018956824678753037, 0.017979492258746177, 0.05976842898235191, 0.053280945066944696, 0.025104954147536773, 0.029487939173122868, 0.008559832967875991, 0.07172256155172363, 0.11381553020328283, 0.052312768893898465, 0.07679647678742185, 0.03563100348401349, 0.0509938759932993, 0.0531277694972232, 0.05731331169954501, 0.04641676183382515, 0.019178901238774415, 0.009136116204899736, 0.048212551409960724, 0.04319418592785951, 0.02383859045949066, 0.06208066799445078, 0.0032701617192287813, 0.0594421400455758, 0.024187448107113596, 0.02290578318934422, 0.07325653627049178, 0.02336010929866461, 0.07580288205645047, 0.023114612413337454, 0.07203220040537417, 0.015963555706548505, 0.04578204003337305, 0.05210822186199948, 0.03799285135755781, 0.061201026328490116, 0.028390738771122415, 0.016552904453419615, 0.07422979615512304, 0.0338337778521236, 0.031240053358487785, 0.03279227748862468, 0.06740946642821655, 0.01829873821407091, 0.0029853393562007113, 0.01037549169268459, 0.02547165859141387, 0.10091119256685488, 0.015224798717099475, 0.020778622820216697, 0.03893874825735111, 0.04929006077873055, 0.001411855130299955, 0.05371857841964811, 0.059242138668196276, 0.03739773055713158, 0.054946877353359014, 0.04977904332918115, 0.02836668019881472, 0.007946358855406288, 0.06369150694808923, 0.07294021808775142, 0.03997035579232033, 0.022932940228201915, 0.07315610142541118, 0.05038288807554636, 0.029545507568400353, 0.0399022860074183, 0.057084181025857106, 0.03228597321140114, 0.03613889966800343, 0.014563164786522975, 0.012430151655280497, 0.025847211290965788, 0.04562027781503275, 0.05885605118237436, 0.02534458621084923, 0.0385757415642729, 0.025161437151837163, 0.036471448620432056, 0.04563477938063443, 0.05683979550667573, 0.04554473460302688, 0.05909547173359897, 0.030796284299867693, 0.03717319377756212, 0.055800777627155185, 0.07169958465965465, 0.004843278002226725, 0.050654261794989, 0.11986890225671232, 0.01757535388605902, 0.050427201713318937, 0.052188692934578285, 0.034544747904874384, 0.0416276902979007, 0.038481574156321585, 0.016653626880724914, 0.10031078025349416, 0.03872339555528015, 0.02385759500612039, 0.02456141446600668, 0.08592910118750297, 0.031180996957118623, 0.061824137228541076, 0.05184634392207954, 0.046396868565352634, 0.05818160221679136, 0.0938672166375909, 0.0587801517394837, 0.011939785927097546, 0.038645629610982724, 0.03362470743013546, 0.04000992339570075, 0.0031990700017558993, 0.036623993364628404, 0.03181626794685144, 0.036467418758547865, 0.10142222803551704, 0.010902476842602482, 0.04327852730057202, 0.056338485883316025, 0.010427002307551447, 0.024428365941275842, 0.0513067765859887, 0.00538134388079925, 0.049580162594793364, 0.07561323363916017, 0.03664684780233074, 0.03830717316304799, 0.012598564444488147, 0.025369344257342163, 0.043686285498552024, 0.0384382141783135, 0.014288372549344786, 0.015127132082852768, 0.17142946366220713, 0.09860395934083499, 0.05985206531477161, 0.04247787241183687, 0.03836125717498362, 0.04038881575979758, 0.031624526673112996, 0.040983242652146146, 0.04677229138906114, 0.06328282848699018, 0.036214216524967924, 0.09096767535083927, 0.009708664583740756, 0.06807521742302924, 0.011625157985690748, 0.037188979258644395, 0.0495937661617063, 0.032229963326244615, 0.02504804255295312, 0.0700900964147877, 0.08075815014308318, 0.0791039846080821, 0.05511065821337979, 0.03176461446855683, 0.012881216953246621, 0.0284659238968743, 0.06757171475328505, 0.0316391544038197, 0.06082155879994389, 0.045442180926329456, 0.009185490362142446, 0.05700501242245082, 0.041545816566213034, 0.017014830154948868, 0.0328795614768751, 0.07507224509026855, 0.0677208715933375, 0.020587133876688313, 0.017658515243965667, 0.01597903319634497, 0.0778617629839573, 0.05841140453412663, 0.029590908452519216, 0.034432883985573426, 0.05782171996543184, 0.05024362777476199, 0.04942440064041875, 0.04497637564782053, 0.11151205224450678, 0.03616514572058804, 0.053269274794729427, 0.03177037353452761, 0.03214467942598276, 0.023840223184379283, 0.0869865354616195, 0.04162063618423417, 0.036485653326963075, 0.038100395977380686, 0.03896883121342398, 0.014380981447175145, 0.01802184106054483, 0.06850141056929715, 0.07607900552102365, 0.03728890202182811, 0.04383054045320023, 0.003110870388809417, 0.006531639846798498, 0.01130298333009705, 0.0033451838044129545, 0.02744844870903762, 0.08330650714924559, 0.021135720162419602, 0.015759364905534312, 0.01364067429676652, 0.025684560350782704, 0.025656570251157973, 0.023356118399533443, 0.023384557498502545, 0.03759952051041182, 0.01723982521070866, 0.008947384339990094, 0.02357028552069096, 0.006518133686768124, 0.028661554024438374, 0.022929908554942813, 0.0564449024386704, 0.03766592788451817, 0.01444750014343299, 0.017414760550309438, 0.042728703483589925, 0.020808963672607206, 0.017148171828011982, 0.013687510308955098, 0.055165814628708176, 0.01631170274777105, 0.04675772303016856, 0.02183005683036754, 0.036109536595176905, 0.07718531021964736, 0.029926793358754367, 0.016722997279430274, 0.02485446817445336, 0.058450745782465674, 0.045693843203480355, 0.07546262218966149, 0.05083687836304307, 0.09350535285193473, 0.01671914738835767, 0.07581687896163203, 0.049172612198162824, 0.04971414622559678, 0.048386729758931324, 0.05807770154206082, 0.00942155733355321, 0.038374838477466255, 0.00981787810815149, 0.09884221843094565, 0.05429539414762985, 0.01693411231826758, 0.09486511582508683, 0.021903945053054485, 0.0500623433617875, 0.03687910291773733, 0.10364319401560351, 0.02729259584157262, 0.03393568214960396, 0.012589537145686336, 0.06592142322915606, 0.0335600737889763, 0.028763929585693404, 0.10281152106472291, 0.041685856122057885, 0.04109837202122435, 0.04791066428879276, 0.026501635256863665, 0.10226521131698973, 0.013648257190652657, 0.055373823779518716, 0.06350488649331965, 0.010503307148610475, 0.029056129824311938, 0.07738931177300401, 0.057810068246908486, 0.004267443764547352, 0.07497238912037574, 0.08588326614699326, 0.0033272936389039387, 0.01133944782850449, 0.07447425959981047, 0.03639204252976924, 0.026660651528800372, 0.016853364795679227, 0.04329251678427681, 0.03362106348504312, 0.006117717648521648, 0.1000326604116708, 0.049309048627037555, 0.05735327264119405, 0.07738501473795623, 0.02748951916146325, 0.01895721987239085, 0.048802725796122104, 0.04823233335628174, 0.023107942361093592, 0.008773134559305618, 0.010615659957693424, 0.04135595663683489, 0.049435098699177615, 0.04302893561543897, 0.007473087571270298, 0.06672005576547235, 0.009544999684294453, 0.013603407351183705, 0.05984668474411592, 0.02946356889879098, 0.03697437612572685, 0.03977796885010321, 0.058099372254218906, 0.06442302707000636, 0.05789085844298825, 0.04233166931953747, 0.019390270463190973, 0.05388528334151488, 0.03603542943892535, 0.03249484325351659, 0.08165370716596954, 0.023422288286383264, 0.0798676248814445, 0.023398847552016377, 0.029893261271354277, 0.0509114790474996, 0.03589491119782906, 0.019880334693880286, 0.029529456769523676, 0.023374915144813713, 0.04646090848837048, 0.15721838950412348, 0.1904227296472527, 0.15046301996335387, 0.2052349879522808, 0.09872229478787631, 0.10135343836736865, 0.19750541599933058, 0.10619561799103394, 0.17334372969344258, 0.13384878257056698, 0.11864700805745088, 0.07966862540342845, 0.20958624430932105, 0.18337550311116502, 0.107191097777104, 0.18873471475671977, 0.15947598789352924, 0.08570502453949302, 0.11864933097967878, 0.06755637456080876, 0.12107432819902897, 0.16851461929036304, 0.12565780256409198, 0.09871137037407607, 0.1355498592602089, 0.14152962510706857, 0.14150103757856414, 0.17053976218448952, 0.30134648142848164, 0.1506352427531965, 0.27840444061439484, 0.0986607039521914, 0.13343926548259333, 0.16932338214246556, 0.1501399779226631, 0.10995766846463084, 0.09715424064779654, 0.07588558699353598, 0.17149357037851587, 0.10780280557810329, 0.18271760403877124, 0.13616624259157106, 0.18495148338843137, 0.23083528300048783, 0.1267765456577763, 0.1350422896211967, 0.19320784660521895, 0.10965833062073216, 0.17523072921903804, 0.10724294421379454, 0.1605424689478241, 0.11524553745402955, 0.13202240166720003, 0.1389167457818985, 0.17025261040544137, 0.2487952567753382, 0.12868769466876984, 0.1478166104061529, 0.20476817706367, 0.13556556310504675, 0.11363824596628547, 0.09549593392875977, 0.15596399665810168, 0.11403139869798906, 0.1169889685115777, 0.2649194689001888, 0.13512379227904603, 0.24250168120488524, 0.11814826255431399, 0.13047913525952026, 0.07795324752805755, 0.13504548085620627, 0.16967878182185814, 0.17424791789380834, 0.15168256155448034, 0.1542476614122279, 0.1263850776012987, 0.11340469951392151, 0.16195468691876158, 0.16217448137467727, 0.08232846041209996, 0.101142445782898, 0.19762962183449417, 0.13111476990161464, 0.22166705777635798, 0.17078441858757287, 0.24217149970354512, 0.2695915853837505, 0.13796508981613442, 0.16660020482959226, 0.08926577487727627, 0.12050325298332609, 0.147824996674899, 0.1309855916770175, 0.13298708974616602, 0.12911273748613894, 0.1335333994938992, 0.19376260199351236, 0.1425328603363596, 0.1342929876409471, 0.08060050313360989, 0.11948442523134872, 0.13078028394374996, 0.1810456343810074, 0.10636200750013813, 0.061549037927761674, 0.12609661964233965, 0.19106780440779403, 0.10095729478052817, 0.17442653799662367, 0.18039288581348956, 0.09914712980389595, 0.10495931870536879, 0.13696057809283957, 0.14816464798059314, 0.1583279002807103, 0.14694139565108344, 0.15745912736747414, 0.1457397101330571, 0.176890364382416, 0.08718226206838153, 0.23705685540335253, 0.2251217106822878, 0.14692241151351482, 0.1783469330985099, 0.16046059521613643, 0.11936744791455567, 0.10043078553280793, 0.23005052120424807, 0.20183243381325155, 0.09810405608732253, 0.13590114744147286, 0.22820094076450914, 0.14743296458618715, 0.2431143241119571, 0.1579208322800696, 0.16816336079500616, 0.18086983443936333, 0.21679068740922958, 0.0959013840474654, 0.19147202256135643, 0.23813719977624714, 0.1212491856131237, 0.12644995615119115, 0.11547211513970979, 0.08349475290742703, 0.1001133763929829, 0.09216979131451808, 0.11729222489520907, 0.12567337282234803, 0.1843030986492522, 0.10074384568724781, 0.12953283759998158, 0.10681233528885059, 0.12210486704134382, 0.1343194377841428, 0.2067362191155553, 0.2814405073877424, 0.18375097046373412, 0.11006093831383623, 0.11824884582892992, 0.08839154717861675, 0.1548276052926667, 0.13707485399208963, 0.12936678947880864, 0.2431301021715626, 0.10380802501458675, 0.2076847877469845, 0.08272612540167756, 0.14870473853079602, 0.12162001454271376, 0.10356684928410687, 0.13931369088822976, 0.18399932276224717, 0.13284188113175333, 0.12975456163985655], [0.025497151364106685, 0.06845373500254937, 0.060506580193759874, 0.04009907388535794, 0.07666767705813982, 0.05671672886819579, 0.005844174538651714, 0.05662620169459842, 0.02169728290027706, 0.05158697815204505, 0.037646620912710205, 0.017881647509057075, 0.061499499570345506, 0.022456997212429997, 0.05631725303828716, 0.06581237947102636, 0.07585197512526065, 0.03916594934707973, 0.017198394816659857, 0.005306210241542431, 0.011596086205827305, 0.07869999652029946, 0.037388450000435114, 0.05404910130891949, 0.04195840243482962, 0.03673111496027559, 0.02849431290087523, 0.01604934241186129, 0.03971142788941506, 0.02125052113115089, 0.01068200146619347, 0.04108774446649477, 0.009093011340155499, 0.025752058681973722, 0.019559977372409776, 0.07073509696056135, 0.08728855988010764, 0.014724639422638575, 0.04499180489801802, 0.03583835954486858, 0.019804411131190136, 0.05232077666732948, 0.04264252900611609, 0.03400192625122145, 0.036499757843557745, 0.04000259097665548, 0.0327424756687833, 0.08467648207442835, 0.03708562406245619, 0.04200418552500196, 0.031672068653278984, 0.02091018519422505, 0.08165296501829289, 0.03743650406249799, 0.05047432438004762, 0.046846695404383354, 0.029380559681158047, 0.07414269028231502, 0.033277515904046595, 0.024338189432455692, 0.07763608329696581, 0.02297999795700889, 0.025822228744800668, 0.03675545369333122, 0.05411539365013596, 0.03197721751348581, 0.06727691143169068, 0.045093924418324605, 0.022352575178956613, 0.014339269037009217, 0.06765962214558385, 0.0069910185902699595, 0.015826711096451618, 0.05561295860388782, 0.04670218440878671, 0.025217708644049708, 0.023677613062318414, 0.037055529974168167, 0.04615828664100263, 0.09810707662836649, 0.05708706798031926, 0.05565774721617345, 0.02392002261331072, 0.04060645056597423, 0.041754768244572915, 0.023456302769773174, 0.030323706923809368, 0.015681135118938982, 0.021480304894794244, 0.10910986122325994, 0.0407953308604192, 0.07743645299342461, 0.03412528232729528, 0.05234117459622212, 0.017284676905546803, 0.07326103368541226, 0.01729146570141893, 0.02148737941752188, 0.06426691630622372, 0.04562012567475904, 0.01846556373493513, 0.0312432149075903, 0.03226115208235569, 0.03436711856920738, 0.03538009819749277, 0.05847721819009166, 0.0579385859600734, 0.056284413003595546, 0.011502579309308203, 0.05327101142029278, 0.02566472645412432, 0.0542860653513344, 0.06195319670950994, 0.10992085793986917, 0.01392020050843712, 0.017938956152647734, 0.017016468445945065, 0.0197865365043981, 0.062151884485501796, 0.03668649333121721, 0.034543909277999774, 0.04618540842784569, 0.0434579118154943, 0.02115603088896023, 0.020179062121314928, 0.05274688075587619, 0.02095617794111604, 0.06154405069537461, 0.045626033170265146, 0.030338987744471524, 0.05822763021569699, 0.07342063254327513, 0.03714947473781649, 0.03208645051927306, 0.06632259115576744, 0.007012276482782909, 0.032853853481356055, 0.05740943466662429, 0.052102499903412536, 0.05170207041373942, 0.027124987354909535, 0.06214033666765317, 0.040656653145560995, 0.055792009152355604, 0.019659920544654597, 0.027305657640681602, 0.028697472116618883, 0.03540254074323457, 0.02341064770007506, 0.03254137220210396, 0.03651961771538481, 0.03731773445906583, 0.05477183440234512, 0.017943822786037344, 0.00572566561459098, 0.0823714752914384, 0.022673489111184608, 0.08323832604219206, 0.03814701769442763, 0.041689366480568424, 0.06892677251016721, 0.04661148283048533, 0.060404631367418915, 0.13588330621132627, 0.058401838250574656, 0.017889013324747793, 0.04254910003510304, 0.10163395534618758, 0.023628013477718923, 0.019632637340691872, 0.005800327062388533, 0.03572604291548487, 0.01704783531749854, 0.005753170999014401, 0.0790579269232694, 0.03842325990262907, 0.011534987042978173, 0.03644728429208044, 0.06837156441179104, 0.05867214327736292, 0.09738092223415151, 0.04760176387208048, 0.022336192268994637, 0.017063923223759048, 0.05640706775011495, 0.02726854098000331, 0.0289903402881464, 0.044271480073803104, 0.02568069932749495, 0.018908727943198755, 0.04955933050950989, 0.04056005891470704, 0.05433207108580973, 0.04488089463848155, 0.09170292105409317, 0.003279520897194743, 0.016569485887885094, 0.0785399969026912, 0.04526723445451353, 0.0382807452842826, 0.023192031403596047, 0.009671437528595561, 0.051945431769127026, 0.03285375329141971, 0.002837134320543555, 0.03556990246579517, 0.07832383154891431, 0.012527332182799, 0.031712178024463356, 0.05538664438063279, 0.017258551451959647, 0.05217555692070164, 0.019208666926715523, 0.00428309148446715, 0.029341502304305322, 0.023682637402089313, 0.06925340654561296, 0.01125716777096386, 0.019504689225868788, 0.11205231348867528, 0.036439235700527206, 0.024766169299255125, 0.061902515444671735, 0.0642021861858666, 0.012873268551629735, 0.008923278455768013, 0.039300367134273984, 0.03202806205081288, 0.07158393578720279, 0.07250075534102507, 0.04975366187863983, 0.029263526703289244, 0.005103569601487834, 0.01647590848733671, 0.014473404808086343, 0.06111880749813281, 0.021081042432342656, 0.0020112684433115646, 0.025017362168000545, 0.041767596267163754, 0.06944470995222218, 0.01713246056169737, 0.012224895872350316, 0.02561504894401878, 0.05142496360349469, 0.03344756791193504, 0.015566211695841048, 0.02881969827285502, 0.034475479551474564, 0.05101951348478906, 0.07422269380185753, 0.028583569146576338, 0.04695632174843922, 0.042521510695223697, 0.07256931494339369, 0.0141000711300876, 0.09296707314206287, 0.05457232655317057, 0.02321670595847536, 0.05487932336109225, 0.027714770258171484, 0.04561816269415431, 0.0227500676191994, 0.03815697731624823, 0.037037844595033675, 0.04245232768880669, 0.042793600587174296, 0.0769421381119173, 0.019618753613031004, 0.015331904542108532, 0.021022663240728434, 0.018267096747877076, 0.050118950675823726, 0.04388647241285071, 0.008112142586469417, 0.03795872369664721, 0.0576608742994722, 0.043150929850526154, 0.008676717516209465, 0.029640309512615204, 0.04439732605533209, 0.01516539536169148, 0.04748205545183737, 0.049954479618463665, 0.0590001873933943, 0.018597356174723245, 0.01798586545191938, 0.04276293133443687, 0.01890702285891166, 0.056194865464931354, 0.006289487264439231, 0.028184863294882234, 0.026295691131963395, 0.022045613623049576, 0.1177125476533547, 0.037421364249894395, 0.049300361788482405, 0.03285442122432869, 0.07579060693387873, 0.01805907832022058, 0.061651654687011614, 0.029000734066357836, 0.07593182279379107, 0.09228478709701449, 0.024626793965580873, 0.03427698844461702, 0.0978771221707575, 0.0945725389465224, 0.04768413113197312, 0.034311906492803246, 0.09368406201247126, 0.003978661115979776, 0.0126966856441868, 0.037377306653070264, 0.011509068463055883, 0.012582310482684989, 0.01178396738396259, 0.02514430096198339, 0.05783736443845555, 0.06380498874932528, 0.014892157923895866, 0.049437347406637855, 0.031050082106958143, 0.03538859949912876, 0.02509642501536291, 0.044218153052497655, 0.01531514220914687, 0.050955061669810675, 0.04452266737644095, 0.09568688852596097, 0.048806399427121505, 0.07218923885375261, 0.018828935935744084, 0.005122094071339234, 0.028116893699916545, 0.02490030321496306, 0.036110312139499, 0.009216888774972176, 0.035710305674001575, 0.06686873020953499, 0.020008199317089748, 0.048682290071155876, 0.01752012325596297, 0.010754633603937691, 0.0318184016214218, 0.09145947435172275, 0.030395563517231494, 0.04031972181110177, 0.025067043388844468, 0.010355321974202525, 0.02355431079195114, 0.02930643953732215, 0.14122169319307432, 0.20850346569204703, 0.22465550835477188, 0.16072616534074768, 0.16225113038672134, 0.13207001786213368, 0.10921407360001467, 0.11704126023687422, 0.1252470535109751, 0.13202900678152218, 0.10689089162042364, 0.11484530463349074, 0.13225279399193823, 0.1081941623124294, 0.14110127231106162, 0.13033780065597966, 0.2167683487641625, 0.20133149897446856, 0.15968732186593115, 0.10154079354833812, 0.16150758747244254, 0.20466691843466833, 0.1521612171200104, 0.1099903674912639, 0.15188145713182166, 0.0843015342252329, 0.11373174915206619, 0.1695327420020476, 0.17070845235139132, 0.14477174176136032, 0.14706776855746284, 0.08938635903177783, 0.10810597290401347, 0.11813579447334632, 0.13672387751284987, 0.1568707823753357, 0.08947554291808046, 0.07266908927704208, 0.09274620999349281, 0.11667602710076608, 0.20642689196392894, 0.14680705207865685, 0.18204921099822968, 0.18201606668299064, 0.0878938332607504, 0.14662641333416104, 0.11691787076415494, 0.14147234614938498, 0.12426729983417317, 0.15257532068062574, 0.08134780131513253, 0.14754961535800248, 0.18488261208403856, 0.13546629343181849, 0.1227092275803443, 0.13634095899760723, 0.10720246005803347, 0.1672216347651556, 0.13734797918004915, 0.15126504411455244, 0.15779091190779582, 0.12804379250155762, 0.10646066119079478, 0.11450399091700092, 0.24703455594135448, 0.12244345707586035, 0.1646871113916859, 0.09166398056549951, 0.12339938781224191, 0.10409554786747321, 0.09535579418297857, 0.18427989911288023, 0.0991231287480332, 0.1810468069743365, 0.10218042836640961, 0.166193789918907, 0.17133050569100305, 0.21317093633115292, 0.14383215311681852, 0.2179088961565867, 0.13882712402846664, 0.1078964868793264, 0.11537800339283422, 0.1589452929329127, 0.12853898311732337, 0.07346349899307825, 0.16413875331636518, 0.17499882291303948, 0.0956581970967818, 0.15288874448742718, 0.14701295353006572, 0.24794123775791377, 0.13854025426553562, 0.08995158612378873, 0.08162733123754151, 0.28029003005940467, 0.17252859921427444, 0.13351756206247956, 0.09255288794520311, 0.08822919495287351, 0.1340783288469538, 0.159868880873546, 0.1770471505005844, 0.12287518664379604, 0.0996684365964029, 0.1534099251148291, 0.10068823656183667, 0.1203515802626498, 0.14185492327669635, 0.1178538377280347, 0.10724636551458389, 0.12769263790687546, 0.12162705010268837, 0.22342268232023343, 0.17945354949915782, 0.18247417960083112, 0.09734981882502325, 0.08154283030307852, 0.17741185671184212, 0.14863264630548656, 0.059629168681567535, 0.12074284051777795, 0.14822773053310812, 0.08184321457520127, 0.20256469608284533, 0.14045104704564437, 0.20044809090904891, 0.14515615941490978, 0.13612696813652292, 0.11643942299997434, 0.1372150902170688, 0.11870484362589195, 0.13310841604834422, 0.11012742732418701, 0.15840918029425666, 0.0914861990895588, 0.09331469511380419, 0.12326398296863772, 0.09346168488264084, 0.13714094966417179, 0.12281176270334981, 0.0961543079756666, 0.11621462646871805, 0.2085912914481014, 0.09597759519238025, 0.08912838849937543, 0.1512142366846092, 0.15701456606620923, 0.14041588408872485, 0.13744211319135502, 0.06765210418961942, 0.10954550190945156, 0.1455392115167342, 0.1933816575910896, 0.15692007582401857, 0.17544857924804091, 0.08304970178869553, 0.10253472966724075, 0.12253378386958502, 0.13051959715085104, 0.08784738965914585, 0.13741823087912053, 0.17976624600123614, 0.26020784047432244, 0.16330686514265835, 0.1365131075726822, 0.16284625860862434, 0.16906109231058508, 0.1158483988547232, 0.20319317642133683, 0.11283290441497229, 0.08431939029833302, 0.08669778806506656, 0.10368240909883752, 0.1502849193639122, 0.13793256890494376], [0.012510625510913087, 0.045726111784460954, 0.0404288917343365, 0.06082220817916095, 0.02778813155600801, 0.03301619457488414, 0.03500863844237756, 0.06337881786748767, 0.034471234466764145, 0.05222711763053667, 0.03291847970103845, 0.03038022889086278, 0.03468472066742834, 0.0363353053398896, 0.05646037621772848, 0.05159969485248439, 0.06251841638004407, 0.02709613265324151, 0.02699322831176687, 0.02631664196087513, 0.015381981884274865, 0.1113601123506669, 0.041276123811258, 0.05130782301421277, 0.07750695702270605, 0.0128131879864668, 0.002784163762044045, 0.0431528223271016, 0.0528524030232802, 0.029015350664849393, 0.03099675137491431, 0.026814398552232888, 0.0671792151115369, 0.026933478002320044, 0.05333241671905853, 0.049627455955487676, 0.0434237618901534, 0.0499650069832569, 0.050975351987290196, 0.04051365984196309, 0.05666026998369489, 0.03375606014742516, 0.06064211862394586, 0.07260018086526543, 0.062407643417827785, 0.00981997189228423, 0.04251913582265843, 0.06285877272603102, 0.044345798742142506, 0.03088304692937527, 0.011768920339818578, 0.04132052279601339, 0.003706313327711541, 0.015707900674897246, 0.0502086577762384, 0.016788363791420124, 0.040664078333065845, 0.05144630034919828, 0.04636396173737012, 0.0037633142119375407, 0.05498485676071141, 0.08365484900423326, 0.0518398018903099, 0.029941936882096343, 0.0325093596620718, 0.020872584282187745, 0.03968849923694506, 0.06266358788707294, 0.03537429089192301, 0.06603581045055762, 0.03622411306423601, 0.03202818079444114, 0.014023927706148243, 0.015519746757490793, 0.037091253252583556, 0.03008971889357781, 0.0644240363908466, 0.08006141448277049, 0.03694847517181188, 0.0357020455703605, 0.04253692510246765, 0.010095701090904186, 0.04708200074674096, 0.0346531459945254, 0.04948043279000558, 0.012637802719837055, 0.03391446785826702, 0.04032545861264225, 0.028187753960082773, 0.06764529869542457, 0.13133886881405488, 0.033866384110297076, 0.03283778227341827, 0.032816178354551084, 0.03141257300740108, 0.07192139775725082, 0.03505538261379115, 0.0166166920462274, 0.05219729071541224, 0.017032719624694437, 0.052541791956173256, 0.03225292166462168, 0.05703124734282028, 0.018313109903829172, 0.06906941329361871, 0.04882754321442917, 0.027166979925823398, 0.03816097378148697, 0.03631426174251828, 0.022166017806739546, 0.016757772464188747, 0.05491445292136632, 0.01003458059130935, 0.03277206138591282, 0.04666817178076599, 0.03005601611221209, 0.016979964057100005, 0.0695805971918162, 0.040200354778789915, 0.010691725456126733, 0.035356256703380495, 0.09409058082383126, 0.07743621550616808, 0.08601568013546057, 0.03417214895307552, 0.02191196024796227, 0.029589027108158916, 0.03287489336798899, 0.07595491100801155, 0.018282474047737196, 0.06624047251534648, 0.05198862847464625, 0.04996238349121995, 0.024246584289357997, 0.05941851377428975, 0.054533155998797156, 0.007968070385686588, 0.05509476141014602, 0.04446090213605203, 0.041019515119842254, 0.019427476181590464, 0.0753717907355167, 0.05314062349498272, 0.02463237862684764, 0.04639759958081413, 0.01957957192644244, 0.01558568750624545, 0.02712733439693693, 0.018716344711720012, 0.03976619838795159, 0.04190691593976226, 0.020916499015584122, 0.0032984349945763825, 0.03126399504253641, 0.016686171911715064, 0.05389930622186512, 0.024711970254429616, 0.024513160024071112, 0.03673795756185427, 0.04507242440013215, 0.050781009485945106, 0.04734587506391108, 0.10539547889493406, 0.06652320851571858, 0.018513499053369742, 0.030442016395682003, 0.036377140204422176, 0.041647353500593454, 0.014942457910365192, 0.04147433290199842, 0.06860138528281823, 0.026985983095073607, 0.015171043105510762, 0.05976627675408963, 0.022829462577647064, 0.023447987005056348, 0.007092027208273066, 0.04757158072607126, 0.04064021828526165, 0.01682177713519195, 0.018408652140351478, 0.02791369923215825, 0.011568786303541856, 0.08057521074078977, 0.03715888145961799, 0.08763106845435686, 0.013100101350573823, 0.06734924856573343, 0.0763151198043488, 0.012218062547617592, 0.05777736550953705, 0.05387124190747272, 0.05829269801324699, 0.04226402255881112, 0.05065796140115708, 0.08053739089518785, 0.03221458973712288, 0.04242919123498723, 0.0295000380356214, 0.05211107541981619, 0.11676623515086249, 0.036490291749942116, 0.09144676136202179, 0.02531676866055932, 0.0698467090842314, 0.01761810159223387, 0.04052875883644447, 0.023938763697515242, 0.05728040116082411, 0.01516931946753175, 0.06004106435284484, 0.04393713883473538, 0.041617448659962974, 0.08366723544895649, 0.0421793731948128, 0.01018552693494712, 0.0170384824014036, 0.024486114307364915, 0.032061488382169046, 0.03946784017898608, 0.01365699412417598, 0.03683377995912451, 0.018339174130233005, 0.022770296709495597, 0.037087360688019544, 0.04702161219029222, 0.05440740649646614, 0.02397369287791662, 0.01655657066294225, 0.028077867864340078, 0.03167207607475575, 0.05520620230527129, 0.03827428488875739, 0.058185669186059386, 0.04331505951995496, 0.043280642421450466, 0.022734113299520686, 0.06602331268368289, 0.0011607712644945423, 0.04638694605091587, 0.05816326374770142, 0.03464119370619301, 0.1048611177247949, 0.08916570368455723, 0.061371404881356284, 0.030087518425716553, 0.037282783014234155, 0.0238895073562162, 0.05520483675354626, 0.018959464869112708, 0.015840331361687277, 0.023240068767336197, 0.014125729958323063, 0.01797872599127004, 0.03318727445730474, 0.0319287292950321, 0.015820833286852576, 0.01922913721500663, 0.052953023405279964, 0.08900446468032897, 0.04756722802994773, 0.06459274140070193, 0.03027284754352877, 0.0539662145456532, 0.006413877244995092, 0.0511135213309899, 0.045221121108625084, 0.08688185553182848, 0.008177354175131768, 0.048953415171126835, 0.03143186513625551, 0.033016420929925516, 0.04962216815329157, 0.03905244899215177, 0.06082909902033862, 0.06702253289404325, 0.01637885783566162, 0.043110698024975136, 0.028478048734541517, 0.06097141325881239, 0.030185600662662182, 0.07695267660892569, 0.012009427209704882, 0.03911257037543692, 0.06234496904653497, 0.03308030871266965, 0.03735970662091859, 0.02294290727149928, 0.012550221872515976, 0.015166336961556226, 0.028666973557847086, 0.039330342478933744, 0.005770988573203795, 0.04301082721212879, 0.043564666048041545, 0.033414019126212224, 0.018503266692277975, 0.021253463746688794, 0.09807511974941008, 0.046055881393840536, 0.025347389673697762, 0.025987970730056986, 0.003896011376127717, 0.03278870033682324, 0.07588194304844365, 0.022313304434646852, 0.053958473945385776, 0.06446675441111438, 0.10074647289002314, 0.0289155559221399, 0.04992108668375295, 0.023182723016361706, 0.036966672632843256, 0.02834177743352484, 0.12395404672133736, 0.06268446450121701, 0.02952742885099724, 0.01306626219957252, 0.10294926367350854, 0.03768832961213775, 0.04282673377019819, 0.052482011960819364, 0.009491103992331773, 0.03441025590291247, 0.017510679426777642, 0.05846692460181657, 0.02069883452350041, 0.03179899445967749, 0.03909372724592686, 0.024791383766569197, 0.021429529006127268, 0.030134756125335116, 0.02313798264367506, 0.04307101909944322, 0.03631395004049409, 0.016418349368905183, 0.031044549396028742, 0.02384924027865054, 0.06880534972879104, 0.010719364890974248, 0.024864490878826473, 0.06655202611000277, 0.04746236627397593, 0.07478338637156412, 0.026775916339829564, 0.08171930559910834, 0.015453325468115509, 0.07214525176095776, 0.01986349350772798, 0.04208160637062974, 0.024474950550938956, 0.06684808366117068, 0.11481124005513266, 0.09128593053901568, 0.15755294967675582, 0.12688072834862396, 0.13855659635737538, 0.08133410126902163, 0.11926514285732992, 0.15741295093903318, 0.15865696856053546, 0.19240040477598086, 0.1262830026098527, 0.10878940185648389, 0.17019555409206077, 0.2031752758193761, 0.12414909797371365, 0.1609311020001769, 0.20802457263926044, 0.15589950402500108, 0.10925366717856377, 0.13093184534227476, 0.17639781581237912, 0.22567372012417763, 0.13077188283205032, 0.15296656609280035, 0.23696880700299516, 0.16436433652415872, 0.11955625028349459, 0.18703164911130443, 0.1734261229285039, 0.08777320457738824, 0.1836499196360819, 0.14702672779094428, 0.19693756912602112, 0.07306924046133645, 0.15920931939035654, 0.1343242172151804, 0.11630686800344847, 0.14968036586651579, 0.1668587839230895, 0.09118081274209544, 0.08027591742575169, 0.09866272259387188, 0.1382722647394985, 0.11512326120282523, 0.14444587955949828, 0.12778907257597893, 0.15745817741844803, 0.12637725536478683, 0.13685065117897466, 0.11611961672315374, 0.08648391594761051, 0.17075149691663682, 0.07890692955697887, 0.13818130712024868, 0.1326309033902362, 0.1389961110544391, 0.14282691408880055, 0.29106447065714747, 0.12385801281197928, 0.14116803591605276, 0.1643232660717331, 0.20918034890200943, 0.13100413052598014, 0.10791558976052329, 0.15130178042454645, 0.12892944185296074, 0.16610367834800854, 0.1868447763263248, 0.23355805955361575, 0.1949723917641677, 0.1504491566447541, 0.2720251173013821, 0.13919895485742018, 0.12064417940564454, 0.12801514560123906, 0.12224909602082334, 0.13709317019674927, 0.2550462627550587, 0.14075742044951767, 0.11411989980842918, 0.11603159800870344, 0.10419532962259836, 0.20746765017975122, 0.2079150316421874, 0.1107205443258863, 0.2116084037697874, 0.08649832845549099, 0.16424727014964446, 0.07422323556966148, 0.11824246335891075, 0.1954073942033574, 0.2213611890329048, 0.07883694503107108, 0.16263957048067823, 0.10235498892143369, 0.13089081941870973, 0.1614630437688902, 0.1000748218211811, 0.21494711836567149, 0.10716110758949071, 0.11516711470903829, 0.1395001183846034, 0.1829173308215104, 0.12609329482074827, 0.135149915877264, 0.20113205420784652, 0.07475769321899861, 0.16130667325342074, 0.13750155922025442, 0.11531813433975913, 0.2229762211209163, 0.1510759152006358, 0.16235320537816733, 0.11521156193339266, 0.12402139662299305, 0.17424635938368738, 0.08576860433095135, 0.11818712140666321, 0.14876914210617542, 0.13139916089130566, 0.11166137977852486, 0.18120740773156285, 0.19094419229077175, 0.09012392765725963, 0.12004837582935579, 0.07335115267778747, 0.11126637909910642, 0.15923099010251462, 0.23323244968196377, 0.07411373167997226, 0.16264472098555416, 0.17926315893419087, 0.22582082863664255, 0.13600749720353633, 0.13594744261354208, 0.18002580472966656, 0.12763099512085319, 0.16802575177280232, 0.22371260973159224, 0.0842818153614644, 0.11417965011787601, 0.1418771580210887, 0.2718678710516542, 0.09022900834679604, 0.2502081129932776, 0.1310135261155665, 0.1815126827568747, 0.1275267530581914, 0.09553960189805366, 0.12828978477045894, 0.09701381888589822, 0.10577719513094053, 0.10200810909736902, 0.06517848887597211, 0.12783186481101438, 0.17294246528763324, 0.1151541642320808, 0.09129007172305137, 0.15397814306197688, 0.14544587902491912, 0.061449267304851674, 0.09870646477793343, 0.3528054873459041, 0.14541255659423769, 0.11704532720614225, 0.23287794057978317, 0.13783448666799814, 0.1952328410698101, 0.1042473096458707, 0.1042261064867489, 0.1065937356906943, 0.15253764926455915, 0.07997265362064354, 0.19996284507215023, 0.13366790633881465, 0.20814526069443673], [0.057014040648937225, 0.043102686540805735, 0.03710251534357667, 0.056783815307426266, 0.04685536739998497, 0.04754318615596276, 0.019891784177161753, 0.04613338016497437, 0.020650400110753253, 0.02179450610128697, 0.06614839425310493, 0.040046418507699855, 0.07507800415623933, 0.042848074226640165, 0.039206645014928654, 0.02718919797189301, 0.052464972250163555, 0.02188232814660296, 0.0255362328607589, 0.05086795208626427, 0.07849347908631898, 0.016191348659049254, 0.056500455903005786, 0.02791953807900427, 0.01658131386648165, 0.017038328405760694, 0.05345307137758937, 0.04338161161285825, 0.03786895722441841, 0.027725227118935436, 0.03147780036670156, 0.04156579147092998, 0.014805374885327183, 0.027390119612391572, 0.07760336942737922, 0.055043000320438296, 0.06827236153185368, 0.0175755134478095, 0.1205288125493098, 0.06720719407894649, 0.038027891860110685, 0.029880739384680055, 0.07115420259651728, 0.02640567927301163, 0.045412984836730175, 0.049803871879703365, 0.05803985201055184, 0.03579028692911379, 0.02744895151408855, 0.06677982833934948, 0.09306674357503653, 0.04072094910952728, 0.06269792706007138, 0.09847895940765738, 0.07986354306922294, 0.0333833053446142, 0.044749757144018076, 0.014447252451645909, 0.03417696549149696, 0.03709088217874523, 0.07956248344271444, 0.06705491279717535, 0.0054929211455601035, 0.019318504782859236, 0.0587354447634425, 0.046896627100068145, 0.0214109975786414, 0.035543196281651035, 0.02538920412916923, 0.04305383095925208, 0.04989975735952612, 0.04527549084741622, 0.048610060548526235, 0.04584219481330365, 0.031960055348463356, 0.04497499525314197, 0.041444784292252734, 0.05300226490362547, 0.021788542944705114, 0.009104364344239002, 0.09416837274329737, 0.04985750318155624, 0.06243735901080072, 0.052896345587214455, 0.008395399017899763, 0.01077940834875335, 0.055281430104514584, 0.011211997880309355, 0.017810477402235847, 0.16735018958570436, 0.05272765542031266, 0.04044203145895153, 0.04720156815892551, 0.054679678214597516, 0.02685004576051142, 0.04022628541861195, 0.013359515360207297, 0.09910919863614254, 0.05596422080998309, 0.03665419135359116, 0.047809958559810184, 0.07161133587942459, 0.03554811301000882, 0.0118700806342531, 0.03170158015564084, 0.06621162523515522, 0.03068457623157883, 0.033805450075306, 0.0704231574491132, 0.04962928163877223, 0.015513307698711287, 0.03648329329735134, 0.0030237313512770925, 0.06013058591634035, 0.03323112425277941, 0.025928238974302076, 0.010118662212335039, 0.051215859784861095, 0.033318129935651086, 0.03235174975998234, 0.04983622580766678, 0.049872921299538575, 0.07412849299726076, 0.03889808969688602, 0.023159712727647275, 0.10349453441449441, 0.027600028661254328, 0.03351544844917953, 0.07227454872918315, 0.06502910939161666, 0.03682503374875523, 0.027830124126921874, 0.0186099151687813, 0.06178154166263994, 0.08012114994926378, 0.04567025032883976, 0.03741285181604326, 0.06551331622176804, 0.007360795525528374, 0.012233572506374912, 0.07983186820638366, 0.052255872142268345, 0.017297414015047252, 0.04214452193991747, 0.046079682069830596, 0.04226551427564118, 0.02438832336338237, 0.043211062366026454, 0.014496825133392122, 0.03386527459952049, 0.02764801036391873, 0.007810960505594267, 0.0303503908435232, 0.04164485988439992, 0.016910170634218957, 0.04434497866895981, 0.07469045463949442, 0.0685666453500744, 0.021336330100893974, 0.03443642031925265, 0.041059991854126565, 0.05418839129561093, 0.0327567954082042, 0.011709789723681752, 0.012657174629566725, 0.04912046519166324, 0.03252905255067162, 0.03898780050803907, 0.03464199893642217, 0.16869784070877358, 0.02888920411351137, 0.01492651472290163, 0.013711332321690861, 0.013955641770735383, 0.014390702654054621, 0.024040853531914763, 0.03236237731471192, 0.06550796533701941, 0.0670626905048266, 0.05492669093655422, 0.04605550289852545, 0.05035073081671726, 0.07092326850397512, 0.0311756906012306, 0.009047321018442744, 0.03794414420553949, 0.08999186247820035, 0.028788520648959093, 0.044211303029442206, 0.049438757487223484, 0.05216286990616936, 0.04569924232782796, 0.0648637069389224, 0.03351157814904582, 0.022536210344696883, 0.016353717583115213, 0.03789269110711757, 0.020912224244966637, 0.03067288183956407, 0.07535351905971766, 0.014502089743473334, 0.005817301371280337, 0.04288827636628412, 0.05175718601094559, 0.07845254222047515, 0.06808460559113882, 0.029135829063307028, 0.03402074711630121, 0.01831813424360007, 0.046223896206356585, 0.014808067953708814, 0.022960401547607034, 0.08988414716441184, 0.03472471500572283, 0.07201407715911046, 0.012882197515864391, 0.04841262700210791, 0.03377771601662971, 0.004549779469016357, 0.07729027958703227, 0.031999129423638806, 0.023203454911708832, 0.08820035509415902, 0.019514270352374297, 0.024509189534001052, 0.029486017010640353, 0.011494809950818308, 0.02138460309652146, 0.03688576369313523, 0.052630348727689125, 0.07084040771587752, 0.06845513024018146, 0.05698078872228507, 0.019581837332225405, 0.03367641656950582, 0.07468352298019454, 0.10592192877084017, 0.05161660839803517, 0.014327865010272944, 0.04352439340436831, 0.02740757121500792, 0.028460511784942355, 0.06776413880288601, 0.037437246210174635, 0.03881002645357512, 0.028534071607282385, 0.05331524713255931, 0.01665428553678794, 0.007498581735490006, 0.04591629454807844, 0.06981346086831763, 0.06085229484597221, 0.03367336263181642, 0.015222182646539295, 0.08120230326312594, 0.014710412451677257, 0.022016834991518408, 0.024942011914390605, 0.032450147409690544, 0.05749082971306052, 0.037231211172183976, 0.02024851415626472, 0.059050297204521485, 0.020422692505235318, 0.014375097143783933, 0.01763507265422959, 0.044906335460837, 0.020218171448505018, 0.036010522962897085, 0.08665499583003111, 0.047959085713955574, 0.08332503857673146, 0.015008514619694324, 0.021843814392923377, 0.07055905211018398, 0.0267984831953072, 0.02796331922581885, 0.039779275030014105, 0.0077788088128727395, 0.038007130278856494, 0.036677286989288405, 0.048856331122806296, 0.06830237398389727, 0.10128901252755895, 0.029807847495249007, 0.04278314001567196, 0.009881295554805547, 0.029754481511190534, 0.10114458316820674, 0.061771656255587004, 0.0681076938053593, 0.03486418310785666, 0.022158134343044367, 0.010124247801286401, 0.024724866925680544, 0.030763371905777603, 0.044108352303737774, 0.04859051237872336, 0.02143800989870215, 0.039604981648153625, 0.07732677840976976, 0.039066204699338414, 0.03252475551562384, 0.012871505023213103, 0.026604220474837348, 0.02123540543834679, 0.025894571444950998, 0.04427834865055047, 0.018261942532262765, 0.06046597729437053, 0.04370287249912508, 0.06740754426573403, 0.05809690832393244, 0.07014158662059344, 0.03708518619532697, 0.012613024264283013, 0.054337388573912904, 0.04927450907416642, 0.024688729899935424, 0.046307198572321795, 0.024542940554965753, 0.05495087752933614, 0.015776903710502665, 0.07992419879883528, 0.025657058213255368, 0.04636624384147581, 0.06698693949147128, 0.03156156657496467, 0.06784478799090721, 0.012677780359808821, 0.03787075693253428, 0.02070872735203011, 0.01824350758397486, 0.028492388883023523, 0.025519252521917224, 0.07624517238582484, 0.02275503629789455, 0.05970988095214125, 0.0710359042568598, 0.02153397144866176, 0.04108941058802884, 0.06395075397449546, 0.019107224616163876, 0.05489842995302752, 0.03625798097345978, 0.011895200477738399, 0.03655384927697014, 0.08402445339015685, 0.04235551452438813, 0.006860347721158178, 0.027525051336851902, 0.018192939496657345, 0.13051032030489296, 0.10162003265577368, 0.14419614686630666, 0.1658304492593743, 0.12987664493266493, 0.11149607380502857, 0.16548870509723201, 0.1112286037823651, 0.07190136719145812, 0.06572356665856205, 0.1915001796442084, 0.08285135540063493, 0.1897588637075387, 0.20319354749517515, 0.19029503571800888, 0.1439150658552535, 0.22064844524720684, 0.11314167495584115, 0.09182418798445724, 0.20442246983293444, 0.1977166163851507, 0.15520344371907413, 0.17146533908089623, 0.07252753945067525, 0.11875842668814585, 0.21244168718112633, 0.23626833833986893, 0.11576316319406033, 0.1552941935369745, 0.15286604961147532, 0.1131633976183366, 0.1953403337392956, 0.129851664241869, 0.22092053142841905, 0.15376688330434263, 0.0823171203956008, 0.21013415709603578, 0.06562478680280037, 0.25197985698468983, 0.12450245674699545, 0.13279650622280315, 0.1488889247411862, 0.17201427603140473, 0.10918796484475024, 0.21380511636380106, 0.13577606587205082, 0.1297319112927653, 0.11890966896316968, 0.11281673301709816, 0.15562326181679964, 0.1440907470532693, 0.13954800175270066, 0.14641319430666044, 0.2128627966158092, 0.27178896591067314, 0.1818625905434601, 0.1530786749208346, 0.13841150648659095, 0.1580754216411151, 0.1035045830940362, 0.21804669813718647, 0.17421389784431085, 0.11460563546279445, 0.14718942140461877, 0.10777112329378724, 0.1809798800968565, 0.17080015211831778, 0.11547737696673721, 0.11867218170664273, 0.16753103613154963, 0.14040926413144916, 0.13382086297497153, 0.10839398557436652, 0.1527642714791, 0.16650587785989046, 0.29777381219901145, 0.1946488450630568, 0.19322807755088434, 0.14288256032159552, 0.11454471998149529, 0.2337937953416258, 0.14283010532381013, 0.12782261765096337, 0.12440254882676527, 0.17791069869417697, 0.09738013555761427, 0.18731437769019976, 0.0810800344333984, 0.11571150971576571, 0.19858268788084388, 0.11235130994464271, 0.141069449018687, 0.18945453863125294, 0.15195136744296178, 0.09039140510139987, 0.16874090011697263, 0.1754598450497724, 0.15043075138237327, 0.2208020252874121, 0.1404337550047785, 0.1814891121466644, 0.1286114612594247, 0.17772352905012667, 0.10971908282954246, 0.14007547579240054, 0.14041367248864844, 0.16308751597534865, 0.1682842566515319, 0.15160521492362022, 0.1295067585306242, 0.09582191487425007, 0.14440495753660798, 0.15635746851330623, 0.2707979019032791, 0.2530734858009964, 0.15907172521110624, 0.07500775987864472, 0.09479928732616827, 0.07004472150583751, 0.1056370628066361, 0.11854591270093806, 0.10394221273600124, 0.2185639156959951, 0.08006823481991887, 0.13109890278428793, 0.25545334559865296, 0.09524493216304109, 0.13231241813628003, 0.2017737299320288, 0.0903246489178855, 0.10274121741531417, 0.08518586997524835, 0.08317069412441924, 0.17623199033550918, 0.1661102834623307, 0.22349078179104254, 0.2297416838700883, 0.14390915835974738, 0.10424607768072747, 0.08499998424667865, 0.15642013546312228, 0.14808270003413782, 0.08094151999102905, 0.2033211968955584, 0.16255137365078554, 0.18277066759765148, 0.0987833586987108, 0.2114183545927517, 0.1497806003317237, 0.11141012568259612, 0.10570577083854005, 0.11697097885189578, 0.13488387077813968, 0.08389948314288631, 0.10633180208969861, 0.1444363355403766, 0.1746529820957221, 0.20495122036663815, 0.08785048441495746, 0.11847882997244596, 0.1543649355880916, 0.12336910076555796, 0.13795182021567598, 0.26352853572461754, 0.150986323133111, 0.13489273202139884, 0.1031440997030586, 0.12261531621334143, 0.09564358420902863, 0.26455646962858737, 0.10116585312061943, 0.1495085735223256, 0.2011464221868664, 0.14252257416956127, 0.1380683819297701, 0.10362947170506231], [0.024360374081879854, 0.03413045880733989, 0.02047057030722499, 0.03878185081703123, 0.006981791839280049, 0.04168164072325453, 0.06374008793500252, 0.029358716419665143, 0.06953071744646877, 0.023983834325917996, 0.022684777177346405, 0.03979648172389716, 0.033608372759772465, 0.09899955373839475, 0.055639245474594645, 0.05587718544120435, 0.04428288317285478, 0.05637021269649267, 0.0286225077798008, 0.011706245040841168, 0.0743067791336216, 0.0596322968340246, 0.02255889594380278, 0.06276858694036491, 0.03596488830226008, 0.04428388136147987, 0.022525829554069787, 0.053509712088271044, 0.03746504706214182, 0.03644512835307978, 0.05147991963895038, 0.021094861222081818, 0.0495639540895354, 0.04254290310200304, 0.0140004109016445, 0.08727834050660022, 0.029503084551834036, 0.021885836649744306, 0.030596128926845267, 0.06584183531231247, 0.028136002147221006, 0.01740510149829788, 0.07883908983785659, 0.10430731970700435, 0.041338727678521536, 0.009181010573229287, 0.006432029713323573, 0.07344950950937346, 0.01242113456100924, 0.032652007867000066, 0.08763376245042309, 0.03624440709245391, 0.02662710459844675, 0.04156522743869573, 0.03929881233489141, 0.06764195903087966, 0.041202851571142673, 0.08695506097865291, 0.037054483545944095, 0.010923653098871, 0.06436736599425785, 0.017549198746564798, 0.013825018213537987, 0.02251465652079787, 0.0207364168818458, 0.12515211798017845, 0.005026971612096531, 0.06234712869627401, 0.06669209906249307, 0.09249171271221712, 0.01858557643572567, 0.026639288807928097, 0.00429612266998447, 0.06626641057664528, 0.00427978057814471, 0.06753576511982828, 0.04031370670418255, 0.02735359110374702, 0.04366448491055053, 0.0732333589985501, 0.027368688242859207, 0.032643020458635874, 0.08120113066979684, 0.0455131042690482, 0.046184191305655986, 0.014548919261869742, 0.11091916530858725, 0.08554147745599039, 0.05037414557591546, 0.031438800506293774, 0.12261604351806454, 0.0520449426403502, 0.028476425286498852, 0.04967794055119157, 0.0029876481312385295, 0.021517853856494185, 0.05018800380639732, 0.04052460652019363, 0.02017477250774391, 0.05187797054531984, 0.07442331116180867, 0.027806000616692472, 0.055442275770474225, 0.06088891241233796, 0.010048321455542464, 0.02041406318312511, 0.01212108982144855, 0.034136985996156, 0.015940762496029492, 0.04347069530922454, 0.03499707949231379, 0.027272678453300614, 0.015677008777856827, 0.033691077696857974, 0.046382148066186346, 0.046466378116747364, 0.021658375808328856, 0.050244173253304325, 0.00853908437420614, 0.07963369251228869, 0.04825389274628833, 0.021925361579633318, 0.0698705913964659, 0.013540419422497507, 0.015439615217474056, 0.05899402756767813, 0.03594809721107595, 0.035758411686401814, 0.01699560110864695, 0.028467337688198313, 0.01754447312123375, 0.04463496916287113, 0.0502134817361366, 0.02942029241239652, 0.049924663835554384, 0.05784212160506286, 0.005462354865812813, 0.032733484549680725, 0.03367100260220468, 0.029529974417528138, 0.04474097011552658, 0.01032555350320763, 0.08323759131599218, 0.009307021682616323, 0.021159210991754662, 0.030922590412956197, 0.08907305396860465, 0.07589959874167107, 0.01160174415417714, 0.020929098827764392, 0.025543103292875458, 0.0482866103266133, 0.07603653240948915, 0.03661293536424637, 0.028021481339237653, 0.05356161047529895, 0.02629136997711612, 0.032699460789444856, 0.00929230674955761, 0.05351695173885673, 0.010004321375163272, 0.06117775628808886, 0.06356465164572, 0.01329827333393041, 0.0035585459272624576, 0.043953488348051906, 0.007288721390068531, 0.08669087867019698, 0.06242972973268479, 0.02104579227307113, 0.04338010876381304, 0.04121163488889579, 0.049127148231491446, 0.031613784085493535, 0.03062578514800407, 0.016526856925338507, 0.04480152565520257, 0.02585821919637965, 0.04989096290955786, 0.037073074345244095, 0.021010640448366757, 0.04894215308013372, 0.013664518573932583, 0.02469105282216333, 0.057507197780068964, 0.004120906705793459, 0.04265248862793669, 0.05316234615747817, 0.03378905232239049, 0.08574370527639985, 0.062028049724176526, 0.05887063809495885, 0.025882717491185758, 0.04471731786907185, 0.00860084590385668, 0.019325688772369176, 0.07115875196177512, 0.041681815127958544, 0.0180332237505354, 0.043633051245706156, 0.01049979586241534, 0.03391178870515432, 0.031209584485623054, 0.026669041508284863, 0.03250386405852623, 0.05192627322685439, 0.04051659503602423, 0.034204250550828874, 0.05213354394072667, 0.020748255992657505, 0.02957416931167245, 0.034159910937887616, 0.028812540258513764, 0.031770933856023476, 0.04512174382398371, 0.020248326763976365, 0.04009469150332734, 0.06339116720482707, 0.06174203343107365, 0.1043079950613901, 0.03125357528915629, 0.018130016505892854, 0.04111876252864022, 0.09566267224727198, 0.03239795958506875, 0.05818497156724334, 0.014926987842045492, 0.032210329809458926, 0.030061699108046014, 0.00980860033450881, 0.02136832037649583, 0.027201061202504206, 0.04176371483481489, 0.08414581679971889, 0.05286803265335038, 0.08096874938928522, 0.03922563286323566, 0.006989556095504668, 0.01613237203855533, 0.06882060086354613, 0.06299045940977521, 0.0533992842247244, 0.06575625084224157, 0.034110550695913844, 0.020977553649572656, 0.033439979451941326, 0.07422629321808927, 0.05058333103079349, 0.05925779798417352, 0.024899345844460186, 0.043534471769817173, 0.01853021592978621, 0.031053983948368113, 0.03946323515265249, 0.03523019920976367, 0.058509880109340884, 0.030910489695088472, 0.022768526687286794, 0.009206110007653479, 0.04043159686261788, 0.02269882974360371, 0.02659807363670552, 0.07247789719258435, 0.02665027630428085, 0.033704046727507375, 0.07351843276410364, 0.10111646319273859, 0.012780533488694346, 0.05565788451349363, 0.05597330840828363, 0.02522259012039285, 0.02054642522125505, 0.11160164431203157, 0.05872108420589939, 0.035276453563710675, 0.053637072051060386, 0.1161211529688444, 0.02950214944576146, 0.01921084327477729, 0.03646127377578523, 0.041479854480712675, 0.029859588175895624, 0.03766939371416811, 0.006804881459174794, 0.03380546120752115, 0.02514019131922396, 0.04606050868460443, 0.03368677324033342, 0.03337317502882797, 0.04901931417407468, 0.01848884676292073, 0.018600660587253515, 0.011831514930236153, 0.07474460173398256, 0.04858588508795947, 0.08050366770476103, 0.01893348784506088, 0.0321090377838118, 0.04430211592989508, 0.01584082860063063, 0.06024596019415185, 0.08035323437070474, 0.04798323519935366, 0.04135328490519896, 0.02223025254352251, 0.07776233003824018, 0.056879671101341955, 0.008185569749912247, 0.04142523612244986, 0.07908966857939959, 0.03933966385375243, 0.025292403952335007, 0.056286212711711414, 0.025495318259345368, 0.014636012147093425, 0.054665080169797875, 0.02990752906043781, 0.04261744812538382, 0.05408031975093763, 0.04952556650096085, 0.016486367203469854, 0.01917595676786732, 0.029290303391462658, 0.05632020678604022, 0.04420012628543191, 0.001549649573462375, 0.015960700293362606, 0.031303228679462336, 0.03404337519896217, 0.033596784123801626, 0.02401644243946066, 0.024481383115926292, 0.056687347241677344, 0.0807810750848148, 0.04092656854481902, 0.020846041370532475, 0.03570170789316762, 0.033543086028657854, 0.04899784384178929, 0.031784518869244494, 0.01598161215952132, 0.04964809137163684, 0.029625624265463557, 0.13088590640109032, 0.045445472351275384, 0.02726209171669325, 0.015237657353281975, 0.07723681526840664, 0.0541590282227844, 0.028435931853891816, 0.03176710437401198, 0.053114132533664815, 0.1355013673310168, 0.17781988950446248, 0.1635960058774799, 0.09565682412358001, 0.1592727136448957, 0.1340329836239107, 0.10030180026660673, 0.12369923773803748, 0.1251461956417188, 0.0959101488115266, 0.09259470796678215, 0.12679190811468288, 0.07539605896454304, 0.27227670536376536, 0.24072358442936093, 0.16482378530781716, 0.13195504434406757, 0.17737702029990032, 0.11911153313121758, 0.11675220855977386, 0.18737637670710683, 0.1423777366289869, 0.08838203284540214, 0.19929828151362017, 0.12128776987083256, 0.14763145940378308, 0.1295800381922163, 0.13235955935670063, 0.10983516214764677, 0.1523588362033479, 0.14685857197036967, 0.10183234626310878, 0.1256977004231885, 0.07757970233797096, 0.11777942258049734, 0.19576157676056027, 0.24454321071971208, 0.14382148103322834, 0.1651350420434028, 0.15398326388094574, 0.20990090008126572, 0.10908468015259132, 0.2242384955752641, 0.20689261931693181, 0.1101340918103233, 0.03773473981709685, 0.11749007404432632, 0.1933982371701859, 0.11599076504353434, 0.13829806179273874, 0.18998392741195858, 0.11255449513555504, 0.11253793782088906, 0.1395064266398549, 0.1785738076432608, 0.1202377125446219, 0.11243135057156906, 0.30802100140135735, 0.23337630758760497, 0.18335916101932526, 0.15478240849915892, 0.08001131951459683, 0.06805235185311176, 0.09896964518702589, 0.24104269308736548, 0.19010434829397127, 0.1359750356641598, 0.10615830280585214, 0.09738026914419606, 0.20398013497469947, 0.20384902716614306, 0.11837031313916668, 0.22595251532038674, 0.18539092387072742, 0.09721461436129175, 0.16435492609161884, 0.09029327091411687, 0.14812274632276967, 0.1389562280382961, 0.23067526111844927, 0.09504216999630444, 0.10651007338310592, 0.14350295125041157, 0.07900541997514665, 0.13398591661825776, 0.1285623904550448, 0.20000795280793682, 0.11194380407687277, 0.23263892449904233, 0.16209848545258865, 0.2043027020408772, 0.18107851152308285, 0.15504272421821952, 0.19476889487123117, 0.11643942299997434, 0.1794202864402905, 0.2457946795038879, 0.1469116355292499, 0.11890144596691243, 0.1649485997040756, 0.3637635352788493, 0.13895639131078497, 0.13980353804072365, 0.14581405848730356, 0.12693628552369773, 0.11610340079641901, 0.10600404741126113, 0.08962617663200945, 0.11705512355547398, 0.12025142743368633, 0.11080975047661923, 0.12441905419109389, 0.1368281789473258, 0.10252977212076075, 0.14882263611070812, 0.11995110995485447, 0.07885745057137683, 0.15320841717766598, 0.09960030743968673, 0.21615380595903844, 0.165437318792101, 0.17762359144398943, 0.08966686116764322, 0.08259331807494164, 0.17614769720239565, 0.1622933882754296, 0.08452280555502512, 0.1305872216471471, 0.13256451085908338, 0.10873434934183024, 0.1475405166274868, 0.18436581012792885, 0.19840486929751933, 0.2244172789505683, 0.17282018903642893, 0.12900533387437463, 0.20230911526596174, 0.10243269920465536, 0.09978688336559571, 0.13780947629129514, 0.1583519607083872, 0.1343623487628065, 0.17184928175993264, 0.11355464303051122, 0.08030660523218103, 0.07900909360614605, 0.11409661121433601, 0.12357846804661676, 0.11503972506034188, 0.06077428028220311, 0.10775741582619958, 0.16256237227935344, 0.19748359685763717, 0.1578123154467903, 0.10405656285001896, 0.18479922437109053, 0.10093137898365967, 0.18029130063951015, 0.11432566025177948, 0.08024260983802378, 0.15563731809379533, 0.10162451522774063, 0.18191912735346705, 0.10868837329326198, 0.13402850105194375, 0.12927305622724816, 0.0797099110786803, 0.25211994478013366, 0.12970691575901583, 0.07673737214645371, 0.14934305974747986, 0.12455838499590755, 0.09235194404027425, 0.10346990995458327, 0.11287923669442534, 0.1679286194848828], [0.034274620993528515, 0.061431184876710176, 0.06238339745323174, 0.011571558225114131, 0.02167026872484712, 0.033441745763411745, 0.045928922190796584, 0.04452107175893616, 0.022678663735860027, 0.010537486759858439, 0.007038376888885978, 0.020344386648503132, 0.040029961382970214, 0.03010812415595865, 0.022431279940064996, 0.023023061075946316, 0.07020439457846805, 0.06003339796734508, 0.013919275606895098, 0.032876232944545336, 0.0157733989180997, 0.03999978565843776, 0.04516524109931197, 0.057727374442038126, 0.05857088093762286, 0.03258301039750222, 0.13106460071867332, 0.06344248671666719, 0.03288490122940857, 0.0472335510130506, 0.030057376097829547, 0.03767069247260224, 0.0319807167397812, 0.013241240212664707, 0.03543093160260469, 0.0179683990063495, 0.035012085718335584, 0.028865891399618704, 0.011255303124926286, 0.01272677416636725, 0.06759928553947248, 0.029049765907984693, 0.05773677374236286, 0.026615753449732438, 0.04014673460915219, 0.054713839272153564, 0.055441370350308716, 0.037990387427271344, 0.04065583678311668, 0.024186325608752668, 0.07150889723561704, 0.03253911607316695, 0.06480834272224456, 0.028313690854702145, 0.08088240050710738, 0.06803752374253236, 0.01748467457218794, 0.03680908128444571, 0.12056828738423064, 0.025140970574284438, 0.014454974498221418, 0.01813190341636073, 0.01496893031799118, 0.013971423541079275, 0.05087217490654439, 0.06367802954628132, 0.08826415752992034, 0.01988591749977786, 0.009626187857065815, 0.005876890263607493, 0.03197102800186258, 0.00417873717196926, 0.10274852756992914, 0.03916501424100716, 0.02942904975498095, 0.03940553688153159, 0.04219144051603507, 0.039081697032088414, 0.035631289210869, 0.026864602987188846, 0.08125747452140786, 0.043053548943134956, 0.0467023402597988, 0.07768697978463024, 0.028700880429823883, 0.03873499903420452, 0.007923785506136483, 0.047244653542293236, 0.0784547018702142, 0.04475491135963239, 0.06377030818839557, 0.07044508791295812, 0.04623158114554826, 0.024098982248688117, 0.033081347719416954, 0.02484488704794785, 0.026397628826089203, 0.03164810470480006, 0.011093171688116854, 0.039728356277919374, 0.08834371576085687, 0.0273608326097019, 0.023140940102166496, 0.10632829173118807, 0.013989255494379904, 0.03345764256664552, 0.022083290605223738, 0.07367548605543561, 0.04180469622951932, 0.045524151137215085, 0.07646047684829682, 0.06943957429029979, 0.050165242137154564, 0.0614545513963094, 0.010530389972700505, 0.029500188320525922, 0.003052186684726621, 0.049955845170188695, 0.02792620627587894, 0.04242004426487256, 0.012347263036645018, 0.05479037696204614, 0.0059761070588137954, 0.06836786109488457, 0.028190008233650587, 0.03274267233791761, 0.031049770404933952, 0.08098129910649732, 0.03500099803204648, 0.07807814356056042, 0.014636017713201, 0.014029866742930608, 0.020522136583167594, 0.07645784222404473, 0.04877657993347384, 0.016562003183935303, 0.01823010254156543, 0.02540336430683965, 0.09016827840241604, 0.01908253150759265, 0.027682119471137412, 0.06930938674486242, 0.028777863408322446, 0.027570300080697052, 0.023328868592216168, 0.01762498501193477, 0.012657543848035857, 0.06471688044257462, 0.013198678043409018, 0.093807881930843, 0.10204660429735668, 0.05859996941580903, 0.08564254312659614, 0.031699680257588625, 0.015283581451512873, 0.06457848474383354, 0.052953093909309246, 0.06157162148156203, 0.00941114221859607, 0.005840266203449573, 0.016118389976327308, 0.059981358572258614, 0.012377161383483326, 0.05957925182883628, 0.06620084925089031, 0.06917169608641416, 0.07346697224420495, 0.03981812646088656, 0.027157083386555314, 0.06094948279496748, 0.05609853098576423, 0.05008121246646624, 0.03609850456996355, 0.024207677197409794, 0.029300298265297897, 0.019139368887408637, 0.06578172877198085, 0.02574993242888013, 0.06217641617695335, 0.04025636095320806, 0.027889763114217203, 0.06503656055429019, 0.01382355247187661, 0.05848350418091286, 0.01167288086435292, 0.01036194935295498, 0.040211438754340634, 0.02358401339733973, 0.015194167499430478, 0.014227596220734995, 0.017820296015997883, 0.04034521829453297, 0.07632984401425347, 0.04963427629263606, 0.055508824152639136, 0.012760378613165813, 0.023740022115816828, 0.03681944537675008, 0.023401907055813354, 0.045708979305345565, 0.034256419821758755, 0.013601717109850142, 0.07769242714857683, 0.010224458146694815, 0.08010998062673025, 0.05964865005807951, 0.026374193657829892, 0.04680751000705641, 0.03816583855950739, 0.008885262868716381, 0.03745604852156248, 0.0473866152606206, 0.028266538502066396, 0.014844052839180222, 0.05940872855717316, 0.05564888968365267, 0.07315089154872112, 0.10218419105513021, 0.06815445653046481, 0.03000596752826823, 0.010254613462166162, 0.011464497856650269, 0.0593936481163837, 0.03737076462130062, 0.016297084293910302, 0.010362659031670773, 0.03730197866389062, 0.05093269333883654, 0.025224805431207642, 0.03878755793266464, 0.03251843241741881, 0.11536900856299326, 0.03499083060887642, 0.0489020325767342, 0.015917581513349432, 0.03647741919849068, 0.0503419141023187, 0.050194022624054924, 0.012723543040920049, 0.11781002875068225, 0.03553511429345235, 0.025786041624087375, 0.0337893603136763, 0.023874996513768565, 0.008009474804566707, 0.005584061518675298, 0.02465902729454683, 0.014456271401286358, 0.06937792408280075, 0.041076460111071356, 0.022826846507086884, 0.03755642399482895, 0.007303767970370245, 0.02172687789425254, 0.04515233886195347, 0.04082546947756782, 0.0581608332140604, 0.04594160920532886, 0.009069438874576008, 0.04190664505586028, 0.024258505036414135, 0.028371873377182055, 0.004649718466680497, 0.025987879816966597, 0.06118317396612838, 0.02081386926874984, 0.0627119313867297, 0.07170725846663117, 0.06127260276116431, 0.008621509150543716, 0.026089023413078394, 0.045040103868814185, 0.03969293356931303, 0.007389412739939871, 0.051425212222966366, 0.00994341702607926, 0.06098971833125688, 0.05085375109047163, 0.04757785558467731, 0.05705282528651878, 0.008268706988019403, 0.061282788738026284, 0.03852914953313302, 0.06700132231344469, 0.03643584037490655, 0.044442515427363105, 0.037374475359683856, 0.026311506298952736, 0.023863211208663415, 0.08293755585327744, 0.05295747258060146, 0.024297360178024974, 0.019642190636659507, 0.0212582431777264, 0.007266289512699586, 0.04122784339415375, 0.09649206680478528, 0.0958925524901133, 0.022285683553491253, 0.08282483846414834, 0.017321207269560546, 0.045378638242254965, 0.02721837179706199, 0.043558665784075856, 0.05372996296500787, 0.049147976606036536, 0.04688198823714629, 0.0031035426081871265, 0.09651282467530109, 0.015894665848463774, 0.01939679579663789, 0.06322324887150899, 0.04493785818340257, 0.02118825308571104, 0.04709211993031204, 0.013201185574871488, 0.012234909299877472, 0.01354441124931327, 0.0269428717365372, 0.012170720947324298, 0.015734797962068114, 0.02600679530587513, 0.025680281869426835, 0.057294546495541, 0.040115961455740035, 0.02409556651400635, 0.04242502407578286, 0.022427201838581823, 0.03380069290869869, 0.00683004861457448, 0.01220399606609135, 0.0626845980877988, 0.014562083106284263, 0.05693089413398411, 0.052820869168499485, 0.042298157641198486, 0.014295348737505265, 0.04665021551772952, 0.04804264412086923, 0.016897982713999227, 0.02231508002296323, 0.01954593408299843, 0.08778903458733112, 0.02511951322958339, 0.022689436009386554, 0.08513357082847506, 0.030269698982010596, 0.052166970272082835, 0.11115139815956354, 0.06259879097342491, 0.040209063881775364, 0.040338546386919916, 0.18333904881728813, 0.13771516416454688, 0.16134430014062673, 0.1708700624294579, 0.08521471725543961, 0.1904117310186848, 0.12921706860652193, 0.22246639535296708, 0.13787785777822137, 0.1315219418029301, 0.20991419936763123, 0.16886454191990197, 0.1377041358500719, 0.15447272511664778, 0.25427128246519715, 0.22850940702483058, 0.21294208767358214, 0.14141465158900246, 0.14128124312264845, 0.1331340498290956, 0.10176927113207057, 0.22592664405237883, 0.08956659701652825, 0.14631819940404966, 0.1695598749211058, 0.10831591163878329, 0.2666611410677433, 0.1273752361885272, 0.20011121523566544, 0.16821930388687178, 0.1123774261213839, 0.13243928086012602, 0.08605214185081422, 0.08223805198213086, 0.16166392830200493, 0.11432288461946882, 0.09795944119105116, 0.12238321694894694, 0.11421954797697254, 0.17615216493140906, 0.17030781134963036, 0.09157009146292694, 0.18580879754154012, 0.1185371627798304, 0.14041995105799288, 0.101376689854078, 0.12958302162587643, 0.09802141794352792, 0.13001037994399667, 0.09426589094800875, 0.08442969570751302, 0.12350479504675604, 0.15202004578895867, 0.18502131948480383, 0.12884684081654996, 0.22550817666342482, 0.10449949884787202, 0.1805086014792323, 0.2652198902796954, 0.1386465594987385, 0.13176993787055835, 0.0976999566773884, 0.14639072207501158, 0.16646707837935537, 0.08884008639142849, 0.13919511053245515, 0.1421807409496978, 0.13365079241339117, 0.09972783067496493, 0.13461482740240172, 0.09765749098733068, 0.07232677366118878, 0.18697808089200407, 0.09162950780591927, 0.09780078486073762, 0.14560241281287745, 0.08318616790347733, 0.15082848316524178, 0.1384817878715694, 0.09680679679149762, 0.19243654736783355, 0.13454328436637297, 0.20273628062568605, 0.1612767795450054, 0.07299573815544136, 0.061329506934271194, 0.11984632612438872, 0.09933337918482721, 0.25580862653441727, 0.11680027746479027, 0.13375001755775884, 0.215059123293031, 0.1461261315853335, 0.08618733147159219, 0.1958543897490017, 0.14787230116780847, 0.11768083568313159, 0.11794711826951243, 0.13929899636423215, 0.1307383822859265, 0.1825081105926074, 0.17047614528564736, 0.186708532855846, 0.1651813817443326, 0.13390469597652555, 0.12494271359173581, 0.1156673148216214, 0.17436887312214822, 0.13117256836267188, 0.11701941883075051, 0.15959214884787798, 0.10979867074638605, 0.16084349888842553, 0.20855056238360703, 0.12662225315580145, 0.09549879119731486, 0.2161518912180327, 0.1235450194508303, 0.15511864592554048, 0.13370505825150758, 0.25630455929785967, 0.11773874546634033, 0.10705106193199754, 0.17833173391409218, 0.09865165717201307, 0.08851932274410501, 0.09526101450319402, 0.21569294709479436, 0.1070784249168355, 0.17457621434004977, 0.15815790393389761, 0.09992311199312098, 0.1871831511380151, 0.1660121270106174, 0.10629300260916352, 0.15538887673756108, 0.12792767607606947, 0.08676398021634668, 0.12892078841105103, 0.07519135979237035, 0.08775374546530657, 0.15688267158111557, 0.0747186117223464, 0.09581366219208576, 0.1171475877345074, 0.10263332398608327, 0.09297297321609221, 0.15246913419105113, 0.1161544605565723, 0.3598268871428445, 0.2365436454419978, 0.17610910552321002, 0.20214326010318473, 0.14791104127652943, 0.10032865116954781, 0.1710525862290524, 0.1928477713954635, 0.173283971962519, 0.1869944971986115, 0.09718174464069307, 0.12723605381324887, 0.22260293568251655, 0.10742470360128209, 0.15208744764095172, 0.18909409234765917, 0.10684926455724053, 0.2093735893140547, 0.17105081991758198, 0.07297261283383705, 0.20323040254879743, 0.10372218079282902, 0.16520429926458746, 0.27751962246838957, 0.19180104631232098, 0.14735140255652368, 0.08980061844340526], [0.06155619223136455, 0.02973069938889239, 0.05188192990317475, 0.039412279293173924, 0.03693078237120062, 0.03257976350141689, 0.04903396787995007, 0.00463988686533412, 0.03907741112925578, 0.030219585460145026, 0.10598355671390891, 0.013698997827304993, 0.045563536914414726, 0.009667301910667447, 0.08062153559876606, 0.0803485514188651, 0.08361600499483757, 0.02178029953938676, 0.011681828382279491, 0.05251161252090242, 0.060532470015459694, 0.092523432103917, 0.0208890822250396, 0.04756618531246204, 0.04614548830431886, 0.02805029522278346, 0.024605535145383328, 0.03900478455761913, 0.06761986529454589, 0.05507384026714135, 0.03408590397157241, 0.06963619889575057, 0.01655898264289135, 0.020318765855336096, 0.02212142771895742, 0.06174870904942509, 0.013710805396840442, 0.04234510961396154, 0.04350641858763993, 0.024129471530613955, 0.09311327623436227, 0.06676261793472804, 0.02530507426854456, 0.038417344985646196, 0.015140756986511406, 0.02778073976514861, 0.013926745323260548, 0.044296085980022326, 0.023408701417793054, 0.05763560788182076, 0.060529727779794484, 0.03298625633760821, 0.007689162011956796, 0.051380319710006006, 0.01352977980786818, 0.05647086647513788, 0.029608591976284515, 0.02168700044421712, 0.051012407420785166, 0.044296223277342506, 0.02807884564390406, 0.06070211384212598, 0.03429134529142175, 0.05563849219470285, 0.003380035523150582, 0.030719214119017124, 0.046437553100986406, 0.024504599350620992, 0.11643879959592596, 0.009889464745356236, 0.00916945904464228, 0.02519734040106414, 0.012795173279300798, 0.03939298716431949, 0.05196943282498978, 0.06946068839170039, 0.0010404764316263027, 0.04280963468772825, 0.029817701361025684, 0.020877116949122865, 0.04429738844919484, 0.0034496826037866413, 0.04851859084737953, 0.016066604766820092, 0.09495662263361737, 0.006734322696502204, 0.03658138666651212, 0.011515384139784146, 0.02770030765532283, 0.0770287393243052, 0.028388005812303163, 0.022172891949594487, 0.0440089750190964, 0.009703318337415112, 0.06038588471710682, 0.03990047887782566, 0.03731981989403721, 0.056032142165349796, 0.042829724625335075, 0.08667473695822991, 0.047249689014279284, 0.027991381684842054, 0.08122356579406187, 0.05636467627482489, 0.0183306988037657, 0.028646371538343374, 0.017799679153540637, 0.03984498849604279, 0.06896295220940374, 0.011870794951391872, 0.0980595123837702, 0.02901334872149164, 0.027952914315392263, 0.04806406250281725, 0.03303090394183528, 0.03964362527767662, 0.0071180000577442115, 0.02100955134665128, 0.03531063317495864, 0.028765684764948674, 0.006670703014606261, 0.07161256784456782, 0.03587689556297846, 0.043626026817946695, 0.0244649593878421, 0.015598697355017066, 0.02979993249027757, 0.008885768456821097, 0.035093324913759716, 0.07250430280691944, 0.05075267057691235, 0.031042462105688173, 0.022575204638997093, 0.02882703069190029, 0.06507038764539175, 0.059117591445101425, 0.021455127534864005, 0.04818550754862372, 0.019477660207485314, 0.023943945743667427, 0.024045124591793865, 0.051840440137311816, 0.013586739642050816, 0.011852482457470614, 0.06031818229530472, 0.028947299433639273, 0.016385757953685243, 0.03929077858629171, 0.006589593231183244, 0.02800432102958439, 0.06380864753737114, 0.024397774614044465, 0.03446124515903648, 0.0687166111310944, 0.04972930830263067, 0.022758370396331884, 0.009727010474307463, 0.05373544372559991, 0.04872402103501372, 0.05975336709525436, 0.03991548881458584, 0.035641668146126904, 0.0341238388500642, 0.012806914983229944, 0.03398838947759941, 0.026689445003285073, 0.02981545821967302, 0.028188872747705318, 0.04973619543306995, 0.02706712210056139, 0.048017641165643, 0.025656013640400488, 0.04182067095825914, 0.06766198959667236, 0.07293368718819693, 0.032159926849999465, 0.0368899308523396, 0.03154696481942665, 0.09297986776800826, 0.017676423267403152, 0.045535327881225385, 0.04053523036418483, 0.09557428245898336, 0.022406102580134757, 0.028109010236221366, 0.02024504832661478, 0.05358178575988859, 0.05024110076192301, 0.018047055527858902, 0.04858073087234516, 0.021766443642263766, 0.03254573974118102, 0.07256627955939621, 0.038466438054456376, 0.038363535568350926, 0.0163145692931721, 0.038328706577885896, 0.08748111009481363, 0.046713175615877844, 0.056876056842156686, 0.008644533354527084, 0.026798880244314205, 0.02590670370409498, 0.012761795187543612, 0.036471493149292655, 0.0057542280956113245, 0.02571481956692878, 0.10858176377951168, 0.05484501758473925, 0.02232749800896272, 0.019402738544158638, 0.009325902847194811, 0.032950937529676594, 0.047107530626817606, 0.02329425853531575, 0.021137120966159273, 0.013082393707009032, 0.04279243541532196, 0.04896139325865079, 0.047145064745564014, 0.028071583728888072, 0.06310233075055294, 0.039726556569803506, 0.06676916367723607, 0.012787717478204286, 0.07264889543876052, 0.044271457809372805, 0.022882618904986884, 0.025611256569391116, 0.0655764433031436, 0.05284754566673655, 0.01686362684267806, 0.08768217274337076, 0.05099351234093774, 0.07742500165477395, 0.06011177247273736, 0.021738520335929934, 0.042364728287793696, 0.06507553072879091, 0.0227630143854185, 0.04999884891731199, 0.013665596543432912, 0.032906275082495995, 0.04072542054927908, 0.06759869182133116, 0.04401945785502903, 0.01959160956175765, 0.08244202384958044, 0.054755599921918474, 0.01977957144845277, 0.045303002261789516, 0.0377608671260532, 0.02763409138424322, 0.012543331031338312, 0.051897945450036786, 0.010578263136267196, 0.04999254808353726, 0.04187227619695477, 0.060433756952988915, 0.016330954058503266, 0.07271818234585226, 0.017234678416571114, 0.06468049294198863, 0.04964989850122947, 0.014417076727113454, 0.03398099768674001, 0.01867908147687558, 0.037608292695949785, 0.04639649378077593, 0.06315606224234216, 0.1166332422872074, 0.08079548759269528, 0.042064900626428425, 0.029329618664633017, 0.0464134963840479, 0.004441559030965436, 0.0310975201864494, 0.0424916318297619, 0.03834178321994841, 0.029896647320128977, 0.03604314406402409, 0.03861547615088057, 0.029619768720294815, 0.0851967053313274, 0.060083723001298495, 0.0503517846664181, 0.06489621300715953, 0.06071159106795676, 0.06531505146995187, 0.025622969515097793, 0.031640957822673954, 0.06813298619817942, 0.05700035544577986, 0.016235361727012787, 0.04991154637536965, 0.04407740474562161, 0.027219618605158757, 0.04887941191555001, 0.04473265435080975, 0.029864627358620055, 0.015682342964282725, 0.00797715705630253, 0.025294684201071505, 0.007461560162482783, 0.0562675365654286, 0.06286148156505078, 0.02842086996679427, 0.061053654353599995, 0.032546578368055634, 0.0259735378131154, 0.03428864016314037, 0.07452221718267538, 0.06437288015149534, 0.03589876665500924, 0.013955302238173317, 0.030897136603016406, 0.024680200767761562, 0.04929463240841869, 0.04211339997709729, 0.01766473815223435, 0.03605847683502361, 0.04802757110155653, 0.016819188895169646, 0.026787504975800402, 0.04183594064670615, 0.0156875713946647, 0.034440687668393366, 0.0242672326930915, 0.05167169430933427, 0.022720350170857273, 0.020690507626568433, 0.02984830382047221, 0.02777884728857316, 0.04410555069625843, 0.09124068179517053, 0.050828610837925225, 0.04166049693594687, 0.05402501490607392, 0.04563773312838748, 0.023243725700012874, 0.07043995225103572, 0.0487596144375857, 0.05611285814666189, 0.04105694162717555, 0.06542054034071043, 0.0326593031786615, 0.031961086933733895, 0.04276545834727585, 0.04527693061390892, 0.01128657444496639, 0.0429906185308937, 0.0367631163680926, 0.09472260120674036, 0.11888869586982764, 0.150973706622608, 0.07482243818230927, 0.10095540972542949, 0.11582425679080188, 0.17234901431947947, 0.14169453032081947, 0.12045255687553436, 0.1781017571920529, 0.2075004976359196, 0.06930106726940721, 0.18028145976131782, 0.09574335112120025, 0.16666972922394052, 0.14960886735934764, 0.13277824938995764, 0.15899377001915127, 0.13951015222119167, 0.16225858154939488, 0.1716348752961494, 0.18415401602396742, 0.12248486149474047, 0.18207034736406058, 0.10617656706017442, 0.10982494277413934, 0.051157356283511035, 0.1260871349950321, 0.13567630638135597, 0.1588360042660497, 0.14606848155381158, 0.17079360637580976, 0.22315218433504924, 0.07548423353000544, 0.16191529372008517, 0.08244574200944044, 0.11273168289335445, 0.10754208167782053, 0.13526100054150447, 0.06619101579417475, 0.2042989170877263, 0.22410717996535823, 0.20010216103401035, 0.1907887717243284, 0.15048801549710333, 0.13502104935469106, 0.08935610909247771, 0.2136775857070461, 0.07236598132294603, 0.15713053406216204, 0.1685606176033616, 0.1223228729213588, 0.12549760256661102, 0.18307972757611424, 0.09465842769714072, 0.1522460742853582, 0.20241280813934281, 0.1617676657042466, 0.2544754621339962, 0.15643175749573857, 0.11766942887334153, 0.23074385040672496, 0.14020541100762784, 0.13032635673880577, 0.08362432447029278, 0.10188299042056315, 0.16493884788360447, 0.1003139566455502, 0.17599012440769002, 0.12032892249408178, 0.10446418746141717, 0.16540007782168686, 0.09869570363662206, 0.1250826529576443, 0.13095684087602422, 0.1332137268036604, 0.09599813784006983, 0.08230757637647912, 0.08825083597912453, 0.11356897390214726, 0.1723552038311027, 0.12767077423632145, 0.10199951502727345, 0.11491223893244751, 0.14892793202307075, 0.11680555413477123, 0.13255328958621249, 0.1298224533093162, 0.16880004928680137, 0.1492946717189625, 0.1883850444573909, 0.19984310696600005, 0.10642503810231574, 0.06294289516517892, 0.19929998845327646, 0.16944320930633694, 0.18314016808290035, 0.14605277770897374, 0.10804195524542592, 0.16043972602346912, 0.07619190102559514, 0.1109532818372827, 0.09468484073295258, 0.15178248431766406, 0.12875037646153942, 0.15145035838941112, 0.11219352192711085, 0.1515808724798262, 0.14980708016082644, 0.1905829444876872, 0.4462794621940702, 0.12082467714208178, 0.10980685663525946, 0.1769826578674838, 0.1033202484541107, 0.15848723938688636, 0.09352815162856132, 0.09345581449451856, 0.16357003070879728, 0.13215291575761512, 0.15464303316548467, 0.1954039654810913, 0.12227468527271412, 0.15074292838107795, 0.10529428705922328, 0.07987143952050246, 0.0880908289400395, 0.09284628118621185, 0.147783748107031, 0.18250312336022034, 0.15040431608213112, 0.21729043481172994, 0.10659009174560197, 0.12976308149518445, 0.1577196954167448, 0.13158181827748194, 0.18504904612200335, 0.1485546911135316, 0.15282224805559963, 0.14404641115106642, 0.17147103877505288, 0.11974503038800322, 0.11143820112920366, 0.13879818026907742, 0.14383838715730235, 0.12268699283595197, 0.1217128275311552, 0.1260459012701176, 0.05841077370860148, 0.1540394889889285, 0.16114892234327272, 0.10067631767014973, 0.10703465304686688, 0.10115242024767213, 0.1308246495318599, 0.08196459282771684, 0.0947425798221957, 0.08729374007089064, 0.1599906524643302, 0.11205851042177528, 0.21378305973485112, 0.14945352100767195, 0.10086844486068003, 0.14051553967874497, 0.13699140690732747, 0.10755898780189455, 0.08917658356949687, 0.1313466316787526, 0.17825437244027853, 0.10994237280101515, 0.17765939264791086, 0.12418959697242826, 0.10189679436734878, 0.129102629434783, 0.1149586083192844, 0.11325459272484295], [0.10715616488596424, 0.03723042449564673, 0.012919149976369226, 0.03328735307150055, 0.0612578859727364, 0.05927634054387454, 0.03833590541034937, 0.057823115203063935, 0.02217975681560347, 0.05251314505585469, 0.01970481862372253, 0.03554782728315331, 0.0409669413784286, 0.020827010848734062, 0.02367825130932033, 0.10179599586990662, 0.03642834097263403, 0.04289006865292322, 0.017247760624741204, 0.055905093904584646, 0.04575933773594443, 0.009432254464627476, 0.04684845058363862, 0.03695883926411625, 0.05786012239695992, 0.061350817704806104, 0.0025868484954116866, 0.03734788049769122, 0.017192312916449737, 0.068530302378349, 0.0233623246094794, 0.015714268301962875, 0.021111025198479183, 0.031645377312088385, 0.0320490388548933, 0.049185098832822405, 0.021989794840919785, 0.022135355975478888, 0.007027317496977048, 0.012538235259853536, 0.060607913037529215, 0.06351715419441462, 0.0400653098768089, 0.04303056462958921, 0.03773411641304847, 0.16786262771347538, 0.017435345871490426, 0.09825875677051954, 0.021833945684193168, 0.010046569059340982, 0.058944296251866035, 0.05925456964178011, 0.006133360730018467, 0.026996426968253218, 0.06791869847802445, 0.013514897891582223, 0.03912886793841608, 0.01844215083110612, 0.02082871964375954, 0.01663182814809261, 0.07420338311931118, 0.021665812128048856, 0.041161747722071595, 0.0033258329995078384, 0.05212472351558972, 0.03391326557903085, 0.07094480562955141, 0.02635547483805567, 0.05051929481851403, 0.03059653339732904, 0.04610938281985, 0.04900416693999432, 0.05608175844827201, 0.01659385430684779, 0.051284886940266006, 0.07139715948142111, 0.0397702913323883, 0.08673139251186512, 0.04991632580640726, 0.05989036384562496, 0.146506734599825, 0.05914618639508262, 0.05239731435722206, 0.01219268202476087, 0.03278603973740246, 0.028409923288563732, 0.028688167440122925, 0.04690413763455581, 0.04404371866257861, 0.05325828729837667, 0.017962563870241866, 0.004281268584236386, 0.005468407080115867, 0.011355755596014205, 0.07124351264792494, 0.037931071274215356, 0.0542706843407359, 0.04584796872222796, 0.023582504982186947, 0.057529462210368365, 0.018015601453953423, 0.05397121291025542, 0.06418574761482887, 0.05872828303836286, 0.010971093961416045, 0.051480123729561456, 0.03756046869966667, 0.09570756476023234, 0.04851951111049857, 0.03914384818926919, 0.031194151524687186, 0.008014080758584896, 0.007048884772302699, 0.03033531040273374, 0.06414161209249869, 0.027324558286636602, 0.038186670644790865, 0.03868045489070937, 0.053715598696726374, 0.03768653732549865, 0.04887501469056588, 0.08259302863734774, 0.0084412479736784, 0.04943557367369067, 0.047874729498289526, 0.04041580767079722, 0.03873428657243494, 0.04323928995290771, 0.02439417705318192, 0.03733616569661535, 0.04634300719772, 0.04773632637807168, 0.06162814715935383, 0.005504387791006593, 0.02494472446414875, 0.040741079865256324, 0.04259878311131615, 0.013871539740648586, 0.05041226599132642, 0.06511392944958061, 0.05336536436516326, 0.027993170260742772, 0.0683532036782708, 0.026049110711028334, 0.026090850951732136, 0.03293266214313917, 0.029524736710300203, 0.10596253909170628, 0.01526641650343663, 0.07692302038776688, 0.03255935444030911, 0.02241633123048814, 0.050912017104565166, 0.06571929930942133, 0.042493954751989804, 0.05119879038829822, 0.07191439188318327, 0.028312633294262923, 0.030488541633530986, 0.01625823657377623, 0.07133516046451405, 0.04433129717654083, 0.049660540898912586, 0.03170159870933276, 0.016585750054218806, 0.047535976191284135, 0.03755925899895374, 0.04364788306702394, 0.05135708677698858, 0.031089592193893623, 0.0491667084133951, 0.05288245258270763, 0.04243165145453531, 0.01482936666434398, 0.019848958545480855, 0.0672696903347969, 0.03342497322591953, 0.06599884407478385, 0.08730723973712884, 0.06125052386778407, 0.07290389738045633, 0.02230400717962766, 0.06329992756946012, 0.034103607904398814, 0.024396019434789196, 0.05398523579060566, 0.03312839617137797, 0.050848177561420016, 0.05769663468527142, 0.05472309385368135, 0.025109980342676863, 0.07763347835862078, 0.09246419387636706, 0.022130415127321612, 0.057360104110557586, 0.031003833319118712, 0.03749222451006062, 0.03594132882426493, 0.019250672485213727, 0.027925798094656784, 0.01901718911540229, 0.031110661766433623, 0.023919337982079014, 0.020437860148376785, 0.016929423800320365, 0.03149609801766928, 0.016541822333238088, 0.02539504483138444, 0.05537012417335063, 0.020007677958346903, 0.044889381097164005, 0.033455790908192284, 0.029486068960977718, 0.028952841421414632, 0.039621275500394404, 0.04265639974619262, 0.045127565972507, 0.07775249658152461, 0.039544103274238296, 0.055250412042369135, 0.03259595716372132, 0.06741521807271056, 0.05315713628078811, 0.03863373298372608, 0.007452213740180014, 0.020736747137561906, 0.03431683435337618, 0.01656718708545668, 0.04370152179035358, 0.09771495548193343, 0.026946547222905792, 0.024321194250660483, 0.030983992000983562, 0.0931791566836182, 0.020634853972296696, 0.04515089909546077, 0.08093959782854654, 0.03414930193684995, 0.045756925755995326, 0.0734763233049307, 0.021485861725523137, 0.03780170751269907, 0.0560089908685768, 0.05425336261396296, 0.06519066751934588, 0.039764573084539734, 0.03597463270125445, 0.04027053226309363, 0.03800603561103344, 0.047365571663249284, 0.015375769180536736, 0.04252894330420531, 0.01018782202663715, 0.1194369129370898, 0.02277995205076877, 0.01815442017687019, 0.09355748872621916, 0.05353213979105931, 0.035651872676680796, 0.016449052018288057, 0.0477604907064233, 0.020685399795183912, 0.015438309965247754, 0.051215228959335946, 0.006619178484470467, 0.0339895212528063, 0.09004498540889472, 0.017565878515597433, 0.10126362365554087, 0.07924365680082701, 0.031743919680593535, 0.0497665715374751, 0.03780955572437961, 0.060322739082039334, 0.03266469488153234, 0.014741608629265102, 0.04920626488456037, 0.014375188984558918, 0.042894688522210345, 0.030083470010140445, 0.061262465023901314, 0.023397580334858503, 0.04601317079504952, 0.025529952436045278, 0.045393362452159636, 0.07797540805768222, 0.0092864883117727, 0.019231998194300104, 0.08069773190072738, 0.03450343254371546, 0.030365324710146524, 0.0037598286689899396, 0.09926244470989332, 0.05383971547416877, 0.04644214699510485, 0.019800199443125166, 0.012546933230623836, 0.02480915263731731, 0.05100913826026954, 0.016272778957500122, 0.05309440253768116, 0.06823145435191691, 0.0535887545265723, 0.034259804015164264, 0.05115609834319912, 0.09628325613448396, 0.0437949581828434, 0.07942336786072701, 0.023079059828887694, 0.01594913577719126, 0.006907652214067639, 0.04481576746911742, 0.04891691263765097, 0.015355967752839206, 0.039658000678173266, 0.04755648544232827, 0.04813258128706366, 0.08529451297363266, 0.04377750286948867, 0.022070277045713738, 0.009773478195711505, 0.0171133984986227, 0.018088517463183962, 0.03516358032356948, 0.013630879802803975, 0.08377799356821924, 0.031229396117851138, 0.014490203320747241, 0.011432950086600613, 0.011051160563511075, 0.05542738828808069, 0.028260716353543103, 0.013529358639061684, 0.03436630591750145, 0.020129414297116455, 0.06244159667403437, 0.10625136070302688, 0.024348919032490812, 0.025473580753896385, 0.016094481688924134, 0.07495005047530867, 0.019796651977230795, 0.03823696228209883, 0.036204060234013014, 0.021683046652469784, 0.06301572211668827, 0.035960442837676965, 0.03933862484700512, 0.030744567739020567, 0.0188395115401363, 0.047345893617602997, 0.07861872392822988, 0.17708535626297817, 0.12886327196611091, 0.14058452972676605, 0.12907413096399978, 0.24034492584178224, 0.13025276537518948, 0.13413865061011165, 0.12216435759910382, 0.16644096962409094, 0.15699461713666096, 0.06943780797882937, 0.11503258559969254, 0.155703873897437, 0.15918001940008253, 0.08502072727424093, 0.19796585926087573, 0.20732137287268415, 0.10851436934899539, 0.09734092789585702, 0.1061486845719628, 0.15496166684897617, 0.0903420893882867, 0.21154428221052513, 0.20154262514552101, 0.14164358930429444, 0.09267476343666203, 0.0988872000016272, 0.07584593404317275, 0.13557515165302902, 0.09177050102152862, 0.0737740655313246, 0.09866978783975355, 0.12648241769056767, 0.12292291416088119, 0.07823919702786952, 0.12537936359876767, 0.11992981031653471, 0.07781994296237826, 0.11555665318155661, 0.06415609139367007, 0.12341390422079712, 0.16061592672485858, 0.1765919171157293, 0.17219947156263515, 0.12333293590927497, 0.2193269770941697, 0.19056376739172265, 0.1940156743512489, 0.10059022853965871, 0.10076303020468913, 0.13012655574129894, 0.09118792993831448, 0.1059741982317064, 0.1704962129588239, 0.1264702167827636, 0.09596214367775247, 0.14142894535325468, 0.13629942841362208, 0.08913908284739591, 0.09685139244538732, 0.18700000393437222, 0.09831788367591798, 0.1968779301387258, 0.2219357597641647, 0.14498611853923649, 0.11614439703407697, 0.10268615005770698, 0.21215055749053136, 0.1399068153114058, 0.13672225963091478, 0.21561525907600299, 0.11481552966870368, 0.1596042310120538, 0.13289424707181752, 0.0874402177578304, 0.1720302173634991, 0.12782395351678133, 0.2809289004653692, 0.15087899373611435, 0.13427502766717225, 0.22548604581970721, 0.17867500690044835, 0.09461988796829246, 0.12149322603363544, 0.09400633964105509, 0.1319118365063332, 0.07965134820551611, 0.09833027012064122, 0.12756120355334133, 0.13114501984091476, 0.18845298065571114, 0.08070473035331815, 0.11264013897744007, 0.17398976924596354, 0.1387864098069258, 0.12948194111231714, 0.11321085796225816, 0.16854374116519466, 0.05870810404303484, 0.11181560548720881, 0.13502014393452555, 0.23501477669924498, 0.09129523707088083, 0.14220576616935432, 0.14823954552412033, 0.10780484648421407, 0.09265777567634359, 0.19808875891612843, 0.1388716825749725, 0.17885240988107398, 0.08874734761775471, 0.13052302587311715, 0.18653730454389006, 0.18234310147818178, 0.17948676802916452, 0.09069397128769197, 0.23643012653337792, 0.1294330632663332, 0.12926106312079355, 0.05561359314015135, 0.07877108684624545, 0.14689610979985446, 0.07990051686647348, 0.1349016823223792, 0.10210143416770734, 0.15061195415910333, 0.13202318834373727, 0.1380516539211385, 0.11714774358551949, 0.16966356779448688, 0.12516897957539186, 0.2043754028272815, 0.14823887759121135, 0.09941040669218637, 0.15595727280015126, 0.19777383597102016, 0.10044710536021739, 0.13303902524057776, 0.15578745456878096, 0.21158803923754022, 0.11462540627690032, 0.19567674928111956, 0.11395460867788643, 0.11946234633796848, 0.11626435778453015, 0.08980088561656885, 0.0921973175718449, 0.14805865444941446, 0.08938701212173328, 0.12977528240298852, 0.10222969955066219, 0.08758847659919411, 0.10763387792394497, 0.16086310643004254, 0.2976319729350507, 0.1906181371305138, 0.1307815159088932, 0.18346102820942178, 0.08862280781613663, 0.09656608119257726, 0.17289104929659516, 0.08450445966445841, 0.121617083059391, 0.13399126008152962, 0.16355860163457692, 0.11754250677768141, 0.13320320314960554, 0.12762691330863163, 0.13935232709627599, 0.16368678538128734, 0.10207747021922842, 0.2124885018565692, 0.13531213451642543, 0.10864413387025706, 0.08086065558018163, 0.1540667554945685], [0.017516445914225187, 0.06390911206835881, 0.02829266210028436, 0.03337507492688019, 0.01927311317558633, 0.03640478149463888, 0.044803655619034544, 0.08655980054754764, 0.006384911221175571, 0.04578524982207455, 0.0351026685530087, 0.047912048394209705, 0.01224587174874614, 0.03890108797349967, 0.03893700792104937, 0.04345247187302448, 0.03965817508287728, 0.01606568450370105, 0.06637222599238157, 0.08495213056448847, 0.05156907383934595, 0.03330507184728049, 0.05034861198510043, 0.030555321936844848, 0.006170945407575346, 0.037249616434564814, 0.03980102737841662, 0.021456609974848107, 0.03174845420289785, 0.05771877295046579, 0.06568448516190983, 0.06165943981613964, 0.09595200594048947, 0.0859288711217232, 0.021209777223702986, 0.052556078298948705, 0.006785641280657728, 0.06997331205639057, 0.014079747415962629, 0.048039853645605035, 0.026617002113198396, 0.06826820550486445, 0.03142422101518605, 0.02507940385839902, 0.03394955288968049, 0.022146953888295684, 0.051064791914541274, 0.07238639038405381, 0.061203664663480595, 0.027832274499814957, 0.028884539715363644, 0.05045561112638097, 0.027402112718846183, 0.058311708125984296, 0.015219804990920238, 0.004419003307702951, 0.027032259713450912, 0.07889130734838545, 0.06457058829255402, 0.01741370855597779, 0.11410031453124247, 0.037354793603299186, 0.028826258858316578, 0.03752374352188781, 0.058339019160484895, 0.03806840941251721, 0.11540754829184152, 0.016102663867059164, 0.04329701048845891, 0.046288377707242034, 0.02638442972966004, 0.044172273483127356, 0.05576505063800141, 0.013869001595594455, 0.0076921714207855985, 0.03143590613035485, 0.03317614595289342, 0.02644790005433606, 0.01227382195793325, 0.03539685960276984, 0.033417522063246, 0.0027260246088189888, 0.009537924233882222, 0.025555033316777553, 0.023176296017481945, 0.023344281144090928, 0.07983318922924809, 0.05042586213676259, 0.01946599735674681, 0.04127419422729872, 0.018613076717883814, 0.02174511246266775, 0.07042338751489297, 0.03416109466343187, 0.029585999145638198, 0.07725962888798676, 0.00913026344278478, 0.027338321415300015, 0.06954496668186039, 0.06537434906931594, 0.020189235110592563, 0.04454380745301023, 0.07988240104168653, 0.04835269857721869, 0.007515166416851571, 0.03590742751839571, 0.047920349315973, 0.031527464889222756, 0.02032402582699433, 0.01214804648043355, 0.038571956611122005, 0.036272226498113014, 0.08896117520635016, 0.035394781589275226, 0.03108904857072048, 0.03562122939911205, 0.07137981549021788, 0.06759651732863858, 0.04082255654793698, 0.07552428724011406, 0.07806686291587539, 0.05801204744784627, 0.04411081623402424, 0.041172453202307224, 0.01925422180647729, 0.04068391222972423, 0.04036123755213339, 0.004797112706000917, 0.03302805409475695, 0.049710390958352946, 0.014592892439395655, 0.042626591384760104, 0.0555689418251859, 0.0382739954511635, 0.10275467997416854, 0.018037374211417045, 0.04862350826442707, 0.0511214660218684, 0.09891333102132194, 0.02811510697938502, 0.015048794684844324, 0.0074941705952369375, 0.06728353881044313, 0.032331637557945214, 0.06203881828696467, 0.048635916973580606, 0.017663760372670367, 0.05019483527576085, 0.042079439299413934, 0.04112859969609417, 0.039081147842807695, 0.004091013461220427, 0.03238472338125575, 0.040650192750035785, 0.028344259917503223, 0.03506835535517894, 0.049709838058333844, 0.05734566933824681, 0.12746166670694947, 0.02902022286434658, 0.04005960647191387, 0.007148809854697902, 0.011224325880903052, 0.046791453642072156, 0.032977573209791444, 0.033677848914521746, 0.01762275856890483, 0.022672156956105027, 0.041074370965361595, 0.0402152311289683, 0.011395435449230717, 0.07831383481970988, 0.011132949875900522, 0.031014624146337155, 0.025767990737222135, 0.02459645867929794, 0.01595668712980114, 0.023243260002345778, 0.016364896182494704, 0.04780401766765863, 0.03093118819379015, 0.024114331718010362, 0.02372215676587075, 0.12155832722783089, 0.02713953344937181, 0.07888617910793982, 0.039466181478928775, 0.028185278897581156, 0.02487628546077758, 0.10713144394685514, 0.01056036438967567, 0.023295347637031227, 0.0485523919633124, 0.008865245290508028, 0.07193673052825034, 0.010756494539236883, 0.0592176997452043, 0.014579636754206149, 0.05792490075691603, 0.0051183188588765915, 0.02303395765920868, 0.02748869352217298, 0.015120480584300822, 0.012647567527892534, 0.06478181094280444, 0.024008768632484134, 0.04496765912335832, 0.050332362661720254, 0.07244246706250124, 0.022557305892405566, 0.028694958091364242, 0.04564645336358808, 0.016197716286114883, 0.02839683922502445, 0.07902573997853324, 0.04553525366645772, 0.03806339249422308, 0.019979235148639418, 0.09432728140382096, 0.034650129164219834, 0.039265219020307995, 0.015439380513271317, 0.020623024138330948, 0.07370987717877142, 0.07572761343908496, 0.016041625931393355, 0.0553558341198368, 0.029173296388762537, 0.05303585079673212, 0.07538816251326352, 0.07033271191176027, 0.08720747282495722, 0.015619078585586976, 0.03563747501175385, 0.037026048157713376, 0.035782156701316126, 0.12401216430589557, 0.038195917804841883, 0.027888490330951754, 0.06550346792209893, 0.041592753696022555, 0.04271650999726262, 0.04763289325637743, 0.012782076228177175, 0.05518594538443722, 0.0841686972125899, 0.06739408170687966, 0.033883505457197316, 0.05524531348783057, 0.07875782466726378, 0.007961019055073848, 0.04578139436489437, 0.017604305066925008, 0.015659824348404072, 0.03794197713432368, 0.05622281474643387, 0.04111091802769806, 0.02886861879233038, 0.037288119056029245, 0.024400620750384405, 0.0302366771211382, 0.01626757650228683, 0.03818466684606392, 0.027789148298325017, 0.06879533815663308, 0.016074942795967218, 0.024496259466104675, 0.023647029156563804, 0.04237502929754555, 0.04306759037717711, 0.01852473331382498, 0.011714748197846347, 0.037650053345714696, 0.04264264032826759, 0.04492689295148011, 0.03131879522698, 0.026950085411954205, 0.07734305370831862, 0.06144935636257287, 0.08484915757435374, 0.0697639818827156, 0.06723478712956421, 0.028698175301542506, 0.0745623376860749, 0.021781570467283018, 0.044725704137817957, 0.026172752513957676, 0.006574628287125961, 0.033935626488528214, 0.036860935142613016, 0.01922959363582777, 0.01741755288094282, 0.0471474359073909, 0.03916865447536111, 0.06475129383034073, 0.08363117449334823, 0.07753357785986736, 0.041566414874978364, 0.09749481221660972, 0.07282261736690998, 0.037520949335885234, 0.04715210772701539, 0.0197037851830828, 0.029098827435518615, 0.01903179829241708, 0.012963621320523089, 0.07367207217612304, 0.05931764106207993, 0.09951594009180553, 0.0275021894776728, 0.03391424521396402, 0.0461596002423903, 0.0039994226972339675, 0.0460039013705682, 0.08657034646603279, 0.018999628046003636, 0.06525853692437522, 0.0010087007990478014, 0.04875259372056462, 0.05721248351619579, 0.055612906653550453, 0.03354863729327917, 0.036671550187747926, 0.07204284280305728, 0.02112769569066586, 0.028528323673526756, 0.02317904381925473, 0.03668779580038972, 0.04473743749258574, 0.0361431336204987, 0.04168543680862058, 0.020849676038778853, 0.01765282853739336, 0.03656241737189703, 0.05272501708532218, 0.0191355041533825, 0.031203684411593713, 0.03671618294902146, 0.05391853897890542, 0.01162095464678714, 0.034081770209013484, 0.03398738757823594, 0.03420811342948582, 0.060392534360289574, 0.046320980254677124, 0.07271221547853202, 0.07698727553361095, 0.043032160247094, 0.035378988686716184, 0.04276814121112693, 0.047304132967838086, 0.04831488986383192, 0.08253160849562846, 0.14568102109478787, 0.10388557944679633, 0.2025940257590264, 0.244249097595457, 0.08345921887666918, 0.17072244925657287, 0.22122732043499127, 0.1372189642279409, 0.12391019321512431, 0.12658619962166995, 0.19640711165266111, 0.12208291431306861, 0.23908836592454463, 0.12713752628769726, 0.17602791456738487, 0.08021338406251743, 0.19327495159814134, 0.1720812325947918, 0.14642481633927673, 0.13347309257369488, 0.16015753179090098, 0.1541634276509285, 0.08179821074008942, 0.08678432248416357, 0.0828013865975663, 0.1971511889132671, 0.08933630117098801, 0.23322235647356138, 0.14572964661056176, 0.20363236457342282, 0.14509105822071433, 0.26224687637295574, 0.17434494628105313, 0.10441375110531226, 0.22914342378498986, 0.10245823650620878, 0.11367083367076702, 0.12538265873445198, 0.12603462062543258, 0.11113361630123109, 0.17660401412285864, 0.19338952435646206, 0.08560248199501075, 0.09439908419153653, 0.12532720546005294, 0.20055970991961658, 0.19398604781599715, 0.2135522072785534, 0.12380833344650455, 0.1055883259687107, 0.19722957455087453, 0.14734565833350644, 0.0861499272286892, 0.15687119797803462, 0.19379314879188314, 0.1259071344975382, 0.08702480801730417, 0.16911952901864424, 0.14088585652643815, 0.16905680269701406, 0.1271932022063993, 0.10453696246258914, 0.1588995469501242, 0.2855479088611901, 0.14762237551622093, 0.23931357805849984, 0.13688072300283238, 0.23389227833831683, 0.13058987853582948, 0.2189784645452164, 0.20100628986256197, 0.12052119069267064, 0.244848960719537, 0.10623917463817634, 0.09349143016152084, 0.08669691233080812, 0.1276540313847363, 0.115040452365065, 0.09385260374983773, 0.1388748738099821, 0.10518326176679693, 0.1040268324140925, 0.1214882759086322, 0.110038636776153, 0.09143210394540802, 0.2586033765692264, 0.2570168726379052, 0.07384773853118531, 0.06349742048769258, 0.09945739948307164, 0.1172415807377547, 0.15048984118038788, 0.15572155185509473, 0.18413005949696526, 0.17111516412114725, 0.1284629723522812, 0.10395131146651693, 0.2688455191673711, 0.15360649034846574, 0.12741829559672624, 0.14168207708280534, 0.15634299663361162, 0.15800981578649953, 0.17178425478050485, 0.11684096942190081, 0.12799994641682133, 0.11424651762354188, 0.11732018901966512, 0.1339036866556853, 0.11989964201347902, 0.13801922206766903, 0.15497027576202527, 0.10538755275774747, 0.11226708360482007, 0.10310360812582076, 0.2073192354873754, 0.11217643768759444, 0.1405704882927239, 0.12668955110711977, 0.2175077801803127, 0.15367396641522646, 0.1794507441809401, 0.15946739382343367, 0.1614416402298957, 0.13999524962855503, 0.10804864199599251, 0.08599607259384356, 0.09974765343940817, 0.10935427271761, 0.1441624978906475, 0.08948127971962094, 0.13061830279184505, 0.11765160990762524, 0.1956728010554798, 0.1884343972778879, 0.07394547938019969, 0.13443717209156603, 0.3068873262964189, 0.09999488509492949, 0.21137020405149087, 0.22176853904966265, 0.14634248247602955, 0.12478534859837964, 0.16118279396323487, 0.12491494242567569, 0.07997922904905863, 0.23698954260908067, 0.10486268365639262, 0.15409287909278646, 0.09225078189047053, 0.14819317613728344, 0.19702024437719956, 0.11791404074756429, 0.105779213772621, 0.11366356804501265, 0.1607915188651532, 0.09276268567191437, 0.22962736344197765, 0.08037235951633193, 0.13440521521260962, 0.10328847711207345, 0.11058551797759719, 0.09422847928362899, 0.12221005163155496, 0.11804959402070381, 0.12319768691668287, 0.10499051859369501, 0.12198512151371688, 0.1607706496724859, 0.11598324708756991, 0.13582457264419645, 0.1226140397193376, 0.1071700059401337, 0.16370305325835943, 0.10370780539233238], [0.021755302150268108, 0.067928183125332, 0.032475488042109646, 0.05971094222331885, 0.06227200850844383, 0.01888866027002223, 0.021972328395349905, 0.029588912075269036, 0.03779143989959266, 0.04186087680864148, 0.02656166016095085, 0.014241773096728139, 0.06710061425110325, 0.039865675862529315, 0.01994899819692364, 0.04319601161114406, 0.06598709587706253, 0.07733609236311167, 0.03694818944495637, 0.00784923677201732, 0.0227611775699188, 0.018114195772795938, 0.0835728416859638, 0.04916684942145366, 0.039941701470525004, 0.03235763870179653, 0.017833010861068033, 0.04301746201235801, 0.038705810366082005, 0.033001982446876355, 0.0758549066085834, 0.04784649077919312, 0.03503373416606337, 0.061066541748004965, 0.02583378583949525, 0.0037076487296872074, 0.04274349819752388, 0.021282073539623525, 0.03061386069020955, 0.022023621932021342, 0.03879313517245464, 0.023198432427307125, 0.07600993383675814, 0.023920827843539882, 0.05393003113567829, 0.02782448565994855, 0.046051621466176584, 0.04390236921608448, 0.019846158793370705, 0.03258479155192617, 0.04368607398646418, 0.03479033199255355, 0.014568915503332391, 0.07016474162810482, 0.10779313539387658, 0.023190665851871017, 0.02458882940118201, 0.04800481314305216, 0.05476784906932153, 0.018518976103223395, 0.02059121754427906, 0.06194524459715467, 0.06151063178549521, 0.017506805415905546, 0.02908010304963682, 0.02795426316879457, 0.07880828328779899, 0.06486669037258253, 0.054762509316788055, 0.11317910888465121, 0.014697657716169488, 0.06402894665370695, 0.04376627417514101, 0.05461687396746129, 0.05266299580398481, 0.017573502227605786, 0.01066542467015097, 0.04666419386921916, 0.023881781598902307, 0.05431803707324434, 0.03941882503568195, 0.04528702382231131, 0.009504874542471953, 0.03605025012802798, 0.06569719073013403, 0.024145793213392608, 0.018150390314985998, 0.018185343615186866, 0.013043796461715829, 0.03952210601710249, 0.03259535973484162, 0.02697673779039178, 0.030740849579160567, 0.019546242074284237, 0.045570075235445984, 0.09689179496490397, 0.026424758034409024, 0.013265281158965081, 0.05077457506558858, 0.060208429786143824, 0.021215929627942387, 0.02702743575355271, 0.07736649815342389, 0.035467007401166484, 0.024231809984485153, 0.04681703547248617, 0.026985179720213637, 0.0463819142896682, 0.039619063900318, 0.08330889686476439, 0.011142779621877708, 0.022412607504520565, 0.05657428104314022, 0.03161195098073222, 0.03350835722812917, 0.05295954688335769, 0.017751814339135308, 0.06341450032778084, 0.023374698066618294, 0.055453348613809794, 0.013820669228152838, 0.025521811076032463, 0.02840018816641532, 0.048004679556470364, 0.03246883468818851, 0.046852502709953114, 0.028348072701191995, 0.043051322500105016, 0.014360791319631971, 0.03820509075012524, 0.009818404105317313, 0.019985281796834897, 0.04692164860898629, 0.0560785301058786, 0.03122293572232593, 0.08454550043097697, 0.030458610817731824, 0.020143795263720676, 0.02881392436393071, 0.03514739037200343, 0.017339564292342402, 0.03768894559470937, 0.015481885166082066, 0.010671125291992212, 0.007598294378112769, 0.07382893993053585, 0.030205902112356853, 0.0639937688538339, 0.025368401729792822, 0.021243006885924842, 0.05269949833746068, 0.05998299500788562, 0.024382360206800513, 0.041443730442551896, 0.029906491909059696, 0.05282001569867134, 0.037028319129603915, 0.03413783204450738, 0.026369052429799922, 0.01111152221710654, 0.035460075741866603, 0.034374128154013306, 0.040970262489281595, 0.03608383973187301, 0.03189087234204635, 0.0519427600374911, 0.013881657068850473, 0.03968540077039506, 0.0246000970582827, 0.059337857164791785, 0.06202619806572329, 0.0028058989482815377, 0.02941203045338625, 0.008742714853724465, 0.07186477931099944, 0.01911672039568657, 0.02113292783178622, 0.06127863271103706, 0.00966393719863845, 0.05237943973043002, 0.011276999812253052, 0.036476450695772655, 0.10486741855856963, 0.01505943429947365, 0.0442393005505437, 0.017177200934384018, 0.025649432645877823, 0.023756566442898475, 0.0394156263791956, 0.03587500308640301, 0.037650624799425714, 0.06100197118939832, 0.027485220271046273, 0.08854786574374884, 0.01781861876224866, 0.027633005993266124, 0.020892176980851218, 0.034385902326903306, 0.055986778388614766, 0.042008130039903335, 0.029637405859830324, 0.014586951547244098, 0.02132497524144128, 0.059192689368501306, 0.04001168599643279, 0.05130568562890403, 0.049213192833121866, 0.03452570439549163, 0.02247120748506859, 0.045288634282769635, 0.056196026926045306, 0.033891320272232406, 0.030936130897316616, 0.018844289115804713, 0.030015852935321163, 0.04751718130137306, 0.06783775985240936, 0.014430082865146687, 0.011046274448744953, 0.0510761616169475, 0.02930353773990646, 0.07316917064599693, 0.03134340855467599, 0.026657131893443875, 0.032113464694703, 0.02616400259285001, 0.06452649729908444, 0.028716788365272805, 0.08160029479768127, 0.020668846191256307, 0.01909383812744636, 0.030448890538536943, 0.03079073674598476, 0.05745010435930453, 0.033580946692381985, 0.045147481505409814, 0.06685178697807714, 0.06755582537152804, 0.07105082884663716, 0.03559293872967828, 0.07961376584717073, 0.006146051919131423, 0.04001902954769321, 0.0812049898377154, 0.03185315268638078, 0.042732755609904416, 0.08134216841426678, 0.034098698597517796, 0.03948595229303464, 0.043222469175816514, 0.03766314111999236, 0.005872279671166325, 0.02356605342356488, 0.02626513691211585, 0.051365536128287204, 0.06746097147697583, 0.03483098313154187, 0.036917920951964334, 0.02751925145275891, 0.019086839674855582, 0.048818162467796355, 0.015961331118887756, 0.05441947010695003, 0.07489051538868807, 0.005983612027193885, 0.017435375557397492, 0.026333896894357167, 0.0302434714831179, 0.0604541660140967, 0.020542170859698672, 0.06746405138983391, 0.07552274357294664, 0.09129178608418442, 0.021368852867453825, 0.052975529033574276, 0.03225071748602204, 0.06383509768056683, 0.017592493786651175, 0.027610752695181873, 0.047235781166818924, 0.021587085102510173, 0.02526675718399929, 0.057880126987583935, 0.01387087922921637, 0.04452715736988466, 0.007452677582477918, 0.05200215782679152, 0.041413376602577046, 0.0678325722401496, 0.08449568005744368, 0.021009042975492775, 0.035950149249401875, 0.04817919929337222, 0.03610453080909792, 0.027088542337878607, 0.013626683885377133, 0.018051361839752644, 0.015376407427538652, 0.02312515462108422, 0.02349428403249476, 0.024440164233965334, 0.05963585543213412, 0.04117255339224357, 0.05644674296490848, 0.040300388864125125, 0.034363764061708935, 0.021235986168903764, 0.030464546143775806, 0.06751235036063008, 0.08216883186833002, 0.03359225702297408, 0.022462099477706943, 0.06845950891147368, 0.02306594979017973, 0.0352277352794772, 0.020002828023280017, 0.05611104359559249, 0.05452738951134961, 0.03129136915958952, 0.02969331184431212, 0.06994823488639668, 0.05526193759578746, 0.05997907275741454, 0.05995611812977586, 0.05880627533770166, 0.02465566165483324, 0.026600255550874863, 0.03504393869661726, 0.06742085097357631, 0.04209079786960501, 0.05593578542175237, 0.050601172260940075, 0.0665990485867951, 0.041063183089136146, 0.02690720411919756, 0.025833848922047764, 0.0355916065745987, 0.0605396614264464, 0.08158055366948247, 0.034065969884977676, 0.05288286818540655, 0.06321435052086599, 0.011436381591920508, 0.06308848227490671, 0.02774086231511319, 0.12578799010952935, 0.07892888970673084, 0.017233383368875366, 0.01153666522441199, 0.03579763419111259, 0.05578508862527087, 0.005016341738155461, 0.060912397675565444, 0.15078125288709998, 0.1228199337492697, 0.1999836103641428, 0.12482192163588479, 0.21443629811983556, 0.19101851095911115, 0.1477482437621802, 0.1458736084168777, 0.13719883718295023, 0.14286084508057684, 0.10662430475349538, 0.09452665195567533, 0.1154739259800408, 0.07512588752433658, 0.16757799923652783, 0.13030602189246565, 0.18848452193196863, 0.10895645929849707, 0.06400593265425414, 0.08832521401927806, 0.18984658556291834, 0.16949967190157622, 0.10118315258296207, 0.1253356659435667, 0.12399544371874072, 0.15508737182244658, 0.18195115844719112, 0.1901870235451497, 0.1296854973770678, 0.14548010687576607, 0.10445341889862902, 0.11623198530287482, 0.10664981236914173, 0.1363456345279701, 0.11085491016274318, 0.0886574735341128, 0.11940314521780238, 0.13875626376830041, 0.12342902176897041, 0.12359725922578946, 0.11143289477331564, 0.18080602458212525, 0.16025985911255702, 0.1386063202517107, 0.21809283003676683, 0.13014527270570397, 0.17371959780575708, 0.06593558340682648, 0.11904429455171339, 0.18957225809572265, 0.12475529161747545, 0.11855225806357339, 0.06988631008425727, 0.21526781521970406, 0.10093812510604039, 0.11536462247022428, 0.12737520650262013, 0.15292916184989735, 0.1129130192566663, 0.14230096887331456, 0.19695616734679788, 0.2571030508261174, 0.1265347984735854, 0.14735080883838236, 0.14433616044698283, 0.1414767248206772, 0.20540124387480319, 0.1245453825686127, 0.19566339062293991, 0.14963944384362549, 0.1790019971667789, 0.17166031611850485, 0.0987088841793593, 0.16502594633493572, 0.13552861899370328, 0.09933555367751978, 0.14804865029873326, 0.12038824977935292, 0.11844160384498537, 0.09818428225116804, 0.10724661042331718, 0.07602186757139862, 0.12163669802248478, 0.1579117780784145, 0.07236244127852842, 0.12819738738471642, 0.17533385806018487, 0.1932877313811332, 0.11794619058491662, 0.16991048032650724, 0.20870464708423242, 0.1347135182004422, 0.08049016061704606, 0.16425902576884255, 0.1464652337017469, 0.15770884521771222, 0.1801904130843468, 0.08156714306096546, 0.16128924762597308, 0.148660788545385, 0.15892044582869858, 0.23150355729740113, 0.16002833872335032, 0.1565460185520351, 0.14393002755241469, 0.13931872264947742, 0.1699484486016445, 0.18475083634257317, 0.17562586348503828, 0.11663532772217877, 0.08784652134636417, 0.16824631806230173, 0.22033598623238504, 0.17658283322816715, 0.13925535808084533, 0.11382840646547265, 0.13021549471886829, 0.13832372525939718, 0.08804768789559603, 0.14887222641846165, 0.12137394063756801, 0.12695816403720528, 0.10934959718724713, 0.11501387605676427, 0.10961592430248857, 0.12003038616967387, 0.14778607845073566, 0.11740248577552848, 0.08430921545368619, 0.1262647457770072, 0.08985274689621292, 0.18804776802426204, 0.2928712440188974, 0.1454633046523668, 0.2698651410173625, 0.10822660900885239, 0.11181265173945576, 0.08482035482302308, 0.07527021298301406, 0.21446932369144633, 0.098848912602989, 0.14881738170515746, 0.2037060449947603, 0.1877260024775751, 0.15535726124653593, 0.20178284350549802, 0.10969948270940222, 0.11833109805593267, 0.09892378788208589, 0.10640819135005586, 0.19025715650059283, 0.13768668053671718, 0.14335979096358642, 0.21721703640650958, 0.15583527856506407, 0.12191202738904394, 0.14473456016276032, 0.14722768653882667, 0.15210278041195124, 0.13405032019363716, 0.09283902298193425, 0.23302319372305647, 0.12819486408261582, 0.18181302992161363, 0.11730409925803542, 0.12069368807715364, 0.22319698036881164, 0.09670909304986708, 0.17689345171675086, 0.10897422631387599, 0.14959944208385423, 0.06929038776434027, 0.12797832023352385, 0.21572520083282143, 0.06968753325054422], [0.03497698584396858, 0.10220906784525141, 0.013833958309987793, 0.07292374983080663, 0.08031209712498821, 0.05135248546139337, 0.06205346086062491, 0.051539900014176965, 0.08082333297352307, 0.018397996755084023, 0.03535077965352684, 0.032510068413103, 0.03397873784706462, 0.03818637378572021, 0.06701873309793882, 0.025262790404667612, 0.010008766839746386, 0.05524643784156069, 0.04235770014929585, 0.024711742044019047, 0.0727663106226828, 0.024803623637126293, 0.03375719934410881, 0.0815123577194754, 0.024771381031314377, 0.054899587703403085, 0.02167418355384143, 0.045727892938884906, 0.01512186654508696, 0.06740085751516744, 0.03316062022349797, 0.034470614773454145, 0.03328154576593079, 0.015025327975308755, 0.022864421443955507, 0.021180627518333495, 0.030415248984354548, 0.04754592839162797, 0.028410732229531277, 0.04303483568946831, 0.06788778060581535, 0.030265546665759757, 0.06735918592312373, 0.0682119581324514, 0.018286756239831448, 0.02164381858165143, 0.02167010916309664, 0.03299824944406282, 0.023114714458642993, 0.008176787359843729, 0.010630297892930685, 0.04282334957679268, 0.009280232934543164, 0.030678407129016705, 0.04765434132423252, 0.05701056739781052, 0.03857128867821302, 0.05456661572679877, 0.019150959378748666, 0.050821104014175944, 0.09693626445368864, 0.07868335014791228, 0.07863836857723072, 0.018049024074571207, 0.10946647060336545, 0.041092791070695966, 0.02489324539055815, 0.04076414952578489, 0.03586437182093505, 0.0531802875775611, 0.09786349633941427, 0.0663478761271108, 0.05472699383972213, 0.052134171055513434, 0.02507775443518767, 0.03492699848720804, 0.05590648914221674, 0.011840039423987037, 0.07447682743077166, 0.019673791284731124, 0.03584571793908253, 0.033887475947267376, 0.046036151397856884, 0.07257282530190423, 0.03393071347090881, 0.008855202177073807, 0.042286817624699324, 0.008738812084629899, 0.02888590155635029, 0.0069997722221160075, 0.024754990699875634, 0.022628913866356015, 0.025961325773096178, 0.0076470344629342435, 0.019645149950520135, 0.014739863654540386, 0.0644075458694715, 0.08543726507923566, 0.03520475096593145, 0.0466453507397091, 0.028714368963846937, 0.04078412814124022, 0.03042288382857805, 0.01626057804969605, 0.02349140078877099, 0.030332852038554847, 0.10262763913488016, 0.009872341543086804, 0.03455001344264019, 0.018535659582994413, 0.03404552371648606, 0.029616868778248318, 0.05787472786323633, 0.09632949935621582, 0.020423571950232144, 0.05738970095990226, 0.0371620652731508, 0.05406652322562877, 0.009153968567261472, 0.025705127118271776, 0.03875745642289985, 0.0312704814132303, 0.03746589682123158, 0.010120417391590308, 0.03193910823029, 0.05226605440839194, 0.0360286016803002, 0.04593671845213976, 0.018190046976087615, 0.0699422977049835, 0.011218673498660792, 0.07562112266896293, 0.03274477261584252, 0.04723589248897042, 0.05893224377359729, 0.037143878944334574, 0.025695280673971865, 0.09669744133134373, 0.032306809007423, 0.0159296506899409, 0.016266802813333925, 0.011119269311166136, 0.004926184246869525, 0.035048729259870015, 0.05366457604395691, 0.08321911926032044, 0.06002384652674664, 0.04676591634051874, 0.022992289777903352, 0.02936022854555631, 0.031011603605293203, 0.02307896520505892, 0.013483394650393166, 0.027076836813648697, 0.045456960797309875, 0.040553361031925306, 0.05223673586442601, 0.019731192696781363, 0.020845842846028972, 0.02640918035467621, 0.041078834983636625, 0.03173396376951132, 0.06016294726578053, 0.04872319725109264, 0.06616718543227762, 0.020285981481720228, 0.03657744586234912, 0.002510821263967955, 0.021521113740163855, 0.015398298928630538, 0.02069931877485942, 0.038802675480837934, 0.04508933794568293, 0.07404623334878124, 0.06546137330587953, 0.03993168247689027, 0.07071715182974003, 0.10296594715327956, 0.03912229622073937, 0.0356640216341475, 0.06573083228431642, 0.046029245713725686, 0.04514804182690568, 0.016271608219540212, 0.022746347603970207, 0.038454099849332124, 0.03986874464317225, 0.009311835437983973, 0.04616548918420449, 0.047542206521029584, 0.009542359493934782, 0.06339677041978575, 0.04026742637506686, 0.06487475009635091, 0.016229435677814763, 0.006742255327480962, 0.022381561611837242, 0.04463430122996215, 0.09070521482499316, 0.08133890296448953, 0.01050275703164516, 0.02279482283483958, 0.0518043680494884, 0.05911633350478951, 0.0524972964922199, 0.03242054313886911, 0.09201711669447832, 0.03293308887805324, 0.028221571774338372, 0.06678672289126553, 0.0583709983038716, 0.050933131205965765, 0.00790738868090557, 0.05291860259603709, 0.048256835361826234, 0.02433334506349638, 0.02230028901976766, 0.011093663360952633, 0.007879321583459387, 0.05483689848915674, 0.05855373732629232, 0.028790943761123344, 0.0511240338528296, 0.01720302396279294, 0.029283540570759214, 0.08340082669747062, 0.029994475371495355, 0.016186745488084853, 0.012105578935006633, 0.06685975764412433, 0.01785243657650426, 0.020168332521279808, 0.0338046745309839, 0.04391295966343023, 0.019058202051382978, 0.08877871820004657, 0.05630924155411776, 0.05991411999275442, 0.03184096662153024, 0.03569586348021403, 0.04691304340667557, 0.0726358410611283, 0.0021833430355400196, 0.012312281905906275, 0.032705390549381264, 0.019675960211316124, 0.03984475100878626, 0.049864831889863126, 0.02951409431261709, 0.06002373520459514, 0.08186975377611816, 0.07888162232120521, 0.01782578790880507, 0.013479782246577088, 0.02869886735425098, 0.05951509316219017, 0.11631684988969937, 0.04373634707008023, 0.03276358234870713, 0.04518392095633317, 0.04752066197397653, 0.016082056281447876, 0.053841834305785596, 0.03025977832294302, 0.07902568802819587, 0.03429786505876109, 0.008449730721622473, 0.05039651019615121, 0.012619806566362968, 0.020487862348090857, 0.019933800867875107, 0.05357417503546458, 0.034185741387773305, 0.07789490729919635, 0.11300570608000271, 0.02037459948041942, 0.002445470986458531, 0.027573060870054178, 0.07985132731846534, 0.024389341961068567, 0.018149722382077016, 0.0967787139234133, 0.04258200686308555, 0.028111524261476006, 0.03689558601763565, 0.031102767170523293, 0.019298455663374625, 0.04120912271901034, 0.02815509204083355, 0.016616436005278956, 0.04237475099216681, 0.0413803436094895, 0.044178745010867715, 0.024909823114285246, 0.07693055318668485, 0.012222506156831514, 0.036423398269107565, 0.05683323492121417, 0.027257774272584356, 0.029476220661308616, 0.06350858981022611, 0.048527010512771085, 0.03410873243410606, 0.046967858434072696, 0.01780541038897354, 0.029317037406144664, 0.053864406727370806, 0.03973168852098752, 0.027672195101331454, 0.13726062839850783, 0.03267930034780875, 0.009746431551320711, 0.06723804515786469, 0.014629286433773814, 0.09195948150590993, 0.03217563440557569, 0.05318051764334086, 0.06390897848177701, 0.02873251632991014, 0.03884002777340356, 0.053290284995455295, 0.05162882043805439, 0.024342551405425183, 0.039374400075757876, 0.04087340479600243, 0.033971052907872945, 0.024556414246035274, 0.08963437736383639, 0.01097392154406407, 0.028895545765408315, 0.01075487294656341, 0.05383190436987206, 0.0029236051932457485, 0.04784548145835288, 0.03376374137587845, 0.032195742896874435, 0.05344752382370643, 0.011707632856996497, 0.07274185685673729, 0.03161248161632102, 0.03992499943706207, 0.04117199678148609, 0.017345521882816684, 0.028109952763770707, 0.025874151251628064, 0.016842278964759316, 0.038710400549462065, 0.046500954777002335, 0.011416899287723936, 0.053737540292786434, 0.0519593581702793, 0.015141159601625986, 0.2355610122322105, 0.2841532352613285, 0.10525032223085873, 0.10455001684022136, 0.11956287766224705, 0.1318722651922144, 0.1437116728629917, 0.11994300570222549, 0.22156900522531942, 0.10678034872398712, 0.1464100179146044, 0.11220620523090474, 0.11360864169546403, 0.17947489366633818, 0.101158557808958, 0.11111567117040977, 0.09243976979632862, 0.1284521518391557, 0.2666157216299325, 0.14995769161032513, 0.10342279099859297, 0.1368660433217883, 0.19542663067113608, 0.19931968505261466, 0.12849932274548337, 0.07678776397369802, 0.07951920881168917, 0.2830574690597132, 0.09115454071434215, 0.1124819353572093, 0.19506373530020937, 0.07595023547764868, 0.12654162623221055, 0.07318086689338088, 0.12669057527091354, 0.18729626928688958, 0.21517078683245927, 0.1931505824904889, 0.0929920760972891, 0.18277192924870178, 0.1689217466628179, 0.1235695845389273, 0.184005556802731, 0.13072497909888625, 0.10645333619322628, 0.12473192880861461, 0.12727783672744408, 0.07350682557444088, 0.06342916516587138, 0.12063306945492513, 0.11291690068901516, 0.11827136258943938, 0.0746860091749113, 0.13059689925285056, 0.12009086378384382, 0.14027063094545156, 0.08728025524760596, 0.1607715105637908, 0.09143885006778874, 0.19346506014699116, 0.11056697170715779, 0.16592321771895513, 0.14615167630836368, 0.2592241979436949, 0.1713422909961082, 0.1299000225844793, 0.08619461936177686, 0.12513372756075114, 0.12395757192280143, 0.14227033301722258, 0.1718408361193724, 0.13713382504647598, 0.12959118525031954, 0.16903217823710293, 0.13952463894383982, 0.12908613891340792, 0.1507343046250753, 0.11439523659646511, 0.12990422314032912, 0.16282865486573428, 0.2036024263361469, 0.10297188433469273, 0.11124568060040474, 0.15545768867013976, 0.10450369198224507, 0.12024684838252142, 0.12578497698996216, 0.1835418926202692, 0.14862001495203003, 0.09325827704742551, 0.14647197240265086, 0.1039074728032574, 0.07156031322665513, 0.11497150684590451, 0.1272622070973739, 0.16472074552439153, 0.18761530373012647, 0.2529498439980671, 0.21391571121057495, 0.16814074013382196, 0.0935352391388733, 0.10412949370220304, 0.2550650539342314, 0.153865069441963, 0.10544431963353418, 0.13460507558193058, 0.20877716975519434, 0.10031970829004422, 0.18824747996404767, 0.09294190691434778, 0.11582012302824296, 0.11228870978811756, 0.12026165422867052, 0.21831606805790216, 0.14265372650697827, 0.297255318146199, 0.14675171754788607, 0.08940837113186717, 0.17572054668562487, 0.1048483230988495, 0.15397784620290622, 0.1314161263871938, 0.16233952017500997, 0.10753034832305275, 0.08266851989901625, 0.11325713086989708, 0.14197596756275743, 0.12210362023324706, 0.1331377457245253, 0.14177358389133587, 0.10758169009932317, 0.11405932571506128, 0.15366042964160442, 0.2667689009103924, 0.11991010629571974, 0.06265106043429114, 0.1110152511682827, 0.13262780121294782, 0.18053085106657818, 0.09461402500164695, 0.10051601377199404, 0.15049355191877112, 0.07620234304340556, 0.09043622339959256, 0.14827668259385973, 0.1953165850136429, 0.14450112503254786, 0.24785437679383904, 0.17848616000264883, 0.08502461612806655, 0.09014531635330059, 0.15923907951219007, 0.06311465782346204, 0.228206061583478, 0.11679249233566225, 0.14139134815195575, 0.13678039947990328, 0.16852940287208185, 0.08525518656824715, 0.12647870695218444, 0.1513705775141716, 0.1251157675869763, 0.18595856294268742, 0.2003876949311234, 0.13956216193037108, 0.11920872479095124, 0.08693656665855087, 0.11039635195629671, 0.12674102646997198, 0.08115389297017828, 0.12814003421226516, 0.13159862050088122, 0.07392811312456615, 0.1730733207659796, 0.17733958637109026, 0.18677661748370156], [0.020853696623817086, 0.012608568595169345, 0.04464984551304951, 0.01921430910442723, 0.03101680977124488, 0.04482869939238299, 0.011908343913091812, 0.015438078971783398, 0.015006418052507797, 0.08636742102680728, 0.01882414351712214, 0.024472000513924286, 0.060672940016957, 0.07095210836268961, 0.019957345502916723, 0.09840225844527595, 0.029638981068274006, 0.03154111669573467, 0.10191489534918219, 0.03753129487449769, 0.07952208834467456, 0.04680303856730461, 0.008313550333696185, 0.041009741034940816, 0.07347151418798603, 0.0387617163505638, 0.008368305989279179, 0.05154998209036421, 0.012308295645198086, 0.038666149994242005, 0.016182159015443176, 0.016041273411246948, 0.03081077287788503, 0.06287002368480898, 0.06220725612365641, 0.06836475891759619, 0.029460980658768676, 0.04310831944167148, 0.0033457060908403946, 0.025617036044423003, 0.03626956960943062, 0.10517992952372879, 0.04082626728632022, 0.07871925525250845, 0.020949049612681847, 0.029687224377994426, 0.012992571573704481, 0.03586662052839529, 0.02571466742665507, 0.006726236997565138, 0.0701594130077865, 0.04576887804432772, 0.03833155642496422, 0.025029110365721863, 0.054801379301352426, 0.01635366934351623, 0.04055827404954471, 0.07220992993097752, 0.006492238298960729, 0.04312755962018855, 0.02101909907651134, 0.13727600569836795, 0.09221208631061018, 0.04509250691626221, 0.03296476003015414, 0.0339696242735954, 0.040230890444945544, 0.05539797697565518, 0.07983730072737671, 0.028225852111063432, 0.022291433342616074, 0.029044578295724932, 0.03646548175311182, 0.06313399819191545, 0.005718087359127821, 0.036084233070141636, 0.01944422459928319, 0.05565951723838225, 0.04485251491132658, 0.04128446555114351, 0.015193541312328307, 0.01464289834984811, 0.021696717012673616, 0.05509681715921033, 0.06077940110117197, 0.04304663583752699, 0.08322418070747517, 0.019569901742215734, 0.04109281704586465, 0.022978085071372334, 0.018410403608868364, 0.06403172228601761, 0.032222126246779226, 0.03845922808977775, 0.0908453916781582, 0.018028583472187165, 0.032360028417315334, 0.04586550567182712, 0.04555217092274688, 0.036192449333611876, 0.03653172214399092, 0.03455391342868097, 0.0055258428164961515, 0.04264081464498304, 0.049325962172588333, 0.047717672496219166, 0.047885939638945274, 0.04425884872034658, 0.056320548173971474, 0.10065326656331308, 0.043744685099227354, 0.07825499735190533, 0.027448398614069447, 0.035851562352036126, 0.06739049713360146, 0.05445880022307392, 0.027587514196056873, 0.014567636226274772, 0.044309121803962626, 0.03202587271516677, 0.1177004432247486, 0.019705406775756273, 0.03778538397455122, 0.02345542703551473, 0.059245786324026994, 0.012970221796422265, 0.01642616232857108, 0.048650800745235756, 0.034945526203955524, 0.021473480846907478, 0.05028086874517612, 0.027495020331116393, 0.02042543845163891, 0.047415755689144135, 0.016044574113038834, 0.009205459700751817, 0.01665698324359255, 0.021496199842658825, 0.002030892915172444, 0.04304088790377136, 0.0404966386849992, 0.046297305743792094, 0.028103614822612144, 0.01811710128095001, 0.048377723796875216, 0.02760686940746382, 0.05813664662127849, 0.057948901812778786, 0.07551993083325215, 0.01467256384785287, 0.01694472688541282, 0.004526886532403296, 0.07631186919752508, 0.10774859169032425, 0.07458020118065178, 0.045897755699115805, 0.026161803980357945, 0.04590527736581862, 0.03115454310318455, 0.03026015496288892, 0.030325610532599967, 0.029829534905729815, 0.04169488063780591, 0.04493317894230131, 0.030834664466965478, 0.026903736434178427, 0.01148661385741434, 0.0541305891238153, 0.036912551513523795, 0.03130744407826569, 0.04819696259801276, 0.03499449681839906, 0.049245164555031806, 0.01616898774955189, 0.02095108309731586, 0.017846696064225398, 0.022683667666569818, 0.03728611896804068, 0.04299394706322346, 0.037663007533410564, 0.0697517216030974, 0.050714516764855944, 0.04706376988906413, 0.016265793492493685, 0.009583711962477537, 0.04131243338633794, 0.006935073179192841, 0.038504343247041106, 0.03630646548117511, 0.021510198603209574, 0.034221371897729114, 0.050236254537594505, 0.012404917706589913, 0.05692365077266004, 0.04336818616138771, 0.003939051766792545, 0.07288201144547202, 0.042832619001274, 0.01665895921178162, 0.06369493567035533, 0.015927259119052906, 0.05305201848386787, 0.01367645045320387, 0.031255475187208503, 0.08710789144970477, 0.019962419937655795, 0.03625909048423637, 0.03674149760627188, 0.013549887371482328, 0.018684113238123246, 0.06489082501502708, 0.07865696679800749, 0.04940783961501438, 0.0463317413959885, 0.061910400763736106, 0.06468268227763474, 0.049774241633713245, 0.013614039544336265, 0.03205525063094683, 0.036023261927766725, 0.09643138881074265, 0.018993995145137887, 0.040851478042895906, 0.044917727427673526, 0.0602941738179652, 0.010522027823753888, 0.050303619282203726, 0.02191212166508194, 0.025479488249402493, 0.06205288940691389, 0.02468005048285704, 0.0765317898185458, 0.03126428076939192, 0.07658171409275383, 0.050099005457013845, 0.01021010222757468, 0.007656082170797163, 0.035279815492685884, 0.005893486541026505, 0.06470090942457318, 0.0275009055621922, 0.06924533197889104, 0.03491584400762804, 0.026013983006123453, 0.039215472861542366, 0.031173401075648144, 0.022571889094251674, 0.04104477040527854, 0.03701623325468972, 0.021935412114544306, 0.05005763814551756, 0.06813051484641619, 0.11393989188945852, 0.09189365300699137, 0.061386540983221494, 0.029611009522341192, 0.02528447781514842, 0.07144427843741141, 0.04908310547762085, 0.02473382650350686, 0.036081145735806786, 0.014319386900751851, 0.058503100590314716, 0.010500630778551567, 0.03343332609802019, 0.015167503988777753, 0.08252749699749984, 0.07259931255248375, 0.028093516048102174, 0.0298190038301982, 0.06111879265517928, 0.0652653572615236, 0.02441523363813758, 0.07370062259724364, 0.03308351107989438, 0.02686674408323597, 0.04008459087344818, 0.03638922607933637, 0.01371211807054351, 0.04450458123756107, 0.03325786012283061, 0.025372555901412852, 0.0573912854451919, 0.022131890145828947, 0.09131212835200131, 0.06549197947606444, 0.048603266186546534, 0.030719318019691855, 0.05585335507930722, 0.1422310882480815, 0.039785620392649435, 0.0563276690809289, 0.06614507685299031, 0.015730448976682965, 0.02204519245424308, 0.045299376870389096, 0.028690347498923074, 0.05747308867285028, 0.017481858121755067, 0.034444483753759414, 0.02934543568699155, 0.039594699192093685, 0.043165253300685436, 0.0836559028539341, 0.029494794762285892, 0.06125482832430862, 0.07910539468866773, 0.0383985538064735, 0.08078166138147935, 0.028631502609641757, 0.04847130490816198, 0.029130303773854394, 0.05220417042437475, 0.05720430504879914, 0.05840201265527867, 0.061668824273510836, 0.018788219858834054, 0.04206174649880268, 0.03708616211952176, 0.008441643167316215, 0.014068104046600638, 0.021111453788762446, 0.019688919965119567, 0.05730465825763531, 0.028935712653037626, 0.018181393534177914, 0.05538765370147303, 0.05864489903615322, 0.04649789712857455, 0.013566911311500007, 0.06739297590684146, 0.05608236700936686, 0.07570962377940305, 0.06565520001458935, 0.025829010119196028, 0.021497185043699574, 0.052622281582443975, 0.021244008785288315, 0.03178519051289186, 0.042162006939179264, 0.0844067485013511, 0.058714805636554956, 0.04555819345114287, 0.03244428815378342, 0.08160843615769409, 0.07510956769692712, 0.04518593959801365, 0.015095860762812663, 0.03742098204384092, 0.04367448535049334, 0.053539895234280266, 0.019988100102636963, 0.10719949146732688, 0.08694766176631674, 0.0934484152821824, 0.10880039306357503, 0.163299948326312, 0.16753103613154963, 0.14274832064984366, 0.10364158355514519, 0.11372423861757852, 0.1603286710451357, 0.13766754796961322, 0.07527606110670604, 0.21064671396743506, 0.16683067136909813, 0.09491326636634767, 0.19916515506338328, 0.12167969063739292, 0.1532844130997546, 0.2597554272506386, 0.13029160938458517, 0.2329077897593379, 0.19606091460445896, 0.1441252717631869, 0.2173286851029843, 0.20189015805954114, 0.1728432104573585, 0.146038023813162, 0.11053773851017468, 0.1791214384138584, 0.11256796511588618, 0.09761310313479044, 0.15291571413399652, 0.1133806687721517, 0.0850328391243238, 0.20765481982380152, 0.14615446678362787, 0.18168373295338824, 0.20213453244650736, 0.10856594861252233, 0.20684424613136798, 0.18892618885729462, 0.16712916316464543, 0.1397275272756815, 0.24840751430019736, 0.13116213376633823, 0.1540741472854279, 0.11547980378963985, 0.11951789609156549, 0.15486597432754934, 0.08334160331287421, 0.17912902316311374, 0.16733126481994987, 0.11649369625956751, 0.12944044021423906, 0.11223669265746139, 0.17767012410331517, 0.1106656105548609, 0.14505362429190427, 0.1481351105030626, 0.1470871237688698, 0.11424508527852595, 0.22559511184226722, 0.1397521814214997, 0.1486648406716995, 0.16640637069940567, 0.16315815359121189, 0.15043735649669543, 0.1428967947140336, 0.1068543853762094, 0.10254860782879405, 0.09020331519423053, 0.1576445158571005, 0.14021382696228102, 0.18081852234899998, 0.11331904825055972, 0.17874390789074823, 0.20238284021615982, 0.16699158382834867, 0.07814129290636629, 0.1431096575106494, 0.1334528170991689, 0.15270417236024514, 0.16324872529366985, 0.12352367528364994, 0.10935811704257503, 0.10176237658015452, 0.2226781300851144, 0.11433239153120667, 0.07976547567523085, 0.14858749404083937, 0.2537431998644024, 0.1535754685755819, 0.10199885451584123, 0.16445069282781333, 0.2253749908413738, 0.18532194866565987, 0.15987449150998145, 0.18292148684849963, 0.10648374940501526, 0.08374481214559637, 0.13940536096924916, 0.17905569897266105, 0.10370813935878687, 0.15959020442096516, 0.17036497156368569, 0.12449513917090371, 0.11319545097649097, 0.10600149442325346, 0.20054883003467694, 0.2030036022188142, 0.10802384684211574, 0.19114619004540145, 0.10815839079441503, 0.194014368171338, 0.1265599424368702, 0.10780412660096772, 0.11733040839317255, 0.08857511740643531, 0.08302765258122236, 0.10314355051377788, 0.28452407161239535, 0.09605059283785522, 0.16011362633435056, 0.11288886977126822, 0.09961932868463919, 0.15721113129984587, 0.10864267183933407, 0.18153888056986034, 0.14473450079094619, 0.17341153230518103, 0.15487269818549976, 0.18203683197498322, 0.18602960131829605, 0.1112796190136578, 0.1716725021833554, 0.11304030500468798, 0.1982324683922343, 0.16524493927136064, 0.15544146532192826, 0.18902044161222875, 0.19878548715496436, 0.10355700840591453, 0.09290618734667078, 0.08157388176186942, 0.08804669341770932, 0.2141531984671019, 0.11245372632401995, 0.18983626971021295, 0.1947070294409059, 0.06733021989930421, 0.12267212761798874, 0.1277053137891926, 0.15584715292789042, 0.20718989399028942, 0.14652131038019434, 0.15320158941904083, 0.1548626643489115, 0.18075446016155183, 0.10974551070830785, 0.1823089478421025, 0.20799163612537086, 0.08488981984555721, 0.1644562292494811, 0.1352800737367943, 0.2061234723078087, 0.14609004836529493, 0.11699336202582344, 0.09075047099031508, 0.2667445287806913, 0.18438201863318682, 0.1464196658344008, 0.16677370411343873, 0.13268148817587644, 0.12439193611498922, 0.24730701319640502, 0.11623231926932931]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.009574321011314169, 0.029354564103414305, 0.04378654593892861, 0.0709403824293986, 0.013370477809075965, 0.016386733877880033, 0.07487837385269813, 0.01829348566388944, 0.0295968215141329, 0.019258476168033667, 0.08404915206483565, 0.008158919226843864, 0.043937042355537415, 0.032819325060700066, 0.04396624215587508, 0.03477634250884876, 0.045832227770006284, 0.05070211547717918, 0.04394500188936945, 0.008054346908465959, 0.03675964311696589, 0.08985400854726322, 0.046314864957821555, 0.028919155338371638, 0.02100282934407005, 0.046835589164402336, 0.06830439262557775, 0.069303902273532, 0.044943376051378436, 0.06310425291303545, 0.033002372074406594, 0.017130490159615874, 0.04678525299823377, 0.06444057144108228, 0.012403986311255721, 0.021978401018714067, 0.06494376983027905, 0.052077860600547865, 0.031239641466527246, 0.08233105050749145, 0.011364180827513337, 0.03272930996899959, 0.014056219479243737, 0.017745812219800428, 0.06458888223278336, 0.01957589829544304, 0.076254033629084, 0.03769664166611619, 0.009594907260179752, 0.026357556562288664, 0.02020977404754376, 0.042049660623888485, 0.08403126630582847, 0.026712212238635402, 0.06368922113324516, 0.0667802662064787, 0.062423332419712096, 0.0746442039962858, 0.06966788860154338, 0.07397623397991993, 0.03620227536885068, 0.08252250976511277, 0.032374155198340304, 0.003070623952226015, 0.04829911922570318, 0.02660581794771133, 0.01558421990921488, 0.02029326009505894, 0.015382251840492245, 0.056177272854256444, 0.009905060978780966, 0.03015970898559317, 0.04053249926073477, 0.08450263398117386, 0.018623322066559922, 0.06007521427818574, 0.05793123127659783, 0.03040735438844422, 0.0191927812556969, 0.05067600301117636, 0.04099338038940914, 0.018282429518876597, 0.03617654881963972, 0.06469388128607534, 0.013863756466889754, 0.021282476154738106, 0.03056532052141847, 0.03327704835101031, 0.027535196495591663, 0.05146565927134361, 0.02029303002927918, 0.027938483253819868, 0.015291500167222694, 0.02476001318427734, 0.06131485693913419, 0.030529231735272333, 0.02248091848741751, 0.07833828116417862, 0.00868040784553159, 0.028874737799924333, 0.026226955269521568, 0.048757729382487014, 0.044304093753453344, 0.008474816240777727, 0.027556060122151393, 0.01934301977598807, 0.06631933312746696, 0.11518608400365338, 0.051788430428132415, 0.026572334099910222, 0.04078661433595698, 0.07389689097180963, 0.028437191649572924, 0.037225552296149544, 0.01749898503476288, 0.021093388058943674, 0.0787097928696312, 0.04323264402046334, 0.08127759414492175, 0.015408643539558398, 0.01428796436812263, 0.027005032170563936, 0.06778639581170864, 0.017368682456435636, 0.04109496185265016, 0.0035459788159641903, 0.012221281613165047, 0.016827690196805634, 0.023299969361687545, 0.026521971958572976, 0.021150173488422297, 0.032972044209600426, 0.023818799236323684, 0.09145919233560562, 0.021226464414212387, 0.012820165102311876, 0.06437287273001857, 0.048923142967396416, 0.10793374269269407, 0.06165362508909311, 0.03171149524860084, 0.009272997922380455, 0.02695899489481235, 0.04547595977783203, 0.08600867426139303, 0.015155988639889983, 0.025696471820992883, 0.05048514489317313, 0.04011092598375399, 0.02541407349781366, 0.047873961375444196, 0.03727085670107044, 0.03648057703685481, 0.05247036024229601, 0.014223387315723812, 0.016164243570528924, 0.029759589342575055, 0.014448556776187615, 0.0180415005524992, 0.01733899840473896, 0.05961145732726436, 0.03708614356582984, 0.03051672098081326, 0.05302279270836152, 0.03353757558215875, 0.05648728649248369, 0.02523518807720393, 0.047082843084353954, 0.009382126099808374, 0.019233591956435703, 0.07058741699438542, 0.06329240219201893, 0.09458718152018264, 0.0690895551815629, 0.025436866708332673, 0.05273407128697727, 0.009495740559941623, 0.01583896952070063, 0.05716088940971531, 0.08597506981459446, 0.05065472192654852, 0.027180266224604566, 0.048732770956121385, 0.04223956508212723, 0.05922253483731765, 0.02869016938348068, 0.06231037754332647, 0.0783231710374821, 0.06643892280408181, 0.03199557824700605, 0.11215646649361588, 0.0377149652922526, 0.08410693568293937, 0.041365819779457524, 0.03421966866881121, 0.007513610225942102, 0.008610003078501904, 0.020978575957997236, 0.05857645446667448, 0.014383800680661807, 0.03202872998372186, 0.022833047150925267, 0.019155447516823187, 0.037973896905896254, 0.017421961238142103, 0.017464742340962403, 0.020402229638420977, 0.01433030482075992, 0.029894784529460594, 0.06029005489835981, 0.03619494666054379, 0.02610788324091118, 0.08755887974984944, 0.09871974179986864, 0.0579074899724219, 0.0789699527376797, 0.04888480361842085, 0.035125500726280734, 0.012629573229787638, 0.03145153204968665, 0.10193285532295704, 0.02298068629897898, 0.09871609043329954, 0.030363578807737213, 0.05167933471966535, 0.025703334831632674, 0.021131868415977806, 0.023277246655197814, 0.03191213858372066, 0.0629350655071903, 0.058253445822629146, 0.03552372974809259, 0.06494258981547318, 0.03409850563912187, 0.007650923316759872, 0.022591568995267153, 0.0048309792236977955, 0.0351007204153575, 0.015571518051729072, 0.013500642162398435, 0.03434119535086211, 0.05010231172491331, 0.05998377797368448, 0.04762111908348743, 0.027142817452840973, 0.07211311676655896, 0.03449954368988983, 0.03202076302841306, 0.00501989848089579, 0.04474383851629682, 0.02274296526593389, 0.07589547240058891, 0.008335080037795706, 0.04223626252496615, 0.03843560923996847, 0.05273274284263607, 0.017427469829272013, 0.018772156072373036, 0.014014550670253811, 0.017798449043766595, 0.03846367726509925, 0.10309787874575704, 0.02309372281160904, 0.021623626598739065, 0.051390360968071036, 0.05167249582882505, 0.03138427120575216, 0.057318206163472496, 0.041287831190857105, 0.022485291592602152, 0.016253317990049254, 0.061316771680139937, 0.05554529700020794, 0.02153785102564143, 0.023155745948315598, 0.014603917970816838, 0.036117982235737145, 0.08230411796830595, 0.06867295800475404, 0.04110270245291758, 0.04136796458624303, 0.045802909226040356, 0.016378405125578865, 0.03521144142723642, 0.04244193391059525, 0.034339046833338216, 0.030834547578706406, 0.018711010525294114, 0.01718833314953372, 0.02636755885760067, 0.03399967012228444, 0.0441378934920067, 0.008774805319262668, 0.027318480097164866, 0.1069312273466494, 0.05191862539504655, 0.02849933909601532, 0.018560187563707586, 0.03193148266291246, 0.031352173318737186, 0.019416128743614536, 0.042347799899289384, 0.06571988560608588, 0.05363456359191332, 0.0159609229376656, 0.0512224760313984, 0.04232707171468064, 0.027082158012490254, 0.005693140992661938, 0.06212330066773575, 0.008259742771770107, 0.02358091493078973, 0.025689298963698093, 0.0656101516506169, 0.058676521948655136, 0.10499353913473897, 0.025186608945659827, 0.03230658265238162, 0.024718048443901353, 0.05446911607577931, 0.025133461895165965, 0.043300160905346274, 0.011059108965127962, 0.010215247166343033, 0.03554101065674331, 0.03731052449438721, 0.0793605599028524, 0.08358799634152092, 0.02286733808432473, 0.04727967178041581, 0.03699215056258254, 0.02541956910135923, 0.008401136747124838, 0.027278843845124356, 0.03323518380057067, 0.005034225177951157, 0.029248058490338735, 0.08556438755476847, 0.011105976518592797, 0.018235889438074082, 0.035967649091617204, 0.050999954182771035, 0.021437078503367957, 0.08621044937171973, 0.030069539898249786, 0.019895782497769687, 0.014006912115291925, 0.04364782740594819, 0.11974867433309555, 0.08216134359827265, 0.013451517552311998, 0.017688720654405188, 0.15024358173832297, 0.1286863291170448, 0.1713274628855288, 0.11724584808689542, 0.14102517248829827, 0.09839535647188313, 0.13764489762252197, 0.10897958462010138, 0.18487294932128862, 0.12791179411578923, 0.2890394761925563, 0.15810320765012875, 0.1563934626756236, 0.14774036215385422, 0.18336063047172502, 0.09308873341069557, 0.16371987032471225, 0.11732954750186764, 0.1097721909172833, 0.14640891953604296, 0.11712945706676692, 0.2163708841544576, 0.14237911702366546, 0.16006143850972876, 0.12719237100100145, 0.10363838489865884, 0.10110830698977225, 0.13993510598083958, 0.14143829641398042, 0.14805126265855506, 0.09326337560196407, 0.23714610608294606, 0.1397313122288324, 0.23525578173575923, 0.11712703766534105, 0.10443492457852699, 0.2555368223693222, 0.18468459224095568, 0.14668456802610308, 0.13779923465335742, 0.10081345913931727, 0.12006597215076908, 0.10054593716631643, 0.08539864371414296, 0.12639745662454516, 0.15349208086263388, 0.1657844806322828, 0.1476993807591498, 0.06649157076026313, 0.14607256336603314, 0.2064133997191675, 0.14484200830338523, 0.18983000598382205, 0.1083118817768991, 0.1456898229662329, 0.22846557578304783, 0.1524801179766655, 0.1262622224749066, 0.14099238440394402, 0.14029084704816341, 0.08702049613930285, 0.19474228145554662, 0.062048440231592394, 0.1403483041212894, 0.12364501642878167, 0.11189792450750247, 0.24249167705420405, 0.1885152913746424, 0.10620122862746939, 0.1445519324624911, 0.09201068969559856, 0.13224526861449704, 0.08166886182152666, 0.12999607133679092, 0.05693866070942022, 0.15378319571027532, 0.1518028785358183, 0.12327875170740299, 0.16722213942557573, 0.14789127046242356, 0.15303010877687484, 0.1438885266543366, 0.133305485942401, 0.21239350695395842, 0.09927195904310793, 0.20000894728582352, 0.23827308701584116, 0.07553214658400975, 0.17696511349640787, 0.20962082839105278, 0.08125818698317744, 0.13053303002379835, 0.0915119590354152, 0.1647344307275489, 0.14093142439378425, 0.10416937671834603, 0.23411079630022869, 0.11360049291397445, 0.18312018946744502, 0.10342211564420722, 0.1443464614567347, 0.1644067873712629, 0.15359243407147005, 0.21817451081005856, 0.13719790207687765, 0.18234598101116717, 0.2941271953750402, 0.2605931041762233, 0.1439638398005627, 0.1399133462109603, 0.12220021817483939, 0.07859382487367839, 0.08388829155592248, 0.12728141387924552, 0.09432149265194312, 0.14699484512675554, 0.09021419507917017, 0.13585295237135142, 0.31659001659136266, 0.1507877541007474, 0.09946168167516589, 0.15212494094157591, 0.21268710057483986, 0.15136642148718238, 0.14220876444596797, 0.21661684673745185, 0.15452571446076035, 0.10370506686740555, 0.1400165937957354, 0.15492772101424634, 0.20747950969962403, 0.07000445999437943, 0.10172938811592758, 0.16989868017844856, 0.0468727781844791, 0.10161178739508614, 0.09940803924109787, 0.09173800237476826, 0.18317923473659903, 0.19644885003799573, 0.09240191284334287, 0.13651935645611957, 0.08677235906361602, 0.14236789575079456, 0.17176619090605527, 0.1845521485665813, 0.06534161293529905, 0.11109869825304486, 0.12232102497364394, 0.11214167549042031, 0.18531409674324095, 0.1440998012549244, 0.0895958005276043, 0.17805933603085577, 0.11916124218259938, 0.17341358063276857, 0.12642378802411258, 0.13290745730046183, 0.10278993198880926, 0.119440497510368, 0.12184844017610885, 0.15172780287684873, 0.08462332203635015, 0.22179769061040133, 0.1496925370884128, 0.18074807769153267, 0.16686809045495465, 0.15973643719917163, 0.1467334310291335, 0.08954238815931603, 0.17431076295906678, 0.13644601742271334, 0.22709560085786507, 0.21063642780063674, 0.09240338229574263, 0.11256420242716558], [0.05340471303497907, 0.04340283703641035, 0.06569888282683678, 0.15814650454558432, 0.037878408475080505, 0.004591060042002937, 0.030516058614011854, 0.07696168628172018, 0.024531637645850424, 0.020328152168076485, 0.0580668624752434, 0.002422120933260885, 0.046480378732667305, 0.03678060878883116, 0.03107454514974961, 0.0576973694114713, 0.031395032347063534, 0.04726255785499234, 0.035368869503145106, 0.02123826456227107, 0.005333518492989242, 0.02722715140407672, 0.022342257470882032, 0.03330726860440336, 0.03706828749272972, 0.014365313782036537, 0.03333608248794917, 0.11704770207870752, 0.01658718796534231, 0.051671608962351456, 0.017415259644621983, 0.03490288610919379, 0.04279461361875292, 0.018304805271327496, 0.048345577670261264, 0.022631231222476345, 0.046865356707712635, 0.01993295667489292, 0.028500467160483822, 0.045693557476624846, 0.07283878876478411, 0.04841569207201246, 0.025419207304366864, 0.0223595940406085, 0.03183718537911773, 0.016595976849202998, 0.03307359969767276, 0.0669760002347175, 0.06903168250573799, 0.02240258294477826, 0.03738959290785715, 0.02933794185082661, 0.04485912373638712, 0.02272537451062817, 0.0544230175728444, 0.04466442871489562, 0.06746241866494529, 0.01648394223593641, 0.077202387037687, 0.020801126593141817, 0.02535439925850369, 0.014169779205985833, 0.03836219970253296, 0.02224342752015218, 0.09098222144530155, 0.009883997900033137, 0.06889587690238841, 0.028688364109257236, 0.07654282555449754, 0.02684538692847127, 0.017063246014004108, 0.051417616341495886, 0.008664534234412713, 0.07334173482377082, 0.06103444015025161, 0.024686137949174736, 0.012277283149160212, 0.020637041452573612, 0.04903555236523971, 0.029414663222269155, 0.02993869740748778, 0.08858316970872693, 0.04372127776150592, 0.04385460830235388, 0.01786482858733507, 0.05641772870148998, 0.03857967123622075, 0.01736551905196393, 0.034450855091563426, 0.029315022475202568, 0.03154671248921659, 0.06999650417128578, 0.05315874674124643, 0.07572754664579406, 0.041030350475921296, 0.021643273103109095, 0.06662679006694816, 0.06149599292257335, 0.036069256530026905, 0.0407848183385795, 0.035952984253526665, 0.08491756132571027, 0.06711501933750696, 0.06949004033231176, 0.011504024641908472, 0.0164136979583418, 0.039148371579358354, 0.046573930158047006, 0.026150822050112765, 0.022152980127430055, 0.10112109419424087, 0.06424789506127127, 0.02579480267741019, 0.020161417560302652, 0.0550781224592356, 0.02169656116166152, 0.012101857992092846, 0.09294576608226635, 0.02027788093982963, 0.01751762963976944, 0.06554272011271678, 0.06044716756150592, 0.025098549413087312, 0.05330528751073871, 0.012623797465494135, 0.05984887036902364, 0.029743625746050384, 0.02395071969658602, 0.07237030804390088, 0.008740290813875617, 0.051785194664262235, 0.06162215431686491, 0.06510728722787462, 0.04816695014596917, 0.012121074050810421, 0.025145364088530187, 0.05073728956631385, 0.0480189028166933, 0.051654279814101756, 0.04227191901009064, 0.013062552388873883, 0.00724385577996145, 0.031155923497863114, 0.02939416324807098, 0.0351750168192666, 0.03556534938979894, 0.021044239329057746, 0.017173558844660874, 0.034372027876088396, 0.038900657527847216, 0.01539828965178458, 0.07504725697799586, 0.038953940020292066, 0.035291819731355645, 0.021639862934534904, 0.036256392777431756, 0.09012944923597388, 0.040600721185910515, 0.07415653875796124, 0.01844323251134483, 0.011108369017165387, 0.033912972430698574, 0.046822701769997366, 0.03236590993765276, 0.054511466732947156, 0.033440001716371626, 0.030480530149361584, 0.03514913812978193, 0.009952802411135053, 0.027871274360222742, 0.04596654536726419, 0.040226244600489736, 0.044704278334393166, 0.04796582812559791, 0.010967822017846629, 0.03330944680783432, 0.018230763052997645, 0.036534241735353135, 0.027742290949390735, 0.020842174781137146, 0.025320577733509708, 0.06603449684916995, 0.036771458107978106, 0.06506505902507342, 0.06109313289925922, 0.025745770835783333, 0.007273909977811854, 0.033572441680007614, 0.07566246029455215, 0.029063777656119782, 0.030319883007905446, 0.036050791895831935, 0.014295121454779292, 0.05006456238334067, 0.026027293424704112, 0.044712297240039334, 0.02555693507019896, 0.05308016072376631, 0.04806094177183695, 0.010681108105927706, 0.0259081824333407, 0.02651208469615085, 0.015781248985149432, 0.02699533786653774, 0.050228944382979535, 0.08871374317095615, 0.044968542279093526, 0.021068073401693255, 0.01686118517682189, 0.02247079559310805, 0.024926142941694707, 0.020359478221507743, 0.010462514073878992, 0.013923921451350907, 0.04502045179833658, 0.07208900438854471, 0.034379063436063007, 0.0317835874739103, 0.03091101661993889, 0.022956182438065298, 0.04180921219813172, 0.017491001381131355, 0.05163560366781894, 0.0546554916218156, 0.0404499613068765, 0.04430341097759083, 0.06772406282834709, 0.044287146811257116, 0.02979726075864164, 0.014301375904324232, 0.070180593902478, 0.013782682399323676, 0.020993424477637745, 0.039692677528364584, 0.10830601881025359, 0.03138039348414168, 0.0630010424356442, 0.009024666032928508, 0.04286643867089879, 0.002195560177824518, 0.05849912267876789, 0.06696045224089175, 0.07527328547439538, 0.01433643774362281, 0.058204913075314835, 0.025884559872793034, 0.04900853818980977, 0.016404113121097907, 0.0040917732349043945, 0.04518656300206203, 0.007580592300655553, 0.010704941250878619, 0.009395863253303105, 0.054621679373667575, 0.03590434760553762, 0.04464277284569107, 0.06526650016894564, 0.02971742051158799, 0.037862181416130625, 0.003602451847655175, 0.010552702642598888, 0.040440795783069916, 0.0285976309896796, 0.02026627003942849, 0.02659069112269208, 0.0524818264239002, 0.06276683547184803, 0.06433193586417474, 0.05711583733500447, 0.04964533058227971, 0.04687442946305964, 0.009376671314385021, 0.07832785398932174, 0.07963545882375911, 0.03695310988405254, 0.07383777148788795, 0.054762015788583085, 0.04277726220607292, 0.09263102867407724, 0.07940024996059947, 0.018697277082537767, 0.10803836325067095, 0.06103265899582766, 0.014478648081421852, 0.0301656999727129, 0.008828974678181112, 0.03141829867672641, 0.024708081400603987, 0.05069259001174942, 0.017409088686690666, 0.08172700909199193, 0.030577616053051315, 0.036689428525278345, 0.03891226471750997, 0.007085258821462048, 0.04184243443887681, 0.02413991911453195, 0.03710659715579823, 0.09331263194326311, 0.05804000415082555, 0.024638928080094047, 0.024156149884220213, 0.03957651657401584, 0.005492826521731331, 0.10707755660405383, 0.020799918747798074, 0.037446393180289306, 0.04290566859708633, 0.04357098543550819, 0.04857307190832216, 0.05995829633320682, 0.010333450882171746, 0.037430752418003976, 0.03991495075752027, 0.05673768711858429, 0.006857881007817923, 0.02969526183733251, 0.038166654921951704, 0.072340844781138, 0.08277667307993397, 0.019857415318256244, 0.06872204365208745, 0.017626601038500667, 0.06791790438001044, 0.08501554708345793, 0.12136292716604657, 0.023907487739052158, 0.0255942632429651, 0.04018850268039387, 0.052444544635363854, 0.0444407899340149, 0.06993768896791153, 0.024680362184881233, 0.040870172742870636, 0.006339906922221417, 0.013751956557825906, 0.047681006690254435, 0.03751613650820218, 0.05362327923648991, 0.014147865440463647, 0.02070557322440436, 0.02750031741015846, 0.09248547125025652, 0.028798734456358943, 0.016967009869404137, 0.07607438194099814, 0.01947763237694744, 0.01494059048127383, 0.017855004407465458, 0.021503981261048466, 0.06986136650084518, 0.01328451391600538, 0.16993482277030125, 0.18732901284238324, 0.06655293895164505, 0.18925773591035977, 0.2011795516591519, 0.09617249059374444, 0.1386450306745246, 0.14056400192203, 0.08871370606357232, 0.0971297720388975, 0.1062779370113276, 0.11865655949804932, 0.1779678143793717, 0.16994476754916832, 0.10933684709016234, 0.10794801419251598, 0.1268804760184139, 0.1629526083706878, 0.06736011360771954, 0.1575811067596078, 0.14257646893383935, 0.1331789349205792, 0.11181107838638127, 0.12348784439382143, 0.059447231178637594, 0.13181988440919667, 0.11536106758285314, 0.24295363429700956, 0.14480424782959744, 0.13541012769564986, 0.14366090996190906, 0.17681723315035924, 0.13051094370894134, 0.12364741356577724, 0.17181080882437527, 0.12091045457054861, 0.1010466345178429, 0.13631661655381322, 0.08771345426794142, 0.14874935644911602, 0.16091939090983942, 0.1341998332645744, 0.0994652439840138, 0.14905782270943746, 0.11701604948029853, 0.16982939327135682, 0.11909240056411363, 0.1437625990365632, 0.17106995248468593, 0.12047785668983124, 0.15953513706335798, 0.13632198970299214, 0.19316702848300338, 0.09070006432011724, 0.15619473037077114, 0.1130318890500348, 0.14155139971990138, 0.16796152631286532, 0.21973474271362647, 0.06641886255238205, 0.1569998121703975, 0.10675170924514532, 0.11770443597924896, 0.12641632201848552, 0.24318813811987638, 0.1758207514649257, 0.1843489336897619, 0.11895668401848525, 0.15308630419895053, 0.15711732383351773, 0.18612560554174706, 0.1674341264879331, 0.09980865055695176, 0.21489580627530813, 0.14198614982888103, 0.09311845642514527, 0.16261668264633045, 0.10458114251377992, 0.08971517498139292, 0.10896719075390138, 0.16298855800414458, 0.14645457646111026, 0.16131036914885044, 0.12195798859465867, 0.13480002293363214, 0.153612234571483, 0.11924028833163902, 0.0913494435371831, 0.20322866592323408, 0.10327835421776399, 0.19529881799826398, 0.21104970015585423, 0.2166301608667709, 0.2321586658945307, 0.12338823333266191, 0.15422551572555676, 0.19034438853850588, 0.16796412382973358, 0.07944805911392905, 0.1567690190859139, 0.13340570556465536, 0.2287152936332859, 0.16138918523211032, 0.2391537046059966, 0.11170395679073408, 0.3254084527725354, 0.18308490776689723, 0.16316079563694075, 0.13100264623062685, 0.11377883842214942, 0.1376137274201028, 0.11832191768917255, 0.11245339977904223, 0.14031144906766713, 0.2674114820547402, 0.09289882524171844, 0.21439632604597136, 0.1838642221991904, 0.11160549605847336, 0.1294121050159447, 0.1444536869530566, 0.20636759436456487, 0.2032139417133294, 0.11348344138241373, 0.10292230886989273, 0.16865823970874771, 0.06300680150161497, 0.15290189534425735, 0.1714939414523542, 0.0959494306880515, 0.1542206620797515, 0.15820952772628516, 0.1330167311243713, 0.1960037840763107, 0.15700068790465593, 0.1691930610104464, 0.15430657309480011, 0.18262529571074992, 0.11856163138872944, 0.1243108045309782, 0.16286049300106242, 0.12859799870057032, 0.15835393482120708, 0.17867243906948715, 0.06257202170672826, 0.16088114061858505, 0.12517644558101892, 0.1007567071064841, 0.1728496077703312, 0.1834772664005868, 0.1338564118486829, 0.1492495639831759, 0.05872110647032969, 0.15812857425771654, 0.09048184321727604, 0.1008929283125326, 0.1626233322895132, 0.11809109491878189, 0.18269425607286394, 0.11299452933599241, 0.1476777545758523, 0.22722623369190842, 0.0865016458556056, 0.10220111944363452, 0.14363279740791768, 0.21822764858370647, 0.19504541909554973, 0.16575492831179872, 0.1404089672723785, 0.26365933183114976, 0.14486923028016463, 0.1323597671580501, 0.13400108611676842, 0.1465892614214681, 0.1350280997576192, 0.05128869044710882], [0.02908246864535613, 0.03611995263781864, 0.023094863863661885, 0.03996408464445267, 0.06548678444232792, 0.04139037373533938, 0.04531521801254712, 0.004076127370353788, 0.0076352259657141985, 0.016716065620130394, 0.018706442606344353, 0.05954989246674813, 0.07570078480057418, 0.0348460932582384, 0.029960976680740714, 0.009780715063243406, 0.035154225552105345, 0.023431353620253503, 0.029977318772580475, 0.05366292847611476, 0.04317099752370268, 0.023413510534737725, 0.025372066083946265, 0.024096579545584973, 0.03001622957526706, 0.0313317419931991, 0.015701724150858354, 0.031135748213273473, 0.0790965482883621, 0.03793079296883661, 0.1322850032011047, 0.03462926368229091, 0.039186677531688474, 0.06104213622165844, 0.06891728786285967, 0.003674515778584464, 0.025896911065501627, 0.04914365730655845, 0.017896098979690578, 0.030195940635167062, 0.03556215815478936, 0.03941882874642033, 0.013158563106117072, 0.054136403850861825, 0.05174030586204026, 0.022475894147646613, 0.05811620787426364, 0.03628067956015002, 0.026448593962413725, 0.06131773647211958, 0.005193789247641689, 0.013543769291572971, 0.042752678564284, 0.05846688749443274, 0.0028365807247610064, 0.07028329229797237, 0.02584998877864564, 0.06409426307072863, 0.03960991321946494, 0.038410012566600926, 0.0900804229604546, 0.030871243070578203, 0.01645355499931611, 0.03554260256350972, 0.09244215951184742, 0.11636712297331542, 0.04188921200693585, 0.0590509354515234, 0.007859433881094446, 0.037820743600605056, 0.025084968110604677, 0.0345931025367463, 0.018280490658071358, 0.025472423003520817, 0.024378723683184944, 0.051035725700785406, 0.020672018872573972, 0.03477758931694552, 0.039506012544734403, 0.020944561474607326, 0.02683023969439091, 0.08348172079422511, 0.05116323780384846, 0.051737281610257924, 0.023370725721179042, 0.0023718408920103684, 0.0527508401137311, 0.0343804586736951, 0.06435356946894899, 0.049497561558382586, 0.01679658493230818, 0.051024868080276065, 0.020604759884008672, 0.04090639697096776, 0.0131232340936549, 0.011717791931005195, 0.03671369675430469, 0.03702339869050775, 0.0436196740338346, 0.026918148942058906, 0.060588279520743527, 0.08816059082164429, 0.05406739153841045, 0.06840316505986266, 0.019350237162143458, 0.058002941295853816, 0.029252828644530382, 0.06044482237484772, 0.023314133250096347, 0.005846938574904925, 0.009864298517641146, 0.1022478227969259, 0.016802735481178388, 0.02786850614938885, 0.024279962381115183, 0.03249832763685845, 0.017952947491721716, 0.04192516906186938, 0.052096577564952895, 0.016326727527484763, 0.05936765068327077, 0.046696180434082635, 0.035739420127356425, 0.036366787244332954, 0.04457069546333514, 0.034498237509978935, 0.05027398903621361, 0.02952158814878203, 0.048512264038436115, 0.03234131516364869, 0.0326948038127739, 0.03243849569116719, 0.034211423408123665, 0.05532158771529794, 0.05096030865388457, 0.11433119667344727, 0.022011344954080414, 0.04531522543402389, 0.0517090466018999, 0.05614628076727968, 0.06745113802026026, 0.04302066066884436, 0.08766363389440812, 0.025044723297469318, 0.03574700116587337, 0.03955089392547961, 0.027864704497915227, 0.007071137142702355, 0.012017582484986633, 0.018435801757732406, 0.0018316809973839554, 0.0737626661430113, 0.028592929484148044, 0.02514357922336785, 0.05132841019076295, 0.057513120118528605, 0.018162485466746148, 0.04064636326802429, 0.03214333613868803, 0.01944390547578223, 0.03823778977675829, 0.009077839058591053, 0.013105655398248928, 0.014623195256717736, 0.00919821541174315, 0.08536757741239853, 0.08601295645348728, 0.010199506214121357, 0.05229885733569972, 0.056376687934971415, 0.006424778930522734, 0.024956003253464587, 0.031360652355942875, 0.03125141935015563, 0.06081436738895718, 0.0015945258519423078, 0.04912974945909809, 0.05254199233604595, 0.04120985744521022, 0.0380891932582017, 0.057319616244058125, 0.022092294711910654, 0.06593690442969091, 0.03155493919621222, 0.010841585481102811, 0.06018619504175149, 0.0793519732542336, 0.06212803928065114, 0.04248128258041106, 0.02716753468121169, 0.061046767223160714, 0.025867267831927165, 0.016648726850689854, 0.027773084511864, 0.037188623027759604, 0.05543804552871734, 0.03682417285745032, 0.03752245960640721, 0.008355117097380571, 0.021705401995859575, 0.04819486603082623, 0.03696304724144284, 0.028714159307128284, 0.03991459452663548, 0.008810564777377294, 0.017951956724573392, 0.04597632316290401, 0.05813408250105567, 0.04680350983107928, 0.1523055203142576, 0.062085402896627784, 0.055348037858493626, 0.027197005365451332, 0.06855881569208577, 0.018571993277873844, 0.03066756991756847, 0.031102826542337425, 0.05553869188588578, 0.038158565512276255, 0.0475962274504127, 0.06913713426911272, 0.0999251900066156, 0.03851412475341931, 0.048277563546434976, 0.012810891967092175, 0.05086025230411906, 0.05754677651566453, 0.04158516152529046, 0.058322688200860284, 0.04796855922904797, 0.0695765450655017, 0.05651181818393525, 0.046000910515431315, 0.04849889053730294, 0.035300380404805765, 0.029435970282065682, 0.06712683432851918, 0.04370913622551598, 0.01693779522611294, 0.029391215066425502, 0.11980930037680082, 0.10654097641236149, 0.03352410189108923, 0.023527751181973144, 0.01087457116227597, 0.04822834802325815, 0.08531625047908165, 0.028960047675354872, 0.023288529155252036, 0.005423200545919826, 0.02266672072437359, 0.01748906994180288, 0.01732240398268914, 0.08760437340242788, 0.08175952258170582, 0.043572859358391725, 0.0464775251748506, 0.01798539418814471, 0.028536919598991517, 0.06750465428922325, 0.02143250501831062, 0.02152476881747134, 0.05881078388483729, 0.03535253483278211, 0.06428382243029773, 0.08291077916510403, 0.01063767113009817, 0.013654305694217328, 0.04425110440934077, 0.02711539880692726, 0.00819594219137798, 0.019437667724560015, 0.029254958608362358, 0.06168983818497509, 0.07923967888928019, 0.05435981627670117, 0.05904393328819424, 0.03179668266966473, 0.03134905258775689, 0.029615681341965683, 0.027797143084171694, 0.02745548241364304, 0.030185858558979817, 0.05207722606428433, 0.03285593891632743, 0.04272518570360262, 0.04230918966641184, 0.055214985623024404, 0.010190771135967225, 0.047266042238334194, 0.053037865727674216, 0.05374346634198446, 0.021127471190993674, 0.04989528963051271, 0.039120852743508294, 0.007394271488010418, 0.009504598092462402, 0.040614272802486084, 0.010944183686660836, 0.03888827108312398, 0.02380107489443617, 0.019233126258768607, 0.03556464063876774, 0.020111968260607682, 0.05674166131939273, 0.03006312959769275, 0.02950524605694227, 0.018343806987104472, 0.008506333397235721, 0.0720842249575071, 0.06830220328993164, 0.08136285207001492, 0.033503726226626895, 0.021499546928680502, 0.06514699212857522, 0.07116476335795596, 0.028545927416416816, 0.02087443594064098, 0.014873835225444054, 0.05079062771983445, 0.07433982696966268, 0.017432865242881235, 0.046216619448387064, 0.09681209572590888, 0.026588930377329234, 0.0941525204689242, 0.034108394756913185, 0.06271003148867749, 0.014144844899419695, 0.04018901105155237, 0.05278145370539278, 0.08716267679119483, 0.020245745945430826, 0.03622054333391134, 0.08452503199805506, 0.023782228054187726, 0.06803015421610326, 0.03455882273556199, 0.011108584239991615, 0.05560263532970566, 0.006852724472992122, 0.038840903507662006, 0.06226182624232024, 0.01960553967364831, 0.01000572960037971, 0.05305371058057062, 0.02205116117693251, 0.003766971840377664, 0.1075828552711755, 0.07026748455245979, 0.009978029866033467, 0.05413237398897763, 0.1860977304750122, 0.18306963436771184, 0.05936489731539041, 0.20619569811969995, 0.12274856140720658, 0.1398995125782676, 0.23793744330760092, 0.12245869336766191, 0.0899738357111346, 0.1519813947379589, 0.21704074664739892, 0.1482120860600844, 0.16546329396078363, 0.10989702015649527, 0.1739578420529142, 0.08310117715154774, 0.09679851442342624, 0.14684794441564009, 0.09526300345896743, 0.17201771959662437, 0.07333394227316603, 0.1303071647998877, 0.09310535009717569, 0.12948299496201798, 0.0907347968313843, 0.12219705662573688, 0.12112127646105364, 0.12215868016937748, 0.15576112316921353, 0.10539448441704735, 0.1452694705221802, 0.1560559932840988, 0.14124756446108222, 0.19591515680076554, 0.11838736027129926, 0.18293095665285364, 0.07601023811730556, 0.1578799547860399, 0.07397395558655262, 0.18346611934248358, 0.1922554781776853, 0.1122898526955396, 0.16060531401308253, 0.13446918834233657, 0.10460683566634543, 0.17254658887395635, 0.1918737470987253, 0.12214073503855616, 0.0828638012171723, 0.18645528238266706, 0.13628828135551885, 0.14768352848477662, 0.21638081409037113, 0.17209494748385623, 0.1760566802113317, 0.12179846395156346, 0.09489494274021126, 0.1422391034429893, 0.11052875852328725, 0.13334894611034542, 0.22860449098516256, 0.18602964584715664, 0.09174373917630874, 0.15447919664438814, 0.1976649629068561, 0.2413661655737087, 0.12551835301565006, 0.1063993969000876, 0.12430245536961593, 0.17894802818773314, 0.1127542664471548, 0.1429338427260518, 0.0886547943810001, 0.093270782235777, 0.12585234915604815, 0.16802260506665334, 0.10998853438650258, 0.13264025445096195, 0.11692993808537722, 0.12984108121600002, 0.081671043735696, 0.1403839123668149, 0.1609411506797187, 0.21723545651184395, 0.11955723733990453, 0.083847851929022, 0.2750691695837304, 0.15606472094077617, 0.1866621634690091, 0.13781881250906736, 0.09272032388253137, 0.19627701316494495, 0.12772002315614372, 0.11370949956472032, 0.12717654841253534, 0.1146759168477729, 0.11102768214186653, 0.13539823848986998, 0.1699884800473228, 0.13435368047794327, 0.21511028695385903, 0.18000397074501961, 0.1843843489768915, 0.19655702548334375, 0.14056771266041324, 0.1340676864492707, 0.1617118265130557, 0.2314362593460828, 0.12266227189684287, 0.10022587113780901, 0.09803079869016074, 0.1833678738330491, 0.08596560743171722, 0.11866478249430656, 0.0964367545384448, 0.1192883646581322, 0.21266842813929543, 0.1285561267286539, 0.16468415764393285, 0.12132204967201687, 0.13097042217850685, 0.09856076634605415, 0.07102131363353692, 0.08943854685639963, 0.09620541226468049, 0.12490582885220647, 0.16049733152613044, 0.1641051340266131, 0.17327450215816498, 0.17295738245593384, 0.1388880395097658, 0.1858659874415025, 0.1361673854989931, 0.13568058115197346, 0.1351640760549344, 0.17056915123248473, 0.1435945471166633, 0.12644985225051641, 0.152490938489791, 0.1656204808386974, 0.19421874079853296, 0.1283717920887284, 0.22191315394593403, 0.22693826555041596, 0.207507889426779, 0.07287717264262028, 0.13552878226619214, 0.1801611576229334, 0.13026964181335643, 0.12251397594809532, 0.1239191138301976, 0.1697185609373264, 0.11838085163617507, 0.16037668799981475, 0.11595076328376308, 0.2314751478843391, 0.07805737826856785, 0.08331038858159445, 0.14796362986089662, 0.09214328922098503, 0.10031951533164829, 0.13818832783726975, 0.062138032299117185, 0.10120016260771081, 0.1311364257708192, 0.18376900465227664, 0.20609675499144942, 0.09862540740869008, 0.1301602492458187, 0.16924575349548832, 0.06678893449134193, 0.11937570059671998, 0.22227049805223942, 0.1093679282348603, 0.1101241767173633, 0.10512746710446663], [0.03574449641746469, 0.0438620631757658, 0.02494908829248743, 0.019140342956234235, 0.010508122759347316, 0.029834746637789067, 0.014729596041433979, 0.033471902934252284, 0.010952427091979189, 0.03138367748761084, 0.04382456245366484, 0.023985357584024314, 0.030008281173650175, 0.04736722294182982, 0.04495717628742568, 0.048070021948660724, 0.07866668893257156, 0.022547457592736464, 0.04949233312800061, 0.06202401615155395, 0.05850682617165148, 0.009954643865057733, 0.11983345728367567, 0.06552657097927295, 0.0486944575823145, 0.0421376088343095, 0.04485794001084287, 0.057235590284108184, 0.016996270896925125, 0.06844513351097703, 0.04769947874592617, 0.02936026379757095, 0.03387709330127109, 0.08846752825775184, 0.04026791619253345, 0.028813514327339362, 0.03678109489555936, 0.06588920659851283, 0.034425607227603905, 0.017327530367765576, 0.049556443555047736, 0.004405538893479388, 0.012092257384210825, 0.07344789904891513, 0.07496986581827514, 0.00803367345724837, 0.03383128052519169, 0.027976787350780796, 0.10467979620443657, 0.07995105712325312, 0.036080822901567444, 0.05676266038790345, 0.019415438546275254, 0.03351424245920498, 0.06498998336610384, 0.020399012428242713, 0.027145700696564745, 0.037937668967060745, 0.07076369933201931, 0.06462321398430504, 0.07392688858089969, 0.06462552206357941, 0.030432778512476943, 0.03104593350144569, 0.03885667414579075, 0.02948480730992742, 0.05439023319922853, 0.03964653078583069, 0.051528470939956605, 0.06829833670053631, 0.07191615077317692, 0.02943973297078628, 0.08170374276232906, 0.054295928493957035, 0.020414929640537594, 0.040759199400781654, 0.06758829433238134, 0.01706693263258785, 0.023068632654030807, 0.014883977601130027, 0.07177618172136135, 0.08723600098164752, 0.04280426896002609, 0.039822160033509135, 0.047584701896994375, 0.040727813975536264, 0.021026540962338913, 0.05218566126131918, 0.02170414405554766, 0.05320225143805146, 0.03710929486260284, 0.03327337843074929, 0.061614484220626764, 0.05806666951684747, 0.048885215510381386, 0.041594074718886986, 0.04636366116756108, 0.028921827070007566, 0.06302739609964192, 0.07328886422328651, 0.04441203913302161, 0.01052718389473739, 0.11302008890197612, 0.03209062881069258, 0.047697968475404195, 0.033052385406335816, 0.02820478068315424, 0.0174316778065986, 0.005086373112135334, 0.0543153022590559, 0.03105258128925925, 0.04047622591315303, 0.025461654440732673, 0.04526313037786167, 0.026310587891202886, 0.010630888828018215, 0.009079633200599346, 0.09237909180228598, 0.012648671472561546, 0.02593787390651414, 0.03383405986824073, 0.06619465973926708, 0.02140926466381643, 0.014166058263072046, 0.0327586990169948, 0.05672547878930345, 0.06351606323732994, 0.043327475650585257, 0.014597248846257571, 0.042873158818110824, 0.04393221839563921, 0.04670212874771096, 0.03237015873310156, 0.011454030791355763, 0.045740906498394907, 0.0036192807419865858, 0.014972266271797707, 0.05257249460555613, 0.014559100600308739, 0.016995463811326772, 0.036803129260079004, 0.06030368815117981, 0.0878836732590571, 0.01841683802922489, 0.01860535838204669, 0.04092374467290938, 0.05107901517476421, 0.016184203632292338, 0.08593724254751578, 0.06110848051321227, 0.05146845716808457, 0.05360415038012434, 0.01640704089368228, 0.021126899737282656, 0.10627435243804939, 0.08911279597668909, 0.04051574527693447, 0.02861954661057098, 0.029138890422473196, 0.022437476873164997, 0.03953525687393267, 0.041391034246771596, 0.09997748915338889, 0.014803957383264787, 0.005573282287514303, 0.02417968338704668, 0.07158462598454207, 0.017689173364487942, 0.04101796403119806, 0.03805629014095757, 0.023005269940767903, 0.061469375796150416, 0.01937162029207684, 0.03527915498125367, 0.029124604079697747, 0.06574941566213965, 0.044590243633138016, 0.04791316532646306, 0.047298693025368266, 0.02072084662358975, 0.023413842645823024, 0.0274148127209628, 0.029837960137228947, 0.008450637997157173, 0.07839480313123204, 0.01241183916135924, 0.02314484750968404, 0.038440477728727274, 0.03403444716241211, 0.037380371722974814, 0.03996371728135273, 0.05826027729199268, 0.06995383810135536, 0.03630203857028391, 0.02982159949169727, 0.0638710695784539, 0.03389257821254432, 0.03670658697956242, 0.04958078970958013, 0.08513162640156224, 0.056819089586497284, 0.08787453742115758, 0.030850247712805867, 0.04727806503069587, 0.01311682472078246, 0.04902011940430384, 0.06997453660005704, 0.051674406859092414, 0.057518526664352976, 0.04249827405146789, 0.06779096001992002, 0.026968518504872918, 0.019187565812899265, 0.04372832445369568, 0.01020450736177736, 0.020663222567236517, 0.031024960408103652, 0.04577861873258371, 0.038598317696596496, 0.1497939886758104, 0.020450205774977803, 0.016326363875123207, 0.026804351728060283, 0.010450803911226103, 0.037769194022985175, 0.07799301922204904, 0.04362757048511412, 0.024665712189744227, 0.049193603845196776, 0.06739022996043786, 0.041312767352792434, 0.03734857811650727, 0.09500657659373246, 0.007214434263005387, 0.02540430868975818, 0.03550472334609367, 0.06055137993826065, 0.06217156624188647, 0.05016851871914696, 0.030571602801501285, 0.07726598909357563, 0.004601696409736178, 0.053261400607880205, 0.025819664624577854, 0.03741150852874853, 0.044837145032943226, 0.06723322119796649, 0.05081450261059217, 0.05326386453816667, 0.033637223750702105, 0.04904673281998839, 0.023819476446078625, 0.022664672396786045, 0.024077634370769374, 0.01097617674531648, 0.039819736921344884, 0.04644680397177581, 0.04572225261654239, 0.0033807623640313977, 0.08898639338440262, 0.08058665465796366, 0.018076984488288872, 0.04577475214318838, 0.042524330856394954, 0.04149964384851046, 0.01304490040638484, 0.036910165508743376, 0.015400482698169071, 0.007913897316029761, 0.03703984468302224, 0.03216019402316306, 0.026604335507727228, 0.06862929745693691, 0.04132586997002363, 0.04851452016737312, 0.044561311005963944, 0.010076967428176431, 0.03840416815364733, 0.015415135476359865, 0.06826418306445703, 0.03545519612089265, 0.02266223444166826, 0.04306631759391166, 0.025734937335073482, 0.05710997436835896, 0.018173302269133274, 0.0350609932502266, 0.04677803190134, 0.028639202391786966, 0.01241522521013394, 0.04696566167694982, 0.0516184377920581, 0.0190963966815616, 0.030620818324678112, 0.00512101053573133, 0.10187694933847524, 0.08683965701493435, 0.05327207640220877, 0.04141067147429567, 0.02617621277750004, 0.04974985837179702, 0.054952766295173205, 0.04507265446591191, 0.03882416436681524, 0.020546028172248043, 0.03491819661576301, 0.04594629586790688, 0.06326886126771569, 0.015143709806579864, 0.03164724381349515, 0.10387761620222591, 0.05650128339766525, 0.028830923256464303, 0.0626130921591539, 0.008095070406852756, 0.007583075712318532, 0.009831087409111205, 0.03637161120423116, 0.08405663291341625, 0.02609320912597468, 0.01936065877089277, 0.028359410862321965, 0.04166492755757645, 0.013684281966561684, 0.011784272592194611, 0.030041054415050894, 0.038859665000927635, 0.022603450779570267, 0.010182438672927674, 0.08953830634709448, 0.05622306707664393, 0.03858355637930799, 0.062031571214902215, 0.010063783174700802, 0.016271094282274134, 0.06958965881494805, 0.034601841325638816, 0.04770956082211342, 0.05165400893019978, 0.02887978254875634, 0.04223845557135064, 0.005191645832383074, 0.05017502735427115, 0.011758815071516437, 0.0025815583740040893, 0.06371786061208695, 0.01577266233653063, 0.022034572320990264, 0.06120568701589946, 0.0224534998415038, 0.0734649907099083, 0.02490032733476255, 0.12242733762832358, 0.10965631197905168, 0.1026966143399477, 0.09746848081704229, 0.08353936340427026, 0.11660563439363614, 0.19043049251195043, 0.14845938450889662, 0.15079999953741208, 0.1170879413257353, 0.16774697141954675, 0.10535146211623214, 0.08694553180248477, 0.13583203864982352, 0.20352178456960246, 0.12352973120869137, 0.1487243757583201, 0.2227616959135048, 0.12307881712331437, 0.14977283746702597, 0.1254404423525557, 0.15139159513637424, 0.2574771229410544, 0.16846491023898125, 0.13674554822500795, 0.2617173985345289, 0.15929589833831415, 0.14951734570786357, 0.0851206797233317, 0.09922636891133152, 0.11168509139679372, 0.12199833916383795, 0.14915033883880824, 0.17386335181072354, 0.20063238102011383, 0.08332099387189373, 0.12385144480504096, 0.14609248260967433, 0.03818885255896021, 0.16006598045350984, 0.1288206281606108, 0.14349428296554834, 0.11865556502016261, 0.20066046388819814, 0.16174532705917954, 0.14899665489792824, 0.13086429506074637, 0.1296964960056357, 0.14737236080691218, 0.12808373488951474, 0.2210775253479369, 0.12667310511460528, 0.15481362323043868, 0.13719322654651478, 0.20589361432939768, 0.11801956672570668, 0.11681186981149949, 0.1629501741263084, 0.2273855431121774, 0.14842748700175434, 0.23320317937759683, 0.14510033506667241, 0.18233281531138346, 0.13615902891615406, 0.16023692674934864, 0.10026474483311176, 0.10096214842633344, 0.08058422783506103, 0.13758165179751813, 0.1466875069309026, 0.10442661252454855, 0.12899915920570493, 0.26555679563898593, 0.1502710857312195, 0.17030840506777167, 0.10868373487028293, 0.18239292927319184, 0.11608668763074093, 0.05565056693740189, 0.13191167323384434, 0.1385899484739639, 0.13199221109971404, 0.13468736491631716, 0.1523225154960528, 0.2303870554897003, 0.14214375230949372, 0.11466172698419541, 0.13406648417003453, 0.2272700797766447, 0.18032959545962512, 0.10748933724244125, 0.10161106751183979, 0.15498125954763964, 0.10282036746502854, 0.15948271175147966, 0.16845613805344328, 0.1865446221199818, 0.13451714592520148, 0.1854451303370297, 0.15269476192770526, 0.13494051148882136, 0.12086104979971424, 0.17848115792730823, 0.16118104249471799, 0.11915062947082333, 0.10412168630864471, 0.09110405982937664, 0.1398018014151603, 0.13506868039257824, 0.18007867533015087, 0.14268316008383408, 0.1775461557554081, 0.08722149199456908, 0.18405308393994346, 0.1388733004569076, 0.18873124150559306, 0.15010812494438142, 0.219428057607729, 0.08382805885048583, 0.17589599039638415, 0.18700276472372934, 0.2220060708350502, 0.09743197457282804, 0.06005104623909574, 0.10069251875393093, 0.10556520806858316, 0.16410727141192183, 0.12384055007714778, 0.11455629748525098, 0.12993644719244912, 0.1525310886790976, 0.11048653774196282, 0.13371288048801944, 0.15225987823214382, 0.3602846438298002, 0.10447105232742615, 0.13025180058320984, 0.17144295590696856, 0.17941840138519183, 0.12140022008679807, 0.16445201385067776, 0.18013662222074345, 0.1990067065344192, 0.04453956236829981, 0.13352769979974255, 0.09601232028217055, 0.19684177270391956, 0.09668397877248935, 0.12194627750432119, 0.08719631834537722, 0.16236372903222218, 0.07710056437645108, 0.09974397980840877, 0.15068054344737902, 0.12283698830287904, 0.19400231569306925, 0.11915034003322944, 0.11039365796023048, 0.10506867416552268, 0.10375395955634303, 0.07248401248943992, 0.07545240281615406, 0.18801273865392432, 0.09941256634192541, 0.14736001146957278, 0.10988359470502473, 0.10316591884475201, 0.1288588487659581, 0.10421814324217848, 0.14219401055015624, 0.1356690630200319, 0.13292802963405848, 0.17265411122934893, 0.13979825394926593, 0.16244573635049164, 0.15095225855475292], [0.06657228674157523, 0.014595181037293514, 0.048477401651325636, 0.06944900698726997, 0.02821962920279475, 0.02643035197252175, 0.03231974464142695, 0.040439211297780275, 0.01220124919200316, 0.03305964361061342, 0.042280828492948785, 0.024006050516618416, 0.009836163699219469, 0.049612913571763784, 0.03054248092666967, 0.012522880224423716, 0.033848205202957615, 0.06132515052740928, 0.014557970680471044, 0.03525067135342397, 0.04216414061374962, 0.04292837831599172, 0.006415633351934957, 0.10389490824309178, 0.026301093967049383, 0.04187312595604453, 0.024214723889599554, 0.08209713298128918, 0.05990986006509047, 0.001794099102880864, 0.05259212070086505, 0.0666512141469866, 0.07782555359881371, 0.027656186975946184, 0.0726270540326368, 0.010008227854996221, 0.0839704398822505, 0.021497843699762598, 0.027829858809127472, 0.031037552798807155, 0.03912743188266177, 0.04032043427287135, 0.022721602545061614, 0.06378326608682983, 0.02907544607296586, 0.010471281620993977, 0.012427182136889314, 0.01610239669389557, 0.04900329491647426, 0.05622771663183812, 0.08163309030351229, 0.014637823915109038, 0.03253276699979324, 0.016254741058219224, 0.020297421688155737, 0.04076419776538387, 0.09731030688271858, 0.01606040783372009, 0.012055036822857801, 0.013898475990572479, 0.04118870623642579, 0.03883214245433919, 0.04144677324802615, 0.012671127005887683, 0.04966034794051666, 0.028787412993551698, 0.009063401503226487, 0.015983699449861888, 0.03749484800209757, 0.06538770772749558, 0.04774575907504186, 0.01931419290485792, 0.10477410090970807, 0.0633306970121339, 0.03568130254279822, 0.08453401940641925, 0.04886701062787324, 0.04930166425765492, 0.011397830730857095, 0.03985534516687039, 0.022041318443370983, 0.013950125758128706, 0.0620649047777988, 0.011583420528040733, 0.049096749862656, 0.04861608307692222, 0.004375025491754059, 0.02649659236340085, 0.03270251843787264, 0.06348752023768611, 0.008002344620763324, 0.01830371060350444, 0.08274147301563062, 0.04697237069194671, 0.04617428363417275, 0.004025761054435861, 0.015680060860177036, 0.10418413061415777, 0.05514481927093584, 0.01648465469770599, 0.020750089097418822, 0.045742739603156224, 0.030802436704107095, 0.02162818709621206, 0.05466495771543123, 0.01847259558417136, 0.03852173547784332, 0.05021214958105702, 0.021359366364777088, 0.05543054241570644, 0.09587740525603294, 0.015733467662357725, 0.03883023513481021, 0.06279768655076623, 0.009169668701360933, 0.004888405683232122, 0.1096878680982627, 0.028890115099784452, 0.07175383565481752, 0.037136809987714514, 0.060855159536004066, 0.01497438139267615, 0.040756308735581115, 0.0493097462458536, 0.025778651688597165, 0.045914921574876644, 0.0632266775937751, 0.009479042237217072, 0.02294775164045859, 0.03471478135907091, 0.011311800972180208, 0.03442152541538235, 0.04523765244812239, 0.03533107192197349, 0.028896085677843075, 0.011323756971250987, 0.026471648779988755, 0.016363471258955542, 0.034194209292763844, 0.06504144388600253, 0.021370357571868226, 0.03196041529008653, 0.06156194387585856, 0.023565597002743743, 0.01464910641516326, 0.010361600543546956, 0.03266393418016378, 0.028876097785541788, 0.059738876661867835, 0.020545193256111816, 0.052029721191502176, 0.06900875756400637, 0.03483935826807283, 0.047511670854873955, 0.029274760963744484, 0.0054166394966159714, 0.028658295996137895, 0.06427998552680947, 0.019506971329974476, 0.037182288797339424, 0.02083110564853996, 0.014047169916011626, 0.0529548750637332, 0.04182874923571944, 0.06503495751530863, 0.030625697945652064, 0.027425915250205435, 0.03237196215195581, 0.07039800606435165, 0.07372743639280088, 0.03319583513075486, 0.04342893837019801, 0.030529487776220776, 0.020817279437324032, 0.050321486487518996, 0.11483702968689613, 0.06163042184198275, 0.030303952808026224, 0.051070977715426125, 0.030131332969176583, 0.020490383794822264, 0.00984144407993881, 0.05313686822773889, 0.04073341719049495, 0.06161203884403221, 0.043461039967951365, 0.01111819505240419, 0.04072874908160884, 0.06500604344182648, 0.02074991283734562, 0.035003354350919835, 0.043103191201225854, 0.016399886590079404, 0.04227066849125549, 0.05661203038471285, 0.06469704283517785, 0.01865550901129609, 0.04478517243114766, 0.0196474153563031, 0.0483211795653915, 0.015101019616849953, 0.0027980129334537196, 0.036966913830838166, 0.03694671257107984, 0.055841068824520335, 0.07596521943924017, 0.028319004632066935, 0.038757990769227035, 0.075070419406984, 0.047506060218438506, 0.09719371548271738, 0.02469928323989734, 0.031826119957258925, 0.10056426821392961, 0.11847681875224225, 0.01709395979560213, 0.01743540709867375, 0.03868626219627913, 0.07052081666188315, 0.03888915423885919, 0.05925514851696789, 0.021924920001765713, 0.06724435341311619, 0.10700172395445406, 0.08091800875263289, 0.0554903743613977, 0.022923761716810986, 0.0819130135641899, 0.029792247551085893, 0.02339145947189536, 0.05837648277520202, 0.025789624341996387, 0.02581184424343519, 0.0209843164702761, 0.03015624501131242, 0.010571898292255355, 0.053359438315965235, 0.049903379040188156, 0.030434492873609997, 0.026624393904057797, 0.03784744236327242, 0.007450070324921398, 0.007397233584924834, 0.041367140802321956, 0.07014730857918039, 0.022529983725689817, 0.05499188118847087, 0.023239207876031287, 0.07173310004873201, 0.04875685364822857, 0.03133322257781401, 0.09769180047442205, 0.06344549983623438, 0.008519061229890212, 0.05840410180098843, 0.008226166155509418, 0.01137268120146473, 0.04001064698968548, 0.09254549615434371, 0.025234573950001504, 0.029396404534054454, 0.06826836135587655, 0.035291979293106124, 0.02454664387187222, 0.057219949521822855, 0.040320048356079496, 0.026896982890320942, 0.030529374598700088, 0.06400238518835977, 0.05882107747311238, 0.016969310527201742, 0.027356748942111153, 0.06912894838023931, 0.033132726603071205, 0.08956068209954537, 0.03720336208061781, 0.04281869260012172, 0.012205927505419822, 0.03425049006182235, 0.044776470749638975, 0.026532311931077857, 0.038241214788286015, 0.019400111341383308, 0.09013906004838645, 0.06586642266483977, 0.04173265224380884, 0.04704995109932497, 0.04647687579563353, 0.017574856647115666, 0.059838476590812206, 0.055849755663075484, 0.031582996089127846, 0.06363872540532611, 0.057341316642123275, 0.022550810244865716, 0.03334424982313067, 0.03463116729108151, 0.0851890463673044, 0.031600507063558325, 0.05007547195418738, 0.033847930608317256, 0.05336363145033829, 0.007837461671442725, 0.03209413174772635, 0.03132630205072928, 0.02597248210804537, 0.04067044967086986, 0.08318901775055565, 0.03339756571222097, 0.07789129304001108, 0.05424479451903608, 0.050661178611335345, 0.014696069520141464, 0.013026301257923478, 0.016272151842713356, 0.04206117504509166, 0.016994560246530455, 0.014832206306891749, 0.056060874412651174, 0.0160365477859159, 0.012253424956725212, 0.006812138735767803, 0.04207496785966214, 0.032672249944880605, 0.08830540609778836, 0.03063971525989473, 0.06153117443318479, 0.05584684644418303, 0.014794164744671434, 0.042645286084734835, 0.02648030778800603, 0.04415968665853143, 0.04965601008734666, 0.07030367909464985, 0.03738617531780619, 0.024475577665725723, 0.04477925751416478, 0.05121789698023349, 0.03382372917258181, 0.07277157244971022, 0.039733955782139674, 0.006858940887468634, 0.048824481855263, 0.04547207834548317, 0.04947974630340468, 0.08037459338083863, 0.014956188570067752, 0.05793279349745717, 0.0492305145598948, 0.06440301876864396, 0.08438532269792631, 0.03202864092600066, 0.15331626607803628, 0.10907751100603491, 0.16717339516617358, 0.14125534216873348, 0.08378827973501757, 0.0841689643857535, 0.0902911409502849, 0.13434605119982734, 0.1382122843642719, 0.1271273588645272, 0.1470509366481565, 0.09375757173984312, 0.16037913708714768, 0.11819205668871291, 0.12940394139150158, 0.2627519523957744, 0.11377390314009972, 0.12264374789083377, 0.09999723770306446, 0.10831228995812126, 0.11062663295888342, 0.08912993958801962, 0.10139029342099093, 0.22866469400469214, 0.10320947549189441, 0.13969862804515287, 0.16172707022633404, 0.222483939724043, 0.16094689490273595, 0.1566226378781721, 0.1703924755565822, 0.1510739410878159, 0.23260818474227563, 0.081678480055416, 0.21980499441269785, 0.10836931658559479, 0.11801521774032153, 0.15753963554743677, 0.1724211807595566, 0.12417485049809329, 0.12633093050681055, 0.18665719107957557, 0.15529612312093377, 0.08233724744059145, 0.1680739171570167, 0.07895836039097048, 0.1145419072418008, 0.14586430188501254, 0.19794870080659166, 0.13450953149003908, 0.13285267195897177, 0.10749078443041071, 0.0644275541708339, 0.13843458727933466, 0.1990401031798683, 0.09760338100022636, 0.14233525609597564, 0.12955572543432936, 0.11326313484460115, 0.08193615372874774, 0.10498373536393046, 0.18577356036985293, 0.06440845128963701, 0.10045859380625188, 0.12551395950140432, 0.16149375383974984, 0.07745839087874629, 0.21959376434097067, 0.1524141855770722, 0.09382745978655294, 0.1233054393378552, 0.08980207305285148, 0.20213647687342018, 0.12055213082931004, 0.13795830658636987, 0.2854063961422071, 0.16802656813524663, 0.1039174101606477, 0.08703671948751435, 0.0884876107738819, 0.1185567925858777, 0.13808926596539095, 0.20929708873154595, 0.13998123788041994, 0.11239909683354199, 0.1401946201804094, 0.1510349931777455, 0.20955761225195602, 0.1686045082169585, 0.16775308671640232, 0.09248940463294275, 0.08288800265290774, 0.21448542829602957, 0.1317887587356381, 0.09595024705049582, 0.08254385393229313, 0.09870342939393595, 0.2976435801247135, 0.1604476521606557, 0.10371406911872327, 0.1242450725112576, 0.18618392350617796, 0.1389956657658331, 0.17438626906368881, 0.15916137665044516, 0.1144288781506475, 0.09045242448337376, 0.10719624086050317, 0.1433452300261706, 0.18561175733339041, 0.143970058998093, 0.12696744088316336, 0.1851400631130673, 0.2007127259275876, 0.18816158379195258, 0.15080593671882525, 0.2324520071852021, 0.20544240338495, 0.2704711491242051, 0.14064673654502258, 0.11243073458899744, 0.17331877868855372, 0.1376679487293586, 0.14776742085814476, 0.112993779766839, 0.158282465999946, 0.22102734132204205, 0.08655815297970548, 0.06645485671469942, 0.2635157707845792, 0.18084132112562656, 0.13481778994901106, 0.0947225269919727, 0.16706416587112471, 0.1507244340609759, 0.15936459152726457, 0.07060488715069368, 0.10094685276271775, 0.11178392320289277, 0.18089441437041387, 0.12258165239472874, 0.13262443186249584, 0.2004435786511749, 0.08268215315183625, 0.11373309243936092, 0.17216162203112617, 0.13434881198918447, 0.18409121548756957, 0.12715009826933965, 0.09695778673631139, 0.1336133584845811, 0.15320807578973472, 0.09589565466740169, 0.10155469397432171, 0.17932305025169626, 0.10316142142983153, 0.198501393024344, 0.38102102174889296, 0.12851778737967834, 0.10075479978695512, 0.1212927422602661, 0.12023916715406813, 0.1851489837281406, 0.13634817267302424, 0.10920528657152317, 0.14046396041521803, 0.12696643156232312, 0.17030136950779706, 0.13564764463808388, 0.1543693884741515, 0.12650603282963857, 0.11641044955467805, 0.2023403299972415, 0.10504372316063382, 0.14052612270461395, 0.13442716794088483], [0.022679277863062453, 0.032981246840790845, 0.02993534475535853, 0.07384848810033873, 0.049196791369467974, 0.03632488558650948, 0.07695260981563479, 0.030664282203360926, 0.011222524317417992, 0.03930709841370117, 0.013950238935649395, 0.06689371090033092, 0.009075717443920439, 0.0430679688724922, 0.07204446068499237, 0.035883945965906605, 0.026841479520953726, 0.040216581837739795, 0.03676510903460439, 0.048219883829005994, 0.04404524377605412, 0.037568517291219905, 0.04151747765718028, 0.009886763327813242, 0.04512865692959167, 0.07576196003356017, 0.014501779896818334, 0.14224446174921468, 0.03112388869340066, 0.030486061004921794, 0.0909206157666631, 0.03481359461147804, 0.045729807679890655, 0.03616661888372619, 0.013607446489913855, 0.025739982083905488, 0.034574489473016, 0.022793440584791824, 0.06976091681281105, 0.020454983350646216, 0.04617368249455467, 0.009414254600415006, 0.08611083088908345, 0.07747177922283299, 0.007932576245366363, 0.06194128895003814, 0.007928850664029596, 0.04257191736542154, 0.06348143462673761, 0.01859500727732666, 0.06891405952046625, 0.06369536611600779, 0.029040266417723615, 0.025369555769430008, 0.06154412119940389, 0.039631765757803805, 0.08015386381885037, 0.03131440913421102, 0.060967034587520175, 0.014032493018021341, 0.016714598023099825, 0.09484653986874036, 0.05653239422827028, 0.018803240927809384, 0.042101369763258845, 0.007697872970311437, 0.027377133883419447, 0.05811695744341705, 0.07198276594863273, 0.00825563220132608, 0.03648425066785421, 0.0074908884471369674, 0.07348978586378507, 0.08303814654937014, 0.03680545218230691, 0.014558507809852017, 0.015322588733397424, 0.040487180012860335, 0.03739365245564841, 0.03406421099498402, 0.018142363987863064, 0.04531262049567886, 0.016547525738133118, 0.06160399396321736, 0.05213587799516972, 0.1067103270906955, 0.049772163620218635, 0.03531543115968816, 0.06892146615427919, 0.02625261873618001, 0.07099691181792878, 0.10263651522109285, 0.012372688088362338, 0.0205799220566405, 0.05452233548567165, 0.026468335090612527, 0.04798573623702396, 0.05592030051047914, 0.040202844684245065, 0.01868412808107678, 0.036825727656832896, 0.04197742367978208, 0.05281147357891314, 0.0370660128101008, 0.03298850133433007, 0.03020538075361401, 0.049613522132858634, 0.026213041855953634, 0.006531321650982136, 0.01310400597503758, 0.039680491463514045, 0.07405045616906136, 0.034543452857178636, 0.03604671008361038, 0.008115609343803953, 0.01447028500479064, 0.04493275220738724, 0.04554121311230119, 0.013611839076475007, 0.03558140204404481, 0.037249375236569904, 0.04689040048106108, 0.0053153516455495264, 0.06929829905857332, 0.08950093179009855, 0.003445525417191675, 0.011717214911186602, 0.02110382636601571, 0.03260879631852731, 0.028576964032254182, 0.0759593045222573, 0.01876272708614124, 0.027652581993606873, 0.012779526023223298, 0.08059940475504845, 0.11352114248438738, 0.08922135733882897, 0.015349032382800942, 0.018444316046952736, 0.019624559063231573, 0.0457578163332073, 0.02094345196383074, 0.02838995209458517, 0.05823594598041382, 0.09167907584924251, 0.06438393815187737, 0.0044526740839501144, 0.023934477794682607, 0.027999012818327174, 0.0244587401903118, 0.01890919364086585, 0.046316839070641436, 0.06933585173101164, 0.04599773412337527, 0.01451575732062338, 0.06987453220062889, 0.018536889692768455, 0.021682660735677928, 0.08933629374951124, 0.022608747858612332, 0.03506629218463786, 0.022746505310351495, 0.012109803610655945, 0.036168522492516786, 0.020550633198581636, 0.03443321795202792, 0.016236358060268685, 0.024966814489744138, 0.1354357021045871, 0.0481086470244918, 0.04678438097471371, 0.017907067922351416, 0.06738938391208649, 0.05485692534421105, 0.04389724839711562, 0.07205522924778052, 0.0554034614469856, 0.021212343199294992, 0.04164171317825094, 0.0778444783645682, 0.037912217012490146, 0.07027276122244075, 0.033890284976223484, 0.0427040975773707, 0.026496573809708934, 0.026575976189633366, 0.0515962624194799, 0.03176180172886234, 0.035072255341219716, 0.04997753072530031, 0.08181836747098714, 0.03912989210220985, 0.06556733715115115, 0.015704388461017516, 0.01960805369890295, 0.029727495166298468, 0.012210997301735915, 0.07662621326744556, 0.04918856095173396, 0.015361668374680448, 0.018828225329343695, 0.013793369325867388, 0.012728083129331935, 0.050147066940553486, 0.012045406529068714, 0.023451998313248623, 0.0322671041067224, 0.03379482252057642, 0.01852834571764106, 0.05244873776973691, 0.07286373976967297, 0.015456553810508922, 0.052703324108733796, 0.014097182320256252, 0.021767621801700443, 0.082411180192139, 0.02833627069776412, 0.034845480986405164, 0.04065376990183722, 0.036944742168998346, 0.04895301070064306, 0.054417651845142245, 0.046094610370346345, 0.03170823722030036, 0.0035457404010230675, 0.02627650846989127, 0.028953307119081728, 0.027809985949716065, 0.04961370395903941, 0.03521605387504678, 0.019572977944335435, 0.04858798907662276, 0.06966687185922638, 0.03245006206270773, 0.05783609907666687, 0.05956154418527149, 0.046505429927492514, 0.07789926370605826, 0.013438710866466863, 0.015316063399950508, 0.04998639567929786, 0.01782172836101381, 0.030567561807401944, 0.06418178454623558, 0.05109756515594199, 0.027438264587544836, 0.013028995253989706, 0.037606077385134995, 0.04992310903617181, 0.036917772522429004, 0.07917439215816557, 0.0252825129791745, 0.09240722662070766, 0.0426732019695919, 0.015322266826842679, 0.04294319158361759, 0.02892785516451113, 0.04829301506106276, 0.013621586258523166, 0.06568436641828157, 0.03555907453119289, 0.05150721211975906, 0.010509352869121358, 0.03663232768303715, 0.02152567609300604, 0.02325886736798566, 0.09748968397616409, 0.044700730868498795, 0.053625171713065356, 0.07109201804269105, 0.07265180465765297, 0.011041117450076854, 0.04040661246108357, 0.00838076386571629, 0.05788882124761585, 0.018946217533084564, 0.008536507266398985, 0.024462211586069316, 0.0448562070960179, 0.07229331764392555, 0.04029319745313842, 0.03290588916570414, 0.022420466848416254, 0.03310877007606905, 0.031850584855419584, 0.02506126205844339, 0.05160368018550798, 0.06959994498174638, 0.03384921081305947, 0.03310986103315372, 0.016628837292955723, 0.026427353695908096, 0.08210641724872403, 0.04417297481268179, 0.02255447459901916, 0.007174747452154406, 0.035099703673040494, 0.027691383329511154, 0.006826780381743447, 0.020597227085090708, 0.11265562759945169, 0.023336564663622994, 0.061442818041541614, 0.02164324341720203, 0.04383358696941286, 0.046237952483352274, 0.009165311366814421, 0.018000190757447854, 0.05908802428166382, 0.033226563755306415, 0.042695778101915494, 0.007914943744253833, 0.020543996542983223, 0.053885235101915896, 0.045259267499204725, 0.04558524102321826, 0.04032256794744171, 0.034148140475736, 0.03856002658721991, 0.05651325795042794, 0.04561924622976221, 0.031664862399338745, 0.04900442669168115, 0.010008740864577703, 0.0605458583595464, 0.053215049774735235, 0.020403326161613222, 0.06507723024697043, 0.010498780975467525, 0.05314461996022146, 0.03471948657534085, 0.045854102572775446, 0.02393353897787165, 0.047443103831028566, 0.017423386161681265, 0.05804951477330178, 0.00424103861405456, 0.07304702798137441, 0.011418730537116062, 0.031190010340651497, 0.04838695240323432, 0.05953625921392813, 0.07195233789389022, 0.02657349185028579, 0.07654045068193227, 0.02241239413706353, 0.05281923644361086, 0.04878464707871899, 0.06731398912961595, 0.035236106705269776, 0.07408492150716484, 0.0346179125335766, 0.14707743132021278, 0.058248291607014835, 0.16605028824415058, 0.19346267043147236, 0.09833792166318744, 0.14415774814551696, 0.19102612539427355, 0.09191314922645688, 0.1582691221847199, 0.13630928413476795, 0.11638894211500883, 0.1221526539302431, 0.14030374557478353, 0.11537994039827026, 0.22493225522339344, 0.16204326966544613, 0.159316337085329, 0.1115309918532148, 0.11367041064659134, 0.1579246172332205, 0.13405076548224315, 0.15495979663683102, 0.13133161060977727, 0.0801789558317978, 0.10115203433088027, 0.10487109218956903, 0.05836823380377609, 0.25532801169902086, 0.08914536883821711, 0.14554310037055984, 0.14662991627119482, 0.13760523725068197, 0.15051890368340537, 0.14379513479070738, 0.18774455616949126, 0.08118413548800163, 0.15573716664221138, 0.11243832675972953, 0.14982014195993543, 0.16108241106849164, 0.16533215646632016, 0.10771634537377395, 0.19798232009634376, 0.18920085771242157, 0.1358897183672525, 0.12861465249443427, 0.08694709773408249, 0.17350596317555755, 0.15216338419122621, 0.06617134145926684, 0.09487575822276995, 0.14537117443978786, 0.12468386732507497, 0.13177666172850877, 0.10092017997521907, 0.1997068931814283, 0.20494896423770115, 0.16567869490245357, 0.160551211447455, 0.13452217768644914, 0.11605855281231925, 0.2946130943018943, 0.13262710359413177, 0.141535903676413, 0.10688090231269598, 0.12824340054066852, 0.19136084883939475, 0.1741999454679899, 0.1568543809116818, 0.09803841312532313, 0.09943394019501284, 0.15698384115239605, 0.12339063789113425, 0.2178932962124236, 0.1462783312308602, 0.11892938040546142, 0.18378558423137292, 0.11360024058376439, 0.10322942442144267, 0.1305834366939962, 0.11490551507449709, 0.1422069239197299, 0.10475108691025525, 0.19367569650057703, 0.14711001160321757, 0.16280003765132278, 0.1388101585325785, 0.21222049748757854, 0.19393958937143907, 0.09466466915910132, 0.21313215169357136, 0.2534889697562903, 0.11629805128904991, 0.17038857185980305, 0.149272822891362, 0.15016142599051818, 0.11790766569902189, 0.18014760600635782, 0.15824191505089402, 0.16090255900053307, 0.12902259622933343, 0.1490859649493359, 0.1267903347616084, 0.12705882894806564, 0.0777095410740003, 0.0946319404465612, 0.09750694633112289, 0.15211119636660442, 0.07743123569525778, 0.13605622661998495, 0.1588193653151393, 0.1784093922469765, 0.1538104028441012, 0.0990349987114314, 0.10231336927972734, 0.11771145669627003, 0.1702577609103173, 0.1460384245729074, 0.10314388448023237, 0.10081049054861069, 0.1556666032411158, 0.20202105806674808, 0.07991502585355192, 0.11166594398673624, 0.23728911794023588, 0.08534634456736967, 0.1736158604035154, 0.10199780808761716, 0.12505106715252623, 0.2984353626379743, 0.09676673565991223, 0.1248747477075085, 0.0887353322468698, 0.07299599790712819, 0.10072788951219991, 0.1855611428618431, 0.12193351998575963, 0.14445957960560918, 0.14873435022309422, 0.13337702897842973, 0.10750820263638161, 0.11478342436021194, 0.11971341489697807, 0.13403434917563573, 0.1923210543463938, 0.11055015464080498, 0.1721443299902603, 0.06780259689548984, 0.11614130227826536, 0.13714069733396173, 0.11822743486845866, 0.13973543856991455, 0.14641139830928296, 0.12373969962936826, 0.13472018268657848, 0.15987190883606672, 0.26160839188378304, 0.07744096525129862, 0.21255001105600968, 0.21113601193064824, 0.1136481091089081, 0.1257726424955763, 0.09752000813023187, 0.20614233770174906, 0.17744120123097673, 0.13694953493541107, 0.1683057937771082, 0.10817370872246101, 0.22573668393306434, 0.1285673925303854, 0.17402015277184546, 0.0863765791291371, 0.08810864790575579, 0.12793885282007977, 0.11215393577003852, 0.15789485711138695], [0.02833961036230903, 0.06318418963928707, 0.033162323452415876, 0.06611835953663103, 0.06763703117030673, 0.09225884161423892, 0.03889360712491907, 0.03106050000496907, 0.04130410648940597, 0.06737520889146253, 0.021556259998760652, 0.03407709096791223, 0.047582545957993716, 0.042729861233965494, 0.043232421376160346, 0.021155813810764812, 0.01316038044024026, 0.022294008595054038, 0.03867600200464949, 0.04221248411340639, 0.030086920996836852, 0.025021089604706503, 0.01166327097962494, 0.02749891846178798, 0.03941613103961572, 0.0481216605840018, 0.12305658237892203, 0.04361187035101466, 0.021587124065263197, 0.045921463606646284, 0.028928575047757477, 0.00838527426822111, 0.02623415410198504, 0.06509459650260396, 0.06724359642248601, 0.026378147449577227, 0.003530139529175358, 0.034269845273229294, 0.07291827278095298, 0.07893668225733563, 0.0503423779446166, 0.032815766462590545, 0.04151482818997465, 0.011099770308646839, 0.022560152028745506, 0.037438452200149186, 0.042044105648528785, 0.07593716625706293, 0.007221196619866532, 0.11482157075079158, 0.05852720183611382, 0.10127056273631752, 0.029200310564192478, 0.0447172844724264, 0.07139705558074638, 0.029350871918722987, 0.04568228425341658, 0.0374378733249614, 0.02897085705626523, 0.027760098782891873, 0.023798807633284014, 0.05974465799226891, 0.03350776722072624, 0.031107075337786227, 0.04093927411304321, 0.04287530362489633, 0.02003557343414286, 0.04060204591951333, 0.032752361075836234, 0.03861187673464883, 0.018619203146954533, 0.01422733832441736, 0.058802891144296154, 0.022575434704776853, 0.07542702878708951, 0.02296592869242886, 0.027515600086189806, 0.027315235056448728, 0.0713011775224004, 0.020374649575387593, 0.08579471308621578, 0.010372934993938543, 0.013071152952761622, 0.035802124184556305, 0.07782436616253108, 0.06322874076431617, 0.09926012178766541, 0.07075382876791991, 0.008566037322452758, 0.029188315602368675, 0.00881937407029909, 0.08795232934062369, 0.032375624650740065, 0.07562025435618125, 0.03368940044310875, 0.002016248718064162, 0.027236140667810105, 0.03924274307792075, 0.03016378337633796, 0.09354749199701473, 0.013537333015847253, 0.06512414140161127, 0.018896141118602827, 0.0681935677130241, 0.09468202057178132, 0.025319815176771954, 0.008801012409094255, 0.024778713450359646, 0.08759004253079183, 0.061232263324200176, 0.019680275800055824, 0.008855817231960827, 0.036167398138786666, 0.06206313475559, 0.033835087742772885, 0.034092627829522826, 0.007005917204878642, 0.032306426801369525, 0.0911871729476843, 0.03358617141202558, 0.04527090066403616, 0.04941441133269109, 0.03336096298880875, 0.052947000876883976, 0.05239004130999092, 0.022568998429051135, 0.022519413687405176, 0.050508470594650134, 0.017927410190168303, 0.04699199678725563, 0.025117030745605007, 0.0941870897077024, 0.06462418619776145, 0.06819810965680517, 0.004320045336498879, 0.044091839517932385, 0.016918339824769646, 0.03182471729815006, 0.034702368939178996, 0.04910798968921881, 0.008552488488930976, 0.031735540833324194, 0.03981788526289165, 0.010903634592978051, 0.04327332484535873, 0.01076486967576784, 0.04288124822778627, 0.06815536195063032, 0.01303896693571005, 0.01151826274508494, 0.08126514832838438, 0.05252818838926032, 0.016970080505416263, 0.025170433837047312, 0.025893716119753662, 0.04520982562098652, 0.03365363634657115, 0.026336249502492137, 0.010614686816552421, 0.07285815881914459, 0.024203478496929165, 0.08109889982733876, 0.012424041924532503, 0.011141543018311495, 0.03475299083220307, 0.08161539750290103, 0.05515736898814794, 0.036449288090807386, 0.007491881997339078, 0.012938314084749436, 0.0360991353954887, 0.008182431392924627, 0.048719735132181086, 0.019232001905038487, 0.004794777723873267, 0.035008976119570434, 0.014715419165440835, 0.050858229951700196, 0.03312343491415959, 0.030613831004302483, 0.07539411453763023, 0.046870737278368324, 0.033208548120455816, 0.006633685152337421, 0.026885197585215792, 0.07094795233570039, 0.050632030761335045, 0.031056896877998952, 0.02348579200770473, 0.048719801925471984, 0.05142404705111403, 0.036877195598208345, 0.07326397259021178, 0.03423031106649432, 0.03127650765236467, 0.04028363116958644, 0.057820706933853216, 0.019604537774284836, 0.032302445179084316, 0.019065482520090882, 0.047231959106284194, 0.028696581539406907, 0.044926870687049814, 0.008403116426052293, 0.03872824177960865, 0.025108650042966474, 0.015015506578492932, 0.025363219683640637, 0.07265859530889429, 0.032463665629620664, 0.04923439599224366, 0.023327927920036018, 0.05557195865549147, 0.0337633331946563, 0.02969083307107212, 0.06541576833114959, 0.009878965211100876, 0.05487624344823416, 0.032823674046085216, 0.04366646273410879, 0.02096814878314035, 0.025300962770415936, 0.03600481213652529, 0.043812116637127474, 0.05680158232280519, 0.07614706046297215, 0.06539023102959618, 0.053788985969731584, 0.005289428427204257, 0.05380464899644721, 0.06577996246051043, 0.03297139111964498, 0.02412609290331602, 0.014672382021672092, 0.031650828386773355, 0.033409132083761506, 0.040577584732091054, 0.022708598262397572, 0.05791899326140992, 0.04735047637950629, 0.057772563814069144, 0.04294060148822609, 0.02809420067933388, 0.015141070543904789, 0.06089500544476323, 0.015436603953276062, 0.04553931692498736, 0.01787482717190869, 0.03491912430035882, 0.014349506036523962, 0.047071243316167966, 0.01979763346753316, 0.024384876087424345, 0.028287678578635678, 0.06358442245982587, 0.05136174746439792, 0.08508584331138991, 0.02011246921028942, 0.039891302221803926, 0.032941048411885276, 0.058218238336849026, 0.035936219137511216, 0.08680968909175135, 0.004739448759210063, 0.06317384410067461, 0.024013672373257577, 0.05069885002740193, 0.057607840426499024, 0.008964180069597205, 0.0806002804893069, 0.06486263082479127, 0.025456982621108182, 0.017912791736307554, 0.03222277191525791, 0.032869082351680845, 0.12388229588395916, 0.012844944485550513, 0.04632510659575928, 0.022549791647179518, 0.01416659724782221, 0.018176653065893333, 0.05350342609744985, 0.033308144338661805, 0.013219857082731323, 0.08303036884171888, 0.08931687916629016, 0.034438776638126, 0.037687487274524756, 0.032137632733793, 0.04196999107080046, 0.00528515412042907, 0.044481225850177, 0.009398055372003, 0.059700388883356936, 0.05279654527839739, 0.030985381672508083, 0.033658694082987495, 0.04776700305228587, 0.02334153890842572, 0.03178391030814964, 0.050583360716700554, 0.04564404138363898, 0.010343670255679172, 0.05330408523150254, 0.019341101324243937, 0.01546238152513979, 0.00760455300223839, 0.04761901138408575, 0.05190968993701972, 0.02466205711243674, 0.03848736290819943, 0.01842725778260501, 0.004809370666407631, 0.05197842765483074, 0.08447078842436895, 0.013310212634678464, 0.021418380092654843, 0.045120055438019335, 0.024472926343150903, 0.023148343025241047, 0.07298352240468375, 0.02262656682432862, 0.03942958246625494, 0.014361616958922241, 0.03982358866778668, 0.014009506849106401, 0.0642939230601769, 0.024261100697913207, 0.017406632177880965, 0.017299256396654528, 0.11399753449950367, 0.041838037213892676, 0.04975987736543175, 0.029589910263894126, 0.014058253891562345, 0.029011964616074692, 0.040216340639744885, 0.11116756955743767, 0.03303097444586456, 0.060691530816257, 0.03228344990930054, 0.024823017811286263, 0.06055449695850257, 0.05716787673009094, 0.04292209974664729, 0.02809422108839499, 0.07121104368707165, 0.045910160697530955, 0.020341386516520288, 0.06698632350889966, 0.005555463321798015, 0.02647293084010016, 0.12311126381973736, 0.23096870630979538, 0.07387515346636064, 0.18577118549728766, 0.13812356803100556, 0.23724737955490127, 0.13921522273449227, 0.09882923084660433, 0.18486747227143496, 0.1634031513822265, 0.12177642958704382, 0.12182959704659879, 0.1798088601208292, 0.16229824192123488, 0.12066498922649771, 0.1305323769338429, 0.1526436279527843, 0.11023949904483743, 0.12056277322699316, 0.11944346610107459, 0.14846072037471458, 0.10039231259725057, 0.11156599153764546, 0.08432002854533494, 0.18427237373543903, 0.07254486117744818, 0.19868826580932364, 0.15696153219323605, 0.0975340792501811, 0.12726571003440768, 0.08619428539532237, 0.1206865486165043, 0.1348791952477768, 0.2829754172125831, 0.20113667036639526, 0.09478890468017198, 0.17675437324214727, 0.11450476275058463, 0.16956628707703203, 0.18433612422086298, 0.0814837850339245, 0.07424324387102388, 0.13554951787227765, 0.11408579812268727, 0.12482232239563018, 0.1403815671801567, 0.1313755160663277, 0.16573876433540136, 0.11387407081201673, 0.18783582549076527, 0.13631957030156627, 0.16092834121081978, 0.1075297397619579, 0.11023886821931228, 0.17237130843568593, 0.14648592477897182, 0.14939735527150333, 0.17173110216390342, 0.12413470773026347, 0.11641410092124715, 0.13038724253419787, 0.16852886852575466, 0.10570324753643945, 0.13067748164758086, 0.17107970430515707, 0.15165605203947052, 0.12793095636880025, 0.0814725860254839, 0.13192461628932506, 0.09427824028534815, 0.09636032074922696, 0.11840944658615626, 0.13323155319085345, 0.16418696322944015, 0.23798906709998846, 0.10900753390160389, 0.07121003436623141, 0.13498612388502806, 0.2239307714626193, 0.12772170040989295, 0.20765983674209565, 0.06693167917546816, 0.10181730292970315, 0.14655003149528056, 0.20638543559471145, 0.16404148744186386, 0.23027757386444137, 0.15141191513976082, 0.1430507903569378, 0.0995805514685344, 0.169584306422621, 0.21450269065098837, 0.13257963582873344, 0.15131160645978525, 0.1298731568385847, 0.09693849089671858, 0.08576697160606273, 0.0853998534148559, 0.12451786373276263, 0.2436497391317971, 0.1240455312654376, 0.18840534961782396, 0.06712259666528553, 0.15936144482111558, 0.12119951366912574, 0.19239261222537607, 0.19078026671195403, 0.10095205521793105, 0.2269911509938538, 0.2031704963883385, 0.21005652844905853, 0.07669954487937503, 0.1507133463746868, 0.0882976729189977, 0.2047472633421421, 0.11838833990623243, 0.20559389056870714, 0.2433145110262558, 0.17232539918040857, 0.13608560082502663, 0.08705841246410273, 0.149521368148271, 0.0937691937724594, 0.23933774238685146, 0.14291637256974354, 0.13492810277966782, 0.11526230999152176, 0.1501098764128983, 0.087402635399485, 0.1391834142850712, 0.12544253520900384, 0.22227655397728086, 0.1126976554223802, 0.09446563257370144, 0.10928681149380282, 0.08808081736788154, 0.11597984805121087, 0.19253072590800002, 0.1805053508724086, 0.09835866469074972, 0.0840153249737341, 0.09449136283365078, 0.20162789791356772, 0.10157504366361536, 0.22558644355740398, 0.20714478625450283, 0.15782007831148803, 0.12862961419159546, 0.1162130902230274, 0.12038106578984298, 0.16328075638739392, 0.13603507541120052, 0.10158273231354542, 0.11261178893619217, 0.2094570512417704, 0.198501615668647, 0.16033054125728086, 0.11518405051901937, 0.10504920021048747, 0.1952650205930695, 0.09116095287026837, 0.18472297611879185, 0.09526887384708971, 0.15709940838860348, 0.1379118036129512, 0.3886251855874434, 0.1773460875847377, 0.12035677529638633, 0.10439700083225034, 0.11581950704567134, 0.14440166240092367, 0.17555089172674343, 0.12967492919415236, 0.12309280660701916, 0.1265466134645976, 0.09602589416317642], [0.045580966252600774, 0.059409878886071965, 0.06654744705883786, 0.02384245890425518, 0.04708283566287719, 0.04724358856037725, 0.030153595544106793, 0.012743588449666277, 0.03796849036007188, 0.02922975898400182, 0.07950751256430522, 0.061577061424031854, 0.051099932607030496, 0.017853002464107703, 0.027646171693049837, 0.03385011623322498, 0.010539995219005505, 0.03895639281836338, 0.0353076757164672, 0.057699877870618366, 0.09871477683191188, 0.028717432178382296, 0.055955389252630994, 0.013477256161422702, 0.04432324487424921, 0.04694728610047605, 0.06685125263174996, 0.04108807101147249, 0.05618916948151309, 0.024749775257078, 0.030775442937738262, 0.033656274681561626, 0.013210782472015126, 0.04798530208063312, 0.06098494632169604, 0.008662215950607788, 0.06520323950098827, 0.019274359983683098, 0.03178001403284725, 0.05462913053634111, 0.02343850977922557, 0.03418311047425959, 0.031134249074966647, 0.053398594027385116, 0.0731877243379131, 0.04504958480538335, 0.01579781928739976, 0.014035282565600937, 0.03149409421894234, 0.03652480161690619, 0.019230183643230703, 0.03185881156241521, 0.01785444408596959, 0.12059539061738178, 0.051099275806336664, 0.03363940937560983, 0.017689177075226326, 0.04791700222995132, 0.01342441431916086, 0.04271765661542304, 0.04119983845157549, 0.07318941643461585, 0.07961787734529935, 0.050392346747685224, 0.024460831191390753, 0.09791529824724421, 0.0222650462819729, 0.04830686353670899, 0.0730202067643404, 0.045387955906335264, 0.02497800422133878, 0.018260415563418064, 0.030335612827911973, 0.046475833078147843, 0.025339701023767702, 0.05686846467142459, 0.006209638204381918, 0.049870969451148994, 0.05637486967316363, 0.023397457880491856, 0.022971570870140567, 0.05260052181256469, 0.049517117149662226, 0.046370693016797304, 0.01007552024020697, 0.08674295517266728, 0.010169263696298003, 0.02451780586852692, 0.014216384224710055, 0.05666294171533082, 0.07511666262871586, 0.05130062789248768, 0.007156011470215162, 0.021077027413411997, 0.03596483635192271, 0.06664987828116864, 0.025174048096232582, 0.02772091524093412, 0.061241198782227, 0.06528685727971606, 0.03370644015376456, 0.015807988565939013, 0.009260814640583703, 0.038383926075766794, 0.01134305095547461, 0.034311286799493246, 0.04036002414068207, 0.04227771147270687, 0.05290406392305158, 0.021088647590659093, 0.049974491630564444, 0.04239650705130771, 0.034004698172793724, 0.04741287244542036, 0.024692631741345394, 0.07728849101113155, 0.036733256056322716, 0.062171885365387425, 0.06658997954218648, 0.016343084462278057, 0.02483541909896303, 0.10637230850988999, 0.1179992244578898, 0.07282163773197681, 0.02415279723209096, 0.01106302657717606, 0.06559366855071858, 0.0426937631709734, 0.023869341348472517, 0.05614674460957758, 0.041303471953142434, 0.03845375475066248, 0.02361133741942467, 0.04957560951879714, 0.03482863794488367, 0.006809388150941231, 0.05167707487998996, 0.06380797960446216, 0.05122548172948882, 0.010837013851414667, 0.06063487897336017, 0.035863325392710976, 0.04581339948344976, 0.036025414156029, 0.02134825826942688, 0.042579784130793996, 0.01483704418205889, 0.014300451930466807, 0.006600488886761013, 0.0014257211159929284, 0.02539950884965947, 0.03680934474687092, 0.032790403565741144, 0.0165292262317962, 0.06262979048187844, 0.08911384982638992, 0.05244595471594948, 0.012269764265511185, 0.059343148677726276, 0.022584043617825955, 0.011403080497984774, 0.05235461860138457, 0.019715828384505585, 0.03725534952536691, 0.015029666756163351, 0.024470952230331022, 0.01874490440968657, 0.041848961627692915, 0.07564484913018532, 0.0036948172282791347, 0.05495896693901159, 0.013499280321411788, 0.03474273435131181, 0.07518869548221119, 0.01990844353713328, 0.03417831248953007, 0.06406359010725282, 0.04560631059575826, 0.014364096659846837, 0.02626819084980525, 0.050354961058474146, 0.07557669028756209, 0.0245935234852368, 0.028186330891912803, 0.01619701124582207, 0.018249804707011208, 0.06023619724146556, 0.07916124872281216, 0.0343606284877751, 0.05567983724176884, 0.032854758901521564, 0.05268497079669032, 0.04038290455355309, 0.05631666674162261, 0.03703377762576565, 0.06083014544856269, 0.04207724254229106, 0.07707724609645084, 0.041380428956472315, 0.003477851282696065, 0.0918567088956479, 0.02730279851675732, 0.03831331443507224, 0.033464718944742344, 0.054406497365562245, 0.019833113692584448, 0.045186477655079216, 0.004978872093488462, 0.06426954350899905, 0.05935740904533304, 0.036462323914747685, 0.018712448436417617, 0.027015453779313248, 0.01622711275558686, 0.02419296040898189, 0.01713272402412258, 0.0567186065018177, 0.020124287912040018, 0.030603696977777872, 0.11540256105945446, 0.09496595142991282, 0.0232954867897206, 0.019554320351744536, 0.020470095332711935, 0.02217966590251308, 0.03424335431191139, 0.020472011929086875, 0.04292556557629723, 0.051859168233931996, 0.016460421720694285, 0.02793093561194837, 0.003296664276604133, 0.04379673562652897, 0.03141103676171042, 0.02929397887783125, 0.02677302010852145, 0.060292559646768495, 0.04969043089658953, 0.08010727920918725, 0.06637292361119762, 0.04694517469033599, 0.05741326414863579, 0.07467136660125107, 0.10260164912324399, 0.053340699087129906, 0.0391045403375756, 0.061463772581191733, 0.06303237591055222, 0.024867491010809317, 0.017753990687197074, 0.0260290226287907, 0.00938807163038291, 0.07991196078364737, 0.04228181183862034, 0.03889159961545374, 0.07207181624835357, 0.03537860276992433, 0.030527647249982692, 0.025761739998415578, 0.03578995667339768, 0.041995810388471, 0.036293722805567086, 0.016310960600094404, 0.04153825037064962, 0.0229036847667885, 0.01920747949043289, 0.03428959011216648, 0.06311717370408587, 0.05170662348973565, 0.016815515264170244, 0.051200586385675706, 0.049045816267607734, 0.012832533921027789, 0.008865555137163028, 0.04558096996333916, 0.01944466061104322, 0.053657176831620745, 0.026009177599917166, 0.06653500866377726, 0.03587424609577283, 0.0165457594266627, 0.023535293257737067, 0.05405719071859494, 0.02100068268191535, 0.026986597222276032, 0.01535158258775482, 0.0724711139628198, 0.04919380051433109, 0.02121873494616011, 0.036554899415932596, 0.013497099334927043, 0.06539593814522959, 0.047513210811303, 0.011688123649946647, 0.015825293594389223, 0.07722066613496281, 0.054644181291223504, 0.021064399770693853, 0.05539330515603069, 0.06800820890930481, 0.07127784439944662, 0.07037764895358123, 0.036625407155952416, 0.010779466792882886, 0.04349648123024963, 0.023437185045622755, 0.022167392635310534, 0.023394357558572665, 0.025087960821110755, 0.017524216200399678, 0.032558742168475874, 0.01628823418286629, 0.04812831764866132, 0.04471445317903999, 0.03817767581494991, 0.036163884069537744, 0.042125296604353935, 0.025377378005941864, 0.018993967314600013, 0.017065995671146084, 0.014432933639909606, 0.041830496993497945, 0.016078338121587876, 0.012646588820643956, 0.049403906232328154, 0.04108777786314022, 0.016442884771095123, 0.02859806514607044, 0.03014512392837787, 0.05434575257822871, 0.053207016026135534, 0.04106614796910435, 0.02900720930483658, 0.041590928012738004, 0.04446072030987125, 0.049413097731303424, 0.034865288907894865, 0.08173219670425169, 0.01429909008948016, 0.048962276414386, 0.014222959653125145, 0.02394782717601629, 0.0408299668924883, 0.01567797542520566, 0.000967993651102006, 0.025507728823868092, 0.10269166421494447, 0.033252460998483, 0.02118631236953661, 0.0805356542696245, 0.017560726155352313, 0.05692506085324567, 0.1631034869933501, 0.1468595367623493, 0.13525160495191813, 0.14325707772513852, 0.11375105241313577, 0.20579139090841636, 0.06997867036261596, 0.11030566151021048, 0.09514328019577079, 0.11493683370645158, 0.15102809120435268, 0.11696503424900584, 0.07547260407591239, 0.15191271639196202, 0.10792838438646868, 0.13828897790517658, 0.16901052236789837, 0.2213651966303587, 0.13446062395814806, 0.13365502265514806, 0.15805121278390288, 0.21545686991885304, 0.1850784945418127, 0.06284927323576994, 0.23130173765821382, 0.12493858725065365, 0.2273625513771549, 0.11531613054103218, 0.2220914771896787, 0.1343096562777646, 0.21785252261906862, 0.07445530514814891, 0.10209758242126554, 0.09756938321515918, 0.13594570598797873, 0.1030300983984489, 0.1520128914853558, 0.15777966094901785, 0.15078339027240872, 0.1707129497663118, 0.15171205450315028, 0.07502848806325346, 0.07101577721186914, 0.17984889156650752, 0.28073101420886815, 0.1533596817171201, 0.11360698670614511, 0.12858033558586612, 0.1414612733060494, 0.19087870517978445, 0.155193691898603, 0.20791185525013134, 0.13876024167984724, 0.22555910283699632, 0.12143847037805244, 0.1559680636273697, 0.12596344866324216, 0.1253269679727964, 0.11356030561728403, 0.1013565257017035, 0.17389714921591803, 0.19518458662787452, 0.16474676522193477, 0.15107063110917807, 0.14845150290057063, 0.19401804922381416, 0.18773066316498443, 0.15988816187018529, 0.15262890374287963, 0.06942001869902015, 0.1550133796990849, 0.13077143754344434, 0.09287355511332862, 0.10385406785644591, 0.09259249636670575, 0.12542190350359306, 0.16134268225869164, 0.18432312179356813, 0.12757490359945223, 0.2175138212624006, 0.13087271101539955, 0.14661502878880128, 0.18343085248488933, 0.3181917197071016, 0.11431409759097733, 0.11781771740061231, 0.15956005838233978, 0.1702429327997379, 0.10984268752508797, 0.136207906762138, 0.20232878217939287, 0.19029794493690133, 0.17018212121911347, 0.15280393185094, 0.17709396517602727, 0.10540956485783681, 0.1128769211936742, 0.12718974379822612, 0.1419688726309687, 0.171932149969507, 0.12706785346381366, 0.08462633515591733, 0.1055985304992646, 0.12273101703613065, 0.11211083183297887, 0.13049568515270948, 0.17031457973644137, 0.13786132272798568, 0.13975851936265826, 0.152974299271591, 0.25339578569401056, 0.10168576467549428, 0.17064970394130796, 0.16685722541296855, 0.1420354432775639, 0.19554785307263955, 0.15947981737554073, 0.14677672792458907, 0.20251440815627575, 0.09929693231242709, 0.20131552795646712, 0.12883962714113295, 0.27360672305803746, 0.16726044908864424, 0.2531761990394443, 0.1121543142653536, 0.10735609947005287, 0.10719157275161706, 0.09635627604438923, 0.1405682321637869, 0.10303402435965836, 0.13222114881500602, 0.09807791764615104, 0.12648528238059953, 0.14494898146949708, 0.13591701455879956, 0.39228130190167576, 0.20099720597499982, 0.10277497771312483, 0.08538620531908236, 0.15942863887175918, 0.14315694716060534, 0.13066639396129176, 0.13779484113911167, 0.12999228638364002, 0.13113739056279883, 0.09771026510861702, 0.06231120874872431, 0.16447806323412806, 0.0792662997264415, 0.08405787972151302, 0.1943338182172738, 0.17192208644701168, 0.16233235102845356, 0.15549022442428395, 0.10988098234520294, 0.14512121910229325, 0.2363601271645166, 0.11391339721740223, 0.14099122665356845, 0.11354229369317181, 0.12729637557640672, 0.11619733442785218, 0.1617020004778169, 0.08448025822872296, 0.11110219376860186, 0.2470982470549643, 0.08562496906961314, 0.14912038575857878, 0.10157805678318255, 0.20754401717567816, 0.1202230848139152, 0.13919511053245515, 0.2493442827835679, 0.20793656876776367, 0.11602818412939087], [0.04971558599208947, 0.046106970839900896, 0.02452242017170647, 0.045474219441530295, 0.051927620224887505, 0.09973868829547428, 0.02740690513746813, 0.05437854808405973, 0.05752419296186417, 0.05829397079651244, 0.018391053963568993, 0.022249741341511253, 0.06319563355646096, 0.03026387312274892, 0.030898602344677784, 0.02978026372147724, 0.011258063914283412, 0.022605597441724967, 0.015128159957384923, 0.08002962087630294, 0.042235935979988426, 0.026026421401184052, 0.06872298617963679, 0.025905020884238183, 0.026967171506839804, 0.025998537057603244, 0.0585843063890934, 0.10399176593637094, 0.015293183914764086, 0.02186413068557158, 0.060440068918978795, 0.08951168550993316, 0.010224915495200548, 0.05723083311750088, 0.06882225585286506, 0.03670975966088008, 0.03199834274710156, 0.05996562875225209, 0.02975757441163296, 0.03099328554526437, 0.02228050521807745, 0.09118898378801532, 0.059108915738761425, 0.05605931219179183, 0.04566792740661185, 0.06294721446465701, 0.012609634504769929, 0.013714729502680711, 0.027186121769773308, 0.018124224043276627, 0.07977159839356318, 0.03966139971453231, 0.0828460713091772, 0.02234334657259751, 0.027081759108114056, 0.02767947928077774, 0.015867308429733384, 0.025226081925211474, 0.0227541178901447, 0.003118746662948979, 0.07545666274381801, 0.004419898987180204, 0.02446833244903246, 0.008923671794036636, 0.024725521871005185, 0.03590687090763822, 0.03604170800826978, 0.03916663954441901, 0.052245534025132656, 0.04990537170669995, 0.023092043702490628, 0.03129624135908671, 0.04037521590362303, 0.02540524936193833, 0.003380615557944111, 0.04462628603505436, 0.020791450842807535, 0.0637619590270333, 0.00915452239496517, 0.014150150327623123, 0.022766138827137183, 0.0038385209063562797, 0.05372945830458775, 0.006048082859706483, 0.0785475890734233, 0.02177700625907164, 0.012593645860761171, 0.057400258010602556, 0.051997942427988164, 0.06985172600252554, 0.059137777861906216, 0.04623474640538916, 0.03271755063906312, 0.05607836683338974, 0.0339579168939963, 0.04183285702310968, 0.06927867667400278, 0.10381853382568806, 0.03883144483552314, 0.05987750984786544, 0.01788897436199477, 0.06641672516707331, 0.023406658656313084, 0.01630639824725222, 0.04330907038820442, 0.05382374074542895, 0.015362482881755568, 0.016321393341058865, 0.008049190837482456, 0.05069171056675259, 0.023967052511579823, 0.05803905049106106, 0.06048437142453622, 0.0712042604573071, 0.06458065923652612, 0.018288164465047885, 0.03724066242284607, 0.052302590338513255, 0.044609257456613705, 0.06337043159874156, 0.01981079731194768, 0.030546447706001345, 0.06095914555771742, 0.0345857998036081, 0.018264899990754202, 0.02432310899166623, 0.04211765248328447, 0.06386021937942132, 0.04179782765277196, 0.11643298857961781, 0.03820484584139194, 0.0432483664189931, 0.04471750340599101, 0.01262600071640918, 0.0313082827051403, 0.011780290969909402, 0.030469156736216974, 0.03982685782830231, 0.014658771033282392, 0.023377718607662246, 0.047364951969939284, 0.016519966084160842, 0.02872579247195972, 0.03606717109505553, 0.03454174962826073, 0.006574133367394097, 0.0449274718266679, 0.07673254076507874, 0.03156688777380623, 0.0360451775486581, 0.01605574714631075, 0.03192150448739994, 0.0036663175978901563, 0.0602829748095246, 0.01799363388272468, 0.056500203572795726, 0.05365159588109236, 0.028582031045516487, 0.03422270776354708, 0.03773337426537182, 0.032820976339280605, 0.02568204261478968, 0.05667918732797261, 0.013386369973886758, 0.06090658294851892, 0.01833259313571034, 0.09761228677234612, 0.021180774092499632, 0.06385492786648683, 0.02985479761264287, 0.08638206360046752, 0.01762146352120908, 0.03049037288292311, 0.031249530584318563, 0.04495658999076113, 0.031356396139017306, 0.03644101685495116, 0.033981116430368274, 0.03185148656484671, 0.010730277244874742, 0.01958214161277283, 0.020481286919675767, 0.07951564650284126, 0.030524348403559998, 0.042058659164467826, 0.02265142320538871, 0.05121748508827295, 0.040285011564265005, 0.033103430323535576, 0.07332174136536196, 0.039107345655793324, 0.009885382005450083, 0.030905205603630748, 0.026871614427363966, 0.02980781780934194, 0.04729110456537455, 0.04517430643318221, 0.058878460331470706, 0.04680271202232689, 0.03153103090880904, 0.039280503551708534, 0.007246669911182835, 0.06368775910232216, 0.009022791182360379, 0.06307239993475378, 0.055948079098016024, 0.06507778685772792, 0.09085382989724167, 0.038055295663070865, 0.04910446448775474, 0.04008943709777668, 0.02304514368006494, 0.12864383374108002, 0.06920059531694278, 0.029707891335419845, 0.05702181835658848, 0.038603457069257274, 0.024920714131440036, 0.05848441331181675, 0.033607007208047435, 0.019462160453258548, 0.04440592754690442, 0.019798075045400765, 0.008512969125149539, 0.0074990799021179555, 0.04198609196464531, 0.053653618233511224, 0.029819400879205205, 0.04395064592245035, 0.02933786021458218, 0.03811458584095817, 0.049913383190869354, 0.03627940677688457, 0.017774544467101805, 0.06645939123700373, 0.027528138671186753, 0.07148298143874854, 0.02663724975718651, 0.05271700931189116, 0.007958076439535944, 0.03302918586996384, 0.052693501784233376, 0.09106420649914071, 0.07264692132594064, 0.02806631262501469, 0.07851053363992833, 0.04694570161518641, 0.013170437468943419, 0.026136147935176268, 0.02187865822634194, 0.0240491229124018, 0.01096293497539591, 0.05223511056101415, 0.07845233441912569, 0.0015338770799644408, 0.04155556838668417, 0.04772401414811611, 0.11364697362296283, 0.023191923792182934, 0.03500440448988229, 0.025280490626755636, 0.06310555167146958, 0.029659052452188917, 0.07735333245364018, 0.01851869594247546, 0.06687481582048349, 0.009035593229782535, 0.07253574760397896, 0.051120564312441275, 0.014187763299560174, 0.044604448339669034, 0.08286651747766882, 0.09281673628720455, 0.02208637051808182, 0.04098135388630908, 0.021103783692524303, 0.026043811776617076, 0.050839650284615345, 0.035667179472511634, 0.02706007355300244, 0.041038176423171535, 0.022855270763102453, 0.0583928434207337, 0.013376551360124722, 0.02340721526707057, 0.017907572582771536, 0.05246255284873769, 0.010344614638597704, 0.0061307279611355625, 0.02844130685843993, 0.07019937766017392, 0.11438128422014415, 0.013926920655649155, 0.01886619174911175, 0.00997778124656179, 0.04703666294517461, 0.04001274726761039, 0.007508906401199056, 0.028248103553778492, 0.01226480764671578, 0.0334397864935454, 0.03608973238442559, 0.0900343207467813, 0.017857700258900877, 0.03223377054382581, 0.016658703170833178, 0.01864216334070079, 0.012481834819482174, 0.04858978507400025, 0.061037312261760235, 0.023476249843952246, 0.027894989689229988, 0.01525002802736708, 0.03447329392656684, 0.019934535594074987, 0.02177042897528736, 0.1171762272133492, 0.027181769073649775, 0.03061471044929931, 0.025333756420877762, 0.025621583554311655, 0.04450782071216963, 0.0026285875765097444, 0.08256429267930798, 0.012246765109011903, 0.10954096738714725, 0.015598626850987785, 0.11698424845235422, 0.02018808292632457, 0.021906112124270294, 0.046567388126277365, 0.03280251541582402, 0.07298145181266591, 0.03229147623642348, 0.023976971315278206, 0.04200987779768184, 0.015494689996558009, 0.0684782258758787, 0.06645606641541235, 0.044104107219027355, 0.029270126251503825, 0.010977813180943485, 0.013624178209283855, 0.023200740506581496, 0.0964194476546254, 0.04335998914029915, 0.05115076601214241, 0.02191917948948685, 0.0476594361680327, 0.026951692161674146, 0.05503165659320075, 0.011614471059147036, 0.17699281044770032, 0.14876175031531602, 0.1648188871331513, 0.11448745586676523, 0.18186377797974274, 0.12337586173089221, 0.17143036908237264, 0.12900386442197487, 0.1549446865101345, 0.10045933595392853, 0.20810899935895577, 0.1997309536091052, 0.147121247719042, 0.14980384439695626, 0.1130059955175966, 0.1347361388616264, 0.11992172090685926, 0.13744960888288915, 0.13624824990984052, 0.2925184863852337, 0.1567788451211527, 0.16022840689402074, 0.10084399109473452, 0.15181708324234933, 0.08722785220015794, 0.1004493614891544, 0.18239019816974178, 0.17179298243718222, 0.1304837959469296, 0.13765298703219742, 0.15281004714779556, 0.17935977171873674, 0.19829289405606687, 0.19479010545182973, 0.1376806542975828, 0.091237965534674, 0.26368257589638233, 0.26086823316290975, 0.22695894178468734, 0.07541712111560628, 0.09182841822621413, 0.1971033203881234, 0.09646903796237893, 0.18038323789369315, 0.11956429516430944, 0.1790851473924704, 0.09812827236601152, 0.15397426905110478, 0.12123337044613436, 0.25547822238877416, 0.14156909252051264, 0.19489011727273464, 0.2194766979664564, 0.1204288229928352, 0.0999520557525102, 0.18693304737098515, 0.11019417608622462, 0.1618866913486272, 0.12937489373143762, 0.06584113769349642, 0.1642757686204277, 0.13730570644838735, 0.14676851977128536, 0.0867833651136607, 0.08822035597404465, 0.2248436279478483, 0.12209743072162382, 0.12944321584654972, 0.20526287786196917, 0.15257925406331196, 0.13549839874031022, 0.11074136156821623, 0.1401833098498173, 0.1634550720336847, 0.09122033210587688, 0.09735755942529067, 0.14889778598444536, 0.16478385776281357, 0.142289896029979, 0.1211637124652043, 0.11704369448125362, 0.16353359125787392, 0.08767827646806836, 0.09378158021718264, 0.16538802534341812, 0.14922295056749135, 0.13228669529780746, 0.11127020115964115, 0.16231445042649284, 0.21299866901244968, 0.14004035736434162, 0.16650295379804447, 0.19470809813356027, 0.14499015582259744, 0.11708455713232979, 0.20139072235906497, 0.2045787958195433, 0.14564804005203769, 0.1748702532495372, 0.1481782441260293, 0.17328698508208618, 0.11773530190112069, 0.11324473700369708, 0.08987836583401076, 0.12192674417747185, 0.1087889120390173, 0.20678410248365253, 0.0914128526346758, 0.07180375250754878, 0.13438390073133633, 0.2377239867928438, 0.10967891037580557, 0.14441218605497852, 0.2154285050346516, 0.15726294805062935, 0.21531494159717113, 0.1837442020769231, 0.12003397074295208, 0.15773450868437067, 0.1441003059153445, 0.07640326468390413, 0.09912568173604086, 0.13781438930891454, 0.12886086740763858, 0.15778289671288803, 0.09922916680807248, 0.19271687138825655, 0.10081503249239177, 0.11083918405347504, 0.21929084934527054, 0.14476491400273517, 0.08053539451793768, 0.13915786956204101, 0.1389404945075512, 0.11436140208388679, 0.14379917207406834, 0.1490936684422195, 0.13260141044156626, 0.12595826847245917, 0.1128151967714075, 0.16062211623648182, 0.13248805480543524, 0.15154605091083795, 0.09582964063156396, 0.13614662020700052, 0.08832517691189423, 0.11120081035187468, 0.22606051265029237, 0.09738557550008409, 0.21285979833919555, 0.09671662584878504, 0.240091304294765, 0.10229180988972075, 0.20306429505581036, 0.06178042844112497, 0.11688393235090189, 0.19318711099913344, 0.11947206847253256, 0.13290506758494303, 0.1649314709356986, 0.11234980338485911, 0.15159500297158957, 0.17421124095562845, 0.11207083749468438, 0.13505048293154687, 0.09055406160769053, 0.10690358976717107, 0.13829694857122377, 0.24168476957129315, 0.09973693682695739, 0.2243266033474356, 0.11387684644432738, 0.20767003385117278, 0.0990982296934817, 0.13654536131070927, 0.07901389530161396], [0.08183131794794463, 0.05640910494548734, 0.043915572023252025, 0.027720315956685226, 0.04868818272370845, 0.025586797237338033, 0.03717948718986008, 0.015411510084959446, 0.06740724740666337, 0.07273766372236423, 0.02875058020435972, 0.0714659714139998, 0.04196666995994747, 0.054810604196973145, 0.035960465102107264, 0.022605929552810267, 0.04651710391044617, 0.0921738360193558, 0.011217596456845058, 0.024980583184515126, 0.05373041938582901, 0.0429309498576913, 0.02769539649307262, 0.051774029052467085, 0.02497506902727764, 0.036088003180339, 0.019632561270555016, 0.07938822716823779, 0.018204815714852884, 0.05900126721826382, 0.027544360164029058, 0.0362362212035805, 0.034992600631085224, 0.02150700365746161, 0.05021324053814169, 0.03631006118666846, 0.02970881716464646, 0.05356626003049314, 0.03188663838955108, 0.0018652472931535158, 0.03642332034360152, 0.01903525298985187, 0.0570825668546604, 0.030670560772705358, 0.06404367828508839, 0.07980750349815935, 0.06200137322593946, 0.04604909074259922, 0.045258165409904905, 0.03801072969508823, 0.03438870393438265, 0.0439891003043158, 0.09169800803647377, 0.07734339509624988, 0.025148056229227223, 0.0048112598960869946, 0.041478615094092675, 0.049273885670118034, 0.021424257902253885, 0.03125125978840515, 0.07817152800271288, 0.015937233583827037, 0.04992907961423043, 0.049736967266653664, 0.06263664792641066, 0.02340128179639578, 0.017032213108905125, 0.013657852232427103, 0.037824988685315475, 0.05463087458338123, 0.02674543076864211, 0.0769397929252591, 0.04731592198368162, 0.025080802806769498, 0.04279467299056705, 0.025360291911056265, 0.038130070752231404, 0.03597425420593936, 0.0737340934574604, 0.033004965880536474, 0.08346809496288188, 0.043007955100620165, 0.017957981108338572, 0.035926934870076366, 0.05838282442709897, 0.048665602880646475, 0.08013714323169552, 0.05642601478029974, 0.031741693237563595, 0.04308189898438286, 0.059282292568241246, 0.05009620013879612, 0.03743880100955721, 0.03355446686327923, 0.028558321282616816, 0.1271640061168, 0.05489106784807518, 0.03553471353370696, 0.0774938210088294, 0.056787785797496326, 0.0251752392432536, 0.05415038591308985, 0.040357044417760335, 0.02887379527237499, 0.053759541260660626, 0.049622268343227915, 0.05878214811673388, 0.016554767244087998, 0.003713924515977851, 0.008698272267793072, 0.019790121077676304, 0.026747332522063516, 0.07706779113505036, 0.04579509812174365, 0.03315532871056348, 0.037144535745028406, 0.01330181245066342, 0.024545938831579406, 0.08081752195721492, 0.016849882267706562, 0.05615638510789722, 0.06606453898712061, 0.01579967836732976, 0.05409245386545081, 0.005481733733176952, 0.08636822254629806, 0.021215996421233285, 0.05473437820910476, 0.06608520037843846, 0.06799901369959116, 0.010313683778804261, 0.012024127299810061, 0.028589829162228853, 0.018337300207349472, 0.062489776901202276, 0.03173161487211473, 0.037932425693725236, 0.10311736754374579, 0.09028803135151975, 0.02250843546789838, 0.03316449794510845, 0.036251112396712415, 0.017096663068514317, 0.027828747442981694, 0.04424197228217963, 0.015277173006325029, 0.02943560106359655, 0.04048085320391692, 0.024111431775963865, 0.0388368328276556, 0.037303370190784335, 0.04142492813116405, 0.06462075005401857, 0.105117603961844, 0.024645857884024736, 0.01211363773109042, 0.011631680536083877, 0.03108656979748048, 0.04114385825232603, 0.05001658995752223, 0.0021484414537553675, 0.025074741315620486, 0.057088667308562435, 0.053756531851831824, 0.05494011638802476, 0.04702821730461437, 0.01898683898616582, 0.016163909604074433, 0.03802838167757727, 0.010931646029348485, 0.059916762038483284, 0.026131323975278065, 0.05356183311960194, 0.03452095465036109, 0.05093905725516379, 0.019042730127694085, 0.05507493864570279, 0.014029006779310293, 0.018029986131296027, 0.05253267467196565, 0.05214770782913547, 0.04336400786996819, 0.03579129253921565, 0.030524897592840716, 0.09194739192025736, 0.020714610727736726, 0.03241127371438779, 0.04605752525094431, 0.06889939468237571, 0.020186342590022832, 0.11508789044455625, 0.024410261248704046, 0.026267033099429682, 0.031898991437628865, 0.023326560512941796, 0.027115933153254446, 0.03218209109036252, 0.03560886521881912, 0.029385205525613856, 0.050257082912139595, 0.01941114151122747, 0.02080910468066577, 0.026968294005200732, 0.021893250705034006, 0.019182105461368337, 0.058792460258700885, 0.030348457548825536, 0.007815010776539566, 0.04282740912458394, 0.0637668052513618, 0.046386289250222035, 0.031424836997757666, 0.07385880395304412, 0.033832356639322825, 0.04166209255345166, 0.021160249998501968, 0.07278511664480902, 0.013593150870292448, 0.058229377973475493, 0.04168054976616986, 0.03064440934394952, 0.06438537791837007, 0.03473956909147091, 0.015756210777908564, 0.015992351036402397, 0.036503899027593434, 0.02697089523280738, 0.02104813374899095, 0.05139858396432828, 0.03003073485160712, 0.03438609899603762, 0.09954439403372817, 0.03355020693561528, 0.14090975368162617, 0.09880455443635583, 0.03447759467235301, 0.05548157248995267, 0.014008146863488946, 0.047525281843263656, 0.04603313085681293, 0.052912067985744216, 0.01930329261085717, 0.034660778983379714, 0.023616768085048534, 0.04632527728972491, 0.015674175629101228, 0.06790182946133427, 0.06752294080797583, 0.1030910287227016, 0.08319057626067661, 0.022622694668825716, 0.05685136558895465, 0.08131336566293612, 0.02124748945789179, 0.051231066390755586, 0.10554256514296867, 0.060874344053445384, 0.018993191770277917, 0.0536370906047523, 0.06550046964548528, 0.04591827608237509, 0.024168868440028746, 0.0549077067989856, 0.014912266415194608, 0.05134925711899996, 0.023996792224352248, 0.0031657060571887996, 0.09702973795356229, 0.026354677029303275, 0.037807993503520265, 0.01750938066834351, 0.07119170331861824, 0.054929525940679014, 0.03719947693753056, 0.05391008220613003, 0.06900209307787009, 0.005264698675091495, 0.03517981480399612, 0.033598583831917495, 0.05263311693852302, 0.01347843617622857, 0.04616528138285503, 0.09957319678505883, 0.006403348952517263, 0.026740558569144923, 0.03342986397910863, 0.024606011975265574, 0.02450618012517225, 0.07228429312817752, 0.050434842123650014, 0.05142274087120313, 0.0361134328704793, 0.022431005345424637, 0.044085330882808194, 0.058696971827885136, 0.027042005967814475, 0.05666547243890818, 0.04515201231697574, 0.06300335051491857, 0.018494635514798574, 0.019668087879836094, 0.07934533103252761, 0.031600106303812936, 0.030999007503851317, 0.055693570684525184, 0.04866291259531863, 0.049327145898132585, 0.055551100595039316, 0.019703766629390884, 0.042659116006689146, 0.04824834148166701, 0.026336394221289083, 0.043610627253656276, 0.004906137446596404, 0.05208786104049068, 0.03748321112652775, 0.06642034684773535, 0.041597184317652136, 0.05213294651184697, 0.08185771614080295, 0.04139367629250046, 0.024757478749961592, 0.0304607407815638, 0.07711423473665491, 0.04169325533439405, 0.025582442685845308, 0.011914876668015495, 0.0030175283882272197, 0.023292269579542335, 0.02690517434530193, 0.020481982683122624, 0.018855838789022528, 0.03324837176478468, 0.02985500355862314, 0.022393627077690326, 0.050083995520253666, 0.04479650502617005, 0.019999575561087113, 0.04777303671289701, 0.04009061711258255, 0.034417102215229534, 0.007151586878535454, 0.05481147993123159, 0.10622684756526724, 0.005974716459604679, 0.04304681766370777, 0.0654342255438678, 0.04401009195134975, 0.037918825837550685, 0.020408619529916905, 0.05448001451441087, 0.027977126883342862, 0.16304266056977212, 0.11936329188756645, 0.1371019720681943, 0.13013304211199284, 0.14081131521379575, 0.15062584716361016, 0.2344228545553051, 0.12982321029994637, 0.15161374962190166, 0.17285287322010845, 0.11712196137523279, 0.12745143991196528, 0.19067557936068624, 0.13605419313535094, 0.2784986636834219, 0.13130532373907045, 0.15649822424165905, 0.12836307927500457, 0.14227757637854666, 0.1724676985759288, 0.181263810954988, 0.10957989303278737, 0.2334903459995985, 0.19934969750465825, 0.08095016601146199, 0.0737716312869452, 0.09355627902550623, 0.14425455388845876, 0.14895591099048033, 0.17086989915696904, 0.18858033319702372, 0.09147194985416718, 0.17184288444695994, 0.11354932183166966, 0.11338590833474882, 0.14525064965710044, 0.18356038694037125, 0.14125145331490785, 0.13535071135265753, 0.10248521357425489, 0.27433358249254525, 0.09181059926049784, 0.1641946073505096, 0.12489796208683401, 0.09057114584720694, 0.295978972571902, 0.1029035251121968, 0.1401492304285057, 0.10519489122088999, 0.13294391159433872, 0.1398565570707433, 0.12590565020218492, 0.257496329722926, 0.14516236376948655, 0.13751698104897514, 0.1420476144994609, 0.11650305474177003, 0.2466808632016182, 0.21639285172568634, 0.09206008704495616, 0.1730767494882457, 0.08995777563541196, 0.11852407129481435, 0.13852962671080604, 0.2038036671001464, 0.08989985100924969, 0.1506007180432789, 0.10152057002414949, 0.16371231526136398, 0.19736304238904268, 0.16726711357478052, 0.12532540946267545, 0.14565783640136942, 0.25257639528717846, 0.11860800819704309, 0.12173934446764179, 0.13104563142405823, 0.07486113376216963, 0.2856409444939345, 0.18918335787020624, 0.22183470893651247, 0.09229110277374275, 0.14493946713628247, 0.10239360286504962, 0.1366634073201567, 0.10348018869990483, 0.19501551054418087, 0.1878754116478376, 0.1262025983305648, 0.12253439243067987, 0.1353025162825361, 0.20094489940674976, 0.1042945399240125, 0.16225509345531464, 0.1429981127148494, 0.2322346469736658, 0.1674080325756222, 0.157471684506163, 0.19565402471926063, 0.14462875958997756, 0.06706018204567954, 0.1432749189552851, 0.1226521712669637, 0.1715495579992421, 0.14543177821906283, 0.16077716572908685, 0.16145850182510912, 0.06051322241546586, 0.11671376531012356, 0.12383358873194084, 0.08444497652817518, 0.13009626127313823, 0.18799532786943018, 0.13402841199422255, 0.1287338710972108, 0.16356894717318937, 0.08954370918218046, 0.10473920512595214, 0.1939496083650738, 0.09833614050876349, 0.11046454790630378, 0.15898047073278576, 0.10352182318456471, 0.2168107550824061, 0.0733014139404986, 0.17740808660164475, 0.10087804825161584, 0.19685998500790447, 0.19837142812320963, 0.1307928262394853, 0.14047663629753515, 0.12093774334061891, 0.13656315801199526, 0.24723987851757556, 0.24940113129559904, 0.062073918161331676, 0.10127143104909919, 0.2490919822594151, 0.1426097913645208, 0.13266207359265536, 0.13333116425201297, 0.2383884316077456, 0.10877961292862892, 0.23970598122105002, 0.16779795696493238, 0.1075728956493549, 0.17306833353359252, 0.2081026614177972, 0.14866964978864416, 0.1007886862498708, 0.08459284203127027, 0.13341651123482734, 0.11459450324764475, 0.1759180024964735, 0.11528313465532847, 0.09273589414078742, 0.12239044546731748, 0.09314380076830275, 0.1398938722559251, 0.13259450846817344, 0.15631081711035222, 0.148320973967202, 0.17390075605362654, 0.2734304778277874, 0.10166249092435464, 0.11582592662307434, 0.0996425875928253, 0.2229872197494842, 0.10910115583101287, 0.10839933645911515, 0.16349516285117716, 0.08860362329869531, 0.1277183904312551, 0.051272307537146844, 0.17867846530862153, 0.08047193347010761], [0.02420658438495593, 0.02834645852999529, 0.011812579032266513, 0.045306041356525384, 0.07956870264024474, 0.060716222069459036, 0.07558739205705933, 0.023067057445587125, 0.02324287223018473, 0.019937674878747202, 0.031079220680112485, 0.022621440439252183, 0.011341580575390253, 0.05845783329277765, 0.04500135262787808, 0.1076388725778088, 0.03934833956009243, 0.04644962784368545, 0.055277025458053686, 0.024650397972436622, 0.037275621289154515, 0.061638526094611734, 0.0818188869743608, 0.03230162510590162, 0.09519499304587953, 0.018731258169282228, 0.026197482729912736, 0.026150235753448214, 0.01385733225106378, 0.037381254878710024, 0.036758351780008525, 0.01532805186798214, 0.014419386661757017, 0.02209094771387754, 0.01742194453981938, 0.03619071270804852, 0.029514949637814425, 0.015240908887790283, 0.027979026781395078, 0.008523177366441814, 0.045096633257344365, 0.016906051714613568, 0.04584608737786766, 0.06299065978964791, 0.04650248731195461, 0.038632846117252484, 0.09469284108490683, 0.01969333017768804, 0.06337310333037749, 0.03147687639284413, 0.09514549179584719, 0.057446861173957586, 0.054184784457902424, 0.036797173524973914, 0.03051604377105832, 0.03330571380502079, 0.022409661178244278, 0.03740905573067721, 0.016752935516706202, 0.025718819742905907, 0.01697775616776198, 0.04314967191021424, 0.02862259127141442, 0.06279714478296228, 0.026246124944009352, 0.02349711903661955, 0.030153871994116344, 0.02435635164147243, 0.05227715693763457, 0.00818921183963539, 0.10663354449206963, 0.025103521802520845, 0.04781434094184078, 0.0012993068116884388, 0.03143621783237904, 0.03698239503137302, 0.02779246940917801, 0.01713103563815821, 0.039197832011268474, 0.03675234780530445, 0.015013500924396794, 0.021505589866137598, 0.05582720179518219, 0.02632840314618079, 0.055652741430094466, 0.020708870215457864, 0.028611139932763763, 0.07935631481814198, 0.04001286972197704, 0.003283738151367288, 0.04688273409556132, 0.07213070566649549, 0.00551363958948059, 0.039690818448434584, 0.03547551612427924, 0.02809234159940388, 0.03314754729217384, 0.027438357356004417, 0.025895385952026118, 0.03527765213220846, 0.01900301780551672, 0.07914198999060318, 0.04377824501716532, 0.10975834986311384, 0.04613715398591012, 0.05109295641887002, 0.07334655136219226, 0.049107763334177434, 0.03414663762669079, 0.00872088736286969, 0.05591624096268788, 0.12370317854220048, 0.04322149325162172, 0.02810487276292406, 0.04468773586268071, 0.03692739446705673, 0.016936043757596053, 0.03621200492489152, 0.07740311571978964, 0.049469274599687196, 0.03787346577155404, 0.023065070345182903, 0.03913049695256632, 0.06886343020596541, 0.033040967464330606, 0.0332239773706533, 0.036892802963848226, 0.09717268301756121, 0.026262159044563305, 0.03982774098403752, 0.04824777373869438, 0.03509237867547199, 0.006168071904539829, 0.02235972206108272, 0.03576331728254445, 0.15565683657769114, 0.02594271642010426, 0.010515165740798693, 0.05056594993220642, 0.04979523699148558, 0.04866002193011809, 0.05216965313593391, 0.013959487023385009, 0.07008749147644266, 0.019321130130265374, 0.11396995629183948, 0.044850789417978376, 0.08538915906683542, 0.03393893646716606, 0.022829471854493022, 0.027110799346701242, 0.03476654615951702, 0.038812672210042365, 0.06152590147394221, 0.025119414895016234, 0.04324109337176196, 0.02032576059718849, 0.03258822769566905, 0.010295936244801851, 0.03576276438252535, 0.02663209925231058, 0.024347421749553178, 0.045580060832435265, 0.03461377134954091, 0.03712208948854823, 0.0353151788294781, 0.019159768671670463, 0.03615472225646954, 0.040113493814715184, 0.05531928705750033, 0.052061737442272715, 0.00832223809993593, 0.05704430914192926, 0.017963443315238692, 0.0927553309884388, 0.006875114140711958, 0.05599003270617686, 0.060715691433870234, 0.04351698677055538, 0.028783449924958404, 0.030331814887176733, 0.03237409582652617, 0.010559227976045804, 0.0402555111941183, 0.0006587708639926859, 0.03984777897130698, 0.07533947020419873, 0.022437914740294218, 0.04638322789105587, 0.044941813830519095, 0.03785850407439284, 0.009612551821192028, 0.052291079628048465, 0.06614123994950205, 0.008186349932657322, 0.03205237109796144, 0.025303627080575097, 0.04898656319710426, 0.05706008349079639, 0.009594992607162567, 0.01686569557932671, 0.02944101688626688, 0.06657610880210996, 0.035554569694795646, 0.006270395051615196, 0.03287120118329767, 0.05750346106651705, 0.0033750791362763266, 0.01668809592956677, 0.023755006077408325, 0.07182455490692519, 0.04873475249041803, 0.024805885332170874, 0.04263207585609052, 0.018183300853706896, 0.01725380541756749, 0.024768501498328988, 0.03368057630723342, 0.019851749020745046, 0.01261364024685463, 0.027836747794935945, 0.0390059423079947, 0.031227729996317066, 0.06042968998372089, 0.018272364141012076, 0.043540624174056575, 0.00794547755504027, 0.053822575573576614, 0.02185670364269754, 0.023792070787749253, 0.10406862274976447, 0.05228950256423559, 0.0040315215119335335, 0.007938704529806273, 0.019904064865841065, 0.04555299841740634, 0.006026575883879559, 0.010885554020205745, 0.03960886679124087, 0.023626722140761558, 0.02670073306944687, 0.017012956232065335, 0.05167446252016816, 0.05427299613074865, 0.05729395277739968, 0.02406867850368144, 0.05072212377854157, 0.03801728285907302, 0.014040739206393482, 0.050316217239014804, 0.030730377875443082, 0.012626243769773282, 0.02704428250581259, 0.07659998576855287, 0.0184118786273757, 0.055091232497943565, 0.06272083715884946, 0.06558597990078852, 0.04293010752007831, 0.03693573991768062, 0.017878582439152524, 0.03905175137333572, 0.07828484653146006, 0.031036068503453862, 0.008643835735711036, 0.02900436502386583, 0.04940477083437145, 0.05186610360397026, 0.011509292962728068, 0.011147265904583037, 0.038179464390850626, 0.03318269540613983, 0.0364785212877905, 0.0459952924575191, 0.030355962517205626, 0.030227901224861853, 0.04872895631706342, 0.026445506628078874, 0.043223482207395136, 0.027713953895727172, 0.021009694210079033, 0.044750157903763466, 0.018706550217757467, 0.07098479254636914, 0.008241972973337397, 0.027516379341250286, 0.06152322232082952, 0.03130662029434461, 0.05733504920499399, 0.02915034918260062, 0.031148168054642156, 0.03197874262696132, 0.037996884930180386, 0.017044811065716203, 0.019657349002955016, 0.017980761331273243, 0.10054389626020566, 0.018614753971633036, 0.024949411126726773, 0.09902809673803858, 0.028920882687089033, 0.03884144898620434, 0.031218237927532755, 0.0732012462685816, 0.0322317815880524, 0.03722227571415715, 0.04572606354486197, 0.07012353016762063, 0.04196367910481058, 0.03703042311826721, 0.048470562760485336, 0.07407686178339645, 0.013577703066403046, 0.024406309312325902, 0.027717627526726574, 0.020314355642767623, 0.05348676488210913, 0.03277675175922923, 0.04696304189565126, 0.017411218650522642, 0.034636380878509954, 0.07586158593767323, 0.00815936729850364, 0.08630358148366213, 0.041568251690478064, 0.036021551277372055, 0.027246721838309895, 0.0013874841602046217, 0.05820995596877765, 0.010920769855147228, 0.026218055063509382, 0.009526080484647537, 0.013852279153070413, 0.024016570459934883, 0.028717398781736847, 0.03689662873512134, 0.04074924720043782, 0.05338956951163709, 0.04509834019700065, 0.023195929534267634, 0.053799992019776255, 0.0305973831564188, 0.05322231911122799, 0.05107748263981193, 0.022017577139195055, 0.02877262199035613, 0.05723599846533034, 0.05875557180843316, 0.03788908798014745, 0.014368040247063618, 0.0989446570747532, 0.0499178880272666, 0.16631918319035321, 0.13074044545646757, 0.1247953824349679, 0.11557827194337733, 0.19648770889034495, 0.1404669735347852, 0.16773227689554915, 0.09077942217118107, 0.11539893937879242, 0.1723950423183851, 0.0875381293008104, 0.14955521008232608, 0.13785084360279143, 0.17684708232991397, 0.10543157695792615, 0.16290499217575416, 0.15080713899806142, 0.10569577410933562, 0.20113827340537682, 0.10422456281958148, 0.10216673574177548, 0.243381304317154, 0.17219681467395276, 0.10166158550418913, 0.16541668708669022, 0.0916891690576449, 0.1763432679581456, 0.13295915530761704, 0.10719309415435418, 0.10169126398977824, 0.13463024923112243, 0.09445352814509533, 0.08823032301734202, 0.12844045559177175, 0.14708053349750116, 0.1285454398021102, 0.09919564399751835, 0.17435028974432498, 0.08233788568759337, 0.05618602648610249, 0.1203804869146552, 0.11005845211911947, 0.10708614325267263, 0.17274117999477312, 0.1253049261868, 0.11403810029150918, 0.15957199211698025, 0.1712303899694234, 0.11539507278939709, 0.10590008736471646, 0.28955461573787034, 0.17118802818004042, 0.11831926080049016, 0.13318058248842135, 0.18699207779718563, 0.10783204619656317, 0.11532672098837793, 0.1349120427039452, 0.10127354616997764, 0.13249802927020937, 0.11789649637648836, 0.1583155509433709, 0.1277316006598994, 0.14398368482943624, 0.09054089590790682, 0.14620894042309374, 0.09579634046531282, 0.13946097751613706, 0.17810911929700524, 0.1640529462019913, 0.14481155056273565, 0.17942053877050057, 0.13187369011575356, 0.10325608978746459, 0.1671908059506677, 0.15301176288630813, 0.1657433359650895, 0.15991970314644277, 0.07293593589565717, 0.13567364949267358, 0.15562976303044707, 0.1057325178408064, 0.2154076803708449, 0.1255638466682285, 0.17871484538773075, 0.13802309607854113, 0.18315797962713987, 0.1618615325423889, 0.13900114281568676, 0.12975966761587188, 0.20484225824475288, 0.1397194675519131, 0.13188810262363404, 0.139128346927464, 0.19922084582503885, 0.18822448822902516, 0.08751084795221686, 0.08501448581228033, 0.12227767612785101, 0.12296362838242203, 0.08586149895563722, 0.1973659367649816, 0.13981282972963527, 0.16837450180901214, 0.1269409165252, 0.1869301826809533, 0.10460969293490052, 0.1089340538601391, 0.06884624948725104, 0.13076521834591404, 0.24221111554652452, 0.21709372114855796, 0.12185831074020825, 0.1040801037743222, 0.11118412687210366, 0.11161208632984199, 0.1182086585322395, 0.1065639236185234, 0.15342643047915772, 0.10457180629600771, 0.21043790329713374, 0.07289547400432639, 0.11631523200776428, 0.20521526166703552, 0.1365825577522628, 0.18651723687071353, 0.1067808162770234, 0.18465836474206299, 0.08297276333905756, 0.126160325598903, 0.12619018962141126, 0.12578335910802707, 0.11123361327918246, 0.09457788240979426, 0.1336756840464659, 0.2336034196196124, 0.12446713051758707, 0.18512202892452478, 0.10332044141250663, 0.14775006944546476, 0.13038537232205272, 0.12223043842823245, 0.099087097478332, 0.13686328253243119, 0.08279161993414164, 0.1610121742123738, 0.10164257910219021, 0.20429507276276127, 0.19053933589020744, 0.11634955633780919, 0.2255890707601793, 0.08580500667449087, 0.17857873550383374, 0.09722661488922313, 0.08700737496837974, 0.1511663681594655, 0.1605968238436617, 0.1534894685028121, 0.07161925459513441, 0.17780602618586272, 0.15062598075019196, 0.12544854660518467, 0.16375828388845548, 0.08032733341678977, 0.20803291437914595, 0.07769361458485946, 0.10751452573458664, 0.1272610790329054, 0.16460384242236614, 0.16088428732473403, 0.20640786329749972, 0.14476531476248056, 0.15817884734133258, 0.08874086124706082, 0.1605920444126241, 0.17816323670558631], [0.05705620947992429, 0.005230947190284496, 0.05103300944028888, 0.03556719733751379, 0.035870231076842174, 0.007131631919037318, 0.03737236023880541, 0.06132309106760658, 0.03277116338722408, 0.03299066469480749, 0.03849026470561512, 0.036354289477458224, 0.03356988127052318, 0.03930630802642554, 0.016112935190903954, 0.09681847819592804, 0.011614629693212919, 0.03523715313349385, 0.04342473410360981, 0.006943148673599353, 0.04957850760547444, 0.08605570415966213, 0.0211267791382852, 0.012696090998360887, 0.03850717454042751, 0.025992993214458693, 0.01899313610920217, 0.07524862390710041, 0.027682579602696933, 0.015713409266027156, 0.05679968242475297, 0.04497479116253089, 0.005182207569305319, 0.10802830714965239, 0.08401901344768703, 0.02683765189431142, 0.03550977366103325, 0.02794672665913822, 0.022692933380312752, 0.011313067261653487, 0.032751741382526234, 0.03226716347853653, 0.04472851687751245, 0.027202690216654446, 0.050145000059274025, 0.03513999115966726, 0.0250397471972974, 0.03274801951192785, 0.020940542744938284, 0.014999696977611165, 0.03470737472525798, 0.03429003911151085, 0.07348216400714591, 0.04781120536790695, 0.058989890094380826, 0.046043142428970896, 0.006338788134598872, 0.017873628603410907, 0.07644304379937239, 0.04808482408407144, 0.023019929212750867, 0.05689819510735106, 0.028834426193498075, 0.042366231136838906, 0.05775501202151645, 0.013767752243438736, 0.12411193863954395, 0.02487746733095264, 0.011539819352037739, 0.022491826202895027, 0.0351124500593869, 0.02652742859936552, 0.027975030316156335, 0.048627664291416295, 0.08993057592306286, 0.03438798034039792, 0.06540557122207247, 0.0583233932411531, 0.029102283988322597, 0.05454198384541087, 0.0786317560414318, 0.048813947068993, 0.02056118282780517, 0.030774021724937484, 0.05205467219639104, 0.0452496678190073, 0.015126937269087648, 0.0557084396132268, 0.026695337655837648, 0.020089490462851245, 0.013381392946030246, 0.06993797098402865, 0.027473633490444627, 0.04992625203158241, 0.04344162538473029, 0.00890553370481939, 0.054400133449235, 0.11062010205932893, 0.1000639122503344, 0.011454151390353218, 0.03470045790891163, 0.037408395219244994, 0.044416751770768315, 0.023624937275599223, 0.04102053186215926, 0.02094753934215987, 0.03880052325257566, 0.07430150988511741, 0.04546999291051179, 0.054707505041733384, 0.0651478159124963, 0.02703149901208235, 0.019168090002494864, 0.018190906012023333, 0.11208078969502822, 0.051548312258091755, 0.04314766440074891, 0.025256758599425666, 0.04555365892883856, 0.05173912213649601, 0.011410427759983577, 0.041290710723842494, 0.01548843740238226, 0.009421068443771219, 0.06286905147135258, 0.021629294751619454, 0.034939581601065584, 0.022480879524664488, 0.01261983717995463, 0.015513807720708428, 0.08346289250766858, 0.03959226865845267, 0.06156548763101455, 0.06715908064506948, 0.028259193095436785, 0.027236619353061542, 0.023022302229946945, 0.025036446495505515, 0.10847824160009623, 0.03972648235503584, 0.014508219883282436, 0.04327964052208699, 0.015034494426799938, 0.027647216265904717, 0.02330758194148075, 0.033864157667267136, 0.01291000857236213, 0.08000845482456498, 0.02175083071051631, 0.07530819610110484, 0.015279993167496286, 0.02031723332038382, 0.04091983355465345, 0.03878946525219362, 0.0037184838538451004, 0.047669373525423, 0.04741416749311611, 0.02944252159068128, 0.031719740509288386, 0.05257446871837601, 0.06391032176907174, 0.05010052314901259, 0.059979970756103285, 0.046998668694868684, 0.022794201286160387, 0.03927341604139656, 0.02781600476737367, 0.02938400510174688, 0.024251974136859644, 0.040224626718554646, 0.05057942362327594, 0.026024083636002615, 0.01837249285017606, 0.07911099790362641, 0.017898035985126626, 0.01577177732542623, 0.02122056805092143, 0.04186286576441489, 0.0014583852384930651, 0.033575024353922345, 0.026164698356296867, 0.019973424132331274, 0.03258119213569444, 0.026720424102677498, 0.027894841259694658, 0.15597993799019605, 0.03195514975232072, 0.01644662148464704, 0.06574502956937067, 0.016262249737337697, 0.05199690713197924, 0.016732936492189765, 0.02764298602414783, 0.04453758825547993, 0.037068116798764095, 0.03529821704432834, 0.04862740453972947, 0.034896997167379595, 0.034934097129735164, 0.00866410564412945, 0.013953547058918048, 0.08847229284583591, 0.031128178306971677, 0.09504032947006635, 0.03631877771113068, 0.01434455776688992, 0.03276207578892354, 0.009090183757507475, 0.050815044378396124, 0.0253695798892295, 0.06287864744081162, 0.04255581647157669, 0.02375335850956617, 0.017288313429162372, 0.03371133832843043, 0.019632615076261573, 0.015766164833621588, 0.033582416144781746, 0.014003564101585653, 0.037284642094164155, 0.022041470583644696, 0.023853283128119074, 0.03417921790969558, 0.044314172118902206, 0.030539920517185237, 0.09043443482369184, 0.027591542202571873, 0.014313012779894052, 0.06687273038551211, 0.01820612003939459, 0.04224214033456519, 0.03303837736893911, 0.05509991191502195, 0.03995351646153722, 0.06891018550959416, 0.01827329739171546, 0.02661519498360576, 0.05292649904731661, 0.026927327453449834, 0.06956455938052386, 0.019743772099900525, 0.02217779754573712, 0.05663380870828405, 0.056772820389596745, 0.036522927694022655, 0.044118909354438074, 0.03920846698747482, 0.027651930759020615, 0.11324806924676523, 0.029189937195042148, 0.028248023772903252, 0.08307751748361625, 0.029995590448379517, 0.04057903934153728, 0.07283663653652184, 0.011426344972278457, 0.038166072336025536, 0.03467702459602151, 0.012509404677985003, 0.05303196936438326, 0.0837398249132093, 0.017350444177282043, 0.007667818308618735, 0.018636144523043185, 0.0517151544772787, 0.04427785883308388, 0.029336778534343466, 0.04047277121571824, 0.021780243878311012, 0.04860237560933456, 0.012069239674019627, 0.024985405289044138, 0.05623510842269752, 0.06305251037701964, 0.05211094925471116, 0.01546195664559491, 0.042289218472433276, 0.05028263505664654, 0.018303057513548993, 0.016247638704953715, 0.027012672580895014, 0.03288565079856198, 0.05661724768287968, 0.05394918225647416, 0.026562547027424444, 0.06026302959071472, 0.046191408691811375, 0.02132936133421026, 0.017274730271310546, 0.09596945383236744, 0.025438495722482912, 0.012205439543322427, 0.01100192926969612, 0.04885565947915893, 0.04698926197306719, 0.016543241690669674, 0.054239157907431945, 0.03841954545350745, 0.035046996345045045, 0.08655899902805686, 0.03276575684139971, 0.035669717617565766, 0.011674520083033713, 0.07527065085014328, 0.06025565635354724, 0.019394504415686242, 0.06808564459788613, 0.0468915693636518, 0.011364961010258412, 0.04735753049317282, 0.0743675758712925, 0.06374368735123426, 0.028174063190817833, 0.03548358326952439, 0.04969717701897025, 0.0414895654830616, 0.05361324168916326, 0.09680719012976624, 0.035446869223960675, 0.012324671133683296, 0.03422820336709265, 0.057910332398023456, 0.048427640649606474, 0.02049752882157918, 0.022008806809026282, 0.07519613922340795, 0.0331539520266233, 0.015605907319695689, 0.06847317185020074, 0.023728051273792516, 0.06527344667119905, 0.027204877696931362, 0.05129572600708343, 0.059122456223121844, 0.04048149145091884, 0.052118370731477626, 0.07391243154415861, 0.01716192753519863, 0.0279863035393646, 0.0752215355169028, 0.020876838643744122, 0.06110804635682143, 0.008168861222657142, 0.07077325077261776, 0.06095599143009167, 0.028758190928783733, 0.04454967784113251, 0.04387688386486843, 0.04929268798150588, 0.06211876985616982, 0.04789603284734767, 0.04722576959466096, 0.12825855519622564, 0.16659631597576663, 0.17753353924490511, 0.11987803809461184, 0.15361515863332897, 0.14562809112248942, 0.13705796271096915, 0.12389363590045832, 0.1319443722604774, 0.25935303478036076, 0.14427229121793061, 0.10154487536055967, 0.07565885345684364, 0.1107601156400051, 0.2222624234855175, 0.2067142812302336, 0.09848051049630158, 0.13449446589220315, 0.08079633364104666, 0.146377170458436, 0.1312302183941938, 0.13866137276636437, 0.19944573141401634, 0.0932560209184885, 0.13662906072568148, 0.1387901947600767, 0.17486667609773576, 0.225669608626049, 0.09012495924253017, 0.09558522171573713, 0.1289665640797466, 0.1362316554877907, 0.09402938332641497, 0.1668457518098876, 0.158790391869843, 0.12281003349926323, 0.09585616498952731, 0.2002426644321531, 0.1646438441821374, 0.10162240010686219, 0.09224658875609748, 0.21102871221955866, 0.1455594424623996, 0.07003068749327213, 0.10947731338092126, 0.1381519774440676, 0.13980521529447287, 0.16188137757126242, 0.1724814876797609, 0.13457855122396722, 0.13930971297668293, 0.17476716893725097, 0.1459770489600487, 0.11264655855484307, 0.1586725833476521, 0.12952259596204385, 0.08013502068934031, 0.2061402893741615, 0.16839793883264065, 0.1895741283078678, 0.0958854501368478, 0.14365909912157804, 0.13160193047951907, 0.18534357484895736, 0.18377419968601316, 0.15904802101431414, 0.22870997985592112, 0.11180077737662941, 0.10851224680664018, 0.12250410538399592, 0.11894745170138776, 0.17325940687442198, 0.28352151915896684, 0.10292167804436758, 0.2090675721410662, 0.13820918218698353, 0.11292337963823229, 0.11926388120627962, 0.145722996967379, 0.0970750831766054, 0.1425332759390585, 0.08462868034257554, 0.11268394053331576, 0.10966423811623827, 0.2633104333654046, 0.07903197401901707, 0.15118229464860633, 0.14110511663602665, 0.20903402706608176, 0.1561724956263788, 0.10139153280761093, 0.2322276114136912, 0.06024226800946053, 0.14622256625443697, 0.2364676198340021, 0.23141114506870508, 0.15427146950969473, 0.26280743535608053, 0.12652666453504935, 0.10723714061896317, 0.08878374996129423, 0.09650470557971857, 0.10618025553412735, 0.1775776970316656, 0.16686519607901573, 0.1427440161933191, 0.10299609319190495, 0.18537361698690802, 0.1378556527197361, 0.1428906645742245, 0.20579639298375696, 0.12850098515627906, 0.08285583055112511, 0.1727273315191269, 0.1349363851477392, 0.15422437281813473, 0.14071099169086665, 0.17679443437373266, 0.11230462885578163, 0.2086967061040923, 0.13519854139303789, 0.12466089043300599, 0.13394189241807908, 0.17243298090761527, 0.14453798008617014, 0.16152464202605188, 0.07758856358123012, 0.20520089368801564, 0.13374133442994207, 0.19686142477439716, 0.12930278666317463, 0.1352063042577356, 0.20771157927811146, 0.18948026146972552, 0.17028536880388856, 0.10615315972245298, 0.14659194799605757, 0.11588579567614943, 0.14224639133317396, 0.22510709037305787, 0.20467049558646977, 0.16176460805581883, 0.06495597073808312, 0.08907171068130992, 0.0717619621718768, 0.1527599521796219, 0.2288144445628859, 0.17677610332611948, 0.08194353809813038, 0.24273450777400285, 0.15637780335964635, 0.10048637981526554, 0.1677365368232131, 0.17409132473403588, 0.13742388604441658, 0.19912224408471957, 0.11944612298975699, 0.21322788874385878, 0.20649295795010403, 0.138263032422401, 0.19232531427405775, 0.16423674649558961, 0.1402959381812252, 0.14002545503899455, 0.07037023489829153, 0.13244245725218207, 0.08513628708897159, 0.07292960537597537, 0.0922708644066006, 0.11069291416788474, 0.120533859153511, 0.15999955823644996, 0.16267013212200254, 0.2092319430084899, 0.11799998144851997, 0.08224844204960391], [0.0056475225665053586, 0.03373464547621552, 0.04745970196381677, 0.08426286090980284, 0.0925122108310461, 0.005132527739988291, 0.01164993644124479, 0.02586919927125564, 0.018659555571503006, 0.0200610383762978, 0.023383178959193174, 0.055274776750593446, 0.019851836223097052, 0.04390013906231616, 0.06605052723898552, 0.05502931511728093, 0.02190506198530784, 0.022756926919100806, 0.04667409411922563, 0.03583031466405373, 0.020754386132466607, 0.03941949667932931, 0.059421445257612504, 0.049837795450002886, 0.062199140738812275, 0.018426369060762227, 0.021869550218980294, 0.037892501859460026, 0.015023232335806824, 0.03552500253135804, 0.03289952153863851, 0.007383312749880133, 0.009460151795792626, 0.07324567864998244, 0.03331850472022779, 0.045362203381955624, 0.026265697233611718, 0.035830515043926425, 0.05292114074109122, 0.016963412308541592, 0.09732267848448828, 0.03606249185395427, 0.03540995850926265, 0.053419515170389786, 0.017427733291697223, 0.05500127677805722, 0.08735455907299183, 0.031489752655033953, 0.05415401130449027, 0.027721646256395616, 0.039429768003174104, 0.027291844417050015, 0.02107907388563035, 0.00756773876673833, 0.02616823654534528, 0.04511417020694353, 0.011837325946544297, 0.022797219971835148, 0.08720286408788525, 0.06984072737395763, 0.15660884877434, 0.034901116086984985, 0.01072127221050323, 0.03147325842292048, 0.01683400772890309, 0.09413879073690623, 0.02603806569823064, 0.03138310232316144, 0.005514236554517993, 0.03282631980255246, 0.03571145971363876, 0.048135561009985395, 0.022811420967627782, 0.009901309422275517, 0.05473438934131991, 0.07843313505873084, 0.05268611370411236, 0.03430623277381528, 0.008586084586568177, 0.05042860808316618, 0.05760673462646082, 0.03692016223794781, 0.07465938833774999, 0.061779942334396765, 0.038703951286152005, 0.03328822880575899, 0.0538380048237741, 0.04647157315048389, 0.024357748734473716, 0.10895544255618006, 0.03165717746014707, 0.038670832946081646, 0.023462119352188893, 0.04031651944387704, 0.03780532177188434, 0.01674487579293782, 0.057846515119308606, 0.03807981622230727, 0.06396783821401186, 0.03178277853294276, 0.007512394495279295, 0.09169386685243808, 0.06443470847443677, 0.04640812323486898, 0.03023946388566401, 0.10948512077447958, 0.10698238358600065, 0.056851335903047584, 0.016367528951377608, 0.07122745999367908, 0.01633255338674644, 0.026773151839734055, 0.013150747363397386, 0.006697702810924966, 0.07397569221211597, 0.018386372867098544, 0.06701684062136337, 0.046708700465387665, 0.043713941631722264, 0.020862656201643404, 0.04576255494612269, 0.048596438427921385, 0.04602482251357287, 0.09212031975039281, 0.04871069577347953, 0.026274792253389023, 0.08687085690326057, 0.015363643415184924, 0.02823063339747023, 0.00988680785667384, 0.047811312979320064, 0.022845118182885926, 0.1310484070563689, 0.040099816033034585, 0.010961247517116135, 0.02865509919502074, 0.019101931247860193, 0.02699513192055747, 0.02769130911474349, 0.0020795325781364227, 0.015133439410419669, 0.051712048589251935, 0.013289539183460874, 0.00715988501724496, 0.03637829053332098, 0.07123376824893057, 0.044823211210314184, 0.01903892662085127, 0.0371186644770205, 0.03789603819313925, 0.04344311710156035, 0.05341863943613134, 0.049096137590822764, 0.02025009864155436, 0.06725033512338996, 0.01098380973417079, 0.049170949787367135, 0.041365934812347405, 0.05415084233391099, 0.024949928774731234, 0.030875903757987544, 0.014151336836221162, 0.021941367849649396, 0.03551223759131972, 0.05367711833969224, 0.11628308217041194, 0.041840779449557886, 0.09851047841948457, 0.007873928025219357, 0.03767240312299691, 0.04624042383511551, 0.052391584977158345, 0.05309027619659901, 0.04349046612333041, 0.0239948997477768, 0.07766810696921311, 0.022168429786688648, 0.03337165733682923, 0.021440316122607328, 0.028484551803558134, 0.07598658587085083, 0.03080773378314916, 0.04003327507234644, 0.07669110666029155, 0.015410658470500493, 0.030269522721937392, 0.017531947523821145, 0.05914113608014304, 0.028376426453178283, 0.052361631896928884, 0.05873745227290783, 0.02867256564059062, 0.04073086420248728, 0.023992187198018655, 0.04451025124581065, 0.03010858614288736, 0.007142468202800956, 0.028439405105018523, 0.021058720485598315, 0.038353768904926255, 0.037093479695613496, 0.06214292305230629, 0.02761078238108894, 0.022119553796073887, 0.02435201564367162, 0.056556250565336086, 0.057747594255488366, 0.009120737049670424, 0.04598686908138916, 0.04725238301034551, 0.05058222894149367, 0.04818042754777707, 0.04766677229781635, 0.017142199394584168, 0.009539691473037237, 0.06485467500169761, 0.1285033006570302, 0.029333956517803017, 0.038203183430596255, 0.0626424144138582, 0.0594408116012346, 0.07545432497863658, 0.009947984017344425, 0.04039569175802171, 0.03265160339651629, 0.03025999540113844, 0.03527679124090355, 0.02783387197268894, 0.03163943641993683, 0.07391439823550172, 0.024942410818766803, 0.02488369766069809, 0.05441876135591883, 0.013094528749206802, 0.05403341230703518, 0.05064701472292654, 0.04795235443452839, 0.061982133047422394, 0.04005688278994057, 0.05178556573810056, 0.044636249367613345, 0.013680728934559738, 0.010326958017685683, 0.030496185754600447, 0.0045531386149377795, 0.007067766400723485, 0.03050022860406898, 0.06519253031001426, 0.016972351477306802, 0.010860013007913949, 0.02387930653640069, 0.10058530810056254, 0.009740536115714349, 0.06952506970264949, 0.01958398956048768, 0.021930430448264815, 0.07607983672642149, 0.031911259138723835, 0.03162802218867, 0.0715301968739368, 0.026653092754713725, 0.04888682597083971, 0.07191416181740351, 0.057357899931957945, 0.0307739734853385, 0.04637488615117036, 0.01818276465201052, 0.05002430087188259, 0.018214510018879082, 0.031217139548971318, 0.024133351107593626, 0.024054134264588356, 0.01152564804215217, 0.05531697897822596, 0.06653339820331894, 0.027963406428170856, 0.038672335795126855, 0.07674388820305467, 0.10367749608121812, 0.0291706710413564, 0.02925832424807595, 0.05040835116233211, 0.04558158223517239, 0.027286332115181722, 0.04590177442878485, 0.04345436434959993, 0.034614498654264025, 0.04780055925948545, 0.08609727927250788, 0.04141527650062926, 0.020572426365106367, 0.003048890157515416, 0.05726152092393022, 0.06232084924704395, 0.00988011739536887, 0.03556085939635523, 0.05278254466247745, 0.04227748511766549, 0.005295136470522266, 0.08131702445098199, 0.11256481098826043, 0.022563697639270686, 0.036357458448037505, 0.03799937112489715, 0.05890686603379436, 0.027790280073531903, 0.030167590593919158, 0.02508580859284848, 0.02789743692119373, 0.011302829334454145, 0.04304366353608202, 0.0454281617567176, 0.014292035048129037, 0.0232324765966041, 0.06317585532087833, 0.023495423229178414, 0.004993343509340775, 0.11107537997304462, 0.01935904088895768, 0.01978971475182334, 0.044921616281499155, 0.0701665376254823, 0.021834042163391132, 0.0561459876189474, 0.0122569464474509, 0.055350742986775, 0.0308241909078788, 0.0415012283338001, 0.07532546587754041, 0.0078106608634698205, 0.00764161724873702, 0.0302533865760779, 0.08331942794029601, 0.05035529502492864, 0.032921745150815696, 0.03249519948440138, 0.0851330067962408, 0.050805062492145225, 0.07585455779917538, 0.03229525747883599, 0.008517154838045826, 0.10015291802119464, 0.007469759038940538, 0.03755552970687859, 0.10063474255730398, 0.01142268154580961, 0.055707330102450214, 0.033122811510111205, 0.05357429377909284, 0.02846877003321424, 0.07731751640676521, 0.06710543821100146, 0.18919045280199498, 0.16227119805989787, 0.1628026648540981, 0.13216262304922566, 0.24751834716880694, 0.12968500755960122, 0.08884662471245974, 0.09716365108033642, 0.15432395419338718, 0.07686465047299862, 0.11102506978204474, 0.1870265876641497, 0.11129141174023971, 0.11970665393164381, 0.1553876299294643, 0.1284680189564824, 0.10744599581812508, 0.18112936348188668, 0.1410966709954664, 0.11891583621036261, 0.09809440816752613, 0.16405495000071824, 0.10812503125634976, 0.19440788455540314, 0.22024234203854576, 0.1015623306739144, 0.12088973380741663, 0.14966224262025207, 0.10863780335057527, 0.15231929457513615, 0.2763814647914842, 0.1177299658593256, 0.12433416733983904, 0.1476027531316504, 0.13375849288422614, 0.13111451757140458, 0.10828077836777084, 0.1672693993896246, 0.09718580418848433, 0.15154879685724154, 0.253009750158526, 0.14769369590794668, 0.09941985423211008, 0.1867554514319636, 0.13040495017776266, 0.18808576598530635, 0.18769460963085294, 0.17096306837629527, 0.06828216530266218, 0.1395807453081943, 0.11877324737724848, 0.1168423423951026, 0.13342860824195668, 0.12724916014121845, 0.11979696588241495, 0.10869782825466245, 0.09996883571147919, 0.07357819049502723, 0.16230116598308086, 0.13640613440657035, 0.27670548646710813, 0.2088390797143802, 0.1192822122538928, 0.20645699347369373, 0.0893203227315098, 0.13058658340014517, 0.07941285162814893, 0.10901088098762557, 0.05512116331374273, 0.08424973973887973, 0.17131974454969168, 0.14744843094376847, 0.09718860950670205, 0.050192738708574325, 0.15521631255978718, 0.2789031044812873, 0.11375637361197732, 0.14156245772028342, 0.0977212043653708, 0.14872819039737806, 0.22074223787058145, 0.12395499667036347, 0.16937850887188688, 0.1858863074448891, 0.1453012938145548, 0.21802585863042623, 0.13470148056512699, 0.10530492203542963, 0.1549603755120188, 0.15496108797378838, 0.10585719865048304, 0.17128922743722796, 0.15831227065064013, 0.1399731484707445, 0.09556087185046636, 0.22000340017257258, 0.12810208078008145, 0.14586403471184894, 0.16177765501197428, 0.12382610788336024, 0.16315285465680063, 0.16667559219058603, 0.18213059491245076, 0.1856710549327545, 0.11181385401869193, 0.2279351034667343, 0.2689732873113826, 0.19643737643491477, 0.1047123913303949, 0.2938973967684433, 0.06476999595179223, 0.1633126093656756, 0.18108971795300022, 0.15960424585500732, 0.143367939745076, 0.205987956142053, 0.13481477682944387, 0.09555366559652612, 0.10182700279983692, 0.14966038725106046, 0.19506278535118327, 0.10934720005025156, 0.13111053965985775, 0.16444416192825884, 0.29439137026201934, 0.10774873269838281, 0.19823240902042016, 0.157387851504609, 0.15474383166292682, 0.07935086003271863, 0.11555533215869218, 0.061458677737391554, 0.14019733644090593, 0.08889907228876837, 0.11484833259601146, 0.08337759005371481, 0.06961060964385979, 0.09300685225753114, 0.13280055834911764, 0.05911632237257436, 0.09411940583959222, 0.21185239223996177, 0.2044115454191342, 0.13615901407320052, 0.23753343295538798, 0.30302700062748045, 0.12678044935455546, 0.11777318854001351, 0.10499418480321765, 0.19090327026788145, 0.1712547175702639, 0.1769832961144857, 0.15364986145868897, 0.08620420048828237, 0.13976071611978114, 0.09812670643441379, 0.17639778612647206, 0.09900937235215679, 0.21211981773376465, 0.12571678846143186, 0.16742688312660903, 0.14130518480669707, 0.09386919817188755, 0.17004375520627946, 0.1268206737586297, 0.2641493867849931, 0.10046185925602913, 0.10514649577089585, 0.15460344700841233, 0.2230632008286193, 0.14622246235376224, 0.10294528576196171, 0.13306832523085177, 0.0769246531126555, 0.11199493805179372, 0.17044356500264257], [0.022527087494381703, 0.018144787100027315, 0.06858367763925344, 0.03780532177188434, 0.058234554453520104, 0.05966654323856346, 0.03411262499867007, 0.024002020654734224, 0.008495633483107667, 0.010790902360895416, 0.025249220234400127, 0.017095546136260964, 0.022676342669001315, 0.024716389743844047, 0.044787487931898795, 0.029888671087974217, 0.04851817153394222, 0.002129571421392029, 0.046723836567252874, 0.07175930528319441, 0.0336083208094351, 0.0341498659690842, 0.03995626982941758, 0.06372007221216336, 0.027984943553747144, 0.04510047387157101, 0.02569092612247914, 0.028531490788736846, 0.02828226275596535, 0.05500549217686057, 0.03327708916913252, 0.014189144621923333, 0.03129743992758449, 0.035697188213816844, 0.021859280750504695, 0.0654291789396666, 0.0333858731755754, 0.03324244200484827, 0.046027442294871435, 0.04446477243618574, 0.022436037106672302, 0.0407532139797695, 0.04335458630521316, 0.07359871829976328, 0.0953672084142454, 0.03310759006126318, 0.019455100773484446, 0.04063436274009291, 0.030245517955336254, 0.11698623740812764, 0.048435607604915276, 0.04127171174332034, 0.04730018845293671, 0.03803927269473206, 0.06021093453455251, 0.035983234192826785, 0.023937824880704284, 0.04898501581919845, 0.023446736486221198, 0.026849119931284804, 0.0408646919822786, 0.03749914132640697, 0.06068613911338616, 0.015728430335002486, 0.03898703238519374, 0.06297062922385521, 0.027097513047920074, 0.01813225964724552, 0.04607236820447724, 0.0400998345867265, 0.05035405934904702, 0.00964097978794598, 0.04665099848352838, 0.014810787924943725, 0.054337184483301826, 0.038859241976751946, 0.020899095652566757, 0.03658552413980942, 0.028723005707433913, 0.0028504449710453628, 0.02909006452682661, 0.04234100924804807, 0.031040821959322784, 0.010783291636471404, 0.0380335321824532, 0.07532043411629274, 0.00580842574890994, 0.13918059412389994, 0.016505978455825243, 0.021282949273881968, 0.040513080966775306, 0.021153474190214183, 0.09329610431450419, 0.02204858963523293, 0.006911689033586299, 0.0428883023414528, 0.06510531311505474, 0.07204036402981728, 0.050876212189905345, 0.019636312827060465, 0.03641189498011954, 0.005979489396850113, 0.06624286223086528, 0.007680002054257784, 0.04327531380113214, 0.08424520521657541, 0.019361465856491122, 0.03692408819915727, 0.08675379795022309, 0.02185028963140212, 0.08276662440039217, 0.03076018809224479, 0.015219745619106106, 0.004453803539945511, 0.029210682077973615, 0.03406024050491396, 0.018772339753923006, 0.025415539239475038, 0.02848071675543906, 0.04762965749250725, 0.025374301803822163, 0.05256643868051469, 0.050416941521689296, 0.04921785352053121, 0.024826992012094706, 0.055116810617619194, 0.033174405616591685, 0.053252988363965414, 0.050327497883699834, 0.11103146709501743, 0.035617411049315706, 0.03742857421457302, 0.05865909261046909, 0.02568360483564902, 0.08534236665582284, 0.025813786814978812, 0.02177801372454269, 0.02960895191790769, 0.02744018489465816, 0.04680882360844407, 0.028080307674827054, 0.015612638599122874, 0.03941745948395692, 0.01647296030569123, 0.062118283749441616, 0.056592949767946266, 0.13592412433354184, 0.038657644981867634, 0.08982565850601532, 0.0074778354610316455, 0.08006056101294234, 0.055863952948129736, 0.014586018296540715, 0.049751127444324084, 0.04377709097752813, 0.03584799633244984, 0.06050496602256317, 0.010007246364693856, 0.024234659831563476, 0.061849062258261256, 0.02871078067983035, 0.030772335194342304, 0.02083112791297026, 0.027022402136935852, 0.040890002928790636, 0.02742018215940334, 0.09465390801778995, 0.020181581712677144, 0.04569335338601377, 0.06172927220177371, 0.024900512871681713, 0.030863754800520837, 0.009312500587839168, 0.03328079990751576, 0.06930387258762494, 0.006498906959677697, 0.032092999972519465, 0.04597011880832724, 0.021693561029678676, 0.023719331038591918, 0.1140880913590081, 0.04698396303865593, 0.029539334755099844, 0.022817823846708052, 0.07721248766756617, 0.055442127340938896, 0.011934994436160196, 0.042196457434329204, 0.0312394299544394, 0.043284245548420586, 0.034025838249363005, 0.03752051146875601, 0.02491822979209246, 0.023985758343769703, 0.04758393006341066, 0.04438020470843185, 0.025317616564279888, 0.023589861521031708, 0.08264211428468116, 0.028410830564098433, 0.030356559946085326, 0.026566213236947078, 0.031815136171644554, 0.08133411611197516, 0.031199316872516647, 0.02351376726437593, 0.01801884463930037, 0.05803254556667525, 0.04059045357280411, 0.07902195502538234, 0.0322285495349206, 0.05224241329415236, 0.03151849603455048, 0.005079851953269099, 0.04978443874279037, 0.030374865018529817, 0.013821665561408736, 0.031541313364868984, 0.027516229056345765, 0.03630360079114325, 0.027386152833059896, 0.040336676174774766, 0.0734368187841028, 0.04226140277751256, 0.04206219549814705, 0.05226993955147918, 0.041921213414752856, 0.0164827937624068, 0.04528889032371808, 0.03144191752653569, 0.05986483025480993, 0.04287366718926933, 0.043045975326094776, 0.013144387157808524, 0.05294223999953829, 0.029267474928929005, 0.0276149959245231, 0.022496160345326643, 0.03140232765872497, 0.022119216118881013, 0.016353953215002548, 0.063683855405543, 0.03180876112310216, 0.00813076585473027, 0.007011906800471479, 0.005372133828132064, 0.042097169207409024, 0.02163248042052146, 0.04350396578956861, 0.02459449569869321, 0.06284614879405126, 0.038210964848985896, 0.03452226454101037, 0.04774069020641036, 0.02057363421045011, 0.02878697883716086, 0.01504269608631148, 0.056302154043805785, 0.02079823778331047, 0.012059364471497247, 0.03460745938355103, 0.06058221617422532, 0.036531959631247446, 0.055267730058403686, 0.039455097503378056, 0.01656066917348653, 0.0435410397767555, 0.007988155684870435, 0.041338942901347764, 0.054238204247667454, 0.020062890034751035, 0.04353336225904059, 0.03883074350596871, 0.0261049127948354, 0.09590617089997977, 0.040776780879241414, 0.03942700721381698, 0.024816512886900455, 0.03293554538686294, 0.06017951571266167, 0.03992226462287363, 0.09312697628047317, 0.026514932687859982, 0.031039604837133083, 0.04828638397157192, 0.013726986071560532, 0.03993472899310291, 0.08418177385465242, 0.031930206168908626, 0.08581564165069722, 0.068516891769832, 0.01049671966029564, 0.013297519126354018, 0.05546746055188123, 0.012769447657774435, 0.0503280582051957, 0.0436426472151652, 0.025426565698580816, 0.12400920313666575, 0.047520999651169404, 0.03800244732701685, 0.008125395488605136, 0.026608955377014354, 0.03194701210304629, 0.026213010314677376, 0.11134040090837516, 0.06127747496066149, 0.026660369512683246, 0.010088835297210608, 0.021800354224978946, 0.050386160946800373, 0.07865709296311252, 0.07678026086068712, 0.039002732519293204, 0.030466770731436554, 0.020891598105663434, 0.0370364233822329, 0.025567475422576535, 0.022878926720295567, 0.0955321358924266, 0.0672626993036829, 0.05505830340553075, 0.07766680821077898, 0.0337774302897742, 0.05205761481192894, 0.009266229535569437, 0.06466331964475103, 0.037789677298860624, 0.02616567613586085, 0.0749934661143925, 0.016916219137783628, 0.019683843675011303, 0.07326535298489034, 0.04298772044421639, 0.02569529737229459, 0.03921865667507518, 0.06752499655704014, 0.047640303600928746, 0.04480932933802251, 0.013054788596491562, 0.034957278112415224, 0.009150110327027505, 0.05237389217654709, 0.08734111877856776, 0.03960009460570291, 0.06482494456577115, 0.02210690017818706, 0.057888342562364414, 0.06179954987601377, 0.041455860846326686, 0.04535979140200652, 0.03075945336604491, 0.20608869526768103, 0.09780025051441044, 0.1827985723502934, 0.0645872791938018, 0.23987575492355973, 0.1260801439639181, 0.10402597894426435, 0.14740939397597685, 0.1825124744209461, 0.1108084294537548, 0.11177138090715744, 0.14918231056071818, 0.08302670263219625, 0.11619769065873697, 0.11631437853793614, 0.14330481266370043, 0.09516107689705677, 0.10923392605036497, 0.11493117111967877, 0.12062895053531975, 0.10222680517472327, 0.10883073948207311, 0.12283922958886251, 0.11956169764744118, 0.1866099756443873, 0.2087135676993057, 0.11393840759410523, 0.10143092600628734, 0.08420073572779074, 0.34475184918846935, 0.10511993430554867, 0.13332065544091165, 0.1248539230437018, 0.16199180914554745, 0.16054758976679295, 0.19021884683752432, 0.1419065915979445, 0.11991683015367016, 0.15149646060308442, 0.17372847389196977, 0.07259799152961932, 0.24060237687081099, 0.12210070359287784, 0.1346720173023641, 0.14738834666786715, 0.11658430506940931, 0.1942015378153883, 0.12174661009339616, 0.0981115888862405, 0.21888023387873545, 0.13423928583506495, 0.12418087673722766, 0.13774467195617035, 0.17368407861795276, 0.11447405267972499, 0.16031716775614768, 0.16819941432913765, 0.13473216095007956, 0.16587156424066052, 0.1692997373174876, 0.07198307022918016, 0.13654129434144124, 0.11321311409119517, 0.13506243150914088, 0.12085832611774094, 0.12865316995885223, 0.07660065370146185, 0.11831408060970716, 0.20780874125193805, 0.1316117713577114, 0.11665189245832153, 0.09782436289242469, 0.20743358560139313, 0.2123830872005783, 0.14678487670607865, 0.10578390414593741, 0.09139201312791556, 0.16081697453046218, 0.08376200770726427, 0.1226026625954546, 0.1944416225887835, 0.16566581121878698, 0.09690127219073474, 0.16317416913807392, 0.1385151845170185, 0.37397753563709557, 0.1241358951665461, 0.2495242387522012, 0.13056647119810805, 0.1663459895644337, 0.10989030372002162, 0.09254478369257413, 0.24504375964170322, 0.16815046226838604, 0.10527059770538472, 0.12077807768946514, 0.12181716607301496, 0.1537972074584104, 0.15321497776312754, 0.23267655138624832, 0.19291707314550877, 0.07854434588807635, 0.1485670849797316, 0.2780093508772552, 0.16278191440505907, 0.25224501150660217, 0.2428174501983449, 0.1294898078776896, 0.1845846397918649, 0.09286053042160347, 0.12928616255521774, 0.19062407431192696, 0.0966313827666454, 0.1468238394591026, 0.1293443320901133, 0.06699662451865152, 0.06560456327861175, 0.15373808797448874, 0.10836850764462724, 0.271247168420814, 0.23871899902587757, 0.17248607415240258, 0.18475911871064454, 0.14041909016668797, 0.1652615930652246, 0.09535683318972588, 0.1324429173837416, 0.13790472352411598, 0.13377378112636507, 0.2059650089358911, 0.12075862599886023, 0.15791235695360228, 0.13707544771023095, 0.1372820170945488, 0.20174837816739455, 0.27373161166906357, 0.15981648524757475, 0.10832919608219527, 0.21081616112496704, 0.09341826182208024, 0.10512062450288795, 0.1124828185129445, 0.1217610300227534, 0.1820703622070141, 0.20924837415805086, 0.14048122277017683, 0.23715461109532043, 0.11891000292962417, 0.21508646401343867, 0.05896274233236909, 0.3218822419876233, 0.10987819186993875, 0.11833322801976465, 0.19427119579631835, 0.1369433305808343, 0.09649325424106792, 0.12311471480643377, 0.10250376726617105, 0.12478877732064575, 0.11257078527705744, 0.2636195527156815, 0.1125437488371972, 0.09164639166556299, 0.10193875539698638, 0.1629399324883707, 0.08958028964116238, 0.18929089506855235, 0.1960345238330774, 0.18694444675929844, 0.152935084188357, 0.1178430172149092, 0.13500095199560747, 0.08866067961207591, 0.09721899303258397, 0.1635431798058562, 0.09176015548291616], [0.02878336457797559, 0.08648492526845075, 0.07054544112179428, 0.025170456101477612, 0.03794683078012895, 0.029667982344108168, 0.02686639898456633, 0.08117468794807792, 0.03869118634611368, 0.021890254283789545, 0.07095178923918866, 0.0623997395450715, 0.07159350949223153, 0.0288548259777599, 0.07209234405308962, 0.037715577564085834, 0.10981720217387192, 0.02931822855316568, 0.03036974976566853, 0.0769162223150488, 0.04850386663747486, 0.040739450851106085, 0.08356958365766332, 0.050165012071374804, 0.027741598896682262, 0.018977536165039055, 0.05526003398699686, 0.03342744086694438, 0.055124213540693745, 0.026295692987332586, 0.07039264033664949, 0.031964931258698925, 0.039200255123432726, 0.04472083935979754, 0.050496881958679296, 0.04710402397904545, 0.019799633555521723, 0.06193313645781018, 0.11163799470523372, 0.1001355072367005, 0.11695304114255123, 0.051140268333256245, 0.1138190108758863, 0.028813308381359093, 0.027338139589119237, 0.02713332538405666, 0.01368340437693405, 0.06242414878215641, 0.05946057128312532, 0.05907571205170825, 0.03969292243709788, 0.04496777786698658, 0.02286520440975437, 0.03752210337552242, 0.03795709468249697, 0.021363359119277447, 0.0136400147130189, 0.018147323389712255, 0.014127339491096791, 0.05528183828573674, 0.02239017609099392, 0.04013924262835644, 0.0399312557419762, 0.03735786238394212, 0.061387828609440476, 0.051266982627566904, 0.03272517249570228, 0.07876209943788126, 0.017720874202495907, 0.034955073933815584, 0.07077580376062542, 0.056474061420885846, 0.03492985575576313, 0.02720357893849723, 0.02918991678598104, 0.012991878593311412, 0.034862027168856, 0.02107530934154056, 0.03530574613250792, 0.01805495940061519, 0.023068847876857035, 0.042016323350253515, 0.06655333971139044, 0.08470855769701302, 0.04290990997105837, 0.008975398559414316, 0.14764633204322308, 0.005013375466660364, 0.045492728604585864, 0.0075150374686927535, 0.03844107144686859, 0.036757490888703614, 0.06019875960191712, 0.016896168162929825, 0.055686802297714166, 0.06307760981144384, 0.03254231844039168, 0.04246386437444016, 0.014969111216487363, 0.04650174145353958, 0.018705642942222767, 0.006845080351922661, 0.06011933495756239, 0.061569476674776524, 0.026790813099069055, 0.01190076194689027, 0.004805829230463132, 0.04040020030515734, 0.08465426217298955, 0.05238876481598709, 0.007897728701209417, 0.05305552142090164, 0.048285100056091323, 0.037754228615085594, 0.017712343214952853, 0.0508648239338072, 0.011030472269339953, 0.025153759634122252, 0.03420564578846097, 0.02123814025253523, 0.06719864453771152, 0.023256921085703652, 0.053443360375240445, 0.01631889601412695, 0.03540355006407481, 0.03710354692884721, 0.030081852128205355, 0.0031113469867705135, 0.0632213638164103, 0.01406439887432498, 0.054942413335083984, 0.0771010913013015, 0.033309832724626176, 0.05037332550273277, 0.049665049446048215, 0.03168000592268072, 0.050389778916724026, 0.013166276803531218, 0.024962805036921054, 0.04055569879710674, 0.017502612281532492, 0.02101578353176592, 0.06008744858263526, 0.03508006644551642, 0.06917424165294506, 0.008032902551349252, 0.0720534406718798, 0.06271110018133186, 0.04028370909509249, 0.029885901021771133, 0.05359162292734254, 0.04508014644670766, 0.0331311792251654, 0.04295091734093148, 0.018156713413191028, 0.05388703109929338, 0.020778105172212236, 0.02168948107282631, 0.022620423696935177, 0.040154794332920574, 0.025133550952887163, 0.025849849625956267, 0.0657378307369072, 0.09198559026117437, 0.05615243688225746, 0.039741622167639434, 0.0539383506111335, 0.03395846608327702, 0.02156467966415221, 0.0426991845597513, 0.016164033913810272, 0.028062258643331006, 0.004590600374285714, 0.05199479572183918, 0.06376135788741522, 0.012306417083891574, 0.04846510797506198, 0.057767836333368905, 0.006001373940307531, 0.040524302239646204, 0.09650980413425714, 0.01350079615804134, 0.02177507667511236, 0.03126624746073503, 0.016783691971795633, 0.04941747640259564, 0.07674664899241179, 0.0019688324391609058, 0.03914847919077147, 0.022950163620407693, 0.02925558015704155, 0.026736899781099055, 0.01770499409758486, 0.05060412600869313, 0.018745865490927827, 0.029975847464811523, 0.011589276073209476, 0.051730628256336786, 0.012296315526327817, 0.0386657084163744, 0.04641202322090976, 0.04169172651018016, 0.026039175209007226, 0.0751041500188876, 0.0388734615262365, 0.04161501441558357, 0.029577273344330024, 0.03238397010136396, 0.012771227884513792, 0.09265678119845688, 0.0224463288395782, 0.02509082180040423, 0.025247826852137223, 0.07172918893047608, 0.018143757370125968, 0.10347802905016579, 0.03080048114497913, 0.03583125348086469, 0.08944531524321064, 0.05298002273775637, 0.03501285384118091, 0.04225178083288483, 0.012324915114731994, 0.05528237634280231, 0.07991847684024833, 0.016321679067914374, 0.04566267671179958, 0.026344901089032646, 0.06058242768631317, 0.03488894857582636, 0.04970671361661516, 0.08917739993194118, 0.06955964636290446, 0.11042132522561587, 0.021954359144729096, 0.07498220773413777, 0.0267092028298066, 0.020933592531946488, 0.020898104885418434, 0.07821294726454653, 0.05859356839209795, 0.02474394754244713, 0.011729173693311168, 0.010631064160406822, 0.03715399812790565, 0.03672131490020547, 0.0761850287381094, 0.053436532616615295, 0.0092522725208255, 0.05260274083411787, 0.02974516013637185, 0.02525260999391321, 0.02930105896666646, 0.051965284219477326, 0.011409744984121062, 0.020854236536251847, 0.04936271332553588, 0.04351320552814286, 0.04469283070648089, 0.06541398717672564, 0.029608020522573497, 0.018854467671189923, 0.11252992262598127, 0.04071202849445399, 0.04910964838927612, 0.03820939891738817, 0.05667752862791531, 0.019851767574436963, 0.048061405614134856, 0.03697573054523673, 0.019034486722375732, 0.017997966169787105, 0.052830828790320083, 0.025646792455518153, 0.0210741274713655, 0.06512806736282073, 0.03574569127522409, 0.02830504483426921, 0.05171109864022583, 0.07957812791573815, 0.06166452352772467, 0.030359715929080267, 0.03976682550273836, 0.06083955588110257, 0.04385843778436538, 0.09348092135041952, 0.020404526585480198, 0.08117682533338666, 0.0563766471168492, 0.03925932265701704, 0.050429287148290314, 0.020181529762339778, 0.05097095847304445, 0.029213921552582178, 0.03777490113861859, 0.09845597509411164, 0.006111533239163691, 0.02540141431381926, 0.029167440843593795, 0.017521767113066744, 0.052419252242543735, 0.05006059189327061, 0.0059474406771187205, 0.010834339336724952, 0.024844588333508, 0.04034971942019183, 0.02101223977660993, 0.020211395640217233, 0.03626905752753373, 0.009653755860199453, 0.033683997608022764, 0.020096487060072832, 0.07330574066145346, 0.07704325573286042, 0.03400714726012666, 0.017772100945876446, 0.029978947786730714, 0.03201807274308521, 0.06599317406653427, 0.01206925915539614, 0.009552425799483899, 0.04652106326830108, 0.055633794399909675, 0.031768488479428925, 0.04916689395031426, 0.003947361965401797, 0.04215001383272465, 0.013562536350946175, 0.04989709676010534, 0.014810125558142317, 0.022479834951809607, 0.024822904633765575, 0.03349731778143905, 0.04718318145023659, 0.0171878062246833, 0.045882998092565686, 0.041938401554943994, 0.04255458450643346, 0.06983648228924721, 0.04788217323948629, 0.043811734431074, 0.07828054949641228, 0.05005407212593127, 0.053697868788731284, 0.029488026375474874, 0.030704471355420537, 0.05737724401114974, 0.010570530885161133, 0.01470358190999832, 0.06721756930346601, 0.06464491438237019, 0.017571914031577762, 0.14906702534062788, 0.16922095092013478, 0.117201942630345, 0.10713759635109454, 0.25360228086356074, 0.11307795415632427, 0.1291174575453624, 0.22345069097355008, 0.1374908722937107, 0.1677905800170265, 0.2669950481504202, 0.07711393787758425, 0.18759631959255785, 0.13368828571401536, 0.1412557132425718, 0.15767630946356803, 0.22904991317773238, 0.16110773314721882, 0.07482455330318771, 0.14532928762491792, 0.1656438733334653, 0.21950812049908563, 0.14011942577781156, 0.12845577351981774, 0.1371529427706264, 0.19637617893749848, 0.15296471072360873, 0.2616342779947445, 0.08936083657317795, 0.14142352767521515, 0.14502797566819936, 0.12025905671180226, 0.14847143698716536, 0.2383950664079748, 0.17790784884709865, 0.08325720627908595, 0.1473693031584844, 0.2475516399135813, 0.1216820432455279, 0.18751140305539593, 0.19659926852909848, 0.11657536218990572, 0.282096981536597, 0.22180117870448157, 0.1628157711820677, 0.08109036512905732, 0.0639341892383527, 0.143494802468922, 0.14740267011802644, 0.16901208087801933, 0.15135281049879268, 0.10081173735670745, 0.13833185919793323, 0.09959481554687954, 0.13881844090064988, 0.13561927975388244, 0.18070950085530058, 0.23889972682809457, 0.11424838783568703, 0.13778608379652724, 0.16350197576684877, 0.10596767475362867, 0.11931273678783327, 0.19027970294700935, 0.22515454329550266, 0.12245068559423089, 0.09606488660210744, 0.10736648211604916, 0.17379308526869863, 0.14749123802175745, 0.22176947415573522, 0.22451902739703655, 0.18211085378425196, 0.16825010301545262, 0.10458374003064819, 0.10292291000951082, 0.12021816437481903, 0.12955446378327906, 0.14509003405692056, 0.07296235635294579, 0.20862740435404703, 0.1541703741531819, 0.14719512109877542, 0.19101027311990038, 0.16234226612141356, 0.14775113813811913, 0.18818332871887833, 0.11640900978818536, 0.28811499767471105, 0.15731639752630144, 0.2005750872194767, 0.14360296307131648, 0.1521547307493165, 0.10701106759370305, 0.10316538449842483, 0.16020250594010577, 0.17148307641036808, 0.2066126515273936, 0.09144623443717137, 0.1485101177240722, 0.11222374960198067, 0.13033098774030805, 0.15905560576356947, 0.15984750702045858, 0.12573143845656887, 0.16570888546993956, 0.12522829201770946, 0.11229400130105205, 0.16252235567662865, 0.18601662857690826, 0.11752047983463854, 0.1752395459334366, 0.1448248646920547, 0.12440597754903138, 0.13624182291096076, 0.10831413048435934, 0.13272572017740458, 0.08134421674185432, 0.10040831330115907, 0.128269984270446, 0.1496028559631668, 0.0914352061226964, 0.12498115684138611, 0.08341696840943769, 0.1532495321589522, 0.1787369020166807, 0.08104950247798115, 0.1083193626254797, 0.12770219676895067, 0.1583478640532121, 0.12448029621737078, 0.25812923326157033, 0.19117687043035403, 0.09677688824012876, 0.12664992042118683, 0.17346282955259085, 0.11231509313802235, 0.14174410578561947, 0.1962920490768738, 0.11624467602814548, 0.13909831963246688, 0.1362841995432973, 0.12039302178891376, 0.1234110989025794, 0.2523666643537581, 0.14589231053832918, 0.12260143805178814, 0.14288928417954594, 0.10282795221428387, 0.11264460670645349, 0.1483359801932238, 0.13181891961721703, 0.11115684552351013, 0.11755407685996033, 0.12477445387048647, 0.08242546653491445, 0.09928335100994445, 0.1799843632034026, 0.2231764970929362, 0.13029011024627835, 0.09681695679319091, 0.14704143715789542, 0.15414803550811484, 0.17325063468888402, 0.12836177309509367, 0.15547346672974527, 0.08916738093830645, 0.09214357123710215, 0.11732260842109099, 0.15543245564913377, 0.15668457752326503, 0.11498519947053865, 0.10734436611528508, 0.2519677154486999, 0.1250707489089109, 0.10805531390360557], [0.013165915006538853, 0.016608918049314525, 0.05577534051553812, 0.11058319505536929, 0.06905846661538817, 0.02527627337258309, 0.011625229417404626, 0.053658497854485177, 0.005428121448858292, 0.05761519139923621, 0.024197019956773147, 0.062469761178363115, 0.03332775188027881, 0.037230131347314455, 0.014725354667461943, 0.10742025813669898, 0.027062394619861152, 0.014112799890426686, 0.05321698678017128, 0.0472070155228721, 0.026921703829430044, 0.06663240070338361, 0.04356340810772963, 0.08675377568579279, 0.02587908282293938, 0.058236539698555134, 0.00825915554742096, 0.029773215173918288, 0.059745841717813164, 0.0007993430847363925, 0.011672649870888563, 0.02254008435556898, 0.04247838078299537, 0.07164730035583489, 0.037210152731859125, 0.05678338115103543, 0.017209892539540306, 0.010192795343755279, 0.017902062136272434, 0.017390245557180606, 0.056821683392627165, 0.040239555019070394, 0.07155940780648962, 0.042039663894684054, 0.0342238543817075, 0.02485325105226366, 0.006237361594685353, 0.02326260037079919, 0.0024720674718992086, 0.026186613977188244, 0.03930800383386668, 0.037057422450743616, 0.02745415211393265, 0.02007585164392367, 0.04098345045349561, 0.017489337114966474, 0.006887611907586688, 0.040024844274739735, 0.05166944189113565, 0.04230046572047286, 0.034988789702765644, 0.04294079444662202, 0.023205204524856526, 0.043121655835420825, 0.0335197937238263, 0.14257304021157324, 0.016535092909180094, 0.03125779810943641, 0.006506165163955302, 0.039788099165889435, 0.04501889328821562, 0.023604019843332935, 0.012082409084541723, 0.04037695252918638, 0.03312820692372043, 0.007734330974926706, 0.044791870313929394, 0.01593697197677102, 0.011652491284621647, 0.08950247545726597, 0.018525302912166808, 0.04271274359780364, 0.044812160631408915, 0.06453926966059953, 0.07022534540737979, 0.038555339924641885, 0.014787261843594024, 0.02515018804842839, 0.04453483117686119, 0.08893433172488585, 0.04539991932688281, 0.009360877484141383, 0.025614284531911835, 0.014506104762403993, 0.06248205856536515, 0.04152550027356483, 0.068140118237352, 0.07114199426723644, 0.06944831678993069, 0.014596492783311987, 0.0031028929970489116, 0.05583489044511225, 0.022726146344211884, 0.030572747564292513, 0.040452395551255904, 0.03184241752023809, 0.022654972526652273, 0.028195893464726396, 0.0411906283989083, 0.02186953352065757, 0.08530088060069829, 0.0064321851004933706, 0.021420010962174274, 0.03373651939909905, 0.014295794026111253, 0.04724646067188587, 0.045243704662425444, 0.03334675457153935, 0.0234456733596744, 0.024284574828925543, 0.04321856547903735, 0.02285703336383449, 0.07110864215064794, 0.01938804030942265, 0.010554979180597002, 0.0018217590627500613, 0.01663402304984629, 0.018507431996113155, 0.03887310900609009, 0.02881919175706571, 0.006531431117764441, 0.023275144521903712, 0.030016899363545235, 0.0457423240004573, 0.024110533777275123, 0.028011820431856904, 0.026498809529584832, 0.039621449905098416, 0.06595944345463067, 0.0378258681303123, 0.02347545017983066, 0.022326668658934068, 0.017278921550314408, 0.03829600384051446, 0.0456455850508064, 0.1026807249581907, 0.02580816319095902, 0.07442314046784304, 0.035861466312780976, 0.05508758113137446, 0.018120620916306507, 0.056308258208446205, 0.038094392002676614, 0.038143325509736314, 0.07207208342151716, 0.045254013093654066, 0.046827555415802635, 0.05511788302101195, 0.02860095581127098, 0.04665367021516431, 0.006651682697338401, 0.03589638065022882, 0.016674941361998208, 0.04555078310659155, 0.05405296789831482, 0.060962203206145205, 0.032362611091230065, 0.01744434812280815, 0.04820644353458192, 0.025344101959490217, 0.06007864300045185, 0.014747276782145491, 0.03523868195770774, 0.019639242455014028, 0.017423421413695905, 0.04584063259244431, 0.05610594875179231, 0.05781754167401232, 0.03211566145182587, 0.08315217011841014, 0.04770674437168054, 0.03910174244083464, 0.016721381252864376, 0.035693878235179, 0.037550535053014755, 0.039874351568869315, 0.06951931805815548, 0.03639896305685397, 0.014664016161987092, 0.047384244098793715, 0.04986390420526732, 0.04207482314086519, 0.06345930378302, 0.06386560737155378, 0.05320066695276182, 0.05278147968056146, 0.03946268596337177, 0.014945636157790432, 0.019727431863429956, 0.06657806065049954, 0.07165999850258231, 0.04644005042791832, 0.03737011895282194, 0.013401200867519947, 0.019390149864193518, 0.02188122791267233, 0.07986049284227192, 0.010367797476646956, 0.032252157252514735, 0.015109866017155582, 0.021959921541565564, 0.07903884630650282, 0.08552938044886105, 0.012924616821692325, 0.05517063116712961, 0.02554623886680929, 0.02362220431677997, 0.08310352975968271, 0.04521396680502221, 0.058635473760659806, 0.03215272801753599, 0.011710138533089776, 0.03481532752630301, 0.01872414653917076, 0.02647073779371567, 0.08063749919529073, 0.04029309726320207, 0.046089240931905806, 0.021210445156611968, 0.007273856635947595, 0.05827699787914753, 0.02935623393568676, 0.02520084148272872, 0.04747065235278569, 0.04062311178131495, 0.0787815659714397, 0.03218623598513659, 0.08361860251170583, 0.07484194182325155, 0.034447893922333606, 0.05127166929014493, 0.02196641162299784, 0.04012061472167261, 0.021561312169069424, 0.032877208868740126, 0.03876285183650907, 0.03261344216298312, 0.026781872074934654, 0.07072175314533524, 0.031087104143807665, 0.06493780296295881, 0.020926132092426997, 0.03189935137925204, 0.017066177497326862, 0.04783633819897659, 0.05778349193860777, 0.03741208740393631, 0.05980396301310975, 0.058281870078644715, 0.021608477509289514, 0.03588260638935026, 0.030617827469541226, 0.06603617410291918, 0.038783409327152185, 0.019564740105124656, 0.02543622103985399, 0.016393118203268386, 0.06727813597535715, 0.00928771007238538, 0.007846894368412904, 0.02446377566229785, 0.013600361762655666, 0.06370991963194683, 0.024100871014525183, 0.10700646627810784, 0.04177417911705561, 0.0679046793084126, 0.05841494828928262, 0.04504461983742658, 0.03555183116986882, 0.020038239599671215, 0.00612241126873414, 0.018789715286402497, 0.025720489575178362, 0.056755814075586386, 0.050260159114259295, 0.029087663679092657, 0.03838768134301063, 0.02788241399684921, 0.12867527111666277, 0.06416448508389294, 0.0981005011999514, 0.05912344699027017, 0.04260791523847729, 0.0701110101363156, 0.02077076718705939, 0.047031479043653235, 0.07068783699651249, 0.0560108722129371, 0.07703458002652042, 0.03297956216556486, 0.06259352914639749, 0.05280722107272595, 0.0475156450556824, 0.028436874381441157, 0.028285852895351127, 0.03140753382467665, 0.05310722684953362, 0.02484557538991794, 0.056294558162335306, 0.014195672738424037, 0.036568072537193075, 0.028424398878996726, 0.07153286860557273, 0.06059137427655514, 0.03826736436167266, 0.0475906279461924, 0.0050555016241560224, 0.02344209249713458, 0.010719692363636568, 0.02694128725124756, 0.029191252651799005, 0.021181733318371698, 0.02748020149738295, 0.086795335955685, 0.020957725319021847, 0.05895976260944735, 0.021849942677363288, 0.027411730952735525, 0.054397201965912245, 0.01491447708758642, 0.018339676935283933, 0.047811899275984615, 0.05510829076229129, 0.01244919980308623, 0.03219510464987252, 0.03480823630525265, 0.03790006805502344, 0.01832588040997507, 0.04288279560569208, 0.007671480807402986, 0.0430271581717534, 0.043921999022131786, 0.03930889812181704, 0.0845370176830329, 0.03411021672945935, 0.06295422033872455, 0.033373119367752224, 0.0029768816557407263, 0.061667206391575746, 0.05682830334990285, 0.03514381322020199, 0.19204337237169966, 0.2390627915156074, 0.11027651737094857, 0.2215480024460703, 0.11899519406142645, 0.07399795664241537, 0.14559935516444966, 0.14058001746889204, 0.11523662426043302, 0.2642174268839881, 0.20287329592974856, 0.2716102567501366, 0.0996249244781211, 0.21463779121404514, 0.14502049481961876, 0.19175239111064002, 0.12960442516487092, 0.1753231414477341, 0.17438650655094534, 0.11573551819310524, 0.11043330348911695, 0.16831628774525598, 0.08727280408493243, 0.1411749527323991, 0.2077542379265651, 0.18986211129231378, 0.08281866379547864, 0.11302267899736762, 0.12786984792910516, 0.1189138027257286, 0.16729448398109525, 0.09245401161024347, 0.13117314723785967, 0.15990830375812948, 0.0972859570174478, 0.19607773167081177, 0.16412419237894937, 0.0965198157064151, 0.07966238394146785, 0.16012814274290577, 0.14188119530444965, 0.22187913389643654, 0.22850554785691202, 0.1348831137875095, 0.1544276173808612, 0.09390367835294455, 0.13809211581246927, 0.10396517478511669, 0.08869021708960645, 0.18110582255758345, 0.17884411267004907, 0.07086939600412734, 0.11446316537330858, 0.0926699914271012, 0.13696259673452005, 0.13377936207689345, 0.07494565696106292, 0.12870658974861726, 0.19593135046306998, 0.1485231498372741, 0.11661277385428548, 0.12015858475933783, 0.11753039492759854, 0.11575260243262164, 0.09523238986730576, 0.24730207049287856, 0.12756221287418157, 0.14001972565893084, 0.1200875909125898, 0.1629320954089053, 0.08993807161459699, 0.0976516205992084, 0.11355433132848702, 0.12822704360587522, 0.12264451972441748, 0.07076200723531656, 0.12333528851740994, 0.12871153245214373, 0.12334763043327257, 0.21872065728530288, 0.12492708396166563, 0.16215699637541547, 0.13285636785440147, 0.12045323965139687, 0.1916412470745854, 0.19603847205871716, 0.19446666265139356, 0.20323351956903934, 0.15223335387418047, 0.15069758315803483, 0.15315107884816825, 0.10689324422855861, 0.08759077725699171, 0.11953164808801375, 0.10354741985793225, 0.12489934248151258, 0.34719654300715774, 0.1254233135841787, 0.15547742979833856, 0.10855015570996329, 0.13113586173858494, 0.14223568956367671, 0.22553680872078985, 0.18693782680202276, 0.11240415085921995, 0.1093496268731542, 0.1456347110797651, 0.19824091403279454, 0.20205844746669754, 0.09459118911763653, 0.23032409168081358, 0.1571038761176169, 0.12438430683687329, 0.1588243228616193, 0.13295027922140434, 0.1922675603418611, 0.15435040433658287, 0.15878041740506887, 0.13516653998522088, 0.08409310947172344, 0.09631504974095151, 0.14863819757010788, 0.12487657339079306, 0.20949194702552631, 0.09552121890010312, 0.12391328054945916, 0.1731153708533384, 0.14460437261732295, 0.13134841283317655, 0.28082678094506264, 0.12628086522454396, 0.14144629676593468, 0.13482760114129633, 0.16088459902675822, 0.12508431536844, 0.11966421792749316, 0.1318792562233284, 0.14457048615440726, 0.20507876586634666, 0.13201907684560865, 0.09638243674999103, 0.16450734838144854, 0.16732047399273142, 0.12008102290565148, 0.1362704549683258, 0.26195595448371023, 0.11685403122100979, 0.133532865147572, 0.1098080440715421, 0.20404542912729084, 0.10120586230186746, 0.21437658491777256, 0.06370130329742096, 0.24404671392403543, 0.15512553305597976, 0.06556895503308624, 0.12923808622872457, 0.24371348961722106, 0.1532960351323709, 0.18924880045233294, 0.11452172082499601, 0.15161820250796154, 0.09129406447755173, 0.1433502321015112, 0.1485491992207244, 0.1574492864892818, 0.1735688527696766, 0.09156824351521209, 0.12142813226091675, 0.14167428453220055, 0.13228181196609512, 0.1513715719920583, 0.12596079177455977, 0.11061918179620989, 0.10461525904247537, 0.0925483311584685], [0.054201608945732005, 0.054457427249872126, 0.05138018612342421, 0.00873298900842201, 0.052958084852434695, 0.032913262402871624, 0.0380354357912438, 0.004616089900082443, 0.0750953629903961, 0.03624109711381607, 0.025440759272896685, 0.06833335864939727, 0.03914175904355943, 0.026687476456572767, 0.026182611945841927, 0.06316110142506659, 0.06200549214554485, 0.052028789796167985, 0.018652505168574862, 0.04514811604167335, 0.04647020388802048, 0.05541984435694758, 0.07379449685686268, 0.046794229274382815, 0.018618470276123844, 0.043631236694636755, 0.006720970068272436, 0.04301187364035286, 0.05061297240899876, 0.02486265220795758, 0.024786993963061832, 0.006557937385878176, 0.0012845167361774656, 0.05962908333458472, 0.04566197909298353, 0.048579788344795816, 0.06815695014665835, 0.05660049740981776, 0.041526435379637405, 0.025880880675686058, 0.06050666925148107, 0.044334918857202865, 0.06159866534289904, 0.04845361581828911, 0.04400340149004478, 0.0177121335582342, 0.059828227531397715, 0.08389495604205877, 0.08154614770319313, 0.06510413310024887, 0.05254276045889128, 0.06050125528417993, 0.01152966491645202, 0.04770920459122863, 0.049985390069196, 0.05453801335534081, 0.024201942251238506, 0.019588759714679327, 0.008794710647634929, 0.0748549665149767, 0.03700678200402763, 0.10346355717047118, 0.04641360399546102, 0.038186692909221165, 0.01058238112818799, 0.043590451969066635, 0.07407587472698651, 0.09332306653959677, 0.04028756455227267, 0.017670886845735367, 0.011848823669424746, 0.017138614821305964, 0.034598134297993965, 0.04034978992422111, 0.019733595399884507, 0.01483811751313624, 0.04311534015869256, 0.04822796210646629, 0.021291426455718465, 0.04034889192553237, 0.07800372099154629, 0.014861216859571869, 0.037709358366555534, 0.02565735692769522, 0.04499943788687233, 0.05195335048483685, 0.020110201949137263, 0.11901080142706633, 0.016866307851159945, 0.052202040460542776, 0.009686847297416534, 0.045573567040264606, 0.041800889011938125, 0.01737291084282333, 0.06281769485212862, 0.04935155142447911, 0.018837982715922408, 0.01204054731715587, 0.07715362051385455, 0.036202501723892055, 0.03310191634227522, 0.07110363265383057, 0.08155437812092714, 0.061866113101132214, 0.006509915328933857, 0.004724231948785018, 0.06847496042610146, 0.05529844384000171, 0.029251158812257927, 0.025559751520631835, 0.02524485269532306, 0.013911760433984455, 0.016981559674604796, 0.03566402905562427, 0.05928983278863598, 0.06617325620027259, 0.01004308374831453, 0.026793082215590402, 0.07081228031893261, 0.0389173929579556, 0.04199795519525651, 0.020252356625860557, 0.009333717662229901, 0.05956452019745484, 0.028397809583111666, 0.04320103595091496, 0.044513171596918255, 0.03159039159072563, 0.022045110817998648, 0.03323280150652863, 0.044184815778862685, 0.02054131924523972, 0.03798407175054308, 0.09278175144572742, 0.022332336811814457, 0.08210548956412822, 0.013712632935494184, 0.05423476068244781, 0.03419790889893193, 0.04450284090125933, 0.04257993627106771, 0.015752611361676827, 0.07093605570844375, 0.0793060046271421, 0.012270973966224119, 0.04699371856986545, 0.04486897945753299, 0.03914431574230548, 0.05768811111920513, 0.04576590203214437, 0.018436041100358125, 0.013707781145058107, 0.020346073179098312, 0.048181626116274856, 0.060033620611648075, 0.07130060606868938, 0.0028193691605338245, 0.01814128045225516, 0.03824473256827332, 0.04585934213537257, 0.07244720938615501, 0.010271822011418408, 0.08891976336599328, 0.020452673416002654, 0.06883819718495943, 0.05818368023028597, 0.030595702191931196, 0.019362861094123218, 0.07605545717524365, 0.05276133779261727, 0.04041931431856938, 0.05507887944986578, 0.06627007678616792, 0.01794906049326528, 0.032892630697460845, 0.037090047262609005, 0.048875036954996176, 0.0325070367398439, 0.032528481096960604, 0.02811320522596361, 0.0250875971687492, 0.0750693136069458, 0.061756290087942034, 0.004283969537937082, 0.026229588038404472, 0.08417593315243721, 0.0197697825205978, 0.01868270872364519, 0.08531921906978823, 0.03916453555575572, 0.020096114130865317, 0.07232938602101058, 0.06338202394545078, 0.01731664306134917, 0.027055193932028487, 0.0453921082225861, 0.025666579967946745, 0.06841899506980553, 0.037299640898709185, 0.023756822483846918, 0.05373386666178703, 0.047453304650844075, 0.024520475744793657, 0.03114270955848042, 0.049297652949462645, 0.07624940262758173, 0.01863360081188148, 0.02231263650173787, 0.007244752850965597, 0.03287603256467264, 0.030429013968387153, 0.08126261760480702, 0.05519830585399177, 0.037854641195735894, 0.04886539274593815, 0.025647343500168063, 0.06823779229307547, 0.0486405887932051, 0.061668282505706884, 0.022514476549986284, 0.021064885877422057, 0.055311305259238, 0.03151603210426401, 0.011373755460226675, 0.0768963921291288, 0.023739882963127457, 0.004588888332364149, 0.012502959125413327, 0.006854279736216995, 0.1022687365184538, 0.009615115013730247, 0.09247263209545054, 0.017549491894897074, 0.006661947063548723, 0.015317325978685403, 0.019226224285375793, 0.042797916175914, 0.028173365572001785, 0.05200466628593858, 0.03528819805069361, 0.057995861207018606, 0.042333238961873576, 0.012408821403369075, 0.0912780044018291, 0.004854144435739727, 0.03483130225504283, 0.029471502457454335, 0.029454366267600562, 0.03823270606517326, 0.03321386931929737, 0.0637072033714503, 0.016697443279554136, 0.039206529982038774, 0.03176779086061288, 0.04951129129040055, 0.016815988383314107, 0.1075691774894949, 0.025683795938675757, 0.05858399839780759, 0.014285700817708857, 0.06202552642207593, 0.050161720646428876, 0.04161229073361028, 0.05055075445852708, 0.022261021986196283, 0.0316411248059012, 0.04025933696539141, 0.051007884030696005, 0.05587106272287201, 0.040248052609968, 0.0796183077909518, 0.06590611272258684, 0.07445918658049777, 0.018128569317923393, 0.09323618331109174, 0.04909917297482025, 0.018395002189208753, 0.03307668703200761, 0.036520103822113015, 0.054699026004527695, 0.025590762161300518, 0.025564120915078092, 0.020667706994572654, 0.021774783526780084, 0.018361000693403184, 0.05500664621649776, 0.030522988417942543, 0.04755432208185084, 0.035260308141005225, 0.02473160006047692, 0.016095116225187667, 0.04450487809663173, 0.028958446491742507, 0.013684995356015861, 0.011704591906891437, 0.050606897930265404, 0.005168698626221158, 0.023841444017307367, 0.05920486059039831, 0.0313796587579418, 0.019802494534815196, 0.11624549239058979, 0.04091122835234273, 0.022983333910815418, 0.0200653984938981, 0.03849355984129943, 0.06000912231684197, 0.09085518060601316, 0.013755250765825622, 0.018398328866169322, 0.02897798167396104, 0.024847703498380724, 0.03484101325739175, 0.06313281075563282, 0.03330214036395773, 0.05125644413055852, 0.026582989485177677, 0.05991460238874424, 0.026822714316949714, 0.00833018557386822, 0.08155143921612762, 0.059002053894801065, 0.04324087072745897, 0.009567135166435037, 0.08854817002429627, 0.057977270407718606, 0.06610389507841319, 0.027496471229824238, 0.014864383974781958, 0.011604854680626886, 0.02298855863045901, 0.043743653513956815, 0.02147218579921173, 0.05084064476250205, 0.020429520263860468, 0.027890455166925676, 0.034491261321818456, 0.01893108699732693, 0.07554020630777813, 0.02636064946273109, 0.026647550766938366, 0.06459570999140851, 0.012641557059396291, 0.0759777172061149, 0.05496754987689201, 0.05391555925598368, 0.01860005759226624, 0.04055149453051854, 0.036587064096238464, 0.04989755318092648, 0.05825314154208172, 0.047121609168243594, 0.10900734836468473, 0.19784475560300052, 0.11226749178604223, 0.10096725440234877, 0.1389885856769979, 0.2097936300560832, 0.10151588707230985, 0.08714721785509028, 0.1151032825873699, 0.1644543738802895, 0.12858949368819594, 0.21623605076456442, 0.2254323588567786, 0.1190427879919298, 0.08541334565961733, 0.18850027030566707, 0.11127794918138534, 0.10148052373551764, 0.10185545674175955, 0.1681917702080682, 0.13008134410483763, 0.19840357796056196, 0.10354546800954267, 0.1622131175827235, 0.14008380268933252, 0.09469868920859881, 0.14500865014269948, 0.1419358025304973, 0.141932730039116, 0.10244794291793369, 0.10325506562367082, 0.1243616861756891, 0.09320696495706216, 0.21242742310278118, 0.12324686904321425, 0.12266817197087221, 0.10271056671626866, 0.15547340735793114, 0.14242331933928654, 0.08849801568430848, 0.19168332684785128, 0.18810293928254396, 0.180549701617565, 0.2427471094415523, 0.12637087289476767, 0.13335172174265608, 0.14175580203300342, 0.20103820221265778, 0.20360064518172294, 0.09877270887955092, 0.1814125818782486, 0.214017815887928, 0.12331770703895018, 0.2331894644885324, 0.14668329153209925, 0.19499809975968674, 0.16217130498262122, 0.13424039905657992, 0.10673441720427945, 0.10456923104356974, 0.09843592226388864, 0.21644144755555317, 0.18918484216555953, 0.1287290471373126, 0.10491723151062615, 0.11919211552594788, 0.19322375825140625, 0.37167453265283257, 0.12696273566689342, 0.12498737603891641, 0.12861693830927834, 0.15744805452413857, 0.14767364307772368, 0.19667603628477082, 0.13772530190180987, 0.15888169087702408, 0.08902168992790394, 0.10701768755097874, 0.11080195050453767, 0.09807896407437511, 0.21002274588681757, 0.17337944183964282, 0.19084818806732073, 0.12290018959902227, 0.2656118629965931, 0.19466635974822566, 0.14857297763228416, 0.2561552985571325, 0.0932771572843194, 0.11960590738453902, 0.1827626078738831, 0.13076401606667787, 0.12516880145994946, 0.1660905423341319, 0.20745644374983385, 0.1523896650178358, 0.19911750918254256, 0.13806618517264724, 0.19817719323327765, 0.18115332000888884, 0.10044138340163045, 0.1319044892443344, 0.14779680990613997, 0.21875118924072012, 0.10646446098689921, 0.10156603399082087, 0.13854973891284317, 0.1843554645893164, 0.15127697784919292, 0.08534673790563829, 0.09854749674559571, 0.08710309717571363, 0.1821983529953286, 0.07451630968716927, 0.13190689380280674, 0.23783009906765074, 0.15550285577774048, 0.1180996370385401, 0.18120245018508285, 0.21024058107286692, 0.0724649170297198, 0.10954399534966797, 0.18025803758064285, 0.1452261142549105, 0.14688276598462835, 0.24575755727710202, 0.17194944201037288, 0.17454885877668858, 0.06598721462069079, 0.20389302168041468, 0.20802862476557493, 0.14494494418613613, 0.13255904865218326, 0.18229036446427926, 0.07828748115571216, 0.13239221385447308, 0.11126910278107971, 0.1370117417536676, 0.17239921318832785, 0.10184200160438195, 0.21057007979834452, 0.11449277706560679, 0.1443408359773457, 0.16168319445569068, 0.1077005524712149, 0.16824330494273454, 0.13032567396294326, 0.09905196420731954, 0.1443147420650348, 0.12328633645665832, 0.11780436616390944, 0.12370682248729281, 0.14172158902511, 0.18532034562667832, 0.1298954212688841, 0.15103579469723627, 0.20079440670087934, 0.0778336578514427, 0.10809070692630485, 0.1825976581312716, 0.15843554137973115, 0.17951801244635135, 0.22011515276972204, 0.15712432970758528, 0.12982689135242254, 0.0873682888050098, 0.08811297462671064, 0.15759047266328707, 0.1438663512817584, 0.19218387576984242, 0.09349813917651772, 0.1152806261961814, 0.21858525986317545, 0.14698731974931434, 0.1308005297323689, 0.18908466707216576], [0.07006331230513752, 0.012133489253756125, 0.009390783252456458, 0.015902755258139223, 0.039239707693923265, 0.04285837523639202, 0.015171199884207454, 0.021530718986468855, 0.06404739644494839, 0.05135469706146978, 0.03616426627559122, 0.0128244973893743, 0.09447682416066527, 0.06172488981974311, 0.010438541776238708, 0.02082246333884541, 0.003642208234850841, 0.04112855516723357, 0.05542730665183626, 0.06302417517872527, 0.09254519187379628, 0.0605019714566879, 0.0345893843768863, 0.09224092616932467, 0.008831154736981262, 0.06763303841580637, 0.03377145229023881, 0.02669424855412217, 0.042624320412869565, 0.017759291476977523, 0.020613361375581007, 0.03242735976527911, 0.07433958206092939, 0.04846949035709258, 0.06495162917417474, 0.022594476358790416, 0.007261365826707333, 0.12509041582234204, 0.00493261681185686, 0.004390458916532225, 0.03759954277484212, 0.05884163867449388, 0.02489554233761737, 0.017529652432131115, 0.061193831206765026, 0.04929598682792857, 0.04240837399265729, 0.023896741440694313, 0.0330256309825927, 0.022007617517374456, 0.05280992991174571, 0.042647605296224356, 0.01611494826647686, 0.027020428024115972, 0.04289294818590861, 0.015668006526539102, 0.0732903485186398, 0.044504276957013644, 0.012971874930371996, 0.005953349100309424, 0.023674677868257277, 0.031216657152981497, 0.03632405438111164, 0.02260783872770844, 0.03453155622992199, 0.03246207001211587, 0.027174920905963518, 0.06176199720357545, 0.03681787944515236, 0.008297417898575077, 0.1081035312381573, 0.07894448222941719, 0.02048407925030915, 0.027349670708645135, 0.020144227564742323, 0.007338454561249819, 0.04883657515165396, 0.04355255048722029, 0.013490122219081968, 0.05138002656167373, 0.05250882575637661, 0.021189943327044602, 0.06290709396125749, 0.07592766676680185, 0.013050695652054856, 0.06531669903779402, 0.006669336999038933, 0.03775832898099907, 0.04272040256182663, 0.04687104526965413, 0.010594921568554128, 0.07013895941781811, 0.0019425390746619087, 0.032165630254894495, 0.014225936592993094, 0.011649397456494626, 0.02918635818787152, 0.010393422908236971, 0.035465712353470735, 0.048219505333690904, 0.05387809193052817, 0.051471184560796246, 0.025216029534931295, 0.013727625246247044, 0.008500445383106126, 0.024233008552982938, 0.08007420910871588, 0.009238624425051967, 0.04533531166089233, 0.028795086800528225, 0.06321846201899461, 0.05709008109988645, 0.016535014983674046, 0.03368703299202025, 0.03724279238667805, 0.06401887570973486, 0.03015720609255368, 0.016529422900930513, 0.03440304222749546, 0.036213196071912535, 0.05054331813880708, 0.03840585282887332, 0.02554624072217848, 0.028439291927497834, 0.08388763104449026, 0.020640444199671037, 0.017649524124863092, 0.07493281780625694, 0.01458535964047769, 0.039027557359077036, 0.016902261195355095, 0.032747381264925934, 0.017677334253676236, 0.030371627399290446, 0.014629512788815191, 0.07433040911564603, 0.035664277675095946, 0.04386010761663783, 0.038922116727917455, 0.03955864936870057, 0.03575239286874421, 0.033920880014193244, 0.031802593875909224, 0.052586179808713496, 0.028767718249582686, 0.017101076991821174, 0.02964989806059748, 0.04622784072125796, 0.05089673999464139, 0.08964481196017005, 0.0421810764237307, 0.042456201699678786, 0.0394039189995965, 0.09670895204180852, 0.04398212411615532, 0.012374572215776425, 0.05050711988587864, 0.059043792280135676, 0.024225752204074524, 0.04169617939624004, 0.049476284184493124, 0.013205561463109916, 0.02050847549980972, 0.05163632726180367, 0.04801580806088168, 0.026794097102538217, 0.06611576944123954, 0.03884996142005548, 0.04283759139070753, 0.0336435765348142, 0.010044769351225113, 0.03941588613088243, 0.01837594940298004, 0.03440982545726001, 0.07114748616004363, 0.036735812755068764, 0.006793685233787983, 0.03870375090627931, 0.027149452253070194, 0.005464660625875695, 0.032886274202610366, 0.07752243080176413, 0.029751290276180953, 0.03482547268504277, 0.013561000105255516, 0.04212666586681735, 0.017155198111140635, 0.017090955952880904, 0.01641383711103117, 0.02565326027252013, 0.013826307695126161, 0.06925155859789811, 0.031370979340863414, 0.0666264932078775, 0.05900173848203849, 0.02488653266482288, 0.014864576933177887, 0.0031448301388081745, 0.0319534947630018, 0.05551245696551632, 0.040752991335466504, 0.0181627619167557, 0.01655863568885252, 0.03879730975313578, 0.013964708032290218, 0.05614412482827902, 0.029888749013480265, 0.03732741948624607, 0.05384169700846542, 0.016924341944104526, 0.06588976320927031, 0.021130298773641698, 0.02849089345545508, 0.03398371765797492, 0.05358415321097709, 0.025380832703376655, 0.03436902959947474, 0.031930387995089404, 0.009375431927765021, 0.04797791028977372, 0.035539570890250616, 0.028351206419756636, 0.03768518290598877, 0.030309745270642452, 0.0530669950239826, 0.013723448810196714, 0.05977632543363143, 0.02847603380359942, 0.03517556229780894, 0.031395195619552396, 0.0544824858661741, 0.02276435767271323, 0.04754615103593096, 0.043201470107305795, 0.017810150857258122, 0.06877717780298553, 0.015189205314527499, 0.03766307061596308, 0.06614384488784708, 0.02371062193560647, 0.01473903708756552, 0.03418354091991205, 0.02003406872972846, 0.0484799101104727, 0.040592550139990635, 0.047402560303453356, 0.11254928525886498, 0.10233394161332399, 0.022138133463158738, 0.01811455385904992, 0.05273272057820577, 0.005760835992987268, 0.03005211056006374, 0.01842592377215624, 0.03526241212966852, 0.044873899896629155, 0.02711756958888145, 0.051604359250632115, 0.026512272088439204, 0.08604587812442333, 0.03393125152797438, 0.02228430315881269, 0.009470402710576309, 0.037100248082424514, 0.019314690143801272, 0.037845175102120265, 0.007370078865278629, 0.026311662149964832, 0.026598099611874204, 0.04577103398332838, 0.06642646956606768, 0.030128119469736703, 0.02216247590695275, 0.018757433717837557, 0.03410290657484438, 0.05556545002036728, 0.024722367743379436, 0.02320969637366943, 0.02747212321992265, 0.03443470966885798, 0.053706143735325895, 0.030400398609344848, 0.025449904387642164, 0.03129734715912491, 0.04253714403603226, 0.05817042547278106, 0.07932562701171264, 0.06783226795960218, 0.03845979583275039, 0.029467724925780203, 0.030481956928269938, 0.04113108960154932, 0.025569095159880817, 0.014668028397863964, 0.018593302193039563, 0.015841832355363294, 0.0226176740397932, 0.011266776728007244, 0.04469777341000736, 0.03212236304534599, 0.004129818044020794, 0.0666091640596278, 0.051983622688567266, 0.1190936028433498, 0.037012552202213556, 0.041674252643133514, 0.019265470909886062, 0.04136712224863004, 0.030312478229461703, 0.03458238221355714, 0.027058275700255763, 0.042660355393309146, 0.060472831028164364, 0.07256840210175142, 0.033026666278601624, 0.019743577286135405, 0.02249109518743353, 0.07141626978409477, 0.04859313958149869, 0.03151368691760581, 0.05091617313155439, 0.03969703022448812, 0.014189855228323722, 0.025791260777623393, 0.08026987634366378, 0.020890323467028793, 0.052890849983668886, 0.02072905106615508, 0.06861773479613476, 0.057772415384533815, 0.033654148428468034, 0.009939068968378706, 0.0437424401025055, 0.040562025606050156, 0.03357827867148444, 0.027532573003554717, 0.016944584021985065, 0.0034171619245171314, 0.027143477964273188, 0.022153722275106702, 0.024890532840800006, 0.03880535463395063, 0.04405744097311981, 0.022571490189875476, 0.0804206584871281, 0.0351261278410675, 0.020913482185278554, 0.021820896872668527, 0.05169184361875523, 0.01828245734941447, 0.019975171890109777, 0.06683633546344936, 0.11559967548237182, 0.22940652997931466, 0.08756325842114165, 0.10889530632994138, 0.10841538911336102, 0.13086772378301248, 0.10317829044652171, 0.09399747097631916, 0.27055198384914547, 0.1043266749184113, 0.14667543960968032, 0.11891514601302333, 0.12876863329438493, 0.13549976429203525, 0.12616332387551665, 0.1551949090207927, 0.0832601154979784, 0.14829155523329973, 0.24026870727539062, 0.20062536030309275, 0.13286254252307117, 0.11427449659095146, 0.18023235927103087, 0.2192141706473194, 0.1042447640793398, 0.15290435927454382, 0.12506951694376767, 0.10280772869009525, 0.07982892188010737, 0.1951926018227823, 0.08949615235906094, 0.16997700644424185, 0.18115802522515878, 0.10385446119471453, 0.1234504253079649, 0.114685542503139, 0.09925946869770996, 0.2098297281190753, 0.1303659428958781, 0.12073476595105603, 0.08689256472280249, 0.13864844455383718, 0.07438946180627681, 0.14747243199963123, 0.15088274900335819, 0.18241105251945555, 0.13777226500678807, 0.18023621843894944, 0.12775956478435546, 0.12078301297151484, 0.18733273842372, 0.14435928576858714, 0.09159770677797496, 0.12266289530089125, 0.11913068054127507, 0.12738573015667498, 0.1310071733314544, 0.21234039886621758, 0.1534999773139134, 0.1446152970311232, 0.09967016580048949, 0.09712670696899295, 0.17201758601004258, 0.11602138605667278, 0.1425682459375821, 0.15235810889862478, 0.09113575695664622, 0.18278393719810992, 0.1604773974395357, 0.07268223271239549, 0.21274635364534333, 0.23305316164623946, 0.10811878979438916, 0.09201195876812562, 0.2577307296451181, 0.10919176464085467, 0.1411272623226978, 0.10330202130717225, 0.09936955888406374, 0.1403236945043318, 0.18787223525578156, 0.1614093271200545, 0.24018120806431398, 0.3953349724179134, 0.1623558028950356, 0.2035991015145555, 0.10384791545220651, 0.14521792094456032, 0.17379075492499396, 0.16525725892279297, 0.08841508068144321, 0.20247379783540964, 0.11359780633938499, 0.09912990455632098, 0.14356931409565732, 0.18614271946717054, 0.12999350350582972, 0.1140932270209305, 0.12936521612573415, 0.1468956348253414, 0.1463654890540056, 0.10744009574409574, 0.10855135798919946, 0.11834858305519447, 0.16182936786208302, 0.10263275253237225, 0.1274866473977454, 0.10098681741510518, 0.16443709668237716, 0.11240049949265085, 0.16005063283955678, 0.14179556630551815, 0.12479754950618371, 0.1337106985738501, 0.17694305686745793, 0.09572355804266408, 0.18703818001085892, 0.07342133758356795, 0.12510721804574132, 0.2387375824037008, 0.1546951022464782, 0.14899953443091363, 0.233851341472473, 0.19132386019919068, 0.09594844363164157, 0.13375818118220195, 0.15156651934375986, 0.1747633988270536, 0.15941740275593475, 0.16099274478619918, 0.08665268775075674, 0.17341540631605312, 0.14372359175467864, 0.1175927279109601, 0.12298137313337065, 0.13634645089041442, 0.11505179238156416, 0.17467987752752379, 0.12915398605400696, 0.1318992645246908, 0.14046226831851527, 0.17474490450695157, 0.11778590895119123, 0.15084035752806813, 0.08777477793046273, 0.14265711070038378, 0.10442031911225058, 0.08809754537651315, 0.12107282163924538, 0.2128768083639443, 0.14404678222490475, 0.09546558008878492, 0.18602114083478227, 0.21442831261083484, 0.11194330683792941, 0.13238770159659907, 0.15342758822953328, 0.2093662865809165, 0.07943771357531659, 0.0905761108151637, 0.15404438716359437, 0.06908366252901033, 0.145492248411756, 0.08495282818330452, 0.14343911170726642, 0.20012402470456436, 0.08458831493044272, 0.13071276334812865, 0.1846765770460479, 0.10470674358657561, 0.09619321877835318, 0.21390907641034573, 0.09223059547366574, 0.13822466338751838, 0.14226861123461276, 0.1098599647230003], [0.041080118899117224, 0.04330374918936286, 0.030415200744755566, 0.026973561398335733, 0.03129122815153096, 0.020030409941682592, 0.035589420949690975, 0.02106568183080526, 0.07569688110379502, 0.0263648964028107, 0.028143709350842983, 0.06534034386277199, 0.04012656303530093, 0.011691299114318099, 0.03566909421351738, 0.031325500531238504, 0.04363714419014286, 0.041611734122852795, 0.05222365551162511, 0.03723033172718715, 0.027539808943402022, 0.0751521298661828, 0.0498526866431348, 0.03104714134678943, 0.026955950233968906, 0.01422807768904022, 0.012392540538712637, 0.02967246120533673, 0.07288839391549118, 0.04492888932873029, 0.042073828662978485, 0.012380423122522188, 0.046712763723917305, 0.07999476219993085, 0.049086934959632345, 0.07518375277868472, 0.017154530178231653, 0.05521035833226051, 0.013475867417582776, 0.041695886247907765, 0.05997382948407903, 0.08607470314018428, 0.08006030126125552, 0.03497168319881894, 0.01236532227267162, 0.020857160598097835, 0.019296398058941122, 0.06620148749789223, 0.024184258727473207, 0.01986054161534412, 0.023256028653122485, 0.047023894294397905, 0.08705180734978057, 0.004521439632299007, 0.05100228823721409, 0.03730178199475631, 0.04826457596209366, 0.032093333938973956, 0.02977973494125763, 0.0329811911797151, 0.07404555057291873, 0.043398324778536335, 0.08398354621022008, 0.051482235139701515, 0.0594450381322531, 0.040764134682831354, 0.08268349643913098, 0.03091970345849404, 0.023066933135851286, 0.017002191380015574, 0.03039967687072931, 0.052099883832852356, 0.05693523940863088, 0.039334554166998714, 0.04462354751012754, 0.009341200366179692, 0.03224814965506084, 0.051913883071392775, 0.10011301274062134, 0.07685573727940209, 0.03358581889187917, 0.050895526583190076, 0.06694776893709786, 0.04249084886396304, 0.02855437676771544, 0.08096517223748378, 0.03980516114097554, 0.03530538248014636, 0.006939954655535985, 0.06701230609905906, 0.049126194571726955, 0.012772840200341307, 0.04730046304757707, 0.014558928050973918, 0.021460966381710023, 0.011998619684163714, 0.0117150905134622, 0.0328169501881348, 0.046297112785396166, 0.03269815460953396, 0.03253776907513384, 0.09180765293422155, 0.01036657942677266, 0.015204935134534026, 0.06838702334789559, 0.06171207292936742, 0.06969624606426805, 0.050569579034345224, 0.03606479993322864, 0.0151077815098688, 0.08561489812564105, 0.06258960318518803, 0.0067851941366825486, 0.055827929099905305, 0.09597976968507282, 0.030221053057175595, 0.03466324291366618, 0.047279493664973415, 0.06952851326786913, 0.02251202746265335, 0.012578648911585333, 0.043406198965385556, 0.02430140673823189, 0.03992310696048662, 0.018405748487566598, 0.10544720658799633, 0.046681834719493054, 0.042050083648064174, 0.05308555984811392, 0.03205063818313647, 0.011111813510069624, 0.021189900653553195, 0.015827536735741887, 0.014373628619068768, 0.021455654459714424, 0.023903177716420032, 0.03103419643593952, 0.08338482599356212, 0.0810117123182863, 0.03738722916750703, 0.04188371640339028, 0.0777143205050379, 0.010306335589120863, 0.014957337043597363, 0.037840744480490685, 0.07284819919732399, 0.041621029522502795, 0.013011520459258463, 0.032403807708760723, 0.04695977644587401, 0.006313444719125982, 0.06312101060757414, 0.013436908375297207, 0.02012834003835451, 0.03222290921257809, 0.037642479728674516, 0.020306557526055258, 0.01949451252585277, 0.06219239832716994, 0.020124779584875796, 0.041958209476433694, 0.024826878834574018, 0.07235497527290136, 0.015285583394870628, 0.040867979696486145, 0.07071105879731476, 0.06717318887240253, 0.04903989021840971, 0.0635175994830206, 0.006989465182414278, 0.061851459395256825, 0.009967605474230368, 0.07614683039719239, 0.046476961142616346, 0.0080498893839831, 0.010388995997345774, 0.026833284355234355, 0.003033635080100794, 0.020024506156914867, 0.04140922428632621, 0.025917045531969052, 0.022184593763086013, 0.08699026104295626, 0.031921953486744314, 0.016024949873099104, 0.046468675063806586, 0.05785188826848753, 0.04734155205369461, 0.012393240940582473, 0.02952308172098128, 0.0996719543763902, 0.053409689135150984, 0.03683806957269553, 0.05213299475144595, 0.026388726764707826, 0.039089296624297276, 0.029856430337531492, 0.1010990895156283, 0.027523273893166333, 0.0166299931879621, 0.01879622577689588, 0.04423528182087466, 0.052323923373478465, 0.09047465180628933, 0.04720792094303761, 0.017890954040922225, 0.005511942390512559, 0.09250755014363676, 0.07608901709318161, 0.03779554397624452, 0.0052303697066236055, 0.08474921254673973, 0.010529671017138753, 0.019074991287197918, 0.03953041436034255, 0.05575418188527692, 0.036500032438198105, 0.05167827715922613, 0.0499116243008757, 0.0207890685487655, 0.021363826672313735, 0.01290664014959475, 0.015030851409392199, 0.08550629223464057, 0.08825932614854537, 0.0292322637324105, 0.0080596718180459, 0.03650786580692511, 0.04726137784018647, 0.01070528171112528, 0.02177039372327272, 0.055689028740744106, 0.05631226951663848, 0.05189472452912014, 0.06938449951121584, 0.049121040356112644, 0.03495366756396834, 0.055032153832144104, 0.08905237031285651, 0.04224387324939016, 0.013985585574118886, 0.02345493350730976, 0.05496402096468955, 0.06660441431449726, 0.04228498451993801, 0.07544862528447993, 0.032744431227911264, 0.01988738509680843, 0.035875741523341276, 0.039215116630657576, 0.09527167916530743, 0.07043826757580973, 0.02209499798482284, 0.03505644759570714, 0.032129758546943776, 0.06742387151462026, 0.03742197652172763, 0.0367368443403393, 0.052046085547772236, 0.02298040057212347, 0.047389750834554434, 0.022621566604357213, 0.04334786244726274, 0.061513474211096764, 0.03270460387284402, 0.0587223644106416, 0.03933089166821446, 0.028424914671631996, 0.04052463249536231, 0.03874912210449111, 0.039311443688347936, 0.014750107147847302, 0.05625041892926674, 0.037469058370334096, 0.02673442842933582, 0.009749270266183885, 0.036773888641619124, 0.04544119015918113, 0.044943201646674424, 0.044861736096208915, 0.017250202290597372, 0.020970692494302057, 0.0672362268960569, 0.016540950309718028, 0.03093001931119943, 0.030883859581081197, 0.03243030238081701, 0.027327777352184057, 0.04286267969291657, 0.05132796861289535, 0.08307494223117828, 0.025301033274445217, 0.03604254292440601, 0.008337167328136275, 0.029822439973941073, 0.0200381319882581, 0.026826707071450073, 0.017910873284563422, 0.02453448007145198, 0.05006586485251319, 0.015840412997931708, 0.06549927478772588, 0.0990422346512787, 0.029551763873314485, 0.06050639465684071, 0.05338537637726404, 0.02905418168666074, 0.003961355623687268, 0.023333753779297695, 0.011061558052460896, 0.03598386130761355, 0.04976390722731594, 0.03239533238229342, 0.07158884880482219, 0.05029252417443786, 0.030997055655461736, 0.04944879503455013, 0.04219350368657615, 0.015997991358744912, 0.035818143442156725, 0.014037994187674485, 0.03708440694026649, 0.06362815722241066, 0.02482171719748294, 0.04685702981078066, 0.02669400921149645, 0.032150308616110124, 0.0792897590145003, 0.03404094837605953, 0.018260896104038693, 0.011403053595131496, 0.03998078296717722, 0.0384140016103629, 0.034538977706688456, 0.050224298538523726, 0.02186931644246215, 0.036161267998977564, 0.06833732913946733, 0.043061797914560884, 0.05475018966535572, 0.02696333460335154, 0.053365575877251104, 0.02228382076282287, 0.04728609877929557, 0.030598787670896854, 0.003325887732898991, 0.027886228635907173, 0.03179283463396132, 0.03317984184832312, 0.06651874820818193, 0.01939525955094723, 0.017185997239721473, 0.1129813636362087, 0.12137664947658777, 0.1263712884974666, 0.08137871176586486, 0.06234789310838096, 0.17032298084814101, 0.19730340340174735, 0.11115913875983097, 0.15688283485360444, 0.13542350119678304, 0.12336735671851784, 0.1301707877428271, 0.12415655655786395, 0.11106938341981731, 0.22781505365855992, 0.12817647366318852, 0.15109991625649855, 0.1170146393997129, 0.10189497610554099, 0.21752841188572347, 0.15341860824264586, 0.23545351956272498, 0.10884689603699371, 0.08774430534685962, 0.10171343194087967, 0.15578243765048683, 0.14798218355281278, 0.20077576395124197, 0.20051921834237874, 0.09002309205243364, 0.09761768960743211, 0.2155231882352382, 0.18150953605072573, 0.18174932396505028, 0.12001591428997926, 0.19947797030908987, 0.14903959556249902, 0.11470961035229266, 0.06727292609866709, 0.10460788951604627, 0.1991410055779852, 0.2007693369523622, 0.17275661666644737, 0.1249639390152879, 0.16879571514436975, 0.09099321265239269, 0.05184055145946331, 0.13976833055494353, 0.21193043648963794, 0.12732604664051905, 0.11221761946217157, 0.08511310981702991, 0.15073854970978573, 0.08966214852989651, 0.13778384251054376, 0.24799393024295568, 0.11738115645130165, 0.15752467385027558, 0.1133185658545699, 0.2007011484238319, 0.17712445260258391, 0.12105871341191232, 0.22375565429683775, 0.21484427154064178, 0.10127890447620302, 0.17807460943004116, 0.1976145413937047, 0.1370630390010774, 0.16878890222869813, 0.09127574085141532, 0.1585583371343091, 0.12067641830071807, 0.14634292776463553, 0.09349565298180096, 0.1853231806308031, 0.1553157455055043, 0.08622068358818069, 0.08355800615390763, 0.14098373096203431, 0.12356963648926467, 0.16220321733271703, 0.09929665771778673, 0.3397850110195577, 0.15690089872805402, 0.13253559678560123, 0.21428843261674047, 0.11786063580075279, 0.11898988770553842, 0.15915633004624397, 0.15541176457190886, 0.27482194534968585, 0.09092008142033592, 0.15406993188662454, 0.10951545235002413, 0.13305334869073704, 0.09475644314079545, 0.1516654624720104, 0.11773344653192908, 0.10163887578528374, 0.16152048599906266, 0.11611172027187422, 0.189400480594486, 0.15867351845372468, 0.07934916051453911, 0.21641551691573113, 0.10874735919060186, 0.17116270610131323, 0.16504642961081117, 0.08583685965277255, 0.13562720589106902, 0.12431383249349892, 0.16131146752741188, 0.12446549037122168, 0.17768621386494488, 0.18847140076104552, 0.0696660926041659, 0.14094910235144198, 0.09791713135200553, 0.10971559473546222, 0.09166359464870766, 0.07177207022323273, 0.10570955579169095, 0.1425295800436288, 0.10564629512373358, 0.1608603456406854, 0.25526748213451356, 0.20424445829121396, 0.13604206644231454, 0.14385936025064439, 0.10528138853260316, 0.10215014131972566, 0.08311691068229266, 0.10758793156128377, 0.07730216879281215, 0.2323924720985815, 0.10274461645167321, 0.15373253670986742, 0.2746918913908303, 0.23686094325967133, 0.137653699493967, 0.11405594152165577, 0.23557720589451492, 0.12651459721382707, 0.13267075672047213, 0.08175827577360906, 0.11269972601439804, 0.24397005006903782, 0.1290894192061387, 0.2275676216231659, 0.07606880099046975, 0.09133834842941724, 0.1261457646614872, 0.14590111240977421, 0.13888049928937107, 0.12102811466320418, 0.0796715123578906, 0.06615148900891654, 0.154568595753517, 0.1584947350784205, 0.13737848144955933, 0.0935090116399806, 0.09168169563054107, 0.2463705267291516, 0.07517225691117346, 0.1026199950138107, 0.1297353400150314, 0.11967176556936465, 0.15268039394868538, 0.15439154900377616, 0.16811896552098915, 0.14630322286393493, 0.10531118576182052, 0.15480351517908275, 0.15738647110993043, 0.07550339578301646, 0.14694572979351506], [0.014927170595910866, 0.058593494177330285, 0.06813078201957978, 0.0065065840135503095, 0.05902881202928256, 0.02540036046411842, 0.06412830538465641, 0.021326932655938435, 0.015567417685815599, 0.024298415883095004, 0.043786790847661905, 0.05358312162570655, 0.04750471322040539, 0.043206795016885735, 0.05407015974924434, 0.06533393912832253, 0.02449785879434785, 0.022923368378542364, 0.04130258137593046, 0.036021540145156905, 0.019423678240855224, 0.08279236950329505, 0.07343708595726639, 0.050937172200065106, 0.06274107552599162, 0.06472930399468169, 0.058911419109790586, 0.020272392757760826, 0.03148022347886581, 0.03134056241833605, 0.041017474213731475, 0.037447216964210384, 0.05820307997055352, 0.00358042722382379, 0.015304086064134026, 0.051828183568431996, 0.060089333637733944, 0.05811223738419358, 0.032573822609265335, 0.05852696434885729, 0.03514618438202888, 0.029078691113681998, 0.014577108813682571, 0.0691848766291514, 0.08077495978795923, 0.028056774172000587, 0.01659985642618267, 0.019209945276088547, 0.0583686753816437, 0.046605831375927664, 0.055310451789409854, 0.0543107640260132, 0.02921207546023652, 0.027637490420602262, 0.05363231488445308, 0.01977165087737376, 0.021040291103417985, 0.05873171176062897, 0.04819462483283132, 0.03725363145349547, 0.01926445787830744, 0.020444571018742863, 0.07391838356852531, 0.039879709875094704, 0.01856457551184576, 0.048976366088027135, 0.03796911005338188, 0.011386640071577858, 0.02829299421136966, 0.018785429383569863, 0.010523089094931493, 0.020510405083769, 0.008551814989914419, 0.058406554599059746, 0.022352107625920326, 0.014682470591651509, 0.03750136405869853, 0.022462561464635655, 0.012519576739578042, 0.012325120133027667, 0.0580009523400804, 0.020289582753321156, 0.022113768754934426, 0.0856763034244068, 0.09387362137204036, 0.05140064713486936, 0.01703634872683324, 0.025751108732947614, 0.06060292580514215, 0.07969923899509013, 0.033788714645197615, 0.05902568758756388, 0.043605996252154, 0.04324229194025975, 0.04151404522417579, 0.020005063743155915, 0.031246216894942336, 0.030645758197351824, 0.027119810874864925, 0.059232717103441246, 0.041651223800727166, 0.024999713896249887, 0.04694413939432707, 0.03333272055897396, 0.032579756079940125, 0.016091958386823535, 0.018013065164268482, 0.040304600552190095, 0.024934929970186204, 0.02255647097626934, 0.018575956346467137, 0.047929618740454316, 0.08721985184820369, 0.01683577775111189, 0.10030188190285116, 0.026046871280414052, 0.019492646024446003, 0.052469770234893076, 0.03322256357932929, 0.0456127635698067, 0.026910733031400014, 0.03920730923709925, 0.031242565528373234, 0.04903527777059935, 0.044853887884528376, 0.02086058746499475, 0.03345540499140043, 0.07694434971199371, 0.08398838501307182, 0.08602136498666368, 0.0870408012997359, 0.053140389718464576, 0.030084867103141733, 0.08199690593755804, 0.005713692453355179, 0.03860762793920003, 0.0332257696572924, 0.058964000272681005, 0.08032904035644606, 0.0666735676350072, 0.06528872007038444, 0.03739544474228751, 0.050971151431440376, 0.020725128815684002, 0.07580733494251035, 0.006215300327312434, 0.060135101884952746, 0.05401088441431057, 0.043137975662830286, 0.042258634566678666, 0.03694266044476535, 0.009738788357935846, 0.05769466057245154, 0.03313558016088791, 0.06497054651845247, 0.03633161686593667, 0.12005798664176837, 0.0621822271932615, 0.11357576455338858, 0.021867566829314455, 0.008110174967441708, 0.037990584096405655, 0.08614426464191638, 0.05339294257282745, 0.016728687696740963, 0.06201947791851126, 0.02257058848044835, 0.03707575720909517, 0.05517450517800171, 0.027932269622397143, 0.05823288462124765, 0.03161133128742222, 0.052843742159893736, 0.11948466271860525, 0.049518549494678155, 0.052473944815574214, 0.025015362080011982, 0.023439905016857665, 0.11439828682341613, 0.025351497461088, 0.03858668824250344, 0.02095891089993529, 0.09867255605058745, 0.06371308118104935, 0.04315123784181196, 0.015440182960446691, 0.024194932666432578, 0.04111516311240848, 0.00861191410876927, 0.042450553955859505, 0.007948034253786318, 0.027469004344311543, 0.016077705440693535, 0.009549354235787177, 0.04630565490515437, 0.08919601299567148, 0.058997886735596694, 0.044823600837844424, 0.00997768383967923, 0.025420802921871655, 0.01656978089158656, 0.09369488252559677, 0.0632068251434248, 0.027605027025856543, 0.016806414678285364, 0.03315688722068444, 0.047908434135024436, 0.04664841580961365, 0.05878646741621196, 0.017637961464060936, 0.05612988301436417, 0.043944742137682624, 0.09427406199392863, 0.044888267875649035, 0.008657778835186036, 0.025865143434202764, 0.08028628522879444, 0.020810240166611038, 0.09069247214938514, 0.06191482396388892, 0.06413243914721534, 0.05136841195053421, 0.09235825971700251, 0.07314848699024878, 0.07199136744020507, 0.04612264870957006, 0.020534968316496816, 0.04364933767647017, 0.04742370409076102, 0.03325949655845761, 0.028809788746002596, 0.024822399973345455, 0.015632012364221737, 0.08849046062096022, 0.035624179436126724, 0.05425275405286811, 0.022636834437435027, 0.008265814467449673, 0.006766897877241718, 0.04293565507396124, 0.01263426267541945, 0.01600700845301617, 0.03705798648297787, 0.01763868691341486, 0.11041351041058078, 0.04962483617418911, 0.05702410046069417, 0.01399600903823739, 0.04728714149678126, 0.04444491627509706, 0.05180298394407146, 0.05843194347107783, 0.04386883898405358, 0.04391847010992933, 0.035721656822715886, 0.022587201456190087, 0.052588072285288945, 0.044112760660937056, 0.021219957634457387, 0.03463744214968756, 0.07725283081526868, 0.09287365901400335, 0.013289318394527072, 0.011623642149061197, 0.029937660256109666, 0.022946163444430567, 0.056824162165867165, 0.04895132973615546, 0.03396768726815935, 0.02809259207424475, 0.05576381867285818, 0.04116660507861525, 0.06451899418607354, 0.04275861574569717, 0.050709826391539536, 0.031425167253473774, 0.028736253043462057, 0.017988453691941686, 0.025120734062511474, 0.07694739251746796, 0.02103934300976107, 0.0076831079422845505, 0.06021915753080975, 0.020568032850860618, 0.014486628024314996, 0.029894669496570714, 0.03962864131608512, 0.011709720147337066, 0.03451098389632534, 0.05313044865033589, 0.0964279675099533, 0.0066349500502838055, 0.043741163608501665, 0.03659477872133721, 0.043351528656785376, 0.02288452993525425, 0.061225446697790176, 0.012171193138783565, 0.04845384588406887, 0.01592064101714641, 0.04613407036231365, 0.05134858547535259, 0.028748331496899482, 0.05594836111413315, 0.051477552187861875, 0.05993121536448598, 0.04564560360449832, 0.009009103196149226, 0.04054144585097674, 0.042921450367430225, 0.015847430004214402, 0.008705228046892444, 0.020335851950221695, 0.026644131321518216, 0.017311659539700486, 0.05421005829703063, 0.057197239802917466, 0.0978994979232084, 0.07162266847444698, 0.015810432087164372, 0.015694555004301947, 0.04622720618499443, 0.02416068069578614, 0.059628593517118134, 0.07064097779220901, 0.0359212166222278, 0.05020897318900097, 0.04730807748273946, 0.0371645217819605, 0.030444396834354848, 0.04928019392536953, 0.017833274323493242, 0.01083886365449871, 0.01267467539946665, 0.019803043724095915, 0.026359992662037257, 0.04478087539609987, 0.04789178776263725, 0.060284410865278915, 0.0158081462723203, 0.01874282825156115, 0.02788186480756849, 0.016781124140834436, 0.040545097217545845, 0.02295683923875913, 0.11258775077294558, 0.05466318027174566, 0.05590827400737908, 0.010821707055583829, 0.09365597914438695, 0.008307573261845391, 0.055172768552438356, 0.10546432793489657, 0.16769684676546603, 0.15441399154951796, 0.13256318983621895, 0.11661623968393542, 0.08840226379106753, 0.18899605463957414, 0.1639983686618507, 0.07675540633499622, 0.1609816719428636, 0.14002459414768964, 0.1455676951445639, 0.14978974359109998, 0.12627190008061007, 0.22591760469367728, 0.10227036182186566, 0.1178032009920571, 0.08066060225246474, 0.16436064062872902, 0.2130876376759261, 0.16869350656634197, 0.2291954483371228, 0.16832146793603897, 0.15643436985556036, 0.12550425220979378, 0.16112532204715535, 0.18752798263449222, 0.1606684856233187, 0.07809920571162365, 0.1276741732726805, 0.14370909018907696, 0.13970101776067168, 0.19002827815711498, 0.08913291560020298, 0.1494451198959723, 0.21600951760774478, 0.14884577627526596, 0.13474765699356794, 0.10815566711244173, 0.12005217562546022, 0.2183705268544145, 0.13308030349435285, 0.16655027313390747, 0.08427240492892452, 0.2686313650337979, 0.09857457771431655, 0.21823281393153593, 0.16120393032906577, 0.2917884208727628, 0.1229285990120843, 0.15078729396918789, 0.18088418757542968, 0.18784495390718803, 0.09487779912888072, 0.17005050875013694, 0.09993578787543811, 0.0966936415352393, 0.2247765229549259, 0.1371882393141277, 0.19069089728873223, 0.11447849072283134, 0.14450968941673636, 0.15652706410037354, 0.1864339382154867, 0.07241161598358303, 0.062253729411168024, 0.15745494165457785, 0.14830513653578237, 0.19240430847276002, 0.11959588839090429, 0.22769409843022004, 0.1672751287696883, 0.12971874559298158, 0.14227109000785276, 0.1518611965002492, 0.18807580636348575, 0.1631330096279271, 0.22487515438115224, 0.0988182841683738, 0.1503724927897565, 0.12859455513535067, 0.19286148628452793, 0.15349913126556203, 0.23602185625350103, 0.37228181725367904, 0.25095216056797653, 0.12209083302877843, 0.10345022077672184, 0.2447490973281674, 0.1283390782191418, 0.1556077360874042, 0.16657590691465884, 0.09446759184356779, 0.11591900678467937, 0.09952159525710158, 0.15991096064681187, 0.15310668357415125, 0.06950788156245835, 0.10608933502226137, 0.13074571470497176, 0.13440108887152746, 0.15292172553017735, 0.202867403277196, 0.14116353850113228, 0.1488254711148329, 0.13237177510745823, 0.08073997494648211, 0.23713153030257672, 0.0997478241333738, 0.09817087164265104, 0.12561370414914563, 0.08830775128444657, 0.1318383342004381, 0.11743220136850141, 0.192090617492795, 0.15740064613055438, 0.11771429170039482, 0.19212567654903978, 0.09371814143378288, 0.16901194729143754, 0.0967999616113957, 0.17516074469313025, 0.163473907741718, 0.1827746009803377, 0.14583921729354188, 0.18824507540557534, 0.12734514952171594, 0.1156651922792662, 0.20065259712282568, 0.2105506503721699, 0.19338519021403044, 0.08178451069397852, 0.08767506296862848, 0.1597090222639963, 0.05167850722500589, 0.10551900195423514, 0.11564177752006799, 0.1509269661619328, 0.2029617302468978, 0.15169050253462046, 0.14665696013253182, 0.17861832166090608, 0.20268672000383958, 0.12513343070168048, 0.13213413942139596, 0.09842321669566445, 0.09840278537012637, 0.16598437068751082, 0.1141649333294481, 0.132313754002098, 0.12291668012039736, 0.19009640731383115, 0.1255371590377763, 0.0762455583026167, 0.15984596335329115, 0.09586838074028492, 0.1994190289406106, 0.16277887159958482, 0.2226111141499132, 0.1059419741795864, 0.09818662001634948, 0.1873138136579655, 0.18144652771297842, 0.0844253838295117, 0.15489770856220275, 0.10490063708857633, 0.052797012831433676, 0.14877610345138237, 0.1067759700526949, 0.18613620341056958, 0.14142734231427312, 0.12002040428342298, 0.16620662907371297, 0.24889762862585485, 0.16542548895813525, 0.17531953461002558], [0.04078292957274243, 0.014230320830392884, 0.08119710822938941, 0.017461300631111953, 0.020438080937310588, 0.04414920382259879, 0.07874044356867671, 0.03903312717739027, 0.08236654743086547, 0.0049235626102017704, 0.06180100819619838, 0.021686406726075802, 0.06329954165266827, 0.03001920002134284, 0.014252421060518827, 0.07614688976900652, 0.006162724266687292, 0.0500337038829457, 0.03862280856992584, 0.08971335671958514, 0.08449076703982428, 0.013194165785535006, 0.04263259164872579, 0.03024127843673341, 0.05378920861403458, 0.042959674683515914, 0.05466580747452099, 0.03591943175706547, 0.007510313698730897, 0.017353071380057372, 0.017279917883570306, 0.030854708020342514, 0.03392588208953384, 0.011216359853278846, 0.02659121990291169, 0.05103414863697253, 0.04296966399124358, 0.0530031888774829, 0.012904991654067999, 0.030246336173149757, 0.021824299619765952, 0.024313980575243477, 0.06976372955250554, 0.08454593087662943, 0.027077888807980344, 0.07591594083351083, 0.08795294532319531, 0.03936666689696722, 0.04123004386201501, 0.09855392374447547, 0.08716785698197782, 0.050538709401735105, 0.041957155626732856, 0.013892790211684769, 0.04420768134878017, 0.019093008777417708, 0.08009099648916163, 0.02069252441287972, 0.028537741527543403, 0.0020632862697311793, 0.08663650150992908, 0.04270933713996783, 0.06253527055378072, 0.017220887457369827, 0.07820294311386533, 0.03085496777202934, 0.0255098736306536, 0.07659691327717155, 0.032849040653673, 0.02139846641512122, 0.020407233569130767, 0.02686063806322636, 0.06921418404090218, 0.03511917020659894, 0.055183002768899314, 0.018784492422128096, 0.02716390743444208, 0.026400406313769054, 0.013373262718232581, 0.05024208781833295, 0.13535148318624124, 0.05742394736444112, 0.03489335693302564, 0.10477597112185322, 0.07403861891361885, 0.05653300650010351, 0.046047090654610656, 0.07071050960803404, 0.016362604801543057, 0.018305983430764172, 0.11720334528945386, 0.03213102761947084, 0.08442971797194332, 0.06547659475472756, 0.10646234586602077, 0.025601443521736655, 0.05870414839591831, 0.03747108443349134, 0.023935459284984972, 0.04028173127153423, 0.04158215953793842, 0.013043182334513403, 0.013336737920326414, 0.08161481862771325, 0.052163055443088524, 0.08191744418581948, 0.052953379636164755, 0.031410513547598384, 0.05662791976646986, 0.0170876589618274, 0.016257039860647637, 0.016724630004318897, 0.026910720043815672, 0.058214278978994116, 0.023462959834432695, 0.07447187730576843, 0.059435809525894, 0.044228331607882865, 0.013962460252514575, 0.03085007887420943, 0.059341723754187115, 0.011523192461027065, 0.045163400573073886, 0.01377626096655149, 0.02744868805166334, 0.11335271949064918, 0.06938989492482506, 0.1279046101262793, 0.04671613307436928, 0.02425926759315189, 0.030829716197331436, 0.03234999086998869, 0.0696286438324023, 0.05661175579007249, 0.054409721997217275, 0.03750013580429368, 0.07250538634252734, 0.04779259972565342, 0.06656823461526074, 0.049548409806448035, 0.021462918230099604, 0.021080595288367476, 0.07223096981761046, 0.03801480408583302, 0.046529746396117844, 0.053676134994020686, 0.009004818221001187, 0.046608551347162575, 0.00943676857787068, 0.044914617828908376, 0.04198827387881465, 0.030988359540060628, 0.03265306913817767, 0.012110846328141633, 0.029618423577630892, 0.06260331807425246, 0.02968741362565197, 0.03365791111718863, 0.010721437338361284, 0.036686478488263674, 0.05267855121928733, 0.03196690166078042, 0.029521660508180503, 0.028156678381492384, 0.02458179569657659, 0.05924820201471448, 0.025572199192538392, 0.0650635598867666, 0.04274213635653723, 0.004653237638194696, 0.019970047360402532, 0.12246240410604514, 0.007832797273295, 0.073565581406001, 0.04758632720040623, 0.03174047982611228, 0.05028801562730223, 0.04872462588537019, 0.010754859958979068, 0.09608283915440552, 0.024886287756089587, 0.015034131702122977, 0.039228048553923145, 0.03278317875810899, 0.014245361380744725, 0.050605899741640314, 0.030450029735220596, 0.0684785598423332, 0.07935483052278869, 0.03124281414784491, 0.01265626178792445, 0.048996058976626955, 0.08075636156718247, 0.010245027697237674, 0.016024821852624882, 0.052808623731834814, 0.04050197472679429, 0.04330607582232915, 0.09430585560039617, 0.032979087191051804, 0.053261400607880205, 0.0408466540829977, 0.021527483222598676, 0.02611307270854013, 0.10553006737609394, 0.04946887755068019, 0.010005194326367928, 0.03006110910064308, 0.08142946724547073, 0.014771570986340521, 0.057061411935137585, 0.03200211656803731, 0.05657091169268824, 0.03521849925164133, 0.017579443119757343, 0.03589977597584948, 0.02182407883083215, 0.03913225584255997, 0.025748837761057075, 0.038276559571386315, 0.03969461082306225, 0.08553626015782356, 0.05180535139515996, 0.011586753698793473, 0.05639287788653746, 0.010415763408673229, 0.03649938676971942, 0.05816582415718585, 0.04856740190007258, 0.011207429033674998, 0.03452281001955271, 0.04796690423972905, 0.047218901017913595, 0.028122324365540408, 0.04147471881879028, 0.03796404860622715, 0.059827837903867476, 0.009336950643046293, 0.01565581489558099, 0.048134551689145155, 0.09599898388842121, 0.031584554599248804, 0.0229731126819388, 0.042839684247155674, 0.05155013423063792, 0.02911085022788029, 0.031796456314623356, 0.04787694109836593, 0.02219343830802245, 0.06668254762189463, 0.007154372251534369, 0.048322467191610485, 0.021378296696639154, 0.03270588778832462, 0.07276898977579549, 0.04615686913894024, 0.07508452021284029, 0.03750137519091368, 0.03251726353482809, 0.06322725646896288, 0.0372434232122032, 0.013949131280242, 0.02029588729783427, 0.03662899172923062, 0.02732577355345711, 0.051108445040881634, 0.04873491205216851, 0.03411216486711055, 0.07029493659501895, 0.07162781897932291, 0.030610491339757573, 0.051351639413041994, 0.02986587416671682, 0.012646168579522055, 0.022379247966455296, 0.018061412374663632, 0.058257872733520344, 0.06119965335528832, 0.038910572620807216, 0.006946249459360843, 0.0795664761972148, 0.10571921113296412, 0.04351962881628424, 0.024383063391724136, 0.04324877831095364, 0.020469381015573163, 0.016370176563214045, 0.026610658605932258, 0.018960565103043336, 0.07249346002936363, 0.008273867697425885, 0.012561856892716605, 0.04127495863940567, 0.08352474309504032, 0.039028934043017216, 0.0270218826335622, 0.04743465076899156, 0.05253340939816553, 0.04065853077918291, 0.027785140700871125, 0.023567391144752037, 0.056926389297586866, 0.06956999932299368, 0.05110989965032786, 0.040873738762456924, 0.07691168779274449, 0.04079972808540333, 0.04395801544887945, 0.06127135224232916, 0.026824011220014654, 0.013186502183089033, 0.01562330511660548, 0.058881202567135915, 0.04102072482055519, 0.07508948518079706, 0.06129883768153377, 0.025498995601083152, 0.037897229340160266, 0.051086596213281155, 0.05733460020564962, 0.024969224614324048, 0.059083589949295856, 0.07937259011669084, 0.01754501117829932, 0.01734865189064294, 0.031634141196263954, 0.027665680900099687, 0.03226980923500378, 0.04476616973988712, 0.018105265880876686, 0.04630224844731856, 0.025929244584403932, 0.03158768646244425, 0.03998571824922692, 0.02139976146281697, 0.038831734273117036, 0.01691866636974737, 0.07026362538454123, 0.042817846551770344, 0.041030383872566745, 0.05476664679008536, 0.07267850713105872, 0.04357797275588382, 0.0584813927707728, 0.018121791654266417, 0.03981265312177129, 0.01517241793408175, 0.0447848087787861, 0.02776142537186388, 0.09444031049497426, 0.052486283020698465, 0.030566815948986914, 0.15558426937786862, 0.28673451393842697, 0.1659015766927041, 0.20466009067604318, 0.15889690490439534, 0.21034065226558596, 0.1318540974170901, 0.08818170492304489, 0.168265599058941, 0.12465565087040886, 0.12302364586503245, 0.13090431166347116, 0.22009014239301905, 0.10148381144972518, 0.26762566587422043, 0.29815928370226175, 0.18312214873731136, 0.10497293711523525, 0.11057791838538833, 0.15486079413676634, 0.1083923083206173, 0.09936427479260601, 0.13033961149631068, 0.09059343254193664, 0.14617242675740272, 0.14739051373908296, 0.18890117848059162, 0.11828441696707159, 0.19645882450276986, 0.11151807848364115, 0.08723918479518034, 0.0838811149878893, 0.18013954628258944, 0.11904629835044034, 0.1846885256236419, 0.1452634294400923, 0.11034638315322809, 0.14047297008801252, 0.21049127855803818, 0.13117709546349943, 0.11406354111386463, 0.09607356230844744, 0.09048517546034418, 0.13249323499621823, 0.12893858511233702, 0.1988321979297325, 0.17735117871779948, 0.10226087717455812, 0.1263714220840484, 0.18545111204730347, 0.1369294969481416, 0.1504004717571661, 0.12209188687847927, 0.11789446289185435, 0.18648790719453245, 0.19364988460438326, 0.12377475126413628, 0.13165244105039164, 0.2293393953004852, 0.09012924885610119, 0.19756750407395884, 0.0899549109453801, 0.11445482363342308, 0.11915549053810537, 0.11011252499883994, 0.09594096278306097, 0.09675000765128061, 0.16975549020571634, 0.10322329428163357, 0.10526315396418795, 0.11346553335897624, 0.13064350612694398, 0.17841301392763853, 0.14982668770244345, 0.16527032072190195, 0.11272766787442379, 0.17852916003903374, 0.12857674359111115, 0.2895267406711355, 0.1255794317694381, 0.1992772935773246, 0.1956189062912017, 0.14460686623351648, 0.17714092828100547, 0.22627177240792662, 0.10923753288807347, 0.1762303279247135, 0.14836204441962764, 0.21605918213026598, 0.165392478229478, 0.24778105260338634, 0.09760476881638169, 0.13540732237743214, 0.16665859700879082, 0.20501946826698259, 0.17888889386085793, 0.1490153421764262, 0.14359966793563217, 0.10973278287565336, 0.19798362627625465, 0.09338763338746503, 0.13793454301776364, 0.14552105858456343, 0.2797078597359359, 0.18928369623608887, 0.3286920109530911, 0.2109525678679347, 0.05886175458726939, 0.1641927965101786, 0.10842562332982197, 0.1966820179950446, 0.18378821143414825, 0.1614446978783235, 0.21803624869789928, 0.14674368751002476, 0.17273831530474126, 0.208135464345105, 0.18735262798145413, 0.11226118353079073, 0.15814810758456588, 0.14919062261469662, 0.11629492684733123, 0.11184213726664893, 0.07606773971929215, 0.05594862828729674, 0.19142744917189702, 0.21786638593766838, 0.2510452555725351, 0.13794433936709538, 0.15190317237284034, 0.13927432737546042, 0.17863297165604308, 0.16535094764549285, 0.15702177974162623, 0.128787825233303, 0.09976753557566553, 0.2536575560225174, 0.13384866382693872, 0.15590904804412276, 0.1237579713051673, 0.1787615561624989, 0.08632241719169542, 0.203445180086419, 0.140343836392276, 0.10901312227360904, 0.1505272157373838, 0.18083112401654944, 0.16447815229184926, 0.08822558069368824, 0.12036544358124956, 0.20962824986781925, 0.11223720473935828, 0.14432428608415648, 0.09743145506945439, 0.1720429674605839, 0.2336351093254052, 0.10660981803084724, 0.14220398501493037, 0.11979198607150465, 0.10273160660290159, 0.090328478399897, 0.20915679313475266, 0.12290316561120562, 0.16726150293834507, 0.14346608135383576, 0.18557280942332, 0.09497749924776144, 0.13867550325812772, 0.17990793683566153, 0.10350877622840926, 0.10527393736992963, 0.19929614412831143, 0.14671465469291434, 0.23676343989791349, 0.10949771502055228, 0.15132720640394837], [0.0662945379735902, 0.05730524455429986, 0.060820764701929875, 0.04275922059605364, 0.08226986043155193, 0.03310418360342737, 0.030346598468895536, 0.08996264412417077, 0.06417526106815785, 0.1949732526554726, 0.049270364179392345, 0.019169158695149235, 0.017865099471237045, 0.032345857107429765, 0.034682401455938816, 0.01260360548258177, 0.031188548309728503, 0.03607973565522116, 0.07888026419095695, 0.07400278802379034, 0.0883708857872989, 0.07757184299407527, 0.02669539702765178, 0.03658108238596469, 0.03598098919610493, 0.03523306761053391, 0.04049680566822644, 0.0253872188841342, 0.0350233032804681, 0.03097050717769889, 0.07534965247032233, 0.12024896350339986, 0.04742918485135306, 0.010017663335020188, 0.045466196825145744, 0.057416540730628185, 0.029265367229527328, 0.026441100126248784, 0.041526709974277765, 0.007233806636577356, 0.03368596801010426, 0.010926918548648246, 0.014217378702596761, 0.04083661282493267, 0.025646770191087853, 0.048134080425370485, 0.03901442134520039, 0.020540972291200887, 0.038096217685961165, 0.05084123848064337, 0.048057308958959766, 0.07189561554696411, 0.032544812056585215, 0.009352899396617431, 0.06291175464866683, 0.04102975675777998, 0.021944095242361072, 0.008605123457527952, 0.09426460703252815, 0.03025561116373865, 0.053343381950980984, 0.06833898412878625, 0.004760822612297488, 0.03941054266761057, 0.03192307412973605, 0.029433927520585712, 0.04133890579396393, 0.11376139053027146, 0.007173229296313366, 0.026845635547942948, 0.05048303719377145, 0.03775943107029889, 0.029428379966702778, 0.04018319261376746, 0.010741861242422601, 0.04912250609777402, 0.04217948080622591, 0.08872743579559028, 0.010927030798484338, 0.008252377883763984, 0.04719527845736593, 0.03487906316877343, 0.013428931215457851, 0.026458139836904593, 0.05830613459693268, 0.02053664928098442, 0.02380244230153039, 0.0999284851422999, 0.059698559489334, 0.14626483898609877, 0.027157586191606242, 0.019970062203356065, 0.011370012252882589, 0.00310086832541856, 0.044899515123688616, 0.05035889073042199, 0.018110956298187375, 0.06509400278446265, 0.03034633871720871, 0.11626301449723542, 0.027833914646180347, 0.026966102814185433, 0.013285431396070635, 0.043710282843676396, 0.042497019821894355, 0.02894706565712113, 0.009815260182222119, 0.0285322533454746, 0.04715045273769647, 0.10218843613984063, 0.08464547514449805, 0.022888606181368232, 0.02906374054873595, 0.06035015772795305, 0.05092738698294852, 0.015186874970822828, 0.07753765967208892, 0.03662756680569146, 0.02087815410050098, 0.019044132786802948, 0.04728778345452156, 0.024684792806510814, 0.06676509670796804, 0.05321096054103691, 0.009175142968160799, 0.057530029953341, 0.029286958160810173, 0.04237863242451567, 0.019047516980208457, 0.039234475552802905, 0.01868160663434537, 0.027098342397948727, 0.024809699971228838, 0.053234282531775534, 0.1035992885590531, 0.06304342648945749, 0.08118447687593289, 0.08166336250724271, 0.03979667468229309, 0.07525324006564915, 0.018403440408292226, 0.015929817673168145, 0.03737210790859535, 0.0519686980987899, 0.04511937266215682, 0.04665050124458503, 0.02350843122258084, 0.04937328521918971, 0.05622970929834992, 0.017667599131527822, 0.020299269635870587, 0.04417779877257999, 0.048041230329545215, 0.010722767638071673, 0.018419539446767885, 0.020248855544195976, 0.03342636104207486, 0.056287752668140456, 0.04694141942309216, 0.1324483350617811, 0.04556091342237778, 0.018415730373817496, 0.028149563040642533, 0.02199217713496182, 0.0862650788621977, 0.0235300629719859, 0.06481284013716504, 0.03643254894996062, 0.06851705504232086, 0.059638326783897355, 0.018047767989628483, 0.08088590344414115, 0.04318390347179957, 0.05195568082854152, 0.019557094128686003, 0.044101891908212565, 0.02833170092344517, 0.02017949998844415, 0.0397913609049283, 0.02044376393314451, 0.0679602290620096, 0.054126165923662484, 0.04172890439804178, 0.04538443070487119, 0.027896399769815616, 0.07526149274781346, 0.022668748642900027, 0.03733074801857583, 0.04087608394911513, 0.046472964677377604, 0.023731548644718714, 0.0740390048304107, 0.011352021665516077, 0.0424811861012131, 0.05677364417351782, 0.06655754026724026, 0.020069432066520676, 0.0398593490535859, 0.0404705893015489, 0.03494657634291798, 0.03327081059978809, 0.06306919385679066, 0.0364698010525899, 0.04351064511865843, 0.07386906785541214, 0.013934559210611042, 0.03653830128314439, 0.01056368642821326, 0.048911320554907434, 0.06809967118897475, 0.04425902312505059, 0.04568127864331473, 0.03298338793683797, 0.018482733321434353, 0.042928463662974536, 0.07362182877841406, 0.031035463653097395, 0.013236392132967012, 0.03836860072624404, 0.0025029510197782656, 0.022060083647374995, 0.033636570660746656, 0.09653126704506576, 0.01834128182963468, 0.024005048617254943, 0.04300929096643813, 0.047988062869990245, 0.03968387936765794, 0.046260814342531376, 0.0041550895639375085, 0.07750644494080916, 0.033353437611367553, 0.058058194190380163, 0.024312947134603746, 0.029367622191784903, 0.03712083896971308, 0.03087912467890419, 0.044107606445322745, 0.0034050384783768095, 0.05472875644045416, 0.07023872632998973, 0.05596492213953752, 0.028628014515561517, 0.0411696033552289, 0.01930259128130274, 0.016017289053706918, 0.0492435726482654, 0.014731495011801599, 0.03175587196892593, 0.019253897116868757, 0.029905677401984576, 0.02429682954243617, 0.013527698083635187, 0.025765675236470997, 0.0121947999286931, 0.007651905734746833, 0.04404251267260406, 0.010102755204570713, 0.06672757372143678, 0.03303829573269468, 0.1062765640381258, 0.046493956324411556, 0.04749420069856569, 0.08542898271116428, 0.0640941146411933, 0.04919364466331899, 0.021728492065449245, 0.053958518474246375, 0.04458613213500939, 0.019245974690420553, 0.06446693252655677, 0.04103790553926956, 0.021220909438852686, 0.05756676626333501, 0.042465563892619684, 0.016102778899949044, 0.058475878613535315, 0.06503457901999354, 0.030506590665027034, 0.04375282645924017, 0.03206724002666306, 0.0305695637507597, 0.02287290604726877, 0.037874920381000265, 0.04936437573633157, 0.05276975003653206, 0.05358966736821458, 0.028052228517481126, 0.05984030227409676, 0.014503631555271568, 0.030413089334615506, 0.03130753684672527, 0.04844885494094342, 0.04226372569974046, 0.04972265494870953, 0.06195784626470413, 0.0048397523369203554, 0.01773313448211411, 0.05543890642002225, 0.04916463411063887, 0.05356415604182985, 0.011782569363276707, 0.04221628390951082, 0.023975871081347577, 0.05188862036447972, 0.05994755003484897, 0.01374787474560435, 0.022426712021115236, 0.010549699727562256, 0.0535044762364123, 0.06991312387981452, 0.020936917353537865, 0.029928281364846043, 0.024220310406235512, 0.06609901174670085, 0.06406953471014276, 0.03701229245052673, 0.037899340750300325, 0.05016841481847223, 0.02628216549055651, 0.023549876459583174, 0.0011851457134071097, 0.05420767229225021, 0.027239137089054566, 0.01021126183331944, 0.011653812307486078, 0.03351894025399815, 0.06276484651607461, 0.015838455583434552, 0.07793487195158377, 0.04342499014455825, 0.053762569223181345, 0.031158428246271797, 0.05701076406694483, 0.018417268474877346, 0.03726275986991823, 0.017628617824811954, 0.05783015818451531, 0.02128474156052107, 0.010138076795556117, 0.04729888227302581, 0.03478659527900163, 0.09201451917761005, 0.025732393623911776, 0.07780959000228904, 0.0639379964559339, 0.023078588565113023, 0.05301081073412206, 0.0003381717067441059, 0.0402791040687589, 0.09050417444086634, 0.051121080105076544, 0.12203817765112035, 0.12056209787260741, 0.1254450436681509, 0.11487114621559158, 0.2011504297843203, 0.08705630476470105, 0.09212755569024011, 0.14258337090723217, 0.13689440820598975, 0.28380739444401115, 0.1313258960726671, 0.11940415453864262, 0.1444045567768626, 0.10195177266723476, 0.07255624572280794, 0.12996598466997966, 0.1057941977342125, 0.10760806602775119, 0.138471472018864, 0.20361525064799935, 0.2165434483322315, 0.11892596652614884, 0.09293255585362203, 0.11675516972900368, 0.10278069967171177, 0.2316122522461228, 0.10864351788768545, 0.12472844071453437, 0.20138353836955503, 0.11940298936679028, 0.1837909425375983, 0.170062709657941, 0.16720327403163537, 0.1519508776254952, 0.12090460644685663, 0.12392067234031856, 0.11441992784966715, 0.187771926575806, 0.14214801223715767, 0.13310123205883428, 0.2373789474950172, 0.14425296569243073, 0.15781846042955294, 0.12997174373595044, 0.0749041857488919, 0.20921514078509063, 0.24994465056806803, 0.12264417833648622, 0.08898074564058334, 0.09664938726928085, 0.14506250037811697, 0.28460529225412756, 0.17423665209207684, 0.1210532512050122, 0.18493390933144838, 0.2837871783412993, 0.12965355534106493, 0.11070973865571432, 0.1881780891562812, 0.24220646970206872, 0.11877418248332106, 0.10457881959155202, 0.14441062754485756, 0.1267853326862678, 0.1412003638688475, 0.12364863810944371, 0.19983314734417945, 0.17352512542856857, 0.1101586791628506, 0.0865229826013092, 0.13641763769555837, 0.10392053460236639, 0.12919787666760385, 0.09039565018611029, 0.19581677770474926, 0.15975803369656205, 0.10957841615891084, 0.12572354200528935, 0.07796163379680365, 0.16311176936142147, 0.1827142940601334, 0.1310987988836132, 0.21473559143487364, 0.1441499704378657, 0.23704554507276043, 0.2853298658737913, 0.1429256345727481, 0.329116964712739, 0.19423999590799212, 0.19322497537359595, 0.20647254888899624, 0.15172538347542286, 0.12036986678140238, 0.07853844581404701, 0.14039437664905563, 0.15456190158147365, 0.10115055745700374, 0.10445073974551633, 0.17088833410525694, 0.16050950274802744, 0.13747899793088436, 0.10276631684973836, 0.18018069094978273, 0.17248447111342102, 0.1749295211629942, 0.09557868339470588, 0.12257836468052119, 0.09808093076571822, 0.120910855330294, 0.14430760260438547, 0.12656663660891354, 0.10531795414863154, 0.15317153243813664, 0.12658818857744336, 0.13637879368616268, 0.15183467214228585, 0.13913581293309107, 0.10573722305707633, 0.10835235108970664, 0.10143387975404039, 0.16722700791433454, 0.1185806526336819, 0.16928542871028185, 0.20269050495699048, 0.11626061736023985, 0.12386528585921042, 0.16737068770453334, 0.09561241400660947, 0.09815815123147331, 0.12330729470704682, 0.13546169211622328, 0.14916580519638956, 0.12562862131744623, 0.2651587373111397, 0.17840341053670272, 0.20904793491354212, 0.15405986836412922, 0.19762911717407405, 0.12426412344211712, 0.13809342199238017, 0.09343403246020898, 0.13189641467761248, 0.16576344816712663, 0.09761898836586624, 0.18350021360674873, 0.1622308252262883, 0.10892939317272976, 0.1183535999734886, 0.17592135700397193, 0.07844192208722234, 0.08576720909331925, 0.13843765977071598, 0.16572393622482195, 0.18796231714077294, 0.1283124796464108, 0.17711805528961122, 0.11137767156469636, 0.12360141525277868, 0.2156700741034001, 0.23248525540111586, 0.11205876275198534, 0.19855399645166472, 0.10686907247873023, 0.1638828607974574, 0.1793951276340522, 0.08084343033260666, 0.16279840492643416, 0.14073330065002665, 0.36878523300401866, 0.19251427991548553, 0.12393009019433521, 0.1498989580431953, 0.06970410540816374, 0.19013596378499642, 0.23033494187984616, 0.13946758263045922], [0.1091624349646736, 0.005237942395979189, 0.07676436405745335, 0.03576055278244894, 0.025361275256727822, 0.03711820434546098, 0.018259725366078783, 0.015712730200903025, 0.016381789318984374, 0.02872595017834101, 0.012120852334192023, 0.03931276471121237, 0.03788455716858152, 0.061824801450711675, 0.01312097239861032, 0.02730781172431307, 0.04794877357198857, 0.006653881773672765, 0.058910086954711005, 0.01656086213188246, 0.027725676118279807, 0.04810329985048156, 0.025180729280691594, 0.07278512406628579, 0.0066744077230396215, 0.03842941972834524, 0.04876094659266528, 0.10171144298510626, 0.08644232599181123, 0.0520257098833099, 0.02502194678527303, 0.025197403483616654, 0.027720464386220556, 0.016496790667588357, 0.061104157502995804, 0.03907984537363518, 0.010495623137103394, 0.015231664510793053, 0.023288187767320778, 0.01865025275037624, 0.11866738001117483, 0.04632409356418066, 0.082953014789382, 0.0071285547892330214, 0.013840495703334454, 0.06341542801237665, 0.021681105936295353, 0.03048122405743925, 0.054063762436271645, 0.020070489626959898, 0.04746460013848264, 0.08910722986911424, 0.01146708702435717, 0.05187323193240445, 0.04156995863013435, 0.005902343145862687, 0.05838181881699711, 0.01897466219816124, 0.08177729701856151, 0.017814483144320548, 0.025619692933105398, 0.06423447703127749, 0.058597913666744716, 0.040900971871451475, 0.04569586555589922, 0.032484827970620245, 0.023540260081063025, 0.04688245207944419, 0.037560669079539366, 0.00817657028164831, 0.04298323787224945, 0.017274797064601444, 0.048018301677075215, 0.02828584547387436, 0.030702365511388052, 0.0705708225723356, 0.05659606678818818, 0.052285272322478704, 0.07137821245123632, 0.014615668023907347, 0.0474548705824418, 0.044991860559093766, 0.041205734814866446, 0.06677170924376696, 0.05457824518089183, 0.03191404219251126, 0.04382239538244903, 0.046291179314721376, 0.07964123273268342, 0.05551177047891542, 0.0754338713886682, 0.03156065744406078, 0.035020338400499895, 0.06998704178840853, 0.03994427672296297, 0.025588381722627673, 0.010462002919666702, 0.06309745484031737, 0.03207950772775803, 0.05114603482070379, 0.06274994419072755, 0.026883353348239325, 0.044636984093813226, 0.07327818471821956, 0.047272869996959344, 0.01348595877061598, 0.021435827984532807, 0.026939654526358936, 0.05080668779555708, 0.057785659009823576, 0.01191856699733762, 0.08298887536511756, 0.030088141829764936, 0.02521994993003318, 0.03668004406790715, 0.03049049904802814, 0.059146108469576575, 0.040174041932914406, 0.06666288812994026, 0.0359342969750287, 0.05164007510757074, 0.02171571228245739, 0.044068061106372625, 0.0225407875404926, 0.0400924205314368, 0.013786765139229828, 0.01499119289292139, 0.024606974911876023, 0.05838655371917412, 0.10655506237526424, 0.13133358472259715, 0.014014303906151326, 0.028227416187291965, 0.028317538890405558, 0.02813759034324903, 0.051611346571007743, 0.023714690760243684, 0.05585065366176423, 0.02081160942907445, 0.08328332987730391, 0.06457744573708624, 0.06667159352218732, 0.05475881713209674, 0.04988349690393079, 0.06425235536880791, 0.0399096777982777, 0.014833001332590356, 0.042452264606254175, 0.05437890431494452, 0.042206810394418426, 0.020630974395317025, 0.057526512173353694, 0.0033993826173173147, 0.00448820115707349, 0.04714235590654425, 0.014116680395090953, 0.03546107764123008, 0.03750815099920146, 0.05251946444332134, 0.050415011937730014, 0.07290460984222591, 0.03482547639578115, 0.016080605382740032, 0.022728567601006944, 0.07309982436709106, 0.015099677257239819, 0.053947319465805776, 0.0559686662745662, 0.018327936159039382, 0.0127935127238743, 0.014642339883721434, 0.041496998092043214, 0.046075559439486824, 0.012457755838113371, 0.090710209478857, 0.03534274219418876, 0.01762120933562983, 0.03253810304158833, 0.051340555437491275, 0.0205668417038396, 0.02890080944780493, 0.05824682957609184, 0.0493321665271651, 0.038136935618240386, 0.036012085183756426, 0.08692118935869075, 0.03503723710309714, 0.010667784699762706, 0.01618357466213638, 0.06574508151970804, 0.021358999001677148, 0.011751402871595928, 0.021024744964961428, 0.021682690421584994, 0.06859857254312374, 0.022548229426320177, 0.014813120124017587, 0.04433939771843143, 0.010145196774828946, 0.024171940931410063, 0.07900302283815108, 0.056441481137881055, 0.03485539979010355, 0.030169247438607272, 0.10889519500778988, 0.0755040934018325, 0.022295763774309307, 0.011651872518996242, 0.016458468016935512, 0.03288094187155366, 0.034494623250793666, 0.006099499778429163, 0.04801968578249216, 0.051518292384571396, 0.0639937688538339, 0.10121211118530482, 0.044949732546228915, 0.030865853223076556, 0.015637430042261258, 0.004835035988435266, 0.0906157266581431, 0.01854324062151136, 0.08400394042837434, 0.010132458737643901, 0.03087315595621476, 0.07996359941898845, 0.10238998118438758, 0.04735265458293725, 0.03857862851873506, 0.02286186660057865, 0.011037356616725447, 0.023923651715449523, 0.022174637852003798, 0.03419895161641762, 0.033588954465813003, 0.03114765597274527, 0.0589672323258128, 0.020099429675610736, 0.03463450695562642, 0.03276131137681659, 0.10480223572812974, 0.01785374461178435, 0.03947707620682195, 0.03648672573035583, 0.061463739184546284, 0.03921132425602991, 0.01685426464973716, 0.02646265766088618, 0.03543997467204463, 0.12051917205099016, 0.0337080914323451, 0.15550364245427772, 0.07335567977861501, 0.03903959128365386, 0.031025225725898053, 0.002056461062238668, 0.021616806261590682, 0.04197251808363944, 0.01681820740486728, 0.06634477394982241, 0.10119709753780626, 0.08459054137347266, 0.10189189619268291, 0.04855522696743719, 0.06396239085006528, 0.09157565757050179, 0.023359485894616228, 0.03987207688624039, 0.03062018564378377, 0.06876113257021643, 0.07754679550998844, 0.018964337068609893, 0.0465363069815794, 0.06182150260428898, 0.02237752989458386, 0.09567959321429953, 0.07112053877790459, 0.0570906228676904, 0.10653258272213861, 0.019958588600275107, 0.031762313810759224, 0.07720043518929742, 0.0711028533987701, 0.0238619755327818, 0.03531690803356469, 0.022659093301626854, 0.011284732991043711, 0.039646018703933805, 0.06873053382150829, 0.029487258252629545, 0.02377805718424497, 0.07913398221717216, 0.02466191795974737, 0.0034114093523385236, 0.08381947220186703, 0.013927031050116057, 0.025035344406205695, 0.011322993486828636, 0.05895699068787508, 0.007011599273027969, 0.041122866605292074, 0.06682897335849702, 0.035156314697815105, 0.05867990985279903, 0.08080596671788953, 0.03737143626494799, 0.07026620805845596, 0.022275165465543978, 0.12460831669159234, 0.01892572869110154, 0.084096968639642, 0.010668244831322227, 0.0716987979831174, 0.027589536548475735, 0.03724369038536679, 0.010754604845715221, 0.014442673400480999, 0.06428144755773246, 0.035163981083314866, 0.03126312672975473, 0.02831947032973403, 0.02908756348915631, 0.02219616941147251, 0.04805870048585348, 0.014102648237894755, 0.06834293235442601, 0.05250859569059685, 0.0458522100962, 0.03515912372677121, 0.05361242532671895, 0.06058429047698155, 0.020954753017576877, 0.01252228836165159, 0.029402096806734335, 0.056824952553142793, 0.02204820186307188, 0.09051981149241328, 0.019559240790840704, 0.02381331847573165, 0.05717480096791405, 0.03411308513022959, 0.12956032674992457, 0.06572936283191666, 0.028345901919237804, 0.024460224485665094, 0.020717555198643822, 0.019169926817994565, 0.0491238605172839, 0.04025770795124117, 0.059449275795486756, 0.04020629196020309, 0.04497435700614005, 0.19742621399927884, 0.129603564273566, 0.18451400217600167, 0.110327636502916, 0.08999430414405651, 0.1573493637260981, 0.11294817479210906, 0.0992320611840114, 0.11897354561369866, 0.1870622404385358, 0.08579811212257482, 0.10613958584144711, 0.13796357583487406, 0.21317365259164944, 0.09241483363439329, 0.10326023839297704, 0.13633948954520747, 0.1368116438970901, 0.18830250279279426, 0.13578617392340675, 0.0946876015223097, 0.14917680382495746, 0.0836479989811778, 0.15499914530664682, 0.21376346703618765, 0.16210253757890314, 0.11367725324817002, 0.1590257862699218, 0.16743605607189238, 0.17115979688242078, 0.08936664758948609, 0.10222900935332291, 0.1166911817563232, 0.10555005341302603, 0.1554565754486248, 0.16138617211254314, 0.0970456941286102, 0.13441233983030543, 0.20667325530666858, 0.176598314428702, 0.15595366596244276, 0.15357589902123436, 0.17169221362564713, 0.08446645428193733, 0.13029606227064505, 0.13886901084333658, 0.21255246014334261, 0.07126225929823704, 0.1353338942863047, 0.16062284354120493, 0.22927827201783657, 0.1930244916002266, 0.13357669638935477, 0.12474466406274587, 0.15483930154005066, 0.12379910855088383, 0.1821624330477789, 0.10984596039634198, 0.18312922882614657, 0.09519173501757905, 0.13418331305729225, 0.11433432111516595, 0.1254235510714352, 0.21443162258947268, 0.16616172913927585, 0.07263765932293609, 0.06916029669810086, 0.09977830413845368, 0.12491090514231473, 0.1198336502420716, 0.08701097438461147, 0.11158475303091109, 0.24282684578793123, 0.146062366256956, 0.12088640156434849, 0.2570252143777907, 0.24247152032330632, 0.13570605166023597, 0.18218247103504837, 0.12541969190351665, 0.24284744780743495, 0.2380866595194675, 0.12416048251907341, 0.2774090424645692, 0.2242388518061489, 0.2866587258176878, 0.1391518730088137, 0.18788403540384024, 0.42141611978877336, 0.3570447536185384, 0.14193682669429109, 0.10890243836911395, 0.13311898423125967, 0.19762258627451956, 0.17421165655832738, 0.10305850781151094, 0.15638982615200803, 0.16476558608701453, 0.14565601071808487, 0.25616586674004793, 0.10656597936758772, 0.2671975950943306, 0.14210231078322977, 0.1755174357094802, 0.1479349087458104, 0.06280544199398719, 0.19477624213322997, 0.20681251189671457, 0.24719070381252095, 0.1929329996346496, 0.11428473080741242, 0.19972794048953801, 0.15676250302931294, 0.17750492203049362, 0.11036245065042749, 0.10780978918774053, 0.14811591856414452, 0.15555274294456467, 0.1691594862495549, 0.16339561116183177, 0.14705133740790188, 0.08378641694434918, 0.14775088580790907, 0.17737641173880547, 0.10615714505547658, 0.1474598006461747, 0.15395670983707532, 0.10520465046283789, 0.22461142478277907, 0.1257869362598285, 0.22253933362662792, 0.05942179777775891, 0.20320022682426497, 0.07049866355373524, 0.11893532500835136, 0.16393297060858458, 0.10438440658617765, 0.09885076055070385, 0.209258125978522, 0.13310059381183237, 0.17191847960930318, 0.12518429750343785, 0.11588374734856188, 0.09376947578857653, 0.10540168324951082, 0.13374084461247548, 0.11824204775621183, 0.14408264280064031, 0.09462038520723581, 0.18524987128330395, 0.22757407830795273, 0.11780265180277638, 0.11530867937835865, 0.11128486599773169, 0.17237558320630342, 0.12984534114366397, 0.09158244080026634, 0.11675084300804883, 0.22620993666350842, 0.13547876151278615, 0.16910449310671538, 0.20358036970719695, 0.08460725453915074, 0.24474047357216477, 0.21204477176070213, 0.16623153554974124, 0.11972298118053004, 0.1294434384908527, 0.04712755006039515, 0.09563565807184204, 0.10272250045090914, 0.12600331683643162, 0.14177759148878977, 0.1156400483159814, 0.12783469981513917, 0.11056470815674402], [0.029716739591094665, 0.02604087843792513, 0.029212138542789035, 0.033253451765631326, 0.06203900382388383, 0.06642749372986145, 0.014118645231064875, 0.013597598190244753, 0.032795453880680725, 0.08098826787318103, 0.06275415216805413, 0.016937895416049287, 0.04749728432216216, 0.03800642894930206, 0.08586708732764237, 0.022184942572494037, 0.002849455595423933, 0.05724414724681992, 0.03642665258666966, 0.05045879493991379, 0.04078450663655531, 0.012915524584968807, 0.04886327020358294, 0.07730507059022784, 0.01038318498103763, 0.02145459318853682, 0.040760234696790576, 0.01911226750962669, 0.02683705446543172, 0.02216316610429203, 0.07995889420271851, 0.06010642529872712, 0.06165504630189389, 0.021132027977728285, 0.0644897906749975, 0.04658489167923108, 0.0033976596751017496, 0.012876413402409526, 0.017397039919160306, 0.05408564466051757, 0.01820056506403489, 0.0413654041767586, 0.00902218447663472, 0.030536085469066165, 0.04153617606789339, 0.03991417521319818, 0.04114065217436291, 0.05539664110983722, 0.06104933505412191, 0.028923927347932477, 0.07514559896662831, 0.029356000159168616, 0.02487632998963818, 0.05490621508215554, 0.034813509264495224, 0.015513904199906392, 0.05344831050024368, 0.03606779449910391, 0.03980725770816207, 0.020409736462170258, 0.0161657983699115, 0.011069172487623291, 0.037916784931439906, 0.029000632021052297, 0.03897474984114524, 0.011946224058192456, 0.027915187238249928, 0.01257291303772945, 0.021072344461572357, 0.02960253976198146, 0.07786517686326988, 0.03826505628239829, 0.03566212544683367, 0.08163453749148175, 0.01603320812137099, 0.013796575403830502, 0.06003026239341125, 0.05203649699978996, 0.031005582932266407, 0.04480396361032035, 0.057499683534842916, 0.028379491523082834, 0.016843599987623747, 0.06867468720884062, 0.09512123840977438, 0.11026844280422665, 0.07778405270073563, 0.10182221594732255, 0.10206348073552363, 0.10408385904156603, 0.14923417184036225, 0.05660866474499926, 0.1065402639505919, 0.042268226825399324, 0.06347364207613282, 0.007831278653611662, 0.0478191834554309, 0.05065666635346133, 0.042827041761484, 0.1253016310511157, 0.04133883900067303, 0.005803987241961295, 0.011891524991369806, 0.06497285459772684, 0.02164379631722113, 0.052069129233132116, 0.017528782263980247, 0.04356884062872268, 0.04710861045168713, 0.023960477083164733, 0.039193965421873145, 0.04268427481292747, 0.04082201106939465, 0.03223633837478701, 0.05264727340545505, 0.05102427807287313, 0.015017504811112303, 0.044681130748358555, 0.03538368648150936, 0.07403273368254304, 0.016340156689693686, 0.04731071581772994, 0.0113097888242919, 0.07180895496276207, 0.08741149664274417, 0.0189231256081257, 0.008690175436640857, 0.040673455368960276, 0.03658393965451978, 0.03236329757783096, 0.056506801265641116, 0.027292983613733668, 0.05975351552478969, 0.00504035949234094, 0.024070246290648356, 0.04549235382000916, 0.07213639793917537, 0.06232482715859078, 0.02766514284303412, 0.03409944074519444, 0.05019733631343115, 0.019964304992754478, 0.07746201998088509, 0.06545244526932947, 0.047959386283764616, 0.03670135483844206, 0.030068484193179756, 0.031035818028612994, 0.026227365306112915, 0.016641947331663687, 0.020972950478608254, 0.027244428601989057, 0.0240831169867306, 0.028358444214973133, 0.08598450993304141, 0.024443056754535064, 0.027076799706264865, 0.05701494977984112, 0.003962132559536258, 0.06167094310512766, 0.03710028890054673, 0.016713889272068627, 0.023824732706998475, 0.047785586430109106, 0.017786339049052913, 0.03701189540151972, 0.032247029012069106, 0.03314696099550929, 0.041382622002856806, 0.029542628035414964, 0.06341551707009785, 0.03948598568968009, 0.0089900977218349, 0.038751240936107934, 0.01813231716369046, 0.017968458378163632, 0.007643095977982739, 0.00554531259695068, 0.02226159158453811, 0.021214276493992656, 0.017009306720865425, 0.01019125260427245, 0.019752139814954717, 0.04604932080837898, 0.023855442777858116, 0.021226453281997237, 0.014041358899703482, 0.013533391283999663, 0.05483263114001602, 0.008984273717942415, 0.06269483230425976, 0.01010922951536486, 0.07502143766032532, 0.025291780548286624, 0.05898558192711789, 0.03976396823418327, 0.004053034981552628, 0.02522202423278941, 0.05075196182588115, 0.0277776876828284, 0.05425192655820865, 0.026543050807958934, 0.04923676715407055, 0.0375934163457714, 0.07049855223158374, 0.030649155378341675, 0.03234359355701599, 0.040233153995359316, 0.06020033295499161, 0.038109850938781165, 0.030365519523911644, 0.07204742927569896, 0.03993845086370129, 0.02174008626752766, 0.04700696219515521, 0.03382227456313558, 0.040953152274596505, 0.037272741756169125, 0.055341436454909854, 0.014690715852339054, 0.04511728351644706, 0.14379773230757564, 0.011098712748207618, 0.06384671971318312, 0.05952948340564035, 0.02640494640218094, 0.05648872996971477, 0.0068891792307113064, 0.029788188003294636, 0.03200194958481006, 0.014135258206806611, 0.0458557724050479, 0.02769577313301852, 0.030937726514821406, 0.07032124573015608, 0.031244769706972875, 0.05425683586508967, 0.03834354953141883, 0.02028061204327969, 0.030482617439702153, 0.04941296785546001, 0.02071290378808044, 0.07468303316272795, 0.055448632265324704, 0.038110607929411344, 0.0249862550481339, 0.06539474328747019, 0.061955912970006466, 0.023103619350877125, 0.06032346638676245, 0.03719610016560182, 0.0317228797939606, 0.0671458852593787, 0.058359031172585674, 0.01574055331730051, 0.013912291069573257, 0.08814847155008465, 0.09403730946360156, 0.06042684384738095, 0.016081408757600002, 0.12145195520133711, 0.056746310874586925, 0.06361659456160851, 0.0936107749294024, 0.08571451660827734, 0.10225055390037596, 0.06420010817237198, 0.049176285829162225, 0.1043925850535743, 0.06867565200082026, 0.016668913267494645, 0.0209173227995052, 0.04980171594070271, 0.0451679796242388, 0.026003060447692405, 0.03212470081052743, 0.05625307581794914, 0.05314906171406619, 0.03357364395924378, 0.040772190695861354, 0.0797323313599918, 0.042572436868795194, 0.007649378258065553, 0.03760447434615344, 0.03851550143735949, 0.007651320829609176, 0.060739332548109815, 0.048376632839790545, 0.012399488896335242, 0.039661006376263686, 0.019770489416259807, 0.052246268751332536, 0.05521239552763291, 0.0633678340818733, 0.04315779842727352, 0.04695071853348054, 0.07378629612503573, 0.02743038668995723, 0.024245330059784465, 0.050681376160355285, 0.05197913269512355, 0.03209902992239222, 0.012936518087371951, 0.03107440599706024, 0.05365957025787793, 0.015178923786152154, 0.017155172135971952, 0.024476761391269974, 0.06392028881236911, 0.04577117128064856, 0.027803814991784748, 0.07337139846640639, 0.039360488517559133, 0.03262777674535755, 0.03055206576391356, 0.023369039190583862, 0.042809400911210105, 0.025223530792573, 0.04690589652454946, 0.06180933880386874, 0.023987754721019883, 0.015426701847900404, 0.021348978152673226, 0.027400166436564177, 0.08542772848159075, 0.04009648378996644, 0.04005494949524291, 0.07559196368674748, 0.022505262786580715, 0.017561935856065247, 0.04729457039502449, 0.03920311981346458, 0.05711638652428519, 0.04893278717645444, 0.013368633572099498, 0.08044475602218881, 0.00718244862582651, 0.05735254533647094, 0.03371989900188055, 0.0340656767366454, 0.017650893387326505, 0.03844693812425248, 0.06334925812552683, 0.07886226710979827, 0.0938833954569418, 0.0690327883057762, 0.08190800406737253, 0.04205482968245633, 0.05580313765676692, 0.025974220588977914, 0.04112397611606866, 0.039032845161273144, 0.13930341956438497, 0.14079852058785036, 0.11143528448883444, 0.10199208612903021, 0.10173778922762722, 0.1494447933509946, 0.1014483738981653, 0.08731056455872022, 0.17389228072715923, 0.10053122037788853, 0.0672462755755987, 0.11337477611959912, 0.2266853564651683, 0.1542277421685867, 0.14582930220058188, 0.17252677353098989, 0.14846220467006788, 0.16316643595928326, 0.12800009484635666, 0.13541377906221896, 0.0652257636829745, 0.0723136673332192, 0.16678859159583226, 0.1461546152131632, 0.18643870280357078, 0.08492862674756907, 0.13181900867493823, 0.16977515711914748, 0.15228102944092825, 0.09270531023503281, 0.20939095556968823, 0.1720179125550203, 0.18202099454356357, 0.11071055501815863, 0.1309203272103332, 0.129650438320823, 0.06841018577688374, 0.1031554990913719, 0.11619372016866691, 0.12129705413826741, 0.16583470918703824, 0.10068594332551584, 0.13626729341922328, 0.12442580031347461, 0.10937379120150581, 0.26477712497580796, 0.09467369367484935, 0.16089334152638912, 0.18840457778424025, 0.1608103545731865, 0.11445204057963565, 0.11885476487805136, 0.10939710206002928, 0.1053618744481355, 0.16910416656173766, 0.21566627430729568, 0.18804647668730468, 0.09801928797969595, 0.1552641365560703, 0.1423402433283627, 0.16573627071920782, 0.08316771811223589, 0.1363760922686197, 0.21785028133308515, 0.12067676711012609, 0.16862766322446987, 0.17710552783682942, 0.09960888666682877, 0.1368270508828573, 0.06521418617921881, 0.20853661000728607, 0.15155244822381064, 0.1929966313764453, 0.22640676907030866, 0.1749943700269796, 0.19698350806720555, 0.15052718605147675, 0.13524382724426687, 0.11782297180616297, 0.18877510243328288, 0.22426217008614913, 0.312035100068897, 0.2705857070395723, 0.18789639958413318, 0.38287636125460267, 0.2092830472975038, 0.290170093649067, 0.2712208963930607, 0.22960086876992136, 0.38618010585196316, 0.25178015988785774, 0.13479407090926543, 0.2745048998622224, 0.16976396553218365, 0.2570664481027052, 0.07835978860384785, 0.13711216917727143, 0.1829649618593976, 0.14299618313089013, 0.22527239634655416, 0.1061327951902058, 0.09616578157874756, 0.06380140417604707, 0.16144250112120062, 0.1357771345647052, 0.17048610490746796, 0.14407845708774403, 0.19465147226583213, 0.1888268449692987, 0.1927741800318472, 0.10937206199741922, 0.10178621436352842, 0.07966835080878809, 0.16968409559922293, 0.11986744764726609, 0.14632085629273206, 0.12487770145526156, 0.17519377026474103, 0.09569846602971666, 0.14954168815165758, 0.10684779510484077, 0.12625662668142468, 0.10483304969966412, 0.0962048779183533, 0.11672906839521602, 0.20869906613370404, 0.15427825273945928, 0.14138581173028797, 0.10417682788101956, 0.12316714011831209, 0.1690802545635961, 0.12664249894442037, 0.26894731214269996, 0.1628866165992804, 0.12911000638268888, 0.1409499187138863, 0.13813766883686185, 0.09712680344819091, 0.0868489412823692, 0.07343131946981885, 0.16260333883110434, 0.06264677824219689, 0.2673411264549941, 0.1841867744224146, 0.14098387939156964, 0.1069374020153191, 0.1782099177944474, 0.1686740919831209, 0.14598498994018883, 0.1381738856434822, 0.062311409128597006, 0.23290669138077646, 0.17980409553274512, 0.11969675368163735, 0.10991413408191875, 0.10697042758692987, 0.17728999606333673, 0.17017098900396377, 0.06381444371072575, 0.23765486315824091, 0.13341953919734806, 0.13788128650048748, 0.1282072876347229, 0.19359878031536937, 0.23393906332785264, 0.15676855895435438, 0.12587298086145893, 0.21883067325688899, 0.1332453719805926, 0.19761130562983453, 0.18978078674990684, 0.14546725287800655, 0.10592583246761933, 0.08583003931562416, 0.11141497190692462, 0.14611744845751673], [0.02642772662511561, 0.06304111841018312, 0.0077291498564591166, 0.03108806151431054, 0.02767000019957777, 0.03989735443610698, 0.006441359437303618, 0.014021425740793347, 0.04328500996052753, 0.06264850744628347, 0.06514559689094312, 0.021119841912877746, 0.03606586491514463, 0.03438406922214199, 0.025448000778851565, 0.0455583418806782, 0.06540674381540157, 0.07692027444136329, 0.02255010334920371, 0.004047859893034911, 0.01872909295343561, 0.09228072754922323, 0.05349270948499907, 0.04668175308324862, 0.046026800337131135, 0.04634024269762449, 0.02265174603962805, 0.0803024714696221, 0.04883595174760558, 0.02654895644809585, 0.04174991088802926, 0.0549188835429959, 0.12030158177367412, 0.03379409150511492, 0.03406829280720558, 0.06624916306464002, 0.024376282017328776, 0.03678274246340152, 0.11652119283098727, 0.07452716730767861, 0.06472191962529905, 0.04420198907610029, 0.08814718021312729, 0.017904576161527075, 0.005277673735690769, 0.05234911557636224, 0.07608992251334712, 0.018822260317392647, 0.01827107094868552, 0.07519290345953777, 0.02880334504880011, 0.09676605288404971, 0.02857058341760421, 0.03715577186085284, 0.027911558136111125, 0.023463210309273563, 0.06085277724196203, 0.02240126377728302, 0.09094135879422538, 0.02181932723033242, 0.026232300588162616, 0.04502789925027173, 0.02625319204526022, 0.07424227907904424, 0.09244145447155461, 0.05544203086174093, 0.03161179512972012, 0.041710896184667945, 0.020232363167451695, 0.13646201812662184, 0.047078427305677906, 0.0027396458017392433, 0.05766200978541747, 0.055827736141509376, 0.09572515366016887, 0.026165256822423544, 0.007864897015679162, 0.03923496165953111, 0.014891825812810566, 0.029686684465559665, 0.03816716700384859, 0.06656604527961463, 0.056539355573477224, 0.14009572158101946, 0.15641258039977401, 0.07628394218045287, 0.04908403687295504, 0.024184245739888866, 0.03253488954214845, 0.19324109482113272, 0.12794654147000983, 0.03451193013461307, 0.06441813631681725, 0.02963717393868137, 0.01983391892281361, 0.06238739762920886, 0.045717528846580535, 0.08590750469011255, 0.16862586722709239, 0.07862725862651132, 0.04336064594099298, 0.06174460497277323, 0.0345813951571472, 0.050779436132870615, 0.03861320517899003, 0.0632636142836418, 0.059508031627046876, 0.06969112524529919, 0.029064070804452058, 0.02760575618594885, 0.024499033243046142, 0.0501639730646275, 0.03494122174743097, 0.022182055618031882, 0.02515932388632791, 0.02556868512328947, 0.04713381378678605, 0.04531448699708562, 0.018352185834373813, 0.054054270367487334, 0.08383059699553996, 0.03968352313677315, 0.037421375382109545, 0.06987358967307955, 0.023492050167988054, 0.03665180905954912, 0.050836618611356243, 0.06752962755854242, 0.030158109657349996, 0.037309704421204515, 0.041665383978397585, 0.08425080101005733, 0.07139954919693992, 0.007975530825206079, 0.05229262329521589, 0.035465389519231394, 0.03896507223544177, 0.014951902667235117, 0.027751402667490765, 0.10215799324214458, 0.04258979199221358, 0.009411787887074752, 0.061722897153231315, 0.0658071695943363, 0.046605660681962036, 0.06041394161002245, 0.07651325839105994, 0.036996967101003975, 0.030818522754998412, 0.06309661621344276, 0.07305974839255214, 0.07422355469316244, 0.039390693927998655, 0.015939087097649463, 0.009283781328122132, 0.0837090851564426, 0.08296379819512367, 0.05368247293517925, 0.08191246437490918, 0.019866721850121394, 0.07356167028774507, 0.06416629592422396, 0.05293958311085589, 0.012831500480388058, 0.06549548241309822, 0.014593193009204697, 0.054289208346745, 0.04121779842535034, 0.04755363188451156, 0.009846289376582718, 0.06447051709983498, 0.010868946610571584, 0.04303593777876813, 0.04612545402778778, 0.0253711068580742, 0.02076064429274993, 0.03660023350676056, 0.030184448478394188, 0.01732140579406405, 0.04633384167391341, 0.03223862418963108, 0.06300016670138575, 0.005716619298254955, 0.025055447331396863, 0.06647311354754493, 0.05554941963055171, 0.0620060784422094, 0.004348402335381252, 0.04238826179062016, 0.10478003066964447, 0.04677567558246665, 0.028464413626352325, 0.02597544513264438, 0.013350239441933809, 0.01910775896249106, 0.011805468329839641, 0.09175205865176395, 0.09944315766915679, 0.05289902845106553, 0.03547352345776744, 0.021910620671405923, 0.047434001389774494, 0.012746514366881456, 0.028652590735873673, 0.042402332910569385, 0.023310838114412036, 0.03184579800290521, 0.01474501508710091, 0.04086449902388267, 0.06151211237011012, 0.008834248565108282, 0.05732625846576411, 0.049490433229948394, 0.049183239752892405, 0.09089561281143688, 0.050013383879559115, 0.013873133502784185, 0.04860375229327474, 0.020329703256720677, 0.0077464729747589445, 0.027141487153130583, 0.027158838565810584, 0.058674032043199986, 0.02022773402131861, 0.06017645064275712, 0.07198418345069513, 0.02199291000579251, 0.09307437285315245, 0.01768215821357444, 0.04392760594782885, 0.06127789798483718, 0.09449559307540767, 0.04340005027188454, 0.03614038767409511, 0.010512994958844502, 0.06601537170354277, 0.04618141938408371, 0.0613768893526867, 0.03316876900498755, 0.020691288736998104, 0.06820037320721895, 0.06112276314524934, 0.14265859499573708, 0.02095104970067041, 0.0433443298243219, 0.04110760804906022, 0.01324482478594291, 0.03321264106489252, 0.09032720932736993, 0.06258437846554443, 0.08426179963862523, 0.02951988863060251, 0.06918639803188853, 0.059918175829807296, 0.007647504799024318, 0.027729449939215556, 0.023121662816265598, 0.03072383584367344, 0.13463593408232555, 0.12491642672102898, 0.11896049865754321, 0.07525000430177897, 0.03677691289340146, 0.10901630608714186, 0.0986381500842981, 0.06660839964752086, 0.14347262709634379, 0.04887932285782881, 0.15924289415124804, 0.10527070902753621, 0.049302220868412405, 0.04413244612806011, 0.033358268992742524, 0.018851489803637378, 0.11161178204929456, 0.021244199888315052, 0.04879716339928564, 0.03199903294444084, 0.054773708325228654, 0.058491211384534836, 0.059697416581911966, 0.01635435583011713, 0.03225604239560198, 0.033045453747035936, 0.03290996355644893, 0.03733935322088655, 0.022404467999876942, 0.017844400972535368, 0.05026170278142672, 0.04968838256900199, 0.038417322721215896, 0.028129044512752444, 0.02260336172184907, 0.02240392623207299, 0.03197909514710773, 0.06969726280658506, 0.03517486096825451, 0.0363719117740402, 0.01414737562299706, 0.047582601619069465, 0.017584458182682283, 0.016554362773604225, 0.009696554589027073, 0.02079980000416981, 0.09580660436768085, 0.04208723556075711, 0.035268397550680675, 0.04664739906729665, 0.0412415768369101, 0.07390102473436855, 0.009060732554644346, 0.02223490024334751, 0.012034092487738235, 0.032572527561569586, 0.057945480511989444, 0.019114673923468217, 0.0245492822068627, 0.024296326737385243, 0.09921528122504242, 0.04588906514982227, 0.03244992476538755, 0.009896104184008436, 0.12113206728827208, 0.04368429283204023, 0.07954165877890773, 0.0374583454686217, 0.04174232242803555, 0.04749598556372803, 0.02784095206152415, 0.007463084348273696, 0.05597229908744339, 0.035201240607420914, 0.03272799636761192, 0.08633746794657782, 0.015748152909509372, 0.03607720122090541, 0.06516288151033223, 0.053986081838957034, 0.018380122128291987, 0.03317960065032821, 0.05102363611513283, 0.044786445214413106, 0.05713745980756357, 0.018041114635707345, 0.04612753946275916, 0.01760955390636809, 0.061373850257950835, 0.003606285040405055, 0.047107756981858984, 0.035604211952886544, 0.05369307822547853, 0.012027818556816783, 0.1644117894466035, 0.132514311990235, 0.1421007968019694, 0.11822437722003087, 0.12317370070377365, 0.17683491110801697, 0.08469069420243613, 0.14345499366754666, 0.1879099808866158, 0.15689916210249066, 0.1765426088240929, 0.1468584086978808, 0.1812135081854649, 0.18425137095618993, 0.09247963796951808, 0.09549105059704743, 0.10845714976312593, 0.14330706879263744, 0.12238505747518502, 0.06311084318440408, 0.1670267467852682, 0.35575475252699107, 0.13403449760517105, 0.08591814708779566, 0.16329537669662386, 0.1544382597785443, 0.1116228177852463, 0.15559433290036395, 0.14824704121565446, 0.12918787251692265, 0.10144998435862362, 0.11502442939672619, 0.20621643372578546, 0.18530593311879784, 0.11908199565368704, 0.10089136238093488, 0.11324950901325792, 0.1585499063367024, 0.2170193727943115, 0.15131310559809208, 0.1508066343376413, 0.12416846060659736, 0.28877384669613093, 0.11478766944492236, 0.14219803299056366, 0.13397248374531046, 0.18642786744749174, 0.10221795135294087, 0.11989414269919507, 0.34794427163433284, 0.17381445912178606, 0.25349701463710517, 0.15666044288082048, 0.1446331085753627, 0.14842226228211075, 0.10081329586682841, 0.1646385749336332, 0.09708867932204157, 0.1695678010582924, 0.13964602461783215, 0.09545490800519474, 0.13053816568572074, 0.10555762331932783, 0.17860741209005937, 0.1892565336311236, 0.16333145991666242, 0.252822253969498, 0.14421363186556846, 0.08839169560815208, 0.25196872476954013, 0.20834957394981757, 0.1379016213468276, 0.1895328500540927, 0.25828897312749177, 0.2199224170180969, 0.25393390213139355, 0.20140188426012173, 0.2542475040536374, 0.15329561952967197, 0.1430447938037105, 0.2120929371449165, 0.2703280927380547, 0.19370097405044362, 0.21986451465636492, 0.293493015342392, 0.20452766184462234, 0.2149306278442964, 0.21771317697130144, 0.17075606854632497, 0.3651381115196273, 0.20977851992938668, 0.1695080433273688, 0.3080102551029995, 0.21305039670551196, 0.1925910179852508, 0.16966595751000568, 0.15741189708933234, 0.1725600811187178, 0.24205743160564452, 0.22852506634080783, 0.29699111357331276, 0.13875425996957347, 0.10463450293173082, 0.2978541422635317, 0.1797315728617832, 0.17043296713382006, 0.19431125692790374, 0.11171834703418426, 0.18331521103391424, 0.10391035975771956, 0.2318000898230821, 0.16830429463880137, 0.2009412628831342, 0.11150195903610438, 0.10143304854864255, 0.10178331256611273, 0.13142697658622637, 0.140714984445367, 0.08825494005577639, 0.12195359508041292, 0.22335385554470122, 0.13102869561407715, 0.11459478526376188, 0.168650031555444, 0.07968524951138534, 0.09498033425188623, 0.2887957845814526, 0.20766808942425996, 0.22598234965698794, 0.11763759815949015, 0.15026146749733016, 0.15511463832808658, 0.17019221442751586, 0.13569722010288388, 0.2238946733996272, 0.07456982595613226, 0.14745211199624464, 0.11186867646756582, 0.15484354662476107, 0.14472421462414786, 0.14027901721419767, 0.10910923781921156, 0.2122125416644849, 0.15306518267607316, 0.1328589059994556, 0.18875120527809486, 0.23645470646442845, 0.20861498080193996, 0.16006157209631056, 0.1710931965499185, 0.10857501765713096, 0.1458016349351965, 0.14830449828878045, 0.09236561440047808, 0.16602778632659465, 0.14977461862144992, 0.19107866944978014, 0.17121747659984976, 0.1448952202918008, 0.098239134385949, 0.12698353064479306, 0.184543673240114, 0.19327305170008913, 0.12497971707489341, 0.15815603372175246, 0.07959992479300126, 0.13201132882386446, 0.07735204853815958, 0.134246751840692, 0.12880217836936936, 0.11232799908611923, 0.15412740380270407, 0.10977197569445707, 0.15178046567598358, 0.1342508484958671, 0.12150901151471771], [0.02341623607208021, 0.02883584184019128, 0.03127381736703683, 0.036733497254317626, 0.08296949046780355, 0.004375722646727809, 0.07902372875832953, 0.03596327413106337, 0.016709866831661202, 0.02463207063556183, 0.009566617518430576, 0.027017194115614984, 0.09168407050310634, 0.02594799494545441, 0.01705955382931279, 0.03194344237272162, 0.03135359824227635, 0.050586748620844446, 0.05470461066579446, 0.01842880701588001, 0.021886686408834066, 0.018133931334887166, 0.041508887297823094, 0.006272793116295361, 0.02510696907847887, 0.035577806338551454, 0.030695298410137184, 0.02938386965979589, 0.03841924488369841, 0.021413437389128376, 0.07080782743287273, 0.009318711436208105, 0.061960833409102634, 0.01764667427778477, 0.06533772408147343, 0.04707043066446204, 0.008156413550750585, 0.02602726930490462, 0.03600769166951068, 0.03620246461650822, 0.020079990972590167, 0.10381502346717753, 0.010279056095896522, 0.035669532080646604, 0.0889464064675849, 0.015846687856537756, 0.06384903521393426, 0.017461118804931175, 0.027023494949389715, 0.03614319670305122, 0.03977693726483267, 0.014629330034949817, 0.013777721142105293, 0.021236123466223944, 0.05330171035893727, 0.024638102440803777, 0.06834699932369404, 0.06504635690362193, 0.051531947901821695, 0.03250365254643839, 0.013180335863580694, 0.05047293656389229, 0.03318585695524234, 0.037271732435328886, 0.012141080496803625, 0.011873497296619462, 0.02839793945895508, 0.1475009898422286, 0.08363470711628906, 0.026263598811056, 0.045815221455995925, 0.061781675249221735, 0.10575380263617262, 0.10986473673256114, 0.051945027298643254, 0.0706528447335586, 0.08076632118900307, 0.023426980515068863, 0.07777740305755287, 0.06888691175845452, 0.10916535160504282, 0.4407357081072405, 0.3284684760728851, 0.43662017269525677, 0.5894965678453445, 0.5070086347404867, 0.49918461707420647, 0.6805082154460251, 0.5561449856031686, 0.7745907513890415, 0.639675190905109, 0.4983789415564388, 0.5136400507763028, 0.06100606784457341, 0.1452751553733833, 0.06640136271016672, 0.0690187765576411, 0.031376556580653414, 0.12400797117152251, 0.15195803192909807, 0.03026599752047332, 0.018013697845162824, 0.04994977069145534, 0.0648053889744915, 0.07164094757172279, 0.06182593322591856, 0.052763308194698766, 0.031949416661518626, 0.027307036179990973, 0.03380379879672546, 0.08441212907200679, 0.0792625370377209, 0.008932709297369001, 0.02829388849932002, 0.022835175259388052, 0.012477313284762204, 0.03523562802001834, 0.06075086923374329, 0.03071130282478407, 0.02752294734818861, 0.04882670829829294, 0.03197504673153162, 0.041725987757672556, 0.09796002006623894, 0.01612006723007653, 0.02728185325395316, 0.006228745724001783, 0.02299772600963479, 0.03036332462215796, 0.06215627428900916, 0.050022471477859654, 0.011052028876292752, 0.02414478760329075, 0.03630058767157607, 0.01220450258188066, 0.010043401944130892, 0.04510550563281868, 0.04261507696355693, 0.051127495971741155, 0.04295437203836627, 0.05172685443540104, 0.046234464389272034, 0.02863212601369014, 0.03339919101563282, 0.10256235240376554, 0.05853685717738699, 0.03776152392674703, 0.01569423588080099, 0.06381340470397845, 0.15863255190197378, 0.0759863483835943, 0.04208208505588118, 0.007250032304000342, 0.05347752885427326, 0.023077662735886406, 0.0815283584233839, 0.029034921099082567, 0.011628187803580659, 0.06114431882451754, 0.009021196492540184, 0.01847803552664118, 0.0073982957837870345, 0.01944944931892678, 0.026798524013429414, 0.06062411041057203, 0.0681166589492932, 0.039444700014428236, 0.044880924324388616, 0.06137806565675419, 0.10292662816937082, 0.004111513435418601, 0.10992761148372665, 0.01873276472906582, 0.07450711447745562, 0.06601854067412205, 0.04204688870231621, 0.03023897221282823, 0.050583167758304626, 0.05318839925166685, 0.026485154012334533, 0.12815207184758037, 0.014727089437656105, 0.02906256795540685, 0.05322584431269206, 0.0033530851260366035, 0.027553080399229657, 0.036007276066811755, 0.10037870903033763, 0.01680113058682764, 0.05159703054232523, 0.05361436604289338, 0.1270278071751818, 0.050463670850149356, 0.017154775086964946, 0.04926279427309055, 0.03245040345063899, 0.003978366112278309, 0.026922201068373397, 0.03351868050231133, 0.028738568544213194, 0.019986324514320586, 0.03143248482956551, 0.022952416038606316, 0.018844224177883007, 0.052637072585639544, 0.04007286122941878, 0.03129863107460551, 0.01974525825062301, 0.03684860435896553, 0.035909731886931695, 0.024297822164953686, 0.044304116017883644, 0.02003899102419382, 0.017977089555643033, 0.04798920577741228, 0.053603571504936554, 0.0366222233424196, 0.04160071322985459, 0.017736203262757044, 0.03612124397477601, 0.04806074510270264, 0.0873470411170274, 0.0033282280492130667, 0.022403861294151284, 0.04452882720215712, 0.03263408871134743, 0.003412147789276787, 0.04027299990411848, 0.05912723936489783, 0.043913883637287654, 0.03601329488446936, 0.023290171156986617, 0.0328768823237624, 0.002387466579421016, 0.04405046107422095, 0.1006102813698817, 0.015788240016263444, 0.06169216110720299, 0.04435851544258185, 0.10876384229050018, 0.08031467237742618, 0.04510281163675245, 0.03186018453561701, 0.031989065901143476, 0.06688432273222134, 0.043410763173596933, 0.0829341122880578, 0.06461544369813055, 0.05387114913901314, 0.12495795730501413, 0.10275948166963644, 0.010630708857206628, 0.02962225491501158, 0.028304085608397145, 0.1100076075817924, 0.19680426456034184, 0.2642067993292585, 0.468726193648763, 0.428895988734439, 0.4898490820778534, 0.7348908972926438, 0.6250154587905854, 0.4739764431724325, 0.5070856993552297, 0.6988912727683783, 0.6716714927460998, 0.5225052125751972, 0.4708147159544751, 0.8330309623852372, 0.21247693919576705, 0.1901437563356012, 0.07281982689164579, 0.08452633817796595, 0.02154566769604571, 0.06085098495532293, 0.09131560902460478, 0.08671062721987255, 0.047621653429814614, 0.0481601038336521, 0.11092560715042055, 0.0666549323068466, 0.03259508514020126, 0.01612679294339614, 0.06880530519993044, 0.04742085795442108, 0.028129656784585677, 0.04537891654763371, 0.06656283178017475, 0.04454520640138071, 0.022550327848875895, 0.023987732456589583, 0.018438265688018873, 0.03270726076152641, 0.08610591044998728, 0.046242394237197004, 0.033406237707822584, 0.014488404540315969, 0.014978734088799683, 0.04387354048958514, 0.04239402085659094, 0.02257131207443308, 0.021181813099246938, 0.022515817981911823, 0.014937048581487034, 0.0652739439101424, 0.07110700942575932, 0.046425374457612634, 0.021775310451630503, 0.18859072326449677, 0.017382163568981923, 0.01333913784037577, 0.03612718115618918, 0.04399879646371119, 0.08413701492827386, 0.03863208541588392, 0.03153135745378677, 0.05557048549235333, 0.025142987360595725, 0.042455110742594115, 0.06213947206560988, 0.018995358841493726, 0.031021976974443533, 0.03511604205414187, 0.054671221441822127, 0.03359548907610588, 0.058784827269846573, 0.06001778689096682, 0.05360397226468194, 0.01620642167836195, 0.030589696361857932, 0.017050703718268778, 0.061801264237146825, 0.03340666815347504, 0.056161906686611474, 0.09102383366553113, 0.03153135003231, 0.01016235708448221, 0.01943071751156822, 0.0431102193397237, 0.014434006043302361, 0.028870526111859363, 0.06495978537714109, 0.05261091188003775, 0.025471241133345757, 0.041127423392026685, 0.01595674650161527, 0.040252305116155185, 0.03190495088347234, 0.029319415989448316, 0.051969666601507924, 0.04281499299395364, 0.010493869813217316, 0.09808752845856361, 0.13209363300120458, 0.13087872241158038, 0.1016802505182568, 0.1647666993085295, 0.06559343848493882, 0.22782038227887824, 0.10611119127133861, 0.07198343388154171, 0.08482934965286404, 0.1306107031996362, 0.14996609272202477, 0.13188725657528266, 0.1046922271780204, 0.1101639706757851, 0.20595371344825253, 0.14480984362307936, 0.13030808506300673, 0.18204950785730034, 0.16417100705439225, 0.09557380006299354, 0.08091133684501983, 0.09197682549711317, 0.04905198722553905, 0.1343649611226283, 0.12006035409285687, 0.08311554513056763, 0.11203634247067384, 0.08883547765435651, 0.12823327764635906, 0.10893605023738928, 0.14011114340974018, 0.21350833150791004, 0.1888583120307885, 0.21793144260300323, 0.11182195084984414, 0.07962926931213588, 0.11454457897343673, 0.16960432956693694, 0.1253022692981176, 0.13428359205136076, 0.2959332265891135, 0.0992717215558514, 0.13826350739691406, 0.14408960414584726, 0.11378269759006798, 0.1003650386701338, 0.10057017570943572, 0.14080785680562258, 0.19046339933993295, 0.13991619605803862, 0.13261732208775356, 0.06730797031195834, 0.16474873933475465, 0.13857384386938065, 0.1466425773105584, 0.18548922875197604, 0.2154379599960521, 0.30868706409819424, 0.19344352302141488, 0.1614432135829702, 0.128830409666989, 0.1219769949966576, 0.23717999254586175, 0.13326561776921153, 0.15370535926194862, 0.17621790437260643, 0.22605076082982123, 0.22529739188030362, 0.14477131131570786, 0.16105686634546146, 0.17558028077473864, 0.1964626688277349, 0.32458849833346903, 0.18302510550711304, 0.15727062185760587, 0.14338809647597373, 0.09957768677850254, 0.2997808763757348, 0.26784109650179744, 0.5532399821095169, 0.9118517953902483, 0.7010930764954537, 0.7021738216280937, 1.0178873618133366, 1.0113867418840528, 0.7631233823485672, 1.0059936437755823, 0.9238320775330067, 1.0477465158328414, 0.8791797829326242, 0.6854693242348731, 0.9147230163216591, 0.3833508014213294, 0.4011039831675589, 0.19100874429568648, 0.16675287944963202, 0.11894023060449399, 0.19276815379271284, 0.28735901636537164, 0.13830511219566688, 0.1258285707444884, 0.1829212493612431, 0.31545856792945415, 0.255785976187326, 0.14821769669651985, 0.09572851558914408, 0.12005351149127819, 0.0974223563389387, 0.11407842859625816, 0.16137201193487272, 0.24260884732939303, 0.1027959656494204, 0.0939540182298515, 0.11064810329116881, 0.1459454037831165, 0.13732317660469562, 0.16334550135070458, 0.13066686893580481, 0.08733017210033722, 0.15028103051008657, 0.1191095144895371, 0.153884454339277, 0.1595964829903096, 0.13432731939246878, 0.12616829626495019, 0.21346173947677016, 0.25753685098607093, 0.10054279046016745, 0.18495121621526778, 0.21124887774931267, 0.15258863480994478, 0.22350463026668876, 0.14998095051851124, 0.07114446561899967, 0.07853354021790437, 0.13885303982533514, 0.18656866770470515, 0.1153377938317135, 0.09168896867777221, 0.21902533859247342, 0.12017116416245699, 0.10268739686580375, 0.12701673433184624, 0.13876886543584988, 0.12935053644469008, 0.14981466491008177, 0.1331612272770144, 0.14288297592429444, 0.21109709370648488, 0.1614558746223338, 0.10488866624655202, 0.1817983205546625, 0.13781214802293107, 0.14107704861089587, 0.25840623246040195, 0.12036263826303184, 0.10920726068434305, 0.2414612495340407, 0.13907537242630497, 0.13451664126478136, 0.12841106654377654, 0.13185176707338542, 0.07669407525099814, 0.16126423724927008, 0.18688062205910683, 0.12476183735998347, 0.1648421460413374, 0.1791924174176529, 0.18370924692135304, 0.106383240345167, 0.21468056860612705, 0.07763567511574365, 0.1629604009212926, 0.12819753581425175, 0.12711840856354684], [0.07985952062881552, 0.042310147036914714, 0.0339194291154854, 0.009929087082127808, 0.03968686651205644, 0.04737759445561096, 0.006711255355185131, 0.008763696296227863, 0.015326517477660673, 0.027365942296455614, 0.0476457806507824, 0.020737173872475978, 0.003193465163349174, 0.02973068825667724, 0.06696327982353978, 0.02909448216087185, 0.01823118051106576, 0.057533443832653575, 0.03509097972710151, 0.05261432204861194, 0.05982416798360646, 0.04449384236067999, 0.01846500155807007, 0.012054765938955825, 0.03483745837002061, 0.03610209285398014, 0.028142256596765947, 0.029551442894444335, 0.02681420559383696, 0.04199734663416166, 0.025525230521452613, 0.06781932490412146, 0.0254424161175848, 0.048780175638967194, 0.03341425661346875, 0.016699998122930992, 0.029529228559113108, 0.06085112596338149, 0.011303021365165478, 0.04777928188559599, 0.08477400027913973, 0.035932567770942114, 0.037928570236545056, 0.030926674080546945, 0.0037054830499982927, 0.05844594408699777, 0.10493577035958879, 0.04301094224501867, 0.027541096569621004, 0.016516618998139165, 0.03494206779578235, 0.05111884624056984, 0.035997809973196127, 0.045494335354305804, 0.08289410310680978, 0.006373011810865137, 0.03613108485296834, 0.06641450614552014, 0.0709130046016071, 0.047040451609063894, 0.053858473256696016, 0.008302060959977098, 0.010067371458717389, 0.09969916893169284, 0.06472082124673761, 0.02832755788404029, 0.04021653359814081, 0.0450897424161667, 0.07151490121032111, 0.014880768740113126, 0.08526461184374057, 0.0903133385872934, 0.18476814322639257, 0.33275618974585086, 0.14658890519058332, 0.1361041990458034, 0.14380218519363552, 0.13924744678661227, 1.4834263874217868, 3.21546892169863, 4.344461727887392, 7.176914289593697, 12.446551322937012, 18.606909960508347, 16.937055364251137, 13.118075989186764, 6.932607823982835, 12.085338905453682, 13.031528983265162, 19.328536838293076, 16.440028734505177, 9.851716160774231, 10.1996710896492, 2.332650893367827, 1.5046250936575234, 0.8868221822194755, 0.6546620617154986, 0.07016874180408195, 0.48159666708670557, 0.5157273262739182, 0.1104486733675003, 0.03206179266271647, 0.06254400563193485, 0.03960455862397794, 0.16926448530284688, 0.009136623648373643, 0.09031115667312406, 0.11042737372918054, 0.060383506133803166, 0.020109329925617203, 0.05039086245233193, 0.004455681173567427, 0.05480679697939195, 0.13597996352473274, 0.019762201482080854, 0.048927421448752284, 0.029266204001032747, 0.03753212236915715, 0.006267378221309627, 0.045386968849925324, 0.031285691729863174, 0.038540385648957454, 0.025364310640725307, 0.013884645140933571, 0.04337256854341831, 0.07815183140337467, 0.030932666923035868, 0.05450947777717374, 0.03822152932116296, 0.05729921089368872, 0.020828485867241398, 0.023721930410829373, 0.0636294337164145, 0.028251456205907743, 0.10354313024436124, 0.021481267831404693, 0.027629085598164238, 0.018966426214319654, 0.060362848453223705, 0.01864270139776636, 0.09779181971680373, 0.017937638840521686, 0.0994541562977247, 0.05129621582455002, 0.051514333026716486, 0.04036783895571716, 0.0111709552584216, 0.07410663674818352, 0.0216635003380361, 0.04593054378347006, 0.05439961765659973, 0.00948624663578812, 0.024761039203440305, 0.024445316594210453, 0.024314778383995872, 0.026508069677220192, 0.032948447624221444, 0.10949970397632569, 0.01556978328153491, 0.014671623175672721, 0.0748711230698973, 0.0374143917724723, 0.06356084442813881, 0.022199126869963948, 0.06932126852916554, 0.029799227449984755, 0.06136150463134982, 0.02267599385959329, 0.06611694203456864, 0.07318952775676735, 0.0061349837142188335, 0.030703122502018232, 0.016916104104893748, 0.01640139500523219, 0.050255750757060014, 0.04083397077920381, 0.04059955601405818, 0.060431541642174125, 0.043310743931215256, 0.09200517553836107, 0.016104556343634613, 0.05397288274252787, 0.051269290706841275, 0.03660186623164918, 0.013098696836095769, 0.013864531083527254, 0.08949838622356765, 0.02316050868103048, 0.022610606938542333, 0.0325243881525239, 0.012794509057130199, 0.021145820792298764, 0.006714778701280011, 0.12279665257665329, 0.058085208365810104, 0.04757854578201659, 0.048281270574079826, 0.06627512339036912, 0.025547563600412104, 0.013176144584576832, 0.039580847005709074, 0.0301561169908382, 0.031312865467043594, 0.027180153047083877, 0.024949325779743958, 0.05799104466859717, 0.017058869198081084, 0.04947624336637091, 0.023053735894791316, 0.00997568746242905, 0.03042095609998796, 0.027358429906598758, 0.0632217200472951, 0.010649550131347496, 0.040216500201495364, 0.09545573921059258, 0.05903779572690837, 0.013781562684016535, 0.0027050682137996773, 0.06950584065634757, 0.05432730649772566, 0.031208263462758623, 0.05692274535249453, 0.020110918121645227, 0.036875856021652, 0.025017204461619258, 0.0767028474365361, 0.09052003413671628, 0.03365034492162522, 0.02743658176768804, 0.11125018543680198, 0.08555971944588237, 0.030293970921775326, 0.040066731089609675, 0.11322199017740786, 0.037528099928749725, 0.0918332050787285, 0.019684637773025315, 0.027668590118992142, 0.020411565856193192, 0.02984117734740721, 0.0678089348366484, 0.055271630044444464, 0.041566589279682375, 0.04757805225381162, 0.01851802986493567, 0.16455441538710147, 0.1627945902873762, 0.4309899138752371, 0.45138285553548485, 0.2183265471830964, 0.08348576549906284, 0.04262522954377346, 0.8302120480220765, 3.3649308141320944, 5.736732194200158, 9.193123150616884, 12.891024872660637, 19.97907143086195, 28.014908730983734, 27.318246513605118, 20.064827129244804, 11.393129099160433, 18.953493162989616, 22.43718422949314, 30.500323064625263, 27.0915886759758, 15.61046864837408, 17.066683508455753, 5.997135071083903, 3.577108816243708, 1.169937034137547, 1.4500125241465867, 0.08444595616310835, 0.14728692476637661, 0.4233478708192706, 0.15920405014185235, 0.027636633240035735, 0.018161839798267465, 0.11068647974752821, 0.06984021529206075, 0.061406924069160596, 0.07905885460786521, 0.11031257090508007, 0.07735267936368473, 0.061647591428481974, 0.011306692213111091, 0.030632139787485357, 0.014975736739870626, 0.09626992716221139, 0.05408217140939087, 0.03390935075003654, 0.04365421358670574, 0.009300647561758524, 0.01180709085019771, 0.0010324008212592162, 0.03365998541994486, 0.04593262179696467, 0.0255957456829492, 0.02045874047325924, 0.03396137530216947, 0.034102220088243484, 0.07247377827297896, 0.05845324682013597, 0.04054567980347201, 0.0929476140299812, 0.0748177403875161, 0.00644992614070361, 0.06134861723694485, 0.07673360203625634, 0.06590878445422277, 0.020788883011846337, 0.02950556703581242, 0.033824738493422046, 0.053061744329170324, 0.007718023207416991, 0.0478695789934136, 0.018608968930493575, 0.06673984142253175, 0.02101000220136484, 0.04455243491975125, 0.11152159626362845, 0.031107420436455868, 0.074933864234481, 0.020458593899093103, 0.0650673893687781, 0.025407353350601625, 0.11362925855792128, 0.041294499387731776, 0.07061133641400374, 0.04191371401248034, 0.04607134404068347, 0.03487843234324828, 0.02188621885579778, 0.011406831126805628, 0.03222349921998102, 0.06628406626987271, 0.0216363228901173, 0.10475992588908412, 0.045011998736299574, 0.03452511067735031, 0.023844805946282577, 0.009991984097723616, 0.07576324394904077, 0.07312628935324028, 0.02481816973158857, 0.04771716041432228, 0.014205229745130055, 0.03493073891149834, 0.02604179684567498, 0.04262273221684154, 0.10745612613391131, 0.1435828211833723, 0.14641499030403793, 0.0707292859442532, 0.16099313070299104, 0.06545147305587307, 0.17375272727804258, 0.26569777401164174, 0.07583267186419107, 0.13546883157687262, 0.1102441745752003, 0.1800123866996728, 0.09674221510067582, 0.13581354432972148, 0.1195930756512098, 0.1630265114363283, 0.10737074946518987, 0.1986396699794568, 0.3045070212101564, 0.09195571881718934, 0.14175324904499575, 0.18700573331443593, 0.24763817433267832, 0.16091606608824804, 0.10136732395039871, 0.15344542945967987, 0.12816403526812792, 0.2417672667070292, 0.09164018731098622, 0.09967090794816613, 0.26366265665274113, 0.08351254960871302, 0.16808341664727777, 0.10277275127009489, 0.14275235793320462, 0.09609451313735917, 0.09606335777789354, 0.1901958996313624, 0.093357984587783, 0.10729090921813622, 0.13722675677854568, 0.2664916048524901, 0.14829952589934692, 0.10730868365499191, 0.11644732687273063, 0.25957517442293465, 0.13861252460628748, 0.2244346303632483, 0.10856761844479479, 0.14651941048214212, 0.08650077754282393, 0.1728273878688924, 0.17015719990013167, 0.11854411670356058, 0.08245677032391541, 0.2537199854850769, 0.23246450495207682, 0.19351899944012985, 0.13178722991142422, 0.23030411306535825, 0.172831944655627, 0.19478059111861512, 0.07142495291191153, 0.15442311996594071, 0.17980933509534225, 0.20724561443785205, 0.16971271281363443, 0.16724654124118388, 0.2111581724602729, 0.22010412445524707, 0.10070098665892147, 0.3267173341009766, 0.27661972388159484, 0.62137151369825, 0.47004870080854744, 0.35426113579887897, 0.1928152801701799, 0.1938769075786695, 0.7800349092576653, 3.6355195194482803, 6.3825958874076605, 10.626594331115484, 14.607824049890041, 21.070948541164398, 30.370066054165363, 29.388732612133026, 21.78439635783434, 12.45661698281765, 19.80952262878418, 23.281356431543827, 35.41073687374592, 31.493794955313206, 16.527211256325245, 16.837665997445583, 7.639513341709971, 4.019483216106892, 1.584560216870159, 1.2351323920302093, 0.11152994542499073, 0.41594289941713214, 0.6805235927458853, 0.46946872724220157, 0.1337654987582937, 0.1260911871213466, 0.2702834451338276, 0.4409145063254982, 0.13901730679208413, 0.21912545431405306, 0.31402375898323953, 0.1867242218577303, 0.16732048883568496, 0.23792307532858104, 0.19952254369854927, 0.24769413226749748, 0.2768958918750286, 0.09343437384814024, 0.11668700346490368, 0.11508388284710236, 0.09932539367582649, 0.11666476129903458, 0.16127214854350314, 0.21474630804732442, 0.19647941167932004, 0.12767794338287786, 0.12554830609587952, 0.09429833764443174, 0.1852021660306491, 0.13579294231021777, 0.23074671509675682, 0.12327181262662634, 0.24552343937102705, 0.11170679921633564, 0.08696128017618321, 0.17791843187296763, 0.13221282191807404, 0.12916844309074804, 0.1146325383160729, 0.11015607422450557, 0.07637812072061934, 0.10302968279574998, 0.11501850705826655, 0.15584528271574527, 0.19538487744284794, 0.17322909756330773, 0.09211847180267796, 0.12194273003842682, 0.2586091950070113, 0.17252039106097072, 0.21689515211619437, 0.09711780861834995, 0.19867392751621082, 0.1197395236522425, 0.23981636826647446, 0.13388088787905872, 0.15766816068207845, 0.16093715792521834, 0.10911195407970808, 0.13111799082253128, 0.22559631412150338, 0.09989699581637979, 0.1261273742420599, 0.16681562061421573, 0.1350742910290137, 0.17587570007890463, 0.17089121363824233, 0.22889373562065884, 0.09501586086116731, 0.11009112145984545, 0.14499443059321493, 0.11119868780951947, 0.15662753605283797, 0.09555398472002707, 0.11523340333951637, 0.16702931461622939, 0.11019724857760593, 0.15377100964542478, 0.11272543400991708], [0.0358933304232778, 0.030159796187945176, 0.03109699140622979, 0.018423591573082376, 0.016962666450126562, 0.05298375945130829, 0.02336165667657042, 0.011600931502471212, 0.03318917806609534, 0.038223907904466614, 0.03127267074887641, 0.02599963358079549, 0.010659644267434487, 0.055408044208888896, 0.0027870718213307555, 0.032830282871145755, 0.049968502498813905, 0.02175890713260742, 0.03532061506120954, 0.07116147564374842, 0.06458045885665342, 0.06309810793027282, 0.03262464117142372, 0.00999387564661447, 0.08320104054291733, 0.035163097927579656, 0.03674541243526619, 0.05909540494030807, 0.04378911748062819, 0.04255910789652262, 0.07061436437652446, 0.036214791689417325, 0.020491474751906935, 0.05623363525955938, 0.08578545108321123, 0.02358878540690057, 0.00521046994435892, 0.08729101638891734, 0.022764485693187453, 0.06527724646730348, 0.06665079112281092, 0.04111646929231938, 0.01666581109020626, 0.03847243460768368, 0.014930904526408995, 0.011232979322812753, 0.004986746744179982, 0.04996971219952684, 0.061482378223445266, 0.013506074683391489, 0.044480947544798255, 0.10110326780704781, 0.010469939261383843, 0.0458155813976191, 0.074483172793407, 0.04640286511857994, 0.11472300611785613, 0.01678202213952318, 0.07513400661991909, 0.027815216235467233, 0.1160566826001741, 0.047685678509878926, 0.061879872519057244, 0.034368870037724264, 0.0772855817922391, 0.03654225693026092, 0.21684605162590742, 0.17224094277480617, 0.006832632680016104, 0.24541450693504885, 1.1622867383994162, 2.9876127233728766, 11.107271388173103, 26.377255506813526, 23.73731106519699, 36.747459545731544, 44.40667815506458, 67.352434694767, 84.7917129099369, 90.51620453596115, 100.28857335448265, 108.81623536348343, 117.28876233100891, 120.56160271167755, 118.64085137844086, 110.92857241630554, 109.81891795992851, 130.97555190324783, 126.54843986034393, 128.2956165075302, 126.17820292711258, 120.17911523580551, 121.18710234761238, 96.83208882808685, 89.13210600614548, 76.19926437735558, 75.47917261719704, 55.8758345246315, 38.390449583530426, 10.73704395443201, 1.2709077098406851, 0.45139348309021443, 0.2810950228013098, 0.599394739838317, 0.6992513628210872, 0.24394882464548573, 0.04875584061664995, 0.08592845551902428, 0.03159723419230431, 0.009948184397217119, 0.05862701698788442, 0.07979263828019612, 0.05877864146896172, 0.06330518197501078, 0.024017238392843865, 0.05566993328102399, 0.052233206952223554, 0.031099334737518802, 0.054780365389888175, 0.03886879712808877, 0.031137113764998503, 0.03464780995273031, 0.05541864207771141, 0.007972510284162126, 0.01211676959428587, 0.07517782301874831, 0.03637868016085122, 0.034004308545263484, 0.06092458374041598, 0.07738402026006952, 0.036276575483498164, 0.057268986929557286, 0.028238672712177504, 0.031214360205922276, 0.04578434811264742, 0.08420502534136176, 0.019981539517175406, 0.008498630832036724, 0.039770747753209434, 0.0327833976916736, 0.020412604862940498, 0.0024272074278997025, 0.0320278579602018, 0.03816854368778877, 0.022204735651030205, 0.03526292792230379, 0.03482949883618858, 0.10795295689604245, 0.04945247979776468, 0.01620621573238168, 0.0424514408223331, 0.007753198224236257, 0.02159837316867197, 0.030946515398682095, 0.023904626759758685, 0.035479460639180616, 0.04772922031406779, 0.018765283784887288, 0.018675393002922647, 0.022038774732209276, 0.04178370087174699, 0.03797696568653919, 0.10352750061429106, 0.039278173208003864, 0.024245697422884405, 0.01577985745825572, 0.01426448467100272, 0.03779700229642913, 0.0485207430756418, 0.030030979760340415, 0.030321328340505715, 0.05184707493754104, 0.05179071995371487, 0.05034648573200684, 0.07224717832286842, 0.023525057185906917, 0.04714811126177665, 0.04611661504895892, 0.04469309787964448, 0.017640258411120158, 0.06975558077101596, 0.05753596342401579, 0.03551985202648211, 0.026172084581048694, 0.02498229754564818, 0.06364512271829881, 0.02465665056661237, 0.03463341599854175, 0.010402365787740564, 0.02576807793957414, 0.022023477213224396, 0.03460569307208061, 0.10328031348763034, 0.0316709368780721, 0.03643239680968691, 0.024532340830774046, 0.03694937317050062, 0.036889415059704334, 0.025800103467190638, 0.013820286094414769, 0.07361356867477298, 0.025165398365061264, 0.033026528981281444, 0.020566708117257804, 0.009157000240520574, 0.015783328854013234, 0.012772587870131247, 0.05394059560785536, 0.05454691912746057, 0.05867514155397657, 0.0281318424094934, 0.0185376318404451, 0.041959530499298126, 0.038275895349215716, 0.04152706991590094, 0.05369146405428182, 0.022536920951097272, 0.046653937388327904, 0.008509244471497368, 0.036403211852302775, 0.05364706878026482, 0.039290533677558415, 0.050902179937111214, 0.0469701813563006, 0.03723615387571044, 0.003711818671945366, 0.019179164701199625, 0.038551566103706136, 0.01137239547460922, 0.016558001152588986, 0.028782811677956488, 0.07462888606823981, 0.10183006786974147, 0.05532320930797141, 0.05760008869401645, 0.0504360184277175, 0.12692003248957917, 0.041012724468600936, 0.02392167574726045, 0.12201402816572227, 0.02405516028375132, 0.15257257473422214, 0.21955585543764755, 0.21718093834351748, 0.04505116929067299, 0.6027418852318078, 2.704147221520543, 5.771797662600875, 17.14665211737156, 39.27020877599716, 35.42806774377823, 52.164756059646606, 63.55065129697323, 91.48330584168434, 109.87470656633377, 115.99932432174683, 124.92205113172531, 130.8937954902649, 142.07685381174088, 147.65849590301514, 142.58848875761032, 135.39833217859268, 133.48030149936676, 155.99948912858963, 148.96985113620758, 151.27234518527985, 149.52367901802063, 142.54865169525146, 143.8585326075554, 126.63757547736168, 118.16090673208237, 102.73577123880386, 101.8882267177105, 79.36274662613869, 57.591184079647064, 19.704165682196617, 3.4313443629071116, 1.1605541501194239, 0.15039910620544106, 0.32891679264139384, 0.6040995405055583, 0.27328884636517614, 0.03381313130375929, 0.0252034575532889, 0.04673669798648916, 0.09133561732596718, 0.04966912012605462, 0.021470426909218077, 0.03182414955517743, 0.029484237711585592, 0.027448443142930046, 0.043241416206001304, 0.08601352048572153, 0.01768716214428423, 0.045055228838464245, 0.030806336690147873, 0.04917941027088091, 0.050250770946149714, 0.04912439486361109, 0.057655063283164054, 0.039961568763828836, 0.06505624973215163, 0.02608142382086953, 0.02100047673593508, 0.030107634338492062, 0.01526714473584434, 0.024143353402905632, 0.040797082328936085, 0.08357609229278751, 0.01429046540579293, 0.008982153958640993, 0.050040479691233486, 0.03220242964744102, 0.07040953161776997, 0.05145320603332948, 0.009732972703204723, 0.02164444940717658, 0.02796835655317409, 0.04139932032558136, 0.0773610062606167, 0.034536795792519115, 0.05369691512896679, 0.07274361574673094, 0.004375371518108295, 0.01249356353582698, 0.051866856883862056, 0.02971989000798203, 0.04181257783784531, 0.036190957616781816, 0.03663829826109577, 0.06550685211550444, 0.044177045492688194, 0.044136962096672505, 0.041607040038798004, 0.05573832961090375, 0.04760635034472216, 0.04264122653694358, 0.009389118058606982, 0.04010205731901806, 0.05296369919960853, 0.03863827121676877, 0.04179724877758417, 0.05524686086573638, 0.023335590594797395, 0.023068604823492933, 0.011997665096714627, 0.026645159196050372, 0.035618409237940796, 0.03303441058960743, 0.012685551573667908, 0.02398133699898608, 0.03200132618076168, 0.13693052111193538, 0.11832162825157866, 0.13789497170364484, 0.15196551277767867, 0.2042328065726906, 0.13988358608912677, 0.13670052954694256, 0.10831257197423838, 0.07788745613652281, 0.18649264209670946, 0.10010222933487967, 0.1159833138808608, 0.10558313835645095, 0.15232929872581735, 0.0922804455331061, 0.1431372357183136, 0.1396038112579845, 0.14676988532301039, 0.16630261845421046, 0.1399406127166003, 0.1577974873362109, 0.19639032427221537, 0.09937023423844948, 0.1184628218470607, 0.1573082190589048, 0.12112185533624142, 0.1216123036283534, 0.13536193262552842, 0.07627960803802125, 0.08547201243345626, 0.1523035907302983, 0.15496945939958096, 0.0917439247132279, 0.1363522990141064, 0.1707184565020725, 0.07822117768228054, 0.12462051759939641, 0.123295657831477, 0.18583855766337365, 0.15272458142135292, 0.10434778159833513, 0.10616573170409538, 0.12610510981176049, 0.1100151997525245, 0.13676987582584843, 0.13757096487097442, 0.0912394498300273, 0.13663845631526783, 0.21752943604951724, 0.14473156188614666, 0.22179460327606648, 0.26588544831611216, 0.2016265768907033, 0.13790821161819622, 0.12005560434772633, 0.17218936351127923, 0.2537553710862994, 0.16446823719888926, 0.19318791251862422, 0.1522718564956449, 0.18136193772079423, 0.19502973009366542, 0.07596389099489897, 0.15769766847370192, 0.19367525121197104, 0.24601260374765843, 0.4824757558526471, 0.3566979628521949, 0.18616296525578946, 0.7238669169601053, 3.1123236939311028, 6.406388785690069, 18.064473867416382, 43.399538397789, 42.56648629903793, 58.78979556262493, 72.207882553339, 104.97024893760681, 126.0350190103054, 129.76090908050537, 141.53203904628754, 146.62914633750916, 157.895085811615, 160.36481648683548, 160.02751618623734, 148.88149827718735, 148.4116306900978, 171.33973717689514, 166.6751378774643, 168.05037528276443, 171.3230636715889, 163.69460821151733, 161.22762858867645, 144.31324660778046, 133.91822040081024, 118.0707223713398, 112.11072698235512, 88.89389678835869, 61.72305956482887, 22.095137983560562, 3.6871062638238072, 1.2541341036558151, 0.3476750204572454, 0.6499080418143421, 0.9921377466525882, 0.5513754696585238, 0.12878018111223355, 0.21206013421760872, 0.18269660125952214, 0.1878225855762139, 0.16874731227289885, 0.304101689835079, 0.12087433424312621, 0.09846030181506649, 0.1436803097021766, 0.09327755804406479, 0.12307333265198395, 0.15377630857983604, 0.16953620041022077, 0.12886156502645463, 0.15382876357762143, 0.18211422313470393, 0.1376501371851191, 0.1590461062733084, 0.14301215414889157, 0.20496245648246258, 0.14483823819318786, 0.1285807363456115, 0.11366854043444619, 0.1653241115855053, 0.11865989174111746, 0.14756114833289757, 0.23962679406395182, 0.20236496930010617, 0.09323768987087533, 0.20164422516245395, 0.10137563600437716, 0.14145091292448342, 0.12196357696666382, 0.10742509693955071, 0.08351148833753541, 0.0950622970412951, 0.1261466700816527, 0.19762800395255908, 0.13514863938326016, 0.10606817639200017, 0.09307765314588323, 0.21845689800102264, 0.09177822677884251, 0.12354857433820143, 0.15651760913897306, 0.16263208963209763, 0.12421943130902946, 0.13163013209123164, 0.12551716557936743, 0.11294919895590283, 0.2810083993244916, 0.07433630918967538, 0.1719456719001755, 0.1244199818756897, 0.18235510942758992, 0.23943183186929673, 0.24123143608449027, 0.14165494416374713, 0.1000338552694302, 0.21659431513398886, 0.18283234006958082, 0.21266507363179699, 0.13329105859156698, 0.08512275031534955, 0.13309388479683548, 0.10767571278847754, 0.1045211695600301, 0.14229335443815216, 0.1466490636812523, 0.11381420175894164], [0.04878567866398953, 0.04249188415997196, 0.012840420167776756, 0.05943442170973867, 0.023408872111758683, 0.016877373273018748, 0.022931574676476885, 0.1035322280949913, 0.011149596248287708, 0.039602031611138955, 0.017507792472315487, 0.024099499896692578, 0.013686064976354828, 0.06222895652172156, 0.047973464825190604, 0.03647096251370385, 0.018707325762079563, 0.011650069100141991, 0.09743921793415211, 0.005902325519855367, 0.07138644286897033, 0.05956414170213975, 0.03295127520686947, 0.019916434612241574, 0.014946221526770387, 0.03322044474771246, 0.006713332440995146, 0.0323830758134136, 0.03172890232235659, 0.05484336259542033, 0.006488474218713236, 0.02716284987400286, 0.04984108316421043, 0.04146701903664507, 0.046925281421863474, 0.02206098350143293, 0.006920315572642721, 0.04917093123367522, 0.01687223575572716, 0.03692512349516619, 0.05542338440136518, 0.016873538224899676, 0.05026459344662726, 0.04083207830262836, 0.06518946524010971, 0.05016562434320804, 0.04682588558353018, 0.025422350299777463, 0.04961075392202474, 0.0392923742037965, 0.07453957601683214, 0.02486629058694234, 0.0017297451586273382, 0.043589097549556755, 0.05135961007908918, 0.04746854094264563, 0.04156970629992429, 0.01390352630551206, 0.12174420553492382, 0.026109579048352316, 0.09113491090829484, 0.03506857799948193, 0.12631430639885366, 0.28285320033319294, 0.03510925882437732, 0.7064208062365651, 7.0588973723351955, 18.121400512754917, 40.11817127466202, 63.79635751247406, 73.89060705900192, 92.32729375362396, 100.39325773715973, 112.75499001145363, 113.4279415011406, 112.55424678325653, 110.54046124219894, 96.25614613294601, 99.79007810354233, 89.35569360852242, 92.56427943706512, 88.3522966504097, 86.73500463366508, 89.59982290863991, 98.42907473444939, 100.3677687048912, 96.97620749473572, 91.88371315598488, 101.95517912507057, 91.446653008461, 99.68837276101112, 105.94046607613564, 101.94669038057327, 106.58947125077248, 113.3516263961792, 122.37088322639465, 113.35578337311745, 125.70172369480133, 130.98415464162827, 113.70419427752495, 89.44929778575897, 78.7667790055275, 50.905515030026436, 31.064535789191723, 15.749388244003057, 2.9705402394756675, 0.2826884435489774, 0.2967279776930809, 0.12247838254552335, 0.03913152853783686, 0.022650452847301494, 0.06292641948675737, 0.03666291158879176, 0.08226379708503373, 0.04089061148988549, 0.09844771499047056, 0.052567392340279184, 0.023670545961067546, 0.01849701780884061, 0.04848981407121755, 0.04418945791258011, 0.0243856609085924, 0.09657280505052768, 0.04341324565757532, 0.018820842815330252, 0.039381283495458774, 0.02896640231483616, 0.029729578745900653, 0.053751162413391285, 0.027666781134030316, 0.019983984893769957, 0.04265425122866873, 0.027410031434556004, 0.03303695244539995, 0.026805672750924714, 0.02398930209892569, 0.033434895740356296, 0.09459800203330815, 0.00722493518878764, 0.09129792364547029, 0.03603705845307559, 0.01805747528123902, 0.03161185450153425, 0.01039112132275477, 0.046139332189341076, 0.03963328716054093, 0.04999726443202235, 0.03540945013810415, 0.10760719771496952, 0.019694074180733878, 0.021474117238540202, 0.05588251406152267, 0.041945448247133754, 0.01568016847159015, 0.028641814751608763, 0.06970558970351703, 0.07218034050310962, 0.058609814004739746, 0.04968108725734055, 0.04989176813978702, 0.051959269112558104, 0.05549518718908075, 0.0839058359269984, 0.01579066683916608, 0.07000860117841512, 0.030910972091078293, 0.10399216669611633, 0.024617294475319795, 0.0931657015462406, 0.03751915704924613, 0.05259043973637745, 0.09036655799718574, 0.023451829474652186, 0.0508704011735972, 0.0023249981541084708, 0.018439482810208574, 0.06498438757262193, 0.031389492214657366, 0.05669661295542028, 0.02067971865471918, 0.03143902686133515, 0.028348362138785888, 0.019808038377959747, 0.056656284650671296, 0.03700091161590535, 0.023597229192091618, 0.018458155245753005, 0.043659594157361425, 0.03770649367652368, 0.05896763308555819, 0.007662698417334468, 0.07416405671392567, 0.12787305400706828, 0.008696637687535258, 0.04462699478608556, 0.016065977652033325, 0.022779143109801225, 0.04651698887755629, 0.03532286747940816, 0.04706677187641617, 0.060335396410664544, 0.03753186632820871, 0.042269729674444534, 0.037004874684498645, 0.029141506493033376, 0.03309437612188049, 0.04588215204421431, 0.04161757853580639, 0.055375979718519375, 0.01226809443323873, 0.03688750774017535, 0.0383947911177529, 0.02764054250292247, 0.08303285503643565, 0.030375839087355416, 0.009517042981315171, 0.0979106524027884, 0.05678577086655423, 0.05344965378753841, 0.024785311143205035, 0.06022273839334957, 0.014398448820429621, 0.058015884351334535, 0.048000044844229706, 0.028607536805793643, 0.04737414717965294, 0.04710770503152162, 0.046337092280737124, 0.0400850955338683, 0.018954822735395283, 0.023149795779318083, 0.10239639334031381, 0.05678408248058986, 0.06751492561306804, 0.10942591223283671, 0.044786166909034364, 0.08753334986977279, 0.010972689578920836, 0.10174978233408183, 0.3097264270763844, 0.027423896608524956, 2.0198756642639637, 10.904111489653587, 27.41277404129505, 55.30282527208328, 82.22121924161911, 95.35903707146645, 116.9832131266594, 120.53762599825859, 133.19695830345154, 135.79276621341705, 134.54055100679398, 126.26509666442871, 120.28409600257874, 117.86897599697113, 114.36222016811371, 114.75562065839767, 115.40450423955917, 108.055759370327, 109.76310655474663, 120.26970237493515, 124.64816182851791, 124.52890142798424, 115.86856573820114, 116.29638478159904, 109.04972523450851, 115.68033143877983, 122.8578194975853, 119.51226621866226, 119.4864884018898, 129.6814477443695, 136.18698745965958, 131.26052141189575, 143.82781505584717, 151.21106207370758, 140.34624427556992, 118.60113590955734, 103.6859330534935, 76.4446172118187, 46.50896094739437, 27.549048028886318, 7.839286671951413, 0.43090106395538896, 0.1305209775455296, 0.0628718122607097, 0.18402011774014682, 0.02323042084753979, 0.10769506057840772, 0.05783722714113537, 0.06251679107663222, 0.04394528761622496, 0.08120600658003241, 0.027458011281851213, 0.09086746315006167, 0.04258209592080675, 0.040808466874295846, 0.11012813236447982, 0.06747890918632038, 0.06201085045177024, 0.011314583098283038, 0.024773041586740874, 0.014706501333421329, 0.05852091584529262, 0.05800192826427519, 0.01853528850915609, 0.02414819406112656, 0.06522309937281534, 0.021586051661870442, 0.009390289724251488, 0.04412081296322867, 0.03166160808177665, 0.02283295994857326, 0.010572449336905265, 0.06407618435332552, 0.05269349436275661, 0.04272359008609783, 0.05010201486584265, 0.037559233023785055, 0.023732433655823115, 0.09043662415933795, 0.036373444308992475, 0.031326821554102935, 0.030257349644671194, 0.053432539862114936, 0.05983804614515975, 0.011350638487783726, 0.033066616088035516, 0.05336304886441212, 0.05743165827880148, 0.021678146622434724, 0.03088784491410479, 0.051073686554445885, 0.030587059882236645, 0.05195368816202972, 0.07267205786774866, 0.017792951584851835, 0.05480017702211626, 0.05596352319116704, 0.0409626480541192, 0.06459937620093115, 0.025674231510492973, 0.01795281576050911, 0.10228641447611153, 0.03818601013335865, 0.02915895624028053, 0.053792819162481464, 0.035950939636677504, 0.04019610227260273, 0.02444689736876171, 0.027909058953810018, 0.036861198605038226, 0.10332838239264674, 0.183440619148314, 0.12405500106979162, 0.1227960291726049, 0.20578729425324127, 0.1167943180189468, 0.10333852012990974, 0.14826178026851267, 0.1363875955576077, 0.1520311928470619, 0.11886337379110046, 0.09595268871635199, 0.1751950170728378, 0.21478638402186334, 0.18396905797999352, 0.18927967379568145, 0.14394803205505013, 0.18542316276580095, 0.0877027673413977, 0.1589792684535496, 0.17345422063954175, 0.1550533963018097, 0.07958203903399408, 0.09645442507462576, 0.14736493933014572, 0.11709775993949734, 0.18810139561537653, 0.2201662422157824, 0.13868706591892987, 0.11863120773341507, 0.176146732410416, 0.09287399298045784, 0.17582266620593145, 0.14156933000776917, 0.1443854984245263, 0.13191005535190925, 0.13783101341687143, 0.07846225693356246, 0.1898727091611363, 0.08397977610002272, 0.14267787599237636, 0.25819142523687333, 0.13099900970701128, 0.17969825043110177, 0.1728177844779566, 0.15313340089051053, 0.09635589012759738, 0.19693203270435333, 0.18277314637089148, 0.15310641640098765, 0.143375598709099, 0.1728758797980845, 0.09043797486810945, 0.09386506440932862, 0.12703665357548743, 0.10523353485041298, 0.2927775849821046, 0.12335078456089832, 0.13080529432045296, 0.33556094393134117, 0.10574279658612795, 0.19831348123261705, 0.13016140699619427, 0.40514663967769593, 0.519243503222242, 0.22021957294782624, 1.7949449527077377, 11.763817258179188, 29.727587029337883, 60.92038683593273, 93.76303151249886, 107.85984188318253, 129.48972523212433, 134.6631172299385, 148.93194437026978, 149.60595220327377, 146.38082206249237, 142.6665061712265, 128.2815420627594, 129.48323518037796, 120.57326048612595, 119.67544466257095, 115.33654868602753, 113.55888247489929, 117.30305716395378, 123.85236293077469, 127.70300030708313, 125.60739755630493, 118.69084909558296, 127.83971697092056, 119.53154638409615, 127.20822885632515, 134.4760000705719, 133.14801692962646, 133.04552882909775, 140.54310411214828, 153.9829981327057, 145.50177723169327, 161.02180123329163, 166.82568579912186, 154.41406220197678, 132.1172234416008, 115.54392635822296, 82.77583748102188, 50.42593516409397, 28.725567497313023, 7.241810532286763, 0.511038318509236, 0.5051246483344585, 0.2961944922572002, 0.26647818682249635, 0.2066915121395141, 0.15564680274110287, 0.11705095268553123, 0.41487960959784687, 0.17986771243158728, 0.17755152890458703, 0.0953745111473836, 0.20648834179155529, 0.1335986194317229, 0.1497030904283747, 0.1970832675579004, 0.13554448611102998, 0.16059345449320972, 0.17064008570741862, 0.20086900738533586, 0.175395886762999, 0.15145077399211004, 0.15951664274325594, 0.09750917277415283, 0.14612895174650475, 0.12951962737133726, 0.17571742966538295, 0.09268558394978754, 0.18911390769062564, 0.17833669146057218, 0.08868773831636645, 0.1403256834601052, 0.19219953508581966, 0.15800162247614935, 0.13499130407581106, 0.14223331469111145, 0.10688651294913143, 0.06531162274768576, 0.11748621487640776, 0.13098844152409583, 0.1398402446648106, 0.09559334081131965, 0.14085812988923863, 0.20929162652464584, 0.10996799916028976, 0.15204452181933448, 0.157206010480877, 0.11139896378153935, 0.12553135544294491, 0.11026412350474857, 0.11128467303933576, 0.12938010360812768, 0.16651592653943226, 0.20123129419516772, 0.11169919220265001, 0.26135208376217633, 0.19955792929977179, 0.20206886722007766, 0.13533818389987573, 0.15348226967034861, 0.09627772713429295, 0.27242943935561925, 0.08468538784654811, 0.1611660362686962, 0.13792508805636317, 0.12793874891940504, 0.23345963592873886, 0.12921586632728577, 0.20416242128703743, 0.1857758016558364, 0.17414124158676714], [0.05303958008880727, 0.04028929375635926, 0.012754100043821381, 0.020452228127396666, 0.09125479002250358, 0.04779249582497869, 0.03303293000499252, 0.012832404045184376, 0.043730743855121545, 0.1091955199080985, 0.02622890711791115, 0.031273275599232875, 0.027275585816823877, 0.031322494833148085, 0.05968091121758334, 0.028512851749837864, 0.03738433479156811, 0.0451275882369373, 0.055813126964494586, 0.057850463344948366, 0.05187949565879535, 0.016533864654775243, 0.07430077515891753, 0.04050781913974788, 0.06469302039477043, 0.02153082659788197, 0.06397980163455941, 0.019968767155660316, 0.059879996042582206, 0.0268111869081622, 0.01886412857857067, 0.034807163901859894, 0.04035551559354644, 0.008506552330800332, 0.03840944111288991, 0.03419849890633486, 0.04164294143265579, 0.1177737006219104, 0.02774346539808903, 0.04062948311911896, 0.09372935528517701, 0.10279665584675968, 0.00563694325137476, 0.013030242989771068, 0.0589555917395046, 0.06087829598982353, 0.027315682200423907, 0.06481030941358767, 0.0495093097561039, 0.11455657207989134, 0.018662158654478844, 0.03066056775423931, 0.029000834256294183, 0.02357302775635617, 0.04953665047651157, 0.07799010258167982, 0.037786178072565235, 0.0677980030013714, 0.16708960669348016, 0.07824327884009108, 0.191505181719549, 0.48197988246101886, 5.331383245065808, 20.995948165655136, 49.16034087538719, 72.44047567248344, 92.21795842051506, 110.76498359441757, 106.10416889190674, 92.62959033250809, 97.33071327209473, 73.5442328453064, 75.98963722586632, 69.72897917032242, 68.35450172424316, 65.12814044952393, 70.06104335188866, 54.55131679773331, 56.29674553871155, 64.77558016777039, 63.8638798892498, 60.8967749029398, 60.245436653494835, 99.51010152697563, 59.19650673866272, 59.94706906378269, 66.1070667207241, 52.67882287502289, 85.35293519496918, 69.21502634882927, 75.90475738048553, 76.42830848693848, 70.52015751600266, 89.91069942712784, 79.35516223311424, 104.11161661148071, 87.04727187752724, 93.88455659151077, 88.47845748066902, 95.02206355333328, 108.21259215474129, 112.69402608275414, 116.74535349011421, 117.18856930732727, 116.8713927268982, 94.64033603668213, 66.2115915119648, 30.34628313034773, 10.868117921054363, 2.881763228215277, 0.22184875037055463, 0.2796148834750056, 0.18420814827550203, 0.05135874918778427, 0.05571789457462728, 0.09157573920674622, 0.08091530733508989, 0.011781650955526857, 0.045843601183150895, 0.03487675880023744, 0.08808810525806621, 0.08103722735540941, 0.044787291262764484, 0.04314352321671322, 0.019719429656106513, 0.05159501561138313, 0.07240132981678471, 0.05976933069177903, 0.055407424515578896, 0.040887776485760696, 0.1259767182637006, 0.06314027676125988, 0.061475650654756464, 0.04016523263999261, 0.055850802091299556, 0.07704609815846197, 0.05989242701616604, 0.06784366734791547, 0.03376216802280396, 0.045819503648090176, 0.022487130263471045, 0.05721061330405064, 0.06638661623583175, 0.029461333178915083, 0.08800539289950393, 0.05519536694919225, 0.035407416653470136, 0.05453190176922362, 0.029769354150630534, 0.06176323659019545, 0.02830019118846394, 0.029193202644819394, 0.02350504702917533, 0.02551709101680899, 0.034285556539543904, 0.03267065061663743, 0.05976714877760969, 0.0454677998641273, 0.033093043966800906, 0.08624242851510644, 0.044678076810669154, 0.028710914266412146, 0.04590464282955509, 0.010768807696877047, 0.040245948621304706, 0.01915668875881238, 0.020454751429497264, 0.06420704725314863, 0.04831027741602156, 0.050750232621794567, 0.009773832571227103, 0.019275638333056122, 0.04182071177638136, 0.014265634072216926, 0.04077036872331519, 0.013363546149776084, 0.019841191970044747, 0.07266746397363022, 0.02377076743869111, 0.038021179134375416, 0.034972829816979356, 0.08263754265499301, 0.06078251812141389, 0.03962394352129195, 0.058164633010164835, 0.10653002231265418, 0.033709267736412585, 0.018707077142607886, 0.029618770531669725, 0.02340336166525958, 0.02218403900769772, 0.05454785052279476, 0.039607289727428, 0.004321204942243639, 0.031240227763191797, 0.021316789352567866, 0.009362920245621353, 0.012468982677091844, 0.05237643032160122, 0.050412132404744625, 0.0790542978211306, 0.013025950593146263, 0.06638864972046576, 0.007841113038011827, 0.011342033285473008, 0.04406575302709825, 0.0269667744578328, 0.026486326605663635, 0.03978489308792632, 0.03220337959646713, 0.04482090313103981, 0.014560384515789337, 0.012010734317300376, 0.07605629580211826, 0.03644345109933056, 0.03360846923897043, 0.015222824604279594, 0.028642332399613224, 0.09266316366847605, 0.01863358967966633, 0.060711368423653767, 0.0482083953829715, 0.06538490983075462, 0.018392252532066777, 0.0528499465144705, 0.04545622236037161, 0.034346319880569354, 0.09303447499405593, 0.04172603970800992, 0.018163147833547555, 0.047568682639393955, 0.12053111320710741, 0.027015795167244505, 0.03911265201168135, 0.10002786613767967, 0.1743777046795003, 0.08106055305688642, 1.5556972031481564, 9.039945770055056, 29.9828839302063, 65.32924085855484, 91.71418905258179, 111.45108237862587, 125.74595332145691, 122.5816123187542, 112.71494776010513, 113.31403881311417, 101.34640619158745, 103.67970138788223, 102.98564583063126, 98.03075730800629, 89.16054368019104, 99.54338774085045, 86.43427357077599, 87.51442641019821, 91.85510829091072, 91.62075206637383, 91.84160381555557, 91.44362077116966, 127.25907012820244, 97.07798883318901, 95.72071686387062, 109.7840966284275, 87.9359757900238, 119.05983969569206, 110.49177065491676, 106.8300287425518, 111.78608000278473, 104.08936500549316, 116.32380411028862, 109.08696323633194, 130.1700559258461, 112.77652725577354, 114.26255911588669, 108.94393891096115, 109.74710941314697, 128.50659638643265, 121.93756967782974, 131.72899067401886, 134.0142184495926, 138.97126525640488, 122.18139499425888, 95.00936463475227, 47.17694230377674, 20.347611755132675, 5.944690760225058, 0.10350393742555752, 0.0731258440646343, 0.26101547526195645, 0.03405348696105648, 0.012528632796602324, 0.0224671330943238, 0.034713282220764086, 0.013734248914261116, 0.05204826746194158, 0.0987447150691878, 0.05035823764046654, 0.061209345803945325, 0.021084825530124363, 0.03703284994116984, 0.029946773829578888, 0.010370800391683588, 0.08379494422115386, 0.06743478108546697, 0.04388113637105562, 0.05935233646596316, 0.06722821170114912, 0.03507687149976846, 0.1109548106614966, 0.1675404465640895, 0.021459637937368825, 0.011279167811153457, 0.012650794014916755, 0.0812668033177033, 0.03877006922266446, 0.03080951122683473, 0.023850377619965002, 0.07899842152255587, 0.03664622068754397, 0.021541589594562538, 0.05705996103642974, 0.05358967850042973, 0.012128184753237292, 0.040399469289695844, 0.041742856774362735, 0.050390487667755224, 0.037718802195740864, 0.014050057798158377, 0.029416822872008197, 0.056105481198756024, 0.02039883616816951, 0.042948349509970285, 0.05216984609432984, 0.0509801536827581, 0.03345176846778486, 0.0524731729819905, 0.03477879159618169, 0.0031780083145349636, 0.08845595075399615, 0.028623836224141996, 0.014720988983754069, 0.039874626163509674, 0.01662915641645668, 0.025398618272447493, 0.07264663930982351, 0.06729441869538277, 0.03984047994890716, 0.02928089481429197, 0.015012832063803216, 0.03839791927020997, 0.040596246035420336, 0.017480538954259828, 0.2663870807737112, 0.214759191730991, 0.08825244643958285, 0.11323704835376702, 0.14216408715583384, 0.2359970091492869, 0.10437423916300759, 0.23514998116297647, 0.1706430988269858, 0.24787524598650634, 0.12520638381829485, 0.15673433110350743, 0.11920665419893339, 0.17082194157410413, 0.18742532876785845, 0.1166406786069274, 0.13883790001273155, 0.13667600898770615, 0.16788732638815418, 0.12815995345590636, 0.12505008751759306, 0.09203944791806862, 0.15887556073721498, 0.14518551877699792, 0.16432909935247153, 0.09841730177868158, 0.14906494732713327, 0.19676922034705058, 0.2644737053196877, 0.11071574263041839, 0.13175243802834302, 0.22375118656782433, 0.12495040224166587, 0.12566663412144408, 0.18694318510824814, 0.08553234903956763, 0.15194315928965807, 0.31755537260323763, 0.1801508862990886, 0.10124702923349105, 0.19367201544810086, 0.19693461537826806, 0.22688070457661524, 0.13191121310228482, 0.21617675316520035, 0.11743709954316728, 0.10290193691616878, 0.16935867868596688, 0.2041602839017287, 0.1924606374814175, 0.10451305788592435, 0.14534050889778882, 0.16876024048542604, 0.10149660607567057, 0.19072154798777774, 0.2564452704973519, 0.17240470508113503, 0.2026771314558573, 0.25367308175191283, 0.438672240707092, 0.30815337086096406, 1.2909731268882751, 9.987646266818047, 31.353629976511, 73.22869777679443, 102.26076632738113, 125.35292521119118, 145.18303513526917, 137.36664175987244, 119.5781546831131, 122.19606220722198, 99.32431429624557, 100.49547985196114, 94.50278341770172, 93.53005841374397, 92.1581420302391, 96.82549998164177, 81.78225919604301, 85.09199559688568, 96.9325478374958, 95.94685792922974, 81.94185063242912, 88.0773814022541, 128.0464866757393, 84.73034620285034, 86.30093112587929, 96.83690696954727, 78.86348381638527, 116.9906759262085, 101.64402902126312, 108.8069486618042, 111.37680396437645, 104.5194411277771, 124.81070950627327, 111.61742985248566, 134.07959014177322, 115.70078954100609, 123.8817049562931, 115.06392851471901, 120.12787878513336, 135.05788564682007, 141.39915257692337, 146.41533941030502, 148.4202030301094, 153.98749709129333, 137.12155491113663, 101.09818071126938, 51.21221177279949, 23.11675876379013, 5.8959265518933535, 0.17031444614985958, 0.3545582026708871, 0.42429455439560115, 0.13359750621020794, 0.16131920070620254, 0.12914423423353583, 0.17294806108111516, 0.20652148610679433, 0.15590419439831749, 0.23400557460263371, 0.19673807983053848, 0.10074286605231464, 0.2001317430404015, 0.14450458344072104, 0.1143696102371905, 0.1415002063731663, 0.15398016170365736, 0.14326954580610618, 0.23792732041329145, 0.1310476055368781, 0.27024351758882403, 0.13206549076130614, 0.17677139810984954, 0.257928526843898, 0.12927464442327619, 0.26516069658100605, 0.15862759435549378, 0.19360703299753368, 0.07974453226779588, 0.18782564322464168, 0.09001388942124322, 0.17847625975264236, 0.1450598583323881, 0.12988949893042445, 0.2162642078474164, 0.1840428274590522, 0.10005901407566853, 0.15646338782971725, 0.13459239969961345, 0.1899642011267133, 0.11315761628793553, 0.10578947025351226, 0.12158035417087376, 0.09943540222593583, 0.14013498119311407, 0.12883363058790565, 0.24638848670292646, 0.11137774577946402, 0.1863490662071854, 0.1574605968198739, 0.10916519575403072, 0.10756588977528736, 0.27240171271841973, 0.10113876473042183, 0.10469293963978998, 0.14287478261394426, 0.14925729716196656, 0.17104142432799563, 0.15059541910886765, 0.16615135391475633, 0.1694352534832433, 0.15754278225358576, 0.13153368257917464, 0.08461103207082488, 0.1396397312055342, 0.11521201464347541], [0.05183103341551032, 0.07197214581537992, 0.030827797745587304, 0.06148109430796467, 0.011546583100425778, 0.02292738154210383, 0.045023498314549215, 0.02415856928564608, 0.019639580132206902, 0.03759725695999805, 0.020695993953268044, 0.034501725604059175, 0.09781884131371044, 0.024398140121775214, 0.0365020918980008, 0.0487198650080245, 0.026943116645270493, 0.06137982454674784, 0.05034415538830217, 0.023787204154359642, 0.034825146140065044, 0.029621351350215264, 0.01582583165145479, 0.01668252982199192, 0.04539519184618257, 0.09349476240458898, 0.016111569639178924, 0.0788162242679391, 0.03372190651134588, 0.07557205186458305, 0.05722663256165106, 0.017572298093000427, 0.0408900326146977, 0.011769746906793443, 0.024590087341493927, 0.06984975188970566, 0.04657901015889365, 0.03836070427496452, 0.10802466320456006, 0.01202072362502804, 0.03890201565809548, 0.041534157426212914, 0.009590568479325157, 0.026265886481269263, 0.010447772237967001, 0.03574891590687912, 0.06504805642180145, 0.04952083159878384, 0.02786764525808394, 0.08131630456773564, 0.0605613729567267, 0.0015203578163891507, 0.04252521772286855, 0.02997001603944227, 0.10571434264420532, 0.020703933078038972, 0.1385945943184197, 0.33554372610524297, 0.06965904220123775, 2.7628676081076264, 28.86577047407627, 61.35448694229126, 84.06644582748413, 94.74156260490417, 94.99990314245224, 81.47118508815765, 91.96530237793922, 77.4227075278759, 72.02676147222519, 70.16530975699425, 67.16356962919235, 71.61496236920357, 60.1750872284174, 54.70756821334362, 55.04057854413986, 63.09919372200966, 40.42487181723118, 57.11660094559193, 32.48369313776493, 44.99445341527462, 45.2387461066246, 41.746254712343216, 42.30151131749153, 52.31019705533981, 42.59400822222233, 47.65391170978546, 46.81895971298218, 43.56918029487133, 60.630025416612625, 47.57323443889618, 29.479080364108086, 35.51087290048599, 62.32588581740856, 57.17270493507385, 55.08603170514107, 51.57440833747387, 66.15586370229721, 68.9357641339302, 81.30441963672638, 67.15505808591843, 63.203224539756775, 92.00791329145432, 56.83547683060169, 87.57794380187988, 90.59411555528641, 97.46624439954758, 111.18264958262444, 108.22942525148392, 106.81157693266869, 87.1836769580841, 42.945588156580925, 20.075762942433357, 6.6961583867669106, 0.8909856900572777, 0.5319149326533079, 0.08786122329183854, 0.07481716151232831, 0.0960577248770278, 0.027210067164560314, 0.0418786438240204, 0.04079880040080752, 0.08614214209956117, 0.014356953488459112, 0.007270904743563733, 0.019157430906489026, 0.056643775751581416, 0.04179535259027034, 0.06953154865186661, 0.041117716100416146, 0.04996519252017606, 0.07644817946129479, 0.01879585841379594, 0.062411279941443354, 0.03963501636462752, 0.04983686776540708, 0.03981843816291075, 0.06156764357001521, 0.028039085082127713, 0.059297647603671066, 0.07026011502603069, 0.009622247980587417, 0.013357319530769018, 0.060014202317688614, 0.022930346422072034, 0.03325373378174845, 0.024432054415228777, 0.04454132867977023, 0.026199306557828095, 0.017805291645345278, 0.02548716205637902, 0.016469088150188327, 0.08288939789053984, 0.04298361265682615, 0.0601889818062773, 0.051889165843022056, 0.07069747749483213, 0.036815122366533615, 0.0684984122926835, 0.016322653136739973, 0.09573005183483474, 0.03858881820633542, 0.07491384851164185, 0.016125637048389763, 0.019999163669126574, 0.044812620762968436, 0.08934565965319052, 0.07127028933609836, 0.046259471055236645, 0.018682079753489234, 0.03590248481486924, 0.02488273286871845, 0.0030332637743413216, 0.0702744087902829, 0.04831091566302348, 0.08827528232359327, 0.06768188657588325, 0.01947937642398756, 0.013504648832167732, 0.10573435836704448, 0.07116328648407944, 0.015599343023495749, 0.0577356790745398, 0.04124089777178597, 0.026854480092879385, 0.02008550327445846, 0.04280426896002609, 0.04087834378879052, 0.05633457847579848, 0.08080125408014283, 0.025629992087488063, 0.054421002641902305, 0.03199066894012503, 0.10453783077537082, 0.03802579900366254, 0.03844847065920476, 0.07680646609514952, 0.050701907675829716, 0.06067267284379341, 0.048303590665454976, 0.030559587430616375, 0.012472169273678446, 0.03453177887422498, 0.038032285374356434, 0.05366791570850182, 0.057972138456534594, 0.06053314165910706, 0.012503821872087428, 0.08443994476692751, 0.035038984860875644, 0.013406894995569019, 0.043835620454046875, 0.03899969713529572, 0.09227597780409269, 0.042543036688584834, 0.0777157380071003, 0.011084656471211929, 0.027095986079075374, 0.04757832684845198, 0.05583757701970171, 0.054933522405917756, 0.034268928720848635, 0.0781334335624706, 0.0916634981695097, 0.06633451004745439, 0.02273658465128392, 0.03005410879268311, 0.014725485470989952, 0.06806801859056577, 0.03243951985496096, 0.031154624739428982, 0.043713403574656695, 0.06349759118165821, 0.05980630448902957, 0.3001563437283039, 0.09402533862157725, 6.000094162300229, 39.90342579782009, 79.39314499497414, 102.45594665408134, 109.61844071745872, 107.2678792476654, 94.89905655384064, 107.41984069347382, 94.98277366161346, 102.84631490707397, 98.35649102926254, 107.2670204937458, 97.32601672410965, 74.20002445578575, 74.73545372486115, 72.03685373067856, 96.13382309675217, 66.37739941477776, 73.0289576947689, 52.49469995498657, 65.81084981560707, 70.80916240811348, 59.35087725520134, 63.77418950200081, 71.97596579790115, 59.10080127418041, 56.56309984624386, 64.94567424058914, 52.63162560760975, 86.98684751987457, 67.08851605653763, 55.66882163286209, 59.922298192977905, 89.13548782467842, 96.00073143839836, 93.18574368953705, 98.24310511350632, 105.25258898735046, 107.43298038840294, 122.18686670064926, 108.28813210129738, 102.75763526558876, 124.66231986880302, 79.3821407854557, 107.44320943951607, 112.155731767416, 112.5001908838749, 126.6998465359211, 131.67004823684692, 130.0675070285797, 112.28398248553276, 64.25102591514587, 33.86800065636635, 14.511916246265173, 1.5860680234618485, 0.21262066351482645, 0.12122000436647795, 0.025527894831611775, 0.06051878852304071, 0.11336351031786762, 0.05081709641672205, 0.09195130303851329, 0.02658482815604657, 0.04678151628468186, 0.033375564744346775, 0.09035987124661915, 0.025168311294692103, 0.06369940339936875, 0.02913137803261634, 0.06692191993352026, 0.014135750807326986, 0.09055222850292921, 0.020249978042556904, 0.027134978518006392, 0.04176613423624076, 0.06661783234449103, 0.048627961150486954, 0.013668118917848915, 0.042941065330524, 0.035270048829261214, 0.04898326063994318, 0.02761474359431304, 0.03417639403778594, 0.01656419251958141, 0.03575546536012553, 0.07691314240219072, 0.03758509315957781, 0.025777881710382644, 0.030594739255320746, 0.05266822423436679, 0.019814001534541603, 0.04734023103083018, 0.06988711902522482, 0.07119523594155908, 0.008032653931877576, 0.05822007515234873, 0.04880700427747797, 0.017878688195196446, 0.036023881621076725, 0.07818801852408797, 0.08232756983488798, 0.032797357489471324, 0.06157943258585874, 0.025949065493477974, 0.03853567301121075, 0.07031616944004782, 0.045108626363798976, 0.05486207955982536, 0.023471976928703953, 0.05098790912597906, 0.017848744391812943, 0.06358218859531917, 0.01631644321605563, 0.03905394070898183, 0.0031359651848106296, 0.10328980555641465, 0.08016987194423564, 0.16887371486518532, 0.18834536924259737, 0.18517681426601484, 0.16616885375697166, 0.08589155593654141, 0.16030281462008134, 0.20569026586599648, 0.10063169233035296, 0.12805930338799953, 0.16517688432941213, 0.09648087521782145, 0.1385313633363694, 0.22338346723699942, 0.12552751111797988, 0.14229921740479767, 0.13506241666618735, 0.23513190244557336, 0.10585181807982735, 0.20159819716354832, 0.13030238536885008, 0.11342128651449457, 0.10172578127821907, 0.14354151324369013, 0.0987074666772969, 0.08347438095370308, 0.14665982482256368, 0.19670619716634974, 0.13053032860625535, 0.13483046583132818, 0.07519171602325514, 0.11706422228598967, 0.2791504474589601, 0.32777836779132485, 0.10892318139667623, 0.27675304329022765, 0.1454474523779936, 0.13181915710447356, 0.13363301055505872, 0.3055757435504347, 0.12639169755857438, 0.20515829441137612, 0.13722454517846927, 0.19585320231271908, 0.17321174615062773, 0.13387627172050998, 0.15995344117982313, 0.18816621479345486, 0.12931060889968649, 0.10473452959558927, 0.19697286566952243, 0.16502002399647608, 0.13951600034488365, 0.21415677561890334, 0.18053163774311543, 0.3019274049438536, 0.13329335924936458, 0.2901490166550502, 0.60628074221313, 0.20422436093213037, 5.679234629496932, 42.58449353277683, 86.81237608194351, 114.56531167030334, 123.7037605047226, 120.1188200712204, 104.86226633191109, 116.04660898447037, 100.59713199734688, 95.72431907057762, 97.90624558925629, 92.34504640102386, 95.7430824637413, 80.33154264092445, 78.01020160317421, 75.559401512146, 85.76930165290833, 54.28715497255325, 79.20602783560753, 51.47198863327503, 70.3377217054367, 69.8603305220604, 60.54587893188, 61.67487435042858, 72.03049287199974, 61.47500887513161, 68.06532204151154, 65.13747274875641, 61.370320692658424, 82.27800339460373, 66.58565104007721, 48.82756233215332, 52.36003518104553, 88.37756529450417, 85.42675763368607, 80.6815342605114, 72.15992912650108, 89.36736658215523, 93.2858607172966, 109.29315537214279, 97.32748344540596, 92.50782206654549, 126.04542285203934, 83.46017315983772, 117.87792831659317, 116.91259011626244, 122.07811653614044, 136.35300815105438, 143.8543376326561, 143.9976355433464, 124.05696675181389, 67.70212233066559, 35.56877799332142, 14.156217332929373, 1.6003528819419444, 0.5550652497913688, 0.19371802860405296, 0.26719809975475073, 0.17444044584408402, 0.1852244304609485, 0.1767555161495693, 0.2095160519820638, 0.20843762235017493, 0.14027449011337012, 0.14060807065106928, 0.219541858532466, 0.11562119776499458, 0.09427027704077773, 0.2067230682587251, 0.10475087168742903, 0.17995559755945578, 0.34501531161367893, 0.12075429927790537, 0.12772027548635378, 0.19824438728392124, 0.13565579341957346, 0.2262501313816756, 0.12829713203245774, 0.12277303001610562, 0.20105564268305898, 0.19592318683862686, 0.10095240402733907, 0.14835775480605662, 0.1623492719954811, 0.11063194673624821, 0.18491572671337053, 0.1082575491454918, 0.1355201585101895, 0.08892437210306525, 0.13578972138930112, 0.10733675168012269, 0.1641298327012919, 0.19971786212408915, 0.20258504577213898, 0.1639649720164016, 0.14781797595787793, 0.15059561206726357, 0.11317480442812666, 0.13218934036558494, 0.14556885289493948, 0.18928795616375282, 0.157620633544866, 0.19068859663093463, 0.09253399286535569, 0.13027280336245894, 0.15614818286849186, 0.20263883663574234, 0.20829082553973421, 0.18111196754034609, 0.08427824563113973, 0.12205958861159161, 0.16169907641597092, 0.16687643219484016, 0.19142792414641008, 0.1302061733440496, 0.19408187392400578, 0.11821199077530764], [0.07482715082005598, 0.03779152153583709, 0.009618553940526908, 0.09858096760581248, 0.027589399251155555, 0.0027872661712535773, 0.061879712957306765, 0.04050354807986878, 0.11674161069095135, 0.09395101995323785, 0.025841329770628363, 0.013928588632552419, 0.035170096380170435, 0.04100590413145255, 0.024802601328701712, 0.030787343275733292, 0.04980043202522211, 0.00834360638691578, 0.050606244840309955, 0.02867874030926032, 0.008837543700792594, 0.026189896125288215, 0.09443351242225617, 0.019950781206716783, 0.07388256752165034, 0.009627409617678495, 0.09499336636508815, 0.02746609698078828, 0.027696838114934508, 0.053680391210946254, 0.02249483746709302, 0.035084144546999596, 0.07161191475461237, 0.024170668148144614, 0.028522828069981188, 0.037947754753986374, 0.005155430417289608, 0.052073682309128344, 0.08739715092815459, 0.03766309659113176, 0.06424811770557426, 0.01895130681077717, 0.08822769581456669, 0.02178070215450134, 0.0063892272737575695, 0.08370092895347625, 0.07089730817824602, 0.028758228036167566, 0.040940391045296565, 0.026552323943178635, 0.0452910759486258, 0.06752865534508601, 0.12846883531892672, 0.08173400754458271, 0.06320845786831342, 0.29238840274047107, 0.010452147198520834, 7.67164109274745, 44.306093752384186, 80.0624106824398, 82.2528487443924, 84.3343922495842, 84.89566013216972, 63.24409894645214, 80.22115856409073, 66.5830671787262, 75.94273254275322, 74.80172216892242, 50.647588670253754, 55.68860337138176, 29.047997295856476, 60.71667596697807, 56.47559054195881, 54.70665246248245, 51.219742968678474, 27.37431440502405, 41.384517922997475, 45.62537536025047, 46.89715951681137, 32.377314046025276, 30.616817213594913, 43.73341508209705, 57.5273285061121, 43.79942134022713, 74.156334400177, 54.59141984581947, 62.87462197244167, 60.46595022082329, 50.925528556108475, 58.08638110756874, 35.21158955991268, 55.5330815166235, 31.061731539666653, 27.525804676115513, 39.64336775243282, 21.768503710627556, 27.450483217835426, 29.253739155828953, 36.742804795503616, 39.152928069233894, 32.259584963321686, 46.714313328266144, 49.639772549271584, 44.02444526553154, 58.12398009002209, 53.47134254872799, 64.18891444802284, 82.88366809487343, 83.50808098912239, 84.94238242506981, 105.4054319858551, 102.18787103891373, 103.54021087288857, 68.18014428019524, 15.070978347212076, 1.4520665514282882, 0.11459458488388918, 0.35189074580557644, 0.11815166159067303, 0.026115302862308454, 0.027735713665606454, 0.0451411769608967, 0.029552660016634036, 0.023738918171147816, 0.05173121826373972, 0.04523931856965646, 0.06977627184824087, 0.05611441665678285, 0.03334256885864306, 0.020875556583632715, 0.015678611816838384, 0.07401042472338304, 0.039048259568517096, 0.023084831882442813, 0.019783176430792082, 0.07382362615317106, 0.05643377393425908, 0.009941463322320487, 0.034529979166109115, 0.011755237919715, 0.04359184720669873, 0.0773874341393821, 0.0397645582415862, 0.050959455184056424, 0.039038158938637935, 0.026144339390157256, 0.062454131548292935, 0.04295254635508172, 0.05034025169152301, 0.04017648730950896, 0.015803470741957426, 0.07514755823649466, 0.05731103701691609, 0.026265346568834502, 0.04459404342924245, 0.039939096532179974, 0.03241379701648839, 0.06005137649481185, 0.01874233657872537, 0.049259944426012225, 0.050801218167180195, 0.015000522616901435, 0.012316803440626245, 0.046879056753823534, 0.02981830435601296, 0.056099837165675126, 0.10820973999216221, 0.03345354962220881, 0.020129755685047712, 0.06302922920440324, 0.045536522738984786, 0.046198247582651675, 0.021939091311651282, 0.076032183424104, 0.05500394479895476, 0.03412438432860654, 0.07244841908686794, 0.041045119214686565, 0.07269578432897106, 0.06827477351180278, 0.022175116537255235, 0.05215577497438062, 0.037890045350650325, 0.06610465206904337, 0.08854078565491363, 0.027141019600094296, 0.07816808443749323, 0.05538827339478303, 0.05334989800758194, 0.04965120097040199, 0.08825085824355483, 0.06547070210217498, 0.07886294246418402, 0.011525613717822125, 0.029462520615197718, 0.04553524253424257, 0.020092280938115437, 0.07082952783093788, 0.0200353433683631, 0.11043196762329899, 0.05966306627669837, 0.02604704011901049, 0.05305680904712062, 0.032069533262983896, 0.060961572380620055, 0.027851781851495616, 0.03171424490574282, 0.028906939587614033, 0.016807939791760873, 0.022460056716226973, 0.0858237904321868, 0.04996592353563756, 0.03459813058725558, 0.029231805456220172, 0.0413885332091013, 0.016716548016120214, 0.05619612711598165, 0.03225870670576114, 0.06546132135554217, 0.01715087695629336, 0.015667963853047695, 0.057305467198602855, 0.018573614870547317, 0.0817035126965493, 0.032695145200705156, 0.02405074264970608, 0.011522518034325913, 0.04094349322258495, 0.06379383426974528, 0.04280225773982238, 0.026142823553527705, 0.28421774273738265, 0.11817401507869363, 13.269100785255432, 61.71543337404728, 94.4035479426384, 98.36542055010796, 95.88524803519249, 99.74255785346031, 85.83844274282455, 110.49755394458771, 91.14518478512764, 108.47242221236229, 103.06152015924454, 59.58364896476269, 66.67154923081398, 33.86366508901119, 49.338038340210915, 53.818358927965164, 41.60683639347553, 36.496790796518326, 18.761115185916424, 22.09532607346773, 28.56945287436247, 24.852494224905968, 22.56493527442217, 17.062536031007767, 21.455202922225, 29.480488188564777, 23.635949604213238, 31.533238738775253, 29.757326133549213, 30.867763347923756, 29.430108591914177, 36.16519398987293, 35.94993554055691, 21.737624667584896, 25.98066508769989, 28.68889756500721, 22.19435825943947, 30.6534206494689, 20.21058350801468, 29.44702908396721, 31.997995600104332, 41.8318185210228, 43.536889627575874, 44.15071628987789, 73.3488929271698, 66.97749361395836, 79.29313436150551, 88.30840900540352, 91.64640069007874, 103.50506275892258, 104.75616082549095, 100.42470484972, 102.95758813619614, 118.21373909711838, 128.1549632549286, 126.36812433600426, 95.17695844173431, 29.593653716146946, 4.554459359496832, 0.06089825234084856, 0.22259049728745595, 0.1346483576344326, 0.07482764805899933, 0.04024085748824291, 0.008330348846357083, 0.03019250820216257, 0.03147538096527569, 0.013655968105013017, 0.04026204209367279, 0.11355345559422858, 0.021445741222123615, 0.06574200160684995, 0.03312335698865354, 0.049852022420964204, 0.01687990028585773, 0.04642001244064886, 0.031276099471142516, 0.051203580951550975, 0.05037067232478876, 0.01733159919240279, 0.05306561091856565, 0.047066000042832457, 0.020451886739465408, 0.03554545983206481, 0.06306341252638958, 0.07769183343043551, 0.08913692319765687, 0.06314409882179461, 0.04636511206626892, 0.08184994585462846, 0.03362383911735378, 0.010859205922315596, 0.03290531400125474, 0.07126651180442423, 0.02541446126997471, 0.09097401329199784, 0.012950851742061786, 0.07438559521688148, 0.012827749851567205, 0.06725586412358098, 0.017063678315025754, 0.05872248686500825, 0.04823850060347468, 0.03997907602752093, 0.033019793991115876, 0.03539165714755654, 0.0251661868969677, 0.04065043023729231, 0.04000976012321189, 0.02867254337616032, 0.031373769816127606, 0.01097231015592115, 0.03991112869698554, 0.03938438567274716, 0.03367689896549564, 0.04157646355452016, 0.1489952448173426, 0.10253309694235213, 0.07457534753484651, 0.1696549291955307, 0.11490047589177266, 0.18955144827486947, 0.21893116005230695, 0.135536381858401, 0.08106387045700103, 0.17931217036675662, 0.24124056450091302, 0.25877614854834974, 0.18899972084909678, 0.10752959133242257, 0.17256529099540785, 0.1344919574330561, 0.1038145188067574, 0.21861706831259653, 0.13189763179980218, 0.1721457252278924, 0.06509257786092348, 0.14545463636750355, 0.10073594923596829, 0.05605716738500632, 0.12013617932097986, 0.1711049521691166, 0.1102701126364991, 0.11933380636037327, 0.09764798407559283, 0.2019608995760791, 0.12895988475065678, 0.1329597193398513, 0.13537432649172843, 0.15206127951387316, 0.11426268902141601, 0.11637338669970632, 0.15263495966792107, 0.21469838015036657, 0.18141197331715375, 0.11024699473637156, 0.12433585201506503, 0.20779302256414667, 0.13712106010643765, 0.1970176468603313, 0.10527654972975142, 0.17908522160723805, 0.08351190394023433, 0.12024644020129927, 0.20439705869648606, 0.09734195948112756, 0.1291369166574441, 0.05929666425799951, 0.12086700182408094, 0.1921581380884163, 0.1654875770327635, 0.2313861792208627, 0.1669814164051786, 0.15481213893508539, 0.39817932760342956, 0.2545040793484077, 13.370353952050209, 67.05684095621109, 108.01361963152885, 109.65017661452293, 107.26144999265671, 107.25435197353363, 87.38148674368858, 103.61151784658432, 90.31212508678436, 96.63424104452133, 97.62752294540405, 67.95035541057587, 71.04038760066032, 42.234095335006714, 81.40289515256882, 89.09878939390182, 84.86994311213493, 80.66418439149857, 44.679526314139366, 65.49673587083817, 79.9637907743454, 73.34249407052994, 55.17662264406681, 48.17799858748913, 68.80328044295311, 87.47278064489365, 64.86163035035133, 108.58645409345627, 81.01694226264954, 92.14012339711189, 89.20924946665764, 78.73815134167671, 86.7888705432415, 57.04916216433048, 91.99099659919739, 55.17022758722305, 46.92155800759792, 59.16438706219196, 36.21041916310787, 43.44200871884823, 45.96410818397999, 52.186019718647, 54.850144162774086, 49.499149695038795, 65.32927885651588, 74.48976650834084, 68.1230941414833, 83.31021800637245, 78.71257111430168, 89.76440727710724, 106.80874228477478, 106.80444851517677, 109.13779690861702, 133.7080004811287, 135.47215461730957, 139.0945914387703, 104.55232456326485, 32.63476923108101, 3.8521112222224474, 0.16048015822889283, 0.5384200648404658, 0.2011154152569361, 0.15552191413007677, 0.1453971050796099, 0.10590293721179478, 0.1366090969531797, 0.1966022964916192, 0.10725307452958077, 0.21690610621590167, 0.29841951036360115, 0.14230975590180606, 0.11259368053288199, 0.13893302850192413, 0.11583901810809039, 0.1322251118835993, 0.08657755271997303, 0.11352735426044092, 0.10248562917695381, 0.19237952074036002, 0.1388076352304779, 0.08605463546700776, 0.12015931948553771, 0.13705328718060628, 0.07488788076443598, 0.20339590148068964, 0.13579607417341322, 0.22245593107072636, 0.10353951598517597, 0.12664243957260624, 0.19047123641939834, 0.10313904567738064, 0.11562455227249302, 0.1584820295101963, 0.15604284242726862, 0.15706780774053186, 0.22137932712212205, 0.09323039455921389, 0.23263367009349167, 0.10021120629971847, 0.12066603565472178, 0.1017111683904659, 0.15202999056782573, 0.10641552376910113, 0.1201880480221007, 0.09026831990922801, 0.08052827732171863, 0.147785781591665, 0.13925074192229658, 0.14267533784732223, 0.24229297443525866, 0.12044169183354825, 0.1279758266173303, 0.15353285445598885, 0.1511364447651431, 0.10643922054441646, 0.14540770294843242, 0.23131837660912424, 0.22760806867154315, 0.13722398114623502], [0.02817260301526403, 0.08571613449021243, 0.022646884972346015, 0.032819714688230306, 0.06210376734088641, 0.015218450571410358, 0.047699092829134315, 0.044092793177696876, 0.014890396250848426, 0.051300757768331096, 0.024837482269504108, 0.07032744266325608, 0.035349380705156364, 0.036970665387343615, 0.022895795736985747, 0.0010892028330999892, 0.01748842612869339, 0.04836556741793174, 0.02650418824487133, 0.012952728447999107, 0.03117149004538078, 0.04889740528597031, 0.07129589343094267, 0.058081894676433876, 0.02366785196500132, 0.027167909465788398, 0.029262368952913675, 0.01928515081090154, 0.019435992326179985, 0.028425740310922265, 0.0739860897010658, 0.018193527648691088, 0.03588949351978954, 0.03836801814031787, 0.07687153018196113, 0.04247974262398202, 0.04176672053290531, 0.02154266941943206, 0.06828664787462912, 0.04836534848436713, 0.05234249561908655, 0.028300411977397744, 0.022553667513420805, 0.048454265197506174, 0.057300060652778484, 0.01736899601382902, 0.030869970287312753, 0.08490271095070057, 0.061891624427516945, 0.08086432921118103, 0.02765999233815819, 0.015408281742566032, 0.012941349468746921, 0.118764015060151, 0.2671030751662329, 10.441713351756334, 40.253314822912216, 85.18208116292953, 77.63158991932869, 70.1455508172512, 68.0369907617569, 78.25864747166634, 64.87984657287598, 65.61403557658195, 44.703518226742744, 37.92036160826683, 30.82734491676092, 24.886105321347713, 56.039917320013046, 40.71719013154507, 68.34717571735382, 52.4256956577301, 39.023871794342995, 46.239061430096626, 51.38671740889549, 82.29458570480347, 85.89303821325302, 70.52548483014107, 80.4897053539753, 91.90328970551491, 102.74813577532768, 101.978008300066, 94.73252668976784, 81.99187874794006, 86.61485508084297, 79.71239626407623, 98.93518477678299, 85.74840277433395, 75.91935619711876, 88.83501514792442, 84.98966708779335, 82.3268611729145, 78.47641378641129, 80.29141679406166, 103.80393952131271, 114.09650042653084, 96.36253282427788, 104.08446326851845, 88.73394057154655, 84.3432229757309, 84.27073046565056, 34.18722912669182, 42.0197906345129, 39.19721469283104, 42.494293972849846, 32.81353443861008, 45.84351785480976, 54.55418184399605, 60.45907638967037, 58.07097293436527, 63.3050362765789, 64.44462552666664, 77.10160195827484, 91.79510191082954, 102.1946270763874, 70.65364435315132, 39.66892518103123, 16.84215735644102, 0.6220018048770726, 0.21389263041783124, 0.22304405341856182, 0.03798119221755769, 0.016971967415884137, 0.06421849117032252, 0.04977791155397426, 0.0493233794986736, 0.04210502484056633, 0.04357106707175262, 0.025849608427961357, 0.06173600719193928, 0.041092490500886925, 0.027113346768601332, 0.07437215492245741, 0.016699658590368927, 0.030802035944361705, 0.016733407755964436, 0.017470106213295367, 0.008218949697038624, 0.018328271980863065, 0.007908306160970824, 0.04519402529695071, 0.02629411406815052, 0.05585125109064393, 0.02748529819655232, 0.04032734737847932, 0.05679545960447285, 0.0273788259801222, 0.038566149305552244, 0.021236296015558764, 0.08204921992728487, 0.036522411901387386, 0.032129769679158926, 0.04158144707616884, 0.0423626020347001, 0.02436876962747192, 0.029690690207644366, 0.06682132923742756, 0.025551235376042314, 0.028886157597298734, 0.027323036883899476, 0.04506225697696209, 0.059886319140787236, 0.015025713892100612, 0.035800699261017144, 0.03431119032029528, 0.043001735903089866, 0.009407186571479542, 0.12022787166642956, 0.05791887451778166, 0.02006633731070906, 0.013677658298547613, 0.08746102757868357, 0.06477398128481582, 0.07124361654859968, 0.05872204899787903, 0.03243103710701689, 0.045818353319191374, 0.053873872820986435, 0.04011102246295195, 0.028086105703550857, 0.020529068242467474, 0.06821605478762649, 0.0452651601517573, 0.045975480825291015, 0.04088409543328453, 0.14596033579437062, 0.016187047913263086, 0.04626793153875042, 0.10084418405313045, 0.03904951750882901, 0.05688708886737004, 0.030711614526808262, 0.02644093314302154, 0.049407223632442765, 0.05633135013340507, 0.017051995055226143, 0.03293563444458414, 0.028655195674218703, 0.03388246645045001, 0.009632386645535007, 0.033023200448951684, 0.11094744113506749, 0.03313990317110438, 0.04490464707487263, 0.012758877619489795, 0.008773918452789076, 0.07892987676314078, 0.08081660169409588, 0.021566753966908436, 0.013593990424851654, 0.07085393706802279, 0.03919883391063195, 0.04394607800350059, 0.008355344380106544, 0.05123313698277343, 0.013771225494565442, 0.0175125923124142, 0.09352630368084647, 0.036836422004853375, 0.0343599642656045, 0.05880789321963675, 0.04352002957602963, 0.02105624727846589, 0.03520257647323888, 0.04573358892230317, 0.047843399734119885, 0.029316978034330532, 0.07035450136754662, 0.07478345316485502, 0.020040514282300137, 1.160617796704173, 17.123218774795532, 56.044161692261696, 102.10376635193825, 90.17929941415787, 88.59191179275513, 91.99139937758446, 102.84608691930771, 99.33459654450417, 84.69779714941978, 70.94017177820206, 53.91556531190872, 28.48877940326929, 29.828826896846294, 41.332422718405724, 26.976340860128403, 37.032824233174324, 41.30701348185539, 39.860655292868614, 39.17895287275314, 43.509132117033005, 51.647182032465935, 64.19984266161919, 60.71561962366104, 65.5453884601593, 68.23179870843887, 68.36435839533806, 67.20879480242729, 67.31509789824486, 63.87986183166504, 67.79960229992867, 62.73005872964859, 66.92336171865463, 66.30182906985283, 53.874037340283394, 63.44181753695011, 55.07457911968231, 72.0915099978447, 49.530912190675735, 51.85679778456688, 64.62383151054382, 50.014869421720505, 46.18196189403534, 64.86019402742386, 44.345968812704086, 54.56713154911995, 44.599202424287796, 20.731615349650383, 34.469109401106834, 28.588871732354164, 33.308853060007095, 38.87011304497719, 64.90199938416481, 97.40540966391563, 98.09693455696106, 95.29955506324768, 97.59004935622215, 87.51748904585838, 91.71089842915535, 102.83829733729362, 123.7882299721241, 92.21500977873802, 59.91912916302681, 28.99825606495142, 2.5753053976222873, 0.07200115636806004, 0.25164360471535474, 0.05377317822421901, 0.03439059270021971, 0.04214409891574178, 0.08512767817592248, 0.030822116605122574, 0.058032950037159026, 0.0998580182204023, 0.05576032315730117, 0.046228234059526585, 0.05707972071832046, 0.03358496542205103, 0.05132581267389469, 0.04830457030038815, 0.020047703837917652, 0.03452320335782133, 0.014396969163499307, 0.03297186238341965, 0.06481998701929115, 0.03632447369454894, 0.027731116060749628, 0.038086807253421284, 0.022826575623184908, 0.04540505127806682, 0.007622595539942267, 0.04771256280946545, 0.05467046445119195, 0.017226613126695156, 0.03907715879904572, 0.025317017280030996, 0.02280538359627826, 0.11643392368569039, 0.006484920722868992, 0.029009869904257357, 0.04886874354269821, 0.024284899518534075, 0.08270827675005421, 0.011182544822077034, 0.023687654320383444, 0.020745337496919092, 0.024723397473280784, 0.028149520367151126, 0.013798903892165981, 0.034131976499338634, 0.05091558683488984, 0.08609724958660081, 0.020643106654461008, 0.08636028156615794, 0.07626385966432281, 0.012526543650892563, 0.048206929641310126, 0.06293946644291282, 0.08155351722962223, 0.06196840331540443, 0.0757966331730131, 0.03306902806798462, 0.1527797823655419, 0.24299991462612525, 0.11895971198100597, 0.10272871222696267, 0.17219644360011443, 0.1926670881221071, 0.1791603269521147, 0.13109079853165895, 0.12161697173723951, 0.24947837402578443, 0.1381569349905476, 0.1720688387285918, 0.20889699691906571, 0.14376561215613037, 0.18321785610169172, 0.11504283465910703, 0.09081868920475245, 0.1137075106089469, 0.14894565450958908, 0.09437656743102707, 0.1760091382311657, 0.12994841061299667, 0.1740349511965178, 0.20315142319304869, 0.0793220275954809, 0.17187884892337024, 0.18042034527752548, 0.11484912669402547, 0.1431363302981481, 0.17402312136255205, 0.2783100988017395, 0.2450146822957322, 0.22849980363389477, 0.10810237348778173, 0.1662896160269156, 0.19693231472047046, 0.12500144715886563, 0.09339799376903102, 0.18686724855797365, 0.2096519392216578, 0.15896739409072325, 0.19127155363094062, 0.15354903327533975, 0.14244263002183288, 0.17646480206167325, 0.14869025180814788, 0.12021820890367962, 0.13772616279311478, 0.10667034759535454, 0.14749065914656967, 0.16564140940317884, 0.156933790713083, 0.3222497535170987, 0.21205581491813064, 0.6497704179491848, 16.566655039787292, 60.10763704776764, 115.29327660799026, 98.428915143013, 90.7703272998333, 89.05047878623009, 104.523985683918, 85.89547008275986, 87.95004263520241, 58.18862222135067, 53.43349277973175, 45.83705820143223, 36.915060952305794, 86.42273738980293, 61.03631101548672, 104.90602478384972, 79.31831181049347, 67.21232861280441, 69.27209168672562, 78.00072491168976, 116.92172482609749, 122.6184019446373, 104.74793806672096, 114.27253738045692, 128.22329878807068, 139.39796715974808, 133.2802650332451, 131.5102744102478, 113.22535917162895, 122.95862048864365, 111.13534212112427, 139.32572543621063, 119.00500863790512, 110.48414066433907, 116.75301387906075, 116.77650421857834, 125.917878895998, 110.5700996518135, 119.03666093945503, 151.70289248228073, 159.3408778309822, 134.524105489254, 138.24287474155426, 114.56908866763115, 125.63437610864639, 120.90772613883018, 55.30114196240902, 67.4232704937458, 61.515731289982796, 62.16786369681358, 45.462679490447044, 60.74099846184254, 79.03675451874733, 86.11658781766891, 83.54012086987495, 88.81034687161446, 84.62633818387985, 97.15591505169868, 113.38281512260437, 137.7321669459343, 103.96817430853844, 62.73937202990055, 27.85821843892336, 1.8160275276750326, 0.45812042837496847, 0.5516319558955729, 0.23869290511356667, 0.17546968592796475, 0.16729581984691322, 0.15727391699329019, 0.33529092092067003, 0.15899449732387438, 0.16626214171992615, 0.1802161507657729, 0.20699169603176415, 0.18507190427044407, 0.15193134429864585, 0.12034369865432382, 0.15616287739248946, 0.1600783594767563, 0.12057924148393795, 0.08747177387704141, 0.097057998937089, 0.09603206141036935, 0.17709335661493242, 0.13450712693156675, 0.09791629272513092, 0.15521779685514048, 0.18710578966420144, 0.13294731063069776, 0.1209615143307019, 0.15073903952725232, 0.11894604162080213, 0.17714834975777194, 0.18773765419609845, 0.0800758640980348, 0.15912213188130409, 0.12012892111670226, 0.13213436206569895, 0.11927013008971699, 0.08676041048602201, 0.15038720215670764, 0.08334627884323709, 0.1765267862356268, 0.1130669703707099, 0.1563251850893721, 0.10608970609609969, 0.1264947818708606, 0.13463119918014854, 0.13698765164008364, 0.18235458992421627, 0.10624870381434448, 0.23096645018085837, 0.1818055342300795, 0.09307697037002072, 0.1817202169331722, 0.21280913933878765, 0.1488560179132037, 0.16003172291675583, 0.09994799620471895, 0.12486836523748934], [0.07028662454104051, 0.01182332904136274, 0.013258942290121922, 0.05079857241071295, 0.05454718258988578, 0.055846909526735544, 0.07353443346801214, 0.014771928144909907, 0.04109488021640573, 0.042254137151758187, 0.052324762000353076, 0.03782290696108248, 0.009722599334054394, 0.028319796874711756, 0.05068463789939415, 0.04605827482009772, 0.03546305546478834, 0.03638926689745858, 0.10164051593164913, 0.03701996254676487, 0.041276068150182255, 0.10712008166592568, 0.04762030272104312, 0.06844965319032781, 0.028654232737608254, 0.03148178569972515, 0.09306379724876024, 0.030148396799631882, 0.051045503496425226, 0.011425994307501242, 0.0380615074391244, 0.040152052097255364, 0.01697493044048315, 0.014253987919801148, 0.04045659239636734, 0.014667637842649128, 0.04778124115546234, 0.06669347203569487, 0.0733178154041525, 0.026464396141818725, 0.08827352343359962, 0.026104601092811208, 0.047939155338099226, 0.039485254674218595, 0.06288980192039162, 0.07479759107809514, 0.05600554730335716, 0.07601970050018281, 0.03806752254604362, 0.03825781292107422, 0.034339057965553366, 0.1305498174042441, 1.386541798710823, 19.21223647892475, 65.13339936733246, 83.48247036337852, 83.01676735281944, 72.22163021564484, 75.04739418625832, 56.95824824273586, 51.20594210922718, 45.434621796011925, 32.23752714693546, 50.52248038351536, 36.1308666318655, 53.130261451005936, 81.55318468809128, 54.75191943347454, 34.90140080451965, 56.5721395611763, 58.759252801537514, 55.003253147006035, 56.034806594252586, 48.2977681607008, 40.887911170721054, 43.77303555607796, 38.68497557938099, 39.853709265589714, 40.4205172508955, 38.46255071461201, 35.79319775104523, 26.041845604777336, 20.188664384186268, 17.177981436252594, 14.438277147710323, 16.534124985337257, 20.806676521897316, 25.510056540369987, 29.657655581831932, 30.580228976905346, 39.91239711642265, 26.709980852901936, 53.149211034178734, 52.61767655611038, 56.5801115334034, 64.83475059270859, 83.44907775521278, 87.31136530637741, 82.5442399084568, 64.62532103061676, 81.7953608930111, 95.57135447859764, 64.50102210044861, 82.86507949233055, 66.75592750310898, 59.31518957018852, 62.81651169061661, 20.47545399516821, 24.443814754486084, 28.494598791003227, 31.351006217300892, 64.63449373841286, 67.30919301509857, 87.56291180849075, 64.19545009732246, 85.54193705320358, 98.3927334845066, 93.9897957444191, 57.47139170765877, 25.816481597721577, 5.720591610297561, 0.6754642829764634, 0.11886103602591902, 0.08362758992007002, 0.06644720517215319, 0.11318638193188235, 0.0740639706782531, 0.04784037548233755, 0.07399515132419765, 0.012346403073024703, 0.04748520215798635, 0.04176675764028914, 0.06315394712146372, 0.041726366252987646, 0.024090325096040033, 0.05325364887539763, 0.025716047821333632, 0.034817171763279475, 0.009790672829694813, 0.036202305054757744, 0.07530671180575155, 0.01085418993170606, 0.1323039279668592, 0.03444586785917636, 0.0782164947304409, 0.0688676604477223, 0.045777858031215146, 0.08710418071132153, 0.06318074607406743, 0.04405071711516939, 0.04727213898149785, 0.02211580595030682, 0.06283597394940443, 0.07601661316584796, 0.0923671580676455, 0.023866241026553325, 0.02986737701576203, 0.036596819627447985, 0.08014886916498654, 0.02311479052877985, 0.040736686351010576, 0.09810479081352241, 0.05413941325969063, 0.08284959651064128, 0.05197594146011397, 0.022497460959129967, 0.01095912404707633, 0.04749243067635689, 0.0376070273341611, 0.019074744523095433, 0.040014584083110094, 0.025819111724558752, 0.033137947611976415, 0.0537499193160329, 0.04851194491493516, 0.08384257525904104, 0.05413026628957596, 0.035691874436452053, 0.016745183784223627, 0.017832519188232254, 0.05255274605588056, 0.05373053441871889, 0.046793758010608144, 0.04434398790181149, 0.026038768883154262, 0.03012907869560877, 0.029660679610969964, 0.06988347508013248, 0.030208852149371523, 0.024984930314531084, 0.007950577037263429, 0.018199952792201657, 0.03302253993751947, 0.059362897227401845, 0.07168430383899249, 0.020147339018876664, 0.005861467507202178, 0.06363055435940623, 0.043530697948881425, 0.03907229031028692, 0.01287414614125737, 0.03773901829845272, 0.057248384910053574, 0.05907995342568029, 0.027479574382596184, 0.02483861033397261, 0.08723401202587411, 0.03856015646306332, 0.04197756097710226, 0.032505437411600724, 0.03279246302554384, 0.0322839471482439, 0.009532341427984647, 0.07700862712226808, 0.0477090116328327, 0.042768708954099566, 0.08458101219730452, 0.029677754573640414, 0.045622749166795984, 0.03982375194027554, 0.03897789654729422, 0.0243763432445121, 0.052884675314999186, 0.032626956672174856, 0.06849498357041739, 0.04383639599836897, 0.028776093386113644, 0.07330192602239549, 3.223079200834036, 31.64202120155096, 85.93067139387131, 100.38360625505447, 94.97193664312363, 89.45625901222229, 94.45253491401672, 84.59841728210449, 83.87204825878143, 75.4814524948597, 34.23263669013977, 47.551852986216545, 20.58903370052576, 35.42840592563152, 57.64451041817665, 30.553096532821655, 39.02223788201809, 52.8113179653883, 65.59639692306519, 58.938424587249756, 58.07289183139801, 47.61746786534786, 44.05054226517677, 45.010123774409294, 42.9485671967268, 41.10749378800392, 42.4530053883791, 41.39267988502979, 38.14605429768562, 26.868671737611294, 20.42988684028387, 16.52748104184866, 14.707806184887886, 16.4398330450058, 21.490664519369602, 25.073815248906612, 28.58091875910759, 31.25076949596405, 36.5811500698328, 29.302978813648224, 53.687562346458435, 54.550655633211136, 58.77632908523083, 65.66135823726654, 80.46048492193222, 84.00855213403702, 84.21368792653084, 69.49797436594963, 79.65322583913803, 77.39615455269814, 59.22610715031624, 69.31037083268166, 56.731753796339035, 33.380388021469116, 28.390081599354744, 17.530948296189308, 35.081051364541054, 45.21951153874397, 51.86718262732029, 99.88362908363342, 105.48632964491844, 115.49476459622383, 75.84639251232147, 97.49445408582687, 115.348100066185, 113.37757140398026, 81.20066240429878, 40.70680908858776, 12.72468214854598, 0.9198495943564922, 0.24090791906928644, 0.03552631984348409, 0.06583525246242061, 0.010275635722791776, 0.1161719232914038, 0.02863368637918029, 0.052442125233937986, 0.04009247619251255, 0.0539134738210123, 0.02930635047960095, 0.06457613955717534, 0.03756073216209188, 0.024672747749718837, 0.025111785616900306, 0.014416361482290085, 0.025761485812836327, 0.06125509549747221, 0.009599728437024169, 0.0596888002473861, 0.010792613011290086, 0.04923201369820163, 0.06375851546181366, 0.03415635605051648, 0.07065634767059237, 0.02263090467749862, 0.016781574995548, 0.019874479148711544, 0.02503175983292749, 0.039345341283478774, 0.0726953316188883, 0.012940408796566771, 0.048215943024843, 0.045460986948455684, 0.057972401918959804, 0.026183099907939322, 0.04023549547127914, 0.03370184625964612, 0.012742209910356905, 0.05252648516034242, 0.042412511465954594, 0.035735368001041934, 0.07628991646924987, 0.02628049194754567, 0.028608534994418733, 0.026517472688283306, 0.004029131332572433, 0.04211861356452573, 0.049377971881767735, 0.022876776347402483, 0.08278596476884559, 0.04927713256620336, 0.05388510522607248, 0.04269398210453801, 0.039387562064803205, 0.11457947475719266, 0.11298392404569313, 0.1359639479778707, 0.1228692643053364, 0.08758099575061351, 0.18998032057425007, 0.21801301947562024, 0.111865715298336, 0.18051724007818848, 0.07901439996203408, 0.15043245832202956, 0.18255363393109292, 0.1654850982595235, 0.11829562339698896, 0.09661399424658157, 0.12383530309307389, 0.18747981725027785, 0.19853903475450352, 0.22212273644981906, 0.12458061974029988, 0.13179297413444147, 0.1998714273213409, 0.18221246864413843, 0.10468405613210052, 0.09262644962291233, 0.09396987792570144, 0.1851285746670328, 0.1399570141802542, 0.10080424166517332, 0.16495271120220423, 0.19884836190612987, 0.140328073175624, 0.09915061047649942, 0.1803803732036613, 0.1155990149709396, 0.13517045852495357, 0.14669000054709613, 0.14907192351529375, 0.140464628348127, 0.13724440505029634, 0.26628502062521875, 0.08715101022971794, 0.1795033921371214, 0.16891573526663706, 0.1673909038072452, 0.07249250265886076, 0.14102781453402713, 0.15390447748359293, 0.17544234520755708, 0.06754300848115236, 0.09062449884368107, 0.28574695286806673, 2.4653865583240986, 32.40487776696682, 91.67613789439201, 108.26960429549217, 105.08010864257812, 91.04112356901169, 96.7478397488594, 74.67473298311234, 69.81166273355484, 62.38796308636665, 45.7953592389822, 71.654092669487, 54.646919667720795, 68.4352245926857, 106.91564574837685, 83.99589121341705, 56.70729450881481, 86.41698449850082, 89.0961979329586, 82.6090644299984, 85.11511355638504, 74.37248200178146, 64.00626584887505, 64.02450487017632, 56.563749611377716, 58.71437720954418, 59.412262961268425, 58.23390059173107, 52.34089560806751, 39.655048325657845, 29.47380244731903, 26.199860125780106, 22.975073866546154, 25.161164961755276, 34.190390557050705, 38.771873116493225, 46.96846269071102, 47.62567162513733, 57.03224927186966, 41.31939321756363, 80.93091487884521, 76.85979053378105, 85.49751743674278, 96.248759329319, 118.22494849562645, 117.74163722991943, 117.73931935429573, 94.22451674938202, 116.56098738312721, 130.7573828101158, 94.9333307147026, 126.52650743722916, 104.67462480068207, 91.72570243477821, 88.96750643849373, 33.93361173570156, 35.5147372931242, 38.52083578705788, 44.677672013640404, 89.23945784568787, 94.14765447378159, 110.59508711099625, 80.30087068676949, 105.92110991477966, 127.6068502664566, 127.02098250389099, 88.97183060646057, 40.126006454229355, 13.082548845559359, 1.231383893173188, 0.7174054824281484, 0.2869826287496835, 0.14120858686510473, 0.19388809916563332, 0.2277880097972229, 0.18682424852158874, 0.179531371104531, 0.10746087587904185, 0.10805513578816317, 0.1512207675841637, 0.2738375309854746, 0.15566130430670455, 0.09531470888759941, 0.06074786353565287, 0.15848263807129115, 0.14120092790108174, 0.1482106462935917, 0.13475558313075453, 0.12200572353322059, 0.10681223138817586, 0.22395262029021978, 0.1708044862607494, 0.1761688632541336, 0.26457101572304964, 0.11798461157013662, 0.09614611466531642, 0.13518663734430447, 0.16755061398725957, 0.1026558481680695, 0.17337215394945815, 0.07253381802001968, 0.19738940347451717, 0.19024223933229223, 0.13464191579259932, 0.08290491619845852, 0.1736282542697154, 0.14212717273039743, 0.0711040482565295, 0.13672751403646544, 0.20551632129354402, 0.13556070945924148, 0.2982621156843379, 0.11345513587002642, 0.09552541203447618, 0.11899195829755627, 0.10952207230729982, 0.09032691246829927, 0.13107481267070398, 0.12701648200163618, 0.14761180733330548, 0.1985644458909519, 0.10219613221124746, 0.18503684521419927, 0.14513790258206427], [0.06087637011660263, 0.03719310188898817, 0.06325895359623246, 0.0449824241513852, 0.05047977916547097, 0.04323303364799358, 0.016095919600047637, 0.07273672861629166, 0.03881625678332057, 0.08709765723324381, 0.030695853165525477, 0.04659829486627132, 0.02455420450132806, 0.02499671190889785, 0.03979401408287231, 0.02782819083222421, 0.03146713199384976, 0.0035684378281075624, 0.009608057189325336, 0.036007138769491576, 0.0229957760166144, 0.023218952810566407, 0.12652374047320336, 0.04010125951026566, 0.04476678943319712, 0.025887146257446148, 0.03876278133247979, 0.07877157666371204, 0.03351088053022977, 0.022801036466262303, 0.01677217940596165, 0.016274677000183146, 0.03311510430648923, 0.07220896513899788, 0.03214560711057857, 0.044293239843682386, 0.01156993848780985, 0.06830710888607427, 0.0282970797343296, 0.014279229289968498, 0.020511668590188492, 0.04653390984458383, 0.0353138726495672, 0.008621593569841934, 0.04802688832569402, 0.16242452576989308, 0.07331807515583932, 0.07720485838945024, 0.01835770370234968, 0.08939185092458501, 0.07167814401327632, 13.82923062890768, 61.4103439450264, 97.70427122712135, 80.56687161326408, 83.32484722137451, 69.05804917216301, 53.22450779378414, 58.971934989094734, 48.113432452082634, 48.19159805774689, 26.872197948396206, 60.95798581838608, 34.29441377520561, 71.90762266516685, 90.29477521777153, 56.730423867702484, 52.9891674220562, 36.75160512328148, 31.077950969338417, 19.503513649106026, 8.543096780776978, 6.180765917524695, 5.328013775870204, 4.249078296124935, 2.201610174961388, 1.6642294730991125, 1.7952833720482886, 1.1040673311799765, 0.661176455905661, 0.12047525175148621, 0.11563551379367709, 0.17578017082996666, 0.17607784626306966, 0.2433594554895535, 0.16611567145446315, 0.34058142453432083, 0.11703290365403518, 0.16419398394646123, 0.343068391084671, 0.18286520236870274, 0.5284455406945199, 0.4338198417099193, 2.128063696436584, 4.5666880533099174, 6.418564282357693, 5.873271692544222, 6.632687067613006, 7.57605342194438, 16.001028791069984, 18.695300817489624, 32.304509952664375, 39.89475466310978, 36.16676330566406, 42.141912281513214, 58.301905542612076, 79.83274340629578, 103.11038553714752, 71.00693419575691, 48.39289225637913, 49.69328127801418, 33.93471747636795, 32.24984608590603, 41.777390241622925, 68.7420429289341, 74.77184817194939, 64.05845984816551, 71.41910567879677, 82.1244764328003, 89.29293617606163, 78.80782440304756, 41.710152849555016, 3.07431077118963, 0.3948637977009639, 0.18239402765175328, 0.006712919157507713, 0.1775722051388584, 0.07877520576585084, 0.054495158037752844, 0.0539705301343929, 0.013309086425579153, 0.09076820089831017, 0.011177687465533381, 0.010255955821776297, 0.03348941019794438, 0.009392130250489572, 0.0307799496295047, 0.024156142462743446, 0.009614641894586384, 0.03418318839976564, 0.05931070198130328, 0.07629686297150329, 0.04400854457344394, 0.01567917955981102, 0.05079180402390193, 0.029789037762384396, 0.06635077792452648, 0.02286060494952835, 0.05008110485505313, 0.009431032704014797, 0.05011443470721133, 0.03254658207879402, 0.031098078652576078, 0.061984441126696765, 0.035075479972874746, 0.02555584411311429, 0.061049787764204666, 0.051504944858606905, 0.052172592040733434, 0.06230021012015641, 0.04939464051858522, 0.07882483318098821, 0.050035852400469594, 0.024918476556194946, 0.048008824451244436, 0.029914317856309935, 0.023957566008903086, 0.0316702949203318, 0.0652405917935539, 0.03187244110449683, 0.03201719329808839, 0.031125218993111048, 0.0314521406107815, 0.04356594625278376, 0.007483240151486825, 0.03221429287805222, 0.06754236281267367, 0.0639740499900654, 0.038678933487972245, 0.0778531095420476, 0.01639647271076683, 0.045500740088755265, 0.01197068988403771, 0.11221427979762666, 0.025138530763797462, 0.11285146552836522, 0.021506537959794514, 0.041588356471038423, 0.019833440237562172, 0.005705204139303532, 0.06504922159365378, 0.09222292908816598, 0.03617087138991337, 0.03848759297397919, 0.03832277681794949, 0.016181351929844823, 0.05931300263910089, 0.01778637986717513, 0.06952439434826374, 0.05331254200427793, 0.002074926856039383, 0.02224327537987847, 0.03721870598383248, 0.05356787791242823, 0.010376444424764486, 0.0211801618206664, 0.02581850130809471, 0.02073050938633969, 0.015604985201207455, 0.08030224882531911, 0.03443044231971726, 0.03646763398137409, 0.03927238445612602, 0.11704155709594488, 0.0313845495111309, 0.02384106923273066, 0.040016112907323986, 0.03288644860731438, 0.04086830995220225, 0.04152849855017848, 0.08438467702944763, 0.1630815045791678, 0.03963975497754291, 0.11837653233669698, 0.06661249630269594, 0.06049343304766808, 0.7571421470493078, 23.50207708775997, 81.77803382277489, 113.73558059334755, 90.1288153231144, 99.20710578560829, 94.52396348118782, 86.2809593975544, 89.456866979599, 52.58414715528488, 42.1413879096508, 19.756046198308468, 41.292171478271484, 31.956239640712738, 52.97494478523731, 81.40091925859451, 66.71096831560135, 58.36087077856064, 39.09164875745773, 30.83452083170414, 19.713585376739502, 10.20503830164671, 6.7951288260519505, 4.760224018245935, 2.9571112850680947, 1.9267212878912687, 1.6170206875540316, 1.4735440677031875, 0.9772481268737465, 0.39636816072743386, 0.07368133417912759, 0.43933857057709247, 0.3048366238363087, 0.13655435614055023, 0.1769469160353765, 0.3246656816918403, 0.4596856178250164, 0.09975925320759416, 0.054575131871388294, 0.27619275148026645, 0.15601171675371006, 0.34461974690202624, 0.25734208174981177, 1.4083946635946631, 4.163567209616303, 4.609268568456173, 3.7525017047300935, 4.605603190138936, 5.658997865393758, 14.877034854143858, 21.203443631529808, 32.45103769004345, 42.29279838502407, 41.370549872517586, 47.76778779923916, 56.64083607494831, 68.45812976360321, 57.305640801787376, 33.222012519836426, 21.81636594235897, 31.612420789897442, 30.89810661971569, 42.062010169029236, 69.72361385822296, 110.20413368940353, 104.7099021077156, 83.95543098449707, 89.01625022292137, 96.16684332489967, 104.36556458473206, 97.05816149711609, 61.27695210278034, 7.282783733680844, 0.2551427122671157, 0.3722786111757159, 0.02624737360747531, 0.14880348870065063, 0.062122666131472215, 0.0156876159235253, 0.015603124265908264, 0.08033671416342258, 0.0491363211767748, 0.07205142203019932, 0.025891524928738363, 0.027024598894058727, 0.02718179875955684, 0.06683113300823607, 0.026030189656012226, 0.004725930539279943, 0.031630872035748325, 0.07124342359020375, 0.06176634989969898, 0.029907911266491283, 0.042780126896104775, 0.0430902555672219, 0.06052446966350544, 0.10623975351336412, 0.04624326997145545, 0.02564960148447426, 0.00991929537121905, 0.009555373053444782, 0.03904349126969464, 0.028884393141197506, 0.10878572080400772, 0.04749970743432641, 0.08210280298953876, 0.029100801548338495, 0.03752300137421116, 0.020598965566023253, 0.07202561755548231, 0.03610863859648816, 0.016326111544913147, 0.010663311404641718, 0.08313887083204463, 0.029428227826429065, 0.03138622676488012, 0.04709558575996198, 0.03509294270770624, 0.03431451885262504, 0.010552738822298124, 0.06864453374873847, 0.01850639298936585, 0.052651336663984694, 0.04580565517244395, 0.005116200491102063, 0.061312363322940655, 0.2816393435932696, 0.1460115736699663, 0.14027030440047383, 0.16893394757062197, 0.13829766103299335, 0.12948342540767044, 0.12977375357877463, 0.18045414268271998, 0.11645422884612344, 0.3989073447883129, 0.10904109381954186, 0.16432645730674267, 0.1599052461097017, 0.11734980071196333, 0.11355210488545708, 0.17053266725270078, 0.22186151531059295, 0.14595959364669397, 0.1634679557173513, 0.13751233520451933, 0.19235226907767355, 0.1308232097653672, 0.23535163752967492, 0.13641930010635406, 0.12218689662404358, 0.21794060070533305, 0.12228945401147939, 0.22235916985664517, 0.13843917375197634, 0.09266122666304, 0.11278302466962487, 0.14897534041665494, 0.13268515438539907, 0.1982759582460858, 0.15934989700326696, 0.14714487770106643, 0.19368377106729895, 0.16785845684353262, 0.1653737761080265, 0.19440107163973153, 0.108997552015353, 0.10804657882545143, 0.17719316063448787, 0.15793144499184564, 0.20846528961556032, 0.1866192079614848, 0.169255520158913, 0.19563848414691165, 0.18186284287367016, 0.1510163801140152, 0.5154592031612992, 23.437073975801468, 91.19446814060211, 124.11416888237, 100.03266468644142, 103.60647931694984, 90.21880209445953, 71.21944919228554, 75.13410553336143, 59.92099106311798, 68.95108491182327, 43.069089129567146, 97.40157946944237, 56.12540893256664, 100.47923192381859, 122.59313330054283, 81.91651359200478, 85.80960229039192, 58.831483125686646, 49.19858202338219, 30.092091970145702, 18.399287201464176, 10.685599464923143, 10.199985522776842, 6.99520661495626, 4.030653666704893, 4.576209867373109, 4.775019949302077, 3.0810416350141168, 2.003177460283041, 0.5777324584778398, 0.5943496199324727, 0.38288811687380075, 0.3690033353632316, 0.33801590907387435, 0.38729549443814903, 0.7234301778953522, 0.3516958875115961, 0.3985660459147766, 0.5371076508890837, 0.5065552121959627, 2.3717973427847028, 0.9711483854334801, 3.834727155044675, 8.390818051993847, 11.07710575684905, 8.750865831971169, 12.543416675180197, 13.072985708713531, 26.59380778670311, 31.80326744914055, 50.51545076072216, 63.872877806425095, 57.520405277609825, 66.0850279033184, 93.44961673021317, 119.31555837392807, 148.66892248392105, 100.19919455051422, 71.38724058866501, 71.28127187490463, 46.025410294532776, 40.76414421200752, 56.82369366288185, 96.02508053183556, 97.67709508538246, 83.94898653030396, 88.90536457300186, 104.45410743355751, 116.5836949646473, 110.35340487957001, 66.49410635232925, 7.591031268239021, 0.5129660619422793, 0.6480521976482123, 0.18084158829879016, 0.30493624974042177, 0.20205218374030665, 0.16070020501501858, 0.14397756953258067, 0.2268077663029544, 0.216504248091951, 0.07771269520162605, 0.08488066916470416, 0.1521783013595268, 0.1225273939780891, 0.16322551091434434, 0.13753847364569083, 0.10842775329365395, 0.15058464312460274, 0.1318834419362247, 0.1912390920915641, 0.07955873559694737, 0.1483623858075589, 0.1440694771008566, 0.08921056651161052, 0.18113169382559136, 0.06367837835568935, 0.12688010494457558, 0.11419948772527277, 0.18670737510547042, 0.08614081365521997, 0.16614253720035776, 0.1591983504476957, 0.22018274758011103, 0.20345381868537515, 0.13103715609759092, 0.1584207874839194, 0.15095776529051363, 0.1604023959953338, 0.11774486818467267, 0.21248047181870788, 0.06431206114939414, 0.10215722140856087, 0.08711314585525542, 0.1566396775888279, 0.10880267145694233, 0.1458877685945481, 0.15853694843826815, 0.1307118430850096, 0.20288132596760988, 0.2168368935235776, 0.13288131885929033, 0.18001093209022656, 0.0770932319574058, 0.2650194213492796], [0.03482512758637313, 0.043224569453741424, 0.04820885922526941, 0.037759093393106014, 0.01742756816383917, 0.054599095819867216, 0.005886189837838174, 0.08595802268246189, 0.044247853802517056, 0.06101435763412155, 0.007567921520603704, 0.050385771319270134, 0.027807162077806424, 0.015090333617990837, 0.012020685589959612, 0.047898507909849286, 0.03543000762874726, 0.028753428196068853, 0.019995196889794897, 0.08871255573467351, 0.09051354776602238, 0.026954425120493397, 0.022517103752761614, 0.036478973997873254, 0.02917935973528074, 0.026703015173552558, 0.026803359105542768, 0.024982431132229976, 0.032746887736720964, 0.06106731729232706, 0.03881043092405889, 0.007451261471942416, 0.015787234406161588, 0.022490432820632122, 0.061484856996685266, 0.05293012072797865, 0.051575497127487324, 0.0753544393228367, 0.05248456494882703, 0.0858347667963244, 0.02336746583750937, 0.08707024971954525, 0.1252061314880848, 0.03991213801782578, 0.08164299797499552, 0.04569544253172353, 0.019256320229033008, 0.02045791297859978, 0.11532266886206344, 4.501286912709475, 44.90788646042347, 90.43180346488953, 85.43378725647926, 72.61079773306847, 71.41418874263763, 53.621662482619286, 54.42545235157013, 33.94041337072849, 44.73279565572739, 51.639757230877876, 73.15607607364655, 73.35037484765053, 65.254947245121, 51.93059362471104, 48.22559863328934, 28.86511690914631, 19.137353897094727, 11.079076901078224, 5.5285347159951925, 1.9839065568521619, 0.2483930127345957, 0.27381321822758764, 0.05698138244042639, 0.07460043954779394, 0.046877394343027845, 0.10239344701403752, 0.05902646684262436, 0.0248659232238424, 0.035601618146756664, 0.005247468789093546, 0.16671327844960615, 0.15041293983813375, 0.22490144125185907, 0.27418850746471435, 0.2409912770963274, 0.20388895471114665, 0.38802268041763455, 0.22943928837776184, 0.24683996482053772, 0.17857373342849314, 0.15483348310226575, 0.03427523326536175, 0.12004179297946393, 0.030831538169877604, 0.11299578356556594, 0.10878350920393132, 0.1489357987884432, 0.05832709284732118, 0.10728098670369945, 0.10328406875487417, 0.09841019942541607, 0.36376680072862655, 0.4217681352747604, 3.416087944060564, 6.105587426573038, 13.750602398067713, 24.16296422481537, 41.524662002921104, 77.76307046413422, 97.28912830352783, 66.25522077083588, 68.4665197134018, 66.25445321202278, 45.24550974369049, 19.572837129235268, 33.067683801054955, 63.067351430654526, 58.141052573919296, 70.04883840680122, 67.54759222269058, 70.89559257030487, 89.0142971277237, 64.12215203046799, 17.3494890332222, 2.2226726822555065, 0.2510980371152982, 0.3871189820347354, 0.02844143487891415, 0.03136594015813898, 0.0062556903230870375, 0.02809055116813397, 0.08397914527449757, 0.09270065696910024, 0.021382968516263645, 0.045173842590884306, 0.07805972345522605, 0.06129494882770814, 0.04004605856607668, 0.03066390741878422, 0.05032173510699067, 0.025260409965994768, 0.03235178686736617, 0.00360949088644702, 0.04356701123469975, 0.06310262018814683, 0.05987738368276041, 0.07849259593058378, 0.06913558318046853, 0.014049350902496371, 0.09111713647143915, 0.023480073759856168, 0.025245338802051265, 0.02634707558172522, 0.032880006765481085, 0.09049491985933855, 0.08097764773992822, 0.019168518592778128, 0.09756696381373331, 0.03205251952749677, 0.06852776423329487, 0.01915758304676274, 0.003475057792456937, 0.08988346438854933, 0.05055948953668121, 0.04784564473084174, 0.03819489364104811, 0.04709593456937, 0.042547511839075014, 0.023018066422082484, 0.029364609072217718, 0.026270992457284592, 0.04846030999033246, 0.03517893906973768, 0.03939512826036662, 0.06548932258738205, 0.026941337346215732, 0.0045690089791605715, 0.04921412793919444, 0.05599752097623423, 0.02332135434699012, 0.00652162038932147, 0.036592663600458764, 0.03334687331516761, 0.02380782472755527, 0.046839708084007725, 0.06100686936406419, 0.0483677010925021, 0.03475875731965061, 0.03678835681057535, 0.024423677423328627, 0.02168112448998727, 0.033453360374551266, 0.04778098882525228, 0.037227548673399724, 0.03817298173089512, 0.05023646604968235, 0.05477147817146033, 0.04552163154585287, 0.035686197006725706, 0.019516010688676033, 0.012111430769436993, 0.029606929565488826, 0.1363543324987404, 0.028366349943098612, 0.0528730755468132, 0.06338493316434324, 0.02736504244239768, 0.07857207252527587, 0.05940773779002484, 0.008250323990068864, 0.09314607916167006, 0.06836780172307044, 0.05918802497035358, 0.048740377969807014, 0.03717464467626996, 0.03055952434806386, 0.023607828916283324, 0.04795723405550234, 0.12364365087705664, 0.04256089647242334, 0.05192200587771367, 0.06592055491637439, 0.02126794304786017, 0.04376195116492454, 0.23007412150036544, 9.923640601336956, 63.173760920763016, 108.866977840662, 93.33042472600937, 88.85790511965752, 97.68063649535179, 85.28980538249016, 82.78034403920174, 40.943247601389885, 39.12333145737648, 36.94918692111969, 49.572227373719215, 51.06437310576439, 71.29596188664436, 54.91042412817478, 52.20512889325619, 31.35476041585207, 20.57821188122034, 10.251455660909414, 5.050752628594637, 1.8984804907813668, 0.1814352025394328, 0.3111705870833248, 0.04831088226637803, 0.13597779645351693, 0.05983589020615909, 0.1603492136928253, 0.07306398605578579, 0.05060000708908774, 0.08141830534441397, 0.09410350903635845, 0.24885612772777677, 0.35875956004019827, 0.3027806372847408, 0.23115623218473047, 0.4132238187594339, 0.3112852043705061, 0.7317370071541518, 0.3184539353242144, 0.29876330285333097, 0.4109566466649994, 0.1926817381172441, 0.04053763121191878, 0.3734344616532326, 0.2050565162790008, 0.033739243081072345, 0.10459729164722376, 0.06929890761966817, 0.06569727978785522, 0.10213474175543524, 0.13694582419702783, 0.16925035481108353, 0.11614011484198272, 0.4363320115953684, 2.6219032471999526, 5.014681164175272, 11.97757288813591, 25.166212990880013, 44.04755562543869, 71.7594838142395, 70.39656534790993, 46.925726383924484, 38.10992203652859, 33.76070201396942, 31.34207669645548, 28.429470285773277, 60.33578060567379, 97.46044591069221, 94.06357258558273, 97.72265464067459, 87.57151454687119, 86.7563670873642, 103.46622884273529, 82.50362008810043, 31.425202935934067, 6.670336872339249, 0.051404636178631335, 0.49266387009993196, 0.04599167077685706, 0.03603537748858798, 0.04500543072936125, 0.021582326080533676, 0.04714020367828198, 0.047483762391493656, 0.05317964933055919, 0.008708382174518192, 0.05622585755190812, 0.08317868705489673, 0.029350836666708346, 0.026215040088573005, 0.05554622468480375, 0.05546307816985063, 0.03320592091768049, 0.03262352794990875, 0.022050957086321432, 0.02537589371058857, 0.02903875614720164, 0.05123259892570786, 0.05959823967714328, 0.0689162191702053, 0.03777631121920422, 0.08748395252041519, 0.04086191263922956, 0.03414170234464109, 0.03710460820002481, 0.08246628465713002, 0.05691067060979549, 0.03705003808136098, 0.009647357619542163, 0.02169575593143236, 0.03430137541727163, 0.007891378700151108, 0.05989145109197125, 0.0462580646853894, 0.08945451787440106, 0.059560278823482804, 0.041234044037992135, 0.020260178862372413, 0.02612354997836519, 0.0417905360518489, 0.07116000619134866, 0.023050047420838382, 0.02798173933115322, 0.05453504105389584, 0.03744731344340835, 0.03509290560032241, 0.026295448078599293, 0.07665807366720401, 0.11424784606788307, 0.1990196347469464, 0.21369416528614238, 0.12397840400808491, 0.11896486990735866, 0.12622376438230276, 0.15577909798594192, 0.17641850688960403, 0.17366163607221097, 0.15634644019883126, 0.17576132027897984, 0.10596970823826268, 0.19894277793355286, 0.08983918785816059, 0.14662676956504583, 0.11484317466965877, 0.07410254009300843, 0.07663588345167227, 0.14268764265580103, 0.17672565212706104, 0.0943479873239994, 0.12979914987226948, 0.25422630831599236, 0.07580955396406353, 0.16629436577204615, 0.19069217378273606, 0.08682401254191063, 0.10803376193507574, 0.0986704631941393, 0.11716623790562153, 0.13323124148882926, 0.1848445102223195, 0.09336634117062204, 0.19172990403603762, 0.1536466256948188, 0.15847998118260875, 0.14494225761154667, 0.23325000889599323, 0.15491765749175102, 0.13938962743850425, 0.2038302953587845, 0.2344135331804864, 0.138426631456241, 0.23972475755726919, 0.14907725213561207, 0.19092079979600385, 0.2137444235268049, 0.26396889647003263, 8.543572705239058, 70.45274153351784, 121.4466056227684, 104.9284739792347, 93.39769631624222, 95.94986736774445, 73.70976716279984, 65.6229119002819, 47.12029494345188, 59.5059697329998, 75.69557100534439, 103.1435577571392, 103.07117164134979, 90.98596572875977, 77.73409321904182, 71.50440350174904, 46.375740095973015, 31.968034207820892, 16.850644201040268, 9.185158777981997, 4.176757726818323, 1.0458991024643183, 0.5652055400423706, 0.24099342932458967, 0.25385152373928577, 0.3385500475997105, 0.3184308100026101, 0.24738102016272023, 0.16091648169094697, 0.23574436723720282, 0.2925823407713324, 0.4376727162161842, 0.5851919925771654, 0.7512690871953964, 0.6471735541708767, 0.9964072331786156, 0.5534196412190795, 1.3767425995320082, 0.580404190113768, 0.6773262424394488, 0.8186965878121555, 0.5022748012561351, 0.1862608693772927, 0.7848714559804648, 0.44583307520952076, 0.1927649328717962, 0.3492354601621628, 0.23174134141299874, 0.3301920398371294, 0.30671787913888693, 0.28665920079220086, 0.7856215594802052, 1.0543582797981799, 1.4357433398254216, 6.74931088462472, 10.818413738161325, 22.60936439037323, 40.42147099971771, 67.19644546508789, 117.12679222226143, 137.21042454242706, 91.41686260700226, 97.80267834663391, 93.47411781549454, 60.971190109848976, 26.39448568224907, 45.57024411857128, 84.31974783539772, 81.1131303012371, 90.74068129062653, 87.44113594293594, 89.74280163645744, 113.52058812975883, 94.09008756279945, 32.94134058058262, 6.024135947227478, 0.41318632545880973, 0.6033240852411836, 0.263696409529075, 0.12495869945269078, 0.12692963588051498, 0.13583499239757657, 0.15700944524724036, 0.2226803862140514, 0.1268795705982484, 0.1422947645187378, 0.12923203030368313, 0.22951783728785813, 0.11523660941747949, 0.10835150504135527, 0.11160275753354654, 0.1289631353574805, 0.08962527121184394, 0.15638443815987557, 0.11269283146248199, 0.15281654836144298, 0.1967735099606216, 0.1621707557933405, 0.17899693571962416, 0.12834338267566636, 0.12081873253919184, 0.11415957502322271, 0.07914051311672665, 0.14521287434035912, 0.13623469829326496, 0.14112665376160294, 0.10501832686713897, 0.1583397449576296, 0.17104391794418916, 0.15119112620595843, 0.15547106217127293, 0.13379837590036914, 0.17786695651011541, 0.23740520467981696, 0.16205254651140422, 0.12309688841924071, 0.11500084394356236, 0.11807078233687207, 0.08127538254484534, 0.19595162593759596, 0.21022964181611314, 0.13820262160152197, 0.10910212062299252, 0.1132727085496299, 0.1569799819844775, 0.3004785248776898, 0.16024900891352445], [0.011773745227401378, 0.04774275337695144, 0.040524417272536084, 0.03395650681341067, 0.031065208931977395, 0.08661408122861758, 0.08909162992495112, 0.0605676812119782, 0.045229945244500414, 0.017807694348448422, 0.0394744972436456, 0.019476845700410195, 0.04358974692877382, 0.059629398747347295, 0.03851355329970829, 0.030741573173145298, 0.043497086080606095, 0.02184688317356631, 0.0754845749179367, 0.008660183393658372, 0.05412655555119272, 0.006499854589492315, 0.03565060360415373, 0.0539252702583326, 0.027212844652240165, 0.04407265871122945, 0.04453492394532077, 0.017892605319502763, 0.024024216436373536, 0.02662945906195091, 0.04978716984624043, 0.036346463530207984, 0.0777205397025682, 0.033108692150563, 0.014113202505541267, 0.06234321015654132, 0.03907882120984141, 0.04365181644971017, 0.055110925386543386, 0.06057338832761161, 0.12804934376617894, 0.07052044558804482, 0.07218540937174112, 0.04024500980449375, 0.25242784700822085, 0.029431587900035083, 0.03499119797197636, 4.664365611970425, 31.368684768676758, 80.93807369470596, 92.92033553123474, 63.941950500011444, 69.88723307847977, 56.83397211134434, 43.38729925453663, 41.88384532928467, 30.64011186361313, 61.39306627213955, 76.78431138396263, 73.12641486525536, 53.983619660139084, 46.53620928525925, 21.709829159080982, 11.209687292575836, 3.296326445415616, 0.8546937780920416, 0.4573284083744511, 0.050215611699968576, 0.09338842006400228, 0.0518577952607302, 0.07015985087491572, 0.01980032004212262, 0.04476390990021173, 0.22598932584514841, 0.11866073036799207, 0.042472922286833636, 0.040752475542831235, 0.2118996818899177, 0.04969804533175193, 0.1650889843585901, 0.1454085935256444, 0.1803997135721147, 0.09117800742387772, 0.0597253844171064, 0.09941523807356134, 0.09964859898900613, 0.07655095207155682, 0.12789539265213534, 0.20603873388608918, 0.10156980410101824, 0.1151197508443147, 0.11107917976914905, 0.08758537442190573, 0.07029130007140338, 0.22662890871288255, 0.26745675306301564, 0.052263686957303435, 0.18032414809567854, 0.13610195775981992, 0.15604515792801976, 0.04853626880503725, 0.12091591677744873, 0.019139457945129834, 0.18695553444558755, 0.21428026899229735, 0.12313561368500814, 0.5779360444284976, 3.6655794689431787, 11.78338335826993, 28.868664018809795, 45.79543523490429, 51.75984598696232, 51.320612356066704, 85.40919497609138, 71.47278159856796, 38.789804354310036, 21.2617914006114, 21.017772294580936, 33.18816773593426, 50.842392817139626, 57.851663902401924, 67.80240654945374, 71.56754851341248, 82.37133398652077, 71.78604438900948, 28.57117608189583, 3.453055922873318, 0.35274638270493597, 0.04930845861963462, 0.04172908993496094, 0.08753473768592812, 0.03484532513539307, 0.12904742849059403, 0.06438433891162276, 0.02525400894228369, 0.0705558386107441, 0.03904957316990476, 0.036888257309328765, 0.04278060558135621, 0.07169467906351201, 0.041204172594007105, 0.038741785974707454, 0.02643163774337154, 0.10823040880495682, 0.04637106780137401, 0.020066953293280676, 0.03994694474386051, 0.015219544311548816, 0.017897470097523183, 0.013872210456611356, 0.02655519791005645, 0.049261528911301866, 0.04485435172682628, 0.008896642775653163, 0.04095827680430375, 0.07760279055219144, 0.07271564420079812, 0.026940294628730044, 0.022914178734936286, 0.02576940638391534, 0.043892884568776935, 0.04465933387109544, 0.0059437076743051875, 0.012794250233127968, 0.022987922238826286, 0.01011904256301932, 0.04658190824557096, 0.058869840286206454, 0.05705705552827567, 0.04048450085974764, 0.08837376532028429, 0.007836949589545839, 0.036229790493962355, 0.024118984983942937, 0.05087256453407463, 0.0895905758079607, 0.0383837034314638, 0.07092355052009225, 0.08047493916819803, 0.03895613677741494, 0.022540353384101763, 0.03324918812722899, 0.07294678609468974, 0.025225107856385875, 0.029811324457114097, 0.012369789074000437, 0.020736791666422505, 0.04475136018299963, 0.05344973542378284, 0.07860132798668928, 0.04417290801939089, 0.04575823935738299, 0.03088486333581386, 0.03928479316527955, 0.04327502436353825, 0.04579543950967491, 0.021923576714470983, 0.06044579829904251, 0.010094899571413407, 0.06074435317714233, 0.04736200935440138, 0.022317074544844218, 0.03495908524200786, 0.039710592973278835, 0.07229020062368363, 0.024734689250180963, 0.05986108611978125, 0.028389462277118582, 0.03366641984030139, 0.02455123591062147, 0.010961448824673425, 0.04474805020436179, 0.026879805882344954, 0.04045908230182249, 0.05338234841474332, 0.028384632751112804, 0.09311906498624012, 0.09397945163073018, 0.05003648322599474, 0.0468903077126015, 0.3322654223302379, 0.03290141401521396, 0.13430588616756722, 9.15067657828331, 45.63339672982693, 101.712356954813, 104.3767511844635, 76.98647573590279, 95.93564093112946, 85.43502599000931, 72.07433491945267, 49.464050978422165, 21.60679768770933, 33.45049045979977, 52.81522415578365, 64.91464510560036, 51.69390432536602, 49.72046501934528, 23.767302855849266, 13.397041819989681, 3.1377421924844384, 0.95151103916578, 0.3695578087354079, 0.2214420831296593, 0.09485834001679905, 0.008121241316985106, 0.017588983428140637, 0.16008526145014912, 0.1607636289554648, 0.40108219371177256, 0.06296662904787809, 0.10664995337720029, 0.06704994782921858, 0.2748820889974013, 0.18664880481082946, 0.11186086165253073, 0.1813026549643837, 0.38445775920990855, 0.28578783036209643, 0.14439945080084726, 0.21738847251981497, 0.3337173006730154, 0.2694506070110947, 0.2223663983750157, 0.16435516357887536, 0.21152278961380944, 0.14999416074715555, 0.06634199831751175, 0.12135402881540358, 0.24157197796739638, 0.2360962936654687, 0.2640785265248269, 0.043022230311180465, 0.10103190288646147, 0.047984070115489885, 0.11556267942069098, 0.05112619721330702, 0.13138506008544937, 0.07504821434849873, 0.2767779497662559, 0.17088647873606533, 0.17454369342885911, 0.16592507308814675, 1.8365693441592157, 8.987444937229156, 27.36264143139124, 45.34579016268253, 55.07609523832798, 53.95062603056431, 64.46029588580132, 34.118357822299004, 22.51737702637911, 28.32834631204605, 39.70556661486626, 61.366300508379936, 82.35193982720375, 79.87691223621368, 85.52586391568184, 81.70109555125237, 96.88285410404205, 89.96971026062965, 46.24767556786537, 7.7549221739172935, 0.20859758486039937, 0.04410224071762059, 0.024648908110975754, 0.09591539579560049, 0.03992209763964638, 0.0690831801330205, 0.05572723450313788, 0.04984315004548989, 0.01610479383089114, 0.034684843121794984, 0.0493600749905454, 0.032263230095850304, 0.033757833880372345, 0.058880571741610765, 0.0659817449923139, 0.02121261593856616, 0.018966507850564085, 0.03906284648110159, 0.014502020167128649, 0.015263358855008846, 0.047087021375773475, 0.016607723191555124, 0.0020864275938947685, 0.038406246167141944, 0.06344052002532408, 0.02596286758489441, 0.06845694108051248, 0.04221329676511232, 0.07318808056879789, 0.04337813094025478, 0.05370021768612787, 0.018854972331610043, 0.02761952673608903, 0.049533125275047496, 0.06821529037551954, 0.03042605094378814, 0.016398736261180602, 0.018484505199012347, 0.022242306877160445, 0.06201778211107012, 0.017195064428960904, 0.06881632609292865, 0.02959017929242691, 0.009862763199635083, 0.02489715836418327, 0.08466835555736907, 0.061222919684951194, 0.021449850864883047, 0.06841934387921356, 0.09565153261064552, 0.15812668920261785, 0.27963958214968443, 0.13176971522625536, 0.1223585702246055, 0.1723858990590088, 0.1394792937207967, 0.0895028687955346, 0.13258581049740314, 0.10099049846758135, 0.06739042291883379, 0.0808531376242172, 0.18685252434806898, 0.14513370202621445, 0.22281521960394457, 0.16402394307078794, 0.16303195880027488, 0.1021290197968483, 0.12499393662437797, 0.11806618102127686, 0.11850107213831507, 0.18031812185654417, 0.17523574613733217, 0.13372068788157776, 0.13360412616748363, 0.09267152767279185, 0.1699603526503779, 0.1033822623139713, 0.16529528656974435, 0.14027837896719575, 0.21442011930048466, 0.14027864614035934, 0.15162983938353136, 0.11077101778937504, 0.06452531728427857, 0.1485927336034365, 0.12761395541019738, 0.10037379601271823, 0.11733005958376452, 0.1363070131628774, 0.3484633890911937, 0.1275190495653078, 0.11530533229233697, 0.2208454260835424, 0.4042616137303412, 0.14252284134272486, 0.25135746225714684, 8.560080919414759, 48.05705487728119, 111.94662138819695, 115.40445104241371, 81.36829420924187, 92.47544020414352, 79.0648578107357, 56.33255861699581, 56.678340062499046, 46.00943215191364, 88.83638307452202, 102.10636541247368, 99.23827171325684, 77.72568047046661, 68.77001702785492, 37.540887370705605, 21.05828382074833, 7.036593044176698, 2.6662601670250297, 0.9641341399401426, 0.7156775845214725, 0.20477068552281708, 0.09494765748968348, 0.19768495636526495, 0.38380805344786495, 0.3163451672298834, 0.8249684481415898, 0.37229651177767664, 0.6040609488263726, 0.4901313059963286, 0.7561788987368345, 0.778342931298539, 0.688700278988108, 0.34700388147030026, 0.5112507508601993, 0.3943634417373687, 0.15262833971064538, 0.3002452530199662, 0.26055685768369585, 0.26323612954001874, 0.3455704974476248, 0.5669673392549157, 0.31812424364034086, 0.4380675684660673, 0.41472951765172184, 0.28737831220496446, 0.5450071301311255, 0.8211010869126767, 0.7080033619422466, 0.3708845312939957, 0.5955207289662212, 0.3106308972928673, 0.3279755712719634, 0.12484736245824024, 0.3103226685198024, 0.279282905976288, 0.4222954163560644, 0.2912196092074737, 0.3724754584254697, 2.0573518658056855, 6.5996986627578735, 17.744329646229744, 47.30477124452591, 71.61375403404236, 77.88638904690742, 76.27669662237167, 122.47129663825035, 102.91249975562096, 53.07455264031887, 31.483854688704014, 30.346813201904297, 45.609898790717125, 69.14275422692299, 78.70133131742477, 86.16537719964981, 93.7819392979145, 109.75078761577606, 101.17524057626724, 48.44384752213955, 7.364901602268219, 0.4657607793342322, 0.15217242354992777, 0.12198851312859915, 0.17500143527286127, 0.11328321736073121, 0.2489329400123097, 0.21847190422704443, 0.16614436288364232, 0.16191302274819463, 0.08216253845603205, 0.12008074831101112, 0.19388879678444937, 0.17260121094295755, 0.19859146006638184, 0.22282007324974984, 0.0744942827441264, 0.2745098574087024, 0.16272528853733093, 0.16133980272570625, 0.12680112558882684, 0.1260670821648091, 0.12299928115680814, 0.15176504384726286, 0.10421475904877298, 0.09683997821412049, 0.15575809520669281, 0.1587858350831084, 0.16464887594338506, 0.13351371773751453, 0.24897822586353868, 0.13929044682299718, 0.09208895658957772, 0.15964644437190145, 0.10265735472785309, 0.1497922817361541, 0.15427850506966934, 0.09465529583394527, 0.1773478984250687, 0.08457590622128919, 0.13362069090362638, 0.08849744423059747, 0.1522989448858425, 0.11136868415633217, 0.16408177121775225, 0.16196978220250458, 0.09044409758644179, 0.13954492926131934, 0.2324866209528409, 0.1303653937065974], [0.04419691649673041, 0.047496018960373476, 0.07005695209954865, 0.05942628034972586, 0.01904530723550124, 0.05301337114360649, 0.01788624325854471, 0.03978285960329231, 0.03237542427086737, 0.026034777984023094, 0.01166302514320705, 0.004716088269560714, 0.026409098718431778, 0.07844684994779527, 0.05211151328694541, 0.04103460298210848, 0.023364569606201258, 0.040884848713176325, 0.06068553797376808, 0.009996909175242763, 0.04217644913296681, 0.01828482108976459, 0.07600305412779562, 0.028307508764555678, 0.022635773166257422, 0.04190619605651591, 0.033305583929177374, 0.030877250756020658, 0.041041148724616505, 0.027182064077351242, 0.04418799217091873, 0.05966764532786328, 0.0415203720331192, 0.02470526309480192, 0.04636762423615437, 0.0698691961588338, 0.037241571553749964, 0.06117381919466425, 0.058928091457346454, 0.0579377436224604, 0.05211611460254062, 0.005028337627663859, 0.21913550299359486, 0.06494693880085833, 0.2279893693048507, 0.36043835745658726, 23.504894636571407, 80.74492245912552, 98.96358445286751, 74.17053043842316, 65.1272664964199, 69.96609404683113, 47.63590067625046, 33.664817959070206, 42.50439763069153, 50.15323519706726, 71.05058625340462, 62.0021203905344, 42.08371840417385, 32.959199622273445, 20.689255222678185, 4.613938992843032, 1.4107284508645535, 0.21369780180975795, 0.054101114728837274, 0.03846023369987961, 0.005087320741949952, 0.021774128581455443, 0.014958077335904818, 0.14818231109529734, 0.06909633841132745, 0.1017806408344768, 0.11556524725165218, 0.050782820326276124, 0.07480596992536448, 0.008863395487423986, 0.13206084491685033, 0.09380134360981174, 0.056467311587766744, 0.04775204877660144, 0.0553980400582077, 0.1081579974561464, 0.13460329442750663, 0.0872216626885347, 0.06873289385112002, 0.11651756372884847, 0.15027579094748944, 0.4207257443340495, 0.6060056132264435, 0.17131229338701814, 0.21697763440897688, 0.1481101446552202, 0.05606993603578303, 0.03718536128872074, 0.08259863185230643, 0.03904547651472967, 0.06838082641479559, 0.08449926463072188, 0.09332806861493737, 0.1246456170338206, 0.10780930679175071, 0.2065002458402887, 0.013398778683040291, 0.24923040764406323, 0.1856031929492019, 0.21401207166491076, 0.03504912259813864, 0.042126766056753695, 0.12259137452929281, 0.6672067323233932, 7.276923973113298, 25.073231980204582, 36.066881865262985, 42.787102460861206, 61.4234684407711, 89.86935764551163, 70.96689954400063, 57.86677949130535, 25.731320567429066, 27.223006524145603, 50.84317937493324, 59.42059591412544, 75.55336743593216, 63.629291877150536, 75.4880641400814, 92.1137984097004, 68.09909462928772, 18.34671702235937, 1.0457259742543101, 0.28712660539895296, 0.09169006705633365, 0.09194898753776215, 0.04296162282116711, 0.040842961898306385, 0.07955526234582067, 0.017815075007092673, 0.08609912722022273, 0.02423309204459656, 0.06246964243473485, 0.00224518620143499, 0.09653104440076277, 0.03192679971107282, 0.0548731375602074, 0.046664509281981736, 0.05799464779556729, 0.032331214533769526, 0.08917370403651148, 0.011302818202238996, 0.06854228806332685, 0.00704860136465868, 0.018184517975896597, 0.027179453572898638, 0.03411684781895019, 0.04413421615026891, 0.022490197188744787, 0.029910310258856043, 0.04398779041366652, 0.028994166059419513, 0.0598802632157458, 0.05824393520015292, 0.05848376764333807, 0.026832891016965732, 0.03770723953493871, 0.01977199783141259, 0.03403362337849103, 0.02310291431058431, 0.068093021545792, 0.05083939053292852, 0.09844983753282577, 0.019914104268536903, 0.059159856755286455, 0.019351040537003428, 0.024181423723348416, 0.015260060936270747, 0.007866933283366961, 0.008496246682625497, 0.023018159190542065, 0.03050181308935862, 0.017233542930625845, 0.023098400197341107, 0.010334061298635788, 0.11558996076928452, 0.07349037216044962, 0.031540567506453954, 0.033438669561292045, 0.009377449641760904, 0.03767621405131649, 0.03991418634541333, 0.03980698311352171, 0.0047281713614211185, 0.010030888406618033, 0.07215414269012399, 0.06242004470550455, 0.01688834592641797, 0.04240176516759675, 0.030350902925420087, 0.06518546506413259, 0.006784246043025632, 0.007588186326756841, 0.06423058817745186, 0.03714042795763817, 0.053650003974325955, 0.018693360398174264, 0.08302514412207529, 0.03060258190089371, 0.13578829646576196, 0.006388635874827742, 0.04819603491341695, 0.03090181213337928, 0.042515632885624655, 0.061189493353595026, 0.08441970639978535, 0.01682923386397306, 0.06064812630938832, 0.01995078862819355, 0.03683671515318565, 0.04859358487010468, 0.037318413524189964, 0.0722020112152677, 0.0898187120037619, 0.3151153097860515, 1.7802265612408519, 38.44898924231529, 100.98132938146591, 114.00893792510033, 81.6236025094986, 91.3074740767479, 99.42345097661018, 74.1130319237709, 50.885782688856125, 35.55275805294514, 36.584136709570885, 42.30399638414383, 56.98420464992523, 44.49773266911507, 37.67035022377968, 21.723149344325066, 4.717712374404073, 1.1797621194273233, 0.23785864206729457, 0.06309093878371641, 0.03403616894502193, 0.047421151102753356, 0.054566170438192785, 0.025653750089986715, 0.09987285375245847, 0.0958469623583369, 0.10414449250674807, 0.105791830283124, 0.02763758133369265, 0.22886097722221166, 0.29107302019838244, 0.37296150578185916, 0.06154730130219832, 0.22672420047456399, 0.32630475936457515, 0.3190456348238513, 0.813839795300737, 0.8750890055671334, 0.8837576466612518, 1.03675453690812, 1.37573933461681, 1.267231882084161, 0.8854676142800599, 1.3727599382400513, 0.9698203566949815, 0.7772789290174842, 0.34332101815380156, 0.6793112203013152, 0.34887801215518266, 0.13323553110240027, 0.26219617284368724, 0.20107211836148053, 0.09095372297451831, 0.06967381836147979, 0.19772800093051046, 0.08919343774323352, 0.1395238225813955, 0.052920606394764036, 0.12796211172826588, 0.23778548114933074, 0.16626574855763465, 0.07196284670499153, 0.04128653985389974, 0.01900830931845121, 0.30623966886196285, 5.821827203035355, 20.962177477777004, 37.179572358727455, 45.76840728521347, 64.08625915646553, 64.50912326574326, 39.0099835395813, 34.24899861216545, 22.890205420553684, 39.41605255007744, 82.98615619540215, 84.74434465169907, 90.91260686516762, 78.76991763710976, 85.78916698694229, 103.37867394089699, 86.42152905464172, 31.750062704086304, 1.7288149637170136, 0.41620137460995466, 0.050838685492635705, 0.010104429675266147, 0.08475887530948967, 0.019684363178384956, 0.021471937179740053, 0.014039727102499455, 0.03507309025735594, 0.035964253765996546, 0.05300308497680817, 0.03957774111768231, 0.08721394435269758, 0.027267754303466063, 0.07294454480870627, 0.011969660154136363, 0.06499810988316312, 0.036784033800358884, 0.040086950903059915, 0.012694840479525737, 0.04244200812536292, 0.02891627766075544, 0.0425418269878719, 0.035227052503614686, 0.04759239425766282, 0.020234417061146814, 0.018921567098004743, 0.025869425626297016, 0.03834005772660021, 0.034770672500599176, 0.04863764617766719, 0.009464625090913614, 0.0360960814577993, 0.024583235463069286, 0.050745100670610555, 0.0381456744071329, 0.03804638618021272, 0.10328166419640183, 0.0436152025940828, 0.036629340538638644, 0.07364888006122783, 0.030630119290435687, 0.03296230352134444, 0.02206334724178305, 0.008098002817860106, 0.034160460127168335, 0.045579567304230295, 0.0324964796891436, 0.10461660975124687, 0.294223555829376, 0.11120423165266402, 0.061889776479802094, 0.1086664576723706, 0.22339608374750242, 0.1309550745645538, 0.12436479577445425, 0.10360706626670435, 0.10750682966317981, 0.08521562267560512, 0.09259340920834802, 0.080375662073493, 0.23308100702706724, 0.13158318382920697, 0.13817100611049682, 0.17059353820513934, 0.15941479039611295, 0.22783412685384974, 0.11229836512939073, 0.17864371795440093, 0.13123967335559428, 0.13682672433787957, 0.11544760200195014, 0.159693333262112, 0.11520225540152751, 0.1229909691028297, 0.22932618507184088, 0.15477534325327724, 0.12696037563728169, 0.13179895584471524, 0.15032667259220034, 0.11567602763534524, 0.2235701767494902, 0.1656148850452155, 0.17045370273990557, 0.14486194238997996, 0.17163502372568473, 0.14980491308961064, 0.09238435362931341, 0.18119542946806177, 0.10533298263908364, 0.2896727656479925, 0.16540714306756854, 0.5819037440232933, 1.4810637454502285, 41.851968839764595, 111.56792610883713, 125.4428967833519, 90.43557286262512, 84.2114232480526, 93.51900100708008, 62.938329353928566, 44.309034794569016, 59.44795444607735, 73.81740018725395, 101.1149150133133, 89.46240708231926, 65.8048765361309, 54.51294265687466, 34.127868711948395, 9.087049942463636, 3.046929440461099, 0.4346519079990685, 0.20314558991231024, 0.14118694583885372, 0.17105297214584425, 0.17548553820233792, 0.3676690725842491, 0.5671978206373751, 0.3632647229824215, 0.37472891563083977, 0.518227651482448, 0.17348801804473624, 0.2719947189325467, 0.3449590568197891, 0.44561859453096986, 0.2958016289630905, 0.2804764575557783, 0.2157614176394418, 0.2420002268627286, 0.2979676314862445, 0.5694437376223505, 0.3281325800344348, 0.4691243410343304, 0.4733690695138648, 0.6113133346661925, 0.9622167865745723, 1.253689646255225, 0.46372257464099675, 0.6304145534522831, 0.2790400158846751, 0.5013349454384297, 0.3266816516406834, 0.13485767296515405, 0.19163076794939116, 0.3333014901727438, 0.3181869105901569, 0.4657026246422902, 0.3958689031424001, 0.41132837359327823, 0.6148409703746438, 0.14286841498687863, 0.7454625831451267, 0.6161999912001193, 0.50940957153216, 0.1839425484649837, 0.16873316693818197, 0.5291951692197472, 2.5359209859743714, 13.90675026923418, 41.959518268704414, 59.69897277653217, 66.88613131642342, 92.48775914311409, 127.26054444909096, 95.90388223528862, 77.19617888331413, 38.40703949332237, 38.94855223596096, 68.18754628300667, 78.82546305656433, 96.28797322511673, 81.37004971504211, 94.31052893400192, 114.96112123131752, 95.26125311851501, 34.17045682668686, 1.651665922254324, 0.7273532298859209, 0.25084802240598947, 0.21620464307488874, 0.14746833534445614, 0.09702751151053235, 0.11532815333339386, 0.10137223696801811, 0.1404615113278851, 0.19230137259000912, 0.15992540284059942, 0.13323177583515644, 0.1848669082392007, 0.13670728309080005, 0.1665871133445762, 0.18839950149413198, 0.260424428852275, 0.2920221083331853, 0.15443815587786958, 0.12507523148087785, 0.2825015113921836, 0.06448371990700252, 0.1506541229900904, 0.10167329659452662, 0.17255374317755923, 0.2212261626846157, 0.19922739156754687, 0.09328685715445317, 0.1896579167805612, 0.09906823208439164, 0.16829555213917047, 0.17118940857471898, 0.1673586797551252, 0.11237649101531133, 0.16411524207796901, 0.07474089099559933, 0.12495271774241701, 0.12241220523719676, 0.16005520446924493, 0.1475250205839984, 0.17313454794930294, 0.16922400856856257, 0.10804696474224329, 0.09154024228337221, 0.07379310161923058, 0.09593487717211246, 0.1746834398363717, 0.06214789544173982], [0.02207779685704736, 0.08801878124359064, 0.03363467818417121, 0.07213011194835417, 0.011530747524375329, 0.08819105598377064, 0.034431024905643426, 0.004937638832416269, 0.10587924785795622, 0.04662085986637976, 0.043714346102206036, 0.07487936833058484, 0.0349104745691875, 0.07583711732877418, 0.07802512453054078, 0.0331031371752033, 0.021285426191752777, 0.03825269952358212, 0.026637509508873336, 0.053264647503965534, 0.05993611353915185, 0.04952738847350702, 0.04155835515120998, 0.01981379187782295, 0.06277436827076599, 0.03433856072661001, 0.048286662276950665, 0.060515029545058496, 0.0475783008732833, 0.05316955241141841, 0.029184766281105112, 0.0422827729198616, 0.028990497994527686, 0.018634224215929862, 0.10177959440625273, 0.033048734039766714, 0.0711559466435574, 0.1093803888943512, 0.029564766300609335, 0.027744984945456963, 0.04901948857877869, 0.016964067253866233, 0.18171518517192453, 0.2802185760810971, 15.619633756577969, 67.4359542131424, 96.57365709543228, 92.13838309049606, 62.02058359980583, 77.7161505818367, 46.337973922491074, 39.13845844566822, 40.77770568430424, 48.22932243347168, 72.95530244708061, 46.12536773085594, 43.985938131809235, 28.293173499405384, 12.655303571373224, 1.425254715140909, 0.4782742203678936, 0.15111890039406717, 0.016568372666370124, 0.090716183767654, 0.1761994100525044, 0.016791792513686232, 0.03941287301131524, 0.04476674490433652, 0.06755547656212002, 0.03469468399998732, 0.04679263736761641, 0.08334978178027086, 0.16229662403929979, 0.21532022568862885, 0.02827513628290035, 0.08304424700327218, 0.03699105960549787, 0.10349543241318315, 0.14210499735781923, 0.06458517149440013, 0.12929251533932984, 0.738508659414947, 0.44332663470413536, 0.3433238383149728, 0.3652414778480306, 0.9404478734359145, 0.1476407956215553, 0.19593926175730303, 0.32199671084526926, 0.4862701194360852, 0.08154473020113073, 0.060348009210429154, 0.014963902267481899, 0.07836288335965946, 0.17576894955709577, 0.13975230016512796, 0.03259391254687216, 0.10741469945060089, 0.17439539748011157, 0.08890310215065256, 0.059856581283384, 0.0816511022276245, 0.13646099396282807, 0.1344714593142271, 0.10218384224572219, 0.16112189332488924, 0.17892445757752284, 0.06875492821563967, 0.028627459760173224, 0.029870872531319037, 0.19721765565918759, 0.19177364622009918, 5.4198686219751835, 25.436232201755047, 46.33062891662121, 60.195279344916344, 49.32986877858639, 71.06996521353722, 75.71852937340736, 44.59228299558163, 19.115649461746216, 27.673443853855133, 50.00291146337986, 49.25014145672321, 59.67259459197521, 65.63846826553345, 80.21373376250267, 85.4308994114399, 49.90140751004219, 1.7176445131190121, 0.2665662352228537, 0.07524598186137155, 0.037689171949750744, 0.09541292471112683, 0.07008157655945979, 0.02204510154115269, 0.05485564885020722, 0.027741415215132292, 0.053609126480296254, 0.028298165125306696, 0.047603808488929644, 0.06283666414674371, 0.06315031059784815, 0.030024497100384906, 0.014455238888331223, 0.07778732557198964, 0.08215574780479074, 0.07587492233142257, 0.032410557541879825, 0.028885565734526608, 0.006643981059824, 0.02035937061009463, 0.028546463618113194, 0.05363116826629266, 0.018211968163086567, 0.018146096990676597, 0.06608796858927235, 0.026083618722623214, 0.020364081392472144, 0.040911117030191235, 0.04377825986011885, 0.0489709298562957, 0.01605396784725599, 0.030449014848272782, 0.043364724042476155, 0.03331551015435252, 0.0446490514150355, 0.03275761548138689, 0.0436307617201237, 0.060233447584323585, 0.05046045363997109, 0.03365313539688941, 0.04040107975015417, 0.030386396138055716, 0.024975473497761413, 0.024518015525245573, 0.021292586061463226, 0.03754529920115601, 0.07699342793785036, 0.03964345087297261, 0.013721352243010188, 0.07418451772537082, 0.07729630582616664, 0.04671586590120569, 0.02920653161709197, 0.021708168351324275, 0.003267941769991012, 0.03430704171478283, 0.03437730825680774, 0.008976284498203313, 0.10470332228578627, 0.06594667851459235, 0.041666404431452975, 0.037730372278019786, 0.09072843662579544, 0.04777423157065641, 0.04773283457325306, 0.04271471028914675, 0.003047452478313062, 0.0565130019094795, 0.03745835660083685, 0.02516941152862273, 0.05085418153612409, 0.048235869689960964, 0.045674758875975385, 0.06916528393048793, 0.06002139372867532, 0.029921774585091043, 0.06708167464239523, 0.02084749412460951, 0.0716291919525247, 0.0871278478007298, 0.02753615572146373, 0.09706907178042457, 0.07418992798193358, 0.09610364155378193, 0.06870930839795619, 0.01817474389099516, 0.18111336277797818, 1.4877611235715449, 26.02954376488924, 87.15413734316826, 115.34537181258202, 102.39340960979462, 74.73441258072853, 106.41276553273201, 75.90799480676651, 60.00704884529114, 39.92045648396015, 28.838144056499004, 49.50320407748222, 37.07416981458664, 50.27560383081436, 31.52700327336788, 13.027067072689533, 1.1638872837647796, 0.3897098492598161, 0.13424966105958447, 0.10420367878396064, 0.097676230216166, 0.08018417312996462, 0.16047211334807798, 0.04321255037211813, 0.2083053716341965, 0.11087027261964977, 0.12812502798624337, 0.19262347952462733, 0.298162103863433, 1.0163668496534228, 1.3257130002602935, 0.7048213889356703, 1.080483659170568, 0.5215762811712921, 2.378188599832356, 2.194019607268274, 1.626469949260354, 1.6074831993319094, 4.6087185479700565, 2.392258057370782, 2.622976452112198, 3.8439922453835607, 5.115512553602457, 3.400648422539234, 2.613718011416495, 5.0621790904551744, 2.8492288989946246, 1.6105165053158998, 1.479981041047722, 0.6927655264735222, 0.6999590154737234, 1.425661293324083, 0.852143521187827, 0.7102450635284185, 0.9125009668059647, 1.0032526846043766, 0.21271810750477016, 0.32490474230144173, 0.7050346524920315, 1.3106991746462882, 0.2612751378910616, 0.12813449779059738, 0.264389545773156, 0.17967680236324668, 0.20407953823450953, 0.03906653495505452, 0.02355129581701476, 0.21485920355189592, 0.11076032344135456, 3.3109582727774978, 21.098937839269638, 41.592689752578735, 63.70520420372486, 44.04821299016476, 43.179545402526855, 30.366157963871956, 22.439752891659737, 21.007877625524998, 41.48365460336208, 83.2375431060791, 80.32683089375496, 86.09030842781067, 81.68284893035889, 90.95041483640671, 98.16456332802773, 70.18117770552635, 7.424132823944092, 0.206696885288693, 0.060682495168293826, 0.1643262049765326, 0.019396827337914146, 0.07568304747110233, 0.12421110441209748, 0.023290490280487575, 0.037284675490809605, 0.07233199095935561, 0.07755312602967024, 0.04650014954677317, 0.05015649592678528, 0.09189352684188634, 0.028574646676133852, 0.009440832764084917, 0.050975270351045765, 0.019821541754936334, 0.045701093986281194, 0.03334872868435923, 0.011675322530209087, 0.057814279934973456, 0.045662008778890595, 0.006379717578965938, 0.07128226017812267, 0.06689503192319535, 0.02465688063239213, 0.07901755408965982, 0.03803940999205224, 0.05353828477382194, 0.07001197795034386, 0.012533120934676845, 0.006657247877228656, 0.03188802620570641, 0.03242241706175264, 0.04027663642773405, 0.056032335123745725, 0.05279159886413254, 0.03987585812865291, 0.0319801193109015, 0.07928957347758114, 0.06225503188034054, 0.013928273219789844, 0.04080094149685465, 0.0835033692419529, 0.03637510300904978, 0.03523159815813415, 0.07754060599836521, 0.17477595596574247, 0.23503626929596066, 0.17714788962621242, 0.1510820008115843, 0.24400035938015208, 0.2680427231825888, 0.2719153981888667, 0.12303796931519173, 0.1273785313242115, 0.1304841076489538, 0.10954120487440377, 0.09874149414827116, 0.1937995312619023, 0.16623031842755154, 0.21406111278338358, 0.12187592190457508, 0.09412553597940132, 0.14679217943921685, 0.16853093169629574, 0.1360804948490113, 0.07201959873782471, 0.07750716482405551, 0.17844790971139446, 0.11899111967068166, 0.12505103746661916, 0.14536724105710164, 0.14370790275279433, 0.1455023416201584, 0.16059048590250313, 0.19113997084787115, 0.23564085247926414, 0.1489928551018238, 0.07336396956816316, 0.1387059609987773, 0.1329149233060889, 0.10637380764819682, 0.27813228021841496, 0.20284458965761587, 0.18312349944608286, 0.11103856202680618, 0.10085734975291416, 0.43745627626776695, 1.7839629482477903, 26.490875110030174, 95.825484842062, 123.91594871878624, 111.62129044532776, 76.14852949976921, 102.654599994421, 63.19241791963577, 50.00747501850128, 53.686259016394615, 68.14378783106804, 105.98906546831131, 70.812529027462, 67.78808891773224, 46.601584777235985, 21.84825763106346, 3.8981578638777137, 0.8932056615594774, 0.4502830223646015, 0.13069897424429655, 0.2656880667200312, 0.4772502346895635, 0.6113173719495535, 0.20678104483522475, 0.396028850809671, 0.18022661504801363, 0.26573897805064917, 0.1483358020777814, 0.25244393676985055, 0.45231428055558354, 0.6839020270854235, 0.3456631471635774, 0.6235921382904053, 0.2620853256667033, 0.9345990372821689, 0.5412449163850397, 0.7199804973788559, 0.6407920341007411, 1.9574201968498528, 1.1953739379532635, 0.8062739262823015, 1.1805210099555552, 1.7963639390654862, 1.38352440437302, 0.9418848494533449, 3.569552209228277, 1.0775346611626446, 0.3638522367691621, 0.4858190123923123, 0.18435003206832334, 0.4467195854522288, 0.8796522044576705, 0.7078343897592276, 0.29048532829619944, 0.35807405307423323, 0.46178165066521615, 0.26283115439582616, 0.2549659920623526, 0.35937717533670366, 0.6354958307929337, 0.2618959889514372, 0.1904867176199332, 0.3045143239432946, 0.4564090061467141, 0.40007530711591244, 0.2925891982158646, 0.12037187058012933, 0.3338651068042964, 0.6122867355588824, 11.987476106733084, 43.77172842621803, 68.26703041791916, 82.86498829722404, 71.03848770260811, 98.75378251075745, 102.06500843167305, 61.49845741689205, 26.581369154155254, 37.64392264187336, 71.87475442886353, 68.21588516235352, 78.78892421722412, 84.23562034964561, 98.78715232014656, 111.32498234510422, 78.08995172381401, 6.976029518991709, 0.5186994199175388, 0.16031737555749714, 0.19449965853709728, 0.2545175567502156, 0.18855181988328695, 0.22127567877760157, 0.11936411567148753, 0.07702997128944844, 0.26847729517612606, 0.1326096779666841, 0.11041508376365528, 0.19307565526105464, 0.15826530754566193, 0.17696076451102272, 0.16045741882408038, 0.14715988392708823, 0.11197396495845169, 0.17158198985271156, 0.1382623941753991, 0.07705331925535575, 0.10354930491303094, 0.12420639177435078, 0.11834867953439243, 0.12233365632710047, 0.10975031240377575, 0.09314152979641221, 0.11671552420011722, 0.09158454849966802, 0.10200589749729261, 0.08019523855182342, 0.07091822932125069, 0.10780088341562077, 0.09815896759391762, 0.09666641955845989, 0.11149231111630797, 0.1017424202291295, 0.2271504604141228, 0.18385071511147544, 0.12235677422722802, 0.14755170821445063, 0.3118833457119763, 0.10852245133719407, 0.16559827578021213, 0.22881674522068352, 0.15254775731591508, 0.1571518337004818], [0.03310059903014917, 0.0739670090842992, 0.03790504044445697, 0.04532330742222257, 0.044492881279438734, 0.06165737293486018, 0.02413949423498707, 0.0077848313412687276, 0.028921895718667656, 0.02388375756709138, 0.023108690074877813, 0.03591109001717996, 0.06839473426225595, 0.04017294355435297, 0.06830882324720733, 0.00844339927425608, 0.017614160788070876, 0.02760596398729831, 0.04408779481309466, 0.02173438286263263, 0.022516218741657212, 0.020110246477997862, 0.014030647853360279, 0.025319900523754768, 0.09336129456642084, 0.043715711653931066, 0.02945462601928739, 0.07406387419905514, 0.02340983319299994, 0.02637779307406163, 0.032337066368199885, 0.012769363238476217, 0.02941114544228185, 0.046116540834191255, 0.09054324109456502, 0.06010422854160424, 0.026319341523048934, 0.058530467285891064, 0.031175401163636707, 0.008876892370608402, 0.3577667148783803, 0.07356097266892903, 12.252893764525652, 61.24591536819935, 85.57193264365196, 83.41785863041878, 57.337376698851585, 71.94688975811005, 84.94979202747345, 32.51998879015446, 44.68788966536522, 44.38653163611889, 68.15134182572365, 75.3703160583973, 51.35576047003269, 35.21750204265118, 10.563106387853622, 1.2774266162887216, 0.3699232719372958, 0.11038173906854354, 0.16694488789653406, 0.08379380873520859, 0.11051430890802294, 0.07095610853866674, 0.08345207199454308, 0.06313988342299126, 0.03822727354418021, 0.07132402824936435, 0.03669705780339427, 0.1724963603192009, 0.03276215371442959, 0.2597180230077356, 0.09024164712172933, 0.26910081796813756, 0.4690091003431007, 0.6714032508898526, 0.6538572767749429, 0.17249236756470054, 1.3771194918081164, 1.0479438677430153, 2.3863313253968954, 4.658280238509178, 4.046013867482543, 5.0074938498437405, 6.115050818771124, 9.263838306069374, 6.697737677022815, 1.3108404795639217, 3.625823864713311, 2.6888917526230216, 3.174749119207263, 0.6673515401780605, 1.4446020894683897, 0.45947229489684105, 0.7910407811868936, 0.7438809180166572, 0.26025130064226687, 0.2712874818826094, 0.13994131033541635, 0.08435552546870895, 0.378000540076755, 0.2416292717680335, 0.05438717555080075, 0.10980376930092461, 0.13562245614593849, 0.08569876081310213, 0.116903027810622, 0.07184405854786746, 0.10380193940363824, 0.0704084406606853, 0.1377767772646621, 0.05923699187405873, 0.07562202066765167, 0.16387212934205309, 3.5587738500908017, 24.119836539030075, 56.52596063911915, 62.948216423392296, 56.71387575566769, 59.631754383444786, 71.12516105175018, 40.691427513957024, 13.151766881346703, 26.13673411309719, 35.166573375463486, 59.489980190992355, 66.63782984018326, 74.27040427923203, 84.21198561787605, 71.42334625124931, 20.256158262491226, 1.4181403093971312, 0.35830094246193767, 0.014343389811983798, 0.07464671987690963, 0.004401477954161237, 0.1326373897609301, 0.07950279992655851, 0.038778956441092305, 0.020026296588184778, 0.07868145767133683, 0.05169719079276547, 0.07182830275269225, 0.037058064408483915, 0.022815751399321016, 0.009479281579842791, 0.03269134169386234, 0.033934019738808274, 0.03444947098614648, 0.05528375302674249, 0.015217740892694565, 0.0653236084326636, 0.025875492683553603, 0.027250132006884087, 0.0048956898626784096, 0.00546055840459303, 0.023213214153656736, 0.054343782176147215, 0.04406408690556418, 0.037936292283120565, 0.021391495793068316, 0.010157311407965608, 0.050816513830795884, 0.05032780587498564, 0.010002633916883497, 0.018779913370963186, 0.010627225401549367, 0.0864422220911365, 0.019501418209983967, 0.01605784556886647, 0.09548316898872145, 0.0525867327087326, 0.021742045537394006, 0.047958892755559646, 0.060341630451148376, 0.028934862893947866, 0.015534754838881781, 0.047235287638613954, 0.018158566927013453, 0.06911703691002913, 0.06191585925989784, 0.028252378324395977, 0.03297884970379528, 0.052210578869562596, 0.04103928222320974, 0.0497250075568445, 0.07312519097467884, 0.0735319398518186, 0.11020475169061683, 0.009122102601395454, 0.02244069222797407, 0.022823033723398112, 0.018512985116103664, 0.06319966341834515, 0.04910670577373821, 0.029209468666522298, 0.042649141541915014, 0.010263823514833348, 0.030855095792503562, 0.06207202568475623, 0.004918026652376284, 0.05647687787131872, 0.059230616825516336, 0.06415627693058923, 0.022725916278432123, 0.04182192147709429, 0.04372154493466951, 0.028972345062356908, 0.002628604274832469, 0.04890080803306773, 0.07816127152182162, 0.015862606924201827, 0.03581479635613505, 0.08099952625343576, 0.11678714887239039, 0.03453373443335295, 0.4274005611659959, 0.5509781534783542, 23.45966186374426, 83.67268055677414, 99.60758149623871, 95.59091582894325, 74.49646174907684, 112.11416959762573, 120.74838548898697, 49.431406930089, 40.03674924373627, 29.811496026813984, 40.357167050242424, 55.19143044948578, 49.51396130025387, 34.84602637588978, 11.391348894685507, 1.1451662820763886, 0.42604076850693673, 0.11473728503915481, 0.18271711422130466, 0.08560925038182177, 0.10073825731524266, 0.28160936082713306, 0.35197404446080327, 0.27564561052713543, 0.33927634300198406, 0.13382911565713584, 0.6875037588179111, 1.2664640857838094, 0.5036851787008345, 2.063056784681976, 1.4285728870891035, 1.755973887629807, 2.9940106300637126, 4.874677201732993, 4.576451629400253, 5.274126967415214, 5.962409684434533, 4.386878376826644, 6.1212900839746, 7.307107653468847, 7.523484192788601, 9.193552527576685, 10.37261500954628, 14.65536804869771, 10.033848937600851, 12.557124439626932, 6.754282442852855, 7.138071348890662, 6.809681570157409, 5.354784764349461, 6.64271947927773, 5.0420852936804295, 3.7305507576093078, 3.3356894832104445, 3.5500803915783763, 1.9051981740631163, 2.746276273392141, 1.7144948383793235, 2.3307082476094365, 3.2308257976546884, 0.3365231235511601, 0.5940114974509925, 0.40459276002366096, 0.13886881788494065, 0.3504745796089992, 0.09492593482718803, 0.1318934015580453, 0.16698469669790938, 0.08053834084421396, 0.06371812778525054, 0.15218238317174837, 0.22304451355012134, 2.325958264991641, 17.076751068234444, 46.755928695201874, 56.73219457268715, 52.39306300878525, 40.43716035783291, 28.96564621478319, 24.433825090527534, 27.805201783776283, 43.2407221198082, 63.17605219781399, 89.86865848302841, 89.69666451215744, 88.3363527059555, 95.00517725944519, 93.37682783603668, 39.91433121263981, 2.9369925521314144, 0.5349118437152356, 0.06138121978437994, 0.031152082883636467, 0.09601467289030552, 0.13158967019990087, 0.042597135543473996, 0.034142949152737856, 0.02149775278667221, 0.055891045049065724, 0.05021940407459624, 0.02103871218423592, 0.07082554991939105, 0.046308207893162034, 0.015989067032933235, 0.018915030632342678, 0.005559623987210216, 0.019961464422522113, 0.01895218996651238, 0.021823776405653916, 0.06646003690548241, 0.015858222686802037, 0.021028472401667386, 0.0338060475041857, 0.013735863085457822, 0.046151611022651196, 0.04681584803620353, 0.020694481827376876, 0.05933414642640855, 0.004976138670826913, 0.02462587184709264, 0.027076545520685613, 0.06249223341001198, 0.014257772872952046, 0.04925020373775624, 0.05731475888751447, 0.02313727389264386, 0.028527286522148643, 0.01839307074988028, 0.032799676700960845, 0.059457951501826756, 0.02884106655983487, 0.06663362524705008, 0.019723244295164477, 0.04343236709246412, 0.11842115767649375, 0.1136817061342299, 0.11609401262830943, 0.1308321749093011, 0.1225393425556831, 0.1720654100063257, 0.16812267625937238, 0.1336608559358865, 0.11944875761400908, 0.12363937610643916, 0.2091502325492911, 0.16339072783011943, 0.2690719335805625, 0.16700068255886436, 0.18850246706278995, 0.09290430971304886, 0.11036507785320282, 0.22558795753866434, 0.17655541829299182, 0.10183532227529213, 0.1115210322313942, 0.10359470208641142, 0.10604516239254735, 0.13093683257466182, 0.18041964765870944, 0.09102002644794993, 0.20834252354688942, 0.17349328729324043, 0.1734947122167796, 0.13304252817761153, 0.2126456590485759, 0.09902356221573427, 0.1426740168244578, 0.1932589805801399, 0.21905293164309114, 0.17075036885216832, 0.1668082139804028, 0.12309072117204778, 0.16000936942873523, 0.1442909933393821, 0.6674600124824792, 0.5305155389942229, 24.82942186295986, 92.65735924243927, 116.25792324542999, 104.85016778111458, 74.8871947824955, 93.03170755505562, 106.59234389662743, 41.07949309051037, 55.40525257587433, 63.1094341725111, 93.67173761129379, 106.10798388719559, 72.44058966636658, 55.01628264784813, 17.949923314154148, 3.221309445798397, 0.682095461525023, 0.3013017150806263, 0.4643143928842619, 0.20368078228784725, 0.2953039447311312, 0.33296102250460535, 0.2824763080570847, 0.17490357568021864, 0.17661824851529673, 0.13517694489564747, 0.18931030965177342, 0.46191847301088274, 0.22370018617948517, 0.8805797109380364, 0.27355610858649015, 0.36916447046678513, 1.5812839614227414, 2.1805588295683265, 2.5678326236084104, 2.750453199259937, 3.384522325359285, 6.262850062921643, 6.5659621730446815, 12.082827240228653, 13.290217202156782, 15.883805081248283, 16.697833500802517, 23.16465139389038, 15.898862723261118, 11.503687966614962, 11.028435118496418, 10.086571108549833, 9.432565402239561, 4.0060423873364925, 6.234170626848936, 3.2089928817003965, 1.2185471132397652, 1.7695517465472221, 1.8147624330595136, 1.0579395876266062, 0.8638043829705566, 0.5237867531832308, 1.2576211290434003, 0.9725435636937618, 0.1773253222927451, 0.48950190539471805, 0.5950525228399783, 0.2704986679600552, 0.35727134614717215, 0.10441338003147393, 0.5197580787353218, 0.37316571513656527, 0.653820822481066, 0.18103114765835926, 0.25292075180914253, 0.38360767357517034, 7.243819199502468, 36.591124534606934, 79.32669416069984, 87.21357375383377, 79.51001152396202, 80.2539812028408, 100.45272454619408, 55.82813948392868, 20.10973311960697, 36.14936023950577, 46.70594997704029, 79.2001685500145, 87.0727989077568, 91.76121532917023, 103.75448897480965, 104.55376848578453, 41.573489382863045, 2.632892020046711, 0.6680621614214033, 0.1598640569136478, 0.22157469007652253, 0.1207967427035328, 0.2557585760951042, 0.18065207346808165, 0.21496647357707843, 0.1316307406523265, 0.29940511216409504, 0.1746632534195669, 0.14096372266067192, 0.2304282595287077, 0.10674693723558448, 0.11449750454630703, 0.12035428910166956, 0.15163641481194645, 0.11296837605186738, 0.11598366269026883, 0.0958391475433018, 0.12450595226255246, 0.14069356606341898, 0.2799261105246842, 0.13608030189061537, 0.08040805681957863, 0.15614607516909018, 0.12911227735457942, 0.15413579007145017, 0.20945184136508033, 0.17299852712312713, 0.12960749765625224, 0.15991654159734026, 0.14952556870412081, 0.11825953275547363, 0.06959483900573105, 0.19281177723314613, 0.1268953486578539, 0.08700337479240261, 0.13436727662337944, 0.1184602540160995, 0.0934370158938691, 0.08970812457846478, 0.09967438119929284, 0.17458342801546678, 0.13182206632336602], [0.04473042419704143, 0.07221235675388016, 0.04346354471636005, 0.08508778031682596, 0.06316559883998707, 0.056133701364160515, 0.03968056567828171, 0.017593696065887343, 0.04252246806572657, 0.05564309722103644, 0.052990320036769845, 0.03437179038883187, 0.010015390507760458, 0.01161535328719765, 0.03312690074380953, 0.04748951774672605, 0.040598012346890755, 0.015157953475863906, 0.018681096407817677, 0.01057153649526299, 0.028307744396443013, 0.0367498801642796, 0.03308971914520953, 0.05016924602387007, 0.029710702219745144, 0.052485514897853136, 0.055479550137533806, 0.03243044709961396, 0.04693383467383683, 0.03218009842385072, 0.07086303579853848, 0.04709534456196707, 0.011745119663828518, 0.042472989080124535, 0.05017433715693187, 0.04880439933913294, 0.10599760556942783, 0.14174036536132917, 0.1350595965050161, 0.19762825628276914, 9.727884605526924, 43.27248081564903, 97.93334573507309, 93.11319038271904, 82.3503515124321, 67.42811903357506, 63.321022018790245, 30.65888475626707, 25.831069014966488, 53.03164914250374, 74.88692119717598, 72.9201391339302, 68.57913807034492, 37.45123118162155, 12.470725625753403, 0.9235832502599806, 0.510476304916665, 0.028736503518302925, 0.14780571567825973, 0.06928793125553057, 0.12471546797314659, 0.07761410088278353, 0.062385163764702156, 0.05787254594906699, 0.12014394218567759, 0.3485822514630854, 0.22902971191797405, 0.15233018930302933, 0.2773801877629012, 0.5127548763994128, 0.6580201908946037, 0.652161380276084, 6.961814956739545, 4.38715766184032, 2.6374959480017424, 2.147959666326642, 3.5412848135456443, 9.56137279048562, 17.80911237001419, 6.7109633423388, 7.915616501122713, 16.902760304510593, 5.723273791372776, 13.66150762885809, 20.923497453331947, 19.267221428453922, 11.773859169334173, 12.234212066978216, 8.409187216311693, 9.828564003109932, 12.32778774574399, 6.258169189095497, 11.176068596541882, 5.617401972413063, 5.401974907144904, 1.3660994893871248, 4.201448801904917, 2.5503245880827308, 4.47324869222939, 4.180747512727976, 0.6871282320935279, 2.731470367871225, 3.1247003423050046, 0.7526059029623866, 0.8879123080987483, 0.8074668247718364, 0.11106573947472498, 0.47367848572321236, 0.08628578478237614, 0.18425966816721484, 0.1684295988525264, 0.1176271635631565, 0.07704475487116724, 0.22731814126018435, 0.2651736099505797, 0.2744887210428715, 3.011274766176939, 27.840239703655243, 57.03319922089577, 66.78330883383751, 60.86855761706829, 51.930027455091476, 47.42817722260952, 42.02325224876404, 29.04174853116274, 23.497697822749615, 45.55943749845028, 58.33406701683998, 65.95071271061897, 74.404666274786, 89.48753893375397, 57.47621364891529, 3.732458967715502, 0.2535362297203392, 0.053043086736579426, 0.07353735010838136, 0.09608854627003893, 0.03437795392528642, 0.0672771934478078, 0.05813157775264699, 0.09616045295842923, 0.14438643353059888, 0.054007682047085837, 0.030839299179206137, 0.04707551437604707, 0.10596743726637214, 0.014073450292926282, 0.06938976875972003, 0.03492612646368798, 0.04423099220730364, 0.014710826199006988, 0.05121762238559313, 0.05027889092161786, 0.06587385156308301, 0.02412152312899707, 0.011910379253095016, 0.007057076227283687, 0.017375410025124438, 0.0589860012405552, 0.04061953834025189, 0.022208084592421073, 0.04423330770805478, 0.04537565851933323, 0.04030521282402333, 0.05037813461967744, 0.0911846496455837, 0.03844297876639757, 0.07053017514408566, 0.035016208348679356, 0.02328654762095539, 0.005907398563067545, 0.041074530527112074, 0.060210392766748555, 0.012865627213614061, 0.011608742606767919, 0.041447229668847285, 0.02395620602328563, 0.01862104923930019, 0.06515531160403043, 0.018474875832907856, 0.06699121426208876, 0.046336932718986645, 0.025881418732751627, 0.027479945456434507, 0.012076236271241214, 0.0453495052352082, 0.020702350448118523, 0.09963217526092194, 0.04067473186296411, 0.0350574086769484, 0.008962453648564406, 0.08366019988898188, 0.029650337783095893, 0.01641927705350099, 0.04694677401857916, 0.018242546502733603, 0.04069699258252513, 0.06661617735517211, 0.0442622737318743, 0.02338229023735039, 0.023123618375393562, 0.025716728741826955, 0.048078367399284616, 0.05273121772916056, 0.0452832425798988, 0.04215089698845986, 0.07471775825251825, 0.03638025351392571, 0.01416334849636769, 0.06031213379174005, 0.025258372770622373, 0.01673096980084665, 0.0297043160389876, 0.08446365638519637, 0.2587507967837155, 0.9280741936527193, 17.22989235073328, 64.11991015076637, 114.80255573987961, 105.63845068216324, 99.9221134185791, 99.08890932798386, 88.62791106104851, 37.2922021150589, 32.325416430830956, 30.693858079612255, 40.62271200120449, 49.49603386223316, 68.36077898740768, 39.41042885184288, 13.389407079666853, 0.36263324436731637, 0.1990285553620197, 0.029116325422364753, 0.18510745314415544, 0.03831934809568338, 0.09232225071173161, 0.5531797790899873, 0.175207499996759, 0.38827195297926664, 0.4070487344870344, 1.5329767973162234, 1.0619761585257947, 0.35243761958554387, 1.0457189683802426, 1.7862258455716074, 3.332020780071616, 2.414598958566785, 3.5293287551030517, 2.3461356572806835, 5.953066935762763, 6.304973177611828, 7.882820935919881, 12.35120303928852, 15.427926443517208, 13.80304528400302, 9.472012035548687, 14.267608355730772, 12.299831695854664, 14.798569064587355, 17.49713771045208, 16.42829116433859, 11.699615903198719, 8.793423548340797, 5.912352120503783, 6.61185278557241, 5.029184510931373, 5.86611857637763, 5.4732058849185705, 9.858793281018734, 12.120853699743748, 9.887676481157541, 6.575445989146829, 6.452214801684022, 6.7125388327986, 7.445883806794882, 4.879261180758476, 1.7919434700161219, 1.4958863938227296, 1.2199759553186595, 0.4524742579087615, 0.9942664636764675, 0.3379908838542178, 0.31947400246281177, 0.4508609476033598, 0.24755918013397604, 0.3354344522813335, 0.042406039938214235, 0.2553806151263416, 0.11779340464272536, 0.2965951629448682, 0.27766870509367436, 1.516640167683363, 19.983260706067085, 52.364093363285065, 67.00547531247139, 53.39661955833435, 33.454468846321106, 16.632469408214092, 27.47866440564394, 20.247540324926376, 36.95962116122246, 74.86713945865631, 85.44686615467072, 86.5839247405529, 83.21372598409653, 101.27506121993065, 81.29820317029953, 10.540296211838722, 0.07097194597008638, 0.1355888368561864, 0.04044501489261165, 0.13265377638163045, 0.026998111643479206, 0.05073012784123421, 0.0454652765620267, 0.03730470976734068, 0.0332221628195839, 0.06278105502133258, 0.004427803787621087, 0.031262455086107366, 0.0575406537973322, 0.06625541936955415, 0.036800869420403615, 0.04886878807155881, 0.04136087707593106, 0.023565400333609432, 0.027045930073654745, 0.07154570033890195, 0.017951396403077524, 0.006349087288981536, 0.04616054648067802, 0.003661094269773457, 0.03047291756956838, 0.04594231795636006, 0.03010969936440233, 0.013025205662415829, 0.03472778007562738, 0.0027838580899697263, 0.05051131302025169, 0.019833521873806603, 0.12238630428328179, 0.05213936237851158, 0.013349273722269572, 0.03134235470497515, 0.04378154015284963, 0.07147037977119908, 0.023158252552093472, 0.04009307362139225, 0.020701285466202535, 0.03492584444757085, 0.011787659568653908, 0.09389109894982539, 0.21589714160654694, 0.14384073234396055, 0.17913365416461602, 0.2597688155947253, 0.22230692266020924, 0.12238505747518502, 0.21145172155229375, 0.08199545132811181, 0.09339702897705138, 0.13499633583705872, 0.33752006536815315, 0.07258917481522076, 0.16224226914346218, 0.13712358340853825, 0.1292184935300611, 0.10352936340495944, 0.1672099088318646, 0.12154243784607388, 0.18848548672394827, 0.20422854664502665, 0.1874823702382855, 0.1505731398356147, 0.09766564719029702, 0.12376415339531377, 0.16410914162406698, 0.23206610523629934, 0.14671279932372272, 0.15948599204421043, 0.11430920683778822, 0.10091816875501536, 0.2073927377932705, 0.15095145703526214, 0.11460042558610439, 0.21889902505790815, 0.13257585087558255, 0.16277545772027224, 0.28188324300572276, 0.5424181034322828, 0.8351473300717771, 17.195192612707615, 69.86327156424522, 134.9994295835495, 114.52842324972153, 102.17400938272476, 89.86725255846977, 82.12117820978165, 40.17060466110706, 31.644741855561733, 69.77785214781761, 106.88346907496452, 103.26417088508606, 96.55809313058853, 54.99146617949009, 22.601101733744144, 1.9532887497916818, 0.7950348418671638, 0.11990723418421112, 0.5253329733386636, 0.24535255244700238, 0.3089108958374709, 0.27848931262269616, 0.10617522377287969, 0.4395297775045037, 0.43740845227148384, 1.4540935051627457, 0.8726509020198137, 0.7927807909436524, 1.0791543242521584, 1.5960201644338667, 5.36848065443337, 3.810438858345151, 13.438429199159145, 11.277363561093807, 11.160834264010191, 8.816056083887815, 12.865389548242092, 21.014797054231167, 31.513874977827072, 20.236623510718346, 20.25906130671501, 33.109872937202454, 29.112610928714275, 26.986668705940247, 41.063856929540634, 46.43119432032108, 33.23929399251938, 31.544113755226135, 21.550915986299515, 27.72701147943735, 33.97515490651131, 29.870227575302124, 25.28794515877962, 16.47663976997137, 15.74851144105196, 11.12286290153861, 10.54521219804883, 11.545875202864408, 10.223155729472637, 15.333804544061422, 6.47288759239018, 9.867686703801155, 10.57586420327425, 4.696439215913415, 1.819700743071735, 1.74894901458174, 0.6240111845545471, 0.7321988604962826, 0.41086462035309523, 0.4506495245732367, 0.5143925291486084, 0.27475844719447196, 0.47425044409465045, 0.5251473770476878, 0.5837231338955462, 0.5396891967393458, 5.146169783547521, 38.452773839235306, 75.06182581186295, 91.92262306809425, 86.66972413659096, 79.75339606404305, 64.09527227282524, 57.048014625906944, 39.50560234487057, 32.32694014906883, 59.47216294705868, 75.0985698401928, 84.72081631422043, 89.87260267138481, 115.54394155740738, 90.17093226313591, 9.136376045644283, 0.3869153367122635, 0.24252013099612668, 0.20718097337521613, 0.36765230004675686, 0.11165887874085456, 0.15060141566209495, 0.14940908120479435, 0.23904797824798152, 0.3102741320617497, 0.13896002783440053, 0.1694065917399712, 0.09783478264580481, 0.23454983602277935, 0.2686992863891646, 0.1770036606467329, 0.2085042672115378, 0.11421910268836655, 0.10414101183414459, 0.142388824315276, 0.1511227447190322, 0.12621327041415498, 0.14948840194847435, 0.13494748767698184, 0.08612830846686848, 0.13902769685955718, 0.14133639953797683, 0.18512446316890419, 0.12138646809034981, 0.24694123829249293, 0.12105334768421017, 0.09883482664008625, 0.1644811505684629, 0.2812534268014133, 0.13136462133843452, 0.14608292374759912, 0.09280034966650419, 0.16067485325038433, 0.15103641810128465, 0.1887659591739066, 0.1545014017028734, 0.10545016775722615, 0.0888891497743316, 0.12622867739992216], [0.03685708339617122, 0.01922183819260681, 0.039142360183177516, 0.028940050506207626, 0.038494955078931525, 0.07067179918522015, 0.043226038906141184, 0.04895056161331013, 0.04337319565820508, 0.04014472338894848, 0.01301253720157547, 0.030549663060810417, 0.10220552037935704, 0.018318917209398933, 0.09608212669263594, 0.039572219538968056, 0.009811734980758047, 0.057543852453818545, 0.05621128177153878, 0.04639075697923545, 0.06977397861192003, 0.051496970481821336, 0.048742801081971265, 0.08619015163276345, 0.03877074828778859, 0.024423811009910423, 0.07647435500985011, 0.052656409243354574, 0.018243915765197016, 0.06948411799385212, 0.04757094618980773, 0.058108415323658846, 0.008841788785503013, 0.020586582832038403, 0.02866217928385595, 0.05185158719541505, 0.05475598212797195, 0.07566522850538604, 8.599137123674154, 56.139825358986855, 101.02584019303322, 95.67832633852959, 81.33100301027298, 70.58631956577301, 62.22792707383633, 42.61988863348961, 45.49763381481171, 57.99359388649464, 56.6409120708704, 67.81992360949516, 61.0929811745882, 48.40170778334141, 14.889104906469584, 1.7732667597010732, 0.5550140712875873, 0.0803698213712778, 0.23610460571944714, 0.08183001176803373, 0.26454005332197994, 0.1388968265382573, 0.29792194487527013, 0.1266199376550503, 0.14439639315241948, 0.09555024429573677, 0.5592140334192663, 0.12721107312245294, 1.5799914370290935, 1.3458997732959688, 5.853736465796828, 6.497593866661191, 2.103682542219758, 5.868002800270915, 16.536315567791462, 12.822788134217262, 5.315021323040128, 12.029657643288374, 10.3519232198596, 11.616538111120462, 12.939974796026945, 3.287604725919664, 7.489748178049922, 6.584933130070567, 6.294989213347435, 5.433720778673887, 8.815672304481268, 9.565005395561457, 8.20536045357585, 16.15449495613575, 4.9927416164428, 5.007788334041834, 6.619312260299921, 11.928361728787422, 9.56707913428545, 8.780735079199076, 12.924429830163717, 7.828790210187435, 8.374229092150927, 7.375477384775877, 12.445463631302118, 10.74772423133254, 6.486885091289878, 18.33362102508545, 3.1807530345395207, 6.094869151711464, 4.7408616822212934, 3.1923530995845795, 1.5473450138233602, 1.256528568919748, 1.1450651125051081, 0.52555852686055, 0.09236055295332335, 0.040307583985850215, 0.09468973890761845, 0.1068799226777628, 0.1270598085829988, 0.18461876374203712, 0.4771253460785374, 0.6574997375719249, 2.4281509313732386, 23.26856441795826, 49.777895137667656, 74.08851563930511, 73.7298832833767, 86.99830010533333, 112.98638239502907, 46.16118460893631, 20.7109197601676, 22.249367907643318, 48.37216056883335, 64.53253000974655, 54.21149343252182, 72.68952190876007, 71.67273446917534, 19.147486053407192, 0.35810457018669695, 0.27885391493327916, 0.04398589793709107, 0.029489827938959934, 0.005526759832719108, 0.055766980221960694, 0.10309816076187417, 0.025764229903870728, 0.024267143635370303, 0.018983870395459235, 0.04232660787238274, 0.06985848696785979, 0.06493192515335977, 0.08621571119874716, 0.0816526978451293, 0.012062795976817142, 0.028783223569917027, 0.038902319938642904, 0.059951579896733165, 0.04432651403476484, 0.03467061244009528, 0.03932359264581464, 0.06899023355799727, 0.012727832654491067, 0.02931753650045721, 0.06160391232697293, 0.10264056734740734, 0.0027606956609815825, 0.06474925292422995, 0.02078454701404553, 0.022738365805707872, 0.055311921241809614, 0.042612442339304835, 0.026955111607094295, 0.04158827112405561, 0.0751783796295058, 0.005076199195173103, 0.03432508703554049, 0.07714407649473287, 0.0009455655424517317, 0.006107113285906962, 0.028013827941322234, 0.092134264705237, 0.0435470585944131, 0.012234563273523236, 0.0565526622813195, 0.049026457345462404, 0.026314879360143095, 0.03292532230261713, 0.0440552293730434, 0.04022725021059159, 0.0650462530029472, 0.01483760172050097, 0.05632265587337315, 0.024819717109494377, 0.012008107114525046, 0.03912493084499147, 0.087675523100188, 0.0452237297577085, 0.05891972003155388, 0.0790916130063124, 0.02423712932795752, 0.09566143286065198, 0.01321960753557505, 0.03454917481576558, 0.04623618988262024, 0.02630645969475154, 0.004167410606896738, 0.03191365998645779, 0.0977220429922454, 0.039826590655138716, 0.037115443556103855, 0.02913833381171571, 0.04018839877971914, 0.034904054991784506, 0.022986990843492094, 0.05212933596340008, 0.08057565602939576, 0.016770381553214975, 0.1358893621363677, 16.05243243277073, 74.48994889855385, 119.16703194379807, 108.9704766869545, 100.50321623682976, 91.39410942792892, 99.29908365011215, 69.55511569976807, 56.775402054190636, 44.316562190651894, 22.780801691114902, 57.77651533484459, 62.35385611653328, 48.78424845635891, 14.643863216042519, 1.1242115939967334, 0.6750119884964079, 0.016619271009403747, 0.1250802632421255, 0.5158337205648422, 0.47333861177321523, 0.1657098057330586, 0.3210156213026494, 0.019885969450115226, 0.18272107728989795, 0.36520535009913146, 0.31999309023376554, 0.6710719561669976, 0.8301096910145134, 0.7779438933357596, 1.2910814210772514, 1.0901826387271285, 0.23548326484160498, 0.35630723694339395, 0.7113401172682643, 2.2646837029606104, 2.485132198780775, 2.914012335240841, 6.973015805706382, 11.5099804289639, 18.56470562517643, 9.498102385550737, 11.720517631620169, 10.071636959910393, 12.739190720021725, 10.09212926030159, 12.965137045830488, 8.698421996086836, 1.803451746236533, 2.9890746949240565, 1.5052997949533165, 1.4426879421807826, 1.103342401329428, 0.7688553154002875, 0.8321129553951323, 5.114029683172703, 7.609896780923009, 7.676691021770239, 6.086890529841185, 3.1614695442840457, 6.573751755058765, 2.3283295752480626, 1.507199218031019, 0.7642271637450904, 6.968244211748242, 11.292490549385548, 9.329671673476696, 7.27241076529026, 2.0616081124171615, 1.7534511792473495, 1.5214727958664298, 0.4450867121340707, 0.14845787052763626, 0.016010056824597996, 0.2102364250458777, 0.03409754455788061, 0.14502522972179577, 0.2516187576111406, 0.6306226516608149, 0.6650220870506018, 1.0891176271252334, 20.10592382401228, 46.56095735728741, 73.71936544775963, 46.240030378103256, 46.973740607500076, 58.31337332725525, 27.826359048485756, 26.346254870295525, 40.353583842515945, 75.68770542740822, 94.25464153289795, 72.49239608645439, 78.15731450915337, 89.61471810936928, 32.61566765606403, 1.0307895694859326, 0.2726230805274099, 0.01906243785924744, 0.03591383225284517, 0.024327036808244884, 0.03020833079062868, 0.10596742984489538, 0.013175763306207955, 0.0158339303379762, 0.041176056329277344, 0.020464978224481456, 0.03267561929533258, 0.016048765392042696, 0.018499247962608933, 0.02129789427272044, 0.030617324664490297, 0.011276402383373352, 0.0038569092384932446, 0.05610073516436387, 0.010679672050173394, 0.010281603517796611, 0.046605764582636766, 0.037985604285495356, 0.08470610860968009, 0.017570249765412882, 0.009910326516546775, 0.084467767883325, 0.032189924459089525, 0.1000031600415241, 0.009052758177858777, 0.024980373527796473, 0.04041393374791369, 0.02603022861876525, 0.03340929535625037, 0.013233970876171952, 0.008144246039591962, 0.03199668775778264, 0.10625872280797921, 0.0600165289506549, 0.013287155961734243, 0.06400405502063222, 0.0559366426023189, 0.16287119477055967, 0.1845007177325897, 0.09013552000396885, 0.1026386303419713, 0.16112830548081547, 0.18391557881841436, 0.10882364455028437, 0.13735559361521155, 0.15447089943336323, 0.2496432198677212, 0.1842576198396273, 0.17495012318249792, 0.11601778664044105, 0.09249498558347113, 0.2141426005982794, 0.14577240915969014, 0.12392657983582467, 0.1678432131302543, 0.21932486939476803, 0.1533969078445807, 0.18892526859417558, 0.1175476869684644, 0.13225518370745704, 0.1679376291576773, 0.23197989736218005, 0.14971894270274788, 0.16983286652248353, 0.15628815192030743, 0.1619364894577302, 0.12144072650698945, 0.1474550657439977, 0.18142359534977004, 0.15708226477727294, 0.12046740725054406, 0.13508674426702783, 0.15789640077855438, 0.13019655511016026, 0.28990719525609165, 17.807381562888622, 85.37552878260612, 136.00783467292786, 122.60601460933685, 99.12389785051346, 92.3432756960392, 83.92426505684853, 57.579051330685616, 60.04117101430893, 80.85470616817474, 90.97257524728775, 98.45879673957825, 84.98009160161018, 67.06839233636856, 22.229658365249634, 3.546286295168102, 0.8461362216621637, 0.13875995966373011, 0.44131802686024457, 0.555095529416576, 0.34446570673026145, 0.27725690219085664, 0.4941023304127157, 0.2303344223764725, 0.9458818193525076, 1.0880338540300727, 2.5379550643265247, 1.6129127517342567, 7.081183176487684, 7.647566059604287, 15.693156961351633, 15.943917855620384, 18.09563409537077, 25.3913015127182, 32.26488187909126, 29.05553989112377, 22.345979623496532, 32.31394104659557, 29.67550702393055, 30.973711162805557, 28.991788811981678, 12.522021923214197, 19.92660954594612, 20.234193541109562, 26.080158948898315, 20.892284028232098, 27.900626063346863, 29.888236708939075, 24.660418331623077, 39.530160427093506, 19.432235173881054, 16.39355342835188, 18.15514650195837, 28.516060039401054, 25.411208644509315, 23.19870136678219, 35.94002187252045, 23.463412262499332, 23.625997938215733, 25.551550313830376, 27.596809566020966, 24.076908342540264, 18.75343769788742, 35.17581827938557, 12.785885464400053, 11.638007909059525, 6.0687783267349005, 4.229768207296729, 1.941786054521799, 2.882254826836288, 3.1633190950378776, 2.5309710390865803, 0.4152984480606392, 0.22386844590073451, 0.36716509493999183, 0.32976732356473804, 0.6116723560262471, 0.5406054225750268, 0.9263953368645161, 0.9693475195672363, 4.276786409318447, 36.643356531858444, 69.02584969997406, 95.62338128685951, 104.01325508952141, 108.83175373077393, 133.72417241334915, 56.49424374103546, 28.670158870518208, 33.10679130256176, 60.91638945043087, 86.41109481453896, 70.01678332686424, 92.11152613162994, 100.69308444857597, 32.04098269343376, 0.6957992480602115, 0.391540935379453, 0.12109397284802981, 0.15884878404904157, 0.08703288258402608, 0.18328879057662562, 0.22933347296202555, 0.14021180832060054, 0.14956770784920081, 0.15299270453397185, 0.14981876156525686, 0.15280075545888394, 0.13189159071771428, 0.265310758841224, 0.249202354461886, 0.0734639294387307, 0.07772842873237096, 0.08075553778326139, 0.16832755354698747, 0.1537622226169333, 0.09041589597472921, 0.10368207513238303, 0.1083054176706355, 0.20841235964326188, 0.10384663895820267, 0.1485344601678662, 0.24066422745818272, 0.20807316846912727, 0.16832019144203514, 0.1958179206121713, 0.06903285509906709, 0.1396541585563682, 0.08995935640996322, 0.13838161277817562, 0.15954784263158217, 0.169621488021221, 0.24327752238605171, 0.16347367025446147, 0.22082020790548995, 0.13235342921689153, 0.15874804492341354, 0.08575831074267626], [0.06568525699549355, 0.02305896061443491, 0.04172900829871651, 0.019718101211765315, 0.04644331958843395, 0.019713375586434267, 0.03295046255516354, 0.05074543092632666, 0.03901972399035003, 0.010046505976788467, 0.008024173039302696, 0.025507697282591835, 0.02133796653652098, 0.0016934953032432531, 0.07794242701493204, 0.07300277371541597, 0.017071116490114946, 0.0407266116963001, 0.03311903026769869, 0.019421327488089446, 0.15826271002879366, 0.06276413405430503, 0.0395599481271347, 0.08769494510488585, 0.04674707321100868, 0.013432239338726504, 0.02847938460035948, 0.03558083430107217, 0.11458170862169936, 0.07685676886467263, 0.020856472256127745, 0.08092715943348594, 0.04040116509713698, 0.0694488882436417, 0.010354514888604172, 0.09559242796967737, 0.6600257707759738, 34.97765131294727, 87.39592596888542, 103.02612125873566, 80.99759370088577, 65.73994562029839, 63.13345268368721, 73.02836492657661, 43.60900595784187, 41.07182890176773, 45.442631766200066, 50.925186574459076, 76.83423310518265, 55.97381226718426, 28.644426651299, 3.7114240089431405, 0.4686921735992655, 0.16112668759888038, 0.3841241786722094, 0.10645130270859227, 0.172998913039919, 0.15732852421933785, 0.04600963817210868, 0.0741270012804307, 0.3040099306963384, 2.784750396385789, 1.4852893562056124, 3.511201827786863, 6.821863241493702, 9.792487788945436, 12.444426286965609, 8.527484368532896, 6.856846064329147, 12.573795095086098, 12.278416994959116, 8.052357863634825, 11.201489232480526, 7.037956221029162, 12.791561409831047, 5.52064111456275, 6.571270488202572, 8.648014850914478, 11.206332072615623, 9.976753201335669, 5.9850982669740915, 6.361874174326658, 4.6029632817953825, 9.46688611060381, 7.746830033138394, 7.546028383076191, 4.805707102641463, 3.8047928363084793, 1.8053966481238604, 1.715776794590056, 1.0046298732049763, 0.7508338917978108, 0.8001343463547528, 8.073390685021877, 13.007798306643963, 10.307560600340366, 5.930155590176582, 4.299170533195138, 3.3390340162441134, 3.4025996178388596, 9.843374658375978, 16.439614556729794, 38.21353107690811, 58.84630233049393, 66.80872946977615, 58.31893242895603, 38.954540714621544, 13.139094561338425, 2.023807028308511, 0.05636362613586243, 0.2139027533121407, 0.1938661019084975, 0.12476695817895234, 0.08505934121785685, 0.05708006210625172, 0.08947247042669915, 0.18529756169300526, 0.3879715909715742, 0.17309539223788306, 0.35298330592922866, 1.0653489525429904, 17.733120247721672, 54.29809458553791, 69.86927524209023, 60.97038835287094, 56.61359153687954, 67.92919054627419, 38.95987942814827, 22.23372034728527, 29.076615460217, 47.74615176022053, 70.24851009249687, 71.83206751942635, 80.83149701356888, 44.723619148135185, 3.9763954281806946, 0.4668203287292272, 0.04611753531207796, 0.06174447509692982, 0.03959308873163536, 0.05813851683342364, 0.03617932445195038, 0.058331801774329506, 0.03933039442927111, 0.011420503342378652, 0.03439421809162013, 0.008230273015215062, 0.039002149933367036, 0.027371035284886602, 0.026777011007652618, 0.055813780054450035, 0.08705119136720896, 0.053733098538941704, 0.07058068571495824, 0.02492284223990282, 0.01127345698478166, 0.015761548675072845, 0.08106938461423852, 0.020739788087666966, 0.02908736867539119, 0.016455328732263297, 0.035128198433085345, 0.030549588846042752, 0.05446532741189003, 0.023330013355007395, 0.01994986094359774, 0.015251748882292304, 0.009153837763733463, 0.00962037962381146, 0.03614099623518996, 0.023516928813478444, 0.04692823516961653, 0.07021468074526638, 0.08815956665785052, 0.07341547461692244, 0.03434628277318552, 0.04742054625239689, 0.014056362342671491, 0.046152182476362213, 0.04354058706667274, 0.08646108748507686, 0.006370255196088692, 0.012671867298195139, 0.03500486091070343, 0.05057832895545289, 0.02725168309552828, 0.038033020100556314, 0.015572098782286048, 0.07958035435876809, 0.05302307472447865, 0.06404548170394264, 0.12183629864011891, 0.013249779549369123, 0.03905097211827524, 0.044526942147058435, 0.03588822073652409, 0.03126884126686491, 0.05879783711861819, 0.050402195047354326, 0.010050941236841027, 0.06005687951983418, 0.013976772570458706, 0.0835290401300881, 0.009695711323729483, 0.039600484233233146, 0.0162580658798106, 0.024722974449105095, 0.06952425334020518, 0.08483216239255853, 0.030925178652978502, 0.05660896160406992, 0.1853027567267418, 1.82030966039747, 53.804869651794434, 105.44717654585838, 114.36536639928818, 94.94738236069679, 97.28401377797127, 101.55936196446419, 115.89758098125458, 52.81031861901283, 27.116709128022194, 28.94534580409527, 41.02641373872757, 81.37643337249756, 63.906680792570114, 29.037302769720554, 3.236187072470784, 0.4749146068934351, 0.073598028102424, 0.30062042351346463, 0.14185136096784845, 0.14174225041642785, 0.3590319282375276, 0.06721008103340864, 0.06453113572206348, 0.17736271169269457, 1.2577866576611996, 3.167347591370344, 6.886595617979765, 12.736737951636314, 16.92727468907833, 20.629900507628918, 16.857168450951576, 12.969930488616228, 16.36436529457569, 15.786117073148489, 13.088201992213726, 16.77799589931965, 11.237137969583273, 13.020030800253153, 6.53704097494483, 3.326622457243502, 4.990781871601939, 8.528320323675871, 8.628842979669571, 10.092863570898771, 8.561701532453299, 9.736361000686884, 11.600680612027645, 8.39735085144639, 3.7210469925776124, 0.8027871383819729, 1.0163495130836964, 1.3766877399757504, 0.9783542831428349, 1.4272424834780395, 0.8367001998703927, 0.35016071051359177, 0.44922083092387766, 2.49074995983392, 1.6256345878355205, 2.795657948590815, 1.9908117363229394, 0.9769357717595994, 2.159050083719194, 11.347693987190723, 26.428206972777843, 53.678978607058525, 71.3112522661686, 81.46211877465248, 74.69223484396935, 52.88688451051712, 20.158588998019695, 4.0651425160467625, 0.6690442899707705, 0.38298937550280243, 0.1394334141514264, 0.046250394589151256, 0.04348522656073328, 0.05104687646962702, 0.08313029902637936, 0.16656530904583633, 0.24233002244727686, 0.04271163408702705, 0.5239360139239579, 0.8146642916835845, 15.954088009893894, 50.81143967807293, 66.47087439894676, 64.76888492703438, 34.41629223525524, 29.84475564211607, 27.498049065470695, 34.900827035307884, 52.75178276002407, 71.48717522621155, 93.8335633277893, 87.94721558690071, 91.71708449721336, 64.5655806362629, 9.363869838416576, 0.12458679440896958, 0.03440424821747001, 0.022215316821529996, 0.09744776005391032, 0.12233623157953843, 0.0316838613798609, 0.020162898144917563, 0.08871471538441256, 0.018350903774262406, 0.020946980876033194, 0.029947068833280355, 0.025629181291151326, 0.02327851572772488, 0.04687936474510934, 0.03644892443844583, 0.06111802453233395, 0.058363220596220344, 0.06359271967085078, 0.05402169750595931, 0.019954273011535406, 0.04956997661793139, 0.06641964180744253, 0.012384036454022862, 0.048662838380550966, 0.04314288868044969, 0.03973532875534147, 0.027072344964835793, 0.045166016643634066, 0.026262821411364712, 0.0782759630237706, 0.009880204597720876, 0.024232693140220363, 0.019091270296485163, 0.10083677741931751, 0.053686577011831105, 0.04167504303040914, 0.07458892141585238, 0.03860969110974111, 0.045799636354786344, 0.03891282874974422, 0.15668387990444899, 0.07743262351141311, 0.12638072861591354, 0.26986665499862283, 0.19710768421646208, 0.11410062623326667, 0.098629763815552, 0.12972337659448385, 0.17953882226720452, 0.1072605256922543, 0.11633308065938763, 0.08586238953284919, 0.12838366645155475, 0.09538869358948432, 0.13854908582288772, 0.15063841914525256, 0.12673019111389294, 0.08843863644869998, 0.19307322101667523, 0.13148890138836578, 0.28197078674566, 0.1277064863825217, 0.10895655577769503, 0.14697773120133206, 0.21793096762849018, 0.08473727881209925, 0.1381117827259004, 0.1468557072803378, 0.1992783771129325, 0.13405039440840483, 0.11720219496055506, 0.12701799598289654, 0.18519763892982155, 0.2252874619443901, 0.11166730953846127, 0.2129546002834104, 1.6289565595798194, 57.831357792019844, 120.99930882453918, 129.6122306585312, 98.70354160666466, 86.72793701291084, 84.16213989257812, 92.44366630911827, 57.838193625211716, 56.34821757674217, 69.76593598723412, 74.46209639310837, 104.86098200082779, 75.75799405574799, 40.335994586348534, 5.7606547605246305, 1.0784090892411768, 0.22491491865366697, 0.6315335934050381, 0.1590249253786169, 0.37248757027555257, 0.34706319391261786, 0.17788855300750583, 0.2794540749164298, 0.7369313284289092, 5.494426796212792, 4.939349731430411, 7.6284977328032255, 10.435426589101553, 14.324980527162552, 16.39527853578329, 12.347355745732784, 13.559860233217478, 17.83390413969755, 16.774956062436104, 13.459426872432232, 16.96566592901945, 10.255224108695984, 17.13793158531189, 14.229547698050737, 20.487277060747147, 23.061486929655075, 31.592557355761528, 24.141778461635113, 19.153197146952152, 18.459097892045975, 17.156286500394344, 27.174086049199104, 22.291743233799934, 19.809560626745224, 15.193661414086819, 10.17614085227251, 6.6594865545630455, 5.959166558459401, 6.110170930624008, 3.954625208862126, 7.624821905046701, 20.66206008195877, 28.786480128765106, 22.84237928688526, 18.523521535098553, 14.564764760434628, 19.466613829135895, 16.44565623253584, 15.988939739763737, 18.90901654958725, 42.3281554877758, 61.96295589208603, 74.34742614626884, 68.1183671951294, 46.42999358475208, 15.35963935777545, 4.279385944828391, 0.9311488817911595, 0.926706267055124, 0.6091549911070615, 0.15082230849657208, 0.17417600378394127, 0.1858083819388412, 0.34512114187236875, 0.7105187082197517, 0.6525370851159096, 0.4345572693273425, 0.6559317873325199, 2.8897382877767086, 26.37057166546583, 75.53284093737602, 89.7951552271843, 80.72558149695396, 78.15596178174019, 86.43069416284561, 49.22752887010574, 28.307384736835957, 37.16599948704243, 62.75616712868214, 91.0309249162674, 90.26153460144997, 107.93022930622101, 69.39387515187263, 8.631686177104712, 0.5723467818461359, 0.1504890841897577, 0.14090926386415958, 0.15878142672590911, 0.13867397443391383, 0.11937386749195866, 0.14102576620643958, 0.18332079198444262, 0.1276717390283011, 0.15452661988092586, 0.17022335494402796, 0.12963342829607427, 0.0890503368282225, 0.10435803065774962, 0.1311876784893684, 0.20329016027972102, 0.1925752399256453, 0.21453329682117328, 0.17574601719388738, 0.09803301029023714, 0.12504818761954084, 0.1718712641741149, 0.10512502543861046, 0.10494781541638076, 0.10748384534963407, 0.16373446094803512, 0.1555892120813951, 0.2331233094446361, 0.09179139990010299, 0.10106920322868973, 0.14336430322146043, 0.09198708939948119, 0.11237427199375816, 0.16938845365075395, 0.13898416247684509, 0.16662788693793118, 0.18500969745218754, 0.15250904689310119, 0.11326096035190858, 0.12308542965911329], [0.04200388124445453, 0.03287819221441168, 0.023535085456387606, 0.05559739576710854, 0.0410445143643301, 0.003298223482488538, 0.04132258225581609, 0.017359240482619498, 0.0294067964568967, 0.013998330105096102, 0.057995675670099445, 0.033002487107296474, 0.04215212524286471, 0.03233855437429156, 0.023114191244530957, 0.07074267428833991, 0.07740241067949682, 0.03958946334023494, 0.011423800333432155, 0.0598008979432052, 0.045817770733265206, 0.008119314516079612, 0.020820081044803374, 0.06117800119682215, 0.04343779961345717, 0.04365450302429963, 0.039727955518173985, 0.10290005928254686, 0.13163816212909296, 0.04964931220456492, 0.05815457319840789, 0.048310633646906354, 0.04310152507969178, 0.05293643269396853, 0.039984690374694765, 1.697658416815102, 56.36720895767212, 98.75602439045906, 87.32868477702141, 75.63721373677254, 85.58155372738838, 55.06291754543781, 42.821445018053055, 26.722012907266617, 64.95415538549423, 92.06957638263702, 76.9759351015091, 87.62324497103691, 45.89074172079563, 10.55642919614911, 0.7837302109692246, 0.2228821613243781, 0.02116768817359116, 0.10180706129176542, 0.300886943587102, 0.016530996254005004, 0.08972398427431472, 0.7176429696846753, 1.4546131272800267, 0.5947138066403568, 2.041861996985972, 7.9444479290395975, 25.12164518237114, 50.67624293267727, 78.84626314043999, 93.58022332191467, 100.52584022283554, 95.3613093495369, 82.73033112287521, 63.02095592021942, 68.1811474263668, 49.972558692097664, 59.22843262553215, 41.15194380283356, 31.20442148298025, 13.49064789712429, 5.39083675481379, 6.754479557275772, 14.408918973058462, 6.658030282706022, 8.617668729275465, 6.640161741524935, 9.061375670135021, 7.031533140689135, 8.224806860089302, 4.995756279677153, 0.351703071501106, 2.7898335736244917, 5.935071101412177, 9.726234544068575, 13.234680332243443, 15.293556153774261, 5.70008316077292, 2.9456655867397785, 2.735973126254976, 3.091742810793221, 3.554454669356346, 1.026810233015567, 7.937650568783283, 13.876506742089987, 47.73099057376385, 86.37002661824226, 105.27329787611961, 101.89992249011993, 97.0468533039093, 93.51365089416504, 90.49812510609627, 76.42418950796127, 39.069731533527374, 18.527247235178947, 15.998462028801441, 19.137036614120007, 11.541273649781942, 1.630748282186687, 0.11076962255174294, 0.07316601651837118, 0.12266629433725029, 0.1260656423983164, 0.04029790638014674, 0.14884636999340728, 0.019370946793060284, 0.39926033990923315, 1.0429060505703092, 25.71810107678175, 69.302087277174, 73.77781391143799, 63.88258248567581, 68.86584028601646, 50.64458303153515, 30.525090135633945, 31.750465482473373, 42.776888608932495, 55.240880995988846, 57.64538437128067, 85.24494498968124, 76.3191631436348, 17.121410071849823, 0.30682807322591543, 0.10485374819836579, 0.04033094308397267, 0.16708769195247442, 0.048591310187475756, 0.012792942197847879, 0.03324224904645234, 0.044264585521887057, 0.015605911030434072, 0.04544107141555287, 0.030286302680906374, 0.01954227343958337, 0.07871701396652497, 0.05564340892306063, 0.03775628065341152, 0.0384766351635335, 0.03455266290984582, 0.03678656452393625, 0.014352829002746148, 0.019495594206091482, 0.027460627352411393, 0.004837313454117975, 0.035204190644435585, 0.08221189127652906, 0.045765026297885925, 0.054884852361283265, 0.024438822802039795, 0.02977136908157263, 0.04142055317061022, 0.08299407039885409, 0.03730301024916116, 0.042414622876094654, 0.10216522918199189, 0.043290568646625616, 0.0392464278411353, 0.07635848349309526, 0.030539868566847872, 0.04529775898845401, 0.060665511118713766, 0.04690195943112485, 0.03422305286221672, 0.05041455922764726, 0.037299065734259784, 0.0238501790954615, 0.03735757294634823, 0.04698157703387551, 0.05898218289075885, 0.06201165197126102, 0.022848661938041914, 0.01844294492912013, 0.034790821810020134, 0.0756021607958246, 0.021454350135172717, 0.02686672924028244, 0.040329777912120335, 0.023116336051316466, 0.08467984400340356, 0.01777573375875363, 0.07084293843945488, 0.026800488849403337, 0.02074341718980577, 0.05342700344044715, 0.08603826368926093, 0.02321315107110422, 0.03463341228780337, 0.051318120313226245, 0.09476713006733917, 0.09498482424532995, 0.049503298359923065, 0.04935118406137917, 0.08848928802763112, 0.07552291426691227, 0.07149331213440746, 0.0536209340498317, 4.494674792513251, 79.87878173589706, 112.08994969725609, 104.45501938462257, 101.29743441939354, 114.74154621362686, 79.67204242944717, 59.35169041156769, 29.969227463006973, 46.77641719579697, 63.8791398704052, 64.46664914488792, 89.80816572904587, 48.14179413020611, 9.896890986710787, 0.6046517577487975, 0.19859767926391214, 0.05000283425033558, 0.17661568068433553, 0.26651054446119815, 0.1808875272399746, 0.09230814248439856, 0.3787895618006587, 0.9472356154583395, 0.4831625986844301, 4.224226204678416, 13.201734200119972, 35.4533401876688, 63.58498625457287, 93.44717726111412, 105.64646065235138, 112.43886977434158, 104.90187540650368, 97.39590257406235, 76.92868083715439, 82.37018644809723, 63.24244983494282, 67.7454324066639, 49.955657199025154, 37.52598837018013, 18.739444948732853, 7.154647959396243, 2.6292765140533447, 4.127091066911817, 4.7982704266905785, 5.415719244629145, 7.2790931817144156, 7.951205866411328, 5.742183951660991, 1.440624890383333, 0.3813756495947018, 1.0806971602141857, 4.4459139090031385, 10.37616591900587, 15.791282895952463, 22.406402081251144, 25.61692390590906, 12.026192229241133, 5.510663324967027, 0.671819862909615, 1.415548373479396, 2.322275787591934, 3.243045941926539, 11.206695903092623, 22.59048890322447, 61.99416361749172, 96.29517763853073, 110.56219607591629, 108.28775972127914, 103.13431665301323, 102.26446732878685, 100.5387519299984, 91.68369188904762, 54.50103409588337, 28.157581575214863, 26.479566916823387, 31.875577569007874, 19.19856671243906, 3.6482514487579465, 0.13476768013788387, 0.14086786686675623, 0.2610010775970295, 0.23484905512304977, 0.18195761513197795, 0.15842176711885259, 0.203553800820373, 0.8902199123986065, 0.5786943412385881, 23.38337905704975, 73.66182133555412, 72.51081749796867, 54.52337309718132, 32.801329493522644, 23.8899564743042, 31.255044266581535, 49.13535721600056, 72.97230273485184, 79.36102151870728, 75.98830729722977, 95.10710299015045, 98.32730859518051, 31.436072252690792, 0.31496863171923906, 0.2558431512443349, 0.02601167307147989, 0.18127218238078058, 0.012136652658227831, 0.052654505634563975, 0.020383019145810977, 0.030656671478936914, 0.026299962191842496, 0.016065085219452158, 0.023785552875779103, 0.023539146859548055, 0.01907398567709606, 0.08408027031691745, 0.04152673594944645, 0.04614870180375874, 0.00982105635557673, 0.02672034617717145, 0.030753252722206526, 0.07918680828879587, 0.020935206703143194, 0.031242758486769162, 0.019589722651289776, 0.02783027070108801, 0.03762031177757308, 0.04003101152193267, 0.005099953486933373, 0.05043271215981804, 0.017596748148207553, 0.0051003570297325496, 0.030613996132160537, 0.037292171182343736, 0.09713902662042528, 0.006964490521568223, 0.009504140743956668, 0.08172484944225289, 0.07144288319977932, 0.07506695357733406, 0.0638609986344818, 0.1772244941093959, 0.11502525318064727, 0.0768813636386767, 0.18265416525537148, 0.12612565245945007, 0.1594684922019951, 0.08909626834793016, 0.16107061092043296, 0.22525013191625476, 0.09494946090853773, 0.1644319758634083, 0.10059316002298146, 0.1368537830421701, 0.19662603037431836, 0.12167369408416562, 0.13755064486758783, 0.09232812852133065, 0.17340192891424522, 0.1476019961410202, 0.1650765459635295, 0.14084239635849372, 0.12377750463201664, 0.15600184618961066, 0.1224244358309079, 0.07396282337140292, 0.1482961417059414, 0.18804613529937342, 0.22804179461672902, 0.20474791643209755, 0.11732053782907315, 0.16182035818928853, 0.19817351218080148, 0.14617496490245685, 0.20452929456951097, 0.09120199363678694, 5.129293464124203, 90.31217068433762, 128.1186220049858, 112.73461550474167, 96.43593728542328, 109.19724851846695, 70.54218873381615, 53.847461566329, 35.05219951272011, 86.9915896654129, 125.61120495200157, 103.52920666337013, 115.24315729737282, 59.540452882647514, 17.26363454014063, 1.4868825394660234, 0.3820780181558803, 0.09558811609167606, 0.42328253213781863, 0.4836088669253513, 0.1262731765746139, 0.18984226626344025, 1.914674153085798, 4.089075531810522, 1.6832286911085248, 4.210755927488208, 10.761982016265392, 31.06825388967991, 56.29894942045212, 85.953728556633, 101.160968542099, 111.1885392665863, 102.25553020834923, 92.64531388878822, 73.26579138636589, 79.21725243330002, 63.3555393666029, 65.32428592443466, 48.41006353497505, 35.90839996933937, 18.16448450088501, 9.57361763343215, 14.304093047976494, 29.256816990673542, 25.285931266844273, 25.003262534737587, 18.380955085158348, 19.920269586145878, 20.41654195636511, 23.96205760538578, 11.156604140996933, 2.6484229741618037, 5.047001279890537, 9.18353721499443, 15.20077558234334, 22.92627688497305, 24.31703645735979, 9.843361359089613, 7.271506888791919, 10.160783026367426, 14.737548138946295, 10.98596764728427, 6.435986822471023, 14.578537121415138, 18.324028439819813, 54.79919269680977, 94.48474198579788, 118.59135523438454, 120.22948533296585, 112.27987870573997, 109.61159348487854, 101.59376531839371, 88.26943829655647, 45.69184519350529, 22.147613167762756, 18.274224512279034, 22.609480284154415, 12.897915802896023, 2.189841018989682, 0.40607316652312875, 0.25414612668100744, 0.36169341823551804, 0.3020727768307552, 0.3114221157738939, 0.31446990848053247, 0.5422664678189903, 1.2210626970045269, 2.0936536928638816, 37.754865288734436, 89.07469108700752, 95.8829453587532, 93.02198767662048, 96.86948642134666, 61.82475730776787, 40.6904623657465, 39.69400003552437, 54.53774772584438, 74.03659522533417, 73.57752665877342, 107.33946740627289, 109.08339902758598, 33.227894604206085, 0.3953040693886578, 0.275260970229283, 0.11747244803700596, 0.2821925998432562, 0.16786758525995538, 0.09311655652709305, 0.11010320362402126, 0.19277621351648122, 0.09053716290509328, 0.12444462860003114, 0.07487409166060388, 0.10681234271032736, 0.12309325189562514, 0.21212590334471315, 0.12350007498753257, 0.18958013970404863, 0.09871914808172733, 0.17362693324685097, 0.09990671795094386, 0.11975238507147878, 0.08689974871231243, 0.1413920012419112, 0.14455366908805445, 0.12778831558534876, 0.14069852360989898, 0.1854996188194491, 0.10601693851640448, 0.13838302285876125, 0.1494196048588492, 0.1963366669951938, 0.10702930216211826, 0.14408806047867984, 0.267706589656882, 0.09401800620253198, 0.1473094563698396, 0.14040069974726066, 0.17650021734880283, 0.15142131072934717, 0.1398236650857143], [0.07162368521676399, 0.08474847782053985, 0.00528656605638389, 0.036763654425158165, 0.04718172313005198, 0.02703255471715238, 0.00526754156453535, 0.07246407840284519, 0.05107736389618367, 0.05735106475185603, 0.019021163316210732, 0.0810303253820166, 0.03889588551828638, 0.014207971980795264, 0.06387125511537306, 0.007891566092439461, 0.06209882463735994, 0.04528550984105095, 0.010745689796749502, 0.023996493509912398, 0.05173749683308415, 0.03999158492661081, 0.07991515201865695, 0.10512897366425022, 0.06437521049520001, 0.04507964178628754, 0.06733320333296433, 0.012327046933933161, 0.05211626674281433, 0.02471394993335707, 0.07507756628911011, 0.2034012894728221, 0.0354644581238972, 0.020087944940314628, 1.9247224763967097, 67.93984517455101, 93.13497081398964, 84.02599319815636, 66.45912542939186, 59.7717160731554, 45.07910907268524, 39.824906811118126, 52.22774147987366, 73.75161811709404, 67.2603352367878, 68.14586251974106, 81.66698858141899, 29.068875275552273, 2.137662931345403, 0.6990158348344266, 0.05382243085477967, 0.042559575449558906, 0.14818992553045973, 0.036432304041227326, 0.17895013588713482, 0.3797223523724824, 0.061510906380135566, 1.1634812992997468, 1.1255802330560982, 2.843322353437543, 20.221606716513634, 47.56686978042126, 86.19926378130913, 105.8728601038456, 105.74765682220459, 101.93763926625252, 104.47612345218658, 102.89426073431969, 109.28380787372589, 103.82429882884026, 102.53174498677254, 93.06515336036682, 88.7231719493866, 82.88071185350418, 62.28814624249935, 40.8046006411314, 18.590625934302807, 7.668460188433528, 2.538352617993951, 5.60976343229413, 6.216524848714471, 4.5428766310215, 7.079443344846368, 5.511777615174651, 2.1266342606395483, 0.9400013380218297, 5.907016731798649, 18.387211449444294, 33.381569758057594, 38.1518641859293, 52.52352520823479, 49.358671233057976, 53.19903776049614, 40.1509103178978, 10.34778144210577, 1.5494218398816884, 4.849279839545488, 15.663035977631807, 27.540711276233196, 60.69901451468468, 96.21438637375832, 94.34602662920952, 91.91686257719994, 93.58218401670456, 91.81688994169235, 92.59927555918694, 94.441447108984, 98.97954359650612, 105.3736200928688, 85.43471440672874, 96.20132267475128, 96.62750020623207, 82.89549306035042, 51.77047781646252, 7.02774521894753, 0.07980379275977612, 0.16049409576226026, 0.20082732837181538, 0.07070106206811033, 0.04924522763758432, 0.13487909134710208, 0.1793115321197547, 0.1419005505158566, 0.18041984061710536, 6.851456528529525, 52.384992241859436, 76.5056723356247, 62.90779419243336, 77.14726030826569, 74.26939353346825, 30.40647380053997, 25.13906914740801, 39.705581814050674, 48.17287266254425, 54.99666050076485, 61.2692841142416, 77.71523103117943, 27.145891562104225, 0.7131641975138336, 0.3480964119080454, 0.20060986425960436, 0.051580959334387444, 0.07909306019428186, 0.06578084561624564, 0.05233321506239008, 0.11285692031378858, 0.06868013457278721, 0.031078096326382365, 0.13793616089969873, 0.09421449722140096, 0.048224600177491084, 0.0388348178967135, 0.038018678096705116, 0.008803963373793522, 0.02106987125443993, 0.015307377489079954, 0.05131290301505942, 0.01926035194628639, 0.018505192565498874, 0.03045953479158925, 0.09908487845677882, 0.038897811391507275, 0.03503973814076744, 0.01170732022728771, 0.007131274296625634, 0.04354038668680005, 0.026543249332462437, 0.05388481207774021, 0.005897619839743129, 0.03705894385348074, 0.04590699543769006, 0.025045381953532342, 0.0166817598437774, 0.10609888646285981, 0.04680871970776934, 0.10794401401653886, 0.012643275131267728, 0.02802214185066987, 0.003660050160760875, 0.050712327429209836, 0.051636895004776306, 0.0929997795901727, 0.03884111873048823, 0.07708871227805503, 0.04105786189029459, 0.029185846105974633, 0.03776490440941416, 0.04129255125008058, 0.054462729895021766, 0.018735343692242168, 0.04286472059902735, 0.0008547005177206302, 0.08385427892790176, 0.02519828107324429, 0.029629221826326102, 0.034709931424004026, 0.029391894131549634, 0.021858297404833138, 0.06923616645508446, 0.013699054416065337, 0.055340108010568656, 0.02537529442633968, 0.10229815525235608, 0.046948614544817246, 0.05385621712775901, 0.02692094127269229, 0.11587614775635302, 0.12038036074955016, 0.11637298593996093, 0.09984285614336841, 5.983561249449849, 94.80236694216728, 106.97347864508629, 103.97244527935982, 91.01244270801544, 90.78337579965591, 80.590810328722, 54.81209300458431, 31.427087634801865, 36.7903858423233, 51.982943415641785, 76.2962731719017, 89.08920630812645, 28.737529255449772, 1.4505011541768909, 0.5572428298182786, 0.01747499696648447, 0.12034271159791388, 0.10744631494162604, 0.019830952187476214, 0.40429628686979413, 0.14243785059079528, 0.15898715006187558, 0.9911640489008278, 0.8192039793357253, 3.905250895768404, 23.622997999191284, 54.93514560163021, 93.67106884717941, 112.61062055826187, 110.22307187318802, 107.53057435154915, 108.23483616113663, 107.4472676217556, 111.06157287955284, 108.60523268580437, 104.80775445699692, 102.82381251454353, 96.92626297473907, 90.37315741181374, 71.665408462286, 46.15532152354717, 23.045890666544437, 9.256364107131958, 1.1899702716618776, 1.3026351761072874, 2.1175076253712177, 4.297135267406702, 4.999758889898658, 2.4626891780644655, 1.2463974812999368, 0.7332191057503223, 9.580471515655518, 25.917903855443, 42.23994322121143, 49.12037841975689, 65.4120384156704, 62.93542630970478, 69.5436555147171, 60.151076316833496, 19.037075378000736, 3.980015921406448, 7.522142389789224, 24.03249252587557, 38.39160852134228, 73.14342275261879, 103.74678298830986, 99.95258778333664, 102.05277308821678, 99.54657196998596, 97.91548669338226, 98.6617286503315, 101.87307313084602, 104.11491483449936, 109.50988054275513, 94.62791830301285, 104.71068486571312, 104.4367727637291, 94.69172447919846, 68.28033730387688, 12.053707502782345, 0.31829090032260865, 0.1296543568605557, 0.13574348558904603, 0.2690921793691814, 0.3230060910573229, 0.13925209263106808, 0.2128047458245419, 0.1800828758860007, 0.5072349600959569, 6.401457125321031, 52.495106533169746, 80.35021483898163, 62.960178181529045, 42.642960995435715, 30.14906231313944, 16.452556662261486, 36.9897535443306, 62.67238162457943, 80.45027866959572, 73.37309002876282, 68.6558635532856, 91.01925194263458, 46.46754316985607, 1.928211401682347, 0.22669046244118363, 0.23588562762597576, 0.039376281420118175, 0.08509448191034608, 0.0923300209979061, 0.10763053083792329, 0.0871488060511183, 0.08370345967705362, 0.024174844584194943, 0.06761156066204421, 0.06533355321153067, 0.025595224324206356, 0.011668582901620539, 0.059183509001741186, 0.024753691941441502, 0.03462209082499612, 0.053762903189635836, 0.04171986132860184, 0.06283812617766671, 0.03309223131509498, 0.03262386562710162, 0.018102623835147824, 0.07764974623569287, 0.035191900678910315, 0.033307112753391266, 0.028262369487492833, 0.03909225037205033, 0.041354824861628, 0.05553025737754069, 0.036714286761707626, 0.03922229690942913, 0.08311437995871529, 0.024764957743173, 0.003240431979065761, 0.10396980578661896, 0.02043397500528954, 0.06814194392063655, 0.11870580099639483, 0.15173357678577304, 0.11297458782792091, 0.1497609037323855, 0.14054292492801324, 0.11870833914144896, 0.23301069595618173, 0.1993143415893428, 0.1519335707416758, 0.14903223345754668, 0.1319961147964932, 0.19948404107708484, 0.24794187600491568, 0.13289697817526758, 0.1762485402286984, 0.13199657492805272, 0.26531951618380845, 0.12894706043880433, 0.1395838474854827, 0.08651582829770632, 0.14696469908813015, 0.11818780418252572, 0.1984557806281373, 0.1786325263674371, 0.21240158152068034, 0.11220011961995624, 0.2978984930086881, 0.15729345032013953, 0.3350094985216856, 0.18393787293462083, 0.22568491171114147, 0.24427030817605555, 0.13976640097098425, 0.20756564335897565, 5.175874214619398, 111.38745859265327, 121.84249877929688, 109.13304716348648, 89.31662410497665, 80.26528179645538, 60.00834457576275, 58.9347767829895, 73.39077427983284, 99.8727160692215, 96.83338075876236, 91.71524539589882, 105.50247877836227, 38.10685180127621, 4.811614360660315, 0.946434986544773, 0.09996396722272038, 0.30669864267110825, 0.2670180844143033, 0.11917979587451555, 0.2482888152007945, 0.5918720935005695, 0.547784484224394, 3.269260497763753, 2.4184286780655384, 4.250991018489003, 23.377369679510593, 55.60757651925087, 95.00909864902496, 115.93531295657158, 118.21721971035004, 113.65155950188637, 114.23219874501228, 114.21418771147728, 119.91205036640167, 114.1793891787529, 111.94071650505066, 108.37178081274033, 101.18044629693031, 91.78805708885193, 72.16868385672569, 46.04580380022526, 24.104238376021385, 12.942321170121431, 9.66960048303008, 11.701467353850603, 17.939278185367584, 16.304034031927586, 17.537426948547363, 17.87951499223709, 11.043625753372908, 2.688022549264133, 9.685343988239765, 27.34225172549486, 47.33410567045212, 56.68561287224293, 77.86191835999489, 78.75612437725067, 85.0159464776516, 69.64416772127151, 16.809009835124016, 2.839477672241628, 7.11376310326159, 21.593352109193802, 36.72091796994209, 73.80905583500862, 109.91842702031136, 109.26938384771347, 107.13820740580559, 106.127720028162, 104.86976712942123, 109.02439579367638, 110.29444724321365, 113.1200136244297, 113.15666645765305, 97.36444026231766, 105.0053134560585, 109.85495522618294, 96.6985335946083, 61.654518842697144, 8.138102162629366, 0.6581265258137137, 0.5847737775184214, 0.36302281252574176, 0.3280369914136827, 0.6472882011439651, 0.31248778046574444, 0.36231815814971924, 0.3830381791340187, 0.6199759792070836, 12.53695322200656, 72.86853790283203, 92.80413016676903, 85.82642778754234, 109.4877277314663, 93.29017728567123, 38.71417321264744, 31.195351369678974, 49.143458381295204, 63.78701761364937, 70.37202626466751, 74.49080005288124, 105.3086131811142, 50.52224479615688, 1.5250411606393754, 0.44310345605481416, 0.32165986485779285, 0.13825044559780508, 0.2755492797587067, 0.18179843929829076, 0.23653662472497672, 0.19035838544368744, 0.1548603636911139, 0.12453279574401677, 0.1663807814475149, 0.32137051632162184, 0.16945405950536951, 0.10019436696893536, 0.14210942055797204, 0.10610347293550149, 0.189742328657303, 0.1423180679557845, 0.20006251550512388, 0.15663571452023461, 0.12403910426655784, 0.12637853185879067, 0.09027704014442861, 0.0924093194771558, 0.14575341017916799, 0.10936614708043635, 0.09410363520146348, 0.1264502975391224, 0.09452085578232072, 0.20349830301711336, 0.10652356562786736, 0.13582289539044723, 0.15828035830054432, 0.09106739031267352, 0.1272366475313902, 0.20918891328619793, 0.09570282985805534, 0.22123684961115941], [0.09492447279626504, 0.057414384791627526, 0.01880331514257705, 0.02399444332695566, 0.02173763346945634, 0.08755352886510082, 0.043455177001305856, 0.10574088926659897, 0.031770314162713476, 0.02559420943725854, 0.024598108102509286, 0.02995443093823269, 0.020993732468923554, 0.04098640420124866, 0.058625740493880585, 0.015978233532223385, 0.022843463193567004, 0.03406087133043911, 0.0413778871006798, 0.034671417670324445, 0.06923296037712134, 0.0416121757007204, 0.06472747831139714, 0.04526538650679868, 0.02052518495474942, 0.10191352979745716, 0.013201617875893135, 0.16084532457171008, 0.08220645133405924, 0.18158017366658896, 0.2361455128993839, 0.07430066383676603, 0.261433512205258, 1.7799073783680797, 71.59910961985588, 94.83750745654106, 80.4800994694233, 64.04857277870178, 59.000593051314354, 35.04864290356636, 26.812083274126053, 47.09531508386135, 65.56731328368187, 73.07480603456497, 103.04309874773026, 68.08179795742035, 11.734734568744898, 0.4540876572718844, 0.022527837063535117, 0.15267644572304562, 0.07125844465917908, 0.1320640361518599, 0.07267760913236998, 0.141432240488939, 0.3673169086687267, 0.9335506497882307, 0.4973026493098587, 3.4812010126188397, 16.411332674324512, 40.30907303094864, 71.07344582676888, 101.45607590675354, 109.81186553835869, 98.26322123408318, 100.24628922343254, 97.30624258518219, 96.18505194783211, 96.09333246946335, 95.01027658581734, 92.22192540764809, 96.88372805714607, 91.75333455204964, 96.36016175150871, 96.16944998502731, 94.95346963405609, 70.67918658256531, 51.70848414301872, 26.31698314100504, 9.019095338881016, 1.9141662865877151, 1.2796530593186617, 4.221724038943648, 4.3751968536525965, 2.814432503655553, 0.6492590485140681, 4.776309505105019, 23.77904422581196, 40.47263145446777, 51.62262015044689, 64.8816628754139, 75.38468688726425, 76.76968216896057, 74.01728466153145, 74.33851942420006, 73.94416898488998, 56.4249050617218, 48.15616875886917, 54.21418748795986, 64.49377208948135, 92.66380369663239, 91.38049095869064, 93.85802641510963, 98.91549423336983, 95.63155084848404, 89.87288385629654, 87.90439948439598, 94.63411957025528, 101.74796104431152, 101.22652262449265, 94.58872720599174, 98.61407920718193, 89.47835102677345, 87.21295058727264, 93.11999201774597, 64.20315608382225, 6.770260585471988, 0.14964924019295722, 0.12365095361019485, 0.19663115119328722, 0.09469314536545426, 0.02422741090413183, 0.10645444199326448, 0.1337668049382046, 0.10199952987022698, 0.17599163838895038, 0.2965309820137918, 26.803567931056023, 80.02457991242409, 91.5990324318409, 73.11785012483597, 88.02665412425995, 58.44468668103218, 28.17863054573536, 19.49051834642887, 42.75128938257694, 54.93389166891575, 56.60075582563877, 77.41076856851578, 51.223687157034874, 3.595775314606726, 1.0376447578892112, 0.03266407518822234, 0.03661947739601601, 0.03595883237721864, 0.08715014191693626, 0.061793471686542034, 0.08387854715692811, 0.064291377493646, 0.07277909782715142, 0.11274503413005732, 0.014147786587273004, 0.024971608763735276, 0.11058076081098989, 0.08792076579993591, 0.04290194672648795, 0.08451789253740571, 0.037432793324114755, 0.03093720144534018, 0.08935327408835292, 0.028559120946738403, 0.02338579131901497, 0.018644304436747916, 0.038144268037285656, 0.06152440975711215, 0.012120320770918624, 0.055915283592185006, 0.07062075426802039, 0.07948241312988102, 0.05250093301583547, 0.048944338705041446, 0.026192469522356987, 0.02599885432573501, 0.08052072225837037, 0.021142458863323554, 0.04580285356496461, 0.07214631303213537, 0.024468067131238058, 0.07868208107538521, 0.11748804055969231, 0.034649635636014864, 0.038864277448737994, 0.04286221585061867, 0.014036924567335518, 0.04309252282837406, 0.049251049786107615, 0.026120857837668154, 0.026920473719656002, 0.031233192203217186, 0.03244839594117366, 0.06584438830032013, 0.05852412563399412, 0.11010080648702569, 0.04884631955064833, 0.047707011544844136, 0.046807747494312935, 0.00987500956398435, 0.04323952001868747, 0.019149018662574235, 0.0756569609802682, 0.03766287394682877, 0.01496787461292115, 0.03727047449501697, 0.014297707839432405, 0.1912459940649569, 0.12353891899692826, 0.1831819658400491, 0.20591518114088103, 0.22245530766667798, 0.47357508970890194, 7.842345032840967, 98.99418041110039, 101.94995060563087, 97.92212873697281, 94.61895078420639, 88.66815850138664, 59.82276253402233, 31.400760747492313, 19.85107909888029, 44.03214745223522, 68.10882970690727, 110.42908161878586, 73.82683888077736, 10.948646049946547, 0.6077530444599688, 0.03047668025828898, 0.09636560484068468, 0.06806355086155236, 0.24932430416811258, 0.0743008716381155, 0.14473101269686595, 0.2102995224413462, 0.35627104982268065, 3.36612228769809, 7.802034420892596, 26.375948376953602, 54.57340121269226, 86.46436035633087, 109.43108037114143, 111.71592056751251, 104.36383187770844, 106.05387479066849, 102.03549161553383, 101.27344250679016, 99.0717114508152, 101.12845748662949, 100.05252242088318, 102.36744180321693, 95.38951903581619, 101.89959570765495, 100.40591105818748, 99.40534114837646, 77.33878523111343, 59.846142679452896, 33.59493210911751, 12.72862158715725, 2.9599252715706825, 0.28488154930528253, 0.1688916451530531, 2.2992977080866694, 0.5268683284521103, 0.8193311537615955, 8.370922319591045, 32.14690960943699, 51.59018889069557, 64.17363926768303, 80.36361292004585, 89.75106999278069, 93.28839138150215, 90.40252983570099, 90.52326455712318, 97.74095445871353, 76.51866003870964, 65.19956141710281, 62.609194815158844, 78.0509202182293, 100.11499866843224, 97.89712607860565, 99.01572525501251, 101.92418798804283, 100.2137553691864, 91.2537069618702, 87.67263472080231, 97.36083045601845, 106.49484872817993, 106.13366290926933, 102.7335749566555, 103.06934013962746, 93.73712450265884, 93.00349026918411, 95.9626878798008, 80.07172778248787, 11.510274913161993, 0.2007736117229797, 0.00968602722423384, 0.2294477933901362, 0.10131096525583416, 0.0913370719354134, 0.10349417818360962, 0.01512746790467645, 0.09124295276706107, 0.5453851504717022, 0.7033535395748913, 23.75370528548956, 84.0905213356018, 92.72827863693237, 57.33366809785366, 44.13207069039345, 19.93442192673683, 25.988017693161964, 32.55360558629036, 72.13857427239418, 88.24997574090958, 71.74878358840942, 89.40830558538437, 72.11874693632126, 8.924541212618351, 1.1585983238182962, 0.008915072157833492, 0.07125692325644195, 0.07349152248934843, 0.0624902370327618, 0.06428302091080695, 0.1630399443092756, 0.07885633734986186, 0.037184470711508766, 0.10304969109711237, 0.049677053684717976, 0.07699325724388473, 0.06729429253027774, 0.107995682337787, 0.05230834569374565, 0.05006354935176205, 0.033733732634573244, 0.04550845842459239, 0.07339125091675669, 0.07375407207291573, 0.0228634492304991, 0.05321919838024769, 0.03462372726062313, 0.07784617788274772, 0.07082980242557824, 0.07297095784451813, 0.10114079079357907, 0.07515490549849346, 0.0405156933265971, 0.043036160423071124, 0.052176425233483315, 0.02079284422507044, 0.0393244424049044, 0.07499057915993035, 0.07564153173007071, 0.0885508862847928, 0.1525129802757874, 0.22046989935915917, 0.2498382265912369, 0.17385619750712067, 0.13920999801484868, 0.1070402711047791, 0.1727167039643973, 0.15472397179109976, 0.1617809501476586, 0.11595867457799613, 0.06495539186289534, 0.10366749193053693, 0.08259693975560367, 0.123668713204097, 0.08493883869959973, 0.18129180476535112, 0.1743008627090603, 0.28245736844837666, 0.08421500722761266, 0.2276990856626071, 0.21893570199608803, 0.11665434896713123, 0.18143483146559447, 0.18800257123075426, 0.185672182997223, 0.20065569930011407, 0.19469911814667284, 0.280206345487386, 0.23191304469946772, 0.23390505812130868, 0.3484292502980679, 0.32070742221549153, 0.6558107282035053, 7.148652356117964, 111.97677657008171, 117.96573400497437, 104.03359919786453, 87.10853978991508, 75.32887548208237, 49.04064729809761, 38.34995895624161, 69.49919790029526, 100.4742693901062, 107.41788759827614, 127.62721717357635, 87.32727885246277, 16.881724633276463, 0.8043381082825363, 0.07201648171758279, 0.5737742583733052, 0.30074008740484715, 0.2785418863641098, 0.15802790934685618, 0.41042678290978074, 1.7861226573586464, 4.497832423076034, 4.296041401103139, 4.825266553089023, 20.459842532873154, 48.1812360137701, 85.34980416297913, 112.38821089267731, 120.10208576917648, 106.84454396367073, 110.26037827134132, 106.13313093781471, 107.53663122653961, 104.53165367245674, 105.97737729549408, 106.3214260339737, 112.27351784706116, 104.88759577274323, 109.68871414661407, 108.0074867606163, 102.916649132967, 76.23122826218605, 59.29855406284332, 31.99022501707077, 12.709598857909441, 5.341824134811759, 6.205009091645479, 10.293597299605608, 13.49861416965723, 7.126430198550224, 1.588648441247642, 7.399588515982032, 34.82129730284214, 58.72986517846584, 72.51918464899063, 87.37435832619667, 95.2516396343708, 97.43577003479004, 95.59110581874847, 100.57788982987404, 117.01330751180649, 86.11272722482681, 64.72995981574059, 70.64807385206223, 87.50921308994293, 108.14635410904884, 111.91069811582565, 109.85259935259819, 114.87293556332588, 113.70034128427505, 102.6049442589283, 97.92950794100761, 106.97490736842155, 115.91896623373032, 113.58313277363777, 107.07830742001534, 111.7514106631279, 102.36263886094093, 98.53958040475845, 105.00374034047127, 78.73353078961372, 8.137680385261774, 1.0840095137245953, 0.7666820695158094, 0.48352230282034725, 0.19511662074364722, 0.2496840973617509, 0.4145999683532864, 0.40267591131851077, 0.17421974596800283, 0.7789187191519886, 1.1528277397155762, 41.17166854441166, 99.20225724577904, 106.89356133341789, 104.36095163226128, 119.48293179273605, 69.17247623205185, 33.89468662440777, 24.011924229562283, 56.793401688337326, 76.51667654514313, 71.91422671079636, 101.83701306581497, 80.02358436584473, 8.428872060030699, 1.4061716641299427, 0.09909854139550589, 0.15477305743843317, 0.10796862363349646, 0.266697951592505, 0.12764291401254013, 0.17002239619614556, 0.23727338440949097, 0.19052299379836768, 0.3001657244749367, 0.1690943553694524, 0.18142913177143782, 0.142768299265299, 0.2084710932103917, 0.1418752284371294, 0.27947319264058024, 0.14038113673450425, 0.15744323056424037, 0.2450261707417667, 0.11423808682593517, 0.30790899647399783, 0.19209453603252769, 0.15999792551156133, 0.17061436286894605, 0.19299538456834853, 0.1817087284871377, 0.1136754869366996, 0.24095786560792476, 0.14276656263973564, 0.10341231929487549, 0.14548726117936894, 0.10692992858821526, 0.13311739603523165, 0.19006716669537127, 0.28242509986739606, 0.23431567358784378], [0.10750080342404544, 0.04839293040276971, 0.022960768910706975, 0.03743382862012368, 0.041995999636128545, 0.14311066683148965, 0.09356484340969473, 0.05159236985491589, 0.0794823314936366, 0.09120694376179017, 0.02026089874561876, 0.04361730287200771, 0.014185498821461806, 0.05070334744232241, 0.06225546603673138, 0.03421147535846103, 0.0073239696939708665, 0.0501111432822654, 0.01643079889618093, 0.05332303226168733, 0.03888004437612835, 0.036960048964829184, 0.04838721586565953, 0.026463383110240102, 0.019043958382098936, 0.05091206534416415, 0.03293857334938366, 0.13051118119619787, 0.05415340274339542, 0.16623312374576926, 0.052303013362688944, 0.1835584721993655, 0.6298460683319718, 70.36714732646942, 94.63550269603729, 76.96767434477806, 85.50502583384514, 54.41578567028046, 33.59563507139683, 41.43866501748562, 87.03963428735733, 91.22596085071564, 66.90538108348846, 95.05769804120064, 40.80749228596687, 2.5548038352280855, 0.2435221045743674, 0.12087722861906514, 0.008852921000652714, 0.14633595157647505, 0.06367619644152, 0.1113651144260075, 0.22315070003969595, 0.7106005819514394, 4.378258064389229, 19.146577902138233, 58.7626726180315, 91.73542231321335, 114.55372229218483, 120.13303130865097, 114.02989760041237, 104.2271988093853, 105.93647629022598, 94.47638243436813, 89.64808031916618, 80.18870830535889, 77.43286058306694, 77.72740557789803, 82.04090371727943, 85.77754721045494, 84.5650626718998, 86.34111016988754, 93.61772730946541, 102.88139462471008, 101.19099453091621, 95.81321150064468, 82.41322293877602, 69.78654608130455, 40.676463916897774, 17.269189842045307, 5.041835457086563, 2.254620180465281, 1.7657746304757893, 0.5968663317617029, 6.5285498555749655, 18.7149590626359, 44.490201473236084, 60.93814328312874, 78.25417891144753, 93.30522447824478, 102.63438507914543, 110.9286180138588, 114.490235298872, 104.3776935338974, 96.55487090349197, 84.39826682209969, 101.56653597950935, 89.1011680662632, 98.38001936674118, 105.7791343331337, 98.68344828486443, 99.90455076098442, 91.93064823746681, 89.19835925102234, 87.38353103399277, 87.54885256290436, 94.35090556740761, 103.30643221735954, 109.90625247359276, 109.36355799436569, 101.00521489977837, 90.3301665186882, 93.23019370436668, 85.44953361153603, 100.73396265506744, 50.0419657677412, 4.58934148773551, 0.30860922764986753, 0.40624849149025977, 0.19565444032195956, 0.2080475346883759, 0.16345079726306722, 0.08887908625183627, 0.04167932151176501, 0.3729986725375056, 0.15979502233676612, 0.2762271277606487, 6.437208456918597, 65.34934937953949, 89.45133447647095, 66.91336825489998, 90.67830383777618, 77.5394980609417, 47.617676854133606, 26.930902898311615, 19.181482829153538, 58.70870031416416, 55.0855453312397, 80.89355528354645, 54.80305328965187, 17.484980262815952, 1.2804100499488413, 0.26659716793801636, 0.03295740163594019, 0.1529965637018904, 0.07494841032894328, 0.015514797560172155, 0.09343078927486204, 0.033654541766736656, 0.015983842313289642, 0.06632513672229834, 0.09860056030447595, 0.05502264692040626, 0.05463357229018584, 0.11833010357804596, 0.06207346174051054, 0.04927410831442103, 0.05761336571595166, 0.009450369361729827, 0.07603629492223263, 0.022428183328884188, 0.03735408485226799, 0.04043278058816213, 0.03302063632872887, 0.09965080316760577, 0.006423150380214793, 0.0625645779655315, 0.04378846810141113, 0.04506678036705125, 0.06281178735662252, 0.05418443935923278, 0.0660751888062805, 0.05684025563823525, 0.1101205030863639, 0.08238435155362822, 0.029785122933390085, 0.17150182306068018, 0.0375210235506529, 0.038241982911131345, 0.08466740560834296, 0.022811530434410088, 0.11444852279964834, 0.09100904266233556, 0.04945370805216953, 0.030085154685366433, 0.09687264755484648, 0.0361699362838408, 0.06723214508383535, 0.04289913398679346, 0.04371671355329454, 0.0810043873207178, 0.03654300278867595, 0.06336016027489677, 0.018059141402773093, 0.03356826338858809, 0.047585458887624554, 0.03720464970683679, 0.02169404899177607, 0.005239900274318643, 0.040547290263930336, 0.09339357799035497, 0.0479951763554709, 0.0390853966382565, 0.06606658731470816, 0.05434851707832422, 0.06562061593285762, 0.07851063754060306, 0.06840395915787667, 2.554007302969694, 98.05480241775513, 103.47355484962463, 104.8669020831585, 113.90996843576431, 81.81151002645493, 52.36214406788349, 23.806055076420307, 26.572234444320202, 60.38627229630947, 70.45059844851494, 106.40002101659775, 44.03274022042751, 1.3813884439878166, 0.15103767975233495, 0.08847555087413639, 0.15161762363277376, 0.23534731823019683, 0.04849480130360462, 0.10351532197091728, 0.21835880092112347, 0.6360812368802726, 8.070516139268875, 30.291089192032814, 74.77024465799332, 107.08334594964981, 123.72936353087425, 124.61057424545288, 114.72833052277565, 107.84128367900848, 107.66410678625107, 95.78539699316025, 91.22152268886566, 80.98436281085014, 80.34453794360161, 79.9370402097702, 83.05433213710785, 87.44438096880913, 87.28883251547813, 90.57741165161133, 100.17140284180641, 105.19730195403099, 102.39741459488869, 100.4806986451149, 90.45880481600761, 77.14042827486992, 50.33767729997635, 23.50824225693941, 6.790177691727877, 2.7244435949251056, 0.7833940477576107, 0.8530885423533618, 9.807045757770538, 25.90822197496891, 53.17536123096943, 72.78626471757889, 91.24364510178566, 102.93424978852272, 109.8102468252182, 119.91766646504402, 119.6441039443016, 111.60856872797012, 105.51653802394867, 95.69598019123077, 104.47387397289276, 97.33173161745071, 105.08441001176834, 103.68802294135094, 98.71646091341972, 101.36603593826294, 96.66507259011269, 92.21561774611473, 89.35426488518715, 91.22975304722786, 98.72232779860497, 104.97826650738716, 112.83716440200806, 111.70541793107986, 105.28994858264923, 92.59591653943062, 99.61139649152756, 93.71263861656189, 105.81467762589455, 59.35696452856064, 10.37051847204566, 0.9318170521873981, 0.3869271813891828, 0.3141285799210891, 0.18949281860841438, 0.125587951624766, 0.04199349488771986, 0.2673823304940015, 0.1797185852774419, 0.10092560507473536, 0.6897339422721416, 4.309932980686426, 63.30151006579399, 95.72574779391289, 74.97415691614151, 61.27753347158432, 33.75224746763706, 22.38695092499256, 26.032944582402706, 33.39294634759426, 90.70598915219307, 73.30714076757431, 89.86671298742294, 75.51522508263588, 30.688667558133602, 2.9729901580139995, 0.35081860958598554, 0.054740671621402726, 0.040869263611966744, 0.24047613755101338, 0.00896010011274484, 0.09167065247311257, 0.06830333135440014, 0.11372239066986367, 0.015558946070086677, 0.08633688907139003, 0.13427299418253824, 0.07105761949787848, 0.10123250540345907, 0.03125731942418497, 0.11017421231372282, 0.07349565625190735, 0.03458564024185762, 0.058431824727449566, 0.035357035958440974, 0.025941319327102974, 0.01465063338400796, 0.011842638796224492, 0.0303699334472185, 0.024939844843174797, 0.05369305225030985, 0.04186573045444675, 0.06896616570884362, 0.07584662424051203, 0.02964291074022185, 0.05434441671241075, 0.18365652475040406, 0.06293068683589809, 0.041869526539812796, 0.014774131395824952, 0.2505488181486726, 0.08107760761049576, 0.15634044364560395, 0.12134533826611005, 0.20931167935486883, 0.29250851192045957, 0.13502603658707812, 0.25015536113642156, 0.1775868551339954, 0.24410900980001315, 0.13557037222199142, 0.15304217609809712, 0.09252531715901569, 0.13482861046213657, 0.14593205996789038, 0.24715711420867592, 0.1878290274180472, 0.12575866043334827, 0.12323279792326503, 0.20154531172011048, 0.1213882195588667, 0.11174087863764726, 0.23116261465474963, 0.20647808531066403, 0.18276732793310657, 0.1158224162645638, 0.15236155246384442, 0.23767089354805648, 0.2357642716378905, 0.2456378933857195, 0.1024164239061065, 0.21635040087858215, 2.4177558766677976, 109.09402325749397, 124.40840989351273, 101.91336616873741, 107.78928726911545, 68.74284088611603, 43.00906755030155, 53.864784836769104, 115.33084899187088, 123.98670852184296, 91.01219192147255, 118.88740494847298, 55.039115622639656, 4.28369396366179, 0.4016032407525927, 0.22912353422725573, 0.40616240235976875, 0.36200948408804834, 0.22166453447425738, 0.4251042375108227, 0.6308767630252987, 2.400790499523282, 8.282037489116192, 21.37024138122797, 65.53949117660522, 103.18545430898666, 127.04051345586777, 129.98410910367966, 118.42492416501045, 112.55670145154, 115.86468234658241, 105.04242226481438, 100.78697741031647, 89.77050974965096, 88.3910545706749, 87.15792953968048, 91.02286174893379, 95.92836052179337, 96.35898381471634, 97.60859996080399, 105.42788878083229, 108.89125093817711, 107.4079093337059, 108.02682012319565, 95.1372429728508, 80.0675556063652, 48.935107961297035, 22.65480425208807, 6.990689607337117, 5.178535021841526, 5.01077544875443, 3.039890555664897, 9.440495576709509, 25.115732699632645, 60.387416034936905, 81.39474079012871, 95.33187612891197, 108.81328672170639, 114.46421429514885, 126.06642812490463, 124.03384879231453, 114.81261000037193, 107.70470380783081, 110.06783500313759, 118.74177396297455, 110.87088391184807, 115.98062172532082, 114.57519114017487, 108.90935316681862, 111.88699498772621, 104.285077303648, 99.07975181937218, 96.53556793928146, 96.44909217953682, 107.51635551452637, 113.72167333960533, 119.4076806306839, 117.96548321843147, 112.67277762293816, 100.82951992750168, 106.94099798798561, 99.06769886612892, 110.52346095442772, 60.37318579852581, 7.3948796186596155, 0.8019455429166555, 0.9558504063170403, 0.9366191632580012, 0.48670733347535133, 0.47800942207686603, 0.24747556977672502, 0.41449805663432926, 0.4720028646988794, 0.22107705037342384, 0.7628680835478008, 11.575888842344284, 83.74091729521751, 102.14527532458305, 90.17929181456566, 129.15204495191574, 98.78999456763268, 57.910473346710205, 32.866818979382515, 22.961466796696186, 76.59457996487617, 72.91791245341301, 100.34740939736366, 87.33804747462273, 30.915163904428482, 2.3916180292144418, 0.4645838518626988, 0.09811128460569307, 0.21297144703567028, 0.2944095974089578, 0.17621646460611373, 0.20422253524884582, 0.19063680956605822, 0.28280962142162025, 0.140056076052133, 0.23256773769389838, 0.31476920179557055, 0.11417842557420954, 0.25628621340729296, 0.1305446372134611, 0.16540638607693836, 0.17219185712747276, 0.17303702974459156, 0.19145888654747978, 0.07477247680071741, 0.15328200854128227, 0.1088795208488591, 0.21270804398227483, 0.1686285389587283, 0.10042044741567224, 0.10676598074496724, 0.082544017204782, 0.13677217648364604, 0.19509940291754901, 0.17595408571651205, 0.08770414773607627, 0.2593728946521878, 0.17901798302773386, 0.12797250179573894, 0.09353511297376826], [0.033364822156727314, 0.0717867053754162, 0.019115143331873696, 0.007170988938014489, 0.05986136071442161, 0.08125040185404941, 0.051889154710806906, 0.06811973886215128, 0.0364133644325193, 0.07476636150386184, 0.04712619564088527, 0.03454385732766241, 0.04122933511098381, 0.055865593094495125, 0.03266580810304731, 0.050842036289395764, 0.06720861158100888, 0.0218972360380576, 0.048354784012190066, 0.0417855785053689, 0.057208910075132735, 0.10920979882939719, 0.06506575664388947, 0.09809837865759619, 0.028519787119876128, 0.026795445955940522, 0.08219245442887768, 0.20629713486414403, 0.09957925271010026, 0.038780975082772784, 0.10775462535093538, 0.23771395295625553, 44.028100669384, 99.30098354816437, 91.75633639097214, 63.21630343794823, 42.5750358402729, 38.24321888387203, 55.190845280885696, 99.83080431818962, 83.91255408525467, 76.96668639779091, 91.48338183760643, 29.584745094180107, 1.446979099418968, 0.12626666051801294, 0.23168860439909622, 0.05072446154372301, 0.034749076003208756, 0.1541003747843206, 0.06655033401330002, 0.14214976370567456, 2.8841962851583958, 22.89179753512144, 62.12367206811905, 99.36476692557335, 104.68930721282959, 94.51945692300797, 91.38793095946312, 99.95681315660477, 104.7729179263115, 106.06310069561005, 95.04723340272903, 81.67528733611107, 76.54566138982773, 81.61649689078331, 84.47866290807724, 80.43295159935951, 78.47253799438477, 74.85844552516937, 84.07136276364326, 92.0632155239582, 101.14342868328094, 100.86184099316597, 98.04900392889977, 90.5912809073925, 91.97035610675812, 93.95105302333832, 90.19053921103477, 55.35653539001942, 34.278834611177444, 14.685460533946753, 4.313718527555466, 6.601033341139555, 32.03560598194599, 46.747732535004616, 53.71476888656616, 76.03255972266197, 91.21884003281593, 105.02158418297768, 108.7346613407135, 109.40677687525749, 111.87945619225502, 118.96213933825493, 123.7868620455265, 105.18043845891953, 88.56467485427856, 86.4793087542057, 95.06491005420685, 101.99025884270668, 89.32793989777565, 95.77570751309395, 91.72767072916031, 91.11622273921967, 84.39351707696915, 89.25762847065926, 88.7862029671669, 95.17880514264107, 101.11031726002693, 102.07399874925613, 88.57086092233658, 81.58049762248993, 86.75449758768082, 95.08717685937881, 96.71978205442429, 78.1275925040245, 63.30910585820675, 23.495894819498062, 2.423787578009069, 0.5709964293055236, 0.28232473181560636, 0.05781187166576274, 0.06263830291572958, 0.08069980249274522, 0.08491621061693877, 0.04112518210604321, 0.18168922484619543, 0.24873318354366347, 0.5053586326539516, 42.147342190146446, 94.50029075145721, 67.4326179921627, 80.70876359939575, 107.02259480953217, 72.3765479028225, 45.79654477536678, 25.663287118077278, 42.06440404057503, 60.28963588178158, 69.25349548459053, 72.39871591329575, 52.743210420012474, 2.4734050780534744, 0.1704119791975245, 0.015502372152695898, 0.3611787536647171, 0.008652850046928506, 0.033381427710992284, 0.07529126771260053, 0.0765344244427979, 0.054826738487463444, 0.02353074018174084, 0.05236691598838661, 0.07214297336759046, 0.06784725934267044, 0.06624673624173738, 0.005653665693898802, 0.04089534639206249, 0.01890179999463726, 0.06920617626747116, 0.03119062261248473, 0.06056358455680311, 0.04782258991326671, 0.030091962034930475, 0.04591612014337443, 0.06078775768401101, 0.029390827294264454, 0.07063007564283907, 0.03380319023563061, 0.1261085385340266, 0.0377743890567217, 0.03263293096097186, 0.028838370708399452, 0.09413914696779102, 0.046123023494146764, 0.06555613814271055, 0.03413200247450732, 0.11207725707208738, 0.011693706455844222, 0.058187524555251, 0.022018517811375204, 0.019537245389074087, 0.025471994413237553, 0.018223133774881717, 0.05035327638324816, 0.08483511614031158, 0.060051235486753285, 0.10430022477521561, 0.0754000071901828, 0.08511670181178488, 0.009184572882077191, 0.05376373810577206, 0.060911777982255444, 0.027717423436115496, 0.11344902799464762, 0.09189465490635484, 0.1318496000021696, 0.05155004146217834, 0.07725381787167862, 0.07603137448313646, 0.031034740059112664, 0.056712320510996506, 0.03592375847802032, 0.1211971313750837, 0.015237183306453517, 0.050377221778035164, 0.04719761622254737, 0.09334619928267784, 66.79757326841354, 110.46766474843025, 111.84380650520325, 92.360769957304, 71.35519310832024, 46.4285534620285, 21.69031910598278, 39.157962799072266, 76.11198306083679, 91.3675944507122, 104.22610446810722, 31.25942923128605, 1.3489873451180756, 0.05927979895204771, 0.06751825043465942, 0.008655760193505557, 0.22661810304271057, 0.06945530039956793, 0.12250374915311113, 0.09682739881100133, 6.3588362373411655, 35.77365159988403, 76.65116652846336, 106.52478352189064, 108.02457824349403, 96.98589697480202, 93.77702236175537, 102.30415999889374, 109.06446844339371, 109.5684278011322, 95.51837012171745, 84.67189013957977, 81.71629473567009, 89.02555212378502, 92.26588904857635, 87.44552850723267, 84.95912432670593, 78.93919855356216, 90.25062918663025, 98.92341300845146, 103.95963236689568, 102.52706363797188, 102.55588129162788, 95.62978774309158, 94.29491937160492, 99.20105651021004, 97.98452898859978, 69.56793621182442, 46.30156047642231, 22.57551960647106, 9.36285624280572, 11.735030002892017, 44.961630776524544, 60.158656910061836, 62.26047992706299, 87.98839777708054, 99.1367943584919, 111.74323350191116, 111.42963632941246, 111.47798493504524, 113.91324386000633, 120.5120761692524, 127.97904789447784, 113.39783191680908, 98.06496307253838, 93.86801987886429, 99.99427154660225, 104.82911691069603, 93.37730661034584, 94.12265181541443, 90.81044554710388, 92.36066356301308, 87.0617339015007, 90.77243998646736, 90.68975642323494, 95.64191669225693, 103.30818012356758, 101.94194823503494, 89.54095646739006, 83.6127957701683, 90.46448931097984, 98.47741574048996, 103.03888857364655, 91.56228080391884, 75.38708075881004, 32.096064537763596, 5.9274073876440525, 0.6409262144006789, 0.4339254047954455, 0.25350669224280864, 0.2741216844879091, 0.05978517554467544, 0.0801738201698754, 0.04187214632111136, 0.08257613735622726, 0.4268362617585808, 0.35168045083992183, 37.734163999557495, 102.03587919473648, 75.36279246211052, 74.42995771765709, 69.51881244778633, 34.330637231469154, 16.20306584984064, 36.02588966488838, 76.01734533905983, 84.4473297894001, 81.53452768921852, 84.30298313498497, 74.72159206867218, 6.869310345500708, 0.2341101728961803, 0.11815123856649734, 0.3200607147300616, 0.08664617911563255, 0.014235999187803827, 0.03800719336140901, 0.09282058803364635, 0.031190808149403892, 0.045117335466784425, 0.06605866117752157, 0.10651995879015885, 0.09910904278513044, 0.026229038849123754, 0.09103118092752993, 0.016649875324219465, 0.04424518207088113, 0.028240444589755498, 0.06475372065324336, 0.02668558583536651, 0.05774907855084166, 0.01850008102337597, 0.04112286289455369, 0.10679610451916233, 0.06451231485698372, 0.04472943714063149, 0.03645973753009457, 0.07977246670634486, 0.07082688578520902, 0.026795366175065283, 0.033384492780896835, 0.1104589446913451, 0.0519451052241493, 0.04796405068191234, 0.12550104613183066, 0.3948063851566985, 0.13609860325232148, 0.17025125969666988, 0.14275879977503791, 0.11913359718164429, 0.18605345394462347, 0.2372344068135135, 0.0962793079088442, 0.21478945651324466, 0.16124362038681284, 0.2458810803364031, 0.20366424723761156, 0.2641446073539555, 0.1675047492608428, 0.16128149960422888, 0.2912016195477918, 0.10136365774087608, 0.1562729527358897, 0.18589101266115904, 0.38622588152065873, 0.19510465732309967, 0.2871447434881702, 0.19876720063621178, 0.07007323481957428, 0.14717220357852057, 0.1674782991176471, 0.31219638360198587, 0.13562116480898112, 0.09048732768860646, 0.21470725623657927, 0.24213608441641554, 73.79026964306831, 129.4007796049118, 115.11235311627388, 84.55326810479164, 54.28346537053585, 48.93897235393524, 72.34558716416359, 138.93399685621262, 119.82413068413734, 100.68355455994606, 113.6456698179245, 42.0480877161026, 2.794103119522333, 0.21187771431868896, 0.37109476688783616, 0.16129278024891391, 0.294369580806233, 0.29492957575712353, 0.24190888332668692, 0.5245688580907881, 5.704387854784727, 29.011526852846146, 69.42918285727501, 114.97651800513268, 119.44526821374893, 105.23637905716896, 97.83627614378929, 107.87749573588371, 115.16318678855896, 119.17944207787514, 103.54574337601662, 89.3754069507122, 84.99544277787209, 92.27579891681671, 94.49936360120773, 90.16014844179153, 90.56063175201416, 83.35832342505455, 96.3239648938179, 108.59498843550682, 111.66961625218391, 108.00449252128601, 108.59767869114876, 102.433702647686, 103.5486388206482, 106.9654230773449, 102.37574055790901, 67.93478384613991, 43.58591079711914, 19.806165508925915, 8.54802891612053, 9.045556169003248, 41.00364536046982, 67.33199939131737, 72.42955505847931, 95.75000569224358, 103.99187743663788, 114.74341571331024, 115.86823895573616, 113.16592276096344, 117.59829372167587, 123.80433350801468, 127.49209642410278, 117.28582128882408, 104.00345921516418, 103.55436891317368, 107.57365643978119, 112.11591750383377, 104.01225954294205, 103.22476699948311, 101.08757928013802, 100.82210272550583, 95.87846159934998, 98.86606648564339, 97.26540237665176, 102.97439083456993, 111.39938995242119, 112.40260452032089, 97.17444285750389, 89.87545251846313, 96.69389024376869, 108.00990343093872, 109.32185143232346, 95.1555047929287, 68.470129519701, 26.602283231914043, 4.7086588852107525, 1.6936264769174159, 0.8333328680600971, 0.4045804403722286, 0.27973392396233976, 0.21079849801026285, 0.3438487445237115, 0.17303833592450246, 0.26812854513991624, 1.0498945880681276, 1.5084977983497083, 59.47213254868984, 109.30488914251328, 82.6591457426548, 110.29899939894676, 143.41201096773148, 94.30403888225555, 58.48507471382618, 32.730558291077614, 55.69900721311569, 79.49432596564293, 83.97738620638847, 99.81338605284691, 81.52028605341911, 6.36970080435276, 0.4042474535526708, 0.24007067258935422, 0.5593505292199552, 0.20553588430630043, 0.12406887923134491, 0.16076909116236493, 0.1460577649413608, 0.13591015711426735, 0.11748458215151913, 0.14690819196403027, 0.14074575388804078, 0.1547866387409158, 0.1077541577978991, 0.21849629119969904, 0.08153025832143612, 0.11190297853318043, 0.18244786304421723, 0.22859295801026747, 0.0912927657191176, 0.16179460566490889, 0.07354025190579705, 0.10778185474919155, 0.21003766305511817, 0.22011605818988755, 0.17354538606014103, 0.1381269670673646, 0.21634875331074, 0.20564661273965612, 0.12401280997437425, 0.1718353887554258, 0.19166128506185487, 0.20206971326842904, 0.1098253954842221], [0.028988622216274962, 0.04109008594241459, 0.04485608464165125, 0.03563651393051259, 0.0755069284059573, 0.0492596846743254, 0.08399349098908715, 0.04196087007585447, 0.012183274375274777, 0.02515083186153788, 0.07879951110226102, 0.06966756947804242, 0.14920414454536512, 0.029880464790039696, 0.1391514128772542, 0.061787953818566166, 0.05741370201576501, 0.06399841469828971, 0.0669575652864296, 0.16919165092986077, 0.01582633445650572, 0.12597495195223019, 0.01650947397138225, 0.010958984894386958, 0.06007846117427107, 0.028046178158547264, 0.05439448570541572, 0.06676979450276121, 0.039372585524688475, 0.09985539843910374, 0.08130614456604235, 33.50714161992073, 91.2298746407032, 94.76825997233391, 81.9865894317627, 48.3524814248085, 49.37073938548565, 74.81043130159378, 93.0093115568161, 79.2208394408226, 80.80790027976036, 102.35335975885391, 22.57553480565548, 0.8183117397129536, 0.059383150437497534, 0.22369611921021715, 0.057551782301743515, 0.02813034883729415, 0.05300809447362553, 0.12892332655610517, 0.1521774404682219, 11.37327991425991, 51.86790078878403, 81.95312842726707, 92.90772020816803, 84.98511493206024, 83.0044636130333, 86.21260866522789, 88.68243053555489, 91.10799238085747, 93.58586981892586, 81.87399387359619, 74.13410559296608, 77.33262956142426, 91.57472893595695, 95.15984416007996, 104.59999680519104, 97.79773101210594, 92.06957638263702, 92.63203740119934, 91.65360510349274, 98.30022364854813, 96.6125214099884, 98.43425765633583, 102.13987201452255, 87.16692745685577, 87.30910822749138, 98.66642519831657, 102.25410148501396, 93.58371153473854, 78.93143936991692, 63.61734911799431, 44.77213494479656, 46.71011455357075, 77.51009523868561, 77.92743444442749, 74.24938380718231, 85.19721955060959, 95.61126753687859, 103.14727395772934, 105.57047232985497, 105.11722505092621, 106.99891448020935, 110.26774987578392, 110.32668471336365, 107.28611066937447, 105.5681012570858, 102.98125326633453, 99.61600184440613, 101.8287219107151, 96.86953961849213, 92.87927493453026, 88.04414078593254, 83.06013062596321, 83.7547105550766, 81.66015654802322, 85.75349450111389, 84.4915822148323, 85.67884370684624, 81.74360007047653, 80.71125626564026, 78.6945828795433, 81.6017384827137, 89.54249918460846, 93.17718654870987, 99.93945568799973, 91.12562343478203, 66.0574945807457, 33.886152282357216, 4.039797401055694, 0.34862485073972493, 0.20509485562797636, 0.17695463437121361, 0.09802625674637966, 0.12294892643694766, 0.17377533309627324, 0.38666229404043406, 0.08895719729480334, 0.07682420342462137, 0.25850835198070854, 26.228151507675648, 97.0495131611824, 74.56173464655876, 124.6448864042759, 133.07845026254654, 137.06592589616776, 42.071365267038345, 17.757723927497864, 37.334851026535034, 54.46528181433678, 61.74772024154663, 76.6547155380249, 55.2410975843668, 1.9683744153007865, 0.2842890186002478, 0.12187435597297736, 0.13951567379990593, 0.02826659972924972, 0.06940119041246362, 0.057213797117583454, 0.1032569506787695, 0.011887676027981797, 0.06334031524602324, 0.058100760070374236, 0.048305472009815276, 0.07765497095533647, 0.010868444733205251, 0.018872531545639504, 0.01889542123535648, 0.012775708601111546, 0.03780279846978374, 0.023338779974437784, 0.07941731935716234, 0.08294994971947744, 0.0316689664759906, 0.07094600790878758, 0.08847500168485567, 0.07517449077568017, 0.06840907255536877, 0.07216105950647034, 0.11124707583803684, 0.0788365220068954, 0.0560816508368589, 0.010264122229273198, 0.07897830189904198, 0.04223747964715585, 0.07941098141600378, 0.024903500016080216, 0.01967245541891316, 0.022745481146557722, 0.011990422663075151, 0.05188436043681577, 0.03365292759553995, 0.10716277742176317, 0.033423967615817674, 0.0842902016302105, 0.1750987902050838, 0.1253609434934333, 0.22035194240743294, 0.13521032669814304, 0.044437706310418434, 0.06870705969049595, 0.03004105070431251, 0.07364675009739585, 0.06884382266434841, 0.08300045286887325, 0.022165479749673977, 0.03627698366472032, 0.04390718575450592, 0.005181817014090484, 0.1058563674450852, 0.024935644287324976, 0.0563921394495992, 0.014315765220089816, 0.16108376177726313, 0.05032051798480097, 0.22709042066708207, 58.761012107133865, 107.55794808268547, 111.5758828818798, 105.5982868373394, 74.23104599118233, 47.3954039812088, 22.503910548985004, 54.71325270831585, 87.64512419700623, 94.38148632645607, 109.05175432562828, 23.084340803325176, 0.9969338611699641, 0.06689834932330996, 0.13156293804058805, 0.07661643918254413, 0.02302386816154467, 0.09664092678576708, 0.2816504758084193, 0.39680356392636895, 18.489135280251503, 65.76441630721092, 92.57461488246918, 100.43350517749786, 92.23804414272308, 90.48698410391808, 90.87049752473831, 94.32904914021492, 94.8167073726654, 91.59004211425781, 83.18502232432365, 77.65590861439705, 82.6514245569706, 99.51654598116875, 101.6486343741417, 110.9007503092289, 102.56350368261337, 96.47511318325996, 95.22175803780556, 95.5662627518177, 101.83080419898033, 101.19022697210312, 102.42310121655464, 105.94782248139381, 89.8011589050293, 89.8785911500454, 95.49889996647835, 102.86092892289162, 95.7563665509224, 86.31893455982208, 74.30027067661285, 58.18786606192589, 61.368675380945206, 90.43725237250328, 89.09797623753548, 80.38410902023315, 96.24118253588676, 99.99553307890892, 104.3189562857151, 105.33824399113655, 106.07579961419106, 111.16678163409233, 115.55513575673103, 114.05165523290634, 112.92360216379166, 109.1688184440136, 106.3358348608017, 106.19680792093277, 101.35187789797783, 98.64367961883545, 97.55293294787407, 93.22629511356354, 86.0374304652214, 85.86689561605453, 85.2636855840683, 88.59674513339996, 83.69787320494652, 85.16950383782387, 81.51569589972496, 83.85776862502098, 81.08254194259644, 84.80128839612007, 92.75793984532356, 96.12422481179237, 101.48709744215012, 98.21653693914413, 75.75968116521835, 42.248089984059334, 6.399370087310672, 0.28953852597624063, 0.6474694632925093, 1.1069414019584656, 0.3946103691123426, 0.09176667153951712, 0.11824237430118956, 0.43244434520602226, 0.06343753659166396, 0.04665014501370024, 0.3037347423378378, 23.287251815199852, 100.9580746293068, 80.05962923169136, 120.73149919509888, 129.64668720960617, 105.81580236554146, 15.539854187518358, 23.77188540995121, 67.63700902462006, 79.79310393333435, 84.9155330657959, 85.07884830236435, 77.7116060256958, 5.163729591295123, 0.4159402573714033, 0.2426832402125001, 0.0988589390181005, 0.11694099608575925, 0.09160825269646011, 0.07099857422872446, 0.10611423407681286, 0.05942102965491358, 0.025053098434000276, 0.034356799005763605, 0.012666034945141291, 0.05241082515567541, 0.040525129734305665, 0.06832178856711835, 0.05075784705695696, 0.03644906173576601, 0.030596542674174998, 0.07076922091073357, 0.013923685819463572, 0.03270459645136725, 0.017888564325403422, 0.11132559506222606, 0.14092296391027048, 0.027196741903026123, 0.10679357379558496, 0.0298957790073473, 0.04667135188356042, 0.12613117403816432, 0.11917644878849387, 0.10579002686426975, 0.1251561997924, 0.00552299482478702, 0.20431462093256414, 0.12504561978857964, 0.12213844180223532, 0.09534944882034324, 0.1573067347635515, 0.1252818453940563, 0.20540581550449133, 0.1749570993706584, 0.07775326841510832, 0.16915893706027418, 0.22511247836519033, 0.19514155690558255, 0.3618070262018591, 0.19339856371516362, 0.2533322578528896, 0.1796274643857032, 0.10160478894249536, 0.13417293783277273, 0.1648086158093065, 0.21233673265669495, 0.11510375756188296, 0.207698977610562, 0.1893901647417806, 0.11274997683358379, 0.2238416246837005, 0.16266428399831057, 0.14564906421583146, 0.16991076234262437, 0.35879907198250294, 0.24417031119810417, 0.12364707959932275, 61.97992958128452, 127.33105346560478, 111.89701125025749, 106.6948851943016, 59.2727230489254, 64.88599464297295, 93.3133864402771, 135.12646436691284, 111.14092022180557, 97.65650019049644, 126.48610800504684, 33.205050230026245, 1.6299494937993586, 0.2558869676431641, 0.2190924881142564, 0.24260445381514728, 0.13095505972160026, 0.23226859280839562, 0.403277229052037, 0.8242443494964391, 15.619032438844442, 60.86972415447235, 97.6982219517231, 111.87710791826248, 99.3088187277317, 93.19859459996223, 97.51921355724335, 102.07086011767387, 104.10133436322212, 101.54384359717369, 91.85968324542046, 81.63176447153091, 85.78569397330284, 102.77320683002472, 106.75003543496132, 115.907202064991, 108.85493248701096, 103.21414276957512, 101.13255366683006, 104.06304761767387, 107.9699219763279, 105.81700310111046, 108.74811261892319, 115.41143506765366, 97.24555984139442, 97.82578110694885, 104.31091591715813, 110.77340394258499, 105.85170283913612, 96.32050707936287, 81.8744270503521, 58.88067528605461, 62.92075529694557, 95.77677145600319, 95.12142062187195, 93.52298319339752, 100.40608584880829, 103.07870283722878, 111.66136309504509, 110.74827209115028, 112.59912237524986, 115.9788130223751, 120.8488216996193, 118.94114926457405, 118.79036575555801, 118.22649881243706, 113.38254913687706, 112.01918229460716, 107.94793635606766, 106.55289441347122, 101.31410792469978, 96.975417137146, 87.3166698217392, 91.84392929077148, 89.3146862089634, 93.5136204957962, 91.07455417513847, 92.67439752817154, 86.97936952114105, 88.95362198352814, 85.85234239697456, 91.91595062613487, 100.00848278403282, 103.98091122508049, 108.75470906496048, 106.54505923390388, 78.75740870833397, 40.19140474498272, 4.813648201525211, 2.303227409720421, 1.6144039342179894, 0.8746840304229409, 0.25015111605171114, 0.15968411578796804, 0.34031840739771724, 0.5565245496109128, 0.29383861867245287, 0.17190414131619036, 0.759368590079248, 41.469918340444565, 113.96027013659477, 85.42308703064919, 134.09656763076782, 153.41012567281723, 168.80806982517242, 58.675303906202316, 23.445070646703243, 48.566854521632195, 72.26383835077286, 77.35588431358337, 95.64498692750931, 89.29245740175247, 5.862770956009626, 0.6033363158348948, 0.39528717810753733, 0.23398678342346102, 0.22554745111847296, 0.18496347649488598, 0.1316528714960441, 0.19974018592620268, 0.15783716255100444, 0.12173902534414083, 0.15375079354271293, 0.17822152498411015, 0.18916907894890755, 0.10304122319212183, 0.15694945002906024, 0.10235944922897033, 0.11079852178227156, 0.10570305457804352, 0.20452320895856246, 0.1334167635650374, 0.14245730970287696, 0.17912486713612452, 0.2500162529759109, 0.17091674351831898, 0.17055460513802245, 0.2060634028748609, 0.1328803540673107, 0.2208521350985393, 0.18812867696397007, 0.24697197804925963, 0.15594278607750311, 0.17319340026006103, 0.11730205835192464], [0.042305178358219564, 0.0820180051960051, 0.006825522441431531, 0.03354184293129947, 0.007185952490544878, 0.09252887946786359, 0.06261980117415078, 0.024937581292761024, 0.052233002861612476, 0.037453117038239725, 0.07339059040532447, 0.040049539238680154, 0.007379074622804183, 0.09700423775939271, 0.03912163199856877, 0.035895122709916905, 0.03721320295881014, 0.07079515897203237, 0.04257428852724843, 0.02199832582846284, 0.05647393154504243, 0.040206299381679855, 0.05122355585626792, 0.02910412451456068, 0.049955707872868516, 0.05791892275738064, 0.08388343048864044, 0.22704281931510195, 0.1598676637513563, 0.47158865723758936, 47.05097906291485, 102.96788558363914, 85.31457245349884, 73.2218961417675, 70.77730491757393, 34.73127253353596, 93.85656729340553, 113.05135130882263, 77.96445965766907, 104.78919625282288, 111.51244908571243, 21.244105249643326, 0.4928152385400608, 0.16941031732130796, 0.2376040705712512, 0.030292824303614907, 0.10205709826550446, 0.12425986351445317, 0.203674815420527, 0.23534074280178174, 21.166935190558434, 70.23317411541939, 89.17391896247864, 88.40384468436241, 84.10270348191261, 85.01371219754219, 80.02443552017212, 74.68655034899712, 70.07473781704903, 76.78244188427925, 74.2495433986187, 78.70702341198921, 84.80995193123817, 94.00655284523964, 97.90740072727203, 101.11827403306961, 97.88683623075485, 96.93435654044151, 100.09655445814133, 95.25322034955025, 96.5469141304493, 106.60403206944466, 107.1194440126419, 101.07798099517822, 90.03548473119736, 75.22529304027557, 86.97338864207268, 89.07173484563828, 96.83696776628494, 91.64865016937256, 85.71681886911392, 77.48597413301468, 88.4602564573288, 76.32810026407242, 81.83572232723236, 92.92262300848961, 79.22194138169289, 89.13200721144676, 91.95768758654594, 94.27858024835587, 97.11791709065437, 92.4670122563839, 94.62295576930046, 102.64529049396515, 107.22674265503883, 105.0138022005558, 91.34404331445694, 82.88192018866539, 95.26385977864265, 94.2336742579937, 96.45583301782608, 99.94154557585716, 97.3435489833355, 93.46640422940254, 84.8647753894329, 78.44764932990074, 79.66878220438957, 81.35444775223732, 85.15361309051514, 88.91249299049377, 89.93434935808182, 86.51160702109337, 79.81009662151337, 79.58394795656204, 84.70094338059425, 84.7129887342453, 84.59997519850731, 82.38330334424973, 58.738631308078766, 25.765326842665672, 1.9348000106401742, 0.4720068722963333, 0.49988277023658156, 0.3359700454166159, 0.06780097159207799, 0.1635602640453726, 0.07138183413189836, 0.2626281324774027, 0.223547778732609, 0.051948700929642655, 0.48357986379414797, 16.793377473950386, 101.68056026101112, 80.71016952395439, 95.20218908786774, 92.19632238149643, 102.92442351579666, 70.87277859449387, 25.71624867618084, 20.183515660464764, 41.86618007719517, 63.92008647322655, 69.35836985707283, 53.186350241303444, 3.923351224511862, 0.9376954555045813, 0.040034841003944166, 0.10347804389311932, 0.07932123349746689, 0.03327039128635079, 0.03498487116303295, 0.06420893972972408, 0.04392231443489436, 0.04399019126140047, 0.09049220359884202, 0.036971570807509124, 0.017514054343337193, 0.03348529127833899, 0.05785636341897771, 0.016740153878345154, 0.011816376045317156, 0.03443184497882612, 0.01705101727566216, 0.019850522621709388, 0.08627068207715638, 0.013913378315919545, 0.0848545678309165, 0.09552377188811079, 0.025148425447696354, 0.08424156127148308, 0.042720313504105434, 0.03064951531996485, 0.1013554866949562, 0.0674209177668672, 0.057011205644812435, 0.12766572763212025, 0.040768576436676085, 0.0791014613059815, 0.0031698133807367412, 0.05885118640435394, 0.053875891462666914, 0.03661959242890589, 0.010327121290174546, 0.00482219405057549, 0.03671358172141481, 0.017905732056533452, 0.07889184169471264, 0.12658584339078516, 0.03182885477144737, 0.03419054679397959, 0.08956136487540789, 0.061424435043591075, 0.017259006017411593, 0.10478774158400483, 0.053615805809386075, 0.006687957020403701, 0.057275640283478424, 0.14967416151193902, 0.004444794330993318, 0.06805109762353823, 0.061647569164051674, 0.018590209292597137, 0.1529464835766703, 0.17961680714506656, 0.16687971248757094, 1.8710129521787167, 75.64303502440453, 114.07139897346497, 106.63804784417152, 107.21633121371269, 109.99828353524208, 32.18141935765743, 42.306591644883156, 89.29577842354774, 82.10932284593582, 116.43256187438965, 117.54913195967674, 23.155548982322216, 0.7104296504985541, 0.2948930620914325, 0.2520833123708144, 0.04526929020357784, 0.33457813260611147, 0.21110816654982045, 0.2171447512228042, 1.5056792995892465, 31.264340467751026, 79.54192981123924, 96.28904476761818, 97.5852844119072, 91.59916922450066, 90.85169613361359, 82.92178004980087, 78.28199341893196, 72.99497231841087, 82.32151105999947, 76.9850318133831, 82.9941737651825, 90.01544460654259, 100.68962663412094, 102.18789383769035, 107.47277945280075, 101.10301405191422, 100.07616475224495, 103.21647584438324, 96.63068443536758, 101.40323594212532, 108.47209542989731, 111.1199301481247, 103.37918311357498, 94.93261635303497, 78.46752226352692, 89.85135421156883, 90.9931093454361, 99.47489261627197, 96.24159291386604, 89.75483939051628, 82.69734129309654, 94.7848042845726, 88.15194100141525, 96.01020812988281, 99.89686757326126, 83.34471255540848, 95.18082663416862, 95.44136345386505, 98.2478928565979, 99.35731172561646, 94.44366618990898, 99.99348878860474, 106.9363622367382, 111.15426510572433, 109.86474350094795, 98.79477471113205, 86.77770674228668, 100.63026621937752, 100.13639912009239, 101.06742516160011, 103.46853911876678, 99.92547243833542, 100.13697668910027, 89.36898529529572, 83.4439404308796, 82.12744027376175, 85.54208144545555, 88.46964955329895, 92.26914927363396, 91.94879606366158, 90.15498831868172, 83.39236199855804, 82.2417913377285, 87.02272519469261, 89.44703310728073, 89.42380115389824, 88.2324206829071, 66.6940288245678, 31.04259006679058, 3.219031230546534, 0.24213767261244357, 1.0051515139639378, 0.6354925653431565, 0.5066984763834625, 0.3845475590787828, 0.007130732064979384, 0.2539794996846467, 0.1482479169499129, 0.08949575902079232, 0.6517609173897654, 13.718514069914818, 105.43222054839134, 88.6744737625122, 98.82078051567078, 96.40536412596703, 87.3792752623558, 27.360578142106533, 27.489102445542812, 34.62056927382946, 63.226711079478264, 87.01512560248375, 77.15523228049278, 74.00759518146515, 10.863792803138494, 0.694284257479012, 0.02403576425422216, 0.03747648726857733, 0.08526127960067242, 0.052541869881679304, 0.017265145434066653, 0.03861297511321027, 0.027719777899619658, 0.028862104591098614, 0.038018080667825416, 0.06191462729475461, 0.026696285749494564, 0.07519992417655885, 0.0671313020575326, 0.017239589578821324, 0.0070314257482095854, 0.10470011620782316, 0.07417185668600723, 0.04186753758403938, 0.05858436576090753, 0.07245095723192208, 0.00806625374025316, 0.027992350187560078, 0.014344903793244157, 0.002279502878081985, 0.04900227446341887, 0.018812139278452378, 0.04540617563179694, 0.08164734696038067, 0.03941020127967931, 0.04419918746862095, 0.13546293892432004, 0.22469556948635727, 0.1070573776087258, 0.19501960719935596, 0.08104930209810846, 0.21885250724153593, 0.06735924529493786, 0.08848087207297795, 0.1288251849473454, 0.18320921750273556, 0.20612031075870618, 0.15489873272599652, 0.13467406562995166, 0.21701322781154886, 0.16114438039949164, 0.1716597520862706, 0.11032258247723803, 0.23530866717919707, 0.13990213978104293, 0.13367372477659956, 0.11051263907575049, 0.18658205604879186, 0.12700503808446229, 0.12458777404390275, 0.2176114433677867, 0.2549007721245289, 0.24154962447937578, 0.35961347515694797, 0.2827993204118684, 1.2427630950696766, 80.67826643586159, 139.53035205602646, 105.06492465734482, 97.98496216535568, 82.4807757139206, 48.9656051248312, 113.91619250178337, 146.48729234933853, 99.30851474404335, 118.48105475306511, 135.79556286334991, 34.1421065479517, 1.6070541786029935, 0.28240274637937546, 0.6445043161511421, 0.18423663190333173, 0.5179141683038324, 0.4148951353272423, 0.7572317391168326, 1.5858736401423812, 27.782420106232166, 81.29914551973343, 104.89847838878632, 106.72417402267456, 94.96961876749992, 97.4389086663723, 92.08123415708542, 83.93283739686012, 80.17333433032036, 85.26890650391579, 85.0628587603569, 88.48039537668228, 95.49587532877922, 105.33552333712578, 105.89559808373451, 111.21035769581795, 103.10052886605263, 105.63443809747696, 111.9860328733921, 105.20693823695183, 106.32446587085724, 117.47675344347954, 118.28768312931061, 109.70483288168907, 99.01659160852432, 82.58343860507011, 95.5964483320713, 98.6698830127716, 107.69741579890251, 102.69382148981094, 100.34997805953026, 88.18823665380478, 100.07022947072983, 93.97111594676971, 98.26929330825806, 103.36215242743492, 93.03900316357613, 102.7057072520256, 100.89126661419868, 103.59959408640862, 106.48875385522842, 99.48620080947876, 106.2555755674839, 112.98683077096939, 116.10069528222084, 114.61572736501694, 105.75232297182083, 97.90800869464874, 107.51640871167183, 102.60895684361458, 108.18282455205917, 110.77192962169647, 105.66769391298294, 104.71407428383827, 96.43919751048088, 89.58464652299881, 87.62009114027023, 89.39073532819748, 90.68086490035057, 97.17186659574509, 96.49457573890686, 94.26010563969612, 85.93919813632965, 88.88423770666122, 92.2222825884819, 96.89196601510048, 91.72806590795517, 92.49716743826866, 67.43972361087799, 30.824244283139706, 3.5792910866439342, 1.203750588465482, 3.3969502709805965, 1.1775055155158043, 0.43253055308014154, 0.30656870745588094, 0.24631381180370227, 0.6741475942544639, 0.5184376495890319, 0.17912028066348284, 0.9391057735774666, 28.4733085334301, 123.04464787244797, 92.8889112174511, 101.88431292772293, 99.34326007962227, 133.21446776390076, 93.16551357507706, 33.04496482014656, 26.80613849312067, 60.24775452911854, 81.86632588505745, 88.16310480237007, 85.83045557141304, 12.975003216415644, 1.0696880822069943, 0.15878571633948013, 0.2311051872675307, 0.23751477536279708, 0.23018522100755945, 0.13206497125793248, 0.1797697934671305, 0.16759129852289334, 0.20673071237979457, 0.22511667892104015, 0.15069589106133208, 0.1331569376634434, 0.11627885192865506, 0.17761811439413577, 0.10403988679172471, 0.1381724904058501, 0.15461061615496874, 0.21052633761428297, 0.11828416463686153, 0.17249134340090677, 0.12939510983414948, 0.18182039202656597, 0.16795661329524592, 0.1812319876626134, 0.13526505266781896, 0.19912795862182975, 0.13074482412775978, 0.17064735875464976, 0.1754984664148651, 0.09851283102761954, 0.24549363472033292], [0.11295459436951205, 0.07949742677737959, 0.022018955678504426, 0.04241794398694765, 0.08985279142507352, 0.10438053999678232, 0.031690867253928445, 0.03027276776265353, 0.042095035532838665, 0.003846250838250853, 0.10402223109849729, 0.05921345466049388, 0.09281879945774563, 0.036124821126577444, 0.09983402458601631, 0.1851594034815207, 0.06806516132201068, 0.00825976874693879, 0.07249098125612363, 0.018885400386352558, 0.077394491963787, 0.05552276168600656, 0.01450493680749787, 0.01607677218999015, 0.03573256268282421, 0.16188906622119248, 0.11488230069517158, 0.1976648738491349, 1.8588110944256186, 54.57992546260357, 95.55959790945053, 79.55054774880409, 67.09787875413895, 47.8052993863821, 28.866916112601757, 88.36279928684235, 82.6897644996643, 79.97551694512367, 121.79991826415062, 106.40537112951279, 19.833022467792034, 0.3579578030621633, 0.041186706148437224, 0.25600208959076554, 0.11260991872404702, 0.04994673530745786, 0.2504048711853102, 0.10394412747700699, 0.7572164805606008, 31.15270435810089, 87.00010880827904, 95.35390734672546, 94.565958827734, 94.87002611160278, 90.95321148633957, 84.15245801210403, 87.42671951651573, 88.2753735780716, 85.80146312713623, 88.73214706778526, 86.59174472093582, 85.3340882062912, 86.99770733714104, 98.90536397695541, 107.92363286018372, 106.28510758280754, 103.95694971084595, 97.05921024084091, 106.13642916083336, 101.95824176073074, 102.03635036945343, 103.81491333246231, 101.60031616687775, 93.9247964322567, 80.68809270858765, 82.25278034806252, 94.32056039571762, 92.13639959692955, 92.59397864341736, 87.41808637976646, 76.3930843770504, 74.82267424464226, 92.82035529613495, 105.32120570540428, 101.0145016014576, 99.82523381710052, 94.91581365466118, 87.87000373005867, 90.94473794102669, 91.64263129234314, 96.93162828683853, 95.09937420487404, 100.64912840723991, 96.44303530454636, 96.97223290801048, 91.32587268948555, 99.22421246767044, 80.96411749720573, 79.39164027571678, 99.74713280797005, 99.87844616174698, 98.69050830602646, 96.84234067797661, 91.89863875508308, 89.5075486600399, 79.81103137135506, 76.15335524082184, 81.65274694561958, 96.85851261019707, 102.68998369574547, 100.17652496695518, 101.3961911201477, 97.9920069873333, 92.76480987668037, 88.84566977620125, 90.71336835622787, 89.89399552345276, 93.38305950164795, 84.24569740891457, 49.14213605225086, 8.973457887768745, 0.481677976786159, 1.09706703806296, 1.2006000825203955, 0.1546205609338358, 0.07475621634512208, 0.2868194453185424, 0.032634333620080724, 0.13920355617301539, 0.06544757678057067, 0.051090533306705765, 0.33518132055178285, 11.290019731968641, 88.14928874373436, 82.64650762081146, 81.12085148692131, 40.82966409623623, 91.7856328189373, 80.17501384019852, 45.17026998102665, 32.61485829949379, 38.58227089047432, 62.51573882997036, 70.85323244333267, 63.26044946908951, 16.98213044553995, 1.728264824487269, 0.2889690612209961, 0.06400647442205809, 0.055760705363354646, 0.059814753840328194, 0.04405306972330436, 0.04777262482093647, 0.042164875339949504, 0.009253427488147281, 0.041984411000157706, 0.1358422654448077, 0.02578771145635983, 0.015302557239920134, 0.0461360073677497, 0.0113048090133816, 0.0508226179954363, 0.06569273784407414, 0.019193421358068008, 0.05324696212483104, 0.006797140858907369, 0.06183646430145018, 0.07332350025535561, 0.10695145087083802, 0.04064291970280465, 0.054078371613286436, 0.0618679536273703, 0.05911358384764753, 0.01359846650302643, 0.10123108047991991, 0.0831236939120572, 0.029678763894480653, 0.016760247526690364, 0.0532075540832011, 0.06735440649208613, 0.08974674594355747, 0.020094973078812473, 0.02165233472624095, 0.07459280284820125, 0.039548715722048655, 0.01127761765019386, 0.009078706443688134, 0.03266543702920899, 0.019284881782368757, 0.08038180705625564, 0.0947065262880642, 0.17236166051588953, 0.038761501127737574, 0.05316112903528847, 0.10922853805823252, 0.033483940569567494, 0.09280698446673341, 0.04583210531563964, 0.03196540994395036, 0.11070685912272893, 0.02335883651539916, 0.0615690833365079, 0.07278286793734878, 0.31917812302708626, 6.402114015072584, 89.67927664518356, 106.52908489108086, 101.18165463209152, 102.23669081926346, 79.32601019740105, 25.636004582047462, 29.627259112894535, 66.20266199111938, 86.94688886404037, 128.20045441389084, 110.68144887685776, 20.75789663940668, 0.3662779909791425, 0.09052609006175771, 0.3167680132901296, 0.04698130243923515, 0.12818923860322684, 0.373344513354823, 0.11475193503429182, 2.0131324511021376, 42.26337656378746, 95.54843410849571, 99.99459072947502, 100.56947708129883, 97.23798304796219, 97.96005830168724, 89.62297886610031, 93.67179840803146, 93.66473078727722, 94.12746995687485, 93.29967677593231, 91.84461325407028, 88.97183060646057, 92.0508585870266, 103.67258056998253, 111.87251016497612, 107.94199347496033, 109.0123200416565, 100.70240154862404, 108.35737198591232, 105.50046488642693, 105.56161880493164, 105.32287001609802, 103.42622458934784, 96.55002236366272, 82.09976255893707, 87.43757173418999, 99.94152277708054, 98.13545688986778, 96.34172514081001, 92.79584661126137, 85.84215894341469, 84.1920518875122, 96.26923263072968, 112.2576878964901, 110.14859586954117, 109.39685940742493, 98.89683723449707, 95.26868551969528, 97.49220460653305, 95.81964835524559, 99.78552594780922, 99.506476521492, 102.41786509752274, 98.78999456763268, 99.53777924180031, 95.23184269666672, 99.50601294636726, 90.33945322036743, 87.72198647260666, 100.4348275065422, 101.86999529600143, 104.03176009654999, 100.21638482809067, 97.15260922908783, 94.63738739490509, 84.90012869238853, 82.77603507041931, 85.40341168642044, 98.43144580721855, 103.04587259888649, 100.81274002790451, 103.22865039110184, 101.90626814961433, 96.5704196691513, 94.26607891917229, 93.60019505023956, 92.25199699401855, 98.04961949586868, 89.33756858110428, 55.63898183405399, 11.476305685937405, 0.5279556044843048, 1.196244447492063, 0.8065076731145382, 0.3978916414780542, 0.41610804211813956, 0.4482577013550326, 0.12188919892651029, 0.02028465303737903, 0.1177944362279959, 0.10711176219047047, 0.4185039026197046, 8.447068333625793, 92.37014785408974, 96.70553281903267, 89.54169362783432, 47.20230974256992, 77.20797345042229, 31.783309020102024, 22.163749001920223, 46.71506188809872, 66.67053088545799, 83.23904022574425, 79.9003417789936, 83.29058825969696, 30.069988556206226, 3.26688586268574, 0.2554686041548848, 0.02922671988926595, 0.04263326329237316, 0.026918340045085642, 0.016132253294927068, 0.06943236803635955, 0.08449384695268236, 0.01653157698456198, 0.035090189339825884, 0.016588284488534555, 0.01106917712604627, 0.0766717514488846, 0.028594987088581547, 0.032021471779444255, 0.02526574971852824, 0.04413937407662161, 0.06100758553657215, 0.0034345662152190926, 0.013829885774612194, 0.030904240811651107, 0.025929370749508962, 0.05266583451884799, 0.037041046962258406, 0.01720620035484899, 0.05280157332890667, 0.057304446745547466, 0.06491714157164097, 0.10601694593788125, 0.08787240745732561, 0.17870501935249195, 0.10659239240339957, 0.09260478633223101, 0.18845076905563474, 0.15333477524109185, 0.17240105371456593, 0.1191530488722492, 0.226470475026872, 0.1027661981061101, 0.08038448620936833, 0.1811478874878958, 0.19870048156008124, 0.14166055480018258, 0.20501557941315696, 0.14005249890033156, 0.2591450256295502, 0.1321924722287804, 0.11340831377310678, 0.16373527731047943, 0.17392775538610294, 0.303539676242508, 0.11005913489498198, 0.1455339719541371, 0.2857886615674943, 0.11936552575207315, 0.16556802584091201, 0.18340676237130538, 0.4208583809668198, 6.957629956305027, 103.08497250080109, 124.90488365292549, 100.17809808254242, 91.40825226902962, 57.69374057650566, 39.02506113052368, 113.90850931406021, 115.8906577527523, 98.04868474602699, 144.6295264363289, 128.34892004728317, 32.18727104365826, 1.0705900588072836, 0.15179795067524537, 0.3594621067168191, 0.21985632134601474, 0.26015494018793106, 0.46282205265015364, 0.7370807079132646, 2.4342310801148415, 36.52135267853737, 99.72482040524483, 108.94734352827072, 109.21893015503883, 105.69103986024857, 104.880710542202, 91.67720183730125, 96.42035812139511, 95.26220306754112, 95.64415857195854, 99.11366879940033, 92.40145057439804, 96.004538834095, 97.26788744330406, 108.57071533799171, 115.03840148448944, 114.89498198032379, 112.49123096466064, 105.71758523583412, 113.03617492318153, 109.94107380509377, 109.61460292339325, 108.26710402965546, 111.51487335562706, 103.16064164042473, 89.73596200346947, 89.89974841475487, 106.13934740424156, 101.90935358405113, 104.27321434020996, 98.38581785559654, 92.27607250213623, 86.89559161663055, 103.39116767048836, 114.81886446475983, 115.44200822710991, 105.75366050004959, 102.56503880023956, 101.37813448905945, 99.4227822124958, 103.2821287214756, 105.67104533314705, 109.88875061273575, 109.63542580604553, 104.37305778265, 103.17109107971191, 102.53018707036972, 104.65637817978859, 92.40905776619911, 99.4494491815567, 110.51357388496399, 107.03476175665855, 107.63113975524902, 104.44274604320526, 97.20212817192078, 97.65450909733772, 88.11892077326775, 84.79954808950424, 88.57710778713226, 101.78006932139397, 107.6982669532299, 107.53654763102531, 107.31134131550789, 107.27088868618011, 100.07482722401619, 95.61286345124245, 98.92307862639427, 98.48598048090935, 103.64707633852959, 95.07412075996399, 57.76935651898384, 12.560404613614082, 1.5334378788247705, 4.844507295638323, 3.880103132687509, 0.4889747133711353, 0.2845011540921405, 0.505887873005122, 0.17248037445824593, 0.27588556171394885, 0.2698329614941031, 0.2310654378379695, 0.716634183190763, 19.80315987020731, 110.95017805695534, 101.11685290932655, 99.61583465337753, 53.95598754286766, 123.75004962086678, 100.28644546866417, 58.58231149613857, 40.93350112438202, 52.26478569209576, 83.41923415660858, 87.43255600333214, 101.05869323015213, 39.30837772786617, 4.6822374779731035, 0.27599765569902956, 0.14015028427820653, 0.1963515841634944, 0.22880408418131992, 0.18486046639736742, 0.1425556739559397, 0.16695495141902938, 0.14029087673407048, 0.1969528425252065, 0.16526499210158363, 0.11173031045473181, 0.13804055139189586, 0.10392165524535812, 0.11457460626843385, 0.08718662589672022, 0.1437868078937754, 0.1319351844722405, 0.1748767396202311, 0.11308098954032175, 0.21899200131883845, 0.12939374428242445, 0.19400399294681847, 0.16807660373160616, 0.1181740225001704, 0.11707710596965626, 0.13317148375790566, 0.1420691961538978, 0.17072420072508976, 0.1470211468404159], [0.13193613442126662, 0.07687855832045898, 0.14876436267513782, 0.02704095582885202, 0.048047460659290664, 0.021449926935019903, 0.043628346029436216, 0.026638836097845342, 0.060458566949819215, 0.06852291800896637, 0.04424171624123119, 0.055255807455978356, 0.10730500260251574, 0.08427447552094236, 0.07352052562055178, 0.08703977713594213, 0.10870011406950653, 0.14556184702087194, 0.01485199845774332, 0.050073724196408875, 0.021063319945824333, 0.0072520987214375054, 0.08061585816903971, 0.09095668414374813, 0.06519520946312696, 0.09081488940864801, 0.03687001903017517, 13.504904732108116, 86.223856061697, 98.64493355154991, 102.43184834718704, 54.93396006524563, 36.21478132903576, 45.09532280266285, 95.9235879778862, 95.97554638981819, 99.38100725412369, 126.00592017173767, 90.47398880124092, 10.728480163961649, 0.14377825835254043, 0.066490272001829, 0.1584164533414878, 0.023353804754151497, 0.34260680491570383, 0.03174111065163743, 0.29731789603829384, 0.607161819934845, 33.18873390555382, 111.82248964905739, 101.49558618664742, 102.72306472063065, 91.68374508619308, 94.78078410029411, 99.00926560163498, 105.28296455740929, 99.46198850870132, 97.66578689217567, 97.77506902813911, 89.4563502073288, 94.20934036374092, 93.58397752046585, 96.84563130140305, 100.91509133577347, 100.08148446679115, 96.84424057602882, 97.12775856256485, 102.06056267023087, 102.93512374162674, 107.52253398299217, 98.59075605869293, 104.31527808308601, 98.00416633486748, 91.34820029139519, 72.4311737716198, 89.0975734591484, 98.16364377737045, 96.2486681342125, 89.95163083076477, 88.34253117442131, 85.78380167484283, 80.81220164895058, 86.17176845669746, 113.17106768488884, 103.2465398311615, 98.08861300349236, 98.02514120936394, 91.00452393293381, 86.77057072520256, 91.35197728872299, 88.42284366488457, 93.80250379443169, 94.0957872569561, 94.46802288293839, 88.37909281253815, 84.23694267868996, 75.6032283604145, 78.434669226408, 72.2234009206295, 78.82670179009438, 85.14175772666931, 91.85336038470268, 95.29966905713081, 95.60252040624619, 95.38585603237152, 88.87017086148262, 80.78055694699287, 80.96270397305489, 85.74925392866135, 95.90690687298775, 102.22662135958672, 98.47169324755669, 99.5576673746109, 100.65384775400162, 99.31698828935623, 98.02112102508545, 96.36927366256714, 97.98955231904984, 94.97732475399971, 79.41882401704788, 32.369269877672195, 3.020035196095705, 0.5637980124447495, 0.5259084049612284, 0.8166432136204094, 0.3470538428518921, 0.016844353267515544, 0.12829529150621966, 0.2083864586893469, 0.13639117270940915, 0.22651859588222578, 0.004149549895373639, 0.1938489286112599, 8.34651717916131, 76.45179122686386, 88.16737577319145, 79.45147186517715, 36.53204530477524, 66.66828140616417, 67.67343387007713, 29.570267871022224, 28.453735783696175, 44.45449098944664, 58.177500218153, 72.23988443613052, 77.24278718233109, 62.260460928082466, 13.32021089270711, 0.5079985409975052, 0.01625324563065078, 0.05322909120877739, 0.10450754372868687, 0.05680677364580333, 0.0675638702523429, 0.02799045771098463, 0.0464971772453282, 0.03922186646377668, 0.02540854264225345, 0.02035070789133897, 0.04063834436237812, 0.07381762217846699, 0.0745336982072331, 0.02011149514146382, 0.04545234092802275, 0.011206364979443606, 0.08970291470177472, 0.008042210010898998, 0.02240716385131236, 0.051143904856871814, 0.07034149894025177, 0.012664232453971636, 0.11470991463284008, 0.08761537945247255, 0.010573027284408454, 0.09872199050732888, 0.04081308674358297, 0.12686566275078803, 0.10840554823516868, 0.15011697134468704, 0.07084069715347141, 0.08536243432899937, 0.022541457328770775, 0.052858236304018646, 0.02066810404357966, 0.0140878099227848, 0.1515628382912837, 0.032773616185295396, 0.12675720528932288, 0.15232811128953472, 0.038136315924930386, 0.02453400880767731, 0.03383262381248642, 0.11322376391035505, 0.12919805478304625, 0.02457879927533213, 0.06588094649487175, 0.05607195467746351, 0.007629602805536706, 0.045265887456480414, 0.08995966811198741, 0.1113575445197057, 0.06373199852532707, 0.0717880115553271, 25.400250032544136, 114.95197132229805, 105.72658315300941, 118.78874704241753, 88.4448292851448, 65.89151948690414, 24.754651375114918, 49.55768555402756, 88.19266721606255, 109.03567358851433, 131.46206259727478, 98.42123955488205, 10.37103334441781, 0.4887624888215214, 0.04369162896182388, 0.17923093488207087, 0.03440433727519121, 0.20372062077512965, 0.25901559507474303, 0.5994481150992215, 1.6008576611056924, 42.57218599319458, 117.9591603577137, 102.88156181573868, 104.74716290831566, 93.77837508916855, 101.54627546668053, 103.80647778511047, 109.15394604206085, 105.13983383774757, 102.37001806497574, 100.98789542913437, 97.06714421510696, 97.68186762928963, 97.75254383683205, 102.62699067592621, 102.79724434018135, 101.88211664557457, 101.65038228034973, 99.95410770177841, 103.41663390398026, 105.92015236616135, 106.89733073115349, 98.70744779706001, 101.7745216190815, 101.94564163684845, 95.61622247099876, 75.13078451156616, 93.68686839938164, 102.97610074281693, 98.05995494127274, 92.97591894865036, 92.04706639051437, 92.00955480337143, 86.90340399742126, 92.94622734189034, 114.25532430410385, 111.16571009159088, 100.40699020028114, 97.99984976649284, 99.99818533658981, 90.43119549751282, 99.05755341053009, 92.49656707048416, 98.07551890611649, 95.80527752637863, 96.94162175059319, 93.13791185617447, 87.74462565779686, 79.72821101546288, 82.57186442613602, 80.91585248708725, 86.12557053565979, 87.071423381567, 94.1839349269867, 96.60001248121262, 101.35852754116058, 99.18366104364395, 93.1134107708931, 82.66117483377457, 85.70137649774551, 88.02865281701088, 97.30925962328911, 101.81975439190865, 99.47936117649078, 100.22074699401855, 104.80175837874413, 103.80267798900604, 104.95856836438179, 100.91028079390526, 100.28496354818344, 98.34546402096748, 86.31084099411964, 40.396012365818024, 5.532395308837295, 0.1348808576585725, 0.2946904260898009, 0.7454314723145217, 0.4367910447763279, 0.010976888279401464, 0.3710030671209097, 0.1783975475700572, 0.09093950342503376, 0.13757138047367334, 0.03260940116888378, 0.115415763866622, 6.355182733386755, 76.71767815947533, 95.8898001909256, 82.58498892188072, 43.270691111683846, 62.051620334386826, 42.517016753554344, 20.461183860898018, 40.11239938437939, 64.19772237539291, 83.05765315890312, 82.34534338116646, 89.97059941291809, 81.69096529483795, 23.202987536787987, 0.5299309641122818, 0.06000188637699466, 0.03041540112462826, 0.10703383668442257, 0.03932312138203997, 0.06388088819221593, 0.00743695240089437, 0.052420079737203196, 0.05982967100862879, 0.10874205283471383, 0.09050416701938957, 0.024712300510145724, 0.01396474977809703, 0.03267965657869354, 0.05023740857723169, 0.03645817159849685, 0.049072867550421506, 0.02208866375440266, 0.013697735248570098, 0.03827448897936847, 0.05134537197591271, 0.054964113733149134, 0.02674496321560582, 0.040424694889225066, 0.019392073882045224, 0.005590226446656743, 0.0658382878464181, 0.0867176553583704, 0.1741384362685494, 0.10169441069592722, 0.2521104452898726, 0.28473923506680876, 0.0882209422707092, 0.07654776083654724, 0.1408496397198178, 0.05502821673871949, 0.12420299273799174, 0.17798037151806056, 0.09138956404058263, 0.16152106487425044, 0.2791524661006406, 0.18243552854983136, 0.17233633843716234, 0.20553116424707696, 0.4011075454764068, 0.1789142010966316, 0.07699055582634173, 0.2745756710646674, 0.15748931793496013, 0.22639271279331297, 0.19611816387623549, 0.18335464876145124, 0.17534663784317672, 0.20514870586339384, 0.14176062599290162, 23.509606383740902, 136.3783299922943, 119.68666926026344, 126.0828660428524, 73.46939206123352, 45.99002659320831, 62.438249588012695, 128.10564190149307, 130.12302964925766, 115.82147866487503, 150.56295365095139, 111.27734050154686, 18.559725992381573, 1.0658486257307231, 0.15247199888108298, 0.5059298488777131, 0.16878824913874269, 0.5351976002566516, 0.2834205573890358, 1.4195199916139245, 3.0423115007579327, 35.547233149409294, 125.98341017961502, 110.31971588730812, 112.09635615348816, 103.40781077742577, 107.8843429684639, 108.81437346339226, 117.9457850754261, 112.9199467599392, 109.22006249427795, 103.86833846569061, 100.03412380814552, 103.46312820911407, 102.32732355594635, 106.10651716589928, 106.28422603011131, 106.72953173518181, 105.93890056014061, 105.44990479946136, 110.16704007983208, 111.96403965353966, 114.32554453611374, 104.619679749012, 107.52163723111153, 108.91468808054924, 102.79795870184898, 78.79032254219055, 98.8173758983612, 105.3825344145298, 105.13292580842972, 98.7524525821209, 98.38256523013115, 98.78459885716438, 92.13062390685081, 99.17871370911598, 121.22600466012955, 117.05980181694031, 109.21988010406494, 98.34056228399277, 103.24623584747314, 95.82175344228745, 102.18984693288803, 99.02407720685005, 102.35808670520782, 100.41111677885056, 104.44081574678421, 102.33091816306114, 96.1801578104496, 90.0840537250042, 88.36304247379303, 81.64755642414093, 93.47721844911575, 93.54815304279327, 97.48138278722763, 101.51688784360886, 103.59653905034065, 101.22187167406082, 95.23968547582626, 85.85473626852036, 89.13541942834854, 91.6371975839138, 102.48602584004402, 110.30831649899483, 104.61793184280396, 104.69176948070526, 107.61613816022873, 106.43138453364372, 109.3310621380806, 102.27929413318634, 105.82388833165169, 105.52678227424622, 91.14147618412971, 39.96074192225933, 5.538650248199701, 1.794103179126978, 4.498128332197666, 4.850868629291654, 1.504439259879291, 0.10904483424383216, 0.35757809062488377, 0.38693418726325035, 0.22975927277002484, 0.6230066134594381, 0.1987012682366185, 0.6635103025473654, 15.473053772002459, 91.80197954177856, 101.96973234415054, 96.4850002527237, 50.741025656461716, 97.64242574572563, 78.41386154294014, 38.253888711333275, 35.786798894405365, 59.123896434903145, 79.91995632648468, 88.32103192806244, 102.01490432024002, 95.26339620351791, 27.515378035604954, 0.6904668279457837, 0.07630780222825706, 0.2088606613688171, 0.24859661352820694, 0.13300779566634446, 0.26128336088731885, 0.13965858175652102, 0.12815311085432768, 0.08484230755129829, 0.17767759010894224, 0.09062976809218526, 0.20156904560280964, 0.10989713147864677, 0.1721799382357858, 0.10041677378467284, 0.17374983290210366, 0.1058424447546713, 0.19748858409002423, 0.15170362370554358, 0.15536266408162192, 0.09237687278073281, 0.15951183362631127, 0.06281152018345892, 0.24356930516660213, 0.0930067038279958, 0.11951064530876465, 0.24327979335794225, 0.1494389897561632], [0.02390470282989554, 0.0820803307578899, 0.04090090878889896, 0.015536799455730943, 0.07367675512796268, 0.04029718278616201, 0.028356108305160888, 0.09289944122429006, 0.041991958642029203, 0.06815297223511152, 0.07768188865156844, 0.04600337444571778, 0.05937242640356999, 0.07436728643369861, 0.05729632393922657, 0.031761282225488685, 0.10666216170648113, 0.08396523000556044, 0.01288781928451499, 0.03707573123392649, 0.1307220253511332, 0.1004591207311023, 0.09361769916722551, 0.11752990511013195, 0.21325681766029447, 6.570777464658022, 40.54020322859287, 90.00225931406021, 99.76585820317268, 61.22620202600956, 52.9693590849638, 47.28401675820351, 45.183926448225975, 111.67566552758217, 94.6205846965313, 95.48978805541992, 118.47567424178123, 85.54719597101212, 7.78146754950285, 0.8797640015836805, 0.019721396347449627, 0.06117905875726137, 0.15083014557603747, 0.22200541774509475, 0.29511395492590964, 0.3700343269156292, 2.0609640469774604, 10.267134569585323, 107.57115617394447, 97.13313907384872, 99.85082924365997, 91.01382583379745, 101.59929022192955, 98.81647154688835, 99.67289999127388, 99.2294029891491, 96.57155960798264, 99.65631768107414, 106.45694196224213, 104.17682111263275, 101.54898092150688, 97.56705299019814, 106.80413693189621, 96.84525892138481, 92.87524715065956, 88.40157240629196, 90.00287488102913, 90.04952117800713, 91.75402611494064, 93.32094803452492, 98.55120778083801, 99.83556926250458, 100.39616078138351, 83.95165398716927, 77.20744147896767, 79.76034209132195, 93.04642036557198, 96.01235121488571, 94.35217469930649, 82.57371112704277, 78.54574486613274, 69.72669929265976, 79.95885863900185, 96.35171860456467, 109.18106138706207, 57.26517677307129, 76.16521820425987, 100.91213509440422, 80.47971948981285, 88.89743059873581, 88.95001977682114, 89.82278734445572, 90.96643477678299, 84.51419100165367, 73.15949589014053, 67.79229149222374, 74.1052271425724, 79.15638729929924, 74.4366529583931, 74.77326169610023, 81.08120441436768, 85.94581738114357, 90.39247557520866, 95.83583548665047, 94.31695818901062, 91.68158680200577, 86.44674450159073, 77.3589925467968, 77.588811814785, 87.23861441016197, 97.9122568666935, 100.53822755813599, 97.00625628232956, 99.50017645955086, 97.68355473876, 98.07969868183136, 97.6536275446415, 99.517283141613, 91.12154245376587, 91.09680578112602, 82.97724947333336, 42.47671231627464, 6.6847979463636875, 0.36659147415775806, 1.8188609881326556, 1.3050383096560836, 1.227643706370145, 0.045762914887745865, 0.04909605224383995, 0.20132523524807766, 0.03880304655467626, 0.10062133937026374, 0.055049482980393805, 0.12735239288304, 4.467989299446344, 62.65221610665321, 99.54199701547623, 92.86958545446396, 53.01177620887756, 66.0920575261116, 84.05439287424088, 47.955957502126694, 31.299044005572796, 40.21045312285423, 58.95601384341717, 68.75098004937172, 69.6028183400631, 80.56299582123756, 25.580447763204575, 0.6378201779443771, 0.05751920944021549, 0.08201888093026355, 0.032485837291460484, 0.05503559368662536, 0.10899764107307419, 0.00913626370675047, 0.05215427212533541, 0.06738722426234744, 0.07016690869932063, 0.02551859201048501, 0.008845201737130992, 0.017447452155465726, 0.021799228015879635, 0.015018650501588127, 0.06889781390782446, 0.0639812636654824, 0.014710233408550266, 0.058001779834739864, 0.05603546327620279, 0.018707190320128575, 0.03425214505114127, 0.00809108785688295, 0.02568088300904492, 0.04013326091808267, 0.08554542568163015, 0.05695028645277489, 0.05338003291399218, 0.1250261309905909, 0.03344462900713552, 0.006911233076607459, 0.028660307216341607, 0.0722478685202077, 0.02141887176549062, 0.06222648145921994, 0.023466462771466468, 0.053532069287030026, 0.02435505659377668, 0.011764765240513952, 0.015573173041047994, 0.0693885590590071, 0.05559568511671387, 0.08583858885685913, 0.013568939230026444, 0.03564635851944331, 0.0702781492145732, 0.03835523464658763, 0.17238958011148497, 0.1865998379071243, 0.04858958469412755, 0.09758392188814469, 1.3647977029904723, 13.123309258371592, 61.31081588566303, 114.25131171941757, 111.58813342452049, 100.81433594226837, 93.56268346309662, 66.93126529455185, 21.440393216907978, 70.18009096384048, 90.76651990413666, 104.21444669365883, 121.64431661367416, 96.03334128856659, 8.784625120460987, 0.7858684274833649, 0.043561511920415796, 0.27383067354094237, 0.08720054858713411, 0.35368362616281956, 0.46159376855939627, 0.519548614975065, 2.12739042006433, 14.869577754288912, 118.7120671570301, 97.15912207961082, 104.2219626903534, 94.69951406121254, 103.81424456834793, 103.27050134539604, 103.80039051175117, 103.80870446562767, 104.87779229879379, 106.05825215578079, 108.93111079931259, 108.19437593221664, 103.74951124191284, 100.33031791448593, 107.8140239417553, 102.17339381575584, 96.9213916361332, 92.59698808193207, 90.2978378534317, 92.367282807827, 94.27228018641472, 94.84416469931602, 100.75223207473755, 100.94638645648956, 103.460833132267, 88.05494740605354, 79.70646098256111, 84.47290241718292, 98.53562101721764, 100.42104944586754, 98.473159968853, 87.23079442977905, 87.53537848591805, 78.20890814065933, 84.70725864171982, 100.60937494039536, 110.04367589950562, 64.94087889790535, 77.36664533615112, 100.52706375718117, 88.85020673274994, 90.8794878423214, 94.54554632306099, 92.98652037978172, 94.56743314862251, 90.61519682407379, 78.0136214196682, 74.9281793832779, 82.00456246733665, 85.81783264875412, 78.44170644879341, 78.74145716428757, 86.55214324593544, 87.532247453928, 90.94487473368645, 98.03036212921143, 99.23188045620918, 96.74450352787971, 90.40851071476936, 82.11077436804771, 81.70371741056442, 87.21776872873306, 97.36654534935951, 101.77636072039604, 100.30948743224144, 101.27436965703964, 99.03144121170044, 100.23663014173508, 102.4091711640358, 102.70585164427757, 97.3466420173645, 93.66514876484871, 89.51178163290024, 55.36116734147072, 13.577593881636858, 2.1547603514045477, 0.23121080972487107, 0.6752596283331513, 0.42181011114735156, 0.12297775145270862, 0.3047611622605473, 0.2923224406549707, 0.06550720092491247, 0.0029810782689310145, 0.014921854035492288, 0.2902207081206143, 2.453898824751377, 64.72528606653214, 104.06341999769211, 101.25877529382706, 52.39916928112507, 63.64618197083473, 44.43466365337372, 26.930524818599224, 51.73702821135521, 64.617979824543, 84.69028875231743, 82.85289734601974, 79.62264508008957, 94.3701097369194, 41.87944896519184, 0.49705646408256143, 0.038940362428547814, 0.05771682852355298, 0.03095516141911503, 0.06791434207116254, 0.12105522531783208, 0.09434646592126228, 0.04295616061426699, 0.022143675450934097, 0.008173613750841469, 0.014030680322321132, 0.053558771760435775, 0.01623046540771611, 0.039501674691564403, 0.02521192916901782, 0.05956440887530334, 0.0730650473269634, 0.013073132631689077, 0.05569150009250734, 0.07988124329131097, 0.13036739750532433, 0.042580251683830284, 0.013281290212034946, 0.053687898034695536, 0.07394268148345873, 0.025754554153536446, 0.06048829738574568, 0.091709155094577, 0.14707168709719554, 0.24928701866883785, 0.1486498344456777, 0.1576467274571769, 0.24608080711914226, 0.11316031770547852, 0.16292410989990458, 0.07173671430791728, 0.14768196997465566, 0.1552141158026643, 0.11637219926342368, 0.15214586950605735, 0.17667330102995038, 0.22373520070686936, 0.21536871761782095, 0.20960757363354787, 0.2524473506491631, 0.17279888939810917, 0.12824828387238085, 0.33097521343734115, 0.23646904475754127, 0.20535111922072247, 0.1713595088222064, 2.32255507260561, 16.915179938077927, 72.78882578015327, 137.0164829492569, 120.24156108498573, 93.57610434293747, 74.04684707522392, 53.96473087370396, 64.90367889404297, 144.49586480855942, 121.86461359262466, 113.06985631585121, 138.26295286417007, 108.3296486735344, 17.324727661907673, 1.5061641298234463, 0.11027660642866977, 0.4910239315358922, 0.26138441171497107, 0.5998879414983094, 0.3392995276954025, 0.6103821471333504, 5.1122200302779675, 12.584020346403122, 125.39540693163872, 103.33287879824638, 111.13850355148315, 102.88767948746681, 113.37607428431511, 110.18674582242966, 114.91439893841743, 111.64069220423698, 107.90939882397652, 110.9112985432148, 116.92682415246964, 111.00241765379906, 109.62980210781097, 106.24163031578064, 115.28503865003586, 109.20163348317146, 104.49281215667725, 96.53109937906265, 96.59419879317284, 101.03872910141945, 97.92286589741707, 102.49901354312897, 107.96459466218948, 106.55040934681892, 107.02160686254501, 93.49500149488449, 83.11393573880196, 88.17451179027557, 102.51749575138092, 105.28500124812126, 101.09643280506134, 95.96604689955711, 94.82344061136246, 85.20061656832695, 95.37800565361977, 112.4325393140316, 118.88602942228317, 81.740233451128, 85.14996528625488, 100.03049120306969, 96.61268100142479, 95.799251049757, 100.48398166894913, 98.8924902677536, 100.80256417393684, 96.49925708770752, 88.36735144257545, 87.74758189916611, 87.86161378026009, 86.93853691220284, 83.67543160915375, 77.77994155883789, 87.12873950600624, 89.30856853723526, 94.07830059528351, 101.27186179161072, 101.24433606863022, 98.63495528697968, 93.5401126742363, 83.39589580893517, 86.23923763632774, 92.94783845543861, 105.43014585971832, 106.86840668320656, 104.88137930631638, 103.83977919816971, 102.61931508779526, 102.97030225396156, 105.88816568255424, 108.78168001770973, 101.52843922376633, 101.21989578008652, 97.44153812527657, 55.26786334812641, 11.345283966511488, 2.134475139901042, 4.937585201114416, 5.9386965818703175, 3.166272724047303, 0.14640737586887553, 0.4087180027272552, 0.5434454733040184, 0.26358722476288676, 0.3924467711476609, 0.24234547396190464, 0.7460637227632105, 9.82151348143816, 80.3000195324421, 114.39871340990067, 109.2646037042141, 67.2048582136631, 81.92713782191277, 96.65373399853706, 65.25498524308205, 39.6504657715559, 51.432786136865616, 81.69362515211105, 85.20534351468086, 87.46748372912407, 111.4039421081543, 51.74800582230091, 0.6802332052029669, 0.16764111147494987, 0.22796946490416303, 0.09290760484873317, 0.19512466562446207, 0.174352323228959, 0.2058031762135215, 0.25299256201833487, 0.2698639832669869, 0.19317912549013272, 0.10960316678392701, 0.10906543626333587, 0.1154852808394935, 0.11966904188739136, 0.08749090644414537, 0.18031985848210752, 0.12724533065920696, 0.17373602895531803, 0.1029558465234004, 0.23542295792140067, 0.22294659458566457, 0.1704895484726876, 0.15537988190772012, 0.12007853671093471, 0.2694534865440801, 0.1610643620369956, 0.14606368727982044], [0.03782468440476805, 0.037772221985505894, 0.015433017524628667, 0.02856654056813568, 0.05294661124935374, 0.03409737386391498, 0.06898986248415895, 0.02892353957577143, 0.012638024436455453, 0.021041955369582865, 0.03723834321135655, 0.10271622930304147, 0.03685865674924571, 0.017558939434820786, 0.039155050908448175, 0.002781391144708323, 0.05068638194643427, 0.04757299451739527, 0.057722999481484294, 0.05973594888928346, 0.06558555687661283, 0.14421907922951505, 0.6303532817400992, 19.918441884219646, 63.69817838072777, 92.84874737262726, 113.17210122942924, 84.7965158522129, 76.20763152837753, 50.55013529956341, 40.430510714650154, 50.632720068097115, 138.787522315979, 80.90151965618134, 95.37264794111252, 121.42671748995781, 96.67419970035553, 11.94283040240407, 0.6616263161413372, 0.09451397607335821, 0.16170752205653116, 0.1319044892443344, 0.1371985996956937, 0.06877950072521344, 0.13132525782566518, 0.47578606638126075, 0.8310287666972727, 46.31456337869167, 104.79304924607277, 91.16606086492538, 98.21548819541931, 84.18508306145668, 87.90778890252113, 91.95286944508553, 93.80763351917267, 93.43013137578964, 92.8024810552597, 94.19821456074715, 97.43620321154594, 97.56842091679573, 101.23844638466835, 98.82622942328453, 94.92025941610336, 90.79284489154816, 79.704819470644, 72.13428810238838, 74.85002517700195, 74.1450110077858, 78.387840539217, 86.24369859695435, 94.28774535655975, 100.12863993644714, 102.19331994652748, 89.99076873064041, 73.90368595719337, 73.92030626535416, 86.10473245382309, 88.90995472669601, 95.28502464294434, 82.67334938049316, 85.96231609582901, 80.2255967259407, 67.14321032166481, 71.75129145383835, 77.50277683138847, 65.00848487019539, 47.15091750025749, 74.69945445656776, 92.21600532531738, 84.7430071234703, 88.79487410187721, 86.47548615932465, 81.70085996389389, 69.96475651860237, 68.96331265568733, 69.79399368166924, 78.6218623816967, 93.68302300572395, 76.84527531266212, 89.889055788517, 92.58532270789146, 92.51568004488945, 94.89948213100433, 96.88566595315933, 92.83335819840431, 89.75594893097878, 92.24939793348312, 85.71070119738579, 76.38997614383698, 74.20538976788521, 78.226797580719, 86.1740255355835, 88.09682115912437, 91.35443195700645, 90.03611549735069, 95.46881318092346, 90.01141682267189, 91.85360357165337, 93.67970198392868, 90.04322111606598, 88.19720417261124, 88.27475041151047, 71.58736065030098, 46.69891655445099, 15.146316904574633, 0.9227473544888198, 1.025247685611248, 0.9730624733492732, 0.1538969372631982, 0.08946899717557244, 0.1831347355619073, 0.10299499481334351, 0.12790685141226277, 0.05246128377621062, 0.35166400484740734, 2.9527156334370375, 54.220251962542534, 85.92377096414566, 92.70500868558884, 41.846987307071686, 49.86664317548275, 68.61585170030594, 26.71974252909422, 24.67601839452982, 34.276767522096634, 35.508714616298676, 59.2668941617012, 70.92291310429573, 83.24424594640732, 21.048641838133335, 0.2436203500838019, 0.09392619511345401, 0.04077722245710902, 0.06965021064388566, 0.04393326482386328, 0.06356017649522983, 0.04380270991532598, 0.032757147928350605, 0.05617895752948243, 0.04341472995292861, 0.06093686999520287, 0.014181558944983408, 0.026181528410234023, 0.04564219714666251, 0.06728914944687858, 0.038328164810081944, 0.028395052504492924, 0.023804603806638625, 0.031714508368168026, 0.038334224445861764, 0.027660832820401993, 0.025950269628083333, 0.012064590118825436, 0.03098245018918533, 0.0316256324731512, 0.06022410023433622, 0.031022713556012604, 0.045161745583754964, 0.035702698660315946, 0.04054418808664195, 0.0297771077384823, 0.05829500238178298, 0.035453752643661574, 0.046298879096866585, 0.04379678015538957, 0.038405170053010806, 0.030260448111221194, 0.1421556860441342, 0.03821042308118194, 0.007445837763953023, 0.019446961268840823, 0.059920469066128135, 0.04659524835005868, 0.06013792575686239, 0.0996819139982108, 0.004106373598915525, 0.1053642641636543, 0.2585398784140125, 1.4195248601026833, 30.003300234675407, 86.41213595867157, 110.147425532341, 133.3785429596901, 100.23032248020172, 115.63676297664642, 61.22448451817036, 29.57907199859619, 33.449700102210045, 91.22454732656479, 87.2433565557003, 104.1832123696804, 126.67229801416397, 106.46851614117622, 12.167172264307737, 0.924404599936679, 0.07040522716124542, 0.13635448092827573, 0.06375145021593198, 0.2005729646771215, 0.10333584097679704, 0.1342314635985531, 0.1794715688447468, 0.7605885621160269, 55.313194915652275, 110.87231263518333, 98.34965139627457, 99.31625112891197, 85.922691822052, 90.25592610239983, 94.09153908491135, 96.43811076879501, 95.13246282935143, 96.53444319963455, 95.93095198273659, 99.16108265519142, 99.50260072946548, 104.72427293658257, 102.39555269479752, 96.14881709218025, 93.48825305700302, 81.60527229309082, 74.8926892876625, 79.04819190502167, 77.97525107860565, 81.41808673739433, 87.90689215064049, 97.34636083245277, 102.43749484419823, 105.89929148554802, 92.94740527868271, 75.95790132880211, 78.72260257601738, 89.10231560468674, 92.90737822651863, 99.1167314350605, 87.64772325754166, 91.69674038887024, 85.68099439144135, 75.1143541932106, 75.65198734402657, 82.30752021074295, 75.8549040555954, 52.73656077682972, 73.28267008066177, 96.57469063997269, 92.19795629382133, 93.57864260673523, 90.45507341623306, 85.21745726466179, 74.92653787136078, 78.67955848574638, 77.4418357014656, 81.47015914320946, 95.28251677751541, 79.12979632616043, 93.61850246787071, 95.72939559817314, 95.91574519872665, 96.97303086519241, 96.55398935079575, 95.74768021702766, 96.03166937828064, 95.42292684316635, 89.85402926802635, 80.77965259552002, 75.13432592153549, 79.33022797107697, 85.75361609458923, 88.57197806239128, 91.95263385772705, 94.10334885120392, 98.08206215500832, 95.85633158683777, 94.01876538991928, 97.4396762251854, 94.91709798574448, 91.83648928999901, 92.324930280447, 82.92820170521736, 61.23851336538792, 25.771484412252903, 3.028803700581193, 0.7051469839643687, 0.7196905254386365, 0.19871311291353777, 0.2628181519685313, 0.19819378765532747, 0.05213804877712391, 0.03839186334516853, 0.015332550210587215, 0.43770937831141055, 1.5181237505748868, 57.123193591833115, 91.83284908533096, 100.37545189261436, 47.470955327153206, 53.610335290431976, 32.59456738829613, 17.962722927331924, 39.98228296637535, 56.72929912805557, 61.650472059845924, 77.20072343945503, 79.44213196635246, 96.93530648946762, 35.1854507625103, 0.160444624198135, 0.11494185062474571, 0.07063091426971368, 0.04137010939302854, 0.05446061477414332, 0.07957283640280366, 0.03241322185203899, 0.05879438613192178, 0.015702160162618384, 0.008928908573579974, 0.025995574033004232, 0.014846926806058036, 0.06862896349048242, 0.013829327308485517, 0.030542766653525177, 0.028642690485867206, 0.0440938062092755, 0.020758894679602236, 0.039183764602057636, 0.02483229836798273, 0.07168011070461944, 0.01995531016291352, 0.03429908218095079, 0.026098168527823873, 0.05864942242624238, 0.046917455474613234, 0.16180382313905284, 0.1709953072713688, 0.11129256206913851, 0.13136643217876554, 0.1849065240821801, 0.15548243187367916, 0.2022564079379663, 0.17668670421699062, 0.14457482029683888, 0.1626288241823204, 0.11162214985233732, 0.18656976608326659, 0.22671099024591967, 0.12405191373545676, 0.17941065336344764, 0.15370599750895053, 0.15250618220306933, 0.14533808949636295, 0.25339525134768337, 0.1584761665435508, 0.18188280664617196, 0.3765578643651679, 2.658428787253797, 37.80879959464073, 104.54915553331375, 133.2949474453926, 145.4067975282669, 104.47328880429268, 100.23636415600777, 62.612333446741104, 53.37677702307701, 69.29637998342514, 168.14806044101715, 105.93190133571625, 117.86108762025833, 138.79433155059814, 120.69573551416397, 23.691160641610622, 1.5323918662033975, 0.25986078253481537, 0.34191126411315054, 0.281140620354563, 0.6716391944792122, 0.34810576296877116, 0.37216717028059065, 3.017155663110316, 1.7189614987000823, 56.88322886824608, 116.2772186100483, 103.58896985650063, 106.40056818723679, 92.42493331432343, 99.03311312198639, 102.73568764328957, 104.26722586154938, 102.52289146184921, 104.76072058081627, 105.91802448034286, 107.44504854083061, 107.78648301959038, 110.97744539380074, 108.41800913214684, 105.47323554754257, 101.78066208958626, 88.5460938513279, 80.21103590726852, 83.21737378835678, 80.19250810146332, 86.54460445046425, 90.90459689497948, 103.16432744264603, 107.16905415058136, 111.66669800877571, 96.86323955655098, 80.93615099787712, 83.43103632330894, 95.46518057584763, 97.10654810070992, 100.63566192984581, 94.51105177402496, 97.5298909842968, 90.7729871571064, 84.78133946657181, 88.47066029906273, 96.83844208717346, 82.35535204410553, 62.026013508439064, 80.89028745889664, 97.21082970499992, 95.82061350345612, 97.14870303869247, 92.87796780467033, 92.00966879725456, 85.610211789608, 89.63336750864983, 86.29344552755356, 93.33801671862602, 98.63846629858017, 80.56833073496819, 95.72174280881882, 99.81704905629158, 97.65395432710648, 101.01634070277214, 98.66740554571152, 97.82024100422859, 97.97715738415718, 98.39181393384933, 94.08859044313431, 85.51071792840958, 80.46958923339844, 86.23049810528755, 92.50118762254715, 95.11179193854332, 98.30450221896172, 100.19340366125107, 103.18713381886482, 98.69238540530205, 98.70130732655525, 101.54658704996109, 102.5926785171032, 100.93228161334991, 101.54816016554832, 92.45877429842949, 60.44934891164303, 20.271165557205677, 1.357949876692146, 2.6525431405752897, 3.0043816985562444, 0.5954896181356162, 0.2561517065623775, 0.5060084571596235, 0.2795728779165074, 0.36005279689561576, 0.18478309008060023, 0.9751216066069901, 4.869661470875144, 73.30780953168869, 97.58121103048325, 111.02039828896523, 57.18373194336891, 78.2602509856224, 86.32369190454483, 33.92953835427761, 33.44771280884743, 44.020060300827026, 52.76472106575966, 83.98835241794586, 85.42899191379547, 114.53704878687859, 47.51689486205578, 0.39055663975887, 0.2625554020050913, 0.18990174197824672, 0.16266570892184973, 0.15536929888185114, 0.18813799833878875, 0.09650750347645953, 0.1385269549791701, 0.16622626630123705, 0.16743973712436855, 0.10528885453823023, 0.1633155334275216, 0.1413424257771112, 0.1417328548268415, 0.13900909863878042, 0.10841387513210066, 0.13516832113964483, 0.23571806552354246, 0.0873261051310692, 0.09161121386568993, 0.10569052712526172, 0.1767123825266026, 0.1878132642013952, 0.13410149869741872, 0.12078935833415017, 0.169728075270541], [0.08693779120221734, 0.03160431428113952, 0.02885778529162053, 0.02751485793851316, 0.03769967705011368, 0.022442399167630356, 0.039808192814234644, 0.047791783363209106, 0.04482900367293041, 0.05129446064529475, 0.0286726138801896, 0.03982423062552698, 0.07047865525237285, 0.03991368539573159, 0.09807647787965834, 0.06701721911667846, 0.06976043441682123, 0.04677687415096443, 0.13379055366385728, 0.08441555037279613, 0.46097244252450764, 13.493973668664694, 75.53110063076019, 103.23767110705376, 111.35123893618584, 87.79521614313126, 64.51495975255966, 80.09432896971703, 42.85100743174553, 148.28219443559647, 194.86910820007324, 146.51107907295227, 81.99210673570633, 100.95905497670174, 122.30136215686798, 93.90287160873413, 14.047432970255613, 1.2723627942614257, 0.4123444331344217, 0.33751059556379914, 0.07925968719064258, 0.3926512773614377, 0.04101345177332405, 0.5453500617295504, 0.40162906749174, 0.4018867411650717, 0.199470593361184, 64.2291010916233, 103.03375884890556, 93.07018429040909, 90.01203998923302, 81.56573921442032, 76.80226162075996, 73.5239951312542, 79.27627846598625, 77.61390566825867, 78.3482314646244, 78.82144287228584, 77.66241386532784, 84.37533125281334, 86.08242765069008, 88.10534030199051, 82.25088804960251, 74.01230692863464, 70.20863503217697, 68.6807370185852, 71.0270807147026, 71.8537263572216, 72.72819623351097, 83.24359998106956, 93.15789878368378, 100.15553489327431, 96.04016572237015, 83.15637186169624, 76.14647001028061, 69.45973321795464, 79.00736689567566, 89.598698168993, 95.83768978714943, 84.24676895141602, 82.47269734740257, 83.90773594379425, 76.61952182650566, 69.68417197465897, 65.50818845629692, 79.69843581318855, 67.74733230471611, 48.70364338159561, 84.32202011346817, 97.02666118741035, 96.87021598219872, 88.4158444404602, 75.78437224030495, 71.55741065740585, 69.64007154107094, 74.31198924779892, 77.88410916924477, 79.90022018551826, 93.77212062478065, 90.03232330083847, 86.46964207291603, 86.96634382009506, 88.60493749380112, 85.70895329117775, 92.22431167960167, 89.89408671855927, 89.82205018401146, 86.37961730360985, 82.86805093288422, 80.12343540787697, 77.28556528687477, 74.20893877744675, 71.91000893712044, 76.04835167527199, 78.56356590986252, 79.29077848792076, 80.4353378713131, 83.95989194512367, 85.05644470453262, 82.51108288764954, 82.16768771409988, 81.336679905653, 90.24640381336212, 91.75700515508652, 93.88007283210754, 63.70980195701122, 18.52843277156353, 0.147890335356351, 0.5628689029254019, 0.2730381488800049, 0.09219530635164119, 0.3250851732445881, 0.23076218145433813, 0.20995057944674045, 0.24123241571942344, 0.369528568116948, 4.299256028607488, 50.084998458623886, 79.43638667464256, 101.08037486672401, 48.16707797348499, 60.09132072329521, 92.16381132602692, 46.00234933197498, 28.33813838660717, 35.05844257771969, 47.60890692472458, 56.39544524252415, 70.06756380200386, 80.39602518081665, 14.341402295976877, 0.9769006830174476, 0.07625132479006425, 0.032883220264920965, 0.10245003577438183, 0.05065574609034229, 0.09138453970081173, 0.037490836693905294, 0.05227214001934044, 0.004852544643654255, 0.03486093621177133, 0.04070614326337818, 0.03330145016661845, 0.05379861162509769, 0.1397893630200997, 0.10950820898870006, 0.017470031998527702, 0.062426152580883354, 0.04103034305444453, 0.03410541874472983, 0.025385357948835008, 0.06504856850369833, 0.06225677963811904, 0.017876482161227614, 0.02025537716690451, 0.0646717801282648, 0.04971940434188582, 0.04218888010655064, 0.04570702003547922, 0.036036253222846426, 0.10031401601736434, 0.04403690203616861, 0.038597627499257214, 0.11573246054467745, 0.0677002695738338, 0.014233357142074965, 0.010481019526196178, 0.07380806331639178, 0.030375243513844907, 0.009995659584092209, 0.07951880063046701, 0.05629594226775225, 0.08833409010549076, 0.08303268434247002, 0.09863941915682517, 0.06125167419668287, 0.6099994957912713, 19.760982133448124, 95.31403988599777, 122.54573464393616, 120.21561607718468, 105.36149874329567, 94.67191234230995, 124.52823266386986, 70.36647096276283, 153.35448145866394, 152.9949751496315, 99.83286380767822, 92.7593457698822, 112.15279072523117, 130.31380981206894, 103.79387006163597, 13.652382418513298, 1.3523857877589762, 0.3297601395752281, 0.2519049297552556, 0.07436055515427142, 0.40991110901813954, 0.23408262437442318, 0.38401707191951573, 0.47832703159656376, 0.16864161560079083, 0.28033752751071006, 69.75638329982758, 110.11717155575752, 93.92554879188538, 93.60813662409782, 85.4698397219181, 83.534846752882, 75.32834351062775, 83.3249232172966, 79.75586593151093, 82.26480290293694, 81.80396363139153, 83.51834043860435, 84.66455653309822, 87.93998077511787, 88.97568359971046, 82.26673319935799, 75.55187791585922, 74.03879150748253, 72.51625880599022, 74.87033128738403, 76.28446340560913, 75.22630378603935, 88.44741314649582, 96.56071498990059, 101.2353153526783, 101.80481359362602, 87.83124580979347, 80.99220559000969, 73.6951531469822, 84.93897780776024, 94.240453094244, 97.74783208966255, 89.12102580070496, 85.8267317712307, 91.04590371251106, 84.26499277353287, 77.07836240530014, 72.69548758864403, 81.49690210819244, 78.9629852771759, 56.09609730541706, 85.01129552721977, 99.95552882552147, 102.49204471707344, 93.07625636458397, 83.73023986816406, 80.53064435720444, 76.51007249951363, 79.88648012280464, 84.38231527805328, 84.657162129879, 93.50441738963127, 93.71670439839363, 89.52362179756165, 87.93775409460068, 91.2954743206501, 90.3071777522564, 92.53078043460846, 92.99227327108383, 94.16848495602608, 93.00864279270172, 86.74299940466881, 81.56853586435318, 81.35284423828125, 78.1427612900734, 75.72333991527557, 81.0046537220478, 82.4606291949749, 83.16292271018028, 83.46700519323349, 87.267796844244, 87.98475757241249, 85.23109093308449, 88.6397360265255, 87.84395232796669, 93.21186348795891, 97.72636324167252, 102.12340369820595, 76.773481965065, 28.333316445350647, 1.9380900403484702, 0.6078745191916823, 0.2420348406303674, 0.11281837316346355, 0.5381463014055043, 0.2170490290154703, 0.10302620954462327, 0.18997705512447283, 0.2527017588727176, 2.860944145359099, 52.66720309853554, 83.16776365041733, 110.67501962184906, 52.661207020282745, 59.450732097029686, 43.67063485085964, 31.401902586221695, 34.49131540954113, 44.70520533621311, 70.07561177015305, 73.89912620186806, 82.05477297306061, 94.54248368740082, 25.318324528634548, 0.7546137389726937, 0.16143390705110505, 0.07139807974454015, 0.11324193910695612, 0.0920613190100994, 0.08548134865122847, 0.045787001290591434, 0.05894362089748029, 0.031061218032846227, 0.04901719163171947, 0.037320239207474515, 0.035242062440374866, 0.05826771361171268, 0.09494143829215318, 0.12558456743136048, 0.032484931871294975, 0.02380854461080162, 0.031320969719672576, 0.017973742469621357, 0.019916377095796634, 0.05198155951802619, 0.03516937649692409, 0.03204352098691743, 0.06557621323736385, 0.046844917960697785, 0.15562658663839102, 0.10743288206867874, 0.1443278483930044, 0.10669422990758903, 0.2933499589562416, 0.09576317388564348, 0.16965552291367203, 0.11162580864038318, 0.14124483335763216, 0.16493466217070818, 0.09336081959190778, 0.21099530073115602, 0.19210489641409367, 0.19598082202719525, 0.15677881543524563, 0.13083539583021775, 0.13443092320812866, 0.2196217284654267, 0.21067726076580584, 0.30650799977593124, 0.8550051832571626, 25.629805214703083, 111.90998375415802, 146.8789753317833, 134.55271035432816, 110.20524322986603, 87.29993551969528, 113.0286057293415, 53.41114617884159, 163.88093501329422, 198.64485919475555, 175.54261565208435, 115.44813349843025, 118.25761914253235, 138.47244322299957, 114.78022053837776, 24.919446632266045, 2.5223792251199484, 0.955964756431058, 0.614771208493039, 0.2739210374420509, 0.9681222040671855, 0.2507557882927358, 1.182724297977984, 3.33212788682431, 3.7658978858962655, 0.5443023866973817, 76.30891889333725, 115.9163747727871, 102.76904225349426, 98.56841325759888, 90.86972236633301, 85.46746864914894, 84.04088079929352, 91.69429332017899, 85.61927050352097, 86.57604396343231, 88.49297270178795, 89.94272410869598, 89.79235097765923, 93.14283639192581, 97.44365841150284, 93.26542541384697, 82.10111528635025, 79.55341279506683, 75.8755673468113, 80.32185316085815, 79.015202075243, 78.18734809756279, 91.28748714923859, 101.68966457247734, 104.15286719799042, 105.09248077869415, 93.42336013913155, 85.23567348718643, 76.9464410841465, 91.22859790921211, 99.24320384860039, 101.51035979390144, 93.99730414152145, 93.175408244133, 96.14425733685493, 93.40910330414772, 87.8763721883297, 91.17873698472977, 95.36760941147804, 87.45995253324509, 65.2954150736332, 90.45161560177803, 99.79739651083946, 100.26491582393646, 94.05755370855331, 89.69904318451881, 87.23631173372269, 84.52669993042946, 83.10768127441406, 85.19560843706131, 89.51664537191391, 95.9247051179409, 97.93381690979004, 90.73144778609276, 94.91996303200722, 94.05053168535233, 92.46386602520943, 93.21378618478775, 96.58847630023956, 97.67354607582092, 94.93303433060646, 88.84547218680382, 86.133474111557, 83.28122556209564, 82.49722883105278, 79.40286487340927, 86.13288134336472, 87.55884602665901, 86.75660267472267, 86.44291430711746, 92.02782422304153, 93.75214129686356, 91.2201775610447, 92.5970108807087, 92.57547363638878, 99.97119158506393, 107.03936710953712, 110.21538108587265, 77.13476657867432, 21.98185656219721, 1.6150082205422223, 2.291611433029175, 0.7861518685240299, 0.23410168272675946, 0.6767664849758148, 0.33751997631043196, 0.49547942995559424, 0.7064950210042298, 0.4883807577425614, 8.350387271493673, 69.8530425131321, 90.52004233002663, 120.10019347071648, 62.25520960986614, 86.2512069940567, 121.15048751235008, 57.426850497722626, 38.896255642175674, 46.07355371117592, 61.381298303604126, 78.37173700332642, 88.35576206445694, 107.6048755645752, 36.41354866325855, 1.220621089451015, 0.22179187217261642, 0.2336016236222349, 0.20522361824987456, 0.1821951469173655, 0.1774598439806141, 0.13442921626847237, 0.11613505339482799, 0.10356251514167525, 0.14759065612452105, 0.20492031733738258, 0.0778323071426712, 0.1344564530882053, 0.21526870579691604, 0.16236380324698985, 0.20687507494585589, 0.14880993054248393, 0.1159663409634959, 0.20193531032418832, 0.13256942387670279, 0.1856110745575279, 0.09752704369020648, 0.20967678632587194, 0.11547226356924511, 0.0767164138960652], [0.13651269196998328, 0.01903580588987097, 0.0779984294786118, 0.04400227713631466, 0.021895542085985653, 0.10955830395687371, 0.08796235575573519, 0.08363363842363469, 0.0672833235876169, 0.004786415111084352, 0.06337944127153605, 0.13069780165096745, 0.06230248851352371, 0.11111230181995779, 0.12247697246493772, 0.02403905011306051, 0.08420903293881565, 0.08843540810630657, 0.01065772488800576, 0.3683232015464455, 26.382406130433083, 110.58588400483131, 105.38968563079834, 92.3324766755104, 82.71415159106255, 88.51479113101959, 64.94217842817307, 40.307758301496506, 35.13673737645149, 71.07028439640999, 95.26054635643959, 80.36444887518883, 109.28455263376236, 123.63085761666298, 96.47646591067314, 16.766881495714188, 0.8583715057466179, 0.38690132496412843, 0.3114469035062939, 0.1328076681238599, 0.2724668139126152, 0.17892067262437195, 0.054219361118157394, 0.31556077650748193, 0.6029306282289326, 0.22279003111179918, 1.9433060917071998, 74.2143876850605, 103.22217553853989, 98.24001967906952, 97.04075083136559, 95.7743851840496, 95.45875892043114, 82.80489072203636, 77.03110814094543, 76.679497808218, 73.52120608091354, 67.26212874054909, 68.17826718091965, 66.10703632235527, 69.12960693240166, 69.74161729216576, 70.66907912492752, 74.95031699538231, 78.61930891871452, 78.25837388634682, 73.44259589910507, 72.05580711364746, 77.81237661838531, 86.72890216112137, 96.19698330760002, 98.01637887954712, 91.64973691105843, 85.01952588558197, 74.5465886592865, 76.83022052049637, 82.94434323906898, 88.98195326328278, 94.27735671401024, 83.86334672570229, 77.52296134829521, 87.48221933841705, 84.50450152158737, 75.14236629009247, 63.09729002416134, 61.03970043361187, 74.97291058301926, 71.2520894408226, 67.01232254505157, 93.83339613676071, 102.58662924170494, 86.46587267518044, 74.31961163878441, 82.89505988359451, 81.24068945646286, 77.85624146461487, 91.28421172499657, 85.20564749836922, 84.59701895713806, 86.71651482582092, 81.40468865633011, 77.79840096831322, 78.62313151359558, 84.68024969100952, 89.02343943715096, 92.52546072006226, 85.89784115552902, 90.93535244464874, 84.15162205696106, 86.31649509072304, 86.55748575925827, 85.35542786121368, 82.07196325063705, 80.5274449288845, 75.10298520326614, 72.61867091059685, 73.74082669615746, 74.29048240184784, 71.47327557206154, 71.64539113640785, 74.21504884958267, 79.84747901558876, 81.2767343223095, 85.52150934934616, 82.85938739776611, 91.42706885933876, 91.03996083140373, 47.595679834485054, 1.3840493699535728, 0.7117667037528008, 0.2588218648452312, 0.1765420744777657, 0.2609115745872259, 0.14350114041008055, 0.2245115613914095, 0.41892829234711826, 0.2962585841305554, 5.7872167602181435, 43.23920980095863, 79.74379017949104, 106.75457239151001, 71.23226970434189, 72.9612909257412, 86.99684858322144, 79.95909422636032, 52.00382709503174, 22.274376265704632, 51.33722126483917, 59.290984869003296, 64.37098547816277, 72.89287939667702, 21.11494828015566, 0.5494680907577276, 0.06015312494128011, 0.08569379584514536, 0.028802294909837656, 0.015951369641697966, 0.053721060903626494, 0.03165381924191024, 0.08723961524083279, 0.02641851100634085, 0.018848330109904055, 0.03440563603362534, 0.08493172150338069, 0.14161425962811336, 0.042880205510300584, 0.0416777741338592, 0.1837840850930661, 0.06254549734876491, 0.030294219541247003, 0.02153125333279604, 0.041143283087876625, 0.14844994439044967, 0.08326606752234511, 0.08044771719141863, 0.12037418608088046, 0.1322582265129313, 0.018537221803853754, 0.07794127668603323, 0.046415644901571795, 0.024399785834248178, 0.031638375148759224, 0.07451454337569885, 0.02146907620044658, 0.039820059755584225, 0.023885462651378475, 0.06986331834923476, 0.05986416232190095, 0.03168729381286539, 0.1394198476918973, 0.10930540971457958, 0.03955224463425111, 0.014248537772800773, 0.1320326581480913, 0.03099117413512431, 0.36075843090657145, 35.029936507344246, 132.43170976638794, 111.33155599236488, 103.71327638626099, 114.63598027825356, 124.28011357784271, 98.3438529074192, 69.86347675323486, 54.813073351979256, 77.27405950427055, 109.43203032016754, 94.53915506601334, 118.2164217531681, 127.8550073504448, 105.6744347512722, 17.68896471709013, 0.8075245935469866, 0.5662656831555068, 0.27724366227630526, 0.08960401610238478, 0.3950251406058669, 0.2576929097995162, 0.3698168776463717, 0.22530705464305356, 1.217440185137093, 0.16114895202917978, 3.8943526055663824, 78.32091093063354, 109.8249064385891, 103.98213475942612, 101.76828235387802, 101.38579487800598, 98.88755813241005, 89.52137991786003, 80.48828423023224, 80.46610102057457, 75.39661064743996, 71.20832338929176, 70.88597148656845, 70.43901666998863, 73.51733028888702, 74.58334028720856, 73.80374372005463, 77.30331793427467, 82.12041825056076, 81.4498682320118, 76.5192224085331, 77.01459422707558, 80.62351137399673, 92.34071463346481, 97.76256769895554, 99.17663142085075, 91.68243035674095, 88.08597654104233, 77.98642247915268, 79.57862064242363, 86.64507865905762, 92.0404851436615, 94.4761012494564, 87.81687498092651, 83.67912501096725, 88.97319093346596, 91.99856579303741, 81.74556076526642, 72.1183517575264, 64.21344593167305, 78.27299550175667, 81.52933716773987, 73.1594654917717, 97.91214287281036, 104.14646074175835, 91.07348263263702, 80.11373832821846, 87.25161731243134, 86.39712676405907, 85.79086929559708, 93.18358540534973, 91.71909838914871, 89.60946679115295, 91.36298149824142, 82.6511737704277, 82.91371688246727, 82.79481366276741, 88.89499112963676, 93.26693773269653, 93.35538178682327, 89.08409178256989, 94.53546166419983, 89.01809692382812, 90.71062490344048, 90.54901197552681, 90.7827678322792, 87.57579311728477, 85.89231625199318, 79.8307903110981, 77.5980757176876, 74.54158812761307, 75.15666112303734, 73.61687734723091, 75.33776700496674, 76.8299013376236, 82.68520474433899, 87.18923225998878, 90.57413622736931, 86.4322292804718, 92.74374380707741, 98.45553651452065, 62.330475971102715, 4.877945026382804, 0.7030205824412405, 0.10348848591092974, 0.31981871521566063, 0.35697997896932065, 0.11903727383469231, 0.6655653391499072, 0.33162212872412056, 0.31546788930427283, 3.752598837018013, 51.84685371816158, 83.40107873082161, 117.14833706617355, 81.38072714209557, 72.44688972830772, 40.711460039019585, 45.98573662340641, 61.749927923083305, 41.11938335001469, 67.62732714414597, 77.72057354450226, 70.02428412437439, 89.66323390603065, 34.05656933784485, 0.500440924661234, 0.06055004778318107, 0.08853682258632034, 0.0688082812121138, 0.0969522503146436, 0.05164777488971595, 0.05366164827137254, 0.01940497797477292, 0.006567419250131934, 0.04461591823201161, 0.033443582578911446, 0.0443782454385655, 0.06358021448249929, 0.04741978184028994, 0.1254900178173557, 0.03222746971005108, 0.09517053185845725, 0.07486307818908244, 0.07040023992885835, 0.06698403027257882, 0.051406094498815946, 0.1250445659388788, 0.021674784693459515, 0.09266055130865425, 0.29833000735379755, 0.23859973589424044, 0.2855626627570018, 0.23351456969976425, 0.20024070516228676, 0.09901145778712817, 0.27184133185073733, 0.2330656594131142, 0.1363916031550616, 0.11801102460594848, 0.09213602359523065, 0.31809565611183643, 0.22245086962357163, 0.24374688626267016, 0.2537779323756695, 0.10082184540806338, 0.2760174561990425, 0.3107187675777823, 0.18929611978819594, 0.8854668424464762, 44.778792187571526, 155.39916694164276, 128.94991099834442, 112.12407946586609, 109.57198441028595, 116.72134637832642, 87.28952407836914, 45.00123605132103, 49.8436164110899, 78.63213703036308, 110.77116966247559, 116.51486545801163, 127.13773503899574, 133.20613861083984, 116.68134212493896, 30.181518271565437, 1.4730069902725518, 0.9163255803287029, 0.5259851133450866, 0.3050516388611868, 0.6921104772482067, 0.5220133764669299, 0.2679115114733577, 0.6335731933359057, 1.57598324585706, 0.6869231024757028, 3.582146870903671, 85.04290983080864, 111.52301251888275, 107.95439600944519, 105.33941432833672, 109.07120168209076, 105.49346566200256, 94.08022329211235, 82.36517831683159, 87.97097951173782, 81.44812032580376, 76.02300703525543, 75.59433683753014, 75.85995778441429, 76.96326658129692, 76.9274041056633, 76.65371239185333, 81.81481584906578, 86.82705849409103, 86.41057804226875, 79.38046127557755, 78.98436293005943, 83.81578847765923, 94.99823123216629, 102.55990147590637, 100.80821067094803, 98.06019052863121, 95.49712166190147, 82.60062888264656, 83.98463621735573, 89.7528862953186, 96.14503249526024, 98.96929934620857, 93.05102571845055, 84.90632236003876, 95.45887291431427, 97.66245827078819, 92.07740396261215, 83.36127206683159, 78.88008892536163, 93.48707512021065, 89.63896080851555, 81.49141520261765, 95.20274385809898, 97.47350960969925, 90.11713474988937, 89.27014499902725, 95.81934437155724, 89.91523638367653, 84.87985298037529, 94.73910793662071, 94.56293419003487, 95.02949595451355, 92.81871378421783, 88.15954819321632, 85.28298854827881, 86.17326557636261, 93.56976628303528, 97.98063799738884, 94.75835010409355, 91.11808463931084, 96.47849500179291, 92.26818412542343, 92.8080515563488, 94.31191205978394, 93.88122797012329, 88.64792838692665, 88.17722484469414, 83.67042347788811, 79.52537029981613, 78.0823977291584, 80.43957844376564, 76.76813945174217, 80.4955342411995, 82.42061734199524, 89.42978963255882, 94.73809719085693, 95.08700966835022, 92.4932612478733, 101.35568529367447, 105.12866243720055, 57.68094666302204, 2.8567192470654845, 3.2628231681883335, 0.8509056782349944, 0.44166404579300433, 0.9819763200357556, 0.3448901855153963, 0.7847634586505592, 0.5333945970050991, 0.5866648291703314, 10.845289696007967, 66.3758111000061, 90.52008032798767, 134.74584639072418, 85.40186896920204, 99.25702750682831, 118.82039174437523, 89.05299425125122, 63.56498032808304, 34.290044009685516, 66.07818827033043, 82.19398990273476, 80.48414245247841, 105.57194665074348, 49.85011026263237, 0.7742653938475996, 0.21065667358925566, 0.16699349856935441, 0.1364983239909634, 0.28176150110084563, 0.10298860492184758, 0.17571318458067253, 0.18397401552647352, 0.10265420060022734, 0.07987356948433444, 0.1477871323004365, 0.13175079046050087, 0.2863379695918411, 0.2677926194155589, 0.2180740685435012, 0.33666659554000944, 0.17790085781598464, 0.13862598716514185, 0.21089966758154333, 0.2889913256512955, 0.19860547181451693, 0.36224492301698774, 0.21539718640269712, 0.22576323797693476], [0.08986046523205005, 0.1530404543154873, 0.08530141494702548, 0.06375734286848456, 0.016996810809359886, 0.07673438129131682, 0.10156068310607225, 0.02956506872578757, 0.033424197681597434, 0.08462211233563721, 0.002009125955737545, 0.028645660931942984, 0.037374690582510084, 0.050716342448140495, 0.045087519683875144, 0.04897414706647396, 0.05164829810382798, 0.0574185074219713, 0.554190999828279, 16.442812085151672, 98.89524891972542, 88.33016663789749, 88.9750300347805, 84.27380830049515, 57.35631488263607, 38.64739939570427, 34.26569491624832, 38.30453999340534, 58.96424800157547, 67.14444145560265, 65.77995747327805, 105.74421420693398, 116.98977917432785, 100.70157319307327, 22.48869426548481, 0.92784199048765, 0.24126156728016213, 0.17968422384001315, 0.14083748334087431, 0.16472882009111345, 0.1589718321338296, 0.1762776472605765, 0.2955713256960735, 0.7869910297449678, 0.1356187157216482, 3.4735997579991817, 65.97464382648468, 99.78934854269028, 107.74562001228333, 103.1198014318943, 101.69480949640274, 100.0348761677742, 99.62154194712639, 100.99314674735069, 88.31590980291367, 77.0743878185749, 75.81027925014496, 73.68508368730545, 70.94643384218216, 68.97712871432304, 73.6826366186142, 72.99691781401634, 79.41016048192978, 79.7433266043663, 79.11899730563164, 79.64725255966187, 76.70717552304268, 74.67433780431747, 77.37423732876778, 89.05942350625992, 94.10320445895195, 85.42746439576149, 87.42747947573662, 81.70067757368088, 80.0545147061348, 72.88315951824188, 76.47870898246765, 87.48150497674942, 89.68433037400246, 91.03076532483101, 87.05834448337555, 75.50703272223473, 82.78418183326721, 71.19055554270744, 72.6188836991787, 54.87216778099537, 70.47025099396706, 74.36866700649261, 69.64889466762543, 110.61667755246162, 94.27563160657883, 79.06032085418701, 64.02272656559944, 72.23333358764648, 74.2215085029602, 83.14760193228722, 84.80317309498787, 80.97208186984062, 81.18193700909615, 78.77778321504593, 72.32779651880264, 74.96441423892975, 67.80929937958717, 75.49016162753105, 81.89391240477562, 88.3805975317955, 85.70918887853622, 77.82812297344208, 86.15811958909035, 90.13374745845795, 87.82275706529617, 92.9082141816616, 89.52865272760391, 88.6141861975193, 82.19079047441483, 80.56876391172409, 76.52139589190483, 73.0184930562973, 72.70882487297058, 71.97978839278221, 72.32028812170029, 69.81873795390129, 72.46343404054642, 79.01945024728775, 86.08681261539459, 84.14159819483757, 85.47177001833916, 94.1941487789154, 74.02522623538971, 9.485178329050541, 0.16541172954021022, 0.1183497259626165, 0.20194656128296629, 0.2728524338454008, 0.2643302333308384, 0.0426117632741807, 0.03515007694659289, 0.3515153971966356, 12.561395410448313, 36.611681431531906, 54.30849462747574, 85.94068765640259, 75.02022564411163, 76.60525739192963, 60.1959253102541, 34.994647800922394, 31.321392506361008, 24.93650771677494, 45.35096548497677, 66.80691316723824, 72.63561800122261, 75.19125446677208, 16.957317776978016, 0.3379582887282595, 0.0706169693148695, 0.06218761518539395, 0.0776290922658518, 0.03505818793200888, 0.0560350625164574, 0.030373551417142153, 0.03924961907614488, 0.07420610680128448, 0.08242314361268654, 0.06919143721461296, 0.04787426194525324, 0.017299709106737282, 0.1353521362761967, 0.16659217479173094, 0.09449764882447198, 0.15594262280501425, 0.039541657897643745, 0.06309985197731294, 0.07760450491332449, 0.03906124344212003, 0.06323894529487006, 0.0728034254279919, 0.04158565505349543, 0.05038765266363043, 0.03668968827696517, 0.06118759345554281, 0.04154078480496537, 0.10476699113496579, 0.111795070260996, 0.014870199629513081, 0.05698777975339908, 0.09750595185323618, 0.016956371182459407, 0.07799644794431515, 0.06733831673045643, 0.060841604208690114, 0.01549418719150708, 0.12798355979612097, 0.22421915520681068, 0.1586978608975187, 0.532783423550427, 20.579475313425064, 120.95654591917992, 90.17482325434685, 113.09251829981804, 109.40560653805733, 89.00903820991516, 70.84618762135506, 57.14137181639671, 38.74085158109665, 7.179364208132029, 43.415045365691185, 79.2117427289486, 113.0338342487812, 120.26681452989578, 109.44990456104279, 22.647322453558445, 0.7729110633954406, 0.1872130300034769, 0.2532148500904441, 0.14658694592071697, 0.5097644368652254, 0.6296421261504292, 0.6288563401903957, 1.0269915545359254, 0.9705348371062428, 0.17351804533973336, 6.792101338505745, 77.65498146414757, 103.26568320393562, 108.53976979851723, 107.78567746281624, 108.60872849822044, 107.64424905180931, 103.70990216732025, 105.66349133849144, 95.25253638625145, 80.38087159395218, 78.67584988474846, 77.17306092381477, 74.42067861557007, 75.01918449997902, 75.820432305336, 74.97235581278801, 81.13046497106552, 84.34883907437325, 85.01487493515015, 83.2111345231533, 79.19267535209656, 76.05072274804115, 81.39283329248428, 91.0575158894062, 96.12351045012474, 90.10732367634773, 92.24504336714745, 86.26791849732399, 83.8330015540123, 72.80830353498459, 80.13823181390762, 90.60973271727562, 93.44276949763298, 94.26124557852745, 92.96325042843819, 82.76843547821045, 84.85084533691406, 79.17775735259056, 81.84099644422531, 63.748905658721924, 78.03735494613647, 78.00222963094711, 80.01488283276558, 111.18264958262444, 97.7551580965519, 81.78677335381508, 71.01436659693718, 79.74139630794525, 79.04009073972702, 87.57880255579948, 88.77572312951088, 86.06788203120232, 83.33107888698578, 83.47951412200928, 80.84016054868698, 79.64096009731293, 71.02341771125793, 80.27535885572433, 85.76780453324318, 92.25813746452332, 90.05785033106804, 80.03154873847961, 90.25926992297173, 95.27730345726013, 93.45517203211784, 96.38700351119041, 94.5320950448513, 94.12698358297348, 89.3357902765274, 84.87349972128868, 80.79302787780762, 78.88635098934174, 76.6092623770237, 76.74676939845085, 75.24445161223412, 75.86083173751831, 76.77829250693321, 79.8944216966629, 89.1977208852768, 88.5404321551323, 87.67824321985245, 96.0296630859375, 86.17929205298424, 19.172650203108788, 0.07201611064374447, 0.1209105436282698, 0.5428716447204351, 0.5545594019349664, 0.08149065732141025, 0.0942750193644315, 0.0480411227181321, 0.3917054843623191, 10.383989699184895, 44.5161996781826, 58.6493057012558, 96.23223781585693, 85.55770620703697, 73.36656957864761, 40.6620778888464, 17.2578227519989, 40.87145045399666, 55.53458243608475, 62.78735585510731, 87.26876959204674, 77.28219866752625, 89.80928286910057, 24.848557636141777, 0.1841423791483976, 0.10589656958472915, 0.01043014901370043, 0.06640420513576828, 0.01461985466448823, 0.07739616921753623, 0.02227516917628236, 0.057129129199893214, 0.07228046364616603, 0.039767823691363446, 0.062180423774407245, 0.037987370596965775, 0.03277427298598923, 0.07210288997157477, 0.08261238384875469, 0.030927510852052364, 0.01707350991637213, 0.03900025745679159, 0.09213454672135413, 0.058121714610024355, 0.031863668918958865, 0.03237281933252234, 0.010587376709736418, 0.13171571656130254, 0.20226149907102808, 0.2790520089911297, 0.2338513860013336, 0.12056557112373412, 0.22196569800144061, 0.2268353445106186, 0.16519485914614052, 0.1469406089745462, 0.2717414981452748, 0.07296441952348687, 0.11640215234365314, 0.19335079909069464, 0.15275726560503244, 0.19171951396856457, 0.23813860985683277, 0.37690409109927714, 0.23747018713038415, 0.9160233777947724, 28.110481202602386, 139.21502977609634, 108.74833300709724, 115.14467418193817, 114.34942245483398, 79.27165791392326, 52.21243970096111, 41.76309160888195, 55.62208414077759, 78.08187335729599, 103.96907106041908, 103.0410772562027, 122.76490688323975, 130.35024225711823, 121.67085438966751, 36.40668623149395, 1.430063594598323, 0.4305173142347485, 0.4767932795220986, 0.30406808538828045, 1.1710184323601425, 0.6503964937292039, 0.3645028924802318, 1.2349877622909844, 2.3838954186066985, 0.31921187590342015, 6.851059924811125, 79.25443723797798, 101.25535547733307, 114.10681307315826, 109.58890870213509, 111.69517368078232, 110.28511494398117, 107.19917133450508, 112.62441381812096, 100.49703016877174, 86.75436839461327, 83.86548981070518, 79.61345717310905, 79.44761887192726, 77.45419263839722, 80.57103618979454, 81.10874533653259, 84.46347892284393, 87.30211660265923, 88.70805636048317, 86.77190825343132, 81.21179580688477, 81.33284211158752, 86.20665058493614, 95.49272909760475, 97.5097444653511, 92.00656056404114, 97.09502711892128, 90.43095991015434, 85.32263562083244, 77.16657847166061, 84.65350672602654, 95.51013216376305, 95.90590372681618, 99.27155792713165, 97.97677740454674, 89.9405126273632, 92.80906230211258, 86.5161743760109, 90.98666489124298, 74.89492356777191, 87.79078558087349, 91.81526362895966, 86.62168711423874, 99.84160333871841, 97.31324180960655, 86.91610291600227, 81.91468968987465, 85.22719994187355, 85.91924920678139, 93.3788113296032, 96.33873090147972, 89.99087512493134, 89.53094020485878, 84.5909620821476, 83.71657580137253, 82.00035229325294, 74.97958302497864, 81.98579147458076, 87.63304844498634, 94.64329227805138, 92.22165942192078, 82.28367269039154, 94.23088520765305, 95.80237448215485, 94.17942836880684, 97.89031684398651, 97.86373347043991, 98.86748000979424, 90.45551419258118, 85.0312140583992, 84.91882368922234, 82.63629376888275, 78.7831561267376, 77.8568722307682, 78.44267919659615, 79.3445760011673, 81.69858768582344, 88.02476182579994, 97.60377421975136, 94.00067836046219, 92.04496130347252, 105.04781037569046, 86.65211588144302, 14.806401394307613, 0.8825915842317045, 0.7686124846804887, 0.5508448043838143, 0.7659446122124791, 0.4084555496228859, 0.29049853852484375, 0.12271883839275688, 1.1642021918669343, 23.34723349660635, 58.69499444961548, 67.39356368780136, 107.67726168036461, 91.82201206684113, 101.34813889861107, 87.29509457945824, 44.242766350507736, 41.402791142463684, 40.179085806012154, 58.200074806809425, 85.82857087254524, 85.01802876591682, 105.89013397693634, 37.244871854782104, 0.46123917039949447, 0.15381731966044754, 0.17604096152354032, 0.119967682112474, 0.12204695725813508, 0.21718917618272826, 0.15215024817734957, 0.19727968436200172, 0.17294956021942198, 0.14764793508220464, 0.2462072393973358, 0.11196580875548534, 0.10857634610147215, 0.26887018815614283, 0.24665517004905269, 0.09436987325898372, 0.18262237164890394, 0.11502190609462559, 0.359266001614742, 0.1354016226832755, 0.14933624683180824, 0.10204637423157692, 0.1483229035511613], [0.0854308603447862, 0.007807192250766093, 0.0267379517754307, 0.09402090799994767, 0.1026084620389156, 0.040082464620354585, 0.040509488972020335, 0.02035775272815954, 0.03533099399646744, 0.06117271710536443, 0.028856909557362087, 0.018033917658613063, 0.06656548866885714, 0.03313000292109791, 0.06861230969661847, 0.10342460183892399, 0.07133735722163692, 0.2979748451616615, 1.8273553135804832, 81.90885320305824, 93.56749400496483, 101.97821348905563, 55.78131839632988, 32.10149064660072, 37.43211820721626, 40.061512514948845, 55.06417527794838, 91.4764966070652, 187.96379953622818, 129.89098370075226, 124.79085177183151, 127.35582053661346, 103.16368147730827, 29.655314907431602, 0.48512011708226055, 0.14710293151438236, 0.09469232900300995, 0.06672974821412936, 0.34611318551469594, 0.32641842670273036, 0.5782993999309838, 0.49292341398540884, 1.8593150423839688, 1.0314988251775503, 8.372750021517277, 74.92886334657669, 106.3329166173935, 106.18910193443298, 99.02625069022179, 107.54523396492004, 104.56076771020889, 105.2728570997715, 108.58064040541649, 98.0819633603096, 90.21702378988266, 80.89074343442917, 76.00127220153809, 70.45274153351784, 67.81839609146118, 71.64744302630424, 75.63044250011444, 79.60752189159393, 87.80668392777443, 87.68951341509819, 85.03310635685921, 82.42631703615189, 78.22012513875961, 74.71435725688934, 77.95056760311127, 87.65418291091919, 96.22153759002686, 98.00069332122803, 91.3711054623127, 87.85883232951164, 78.70168849825859, 70.58190420269966, 70.02147987484932, 77.02218621969223, 94.0926942229271, 92.69881501793861, 92.74770319461823, 90.92839881777763, 72.79146283864975, 73.3460582792759, 69.43845435976982, 61.87206856906414, 64.9099713563919, 71.65165320038795, 78.25248420238495, 107.06104874610901, 79.17316719889641, 64.18255358934402, 62.61526308953762, 73.06155994534492, 82.32312217354774, 77.90100306272507, 77.27587580680847, 75.04798695445061, 64.23945933580399, 73.98772224783897, 77.7987353503704, 71.96863979101181, 64.16789397597313, 67.06898510456085, 73.72348442673683, 87.14589938521385, 86.28538995981216, 81.50821790099144, 85.0515353679657, 85.20808696746826, 88.02993714809418, 89.74805295467377, 84.5792207121849, 85.14184132218361, 85.27846679091454, 88.47560003399849, 79.55599665641785, 79.13812547922134, 76.42566382884979, 79.74490731954575, 74.37207162380219, 73.72244328260422, 69.93197947740555, 68.76038834452629, 67.63382479548454, 81.18459686636925, 85.97432345151901, 84.78276818990707, 92.49339044094086, 96.98371589183807, 12.265511937439442, 0.5784357176162302, 0.07535005323006772, 0.1888275277451612, 0.29426185064949095, 0.033875241642817855, 0.1942220953060314, 0.04511843384534586, 1.2919813790358603, 14.767490532249212, 21.82677548378706, 43.56351859867573, 78.69258418679237, 87.1242481470108, 75.79029992222786, 87.80776306986809, 57.48967632651329, 23.617226108908653, 21.99772261083126, 35.946074947714806, 77.0459957420826, 65.77660605311394, 80.33305495977402, 19.498855099081993, 0.4296330898068845, 0.06516465524327941, 0.09421014823601581, 0.04082435625605285, 0.035988121235277504, 0.05222968175075948, 0.029813660366926342, 0.040523582356399857, 0.07117116809240542, 0.06780139461625367, 0.07991966427653097, 0.07368951264652424, 0.018167888301832136, 0.04831760612432845, 0.025664546483312733, 0.05402723763836548, 0.06814650812884793, 0.049921728641493246, 0.05829645328049082, 0.035077865977655165, 0.06507398706162348, 0.139812488341704, 0.06318151048617437, 0.08346445101778954, 0.07819015590939671, 0.09123115261900239, 0.08526494581019506, 0.04022047811304219, 0.040731958870310336, 0.03180542516929563, 0.06837712309788913, 0.011173917355336016, 0.024920061041484587, 0.03815286581811961, 0.03159926025546156, 0.14271501306211576, 0.09276503085857257, 0.08834216467221268, 0.04077883291756734, 0.2533984574256465, 3.1311604706570506, 104.6165943145752, 104.78343576192856, 122.4773383140564, 75.26937827467918, 55.63451707363129, 62.418087869882584, 54.168844521045685, 33.465606048703194, 34.28391873836517, 132.10077792406082, 132.28473365306854, 133.48366051912308, 125.26005819439888, 115.37197798490524, 32.471210807561874, 0.4423518088879064, 0.24361938529182225, 0.10173937742365524, 0.03490214025077876, 0.25259675981942564, 0.6074035819619894, 1.1644302983768284, 1.0455494024790823, 0.6531318125780672, 1.2321734195575118, 11.066654417663813, 91.02025508880615, 112.29691699147224, 111.0092344880104, 103.30131769180298, 109.7345320880413, 105.45197188854218, 108.35772156715393, 110.19395023584366, 102.29337617754936, 92.53143399953842, 83.89652654528618, 77.85881772637367, 72.97997832298279, 71.04895234107971, 75.06182581186295, 79.65264827013016, 83.03648829460144, 89.22474503517151, 92.89964184165001, 87.70020604133606, 87.89286330342293, 79.42018434405327, 76.91919654607773, 80.88027879595757, 88.24471682310104, 98.05092662572861, 100.83170861005783, 96.20576843619347, 92.8916622698307, 79.71193268895149, 72.59613052010536, 73.9497622847557, 83.69741722941399, 95.65281450748444, 96.42192363739014, 95.87557375431061, 94.66870531439781, 78.77516895532608, 77.56629422307014, 76.69339746236801, 74.47965145111084, 69.46195989847183, 79.37994450330734, 86.45953461527824, 103.08865070343018, 85.97443744540215, 68.71684268116951, 71.50307357311249, 79.80903267860413, 88.20545732975006, 81.86024621129036, 80.60276448726654, 80.77362611889839, 69.84083756804466, 78.04815396666527, 82.52828076481819, 77.62176364660263, 70.06295084953308, 72.20528349280357, 76.49370297789574, 90.10276392102242, 87.07689508795738, 86.93745017051697, 89.26259860396385, 89.21215251088142, 90.16768723726273, 91.22527688741684, 88.59630435705185, 90.56671142578125, 90.82612350583076, 92.54031032323837, 84.64979812502861, 85.36348342895508, 79.71073195338249, 85.03531023859978, 78.93120378255844, 76.17391213774681, 72.68887594342232, 75.8037967979908, 70.29925256967545, 82.46170833706856, 91.08639433979988, 90.69093436002731, 89.96037036180496, 104.19079676270485, 20.227505899965763, 0.24583370162872598, 0.17226135183591396, 0.6609063141513616, 0.6699573691003025, 0.08315265251439996, 0.16289372637402266, 0.02664032410393702, 1.4190937019884586, 14.005725458264351, 27.62336254119873, 50.838980600237846, 85.9860648214817, 95.6977204978466, 81.48128494620323, 48.97403307259083, 17.386485747992992, 24.915063567459583, 41.83101296424866, 50.35665728151798, 88.14733564853668, 76.48763090372086, 92.84793421626091, 27.391658574342728, 0.4395089083118364, 0.05691337944881525, 0.055946921347640455, 0.052728994996869005, 0.10992444993462414, 0.0920090643921867, 0.03869849650072865, 0.023427303349308204, 0.02782815929094795, 0.04802666568139102, 0.026491757271287497, 0.09978562913602218, 0.04030466363474261, 0.06315756138064899, 0.026149792320211418, 0.003985109915447538, 0.0988725945353508, 0.06225688353879377, 0.031863553886068985, 0.11194917722605169, 0.04519165042438544, 0.05237640434643254, 0.17567744274856523, 0.2093702051206492, 0.18057523149764165, 0.2158429499831982, 0.30552011216059327, 0.16277456714306027, 0.12856577464845031, 0.16393875936046243, 0.11013671901309863, 0.1850876081152819, 0.07576101750601083, 0.1473638557945378, 0.14558446768205613, 0.26180313143413514, 0.27967514586634934, 0.2358130455831997, 0.2383107881178148, 0.7957110274583101, 5.403717588633299, 123.48284035921097, 117.94890850782394, 129.7781753540039, 75.5168741941452, 46.77851088345051, 54.227053597569466, 57.955459132790565, 76.81958109140396, 118.10780078172684, 227.46663182973862, 167.3787385225296, 130.79702228307724, 141.95428758859634, 126.69103100895882, 48.79275619983673, 0.8236730739008635, 0.348475708742626, 0.26667274825740606, 0.3315225918777287, 0.44351606047712266, 1.0576624399982393, 1.1071608401834965, 2.2868141904473305, 9.889443386346102, 3.414462343789637, 11.169026624411345, 92.24385023117065, 113.0956569314003, 115.72453826665878, 105.11237651109695, 113.9289066195488, 108.65672752261162, 112.45970025658607, 116.29244819283485, 106.98867782950401, 97.03150972723961, 90.08289858698845, 84.98991027474403, 80.04707470536232, 73.54970455169678, 79.40092697739601, 81.89687624573708, 89.11046236753464, 93.471769541502, 93.01227539777756, 88.80542993545532, 91.27307832241058, 82.7263793349266, 81.4313480257988, 83.53922411799431, 95.79048871994019, 97.35955372452736, 100.01021549105644, 101.33337289094925, 96.7859973013401, 85.82305356860161, 75.71578592061996, 77.69947707653046, 89.09546077251434, 102.38634198904037, 102.68053740262985, 101.16514831781387, 99.38194960355759, 83.6262546479702, 86.45239859819412, 87.53970265388489, 85.40229454636574, 79.915601760149, 90.7232478260994, 85.1955096423626, 100.39827346801758, 83.86617377400398, 71.91465988755226, 79.38257396221161, 84.74996834993362, 92.37015545368195, 86.38881281018257, 87.12817713618279, 82.36906930804253, 72.58615225553513, 79.58565026521683, 86.57127141952515, 80.00288307666779, 71.1525271832943, 74.90715131163597, 81.62683233618736, 93.18619966506958, 91.43418207764626, 88.06076869368553, 91.69208943843842, 93.22238132357597, 94.23957914113998, 95.9042090177536, 89.76301655173302, 93.13929498195648, 95.64219027757645, 96.09574154019356, 86.79631814360619, 87.80401647090912, 83.8564082980156, 86.21257826685905, 80.00261709094048, 81.50116547942162, 78.08619752526283, 79.9141426384449, 73.01052868366241, 87.795170545578, 96.69748485088348, 95.50032868981361, 99.79307994246483, 110.12942209839821, 15.422181151807308, 1.5838965587317944, 0.7990192843135446, 0.5707278312183917, 1.7980269435793161, 0.15308801113860682, 0.5430797429289669, 0.17256579565582797, 5.836421744897962, 27.926825657486916, 46.92317672073841, 68.49801242351532, 98.60626682639122, 106.00236475467682, 98.41166406869888, 132.84819781780243, 73.12341302633286, 30.0266195833683, 30.384706668555737, 47.626157999038696, 97.1117690205574, 83.1072860956192, 111.44146889448166, 41.521025598049164, 0.6972095067612827, 0.20010501088108867, 0.22435989609220996, 0.11899576551513746, 0.19779559574089944, 0.1907015248434618, 0.1756228503654711, 0.12442355160601437, 0.24935075431130826, 0.17074411996873096, 0.1559354833443649, 0.20801673555979505, 0.14057065156521276, 0.1877807136042975, 0.10899732937105, 0.12238616327522323, 0.1685445723705925, 0.21747598657384515, 0.1030089842970483, 0.3250061790458858, 0.2307924017077312, 0.23264196730451658], [0.1389254882815294, 0.03414385828364175, 0.05088571168016642, 0.08672350348206237, 0.08010533478227444, 0.14719733269885182, 0.03878117546264548, 0.20249551307642832, 0.0703132527996786, 0.01857495073636528, 0.033875148874358274, 0.037082748240209185, 0.049225171096622944, 0.07776718368404545, 0.03239862009650096, 0.15818751562619582, 0.10198346979450434, 0.118727850203868, 28.182075060904026, 100.48246175050735, 89.5225578546524, 59.45456989109516, 63.552045822143555, 87.42990374565125, 71.29923731088638, 75.72854563593864, 107.2821968793869, 105.25648757815361, 86.15022361278534, 121.69750615954399, 107.71726593375206, 101.93551138043404, 35.83121471107006, 1.1910086846910417, 0.026785176487464923, 0.33548773848451674, 0.07853474991861731, 0.36485538294073194, 0.15795197279658169, 1.0030828812159598, 0.524222661042586, 2.1900181844830513, 0.6691211764700711, 8.316189106553793, 76.886677891016, 98.64390760660172, 103.96726235747337, 99.55467313528061, 107.00377061963081, 99.92935582995415, 98.37614357471466, 98.2137630879879, 99.94830161333084, 95.71617230772972, 88.69044810533524, 76.1717614531517, 72.83595845103264, 74.55793485045433, 77.06814095377922, 78.39609369635582, 85.51979944109917, 89.58125710487366, 88.687165081501, 92.7914996445179, 84.57953229546547, 80.73373585939407, 72.51098468899727, 73.27656760811806, 77.03369960188866, 85.3906823694706, 88.38289260864258, 94.44312661886215, 89.99189347028732, 84.82250645756721, 73.68102550506592, 69.68365520238876, 67.28318721055984, 77.5446429848671, 80.11458948254585, 88.10407117009163, 81.46027207374573, 76.39018133282661, 88.21488082408905, 74.17276471853256, 72.96218767762184, 79.68401938676834, 65.15364468097687, 85.47797128558159, 82.37432822585106, 79.59975510835648, 73.3652700483799, 55.34848362207413, 69.1712374985218, 67.01936736702919, 78.9705240726471, 74.33801785111427, 79.29173603653908, 71.15992918610573, 75.44541522860527, 72.35365033149719, 78.01556691527367, 72.60974898934364, 68.84286671876907, 61.48108474910259, 65.32392114400864, 70.72014838457108, 76.37125074863434, 78.33336666226387, 81.6895517706871, 82.63678774237633, 78.89564529061317, 81.75312235951424, 85.18550097942352, 88.12418729066849, 82.35010832548141, 86.35117202997208, 82.49765440821648, 83.86829406023026, 84.52448084950447, 79.13074627518654, 83.64825546741486, 75.8941787481308, 72.52733901143074, 72.35504105687141, 69.91235733032227, 68.05890038609505, 72.6884351670742, 85.91654375195503, 85.98570764064789, 87.63186290860176, 94.79141592979431, 3.0834910785779357, 0.8683076757006347, 0.24343595607206225, 0.11264621716691181, 0.11268714661127888, 0.09062731900485232, 0.060011218884028494, 0.05032174252846744, 3.5464154882356524, 6.208081701770425, 5.490952832624316, 33.93497586250305, 74.53094869852066, 86.18927031755447, 68.61069917678833, 107.68955782055855, 88.60110729932785, 29.12067599594593, 29.36904776841402, 40.70492058992386, 67.20428064465523, 58.13795194029808, 69.79615196585655, 6.7745505552738905, 0.16939421271672472, 0.10940890962956473, 0.13433009502477944, 0.06555797124747187, 0.09369546882226132, 0.09079578652745113, 0.01878709179436555, 0.0759255739103537, 0.08570926962420344, 0.011785175229306333, 0.05489637791470159, 0.05358833150239661, 0.05696688458556309, 0.06631847223616205, 0.034849095245590433, 0.1225013668590691, 0.021431725763250142, 0.012006977194687352, 0.03575721682864241, 0.21669667214155197, 0.04305465845391154, 0.059099275240441784, 0.10512352630030364, 0.03588314444641583, 0.09022120095323771, 0.022858786687720567, 0.05518266880244482, 0.1187898863281589, 0.029888333410781343, 0.025385868175362702, 0.038322442851495, 0.07906585306045599, 0.024053753913904075, 0.08320061751874164, 0.07547024404630065, 0.03911721993063111, 0.08544297219486907, 0.16768871282693, 0.21417405281681567, 38.663191348314285, 115.34718051552773, 101.3172921538353, 80.33335894346237, 83.72432738542557, 71.25506848096848, 45.30346043407917, 50.25409318506718, 50.6157273799181, 95.43592974543571, 104.6360644698143, 127.00819998979568, 111.41344919800758, 115.21083623170853, 41.77973471581936, 0.8858022338245064, 0.014569797731383005, 0.041891813234542497, 0.14861437462968752, 0.43717126187402755, 0.29999808815773576, 1.9430124387145042, 0.7223544793669134, 0.8492380427196622, 0.5879781336989254, 12.502211686223745, 90.61173141002655, 105.73013216257095, 108.30414444208145, 103.85250091552734, 109.77922528982162, 103.04224759340286, 102.66786888241768, 101.88416853547096, 103.57401385903358, 98.19531127810478, 91.89701244235039, 80.08289158344269, 75.61237826943398, 79.9814522266388, 82.16891884803772, 81.87857642769814, 90.50781458616257, 92.95933663845062, 94.09706398844719, 96.4179490506649, 89.65972289443016, 84.78026792407036, 74.6652714908123, 74.9803201854229, 78.52723225951195, 87.14370310306549, 91.52266412973404, 96.90234705805779, 92.00326234102249, 89.12211254239082, 78.5454560816288, 73.11174765229225, 68.98205325007439, 81.17660969495773, 83.45347791910172, 91.56023651361465, 85.643140822649, 77.92286708950996, 88.54376837611198, 80.0633454322815, 81.89216449856758, 87.13382363319397, 76.9916282594204, 88.44769433140755, 89.67524126172066, 83.07413667440414, 77.60684564709663, 62.8423997014761, 72.84273728728294, 76.23087108135223, 84.64784502983093, 77.34841391444206, 83.5085141658783, 74.05227318406105, 78.72796028852463, 77.9477709531784, 82.61546328663826, 76.5745322406292, 73.97617846727371, 67.35418260097504, 68.60798612236977, 72.44250476360321, 77.84339055418968, 80.39706632494926, 86.21979787945747, 84.85213726758957, 81.26822277903557, 84.16980028152466, 86.98542639613152, 89.62106376886368, 86.19893699884415, 87.90052369236946, 88.33864018321037, 86.83291777968407, 89.64627161622047, 81.98912009596825, 86.84858813881874, 79.33553248643875, 78.20059418678284, 74.33594316244125, 75.36087736487389, 73.13952416181564, 77.23951935768127, 86.55820772051811, 93.93428072333336, 85.489302277565, 103.94269287586212, 7.455609859898686, 0.7486205699387938, 0.8476665301714092, 0.39825229556299746, 0.188379226019606, 0.03701876768900547, 0.06170397980895359, 0.04434412890987005, 1.761834123171866, 6.214405037462711, 7.298805573955178, 42.39799574017525, 81.55271351337433, 94.85095113515854, 78.18342670798302, 67.47933268547058, 33.492474406957626, 26.029078289866447, 46.940177008509636, 61.56896263360977, 80.47079756855965, 67.84548103809357, 84.04642090201378, 11.078700721263885, 0.2249845172627829, 0.12475944764446467, 0.07892663357779384, 0.03955100524763111, 0.04355665827461053, 0.08580535548389889, 0.03181365558702964, 0.08536421548342332, 0.07382807903923094, 0.08135695941746235, 0.0898299778054934, 0.020312965971243102, 0.06919259496498853, 0.0778234533208888, 0.01902972213429166, 0.05108188357553445, 0.05241600905719679, 0.10674079225282185, 0.059484093653736636, 0.08626677095890045, 0.0643891554500442, 0.30680848052725196, 0.2680524898460135, 0.1666944130556658, 0.17289974726736546, 0.18950761703308672, 0.17928100016433746, 0.24208900256780908, 0.3307575860526413, 0.1140622646198608, 0.12592819664860144, 0.16117354680318385, 0.13322022801730782, 0.28621495119296014, 0.2325754115008749, 0.17788329860195518, 0.2180088040768169, 0.2488805740722455, 0.29978369653690606, 52.854681238532066, 128.59928101301193, 110.71273639798164, 78.59496742486954, 83.64900022745132, 112.11470916867256, 85.5714462697506, 95.54872289299965, 143.7346288561821, 143.2908734679222, 103.00687909126282, 132.1806800365448, 124.67096820473671, 126.98116064071655, 58.7251952290535, 2.259720219299197, 0.09200785469147377, 0.7792097004130483, 0.24592540139565244, 0.6441147183068097, 0.9480310196522623, 1.9964416092261672, 2.370586870238185, 5.521323177963495, 5.1130944583565, 11.512160561978817, 92.76658058166504, 107.41817638278008, 109.59234371781349, 110.35427123308182, 114.13357123732567, 109.45342317223549, 107.31344640254974, 106.1179469525814, 107.81953364610672, 105.13447612524033, 97.6743820309639, 85.57922825217247, 79.31592553853989, 83.57474461197853, 85.21886318922043, 86.36220663785934, 91.95784717798233, 98.3675104379654, 95.69819167256355, 100.37610545754433, 92.01729118824005, 89.89858567714691, 79.64551225304604, 79.30108353495598, 83.94785419106483, 90.4599903523922, 95.38351535797119, 98.17035421729088, 95.47404170036316, 91.55932456254959, 81.63524508476257, 78.04893672466278, 72.49624148011208, 86.40972688794136, 88.01349923014641, 99.00042727589607, 89.45717856287956, 90.3722682595253, 97.4135260283947, 86.87509551644325, 86.65118113160133, 94.2032378911972, 83.13621014356613, 94.15942624211311, 86.84875532984734, 83.6374868452549, 77.55192339420319, 69.38290134072304, 83.48447665572166, 79.01604562997818, 90.5161665380001, 80.30976220965385, 89.64523807168007, 78.84396806359291, 83.00476759672165, 81.54349520802498, 86.78104296326637, 80.35612732172012, 75.95293119549751, 68.45909491181374, 70.86622774600983, 78.22446450591087, 85.12658134102821, 87.19248488545418, 90.09303644299507, 88.8509438931942, 88.66197243332863, 89.73005712032318, 92.30066478252411, 96.72749564051628, 89.24217849969864, 91.03593304753304, 90.29510959982872, 92.71084517240524, 90.81391856074333, 84.25666362047195, 91.58317968249321, 81.51398599147797, 79.5687335729599, 79.46689903736115, 79.28911417722702, 76.17239221930504, 80.10531798005104, 94.67612251639366, 97.37860590219498, 93.77369374036789, 110.68742215633392, 5.657616639509797, 3.0403833417221904, 1.74888952402398, 0.5032474896870553, 0.48102405562531203, 0.12752077134791762, 0.15836484439205378, 0.31337423133663833, 6.045779585838318, 11.335305701941252, 22.394396625459194, 60.15529029071331, 95.61208069324493, 103.98257553577423, 88.67676883935928, 154.05522465705872, 115.77826738357544, 36.96608081459999, 42.05044738948345, 54.222243055701256, 89.59315046668053, 77.06865012645721, 100.66761821508408, 20.240172520279884, 0.28233577497303486, 0.21325788635294884, 0.17590848816325888, 0.21355156903155148, 0.18685521092265844, 0.2604738558875397, 0.13590416056104004, 0.22971478843828663, 0.1575446969945915, 0.16006039950298145, 0.15176538523519412, 0.18005428835749626, 0.13639843091368675, 0.18890088162152097, 0.09081932745175436, 0.1921080134343356, 0.15571506548440084, 0.19974342169007286, 0.12393708122544922, 0.42109076224733144, 0.13259623025078326], [0.08138643752317876, 0.10065481765195727, 0.0776288473571185, 0.03963589209888596, 0.21471390587976202, 0.08405146014411002, 0.03140049084322527, 0.026630208631104324, 0.04531054990366101, 0.030673889305035118, 0.03153763973386958, 0.045086877726134844, 0.017204656687681563, 0.0754683515697252, 0.12508651212556288, 0.0388683481287444, 0.18011846928857267, 1.3440673216246068, 74.84773769974709, 95.95498949289322, 77.93682754039764, 87.50716879963875, 42.89905205368996, 97.12906569242477, 166.51560723781586, 109.61008876562119, 83.68664100766182, 68.03926303982735, 99.34044823050499, 108.81961718201637, 99.33661043643951, 50.08783310651779, 3.7558186892420053, 0.19588916678912938, 0.0643471944204066, 0.17433246335713193, 0.059114953110110946, 0.17073322524083778, 0.285666860290803, 0.7671679090708494, 1.3282665819860995, 1.1824293388053775, 2.340480135753751, 61.09149545431137, 100.18017277121544, 100.2335675060749, 100.14588341116905, 96.95703372359276, 94.87109765410423, 95.13941645622253, 93.83143544197083, 90.32148018479347, 87.51335486769676, 83.55395212769508, 77.76257649064064, 74.89246889948845, 76.1937090754509, 80.17141923308372, 80.59804514050484, 85.31792387366295, 88.1284810602665, 91.31212502717972, 89.19553980231285, 86.44678249955177, 90.35712987184525, 82.62943893671036, 69.58582565188408, 70.54076001048088, 74.05426427721977, 82.61431574821472, 85.84558635950089, 88.91504645347595, 91.44336998462677, 85.21467581391335, 71.46231696009636, 65.57609841227531, 63.10770906507969, 70.86935117840767, 74.85175788402557, 80.75541749596596, 85.83693042397499, 62.96464294195175, 80.28093695640564, 79.54632997512817, 69.65083256363869, 80.41335225105286, 77.73316606879234, 88.73078674077988, 69.2208856344223, 65.57873547077179, 57.077204659581184, 44.37400370836258, 64.76820856332779, 70.69872513413429, 79.05604228377342, 74.72631901502609, 77.95860797166824, 69.59791660308838, 69.25148159265518, 77.29324087500572, 79.10416290163994, 70.56960806250572, 68.57188805937767, 63.56688402593136, 65.22602319717407, 64.5132802426815, 68.10715779662132, 63.318115174770355, 67.38380581140518, 67.12687879800797, 72.70812571048737, 71.80428341031075, 73.71415212750435, 76.05482652783394, 82.67924666404724, 80.05207523703575, 82.90306985378265, 81.57720699906349, 87.69993245601654, 83.47417920827866, 84.2515566945076, 78.49409803748131, 75.73868349194527, 66.546201556921, 65.5549031496048, 64.40452247858047, 72.87033900618553, 70.23351609706879, 86.12055480480194, 81.83617830276489, 98.58577072620392, 49.3528613448143, 0.5510277883149683, 1.0696339351125062, 1.4600826962850988, 0.11111378611531109, 0.1717269906657748, 0.07036346651148051, 0.0355487586784875, 0.6988636055029929, 0.5753833532799035, 0.6950575159862638, 1.996140475384891, 34.02191139757633, 79.14979845285416, 95.87815761566162, 69.21695664525032, 83.24331879615784, 59.74421314895153, 16.93919274955988, 24.602499939501286, 32.78849758207798, 68.19465190172195, 66.37518793344498, 64.08087864518166, 3.8338838377967477, 0.17724542267387733, 0.03557487856596708, 0.052161233470542356, 0.03258394179283641, 0.05575008151936345, 0.026549110443738755, 0.06817692876211368, 0.07321936951484531, 0.032565963265369646, 0.02855315036867978, 0.03480705629044678, 0.03888476814609021, 0.019689298460434657, 0.02111626476107631, 0.0660553363559302, 0.017742652526067104, 0.043489705421961844, 0.03839929966488853, 0.08279692629002966, 0.08158526630722918, 0.022298160911304876, 0.03658737950900104, 0.027815850771730766, 0.09688564256066456, 0.12237580289365724, 0.020800380734726787, 0.04454851266928017, 0.08595935854827985, 0.02910344730480574, 0.03018978823092766, 0.025003420923894737, 0.05906170772504993, 0.03249526627769228, 0.0972191414621193, 0.060458934312919155, 0.020595618480001576, 0.26539212791249156, 1.9173316354863346, 89.95422229170799, 107.02090010046959, 92.50631734728813, 92.78611153364182, 59.56492356956005, 111.06657341122627, 129.96573328971863, 57.63602927327156, 80.44891834259033, 75.76007634401321, 103.4576641023159, 119.4873471558094, 110.72049558162689, 59.732992351055145, 3.2858990924432874, 0.07781717475154437, 0.07624297562870197, 0.19590521202189848, 0.5079967598430812, 0.2774770528776571, 0.7789344526827335, 1.556596567388624, 1.0892032412812114, 2.0221104193478823, 5.705711608752608, 74.81797769665718, 109.37053442001343, 105.84870859980583, 104.6268081665039, 102.04356998205185, 96.90454334020615, 98.33349466323853, 96.1865946650505, 91.77343547344208, 88.145382553339, 86.82974874973297, 79.57429647445679, 78.38618382811546, 79.0639990568161, 84.01653170585632, 82.71147653460503, 88.72953280806541, 92.03339472413063, 98.17897215485573, 93.76318350434303, 93.43547388911247, 95.60830369591713, 84.11247655749321, 72.78826341032982, 72.73443549871445, 74.90766808390617, 87.13000103831291, 88.73264864087105, 96.79587677121162, 94.34513747692108, 88.61420139670372, 76.21637105941772, 69.31347906589508, 68.32758396863937, 73.49996522068977, 81.09106108546257, 86.59512653946877, 91.22355937957764, 72.59837999939919, 81.92714542150497, 84.19801756739616, 77.34405934810638, 87.8930912911892, 84.12251561880112, 90.5466029047966, 76.4621114730835, 72.83611044287682, 63.28657306730747, 52.28983394801617, 69.8914660513401, 75.44590160250664, 82.2035425901413, 80.15238225460052, 80.57663708925247, 74.48953092098236, 72.28764787316322, 83.63239511847496, 82.73951143026352, 75.8776344358921, 71.95901870727539, 69.52788636088371, 70.4211500287056, 69.55345138907433, 71.7118951678276, 66.62712961435318, 70.62387675046921, 70.64723789691925, 76.53587311506271, 75.4693691432476, 77.03007459640503, 77.4227987229824, 86.53217151761055, 83.72121155261993, 85.6666387617588, 87.22026899456978, 90.13418063521385, 87.5201641023159, 86.31776422262192, 83.04102525115013, 78.14438760280609, 72.53122240304947, 68.76943945884705, 69.20529127120972, 76.2346176803112, 72.52776458859444, 84.8531936109066, 87.80895620584488, 96.40057638287544, 61.616669073700905, 0.3164588939398527, 1.4973083487711847, 1.464271021541208, 0.3704893821850419, 0.26095954701304436, 0.04403995226311963, 0.050624698342289776, 0.6345483753830194, 0.8315610350109637, 0.49676438444294035, 2.4707357212901115, 39.65031757950783, 86.28155216574669, 101.65051147341728, 86.44527018070221, 66.75565391778946, 24.049950689077377, 28.12430676072836, 40.24077549576759, 47.86716766655445, 78.91897603869438, 74.4055326282978, 78.1083807349205, 5.522082662209868, 0.19941347767598927, 0.05114106243127026, 0.02918963105912553, 0.028818982100347057, 0.09397393005201593, 0.03417254600208253, 0.04479200018977281, 0.045144579707994126, 0.021732174973294605, 0.0495814168243669, 0.04228308462188579, 0.05492403775861021, 0.003990835584772867, 0.0976691946561914, 0.052515727729769424, 0.013054491737420904, 0.011037999502150342, 0.03463613596977666, 0.03377686625753995, 0.0628644204698503, 0.12317329994402826, 0.1689139541122131, 0.12706117413472384, 0.1144156679220032, 0.2717537881108001, 0.17426230071578175, 0.13655946211656556, 0.13697175483684987, 0.17378434276906773, 0.1473235126468353, 0.1586890738690272, 0.15289868926629424, 0.13333720533410087, 0.3219042392447591, 0.2897066966397688, 0.21142151614185423, 0.3408041875809431, 3.6821831529960036, 110.16042843461037, 120.89014828205109, 99.6068823337555, 110.22257789969444, 61.070596575737, 109.2292732000351, 182.10749298334122, 142.38319337368011, 111.17595434188843, 88.72736692428589, 127.69230008125305, 133.53799760341644, 118.50681737065315, 79.6531194448471, 8.10630451887846, 0.5048912577331066, 0.2447465740260668, 0.3091413772199303, 0.6539095239713788, 1.0225443681702018, 1.667462862096727, 2.7726254845038056, 6.1530673038214445, 5.044581759721041, 4.965300438925624, 79.2961286008358, 112.80586168169975, 106.35799527168274, 110.87935745716095, 107.64769166707993, 103.01477506756783, 103.03954973816872, 100.71217462420464, 95.16226842999458, 96.39458790421486, 90.25741562247276, 84.34209823608398, 83.00833940505981, 83.96053791046143, 87.21371814608574, 87.16327965259552, 92.78330728411674, 96.88378885388374, 99.5605856180191, 97.26892098784447, 96.03984653949738, 97.83452063798904, 89.05996307730675, 79.00470703840256, 77.27706134319305, 79.20299559831619, 88.45392599701881, 93.85781362652779, 95.89394956827164, 98.81832584738731, 92.65611290931702, 78.85748773813248, 72.75142818689346, 70.35226732492447, 77.90915742516518, 84.64472159743309, 91.3211153447628, 95.18143460154533, 76.67866945266724, 88.0652828514576, 92.29919046163559, 81.90280392765999, 93.00244152545929, 89.96532529592514, 97.64957696199417, 77.25303903222084, 71.80464059114456, 67.40030452609062, 61.18396729230881, 79.21661406755447, 80.39714232087135, 84.33978036046028, 82.67833471298218, 84.97157245874405, 77.41114854812622, 78.23316603899002, 83.64874184131622, 86.51948779821396, 77.49086067080498, 74.4446249306202, 72.6982082426548, 72.28228256106377, 69.53848779201508, 76.17277979850769, 72.17591866850853, 76.52322739362717, 74.69853490591049, 78.77643048763275, 78.77019882202148, 81.06783673167229, 81.90794125199318, 89.5829214155674, 89.20019835233688, 89.75541695952415, 91.02452605962753, 93.52942764759064, 90.26589676737785, 88.80445718765259, 84.26870137453079, 82.5193740427494, 74.85145390033722, 72.56635531783104, 74.17513579130173, 80.78711539506912, 76.40231788158417, 92.86080792546272, 90.78605085611343, 105.30311867594719, 62.584765926003456, 1.0161419492214918, 4.928609132766724, 2.0307893911376595, 1.2208659388124943, 0.6240129063371569, 0.3783378907246515, 0.23823896306566894, 1.9544592057354748, 2.29024825617671, 2.2458360018208623, 8.4227410890162, 52.50628553330898, 102.66783088445663, 114.37616541981697, 92.82026410102844, 117.26181417703629, 81.6266119480133, 21.89643334597349, 32.775768265128136, 48.80383640527725, 90.95973953604698, 84.21154484152794, 97.80620455741882, 11.627712361514568, 0.38279077678453177, 0.24148648255504668, 0.2918686025077477, 0.0823591927473899, 0.285186868859455, 0.15120605821721256, 0.1455190993146971, 0.11720870359567925, 0.14354540209751576, 0.14850229548756033, 0.0979924741841387, 0.19993119989521801, 0.09997306595323607, 0.15113706816919148, 0.16159060411155224, 0.17054995929356664, 0.06572693600901403, 0.16039310430642217, 0.15090134722413495, 0.3150797460693866], [0.0456278365891194, 0.07287474581971765, 0.09294153584050946, 0.047866766253719106, 0.07081901901983656, 0.05021534823754337, 0.031583074014633894, 0.0554375668434659, 0.03448638912232127, 0.026936910435324535, 0.03081468585151015, 0.05538256256841123, 0.06630805248278193, 0.09432219027075917, 0.04527196935669053, 0.04006892784673255, 0.25812685838900506, 10.851129982620478, 95.35036593675613, 80.14551222324371, 71.57167509198189, 61.12371772527695, 71.77291989326477, 15.278653353452682, 30.80315161496401, 74.8943156003952, 85.79884126782417, 129.2102426290512, 114.09374177455902, 98.71219754219055, 38.70114751160145, 4.738250747323036, 0.22673307656077668, 0.08656714780954644, 0.06325023336103186, 0.08383181411772966, 0.1926892189658247, 0.7317650900222361, 0.14127754722721875, 1.9140535988844931, 0.4052774060983211, 2.872396493330598, 53.14911983907223, 102.80255645513535, 102.67662361264229, 101.99424862861633, 90.73647111654282, 87.64368787407875, 83.16632732748985, 81.07617348432541, 77.40644440054893, 72.66183659434319, 72.25007548928261, 74.97230261564255, 73.46376836299896, 79.05806377530098, 79.96503710746765, 89.39642742276192, 88.38465571403503, 89.6450100839138, 89.5629420876503, 94.86910656094551, 86.73260316252708, 88.9365305006504, 83.70263814926147, 72.26496309041977, 67.6155173778534, 67.86653190851212, 74.45743024349213, 84.80261072516441, 83.59680622816086, 89.47716549038887, 89.73364412784576, 80.76120838522911, 72.47759208083153, 64.9064527451992, 63.425827994942665, 62.3012251406908, 68.50722312927246, 79.11189168691635, 80.60456559062004, 93.81695821881294, 81.7073880136013, 78.90394404530525, 72.69330650568008, 79.55444633960724, 74.87381190061569, 74.55153599381447, 52.57923781871796, 50.289465487003326, 46.49120070040226, 41.82237222790718, 70.31587287783623, 66.34564071893692, 74.50161427259445, 78.95248264074326, 75.86735978722572, 73.17252159118652, 74.53636720776558, 77.65798330307007, 81.3772389292717, 75.91726630926132, 67.43323355913162, 62.249183133244514, 68.2688695192337, 77.58470043540001, 72.78925135731697, 59.767524898052216, 60.563969761133194, 58.81473742425442, 66.29093885421753, 63.70405666530132, 67.91388496756554, 72.7499158680439, 75.27826219797134, 76.81444376707077, 77.90547922253609, 81.23210191726685, 81.92567110061646, 80.63987329602242, 80.27066230773926, 79.06462982296944, 71.91884726285934, 68.78064125776291, 66.48997977375984, 64.49829384684563, 65.6597775220871, 73.29970836639404, 71.5264119207859, 81.52343228459358, 86.9458781182766, 88.2490485906601, 4.366471571847796, 0.8660307666286826, 2.975109494291246, 0.13789140939479694, 0.017037614088621922, 0.05482912820298225, 0.054105716044432484, 0.41180106229148805, 1.9612020626664162, 0.11568061410798691, 0.29868635698221624, 0.6167022767476737, 28.961783722043037, 71.28624960780144, 82.29998901486397, 65.06412148475647, 69.22478422522545, 54.48841877281666, 22.27263405919075, 27.33625564724207, 50.46647138893604, 57.76236489415169, 73.98106500506401, 33.82997989654541, 2.180937146767974, 0.025827392237260938, 0.1271397972595878, 0.06719750905176625, 0.044526849378598854, 0.03427529263717588, 0.08619856758741662, 0.09048305291798897, 0.036159267910989, 0.04124577739275992, 0.06813034415245056, 0.06700014229863882, 0.03942725212255027, 0.05840597572387196, 0.05664523036102764, 0.007027563797237235, 0.060282403355813585, 0.005574306915150373, 0.07571348294732161, 0.03549603279680014, 0.03939571455703117, 0.04699957040429581, 0.035477300989441574, 0.039035795198287815, 0.07873896669480018, 0.021392386370280292, 0.029128752685210202, 0.10892983103985898, 0.06386643115547486, 0.06438110314775258, 0.04329532581323292, 0.08967562593170442, 0.056154897101805545, 0.09924237703671679, 0.13745033618761227, 0.04577991749101784, 0.4212742211529985, 16.319837383925915, 115.56039467453957, 90.00944092869759, 89.84599649906158, 73.91092076897621, 42.8656442463398, 28.104279935359955, 43.68974022567272, 69.53795582056046, 93.71113389730453, 128.79960626363754, 122.81450942158699, 107.84028053283691, 47.400526106357574, 6.282483134418726, 0.15425484540173784, 0.05806297362141777, 0.07300308541744016, 0.10216580805717967, 0.2715655497740954, 0.6994928873609751, 0.4935474711237475, 2.2508918680250645, 0.1839385853963904, 5.257775019854307, 62.927344143390656, 114.26321268081665, 106.94569453597069, 105.56615576148033, 95.06482645869255, 91.06146767735481, 86.02012619376183, 82.31677651405334, 79.13763150572777, 77.14093744754791, 76.34198471903801, 78.11097979545593, 76.54428586363792, 82.48861089348793, 83.13202276825905, 94.11197438836098, 92.00319394469261, 95.11412501335144, 95.50515443086624, 96.151172965765, 89.27646785974503, 93.414825797081, 87.49165803194046, 75.96949830651283, 69.92706254124641, 70.5093052983284, 76.34281307458878, 86.84713661670685, 86.97853356599808, 93.34414958953857, 91.55863299965858, 85.86304262280464, 76.20713755488396, 69.84511613845825, 68.19987282156944, 67.35923632979393, 72.89959743618965, 82.5054743885994, 83.0833625793457, 95.19294798374176, 84.69994783401489, 86.78795859217644, 78.64448636770248, 85.92839151620865, 79.69994813203812, 76.80252760648727, 60.606709867715836, 58.44251699745655, 54.71594676375389, 55.536535531282425, 77.16251268982887, 72.9452557861805, 76.85244172811508, 80.9409311413765, 79.62889194488525, 75.80995246767998, 76.6871277987957, 82.2627130150795, 86.37815818190575, 79.81262728571892, 70.82601070404053, 67.30440527200699, 73.49884048104286, 81.61044761538506, 78.37348490953445, 64.59917843341827, 64.06916007399559, 62.436885461211205, 70.48899158835411, 67.23155558109283, 69.91232693195343, 77.04346507787704, 77.87370532751083, 81.4552715420723, 81.75911843776703, 86.12502336502075, 83.02768796682358, 84.2116816341877, 86.6101585328579, 83.37906271219254, 76.7952547967434, 72.88543939590454, 69.2819407582283, 67.64627292752266, 68.58504295349121, 78.38050693273544, 75.39189130067825, 83.30850049853325, 89.90008279681206, 94.11325871944427, 6.981180617585778, 0.9265784395392984, 3.5829543275758624, 0.1585038041230291, 0.08273280473076738, 0.022886420556460507, 0.07619466181495227, 0.8554079022724181, 2.4665096355602145, 0.21320071129593998, 0.24545118387322873, 0.5391763430088758, 34.306911304593086, 81.13140732049942, 84.05349612236023, 72.69615635275841, 49.98261295258999, 22.47260022908449, 32.73957520723343, 44.13556270301342, 64.95312944054604, 68.79142507910728, 84.07646968960762, 45.52118495106697, 1.759523015934974, 0.035871103100362234, 0.19310307019622996, 0.03865212340315338, 0.08527399259037338, 0.014556166333932197, 0.04382117826025933, 0.03817265147517901, 0.05012105466448702, 0.02088235651171999, 0.048843603290151805, 0.022535544267157093, 0.022671132792311255, 0.054824215185362846, 0.013678227896889439, 0.037636453489540145, 0.07657956928596832, 0.02219682250142796, 0.05060188843344804, 0.029233165441837627, 0.17237216932699084, 0.19954317540396005, 0.1061092023155652, 0.2102707716403529, 0.28266148874536157, 0.15210497716907412, 0.1280267973197624, 0.2352308455738239, 0.11883145401952788, 0.19253470381954685, 0.32136178866494447, 0.28257608239073306, 0.18219526566099375, 0.22112285572802648, 0.2721295820083469, 0.11104323755716905, 0.7314998167566955, 23.29622123390436, 134.40451830625534, 99.70053970813751, 97.72501051425934, 76.82706668972969, 97.7447846531868, 25.1125218719244, 44.364207834005356, 101.7226392030716, 105.02681270241737, 153.27836394309998, 132.4525022506714, 119.75373566150665, 69.67890545725822, 15.948508009314537, 0.44779688701964915, 0.29260638635605574, 0.3531944321002811, 0.3694269829429686, 1.3574082870036364, 1.6909433458931744, 0.9043236274737865, 6.442214688286185, 4.013979686424136, 4.640799276530743, 58.636036813259125, 117.0772048830986, 110.06155014038086, 110.31023919582367, 98.46190497279167, 97.23634913563728, 91.5124274790287, 88.23744401335716, 84.50477510690689, 81.01068019866943, 80.50495773553848, 82.47170180082321, 81.30412325263023, 86.55838251113892, 86.71499490737915, 97.26434603333473, 97.43673518300056, 98.47718015313148, 96.11303821206093, 100.36089107394218, 94.13090497255325, 97.47357800602913, 93.11404913663864, 80.49866527318954, 73.50596129894257, 75.09228497743607, 80.27886226773262, 91.34706795215607, 89.85700070858002, 95.34500822424889, 94.2473991215229, 90.41179373860359, 77.80024766921997, 73.459512591362, 71.99293568730354, 69.67429250478745, 75.58185830712318, 86.71334579586983, 88.3112208545208, 100.94587728381157, 89.99357298016548, 93.16109821200371, 85.5856803059578, 94.85933348536491, 85.85976719856262, 88.18030267953873, 63.53307344019413, 64.20926615595818, 58.65054823458195, 61.305279582738876, 87.12018996477127, 79.46882173418999, 82.65052020549774, 88.85279819369316, 84.42217513918877, 80.15161469578743, 80.54346486926079, 86.19367808103561, 88.03359255194664, 82.51074090600014, 72.71048918366432, 68.73782515525818, 76.69096559286118, 84.49279054999352, 81.81720972061157, 66.9644983112812, 67.78669819235802, 65.44189721345901, 75.48579186201096, 72.70071610808372, 73.33640679717064, 80.98702266812325, 82.12592795491219, 85.97103282809258, 85.60886666178703, 90.86631774902344, 86.88925355672836, 87.2611927986145, 87.81116768717766, 86.4854796230793, 78.55824619531631, 78.03980961441994, 74.27946299314499, 70.71593821048737, 71.11727267503738, 83.01277756690979, 78.77469018101692, 89.35806468129158, 95.9620875120163, 101.53482288122177, 7.193603469058871, 1.6188897122628987, 9.406830333173275, 0.8003579406067729, 0.17329305585008115, 0.3223419579444453, 0.21291428682161495, 1.2031761067919433, 4.032579688355327, 0.2743733616080135, 0.46228019578848034, 1.6303485911339521, 47.20003366470337, 95.6592209637165, 96.98953717947006, 81.46300792694092, 100.75646504759789, 69.06175017356873, 30.745763294398785, 38.959343656897545, 65.54655879735947, 81.945521235466, 92.9520334303379, 70.29294490814209, 3.923233193345368, 0.14692543947603554, 0.25328576972242445, 0.42704964405857027, 0.20747238508192822, 0.15274794423021376, 0.1561257551657036, 0.25785552919842303, 0.20684374147094786, 0.1559987143264152, 0.16310338309267536, 0.1522695113089867, 0.19550808880012482, 0.1594860662589781, 0.1523105669184588, 0.169634104531724, 0.16195661650272086, 0.125471449282486, 0.22026140039088205, 0.11612609567237087], [0.01488532923758612, 0.04250847858202178, 0.07629238782101311, 0.01818636777898064, 0.02540647761634318, 0.05240278027486056, 0.03577028233848978, 0.04656101678847335, 0.02441289216221776, 0.00590723807363247, 0.03410719247767702, 0.03913006279617548, 0.05568049404246267, 0.01302657956330222, 0.08451182919088751, 0.02357413170102518, 0.2149169723270461, 51.01937972009182, 94.38203349709511, 84.21727493405342, 78.57028394937515, 68.39987888932228, 60.36562040448189, 39.831294268369675, 45.29342137277126, 75.42976006865501, 116.59013941884041, 105.37308812141418, 97.99951538443565, 24.488604851067066, 1.691790937911719, 0.6389535265043378, 0.10397890451713465, 0.11228608258534223, 0.14990011579357088, 0.5165849521290511, 0.5265360837802291, 0.15547357063042, 0.8747550391126424, 0.6006860174238682, 2.4147659121081233, 39.74518708884716, 98.03748294711113, 109.10856127738953, 103.21690902113914, 97.39347830414772, 86.77736476063728, 78.29103693366051, 74.35024559497833, 70.71730613708496, 73.70560258626938, 67.63059496879578, 76.82982534170151, 74.86706346273422, 80.8557017147541, 84.03535589575768, 86.88762724399567, 93.04210379719734, 94.54871535301208, 94.23563495278358, 90.94671383500099, 88.05063843727112, 85.32983243465424, 79.37082499265671, 72.13941782712936, 63.41643489897251, 66.8940956890583, 69.11417216062546, 79.80541527271271, 83.37325662374496, 85.15523180365562, 86.84088975191116, 89.73567321896553, 81.11807763576508, 73.70152160525322, 65.74781879782677, 63.402444049715996, 65.07404655218124, 69.51479986310005, 75.46135917305946, 79.14039015769958, 82.3061066865921, 72.74283304810524, 70.12157410383224, 69.45825889706612, 75.13207644224167, 69.70046550035477, 63.65024775266647, 40.0543574988842, 29.77182425558567, 42.07581862807274, 56.77989721298218, 67.8183200955391, 72.33285024762154, 77.52649515867233, 69.61832910776138, 77.22540691494942, 70.59726297855377, 72.0584137737751, 70.57180434465408, 80.6474044919014, 78.1876140832901, 67.646903693676, 67.5831887125969, 68.60436111688614, 77.99076944589615, 77.42872640490532, 72.98665076494217, 62.32487127184868, 60.95196694135666, 59.285554960370064, 60.569399669766426, 65.14631867408752, 64.11808624863625, 66.28855258226395, 71.7733682692051, 73.13121020793915, 76.4392215013504, 78.59796926379204, 78.22848469018936, 74.82477933168411, 77.97781974077225, 68.30835700035095, 61.25103369355202, 58.94117943942547, 70.70058703422546, 72.61068373918533, 73.76509979367256, 69.36750456690788, 80.85598289966583, 77.83286511898041, 105.51061794161797, 22.603569701313972, 1.1378476372919977, 0.3769404860213399, 0.7883865048643202, 0.06769439918571152, 0.15837015816941857, 0.1632676352164708, 0.37845215178094804, 0.5718798818998039, 0.5795628915075213, 0.3088481101440266, 0.306431736680679, 0.571064647519961, 33.500301986932755, 57.108754366636276, 80.45062825083733, 77.8620095551014, 97.85431757569313, 45.25859624147415, 19.157608710229397, 25.760725289583206, 51.12066708505154, 67.06538289785385, 59.98638555407524, 28.1503239646554, 1.1227459413930774, 0.04746048492961563, 0.12542024109279737, 0.011791089218604611, 0.018742670545179863, 0.08498982424498536, 0.024316374001500662, 0.08586923213442788, 0.06032378922100179, 0.011556105782801751, 0.04165337602898944, 0.037758967228000984, 0.04715133589343168, 0.07465039350790903, 0.01654813800996635, 0.022356285917339846, 0.06543472278281115, 0.03636719913629349, 0.05207850626902655, 0.018157626254833303, 0.0756185399950482, 0.05581618461292237, 0.009835212822508765, 0.051281525011290796, 0.0005518530690551415, 0.02483489217411261, 0.009137871384155005, 0.050661694403970614, 0.03430723096244037, 0.04711341214715503, 0.024947763558884617, 0.0575052644853713, 0.031831363230594434, 0.07985939446371049, 0.029413960037345532, 0.0834881181071978, 61.38298541307449, 108.61600890755653, 94.49861124157906, 94.68302294611931, 70.24431511759758, 74.26777482032776, 38.775311931967735, 35.72845682501793, 89.00796666741371, 124.75451812148094, 117.53226846456528, 106.58394634723663, 32.04319417476654, 1.6244542761705816, 0.8917765819933265, 0.19902830303180963, 0.0900455642840825, 0.2299581386614591, 0.17768700054148212, 1.075255258474499, 0.20278021576814353, 2.0879406994208694, 1.5728417644277215, 3.7618458783254027, 49.318169206380844, 103.22944074869156, 111.76308363676071, 106.89872905611992, 101.75619900226593, 91.63399055600166, 80.32831281423569, 75.56288212537766, 74.35102075338364, 75.43870478868484, 73.3638109266758, 80.5487085878849, 79.02862295508385, 86.41368627548218, 88.25536385178566, 89.34430941939354, 95.10358437895775, 96.88619032502174, 96.54664054512978, 93.2669985294342, 89.48095768690109, 88.1305405497551, 81.82702839374542, 74.29090037941933, 67.49485865235329, 70.69721281528473, 71.52491480112076, 84.35589149594307, 88.41845110058784, 87.19943851232529, 91.43095225095749, 92.29633301496506, 82.92384713888168, 78.53037849068642, 70.50340041518211, 68.61446097493172, 70.63232749700546, 71.96085780858994, 77.76243209838867, 81.39727145433426, 87.2112026810646, 75.44327974319458, 73.98891538381577, 74.64637130498886, 79.32855606079102, 75.61867833137512, 68.37183639407158, 48.725093230605125, 42.82974377274513, 52.183568850159645, 66.40626266598701, 72.25386768579483, 80.14689534902573, 83.07961598038673, 74.40803289413452, 80.29140159487724, 76.02882832288742, 76.76257655024529, 71.97227239608765, 88.35490331053734, 82.42402195930481, 72.36102193593979, 71.59517303109169, 74.26622450351715, 81.98864132165909, 80.640549659729, 79.069052785635, 66.21537610888481, 65.59887439012527, 64.91050332784653, 63.26334111392498, 68.37342470884323, 67.28574827313423, 70.3162756562233, 74.67651128768921, 74.62322294712067, 79.03824403882027, 80.45635834336281, 82.66345471143723, 77.40981861948967, 79.82502982020378, 71.73797696828842, 65.45167028903961, 62.12932236492634, 73.45388889312744, 76.63586094975471, 78.37382689118385, 72.60218739509583, 83.59150931239128, 80.37167608737946, 104.47968766093254, 27.09852520376444, 1.1593415401875973, 0.27262827556114644, 0.681928270496428, 0.04186361162282992, 0.2315686288056895, 0.20255535986507311, 0.7611329422798008, 0.25042648252565414, 0.3015973273431882, 0.21150714514078572, 0.23848298122175038, 0.40940054110251367, 37.706550881266594, 67.20240354537964, 88.86523112654686, 88.4600892663002, 61.11685149371624, 34.747862443327904, 30.651545450091362, 38.25826607644558, 65.55095136165619, 74.8018741607666, 72.37127378582954, 36.616902351379395, 0.6010767433326691, 0.016264875084743835, 0.06402367740520276, 0.1250470892409794, 0.0824592713615857, 0.0636305172520224, 0.060909106250619516, 0.07514450800954364, 0.05090530808956828, 0.024118099972838536, 0.022897736453160178, 0.036353328396216966, 0.05719869070162531, 0.02513755298423348, 0.035937859283876605, 0.08311867699376307, 0.04298846259189304, 0.07746314062387682, 0.047552180985803716, 0.07510735609685071, 0.19448428123723716, 0.19210899306926876, 0.1027709330082871, 0.13362725148908794, 0.1666882383869961, 0.20196149329422042, 0.11388575221644714, 0.14373076090123504, 0.11170047611813061, 0.21552415302721784, 0.12056442079483531, 0.22485781781142578, 0.11889664427144453, 0.11442368311691098, 0.10476279800059274, 0.4567780316574499, 81.7217056453228, 123.01818609237671, 105.97385868430138, 102.47759029269218, 91.47376075387001, 74.4004637002945, 49.966866597533226, 68.29414576292038, 102.43031322956085, 141.23799562454224, 123.98542419075966, 125.56171640753746, 39.88186575472355, 5.185622591525316, 3.2532901922240853, 0.3278379770927131, 0.2424099517520517, 0.7329481921624392, 1.2306746374815702, 1.4176880149170756, 0.5856222007423639, 3.6788402823731303, 6.337065305560827, 3.967449520714581, 47.02414110302925, 107.1100889146328, 116.49819955229759, 111.29249408841133, 107.49199882149696, 95.13603463768959, 85.38940563797951, 81.31377473473549, 78.02251294255257, 79.31534796953201, 74.96768966317177, 84.03499111533165, 81.44598484039307, 88.37432786822319, 93.13941657543182, 93.98695349693298, 102.285176217556, 101.08195558190346, 101.90728649497032, 96.31009563803673, 94.1762213408947, 92.39642724394798, 86.79866641759872, 80.82020401954651, 70.50463914871216, 73.33471208810806, 76.76901340484619, 88.48247766494751, 91.52018666267395, 90.37759557366371, 93.0192518234253, 94.91278901696205, 87.85311743617058, 80.82794800400734, 74.96769726276398, 71.50352194905281, 74.02720972895622, 77.04139038920403, 82.48331397771835, 85.52407041192055, 94.19564589858055, 81.58580213785172, 83.12541872262955, 81.79405376315117, 91.346665173769, 82.82293975353241, 75.3945055603981, 50.241679251194, 45.620283633470535, 54.54510413110256, 73.13315570354462, 85.16761153936386, 84.65235158801079, 84.06029775738716, 74.78988960385323, 85.10764315724373, 79.64081570506096, 82.1766172349453, 78.19883108139038, 88.42874094843864, 83.37605327367783, 75.16513466835022, 73.76162678003311, 76.31876796483994, 85.28868064284325, 83.58463168144226, 80.92097461223602, 69.39217284321785, 67.84927323460579, 68.15972417593002, 65.58064296841621, 71.56963840126991, 72.2289714217186, 73.0912135541439, 79.07097548246384, 80.08368954062462, 82.02739164233208, 84.29172053933144, 87.44470775127411, 80.76522096991539, 85.7806022465229, 76.06755584478378, 69.55027475953102, 66.14516347646713, 80.78833892941475, 82.49368742108345, 83.04535701870918, 76.7581307888031, 88.94245818257332, 85.3517496585846, 115.63424751162529, 28.417016454041004, 1.4909978373907506, 0.902908737771213, 1.1294835736043751, 0.22701059526298195, 0.5781876621767879, 0.36750951083377004, 1.66923368582502, 3.251907303929329, 1.488699079491198, 0.8665342989843339, 0.36616251280065626, 1.0638336651027203, 51.78279675543308, 76.66942074894905, 101.22251003980637, 94.00375619530678, 140.76654732227325, 57.974427714943886, 25.80643303692341, 37.962307557463646, 70.0682781636715, 86.79848402738571, 82.7964323759079, 59.64777812361717, 1.920832791365683, 0.12814625340979546, 0.2031681512016803, 0.27009695826563984, 0.1367886966909282, 0.2156316753826104, 0.1597016750019975, 0.1660073030507192, 0.1359808986308053, 0.10295626212609932, 0.18672258913284168, 0.12299496185733005, 0.10479501463123597, 0.18608233833219856, 0.11821412073913962, 0.19502515846397728, 0.2100611149217002, 0.13121132331434637, 0.1555313097196631], [0.08781612297752872, 0.07258771278429776, 0.049790798948379233, 0.0425436638033716, 0.04656223762140144, 0.023763828357914463, 0.03033924749615835, 0.020994086844439153, 0.018764088927127887, 0.023625022622582037, 0.07854531810153276, 0.07068067527143285, 0.047305509651778266, 0.022157223356771283, 0.07493835422792472, 0.2515979774761945, 8.662464525550604, 88.33141297101974, 82.4097803235054, 67.59687557816505, 55.756539925932884, 44.26493436098099, 14.2066415771842, 55.98600201308727, 72.84449279308319, 112.75798425078392, 107.0666116476059, 100.00129356980324, 19.9054541811347, 0.6158065935596824, 0.2507479808991775, 0.13586190267233178, 0.017603030428290367, 0.10102022890350781, 0.16535657312488183, 0.015591418741678353, 0.1251453347504139, 0.16772926377598196, 0.36938153381925076, 1.5665991744026542, 23.816187232732773, 86.9214454293251, 101.56841307878494, 96.79855942726135, 93.02549108862877, 86.07881024479866, 74.66804534196854, 76.67818307876587, 77.21363514661789, 74.54844295978546, 74.65072587132454, 77.24493026733398, 79.7366389632225, 87.60654866695404, 88.75608578324318, 91.15127965807915, 90.51659971475601, 92.8687646985054, 94.09960985183716, 93.06512296199799, 88.99711444973946, 85.90608671307564, 77.07337707281113, 70.50314962863922, 65.6274564564228, 65.81718787550926, 62.85688452422619, 71.18514463305473, 83.41721266508102, 84.87536922097206, 82.40229472517967, 82.23374336957932, 86.52115970849991, 81.6411803662777, 72.18505337834358, 65.65540015697479, 64.18928682804108, 65.55614948272705, 68.00365135073662, 77.78896227478981, 81.34167283773422, 84.10720244050026, 70.95417782664299, 56.17363214492798, 65.08407041430473, 61.98360778391361, 67.79906272888184, 58.7343717366457, 29.082322753965855, 25.820049606263638, 45.05145415663719, 66.89939260482788, 77.5766296684742, 69.81043919920921, 75.24028703570366, 79.57457765936852, 77.60140433907509, 72.19496324658394, 71.52789384126663, 65.77711522579193, 72.75891378521919, 84.1097255051136, 73.82771283388138, 70.6760935485363, 69.38890501856804, 77.50664502382278, 77.23443523049355, 76.55903667211533, 69.32287976145744, 61.165785267949104, 61.75224579870701, 61.52092181146145, 63.56770858168602, 62.599144354462624, 63.103160709142685, 65.82263678312302, 67.42613554000854, 68.79619762301445, 66.38968035578728, 65.96636787056923, 66.90477311611176, 71.21772408485413, 61.040331199765205, 60.16860477626324, 65.12210637331009, 78.83959829807281, 75.57214602828026, 74.5644249022007, 70.10160237550735, 72.65843197703362, 80.80187380313873, 96.97081178426743, 47.36744128167629, 0.6765645020641387, 0.21400693600298837, 0.28870939859189093, 0.11589220783207566, 0.04337486549047753, 0.07381083152722567, 0.23508566664531827, 0.5354527803137898, 0.8646135020535439, 0.3067122685024515, 0.1309408847009763, 0.32274010533001274, 1.216392272617668, 51.61142975091934, 74.4231940805912, 81.84255436062813, 67.77421966195107, 80.45553758740425, 34.25983943045139, 22.244097590446472, 37.78470888733864, 57.00906291604042, 70.53798615932465, 63.12982767820358, 31.406259052455425, 2.6078033912926912, 0.017563742985657882, 0.1790882198838517, 0.08406360168009996, 0.027605409231910016, 0.07450209013768472, 0.019244097056798637, 0.03384922194527462, 0.12998490943573415, 0.03007783154316712, 0.03496908568195067, 0.06370057599269785, 0.040304199792444706, 0.05541313163121231, 0.0469384656753391, 0.04945623135427013, 0.010289038909832016, 0.046488390216836706, 0.04832294216612354, 0.033182521001435816, 0.019500568450894207, 0.019087529872194864, 0.01240854588104412, 0.05189395269553643, 0.02242041675344808, 0.01873805253126193, 0.06829190228017978, 0.03520748949085828, 0.013533941400964977, 0.0067715270233748015, 0.08415372067247517, 0.10719797748606652, 0.1416660170070827, 0.25906220194883645, 10.06152855232358, 105.24634212255478, 89.95509624481201, 83.94740581512451, 64.84860464930534, 67.39492401480675, 28.003385849297047, 40.053168162703514, 79.11618545651436, 121.64455980062485, 113.16282972693443, 111.6763798892498, 25.172995626926422, 0.6978545221500099, 0.4457035259110853, 0.2864630363183096, 0.022601886703341734, 0.5779872229322791, 0.06804629592807032, 0.22851285059005022, 0.10103237786097452, 1.3264499232172966, 1.1143648973666131, 2.6236846391111612, 29.108624942600727, 92.29168966412544, 105.70212006568909, 101.59575641155243, 96.71934887766838, 87.67033964395523, 80.28598308563232, 80.45493721961975, 78.89110073447227, 79.04002234339714, 77.42471382021904, 80.80558240413666, 86.43153011798859, 91.76612466573715, 91.04262828826904, 96.5889398753643, 94.35717523097992, 96.96559086441994, 98.09910044074059, 95.46252071857452, 92.37079381942749, 87.98563152551651, 79.09939035773277, 72.25840464234352, 69.66186717152596, 69.63190197944641, 65.44832646846771, 75.3778700530529, 86.9535157084465, 89.77263763546944, 85.34481883049011, 82.89180725812912, 89.3661430478096, 84.47497710585594, 76.10771209001541, 70.77049568295479, 68.47117066383362, 68.70219826698303, 71.80711805820465, 80.01818105578423, 85.77001601457596, 87.7960292994976, 77.39110842347145, 67.4993272125721, 73.38363826274872, 67.47449934482574, 73.18784236907959, 66.39576762914658, 36.10635034739971, 34.55669470131397, 52.00584098696709, 77.80364468693733, 85.00003293156624, 70.82705944776535, 74.74654912948608, 82.52595528960228, 81.92938730120659, 74.67428460717201, 73.82812321186066, 69.97988730669022, 77.61254534125328, 87.70368665456772, 76.51181280612946, 73.49405273795128, 71.41529068350792, 80.49428790807724, 82.72187277674675, 81.11769765615463, 74.41437095403671, 63.40867951512337, 65.3261250257492, 66.36621281504631, 66.09455779194832, 67.19119414687157, 67.28060334920883, 67.92171254754066, 70.34336060285568, 70.00935852527618, 70.0717131793499, 67.55239516496658, 69.10506024956703, 73.78518551588058, 63.63454319536686, 64.04595851898193, 69.4380895793438, 81.91972061991692, 78.52152496576309, 79.0338970720768, 73.62017557024956, 76.25892117619514, 86.28685668110847, 99.23925206065178, 51.163730174303055, 0.5797774612437934, 0.05471585420309566, 0.27381016057915986, 0.15394109504995868, 0.09293387687648647, 0.04759262432344258, 0.49646797066088766, 1.0056763608008623, 0.7321881735697389, 0.1581338286632672, 0.25157722702715546, 0.39827571774367243, 1.2583198165521026, 58.51378597319126, 81.8297490477562, 90.75895071029663, 72.17617705464363, 42.18053340911865, 29.179787524044514, 36.15514352917671, 50.044918209314346, 71.71616613864899, 74.93942677974701, 73.00428941845894, 38.144067004323006, 1.3433821708895266, 0.02688398973987205, 0.0911254262609873, 0.017050089591066353, 0.01116632518460392, 0.06403146253433079, 0.056680393317947164, 0.044333174810162745, 0.04475664427445736, 0.05287380285153631, 0.03562244281056337, 0.02847926771210041, 0.05712430152925663, 0.07293045142432675, 0.051341037833481096, 0.07845211919629946, 0.00563566397431714, 0.05322344717569649, 0.2499925933079794, 0.2129011508077383, 0.22277226409642026, 0.09521382133243605, 0.10928709350991994, 0.12318613167735748, 0.18707448587520048, 0.09581226695445366, 0.14370822929777205, 0.15755444881506264, 0.14510593086015433, 0.19484517280943692, 0.2088740497129038, 0.22830460395198315, 0.33221608435269445, 0.6245288474019617, 16.08212023973465, 124.40571203827858, 103.27746257185936, 95.52932113409042, 77.05558642745018, 57.44572028517723, 20.205282792448997, 86.19510680437088, 106.37084618210793, 132.7186095714569, 126.16789028048515, 126.25905498862267, 31.941078454256058, 1.146698787342757, 1.2915389402769506, 1.0886805318295956, 0.14117861894192174, 0.5249094741884619, 0.3454437979962677, 0.5131684010848403, 1.247042971663177, 2.196613918058574, 3.6397173441946507, 5.636566719040275, 27.924627475440502, 97.62154206633568, 111.17906257510185, 108.55373784899712, 103.43796595931053, 94.0524011850357, 83.00985172390938, 84.48632329702377, 82.43419781327248, 81.56352013349533, 81.32893592119217, 83.83736371994019, 87.82627567648888, 95.32116830348969, 95.71928054094315, 101.11579656600952, 96.5994045138359, 98.76941487193108, 101.08399227261543, 100.72143852710724, 96.57697051763535, 92.2143942117691, 84.6469558775425, 79.03996914625168, 73.36300536990166, 73.33310097455978, 69.27098214626312, 79.72443401813507, 90.84088191390038, 89.62347283959389, 88.05577576160431, 89.41554799675941, 94.69018936157227, 88.05792644619942, 78.82434591650963, 73.12715202569962, 72.54262939095497, 72.38990038633347, 74.36475321650505, 85.6648376584053, 91.20927974581718, 94.86365005373955, 82.6497146487236, 74.7044549882412, 81.13690182566643, 77.28311821818352, 80.10603994131088, 76.16828083992004, 41.42275147140026, 36.336750984191895, 59.03190717101097, 86.82535618543625, 91.88420712947845, 82.32913345098495, 84.71112683415413, 86.75564512610435, 85.59739887714386, 79.34684067964554, 79.57732111215591, 75.8038803935051, 79.33215066790581, 86.98547199368477, 81.93647772073746, 76.9580228626728, 75.98459109663963, 85.98586723208427, 86.0538911819458, 84.57923591136932, 74.46542501449585, 66.49029895663261, 68.4919935464859, 69.56413641571999, 68.95721778273582, 70.3468108177185, 69.00631114840508, 71.42016962170601, 73.4168028831482, 76.32221817970276, 73.79203274846077, 72.45385855436325, 74.37012612819672, 78.16611483693123, 66.98329970240593, 67.8479965031147, 71.83216631412506, 88.54639023542404, 82.27791979908943, 85.4862928390503, 77.06903010606766, 80.89206576347351, 88.94245058298111, 105.97477823495865, 56.60607174038887, 1.1167793115600944, 0.2562779310392216, 0.8119192952290177, 0.3015429724473506, 0.27712076262105256, 0.13294901757035404, 1.2303845467977226, 2.6783029083162546, 1.5455657592974603, 0.7372877968009561, 0.9924267092719674, 0.6926909554749727, 2.6701810816302896, 74.06686440110207, 96.1292177438736, 97.73070260882378, 87.28705421090126, 112.1285480260849, 44.2343308031559, 32.80701398849487, 50.88523551821709, 79.86776992678642, 89.13013771176338, 85.14017701148987, 61.845792979002, 4.540386814624071, 0.13097092683892697, 0.24086312303552404, 0.15827318915398791, 0.10406472647446208, 0.21711402630899101, 0.10927432114840485, 0.15818689222214743, 0.18988878407981247, 0.13332163507584482, 0.14410242845769972, 0.17426889098715037, 0.1483323733555153, 0.12759718287270516, 0.16585865087108687, 0.2158716117264703, 0.07918407718534581, 0.20448348921490833], [0.04673294271924533, 0.04216362111037597, 0.03200733015546575, 0.02800321894028457, 0.0038204234033401008, 0.02142940469639143, 0.008679313177708536, 0.07583811180666089, 0.0679382095404435, 0.07883659622166306, 0.08132362956530415, 0.035659490822581574, 0.1207412152143661, 0.08933097997214645, 0.30111240805126727, 0.22912308893864974, 50.10543376207352, 94.08379510045052, 83.743045181036, 57.248203083872795, 47.344737499952316, 15.142165627330542, 44.738590344786644, 84.78011593222618, 91.1182290315628, 109.21535834670067, 103.64019110798836, 23.540607020258904, 1.0683301300741732, 0.19837469357298687, 0.2189374979934655, 0.027354923258826602, 0.21454022848047316, 0.04200546201900579, 0.19327217596583068, 0.24450898286886513, 0.5277779046446085, 0.33029035956133157, 0.9278077923227102, 5.912314597517252, 53.00051361322403, 90.10553017258644, 97.12431594729424, 90.58254897594452, 89.3722303211689, 81.28282159566879, 82.42000937461853, 75.61435416340828, 77.105173766613, 82.09842503070831, 87.00260147452354, 86.49134650826454, 91.1066472530365, 95.06359532475471, 93.1081822514534, 93.98526638746262, 94.78826969861984, 92.41816207766533, 87.07692548632622, 87.36892461776733, 81.7598707973957, 75.78995794057846, 66.5692587196827, 64.38395038247108, 66.93567305803299, 66.47769123315811, 64.23073500394821, 72.35713094472885, 82.69323751330376, 85.31365290284157, 83.96843388676643, 77.9766646027565, 74.47140589356422, 86.16259574890137, 71.19844391942024, 64.08186659216881, 67.99020007252693, 68.88056829571724, 70.01119762659073, 77.41861894726753, 80.15033796429634, 74.36671391129494, 67.01779425144196, 65.17358601093292, 62.12346687912941, 54.295233339071274, 58.4684544056654, 55.0086260586977, 33.952359929680824, 25.245718024671078, 34.86445538699627, 70.9553025662899, 80.2256727218628, 51.03293739259243, 55.09143881499767, 67.6027424633503, 76.58761873841286, 78.15635696053505, 60.4625304043293, 67.30549961328506, 65.85970759391785, 76.54060766100883, 83.3128322660923, 70.25707483291626, 64.19392257928848, 72.17362359166145, 79.95010390877724, 76.0774277150631, 74.57361280918121, 71.3868074119091, 62.876818254590034, 60.047246888279915, 61.5837362408638, 63.376666232943535, 61.50396712124348, 61.872870326042175, 64.59935322403908, 64.01397943496704, 63.02240364253521, 61.14773243665695, 59.640011340379715, 61.966098323464394, 60.87204962968826, 60.885789692401886, 69.02930751442909, 77.58163779973984, 82.36510992050171, 73.62482652068138, 71.24936118721962, 67.87176042795181, 76.50643989443779, 91.833905428648, 65.54611042141914, 0.9986295201815665, 0.321152918622829, 0.08315173967275769, 0.338812560075894, 0.08465811391943134, 0.07775605146889575, 0.34571916447021067, 0.36336826742626727, 0.5542992346454412, 0.025186499478877522, 0.3228822414530441, 0.17943279905011877, 0.8084395725745708, 12.867006361484528, 62.304983139038086, 72.99972206354141, 88.2152684032917, 83.32805424928665, 75.05582973361015, 22.607814073562622, 22.052137590944767, 27.294531986117363, 56.74982562661171, 61.91643498837948, 63.181341513991356, 46.896555349230766, 9.921600110828876, 0.27935827849432826, 0.04738704570627306, 0.13157126493752003, 0.004837531923840288, 0.07971740677021444, 0.026156582971452735, 0.04160998265433591, 0.09079240233404562, 0.02611446238006465, 0.02258958003949374, 0.06790427112719044, 0.14558365131961182, 0.08125144086079672, 0.07762943365378305, 0.015223083428281825, 0.06430730398278683, 0.025706741289468482, 0.04691859467129689, 0.06668289643130265, 0.031291959166992456, 0.03791318180446979, 0.00853018973430153, 0.04776101020979695, 0.09060043841600418, 0.04766836420458276, 0.037255286442814395, 0.09370899075292982, 0.04502611067437101, 0.10828101585502736, 0.157468760444317, 0.11437895387643948, 0.10366308357333764, 60.15881270170212, 105.99964410066605, 92.3640225827694, 77.43163704872131, 60.898986384272575, 27.81616609543562, 30.17179649323225, 67.38623768091202, 101.63177087903023, 115.58911353349686, 117.38149255514145, 32.00524941086769, 1.011686569545418, 0.11992005107458681, 0.3473187598865479, 0.3327587724197656, 0.2317943752859719, 0.17082087288144976, 0.3641350247198716, 0.1725709906895645, 0.45287317712791264, 0.6657077127601951, 0.9408421022817492, 8.144027944654226, 58.51495251059532, 95.10071933269501, 99.42881628870964, 94.20770645141602, 90.87824910879135, 84.50249522924423, 85.78494921326637, 82.63196960091591, 79.71875712275505, 85.57532206177711, 91.83722645044327, 91.75176903605461, 93.95803704857826, 99.31753545999527, 98.47816050052643, 96.66796043515205, 97.19853356480598, 94.40370753407478, 90.19417181611061, 89.54805448651314, 84.94560465216637, 78.1022022664547, 68.97784307599068, 68.34939479827881, 68.64064916968346, 70.22381141781807, 66.50326386094093, 73.79836320877075, 86.41247794032097, 88.26472654938698, 88.33758383989334, 82.57045090198517, 81.6416135430336, 89.14526849985123, 73.1821882724762, 67.37598583102226, 69.63744968175888, 71.659404784441, 73.93901646137238, 79.99027535319328, 82.99559488892555, 77.73366764187813, 71.08563557267189, 70.07546737790108, 67.35095277428627, 62.106124609708786, 64.46614757180214, 64.11249294877052, 42.71812096238136, 32.16658875346184, 42.1127450466156, 73.1190812587738, 79.09214794635773, 59.89048629999161, 62.11907811462879, 70.49812629818916, 79.21506375074387, 83.0083318054676, 66.18747800588608, 70.62327638268471, 67.87100046873093, 82.12861821055412, 87.4884282052517, 74.34672698378563, 68.37492182850838, 75.12185499072075, 83.3408671617508, 81.73006519675255, 80.64940318465233, 74.0710973739624, 67.32603371143341, 64.08954218029976, 64.0382981300354, 66.43836334347725, 63.75347301363945, 65.48877149820328, 67.23772644996643, 65.74087277054787, 64.97807890176773, 64.73413199186325, 62.135014459490776, 66.11067652702332, 65.15071883797646, 66.06734365224838, 72.76651337742805, 80.86973816156387, 86.9802738726139, 80.31043857336044, 73.39386731386185, 73.44410821795464, 80.31628265976906, 94.79316383600235, 69.70168143510818, 1.3315300131216645, 0.312890944769606, 0.10190894332481548, 0.23734109796350822, 0.1382860538433306, 0.13895456562750041, 1.0183284943923354, 0.15874817850999534, 0.34388332860544324, 0.14064793882425874, 0.7058683515060693, 0.292710168287158, 1.3164702337235212, 15.363819133490324, 77.18552425503731, 81.20723605155945, 98.3333882689476, 65.08785501122475, 41.26533351838589, 32.151879742741585, 32.325484827160835, 40.41807018220425, 71.84652954339981, 74.95337963104248, 73.92054185271263, 54.137640595436096, 8.317432589828968, 0.10014561528805643, 0.04611096730513964, 0.11103476223070174, 0.01257198999155662, 0.10349075688282028, 0.031888720113784075, 0.05214623837673571, 0.020714738748210948, 0.06699725534417666, 0.044101995808887295, 0.006143515165604185, 0.038087323046056554, 0.05162046756595373, 0.08100076564005576, 0.029285488708410412, 0.04614898010913748, 0.17173608939629048, 0.15978697745595127, 0.15078877826454118, 0.14024241449078545, 0.15101888857316226, 0.1718831979087554, 0.1528015421354212, 0.2673204056918621, 0.1931537440395914, 0.14727369969477877, 0.20453028904739767, 0.12964415975147858, 0.20396444597281516, 0.22652760555502027, 0.28962523851078004, 0.35182935534976423, 80.1840041577816, 116.75593972206116, 104.69254463911057, 81.06362655758858, 71.86883434653282, 28.42431966215372, 66.28977611660957, 120.27252182364464, 109.23067152500153, 131.15292638540268, 127.65165746212006, 38.61487314105034, 1.2587979971431196, 0.5103481805417687, 0.9612676093820482, 0.8967247477266937, 0.463941716006957, 0.8029535575769842, 0.8327464526519179, 0.5665213381871581, 2.3041388858109713, 2.2417600080370903, 4.35834095813334, 9.296505153179169, 60.052650198340416, 97.88433596491814, 104.44824054837227, 101.18236899375916, 96.41392886638641, 87.97744676470757, 89.63704571127892, 83.82692947983742, 83.95097762346268, 89.29208502173424, 91.91182404756546, 96.05851113796234, 98.01777720451355, 104.63099554181099, 100.61276435852051, 102.2386135160923, 102.97186776995659, 97.9672323167324, 92.58069455623627, 94.38332542777061, 89.59188133478165, 82.73638799786568, 73.82725685834885, 71.01631209254265, 72.1431340277195, 74.94372054934502, 71.62436306476593, 77.96942219138145, 89.27753940224648, 94.86820980906487, 89.16644096374512, 86.01834028959274, 85.58229088783264, 93.02761897444725, 78.55794221162796, 71.16868391633034, 75.69750890135765, 76.20001673698425, 77.77193158864975, 86.64475187659264, 90.77095806598663, 86.21848315000534, 78.72293695807457, 76.38406366109848, 74.11137521266937, 71.05904459953308, 72.9516014456749, 74.16182890534401, 47.08227418363094, 36.60228833556175, 48.72209519147873, 81.65452525019646, 87.28570148348808, 68.15033107995987, 73.03946033120155, 82.68977209925652, 85.5609056353569, 83.56598988175392, 75.77749460935593, 74.84751731157303, 75.06517723202705, 83.26268255710602, 89.21802699565887, 78.85023772716522, 71.78587719798088, 79.05995607376099, 85.80802157521248, 82.9460759460926, 83.6699067056179, 78.04401978850365, 71.53543263673782, 67.14314192533493, 66.85394704341888, 69.92255598306656, 67.81917124986649, 71.1946289241314, 71.64859056472778, 70.90408891439438, 67.8340208530426, 69.82642874121666, 64.11794945597649, 70.26133060455322, 67.42753386497498, 68.56172740459442, 78.08736026287079, 84.26876217126846, 89.48016732931137, 84.83816921710968, 81.24049946665764, 75.9906479716301, 83.69377702474594, 97.18461871147156, 79.66660112142563, 2.0887519558891654, 0.3204545279731974, 0.6117729912512004, 0.7221427001059055, 0.3782808344112709, 0.24185153015423566, 1.6005558148026466, 1.2914803996682167, 2.524663140065968, 0.35043913463596255, 1.1349277314729989, 0.5156210507266223, 1.5115269483067095, 17.542588971555233, 88.84939357638359, 94.12454411387444, 105.91581299901009, 116.6925211250782, 101.10961049795151, 31.856077015399933, 34.08538319170475, 44.3119378387928, 79.95955780148506, 83.30207884311676, 85.9396693110466, 76.86467707157135, 16.13523378968239, 0.31536238559056073, 0.14156014221953228, 0.1904503523837775, 0.16534858761588112, 0.24850270216120407, 0.12447660032194108, 0.1762242868426256, 0.194395431317389, 0.06956479686778039, 0.31472790869884193, 0.22513863164931536, 0.20832941721891984, 0.15315376542275771, 0.1572984375525266, 0.07835825235815719, 0.15444672026205808], [0.022176734419190325, 0.029327950687729754, 0.08960550039773807, 0.0115459142398322, 0.019214910244045313, 0.06381287035765126, 0.05376440232794266, 0.0834831605607178, 0.04329680268710945, 0.09789914169232361, 0.12381767708575353, 0.14215246512321755, 0.03600625190301798, 0.12381483466015197, 0.12894946499727666, 8.120176624506712, 83.25493097305298, 87.64866560697556, 58.68530876934528, 45.01170448958874, 28.443609327077866, 39.595596715807915, 73.97478774189949, 68.02410185337067, 109.19524982571602, 107.93583020567894, 46.66936174035072, 0.7770158525090665, 0.0854978317511268, 0.25879517721477896, 0.09659777089837007, 0.29673177748918533, 0.11934660840779543, 0.12531463347841054, 0.054950480480329134, 0.21742758370237425, 0.1395237335236743, 0.27303286478854716, 0.7778657006565481, 10.293957330286503, 62.91518859565258, 99.3474018573761, 94.33035627007484, 94.36197817325592, 92.55386039614677, 96.3212138414383, 90.72658404707909, 94.80236694216728, 86.06201514601707, 88.64963829517365, 90.79789102077484, 91.43771588802338, 91.40916422009468, 92.62260630726814, 96.7659267783165, 93.2909144461155, 91.07521533966064, 92.35486507415771, 86.4777584373951, 80.33713594079018, 72.84719824790955, 67.33767628669739, 63.10163699090481, 67.2418150305748, 64.81416329741478, 63.73485401272774, 63.95566776394844, 69.185471534729, 79.32670176029205, 80.78338399529457, 82.66303673386574, 88.01834017038345, 80.4777891933918, 77.98569291830063, 67.78748095035553, 67.2860598564148, 69.31145757436752, 73.6933596432209, 73.47564652562141, 75.67917108535767, 73.09869155287743, 72.45365336537361, 63.82034942507744, 68.84349748492241, 65.71184232831001, 61.28606401383877, 65.68924874067307, 66.52413234114647, 53.27893607318401, 42.32368692755699, 36.20052449405193, 48.59398886561394, 56.99530765414238, 55.16671657562256, 50.86104601621628, 58.02942216396332, 55.45728698372841, 73.11891406774521, 64.20893177390099, 61.28501906991005, 63.640379682183266, 66.16958856582642, 79.47261393070221, 70.93204781413078, 69.8747469484806, 68.00445690751076, 73.30579563975334, 78.11347246170044, 76.67300775647163, 75.39852574467659, 72.25954458117485, 64.09716457128525, 66.08100771903992, 64.70348283648491, 64.50216963887215, 62.46435798704624, 61.79737977683544, 61.729363426566124, 65.66959619522095, 63.50248508155346, 59.79392968118191, 60.161400362849236, 62.98048809170723, 68.14897075295448, 77.4122428894043, 76.07764050364494, 77.01172158122063, 77.86959394812584, 68.47129225730896, 72.15055882930756, 75.36498874425888, 87.63053297996521, 83.7337052822113, 9.577251188457012, 0.4832630854798481, 0.09678050992079079, 0.7289874390698969, 0.21032993565313518, 0.08752028807066381, 0.6495185033418238, 0.5775760137476027, 0.06142030128103215, 0.2806191280251369, 0.24646510602906346, 0.08636957325506955, 0.05108347919303924, 0.436701838625595, 10.475867819041014, 49.98096764087677, 86.25347927212715, 73.16697388887405, 90.56094333529472, 58.872524723410606, 21.287495121359825, 23.52999608963728, 40.902437791228294, 51.22419252991676, 59.413874074816704, 67.64869719743729, 61.18518702685833, 9.916139803826809, 0.10282560702762567, 0.06714385919622146, 0.15711128275142983, 0.09011180096422322, 0.07251242190250196, 0.04102758968656417, 0.011195411807420896, 0.03011655866430374, 0.08115251999697648, 0.011035090283257887, 0.05484367429744452, 0.06551011014380492, 0.11432927451096475, 0.011428089947003173, 0.037416659033624455, 0.037935375730739906, 0.0036819402703258675, 0.13854576100129634, 0.051348600318306126, 0.051200389716541395, 0.014104349611443467, 0.028354028436297085, 0.04212643580103759, 0.03947673481889069, 0.03844094528176356, 0.09708102035801858, 0.09890423971228302, 0.03921787370927632, 0.12203539459733292, 0.23436622868757695, 8.37919732555747, 100.58455467224121, 93.0989183485508, 80.55277436971664, 58.507846891880035, 51.29452295601368, 42.8297171741724, 52.29155145585537, 83.13994154334068, 117.32731506228447, 120.15159711241722, 57.626472786068916, 0.5432580364868045, 0.028332886504358612, 0.2435844301362522, 0.255248750327155, 0.17984936654102057, 0.08073432720266283, 0.5058895354159176, 0.33509122382383794, 0.11973491491517052, 0.029934867925476283, 0.0960266956826672, 1.37450440088287, 11.276714745908976, 66.39409571886063, 100.04300013184547, 98.74429821968079, 96.37860596179962, 97.56620943546295, 102.57592901587486, 97.11341813206673, 98.09180483222008, 90.57820200920105, 91.69872388243675, 94.94116589426994, 97.48800203204155, 96.17180585861206, 96.90746918320656, 99.65529173612595, 95.94327852129936, 94.20071482658386, 95.04244565963745, 90.23476123809814, 82.5355763733387, 75.30423000454903, 68.53485524654388, 65.72487562894821, 67.87227720022202, 67.89234012365341, 67.48645350337029, 67.05258518457413, 70.93714714050293, 82.58992105722427, 85.43564155697823, 85.39206549525261, 89.6142165362835, 82.23663121461868, 80.47762960195541, 71.66161626577377, 72.84410521388054, 73.78301963210106, 76.995580047369, 76.11019715666771, 78.83997067809105, 76.60151839256287, 77.68239319324493, 70.25172472000122, 74.76247027516365, 72.04721197485924, 68.15613716840744, 70.41242569684982, 68.52474018931389, 58.950591534376144, 50.64223475754261, 47.404154911637306, 56.347533613443375, 60.34773476421833, 64.33839082717896, 59.65787798166275, 66.2862803041935, 60.55375210940838, 73.89308452606201, 66.2059298157692, 66.74490049481392, 66.71519368886948, 73.0448180437088, 83.48391428589821, 72.14455515146255, 72.9875323176384, 71.76613345742226, 77.0442858338356, 80.56313261389732, 80.89923217892647, 78.23324203491211, 75.88358491659164, 67.87387311458588, 68.95356997847557, 68.25919523835182, 67.50236704945564, 67.21944183111191, 66.4258924126625, 67.52789407968521, 68.42249527573586, 66.48698553442955, 61.514359563589096, 64.49404567480087, 65.6806991994381, 71.21931239962578, 81.22805133461952, 79.93593826889992, 82.39764377474785, 78.10448974370956, 73.68848070502281, 73.23446586728096, 80.95197334885597, 89.05907392501831, 89.5524014532566, 11.572118494659662, 0.7372408336959779, 0.06954814307391644, 0.9624341467861086, 0.06872003243188374, 0.7332920737098902, 0.34421260468661785, 0.26602776255458593, 0.05685720629116986, 0.15602026629494503, 0.19333616393851116, 0.14526040147757158, 0.10061696069897152, 0.7004678912926465, 13.470154646784067, 60.277430936694145, 94.89401042461395, 82.9128885269165, 62.85022348165512, 38.3364886790514, 34.63408134877682, 39.15954731404781, 51.82772554457188, 56.89291454851627, 68.25924083590508, 77.32556954026222, 68.84225115180016, 7.9477884247899055, 0.07790908974129707, 0.11166611468070187, 0.1408016969799064, 0.03142697809380479, 0.020762785388797056, 0.05018956973799504, 0.021240646856313106, 0.014609444187954068, 0.08892578960512765, 0.04253146660630591, 0.04110147048777435, 0.023992229871510062, 0.034494920109864324, 0.02173017117456766, 0.09904076519887894, 0.15053903072839603, 0.08459895732812583, 0.25245497992727906, 0.15091006003785878, 0.08688547721249051, 0.16614688618574291, 0.18319700175197795, 0.10215933652943932, 0.1801852328935638, 0.1568122862954624, 0.24492385826306418, 0.314930752501823, 0.18206723034381866, 0.34498283523134887, 0.6738606502767652, 14.507776368409395, 115.86630865931511, 108.35557088255882, 82.21324726939201, 66.20817169547081, 41.7208568751812, 54.64256510138512, 104.5261287689209, 89.8968605697155, 133.04046750068665, 125.97941279411316, 69.17800113558769, 1.322658439166844, 0.18573449371615425, 0.5408284231089056, 0.6530000665225089, 0.6356177211273462, 0.2492239064304158, 2.3100069584324956, 1.153567275032401, 0.2663868432864547, 0.7310518564190716, 2.9737546294927597, 2.6398503966629505, 13.614413905888796, 70.08042991161346, 107.72745698690414, 102.4423585832119, 103.60130399465561, 101.65846064686775, 106.12790241837502, 99.58422034978867, 103.71291920542717, 94.12371575832367, 95.40465742349625, 100.8135075867176, 99.13797229528427, 98.49069982767105, 98.29298123717308, 102.52851516008377, 101.04184493422508, 97.83654972910881, 98.4495784342289, 95.2369724214077, 87.42697790265083, 79.65043678879738, 72.92687997221947, 69.40896794199944, 73.53116154670715, 71.90418764948845, 72.25099503993988, 69.8455037176609, 77.1100603044033, 88.56698513031006, 88.84209796786308, 90.30812010169029, 95.79261660575867, 87.79073238372803, 86.31490677595139, 76.01812049746513, 76.31682246923447, 76.2275804579258, 82.41487205028534, 80.23729249835014, 83.31467136740685, 82.95634299516678, 85.34864142537117, 74.71075505018234, 81.38173788785934, 79.59055960178375, 72.13149145245552, 70.06714582443237, 71.3892088830471, 61.85320258140564, 53.22216711938381, 50.79108037054539, 62.48101249337196, 69.25212755799294, 68.06450128555298, 64.250448346138, 72.31662511825562, 66.98897659778595, 84.1625502705574, 70.51970914006233, 70.1828496158123, 71.67222529649734, 74.61509138345718, 85.77301025390625, 77.92861238121986, 76.13084524869919, 76.06621071696281, 80.17099365592003, 85.46512797474861, 84.59971681237221, 83.37632685899734, 79.52077254652977, 70.04386067390442, 72.24811479449272, 70.94362959265709, 69.76192340254784, 70.4439640045166, 71.40436246991158, 69.13960799574852, 72.23275601863861, 70.7321785390377, 64.49317172169685, 66.30853950977325, 70.13108879327774, 75.32754555344582, 86.8622674047947, 82.95486867427826, 86.45947381854057, 80.94020158052444, 76.8046098947525, 76.88432961702347, 87.79094517230988, 91.1195133626461, 95.66108286380768, 13.260318506509066, 0.9280472982209176, 0.09341279219370335, 2.280522440560162, 0.5766735028009862, 1.7008840874768794, 1.789908204227686, 1.4648656896315515, 0.7430481095798314, 0.7706648495513946, 0.6241486896760762, 0.22123281232779846, 0.11028736756998114, 0.9422880434431136, 19.998212903738022, 71.27979755401611, 103.77658098936081, 91.06019854545593, 121.61685168743134, 78.9950479567051, 30.118342861533165, 39.025938883423805, 60.660792365670204, 69.29421409964561, 79.74189788103104, 87.02013373374939, 85.66267937421799, 14.017371833324432, 0.21425398212159052, 0.18251327594043687, 0.22684294410282746, 0.12160833313828334, 0.11972394597250968, 0.1608023839071393, 0.15039934369269758, 0.08739153287024237, 0.12396701204124838, 0.08598760468885303, 0.15046410349896178, 0.14280263101682067, 0.23881779372459278, 0.10106622721650638, 0.1686981227248907], [0.05721479159547016, 0.027042570000048727, 0.054825959232402965, 0.019336620607646182, 0.09655433299485594, 0.1319591558421962, 0.044408432295313105, 0.04179648065473884, 0.02104605759086553, 0.1586640634923242, 0.07095679873600602, 0.032419589479104616, 0.08409136542468332, 0.09809043767745607, 0.25712178263347596, 25.160830579698086, 90.488291233778, 76.51175200939178, 62.28660352528095, 38.532641753554344, 33.041495606303215, 54.31234762072563, 65.68992510437965, 99.20497789978981, 109.95958641171455, 69.00987535715103, 3.8651796709746122, 0.07829514011973515, 0.0035767879171544337, 0.04044845845783129, 0.06863520495244302, 0.3162645996781066, 0.09801390740904026, 0.17766479548299685, 0.32331325113773346, 0.34768567769788206, 0.17789355508284643, 0.31220650649629533, 0.5253717431332916, 10.289353877305984, 65.15687450766563, 97.54043161869049, 97.27129966020584, 98.43961536884308, 98.47549304366112, 101.33507519960403, 101.00929588079453, 91.43195539712906, 89.542445987463, 93.5295644402504, 91.46356970071793, 95.37484422326088, 93.16035345196724, 92.47574418783188, 92.54837349057198, 90.96508204936981, 87.3672679066658, 83.04781168699265, 75.87907835841179, 71.05557918548584, 63.901323080062866, 63.5776374489069, 66.17902725934982, 64.71169039607048, 62.80533269047737, 64.65436667203903, 64.04270589351654, 66.74622282385826, 69.11852672696114, 73.77560243010521, 76.49770796298981, 77.8635522723198, 73.48520681262016, 68.35004836320877, 65.89909628033638, 72.2227093577385, 74.58231434226036, 73.40880051255226, 72.14308083057404, 70.67164018750191, 69.06065583229065, 68.18652033805847, 66.85073241591454, 69.16914001107216, 62.11065396666527, 66.05027496814728, 68.43128800392151, 61.608043536543846, 62.31007866561413, 63.11006873846054, 56.86860725283623, 55.03962479531765, 45.89701138436794, 63.43922607600689, 64.92961630225182, 62.53155738115311, 61.887381747365, 50.4624056071043, 59.241530522704124, 70.84235742688179, 67.24492326378822, 65.21293669939041, 71.52638912200928, 74.0665452182293, 67.30173781514168, 67.1672934293747, 68.08105319738388, 72.83127710223198, 71.94081768393517, 77.2911661863327, 71.55251652002335, 70.19122436642647, 71.22655481100082, 72.4583651125431, 70.2931196987629, 69.72069561481476, 64.88524228334427, 65.18318429589272, 61.23382441699505, 62.079111859202385, 60.203186720609665, 61.8469101190567, 61.43078684806824, 72.04045593738556, 74.35000240802765, 82.54527345299721, 80.29210075736046, 78.69268298149109, 71.45255908370018, 70.18073692917824, 72.37872898578644, 82.19089686870575, 88.36458519101143, 46.71257682144642, 0.24612294626422226, 0.17857904720585793, 0.05346934667613823, 0.41398072033189237, 0.1426776236621663, 0.2311191990156658, 0.08689935537404381, 0.2548288134858012, 0.08896062601706944, 0.06292932870564982, 0.1322283921763301, 0.1488122608861886, 0.06492347951279953, 0.15419706178363413, 13.464485350996256, 68.09425368905067, 87.57439479231834, 82.82330453395844, 91.2116052210331, 35.2307253330946, 20.633960589766502, 37.304467856884, 52.450789511203766, 64.65163841843605, 68.12927260994911, 54.91051532328129, 59.88648511469364, 4.962243027985096, 0.17628655303269625, 0.04080642967892345, 0.13582926301751286, 0.0532046114676632, 0.04424013546667993, 0.053633513452950865, 0.03356769935635384, 0.03311116721306462, 0.051042872582911514, 0.07870234170695767, 0.03278510463132989, 0.03527132903400343, 0.03404429917281959, 0.015951779678289313, 0.08843756033456884, 0.02025880774453981, 0.028096818605263252, 0.08194819136406295, 0.01751673720718827, 0.031018537119962275, 0.01701919212791836, 0.0384462256624829, 0.01865267586254049, 0.06730414825142361, 0.03030319025128847, 0.011758036744140554, 0.09332561210612766, 0.12268561986275017, 0.3893971082288772, 32.55712419748306, 101.35048717260361, 87.5608903169632, 68.4041802585125, 51.66904605925083, 34.694779291749, 27.015898637473583, 66.56476736068726, 106.42035752534866, 116.98528781533241, 87.08444148302078, 6.262801140546799, 0.24883006350137293, 0.10489124149898998, 0.2080896738334559, 0.09968603291781619, 0.444310781895183, 0.18638290814124048, 0.2600301109487191, 0.2875125815626234, 0.34477984299883246, 0.15627623302862048, 1.0284543572925031, 0.6634130515158176, 11.570840813219547, 67.49996557831764, 101.57713741064072, 99.80165988206863, 100.74542284011841, 103.37530732154846, 105.1149071753025, 104.41547110676765, 98.72932702302933, 93.40711981058121, 97.7508719265461, 96.50799661874771, 98.895742893219, 96.81565091013908, 97.01530739665031, 93.17692056298256, 91.87797546386719, 88.69126126170158, 84.6545858681202, 78.57908427715302, 72.64894768595695, 66.42665237188339, 66.36806711554527, 68.19193124771118, 67.77843743562698, 65.10047033429146, 66.74450531601906, 67.05520704388618, 70.25639846920967, 71.14544436335564, 76.4068092405796, 79.9098488688469, 80.24932265281677, 76.5095329284668, 72.92384773492813, 69.7413133084774, 73.92710030078888, 76.49938747286797, 77.61278852820396, 73.72057378292084, 74.2370192706585, 74.78227481245995, 74.29152354598045, 70.05003914237022, 76.43943428993225, 65.06579339504242, 71.23363763093948, 68.1820897758007, 64.11633834242821, 66.1086854338646, 69.82066065073013, 61.86641067266464, 59.154997766017914, 54.978334084153175, 69.2942065000534, 68.66714134812355, 68.8003545999527, 66.84377878904343, 56.808802261948586, 61.03074811398983, 74.36656951904297, 70.94958767294884, 70.50086975097656, 76.639873534441, 75.2980363368988, 71.75474166870117, 72.87652507424355, 70.98526015877724, 77.56206125020981, 75.11416420340538, 82.65445679426193, 74.47003796696663, 74.91242542862892, 73.30707237124443, 76.99713796377182, 74.92710024118423, 77.14542880654335, 69.63021486997604, 69.17992383241653, 63.70282933115959, 68.1514710187912, 63.59795115888119, 66.23565942049026, 64.57169070839882, 74.397644251585, 77.08945021033287, 85.94491302967072, 83.86822566390038, 81.31011933088303, 75.47718912363052, 72.75228694081306, 75.59141099452972, 83.81537050008774, 93.32198917865753, 48.989509642124176, 0.06672572577372193, 0.06441190969781019, 0.25836188171524554, 0.2612711599795148, 0.44093326781876385, 0.18171450239606202, 0.20611352752894163, 0.20078327448572963, 0.10677778089302592, 0.31070938683114946, 0.12992231670068577, 0.11045538980397396, 0.022374073341779877, 0.03851347908494063, 17.63290822505951, 80.1046872138977, 95.06044149398804, 86.89205020666122, 52.74976126849651, 23.328661993145943, 31.293956078588963, 55.16575522720814, 64.70610469579697, 74.2551138997078, 77.25421696901321, 66.79661571979523, 69.98652175068855, 3.8020401215180755, 0.15565223526209593, 0.03693803315400146, 0.10694753975258209, 0.09841300474363379, 0.03446629176323768, 0.11320644218358211, 0.014472984566964442, 0.01919976857607253, 0.03898211936757434, 0.10923969995928928, 0.057401701487833634, 0.02518767949368339, 0.014636871183029143, 0.013853019445377868, 0.2397155697690323, 0.16399799758801237, 0.17384689097525552, 0.1002113102003932, 0.17177984642330557, 0.2117834021919407, 0.12310978694586083, 0.1717894646571949, 0.13181194342905656, 0.3870585118420422, 0.19370487774722278, 0.30095127294771373, 0.1527825283119455, 0.3549993352498859, 0.48387983988504857, 44.46628175675869, 118.00360277295113, 97.66302824020386, 81.03752955794334, 59.83920805156231, 48.985204473137856, 81.16876691579819, 86.936614215374, 122.26677641272545, 127.80243337154388, 99.69556957483292, 8.655975423753262, 0.37641267059370875, 0.21809860394569114, 0.3417561255628243, 0.3184688079636544, 0.9582375688478351, 0.7990713533945382, 0.33165641594678164, 0.652988845249638, 1.3225324521772563, 0.3751209774054587, 3.156131305731833, 1.9515985529869795, 12.416975609958172, 71.48964509367943, 107.48322889208794, 106.69808462262154, 106.13144382834435, 106.78659707307816, 107.70413383841515, 110.19693687558174, 102.09979176521301, 98.29447075724602, 101.97968021035194, 101.9257003068924, 101.75430670380592, 102.42077574133873, 99.78407442569733, 99.09403905272484, 98.89024078845978, 95.2178518474102, 90.39391189813614, 85.35096690058708, 77.05823868513107, 69.54263716936111, 70.13305708765984, 72.28920578956604, 70.58551400899887, 69.97392922639847, 71.34363412857056, 71.61954492330551, 73.416977673769, 77.22121953964233, 79.6223258972168, 84.5726166665554, 85.39264306426048, 80.84413513541222, 76.50931254029274, 74.99114200472832, 81.37839406728745, 82.77821615338326, 83.79300490021706, 80.84044173359871, 80.40363237261772, 80.61297833919525, 77.52411648631096, 77.89756044745445, 80.87967842817307, 72.99288243055344, 70.0715383887291, 73.05798813700676, 65.45209586620331, 66.02850213646889, 69.10078167915344, 64.06143888831139, 62.89114348590374, 59.98471364378929, 75.2463211119175, 72.48990342020988, 72.72030785679817, 72.1901299059391, 67.48110339045525, 66.90325319766998, 77.77880162000656, 76.5162281692028, 75.64140111207962, 78.30300629138947, 81.47951424121857, 75.74648827314377, 76.06313288211823, 74.81459587812424, 79.74160149693489, 79.63735789060593, 86.18609368801117, 79.98680993914604, 75.84462180733681, 78.0033391714096, 78.59309792518616, 74.64023843407631, 78.46379086375237, 70.76408922672272, 71.30916237831116, 69.54370111227036, 69.39354076981544, 67.66727820038795, 69.64678198099136, 67.65399411320686, 78.89613166451454, 81.98430195450783, 89.80577945709229, 86.60546958446503, 85.57390093803406, 82.08257228136063, 75.82621559500694, 81.78264677524567, 87.72136330604553, 97.70495519042015, 53.99082027375698, 0.28932532179169357, 0.48628724820446223, 0.43216019170358777, 0.9012085665017366, 1.0163135337643325, 0.7196116796694696, 1.1595841334201396, 0.8393019321374595, 0.880657488014549, 0.7853293314110488, 0.5217675771564245, 0.3598673193482682, 0.19044217391638085, 0.6197533942759037, 26.06609970331192, 91.4540246129036, 103.14587563276291, 105.0110587477684, 123.92098724842072, 47.34706677496433, 30.239303670823574, 50.16668647527695, 69.42655339837074, 84.57613527774811, 87.20024406909943, 75.0290335714817, 86.0897308588028, 7.543070241808891, 0.2230209280969575, 0.1958999427733943, 0.13487744377925992, 0.24095100816339254, 0.14837498747510836, 0.29724106891080737, 0.09803247594390996, 0.09919340271153487, 0.12578721827594563, 0.14144191809464246, 0.15748508769320324, 0.195870746683795, 0.23951625858899206, 0.09349258791189641], [0.014597319350286853, 0.06579228953341953, 0.02343348543945467, 0.01908257974719163, 0.08902065092115663, 0.01241218426002888, 0.06502801101305522, 0.10715919284848496, 0.00625177456640813, 0.046060308304731734, 0.034439849041518755, 0.007901970075181453, 0.044973269759793766, 0.04577263702230994, 0.08385441993596032, 43.36443208158016, 90.99003911018372, 66.84086054563522, 73.77519205212593, 29.59418758749962, 47.07148656249046, 63.17568741738796, 65.9816962480545, 109.54446628689766, 89.73687395453453, 26.185238510370255, 0.42888927971944213, 0.2069142009713687, 0.12956941063748673, 0.1518556007067673, 0.405503167421557, 0.030000937622389756, 0.26816333702299744, 0.1151036388182547, 0.2025530146784149, 0.1523197250207886, 0.43856780568603426, 0.1922549438313581, 0.302651830133982, 9.51068066060543, 58.676288053393364, 97.6881904900074, 102.2592844069004, 101.00542768836021, 101.26003682613373, 96.79670512676239, 95.56833744049072, 94.84853446483612, 94.35634687542915, 92.20868691802025, 91.7638447880745, 92.75413244962692, 92.23966285586357, 88.61948311328888, 86.463782787323, 81.79457813501358, 78.10071274638176, 72.83252343535423, 68.19424152374268, 67.20300391316414, 65.3730297088623, 63.850231021642685, 64.71108242869377, 63.47021721303463, 62.727851048111916, 59.66061383485794, 64.50028494000435, 64.1429977118969, 63.091962710022926, 68.18112462759018, 67.39251494407654, 69.93267863988876, 67.75436952710152, 67.73204192519188, 69.24914851784706, 72.0050798356533, 73.5060752928257, 73.33024352788925, 68.62943217158318, 67.99184918403625, 68.73327299952507, 69.89819929003716, 64.96186897158623, 67.18250021338463, 58.114332407712936, 74.84460666775703, 55.03443047404289, 61.28362454473972, 83.34161192178726, 74.5868057012558, 74.52625975012779, 67.69614905118942, 60.817925333976746, 64.03321400284767, 68.30469399690628, 65.37545397877693, 61.187516301870346, 56.57297171652317, 61.07094615697861, 66.05453073978424, 66.42170503735542, 63.04191179573536, 65.65947353839874, 73.87531667947769, 67.89491638541222, 69.46113154292107, 63.30594822764397, 70.6258450448513, 68.92419755458832, 72.27130874991417, 72.2113935649395, 73.85548174381256, 74.83407363295555, 76.40684723854065, 74.62075307965279, 75.5885611474514, 77.20766186714172, 73.00563454627991, 62.84082278609276, 62.96994365751743, 61.45111195743084, 59.15077619254589, 63.4508990496397, 70.6320159137249, 78.61794099211693, 71.79199486970901, 75.49810320138931, 82.02016443014145, 71.0922472178936, 67.43873566389084, 70.42939558625221, 77.24448949098587, 77.06450074911118, 79.60134342312813, 7.125165816396475, 0.15539914806140587, 0.2089684212114662, 0.5229502636939287, 0.27513228182215244, 0.15829327167011797, 0.17497266962891445, 0.5254167469684035, 0.1356267457595095, 0.04674839052313473, 0.06508618796942756, 0.09820015678997152, 0.07286886058864184, 0.08041032779146917, 0.6094148615375161, 25.899102464318275, 79.05433237552643, 84.8020787537098, 90.08897066116333, 89.20605003833771, 32.5063931196928, 9.441800806671381, 15.964208766818047, 33.625953644514084, 47.857481986284256, 55.836134254932404, 62.43481457233429, 50.42279653251171, 2.0515479147434235, 0.014855930912744952, 0.04235938482452184, 0.04927385969494935, 0.02783333206025418, 0.049880287115229294, 0.05505262226506602, 0.0791373589891009, 0.026324163627577946, 0.03293415757070761, 0.033609419187996536, 0.016268433682853356, 0.0746701197931543, 0.05609185165667441, 0.070624071668135, 0.025523887234157883, 0.06295332234003581, 0.04196977213723585, 0.010026131240010727, 0.019781311784754507, 0.027135995260323398, 0.05068686434242409, 0.01404216041919426, 0.011507834642543457, 0.052146483285469, 0.10910697426879779, 0.06478234528913163, 0.01312510894422303, 0.2047055694856681, 51.01738482713699, 98.44551265239716, 77.17997655272484, 85.56488782167435, 46.416078731417656, 53.38468819856644, 54.03717398643494, 77.87711754441261, 119.16979059576988, 105.6894363462925, 34.458553567528725, 0.36925700143910944, 0.12148469875683077, 0.2705609193071723, 0.15392363973660395, 0.31736185017507523, 0.04644399865355808, 0.202137753367424, 0.2104048480396159, 0.06466165723395534, 0.22792290255893022, 0.19567637820728123, 0.41621687065344304, 0.5293281620834023, 9.858726784586906, 62.695229798555374, 100.6059019267559, 104.75334137678146, 105.42178630828857, 104.2228290438652, 98.58383283019066, 96.41775146126747, 99.11841094493866, 99.01163667440414, 95.48006817698479, 94.9738897383213, 96.23505726456642, 94.94342297315598, 90.57795122265816, 87.90358632802963, 81.77243292331696, 79.58384156227112, 76.20120987296104, 70.02825871109962, 70.39451345801353, 70.24132087826729, 66.78813457489014, 68.7477958202362, 66.69132336974144, 65.38353234529495, 63.56998845934868, 68.84223595261574, 69.37750563025475, 66.47197633981705, 70.60597971081734, 70.74678495526314, 72.05551832914352, 70.29264092445374, 72.26611062884331, 72.10286378860474, 77.72010236978531, 76.42402231693268, 74.46789488196373, 71.63858190178871, 73.93230602145195, 72.97691568732262, 74.21878024935722, 70.66697403788567, 70.5890554189682, 63.61752770841122, 74.44064274430275, 59.23786371946335, 68.28182682394981, 86.26155003905296, 77.5351282954216, 77.56798893213272, 71.11890658736229, 66.1379286646843, 66.66948974132538, 70.61576798558235, 68.25846567749977, 66.54432445764542, 67.59386613965034, 72.31238454580307, 69.15218532085419, 70.82635268568993, 68.27265411615372, 72.1163758635521, 74.65296775102615, 73.03566053509712, 72.98028990626335, 67.77968376874924, 73.90509188175201, 71.94158524274826, 71.8787594139576, 75.03021910786629, 77.1224856376648, 79.44941997528076, 80.36563441157341, 78.22690397500992, 79.16574999690056, 80.23647174239159, 78.00681978464127, 66.91881716251373, 64.35774698853493, 65.53136721253395, 63.00815440714359, 68.79659280180931, 75.36499634385109, 81.45543113350868, 77.37315818667412, 78.80721643567085, 83.23403209447861, 75.53638994693756, 71.57447174191475, 73.0948081612587, 82.3723903298378, 83.04766729474068, 88.93024563789368, 8.13115993514657, 0.22053822147427127, 0.1926397325587459, 0.7175326568540186, 0.35001329029910266, 0.2218993054702878, 0.10224460929748602, 0.592236933298409, 0.20884575904347003, 0.25706692307721823, 0.09080676289158873, 0.13418099755654112, 0.12407652335241437, 0.21095075702760369, 0.7541278994176537, 33.32337588071823, 91.20428681373596, 95.57091370224953, 82.4618299305439, 38.32703098654747, 29.95796676725149, 25.635172426700592, 31.37394178658724, 50.98581612110138, 61.60987123847008, 65.33041879534721, 73.77685636281967, 59.16140802204609, 1.6721749654971063, 0.010210459386144066, 0.06830025886301883, 0.029655777725565713, 0.03932430139684584, 0.07967004290549085, 0.006284765349846566, 0.02667582102731103, 0.04969455723767169, 0.037382279042503797, 0.03016734011907829, 0.03162409622746054, 0.02614394234115025, 0.019522530456015375, 0.1327311378554441, 0.12508324667578563, 0.17336727061774582, 0.09511631054920144, 0.21115824667504057, 0.09914794616634026, 0.21577599341981113, 0.13889566878788173, 0.08243147050961852, 0.12128506845328957, 0.23982812388567254, 0.18398670625174418, 0.2010834138491191, 0.16049448167905211, 0.7122664956841618, 66.74143508076668, 114.67963993549347, 87.48935535550117, 98.7545120716095, 45.71686305105686, 65.05681067705154, 91.79277643561363, 90.3674729168415, 129.65805619955063, 118.3386155962944, 41.7542988806963, 0.6853466026950628, 0.4703956103185192, 0.8155405602883548, 0.30195919855032116, 0.8516353578306735, 0.3597600047942251, 0.792224002070725, 0.3328786144265905, 0.5083038902375847, 0.4808555287308991, 0.920094265602529, 1.38636558316648, 1.1158493114635348, 11.16880813613534, 65.92255622148514, 105.7561607658863, 110.00981971621513, 111.74488261342049, 108.07053297758102, 102.76454329490662, 99.71466735005379, 102.96929910779, 102.69115403294563, 99.90455836057663, 99.1301903128624, 101.41386777162552, 99.28194656968117, 95.01913771033287, 94.73276987671852, 89.69476461410522, 85.4360519349575, 80.72134092450142, 73.53671684861183, 73.19528996944427, 72.03344151377678, 68.49561855196953, 72.53100201487541, 70.18045574426651, 69.85517039895058, 66.9039599597454, 74.13372561335564, 72.7976793050766, 68.81514340639114, 75.82604080438614, 75.26104912161827, 75.20288944244385, 73.96984800696373, 74.94753554463387, 76.65143251419067, 82.53406405448914, 83.46021875739098, 82.69051685929298, 78.85130926966667, 78.24531778693199, 79.1902282834053, 77.10604771971703, 76.34953111410141, 76.77538186311722, 64.56116527318954, 74.55498620867729, 62.82791867852211, 68.69549542665482, 86.66747465729713, 79.96476352214813, 78.96943733096123, 73.57251852750778, 67.81800851225853, 71.67526513338089, 76.44113659858704, 72.31918618083, 72.52530232071877, 69.02173832058907, 71.85060292482376, 73.72172892093658, 75.22232159972191, 72.78051182627678, 73.09145674109459, 80.94157710671425, 76.95858523249626, 78.70216727256775, 71.80794641375542, 78.44321116805077, 77.00618147850037, 78.39490815997124, 78.47167164087296, 81.32789477705956, 83.6337174475193, 82.99196988344193, 81.46423146128654, 83.02246704697609, 84.87190380692482, 81.89100936055183, 68.43131840229034, 67.46490865945816, 67.63194009661674, 66.0773067176342, 71.88741534948349, 78.20066258311272, 83.58238980174065, 79.32049289345741, 82.40169435739517, 87.02783972024918, 76.86349913477898, 75.3753773868084, 77.2349064052105, 85.91456025838852, 86.11021935939789, 95.51276922225952, 9.811669159680605, 0.5424189940094948, 0.6943943328224123, 1.2117518903687596, 1.1028626770712435, 0.5096218851394951, 0.22137674444820732, 0.7984353031497449, 0.5218233272898942, 1.2237744452431798, 0.7212494511622936, 0.30446771706920117, 0.5556806386448443, 0.28652074572164565, 1.8341873469762504, 43.832323774695396, 99.74112153053284, 102.4059185385704, 112.80402258038521, 120.93370154500008, 40.635011941194534, 18.147493712604046, 27.303434908390045, 52.04192005097866, 67.8724367916584, 75.76432451605797, 80.65644040703773, 76.36164486408234, 2.68070200458169, 0.17284962261328474, 0.126519970363006, 0.14043733215657994, 0.12247745486092754, 0.21524923184188083, 0.1215146147296764, 0.15427651611389592, 0.09809064547880553, 0.14583660493372008, 0.11634367852821015, 0.11451666679931805, 0.18026562232989818, 0.10067358656669967], [0.03776007302803919, 0.008861697824613657, 0.07275001305970363, 0.04604735782777425, 0.055277047722483985, 0.04780634058988653, 0.043728599048336037, 0.016808036270958837, 0.011703957370627904, 0.03061054700083332, 0.056558718206360936, 0.007407124558085343, 0.04492885964282323, 0.22515430580824614, 2.8630765434354544, 74.77179497480392, 72.30450376868248, 74.98559430241585, 41.426167488098145, 32.24992588162422, 30.78053902834654, 31.801335252821445, 86.46639704704285, 102.58630245923996, 53.86670373380184, 1.2784481677226722, 0.2580279152607545, 0.032028952628024854, 0.12931878736708313, 0.14853254542686045, 0.04655038552300539, 0.7810620416421443, 0.36840854852925986, 0.3068037604680285, 0.40858316933736205, 0.22790782211814076, 0.3102137509267777, 0.368676315410994, 0.11723702395102009, 12.298797201365232, 66.9349130988121, 100.13542637228966, 97.40566045045853, 100.16336247324944, 101.30415245890617, 96.63598895072937, 94.60373640060425, 88.65606755018234, 88.53347092866898, 92.32803851366043, 91.77795723080635, 87.0464663207531, 85.37707149982452, 80.83469644188881, 74.32354062795639, 70.89311510324478, 67.64440342783928, 66.90634623169899, 63.592152670025826, 62.77267724275589, 62.94815182685852, 62.022232711315155, 64.15739893913269, 63.751094341278076, 65.28738990426064, 64.18338194489479, 62.54507705569267, 62.68297165632248, 64.85838532447815, 63.451913595199585, 67.49043568968773, 65.63235059380531, 68.23897272348404, 65.92636361718178, 70.72941988706589, 73.24798554182053, 72.52843335270882, 69.51834887266159, 64.47415754199028, 71.40053227543831, 71.96864739060402, 68.81452023983002, 66.15033119916916, 61.7966578155756, 63.91003981232643, 71.11652791500092, 59.714692533016205, 72.35126405954361, 78.17401841282845, 72.68681645393372, 79.17005136609077, 79.45787832140923, 72.47133761644363, 69.76910501718521, 67.2912123799324, 65.20048096776009, 65.65019443631172, 69.29264858365059, 73.16239133477211, 67.999007999897, 70.55085226893425, 66.16541638970375, 61.629702374339104, 67.405776232481, 70.06659865379333, 68.41266140341759, 66.99072450399399, 67.03100234270096, 63.58455687761307, 58.32673341035843, 64.59290876984596, 63.864586651325226, 67.60237768292427, 70.78411415219307, 71.94550663232803, 73.11215043067932, 74.31658700108528, 72.90128454566002, 69.57301273941994, 61.96767143905163, 60.60468837618828, 59.77956645190716, 63.28175112605095, 71.67658746242523, 71.08343929052353, 71.09917044639587, 79.54804748296738, 74.91350457072258, 73.6477392911911, 66.58971682190895, 66.6775681078434, 74.5478729903698, 77.15153127908707, 74.92259368300438, 38.84071782231331, 0.47182201815303415, 0.10136218086699955, 0.5988047027494758, 0.19499145011650398, 0.26259607169777155, 0.06907599614351057, 0.406916958745569, 0.13566480309236795, 0.22496971883811057, 0.12431429262505844, 0.28302235063165426, 0.036403924314072356, 0.14088370429817587, 0.07403116775094531, 4.680676236748695, 45.39178289473057, 83.7529930472374, 75.9788154065609, 73.94733801484108, 51.89456395804882, 34.07089836895466, 22.278966419398785, 18.421478010714054, 31.165906749665737, 57.03231006860733, 61.33345127105713, 66.0685595870018, 39.38516780734062, 0.1389747075154446, 0.07415774103719741, 0.0976207027269993, 0.061084857952664606, 0.03874285837810021, 0.05041032527515199, 0.0614209543709876, 0.061055075566400774, 0.016331080223608296, 0.03646267272415571, 0.04348959409981035, 0.03406780670047738, 0.04937541889376007, 0.04122008795093279, 0.05486004978592973, 0.08759254356846213, 0.056715545142651536, 0.05429705655842554, 0.04517184992437251, 0.014685981877846643, 0.03068541300308425, 0.08144579449435696, 0.08046447488595732, 0.04884886140644085, 0.04739481970318593, 0.07789466239046305, 0.2579205413348973, 3.373246667906642, 86.64397671818733, 82.08440378308296, 82.71418198943138, 56.5865445882082, 39.74563166499138, 36.284811571240425, 38.444695472717285, 98.1025430560112, 112.19061389565468, 70.72338581085205, 2.2246326645836234, 0.33499640703666955, 0.0323271030356409, 0.4369207425042987, 0.031108977091207635, 0.10493522859178483, 1.190008269622922, 0.6506618263665587, 0.7040237286128104, 0.4068116034613922, 0.26374292734544724, 0.36161017895210534, 1.760885955300182, 0.8760056470055133, 14.02300788089633, 71.2859608232975, 101.26682326197624, 100.47016561031342, 103.56927931308746, 104.99220415949821, 98.12525063753128, 97.31641083955765, 89.51838567852974, 92.01301261782646, 94.2317895591259, 93.35830003023148, 91.05009868741035, 89.14102792739868, 83.84687840938568, 77.75423213839531, 73.35931196808815, 71.39273509383202, 66.4170540869236, 68.57736736536026, 65.16385853290558, 64.74186077713966, 64.834074229002, 69.44105342030525, 68.43587815761566, 67.72402435541153, 67.78366595506668, 65.6613202393055, 66.60232454538345, 69.4207701086998, 66.60474881529808, 70.56565627455711, 68.76428693532944, 72.35205441713333, 70.56181088089943, 74.07541394233704, 75.36742061376572, 74.51685905456543, 71.51623606681824, 71.51267185807228, 74.66365277767181, 74.96449023485184, 70.48287391662598, 70.59334918856621, 66.01684436202049, 69.20180305838585, 71.35519310832024, 63.90017554163933, 76.11303180456161, 81.15880385041237, 74.95252847671509, 79.83352616429329, 79.22207817435265, 76.23659357428551, 73.20426508784294, 68.91759350895882, 71.1549286544323, 71.48606568574905, 70.34355819225311, 73.55608060956001, 72.15483739972115, 73.15794557332993, 68.39096456766129, 69.05527532100677, 72.43178933858871, 73.86378809809685, 69.67140465974808, 70.83179399371147, 73.01440447568893, 69.81569811701775, 62.461101561784744, 64.7888794541359, 64.43331733345985, 68.31143483519554, 71.67986288666725, 74.31255161762238, 76.91859617829323, 78.68672490119934, 76.90561607480049, 74.48531314730644, 64.68716651201248, 64.98215228319168, 63.1049770116806, 66.44997552037239, 74.20549616217613, 75.88760510087013, 74.7966380417347, 82.61945307254791, 78.06436389684677, 76.01133406162262, 70.36894842982292, 70.48967555165291, 78.77871796488762, 82.52838715910912, 83.12583670020103, 49.28530476987362, 0.4608734993962571, 0.10756416799267754, 1.1584677058272064, 0.5196038901340216, 0.5261971894651651, 0.09979302092688158, 0.11666683931252919, 0.11856339027872309, 0.14303340925835073, 0.08781184078543447, 0.32471398066263646, 0.1010370756557677, 0.1282031019218266, 0.30393066932447255, 5.986407771706581, 57.777275294065475, 93.55448350310326, 86.3475014269352, 68.9178366959095, 30.267429761588573, 29.577377289533615, 31.247670762240887, 29.80018213391304, 40.73937714099884, 70.5512398481369, 69.65790778398514, 78.55852738022804, 43.29255513846874, 0.14651721372501925, 0.08658305945573375, 0.08923778106691316, 0.055015700418152846, 0.09148267388809472, 0.02466386795276776, 0.1122314679378178, 0.07919405907159671, 0.08512473927112296, 0.05031215026974678, 0.047848335016169585, 0.06346772715914994, 0.04047044087201357, 0.17377695097820833, 0.12133392403484322, 0.22832574031781405, 0.20253505470464006, 0.15645693114493042, 0.10307814503903501, 0.16717222257284448, 0.16831622837344185, 0.1759375655092299, 0.24536133947549388, 0.20177451660856605, 0.15558995422907174, 0.21325255773263052, 0.40723913989495486, 5.465939724817872, 107.26574376225471, 93.08520868420601, 96.90970346331596, 58.8069174438715, 45.08162073791027, 45.26207685470581, 51.083862259984016, 110.62739297747612, 121.4315128326416, 83.361104875803, 3.4654553700238466, 0.3483775374479592, 0.14222559635527432, 0.7539379096124321, 0.47578110883478075, 0.7142029074020684, 2.3378917621448636, 1.697336621582508, 1.024075448513031, 0.8182116388343275, 0.6646733963862062, 0.8164436649531126, 2.8013125201687217, 2.133914907462895, 15.00103835016489, 78.30038443207741, 106.82106882333755, 108.2930338382721, 107.85117074847221, 111.20812341570854, 101.03161588311195, 98.83024960756302, 92.21983551979065, 93.73987555503845, 96.77744776010513, 98.13323020935059, 93.8798600435257, 94.36703190207481, 89.71312522888184, 81.99937954545021, 77.59733095765114, 74.69883888959885, 71.35952487587929, 71.18910402059555, 68.66280198097229, 68.57064932584763, 68.41826990246773, 73.32189917564392, 71.75955221056938, 72.076675593853, 68.95662501454353, 70.12348920106888, 71.04305505752563, 75.55578410625458, 71.55554875731468, 76.49721398949623, 74.3982370197773, 76.99907585978508, 75.38780272006989, 80.06752520799637, 81.71273812651634, 83.04041728377342, 78.58545273542404, 78.74970272183418, 80.28554990887642, 80.61626136302948, 75.13096690177917, 74.84550341963768, 68.85170504450798, 67.89276570081711, 71.73653304576874, 64.6286192536354, 79.2272686958313, 86.77329897880554, 79.21820998191833, 82.68467277288437, 83.05869430303574, 76.27987325191498, 73.48782867193222, 73.88941392302513, 73.24082672595978, 71.67451277375221, 73.47050160169601, 77.2359399497509, 75.81471741199493, 75.79878106713295, 74.6283982694149, 70.30188962817192, 73.61726492643356, 81.22621983289719, 74.9011704325676, 74.92640107870102, 76.29897862672806, 74.45936813950539, 67.52009689807892, 73.69013741612434, 71.8691535294056, 74.3595626950264, 74.68743190169334, 77.26864859461784, 79.12939354777336, 80.25883734226227, 80.95711067318916, 77.76724264025688, 67.98761621117592, 68.35751876235008, 67.25866332650185, 70.02731636166573, 77.85770818591118, 78.5757252573967, 77.48978152871132, 86.20135366916656, 81.68927818536758, 79.76945400238037, 73.47806319594383, 72.60742351412773, 82.61437654495239, 85.49719825387001, 89.40150395035744, 59.023540019989014, 0.5168672651052475, 0.19396189833059907, 2.1324811968952417, 1.2505517271347344, 0.9220748499501497, 0.3785126516595483, 0.6447181140538305, 0.39489134622272104, 1.0005520982667804, 1.239266807679087, 0.710020816186443, 0.2835769724333659, 0.3485654789255932, 0.6786649581044912, 9.977554008364677, 68.00413772463799, 102.75751367211342, 93.4968101978302, 100.22922813892365, 71.07416778802872, 44.864929765462875, 31.36628709733486, 31.055832356214523, 48.69135484099388, 78.33161875605583, 80.81261962652206, 87.7775850892067, 54.64907415211201, 0.21487778692971915, 0.2619971882086247, 0.20096597640076652, 0.15031153277959675, 0.1266749604837969, 0.11441724127507769, 0.20281570527004078, 0.1360344816930592, 0.1446152970311232, 0.11540734791196883, 0.13058331795036793, 0.1383079175138846, 0.14168140914989635], [0.050315378612140194, 0.04482561576878652, 0.03514759075187612, 0.058257839336874895, 0.008138590874295915, 0.059966489643557, 0.07359418377745897, 0.01631488099519629, 0.15171058505075052, 0.018238232769363094, 0.1422030499088578, 0.07962109084473923, 0.09989787155063823, 0.23849113000323996, 20.198773741722107, 76.26012951135635, 68.17578211426735, 63.96948382258415, 42.82127022743225, 36.83367691934109, 58.844421431422234, 66.94555252790451, 92.96644225716591, 84.32267367839813, 11.169637441635132, 0.06947721602045931, 0.0636540210689418, 0.19330575072672218, 0.07196750739240088, 0.3218802233459428, 0.2200956194428727, 0.6850563932675868, 0.3133370348950848, 0.6334729143418372, 0.13716063142055646, 0.20624264638172463, 0.5320537439547479, 0.658216355368495, 0.324199998867698, 27.09729216992855, 88.82352456450462, 96.58787593245506, 99.76511344313622, 97.61181458830833, 97.69362419843674, 96.5638916194439, 97.75144189596176, 93.15317943692207, 91.62614017724991, 88.92021417617798, 87.00927391648293, 79.71068635582924, 75.08255749940872, 70.47942370176315, 69.00081664323807, 67.2012560069561, 68.01977008581161, 68.5499556362629, 67.2034902870655, 69.89294797182083, 67.59397253394127, 70.61131462454796, 72.74643525481224, 74.14971515536308, 70.92377185821533, 69.75179314613342, 65.0223009288311, 62.466675862669945, 63.46159167587757, 63.9912186563015, 66.76050245761871, 65.30832678079605, 69.65087816119194, 68.14360544085503, 73.89679312705994, 71.376251578331, 65.98676517605782, 61.867691203951836, 65.33972069621086, 72.09027126431465, 70.60152634978294, 64.9517235159874, 64.54687044024467, 66.90383836627007, 67.10534155368805, 69.49170470237732, 67.4390472471714, 73.91542732715607, 74.48324605822563, 72.63679593801498, 74.22196447849274, 74.89004462957382, 79.05035018920898, 79.13512364029884, 75.13111129403114, 67.63545110821724, 68.1034491956234, 62.32036851346493, 66.20994240045547, 72.34417364001274, 71.17407962679863, 74.19254645705223, 63.249221071600914, 72.2134530544281, 70.93383371829987, 69.70167383551598, 66.83893784880638, 67.8143835067749, 62.120719626545906, 56.73049606382847, 59.54080246388912, 63.16438302397728, 68.90653610229492, 66.91920474171638, 75.19848167896271, 78.6978355050087, 75.26483371853828, 72.41785928606987, 68.08778643608093, 61.803771033883095, 58.89493212103844, 59.66121420264244, 59.38908040523529, 71.20385482907295, 70.00488996505737, 76.16940557956696, 72.65469297766685, 75.96480175852776, 70.03030300140381, 66.52679979801178, 63.32457862794399, 69.44946616888046, 77.17100903391838, 72.32858687639236, 62.42485150694847, 13.915972374379635, 0.2488497452577576, 0.09945500234607607, 0.30020007106941193, 0.8560751227196306, 0.2000545448390767, 0.09922682162141427, 0.18233443319331855, 0.050604808784555644, 0.10574539410299622, 0.1486111685517244, 0.10486962273716927, 0.08883634596713819, 0.0061913915760669624, 0.21283653943100944, 13.396081421524286, 62.94605053961277, 84.4631065428257, 71.36230632662773, 96.18493035435677, 77.068642526865, 38.7531591206789, 25.491388142108917, 21.247610561549664, 25.599328950047493, 59.02501054108143, 55.282572358846664, 68.79429012537003, 6.867320202291012, 0.25086411216761917, 0.06506377510959283, 0.08442420381470583, 0.05220848601311445, 0.006147540389065398, 0.08475509777781554, 0.022096218817750923, 0.041612261047703214, 0.03600759147957433, 0.07312395900953561, 0.03320140494906809, 0.023728093947283924, 0.054246627623797394, 0.055131041299318895, 0.052452370582614094, 0.12798265437595546, 0.01918147649121238, 0.13702784635825083, 0.06431651403545402, 0.07998584158485755, 0.1422745335730724, 0.02901518553699134, 0.09329451611847617, 0.14236088987672701, 0.1903858597506769, 0.4034454590873793, 23.59069213271141, 89.41120103001595, 74.4907620549202, 76.23758152127266, 47.18766912817955, 45.498344376683235, 40.588415041565895, 63.19970592856407, 105.89547649025917, 98.16870510578156, 17.692897506058216, 0.27733951807022095, 0.04378765916044358, 0.42395058379042894, 0.18542371195508167, 0.39968496712390333, 0.3152850241167471, 1.1550786439329386, 0.24326578160980716, 0.5814792949240655, 0.3232090832898393, 0.2618193399393931, 0.6596706679556519, 1.694493186660111, 1.141712861135602, 32.08803556859493, 95.39983168244362, 102.20443814992905, 103.72010841965675, 99.91920277476311, 102.90262028574944, 98.81851583719254, 102.06164941191673, 95.4044522345066, 94.05778169631958, 91.86087638139725, 89.55322220921516, 82.64874950051308, 77.63127833604813, 72.15480700135231, 70.17737030982971, 70.18681660294533, 70.5963434278965, 72.88015007972717, 71.80256590247154, 72.80142590403557, 71.60670161247253, 73.62912029027939, 75.92012375593185, 78.34714472293854, 75.91540440917015, 75.19630059599876, 68.74096378684044, 65.71957871317863, 67.48329967260361, 68.18570718169212, 69.32348772883415, 70.32034903764725, 73.05289641022682, 72.65573412179947, 76.89750730991364, 74.29774761199951, 68.9018851518631, 68.94755110144615, 71.5727086365223, 75.56820183992386, 73.38395744562149, 67.61101841926575, 69.25763726234436, 68.71984452009201, 68.70874151587486, 68.9728881418705, 70.49362733960152, 77.94379636645317, 79.73789289593697, 77.40825310349464, 76.67468726634979, 76.06174975633621, 80.23397907614708, 79.40584391355515, 76.36147007346153, 73.42754110693932, 70.28432697057724, 68.05965274572372, 68.48320081830025, 73.61144363880157, 72.24464178085327, 75.62570035457611, 71.10189110040665, 74.14190277457237, 72.20048055052757, 73.98587554693222, 70.40104910731316, 72.30339422821999, 66.72491356730461, 58.42199809849262, 62.54301376640797, 68.69535103440285, 74.34476628899574, 70.91214448213577, 76.23671516776085, 80.56056395173073, 76.30319640040398, 75.46209633350372, 69.87391099333763, 65.19798070192337, 62.371893748641014, 63.97669583559036, 64.66894268989563, 75.51085531711578, 73.24822872877121, 78.95100831985474, 75.90581372380257, 79.82336550951004, 74.31423112750053, 68.57365876436234, 67.69650623202324, 72.72529318928719, 81.01181253790855, 79.02925372123718, 75.06938740611076, 18.560962826013565, 0.15236836537951604, 0.3209806513041258, 0.8884108532220125, 1.626177008729428, 0.3037306753685698, 0.3221506025874987, 0.1954874867806211, 0.1969737117178738, 0.5774652259424329, 0.19851519697112963, 0.5378849466796964, 0.14822608296526596, 0.021664110754500143, 0.10934372679912485, 16.553711034357548, 74.68908101320267, 92.44704812765121, 81.53329655528069, 60.55172681808472, 26.78635485470295, 19.58491288125515, 29.2527512088418, 33.590847328305244, 34.69634100794792, 76.7764762043953, 64.63355898857117, 83.17021831870079, 7.367686377838254, 0.29802195669617504, 0.10416628938401118, 0.08790901760221459, 0.02841772511601448, 0.06937984624528326, 0.03708219534019008, 0.06442114943638444, 0.04193735141598154, 0.048222822733805515, 0.07984698575455695, 0.08108354479190893, 0.08225368161220104, 0.2544858225155622, 0.1393695449223742, 0.1683390568359755, 0.1327370898798108, 0.21661421953467652, 0.2495978301158175, 0.1609038800233975, 0.24783487315289676, 0.47414633561857045, 0.12755421252222732, 0.1924092957051471, 0.29231629567220807, 0.3066766750998795, 0.49965074518695474, 32.7912562340498, 103.42320755124092, 87.20735728740692, 85.91168001294136, 61.28779672086239, 50.71987599134445, 80.71330815553665, 98.86374101042747, 111.1270509660244, 114.3793648481369, 22.188818156719208, 0.524295213399455, 0.2608125424012542, 0.5468106083571911, 0.4008048976538703, 0.6894989486318082, 0.5890155374072492, 1.8951092404313385, 0.8170866023283452, 2.0678979624062777, 1.412983036134392, 0.7733688200823963, 1.2625436461530626, 3.6061570700258017, 2.596618691459298, 33.10997933149338, 105.67895650863647, 110.1848991215229, 109.97880578041077, 106.78769901394844, 106.29650697112083, 102.40812242031097, 105.42829915881157, 99.54756751656532, 97.3750188946724, 96.9895675778389, 97.34557047486305, 87.11854845285416, 82.55499333143234, 76.21713101863861, 76.90592765808105, 71.37427568435669, 74.63188648223877, 75.1059490442276, 74.71950218081474, 76.73226937651634, 74.90987196564674, 77.6164211332798, 77.63960748910904, 80.28720661997795, 77.75435373187065, 78.9708736538887, 73.01004230976105, 70.81215664744377, 73.60854059457779, 70.78344538807869, 75.11810079216957, 73.0120562016964, 76.45959600806236, 75.33545672893524, 83.2615502178669, 83.06980490684509, 79.46511313319206, 75.88712632656097, 76.72754243016243, 80.5176642537117, 77.35506355762482, 70.17403408885002, 69.92150723934174, 71.05932578444481, 69.0415732562542, 70.2637928724289, 72.45928466320038, 81.04294806718826, 79.87412318587303, 79.17557626962662, 80.69300204515457, 79.50160637497902, 80.64278393983841, 84.50679659843445, 77.46265098452568, 75.36785379052162, 71.62411227822304, 68.81341829895973, 74.41415056586266, 80.2051006257534, 77.37616002559662, 78.98297980427742, 70.75606405735016, 77.39548578858376, 77.66454935073853, 76.81022599339485, 75.02446621656418, 77.48851999640465, 74.99019965529442, 64.40586760640144, 66.14304319024086, 73.55000853538513, 80.5535039305687, 75.33759981393814, 80.96874564886093, 85.80467775464058, 82.58183509111404, 80.24841830134392, 75.7803900539875, 69.1376169025898, 65.84006264805794, 67.6871207356453, 68.29346939921379, 80.12566968798637, 77.4179957807064, 83.20054069161415, 79.69927936792374, 82.3519018292427, 78.95887389779091, 71.78038269281387, 71.5224677324295, 74.8213443160057, 84.18143525719643, 80.7950721681118, 86.60186737775803, 21.36630669236183, 0.38212987943552434, 0.8287261496298015, 1.5615659882314503, 2.986931847408414, 0.5156274035107344, 0.5406799935735762, 0.5139379191678017, 0.24536447133868933, 1.0463479533791542, 0.8902659255545586, 0.5382984119933099, 0.22407992830267176, 0.16548738407436758, 0.5026598274707794, 24.83865726739168, 83.49776834249496, 103.87089192867279, 91.66447252035141, 131.33470863103867, 99.25799265503883, 50.79300306737423, 38.23777757585049, 36.90684959292412, 43.55966180562973, 79.25828263163567, 74.0077243745327, 94.68471765518188, 9.318641815334558, 0.5290758318733424, 0.2616715634940192, 0.23477872920921072, 0.09007392174680717, 0.21731909655500203, 0.17515972052933648, 0.15816847211681306, 0.2050535031594336, 0.1291485535330139, 0.18847097031539306, 0.15746743942145258, 0.17460346600273624], [0.05906685451918747, 0.018277052658959292, 0.015984877609298564, 0.018378086788288783, 0.03702245987369679, 0.051222917609266005, 0.059549825673457235, 0.032588799149380066, 0.01632395746128168, 0.004494716285989853, 0.0752936871140264, 0.06939111204701476, 0.060327065802994184, 0.1068616658449173, 28.223004564642906, 81.24819025397301, 65.08257329463959, 78.42510133981705, 38.316934928298, 39.252752512693405, 58.44532884657383, 69.58864510059357, 99.06667292118073, 45.626389905810356, 1.3029925944283605, 0.019943322622566484, 0.1932835456682369, 0.07201944288681261, 0.310040355543606, 0.12567127996589988, 0.1269770591170527, 0.15283605200238526, 0.40563004498835653, 0.6406930612865835, 0.6927500304300338, 0.4067001328803599, 0.4054375021951273, 0.32816523453220725, 4.390595527365804, 72.56642371416092, 101.10482275485992, 90.90442970395088, 92.94116601347923, 90.88475435972214, 92.89504408836365, 89.3855220079422, 93.84690061211586, 92.84000024199486, 92.23644062876701, 89.6215957403183, 83.44184294342995, 76.39354795217514, 72.42988184094429, 70.5809998512268, 68.95658701658249, 70.52872225642204, 74.4261047244072, 80.16039222478867, 78.23051378130913, 79.47960555553436, 77.26880818605423, 82.74322763085365, 79.65155392885208, 77.05605760216713, 76.99323177337646, 76.57089963555336, 68.14055040478706, 66.93058893084526, 63.69643047451973, 67.3600722849369, 64.78625759482384, 66.78666025400162, 70.23502081632614, 73.05429473519325, 68.58467817306519, 65.64205527305603, 57.20996953547001, 63.696829453110695, 71.9497700035572, 72.06336110830307, 71.5246944129467, 72.43671387434006, 74.72464710474014, 67.8889887034893, 68.52325826883316, 70.53164049983025, 72.8092534840107, 74.13256287574768, 80.03414779901505, 74.03982505202293, 70.65161526203156, 72.90494754910469, 72.71200150251389, 74.59236860275269, 74.93699491024017, 79.76854965090752, 69.18870896100998, 71.36994391679764, 57.04655550420284, 65.1959440112114, 60.34964606165886, 66.44649490714073, 63.37502472102642, 63.74611280858517, 67.58394107222557, 68.54065373539925, 67.56010875105858, 64.06387075781822, 53.168445602059364, 46.0418976098299, 61.103461012244225, 62.83424913883209, 65.36679044365883, 68.83150532841682, 70.30705735087395, 69.9718089401722, 69.52923908829689, 68.56932699680328, 66.1837238073349, 63.07073324918747, 58.02920177578926, 61.26239128410816, 62.071747854352, 67.2587925195694, 70.68424791097641, 72.93052777647972, 73.72682064771652, 78.253213763237, 69.21652346849442, 66.46360158920288, 60.77575899660587, 69.18600350618362, 70.55962219834328, 76.50616630911827, 63.634831979870796, 41.695599630475044, 3.3105889800935984, 0.5838139727711678, 0.22138199885375798, 0.9079110505990684, 0.3619185264687985, 0.41017026698682457, 0.1140511546691414, 0.3487856889842078, 0.12484020815463737, 0.1931194419739768, 0.4008619539672509, 0.02880609841668047, 0.15594109398080036, 0.07190803167759441, 1.2156336195766926, 28.211804665625095, 77.29068741202354, 83.8438081741333, 79.43935051560402, 77.31324300169945, 85.9927448630333, 36.404315158724785, 39.25836481153965, 62.36807495355606, 27.6981121301651, 56.63824841380119, 65.62396064400673, 24.61853887885809, 0.4449766961624846, 0.11861377468449064, 0.1359544781735167, 0.0448368407523958, 0.10493857567780651, 0.03211867828213144, 0.04053640295751393, 0.03863458645355422, 0.09280097307055257, 0.04515276930760592, 0.05851542024174705, 0.044328573494567536, 0.012635401872103103, 0.009578520639479393, 0.0847017670457717, 0.054489376707351767, 0.006045016862117336, 0.09641731769079342, 0.07136227111914195, 0.05726326126023196, 0.06990631838561967, 0.045445657888194546, 0.08948708331445232, 0.026171444478677586, 0.044141184916952625, 0.15367257117759436, 36.65296621620655, 94.66146290302277, 72.63451606035233, 85.59214755892754, 49.81151193380356, 35.610252767801285, 31.95509970188141, 80.28492674231529, 110.9455195069313, 60.43579503893852, 1.7372426739893854, 0.05862827863893472, 0.5018086137715727, 0.3364645829424262, 0.6308388244360685, 0.2026560841477476, 0.03957034932682291, 0.21162633405765519, 0.8293177897576243, 0.8049403165932745, 1.1958339507691562, 1.1146226897835732, 1.4800709299743176, 0.724027695832774, 6.402135388925672, 79.16807547211647, 106.62649646401405, 98.84184658527374, 98.80106717348099, 94.6650119125843, 95.59539958834648, 92.83914908766747, 96.31704166531563, 96.73441126942635, 93.86804267764091, 91.84027388691902, 87.19233289361, 79.78702425956726, 73.60129818320274, 72.51083269715309, 70.91168090701103, 72.89293259382248, 77.39693731069565, 80.53985506296158, 82.42347478866577, 84.24993798136711, 80.55675655603409, 87.9018384218216, 82.88942858576775, 81.30643352866173, 83.09207171201706, 81.59099265933037, 72.76907444000244, 69.04681697487831, 70.14080867171288, 68.77858176827431, 70.58350011706352, 68.77313286066055, 73.98710668087006, 76.75892114639282, 72.0219737291336, 68.7542174756527, 66.47697687149048, 68.73140349984169, 74.4103279709816, 74.9534024298191, 74.21631038188934, 76.53540953993797, 77.47328281402588, 69.03484001755714, 69.90323022007942, 73.50083917379379, 75.38763552904129, 75.50814226269722, 81.5421424806118, 76.7520359158516, 76.23235300183296, 75.46714246273041, 76.14748075604439, 76.78143873810768, 75.13981282711029, 79.55390676856041, 71.03822931647301, 73.05446192622185, 63.47034640610218, 67.7102766931057, 63.36131125688553, 64.3848167359829, 68.5353872179985, 69.22913119196892, 70.80704972147942, 71.24021887779236, 68.37109163403511, 67.19169571995735, 60.26171118021011, 53.97292323410511, 67.75677099823952, 70.32660350203514, 71.21826365590096, 73.65013316273689, 76.5091985464096, 74.40279677510262, 72.38185241818428, 70.67107021808624, 69.59137335419655, 65.49382522702217, 60.32859519124031, 63.74372273683548, 65.4949651658535, 70.18547147512436, 74.48972851037979, 75.30013382434845, 77.97267481684685, 80.8286015689373, 75.64578607678413, 70.51677569746971, 65.00704854726791, 72.26343557238579, 76.56142294406891, 80.82711964845657, 72.19903662800789, 54.46856863796711, 4.68522316776216, 0.36832299374509603, 0.7066302106250077, 1.8942616484127939, 1.6925753583200276, 0.3950890840496868, 0.007185891263361555, 0.2066751997335814, 0.1306412648409605, 0.1820183970266953, 0.4496596776880324, 0.31778956472408026, 0.33539511845447123, 0.22033865796402097, 1.4467457681894302, 37.38195709884167, 86.50874197483063, 95.54802373051643, 88.9298352599144, 65.65756604075432, 46.26951299607754, 23.683395758271217, 38.89382757246494, 66.2349146604538, 39.81561630964279, 60.38957431912422, 80.77844426035881, 27.90539860725403, 0.37470056558959186, 0.1431710331235081, 0.09733894636156037, 0.06831868638982996, 0.06823698335210793, 0.09208011761074886, 0.06335673155263066, 0.06572686921572313, 0.06794209839426912, 0.03477203434158582, 0.020225544685672503, 0.07460975350113586, 0.11489277239888906, 0.07715058512985706, 0.17781622329493985, 0.12530630658147857, 0.11626010527834296, 0.19181992654921487, 0.14092146477196366, 0.09170120669296011, 0.17644552106503397, 0.2398780852672644, 0.21159575757337734, 0.12309722980717197, 0.16482546256156638, 0.2997860120376572, 44.92259167134762, 108.75267997384071, 81.61650449037552, 98.04015800356865, 53.79260390996933, 55.77105514705181, 87.33988657593727, 92.64876410365105, 119.51080709695816, 72.87371322512627, 3.2630521059036255, 0.1468403299804777, 0.5303907988127321, 0.3757554542971775, 0.8047963993158191, 0.34934995870571584, 0.27424479194451123, 0.5269068013876677, 1.4955095015466213, 1.3026814861223102, 2.190152364782989, 1.762009032536298, 3.2839220110327005, 3.050876003690064, 6.096923891454935, 86.52476951479912, 113.22982773184776, 104.7623772919178, 106.03860720992088, 101.00276783108711, 101.25062093138695, 96.54225558042526, 99.71458375453949, 100.61898082494736, 97.32818260788918, 96.54181480407715, 92.21733525395393, 83.9613738656044, 78.76636102795601, 75.47986418008804, 74.01083260774612, 76.12593591213226, 80.49889326095581, 86.17719456553459, 84.7421407699585, 87.5906503200531, 83.0194728076458, 93.27737957239151, 86.06371745467186, 85.49176454544067, 84.00775417685509, 85.9340988099575, 75.50378769636154, 74.65284615755081, 71.7401884496212, 74.1782820224762, 74.62528243660927, 74.21248778700829, 80.44850036501884, 81.95145651698112, 78.33569973707199, 79.97544094920158, 73.14938843250275, 73.34618747234344, 78.72944220900536, 78.70223566889763, 77.84890785813332, 81.15105986595154, 78.98655161261559, 70.52916303277016, 70.30834928154945, 75.08032321929932, 77.62858048081398, 77.66705721616745, 84.1050973534584, 81.50730594992638, 76.8836684525013, 75.47877743840218, 79.43092256784439, 80.0092363357544, 79.34152856469154, 81.03540927171707, 75.59334129095078, 77.48915076255798, 66.83266058564186, 73.53734761476517, 68.26510012149811, 72.51274779438972, 70.15016376972198, 72.49971449375153, 75.24448961019516, 76.69937074184418, 76.91964492201805, 74.54949170351028, 66.61284998059273, 56.89802527427673, 70.72673723101616, 74.5617726445198, 74.54750061035156, 79.31134298443794, 79.13609638810158, 79.18952152132988, 76.7047892510891, 76.4267885684967, 74.04218852519989, 70.75522050261497, 64.0810914337635, 67.5047305226326, 70.56712299585342, 75.15541478991508, 78.95515009760857, 79.05571550130844, 81.83376923203468, 84.11829024553299, 80.59057474136353, 73.43840092420578, 67.98070058226585, 73.895812779665, 79.10578161478043, 84.89824399352074, 80.06722882390022, 64.08106863498688, 5.33321569673717, 0.5671739531680942, 1.245440763887018, 4.219626551494002, 3.312313612550497, 0.810012094443664, 0.34416834299918264, 0.6805944233201444, 0.7373374316375703, 1.2204405991360545, 1.3033399195410311, 0.6238414999097586, 0.593469551531598, 0.39852819638326764, 2.8605769900605083, 47.8690105676651, 95.34598857164383, 100.83122983574867, 102.95414552092552, 112.60973900556564, 115.8794255554676, 54.344319105148315, 55.236678421497345, 79.25301611423492, 42.9480542242527, 75.83011418581009, 91.29252567887306, 32.721100598573685, 0.5479705554898828, 0.3860256203915924, 0.39501920342445374, 0.1912378749693744, 0.11989838778390549, 0.15552992932498455, 0.18778751167701557, 0.15989212493877858, 0.24003923521377146, 0.17829324613558128, 0.12630464363610372, 0.17098819749662653], [0.049031529924832284, 0.018544971680967137, 0.03154442296363413, 0.030992753054306377, 0.023926662979647517, 0.10601807400234975, 0.10469237560755573, 0.05742149085563142, 0.043666340279742144, 0.03414861916098744, 0.024225579654739704, 0.0669998157536611, 0.05737381899962202, 0.03808787223533727, 31.843678280711174, 76.33136808872223, 63.43236744403839, 55.41878744959831, 34.318975657224655, 53.44317466020584, 60.00680945813656, 92.52988368272781, 90.68305358290672, 15.164269991219044, 0.11100126910605468, 0.0940120244922582, 0.06604951791814528, 0.4179417109116912, 0.1904830217245035, 0.22050786763429642, 0.12738972291117534, 0.07767850445816293, 0.14514709037030116, 0.429045160417445, 2.1071966411545873, 1.8989678146317601, 0.7573620602488518, 0.21889123250730336, 40.07615312933922, 106.2145833671093, 92.1564245223999, 96.6547903418541, 91.29620388150215, 86.52349278330803, 77.37163826823235, 85.75289413332939, 90.01256436109543, 93.96540105342865, 88.8589158654213, 90.03444358706474, 83.56544271111488, 76.98543459177017, 67.17968836426735, 69.37495976686478, 67.05900683999062, 73.73447343707085, 79.50001806020737, 84.65327873826027, 82.68322125077248, 83.02794635295868, 85.0766596198082, 83.49832311272621, 75.80641865730286, 81.3877035677433, 81.90333589911461, 79.94682088494301, 73.98509278893471, 70.33979639410973, 69.48314756155014, 65.25585159659386, 67.93224558234215, 69.82658833265305, 67.70827800035477, 68.7489965558052, 68.639395236969, 57.82792657613754, 58.31445246934891, 71.5787123143673, 71.32818415760994, 71.07928991317749, 73.47647488117218, 76.3604137301445, 72.13127866387367, 69.86800611019135, 77.72424414753914, 80.83022788167, 75.3529965877533, 71.04874715209007, 78.77786681056023, 75.75607135891914, 78.08195695281029, 73.0111214518547, 66.84973686933517, 75.80514952540398, 76.3530421257019, 74.12441611289978, 70.60677006840706, 71.9610857963562, 64.67898175120354, 56.21381118893623, 64.34838429093361, 58.684556409716606, 56.41768924891949, 61.68820023536682, 67.78339236974716, 65.48185586929321, 56.451241448521614, 55.77973388135433, 54.54260006546974, 61.40862263739109, 67.6725523173809, 66.98871061205864, 68.94825026392937, 64.65002730488777, 65.49160614609718, 63.777890503406525, 67.49232038855553, 67.50495091080666, 65.16528725624084, 63.28440718352795, 63.411567360162735, 61.8391889333725, 64.49871182441711, 64.0008245408535, 70.14435768127441, 76.05974346399307, 74.11366268992424, 75.95248281955719, 72.09998354315758, 64.38898891210556, 65.34273013472557, 65.68415701389313, 70.79499676823616, 73.51297572255135, 70.64791426062584, 60.01380108296871, 29.236854761838913, 0.6029534863773733, 0.23068713548127562, 1.2285848683677614, 0.3413075121352449, 0.06421489917556755, 0.23956365213962272, 0.1406445843167603, 0.4022664832882583, 0.13603437779238448, 0.19985612423624843, 0.1948523716419004, 0.10542928372160532, 0.0440006740973331, 0.08254071464762092, 6.234004385769367, 53.85482557117939, 75.8040551841259, 83.17568242549896, 28.65388434380293, 48.77844616770744, 63.529193848371506, 43.530372977256775, 41.023039519786835, 37.01011665165424, 58.41770812869072, 63.73377867043018, 35.536635518074036, 0.2463550158427097, 0.019789731450146064, 0.08592472251621075, 0.033032495848601684, 0.06432538270018995, 0.06456439135945402, 0.05807447319966741, 0.024657632056914736, 0.038817585227661766, 0.09232553842593916, 0.0219291279790923, 0.026320580909668934, 0.07452796882716939, 0.009373645207233494, 0.05794166587293148, 0.01030827723297989, 0.08562840521335602, 0.09134650463238358, 0.016810375891509466, 0.07840317455702461, 0.030667263781651855, 0.03915740722732153, 0.09301661892095581, 0.08514272893080488, 0.10043699730886146, 0.16454467840958387, 42.39811733365059, 86.86250299215317, 70.42199358344078, 70.94418436288834, 46.173442751169205, 37.516010105609894, 47.41299703717232, 103.92345070838928, 104.23870459198952, 21.183158420026302, 0.10198128045885824, 0.049280427701887675, 0.3496127383550629, 0.5215905897784978, 0.4435808944981545, 0.30253620352596045, 0.28236047364771366, 0.045585374609800056, 0.0688962776621338, 0.9981664200313389, 3.745563277043402, 2.4276609951630235, 2.6473682932555676, 0.4438641871092841, 44.45981450378895, 111.43872544169426, 98.94340753555298, 100.89292332530022, 96.12812340259552, 91.89941391348839, 81.27366408705711, 87.51642510294914, 92.36961588263512, 95.76065272092819, 94.24197301268578, 92.87140175700188, 86.51105225086212, 81.4255191385746, 69.70719873905182, 70.38768142461777, 70.21647781133652, 75.14644727110863, 83.50143894553185, 87.31464833021164, 86.7791810631752, 87.43561863899231, 89.10907924175262, 85.45772597193718, 79.32936161756516, 83.9625746011734, 85.09882763028145, 82.9312415421009, 77.73533195257187, 75.00295177102089, 72.98775270581245, 71.93462401628494, 71.56879484653473, 72.68991708755493, 69.90350380539894, 74.85798954963684, 70.95816001296043, 64.69589844346046, 67.86018624901772, 74.76589769124985, 75.67110031843185, 76.3385421037674, 77.26116299629211, 79.60940659046173, 75.08438900113106, 72.84222051501274, 81.98224246501923, 82.69025087356567, 77.26305529475212, 73.11802491545677, 78.35118770599365, 78.92083793878555, 79.99370276927948, 74.91076871752739, 66.99804291129112, 75.85090667009354, 78.62684771418571, 77.09331080317497, 73.4857539832592, 73.68250742554665, 68.15530881285667, 62.291896641254425, 66.64228320121765, 64.95594128966331, 59.18964810669422, 64.41567108035088, 68.61455217003822, 69.57414507865906, 63.33332575857639, 62.68447257578373, 60.042067766189575, 66.70348271727562, 72.54918783903122, 69.72550615668297, 72.50811204314232, 68.82905825972557, 68.75049367547035, 67.83357247710228, 71.50864407420158, 71.23435199260712, 67.66999885439873, 66.42244979739189, 67.78333157300949, 66.65343180298805, 67.77978256344795, 69.2443835735321, 74.13045778870583, 78.23619067668915, 76.85617312788963, 78.07958588004112, 76.60408705472946, 67.93264836072922, 69.73784789443016, 69.4314019382, 74.78229761123657, 79.89866226911545, 79.3584680557251, 71.65275514125824, 37.65875704586506, 0.760106819216162, 0.1570150558836758, 1.9371266732923687, 0.22785743029089645, 0.3066411113832146, 0.25811747764237225, 0.25699166930280626, 0.34693275403697044, 0.10603734757751226, 0.8031982881948352, 0.5946446978487074, 0.20432648045243695, 0.05913252345635556, 0.04197349771857262, 7.1869775746017694, 63.49279560148716, 84.17893499135971, 94.39208015799522, 37.529567778110504, 51.89144052565098, 41.48259066045284, 36.44140116870403, 55.29844030737877, 39.950402677059174, 66.87331840395927, 71.2142738699913, 42.683041244745255, 0.11553869320778176, 0.07206104026408866, 0.13457354914862663, 0.008940178086049855, 0.08206185870221816, 0.021910058494540863, 0.0676368827407714, 0.03753178840270266, 0.07025644881650805, 0.07389840495306998, 0.03186200279742479, 0.028093482651456725, 0.1927333025378175, 0.13057671283604577, 0.24337768263649195, 0.12957839062437415, 0.1822966430336237, 0.15029280097223818, 0.1891091134166345, 0.1662948852754198, 0.09178127700579353, 0.11532195640029386, 0.22100497299106792, 0.25265535979997367, 0.21573398786131293, 0.3054053464438766, 52.26817511022091, 99.33594927191734, 81.47506847977638, 77.05083668231964, 49.32823866605759, 72.83839032053947, 88.54566067457199, 111.9476929306984, 117.66824036836624, 26.057785749435425, 0.21170378458919004, 0.28800985019188374, 0.32390355539973825, 1.4553419756703079, 1.310776595491916, 0.5585710960440338, 0.4371589719085023, 0.26163605914916843, 0.29696781013626605, 2.767980471253395, 8.104454018175602, 3.441316452808678, 5.393168879672885, 0.8644872775766999, 48.43965254724026, 116.48129045963287, 103.96215543150902, 106.98511362075806, 100.36424249410629, 96.66394785046577, 84.43425849080086, 92.53239914774895, 96.27115532755852, 100.04281774163246, 96.70842826366425, 96.7992813885212, 89.9671795964241, 86.12213551998138, 74.839948117733, 74.81836527585983, 73.58259558677673, 80.23885801434517, 87.2560478746891, 91.6861617565155, 89.28520739078522, 89.93848353624344, 92.89502128958702, 90.19738644361496, 85.13182505965233, 89.33420196175575, 87.85691723227501, 89.0100185573101, 81.71532198786736, 79.35677334666252, 76.89977198839188, 77.86774724721909, 74.67723324894905, 78.90813142061234, 77.25888311862946, 82.43274629116058, 80.02521827816963, 73.6634324491024, 72.43720024824142, 78.44931364059448, 79.58989843726158, 77.54411101341248, 81.5031261742115, 82.82915621995926, 75.4317207634449, 73.8303042948246, 85.66859185695648, 85.39358541369438, 80.6834189593792, 75.89471831917763, 82.49739602208138, 81.1975845694542, 82.71219849586487, 76.74865409731865, 69.29524004459381, 76.13567858934402, 80.59551447629929, 79.87088575959206, 73.73646453022957, 79.76684734225273, 71.52787104249, 66.69750943779945, 71.51784718036652, 70.90463608503342, 65.57037591934204, 67.19609588384628, 76.14768594503403, 76.69994071125984, 68.19991081953049, 66.4776836335659, 63.811024725437164, 66.14488989114761, 76.72219231724739, 74.56874147057533, 77.09768056869507, 74.08489063382149, 72.36489772796631, 70.96984818577766, 76.27922728657722, 73.90968963503838, 71.82875409722328, 69.62279006838799, 71.0947322845459, 67.83631592988968, 70.01104563474655, 70.63469097018242, 76.0384950041771, 83.27684059739113, 79.67105448246002, 82.45965644717216, 81.13719820976257, 71.42083838582039, 71.52128219604492, 71.23078778386116, 77.94027775526047, 83.01113605499268, 82.307558208704, 80.85456177592278, 45.63868224620819, 0.8642278821207583, 0.7114002609159797, 3.9623114839196205, 0.7584003545343876, 0.9486318624112755, 0.4857607983285561, 0.9650249546393752, 1.1948000499978662, 0.26544651249423623, 3.051146501675248, 1.5947562572546303, 0.5096807226072997, 0.22179669613251463, 0.25165482598822564, 11.93370709195733, 75.35927385091782, 92.4155706167221, 100.57018384337425, 48.00102308392525, 81.67294666171074, 91.50077730417252, 58.44391532242298, 50.619394183158875, 58.413828536868095, 73.91016080975533, 84.37636479735374, 47.70914934575558, 0.32922781188972294, 0.1573494527838193, 0.4576328373514116, 0.08884678056347184, 0.1181403141526971, 0.11937130708247423, 0.17781598580768332, 0.14149518945487216, 0.17397878546034917, 0.1511622269754298, 0.15220409841276705, 0.11733308754628524], [0.023290169301617425, 0.03076763554417994, 0.041536235439707525, 0.026537425328569952, 0.017518267886771355, 0.010773782869364368, 0.09519792452920228, 0.027407864363340195, 0.07767744318698533, 0.004599232015607413, 0.05279658980725799, 0.02266599713038886, 0.05481602929648943, 0.042946731628035195, 25.885774679481983, 72.76120886206627, 62.00682833790779, 55.40351986885071, 51.45942650735378, 49.539332538843155, 57.4528981000185, 94.40836608409882, 56.30106210708618, 2.383131184615195, 0.030051199573790655, 0.22104852221673355, 0.6965404457878321, 0.6186936073936522, 0.45485940179787576, 0.2377858670661226, 0.12102145759854466, 0.5174738075584173, 0.2745118166785687, 0.08900209722924046, 0.5784630286507308, 0.7267146266531199, 0.4590860812459141, 22.14798554778099, 108.34684655070305, 93.83933141827583, 89.6270826458931, 92.38189682364464, 93.60755905508995, 84.95774880051613, 77.69946187734604, 78.4940904378891, 89.93120312690735, 89.23714756965637, 88.49350467324257, 85.98557844758034, 89.84242469072342, 80.39157181978226, 71.94600060582161, 63.6588428914547, 65.91298073530197, 71.822340041399, 78.94144803285599, 83.34231868386269, 83.33593502640724, 83.97670984268188, 87.25275725126266, 78.34842145442963, 77.51329466700554, 83.42440187931061, 79.08612906932831, 77.30763450264931, 75.49136996269226, 74.28366556763649, 74.39775064587593, 71.68826803565025, 69.51703414320946, 65.13997301459312, 66.98433324694633, 72.47243955731392, 61.84005908668041, 55.273422449827194, 73.03578212857246, 75.83791896700859, 73.08239802718163, 70.71916803717613, 74.49181079864502, 74.90364789962769, 76.20608121156693, 75.58082476258278, 75.11446818709373, 72.21457779407501, 73.67315232753754, 65.73423832654953, 67.28533029556274, 71.34725913405418, 68.37972477078438, 68.61566931009293, 63.75227987766266, 63.627790957689285, 73.96576702594757, 70.58704912662506, 75.38917824625969, 72.7587541937828, 76.48639976978302, 62.44898781180382, 60.64894080162048, 67.8709776699543, 56.333538964390755, 54.27591137588024, 52.90345922112465, 54.59921322762966, 60.23636274039745, 54.58220154047012, 55.43130777776241, 71.24390468001366, 67.99707010388374, 66.63782984018326, 65.54393693804741, 64.07789200544357, 62.0063229650259, 61.84923939406872, 63.344736546278, 61.840302273631096, 64.62628617882729, 67.5700718164444, 67.65587881207466, 66.9343127310276, 69.61642161011696, 67.98519194126129, 71.91170364618301, 70.89761406183243, 76.92188680171967, 75.7226787507534, 75.17061397433281, 70.0894658267498, 66.520986109972, 66.7798662185669, 68.81974875926971, 70.4502260684967, 75.31474024057388, 66.67524263262749, 58.106801211833954, 17.47864980250597, 0.053530666627921164, 0.18145335547160357, 0.19949187815655023, 0.11620852601481602, 0.11826118774479255, 0.15071612200699747, 0.021417348507384304, 0.08366533555090427, 0.4543316754279658, 0.5091809306759387, 0.41435028018895537, 0.15069093351485208, 0.026667930142139085, 0.5154426977969706, 18.63545212894678, 73.45535561442375, 73.35119560360909, 79.28115740418434, 88.67917031049728, 54.37086068093777, 34.22654561698437, 17.31567084789276, 43.96132305264473, 49.181900918483734, 65.25221139192581, 38.93005482852459, 0.14655357896117494, 0.013615241823572433, 0.042463270656298846, 0.02590765550849028, 0.06691688075079583, 0.06775524787371978, 0.034382384546916, 0.07333801666391082, 0.032847667680471204, 0.03762333231861703, 0.02646358905622037, 0.0062296970645547844, 0.03218454017769545, 0.011461553385743173, 0.01017527973090182, 0.015706657577538863, 0.06457270341343246, 0.047473134836764075, 0.029791939559800085, 0.04014426325738896, 0.05060013696493115, 0.06771224783733487, 0.0329476609476842, 0.019928568726754747, 0.08696487959241495, 0.06456584596890025, 33.96920062601566, 80.8218303322792, 67.73113757371902, 49.19219836592674, 39.95661914348602, 40.584600046277046, 62.035300210118294, 108.76353219151497, 69.1033199429512, 3.139870553277433, 0.10141065795323811, 0.4401335591683164, 1.60505156731233, 0.37992976780515164, 0.5389395682141185, 0.4464945662766695, 0.0513099641102599, 0.35844046622514725, 0.22856434079585597, 0.13630576635478064, 0.7098100462462753, 1.3057981501333416, 0.2500228729331866, 28.645211309194565, 111.40166983008385, 100.43265402317047, 97.61996895074844, 98.43865022063255, 96.58434972167015, 90.5080197751522, 79.74945187568665, 83.19467380642891, 91.8628902733326, 91.2739522755146, 91.20627030730247, 91.5321484208107, 92.69569158554077, 84.22310382127762, 76.0872919857502, 66.83291897177696, 69.02598649263382, 74.9952457845211, 81.52440503239632, 87.35124036669731, 86.05566188693047, 87.0719401538372, 88.09859186410904, 83.14795151352882, 79.3842838704586, 81.62833705544472, 82.28421986103058, 80.78740417957306, 81.85836151242256, 80.54679349064827, 76.02744519710541, 76.31351664662361, 74.00966987013817, 67.68123865127563, 70.95656409859657, 75.53743109107018, 65.62340587377548, 63.52578543126583, 77.97516748309135, 79.1197420656681, 77.23942816257477, 75.02701207995415, 77.36066445708275, 77.3854011297226, 79.93517830967903, 76.75749242305756, 75.00814989209175, 74.27285894751549, 72.6916953921318, 68.2927930355072, 68.45723301172256, 70.42762488126755, 68.99422779679298, 69.41095903515816, 65.58264166116714, 65.26484951376915, 75.8477072417736, 73.95792424678802, 76.51656255126, 74.68166381120682, 77.07447901368141, 65.97763046622276, 64.67288687825203, 71.40293374657631, 64.31662559509277, 57.58120961487293, 57.50642582774162, 60.28135992586613, 65.60418650507927, 55.94528719782829, 58.40479262173176, 73.03165555000305, 71.69956102967262, 69.46460455656052, 68.39116975665092, 69.7263877093792, 65.79934403300285, 64.81345653533936, 67.41513133049011, 64.51268747448921, 66.41377866268158, 70.81574365496635, 70.15239045023918, 72.90957570075989, 72.08360642194748, 74.17521938681602, 75.27197733521461, 72.689628303051, 82.21253290772438, 79.26479548215866, 76.71583145856857, 73.88606250286102, 70.22931352257729, 70.10889038443565, 72.86045953631401, 76.49994224309921, 81.616230905056, 74.30624395608902, 70.09685263037682, 23.118082992732525, 0.04469103099836502, 0.0703623607114423, 0.3448141599074006, 0.192266610392835, 0.15142476913752034, 0.23089860304025933, 0.05978640750981867, 0.1889546576421708, 0.6876085500698537, 0.33795172814279795, 0.7532858289778233, 0.5477105663158, 0.03231739203329198, 0.583568470319733, 24.129784405231476, 81.06820911169052, 85.6894451379776, 84.79166731238365, 94.7253754734993, 58.16583104431629, 34.15776930749416, 20.735645033419132, 39.919875115156174, 58.73439833521843, 73.13599035143852, 47.134361788630486, 0.10445453954162076, 0.033467910179751925, 0.019641487451735884, 0.014965700120228576, 0.03462244705588091, 0.04343950284237508, 0.06520574796013534, 0.036547656054608524, 0.06269937424804084, 0.030344225451699458, 0.040282796253450215, 0.02675781350262696, 0.07340467636822723, 0.12962174689164385, 0.11192418169230223, 0.2542873128550127, 0.11747479322366416, 0.14107710798271, 0.1409246411640197, 0.09289787529269233, 0.1454252324765548, 0.10399477905593812, 0.11271948940702714, 0.09527869246085174, 0.17061408085282892, 0.21723213169025257, 42.53263771533966, 94.5047365128994, 78.32529589533806, 70.39056167006493, 68.99335384368896, 70.88426157832146, 80.52293077111244, 113.35184678435326, 81.32545530796051, 4.705843236297369, 0.22413710335968062, 0.6398956978227943, 1.56030303100124, 1.6995331412181258, 0.9012282185722142, 1.3729391223751009, 0.29386402980890125, 1.151760471984744, 0.44562331459019333, 0.5257146153599024, 0.9193782415241003, 3.814815510995686, 0.9518115199171007, 28.543673157691956, 115.07488712668419, 105.16723036766052, 101.45370483398438, 100.01156821846962, 99.53668490052223, 90.73163017630577, 83.4958304464817, 84.80030044913292, 97.89528697729111, 95.49279749393463, 93.46083372831345, 93.40678542852402, 96.56137615442276, 87.57935732603073, 77.80581057071686, 67.95297726988792, 70.08547604084015, 81.17223232984543, 84.7120463848114, 89.80489790439606, 86.96366116404533, 90.00927373766899, 91.82728618383408, 88.27361047267914, 86.90731778740883, 80.86376488208771, 84.41224247217178, 83.60690608620644, 85.60500606894493, 83.65602225065231, 81.13632425665855, 78.91988039016724, 76.24947488307953, 73.58672216534615, 77.71722972393036, 85.17661705613136, 74.31980922818184, 70.75489372015, 82.6335883140564, 82.58961707353592, 80.9878434240818, 76.40284225344658, 77.91032776236534, 79.44299072027206, 81.52060523629189, 81.41920387744904, 80.12351140379906, 76.76827624440193, 74.62323054671288, 72.86954864859581, 72.97289550304413, 74.97249260544777, 73.94618287682533, 72.0789934694767, 65.32648220658302, 67.39566877484322, 77.65665337443352, 76.60697489976883, 78.16289260983467, 79.37669947743416, 82.82898902893066, 69.66523379087448, 69.5103845000267, 75.54900527000427, 67.23973274230957, 62.727155685424805, 61.77752964198589, 65.35728335380554, 68.9306192100048, 61.35534569621086, 62.58822754025459, 77.54057720303535, 78.66275578737259, 72.57574081420898, 74.92308005690575, 72.72694230079651, 69.45682257413864, 68.24925497174263, 72.35444068908691, 67.32483297586441, 69.05758559703827, 74.49672773480415, 74.41698521375656, 75.34784406423569, 74.06139269471169, 75.96271947026253, 78.37311252951622, 78.44571143388748, 83.77628579735756, 80.3236086666584, 81.50532245635986, 77.32376083731651, 72.72756546735764, 71.8382003903389, 77.65508025884628, 79.96265083551407, 84.21861246228218, 77.93432727456093, 82.79179662466049, 28.514302633702755, 0.1875440130243078, 0.611961199901998, 0.7731007563415915, 0.4913650522939861, 1.0322207864373922, 0.6309721141587943, 0.1013641401368659, 0.5864922353066504, 2.14316432364285, 1.1662650061771274, 1.0172626515850425, 0.42575180588755757, 0.11091789623606019, 1.77068289835006, 32.49685563147068, 93.52194204926491, 95.57460710406303, 104.15672019124031, 97.9814587533474, 86.87811255455017, 47.15535946190357, 25.989311523735523, 61.21789567172527, 65.70331558585167, 88.02602335810661, 53.82812820374966, 0.21806168952025473, 0.116795423818985, 0.06859178189188242, 0.1024302352743689, 0.1382460817694664, 0.16855172667419538, 0.2220314968144521, 0.14163851301418617, 0.1494641782483086, 0.12045303185004741, 0.1025476430368144, 0.13750960410106927], [0.04797932408109773, 0.05712514015613124, 0.05144090864632744, 0.02735849113378208, 0.04069014255946968, 0.06754481932148337, 0.03394056919205468, 0.0212841812390252, 0.05195106838073116, 0.056001432094490156, 0.03448866380495019, 0.01016163534586667, 0.1135514369525481, 0.23200720839668065, 23.215188682079315, 74.69386875629425, 66.76465183496475, 77.53773495554924, 61.046152487397194, 53.668190985918045, 68.55298787355423, 92.97720327973366, 23.16519856452942, 0.026340168042224832, 0.04888363473583013, 0.15071171364979818, 0.7624701142776757, 0.24395158543484285, 0.15106286824448034, 0.3366476856172085, 0.6486741174012423, 0.07866180560085922, 0.4459292278625071, 0.46279055590275675, 0.2541498077334836, 0.5029851850122213, 9.483891148120165, 100.69324404001236, 89.70931023359299, 76.13444745540619, 86.39559924602509, 99.26579743623734, 94.84209761023521, 90.29521599411964, 76.20238780975342, 76.00466161966324, 85.36486655473709, 89.07823249697685, 91.01958632469177, 91.1662508547306, 88.53016510605812, 83.99754032492638, 72.7285686135292, 67.70357385277748, 63.008568584918976, 66.75728023052216, 77.25543290376663, 82.85650715231895, 81.5302187204361, 85.29460832476616, 81.869365721941, 94.07560274004936, 99.39753636717796, 78.54196786880493, 79.92636278271675, 78.08562755584717, 79.5225128531456, 72.42878749966621, 75.06276816129684, 71.33940875530243, 71.83332145214081, 63.348239958286285, 72.40615591406822, 66.9993044435978, 53.84368076920509, 64.00567308068275, 73.06689485907555, 68.4040130674839, 73.74242261052132, 73.26106444001198, 74.4394800066948, 75.74945211410522, 70.6670044362545, 75.653385668993, 77.09129691123962, 73.91933351755142, 65.71393221616745, 65.46004503965378, 71.20560273528099, 69.25117760896683, 70.32120779156685, 65.69508522748947, 75.83800256252289, 70.79625070095062, 69.07191082835197, 65.0738337635994, 69.98885482549667, 66.1520867049694, 72.26345837116241, 69.7469674050808, 59.16684553027153, 66.76823124289513, 67.23689049482346, 55.68320386111736, 60.78006036579609, 58.21573756635189, 59.17151167988777, 47.483878433704376, 58.7124203145504, 68.96458938717842, 67.04987972974777, 64.52358528971672, 63.00631530582905, 63.528506085276604, 62.08300665020943, 62.165188640356064, 60.361296236515045, 57.649317160248756, 62.92533025145531, 67.5396354496479, 69.35444846749306, 70.84047272801399, 72.92112708091736, 71.80075719952583, 74.56029832363129, 73.79389464855194, 72.61920288205147, 70.91883212327957, 72.56256312131882, 72.7702371776104, 71.08571916818619, 69.06171217560768, 66.51480004191399, 70.77951639890671, 73.80099266767502, 76.60553857684135, 62.58910149335861, 50.8794180303812, 5.803190153092146, 0.4078374890377745, 0.3386669507017359, 0.33426310576032847, 0.07549005196779035, 0.10460359248099849, 0.5367708939593285, 0.17982992227189243, 0.5449557735119015, 0.1153450743004214, 0.5655900319106877, 0.04793753374542575, 0.07698045519646257, 0.010868556055356748, 3.593593519181013, 52.70298197865486, 77.91471272706985, 93.17225441336632, 104.79184091091156, 77.94200286269188, 40.07052183151245, 26.139547862112522, 55.86350038647652, 58.34856703877449, 61.41899608075619, 32.90887892246246, 0.20192468276945874, 0.02393115482846042, 0.05536168966500554, 0.03326354497403372, 0.034903424166259356, 0.04206983961921651, 0.040061773543129675, 0.014212628957466222, 0.10231936583295465, 0.02313468008651398, 0.04746554266603198, 0.06387756337062456, 0.042438423552084714, 0.018103740767401177, 0.12631055113160983, 0.0453282575472258, 0.007562341033917619, 0.04233574371028226, 0.011684842429531273, 0.01027737234835513, 0.06706164407660253, 0.016158629223355092, 0.038563121343031526, 0.00515334080773755, 0.06193945213453844, 0.3173981263535097, 29.018075801432133, 86.48623958230019, 75.35268500447273, 88.23527812957764, 50.62717616558075, 44.99904736876488, 76.37306705117226, 107.33258217573166, 29.620064198970795, 0.056384124254691415, 0.08362499982467853, 0.7502895116340369, 1.784788928925991, 0.29829705599695444, 0.1298234032583423, 0.3826629789546132, 0.557294423924759, 0.11589066416490823, 0.8783317159395665, 0.7560676359571517, 0.9569074027240276, 0.36233712744433433, 12.039428818970919, 104.80578616261482, 94.65541362762451, 86.94934353232384, 92.33340382575989, 103.29695552587509, 100.08665978908539, 96.37778520584106, 80.61916440725327, 78.49555715918541, 87.06443935632706, 93.40478673577309, 94.10694345831871, 93.21825474500656, 90.84377735853195, 89.57133963704109, 75.59607714414597, 69.50773984193802, 64.88156408071518, 67.95325845479965, 79.40960571169853, 86.04518204927444, 85.759247392416, 84.84323814511299, 84.26022782921791, 96.13049447536469, 99.3910463154316, 83.18065255880356, 83.0627752840519, 80.44836357235909, 82.3772768676281, 78.23044538497925, 80.1475565135479, 77.55157381296158, 75.31144961714745, 68.1007969379425, 74.57306563854218, 70.47090455889702, 63.419087156653404, 72.60727912187576, 75.89418634772301, 72.03746169805527, 76.61821469664574, 76.14216104149818, 78.15042167901993, 78.52768063545227, 74.38239946961403, 78.09813648462296, 79.3691910803318, 74.42635551095009, 65.87084859609604, 70.00778540968895, 75.33045619726181, 73.23657855391502, 72.83235624432564, 68.82195264101028, 78.02875980734825, 74.18161824345589, 70.14613598585129, 66.77289739251137, 69.95283275842667, 67.36448764801025, 73.81116092205048, 73.62703800201416, 63.683237582445145, 69.1504754126072, 70.32924056053162, 62.72315450012684, 63.717306554317474, 61.45521193742752, 60.347145795822144, 51.75392210483551, 64.15150165557861, 73.2204370200634, 68.90494778752327, 67.4220621585846, 65.7271859049797, 66.59243747591972, 64.73250567913055, 66.00188076496124, 64.5259715616703, 62.55899950861931, 68.11164155602455, 70.5899065732956, 72.6402385532856, 74.56877946853638, 74.6861019730568, 75.90555533766747, 77.73907095193863, 77.23719388246536, 73.69748622179031, 73.34416598081589, 76.26552522182465, 76.70519962906837, 73.34633186459541, 72.61584386229515, 70.29545277357101, 75.69810166954994, 79.57331612706184, 82.60502904653549, 70.52880585193634, 63.083952739834785, 7.791264373809099, 0.25780334137380123, 0.40862674824893475, 0.6920432683546096, 0.9028148709330708, 1.0117166116833687, 0.9487000212538987, 0.4280834854580462, 1.1213774210773408, 0.05398759582021739, 0.9354086313396692, 0.8152372296899557, 0.30008019937667996, 0.15623385639628395, 4.715193584561348, 58.66537123918533, 86.89377531409264, 100.51154538989067, 112.68708765506744, 86.31265729665756, 55.44797368347645, 27.605777084827423, 53.08302238583565, 63.00178974866867, 72.54990220069885, 37.67726965248585, 0.14918091532308608, 0.08199243078706786, 0.03512602765113115, 0.0621456652879715, 0.05221575534960721, 0.04786954930750653, 0.007083321816026, 0.03561170022294391, 0.04194067252683453, 0.06295607570791617, 0.029314567909750622, 0.02629261121910531, 0.15595847507938743, 0.10395606863312423, 0.2451177517650649, 0.12990220449864864, 0.16502956801559776, 0.20452812197618186, 0.10920875240117311, 0.1462995121255517, 0.26842875871807337, 0.1562226944952272, 0.11173874867381528, 0.18678987224120647, 0.22666044998914003, 0.4878770769573748, 35.172797441482544, 99.85310152173042, 83.05966705083847, 98.10672283172607, 78.71542096138, 80.30132666230202, 89.33633744716644, 118.40513482689857, 38.11545833945274, 0.14668035262729973, 0.1162006740923971, 0.46676956582814455, 4.171690223738551, 0.9800851496402174, 0.5837244994472712, 1.6548710502684116, 2.1469201846048236, 0.8414165780413896, 1.4094747556373477, 1.2891778419725597, 3.631326206959784, 0.8620821253862232, 11.814609132707119, 107.5325046479702, 99.57352012395859, 93.36379453539848, 95.09773269295692, 107.86605075001717, 99.9276003241539, 98.36510896682739, 82.90565371513367, 80.60163214802742, 95.23641005158424, 98.17245170474052, 95.67166149616241, 96.19089603424072, 94.53403294086456, 92.35174164175987, 80.06117954850197, 73.07689592242241, 68.88982459902763, 71.5614764392376, 84.71620336174965, 86.00384026765823, 89.40923273563385, 90.29494240880013, 86.85718327760696, 97.64297291636467, 100.2791878581047, 85.60494527220726, 87.57218331098557, 85.8778466284275, 88.41339737176895, 83.8188511133194, 84.45026323199272, 79.94771763682365, 80.46702057123184, 74.32453617453575, 82.39926248788834, 81.68853342533112, 72.9729562997818, 75.59090182185173, 81.10076576471329, 75.67992344498634, 79.5444604754448, 79.09508138895035, 78.20311725139618, 82.11682364344597, 74.79044437408447, 81.66989922523499, 83.25987830758095, 76.96037113666534, 68.6728486418724, 70.30996039509773, 76.09908655285835, 75.12178659439087, 74.15862187743187, 70.59741497039795, 83.71963083744049, 76.9629018008709, 71.80841758847237, 69.90693122148514, 72.72142499685287, 69.96211186051369, 75.84519177675247, 75.72684332728386, 70.2324977517128, 71.79571107029915, 74.40916523337364, 64.96496960520744, 66.69118657708168, 62.81243450939655, 61.28984861075878, 54.35781978070736, 65.28680473566055, 75.41065469384193, 74.72653940320015, 72.06162080168724, 68.91069307923317, 69.50375005602837, 68.41526806354523, 68.70788276195526, 68.64082396030426, 65.18585935235023, 70.55104225873947, 74.5243826508522, 78.17755982279778, 78.34422647953033, 78.7819553911686, 79.19688552618027, 80.31309843063354, 79.4041796028614, 74.98235687613487, 78.48319262266159, 77.41548791527748, 80.58492824435234, 76.10636696219444, 76.24620705842972, 72.2034139931202, 78.632752597332, 84.60572049021721, 86.88511177897453, 72.87806779146194, 73.83206740021706, 9.584278911352158, 0.4544369416544214, 1.3304063421674073, 1.4692886522971094, 1.2879563262686133, 1.9819960906170309, 1.3438773318193853, 0.6788835651241243, 2.535420600324869, 0.574876080499962, 2.6810496859252453, 0.991133947391063, 0.28016626951284707, 0.2372637068037875, 8.45128895714879, 71.16483092308044, 94.14081484079361, 101.56372413039207, 111.77498459815979, 96.22549697756767, 56.10502302646637, 39.668906182050705, 78.99181053042412, 74.26314666867256, 84.62668016552925, 45.73708176612854, 0.2434747852385044, 0.1776547616464086, 0.19213188090361655, 0.17362874408718199, 0.08430207599303685, 0.1730974850943312, 0.15762317168992013, 0.10562930736341514, 0.1489456693525426, 0.11615003735641949, 0.10617003616061993, 0.14922606758773327], [0.10074148565763608, 0.027057151346525643, 0.04579129090416245, 0.09202416709740646, 0.05491481286298949, 0.055546428775414824, 0.05108981342345942, 0.016668399330228567, 0.09588573215296492, 0.012672152097366052, 0.03448699397267774, 0.05436851424747147, 0.12051364305079915, 0.2713459631195292, 18.54209303855896, 73.37030857801437, 55.08578471839428, 49.565991908311844, 40.48838920891285, 51.34479805827141, 72.37562835216522, 64.54892992973328, 3.9824520656839013, 0.03510959279083181, 0.18995470163645223, 0.9420298947952688, 1.4145560329779983, 0.24488112539984286, 0.05740255866840016, 0.10141804232262075, 0.11554147626156919, 0.504005370894447, 0.3970562503673136, 1.0982696735300124, 0.05959134883596562, 2.50951477792114, 74.8721019923687, 85.96851736307144, 64.58082541823387, 85.63855066895485, 94.58986714482307, 91.5725326538086, 93.80636438727379, 94.38899472355843, 81.9594056904316, 72.25728750228882, 83.75088796019554, 87.90368512272835, 89.07773852348328, 89.81700405478477, 88.64447057247162, 82.95175284147263, 76.81681483983994, 67.01359927654266, 61.51077255606651, 63.751200735569, 65.44441267848015, 75.80495953559875, 78.39057639241219, 81.38557568192482, 79.13339093327522, 82.2474454343319, 86.79001048207283, 75.69962158799171, 78.07921350002289, 77.55737230181694, 77.3975832760334, 75.71502596139908, 74.8347195982933, 73.92233535647392, 68.45481634140015, 63.73866520822048, 70.33820807933807, 58.98584984242916, 58.85160684585571, 71.09313637018204, 68.74509036540985, 72.97617092728615, 73.093691021204, 76.74442872405052, 73.10265854001045, 72.95141905546188, 73.50615128874779, 73.310476988554, 74.39749225974083, 63.470449000597, 66.29786968231201, 74.76493254303932, 71.35571748018265, 72.10089549422264, 71.01062759757042, 71.1029702425003, 68.74904975295067, 70.79175174236298, 70.59663221240044, 70.07147759199142, 71.53461948037148, 70.73795422911644, 71.87209457159042, 68.9762319624424, 60.27855947613716, 68.81337270140648, 66.17484748363495, 63.82440760731697, 63.35284151136875, 62.217207849025726, 59.67626139521599, 55.37638932466507, 64.07024681568146, 64.74113881587982, 64.17984813451767, 64.52243775129318, 63.4185665845871, 65.77437177300453, 67.82528132200241, 66.9179356098175, 62.873406037688255, 59.081904888153076, 62.80179128050804, 68.047364205122, 67.89749264717102, 70.49433410167694, 70.00210091471672, 73.39501485228539, 75.94724670052528, 71.74081921577454, 68.20790559053421, 67.83686310052872, 71.82399675250053, 74.15796831250191, 73.57979133725166, 74.77152898907661, 70.05700796842575, 70.7934844493866, 70.53372278809547, 71.72147825360298, 75.45835733413696, 68.75161841511726, 33.52971240878105, 0.4204709501937032, 0.08545358490664512, 0.7947118591982871, 1.9472493301145732, 1.3728839065879583, 0.8239246322773397, 1.119238135870546, 0.289026265963912, 0.13939994329120964, 0.8468577079474926, 1.9996947096660733, 0.2572401106590405, 0.03293242465588264, 0.18957853666506708, 16.659166775643826, 73.78909170627594, 77.68344953656197, 96.14907547831535, 78.11084300279617, 28.666752353310585, 42.84150414168835, 59.26233820617199, 54.94790531694889, 63.09547372162342, 24.79149989783764, 0.1906370767392218, 0.09351247746963054, 0.0735258987697307, 0.0348540602135472, 0.038049295399105176, 0.037333575601223856, 0.016041165799833834, 0.07006071478826925, 0.04608475464920048, 0.02785714386845939, 0.032273319593514316, 0.009236833993782056, 0.039013727437122725, 0.014980472569732228, 0.01368004894175101, 0.05851570596860256, 0.026158317741646897, 0.10197362149483524, 0.06433093396481127, 0.09313831629697233, 0.04773961038154084, 0.04737659255624749, 0.013325576946954243, 0.026556561606412288, 0.011886027532455046, 0.24482104112394154, 23.78444943577051, 83.1232300400734, 64.35843855142593, 59.02642786502838, 45.43437480926514, 47.38460876047611, 84.2741046845913, 78.82591903209686, 4.752084380015731, 0.19157092116074637, 0.13545443391194567, 2.018740475177765, 0.7471625169273466, 0.28625903476495296, 0.12273274624021724, 0.37390839715953916, 0.8199390023946762, 1.0252530290745199, 1.3219026359729469, 1.3515335647389293, 0.06145838458905928, 4.20440124347806, 79.83080551028252, 88.33370044827461, 76.34418100118637, 93.81335601210594, 98.82003575563431, 95.96521094441414, 96.27250045537949, 97.97863930463791, 84.03904929757118, 73.78982126712799, 88.39625269174576, 89.60122883319855, 91.94962441921234, 93.560441583395, 91.3765087723732, 85.92266142368317, 79.30747479200363, 69.0440583229065, 64.8223328590393, 66.91246390342712, 66.61413431167603, 74.21479046344757, 80.10151818394661, 82.59977772831917, 83.1606276333332, 81.36539116501808, 86.12588211894035, 82.01635703444481, 80.7612843811512, 80.63272207975388, 80.25126054883003, 79.90846574306488, 75.0051936507225, 72.09762006998062, 70.69383099675179, 68.50992858409882, 75.52706524729729, 64.65567380189896, 67.23587214946747, 73.40078294277191, 71.97886884212494, 75.62935575842857, 75.3109860420227, 78.51419895887375, 75.43814241886139, 74.56017673015594, 75.15168339014053, 75.46939194202423, 77.10292428731918, 63.011087849736214, 72.88622975349426, 77.17667073011398, 72.19054788351059, 73.91412779688835, 72.36184269189835, 72.69035786390305, 70.70744186639786, 71.83538094162941, 70.64191818237305, 73.22377324104309, 71.86502695083618, 73.0486710369587, 70.9705701470375, 71.26380041241646, 64.27953958511353, 72.38995358347893, 71.62260755896568, 65.89532688260078, 66.0838271677494, 66.85247272253036, 62.06721089780331, 58.980647921562195, 66.13470643758774, 69.77505549788475, 68.31806167960167, 66.6996905207634, 65.7523937523365, 69.1106915473938, 70.4033973813057, 70.67065984010696, 67.78649300336838, 62.55125172436237, 67.07881137728691, 71.65476143360138, 72.1731448173523, 72.13701635599136, 72.95471727848053, 77.41148293018341, 80.1051127910614, 74.15342375636101, 69.76637676358223, 71.77418142557144, 76.09353885054588, 77.48520657420158, 75.98754733800888, 77.44355320930481, 75.62873259186745, 74.77719068527222, 75.22949561476707, 77.52191260457039, 80.00934273004532, 77.77469784021378, 41.98435753583908, 1.252494491636753, 0.2617493999423459, 1.3707067421637475, 4.906498119235039, 1.9599347119219601, 1.7140387441031635, 2.2485393192619085, 1.0690643219277263, 0.1244276408397127, 0.5312823259737343, 1.1578524950891733, 0.8707288582809269, 0.08396853998419829, 0.23926192458020523, 20.82476545125246, 85.87836340069771, 88.53540122509003, 101.77836701273918, 93.72526913881302, 42.821281626820564, 29.092544205486774, 62.555720284581184, 60.404283329844475, 72.42596045136452, 29.8766378313303, 0.1828001902322285, 0.02928873374912655, 0.021604967150778975, 0.046613015365437604, 0.013081065262667835, 0.1119909824046772, 0.057020408276002854, 0.031967684626579285, 0.046771393390372396, 0.0218197075810167, 0.046255934721557423, 0.03226012791856192, 0.25520867435261607, 0.10960459912894294, 0.16833828500239179, 0.17880805913591757, 0.20131149067310616, 0.17645383311901242, 0.3354144736658782, 0.12775494862580672, 0.12838136579375714, 0.10817624686751515, 0.1763692728127353, 0.1139517143019475, 0.18922292918432504, 0.29517709685023874, 27.91303049772978, 98.61686825752258, 69.93451774120331, 65.45777276158333, 50.045218393206596, 80.32675489783287, 92.35266879200935, 87.9372601211071, 7.340182978659868, 0.19672179711051285, 0.35031187115237117, 1.6346830897964537, 2.815312393940985, 0.6892238196451217, 0.6749941769521683, 0.7196793041657656, 1.6035757027566433, 1.6683536767959595, 3.2565207313746214, 2.9625352565199137, 0.5329833284486085, 4.1983044706285, 83.6903116106987, 96.0324065387249, 84.32132855057716, 97.52175182104111, 101.8953475356102, 99.31950375437737, 99.34579834342003, 100.76572135090828, 86.7720602452755, 77.56515428423882, 91.1965124309063, 93.6295522749424, 95.62940776348114, 96.02917671203613, 95.58848395943642, 89.55264464020729, 82.66522541642189, 74.7681775689125, 69.63023006916046, 70.61759948730469, 70.71683496236801, 79.8620930314064, 85.88994517922401, 87.5016438961029, 87.84137606620789, 85.09836405515671, 90.80869764089584, 86.87018617987633, 84.36649292707443, 84.82715740799904, 83.4572397172451, 82.7437824010849, 81.9655005633831, 82.2820995748043, 77.76933252811432, 76.81345582008362, 84.87395569682121, 75.92296600341797, 73.55576902627945, 79.78398442268372, 76.4560241997242, 79.42393094301224, 79.7924655675888, 79.9171444773674, 76.28206193447113, 76.25227153301239, 80.63280567526817, 77.8896264731884, 80.89879900217056, 66.93635702133179, 72.13384732604027, 81.68599516153336, 77.17032507061958, 78.37400168180466, 77.26057022809982, 74.88918587565422, 77.12707579135895, 77.83487901091576, 74.02665495872498, 74.04230251908302, 73.78712341189384, 75.4209977388382, 76.06275290250778, 75.4074476659298, 68.31824406981468, 75.77662825584412, 75.49016162753105, 68.51177528500557, 69.93989825248718, 70.27402192354202, 64.68835204839706, 59.4970478117466, 70.6744672358036, 74.99469101428986, 72.94966354966164, 71.33095040917397, 71.31440609693527, 72.51030072569847, 73.44619050621986, 73.98567035794258, 69.77525308728218, 65.05463719367981, 70.18235564231873, 75.288255661726, 76.87548369169235, 77.21122607588768, 75.87054401636124, 79.76712852716446, 80.94217747449875, 76.9601659476757, 71.46669432520866, 73.00402343273163, 78.35176527500153, 80.1921509206295, 78.90400484204292, 80.91573089361191, 75.92053413391113, 78.3255922794342, 78.52695867419243, 83.0226494371891, 85.47349512577057, 82.58516371250153, 47.39296831190586, 1.5624021808616817, 0.6012760545127094, 1.8929514312185347, 9.123887065798044, 5.330472718924284, 5.126018514856696, 4.4870528765022755, 2.1699414867907763, 0.28550765477120876, 2.9644515411928296, 5.6193887908011675, 0.8802850486245006, 0.13659848424140364, 0.5906445218715817, 29.09396532922983, 95.02631932497025, 91.14735066890717, 108.11334148049355, 92.80162990093231, 44.28167246282101, 60.219180062413216, 78.34157422184944, 70.2806031703949, 84.86460819840431, 35.61857432126999, 0.40009374206420034, 0.16712120734155178, 0.12691786541836336, 0.14896367385517806, 0.14120319887297228, 0.1588229721528478, 0.09483043526415713, 0.13192375539802015, 0.16690450021997094, 0.07898357114754617, 0.08905012160539627, 0.11111271000117995], [0.04741806747915689, 0.002655101266100246, 0.007490532680094475, 0.06659846229013056, 0.08265000331448391, 0.07126590324332938, 0.0637458470009733, 0.04374498937977478, 0.024638890972710215, 0.026367015234427527, 0.06766839433112182, 0.024952027197286952, 0.10177045114687644, 0.30044664221350104, 10.774191711097956, 67.48060941696167, 49.134772047400475, 77.50364318490028, 51.966368705034256, 59.37667787075043, 91.05024307966232, 35.626846477389336, 0.2597863896517083, 0.08035477803787217, 0.364182076882571, 2.127689654007554, 0.40657180070411414, 0.08068619892583229, 0.136733406689018, 0.17090448323870078, 0.9806290548294783, 0.3120121528627351, 0.3583553567295894, 0.7255170971620828, 0.7895872998051345, 48.17322984337807, 77.93305054306984, 64.33103442192078, 95.88659316301346, 95.4749384522438, 95.0467774271965, 96.10192760825157, 90.39760529994965, 92.96280205249786, 80.35688728094101, 72.38991558551788, 79.5086207985878, 84.51280787587166, 87.80509561300278, 88.44001114368439, 87.03528732061386, 82.88208737969398, 75.01366719603539, 69.5815546810627, 63.512068167328835, 63.58255438506603, 62.91381686925888, 62.37906776368618, 64.68104124069214, 72.46863216161728, 74.19102653861046, 73.06060239672661, 71.40795707702637, 74.45619150996208, 70.27752533555031, 73.12755480408669, 71.6748471558094, 72.17772737145424, 62.01192386448383, 50.38439579308033, 59.70839627087116, 63.92941117286682, 62.61165328323841, 47.78813950717449, 65.35207003355026, 70.25335103273392, 71.70839175581932, 72.68298625946045, 74.18078988790512, 72.87619829177856, 75.35950183868408, 75.8776344358921, 70.67404165863991, 78.8459287583828, 70.0128847360611, 64.89790320396423, 75.58578729629517, 62.93329082429409, 69.0318837761879, 63.797786235809326, 61.87218256294727, 65.57939663529396, 68.60468789935112, 65.46837419271469, 66.17106288671494, 70.8788126707077, 71.13290503621101, 72.80751317739487, 72.12445423007011, 72.171860486269, 63.57561215758324, 61.93139858543873, 71.32563829421997, 61.38831652700901, 63.05122509598732, 60.553835704922676, 65.01083314418793, 59.76060926914215, 62.51700796186924, 65.94460263848305, 63.7314759939909, 62.006197571754456, 61.3027261197567, 64.84546601772308, 69.72148597240448, 69.33668062090874, 68.47804829478264, 63.44650648534298, 62.53141298890114, 70.86874321103096, 69.56953212618828, 67.87373632192612, 70.27741134166718, 74.26281228661537, 71.34089827537537, 71.09597101807594, 74.91132348775864, 75.29232144355774, 71.37098506093025, 72.72472321987152, 70.88161692023277, 71.63504049181938, 73.04402008652687, 74.97360974550247, 75.8951210975647, 73.94252747297287, 69.11409616470337, 69.15197253227234, 66.89080506563187, 19.820194356143475, 0.12331133941188455, 0.03738244231499266, 0.36944277584552765, 0.4277764441212639, 0.13882335391826928, 0.35119443316943944, 0.14984818029915914, 0.20429501339094713, 0.44116072123870254, 0.7011376053560525, 1.6724090091884136, 0.03631669969763607, 0.04223435520543717, 2.4453801568597555, 41.64176031947136, 73.90423312783241, 70.39574459195137, 28.964107297360897, 39.403315633535385, 55.9769356995821, 48.19258600473404, 47.83886678516865, 60.75415335595608, 14.95501996949315, 0.21346908673876897, 0.09380800809594803, 0.030675963607791346, 0.054221439131652005, 0.0724289525533095, 0.03504154155962169, 0.05541933227505069, 0.030370773929462302, 0.01896417379612103, 0.016395632228523027, 0.05259740479232278, 0.036985226324759424, 0.0703640676510986, 0.022571935478481464, 0.018767517649393994, 0.01988855769013753, 0.03549261520674918, 0.00998998029899667, 0.04129634362470824, 0.04458985029486939, 0.01883452987385681, 0.055380981793859974, 0.1646367640933022, 0.08041922614211217, 0.06808325488236733, 0.33967024530284107, 14.162090867757797, 80.64352869987488, 51.19780674576759, 79.08733740448952, 42.478976994752884, 53.498351499438286, 108.59477564692497, 42.86644980311394, 0.14908272918546572, 0.1055498604546301, 0.6092865590471774, 2.1206875797361135, 1.3524538278579712, 0.11905037274118513, 0.06328787509119138, 0.39164623129181564, 1.7477098060771823, 0.4896432103123516, 0.20967160613508895, 1.3118182145990431, 1.2735184072516859, 54.63604085147381, 83.52930665016174, 76.7714224755764, 99.93293523788452, 96.00032866001129, 97.1385195851326, 99.49766099452972, 95.4738213121891, 95.84347307682037, 84.17711868882179, 76.92048847675323, 82.38904103636742, 87.86542117595673, 93.03636610507965, 91.16534650325775, 89.4702422618866, 84.71900001168251, 77.95585691928864, 71.3268694281578, 65.52349403500557, 66.2549851834774, 66.50497376918793, 64.98270705342293, 66.42499566078186, 74.02625977993011, 77.616246342659, 77.76958331465721, 73.87796133756638, 76.3020108640194, 74.2240771651268, 78.89775037765503, 76.62955328822136, 77.24524945020676, 67.20696330070496, 53.27689178287983, 63.768071830272675, 69.82151180505753, 66.08606904745102, 56.62438675761223, 72.08479195833206, 74.4824481010437, 75.00066429376602, 77.91649103164673, 75.72245076298714, 75.33566951751709, 77.20504760742188, 75.72970077395439, 75.08775562047958, 81.26886874437332, 67.8309354186058, 68.60374554991722, 77.53288641571999, 66.86968579888344, 74.08401668071747, 69.39330518245697, 67.04371646046638, 67.80327290296555, 71.3682872056961, 69.85241174697876, 67.4402479827404, 72.3779234290123, 73.4554772078991, 75.0906890630722, 73.18610966205597, 74.61189955472946, 68.89316082000732, 64.73176091909409, 74.60303843021393, 65.41956201195717, 66.29287675023079, 64.03052374720573, 67.34415113925934, 63.16880598664284, 67.24718794226646, 71.3962385058403, 68.36372762918472, 66.9997376203537, 65.67125290632248, 69.63087603449821, 71.69933304190636, 72.56142318248749, 72.62705326080322, 67.70729005336761, 64.64716985821724, 74.12198424339294, 76.02553009986877, 72.29704856872559, 73.41174155473709, 75.43852239847183, 74.35627967119217, 76.02425336837769, 78.87309730052948, 76.58408492803574, 74.13975968956947, 75.9489718079567, 75.5233946442604, 73.57978373765945, 77.07813441753387, 78.55965971946716, 78.08533877134323, 77.96195179224014, 76.05481892824173, 79.22251895070076, 73.87899488210678, 26.357146985828876, 0.1251530382432975, 0.11250186202232726, 0.34343896026257426, 0.254092306131497, 0.3357272146968171, 0.460953235742636, 0.1991014342638664, 0.35396602819673717, 0.5855649069417268, 1.5190916298888624, 3.4302162984386086, 0.5631711648311466, 0.12816615781048313, 2.988126170821488, 48.90953913331032, 84.26088899374008, 79.81922373175621, 39.32499423623085, 35.09639874100685, 50.70928975939751, 56.84552729129791, 55.354536697268486, 70.62560945749283, 20.259958058595657, 0.2629659284139052, 0.07137223074096255, 0.053310953808249906, 0.031296927845687605, 0.030732190571143292, 0.08982803337858059, 0.012454756633815123, 0.009696131564851385, 0.013627003008878091, 0.051373525348026305, 0.039241448030225, 0.06712068934575655, 0.18715868995059282, 0.18063927884213626, 0.07899425807408988, 0.26906857907306403, 0.270591881708242, 0.10528390441322699, 0.1328180285054259, 0.2400067588314414, 0.0875144473684486, 0.23357713274890557, 0.43077086156699806, 0.29283710522577167, 0.3391551354434341, 0.7672240154352039, 19.518452547490597, 94.68307614326477, 64.87603917717934, 91.919666826725, 64.90734949707985, 81.04772821068764, 114.20402705669403, 56.69944413006306, 0.35849882871843874, 0.3565240034367889, 0.47172354999929667, 6.2058934941887856, 3.021183446981013, 0.7566683599725366, 0.4308275319635868, 0.590857369825244, 3.1314601795747876, 0.974893975071609, 1.0182884777896106, 2.165175355039537, 1.3901229877956212, 59.50585953891277, 87.38310545682907, 84.32620748877525, 106.27819955348969, 100.53838714957237, 99.818956553936, 101.88243582844734, 97.08388611674309, 101.00330740213394, 88.47911864519119, 80.94996705651283, 84.53674659132957, 89.67600882053375, 93.71836870908737, 94.04959693551064, 92.99639225006104, 89.49879392981529, 81.39680787920952, 75.79640999436378, 69.18994009494781, 70.3835092484951, 68.07225286960602, 68.10743138194084, 69.60975676774979, 76.79720789194107, 83.04984077811241, 81.81701213121414, 76.76906660199165, 80.58024689555168, 79.8751263320446, 82.27121695876122, 84.29015502333641, 80.53520411252975, 70.77706173062325, 61.8921010941267, 69.14384856820107, 76.58805951476097, 75.93162953853607, 65.91706931591034, 76.17332696914673, 77.55852743983269, 78.03153365850449, 79.76230278611183, 79.1744515299797, 76.98223516345024, 80.08759573101997, 79.00393947958946, 76.53604030609131, 83.98705288767815, 72.0115014910698, 68.84988114237785, 82.28407546877861, 71.34122505784035, 77.02692836523056, 70.80011889338493, 68.8928796350956, 70.5370058119297, 73.72396320104599, 74.44635763764381, 72.79389470815659, 79.16083306074142, 76.79547518491745, 77.96077385544777, 77.74372950196266, 76.85886338353157, 69.97681707143784, 70.0442786514759, 76.72816559672356, 66.93836331367493, 69.88265812397003, 66.14849209785461, 71.64624229073524, 66.74155667424202, 70.96205860376358, 74.23717886209488, 71.64532274007797, 69.46185350418091, 71.17280289530754, 74.34100449085236, 77.18797892332077, 75.54340437054634, 75.88641956448555, 68.95037814974785, 69.00721549987793, 78.44965562224388, 79.33366298675537, 76.31144195795059, 79.75999251008034, 79.8677471280098, 77.01406985521317, 79.4258688390255, 82.02522575855255, 80.59473931789398, 79.39158707857132, 77.63377860188484, 79.24388900399208, 75.30430600047112, 78.2767952978611, 80.11864006519318, 81.74097061157227, 80.69103375077248, 78.11385244131088, 81.75917163491249, 80.35719886422157, 31.314674466848373, 0.42449876375030726, 0.37605076970066875, 1.8408411461859941, 1.2068628589622676, 1.0228465707041323, 1.3562790350988507, 0.8818640420213342, 0.7753712532576174, 1.389706910122186, 4.899553041905165, 3.4724151715636253, 0.4143044154625386, 0.24886766070267186, 5.293618021532893, 63.25698025524616, 86.75433799624443, 87.15206265449524, 42.008919417858124, 57.591545060276985, 72.25971177220345, 67.7557298541069, 63.625826463103294, 84.69289541244507, 27.678222097456455, 0.3985236247535795, 0.21611816802760586, 0.24912211345508695, 0.23345396592048928, 0.247865405108314, 0.19086702377535403, 0.1875373930670321, 0.08002323840628378, 0.09747444026288576, 0.15261909255059436, 0.16342332295607775, 0.12950376025401056], [0.03288584375695791, 0.07398169618682005, 0.05776106052508112, 0.06793819469748996, 0.015995597932487726, 0.09319117947597988, 0.03402040201763157, 0.03276957890193444, 0.04121590965951327, 0.04939921585901175, 0.05238935482339002, 0.11004411382600665, 0.17180785507662222, 0.3900936583522707, 12.416613679379225, 63.535771295428276, 61.74951754510403, 41.71901397407055, 43.924290239810944, 78.14390122890472, 75.60597941279411, 9.16493721306324, 0.35768107103649527, 0.17479753762017936, 0.48417088051792234, 2.9072907334193587, 0.3745497908676043, 0.030091067746980116, 0.31186075473669916, 0.21222799317911267, 0.22192415257450193, 0.6257738743443042, 0.0790570882963948, 0.17361336678732187, 31.400950737297535, 78.2960070669651, 74.42887097597122, 96.56007662415504, 95.9770055115223, 93.77506166696548, 93.06300267577171, 92.55355641245842, 92.13902905583382, 84.42048043012619, 77.06224367022514, 74.43705573678017, 77.08309695124626, 83.21333840489388, 85.60760512948036, 87.20864161849022, 88.37226837873459, 83.01163002848625, 74.1193699836731, 66.22276291251183, 61.27320170402527, 61.75776690244675, 62.36502751708031, 61.45684204995632, 59.50645990669727, 61.71233274042606, 65.95018833875656, 66.30344018340111, 65.69323852658272, 65.13711556792259, 70.74574381113052, 71.95714920759201, 72.1078111231327, 73.39711993932724, 67.96721890568733, 51.34691074490547, 61.00364796817303, 66.99564903974533, 52.06298992037773, 55.70234343409538, 72.68638327717781, 73.02484631538391, 74.8078702390194, 70.07985234260559, 73.4603713452816, 74.51261088252068, 71.88654899597168, 68.187485486269, 75.41678756475449, 67.9489266872406, 65.7988728582859, 76.58500447869301, 64.94749814271927, 67.67024964094162, 70.00678986310959, 72.1187773346901, 72.5832188129425, 70.76988011598587, 67.10160255432129, 65.18097281455994, 67.27450087666512, 64.33041125535965, 64.70551952719688, 66.609658151865, 71.4039520919323, 69.644585698843, 69.18775141239166, 60.10743945837021, 66.70967638492584, 68.51894930005074, 66.07176661491394, 62.97995612025261, 64.30810645222664, 63.781629502773285, 65.73872968554497, 68.71938094496727, 64.23474758863449, 61.65342070162296, 63.0379182100296, 63.69025960564613, 65.88519662618637, 71.62941679358482, 71.58241331577301, 67.40661978721619, 67.49809607863426, 66.70965358614922, 71.32610186934471, 70.19247829914093, 65.89331299066544, 70.03325164318085, 70.10036364197731, 70.35767063498497, 68.96939992904663, 67.38429978489876, 72.27786719799042, 72.61064574122429, 70.1239375770092, 70.98739564418793, 73.99200081825256, 72.46373042464256, 73.77908304333687, 75.13727456331253, 76.81673884391785, 65.37898778915405, 59.3191147595644, 61.46804764866829, 14.263458978384733, 0.1314036434632726, 0.1777483316254802, 0.22182840068126097, 0.06429054628824815, 0.04962486957083456, 0.05791649964521639, 0.12508191080996767, 0.007412214299620246, 0.4498518642503768, 1.2234832858666778, 0.4402453266084194, 0.006734805092492024, 0.19300473562907428, 13.984168265014887, 61.04142174124718, 68.5520151257515, 34.63771775364876, 52.973155081272125, 36.6227388381958, 50.34151889383793, 47.33295813202858, 58.724017292261124, 5.541678685694933, 0.23182223550975323, 0.09398424590472132, 0.01209754147566855, 0.1413931738352403, 0.018054864776786417, 0.046526636797352694, 0.07777196311508305, 0.07428786178934388, 0.042821991446544416, 0.032627702530589886, 0.05585405269812327, 0.07421113114105538, 0.042511053834459744, 0.0462537490966497, 0.030159059606376104, 0.029315927895368077, 0.06615888822125271, 0.0569616821303498, 0.009337798546766862, 0.031764655286679044, 0.06569627046701498, 0.025456450130150188, 0.1769587310263887, 0.07751903176540509, 0.14994584693340585, 0.5337874009273946, 16.3775771856308, 75.92070892453194, 65.44842526316643, 49.708522260189056, 33.94947208464146, 82.88093984127045, 90.94951048493385, 12.418859358876944, 0.28593557712156326, 0.2771178534021601, 2.391720861196518, 2.0837053516879678, 0.652512030210346, 0.012737814540741965, 0.24382899748161435, 0.43246506596915424, 0.30723275151103735, 1.2602961855009198, 0.19417985226027668, 0.6914961570873857, 39.61646519601345, 83.50682705640793, 84.72863629460335, 105.31544521450996, 98.84445324540138, 100.17024770379066, 96.59874334931374, 98.1431856751442, 93.28899174928665, 88.96372944116592, 80.70663571357727, 78.74900355935097, 79.3631038069725, 87.41018280386925, 87.96209558844566, 89.95299875736237, 90.2964623272419, 86.32834285497665, 77.29376524686813, 71.54197588562965, 64.56268519163132, 63.55680696666241, 64.83003124594688, 63.78226026892662, 60.426417142152786, 64.4738307595253, 66.51148661971092, 68.57981443405151, 67.45581194758415, 68.48788976669312, 72.13282138109207, 74.71086904406548, 73.59221667051315, 76.57480582594872, 73.7730185687542, 57.81102128326893, 64.28944945335388, 68.03056910634041, 57.71770589053631, 64.28444892168045, 76.11340418457985, 74.96717289090157, 78.60866189002991, 70.8331923186779, 76.89518943428993, 77.91780576109886, 73.86454045772552, 70.84035873413086, 79.06913638114929, 67.83664271235466, 68.53237017989159, 76.11125349998474, 66.57081663608551, 73.10542479157448, 72.40717425942421, 74.0795861184597, 74.35605928301811, 72.99779176712036, 68.36334004998207, 67.78387114405632, 70.14434248209, 68.06627199053764, 66.42371892929077, 68.02613094449043, 74.57873493432999, 71.21482864022255, 72.46121495962143, 65.9427635371685, 67.5192229449749, 71.18190720677376, 66.63466840982437, 67.0835991203785, 67.39345729351044, 66.62339061498642, 67.11666494607925, 70.17514362931252, 67.62004673480988, 67.15410813689232, 63.721311539411545, 68.11669528484344, 69.42601382732391, 74.67306107282639, 72.43016302585602, 72.07962423563004, 69.65445756912231, 69.72231432795525, 73.18415656685829, 74.13816377520561, 69.95222479104996, 73.3644112944603, 73.74684557318687, 72.5122158229351, 71.64579391479492, 73.30512687563896, 75.57403072714806, 75.65994411706924, 73.56032878160477, 73.32900479435921, 77.89718806743622, 76.34647607803345, 76.06471359729767, 78.96372243762016, 82.70098149776459, 72.69136860966682, 68.41713756322861, 69.36283081769943, 19.75514754652977, 0.1089910433802288, 0.0820329668931663, 0.39781917817890644, 0.13447613484458998, 0.19499553192872554, 0.1173768074659165, 0.16966819879598916, 0.07235740209580399, 0.8741577586624771, 0.5819650157354772, 1.7129143606871367, 0.0417484414356295, 0.16193356539588422, 18.62168736755848, 69.68468874692917, 76.28233551979065, 37.734103202819824, 34.00064013898373, 37.005135118961334, 56.931710466742516, 55.62610052525997, 69.84933391213417, 8.715830761939287, 0.15311679162550718, 0.04763530523632653, 0.10069780284538865, 0.04813858155102935, 0.041088278812821954, 0.046549175822292455, 0.052373454309417866, 0.013974784542369889, 0.007221647474580095, 0.02026314559770981, 0.0813862965151202, 0.0684414673014544, 0.12399247512803413, 0.1254012866411358, 0.1355066811083816, 0.23464296071324497, 0.24107246805215254, 0.14626559597672895, 0.1995292230276391, 0.15257315360940993, 0.20059269096236676, 0.1413454388966784, 0.29203362646512687, 0.19954137940658256, 0.25269261561334133, 0.9680846217088401, 22.629668600857258, 87.4079105257988, 78.78511682152748, 52.392443642020226, 64.49982136487961, 101.64677247405052, 97.57124796509743, 17.485367842018604, 0.5355597683228552, 0.7349715835880488, 2.101972633972764, 8.630703929811716, 1.0191130335442722, 0.16904234566027299, 0.7490216265432537, 0.9394982212688774, 0.4203313373727724, 1.820316903758794, 0.3396175825037062, 1.17566843284294, 40.65926983952522, 86.4034116268158, 88.07818695902824, 110.13603374361992, 102.4095131456852, 103.98947596549988, 100.10195016860962, 101.16998165845871, 96.86922803521156, 92.87377282977104, 86.03163957595825, 84.62830647826195, 82.59815141558647, 89.50816422700882, 92.27065399289131, 95.33252969384193, 93.33492368459702, 90.03820538520813, 80.58039128780365, 74.00673642754555, 66.92679673433304, 67.58976235985756, 68.88244539499283, 67.41385459899902, 63.58316235244274, 67.81880646944046, 71.50071009993553, 73.52166205644608, 70.87516486644745, 72.69661232829094, 77.27687895298004, 82.03945979475975, 76.99653759598732, 79.91187036037445, 75.12212857604027, 58.66445928812027, 67.46015891432762, 78.43819543719292, 71.18439987301826, 69.24407958984375, 80.97303181886673, 79.4635172188282, 82.387825101614, 74.24901902675629, 80.11642098426819, 82.11360141634941, 79.00261715054512, 73.09732362627983, 81.95840254426003, 70.45612335205078, 67.05977439880371, 83.83007571101189, 72.32439950108528, 75.06814107298851, 77.2328469157219, 77.88890451192856, 77.91839092969894, 77.45174556970596, 72.64886409044266, 70.18484830856323, 73.3270289003849, 71.07159152626991, 68.95724818110466, 72.26629301905632, 78.50558862090111, 73.96395072340965, 75.98794251680374, 67.07807421684265, 72.50615894794464, 75.2579864859581, 72.38603979349136, 68.08122038841248, 69.32273536920547, 69.62106496095657, 70.01697331666946, 75.99121034145355, 71.04923352599144, 70.76845899224281, 70.5279091000557, 71.7452421784401, 73.41973632574081, 78.23659345507622, 75.30894935131073, 74.06222105026245, 73.70336830615997, 72.71497294306755, 76.11703678965569, 77.40544125437737, 75.58371260762215, 76.24114573001862, 75.9667320549488, 79.92260858416557, 74.76776719093323, 77.51645609736443, 77.82524272799492, 79.10217180848122, 77.71382510662079, 77.13836878538132, 77.93091505765915, 78.37469324469566, 77.13396102190018, 80.05651339888573, 85.15002608299255, 75.16001254320145, 73.73605415225029, 77.80218556523323, 24.941854029893875, 0.20858814474195242, 0.3303974959999323, 0.8043333585374057, 0.35355701576918364, 0.2968053094809875, 0.21694738446967676, 0.5032833502627909, 0.17119173891842365, 2.6255460642278194, 4.650279767811298, 1.905700103379786, 0.06453709516790695, 0.652375950012356, 27.229422479867935, 85.05741745233536, 83.48941639065742, 50.56549407541752, 71.1052805185318, 47.511746138334274, 66.52867689728737, 62.312366142868996, 82.53176137804985, 12.81640162691474, 0.41711982688866556, 0.1935161792789586, 0.16515282390173525, 0.13978376722661778, 0.12163249746663496, 0.17539398686494678, 0.16067274555098265, 0.15171579492744058, 0.06736563518643379, 0.11874725736561231, 0.16701592627214268, 0.1253896942944266], [0.02102093589201104, 0.04394318733830005, 0.06279100722167641, 0.05000655983167235, 0.013107005179335829, 0.03571298482711427, 0.23739474039757624, 0.012931358305650065, 0.1303640429978259, 0.041353496417286806, 0.12524586607469246, 0.025330179269076325, 0.23778079077601433, 0.4687013168586418, 17.64240201562643, 65.46329006552696, 42.01193265616894, 45.47492243349552, 43.947734981775284, 84.93830904364586, 50.65701976418495, 1.000588908791542, 0.039584060505148955, 0.033844498175312765, 2.3351050866767764, 0.7399856520351022, 0.3294571058358997, 0.11526620626682416, 0.09028921878780238, 0.4470087855588645, 1.23486771248281, 0.6626846781000495, 1.2734381365589797, 50.302935764193535, 95.51113530993462, 93.21904510259628, 95.16430512070656, 96.0775177180767, 95.334133207798, 94.11841124296188, 90.39906442165375, 90.56378558278084, 84.50429633259773, 79.6601490676403, 74.00224506855011, 75.25195240974426, 77.30253517627716, 86.10151022672653, 85.23095414042473, 85.60064390301704, 81.53154104948044, 79.80118989944458, 75.16012653708458, 70.0441038608551, 61.92875012755394, 61.521039605140686, 61.69513486325741, 61.22180186212063, 62.37598232924938, 62.68904373049736, 59.1183677315712, 62.94613793492317, 62.19867244362831, 63.80913242697716, 64.17277291417122, 69.21332404017448, 72.17319801449776, 71.75221100449562, 67.25573748350143, 61.72570042312145, 66.17558464407921, 57.774273455142975, 47.92557053267956, 67.93669134378433, 71.2259316444397, 72.05681785941124, 68.04949969053268, 72.00743570923805, 74.69587504863739, 69.29940462112427, 71.14482879638672, 76.22679010033607, 68.17473337054253, 68.12266856431961, 73.0609367787838, 60.32801382243633, 68.43080163002014, 70.3480115532875, 70.31617686152458, 68.58763441443443, 71.59086406230927, 69.15414601564407, 66.99838489294052, 64.99703988432884, 67.75696858763695, 68.06647717952728, 66.98261573910713, 67.42093741893768, 63.141595646739006, 68.57615143060684, 69.55142229795456, 67.83726587891579, 63.056073635816574, 63.15472014248371, 65.1750223338604, 66.36939704418182, 65.77181071043015, 63.04439306259155, 64.82652023434639, 67.99938037991524, 65.81939935684204, 63.58565501868725, 60.57011403143406, 59.405385330319405, 66.27115711569786, 69.0348020195961, 69.30889651179314, 71.03765174746513, 72.43162974715233, 68.34663614630699, 71.84116423130035, 72.92530685663223, 71.06919765472412, 71.44397154450417, 66.48285135626793, 66.15435898303986, 67.07557395100594, 68.96649688482285, 68.43867480754852, 71.67905732989311, 72.41690933704376, 69.78100597858429, 69.75240111351013, 70.34724399447441, 73.65784674882889, 72.32737854123116, 74.04037222266197, 74.216697961092, 62.74379499256611, 50.270804688334465, 59.58770714700222, 12.979213390499353, 0.46954169520176947, 0.20827316242503002, 0.11790743563324213, 0.3629403153900057, 0.2797108580125496, 0.035595410081441514, 0.29844420903827995, 0.43905346712563187, 3.7268051085993648, 2.0178546477109194, 0.1414177834521979, 0.10145924636162817, 3.5443640733137727, 34.364842996001244, 77.00650066137314, 41.26849114894867, 35.08941851556301, 57.757098376750946, 52.90599748492241, 43.73916417360306, 50.30624158680439, 1.2049253191798925, 0.03413744612771552, 0.03812025584920775, 0.09245333625585772, 0.12968677387107164, 0.02019181221839972, 0.10029763681814075, 0.01873189085017657, 0.046871531376382336, 0.02115948187565664, 0.03536544449161738, 0.019678589269460645, 0.03529563808115199, 0.01956374562723795, 0.07193079334683716, 0.05172072800633032, 0.02257490406918805, 0.030393361194001045, 0.01547339870739961, 0.06256374676013365, 0.030812578152108472, 0.1102036533120554, 0.07786646820022725, 0.08338446234120056, 0.01840015269408468, 0.2399922869517468, 0.37055014923680574, 24.021786600351334, 77.29170575737953, 50.300370901823044, 40.793611630797386, 40.61364188790321, 97.55940780043602, 62.3965772241354, 1.5666989190503955, 0.015969613486959133, 0.2021290108677931, 0.9904723078943789, 0.5635284050367773, 1.6528740199282765, 0.08010918652871624, 0.4228443978354335, 0.8755040739197284, 2.343398379161954, 0.6727699900511652, 3.074151654727757, 59.19505141675472, 99.4025444984436, 99.04429972171783, 102.30256408452988, 98.57051074504852, 99.24877434968948, 97.27351114153862, 93.19584354758263, 94.47540208697319, 88.15156862139702, 83.34307104349136, 78.71542856097221, 77.50251084566116, 80.22954851388931, 87.1049451828003, 88.10789376497269, 88.15226778388023, 85.9962710738182, 83.91953811049461, 79.79049727320671, 73.42955499887466, 66.39462009072304, 64.51220110058784, 65.74576690793037, 66.32674053311348, 64.93952617049217, 65.08169174194336, 64.59497585892677, 65.17398118972778, 65.21771684288979, 67.4644222855568, 68.22270959615707, 72.29355275630951, 74.93463143706322, 75.55136114358902, 73.03787961602211, 64.37327295541763, 69.80921566486359, 59.79777127504349, 59.223952665925026, 73.58653217554092, 74.70828518271446, 76.75636008381844, 72.19934061169624, 73.93367394804955, 77.9205872118473, 73.07467684149742, 75.0909474492073, 80.11846527457237, 70.35451680421829, 72.99386277794838, 75.82719594240189, 63.62706899642944, 73.87846291065216, 71.51504293084145, 73.2776391506195, 71.334408223629, 76.49443253874779, 71.63727477192879, 70.47675624489784, 68.27398404479027, 69.17740076780319, 71.27230435609818, 70.3617212176323, 71.412782818079, 65.83557888865471, 68.54329839348793, 69.16879042983055, 71.84530600905418, 67.14956358075142, 66.46900489926338, 67.5955456495285, 68.02803084254265, 69.71066415309906, 65.16895785927773, 67.2259470820427, 70.61542600393295, 69.11905109882355, 65.74151873588562, 63.620810732245445, 62.87880174815655, 68.26832994818687, 72.42430374026299, 70.38245290517807, 73.91184031963348, 74.02018010616302, 72.73401752114296, 75.09734630584717, 74.34527546167374, 74.38089475035667, 75.11703684926033, 69.09967213869095, 68.4812705218792, 69.49483573436737, 69.60236996412277, 70.47866374254227, 75.58486014604568, 74.32943791151047, 72.24802359938622, 72.4087929725647, 71.79345399141312, 74.90504622459412, 76.3345143198967, 76.82866260409355, 76.26156583428383, 66.92570999264717, 58.17661866545677, 68.15321892499924, 17.90581338107586, 0.22907162841875106, 0.0634481270390097, 0.2637163584586233, 0.4474057158222422, 0.8762392157223076, 0.09638679315685295, 0.1505327521590516, 0.6865408073645085, 2.1905598929151893, 2.4099788814783096, 1.4021333120763302, 0.20852880261372775, 3.859957563690841, 41.28720134496689, 88.04066777229309, 45.40192075073719, 36.41116999089718, 64.08291533589363, 54.747447073459625, 50.07554456591606, 60.053824335336685, 2.3899207077920437, 0.0730067070981022, 0.04881611042947043, 0.04935233067953959, 0.041923669923562557, 0.010427130328025669, 0.10012381098931655, 0.03070362530706916, 0.002102785456372658, 0.04344913591921795, 0.018319998889637645, 0.05038256524130702, 0.03751274860405829, 0.1796175492927432, 0.22508806170662865, 0.2869754150742665, 0.12502101017162204, 0.18173753865994513, 0.13770244375336915, 0.26184329646639526, 0.152232923428528, 0.2529580966802314, 0.16692899109330028, 0.18421910237520933, 0.19906410423573107, 0.4951587924733758, 0.6294413900468498, 29.430537968873978, 89.37219232320786, 57.498898431658745, 57.433728128671646, 60.76404042541981, 106.45612880587578, 73.29760327935219, 2.7871613670140505, 0.07366467296378687, 0.19577072001993656, 5.706806899979711, 4.3239751271903515, 2.6351673854514956, 0.5177886562887579, 0.6865835550706834, 1.2895428598858416, 4.424997456371784, 1.1965864291414618, 2.785713644698262, 60.525964200496674, 100.90770453214645, 103.20577561855316, 107.3222391307354, 102.735885232687, 104.88313481211662, 100.91729521751404, 97.19478696584702, 97.72045835852623, 93.74734595417976, 86.06445461511612, 81.96427702903748, 80.99501743912697, 83.69311586022377, 90.55686995387077, 91.32955849170685, 90.93978300690651, 90.60763522982597, 86.54566839337349, 84.14164379239082, 77.46708154678345, 68.77640828490257, 68.69551822543144, 67.29882717132568, 68.64612087607384, 68.847266882658, 68.14697965979576, 65.08975490927696, 70.01249715685844, 69.38833504915237, 72.9853056371212, 73.05912807583809, 77.53357797861099, 81.01750463247299, 80.28976768255234, 79.8547138273716, 70.83729609847069, 78.1949856877327, 73.01584839820862, 66.59418538212776, 78.81052985787392, 79.23710256814957, 80.73913916945457, 74.33972775936127, 76.93840831518173, 83.64920541644096, 77.8730745613575, 77.60241508483887, 83.29462364315987, 73.00430461764336, 71.96367725729942, 83.30625861883163, 68.32102552056313, 73.97743239998817, 76.13244116306305, 76.6361953318119, 75.55662006139755, 79.18449819087982, 72.91538938879967, 73.82545575499535, 70.68219602108002, 73.23222398757935, 75.75335070490837, 72.87203371524811, 74.63094413280487, 68.14080879092216, 72.31359288096428, 73.10809224843979, 76.87811315059662, 66.40215888619423, 69.76221978664398, 70.9729640185833, 72.2237429022789, 73.48723590373993, 67.70748004317284, 70.45078843832016, 75.66684454679489, 73.1479749083519, 68.84596735239029, 67.44407057762146, 67.38607048988342, 73.73124361038208, 76.83963641524315, 74.33012947440147, 78.42879474163055, 77.79805898666382, 75.3335340321064, 78.12275916337967, 78.59074965119362, 76.44431322813034, 79.12249311804771, 72.93532311916351, 72.44594737887383, 72.7025780081749, 75.6759412586689, 75.71130976080894, 79.58641782402992, 78.49016144871712, 74.80531677603722, 75.62439322471619, 74.75255280733109, 75.58771759271622, 75.64578607678413, 79.01551365852356, 77.1961484849453, 70.13805001974106, 63.18587087094784, 74.537583142519, 20.917738862335682, 0.6233617756515741, 1.2184328818693757, 1.326619607862085, 1.8627305841073394, 1.0596717009320855, 0.20085312542505562, 0.5488494364544749, 2.469263062812388, 12.216068990528584, 6.262078229337931, 1.3182000909000635, 0.272100786678493, 5.84645795635879, 52.36029356718063, 95.46651810407639, 57.400411516427994, 53.43594744801521, 71.34333774447441, 65.93768700957298, 58.06495025753975, 74.93928238749504, 3.5505024064332247, 0.22318311705021188, 0.15948098996886984, 0.2605198393575847, 0.14699074847158045, 0.13464935211231932, 0.2374900915310718, 0.1163219336012844, 0.1032447126635816, 0.15287936374079436, 0.09486440336331725, 0.12816872564144433, 0.10353666613809764], [0.05828258625115268, 0.07658615955733694, 0.05251310794847086, 0.04616363010427449, 0.03578783042030409, 0.06157853458717, 0.013054918472334975, 0.0626016259775497, 0.053268146730260924, 0.10396515252068639, 0.0299538093895535, 0.017851623924798332, 0.0750903609150555, 0.1280435995431617, 31.801975518465042, 65.6548909842968, 50.92076741158962, 40.3416258841753, 48.54914367198944, 93.55697616934776, 21.990565694868565, 0.49628905369900167, 0.06654309065197594, 0.16035316191846505, 2.678437801077962, 1.3304937374778092, 0.9751239221077412, 0.1740380682167597, 0.33716911857482046, 0.16119364416226745, 0.3408554254565388, 8.528639506548643, 78.96897375583649, 105.87197095155716, 95.81098482012749, 90.58262497186661, 90.37185028195381, 92.18048483133316, 89.11992385983467, 86.85454621911049, 86.53008922934532, 84.54824477434158, 78.16203385591507, 75.26299461722374, 71.73473194241524, 73.59454214572906, 76.31241470575333, 84.71219077706337, 87.1208131313324, 87.7564962208271, 83.83314594626427, 84.19485613703728, 75.8038803935051, 67.22764939069748, 61.693124771118164, 64.06286761164665, 66.68063074350357, 66.1428152024746, 65.5438381433487, 64.98905271291733, 60.56595325469971, 63.057000786066055, 65.03787249326706, 63.61831806600094, 67.06592246890068, 66.92708551883698, 71.42060279846191, 65.13353615999222, 65.47531262040138, 64.56854447722435, 62.25972756743431, 48.78262974321842, 60.673502683639526, 70.29805943369865, 71.70143812894821, 71.15464746952057, 72.36929789185524, 73.46850290894508, 68.89565348625183, 71.2090453505516, 68.46800163388252, 66.406589448452, 70.18539547920227, 74.72787693142891, 58.48396137356758, 63.04856903851032, 71.50215402245522, 70.27557224035263, 66.99372634291649, 61.60916067659855, 66.78359761834145, 71.35689541697502, 65.06439507007599, 63.450773656368256, 66.79021686315536, 66.09430700540543, 66.758693754673, 71.35163649916649, 70.38957372307777, 67.4589429795742, 64.78384092450142, 63.57438862323761, 69.81678485870361, 65.07836312055588, 66.39759913086891, 65.43291449546814, 67.30014950037003, 63.076166957616806, 63.60658809542656, 67.27086827158928, 65.89891389012337, 64.64970052242279, 59.545153230428696, 61.549697667360306, 61.41314439475536, 63.2408045232296, 67.36419886350632, 68.21103662252426, 67.06786036491394, 68.49270790815353, 71.76290363073349, 68.87717127799988, 70.04052445292473, 68.52091759443283, 64.44543108344078, 63.23262736201286, 59.17553946375847, 62.053687423467636, 67.18952223658562, 69.16064366698265, 69.28848400712013, 74.97070670127869, 64.24977198243141, 58.71879257261753, 65.97348868846893, 69.72402423620224, 70.27737334370613, 70.77793568372726, 68.43485981225967, 64.57323342561722, 48.91748070716858, 69.07074049115181, 18.74636247754097, 0.156009208294563, 0.18260516866575927, 0.3468737087678164, 2.340190401300788, 0.3681460954248905, 0.12584982585394755, 0.6964995386078954, 0.12093850033124909, 1.9734807475470006, 0.44886528281494975, 0.07903833422460593, 0.6452513323165476, 19.95697371661663, 63.154389560222626, 46.91996209323406, 14.698685724288225, 26.90414473414421, 50.69884032011032, 43.62019255757332, 39.84781198203564, 0.5622889590449631, 0.10369510724558495, 0.02802774506562855, 0.05417607906565536, 0.03740197935258038, 0.06062088948965538, 0.015597665769746527, 0.010867147830140311, 0.054235588177107275, 0.04651954928704072, 0.0849238176306244, 0.02955840238428209, 0.16570388339459896, 0.01935757329192711, 0.02911972074798541, 0.07112827195669524, 0.05572842936089728, 0.020257985815987922, 0.06703178005409427, 0.05007206549635157, 0.04091991519089788, 0.11414536289521493, 0.022969388955971226, 0.042090731076314114, 0.051053192146355286, 0.07301692647160962, 0.10751364257885143, 43.094521164894104, 70.72460174560547, 60.188762694597244, 42.00093984603882, 50.508645325899124, 111.12377554178238, 30.10295368731022, 0.23506291239755228, 0.4478477092925459, 1.071645689662546, 1.0780374216847122, 2.0784321846440434, 1.4057589112780988, 0.4140491463476792, 0.7025622320361435, 0.9767758834641427, 0.38514163345098495, 12.574587352573872, 85.84781304001808, 109.94840741157532, 97.93054148554802, 95.48972725868225, 95.3058323264122, 96.19581297039986, 91.0486851632595, 90.68014293909073, 90.37491291761398, 88.43520820140839, 80.56381657719612, 78.58286127448082, 74.91914346814156, 76.97589710354805, 80.15451774001122, 88.61591130495071, 89.85576957464218, 90.85527554154396, 87.0516188442707, 88.16156208515167, 78.3802105486393, 71.27353549003601, 65.22572681307793, 67.32658088207245, 68.65848541259766, 69.63547378778458, 68.67436856031418, 67.44325742125511, 62.86954164505005, 67.36540719866753, 69.35321733355522, 68.29941987991333, 70.35261690616608, 70.05045711994171, 75.1143465936184, 69.2274060845375, 68.96086558699608, 69.62696984410286, 63.65525208413601, 56.14518687129021, 67.12007716298103, 74.40438508987427, 75.45483112335205, 73.94586369395256, 76.85944095253944, 74.16620627045631, 72.56363466382027, 73.31709623336792, 71.0373705625534, 69.04417231678963, 73.34911331534386, 75.14580890536308, 62.09091782569885, 68.04287284612656, 74.64601412415504, 71.92762479186058, 66.04354172945023, 62.80749097466469, 68.67217987775803, 73.9159744977951, 70.02042353153229, 66.25332847237587, 69.08641085028648, 69.27986606955528, 69.74737018346786, 74.51745182275772, 71.1288620531559, 68.64335462450981, 67.0194585621357, 64.93159219622612, 73.2655481994152, 70.53553149104118, 70.21863609552383, 69.663797467947, 70.51409304141998, 67.37902566790581, 67.53034114837646, 70.55771470069885, 70.28606727719307, 67.5219663977623, 62.11673744022846, 64.2539593577385, 63.103426694869995, 66.672423183918, 69.89221841096878, 69.34841439127922, 70.5142830312252, 69.87313583493233, 73.95792424678802, 72.58968606591225, 72.45337978005409, 71.60267382860184, 69.0201424062252, 64.03715059161186, 61.004734709858894, 65.16037791967392, 69.2768794298172, 72.68026560544968, 72.34401404857635, 76.61142066121101, 67.84913644194603, 63.1660283356905, 66.32899761199951, 71.61449119448662, 73.1358839571476, 71.89658805727959, 72.65495136380196, 70.40919587016106, 60.38711205124855, 79.27052557468414, 25.10163925588131, 0.035843469231622294, 0.35988875257316977, 0.4251347546232864, 3.106592413969338, 0.3491268988000229, 0.16951219935435802, 0.48498685704544187, 0.5171543278265744, 1.126478766091168, 3.7678873166441917, 0.22449253272498026, 0.48268988030031323, 23.86525969952345, 73.92605915665627, 48.45065675675869, 19.025421403348446, 31.07874132692814, 52.09244593977928, 48.11908654868603, 49.78511855006218, 0.8872967411298305, 0.16189050598768517, 0.03597448427171912, 0.032659774442436174, 0.03800742342718877, 0.04461561766220257, 0.016179747035494074, 0.04153059511736501, 0.03614010565797798, 0.1488121272996068, 0.026396829161967617, 0.0202018200798193, 0.04190634819678962, 0.11748615550459363, 0.12360940818325616, 0.14744648651685566, 0.13509707496268675, 0.1451760935015045, 0.14182286249706522, 0.16818985546706244, 0.13371834269491956, 0.20246447646059096, 0.12417164442013018, 0.0717606114631053, 0.10487247258424759, 0.1473511799122207, 0.21057108911918476, 51.62601336836815, 84.39964234828949, 69.9272221326828, 54.54105354845524, 67.3546689748764, 116.8075941503048, 38.4788404405117, 0.5578119086567312, 0.3940791398053989, 1.180019793100655, 5.352840218693018, 3.51847012527287, 4.1689448710531, 1.0821346705779433, 0.6620195356663316, 2.5877209939062595, 1.175218157004565, 12.13825486600399, 82.30803698301315, 110.91616988182068, 101.13034218549728, 99.20503109693527, 99.97293949127197, 100.00394582748413, 94.499591588974, 94.14025247097015, 92.5542251765728, 92.41896763443947, 86.57308772206306, 83.15173611044884, 77.75790274143219, 83.75004440546036, 80.9490855038166, 91.71606615185738, 93.03293868899345, 95.473053753376, 86.78000941872597, 92.05787301063538, 83.55966702103615, 74.79422137141228, 66.79974675178528, 70.8753852546215, 72.38775730133057, 72.32440710067749, 70.98842158913612, 70.71406871080399, 66.56713843345642, 72.23455712199211, 73.39135184884071, 73.3323410153389, 74.4391380250454, 75.144023001194, 79.32079687714577, 73.9602193236351, 75.6744821369648, 75.55137634277344, 75.05277469754219, 65.98485007882118, 73.82538735866547, 80.01651674509048, 78.84603515267372, 77.05927222967148, 80.36802068352699, 81.29120394587517, 75.17809197306633, 76.30625143647194, 72.2375513613224, 71.03829771280289, 77.08879664540291, 82.91361048817635, 65.75006827712059, 68.68489399552345, 78.50225999951363, 74.04151976108551, 72.50025406479836, 65.34290492534637, 73.42284455895424, 77.36466184258461, 73.0573345720768, 71.4571264386177, 73.72172132134438, 70.97577586770058, 71.80040001869202, 77.32026502490044, 75.82770511507988, 72.51201063394547, 69.7524619102478, 69.62663546204567, 77.67288610339165, 71.26310124993324, 72.8857509791851, 72.26696938276291, 76.6155244410038, 70.932237803936, 70.53651943802834, 74.95800018310547, 72.62119397521019, 71.20395362377167, 65.39975747466087, 68.76062393188477, 67.5907427072525, 72.67486229538918, 73.1544953584671, 71.53991639614105, 72.85503342747688, 73.82611691951752, 78.69223460555077, 76.6812913119793, 73.95144179463387, 74.67955872416496, 72.11474195122719, 69.47585195302963, 64.53404232859612, 68.40057045221329, 73.13317090272903, 75.21558076143265, 76.2792120873928, 79.21128675341606, 69.01151686906815, 63.973412811756134, 68.2852466404438, 72.50813484191895, 72.31536358594894, 73.45235377550125, 72.25921019911766, 70.73412403464317, 61.917631924152374, 80.43097570538521, 27.479526959359646, 0.3478666429873556, 1.1018712865188718, 1.0041203442960978, 4.57133567892015, 0.846154389437288, 0.3612307633738965, 2.341538853943348, 1.3899125740863383, 5.468571083620191, 4.339553816244006, 0.25729443586897105, 1.4235311513766646, 33.277964517474174, 79.51014831662178, 60.939906388521194, 23.8372191041708, 35.322881788015366, 64.70867335796356, 56.23137004673481, 60.16148395836353, 1.5041381260380149, 0.19261564244516194, 0.18658006709301844, 0.1686610747128725, 0.1604347536340356, 0.12634425947908312, 0.10129669375601225, 0.16607696103164926, 0.12969556089956313, 0.16073048464022577, 0.14478616911219433, 0.08547734847525135, 0.34598663449287415], [0.029220174146757927, 0.0346215639001457, 0.0018153051610170223, 0.06606779701542109, 0.030070077955315355, 0.043034958143834956, 0.07981967472005635, 0.06665470966254361, 0.04299511594581418, 0.049318470191792585, 0.06454860587837175, 0.060758335239370354, 0.06332098972052336, 0.17937005788553506, 44.80851039290428, 59.441384598612785, 37.37576723098755, 37.765284329652786, 65.52838057279587, 79.37768742442131, 7.390034878626466, 0.12045346971717663, 0.20655002910643816, 0.8175893034785986, 0.2838964224793017, 0.5152987211477011, 0.45432173064909875, 0.10512800887227058, 1.9971459964290261, 0.28922061959747225, 16.94106224924326, 101.35054036974907, 99.26637500524521, 89.65482875704765, 91.49145260453224, 90.5315937101841, 90.51882639527321, 89.82592597603798, 88.03729355335236, 82.29771673679352, 80.19342765212059, 75.22483706474304, 74.2393447458744, 69.00032266974449, 70.14344573020935, 74.62517604231834, 77.19539612531662, 83.5666586458683, 86.84834495186806, 81.432373970747, 84.17603194713593, 78.33230271935463, 72.00590819120407, 69.13723692297935, 64.45235431194305, 67.37414672970772, 68.56332331895828, 73.24971824884415, 73.20162042975426, 70.66716402769089, 63.834530264139175, 62.48641200363636, 62.32253819704056, 66.42806589603424, 67.20256313681602, 67.3569868505001, 64.79892611503601, 63.91771540045738, 65.69993376731873, 62.94019505381584, 51.83877155184746, 50.05112707614899, 67.83979654312134, 70.29885739088058, 68.72031569480896, 69.97953772544861, 71.9520802795887, 67.18906626105309, 71.1220832169056, 65.74275746941566, 67.47848153114319, 73.82363945245743, 74.13586869835854, 59.676443785429, 67.32218831777573, 70.95027163624763, 67.70494937896729, 64.1823635995388, 59.48277197778225, 57.67049342393875, 63.74659538269043, 63.34575869143009, 69.90009918808937, 65.44777169823647, 65.651296377182, 71.08877420425415, 70.21995082497597, 67.19245567917824, 68.33389922976494, 69.1002345085144, 68.86018618941307, 62.563540264964104, 65.50957918167114, 69.15172934532166, 65.60024991631508, 66.07401609420776, 64.93385687470436, 64.83635410666466, 62.18158856034279, 66.33871749043465, 63.453714698553085, 64.73329603672028, 61.29989147186279, 59.40224289894104, 58.65334868431091, 61.73250965774059, 62.10145466029644, 66.94466337561607, 66.64492785930634, 68.17053079605103, 67.90795728564262, 68.09255138039589, 68.40620934963226, 69.9946229159832, 62.386842146515846, 55.4448464512825, 55.44730871915817, 62.00453706085682, 62.269386649131775, 67.95828178524971, 69.66581135988235, 66.37202650308609, 62.989334017038345, 68.94142583012581, 70.59014216065407, 73.62905189394951, 75.29514089226723, 77.10241511464119, 76.67150303721428, 72.29434311389923, 77.6692458987236, 59.8265091329813, 74.83217373490334, 25.832068361341953, 0.09236590383807197, 0.09489827498327941, 0.22142272791825235, 0.07238955193315633, 0.09871502174064517, 0.08707210508873686, 0.3503351745894179, 1.143256409559399, 3.910586521960795, 0.1713087162352167, 0.07641571792191826, 7.184746144339442, 49.40236508846283, 53.02146568894386, 28.821554146707058, 42.94096380472183, 38.656914085149765, 48.77395860850811, 36.56246267259121, 1.4453595550730824, 0.24678558023879305, 0.15649950073566288, 0.05319625859556254, 0.04060473991557956, 0.08504312529112212, 0.05188947754504625, 0.05760774394730106, 0.05986652606225107, 0.003875701113429386, 0.022530965215992182, 0.057736747767194174, 0.018792537302942947, 0.04392681184981484, 0.06654886456090026, 0.07360929390415549, 0.07088455808116123, 0.06619609950575978, 0.05868065942195244, 0.023358519247267395, 0.06027889670804143, 0.035598256217781454, 0.01896877325634705, 0.06243523646844551, 0.08090376693871804, 0.0693422119366005, 0.38503354706335813, 56.704391464591026, 69.43557411432266, 52.97981612384319, 27.997752651572227, 67.20903038978577, 93.10713350772858, 9.564906600862741, 0.20740370673593134, 0.3130813501775265, 1.5511578717269003, 0.2640900743426755, 1.8311935826204717, 1.3988282019272447, 0.6457855005282909, 2.071530567482114, 0.2745305188000202, 21.923180110752583, 109.70667198300362, 101.97676196694374, 93.24979305267334, 95.08593812584877, 95.99380061030388, 96.2310978770256, 90.09759619832039, 91.23396322131157, 86.28365725278854, 83.7751154601574, 79.45495247840881, 79.11943808197975, 73.43359038233757, 72.61199846863747, 76.43051236867905, 80.7669384777546, 86.48274376988411, 88.5464434325695, 85.79176604747772, 87.00932711362839, 78.38537067174911, 76.40643686056137, 71.65611416101456, 67.49353632330894, 70.4207244515419, 73.590027987957, 76.52776435017586, 78.24195876717567, 74.93173599243164, 69.68069136142731, 65.20359680056572, 67.38277226686478, 70.42319431900978, 69.58030834794044, 71.59296154975891, 68.36818099021912, 68.23166951537132, 70.1340526342392, 65.87806820869446, 58.06459687650204, 61.03220343589783, 73.76065403223038, 75.5342848598957, 72.98438608646393, 73.99213001132011, 73.27476650476456, 70.35455480217934, 72.69782826304436, 66.68646723031998, 68.8854244351387, 77.476125061512, 75.97001507878304, 62.39808954298496, 71.82612463831902, 73.06277588009834, 70.35806581377983, 63.66363823413849, 62.71800197660923, 61.995007172226906, 66.09271109104156, 62.20184147357941, 70.77163562178612, 72.30034679174423, 67.48503997921944, 73.67870762944221, 70.95317468047142, 68.92077773809433, 70.77181041240692, 70.50036817789078, 72.35781490802765, 66.55169606208801, 68.67591887712479, 69.10746172070503, 68.94269496202469, 65.97865641117096, 67.5560961663723, 66.7146161198616, 65.67106291651726, 68.61396700143814, 67.00965508818626, 66.06749564409256, 65.3382995724678, 62.71309643983841, 62.318924590945244, 62.8687284886837, 65.70304960012436, 68.99815678596497, 69.95853245258331, 71.80881276726723, 71.34628638625145, 69.75208953022957, 70.21634861826897, 70.37837952375412, 64.94181364774704, 58.41873787343502, 59.760920852422714, 64.51793119311333, 65.98618000745773, 70.41087538003922, 72.77054116129875, 68.14970791339874, 66.57049745321274, 70.0724883377552, 75.43121919035912, 74.64558854699135, 79.1356860101223, 81.07514753937721, 80.20826205611229, 77.20509320497513, 80.88137313723564, 67.7383191883564, 80.26057004928589, 30.880627557635307, 0.04817730681679677, 0.06702339378534816, 0.2600961917778477, 0.19926420209230855, 0.23513972468208522, 0.9895135124679655, 2.1456434531137347, 1.2020466173999012, 3.1685248157009482, 0.22366814024280757, 0.23332777112955227, 5.848567318171263, 55.63732512295246, 64.22996744513512, 27.212604582309723, 38.717600628733635, 50.05120687186718, 54.36173357069492, 45.78930616378784, 1.5081478608772159, 0.04193785607640166, 0.1028937881346792, 0.13466278498526663, 0.0660466606495902, 0.016956692161329556, 0.07977303073857911, 0.05572733840381261, 0.020179733764962293, 0.03779207072511781, 0.022072616666264366, 0.030338843025674578, 0.02980632423714269, 0.060683482224703766, 0.14138572267256677, 0.14543768571456894, 0.17660425161011517, 0.15094494097866118, 0.17663944425294176, 0.2968155511189252, 0.2640708675608039, 0.13515088066924363, 0.10987205430865288, 0.17618520534597337, 0.17069729045033455, 0.20723602588986978, 0.4995646560564637, 69.61136788129807, 77.00628027319908, 51.198604702949524, 55.94060204923153, 89.63719010353088, 104.21455308794975, 15.60099195688963, 0.28176687425002456, 0.6845579668879509, 2.2362688276916742, 0.459075661492534, 3.2559493370354176, 5.398437296971679, 1.0913419327698648, 5.744926929473877, 1.354009488131851, 21.755852289497852, 109.58526849746704, 105.57831510901451, 98.07737320661545, 100.12212708592415, 99.55250725150108, 101.19455114006996, 95.87090760469437, 94.90268155932426, 88.92180249094963, 87.44567289948463, 82.22785368561745, 83.16021725535393, 75.01686662435532, 77.73568153381348, 82.13026732206345, 83.8069349527359, 91.20978131890297, 92.72507160902023, 88.49622532725334, 89.11267384886742, 83.05817753076553, 79.58896368741989, 76.00972294807434, 71.78963899612427, 73.78321722149849, 74.9099175632, 77.78969943523407, 79.68615487217903, 78.8096635043621, 71.32740899920464, 69.15612190961838, 69.63304951786995, 73.92705470323563, 74.94386494159698, 76.36001095175743, 73.97356420755386, 74.19219687581062, 76.42372593283653, 77.89495378732681, 66.62035077810287, 66.82349547743797, 79.48042631149292, 77.95981630682945, 75.9695515036583, 77.25263625383377, 79.36231344938278, 74.37616020441055, 77.48062402009964, 67.17216476798058, 71.16502851247787, 78.74062120914459, 80.04607915878296, 66.29737570881844, 75.00747352838516, 76.02168470621109, 73.86551320552826, 65.29632702469826, 65.10966584086418, 62.99583546817303, 66.3152727484703, 65.68831399083138, 77.91479632258415, 73.465516269207, 74.68145862221718, 77.46139705181122, 74.62022110819817, 71.92108914256096, 74.45609271526337, 73.82974192500114, 76.00134059786797, 70.53677782416344, 72.38131284713745, 74.1980105638504, 72.88512021303177, 71.05668872594833, 73.02302241325378, 70.38535594940186, 68.31137403845787, 74.42108899354935, 70.50445675849915, 70.76845899224281, 68.99369582533836, 65.79010292887688, 65.11057779192924, 68.71421322226524, 71.11312329769135, 74.2643778026104, 73.58842447400093, 75.64042836427689, 74.64576333761215, 74.66757416725159, 74.8672154545784, 74.8619033396244, 70.96707433462143, 61.465729773044586, 62.3764269053936, 68.07051256299019, 68.47485646605492, 72.51611441373825, 76.30058214068413, 71.40744790434837, 68.43149319291115, 70.75999304652214, 75.91933339834213, 76.7704801261425, 80.80034628510475, 83.02797675132751, 83.55392932891846, 77.53387436270714, 83.34152832627296, 69.25188437104225, 83.24602425098419, 32.45600022375584, 0.19246675277827308, 0.42585149116348475, 1.0112392622977495, 0.3312704397831112, 0.3186723939143121, 1.129698499571532, 4.435325302183628, 3.077925802208483, 8.124902620911598, 0.5965722631663084, 0.2680755261098966, 10.829865373671055, 70.03157213330269, 65.84681868553162, 46.48319453001022, 57.60582469403744, 52.761742025613785, 65.23167729377747, 56.06453239917755, 2.4730239110067487, 0.31795072951354086, 0.29174142808187753, 0.31721321283839643, 0.13164672651328146, 0.18063035822706297, 0.14569391962140799, 0.19491656741593033, 0.1161225036776159, 0.10709164256695658, 0.10699093312723562, 0.12825959420297295, 0.17720959178404883], [0.08255424399976619, 0.049279303348157555, 0.03130688004603144, 0.09505674577667378, 0.05467000803037081, 0.04208536534861196, 0.09270131748053245, 0.026508418486628216, 0.0480857629008824, 0.06185116995766293, 0.08546131808543578, 0.031789135027793236, 0.18068857229081914, 4.274953007698059, 58.34541320800781, 42.620477601885796, 34.48746241629124, 36.27277761697769, 75.44438928365707, 51.055846363306046, 2.0513037778437138, 0.0021151081227799295, 1.8623102316632867, 1.062736592721194, 0.19689676584675908, 1.961682380642742, 0.9777236357331276, 1.2080197781324387, 0.5210405099205673, 12.259352467954159, 104.86465260386467, 95.10057494044304, 93.80599960684776, 93.37851494550705, 95.77476516366005, 92.36672803759575, 91.28161266446114, 87.0057325065136, 83.29638674855232, 79.53661769628525, 74.54763740301132, 71.29909291863441, 69.19700771570206, 65.78010946512222, 69.9507124722004, 69.98366430401802, 78.13506290316582, 82.98724293708801, 83.84416535496712, 84.57608208060265, 80.72631865739822, 78.5014696419239, 72.06824004650116, 63.94351601600647, 63.083557561039925, 66.57271653413773, 75.00783070921898, 76.96431532502174, 77.74997636675835, 72.44493663311005, 68.79403933882713, 62.51386933028698, 66.55317798256874, 68.07559669017792, 66.93802133202553, 67.36793026328087, 65.46702146530151, 64.7888034582138, 60.66323943436146, 52.12462641298771, 48.70176628232002, 61.62029027938843, 72.75046303868294, 71.74268111586571, 69.15900975465775, 70.19044920802116, 68.44229981303215, 68.97267535328865, 62.181242778897285, 70.00949531793594, 74.25330519676208, 68.2050633430481, 61.095580235123634, 65.22817388176918, 66.96756854653358, 66.50029242038727, 61.642427891492844, 62.24691845476627, 67.77634754776955, 66.48021429777145, 68.10377597808838, 61.504848673939705, 61.539423018693924, 70.15588626265526, 63.16151037812233, 59.04158525168896, 67.40624740719795, 70.29017865657806, 69.17756035923958, 63.93021672964096, 65.40804862976074, 65.91376349329948, 65.91962277889252, 66.76420345902443, 66.40476554632187, 64.33798044919968, 65.7187807559967, 62.6069301366806, 62.986966744065285, 63.80597859621048, 64.40538883209229, 65.43140977621078, 62.86651700735092, 60.204790234565735, 59.563331454992294, 57.12287060916424, 56.80423490703106, 57.39762246608734, 60.77948659658432, 60.098107159137726, 63.16507078707218, 62.48555324971676, 64.23379004001617, 58.540088161826134, 56.05250224471092, 51.80000603199005, 53.761950954794884, 59.06633332371712, 65.61193808913231, 70.34652963280678, 67.28311881422997, 69.53344166278839, 68.96870836615562, 69.85624194145203, 72.63414368033409, 75.37412345409393, 71.96119979023933, 74.04349565505981, 73.75224128365517, 78.03272679448128, 69.55530568957329, 80.21597564220428, 67.1347975730896, 84.42189395427704, 32.18355484306812, 0.05697087362932507, 0.09687404279247858, 0.05657096364302561, 0.0631633352895733, 0.09379938433994539, 0.5116009258199483, 0.3501597902504727, 3.9347985852509737, 0.5283553549088538, 0.046027765129110776, 0.5290803441312164, 25.76197922229767, 57.55123682320118, 42.541989013552666, 36.43719099462032, 25.36547999829054, 41.06364794075489, 35.79391971230507, 0.17806594114517793, 0.059283001319272444, 0.0609257526230067, 0.10228196159005165, 0.03415945822780486, 0.044690103313769214, 0.01890083705802681, 0.009854540203377837, 0.008030378321564058, 0.06332931661745533, 0.049532999109942466, 0.05947820842266083, 0.06463304744102061, 0.06279018343775533, 0.06500409901491366, 0.054143116576597095, 0.03914036009518895, 0.039214185235323384, 0.06954897427931428, 0.11443767260061577, 0.07841735699912533, 0.03260309291363228, 0.03748573813936673, 0.032817165410961024, 0.11095746012870222, 0.2742723998380825, 5.971793280914426, 67.73331105709076, 51.0723564773798, 36.9098362326622, 32.883059307932854, 89.49943989515305, 60.69202668964863, 1.575031871907413, 0.022199143568286672, 3.2857931731268764, 1.451645961496979, 1.193278469145298, 2.5352332228794694, 0.8199780096765608, 1.843371691647917, 1.1563638062216341, 18.02181925624609, 115.75740650296211, 97.14894622564316, 100.86785987019539, 95.00204622745514, 99.95891824364662, 95.96594050526619, 97.01381027698517, 91.38193488121033, 87.42589876055717, 81.73069596290588, 77.00034499168396, 74.85061794519424, 72.49582350254059, 68.66079568862915, 72.57501885294914, 71.68791085481644, 80.56826993823051, 85.88206440210342, 85.91804087162018, 89.24939811229706, 85.08365124464035, 81.82107031345367, 74.87528622150421, 65.34578517079353, 66.49690300226212, 68.7224131822586, 78.58846977353096, 81.5023586153984, 81.25196725130081, 74.67789441347122, 71.02439045906067, 66.1708652973175, 67.89425522089005, 71.30701169371605, 71.5270958840847, 69.89160284399986, 70.30440509319305, 65.95816791057587, 66.76439344882965, 59.507713839411736, 58.563928082585335, 68.59040826559067, 76.1177359521389, 75.98134607076645, 74.62478086352348, 71.71590015292168, 71.80694326758385, 71.53247639536858, 64.49709311127663, 73.03276509046555, 76.077351719141, 69.24540191888809, 62.648674696683884, 67.49321714043617, 71.35394677519798, 70.74252918362617, 62.81949833035469, 66.09033241868019, 69.67955902218819, 68.19573104381561, 71.5013636648655, 64.84354332089424, 62.01222784817219, 73.603745251894, 69.06282931566238, 63.03039841353893, 67.27847546339035, 72.61540308594704, 71.8117918074131, 64.81081187725067, 66.70314833521843, 69.18560832738876, 69.96402695775032, 69.16929960250854, 68.47929462790489, 68.12911301851273, 68.170857578516, 64.81762871146202, 66.76645293831825, 64.95089516043663, 68.13622623682022, 67.43022412061691, 65.73795452713966, 64.65223878622055, 62.9003731906414, 59.794313460588455, 59.41087983548641, 59.306624829769135, 63.83341312408447, 61.8350737541914, 65.50419867038727, 63.557183146476746, 64.09405633807182, 62.5075426697731, 58.46470780670643, 55.29809072613716, 57.29446180164814, 61.78828306496143, 69.05044198036194, 71.21736690402031, 70.7220558822155, 72.88714170455933, 72.61290282011032, 73.69608789682388, 74.95189011096954, 79.3428584933281, 76.0051403939724, 76.73346251249313, 77.07724526524544, 79.75028783082962, 76.63528338074684, 84.95812878012657, 75.50540640950203, 90.29092982411385, 39.30349878966808, 0.04826926262467168, 0.16870570747414604, 0.13231715303845704, 0.32645657309331, 0.8218471531290561, 1.1669938545674086, 1.1582843656651676, 3.778967522084713, 1.5673410845920444, 0.24966545461211354, 0.444779492681846, 27.688196562230587, 69.73731592297554, 34.36855919659138, 35.62662988901138, 41.30070202052593, 47.00942449271679, 46.333216577768326, 0.606945528415963, 0.06220862167538144, 0.046249452061601914, 0.07780530781019479, 0.038218308400246315, 0.03198876904207282, 0.014926279091014294, 0.03099042642134009, 0.055302948676398955, 0.03096040654781973, 0.07625504294992425, 0.04776511799718719, 0.06069564231438562, 0.2519955311436206, 0.21968610235489905, 0.1575369489728473, 0.20026553742354736, 0.14068982563912868, 0.22764339490095153, 0.24203064007451758, 0.27804660669062287, 0.09668754108133726, 0.21211618121014908, 0.16707289352780208, 0.2000180460163392, 0.40894551551900804, 6.977716153487563, 84.10854756832123, 57.62950122356415, 46.83018431067467, 56.983178704977036, 99.17799174785614, 76.05510771274567, 2.524349419400096, 0.09001400816487148, 3.2212353497743607, 4.420424876734614, 1.0625866195186973, 5.745304534211755, 5.359547808766365, 4.391926880925894, 1.9653033488430083, 18.084455095231533, 118.50410431623459, 98.82151767611504, 103.59635666012764, 97.40530326962471, 105.757095515728, 101.54516592621803, 101.63820773363113, 94.93577018380165, 90.53636625409126, 85.38272559642792, 81.86786860227585, 80.91586768627167, 77.01627373695374, 73.03022682666779, 77.84908264875412, 74.91405934095383, 84.8470151424408, 89.2466014623642, 86.55072972178459, 92.36086115241051, 88.6974549293518, 85.50599098205566, 78.63585323095322, 69.80484589934349, 71.76866412162781, 72.9219326376915, 82.14313343167305, 84.99311730265617, 83.09155493974686, 77.4918182194233, 73.99706974625587, 67.47026637196541, 71.34087547659874, 74.77481201291084, 74.30264174938202, 74.38382059335709, 75.56378647685051, 73.17580461502075, 78.31062108278275, 68.79139468073845, 64.52773466706276, 73.41370224952698, 80.81473991274834, 79.49743419885635, 78.0066829919815, 76.98699250817299, 74.80929136276245, 74.20861959457397, 64.91642341017723, 73.39395090937614, 79.03985515236855, 75.25417909026146, 66.00786164402962, 69.54490944743156, 72.82259836792946, 72.02382802963257, 63.69093596935272, 66.17573663592339, 72.80863791704178, 72.65967071056366, 75.12843623757362, 63.80418509244919, 64.9499224126339, 75.91067746281624, 69.05596688389778, 65.94054445624352, 72.08460196852684, 77.92137756943703, 74.00349900126457, 67.3842465877533, 71.5692812204361, 71.39772042632103, 71.62074565887451, 71.50752693414688, 71.31540924310684, 71.26754701137543, 70.57035282254219, 68.638376891613, 71.57353699207306, 68.8781364262104, 70.8660301566124, 70.87473928928375, 70.10277271270752, 68.6303061246872, 67.38597929477692, 64.2925576865673, 62.05044239759445, 64.55262333154678, 68.73920828104019, 65.05586832761765, 69.70742672681808, 67.26416543126106, 71.02924659848213, 66.01786270737648, 62.52012379467487, 57.244429886341095, 59.01423431932926, 64.46006789803505, 71.9301326572895, 75.15248894691467, 74.2920783162117, 74.07488197088242, 74.25106331706047, 74.89572152495384, 79.6164058148861, 82.86096051335335, 76.98423385620117, 80.27547284960747, 79.94503498077393, 83.4844234585762, 78.60244542360306, 91.63759276270866, 79.55541148781776, 92.3087127506733, 39.24963288009167, 0.09854594565695152, 0.5692729249130934, 0.3592063032556325, 0.439913883456029, 1.0263001103885472, 1.7518551461398602, 1.234225903172046, 9.594144131988287, 2.4067654414102435, 0.2577913482673466, 0.8979606907814741, 40.74984937906265, 70.71542143821716, 59.0811563283205, 47.73713484406471, 34.9292229115963, 56.354608833789825, 55.681816935539246, 1.6674641682766378, 0.18939489964395761, 0.2594363037496805, 0.26599442528095096, 0.07208005408756435, 0.14305855322163552, 0.15191105398116633, 0.15207095711957663, 0.11705643715686165, 0.232376026106067, 0.16266369028016925, 0.13397990522207692, 0.10668030721717514], [0.033363204274792224, 0.04766230456880294, 0.013942215391580248, 0.03635693894466385, 0.05056558999058325, 0.01971576715732226, 0.080063336645253, 0.05405195115599781, 0.015136249367060373, 0.08944038738263771, 0.058842265789280646, 0.19273034879006445, 0.3838464670116082, 20.144474655389786, 61.26074597239494, 34.63614083826542, 39.95706371963024, 32.63937458395958, 87.40316838026047, 21.533585116267204, 0.376964412862435, 0.10207762607024051, 0.6983427365776151, 1.3480369211174548, 0.2384773557423614, 1.1229885346256196, 0.47353124362416565, 0.39097625005524606, 3.121322561055422, 84.90743950009346, 97.63027399778366, 96.70848146080971, 94.21194702386856, 91.03580385446548, 92.89916306734085, 89.70832988619804, 93.01517084240913, 89.46876034140587, 85.95238342881203, 78.74250590801239, 72.43416041135788, 66.16566717624664, 61.90738007426262, 65.67219525575638, 67.58107602596283, 72.31831222772598, 79.19573038816452, 82.75283351540565, 83.14643919467926, 82.77728140354156, 80.44598489999771, 73.96012052893639, 67.70635530352592, 59.804557710886, 61.67830936610699, 66.27640843391418, 71.4918565750122, 77.97011375427246, 78.0018724501133, 75.79460889101028, 69.36277002096176, 69.24747660756111, 66.62186309695244, 68.48536670207977, 70.16255870461464, 69.04652059078217, 70.03658026456833, 59.15167294442654, 55.69840304553509, 48.90399523079395, 57.28777036070824, 68.50860625505447, 69.80793133378029, 69.75112438201904, 71.15362152457237, 67.78571024537086, 70.3377141058445, 62.46642507612705, 70.25409579277039, 75.98898366093636, 64.73521113395691, 60.93866005539894, 66.67849525809288, 71.88530266284943, 70.47210529446602, 68.36871296167374, 63.17084647715092, 65.55826976895332, 60.687668323516846, 65.38388952612877, 62.122630923986435, 60.23967996239662, 59.20473709702492, 58.31855244934559, 71.46666392683983, 69.54283475875854, 60.549332946538925, 57.694945111870766, 67.23398745059967, 67.89066061377525, 60.87991900742054, 64.20187175273895, 64.10026520490646, 68.32797154784203, 64.49093744158745, 66.66008904576302, 61.43125802278519, 63.93757313489914, 60.16564853489399, 63.487320095300674, 63.64395909011364, 61.215410605072975, 62.942873910069466, 61.270344257354736, 58.72619077563286, 60.12888550758362, 55.25194600224495, 54.033210799098015, 54.78560842573643, 55.80750659108162, 55.39704881608486, 56.395091861486435, 54.38295543193817, 58.28162603080273, 54.45495776832104, 52.5017523765564, 56.278495118021965, 62.73952782154083, 66.26067727804184, 67.30190500617027, 72.97661930322647, 71.36390224099159, 72.2513522207737, 71.31582722067833, 71.42484337091446, 68.77766221761703, 73.20047289133072, 71.33533537387848, 72.26300999522209, 71.68593496084213, 77.81228542327881, 70.32253012061119, 76.79942697286606, 68.93997430801392, 88.23934391140938, 29.632166549563408, 0.022078227302699815, 0.16950688557699323, 0.2902557671768591, 0.6302547245286405, 0.4835584602551535, 0.10645360336638987, 1.4691098243929446, 0.22286451305262744, 0.3236306825419888, 0.04545138726825826, 9.104354213923216, 53.38479459285736, 44.765929877758026, 37.81703755259514, 27.004102170467377, 38.98183844983578, 45.76979421079159, 1.8127948511391878, 0.08108756723231636, 0.012124027798563475, 0.014359847864398034, 0.03306365862954408, 0.07070367442793213, 0.09490764088695869, 0.05855895462445915, 0.06243423456908204, 0.038494417021865956, 0.008752162393648177, 0.03845697567157913, 0.031055156541697215, 0.009724406463647028, 0.043562072241911665, 0.023793922446202487, 0.056674712177482434, 0.029616304746014066, 0.035752099720411934, 0.023164276935858652, 0.050474354065954685, 0.029753405397059396, 0.15066893625771627, 0.09102033814997412, 0.15887032117461786, 0.2995424688560888, 24.767650477588177, 72.76093527674675, 41.316980347037315, 49.0171417593956, 35.31000427901745, 99.4739730656147, 28.64911749958992, 0.4197241715155542, 0.05291722220135853, 2.201885422691703, 1.7789807030931115, 0.6826816988177598, 1.8593328539282084, 0.47473592741880566, 0.10335099563235417, 5.656314259395003, 91.2499451637268, 97.59095370769501, 101.7031842470169, 97.75323539972305, 94.86450120806694, 95.39629027247429, 94.43767011165619, 95.29370337724686, 92.97729447484016, 88.93296629190445, 80.0511708855629, 74.54990208148956, 68.48304882645607, 67.64463901519775, 68.9796593785286, 71.1232079565525, 75.03198221325874, 80.1147110760212, 86.74860030412674, 86.87132611870766, 86.826511323452, 83.28464537858963, 78.45856994390488, 70.44376641511917, 64.08267974853516, 64.677325040102, 69.37112957239151, 75.3698980808258, 79.40448358654976, 79.07735154032707, 78.71713846921921, 74.50964704155922, 74.11424025893211, 69.51125845313072, 70.79234451055527, 73.84469032287598, 71.84048026800156, 73.6924096941948, 64.8828712105751, 61.42482876777649, 57.794784754514694, 65.64371958374977, 73.9192347228527, 72.15394824743271, 74.0909019112587, 74.47696879506111, 70.11171743273735, 74.20842960476875, 61.51860773563385, 73.6328972876072, 78.38080331683159, 67.34190925955772, 65.24241551756859, 70.37840992212296, 73.6796347796917, 72.16375172138214, 70.70403724908829, 65.43967813253403, 66.61224961280823, 62.650107219815254, 66.84028297662735, 62.83652901649475, 62.11989127099514, 59.025633707642555, 58.46800982952118, 72.39211946725845, 73.16237613558769, 62.161012664437294, 59.91554215550423, 65.76174885034561, 70.78871190547943, 65.12586057186127, 66.4244256913662, 64.71080884337425, 69.35256376862526, 68.8467425107956, 67.85952508449554, 65.65113678574562, 68.12258496880531, 63.361539244651794, 67.08902522921562, 67.94252023100853, 63.693888410925865, 66.21535331010818, 64.06245723366737, 61.24154940247536, 61.17806240916252, 60.31428515911102, 58.1145565956831, 58.03673297166824, 58.29200327396393, 59.13387469947338, 59.08022157847881, 58.5790740698576, 60.76193153858185, 57.20438003540039, 55.05403742194176, 58.85802090167999, 64.35187250375748, 70.56064814329147, 71.44904807209969, 74.60680782794952, 73.00722286105156, 73.79320308566093, 74.52913239598274, 73.0169503390789, 71.44367516040802, 75.0972855091095, 73.14932763576508, 76.45340234041214, 74.78134766221046, 82.28421226143837, 76.08237504959106, 84.85014617443085, 73.43412235379219, 93.52511867880821, 38.834193572402, 0.045586921987705864, 0.10371746073360555, 0.08686575834872201, 1.3458198588341475, 1.8875553645193577, 1.284674252383411, 1.9633380230516195, 1.2036660430021584, 0.8204629586543888, 0.15032094321213663, 9.533890765160322, 59.84792098402977, 48.157578483223915, 25.08053708821535, 36.15794777870178, 47.821843698620796, 55.87844118475914, 2.873721197247505, 0.22051781241316348, 0.09803161505260505, 0.06176491384394467, 0.05505625878868159, 0.1258989263442345, 0.007786998412484536, 0.008483964138576994, 0.07907147111836821, 0.061071439922670834, 0.041361404000781476, 0.04900872372672893, 0.09125038908678107, 0.12011588900350034, 0.1923595421249047, 0.1048350015480537, 0.1578631525626406, 0.12285703371162526, 0.17441503470763564, 0.11204823909793049, 0.15061496727867052, 0.159413231885992, 0.39068826707080007, 0.19429430627496913, 0.25413923955056816, 0.5576899589505047, 30.26765014976263, 86.59797638654709, 49.60745148360729, 58.018178567290306, 49.208252504467964, 113.96545305848122, 38.21248613297939, 0.5701553681865335, 0.15486989286728203, 3.325144574046135, 4.592172810807824, 1.7608291958458722, 3.8658693339675665, 3.088763295672834, 1.2665570620447397, 5.719635486602783, 93.69173973798752, 97.7476193010807, 107.50401377677917, 101.84266716241837, 98.94922122359276, 99.08733621239662, 96.71127811074257, 98.45512613654137, 97.37860590219498, 91.41613304615021, 85.01840874552727, 77.9218639433384, 73.76705288887024, 70.51636531949043, 72.22594678401947, 73.34967568516731, 78.87756586074829, 84.77639213204384, 89.05021280050278, 90.29010906815529, 89.32825908064842, 86.2966601550579, 81.65083944797516, 74.48483437299728, 65.45604765415192, 69.81298506259918, 73.78660663962364, 80.789585262537, 83.20222020149231, 84.42617252469063, 80.4560923576355, 78.31204980611801, 77.00064897537231, 73.77057150006294, 72.83906668424606, 77.8211085498333, 77.083560526371, 79.80611443519592, 75.9635554254055, 72.88344830274582, 66.355140209198, 69.31797802448273, 76.5872311592102, 75.75942277908325, 76.77251681685448, 79.1864512860775, 73.56957748532295, 77.53842651844025, 66.08051374554634, 75.04028856754303, 83.93845349550247, 71.2925572693348, 68.77032101154327, 72.8707417845726, 78.09325754642487, 77.91794255375862, 74.13932651281357, 70.26015266776085, 70.28638646006584, 67.68126145005226, 72.0525772869587, 64.17254492640495, 66.06414422392845, 60.88276885449886, 61.59478224813938, 77.0521742105484, 72.86448732018471, 63.4415515512228, 64.02207300066948, 72.24375262856483, 72.31590315699577, 64.97465908527374, 70.06638586521149, 67.42820262908936, 73.05266842246056, 70.9595887362957, 70.4766346514225, 68.59218657016754, 72.8797473013401, 66.9027516245842, 71.29653185606003, 71.46975696086884, 67.22113654017448, 69.48147565126419, 69.65645626187325, 67.48065501451492, 66.92677393555641, 61.98189787566662, 60.91192848980427, 62.06537179648876, 62.88234695792198, 62.535980343818665, 61.362869292497635, 60.79263389110565, 64.69064712524414, 62.85620056092739, 56.89894862473011, 61.64322204887867, 68.19934844970703, 72.90721222758293, 73.45288574695587, 76.48217439651489, 75.93807399272919, 78.0010212957859, 76.72840878367424, 74.75476428866386, 72.14403837919235, 79.22723069787025, 75.37696570158005, 78.97702172398567, 80.06912112236023, 85.18154919147491, 77.27162003517151, 88.2336974143982, 77.27062448859215, 97.09603786468506, 38.08133617043495, 0.11350977278198116, 1.3780133938416839, 1.5781309618614614, 1.6527342586778104, 2.539152237586677, 3.222903460264206, 5.986486142501235, 2.7516843331977725, 0.9498555155005306, 0.2536327682901174, 16.840901523828506, 70.35511717200279, 60.0320553034544, 53.17574881017208, 37.45852679014206, 53.893572092056274, 65.19419610500336, 3.4485028171911836, 0.2714337146608159, 0.20030917570693418, 0.10801110416650772, 0.1382847476634197, 0.21842814720002934, 0.1494619221193716, 0.10096969606820494, 0.23202303098514676, 0.13178782362956554, 0.11847923073219135, 0.11224284506170079, 0.20429045660421252], [0.03105720301391557, 0.06119836572906934, 0.04775454610353336, 0.009552116880513495, 0.058948300138581544, 0.07750528719043359, 0.06640501407673582, 0.03438115258177277, 0.025410086309420876, 0.05403722323535476, 0.03501273880829103, 0.04178103285084944, 0.03255876443290617, 31.774869672954082, 59.1964041441679, 43.5357116907835, 27.688580341637135, 37.92529374361038, 82.99291223287582, 7.429650602862239, 0.03707881856826134, 0.4338636581087485, 3.5937483608722687, 1.9208008493296802, 1.0814118781127036, 0.3997642284957692, 0.2745147852692753, 0.22253980860114098, 30.075688250362873, 102.90620729327202, 93.001848757267, 95.45036137104034, 88.40521261096, 92.7598625421524, 87.07985132932663, 92.55426317453384, 87.13251650333405, 90.67297652363777, 83.12259927392006, 79.98250097036362, 71.16902589797974, 65.11955291032791, 64.34836149215698, 66.8019126355648, 66.9696432352066, 72.15018644928932, 78.85573223233223, 83.12059298157692, 80.03203511238098, 84.37398612499237, 78.78202378749847, 72.45058313012123, 66.38296991586685, 62.30734281241894, 59.031189009547234, 64.96439963579178, 69.9612683057785, 75.17256706953049, 76.02112233638763, 74.48903694748878, 73.61193001270294, 70.91481953859329, 66.62324622273445, 66.96967363357544, 69.111717492342, 70.72030037641525, 64.3769283592701, 54.717630073428154, 49.427443742752075, 56.016780361533165, 68.5709685087204, 70.9905494749546, 70.41393801569939, 71.46122261881828, 68.9201545715332, 71.44525587558746, 64.64106738567352, 68.81892800331116, 73.24391975998878, 65.12968316674232, 62.6682398468256, 67.91594445705414, 70.98918914794922, 65.26399835944176, 61.68487921357155, 59.138825833797455, 59.81811538338661, 60.101321786642075, 55.67656181752682, 57.04195775091648, 57.90578059852123, 56.779475435614586, 56.11222364008427, 57.01850160956383, 53.261487409472466, 64.95664045214653, 70.18604904413223, 65.86264103651047, 57.80594475567341, 62.50323370099068, 67.16312125325203, 66.25598073005676, 60.689013451337814, 62.519303038716316, 65.8564929664135, 63.330650702118874, 61.521013006567955, 63.28327864408493, 60.10842740535736, 61.2416709959507, 63.40797275304794, 61.60887949168682, 61.948588863015175, 60.13868898153305, 59.328321665525436, 56.78240887820721, 54.83760103583336, 56.40903331339359, 54.249005019664764, 57.819654420018196, 58.50831426680088, 57.25154310464859, 58.47524084150791, 54.93320390582085, 53.57711747288704, 55.08600890636444, 55.9734208881855, 60.26218995451927, 66.87400996685028, 69.67249140143394, 68.8771104812622, 71.47580623626709, 69.28122639656067, 69.69679489731789, 70.76038062572479, 68.03230941295624, 66.90135329961777, 66.3018062710762, 65.75440764427185, 71.44853889942169, 68.18675592541695, 72.89971143007278, 72.54233300685883, 76.44535437226295, 68.71226772665977, 81.49709969758987, 16.371955387294292, 1.286067352630198, 0.745812461245805, 1.4917036495171487, 0.3649884054902941, 2.0792947383597493, 1.5366389695554972, 1.4237393089570105, 0.3832203318597749, 0.023319077808992006, 1.9340722309425473, 35.010538548231125, 58.27079281210899, 41.10324561595917, 49.51540142297745, 42.6018738001585, 48.129228204488754, 3.6598966363817453, 0.15577514976030216, 0.061103689949959517, 0.024278543023683596, 0.07119859044905752, 0.003525848524077446, 0.044265969627304, 0.05187178103369661, 0.07402306349831633, 0.030607428125222214, 0.06346020178170875, 0.10387209462351166, 0.03915941844752524, 0.012340510420472128, 0.05222940715611912, 0.04862523746851366, 0.06400219222996384, 0.17679505777778104, 0.11594231764320284, 0.09237452017259784, 0.04601772016030736, 0.04143915881286375, 0.03231310984119773, 0.04892041557468474, 0.02347423305764096, 0.09177835294394754, 40.749157816171646, 69.0115624666214, 56.21234066784382, 32.92240619659424, 46.35547578334808, 100.90917125344276, 9.91509011015296, 0.03189096511050593, 1.4082836383022368, 3.771281959488988, 1.968036589678377, 2.890213024802506, 0.8525922533590347, 0.24111306353006512, 0.3178472147556022, 35.04409834742546, 106.53942793607712, 97.63228788971901, 97.35815539956093, 92.71001681685448, 99.74543809890747, 91.93049624562263, 98.06216642260551, 89.81034681200981, 94.24531683325768, 85.53245276212692, 83.13016086816788, 75.32468050718307, 69.10996198654175, 67.14284554123878, 70.25363981723785, 69.47960615158081, 76.28755643963814, 80.48266813158989, 82.67087951302528, 85.15837043523788, 86.29975318908691, 79.19838264584541, 76.70940980315208, 67.05913603305817, 64.21021610498428, 61.99690707027912, 67.78946444392204, 70.35114258527756, 79.33023557066917, 78.27237233519554, 75.74638947844505, 75.90315386652946, 72.15871319174767, 69.56523835659027, 69.80886608362198, 72.5925663113594, 72.91362628340721, 68.41376334428787, 60.09612366557121, 58.812780529260635, 64.76146772503853, 71.64882615208626, 73.98528277873993, 73.75929370522499, 72.5541427731514, 70.41493356227875, 72.80032396316528, 63.01359571516514, 73.5029062628746, 74.99218314886093, 65.86728438735008, 67.59752154350281, 72.35043570399284, 73.28497275710106, 66.05705380439758, 61.149818524718285, 58.55646528303623, 60.286615043878555, 64.15438190102577, 59.03170958161354, 56.74665279686451, 59.35971558094025, 59.007736667990685, 58.777510821819305, 60.269086584448814, 54.13613207638264, 63.00593912601471, 70.61418727040291, 71.11036464571953, 60.89465081691742, 64.84555721282959, 69.8895737528801, 69.79563519358635, 63.21091152727604, 65.26057854294777, 67.18737915158272, 67.1448290348053, 64.17616233229637, 66.79800644516945, 63.90256941318512, 65.54188504815102, 66.40337482094765, 65.90208292007446, 68.46595734357834, 63.77801209688187, 63.28647047281265, 59.30441714823246, 58.932591900229454, 59.31364305317402, 57.78323717415333, 59.07908543944359, 60.903325751423836, 61.666773185133934, 61.04775220155716, 56.87884770333767, 58.555686324834824, 55.36575749516487, 58.22192743420601, 65.39101794362068, 70.25335863232613, 70.95854759216309, 71.59195080399513, 74.54492434859276, 74.4499446451664, 73.43023136258125, 73.27655240893364, 68.62858861684799, 68.85465368628502, 69.92372632026672, 68.82524326443672, 73.4237565100193, 71.05071544647217, 77.83712849020958, 77.21662178635597, 83.30886527895927, 73.78690302371979, 87.03152552247047, 23.93984779715538, 1.31418916862458, 0.4802388633834198, 2.6016693329438567, 3.1810494186356664, 3.3059919392690063, 3.382156239822507, 3.055006144568324, 1.2379365228116512, 0.1431501639308408, 1.8061209842562675, 36.48353710770607, 69.50235933065414, 29.70178261399269, 47.4398197978735, 51.476107612252235, 57.43221580982208, 6.338425632566214, 0.19896980695193633, 0.14156725199427456, 0.05958627996733412, 0.0326103251427412, 0.004045690502607613, 0.0974234398745466, 0.07120478738215752, 0.07515912089729682, 0.07592626410769299, 0.04780519026098773, 0.11606466810917482, 0.06071069306926802, 0.1786196426837705, 0.19502817158354446, 0.1161247820709832, 0.12122718093451113, 0.23318529361858964, 0.1189423754112795, 0.1894216614891775, 0.11825876834336668, 0.08096509802271612, 0.13959649368189275, 0.09785444955923595, 0.18721187225310132, 0.15133084292756394, 48.27550135552883, 83.47090378403664, 59.97304826974869, 40.12886010110378, 56.09988950192928, 115.83882093429565, 14.34770330786705, 0.19139871321385726, 1.5683634672313929, 10.46641107648611, 4.173956802114844, 6.117938663810492, 6.294213104993105, 0.5037520313635468, 0.5725199694279581, 35.621682554483414, 107.56515249609947, 100.71652919054031, 102.55355581641197, 95.46974793076515, 103.3883786201477, 94.07538995146751, 102.06901341676712, 93.13327610492706, 96.46838754415512, 88.96564453840256, 87.98301726579666, 79.34839859604836, 72.95187503099442, 71.60994663834572, 73.53853315114975, 71.81398808956146, 81.12105667591095, 83.69364783167839, 86.70624777674675, 86.29595339298248, 92.07938745617867, 82.84938633441925, 77.59508147835732, 72.99553468823433, 68.83522152900696, 65.15617534518242, 72.47123122215271, 74.50212344527245, 84.1797785460949, 80.70730447769165, 78.84804144501686, 79.91310149431229, 76.32026508450508, 72.9416611790657, 75.16883566975594, 75.82119226455688, 76.75252988934517, 75.96230149269104, 68.36508795619011, 65.17540231347084, 70.51950395107269, 76.97631508111954, 78.93517076969147, 77.28666722774506, 78.28852906823158, 74.73350062966347, 77.40534245967865, 67.19356521964073, 75.20213708281517, 79.43690344691277, 71.55028983950615, 69.86705616116524, 74.936333745718, 78.65707129240036, 68.44374373555183, 66.58758893609047, 61.37719452381134, 62.66419306397438, 64.23739224672318, 59.85449083149433, 59.38726410269737, 59.46020878851414, 59.626043289899826, 58.02812643349171, 59.991731867194176, 55.84182634949684, 68.55070039629936, 74.39114660024643, 71.60657241940498, 62.451104298233986, 70.00810459256172, 71.84693232178688, 74.0734076499939, 64.75862547755241, 67.98446998000145, 71.02341771125793, 71.10838875174522, 66.03297829627991, 70.63291266560555, 68.42941850423813, 68.2523176074028, 69.63433384895325, 69.8048534989357, 71.71714648604393, 68.65865260362625, 68.44519525766373, 63.75379219651222, 60.345637276768684, 65.63083067536354, 61.987168192863464, 62.66154460608959, 64.20457720756531, 63.6140850931406, 65.0127786397934, 60.36037288606167, 60.12725539505482, 59.5942085981369, 60.79474277794361, 69.22099962830544, 74.08282354474068, 74.6485447883606, 74.28368076682091, 77.17955857515335, 76.50938093662262, 77.44179010391235, 76.75149634480476, 72.0386092364788, 72.90963649749756, 72.7725550532341, 72.26467430591583, 77.61378407478333, 75.57214602828026, 82.32885986566544, 81.43273115158081, 85.8129309117794, 78.22887986898422, 92.10228502750397, 22.696689404547215, 2.2401688434183598, 2.9465105663985014, 4.209973644465208, 5.438681412488222, 7.731265593320131, 5.065036062151194, 4.1129012033343315, 1.2803874886594713, 0.3092804556945339, 2.9565486777573824, 50.93956500291824, 72.6602254807949, 57.95692205429077, 62.17170529067516, 54.31501507759094, 69.76756229996681, 7.809340953826904, 0.3396970813628286, 0.21242443966912106, 0.1449877067352645, 0.20625253178877756, 0.12095305384718813, 0.25196869508363307, 0.14802822639467195, 0.15732729225419462, 0.2232666383497417, 0.2594523935113102, 0.2460980843170546, 0.14391150354640558], [0.1317421073326841, 0.08115870208712295, 0.04597306884534191, 0.08458737240289338, 0.03799222795350943, 0.03525758074829355, 0.08986681801616214, 0.052047473363927566, 0.011535616013134131, 0.008998351331683807, 0.053714106979896314, 0.04931892290187534, 0.27292457059957087, 46.00465200841427, 46.64410449564457, 26.3816062733531, 30.397730469703674, 49.035908952355385, 59.44056764245033, 2.6499250810593367, 0.059372021933086216, 0.1448812976013869, 2.4468174297362566, 0.5628012190572917, 0.3754220518749207, 1.6930718254297972, 0.12339138746028766, 1.5052821021527052, 70.53466513752937, 101.73296704888344, 92.67690539360046, 92.29768574237823, 89.01672899723053, 84.31984663009644, 82.84030482172966, 87.016881108284, 87.25683823227882, 86.84816256165504, 83.42633217573166, 77.97552466392517, 68.7473626434803, 65.78719988465309, 63.36282357573509, 65.81551596522331, 69.07671377062798, 75.92813372612, 78.46148058772087, 81.30036905407906, 85.44824928045273, 79.96780335903168, 76.20675757527351, 71.2984849512577, 63.70762847363949, 59.46345001459122, 59.88697528839111, 63.04619416594505, 66.6646260023117, 72.14070975780487, 75.1459912955761, 76.93504929542542, 76.59217089414597, 70.35089939832687, 66.47927194833755, 67.25942328572273, 67.48660549521446, 67.98479676246643, 61.7500951141119, 55.15357308089733, 54.11235295236111, 67.2219268977642, 71.25581324100494, 69.81266587972641, 71.95423096418381, 66.13871902227402, 71.70171931385994, 66.6423287987709, 64.05099704861641, 72.8727100789547, 61.86220429837704, 64.43297535181046, 68.72350752353668, 67.9590417444706, 62.21095338463783, 59.45292837917805, 57.08749070763588, 56.781189143657684, 60.2898258715868, 65.65638050436974, 59.27311822772026, 61.473203971982, 64.5023064315319, 67.7193658053875, 67.07797542214394, 68.19883927702904, 62.55360759794712, 56.639673337340355, 58.33184413611889, 66.55192404985428, 67.17948317527771, 61.65485702455044, 59.51641157269478, 62.93692342936993, 65.60179263353348, 64.0285250544548, 63.12508553266525, 64.5750193297863, 63.60085040330887, 62.61219285428524, 61.63290560245514, 60.89196816086769, 64.45290148258209, 62.60999657213688, 64.7907717525959, 61.44728936254978, 59.19542759656906, 58.153512105345726, 56.5267775952816, 54.87698972225189, 55.16705475747585, 57.33899541199207, 58.88407610356808, 57.19933770596981, 56.84985525906086, 55.01181408762932, 53.47689785063267, 54.231039583683014, 56.89840525388718, 61.09253279864788, 66.71853750944138, 67.7458655834198, 70.01667693257332, 68.59655633568764, 71.57551288604736, 68.8091017305851, 66.54687032103539, 64.34885546565056, 67.0799133181572, 63.79324167966843, 64.6622322499752, 63.595933467149734, 68.18532720208168, 63.615460619330406, 72.58208647370338, 73.04873943328857, 76.81046158075333, 71.9793476164341, 72.87104576826096, 2.6691209385171533, 0.7837986072991043, 2.248758519999683, 1.6069050366058946, 0.7303379103541374, 1.1165674729272723, 0.4605780652491376, 0.6208803306799382, 0.0823703917558305, 0.10024752700701356, 14.933579619973898, 53.5972335934639, 43.03301766514778, 37.61774584650993, 34.86774601042271, 49.64374713599682, 5.924731381237507, 0.19064160384004936, 0.14678267994895577, 0.049773232312873006, 0.1351257663918659, 0.05625912432151381, 0.0858385962783359, 0.048686293957871385, 0.05205576686421409, 0.0636778143234551, 0.04576425075356383, 0.050336930580670014, 0.08514680332154967, 0.06108135130489245, 0.06547623852384277, 0.020627794292522594, 0.07718556254985742, 0.055729524028720334, 0.08775874754064716, 0.054046960212872364, 0.03199426835635677, 0.03656120767118409, 0.04172703789663501, 0.09634646485210396, 0.041885534665198065, 0.49939146847464144, 59.64613281190395, 54.79559428989887, 41.48800536990166, 29.13373589515686, 55.95317177474499, 71.82881489396095, 2.8488990291953087, 0.07868244472774677, 1.2826674850657582, 1.6433455562219024, 1.5895720291882753, 3.1932261027395725, 0.7243101275525987, 0.30970389547292143, 2.2312378976494074, 77.95271068811417, 101.93212956190109, 97.43766233325005, 95.64306423068047, 94.05897483229637, 87.57187932729721, 88.98842051625252, 89.04404953122139, 90.13820081949234, 89.54300835728645, 86.17958083748817, 79.81182172894478, 73.62120151519775, 68.60830530524254, 69.42607462406158, 70.94378158450127, 72.23030135035515, 76.21441036462784, 81.00317180156708, 85.60125946998596, 87.20655173063278, 81.13933369517326, 80.02317398786545, 73.14542144536972, 65.60431569814682, 62.33679503202438, 61.07566550374031, 65.08726224303246, 67.81173124909401, 74.8689329624176, 78.54178547859192, 80.42378649115562, 78.10438334941864, 73.02860051393509, 69.88740786910057, 69.15543034672737, 69.63766247034073, 71.45582690834999, 67.53672480583191, 62.37366445362568, 62.01668880879879, 69.38591077923775, 73.98447722196579, 73.54117780923843, 73.35646972060204, 70.82103297114372, 73.44953432679176, 68.4864230453968, 69.27306443452835, 74.6548144519329, 63.87717917561531, 68.86729940772057, 73.03062960505486, 71.92192509770393, 62.60840445756912, 60.68557843565941, 59.185388535261154, 60.92258311808109, 62.93030418455601, 66.29599258303642, 63.05159367620945, 64.86926034092903, 68.07419076561928, 69.25091922283173, 69.00511801242828, 71.59024849534035, 63.40370178222656, 58.90451140701771, 59.73812207579613, 68.0940181016922, 70.55636957287788, 65.71763321757317, 61.96219973266125, 66.79404705762863, 68.50383371114731, 67.39364728331566, 64.36281591653824, 67.55131602287292, 65.66864624619484, 66.13453924655914, 63.94999086856842, 64.59274917840958, 67.36380368471146, 65.46873897314072, 65.85352912545204, 64.78664517402649, 62.856280356645584, 60.88711202144623, 61.04845516383648, 59.16195139288902, 58.86666543781757, 60.55645376443863, 62.238790690898895, 58.86158511042595, 58.07638004422188, 57.36536979675293, 56.05577766895294, 55.71235969662666, 59.03944976627827, 64.22590166330338, 69.51386511325836, 68.28624978661537, 72.98218220472336, 72.2780267894268, 73.25923293828964, 71.72375813126564, 69.73944380879402, 65.99980607628822, 68.75861003994942, 67.44802236557007, 68.14503416419029, 64.0675413608551, 71.91985800862312, 65.3496989607811, 76.16749808192253, 76.33692339062691, 81.37282356619835, 74.95020300149918, 81.74213334918022, 4.788716789335012, 0.7586440164595842, 1.1150368675589561, 2.5686723785474896, 3.613747637718916, 2.222215519286692, 1.618532412685454, 2.1095059672370553, 0.2672367211198434, 0.05295718314300757, 17.767869383096695, 61.02113462984562, 43.698103576898575, 34.31333675980568, 40.72384737432003, 56.9255243986845, 8.693445213139057, 0.34584939654450864, 0.11263794964179397, 0.08280137175461277, 0.10025416922871955, 0.04762193544593174, 0.07019917728030123, 0.04239830304868519, 0.02874548350519035, 0.01329200125837815, 0.012972146741958568, 0.023144504266383592, 0.0692903803428635, 0.272524879546836, 0.19549562071915716, 0.15183502837317064, 0.17278744548093528, 0.12884500029031187, 0.15923808503430337, 0.2015542471781373, 0.11527640337590128, 0.2077171008568257, 0.06574258048203774, 0.20665237127104774, 0.17595413024537265, 1.0135164088569582, 70.18797934055328, 66.56835436820984, 41.72383591532707, 47.18847468495369, 69.66056764125824, 86.45905584096909, 4.286165731027722, 0.14086102426517755, 1.2837029295042157, 8.325001783668995, 2.8168332623317838, 4.341314546763897, 4.495879802852869, 0.6233114283531904, 3.0835238518193364, 78.48838314414024, 105.36219790577888, 101.13493233919144, 100.09079396724701, 96.44733667373657, 91.11331209540367, 91.72696396708488, 96.04531824588776, 94.12044793367386, 94.63642224669456, 88.04568350315094, 84.79540631175041, 76.79452523589134, 72.77253985404968, 71.11627712845802, 74.28453952074051, 75.72864443063736, 80.97121551632881, 85.15776246786118, 88.51666823029518, 91.20094299316406, 85.99651426076889, 83.7732307612896, 80.37890329957008, 68.42183411121368, 64.11503121256828, 64.3917627632618, 68.60751494765282, 70.29219254851341, 79.21161353588104, 83.33802491426468, 82.2432504594326, 81.83398202061653, 74.47101831436157, 73.49541306495667, 73.50086197257042, 72.64765575528145, 74.08346951007843, 70.4521943628788, 66.96995481848717, 69.89636018872261, 77.16808319091797, 77.27407470345497, 75.99675804376602, 77.7363882958889, 74.35066357254982, 77.7458193898201, 73.6143770813942, 68.81971836090088, 77.82515913248062, 66.70425027608871, 72.06849843263626, 76.14771634340286, 76.13450825214386, 66.20212242007256, 60.94508931040764, 59.252755120396614, 61.63486249744892, 62.60899342596531, 70.34712240099907, 64.35354441404343, 66.84219807386398, 71.3549879193306, 73.57729107141495, 73.26275154948235, 75.28176560997963, 65.02344846725464, 60.1135191321373, 61.031926050782204, 71.66784033179283, 72.16481566429138, 65.81062942743301, 62.731194868683815, 70.63256308436394, 71.05192378163338, 66.89697593450546, 66.26752451062202, 69.54434707760811, 68.88723313808441, 70.50834774971008, 67.91579246520996, 67.94927626848221, 72.88719490170479, 70.18681660294533, 69.38168540596962, 69.0089026093483, 65.33207550644875, 65.52009701728821, 64.83632370829582, 62.20538668334484, 63.017691895365715, 64.50765654444695, 65.20930409431458, 63.29855762422085, 61.99689567089081, 60.287728384137154, 57.642412930727005, 58.863990381360054, 62.43494376540184, 67.00678244233131, 73.53146553039551, 72.31825903058052, 75.1102352142334, 74.83738705515862, 76.21844574809074, 74.40237879753113, 71.24250635504723, 71.32490873336792, 73.49159806966782, 71.06579303741455, 69.89312276244164, 66.7744705080986, 74.71118062734604, 69.79990616440773, 80.58902442455292, 79.84243288636208, 84.6188297867775, 80.4583190381527, 86.53962671756744, 4.2790900357067585, 2.1331751346588135, 9.971335642039776, 4.039891920983791, 4.9718360882252455, 2.6668531727045774, 1.5210766671225429, 2.6464542048051953, 0.2960433316184208, 0.2879174379631877, 26.541476994752884, 72.2951790690422, 59.940229430794716, 51.20031461119652, 45.791863426566124, 70.35089179873466, 10.04467360675335, 0.45679278555326164, 0.196334054635372, 0.13085586426313967, 0.3411860077176243, 0.22127643576823175, 0.17686781793599948, 0.11607196342083625, 0.14311696024378762, 0.12685441179201007, 0.1638377085328102, 0.15733757842099294, 0.16236176976235583], [0.0864048401126638, 0.04720097815152258, 0.08067027985816821, 0.04275255610991735, 0.017877747523016296, 0.05087644967716187, 0.032686250560800545, 0.05977684493700508, 0.0280695854962687, 0.029623486880154815, 0.18763970554573461, 0.20406101422850043, 3.076694430783391, 57.47872531414032, 40.65472908318043, 29.47298739105463, 27.649235352873802, 63.871274292469025, 33.76509077847004, 0.9523089369758964, 0.09310319044743665, 1.9446178525686264, 2.202205080538988, 0.5306854017544538, 2.079341998323798, 0.22457853279775009, 0.5452410550788045, 12.767958026379347, 92.45601564645767, 91.79007098078728, 97.72710800170898, 86.21680364012718, 88.73273223638535, 79.73777130246162, 74.33799505233765, 73.89317572116852, 81.25806212425232, 79.71114993095398, 81.14840000867844, 71.37783229351044, 70.56156009435654, 66.49776935577393, 65.84841459989548, 70.99606677889824, 73.19018304347992, 75.0722448527813, 80.9197586774826, 83.70605796575546, 82.01482951641083, 80.61477184295654, 74.35179591178894, 65.83584487438202, 62.243540436029434, 60.57296767830849, 58.65880899131298, 58.4242969751358, 61.462933123111725, 71.48809477686882, 72.8619110584259, 78.57788354158401, 75.18118500709534, 73.6389085650444, 71.58037662506104, 65.68237870931625, 66.60468801856041, 69.38357010483742, 63.46632242202759, 62.91406765580177, 63.63248750567436, 62.82577559351921, 72.3689179122448, 69.91066262125969, 67.8024673461914, 71.94517225027084, 67.22932890057564, 69.8990124464035, 70.75769037008286, 62.42634482681751, 67.01303690671921, 68.49665969610214, 69.13233518600464, 61.33947774767876, 60.045685172080994, 65.62286630272865, 65.17874613404274, 61.492518335580826, 66.33481130003929, 65.93894854187965, 65.30872955918312, 63.05911347270012, 68.04338961839676, 66.16051465272903, 63.32560837268829, 64.65634256601334, 66.75849616527557, 67.41269946098328, 64.77779164910316, 61.25955283641815, 60.926470309495926, 68.96009802818298, 67.61164918541908, 61.183442920446396, 59.58127409219742, 64.56141605973244, 65.10389015078545, 58.86921890079975, 62.33570449054241, 62.390098571777344, 60.35864017903805, 59.81838136911392, 60.03004141151905, 65.111223757267, 61.006999388337135, 61.493985056877136, 59.95692953467369, 59.85097222030163, 57.102287113666534, 56.102488562464714, 54.9265580624342, 57.7353635430336, 58.59138920903206, 58.023931458592415, 54.304968416690826, 53.9569640904665, 53.56603726744652, 52.02630288898945, 57.29070000350475, 61.430862843990326, 64.03088852763176, 68.27098220586777, 69.78843837976456, 71.12905964255333, 70.47064617276192, 67.56205424666405, 67.7647353708744, 64.12903726100922, 64.41868051886559, 59.14928287267685, 65.6975930929184, 62.66594476997852, 63.01027089357376, 64.69313219189644, 66.66505917906761, 67.11634576320648, 75.21020784974098, 72.00741291046143, 79.77849751710892, 36.34199470281601, 0.3427576686954126, 1.765661349054426, 2.771848663687706, 0.8462344226427376, 3.198931021615863, 2.184724356047809, 3.333417442627251, 0.17335965618258342, 0.20046760939294472, 6.427420182153583, 45.61765797436237, 46.4889170229435, 41.96160435676575, 37.45739445090294, 55.97937136888504, 9.583626296371222, 0.24710387253435329, 0.19313719414640218, 0.011025669646187453, 0.08720697558601387, 0.057052643460338004, 0.028577223783941008, 0.1241635401675012, 0.0687673814536538, 0.03040528936253395, 0.07326389095396735, 0.02405727169389138, 0.011749622644856572, 0.04529770703811664, 0.05589839973254129, 0.06375607379595749, 0.09742748457938433, 0.033230326444027014, 0.01661143578530755, 0.0631383249128703, 0.031245860664057545, 0.06800555202062242, 0.007609901103933225, 0.022755602185497992, 0.25690296781249344, 4.474833207204938, 71.64353683590889, 50.84601782262325, 43.86367589235306, 24.53975770622492, 74.82525050640106, 40.4094522446394, 0.38086864398792386, 0.05296262308547739, 3.3179468102753162, 1.481385303195566, 1.6793513554148376, 5.364356450736523, 0.3582967270631343, 0.3633566899225116, 15.033382214605808, 95.90290948748589, 94.11372229456902, 101.53092429041862, 90.9071883559227, 92.38584861159325, 82.72995874285698, 77.88554549217224, 75.62630072236061, 83.48604217171669, 81.99667409062386, 82.77550309896469, 76.31756722927094, 73.12517613172531, 70.6241275370121, 73.07703271508217, 72.47588217258453, 77.76668027043343, 77.66001239418983, 83.44032302498817, 89.31761965155602, 85.66392570734024, 83.80802929401398, 77.26581394672394, 68.7086883187294, 64.82760697603226, 61.56280316412449, 61.04062758386135, 61.88243821263313, 63.21028456091881, 74.51144054532051, 77.37053632736206, 77.67812222242355, 77.05693155527115, 75.76361775398254, 74.24698233604431, 69.50897857546806, 70.56469112634659, 73.53153392672539, 69.20278340578079, 69.76753950119019, 68.77487316727638, 68.7799420952797, 75.22919163107872, 73.01726952195168, 71.83677926659584, 76.97985649108887, 69.25297111272812, 73.40752378106117, 73.7055341899395, 65.82664176821709, 70.3992860019207, 72.7035203576088, 69.60606336593628, 63.268182054162025, 63.21830973029137, 68.55097398161888, 68.56369569897652, 65.9436146914959, 69.27257046103477, 69.13183361291885, 69.10170882940292, 66.9195619225502, 68.79607602953911, 68.54153528809547, 64.32322964072227, 67.39275813102722, 69.01264160871506, 68.37742209434509, 65.17704382538795, 62.0931863039732, 63.499950617551804, 69.92064088582993, 70.61138302087784, 63.66157494485378, 63.902599811553955, 66.89522802829742, 70.18092691898346, 63.47451098263264, 63.521123081445694, 63.89154240489006, 62.5714248418808, 59.57454465329647, 59.66137379407883, 68.38112309575081, 64.81714993715286, 63.052798211574554, 66.15066558122635, 63.88846457004547, 61.5639279037714, 58.45298923552036, 58.80135454237461, 58.884630873799324, 62.0624915510416, 60.189431458711624, 57.73346744477749, 55.264682918787, 56.40357680618763, 54.846302568912506, 61.7876560986042, 64.4482809305191, 65.51207944750786, 69.56112697720528, 71.26453757286072, 73.74281778931618, 73.04752349853516, 70.32280370593071, 69.72960233688354, 65.95496088266373, 67.67128318548203, 62.7629079669714, 67.89756864309311, 63.45727890729904, 66.02606266736984, 66.16366848349571, 69.87825036048889, 71.20697066187859, 78.97707492113113, 76.26789629459381, 84.87449526786804, 42.82475084066391, 0.10016124491812661, 0.8683370053768158, 1.0964207164943218, 1.798321190290153, 2.967739077284932, 1.1115383240394294, 1.584221322555095, 0.20411795179825276, 0.28638030169531703, 7.408734625205398, 54.69595603644848, 48.45124952495098, 34.49375107884407, 44.882336631417274, 63.72509993612766, 11.47039320319891, 0.38791308004874736, 0.21394271054305136, 0.08544596305000596, 0.10702067840611562, 0.12213903552037664, 0.10421617655083537, 0.042038814135594293, 0.02188346548791742, 0.0834736239630729, 0.05234262549492996, 0.08723429404199123, 0.04250920217600651, 0.1748337989556603, 0.16239423130173236, 0.12011167360469699, 0.15331144211813807, 0.1300294976681471, 0.13047702756011859, 0.14799436961766332, 0.14298666879767552, 0.1257212710333988, 0.06882294605020434, 0.366326438379474, 0.4727510386146605, 6.227027485147119, 88.39648067951202, 57.00576089322567, 40.427691265940666, 44.02877323329449, 89.12197574973106, 53.26427266001701, 1.237853046040982, 0.09592793066985905, 7.938624741509557, 5.510521782562137, 2.975095007568598, 7.54521475173533, 0.9867284400388598, 2.1080810436978936, 17.644702792167664, 98.29815655946732, 100.45850783586502, 107.02457070350647, 94.42465960979462, 96.44731387495995, 86.8443475663662, 82.20300301909447, 80.79106718301773, 89.48444589972496, 85.30996710062027, 87.57220610976219, 79.36682000756264, 76.65226086974144, 74.55997914075851, 75.20763918757439, 75.52597090601921, 79.33141350746155, 81.17961153388023, 85.46404123306274, 90.78899189829826, 90.82307606935501, 86.02934449911118, 81.45213291049004, 71.04056239128113, 70.66207990050316, 66.0296268761158, 64.81217980384827, 64.5303413271904, 65.84281370043755, 79.38074246048927, 79.07726794481277, 83.24660181999207, 81.62764549255371, 79.25926297903061, 77.72634163498878, 73.71827110648155, 73.11177045106888, 77.26087421178818, 71.4606374502182, 73.40349599719048, 71.33016765117645, 70.83846643567085, 80.31900331377983, 76.48133084177971, 74.61459740996361, 79.41217437386513, 74.0869577229023, 74.74274933338165, 77.46585801243782, 68.25875446200371, 74.28380236029625, 77.16793119907379, 74.30358409881592, 65.52415519952774, 65.24265870451927, 71.81002110242844, 69.90931749343872, 67.17371508479118, 73.573909252882, 72.68455937504768, 72.49418199062347, 70.07201716303825, 73.25509876012802, 70.5873455107212, 68.71115058660507, 68.29628124833107, 72.96806216239929, 70.55662795901299, 67.40041851997375, 63.81564527750015, 66.43011778593063, 73.84833812713623, 75.2185370028019, 66.82658851146698, 66.53070598840714, 69.45048451423645, 73.48547279834747, 62.86580644547939, 68.58133435249329, 67.1357399225235, 64.57104474306107, 64.3010464310646, 65.86726158857346, 71.73591747879982, 68.47059309482574, 66.6232918202877, 68.8079085946083, 65.51343977451324, 66.52337998151779, 63.99754151701927, 62.43316166102886, 62.26077251136303, 67.308699041605, 63.51686730980873, 60.91029457747936, 59.088687524199486, 58.57262581586838, 56.480287089943886, 65.37015706300735, 67.23451942205429, 69.63438704609871, 72.08306685090065, 74.97481048107147, 77.24538624286652, 76.33500829339027, 73.03004443645477, 73.1276535987854, 69.83298718929291, 70.40316179394722, 64.74675491452217, 70.76580673456192, 66.80239140987396, 69.01245921850204, 71.19345098733902, 71.81066706776619, 75.37661612033844, 83.30999001860619, 81.26892194151878, 89.76263657212257, 43.90609681606293, 0.8782655757386237, 5.309612788259983, 7.731293141841888, 4.239627728238702, 9.12652412429452, 4.326775576919317, 6.159028233960271, 0.6822046462912112, 0.4185431177029386, 11.963836625218391, 66.7200194299221, 58.97591717541218, 57.654674872756004, 47.37943723797798, 74.82366219162941, 13.078066986054182, 0.5489047116134316, 0.38762233627494425, 0.25869002973195165, 0.16743406711611897, 0.206677723035682, 0.19162333162967116, 0.25226095283869654, 0.2370534563669935, 0.1476037030806765, 0.16607903904514387, 0.15708671766333282, 0.12468362983781844], [0.07724245559074916, 0.02499264679499902, 0.04703744220023509, 0.033625701908022165, 0.03747543341887649, 0.04477955437323544, 0.06310230848612264, 0.030035503150429577, 0.10149532216018997, 0.05010122447856702, 0.06210858016856946, 0.2282845659647137, 7.057173689827323, 59.97671127319336, 36.287254840135574, 31.43417615443468, 37.669909447431564, 63.99503365159035, 15.076856631785631, 0.129477814771235, 0.10645400412613526, 1.2476296839304268, 0.4655708489008248, 0.9225152106955647, 2.8013417311012745, 0.5481110292021185, 0.1952991000143811, 37.4041935056448, 98.29972207546234, 91.08251094818115, 95.41136786341667, 86.85809522867203, 86.14293560385704, 74.65929061174393, 71.910320520401, 65.90266808867455, 69.62799578905106, 70.60445979237556, 73.022520840168, 69.14539128541946, 67.92901575565338, 67.17413306236267, 70.8341346681118, 72.7431370317936, 78.60972583293915, 77.88735419511795, 82.52926111221313, 85.50471425056458, 81.32006719708443, 79.2611400783062, 76.14445611834526, 66.3716921210289, 59.58954244852066, 57.77886360883713, 56.99325196444988, 57.6159131526947, 58.02030265331268, 67.2527888417244, 73.41914355754852, 74.80318889021873, 74.99869599938393, 72.51365214586258, 73.17411750555038, 66.60189896821976, 67.02558383345604, 68.46665650606155, 66.64981439709663, 64.2670838534832, 65.87557554244995, 69.2415489256382, 64.11066144704819, 75.64517050981522, 72.25888341665268, 64.1375184059143, 67.9880341887474, 72.30120554566383, 61.03777773678303, 63.63892816007137, 68.19883927702904, 65.72341650724411, 63.32592375576496, 64.78908464312553, 67.31561467051506, 70.04245474934578, 65.55932611227036, 65.19418090581894, 62.82822646200657, 66.94498255848885, 66.02523431181908, 65.35974562168121, 64.79859173297882, 64.87898781895638, 63.15060876309872, 63.62554527819157, 67.00185030698776, 67.50623524188995, 65.30148714780807, 65.97075283527374, 64.61166456341743, 61.82067632675171, 66.28517836332321, 68.44890385866165, 62.65547253191471, 61.941342651844025, 63.39086227118969, 66.97013720870018, 58.58024060726166, 59.024938344955444, 62.366646230220795, 57.84746892750263, 53.79719026386738, 58.647664189338684, 66.8876588344574, 62.29475408792496, 60.75795315206051, 59.03439983725548, 57.752637416124344, 56.66821740567684, 54.365354776382446, 55.82628518342972, 56.140486523509026, 55.03316894173622, 52.90376700460911, 52.287405878305435, 53.56857173144817, 53.169517144560814, 56.98950156569481, 61.391766741871834, 63.35169397294521, 66.03638291358948, 69.67572882771492, 68.21275413036346, 68.5396733880043, 67.29195713996887, 64.18284237384796, 61.87579996883869, 62.74017758667469, 58.707640171051025, 63.04610677063465, 61.967215463519096, 63.28109376132488, 64.60550129413605, 62.16572821140289, 62.84577012062073, 71.0811898112297, 76.67809948325157, 73.1296294927597, 70.28511732816696, 3.5849679820239544, 1.2431865348480642, 2.691214852966368, 3.6875845631584525, 3.322721254080534, 2.387185567058623, 1.9290724117308855, 0.6634267664048821, 0.1213399280095473, 1.868641166947782, 30.56903477758169, 50.18551826477051, 51.79594784975052, 27.699778340756893, 59.66336868703365, 10.119511540979147, 0.23849445482483134, 0.1673599859350361, 0.02958799737825757, 0.09589693858288229, 0.024631215310364496, 0.036461336858337745, 0.07948155223857611, 0.12298298359382898, 0.004108065231775981, 0.06446287297876552, 0.10366896138293669, 0.053335593111114576, 0.02113885017024586, 0.011957757033087546, 0.03229062647733372, 0.04194766726868693, 0.09270133232348599, 0.026730608224170282, 0.04826136617339216, 0.021333509939722717, 0.033843203127617016, 0.0567111701820977, 0.04584257701935712, 0.22606248676311225, 11.485274154692888, 70.56313320994377, 48.56202878057957, 35.51454730331898, 31.186186261475086, 77.91990324854851, 18.630784079432487, 0.12238598515978083, 0.38248943514190614, 1.1541036400012672, 1.322614741511643, 3.8094190880656242, 5.365198580548167, 0.4406901402398944, 0.18051642371574417, 42.07812510430813, 100.83800867199898, 95.48781216144562, 99.56836000084877, 93.78137692809105, 89.99931067228317, 80.2939322590828, 76.99855908751488, 70.11018231511116, 71.2761041522026, 72.54962861537933, 74.74977895617485, 72.93765619397163, 69.07430469989777, 72.23798453807831, 73.53985548019409, 76.77671179175377, 79.88366827368736, 82.45875969529152, 83.81849393248558, 86.92748710513115, 85.23643344640732, 81.04113936424255, 79.02191251516342, 70.16375944018364, 62.63307273387909, 60.99635995924473, 59.778825491666794, 60.458453223109245, 61.5837362408638, 69.64001834392548, 74.82038676738739, 76.48959919810295, 77.79637187719345, 75.7751539349556, 74.18230220675468, 69.95448186993599, 70.93345373868942, 71.80766522884369, 70.86274713277817, 66.33676439523697, 68.88086467981339, 70.33262237906456, 67.0968148112297, 76.1639566719532, 74.19889211654663, 65.63258618116379, 71.48924991488457, 71.79857611656189, 64.428301602602, 68.10908049345016, 70.3510893881321, 67.46309235692024, 61.98609285056591, 70.07674410939217, 70.06841495633125, 74.56610441207886, 69.29667636752129, 67.67335787415504, 67.162756472826, 67.74942219257355, 67.132738083601, 64.59211841225624, 66.31965011358261, 65.44189721345901, 66.79291471838951, 66.02539390325546, 70.0535349547863, 68.65548357367516, 68.09798508882523, 68.45556870102882, 66.25949174165726, 65.88536381721497, 67.22150892019272, 68.95825892686844, 66.44190475344658, 64.37550723552704, 66.44825041294098, 70.15685141086578, 62.0763798058033, 60.68386472761631, 63.395832404494286, 59.335119500756264, 60.26717908680439, 60.673852264881134, 69.46278065443039, 66.5046925842762, 63.66916313767433, 64.16764318943024, 61.54435895383358, 59.1876570135355, 57.60124213993549, 57.94302240014076, 58.679248094558716, 57.49107085168362, 56.30937606096268, 55.247473642230034, 55.14825716614723, 55.66323593258858, 59.96145889163017, 64.02436807751656, 66.6398437321186, 68.88163983821869, 72.36622765660286, 70.07164478302002, 69.83156606554985, 68.24861660599709, 66.41770005226135, 64.46995496749878, 64.4672267138958, 63.528791069984436, 64.07843917608261, 65.09736210107803, 67.37502828240395, 69.45220202207565, 65.49495756626129, 66.469536870718, 75.06637796759605, 81.0665675997734, 76.73345491290092, 78.55547994375229, 4.773828713223338, 0.9026430489029735, 0.8453464577905834, 3.3745727967470884, 2.3673470690846443, 1.8991484236903489, 1.4221565751358867, 0.6460630043875426, 0.07267586508532986, 1.3073367113247514, 38.89345519244671, 55.705725252628326, 42.506088539958, 29.466784223914146, 70.0298622250557, 13.178772032260895, 0.2186909268493764, 0.25650514697190374, 0.04610344192769844, 0.0788769542123191, 0.10892187521676533, 0.02476659788953839, 0.03638895519543439, 0.04314472549594939, 0.03408825657970738, 0.010741127443907317, 0.09330754823167808, 0.014253781973820878, 0.07435990948579274, 0.11161797898239456, 0.19321997329825535, 0.11175379200722091, 0.16959153494099155, 0.16855058376677334, 0.0931819471588824, 0.17067051376216114, 0.18507911794586107, 0.10336790917790495, 0.30333383416291326, 0.43460776505526155, 15.876983497291803, 88.48930209875107, 51.26080736517906, 42.49064616858959, 51.28404691815376, 91.71091362833977, 25.482751205563545, 0.24805641907732934, 0.6508035468868911, 4.788534399122, 3.5361018916592, 5.17679993994534, 7.383095026016235, 1.6491035535000265, 0.2889718220103532, 46.51011988520622, 103.67815107107162, 101.25154808163643, 103.90432253479958, 96.2982326745987, 94.83284130692482, 85.32566025853157, 78.37256535887718, 72.41260036826134, 75.57945683598518, 76.10024929046631, 78.83210510015488, 78.24700489640236, 73.3843906223774, 75.91535121202469, 76.94128856062889, 80.07153019309044, 84.12959083914757, 83.23198780417442, 88.69997799396515, 88.57478231191635, 86.40722662210464, 84.96898859739304, 81.90932437777519, 72.67344117164612, 65.12130081653595, 63.06768961250782, 63.661688938736916, 61.7517252266407, 65.64370438456535, 73.05817052721977, 79.8335337638855, 80.22223010659218, 81.56166583299637, 77.52685993909836, 78.6784565448761, 73.94798398017883, 75.03636717796326, 76.83687776327133, 75.22951081395149, 72.17415556311607, 74.02406349778175, 74.02391150593758, 71.32521271705627, 80.82973390817642, 78.0718494951725, 69.07343074679375, 74.87325713038445, 76.33683979511261, 68.16712617874146, 69.53255251049995, 74.52762007713318, 71.64012461900711, 65.21857559680939, 73.24657201766968, 74.1428755223751, 79.18257549405098, 71.55006945133209, 69.10407230257988, 71.18210479617119, 72.75890618562698, 71.49147659540176, 67.4719762802124, 68.99402260780334, 69.02284026145935, 67.45781064033508, 70.41628628969193, 73.04832145571709, 71.21563419699669, 71.66011154651642, 71.29945009946823, 69.71226006746292, 65.75853422284126, 70.98912075161934, 73.19532796740532, 67.70901516079903, 68.44184383749962, 70.53116172552109, 72.76190802454948, 66.05105772614479, 65.74463456869125, 68.54535028338432, 62.35894404351711, 61.985804066061974, 65.33674165606499, 73.08969363570213, 68.39025780558586, 66.91015362739563, 67.9170235991478, 65.22683635354042, 64.14061143994331, 59.83836069703102, 62.25844323635101, 63.10635633766651, 59.694215431809425, 59.47907477617264, 57.87195481359959, 58.69734272360802, 60.275595635175705, 62.940746024250984, 68.12890782952309, 69.51435148715973, 72.09132760763168, 74.29815039038658, 72.27272987365723, 73.13203856348991, 72.47124642133713, 69.66182917356491, 66.86452567577362, 69.19821605086327, 65.22270977497101, 67.93293714523315, 68.19307878613472, 69.67256739735603, 72.53480941057205, 69.98394548892975, 69.77039694786072, 80.4122807085514, 86.46795496344566, 82.027498036623, 81.61661088466644, 4.845212632790208, 3.078768406994641, 7.005080860108137, 9.05929148197174, 10.09988559409976, 7.954030064865947, 5.485430303961039, 1.8338479776866734, 0.3643531567649916, 3.0537467496469617, 50.72003938257694, 66.63283690810204, 67.21099868416786, 35.64763516187668, 82.49572411179543, 15.546684321016073, 0.3912547038635239, 0.2534277574159205, 0.14502992009511217, 0.21733249974204227, 0.2136925028753467, 0.08975586693850346, 0.15428248298121616, 0.23812486528186128, 0.16046678472775966, 0.2602523396490142, 0.21324445348000154, 0.1840605796314776], [0.027231656240473967, 0.06507301484816708, 0.049264968765783124, 0.03053905034903437, 0.07268629226018675, 0.04412139183841646, 0.04168688399659004, 0.024707391203264706, 0.02751064625044819, 0.02633227159094531, 0.06770582083845511, 0.25828855752479285, 18.17902822047472, 62.69049905240536, 36.7506817728281, 55.07083632051945, 37.27540321648121, 59.106067791581154, 4.929747171700001, 0.015175542375800433, 0.4146857012528926, 1.4688985794782639, 0.7604303956031799, 1.3076220522634685, 3.697229395620525, 0.5250916269142181, 1.4616330130957067, 49.180521592497826, 98.40898901224136, 87.50668242573738, 95.52317306399345, 88.32505971193314, 87.37071812152863, 73.00513297319412, 70.58726191520691, 72.74787917733192, 69.1700367629528, 66.06477499008179, 63.741944432258606, 63.698391169309616, 62.8684701025486, 64.4734051823616, 70.45436024665833, 74.57555070519447, 76.56103536486626, 79.69918817281723, 80.4067026078701, 80.91903671622276, 82.34542697668076, 78.93238171935081, 75.58282345533371, 72.74797037243843, 60.49376852810383, 59.160131290555, 56.79353088140488, 56.678750440478325, 57.920884788036346, 62.80919708311558, 71.49439483880997, 73.94270986318588, 74.73117515444756, 73.4409011900425, 70.76015263795853, 67.65090867877007, 66.64111286401749, 67.65978500247002, 68.95913287997246, 67.72647902369499, 69.2184841632843, 68.43804404139519, 63.37134271860123, 68.11379224061966, 67.84738853573799, 66.40044897794724, 71.13621845841408, 62.16053009033203, 68.30811381340027, 68.76469731330872, 62.6017814129591, 64.33682531118393, 67.17157199978828, 68.21804344654083, 61.245501190423965, 62.06477902829647, 62.57440768182278, 65.08064299821854, 63.8730525970459, 58.75886142253876, 58.67392458021641, 59.62406359612942, 60.67760646343231, 62.603544518351555, 62.198170870542526, 62.571987211704254, 56.342696473002434, 61.143670454621315, 63.62404815852642, 64.61341246962547, 65.269356071949, 67.22327962517738, 66.8719656765461, 60.463803336024284, 65.3380335867405, 64.15365234017372, 60.92535316944122, 61.936129331588745, 66.8481257557869, 59.04258079826832, 57.948478907346725, 59.427158161997795, 61.2291506677866, 59.71213147044182, 57.30149522423744, 63.85782301425934, 62.084017395973206, 61.37279815971851, 62.22097724676132, 56.25573053956032, 57.3078902810812, 56.58244080841541, 54.89291846752167, 55.03162242472172, 53.11695456504822, 50.31669482588768, 50.58483883738518, 51.248659417033195, 55.86609564721584, 60.079043582081795, 66.14957883954048, 68.31052288413048, 68.94632756710052, 67.54335924983025, 68.99039000272751, 64.78329375386238, 65.14440357685089, 61.568939834833145, 60.28238207101822, 58.42337362468243, 58.84338028728962, 63.918292969465256, 63.9799028635025, 66.47986471652985, 62.54066929221153, 61.40119403600693, 67.12245583534241, 76.58341616392136, 69.86774772405624, 76.71438753604889, 23.226584270596504, 0.5685860523954034, 0.6233529292512685, 1.7560799256898463, 1.2842523562721908, 0.9869544685352594, 0.7188913808204234, 0.4019610449904576, 0.04923346088617109, 0.2557732112472877, 22.712165974080563, 41.275528371334076, 56.85211233794689, 32.49744459986687, 53.69478575885296, 13.163083624094725, 0.26596138486638665, 0.10649061427102424, 0.04271851008525118, 0.03798915917286649, 0.10303296308848076, 0.044613654681597836, 0.05300855089444667, 0.022918789327377453, 0.05958422421826981, 0.030341349629452452, 0.06251323618926108, 0.029374438818194903, 0.016905574884731323, 0.017220601730514318, 0.04006255650892854, 0.050586206853040494, 0.032656401381245814, 0.02247497202915838, 0.07020608667517081, 0.029862035407859366, 0.029397423131740652, 0.034896618672064506, 0.03562062825949397, 0.2536699647316709, 26.085286773741245, 74.73026320338249, 44.35573808848858, 43.046955317258835, 38.813195899128914, 71.63469851016998, 6.245507318526506, 0.07745493247057311, 1.3178822142072022, 2.086765612475574, 1.407950681168586, 2.2136809397488832, 4.851788654923439, 0.3142897743964568, 1.475268581416458, 56.91960051655769, 99.8767438530922, 93.26017409563065, 98.43956977128983, 93.79245713353157, 89.98961359262466, 76.98898360133171, 72.83389136195183, 75.30312046408653, 72.7656926214695, 69.49167430400848, 67.50388696789742, 65.86554408073425, 66.71686559915543, 68.27300369739532, 73.0357213318348, 79.19748589396477, 80.70019125938416, 83.48424106836319, 81.66388794779778, 82.60945200920105, 83.13757047057152, 84.31590244174004, 81.28907606005669, 75.13327717781067, 63.66573952138424, 61.485545709729195, 60.04223495721817, 60.37874490022659, 59.58679519593716, 65.00004172325134, 73.13114941120148, 75.02351626753807, 77.52512723207474, 73.80223140120506, 73.78621906042099, 70.8460584282875, 70.77563300728798, 70.88530272245407, 70.17395809292793, 74.04626190662384, 70.86330950260162, 69.70775350928307, 67.59172305464745, 69.7887271642685, 70.32032623887062, 68.73388096690178, 73.32759127020836, 64.11920338869095, 72.8222867846489, 68.71710106730461, 64.07068759202957, 68.77053380012512, 69.73592519760132, 71.00784614682198, 61.5774741768837, 61.881264075636864, 64.8052641749382, 67.20269992947578, 66.15511134266853, 63.361204862594604, 58.14091198146343, 62.038465440273285, 60.364127084612846, 65.6535230576992, 64.9809667468071, 65.90367123484612, 58.13700199127197, 60.57777062058449, 64.57801356911659, 68.24616953730583, 67.30592519044876, 69.07189562916756, 68.5505636036396, 62.69874840974808, 66.1660623550415, 67.56539806723595, 64.4080638885498, 63.64557020366192, 70.70646151900291, 64.02247577905655, 62.25514121353626, 65.59463381767273, 63.577831238508224, 65.8590616285801, 58.43455642461777, 64.42507177591324, 65.24502977728844, 64.53729495406151, 65.00716254115105, 59.28157277405262, 60.75221925973892, 59.565527737140656, 56.88574053347111, 58.5616672039032, 57.10172854363918, 53.08807231485844, 54.02723751962185, 53.8020996004343, 59.20025713741779, 65.2056410908699, 67.235818952322, 71.73929929733276, 73.07479083538055, 70.38433760404587, 71.50747373700142, 67.82084316015244, 67.54086658358574, 65.48072353005409, 63.2649864256382, 61.93393684923649, 60.455443784594536, 65.58359920978546, 68.41355815529823, 67.99613535404205, 65.47693133354187, 65.26687100529671, 71.4355055987835, 79.00437265634537, 75.75716570019722, 82.73488327860832, 29.65570628643036, 0.2825866802595556, 0.41809776972513646, 2.753481399267912, 1.7669932963326573, 2.6063713431358337, 1.7826948850415647, 0.609486938919872, 0.05395816595409997, 0.2506326511502266, 24.044505581259727, 49.933044612407684, 52.10213162004948, 35.83684600889683, 64.02290135622025, 16.7065217345953, 0.22800246078986675, 0.10824494005646557, 0.06524913391331211, 0.08746811508899555, 0.12243269593454897, 0.0835257004655432, 0.031148542839218862, 0.09919469404849224, 0.07777459031785838, 0.09716635249787942, 0.08787409955402836, 0.03693736893183086, 0.10683481494197622, 0.10112297924933955, 0.12176692267530598, 0.10030410092440434, 0.18483345222193748, 0.19228857796406373, 0.1417737768497318, 0.1526660259696655, 0.1529782178113237, 0.1256894032121636, 0.2719011786393821, 0.28875835065264255, 31.186982318758965, 90.16472339630127, 47.137542217969894, 70.09456515312195, 54.874858036637306, 87.38746002316475, 10.471061076968908, 0.13908654917031527, 2.358379550278187, 6.1165460385382175, 3.344195089302957, 7.452024752274156, 11.251329258084297, 2.088482170365751, 1.7253965721465647, 61.298512145876884, 105.30957832932472, 99.25362288951874, 103.70619356632233, 98.27937796711922, 96.40914872288704, 79.81384322047234, 77.16915473341942, 78.65494340658188, 76.2427644431591, 73.17766651511192, 71.8421521782875, 69.79024708271027, 69.2849349975586, 72.3000656068325, 76.92839965224266, 82.13782131671906, 82.94002667069435, 87.52898722887039, 84.4917494058609, 86.98894500732422, 87.77652114629745, 86.78311765193939, 83.94265606999397, 77.15111330151558, 65.51813632249832, 63.555674627423286, 62.75213934481144, 64.50353756546974, 62.67825610935688, 68.10821413993835, 80.02282440662384, 80.05576103925705, 82.12623953819275, 78.03213402628899, 76.07856765389442, 74.50830191373825, 75.40801003575325, 74.90148201584816, 74.27203819155693, 76.24985486268997, 75.712730884552, 73.81013497710228, 72.85464584827423, 77.22318783402443, 71.41610383987427, 71.37594759464264, 77.39126041531563, 68.28997358679771, 72.50916078686714, 74.99288991093636, 66.16525679826736, 70.9953448176384, 73.38346347212791, 75.1610004901886, 67.4940986931324, 67.39288732409477, 67.34970644116402, 70.91542750597, 68.1109955906868, 65.19067749381065, 60.162240117788315, 64.60138991475105, 64.7202779352665, 68.03196743130684, 68.7216380238533, 68.65773305296898, 62.38821767270565, 67.82812356948853, 68.50996658205986, 69.4622790813446, 70.8590917289257, 72.72314250469208, 70.92104360461235, 65.60971140861511, 72.73539304733276, 68.8314901292324, 67.06834673881531, 67.65366733074188, 74.54645186662674, 67.77608156204224, 63.05081091821194, 64.52148780226707, 67.69571587443352, 69.57654654979706, 65.78629553318024, 68.50049749016762, 67.39029586315155, 68.03839668631554, 69.99758675694466, 62.08576150238514, 63.902736604213715, 61.73281364142895, 61.64277747273445, 62.95030631124973, 58.233748599886894, 55.79314336180687, 56.0182698816061, 55.71649767458439, 63.422628566622734, 66.28412961959839, 71.39208912849426, 73.00389423966408, 76.84774518013, 72.89124548435211, 74.98386159539223, 69.09622952342033, 71.80790081620216, 66.37562870979309, 66.50053560733795, 64.71553578972816, 64.31830510497093, 68.69919642806053, 71.22472330927849, 72.07776233553886, 69.21542912721634, 66.96721896529198, 75.50037547945976, 84.85367998480797, 81.25914126634598, 86.72001823782921, 32.46160872280598, 0.808683471987024, 3.0956585006788373, 7.668876741081476, 4.067511213943362, 3.2057547429576516, 3.379663573578, 0.7248225656803697, 0.15476961387321353, 0.39340529940091074, 32.21570111811161, 55.09912580251694, 72.15484499931335, 46.49348437786102, 68.50041389465332, 21.75812266767025, 0.5415604182053357, 0.2776375348912552, 0.2932530938414857, 0.21539786917855963, 0.18473357398761436, 0.3226595971500501, 0.21353770571295172, 0.24326633079908788, 0.16614419961115345, 0.14730982744367793, 0.17461649811593816, 0.12905312818475068], [0.029580575901491102, 0.005475309053508681, 0.1365034596528858, 0.07825421809684485, 0.09261861254344694, 0.004913473112537758, 0.1266674351063557, 0.025356872465636116, 0.06157394440378994, 0.06730257489834912, 0.11819985666079447, 0.13895576790673658, 35.256259962916374, 50.29481939971447, 38.92928346991539, 43.31861414015293, 45.55588848888874, 43.145347237586975, 1.2287254608236253, 0.05631358682876453, 0.21581566863460466, 0.22924586985027418, 0.23264567804289982, 3.375154878012836, 4.906179886311293, 0.20343772892374545, 2.9093537852168083, 71.76798015832901, 95.23590847849846, 92.51646280288696, 91.34176343679428, 94.09832552075386, 87.5272773206234, 74.90075245499611, 65.87180614471436, 72.16839507222176, 71.96158736944199, 71.72060430049896, 67.55931839346886, 61.83388061821461, 61.58378943800926, 63.058098927140236, 67.44912430644035, 73.12045678496361, 77.06054136157036, 77.50104412436485, 78.51248145103455, 78.84991094470024, 77.68360912799835, 80.6203119456768, 78.12684774398804, 75.52428379654884, 66.53612449765205, 55.823967307806015, 59.509180560708046, 56.639243960380554, 57.309900373220444, 61.82061932981014, 68.24158698320389, 71.03420913219452, 73.2015672326088, 71.65119722485542, 69.47611793875694, 68.73842552304268, 65.10952904820442, 64.13061037659645, 68.55371743440628, 68.95852491259575, 69.75148156285286, 67.81354755163193, 58.70562627911568, 64.9051684141159, 69.4293424487114, 68.3614781498909, 60.54649829864502, 68.92689540982246, 66.85191795229912, 61.34970299899578, 66.94234549999237, 69.34300348162651, 59.773741364479065, 56.22383885085583, 52.851550206542015, 53.91216829419136, 55.797410532832146, 57.03873552381992, 64.25452172756195, 63.408865705132484, 60.60545593500137, 61.09195522964001, 63.58476206660271, 64.42641690373421, 58.78954857587814, 52.48878747224808, 55.319198593497276, 52.74910390377045, 52.77187988162041, 58.05116459727287, 61.767190396785736, 64.33272913098335, 64.16453495621681, 62.198607847094536, 58.13775435090065, 62.34835781157017, 65.49443319439888, 63.23743410408497, 60.85297845304012, 61.176762878894806, 61.897694393992424, 52.11154751479626, 57.19257026910782, 62.65250489115715, 61.42971150577068, 52.667286694049835, 65.38406431674957, 61.33331447839737, 61.627696081995964, 60.46500787138939, 55.66243797540665, 54.88494269549847, 55.78964754939079, 52.961227521300316, 52.652718275785446, 50.55403769016266, 50.12947507202625, 50.53471952676773, 57.55813725292683, 62.098517417907715, 66.48035109043121, 66.87550708651543, 70.5199371278286, 68.76875549554825, 69.8814269900322, 65.84276050329208, 63.056776598095894, 60.62492989003658, 59.441384598612785, 54.9081252515316, 55.90302586555481, 60.61726190149784, 68.9038534462452, 63.66804599761963, 62.42397755384445, 57.056822553277016, 72.72498160600662, 72.01559767127037, 76.34836077690125, 69.14248064160347, 54.35705602169037, 2.0953982742503285, 0.807755965506658, 1.5377933951094747, 0.3464157145936042, 0.1436157725402154, 0.13393404049566016, 0.9652705164626241, 0.11866766202729195, 0.4267510335193947, 11.068167686462402, 43.05449031293392, 50.54670788347721, 31.06286007910967, 49.79406327009201, 20.04827331751585, 0.48142864485271275, 0.20264177554054186, 0.04083497267856728, 0.09098522714339197, 0.01334936927378294, 0.10700205792090856, 0.04424182014190592, 0.1006267273623962, 0.05226481502177194, 0.08805280129308812, 0.022894621288287453, 0.02236503398307832, 0.012667273404076695, 0.002761990708677331, 0.12963117216713727, 0.05891521890589502, 0.0796170684043318, 0.03509370711981319, 0.07676176654058509, 0.023117378768802155, 0.016781871854618657, 0.04080980274011381, 0.14089036878431216, 0.0872626069758553, 45.45525848865509, 59.42847669124603, 45.124904215335846, 42.969906851649284, 48.932535499334335, 52.871016561985016, 1.039849470835179, 0.03567198116797954, 2.807093197479844, 1.346158990636468, 1.567692921962589, 2.179386354982853, 0.5801388574764132, 0.35792497044894844, 4.500362137332559, 76.60372987389565, 98.70682463049889, 96.58451691269875, 95.93429580330849, 96.27411916851997, 91.3766759634018, 78.19275140762329, 69.09117579460144, 75.40759965777397, 74.35140833258629, 76.14001795649529, 71.36430501937866, 65.16989260911942, 64.62009251117706, 66.59702003002167, 69.71843853592873, 75.4471555352211, 80.38394942879677, 81.09545364975929, 82.26036474108696, 82.57229760289192, 78.05406644940376, 83.4734496474266, 81.13719820976257, 79.4860728085041, 69.88317489624023, 59.400730580091476, 62.85889841616154, 59.93891850113869, 60.47794617712498, 64.68245476484299, 69.4438424706459, 74.8489536345005, 75.70834591984749, 74.09944385290146, 73.62834513187408, 72.22613677382469, 67.74224057793617, 69.97281208634377, 72.3297344148159, 70.55170342326164, 74.58511859178543, 70.16682967543602, 62.67653480172157, 70.15418395400047, 72.12060883641243, 70.39986357092857, 65.37236854434013, 72.24607810378075, 67.45429962873459, 65.87367564439774, 72.42202386260033, 69.40989509224892, 59.70761351287365, 59.02471035718918, 58.49357105791569, 60.21058112382889, 58.23819436132908, 58.12092125415802, 67.28330880403519, 65.15245914459229, 62.02499516308308, 63.54475021362305, 66.68867111206055, 66.66629791259766, 60.31388238072395, 55.52235849201679, 59.544689655303955, 56.16368047893047, 54.34608221054077, 58.043766394257545, 63.225365951657295, 64.05915141105652, 67.37954244017601, 63.87049153447151, 61.69636219739914, 62.53604494035244, 68.35855230689049, 65.49766302108765, 64.28306579589844, 60.82569971680641, 62.635968178510666, 55.240246430039406, 58.82826089859009, 62.2009789198637, 70.38542434573174, 58.46685849130154, 66.93207085132599, 64.80058282613754, 63.69630508124828, 65.62490299344063, 59.434533566236496, 59.79934819042683, 57.55334571003914, 55.024923384189606, 53.46755035221577, 53.30767013132572, 53.183428198099136, 53.118949458003044, 61.043838411569595, 65.59938356280327, 68.92844572663307, 69.59708824753761, 72.58229926228523, 71.47201403975487, 71.36881157755852, 65.95136627554893, 65.04423335194588, 62.0890749245882, 62.80168868601322, 57.43405871093273, 59.41485062241554, 62.54129245877266, 69.5857572555542, 66.02306842803955, 66.1661459505558, 60.98309867084026, 75.56828543543816, 77.22836315631866, 81.88667759299278, 75.17021879553795, 64.65469345450401, 3.1833532825112343, 1.2546607316471636, 1.1363126384094357, 1.6231524897739291, 2.6297505386173725, 0.7259993744082749, 1.0341769689694047, 0.12029430130496621, 0.4869954945752397, 9.645711164921522, 50.42312331497669, 51.81509502232075, 34.454970359802246, 60.480431243777275, 23.840578123927116, 0.37440243002492934, 0.170184614835307, 0.1130221966013778, 0.08462881392915733, 0.013694787066924619, 0.04765856414451264, 0.10399352482636459, 0.0753778318176046, 0.02657489265402546, 0.14706187590491027, 0.034320203703828156, 0.05069964041467756, 0.11945568927330896, 0.13651696674060076, 0.24671455670613796, 0.13080674892989919, 0.15647650900064036, 0.1713622992974706, 0.3306341520510614, 0.09299768673372455, 0.15107613784493878, 0.08910093645681627, 0.22034753405023366, 0.15903626539511606, 54.93559017777443, 71.7091517150402, 54.563852325081825, 62.672719806432724, 61.17868557572365, 67.2649709880352, 2.071005958132446, 0.13808315066853538, 3.065434922464192, 1.6790816886350513, 3.6880550254136324, 7.885415721684694, 10.713937394320965, 0.8192251750733703, 4.903448782861233, 84.07927393913269, 105.22138506174088, 102.89069652557373, 100.94258666038513, 101.10490635037422, 95.80443397164345, 83.68876129388809, 72.10928544402122, 78.16549926996231, 78.82144287228584, 80.2918803691864, 72.88787126541138, 68.16074252128601, 66.46503031253815, 70.72578728199005, 72.51500487327576, 78.46251413226128, 84.84831467270851, 83.23969379067421, 83.87239024043083, 85.58819577097893, 79.86911505460739, 85.4947891831398, 83.65217685699463, 82.44903981685638, 72.51517966389656, 62.26499028503895, 66.89557760953903, 63.86080965399742, 63.23637016117573, 66.9462288916111, 74.92257088422775, 77.1028558909893, 78.15038368105888, 79.02876734733582, 76.45195841789246, 75.80192729830742, 71.96231693029404, 72.23642662167549, 75.50638675689697, 75.37299111485481, 77.03602507710457, 74.69566226005554, 67.79704123735428, 71.97316154837608, 74.88870710134506, 72.99685701727867, 69.52366098761559, 74.74056825041771, 72.96636745333672, 67.15664640069008, 72.71065637469292, 74.23971712589264, 66.68592005968094, 65.46059980988503, 61.68022446334362, 61.17083139717579, 61.881514862179756, 62.09930017590523, 72.63206139206886, 65.93840897083282, 65.76266840100288, 65.01273304224014, 67.46452108025551, 71.97751611471176, 64.51404020190239, 59.98629815876484, 62.001181840896606, 57.59631760418415, 59.9252962321043, 63.61762270331383, 67.78666019439697, 66.37528672814369, 68.97892981767654, 64.76905211806297, 63.01978938281536, 66.3058340549469, 68.43232154846191, 67.73191273212433, 66.73678413033485, 63.95905718207359, 65.06756410002708, 56.85868978500366, 63.3446529507637, 65.91610416769981, 72.26547986268997, 62.62451559305191, 73.57935056090355, 68.11372384428978, 71.0772456228733, 66.70019969344139, 62.9124603420496, 63.0843061208725, 62.114123180508614, 59.15397182106972, 58.20788338780403, 56.23776890337467, 55.44919341802597, 56.99553184211254, 64.93001148104668, 69.05020639300346, 73.13766986131668, 72.5178775191307, 76.83889165520668, 73.95518839359283, 76.75917953252792, 68.43492060899734, 68.3051347732544, 66.45406410098076, 66.93427473306656, 60.56016996502876, 63.817841559648514, 65.03539502620697, 74.67021882534027, 67.76734963059425, 70.48602774739265, 62.9835507273674, 83.1081448495388, 80.38351625204086, 87.7917355298996, 78.46568316221237, 70.827447026968, 2.9814653657376766, 2.136108339764178, 6.762951202690601, 2.9867036221548915, 1.7336602974683046, 1.4615390868857503, 2.249090289697051, 0.21311151998816058, 0.690706274472177, 15.690385960042477, 60.56154929101467, 66.92355170845985, 42.00308293104172, 65.86682081222534, 28.984924480319023, 0.9043360955547541, 0.4361118015367538, 0.2647759672254324, 0.28155230451375246, 0.1476035249652341, 0.2909459942020476, 0.23385932698147371, 0.2591116289841011, 0.12737042707158253, 0.2907486126059666, 0.12648339732550085, 0.19736020738491789], [0.004681225418607937, 0.05868327178177424, 0.045959828930790536, 0.03423177309741732, 0.07595068818773143, 0.022190504969330505, 0.035870576175511815, 0.11102274685981683, 0.06887692987220362, 0.03589403546357062, 0.14596747525501996, 0.8563828468322754, 52.91718788444996, 49.46414217352867, 43.82296107709408, 33.957231268286705, 52.48300418257713, 24.876054860651493, 0.45928209729027003, 0.05130452787852846, 0.4412466025678441, 1.0997946979478002, 0.7204319012816995, 0.9698784223292023, 1.8262531352229416, 0.2829594461945817, 10.52108634263277, 74.87288475036621, 89.56987291574478, 89.9912703037262, 91.36448621749878, 89.25382867455482, 85.13013035058975, 75.39550870656967, 66.65353819727898, 72.90466636419296, 77.40183904767036, 79.5268826186657, 71.14894017577171, 65.98518446087837, 57.93135702610016, 61.549139097332954, 61.555237770080566, 66.38331189751625, 70.0169125199318, 76.45603939890862, 79.20201525092125, 78.43400806188583, 76.95023328065872, 77.93931260704994, 78.82548585534096, 77.68351033329964, 68.48025217652321, 60.422248765826225, 59.25166457891464, 56.10702931880951, 61.142025142908096, 65.62011525034904, 66.12962990999222, 70.33503144979477, 70.93361333012581, 71.01445019245148, 65.42068675160408, 67.83854261040688, 67.76918113231659, 66.18523612618446, 70.47859534621239, 68.81015807390213, 70.00176653265953, 58.63285258412361, 61.45042039453983, 72.57906943559647, 65.21186515688896, 61.9000768661499, 69.66677650809288, 66.5064024925232, 56.68299861252308, 71.29924491047859, 67.65448048710823, 53.414717987179756, 54.9402791261673, 63.260130286216736, 68.2913339138031, 70.15049055218697, 60.11072248220444, 50.715779811143875, 56.521302089095116, 60.61789646744728, 61.82645961642265, 60.69103494286537, 59.54463645815849, 57.35343083739281, 54.23993870615959, 57.10661128163338, 66.17964282631874, 66.53040200471878, 61.22514948248863, 54.40559081733227, 54.10800598561764, 59.781234562397, 63.10002587735653, 63.73441703617573, 64.06371876597404, 54.74218435585499, 56.3087110966444, 63.95746126770973, 65.4539805650711, 61.10785737633705, 56.6039514541626, 50.84903486073017, 58.70819874107838, 54.26201552152634, 64.42978352308273, 63.50443817675114, 54.91277240216732, 64.98598247766495, 61.07986807823181, 63.21376517415047, 61.15002751350403, 60.335579216480255, 54.289556443691254, 52.771062925457954, 51.2886218726635, 49.99232143163681, 48.287774696946144, 52.285038605332375, 54.495395198464394, 58.8586250692606, 65.13957783579826, 69.42352876067162, 68.57287600636482, 69.96341899037361, 68.52041602134705, 64.24243837594986, 64.05456125736237, 58.94425727427006, 57.647523656487465, 53.776443377137184, 56.71484090387821, 61.413334384560585, 66.46520510315895, 62.30459176003933, 63.264374658465385, 57.27550461888313, 70.4520271718502, 69.26155105233192, 79.83237102627754, 65.1727044582367, 66.5710674226284, 15.331373624503613, 0.6925583188422024, 1.322152828797698, 0.8222878107335418, 1.4598703826777637, 1.8006600835360587, 0.5222150625195354, 0.36293975135777146, 0.05126776188262738, 1.7524055228568614, 47.50675320625305, 37.226290851831436, 40.635844096541405, 42.86068171262741, 31.63500487804413, 0.11032587019144557, 0.06111890026659239, 0.07688319674343802, 0.09382836520671844, 0.06905572066898458, 0.060082023483118974, 0.09338481322629377, 0.04456445029063616, 0.027601438741839956, 0.05741093380493112, 0.012459503595891874, 0.06944601613213308, 0.06790197046939284, 0.05424548842711374, 0.03654049432952888, 0.04130330868065357, 0.0952961848815903, 0.06248676378163509, 0.022105391763034277, 0.02984128124808194, 0.0748240486427676, 0.05496270736330189, 0.14570193481631577, 1.244228035211563, 66.18531212210655, 59.02986288070679, 52.633327916264534, 26.529234051704407, 58.86137992143631, 31.236394867300987, 0.3220194502500817, 0.1840850556618534, 1.8385509378276765, 1.891042508650571, 1.7477238178253174, 1.4063888462260365, 1.211556438356638, 0.5681167775765061, 13.771025352180004, 82.68246129155159, 93.50698605179787, 94.27813947200775, 94.74090903997421, 92.22877264022827, 87.24437490105629, 78.23600068688393, 70.0634828209877, 74.63376358151436, 80.51885738968849, 81.31490707397461, 76.74402594566345, 68.55456858873367, 63.26796546578407, 64.1306559741497, 63.51206436753273, 67.76126995682716, 72.55441635847092, 78.26396718621254, 80.6444938480854, 81.91445410251617, 80.76740205287933, 80.60422360897064, 79.35750290751457, 78.72245818376541, 72.54259899258614, 62.79598519206047, 59.68191549181938, 59.07315015792847, 65.8187685906887, 67.15010315179825, 68.3831749856472, 76.64719954133034, 75.2802000939846, 72.99750298261642, 68.23647245764732, 70.57215392589569, 70.55918902158737, 70.24660259485245, 71.58302888274193, 70.607750415802, 71.90898299217224, 63.522460609674454, 66.29136443138123, 74.1549588739872, 68.34592938423157, 64.7888794541359, 72.73043811321259, 68.04011419415474, 62.38366551697254, 75.285854190588, 67.76780560612679, 54.84249897301197, 59.8185333609581, 67.58166119456291, 70.77706933021545, 72.2202242910862, 67.172179967165, 54.687505289912224, 59.376556277275085, 63.12226228415966, 62.10352174937725, 63.24813812971115, 60.380394011735916, 58.49307328462601, 56.308517307043076, 62.30618767440319, 69.35821026563644, 70.10313749313354, 65.67331999540329, 60.57061180472374, 54.51540492475033, 60.823096856474876, 66.67886763811111, 69.17404174804688, 68.6731906235218, 60.13128697872162, 60.58502443134785, 65.86049035191536, 67.5870569050312, 63.85989010334015, 60.13760223984718, 57.46366672217846, 64.65781688690186, 59.68472734093666, 63.949550092220306, 69.77968364953995, 60.17264015972614, 66.44188955426216, 64.67094898223877, 64.98923510313034, 64.78042870759964, 64.07358303666115, 59.39270921051502, 55.830715745687485, 53.20203959941864, 53.09453196823597, 51.94224379956722, 54.12803091108799, 56.730047687888145, 60.64278893172741, 66.38857081532478, 70.13798922300339, 71.72910064458847, 72.40927934646606, 72.30330303311348, 66.29696533083916, 64.4505076110363, 61.08220875263214, 59.62069317698479, 56.32875122129917, 59.03668351471424, 63.888776153326035, 68.85222181677818, 66.67031049728394, 64.0826341509819, 60.37106931209564, 75.05617171525955, 73.58569622039795, 82.30691984295845, 69.35555040836334, 72.14628025889397, 20.2722143009305, 0.9256444615311921, 1.042052402626723, 1.7530549317598343, 2.2950279247015715, 1.399854146875441, 0.9619449230376631, 0.2026146574644372, 0.12592666782438755, 1.1937452503480017, 50.051845237612724, 40.92175975441933, 37.80341148376465, 54.59466867148876, 38.360058814287186, 0.15656004514312372, 0.10487247258424759, 0.03730059084773529, 0.08546833880245686, 0.10452153321239166, 0.023760974800097756, 0.09219067535013892, 0.13093104382278398, 0.025895094659063034, 0.034580255960463546, 0.008330274631589418, 0.1003824123472441, 0.15714033041149378, 0.17487797158537433, 0.08173324313247576, 0.15401766984723508, 0.20819925935938954, 0.20554997026920319, 0.20074037835001945, 0.28576301294378936, 0.18737429869361222, 0.10942157809040509, 0.3184883709764108, 1.7254479881376028, 79.9249416589737, 68.00424411892891, 59.53228712081909, 47.90312513709068, 73.71730595827103, 41.38158828020096, 0.5997367214877158, 0.4632639867486432, 5.130200190469623, 6.112461257725954, 4.5061596762388945, 2.5508057372644544, 3.933053291402757, 0.7166779995895922, 15.142329968512058, 89.87880393862724, 98.95626604557037, 99.54950541257858, 98.82402554154396, 96.42006173729897, 94.12352576851845, 81.73594728112221, 74.73329544067383, 80.06047278642654, 85.15422105789185, 85.10388895869255, 78.50650057196617, 72.21213832497597, 64.54964429140091, 66.16755947470665, 67.0506776869297, 71.1837387084961, 75.69568499922752, 84.12582144141197, 83.93295899033546, 83.41892257332802, 84.20524477958679, 82.65547513961792, 82.1545784175396, 81.15112826228142, 74.73131194710732, 67.53973424434662, 65.19530564546585, 62.59383223950863, 65.99613547325134, 73.2104055583477, 70.76351165771484, 78.96104738116264, 74.56618040800095, 75.53202778100967, 73.02049934864044, 73.58878165483475, 71.98567807674408, 73.48507761955261, 76.1302600800991, 75.21669790148735, 76.37710243463516, 68.3250305056572, 67.75385275483131, 77.86849200725555, 72.33998626470566, 67.71480605006218, 74.30489122867584, 72.63281375169754, 62.618447318673134, 77.04610213637352, 73.34585309028625, 61.087733656167984, 60.64740188419819, 71.30046084523201, 72.30008080601692, 75.06272256374359, 69.10800889134407, 59.0939312428236, 61.75666496157646, 66.75390601158142, 65.3760239481926, 65.59048444032669, 64.62506264448166, 64.35242727398872, 59.91179935634136, 62.599778920412064, 73.24735477566719, 73.08668419718742, 66.51152461767197, 60.643324702978134, 57.70321346819401, 67.45407924056053, 70.00397801399231, 70.8703163266182, 71.86568051576614, 61.004761308431625, 61.5660709887743, 70.40633082389832, 69.8105151951313, 66.46967366337776, 64.31473329663277, 58.814847618341446, 69.19206038117409, 64.26952332258224, 64.76447716355324, 71.00428953766823, 65.98405972123146, 68.49359706044197, 67.05972120165825, 68.75980317592621, 66.98462203145027, 67.82949149608612, 61.42571032047272, 59.638571217656136, 57.482973486185074, 55.276124104857445, 54.310584515333176, 58.13292481005192, 59.51405569911003, 63.41857798397541, 69.4564501941204, 73.01511883735657, 73.86419087648392, 76.26465886831284, 74.90021288394928, 69.57073286175728, 69.59477037191391, 66.19706869125366, 63.86480703949928, 59.80534806847572, 62.90452636778355, 65.93775540590286, 72.44187399744987, 69.89898964762688, 69.89066049456596, 63.492457419633865, 77.09571227431297, 78.25618520379066, 90.83531901240349, 74.10208091139793, 80.43960124254227, 21.034491397440434, 1.2316838395781815, 4.997325595468283, 4.39739003777504, 5.64533949829638, 3.550046430900693, 1.6889675706624985, 0.5812900175806135, 0.19196607026970014, 2.88080092985183, 57.97559805214405, 50.678401216864586, 51.84865862131119, 57.80047684907913, 44.43842925131321, 0.33329317811876535, 0.20405345916515216, 0.15583444735966623, 0.2674360916716978, 0.31500900455284864, 0.12323733244556934, 0.1788130760542117, 0.2796872874023393, 0.10178300086408854, 0.2198729751398787, 0.0768594109104015, 0.19067933462793007], [0.056522453160141595, 0.030020109152246732, 0.04778593895025551, 0.04514216030656826, 0.09490504337009043, 0.06875265724374913, 0.019112800000584684, 0.08322334950207733, 0.04376928729470819, 0.06017037987476215, 0.141136375896167, 6.027564788237214, 64.91183325648308, 39.8167410492897, 33.29892039299011, 44.03899468481541, 56.64202161133289, 14.4597801938653, 0.06640093968599103, 0.5074292840436101, 2.3633116856217384, 2.5894494261592627, 0.6528585834894329, 0.5399199749808758, 0.39023333054501563, 0.6711446272674948, 15.966729931533337, 87.95752823352814, 88.66985321044922, 92.37486720085144, 84.67957332730293, 88.47477167844772, 86.84680983424187, 73.52140367031097, 65.36257266998291, 75.28418228030205, 76.881183385849, 79.50393185019493, 82.85332292318344, 74.0353412926197, 65.53409546613693, 60.880086198449135, 63.245748057961464, 62.69634313881397, 62.91774965822697, 61.621050238609314, 68.97652834653854, 74.34972122311592, 76.49445533752441, 76.63580015301704, 73.96489307284355, 77.28402256965637, 70.41231170296669, 56.299640983343124, 55.90822018682957, 57.80101642012596, 69.84891593456268, 65.91168120503426, 65.7952706515789, 69.95318993926048, 72.45263502001762, 68.60176965594292, 67.85070195794106, 66.07206299901009, 68.5809163749218, 68.18499282002449, 69.14951026439667, 66.53668686747551, 60.31233586370945, 61.27804644405842, 73.37112173438072, 65.89377656579018, 65.00385671854019, 70.53696781396866, 65.99958568811417, 58.80144573748112, 71.21554300189018, 68.7075711786747, 56.06476418673992, 56.81678183376789, 68.02839562296867, 69.61496248841286, 65.88192880153656, 65.21637171506882, 66.66808381676674, 52.161967009305954, 51.190940514206886, 59.65883173048496, 60.10723426938057, 60.1348701864481, 55.47962598502636, 53.42050887644291, 62.4068708717823, 67.93021649122238, 63.82908895611763, 63.092578276991844, 63.94746780395508, 67.72349238395691, 61.58192753791809, 53.78009498119354, 59.35685433447361, 60.264439433813095, 62.64100670814514, 64.23417001962662, 59.736738950014114, 60.822614282369614, 61.49452082812786, 65.01429095864296, 61.71357527375221, 56.58564403653145, 60.17219178378582, 63.07299792766571, 55.98637439310551, 66.06887876987457, 62.21334345638752, 57.48698987066746, 63.13648112118244, 59.0923885256052, 63.28707084059715, 58.966026306152344, 55.89053213596344, 53.379851058125496, 51.68349288403988, 49.72234591841698, 50.89797243475914, 49.44722168147564, 53.2877553999424, 59.353753700852394, 64.54228788614273, 66.91771522164345, 67.9143713414669, 68.40638414025307, 67.26649850606918, 64.32551711797714, 60.10883778333664, 56.29307493567467, 55.5753580480814, 53.836632147431374, 56.02371118962765, 65.17189890146255, 65.75598075985909, 63.17291356623173, 61.47648699581623, 61.59871883690357, 71.09236121177673, 76.32384449243546, 72.58617505431175, 66.22289970517159, 68.38318258523941, 36.97450116276741, 2.5633298652246594, 0.4631447681458667, 1.2814587936736643, 3.4568110713735223, 2.3258570954203606, 0.4256951354909688, 0.22785671782912686, 0.3090364672243595, 0.8234180719591677, 32.73623138666153, 49.29297275841236, 40.227134227752686, 47.13690385222435, 38.56965556740761, 0.10460132893058471, 0.04578612555633299, 0.046739399404032156, 0.06943466127268039, 0.07027400803053752, 0.003715406260198506, 0.044120575475972146, 0.052462515741353855, 0.0023127014628698817, 0.06973997340537608, 0.001940642539466353, 0.06936433535884134, 0.04693818365922198, 0.034585922257974744, 0.08168110725819133, 0.09963595279259607, 0.07454860053258017, 0.053293624660000205, 0.013410129831754602, 0.03264198516262695, 0.04480056457396131, 0.22481536696432158, 0.37960541958454996, 9.238980989903212, 74.75785732269287, 50.288070961833, 42.74837113916874, 34.10474315285683, 66.77823230624199, 17.36598964780569, 0.11606259009568021, 0.05414428174844943, 2.331539453007281, 2.5700348429381847, 0.9476025926414877, 0.9997796709649265, 0.1084100382286124, 1.0387228312902153, 19.136231057345867, 92.86887869238853, 92.99357280135155, 96.01692616939545, 90.50575509667397, 92.47511342167854, 88.1387785077095, 78.03475588560104, 69.06238853931427, 77.69328340888023, 80.82455098628998, 83.4251618385315, 84.68360111117363, 79.13132384419441, 69.37156274914742, 62.78294429183006, 65.99882572889328, 64.20772343873978, 64.37113747000694, 63.836012184619904, 71.3245515525341, 77.48268350958824, 78.90551716089249, 79.15620490908623, 75.96075117588043, 78.58261808753014, 74.39176216721535, 58.42629186809063, 57.051043063402176, 61.74393184483051, 72.58099213242531, 69.48765411973, 69.57694172859192, 72.38270357251167, 76.52144148945808, 71.62063166499138, 69.71417516469955, 69.40867155790329, 72.37065821886063, 71.46087303757668, 72.26363316178322, 69.93737518787384, 63.82127657532692, 67.96606376767159, 73.98138418793678, 69.46186870336533, 70.03237009048462, 74.75234761834145, 66.66477799415588, 61.69925384223461, 71.89823716878891, 67.26675689220428, 59.58044953644276, 63.18464733660221, 69.46951389312744, 69.97486397624016, 68.93552094697952, 67.47231066226959, 68.47481846809387, 55.12784466147423, 54.40411649644375, 61.014785170555115, 62.34300769865513, 60.98751403391361, 56.15837596356869, 53.851390555500984, 66.67626857757568, 68.05027484893799, 65.2463673055172, 65.60578241944313, 65.23631304502487, 70.59032455086708, 64.50663059949875, 58.971053436398506, 60.75042575597763, 61.52451641857624, 63.84871870279312, 66.57505720853806, 63.14188063144684, 63.8813741505146, 62.35475666821003, 67.35956311225891, 64.39259871840477, 60.5501689016819, 63.99339973926544, 66.87416195869446, 58.04823115468025, 65.87181374430656, 69.90915790200233, 59.23940643668175, 65.18024325370789, 65.40630832314491, 65.62833800911903, 63.579297959804535, 60.71636438369751, 57.322720885276794, 54.63387876749039, 53.26680712401867, 53.617364913225174, 53.84466491639614, 55.164159312844276, 63.32033805549145, 68.46699088811874, 68.74579712748528, 69.30045336484909, 70.64336210489273, 69.75287988781929, 66.4520426094532, 61.8453636020422, 59.347837418317795, 57.89582513272762, 56.08503609895706, 59.25174817442894, 68.15289974212646, 67.80261173844337, 65.99983647465706, 63.46906587481499, 64.44100812077522, 73.685212880373, 78.877482265234, 76.20500966906548, 73.20140764117241, 76.17486968636513, 44.084535241127014, 3.436581906862557, 0.4188469529617578, 3.501125006005168, 2.2535441257059574, 2.387081547640264, 0.04960781130648684, 0.09170857621938922, 0.2194414014229551, 0.9233623871114105, 33.43188665807247, 57.59523086249828, 36.77770212292671, 58.69196221232414, 46.83546982705593, 0.3802123182686046, 0.031106544702197425, 0.1314294256735593, 0.00533172620635014, 0.060127906763227656, 0.025192542416334618, 0.04416097428475041, 0.03361361232236959, 0.03626283461926505, 0.01649990397709189, 0.04900675703538582, 0.026325070903112646, 0.09065057791303843, 0.08589494755142368, 0.22199026308953762, 0.1153230102499947, 0.2918246079934761, 0.18110013770638034, 0.11797701939940453, 0.18105390190612525, 0.20723976631416008, 0.3530604892875999, 0.4338832211215049, 9.72190372645855, 88.36595311760902, 55.57409651577473, 46.64191581308842, 62.55412057042122, 79.64391633868217, 25.114617459475994, 0.16118361032567918, 1.379585440736264, 8.236133102327585, 6.207407237961888, 2.4629126535728574, 2.2505650855600834, 1.3116566045209765, 1.3505359995178878, 22.74769026786089, 100.08070930838585, 99.60141062736511, 100.20661935210228, 94.83673229813576, 98.23180451989174, 93.40943768620491, 83.44264850020409, 72.65021681785583, 80.40904328227043, 84.8801189661026, 86.22398525476456, 89.67700436711311, 82.16979280114174, 71.19347378611565, 66.50633409619331, 69.35925900936127, 67.90155842900276, 68.81300792098045, 67.28385597467422, 75.41625559329987, 80.71332335472107, 82.94514879584312, 81.65765628218651, 79.57313373684883, 81.43067926168442, 78.02050665020943, 62.88057625293732, 61.88668258488178, 63.55528324842453, 77.74306833744049, 71.790611743927, 71.9003726541996, 76.9103430211544, 79.85168918967247, 74.83192294836044, 73.5522048175335, 73.817438185215, 75.760068744421, 75.44140264391899, 77.78084591031075, 73.28496515750885, 71.37701913714409, 69.10637497901917, 78.79178926348686, 74.69793453812599, 71.54085874557495, 78.57030674815178, 70.07723808288574, 62.00604557991028, 77.39593416452408, 75.8567963540554, 61.653181314468384, 61.65849722921848, 73.15069556236267, 76.43931269645691, 71.9458182156086, 69.88318249583244, 73.77270698547363, 59.53917235136032, 57.97133468091488, 66.37675344944, 67.44263425469398, 65.7248604297638, 59.640809297561646, 58.29401716589928, 70.2709136903286, 72.34719827771187, 71.02978616952896, 69.0898534655571, 67.4636623263359, 72.72337809205055, 65.5261842906475, 58.894871324300766, 66.8573060631752, 65.41033610701561, 68.277867436409, 69.3421371281147, 64.8625423014164, 67.72856131196022, 66.18579089641571, 72.30243667960167, 68.70952427387238, 61.90351188182831, 65.66729351878166, 70.70957735180855, 63.746564984321594, 68.17622289061546, 69.92714613676071, 65.03399670124054, 67.34941005706787, 67.39794105291367, 69.9464263021946, 68.04991006851196, 61.865950897336006, 60.121164321899414, 56.931075900793076, 55.435373559594154, 56.798744201660156, 55.60134865343571, 56.68637663125992, 66.82338908314705, 71.27003207802773, 72.96273484826088, 71.36530056595802, 73.86739790439606, 71.85210764408112, 69.37447339296341, 66.06801241636276, 62.34725967049599, 60.72730019688606, 57.670231238007545, 61.33223533630371, 71.59364551305771, 71.08088582754135, 67.47340500354767, 68.14653128385544, 68.74113857746124, 78.56804966926575, 84.51131835579872, 82.58970826864243, 78.10029476881027, 84.50377196073532, 47.342970594763756, 3.6122994404286146, 1.3433180493302643, 7.661960162222385, 11.201855912804604, 6.026859926059842, 1.7200129735283554, 0.19299756648251787, 0.8615483134053648, 1.249724084045738, 39.499442875385284, 67.4714595079422, 53.07719349861145, 62.06216476857662, 55.96528932452202, 0.509959829505533, 0.13975396257592365, 0.2595785289304331, 0.20583263947628438, 0.12987517548026517, 0.13942379591753706, 0.15473964595003054, 0.1293681698734872, 0.21923469845205545, 0.20449445815756917, 0.1362384980893694, 0.15208204480586573], [0.03363875628565438, 0.022332392472890206, 0.03251788693887647, 0.05149543423613068, 0.040330019110115245, 0.042320050997659564, 0.11318992939777672, 0.08666207591886632, 0.00801842232249328, 0.07179610096500255, 0.28571468428708613, 12.274752091616392, 66.83815509080887, 28.576034121215343, 26.55064970254898, 46.70537240803242, 48.70688080787659, 8.231328260153532, 0.07138699205825105, 0.20693618338555098, 1.1233572335913777, 0.5018683418165892, 1.74570505740121, 1.5878251916728914, 0.8997838210780174, 1.5726972534321249, 40.29409043490887, 93.87529268860817, 86.38973236083984, 88.91459047794342, 85.84116339683533, 87.88055196404457, 80.99522262811661, 70.44213250279427, 71.03799372911453, 76.24093294143677, 79.562479108572, 80.17375990748405, 80.84151327610016, 83.91638427972794, 72.3930162191391, 65.18490180373192, 61.10022358596325, 62.53976494073868, 60.422153770923615, 61.086920499801636, 62.23616883158684, 69.59181413054466, 72.81556874513626, 76.31429940462112, 75.78721448779106, 76.5905673801899, 67.50595405697823, 55.0049402564764, 54.38248425722122, 63.76507759094238, 68.60066011548042, 68.16043093800545, 66.94920033216476, 64.91478189826012, 70.56466832756996, 67.26078361272812, 67.10937693715096, 66.67531862854958, 68.42893213033676, 71.51007279753685, 70.96459686756134, 61.312799379229546, 56.406248062849045, 69.15934413671494, 64.65822726488113, 64.21471506357193, 69.91802662611008, 63.738049641251564, 63.49655739963055, 68.73470172286034, 64.36790764331818, 54.54435557126999, 61.87577337026596, 67.81777292490005, 64.94053691625595, 64.19502452015877, 68.40984955430031, 67.40891486406326, 57.61489860713482, 50.29017984867096, 51.46892599761486, 52.75501638650894, 54.517194628715515, 53.14641438424587, 53.87153707444668, 50.748306065797806, 59.3497297167778, 64.66863110661507, 61.32661543786526, 60.96493184566498, 58.677507787942886, 60.27505986392498, 64.18984919786453, 62.18500077724457, 56.925801783800125, 58.74048560857773, 59.928446263074875, 62.90359541773796, 63.21857951581478, 61.04331023991108, 62.007595896720886, 59.91813361644745, 54.990022256970406, 57.67008304595947, 59.87309083342552, 58.811682388186455, 59.3180850148201, 58.84840361773968, 66.89729511737823, 60.305788815021515, 60.697589591145515, 66.69931054115295, 61.388346925377846, 59.205481857061386, 60.50685502588749, 58.1125009059906, 56.59808076918125, 52.04661279916763, 48.86384658515453, 49.563780426979065, 52.89931744337082, 58.75798746943474, 62.4072128534317, 67.60863974690437, 68.3673070371151, 69.80704978108406, 65.54475769400597, 63.02075453102589, 60.61684012413025, 57.09459252655506, 54.03800994157791, 53.772525787353516, 57.04678729176521, 67.27557241916656, 63.069657906889915, 66.37513473629951, 60.468503683805466, 60.1297290623188, 69.78681206703186, 76.42185643315315, 69.67569842934608, 71.80583372712135, 65.38927763700485, 50.09097933769226, 7.726437002420425, 0.7904403540305793, 1.6282818582840264, 1.1942867212928832, 0.834635307546705, 0.2815236576134339, 0.1275411358801648, 0.4279658698942512, 0.6357565918006003, 13.322176337242126, 58.30787882208824, 35.27277387678623, 28.184339739382267, 49.793090522289276, 1.4441594132222235, 0.119415932422271, 0.07250240290886723, 0.040586720569990575, 0.1244470034725964, 0.05242987608653493, 0.07106320044840686, 0.014510504770441912, 0.13582979736384004, 0.034120020500267856, 0.07772611323161982, 0.022888309322297573, 0.01819633111153962, 0.039905150697450154, 0.03271820743975695, 0.019900094375771005, 0.032629984634695575, 0.05934872962825466, 0.035584819634095766, 0.04371130700747017, 0.028983037555008195, 0.1686801775940694, 0.3392088372493163, 17.236380502581596, 75.52600890398026, 40.210506319999695, 33.489335775375366, 45.14571189880371, 58.28055068850517, 11.139340717345476, 0.043672923129634, 0.253748869872652, 1.5165701089426875, 1.4039100729860365, 0.8049881702754647, 0.7555773435160518, 0.837827967479825, 1.4957045973278582, 46.924191266298294, 98.31318855285645, 89.94856059551239, 94.18062910437584, 90.47262847423553, 92.58837014436722, 84.19288024306297, 77.28959307074547, 73.74975621700287, 79.1503456234932, 82.56886258721352, 85.94406187534332, 84.0034832060337, 85.95300659537315, 77.94796094298363, 68.74244570732117, 62.710983753204346, 65.89230224490166, 63.02771955728531, 62.89643280208111, 63.6729097366333, 70.31166270375252, 74.05802607536316, 77.79580190777779, 77.66030877828598, 79.09585654735565, 69.85149219632149, 58.76809112727642, 57.357717007398605, 67.86910817027092, 72.52911731600761, 71.74689888954163, 68.08919996023178, 67.79679045081139, 70.69193109869957, 70.40174826979637, 70.2290703356266, 70.69102674722672, 71.80351585149765, 73.23130443692207, 72.26896807551384, 64.67412561178207, 62.16362312436104, 72.2607073187828, 70.17596438527107, 69.1806609928608, 72.09979355335236, 64.28368136286736, 66.64903163909912, 69.55013036727905, 64.46747750043869, 56.888362392783165, 67.37822771072388, 69.70636278390884, 67.19228088855743, 66.52070492506027, 71.88894286751747, 68.61123114824295, 61.27655312418938, 53.1221678853035, 54.49176639318466, 55.57214342057705, 56.29866823554039, 56.95066764950752, 54.91149187088013, 53.489946350455284, 58.67569908499718, 67.68486365675926, 63.69708023965359, 64.25459012389183, 58.98397274315357, 61.09905704855919, 66.63896977901459, 66.76040366292, 60.778719037771225, 60.24608641862869, 61.73923149704933, 64.33035805821419, 67.08690494298935, 62.137757912278175, 66.36976942420006, 63.90198424458504, 57.89080560207367, 62.41032488644123, 64.29867535829544, 62.632639557123184, 61.71904698014259, 61.05405606329441, 66.1355347931385, 67.60876893997192, 63.49728316068649, 67.98693224787712, 64.36902478337288, 63.45571719110012, 64.3458916246891, 62.54014112055302, 56.442015543580055, 54.43236418068409, 52.66108922660351, 53.32259953022003, 54.87237296998501, 61.12353153526783, 65.03529623150826, 70.72720840573311, 70.00634148716927, 70.17531082034111, 68.56619596481323, 67.88411736488342, 62.06462323665619, 60.17526961863041, 57.01355427503586, 56.61035031080246, 60.49724154174328, 70.96984818577766, 66.58055931329727, 68.0356228351593, 62.38510183990002, 63.94750580191612, 73.32372307777405, 78.3864726126194, 75.83258405327797, 76.11220344901085, 69.80301439762115, 57.85091534256935, 9.17568588629365, 0.9545248711947352, 1.5463941148482263, 0.784272572491318, 0.41783448541536927, 0.3723873506532982, 0.13378555158851668, 0.5962889408692718, 0.8068897307384759, 12.221122719347477, 66.49238124489784, 34.576153457164764, 34.339452758431435, 63.28682005405426, 3.266281457617879, 0.2833266311790794, 0.09949213941581547, 0.02063966679997975, 0.0605588719190564, 0.022407147152989637, 0.04675153351854533, 0.03452554483374115, 0.03361625065736007, 0.0649929593782872, 0.07202908338513225, 0.059302200679667294, 0.09976185814593919, 0.16685419745044783, 0.1263561932137236, 0.10328142670914531, 0.15631871356163174, 0.24813471565721557, 0.24740916240261868, 0.12542772194137797, 0.06826122931670398, 0.2574977546464652, 0.3830389806535095, 18.27146966010332, 89.73226860165596, 41.28387652337551, 44.165847077965736, 62.870506793260574, 71.82194486260414, 16.773677431046963, 0.1262355496874079, 1.324947103857994, 4.0287794172763824, 4.273516684770584, 3.5740974778309464, 3.5634319251403213, 1.7219844739884138, 2.133433995768428, 50.774330869317055, 105.16362056136131, 94.76088836789131, 100.25006622076035, 96.1658401787281, 98.28602761030197, 89.10079568624496, 79.54604879021645, 78.06273758411407, 84.00222167372704, 87.03106194734573, 88.31597059965134, 88.44554364681244, 90.35947814583778, 79.02527913451195, 72.47022047638893, 66.41041204333305, 69.63646173477173, 65.53594216704369, 66.57906219363213, 67.35879555344582, 74.60028737783432, 78.54087352752686, 82.02138796448708, 80.280222594738, 82.12102621793747, 72.53478661179543, 60.06362780928612, 59.67734433710575, 71.03689178824425, 75.8056890964508, 74.59578081965446, 70.98097398877144, 71.71666011214256, 76.32925540208817, 73.56539770960808, 74.67167034745216, 75.00108987092972, 74.57417517900467, 76.89906522631645, 74.92842257022858, 70.41124776005745, 62.81090319156647, 75.72827205061913, 71.78922101855278, 72.17493072152138, 75.92400714755058, 67.10642069578171, 68.93699526786804, 73.74302297830582, 68.78743529319763, 62.8779011964798, 69.06604394316673, 73.13647672533989, 69.4144244492054, 68.00615921616554, 75.56225895881653, 72.4970318377018, 65.98991140723228, 54.67369683086872, 57.1924714744091, 58.85647438466549, 59.547835886478424, 62.048987075686455, 59.77915607392788, 57.79673404991627, 63.21283042430878, 69.06607434153557, 65.71119636297226, 65.96525833010674, 61.869800090789795, 64.17769744992256, 70.87625160813332, 68.61721202731133, 62.335191518068314, 62.923673540353775, 65.2726922929287, 68.50370451807976, 69.66623693704605, 65.6181925535202, 66.05100452899933, 65.38762852549553, 61.933883652091026, 63.82120817899704, 69.2569912970066, 66.40275925397873, 65.2591498196125, 65.68594291806221, 67.19600468873978, 68.01457956433296, 65.40891498327255, 71.64287567138672, 68.5321193933487, 65.95350936055183, 66.28469958901405, 66.1257617175579, 61.35414116084576, 58.50467786192894, 54.53207843005657, 56.196670308709145, 58.20493474602699, 63.52870747447014, 66.89851105213165, 72.81789422035217, 73.99972960352898, 73.53089556097984, 71.13816395401955, 69.81589570641518, 65.68666487932205, 64.18626219034195, 59.31085020303726, 60.856307074427605, 62.59924694895744, 73.15759599208832, 69.49792116880417, 72.59428381919861, 66.04852706193924, 66.16787865757942, 76.3428358733654, 86.58907726407051, 78.87403205037117, 83.43681961297989, 77.69905909895897, 65.37888139486313, 10.03301203250885, 1.5814941376447678, 4.634838346391916, 4.6952988021075726, 3.4948071325197816, 1.446860593277961, 0.2533151290845126, 1.36920974124223, 1.2095464649610221, 15.763482637703419, 73.68167147040367, 47.26418562233448, 39.739069417119026, 68.59561398625374, 2.850527004338801, 0.3677364595932886, 0.275363297550939, 0.15708009770605713, 0.24023569654673338, 0.16859138704603538, 0.1466848055133596, 0.17900974518852308, 0.29355657286942005, 0.14169948786729947, 0.1799559686332941, 0.19985658436780795], [0.026420193826197647, 0.01770388273143908, 0.019340262697369326, 0.052052004175493494, 0.04816625252715312, 0.11688958009472117, 0.07159923887229525, 0.023965404943737667, 0.05215260600380134, 0.11915183917153627, 0.1304204313782975, 25.1204539462924, 63.66338364779949, 28.565531484782696, 42.36169248819351, 51.11024424433708, 39.31508056819439, 6.035584732890129, 0.06637069716816768, 0.16443970904219896, 1.2325073266401887, 0.992159714223817, 1.5825088019482791, 0.9721997415181249, 0.3036046290071681, 9.700819607824087, 84.88670021295547, 85.95923826098442, 89.0931884944439, 85.55025860667229, 85.33072918653488, 85.56421905755997, 77.77773767709732, 62.66653373837471, 69.0851341187954, 70.31091794371605, 80.08128046989441, 80.59532448649406, 83.59438955783844, 78.39872315526009, 81.0117669403553, 72.39480972290039, 63.92035245895386, 60.00544913113117, 62.481605261564255, 62.94643431901932, 59.763459116220474, 64.56938043236732, 69.85117301344872, 72.56891638040543, 72.58785456418991, 71.72385692596436, 62.97440081834793, 52.32633098959923, 57.554044872522354, 68.69672656059265, 69.90858033299446, 69.70295816659927, 67.13974490761757, 62.96787656843662, 64.24310714006424, 62.69076123833656, 63.579126968979836, 64.0227797627449, 65.70709258317947, 66.13566398620605, 62.47551038861275, 61.895912289619446, 68.98624822497368, 65.78353688120842, 65.45262783765793, 68.0681262910366, 63.37394177913666, 63.6791680008173, 68.43438863754272, 60.566508024930954, 57.087084129452705, 60.201256424188614, 67.22051337361336, 64.51786279678345, 64.12330716848373, 64.51963350176811, 64.54465135931969, 59.67939242720604, 58.96622009575367, 47.295712530612946, 52.90208749473095, 56.76186718046665, 60.71705214679241, 57.08445847034454, 52.376621291041374, 46.22750625014305, 51.513307616114616, 64.45111557841301, 69.16401788592339, 63.26177939772606, 61.11370526254177, 60.0780176371336, 62.48909845948219, 63.85506436228752, 61.4816889166832, 57.88213826715946, 61.7061048746109, 57.27267377078533, 59.46879252791405, 60.799264535307884, 61.294826343655586, 60.05413971841335, 56.45212680101395, 58.207750394940376, 59.65377040207386, 59.96041774749756, 59.58207584917545, 58.693311139941216, 59.5766307413578, 65.89678600430489, 61.827439963817596, 62.65047959983349, 61.33589453995228, 62.12318189442158, 62.11870953440666, 60.02917505800724, 58.34804266691208, 54.463625103235245, 50.01384727656841, 49.49694961309433, 51.114807799458504, 58.56566458940506, 62.96493552625179, 67.45763584971428, 66.4402936398983, 68.26409697532654, 65.19069269299507, 63.59909489750862, 56.949246525764465, 55.60491666197777, 52.23456971347332, 55.66492684185505, 62.062947526574135, 68.35234344005585, 65.28286054730415, 66.7829592525959, 57.74311512708664, 63.5236157476902, 69.73993018269539, 72.95904904603958, 72.85861283540726, 71.7040903866291, 66.15862995386124, 61.89854174852371, 17.935721576213837, 0.6321739184204489, 2.0077372156083584, 0.941639703232795, 1.057782608550042, 0.1649894326692447, 0.040855352053768, 0.526678457390517, 0.36617809790186584, 3.905924172140658, 62.23082631826401, 44.56870526075363, 31.54214546084404, 51.931809559464455, 10.256952065974474, 0.40794026164803654, 0.13413350010523573, 0.1390439795795828, 0.1179306351696141, 0.03366370729054324, 0.04581606379360892, 0.039436666265828535, 0.04708299151388928, 0.024104019576043356, 0.07380125782219693, 0.058987949378206395, 0.08057118830038235, 0.04176482434559148, 0.009018630516948178, 0.13177369313780218, 0.0391137689439347, 0.1025601704895962, 0.07353440378210507, 0.0966536026680842, 0.02485350523784291, 0.11594211726333015, 0.18023094919044524, 33.5938111692667, 69.43935111165047, 40.9543202072382, 44.16013978421688, 53.64070326089859, 49.13966618478298, 8.245548997074366, 0.15119065123144537, 0.18931253609480336, 1.2515277997590601, 1.1757097556255758, 2.4055962916463614, 2.713132076896727, 3.2940957276150584, 11.861463468521833, 93.68948265910149, 88.7954592704773, 96.55767515301704, 87.08035290241241, 88.42586070299149, 86.04050070047379, 83.09016421437263, 66.99320957064629, 74.29984509944916, 73.35852921009064, 82.05197632312775, 82.37810522317886, 87.13627070188522, 82.05997109413147, 83.5762645304203, 75.63813328742981, 66.24803155660629, 61.21087744832039, 63.597829565405846, 61.04192331433296, 62.238387912511826, 66.64709374308586, 71.069266051054, 73.39431568980217, 75.53246855735779, 75.52354663610458, 63.3385618776083, 54.65397588908672, 60.07685489952564, 71.63824751973152, 71.61463558673859, 71.80701166391373, 69.35801267623901, 65.59014245867729, 66.27994984388351, 67.18262940645218, 66.65063515305519, 67.33090505003929, 67.95808419585228, 67.65803709626198, 64.86695006489754, 68.35030674934387, 70.96897423267365, 68.93536895513535, 71.05085223913193, 72.39534929394722, 65.93033820390701, 67.56640121340752, 69.02473255991936, 65.26041895151138, 63.13365787267685, 63.52586902678013, 70.3003241121769, 67.80979335308075, 66.3314750790596, 66.8710309267044, 66.73577338457108, 61.692285016179085, 61.516612842679024, 50.687490329146385, 55.89402034878731, 60.97528629004955, 64.80591014027596, 61.017931401729584, 57.79815137386322, 49.38397407531738, 53.39961379766464, 62.66775347292423, 68.55275228619576, 68.03542524576187, 63.48115302622318, 62.34342947602272, 64.94729295372963, 66.17684617638588, 65.67453593015671, 60.67004106938839, 64.363644272089, 62.76510424911976, 63.19035463035107, 63.84184867143631, 61.91269978880882, 63.745425045490265, 59.09216433763504, 61.98414735496044, 61.86633087694645, 62.478364035487175, 61.26055218279362, 61.09481267631054, 60.923810452222824, 65.78887939453125, 65.65239831805229, 64.16588008403778, 67.10094898939133, 64.34184104204178, 64.5870190858841, 62.257493287324905, 62.3509606719017, 57.05966480076313, 52.60504603385925, 52.32585221529007, 53.41622270643711, 60.98631329834461, 66.83936342597008, 70.03414079546928, 69.08700361847878, 69.25291791558266, 67.46746212244034, 65.11703744530678, 61.405461207032204, 58.626776710152626, 53.913768008351326, 58.053113892674446, 64.74460422992706, 70.11411890387535, 68.12962219119072, 68.26563209295273, 61.44095130264759, 65.71130275726318, 73.3447815477848, 78.35231244564056, 76.74986243247986, 79.24991548061371, 72.2317984700203, 70.38922414183617, 21.673052832484245, 1.2926299567334354, 1.0067509906366467, 0.7581312221009284, 0.6747893441934139, 0.05669458689226303, 0.033289015482296236, 1.1056834319606423, 0.4904598993016407, 3.496493767015636, 70.17700552940369, 47.38790698349476, 30.68934202194214, 62.94586054980755, 14.80820819735527, 0.47665832738857716, 0.16282718541333452, 0.1159006757370662, 0.11598771481658332, 0.08098562582745217, 0.01745025561831426, 0.050756381315295584, 0.01204186184622813, 0.07159615895943716, 0.09995031170547009, 0.021140668432053644, 0.13408248487394303, 0.13618558296002448, 0.10907627161941491, 0.28150367899797857, 0.18154682155000046, 0.2283808373613283, 0.2100281635648571, 0.13792977842967957, 0.1379532302962616, 0.27891803649254143, 0.23493650980526581, 36.73096463084221, 81.67760521173477, 42.01560325920582, 57.63817235827446, 66.4312881231308, 61.03165626525879, 13.016634732484818, 0.3352319943951443, 0.2754999417811632, 4.754312010481954, 2.5257125962525606, 6.401326032355428, 2.095667109824717, 4.445686396211386, 15.371669512242079, 103.64792749285698, 95.44450968503952, 101.72853648662567, 92.78915897011757, 95.60068130493164, 93.26593458652496, 90.91333642601967, 73.01742151379585, 77.53239244222641, 75.93378782272339, 87.10774943232536, 86.44289910793304, 90.14274537563324, 86.23134925961494, 88.5856269299984, 79.17241483926773, 69.0926045179367, 64.80314388871193, 67.5876496732235, 68.20554971694946, 64.5371125638485, 70.4965303838253, 74.9271534383297, 76.69220432639122, 77.52948179841042, 78.46998453140259, 65.91174960136414, 56.75355702638626, 63.29084783792496, 73.4004257619381, 74.93096843361855, 74.96299311518669, 74.73422259092331, 69.74627584218979, 69.9877680838108, 69.9105866253376, 72.29794532060623, 72.78037503361702, 73.2535408437252, 73.9657062292099, 72.6281476020813, 72.13940262794495, 71.39712005853653, 68.95654901862144, 76.4712005853653, 75.4842871427536, 67.25684702396393, 69.23581883311272, 76.76760748028755, 68.87029364705086, 66.43143251538277, 64.41033616662025, 71.52518838644028, 70.31800836324692, 69.73819747567177, 68.06235820055008, 69.24157932400703, 66.16540119051933, 64.32018220424652, 53.45945678651333, 57.16175392270088, 62.74663724005222, 66.19342088699341, 64.43475365638733, 59.62780639529228, 51.99046701192856, 58.05696688592434, 68.61989468336105, 72.95140385627747, 69.36352998018265, 67.454132437706, 64.02319014072418, 66.32208958268166, 70.1162999868393, 66.78546711802483, 64.22012597322464, 66.3413317501545, 63.78039836883545, 66.54244735836983, 67.60329723358154, 65.32743975520134, 68.27252492308617, 60.16965351998806, 65.14584749937057, 65.53178519010544, 65.26070013642311, 65.61135292053223, 65.20010098814964, 64.32918772101402, 68.84437903761864, 69.2210528254509, 67.95377522706985, 69.84796598553658, 67.50584006309509, 69.16572019457817, 66.78138613700867, 65.84161296486855, 60.790673196315765, 54.65985417366028, 56.017756909132004, 55.82040689885616, 63.99841547012329, 70.91026738286018, 74.45170775055885, 71.6273345053196, 73.38186755776405, 70.32762184739113, 68.73397216200829, 62.78441861271858, 62.74407617747784, 56.826045736670494, 63.515465185046196, 67.26960673928261, 73.62750917673111, 70.48124000430107, 72.20390036702156, 62.33737260103226, 69.15740624070168, 75.38863107562065, 84.12966683506966, 80.42555719614029, 86.89149543642998, 78.32894369959831, 80.25439158082008, 23.021343983709812, 1.9984094286337495, 4.9865185003727674, 5.382806835696101, 3.9087383961305022, 0.6548739003483206, 0.16995155077893287, 2.3089993000030518, 0.9669913491234183, 5.658588912338018, 77.35742703080177, 58.648093566298485, 42.19739690423012, 69.6757060289383, 16.661224365234375, 0.8794882788788527, 0.44395538221579045, 0.29048829688690603, 0.28428017219994217, 0.19271366531029344, 0.0979564651788678, 0.18839393538655713, 0.17964339087484404, 0.1435339284944348, 0.2668273524614051, 0.11578164267120883], [0.06816672423155978, 0.031720783226774074, 0.053239666813169606, 0.011637504539976362, 0.06034515565261245, 0.02437302769976668, 0.10384159977547824, 0.0453078299324261, 0.037405229959404096, 0.025266764605476055, 0.040298737585544586, 41.36983551084995, 61.77604392170906, 32.89283998310566, 55.137781128287315, 54.68823865056038, 24.208812564611435, 2.7301380643621087, 0.12821114680264145, 0.30381542863324285, 1.062700969632715, 0.6612519768532366, 0.5229338770732284, 2.722108382731676, 3.944573560729623, 52.81862497329712, 90.27415752410889, 87.20869481563568, 86.46719500422478, 82.02579572796822, 84.88214805722237, 76.32117703557014, 67.81761333346367, 65.95860868692398, 66.11807093024254, 70.68240121006966, 74.73491415381432, 77.15337038040161, 81.55511498451233, 80.4501722753048, 80.3678610920906, 79.41297993063927, 72.41343632340431, 61.44305258989334, 59.98517341911793, 59.68477673828602, 58.66752192378044, 63.37980106472969, 64.97255399823189, 68.31821367144585, 67.51311287283897, 63.40816654264927, 60.23817524313927, 53.60757663846016, 58.99348743259907, 69.08408537507057, 68.08746725320816, 68.78902360796928, 64.0790243446827, 61.636006236076355, 62.11699202656746, 62.34163977205753, 61.08910158276558, 64.30600896477699, 66.4891742169857, 65.37766546010971, 61.04788899421692, 57.84039370715618, 61.195541471242905, 64.01515737175941, 65.56615054607391, 65.66600158810616, 66.17735534906387, 68.01714822649956, 59.65964488685131, 61.00756175816059, 62.26420372724533, 70.26946976780891, 64.54871714115143, 63.952696323394775, 61.01038500666618, 63.49941484630108, 62.91868440806866, 62.96097233891487, 50.10434702038765, 50.20967736840248, 61.068122908473015, 61.677758395671844, 64.81185302138329, 63.851188570261, 62.12870679795742, 54.13528472185135, 44.78557862341404, 49.719720259308815, 55.95493488013744, 60.967185124754906, 64.85044375061989, 64.91779133677483, 62.79514163732529, 60.049826949834824, 60.90354613959789, 60.70789083838463, 56.88712365925312, 62.34301529824734, 58.15247856080532, 60.42217276990414, 59.082117676734924, 58.155997171998024, 60.62426492571831, 52.89320357143879, 56.1239156126976, 60.31191788613796, 58.01804557442665, 55.710972771048546, 55.4902084171772, 57.42445282638073, 60.85927851498127, 63.91852855682373, 62.574894055724144, 62.82074846327305, 61.48559890687466, 61.347708106040955, 61.938059628009796, 58.76794673502445, 51.755426824092865, 49.86772991716862, 51.053220704197884, 56.67496204376221, 62.55229286849499, 67.87999078631401, 65.66435247659683, 68.06843787431717, 64.7231125831604, 62.540627494454384, 58.11275169253349, 53.97996425628662, 52.380489483475685, 58.537147119641304, 67.97200664877892, 67.50213146209717, 64.39260631799698, 65.16025632619858, 60.231449604034424, 65.29402434825897, 70.78762516379356, 74.27004709839821, 73.4240984916687, 71.14324808120728, 65.14983728528023, 59.76818226277828, 33.49821589887142, 3.2931809267029166, 0.40400019963271916, 0.5103954998776317, 0.08559025882277638, 0.22338698501698673, 0.19026969879632816, 0.6029378122184426, 0.14990600844612345, 1.3776658312417567, 58.46409983932972, 47.275520414114, 30.193014554679394, 46.70464284718037, 19.087624065577984, 0.37750065908767283, 0.2524390979669988, 0.03577211915398948, 0.05486062495037913, 0.13436754379654303, 0.09125782540650107, 0.0723259944061283, 0.0604009169182973, 0.04472250919206999, 0.08458842625259422, 0.07582220758195035, 0.03397241474885959, 0.0407258138875477, 0.07302076337509789, 0.02418334403046174, 0.05683164672518615, 0.016703617948223837, 0.012306363278185017, 0.07891835863119923, 0.07622733857715502, 0.017925970423675608, 0.17469080194132403, 50.24006433784962, 69.59990009665489, 38.618368953466415, 45.352086424827576, 57.24746212363243, 28.846608102321625, 3.5456628911197186, 0.25766580656636506, 0.25915900769177824, 2.527187867090106, 1.2485436536371708, 2.099438882432878, 8.657915219664574, 10.209136381745338, 58.43959875404835, 98.01726803183556, 88.8553212583065, 91.0838332772255, 87.06142991781235, 91.48604929447174, 80.77206060290337, 74.75411832332611, 66.92543640732765, 68.75363230705261, 73.02066653966904, 76.86150044202805, 81.82185307145119, 82.10252121090889, 84.83860239386559, 81.45337924361229, 82.64232784509659, 75.46604052186012, 64.42004084587097, 61.989630460739136, 62.171055525541306, 60.92658430337906, 64.97364073991776, 66.2558363378048, 71.00869730114937, 70.14517843723297, 67.22673743963242, 59.06438022851944, 55.449789986014366, 62.541246861219406, 72.32487067580223, 71.2836429476738, 72.01020196080208, 66.60465002059937, 64.81042429804802, 64.59567502140999, 63.768011033535004, 63.70075084269047, 67.43797570466995, 68.52315947413445, 68.99478256702423, 65.03914162516594, 62.564767599105835, 64.55233454704285, 66.86375811696053, 69.03946056962013, 67.09348618984222, 68.01120534539223, 69.54414188861847, 63.78111273050308, 66.17192924022675, 64.95454296469688, 71.4798492193222, 64.08118262887001, 65.26229605078697, 62.6445709168911, 68.34639295935631, 66.95838063955307, 66.04852706193924, 49.994323924183846, 55.27770861983299, 63.197779431939125, 62.32503466308117, 65.15722408890724, 65.52167013287544, 66.36117428541183, 57.26866498589516, 45.9686641395092, 51.3489930331707, 57.851261124014854, 62.10204362869263, 67.31019616127014, 66.34840697050095, 66.08961045742035, 60.93186981976032, 62.30484254658222, 64.21924442052841, 59.86422970890999, 64.636500030756, 62.12489180266857, 64.62433308362961, 62.61634223163128, 60.670671835541725, 63.507318422198296, 56.56844615936279, 58.13236624002457, 63.18270944058895, 61.59541301429272, 58.721068650484085, 58.723838701844215, 60.02646200358868, 62.226863130927086, 65.92954784631729, 63.780018389225006, 65.79755812883377, 65.01388058066368, 65.97711369395256, 63.96040990948677, 62.70741954445839, 56.01189002394676, 53.27543266117573, 53.414022624492645, 60.568008944392204, 65.71470737457275, 70.33988758921623, 68.0808176100254, 70.22758841514587, 65.30890434980392, 63.76937136054039, 58.88330854475498, 57.9377406835556, 55.01039296388626, 61.91915564239025, 70.40136829018593, 70.9880568087101, 68.11829879879951, 67.93574139475822, 63.179935589432716, 67.97497808933258, 73.82317587733269, 74.87009570002556, 77.58191898465157, 76.15194171667099, 72.34866499900818, 68.17704364657402, 39.79710750281811, 4.974696859717369, 0.9660116548184305, 0.19007426162716, 0.14613129693316296, 0.3573943942319602, 0.062449634133372456, 0.6011139694601297, 0.4618768236832693, 1.5610945760272443, 62.133410945534706, 54.885516464710236, 26.982304640114307, 57.622201815247536, 26.22863408178091, 0.34750972932670265, 0.15370158915175125, 0.08662678679684177, 0.09794224562938325, 0.1016825511760544, 0.04847600270295516, 0.05335924906830769, 0.11768979340558872, 0.11360265998519026, 0.044032749719917774, 0.029452833732648287, 0.13060442463029176, 0.13948518637334928, 0.14549015555530787, 0.0991738322773017, 0.17525706061860546, 0.17068823624867946, 0.12514310830738395, 0.16284052922856063, 0.16965685877949, 0.12735607393551618, 0.1953932488686405, 58.39817337691784, 78.38212564587593, 45.38199082016945, 71.19398295879364, 70.27360394597054, 41.12285636365414, 7.914541158825159, 0.40070064074825495, 0.5862421612255275, 5.69531774148345, 1.3346143788658082, 2.9933827137574553, 20.575648918747902, 14.405320566147566, 58.75972397625446, 102.6594865322113, 93.56145992875099, 96.59479916095734, 91.36953994631767, 96.99636161327362, 86.05902090668678, 79.49390038847923, 70.28670564293861, 72.48964503407478, 78.28304216265678, 81.2890076637268, 85.385020673275, 87.88497492671013, 87.4272058904171, 87.48821541666985, 84.92954671382904, 78.82322117686272, 67.66326561570168, 65.23878291249275, 65.64463913440704, 63.039540722966194, 68.83092015981674, 69.0894278883934, 74.93766367435455, 71.88130527734756, 68.20561811327934, 64.76395279169083, 59.1470979899168, 63.56325522065163, 75.34525260329247, 73.86437326669693, 74.49183359742165, 70.81683039665222, 67.77166619896889, 67.79755041003227, 68.28194841742516, 68.03173184394836, 70.58583319187164, 73.19190055131912, 71.45966470241547, 69.09081101417542, 67.93818846344948, 66.35628774762154, 70.64422085881233, 72.4382109940052, 67.90614858269691, 70.30651777982712, 76.1100223660469, 67.70451620221138, 68.65717068314552, 67.95192092657089, 75.66699653863907, 69.73817467689514, 66.66023343801498, 66.2778827548027, 70.74046209454536, 69.04953762888908, 68.2340481877327, 56.2835868448019, 56.33429512381554, 65.35635620355606, 64.84655275940895, 70.23878261446953, 68.13056454062462, 68.89603346586227, 59.593619629740715, 49.84124913811684, 55.70849530398846, 63.03639829158783, 67.05980479717255, 71.75624638795853, 68.41185584664345, 68.7801168859005, 61.722812578082085, 65.76684057712555, 65.91340631246567, 62.165739610791206, 65.85240438580513, 66.85065641999245, 66.58972442150116, 64.78457808494568, 62.54331015050411, 67.04212054610252, 62.58516110479832, 61.06167085468769, 68.22750493884087, 64.85100612044334, 61.632491424679756, 61.98209546506405, 63.96822988986969, 64.78086948394775, 69.18793380260468, 67.69549548625946, 69.07393231987953, 67.68290296196938, 67.83623993396759, 66.20751053094864, 65.60393571853638, 59.581433683633804, 57.95725263655186, 56.914645582437515, 64.93613675236702, 69.3868075311184, 73.45557600259781, 69.749376475811, 73.35972234606743, 69.10311475396156, 69.33006137609482, 61.2608789652586, 62.67333537340164, 59.266768768429756, 64.67435359954834, 72.84024462103844, 73.51790025830269, 69.1660925745964, 71.62738010287285, 66.63240373134613, 71.73388838768005, 77.37529367208481, 82.07772374153137, 82.088043987751, 83.9213240146637, 79.14805814623833, 79.51606079936028, 41.20224930346012, 5.487336851656437, 1.0852728271856904, 1.3548912783153355, 0.3919671953190118, 0.5733535496983677, 0.29425428074318916, 1.7254023905843496, 0.8911385131068528, 2.727356138639152, 66.70711532235146, 64.68325272202492, 40.407453551888466, 65.05364924669266, 31.019485406577587, 0.6602883129380643, 0.36403922829777, 0.2824475127272308, 0.21388078574091196, 0.3447858098661527, 0.36634116258937865, 0.20257435884559527, 0.2426455687964335, 0.17544231552165002, 0.27944335830397904, 0.20708770025521517], [0.024603418169135693, 0.027555718734220136, 0.14828474231762812, 0.03388028824701905, 0.041089863298111595, 0.12880590395070612, 0.026182285400864203, 0.1568875549128279, 0.06753612877218984, 0.07511958669056185, 0.7704511703923345, 49.58620302379131, 49.90202687680721, 29.251402281224728, 59.92171302437782, 42.88877360522747, 7.078651087358594, 1.3743285415694118, 0.2828800067072734, 0.10187480453168973, 0.5152325809467584, 1.1444769753143191, 4.976393468677998, 8.775599654763937, 13.178893625736237, 105.27384504675865, 84.50700178742409, 91.84721991419792, 78.3597980439663, 82.24834218621254, 72.81249091029167, 71.64831697940826, 65.43680548667908, 66.56287506222725, 66.52442872524261, 71.6856537759304, 69.17711958289146, 76.56991168856621, 79.52667742967606, 83.91147494316101, 78.21515500545502, 79.69484880566597, 78.7321400642395, 75.65661549568176, 59.55499090254307, 62.101595252752304, 55.70200525224209, 60.712697580456734, 62.867531552910805, 66.59999907016754, 64.4704869389534, 60.60997389256954, 56.39196842908859, 57.25118212401867, 65.73766574263573, 72.83028915524483, 69.68348801136017, 71.72777831554413, 63.23228158056736, 59.866095408797264, 57.23664790391922, 59.00559738278389, 59.78584751486778, 61.08973614871502, 64.01056721806526, 65.60143545269966, 63.550415709614754, 64.23388123512268, 60.73104679584503, 59.850694835186005, 67.28307321667671, 67.92080819606781, 65.06096765398979, 60.64366288483143, 62.930961549282074, 62.01473951339722, 66.13811105489731, 63.38322468101978, 63.36658917367458, 63.44599351286888, 63.94112214446068, 68.66858527064323, 63.093771412968636, 50.5964320152998, 46.87150329351425, 59.039662554860115, 61.27927377820015, 62.337961569428444, 61.45420499145985, 60.47300644218922, 59.9871227145195, 60.8618775755167, 51.64765700697899, 48.448954448103905, 55.667085126042366, 54.80567514896393, 53.526204004883766, 60.34992344677448, 67.19744101166725, 60.63741981983185, 56.32080964744091, 61.44337177276611, 57.24363572895527, 58.31495404243469, 61.08134239912033, 58.9755941927433, 59.594485983252525, 59.92183081805706, 54.22602005302906, 52.186380699276924, 57.834222838282585, 60.07367067039013, 58.325160294771194, 58.0525591224432, 55.26567846536636, 56.461128517985344, 57.87662476301193, 60.71022771298885, 62.55771517753601, 62.26482309401035, 65.27379423379898, 64.50505748391151, 59.83835309743881, 61.50452569127083, 55.35549804568291, 47.37064450979233, 50.991481617093086, 56.491390094161034, 61.27968795597553, 65.82946121692657, 64.67370003461838, 67.37030893564224, 62.26977422833443, 61.14893317222595, 56.55956223607063, 52.90543511509895, 54.680981040000916, 64.57000359892845, 68.14978390932083, 66.83044150471687, 67.43436589837074, 63.84325459599495, 60.360369086265564, 65.18826842308044, 69.23198103904724, 71.28592282533646, 73.17244559526443, 72.4115440249443, 64.6426784992218, 58.92621964216232, 51.72756291925907, 12.233551852405071, 1.8980612070299685, 0.08323576563270763, 0.21821123227709904, 0.21884851448703557, 0.1286939880810678, 0.05434049817267805, 0.15254119673045352, 0.24739397806115448, 52.96552889049053, 56.12981669604778, 32.67723195254803, 47.09087312221527, 32.32573181390762, 0.1591093372553587, 0.1262234675232321, 0.0005904103659304383, 0.04417817726789508, 0.01445679554308299, 0.05531541675736662, 0.0501025566336466, 0.08583863338571973, 0.05046901060268283, 0.02709427357331151, 0.0380830853828229, 0.04028751631267369, 0.04208909464068711, 0.10795370646519586, 0.07500946681830101, 0.05721046858525369, 0.03909730810846668, 0.03628803424362559, 0.11620249235420488, 0.19858363782986999, 0.3011214028811082, 2.6749745244160295, 59.74568746984005, 61.71842761337757, 34.770228043198586, 47.29385823011398, 54.11659732460976, 7.358444323763251, 2.5332129187881947, 0.40398342709522694, 0.047079930154723115, 0.35019428527448326, 3.077120245434344, 5.584869543090463, 11.343239676207304, 14.947408027946949, 110.22685647010803, 87.04133659601212, 97.33905762434006, 82.53907218575478, 86.5223528444767, 78.36549773812294, 75.85611999034882, 66.22818902134895, 69.56537514925003, 67.0793129503727, 75.67768916487694, 72.66951218247414, 83.10158640146255, 80.95141857862473, 86.53480097651482, 80.28034418821335, 82.61614724993706, 80.33220380544662, 81.11961275339127, 62.93042577803135, 62.895410656929016, 57.869621738791466, 62.38719932734966, 65.24773523211479, 67.72935926914215, 65.86517170071602, 64.01481539011002, 56.88500717282295, 58.63201282918453, 68.71251091361046, 73.37762698531151, 71.52702748775482, 72.46005982160568, 66.60647392272949, 64.34979781508446, 59.634627029299736, 62.41782188415527, 61.328492537140846, 64.83370184898376, 67.40117087960243, 69.971474558115, 68.57824891805649, 67.33633875846863, 65.16398772597313, 63.97615626454353, 69.18928653001785, 67.8787824511528, 67.22301363945007, 63.714829087257385, 65.81956654787064, 64.28357496857643, 67.05776050686836, 66.22810542583466, 63.9312806725502, 64.48153674602509, 67.82522052526474, 69.6759720146656, 61.53938502073288, 51.03456750512123, 48.892994821071625, 61.47005774080753, 63.614328280091286, 63.76864939928055, 63.717599138617516, 64.24687653779984, 61.13715000450611, 64.00678262114525, 55.90230010449886, 50.84802031517029, 55.9940879791975, 57.44540490210056, 54.92781959474087, 60.06268925964832, 69.56598311662674, 63.42406488955021, 57.993711680173874, 62.52364620566368, 61.12123265862465, 61.93983793258667, 62.638042867183685, 62.68952630460262, 62.26068131625652, 60.60124196112156, 55.54468609392643, 56.114613711833954, 61.13623425364494, 62.30381280183792, 62.728022038936615, 61.65826924145222, 58.34772348403931, 58.93944293260574, 61.544396951794624, 63.50381501019001, 62.86254622042179, 64.9988941848278, 66.69598191976547, 65.97932517528534, 64.0324692428112, 63.94005820155144, 59.11385357379913, 48.71510736644268, 53.96758832037449, 58.67449074983597, 64.67205092310905, 68.44635799527168, 67.4956414103508, 69.00957137346268, 64.77398425340652, 63.437155187129974, 58.70630644261837, 56.1691901832819, 57.739037945866585, 66.74081951379776, 69.22584056854248, 69.65312764048576, 68.9443364739418, 66.26028969883919, 62.375256568193436, 66.6099925339222, 73.2718862593174, 76.87784716486931, 76.99775353074074, 76.31024122238159, 73.02537068724632, 68.57013255357742, 55.55534452199936, 15.123188495635986, 3.1883243657648563, 0.09262370367650874, 0.373569413786754, 0.5001760669983923, 0.11137878478621133, 0.1587761426344514, 0.43093386688269675, 0.3136227320646867, 56.12429179251194, 68.07653144001961, 31.99486456811428, 55.52897773683071, 41.60709097981453, 0.0525097126228502, 0.03998103529738728, 0.045219881722005084, 0.08863327951985411, 0.07596527138957754, 0.042894759026239626, 0.02178141090553254, 0.013290300812514033, 0.02895140536566032, 0.042329472562414594, 0.023492977852583863, 0.11522108368808404, 0.15386406012112275, 0.19907256471924484, 0.17777524190023541, 0.20086247648578137, 0.14650550263468176, 0.31990385439712554, 0.31362567096948624, 0.34578865917865187, 0.33312548242975026, 2.546708844602108, 71.8207061290741, 64.65455666184425, 43.20852264761925, 74.72801372408867, 59.04764972627163, 16.914121694862843, 4.85383247025311, 0.802909325575456, 0.2990480203879997, 0.7001050701364875, 3.1106104608625174, 4.6621873788535595, 16.081086695194244, 16.216866709291935, 116.95142403244972, 92.65063360333443, 104.07048761844635, 85.85000172257423, 93.89822825789452, 81.14720687270164, 83.72824117541313, 71.61531955003738, 74.29435819387436, 70.48260033130646, 81.15593880414963, 75.45106172561646, 85.80621287226677, 86.18563771247864, 89.6149916946888, 82.24525675177574, 87.00262427330017, 83.27006936073303, 85.29857531189919, 63.98378625512123, 67.81581982970238, 60.187862142920494, 66.8976067006588, 68.15205618739128, 71.90403565764427, 68.97490203380585, 67.02942162752151, 61.16823233664036, 61.43282353878021, 71.62165760993958, 77.64105901122093, 73.3799296617508, 75.08809000253677, 67.93185040354729, 66.79214715957642, 62.92355194687843, 67.09283262491226, 65.73508188128471, 68.92995804548264, 70.7882559299469, 72.62639969587326, 73.12604248523712, 71.48738041520119, 67.81607821583748, 65.72802186012268, 72.13051110506058, 72.51596242189407, 73.0414742231369, 67.06994265317917, 70.51631212234497, 67.79010280966759, 72.44238317012787, 69.37709525227547, 65.16749873757362, 69.79399368166924, 70.17245337367058, 74.60705101490021, 68.34597498178482, 57.43739873170853, 51.27088442444801, 65.1336881518364, 66.53822958469391, 67.11290314793587, 66.3491441309452, 67.9197670519352, 66.47936314344406, 67.39912658929825, 55.56205116212368, 52.43441998958588, 60.46377673745155, 61.06732115149498, 58.92074033617973, 64.39401224255562, 73.16043823957443, 64.24824446439743, 59.94119077920914, 65.36066517233849, 65.13958543539047, 63.63312587141991, 66.0861374437809, 64.00835573673248, 64.6744067966938, 61.85053512454033, 58.46664570271969, 59.69844840466976, 62.196745947003365, 66.21799036860466, 65.04883870482445, 64.34621080756187, 61.59240357577801, 61.10293664038181, 63.749240040779114, 68.03414851427078, 67.31812253594398, 66.78234368562698, 70.2154366672039, 69.16724011301994, 67.24613159894943, 66.14730656147003, 59.88647371530533, 53.293481692671776, 56.691339164972305, 62.5163733959198, 67.30970978736877, 72.18686208128929, 68.80990728735924, 72.94293031096458, 67.88391977548599, 67.54329085350037, 62.14808575809002, 59.96694199740887, 60.19387722015381, 69.56067100167274, 73.33648279309273, 73.39912623167038, 72.06011608242989, 70.09457275271416, 66.09341025352478, 71.31414771080017, 77.25734040141106, 82.11547091603279, 83.28721404075623, 84.39437583088875, 80.39719551801682, 75.7496877014637, 60.21795652806759, 15.56579064577818, 3.666350827552378, 0.18836858362192288, 0.6215037941001356, 0.6800698139704764, 0.34577277721837163, 0.32665083766914904, 0.89098040596582, 0.9519293729681522, 62.32894845306873, 77.87416130304337, 43.423731699585915, 65.55231168866158, 45.04784435033798, 0.1623387631843798, 0.19262960966443643, 0.1474669697927311, 0.1235959010955412, 0.1555910229217261, 0.19980231852969155, 0.1383026037365198, 0.34440873947460204, 0.14026288292370737, 0.17784454365028068, 0.1478889846475795], [0.02542033722420456, 0.0559570034238277, 0.02175133537093643, 0.007074968480083044, 0.10541415133047849, 0.06652413620031439, 0.0068176468630554155, 0.03345326018461492, 0.07151714991778135, 0.1967227173736319, 5.920547330752015, 63.558786660432816, 29.69555474817753, 26.559683717787266, 60.82993648946285, 24.014762677252293, 0.49851989024318755, 0.7536268013063818, 0.20457922626519576, 0.03736193677468691, 1.0547673515975475, 2.7274542208760977, 3.194741508923471, 0.9372859087307006, 57.48696327209473, 95.71728944778442, 82.18132138252258, 83.34231108427048, 77.22132593393326, 73.30732315778732, 66.4461301267147, 68.15306693315506, 65.14932051301003, 66.88353225588799, 65.8879628777504, 70.67042425274849, 75.43400824069977, 77.39885240793228, 79.4872659444809, 79.53844919800758, 77.77140721678734, 79.27260786294937, 77.27659776806831, 76.45316675305367, 75.11990949511528, 59.52819474041462, 57.505639269948006, 60.43778993189335, 61.229363456368446, 60.27874946594238, 59.95431907474995, 58.61259967088699, 56.75837516784668, 59.26077648997307, 69.40746322274208, 68.0980534851551, 71.76118612289429, 69.2335769534111, 63.65273281931877, 58.59049245715141, 60.17108604311943, 57.53672540187836, 59.793120324611664, 60.970631539821625, 63.515199199318886, 63.927374482154846, 65.39167910814285, 61.842110976576805, 68.17035600543022, 61.26155912876129, 64.88461151719093, 65.2706404030323, 62.41976737976074, 66.20602861046791, 61.13529570400715, 64.13367301225662, 59.35557760298252, 61.73863872885704, 62.99920208752155, 64.50008735060692, 66.48225858807564, 54.6612448990345, 50.26258572936058, 46.650712341070175, 56.18086315691471, 61.18743650615215, 65.3831447660923, 62.409386336803436, 60.879026055336, 63.099653497338295, 62.69380107522011, 61.35338880121708, 62.08267606794834, 53.20605978369713, 50.39862222969532, 63.713955134153366, 55.53783506155014, 53.41756783425808, 59.04340535402298, 66.03526577353477, 54.2950015515089, 56.3091404736042, 61.0879198461771, 56.248499527573586, 59.80562545359135, 60.12701980769634, 60.25767959654331, 57.231738567352295, 57.45510198175907, 54.682557955384254, 57.9173281788826, 58.68030063807964, 57.07047142088413, 58.87348607182503, 55.32194584608078, 54.99375745654106, 54.59765151143074, 55.584032982587814, 58.399412110447884, 61.865555718541145, 59.81991268694401, 61.4220055192709, 62.84616909921169, 65.77672004699707, 58.46661530435085, 49.28128078579903, 48.25795769691467, 48.546746000647545, 57.471209317445755, 64.24948319792747, 66.46227926015854, 66.67528823018074, 62.14496612548828, 57.4167962372303, 55.39129592478275, 52.435696721076965, 62.744220569729805, 66.08464792370796, 69.58229184150696, 69.2519299685955, 66.31239250302315, 62.40581452846527, 59.90175649523735, 65.47931760549545, 70.89575976133347, 70.4315310716629, 73.71558845043182, 68.90455260872841, 65.22199541330338, 61.17189534008503, 60.090997740626335, 27.69463151693344, 6.254092957824469, 0.10779743985040113, 0.11276769189862534, 0.3542636294150725, 0.4690405377186835, 0.3750243497779593, 0.08384489818126895, 0.17431750165997073, 39.726385697722435, 66.74415573477745, 33.18229325115681, 34.68253254890442, 41.19877628982067, 0.0982654064137023, 0.13454165164148435, 0.05158051033504307, 0.036449069157242775, 0.01577501680003479, 0.04764028133649845, 0.09320211873273365, 0.037525472725974396, 0.049661973243928514, 0.0743117144156713, 0.051653819682542235, 0.04503806296270341, 0.09597109397873282, 0.08193095127353445, 0.04742736658954527, 0.06108052752097137, 0.002896966034313664, 0.05348576669348404, 0.08763345816987567, 0.27787321130745113, 0.41442485118750483, 11.169338207691908, 73.97567689418793, 45.8250318467617, 25.670090653002262, 59.77698639035225, 29.478745982050896, 0.7418834720738232, 1.956879913341254, 0.3011307242559269, 0.0553986374870874, 1.0985632077790797, 1.9446139340288937, 2.5013720523566008, 1.0571639542467892, 62.75511458516121, 98.4496696293354, 84.01952594518661, 87.44509533047676, 82.49068558216095, 79.3912222981453, 72.5641818344593, 71.57661482691765, 68.63213762640953, 69.19176399707794, 69.32860985398293, 75.11043280363083, 78.96594151854515, 82.38439008593559, 81.11303150653839, 81.70190870761871, 78.51872071623802, 81.82515129446983, 80.6265664100647, 80.41481137275696, 77.38930732011795, 62.6828196644783, 57.744885832071304, 62.844584584236145, 61.809007152915, 63.92752647399902, 62.57506124675274, 61.15641497075558, 59.04638059437275, 61.697319746017456, 71.00757256150246, 70.79827219247818, 73.20848286151886, 70.5273087322712, 65.72816625237465, 62.9669114202261, 61.77389323711395, 61.426420882344246, 62.72750526666641, 64.2651155591011, 66.08346998691559, 68.31390470266342, 64.84480485320091, 66.32250756025314, 69.47867140173912, 65.21482139825821, 66.72809019684792, 67.68435448408127, 64.59536343812943, 69.64233621954918, 63.90061631798744, 65.58873653411865, 61.42564572393894, 62.49195210635662, 65.56728288531303, 68.29915389418602, 66.57333970069885, 58.51154789328575, 53.15108433365822, 51.44497208297253, 59.78895954787731, 65.3416433930397, 66.277274787426, 65.3546766936779, 61.79197646677494, 66.36605322360992, 66.58643379807472, 64.67756062746048, 63.53841595351696, 57.644856199622154, 51.72574661672115, 65.34323170781136, 61.73592187464237, 56.40609227120876, 61.5766192227602, 67.8118984401226, 58.44690576195717, 57.68565081059933, 63.859646916389465, 58.36444638669491, 59.16469104588032, 63.916636258363724, 62.19207979738712, 58.52790981531143, 59.157596826553345, 57.53986403346062, 61.912597194314, 61.45341843366623, 60.443128645420074, 60.76246351003647, 57.89861038327217, 57.8855998814106, 56.36475048959255, 58.56618896126747, 60.78160688281059, 65.86503490805626, 62.003830298781395, 62.901361137628555, 63.919828087091446, 67.18260660767555, 61.83794640004635, 51.59512102603912, 49.52049694955349, 52.627377435564995, 60.038165375590324, 68.40703010559082, 67.59230822324753, 67.25411877036095, 62.78909996151924, 60.653033182024956, 57.0909409224987, 54.97520685195923, 63.17248038947582, 68.99755641818047, 72.09011927247047, 70.61319172382355, 69.96093392372131, 63.9932781457901, 63.11223082244396, 67.85012438893318, 74.35446336865425, 74.93889480829239, 76.68880730867386, 74.08767208456993, 72.03250676393509, 69.87323462963104, 65.20599067211151, 30.356371589004993, 7.376188421621919, 0.32661646138876677, 0.1406009163474664, 0.5939794366713613, 0.7726425246801227, 0.5783714179415256, 0.1250983716454357, 0.46561359660699964, 41.03688217699528, 77.84890025854111, 31.2228561937809, 43.785639479756355, 51.95605605840683, 0.6306424818467349, 0.09533301767078228, 0.033065261668525636, 0.052846243197564036, 0.06799950351705775, 0.0366843039955711, 0.07488275994546711, 0.0032787597319838824, 0.02510595975763863, 0.028864477608294692, 0.1021994421898853, 0.0860467241727747, 0.22601558302994817, 0.11827227543108165, 0.1932703354395926, 0.15990034793503582, 0.11229911469854414, 0.10860374619369395, 0.17436154070310295, 0.43110616388730705, 0.6949655490461737, 9.63512683287263, 90.04334270954132, 43.99900183081627, 39.76591497659683, 77.96769708395004, 36.231078654527664, 3.2137932116165757, 4.855010407045484, 1.5463778469711542, 0.14059940236620605, 3.469838434830308, 7.645003572106361, 4.5205433294177055, 2.316524558700621, 65.8731284737587, 104.82760459184647, 90.92139959335327, 93.76522019505501, 87.22824856638908, 83.17432969808578, 76.24405637383461, 78.8777406513691, 72.39727959036827, 73.91919672489166, 72.4677886068821, 77.89727926254272, 84.33582097291946, 86.70117124915123, 84.10086438059807, 84.40346494317055, 81.46480143070221, 82.80796095728874, 82.78770044445992, 82.2313266992569, 80.04563838243484, 65.23094773292542, 61.845086216926575, 64.83665809035301, 66.06540575623512, 66.44974753260612, 66.1233526468277, 64.87363770604134, 62.16626398265362, 63.96237060427666, 73.87495189905167, 72.89430812001228, 76.28500297665596, 73.67540940642357, 68.5752622783184, 64.01710286736488, 67.87176042795181, 64.06935006380081, 65.40450721979141, 68.05165797472, 71.09504386782646, 70.45310631394386, 71.39699846506119, 69.33219686150551, 73.3669039607048, 65.0948466360569, 69.89881485700607, 72.89494648575783, 67.09733158349991, 73.70388507843018, 68.29190388321877, 70.8139805495739, 63.48559118807316, 63.330301120877266, 70.4232095181942, 69.94673788547516, 72.06629455089569, 64.08986136317253, 56.27173528075218, 51.84753768146038, 61.147907227277756, 67.10582032799721, 69.05770719051361, 67.12721318006516, 62.88616955280304, 67.7048809826374, 68.2655256986618, 65.9873579442501, 66.01457968354225, 56.392526999115944, 54.33749847114086, 68.89232486486435, 60.3764346241951, 59.61196504533291, 64.50037613511086, 70.93732193112373, 59.08210247755051, 60.936596766114235, 67.11984157562256, 61.35088853538036, 62.18935914337635, 64.43071827292442, 63.60274650156498, 61.26534752547741, 63.204364478588104, 60.856462866067886, 63.48747968673706, 64.62726652622223, 62.84692905843258, 63.68644081056118, 61.70866973698139, 59.89887244999409, 58.874846398830414, 61.439351588487625, 62.03712411224842, 69.27343681454659, 64.57950308918953, 64.62360352277756, 67.1120747923851, 72.05426439642906, 65.470350086689, 55.11343963444233, 54.340348318219185, 54.32113274931908, 63.56379859149456, 69.80505108833313, 70.82905814051628, 70.90503886342049, 66.83861866593361, 62.57964000105858, 60.73588013648987, 58.73137749731541, 67.12855830788612, 71.53442949056625, 75.68875417113304, 73.86867463588715, 73.35119560360909, 67.61182397603989, 65.38601741194725, 71.06204643845558, 78.35069373250008, 78.77095878124237, 84.20968294143677, 79.82048526406288, 80.91275945305824, 77.54866316914558, 71.74993872642517, 33.044736832380295, 9.611546248197556, 0.4238344228360802, 0.3420423867646605, 0.8327286411076784, 1.0107970610260963, 0.7879979163408279, 1.0172954248264432, 0.5864900385495275, 46.816299855709076, 84.12934005260468, 46.076475754380226, 51.75559401512146, 60.27067869901657, 0.8625627995934337, 0.2880794042721391, 0.21394787589088082, 0.14053306920686737, 0.16510090325027704, 0.18620933464262635, 0.1791133193182759, 0.09925364283844829, 0.16949964221566916, 0.19367885804967955, 0.20114798069698736], [0.02962403050332796, 0.026478476538613904, 0.06670927235973068, 0.03497493380564265, 0.061356016449281015, 0.015541341399512021, 0.0725305377272889, 0.041356743313372135, 0.10009184668888338, 0.08820896400720812, 29.58117138594389, 58.09127904474735, 29.394289813935757, 38.90306867659092, 48.60801391303539, 13.420940637588501, 0.26537648343946785, 0.6076663616113365, 0.046526005971827544, 0.06131464171630796, 0.9659419523086399, 1.1059576109983027, 0.6543488160241395, 2.703775316476822, 74.15685877203941, 89.9893020093441, 85.1240886747837, 83.41584473848343, 73.67841124534607, 68.32132190465927, 68.57104450464249, 64.58414644002914, 67.61966675519943, 66.99171245098114, 67.69669622182846, 68.61107915639877, 75.75782686471939, 79.05620187520981, 79.82775047421455, 77.68401950597763, 77.20311731100082, 78.56430307030678, 78.58460918068886, 76.16768047213554, 76.43214628100395, 72.50115841627121, 57.350212410092354, 57.93927200138569, 56.9136006385088, 59.78786900639534, 56.9186619669199, 55.82759611308575, 53.69562171399593, 62.31010526418686, 70.25192990899086, 69.50701028108597, 72.23957285284996, 68.70227426290512, 61.513098031282425, 60.3200950473547, 56.37907572090626, 58.07516410946846, 59.77459631860256, 62.278031185269356, 60.43194204568863, 62.31278412044048, 64.37610760331154, 64.06407594680786, 62.42721118032932, 63.24693739414215, 65.1992954313755, 62.73629039525986, 64.2071382701397, 60.27358554303646, 63.592289462685585, 62.9845766723156, 61.548162549734116, 61.53199061751366, 67.6570263504982, 68.85278418660164, 56.49020075798035, 56.60498879849911, 54.75109487771988, 55.65913215279579, 65.92083871364594, 63.91372561454773, 66.11196085810661, 63.79460960626602, 61.932363733649254, 65.00767931342125, 65.06753370165825, 66.66404843330383, 62.27067098021507, 64.02970299124718, 51.94791689515114, 51.270610839128494, 66.63396924734116, 61.402554363012314, 56.015974804759026, 58.26680302619934, 64.17895138263702, 53.056522607803345, 61.677184626460075, 57.896315306425095, 58.283666521310806, 58.72619837522507, 58.63239660859108, 56.357584074139595, 54.31588143110275, 57.159569039940834, 60.220593586564064, 57.30073146522045, 58.40382747352123, 58.13886769115925, 54.48149934411049, 54.525846764445305, 52.17556267976761, 52.47850142419338, 55.847522243857384, 58.27425442636013, 60.35113178193569, 61.79227665066719, 59.95663695037365, 62.18431681394577, 57.877783700823784, 52.03693091869354, 48.12423527240753, 49.53764542937279, 50.925038382411, 58.02204675972462, 62.18654729425907, 60.49472227692604, 58.51387336850166, 54.09343756735325, 53.07908959686756, 57.56343796849251, 64.53193724155426, 68.4266446530819, 69.38160181045532, 68.22271719574928, 68.14420580863953, 58.710676208138466, 62.48929984867573, 65.56752607226372, 71.40928700566292, 70.85507914423943, 73.70900720357895, 68.51748257875443, 63.280736580491066, 60.51375165581703, 65.2468004822731, 42.87273846566677, 11.245526019483805, 0.5605899752117693, 0.2224890308571048, 0.37665134528651834, 0.6886664964258671, 0.3726503381039947, 0.11794011981692165, 0.3936418367084116, 30.72164598852396, 78.50759491324425, 35.565415173769, 25.717764794826508, 44.19307641685009, 2.2329979157075286, 0.35904356511309743, 0.11460447771241888, 0.029058293184789363, 0.1117441440874245, 0.03023623925400898, 0.05168085983314086, 0.05898151866858825, 0.030409851715376135, 0.03734249621629715, 0.023429316424881108, 0.11185117662535049, 0.07297868360183202, 0.07381327319308184, 0.027334280421200674, 0.06703879334963858, 0.007177049501478905, 0.02926954737631604, 0.030152382132655475, 0.06325095324427821, 0.04144932252529543, 41.33347146213055, 66.7562086880207, 38.550838977098465, 35.692009180784225, 56.70000270009041, 14.878967050462961, 0.543962245574221, 1.5158599033020437, 0.19969261426012963, 0.10432228140416555, 0.5546419881284237, 0.6934125011321157, 0.4949192568892613, 3.7248097406700253, 76.60781845450401, 92.20330640673637, 89.3150281906128, 84.7180500626564, 78.95983144640923, 72.98634678125381, 72.25645914673805, 68.77721384167671, 69.68169450759888, 69.31077361106873, 69.48632419109344, 72.72058144211769, 79.67614620923996, 80.5476826429367, 81.77158176898956, 80.28843775391579, 79.00289833545685, 80.27916625142097, 79.58418354392052, 80.37182807922363, 79.79479104280472, 74.59098547697067, 60.53091153502464, 59.65573109686375, 59.06145058572292, 62.041474878787994, 59.14398975670338, 57.5578560680151, 55.13265140354633, 64.89338144659996, 72.30158552527428, 71.39070600271225, 71.81319013237953, 69.3251596391201, 65.15209436416626, 61.86348482966423, 60.65166525542736, 60.05991920828819, 62.337353602051735, 64.87721711397171, 65.20038977265358, 66.17082729935646, 65.4627276957035, 69.69282031059265, 66.42240419983864, 66.19966015219688, 66.63826301693916, 64.9692177772522, 67.30174541473389, 63.31709302961826, 64.60514411330223, 63.91252487897873, 64.97021332383156, 64.50628861784935, 68.01705703139305, 69.69461381435394, 60.941734090447426, 59.450644701719284, 58.01129333674908, 59.92565341293812, 68.10115411877632, 66.38569056987762, 70.31499132514, 67.3465222120285, 63.71110528707504, 67.0832571387291, 67.12053313851357, 66.51723191142082, 66.89485564827919, 64.60153430700302, 55.865145698189735, 49.88373465836048, 65.34111142158508, 65.31468763947487, 59.277856573462486, 60.28612866997719, 66.93675979971886, 56.12279087305069, 62.128683999180794, 59.69541236758232, 61.81463845074177, 61.98710739612579, 60.45209616422653, 61.24765947461128, 56.46248884499073, 57.96348050236702, 63.60810801386833, 59.13048908114433, 61.37551501393318, 62.48809151351452, 58.18266034126282, 55.95123007893562, 55.25124303996563, 54.33144919574261, 56.888088807463646, 60.03480635583401, 61.79306700825691, 64.96512159705162, 61.466113552451134, 64.34467568993568, 61.4982446283102, 54.67837817966938, 52.555200308561325, 52.00405888259411, 53.55731673538685, 59.608009457588196, 64.85892489552498, 61.692079827189445, 61.40639215707779, 55.15034705400467, 56.16734728217125, 59.603677690029144, 68.00672918558121, 71.72967821359634, 69.56789061427116, 71.3204325735569, 69.12693947553635, 61.308813393116, 64.62099686264992, 67.99135521054268, 74.71939578652382, 74.83631551265717, 78.75782668590546, 74.92798939347267, 73.26701492071152, 68.4394271671772, 69.88916337490082, 43.32788564264774, 14.76756177842617, 1.1679362040013075, 0.17843958281446248, 0.5240631883498281, 1.2110256543383002, 0.6653663842007518, 0.3553203586488962, 0.42886811366770416, 33.13854239881039, 89.72156077623367, 37.648892775177956, 29.30505160242319, 58.436106741428375, 4.508348358795047, 0.29118119564373046, 0.025918492719938513, 0.07557219287264161, 0.03485906599962618, 0.01791208855138393, 0.06932690143003128, 0.0894929759670049, 0.02962568549264688, 0.10498421033844352, 0.037330280465539545, 0.24934505461715162, 0.14585219003492966, 0.2602257113903761, 0.14016404369613156, 0.20482268038904294, 0.11132569154142402, 0.1557844562921673, 0.158974043733906, 0.27756860421504825, 0.17380319332005456, 47.23072461783886, 80.84355756640434, 42.359697595238686, 53.84035214781761, 70.3312848508358, 18.566153347492218, 1.233771233819425, 3.9219728484749794, 0.8693242992740124, 0.291686212294735, 4.2496810387820005, 5.1107043866068125, 1.512965764850378, 5.130008300766349, 81.85853630304337, 97.91307002305984, 95.3933872282505, 93.1814955174923, 85.51301300525665, 78.62379267811775, 77.5898377597332, 72.67515107989311, 73.98883178830147, 74.39066022634506, 72.55405157804489, 74.66292321681976, 83.08240503072739, 83.65187287330627, 85.8882200717926, 84.32798579335213, 82.51476109027863, 84.819914996624, 81.7984539270401, 80.11756852269173, 80.85076957941055, 78.43482121825218, 64.37970221042633, 63.21429714560509, 60.66945590078831, 65.0206746160984, 61.11011825501919, 61.71652011573315, 58.17751921713352, 68.63358154892921, 75.76128467917442, 74.63050335645676, 77.00944930315018, 72.05122455954552, 68.41569364070892, 65.93498915433884, 64.54670324921608, 63.81922468543053, 66.5365044772625, 70.08587121963501, 66.92739710211754, 68.08553695678711, 70.8515377342701, 71.19542688131332, 70.09393438696861, 67.75989443063736, 67.30370610952377, 68.57874289155006, 70.08011072874069, 65.06811127066612, 68.4564882516861, 67.63309523463249, 66.9689592719078, 66.00542217493057, 72.07697957754135, 74.63917449116707, 66.4070226252079, 62.163311541080475, 61.11683629453182, 63.21200206875801, 72.4438650906086, 68.73026356101036, 74.17524218559265, 70.42780727148056, 64.42633330821991, 72.8806060552597, 69.67354774475098, 73.55764612555504, 68.54592025279999, 67.827158421278, 57.93927580118179, 56.11665040254593, 72.25792586803436, 66.9268499314785, 62.36432455480099, 65.27160555124283, 68.97852703928947, 59.27531071007252, 67.54839017987251, 63.07851143181324, 65.28892502188683, 63.62466752529144, 64.8278957605362, 63.2975734770298, 60.424194261431694, 61.65372468531132, 65.6700673699379, 62.629356533288956, 64.89332064986229, 65.27453139424324, 61.069760620594025, 59.59945231676102, 60.03075197339058, 57.505517676472664, 57.894240617752075, 62.85216137766838, 63.557224944233894, 65.77834635972977, 66.67372271418571, 68.40801045298576, 64.89234030246735, 56.8277632445097, 55.70281840860844, 54.20042082667351, 56.99109748005867, 63.60288709402084, 71.05300292372704, 65.67369237542152, 64.27630215883255, 58.059227764606476, 58.37211437523365, 61.77379064261913, 71.10573649406433, 73.82487818598747, 74.4960817694664, 74.25300881266594, 75.66245958209038, 64.85856771469116, 68.3027333021164, 70.05596682429314, 78.82682338356972, 79.26361754536629, 85.96326604485512, 81.79531529545784, 82.24895775318146, 77.714524269104, 77.31301501393318, 45.04149489104748, 17.912928499281406, 1.8337706755846739, 0.3980233578477055, 0.8705146447755396, 2.2472200775519013, 1.2789055681787431, 1.055089384317398, 0.6199744949117303, 38.49794201552868, 97.52475365996361, 51.10789597034454, 38.725086227059364, 65.19016832113266, 4.995494093745947, 0.5847738368902355, 0.3414139657979831, 0.13923474121838808, 0.2655434072948992, 0.2440812237909995, 0.16420229600043967, 0.12717899749986827, 0.14390170719707385, 0.13993685744935647, 0.1275741762947291], [0.05591343935520854, 0.1427025895100087, 0.03356674569658935, 0.05067494545073714, 0.008007301239558728, 0.01586564045283012, 0.03445776448643301, 0.04449077729077544, 0.08059843996306881, 1.6817980678752065, 52.76442468166351, 44.03340898454189, 33.9198412746191, 37.43502505123615, 44.293839409947395, 11.11360564827919, 0.4760064842412248, 0.5324460135307163, 0.1916510731098242, 0.24007217172766104, 0.6606627115979791, 0.4897585400613025, 0.014339337685669307, 3.6707248678430915, 82.15804383158684, 86.49227365851402, 83.42120245099068, 77.68658056855202, 74.6492287516594, 74.62185502052307, 76.73854663968086, 73.70908319950104, 66.04636877775192, 66.36833310127258, 64.70640107989311, 72.63181820511818, 74.7488822042942, 81.66289240121841, 78.59891161322594, 80.43301999568939, 75.65482959151268, 77.62310117483139, 76.20896145701408, 80.06046518683434, 74.4164988398552, 76.05195388197899, 65.48641562461853, 54.40076507627964, 56.26183681190014, 56.934427320957184, 56.38353668153286, 56.37158252298832, 55.38428530097008, 62.96549029648304, 67.53648161888123, 67.20161318778992, 70.20006269216537, 64.1116113960743, 60.865696370601654, 57.79804117977619, 55.25075286626816, 57.09366537630558, 59.28213134407997, 59.688572734594345, 62.44614936411381, 64.45904955267906, 62.82993257045746, 64.8710386455059, 67.02960401773453, 59.53760303556919, 61.88537925481796, 63.50175932049751, 62.70312577486038, 62.45901547372341, 62.15768404304981, 61.05237275362015, 61.87822423875332, 63.112249821424484, 66.29454866051674, 53.7057975679636, 55.117516815662384, 58.56980636715889, 51.33301869034767, 59.41090643405914, 58.10159549117088, 63.33635039627552, 65.28217658400536, 61.74771264195442, 55.654367208480835, 60.60137115418911, 63.87105390429497, 63.22970151901245, 61.35032616555691, 56.99495047330856, 60.054656490683556, 50.543348863720894, 48.978737220168114, 64.79420676827431, 60.23318611085415, 53.83556440472603, 64.72424492239952, 56.22353106737137, 55.48061013221741, 58.43217775225639, 58.196730986237526, 59.30540129542351, 57.247610315680504, 57.11450345814228, 55.46408861875534, 54.972151815891266, 59.56652708351612, 59.27644684910774, 59.583508372306824, 56.95013947784901, 53.46348077058792, 52.95737072825432, 50.479208305478096, 50.196431279182434, 53.295487985014915, 55.518338307738304, 60.00014841556549, 64.82793375849724, 60.82755781710148, 61.203996017575264, 58.58749061822891, 51.08033984899521, 51.294158175587654, 49.92273196578026, 51.558411195874214, 50.610339269042015, 51.3087759912014, 51.70379139482975, 52.40551874041557, 49.73328933119774, 57.14542239904404, 66.58904805779457, 69.10247638821602, 68.22629660367966, 68.33195373415947, 66.01828828454018, 63.45590718090534, 58.66752952337265, 63.82683947682381, 67.6740038394928, 70.04772886633873, 71.94321915507317, 68.54657381772995, 64.52689871191978, 62.15943194925785, 56.32991395890713, 68.24081942439079, 58.42528112232685, 23.96585740149021, 1.3870326848700643, 0.13085758604574949, 0.5365960439667106, 1.4273611083626747, 0.4759957973146811, 0.18356408283580095, 0.3148202912416309, 23.942057378590107, 76.73588678240776, 42.00404427945614, 26.317980587482452, 29.249289594590664, 6.325730513781309, 0.4988708964083344, 0.07756759048788808, 0.1776653149863705, 0.10627205920172855, 0.03830323606962338, 0.07755431346595287, 0.03668966601253487, 0.02685962874238612, 0.06414804651285522, 0.015233928061206825, 0.03230683498259168, 0.11903403064934537, 0.018107388423231896, 0.05334748602763284, 0.03565426610293798, 0.0435699872468831, 0.04021021421067417, 0.059829318488482386, 0.042677246674429625, 3.7963641760870814, 66.30049154162407, 53.591408506035805, 43.70804384350777, 36.23581700026989, 54.06260222196579, 10.8987195789814, 0.4629161866614595, 0.9359008830506355, 1.033594412729144, 0.09533424963592552, 0.5744602403137833, 0.27597268985118717, 0.2699970651883632, 4.340756451711059, 84.09572705626488, 89.28983554244041, 86.42987340688705, 82.35315576195717, 78.77215951681137, 78.86960908770561, 79.63314011693001, 76.21658384799957, 70.62046453356743, 70.86293712258339, 69.20019194483757, 76.17552325129509, 77.8562642633915, 84.94903206825256, 80.5077999830246, 79.20573145151138, 78.76482591032982, 78.06332275271416, 78.26256886124611, 81.56839147210121, 76.74160927534103, 78.94992157816887, 68.2879064977169, 58.36478836834431, 59.62740361690521, 58.392458483576775, 57.6355466991663, 57.11178280413151, 58.302076533436775, 65.37356168031693, 70.5201043188572, 69.63027566671371, 71.49979054927826, 66.43170610070229, 62.614734917879105, 60.69930709898472, 58.39622788131237, 60.77916741371155, 62.30183310806751, 62.54216641187668, 65.15870600938797, 66.6731907427311, 66.23485386371613, 66.48124024271965, 71.15575700998306, 60.74558861553669, 65.27744203805923, 67.52667054533958, 65.96826016902924, 66.87236085534096, 64.26834538578987, 65.24292469024658, 62.23747216165066, 65.20225927233696, 65.76271399855614, 54.73140813410282, 59.63561877608299, 60.239691361784935, 54.61309388279915, 61.675075739622116, 59.40693184733391, 63.97291123867035, 66.09920874238014, 62.2343373298645, 58.45286764204502, 62.13710814714432, 67.92988210916519, 66.93041414022446, 61.719039380550385, 58.89957167208195, 63.39177802205086, 54.398967772722244, 49.87591467797756, 64.93324890732765, 63.20186801254749, 57.10540674626827, 64.37576562166214, 58.587133437395096, 58.15927639603615, 60.412335097789764, 61.54474273324013, 61.005756855010986, 60.715167447924614, 60.692786648869514, 58.90965633094311, 57.77816444635391, 61.4398417621851, 62.511198073625565, 60.77750690281391, 59.683120027184486, 55.75896039605141, 55.758667811751366, 52.7730768173933, 53.04883562028408, 56.13496161997318, 56.990166530013084, 63.27911786735058, 66.65669962763786, 63.17484386265278, 63.39291036128998, 61.01329185068607, 53.2316742092371, 53.2925583422184, 54.42949913442135, 55.76230801641941, 52.9856526106596, 54.853993356227875, 53.26304152607918, 54.589500948786736, 52.18003123998642, 60.593862757086754, 67.92571753263474, 71.1665028333664, 70.3718438744545, 71.14213854074478, 68.07447955012321, 65.87942093610764, 60.740952864289284, 64.3829320371151, 71.52041584253311, 73.7015900015831, 74.18316096067429, 73.13119500875473, 73.45252856612206, 70.0321877002716, 65.63874945044518, 71.9827826321125, 58.7251952290535, 28.5482557117939, 2.8418354457244277, 0.06657223479123786, 0.5249611870385706, 1.8698642263188958, 0.7895595137961209, 0.25634475401602685, 0.3674743924057111, 26.852902583777905, 88.3233118057251, 48.058559596538544, 28.60052190721035, 45.79821668565273, 10.88786356151104, 0.3581147821387276, 0.11489720302051865, 0.02211314349551685, 0.01688483371253824, 0.0376010530453641, 0.1361075832392089, 0.01828401585953543, 0.03747394170204643, 0.02604155379231088, 0.06362414962495677, 0.18690524651901796, 0.3668326127808541, 0.16717934719054028, 0.1778801518958062, 0.14177322766045108, 0.14613849576562643, 0.19768978032516316, 0.1552244761842303, 0.19355425145477057, 3.6372816748917103, 80.77821627259254, 60.20070165395737, 48.528814762830734, 46.21189668774605, 65.81040143966675, 13.991748858243227, 1.1015858268365264, 4.540309393778443, 2.0224787620827556, 0.3674091724678874, 2.3870190884917974, 1.6557043930515647, 0.35883220145478845, 6.013089939951897, 91.71032845973969, 93.38273271918297, 92.86098271608353, 85.4928208887577, 86.74260422587395, 84.57892432808876, 86.4765653014183, 81.95326521992683, 75.7399982213974, 75.11025801301003, 73.13424244523048, 80.7118870317936, 81.7805264890194, 89.84294906258583, 84.08941939473152, 84.26283448934555, 82.22862884402275, 81.11588135361671, 81.02637335658073, 82.97240853309631, 78.22869747877121, 81.30388006567955, 69.96367737650871, 60.70550076663494, 61.11174836754799, 61.82201385498047, 61.136431843042374, 62.48003214597702, 58.45062576234341, 66.18319943547249, 72.86470010876656, 72.49190211296082, 73.19932535290718, 69.72796082496643, 66.32691532373428, 64.88168567419052, 60.763113275170326, 64.11304011940956, 65.41399911046028, 65.47210559248924, 69.6050526201725, 69.86593142151833, 69.47975054383278, 70.94319641590118, 73.27116429805756, 65.5685444176197, 67.87870645523071, 69.30644944310188, 68.33465918898582, 68.70099753141403, 68.57100650668144, 67.77342930436134, 66.62222027778625, 69.11524370312691, 72.19822347164154, 57.6843398809433, 59.95617337524891, 64.347343146801, 56.67076326906681, 63.78279983997345, 62.043302580714226, 67.1478308737278, 69.2654724419117, 63.52064810693264, 59.95444066822529, 64.88474830985069, 70.02010434865952, 69.30095493793488, 64.65796127915382, 59.70786809921265, 65.35489708185196, 56.701819002628326, 52.669824957847595, 69.50171336531639, 64.80321988463402, 59.154492393136024, 69.48415070772171, 59.64378073811531, 59.98666673898697, 61.79343938827515, 62.95217581093311, 63.71952183544636, 61.448467299342155, 63.37240286171436, 62.65612989664078, 60.09111933410168, 63.618899434804916, 65.07798314094543, 65.91562539339066, 64.07614409923553, 60.96734091639519, 58.807008638978004, 56.211573109030724, 56.22143357992172, 60.40356136858463, 59.73034009337425, 66.61117047071457, 69.51319634914398, 68.06217581033707, 65.24230912327766, 64.79520231485367, 55.925737246870995, 57.18475788831711, 54.97298017144203, 60.03638707101345, 56.13415606319904, 59.294929057359695, 55.81404983997345, 59.027244821190834, 54.415595680475235, 64.03031095862389, 69.87815916538239, 74.42299649119377, 74.35849875211716, 74.61341947317123, 72.40325286984444, 71.51407778263092, 63.979150503873825, 68.30854699015617, 72.78881058096886, 78.70395317673683, 79.21253308653831, 80.74976339936256, 79.36543688178062, 82.28627935051918, 75.30989930033684, 83.17825108766556, 63.40781316161156, 32.253383696079254, 4.2729386407881975, 0.33493943978101015, 0.8115801634266973, 3.491287096403539, 0.9660824260208756, 0.7207599305547774, 0.5826456542126834, 32.73480646312237, 97.11086466908455, 61.42371542751789, 37.97785632312298, 58.62270712852478, 15.835568569600582, 0.962223851820454, 0.5137994640972465, 0.37845476414076984, 0.27763183519709855, 0.19596922968048602, 0.190775977098383, 0.11486850416986272, 0.11994549931841902, 0.12653496174607426, 0.1563522289507091], [0.0853265737532638, 0.018704284811974503, 0.04519946523942053, 0.08452731781289913, 0.06068248032534029, 0.12027795179164968, 0.1078046609472949, 0.05602039767836686, 0.0763485387142282, 14.36322832480073, 63.07695731520653, 27.694061547517776, 24.553697258234024, 44.9472713470459, 48.51971045136452, 10.738452728837729, 0.4146275168750435, 0.6958251935429871, 0.26685775083024055, 0.1740308990702033, 0.03853418500511907, 0.13564776338171214, 0.11827030131826177, 3.866056236438453, 71.41761615872383, 88.2744312286377, 80.91459855437279, 83.055829256773, 79.48052510619164, 77.87824228405952, 78.06991159915924, 77.9235814511776, 74.12706837058067, 67.33886942267418, 64.57462415099144, 72.06719890236855, 73.49067851901054, 79.17610064148903, 81.23376622796059, 77.07520857453346, 75.09079545736313, 74.94479209184647, 72.79618978500366, 77.95120596885681, 76.35808065533638, 75.55301785469055, 68.8259120285511, 56.8139623850584, 56.26908682286739, 54.893233850598335, 55.39781257510185, 53.535737693309784, 58.45836214721203, 67.27057188749313, 67.50859871506691, 67.8335876762867, 67.42554277181625, 61.51287004351616, 58.969157338142395, 55.13593442738056, 53.80393870174885, 55.993628203868866, 56.81714281439781, 59.42428171634674, 60.967888087034225, 63.48358869552612, 68.00609841942787, 66.15934431552887, 63.52150686085224, 62.48056411743164, 60.135280564427376, 63.16433742642403, 64.28941905498505, 61.48678444325924, 63.157664984464645, 58.53865183889866, 59.07175563275814, 66.12531334161758, 55.73000214993954, 57.59379453957081, 60.76457239687443, 52.55445174872875, 59.005525186657906, 62.5309494137764, 61.08553357422352, 62.971368581056595, 61.4877799898386, 60.45990474522114, 59.96416054666042, 61.16023376584053, 61.76807954907417, 64.10227909684181, 58.80187131464481, 60.13601012527943, 62.148553133010864, 56.59350201487541, 51.252698600292206, 55.24618551135063, 62.163474932312965, 56.70954018831253, 54.50724296271801, 64.9922825396061, 54.89135295152664, 57.33098924160004, 59.88942615687847, 57.62394592165947, 59.31532636284828, 54.82294142246246, 55.12196637690067, 56.58257760107517, 59.86103028059006, 57.89506137371063, 55.27407981455326, 53.812742829322815, 52.45097570121288, 53.09718802571297, 50.52333913743496, 48.91956679522991, 53.943034037947655, 56.30483530461788, 58.99024240672588, 62.094083055853844, 59.8426278680563, 59.186813458800316, 55.8181232213974, 47.22701221704483, 49.26931522786617, 52.99694940447807, 53.718553483486176, 49.80716876685619, 51.93901017308235, 52.12497219443321, 51.525235176086426, 54.47383515536785, 63.33862267434597, 66.56894713640213, 69.36986044049263, 68.22691977024078, 66.2472715973854, 62.06203557550907, 59.66526858508587, 58.29666942358017, 65.33413499593735, 68.41592162847519, 71.62871763110161, 70.01141801476479, 67.93328672647476, 63.00074480473995, 54.623174741864204, 55.57060830295086, 63.32696110010147, 66.74040153622627, 40.08357033133507, 6.695863427594304, 0.18331295490497723, 0.4629381245467812, 1.2165389209985733, 0.49111450323835015, 0.3568270371761173, 0.16824291902594268, 23.37223805487156, 78.84728908538818, 45.879555121064186, 30.597766935825348, 18.33564631640911, 8.667565751820803, 0.4204174265032634, 0.01131653680204181, 0.048529856649111025, 0.04849269360420294, 0.09542013838654384, 0.05715565726859495, 0.05820962200232316, 0.01280217544262996, 0.1261242275359109, 0.08494235647958703, 0.04076107703440357, 0.03266240906668827, 0.04844231661991216, 0.05196735852223355, 0.010020098507084185, 0.052725803761859424, 0.0892758383997716, 0.05802410734759178, 0.037681691101170145, 21.13154958933592, 74.61151197552681, 37.11951658129692, 26.454927138984203, 41.20902054011822, 60.0623244792223, 10.20513329654932, 0.39221741782967, 0.425089038326405, 0.6941176007967442, 0.1454760250635445, 0.15534786565694958, 0.22107069758931175, 0.48203061567619443, 5.020003728568554, 71.51875913143158, 90.40422454476357, 85.12398988008499, 85.92005476355553, 85.9057143330574, 81.39916375279427, 82.6275010406971, 81.54905810952187, 76.81208789348602, 69.81381341814995, 67.80570477247238, 72.78617352247238, 76.99890866875648, 81.27437084913254, 83.17401811480522, 78.28698635101318, 75.45252844691277, 77.42010846734047, 76.32664874196053, 78.19862589240074, 81.30208656191826, 75.61830595135689, 73.10172379016876, 58.9823654294014, 57.75158107280731, 57.69253984093666, 58.707769364118576, 57.554234862327576, 58.6250402033329, 68.59904900193214, 70.18932446837425, 69.47208255529404, 69.34957712888718, 65.66328853368759, 62.96804755926132, 59.616258814930916, 56.342647075653076, 58.322014063596725, 57.00790777802467, 61.737939566373825, 65.38436830043793, 66.14146247506142, 72.04420253634453, 69.37482297420502, 65.17528831958771, 66.70161321759224, 65.17662584781647, 66.05919688940048, 65.90130016207695, 62.706952169537544, 64.85811173915863, 61.220126152038574, 62.422746419906616, 66.59498333930969, 58.85949142277241, 62.490618377923965, 62.539624348282814, 56.19399905204773, 61.72481507062912, 64.26681026816368, 62.30787478387356, 64.57654684782028, 62.17975325882435, 64.69914346933365, 62.89202883839607, 64.042067527771, 63.20555001497269, 64.79652464389801, 58.85676696896553, 61.45062938332558, 62.97344706952572, 59.42293278872967, 56.216368451714516, 53.78650523722172, 65.48442453145981, 60.51721327006817, 56.72570452094078, 65.48839911818504, 56.219841465353966, 60.066926032304764, 62.4933922290802, 59.56708945333958, 62.21252270042896, 57.82044477760792, 56.519930362701416, 58.62490341067314, 62.47537359595299, 60.04058584570885, 59.934389144182205, 57.08397589623928, 54.8994655162096, 54.60132971405983, 52.7214489877224, 53.22362624108791, 54.76938709616661, 59.17885288596153, 61.056256145238876, 63.66714544594288, 63.07432785630226, 62.25900560617447, 59.26099307835102, 51.02700971066952, 52.72954635322094, 54.44252483546734, 54.1939801722765, 52.79426068067551, 54.00886170566082, 53.828170001506805, 54.909869357943535, 56.49714678525925, 66.94822758436203, 68.3295750617981, 71.71099081635475, 69.23377454280853, 69.4317439198494, 64.43273216485977, 63.148610070347786, 60.93136064708233, 66.99172765016556, 71.1256854236126, 75.13828530907631, 74.59228500723839, 71.43596157431602, 70.02973303198814, 64.95129033923149, 66.67192921042442, 69.17857870459557, 68.26815515756607, 44.54711101949215, 9.830592144280672, 0.31928223150316626, 0.6202172068879008, 2.395520182326436, 0.4067696869606152, 0.4392131476197392, 0.1609885590733029, 28.126204758882523, 88.168014138937, 55.974606424570084, 32.35759690403938, 25.859174206852913, 15.049116220325232, 0.8131897926796228, 0.1297313324175775, 0.025823416181083303, 0.009104417222260963, 0.043984851508866996, 0.03100291305599967, 0.017587526963325217, 0.05761150663602166, 0.14835413312539458, 0.1013094512745738, 0.17527732125017792, 0.1606355787953362, 0.21854657912626863, 0.1732901911600493, 0.1278574689058587, 0.1931462631910108, 0.2984493150142953, 0.11603856677538715, 0.1507630554260686, 23.092436268925667, 94.55565378069878, 43.998956233263016, 37.52301312983036, 57.36073784530163, 72.01072633266449, 13.052271120250225, 0.8315732062328607, 1.835335954092443, 1.6669473960064352, 0.33687792951241136, 0.21791922685224563, 0.502421212149784, 0.7639840361662209, 6.56155725941062, 77.68795609474182, 97.99117103219032, 93.51081624627113, 93.99891525506973, 91.34794190526009, 87.29162156581879, 87.42231175303459, 86.4955186843872, 84.21621099114418, 75.49751803278923, 72.14722260832787, 78.95072713494301, 82.27092817425728, 87.24733114242554, 87.91529729962349, 82.60849446058273, 79.22960177063942, 80.37869811058044, 76.79729148745537, 81.80967852473259, 81.19886130094528, 79.69224214553833, 74.52368348836899, 61.85682758688927, 59.14522089064121, 60.83114482462406, 60.66052258014679, 60.643358901143074, 61.71721167862415, 72.4925708770752, 71.69198423624039, 73.92213016748428, 72.34522998332977, 68.02681490778923, 66.3741771876812, 61.55499838292599, 61.63162127137184, 62.94635832309723, 62.11323782801628, 65.11035740375519, 68.5130824148655, 69.83404353260994, 77.06475153565407, 74.5687186717987, 70.67827463150024, 67.83686310052872, 67.44723200798035, 70.8485434949398, 68.70269984006882, 64.68360990285873, 68.8031892478466, 63.9965383708477, 62.62226991355419, 73.5599336028099, 62.438386380672455, 65.3911167383194, 64.85081613063812, 58.769630044698715, 63.25203292071819, 67.28087693452835, 63.57003405690193, 68.8897942006588, 64.81600999832153, 64.70523074269295, 65.55288925766945, 67.70923554897308, 67.19332203269005, 70.03314524888992, 60.02767413854599, 64.18644458055496, 66.03124558925629, 61.28402352333069, 58.02659131586552, 59.75827619433403, 67.25441515445709, 61.42457418143749, 59.35344971716404, 69.99287500977516, 59.16572839021683, 62.01904848217964, 64.87634316086769, 63.16888578236103, 61.395866721868515, 59.90482673048973, 58.041501715779305, 59.97505076229572, 64.96970415115356, 64.21590819954872, 62.502751126885414, 60.173020139336586, 57.376351207494736, 59.175391271710396, 57.21956022083759, 56.5146866440773, 57.372790798544884, 62.02062539756298, 62.021305561065674, 65.88597938418388, 65.19153624773026, 63.67351770401001, 62.162008211016655, 55.12860842049122, 54.54937890172005, 57.596484795212746, 57.7702646702528, 55.24441860616207, 56.44276410341263, 57.32673726975918, 57.20930077135563, 59.3932031840086, 70.11333614587784, 70.13864278793335, 76.66660889983177, 73.25371563434601, 72.63073146343231, 68.65673750638962, 69.22008767724037, 65.66591799259186, 71.00296720862389, 74.58470821380615, 80.05430951714516, 77.83503100275993, 79.79181200265884, 79.71121832728386, 76.68905809521675, 77.85945609211922, 80.03857836127281, 73.804412484169, 48.11432160437107, 11.358073130249977, 0.4285416874336079, 0.9563262714073062, 4.281590776517987, 0.852793405065313, 0.9704694687388837, 0.37535531795583665, 34.92172971367836, 97.71616458892822, 66.00178956985474, 44.676619470119476, 39.820533245801926, 32.32229679822922, 1.2095030047930777, 0.235206785146147, 0.16595913766650483, 0.13760915579041466, 0.1738312910310924, 0.2245976950507611, 0.15083784906892106, 0.27521445241291076, 0.3225596447009593, 0.3439267590874806], [0.31929084041621536, 0.037566784376394935, 0.03662251649075188, 0.02376142751018051, 0.047663885343354195, 0.046529278843081556, 0.04664620049879886, 0.0826613581739366, 0.37895470450166613, 31.984031349420547, 54.198034554719925, 25.517336949706078, 46.09009422361851, 34.32693623006344, 50.04241794347763, 9.190928768366575, 0.3551977261668071, 0.4099000064888969, 0.18695422826567665, 0.38944870233535767, 0.16005072189727798, 0.29604701267089695, 0.15011991024948657, 2.0448227506130934, 63.756512850522995, 90.41447639465332, 80.21606683731079, 83.89638975262642, 80.00883355736732, 81.22035294771194, 79.72568035125732, 79.43250328302383, 78.31645756959915, 74.59119826555252, 65.43364405632019, 66.8583320081234, 68.04082095623016, 77.30803728103638, 75.71162894368172, 77.55975857377052, 66.51742950081825, 67.49159082770348, 76.2022054195404, 76.71468392014503, 76.42964601516724, 73.58852326869965, 71.56046569347382, 58.87536697089672, 55.67861370742321, 54.36077982187271, 54.546779841184616, 54.79052156209946, 61.172191724181175, 67.07673668861389, 64.6906167268753, 67.62720555067062, 65.16805350780487, 63.328936994075775, 59.69560995697975, 54.32207129895687, 55.68888835608959, 57.203243896365166, 59.19089823961258, 59.396467208862305, 62.46441878378391, 63.529999405145645, 62.97386884689331, 62.93894112110138, 62.15896837413311, 59.52004797756672, 64.30515021085739, 63.49458910524845, 60.42002588510513, 64.29496675729752, 58.98904927074909, 61.96286469697952, 64.53177765011787, 61.3765599578619, 57.765032351017, 64.46584358811378, 52.28811264038086, 53.865841180086136, 64.83443140983582, 66.49593025445938, 63.92469182610512, 59.70766291022301, 58.33686746656895, 59.224226251244545, 61.50118947029114, 57.42376506328583, 56.60184636712074, 55.14772139489651, 58.42058077454567, 61.17951773107052, 60.34394256770611, 58.84827822446823, 58.21307010948658, 52.605809792876244, 55.23482792079449, 60.41951671242714, 57.17299371957779, 60.63784159719944, 54.512623474001884, 56.62886671721935, 58.158664628863335, 60.43355315923691, 61.727493926882744, 55.10699898004532, 53.858233988285065, 58.597902059555054, 58.13741996884346, 56.45372651517391, 57.403379157185555, 53.54313589632511, 52.192760556936264, 49.98445205390453, 48.72440166771412, 53.029331266880035, 54.85983744263649, 57.037458792328835, 60.00478036701679, 58.518239334225655, 59.44467142224312, 58.41860868036747, 52.864138931035995, 47.34108209609985, 50.00836797058582, 48.982134237885475, 48.94602857530117, 50.162723287940025, 52.00869083404541, 51.75218179821968, 51.38704799115658, 59.67323295772076, 66.06235831975937, 67.81461149454117, 66.54307052493095, 69.12182494997978, 64.23890456557274, 61.29536211490631, 55.14360621571541, 61.42594210803509, 66.252750903368, 68.45918610692024, 70.93098387122154, 69.74266603589058, 64.95482414960861, 59.63493101298809, 51.37691393494606, 50.95254510641098, 59.424756690859795, 70.91662064194679, 54.65227358043194, 18.378834798932076, 0.4396862519206479, 0.6541481986641884, 1.4299703808501363, 0.16042240429669619, 0.40191054926253855, 0.4123519139830023, 19.444926492869854, 75.2244570851326, 46.66726045310497, 36.653330996632576, 16.77080098539591, 8.498885203152895, 2.687441180460155, 0.17350486479699612, 0.08920664055040106, 0.028330916102277115, 0.022799053076596465, 0.06609357180423103, 0.13388247607508674, 0.2540843503084034, 1.0602717124857008, 1.0891024279408157, 0.015740792659926228, 0.044327345240162686, 0.03715749364346266, 0.03560722136171535, 0.045006755462964065, 0.01398350663293968, 0.016034098698582966, 0.07390150713035837, 0.47558366786688566, 46.83188281953335, 60.38704365491867, 38.5350052267313, 42.92309336364269, 35.47690652310848, 60.288089364767075, 9.561169501394033, 0.29020334186498076, 0.22067219397285953, 0.28676794026978314, 0.24239754304289818, 0.32679068797733635, 0.14603805349906906, 0.27466380852274597, 3.2311333436518908, 66.67420908808708, 96.00390046834946, 85.47927841544151, 90.62134489417076, 83.10262754559517, 86.4176532626152, 82.99915909767151, 84.41830694675446, 83.07973757386208, 77.86093801259995, 69.55953106284142, 68.54088932275772, 72.53534138202667, 79.20156687498093, 77.45789363980293, 79.72282290458679, 68.43661531805992, 70.25501534342766, 77.67561435699463, 80.65834790468216, 77.19913512468338, 77.72642523050308, 73.50400820374489, 60.77393889427185, 58.07691961526871, 55.92109389603138, 56.070813462138176, 57.016810700297356, 61.917092353105545, 68.02582696080208, 69.33642983436584, 70.30535504221916, 67.88293942809105, 64.74510580301285, 61.766905412077904, 56.773574352264404, 56.3196887075901, 58.382476419210434, 61.87930338084698, 62.89309658110142, 63.2000707089901, 68.53689193725586, 66.62326902151108, 66.19721308350563, 66.75627708435059, 62.20572866499424, 67.65941262245178, 64.20947134494781, 63.152356669306755, 66.25506117939949, 62.71614387631416, 62.450040355324745, 66.88529536128044, 62.981316447257996, 61.44462950527668, 68.50997418165207, 55.12914039194584, 58.128942623734474, 66.28262490034103, 67.70563334226608, 63.66446278989315, 61.52138538658619, 60.43922245502472, 62.6739015430212, 63.838276863098145, 59.77663680911064, 58.17789539694786, 59.27660644054413, 58.99631068110466, 64.9273744225502, 62.36859552562237, 62.71944969892502, 59.90310542285442, 56.764185056090355, 53.84001776576042, 62.94880159199238, 59.185407534241676, 62.107530534267426, 57.46789589524269, 56.49239704012871, 60.630830973386765, 60.662198290228844, 62.42347978055477, 58.878019228577614, 56.210630759596825, 58.20985548198223, 62.520743161439896, 60.0304251909256, 60.55785968899727, 56.02145031094551, 52.89903245866299, 53.97601246833801, 52.78148956596851, 54.393781051039696, 57.78591603040695, 59.27964627742767, 63.44792000949383, 61.74561895430088, 61.65177159011364, 60.55044248700142, 53.3048202842474, 49.34056520462036, 52.623209059238434, 53.40834952890873, 51.76408275961876, 53.07468943297863, 52.75072641670704, 53.92421744763851, 53.35201375186443, 62.51742213964462, 66.91813319921494, 69.64687317609787, 69.10784929990768, 72.1799236536026, 68.26411977410316, 64.75338935852051, 57.40781731903553, 62.84518115222454, 69.52738478779793, 71.1504676938057, 73.2369813323021, 74.30581077933311, 72.96595707535744, 67.75753855705261, 63.420375287532806, 63.380481228232384, 68.61376941204071, 74.53423172235489, 55.901076570153236, 22.094359025359154, 1.0991194029338658, 0.3917630750220269, 2.48081230558455, 0.19956196658313274, 0.41771084361243993, 0.5430699465796351, 23.336227387189865, 87.08732172846794, 58.03202882409096, 43.01081545650959, 30.916254445910454, 13.158991243690252, 4.643322341144085, 0.09848042886005715, 0.005158999683771981, 0.035173584474250674, 0.061388630128931254, 0.04375862634333316, 0.11070792039390653, 0.08176609801012091, 0.27304521412588656, 0.06482264390797354, 0.6953556812368333, 0.16817395866382867, 0.12186647436465137, 0.07529657406848855, 0.10614327431540005, 0.13604553969344124, 0.24741492146858945, 0.1814147489494644, 0.712902070954442, 56.22988432645798, 73.8135015964508, 42.685066536068916, 61.39141336083412, 46.216885820031166, 71.15877404808998, 12.46995996683836, 0.4678801749832928, 1.236296792048961, 1.1866108956746757, 0.4816697834758088, 0.7913149602245539, 0.6889207859057933, 0.5108374042902142, 4.647414721548557, 74.05646055936813, 101.37093767523766, 92.93300405144691, 94.85095113515854, 91.21681094169617, 92.82708093523979, 90.4221747815609, 88.4925851225853, 88.22865128517151, 84.07425820827484, 73.8621997833252, 73.18187668919563, 75.22473067045212, 84.74585697054863, 82.93136313557625, 84.51579451560974, 71.74904957413673, 72.30981588363647, 81.08736768364906, 83.94734501838684, 79.1777877509594, 79.06109601259232, 75.86140170693398, 65.5175131559372, 61.11286550760269, 61.02932699024677, 57.55938358604908, 60.7778412848711, 65.30993789434433, 71.98917388916016, 72.2077913582325, 74.32385221123695, 69.39664140343666, 68.2011267542839, 65.40210574865341, 60.56418254971504, 61.93391025066376, 63.794989585876465, 66.76791206002235, 67.0279549062252, 68.31423908472061, 71.52385845780373, 68.26099634170532, 70.46031832695007, 68.17167073488235, 67.05657497048378, 70.73948934674263, 69.29964780807495, 67.56624922156334, 70.06929650902748, 63.88458877801895, 64.55170378088951, 68.99968430399895, 66.32725730538368, 65.20358920097351, 71.10091835260391, 58.96147795021534, 60.01656733453274, 69.95076566934586, 71.90573036670685, 66.74240782856941, 63.49506787955761, 64.1011543571949, 67.137541025877, 66.56081557273865, 62.16770030558109, 59.471148401498795, 62.30964928865433, 64.28379535675049, 65.78014746308327, 63.51297251880169, 66.08600065112114, 63.74415211379528, 60.70047743618488, 58.84617693722248, 65.64816534519196, 60.255221128463745, 65.05944773554802, 60.29491759836674, 60.99412187933922, 61.94416590034962, 63.84251743555069, 63.76748666167259, 61.98573186993599, 57.921602949500084, 62.64713577926159, 66.00365146994591, 61.61073759198189, 64.66645762324333, 59.25017885863781, 56.362121030688286, 57.29850858449936, 57.11907461285591, 59.627791196107864, 62.98922762274742, 62.67051212489605, 65.91352790594101, 64.98077675700188, 65.01669242978096, 62.436353489756584, 57.70647369325161, 52.7508670091629, 55.23280642926693, 57.13925153017044, 55.17711661756039, 56.955968365073204, 57.06491231918335, 57.31846131384373, 57.34298139810562, 65.87916254997253, 71.28537565469742, 73.46634462475777, 71.29502713680267, 76.18497714400291, 71.9460842013359, 68.31323593854904, 62.157634645700455, 67.88594886660576, 72.32546344399452, 74.06428813934326, 79.05463635921478, 78.0726170539856, 80.54859459400177, 77.12409675121307, 74.58201795816422, 73.33626240491867, 79.36252623796463, 81.2182554602623, 62.906437665224075, 24.500188529491425, 1.463535523507744, 1.0467605874873698, 4.04144081287086, 0.42042662913445383, 0.9022107033524662, 0.8558268297929317, 27.694008350372314, 97.18933805823326, 66.6217415034771, 58.47032770514488, 47.41899311542511, 36.593013033270836, 6.5472334530204535, 0.2725823811488226, 0.17345056927297264, 0.14775989548070356, 0.1542351784883067, 0.1302240591030568, 0.29072581382934004, 0.8492147095967084, 1.758578410372138, 2.2004659613594413], [3.0027264123782516, 0.7270656921900809, 0.04475942732824478, 0.047702569790999405, 0.09823966873227619, 0.11660092175588943, 0.2162993559613824, 0.1676148988190107, 5.07138267159462, 56.03041023015976, 47.23103620111942, 16.041357927024364, 29.339251667261124, 45.267081186175346, 53.73012766242027, 13.517541904002428, 0.8953415032010525, 0.598015176365152, 0.3984178835526109, 0.19728784798644483, 0.10896666382905096, 0.49913634778931737, 0.04214097076328471, 3.63489659037441, 60.29088221490383, 81.6816557943821, 80.93265518546104, 81.70571610331535, 78.8691683113575, 80.35801202058792, 80.0065004825592, 82.91034266352654, 78.96364644169807, 77.81586483120918, 69.10358592867851, 65.3183202445507, 64.28936585783958, 70.60068279504776, 71.20982050895691, 66.24499931931496, 58.85388672351837, 66.17348715662956, 71.59017249941826, 77.2545437514782, 72.88397267460823, 74.54892933368683, 73.4560775756836, 60.8160824328661, 55.25101885199547, 54.01711106300354, 55.557951182127, 56.17011733353138, 63.08925725519657, 65.47211319208145, 65.30271828174591, 65.31086504459381, 60.58945879340172, 60.74340373277664, 55.59680409729481, 54.17718127369881, 52.25987635552883, 56.1208263784647, 58.21118921041489, 58.96827578544617, 59.567929208278656, 63.13630633056164, 63.458088263869286, 61.59828186035156, 58.1185881793499, 59.318244606256485, 61.53185002505779, 61.7421193420887, 65.95471769571304, 60.16258969902992, 64.01281669735909, 55.39701461791992, 61.36785842478275, 58.075065314769745, 62.20317140221596, 60.81912226974964, 48.63232120871544, 59.68205228447914, 65.10300859808922, 61.99018523097038, 59.18213210999966, 56.869352012872696, 55.18755845725536, 55.2698278427124, 55.18275551497936, 55.87888956069946, 53.65338698029518, 55.468492582440376, 53.87982062995434, 60.20238496363163, 59.156396090984344, 60.71576401591301, 55.353609547019005, 58.83733481168747, 54.335564374923706, 55.839804857969284, 59.00193817913532, 57.70962372422218, 56.593616008758545, 57.5918984413147, 61.9143982976675, 56.46165668964386, 55.49925193190575, 55.933120250701904, 54.65765029191971, 57.76909813284874, 58.951131105422974, 57.96007588505745, 55.704927295446396, 50.830507054924965, 49.648447483778, 52.11802996695042, 49.85516399145126, 50.701424181461334, 54.532621800899506, 56.62201948463917, 57.32912354171276, 58.40890400111675, 58.33544634282589, 55.37447802722454, 47.689287811517715, 47.35555171966553, 48.48827853798866, 48.72847504913807, 48.831229135394096, 49.856227934360504, 48.33462618291378, 48.825689032673836, 53.474082201719284, 64.09838050603867, 66.29410788416862, 67.64728367328644, 68.30414682626724, 67.09135830402374, 62.06629894673824, 58.16534847021103, 54.25384595990181, 61.199607253074646, 67.36665353178978, 68.93444940447807, 72.5472803413868, 66.17125287652016, 62.44418866932392, 53.915781900286674, 49.19454284012318, 46.66917935013771, 57.54483036696911, 69.28957834839821, 65.59510499238968, 37.7422309666872, 2.3050403874367476, 0.3299877711106092, 1.0486906464211643, 0.13167583354515955, 0.45571871974971145, 0.2278457340435125, 21.61173552274704, 77.85141572356224, 50.20105563104153, 39.85441602766514, 10.714226178824902, 4.682839745655656, 11.032344158738852, 1.1242143251001835, 0.22458224353613332, 0.1114601687004324, 0.024989214361994527, 0.15124733647098765, 1.2342895497567952, 2.2523310407996178, 5.2177047450095415, 4.345794031396508, 0.8632963977288455, 0.05737911051255651, 0.056632714040460996, 0.05663912990712561, 0.08984125845017843, 0.06426579566323198, 0.22176203783601522, 0.23896641621831805, 9.357491880655289, 69.03326690196991, 58.04352320730686, 30.52807677537203, 37.6078549772501, 47.136041298508644, 68.5989198088646, 15.89117668569088, 0.9607142047025263, 0.7616479333955795, 0.513958343071863, 0.25957570876926184, 0.0831289186317008, 0.558744699228555, 0.052485433261608705, 4.642142029479146, 61.20159454643726, 91.52467042207718, 86.53236910700798, 87.73676007986069, 83.34009200334549, 84.22226026654243, 82.15057343244553, 87.78507828712463, 82.66989916563034, 82.56300330162048, 72.41767689585686, 69.31571334600449, 67.636788636446, 74.02100086212158, 74.84830006957054, 69.12636190652847, 62.003153935074806, 67.9643614590168, 72.66072705388069, 79.40934732556343, 72.34221294522285, 75.15248894691467, 75.50356730818748, 62.02463038265705, 57.73470237851143, 57.52377949655056, 55.82936681807041, 59.47452262043953, 65.51274061203003, 69.31634411215782, 67.88291662931442, 66.69923454523087, 64.92013961076736, 63.10512900352478, 58.059501349925995, 55.600265711545944, 55.682383105158806, 58.8305027782917, 61.628083661198616, 59.62991148233414, 61.601276099681854, 65.406893491745, 66.45167782902718, 66.83690875768661, 60.939359217882156, 62.233474776148796, 63.270222544670105, 64.6398438513279, 68.39485555887222, 62.400141432881355, 67.1799011528492, 57.68565081059933, 63.104403242468834, 60.41241109371185, 64.90712910890579, 62.840374410152435, 52.44165480136871, 62.2555173933506, 67.67132878303528, 63.71502287685871, 60.55751010775566, 56.986495926976204, 55.85524722933769, 57.95541353523731, 56.3496159017086, 57.03512951731682, 57.092400044202805, 57.433503940701485, 56.215441301465034, 61.584443002939224, 60.10503798723221, 64.63508650660515, 58.32414574921131, 60.22020220756531, 58.23157511651516, 57.99629934132099, 62.494570165872574, 61.544894725084305, 58.12341012060642, 57.206895500421524, 61.87646113336086, 59.19423446059227, 57.778278440237045, 61.15957260131836, 55.498822554945946, 59.09478239715099, 60.90693175792694, 60.20231656730175, 57.300537675619125, 54.68670353293419, 52.756973281502724, 54.72780592739582, 52.63906180858612, 54.94478948414326, 57.84439109265804, 58.76460291445255, 60.26268772780895, 61.229146867990494, 61.64417579770088, 56.09725244343281, 49.30255584418774, 50.956219509243965, 50.850539579987526, 51.312226206064224, 50.43085590004921, 54.08559858798981, 49.519429206848145, 52.49057337641716, 57.28937767446041, 65.56110441684723, 68.65625113248825, 70.50780057907104, 69.03487041592598, 69.54031929373741, 64.86605331301689, 59.6180485188961, 57.706838473677635, 63.6601310223341, 70.46285659074783, 71.21720731258392, 74.06057193875313, 69.42117288708687, 69.97174814343452, 63.9287044107914, 61.10718861222267, 59.449094384908676, 65.91990396380424, 73.48440885543823, 67.12196186184883, 41.24282732605934, 3.7708062725141644, 0.473881121724844, 1.7560997558757663, 0.2117513117264025, 0.7657216116786003, 0.33192664675880224, 26.331754848361015, 88.35234984755516, 61.483068242669106, 49.40041959285736, 20.196668654680252, 17.608574330806732, 11.047070268541574, 1.4003355335444212, 0.2749172964831814, 0.041384514479432255, 0.050930066136061214, 0.029953017146908678, 0.44590004661586136, 1.4416092750616372, 2.2138490807265043, 1.437868969514966, 3.881486733444035, 1.145843358244747, 0.1925696589751169, 0.18553132336819544, 0.2574521867791191, 0.22123186237877235, 0.46388088958337903, 0.3860377619275823, 11.59825349226594, 79.17978644371033, 74.55815523862839, 29.101511724293232, 42.778362929821014, 62.433309853076935, 75.5385710299015, 18.10764905065298, 1.473410481121391, 1.5308071137405932, 0.8584191813133657, 0.7522452191915363, 0.14415080164326355, 1.2514446792192757, 0.20828592736506835, 6.339104846119881, 66.70923560857773, 98.10411617159843, 94.96705010533333, 94.88754317164421, 88.66645619273186, 89.51295956969261, 90.04605576395988, 95.18138140439987, 88.03711876273155, 87.59566605091095, 75.31701251864433, 72.91051805019379, 70.5511562526226, 78.14450159668922, 78.01425218582153, 71.79406195878983, 62.65076458454132, 71.9440247118473, 76.21809616684914, 82.60053768754005, 74.85622644424438, 78.8855454325676, 79.37637269496918, 66.13985136151314, 60.1593978703022, 59.43809777498245, 60.124063566327095, 62.115042731165886, 67.78835490345955, 72.97731086611748, 71.28048151731491, 71.57329380512238, 67.21994340419769, 67.57601469755173, 63.128938525915146, 57.830210253596306, 58.43060463666916, 61.24908059835434, 65.3863137960434, 64.75906625390053, 64.09125208854675, 69.37726244330406, 68.26262265443802, 68.23468655347824, 64.59284037351608, 65.6882455945015, 65.41599780321121, 70.13529136776924, 71.01085558533669, 65.30966430902481, 69.0371122956276, 60.55547721683979, 68.388661891222, 65.2992756664753, 66.77745714783669, 66.53255268931389, 55.225632414221764, 65.01305982470512, 69.4518980383873, 66.92985936999321, 62.069969549775124, 60.61725810170174, 59.682466462254524, 61.00189246237278, 58.88526163995266, 62.80128590762615, 58.787766471505165, 63.18408116698265, 57.55299612879753, 66.14562705159187, 62.92475648224354, 65.94657093286514, 61.24072104692459, 63.50950710475445, 60.027199164032936, 60.556681752204895, 63.20965379476547, 64.22368258237839, 60.70712327957153, 60.72676442563534, 67.26877838373184, 62.8475446254015, 63.316511660814285, 61.830722987651825, 57.406688779592514, 62.32957161962986, 63.45914840698242, 63.66478197276592, 60.14061167836189, 56.90567046403885, 56.6110684722662, 59.84736241400242, 55.186171531677246, 57.9129584133625, 60.75986444950104, 65.25575280189514, 62.198254466056824, 63.49203944206238, 64.16474014520645, 61.265841498970985, 52.306116074323654, 55.08514255285263, 54.00718979537487, 55.154656022787094, 53.91012780368328, 56.51427626609802, 52.08151772618294, 54.25072632730007, 57.13229030370712, 69.17401134967804, 72.61196047067642, 73.24521169066429, 72.07927465438843, 73.1387186050415, 69.40196871757507, 64.47861090302467, 60.76587572693825, 69.07529264688492, 75.07421314716339, 76.11163347959518, 79.02359962463379, 76.99910625815392, 79.06774565577507, 74.40984919667244, 75.7155579328537, 72.02863857150078, 78.08667629957199, 82.4153508245945, 73.94791558384895, 45.165197253227234, 4.451435962691903, 0.9350770991295576, 3.369641611352563, 0.3732521604979411, 0.980237735202536, 0.6270058988593519, 32.97870397567749, 98.16864430904388, 71.69515326619148, 65.71701005101204, 33.05060751736164, 38.13541866838932, 13.986230604350567, 2.2256020875647664, 0.45798719802405685, 0.2483134248177521, 0.19437877752352506, 0.2979042223887518, 3.1242536287754774, 5.829522740095854, 6.223919251933694, 6.437758002430201], [9.110515583306551, 4.076421735808253, 0.23003616806818172, 0.09706963581265882, 0.050853123975684866, 0.11170420912094414, 0.07032964684185572, 0.12272348423721269, 23.237974159419537, 56.272483840584755, 29.22873269766569, 12.323351483792067, 42.85321891307831, 42.99012176692486, 54.072124511003494, 21.47534754127264, 0.7558386982418597, 0.7202985521871597, 0.9367409942205995, 1.3594530522823334, 0.2696340956026688, 0.9662118565756828, 0.14737860969034955, 6.063043009489775, 71.35047376155853, 62.019933834671974, 85.60147225856781, 85.02945855259895, 83.96330416202545, 78.84405165910721, 79.6793532371521, 78.9532122015953, 79.66600835323334, 78.16499009728432, 72.108403891325, 70.93886464834213, 62.5938930362463, 66.19171857833862, 63.63930433988571, 64.46221858263016, 57.978379502892494, 64.03914168477058, 72.80012637376785, 76.82748466730118, 74.67816799879074, 72.19753190875053, 72.55198448896408, 59.891497045755386, 54.217364117503166, 54.475286677479744, 51.98229745030403, 56.74412213265896, 61.15434028208256, 60.83677612245083, 62.90131933987141, 63.207590505480766, 58.55351664125919, 54.14807103574276, 52.97972492873669, 51.42158433794975, 53.49489368498325, 54.67515215277672, 55.20124912261963, 57.0946229249239, 58.71720425784588, 62.83347398042679, 63.250809386372566, 63.74620780348778, 57.59812630712986, 58.79742935299873, 62.09727868437767, 63.190601617097855, 60.31904250383377, 61.862493082880974, 62.749103307724, 57.243468537926674, 60.35514436662197, 55.820433497428894, 65.49915254116058, 54.24198679625988, 53.94107334315777, 63.755980879068375, 61.103958785533905, 62.5944098085165, 56.09575912356377, 55.28713211417198, 54.37583081424236, 55.13740874826908, 57.06466533243656, 58.809676095843315, 56.97108395397663, 55.758702009916306, 57.482570707798004, 52.99137510359287, 57.40977801382542, 60.082440599799156, 56.228166818618774, 55.97511939704418, 60.14590859413147, 56.56221069395542, 56.6359381377697, 59.66689869761467, 55.42671762406826, 53.73790204524994, 56.89813546836376, 57.505905255675316, 55.0665919482708, 53.2243026047945, 51.77300468087196, 58.135615065693855, 57.411696910858154, 57.353214249014854, 55.13889826834202, 53.259986490011215, 50.85336662828922, 50.94257444143295, 51.45959749817848, 54.9813549220562, 54.45609010756016, 55.86894549429417, 59.20119568705559, 58.02348308265209, 53.77569101750851, 48.97746428847313, 48.855418637394905, 49.85367827117443, 47.613808661699295, 51.090557500720024, 47.22719460725784, 50.72958447039127, 50.61669632792473, 55.905252546072006, 62.296604588627815, 63.45239996910095, 65.19424170255661, 67.51286968588829, 67.36551359295845, 64.8526020348072, 61.780816465616226, 58.109107688069344, 57.27173902094364, 63.17607119679451, 67.33629316091537, 69.30501312017441, 70.06272286176682, 65.11804819107056, 61.224131137132645, 51.36498637497425, 48.73032554984093, 43.8778605312109, 52.80996523797512, 61.87396466732025, 69.39817652106285, 47.204350233078, 14.614789076149464, 0.31654287537094206, 0.7711666007526219, 0.09886834202916361, 0.2607808675384149, 0.6654518202412874, 20.688305273652077, 74.17234674096107, 54.90822784602642, 38.43873739242554, 12.505203075706959, 8.434178475290537, 18.375886157155037, 3.0590648017823696, 0.38030113850254565, 0.059051009666291066, 0.1679894162225537, 0.7329591165762395, 2.9339261166751385, 5.394782368093729, 11.219214331358671, 11.424591410905123, 4.423486087471247, 1.2754136743023992, 0.10626009578118101, 0.13710399070987478, 0.019426617145654745, 0.10280087124556303, 0.13389788306085393, 0.19834477017866448, 33.47028739750385, 64.45132076740265, 42.415676191449165, 15.74994396418333, 40.27160704135895, 49.52542908489704, 66.20217561721802, 23.85019350796938, 0.5861664027906954, 0.8583799959160388, 1.3334457040764391, 3.2138611329719424, 0.2847130224108696, 0.5880957492627203, 0.27080327505245805, 6.819786177948117, 75.49917474389076, 73.71189504861832, 83.52419212460518, 88.6880162358284, 85.87112098932266, 83.024792522192, 80.65900906920433, 83.48315432667732, 81.40377670526505, 81.3676406443119, 75.01206368207932, 75.27881696820259, 66.83133825659752, 70.78416734933853, 67.96501502394676, 66.2771075963974, 59.93084393441677, 66.10420167446136, 73.76261472702026, 79.10448208451271, 76.77860409021378, 73.7249131500721, 74.31896567344666, 62.79644496738911, 56.78176291286945, 56.25286169350147, 54.70008261501789, 59.24892872571945, 62.5590755045414, 64.51001241803169, 66.34564831852913, 65.2431982755661, 59.99345317482948, 58.478554263710976, 55.51229663193226, 53.56634125113487, 54.290825575590134, 56.05070874094963, 57.55412086844444, 59.12668168544769, 62.773710787296295, 64.96102541685104, 66.01480007171631, 66.27598285675049, 59.67445649206638, 60.4832848906517, 65.17162531614304, 63.726182878017426, 61.0527603328228, 65.48633962869644, 64.38491553068161, 58.756433352828026, 62.587938755750656, 58.911206647753716, 66.29457145929337, 56.07667274773121, 55.9143340587616, 66.36995181441307, 63.03195632994175, 64.14704829454422, 57.30302274227142, 59.41954717040062, 56.76553398370743, 59.84596788883209, 61.10572189092636, 60.3819215297699, 59.74188007414341, 58.956158235669136, 59.9035158008337, 56.148048117756844, 61.44617602229118, 60.92205114662647, 58.63915264606476, 58.65651771426201, 61.25636860728264, 61.03439971804619, 59.42943423986435, 61.18744410574436, 58.95581245422363, 56.926124766469, 59.28460881114006, 60.42159140110016, 58.39343123137951, 54.576235860586166, 53.019041419029236, 60.37509709596634, 57.574214190244675, 60.21337017416954, 55.30186392366886, 57.06857152283192, 53.89993295073509, 54.55729007720947, 53.64357590675354, 56.145107075572014, 56.374048590660095, 58.47955361008644, 60.03878854215145, 60.28258726000786, 55.55258587002754, 52.028168588876724, 51.4608134329319, 52.94833481311798, 51.41422413289547, 53.08526046574116, 49.45821829140186, 52.44768887758255, 54.842434376478195, 59.982521161437035, 67.26698487997055, 66.34418159723282, 68.82927864789963, 72.15061202645302, 68.75316113233566, 67.69529789686203, 63.31994287669659, 59.63398486375809, 58.39784279465675, 65.03928601741791, 71.04204431176186, 71.48090556263924, 74.04679387807846, 70.74843406677246, 70.15207126736641, 62.17528469860554, 62.13310316205025, 55.125690177083015, 65.41282877326012, 69.96176227927208, 72.71873474121094, 50.97471311688423, 16.76214884966612, 0.7633370021358132, 1.3968162098899484, 0.2428564426372759, 0.34419989911839366, 0.8593694865703583, 25.261215493083, 83.88398721814156, 66.63482040166855, 51.65389247238636, 27.510121017694473, 24.067486748099327, 20.09356688708067, 5.631527714431286, 0.6748977571260184, 0.18752563744783401, 0.28921376215294003, 0.9236327069811523, 3.4459172934293747, 5.0780427642166615, 7.043882953003049, 6.560270078480244, 10.988711100071669, 6.329529359936714, 0.4409683565609157, 0.25868296448607, 0.24558815464843065, 0.20887180842692032, 0.2215773321222514, 0.3019709838554263, 40.42573817074299, 78.2773120701313, 53.279726430773735, 22.790912948548794, 62.32230260968208, 61.11648291349411, 75.75662612915039, 28.752126172184944, 0.7799091597553343, 1.4541230723261833, 2.3625419894233346, 5.708285495638847, 0.7708108448423445, 1.065882823895663, 0.47664701705798507, 9.713984001427889, 82.8470228612423, 78.34699273109436, 85.2220170199871, 95.99522173404694, 91.76632985472679, 91.2016573548317, 85.09014129638672, 86.62602648139, 86.84671863913536, 87.43000254034996, 78.2342679798603, 82.05130755901337, 70.14359772205353, 76.38557597994804, 72.43475317955017, 70.51852360367775, 63.58256198465824, 68.57213124632835, 77.24328115582466, 83.08792993426323, 78.44153925776482, 77.7485704421997, 78.7124115228653, 66.70008569955826, 59.18840177357197, 60.95123738050461, 57.33744889497757, 63.24815712869167, 66.01502045989037, 66.25529676675797, 69.80575025081635, 68.34704652428627, 62.672678008675575, 61.92213848233223, 59.703065156936646, 56.124287992715836, 58.016077280044556, 59.67681996524334, 61.23380161821842, 62.31321729719639, 65.00473827123642, 69.56521555781364, 68.38499888777733, 72.63935700058937, 62.50666491687298, 66.56810358166695, 71.60240784287453, 68.09438288211823, 66.04613319039345, 66.68130710721016, 66.5254394710064, 60.36526322364807, 66.11541107296944, 62.02553853392601, 69.2776545882225, 59.79559779167175, 58.055788949131966, 68.23792397975922, 67.03083515167236, 67.93339312076569, 61.24708570539951, 61.04518733918667, 59.617493748664856, 62.12121360003948, 61.93136818706989, 64.88362357020378, 64.39572215080261, 62.0539116114378, 63.224389404058456, 59.553110003471375, 63.016080781817436, 62.73432970046997, 59.94416981935501, 61.496523320674896, 62.80267283320427, 63.10522399842739, 61.86606489121914, 63.874146938323975, 61.32259905338287, 56.874926313757896, 62.102925181388855, 63.45768928527832, 58.774345591664314, 58.36033120751381, 54.16392378509045, 63.2942258566618, 60.43001934885979, 63.66377882659435, 57.316580414772034, 58.88882964849472, 57.04204134643078, 58.83983127772808, 57.04610712826252, 60.83127781748772, 61.62791267037392, 60.61112903058529, 64.10967350006104, 64.76513832807541, 58.56688052415848, 55.29343597590923, 54.8095965385437, 55.18716707825661, 55.21715886890888, 57.595721036195755, 52.02450558543205, 56.52737036347389, 57.574407979846, 62.62236870825291, 71.14165216684341, 69.44274052977562, 71.39317587018013, 74.8842841386795, 73.33349615335464, 69.04204443097115, 67.70825520157814, 66.06656849384308, 64.05127063393593, 69.21263247728348, 74.69137609004974, 78.2098276913166, 78.0451749265194, 79.85834643244743, 78.76055493950844, 73.75619307160378, 75.13864248991013, 67.27218300104141, 75.38299977779388, 80.4190443456173, 80.61535701155663, 58.24330888688564, 19.47358075529337, 1.0786089347675443, 2.298907754011452, 0.6507721391972154, 0.7872816547751427, 1.0840167570859194, 30.792122706770897, 95.19758373498917, 78.87261092662811, 63.803265541791916, 36.46237604320049, 43.24117049574852, 31.203766018152237, 7.487192815169692, 0.7218706584535539, 0.2399136935127899, 0.2727351151406765, 1.174086055252701, 9.395816624164581, 14.009856786578894, 15.148011613637209, 16.893986575305462], [11.469505000859499, 7.180079044774175, 0.5028143723029643, 0.0746788622927852, 0.04148497901041992, 0.07023249971098267, 0.06773081637220457, 2.025528810918331, 40.383655428886414, 52.98143483698368, 28.831285424530506, 40.82018360495567, 88.697280138731, 38.80899332463741, 60.98888576030731, 34.087351486086845, 0.5879784899298102, 1.096335577312857, 0.8130960445851088, 1.0866383789107203, 0.3320700296899304, 0.2644145709928125, 0.2411555143771693, 11.602352522313595, 76.03742346167564, 56.490542739629745, 89.55215826630592, 75.00614359974861, 86.43260926008224, 76.36621981859207, 80.58363631367683, 77.84682556986809, 76.67316734790802, 79.52545389533043, 76.5893742442131, 75.28859004378319, 68.68246972560883, 65.36725401878357, 58.25622819364071, 59.22679491341114, 59.911886751651764, 61.890911757946014, 70.29645591974258, 75.13255521655083, 73.56029078364372, 71.45373702049255, 67.6162089407444, 57.55582317709923, 53.710448518395424, 54.2214222997427, 51.2157341837883, 54.75341655313969, 60.177306309342384, 60.885687097907066, 58.607420548796654, 58.99159133434296, 56.804189309477806, 55.226061791181564, 53.210893124341965, 51.264489367604256, 51.14959493279457, 55.345892161130905, 55.37870720028877, 57.18134947121143, 58.761646673083305, 60.971927270293236, 64.06511709094048, 62.289555966854095, 56.182546466588974, 56.597731187939644, 60.17345331609249, 58.87933395802975, 60.81554666161537, 54.72130447626114, 58.40262293815613, 59.86147105693817, 57.63962388038635, 63.50979968905449, 59.94721345603466, 50.398086458444595, 57.912916615605354, 60.80281734466553, 61.38463832437992, 60.77610857784748, 59.89675976336002, 59.32351492345333, 60.492092818021774, 60.666537657380104, 61.45308405160904, 59.84596028923988, 60.90224280953407, 59.31264370679855, 55.58686763048172, 58.14354903995991, 60.22553712129593, 59.46840114891529, 58.81929337978363, 56.47923834621906, 56.638677790760994, 59.47777904570103, 58.547395169734955, 57.7757515758276, 56.54354989528656, 56.402672454714775, 58.59643153846264, 58.538374453783035, 58.7222807854414, 53.20822186768055, 49.28672969341278, 63.82867857813835, 64.7861436009407, 58.543492779135704, 55.21224573254585, 55.14633446931839, 51.76097072660923, 50.83219036459923, 49.68062415719032, 49.95275795459747, 50.894700810313225, 54.21044088900089, 52.84252569079399, 49.70916822552681, 46.41775444149971, 45.003128349781036, 46.50417700409889, 50.078584402799606, 47.85765677690506, 50.106847286224365, 50.93928761780262, 58.846807703375816, 60.41581951081753, 62.52702422440052, 62.14728020131588, 65.4513131082058, 64.67428520321846, 65.9518450498581, 65.84880977869034, 62.642526626586914, 59.22711029648781, 53.8106719404459, 57.45079681277275, 61.350546553730965, 68.28222960233688, 68.64226028323174, 68.48858892917633, 63.730127066373825, 60.61299093067646, 51.430453062057495, 47.62876085937023, 42.77411475777626, 52.58068934082985, 56.564323380589485, 68.69697734713554, 55.85083946585655, 33.500894755125046, 0.7601574040018022, 0.04897669634374324, 0.43249472219031304, 0.48658823361620307, 0.35809771274216473, 27.531952746212482, 74.47367817163467, 57.7009791880846, 44.25538547337055, 20.75689349323511, 14.983316101133823, 21.261580511927605, 14.380459450185299, 0.9636944916564971, 0.22619222901994362, 0.3342599590541795, 5.329415425658226, 8.366483207792044, 9.263683464378119, 13.377349376678467, 16.542241349816322, 9.79156918823719, 6.603182125836611, 0.6776707177050412, 0.049687863065628335, 0.028529615010484122, 0.08928302238928154, 0.02162183987820754, 3.202348225750029, 53.717987313866615, 60.545833334326744, 43.13875839114189, 49.57574978470802, 77.36279234290123, 47.03608386218548, 67.59790152311325, 36.55772052705288, 0.536626442335546, 0.9419265878386796, 0.9954789548646659, 3.247683118097484, 0.6367801618762314, 0.45608341111801565, 0.11719962712959386, 11.862033437937498, 83.74251320958138, 63.19969452917576, 86.39428451657295, 80.56412056088448, 87.94868230819702, 79.70930323004723, 84.1381023824215, 79.95147943496704, 80.08328676223755, 81.52671530842781, 82.21398442983627, 77.00941130518913, 72.6546473801136, 67.59771153330803, 61.024432852864265, 62.278107181191444, 63.77903804183006, 64.96455162763596, 73.52804571390152, 75.35963863134384, 73.70969116687775, 73.67040887475014, 71.14437282085419, 60.24097189307213, 56.219514682888985, 56.54224656522274, 54.421804547309875, 58.117505237460136, 61.96965493261814, 61.262402683496475, 60.26736527681351, 60.1834961771965, 59.728782176971436, 58.293337002396584, 55.27309566736221, 52.665056213736534, 52.96302482485771, 56.97350062429905, 58.91352452337742, 60.06793297827244, 61.8661142885685, 63.17047409713268, 66.45031750202179, 66.75820738077164, 59.62032079696655, 58.852294608950615, 61.9461227953434, 62.83060133457184, 63.34441736340523, 56.63775444030762, 59.98162820935249, 62.00736030936241, 62.2299599647522, 66.85155317187309, 62.44894601404667, 52.90073476731777, 60.673305094242096, 62.838497310876846, 62.7876066416502, 62.38989718258381, 61.56389370560646, 60.75960226356983, 60.86217015981674, 62.93213188648224, 63.33587162196636, 62.479693964123726, 62.358396872878075, 61.97369411587715, 60.121225118637085, 61.54207907617092, 63.93174424767494, 61.108324751257896, 61.839367523789406, 60.79844757914543, 58.425455912947655, 61.26210629940033, 60.280843153595924, 58.27963873744011, 61.46313451230526, 57.44823195040226, 58.928134739398956, 62.22371689975262, 59.82038766145706, 56.467740163207054, 51.13894410431385, 64.80104640126228, 68.20738881826401, 61.359286084771156, 56.062640100717545, 58.53972718119621, 54.47826191782951, 51.97263836860657, 51.9496838003397, 52.72408224642277, 51.518425941467285, 56.159018129110336, 52.92557403445244, 51.307115480303764, 48.995270133018494, 48.21218155324459, 49.41809244453907, 53.77511724829674, 49.754723981022835, 53.59210006892681, 53.90080310404301, 63.017399311065674, 64.02698993682861, 65.81534877419472, 64.61936295032501, 69.64857548475266, 66.49306520819664, 67.14780807495117, 69.34836879372597, 65.48074632883072, 62.88196697831154, 57.09838092327118, 62.56311468780041, 64.66758236289024, 70.54211273789406, 69.96457412838936, 73.70420426130295, 70.40389895439148, 70.85474476218224, 61.60893268883228, 60.560625940561295, 54.87788647413254, 65.47979637980461, 66.03960514068604, 76.37517213821411, 58.32039535045624, 34.86457318067551, 1.412088421639055, 0.06855973595520481, 0.2726577239809558, 0.6038338516373187, 0.4132435598876327, 32.225797176361084, 82.57795169949532, 68.97744029760361, 55.68089358508587, 35.11728622019291, 24.661563970148563, 35.08291706442833, 17.03608375042677, 1.0281763784587383, 0.14730798691743985, 0.2424646183499135, 2.0600618328899145, 9.44956948980689, 11.441282965242863, 14.019991792738438, 13.631180506199598, 18.01965717226267, 12.59550902992487, 1.487431253772229, 0.2661802590591833, 0.11138267364003696, 0.17940397403435782, 0.20314388297265396, 3.450852041132748, 63.371931686997414, 74.04467359185219, 53.207412511110306, 59.21699523925781, 104.12281081080437, 57.49536842107773, 78.75881463289261, 43.06555151939392, 0.8258437074255198, 1.664787211921066, 1.8425193498842418, 6.085495529696345, 1.2167832953855395, 1.2512150290422142, 0.1939755241619423, 16.82508297264576, 91.80550575256348, 72.86529287695885, 94.49871003627777, 89.3906669318676, 94.17799204587936, 86.91004604101181, 89.03846383094788, 84.09519508481026, 84.19312343001366, 85.87717786431313, 86.21140033006668, 83.18193688988686, 76.62734180688858, 72.7793338894844, 65.1850537955761, 65.15203356742859, 67.36162260174751, 67.70321667194366, 76.62079095840454, 79.47883039712906, 78.51946547627449, 76.27901449799538, 72.41458386182785, 63.75132232904434, 61.25020533800125, 58.509853184223175, 56.377495005726814, 61.53525844216347, 67.03050836920738, 67.75132969021797, 63.25903594493866, 64.37691316008568, 61.923267021775246, 61.68061964213848, 58.43679830431938, 56.814710944890976, 56.022233068943024, 60.53342320024967, 61.13658383488655, 63.81841912865639, 64.81259778141975, 66.0991783440113, 71.79453313350677, 65.80629765987396, 63.21309261023998, 60.21426312625408, 64.974195510149, 66.27332299947739, 64.84700873494148, 59.40531313419342, 61.94731593132019, 64.71732169389725, 65.21330147981644, 68.87328028678894, 66.1393877863884, 56.740261539816856, 63.54174457490444, 65.28678193688393, 63.69495615363121, 64.24903482198715, 63.958441615104675, 64.49311092495918, 65.26217445731163, 65.98093628883362, 69.0706416964531, 64.65310513973236, 65.90382322669029, 63.16369906067848, 62.26245582103729, 65.37477001547813, 65.99881812930107, 64.23572793602943, 63.812081068754196, 62.564433217048645, 60.09451635181904, 63.1100345402956, 64.66956585645676, 62.63367310166359, 65.1264001429081, 60.871897637844086, 60.46668738126755, 68.00798311829567, 62.638506442308426, 56.47787801921368, 53.60004544258118, 63.46481770277023, 66.614461094141, 64.88920167088509, 58.74443739652634, 61.26380480825901, 57.151585668325424, 56.61838687956333, 55.72158560156822, 56.67488984763622, 55.95243081450462, 61.50174804031849, 57.112166583538055, 54.30051885545254, 52.84732483327389, 50.237765461206436, 52.46704503893852, 55.42702540755272, 54.56501126289368, 57.47632384300232, 56.74365475773811, 66.81549310684204, 65.98731234669685, 69.18645948171616, 68.69812488555908, 70.64856022596359, 69.5581479370594, 70.87209463119507, 73.78085374832153, 69.63860481977463, 66.6538117825985, 60.54179035127163, 64.72138747572899, 69.44063544273376, 75.05296468734741, 76.67274177074432, 77.17795506119728, 77.97818452119827, 78.64425837993622, 70.72355300188065, 73.57906937599182, 67.49196320772171, 78.80051359534264, 76.73114463686943, 85.355693846941, 65.03990918397903, 38.892919421195984, 1.5932281455025077, 0.19189568498404697, 0.544809065759182, 1.0652689193375409, 0.6325470702722669, 37.651738822460175, 94.61310669779778, 79.31735426187515, 69.46085035800934, 47.401331663131714, 38.802005499601364, 54.09351356327534, 21.644309274852276, 0.9965290641412139, 0.26007173059042543, 0.3792752232402563, 5.820547621697187, 16.100879833102226, 24.91788301616907, 24.711215905845165, 26.39606449753046], [12.253009658306837, 10.90217549353838, 2.01389336027205, 0.043970587430521846, 0.0134269506088458, 0.10520173382246867, 0.17290439311182126, 6.845846129581332, 50.99607557058334, 53.55062909424305, 19.417908042669296, 18.86006947606802, 60.087482929229736, 44.904915019869804, 58.51380117237568, 47.91781894862652, 0.25524616765324026, 0.6242576369550079, 0.21377891855081543, 0.7218713115435094, 0.528527176938951, 0.12187320564407855, 0.23013631347566843, 15.725907403975725, 56.80402211844921, 58.098871037364006, 82.26809352636337, 76.44123539328575, 81.7679263651371, 77.60256707668304, 80.59211745858192, 81.4440469443798, 74.755569845438, 75.28722211718559, 74.63331520557404, 77.53739297389984, 69.79900181293488, 69.45500627160072, 58.802258893847466, 58.37879441678524, 55.46511836349964, 62.506790310144424, 68.50706353783607, 70.93825668096542, 69.67212662100792, 74.10737782716751, 69.15015622973442, 53.940822556614876, 53.829317539930344, 52.03853823244572, 50.693862587213516, 55.523585826158524, 55.49116216599941, 58.01887392997742, 57.41094455122948, 54.65733490884304, 53.007600232958794, 52.093057706952095, 52.72851660847664, 55.493590235710144, 56.54797285795212, 58.152516558766365, 58.00913505256176, 54.915778040885925, 58.76240283250809, 61.12481966614723, 62.673046588897705, 64.83512297272682, 59.16273035109043, 54.10757280886173, 60.43914645910263, 56.73628695309162, 52.60574899613857, 51.3148632645607, 59.36453752219677, 57.77222536504269, 60.02673178911209, 61.08974754810333, 53.99527743458748, 52.309125512838364, 59.19399507343769, 60.25470815598965, 61.20706245303154, 57.898424193263054, 60.57339325547218, 57.69692100584507, 59.31878797709942, 57.10126876831055, 55.29431372880936, 54.11359168589115, 56.47600471973419, 56.930483132600784, 58.12822446227074, 57.68810547888279, 54.34905745089054, 60.06576709449291, 60.0173918902874, 55.34617714583874, 57.788294702768326, 57.50092752277851, 58.63021932542324, 55.61882771551609, 57.826083675026894, 53.30409072339535, 56.23210720717907, 54.997481256723404, 54.1673967987299, 50.58104284107685, 59.60374228656292, 66.03677049279213, 56.662122532725334, 60.042831525206566, 54.7793235629797, 53.798516392707825, 50.46613700687885, 50.61559058725834, 46.73435725271702, 48.32780174911022, 47.4411079287529, 44.7315189242363, 46.79067403078079, 46.56168691813946, 46.33889727294445, 47.64253132045269, 46.09072118997574, 48.3908099681139, 46.71228043735027, 51.24700270593166, 58.5599534958601, 63.574787601828575, 64.84225139021873, 63.1946711987257, 62.733835726976395, 64.73767340183258, 63.223857432603836, 66.586152613163, 67.3418940603733, 60.935859605669975, 57.43055909872055, 52.07362174987793, 59.15345884859562, 62.60265156626701, 69.03064504265785, 68.38498368859291, 66.56661406159401, 63.78210827708244, 59.75832939147949, 52.278282567858696, 51.04034699499607, 45.79773411154747, 49.042718186974525, 56.02925889194012, 70.5918824672699, 66.81531071662903, 53.870659321546555, 5.744930254295468, 0.04720342352811713, 0.5145744443871081, 0.29431299946736544, 0.6562522170133889, 23.190945982933044, 73.89348730444908, 58.22405532002449, 46.56456716358662, 24.384862817823887, 21.835387721657753, 27.55339689552784, 29.342519491910934, 1.3927776203490794, 0.25493740453384817, 0.6271377636585385, 8.17705387249589, 14.025571793317795, 7.693032519891858, 12.766714543104172, 18.125369399785995, 15.023227259516716, 9.1894924454391, 1.8461286812089384, 0.06903304063598625, 0.04546739910438191, 0.11346099883667193, 0.12228711624629796, 9.31173948571086, 65.84608152508736, 59.94480058550835, 34.27258014678955, 28.13038643449545, 69.61149707436562, 49.275885075330734, 66.66509717702866, 52.27289445698261, 0.3414507763227448, 1.0899452702142298, 0.3775026777293533, 0.9750729810912162, 1.038084584288299, 0.3079084918135777, 0.2723664458608255, 19.61394902318716, 79.2498242855072, 70.65214723348618, 86.8837970495224, 79.52031657099724, 82.95506626367569, 81.56523764133453, 83.05667281150818, 81.73335582017899, 78.5561791062355, 77.96198979020119, 77.952049523592, 79.95801508426666, 74.60131332278252, 72.89267420768738, 63.53474535048008, 63.30086790025234, 58.41009333729744, 65.56051164865494, 70.41965290904045, 73.91303345561028, 71.73749059438705, 77.24562183022499, 67.56785273551941, 57.21087768673897, 54.51196610927582, 55.98693676292896, 51.872487142682076, 56.897006928920746, 57.033978179097176, 59.09896597266197, 60.76083719730377, 57.66717240214348, 56.15084856748581, 55.971965566277504, 56.56906932592392, 59.16792467236519, 59.31660309433937, 62.01586425304413, 61.38687640428543, 59.43903252482414, 60.409128069877625, 63.78111273050308, 60.65378174185753, 65.13714596629143, 60.68806730210781, 55.13412572443485, 62.8162457048893, 60.41431859135628, 53.44974830746651, 52.16987058520317, 63.15440475940704, 61.832668483257294, 63.061408549547195, 62.51749433577061, 56.70020028948784, 58.08389224112034, 63.14574122428894, 61.848285645246506, 62.80985064804554, 59.76787827908993, 60.71377672255039, 61.40527501702309, 59.544628858566284, 59.113013818860054, 55.66902682185173, 56.70032948255539, 58.2968670129776, 59.78514455258846, 61.68831802904606, 62.800594344735146, 58.67142431437969, 61.448501497507095, 62.45998442173004, 59.37125936150551, 57.23713807761669, 61.751702427864075, 60.3243014216423, 59.55464132130146, 60.29769144952297, 58.541889265179634, 57.79132314026356, 56.051423102617264, 58.38752254843712, 52.10115887224674, 63.891253620386124, 69.61221903562546, 57.84742332994938, 61.70182250440121, 56.86706833541393, 57.05645017325878, 51.43413506448269, 52.28100702166557, 48.587650805711746, 50.39648674428463, 49.47729706764221, 47.95014001429081, 46.93422272801399, 51.07353441417217, 48.719853311777115, 50.53879290819168, 48.85972760617733, 50.619720965623856, 49.256540313363075, 54.6422953158617, 60.00283487141132, 66.34564071893692, 68.1386961042881, 65.5594553053379, 66.35318711400032, 64.99405324459076, 63.09729002416134, 68.1820897758007, 67.95125976204872, 61.813281923532486, 60.10439582169056, 56.13460823893547, 63.328731805086136, 65.80686762928963, 71.71472981572151, 70.83660453557968, 71.58931374549866, 70.38304567337036, 68.36100697517395, 62.21872016787529, 60.08627079427242, 55.01221306622028, 59.86190043389797, 64.30555298924446, 77.79688104987144, 69.23439010977745, 57.24935442209244, 7.905042618513107, 0.05496037701959722, 0.6435547233559191, 0.2547447133110836, 0.5549091019202024, 27.395332977175713, 83.02818953990936, 70.49143105745316, 60.419186130166054, 39.909174889326096, 30.25987956672907, 40.72245664894581, 37.08860144019127, 1.3470787787809968, 0.24350390711333603, 0.6313689553644508, 7.848899206146598, 17.402710877358913, 15.498196072876453, 18.50164420902729, 20.82756780087948, 23.868369832634926, 15.635228119790554, 3.1437936052680016, 0.17021550302160904, 0.1081246230751276, 0.2946844295365736, 0.4875821771565825, 12.980853002518415, 78.38442072272301, 72.79856085777283, 39.21939790248871, 26.872268244624138, 74.84306395053864, 61.89195290207863, 78.37728470563889, 60.12584947049618, 0.43725503550376743, 1.8626202712766826, 0.6739191908854991, 1.6053560259751976, 3.696806668303907, 0.4923840507399291, 0.304923276999034, 24.257638044655323, 93.7295401096344, 82.26095750927925, 92.55605667829514, 86.68787196278572, 91.10517293214798, 86.94767162203789, 88.34401309490204, 85.19386053085327, 82.73286938667297, 79.77801114320755, 80.85902273654938, 84.05671834945679, 78.10080394148827, 75.7041585445404, 68.07740539312363, 65.4374286532402, 63.07908520102501, 69.83617901802063, 74.95624467730522, 77.51726925373077, 74.39010545611382, 80.98063141107559, 71.92026078701019, 59.76695492863655, 58.87985073029995, 60.2760212123394, 54.33116041123867, 61.045039147138596, 60.22853136062622, 62.45152987539768, 62.767235934734344, 60.399138405919075, 59.71922188997269, 58.87927696108818, 59.33646082878113, 61.60444512963295, 61.95719540119171, 65.66054508090019, 64.30264994502068, 62.48123288154602, 63.881488144397736, 67.11194559931755, 64.80018004775047, 71.85868129134178, 63.345777690410614, 61.934655010700226, 66.08473911881447, 64.6212400496006, 58.128471449017525, 54.70955170691013, 64.31389734148979, 64.67701345682144, 65.77890872955322, 68.4661853313446, 59.31822560727596, 58.454303964972496, 64.11348089575768, 65.18655091524124, 65.14551311731339, 63.79032343626022, 64.93656232953072, 62.18104138970375, 62.810325622558594, 61.26816317439079, 60.785372480750084, 60.218340307474136, 62.27469876408577, 62.22866043448448, 63.55530604720116, 65.22718593478203, 60.46967402100563, 64.13133233785629, 65.17102494835854, 59.65175651013851, 60.468066707253456, 63.40877830982208, 63.538822531700134, 61.587471440434456, 62.01353497803211, 59.31080460548401, 59.75908935070038, 59.21111315488815, 61.40602357685566, 55.7267115265131, 59.68288443982601, 69.68563869595528, 65.70558026432991, 65.23699700832367, 59.60427425801754, 60.835392996668816, 57.28158809244633, 55.51620662212372, 52.213591039180756, 53.86276714503765, 53.8284245878458, 49.93551068007946, 52.0960633456707, 54.44150269031525, 52.79714472591877, 54.49597276747227, 51.26705043017864, 53.5139686614275, 51.25722035765648, 56.88156075775623, 63.9545202255249, 69.88214895129204, 72.65702605247498, 69.19939398765564, 69.52087193727493, 69.46112394332886, 67.08379670977592, 74.08303633332253, 71.29071056842804, 66.68115511536598, 62.1842560172081, 58.35769794881344, 67.36236736178398, 71.53521984815598, 78.27390745282173, 75.23013398051262, 75.81120640039444, 75.86076334118843, 77.27517664432526, 72.54449889063835, 74.18376132845879, 67.1138758957386, 71.56429588794708, 74.78903844952583, 85.72662994265556, 74.94092389941216, 61.81073606014252, 8.245137669146061, 0.13266900525195524, 1.1920352233573794, 0.5155784811358899, 0.8022440643981099, 32.448366433382034, 96.13442346453667, 81.48381561040878, 73.94584089517593, 53.539210706949234, 41.84214636683464, 55.282340571284294, 47.017601653933525, 1.15169373806566, 0.32228374388068914, 0.99447758984752, 15.432877577841282, 25.72454933077097, 22.602353766560555, 29.430739358067513, 31.03756483644247], [14.911023080348969, 7.752558225765824, 3.1060409685596824, 0.1742699893657118, 0.03488288894004654, 0.016707009563106112, 0.23797866218956187, 20.333693102002144, 56.10970437526703, 48.96244369447231, 17.757902517914772, 31.502847969532013, 46.258379593491554, 47.563267573714256, 62.914858013391495, 58.062415793538094, 0.10078351348056458, 0.09531766263535246, 0.09118815258261748, 0.5392876057885587, 0.47819988685660064, 0.020078979796380736, 0.7192835910245776, 12.077704165130854, 21.37264285236597, 49.87271524965763, 70.63812598586082, 76.54533460736275, 74.16684463620186, 77.63076916337013, 76.93954825401306, 81.14001005887985, 81.06240302324295, 78.97924080491066, 76.03460401296616, 74.7896084189415, 70.94615265727043, 69.00756508111954, 63.166822493076324, 56.62354700267315, 54.33562897145748, 59.18780900537968, 66.24664083123207, 68.22431311011314, 67.58352309465408, 69.52789396047592, 64.35492753982544, 56.14169865846634, 52.9985149204731, 52.6757488399744, 49.980671256780624, 49.83498327434063, 52.21764922142029, 56.56547851860523, 55.51497928798199, 53.44032481312752, 51.396213099360466, 54.61461380124092, 60.15284702181816, 59.296893551945686, 62.3526705801487, 61.20000623166561, 59.79162700474262, 58.981856256723404, 59.15741063654423, 61.846416145563126, 69.19697731733322, 65.15862241387367, 54.75787751376629, 55.11440098285675, 52.962428256869316, 54.8169681429863, 49.944930374622345, 50.149758383631706, 61.66216403245926, 58.95454332232475, 63.74964661896229, 57.12698578834534, 55.181995555758476, 59.56979490816593, 57.34243802726269, 60.703745260834694, 61.58736504614353, 57.849513217806816, 60.78003376722336, 62.35849566757679, 58.967360034585, 58.32052454352379, 55.19158624112606, 56.49905428290367, 55.46931333839893, 57.657213136553764, 58.3061309158802, 56.86614118516445, 55.85368551313877, 60.96271276473999, 58.820532113313675, 57.956994250416756, 54.213134944438934, 56.58646859228611, 56.07751630246639, 56.40412017703056, 55.848886370658875, 54.30671252310276, 54.008386731147766, 52.34424702823162, 52.156651094555855, 54.27818365395069, 61.14603392779827, 51.26159392297268, 54.30833883583546, 57.84519664943218, 53.56153830885887, 54.16181869804859, 51.76405996084213, 49.74219985306263, 45.19138164818287, 44.73913371562958, 42.76691414415836, 45.31278893351555, 45.24460919201374, 45.40631711483002, 46.45265556871891, 46.92296773195267, 47.24033050239086, 47.220267578959465, 47.7731379121542, 55.64894109964371, 59.640345722436905, 61.42875015735626, 59.84336502850056, 63.27640101313591, 60.14955259859562, 62.13928163051605, 65.92473730444908, 64.51596289873123, 64.11231055855751, 59.86548364162445, 53.914068192243576, 51.23038999736309, 61.13332360982895, 61.56677395105362, 67.3852801322937, 66.92054226994514, 68.3554744720459, 61.83022901415825, 59.15904074907303, 56.76257014274597, 50.397022515535355, 46.691453754901886, 49.24091935157776, 54.5297035574913, 66.3304415345192, 70.29793784022331, 74.75023493170738, 21.17630358785391, 0.0690252183994744, 0.4741020145593211, 0.6562349398154765, 0.40179486328270286, 25.17092663794756, 70.3456024825573, 60.61321511864662, 49.09100219607353, 30.309014730155468, 26.36344514787197, 30.85434626787901, 38.40197056531906, 0.9527770837303251, 0.07191459968453273, 0.3216152172535658, 11.676213908940554, 13.477266915142536, 6.839425899088383, 9.800951834768057, 14.25687013193965, 19.33058112859726, 12.196914218366146, 2.143787727691233, 0.061669970891671255, 0.06435897230403498, 0.056675929299672134, 0.2424874616554007, 27.588630504906178, 68.7868121266365, 55.85650496184826, 23.8021032884717, 30.606793351471424, 55.552065297961235, 55.895004495978355, 70.63910633325577, 62.49590389430523, 0.1129378960467875, 0.13231179473223165, 0.2150730459834449, 1.1021585273556411, 0.7663280353881419, 0.16946697287494317, 0.8537485194392502, 22.006291151046753, 58.607849925756454, 67.54933252930641, 77.72057354450226, 81.28563344478607, 79.19028148055077, 84.45758923888206, 79.4560544192791, 83.90276581048965, 82.05205231904984, 79.05084416270256, 79.86076310276985, 80.03797799348831, 74.81920123100281, 71.77823200821877, 65.91067045927048, 60.13165935873985, 57.913885563611984, 60.80332651734352, 68.1585842370987, 70.57652369141579, 70.1128725707531, 70.88062137365341, 64.5046167075634, 58.572185039520264, 55.96406579017639, 53.67573358118534, 52.34600633382797, 53.00767242908478, 55.80124452710152, 57.759549245238304, 57.50788874924183, 53.85744743049145, 52.962428256869316, 58.973006531596184, 63.50018620491028, 63.78816515207291, 63.51294972002506, 61.882620602846146, 63.98811802268028, 62.88278393447399, 59.13276135921478, 63.75526651740074, 71.09160885214806, 67.35379502177238, 54.66545507311821, 58.00827629864216, 57.98585370182991, 56.09789080917835, 52.75392584502697, 53.50401319563389, 64.58350047469139, 60.98577372729778, 65.94806805253029, 59.379299730062485, 59.4095803052187, 61.455447524785995, 59.09928135573864, 63.63273449242115, 61.44937165081501, 58.44943642616272, 63.62210266292095, 62.75085501372814, 61.373827904462814, 61.37642316520214, 58.76290060579777, 60.22853136062622, 57.55432225763798, 59.488308280706406, 60.83390727639198, 61.21515981853008, 58.67545589804649, 62.524010986089706, 62.1123106777668, 60.82096517086029, 57.07555554807186, 59.225221797823906, 59.67574842274189, 57.184043526649475, 56.90398335456848, 55.84023803472519, 54.28330197930336, 55.98489627242088, 56.228637993335724, 59.71498131752014, 63.20189841091633, 51.89490593969822, 58.92821453511715, 62.12642692029476, 58.02756026387215, 55.20059555768967, 52.20749996602535, 49.526246041059494, 48.3729737251997, 47.272070199251175, 45.304604172706604, 47.00001619756222, 48.05040903389454, 48.82733054459095, 49.575639590620995, 48.801016956567764, 47.380311191082, 50.76960392296314, 50.50917349755764, 58.915614411234856, 63.48434865474701, 64.16522651910782, 62.20572866499424, 64.19681042432785, 62.35655777156353, 64.40798029303551, 69.67302337288857, 65.36327183246613, 66.3862681388855, 62.07190744578838, 56.102051585912704, 54.11799944937229, 64.91102010011673, 65.920549929142, 71.29734501242638, 70.3613868355751, 73.38550016283989, 68.26949268579483, 68.96258309483528, 64.74690690636635, 62.46120035648346, 57.776450738310814, 61.56825207173824, 64.33351188898087, 73.43187287449837, 73.8020870089531, 79.29598420858383, 23.536261953413486, 0.06119605393905658, 0.4141566390171647, 0.41212036390788853, 0.311484367121011, 29.167225398123264, 81.9037614762783, 72.54892185330391, 63.67692232131958, 43.485721573233604, 36.279032081365585, 35.29643140733242, 49.13173981010914, 1.033557839691639, 0.02309602903551422, 0.860871949698776, 10.42170837521553, 22.56018552929163, 14.60323104634881, 19.436223059892654, 22.12837480008602, 29.554650709033012, 13.540081344544888, 4.267374314367771, 0.206109861319419, 0.2564476750558242, 0.15892749623162672, 0.534076482290402, 33.18858191370964, 81.77520677447319, 65.15664651989937, 33.985794335603714, 44.92472715675831, 65.35533785820007, 64.56896245479584, 81.75224080681801, 69.77099731564522, 0.2438818383961916, 0.15808152209501714, 0.6150607054587454, 1.7201201990246773, 1.2824527965858579, 0.45346597500611097, 1.667231668252498, 30.686497874557972, 77.89864718914032, 84.41118612885475, 88.43289032578468, 91.82793974876404, 87.08603739738464, 90.29564917087555, 85.95546886324883, 88.67822796106339, 87.13215172290802, 82.44017869234085, 84.61355566978455, 82.57406830787659, 79.36068713665009, 75.14070197939873, 70.64964696764946, 62.599976509809494, 59.557312577962875, 65.45869991183281, 69.97022822499275, 74.59481567144394, 70.96965819597244, 75.76173305511475, 68.1687904894352, 62.84380942583084, 59.57502722740173, 55.89767575263977, 52.65017241239548, 55.76737694442272, 57.21418730914593, 61.68079063296318, 61.81381769478321, 59.05013859272003, 55.68792320787907, 59.52884070575237, 65.91057926416397, 67.57682785391808, 67.16687545180321, 65.09067445993423, 65.20187929272652, 64.48054879903793, 62.4531713873148, 68.48541989922523, 74.31018054485321, 62.12981253862381, 60.18123149871826, 60.85224889218807, 62.22915440797806, 58.33357684314251, 54.587297067046165, 57.27404169738293, 70.01278594136238, 66.0592120885849, 68.30338686704636, 62.03346490859985, 62.05607749521732, 64.2381902039051, 60.1727731525898, 63.38576674461365, 63.571272790431976, 63.53669844567776, 65.68174034357071, 66.7115306854248, 63.3154933154583, 64.69131588935852, 60.293355882167816, 63.02647702395916, 61.123596131801605, 63.578287214040756, 65.6209360063076, 63.58309395611286, 63.43788094818592, 67.6535077393055, 64.6166042983532, 62.83360317349434, 59.493479803204536, 60.6432981044054, 60.412422493100166, 60.4507852345705, 59.287717044353485, 57.50516049563885, 58.88075888156891, 58.48593346774578, 59.11196507513523, 56.537542417645454, 60.07669910788536, 61.42367362976074, 62.38134764134884, 64.7815078496933, 60.88909171521664, 57.50239044427872, 57.18215122818947, 55.10645180940628, 51.53042569756508, 50.34447133541107, 49.131796807050705, 49.793200716376305, 50.25708742439747, 50.48360846936703, 52.63353310525417, 53.119952604174614, 51.393047869205475, 52.99081273376942, 52.69903019070625, 60.29095061123371, 65.46154975891113, 67.30285495519638, 66.04277417063713, 66.52211844921112, 65.13891667127609, 67.69494071602821, 71.6321450471878, 69.29163783788681, 69.90038797259331, 64.19716760516167, 59.85455922782421, 58.416666984558105, 68.97626236081123, 69.54630017280579, 74.43443387746811, 74.39119219779968, 79.47019726037979, 74.84206840395927, 76.34988069534302, 73.74278739094734, 73.16527158021927, 67.06271544098854, 75.03442928195, 73.33433970808983, 85.49129337072372, 80.68129107356071, 85.12467384338379, 25.796621963381767, 0.10359515479649417, 0.7760514761321247, 1.055416523013264, 0.4587400029413402, 33.20823445916176, 93.59447255730629, 82.91351929306984, 77.89298549294472, 58.57061192393303, 48.015393912792206, 49.771583676338196, 59.372558891773224, 0.8165177016053349, 0.1612967878463678, 1.5447376412339509, 21.20290596038103, 28.817049488425255, 20.83818633109331, 27.741230316460133, 31.41780663281679], [24.079834185540676, 8.407510556280613, 2.604844537563622, 0.16140000574523583, 0.01332342193563818, 0.04873206220509019, 0.2166709493030794, 22.185160852968693, 59.97764602303505, 40.40700897574425, 24.923520013689995, 41.44862048327923, 53.410994186997414, 40.395506992936134, 71.64841577410698, 65.06636336445808, 0.5958945932798088, 0.11736325584934093, 0.0498411351145478, 0.24400187336141244, 0.3818617563229054, 0.0655939060379751, 0.39789083995856345, 8.415397983044386, 2.8202704153954983, 34.349879398941994, 62.55821295082569, 76.48078367114067, 73.36533084511757, 79.22354489564896, 75.92816412448883, 74.44888830184937, 75.66486865282059, 76.65066495537758, 76.58192664384842, 78.0367773771286, 72.74356260895729, 68.53605598211288, 60.684639886021614, 58.66927742958069, 55.669828578829765, 56.487548500299454, 59.77859370410442, 66.91712245345116, 66.11937046051025, 65.82662656903267, 60.51001265645027, 56.68269842863083, 52.264827489852905, 53.11948522925377, 52.37694427371025, 50.26007406413555, 50.80219477415085, 50.43461009860039, 51.56597279012203, 53.573614060878754, 59.04680237174034, 61.156437769532204, 61.133688390254974, 63.52252520620823, 63.7052346020937, 64.48906034231186, 59.850892424583435, 61.54544949531555, 62.0840135961771, 60.72832994163036, 62.15824641287327, 74.7736644744873, 63.298599421978, 51.62552699446678, 57.333345115184784, 56.48884803056717, 47.017772644758224, 50.825799107551575, 58.47467467188835, 57.470472157001495, 62.05761261284351, 57.80526079237461, 59.76534381508827, 56.98978275060654, 56.92477583885193, 61.231909319758415, 58.02523098886013, 57.63217628002167, 61.58775642514229, 61.00003436207771, 61.358803510665894, 57.2807901352644, 57.61810563504696, 56.88683867454529, 57.030683755874634, 57.986457869410515, 56.273023411631584, 58.3186474442482, 54.711071625351906, 55.51437132060528, 57.35796399414539, 55.4712588340044, 55.953331366181374, 56.24511390924454, 61.33748285472393, 57.007197216153145, 54.39261831343174, 53.98401863873005, 48.62116500735283, 50.95501497387886, 51.80563732981682, 58.37830424308777, 44.68222796916962, 55.535840168595314, 58.461797162890434, 56.41612373292446, 54.99001085758209, 53.253667429089546, 50.89375086128712, 49.10845085978508, 47.357941791415215, 47.36213676631451, 45.00143364071846, 48.08571293950081, 47.806348130106926, 48.708765506744385, 47.35531613230705, 45.804349556565285, 46.15939870476723, 47.033807784318924, 48.27428162097931, 56.44116058945656, 58.03965121507645, 60.36869443953037, 61.2556466460228, 63.48670452833176, 63.46645541489124, 66.2810517847538, 65.21277710795403, 62.00361751019955, 62.336152866482735, 58.95614683628082, 56.691947132349014, 53.87974463403225, 62.05686405301094, 63.23100484907627, 66.64039850234985, 66.75029620528221, 65.272775888443, 63.03449459373951, 61.25418372452259, 57.591415867209435, 52.304615154862404, 49.30557668209076, 47.12453931570053, 48.96221190690994, 60.32527416944504, 66.14194124937057, 79.78865057229996, 55.68227291107178, 1.4594020578078926, 0.2588976826518774, 0.47231533855665475, 0.48596619511954486, 11.634434200823307, 64.79202568531036, 60.2141947299242, 49.50770303606987, 27.933940775692463, 20.58520920574665, 27.85511590540409, 47.13378041982651, 2.0727500645443797, 0.41839130397420377, 1.3949594157747924, 15.583695285022259, 16.57715007662773, 7.157846437767148, 6.560187907889485, 11.317686047405005, 22.573414519429207, 11.337026059627533, 2.9211830254644156, 0.09719934096210636, 0.01682952144619776, 0.09869323228485882, 0.1757727493532002, 31.609517745673656, 70.89465022087097, 47.778624817728996, 29.37593299895525, 42.40700125694275, 54.961364194750786, 49.86829988658428, 78.04052397608757, 70.65800651907921, 0.4880872234934941, 0.131009251344949, 0.246080465731211, 0.39222590799909085, 0.5319596990011632, 0.0391213388502365, 1.5100158168934286, 18.947911262512207, 29.690014645457268, 62.826809138059616, 73.51080223917961, 81.82671681046486, 77.91209846735, 83.08096870779991, 79.2177464067936, 80.65410733222961, 78.51755797863007, 81.26588210463524, 79.19661954045296, 79.50425863265991, 75.79655438661575, 71.9996765255928, 62.26967163383961, 60.863450691103935, 58.57314258813858, 56.846036463975906, 59.9216066300869, 69.56007823348045, 68.73103871941566, 66.5126721560955, 63.305594846606255, 59.656502455472946, 53.73317889869213, 54.621305242180824, 54.75657798349857, 52.231735065579414, 52.94551536440849, 52.88423225283623, 53.60291048884392, 55.79239100217819, 59.834127724170685, 63.47360283136368, 63.571246191859245, 65.086699873209, 64.43860664963722, 68.1525045633316, 62.77616925537586, 62.596522495150566, 65.84017664194107, 63.85485157370567, 65.43456360697746, 74.75141286849976, 65.81195175647736, 53.12032878398895, 61.31325155496597, 59.6910198032856, 49.04686376452446, 54.704433381557465, 63.2910530269146, 61.867896392941475, 62.17014737427235, 60.385782122612, 63.285881504416466, 59.51785549521446, 60.132920891046524, 63.70199337601662, 61.01972110569477, 58.668673262000084, 62.07094229757786, 63.006467297673225, 61.93314649164677, 62.09846422076225, 59.49615105986595, 58.78583997488022, 60.3361301869154, 60.912380665540695, 57.12547726929188, 60.49644358456135, 59.74066033959389, 60.700975209474564, 57.137317433953285, 59.568563774228096, 56.98190197348595, 59.04572702944279, 61.90017566084862, 59.72604252398014, 58.4686253964901, 56.126233488321304, 52.442342564463615, 53.150970339775085, 58.69757071137428, 64.54238668084145, 46.58304177224636, 57.440655156970024, 58.67403857409954, 58.484531342983246, 57.22270645201206, 56.52392774820328, 53.21689300239086, 50.152030661702156, 48.465643152594566, 50.30002512037754, 48.79010394215584, 49.83966462314129, 52.381568625569344, 51.60962104797363, 50.193543434143066, 48.525136560201645, 48.388670682907104, 49.33892749249935, 50.79621009528637, 60.92999652028084, 61.06346435844898, 60.012885332107544, 63.660659193992615, 65.85616618394852, 63.166488111019135, 69.1822949051857, 66.21825635433197, 64.3963073194027, 64.88694459199905, 60.84351696074009, 59.15865316987038, 54.97271038591862, 61.20701685547829, 66.53680846095085, 70.92361986637115, 71.6895067691803, 72.66489163041115, 68.87194275856018, 69.81775760650635, 67.31582745909691, 64.80014204978943, 59.233117774128914, 57.2358613461256, 61.94855846464634, 71.82730257511139, 73.53198230266571, 81.32099434733391, 60.05939483642578, 1.9396719429641962, 0.3069784620311111, 0.5197355174459517, 0.737632509553805, 18.15046515315771, 75.89002937078476, 73.79099160432816, 62.3343251645565, 45.49236349761486, 32.31615632772446, 35.11602848768234, 60.31262844800949, 2.269856887869537, 0.2970748278312385, 1.7500929906964302, 20.056057199835777, 23.143429532647133, 11.292211264371872, 12.734790556132793, 22.807852439582348, 36.85925714671612, 15.553362462669611, 3.592205406166613, 0.2549748681485653, 0.10628434174577706, 0.2527527592610568, 0.3001954994397238, 42.6362581551075, 83.40428575873375, 57.016974091529846, 40.42126961052418, 57.65658237040043, 69.44545358419418, 57.350668385624886, 89.93881031870842, 79.18549373745918, 0.8943689335137606, 0.18513900926336646, 0.2743802487384528, 0.46957206388469785, 1.1591287516057491, 0.16895152162760496, 2.6613152073696256, 27.389006316661835, 49.86360713839531, 83.55255380272865, 84.69092711806297, 89.86681178212166, 83.35837662220001, 88.71517717838287, 84.73011061549187, 84.31301459670067, 83.19833680987358, 86.4493815600872, 82.47012108564377, 87.1223558485508, 79.91794243454933, 78.67431476712227, 66.9296845793724, 65.50364390015602, 60.24244621396065, 59.54300254583359, 62.69680671393871, 73.01681354641914, 72.03979477286339, 70.54431661963463, 66.86972379684448, 62.954090908169746, 57.55359269678593, 56.69293887913227, 58.14151614904404, 54.56929363310337, 56.677139326930046, 57.34243042767048, 56.404971331357956, 57.524452060461044, 63.120369985699654, 66.08804494142532, 65.5492414534092, 69.02812197804451, 68.81950557231903, 70.01435905694962, 66.51045307517052, 65.80960348248482, 69.23518806695938, 65.00862166285515, 72.195875197649, 78.73598545789719, 57.54407420754433, 56.59509792923927, 63.91336843371391, 64.03431594371796, 54.27494242787361, 59.21648986637592, 63.50402779877186, 62.469214126467705, 66.63128659129143, 63.54767605662346, 64.91317838430405, 62.727189883589745, 60.89554376900196, 66.18474215269089, 62.31073223054409, 60.41865795850754, 64.68799486756325, 66.60471841692924, 67.0021390914917, 62.87362642586231, 63.38175415992737, 60.37601664662361, 61.73907570540905, 62.968693524599075, 61.77440620958805, 63.21235544979572, 59.321451634168625, 61.51881292462349, 59.30211067199707, 60.89857220649719, 61.48592948913574, 61.18796467781067, 63.571656569838524, 63.572085946798325, 60.233585089445114, 59.27612006664276, 55.89381895959377, 57.43167623877525, 58.4969262778759, 58.1810150295496, 51.074795946478844, 60.809204801917076, 60.39846584200859, 63.257865607738495, 60.17945319414139, 59.79815885424614, 58.1267349421978, 53.716623187065125, 52.309691682457924, 52.85096123814583, 50.8188758790493, 53.56536850333214, 56.37916311621666, 54.58598233759403, 55.41064068675041, 51.365700736641884, 51.13660342991352, 51.63848049938679, 53.43865290284157, 63.30271080136299, 63.51679511368275, 63.591088727116585, 66.73689812421799, 69.54171001911163, 68.3286327123642, 72.12690129876137, 69.81379061937332, 65.785923153162, 67.64659970998764, 64.93198737502098, 64.40013751387596, 60.71761831641197, 66.95539399981499, 69.1695123910904, 75.16148686408997, 75.28691813349724, 74.92583110928535, 76.15591630339622, 76.77954643964767, 75.73786273598671, 73.96040171384811, 68.80440518260002, 68.40042605996132, 70.76383084058762, 81.27924978733063, 84.95562851428986, 89.13797289133072, 66.23341754078865, 2.484009596519172, 0.529899972025305, 1.0977159719914198, 0.9520011534914374, 26.20034269988537, 85.69994017481804, 84.28219065070152, 75.54981842637062, 58.934263810515404, 43.717638328671455, 51.45314164459705, 75.9265910089016, 1.9635934405960143, 0.49759229470510036, 2.9799307230859995, 31.936564296483994, 36.17327615618706, 19.49984684586525, 17.436874844133854, 29.376466870307922], [18.472875952720642, 9.551611114293337, 1.9748462992720306, 0.06978522214922123, 0.10349492775276303, 0.12472734233597293, 0.45451569836586714, 25.246533080935478, 63.92469182610512, 30.648262426257133, 12.2703861258924, 43.71270999312401, 41.89171850681305, 40.378837287425995, 77.8718738257885, 69.0666215121746, 1.2772797304205596, 0.040412219386780635, 0.16304052318446338, 0.15604171436280012, 0.3499350679339841, 0.2198492709430866, 3.478054068982601, 8.600047174841166, 4.291697759181261, 29.533318653702736, 58.12126323580742, 76.46299302577972, 76.32111623883247, 78.26073735952377, 75.8286626636982, 72.56500259041786, 74.81609299778938, 72.47219637036324, 74.46507543325424, 71.99594512581825, 71.56827047467232, 62.71080516278744, 58.36250849068165, 56.944143399596214, 56.32916919887066, 57.07231052219868, 57.25725419819355, 59.274657145142555, 61.63423553109169, 63.61634977161884, 58.35008695721626, 56.06857918202877, 54.17867459356785, 49.39772553741932, 49.71259564161301, 52.413323521614075, 50.71793429553509, 50.09808115661144, 53.34726780653, 58.698866441845894, 63.81987825036049, 62.89729155600071, 63.59715320169926, 64.01801481842995, 63.720513582229614, 57.32223451137543, 60.41515074670315, 63.79172936081886, 63.77175763249397, 60.893336087465286, 60.58958798646927, 47.22100853919983, 58.149051144719124, 66.72558233141899, 52.96095013618469, 52.08591029047966, 50.02804711461067, 50.337665900588036, 63.89308512210846, 60.261669382452965, 61.060147136449814, 57.51524895429611, 60.04369407892227, 58.28435428440571, 58.97228077054024, 60.17103284597397, 61.93753905594349, 60.59366136789322, 63.90104949474335, 53.540042862296104, 55.03554381430149, 62.31973014771938, 58.13263222575188, 60.150373354554176, 63.55746053159237, 56.98882520198822, 41.17527075111866, 56.1438949406147, 63.927640467882156, 58.86911250650883, 55.05987010896206, 55.231001526117325, 54.89505015313625, 54.00321900844574, 58.44511605799198, 56.619659811258316, 55.877837017178535, 55.6395898014307, 51.35635703802109, 51.433660089969635, 55.63319094479084, 36.86691373586655, 45.251027047634125, 64.24940720200539, 56.485234424471855, 56.923734694719315, 51.45579390227795, 51.46041825413704, 51.6892533749342, 50.43255440890789, 47.50117510557175, 46.44147276878357, 46.007608249783516, 49.093095883727074, 45.57261519134045, 48.53437766432762, 46.12051919102669, 44.64330665767193, 46.07973977923393, 45.32382734119892, 48.314985036849976, 55.56998133659363, 56.920786052942276, 59.73506323993206, 57.60061517357826, 63.69095116853714, 62.00321853160858, 65.07495850324631, 62.38552741706371, 61.511467918753624, 60.23160919547081, 58.1767288595438, 54.13428157567978, 54.724078327417374, 59.8517169803381, 62.096108347177505, 66.97824597358704, 67.67770484089851, 66.93951085209846, 63.31156812608242, 63.88700544834137, 59.45336155593395, 53.91274966299534, 49.72903735935688, 46.750134006142616, 45.99393658339977, 53.34374159574509, 59.61106829345226, 70.05241021513939, 79.50849920511246, 10.604703705757856, 0.4879455326590687, 0.6203943723812699, 0.033702117143548094, 34.728909060359, 61.50196082890034, 63.221387565135956, 52.251098826527596, 33.98546375334263, 25.519039258360863, 26.27530887722969, 48.70039455592632, 2.376478216610849, 0.5362836888525635, 3.6849313555285335, 20.29197134077549, 20.047036483883858, 3.5400387179106474, 3.792870263569057, 9.144703298807144, 26.619034633040428, 13.158846851438284, 1.8497508368454874, 0.021555092971539125, 0.06431416142731905, 0.019082008293480612, 0.4824239242589101, 34.587043672800064, 74.16841015219688, 42.51211881637573, 19.443566165864468, 45.899192467331886, 47.48233951628208, 48.98359715938568, 83.48355710506439, 78.74103918671608, 1.5966693358495831, 0.06594188424060121, 0.36873933859169483, 0.01497225699495175, 0.6118730921298265, 0.06385591492289677, 4.1742137633264065, 7.25881271995604, 14.794752169400454, 56.46409995853901, 70.98013043403625, 80.96835047006607, 82.12275132536888, 84.60628286004066, 78.966845870018, 77.08758071064949, 80.0428569316864, 75.06833866238594, 79.81240689754486, 74.42632511258125, 75.80932170152664, 64.70514714717865, 60.87301857769489, 59.8924545943737, 60.00318445265293, 58.48225146532059, 58.92303541302681, 62.202263250947, 64.46927100419998, 64.83024403452873, 60.70200115442276, 58.23430337011814, 55.998814925551414, 52.99488611519337, 51.46151639521122, 53.38399663567543, 54.732354283332825, 54.046004712581635, 56.012611985206604, 60.74544042348862, 64.45990070700645, 66.19228094816208, 65.54127708077431, 65.80901831388474, 65.54757714271545, 61.54509611427784, 63.28416019678116, 68.00146266818047, 67.38460376858711, 63.76451522111893, 63.09784099459648, 50.03389120101929, 57.884395346045494, 69.2436084151268, 55.69942519068718, 54.525185599923134, 53.8916227966547, 55.012900829315186, 64.94341716170311, 63.41864638030529, 62.27030619978905, 59.35268595814705, 59.38149981200695, 63.42034488916397, 59.45390872657299, 58.77933852374554, 64.32589709758759, 59.994140937924385, 64.32262927293777, 53.201880007982254, 54.63648922741413, 65.62760084867477, 60.764450803399086, 63.352157548069954, 64.09426152706146, 56.58692076802254, 42.45957523584366, 58.350577130913734, 61.223367378115654, 62.5228064507246, 58.659549951553345, 57.29131557047367, 58.20995807647705, 57.989835888147354, 59.35974977910519, 59.38419386744499, 58.08807961642742, 58.374683037400246, 55.9043899923563, 56.988091841340065, 61.3630098849535, 41.23332783579826, 52.92395532131195, 66.6303214430809, 57.631693705916405, 59.04850088059902, 55.14529712498188, 54.97060529887676, 52.34557315707207, 50.30763231217861, 49.51054908335209, 48.01277965307236, 48.57888847589493, 52.000574469566345, 50.36176800727844, 50.54758183658123, 49.77000676095486, 47.23825201392174, 48.36915872991085, 49.436054080724716, 51.07808277010918, 57.857838571071625, 60.06125293672085, 62.759750336408615, 61.436908319592476, 64.4260673224926, 65.12583777308464, 65.75234055519104, 64.7229453921318, 62.91599415242672, 62.96036817133427, 61.25357195734978, 55.682253912091255, 58.30824360251427, 65.19541963934898, 65.89236304163933, 69.77710738778114, 72.9103584587574, 71.35982125997543, 70.88445156812668, 70.31655684113503, 67.77240335941315, 63.542417138814926, 61.15136504173279, 58.34073185920715, 60.26953116059303, 65.23872971534729, 72.81239211559296, 75.02942875027657, 82.51777052879333, 13.505607694387436, 0.663548419252038, 0.5113822594285011, 0.08678894606418908, 43.10346968472004, 71.96419402956963, 73.84129330515862, 66.20604380965233, 46.97947449982166, 34.52782765030861, 34.51545171439648, 64.22175228595734, 2.620731247588992, 0.3756289032753557, 3.4419077960774302, 25.596279613673687, 23.52211531251669, 8.2780790515244, 8.558428958058357, 18.1720232963562, 34.97295096516609, 19.664341919124126, 1.7493633111007512, 0.20593746041413397, 0.13381808734266087, 0.21078837511595339, 0.5535238981246948, 47.31346137821674, 86.30851551890373, 52.904887944459915, 24.210520572960377, 59.994714707136154, 60.65309397876263, 60.47820836305618, 92.38825768232346, 89.20240223407745, 2.6316908095031977, 0.17779522051569074, 0.8800290967337787, 0.22768158582039177, 0.7671651779673994, 0.23412302689393982, 8.366053830832243, 18.670966923236847, 41.803339049220085, 77.62254640460014, 81.98906689882278, 88.68594154715538, 86.98778226971626, 87.61823683977127, 82.49112635850906, 81.13509312272072, 83.90919506549835, 80.33970460295677, 83.00355926156044, 79.86792951822281, 79.33174788951874, 69.75622370839119, 65.08811339735985, 62.97785863280296, 60.89818462729454, 61.91994599997997, 62.26052172482014, 63.99459287524223, 67.67809242010117, 68.31755250692368, 61.91510505974293, 60.4476124048233, 59.5130829513073, 54.53839369118214, 52.0958087593317, 56.88930854201317, 57.47696600854397, 56.45754911005497, 59.169653579592705, 62.76109926402569, 69.17187586426735, 69.46946829557419, 68.36480677127838, 71.62418067455292, 67.58609935641289, 60.64273193478584, 67.23748326301575, 70.1464931666851, 71.04725763201714, 64.69734996557236, 64.21112045645714, 61.429369524121284, 63.96235540509224, 61.65099263191223, 58.27323608100414, 57.468595057725906, 56.13983675837517, 59.80248302221298, 69.46129113435745, 66.58688217401505, 64.9265992641449, 61.41589544713497, 62.527259811758995, 65.6873868405819, 62.52207309007645, 61.22321918606758, 66.6593898832798, 62.143176421523094, 68.00844669342041, 55.56083142757416, 57.931645810604095, 68.74026462435722, 62.36061595380306, 63.450773656368256, 66.53294026851654, 59.98122923076153, 42.54625238478184, 61.17434240877628, 66.91337585449219, 63.62325020134449, 58.591590598225594, 58.711576759815216, 60.427059307694435, 60.49123406410217, 62.273957803845406, 62.15830720961094, 59.156791269779205, 62.32622019946575, 59.84768159687519, 59.897918701171875, 56.47880896925926, 44.69197444617748, 52.20452852547169, 69.80850130319595, 60.91743439435959, 59.88955155014992, 57.54651367664337, 58.08015324175358, 57.15551845729351, 55.316033363342285, 52.48572863638401, 52.2965481877327, 51.6143099963665, 54.88195985555649, 52.211584746837616, 54.4039873033762, 54.938785806298256, 49.89966340363026, 51.975568011403084, 53.71422931551933, 54.9041772633791, 59.84049618244171, 64.15558263659477, 64.05500963330269, 63.13760206103325, 67.911536693573, 70.20989656448364, 70.62268361449242, 69.48782131075859, 65.18001526594162, 68.64425897598267, 65.95097109675407, 60.24297058582306, 63.295612782239914, 68.91751751303673, 70.83328351378441, 73.85013923048973, 76.78932711482048, 75.5529722571373, 76.18250727653503, 76.52448132634163, 74.97369334101677, 71.87853142619133, 71.73116013407707, 66.84149891138077, 73.23445826768875, 78.02787065505981, 84.59637299180031, 83.01852285861969, 92.18767404556274, 15.297189708799124, 0.8283846429549158, 2.039497336372733, 0.2750290045514703, 56.05503670871258, 83.47217291593552, 85.94921439886093, 79.40130695700645, 66.62186309695244, 46.5316267311573, 50.871161073446274, 80.04989415407181, 3.0317288311198354, 0.46566507196985185, 5.247868001461029, 38.43352787196636, 46.02838933467865, 11.624169051647186, 10.317792501300573, 22.566937766969204], [18.846069127321243, 10.26314003393054, 0.7188683445565403, 0.03513806528644636, 0.07238565565785393, 0.0374520817422308, 0.5185234418604523, 27.730531990528107, 63.16478580236435, 35.25972917675972, 13.677295781672, 38.45098413527012, 39.485569819808006, 45.263915956020355, 78.96566793322563, 74.0981063246727, 4.981276206672192, 0.2355199120938778, 0.1709586154902354, 0.17228885582881048, 0.23338387749390677, 0.6042049848474562, 5.931823700666428, 4.443233152851462, 4.127579340711236, 32.26906165480614, 67.39559277892113, 76.40404298901558, 77.69456773996353, 78.07402297854424, 75.78065603971481, 69.82398927211761, 69.48895364999771, 68.82364735007286, 68.74544754624367, 66.17262840270996, 62.06817984580994, 57.785695642232895, 57.50130370259285, 55.185639560222626, 53.2753224670887, 55.44185981154442, 55.33575430512428, 56.31876915693283, 57.431695237755775, 59.88462321460247, 56.74602963030338, 54.98690262436867, 53.86902540922165, 50.08845627307892, 48.87895077466965, 49.911898747086525, 50.35460539162159, 54.963378086686134, 58.21361728012562, 61.10818795859814, 61.55446641147137, 62.89427071809769, 63.525215461850166, 66.81908771395683, 62.46650867164135, 61.620803251862526, 65.40296450257301, 59.83758553862572, 66.83296456933022, 68.42617347836494, 61.602408438920975, 58.47436688840389, 39.589646235108376, 50.107960626482964, 59.3733986467123, 52.32129625976086, 46.75813637673855, 49.40896153450012, 58.13732497394085, 56.52428112924099, 59.320155903697014, 60.00447638332844, 57.636606842279434, 53.62018436193466, 55.03467746078968, 59.75530095398426, 59.002489149570465, 60.857971385121346, 50.50275944173336, 47.18395292758942, 47.301568016409874, 57.304645255208015, 54.376852959394455, 55.13268560171127, 52.43652507662773, 45.055143758654594, 47.30803146958351, 48.88512544333935, 46.593198627233505, 48.98077391088009, 60.203049927949905, 59.01405952870846, 55.092726945877075, 53.14458288252354, 56.69526055455208, 54.69269201159477, 56.40282064676285, 53.163866847753525, 49.603389501571655, 55.10483309626579, 37.27875083684921, 41.37778848409653, 54.91149187088013, 57.636736035346985, 57.7083545923233, 55.46882316470146, 54.05389688909054, 52.06465043127537, 51.40862703323364, 46.31547912955284, 49.909360483288765, 46.86267636716366, 49.16647754609585, 49.06064562499523, 47.65341013669968, 46.345083341002464, 45.776128470897675, 44.05645854771137, 47.06369698047638, 44.00575026869774, 49.068332612514496, 54.57236006855965, 57.380390390753746, 55.571360662579536, 56.03067621588707, 58.33518795669079, 56.67168281972408, 55.03155402839184, 56.29368670284748, 54.27874602377415, 55.28572998940945, 55.03329813480377, 53.86613376438618, 54.50540006160736, 60.21909646689892, 65.98298817873001, 67.37890407443047, 67.42264732718468, 65.48485770821571, 66.01629719138145, 64.61253091692924, 62.724579423666, 57.21165284514427, 51.65678791701794, 47.67891816794872, 43.42249296605587, 45.3444754332304, 53.67922179400921, 61.22545726597309, 74.19655904173851, 25.60788419097662, 0.23658332065679133, 0.10345866641728207, 0.14696884027216583, 26.53541821986437, 62.843486443161964, 58.572511821985245, 55.39884991943836, 31.705796979367733, 30.98391931504011, 21.3279477506876, 42.793413922190666, 3.6295965872704983, 0.8889773197006434, 4.675363646820188, 28.657767735421658, 13.28848734498024, 3.2923822570592165, 5.388307040557265, 7.83542275428772, 31.124072894454002, 13.05124992504716, 1.218675475101918, 0.05255105395917781, 0.03200433558959048, 0.03029036222869763, 0.39354975102469325, 37.33632154762745, 72.73809850215912, 43.846470415592194, 23.63734792917967, 40.97079612314701, 49.3664076179266, 52.79489144682884, 86.34842097759247, 83.74372154474258, 4.464972736313939, 0.19263697176938877, 0.20419256732566282, 0.221953927539289, 0.17899981525260955, 0.5528062710072845, 8.10070076957345, 2.918396587483585, 12.148212231695652, 54.83179874718189, 75.24228572845459, 81.10838815569878, 83.03817540407181, 80.70047244429588, 81.08229875564575, 76.20401412248611, 73.70666652917862, 73.14903885126114, 73.59252065420151, 69.72395583987236, 65.46610951423645, 62.635607197880745, 59.37496416270733, 59.8590923845768, 58.78158800303936, 58.952863812446594, 58.12448166310787, 58.94361510872841, 59.802365228533745, 62.5896030664444, 59.647960513830185, 56.78259886801243, 55.32913126051426, 51.42501935362816, 52.128859385848045, 52.654321789741516, 52.20632962882519, 58.19929204881191, 59.15828838944435, 61.05852462351322, 63.81924748420715, 65.51044553518295, 66.19417324662209, 65.63326254487038, 66.85225233435631, 65.69046467542648, 65.56165918707848, 63.15300643444061, 65.67471072077751, 68.77024501562119, 62.96306602656841, 60.24973422288895, 44.706846848130226, 53.50612588226795, 65.59802323579788, 58.18561278283596, 49.171037301421165, 49.947305247187614, 59.0420488268137, 60.2893128991127, 62.414067685604095, 62.26316638290882, 59.21196050941944, 57.842840775847435, 57.56827890872955, 63.805948197841644, 60.38539074361324, 61.92086175084114, 52.70000673830509, 47.20940016210079, 46.1800391972065, 56.52200885117054, 55.804371759295464, 53.235170021653175, 51.928800120949745, 45.86101971566677, 51.82470850646496, 50.07555976510048, 48.40652972459793, 50.95803201198578, 59.96674820780754, 61.67709343135357, 58.096967339515686, 57.4187683314085, 56.935415267944336, 58.65055963397026, 54.851721078157425, 54.50832970440388, 51.5839534252882, 62.16544322669506, 41.353450790047646, 44.592693373560905, 55.857325717806816, 60.548124611377716, 58.10073293745518, 57.33377829194069, 57.44158610701561, 55.404933393001556, 52.793436124920845, 51.701249331235886, 50.87586522102356, 49.329146817326546, 51.53813548386097, 51.50791950523853, 50.95847658813, 49.141889065504074, 48.66673596203327, 48.69578920304775, 51.246523931622505, 44.19877611100674, 51.28045231103897, 58.748791962862015, 58.03482927381992, 59.06427763402462, 59.23687197268009, 59.85531538724899, 58.89230266213417, 55.84382504224777, 56.18690103292465, 57.926295697689056, 57.3869526386261, 57.23182216286659, 57.35024280846119, 56.983847469091415, 61.60089612007141, 70.9246914088726, 72.52417758107185, 71.94353073835373, 71.44088611006737, 72.09935277700424, 70.08562043309212, 71.30806043744087, 65.1120825111866, 61.380405351519585, 56.85827940702438, 58.30233491957188, 58.40622894465923, 68.54810893535614, 71.19948506355286, 84.17461842298508, 32.36521549522877, 0.33670414821244776, 0.39198515529278666, 0.17364982108119875, 31.794647611677647, 74.40686255693436, 68.98679539561272, 67.67854079604149, 48.39478075504303, 40.21986521780491, 27.996774204075336, 60.75025096535683, 4.024149365723133, 0.7608036661986262, 4.838869348168373, 32.676312401890755, 27.659416906535625, 3.847538405098021, 5.763779142871499, 12.458765767514706, 37.134225592017174, 18.663361631333828, 0.9023179882206023, 0.20396716223331168, 0.21640713064698502, 0.1790415239520371, 0.6272983050439507, 50.143515318632126, 84.7822818160057, 55.25228038430214, 27.080041095614433, 51.80334985256195, 57.872038409113884, 64.36409264802933, 91.48022800683975, 93.9676733314991, 7.220381582155824, 0.37315214867703617, 0.6287715572398156, 0.3464244125643745, 0.4351027181837708, 0.9815804881509393, 11.853653937578201, 14.532246105372906, 44.87946778535843, 79.1082514822483, 85.54022714495659, 90.14015391469002, 87.67019525170326, 85.12794926762581, 84.4871136546135, 78.6398734152317, 78.28517004847527, 73.76002326607704, 77.56678819656372, 73.77279818058014, 70.79805180430412, 65.74619248509407, 63.782640248537064, 63.86409267783165, 60.18164947628975, 61.70566409826279, 60.39620116353035, 62.5934636592865, 64.33483421802521, 67.6445098221302, 62.65249729156494, 59.34428080916405, 60.322279930114746, 55.99238947033882, 54.65947799384594, 55.11923432350159, 54.89298686385155, 60.388916954398155, 61.147417053580284, 64.00600746273994, 68.43432784080505, 66.71591565012932, 68.54557067155838, 72.22996696829796, 67.8935332596302, 66.83999419212341, 68.82300138473511, 66.98889300227165, 69.35444086790085, 70.7132251560688, 65.366250872612, 60.89409984648228, 51.270439848303795, 58.618371561169624, 60.40951944887638, 60.30336834490299, 56.15719422698021, 56.821330189704895, 61.84618815779686, 60.610817447304726, 67.24274978041649, 67.6563347876072, 60.89243933558464, 61.532803773880005, 61.064383909106255, 66.08034655451775, 65.46922534704208, 64.7705340385437, 54.05766248703003, 48.50342072546482, 46.55157186090946, 59.32848505675793, 58.745679929852486, 55.656270906329155, 55.11956490576267, 47.76735842227936, 50.614918023347855, 52.026652470231056, 52.068233639001846, 53.764538615942, 64.32734861969948, 62.25718930363655, 61.916294395923615, 57.436547577381134, 61.02451264858246, 60.379569455981255, 59.8750439286232, 59.377000853419304, 58.68859559297562, 56.20026111602783, 44.15326215326786, 44.95151951909065, 55.183215290308, 65.25775909423828, 61.32527410984039, 59.91147257387638, 60.84032513201237, 59.91325467824936, 57.142162173986435, 52.409918904304504, 55.03831006586552, 53.15777577459812, 54.05736230313778, 53.529281839728355, 52.8594271838665, 52.88392826914787, 52.990983724594116, 51.41863189637661, 54.176151528954506, 46.53680965304375, 53.99910382926464, 60.23265793919563, 59.57939699292183, 62.06930458545685, 62.40485318005085, 63.20971079170704, 62.056772857904434, 59.267008155584335, 60.757041200995445, 60.037865191698074, 62.555138915777206, 60.22428318858147, 59.16672773659229, 59.81488175690174, 65.56619614362717, 73.55610340833664, 75.5690149962902, 77.52064347267151, 76.70189380645752, 77.69401296973228, 76.70433327555656, 78.05994853377342, 70.92242673039436, 68.90433982014656, 68.34735050797462, 69.74189087748528, 71.66594043374062, 79.66233775019646, 81.5952256321907, 95.79130187630653, 38.72987397015095, 0.2858021983411163, 2.2024012450128794, 0.4484299389878288, 44.927649199962616, 84.49964538216591, 80.91275945305824, 80.22682785987854, 62.37966813147068, 56.10287234187126, 44.66345317661762, 80.0886444747448, 4.016957776620984, 0.7394945877604187, 6.898574475198984, 41.47413991391659, 39.51048508286476, 6.831499049440026, 7.274186220020056, 14.509947001934052], [18.328455202281475, 8.179231155663729, 0.07133540537324734, 0.07525766326580197, 0.025263807146984618, 0.028870312744402327, 0.7806691783480346, 26.776173301041126, 56.252572908997536, 34.2923466861248, 26.972938142716885, 32.28675730526447, 40.553608909249306, 49.89446148276329, 81.65754228830338, 78.63141506910324, 7.601502081379294, 0.4511527600698173, 0.48241929325740784, 0.133950189629104, 0.21083204308524728, 0.3499245294369757, 3.4762014308944345, 5.088831810280681, 3.248322196304798, 46.69075459241867, 70.71992799639702, 74.43240478634834, 77.93679714202881, 76.76110982894897, 77.14518561959267, 74.46037128567696, 72.96014338731766, 63.41000184416771, 63.00572633743286, 61.451149955391884, 55.853628516197205, 55.787960439920425, 55.63370391726494, 55.55170051753521, 53.300169333815575, 54.70663346350193, 54.441688880324364, 54.05990056693554, 53.24886828660965, 53.32716308534145, 55.72933718562126, 54.45716165006161, 50.87162084877491, 49.21312004327774, 49.523829370737076, 50.74451006948948, 52.69089102745056, 56.7272624373436, 62.96267084777355, 59.96666081249714, 59.748427122831345, 65.25827586650848, 63.26108403503895, 62.70784892141819, 62.40158535540104, 64.07629609107971, 66.50292187929153, 60.651042088866234, 57.810804694890976, 58.06670196354389, 60.418551564216614, 60.744957849383354, 65.67947566509247, 42.9342457652092, 37.25611925125122, 47.12286740541458, 50.56522808969021, 43.366947546601295, 53.106394931674004, 58.50453346967697, 57.655309438705444, 57.53207065165043, 55.531656593084335, 57.274364680051804, 54.932789728045464, 57.812108024954796, 58.50864864885807, 53.25279347598553, 42.57036969065666, 46.61801129579544, 47.1789675951004, 46.104069873690605, 47.34333157539368, 44.44167047739029, 42.05154173076153, 42.83472530543804, 48.849680945277214, 48.010085597634315, 48.73580865561962, 44.395601749420166, 50.89763045310974, 58.648332953453064, 62.27862015366554, 52.62709625065327, 54.354403764009476, 55.64383417367935, 54.57807496190071, 49.45291757583618, 54.297558814287186, 47.76100896298885, 35.95154285430908, 49.32874023914337, 50.32454900443554, 58.328633308410645, 55.9977737814188, 54.04303327202797, 54.74557377398014, 54.09656099975109, 52.80078113079071, 53.44747222959995, 52.1144999563694, 50.11066988110542, 48.495707139372826, 46.97582669556141, 47.97901086509228, 46.10047526657581, 44.084288254380226, 43.34521271288395, 44.028583243489265, 43.29580016434193, 47.0072016119957, 54.41654182970524, 55.161035880446434, 53.644153475761414, 55.86489491164684, 52.262733802199364, 50.668692737817764, 51.96141377091408, 51.03872828185558, 50.47287404537201, 53.47121335566044, 51.46646372973919, 52.271944507956505, 58.06726813316345, 61.28865547478199, 64.0879462659359, 63.31819497048855, 67.5283120572567, 65.83355739712715, 64.90427926182747, 62.29452230036259, 62.27054178714752, 54.756665378808975, 50.68229600787163, 45.344137251377106, 46.82049483060837, 44.13582108914852, 51.704334765672684, 54.62336853146553, 64.15470868349075, 37.94104389846325, 0.2854105818551034, 0.5879632907453924, 0.33360203029587865, 21.31405759602785, 70.35506397485733, 52.69651472568512, 56.70100584626198, 32.80187666416168, 28.87068171054125, 22.365856356918812, 39.28073041141033, 2.8282620990648866, 0.23562102229334414, 6.362813673913479, 21.507020741701126, 17.77993183583021, 3.9649492548778653, 3.9908379781991243, 8.206444345414639, 24.415304884314537, 12.098083421587944, 0.24440545326797292, 0.05983914452372119, 0.14325106632895768, 0.028156680236861575, 0.6250312516931444, 36.35200336575508, 64.88832011818886, 44.54087555408478, 29.4014011323452, 33.44371162354946, 41.164950504899025, 59.16848324239254, 86.76030367612839, 89.24081817269325, 8.688875008374453, 0.3640477481530979, 0.36665330990217626, 0.0537661649286747, 0.21374648669734597, 0.29007768142037094, 4.8335933312773705, 2.911429898813367, 16.947166621685028, 60.667457208037376, 78.45945909619331, 80.32421663403511, 84.31133508682251, 79.38391149044037, 82.16293796896935, 79.21520814299583, 77.27852046489716, 68.7229223549366, 67.93187320232391, 64.40546482801437, 61.992271319031715, 58.77552732825279, 59.894153103232384, 58.38909566402435, 55.6195230782032, 57.660317569971085, 56.122616082429886, 57.35200971364975, 56.160595044493675, 58.10741677880287, 56.64105266332626, 57.18458689749241, 54.231624752283096, 51.97560980916023, 51.54823154211044, 53.14416490495205, 54.23009343445301, 57.91334219276905, 63.73119480907917, 62.26660139858723, 64.53189924359322, 66.5549410879612, 65.92975303530693, 63.948554545640945, 64.97662737965584, 68.1070514023304, 67.95199692249298, 65.35408392548561, 61.01339444518089, 60.15077993273735, 62.39591985940933, 62.27796658873558, 67.32329785823822, 48.161480873823166, 42.578801438212395, 54.48299266397953, 59.52870391309261, 46.926326751708984, 53.11305597424507, 60.580118894577026, 59.75741744041443, 61.7071308195591, 58.2810028642416, 61.74309588968754, 57.79907092452049, 57.84154884517193, 57.88888670504093, 53.211725279688835, 44.698597490787506, 48.41410271823406, 49.01666298508644, 47.869485542178154, 47.69394636154175, 45.04363417625427, 43.74598480761051, 44.2762615531683, 49.38289113342762, 49.67963621020317, 54.74563457071781, 44.353557005524635, 51.43316991627216, 59.56253729760647, 63.2195408642292, 56.074962839484215, 58.595219403505325, 54.080263674259186, 56.36258080601692, 51.48325502872467, 59.89618979394436, 51.56467705965042, 39.454920664429665, 52.248723953962326, 53.258683159947395, 60.28212368488312, 55.664056688547134, 57.23798543214798, 57.42462761700153, 54.73265826702118, 54.13703642785549, 55.939997881650925, 51.989897042512894, 54.75302517414093, 53.610513880848885, 51.600345745682716, 50.8437455445528, 46.82109899818897, 46.74565404653549, 46.85836739838123, 48.148523569107056, 46.74035333096981, 49.57357630133629, 57.149484381079674, 57.19627507030964, 56.5643347799778, 58.36011841893196, 56.192589327692986, 53.45196358859539, 55.5178215354681, 53.30200843513012, 54.06168647110462, 55.700485333800316, 54.08744528889656, 56.60357527434826, 61.0597063601017, 65.53401187062263, 67.4477867782116, 69.73280176520348, 72.90609508752823, 70.25873154401779, 69.69304829835892, 69.04506906867027, 68.89041736721992, 64.93120461702347, 60.699801072478294, 57.69370257854462, 57.50025115907192, 57.22621746361256, 64.19178709387779, 66.33682519197464, 76.14106670022011, 49.37048099935055, 1.0006028017960489, 0.4305604478577152, 0.4611981147900224, 26.2477470561862, 83.34388419985771, 65.02274930477142, 72.78646230697632, 43.567151203751564, 41.19712717831135, 28.62840101122856, 58.74108977615833, 4.157813843339682, 0.2950161398621276, 5.637285830453038, 33.007597625255585, 24.284014329314232, 3.087662304751575, 5.909382104873657, 7.3881463799625635, 31.05209145694971, 13.577920664101839, 0.23424718820024282, 0.1592831630841829, 0.2543440129375085, 0.1294657919788733, 0.9975613025017083, 49.67723473906517, 78.61742421984673, 53.195199966430664, 40.48249572515488, 49.87335741519928, 53.39182801544666, 71.13011598587036, 91.9640864431858, 100.2574074268341, 12.672950774431229, 0.6219304993283004, 1.7151145613752306, 0.1452881726436317, 0.44138882774859667, 0.8561222045682371, 5.400267848744988, 24.05178029090166, 53.96607980132103, 80.17080366611481, 87.97631442546844, 86.83831349015236, 88.00486609339714, 83.63887757062912, 85.9267196059227, 84.72532287240028, 81.6579982638359, 70.59319719672203, 71.57561928033829, 69.36993643641472, 65.62057882547379, 61.244026869535446, 62.33842134475708, 61.250482723116875, 57.963913679122925, 62.1180559694767, 61.27318650484085, 59.87542010843754, 58.593357503414154, 61.06636360287666, 60.17424367368221, 60.259594693779945, 57.60284945368767, 52.39299841225147, 54.89288046956062, 55.69299973547459, 58.3672696352005, 59.31964673101902, 69.86835569143295, 66.16587996482849, 64.78402331471443, 68.2461467385292, 65.65066561102867, 64.8928190767765, 67.87909403443336, 69.02318984270096, 70.10832041501999, 67.03949108719826, 65.38253679871559, 66.41051083803177, 66.94437459111214, 66.72926813364029, 68.86137932538986, 51.50340534746647, 48.772556483745575, 53.05743835866451, 55.92621982097626, 50.69357380270958, 57.49112404882908, 64.91309478878975, 62.47194617986679, 65.10930106043816, 60.39431266486645, 62.82188080251217, 59.56661827862263, 66.0575857758522, 57.1565406024456, 59.171222895383835, 45.796202793717384, 49.371677935123444, 48.26911009848118, 50.03108695149422, 49.21526312828064, 45.89685179293156, 44.4306206703186, 44.55768205225468, 53.62773075699806, 51.0234759002924, 53.2002878934145, 43.09831716120243, 53.93712915480137, 64.07116636633873, 66.07769429683685, 59.88163277506828, 58.160328939557076, 59.09205034375191, 59.93461713194847, 55.55116854608059, 58.12473624944687, 54.47621002793312, 42.74753138422966, 54.37665916979313, 53.708913400769234, 63.1058319658041, 61.0566171258688, 61.1374805867672, 59.50200654566288, 57.92042501270771, 57.367296293377876, 58.844052851200104, 57.43084408342838, 55.42757257819176, 56.17387533187866, 52.3762983083725, 52.742404863238335, 49.85474221408367, 52.0097129791975, 49.89448048174381, 49.34089578688145, 50.78524008393288, 51.36850118637085, 60.589052215218544, 61.25528946518898, 59.7008840739727, 61.229165866971016, 58.54316979646683, 55.55355481803417, 60.194998160004616, 56.391911432147026, 57.02194422483444, 60.088759660720825, 56.90781734883785, 60.05087569355965, 64.44612264633179, 69.02076557278633, 70.65543785691261, 73.19847419857979, 74.85745757818222, 74.23498257994652, 72.63193979859352, 73.87265682220459, 74.31508988142014, 72.23779454827309, 67.73829638957977, 67.57568031549454, 69.40340504050255, 68.6289381980896, 76.19455263018608, 76.41973614692688, 84.73012581467628, 57.53269001841545, 1.5702671650797129, 0.8630458486732095, 0.5321967112831771, 32.379525527358055, 93.72630268335342, 74.48101177811623, 83.88264209032059, 58.70506010949612, 56.837228536605835, 47.83028684556484, 80.1600730419159, 5.669212192296982, 0.2751114423153922, 9.06798541545868, 33.693947196006775, 47.702723890542984, 5.128916334360838, 7.4628907442092896, 15.37444431334734], [10.068408083170652, 3.913128348067403, 0.06319697684375569, 0.024531132985430304, 0.050353985134279355, 0.059989347791997716, 1.3965459493920207, 28.722784146666527, 57.0538929104805, 29.607139192521572, 32.52049796283245, 42.01718397438526, 60.989231541752815, 53.33734653890133, 77.8769351541996, 82.10721015930176, 15.252521205693483, 0.16151512769283727, 0.16109781805425882, 0.028584255633177236, 0.09141709771938622, 0.31209447188302875, 6.258385302498937, 5.6218477338552475, 16.33814860135317, 58.91542062163353, 72.35636338591576, 71.74355506896973, 81.18140503764153, 76.57724529504776, 78.1010851264, 74.27211418747902, 73.28130975365639, 67.41976708173752, 64.20396164059639, 62.71541431546211, 54.8364344984293, 58.09460386633873, 53.83266896009445, 52.70179644227028, 52.79139183461666, 52.56824500858784, 51.59873463213444, 54.21721592545509, 53.78335900604725, 52.498860731720924, 53.48963476717472, 53.61259616911411, 50.34900829195976, 48.08890096843243, 50.22277906537056, 52.131295055150986, 51.83774560689926, 57.54750542342663, 59.59625668823719, 61.53345353901386, 64.4900330901146, 62.20290161669254, 60.93302495777607, 60.4934873431921, 58.34301173686981, 58.81200537085533, 61.11799903213978, 64.47776734828949, 65.89341178536415, 60.21288000047207, 59.57407347857952, 59.720635414123535, 60.85995487868786, 64.19668883085251, 51.58240310847759, 39.08537149429321, 43.7215331196785, 53.167906031012535, 54.7090957313776, 59.17226783931255, 58.53939279913902, 53.040916845202446, 55.035213232040405, 60.044571831822395, 54.75177884101868, 54.45371523499489, 50.75017936527729, 43.13438482582569, 47.0206680893898, 49.4612505286932, 49.97924253344536, 43.68837229907513, 39.98639814555645, 40.38639508187771, 43.03461737930775, 47.265466153621674, 44.096869379282, 46.11042693257332, 46.02010577917099, 43.36897663772106, 42.87910312414169, 55.186787098646164, 56.83564022183418, 55.576684176921844, 56.25203713774681, 53.402627035975456, 47.33275294303894, 49.090876802802086, 46.74654699862003, 36.905800849199295, 46.667347848415375, 52.44549259543419, 55.7912814617157, 58.501201048493385, 55.689705312252045, 54.62455026805401, 54.12242241203785, 53.144993260502815, 54.01927314698696, 55.36957249045372, 52.336997017264366, 48.761229291558266, 52.41304233670235, 50.56420214474201, 52.818655371665955, 47.712610960006714, 44.883210584521294, 45.22726312279701, 45.26675820350647, 45.49729563295841, 46.7141879349947, 53.022271245718, 54.8745958507061, 53.257885202765465, 54.1970694065094, 53.53616327047348, 55.13503007590771, 49.92170222103596, 49.41042445600033, 50.89061602950096, 52.17048995196819, 50.826331079006195, 52.15957313776016, 58.216212540864944, 62.68820017576218, 64.10563811659813, 66.27630203962326, 68.29135671257973, 66.89876183867455, 66.07281535863876, 63.6900582164526, 63.020503744482994, 55.394863933324814, 54.05962698161602, 49.050872549414635, 50.53797595202923, 47.11941339075565, 55.240854397416115, 56.79049864411354, 66.62121713161469, 57.22250506281853, 0.9357265674043447, 0.21349958900827914, 0.08453283197013661, 38.759884759783745, 74.12735715508461, 51.02864742279053, 59.20320577919483, 33.511287197470665, 20.46246439218521, 21.778852455317974, 41.829329654574394, 1.6615136875770986, 0.09225116038578562, 7.352199833840132, 20.280663147568703, 20.01386236399412, 4.548819037154317, 4.018178461119533, 10.932022891938686, 19.65687531977892, 7.774351956322789, 0.09660121446358971, 0.07864535218686797, 0.0965781559352763, 0.056306365731870756, 1.4277921477332711, 41.80443339049816, 68.34622576832771, 36.115253269672394, 37.57813677191734, 46.32555238902569, 64.287488758564, 65.15628933906555, 80.75670942664146, 94.31209444999695, 17.608277946710587, 0.21528929297346622, 1.295295632444322, 0.034647331267478876, 0.18753087701043114, 0.3852284647291526, 4.7734354343265295, 1.6959323594346642, 29.337178878486156, 73.02787855267525, 79.983861297369, 79.51220020651817, 87.71989658474922, 80.27715235948563, 80.87572664022446, 78.84391486644745, 79.41479623317719, 72.46227890253067, 71.44515708088875, 67.1409684419632, 61.712283343076706, 61.33347786962986, 58.69457267224789, 54.91552725434303, 56.047007739543915, 55.65374404191971, 55.42487092316151, 57.70220272243023, 55.67916087806225, 55.23387037217617, 54.40539702773094, 56.31228670477867, 52.93205268681049, 53.501026555895805, 51.51690982282162, 53.303566351532936, 54.82248544692993, 60.06088815629482, 61.90926097333431, 64.46218058466911, 67.33364090323448, 64.43860664963722, 62.13216841220856, 63.06566812098026, 61.12514644861221, 60.52222520112991, 64.11304771900177, 64.01787802577019, 67.239421159029, 61.268223971128464, 61.071827709674835, 64.44264203310013, 62.00156182050705, 67.88030236959457, 57.20711208879948, 44.121666848659515, 47.913031205534935, 59.15058620274067, 57.21432410180569, 61.03112429380417, 61.65749788284302, 56.10330931842327, 57.07043722271919, 62.67582044005394, 55.047011598944664, 55.18960654735565, 52.10298277437687, 49.2690796405077, 49.11959186196327, 50.25358781218529, 54.30786766111851, 44.516252875328064, 39.20833669602871, 40.25126293301582, 42.967497780919075, 50.60816578567028, 43.733939453959465, 45.72234235703945, 43.787645772099495, 44.83318246901035, 42.36536309123039, 56.97004280984402, 60.07675610482693, 59.89305876195431, 59.834598898887634, 56.64192281663418, 48.500893861055374, 51.65721729397774, 53.79955753684044, 40.48079341650009, 49.762133583426476, 53.427546098828316, 59.26030531525612, 59.93057034909725, 58.36035780608654, 56.767118498682976, 57.78531566262245, 56.438303142786026, 58.35204005241394, 56.371286138892174, 55.22144503891468, 54.018950164318085, 55.037493109703064, 53.16037103533745, 54.05804246664047, 48.08371804654598, 46.07555240392685, 47.62730173766613, 46.79270312190056, 47.550686448812485, 49.02530372142792, 54.883354380726814, 56.42066828906536, 56.15824297070503, 55.373205095529556, 55.07069572806358, 57.08269156515598, 52.8572802990675, 52.91803523898125, 54.82965186238289, 55.76548084616661, 54.229059889912605, 54.913410767912865, 61.56814947724342, 65.90081378817558, 68.28678175806999, 69.30820494890213, 74.20636251568794, 75.11969670653343, 73.07144701480865, 71.47406592965126, 69.654700756073, 66.13605916500092, 62.71577909588814, 58.92133690416813, 60.11759251356125, 59.41839203238487, 67.30251297354698, 68.78748089075089, 75.09083345532417, 66.54117062687874, 2.3845606204122305, 0.6014265620615333, 0.07678898851736449, 42.676251009106636, 84.83357906341553, 60.04038445651531, 72.82776609063148, 47.30238117277622, 34.360161647200584, 31.191483177244663, 59.60280753672123, 2.5046149408444762, 0.18481323611922562, 7.355985855683684, 28.63050799816847, 25.78432012349367, 4.409478614106774, 6.142934197559953, 9.975035693496466, 22.899687811732292, 6.102639259770513, 0.22453859040979296, 0.1689290048670955, 0.3040882421191782, 0.17890764051117003, 2.0174789428710938, 55.00611059367657, 78.78587678074837, 46.19040884077549, 44.82625924050808, 58.30660209059715, 76.31449699401855, 73.72882694005966, 84.94283840060234, 103.46296101808548, 20.949695147573948, 0.25551598286256194, 1.4286725129932165, 0.22630726190982386, 0.3050709643866867, 0.6000627914909273, 11.739697102457285, 41.276668310165405, 67.6713515818119, 81.97623878717422, 87.53121390938759, 84.65413749217987, 88.6758416891098, 85.20127773284912, 84.20913577079773, 81.2681695818901, 82.51594662666321, 76.87327221035957, 73.3846490085125, 73.88662487268448, 64.0988440811634, 66.05961486697197, 63.449812307953835, 58.868888318538666, 58.623843267560005, 57.88325160741806, 57.880572751164436, 60.06025359034538, 59.70653057098389, 56.32169499993324, 59.45770852267742, 59.586544409394264, 55.9944261610508, 53.44053380191326, 54.58834961056709, 56.18268705904484, 55.32737195491791, 62.959251031279564, 63.758648335933685, 66.23299196362495, 67.8509147465229, 66.27845272421837, 64.92194071412086, 65.04585966467857, 62.14370459318161, 61.96252651512623, 64.89766761660576, 64.85768616199493, 70.17088785767555, 64.62811008095741, 66.32665693759918, 64.61260691285133, 68.32465812563896, 66.14466950297356, 60.71536123752594, 48.55452798306942, 50.704760402441025, 56.507854610681534, 54.947643131017685, 63.57954114675522, 64.03542548418045, 59.65983107686043, 60.18119730055332, 66.01930662989616, 58.513052612543106, 53.53594288229942, 56.05431094765663, 48.65978613495827, 51.346998140215874, 53.4860173612833, 53.49603742361069, 44.413103610277176, 41.59149281680584, 42.394864708185196, 44.49246235191822, 49.41107802093029, 45.662970542907715, 50.10175555944443, 45.11564031243324, 45.16569122672081, 42.70294837653637, 57.448767721652985, 63.595435693860054, 60.968195870518684, 62.09016926586628, 57.79509633779526, 48.88823747634888, 51.74518257379532, 52.19306454062462, 44.92239028215408, 52.14843973517418, 55.97526378929615, 61.69734634459019, 64.21241238713264, 59.36931386590004, 59.91676568984985, 60.52374131977558, 57.01407104730606, 60.71796029806137, 61.005327478051186, 57.74222977459431, 56.31669446825981, 57.49778889119625, 55.63988998532295, 59.294560477137566, 53.33715654909611, 50.55752590298653, 51.76539748907089, 50.002607479691505, 49.204110726714134, 53.312834054231644, 59.46464315056801, 59.82688531279564, 57.05163963139057, 58.00587482750416, 59.417803063988686, 60.43910466134548, 56.237651109695435, 57.96666853129864, 58.861949890851974, 57.59289778769016, 57.504370138049126, 56.4954786747694, 63.91151413321495, 69.26673397421837, 71.7062258720398, 75.44319614768028, 76.37356862425804, 78.31211060285568, 76.6555742919445, 75.23069635033607, 71.54781997203827, 73.09492975473404, 68.52774202823639, 67.2425901889801, 70.5513234436512, 72.96410277485847, 75.52889674901962, 78.33588972687721, 81.41726598143578, 76.96454331278801, 3.3701645582914352, 1.9723115977831185, 0.1600994958425872, 49.62585389614105, 95.24274051189423, 71.04144394397736, 86.58395513892174, 58.16793613135815, 44.229816645383835, 48.34265135228634, 84.90365490317345, 4.610326336696744, 0.2464258167310618, 12.44669571518898, 29.517779387533665, 43.37325520813465, 7.254123296588659, 8.328048270195723, 21.412656605243683], [5.263777272775769, 0.4927835933631286, 0.06415401338017546, 0.10905154325882904, 0.05125915296957828, 0.04821708222152665, 2.1764291636645794, 29.340889379382133, 54.81446407735348, 37.74153180420399, 24.16481852531433, 29.559018574655056, 51.621430814266205, 55.3562618046999, 76.08278542757034, 80.01315012574196, 18.617602586746216, 0.41348270955495536, 0.9125677007250488, 0.046155729942256585, 0.6490425195079297, 1.2245568470098078, 5.604771925136447, 8.710723835974932, 36.670369282364845, 65.60936942696571, 71.38622984290123, 75.50222977995872, 78.72278496623039, 76.16742208600044, 76.8070113658905, 76.00264012813568, 72.35857486724854, 69.31252911686897, 65.47032728791237, 61.75931341946125, 57.81943403184414, 56.79712928831577, 56.803554743528366, 51.34347192943096, 54.05305713415146, 50.982878878712654, 52.53210134804249, 52.38245777785778, 52.51511625945568, 50.680947080254555, 51.8489246070385, 48.23806196451187, 50.14532022178173, 47.50167667865753, 48.004511296749115, 52.541171461343765, 53.60304728150368, 58.6153507232666, 61.00116670131683, 62.565839141607285, 61.99406482279301, 63.25613670051098, 63.48355829715729, 63.2681592553854, 59.37052220106125, 58.043697997927666, 60.92511758208275, 62.41425767540932, 62.31578215956688, 64.28279981017113, 61.104471758008, 59.939097091555595, 60.19337184727192, 59.40864555537701, 70.43001115322113, 63.40936727821827, 38.11830818653107, 35.79791709780693, 52.99205146729946, 57.82854974269867, 56.314425989985466, 54.54516492784023, 57.84197822213173, 53.445826917886734, 49.96816612780094, 49.48137424886227, 47.540901973843575, 50.75409695506096, 45.69535240530968, 54.02815327048302, 57.57606089115143, 35.710890367627144, 33.85863795876503, 32.9024800658226, 40.90371072292328, 59.185046553611755, 45.45697219669819, 43.32489900290966, 41.15494184195995, 43.98756064474583, 40.067557990550995, 51.65100462734699, 59.5234601944685, 57.98443637788296, 55.298299714922905, 57.01535537838936, 50.31923308968544, 56.89735271036625, 37.80111640691757, 39.31761883199215, 53.94235387444496, 50.708157420158386, 54.41767796874046, 59.02256727218628, 53.86733829975128, 57.81164824962616, 55.075954645872116, 56.876640021800995, 56.50368623435497, 55.2002839744091, 52.825806587934494, 53.75600427389145, 55.244015827775, 53.70100602507591, 50.43941684067249, 50.01928098499775, 48.403197303414345, 45.379243567585945, 44.847332909703255, 44.33852881193161, 45.440435484051704, 49.907388389110565, 54.00006137788296, 53.9206076413393, 55.012197867035866, 51.61890774965286, 54.71102222800255, 49.54827345907688, 53.59911069273949, 49.63483281433582, 53.00874397158623, 50.28768718242645, 53.56167130172253, 58.567667081952095, 64.10571411252022, 63.941137343645096, 66.93666100502014, 66.2929755449295, 68.07916089892387, 64.09208804368973, 67.91052594780922, 61.93447642028332, 60.75963266193867, 55.34361608326435, 54.59085367619991, 52.701682448387146, 56.34096376597881, 59.19728949666023, 66.66031703352928, 62.83495590090752, 76.17821350693703, 8.204103671014309, 0.40593750192783773, 0.11821570893516764, 33.95617112517357, 79.68297824263573, 48.119341135025024, 60.85696443915367, 36.36130906641483, 16.61723792552948, 17.016286812722683, 34.26395460963249, 0.47561664890963584, 0.29060656554065645, 7.6343228202313185, 19.024340361356735, 16.461431086063385, 5.755449514836073, 4.555822536349297, 12.680334728211164, 13.79537159577012, 2.6299293665215373, 0.02971123842144152, 0.029701002349611372, 0.04815784399397671, 0.06706721018417738, 2.1467449190095067, 40.700740814208984, 64.88929286599159, 44.170973002910614, 26.734031662344933, 39.33463051915169, 59.34670127928257, 64.27724450826645, 83.4524367749691, 87.81250521540642, 28.45971666276455, 0.33039004483725876, 0.9708768781274557, 0.0530104470817605, 0.6400674011092633, 1.7173795960843563, 9.793273396790028, 12.124029379338026, 49.34773921966553, 76.56902253627777, 79.01951864361763, 83.15511032938957, 82.56260052323341, 82.19696894288063, 81.71643152832985, 80.65210103988647, 78.86851474642754, 72.4665042757988, 71.05042666196823, 65.15903279185295, 64.8770423233509, 59.2037757486105, 59.19783666729927, 56.386249735951424, 57.953057661652565, 55.01820534467697, 56.74004875123501, 55.3327676653862, 56.65038116276264, 54.37659077346325, 57.582524344325066, 51.0799902677536, 52.145563289523125, 51.19466811418533, 50.85582509636879, 53.569825664162636, 55.018155947327614, 60.25606848299503, 63.79015624523163, 64.64821860194206, 64.47464391589165, 65.40308609604836, 67.30460286140442, 65.89433893561363, 61.00048653781414, 61.17486298084259, 63.228907361626625, 63.448630571365356, 60.92119239270687, 64.07111316919327, 64.0845188498497, 60.446841046214104, 61.23087577521801, 60.33048368990421, 70.90652078390121, 66.92553520202637, 44.33751046657562, 41.09449468553066, 55.43890357017517, 60.12197367846966, 60.10810062289238, 57.10310027003288, 60.747686102986336, 54.105319529771805, 52.95407250523567, 51.5255543589592, 49.489475414156914, 51.90342128276825, 47.48531475663185, 55.73800452053547, 58.405518382787704, 37.04243391752243, 34.01502996683121, 33.06101515889168, 41.576286032795906, 62.4039526283741, 47.293052673339844, 46.707162111997604, 44.23353664577007, 45.59263251721859, 41.8895298242569, 52.71554410457611, 61.07091195881367, 60.898078233003616, 57.25153170526028, 59.535566344857216, 50.93716353178024, 62.307502403855324, 42.55512110888958, 43.61956559121609, 56.750524789094925, 56.408022567629814, 55.65540835261345, 59.28452521562576, 56.814760342240334, 62.20414415001869, 56.23412489891052, 57.27509044110775, 57.40523345768452, 55.99215388298035, 54.76979747414589, 55.98506726324558, 58.030250519514084, 54.688371643424034, 53.45448665320873, 53.69522653520107, 49.79041166603565, 46.69254049658775, 46.93861909210682, 47.6900439709425, 49.15758602321148, 52.14898310601711, 56.77004814147949, 54.66109670698643, 57.47685581445694, 55.33812537789345, 57.55295433104038, 53.70183438062668, 55.983011573553085, 53.33948962390423, 54.71358709037304, 54.74866680800915, 55.775379315018654, 60.54359905421734, 66.76739528775215, 68.20773839950562, 71.57575607299805, 71.88512787222862, 74.17031764984131, 70.40575325489044, 74.2552962899208, 67.47245505452156, 69.61884588003159, 64.1297972202301, 62.21397802233696, 61.126168593764305, 67.1542601287365, 67.66223967075348, 80.35067081451416, 68.3659391105175, 82.04000696539879, 10.99410206079483, 0.7354936993215233, 0.14297540299594402, 37.723805755376816, 90.30717015266418, 57.155693247914314, 73.10018107295036, 49.019273445010185, 24.864651672542095, 24.07127134501934, 49.89065408706665, 0.7825000863522291, 0.14038802386494353, 9.29216768592596, 26.792086847126484, 27.684970535337925, 6.528594978153706, 6.303344490006566, 14.730314277112484, 14.54599566757679, 1.2503664870746434, 0.20023070101160556, 0.21964046027278528, 0.2365499536972493, 0.22588797815842554, 2.742751962505281, 57.385816499590874, 76.80562064051628, 57.8680220246315, 34.60421875119209, 41.39444299042225, 65.90576112270355, 74.87727731466293, 87.7391767501831, 94.39527198672295, 34.337780848145485, 0.40727357554715127, 2.7749469224363565, 0.21045161818619817, 1.2373406672850251, 2.81947982031852, 46.165976151824, 56.88020423054695, 76.52489170432091, 81.71355128288269, 84.55731868743896, 83.70907500386238, 85.52397921681404, 84.9024997651577, 84.59294557571411, 86.12165674567223, 81.68531879782677, 78.44303637742996, 75.80608427524567, 67.96068325638771, 65.54107949137688, 64.00012537837029, 61.872965320944786, 59.23219822347164, 60.35367764532566, 56.80625639855862, 58.964373394846916, 57.791938707232475, 59.678856655955315, 57.86040723323822, 60.497530326247215, 52.58284002542496, 54.996873289346695, 54.36307869851589, 54.14438143372536, 56.414387226104736, 57.44451195001602, 60.8205433934927, 67.40935564041138, 64.34098988771439, 67.36413046717644, 68.21156099438667, 68.00270140171051, 67.86657750606537, 63.00038002431393, 64.41305682063103, 66.53961271047592, 68.0346728861332, 64.54272866249084, 66.96126848459244, 63.607313856482506, 64.77966874837875, 63.53094555437565, 63.515472784638405, 73.9904049038887, 66.12880155444145, 49.739357605576515, 44.30428504943848, 53.66073578596115, 60.76265349984169, 61.18166081607342, 58.44289317727089, 62.44772627949715, 58.5283961892128, 52.269448041915894, 54.12608541548252, 52.935578897595406, 55.16799330711365, 51.462283954024315, 58.12369890511036, 61.07570730149746, 36.5595368295908, 35.073197185993195, 33.48148159682751, 43.67295652627945, 64.60408017039299, 47.807119488716125, 47.17555917799473, 44.65138882398605, 45.522868260741234, 42.81163014471531, 53.10927897691727, 63.813418596982956, 63.01528662443161, 59.35609817504883, 63.9478325843811, 53.4649208933115, 58.44493746757507, 44.036737605929375, 47.36940197646618, 57.5577724725008, 56.208024099469185, 55.6340117007494, 65.21068722009659, 60.687368139624596, 62.62361504137516, 58.86961027979851, 60.43021693825722, 61.27790205180645, 61.33058622479439, 59.81598749756813, 59.987692683935165, 62.59434141218662, 58.55787880718708, 56.5152832120657, 56.717656552791595, 54.39229153096676, 50.739061161875725, 51.228797882795334, 48.96605350077152, 52.298657074570656, 55.04988804459572, 60.43202184140682, 57.891272976994514, 61.13045856356621, 56.99738994240761, 62.19150982797146, 57.2452088445425, 58.997986391186714, 58.14653567969799, 58.949349001049995, 56.0289017111063, 58.5850815474987, 63.94078016281128, 71.85191005468369, 70.04429385066032, 76.12994089722633, 74.26740244030952, 76.74405634403229, 73.75975728034973, 76.74914807081223, 73.4376409649849, 75.750972032547, 69.80714097619057, 71.41186326742172, 68.44529405236244, 78.81733909249306, 76.78558811545372, 88.00154507160187, 73.36460128426552, 85.94074085354805, 11.862952038645744, 1.5562659851275384, 0.33013041189406067, 40.823512226343155, 98.46439003944397, 65.50074845552444, 85.63440889120102, 61.723815724253654, 37.80338108539581, 38.3552672713995, 76.49362698197365, 2.272927835583687, 0.7837543752975762, 11.460528932511806, 31.574261337518692, 39.08718779683113, 14.462539795786142, 10.837495364248753, 27.74518210440874], [4.164080182090402, 0.14239246083889157, 0.035254040703875944, 0.06873749516671523, 0.020084460556972772, 0.1339052600087598, 3.0862338189035654, 37.10498236119747, 55.556412264704704, 30.62405962496996, 34.26018141210079, 35.81864878535271, 57.86567375063896, 58.45218367874622, 77.67508998513222, 76.77092850208282, 48.71071860194206, 0.42719994380604476, 0.7603609305806458, 0.29377411119639874, 0.30814137775450945, 1.4173509017564356, 9.517071917653084, 18.506610542535782, 51.24320670962334, 67.06586927175522, 72.27529093623161, 74.897401034832, 74.9533112347126, 75.95587983727455, 72.8171418607235, 73.7436917424202, 73.24244543910027, 68.86208608746529, 68.08462500572205, 66.38637453317642, 61.14062301814556, 57.73911774158478, 55.320467725396156, 52.537861838936806, 55.152383744716644, 53.64000789821148, 51.067602932453156, 51.8741362541914, 50.74199840426445, 52.52350240945816, 52.34398104250431, 49.35970477759838, 48.49651649594307, 49.006152749061584, 47.29064740240574, 51.59240037202835, 54.560079127550125, 62.527567595243454, 61.34195141494274, 62.415036633610725, 61.19135029613972, 65.95479369163513, 61.91253639757633, 59.582737013697624, 56.38273872435093, 58.73243764042854, 58.34269255399704, 60.68358734250069, 58.2882072776556, 58.72972458600998, 58.85297477245331, 57.3145817220211, 55.5236542224884, 61.16000957787037, 56.7199744284153, 61.54630824923515, 51.92140191793442, 44.87554259598255, 43.51285971701145, 48.053483068943024, 59.92476046085358, 56.58587962388992, 59.99234363436699, 49.31580193340778, 47.46359892189503, 48.27623851597309, 49.636052548885345, 45.25990717113018, 46.075119227170944, 52.780239433050156, 61.651475206017494, 52.15828500688076, 33.67886580526829, 33.62124189734459, 51.65929198265076, 58.32791894674301, 48.495714738965034, 41.55267030000687, 46.18907131254673, 47.292049527168274, 49.24517132341862, 43.21250483393669, 47.22599387168884, 55.50428666174412, 63.037439435720444, 54.16892811655998, 58.917054533958435, 49.549246206879616, 30.02869237214327, 53.147094547748566, 51.90967954695225, 54.61874797940254, 52.18286208808422, 54.41521190106869, 55.10171726346016, 57.85110913217068, 51.91365413367748, 57.230967208743095, 54.56803970038891, 54.6554122120142, 55.0275756418705, 58.61905552446842, 56.992492005228996, 53.752356469631195, 52.525649294257164, 51.547452583909035, 51.1088041216135, 46.929294392466545, 46.86038888990879, 47.05520063638687, 45.007441118359566, 46.23515523970127, 50.78076012432575, 52.63260215520859, 54.278031662106514, 53.70819143950939, 55.536132752895355, 52.97749824821949, 55.04399836063385, 48.968671560287476, 51.21338210999966, 50.03883473575115, 52.229257598519325, 57.14354149997234, 65.28377249836922, 64.94826570153236, 66.8393026292324, 65.64359039068222, 66.51359170675278, 63.746367394924164, 63.4194291383028, 60.92359006404877, 60.174923837184906, 57.24393971264362, 58.808064982295036, 57.186323404312134, 62.649772837758064, 64.51845556497574, 71.72737553715706, 65.99925890564919, 84.17976334691048, 31.329183988273144, 0.055220863432623446, 0.21072558942250907, 36.51714630424976, 78.43628033995628, 49.99965503811836, 56.38729847967625, 35.61091013252735, 19.30680200457573, 21.89300213009119, 36.71613782644272, 0.42886428418569267, 0.8614511811174452, 7.32750590890646, 15.213944725692272, 16.765403375029564, 9.766670074313879, 6.544631067663431, 11.699967384338379, 6.039181714877486, 0.2177649937220849, 0.0380930672690738, 0.04516763081483077, 0.05691358725016471, 0.16234514565439895, 5.660411864519119, 51.83993048965931, 64.12246361374855, 37.070187628269196, 35.01575946807861, 33.35579574108124, 66.69071540236473, 67.94749796390533, 86.46436795592308, 84.55521360039711, 52.67910785973072, 0.3842897666618228, 0.44467220781371, 0.5157177080400288, 0.1939863892039284, 0.6078367587178946, 14.911778289824724, 32.57706552743912, 67.03415617346764, 76.46990865468979, 79.43185731768608, 80.9962485730648, 79.18438419699669, 80.69892212748528, 78.55718985199928, 79.00368869304657, 78.2101620733738, 74.15618240833282, 71.10752999782562, 70.60977190732956, 65.98694756627083, 63.41941013932228, 59.41219076514244, 54.49858322739601, 56.566603258252144, 56.14788472652435, 54.21077907085419, 55.402444526553154, 54.68544580042362, 53.22413921356201, 54.175361171364784, 51.56300514936447, 51.1295510083437, 50.34718059003353, 48.86780597269535, 53.15853953361511, 57.74260215461254, 64.823267608881, 64.83874797821045, 63.811146318912506, 63.1044602394104, 69.01264920830727, 64.13393139839172, 62.425695061683655, 61.41624502837658, 61.70288644731045, 61.664827689528465, 66.08068093657494, 61.63505248725414, 60.2767925709486, 62.05861575901508, 60.50142511725426, 55.913220718503, 64.34770032763481, 59.18247029185295, 60.77771209180355, 55.31773567199707, 45.36263465881348, 42.674620896577835, 52.86158926784992, 61.65212497115135, 58.95043574273586, 61.68463222682476, 52.05240748822689, 50.751486495137215, 48.8888568431139, 50.57927593588829, 47.13739402592182, 46.53148993849754, 56.03309288620949, 63.13628353178501, 55.29905967414379, 34.664453119039536, 35.29695577919483, 53.27864728868008, 62.08310924470425, 50.78127309679985, 43.60719345510006, 46.89752049744129, 49.553156197071075, 50.83483122289181, 46.96989521384239, 49.13572579622269, 56.452312991023064, 64.2931504547596, 56.16957016289234, 60.60078598558903, 55.98320536315441, 33.0172985047102, 55.50492122769356, 56.9653956592083, 56.61915823817253, 53.43166887760162, 53.74809689819813, 55.64377337694168, 56.44315928220749, 55.71483336389065, 61.01329185068607, 57.685631811618805, 57.77630254626274, 58.501208648085594, 60.4530993103981, 55.57981140911579, 55.54821990430355, 56.17337755858898, 56.422036215662956, 53.071615397930145, 49.16330851614475, 48.269604071974754, 50.262262746691704, 46.83041989803314, 48.17253828048706, 52.147269397974014, 53.226886466145515, 54.15974780917168, 55.86286202073097, 59.776184633374214, 57.052088007330894, 57.14922599494457, 51.38491630554199, 54.711071625351906, 53.97510811686516, 57.43833348155022, 60.81130608916283, 67.52600938081741, 68.22422191500664, 74.09426853060722, 70.75829833745956, 72.17171609401703, 68.4147360920906, 69.43875074386597, 65.88714972138405, 68.66124406456947, 65.07328659296036, 68.59536319971085, 63.667947202920914, 74.27453085780144, 72.48760834336281, 82.4528320133686, 71.15932881832123, 88.30199494957924, 37.381432726979256, 0.06356600977596827, 0.22161584958666936, 41.86971388757229, 87.45045304298401, 58.95141988992691, 67.5159703195095, 49.56404261291027, 23.976037055253983, 27.66610834747553, 49.26628679037094, 0.67808483610861, 0.7068793347571045, 8.432686105370522, 24.629356898367405, 19.828605204820633, 10.0098798237741, 9.36750054359436, 17.09720727056265, 7.090083723887801, 0.2625561144668609, 0.1528498114203103, 0.164973788196221, 0.09226957306964323, 0.32103931065648794, 9.405166022479534, 70.19680246710777, 76.52686759829521, 50.06683923304081, 49.64285798370838, 45.13591982424259, 74.20484259724617, 74.7102838754654, 91.48187711834908, 88.23554411530495, 72.7969953417778, 1.2228684313595295, 1.933474000543356, 0.6858430104330182, 1.1620547133497894, 9.814067780971527, 58.62090602517128, 60.71118526160717, 83.95463302731514, 82.05934792757034, 82.77392998337746, 81.15072548389435, 81.3647224009037, 83.25528055429459, 80.84965243935585, 82.16955721378326, 80.27565523982048, 77.77166560292244, 74.59891185164452, 73.00299748778343, 68.23030918836594, 66.38752967119217, 63.89446064829826, 56.79203376173973, 60.297547057271004, 60.810139551758766, 57.38153412938118, 58.9794509857893, 56.752128303050995, 57.42155358195305, 58.72747130692005, 55.75096942484379, 52.130033522844315, 52.874987348914146, 50.87297737598419, 55.43886177241802, 58.92737478017807, 67.36499682068825, 66.48536682128906, 66.16808384656906, 65.82826808094978, 70.08450329303741, 67.38410979509354, 64.63771596550941, 62.36455254256725, 65.40721267461777, 64.54408898949623, 67.86789983510971, 62.88972996175289, 64.31352496147156, 66.53660327196121, 62.0671197026968, 60.264181047677994, 65.73844850063324, 62.41574339568615, 65.70572465658188, 56.27490431070328, 49.51361171901226, 44.81588579714298, 51.53097666800022, 65.06399989128113, 60.42323671281338, 64.82608705759048, 51.225978434085846, 52.67862908542156, 54.108252972364426, 52.95210801064968, 51.388564109802246, 49.13227558135986, 58.87853980064392, 66.87543869018555, 54.50742915272713, 34.43365730345249, 34.222761020064354, 53.02874609827995, 64.44043055176735, 52.47144140303135, 46.9404885917902, 49.46242466568947, 50.90524524450302, 50.387428030371666, 49.587901532649994, 50.436768382787704, 59.383407309651375, 70.05397573113441, 59.66463781893253, 57.925231754779816, 56.728573366999626, 37.43836887180805, 58.087551444768906, 59.908003360033035, 58.8670302182436, 55.989801809191704, 59.046874567866325, 61.78692273795605, 62.97366365790367, 57.420504838228226, 61.27297751605511, 64.08723950386047, 60.541588962078094, 60.77974118292332, 62.09926597774029, 59.29077208042145, 61.87569737434387, 61.33752465248108, 59.47347767651081, 57.54195012152195, 52.345956936478615, 51.899336501955986, 53.114009723067284, 50.11345133185387, 51.437243297696114, 55.835955664515495, 56.92968137562275, 58.732832819223404, 58.093904703855515, 60.566793009638786, 59.6886183321476, 59.75201793015003, 54.33202676475048, 56.56604088842869, 57.59358935058117, 60.57028882205486, 63.14445309340954, 71.04047879576683, 72.39123031497002, 76.31640449166298, 72.64124929904938, 75.41187062859535, 70.96664875745773, 72.53783404827118, 70.29763385653496, 72.95714914798737, 69.15717825293541, 73.78711581230164, 67.56530687212944, 81.40069127082825, 76.82308450341225, 86.3276056945324, 74.85793635249138, 92.13534325361252, 36.55146986246109, 0.19138008530717343, 0.39929382561240345, 44.723961129784584, 94.86623391509056, 68.67822915315628, 81.42225131392479, 63.701366409659386, 41.826586201786995, 43.525433242321014, 74.42077741026878, 1.8401688197627664, 1.236705151386559, 11.291096024215221, 24.483133144676685, 29.461983181536198, 25.50291482359171, 23.492672592401505, 27.17176627367735], [0.6756546883843839, 0.018595454421301838, 0.03996853753051255, 0.029954481033200864, 0.10220856318483129, 0.404942964669317, 5.189867438748479, 40.86567856371403, 59.906255453825, 26.96190543472767, 28.4080945327878, 51.29970967769623, 45.18334127962589, 59.43609528243542, 75.99132433533669, 69.40397500991821, 62.42442212998867, 4.5545353554189205, 0.4987270978745073, 0.5814569711219519, 0.29009516641963273, 5.974729098379612, 18.360869362950325, 26.711738258600235, 56.837555319070816, 69.16751369833946, 74.4070753455162, 75.08410781621933, 72.69445404410362, 71.4926241338253, 73.23737651109695, 74.88130509853363, 71.20899215340614, 71.01426780223846, 71.16407096385956, 68.1292650103569, 64.53940004110336, 60.169984102249146, 55.75489081442356, 52.59534515440464, 51.28925643861294, 51.3340750336647, 51.64352662861347, 49.76992316544056, 51.363747641444206, 50.71195721626282, 48.348848819732666, 48.144381791353226, 46.79414704442024, 45.706607401371, 46.37361221015453, 48.432729318737984, 61.96223773062229, 65.91419667005539, 64.50234442949295, 61.6609100997448, 62.88743108510971, 63.948683738708496, 63.004973977804184, 61.090762093663216, 60.27930423617363, 59.60035666823387, 59.85672131180763, 56.97663925588131, 56.4424829185009, 58.876434713602066, 56.60137139260769, 55.432056337594986, 55.99013239145279, 58.43101121485233, 58.79763454198837, 60.27857847511768, 49.98508661985397, 41.642896458506584, 48.88990178704262, 50.05699776113033, 56.99433870613575, 58.61662745475769, 58.26163150370121, 44.73628006875515, 48.61898012459278, 45.42947307229042, 45.50369068980217, 46.229713931679726, 43.98108959197998, 52.42302060127258, 58.80703903734684, 60.85740901529789, 50.095356702804565, 49.878456741571426, 58.874272629618645, 57.59154126048088, 50.289807468652725, 40.91021977365017, 43.013931289315224, 43.62546667456627, 45.95006413757801, 47.210973277688026, 42.76298135519028, 43.55604439973831, 54.626408368349075, 52.1229887008667, 61.58441260457039, 41.94472186267376, 40.94910308718681, 49.03913877904415, 51.76884010434151, 51.17603771388531, 50.42406566441059, 49.2961759865284, 49.37353603541851, 52.39300601184368, 52.279224917292595, 57.69097052514553, 58.24514798820019, 59.09323588013649, 57.177063301205635, 56.92429706454277, 53.890289068222046, 55.78353747725487, 56.08107291162014, 54.06293660402298, 52.10907764732838, 52.56773583590984, 44.795838072896004, 45.755221992731094, 45.12642793357372, 46.816497445106506, 48.930707797408104, 48.46480719745159, 52.48308777809143, 54.45636749267578, 52.568533793091774, 55.95023833215237, 54.95649665594101, 51.90246373414993, 48.363759219646454, 50.21563544869423, 53.870685920119286, 59.76256236433983, 62.694914415478706, 68.14565733075142, 64.6728564798832, 65.99684983491898, 67.11186200380325, 64.16535571217537, 61.5947974473238, 59.66493800282478, 59.50863718986511, 58.178700953722, 60.520443096756935, 62.53270871937275, 68.5788568854332, 68.32389056682587, 72.09470942616463, 72.84594431519508, 80.06760880351067, 65.8574429154396, 0.8976151468232274, 0.1377201365539804, 34.30646292865276, 76.02378219366074, 54.43642616271973, 52.60842025279999, 37.18048430979252, 24.83632229268551, 20.085486620664597, 36.38399384915829, 0.292376201832667, 1.0112355812452734, 5.379695277661085, 12.171024307608604, 7.3103351052850485, 19.441529475152493, 7.311570513993502, 9.354432094842196, 2.031926242634654, 0.0716728821862489, 0.02994791117089335, 0.04366260356619023, 0.07031845525489189, 0.5099173786584288, 10.397360231727362, 59.65685963630676, 68.91264617443085, 38.519813641905785, 29.19095702469349, 49.02359001338482, 53.2329623401165, 66.38759046792984, 85.0554795563221, 75.67435294389725, 78.96239250898361, 5.350505243986845, 0.7765398686751723, 0.4763679695315659, 0.5675392679404467, 8.005006704479456, 31.35860960930586, 44.498640820384026, 73.73583376407623, 78.19311618804932, 78.93419802188873, 79.83578324317932, 77.15076372027397, 77.82757580280304, 78.29216167330742, 77.86585494875908, 75.16101568937302, 76.35504081845284, 72.20947846770287, 70.57520136237144, 67.2727681696415, 63.63026462495327, 57.963776886463165, 55.5813617259264, 54.74152699112892, 55.07905147969723, 54.0422885119915, 53.66897754371166, 55.31775467097759, 53.48631374537945, 51.52960494160652, 49.25929896533489, 50.184838101267815, 47.91431933641434, 50.7067134976387, 50.973481982946396, 63.18623185157776, 68.23683723807335, 63.6990637332201, 64.03415635228157, 64.33722048997879, 64.55659791827202, 65.23474752902985, 63.883570432662964, 61.94842927157879, 62.25012168288231, 62.89493948221207, 57.83453822135925, 58.421982899308205, 59.44868020713329, 59.58407834172249, 58.244467824697495, 60.65760053694248, 59.19234976172447, 61.66238062083721, 62.71727241575718, 55.569669753313065, 45.123498290777206, 47.59382553398609, 55.43985731899738, 60.401950255036354, 60.90317755937576, 57.34608583152294, 45.656256303191185, 50.32183974981308, 47.34697178006172, 48.627343475818634, 46.07163481414318, 44.790358766913414, 54.38335821032524, 58.27152617275715, 59.50832940638065, 54.249168410897255, 52.48765133321285, 62.265818640589714, 59.080780148506165, 52.792030200362206, 43.89061264693737, 44.91971902549267, 44.76364620029926, 46.16933137178421, 48.224705681204796, 45.86709178984165, 42.99614064395428, 54.63471472263336, 52.84189872443676, 63.861577212810516, 45.3436204791069, 47.82302923500538, 51.84912219643593, 53.62809933722019, 53.72027099132538, 51.06793351471424, 52.616589814424515, 50.89127719402313, 54.23812620341778, 56.39424070715904, 59.00636114180088, 58.78141701221466, 61.11107960343361, 58.504708260297775, 58.024626821279526, 56.18280105292797, 59.68397118151188, 60.02710036933422, 57.41531811654568, 54.318377897143364, 55.76019912958145, 49.53159235417843, 48.16431552171707, 49.12947133183479, 51.04287385940552, 51.071547120809555, 50.106889083981514, 55.33378981053829, 55.99198289215565, 57.22197689116001, 58.95699039101601, 56.399233639240265, 54.2667842656374, 51.897706389427185, 53.56187269091606, 56.3928347826004, 65.66661715507507, 68.44411611557007, 71.59334152936935, 72.50282272696495, 72.36802116036415, 72.10314497351646, 69.17999222874641, 66.82475700974464, 65.29581025242805, 63.877156376838684, 65.69949299097061, 68.80822777748108, 69.2624706029892, 75.71286007761955, 75.10401874780655, 79.60357770323753, 78.38248282670975, 86.09862998127937, 73.05890008807182, 1.5009093680419028, 0.07979102781973779, 39.879658073186874, 83.33368554711342, 65.93888014554977, 64.619872123003, 52.17991724610329, 29.969571344554424, 24.712749123573303, 48.197221755981445, 1.3671989366412163, 1.4566118200309575, 6.790717737749219, 19.72435399889946, 18.754309751093388, 14.240049384534359, 10.114410314708948, 11.684469915926456, 1.0959690157324076, 0.19409827538765967, 0.20917485700920224, 0.22214489697944373, 0.20469810348004103, 0.7326762098819017, 15.976850688457489, 77.55880862474442, 79.95562121272087, 46.06620870530605, 38.022796511650085, 69.12455320358276, 63.12421917915344, 72.43830218911171, 92.86361977458, 77.9329289495945, 91.55509158968925, 6.0095190815627575, 1.5255663637071848, 1.1434098263271153, 0.9471396706067026, 24.11670170724392, 59.63852941989899, 64.17722627520561, 81.75993159413338, 81.53369933366776, 81.51595428586006, 80.29946476221085, 80.48142939805984, 79.36054274439812, 79.49532151222229, 80.81159368157387, 77.16543093323708, 77.71947920322418, 77.54889875650406, 75.18173217773438, 70.20981296896935, 67.23755925893784, 60.93612179160118, 60.269823744893074, 58.25394831597805, 59.53768663108349, 57.26311348378658, 56.202005222439766, 56.7772601544857, 56.86148263514042, 52.56460100412369, 52.833508774638176, 51.55674688518047, 51.89598128199577, 53.116137608885765, 51.71715907752514, 66.0916319489479, 69.72642570734024, 66.54458284378052, 65.27504056692123, 66.91602051258087, 69.16161641478539, 67.38126754760742, 65.31756028532982, 63.001519963145256, 63.54441203176975, 65.12849763035774, 60.758549720048904, 62.15675689280033, 64.14483681321144, 62.81022682785988, 63.59600946307182, 62.81691446900368, 62.25394047796726, 64.13783758878708, 64.8762671649456, 57.798421159386635, 46.850137040019035, 49.65355060994625, 56.75201050937176, 60.7670346647501, 63.55460308492184, 57.45335027575493, 49.08869571983814, 52.800974920392036, 47.8136171400547, 50.686616376042366, 49.957553297281265, 47.80018866062164, 57.72597424685955, 62.359802797436714, 61.83407060801983, 54.94896166026592, 53.01127843558788, 65.65538495779037, 61.81601017713547, 55.42156130075455, 44.3879109621048, 47.92075619101524, 46.43787436187267, 49.07173343002796, 49.3496011197567, 48.10043714940548, 43.83862383663654, 57.94700838625431, 56.28355644643307, 57.68838286399841, 49.594171196222305, 52.42595784366131, 54.7023168951273, 56.842878833413124, 56.971315741539, 53.79735365509987, 54.38024617731571, 54.95174691081047, 55.79948142170906, 58.653477877378464, 62.95278377830982, 62.737977504730225, 62.97759644687176, 62.36463613808155, 63.048082664608955, 60.40320798754692, 62.64701418578625, 63.10244634747505, 60.391797199845314, 57.784365713596344, 58.66599440574646, 51.12904943525791, 50.5984915047884, 51.28126546740532, 53.98095600306988, 54.013546854257584, 53.79504717886448, 56.59286364912987, 59.95569460093975, 58.69316294789314, 61.84806525707245, 60.12939468026161, 57.99138620495796, 53.345713689923286, 55.5075316876173, 59.205926433205605, 67.18630000948906, 71.03171646595001, 75.13041973114014, 71.43995895981789, 74.8865108191967, 75.69188520312309, 72.0114178955555, 68.32598805427551, 68.6435978114605, 67.63320162892342, 69.29672196507454, 72.93952569365501, 73.99552702903748, 80.0242455303669, 78.89876112341881, 82.12452962994576, 81.02539300918579, 84.65925961732864, 71.26082137227058, 1.0966959642246366, 0.19629108428489417, 43.70808944106102, 91.45532414317131, 74.40933242440224, 78.08872818946838, 65.80738440155983, 51.451728120446205, 41.912997364997864, 77.12179407477379, 2.4930445617064834, 2.0494910376146436, 7.896301187574863, 19.99344415962696, 19.858997873961926, 34.216483756899834, 22.789921201765537, 16.81159369647503], [0.039597281866008416, 0.03799719663220458, 0.061088000948075205, 0.0333206717914436, 0.11271988274529576, 0.2629768825136125, 5.73871711269021, 51.544047966599464, 58.18801425397396, 25.98909493535757, 30.541159473359585, 45.11494494974613, 51.5748643130064, 59.74162548780441, 72.37176775932312, 71.78149223327637, 42.90180690586567, 0.5947534076403826, 0.62121014110744, 0.2748306136345491, 2.026494196616113, 21.924004666507244, 23.78298081457615, 35.89594803750515, 62.36002318561077, 73.20492625236511, 76.70794308185577, 76.77488788962364, 71.7917212843895, 73.68094950914383, 70.68169444799423, 70.72155430912971, 69.65829536318779, 70.45474782586098, 69.14013996720314, 69.36857610940933, 68.18077504634857, 61.29828795790672, 57.09508270025253, 52.141277119517326, 51.309824734926224, 49.8863261193037, 52.05964230000973, 49.60050545632839, 49.75353844463825, 49.543481916189194, 48.33038181066513, 49.51084926724434, 46.17831028997898, 48.321072310209274, 47.61813282966614, 51.93994492292404, 63.38195934891701, 66.7264486849308, 62.44404047727585, 65.43769463896751, 63.42662215232849, 62.70061410963535, 60.10216914117336, 58.79367135465145, 54.44929227232933, 54.69838410615921, 53.86069245636463, 53.721802309155464, 52.363314405083656, 54.43676054477692, 52.19013869762421, 51.658896803855896, 53.45236636698246, 55.095075219869614, 52.771260514855385, 58.1369411945343, 54.885311275720596, 51.05745367705822, 44.06415693461895, 61.82859130203724, 57.15260401368141, 63.44100058078766, 47.949003875255585, 44.035571068525314, 49.84949469566345, 46.72901853919029, 45.41095666587353, 41.91202461719513, 43.488996997475624, 46.00226193666458, 54.64482218027115, 50.967805087566376, 52.50902898609638, 52.76007391512394, 51.702184081077576, 50.666257068514824, 44.752414003014565, 41.78619056940079, 45.128092244267464, 45.25875583291054, 41.742093935608864, 46.442901492118835, 46.56121574342251, 43.920209258794785, 49.60778966546059, 48.698243871331215, 53.11569683253765, 33.30723434686661, 55.29967524111271, 54.989634677767754, 50.50391837954521, 51.76155969500542, 52.159687131643295, 54.53671038150787, 56.47393003106117, 58.108138740062714, 58.052821308374405, 54.5609986782074, 54.654868841171265, 50.06488233804703, 50.99926359951496, 52.581525295972824, 55.793568938970566, 56.066721081733704, 55.659375339746475, 56.312529891729355, 55.27890935540199, 53.433093801140785, 46.43734239041805, 46.083189994096756, 47.4047476798296, 49.3849316239357, 49.24966648221016, 49.23084609210491, 48.09031829237938, 53.119842410087585, 52.89204463362694, 56.445849537849426, 52.766689360141754, 51.627339497208595, 49.551149904727936, 48.60645979642868, 52.471300810575485, 61.82437352836132, 62.46482916176319, 67.62089028954506, 67.50520929694176, 64.98991906642914, 64.61474239826202, 63.45270395278931, 61.35165609419346, 60.48728607594967, 59.06689189374447, 57.66421236097813, 59.70141984522343, 66.56573250889778, 69.59188252687454, 70.16030922532082, 68.72530862689018, 76.16242155432701, 75.00258699059486, 84.92184832692146, 8.168461583554745, 0.17247550596948713, 41.95713199675083, 69.01990681886673, 57.44355820119381, 50.01122921705246, 30.875195749104023, 18.590266853570938, 24.2893473431468, 35.63451446592808, 0.92907146201469, 0.33230956527404487, 1.1543746129609644, 7.119403900578618, 5.46148493885994, 10.680285450071096, 6.329895090311766, 0.5747703986708075, 0.18245516577735543, 0.004953606603521621, 0.03966865420807153, 0.06488269107649103, 0.0730993271281477, 0.27840173919685185, 11.108345780521631, 67.89759144186974, 66.75906613469124, 35.92339776456356, 34.518871530890465, 45.17925649881363, 60.592825412750244, 66.15381941199303, 79.15516376495361, 81.30990654230118, 51.87852881848812, 0.8804140635766089, 0.981692997738719, 0.9365030319895595, 1.926539372652769, 26.347123123705387, 36.623814180493355, 53.24801713228226, 75.84997192025185, 81.73783957958221, 82.79811948537827, 83.05227264761925, 76.34633928537369, 79.01957184076309, 77.86868199706078, 75.77055618166924, 74.5550774037838, 74.90238636732101, 72.18044802546501, 71.24633654952049, 70.70760145783424, 66.34664386510849, 60.95781482756138, 54.74529638886452, 54.11962576210499, 55.336134284734726, 54.24030348658562, 53.499259650707245, 55.21270550787449, 53.143180757761, 51.41914486885071, 50.74716992676258, 48.60121227800846, 51.12822487950325, 50.298957377672195, 54.361760169267654, 65.00460147857666, 67.08160802721977, 63.28560411930084, 65.94122841954231, 64.86311987042427, 63.87128949165344, 61.799724251031876, 58.3759331703186, 57.408311292529106, 55.0586199760437, 55.15275992453098, 56.37493014335632, 55.90049900114536, 54.41836193203926, 57.122920006513596, 51.20631828904152, 55.86913928389549, 56.25025883316994, 56.76219776272774, 60.22498235106468, 60.0710754096508, 55.40494479238987, 46.001699566841125, 65.82655057311058, 58.9553564786911, 63.09071637690067, 49.79462943971157, 43.993347734212875, 50.699239298701286, 47.456470504403114, 48.491838946938515, 46.6630806773901, 44.809593334794044, 48.625226989388466, 56.4598897844553, 51.9643472135067, 54.27812285721302, 55.27423180639744, 55.48358917236328, 53.5394386947155, 46.769083589315414, 44.30079683661461, 46.188577339053154, 46.22117578983307, 45.00505864620209, 49.07590560615063, 47.15842969715595, 45.29779493808746, 50.83746448159218, 49.31455560028553, 59.83912445604801, 39.756974056363106, 54.083083122968674, 60.676477923989296, 54.05480124056339, 55.75962916016579, 54.96082082390785, 54.66378316283226, 55.14598108828068, 58.65624412894249, 58.84519658982754, 59.85792584717274, 57.94068172574043, 53.96582521498203, 56.037078872323036, 55.573477149009705, 58.662783578038216, 59.67126086354256, 58.02144259214401, 58.92081633210182, 59.10491265356541, 57.15660519897938, 48.23130592703819, 47.69218325614929, 50.1965718716383, 50.515325367450714, 50.8744440972805, 50.39016008377075, 50.06762959063053, 55.75935937464237, 55.702225640416145, 58.971771597862244, 56.03596173226833, 55.54513446986675, 52.87737362086773, 52.90147192776203, 56.47289268672466, 66.29141002893448, 68.42075496912003, 70.6317575275898, 72.08582550287247, 71.20416641235352, 70.16090199351311, 69.01801452040672, 65.92824071645737, 66.05390757322311, 63.79634231328964, 62.976642698049545, 68.35591524839401, 73.42519283294678, 73.68044033646584, 79.28761705756187, 77.40246221423149, 82.08622768521309, 78.86199429631233, 89.29485887289047, 10.31828647479415, 0.22060022049117833, 49.8605976998806, 78.70557188987732, 70.09314402937889, 62.465296536684036, 46.55663698911667, 22.488597370684147, 28.60643059015274, 44.09302778542042, 1.4142775791697204, 1.5385880274698138, 4.227680219337344, 11.925661023706198, 9.856672044843435, 14.909727349877357, 7.324340678751469, 4.766807164996862, 0.15054446324938908, 0.13032102811848745, 0.12040095534757711, 0.2224783439305611, 0.22447549301432446, 0.4352181073045358, 19.580773003399372, 84.71509382128716, 75.87578013539314, 43.865328803658485, 42.03502781689167, 58.39694984257221, 68.37679892778397, 73.61927881836891, 86.95407807826996, 84.40196022391319, 62.848562970757484, 0.7358713040594012, 1.6021047066897154, 1.3150213239714503, 3.4354992024600506, 40.659999400377274, 62.6917377859354, 69.54002290964127, 82.37261831760406, 85.06100445985794, 83.83659616112709, 81.55571535229683, 78.43916058540344, 83.96204262971878, 78.15444186329842, 77.55217418074608, 75.583416223526, 77.6536363363266, 74.8721019923687, 73.65192666649818, 72.88974076509476, 69.97283488512039, 64.32617828249931, 59.54332172870636, 57.523441314697266, 60.643659085035324, 56.55448570847511, 58.16999562084675, 58.715916126966476, 56.73735089600086, 53.853982016444206, 54.98592607676983, 51.97342872619629, 53.08456890285015, 51.51849813759327, 57.574548572301865, 67.72771015763283, 71.46850302815437, 65.58400198817253, 69.86931324005127, 68.03156465291977, 67.23287791013718, 63.612903356552124, 61.97072647511959, 58.754761442542076, 57.99875780940056, 59.54858064651489, 60.551373437047005, 58.15995275974274, 57.580054476857185, 60.38309946656227, 54.527621269226074, 61.429103538393974, 58.64351861178875, 60.51635831594467, 64.28009435534477, 62.29058191180229, 54.29927632212639, 46.77552804350853, 65.97451463341713, 59.46291044354439, 65.39645925164223, 50.50995245575905, 45.27127996087074, 51.68073423206806, 51.252808794379234, 50.82951910793781, 49.27461214363575, 46.975454315543175, 50.93381971120834, 58.815497383475304, 55.97044564783573, 54.60260644555092, 56.69103518128395, 59.17747735977173, 56.544283255934715, 47.9593925178051, 46.71913146972656, 50.72066254913807, 49.40847136080265, 45.454532727599144, 52.02779620885849, 47.42345787584782, 45.14795757830143, 52.733418345451355, 49.626199677586555, 56.94708824157715, 45.05749963223934, 57.1654587239027, 62.454018741846085, 55.444652661681175, 56.16317130625248, 57.86405883729458, 58.806161284446716, 58.271077796816826, 62.13236220180988, 62.87064738571644, 63.29100362956524, 60.342730432748795, 55.49582451581955, 58.83678764104843, 57.81824089586735, 60.98760522902012, 64.90392968058586, 60.52512064576149, 60.48564076423645, 61.23765081167221, 62.50291831791401, 51.00748635828495, 48.83295804262161, 53.273304775357246, 54.79378178715706, 52.27101355791092, 53.258512169122696, 52.54318155348301, 58.318438455462456, 58.37649554014206, 64.04010683298111, 60.17999276518822, 57.56153807044029, 54.76716421544552, 55.07777474820614, 60.26201516389847, 69.29747432470322, 71.43586277961731, 74.34491828083992, 73.94875913858414, 75.3191252052784, 73.07827144861221, 71.13428816199303, 70.82923293113708, 69.52999144792557, 65.37236094474792, 66.44604653120041, 70.30827328562737, 76.62325322628021, 79.23722416162491, 82.9514792561531, 77.5070858001709, 84.1387939453125, 79.77907508611679, 91.96737706661224, 9.478502087295055, 0.20631340274121612, 51.433686688542366, 87.05730333924294, 79.21265468001366, 76.49644643068314, 59.122517108917236, 41.85226522386074, 51.06048211455345, 68.92849892377853, 3.0076252995058894, 1.580922743305564, 2.9155403282493353, 11.579796932637691, 10.184611547738314, 16.515213400125504, 11.460491884499788, 2.015911052003503], [0.026780539919855073, 0.055054039767128415, 0.12007207260467112, 0.08163597725797445, 0.11360352829797193, 0.4452516173478216, 14.659554474055767, 51.79179087281227, 59.75986450910568, 27.42579974234104, 27.70529754459858, 56.76947817206383, 45.56637592613697, 58.733357191085815, 75.91342091560364, 67.63080775737762, 67.68379211425781, 1.2142100022174418, 0.562747250078246, 0.8746077376417816, 2.948006261140108, 33.93449708819389, 34.51420158147812, 47.53155827522278, 64.17064502835274, 74.27137702703476, 71.60926267504692, 76.05615645647049, 70.69177150726318, 74.79095354676247, 70.11243939399719, 72.92704716324806, 68.82474169135094, 71.81200459599495, 66.99162885546684, 70.01835644245148, 65.7666277885437, 64.50294479727745, 53.72767299413681, 48.77056539058685, 48.164763897657394, 50.28408497571945, 50.45010186731815, 48.20900112390518, 50.127119198441505, 49.31909255683422, 46.94352462887764, 48.95324818789959, 45.53077943623066, 48.297293186187744, 47.70796000957489, 52.83839151263237, 63.238133266568184, 63.341894298791885, 61.71936236321926, 62.44036607444286, 61.547432988882065, 58.831680715084076, 53.755297511816025, 55.32836750149727, 52.421728670597076, 52.160485088825226, 51.649275720119476, 52.996797412633896, 49.55164387822151, 51.2864787876606, 50.94876430928707, 48.94966498017311, 50.43841749429703, 53.20892482995987, 55.19597500562668, 57.983019053936005, 56.07781648635864, 49.518186673521996, 52.96442694962025, 54.28296759724617, 48.983479365706444, 54.65771108865738, 41.82181365787983, 49.18002001941204, 50.055515840649605, 48.43109540641308, 43.419057950377464, 42.43063598871231, 42.97936454415321, 44.67146314680576, 49.40174952149391, 46.96259580552578, 50.43039612472057, 49.758041203022, 46.85467779636383, 49.15032461285591, 42.57145643234253, 41.21006928384304, 40.02488628029823, 42.6978300511837, 43.19736644625664, 51.48692183196545, 42.5577087700367, 40.11672355234623, 45.245916321873665, 50.767187252640724, 40.80058425664902, 38.627062886953354, 52.72913597524166, 60.87269179522991, 59.056263864040375, 56.805561035871506, 55.46023942530155, 52.22778707742691, 52.879642099142075, 54.50575724244118, 54.583497270941734, 53.55585001409054, 55.66914461553097, 57.98145353794098, 58.20881813764572, 58.60055431723595, 57.99072504043579, 53.83800387382507, 56.52868129312992, 56.54943197965622, 57.0202799141407, 56.00188136100769, 48.11922334134579, 46.88853397965431, 47.71482244133949, 48.15322011709213, 48.51685680449009, 50.568682104349136, 51.35106012225151, 54.40876364707947, 54.39653970301151, 56.437015011906624, 54.32631567120552, 51.62316732108593, 49.75400201976299, 51.17205172777176, 52.975495755672455, 62.83598564565182, 61.82784654200077, 66.46238565444946, 66.91906794905663, 65.8059860765934, 61.15367151796818, 62.66908720135689, 60.32276250422001, 58.540441542863846, 55.9337168186903, 53.96316155791283, 56.861573830246925, 63.553539142012596, 65.84096699953079, 68.6058734357357, 69.53311488032341, 77.15176686644554, 72.55146011710167, 90.78716799616814, 18.059802018105984, 0.24023930338444188, 43.88298265635967, 66.08379676938057, 53.77078928053379, 38.44655357301235, 35.180028453469276, 20.712226890027523, 19.097769521176815, 22.184587083756924, 0.6365816225297749, 0.4497701983200386, 1.033053535502404, 5.051411893218756, 2.8153575165197253, 2.3353283246979117, 1.6728584538213909, 0.10152296716114506, 0.04798518704774324, 0.15078681899467483, 0.032093641930259764, 0.046353631041711196, 0.1687645449419506, 0.44849284342490137, 20.714938044548035, 67.63066336512566, 67.5591892004013, 36.727214232087135, 26.080972105264664, 56.89313493669033, 59.67698335647583, 63.94425317645073, 83.54549378156662, 78.99161294102669, 76.05912789702415, 1.7393238935619593, 0.21124748251168057, 1.606215729843825, 2.505160211585462, 42.3165775090456, 44.167234003543854, 59.62735041975975, 75.31847164034843, 82.15451762080193, 77.56206125020981, 81.99153676629066, 76.41233414411545, 78.58180493116379, 76.40730321407318, 77.05424889922142, 73.49985882639885, 75.33617109060287, 71.60904988646507, 73.46764415502548, 69.31195914745331, 69.84880194067955, 58.78018207848072, 53.03840897977352, 53.592867627739906, 54.45930473506451, 52.75002345442772, 53.51363427937031, 52.24379941821098, 52.47267633676529, 49.66149978339672, 49.169939160346985, 48.15929599106312, 49.29887384176254, 49.43058617413044, 52.232403829693794, 64.67699065804482, 63.65209445357323, 63.97028177976608, 64.04166474938393, 61.24982915818691, 59.834994077682495, 56.53823398053646, 56.486074179410934, 54.6526725590229, 52.48453550040722, 53.81172448396683, 54.96689669787884, 52.08844855427742, 53.703966066241264, 51.66247621178627, 51.55438721179962, 54.50117848813534, 54.755540639162064, 56.819768473505974, 60.9702667593956, 58.4795194119215, 50.89671470224857, 55.19308716058731, 54.60272043943405, 50.96042588353157, 56.61580301821232, 43.53679083287716, 50.405572056770325, 53.1753346323967, 49.755651131272316, 47.16955929994583, 45.17611786723137, 44.96917337179184, 45.63001491129398, 51.6667053848505, 48.56971576809883, 52.82237537205219, 51.64943531155586, 50.519254356622696, 50.99010989069939, 46.392478197813034, 43.738476410508156, 42.74710200726986, 43.5592932254076, 47.21383452415466, 52.58220545947552, 45.58636285364628, 38.955562859773636, 42.259607166051865, 49.67838227748871, 49.742530435323715, 48.48327800631523, 54.964464828372, 60.291957557201385, 59.268843457102776, 59.86665017902851, 56.5645931661129, 55.53123481571674, 53.78270544111729, 57.50066913664341, 56.460478752851486, 57.41327002644539, 58.207260221242905, 62.03835144639015, 58.19695517420769, 60.4009585082531, 59.57472704350948, 57.266730889678, 57.84740813076496, 58.28104466199875, 61.1682665348053, 58.39401639997959, 53.20074386894703, 49.86245200037956, 50.06341561675072, 49.28956054151058, 51.22845210134983, 52.28759966790676, 54.166006073355675, 57.22343601286411, 57.3186969012022, 58.63254860043526, 56.40292704105377, 53.296251744031906, 52.84599490463734, 52.91444443166256, 56.9251824170351, 67.3068979382515, 69.55645322799683, 70.5210542678833, 72.7946774661541, 71.42036721110344, 66.55242562294006, 67.02198162674904, 64.59860846400261, 65.3605891764164, 61.27163998782635, 60.62282480299473, 61.449299454689026, 70.81817552447319, 71.31656438112259, 73.91679525375366, 76.04351833462715, 85.07466852664948, 77.1457327902317, 96.58558085560799, 19.299337305128574, 0.23885582137154415, 49.262920171022415, 76.6487118601799, 66.12570092082024, 51.96909315884113, 54.063362181186676, 25.648131631314754, 22.549361810088158, 23.512980602681637, 1.9594052340835333, 0.8325711276847869, 2.040111478418112, 7.655737521126866, 6.4075111504644156, 9.235082399100065, 4.011916872113943, 0.7976675662212074, 0.10237544251140207, 0.1862071081995964, 0.16158962447661906, 0.15080716868396848, 0.3726521786302328, 0.6355594773776829, 27.378579676151276, 84.63694721460342, 79.13657516241074, 44.208849370479584, 41.82596683502197, 69.28343787789345, 67.53004476428032, 72.79988318681717, 89.89563703536987, 83.20505484938622, 83.90243902802467, 2.422953760251403, 1.8611075961962342, 9.852212984114885, 3.320749872364104, 56.10921800136566, 63.37371379137039, 71.11467361450195, 80.4178512096405, 83.48807126283646, 79.63387727737427, 84.38454195857048, 79.71840754151344, 80.4670737683773, 77.99797385931015, 80.80176740884781, 75.6996975839138, 79.5756796002388, 74.10936892032623, 75.45677661895752, 72.38505944609642, 72.85751849412918, 60.11991038918495, 56.99073649942875, 56.34536772966385, 59.56235870718956, 56.28037981688976, 55.03720812499523, 56.66322447359562, 56.48463025689125, 51.523871049284935, 53.92797164618969, 50.60068018734455, 54.2205635458231, 50.98309926688671, 56.2746687233448, 66.14707857370377, 67.6008577644825, 64.87024828791618, 67.30266496539116, 64.59780290722847, 64.09732416272163, 57.20838122069836, 60.581756606698036, 57.213172763586044, 56.70494623482227, 57.168608754873276, 58.93096178770065, 56.56371921300888, 56.61070369184017, 55.86123190820217, 55.29432512819767, 55.65892696380615, 60.827675610780716, 59.66869980096817, 62.90111035108566, 63.019937574863434, 53.84908027946949, 53.486610129475594, 58.92867811024189, 53.64446885883808, 56.50823079049587, 45.0433985888958, 52.302764654159546, 54.245790392160416, 51.896676644682884, 49.84020799398422, 48.58755961060524, 45.92366695404053, 49.348894357681274, 56.70915640890598, 52.164737060666084, 56.725845113396645, 54.46330592036247, 53.00468198955059, 55.631078258156776, 49.12845678627491, 46.97436757385731, 45.33150292932987, 47.353663221001625, 47.31130689382553, 55.93446157872677, 44.26167033612728, 39.4022136926651, 45.63712812960148, 49.13399688899517, 46.94664806127548, 48.30460399389267, 56.56010940670967, 61.47112928330898, 61.4103477448225, 63.91814857721329, 58.31626497209072, 57.90353111922741, 55.79014912247658, 59.31200534105301, 58.669163435697556, 59.65117134153843, 58.8587960600853, 63.99709314107895, 62.4102146923542, 62.53031104803085, 64.49951738119125, 60.836764723062515, 62.243593633174896, 61.89701423048973, 63.649297803640366, 61.97451487183571, 54.72198083996773, 52.82985717058182, 52.78727285563946, 52.57582560181618, 52.89806351065636, 56.132837533950806, 56.38243094086647, 62.629466727375984, 58.94297294318676, 63.171435445547104, 60.13685368001461, 56.929016411304474, 54.359548687934875, 56.021119728684425, 57.30620317161083, 69.67736274003983, 71.77173435688019, 74.51849296689034, 75.26365578174591, 74.001804292202, 68.77081498503685, 68.9613975584507, 68.14917594194412, 68.14781561493874, 64.78539884090424, 62.88393147289753, 63.83330672979355, 74.6660466492176, 72.51377373933792, 75.96061438322067, 78.98680999875069, 86.8934865295887, 78.3643501996994, 100.58442547917366, 20.00077586621046, 0.22911197156645358, 52.51985460519791, 84.29705545306206, 77.099170088768, 65.11947691440582, 68.49406823515892, 43.98091100156307, 42.91590414941311, 60.11479966342449, 3.8283515721559525, 1.1544295912608504, 1.8241029256023467, 8.486403822898865, 5.253910152241588, 4.741171365603805, 2.4356467416509986, 0.31875492073595524], [0.08718998782569543, 0.09026037150761113, 0.08377253878279589, 0.014335242885863408, 0.10947550996206701, 0.1178180513670668, 14.002476632595062, 55.25535061955452, 61.04104936122894, 17.59371142834425, 49.5147630572319, 46.262513771653175, 42.1930081397295, 57.61740267276764, 71.98968306183815, 65.94476222991943, 71.89534172415733, 1.4456762443296611, 0.23596410232130438, 0.4795904934871942, 2.989665325731039, 44.817971885204315, 50.23463822901249, 60.925166979432106, 70.58364450931549, 73.27288180589676, 69.8406171798706, 73.39756831526756, 72.30777159333229, 73.51289972662926, 70.72469294071198, 71.87274053692818, 68.39974969625473, 70.93045189976692, 67.03431576490402, 67.36004948616028, 63.543633073568344, 63.31413298845291, 51.63487829267979, 50.18378175795078, 50.33370651304722, 50.76122537255287, 48.39592829346657, 51.063658744096756, 47.6620888710022, 47.0954404771328, 45.56196056306362, 46.69247969985008, 46.46040715277195, 48.638150095939636, 48.61670784652233, 51.34744271636009, 60.50448015332222, 59.56330865621567, 62.85909980535507, 59.68871712684631, 57.602271884679794, 55.17881512641907, 53.986211121082306, 52.391953468322754, 52.644518315792084, 50.94123311340809, 50.647280886769295, 50.503097623586655, 51.827759742736816, 48.18885080516338, 50.49222260713577, 46.518859416246414, 48.58154073357582, 49.90714520215988, 49.397645741701126, 53.083113580942154, 55.159656554460526, 53.2762648165226, 53.79074580967426, 48.92097271978855, 54.60672542452812, 43.23985196650028, 41.5780795365572, 49.764679446816444, 50.40962263941765, 45.99440775811672, 42.979022562503815, 42.38383010029793, 40.98815739154816, 45.1280352473259, 48.69243398308754, 49.239483028650284, 51.689963936805725, 49.98254835605621, 47.80054584145546, 47.09086932241917, 41.75331853330135, 41.08005926012993, 41.9754584133625, 44.18110705912113, 44.716209545731544, 49.492264464497566, 47.14116342365742, 36.67336352169514, 36.93745315074921, 45.57230740785599, 34.96829241514206, 43.9719282835722, 53.58791269361973, 54.43865664303303, 55.05072019994259, 55.21101459860802, 58.58027100563049, 54.771602377295494, 54.609267488121986, 54.81439188122749, 58.12646135687828, 54.50916565954685, 57.336449548602104, 56.59827835857868, 56.10466584563255, 59.485982805490494, 57.798044979572296, 57.18125827610493, 54.54312063753605, 59.18557472527027, 56.31785340607166, 57.212572395801544, 47.54104636609554, 47.44346380233765, 44.7531321644783, 47.27088086307049, 49.54793147742748, 51.59001410007477, 52.43164233863354, 53.635820522904396, 54.61583733558655, 54.624512270092964, 53.20902742445469, 51.08082242310047, 49.096785485744476, 49.92013670504093, 53.94943289458752, 66.72302886843681, 64.51494455337524, 66.02814495563507, 68.17411780357361, 65.15610694885254, 60.34086473286152, 59.602298364043236, 57.37483508884907, 57.483893036842346, 55.13297438621521, 57.99566097557545, 55.231628492474556, 56.99867807328701, 56.81491233408451, 62.13693715631962, 67.29073360562325, 78.61025020480156, 71.23881295323372, 92.58442595601082, 19.175940826535225, 0.054984504240565, 50.909656807780266, 67.89937734603882, 50.13438440859318, 37.85634644329548, 37.580504044890404, 16.26355480402708, 10.554185416549444, 7.159150717779994, 4.449136136099696, 0.2422712295083329, 0.3785833338042721, 1.312059264164418, 1.4589738682843745, 0.5943614349234849, 0.06148038926767185, 0.017572376018506475, 0.03681481808598619, 0.06521322880871594, 0.11127628677058965, 0.048744752930360846, 0.20721153501654044, 0.29248722712509334, 18.27559433877468, 69.16993796825409, 69.60652694106102, 24.74778324365616, 43.383674249053, 53.143458142876625, 53.37991565465927, 64.36619013547897, 79.55725818872452, 73.04551720619202, 78.37008029222488, 2.043538657017052, 0.24506814661435783, 1.5540262428112328, 3.5796720162034035, 54.289377853274345, 60.03110535442829, 73.05123969912529, 77.6805616915226, 84.11815345287323, 76.56435638666153, 80.91081395745277, 76.64251819252968, 79.08548310399055, 73.97851914167404, 76.94990649819374, 71.14091500639915, 76.4087775349617, 71.16846352815628, 73.5949981212616, 67.14854523539543, 67.84920483827591, 54.27769348025322, 55.06156101822853, 54.28205944597721, 55.196932554244995, 52.49905452132225, 52.94656030833721, 50.017270892858505, 50.20819924771786, 47.37231262028217, 50.42282693088055, 47.87914842367172, 50.1100505143404, 49.620195999741554, 53.354331627488136, 60.35801701247692, 60.88775798678398, 62.4811302870512, 60.56014336645603, 59.88722987473011, 56.00383825600147, 57.705527544021606, 54.807396456599236, 54.39345806837082, 53.71794551610947, 55.2392964810133, 54.05152201652527, 55.43008044362068, 50.81999681890011, 52.5539805740118, 49.18645687401295, 51.779935508966446, 52.319270968437195, 52.23647341132164, 55.19404470920563, 58.18071864545345, 56.093958020210266, 54.867087453603745, 52.208959087729454, 55.96507653594017, 45.672162249684334, 40.116145983338356, 52.05770440399647, 51.89896032214165, 49.09701347351074, 45.41385591030121, 42.95741692185402, 43.67601916193962, 48.95899347960949, 51.840390264987946, 52.063772678375244, 54.75028932094574, 53.40392276644707, 50.23552358150482, 51.62976756691933, 47.065684273839, 43.88522073626518, 45.154006853699684, 45.36770738661289, 47.88569927215576, 53.11752453446388, 48.68205673992634, 36.58418230712414, 35.969192907214165, 40.147908478975296, 44.71096582710743, 55.37222854793072, 51.51434876024723, 58.14449518918991, 54.28125388920307, 58.34436446428299, 59.446202740073204, 59.93451073765755, 58.871631771326065, 57.24946081638336, 58.889999985694885, 58.05169656872749, 58.30036282539368, 57.83046863973141, 58.532765954732895, 60.85653506219387, 58.64891052246094, 61.73164330422878, 57.08162002265453, 61.66784852743149, 57.758546099066734, 59.30236905813217, 51.78165681660175, 49.47804182767868, 48.02089221775532, 49.524737522006035, 53.08961883187294, 55.265868455171585, 55.54535485804081, 56.85841619968414, 59.338980093598366, 57.06300102174282, 56.19913637638092, 53.52917164564133, 51.291604712605476, 52.31277711689472, 56.773764342069626, 69.96864750981331, 68.7411841750145, 72.27704644203186, 70.67876860499382, 70.9808523952961, 64.19461414217949, 65.39930909872055, 62.412403374910355, 63.58276717364788, 59.36513788998127, 62.22328372299671, 58.85169804096222, 63.23790527880192, 61.15371711552143, 67.70632490515709, 71.17582753300667, 86.80538445711136, 73.94242867827415, 97.36985877156258, 21.199052967131138, 0.01685441493464168, 60.9056132286787, 76.30705699324608, 63.2660997658968, 47.729729041457176, 56.15103855729103, 19.515638798475266, 19.402644261717796, 16.49129368364811, 4.139255164191127, 0.4301043238956481, 0.9007596562150866, 3.1443146523088217, 2.0483204629272223, 2.5007389113307, 0.46331249352078885, 0.049844886671053246, 0.18120516644557938, 0.17365514970151708, 0.34512054815422744, 0.1535956104635261, 0.3320349409477785, 0.4390713677275926, 23.632506988942623, 84.82908770442009, 80.26984915137291, 31.693202555179596, 68.03409531712532, 61.99039801955223, 60.905092656612396, 73.94733801484108, 83.13889279961586, 78.535166233778, 81.4370933175087, 2.9966966109350324, 0.6517872191034257, 3.5462478222325444, 3.0543694412335753, 64.19564008712769, 70.54797202348709, 79.29989039897919, 80.25369241833687, 84.3174147605896, 78.31031709909439, 80.65651640295982, 80.38332626223564, 81.91208302974701, 76.93352937698364, 78.31797748804092, 74.53944504261017, 77.00802057981491, 72.96067535877228, 75.01109853386879, 69.59822818636894, 70.7295110821724, 57.73524194955826, 57.360255271196365, 57.209787145256996, 58.60427051782608, 56.01300336420536, 56.341077759861946, 54.342525601387024, 53.028027936816216, 52.23501808941364, 53.55040490627289, 49.759602919220924, 52.7145029604435, 53.4755527228117, 56.26027889549732, 65.28134062886238, 64.22109872102737, 65.81712707877159, 62.69063964486122, 61.96778543293476, 59.67510625720024, 59.48072388768196, 58.670364171266556, 57.66748398542404, 55.583861991763115, 57.106318697333336, 56.30762815475464, 57.97024413943291, 54.692566618323326, 55.806834027171135, 52.402193918824196, 53.58173422515392, 58.85951802134514, 53.77314515411854, 60.24928204715252, 60.13055361807346, 61.00211285054684, 56.4710383862257, 53.568222150206566, 56.187725588679314, 44.72534045577049, 42.67290718853474, 55.70089191198349, 53.377027809619904, 51.44348256289959, 47.73430399596691, 48.064658269286156, 46.08643501996994, 51.93624012172222, 54.26277928054333, 53.993206545710564, 56.33308298885822, 54.24926720559597, 51.65196217596531, 53.620093166828156, 48.664775267243385, 45.76632119715214, 48.54385055601597, 49.37888614833355, 49.37175773084164, 54.747644662857056, 49.01828549802303, 36.21556028723717, 37.636440843343735, 41.24348849058151, 39.34729523956776, 50.300431698560715, 57.0502033084631, 60.21029233932495, 58.675182312726974, 59.92298595607281, 63.653352186083794, 62.29131147265434, 59.154313802719116, 58.89664962887764, 63.02537888288498, 57.95784920454025, 61.146216318011284, 61.29272885620594, 61.95484712719917, 65.19478127360344, 64.16695162653923, 63.31721842288971, 57.39451043307781, 63.853704035282135, 60.995808988809586, 61.681033819913864, 52.85188838839531, 51.475910022854805, 49.49754238128662, 52.9661900550127, 53.36165003478527, 57.36907459795475, 59.27597567439079, 59.20184165239334, 61.4263790845871, 61.836966052651405, 57.95280307531357, 56.64139844477177, 52.72361867129803, 54.31031472980976, 59.1686200350523, 72.59814441204071, 71.17773503065109, 76.20191663503647, 76.21434196829796, 73.22530835866928, 66.56063318252563, 68.02362307906151, 65.41337594389915, 65.48650681972504, 61.60101771354675, 66.37217089533806, 61.89797557890415, 66.57562717795372, 62.50803664326668, 68.18009108304977, 72.85199359059334, 86.8464982509613, 75.54965123534203, 98.21379348635674, 22.512530386447906, 0.09407737059518695, 64.82760697603226, 85.66658556461334, 71.64984449744225, 59.418506026268005, 70.77420428395271, 37.17251233756542, 44.69874568283558, 47.16502994298935, 6.181734865531325, 0.38798346533440053, 0.8415715978480875, 2.5764462864026427, 2.4950420670211315, 1.1232470395043492, 0.1890617495519109, 0.2349120783037506], [0.02254334609460784, 0.029141617815184873, 0.05952394327323418, 0.059931887008133344, 0.06104326428612694, 0.20740888692671433, 11.110670305788517, 52.26155586540699, 61.2361840903759, 32.36426554620266, 35.978677198290825, 44.25271421670914, 48.56346510350704, 52.781740352511406, 75.55926471948624, 66.88850238919258, 74.44115191698074, 2.9348582541570067, 0.11328876862535253, 0.6140632589813322, 3.334985333494842, 50.461318865418434, 56.88431940972805, 64.62275996804237, 69.49430376291275, 72.88777247071266, 73.34871053695679, 74.28643941879272, 70.74889004230499, 73.15181270241737, 71.96821421384811, 69.94563594460487, 70.28228268027306, 69.3153865635395, 69.28587734699249, 65.6530898809433, 64.73221689462662, 60.84727495908737, 53.09260547161102, 53.358488604426384, 48.414216712117195, 49.62172731757164, 48.29747177660465, 47.48571753501892, 48.4257110953331, 45.64519889652729, 44.62495744228363, 45.27779661118984, 48.70596505701542, 47.78011433780193, 46.34756460785866, 49.87008959054947, 58.66304576396942, 58.9043328166008, 59.44134280085564, 60.582193583250046, 57.90056347846985, 53.7469607591629, 54.43792708218098, 54.353905990719795, 53.19267310202122, 53.3978620916605, 52.11281284689903, 52.91406065225601, 51.644499376416206, 52.11736120283604, 49.487195536494255, 48.527648225426674, 45.811329782009125, 47.17996694147587, 48.52191053330898, 50.964229479432106, 55.728600025177, 58.16551946103573, 48.69184501469135, 54.03014436364174, 48.18882420659065, 36.10320791602135, 42.77233645319939, 42.43246749043465, 54.468701630830765, 44.40399169921875, 44.01809960603714, 41.36345945298672, 44.06468130648136, 44.29338723421097, 46.13489381968975, 46.85527816414833, 51.337301060557365, 51.64162293076515, 46.23347572982311, 46.24957166612148, 43.98973032832146, 41.325290501117706, 42.772754430770874, 41.474523693323135, 46.19305729866028, 50.26550017297268, 44.13337022066116, 41.984627321362495, 35.123183503746986, 41.58172354102135, 36.9804098457098, 48.38493928313255, 57.18843229115009, 57.642173543572426, 54.47638101875782, 51.66470669209957, 53.9368099719286, 52.96170249581337, 60.24831309914589, 57.49160662293434, 55.538439229130745, 57.44427636265755, 52.702127024531364, 55.32258041203022, 54.95785318315029, 54.91208463907242, 54.758344888687134, 54.81309615075588, 56.94305665791035, 58.80068577826023, 54.956869035959244, 59.75031562149525, 49.524566531181335, 45.98667897284031, 44.61639270186424, 46.14731915295124, 49.14033114910126, 52.6024279743433, 53.57362546026707, 55.47916620969772, 56.02946028113365, 55.148097574710846, 50.53541108965874, 50.76572433114052, 49.260811284184456, 50.17035327851772, 57.33251295983791, 65.66375970840454, 63.671788796782494, 64.51515734195709, 64.96845781803131, 64.11179378628731, 60.847027972340584, 61.74374185502529, 59.4771558791399, 57.86139518022537, 54.82632704079151, 59.1653598099947, 57.40131586790085, 57.63547070324421, 56.779578030109406, 65.37788584828377, 69.68889892101288, 80.29903158545494, 71.96889817714691, 94.56658959388733, 15.976778492331505, 0.15341945429099724, 62.685095742344856, 63.38863559067249, 52.70437650382519, 37.72192865610123, 36.36641979217529, 15.756638254970312, 8.643080815672874, 6.1163161508738995, 2.711650631390512, 0.1712208311073482, 0.010550965089350939, 0.15356032876297832, 0.04715957744338084, 0.07288282780791633, 0.12971548014320433, 0.0367926167382393, 0.11554849697859026, 0.056678029577597044, 0.07852617069147527, 0.13983408483909443, 0.11883243365446106, 0.30469490331597626, 14.697114508599043, 63.357226476073265, 72.2180812060833, 30.224588960409164, 38.385304659605026, 54.167275205254555, 56.53242789208889, 60.213297978043556, 82.85624116659164, 75.94093903899193, 84.23523277044296, 4.6373789850622416, 0.5761182575952262, 0.6996958202216774, 3.1826277589425445, 61.74574054777622, 64.91273760795593, 74.54455956816673, 78.05769145488739, 78.58261048793793, 78.26709821820259, 80.815819054842, 77.50145450234413, 78.86094555258751, 76.20902225375175, 74.09616842865944, 74.94930624961853, 73.38889718055725, 72.19889223575592, 69.9297907948494, 68.10997724533081, 63.393472731113434, 55.01519210636616, 56.01600140333176, 51.31424009799957, 54.56770911812782, 51.53774790465832, 53.33871826529503, 52.02039420604706, 49.85205575823784, 46.947001442313194, 47.77757607400417, 51.031166687607765, 49.7778457403183, 48.99629607796669, 51.201040372252464, 58.876734897494316, 60.90030871331692, 60.608818754553795, 61.84673152863979, 59.38786447048187, 57.16118015348911, 55.947304889559746, 58.07729959487915, 54.68540020287037, 55.95243461430073, 54.70041699707508, 55.43349266052246, 55.98779931664467, 53.985283970832825, 52.191989198327065, 51.47739194333553, 48.37033286690712, 51.39089718461037, 48.105810061097145, 55.27433060109615, 57.253006026148796, 59.18938972055912, 51.9238755851984, 54.16899271309376, 48.88738252222538, 38.08589592576027, 43.91056917607784, 44.34284918010235, 54.62509363889694, 47.39436283707619, 44.1623018682003, 45.480181351304054, 44.91549365222454, 47.75142967700958, 48.76279100775719, 48.611129745841026, 54.34866987168789, 52.225913777947426, 49.18388441205025, 49.26094047725201, 47.28184327483177, 43.818104937672615, 44.19969946146011, 42.692088559269905, 46.572155356407166, 53.40220905840397, 46.66885256767273, 41.730337366461754, 35.49660086631775, 40.2822008728981, 40.81956043839455, 61.50957942008972, 60.3914400190115, 58.60330916941166, 57.338243052363396, 53.04244056344032, 55.514086335897446, 55.78640632331371, 63.026370629668236, 57.50793434679508, 56.85566894710064, 58.56771647930145, 56.15879774093628, 57.059292420744896, 55.75169898569584, 55.526272282004356, 56.24144710600376, 57.64728046953678, 58.868097960948944, 59.59021881222725, 58.13052713871002, 60.2525232732296, 51.842320561409, 47.573538422584534, 46.2396389991045, 50.882849246263504, 51.29948548972607, 55.865753665566444, 56.14247761666775, 60.57088539004326, 58.23964208364487, 58.242830112576485, 52.82335191965103, 53.445313945412636, 50.14335572719574, 54.07322645187378, 59.122456312179565, 67.47934028506279, 69.16679933667183, 72.08856895565987, 70.19316986203194, 70.08913144469261, 64.75683957338333, 67.53255262970924, 63.31848755478859, 64.42827880382538, 57.71978437900543, 64.5199678838253, 59.977805614471436, 63.74145805835724, 63.213936164975166, 71.5748593211174, 73.60528036952019, 87.6033416390419, 74.31940644979477, 100.11485427618027, 15.544883217662573, 0.18030454055406153, 69.87886592745781, 73.15008759498596, 62.39651642739773, 48.47466766834259, 50.44976748526096, 22.771070413291454, 15.577990841120481, 18.84215533733368, 6.102402247488499, 0.2751816197996959, 0.12465988111216575, 0.6758373754564673, 0.4168280737940222, 0.07858537181164138, 0.10659548715921119, 0.11167092379764654, 0.20547508756862953, 0.18776811193674803, 0.22769314848119393, 0.27270634949672967, 0.2949217980494723, 0.7737999781966209, 18.28317493200302, 76.81898072361946, 83.65388676524162, 46.35565437376499, 51.723459139466286, 55.14690823853016, 67.71477565169334, 71.16249784827232, 88.80911573767662, 80.92922016978264, 90.51742047071457, 6.118833990767598, 0.743155216332525, 0.9820047591347247, 3.6369909904897213, 68.53862464427948, 68.39781939983368, 78.73526349663734, 76.01016372442245, 82.03282535076141, 78.37710231542587, 81.82251423597336, 78.62259954214096, 80.44558212161064, 77.74630576372147, 76.76558598876, 77.88300722837448, 75.44737592339516, 73.75754579901695, 72.99792855978012, 70.06596788764, 66.43015578389168, 58.33852797746658, 59.70359332859516, 55.69740749895573, 55.74235908687115, 54.84515883028507, 55.74207790195942, 53.90198104083538, 54.33882839977741, 50.36071166396141, 49.78272467851639, 51.82365596294403, 52.63258695602417, 51.849540174007416, 53.931414261460304, 62.17287942767143, 63.68228763341904, 64.9738459289074, 66.69410482048988, 63.22758123278618, 58.90418462455273, 58.67052376270294, 61.505456641316414, 58.981590270996094, 60.391352623701096, 58.198915868997574, 58.34276854991913, 59.367242977023125, 57.18880847096443, 54.62450847029686, 54.606539234519005, 51.510674357414246, 54.65966418385506, 52.95569121837616, 57.14718170464039, 63.36484506726265, 60.03620848059654, 53.47678765654564, 56.57918818295002, 46.22616492211819, 38.72471384704113, 44.00937147438526, 47.302563562989235, 56.56240068376064, 50.60831777751446, 48.73002156615257, 48.16558085381985, 47.915200889110565, 50.467166751623154, 50.62382094562054, 51.263649612665176, 56.66933834552765, 57.76250168681145, 51.28559723496437, 51.43188938498497, 50.168829560279846, 46.746444404125214, 47.01455421745777, 47.460749074816704, 48.05606693029404, 55.79494446516037, 48.53982277214527, 43.114812076091766, 36.65623404085636, 43.70403505861759, 35.61337240040302, 50.77124923467636, 64.4544517993927, 60.28644785284996, 59.35235537588596, 55.56399665772915, 59.61481109261513, 57.69339099526405, 68.06744232773781, 61.15544982254505, 59.84261266887188, 61.7002759873867, 58.73206906020641, 58.800218403339386, 59.29635018110275, 59.28762964904308, 59.086783826351166, 60.41327364742756, 61.049959883093834, 64.02538642287254, 60.3506264090538, 64.30757448077202, 53.1936040520668, 50.50860732793808, 50.64609535038471, 52.32386112213135, 53.79658229649067, 58.59776146709919, 57.663190215826035, 62.75420643389225, 62.206804007291794, 62.400605008006096, 55.53542599081993, 55.21808221936226, 53.55900004506111, 55.8442772179842, 62.78270110487938, 71.02308332920074, 70.34229665994644, 74.34794291853905, 72.06251755356789, 72.59039282798767, 67.85470694303513, 70.91087535023689, 67.17808485031128, 66.51622876524925, 58.82033832371235, 68.42580869793892, 62.847962602972984, 65.48843711614609, 63.843626976013184, 74.3039944767952, 73.0383887887001, 87.97600284218788, 76.4287568628788, 102.55545571446419, 18.529183231294155, 0.40083900676108897, 76.08644843101501, 78.02450403571129, 72.40791141986847, 62.12882079184055, 67.69370198249817, 37.16025419533253, 42.81930573284626, 46.672390177845955, 9.348872043192387, 0.4197328398004174, 0.1244448364013806, 0.3888313245261088, 0.2014329654048197, 0.24603523925179616, 0.18448511778842658, 0.1537532574729994], [0.015736922359792516, 0.12133353811805137, 0.025894990758388303, 0.04271136691386346, 0.048362424422521144, 0.36220639070961624, 6.009167125448585, 48.703593984246254, 54.24137502908707, 34.59384150803089, 31.695849113166332, 23.424604944884777, 45.2082185447216, 53.37691381573677, 69.80986163020134, 61.23045779764652, 77.67423883080482, 4.290922125801444, 0.3097586065996438, 0.5025007110089064, 4.82791643589735, 52.229660376906395, 62.879622504115105, 69.48000892996788, 74.28035214543343, 74.55768406391144, 74.1288086771965, 72.7841368317604, 71.99725985527039, 71.6098402440548, 69.16610017418861, 69.82490882277489, 67.58605375885963, 73.8381926715374, 66.5280233323574, 67.12263062596321, 60.3231006860733, 55.18950395286083, 50.74639096856117, 50.87708495557308, 47.84992799162865, 48.827163353562355, 48.6224265396595, 52.10509926080704, 46.86874844133854, 43.300420716404915, 42.42696538567543, 45.86120590567589, 47.328846752643585, 50.38708224892616, 45.735508650541306, 49.49724979698658, 54.62439447641373, 59.76706512272358, 59.09116119146347, 58.332946076989174, 55.273525044322014, 54.54826936125755, 55.198072493076324, 53.48165899515152, 54.37721014022827, 53.54953855276108, 52.961964681744576, 53.0070910602808, 50.09585827589035, 52.72906377911568, 51.38518609106541, 49.13859844207764, 44.42917674779892, 46.99518285691738, 45.85659295320511, 49.663502275943756, 58.24477940797806, 62.425463274121284, 45.899165868759155, 53.767681047320366, 43.053034991025925, 43.74690055847168, 42.057705000042915, 40.50114892423153, 52.49082416296005, 48.255909606814384, 43.69638226926327, 42.68114134669304, 41.649337112903595, 44.25097391009331, 44.37824048101902, 43.04951258003712, 43.09121914207935, 46.562112495303154, 41.97473645210266, 43.97797375917435, 43.782896026968956, 42.45731055736542, 41.30897417664528, 42.83821351826191, 46.3761580735445, 48.65471340715885, 39.13247376680374, 42.23032973706722, 37.44979865849018, 37.81093508005142, 26.988443210721016, 42.55674362182617, 61.839789301157, 51.07686683535576, 52.74742439389229, 46.13400846719742, 48.57705697417259, 50.00032000243664, 53.618729040026665, 52.18800701200962, 51.94068968296051, 50.2494840323925, 49.6830902248621, 49.22042325139046, 50.613572895526886, 51.83606989681721, 51.11210614442825, 54.281968250870705, 56.354513838887215, 58.11003863811493, 54.87761668860912, 55.43040342628956, 51.17286868393421, 44.187190532684326, 43.26103202998638, 45.98108567297459, 51.85603402554989, 51.33477419614792, 53.12911011278629, 56.578318029642105, 53.804029896855354, 52.06642873585224, 49.38638314604759, 48.90528716146946, 49.80009734630585, 49.080602154135704, 54.22810234129429, 67.2032319009304, 64.13629487156868, 64.6751819550991, 65.95096349716187, 63.66036280989647, 60.726240053772926, 60.67213475704193, 58.12245637178421, 61.30724787712097, 56.45927421748638, 57.82066896557808, 57.694652527570724, 61.32643684744835, 60.74056148529053, 71.12149804830551, 71.91523745656013, 81.92744180560112, 68.58879715204239, 93.55500027537346, 6.162268985062838, 1.0179822379723191, 68.57640221714973, 62.309356704354286, 53.77373032271862, 36.90231643617153, 33.40449772775173, 12.207165118306875, 9.976393170654774, 3.4640929056331515, 2.604371225461364, 0.3392737009562552, 0.05427369003882632, 0.10851435450604185, 0.00944646009884309, 0.018545658167568035, 0.06479458330431953, 0.04283617759938352, 0.04644249209377449, 0.07145204130210914, 0.028620216398849152, 0.008046853999985615, 0.03423038528126199, 0.19830675737466663, 7.826198749244213, 63.430604338645935, 64.77856680750847, 35.8943597227335, 36.77294857800007, 28.227015249431133, 55.672640427947044, 61.95000618696213, 77.16701924800873, 69.560716599226, 85.25173142552376, 6.8021266255527735, 1.1852352507412434, 0.8105946506839246, 6.01006387732923, 63.791524171829224, 70.5238889157772, 79.08153891563416, 79.32737052440643, 82.09328010678291, 76.89737811684608, 79.17885929346085, 76.45677655935287, 75.79883426427841, 71.91545024514198, 76.37706443667412, 71.94319635629654, 78.3160699903965, 73.79768684506416, 71.81471765041351, 64.36171397566795, 59.03832122683525, 54.08595956861973, 53.62665541470051, 52.76311755180359, 53.508211970329285, 52.61099651455879, 54.680517464876175, 50.32246291637421, 47.16526173055172, 43.94779957830906, 49.700907468795776, 50.94401456415653, 51.82332918047905, 49.24116253852844, 51.669828817248344, 54.09585423767567, 60.18331378698349, 58.78564238548279, 60.44680304825306, 57.68448427319527, 57.02394291758537, 55.63829027116299, 55.671397894620895, 56.35051265358925, 56.77351355552673, 55.50882361829281, 56.87061734497547, 54.90728169679642, 56.76191657781601, 53.80660615861416, 51.36360704898834, 46.511107832193375, 48.66492345929146, 47.39425264298916, 51.09618119895458, 60.60108236968517, 67.97213584184647, 47.749715968966484, 53.538165763020515, 46.623828783631325, 44.13289524614811, 44.067333564162254, 41.93241432309151, 52.69732788205147, 50.31487472355366, 46.9073049724102, 44.25550326704979, 43.17952260375023, 45.42086273431778, 47.49335132539272, 45.18888518214226, 46.010256707668304, 47.300925850868225, 44.71220076084137, 46.254659593105316, 45.135631039738655, 45.11951990425587, 45.27954451739788, 46.25110298395157, 47.65838786959648, 52.7223951369524, 41.91444128751755, 42.15745724737644, 37.52917259931564, 38.13967064023018, 27.68020749092102, 49.45843867957592, 69.27570149302483, 54.238346591591835, 54.7092629224062, 48.23702082037926, 51.22556805610657, 50.616377145051956, 54.03726518154144, 52.97394923865795, 51.81961677968502, 51.48374140262604, 49.87232007086277, 49.8478227853775, 49.87064056098461, 53.33896145224571, 54.61706466972828, 58.24134819209576, 58.401144817471504, 61.02765507996082, 56.85102939605713, 57.664732933044434, 52.670957297086716, 48.04207228124142, 45.00826947391033, 48.876366913318634, 53.15773397684097, 54.167567789554596, 55.490383207798004, 60.36299854516983, 56.60423643887043, 55.68609170615673, 52.38064147531986, 52.12167777121067, 51.78666494786739, 52.26344436407089, 57.52289794385433, 71.47326037287712, 68.39540272951126, 71.26339003443718, 69.07958641648293, 66.93520188331604, 63.20005550980568, 66.20805010199547, 61.7259968072176, 65.849888920784, 58.675079718232155, 60.917764976620674, 58.62497940659523, 65.79059690237045, 65.11416479945183, 76.61889865994453, 76.69877797365189, 87.59547606110573, 73.49594503641129, 97.59932845830917, 5.49389767460525, 2.024865271523595, 77.52807587385178, 70.1513797044754, 62.76756651699543, 48.45553569495678, 45.72566717863083, 20.922595001757145, 19.015327244997025, 14.48317838832736, 4.9504997581243515, 0.33104898291639984, 0.013024268700974062, 0.22065975557779893, 0.03610397790907882, 0.08668817725265399, 0.08528092424967326, 0.027625551119854208, 0.16528234351426363, 0.15115151036297902, 0.16933553852140903, 0.15180986956693232, 0.16740509367082268, 0.5893051531165838, 10.085382722318172, 74.45605471730232, 77.40364775061607, 51.989194080233574, 51.27032205462456, 32.46758960187435, 64.95709642767906, 70.96005991101265, 82.0334105193615, 73.08114409446716, 91.0790303349495, 7.417965279892087, 1.5512274554930627, 2.0684071350842714, 6.856710221618414, 72.2567631304264, 72.08874374628067, 80.75412556529045, 77.97880008816719, 82.59992972016335, 75.98219722509384, 82.75067523121834, 78.17838817834854, 78.49510118365288, 75.11802479624748, 78.5934779047966, 72.48903706669807, 82.00767830014229, 76.4085191488266, 74.15036872029305, 65.90204492211342, 61.47321157157421, 56.84979446232319, 56.68767236173153, 55.49474537372589, 56.600698828697205, 56.474507600069046, 59.11055535078049, 52.68480755388737, 50.67127279937267, 47.604453563690186, 51.83067038655281, 54.746804907917976, 55.16180343925953, 50.90068928897381, 53.90926904976368, 58.400141671299934, 63.393936306238174, 60.92571035027504, 62.744418159127235, 59.8900493234396, 59.97214391827583, 59.60065685212612, 59.18308585882187, 60.02544365823269, 60.614237263798714, 58.31450566649437, 58.40560957789421, 57.291497960686684, 58.36048699915409, 56.28441520035267, 54.570034593343735, 50.05732074379921, 52.18654029071331, 51.4557521045208, 56.38247653841972, 59.6077548712492, 68.13204646110535, 52.70468808710575, 52.18377023935318, 44.46902520954609, 45.278776958584785, 44.603256806731224, 44.12990100681782, 56.682155057787895, 52.58319340646267, 49.08408656716347, 46.63346506655216, 46.451888009905815, 50.452503338456154, 49.63480621576309, 49.027754589915276, 48.237465396523476, 50.32373584806919, 46.820004656910896, 50.34043975174427, 46.31975769996643, 47.843399941921234, 46.05618864297867, 49.2795442789793, 51.226476207375526, 54.463925287127495, 43.96792329847813, 45.46931013464928, 39.524696320295334, 40.0810244679451, 29.946649074554443, 41.56022809445858, 68.04009899497032, 57.51237250864506, 58.198950067162514, 50.06481774151325, 53.837551698088646, 54.50442351400852, 57.97755114734173, 57.12216004729271, 56.16115741431713, 55.79614520072937, 52.04244442284107, 54.10474196076393, 54.65689793229103, 59.063646867871284, 56.550123542547226, 62.38737031817436, 60.87780252099037, 65.07962465286255, 57.78359055519104, 59.75966311991215, 57.15914726257324, 51.014041006565094, 47.37074330449104, 50.878160297870636, 56.9322120398283, 56.277301982045174, 58.99467296898365, 61.840617656707764, 60.69513872265816, 57.18883126974106, 54.627685099840164, 55.17179310321808, 54.16333481669426, 54.69779893755913, 59.93219666182995, 75.8918608725071, 69.638582020998, 72.06811085343361, 71.35231286287308, 71.6462042927742, 66.00845441222191, 68.47820028662682, 63.8724522292614, 69.26234140992165, 61.638134121894836, 64.80795443058014, 63.266149163246155, 67.79078677296638, 65.076584815979, 78.34690153598785, 76.30416914820671, 88.61121475696564, 72.82557740807533, 101.98799416422844, 7.6075665559619665, 2.1651062462478876, 85.23448035120964, 75.15299052000046, 72.15473860502243, 58.78403127193451, 61.61356844007969, 31.40855982899666, 45.95448710024357, 39.52991344034672, 7.698008352890611, 0.3763222473207861, 0.1869182934751734, 0.2910815994255245, 0.1373730192426592, 0.22420774097554386, 0.2581755432765931, 0.14557277143467218], [0.023866170522524044, 0.021335953460948076, 0.06515105909784324, 0.05066011734015774, 0.054475431752507575, 0.3268191864481196, 3.0746342288330197, 44.79996085166931, 60.20524621009827, 34.36812601983547, 22.990919016301632, 40.511959344148636, 48.63394372165203, 49.04520325362682, 66.62863433361053, 64.04554814100266, 85.56901440024376, 9.726039804518223, 0.5527528957463801, 0.22612090862821788, 5.2969518676400185, 55.50313912332058, 65.06786048412323, 72.48385414481163, 73.68535727262497, 73.75110894441605, 73.98926496505737, 73.86463925242424, 73.35479781031609, 72.14730620384216, 70.44103816151619, 73.61623138189316, 71.93223014473915, 68.32855671644211, 65.61404317617416, 66.48619517683983, 56.94839157164097, 52.204038351774216, 52.12953194975853, 51.29687123000622, 50.61788186430931, 49.067295268177986, 48.84114280343056, 51.036611795425415, 46.05987824499607, 44.23748843371868, 42.84573331475258, 46.27643242478371, 48.44777271151543, 48.44727873802185, 46.194607615470886, 46.82028964161873, 51.33257031440735, 57.950021624565125, 55.256110578775406, 58.00641059875488, 54.406137987971306, 54.55338388681412, 53.24777774512768, 54.535570442676544, 53.52183423936367, 51.64001941680908, 55.01392677426338, 55.18552176654339, 52.3814432322979, 52.89893366396427, 53.05093690752983, 47.317834943532944, 45.14750920236111, 47.39927597343922, 44.94588442146778, 53.843277990818024, 92.93387040495872, 51.930874809622765, 44.209210351109505, 49.57707591354847, 37.42859959602356, 44.51399579644203, 45.85060067474842, 41.88261039555073, 46.878494918346405, 48.262555450201035, 44.27225276827812, 42.44243435561657, 45.39315462112427, 40.12073993682861, 41.352455243468285, 44.6447391808033, 37.68073506653309, 39.565471932291985, 41.83866195380688, 42.037433087825775, 40.145001634955406, 43.03814359009266, 40.48903897404671, 43.22866916656494, 45.58554209768772, 46.23216100037098, 37.921676337718964, 42.183083072304726, 39.39360335469246, 42.31928676366806, 35.380095317959785, 27.898807860910892, 62.345131784677505, 54.738228768110275, 50.8667267113924, 43.68828870356083, 44.941324666142464, 44.36968334019184, 45.4490040242672, 50.12720659375191, 47.137903198599815, 47.077627032995224, 48.85630778968334, 47.370788902044296, 49.057510793209076, 49.800275936722755, 48.9199847728014, 53.421835005283356, 52.8273569047451, 55.32975062727928, 55.44168122112751, 55.5083904415369, 47.94586144387722, 45.79297676682472, 42.826950922608376, 44.27311152219772, 48.1876652687788, 47.9819443076849, 52.391071915626526, 52.265899032354355, 51.17200993001461, 50.913205817341805, 47.38235928118229, 47.13112436234951, 48.598757609725, 49.739501997828484, 54.64208632707596, 66.01964861154556, 64.51332584023476, 65.92051953077316, 63.62046115100384, 64.13789078593254, 63.417654633522034, 63.54798763990402, 60.62638521194458, 64.8820124566555, 59.0279021859169, 60.248533487319946, 57.09704339504242, 63.636374697089195, 65.70618823170662, 72.2740826010704, 74.39699828624725, 76.4659796655178, 72.17385917901993, 81.2985147535801, 1.6943186335265636, 3.9913044031709433, 73.88232350349426, 60.36307454109192, 50.60293346643448, 33.38263750076294, 40.3589453548193, 15.676765590906143, 10.866831690073013, 7.8622564394026995, 1.0927413264289498, 0.3041767654940486, 0.065298776171403, 0.10560536567936651, 0.04952015995513648, 0.1726197052630596, 0.03511245748086367, 0.08523056210833602, 0.01068558232873329, 0.09285177307901904, 0.04653376883652527, 0.01722271685139276, 0.057736807139008306, 0.2254435801296495, 3.171816864050925, 60.37725158035755, 71.10625326633453, 39.37694884836674, 19.15145304054022, 34.50532525777817, 58.79400193691254, 55.73890507221222, 77.24379032850266, 70.12124732136726, 95.40673211216927, 11.163357328623533, 1.567615382373333, 1.8783009611070156, 7.008182443678379, 66.75272047519684, 70.69776758551598, 81.2946617603302, 78.9508943259716, 81.1637131869793, 79.14625704288483, 79.74581927061081, 76.6821500658989, 75.53999215364456, 74.16821256279945, 75.84355786442757, 75.34019127488136, 74.67490017414093, 71.48715242743492, 70.96089586615562, 60.33685974776745, 56.09929293394089, 55.24668328464031, 53.36654417216778, 52.63168640434742, 54.024668857455254, 53.42870123684406, 53.29810984432697, 49.434328973293304, 46.176349595189095, 46.37291304767132, 48.96216630935669, 49.67948421835899, 50.80633655190468, 49.6475925296545, 49.78810518980026, 52.58554168045521, 60.02979442477226, 58.19879427552223, 60.153329595923424, 55.90743362903595, 56.52877248823643, 55.650388821959496, 55.8534537255764, 55.68877816200256, 57.958210185170174, 57.267669439315796, 59.54126983880997, 55.379987731575966, 56.51087544858456, 57.68741391599178, 51.62261635065079, 47.19373740255833, 51.302776113152504, 45.14582209289074, 61.63727916777134, 95.30465438961983, 54.34720695018768, 43.80365051329136, 51.26094035804272, 41.61051459610462, 45.5465903878212, 50.80917879939079, 41.89101554453373, 48.891752287745476, 49.192878529429436, 46.55959703028202, 47.359305918216705, 46.548402830958366, 44.3227406591177, 44.46664273738861, 47.23628371953964, 41.96272909641266, 43.952195942401886, 44.06687758862972, 43.50754380226135, 42.392660826444626, 46.338369101285934, 45.25354631245136, 45.92760354280472, 47.98519313335419, 47.5147707760334, 41.90507099032402, 45.93141853809357, 39.503045082092285, 44.13685083389282, 36.878282725811005, 34.58522357046604, 73.18964347243309, 56.75095796585083, 54.207511246204376, 46.535950899124146, 47.2570876032114, 46.65858171880245, 47.08979777991772, 52.12373726069927, 49.31588552892208, 48.802954852581024, 50.5225183814764, 51.25409692525864, 50.02553924918175, 50.743803307414055, 50.92777423560619, 54.12895806133747, 55.13264760375023, 56.021146327257156, 59.097852632403374, 56.790441647171974, 50.09233586490154, 49.09784182906151, 46.62435695528984, 48.57885427772999, 49.101406037807465, 51.960099041461945, 54.6629586070776, 54.77802403271198, 53.67054685950279, 54.03930947184563, 48.71912755072117, 50.258816331624985, 51.97788588702679, 52.54818968474865, 55.90420380234718, 70.78281462192535, 66.80101588368416, 69.00868982076645, 68.05744886398315, 69.67998459935188, 67.44366779923439, 67.24749192595482, 65.86697280406952, 69.6944010257721, 62.84006282687187, 65.02078860998154, 57.67980672419071, 70.13865038752556, 69.35269296169281, 79.50377985835075, 77.9595199227333, 83.05150508880615, 75.58361381292343, 86.79524660110474, 1.1031686794012785, 5.730697643011808, 81.26875475049019, 71.68330550193787, 59.053657203912735, 45.7017170637846, 58.26733499765396, 25.120305754244328, 20.63715811818838, 18.039851188659668, 3.7839257810264826, 0.5534639919642359, 0.04985724342986941, 0.25439563672989607, 0.04149769200012088, 0.13429386337520555, 0.06590445031179115, 0.00767634233852732, 0.2727859077276662, 0.1614160361350514, 0.10978703387081623, 0.09021717109135352, 0.15368956635938957, 0.46004006755538285, 3.6950943851843476, 74.06974464654922, 85.80652445554733, 50.12469492852688, 36.7042026668787, 51.03569604456425, 70.20744189620018, 63.95293191075325, 85.39812237024307, 74.91565525531769, 103.43526810407639, 12.71088033914566, 2.497100131586194, 2.186308396048844, 8.567596916109324, 71.78790628910065, 68.6045891046524, 80.15935868024826, 78.32135930657387, 83.24566707015038, 77.08542242646217, 83.98799523711205, 79.92865025997162, 78.80755841732025, 75.92212244868279, 79.65709403157234, 74.3103401362896, 80.22838577628136, 71.37001991271973, 73.27127829194069, 63.14970441162586, 57.45709307491779, 59.22364488244057, 57.70550474524498, 55.750323459506035, 56.51874482631683, 55.91128662228584, 55.78185796737671, 52.32165724039078, 51.14997111260891, 48.38434271514416, 51.442202031612396, 52.20990903675556, 53.30768533051014, 50.64940497279167, 52.7595267444849, 56.028761118650436, 62.377133667469025, 60.69794297218323, 62.63872683048248, 57.64537297189236, 59.56045500934124, 59.63292472064495, 58.65810602903366, 59.0499410033226, 59.74134810268879, 59.61608022451401, 61.270986422896385, 59.29916203022003, 57.12282121181488, 62.367649376392365, 53.466323018074036, 51.5698029845953, 52.613656371831894, 51.653786078095436, 61.48747980594635, 86.470295637846, 58.960907980799675, 44.50948923826218, 49.80645440518856, 44.28188905119896, 49.45234760642052, 52.53623552620411, 45.28544560074806, 52.34552375972271, 52.93845534324646, 50.44048458337784, 48.83470594882965, 50.75176388025284, 45.01334600150585, 46.4425291121006, 49.654515758156776, 43.55827867984772, 46.39512285590172, 47.13742822408676, 46.835903003811836, 46.044249683618546, 48.38159926235676, 48.401362001895905, 49.63544838130474, 51.01751022040844, 49.85631912946701, 44.2928134649992, 46.58635899424553, 41.98077812790871, 43.17389890551567, 38.181719183921814, 35.39784036576748, 66.76722049713135, 59.835104271769524, 55.69613836705685, 48.84031444787979, 49.7185043245554, 48.14638428390026, 51.48597188293934, 53.9594529569149, 53.065801709890366, 51.81164860725403, 55.63391290605068, 54.059193804860115, 54.21480305492878, 53.59401896595955, 52.624060213565826, 56.890771463513374, 58.32688920199871, 59.55362677574158, 60.49545183777809, 58.18382307887077, 52.52034857869148, 51.53895244002342, 48.26273404061794, 50.484018847346306, 53.70497301220894, 52.83536687493324, 56.283347457647324, 58.13824452459812, 57.19044618308544, 55.90303346514702, 51.02864362299442, 51.74642130732536, 53.19018803536892, 55.522867664694786, 57.97515347599983, 72.36440375447273, 68.79562005400658, 71.26918852329254, 68.0568864941597, 71.66422292590141, 69.18845817446709, 68.8694728910923, 67.03768998384476, 74.75294038653374, 64.71305072307587, 68.50444167852402, 60.08289277553558, 72.15406984090805, 69.56536754965782, 81.06535166501999, 76.86045929789543, 84.44016337394714, 74.28201645612717, 92.30036079883575, 2.517272299155593, 5.448549007996917, 89.45961803197861, 76.82854101061821, 68.50369691848755, 57.97218583524227, 68.65713268518448, 37.372187823057175, 51.90707288682461, 35.95875486731529, 7.3047826532274485, 0.6559362995903939, 0.1850609204848297, 0.42691840266343206, 0.15315599186578766, 0.1917720728670247, 0.1686478644842282, 0.12852906802436337], [0.0609362206159858, 0.06991729474975727, 0.06355179764796048, 0.06585350929526612, 0.10576879401924089, 0.17577101272763684, 0.390152822365053, 33.712923377752304, 49.39475789666176, 48.70122671127319, 36.763118505477905, 39.33698259294033, 48.95792953670025, 45.24449899792671, 54.21751610934734, 61.67373061180115, 80.33322215080261, 14.944863114506006, 1.0721835982985795, 0.5376832606270909, 6.576781617477536, 56.923160925507545, 62.12742246687412, 75.28021529316902, 74.03624564409256, 75.05894556641579, 71.45349383354187, 72.53658011555672, 72.24208071827888, 76.34057119488716, 71.40614837408066, 72.29104489088058, 65.76386153697968, 70.1942566037178, 68.5254317522049, 61.7641581594944, 50.61186298727989, 52.24887974560261, 49.45414111018181, 52.56279230117798, 48.06320674717426, 50.26985853910446, 49.583512768149376, 51.720354706048965, 45.263083800673485, 43.86607736349106, 43.16940754652023, 44.855787456035614, 45.07857710123062, 48.829811811447144, 50.91320961713791, 50.06034158170223, 48.92622783780098, 58.63698676228523, 59.55066293478012, 58.25714394450188, 53.421671614050865, 53.36073808372021, 54.27507542073727, 54.66268502175808, 52.795168831944466, 54.71467383205891, 54.84078526496887, 52.80410975217819, 53.99911902844906, 54.0289132297039, 51.37122564017773, 49.70551282167435, 48.8847416639328, 48.9333638548851, 41.95398956537247, 69.08109113574028, 86.4667846262455, 43.07971715927124, 48.969914093613625, 42.71572329103947, 39.815688505768776, 44.43222038447857, 44.0851242095232, 43.02076332271099, 44.44435693323612, 44.19155649840832, 43.56980726122856, 43.23697172105312, 43.02255302667618, 39.26198601722717, 39.74337458610535, 41.673158034682274, 40.46109527349472, 38.08946393430233, 42.76946000754833, 40.74946179986, 40.797460824251175, 38.79026412963867, 43.180187568068504, 47.117441296577454, 47.729641646146774, 43.97850953042507, 41.05685770511627, 40.46525605022907, 42.73175083100796, 44.512335285544395, 51.98523089289665, 26.045474410057068, 46.077581495046616, 66.01091668009758, 48.15472103655338, 49.367330968379974, 44.104636162519455, 43.41997370123863, 44.80805441737175, 49.45517845451832, 47.63638325035572, 48.264949321746826, 47.26443640887737, 52.31606774032116, 50.667423605918884, 51.741063594818115, 49.82033126056194, 51.02522000670433, 52.64889948070049, 51.84989355504513, 50.41239269077778, 54.64022062718868, 48.2439174503088, 43.16490098834038, 43.456687331199646, 43.088734075427055, 43.89930658042431, 48.58106955885887, 50.199930891394615, 49.945059567689896, 48.520155027508736, 46.58429950475693, 47.19528391957283, 48.04353520274162, 49.54533241689205, 48.45311142504215, 53.82420301437378, 65.618876516819, 63.38022664189339, 67.07007184624672, 65.21193355321884, 67.0521292090416, 67.86844700574875, 66.64845407009125, 64.77043524384499, 64.4680018723011, 63.97366359829903, 62.438694164156914, 59.85692650079727, 65.04589766263962, 66.82713568210602, 73.65647882223129, 71.43627315759659, 75.84709167480469, 75.39223328232765, 65.56208476424217, 0.0494060213532066, 8.124391548335552, 71.96189895272255, 61.89563870429993, 40.118555054068565, 36.984213441610336, 40.28332561254501, 13.78059608861804, 10.813615545630455, 8.738019671291113, 1.1653252691030502, 0.23012785299215466, 0.05676775523170363, 0.06323027701000683, 0.1701502237119712, 0.04466632490220945, 0.06559973189723678, 0.06404096944606863, 0.11976414811215363, 0.07765926056890748, 0.03770096467633266, 0.04367713110696059, 0.04825333242479246, 0.07015081151621416, 0.41062995325773954, 43.562036678195, 66.28673627972603, 55.40332227945328, 30.813302770256996, 45.31817704439163, 61.22496709227562, 54.09565284848213, 63.946077078580856, 68.53106305003166, 87.50766277313232, 18.124569542706013, 1.1609100247733295, 1.3227368099614978, 8.83419631049037, 69.2582680284977, 67.20797404646873, 81.68762147426605, 79.18990910053253, 81.7390251159668, 77.53113090991974, 77.79986009001732, 74.4213093817234, 81.50352895259857, 74.84399110078812, 73.98938655853271, 71.30046084523201, 73.65688920021057, 72.55712181329727, 65.4192428290844, 54.745877757668495, 56.57483361661434, 54.84711952507496, 56.187349408864975, 51.42400860786438, 54.87415887415409, 52.50869460403919, 55.37703529000282, 48.198456689715385, 47.455269768834114, 46.700216084718704, 46.90630562603474, 48.012186884880066, 50.59556186199188, 50.592810809612274, 51.680711433291435, 51.00299879908562, 59.07998979091644, 57.925144359469414, 58.480123579502106, 56.112326234579086, 54.68644514679909, 57.08826586604118, 55.91732069849968, 56.56430058181286, 59.182835072278976, 59.110475555062294, 55.29616802930832, 56.451841816306114, 58.60647439956665, 55.378323420882225, 53.33138845860958, 52.286934703588486, 52.464191392064095, 50.00664286315441, 70.17872303724289, 82.12511479854584, 49.695633351802826, 48.19999560713768, 47.5850024074316, 42.31018245220184, 46.536798253655434, 45.01941807568073, 44.462041184306145, 48.40107701718807, 48.51450093090534, 44.92073357105255, 46.97520732879639, 43.41506816446781, 41.42069958150387, 40.501110926270485, 43.09755340218544, 42.3677683621645, 39.26619619131088, 43.17202180624008, 41.90322808921337, 42.77167148888111, 42.86512367427349, 47.36449643969536, 49.96883109211922, 49.887724444270134, 44.92555931210518, 42.00193539261818, 46.82572714984417, 45.13767912983894, 44.86206091940403, 50.48802003264427, 28.47488734871149, 54.35803256928921, 73.07634115219116, 49.30405296385288, 51.78625836968422, 45.61144530773163, 47.49001890420914, 46.875580474734306, 52.243484035134315, 48.78908559679985, 48.729869574308395, 49.21277046203613, 54.32095795869827, 52.34874598681927, 54.13008280098438, 52.28738687932491, 51.93240612745285, 54.67816919088364, 53.56557369232178, 52.44062885642052, 55.53174778819084, 49.89173702895641, 45.971145406365395, 48.08762803673744, 44.65027928352356, 45.608268678188324, 51.33554555475712, 52.37166255712509, 54.05829705297947, 50.71637637913227, 49.29579980671406, 49.854461029171944, 51.72786310315132, 51.50473527610302, 51.22048772871494, 57.16074697673321, 68.85864347219467, 66.6961795091629, 70.23148700594902, 68.52006644010544, 72.14920610189438, 69.8100820183754, 71.73757418990135, 67.81578943133354, 71.74952074885368, 66.0464295744896, 66.19423404335976, 63.18019017577171, 70.74875324964523, 70.18717378377914, 79.2463892698288, 76.06886297464371, 82.05354943871498, 80.00359743833542, 72.08693504333496, 0.12641745008295402, 9.538520816713572, 81.02907121181488, 73.8190720975399, 46.816531643271446, 48.227988705039024, 52.115704491734505, 20.233209393918514, 25.87349183857441, 19.80121247470379, 2.2878949949517846, 0.23841105226892978, 0.0163734178931918, 0.04221990930091124, 0.07758522391668521, 0.06853229875559919, 0.06489404593594372, 0.05981041227641981, 0.12970560957910493, 0.23075670440448448, 0.22725946706486866, 0.17528604890685529, 0.22145049908431247, 0.19640118931420147, 0.23750465246848762, 50.70266671478748, 83.40731799602509, 64.6272361278534, 52.83309079706669, 51.75617158412933, 68.03683117032051, 61.87866121530533, 69.52889710664749, 73.32018926739693, 94.9870978295803, 19.38335459679365, 3.50104212295264, 2.761140838265419, 11.176821906119585, 72.92800471186638, 67.16278687119484, 81.77465200424194, 77.59796172380447, 83.34520652890205, 78.10996145009995, 79.8420225083828, 76.97745501995087, 83.0442626774311, 76.23749792575836, 79.91550296545029, 74.57764819264412, 77.23039224743843, 76.01736813783646, 67.26066201925278, 57.33999855816364, 56.93690478801727, 57.64078661799431, 58.844406232237816, 53.59752997756004, 58.97872902452946, 55.32400533556938, 58.188249841332436, 52.39424854516983, 50.381561145186424, 49.792756140232086, 49.77333538234234, 52.52661444246769, 52.70309217274189, 54.48824018239975, 55.25883503258228, 53.721863105893135, 62.913744673132896, 63.24544407427311, 63.325403183698654, 57.44493752717972, 58.43907058238983, 59.02948670089245, 59.84469495713711, 59.08356159925461, 60.51744885742664, 61.967428252100945, 55.95042072236538, 59.5335828512907, 61.59580819308758, 58.64690043032169, 55.9867087751627, 55.61747878789902, 53.13166357576847, 54.84821006655693, 70.3024671971798, 79.25281092524529, 51.40555299818516, 45.97752906382084, 46.98436863720417, 43.83139282464981, 47.52918720245361, 46.70770928263664, 50.30601739883423, 50.82303665578365, 51.450629979372025, 48.320171758532524, 49.30395416915417, 47.41269685328007, 44.23223711550236, 43.602215722203255, 47.19499133527279, 46.35551378130913, 43.535122722387314, 48.16506028175354, 45.43948173522949, 44.554395228624344, 45.98950982093811, 49.90356579422951, 54.814479276537895, 53.8016702234745, 48.6887139827013, 44.164429754018784, 48.10527428984642, 47.861502170562744, 47.675034776329994, 56.60211995244026, 30.766242295503616, 52.302764654159546, 65.84173455834389, 54.71701070666313, 54.086651131510735, 48.49341966211796, 48.569255992770195, 49.465327709913254, 54.06095691025257, 53.62380936741829, 50.7333804666996, 52.49389059841633, 57.1967538446188, 55.31237795948982, 57.57715903222561, 54.929814487695694, 56.03765644133091, 60.56285262107849, 55.88810786604881, 56.73942178487778, 58.593091517686844, 50.1459813863039, 49.60353769361973, 49.6554809063673, 46.037079468369484, 47.88784235715866, 55.4976674169302, 55.738027319312096, 56.29916600883007, 53.239851370453835, 50.738282203674316, 52.50932916998863, 53.98923195898533, 53.92568416893482, 53.96678276360035, 57.93449565768242, 71.40804827213287, 69.19194638729095, 73.21390137076378, 68.55317026376724, 75.72869762778282, 72.02682986855507, 74.05232638120651, 68.4417374432087, 72.54721194505692, 67.60123774409294, 70.00587031245232, 64.18338194489479, 74.05260756611824, 71.54174789786339, 80.88722482323647, 76.32635995745659, 83.89170840382576, 77.66079515218735, 78.48806396126747, 0.4510766454041004, 10.206244736909866, 90.25819838047028, 77.98305585980415, 54.63164068758488, 58.19567084312439, 66.6507263481617, 30.611337907612324, 51.32244385778904, 38.05511757731438, 4.045334653928876, 0.25686407927423716, 0.16367286269087344, 0.1154976747056935, 0.3006179298972711, 0.10969578681397252, 0.13229245436377823, 0.17612884665140882], [0.08367128757527098, 0.01739895094942767, 0.10921898661763407, 0.023730266584607307, 0.04152515888563357, 0.09927393315592781, 0.2286602114327252, 15.745911430567503, 44.85136069357395, 52.52770118415356, 35.957797318696976, 22.862275019288063, 49.472695514559746, 52.529680877923965, 51.8092243373394, 59.35561940073967, 86.63550317287445, 22.85395346581936, 0.3834521194221452, 1.3570248638279736, 7.292186329141259, 60.26456102728844, 57.37611182034016, 74.75998520851135, 71.37422248721123, 73.5639613866806, 74.3210631608963, 76.17653399705887, 74.56497207283974, 70.2024033665657, 69.48995679616928, 69.81681525707245, 69.1778339445591, 69.99997302889824, 63.68027754127979, 56.143332570791245, 51.99419841170311, 50.55086866021156, 48.28690454363823, 49.141984060406685, 49.386101961135864, 51.165626272559166, 47.89517596364021, 50.93131184577942, 43.07391867041588, 42.9270451515913, 42.07886226475239, 44.43931460380554, 48.209517896175385, 48.942414969205856, 47.39286191761494, 48.811470195651054, 48.86601246893406, 54.595656618475914, 56.45091086626053, 56.48736611008644, 53.37723679840565, 54.950405582785606, 51.951944679021835, 52.49322563409805, 53.091131150722504, 55.933633223176, 53.063366040587425, 54.45436879992485, 54.55535218119621, 53.41607451438904, 51.511187329888344, 52.82748989760876, 49.982145577669144, 48.345976173877716, 59.00347329676151, 59.77533347904682, 52.113637402653694, 40.88517151772976, 51.3120324164629, 42.605255618691444, 40.91226026415825, 44.780027121305466, 40.394709035754204, 45.51567144691944, 43.33431489765644, 44.93812523782253, 43.448445573449135, 43.658262714743614, 41.92025497555733, 39.45127286016941, 37.34216183423996, 40.827353820204735, 39.4781868159771, 39.201645255088806, 39.924951642751694, 38.34610976278782, 39.521952867507935, 40.540522411465645, 39.71599705517292, 44.29488055408001, 46.704126074910164, 44.99999351799488, 42.24616348743439, 42.90575869381428, 40.6610481441021, 42.50036984682083, 39.18596729636192, 37.03001618385315, 26.132601834833622, 62.84101277589798, 63.934662491083145, 44.55063343048096, 45.68798080086708, 43.26994255185127, 44.096044823527336, 47.45098739862442, 49.3474580347538, 50.59585064649582, 49.46763798594475, 52.96238265931606, 52.210725992918015, 50.55251397192478, 49.66676250100136, 51.076950430870056, 48.57815511524677, 50.644374042749405, 49.31911535561085, 52.28389486670494, 45.7874708622694, 42.85809405148029, 43.20760689675808, 43.85054759681225, 44.11931097507477, 47.47215986251831, 45.762734189629555, 44.435381814837456, 48.14793460071087, 44.53891485929489, 46.1007184535265, 49.585055485367775, 50.02353295683861, 51.370142698287964, 54.2219390720129, 63.74255619943142, 63.784365355968475, 65.5213737487793, 64.1725905239582, 64.13745000958443, 66.73668533563614, 69.0775953233242, 68.52636650204659, 66.85536816716194, 65.30239909887314, 63.590222373604774, 62.53865920007229, 64.01595532894135, 67.50332459807396, 71.27045005559921, 74.34168085455894, 75.0719104707241, 75.74619188904762, 55.088345780968666, 0.26336345239542425, 8.650967292487621, 74.43350672721863, 66.95324331521988, 49.6069423109293, 40.027451142668724, 39.998021721839905, 23.57372034341097, 15.823865197598934, 10.011589732021093, 0.31783246085979044, 0.1716908926027827, 0.0671990452974569, 0.06604243040783331, 0.03502417901472654, 0.025087120338866953, 0.03566138700989541, 0.053350981543189846, 0.086398732237285, 0.02251527621410787, 0.2730427501956001, 0.06698404511553235, 0.04435906834260095, 0.1961151507566683, 0.26902010198682547, 23.686063215136528, 58.76307159662247, 59.318313002586365, 35.470538064837456, 28.786001354455948, 65.88581219315529, 63.09387780725956, 60.53999304771423, 64.89848837256432, 96.73806667327881, 26.9311460852623, 0.4583760834066197, 1.5658281720243394, 8.290378041565418, 68.95214885473251, 64.19200748205185, 82.61143550276756, 75.64813435077667, 79.31101620197296, 79.014001339674, 80.57277649641037, 76.41680270433426, 74.82223346829414, 71.65142521262169, 74.3663339316845, 70.4575064778328, 73.36742833256721, 66.51882782578468, 61.18026249110699, 53.57943914830685, 54.07130375504494, 52.512023225426674, 54.5082651078701, 52.07963302731514, 53.60640250146389, 50.867243483662605, 51.163027212023735, 47.2636004537344, 46.10005348920822, 45.949296578764915, 49.17078651487827, 51.35753497481346, 51.53895623981953, 51.83326184749603, 50.990581065416336, 51.37193240225315, 56.88390523195267, 58.832854852080345, 58.81187617778778, 55.5694455653429, 54.89870175719261, 54.303406700491905, 55.07832191884518, 56.495189890265465, 58.1646379083395, 56.71187326312065, 55.84866978228092, 57.509378269314766, 57.508253529667854, 56.15607708692551, 56.66463419795036, 53.696419671177864, 53.73957395553589, 63.07589717209339, 57.55247935652733, 57.73254409432411, 43.14525604248047, 51.49903938174248, 47.21210181713104, 42.24408119916916, 45.49963250756264, 44.093445762991905, 46.57005026936531, 47.312982603907585, 47.868140414357185, 45.268897488713264, 47.526804730296135, 41.87339968979359, 41.77382603287697, 40.22069737315178, 42.78731144964695, 44.25975523889065, 42.601273432374, 41.48172810673714, 41.39865316450596, 41.925004720687866, 42.098780795931816, 44.0161807090044, 47.24884204566479, 49.502432718873024, 48.308681175112724, 43.60929474234581, 46.12702824175358, 42.81219631433487, 43.997584506869316, 42.39918887615204, 38.79583083093166, 29.865909107029438, 66.46556988358498, 67.42564156651497, 47.34145827591419, 46.03489078581333, 48.97412806749344, 44.277648478746414, 49.3959092348814, 51.40554539859295, 54.10388320684433, 54.170413836836815, 56.94587990641594, 53.551525846123695, 50.667864382267, 51.06181204319, 54.095930233597755, 50.28399758040905, 53.261563405394554, 51.00331798195839, 53.58190141618252, 47.95882634818554, 45.63612878322601, 46.47002823650837, 46.2525887042284, 46.59632965922356, 50.49723833799362, 47.494742050766945, 48.235896080732346, 48.918951228260994, 46.32829204201698, 47.25951187312603, 52.94132798910141, 52.72611513733864, 53.33976700901985, 55.56201696395874, 68.2126173377037, 66.78834736347198, 68.92585426568985, 67.01900258660316, 69.92535263299942, 71.22923746705055, 73.53075116872787, 71.57680481672287, 71.04250028729439, 68.42843815684319, 69.27866533398628, 65.72308972477913, 68.6784115433693, 71.09966441988945, 76.94542273879051, 76.64882585406303, 83.42137724161148, 76.3060462474823, 60.06444476544857, 0.15333654155256227, 10.48723965883255, 80.08853048086166, 76.48394510149956, 58.49796362221241, 49.77761395275593, 52.1804416179657, 31.193764954805374, 32.18880996108055, 17.04894796013832, 1.0652151284739375, 0.12122200074372813, 0.024888742409530096, 0.0796768929285463, 0.03974068706156686, 0.0433984880510252, 0.021369314854382537, 0.05540622594708111, 0.20725683571072295, 0.11256011319346726, 0.31341709778644145, 0.16952762118307874, 0.13469435594743118, 0.34608830872457474, 0.325264951097779, 27.96618204563856, 75.21321728825569, 70.42865842580795, 51.838494166731834, 32.973821237683296, 65.9614585340023, 69.71030697226524, 68.98919686675072, 71.48191630840302, 102.68401801586151, 28.785138800740242, 1.607345100492239, 7.23706791177392, 11.068725306540728, 69.47451442480087, 62.841316759586334, 81.28018453717232, 74.2169563472271, 79.86751154065132, 80.0688399374485, 81.09041512012482, 77.40492448210716, 76.6242715716362, 72.59546935558319, 78.27515378594398, 75.2862037718296, 76.19467422366142, 67.99493461847305, 62.11136072874069, 56.00028544664383, 53.597180396318436, 55.492723882198334, 56.39473848044872, 57.11643375456333, 55.591871961951256, 53.66752602159977, 56.35588936507702, 49.005312994122505, 50.91849893331528, 49.555325880646706, 50.00164993107319, 57.26828120648861, 51.389172077178955, 52.8683453053236, 51.886181607842445, 53.368463069200516, 58.921530693769455, 60.933792516589165, 62.70973742008209, 59.36440832912922, 58.47026690840721, 58.020253255963326, 55.84617331624031, 59.039670154452324, 59.30326581001282, 58.29794615507126, 57.8592748939991, 60.29276691377163, 59.81863595545292, 56.89429387450218, 59.43923771381378, 57.42694169282913, 59.23873007297516, 64.58495199680328, 57.78925985097885, 61.43818125128746, 46.1375080794096, 48.796574994921684, 51.946963146328926, 45.85475005209446, 49.31254930794239, 46.77338495850563, 49.881139397621155, 51.68468602001667, 49.59228649735451, 47.86899536848068, 51.3926412910223, 47.590303122997284, 44.30317170917988, 41.80072858929634, 46.65961906313896, 48.024817407131195, 47.250453159213066, 44.38557788729668, 43.33990819752216, 46.45955979824066, 45.572417601943016, 45.24435840547085, 49.153911620378494, 53.17344233393669, 50.49342714250088, 46.93032793700695, 49.534996971488, 47.70281508564949, 47.63011738657951, 44.02318373322487, 39.93000537157059, 36.36705815792084, 61.95071294903755, 59.08260025084019, 51.43194258213043, 49.138393253088, 51.58711105585098, 45.50622895359993, 54.669832438230515, 55.90101197361946, 58.59223656356335, 55.458757504820824, 59.80411313474178, 57.66375258564949, 54.965274184942245, 54.08127062022686, 59.18052479624748, 53.518270030617714, 57.76551112532616, 53.581282049417496, 56.05787135660648, 50.227517411112785, 47.43664316833019, 49.15799640119076, 48.02538737654686, 50.298201218247414, 51.36383503675461, 51.009298861026764, 49.672762379050255, 51.34521223604679, 46.73782266676426, 49.12242650985718, 55.4533351957798, 55.11036179959774, 58.37466403841972, 57.492510974407196, 70.02131268382072, 67.82078996300697, 70.38100898265839, 68.18669512867928, 71.65174439549446, 72.2380605340004, 75.68965092301369, 73.24191346764565, 71.35317161679268, 69.20772314071655, 72.9194475710392, 68.26161190867424, 70.85125654935837, 71.90076783299446, 77.96708151698112, 76.48360311985016, 84.2242893576622, 79.17014256119728, 65.52648067474365, 0.318327562417835, 11.087748985737562, 88.25353235006332, 80.33996298909187, 64.67803940176964, 58.72415408492088, 60.47004260122776, 47.097051590681076, 57.57756561040878, 36.22794762253761, 2.1302682906389236, 0.27749180677346885, 0.16058788838563487, 0.1658797130221501, 0.189628973021172, 0.13427386991679668, 0.14098612067755312, 0.22412368532968685], [0.10973524680593982, 0.09752544065122493, 0.06164525366330054, 0.1280200289329514, 0.08646867223433219, 0.1533797790762037, 0.6238280225079507, 7.13555920869112, 40.715962797403336, 57.952054515480995, 33.49774472415447, 30.09805005043745, 44.58873778581619, 55.660541877150536, 52.70442210137844, 59.31914895772934, 84.84695434570312, 33.53134632110596, 0.21166670689126477, 0.22647384437732399, 3.8678537774831057, 55.15775665640831, 60.77686093747616, 68.07647824287415, 68.20461496710777, 76.98054045438766, 74.53624561429024, 72.65403181314468, 68.61971989274025, 71.12435549497604, 69.55824673175812, 69.87066596746445, 67.82271265983582, 67.46262118220329, 59.15540434420109, 53.16245712339878, 50.44811837375164, 50.54526016116142, 47.70503796637058, 51.497743651270866, 49.58587624132633, 50.609499514102936, 47.33817905187607, 46.783249229192734, 44.535487443208694, 42.118193954229355, 41.11910596489906, 45.093586295843124, 47.79040798544884, 51.105152517557144, 48.575103878974915, 52.22851663827896, 47.658501863479614, 54.94274899363518, 56.88742384314537, 55.80067455768585, 54.151232466101646, 56.489007622003555, 55.011905282735825, 57.20032945275307, 55.98984740674496, 57.69973285496235, 57.49276176095009, 58.198874071240425, 57.83758565783501, 52.37197794020176, 51.40472084283829, 55.862204656004906, 50.9409861266613, 62.195039838552475, 54.2007590085268, 49.055914878845215, 55.18268331885338, 52.0107427239418, 49.66262072324753, 39.92553301155567, 40.172956734895706, 40.48930875957012, 41.839045733213425, 42.238666489720345, 46.194410026073456, 43.42475764453411, 45.14573849737644, 42.32032410800457, 42.05813057720661, 39.52907748520374, 38.07435594499111, 41.95312321186066, 38.41125726699829, 41.98752276599407, 39.551838263869286, 39.04682256281376, 37.39170357584953, 41.22288979589939, 42.20404654741287, 47.426303923130035, 45.141444727778435, 43.82731184363365, 41.1147627979517, 43.349677473306656, 39.904896318912506, 42.95849986374378, 40.23450203239918, 42.52270504832268, 31.3200568780303, 36.789067313075066, 73.96928563714027, 52.80080772936344, 46.863599717617035, 47.33618415892124, 44.044891968369484, 44.84260976314545, 49.10224199295044, 54.656533151865005, 54.48140434920788, 52.950447499752045, 49.74945366382599, 52.600915655493736, 50.446750447154045, 51.2149628251791, 50.122703835368156, 48.60386833548546, 51.43421106040478, 48.83289724588394, 44.941959232091904, 45.771618112921715, 43.88210490345955, 43.423294723033905, 44.04261589050293, 42.91327469050884, 42.6187676936388, 43.79550375044346, 43.12528811395168, 44.19733218848705, 48.37052285671234, 48.2897961884737, 49.943687841296196, 50.720160976052284, 53.093327432870865, 61.52735486626625, 61.742818504571915, 62.13551603257656, 62.32537284493446, 62.74785317480564, 61.8481108546257, 64.27263155579567, 67.51185894012451, 68.24438363313675, 66.19218975305557, 62.98061728477478, 61.69151745736599, 64.29759621620178, 65.24753764271736, 71.86356022953987, 75.74880614876747, 72.58793815970421, 68.82536485791206, 50.40260821580887, 0.14663200912764296, 7.704808562994003, 74.49452385306358, 64.14159178733826, 52.91427344083786, 40.34363217651844, 47.35311985015869, 20.245995707809925, 18.91191579401493, 5.022608013823628, 0.11752760445233434, 0.10870124213397503, 0.04986961132090073, 0.1393342186929658, 0.1827794694690965, 0.002096359385177493, 0.07019121403573081, 0.05874878115719184, 0.07960751696373336, 0.04310923228331376, 0.14872152591124177, 0.037401715890155174, 0.1329495370737277, 0.31864775461144745, 0.4165818588808179, 10.794796105474234, 57.994080260396004, 65.45633643865585, 30.18061961978674, 27.75510337203741, 55.324959084391594, 66.49236604571342, 59.66805003583431, 67.93011769652367, 89.8478052020073, 37.145947962999344, 0.2071576105663553, 0.7656725705601275, 3.8967129914090037, 65.63286736607552, 64.71720770001411, 75.20974427461624, 71.73073455691338, 82.37614452838898, 78.07817235589027, 78.56601297855377, 73.20754811167717, 77.52233058214188, 72.79852285981178, 74.22340840101242, 69.74243804812431, 72.29756534099579, 62.03511781990528, 56.81275025010109, 53.859476521611214, 54.39707547426224, 50.74897862970829, 55.24841599166393, 51.967919021844864, 51.72454208135605, 48.74903954565525, 51.54311701655388, 48.00447329878807, 44.53811690211296, 42.57982738316059, 47.77281492948532, 48.44211481511593, 53.51679190993309, 52.0741955190897, 54.39059302210808, 48.3714310079813, 57.360897436738014, 60.185316279530525, 58.07430915534496, 55.87084539234638, 58.61865654587746, 58.317769691348076, 61.28822609782219, 59.059839472174644, 58.27126398682594, 60.4820803552866, 59.83109548687935, 58.15320052206516, 57.0944519340992, 52.99758777022362, 56.88947953283787, 56.16309151053429, 64.74904999136925, 53.28712843358517, 51.24375008046627, 51.8120513856411, 59.038951992988586, 52.46506914496422, 44.00551088154316, 40.886539444327354, 43.56110192835331, 43.729797676205635, 45.524661764502525, 48.23419377207756, 49.78275887668133, 45.340998619794846, 45.6908268481493, 44.29162032902241, 45.06623916327953, 40.8050300180912, 44.56029251217842, 42.04309098422527, 45.73194444179535, 42.113854587078094, 40.38718543946743, 39.52810853719711, 43.62443692982197, 44.81790728867054, 49.389445781707764, 46.0418976098299, 48.15034367144108, 43.335124254226685, 45.299048870801926, 42.54516564309597, 43.75898391008377, 41.67704522609711, 43.15868832170963, 34.752938970923424, 38.7247746437788, 68.5688254237175, 57.02691815793514, 49.864013716578484, 50.35481438040733, 47.07807540893555, 47.13610589504242, 51.26260466873646, 57.82863713800907, 55.69913640618324, 54.21344272792339, 52.523076832294464, 54.53129567205906, 51.295685693621635, 55.02514757215977, 52.992397248744965, 52.21024341881275, 52.67681658267975, 50.55692173540592, 47.1905417740345, 47.207447066903114, 46.55026473104954, 46.963937133550644, 46.20622739195824, 45.83565607666969, 45.12634053826332, 48.056716695427895, 44.08317111432552, 48.008010908961296, 49.17343117296696, 51.85378834605217, 51.87788665294647, 52.74620085954666, 55.01943647861481, 63.67560759186745, 63.89481782913208, 67.78488948941231, 65.15808284282684, 66.62484213709831, 64.7117967903614, 69.82699111104012, 70.81837311387062, 72.07775473594666, 70.08413851261139, 69.11062315106392, 64.85325559973717, 69.55107271671295, 66.6038216650486, 76.91064700484276, 77.9668003320694, 79.9547928571701, 71.91456109285355, 60.50593927502632, 0.11260663843131624, 9.61052030324936, 81.17618411779404, 74.21135544776917, 56.64890684187412, 50.980709195137024, 55.013201013207436, 28.617537394165993, 40.94748057425022, 8.58014004305005, 0.5322630889713764, 0.10638458363246173, 0.07310068525839597, 0.11157537970575504, 0.10285509255481884, 0.04241687900503166, 0.08797513553872705, 0.023919130180729553, 0.3233787085628137, 0.20292808127123863, 0.2978718053782359, 0.19059971702517942, 0.24126550066284835, 0.42825566371902823, 0.6702940666582435, 12.42295553907752, 73.62154349684715, 76.66822761297226, 47.57812477648258, 42.89618320763111, 55.961136147379875, 75.7631465792656, 66.80606201291084, 73.95113781094551, 94.96195077896118, 40.861320197582245, 0.8037388685625046, 3.3253236394375563, 5.669969776645303, 67.06694841384888, 64.21004891395569, 77.79162973165512, 72.45265781879425, 80.58812767267227, 79.07804310321808, 78.62485662102699, 74.42706987261772, 77.77675732970238, 74.27554160356522, 76.3045947253704, 70.8075512945652, 74.78716135025024, 64.81783390045166, 59.251083210110664, 55.446890741586685, 57.18907065689564, 53.23823645710945, 59.253811463713646, 55.3187046200037, 55.641770884394646, 51.13865911960602, 52.931934893131256, 50.76155215501785, 47.25842893123627, 45.3435292840004, 49.77035254240036, 51.1943831294775, 54.73444037139416, 52.007056921720505, 58.39754641056061, 50.30532203614712, 59.55255143344402, 64.52537879347801, 60.55098965764046, 59.01669658720493, 62.72098861634731, 58.8917250931263, 63.48937578499317, 60.4047355055809, 64.39249232411385, 61.919733211398125, 61.37347832322121, 62.97167256474495, 57.547965198755264, 55.75625494122505, 60.64884580671787, 56.528023928403854, 65.67863211035728, 54.096409007906914, 57.091054916381836, 60.10353326797485, 54.66288261115551, 56.515135020017624, 46.20850346982479, 43.707082495093346, 47.06555888056755, 47.28048674762249, 47.551963180303574, 52.09730587899685, 50.15418894588947, 49.72212553024292, 48.8091941177845, 48.994722962379456, 45.88150441646576, 43.37857112288475, 47.43815928697586, 43.84841211140156, 47.168841138482094, 44.64970551431179, 44.38643664121628, 42.73765191435814, 47.2430245578289, 47.46797248721123, 51.57851591706276, 50.01005508005619, 52.44230456650257, 45.914866626262665, 46.57378546893597, 45.30500315129757, 46.18288904428482, 46.182797849178314, 43.36923882365227, 36.616833955049515, 46.37133613228798, 67.9011632502079, 56.89655475318432, 51.82470850646496, 53.688820078969, 48.4513521194458, 50.503063425421715, 53.28386440873146, 61.52545876801014, 58.958274722099304, 58.50099205970764, 54.1771736741066, 55.967345014214516, 56.2977334856987, 55.83063594996929, 55.114807561039925, 53.430829122662544, 57.520371079444885, 54.081206023693085, 49.667488262057304, 50.301533639431, 49.83635500073433, 49.599977284669876, 48.45321781933308, 48.697103932499886, 48.47586080431938, 50.140813663601875, 46.93348936736584, 50.24863287806511, 53.55815269052982, 54.16453555226326, 54.09812271595001, 55.769960805773735, 58.264466151595116, 67.8245897591114, 65.73561385273933, 68.00281539559364, 65.92585444450378, 68.28552782535553, 65.72221577167511, 70.11272817850113, 71.50129526853561, 74.5803764462471, 71.57690361142159, 68.95990043878555, 67.32635289430618, 73.39008271694183, 69.70573201775551, 80.55850446224213, 79.54680874943733, 79.43621188402176, 74.06630203127861, 64.90652114152908, 0.1905274169985205, 10.690397657454014, 90.85631668567657, 79.20764654874802, 65.83861872553825, 62.13955141603947, 65.77289745211601, 39.45374272763729, 59.90288123488426, 20.256116464734077, 0.9112980344798416, 0.15140088682528585, 0.20972104801330715, 0.19826890784315765, 0.2928360959049314, 0.12955620040884241, 0.17498268862254918, 0.09834816330112517], [0.08216424539568834, 0.07496194710256532, 0.04278650194464717, 0.12881451286375523, 0.09342387245851569, 0.07164832451962866, 0.3476885275449604, 1.324864577036351, 18.539007604122162, 45.53470082581043, 45.234433338046074, 29.444188736379147, 42.01008215546608, 60.41791319847107, 50.69972187280655, 51.78156182169914, 81.7949429154396, 37.35863395035267, 0.0749488481960725, 0.13319811201654375, 1.6698725265450776, 51.229063868522644, 59.12602812051773, 73.33737194538116, 69.30505111813545, 71.43175140023232, 68.96113157272339, 72.61346518993378, 70.45904159545898, 72.03362390398979, 66.69272929430008, 68.52829679846764, 67.64735966920853, 64.47934806346893, 52.876640260219574, 50.91384798288345, 50.18607683479786, 50.29986932873726, 49.38340410590172, 47.401419058442116, 48.10920707881451, 49.28474240005016, 46.57970555126667, 48.56901280581951, 44.93614174425602, 40.489217564463615, 42.10856147110462, 46.128586158156395, 47.74885721504688, 50.83400286734104, 51.932573318481445, 50.247428342700005, 48.22035111486912, 52.42189586162567, 55.494456589221954, 53.125055730342865, 52.50062383711338, 56.01713754236698, 57.94074632227421, 60.30315935611725, 56.891972199082375, 55.87404102087021, 56.44472859799862, 57.41909511387348, 59.39034953713417, 56.52531087398529, 51.49327129125595, 53.43025155365467, 56.449527740478516, 53.515021204948425, 52.70620800554752, 45.24015583097935, 37.222061678767204, 74.61344987154007, 45.66813446581364, 41.50741092860699, 38.514129146933556, 40.160067826509476, 41.04876793920994, 43.6629668623209, 48.21430183947086, 47.08331152796745, 42.710525169968605, 45.64308241009712, 41.71600453555584, 41.15682654082775, 40.9345992654562, 39.52917627990246, 40.666474252939224, 41.874547228217125, 39.299512803554535, 38.47637057304382, 37.33542859554291, 40.49885764718056, 42.718234956264496, 43.91612067818642, 44.31136026978493, 44.922572672367096, 44.10158112645149, 42.727787643671036, 43.351949751377106, 41.125649213790894, 39.642717987298965, 39.6960823237896, 42.80211165547371, 41.48754559457302, 55.929476246237755, 49.1728688031435, 47.11071565747261, 49.75774481892586, 45.27642488479614, 46.29577338695526, 48.054246827960014, 53.325483575463295, 54.23649609088898, 55.97912438213825, 53.69597129523754, 54.98980566859245, 56.81900091469288, 57.12885148823261, 58.5850777477026, 53.00720125436783, 51.5481099486351, 45.73876887559891, 47.053167745471, 44.58032123744488, 45.580948144197464, 42.29896165430546, 44.9580779671669, 42.53003105521202, 43.58519643545151, 39.94362764060497, 42.47032105922699, 45.27606390416622, 46.69195532798767, 46.87187947332859, 47.60987587273121, 48.65242972970009, 50.28357580304146, 59.52942967414856, 62.1311766654253, 60.69580368697643, 60.07569596171379, 60.0396890938282, 60.05843348801136, 63.54484520852566, 65.90155094861984, 66.57120421528816, 67.62579962611198, 64.37380492687225, 63.25453318655491, 64.06611263751984, 65.38306877017021, 69.79002669453621, 73.4680849313736, 76.14717677235603, 64.59996119141579, 52.14484512805939, 0.02066461409413023, 5.3975182212889194, 72.04319939017296, 64.53663378953934, 58.792516216635704, 39.988666623830795, 44.50915105640888, 25.60935851186514, 36.48258715867996, 2.7695725858211517, 0.17281775479204953, 0.14554620254784822, 0.01924916035932256, 0.12044668648741208, 0.027326558374625165, 0.03435324782913085, 0.10147928434889764, 0.06642856984399259, 0.016347789678547997, 0.0920513816527091, 0.13551021373132244, 0.09697609551949427, 0.0714238990622107, 0.19150742300553247, 0.5779253575019538, 2.2175317956134677, 28.947420492768288, 62.76832267642021, 43.97993825376034, 16.503373235464096, 48.677705973386765, 71.77068561315536, 57.31151908636093, 62.78471879661083, 85.06992638111115, 42.13897883892059, 0.07298416065168567, 0.8237741247285157, 2.7635608334094286, 59.95886743068695, 64.21163722872734, 78.63521486520767, 73.01468566060066, 77.18275800347328, 69.6382400393486, 77.31469452381134, 73.34226608276367, 78.32260563969612, 71.52757465839386, 71.97942361235619, 69.63767006993294, 68.29900190234184, 55.030866265296936, 54.6735904365778, 52.99596145749092, 53.72235327959061, 52.5215645134449, 51.35560467839241, 50.76692506670952, 52.795313224196434, 50.25958389043808, 52.25399427115917, 47.87044309079647, 45.471931993961334, 44.35570389032364, 50.78152008354664, 50.96278175711632, 53.658509105443954, 53.84073592722416, 51.221483275294304, 50.58322012424469, 53.021579682826996, 55.86221985518932, 55.437877625226974, 55.45054614543915, 59.35123823583126, 59.022692665457726, 61.44651040434837, 59.95061047375202, 59.69440162181854, 59.54247437417507, 60.660416185855865, 58.97171460092068, 60.01930698752403, 53.60899396240711, 56.51715651154518, 57.62416251003742, 55.315372198820114, 54.84653055667877, 46.71980023384094, 41.34004130959511, 67.07376524806023, 50.625473856925964, 42.87923611700535, 41.90982833504677, 41.349385008215904, 43.63195672631264, 45.89922286570072, 52.47516520321369, 48.23788717389107, 44.599339216947556, 46.80546663701534, 44.24379609525204, 43.8081456720829, 42.423059195280075, 42.39299140870571, 45.05510576069355, 43.63306246697903, 40.698992908000946, 40.93047648668289, 40.937133729457855, 43.29959996044636, 45.42250044643879, 48.01942929625511, 46.679412201046944, 47.12750695645809, 46.529012471437454, 45.68932592868805, 44.42549854516983, 42.20284961163998, 41.58146135509014, 40.451519787311554, 44.949866607785225, 43.44883315265179, 62.84772701561451, 51.36933334171772, 48.92450653016567, 51.72502465546131, 47.84507945179939, 48.028864189982414, 51.283457949757576, 59.57219637930393, 57.685563415288925, 57.65472427010536, 58.66358533501625, 59.347974210977554, 58.29913169145584, 60.232977122068405, 59.084287360310555, 55.95276899635792, 52.92096108198166, 48.46221573650837, 46.80458888411522, 49.41640913486481, 49.029297307133675, 46.8237816542387, 46.64716333150864, 47.59528465569019, 44.84262116253376, 43.21874029934406, 45.85180900990963, 49.76833485066891, 48.492842093110085, 50.33388890326023, 50.3792280703783, 51.32774077355862, 52.47202277183533, 61.865316331386566, 64.52566757798195, 64.36548337340355, 61.99578993022442, 62.887632474303246, 63.4188249707222, 67.3418940603733, 68.15520241856575, 69.85052704811096, 69.36192646622658, 69.17927786707878, 65.82887604832649, 69.7461086511612, 67.70519256591797, 75.43023884296417, 75.8386181294918, 80.84738776087761, 69.78507936000824, 64.8332990705967, 0.14531808119500056, 6.327185835689306, 75.3418555855751, 75.1579986512661, 60.94910569489002, 54.04027841985226, 53.53127293288708, 35.68779520690441, 60.23034006357193, 5.494788251817226, 0.2999830967746675, 0.0449163173470879, 0.09348898849566467, 0.06365542372805066, 0.06523675489006564, 0.04431991263118107, 0.08310075412737206, 0.04714083821454551, 0.19131749257212505, 0.1930985282524489, 0.2550568012520671, 0.3664619248593226, 0.2103969664312899, 0.25563276722095907, 0.6586443074047565, 1.7719927593134344, 42.88700670003891, 78.60722556710243, 58.45171630382538, 43.31569589674473, 53.829112350940704, 80.62601163983345, 63.97824615240097, 65.68706765770912, 91.50696337223053, 45.6759050488472, 0.8364695403724909, 2.513178731314838, 3.88568835798651, 66.63017705082893, 63.12385819852352, 76.0637940466404, 73.42571720480919, 79.58856090903282, 71.63178026676178, 80.03695204854012, 75.26560127735138, 79.470204859972, 74.54274326562881, 74.38094034790993, 71.87141820788383, 68.97490203380585, 58.64935129880905, 54.847442507743835, 55.97761586308479, 56.56662605702877, 55.01400277018547, 52.96759977936745, 52.4754273891449, 56.17266699671745, 52.14601166546345, 54.651293233036995, 51.32141791284084, 45.99346540868282, 46.03051722049713, 51.2822762131691, 53.24980303645134, 56.06502257287502, 56.078504249453545, 52.482498809695244, 51.17076359689236, 55.78637972474098, 58.54696959257126, 58.55127856135368, 57.69573166966438, 62.3589326441288, 60.92169016599655, 65.16777232289314, 63.1971600651741, 63.20171222090721, 61.01600110530853, 62.80754417181015, 62.210562005639076, 63.21277342736721, 54.16074335575104, 63.394973650574684, 59.864089116454124, 59.18375842273235, 53.94658304750919, 50.48539437353611, 47.41514392197132, 71.62681773304939, 59.123923033475876, 49.27712760865688, 43.497443944215775, 44.46129262447357, 46.29773788154125, 49.70366612076759, 55.7996866106987, 50.18454931676388, 48.30759063363075, 49.08336080610752, 48.49347285926342, 45.537394881248474, 46.8590247631073, 45.487590953707695, 49.10017490386963, 46.509565114974976, 44.23043221235275, 43.10183197259903, 44.50527526438236, 46.29871442914009, 48.561409413814545, 50.102542117238045, 48.92320320010185, 50.12063294649124, 50.08659817278385, 49.370838180184364, 49.2593901604414, 45.02689227461815, 45.38036830723286, 43.49378854036331, 45.196359381079674, 45.64871370792389, 66.31734743714333, 56.13422445952892, 54.36490260064602, 54.12136986851692, 51.016237288713455, 48.045233711600304, 56.32878161966801, 61.038161516189575, 59.841305539011955, 59.67344954609871, 61.44134648144245, 61.94049149751663, 61.391485556960106, 61.431763395667076, 64.42397743463516, 57.97485329210758, 55.08693225681782, 50.05996160209179, 49.2567341029644, 50.70964314043522, 50.42625814676285, 46.80373392999172, 50.181254893541336, 49.10970859229565, 50.33448547124863, 44.506624191999435, 48.5918115824461, 51.85962103307247, 51.9766091555357, 52.31688089668751, 51.82958364486694, 55.18689729273319, 52.86778673529625, 64.53204363584518, 66.7659741640091, 67.14413747191429, 64.2916913330555, 65.43074861168861, 63.10185357928276, 69.51122045516968, 69.33825373649597, 71.05447724461555, 71.0401064157486, 71.37921541929245, 66.53416380286217, 71.48256987333298, 69.57796767354012, 77.61751547455788, 77.90451407432556, 81.20334506034851, 70.10251432657242, 69.67526525259018, 0.4351658304221928, 6.980642946437001, 83.70980456471443, 80.47866314649582, 76.17309138178825, 65.33429458737373, 62.14235566556454, 42.24906653165817, 79.68431577086449, 11.008036863058805, 0.4812652536202222, 0.19990664965007454, 0.2146036078920588, 0.2098778638173826, 0.26706317730713636, 0.11109974468126893, 0.20522355887806043, 0.09448579672607593], [0.0366290844976902, 0.01131796636400395, 0.09428046672837809, 0.05152602927410044, 0.05603876954410225, 0.047207620373228565, 0.153046406339854, 0.19488916732370853, 6.617101728916168, 36.46954245865345, 44.86834958195686, 39.452355802059174, 42.22053386271, 54.30224396288395, 49.15224730968475, 48.50557141005993, 73.78835454583168, 41.06441929936409, 0.020801069076696876, 0.8139447646681219, 7.133891573175788, 50.90801149606705, 67.84572422504425, 71.21653094887733, 69.47725787758827, 65.51281660795212, 71.01711004972458, 70.9144015610218, 69.2500376701355, 70.09521871805191, 68.38500648736954, 67.48510837554932, 63.60045902431011, 56.70764409005642, 50.203867480158806, 51.606440618634224, 50.78147068619728, 50.104084834456444, 49.80384014546871, 47.76470236480236, 47.17362888157368, 48.454821333289146, 47.57664665579796, 48.2779598236084, 46.626838222146034, 40.9972009062767, 42.28710249066353, 46.05567567050457, 47.85971246659756, 49.98195558786392, 51.40171900391579, 47.30256736278534, 47.26477079093456, 52.11523711681366, 54.140083864331245, 51.42549812793732, 53.996679559350014, 57.767756804823875, 56.18981547653675, 60.42974956333637, 55.89619763195515, 55.27552753686905, 55.69187879562378, 56.52166686952114, 57.8298606723547, 55.688306987285614, 53.89048285782337, 52.28398986160755, 50.76779522001743, 49.707800298929214, 52.828903421759605, 53.11906345188618, 46.58276438713074, 47.610894218087196, 45.0230772793293, 39.19750727713108, 40.10834500193596, 40.94598725438118, 41.91790670156479, 41.79318219423294, 50.596337020397186, 44.57076095044613, 43.3112995326519, 42.46943190693855, 41.55406102538109, 40.94846472144127, 37.6469586789608, 39.05581668019295, 40.6232325732708, 42.66916438937187, 39.85814742743969, 39.5616265386343, 41.53329513967037, 41.22097469866276, 45.97812183201313, 44.72656399011612, 41.67803697288036, 43.31861034035683, 42.96847812831402, 39.15871895849705, 40.63835956156254, 40.128571316599846, 39.72490377724171, 38.29072393476963, 42.550941333174706, 52.05019220709801, 64.12937924265862, 59.45662558078766, 47.9416436702013, 52.65381261706352, 48.697875291109085, 47.020732685923576, 51.302760913968086, 53.02581265568733, 54.82785455882549, 56.821972355246544, 56.6772685199976, 59.82841283082962, 56.722577288746834, 55.58593288064003, 52.519288435578346, 50.98605550825596, 51.87758646905422, 47.28551767766476, 45.556466057896614, 48.54305259883404, 47.45140537619591, 42.845756113529205, 43.69982868432999, 41.62789486348629, 41.579029485583305, 41.19765155017376, 44.56566922366619, 45.682934671640396, 47.275680005550385, 47.71248556673527, 47.93825805187225, 47.73754522204399, 48.4188486635685, 52.41512842476368, 55.245467349886894, 57.61079862713814, 56.24915689229965, 56.70750729739666, 57.89756163954735, 59.62718702852726, 64.28599163889885, 66.14688858389854, 67.62535884976387, 66.6079330444336, 63.41349385678768, 64.61409643292427, 61.35793715715408, 69.25393626093864, 71.16720959544182, 75.29248863458633, 68.46005246043205, 53.06281507015228, 0.20543357182759792, 4.816057272255421, 70.608951151371, 62.87223570048809, 49.88406524062157, 48.60550984740257, 32.61201225221157, 25.10154616087675, 48.13139408826828, 3.2917405664920807, 0.34115290793124586, 0.17047920293407515, 0.06644729422987439, 0.0848853743809741, 0.12527844635769725, 0.08991265305667184, 0.05810899419884663, 0.03487053589196876, 0.04890797717962414, 0.08046738410484977, 0.04886068381892983, 0.04064955450303387, 0.013138967624399811, 0.032484494004165754, 0.17916405253345147, 0.34907972789369524, 11.14700585603714, 51.66720695793629, 53.492306023836136, 25.939737483859062, 39.67498205602169, 68.03804710507393, 55.616293251514435, 59.122832491993904, 79.24402579665184, 48.20483274757862, 0.08245596138294786, 1.1713732383213937, 10.617778804153204, 59.61832970380783, 70.14299735426903, 75.19433230161667, 70.84735035896301, 72.02413201332092, 72.1794980764389, 77.20029026269913, 74.16768819093704, 72.27370262145996, 71.56942561268806, 69.55056354403496, 65.79883486032486, 59.73888203501701, 52.9590730369091, 55.18685929477215, 53.25413480401039, 53.29648733139038, 52.560474425554276, 50.448851734399796, 51.12907603383064, 52.07826890051365, 49.232495203614235, 51.64401300251484, 49.76347491145134, 44.04200032353401, 45.41038289666176, 49.55547787249088, 49.423275366425514, 51.01861596107483, 53.142960369586945, 50.43078750371933, 49.17773254215717, 54.05517362058163, 55.0880341976881, 54.30171579122543, 56.84378318488598, 60.14119304716587, 58.67536850273609, 63.823108077049255, 59.21057738363743, 56.708738431334496, 59.472554326057434, 58.08711066842079, 59.43961389362812, 56.712580025196075, 55.42012877762318, 55.058384388685226, 55.99362060427666, 51.584382802248, 51.62525340914726, 54.692676812410355, 50.35449139773846, 50.78275501728058, 46.29215218126774, 42.43278667330742, 43.197491839528084, 42.71595507860184, 44.3437535315752, 45.25746010243893, 51.05102442204952, 48.9643169939518, 46.10274374485016, 45.47486923635006, 44.567823708057404, 42.729303762316704, 39.870466366410255, 42.705577835440636, 42.6522096991539, 46.57661251723766, 42.91267432272434, 42.19238877296448, 44.28001955151558, 46.26747630536556, 51.023878678679466, 47.00405538082123, 46.17391772568226, 46.74927145242691, 44.59398910403252, 41.57664321362972, 42.68906392157078, 44.531372264027596, 41.58449359238148, 41.51955507695675, 45.63660755753517, 50.06894811987877, 55.11665426194668, 66.94518774747849, 55.02975672483444, 56.58281318843365, 50.32126598060131, 49.814331382513046, 51.16350218653679, 58.07444594800472, 57.254917323589325, 57.98616908490658, 59.139452800154686, 61.182846352458, 56.02806195616722, 59.21576030552387, 55.87786741554737, 54.49807405471802, 54.82630044221878, 49.82772186398506, 47.56552465260029, 52.21495136618614, 48.487404584884644, 46.22313268482685, 44.2074890434742, 44.2355315387249, 43.88713963329792, 44.76523071527481, 47.96899080276489, 50.49738273024559, 49.527283385396004, 49.99683178961277, 50.830138474702835, 49.75347004830837, 51.13926328718662, 57.041832357645035, 59.94830399751663, 62.28874661028385, 59.54810947179794, 61.096302196383476, 57.80675411224365, 63.44219371676445, 65.1153427362442, 69.33764576911926, 66.55593663454056, 69.21542152762413, 65.72449564933777, 70.50929009914398, 65.11535033583641, 73.40966686606407, 72.7122750878334, 82.95188963413239, 72.58036136627197, 63.42076286673546, 0.2944539481541142, 5.673411441966891, 77.73015663027763, 69.39132928848267, 53.59160229563713, 58.21174398064613, 42.12031044065952, 28.278160504996777, 63.54731887578964, 3.6909281462430954, 0.3402444894891232, 0.08225449055316858, 0.07203749191830866, 0.02059120641206391, 0.06363331514876336, 0.059812987528857775, 0.029773610367556103, 0.006230647941265488, 0.12127346126362681, 0.10033213184215128, 0.23991180845769122, 0.09243560634786263, 0.2509838651167229, 0.10895309736952186, 0.321362916729413, 0.35743458895012736, 15.678405202925205, 69.08741399645805, 66.27782195806503, 58.943611308932304, 53.94347481429577, 74.26617130637169, 62.42675140500069, 62.13887885212898, 85.5307124555111, 49.50428321957588, 0.3994972334476188, 2.3213488748297095, 14.12320850417018, 64.30144920945168, 70.20635515451431, 77.81472489237785, 72.00774729251862, 72.49097496271133, 73.38484659790993, 77.71433427929878, 74.37438949942589, 75.18909618258476, 71.54965907335281, 70.82746982574463, 68.03081229329109, 61.86888054013252, 55.89248903095722, 56.247374787926674, 56.44955813884735, 56.66190594434738, 54.89922992885113, 53.0867537856102, 53.884011805057526, 53.55596400797367, 52.08463355898857, 51.75798788666725, 53.26498322188854, 46.9008719176054, 45.92897906899452, 50.29449261724949, 53.09762880206108, 54.00666922330856, 57.53900147974491, 51.67395919561386, 50.157019793987274, 55.87899595499039, 60.02877227962017, 54.80224013328552, 58.012851253151894, 61.18702992796898, 60.37678800523281, 65.341726988554, 61.898853331804276, 59.37144175171852, 63.508587554097176, 62.2066406160593, 64.20913696289062, 61.08790844678879, 59.952593967318535, 56.84141971170902, 59.88815322518349, 54.790529161691666, 55.77957049012184, 59.43991407752037, 53.57856139540672, 52.516662776470184, 50.85207849740982, 44.60549108684063, 46.23435728251934, 46.710840314626694, 45.76614260673523, 48.566090762615204, 55.72972856462002, 51.757022738456726, 50.510051250457764, 48.56292173266411, 46.211319118738174, 45.40048062801361, 41.25362254679203, 43.71410831809044, 46.829272359609604, 48.894659131765366, 44.858720898628235, 44.15705434978008, 45.09588897228241, 46.35693870484829, 52.16055728495121, 49.0655891597271, 47.64112539589405, 48.653919249773026, 47.82480373978615, 43.556800559163094, 45.77000319957733, 48.23417477309704, 45.049588456749916, 43.77777010202408, 46.91058799624443, 53.15484993159771, 64.72400173544884, 65.22846266627312, 57.70947553217411, 58.66827428340912, 53.83169241249561, 50.6489983946085, 55.346629321575165, 59.66181457042694, 60.12773796916008, 61.46127641201019, 63.016327768564224, 63.26993376016617, 59.89706754684448, 61.13029137253761, 56.73337630927563, 54.13907311856747, 55.90159334242344, 49.72668908536434, 48.71210552752018, 54.93815504014492, 52.6292659342289, 46.33155606687069, 46.63302429020405, 47.78382673859596, 46.73649653792381, 46.72407120466232, 51.60756915807724, 51.247595474123955, 52.25533179938793, 51.89091235399246, 51.21914640069008, 53.05238462984562, 50.667921379208565, 58.96520934998989, 61.188834831118584, 64.22447293996811, 60.32482959330082, 64.0806582570076, 62.543382346630096, 67.80046105384827, 69.64694917201996, 72.57949501276016, 69.64584723114967, 73.37537750601768, 68.48085254430771, 76.40493974089622, 65.51627442240715, 76.23848587274551, 75.4760491847992, 86.28197014331818, 73.57934296131134, 67.5686126947403, 0.5574216577224433, 6.660522473976016, 84.03483152389526, 76.55152827501297, 64.09464910626411, 69.70330774784088, 46.95613615214825, 37.39252433180809, 85.78688710927963, 6.666618771851063, 0.6153119669761509, 0.23712902184342965, 0.3166658047121018, 0.289252056973055, 0.18923009833088145, 0.1717053644824773, 0.15690600470406935, 0.08108426467515528], [0.05235768738202751, 0.04573626436467748, 0.036360475278343074, 0.11241648535360582, 0.03409760021895636, 0.04614694291376509, 0.10142639890545979, 0.10442899481859058, 0.8748569211456925, 28.620556332170963, 53.41243430972099, 34.65186819434166, 35.02714365720749, 57.56333537399769, 51.51007018983364, 51.66495367884636, 72.63229697942734, 48.51488471031189, 0.46150916372425854, 0.19368760054931045, 6.8257309589535, 47.75981202721596, 61.59973718225956, 66.11907407641411, 69.26536604762077, 75.30514195561409, 71.45229309797287, 71.21612057089806, 71.12117886543274, 70.17913341522217, 69.40674126148224, 63.929851949214935, 60.475388914346695, 52.21256509423256, 49.24997426569462, 49.762965738773346, 50.24223022162914, 49.5235899835825, 49.59884114563465, 48.19616161286831, 48.21686290204525, 48.502797558903694, 47.18900665640831, 48.6856285482645, 48.12064826488495, 44.944052919745445, 42.991816475987434, 43.556390181183815, 46.98675110936165, 49.41817224025726, 53.51642332971096, 49.69428062438965, 45.975655764341354, 51.95916809141636, 48.48627224564552, 51.0721018910408, 53.95665630698204, 57.02720694243908, 57.08060547709465, 58.45102474093437, 57.87532143294811, 54.577854573726654, 55.833820179104805, 54.24189940094948, 55.432964488863945, 55.45055754482746, 53.725111931562424, 52.52639405429363, 53.278362303972244, 51.205140352249146, 44.96717467904091, 46.144457906484604, 34.70763020217419, 46.26560680568218, 44.71074163913727, 41.78417667746544, 40.7059009373188, 41.12952500581741, 41.967828422784805, 45.572717785835266, 46.72476276755333, 50.505970269441605, 47.53524407744408, 48.327205181121826, 46.883674040436745, 40.62636360526085, 39.2643266916275, 41.38463571667671, 45.88312312960625, 48.72698932886124, 40.33612757921219, 38.15524220466614, 39.97266188263893, 44.79676142334938, 47.58395366370678, 49.66414824128151, 52.27649666368961, 48.42938929796219, 43.629236072301865, 42.97610431909561, 44.01353985071182, 40.0884872674942, 41.09476067125797, 42.334219962358475, 40.91552048921585, 43.69507513940334, 30.52860114723444, 58.298440128564835, 61.402820348739624, 53.97698521614075, 52.82045267522335, 50.06534971296787, 51.38202466070652, 57.463731318712234, 54.108165577054024, 57.41179570555687, 55.543876737356186, 56.3231161236763, 57.474477142095566, 55.91881021857262, 56.27594545483589, 56.006095334887505, 54.44105811417103, 51.91382512450218, 44.94322456419468, 46.98541738092899, 47.73376442492008, 44.659767374396324, 44.25237603485584, 40.72463393211365, 40.05841948091984, 42.04604722559452, 44.35407377779484, 45.32120928168297, 46.793523877859116, 46.94968029856682, 48.39540012180805, 47.94450871646404, 49.91682708263397, 48.4675582498312, 50.81379555165768, 54.26968730986118, 54.141155406832695, 50.93559421598911, 52.47839502990246, 54.25387255847454, 59.55886289477348, 63.21780055761337, 64.25866350531578, 64.33271393179893, 61.867569610476494, 61.685578376054764, 62.33233407139778, 70.66843315958977, 67.98456877470016, 75.25281116366386, 73.77092108130455, 58.48239205777645, 0.6629223434720188, 5.123515399172902, 80.02478510141373, 53.27957063913345, 51.08795844018459, 46.52008295059204, 32.75296188890934, 36.75475895404816, 52.60057367384434, 1.5957508538849652, 0.21938988153124228, 0.09783275658264756, 0.11019280311302282, 0.026309610111638904, 0.0725219065498095, 0.08094909731880762, 0.03609620391216595, 0.03869332002068404, 0.06223891985428054, 0.029367839269980323, 0.06598757085157558, 0.049311263937852345, 0.06517358327982947, 0.04245164120220579, 0.12651838216697797, 0.12617000320460647, 0.8979318954516202, 40.52992857992649, 64.2826934158802, 30.135460942983627, 37.93462224304676, 71.97587460279465, 57.25693501532078, 59.83722075819969, 79.40939292311668, 55.719419717788696, 0.5078489240258932, 0.0973937836533878, 7.374431490898132, 56.14675998687744, 68.01708742976189, 69.35389369726181, 70.927944034338, 78.99190172553062, 76.01421430706978, 78.29309642314911, 73.52848649024963, 76.54903560876846, 70.60506016016006, 67.09240704774857, 64.355748295784, 54.39733386039734, 52.924559488892555, 54.91510167717934, 52.55745738744736, 51.15263096988201, 51.67587049305439, 51.691103875637054, 50.93050628900528, 50.555739998817444, 50.508801117539406, 49.98855583369732, 50.661533921957016, 47.146057561039925, 47.776401937007904, 45.716642662882805, 50.33290855586529, 50.33474385738373, 54.93156999349594, 51.81053526699543, 48.381793051958084, 53.07371288537979, 50.19493795931339, 54.7614911198616, 58.8935261964798, 59.95017349720001, 58.280904069542885, 58.200675174593925, 61.21314212679863, 60.01887381076813, 58.56453225016594, 57.51500576734543, 57.809269577264786, 60.00446118414402, 52.83008135855198, 53.608670979738235, 53.63165594637394, 51.63501888513565, 44.537896513938904, 46.95814624428749, 39.296263977885246, 52.11082935333252, 44.954266771674156, 44.53553684055805, 43.22970271110535, 43.33963841199875, 43.730500638484955, 48.4173933416605, 48.33354324102402, 52.47126281261444, 51.45091496407986, 52.086936235427856, 49.73826706409454, 45.00516124069691, 42.14131571352482, 43.905116468667984, 48.27696807682514, 49.83503267168999, 41.64872154593468, 39.556656405329704, 42.5418446213007, 44.420049637556076, 49.076179191470146, 52.303467616438866, 54.25673380494118, 53.94250586628914, 45.942650735378265, 45.77484034001827, 43.562982827425, 41.67306683957577, 43.12972627580166, 43.66251848638058, 42.23937705159187, 41.861411333084106, 30.11642586439848, 49.04116027057171, 59.21952970325947, 57.24812708795071, 53.11633139848709, 53.359347358345985, 52.656506672501564, 59.432227090001106, 59.12290468811989, 60.02729035913944, 57.69112631678581, 58.8170363008976, 58.27117279171944, 61.08186677098274, 58.42897832393646, 59.285342171788216, 57.737126648426056, 54.170379638671875, 45.54337576031685, 48.936506286263466, 50.796008706092834, 47.06744357943535, 45.874881371855736, 43.26282553374767, 41.61001682281494, 45.360316783189774, 48.19498747587204, 49.480222910642624, 48.60456369817257, 50.09830914437771, 50.191483944654465, 51.0102716088295, 51.12116865813732, 51.418593898415565, 52.39376597106457, 57.842308804392815, 54.02097165584564, 56.17642879486084, 55.44134683907032, 59.058167561888695, 61.17440700531006, 66.47975072264671, 67.17135161161423, 68.28051969408989, 64.88923206925392, 65.76180204749107, 65.68956792354584, 75.6315216422081, 72.05962210893631, 81.10874533653259, 74.04281169176102, 71.7239785194397, 0.81637580296956, 6.8140689097344875, 86.72246530652046, 64.31020393967628, 56.73150680959225, 53.520192727446556, 39.036297127604485, 42.86829270422459, 67.9652202129364, 2.1508586732670665, 0.27224583202041686, 0.04884670546744019, 0.09392999490955845, 0.03305031110357959, 0.10155565134482458, 0.036218498717062175, 0.08888946147635579, 0.06575864797923714, 0.14027557364897802, 0.16616883891401812, 0.11751935177017003, 0.22062923846533522, 0.23499095375882462, 0.13290900096762925, 0.2628299966454506, 0.3825876658083871, 1.2735470244660974, 57.597195357084274, 71.81795507669449, 51.72979339957237, 47.272864356637, 74.85176548361778, 64.41804215312004, 65.26109531521797, 85.68329706788063, 56.818252354860306, 0.6883789587300271, 0.4767551925033331, 11.215977855026722, 63.50344642996788, 68.43510299921036, 70.34686401486397, 69.28334668278694, 79.99799653887749, 76.78619608283043, 78.96157935261726, 74.43122684955597, 77.73255810141563, 73.26136842370033, 67.77835384011269, 66.93100690841675, 57.83624432981014, 54.605843871831894, 56.75079457461834, 55.196803361177444, 54.92865175008774, 55.20483613014221, 53.976236656308174, 53.83821666240692, 52.084774151444435, 53.09068277478218, 53.325141593813896, 52.608648240566254, 50.22699683904648, 50.23750327527523, 49.81456317007542, 51.46954156458378, 54.37026411294937, 57.94111110270023, 53.167229667305946, 48.29940967261791, 56.727387830615044, 52.141277119517326, 56.144525706768036, 59.57751229405403, 62.327208146452904, 61.822173446416855, 61.39329805970192, 64.85163688659668, 60.64992114901543, 60.01887761056423, 59.9802602827549, 62.18317307531834, 63.144673481583595, 56.267836689949036, 59.10086207091808, 56.14507667720318, 54.60153490304947, 46.80583521723747, 49.3985690921545, 43.24516408145428, 51.696248799562454, 49.9690742790699, 47.6270205527544, 48.04163530468941, 44.48776200413704, 46.46843992173672, 51.054011061787605, 52.091720178723335, 55.08688285946846, 53.18302921950817, 54.14959475398064, 53.421242237091064, 48.332091718912125, 45.44378310441971, 46.68440133333206, 52.87396900355816, 52.91093721985817, 43.12802396714687, 42.80179247260094, 43.825712129473686, 46.761658787727356, 52.088984325528145, 55.14907792210579, 55.95625340938568, 55.555203929543495, 47.70773582160473, 50.041521191596985, 47.23333887755871, 43.731306195259094, 45.58664783835411, 48.13755355775356, 43.114090114831924, 49.68577668070793, 41.906815096735954, 52.778635919094086, 58.32078292965889, 58.926941603422165, 56.974602565169334, 54.686118364334106, 55.91361589729786, 62.64776274561882, 61.376290172338486, 61.64317265152931, 60.12782156467438, 62.668338641524315, 62.11097314953804, 62.25220017135143, 59.619363248348236, 59.71248485147953, 59.42631080746651, 56.28913834691048, 45.747538805007935, 51.18221238255501, 52.66715370118618, 50.29446981847286, 48.964734971523285, 46.497774347662926, 45.54409772157669, 49.07533183693886, 49.07187782227993, 51.054816618561745, 51.48435316979885, 52.30856694281101, 51.36137656867504, 55.36344721913338, 54.8095927387476, 52.44564838707447, 54.04848597943783, 60.7308492064476, 57.01287031173706, 57.16051518917084, 60.0580383092165, 62.213210463523865, 63.77418950200081, 71.28684237599373, 69.30444315075874, 71.63263902068138, 67.65676036477089, 69.85743507742882, 69.5668950676918, 79.2742645740509, 73.63360404968262, 85.08165255188942, 77.19034239649773, 73.9073033630848, 1.2625209661200643, 7.027295418083668, 92.2989396750927, 70.29675990343094, 68.06976780295372, 63.167080879211426, 44.82568547129631, 55.6758626550436, 77.70402923226357, 4.151995405554771, 0.685183567693457, 0.11529624098329805, 0.2826795674627647, 0.10436260970891453, 0.2505303535144776, 0.13140549883246422, 0.23374690645141527, 0.12281548086320981], [0.07679430971620604, 0.06427061220165342, 0.04737549417768605, 0.03571771230781451, 0.017404804639227223, 0.02530042656871956, 0.05288027066853829, 0.13109238672768697, 0.27133444498758763, 14.523455277085304, 55.12611195445061, 32.69211195409298, 24.33337178081274, 47.125375270843506, 53.64917680621147, 55.08377842605114, 69.06826302409172, 56.79179437458515, 1.6744690923951566, 0.24944948963820934, 3.2650864217430353, 31.964682787656784, 65.45546248555183, 72.8678235411644, 76.5433207154274, 72.60466486215591, 70.57492017745972, 70.53413316607475, 70.47626227140427, 68.09129744768143, 68.33983451128006, 61.6416185349226, 52.00731910765171, 51.10136792063713, 51.67055457830429, 50.09280703961849, 45.64671881496906, 45.70619322359562, 48.3685165643692, 49.443934857845306, 50.30397690832615, 46.822953298687935, 48.272263929247856, 50.59435732662678, 47.28396736085415, 45.841652154922485, 43.696158081293106, 44.111677184700966, 45.39252385497093, 48.27365465462208, 52.18880496919155, 51.04454576969147, 45.659926906228065, 47.767286226153374, 48.193345963954926, 51.79137669503689, 54.591815024614334, 57.269519940018654, 57.53368176519871, 57.78975002467632, 57.23836921155453, 55.00076048076153, 53.821121379733086, 55.39441555738449, 54.62715692818165, 56.640342101454735, 48.75142201781273, 48.92203286290169, 51.92144751548767, 57.48174615204334, 51.496679708361626, 50.50324201583862, 38.41997779905796, 39.22257833182812, 45.65269209444523, 41.01154513657093, 43.01096744835377, 40.78508488833904, 42.98751510679722, 41.385581865906715, 46.383655071258545, 51.49707488715649, 54.48186032474041, 49.79100443422794, 48.978068456053734, 44.0938713401556, 45.23513250052929, 43.47082257270813, 47.655131444334984, 51.10031917691231, 45.64730778336525, 42.68085636198521, 45.23099832236767, 46.71265661716461, 50.12776896357536, 52.710000202059746, 54.60922949016094, 49.49063815176487, 44.55705888569355, 41.07030138373375, 41.169597655534744, 38.832061886787415, 40.84272399544716, 38.4655449539423, 44.59965080022812, 33.366530165076256, 27.748493626713753, 33.48751187324524, 44.79263484477997, 53.94578129053116, 48.54616843163967, 52.61310540139675, 52.175353690981865, 57.60799817740917, 56.63599133491516, 53.750813752412796, 56.768684014678, 57.167620807886124, 55.84661789238453, 57.86093160510063, 56.560618579387665, 55.67640982568264, 57.44451195001602, 56.7863492667675, 47.343510165810585, 46.883373856544495, 51.197088584303856, 47.019737139344215, 43.555778414011, 41.63237102329731, 39.277344793081284, 40.64620614051819, 46.94091796875, 45.55652305483818, 45.9249322861433, 49.53876256942749, 49.32031989097595, 47.40717954933643, 49.32251237332821, 50.82500874996185, 47.576996237039566, 49.707534313201904, 50.48796683549881, 51.49199075996876, 51.03501968085766, 49.81788419187069, 57.17745468020439, 63.01470905542374, 63.07784266769886, 63.20665955543518, 59.46337781846523, 61.701263934373856, 61.073191836476326, 70.10281831026077, 67.27974459528923, 76.53784900903702, 67.81743094325066, 71.42114996910095, 0.6649547594133765, 7.023235335946083, 84.1285952925682, 53.0644603818655, 53.91596809029579, 42.15273790061474, 42.04340636730194, 39.19147700071335, 60.50944268703461, 1.6652368940412998, 0.17053778807166964, 0.14425283210584894, 0.08759338961681351, 0.03880913587636314, 0.025619255065976176, 0.07556668613688089, 0.031347534895758145, 0.02350645896513015, 0.05805545566545334, 0.07152702790335752, 0.10410685077658854, 0.0010961289262922946, 0.03293537469289731, 0.07947004152811132, 0.07315965631278232, 0.0557344222033862, 0.4752527887467295, 13.724301159381866, 73.40826854109764, 31.604021340608597, 31.5083234757185, 63.08565504848957, 55.24291008710861, 61.44537806510925, 75.3433983027935, 61.58719785511494, 1.5783722489140928, 0.2819308592006564, 3.8939624140039086, 42.416747733950615, 71.47696897387505, 76.76451444625854, 79.36265543103218, 75.94153940677643, 74.3891479074955, 73.096784055233, 74.10575151443481, 71.19738757610321, 71.47177085280418, 66.15890353918076, 55.45786075294018, 53.918278366327286, 52.68503554165363, 53.31547871232033, 51.62843383848667, 49.438007175922394, 51.095402240753174, 51.621525809168816, 52.801024317741394, 50.67079782485962, 50.475013330578804, 52.55379058420658, 49.96321119368076, 49.46958348155022, 46.819978058338165, 45.75620234012604, 48.28270956873894, 51.2585236877203, 56.661324575543404, 50.838019251823425, 47.2089783847332, 49.33143429458141, 50.11668115854263, 52.1318194270134, 58.45614306628704, 60.92277690768242, 59.72795382142067, 60.285440906882286, 58.94145682454109, 58.30179154872894, 58.92307721078396, 56.96438491344452, 56.7859198898077, 57.57038399577141, 51.068066507577896, 51.808532774448395, 56.62663243710995, 61.8911549448967, 55.43070740997791, 52.20946066081524, 43.0438356846571, 43.73569495975971, 46.727939397096634, 41.73101373016834, 45.24259530007839, 42.21406660974026, 45.90402200818062, 43.1951055675745, 50.67543737590313, 53.790259435772896, 55.57118587195873, 53.44489976763725, 52.40362264215946, 46.11202284693718, 47.85625085234642, 46.94389320909977, 50.83109602332115, 52.73179203271866, 48.23637865483761, 46.34477935731411, 45.97374826669693, 51.71207495033741, 54.294891357421875, 54.26003962755203, 57.28870511054993, 52.242754474282265, 47.767483815550804, 43.18079933524132, 43.85169893503189, 40.64461022615433, 43.61020289361477, 40.841914638876915, 47.470860332250595, 33.48536878824234, 32.71416217088699, 34.78312075138092, 43.65169286727905, 54.735116735100746, 51.39825738966465, 54.52518180012703, 55.56279972195625, 58.53370450437069, 57.77361989021301, 58.587809801101685, 57.58097402751446, 59.38392408192158, 59.90782476961613, 60.34838452935219, 57.26495638489723, 57.47653283178806, 58.50401669740677, 58.974731639027596, 47.641121596097946, 49.80405293405056, 53.78848493099213, 48.95783454179764, 46.32241375744343, 43.75432915985584, 43.12172390520573, 43.447244837880135, 50.40722496807575, 50.05699776113033, 49.035969749093056, 52.6986388117075, 51.32958747446537, 50.599483251571655, 51.08978234231472, 52.95198641717434, 51.09855227172375, 53.45516301691532, 52.29323476552963, 54.43251617252827, 53.60642150044441, 56.16691030561924, 60.137894824147224, 67.88219466805458, 64.84057947993279, 67.78270080685616, 63.20486605167389, 66.13335371017456, 63.41449700295925, 75.35718396306038, 69.80087891221046, 80.17252877354622, 71.5182575583458, 81.39063701033592, 0.8826717361807823, 8.7824497371912, 91.36841520667076, 59.881051406264305, 61.868694350123405, 51.44249461591244, 45.264482125639915, 42.749841660261154, 69.56640109419823, 2.2602493409067392, 0.2537890645908192, 0.06861934525659308, 0.12802786601241678, 0.022472237214969937, 0.02649855348863639, 0.09769094700459391, 0.09591991547495127, 0.06529337333631702, 0.18751483177766204, 0.1797281886683777, 0.16112906247144565, 0.1393483640276827, 0.16749925736803561, 0.19178675254806876, 0.30117949820123613, 0.2785011276137084, 0.7244996423833072, 25.691301114857197, 82.849340736866, 49.97971750795841, 35.10152846574783, 61.23391941189766, 69.29305896162987, 68.7113405764103, 82.64501050114632, 65.5459812283516, 2.030044156126678, 0.5002433352638036, 4.8923856765031815, 48.45816135406494, 71.68042525649071, 80.34096613526344, 81.69362515211105, 78.041922301054, 74.08615976572037, 75.4552111029625, 75.10990083217621, 71.23232290148735, 72.80289262533188, 69.2748275399208, 57.18404732644558, 56.45770490169525, 57.628779262304306, 55.447730496525764, 51.96152776479721, 50.98698265850544, 56.44262731075287, 55.509815365076065, 55.72150580585003, 52.257239297032356, 51.75539642572403, 56.17938123643398, 52.47444324195385, 51.50571942329407, 49.1191852837801, 48.340743854641914, 50.67924477159977, 54.24316853284836, 59.77417454123497, 54.39934395253658, 47.78373934328556, 52.78710186481476, 50.36409728229046, 54.7194729745388, 59.61682878434658, 62.90021739900112, 62.061887383461, 63.915549516677856, 61.30071982741356, 60.544351413846016, 61.22888848185539, 59.45788711309433, 58.96228350698948, 62.00867883861065, 53.513683676719666, 53.12504053115845, 58.10961306095123, 63.0599532276392, 56.351306810975075, 52.69857041537762, 45.12555778026581, 43.66438798606396, 50.2845561504364, 45.36549970507622, 47.714248672127724, 46.57885819673538, 49.14496690034866, 45.40451981127262, 52.098005041480064, 56.68391056358814, 59.404879957437515, 55.84201633930206, 54.55187916755676, 49.597488418221474, 50.38168653845787, 48.50307114422321, 52.175387889146805, 56.331327483057976, 49.99347276985645, 48.38400073349476, 48.93151715397835, 53.24827551841736, 57.10798680782318, 57.72349677979946, 60.11809788644314, 56.05334199965, 46.564213782548904, 45.281820595264435, 45.26957765221596, 42.93331101536751, 46.89275175333023, 42.73479446768761, 49.28414583206177, 40.994142070412636, 36.51135541498661, 37.33412906527519, 44.020710065960884, 56.36551424860954, 54.59686115384102, 55.92845790088177, 58.19689817726612, 62.49931611120701, 60.17066426575184, 60.329438745975494, 59.69926916062832, 60.44141873717308, 60.914823934435844, 62.93180510401726, 59.442824721336365, 58.76519188284874, 59.14340078830719, 61.31620019674301, 47.54561372101307, 48.67274343967438, 56.6521442681551, 53.18148650228977, 48.94184119999409, 48.00699636340141, 46.84225246310234, 46.48167461156845, 51.91661037504673, 52.323712930083275, 50.52292115986347, 55.875538140535355, 53.42362470924854, 52.837289571762085, 54.32441957294941, 56.65372118353844, 52.03641414642334, 54.67492796480656, 54.20531876385212, 57.296893671154976, 54.617824628949165, 56.75595089793205, 63.25587831437588, 70.56756377220154, 67.42728307843208, 69.92766290903091, 66.337129175663, 68.73890429735184, 64.90342810750008, 79.23701897263527, 71.77948594093323, 83.37682083249092, 74.35462296009064, 84.44599986076355, 1.316256020218134, 9.98739643022418, 98.70950728654861, 69.62659746408463, 72.9881326854229, 58.12038168311119, 58.21278892457485, 55.22631257772446, 85.60508966445923, 3.2985224900767207, 0.3764729923568666, 0.2213571369065903, 0.2909862482920289, 0.12029174831695855, 0.10242978998576291, 0.17191082064528018, 0.1998972985893488, 0.13728785037528723], [0.041139208697131835, 0.03700431807374116, 0.04932133117108606, 0.039610165549675, 0.0317633157101227, 0.04758325099828653, 0.059998264696332626, 0.1370811919332482, 0.332967612775974, 1.6913148947060108, 53.459471985697746, 48.98462690412998, 23.3992850035429, 34.50503267347813, 57.90981978178024, 49.62447077035904, 69.9733516573906, 58.49430821835995, 3.13589786645025, 0.3144887590315193, 5.508488891646266, 58.995379731059074, 70.93276977539062, 73.18655803799629, 71.71916037797928, 73.07732909917831, 73.07604476809502, 69.76864904165268, 68.5244970023632, 67.42296651005745, 63.47357243299484, 56.11285820603371, 49.24810856580734, 51.91064849495888, 50.132803693413734, 51.12464167177677, 49.51265037059784, 48.91048148274422, 48.62452782690525, 48.55247609317303, 46.40032857656479, 48.25185902416706, 47.850767746567726, 48.86365659534931, 48.65203455090523, 45.50518020987511, 43.91132913529873, 44.885980635881424, 46.189580485224724, 46.65835753083229, 52.575248032808304, 46.651989072561264, 47.450691014528275, 48.86550709605217, 48.89731138944626, 51.026356145739555, 55.607169941067696, 59.66520018875599, 59.82578717172146, 59.102423787117004, 58.09748411178589, 58.805937096476555, 55.384969264268875, 57.811420261859894, 57.15734615921974, 53.32203336060047, 47.48434580862522, 55.782009959220886, 57.098840698599815, 61.96991331875324, 59.65555630624294, 46.40236906707287, 46.859055161476135, 39.799531772732735, 45.037573501467705, 42.06148199737072, 44.1045867651701, 39.99394454061985, 42.74248905479908, 42.25285492837429, 48.42331722378731, 49.46930609643459, 49.73983258008957, 52.07067310810089, 52.79469385743141, 45.25093965232372, 46.704528853297234, 48.64690102636814, 52.051005363464355, 53.3290059864521, 50.59740096330643, 45.80336160957813, 48.73849891126156, 48.02195616066456, 52.93641485273838, 53.086252212524414, 52.27689564228058, 46.86457246541977, 45.232693031430244, 41.02730669081211, 41.11567094922066, 40.38678266108036, 38.34020487964153, 40.235622972249985, 40.03336362540722, 33.51239673793316, 33.170111104846, 40.87378732860088, 49.02666784822941, 46.31360203027725, 49.34800520539284, 50.44638566672802, 54.329560697078705, 55.23033656179905, 54.40335653722286, 56.52719557285309, 56.27553507685661, 59.07624699175358, 58.190966695547104, 57.21308156847954, 56.66960433125496, 58.835187926888466, 56.63376845419407, 58.81748467683792, 49.05069775879383, 49.049903601408005, 51.02981775999069, 45.76155245304108, 43.31785038113594, 42.13009871542454, 40.533568784594536, 39.59799438714981, 45.26642382144928, 46.18493713438511, 47.88018956780434, 46.8914408236742, 47.99030765891075, 48.45674403011799, 48.16173546016216, 45.82800328731537, 46.60650171339512, 48.89681741595268, 48.46427142620087, 51.408019065856934, 52.154120430350304, 51.660481318831444, 55.580225586891174, 60.216383412480354, 62.200082167983055, 63.92053484916687, 58.41924324631691, 61.1091835051775, 59.31175455451012, 69.20326977968216, 69.44761946797371, 76.88591793179512, 68.23316663503647, 74.54029619693756, 0.9186853724531829, 8.931508138775826, 83.16741406917572, 49.11053694784641, 51.50279738008976, 45.08430339396, 33.63460958003998, 41.92723140120506, 62.189902514219284, 1.7237023380585015, 0.13022567698499188, 0.0563393987249583, 0.0534777848952217, 0.06559991743415594, 0.022327375554596074, 0.018821558987838216, 0.01888310715003172, 0.05606043283478357, 0.06724526625475846, 0.03896833768521901, 0.007831814855308039, 0.005009206452086801, 0.04387391898490023, 0.03890912172209937, 0.04169646512309555, 0.08886231371434405, 0.3092956548789516, 1.4995541470125318, 64.1704474389553, 51.19627542793751, 18.633991107344627, 47.69072413444519, 65.94802245497704, 60.563962161540985, 77.6693294942379, 63.31630267202854, 3.68667664937675, 0.5744144052732736, 9.502788484096527, 71.63982063531876, 78.01460936665535, 77.8314819931984, 77.75907307863235, 76.28941833972931, 74.66622143983841, 72.95642718672752, 72.89099469780922, 70.00008702278137, 67.60490074753761, 59.15469378232956, 53.85951451957226, 54.93860721588135, 54.26271468400955, 51.60142868757248, 51.24778926372528, 51.96461699903011, 51.799306869506836, 51.05610474944115, 49.1515139490366, 51.27913758158684, 50.993229523301125, 51.83999128639698, 51.34004071354866, 47.979504838585854, 45.41534923017025, 46.894393265247345, 49.63712029159069, 48.90674248337746, 53.891094624996185, 50.05444809794426, 49.33777995407581, 49.937779158353806, 49.63615134358406, 53.15687142312527, 59.261107072234154, 61.345565021038055, 61.298116967082024, 59.11745958030224, 60.16790561378002, 59.23450469970703, 57.636025473475456, 60.67477561533451, 60.02114228904247, 56.45523503422737, 50.88588908314705, 58.467037081718445, 62.157668843865395, 63.800408095121384, 61.95354379713535, 49.41762886941433, 48.81310410797596, 46.20701014995575, 47.36712209880352, 44.36044983565807, 44.129718616604805, 41.34448707103729, 44.00985024869442, 43.98380644619465, 51.53090447187424, 53.918156772851944, 56.26909822225571, 53.7406986951828, 55.703639164566994, 47.87081927061081, 46.44171595573425, 50.73853299021721, 54.43632356822491, 55.84626451134682, 52.788454592227936, 48.65654110908508, 53.574146032333374, 49.34088818728924, 55.677880346775055, 55.00160403549671, 54.21214319765568, 50.87378293275833, 48.14433619379997, 43.34406517446041, 43.277903124690056, 42.3597963899374, 41.48759879171848, 41.278648003935814, 42.00239896774292, 37.01013185083866, 34.50960762798786, 41.46401345729828, 50.12917868793011, 48.68994891643524, 50.01481242477894, 52.14816614985466, 56.63304649293423, 58.00518326461315, 55.760974287986755, 57.976141422986984, 57.774873822927475, 59.04619440436363, 59.38143141567707, 60.001352950930595, 57.42216534912586, 60.376499220728874, 59.344132617115974, 61.00649021565914, 50.259450897574425, 49.1193562746048, 52.86640360951424, 49.5066998898983, 45.917746871709824, 45.12707009911537, 42.95250378549099, 44.49131481349468, 49.63491640985012, 49.164752438664436, 50.43928004801273, 50.02620421350002, 50.8477733284235, 51.84822924435139, 50.81626921892166, 50.83371788263321, 51.03789612650871, 52.14518330991268, 53.1917155534029, 53.9132322371006, 54.425380155444145, 55.71858376264572, 57.18847408890724, 64.491066634655, 64.41909089684486, 68.44493687152863, 61.22582204639912, 64.89981070160866, 63.078739419579506, 73.47138315439224, 73.35434183478355, 82.62663468718529, 70.79867497086525, 83.55630040168762, 1.4437597221694887, 9.547448437660933, 90.52999779582024, 53.53045977652073, 61.37473225593567, 54.878380447626114, 42.26657219231129, 46.386725306510925, 70.91260805726051, 1.2425133772194386, 0.09145400472334586, 0.02195385819504736, 0.04175698726612609, 0.036641689875978045, 0.04234782587445807, 0.02188503884099191, 0.03270611785410438, 0.08408049296122044, 0.1902499279822223, 0.1798534335102886, 0.19260225410107523, 0.2601842995500192, 0.07947672827867791, 0.18653010571142659, 0.23893193603726104, 0.3473179286811501, 0.503518640762195, 5.011076107621193, 75.53923219442368, 64.16584208607674, 34.50208023190498, 44.75904084742069, 77.15383395552635, 63.03351804614067, 83.23014110326767, 67.11509943008423, 4.325618064031005, 0.963068890850991, 11.404894217848778, 73.36199462413788, 77.5292082130909, 78.52584153413773, 79.51632678508759, 78.95111471414566, 78.71058002114296, 74.74926218390465, 74.50856789946556, 72.28964656591415, 69.39578264951706, 60.65196543931961, 55.004058703780174, 56.71739436686039, 57.15086750686169, 57.319582253694534, 55.4118338227272, 53.87885548174381, 55.43984591960907, 54.002314656972885, 51.40101604163647, 52.660169675946236, 53.154485151171684, 54.95035618543625, 54.25959885120392, 48.81335489451885, 48.95962804555893, 50.066998824477196, 52.956329584121704, 51.93705327808857, 56.35812744498253, 50.07273651659489, 48.3373012393713, 51.10371619462967, 51.80091418325901, 53.87279860675335, 60.645213201642036, 64.60556969046593, 65.39543330669403, 63.52463789284229, 62.9896380007267, 62.58049115538597, 59.344166815280914, 62.865593656897545, 63.014021292328835, 59.64804030954838, 54.784217700362206, 60.149883180856705, 64.78722274303436, 65.81107780337334, 65.6344024837017, 51.85588203370571, 52.3628356307745, 44.17856499552727, 50.734755992889404, 48.88478346168995, 50.0568837672472, 44.70987908542156, 47.48386323451996, 47.40557223558426, 52.869679033756256, 56.866445168852806, 59.11988005042076, 58.350869715213776, 58.685130178928375, 50.560850724577904, 47.645947337150574, 53.11761952936649, 57.401768043637276, 59.72306348383427, 56.157756596803665, 51.75659716129303, 55.77791377902031, 54.391611367464066, 59.73516583442688, 59.34984751045704, 57.430228516459465, 53.83246757090092, 50.80465704202652, 45.56864060461521, 45.61774916946888, 45.1867762953043, 43.9493802934885, 45.88194139301777, 44.46796126663685, 40.21207943558693, 38.34512561559677, 40.28833754360676, 50.25188930332661, 50.23493081331253, 53.23466084897518, 55.940153673291206, 58.935920521616936, 61.068947464227676, 59.03876580297947, 60.83633154630661, 59.64082069694996, 61.86263747513294, 63.80363032221794, 62.57252298295498, 59.21390600502491, 63.017862886190414, 61.378228068351746, 63.5807228833437, 50.989680513739586, 50.33570520579815, 54.798254147171974, 51.75465926527977, 48.6940298974514, 48.91361251473427, 45.648607313632965, 46.87147669494152, 51.03330597281456, 52.87908732891083, 52.93366760015488, 53.11471648514271, 53.414467200636864, 54.24079746007919, 53.09021919965744, 52.60331332683563, 51.811261028051376, 54.25737977027893, 54.583155289292336, 58.46672549843788, 55.7544082403183, 57.86083661019802, 58.774011209607124, 66.21625766158104, 67.65149384737015, 72.1911558508873, 61.61428280174732, 67.19997927546501, 64.3474343419075, 77.84607321023941, 76.19901359081268, 86.04097187519073, 72.86580964922905, 86.3541054725647, 1.9884249893948436, 10.830744076520205, 96.47899657487869, 60.163782835006714, 69.80924606323242, 60.53952947258949, 49.28148977458477, 59.259788542985916, 86.24518051743507, 2.6887699216604233, 0.5096205195877701, 0.16320915397955105, 0.14208813576260582, 0.2314803726039827, 0.12240986747201532, 0.15657834650482982, 0.11851711737108417, 0.2173500886419788], [0.047398842143593356, 0.0050250049207534175, 0.05540816666325554, 0.018125864189642016, 0.018776204487949144, 0.047482764202868566, 0.04921361956803594, 0.046467650900012814, 0.05325163023371715, 0.17673136666417122, 39.14385415613651, 58.00424471497536, 41.93254731595516, 23.22543103247881, 53.50735701620579, 44.14912037551403, 63.74303117394447, 62.798056080937386, 4.508756836876273, 0.5173513235058635, 32.60980077087879, 76.84605807065964, 68.49820241332054, 72.18882277607918, 72.79137164354324, 71.33172556757927, 68.9109818637371, 65.32295599579811, 62.47138001024723, 63.898465633392334, 58.18102642893791, 50.06017439067364, 49.490163177251816, 49.71213586628437, 47.483148872852325, 50.50165370106697, 49.804949685931206, 49.97695505619049, 49.69991572201252, 49.1486831009388, 48.49024683237076, 49.98760208487511, 48.13755735754967, 48.666120395064354, 47.92022801935673, 46.298452243208885, 43.28216269612312, 44.16159510612488, 43.41884896159172, 46.105946972966194, 51.14952653646469, 51.25589422881603, 48.9323341101408, 45.14340162277222, 46.98706269264221, 53.447783812880516, 61.46894060075283, 57.91934587061405, 57.817860916256905, 56.039890721440315, 56.04140684008598, 56.940772980451584, 57.86837540566921, 55.63919082283974, 58.63900065422058, 51.71122379601002, 51.69238440692425, 57.93563939630985, 56.865381225943565, 59.57728810608387, 59.15191613137722, 46.85463599860668, 46.79439403116703, 40.44237747788429, 43.18950466811657, 41.51731699705124, 39.415132999420166, 40.567808747291565, 44.16540630161762, 42.33256325125694, 46.304463520646095, 50.14388769865036, 50.973721370100975, 53.396083787083626, 50.80734349787235, 50.74662275612354, 48.81986014544964, 52.53195695579052, 47.22797356545925, 50.18792733550072, 50.2258986979723, 52.59262070059776, 51.378460451960564, 51.542110070586205, 47.761396542191505, 50.21006114780903, 50.25158151984215, 47.242306396365166, 42.48931623995304, 41.80974170565605, 43.17331753671169, 40.13421781361103, 40.32119058072567, 39.22117240726948, 40.07949694991112, 38.12119223177433, 36.27881169319153, 44.443802163004875, 46.93153627216816, 52.22179859876633, 51.03015214204788, 48.85229900479317, 46.53466276824474, 51.99541814625263, 56.91458098590374, 56.70501843094826, 57.11018308997154, 56.108868420124054, 59.2253053933382, 57.1670888364315, 55.65381623804569, 57.83746026456356, 56.79028205573559, 58.62604334950447, 49.920516684651375, 49.695830941200256, 51.182569563388824, 43.88256847858429, 45.35199522972107, 40.757878348231316, 41.7256598174572, 41.705422103405, 45.40920116007328, 45.38893684744835, 47.44135871529579, 48.07777896523476, 47.68923081457615, 47.151726856827736, 47.57866434752941, 50.88322922587395, 49.873866587877274, 49.17614042758942, 48.59989754855633, 49.824096858501434, 51.29268765449524, 52.03210897743702, 55.05022622644901, 59.078747257590294, 58.43244753777981, 60.35674408078194, 57.249548211693764, 60.52282936871052, 62.363746985793114, 69.98489543795586, 67.67746925354004, 77.02626720070839, 74.08873602747917, 75.47854945063591, 0.9297756117302924, 10.650444701313972, 83.16049844026566, 46.63188435137272, 57.317868545651436, 48.23343761265278, 34.73800577223301, 46.684583723545074, 51.06240101158619, 0.7782682415563613, 0.08501013682689518, 0.06617562365136109, 0.0516704920300981, 0.039239915495272726, 0.026683342694013845, 0.014817808641964803, 0.10524437020649202, 0.04359088612545747, 0.026119104513782077, 0.04632955577108078, 0.034024988490273245, 0.06211454332515132, 0.02993621863424778, 0.1186772134678904, 0.0056654361560504185, 0.07075282686855644, 0.10514235458686016, 0.24729034455958754, 46.56861014664173, 66.5229620039463, 27.25843772292137, 31.482819244265556, 61.58792361617088, 48.43026705086231, 71.74438342452049, 68.77964571118355, 5.7225641794502735, 0.6286848743911833, 42.189436331391335, 82.68387481570244, 72.38487705588341, 75.90845838189125, 74.87590938806534, 74.92435678839684, 74.3421596288681, 67.08210200071335, 67.25208207964897, 67.24442169070244, 61.42947971820831, 53.27769733965397, 54.191259518265724, 52.736598774790764, 51.72321975231171, 52.23019614815712, 53.51273752748966, 51.88592702150345, 52.34522357583046, 50.822291895747185, 50.336807146668434, 50.94127111136913, 51.370169296860695, 52.01728977262974, 51.90848261117935, 47.46681734919548, 47.68580719828606, 46.06922574341297, 47.83048443496227, 49.073922112584114, 54.081730395555496, 51.78258016705513, 49.55244943499565, 46.60429783165455, 48.932980075478554, 54.97110687196255, 61.49632193148136, 59.180167615413666, 57.93925680220127, 59.159124344587326, 58.3428293466568, 58.876476511359215, 62.014025151729584, 58.81817243993282, 60.225369930267334, 54.949873611330986, 57.94252082705498, 59.79665033519268, 58.91846425831318, 60.80967977643013, 61.77845299243927, 51.464959010481834, 48.50390709936619, 44.49191518127918, 46.73428885638714, 42.957112938165665, 43.23032207787037, 42.11894631385803, 45.4460059851408, 44.64615270495415, 49.308035150170326, 51.47032052278519, 52.188637778162956, 56.68411575257778, 54.446225836873055, 53.37400697171688, 52.959487214684486, 53.50408539175987, 49.06905077397823, 50.79378962516785, 51.38368517160416, 54.54100415110588, 54.0917656570673, 55.38234740495682, 52.245953902602196, 54.49536480009556, 51.82647541165352, 51.036019027233124, 45.28249315917492, 44.08924698829651, 43.61821286380291, 41.60152807831764, 41.33843019604683, 41.959218084812164, 42.36044995486736, 40.01944497227669, 39.73435007035732, 44.82403255999088, 48.370021283626556, 55.022632107138634, 55.48799313604832, 50.18341697752476, 48.760260343551636, 56.22242532670498, 59.690415635704994, 58.33829239010811, 58.3940239995718, 57.26789742708206, 59.25283491611481, 60.24021193385124, 58.047144412994385, 61.00219264626503, 60.749870985746384, 61.52767404913902, 51.377381309866905, 52.3608635365963, 53.560641556978226, 47.590405717492104, 48.516989797353745, 44.331825971603394, 45.26855170726776, 44.791962280869484, 47.59891726076603, 48.63857567310333, 49.45784971117973, 49.778734892606735, 50.04226595163345, 51.068271696567535, 51.26840315759182, 51.68597795069218, 53.33062469959259, 51.225978434085846, 51.43068864941597, 52.3812722414732, 54.319878816604614, 54.84910301864147, 58.9672764390707, 64.44157809019089, 62.332174479961395, 65.94179838895798, 60.50984546542168, 65.72794586420059, 66.289973706007, 74.33139860630035, 70.57108238339424, 82.613016217947, 77.62732654809952, 82.16553702950478, 1.0533914691768587, 13.066177424043417, 90.42979717254639, 52.1852445602417, 66.38505220413208, 57.101850137114525, 40.940504148602486, 50.515762344002724, 54.73599448800087, 0.6120174843817949, 0.028555426906677894, 0.04521357346675359, 0.07522143161622807, 0.03933530744689051, 0.06044065150490496, 0.030186524636519607, 0.06165366590721533, 0.04637005848053377, 0.12169709400041029, 0.15306338667869568, 0.14488719025393948, 0.18777857621898875, 0.11636002062004991, 0.18254552967846394, 0.0732744146080222, 0.17709589475998655, 0.26015494018793106, 0.31181622587610036, 63.29672232270241, 74.13759380578995, 58.49927835166454, 32.111499309539795, 71.12578421831131, 54.34931203722954, 76.10094845294952, 73.38119879364967, 5.940976459532976, 0.7164585613645613, 42.5173207372427, 83.04491624236107, 75.31220957636833, 78.49703907966614, 79.20339077711105, 78.78686472773552, 76.24857813119888, 71.00794494152069, 68.78205478191376, 70.61746269464493, 64.18593540787697, 53.89270953834057, 56.408923119306564, 54.37787130475044, 54.318712279200554, 55.59854820370674, 55.806723833084106, 55.106592401862144, 54.551856368780136, 53.3303739130497, 54.28835950791836, 53.9875790476799, 52.100338116288185, 55.1075841486454, 55.40794663131237, 49.9929977953434, 50.40611542761326, 49.260423704981804, 49.738198667764664, 48.1458181142807, 58.31018149852753, 54.542087092995644, 51.177949011325836, 47.517552226781845, 50.252531468868256, 57.04508878290653, 65.10130628943443, 61.273661479353905, 61.36872857809067, 58.25788490474224, 60.22423379123211, 60.31943768262863, 64.27545100450516, 59.99285280704498, 63.7789848446846, 57.086217775940895, 59.62956950068474, 63.41300368309021, 61.696255803108215, 64.31271940469742, 63.68344657123089, 53.458415642380714, 53.58732372522354, 45.58002859354019, 48.885535821318626, 47.13975369930267, 46.070977449417114, 44.623194336891174, 49.529939442873, 47.751543670892715, 51.18564359843731, 56.59025698900223, 54.9930164963007, 60.53468093276024, 55.71786940097809, 57.1281523257494, 56.213169023394585, 58.33635829389095, 51.95086173713207, 53.74548643827438, 53.65383915603161, 57.96062685549259, 56.98748767375946, 59.396904185414314, 55.007626712322235, 58.284909054636955, 56.04445047676563, 54.627369716763496, 47.578546553850174, 48.64922650158405, 45.89835271239281, 44.419183284044266, 43.17036509513855, 44.89371322095394, 44.029027819633484, 44.85235624015331, 39.93881709873676, 45.34836262464523, 51.84154160320759, 56.50681346654892, 57.39848501980305, 53.46985682845116, 50.89676409959793, 59.520078375935555, 62.91149139404297, 61.47193104028702, 60.54760783910751, 59.528627917170525, 63.311530128121376, 62.815626338124275, 61.07581369578838, 63.29701870679855, 63.36081728339195, 65.25028869509697, 53.184780925512314, 52.57051348686218, 56.98664411902428, 49.81410339474678, 51.85821890830994, 47.5573018938303, 48.59091863036156, 45.27704045176506, 49.00219716131687, 49.6646574139595, 52.08373300731182, 52.65316665172577, 52.067580074071884, 52.72729307413101, 53.60305108129978, 55.744980946183205, 56.29636935889721, 54.80523817241192, 52.852648347616196, 56.21236726641655, 54.857424572110176, 57.15189345180988, 61.868470162153244, 66.25966653227806, 63.964992463588715, 69.15198773145676, 62.380701676011086, 67.63062536716461, 69.14391696453094, 79.39847230911255, 72.73492187261581, 88.08032244443893, 82.32971101999283, 87.48370885848999, 1.7247335077263415, 14.34131395071745, 97.29292050004005, 58.96379962563515, 77.90595039725304, 63.89043286442757, 50.679970532655716, 67.53949865698814, 74.37640339136124, 1.6090316162444651, 0.3091156395385042, 0.10942175620584749, 0.15810875891475007, 0.1112473504326772, 0.18237174837850034, 0.13171653292374685, 0.12278990645427257, 0.12002482006209902], [0.03626260826422367, 0.013051330188318389, 0.015483932565985015, 0.01894755710964091, 0.04640776700398419, 0.02530538782593794, 0.00646593194687739, 0.0928707720595412, 0.07150272256694734, 0.3310822608182207, 20.329180844128132, 70.2445051074028, 51.09457388520241, 31.00067261606455, 46.796335726976395, 48.36985409259796, 49.239878207445145, 74.32601049542427, 5.041199941188097, 0.13616275449749082, 65.34576997160912, 76.16741448640823, 74.18053150177002, 67.68240138888359, 69.29768711328506, 67.19180971384048, 63.260362073779106, 60.996078774333, 59.62690584361553, 56.251904144883156, 50.78150488436222, 51.5616562217474, 51.674692556262016, 49.36099290847778, 48.35535787045956, 47.949072271585464, 48.69535982608795, 49.25032004714012, 51.420395001769066, 48.87579694390297, 50.52571401000023, 50.38173973560333, 47.97212563455105, 47.20989033579826, 48.199820816516876, 47.931741401553154, 45.27475297451019, 42.616514414548874, 43.08087609708309, 46.42071068286896, 49.371643736958504, 50.365928784012794, 49.33558367192745, 49.38834764063358, 46.7340000718832, 54.56449069082737, 57.77252934873104, 57.606945633888245, 56.94530613720417, 55.35903565585613, 58.46174776554108, 58.206549659371376, 59.184875562787056, 54.19347479939461, 57.44846373796463, 53.35872799158096, 60.120795741677284, 57.24940001964569, 58.57323758304119, 55.25014489889145, 60.1738028973341, 47.736055701971054, 41.44001394510269, 38.639070242643356, 40.869242772459984, 42.0667789131403, 43.490497916936874, 40.06193049252033, 40.06136812269688, 42.315251380205154, 47.22024857997894, 47.00134992599487, 52.67074070870876, 51.842138171195984, 53.24595004320145, 47.314757108688354, 52.70348735153675, 47.159641832113266, 44.74424064159393, 43.1020637601614, 46.66362784802914, 50.252402275800705, 55.20641304552555, 51.892253682017326, 49.05842274427414, 52.20249943435192, 49.749810844659805, 43.8575392216444, 42.55664482712746, 40.35040721297264, 41.499150171875954, 41.59702531993389, 39.0160746127367, 40.304764062166214, 42.04554185271263, 37.75955803692341, 43.45590077340603, 46.99378453195095, 52.86188565194607, 57.742476761341095, 52.09367707371712, 51.16601005196571, 45.235060304403305, 48.32189306616783, 54.416572228074074, 55.88868163526058, 57.55178399384022, 57.44429536163807, 59.663558676838875, 57.7441980689764, 54.899245128035545, 57.05781809985638, 54.37366873025894, 57.83720187842846, 47.717421501874924, 48.27780023217201, 50.694975927472115, 46.53499715030193, 43.772142603993416, 42.916971892118454, 40.36294274032116, 44.308434426784515, 46.48779608309269, 45.49592010676861, 45.2153355628252, 45.829002633690834, 46.972391679883, 47.90749870240688, 47.4441097676754, 47.69344478845596, 50.10884217917919, 51.22985802590847, 49.17593143880367, 49.08629424870014, 48.98482069373131, 51.52248412370682, 52.2071997821331, 56.091856732964516, 56.2992800027132, 58.21775525808334, 57.87087567150593, 61.26965269446373, 59.78702165186405, 67.4827829003334, 70.12928009033203, 76.32796347141266, 72.33608767390251, 73.30899506807327, 1.032442837022245, 18.50936159491539, 79.73951920866966, 42.66666792333126, 45.98111227154732, 38.66112045943737, 33.93716834485531, 50.848373696208, 35.28101183474064, 0.15481718553928658, 0.07619812764460221, 0.0880918902112171, 0.007115007347238134, 0.03639736743934918, 0.017062294209608808, 0.05401625756348949, 0.040854428079910576, 0.0021318778772183578, 0.01918027235660702, 0.056353403051616624, 0.033173867559526116, 0.13209545868448913, 0.04628362425137311, 0.02676775086001726, 0.10500027783564292, 0.023216062145365868, 0.17000314488541335, 0.48112685792148113, 20.01489970833063, 78.30675289034843, 44.63032655417919, 36.07394568622112, 56.17387153208256, 49.3190735578537, 56.75104156136513, 82.12883859872818, 5.515938866883516, 0.473178070387803, 74.52596336603165, 76.61770552396774, 82.01359838247299, 71.15777090191841, 75.70840671658516, 69.62934851646423, 66.46731778979301, 62.44917020201683, 63.84713038802147, 59.7121998667717, 55.604365691542625, 55.325586050748825, 53.0416464060545, 52.76074267923832, 52.40718685090542, 51.453263238072395, 50.99661514163017, 50.198627561330795, 54.0103854238987, 50.85726521909237, 51.76078833639622, 52.85328671336174, 51.36248990893364, 49.212660267949104, 51.77779622375965, 49.570460468530655, 47.23570995032787, 45.10650560259819, 46.58754453063011, 48.01311403512955, 51.27977214753628, 54.67803619801998, 51.557210460305214, 51.17604151368141, 46.56088896095753, 55.70705138146877, 59.541053250432014, 59.04415011405945, 59.38504882156849, 58.448224291205406, 61.583534851670265, 61.325300708413124, 59.79806385934353, 58.50425988435745, 59.97648328542709, 56.63437262177467, 61.80151775479317, 58.65198075771332, 63.07845823466778, 59.33084473013878, 62.96366259455681, 51.21418386697769, 44.4338770955801, 46.182197481393814, 48.65087181329727, 44.212922751903534, 43.8104597479105, 41.3212551176548, 43.132055550813675, 45.39272144436836, 48.370389863848686, 48.4532368183136, 55.976263135671616, 54.37068589031696, 56.12490735948086, 52.39388756453991, 53.925102800130844, 48.60922984778881, 45.930996760725975, 42.72283650934696, 46.68139949440956, 50.65687157213688, 57.899693325161934, 54.446928799152374, 51.85605302453041, 54.667757749557495, 52.98612378537655, 48.720161095261574, 45.3363286703825, 43.74240159988403, 42.56031543016434, 44.098153710365295, 40.66101394593716, 42.94129058718681, 42.38770969212055, 42.67818510532379, 43.617745488882065, 50.42989455163479, 57.914759516716, 60.76503597199917, 55.57524025440216, 55.264891907572746, 48.07162329554558, 50.74715092778206, 57.456477507948875, 57.42767505347729, 60.275037065148354, 59.877680987119675, 61.19392655789852, 59.39356416463852, 57.418376952409744, 58.48487712442875, 56.84668242931366, 59.50511857867241, 50.45591555535793, 53.37645784020424, 53.83352771401405, 49.2659068107605, 46.73607476055622, 44.31830629706383, 43.60511876642704, 47.89845898747444, 47.83812962472439, 48.85871306061745, 49.48695234954357, 48.42993646860123, 50.146954134106636, 51.267301216721535, 49.937957748770714, 51.48498013615608, 50.948578119277954, 55.208130553364754, 52.06522420048714, 53.41023422777653, 52.33200028538704, 54.64664988219738, 55.95171645283699, 59.87868033349514, 61.400806456804276, 62.256353348493576, 61.83821238577366, 65.53493142127991, 62.625788524746895, 72.76609539985657, 72.21884876489639, 81.9426941871643, 76.09830379486084, 78.9906857907772, 1.449339366517961, 23.334306590259075, 84.5257043838501, 49.76959638297558, 53.78041036427021, 46.15674264729023, 35.188190415501595, 58.833162635564804, 42.98645876348019, 0.17465105251176283, 0.07945983699755743, 0.1210522567271255, 0.024526472298020963, 0.06560513473232277, 0.03436085855355486, 0.04842977061343845, 0.09205187889165245, 0.060456077044364065, 0.17726299673086032, 0.09193048579618335, 0.13983279350213706, 0.14972271281294525, 0.2461815017159097, 0.15200386696960777, 0.28501415625214577, 0.2598131663398817, 0.3196182759711519, 0.7831461110617965, 32.69031465053558, 87.69395917654037, 69.04335156083107, 44.22758236527443, 64.16340261697769, 63.086069226264954, 61.21272414922714, 86.7748112976551, 6.40219428576529, 0.5261575290933251, 77.08085507154465, 80.02848610281944, 82.84237191081047, 74.25419434905052, 78.52262690663338, 71.63224384188652, 70.5986613035202, 64.9672418832779, 65.87963372468948, 61.42158754169941, 57.95976050198078, 58.085982128977776, 55.7508060336113, 55.568503215909004, 53.29583376646042, 51.85417592525482, 53.512121960520744, 51.56815007328987, 57.69364558160305, 53.60922954976559, 55.61588667333126, 54.262840077281, 53.11733454465866, 51.38241603970528, 52.895479649305344, 52.33238786458969, 50.36556780338287, 47.41540610790253, 48.38698737323284, 51.10787317156792, 55.90834178030491, 56.49657681584358, 54.73552331328392, 51.43223516643047, 46.96906305849552, 58.0583082139492, 62.045377269387245, 59.82635714113712, 61.24100603163242, 58.961911126971245, 62.75011405348778, 64.92367342114449, 63.0789066106081, 58.939256742596626, 62.24398881196976, 58.31952899694443, 63.91846776008606, 62.15076841413975, 65.5879233777523, 60.599395260214806, 66.32142841815948, 55.955656841397285, 51.1714855581522, 47.57429838180542, 47.55240395665169, 48.50183241069317, 47.751482874155045, 44.77375365793705, 45.40564075112343, 46.99701815843582, 53.64910840988159, 54.0314856916666, 59.360433742403984, 59.176599606871605, 61.79843612015247, 54.07874375581741, 58.97037327289581, 50.766305699944496, 47.20044404268265, 46.93425312638283, 50.092518255114555, 56.286501288414, 64.02481645345688, 57.06137090921402, 57.65284337103367, 59.68440055847168, 56.85132957994938, 50.42335130274296, 48.470392897725105, 46.98532998561859, 44.53355334699154, 45.89392974972725, 42.45641380548477, 45.944793820381165, 45.9160103648901, 43.27278479933739, 46.356642320752144, 52.17777796089649, 58.06597240269184, 63.39048229157925, 58.132837414741516, 58.84887099266052, 52.39172928035259, 52.608864828944206, 58.05064022541046, 59.10264417529106, 61.67349502444267, 61.68357968330383, 63.75647485256195, 62.668904811143875, 59.733455926179886, 61.831083968281746, 58.288655653595924, 60.516840890049934, 52.198437452316284, 53.50058197975159, 55.99690742790699, 51.82126969099045, 48.73202785849571, 47.11174540221691, 45.444242879748344, 50.60783140361309, 49.72011163830757, 50.05310297012329, 51.249130591750145, 50.19370302557945, 51.68424904346466, 52.933435812592506, 51.74505718052387, 52.05921672284603, 55.37730127573013, 58.39557811617851, 54.22441653907299, 55.290111154317856, 53.06115075945854, 57.6956594735384, 58.086924478411674, 63.7659515440464, 62.413896694779396, 64.91998001933098, 64.1432636976242, 69.0319673717022, 64.56410631537437, 76.76811665296555, 76.5062727034092, 85.49211412668228, 76.87314301729202, 83.70722070336342, 1.8850847845897079, 22.851857878267765, 93.30101430416107, 56.97875954210758, 62.3876591026783, 53.984873592853546, 46.660857796669006, 68.86850774288177, 54.99259851872921, 0.2732786047272384, 0.1774611946893856, 0.24015855771722272, 0.11448183780885302, 0.19024255103431642, 0.13591728173196316, 0.0870621825743001, 0.15905618463875726, 0.17221239977516234], [0.04629096409189515, 0.05482096457853913, 0.06259915462578647, 0.025709199653647374, 0.028921489392814692, 0.08730696514248848, 0.061096606150385924, 0.15609715279424563, 0.1202031878347043, 0.2633286011405289, 8.187078684568405, 60.2935154736042, 38.967790603637695, 26.75634976476431, 35.698164850473404, 49.56245429813862, 38.6494816839695, 77.99688711762428, 4.342578928917646, 2.2869963431730866, 78.3893832564354, 69.55148309469223, 73.56355100870132, 66.46746978163719, 68.2094407081604, 59.36064273118973, 58.63160625100136, 57.36037686467171, 55.26535168290138, 50.79977810382843, 49.37763221561909, 49.2103385925293, 49.83061730861664, 49.91308808326721, 49.29200381040573, 49.305409491062164, 47.68833786249161, 47.01477840542793, 52.72657871246338, 53.92316110432148, 56.15241028368473, 53.06277707219124, 52.635885179042816, 47.474641129374504, 47.70151175558567, 44.25939045846462, 44.57130432128906, 43.69111955165863, 42.00564779341221, 44.337434470653534, 48.59058424830437, 50.01756347715855, 51.34023830294609, 51.38572186231613, 48.95502649247646, 52.847408428788185, 58.709209486842155, 59.489850997924805, 56.68951906263828, 55.59095241129398, 57.36137241125107, 56.560318395495415, 57.14123882353306, 55.41099026799202, 55.72200357913971, 54.78847727179527, 56.12707704305649, 55.26378236711025, 55.46591252088547, 56.04636177420616, 59.21856835484505, 49.330845326185226, 44.12758693099022, 37.712330371141434, 38.246566504240036, 40.91769017279148, 41.10494792461395, 41.500419303774834, 41.981994062662125, 45.277481228113174, 41.54939487576485, 48.02352547645569, 48.96805219352245, 48.454904928803444, 54.77344147861004, 48.92396315932274, 46.85032702982426, 48.00560183823109, 44.99671049416065, 44.65411327779293, 41.80556192994118, 46.20175503194332, 52.496349066495895, 47.64805242419243, 45.01969166100025, 47.666451036930084, 46.53824597597122, 45.36177970468998, 42.802305445075035, 42.527667582035065, 41.8476864695549, 41.213633492589, 39.11981284618378, 41.13177068531513, 41.025099009275436, 42.27165251970291, 44.19766657054424, 55.36383479833603, 57.76197351515293, 59.43258047103882, 55.63852205872536, 53.65559846162796, 49.24801357090473, 45.79608500003815, 55.467006862163544, 55.870419815182686, 56.592586264014244, 55.08721724152565, 56.76162779331207, 58.87489579617977, 55.20421676337719, 57.41831995546818, 58.58712583780289, 56.12550012767315, 47.13260628283024, 48.392744064331055, 48.972691744565964, 45.882359370589256, 43.211083710193634, 40.92288829386234, 42.48649299144745, 46.18405178189278, 46.178675070405006, 45.86261942982674, 45.44731691479683, 48.89414235949516, 48.67656223475933, 50.0457389652729, 49.017096161842346, 48.966596871614456, 47.86614552140236, 49.69907596707344, 51.510047391057014, 51.40189379453659, 51.46549478173256, 49.81900133192539, 50.69506332278252, 54.57503892481327, 53.99542562663555, 58.458411544561386, 63.23553420603275, 61.48317463696003, 62.875412330031395, 65.34147620201111, 67.88056075572968, 73.64441826939583, 77.99404487013817, 67.34815612435341, 1.501073115505278, 28.74063938856125, 65.82092687487602, 35.3602147847414, 39.84494313597679, 45.66668674349785, 49.397755935788155, 59.060842618346214, 31.03525836020708, 0.15821634064195678, 0.05282377096591517, 0.07486627684556879, 0.030646376035292633, 0.03790486975049134, 0.013397620932664722, 0.04360998158517759, 0.03719526524946559, 0.059570446246652864, 0.07759132437058724, 0.05376977918785997, 0.018583865785331, 0.009122600768023403, 0.05405297903052997, 0.08967541070887819, 0.06257200686377473, 0.14762620499823242, 0.07007814783719368, 0.27154883660841733, 9.12532813847065, 72.07956343889236, 38.02267111837864, 31.221007592976093, 45.73084630072117, 53.60267870128155, 44.38681662082672, 86.80835589766502, 5.867377733811736, 2.568922690115869, 86.63690909743309, 71.6617226600647, 77.29851499199867, 67.94345498085022, 69.80264201760292, 61.82638742029667, 65.42789876461029, 60.52230879664421, 57.9036071151495, 55.04167288541794, 54.29432898759842, 55.162795186042786, 51.74004524946213, 51.40298813581467, 53.70234355330467, 53.23002129793167, 51.184260472655296, 52.40330345928669, 55.8328740298748, 57.07263730466366, 59.44317050278187, 57.50231444835663, 56.2245874106884, 51.97726272046566, 48.97156320512295, 47.61261932551861, 48.0966829508543, 47.64471620321274, 47.658125683665276, 46.143789142370224, 49.40798498690128, 51.92956767976284, 53.16304609179497, 52.52565309405327, 51.51170790195465, 55.380732491612434, 60.67693389952183, 61.23909093439579, 59.05849814414978, 60.1312717795372, 61.59534461796284, 59.895285442471504, 61.09703175723553, 56.35633014142513, 57.44040057063103, 55.61229586601257, 57.397789657115936, 55.96039518713951, 58.091624826192856, 58.994566574692726, 60.54600052535534, 54.26983170211315, 46.41490459442139, 44.21954199671745, 47.05195181071758, 44.53156225383282, 44.82967145740986, 42.77967385947704, 43.0113360285759, 47.44245305657387, 44.00076873600483, 48.914201483130455, 51.00400574505329, 52.860270738601685, 55.217899829149246, 53.59956666827202, 48.29068534076214, 47.97917805612087, 44.39325347542763, 45.00562101602554, 42.39031635224819, 50.21025873720646, 54.89531233906746, 49.90033596754074, 47.51440219581127, 51.48994266986847, 48.38453650474548, 48.93269509077072, 43.91523152589798, 42.99832172691822, 43.74435469508171, 42.43795819580555, 39.679427817463875, 41.175240352749825, 41.866427063941956, 43.04304152727127, 48.85920703411102, 57.54447318613529, 57.104825377464294, 59.18307065963745, 57.089595794677734, 55.33074617385864, 52.08378240466118, 46.47229291498661, 57.16782979667187, 59.05905291438103, 58.18627014756203, 57.074202820658684, 59.55763176083565, 59.51515384018421, 57.89102219045162, 56.497693955898285, 60.23189418017864, 58.603373765945435, 49.78409260511398, 50.95509096980095, 52.16782249510288, 48.491762951016426, 47.5348336994648, 43.157643377780914, 46.22278310358524, 48.90683747828007, 48.68517257273197, 50.155982449650764, 49.207481145858765, 51.75930641591549, 51.30358166992664, 54.046141505241394, 53.56135971844196, 52.14444614946842, 51.440632715821266, 52.041581869125366, 52.53973513841629, 53.648021668195724, 55.20502611994743, 53.771796226501465, 55.67437693476677, 58.184142261743546, 57.63362020254135, 63.23265016078949, 65.03382951021194, 66.80549204349518, 67.75964364409447, 71.06516987085342, 72.80335620045662, 76.29121944308281, 79.62857276201248, 69.84763160347939, 1.7252657166682184, 36.129377111792564, 72.89038673043251, 43.39819706976414, 49.7037573158741, 59.408189579844475, 49.44816403090954, 67.88648083806038, 38.8678939640522, 0.10727705332101323, 0.06471059445175342, 0.044783231714973226, 0.07064553457894363, 0.056459923507645726, 0.03156127713737078, 0.04934168086037971, 0.06625614667427726, 0.017619459722482134, 0.1849939045496285, 0.19529344484908506, 0.1896537162247114, 0.0961691583506763, 0.18675506551517174, 0.29813007276970893, 0.15175051259575412, 0.2885272161802277, 0.37596203852444887, 0.6478755071293563, 15.516015216708183, 82.20801874995232, 50.84678158164024, 40.14595538377762, 52.18145616352558, 65.10289460420609, 48.8420357555151, 95.4117402434349, 5.5500292126089334, 3.2439854415133595, 87.2232024371624, 73.6903578042984, 81.89111575484276, 72.34157457947731, 75.43401584029198, 64.37382772564888, 67.3085318505764, 63.697334825992584, 61.34464547038078, 56.01848267018795, 54.979474022984505, 57.42496199905872, 55.407042279839516, 54.83500577509403, 55.95330476760864, 54.45254109799862, 53.11228081583977, 53.37621845304966, 57.261031195521355, 58.248480409383774, 59.77195166051388, 58.8991042971611, 57.9596047103405, 53.155891075730324, 51.88458949327469, 49.356938526034355, 51.03340856730938, 48.61652545630932, 49.893203750252724, 49.78866755962372, 54.05106224119663, 54.699847027659416, 54.635402485728264, 56.681664884090424, 52.863143384456635, 55.90731583535671, 63.42880703508854, 66.64348393678665, 61.57538428902626, 61.588740572333336, 62.70637460052967, 60.763162672519684, 63.53376120328903, 56.55324697494507, 58.40833023190498, 57.76216350495815, 61.576425433158875, 60.23051105439663, 60.17718851566315, 62.508618012070656, 64.74201276898384, 57.10096098482609, 53.78902070224285, 47.48118817806244, 45.58551549911499, 46.57942816615105, 47.61020265519619, 45.577338337898254, 45.15691749751568, 51.54555268585682, 47.37852908670902, 52.49442256987095, 55.324385315179825, 57.25544169545174, 60.26228494942188, 56.18419177830219, 53.20442587137222, 49.9475522339344, 47.36921578645706, 44.99759204685688, 43.88700284063816, 51.92113593220711, 57.77538299560547, 54.9144671112299, 51.49705208837986, 57.239277362823486, 54.259553253650665, 53.26654493808746, 48.52050080895424, 47.05424688756466, 46.23068667948246, 45.86918547749519, 43.984961584210396, 45.241801142692566, 45.383066162467, 44.53850828111172, 51.58358484506607, 59.14913468062878, 59.25383046269417, 63.961922228336334, 61.340283304452896, 58.49878437817097, 54.51526813209057, 49.727129861712456, 60.56678161025047, 61.50041051208973, 61.588447988033295, 59.406510069966316, 62.04522147774696, 61.62594057619572, 60.15867590904236, 60.134292617440224, 61.77835039794445, 60.823343843221664, 50.91263584792614, 54.758835062384605, 54.326954036951065, 51.2922240793705, 49.53591652214527, 46.86887763440609, 47.873593121767044, 50.54025582969189, 52.28264473378658, 51.99080139398575, 50.38528874516487, 54.450755193829536, 54.60869751870632, 55.487012788653374, 54.58368346095085, 54.81702134013176, 53.884387984871864, 54.85623523592949, 57.129178270697594, 56.48257456719875, 57.58725889027119, 55.819027572870255, 56.91662907600403, 62.09459602832794, 60.32062701880932, 65.66985458135605, 69.18384522199631, 69.54256877303123, 70.65262600779533, 74.04402762651443, 72.05484196543694, 80.92826262116432, 83.57665210962296, 77.80894920229912, 2.398318494670093, 35.55374599993229, 81.57349079847336, 49.429176449775696, 55.50282374024391, 60.347464978694916, 69.20342937111855, 82.44237497448921, 47.83067062497139, 0.21680481790099293, 0.14366847986821085, 0.17043011728674173, 0.20403894275659695, 0.10548443271545693, 0.11551140443771146, 0.16935735766310245, 0.08041314053116366, 0.19812454527709633], [0.046998060133773834, 0.04245310694386717, 0.051879777674912475, 0.04014107573311776, 0.033058764165616594, 0.06710811736411415, 0.10395360470283777, 0.028841296625614632, 0.008732511250855168, 0.2098744796239771, 4.352676887065172, 61.458593755960464, 43.833171129226685, 35.385232642292976, 31.346628852188587, 53.11983101069927, 40.35749763250351, 76.98740288615227, 6.225688057020307, 2.6930221309885383, 83.6448660492897, 65.73298439383507, 74.76708322763443, 62.122133150696754, 62.10084669291973, 56.581559255719185, 55.85461266338825, 53.20262476801872, 53.4445121884346, 52.841723933815956, 50.62466450035572, 48.67421396076679, 51.40156701207161, 49.58933025598526, 49.36528667807579, 47.14736849069595, 49.47773024439812, 53.83089445531368, 60.671982765197754, 59.37557592988014, 63.40185508131981, 57.35808178782463, 54.975769221782684, 51.26044258475304, 48.34709711372852, 47.15553045272827, 47.104639783501625, 44.085735976696014, 40.887713581323624, 43.51986274123192, 47.149659767746925, 45.51206164062023, 50.77843464910984, 49.41887140274048, 49.713013619184494, 53.846572414040565, 58.09870384633541, 57.5142078101635, 56.28259889781475, 57.28352978825569, 59.36951145529747, 55.60071408748627, 57.952457293868065, 54.05843384563923, 56.16227075457573, 53.28005701303482, 55.52856355905533, 52.09510199725628, 56.29225417971611, 54.82131890952587, 58.024839609861374, 51.960828602313995, 42.6107083261013, 37.903232127428055, 36.30203224718571, 42.86695517599583, 39.87826354801655, 41.3961187005043, 41.472259014844894, 41.12352132797241, 42.57945500314236, 43.564605340361595, 44.598567858338356, 49.6185202896595, 48.963055461645126, 49.39081750810146, 45.80090694129467, 41.33462280035019, 43.21391075849533, 47.54295006394386, 43.700334057211876, 45.5481369048357, 46.988616809248924, 45.30875355005264, 41.65336109697819, 43.81988704204559, 42.14123971760273, 44.07868355512619, 41.661994233727455, 41.40961937606335, 42.12623052299023, 41.65429964661598, 38.731302693486214, 40.850600972771645, 39.95164521038532, 42.97740764915943, 54.83150616288185, 57.393465489149094, 53.40879410505295, 57.05799289047718, 56.39761112630367, 57.48540535569191, 54.1390161216259, 49.494973719120026, 53.0781814455986, 53.79336006939411, 54.620138704776764, 55.10439991950989, 56.836799159646034, 56.871495097875595, 54.898207783699036, 54.778301417827606, 56.09828598797321, 52.7731604129076, 49.33280222117901, 46.84112012386322, 46.81835934519768, 47.48233951628208, 42.87944510579109, 40.35264149308205, 46.3918512314558, 46.27355217933655, 46.39020971953869, 46.860392689704895, 47.08325833082199, 48.91211919486523, 52.53530837595463, 53.32719728350639, 53.8575804233551, 52.18770682811737, 52.666781321167946, 50.67219614982605, 49.45500746369362, 49.72634330391884, 50.49103707075119, 49.21992927789688, 49.40170392394066, 53.667617216706276, 57.69750617444515, 57.686471566557884, 60.79813599586487, 64.65395629405975, 68.39365482330322, 67.58144840598106, 69.94237571954727, 73.50860595703125, 79.0898984670639, 51.192981004714966, 1.6948371869511902, 41.962520107626915, 59.4328198581934, 44.66639801859856, 31.88432089984417, 20.734582990407944, 35.729011595249176, 52.547988295555115, 32.41150461137295, 0.1319480681559071, 0.04536696425930131, 0.10602256399579346, 0.03635669403593056, 0.051196556523791514, 0.011356918912497349, 0.013818135721521685, 0.08740949284401722, 0.061331573815550655, 0.02134265876520658, 0.0963462793151848, 0.044544479096657597, 0.05373863496060949, 0.06603437068406492, 0.04213596126646735, 0.01704407448414713, 0.03182626096531749, 0.09790229581994936, 0.2256218736874871, 4.680490521714091, 74.34615701436996, 46.480606868863106, 33.89166958630085, 45.00013031065464, 58.02783004939556, 45.523898005485535, 86.38796165585518, 7.838264526799321, 2.44557679630816, 89.01565745472908, 70.0827705860138, 80.21560326218605, 66.47690087556839, 63.741993829607964, 60.11606119573116, 58.75886522233486, 56.1559022963047, 55.19838787615299, 55.088516771793365, 54.84692573547363, 51.71151638031006, 54.00416135787964, 53.96482586860657, 53.36200341582298, 52.482730597257614, 51.5648328512907, 56.87239944934845, 62.56034083664417, 61.14248871803284, 65.31207337975502, 62.00831025838852, 59.33426074683666, 54.102420285344124, 52.29352355003357, 49.10742491483688, 49.706018194556236, 48.04352380335331, 44.89644527435303, 46.177782118320465, 50.66025719046593, 46.32355369627476, 53.504533767700195, 53.69035519659519, 52.006251364946365, 55.18340528011322, 60.840279534459114, 59.08824294805527, 60.016795322299004, 59.22940917313099, 62.18709446489811, 59.396623000502586, 61.11283130943775, 57.970935702323914, 56.76750227808952, 56.677044332027435, 56.222208738327026, 54.63728718459606, 60.16996890306473, 57.74559259414673, 59.010996893048286, 54.80638191103935, 45.18292710185051, 45.618550926446915, 48.1673439592123, 44.34860587120056, 41.53501644730568, 41.83875694870949, 44.38219226896763, 42.59453259408474, 45.25848984718323, 44.723516553640366, 47.71145582199097, 54.924027398228645, 53.09732101857662, 51.474716886878014, 48.1374167650938, 42.29172684252262, 44.61222432553768, 48.974424451589584, 43.27649340033531, 46.70203998684883, 51.016681864857674, 48.34339611232281, 45.50955377519131, 46.932877600193024, 46.13848842680454, 46.84013977646828, 44.51043538749218, 43.42722371220589, 44.43356931209564, 42.92375832796097, 38.91026549041271, 43.47081117331982, 41.65305711328983, 45.2164451032877, 58.12160901725292, 58.87435242533684, 55.74982188642025, 58.446286395192146, 56.505548134446144, 56.52753375470638, 56.226118728518486, 53.28970089554787, 55.684131011366844, 56.23485445976257, 55.75411565601826, 56.61400571465492, 59.035057201981544, 57.60154992341995, 58.3875947445631, 58.04408177733421, 59.12731625139713, 57.40958422422409, 52.34764784574509, 49.80947904288769, 49.102340787649155, 48.72097045183182, 46.254735589027405, 44.3602142482996, 47.458708584308624, 49.305333495140076, 49.255202785134315, 49.43666584789753, 51.74929015338421, 51.02113902568817, 57.45593413710594, 57.637062817811966, 58.85729894042015, 56.667294055223465, 57.586700320243835, 54.6720477193594, 52.7414321154356, 54.54009220004082, 55.525052547454834, 55.45054614543915, 54.847803488373756, 57.961667999625206, 61.806404292583466, 61.72781690955162, 65.38355514407158, 69.63143840432167, 70.55806428194046, 73.13534438610077, 74.33669552206993, 77.09699660539627, 83.62636864185333, 54.09072831273079, 1.5375752630643547, 49.39098469913006, 65.8615542948246, 51.59851424396038, 33.58743131160736, 21.031326167285442, 42.12847240269184, 68.02665531635284, 36.58143125474453, 0.04620451130904257, 0.0876581048942171, 0.07884216975071467, 0.05115558626130223, 0.07214994213427417, 0.019952541952079628, 0.02795813346892828, 0.054851066088303924, 0.039135829283623025, 0.10424428910482675, 0.16233028785791248, 0.13927410473115742, 0.14159376150928438, 0.1496441787458025, 0.18910800019511953, 0.1491451883339323, 0.18875801819376647, 0.44334334786981344, 0.4375242273090407, 8.503425009548664, 85.60793951153755, 57.39334389567375, 49.21097695827484, 47.5198283046484, 71.0804982483387, 53.13346467912197, 92.48345017433167, 7.773924479261041, 3.2416756404563785, 93.80456328392029, 71.90959855914116, 80.92311009764671, 67.96151161193848, 67.33530521392822, 61.35564208030701, 60.81758335232735, 57.54212111234665, 57.63710081577301, 58.3893920481205, 58.20569850504398, 54.116346538066864, 57.189720422029495, 55.710801780223846, 55.24059981107712, 53.296232745051384, 53.29474702477455, 57.31235884130001, 64.30642694234848, 63.130857422947884, 68.35344538092613, 62.30921231210232, 59.816891849040985, 55.94087563455105, 54.308988600969315, 51.73035576939583, 52.73875705897808, 48.781698793172836, 46.57301411032677, 50.20718850195408, 53.55732053518295, 49.339265674352646, 58.179837092757225, 54.85121950507164, 53.94147232174873, 56.11034274101257, 63.82581353187561, 61.33012644946575, 60.28657324612141, 61.65609195828438, 64.1982239484787, 60.899757742881775, 61.85064151883125, 59.87750619649887, 62.05505155026913, 59.232175424695015, 60.04508480429649, 57.587737664580345, 63.123364225029945, 61.28847688436508, 63.5455671697855, 57.12771154940128, 49.259618148207664, 47.71648295223713, 44.24900941550732, 48.58519993722439, 43.44862796366215, 43.17436248064041, 45.94317890703678, 46.6798909753561, 48.69906462728977, 49.380425065755844, 51.122175604104996, 58.891063928604126, 57.298026010394096, 56.11453391611576, 49.832167625427246, 43.853598833084106, 46.22390404343605, 49.570992439985275, 45.11663965880871, 50.53547568619251, 53.62264283001423, 50.95827519893646, 50.58985456824303, 51.8169417232275, 49.49004918336868, 51.474640890955925, 49.08091373741627, 46.021713092923164, 46.6251815110445, 45.76274938881397, 43.0922032892704, 48.542741015553474, 44.3838831782341, 47.792102694511414, 60.22648707032204, 61.49238534271717, 56.61009572446346, 61.53684675693512, 60.41961930692196, 62.47532419860363, 59.89026591181755, 55.38235120475292, 56.98407545685768, 59.59176152944565, 59.043804332613945, 60.535106509923935, 59.448699206113815, 60.49886405467987, 60.063247829675674, 59.97745223343372, 60.420018285512924, 58.05941015481949, 54.82648283243179, 51.61957271397114, 51.94806508719921, 53.76192815601826, 47.04814821481705, 45.17233707010746, 50.51444001495838, 51.89148232340813, 51.03367455303669, 52.915736362338066, 53.77398870885372, 53.47433678805828, 59.265336245298386, 60.747549310326576, 58.60891006886959, 57.572439685463905, 59.12211433053017, 57.03386418521404, 55.75504660606384, 56.923005133867264, 57.83978193998337, 58.42280365526676, 54.43647176027298, 61.83594770729542, 66.71245783567429, 65.42444854974747, 66.2934923171997, 72.33763799071312, 72.36115872859955, 75.72974637150764, 76.14619642496109, 84.72271621227264, 84.06043455004692, 64.09202724695206, 2.7956427494063973, 51.651555597782135, 74.80439722537994, 59.7096312046051, 47.22236126661301, 32.90278784930706, 52.78737165033817, 72.56954714655876, 50.53854212164879, 0.165199579205364, 0.257997932494618, 0.1702699321322143, 0.13049270171904936, 0.3156366536859423, 0.11221883658436127, 0.12576324690598994, 0.16425221285317093, 0.1991905365139246], [0.03538091455993708, 0.049766530719352886, 0.018592845772218425, 0.014176320310070878, 0.09869654226349667, 0.03232487288187258, 0.06271909311180934, 0.011761763253161917, 0.028393065404088702, 0.06301176646957174, 1.7531046853400767, 51.643477231264114, 47.23158337175846, 49.02221068739891, 23.012009784579277, 43.68769593536854, 40.96052907407284, 77.53080412745476, 14.543408006429672, 1.0199374705553055, 76.02677643299103, 66.30158588290215, 73.33140626549721, 67.87299916148186, 63.5700910538435, 60.67411445081234, 57.08513103425503, 51.30196675658226, 52.89353795349598, 51.45445637404919, 51.93121679127216, 50.40420413017273, 51.78960978984833, 47.7344673871994, 49.970389008522034, 47.42306649684906, 57.19791658222675, 58.94876383244991, 64.75324496626854, 64.10193711519241, 64.7883702814579, 59.49884511530399, 57.5913018733263, 53.25082518160343, 48.765105083584785, 47.626431584358215, 45.594635009765625, 45.623817443847656, 41.18431806564331, 42.46162332594395, 47.30798587203026, 47.452218532562256, 46.90735436975956, 51.35074093937874, 48.45371559262276, 51.42048999667168, 59.37236130237579, 59.516992941498756, 57.51648388803005, 57.673316672444344, 60.7182414829731, 56.449105963110924, 55.53170219063759, 55.72932958602905, 57.510928586125374, 54.94107328355312, 53.10067243874073, 54.68698091804981, 51.955459490418434, 53.691909313201904, 55.130645111203194, 54.74440723657608, 46.6034010797739, 37.730159014463425, 34.69328977167606, 42.350118309259415, 40.27283437550068, 43.007768020033836, 39.31816980242729, 42.88634553551674, 40.000096410512924, 44.51119914650917, 41.17004983127117, 46.165417581796646, 46.26648835837841, 47.66701340675354, 41.97654515504837, 44.755013063549995, 43.521713241934776, 48.27206254005432, 46.35321490466595, 44.72143426537514, 49.683318212628365, 41.378008872270584, 38.195235058665276, 39.65275704860687, 44.938178434967995, 41.255024671554565, 37.93032847344875, 42.08563730120659, 40.61892360448837, 41.368482783436775, 41.52579814195633, 38.58138173818588, 41.36383943259716, 50.24750053882599, 54.5860393345356, 54.84079286456108, 54.36563976109028, 54.75791171193123, 55.391375720500946, 52.76806868612766, 50.58287434279919, 51.40215218067169, 50.32077580690384, 54.10970449447632, 53.99614378809929, 53.33684116601944, 55.273251459002495, 56.17242380976677, 53.96660417318344, 57.22855433821678, 58.80260847508907, 52.696210741996765, 49.30820994079113, 48.57033893465996, 47.192920446395874, 43.280456587672234, 43.041339218616486, 40.30374951660633, 44.10101495683193, 46.183124631643295, 47.40508586168289, 46.29716031253338, 48.460437431931496, 52.83834211528301, 56.82858020067215, 56.39550223946571, 58.48050735890865, 57.89887636899948, 58.277396857738495, 57.17007167637348, 54.45917934179306, 52.18149036169052, 50.56229084730148, 52.23178446292877, 51.24244675040245, 53.167742639780045, 56.880876794457436, 62.18810901045799, 69.06812623143196, 68.00434291362762, 69.28501099348068, 73.09519574046135, 75.76516047120094, 69.52704280614853, 85.54378375411034, 34.232306107878685, 0.6746425770688802, 55.315638184547424, 56.28647468984127, 39.35444265604019, 37.64653690159321, 71.4073035120964, 36.03695087134838, 60.69759339094162, 22.24035669118166, 0.08415439602686092, 0.13776892534224316, 0.049919249868253246, 0.029875735453970265, 0.02670594480150612, 0.053305480469134636, 0.01404750109941233, 0.050759090154315345, 0.09409285921719857, 0.020744665853271727, 0.03449315750913229, 0.03400346991838887, 0.05918811402807478, 0.04129486304009333, 0.04382662562420592, 0.04642579748178832, 0.027231322274019476, 0.03973069033236243, 0.03592512402974535, 1.6947123873978853, 61.576212644577026, 47.12416313588619, 52.24279627203941, 36.51085764169693, 48.7821851670742, 48.14630828797817, 85.20233407616615, 18.359486237168312, 0.678378192242235, 79.38996836543083, 70.4753503203392, 77.93930500745773, 70.82507595419884, 67.61867880821228, 65.2509194612503, 60.74751131236553, 54.510848969221115, 56.41301929950714, 54.99642111361027, 54.99281890690327, 53.63078959286213, 55.09675092995167, 50.66238507628441, 53.8903346657753, 50.954650193452835, 59.490914940834045, 63.78619685769081, 68.64691123366356, 65.92881828546524, 70.33028170466423, 61.78968518972397, 60.064817145466805, 56.54143340885639, 51.19620703160763, 49.966068640351295, 48.6625599861145, 48.20428557693958, 46.52856029570103, 46.6780024766922, 49.1744989156723, 48.76591444015503, 49.237210750579834, 52.279893681406975, 51.741705760359764, 54.971688240766525, 59.75140996277332, 58.7282844632864, 58.537215515971184, 59.94426481425762, 61.9918267428875, 59.46041397750378, 58.965881913900375, 60.55412068963051, 59.27653804421425, 56.39407351613045, 55.17202489078045, 55.60745112597942, 56.1933758854866, 55.54873667657375, 58.489554673433304, 57.61469341814518, 49.46877032518387, 44.075472727417946, 48.399226516485214, 44.94695596396923, 41.02014787495136, 44.201416969299316, 42.771614491939545, 46.326946914196014, 43.02841231226921, 46.22760124504566, 45.09396627545357, 49.169228598475456, 49.514953047037125, 49.83881726861, 42.513167560100555, 46.1829574406147, 43.63806679844856, 47.208271622657776, 46.53875134885311, 45.212481915950775, 49.79570858180523, 44.28516827523708, 42.88205936551094, 42.3384415358305, 48.32087092101574, 42.62377582490444, 41.171330362558365, 42.42978863418102, 43.185385689139366, 43.19759823381901, 40.60298725962639, 40.80450564622879, 42.1368433535099, 51.634498313069344, 55.730351731181145, 58.64900931715965, 56.889802515506744, 58.25995199382305, 58.71243931353092, 54.10523973405361, 52.410941049456596, 53.55777271091938, 52.27623447775841, 56.607310473918915, 56.55763193964958, 57.04958774149418, 57.26270690560341, 59.43326063454151, 55.8479668200016, 58.53796027600765, 60.3976146876812, 56.119021475315094, 52.932953238487244, 50.345615074038506, 49.23008233308792, 48.05582754313946, 44.78971280157566, 43.1801837682724, 47.68127404153347, 49.30349059402943, 49.24669124186039, 49.94270369410515, 51.976821944117546, 58.159504383802414, 60.4717069119215, 60.402847006917, 62.31885999441147, 60.76315887272358, 63.55032831430435, 61.746891885995865, 58.32066513597965, 56.3973793387413, 55.85742451250553, 53.206287771463394, 55.419346019625664, 57.80265033245087, 60.79187013208866, 67.29024723172188, 72.40342766046524, 73.79739806056023, 74.34713736176491, 75.35779193043709, 79.49302643537521, 73.50862875580788, 91.15113526582718, 35.75077682733536, 0.4119901021476835, 64.32411879301071, 61.75512604415417, 45.885737389326096, 41.95578686892986, 83.85638549923897, 42.09018565714359, 68.90460580587387, 26.78104653954506, 0.16272574866889045, 0.20910585211822763, 0.07582698701298796, 0.01630145368835656, 0.04163567580690142, 0.06311505116173066, 0.03785961729590781, 0.060749121475964785, 0.030124564582365565, 0.15310646092984825, 0.08373532749828883, 0.10218272902420722, 0.16187489120056853, 0.3209990565665066, 0.16073431412223727, 0.13859282800694928, 0.1321410117088817, 0.23517988971434534, 0.16719730716431513, 3.5475421277806163, 76.03526517748833, 60.66878333687782, 65.88999196887016, 33.84667620062828, 62.11976207792759, 51.99015162885189, 92.65683487057686, 17.408389672636986, 1.6874960996210575, 85.62189236283302, 71.19494810700417, 82.1406863629818, 74.40763011574745, 69.21371921896935, 66.3888368010521, 63.180414363741875, 56.28501936793327, 61.012049317359924, 57.74387888610363, 57.070517018437386, 55.154048055410385, 58.588041588664055, 53.15445855259895, 55.995881482958794, 51.93173736333847, 61.41043893992901, 66.35147720575333, 70.94361439347267, 68.97551000118256, 72.88441345095634, 64.08390328288078, 61.075395718216896, 58.01446996629238, 52.308019772171974, 51.94081887602806, 49.761765003204346, 50.6522586196661, 46.95220336318016, 50.91886751353741, 53.89602296054363, 51.0570053011179, 52.619367465376854, 55.67750036716461, 51.576315835118294, 56.96589343249798, 60.76640009880066, 62.27133974432945, 62.02047720551491, 62.663801684975624, 66.89682394266129, 60.78029215335846, 62.65093557536602, 62.77055315673351, 64.40086707472801, 57.147314697504044, 58.798915073275566, 60.130150839686394, 58.27420882880688, 59.232878386974335, 61.6469382494688, 59.60470363497734, 54.95098315179348, 44.59441468119621, 43.33323955535889, 45.54270699620247, 45.04346698522568, 46.005848944187164, 43.531349524855614, 48.77655386924744, 45.574431493878365, 49.15605090558529, 49.260340109467506, 53.191445767879486, 53.43150548636913, 53.71272839605808, 43.00763122737408, 45.132321417331696, 43.277371153235435, 48.98675099015236, 46.92561998963356, 47.330894842743874, 53.31358261406422, 48.41055370867252, 44.211577624082565, 46.996584981679916, 52.27222569286823, 43.88791099190712, 41.99369743466377, 47.007148414850235, 44.69354376196861, 45.70672519505024, 45.58261625468731, 43.05758714675903, 44.931996166706085, 53.10336269438267, 56.933253183960915, 65.05371004343033, 60.10300129652023, 58.98180305957794, 61.54139131307602, 59.62193951010704, 55.08724384009838, 57.11215518414974, 56.5323480963707, 57.81575582921505, 59.220719039440155, 58.59798185527325, 59.52859751880169, 59.47647951543331, 57.96022407710552, 61.33496358990669, 64.2067962884903, 57.20084622502327, 54.58530217409134, 54.56157624721527, 52.079431638121605, 51.126723960042, 48.332426100969315, 45.206394642591476, 49.066702499985695, 51.897030025720596, 51.98521189391613, 52.69585736095905, 53.213226199150085, 61.002720817923546, 62.28727608919144, 61.45406439900398, 64.49584677815437, 63.82970452308655, 65.69438606500626, 65.2334176003933, 59.57451045513153, 58.46615552902222, 56.44707307219505, 56.9870924949646, 58.638582676649094, 60.860072672367096, 62.79383450746536, 70.66856995224953, 75.78130960464478, 75.97533479332924, 74.56646159291267, 79.42054152488708, 81.46768927574158, 77.28124111890793, 91.96316689252853, 52.90587589144707, 1.9316585292108357, 66.0605800151825, 70.34390017390251, 57.466793954372406, 50.93280516564846, 85.31784027814865, 50.348924696445465, 82.3843976855278, 37.155390456318855, 0.2302908434648998, 0.40953317773528397, 0.15668054023990408, 0.13278608646942303, 0.16973662481177598, 0.1478439214406535, 0.1339421299053356, 0.32279707258567214, 0.2496672357665375], [0.030856899211357813, 0.1087045892199967, 0.06338350824080408, 0.033728225898812525, 0.11739625173504464, 0.11787697047111578, 0.03622667718445882, 0.0660810740373563, 0.099036282626912, 0.02678474975255085, 0.21224182681180537, 37.90640115737915, 56.57173678278923, 27.69100271165371, 19.023578502237797, 37.42584094405174, 48.751042038202286, 71.81562960147858, 38.04265044629574, 0.01780563859938411, 58.87401804327965, 71.87144100666046, 69.58296820521355, 69.73954260349274, 66.19732707738876, 70.31667083501816, 65.59509739279747, 59.233942329883575, 54.04465198516846, 51.98075093328953, 52.12516598403454, 50.68117506802082, 51.15678034722805, 49.26747992634773, 46.50614909827709, 55.389650613069534, 61.29514552652836, 62.48538225889206, 62.14024677872658, 61.341164857149124, 63.1535080075264, 58.21438103914261, 58.880086317658424, 50.818792283535004, 48.15945938229561, 46.92440025508404, 47.296442091464996, 45.81881918013096, 42.05418638885021, 41.841644793748856, 42.61005096137524, 44.21221598982811, 46.9686146825552, 48.35001155734062, 51.45753800868988, 52.94983573257923, 55.99096454679966, 55.62734305858612, 55.93929871916771, 55.31830184161663, 57.1101450920105, 56.11956104636192, 58.19416232407093, 55.13732895255089, 55.815125182271004, 53.2374233007431, 57.73507095873356, 55.595876947045326, 53.95256772637367, 51.992796286940575, 55.0068249553442, 55.20453594624996, 45.11326164007187, 41.22538626194, 31.02580636739731, 44.85442332923412, 41.47434890270233, 42.39270642399788, 38.20067256689072, 42.82825045287609, 37.72479750216007, 41.680628433823586, 43.17635357379913, 43.96263778209686, 42.04603582620621, 45.61367578804493, 42.74709440767765, 43.3187585324049, 48.25544223189354, 42.50307910144329, 44.68728929758072, 44.603891372680664, 49.66963514685631, 39.89790089428425, 40.27406930923462, 41.332510113716125, 39.38443444669247, 40.5042989552021, 38.969067335128784, 41.498147025704384, 39.59154233336449, 39.83514346182346, 39.727312847971916, 39.684941321611404, 44.65748369693756, 51.23439118266106, 54.223793372511864, 55.418608859181404, 52.59021922945976, 53.30303817987442, 53.58141504228115, 50.943588986992836, 50.47829255461693, 49.88870099186897, 53.792075738310814, 55.28684712946415, 57.575673311948776, 54.306818917393684, 55.586134269833565, 55.92061132192612, 53.45902360975742, 56.84055335819721, 53.97643804550171, 51.83339104056358, 46.099525317549706, 43.52805130183697, 46.178675070405006, 44.13038358092308, 40.95251150429249, 42.78996750712395, 47.22583048045635, 46.98726408183575, 47.9455878585577, 47.842594385147095, 49.33080352842808, 54.049477726221085, 58.299032896757126, 56.55755214393139, 60.74999637901783, 60.63157193362713, 61.84491902589798, 61.81690692901611, 59.900559559464455, 59.12659049034119, 56.30237303674221, 51.19664780795574, 50.06062276661396, 53.54890778660774, 57.03282684087753, 62.537720650434494, 68.20554971694946, 70.89659571647644, 76.38251334428787, 70.43267101049423, 76.68135210871696, 67.16193571686745, 90.27319997549057, 14.756582267582417, 0.5862831277772784, 60.67235894501209, 55.288944616913795, 34.56535443663597, 65.67854851484299, 81.7333710193634, 29.088753908872604, 70.25734841823578, 14.992744345217943, 0.011891166905115824, 0.09410662605660036, 0.008323423680849373, 0.025027470219356474, 0.057003286929102615, 0.0327307460247539, 0.08141234589857049, 0.018010235726251267, 0.03215552591427695, 0.036414722562767565, 0.09147374585154466, 0.06335249388939701, 0.040570597411715426, 0.007321415778278606, 0.16245943639660254, 0.014369625660037855, 0.09363635675981641, 0.09415252789040096, 0.07095391178154387, 0.19892556010745466, 44.38150070607662, 64.69462931156158, 32.0188032835722, 28.79494607448578, 45.45314200222492, 54.30179178714752, 76.97386801242828, 45.753481686115265, 0.34389080945402384, 58.608142510056496, 77.20248654484749, 74.49326232075691, 72.80355378985405, 71.348307877779, 74.61859479546547, 71.3746328651905, 65.20511671900749, 58.79436291754246, 55.50390288233757, 58.014918342232704, 53.548360615968704, 53.13332028687, 52.57656276226044, 52.55030237138271, 58.91373731195927, 64.09679979085922, 63.92747327685356, 63.63600231707096, 64.66432973742485, 65.19333735108376, 60.972056463360786, 62.64725737273693, 54.433492720127106, 52.3743262141943, 51.09905004501343, 51.07961408793926, 47.635847479104996, 46.26517742872238, 46.298212856054306, 46.2566164880991, 47.92959451675415, 48.36026340723038, 48.909254148602486, 53.029426261782646, 56.316173896193504, 58.2268937677145, 57.77439504861832, 59.66602474451065, 58.29473912715912, 61.32079415023327, 59.19066645205021, 60.403443574905396, 58.773935213685036, 57.29538135230541, 58.23707342147827, 57.5155795365572, 57.97573484480381, 59.05725561082363, 53.335028663277626, 56.97588309645653, 58.05003985762596, 46.98060683906078, 46.00715607404709, 47.47572027146816, 48.67398977279663, 42.36591026186943, 43.66165593266487, 41.62925139069557, 43.484555035829544, 41.13690420985222, 43.128650933504105, 44.496170952916145, 45.337825790047646, 46.3785557448864, 47.76358902454376, 43.80395829677582, 41.745832934975624, 47.33784466981888, 44.375793412327766, 44.43636976182461, 43.142201006412506, 50.85854195058346, 43.96277077496052, 43.97636644542217, 44.728490486741066, 41.670817360281944, 41.863862201571465, 41.614409387111664, 43.559973388910294, 40.87412931025028, 41.519688069820404, 41.51213027536869, 42.63118162751198, 47.641360983252525, 54.333204701542854, 56.1306868493557, 57.5328154116869, 55.219852924346924, 52.900050804018974, 57.21878506243229, 53.02395835518837, 51.33641190826893, 56.735200211405754, 58.056560307741165, 57.112132385373116, 57.388115376234055, 57.31842331588268, 59.484835267066956, 58.1554614007473, 56.88263230025768, 59.50524017214775, 56.224146634340286, 52.173066213727, 48.73353257775307, 47.74324111640453, 47.60283105075359, 48.00821229815483, 44.6716683357954, 45.745274126529694, 49.808798879384995, 50.201636999845505, 48.97636994719505, 51.57866790890694, 53.49732555449009, 54.87244136631489, 61.10354460775852, 60.12395717203617, 64.33082163333893, 64.7139398753643, 65.1269169151783, 63.24686139822006, 64.01050642132759, 62.95057989656925, 59.658550545573235, 55.27569852769375, 54.60037216544151, 55.16124866902828, 60.80635875463486, 67.00552091002464, 72.64473751187325, 74.85320940613747, 80.81845611333847, 73.32070603966713, 80.97718879580498, 70.544293820858, 92.17216327786446, 15.915452633053064, 1.5257149119861424, 68.07545989751816, 61.102150082588196, 41.472354009747505, 73.59511211514473, 93.1075818836689, 32.43952050805092, 76.243706792593, 22.620153911411762, 0.06834121799329296, 0.045648939558304846, 0.05068514998129103, 0.019999705436930526, 0.0315668061375618, 0.07239263184601441, 0.015924012222967576, 0.041369389509782195, 0.02246318672405323, 0.08268942619906738, 0.15783089882461354, 0.1176766054413747, 0.16887874662643299, 0.18486085231415927, 0.3287970396922901, 0.07736743325949647, 0.1946062161005102, 0.2438527758931741, 0.18295218207640573, 0.34036258002743125, 54.59465727210045, 77.07865118980408, 40.27311936020851, 27.08755899220705, 55.23582726716995, 59.87555310130119, 85.18864721059799, 45.93795798718929, 0.5899353849235922, 69.7489432990551, 78.46404924988747, 78.54225665330887, 76.59242168068886, 75.35744994878769, 77.22065716981888, 72.69874781370163, 66.14730656147003, 61.04879714548588, 57.51951612532139, 59.6443735063076, 56.26431807875633, 57.240417301654816, 54.596659764647484, 52.8222081810236, 60.37681460380554, 66.35099083185196, 66.68122351169586, 67.09626004099846, 65.35486668348312, 68.7030266225338, 62.642887607216835, 64.18797969818115, 57.95645847916603, 54.32761900126934, 52.98867724835873, 53.389806523919106, 50.93226179480553, 48.18725109100342, 49.274083971977234, 47.19398818910122, 50.044994205236435, 51.43435925245285, 52.491770312190056, 57.06240825355053, 58.76620642840862, 59.278430342674255, 57.98209190368652, 60.40450371801853, 58.862823843955994, 62.22364090383053, 60.670671835541725, 64.68171760439873, 61.9558996707201, 61.0072235763073, 60.90866066515446, 63.4322876483202, 61.96191094815731, 61.860444992780685, 55.72142980992794, 59.26533244550228, 60.59850990772247, 53.479683101177216, 47.887040600180626, 36.814183965325356, 48.31707492470741, 45.14002740383148, 48.568355441093445, 44.104909747838974, 46.23693734407425, 42.32111446559429, 48.10222305357456, 50.73636710643768, 50.32923795282841, 50.73906496167183, 48.64862993359566, 44.52720768749714, 41.36380523443222, 47.5262575596571, 46.35562017560005, 44.21509623527527, 45.54217882454395, 52.799842581152916, 46.29514642059803, 48.603385761380196, 49.09887537360191, 43.762270733714104, 45.532481744885445, 44.48264367878437, 46.577805653214455, 43.34538750350475, 43.346451446413994, 44.4510255753994, 44.88867849111557, 49.74619723856449, 55.42796015739441, 57.79389560222626, 59.9017108976841, 57.55962677299976, 57.00573429465294, 60.712458193302155, 55.301172360777855, 54.55061763525009, 57.667795568704605, 59.268680065870285, 60.09515851736069, 63.272502422332764, 59.31831680238247, 61.41630582511425, 59.968363121151924, 60.07371246814728, 62.52468355000019, 57.57753141224384, 56.248928904533386, 51.86987668275833, 50.83489201962948, 50.66549710929394, 51.391942128539085, 48.3525650203228, 48.71921494603157, 53.81285302340984, 53.42413008213043, 53.61116744577885, 53.89311231672764, 54.595759212970734, 57.38482095301151, 63.94626706838608, 63.37664343416691, 66.44036963582039, 67.17800125479698, 68.32639843225479, 66.65249705314636, 66.97823837399483, 64.46869343519211, 60.57238630950451, 56.36201463639736, 56.74906566739082, 59.22836422920227, 62.82595798373222, 70.34548848867416, 74.19407397508621, 78.38007375597954, 80.87659299373627, 74.3194292485714, 85.03904163837433, 74.27197739481926, 97.5066590309143, 30.646584816277027, 2.153668384999037, 71.532491594553, 69.14804354310036, 50.609138533473015, 76.94778621196747, 91.4806991815567, 42.418609634041786, 93.14741134643555, 27.350398488342762, 0.17986811319133267, 0.24561083468142897, 0.14968097442761064, 0.18502747931052, 0.1470094357500784, 0.21917915611993521, 0.14778498007217422, 0.07511972027714364, 0.1526953259599395], [0.034765540549415164, 0.04033695448015351, 0.11503348359838128, 0.02895960980822565, 0.037368745979620144, 0.03379809910256881, 0.004613488672475796, 0.05304673068167176, 0.16007395111955702, 0.06314020254649222, 0.12074995771399699, 24.86325714737177, 55.36161191761494, 44.40682254731655, 31.693039163947105, 30.65884105861187, 48.924723118543625, 55.87801940739155, 65.29960244894028, 0.34616077202372253, 25.502242259681225, 79.07786831259727, 64.39120799303055, 75.01926049590111, 67.6620800793171, 70.85371121764183, 69.28097561001778, 66.97257667779922, 59.67245779931545, 53.54606173932552, 49.39595863223076, 50.461045280098915, 51.34805828332901, 46.832866966724396, 52.731875628232956, 59.55075792968273, 62.42537587881088, 63.44664327800274, 57.61964835226536, 63.25518295168877, 58.70295122265816, 59.90588307380676, 50.58229677379131, 48.83885532617569, 47.54653327167034, 48.15536320209503, 44.98562268912792, 45.909885093569756, 40.26960834860802, 42.71137252449989, 40.7997141033411, 42.90489614009857, 44.96465161442757, 47.53280460834503, 48.61122094094753, 52.528111562132835, 53.5284610837698, 58.541676476597786, 56.57769486308098, 55.744543969631195, 54.595949202775955, 57.0297110080719, 57.353746220469475, 53.86035807430744, 54.93947736918926, 57.123098596930504, 59.04838688671589, 57.79248967766762, 45.03886543214321, 49.62645426392555, 55.129364579916, 57.2374876588583, 45.24258770048618, 43.92856881022453, 31.723241843283176, 42.26078510284424, 43.204791247844696, 41.143914833664894, 39.509227350354195, 43.02469611167908, 38.701531291007996, 42.20821112394333, 41.81250035762787, 42.38677494227886, 44.31867487728596, 47.03694261610508, 38.95248122513294, 45.34214235842228, 46.96954943239689, 43.41758742928505, 44.296446070075035, 43.71805630624294, 47.44098633527756, 44.71637673676014, 40.1880457252264, 40.0360044836998, 41.1449483782053, 41.580632999539375, 37.13503874838352, 42.65122175216675, 37.457227259874344, 39.2524029314518, 42.029191330075264, 42.50249393284321, 52.07183204591274, 54.93967115879059, 54.880869314074516, 51.53865225613117, 49.808928072452545, 53.02887909114361, 52.58592166006565, 54.84126403927803, 53.390836268663406, 52.126423716545105, 52.368269339203835, 54.83347825706005, 57.13615469634533, 54.945207461714745, 55.17651624977589, 54.24761049449444, 53.975438699126244, 52.49775119125843, 52.46259547770023, 50.7820026576519, 45.277276039123535, 43.24291840195656, 44.24797587096691, 42.72925056517124, 42.512396201491356, 43.32145258784294, 43.34394358098507, 46.898911222815514, 46.79167717695236, 49.66468021273613, 54.444409534335136, 53.436259031295776, 56.12596370279789, 57.43932142853737, 58.03448349237442, 60.23776486515999, 62.099847346544266, 61.87041945755482, 59.69009645283222, 61.85997761785984, 62.22750149667263, 59.092373326420784, 52.49792978167534, 50.76345965266228, 59.89423669874668, 64.30262714624405, 72.1615782380104, 68.44886586070061, 71.81352451443672, 77.46090307831764, 76.00023105740547, 70.1531808078289, 76.26645997166634, 6.242581000551581, 1.9795591151341796, 74.60080415010452, 47.64827661216259, 47.07927614450455, 29.44981623440981, 39.99794952571392, 49.09257911145687, 64.54049438238144, 19.945640824735165, 0.32707570237107575, 0.24171800294425339, 0.06542286326293834, 0.12274820517632179, 0.06885439084726386, 0.07501819447497837, 0.07052426022710279, 0.07196829406893812, 0.02350903050682973, 0.04754739042255096, 0.023588262192788534, 0.0741914939135313, 0.05528861038328614, 0.05067387304734439, 0.0421023085800698, 0.027551412422326393, 0.09357276954688132, 0.12254881978151388, 0.0505140552559169, 0.09594885923434049, 28.83360330015421, 64.55447003245354, 34.59354892373085, 32.29076988995075, 40.07461801171303, 54.47552986443043, 62.027301639318466, 72.95939102768898, 0.8614729705732316, 25.90235508978367, 83.83878484368324, 68.2710126042366, 79.08756539225578, 72.26950764656067, 73.54124620556831, 71.64326325058937, 69.26009953022003, 64.71054285764694, 58.92507590353489, 53.75400938093662, 55.038530454039574, 54.4551857560873, 50.693475008010864, 56.53762601315975, 64.93136420845985, 66.71412214636803, 66.19244053959846, 59.87806856632233, 64.96726468205452, 62.814125418663025, 60.73181435465813, 52.537637650966644, 53.4834410995245, 51.086639910936356, 49.700272902846336, 47.22428396344185, 48.787219896912575, 44.91574823856354, 44.61460679769516, 43.81227605044842, 45.84971912205219, 47.15065151453018, 49.19455423951149, 51.00964464247227, 57.05311395227909, 55.38933143019676, 58.15821245312691, 58.94664354622364, 57.67188414931297, 58.74010182917118, 59.82144020497799, 61.74904637038708, 56.92450985312462, 57.76360362768173, 60.60381442308426, 60.88868133723736, 58.555180951952934, 49.674092307686806, 53.47479656338692, 58.27186435461044, 58.075973466038704, 50.09582407772541, 45.453350991010666, 50.02787232398987, 52.51772291958332, 42.16385990381241, 43.59849192202091, 40.77451005578041, 44.36472460627556, 41.16151548922062, 44.866594076156616, 42.26549685001373, 44.100501984357834, 45.458701103925705, 47.649215161800385, 37.72145368158817, 44.504146724939346, 45.820779874920845, 42.68434837460518, 44.35623586177826, 43.76384384930134, 49.493172615766525, 46.62918649613857, 43.01851764321327, 43.24077911674976, 41.91061109304428, 42.954601272940636, 40.07218234241009, 44.574427753686905, 40.60115195810795, 42.48445250093937, 43.00129696726799, 43.66699084639549, 53.655929043889046, 56.68625883758068, 57.08404429256916, 54.0566935390234, 52.57894903421402, 54.07338224351406, 55.09740449488163, 57.25765697658062, 53.64811286330223, 55.99518612027168, 55.634087696671486, 58.51991884410381, 57.93660834431648, 57.79643766582012, 57.64310449361801, 56.02689541876316, 56.7997245490551, 53.79090920090675, 54.36592474579811, 52.359343618154526, 49.64905545115471, 46.171470656991005, 45.44664815068245, 46.94093316793442, 46.29102744162083, 45.353294759988785, 46.820122450590134, 50.6191585958004, 51.03962503373623, 51.745680347085, 58.319270610809326, 57.73786760866642, 61.71864800155163, 61.92653104662895, 60.3181267529726, 61.46535739302635, 65.75990214943886, 64.87483844161034, 63.261296823620796, 64.442018866539, 64.47107210755348, 62.23389655351639, 58.033742532134056, 55.179259702563286, 60.76852798461914, 67.50771716237068, 74.92402240633965, 72.35121846199036, 77.8755596280098, 78.36814239621162, 81.27294972538948, 71.94720894098282, 78.77652168273926, 4.350774614140391, 2.954047224484384, 81.73086315393448, 51.52651570737362, 51.401897594332695, 41.32030516862869, 54.45461578667164, 53.31127233803272, 73.12952309846878, 26.005950830876827, 0.3974573069717735, 0.19478746340610087, 0.051393767425906844, 0.12837709102313966, 0.02159687217499595, 0.06436228228267282, 0.060549075569724664, 0.04333683042204939, 0.03607739046856295, 0.13776914798654616, 0.11288574532954954, 0.17959598248125985, 0.17524266295367852, 0.15308171772630885, 0.14644712529843673, 0.12614263279829174, 0.2524659043410793, 0.2745563752250746, 0.24172681965865195, 0.232264036021661, 40.32682187855244, 73.54661911725998, 60.67336209118366, 42.70977661013603, 45.81892177462578, 63.67132902145386, 66.36266380548477, 77.28972226381302, 0.8202499919570982, 32.94607512652874, 88.25674697756767, 73.32192197442055, 81.68702110648155, 75.27901455760002, 75.36444157361984, 76.10794767737389, 71.94953441619873, 65.97132280468941, 60.85397019982338, 54.75179024040699, 58.27127158641815, 57.66404137015343, 52.5246499478817, 56.63239672780037, 66.32543340325356, 67.96372309327126, 67.24787190556526, 59.76333752274513, 66.32247716188431, 64.7758461534977, 63.089827224612236, 53.09290565550327, 56.21178589761257, 53.20628397166729, 51.204881966114044, 48.671231120824814, 51.76769636571407, 45.327570140361786, 46.936206221580505, 46.23542122542858, 48.978961408138275, 49.13636416196823, 54.31956343352795, 53.22792761027813, 58.84786784648895, 56.566090285778046, 62.500684037804604, 60.61093904078007, 61.154423877596855, 58.9766201376915, 61.76677241921425, 62.97999031841755, 57.334203869104385, 58.470844477415085, 62.93692342936993, 66.158257573843, 61.777514442801476, 51.01493015885353, 56.17859087884426, 60.79620189964771, 61.58011883497238, 53.873756155371666, 48.44453528523445, 36.87447912991047, 48.03574562072754, 46.42859905958176, 46.276276633143425, 43.804642260074615, 47.12015055119991, 43.77436548471451, 46.304471120238304, 46.49101071059704, 48.70510630309582, 47.834918797016144, 48.692259192466736, 37.14219756424427, 43.51509019732475, 45.92702217400074, 42.84123815596104, 46.446674689650536, 42.90361940860748, 50.33792808651924, 49.02066417038441, 46.01207681000233, 46.4488709717989, 45.47422707080841, 43.928963989019394, 42.99637243151665, 46.969511434435844, 42.13194541633129, 42.79304914176464, 46.57868340611458, 46.05545528233051, 57.07088179886341, 58.306054919958115, 60.451917573809624, 56.65947027504444, 55.43345466256142, 56.51601277291775, 56.85388684272766, 60.952992886304855, 56.56051978468895, 57.289921045303345, 58.92359018325806, 62.425334081053734, 61.81814946234226, 60.59138149023056, 60.05985461175442, 58.9629864692688, 57.32497416436672, 58.22711415588856, 58.27001005411148, 54.79480393230915, 50.317933559417725, 48.17345403134823, 49.10648636519909, 49.157487228512764, 50.69963067770004, 48.158513233065605, 48.45903530716896, 51.082866713404655, 53.05344097316265, 54.241982996463776, 62.47073024511337, 57.99375347793102, 63.83067727088928, 63.948296159505844, 64.6476486325264, 65.88946759700775, 69.68794897198677, 67.07251891493797, 67.04237133264542, 68.99371102452278, 68.2939025759697, 64.90900620818138, 59.592084512114525, 58.645821288228035, 65.16426131129265, 68.53530362248421, 78.48622485995293, 74.19161930680275, 83.42198520898819, 80.10123699903488, 81.63774535059929, 73.78584668040276, 91.24597817659378, 15.45905627310276, 2.4532706709578633, 89.4269397854805, 59.559782445430756, 65.06379470229149, 44.12542104721069, 52.185001373291016, 62.526693642139435, 83.86888682842255, 32.61390455067158, 0.4795258672675118, 0.5312728858552873, 0.17210189398610964, 0.17416405520634726, 0.12548546103062108, 0.20798370998818427, 0.11353184425388463, 0.18053064326522872, 0.08498893366777338], [0.09132519015111029, 0.05297691313899122, 0.015494625986320898, 0.023851826663303655, 0.07103972631739452, 0.034228374061058275, 0.03242115541070234, 0.10696899524191394, 0.07152373276767321, 0.040118933757185005, 0.29591238708235323, 18.816708102822304, 57.10962451994419, 55.48418194055557, 56.06240451335907, 39.57622915506363, 45.15892758965492, 49.66384805738926, 76.74224764108658, 4.352940497919917, 4.882225971668959, 71.63084551692009, 57.90586419403553, 71.88981682062149, 66.4210894703865, 70.76883897185326, 66.88453540205956, 68.39453637599945, 61.9762247800827, 55.65431401133537, 49.65068556368351, 53.25136475265026, 49.72907915711403, 52.60955639183521, 58.25937442481518, 59.777780547738075, 59.86974321305752, 59.26803410053253, 61.450910568237305, 60.114571675658226, 58.58742982149124, 53.58361132442951, 44.627765491604805, 45.74472315609455, 48.48368838429451, 50.26751406490803, 46.71674519777298, 46.00147157907486, 43.39824266731739, 43.51520799100399, 42.144306153059006, 41.40156760811806, 42.905017733573914, 45.773453414440155, 50.576904863119125, 47.57823497056961, 48.96305926144123, 54.94152545928955, 56.664155423641205, 56.30960404872894, 55.34560717642307, 57.140421867370605, 56.06255270540714, 56.972269490361214, 54.99825641512871, 55.53794525563717, 58.894605338573456, 59.29705314338207, 45.278947949409485, 46.77351415157318, 55.04088632762432, 60.359111353755, 48.434230238199234, 44.09886047244072, 29.120320715010166, 41.723512932658195, 42.31205195188522, 40.047844648361206, 40.549079552292824, 40.4115991294384, 39.73137483000755, 38.51214945316315, 40.57644948363304, 41.429040133953094, 47.63683162629604, 44.26876835525036, 38.9920599013567, 43.663263246417046, 45.66073626279831, 43.274274319410324, 44.22617644071579, 41.800705790519714, 43.031098768115044, 46.190712824463844, 44.004796519875526, 38.945497199893, 39.10113304853439, 41.482704654335976, 40.50007738173008, 42.63964757323265, 41.82744115591049, 38.574276119470596, 42.65877194702625, 47.51797780394554, 53.30740034580231, 53.5449294000864, 54.5477107912302, 50.843935534358025, 49.99114729464054, 52.37917475402355, 54.49630714952946, 54.92566131055355, 55.99997766315937, 52.83432953059673, 51.007516756653786, 52.94638551771641, 56.0208423435688, 53.133434280753136, 52.67470769584179, 52.41147682070732, 53.93900625407696, 47.070631608366966, 48.86220507323742, 49.92875084280968, 43.916694447398186, 41.106065064668655, 43.66212710738182, 42.600034698843956, 42.22771167755127, 44.55463841557503, 44.885346069931984, 45.236527025699615, 47.715544402599335, 52.22562499344349, 54.21395570039749, 54.29494835436344, 59.81639787554741, 56.79638832807541, 58.178697153925896, 58.1833329051733, 61.98114551603794, 59.911955147981644, 60.12617625296116, 60.390159487724304, 63.97291123867035, 60.1242383569479, 58.99214990437031, 53.315706700086594, 54.985812082886696, 66.30790874361992, 70.16540855169296, 70.29460921883583, 67.65140265226364, 66.6278287768364, 78.33457499742508, 69.0524710714817, 52.38624997437, 0.8366287755779922, 8.810834214091301, 70.96109345555305, 45.661040246486664, 45.49294866621494, 37.45829880237579, 56.212827041745186, 36.26099444925785, 70.66170752048492, 17.08963617682457, 0.34907631401438266, 0.20619614340830594, 0.0449174676759867, 0.039385691852658056, 0.030481426292681135, 0.013258397739264183, 0.04710396460723132, 0.07777710619848222, 0.020614159184333403, 0.03417950363655109, 0.05673533451044932, 0.036185287608532235, 0.04409763940202538, 0.06988035805989057, 0.02881957210774999, 0.0899167126044631, 0.08742063248064369, 0.0805383334227372, 0.151903914520517, 0.30623480037320405, 23.69747020304203, 68.17036360502243, 48.475674614310265, 54.351128339767456, 44.800777807831764, 51.99731044471264, 54.956234470009804, 86.73825725913048, 5.969827361404896, 4.107896871864796, 73.86571079492569, 63.11383053660393, 74.60629105567932, 70.2248677611351, 75.40234833955765, 71.63646161556244, 72.17794016003609, 66.57328650355339, 60.38140095770359, 52.141824290156364, 56.958259642124176, 52.540544494986534, 56.55238062143326, 62.01127029955387, 64.39110159873962, 66.48918941617012, 61.31410650908947, 64.0364970266819, 63.39830607175827, 61.24278053641319, 58.18903259932995, 48.08067820966244, 50.06547890603542, 50.90929202735424, 52.62898474931717, 49.01026412844658, 49.377689212560654, 46.613778322935104, 46.317291632294655, 45.67306660115719, 44.26544353365898, 44.83688727021217, 46.89677193760872, 52.36400596797466, 52.06157639622688, 51.329796463251114, 55.609252229332924, 59.37509335577488, 56.89579099416733, 57.78675578534603, 59.353651106357574, 58.2815158367157, 61.01636588573456, 57.24644757807255, 57.14742869138718, 59.58789333701134, 59.27376799285412, 46.859750524163246, 47.686278373003006, 56.92028068006039, 62.06365808844566, 53.52631039917469, 43.81514869630337, 46.149329245090485, 56.40765018761158, 42.042270228266716, 40.84343075752258, 40.81007234752178, 42.15696707367897, 40.66123813390732, 42.091344594955444, 41.49666130542755, 43.580579683184624, 48.026557713747025, 44.69342216849327, 38.05484779179096, 43.53866793215275, 45.20140931010246, 43.605244159698486, 44.5908010751009, 39.72205013036728, 42.681061550974846, 47.40361534059048, 49.5013839751482, 42.30848014354706, 40.561960861086845, 43.386463299393654, 43.09751160442829, 44.28911246359348, 44.2838991433382, 42.63824164867401, 44.45523954927921, 49.345489740371704, 55.84201633930206, 53.63661468029022, 55.551198944449425, 53.370545357465744, 53.71029652655125, 54.22199606895447, 56.45021170377731, 56.8177355825901, 54.048011004924774, 53.1548423320055, 54.75621700286865, 58.77207711338997, 58.24925176799297, 53.689507842063904, 57.59279139339924, 56.4375925809145, 55.06690353155136, 49.67637978494167, 52.484729290008545, 50.35542994737625, 47.10696525871754, 45.686510279774666, 45.5838967859745, 43.43216724693775, 45.657586231827736, 47.35645607113838, 47.9366659373045, 48.355141282081604, 49.254078045487404, 52.74730660021305, 57.29507356882095, 58.73653382062912, 63.447695821523666, 61.71509899199009, 61.066751182079315, 60.698292553424835, 63.54781664907932, 62.08063177764416, 66.24857112765312, 65.4514043033123, 65.35097569227219, 62.49176971614361, 62.946251928806305, 57.964350655674934, 59.6286803483963, 68.73197346925735, 73.63811820745468, 73.49669739603996, 74.48727384209633, 70.78348338603973, 79.79361310601234, 72.59056001901627, 58.26056756079197, 0.5032065825071186, 10.954060759395361, 78.20886254310608, 50.3243438154459, 56.39588601887226, 45.44903062283993, 61.881058886647224, 40.96811346709728, 80.22752702236176, 21.307242661714554, 0.19952284055761993, 0.10818288908922113, 0.07083836680976674, 0.11145817974465899, 0.030156779357639607, 0.047137617293628864, 0.011373748038749909, 0.03466024463705253, 0.008867061696946621, 0.22725731483660638, 0.1517210344900377, 0.10977186437230557, 0.16074823681265116, 0.3362298564752564, 0.0965721816464793, 0.13318430806975812, 0.2789483161177486, 0.14978753199102357, 0.2014611373306252, 0.6908045941963792, 32.79359310865402, 77.8985483944416, 73.41787442564964, 76.91747903823853, 55.17099894583225, 64.19414296746254, 58.148142993450165, 94.30156901478767, 5.167238702997565, 7.693016845732927, 81.62150502204895, 67.42382526397705, 80.742247402668, 74.27345931529999, 77.45840281248093, 72.23469391465187, 76.06057941913605, 68.25516745448112, 62.02495716512203, 53.79004664719105, 59.15946252644062, 56.411427184939384, 57.74483263492584, 63.164371624588966, 66.63567915558815, 68.17353263497353, 62.66768887639046, 64.45926234126091, 67.7287209033966, 62.548569068312645, 59.89920683205128, 49.29899923503399, 51.05764366686344, 52.50795744359493, 55.5688413977623, 51.02165959775448, 51.084470227360725, 47.795104533433914, 51.123581528663635, 47.87652276456356, 47.3526106774807, 47.68848605453968, 49.89664636552334, 54.662388637661934, 52.56225273013115, 52.263231575489044, 59.365536868572235, 60.9953948110342, 59.284749403595924, 60.064741149544716, 61.331148594617844, 60.85868954658508, 63.251785933971405, 60.77636316418648, 60.63711203634739, 65.61978086829185, 64.81544002890587, 47.62374132871628, 51.90943256020546, 60.037584006786346, 66.40984207391739, 55.726536735892296, 49.209289848804474, 37.49527841806412, 45.57704955339432, 46.352424547076225, 42.916732504963875, 44.44021515548229, 43.346519842743874, 43.665999099612236, 44.132952243089676, 45.52959389984608, 45.457629561424255, 49.49242405593395, 45.26236563920975, 39.07955400645733, 44.211003854870796, 46.59215368330479, 43.98047022521496, 46.57330669462681, 41.9295796751976, 42.70582862198353, 49.70738612115383, 51.48325502872467, 44.18131984770298, 44.40888583660126, 46.17795690894127, 44.49978455901146, 46.33778013288975, 47.57519133388996, 44.052559956908226, 46.04067787528038, 52.648747488856316, 58.817701265215874, 56.01377472281456, 59.57146681845188, 58.07975046336651, 56.68033115565777, 56.77482068538666, 59.578382447361946, 60.87196983397007, 59.06582415103912, 58.083854243159294, 55.945040211081505, 60.369887575507164, 61.78179681301117, 57.75766834616661, 59.481001272797585, 57.80117981135845, 58.121586218476295, 51.5577158331871, 54.71305891871452, 52.71117053925991, 48.57215143740177, 47.42499679327011, 48.00220102071762, 45.97248673439026, 50.02428911626339, 51.45247668027878, 49.26478587090969, 52.21892975270748, 53.28940071165562, 56.4948745071888, 60.974446535110474, 59.71552848815918, 67.76719003915787, 65.64364358782768, 63.4614472836256, 64.58625912666321, 68.91485005617142, 63.722006902098656, 68.78454744815826, 68.38587284088135, 70.74346393346786, 65.44460266828537, 65.38705855607986, 59.48887825012207, 62.65095457434654, 71.52473241090775, 77.46930822730064, 73.90279680490494, 75.31557619571686, 73.59218627214432, 86.5653969347477, 73.44557493925095, 76.37822717428207, 2.7770990319550037, 10.157985426485538, 86.96815252304077, 58.21126140654087, 64.29256528615952, 50.37610463798046, 72.43891775608063, 45.47167740762234, 90.7446862757206, 28.271486163139343, 0.5412371386773884, 0.3267214901279658, 0.12869713478721678, 0.239970067050308, 0.0988702938775532, 0.1924248511204496, 0.18731192860286683, 0.18827770021744072, 0.15064175880979747], [0.049019985817722045, 0.005534732817977783, 0.019998096831841394, 0.15671366971218958, 0.06904116715304554, 0.10504062098334543, 0.04350605122453999, 0.05036312839365564, 0.053289483475964516, 0.07364295772276819, 0.2271576740895398, 13.597377520054579, 57.98167012631893, 41.795629262924194, 40.51642410457134, 35.093735083937645, 33.38468179106712, 38.55556592345238, 71.21591538190842, 18.443627022206783, 0.15782629750901833, 54.16003279387951, 60.91535210609436, 69.26827669143677, 69.24365401268005, 71.25901266932487, 68.19817811250687, 66.08005777001381, 61.23241849243641, 55.138894468545914, 49.9963454157114, 51.8292872607708, 49.6880641579628, 61.28476828336716, 59.80804592370987, 61.56146943569183, 58.03411491215229, 56.84850253164768, 63.72306324541569, 59.81623828411102, 61.685338988900185, 54.659379199147224, 48.43698509037495, 44.891007766127586, 48.68412382900715, 48.75470884144306, 49.22999493777752, 44.50440511107445, 44.307404682040215, 40.94035975635052, 41.12200900912285, 42.70737513899803, 40.3604918718338, 41.660132333636284, 46.40502132475376, 46.22092880308628, 46.27046674489975, 52.25764587521553, 55.363086238503456, 55.112425088882446, 53.503701612353325, 54.10309284925461, 53.5227157920599, 53.798455595970154, 54.421967938542366, 55.395696088671684, 56.7729701846838, 59.63637113571167, 41.931099593639374, 42.16550521552563, 50.34880310297012, 56.98645792901516, 55.70306919515133, 44.694121330976486, 28.545122779905796, 39.260469898581505, 50.02851828932762, 45.63008330762386, 43.414418399333954, 39.134381264448166, 40.3739545494318, 39.531076177954674, 47.07090899348259, 46.071965396404266, 46.84544049203396, 44.299721494317055, 45.015329495072365, 43.69249127805233, 39.781737327575684, 41.02481782436371, 42.98896282911301, 44.50986921787262, 43.17936681210995, 40.82196190953255, 39.19773906469345, 43.43016855418682, 43.33095967769623, 44.68369469046593, 42.204855903983116, 44.48968090116978, 41.66385993361473, 42.58075833320618, 47.99032665789127, 56.39946162700653, 56.25111758708954, 53.61537002027035, 49.03606854379177, 46.62491172552109, 52.67902046442032, 52.59132117033005, 53.73683050274849, 56.175292655825615, 59.32603798806667, 52.487104162573814, 54.439143016934395, 53.74088488519192, 54.33555297553539, 54.991359785199165, 52.79375530779362, 51.0349702835083, 45.07803753018379, 44.99222673475742, 44.08531419932842, 46.04162022471428, 42.87211149930954, 42.028841748833656, 41.66140526533127, 41.909011378884315, 42.89242900907993, 45.97182177007198, 45.847492441534996, 43.32144878804684, 47.276607155799866, 53.886215686798096, 57.35797919332981, 55.51638521254063, 54.932618737220764, 56.01748712360859, 58.58461797237396, 59.82780106365681, 58.56795206665993, 57.74056926369667, 60.86708329617977, 59.32962879538536, 63.05081471800804, 63.6098825186491, 62.0738111436367, 56.77328176796436, 52.21623569726944, 63.513527289032936, 70.81988543272018, 69.73677635192871, 75.11480256915092, 68.29147070646286, 65.88555380702019, 68.45068216323853, 35.18974453210831, 0.46149357862304896, 20.88673062622547, 65.59283271431923, 43.14616799354553, 42.32263818383217, 36.56564310193062, 38.31345051527023, 36.909110471606255, 68.3222034573555, 11.294299252331257, 0.2294371064635925, 0.07847237240639515, 0.10000016176491044, 0.0845407358428929, 0.06410347312339582, 0.022241833758016583, 0.0453474680398358, 0.06045174290193245, 0.08667857386171818, 0.04556560379569419, 0.031144642853178084, 0.09581916892784648, 0.015636689749953803, 0.05596193499513902, 0.046901150490157306, 0.006578811216968461, 0.12529895931947976, 0.09508537041256204, 0.1592530615744181, 0.14214954106137156, 15.356059949845076, 68.6200162768364, 48.251391649246216, 43.47935691475868, 41.677926778793335, 38.72946739196777, 42.763004153966904, 77.74132803082466, 22.81203031539917, 0.12569373735459521, 53.85758802294731, 65.51467850804329, 74.23605412244797, 72.03548580408096, 74.44929108023643, 72.60504484176636, 69.7170478105545, 64.60530370473862, 58.46724607050419, 53.73875319957733, 54.60189588367939, 54.735861495137215, 63.21368157863617, 63.17162923514843, 67.72121250629425, 60.229770094156265, 58.27857859432697, 65.73340237140656, 63.705618381500244, 64.99360486865044, 57.7333914488554, 50.73559954762459, 48.165527656674385, 52.01301880180836, 50.46834468841553, 49.28334027528763, 46.494977697730064, 45.60702234506607, 45.574758276343346, 44.54991526901722, 45.74321083724499, 44.038667902350426, 45.66427767276764, 47.29385443031788, 49.626173079013824, 48.74392122030258, 54.51228529214859, 55.85667595267296, 57.50539608299732, 56.99998140335083, 59.41368788480759, 55.36799557507038, 57.274189889431, 59.073739126324654, 57.85743199288845, 61.328173354268074, 60.26475861668587, 43.23924779891968, 46.06784261763096, 55.75800284743309, 58.62412445247173, 57.824069783091545, 44.3083356320858, 39.583874344825745, 59.39003795385361, 49.9720761179924, 46.42387591302395, 42.30797857046127, 43.29876780509949, 41.55870817601681, 42.537915632128716, 46.907624155282974, 45.89476950466633, 47.53734916448593, 42.871978506445885, 46.16434223949909, 45.247709825634956, 40.7745024561882, 40.67697688937187, 40.85796117782593, 42.78843618929386, 43.54860819876194, 41.864120587706566, 41.13441914319992, 45.379585549235344, 45.34544438123703, 46.992443203926086, 44.95651625096798, 46.605365574359894, 41.207474023103714, 44.65737730264664, 52.1815549582243, 57.156449407339096, 56.194105446338654, 54.19778756797314, 54.15546543896198, 51.907620057463646, 53.52199763059616, 55.748153775930405, 54.50133427977562, 58.15112583339214, 58.59343729913235, 55.35145506262779, 57.81091868877411, 58.67471493780613, 58.541786670684814, 54.94678057730198, 55.53792245686054, 53.32964055240154, 50.05331575870514, 47.91004836559296, 47.651343047618866, 44.73913371562958, 43.98147717118263, 45.43160855770111, 46.11834950745106, 42.34072521328926, 47.926699072122574, 47.5410083681345, 47.99827203154564, 48.79141867160797, 50.911465510725975, 55.31653493642807, 58.41475568711758, 60.900016129016876, 58.95769715309143, 60.77593378722668, 61.484747752547264, 60.646360740065575, 61.44397974014282, 62.57820747792721, 64.27742689847946, 65.05304887890816, 65.44524863362312, 66.59089475870132, 63.54577995836735, 61.400985047221184, 56.854791194200516, 66.45258218050003, 72.13133946061134, 71.29270926117897, 77.01823443174362, 72.49496474862099, 68.82331296801567, 73.32656532526016, 44.92790378630161, 0.34903101332020015, 26.8544415012002, 74.01169896125793, 45.9748388081789, 54.65805687010288, 41.35788515210152, 48.046050667762756, 37.66970045864582, 74.40815448760986, 13.357383348047733, 0.4201308387564495, 0.10505960512091406, 0.06965670443605632, 0.05396616630605422, 0.06392391791450791, 0.07169094606069848, 0.041864201630232856, 0.029176923635532148, 0.018378194399701897, 0.24551536480430514, 0.09901432247716002, 0.22982300841249526, 0.18724658992141485, 0.14470239548245445, 0.16611651750281453, 0.0953756614762824, 0.35292331071104854, 0.17361237230943516, 0.30553082877304405, 0.3164280502824113, 21.341416127979755, 80.648954808712, 56.358252838253975, 54.683253318071365, 50.317257195711136, 49.083964973688126, 48.89066554605961, 85.6262469291687, 22.91227463632822, 0.2581834694137797, 61.137298196554184, 63.580369502305984, 78.27377825975418, 71.99067860841751, 77.07599893212318, 72.17917889356613, 73.488839417696, 66.7254151403904, 61.76512710750103, 54.2428607493639, 58.19037012755871, 55.39978086948395, 66.73388868570328, 64.8363845050335, 68.7907487154007, 62.85431206226349, 59.90847833454609, 68.50452527403831, 65.24009764194489, 67.33680993318558, 61.95517770946026, 51.456770449876785, 48.48902329802513, 54.83649529516697, 53.94190929830074, 52.70882986485958, 48.88298235833645, 48.7193289399147, 46.07957258820534, 47.660139575600624, 47.90947079658508, 45.4233667999506, 47.249533608555794, 49.89992938935757, 51.232715472579, 49.95717331767082, 57.888734713196754, 59.03164118528366, 58.75815846025944, 56.44689068198204, 63.22930634021759, 57.53900907933712, 57.96810485422611, 60.440385192632675, 59.2022330313921, 63.13609354197979, 65.402090549469, 42.339486479759216, 46.56286485493183, 57.74151921272278, 63.796919882297516, 60.66793218255043, 51.21351130306721, 37.12312638759613, 43.78384217619896, 53.269649371504784, 47.749700769782066, 46.18810996413231, 46.21149770915508, 41.63020893931389, 43.57977032661438, 51.60608723759651, 49.645278453826904, 47.01708108186722, 43.904550299048424, 45.60209400951862, 45.4267980158329, 40.59514828026295, 40.120329558849335, 40.385422334074974, 43.82025182247162, 45.590322241187096, 43.57153996825218, 43.92747826874256, 49.0174875408411, 47.719651982188225, 47.65521124005318, 45.668278858065605, 49.1024623811245, 45.06678253412247, 43.44303846359253, 49.99838590621948, 60.73181815445423, 58.59805405139923, 57.459828928112984, 55.005388632416725, 52.14177869260311, 54.76566709578037, 58.26851673424244, 57.338490039110184, 59.70778450369835, 63.64320293068886, 56.952111572027206, 59.87108074128628, 59.15260389447212, 60.47443136572838, 57.64494739472866, 58.15590217709541, 55.8627138286829, 51.15362271666527, 49.57492522895336, 51.494783610105515, 48.98314118385315, 47.47546188533306, 47.066136449575424, 48.797980919480324, 45.966137275099754, 49.6775159239769, 51.86506614089012, 50.01763567328453, 48.909683525562286, 51.70258305966854, 57.268801778554916, 62.686201483011246, 62.150175645947456, 60.126662626862526, 63.007204458117485, 63.90439331531525, 64.1685551404953, 64.24653455615044, 65.24186074733734, 68.0676931142807, 69.22675251960754, 71.31076589226723, 69.53888297080994, 67.64701008796692, 62.5704824924469, 61.26526013016701, 69.30739939212799, 76.75447538495064, 73.20346713066101, 82.37875118851662, 71.72273218631744, 75.72408467531204, 72.5568862259388, 57.167750000953674, 0.4461888311197981, 24.473320171236992, 82.83335119485855, 55.8063780516386, 60.505323708057404, 51.45464636385441, 53.69434118270874, 45.196393579244614, 91.03362277150154, 16.808192878961563, 0.5296675907447934, 0.1710894561256282, 0.23892190220067278, 0.16533530317246914, 0.17221823305590078, 0.15749515121569857, 0.12565143493702635, 0.12321664136834443, 0.11366149745299481], [0.054588939528912306, 0.04184977056866046, 0.05022812802053522, 0.0582063157344237, 0.04356370496680029, 0.038316516802296974, 0.0663575463113375, 0.05845343606779352, 0.0790471509390045, 0.08342328408616595, 0.402879734756425, 4.866505265235901, 50.499951392412186, 44.85059313476086, 36.114402115345, 36.536483466625214, 36.12360142171383, 30.18820211291313, 70.05866467952728, 29.58916425704956, 0.06709311855956912, 37.672003135085106, 74.10528793931007, 70.50820335745811, 73.06107357144356, 68.06738153100014, 66.98405966162682, 63.037105053663254, 59.69828501343727, 54.1066038608551, 50.96847005188465, 50.6098110973835, 56.37935310602188, 61.775815933942795, 59.43679824471474, 57.86207154393196, 55.683865025639534, 58.55868436396122, 61.82926006615162, 62.57120445370674, 58.85510265827179, 55.501558408141136, 53.964438289403915, 51.88672497868538, 46.49736396968365, 45.79051449894905, 46.188774928450584, 44.59810048341751, 43.715476244688034, 44.972118213772774, 43.94958548247814, 39.43399898707867, 40.46490266919136, 44.90871861577034, 46.901768669486046, 44.316949769854546, 43.18254344165325, 52.24951431155205, 55.15575796365738, 55.90454578399658, 53.91916371881962, 51.38642102479935, 54.79571208357811, 56.705026030540466, 52.075016275048256, 56.772510409355164, 57.01555676758289, 55.02410642802715, 49.35790367424488, 50.167799815535545, 50.69125592708588, 53.984375819563866, 58.22960302233696, 52.927561327815056, 27.11318101733923, 31.85583382844925, 58.08499418199062, 44.169696271419525, 44.11325789988041, 38.30020822584629, 42.58760176599026, 36.606783494353294, 46.378320157527924, 43.668476566672325, 41.99927553534508, 39.22480881214142, 42.49649405479431, 41.66956342756748, 42.80834712088108, 42.25844822824001, 40.26909537613392, 42.60233357548714, 47.87888243794441, 50.10652810335159, 41.97260096669197, 32.8903017193079, 36.627553179860115, 37.85693161189556, 42.65564851462841, 41.58936493098736, 53.942623659968376, 50.629076063632965, 55.72671912610531, 56.35422125458717, 59.95681174099445, 52.402904480695724, 49.8973835259676, 49.47005085647106, 50.64992934465408, 53.353146091103554, 52.375488951802254, 55.70725657045841, 55.71536913514137, 57.10125356912613, 52.066234946250916, 52.51086808741093, 52.51493766903877, 55.564190447330475, 53.99173602461815, 50.34116931259632, 48.066124990582466, 43.91425117850304, 43.29606235027313, 40.27304336428642, 40.0863441824913, 41.69023051857948, 41.29202328622341, 41.97585739195347, 43.787687569856644, 43.69977168738842, 45.39734199643135, 45.664703249931335, 47.0412477850914, 56.3496994972229, 58.55787880718708, 56.58784031867981, 57.960930839180946, 57.757903933525085, 56.59403778612614, 58.56491982936859, 56.403367817401886, 60.75557827949524, 57.04515717923641, 59.527761563658714, 57.3102081567049, 63.713130578398705, 59.14703719317913, 61.43373169004917, 51.56727612018585, 58.358123525977135, 66.4265763759613, 69.92350593209267, 67.99254074692726, 75.97004547715187, 61.70634426176548, 70.15337839722633, 30.35263068974018, 0.4286276875063777, 39.563534036278725, 65.83470493555069, 46.408703327178955, 38.07397596538067, 31.136895306408405, 48.02980653941631, 55.81202834844589, 62.21933573484421, 11.3545336201787, 0.38917449361179024, 0.1664211245952174, 0.013922852758696536, 0.09366276979562826, 0.03775155317271128, 0.009072613411262864, 0.06650449155131355, 0.01966908050235361, 0.033124017500085756, 0.08090463525149971, 0.06842977847554721, 0.032151032210094854, 0.12869265221524984, 0.02242374343040865, 0.014297437883215025, 0.07781783526297659, 0.1045013616385404, 0.061962878025951795, 0.12933435762533918, 0.2535628282930702, 7.06856120377779, 64.6571633219719, 51.49804003536701, 39.78597790002823, 50.001345947384834, 45.09058825671673, 37.03087493777275, 75.38563683629036, 36.67711392045021, 0.04667371562391054, 39.958800226449966, 76.85365006327629, 76.52726277709007, 73.26962918043137, 72.27895393967628, 69.46242347359657, 66.57447203993797, 63.043819293379784, 57.41399958729744, 54.14702609181404, 54.75414991378784, 60.933260545134544, 64.97780531644821, 61.87029406428337, 61.036360412836075, 58.73593345284462, 62.448281049728394, 65.15944316983223, 63.99533003568649, 62.47730769217014, 58.62956576049328, 56.262091398239136, 55.05319386720657, 52.93443135917187, 48.96027401089668, 47.80423164367676, 46.88550554215908, 47.302126586437225, 48.385224267840385, 45.561010614037514, 43.226605877280235, 45.63484065234661, 45.582414865493774, 47.893694043159485, 46.64593979716301, 48.24452921748161, 55.56312270462513, 56.858195811510086, 59.780033826828, 54.87398788332939, 56.10169440507889, 56.81445635855198, 58.702434450387955, 55.009667202830315, 58.95847991108894, 59.337908551096916, 58.59894700348377, 49.17616702616215, 53.356482312083244, 54.876864328980446, 57.67162196338177, 58.07290323078632, 58.109727054834366, 29.254459217190742, 56.194869205355644, 63.68424452841282, 43.30607481300831, 45.136953368783, 38.47035549581051, 44.66174706816673, 39.357258304953575, 51.090815886855125, 42.20858350396156, 39.75682966411114, 39.90150310099125, 40.779958963394165, 41.37213058769703, 42.83704698085785, 43.325727358460426, 39.8157075047493, 40.84208182990551, 43.21180947124958, 51.131306514143944, 44.47458431124687, 37.49063886702061, 39.317812621593475, 40.33866964280605, 42.91642092168331, 44.32686723768711, 53.66467997431755, 53.80761310458183, 58.81620794534683, 57.495125234127045, 59.56927813589573, 53.1641898304224, 52.422097250819206, 51.09633319079876, 51.170068234205246, 52.4385579675436, 53.952886909246445, 54.70745801925659, 60.60670606791973, 54.347020760178566, 58.37366849184036, 57.70684227347374, 57.4023874104023, 54.073051661252975, 57.22063936293125, 54.485268741846085, 52.21975050866604, 45.782295539975166, 46.11176446080208, 44.07394140958786, 41.55615471303463, 43.131303191185, 45.4216530919075, 42.60971657931805, 45.82696974277496, 49.41273473203182, 47.60870933532715, 51.01095177233219, 52.3683263361454, 59.02328543365002, 60.590279549360275, 59.52960066497326, 62.69710689783096, 61.639304459095, 60.02747654914856, 62.8720723092556, 60.85989408195019, 63.5633160173893, 61.02630615234375, 64.71241995692253, 63.86623576283455, 65.35507187247276, 61.975582614541054, 64.19438615441322, 57.6539871096611, 62.332345470786095, 67.22816616296768, 73.75265166163445, 70.12662023305893, 79.1242790222168, 65.3495241701603, 77.27564021945, 33.0990245193243, 0.27191334986127913, 46.22752904891968, 67.65511125326157, 54.49270114302635, 43.389088958501816, 32.52334401011467, 48.8701618462801, 55.82647517323494, 70.80765768885612, 13.60895549878478, 0.40995501447468996, 0.3315621631918475, 0.13424154196400195, 0.09435231404495426, 0.07769891351927072, 0.03443805675487965, 0.06554069404955953, 0.08490973166772164, 0.028101310454076156, 0.2111089532263577, 0.25652376003563404, 0.1340590775362216, 0.17720411473419517, 0.13532409793697298, 0.15054308285471052, 0.19400023767957464, 0.2112664221203886, 0.18135459045879543, 0.2275856854976155, 0.6332185654900968, 10.391611140221357, 74.82733279466629, 60.938363671302795, 51.195716857910156, 52.826878130435944, 55.44479325413704, 44.09362435340881, 80.8940264582634, 37.759444043040276, 0.11676374895614572, 45.37629492580891, 77.02484607696533, 80.71717634797096, 77.55206018686295, 75.3490599989891, 73.91272187232971, 70.78146949410439, 66.74126029014587, 61.66818670928478, 55.17837055027485, 57.58226215839386, 63.117318749427795, 67.9673632979393, 63.77279117703438, 62.97597013413906, 59.718670919537544, 63.24059173464775, 66.07786908745766, 68.27542036771774, 64.56235080957413, 61.36356845498085, 58.88086147606373, 55.95212683081627, 51.82848550379276, 50.44570170342922, 50.30985899269581, 48.71628910303116, 50.97166948020458, 51.30643531680107, 49.528981894254684, 43.18452313542366, 46.69033661484718, 50.30034430325031, 52.8315556794405, 47.50460632145405, 50.39346590638161, 57.95962750911713, 61.52187556028366, 61.82218864560127, 57.370047345757484, 55.39163030683994, 57.401243671774864, 58.84534478187561, 58.49670208990574, 61.1630380153656, 62.274770960211754, 62.27888993918896, 49.93997544050217, 52.56954833865166, 55.45808494091034, 57.720190957188606, 60.789841040968895, 60.50252705812454, 31.34269416332245, 44.84359011054039, 53.6899334192276, 47.11575038731098, 46.28888815641403, 42.263372763991356, 47.624432891607285, 41.470723897218704, 53.73922057449818, 44.31332476437092, 44.46016788482666, 38.53206418454647, 41.42419919371605, 42.02529273927212, 39.88734886050224, 42.994107753038406, 39.556777998805046, 43.24737936258316, 44.84000690281391, 52.277123630046844, 43.52793350815773, 36.81368239223957, 42.13148184120655, 43.81921447813511, 46.79641172289848, 47.233764454722404, 51.359586864709854, 50.52211560308933, 59.301582500338554, 60.4349210858345, 62.79871724545956, 57.633168026804924, 54.305971562862396, 54.270169883966446, 53.53959448635578, 56.99930503964424, 56.561253145337105, 58.287439718842506, 64.90503162145615, 58.43669950962067, 60.97468592226505, 57.84236580133438, 59.32109445333481, 58.74538354575634, 57.48600572347641, 55.517464354634285, 52.75560915470123, 46.8297815322876, 50.60017101466656, 46.873923763632774, 44.51080396771431, 46.226145923137665, 47.83068582415581, 46.36850908398628, 46.762095764279366, 53.08317057788372, 49.45489726960659, 53.12240727245808, 53.3477807790041, 61.925436705350876, 61.43905520439148, 60.42674012482166, 64.99190255999565, 63.872079849243164, 63.801335245370865, 66.54801785945892, 63.36993299424648, 69.14283782243729, 63.55881705880165, 65.58726981282234, 67.07269370555878, 68.26155111193657, 66.95509761571884, 67.71834746003151, 59.171899259090424, 65.34545078873634, 70.07158398628235, 76.75566092133522, 73.11654299497604, 81.61724925041199, 66.92359730601311, 80.19125416874886, 40.388028994202614, 0.4696736787445843, 48.49584013223648, 78.96399602293968, 58.72232258319855, 49.70236659049988, 42.15033642947674, 63.16134698688984, 70.31257465481758, 85.0257195532322, 15.860955957323313, 0.6802533916197717, 0.654848370468244, 0.22368365112924948, 0.3108642582083121, 0.21464653371367604, 0.08406541994190775, 0.17016010911902413, 0.21205081284279004, 0.1688571649719961], [0.16587946069194004, 0.16230909212026745, 0.05446048860903829, 0.016734600758354645, 0.01870211217465112, 0.16841573553392664, 0.11107151338364929, 0.1085856081044767, 0.028501125816546846, 0.14476436481345445, 0.3215373808052391, 3.388561508618295, 47.31186166405678, 43.75428356230259, 31.856620386242867, 18.74238409101963, 31.457985676825047, 37.43427649140358, 62.75376185774803, 51.82337857782841, 0.312543916516006, 24.054544642567635, 76.0021461546421, 65.58948129415512, 70.2169717848301, 63.86831805109978, 64.86319586634636, 58.37005868554115, 58.46741706132889, 51.70548230409622, 49.576179161667824, 54.71350349485874, 62.57623918354511, 61.09461508691311, 61.52466461062431, 55.19315555691719, 58.6289843916893, 58.849216774106026, 57.586373537778854, 58.87033224105835, 56.322690546512604, 58.22803370654583, 59.363693967461586, 59.54062767326832, 55.43903276324272, 47.50564746558666, 44.34601441025734, 45.91203957796097, 45.42200647294521, 41.93314388394356, 41.63615562021732, 42.58111171424389, 40.83248734474182, 40.9024415910244, 41.00751355290413, 44.156328588724136, 44.39730025827885, 48.66670936346054, 57.680726274847984, 57.26017624139786, 55.19431069493294, 53.51260833442211, 49.299200624227524, 45.3449922055006, 45.166432186961174, 47.12866589426994, 56.19137339293957, 56.12904153764248, 58.783864080905914, 57.28712059557438, 54.99005265533924, 53.92836682498455, 61.175064370036125, 54.58856239914894, 39.02335122227669, 21.240354850888252, 63.92687290906906, 52.73110046982765, 35.9079971909523, 42.358223274350166, 35.67319259047508, 48.42512972652912, 44.72765073180199, 28.816637210547924, 27.414335757493973, 38.96183632314205, 40.395260006189346, 44.69383254647255, 38.48009817302227, 41.93405583500862, 40.771299228072166, 41.47753693163395, 41.30728326737881, 50.75154349207878, 52.837015986442566, 49.480876475572586, 48.13024654984474, 45.470431074500084, 48.14328745007515, 50.502702444791794, 49.96629282832146, 46.98021546006203, 53.287580609321594, 58.89816574752331, 56.977277621626854, 53.86483043432236, 50.381450951099396, 50.24986021220684, 52.2253780066967, 51.921322122216225, 50.22907912731171, 48.43039244413376, 51.881010085344315, 57.09680400788784, 53.965346440672874, 54.17350307106972, 52.10514485836029, 56.01505905389786, 56.835195645689964, 51.94801568984985, 46.98986694216728, 46.05931967496872, 43.891114220023155, 41.77580572664738, 39.21159312129021, 42.96791195869446, 40.82370601594448, 42.40158274769783, 44.084459245204926, 46.573158502578735, 43.08398053050041, 46.45142823457718, 48.27400043606758, 59.104654267430305, 61.00562006235123, 63.00728425383568, 57.859339490532875, 59.606516137719154, 56.98694050312042, 59.9462179094553, 57.59485088288784, 57.773475497961044, 58.73597905039787, 58.9357191324234, 57.2147648781538, 61.92276544868946, 57.21842788159847, 59.2835258692503, 51.35014437139034, 54.43848945200443, 65.21324828267097, 72.293461561203, 65.47093525528908, 74.02271836996078, 60.05326196551323, 73.71578603982925, 17.511396445333958, 0.7944247964769602, 52.45015874505043, 56.36275179684162, 46.7664997279644, 45.94865061342716, 42.93691702187061, 42.43499435484409, 47.77860201895237, 57.33117163181305, 9.44064661860466, 0.2660349465440959, 0.035035704568144865, 0.10761249664938077, 0.15771056700032204, 0.06719911951222457, 0.05505002845893614, 0.10738737357314676, 0.02579979547590483, 0.058018949421239085, 0.03642942821898032, 0.13712621061131358, 0.020241339443600737, 0.058168098839814775, 0.0364823062409414, 0.11983959484496154, 0.08342481291037984, 0.03468094684649259, 0.017930727590282913, 0.04033475401229225, 0.24005468672839925, 4.295366462320089, 62.021058574318886, 48.218401819467545, 34.529066383838654, 24.147937931120396, 36.1193722486496, 43.195648938417435, 63.55681836605072, 63.015719801187515, 0.40767038706690073, 23.960005715489388, 80.53527250885963, 70.25621607899666, 79.02861535549164, 65.56700929999352, 66.94179832935333, 63.11349235475063, 63.24871189892292, 53.88307325541973, 51.46945796906948, 59.58503969013691, 67.24809989333153, 63.03676687180996, 65.66165462136269, 60.95670148730278, 61.89183130860329, 64.62414309382439, 64.12966042757034, 58.97084064781666, 58.35887588560581, 58.8085513561964, 63.30885887145996, 62.0775805413723, 58.002663999795914, 50.619933754205704, 48.60951103270054, 46.74251541495323, 47.79735781252384, 44.25544627010822, 47.07561694085598, 42.19897761940956, 45.096424743533134, 43.84972304105759, 44.042954072356224, 45.99062316119671, 46.10652834177017, 52.305815890431404, 58.10083553195, 58.2261186093092, 54.56577882170677, 54.11030866205692, 50.95156475901604, 46.35718949139118, 46.14771053195, 50.20141661167145, 57.95451298356056, 59.84015800058842, 59.61491368710995, 56.96331337094307, 58.7817095965147, 54.9145583063364, 60.290498435497284, 58.135444074869156, 40.302423387765884, 31.53670985251665, 84.36873480677605, 47.677307054400444, 38.013414815068245, 42.189709916710854, 39.66191455721855, 48.12100164592266, 46.87304601073265, 30.1480420678854, 31.152371875941753, 39.74785454571247, 39.517537504434586, 43.96571561694145, 36.812040880322456, 43.29130120575428, 38.18198896944523, 41.027584075927734, 38.6252161860466, 47.8228772431612, 52.98352472484112, 51.10623545944691, 50.903653129935265, 47.73835077881813, 49.65820915997028, 53.74835908412933, 56.10496982932091, 51.321102529764175, 55.0064791738987, 58.4098045527935, 56.17761813104153, 55.03513723611832, 52.85017088055611, 50.99257975816727, 54.33098942041397, 52.14004598557949, 51.98835052549839, 48.43219354748726, 55.666921734809875, 59.929286018013954, 56.14873968064785, 57.69393436610699, 56.21462054550648, 56.735724583268166, 57.652034014463425, 56.31010562181473, 49.691806957125664, 46.40073895454407, 46.22622951865196, 45.55090695619583, 41.15102045238018, 45.53583696484566, 44.215084835886955, 45.18217474222183, 44.45517115294933, 49.565254747867584, 46.794131845235825, 47.6249610632658, 53.14085528254509, 64.52026426792145, 62.933765798807144, 62.63284474611282, 62.6707249134779, 64.48097437620163, 62.557848170399666, 64.12449270486832, 59.279030710458755, 63.17654237151146, 62.7742275595665, 63.099585101008415, 60.982258915901184, 66.50774002075195, 59.29146744310856, 61.068149507045746, 55.44099345803261, 57.346826791763306, 64.97733414173126, 73.73787805438042, 69.17056873440742, 76.38575837016106, 63.710018545389175, 82.78843760490417, 18.36777739226818, 0.877357127610594, 64.58233773708344, 59.95206579566002, 51.85155026614666, 52.760575488209724, 38.793919533491135, 39.99645620584488, 49.54329572618008, 63.598361536860466, 13.410240411758423, 0.5620992067269981, 0.16242235869867727, 0.10856822700588964, 0.10358495768741705, 0.04235177410009783, 0.00868607599841198, 0.10687447531381622, 0.052274314512033015, 0.030893642942828592, 0.3131840337300673, 0.31499995035119355, 0.1741490192944184, 0.13299314567120746, 0.12065496281138621, 0.3265447402372956, 0.17831162171205506, 0.17290843039518222, 0.16332858038367704, 0.3461581002920866, 0.49873184761963785, 6.5943400003015995, 75.49823999404907, 57.5028882175684, 44.42047521471977, 29.509718120098114, 44.72542405128479, 52.053004056215286, 71.87985375523567, 62.22223497927189, 0.481559915933758, 30.716900043189526, 82.5735667347908, 71.23289287090302, 81.56562522053719, 69.69763845205307, 70.76589033007622, 65.44622138142586, 66.1418728530407, 57.282735630869865, 54.99589294195175, 59.083044826984406, 70.43723076581955, 67.44527131319046, 68.125921189785, 59.07632678747177, 61.87665872275829, 64.9581603705883, 66.26712933182716, 61.771039590239525, 63.58131565153599, 63.180585354566574, 64.30151000618935, 63.39281536638737, 59.30025637149811, 52.36166149377823, 50.572565495967865, 50.206268951296806, 49.86614540219307, 47.18485727906227, 48.884874656796455, 46.924525648355484, 49.1231294721365, 46.41954034566879, 46.749507039785385, 47.36478142440319, 48.047566786408424, 53.853355050086975, 63.14991720020771, 62.21211992204189, 58.551035374403, 55.74984088540077, 53.23146902024746, 47.921204566955566, 46.4846308529377, 51.717482060194016, 60.30713014304638, 64.04810920357704, 63.23918201029301, 58.757641687989235, 60.70534497499466, 56.9479051977396, 62.36970506608486, 61.28960162401199, 43.132028952240944, 34.996939077973366, 61.62613816559315, 46.32868342101574, 43.91729101538658, 41.96947753429413, 40.114257484674454, 48.93668867647648, 49.803980737924576, 32.897680923342705, 31.072405166924, 39.89261917769909, 40.4156307131052, 43.92281211912632, 37.484376803040504, 41.55704766511917, 38.98367755115032, 41.382640823721886, 41.28415770828724, 47.1344605833292, 52.4512492865324, 48.2568633556366, 51.09777331352234, 48.63259859383106, 52.41091065108776, 55.474253073334694, 58.595656380057335, 56.5971802175045, 58.44366453588009, 63.34712281823158, 61.30659431219101, 57.461132258176804, 54.290707781910896, 52.90750980377197, 55.68633869290352, 52.15503238141537, 52.33767718076706, 50.010119676589966, 58.31880323588848, 63.20386290550232, 58.95470291376114, 61.51909410953522, 57.35015541315079, 59.0174375474453, 61.29531271755695, 59.76022928953171, 51.70639045536518, 48.733281791210175, 47.64158517122269, 48.654056042432785, 44.5926895737648, 46.01944841444492, 45.67543387413025, 49.48173142969608, 47.461315244436264, 51.29780597984791, 49.69543196260929, 51.94107346236706, 55.92572204768658, 68.36368963122368, 65.33098116517067, 64.09508228302002, 62.76614539325237, 66.39034911990166, 65.028555393219, 67.40527465939522, 62.12282091379166, 65.8703850209713, 67.27076187729836, 66.14306598901749, 64.9844017624855, 72.81255930662155, 63.09464156627655, 65.67951366305351, 57.83477000892162, 60.38609370589256, 71.7042575776577, 77.03640505671501, 71.36129558086395, 79.86507967114449, 66.07556641101837, 87.7683287858963, 23.790274523198605, 0.8326602447777987, 67.24034830927849, 66.8581572175026, 55.29160067439079, 59.00307431817055, 57.97274060547352, 53.786649629473686, 60.074172243475914, 76.5379250049591, 16.40699900686741, 1.0561483399942517, 0.4379227012395859, 0.2096781667205505, 0.23723408026853576, 0.1279395801248029, 0.08935986435972154, 0.3700475668301806, 0.2567163622006774, 0.1172466496063862], [0.19886988418875262, 0.28937359107658267, 0.0529094370722305, 0.08797848262474872, 0.04846815449127462, 0.05288189226121176, 0.09503008783212863, 0.11086106256698258, 0.14096670609433204, 0.059408030938357115, 0.1879640982951969, 2.4112710496410728, 42.71200709044933, 53.44527594745159, 36.18319742381573, 63.816557228565216, 44.22743037343025, 27.83590793609619, 54.1722871363163, 66.02981686592102, 4.733646344393492, 7.820283891633153, 84.46672394871712, 60.448429360985756, 73.16280171275139, 62.34059862792492, 65.86656242609024, 58.31789508461952, 57.80754067003727, 50.639939680695534, 51.08165077865124, 61.455789506435394, 65.15439704060555, 59.298778250813484, 59.04336355626583, 59.899111837148666, 60.56727938354015, 57.09851771593094, 57.19848275184631, 57.54135735332966, 59.248769134283066, 56.12737722694874, 60.39060786366463, 59.43019039928913, 59.50709067285061, 51.94411709904671, 48.100775331258774, 46.298862621188164, 44.01520416140556, 43.870500326156616, 41.37671694159508, 40.492185205221176, 40.3595495223999, 42.41531901061535, 40.813058987259865, 42.188022807240486, 43.41887176036835, 45.40620692074299, 51.123307943344116, 52.00841724872589, 55.030463486909866, 48.45745839178562, 46.26597158610821, 43.758926913142204, 51.43884301185608, 54.05393488705158, 57.352203503251076, 58.23884032666683, 56.40100434422493, 52.909869477152824, 58.162772208452225, 56.298371851444244, 57.26617231965065, 56.796186938881874, 51.91639758646488, 29.376383274793625, 26.55699346214533, 79.43817257881165, 56.92434646189213, 48.287508711218834, 40.601816922426224, 40.64750947058201, 22.072339206933975, 29.475797340273857, 46.53843216598034, 45.05422800779343, 43.37460033595562, 41.826810389757156, 45.70588544011116, 48.093179538846016, 45.27495056390762, 48.57211723923683, 43.06065358221531, 43.55719953775406, 42.04556085169315, 41.90070882439613, 45.14661245048046, 42.51348294317722, 41.929686069488525, 44.594673067331314, 44.50780972838402, 54.06762175261974, 53.004514798521996, 54.336077347397804, 53.73010866343975, 54.439914375543594, 53.49719636142254, 54.331756979227066, 52.265025079250336, 52.62174233794212, 53.67793366312981, 52.36018717288971, 51.5291603654623, 55.33984288573265, 51.42230249941349, 46.25394903123379, 49.2343495041132, 53.86725090444088, 54.998913779854774, 52.90285125374794, 48.10450293123722, 41.702674850821495, 41.57932206988335, 41.4643744379282, 38.313100934028625, 43.09722661972046, 43.74204441905022, 43.00872936844826, 41.39685966074467, 43.40884409844875, 45.80099433660507, 42.69261673092842, 50.57548373937607, 61.425964906811714, 60.16866557300091, 61.77038222551346, 60.36961019039154, 63.678126856684685, 56.94776080548763, 59.522605240345, 56.41043543815613, 65.41139245033264, 59.96281921863556, 62.334944531321526, 55.4007688164711, 60.0778466463089, 54.0487177670002, 58.42016279697418, 50.62308378517628, 53.94185610115528, 52.34021544456482, 70.45787125825882, 62.33327642083168, 77.78905346989632, 60.883988589048386, 73.45496043562889, 5.020200368016958, 2.955458373762667, 62.75267131626606, 48.209407702088356, 39.435781091451645, 40.190827175974846, 54.083751887083054, 51.87635153532028, 54.16076235473156, 52.604396268725395, 16.508138179779053, 0.3959997883066535, 0.09115923108765855, 0.01925912183651235, 0.008112701052596094, 0.1001269205880817, 0.1148123606981244, 0.15285827190382406, 0.17161586147267371, 0.04520738766586874, 0.24927021644543856, 0.18326164281461388, 0.020062387229700107, 0.11891808491782285, 0.08098993028397672, 0.07096419052686542, 0.13109062041621655, 0.13521632325137034, 0.16439310216810554, 0.08007728902157396, 0.3180890064686537, 4.11880798637867, 55.53491681814194, 59.724313616752625, 36.29480883479118, 59.51011911034584, 49.84378360211849, 37.08454325795174, 54.59526143968105, 73.7274894118309, 6.2381228897720575, 5.734327873215079, 90.26839703321457, 64.69974383711815, 78.39225590229034, 64.41507831215858, 67.05215200781822, 57.03641764819622, 63.032621294260025, 54.48662526905537, 57.316838800907135, 63.310644775629044, 68.57207804918289, 63.54285031557083, 64.42884877324104, 62.24997729063034, 61.50783151388168, 58.35666060447693, 61.77412122488022, 59.60302412509918, 60.147234722971916, 59.03722308576107, 63.454090878367424, 59.86273638904095, 63.843809366226196, 56.88663348555565, 50.811565071344376, 48.14947731792927, 45.9829855710268, 45.37099041044712, 45.026341304183006, 44.06064972281456, 44.94445949792862, 43.46818171441555, 44.36379365622997, 44.66217264533043, 44.57687862217426, 47.09139369428158, 57.546749264001846, 54.395965933799744, 59.22706849873066, 49.45674017071724, 47.783279567956924, 47.87506364285946, 56.26048408448696, 58.13225604593754, 60.052555203437805, 58.226133808493614, 60.9899915009737, 53.04225817322731, 57.849794402718544, 59.915181174874306, 60.32098039984703, 56.68826512992382, 56.64384551346302, 29.423487447202206, 43.33758272230625, 89.45509627461433, 49.85016345977783, 46.737340092659, 43.58175002038479, 39.67733792960644, 26.25995960086584, 42.316854894161224, 51.38027675449848, 43.21163848042488, 43.11275638639927, 41.954244151711464, 43.276204615831375, 45.50429105758667, 45.763627141714096, 47.29519575834274, 42.466285675764084, 42.63161480426788, 40.33327393233776, 38.62087681889534, 44.08194378018379, 42.74005338549614, 40.9934239089489, 44.77471120655537, 46.735884770751, 55.571265667676926, 53.070688247680664, 56.31006382405758, 55.34638233482838, 56.24804735183716, 53.68056312203407, 57.3294161260128, 53.65862309932709, 53.89998994767666, 55.25783188641071, 56.5965760499239, 53.52727174758911, 56.55765473842621, 52.816478088498116, 47.51346744596958, 52.53570355474949, 56.40913210809231, 55.71744002401829, 53.89717049896717, 52.99596145749092, 45.46891875565052, 43.50036598742008, 46.363785937428474, 43.10836382210255, 46.179659217596054, 44.29292745888233, 46.222038343548775, 46.26908361911774, 46.09684266149998, 49.40365321934223, 47.456462904810905, 53.158858716487885, 66.48003190755844, 64.7063098847866, 60.56493490934372, 60.98975591361523, 68.25973480939865, 60.46976521611214, 64.6949028968811, 60.30111886560917, 69.11285743117332, 61.78128004074097, 68.17258268594742, 60.254149585962296, 64.07155394554138, 56.70515522360802, 61.05229675769806, 52.55299262702465, 58.05574335157871, 54.708841145038605, 75.39670944213867, 64.82898250222206, 82.11869314312935, 61.51154011487961, 82.99813315272331, 4.791309675201774, 4.22740425914526, 74.13448557257652, 53.27648900449276, 48.74792240560055, 49.47226233780384, 58.05738486349583, 51.0678119212389, 59.231130480766296, 63.35350647568703, 22.327769100666046, 0.7837128743994981, 0.2331517485436052, 0.10031742989667691, 0.03355153909069486, 0.023672722309129313, 0.0815681301173754, 0.07756686318316497, 0.10779364747577347, 0.07437797336024232, 0.32802312809508294, 0.34918158024083823, 0.17922510160133243, 0.18337615620112047, 0.18637968722032383, 0.2296196747920476, 0.2538047090638429, 0.3402693959651515, 0.2529773925198242, 0.24869715969543904, 0.6371266557835042, 6.221398087218404, 68.39413359761238, 72.50523179769516, 48.301571756601334, 86.63060903549194, 60.141101852059364, 44.507163763046265, 66.95238456130028, 80.27739554643631, 4.932041773572564, 8.625942785292864, 94.79660645127296, 64.42669808864594, 83.45035448670387, 68.50672915577888, 70.56515470147133, 59.52625684440136, 66.5714094042778, 55.801996886730194, 58.976506143808365, 65.9886346757412, 73.45887422561646, 65.10024234652519, 67.44851633906364, 62.617067992687225, 64.64881137013435, 59.4673828035593, 62.595595344901085, 62.69082583487034, 63.75413417816162, 62.634980231523514, 68.9945013821125, 63.18196468055248, 64.08060505986214, 57.45553515851498, 54.453274458646774, 49.005423188209534, 49.46174830198288, 47.181148678064346, 46.9711871445179, 45.69131702184677, 46.56321823596954, 46.342966854572296, 48.163126185536385, 47.26716846227646, 50.123311802744865, 47.56376534700394, 60.13092219829559, 56.4153865724802, 63.27842630445957, 51.215798780322075, 48.87469120323658, 46.483342722058296, 57.58465602993965, 57.50893369317055, 64.08500522375107, 60.79837538301945, 65.36904752254486, 55.135516449809074, 64.24078926444054, 63.06164413690567, 63.18951867520809, 56.3725970685482, 62.00261436402798, 34.64755542576313, 49.924453273415565, 71.10471814870834, 44.29592549800873, 49.84702482819557, 43.66641707718372, 47.94417053461075, 30.697486884891987, 35.886262357234955, 46.25508517026901, 43.04850183427334, 43.68910185992718, 42.14916609227657, 43.729094713926315, 47.92683206498623, 46.917632818222046, 51.50036171078682, 44.695139676332474, 42.33906850218773, 41.194509118795395, 39.251259192824364, 43.382313922047615, 41.84630714356899, 40.54428420960903, 45.84875017404556, 49.86119046807289, 59.4811000674963, 54.571106135845184, 59.139684587717056, 59.203817546367645, 59.60126481950283, 55.491481348872185, 60.69863073527813, 56.15209490060806, 55.44637396931648, 58.056833893060684, 57.04481899738312, 56.69586092233658, 60.878345891833305, 54.16100174188614, 48.80270026624203, 58.490584418177605, 58.21588955819607, 59.45412151515484, 57.34410993754864, 54.3558818846941, 48.65177236497402, 45.31783506274223, 48.02265912294388, 44.23894375562668, 47.5108227878809, 45.44779188930988, 46.08569785952568, 47.64880858361721, 48.47492605447769, 51.8430083245039, 50.74184261262417, 56.897873282432556, 67.6072110235691, 68.95446673035622, 63.09346742928028, 62.10882626473904, 70.31563729047775, 63.94511193037033, 67.31949806213379, 62.31850281357765, 72.90558591485023, 64.87607717514038, 71.86534613370895, 63.53894792497158, 67.86958694458008, 60.62747195363045, 63.8494710624218, 53.99896703660488, 60.57339705526829, 57.44648024439812, 79.42434892058372, 66.41537457704544, 86.36417493224144, 65.01283183693886, 87.22621947526932, 8.234047014266253, 3.619110812433064, 79.71860513091087, 60.53943067789078, 50.8470019698143, 51.481697112321854, 72.10985541343689, 64.70309525728226, 70.99907621741295, 74.87726211547852, 28.66941411048174, 0.8942144480533898, 0.3115169325610623, 0.4078110685804859, 0.34796285501215607, 0.1950948016019538, 0.17766429082257673, 0.16137857252033427, 0.38962859893217683, 0.36803551542107016], [0.039505392851424403, 0.1523687958251685, 0.0672106228012126, 0.06826408658525907, 0.07033708316157572, 0.02580561205832055, 0.07934768364066258, 0.06938918988453224, 0.09538961385260336, 0.3257235686760396, 0.22121175017673522, 4.849988026544452, 49.676501378417015, 49.915603548288345, 43.86274114251137, 81.28117248415947, 49.06661130487919, 23.374869413673878, 46.31753481924534, 65.65136477351189, 20.436726473271847, 1.2213445943780243, 72.09767326712608, 67.51020982861519, 68.75518262386322, 64.02062147855759, 63.6591012775898, 54.97489146888256, 56.67780049145222, 49.09914895892143, 57.40351974964142, 59.216535463929176, 59.153584241867065, 59.47004646062851, 65.79268679022789, 61.93380765616894, 60.70665970444679, 57.75418013334274, 60.68712115287781, 61.01436339318752, 61.871764585375786, 61.407600492239, 62.924479097127914, 62.67060711979866, 62.30381280183792, 52.78418742120266, 46.12478256225586, 44.02211979031563, 43.2725378125906, 47.532610818743706, 46.165185794234276, 43.860757648944855, 45.44157922267914, 40.825073942542076, 40.47910250723362, 41.95108652114868, 40.7630954682827, 45.12927398085594, 52.23145768046379, 50.600581392645836, 50.6668384373188, 51.79538168013096, 48.84086921811104, 56.17481008172035, 55.086510479450226, 54.72048372030258, 55.89921846985817, 53.08458410203457, 58.8736342638731, 58.803296238183975, 54.133882597088814, 55.2091109007597, 55.13197124004364, 60.00660426914692, 55.60876965522766, 49.55277241766453, 25.24029951542616, 27.67468448728323, 65.27251750230789, 68.72079446911812, 53.19298468530178, 35.42663902044296, 46.625390499830246, 61.5036441385746, 49.8230405151844, 47.42159217596054, 46.99535384774208, 47.21281997859478, 42.174069955945015, 44.326468259096146, 54.651019647717476, 49.21255387365818, 46.48183420300484, 42.66587756574154, 46.80957801640034, 40.875520035624504, 40.43122127652168, 37.84052409231663, 33.217680752277374, 44.23603691160679, 55.17119273543358, 53.14895264804363, 56.632161140441895, 55.99866293370724, 56.93711377680302, 56.48919381201267, 54.823423996567726, 56.3683906942606, 52.999438270926476, 53.54996792972088, 52.98098646104336, 55.11099636554718, 52.47823923826218, 52.706397995352745, 53.25557492673397, 50.082760378718376, 50.86757406592369, 55.599015578627586, 55.21960213780403, 48.558905348181725, 49.6764025837183, 42.06913098692894, 41.342568174004555, 42.78035782277584, 45.71896433830261, 42.48596101999283, 41.55850678682327, 44.972942769527435, 47.54681445658207, 47.20902778208256, 44.494943618774414, 45.72744928300381, 47.903307527303696, 62.64506109058857, 61.272221356630325, 58.175524324178696, 53.02558086812496, 58.33950072526932, 59.70632538199425, 63.870939910411835, 61.02447845041752, 63.16158637404442, 60.33615678548813, 62.24098697304726, 57.18803711235523, 59.178298115730286, 55.47926880419254, 57.59175404906273, 51.27435743808746, 56.588642075657845, 55.9363766759634, 66.29420667886734, 65.00112846493721, 73.96594941616058, 62.103464752435684, 66.39708235859871, 0.7570888311602175, 11.157573089003563, 56.57634973526001, 47.79377840459347, 27.468997724354267, 27.808150425553322, 52.09748066961765, 29.680296666920185, 42.871077954769135, 55.24151936173439, 18.546162620186806, 0.2092619109316729, 0.12952483724802732, 0.03713314748893026, 0.18694664351642132, 0.24749627569690347, 0.07692419298109598, 0.23133937938837335, 0.060575837414944544, 0.06720867837429978, 0.1373212767066434, 0.04281473324226681, 0.07447922456776723, 0.009202340825140709, 0.16642293543554842, 0.03577059404051397, 0.1072159968316555, 0.12242197190062143, 0.08625336035038345, 0.29974543140269816, 0.3975948417792097, 10.173301454633474, 64.75152745842934, 58.298063948750496, 45.42905889451504, 79.7968353331089, 52.29318916797638, 33.99734191596508, 52.47395306825638, 75.22444188594818, 25.629284642636776, 0.704925823956728, 70.9657596051693, 71.07414498925209, 75.54184645414352, 68.31003651022911, 69.08695802092552, 58.941399827599525, 55.339307114481926, 50.17363630235195, 62.03812725841999, 61.05795845389366, 63.10504540801048, 61.64631128311157, 67.65644878149033, 64.2741134762764, 63.39391730725765, 61.685407385230064, 64.59163963794708, 63.31816837191582, 66.95590317249298, 62.89700657129288, 65.29851570725441, 62.956800162792206, 63.259564116597176, 53.513649478554726, 47.90359251201153, 45.22291615605354, 47.20686189830303, 49.79210637509823, 46.789287105202675, 47.53096170723438, 49.91035982966423, 42.136554569005966, 43.60146336257458, 44.50838729739189, 43.49855728447437, 45.735379457473755, 52.32990279793739, 54.218872636556625, 52.15573534369469, 52.63867422938347, 49.28574554622173, 57.95701324939728, 58.318446055054665, 57.11986497044563, 57.24300496280193, 58.35105210542679, 61.67914152145386, 61.60604864358902, 54.78294476866722, 56.418263018131256, 55.06418667733669, 62.123523876070976, 56.654405146837234, 52.525368109345436, 26.496979482471943, 44.42768722772598, 75.31808406114578, 59.288127422332764, 48.71568873524666, 41.52200974524021, 63.77105087041855, 67.68143624067307, 47.77874641120434, 45.03475785255432, 46.62377178668976, 47.768274173140526, 44.23616610467434, 44.783697724342346, 49.676793962717056, 46.456466764211655, 42.57421128451824, 43.39804507791996, 45.224770456552505, 42.09157258272171, 41.5033907443285, 38.03295336663723, 34.173789247870445, 44.24820385873318, 56.51512362062931, 55.775998681783676, 62.17291362583637, 60.12834593653679, 58.5970851033926, 58.8172072917223, 54.18125845491886, 56.66873037815094, 54.40138064324856, 56.23112305998802, 56.10340051352978, 56.88487038016319, 53.14715914428234, 53.64456385374069, 57.01870679855347, 52.17210866510868, 53.76853600144386, 59.05648425221443, 58.40007707476616, 52.300336584448814, 48.84371906518936, 43.444296196103096, 42.284689620137215, 45.40845260024071, 47.95981049537659, 47.34560765326023, 46.07569679617882, 49.67822268605232, 49.747375175356865, 50.79222030937672, 47.62520045042038, 50.03748580813408, 53.25695425271988, 66.39709755778313, 64.88274201750755, 62.53949895501137, 52.85020887851715, 58.38002175092697, 62.00749330222607, 67.30231538414955, 69.04161885380745, 66.48377850651741, 64.02025669813156, 65.29290720820427, 60.02079650759697, 61.35138250887394, 57.06607885658741, 62.682675272226334, 54.4549273699522, 59.962720423936844, 55.11228449642658, 71.66475489735603, 71.11100301146507, 76.96920946240425, 64.66800034046173, 69.23404812812805, 0.7079545583110303, 15.1680270396173, 62.52045437693596, 55.508588030934334, 37.80474901199341, 36.2354826182127, 57.00644485652447, 31.938057616353035, 53.534856140613556, 65.96765980124474, 26.739049293100834, 0.22756079386454076, 0.12303583935135975, 0.1357895729597658, 0.08532631400157697, 0.06915009958902374, 0.18003720411797985, 0.10091770862345584, 0.05859205070009921, 0.15940064506139606, 0.23706219886662439, 0.2754608157556504, 0.1576476328773424, 0.25269546546041965, 0.34368389868177474, 0.2839686779771, 0.19108963839244097, 0.4159486584831029, 0.13087507104501128, 0.650129261193797, 0.6479052524082363, 11.62354588508606, 79.37080219388008, 67.45654910802841, 54.6473528444767, 93.77117827534676, 60.04238694906235, 41.57414674758911, 61.64930172264576, 83.665871322155, 24.773127883672714, 1.4116343460045755, 77.6912771165371, 71.7256048321724, 80.4173344373703, 71.5432146191597, 74.01572674512863, 61.38614684343338, 62.327500730752945, 52.54930682480335, 63.51520299911499, 60.47246307134628, 66.28200173377991, 62.37477019429207, 70.02311378717422, 68.11842039227486, 63.33291158080101, 61.49392805993557, 67.20181077718735, 67.01089382171631, 67.66051456332207, 64.81498405337334, 70.29821902513504, 68.86987566947937, 67.45421603322029, 58.76174546778202, 52.44697831571102, 48.41643199324608, 48.17426718771458, 51.50893785059452, 47.78029292821884, 49.85224574804306, 51.8281739205122, 46.043288335204124, 48.78059685230255, 45.62391623854637, 45.126815512776375, 48.031755834817886, 56.00587874650955, 55.7784191519022, 54.23639349639416, 54.92463916540146, 49.98931959271431, 60.8119710534811, 60.28376519680023, 58.088151812553406, 60.10625012218952, 60.81110090017319, 63.16510118544102, 63.56808856129646, 57.20791384577751, 59.56507556140423, 59.08964887261391, 64.69313219189644, 59.020549580454826, 55.75931757688522, 32.52595826983452, 55.459908843040466, 69.81983989477158, 56.85480259358883, 51.3623683154583, 43.42421427369118, 48.475948199629784, 55.23308381438255, 48.96708324551582, 46.38424023985863, 44.88098010420799, 47.04141117632389, 46.68275982141495, 45.1024816185236, 50.3995493799448, 45.74869014322758, 45.197620913386345, 45.33052638173103, 44.928017780184746, 41.79836891591549, 41.152300983667374, 37.52293333411217, 34.950459972023964, 43.299827948212624, 56.257957220077515, 57.30194739997387, 63.872345834970474, 62.92983680963516, 64.67272728681564, 60.91820575296879, 57.60816156864166, 60.551278442144394, 57.77898520231247, 60.5120075494051, 58.23496833443642, 58.515264093875885, 54.85872030258179, 55.473618507385254, 59.89197202026844, 52.132476791739464, 55.52911072969437, 60.828978940844536, 62.61574566364288, 57.09684960544109, 53.144050911068916, 45.02613231539726, 43.68361495435238, 46.50965631008148, 52.47296132147312, 48.85319955646992, 48.3376432210207, 50.38755722343922, 51.450922563672066, 53.909006863832474, 51.68332949280739, 52.817891612648964, 55.84329307079315, 69.79090064764023, 67.76706844568253, 64.73102375864983, 54.14642572402954, 60.02258621156216, 64.07480657100677, 67.80764266848564, 71.08807504177094, 72.41869524121284, 71.00806653499603, 68.96561533212662, 61.313699930906296, 65.95952823758125, 57.09551967680454, 64.55324649810791, 56.35217696428299, 62.5446704775095, 60.32313108444214, 75.8196571469307, 74.7367000579834, 83.76606434583664, 65.57134106755257, 78.57299700379372, 1.815282292664051, 13.172784503549337, 74.40408110618591, 63.030778393149376, 39.545063227415085, 36.427030339837074, 67.84212961792946, 38.42836394906044, 55.51537446677685, 78.00328597426414, 30.933919697999954, 0.3581431618658826, 0.29496721748728305, 0.39602600096259266, 0.4569791833637282, 0.35578259790781885, 0.30880168138537556, 0.46543301723431796, 0.2053869204246439, 0.33958979649469256], [0.18758189224172384, 0.024261625767394435, 0.12311549406149425, 0.03658897883724421, 0.03309295861981809, 0.08235966772190295, 0.04617559723556042, 0.10303599105100147, 0.04904357498162426, 0.18898244365118444, 0.2967886853730306, 11.13396780565381, 63.285683915019035, 34.0445201843977, 43.71435530483723, 71.34673476219177, 50.08013851940632, 24.73397858440876, 36.966795176267624, 51.07490994036198, 38.30623850226402, 0.09459421708015725, 47.87539042532444, 83.07797446846962, 68.20338383316994, 68.56872662901878, 58.34836184978485, 58.115472346544266, 47.29787081480026, 54.60381858050823, 63.08780573308468, 60.31324781477451, 62.64430493116379, 61.772479712963104, 60.131549164652824, 59.606447741389275, 61.793557181954384, 64.2167517542839, 63.04473124444485, 60.0641255825758, 62.122596725821495, 61.666841581463814, 61.357606574893, 59.92179661989212, 57.051377445459366, 47.82139152288437, 44.70029599964619, 47.437501922249794, 48.03241319954395, 48.97754028439522, 49.60402026772499, 49.39895287156105, 45.44092185795307, 43.85118596255779, 42.431635335087776, 43.52659597992897, 43.541426584124565, 42.32616439461708, 46.96639560163021, 57.31710098683834, 53.383795246481895, 52.936650440096855, 51.6643875092268, 54.262786880135536, 55.29714837670326, 55.582475066185, 53.29817444086075, 56.29373610019684, 60.59760555624962, 59.18407000601292, 60.20645834505558, 55.74226789176464, 58.57711337506771, 54.89893354475498, 56.036014929413795, 48.18190857768059, 49.19350169599056, 35.21026723086834, 26.380631625652313, 44.83333446085453, 59.6554347127676, 76.62582948803902, 68.95457312464714, 38.313078135252, 44.5734816044569, 44.68159340322018, 48.32882009446621, 41.73549748957157, 53.700056076049805, 46.233357936143875, 47.51311406493187, 45.96049837768078, 46.411807760596275, 43.55760611593723, 44.5240842550993, 48.560748249292374, 42.71370179951191, 45.365309715270996, 46.09922893345356, 53.38408783078194, 53.67554359138012, 56.66004404425621, 56.632719710469246, 56.185343116521835, 54.55030605196953, 54.04521055519581, 55.673411786556244, 51.22077651321888, 53.30892786383629, 52.10418350994587, 50.74029229581356, 54.08120222389698, 54.93583336472511, 53.46079431474209, 58.11924174427986, 55.79063929617405, 51.72439008951187, 51.883248165249825, 55.9956306964159, 48.50017189979553, 41.44668638706207, 43.73214974999428, 43.106612116098404, 45.893652364611626, 40.97572825849056, 46.11474730074406, 46.374763548374176, 48.81869740784168, 46.915128752589226, 47.71932139992714, 46.42714373767376, 44.43477004766464, 46.22284770011902, 56.06218792498112, 58.30829679965973, 61.605881452560425, 55.716030299663544, 52.886949107050896, 54.28562365472317, 60.30593700706959, 63.226806074380875, 62.46481776237488, 60.51767684519291, 63.37656743824482, 62.63376049697399, 61.22650220990181, 59.21953350305557, 59.270017594099045, 54.38552409410477, 56.63193315267563, 54.780178517103195, 67.22270205616951, 65.30736163258553, 65.97459062933922, 67.29518696665764, 42.20495089888573, 0.26080865354742855, 22.349291145801544, 57.98983208835125, 45.94040505588055, 20.782941095530987, 40.71510784327984, 42.240528389811516, 54.8006746172905, 54.06276561319828, 50.944204553961754, 38.21044944226742, 0.6307031598407775, 0.11521075299242511, 0.07704467323492281, 0.15176559303654358, 0.052403578083612956, 0.0856117439980153, 0.10585343596176244, 0.10890466481214389, 0.01669494780799141, 0.08174481321475469, 0.08618594365543686, 0.06870006123790517, 0.046032882237341255, 0.046705809800187126, 0.06193399734911509, 0.11013990282663144, 0.167544721334707, 0.026812418873305432, 0.11541620915522799, 0.38436451577581465, 18.0627316609025, 75.34798845648766, 43.78663882613182, 50.92035323381424, 77.65782371163368, 58.05017665028572, 34.33998093008995, 45.24014823138714, 57.229192703962326, 47.537831738591194, 0.23298466141568497, 45.135133266448975, 86.4907157421112, 70.38680747151375, 72.86468490958214, 61.623280718922615, 60.048413425683975, 52.76676155626774, 58.27664829790592, 67.89645910263062, 63.487354293465614, 65.2709823846817, 66.77322417497635, 60.86157739162445, 65.25105625391006, 66.73584178090096, 67.02810689806938, 65.76926484704018, 63.99422809481621, 62.97043763101101, 62.01230004429817, 62.86965183913708, 62.042865604162216, 58.95262062549591, 49.433918595314026, 47.89613351225853, 49.26083788275719, 52.23084591329098, 53.07006888091564, 50.9382426738739, 51.442072838544846, 48.84262092411518, 48.771416544914246, 44.474595710635185, 43.62861670553684, 44.40956600010395, 46.456527560949326, 48.0592967569828, 58.89001898467541, 56.941092163324356, 54.90536279976368, 54.90193538367748, 55.59784144163132, 56.82432822883129, 57.10545614361763, 56.177298948168755, 60.215802043676376, 60.64720429480076, 62.27251008152962, 62.667901664972305, 58.91484685242176, 58.218655809760094, 57.44343280792236, 55.47155141830444, 50.34088432788849, 53.83668154478073, 37.19088815152645, 36.57269172370434, 56.69549234211445, 65.27514696121216, 75.83559349179268, 65.26557147502899, 37.35567390918732, 42.115621492266655, 43.17764550447464, 46.901913061738014, 40.92622831463814, 51.917670518159866, 47.07378923892975, 43.19792881608009, 43.25927272439003, 45.08406400680542, 43.496938571333885, 44.938642010092735, 46.81892171502113, 41.9709974527359, 44.39988411962986, 46.05819873511791, 54.03969705104828, 55.39438895881176, 59.86867927014828, 59.61438171565533, 58.5670705139637, 55.60630738735199, 56.50338605046272, 57.540950775146484, 53.348335549235344, 55.83324261009693, 53.66371862590313, 51.44414372742176, 56.39721594750881, 54.8570141941309, 57.08953879773617, 59.40389201045036, 56.714552119374275, 54.18542303144932, 53.08255881071091, 56.8271666765213, 52.76740752160549, 43.89573857188225, 42.82101944088936, 45.172340869903564, 49.275919273495674, 46.20150804519653, 50.4720114916563, 49.89717833697796, 53.311523124575615, 51.59611277282238, 50.14032728970051, 50.04459522664547, 46.020812541246414, 50.60644447803497, 58.1535729020834, 62.13538683950901, 63.054124340415, 60.36565460264683, 54.94925044476986, 56.80301517248154, 62.61520989239216, 64.8305556178093, 66.08641862869263, 66.4892578125, 66.0430857539177, 63.857519030570984, 64.171382188797, 61.3789614289999, 60.649096593260765, 57.06867031753063, 61.054892018437386, 62.47207157313824, 72.9935359954834, 69.67949822545052, 70.67644312977791, 74.62259218096733, 45.0015552341938, 0.11981207600911148, 27.780163027346134, 65.58552950620651, 49.89328354597092, 31.579497456550598, 51.56563840806484, 55.93495935201645, 52.325206249952316, 64.54985707998276, 61.34312555193901, 53.29197317361832, 0.6937112601008266, 0.10021427136962302, 0.040048129158094525, 0.048471078553120606, 0.0453679624479264, 0.10457513111759908, 0.08171363559085876, 0.07877487922087312, 0.15881802944932133, 0.1435088290600106, 0.26678294234443456, 0.3439921571407467, 0.08756840892601758, 0.2278810751158744, 0.19045381079195067, 0.18714631092734635, 0.2903369878185913, 0.1064961135853082, 0.4858796310145408, 0.6021401518955827, 23.038446865975857, 88.70641484856606, 49.683986976742744, 59.664801210165024, 79.71345260739326, 67.58703410625458, 39.307625368237495, 54.614659398794174, 65.91854363679886, 50.52890583872795, 0.4373010783456266, 53.91084976494312, 86.67742252349854, 74.48000863194466, 77.42045044898987, 66.07532322406769, 64.4925257563591, 56.27009756863117, 60.11668436229229, 70.13162076473236, 67.43979200720787, 68.11807081103325, 69.17031034827232, 61.46161839365959, 65.24661049246788, 67.7890008687973, 69.76329892873764, 67.29742124676704, 66.11813932657242, 68.52658689022064, 65.20699381828308, 64.3050666153431, 62.40557134151459, 62.76410110294819, 53.999073430895805, 50.25389939546585, 52.06457443535328, 51.53744012117386, 53.83411668241024, 52.6342398673296, 51.77968092262745, 51.735728681087494, 50.19464537501335, 49.30384777486324, 46.92123122513294, 45.18405184149742, 46.77366994321346, 50.89678309857845, 63.13586175441742, 58.73380556702614, 58.11334826052189, 54.892375096678734, 59.18240949511528, 60.09243406355381, 59.78312686085701, 57.826547250151634, 60.99135562777519, 64.2693105340004, 62.525382712483406, 64.62762370705605, 58.14875476062298, 63.47236409783363, 61.60688079893589, 58.717166259884834, 52.62357383966446, 57.46967040002346, 39.59806278347969, 48.979698568582535, 67.2123210132122, 64.99531477689743, 63.52432630956173, 55.135714039206505, 38.320825919508934, 43.31722341477871, 44.743830263614655, 47.94008195400238, 42.171231508255005, 50.992594957351685, 51.84589996933937, 50.406875386834145, 49.44319009780884, 46.82621732354164, 45.46363323926926, 46.82637311518192, 47.51363083720207, 43.31680543720722, 45.50401747226715, 45.82512304186821, 56.09456218779087, 54.686365351080894, 60.93080587685108, 60.69031298160553, 61.34044669568539, 56.002724915742874, 59.50989872217178, 60.278760865330696, 57.320106625556946, 55.55277965962887, 55.15814423561096, 53.79758924245834, 59.578963816165924, 57.64554776251316, 57.468971237540245, 62.06219896674156, 59.314574003219604, 54.78405810892582, 56.06409542262554, 59.242655262351036, 57.30149142444134, 47.98579730093479, 44.271834790706635, 44.726791977882385, 51.95935808122158, 49.293755516409874, 52.3965398222208, 50.679275169968605, 54.88032214343548, 54.29612249135971, 54.73381720483303, 50.436502397060394, 51.36394523084164, 55.16194403171539, 67.3094742000103, 66.47309347987175, 66.17188364267349, 60.447133630514145, 55.45695640146732, 55.18147498369217, 66.52831211686134, 71.6796424984932, 72.13605880737305, 70.23254334926605, 72.74829715490341, 63.844956904649734, 69.30927649140358, 64.17366966605186, 63.65934066474438, 62.00287654995918, 66.62829235196114, 61.29281625151634, 78.03225561976433, 70.8877269923687, 75.4059049487114, 73.3149303495884, 58.04099254310131, 0.24773449025815353, 29.668477401137352, 72.41211399435997, 56.33208364248276, 32.77047894895077, 55.40435962378979, 61.89226448535919, 66.44032403826714, 71.98709920048714, 69.80481550097466, 61.0649348795414, 0.8004397549666464, 0.2156226063380018, 0.34985316451638937, 0.28956693538930267, 0.06202189360919874, 0.17163394019007683, 0.13873637421056628, 0.33702796208672225, 0.2725151425693184], [0.05766258866060525, 0.07204696914413944, 0.047138801019173115, 0.09156011699815281, 0.03644919903308619, 0.043480914682731964, 0.046513660345226526, 0.003499414383441035, 0.02907742018578574, 0.057826284173643216, 0.16615861211903393, 15.579601004719734, 56.10771708190441, 40.81654720008373, 28.962245397269726, 34.443795159459114, 45.964260175824165, 23.03694974631071, 33.87532666325569, 50.50556369125843, 61.49922877550125, 3.5496612265706062, 14.06383479014039, 91.44301280379295, 63.00419881939888, 72.8969755768776, 59.60768647491932, 58.359985426068306, 55.47843284904957, 62.33225427567959, 62.79759630560875, 65.25282695889473, 62.794719859957695, 59.40902553498745, 58.68807502090931, 61.40232257544994, 61.96679748594761, 60.243027582764626, 60.093441009521484, 59.26051050424576, 57.840165719389915, 57.017145082354546, 60.08130066096783, 59.262437000870705, 53.94955448806286, 48.19807671010494, 43.96208681166172, 46.90308339893818, 49.894670471549034, 50.39743289351463, 51.41821771860123, 48.28419528901577, 50.262821316719055, 45.080594792962074, 45.12675851583481, 39.72686447203159, 42.562173530459404, 45.44486604630947, 48.74132975935936, 55.07505789399147, 52.801050916314125, 54.77641671895981, 56.36685557663441, 54.29885074496269, 53.275208473205566, 52.178689911961555, 55.11354982852936, 52.291882038116455, 53.833288326859474, 56.02293223142624, 58.709673061966896, 55.85250377655029, 59.87509332597256, 57.06833213567734, 51.11442781984806, 47.37065210938454, 38.9484154433012, 48.0797054618597, 51.82463251054287, 47.036931216716766, 46.93095110356808, 44.6408785879612, 39.151487946510315, 38.81106421351433, 47.00438216328621, 43.65928865969181, 45.977757051587105, 46.357440277934074, 37.595080062747, 48.656088933348656, 54.10295605659485, 51.944337487220764, 49.02956709265709, 45.85616357624531, 42.81704485416412, 48.56441505253315, 42.978756576776505, 44.67465117573738, 49.5635524392128, 51.61984249949455, 55.10603003203869, 52.682618871331215, 53.48735108971596, 51.800610199570656, 55.51463730633259, 53.62195126712322, 51.20505675673485, 52.47780226171017, 53.3045618981123, 52.53098040819168, 54.629923179745674, 54.40282076597214, 57.36521780490875, 53.10105621814728, 51.83874115347862, 52.06732928752899, 51.428085789084435, 49.315528348088264, 52.7771881967783, 53.698152378201485, 44.224276542663574, 43.57285089790821, 45.03821946680546, 45.318249240517616, 48.12099404633045, 45.043979957699776, 47.5061110407114, 47.209506556391716, 50.04602015018463, 49.337703958153725, 48.24270151555538, 44.966426119208336, 42.97601692378521, 49.6703115105629, 55.87175354361534, 56.23072788119316, 61.94812908768654, 59.54467065632343, 56.487901881337166, 51.892322078347206, 47.75591343641281, 55.51448531448841, 64.24031808972359, 62.23336078226566, 66.37314364314079, 60.97164608538151, 63.2582151889801, 57.09863930940628, 59.49881091713905, 51.10787317156792, 60.85542932152748, 62.449098005890846, 72.83445373177528, 63.936060816049576, 76.20076909661293, 19.03187345713377, 0.12030897356453352, 38.2755209505558, 60.572184920310974, 35.01350238919258, 18.77323843538761, 32.18884415924549, 41.0477077960968, 27.60787457227707, 36.07541620731354, 54.868827760219574, 48.07829953730106, 1.9544136081822217, 0.05464114590722602, 0.03482654508843552, 0.025730059569468722, 0.10211526780040003, 0.022674921456200536, 0.045558646161225624, 0.020297571973060258, 0.06002515641739592, 0.025231353029084858, 0.07437797336024232, 0.033655962979537435, 0.020442556087800767, 0.07428412878653035, 0.010180338395002764, 0.08729332446819171, 0.04438565578311682, 0.03472038828476798, 0.1239826119854115, 0.12543259043013677, 23.590148761868477, 64.62067767977715, 45.68983510136604, 39.68164689838886, 43.80487024784088, 53.009230345487595, 27.128995768725872, 39.43583808839321, 53.158558532595634, 71.7872679233551, 5.231194021180272, 11.032322309911251, 92.74456456303596, 66.8018290400505, 78.23996007442474, 67.34999522566795, 62.88112722337246, 59.27481293678284, 67.85795196890831, 65.6596103310585, 68.86367440223694, 63.435373082756996, 60.98915934562683, 59.90567408502102, 64.19754758477211, 62.91066683828831, 63.21715459227562, 61.615624129772186, 62.364647537469864, 59.974005818367004, 58.45677003264427, 61.37490704655647, 61.67285665869713, 54.23749543726444, 49.83608901500702, 47.55355529487133, 48.849570751190186, 49.29529823362827, 53.86622115969658, 52.62780301272869, 52.764641270041466, 52.15412802994251, 49.16023828089237, 47.65940621495247, 43.599267080426216, 43.2624189555645, 47.45427802205086, 52.465684711933136, 57.550100684165955, 56.20784550905228, 57.011946961283684, 58.655810952186584, 57.521647810935974, 55.48047713935375, 53.93431730568409, 55.19489586353302, 55.838957503437996, 57.06448294222355, 57.846450582146645, 61.68594315648079, 59.06158737838268, 59.84276466071606, 56.596678644418716, 50.54870657622814, 47.03348480165005, 38.848116025328636, 52.19029448926449, 51.941062062978745, 45.33493414521217, 48.95513288676739, 42.407924607396126, 35.99838674068451, 40.376006439328194, 48.707522973418236, 43.11318576335907, 45.29599763453007, 44.148379415273666, 36.713124588131905, 48.10683600604534, 52.91002906858921, 52.77123771607876, 48.50264556705952, 45.50393767654896, 43.28059338033199, 48.24399724602699, 43.720510974526405, 44.26273427903652, 47.34805092215538, 51.27666011452675, 55.15616834163666, 55.41365012526512, 54.989319294691086, 53.25115956366062, 56.86633877456188, 53.190492019057274, 53.41195173561573, 54.77717287838459, 54.736735448241234, 55.178169161081314, 58.4748000651598, 58.25173683464527, 60.569631457328796, 52.17849612236023, 54.33014966547489, 55.55966109037399, 52.870252802968025, 50.272115617990494, 55.085704922676086, 56.48945979773998, 47.64138378202915, 44.819282814860344, 46.828903779387474, 50.204441249370575, 53.44123676419258, 50.583231523633, 52.20268942415714, 50.46438530087471, 54.02238517999649, 52.28083223104477, 51.453289836645126, 48.73906888067722, 48.203594014048576, 51.57464012503624, 59.38990116119385, 59.56065259873867, 64.72216263413429, 61.388578712940216, 58.6961305886507, 53.63545574247837, 53.72716002166271, 60.20140081644058, 65.9041728079319, 65.18467381596565, 68.78631815314293, 63.48773047327995, 63.42057667672634, 59.69992272555828, 62.014454528689384, 55.14676384627819, 64.96405005455017, 65.20187929272652, 74.00050476193428, 65.5532768368721, 82.77990326285362, 18.367610201239586, 0.13960770011181012, 47.40779131650925, 64.08059746026993, 39.99083250761032, 27.137735299766064, 33.5430458933115, 48.57292279601097, 27.060561440885067, 43.39998297393322, 60.4799410700798, 59.62522633373737, 3.3637450402602553, 0.043827816771226935, 0.09309615488746203, 0.04562369911582209, 0.04053389449836686, 0.06703911247313954, 0.08237218775320798, 0.040535286025260575, 0.0174976751441136, 0.1612881344044581, 0.14591015176847577, 0.13418628164799884, 0.22772627795347944, 0.10251253945170902, 0.13241817418020219, 0.129995433089789, 0.07657420355826616, 0.13744889642111957, 0.20690747711341828, 0.20797094504814595, 30.500879734754562, 77.936622351408, 55.8724907040596, 43.843821957707405, 46.409904062747955, 63.85888695716858, 31.31732862442732, 50.11852785944939, 59.64870147407055, 81.66897967457771, 4.637682493776083, 17.828288041055202, 96.52302861213684, 70.63583090901375, 79.62570771574974, 70.55310174822807, 64.82784256339073, 62.120058462023735, 71.88306078314781, 65.98765432834625, 71.60870790481567, 68.5217459499836, 63.512394949793816, 62.22133442759514, 66.37275606393814, 65.64849212765694, 66.3331013917923, 68.11546415090561, 65.67151889204979, 64.99952495098114, 60.403914749622345, 63.68152767419815, 64.1369180381298, 56.583333760499954, 55.696643739938736, 48.45742419362068, 50.73636710643768, 51.84980995953083, 56.70583538711071, 55.61381198465824, 56.285672932863235, 54.51329983770847, 53.78156550228596, 51.24581336975098, 45.15646532177925, 45.240410417318344, 49.32532042264938, 54.463796094059944, 60.75673721730709, 60.08627839386463, 59.888597801327705, 60.8892323076725, 60.377255380153656, 57.708149403333664, 57.36815504729748, 59.68288443982601, 59.59296986460686, 59.469803273677826, 61.96498118340969, 61.979690194129944, 62.08687864243984, 61.75899803638458, 60.18526688218117, 54.09233942627907, 47.56531946361065, 39.36950504779816, 52.1243604272604, 50.270907282829285, 48.2954540848732, 50.51947094500065, 42.33763597905636, 35.87331265211105, 41.34455546736717, 47.16822937130928, 44.67477276921272, 44.7120525687933, 48.102561235427856, 37.864462807774544, 47.24731832742691, 53.66768181324005, 50.307480320334435, 50.97884349524975, 46.480253487825394, 45.2496363222599, 49.92695353925228, 43.758311346173286, 44.625835195183754, 50.03366321325302, 56.79756626486778, 59.98966097831726, 57.105433344841, 57.00703002512455, 55.56640572845936, 59.338850900530815, 55.83658643066883, 55.257626697421074, 55.67952945828438, 56.40192769467831, 58.1760410964489, 59.704478681087494, 61.67552411556244, 64.65830326080322, 56.13560378551483, 55.51462210714817, 60.10748125612736, 54.248841628432274, 53.817587569355965, 57.16007821261883, 59.33348938822746, 47.869075164198875, 48.095907792449, 48.55372242629528, 54.43448446691036, 56.17803230881691, 53.42166781425476, 54.93576496839523, 52.81254529953003, 55.44006250798702, 56.08845591545105, 54.26868416368961, 51.419030874967575, 51.24166779220104, 57.444899529218674, 62.85319872200489, 61.92173570394516, 66.6106840968132, 63.96188423037529, 60.828952342271805, 54.9293927103281, 53.21662321686745, 62.76932202279568, 68.36511835455894, 69.22831803560257, 73.99073928594589, 64.89702925086021, 68.70393857359886, 61.40744470059872, 63.149784207344055, 59.500767812132835, 67.93368950486183, 67.2883853316307, 78.19560125470161, 70.46853348612785, 85.58458596467972, 26.132630333304405, 0.2372959753847681, 49.59539473056793, 73.56557250022888, 49.67251159250736, 27.561118081212044, 43.50162371993065, 57.286603823304176, 34.06982682645321, 49.969917833805084, 67.91567087173462, 69.83779013156891, 3.980184062384069, 0.1612888468662277, 0.13578062265878543, 0.11827778216684237, 0.14839198265690356, 0.20046222140081227, 0.15033973439130932, 0.12410090290359221, 0.1300483482191339], [0.031465977954212576, 0.04938337100611534, 0.027141880491399206, 0.048559416391071863, 0.04444345424417406, 0.03374423773493618, 0.036044606094947085, 0.08967116562416777, 0.03043675642402377, 0.08074826473603025, 0.22048443061066791, 24.34852346777916, 54.75348114967346, 43.48658412694931, 30.915074609220028, 24.06558685004711, 44.28041473031044, 27.001225724816322, 29.58446580916643, 60.04830703139305, 65.86931347846985, 12.78756782412529, 1.5362129174172878, 72.30338662862778, 70.94584867358208, 71.89583569765091, 62.43757702410221, 59.37943272292614, 56.187254413962364, 63.06610129773617, 61.35236665606499, 63.45914080739021, 57.74017408490181, 60.346435233950615, 60.74727572500706, 59.28362466394901, 60.3756632655859, 61.538944244384766, 58.75410407781601, 56.21041797101498, 56.634896993637085, 58.896543234586716, 58.57055492699146, 54.09093350172043, 51.372304782271385, 44.97443608939648, 45.65417781472206, 49.46294143795967, 55.456348434090614, 53.99841606616974, 53.89495521783829, 52.249366119503975, 50.21430931985378, 48.69157902896404, 46.23874604701996, 41.967862620949745, 43.761962950229645, 44.11451183259487, 48.529939502477646, 53.71283859014511, 56.513052731752396, 53.100634440779686, 53.05651880800724, 51.809159740805626, 54.24651615321636, 53.18651743233204, 52.142538651824, 52.053741216659546, 57.031105533242226, 57.15942084789276, 58.582657277584076, 56.87871091067791, 57.874105498194695, 57.540650591254234, 48.902745097875595, 46.21938608586788, 48.97102743387222, 45.63931301236153, 43.41380663216114, 42.11966447532177, 38.85843247175217, 38.832388669252396, 43.86885121464729, 45.99398598074913, 45.68667747080326, 41.776995062828064, 40.233289897441864, 42.26050391793251, 43.24662700295448, 40.18080711364746, 39.72688727080822, 43.65710757672787, 50.32732665538788, 40.577027052640915, 47.768445163965225, 44.13324862718582, 47.19310283660889, 41.94202400743961, 52.16137804090977, 56.00373946130276, 55.03629997372627, 51.31448708474636, 52.464293986558914, 54.00357238948345, 57.616198137402534, 53.59874211251736, 52.74502672255039, 51.43128141760826, 55.210163444280624, 52.8548826277256, 56.026101261377335, 57.11500883102417, 54.70778480172157, 51.91647358238697, 52.337380796670914, 52.1185277402401, 52.33117192983627, 51.66330836713314, 52.872217297554016, 46.10049046576023, 43.25875595211983, 42.603712901473045, 49.139909371733665, 46.90703518688679, 50.84054611623287, 46.940708979964256, 50.3309478610754, 50.14003470540047, 54.96971234679222, 51.00209064781666, 50.53978845477104, 46.02487452328205, 47.11165800690651, 42.869603633880615, 49.49232906103134, 55.653322264552116, 57.72453412413597, 58.814410641789436, 62.177477180957794, 60.664557963609695, 62.6811857521534, 54.35128033161163, 59.032211154699326, 60.94455733895302, 64.60689961910248, 58.526652082800865, 63.42453986406326, 59.26926143467426, 58.25036510825157, 51.62298113107681, 62.626791670918465, 64.46993976831436, 70.62623262405396, 61.51009239256382, 77.14511722326279, 4.396686125546694, 2.5418534176424146, 62.524010986089706, 59.925265833735466, 23.42916090041399, 23.87071430683136, 38.55319485068321, 32.695288583636284, 53.78373898565769, 48.51613104343414, 53.56417916715145, 51.88075169920921, 4.957888461649418, 0.21957880264380947, 0.08506678495905362, 0.14699772465974092, 0.08716456184629351, 0.09772896723006852, 0.03343289936310612, 0.030541534688381944, 0.08747125437366776, 0.04667503293603659, 0.0635922298533842, 0.11129069185699336, 0.035083558250335045, 0.026987643650500104, 0.07405741751426831, 0.05680282170942519, 0.04068191956321243, 0.05080285089206882, 0.039691920537734404, 0.10872026337892748, 31.930955797433853, 67.78406873345375, 47.71358750760555, 38.67179408669472, 33.169651329517365, 51.93112179636955, 29.031623974442482, 33.48800964653492, 63.10439944267273, 73.42808827757835, 15.978325009346008, 0.7498286082409322, 70.72197988629341, 73.22182774543762, 76.4758363366127, 68.3354951441288, 61.192402839660645, 59.40519534051418, 67.0239195227623, 64.49376448988914, 65.0421890616417, 61.09539024531841, 61.79430194199085, 64.49542120099068, 62.22820445895195, 63.89241635799408, 65.40225014090538, 62.73798130452633, 58.581327348947525, 60.19713744521141, 61.61796100437641, 60.63210390508175, 57.101713344454765, 53.567587584257126, 46.147151961922646, 49.33095932006836, 51.4464920014143, 59.219442307949066, 56.54723569750786, 57.97894187271595, 53.9580774307251, 51.869074925780296, 50.03942370414734, 48.53129602968693, 45.923579558730125, 46.62765517830849, 45.78734166920185, 51.13666422665119, 54.82386477291584, 58.642306476831436, 57.21566542983055, 56.1790506541729, 53.2032935321331, 56.72283947467804, 53.73347528278828, 54.86858457326889, 53.956283926963806, 58.34455445408821, 58.087327256798744, 61.063012182712555, 58.437649458646774, 59.92976099252701, 57.82755419611931, 47.939177602529526, 48.26447054743767, 48.115233555436134, 48.337270841002464, 44.39522176980972, 41.7294330149889, 36.82713367044926, 39.170129746198654, 45.75638473033905, 45.42634204030037, 44.84146602451801, 41.15216039121151, 38.75780247151852, 41.62266254425049, 42.1980656683445, 41.29996486008167, 38.37253734469414, 44.75432530045509, 48.76962684094906, 41.814366057515144, 48.00189323723316, 44.97626379132271, 49.92444187402725, 40.59451371431351, 53.52751113474369, 56.76996074616909, 56.85384504497051, 51.766590625047684, 51.771857142448425, 53.179711997509, 57.45271950960159, 55.93647547066212, 56.22892677783966, 49.45536844432354, 57.36555218696594, 56.06374964118004, 59.09713067114353, 57.457625046372414, 57.51651808619499, 52.70778492093086, 52.61562466621399, 53.42503443360329, 55.53484082221985, 54.074552580714226, 53.97378198802471, 47.094384133815765, 44.278754219412804, 47.86567434668541, 52.99929767847061, 50.71845106780529, 57.05613858997822, 49.830271527171135, 53.675668984651566, 51.662103831768036, 57.598361894488335, 54.14017125964165, 55.83786316215992, 50.89701488614082, 49.92754630744457, 46.30384415388107, 54.65435966849327, 58.29997904598713, 60.94298802316189, 61.28714315593243, 66.34320884943008, 63.273463770747185, 64.6273273229599, 55.24678207933903, 60.18669180572033, 63.583568930625916, 67.94877469539642, 61.32252685725689, 68.2604567706585, 59.77655701339245, 62.21072919666767, 54.23319026827812, 69.90400537848473, 67.72347718477249, 77.6125605404377, 65.52833497524261, 80.41157394647598, 2.573005333542824, 4.400930497795343, 71.48123234510422, 64.34497967362404, 30.731251873075962, 27.991937063634396, 34.68568257987499, 44.26504835486412, 48.664277493953705, 54.43501263856888, 65.00764891505241, 62.0606030523777, 10.629244688898325, 0.1326942234300077, 0.20696956518804654, 0.1204300846438855, 0.09450330398976803, 0.04884820089500863, 0.17933024908415973, 0.04132352478336543, 0.11280039834673516, 0.23404940584441647, 0.152345136157237, 0.19014209392480552, 0.17882112093502656, 0.2217980319983326, 0.13868261303287, 0.11372951528755948, 0.1527089814771898, 0.2501583594130352, 0.22992870508460328, 0.3124171873787418, 39.154797568917274, 77.27725133299828, 59.66088742017746, 43.85966330766678, 37.985459715127945, 63.6944317817688, 40.20093463361263, 44.4827538728714, 69.09146457910538, 83.52311298251152, 16.129843778908253, 2.5806704722344875, 86.29118844866753, 75.65462440252304, 82.90803998708725, 67.79463976621628, 67.59539365768433, 62.80515030026436, 69.14423614740372, 64.82170969247818, 68.35438013076782, 61.259967014193535, 62.585544884204865, 66.5208949148655, 64.88607063889503, 68.12772989273071, 70.02955064177513, 61.426067501306534, 62.88564518094063, 61.181136444211006, 64.06154528260231, 60.32006464898586, 60.05708836019039, 54.40434828400612, 48.34302373230457, 49.3679541349411, 53.51146079599857, 60.08708395063877, 58.636895567178726, 60.006136894226074, 57.61621713638306, 55.87893135845661, 51.981598287820816, 52.06995114684105, 45.538766607642174, 47.627066150307655, 46.92767947912216, 50.27928963303566, 59.43939350545406, 59.760081097483635, 59.50902096927166, 56.9582824409008, 57.38385200500488, 59.60682012140751, 56.136815920472145, 58.382461220026016, 55.056549087166786, 60.69470934569836, 61.75272837281227, 64.65530142188072, 62.06278793513775, 62.46194131672382, 61.892207488417625, 49.317500442266464, 48.657966032624245, 49.50731925666332, 51.56223379075527, 45.29123269021511, 42.835378870368004, 36.43444374203682, 38.985763639211655, 45.311447605490685, 45.282223373651505, 46.558992862701416, 40.99390648305416, 40.09242005646229, 41.85628920793533, 43.52259859442711, 42.642531618475914, 39.15252909064293, 49.379611909389496, 50.49967780709267, 42.45696097612381, 50.77995456755161, 45.01471012830734, 49.52528849244118, 41.07756659388542, 55.90675346553326, 58.704303950071335, 59.29610699415207, 54.84259016811848, 58.62994194030762, 58.277233466506004, 61.07655465602875, 57.061762288212776, 60.30811049044132, 53.70168998837471, 60.58226577937603, 55.624766796827316, 61.367843225598335, 61.609859839081764, 59.67676296830177, 53.27569104731083, 54.9807583540678, 54.81322914361954, 58.62839162349701, 54.250129759311676, 57.532762214541435, 49.45742793381214, 46.31611369550228, 47.55505621433258, 53.9741999655962, 52.67148546874523, 61.2595072388649, 55.72315491735935, 59.64674457907677, 54.03687380254269, 60.899962931871414, 56.408083364367485, 56.610715091228485, 54.10352602601051, 51.0516893863678, 48.76233123242855, 56.93084791302681, 61.4495350420475, 62.3622802644968, 66.56217589974403, 69.90353420376778, 65.22764191031456, 64.2330376803875, 58.032841980457306, 65.6163914501667, 64.53894406557083, 69.80642661452293, 64.55548077821732, 74.07764822244644, 64.20323967933655, 65.21852239966393, 58.85855287313461, 74.56698596477509, 70.9389254450798, 81.61626130342484, 67.17019647359848, 90.76798662543297, 5.6481280736625195, 3.2194608449935913, 77.05061629414558, 72.07524687051773, 37.70134516060352, 30.873423144221306, 49.808988869190216, 50.04670411348343, 67.20098242163658, 63.12120974063873, 67.77533680200577, 73.3302815258503, 11.811729837208986, 0.6510145543143153, 0.3574303141795099, 0.3774069406790659, 0.1519431741326116, 0.27106480789370835, 0.2771505672717467, 0.13834132900228724, 0.3685159521410242], [0.09297937795054168, 0.028312438480497804, 0.05604043566563632, 0.042051979835378006, 0.026656339650799055, 0.10127347937668674, 0.03046909550903365, 0.08442118327366188, 0.07459867323632352, 0.32028469489887357, 0.4978811979526654, 31.513912975788116, 53.020815923810005, 51.04091316461563, 34.44817632436752, 31.1463226005435, 38.12394328415394, 30.697382390499115, 24.317659623920918, 55.51167346537113, 66.19700789451599, 38.854005709290504, 0.07814691838575527, 32.04635940492153, 81.74373686313629, 64.18251559138298, 71.97486385703087, 54.668099731206894, 62.177598774433136, 62.87759721279144, 65.41648417711258, 58.9121337980032, 58.40117521584034, 61.30988873541355, 60.33643797039986, 58.07054355740547, 61.76541209220886, 57.924904972314835, 58.880291506648064, 54.186236187815666, 57.35015541315079, 58.72797667980194, 57.849144637584686, 52.605262622237206, 47.0857547968626, 44.83405262231827, 50.086385384202, 53.046240359544754, 53.98075841367245, 55.67069113254547, 56.947608813643456, 55.19984319806099, 53.16702447831631, 49.287075474858284, 49.88351806998253, 48.89764957129955, 48.77977229654789, 47.97805331647396, 50.98615050315857, 51.62945218384266, 52.05521173775196, 55.63859425485134, 57.95244589447975, 53.51214095950127, 52.74848833680153, 52.01149508357048, 53.891463205218315, 53.948513343930244, 53.75627785921097, 57.38224469125271, 58.375329002738, 55.496231094002724, 57.94916667044163, 54.9008334428072, 48.6516659706831, 47.0295026153326, 45.68737283349037, 48.69509004056454, 41.13998584449291, 43.861794993281364, 43.78214746713638, 46.50540813803673, 48.687790632247925, 41.35220065712929, 40.45316509902477, 41.70546390116215, 41.0001153498888, 40.17446905374527, 36.09989069402218, 39.1808907687664, 44.69785653054714, 52.98887863755226, 44.59722273051739, 39.081575497984886, 46.131151020526886, 40.36964938044548, 47.97648400068283, 46.44037842750549, 44.45902794599533, 49.39897947013378, 53.395612612366676, 57.88245365023613, 54.10071797668934, 55.13131767511368, 54.929179921746254, 53.21734897792339, 53.63878056406975, 52.02556952834129, 53.062758073210716, 51.50670737028122, 52.73607060313225, 55.63364312052727, 56.616836562752724, 53.63166734576225, 52.99265183508396, 49.33240324258804, 50.75921148061752, 54.91778053343296, 48.04450035095215, 47.11538940668106, 45.94866581261158, 50.79573892056942, 50.091412514448166, 49.21858415007591, 50.86656332015991, 48.97377468645573, 50.63024640083313, 53.895844370126724, 54.658102467656136, 50.593506172299385, 54.99066062271595, 50.88057316839695, 44.822018668055534, 44.644393399357796, 45.93946650624275, 51.38306960463524, 57.450192645192146, 57.102085724473, 59.15446199476719, 59.474484622478485, 60.076649710536, 56.94305665791035, 55.47593638300896, 61.210239082574844, 65.79999759793282, 62.45185665786266, 62.264412716031075, 58.7871965020895, 59.82963256537914, 53.26888561248779, 63.35715048015118, 64.66113790869713, 67.07639470696449, 66.6730235517025, 53.65035854279995, 0.41836295393295586, 17.50153787434101, 69.65459436178207, 41.92290723323822, 13.380526956170797, 34.123719334602356, 27.255441583693027, 28.928529806435108, 32.62028440833092, 28.195845521986485, 36.75270326435566, 62.01038874685764, 13.997829481959343, 0.08011992540559731, 0.22086662182118744, 0.05498222213645931, 0.11167006290634163, 0.05045087993494235, 0.06529242338729091, 0.044553737388923764, 0.013874486066924874, 0.041425102535868064, 0.058068020225618966, 0.03185583926097024, 0.053452896972885355, 0.017391716864949558, 0.19951397931436077, 0.0067265695724927355, 0.048011600083555095, 0.08144908963004127, 0.19641775405034423, 0.33194882213138044, 40.819001868367195, 62.125400975346565, 61.05902999639511, 34.6377557516098, 34.850361943244934, 51.33882477879524, 44.51719142496586, 30.264866799116135, 63.361326456069946, 69.1239832341671, 49.75571192800999, 0.0506522468640469, 29.64932832866907, 84.73875135183334, 66.97891473770142, 77.47873172163963, 58.549101278185844, 64.55130100250244, 65.44492945075035, 67.7155052125454, 60.8544147759676, 61.03306598961353, 63.82116258144379, 62.2044937312603, 60.49689196050167, 66.24048516154289, 60.31295523047447, 59.98890481889248, 57.510381415486336, 60.241021290421486, 59.62187871336937, 58.78767527639866, 53.93961422145367, 48.384897485375404, 46.443072482943535, 51.41431912779808, 53.05573605000973, 55.809330493211746, 56.72839097678661, 59.44830022752285, 54.94959242641926, 54.39039923250675, 52.815387547016144, 53.133897855877876, 49.704517275094986, 48.911233842372894, 49.86688256263733, 51.96351885795593, 54.384691938757896, 55.67049354314804, 57.87014991044998, 61.16484671831131, 56.09922453761101, 54.500464126467705, 55.426987409591675, 54.51447777450085, 58.34930419921875, 56.24780796468258, 58.35065312683582, 60.6179116666317, 56.45538702607155, 58.983486369252205, 58.214935809373856, 51.211827993392944, 45.4934274405241, 44.825294092297554, 50.64447283744812, 40.15980564057827, 44.6636051684618, 43.77407290041447, 45.991288125514984, 47.87725992500782, 41.69447869062424, 41.069955602288246, 40.993773490190506, 40.20025447010994, 38.69338072836399, 35.41879624128342, 37.62870065867901, 44.03728857636452, 54.35872033238411, 43.899895548820496, 39.73168261349201, 46.81547909975052, 39.68128591775894, 47.12769314646721, 45.197183936834335, 44.45679746568203, 49.76709611713886, 53.146965354681015, 59.57350730895996, 54.67336244881153, 55.278620570898056, 55.11578030884266, 55.88299334049225, 55.44006630778313, 54.440146163105965, 55.64112491905689, 53.18463273346424, 54.040628001093864, 59.017760530114174, 61.37395329773426, 55.58134272694588, 52.38244257867336, 50.454357638955116, 52.118835523724556, 54.42272029817104, 49.246482253074646, 48.9379920065403, 47.55086123943329, 54.143967255949974, 49.60492081940174, 53.19903016090393, 54.71686251461506, 52.095656767487526, 54.4978878647089, 56.90538927912712, 57.1736016869545, 55.800051391124725, 57.01048403978348, 55.50297573208809, 48.17243568599224, 48.471901416778564, 50.830104276537895, 53.39155822992325, 60.700196251273155, 60.550070106983185, 60.770211294293404, 60.97979284822941, 61.65760047733784, 59.97757762670517, 57.6452399790287, 60.53172469139099, 66.09884396195412, 62.90638446807861, 64.85578626394272, 63.79688948392868, 63.80014210939407, 55.982642993330956, 67.5537858903408, 70.6240363419056, 70.81125989556313, 70.70045784115791, 51.22843310236931, 0.40586070448625833, 24.578285738825798, 73.08698058128357, 47.787223756313324, 16.456896029412746, 33.43272261321545, 22.944631800055504, 32.10372492671013, 33.79222892224789, 30.762638188898563, 50.38845777511597, 71.8775662779808, 23.930678889155388, 0.29655250429641455, 0.25611358985770494, 0.026522474763623904, 0.10415160228149034, 0.06607595321838744, 0.040058226077235304, 0.03534105751896277, 0.005314183690643404, 0.16044015646912158, 0.25464309845119715, 0.1501694114995189, 0.16591723600868136, 0.1674462977098301, 0.3439272043760866, 0.10601540227071382, 0.10766119637992233, 0.15603447100147605, 0.5364097945857793, 0.6209223659243435, 49.57472763955593, 71.41085252165794, 70.56647703051567, 46.391870230436325, 45.293045192956924, 54.86828438937664, 44.205642342567444, 37.65670135617256, 67.75553226470947, 78.12893763184547, 51.53671436011791, 0.16964994196314365, 41.67449176311493, 85.90042501688004, 71.82667940855026, 79.15105238556862, 61.345838606357574, 67.6610617339611, 68.71776983141899, 70.56593745946884, 64.84564080834389, 62.654404789209366, 65.1475802063942, 64.71723049879074, 62.754913195967674, 69.0020401775837, 62.468203380703926, 62.46321424841881, 60.08956141769886, 63.21771316230297, 62.2101516276598, 62.03375369310379, 55.017145201563835, 52.143351808190346, 50.45378386974335, 54.35680903494358, 55.11793479323387, 58.69390770792961, 58.71165655553341, 61.931660771369934, 58.96861396729946, 56.14214323461056, 54.38878431916237, 54.84662935137749, 51.05825163424015, 50.70690728724003, 50.94351679086685, 53.51370267570019, 56.33629381656647, 57.88185328245163, 64.10613968968391, 64.91975963115692, 58.96001122891903, 57.15445451438427, 58.70096392929554, 60.03378041088581, 62.32189983129501, 60.57390622794628, 60.45808844268322, 62.596161514520645, 60.07888779044151, 63.27655300498009, 61.01024441421032, 54.82353799045086, 47.370450720191, 43.96803729236126, 50.6331342458725, 43.14970180392265, 43.38951833546162, 44.72166985273361, 46.68331079185009, 50.74413388967514, 41.6409395635128, 41.83350183069706, 40.44751100242138, 42.116180062294006, 39.7962449491024, 35.80594226717949, 39.283477663993835, 45.940222665667534, 55.24336226284504, 44.199547469615936, 42.953563928604126, 47.63840854167938, 41.01748801767826, 49.42056231200695, 46.21071495115757, 45.70948384702206, 50.669627487659454, 56.68360657989979, 60.62415853142738, 57.298333793878555, 59.025059938430786, 58.11491757631302, 56.9088850915432, 60.278802663087845, 57.136812061071396, 60.62650680541992, 54.86782841384411, 56.82898297905922, 61.95604786276817, 63.8774299621582, 57.56467290222645, 51.90465621650219, 52.88235895335674, 55.21677888929844, 56.86921142041683, 50.57170294225216, 51.942228600382805, 48.28946940600872, 56.79963335394859, 52.641972452402115, 56.343065053224564, 59.01689037680626, 55.700492933392525, 59.29222360253334, 58.96357923746109, 58.21718528866768, 57.41759419441223, 60.005570724606514, 59.33396816253662, 49.445382580161095, 52.37770043313503, 53.855251148343086, 55.95667138695717, 62.83453032374382, 62.8818453848362, 65.32053172588348, 63.723051846027374, 65.26051014661789, 61.39604151248932, 59.318081215023994, 64.67673987150192, 70.41282847523689, 64.61940094828606, 67.49445587396622, 63.846963196992874, 66.6485832631588, 57.42289870977402, 70.76785862445831, 74.27760109305382, 73.33583682775497, 69.77777615189552, 68.28368872404099, 0.3752051369519904, 21.148544177412987, 84.39660251140594, 57.26231932640076, 27.81656887382269, 42.73528844118118, 37.16851495206356, 39.86147604882717, 44.92957189679146, 39.41587395966053, 49.7406305372715, 82.63686373829842, 29.906603023409843, 0.3193957800976932, 0.3622345923213288, 0.1572255586506799, 0.28096018941141665, 0.2642463112715632, 0.16717251943191513, 0.09252569565433078, 0.13182297174353153], [0.06006157731462736, 0.11298996512778103, 0.029192115398473106, 0.0833161328046117, 0.12615012848982587, 0.029442170925904065, 0.10235855865175836, 0.032101226679515094, 0.12927831063279882, 0.14298243855591863, 0.11984262280748226, 35.39346680045128, 55.68581432104111, 50.593346580863, 30.28062455356121, 34.89587590098381, 30.665154419839382, 16.47507805377245, 20.426510721445084, 55.384042114019394, 59.60770547389984, 65.54806351661682, 12.76830855756998, 5.028262585401535, 80.9021732211113, 63.02761696279049, 76.5243749320507, 61.73000939190388, 62.79617138206959, 59.74651962518692, 68.0215559899807, 61.40196159482002, 65.8937993645668, 59.53390583395958, 63.57280030846596, 58.86827275156975, 61.32826454937458, 56.54642254114151, 57.94068552553654, 55.68564713001251, 61.513261422514915, 56.843805983662605, 56.15856975317001, 48.35771754384041, 49.071771427989006, 45.20631864666939, 51.63612462580204, 55.31536839902401, 56.835454031825066, 58.87876778841019, 57.207359075546265, 52.65822038054466, 53.12550030648708, 48.83023738861084, 52.9782772064209, 50.40802672505379, 50.18375515937805, 54.247857481241226, 52.991162315011024, 53.02938066422939, 55.14598488807678, 53.80189061164856, 54.024756252765656, 49.33114551007748, 52.74030737578869, 52.278453558683395, 51.238506361842155, 53.1400041282177, 53.24910007417202, 55.48655301332474, 56.10126122832298, 55.13835109770298, 56.06438420712948, 53.93046051263809, 51.70315682888031, 49.0223740786314, 51.15642696619034, 41.51855953037739, 40.21840609610081, 43.32317769527435, 45.55989347398281, 45.57812489569187, 42.3832069337368, 38.87639030814171, 39.01885986328125, 40.90837687253952, 38.495836928486824, 39.36878688633442, 35.8929879963398, 36.8534092605114, 43.064191192388535, 43.526668176054955, 43.66261348128319, 44.93382386863232, 44.92610648274422, 38.31077925860882, 43.05974543094635, 45.742952451109886, 43.09401959180832, 48.19947123527527, 47.46185481548309, 47.23404943943024, 55.018414333462715, 53.8127276301384, 53.95491220057011, 55.20910330116749, 53.34240406751633, 51.34977959096432, 50.32448060810566, 52.66755647957325, 51.71852320432663, 52.47719429433346, 56.01958841085434, 51.74620471894741, 50.07963314652443, 49.711505100131035, 49.15913634002209, 50.84374934434891, 53.032614290714264, 50.426854714751244, 52.66248755156994, 48.91694113612175, 48.89441594481468, 50.36206439137459, 46.94512814283371, 47.35404320061207, 51.277249082922935, 54.227524772286415, 55.8342457562685, 55.04958786070347, 55.525789707899094, 53.880170211195946, 50.345683470368385, 46.09972670674324, 45.767331942915916, 45.82396790385246, 51.00917726755142, 59.08802255988121, 57.35360562801361, 61.47255800664425, 59.53873157501221, 64.10840436816216, 57.176067754626274, 56.40169210731983, 63.17750371992588, 60.64136020839214, 64.55174937844276, 61.66581943631172, 58.033081367611885, 57.23979793488979, 60.38278788328171, 69.50100660324097, 64.15744453668594, 76.18233248591423, 21.526680886745453, 0.04103676263184752, 45.84613211452961, 58.831988498568535, 32.74930268526077, 11.979140304028988, 36.479570120573044, 33.187685161828995, 31.79172556847334, 42.655010148882866, 37.91823372244835, 42.46723562479019, 61.16558387875557, 31.976576149463654, 0.15798146574525163, 0.03925308490579482, 0.14697085891384631, 0.05454148289572913, 0.018350111531617586, 0.015287736550817499, 0.052055666674277745, 0.023516118017141707, 0.022339171991916373, 0.08638722894829698, 0.020668835059041157, 0.017404312966391444, 0.057550839774194174, 0.08430580157437362, 0.06389591668266803, 0.007797984053468099, 0.03345828452438582, 0.23257069144165143, 0.11368077102815732, 47.16474115848541, 65.80138072371483, 57.271533831954, 28.97934827953577, 42.452420219779015, 43.2974074780941, 29.617943912744522, 27.793205827474594, 59.74122650921345, 63.16479720175266, 74.46309193968773, 19.45489715784788, 2.2148135164752603, 78.42552691698074, 67.03513652086258, 76.0067743062973, 65.13711556792259, 65.06222158670425, 61.298751533031464, 68.4891664981842, 63.98973673582077, 67.83946976065636, 60.81173546612263, 66.09489977359772, 60.88702842593193, 64.07343864440918, 59.49370019137859, 59.30048055946827, 58.29664282500744, 61.28015913069248, 60.569209679961205, 57.66649603843689, 49.7649834305048, 51.86275206506252, 48.47188241779804, 51.90833821892738, 59.97557893395424, 59.66183736920357, 60.66252127289772, 59.9172368645668, 55.35628840327263, 55.029175356030464, 51.635330468416214, 55.352845788002014, 51.09017752110958, 51.26174971461296, 55.029030963778496, 56.813457012176514, 55.718389973044395, 57.60506093502045, 56.102389767766, 55.14664225280285, 54.445823058485985, 57.30075426399708, 52.560979798436165, 53.2100685685873, 54.0523237735033, 56.29280515015125, 58.08176435530186, 60.76671928167343, 58.366570472717285, 58.904234021902084, 56.981180012226105, 53.25009562075138, 49.143184795975685, 53.3085934817791, 43.52444149553776, 39.55104410648346, 44.20548655092716, 44.60979625582695, 45.27678966522217, 42.347447052598, 37.47120290994644, 37.35039219260216, 40.80061085522175, 37.18146465718746, 38.68068940937519, 38.17513033747673, 36.41864039003849, 42.763992100954056, 43.4733722358942, 42.461003959178925, 43.45209717750549, 45.09343050420284, 39.10745970904827, 43.24172146618366, 45.63799448311329, 42.03087843954563, 49.169965758919716, 50.81474170088768, 49.62822116911411, 53.913980796933174, 51.034381315112114, 55.19248679280281, 54.227163791656494, 52.00082525610924, 51.54718279838562, 52.4036530405283, 52.22120203077793, 53.46322238445282, 56.022483855485916, 58.246063739061356, 51.707731783390045, 50.93855805695057, 53.21649022400379, 53.01999896764755, 52.57484145462513, 55.49488976597786, 55.638366267085075, 54.098441898822784, 53.33842188119888, 51.6155107319355, 53.02337698638439, 52.26760894060135, 53.195929527282715, 55.33012680709362, 56.45754911005497, 58.02710808813572, 58.54822352528572, 57.149218395352364, 55.4789724200964, 53.602488711476326, 50.21160386502743, 48.72588738799095, 48.02961654961109, 52.48722955584526, 59.72220093011856, 59.22743707895279, 61.77121818065643, 63.88287886977196, 66.09375983476639, 58.70729058980942, 57.23204255104065, 64.68994036316872, 63.757440000772476, 65.42724519968033, 66.94009602069855, 61.77832379937172, 61.41129769384861, 62.77506731450558, 75.96728682518005, 68.33649069070816, 79.5913727581501, 17.332676835358143, 0.05466564049129374, 52.06478342413902, 62.59774222970009, 39.64650638401508, 17.00055755674839, 31.15263406187296, 30.629478134214878, 43.868209049105644, 45.360943749547005, 42.045758441090584, 50.82184351980686, 66.81600227952003, 49.97236110270023, 1.3427943899296224, 0.06158851276268251, 0.05691324586223345, 0.08681834253366105, 0.07787494352669455, 0.04002161222160794, 0.03297380309959408, 0.03567187726730481, 0.19117615796858445, 0.2141325519187376, 0.09937538474332541, 0.1515283135813661, 0.2721341833239421, 0.4513830930227414, 0.10610258235828951, 0.2087446636869572, 0.18150494957808405, 0.45582594524603337, 0.1614305970724672, 57.33576938509941, 73.220095038414, 66.86719313263893, 44.74280431866646, 55.031671822071075, 45.43490298092365, 23.337694108486176, 32.763677313923836, 69.83785092830658, 69.15572673082352, 85.27339786291122, 15.289262384176254, 5.401084804907441, 89.0907870233059, 67.71205499768257, 81.75324395298958, 66.62275984883308, 69.17579725384712, 63.158341348171234, 73.06430339813232, 64.75352615118027, 72.40728825330734, 62.931854501366615, 70.8705823123455, 64.87220898270607, 68.6155553162098, 61.13527290523052, 61.03674419224262, 60.96506863832474, 63.60939994454384, 63.61947700381279, 59.59006682038307, 52.28793025016785, 55.13461209833622, 48.46665769815445, 55.494380593299866, 59.923943504691124, 62.08356902003288, 60.7949061691761, 61.30367986857891, 57.58601635694504, 58.14496636390686, 55.02055361866951, 58.62957336008549, 54.22103852033615, 53.44255909323692, 56.79439343512058, 55.674870908260345, 57.730359211564064, 61.12673856317997, 59.395171478390694, 59.35355231165886, 55.90603530406952, 61.654477044939995, 55.12279853224754, 54.8101931065321, 55.9929708391428, 58.533605709671974, 59.63352508842945, 61.96007564663887, 60.24378374218941, 62.69220516085625, 59.48602080345154, 54.87173080444336, 51.04655586183071, 52.10152745246887, 42.51227840781212, 40.56601144373417, 45.37317909300327, 45.14156632125378, 46.497576758265495, 42.38416828215122, 38.19248400628567, 38.093145936727524, 41.95937007665634, 39.14028234779835, 41.358227133750916, 38.73569905757904, 38.10399815440178, 44.61285889148712, 44.98387098312378, 44.3181087076664, 46.19772344827652, 46.46033875644207, 39.89829607307911, 45.481955856084824, 45.64628563821316, 45.11141873896122, 49.5924536883831, 53.54757405817509, 54.72147926688194, 54.9668624997139, 54.88460831344128, 57.030881345272064, 56.65767677128315, 56.983649879693985, 55.3069556504488, 54.80527617037296, 54.80639711022377, 56.40098914504051, 59.6665795147419, 61.71132579445839, 53.74132186174393, 53.11750553548336, 54.05908361077309, 55.093832686543465, 54.393127486109734, 55.75975075364113, 56.31254889070988, 59.10213880240917, 56.0292436927557, 54.82718959450722, 54.27843824028969, 55.08359983563423, 57.864818796515465, 58.17571051418781, 58.317872285842896, 59.57743629813194, 60.099874064326286, 58.92895169556141, 59.95860904455185, 56.64008751511574, 52.99982205033302, 51.21038407087326, 48.75677213072777, 54.90395687520504, 63.83491024374962, 64.03712019324303, 68.3719427883625, 67.9935210943222, 70.11346533894539, 60.759647861123085, 59.31701347231865, 66.61866366863251, 67.06094473600388, 68.94779428839684, 68.1072261929512, 65.13471409678459, 62.30242967605591, 67.36111342906952, 79.84021380543709, 72.64269322156906, 83.39851766824722, 29.696385003626347, 0.14024965785210952, 52.72691309452057, 68.63602861762047, 50.840686708688736, 24.314289204776287, 44.34402711689472, 44.13244307041168, 46.75036579370499, 57.532762214541435, 52.61268362402916, 54.747952446341515, 76.6167251765728, 58.75518321990967, 1.4475959725677967, 0.22804695996455848, 0.2665297215571627, 0.17972615518374369, 0.2077994792489335, 0.1586678039166145, 0.11170255413162522, 0.24097696848912165], [0.041487992129987106, 0.03120833025604952, 0.020593173103407025, 0.009066736529348418, 0.09842091603786685, 0.02865089863917092, 0.07355702444328927, 0.03400105793843977, 0.15732632746221498, 0.0825191181502305, 0.2718386601191014, 45.40615372359753, 57.693744376301765, 51.83945931494236, 31.94060727953911, 40.140191093087196, 32.403604835271835, 17.604364156723022, 16.97952378541231, 42.254633232951164, 68.88935342431068, 53.221175372600555, 63.91200050711632, 0.7381953543517739, 31.20937641710043, 83.91860336065292, 64.25637602806091, 71.98682561516762, 61.018087193369865, 62.555541694164276, 61.399244740605354, 64.76311683654785, 63.384341821074486, 61.654545441269875, 59.17094171047211, 56.75114035606384, 57.023635134100914, 56.039495542645454, 56.347807198762894, 59.8060168325901, 60.21963603794575, 56.64525903761387, 52.12558776140213, 48.65435242652893, 44.409740790724754, 46.943023055791855, 51.97239138185978, 60.81502988934517, 57.20561496913433, 56.37178011238575, 59.36365596950054, 57.12288200855255, 55.10454051196575, 47.3022747784853, 50.5150555819273, 53.73473681509495, 49.7474929690361, 50.17476864159107, 55.343893468379974, 53.98195914924145, 52.76516184210777, 54.92515593767166, 53.37170049548149, 56.27292461693287, 53.20816867053509, 51.84063345193863, 53.066983446478844, 52.747720777988434, 54.51620668172836, 54.591172859072685, 54.046700075268745, 54.5955616235733, 52.098939791321754, 52.06807404756546, 48.92072193324566, 52.67345756292343, 36.67303293943405, 33.930621296167374, 45.22993817925453, 48.32496330142021, 44.98213827610016, 46.51045806705952, 43.93991880118847, 39.196200147271156, 39.62210789322853, 38.63934002816677, 39.307971149683, 39.43060576915741, 36.100779846310616, 41.79421953856945, 43.35901357233524, 46.351497396826744, 44.4831832498312, 43.61058287322521, 45.97660571336746, 44.695561453700066, 39.349472522735596, 44.32358041405678, 42.14101932942867, 40.65039351582527, 43.282018303871155, 50.33314034342766, 50.86127780377865, 52.85409986972809, 51.01176492869854, 54.42574493587017, 53.803319334983826, 51.709498688578606, 50.64967855811119, 50.32218933105469, 51.64451077580452, 53.62255923449993, 49.623832404613495, 49.128118604421616, 49.04472827911377, 50.94491511583328, 52.16935381293297, 52.89653979241848, 52.07964822649956, 53.6075272411108, 49.858089834451675, 47.05128684639931, 50.05240760743618, 51.093927919864655, 47.77429684996605, 48.332521095871925, 48.974477648735046, 55.48414774239063, 58.83083336055279, 54.64071460068226, 56.95948697626591, 58.01931090652943, 52.89935544133186, 46.785418912768364, 45.174430757761, 46.06841258704662, 47.25568167865276, 51.27670571208, 55.88995076715946, 59.197110906243324, 56.34928911924362, 60.866999700665474, 60.42713150382042, 53.61966758966446, 62.44391888380051, 64.43872064352036, 64.04288828372955, 62.85241216421127, 57.6577565073967, 61.286687180399895, 64.95612367987633, 64.62817087769508, 62.99529209733009, 69.69168037176132, 2.845702450722456, 0.9679286519531161, 56.422078013420105, 55.511042699217796, 31.629369780421257, 10.615574922412634, 77.12294161319733, 101.72302678227425, 33.31664264202118, 32.95009531080723, 38.98102909326553, 56.98070503771305, 48.36734622716904, 56.34768180549145, 7.506751790642738, 0.18416376784443855, 0.14901118614943698, 0.10851597238797694, 0.08058045772486366, 0.016702983411960304, 0.02175087338400772, 0.007201367825473426, 0.07728895856416784, 0.11651348191662692, 0.03200920778908767, 0.03314808534923941, 0.09744318842422217, 0.06678867473965511, 0.08868791643180884, 0.053752116073155776, 0.024980466296256054, 0.05450178912724368, 0.29341592104174197, 56.792261749506, 63.48663993179798, 59.515670612454414, 28.435168080031872, 45.90480096638203, 41.00869528949261, 22.458060309290886, 26.49852979928255, 43.951124399900436, 78.23876693844795, 57.740975841879845, 74.73094716668129, 2.4111867416650057, 27.013618759810925, 87.77325332164764, 67.58033126592636, 74.40181642770767, 62.85359010100365, 65.5833712220192, 65.28503403067589, 66.72338604927063, 62.1685666590929, 65.30895754694939, 60.81850290298462, 60.990132093429565, 58.26238006353378, 56.608518809080124, 57.2351735830307, 61.03087730705738, 63.20550061762333, 60.97111791372299, 53.698881939053535, 50.17085865139961, 44.76863533258438, 49.36741076409817, 53.58355812728405, 63.07009108364582, 61.278532817959785, 58.153192922472954, 59.75942753255367, 59.49184209108353, 58.162430226802826, 51.322774440050125, 52.90848635137081, 55.14909312129021, 51.44055671989918, 51.63117729127407, 59.00896780192852, 56.11001215875149, 54.73980188369751, 56.338220313191414, 54.02584679424763, 58.014105185866356, 55.291612073779106, 57.10975371301174, 55.86406275629997, 55.697054117918015, 56.175266057252884, 59.3033342063427, 58.43939736485481, 56.718256920576096, 55.881678611040115, 53.45067545771599, 50.923427268862724, 54.862637892365456, 39.434048384428024, 37.28309020400047, 43.832099586725235, 46.37406438589096, 45.48518568277359, 45.13945363461971, 41.88088148832321, 37.81313516199589, 40.499112233519554, 36.5562804043293, 38.79605881869793, 39.9350742995739, 36.5229219943285, 41.80637128651142, 43.23237016797066, 45.99554009735584, 43.428542241454124, 43.163723051548004, 46.85579493641853, 42.934773936867714, 40.072642117738724, 44.53773312270641, 42.539682537317276, 40.64420364797115, 40.909649804234505, 50.651996433734894, 53.21831792593002, 53.024357333779335, 51.22510068118572, 56.225731149315834, 52.38034509122372, 52.384692057967186, 54.45393942296505, 53.17877724766731, 53.43467831611633, 56.72356903553009, 52.34153017401695, 48.737757951021194, 49.551792070269585, 52.8174964338541, 53.00532415509224, 53.832072392106056, 54.360285848379135, 56.10052786767483, 53.47733862698078, 50.130067840218544, 52.27370761334896, 54.55895058810711, 52.261954843997955, 50.96175201237202, 52.7315678447485, 57.924844175577164, 57.15801492333412, 57.997887656092644, 58.644476160407066, 59.64924484491348, 56.924893632531166, 48.955174684524536, 47.095790058374405, 47.94110789895058, 48.60782392323017, 54.388533532619476, 59.60113562643528, 62.37290069460869, 58.8200419396162, 64.76273685693741, 65.10141268372536, 57.74219557642937, 62.66785226762295, 69.42556545138359, 67.55569338798523, 67.24864706397057, 62.85241216421127, 65.57622760534286, 66.79020926356316, 68.5601694881916, 65.89498490095139, 69.08124312758446, 1.728598850313574, 1.8266202905215323, 62.94869899749756, 59.058942720294, 36.22461520135403, 12.185770366340876, 62.448512837290764, 99.73701775074005, 41.87760226428509, 39.58380214869976, 38.6397960036993, 59.75899055600166, 55.92380695044994, 72.49991968274117, 16.75446756184101, 0.12222251229104586, 0.23087549256160855, 0.04038919425511267, 0.07608975924085826, 0.05613888155494351, 0.03163379238685593, 0.04011656259535812, 0.22087258868850768, 0.10451219699461944, 0.08046818562434055, 0.13964016165118665, 0.3021117841126397, 0.1274076828849502, 0.20931636972818524, 0.14955596707295626, 0.25674824486486614, 0.16737318132072687, 0.8526303106918931, 68.13707739114761, 73.24793994426727, 69.52553808689117, 44.151354655623436, 54.28139828145504, 49.75207932293415, 24.233807623386383, 31.76778305321932, 57.49939240515232, 80.25624588131905, 67.75408834218979, 76.27573147416115, 2.5095653627067804, 39.727396443486214, 88.22151526808739, 71.89509853720665, 74.73503574728966, 66.29977717995644, 66.9919328391552, 66.49338439106941, 70.92739686369896, 66.76108002662659, 68.59768867492676, 64.02006670832634, 62.97408163547516, 60.26679150760174, 59.73759390413761, 58.00019793212414, 62.881689593195915, 64.93377327919006, 61.58449240028858, 58.28686594963074, 52.568963170051575, 48.331122770905495, 53.37058335542679, 55.755339190363884, 64.97104167938232, 63.34144592285156, 63.63480158150196, 59.89598460495472, 63.000266030430794, 58.662456795573235, 53.334751278162, 56.13168999552727, 57.873744517564774, 52.94976733624935, 53.489775359630585, 60.42971916496754, 58.60375754535198, 58.221779242157936, 60.07030785083771, 56.96383394300938, 61.332649514079094, 58.68341647088528, 59.08366419374943, 57.465927600860596, 58.52203153073788, 58.753834292292595, 59.939173087477684, 59.98571678996086, 58.97105723619461, 56.68805234134197, 55.632214397192, 54.740371853113174, 50.61420366168022, 41.02191857993603, 39.40174251794815, 46.59848414361477, 47.651711627840996, 46.30536027252674, 45.615944266319275, 43.090782165527344, 40.70698007941246, 39.883723855018616, 37.70365923643112, 38.40797424316406, 41.32975906133652, 40.11795848608017, 44.20521676540375, 43.94330061972141, 46.895791590213776, 46.761066019535065, 43.87768194079399, 47.29239910840988, 44.10940110683441, 42.76340693235397, 45.87756022810936, 43.30487787723541, 41.54217526316643, 41.1478666216135, 50.23428104817867, 55.73459230363369, 53.40674601495266, 54.431064650416374, 57.30369530618191, 55.56299731135368, 53.67497742176056, 56.84112712740898, 55.49669086933136, 55.26601664721966, 60.313342809677124, 56.46570727229118, 52.40105018019676, 50.500224977731705, 56.014679074287415, 56.96607202291489, 57.85886451601982, 58.09386670589447, 60.47475054860115, 56.35966256260872, 51.72475107014179, 54.41490411758423, 57.2640710324049, 54.68735709786415, 53.900639712810516, 55.84884077310562, 59.88642431795597, 60.58902561664581, 59.68994826078415, 61.728352680802345, 60.50802156329155, 58.63730974495411, 52.87330403923988, 52.146703228354454, 51.39115557074547, 51.528552398085594, 60.09789817035198, 63.16747225821018, 66.69938653707504, 62.84433759748936, 69.25199076533318, 66.45291656255722, 60.274353101849556, 67.18408092856407, 71.74005925655365, 69.1162620484829, 69.67357814311981, 64.5591589808464, 70.47300964593887, 69.43896353244781, 72.09616094827652, 66.50918394327164, 78.9547549188137, 6.020530890673399, 1.2726607220247388, 67.3863060772419, 65.14105975627899, 47.50802233815193, 20.765118151903152, 94.44810435175896, 113.95903140306473, 47.849179431796074, 48.16839650273323, 52.25107982754707, 69.78291347622871, 63.68944264948368, 82.94666111469269, 16.51891630142927, 0.4485281399684027, 0.26153732382226735, 0.16337352484697476, 0.1557296561077237, 0.1263314500101842, 0.29794037982355803, 0.10775432107038796], [0.05148176016518846, 0.09447769989492372, 0.03316145885037258, 0.034630577283678576, 0.042302836882299744, 0.026127885976166, 0.10381316809798591, 0.06153049907879904, 0.05289371096296236, 0.0617885438259691, 3.307885187678039, 65.49283728003502, 59.347674027085304, 53.50952289998531, 34.56039570271969, 45.74353761970997, 31.173759028315544, 34.86515834927559, 12.063577473163605, 27.166817039251328, 66.2274518609047, 52.55860112607479, 69.2274820804596, 21.824355013668537, 3.123675584793091, 69.94090139865875, 68.587436825037, 73.54240134358406, 66.67006731033325, 62.22400948405266, 63.64234417676926, 63.82119297981262, 63.45873422920704, 60.70689529180527, 59.10015530884266, 57.94598624110222, 56.28076359629631, 55.12285552918911, 57.97732695937157, 57.78864048421383, 56.91570572555065, 55.94959996640682, 48.21504279971123, 49.38551299273968, 48.162149637937546, 50.580685660243034, 56.30386635661125, 60.045548379421234, 57.56795972585678, 55.0210589915514, 57.85380318760872, 59.18441578745842, 54.32559370994568, 49.845493510365486, 49.753481447696686, 53.16117279231548, 55.55285185575485, 53.384608402848244, 54.00937467813492, 53.14194582402706, 54.101151153445244, 57.42689609527588, 54.61428701877594, 53.29604275524616, 52.87920132279396, 53.6384841799736, 53.53545270860195, 53.675110414624214, 54.96298290789127, 53.33918184041977, 54.26325425505638, 53.27878788113594, 53.808259069919586, 52.92007572948933, 50.60477636754513, 49.37859356403351, 56.48319013416767, 57.58561357855797, 44.403018951416016, 47.40138106048107, 47.117433696985245, 47.96039566397667, 45.76070509850979, 39.24435496330261, 38.3375184237957, 37.78430990874767, 39.235243052244186, 39.498979300260544, 39.871108531951904, 42.67839789390564, 43.70595395565033, 44.911990240216255, 45.70721156895161, 44.66233603656292, 45.06819985806942, 45.695394203066826, 38.25493365526199, 44.7669368237257, 37.085417211055756, 38.185511380434036, 34.818531051278114, 32.662918120622635, 41.25534385442734, 46.68599344789982, 51.34183041751385, 51.8617033213377, 51.245262399315834, 52.476111352443695, 49.39703397452831, 54.04255069792271, 49.80800852179527, 52.176888808608055, 48.961220160126686, 51.34172022342682, 49.97337564826012, 53.494578301906586, 52.30859734117985, 52.5572369992733, 52.64879688620567, 50.75948126614094, 50.012836530804634, 53.32340128719807, 50.35206712782383, 50.598746091127396, 47.96801045536995, 46.7554385215044, 50.277716517448425, 56.41330048441887, 58.829887211322784, 54.96907398104668, 57.87551522254944, 61.12027511000633, 57.53188446164131, 50.69834254682064, 41.84748128056526, 44.42999750375748, 45.681536346673965, 45.934530571103096, 49.09617371857166, 57.45090700685978, 59.6331375092268, 57.64072202146053, 60.333538725972176, 60.27851387858391, 56.16377927362919, 63.33364114165306, 61.51528671383858, 65.54599642753601, 58.606273010373116, 62.52026058733463, 60.82768701016903, 64.65278595685959, 69.30198848247528, 42.49053217470646, 0.7713106961455196, 8.520737830549479, 56.515803784132004, 54.55155238509178, 21.464856304228306, 9.00588819757104, 39.91477198898792, 55.96148192882538, 36.74750134348869, 36.18553809821606, 33.4774424135685, 59.98841464519501, 57.33214817941189, 60.77582359313965, 28.370480351150036, 0.0674878669087775, 0.21183621342061087, 0.021839196379005443, 0.2352127223275602, 0.046357575556612574, 0.038395711380871944, 0.025639222549216356, 0.03100387784797931, 0.034822485540644266, 0.05475983016367536, 0.05075519758975133, 0.036771814338862896, 0.01447013008146314, 0.06842303235316649, 0.059396394062787294, 0.21371816634200513, 0.009225262056133943, 3.939228435046971, 76.89539462327957, 61.87155179679394, 60.60778521001339, 36.30400434136391, 49.26309496164322, 40.95485597848892, 31.315424926579, 17.301670499145985, 29.685861468315125, 74.61550936102867, 58.41827429831028, 75.90607970952988, 29.66621272265911, 1.1373618571087718, 60.797045454382896, 73.4163773059845, 74.64735925197601, 72.51110628247261, 64.28533807396889, 66.83211341500282, 67.7566646039486, 67.69607305526733, 63.81660282611847, 62.685635313391685, 60.86245134472847, 58.83334502577782, 58.91847565770149, 60.20511321723461, 58.399165123701096, 58.50176341831684, 57.27670915424824, 50.276557579636574, 49.131857603788376, 50.88914930820465, 54.41527649760246, 55.711417347192764, 60.52973359823227, 59.65318143367767, 56.67109005153179, 57.62875646352768, 60.34518510103226, 54.75547604262829, 52.14475393295288, 50.781311094760895, 54.17004145681858, 57.814817279577255, 56.11195005476475, 57.91323199868202, 57.52821005880833, 56.724841967225075, 58.352385833859444, 56.37277565896511, 55.056549087166786, 57.6214874535799, 57.4208278208971, 55.73895826935768, 55.865008905529976, 57.58283972740173, 58.901387974619865, 56.1784540861845, 57.9205010086298, 58.82602661848068, 57.31289841234684, 50.364857241511345, 52.73248739540577, 56.730157881975174, 51.90223954617977, 42.827558889985085, 46.61923862993717, 47.579773887991905, 46.389358565211296, 45.74054338037968, 38.16020093858242, 36.43412835896015, 38.049816861748695, 38.15944857895374, 39.819830283522606, 39.554171338677406, 41.9987777620554, 43.970902338624, 43.78502771258354, 46.20253399014473, 45.38397051393986, 43.99582140147686, 46.06973111629486, 39.12951372563839, 46.03858798742294, 38.08267369866371, 37.3168969899416, 37.657047137618065, 33.283162638545036, 38.55489335954189, 46.91392041742802, 51.429047137498856, 51.72599360346794, 53.25980789959431, 54.186312183737755, 51.23695604503155, 55.52404560148716, 51.5619982033968, 55.47301433980465, 51.823093593120575, 50.835344195365906, 52.11215928196907, 52.69965335726738, 54.19303022325039, 54.8184272646904, 56.535999700427055, 53.7754288315773, 53.82736824452877, 55.44871464371681, 54.041760340332985, 53.39557081460953, 50.76199673116207, 48.85809749364853, 53.06451737880707, 59.85517859458923, 62.765119448304176, 56.7874626070261, 60.22864915430546, 63.118329495191574, 59.10373471677303, 53.84187966585159, 47.77973435819149, 46.21969386935234, 49.7629239410162, 49.74344618618488, 51.726502776145935, 59.79519881308079, 59.79885421693325, 61.74646630883217, 64.09885168075562, 62.78736725449562, 58.713419660925865, 64.01843279600143, 65.96898213028908, 67.63872653245926, 63.432603031396866, 65.88854044675827, 65.76066970825195, 66.94695845246315, 75.18297091126442, 37.63719700276852, 0.5508997233118862, 14.987014252692461, 66.54905900359154, 58.78622755408287, 28.627984933555126, 9.954182412475348, 36.852231323719025, 56.22894577682018, 46.353427693247795, 47.6770980656147, 30.782199539244175, 55.56479461491108, 66.62612646818161, 67.48557195067406, 41.658863201737404, 0.3363000339595601, 0.1629942428553477, 0.10282591130817309, 0.1091248971351888, 0.0858955857984256, 0.0886014784919098, 0.023787456484569702, 0.09715820371638983, 0.322739333496429, 0.2846693544415757, 0.14971312426496297, 0.19271178025519475, 0.09413151026819833, 0.14473867166088894, 0.26902342680841684, 0.3128151863347739, 0.2166896959533915, 4.268716117367148, 85.12145161628723, 71.50261759757996, 70.87525606155396, 47.97546185553074, 60.384714379906654, 47.73632928729057, 44.41399276256561, 21.699997186660767, 41.91924422979355, 79.43172812461853, 63.8491290807724, 85.14298126101494, 26.40671532601118, 3.5307802772149444, 77.32742384076118, 70.31958907842636, 80.78934207558632, 71.27118721604347, 69.7905358672142, 70.10848760604858, 69.53000664710999, 69.5468321442604, 67.80451163649559, 65.18264472484589, 63.32438863813877, 60.61347730457783, 59.9298407882452, 62.84036301076412, 62.94578455388546, 60.426888316869736, 60.76890416443348, 53.67007188498974, 52.68239088356495, 50.50076834857464, 54.008652716875076, 58.34714211523533, 64.07547533512115, 60.44371381402016, 59.45953622460365, 59.31206613779068, 61.18641436100006, 59.40880134701729, 55.728508830070496, 54.39891077578068, 57.73550793528557, 60.33187061548233, 57.386401668190956, 59.37650687992573, 61.341997012495995, 57.85885311663151, 59.46010239422321, 58.953859359025955, 58.843513280153275, 59.89778570830822, 59.69320468604565, 58.104692324995995, 58.92955966293812, 60.77254816889763, 62.80602045357227, 61.10852614045143, 59.992469027638435, 61.68795324862003, 56.70512482523918, 52.90186710655689, 58.417970314621925, 56.737928465008736, 50.18293060362339, 44.15371052920818, 48.17590110003948, 48.670683950185776, 47.80676990747452, 47.42892578244209, 39.235851019620895, 38.59582096338272, 38.99593189358711, 39.767039716243744, 40.32247111201286, 40.25538571178913, 42.286722511053085, 46.76774226129055, 45.36479294300079, 47.769284918904305, 46.157973781228065, 46.29138082265854, 46.597655788064, 40.94513610005379, 50.2389357984066, 38.562466353178024, 39.85410824418068, 39.34592351317406, 34.53542724251747, 40.08180342614651, 48.285133838653564, 51.90961875021458, 56.378019377589226, 57.799990475177765, 59.70258258283138, 52.17876970767975, 57.10307367146015, 54.72886227071285, 59.625484719872475, 56.206713169813156, 55.31871981918812, 53.943429216742516, 56.025493294000626, 57.28102572262287, 55.92849209904671, 56.39174424111843, 56.93904407322407, 57.36050985753536, 59.50560875236988, 55.74142813682556, 54.78446088731289, 53.70013207197189, 55.088680163025856, 56.50683246552944, 60.85789158940315, 65.85650816559792, 60.19989609718323, 61.468404829502106, 67.17572897672653, 62.910777032375336, 57.49186880886555, 50.34385196864605, 49.28929075598717, 55.04043035209179, 52.08812177181244, 57.65050649642944, 64.55071583390236, 63.43148209154606, 65.18759205937386, 69.6952673792839, 62.14138671755791, 59.29902903735638, 70.1464931666851, 69.41737309098244, 71.97704493999481, 68.45284044742584, 73.65268662571907, 68.6701887845993, 73.14189523458481, 75.08764922618866, 53.29865321516991, 0.5481316312216222, 11.92619014531374, 71.96970373392105, 66.14566504955292, 38.43354307115078, 18.80959678441286, 49.91928555071354, 64.33160439133644, 52.76879444718361, 50.33811807632446, 43.52394372224808, 65.74942231178284, 68.8804543018341, 77.96417847275734, 49.476141929626465, 0.42487152968533337, 0.4205994604853913, 0.23814877728000283, 0.35648508521262556, 0.1409450947539881, 0.27390785689931363, 0.22860882512759417], [0.02541424604714848, 0.07279869052581489, 0.09370907238917425, 0.05405893476563506, 0.13948754640296102, 0.052335972141008824, 0.0743255703127943, 0.14084395486861467, 0.05653354455716908, 0.09158962478977628, 3.320576031692326, 62.88141220808029, 52.68620207905769, 48.58025260269642, 19.61491797119379, 42.36712999641895, 23.65119818598032, 37.06574946641922, 9.688697308301926, 17.578067667782307, 76.74857050180435, 60.51816701889038, 49.80908006429672, 63.16451221704483, 1.823037676513195, 9.7628503292799, 89.9933297932148, 66.54605716466904, 76.67759031057358, 62.64912307262421, 68.64061877131462, 69.05952349305153, 74.00846913456917, 59.41653773188591, 62.66390047967434, 58.24281111359596, 64.63145390152931, 64.44315120577812, 59.174927696585655, 56.483957692980766, 54.00371678173542, 53.009230345487595, 53.33233080804348, 53.8532904535532, 50.850220397114754, 53.242484629154205, 58.43975454568863, 52.930414974689484, 58.778487369418144, 55.757801458239555, 58.54440852999687, 59.05762419104576, 55.77334642410278, 48.09384450316429, 47.32853516936302, 46.90071612596512, 50.88401958346367, 52.99282282590866, 54.6244590729475, 53.232426568865776, 49.111258909106255, 49.4997538626194, 54.122711196541786, 63.129014521837234, 57.84645438194275, 54.500464126467705, 52.0542161911726, 57.386975437402725, 55.3741018474102, 51.2006451934576, 52.12703548371792, 52.407236248254776, 53.528784066438675, 44.65289734303951, 39.42696936428547, 54.81666415929794, 104.49130743741989, 135.0212860107422, 106.37942612171173, 60.55173061788082, 46.51577778160572, 42.0778439193964, 42.36986964941025, 42.56547935307026, 41.38487130403519, 41.21473543345928, 43.894784823060036, 47.983107045292854, 46.396483182907104, 46.019714400172234, 43.68181385099888, 43.826088309288025, 43.51648852229118, 47.79377080500126, 47.36114501953125, 45.906522274017334, 39.6003008633852, 36.078646034002304, 39.42770652472973, 44.57367919385433, 54.34604801237583, 69.92882564663887, 86.600993424654, 66.57431244850159, 50.81525847315788, 51.36009223759174, 46.381785571575165, 49.59821417927742, 52.68057458102703, 51.13288722932339, 50.69966867566109, 50.60407720506191, 49.641273468732834, 51.49750806391239, 49.113291800022125, 47.48291328549385, 57.0756771415472, 55.67452132701874, 51.91570982336998, 48.92273962497711, 50.56986764073372, 50.94575107097626, 53.14166083931923, 50.71895644068718, 47.05444447696209, 48.08303028345108, 55.22553361952305, 55.0755974650383, 57.35588550567627, 53.85453678667545, 57.23940275609493, 59.90500912070274, 58.81115421652794, 56.224815398454666, 51.191111505031586, 42.62641288340092, 44.85318839550018, 47.36928038299084, 46.28087818622589, 50.728615522384644, 56.70207738876343, 60.23474782705307, 63.87612283229828, 63.34635145962238, 63.37547689676285, 66.82756885886192, 62.93968968093395, 59.38710071146488, 58.84830102324486, 60.464164316654205, 64.48936432600021, 63.41971792280674, 73.97269025444984, 10.10705390945077, 0.20801443490199745, 26.17381252348423, 51.77057281136513, 57.19433717429638, 21.203468330204487, 9.496340230107307, 16.710350029170513, 10.427698753774166, 14.852031245827675, 45.71459457278252, 51.1992696672678, 37.83426582813263, 41.96093939244747, 60.436406806111336, 40.158798694610596, 0.6979429861530662, 0.46663918532431126, 0.7200927694793791, 0.19869953161105514, 0.14146444969810545, 0.2966166555415839, 0.13807197392452508, 0.018313583022973035, 0.029478454525815323, 0.035876416877727024, 0.05359846181818284, 0.1047768616990652, 0.07171845747507177, 0.04660110760596581, 0.054465724460897036, 0.11990627681370825, 0.09340897755464539, 3.402750422246754, 73.83248537778854, 59.27074335515499, 54.78363633155823, 22.407371029257774, 48.94043147563934, 32.21007741987705, 35.13613320887089, 14.982390850782394, 20.216678380966187, 77.86237433552742, 69.54182401299477, 55.53955636918545, 71.82389795780182, 3.0916741769760847, 4.801634671166539, 83.25118437409401, 68.52022603154182, 77.64805063605309, 71.65046006441116, 72.29958683252335, 67.90044128894806, 72.49939531087875, 65.94112202525139, 66.9015508890152, 61.54845893383026, 66.36014074087143, 65.87259650230408, 67.07174375653267, 62.49897412955761, 59.98188279569149, 53.928541615605354, 52.27413699030876, 52.03780107200146, 49.81882654130459, 52.244597375392914, 58.621776178479195, 57.63514772057533, 58.390478789806366, 54.17049363255501, 58.376233354210854, 59.934252351522446, 57.880485355854034, 49.57070365548134, 52.350467294454575, 50.8277940005064, 54.105114340782166, 56.93793073296547, 59.77431893348694, 57.79108755290508, 55.38432329893112, 55.81125698983669, 59.974606186151505, 61.527966633439064, 59.32793788611889, 57.90688633918762, 53.160865008831024, 58.76751735806465, 57.8273756057024, 56.84853293001652, 58.64065356552601, 56.80946342647076, 55.86822733283043, 47.72646501660347, 47.5009623169899, 74.135412722826, 116.78918793797493, 121.64721205830574, 81.0973459482193, 50.803213119506836, 45.75153239071369, 45.296373814344406, 43.38577553629875, 41.10189288854599, 40.427022501826286, 38.57841409742832, 42.90698982775211, 45.61444714665413, 43.84679339826107, 45.47065906226635, 42.07666978240013, 44.01486597955227, 43.982636108994484, 46.27224884927273, 45.43902575969696, 45.44475965201855, 39.21589069068432, 40.03247827291489, 42.37412542104721, 39.685944467782974, 41.095414236187935, 51.137910559773445, 80.34451514482498, 73.83696153759956, 56.95882961153984, 51.84377208352089, 48.17273586988449, 50.72560988366604, 54.70327824354172, 51.98676981031895, 52.04711817204952, 54.34938803315163, 52.17167168855667, 51.74578674137592, 51.66341856122017, 51.210121884942055, 56.10974617302418, 55.133004784584045, 55.783594474196434, 52.09825962781906, 55.857565104961395, 51.67465075850487, 54.12236541509628, 53.93249340355396, 51.260647773742676, 49.66229014098644, 57.76381641626358, 57.938337251544, 61.395368948578835, 57.53671020269394, 57.00869433581829, 63.4445533901453, 60.89682050049305, 63.459452390670776, 55.45639783143997, 47.86331087350845, 47.99857221543789, 49.711839482188225, 50.250456780195236, 53.70046645402908, 60.64892940223217, 66.34714543819427, 68.34836885333061, 66.80888146162033, 64.33136880397797, 69.77352038025856, 69.09061342477798, 65.77909871935844, 64.82066854834557, 64.5337763428688, 68.21508720517159, 65.06344512104988, 71.06246441602707, 4.2573746759444475, 0.040755655645625666, 35.244974568486214, 61.39294847846031, 66.84548869729042, 25.498640052974224, 10.145699735730886, 20.087884292006493, 19.177396148443222, 26.220380924642086, 51.012498289346695, 45.19833527505398, 38.78535099327564, 49.97877515852451, 63.69682565331459, 53.368573263287544, 1.2132944888435304, 0.15478939953027293, 0.14096667640842497, 0.10013532912125811, 0.03821261241682805, 0.13181648537283763, 0.12785221450030804, 0.0957959248626139, 0.2314378772280179, 0.15599810576532036, 0.12908989418065175, 0.17181716160848737, 0.1695799722801894, 0.2270592059358023, 0.14659611886600032, 0.258380108862184, 0.20207504188874736, 4.47594559751451, 85.22624239325523, 65.8295676112175, 66.43644824624062, 26.818191446363926, 63.70649233460426, 29.560414999723434, 51.41875348985195, 17.07698665559292, 26.678362749516964, 90.80006450414658, 74.92481276392937, 63.86357590556145, 75.48425674438477, 1.735739498399198, 11.026488672941923, 88.7472702562809, 65.35203963518143, 80.43241202831268, 71.03135168552399, 76.7848889529705, 72.04037994146347, 78.47688496112823, 68.29846993088722, 75.90246990323067, 63.603145480155945, 71.65856122970581, 69.43442657589912, 69.12551835179329, 64.24719572067261, 60.49509085714817, 54.05092164874077, 54.08187858760357, 55.277530029416084, 54.022252187132835, 54.34005193412304, 61.40548400580883, 60.923947244882584, 63.770876079797745, 55.497553423047066, 61.12773410975933, 58.80681864917278, 58.2195183634758, 50.82394860684872, 54.030946120619774, 51.63495808839798, 57.93164201080799, 58.661693036556244, 61.810340881347656, 60.93634217977524, 60.373284593224525, 59.43441577255726, 61.927150413393974, 64.84593719244003, 62.302315682172775, 61.39958672225475, 54.16018858551979, 60.63278786838055, 63.58146384358406, 56.855209171772, 59.25292231142521, 57.09559567272663, 58.68302509188652, 52.14992165565491, 55.78771345317364, 78.76842811703682, 116.79998695850372, 115.38644760847092, 75.77870294451714, 50.41570991277695, 49.4160595536232, 45.28824985027313, 45.96221208572388, 43.76798942685127, 42.05753020942211, 39.32423047721386, 43.947016820311546, 48.59514780342579, 48.14619429409504, 49.19750288128853, 44.81194160878658, 48.39610308408737, 47.112649753689766, 48.969940692186356, 46.597382202744484, 46.77545964717865, 42.61999122798443, 46.89622476696968, 45.88303193449974, 43.014565855264664, 39.41647432744503, 43.963754922151566, 72.1279576420784, 74.33592036366463, 62.90633887052536, 55.47573499381542, 50.64005747437477, 52.12647691369057, 57.66276463866234, 54.500627517700195, 55.68621709942818, 56.70043207705021, 53.66512455046177, 55.11669225990772, 53.80454666912556, 51.33603572845459, 60.895076394081116, 57.11876302957535, 57.63770118355751, 52.485090270638466, 58.04761938750744, 55.75276292860508, 54.61738385260105, 57.924904972314835, 55.35619720816612, 55.18884278833866, 60.92154957354069, 59.80403333902359, 64.64080899953842, 60.62055632472038, 62.50099562108517, 63.25962871313095, 62.986092790961266, 64.16107714176178, 60.24839669466019, 53.726700246334076, 55.61092033982277, 54.385273307561874, 54.25557106733322, 56.06711246073246, 63.31976808607578, 67.53528088331223, 69.865992218256, 66.9609797000885, 63.55703115463257, 68.34045767784119, 72.95431450009346, 69.97454479336739, 70.49766272306442, 72.23305240273476, 76.357411891222, 70.18623903393745, 82.57981359958649, 13.188678100705147, 0.3873705700971186, 36.78291164338589, 68.55984270572662, 71.7966990172863, 34.76544789969921, 18.9701571688056, 21.266415752470493, 16.865186020731926, 23.00587311387062, 65.05269169807434, 70.95635131001472, 49.889430552721024, 55.247542038559914, 72.82188400626183, 63.6545567214489, 1.7585341189987957, 0.3340817545540631, 0.5516059510409832, 0.25298638734966516, 0.21589472220512107, 0.3547496470855549, 0.13970263564260677], [0.12458210403565317, 0.17013600416248664, 0.25165123399347067, 0.14849073282675818, 0.18848578358301893, 0.03538665136147756, 0.00987406425338122, 0.08654395569465123, 0.3457138506928459, 0.19181626033969223, 1.0284396330825984, 58.528863564133644, 54.02117304503918, 47.97065511345863, 24.119456559419632, 41.48971527814865, 32.83443331718445, 24.101304933428764, 29.991762153804302, 4.605260733515024, 30.033578909933567, 61.50934383273125, 47.47143790125847, 54.756802171468735, 36.51681952178478, 0.7871986529789865, 27.16521542519331, 79.22266334295273, 64.29103776812553, 68.6619508266449, 73.03446739912033, 71.02280974388123, 66.15489095449448, 61.18399769067764, 61.69462189078331, 59.53962832689285, 68.06855946779251, 60.79702265560627, 58.113371059298515, 54.154986664652824, 53.8124730437994, 57.465122044086456, 57.4362625926733, 52.81282268464565, 53.960372507572174, 56.6218750923872, 54.961276799440384, 60.54686687886715, 59.564194008708, 56.20439149439335, 60.1443886756897, 60.777613297104836, 58.66351693868637, 47.380976155400276, 45.35837508738041, 50.58714531362057, 48.022837713360786, 52.75559015572071, 51.37932300567627, 49.93679121136665, 51.09756052494049, 57.35251508653164, 60.051825642585754, 60.70539437234402, 59.32896763086319, 55.84954373538494, 53.33695895969868, 55.16682676970959, 49.036440923810005, 49.50429081916809, 51.57098852097988, 49.3126405030489, 46.749514639377594, 50.298391208052635, 62.33138032257557, 81.61955952644348, 89.01632621884346, 70.07017806172371, 63.688751086592674, 61.198638305068016, 38.28801468014717, 34.300839230418205, 38.31552520394325, 41.815790981054306, 41.10178269445896, 41.7694790661335, 45.080450400710106, 55.038754642009735, 52.8348159044981, 50.68367913365364, 48.97878661751747, 40.2118856459856, 47.655458226799965, 48.24896737933159, 47.26272650063038, 45.20294442772865, 37.342636808753014, 37.51692585647106, 37.244613468647, 68.9351637661457, 113.31066459417343, 103.82920816540718, 79.39562246203423, 74.53502207994461, 59.025899693369865, 50.61100423336029, 51.587867215275764, 49.62843015789986, 50.994627848267555, 51.098198890686035, 49.78557072579861, 47.198365554213524, 48.38877707719803, 48.307936415076256, 48.1977841258049, 53.03218491375446, 54.82548728585243, 51.439610570669174, 48.518027141690254, 44.450140222907066, 52.87681125104427, 54.69296179711819, 51.77170515060425, 48.70263263583183, 49.049337431788445, 48.98662939667702, 56.29261136054993, 58.932652696967125, 60.74227139353752, 55.57193823158741, 54.54570829868317, 60.055298656225204, 63.262736946344376, 65.16133546829224, 54.55127879977226, 46.17104887962341, 45.01538269221783, 43.5914471000433, 46.43059775233269, 49.85503479838371, 57.32310086488724, 61.88107788562775, 65.37149459123611, 58.02185297012329, 52.35423669219017, 63.56198608875275, 67.6611377298832, 67.38478615880013, 58.60321797430515, 63.53940390050411, 57.2506919503212, 69.21695664525032, 42.977084666490555, 0.25668655754998326, 2.0839877240359783, 43.12518931925297, 59.778407514095306, 56.35717369616032, 16.43273502588272, 8.040816932916641, 23.743618726730347, 13.947720620781183, 18.871609456837177, 66.28400802612305, 64.68918040394783, 32.81969390809536, 46.75952710211277, 52.66552358865738, 46.286729872226715, 1.9972003810107708, 0.7887132279574871, 0.2998075046343729, 0.4935328953433782, 0.13557932252297178, 0.21447885286761448, 0.05781230211141519, 0.14273484324803576, 0.06301826768321916, 0.1486967530217953, 0.04022518332931213, 0.07690987695241347, 0.07829046458937228, 0.013575553621194558, 0.1474530916311778, 0.20115123130381107, 0.08778615505434573, 1.3184443465434015, 64.79483753442764, 57.52547040581703, 53.4417687356472, 27.206336818635464, 50.675870552659035, 36.043197736144066, 26.066593676805496, 36.42914302647114, 8.239076994359493, 28.639192432165146, 69.15353044867516, 57.438219487667084, 57.956154495477676, 45.98244599997997, 0.20506380416918546, 15.207798555493355, 75.22530063986778, 72.10401892662048, 72.16760471463203, 68.75364750623703, 68.07010978460312, 65.71402341127396, 67.13414400815964, 64.98108074069023, 61.01840257644653, 66.84891611337662, 64.81210380792618, 66.01115986704826, 63.48297692835331, 59.923696517944336, 59.221114218235016, 52.346291318535805, 49.83708456158638, 56.44168496131897, 56.833025962114334, 59.71270903944969, 61.429369524121284, 61.451336145401, 57.87278316915035, 60.31456634402275, 61.35368898510933, 54.75560523569584, 47.313282787799835, 48.43418464064598, 51.99835538864136, 49.32408928871155, 57.87144564092159, 59.24349121749401, 56.119553446769714, 56.928450241684914, 62.1791110932827, 62.91893519461155, 59.469681680202484, 59.16720651090145, 55.0581070035696, 56.58315896987915, 59.33155909180641, 53.062602281570435, 53.61753210425377, 56.25448800623417, 50.43866068124771, 47.07606911659241, 59.63922098278999, 78.92392337322235, 86.27180188894272, 85.8883872628212, 70.39750769734383, 59.99506048858166, 57.4944032728672, 40.43543145060539, 38.52101057767868, 41.791916862130165, 42.262001037597656, 40.59462010860443, 42.692293748259544, 41.89418077468872, 52.50348128378391, 52.887557074427605, 49.355737790465355, 49.11446213722229, 41.2627724558115, 46.74687758088112, 48.464681804180145, 42.45735615491867, 42.093301489949226, 41.196515411138535, 42.48496547341347, 34.53138805925846, 51.70464254915714, 93.52993682026863, 99.26697537302971, 77.26365566253662, 70.94248965382576, 66.54565438628197, 58.4246389567852, 53.969754204154015, 52.52913750708103, 48.99742841720581, 50.665082931518555, 50.75406655669212, 51.69725574553013, 51.16492711007595, 51.1033134162426, 51.20367743074894, 53.078724816441536, 54.46594297885895, 51.48761339485645, 51.04530192911625, 53.07223476469517, 54.92156133055687, 53.60740564763546, 50.995501801371574, 53.860901445150375, 54.146839901804924, 51.152642369270325, 58.36562052369118, 63.377695977687836, 64.41446274518967, 58.75711351633072, 54.80855539441109, 60.497401133179665, 59.54209439456463, 64.11623194813728, 59.59016181528568, 49.92697633802891, 49.98730190098286, 48.05548556149006, 48.653121292591095, 53.48592236638069, 60.83758167922497, 64.18250799179077, 66.97295665740967, 60.59116870164871, 56.04642257094383, 62.6318833976984, 71.17383643984795, 74.10371482372284, 66.35542899370193, 68.35395455360413, 63.85588511824608, 74.53358575701714, 35.082837268710136, 0.5768610583618283, 5.107436561957002, 53.565759882330894, 66.2550687789917, 64.96554717421532, 15.88989520445466, 10.677239913493395, 28.941697999835014, 17.716872319579124, 26.285480931401253, 85.05088180303574, 72.80989184975624, 32.15954773128033, 55.019546672701836, 60.820961371064186, 68.19492548704147, 3.339319475926459, 0.6177450239192694, 0.11740128349629231, 0.23845417104894295, 0.17374589951941743, 0.09609826098312624, 0.01708688712824369, 0.25606915005482733, 0.20676134823588654, 0.32180704758502543, 0.3234514390351251, 0.28410057246219367, 0.172813005046919, 0.07954975561005995, 0.25635538157075644, 0.19835651095490903, 0.18608588579809293, 1.4169622538611293, 74.54737901687622, 65.16089469194412, 63.726095482707024, 34.07392680644989, 59.556909799575806, 47.33484283089638, 32.76601038873196, 43.23640175163746, 10.032176077365875, 44.91120748221874, 73.73302191495895, 61.65342830121517, 62.37545035779476, 42.572945952415466, 1.2715749302878976, 29.855176582932472, 81.68825224041939, 69.86561983823776, 73.72710943222046, 73.78755658864975, 72.21649289131165, 71.76269844174385, 69.50942695140839, 69.89509105682373, 63.976954221725464, 71.51870593428612, 68.74593392014503, 68.06252539157867, 64.3363693356514, 59.28599193692207, 60.32063841819763, 57.563787549734116, 52.29879006743431, 53.12220208346844, 56.09157934784889, 63.22595871984959, 63.91199290752411, 64.80796203017235, 57.718640640378, 61.75993278622627, 60.02009354531765, 56.75665386021137, 46.42315775156021, 46.328147649765015, 55.12435644865036, 51.778005212545395, 60.003127455711365, 63.644008487463, 61.93454101681709, 58.57563525438309, 66.87416955828667, 63.51730428636074, 64.73672345280647, 63.484105467796326, 58.245968744158745, 57.62726314365864, 62.69223935902119, 54.85986404120922, 52.48655319213867, 55.4141478985548, 51.70156851410866, 52.652847468853, 60.77463045716286, 66.5558910369873, 78.83044078946114, 89.44394767284393, 80.56690201163292, 70.32960534095764, 59.09911796450615, 40.65502546727657, 42.492656260728836, 43.72667424380779, 43.69868494570255, 39.99176725745201, 43.71906705200672, 42.989270612597466, 58.056062534451485, 55.40858879685402, 56.55428431928158, 55.04578426480293, 42.988677844405174, 50.604669973254204, 49.11353878676891, 43.34432736039162, 44.671387150883675, 44.56236720085144, 46.51079624891281, 37.41564229130745, 49.68618705868721, 79.72200214862823, 92.63018310070038, 77.28717640042305, 69.39438432455063, 65.40006905794144, 55.035384222865105, 55.70740096271038, 57.3987890034914, 53.123220428824425, 54.69976343214512, 53.73697869479656, 54.25562426447868, 53.35899397730827, 50.5489269644022, 51.78927160799503, 52.90400259196758, 56.91845677793026, 54.54014539718628, 52.783214673399925, 50.549645125865936, 55.03550961613655, 55.70588864386082, 56.08924627304077, 54.77472200989723, 61.15448087453842, 60.13540215790272, 65.26497110724449, 67.91440933942795, 66.36856868863106, 58.36609549820423, 54.616616293787956, 62.21403121948242, 60.39888381958008, 67.3012438416481, 64.89870876073837, 53.76871459186077, 55.93679465353489, 50.872722789645195, 51.48135133087635, 53.83263096213341, 61.40435166656971, 67.33309373259544, 70.085688829422, 62.102556601166725, 59.86363314092159, 69.72092360258102, 74.56832349300385, 71.94249719381332, 69.60312992334366, 74.04414921998978, 71.54822275042534, 73.97624686360359, 53.005612939596176, 0.762975427787751, 3.953683809377253, 62.52918630838394, 76.91921174526215, 71.13197788596153, 27.04259790480137, 14.349854942411184, 30.00899612903595, 17.74531379342079, 24.61419951170683, 89.34797242283821, 88.7280660867691, 43.00597831606865, 59.17310379445553, 67.91825473308563, 75.61132192611694, 4.175793053582311, 0.7756900205276906, 0.43306736333761364, 0.6131513079162687, 0.2133459792821668, 0.2325550766545348, 0.17222636699443683], [0.07327068902668543, 0.09873439921648242, 0.04640541068511084, 0.09599758122931235, 0.08063466419116594, 0.05235916796664242, 0.10506943115615286, 0.2054188773036003, 0.10767618034151383, 0.17508235905552283, 1.744740146677941, 48.699205219745636, 56.073598712682724, 41.46636173129082, 27.041336372494698, 39.43000540137291, 48.265599086880684, 23.40320449322462, 30.754320435225964, 21.212874725461006, 2.3735476238653064, 38.02101440727711, 59.177971333265305, 47.86385424435139, 65.85675895214081, 8.906867410987616, 0.39139434637036175, 23.75398837029934, 62.09485441446304, 70.43788433074951, 58.914292082190514, 66.95828184485435, 55.93539632856846, 52.75569275021553, 52.094129249453545, 61.18701092898846, 58.923358395695686, 57.762817069888115, 54.101607128977776, 56.10540680587292, 52.925167456269264, 53.73440623283386, 50.44241487979889, 55.274984166026115, 56.673012748360634, 52.39961385726929, 55.7774768024683, 61.054094061255455, 57.52757929265499, 62.14685082435608, 60.62149867415428, 60.89087761938572, 58.15116003155708, 51.23292826116085, 50.54268389940262, 55.08342504501343, 52.8358456492424, 54.97846707701683, 54.05363850295544, 55.327584743499756, 57.98880994319916, 58.36381942033768, 57.46063448488712, 61.500209122896194, 56.46324120461941, 54.51423838734627, 49.52954426407814, 47.81916864216328, 47.94424653053284, 48.701758682727814, 51.43313571810722, 48.29697020351887, 52.259082198143005, 52.43823878467083, 59.28646691143513, 49.84341882169247, 28.845690451562405, 24.515665099024773, 23.838499635457993, 32.45500847697258, 40.76144635677338, 37.658890038728714, 40.419954881072044, 41.158836632966995, 38.999047726392746, 40.65712295472622, 42.94773504137993, 52.818115800619125, 48.33470977842808, 44.31218482553959, 49.26029451191425, 42.38419108092785, 42.013292983174324, 40.14754369854927, 42.31936275959015, 37.689349204301834, 36.10845163464546, 35.69480203092098, 51.03902466595173, 67.05666616559029, 44.30536039173603, 37.279267609119415, 43.06326784193516, 56.06668308377266, 61.107629388570786, 53.32864120602608, 48.38828310370445, 48.78108702600002, 52.3570941388607, 51.877658665180206, 48.31858344376087, 47.65524923801422, 51.438812613487244, 50.53187347948551, 52.33868792653084, 50.08529484272003, 55.86216665804386, 54.63995084166527, 53.052776008844376, 55.264667719602585, 57.33388468623161, 53.20935420691967, 50.0561960041523, 50.16529954969883, 51.19343318045139, 43.86249415576458, 55.56537598371506, 58.46508778631687, 60.20752228796482, 55.35462029278278, 52.975153774023056, 52.95186102390289, 69.6770815551281, 70.80208718776703, 53.88273507356644, 51.06493927538395, 44.923986196517944, 47.687494307756424, 46.35979615151882, 51.25443510711193, 60.1848679035902, 61.59872263669968, 63.896314948797226, 58.06247279047966, 54.77236993610859, 48.90884377062321, 51.2015875428915, 65.18880799412727, 67.37581104040146, 54.52031046152115, 64.53109368681908, 53.53336662054062, 5.393387842923403, 0.5347522522788495, 20.765781216323376, 59.348274394869804, 52.074731290340424, 46.85295648872852, 3.2209332659840584, 9.788805786520243, 28.075542077422142, 25.49894403666258, 29.30642142891884, 49.628726541996, 67.52581939101219, 40.5789003521204, 48.920607939362526, 54.36627812683582, 58.25941622257233, 5.9990316443145275, 0.5740356724709272, 0.4959913931088522, 0.35298419650644064, 0.3203630360076204, 0.07391485836706124, 0.2209232625318691, 0.07532216332037933, 0.14581434050342068, 0.10940670545096509, 0.09327968058642, 0.096169136086246, 0.03897099828463979, 0.16506569576449692, 0.05505728295247536, 0.05698457738617435, 0.10550863415119238, 1.5555417677387595, 57.92971931397915, 62.427940741181374, 49.75113317370415, 29.709908477962017, 48.35620902478695, 34.772276133298874, 7.764472961425781, 28.89346718788147, 23.13534926623106, 5.373671650886536, 36.69003702700138, 69.22357589006424, 56.49189926683903, 69.00827944278717, 11.508830040693283, 0.6399985298048705, 17.49705981463194, 56.29652515053749, 69.43424418568611, 59.573374316096306, 65.97581416368484, 54.952677860856056, 55.36942429840565, 58.200941160321236, 65.40647551417351, 65.88268876075745, 63.72692383825779, 60.969320610165596, 62.846412286162376, 57.94955424964428, 51.44533686339855, 50.20562298595905, 53.8755002617836, 54.09009374678135, 54.095124676823616, 58.50889943540096, 61.63024574518204, 57.42471121251583, 61.41200065612793, 59.483607932925224, 58.17525073885918, 57.080833464860916, 52.120746821165085, 52.078892067074776, 55.64780876040459, 57.44038537144661, 59.31004084646702, 58.91892023384571, 60.40890768170357, 63.6434081196785, 62.51306377351284, 62.160841673612595, 64.83177155256271, 59.400601387023926, 56.860175505280495, 54.29230369627476, 52.17455193400383, 53.3093686401844, 52.37556494772434, 53.430323749780655, 52.902942448854446, 56.06345325708389, 57.86106839776039, 66.50239750742912, 53.25164593756199, 34.16943848133087, 31.870670132339, 28.549264557659626, 36.40225186944008, 47.38241247832775, 38.31571139395237, 39.595193937420845, 40.882165879011154, 40.17234496772289, 39.94839258491993, 40.132146924734116, 51.351174116134644, 44.847959876060486, 44.93735767900944, 51.22718296945095, 41.4647202193737, 43.96607659757137, 41.261336132884026, 41.67727701365948, 35.70053592324257, 41.11228533089161, 35.24430200457573, 41.33339926600456, 60.71113206446171, 55.25015629827976, 46.78380399942398, 43.82669247686863, 53.94524171948433, 62.691844180226326, 57.71163001656532, 48.97333391010761, 48.153736889362335, 52.21276268362999, 52.833782359957695, 49.555059894919395, 49.65767718851566, 52.63064906001091, 54.68214377760887, 56.599216908216476, 53.63020442426205, 57.32310466468334, 57.56929725408554, 56.249715462327, 57.17534959316254, 55.508287847042084, 53.31469215452671, 52.06779666244984, 54.41560707986355, 54.13628026843071, 48.446579575538635, 56.93008795380592, 62.361508905887604, 64.03693780303001, 59.992066249251366, 52.51097068190575, 55.517901331186295, 62.65874035656452, 63.44970591366291, 61.62817105650902, 55.97882799804211, 49.39123548567295, 51.88268579542637, 50.213693752884865, 48.787444084882736, 61.30173437297344, 60.78422874212265, 66.14587783813477, 58.30417022109032, 56.55076950788498, 50.91284483671188, 54.75581042468548, 67.20814883708954, 76.09489157795906, 63.99356693029404, 73.96806210279465, 48.58850955963135, 4.064062898978591, 0.1783003262244165, 32.47347168624401, 68.41530606150627, 63.52131687104702, 47.18610741198063, 6.615871544927359, 18.45423225313425, 27.078952454030514, 26.10009267926216, 33.44841957092285, 59.474853202700615, 77.66706481575966, 43.91448676586151, 53.07141400873661, 68.65669950842857, 72.0619323849678, 8.1394605897367, 0.4054137534694746, 0.4012165521271527, 0.10013826060458086, 0.1740777285885997, 0.07171467994339764, 0.2708005142631009, 0.2091741593903862, 0.21604024252155796, 0.21058455167803913, 0.15640213096048683, 0.33271872613113374, 0.17335483222268522, 0.26380900817457587, 0.21641637780703604, 0.2622441452695057, 0.22266349493293092, 1.9163360889069736, 69.99061793088913, 72.02080339193344, 57.04891137778759, 34.989658668637276, 52.75768384337425, 63.629025891423225, 30.612597540020943, 34.92618307471275, 29.958312548696995, 9.250990245491266, 50.496786162257195, 67.54521355032921, 57.30429947376251, 72.88970276713371, 8.900363110005856, 0.7800980808679014, 34.02860663831234, 61.11442342400551, 72.55066975951195, 67.10252210497856, 73.80542322993279, 59.50730346143246, 59.91099759936333, 61.9233164191246, 66.65255025029182, 69.19568538665771, 67.62755513191223, 63.67780767381191, 65.13821750879288, 59.317644238471985, 57.2771043330431, 51.655765771865845, 53.67978796362877, 55.593106895685196, 56.26875624060631, 58.606117218732834, 65.12954637408257, 61.21149301528931, 64.95439857244492, 61.99595332145691, 58.76822032034397, 54.878741428256035, 53.12299624085426, 52.132564187049866, 55.60187302529812, 55.678883492946625, 61.73902630805969, 62.18813940882683, 61.050560250878334, 62.74400778114796, 65.56165918707848, 65.76478868722916, 67.70246431231499, 62.10717715322971, 58.550997376441956, 55.52498795092106, 54.031546488404274, 53.54682929813862, 52.601367831230164, 55.418627858161926, 55.430563017725945, 54.41712699830532, 52.29531705379486, 57.351105362176895, 52.158144414424896, 42.985805198550224, 43.831867799162865, 38.52361723780632, 43.431183099746704, 47.24099166691303, 39.83815670013428, 43.95337387919426, 43.55944521725178, 41.97130523622036, 43.08411352336407, 44.26336504518986, 53.85479897260666, 55.841408371925354, 53.06599169969559, 52.927002757787704, 46.167499870061874, 45.40113419294357, 42.71997906267643, 45.36639265716076, 40.83775766193867, 46.13921798765659, 36.09870135784149, 42.52296343445778, 61.894874945282936, 62.81782642006874, 53.41461539268494, 50.414387583732605, 59.5032262802124, 60.98961532115936, 52.14117832481861, 51.09241180121899, 50.72584167122841, 55.16354754567146, 57.48430721461773, 52.521492317318916, 54.070745185017586, 56.283176466822624, 54.33321610093117, 57.68835626542568, 56.133418902754784, 59.31659549474716, 58.9226858317852, 56.966816782951355, 56.223588064312935, 57.706545889377594, 54.50445011258125, 53.287109434604645, 56.24893270432949, 55.40593273937702, 50.379399061203, 62.74417497217655, 67.47427895665169, 68.57437312602997, 62.80706159770489, 55.629858523607254, 57.01218634843826, 61.99789881706238, 65.13858988881111, 63.03126096725464, 58.66453528404236, 53.144256100058556, 55.06641335785389, 52.304702550172806, 52.144164964556694, 64.00548309087753, 65.07464691996574, 70.28750360012054, 60.0416573882103, 54.57729980349541, 54.48333464562893, 61.221019104123116, 70.29897898435593, 72.5501149892807, 68.18712070584297, 74.2593240737915, 65.78861340880394, 12.564731631428003, 0.5850145302247256, 31.835746206343174, 77.16204151511192, 69.46477174758911, 60.11233739554882, 15.034921132028103, 16.861086040735245, 39.077612310647964, 34.75532904267311, 44.90839563310146, 62.52840735018253, 78.71563374996185, 54.721505865454674, 66.80483087897301, 74.58349987864494, 77.94805213809013, 11.116548590362072, 1.5196211077272892, 0.7550624711439013, 0.4146521264920011, 0.4338055627886206, 0.26545170752797276, 0.3828499704832211], [0.05188807859667577, 0.022729649281245656, 0.052617346300394274, 0.0490116514993133, 0.040491195031790994, 0.08993375973659568, 0.08421197184361517, 0.13336053845705464, 0.029922934190835804, 0.08880018853233196, 1.1023627663962543, 54.79815915226936, 50.84129847586155, 55.017855763435364, 26.260098293423653, 39.91941154003143, 45.031957402825356, 72.79771730303764, 37.75549225509167, 17.998676598072052, 10.13252204284072, 22.700282111763954, 57.00272485613823, 41.58900015056133, 66.82862520217896, 38.75381648540497, 0.19940987083828077, 0.3610414860304445, 11.800282001495361, 29.71591215580702, 41.893884390592575, 35.38117825984955, 40.085257440805435, 49.90101233124733, 57.12834231555462, 57.20499560236931, 57.74499982595444, 59.00494381785393, 58.50778229534626, 56.26999497413635, 54.938417226076126, 45.05965031683445, 49.560546800494194, 50.49359813332558, 60.242187827825546, 67.3181301355362, 62.72375486791134, 60.80805726349354, 61.03231742978096, 58.05595614016056, 59.175554662942886, 58.50276276469231, 55.610240176320076, 50.29290430247784, 49.96549107134342, 53.98931175470352, 55.863036811351776, 55.24029202759266, 57.12010815739632, 55.39263725280762, 55.047414377331734, 54.69225503504276, 54.666652008891106, 52.38375350832939, 52.26434491574764, 50.514827594161034, 45.63596919178963, 47.74875462055206, 46.56895972788334, 50.1934864372015, 49.48688395321369, 48.90607751905918, 46.492800414562225, 41.22612722218037, 39.50409762561321, 44.25075352191925, 32.56953053176403, 19.035317972302437, 23.05867698043585, 29.881854951381683, 37.27200239896774, 43.329515755176544, 39.62575189769268, 42.43850916624069, 41.95812374353409, 40.15589565038681, 42.117585986852646, 40.42461723089218, 43.08217942714691, 45.76120287179947, 40.6921798735857, 41.22037053108215, 40.81180885434151, 40.02161845564842, 40.664965733885765, 38.1543530523777, 39.96244803071022, 42.0558051019907, 43.09530012309551, 27.462984547019005, 20.792869962751865, 17.00332760810852, 23.34882941097021, 35.326586589217186, 44.69735495746136, 48.70183847844601, 48.24402764439583, 51.30124479532242, 49.81793358922005, 48.989258855581284, 48.66822548210621, 49.85440783202648, 53.287417218089104, 52.368269339203835, 53.954148441553116, 50.640239864587784, 48.80097135901451, 55.681421756744385, 57.02237360179424, 55.85862144827843, 55.8236139267683, 48.792220428586006, 49.38672132790089, 49.62796278297901, 45.27811199426651, 46.30476750433445, 56.17415651679039, 56.98039725422859, 63.63199733197689, 51.995824724435806, 52.26250201463699, 51.97190500795841, 74.61640611290932, 83.70958417654037, 53.95213834941387, 56.14430531859398, 44.08980555832386, 44.497972056269646, 46.61369472742081, 46.71048313379288, 56.72234170138836, 60.36839805543423, 60.68556323647499, 61.809208542108536, 61.10503792762756, 60.943500995635986, 55.06757989525795, 48.816881105303764, 62.074498906731606, 57.899993509054184, 50.1704178750515, 11.604400612413883, 0.35528868378605694, 0.1407128619030118, 42.251589596271515, 53.50087456405163, 56.82657390832901, 17.350666970014572, 1.42671454930678, 18.876021020114422, 29.569908790290356, 25.408311299979687, 34.70459036529064, 39.19876500964165, 24.414058551192284, 25.814215019345284, 49.71449553966522, 54.10200610756874, 55.3909083455801, 3.2898817537352443, 0.03391707279661205, 0.12254392160684802, 0.14862246403936297, 0.08595655323006213, 0.04519664878898766, 0.019469043872959446, 0.052732230760739185, 0.04459466683329083, 0.02407897209195653, 0.02320589843293419, 0.03283275422290899, 0.08978426150861196, 0.019932138457079418, 0.014778343083889922, 0.09757976586115547, 0.0636577614932321, 1.3483859086409211, 64.46533441543579, 58.498765379190445, 61.20585411787033, 31.37786317616701, 48.09683874249458, 36.7725495994091, 37.59568803012371, 34.15538303554058, 17.37460568547249, 11.43872095271945, 26.763911359012127, 59.220187067985535, 48.640688359737396, 68.5149747133255, 47.3812535405159, 0.4670052125584334, 0.38858018175233155, 8.557241521775723, 24.561794623732567, 43.563362807035446, 39.35510382056236, 45.14242507517338, 50.94208046793938, 58.532963544130325, 60.73920875787735, 62.309827879071236, 63.42984437942505, 62.3626222461462, 59.07701455056667, 56.19879059493542, 48.366916850209236, 53.496447801589966, 52.944873198866844, 68.50968539714813, 67.9570734500885, 62.91132040321827, 62.9939279705286, 60.95361985266209, 58.622281551361084, 58.93065020442009, 59.93114031851292, 57.07462839782238, 52.758432403206825, 51.44382834434509, 53.59957046806812, 58.61220829188824, 58.905366361141205, 58.28712813556194, 59.050484374165535, 59.09546256065369, 58.985956236720085, 56.84204287827015, 52.88229435682297, 59.13844585418701, 53.31825256347656, 49.05328921973705, 49.382929131388664, 49.24587428569794, 51.93286590278149, 50.34297801554203, 48.47502484917641, 47.85523630678654, 41.66724935173988, 41.38557806611061, 45.4233667999506, 33.52970860898495, 21.231508925557137, 23.422674648463726, 31.60511188209057, 37.1313301473856, 42.82025188207626, 40.684629678726196, 45.118687748909, 42.674286514520645, 39.8316590487957, 40.13360604643822, 40.36502882838249, 44.21386510133743, 43.5044089704752, 39.63748186826706, 39.62713122367859, 42.15614251792431, 41.29872992634773, 40.38676746189594, 40.06376579403877, 40.14879763126373, 40.81804811954498, 45.48377975821495, 31.981823667883873, 25.4339637234807, 23.466491997241974, 27.22770307213068, 39.074576273560524, 43.664076402783394, 48.093145340681076, 50.139688923954964, 50.75123950839043, 50.45514419674873, 48.10330979526043, 50.083797723054886, 51.16948686540127, 53.829617723822594, 54.88133288919926, 58.316131979227066, 53.935943618416786, 55.97568556666374, 55.36824256181717, 55.96114754676819, 56.587863117456436, 58.10978785157204, 51.87537498772144, 51.54357299208641, 50.21765314042568, 47.425505965948105, 49.070338904857635, 57.187018766999245, 60.386678874492645, 60.42550139129162, 55.46360224485397, 54.040225222706795, 52.74359039962292, 68.92137810587883, 76.2709741294384, 58.62113781273365, 55.563951060175896, 48.30555774271488, 45.08738502860069, 48.29172268509865, 46.773312762379646, 59.32439647614956, 60.29061242938042, 60.823773220181465, 62.32465848326683, 65.57097628712654, 60.3119520843029, 54.041733741760254, 54.164265766739845, 69.91415843367577, 62.494767755270004, 47.94340677559376, 8.057956863194704, 0.21398553246399388, 0.2809796039946377, 57.292957082390785, 58.578078523278236, 66.14563465118408, 16.721390336751938, 7.42334864102304, 17.414152063429356, 22.32848536223173, 27.22504321485758, 38.66928242146969, 49.05665963888168, 31.549741253256798, 32.43317484855652, 53.82603071630001, 63.067617416381836, 64.0599113702774, 4.228340908885002, 0.07236351739265956, 0.2544108359143138, 0.10788876854348928, 0.06346377893351018, 0.0903083587763831, 0.060733310019713826, 0.3203917422797531, 0.25562077411450446, 0.2008415330783464, 0.05400689165981021, 0.08277852102764882, 0.2829113253392279, 0.10305381743819453, 0.22550030989805236, 0.32967790961265564, 0.16264025325654075, 1.6476123710162938, 76.8401987850666, 66.39876186847687, 72.65294507145882, 35.89551866054535, 56.028966307640076, 60.87982401251793, 81.94853827357292, 47.88652762770653, 24.62742280215025, 16.455978378653526, 31.572319641709328, 65.80234587192535, 52.417894676327705, 78.41512307524681, 50.25753580033779, 0.3792589850490913, 1.0485651344060898, 16.41626860946417, 38.375330194830894, 56.535072550177574, 48.55547793209553, 53.2475421577692, 55.734561905264854, 63.55166584253311, 66.5612031519413, 66.34377121925354, 68.0376747250557, 64.2702528834343, 62.64830991625786, 60.50245866179466, 51.72984279692173, 56.61253899335861, 55.856903940439224, 66.11901327967644, 69.59555312991142, 67.47778996825218, 65.00896364450455, 64.09968003630638, 61.66017293930054, 59.46073696017265, 63.63384783267975, 61.223530769348145, 54.60523970425129, 54.4470389932394, 60.39531581103802, 62.25456364452839, 61.21548280119896, 62.015260085463524, 58.492009341716766, 61.994551196694374, 61.03283800184727, 62.49119974672794, 58.50397489964962, 59.99172806739807, 54.63384076952934, 50.09110473096371, 52.249639704823494, 52.99541048705578, 54.79084834456444, 53.734265640378, 51.0391690582037, 50.15542007982731, 44.20077480375767, 41.186962723731995, 48.39064657688141, 39.81629267334938, 30.58827504515648, 34.81069207191467, 37.43244878947735, 39.43196229636669, 46.118391305208206, 42.53866799175739, 47.903436720371246, 44.534442499279976, 42.856585532426834, 43.28885033726692, 43.500077202916145, 46.13558538258076, 48.70871230959892, 40.41332423686981, 41.64307124912739, 44.3655339628458, 43.90949383378029, 44.7440430521965, 45.200991332530975, 41.9972388446331, 41.106870621442795, 47.295651733875275, 39.019730016589165, 36.24738357961178, 31.888842657208443, 39.43482354283333, 42.569172754883766, 46.08636662364006, 51.54165409505367, 53.575810343027115, 53.87259341776371, 53.879398852586746, 51.54081054031849, 52.27251447737217, 52.00647935271263, 59.01149846613407, 58.497769832611084, 61.81397348642349, 56.08552247285843, 60.65474309027195, 59.45506006479263, 57.46720053255558, 60.03986768424511, 63.27770434319973, 53.270344734191895, 54.967641457915306, 52.565258368849754, 49.302460849285126, 52.09771245718002, 60.691354125738144, 62.345595359802246, 66.15617528557777, 59.16118003427982, 55.98792850971222, 52.9033300280571, 70.56313320994377, 82.14928150177002, 59.31328967213631, 58.101253509521484, 50.91331601142883, 49.83005873858929, 54.30702030658722, 50.19326984882355, 62.67341896891594, 65.29323399066925, 65.70864289999008, 65.41928842663765, 67.84925043582916, 60.37610024213791, 55.8603123575449, 60.29251992702484, 73.67591857910156, 64.26285848021507, 63.98818641901016, 16.002394817769527, 0.5682347493711859, 0.26648507395293564, 57.5040889531374, 68.4631758928299, 72.41229638457298, 29.00799684226513, 8.976167142391205, 27.96151589602232, 44.459863901138306, 35.61890870332718, 49.899139031767845, 55.30159413814545, 36.571506187319756, 32.75156356394291, 67.41485014557838, 70.61001509428024, 77.88921609520912, 9.060039091855288, 0.5670042685233057, 0.4449727479368448, 0.21651869028573856, 0.27800311683677137, 0.2285457425750792, 0.2807287283940241], [0.095841715374263, 0.027456842399260495, 0.12512209068518132, 0.13822939828969538, 0.05677514702256303, 0.15432134183356538, 0.08474956877762452, 0.06362224230542779, 0.04325557267293334, 0.09478275227593258, 0.7126211829017848, 52.709012255072594, 54.75803330540657, 46.16566076874733, 28.031439743936062, 38.873369470238686, 38.08136276900768, 121.91551566123962, 129.6471431851387, 9.829054176807404, 8.44695433974266, 37.40648478269577, 58.750300481915474, 51.61773361265659, 48.76855909824371, 59.83450770378113, 7.545099807903171, 0.06028274474374484, 0.16870558873051777, 1.3137881713919342, 5.229245200753212, 5.404228186234832, 6.620827903971076, 31.649732887744904, 55.011844485998154, 56.31506435573101, 60.5913320928812, 55.04825413227081, 57.08794288337231, 52.92838208377361, 49.6077174693346, 47.151536867022514, 52.82571539282799, 64.72699597477913, 53.72274465858936, 37.472149059176445, 45.167993903160095, 52.82509982585907, 51.195158287882805, 49.46287304162979, 56.93794973194599, 59.48231980204582, 59.61942404508591, 54.67211231589317, 52.30650745332241, 50.57704545557499, 53.316101878881454, 55.7408581674099, 55.63360512256622, 53.5817152261734, 54.01396103203297, 56.325050219893456, 52.04570844769478, 52.25255034863949, 38.644393756985664, 27.21303965896368, 33.48297871649265, 42.20394395291805, 45.05796320736408, 45.1938097178936, 41.67416878044605, 47.52255275845528, 49.77551266551018, 43.974447548389435, 38.01589608192444, 41.17877796292305, 48.003215566277504, 47.42025084793568, 33.57016123831272, 34.058127254247665, 36.849814653396606, 47.271918207407, 42.635912373661995, 41.764459535479546, 43.41397762298584, 43.123798593878746, 39.16560418903828, 44.243769496679306, 40.441351532936096, 41.18055246770382, 43.36535923182964, 40.280506163835526, 41.39241009950638, 42.92795330286026, 40.55487424135208, 40.04941016435623, 38.50834205746651, 39.90011617541313, 26.87207255512476, 22.601772397756577, 17.048007510602474, 23.086996860802174, 35.62273509800434, 38.06642197072506, 39.982115775346756, 43.86831924319267, 46.15060977637768, 49.01235021650791, 48.354499116539955, 48.74788820743561, 51.16083852946758, 48.77092257142067, 48.71703766286373, 48.388397097587585, 51.25768393278122, 49.78837497532368, 50.14333672821522, 47.663209810853004, 51.251832246780396, 58.41043911874294, 52.908900529146194, 55.58400258421898, 52.64947324991226, 49.564946964383125, 46.09788000583649, 51.93192355334759, 51.638400703668594, 56.614017114043236, 56.188208162784576, 57.20227114856243, 45.567819848656654, 68.24505239725113, 66.87812894582748, 56.386542320251465, 63.60868938267231, 56.300465539097786, 49.18258488178253, 43.692624270915985, 45.16690716147423, 45.81769824028015, 48.82726974785328, 58.147303238511086, 56.68664641678333, 59.87726300954819, 58.19071590900421, 63.225992918014526, 54.9861578643322, 53.303068578243256, 44.94338795542717, 50.23975655436516, 13.904890269041061, 0.9353207016829401, 0.10403633932583034, 7.430738769471645, 55.5065893381834, 53.015344217419624, 50.013231709599495, 11.716384403407574, 7.664373982697725, 13.92641706392169, 24.509473331272602, 25.205343291163445, 34.12682756781578, 55.09601756930351, 48.314882442355156, 18.302728682756424, 46.27679720520973, 50.2922735363245, 45.14058977365494, 1.3528263266198337, 0.1123366154206451, 0.10347094896133058, 0.03691497091494966, 0.05260498954157811, 0.08203628429328091, 0.11831007301225327, 0.1610189425991848, 0.024656158893776592, 0.0262353582365904, 0.0778460294532124, 0.052065548370592296, 0.07147486234316602, 0.022265717925620265, 0.13036788732279092, 0.07275964613654651, 0.15606089145876467, 0.8909991080872715, 58.93042601644993, 63.05991142988205, 51.47159345448017, 22.245687805116177, 45.04928067326546, 45.56301690638065, 134.79436218738556, 139.65495496988297, 13.467239253222942, 8.82476806640625, 41.581233367323875, 59.1600438952446, 54.44787494838238, 55.518323108553886, 64.68105643987656, 11.749811209738255, 0.1999578726827167, 0.4308709624456242, 1.1125083407387137, 3.450365667231381, 6.015847641974688, 13.181209601461887, 38.10001976788044, 57.30666674673557, 59.41447824239731, 61.52376785874367, 58.825867027044296, 59.30683381855488, 56.62528730928898, 52.273054048419, 49.8088900744915, 56.67439587414265, 67.48644590377808, 47.08598658442497, 34.65482823550701, 47.49908521771431, 52.06481382250786, 51.24955616891384, 50.173716098070145, 57.62567102909088, 58.831190541386604, 62.822272181510925, 55.801491513848305, 56.8293933570385, 52.217535227537155, 56.11961044371128, 57.498898431658745, 57.79704563319683, 57.81054250895977, 58.670842945575714, 57.631849497556686, 56.051407903432846, 57.563924342393875, 39.11629043519497, 30.085917301476, 34.75274138152599, 42.53620572388172, 46.676524356007576, 45.9834985435009, 42.88799084722996, 47.473303601145744, 51.511738300323486, 47.69900768995285, 39.5074300467968, 39.61259700357914, 46.34917192161083, 44.62512843310833, 34.27975036203861, 31.85863997787237, 36.8083056807518, 45.98897784948349, 41.783401519060135, 41.50115266442299, 43.87652300298214, 41.55425861477852, 38.19577842950821, 42.92551003396511, 40.710586085915565, 41.943388134241104, 43.26306872069836, 39.33001756668091, 42.302294075489044, 43.14829207956791, 43.204259276390076, 40.754181146621704, 37.4808543920517, 40.604518577456474, 29.62295014411211, 25.582273565232754, 18.56085453182459, 21.659065783023834, 36.177440732717514, 35.232610031962395, 38.281672820448875, 45.02632990479469, 46.34264387190342, 49.15768101811409, 50.553501918911934, 53.242648020386696, 51.789400801062584, 50.65658278763294, 49.89675275981426, 50.64628154039383, 52.60545641183853, 51.35505750775337, 53.299534767866135, 52.132598385214806, 51.31773591041565, 58.7623306363821, 56.74659959971905, 57.96517141163349, 54.42242011427879, 51.83165833353996, 48.39763820171356, 53.372715041041374, 50.64459063112736, 57.05690614879131, 58.43014106154442, 58.59806925058365, 49.13693033158779, 67.97670319676399, 61.56485125422478, 54.871863797307014, 67.36536920070648, 56.91837318241596, 51.22058652341366, 45.1397006213665, 47.46411569416523, 47.31092311441898, 48.90578493475914, 60.11332534253597, 58.97631995379925, 61.19589865207672, 59.655541107058525, 65.80553770065308, 57.78335116803646, 57.59535625576973, 54.911336079239845, 52.9902845621109, 8.964539766311646, 0.11439545181929134, 0.07818301644874737, 13.267589416354895, 65.5924679338932, 60.51386184990406, 55.21456740796566, 16.881694234907627, 11.629357673227787, 10.604299027472734, 22.108148485422134, 27.040680907666683, 27.716210559010506, 53.67854543030262, 57.22434036433697, 15.581662394106388, 50.91062195599079, 57.59347155690193, 57.807605266571045, 2.750076544471085, 0.052016006302437745, 0.12866477714851499, 0.032107033985084854, 0.06903707049787045, 0.0677233948954381, 0.06479696559836157, 0.22545825981069356, 0.12797806790331379, 0.17822579975472763, 0.21944529027678072, 0.15983739896910265, 0.18221163743874058, 0.17833770078141242, 0.21516388485906646, 0.16305398574331775, 0.30758794338908046, 1.16525758523494, 71.86592370271683, 73.5811972618103, 66.12816318869591, 35.70990242063999, 60.12352019548416, 50.10587453842163, 128.6769336462021, 131.07846558094025, 15.410321038216352, 13.695901483297348, 46.75616808235645, 67.15830311179161, 62.360558956861496, 59.463457614183426, 73.75590428709984, 10.08695013821125, 0.4474188369931653, 0.8893506496679038, 1.9174825586378574, 9.334208630025387, 14.9840684607625, 25.840819291770458, 47.32000842690468, 64.29165333509445, 63.80759730935097, 68.3273483812809, 61.69076509773731, 63.653705567121506, 59.20351356267929, 55.981073677539825, 55.20540229976177, 57.90013030171394, 70.53551629185677, 61.608187928795815, 40.81855349242687, 50.02149626612663, 54.21491704881191, 54.10126134753227, 52.255882769823074, 61.446966379880905, 60.583675503730774, 63.35928976535797, 57.41437956690788, 60.71398191154003, 54.523179307579994, 57.98792079091072, 60.79865276813507, 60.488707199692726, 58.94396468997002, 61.937208473682404, 62.935593500733376, 59.01149086654186, 58.86078715324402, 44.0143758058548, 37.45339706540108, 44.002395048737526, 48.43679890036583, 49.175247475504875, 48.686377108097076, 47.17683210968971, 52.585891261696815, 53.99688854813576, 50.54132357239723, 43.93907144665718, 43.939417228102684, 48.22252839803696, 47.07313947379589, 36.45172141492367, 37.33720310032368, 40.123563185334206, 50.03418378531933, 43.5124721378088, 45.254055485129356, 46.68785534799099, 45.35945802927017, 42.48557724058628, 47.079359740018845, 44.14028964936733, 45.081917122006416, 46.193973049521446, 43.40310640633106, 46.59599147737026, 48.395289927721024, 46.102029383182526, 44.41754937171936, 38.04202347993851, 44.395214170217514, 32.79639355838299, 34.94704395532608, 26.781796999275684, 28.298364020884037, 36.65259003639221, 36.93242222070694, 40.533036813139915, 47.15354695916176, 49.8468804359436, 53.92194136977196, 53.70122641324997, 52.736180797219276, 55.92785753309727, 52.16160982847214, 53.25559392571449, 54.548064172267914, 57.440290376544, 53.00916574895382, 54.91486608982086, 55.913919880986214, 58.13735157251358, 58.8903571665287, 57.97691658139229, 60.875423848629, 58.63457769155502, 55.32171405851841, 50.40817491710186, 54.45546314120293, 55.81061862409115, 59.03500780463219, 61.64444178342819, 60.20597577095032, 52.59099438786507, 58.622308149933815, 69.35138583183289, 72.31898859143257, 67.5997406244278, 62.966018468141556, 53.07819664478302, 50.42749688029289, 51.62539400160313, 51.68012246489525, 51.75019450485706, 64.22151669859886, 61.32123112678528, 64.77112680673599, 61.65306732058525, 68.1356030702591, 60.65711036324501, 60.84047332406044, 55.986492186784744, 64.56355154514313, 19.13458574563265, 1.177047046367079, 0.12394326331559569, 11.223386507481337, 70.70906057953835, 66.61587461829185, 60.34421615302563, 19.95991475880146, 16.452659256756306, 22.193243019282818, 36.11137367784977, 35.44719971716404, 48.096188977360725, 77.73530915379524, 70.05093589425087, 25.08541412651539, 63.91190931200981, 66.56520053744316, 73.41764643788338, 5.667196400463581, 0.3946414205711335, 0.23778030095854774, 0.22019199474016204, 0.17819943866925314, 0.12511272478150204, 0.30157841742038727], [0.27343757275957614, 0.054504902436747216, 0.049625207248027436, 0.07870390021707863, 0.1575560963829048, 0.02565003749623429, 0.1429094112245366, 0.1016948114556726, 0.05361771312891506, 0.1754911636817269, 0.21967483655316755, 45.64063914120197, 56.67921781539917, 50.853883400559425, 35.33140853047371, 35.290914103388786, 26.74259640276432, 16.623663380742073, 34.62443746626377, 10.065904017537832, 3.360715890303254, 46.67313113808632, 65.31863182783127, 50.08883625268936, 46.88684307038784, 59.919718131423, 28.414839170873165, 0.03437845858570654, 0.014187303168000653, 0.09100648225285113, 0.2724882768234238, 0.44525488279759884, 3.3777686627581716, 19.27619654685259, 55.276982858777046, 48.90785202383995, 58.86113293468952, 55.38125306367874, 57.74917960166931, 48.776337280869484, 47.542505487799644, 46.03689327836037, 58.9388045668602, 36.628111749887466, 17.73267187178135, 36.74180164933205, 42.22786746919155, 45.94898119568825, 47.13527753949165, 43.11912104487419, 46.72367222607136, 59.85294811427593, 57.595660239458084, 56.87427654862404, 57.765260338783264, 53.38025003671646, 51.85500808060169, 50.95262490212917, 52.717812582850456, 51.05018846690655, 56.6698095202446, 56.880550011992455, 48.920307755470276, 35.002125799655914, 23.688158802688122, 33.388386592268944, 27.113030925393105, 42.282785922288895, 42.760021314024925, 39.530160427093506, 41.72417409718037, 44.69167426228523, 53.27252961695194, 44.36646491289139, 49.69868078827858, 47.80471421778202, 49.334599524736404, 47.86807581782341, 46.6759429872036, 42.52802476286888, 44.291464537382126, 46.07175260782242, 46.27814993262291, 44.8538875579834, 44.31323356926441, 43.7039590626955, 44.50407072901726, 44.17951874434948, 43.876682594418526, 43.29841822385788, 40.80159120261669, 40.59324078261852, 40.40294699370861, 39.647855311632156, 38.45449894666672, 40.63450276851654, 41.67790777981281, 35.01132510602474, 32.6620327681303, 28.624553717672825, 32.52289563417435, 41.80572912096977, 40.69057255983353, 35.56093141436577, 41.57838352024555, 43.079257383942604, 46.34072117507458, 49.0357531607151, 48.90560634434223, 45.70570304989815, 45.7862663269043, 47.40244500339031, 47.03086294233799, 48.106444627046585, 47.13455557823181, 47.600456178188324, 43.329937532544136, 44.48142394423485, 38.20698402822018, 55.58112993836403, 54.02930460870266, 50.948509722948074, 50.2032595127821, 50.32770283520222, 44.89347003400326, 50.44363081455231, 50.233106911182404, 57.36819684505463, 54.69903767108917, 54.1735714673996, 44.530711099505424, 80.97936987876892, 48.72204199433327, 29.153781719505787, 68.516775816679, 52.46653966605663, 50.249138250947, 39.54512022435665, 44.62311454117298, 42.7557959407568, 49.66653071343899, 50.74174381792545, 58.47150944173336, 53.27045872807503, 59.43812817335129, 59.03615914285183, 57.53810092806816, 50.16121856868267, 48.295020908117294, 14.90391556173563, 0.699764572782442, 0.3783129248768091, 0.2763063000747934, 20.21080769598484, 55.05540154874325, 49.983768090605736, 46.26749150454998, 23.43065422028303, 10.06618995219469, 8.315956369042397, 17.585815452039242, 25.107812024652958, 36.31809778511524, 48.735744059085846, 47.69474431872368, 31.627010107040405, 47.80573256313801, 49.994529113173485, 42.72470220923424, 1.8502769898623228, 0.17696365888696164, 0.1628428595722653, 0.06804449250921607, 0.08676787649164908, 0.0776885605591815, 0.16942765389103442, 0.4317975486628711, 0.016481778875458986, 0.02886490990931634, 0.03664062489406206, 0.05923168551817071, 0.03849048734991811, 0.03365919132193085, 0.1179419677646365, 0.10050748649518937, 0.18543537851655856, 0.3422106464859098, 52.71745540201664, 65.22736072540283, 58.59593756496906, 33.63116696476936, 46.74014054238796, 35.718497559428215, 31.321485601365566, 44.17595453560352, 14.775466304272413, 4.522123094648123, 48.65279830992222, 70.98435580730438, 50.709126368165016, 53.45259055495262, 62.559964656829834, 32.12677448987961, 0.24123173294356093, 0.12176599499071017, 0.08046336166444235, 0.10655262813088484, 0.4131583316484466, 2.5022125197574496, 29.51903712004423, 58.744110614061356, 54.23371084034443, 62.063943073153496, 55.955964624881744, 61.68914258480072, 49.82327610254288, 49.39225763082504, 49.15517695248127, 63.30583803355694, 41.8629502505064, 32.57831186056137, 45.00281676650047, 44.36275631189346, 46.104145869612694, 45.44024929404259, 42.54257798194885, 49.73172001540661, 60.28143972158432, 58.56031447649002, 60.36468185484409, 55.731989443302155, 56.16410605609417, 53.699926882982254, 53.002987280488014, 52.99629203975201, 54.67294067144394, 60.84148786962032, 60.93239799141884, 50.21416872739792, 36.50330364704132, 26.477556824684143, 37.41772837936878, 33.67512680590153, 42.974519804120064, 42.271603122353554, 42.40062519907951, 41.96583352982998, 46.5618959069252, 57.089690789580345, 48.08795481920242, 47.419186905026436, 46.916739866137505, 46.92400507628918, 45.35040311515331, 44.9021677672863, 39.90487352013588, 42.14626684784889, 43.24780113995075, 44.32725101709366, 43.517039492726326, 43.3837616443634, 43.68794672191143, 45.63832126557827, 43.55178862810135, 44.140601232647896, 43.03790420293808, 44.4670645147562, 42.46712163090706, 43.269326984882355, 41.866271272301674, 39.905736073851585, 40.476921424269676, 38.161971643567085, 34.90217596292496, 30.524178184568882, 27.913516871631145, 29.95263185352087, 37.9274558275938, 36.8491230905056, 33.29097121953964, 39.86985079944134, 42.159999310970306, 47.855585888028145, 49.329412803053856, 50.92675969004631, 45.916907116770744, 47.12183006107807, 48.7428230792284, 47.71871343255043, 50.71870945394039, 49.11605045199394, 49.770914912223816, 46.05309560894966, 45.416048392653465, 44.513699412345886, 56.69025242328644, 58.318282663822174, 56.37872613966465, 51.98411375284195, 50.65224342048168, 47.49117784202099, 52.57157362997532, 52.47292332351208, 58.26255105435848, 57.09482051432133, 57.65297256410122, 50.709700137376785, 84.30989116430283, 50.23665972054005, 35.28211757540703, 69.50337007641792, 55.17320282757282, 52.33486533164978, 42.93152131140232, 47.076452895998955, 45.40591053664684, 51.43656313419342, 52.516586780548096, 58.82476508617401, 55.40087901055813, 62.50669151544571, 61.26368701457977, 60.78878469765186, 53.66945631802082, 56.77533745765686, 14.983529839664698, 0.55672611691989, 0.12665052898228168, 0.15755896107293665, 29.00165308266878, 61.08624793589115, 56.47330306470394, 53.330902084708214, 31.208779849112034, 15.720224808901548, 9.553576558828354, 17.577662989497185, 23.469938412308693, 29.230182319879532, 49.413122311234474, 50.009097531437874, 29.958988912403584, 57.640182450413704, 61.78792208433151, 55.140782967209816, 2.463900838047266, 0.14982872118707746, 0.06720877485349774, 0.03298464958788827, 0.16498164011863992, 0.09263033847673796, 0.1974884356604889, 0.8045152737759054, 0.2120870296494104, 0.1485838575172238, 0.18809827859513462, 0.3000927862012759, 0.0896922945685219, 0.1986808591755107, 0.21570151147898287, 0.17809313343605027, 0.4316608450608328, 0.4305679287062958, 62.81311087310314, 74.30299893021584, 66.3512872159481, 46.23969219624996, 58.139768242836, 40.66144712269306, 25.413537919521332, 39.083547592163086, 16.842845119535923, 9.604650568217039, 54.47658620774746, 75.86400836706161, 57.60771319270134, 58.40670391917229, 69.17145788669586, 35.751460790634155, 0.2556298876879737, 0.2831244998378679, 0.16862975608091801, 0.6063021754380316, 2.133848648518324, 3.828747938387096, 40.87955541908741, 62.07571104168892, 58.860851749777794, 67.15105310082436, 61.21470384299755, 62.162513583898544, 52.412286177277565, 52.040449529886246, 51.763983964920044, 66.41869559884071, 46.35093502700329, 28.38148646056652, 36.168241426348686, 44.233650639653206, 45.54866887629032, 44.22657161951065, 42.11292743682861, 51.16481691598892, 63.74197103083134, 63.1601956486702, 62.47604615986347, 60.76418861746788, 59.75159615278244, 56.14220403134823, 53.90759713947773, 56.50394082069397, 57.97061651945114, 64.39174756407738, 63.72446916997433, 51.78248517215252, 44.978346079587936, 36.44825980067253, 42.07513086497784, 39.87289823591709, 48.372738137841225, 43.924617022275925, 45.19677735865116, 45.034959241747856, 50.7806271314621, 61.84372588992119, 52.06059604883194, 54.06246542930603, 50.57212091982365, 51.64248928427696, 48.35506148636341, 45.87265469133854, 41.744529604911804, 46.388389617204666, 45.58465674519539, 50.89418403804302, 51.94714553654194, 50.14046788215637, 48.5594867169857, 50.40105789899826, 48.12835045158863, 49.749636054039, 47.34655760228634, 46.53843216598034, 44.254564717411995, 47.43105746805668, 45.502820536494255, 44.138560742139816, 42.87830136716366, 41.80790640413761, 37.96669252216816, 37.054084092378616, 33.602269515395164, 35.91551698744297, 43.500677570700645, 39.195717573165894, 34.29096356034279, 41.91927842795849, 44.860924780368805, 49.07983459532261, 53.04709151387215, 51.48949049413204, 47.358971536159515, 47.34142787754536, 51.909421160817146, 48.63948382437229, 53.14812429249287, 51.90128579735756, 51.35304741561413, 48.95381435751915, 49.045830219984055, 48.899572268128395, 62.11555950343609, 60.63255228102207, 57.0993422716856, 55.29679499566555, 54.390118047595024, 47.27258697152138, 55.7309976965189, 55.1057830452919, 59.4293924421072, 58.42550151050091, 59.88412544131279, 50.43172985315323, 87.83098742365837, 55.03416448831558, 43.30556944012642, 71.32044017314911, 59.939834251999855, 50.786627009510994, 44.46522541344166, 48.988153114914894, 47.201933562755585, 52.37833499908447, 55.41428089141846, 61.73482373356819, 58.883585929870605, 64.6433624625206, 64.33751687407494, 62.11020939052105, 55.30789040029049, 58.69500204920769, 26.705778278410435, 0.7219607848674059, 0.5650622164830565, 0.6246941385325044, 29.61840368807316, 71.22574925422668, 62.38578960299492, 59.10624638199806, 35.11520393192768, 18.550357595086098, 15.93178415670991, 27.44789555668831, 35.072486624121666, 50.01548498868942, 71.8301448225975, 65.61521351337433, 39.785134345293045, 65.58181330561638, 67.99768567085266, 76.5104752779007, 5.757004106417298, 0.35894788743462414, 0.24002182442927733, 0.13349048851523548, 0.40052276279311627, 0.163691594498232, 0.2828415634576231], [0.6011720944661647, 0.3032932832138613, 0.25229547754861414, 0.08157158110407181, 0.15868617949308828, 0.08801720046903938, 0.17736765439622104, 0.17669451161054894, 0.026849273926927708, 0.19810165744274855, 0.23696088086580858, 43.66666406393051, 53.96155804395676, 53.87708097696304, 32.21050679683685, 25.311553291976452, 35.92756614089012, 25.835594572126865, 43.73201295733452, 7.4149121437221766, 7.399446498602629, 33.071259409189224, 68.36362883448601, 53.95863980054855, 46.14551804959774, 52.72269532084465, 44.26192492246628, 0.23267065873369575, 0.046293520790641196, 0.16010599705623463, 0.4757725592935458, 0.6654182157944888, 0.6656481034588069, 16.705106310546398, 53.09063717722893, 52.24953331053257, 61.62157081067562, 51.876997500658035, 57.6849402487278, 46.80445969104767, 44.51959669589996, 46.07942059636116, 66.99563384056091, 50.50007678568363, 77.1408386528492, 121.78341194987297, 64.61940094828606, 44.521280005574226, 46.63148157298565, 44.77588914334774, 50.31180448830128, 54.22722838819027, 62.1882002055645, 56.058232337236404, 57.606740444898605, 52.0099675655365, 52.0621083676815, 48.57121668756008, 52.791156247258186, 54.34969961643219, 53.89723889529705, 38.709719851613045, 30.555625297129154, 24.415188990533352, 38.09395529329777, 40.42918458580971, 65.53943797945976, 51.62255175411701, 47.40310616791248, 43.33389692008495, 44.7967766225338, 49.13135223090649, 47.25081793963909, 49.2244016379118, 59.40879374742508, 51.655199602246284, 53.84532228112221, 48.495182767510414, 54.260985776782036, 48.758664429187775, 50.473702400922775, 47.89879336953163, 49.542866349220276, 47.52397768199444, 46.34741261601448, 47.19692163169384, 46.24739058315754, 47.79082976281643, 43.426209166646004, 40.42130760848522, 39.087989553809166, 41.54253624379635, 43.08196283876896, 41.7280612885952, 40.00835716724396, 41.40277214348316, 44.7396656870842, 43.612041994929314, 45.13033792376518, 46.64789289236069, 51.76449693739414, 49.92417588829994, 46.4306927472353, 40.79273767769337, 43.550755083560944, 45.41437268257141, 51.17927134037018, 49.168704226613045, 48.66683855652809, 47.79412038624287, 48.70900869369507, 46.897402703762054, 43.28041858971119, 43.18188987672329, 39.42161165177822, 43.263479098677635, 41.04698583483696, 30.363456308841705, 24.079706892371178, 40.54188273847103, 59.46872033178806, 52.56397023797035, 50.20768627524376, 50.22987328469753, 50.928427800536156, 52.12790183722973, 54.734463170170784, 53.92243154346943, 53.95153798162937, 51.053308099508286, 51.202396899461746, 44.191271513700485, 46.45768649876118, 46.44803501665592, 62.735712826251984, 57.66774237155914, 53.570828810334206, 42.181213572621346, 41.198050528764725, 41.609591245651245, 50.63144713640213, 48.68810221552849, 53.085439056158066, 54.23902675509453, 57.54223510622978, 55.70288300514221, 60.68863347172737, 54.64351125061512, 36.52623921632767, 0.6263408751692623, 0.22441640321630985, 0.2833603840554133, 0.8116484410129488, 30.52585579454899, 56.039461344480515, 50.008953139185905, 56.20830908417702, 45.49666486680508, 20.945180989801884, 7.60331648401916, 15.425730161368847, 28.6579330265522, 63.32223415374756, 52.611049711704254, 43.80018129944801, 20.05289576947689, 48.94774988293648, 55.87057180702686, 31.338204704225063, 0.9129455429501832, 0.18628672580234706, 0.06840073823696002, 0.11257543112151325, 0.05449592987133656, 0.2520949492463842, 0.39366873214021325, 0.5976742040365934, 0.1588776832795702, 0.05460661748657003, 0.050069820499629714, 0.07531427429057658, 0.1977858439204283, 0.05346049656509422, 0.2581891097361222, 0.029695558696403168, 0.2838569995947182, 0.2825599629431963, 47.674202620983124, 62.45795153081417, 60.4127948731184, 34.454841166734695, 41.2889264523983, 39.96002376079559, 35.007624104619026, 52.82755069434643, 8.835419844835997, 8.941551949828863, 36.95223815739155, 72.81675428152084, 57.375047877430916, 51.97723612189293, 58.58283206820488, 51.284905672073364, 0.352056393167004, 0.2995658613508567, 0.1089256898558233, 0.4843020625412464, 0.49510117212776095, 0.46497425122652203, 23.91472164541483, 60.242237225174904, 53.71545284986496, 64.01108399033546, 56.45248018205166, 62.27963849902153, 50.72440914809704, 49.817382618784904, 48.46989892423153, 71.96422442793846, 60.5187863856554, 92.99065455794334, 100.97541689872742, 58.01081456243992, 45.98746173083782, 50.76489597558975, 45.97081862390041, 51.857930123806, 53.693531826138496, 60.55838406085968, 56.740132346749306, 59.42290619015694, 53.721536323428154, 52.44537100195885, 51.82149387896061, 57.80652232468128, 57.342631816864014, 54.38047796487808, 41.90178416669369, 35.84415681660175, 34.66737896203995, 41.950588747859, 38.44396211206913, 75.4754488170147, 53.736621513962746, 51.15087926387787, 44.40478205680847, 46.16295911371708, 51.56299754977226, 49.085636883974075, 50.77638275921345, 55.593980848789215, 48.5904398560524, 52.92027331888676, 46.5304221957922, 50.45260973274708, 47.57507734000683, 47.096759006381035, 45.58109633624554, 48.08722145855427, 47.579173520207405, 45.9236441552639, 47.3821958899498, 45.851539224386215, 47.02040210366249, 44.608154743909836, 42.75990732014179, 44.12332355976105, 42.33063295483589, 43.91700983047485, 40.70362485945225, 39.44936156272888, 39.86539363861084, 40.96183620393276, 41.980219557881355, 41.49718187749386, 45.03427527844906, 49.64562423527241, 44.82518009841442, 42.709419429302216, 36.400199979543686, 38.53225417435169, 45.61838373541832, 50.39065785706043, 48.90888936817646, 47.5937457382679, 49.51736591756344, 51.15743391215801, 46.805193051695824, 43.96218940615654, 45.45242004096508, 43.41826759278774, 43.58005531132221, 45.41510984301567, 32.46779479086399, 22.83882837742567, 44.76965747773647, 61.102518662810326, 55.89542247354984, 53.419577926397324, 51.23234309256077, 52.03903220593929, 54.039187878370285, 54.76446256041527, 54.89959090948105, 57.51614190638065, 54.8089961707592, 52.320513501763344, 45.475192219018936, 54.84970338642597, 53.55906464159489, 62.83390335738659, 58.63956302404404, 54.314726293087006, 43.56732219457626, 44.93177957832813, 44.99919556081295, 51.50169163942337, 52.98793628811836, 56.02589227259159, 57.33686372637749, 59.28847320377827, 60.0376296043396, 64.71821084618568, 60.08943982422352, 40.500981733202934, 0.32315532211214304, 0.2458910844870843, 0.2367638109717518, 1.494836937636137, 37.93013468384743, 60.65258480608463, 57.47972846031189, 61.39821879565716, 52.23987802863121, 25.92434450984001, 10.324614085257053, 18.575833328068256, 27.834186628460884, 61.75042189657688, 62.159264758229256, 52.1481167525053, 19.121541045606136, 53.3494982868433, 67.1192716062069, 43.18366438150406, 0.8965370140504092, 0.370882423594594, 0.14591252664104104, 0.016554370195080992, 0.03682225811644457, 0.17742048046784475, 0.10956441183225252, 0.8880706527270377, 0.30010849004611373, 0.3346002189209685, 0.09422478338819928, 0.3668491478310898, 0.42521273950114846, 0.21577421226538718, 0.3641801472986117, 0.19135440699756145, 0.6962937559001148, 0.4374205938074738, 59.610813707113266, 67.21108227968216, 75.26668801903725, 41.633438766002655, 40.30450947582722, 52.0952919870615, 31.894416958093643, 53.68370935320854, 11.506419070065022, 15.176630727946758, 41.21170699596405, 82.31628254055977, 62.23362676799297, 60.27738153934479, 64.95201230049133, 54.14027385413647, 0.5300010228529572, 0.6303782179020345, 0.2588923095026985, 0.7699598686303943, 0.4524023289559409, 2.1201959811151028, 34.52410005033016, 65.07424414157867, 61.564102694392204, 68.41196224093437, 58.69375951588154, 64.45383623242378, 51.91425450146198, 52.7740191668272, 50.987142249941826, 78.67467194795609, 45.66700592637062, 74.40256878733635, 101.01058781147003, 57.56571024656296, 47.49388329684734, 46.82406283915043, 46.11487649381161, 49.73212659358978, 58.441859632730484, 65.1391750574112, 59.05600167810917, 61.1996528506279, 55.21304368972778, 56.62648044526577, 54.76515032351017, 59.67006012797356, 59.49098713696003, 58.31671714782715, 47.97410152852535, 46.164954006671906, 45.807925164699554, 48.43237593770027, 43.955744951963425, 74.92103576660156, 57.431858628988266, 54.886690601706505, 49.37295086681843, 50.971988663077354, 60.41545853018761, 56.357842460274696, 58.00463609397411, 59.27865453064442, 55.426447838544846, 57.81203202903271, 49.8446461558342, 52.20609784126282, 49.88425903022289, 54.684856832027435, 51.626302152872086, 54.61497478187084, 53.57029303908348, 49.79865722358227, 51.096739768981934, 52.95247659087181, 54.51408639550209, 50.91453954577446, 50.29771484434605, 50.324381813406944, 47.341845855116844, 49.480310305953026, 47.79079556465149, 42.31072962284088, 41.10660083591938, 47.296810671687126, 48.49133737385273, 47.28476531803608, 51.13672122359276, 55.146741047501564, 47.401829436421394, 46.42612539231777, 40.578064396977425, 42.38296374678612, 47.87667095661163, 54.02630276978016, 50.14480344951153, 50.02250701189041, 54.75734934210777, 53.923088908195496, 49.608773812651634, 45.21162696182728, 45.136360600590706, 42.57961459457874, 45.115590915083885, 47.86181375384331, 40.49097307026386, 28.34816984832287, 49.56427060067654, 63.17457787692547, 55.871130377054214, 54.959673285484314, 57.07221932709217, 53.52353274822235, 56.65958046913147, 58.455785885453224, 58.192836195230484, 59.33856971561909, 59.828621819615364, 52.979029566049576, 55.55777259171009, 51.77033722400665, 46.28057040274143, 68.27355086803436, 57.81634479761124, 60.04318870604038, 44.81497384607792, 48.68182875216007, 47.717569693923, 56.449098363518715, 54.45045121014118, 58.767768144607544, 60.63654586672783, 64.19459134340286, 65.43454840779305, 70.2815455198288, 58.91516983509064, 48.35662320256233, 2.726071570068598, 0.4534047923516482, 0.6107251974754035, 1.5918998792767525, 45.456489622592926, 68.73024076223373, 62.84847177565098, 69.80666220188141, 54.97267618775368, 30.77074695378542, 17.468966022133827, 24.172898791730404, 40.14321953058243, 74.61079001426697, 74.3756890296936, 61.568700447678566, 26.36649828404188, 66.79893359541893, 76.78302705287933, 62.62282848358154, 2.139706271700561, 0.5906696361489594, 0.2710559614934027, 0.16716800717404112, 0.22884470934513956, 0.33825369318947196, 0.41095385618973523], [0.22710527846356854, 0.03743333509191871, 0.13648965570610017, 0.09332365283626132, 0.12937982159201056, 0.0983333500334993, 0.11264401298831217, 0.11338190073729493, 0.10677643760573119, 0.25498935487121344, 0.3041139501146972, 22.276108972728252, 62.319790944457054, 45.6885127723217, 42.2730166465044, 20.751064606010914, 44.44936506450176, 26.403743885457516, 36.26646235585213, 23.08533824980259, 2.7211057115346193, 28.732695914804935, 62.895076274871826, 61.677013635635376, 62.31379486620426, 47.838847786188126, 38.34821105003357, 1.0662416671402752, 0.34806951647624373, 0.11507414586958475, 0.2759052731562406, 0.6041590310633183, 2.292552595026791, 8.879237193614244, 46.02384477853775, 56.22071921825409, 56.44378624856472, 56.541376411914825, 55.21797202527523, 52.2034227848053, 47.273080945014954, 47.31354117393494, 56.83099307119846, 76.52993783354759, 70.24320557713509, 41.493602469563484, 61.711717173457146, 50.09945288300514, 49.61038872599602, 45.7797496765852, 47.2622325271368, 45.187931433320045, 48.00107628107071, 58.44003953039646, 57.058965638279915, 55.882339775562286, 52.850452065467834, 49.559296667575836, 46.36565163731575, 39.031186401844025, 33.363904505968094, 27.445927262306213, 35.471404418349266, 57.876472771167755, 57.302954345941544, 60.185958445072174, 76.85260131955147, 53.95927056670189, 49.752983674407005, 47.11597837507725, 51.75821587443352, 48.24123479425907, 50.717451721429825, 61.53265558183193, 59.22808304429054, 56.56892113387585, 59.040038734674454, 58.082353323698044, 59.00346949696541, 52.52375319600105, 50.474466159939766, 52.02301986515522, 52.177018001675606, 50.08138865232468, 49.674700275063515, 50.38359023630619, 47.209643349051476, 46.6557926684618, 42.442027777433395, 42.28235274553299, 41.924472749233246, 40.595197677612305, 41.054406836628914, 46.27974584698677, 41.41450971364975, 41.62347190082073, 45.05352504551411, 47.98613928258419, 48.58363822102547, 47.970681712031364, 44.9797710031271, 44.620511680841446, 46.879505664110184, 48.17904733121395, 52.2567605227232, 47.18837209045887, 49.89878185093403, 48.415337651968, 49.53889176249504, 45.158072635531425, 47.410671561956406, 45.52390560507774, 50.93416549265385, 46.80478647351265, 44.94660638272762, 36.8857379257679, 49.252596125006676, 30.78068532049656, 8.765331655740738, 23.238669522106647, 52.223322317004204, 57.02779211103916, 53.290384858846664, 54.337243884801865, 50.95680087804794, 53.38260971009731, 51.65636993944645, 55.24716965854168, 54.705941900610924, 45.93200370669365, 49.88429702818394, 36.378168761730194, 42.02530033886433, 53.393279537558556, 55.71896754205227, 62.841670140624046, 51.36771082878113, 43.21855790913105, 40.274605080485344, 47.06503450870514, 46.75438217818737, 55.29218964278698, 48.113561645150185, 55.01208767294884, 56.48020349442959, 61.05180658400059, 53.23348291218281, 64.48158994317055, 17.37663857638836, 0.5907561408821493, 0.18998762330738828, 0.12881001544883475, 0.7779826631303877, 35.995080918073654, 55.414220094680786, 53.722927048802376, 49.27960507571697, 56.08045354485512, 27.719871662557125, 5.25603661313653, 15.253297314047813, 21.806533969938755, 26.137885451316833, 38.799896612763405, 37.078607976436615, 29.737270809710026, 47.07044541835785, 48.38450990617275, 29.590602479875088, 0.5673898290842772, 0.29175003699492663, 0.06260365204070695, 0.07171188946813345, 0.17070187692297623, 0.26036143535748124, 0.02490908282197779, 0.2484107797499746, 0.09907629922963679, 0.05830506590427831, 0.08617038081865758, 0.09372295055072755, 0.05810089365695603, 0.03833366041362751, 0.19879320549080148, 0.12176442163763568, 0.37239236757159233, 0.6190926453564316, 25.070072449743748, 71.4657823741436, 51.28976181149483, 36.48265555500984, 33.084741085767746, 50.181631073355675, 28.510763123631477, 39.43141512572765, 22.81807579100132, 4.952784860506654, 26.17310956120491, 74.27485764026642, 63.24468031525612, 68.14164474606514, 52.834006547927856, 47.91982524096966, 1.7773824138566852, 0.3511654300382361, 0.2630419243359938, 0.2957541908835992, 0.9496223623864353, 2.385484683327377, 19.262370988726616, 53.120176792144775, 56.18401698768139, 61.878589019179344, 60.303250551223755, 62.774953320622444, 54.90223936736584, 51.61999449133873, 49.82099622488022, 59.59846056997776, 75.28605177998543, 67.78751134872437, 41.16222225129604, 59.983687698841095, 48.36390361189842, 48.72277535498142, 48.28532002866268, 47.45887577533722, 44.27238576114178, 48.74128416180611, 60.62171146273613, 59.053623005747795, 58.01060177385807, 56.60121940076351, 54.358971118927, 49.445682764053345, 38.51790614426136, 38.28131563961506, 36.9424232840538, 47.61726647615433, 61.49871960282326, 52.220073491334915, 50.30055709183216, 64.90740269422531, 55.76372534036636, 54.500334933400154, 48.508406057953835, 54.43645656108856, 50.60478016734123, 52.527484595775604, 56.96443431079388, 57.31139749288559, 56.80055670440197, 56.62971407175064, 55.866414830088615, 57.62504406273365, 53.3903156965971, 48.50628577172756, 49.00197297334671, 47.07315847277641, 46.334151327610016, 47.20183476805687, 44.95055437088013, 45.3427617251873, 46.29935659468174, 44.08328130841255, 45.88271655142307, 41.58038221299648, 44.399511739611626, 44.593396335840225, 44.67468537390232, 39.622951447963715, 41.002855002880096, 41.855605244636536, 43.38822640478611, 46.86575800180435, 46.49848870933056, 46.42257258296013, 44.51786778867245, 41.36745683848858, 45.55764399468899, 47.30057246983051, 44.95245806872845, 48.93676467239857, 48.29461432993412, 53.64475764334202, 50.42857222259045, 51.794940903782845, 48.10614824295044, 53.65525268018246, 48.275942131876945, 44.66424733400345, 36.89552240073681, 45.62756024301052, 36.795359775424004, 13.484505526721478, 23.55557631701231, 54.829579666256905, 59.06187616288662, 55.56100621819496, 53.208020478487015, 52.045062482357025, 55.481294095516205, 53.92208956182003, 56.568453758955, 56.150681376457214, 51.387910544872284, 51.99421361088753, 38.407985642552376, 49.789393320679665, 57.701932936906815, 57.66199707984924, 66.28082379698753, 53.61199200153351, 47.787721529603004, 42.25798465311527, 50.89516058564186, 48.43306750059128, 55.80970287322998, 51.875804364681244, 58.22475828230381, 60.015776976943016, 67.04186215996742, 57.879987582564354, 71.91927284002304, 18.813096396625042, 0.3742656373651698, 0.20878974173683673, 0.16719414561521262, 1.7625320982187986, 45.81240512430668, 60.354342609643936, 61.84749908745289, 53.431060910224915, 64.26988050341606, 25.164755769073963, 8.101514875888824, 19.832140915095806, 28.647396191954613, 24.700709469616413, 43.53675663471222, 47.574457973241806, 25.33690743148327, 56.00106820464134, 59.943375661969185, 43.754340559244156, 0.85814981139265, 0.4924522986402735, 0.09611225046683103, 0.17440498602809384, 0.10796092756208964, 0.17348276363918558, 0.057246804135502316, 0.3587471810169518, 0.14980010397266597, 0.12912395875900984, 0.18038905633147806, 0.28351412736810744, 0.2183668754878454, 0.20930556405801326, 0.39782603562343866, 0.1938788074767217, 0.5864198016934097, 0.6983098445925862, 33.76015104353428, 79.06409025192261, 64.50852289795876, 54.412388652563095, 31.587991900742054, 64.49240416288376, 33.657176569104195, 44.79421555995941, 31.449702121317387, 10.87611174210906, 36.68436013162136, 79.93143171072006, 68.85927423834801, 72.68395900726318, 58.64127293229103, 52.24011741578579, 1.888030932750553, 0.4535026371013373, 0.6538144103251398, 0.44159956800285727, 1.6377015528269112, 4.789703311398625, 27.36996553838253, 58.31645876169205, 62.58133850991726, 67.90335193276405, 63.26863802969456, 65.88902682065964, 56.51444345712662, 57.10617430508137, 54.74355228245258, 60.10350286960602, 74.44661602377892, 75.68934693932533, 60.16182214021683, 61.08710289001465, 44.77272391319275, 50.500559359788895, 45.92736415565014, 51.117543652653694, 44.842564165592194, 50.47866873443127, 60.84101289510727, 63.13737027347088, 60.56045114994049, 61.261494532227516, 55.71897894144058, 55.981142073869705, 46.36763893067837, 46.33784852921963, 44.7601617872715, 55.01532129943371, 62.54725433886051, 56.025869473814964, 51.83012701570988, 66.49844571948051, 60.08597820997238, 58.381575867533684, 52.89391413331032, 61.508245691657066, 56.05537489056587, 57.19905272126198, 64.50413033366203, 63.78998905420303, 60.1162663847208, 64.18915763497353, 60.72232626378536, 60.35042122006416, 57.937535494565964, 50.12889750301838, 52.14564308524132, 50.43941304087639, 50.9734021872282, 53.38543675839901, 55.07795713841915, 50.364557057619095, 52.671899646520615, 49.95021969079971, 53.189591467380524, 47.93057106435299, 48.416891768574715, 47.31674060225487, 52.775900065898895, 44.84624616801739, 44.98031437397003, 44.94526885449886, 47.33465664088726, 51.74952954053879, 49.96470831334591, 50.0657144933939, 51.965080574154854, 49.71973165869713, 50.93981198966503, 52.573139145970345, 50.13546735048294, 51.70751139521599, 50.20058065652847, 55.203217417001724, 52.66966536641121, 56.49337358772755, 50.962599366903305, 58.138924688100815, 52.987894490361214, 50.520770475268364, 40.59221863746643, 48.39476935565472, 43.326000943779945, 23.75873241573572, 31.195446364581585, 58.70535649359226, 62.20517009496689, 61.014158204197884, 58.551134169101715, 56.78875453770161, 57.4684202671051, 54.8880585283041, 58.68801802396774, 61.63496509194374, 52.75147117674351, 50.669764280319214, 41.46336369216442, 50.29017224907875, 51.797300577163696, 61.72863766551018, 65.92950984835625, 57.255620285868645, 48.44973340630531, 45.15634372830391, 52.10749693214893, 54.29938651621342, 59.8049832880497, 56.21640644967556, 63.11550624668598, 64.75534245371819, 70.07578656077385, 62.83569686114788, 70.57118117809296, 25.62895406037569, 0.6714731908868998, 0.24757546285400167, 0.3988681297050789, 1.8226314545609057, 53.079830557107925, 69.33684021234512, 66.53722643852234, 60.77105484902859, 69.44725468754768, 36.50161653757095, 12.897560521960258, 21.593312211334705, 30.76662227511406, 33.5573673248291, 57.79241368174553, 55.38991279900074, 37.145742774009705, 66.6299794614315, 67.86415323615074, 57.89467379450798, 1.4132410660386086, 0.5967312015127391, 0.264973200391978, 0.2529152302304283, 0.1994719885988161, 0.3869343950645998, 0.14464701642282307], [0.2548351068980992, 0.15229101874865592, 0.13377134688198566, 0.08781716198427603, 0.07026257153484039, 0.07120103953639045, 0.3314622404286638, 0.07360965755651705, 0.2868398989085108, 0.19718678231583908, 0.48454869305714965, 12.196285352110863, 61.48983187973499, 50.201731994748116, 40.67525938153267, 21.93816840648651, 44.82228085398674, 47.74556279182434, 27.083582505583763, 32.01539866626263, 8.55482580140233, 9.110290445387363, 61.49397365748882, 64.12510067224503, 60.7257004827261, 54.27758328616619, 41.680104061961174, 7.178909182548523, 0.37218014302197844, 0.24582353420555592, 0.6014566635712981, 1.2188430223613977, 0.3807339887134731, 20.936779640614986, 46.10819645226002, 56.12377502024174, 57.676679491996765, 59.31307688355446, 57.33254335820675, 55.63273876905441, 48.920281156897545, 49.190845638513565, 55.578055903315544, 62.96758398413658, 65.14860615134239, 39.67349253594875, 34.75474767386913, 81.70949310064316, 53.74649338424206, 47.93490283191204, 47.33073145151138, 51.15082986652851, 52.53728806972504, 50.98997309803963, 50.25241747498512, 47.16048538684845, 40.50320461392403, 39.39107269048691, 26.935610845685005, 29.785454124212265, 37.501202300190926, 56.224686205387115, 73.83962899446487, 80.81735417246819, 71.09615340828896, 59.13503363728523, 52.88534179329872, 54.513790011405945, 53.420231491327286, 55.234132558107376, 51.60157687962055, 54.77977193892002, 57.030349373817444, 60.189416259527206, 52.77543269097805, 45.043782368302345, 46.83104306459427, 54.728178307414055, 57.01820522546768, 53.41347925364971, 55.30952051281929, 54.502857998013496, 57.537975534796715, 56.67463146150112, 59.82259914278984, 57.14330591261387, 58.398291170597076, 45.96128113567829, 41.37808106839657, 37.6835773140192, 36.93622201681137, 35.92862628400326, 42.118855118751526, 36.72454297542572, 43.05398873984814, 47.4100635945797, 51.577835753560066, 54.38018158078194, 51.05226315557957, 46.54172658920288, 44.292467683553696, 35.530365854501724, 34.240855649113655, 38.52729544043541, 45.43422281742096, 53.209718987345695, 52.42348037660122, 46.58606261014938, 46.90022215247154, 43.03258068859577, 45.69268494844437, 44.22965705394745, 52.85583637654781, 49.279084503650665, 51.43711790442467, 42.522625252604485, 43.850296810269356, 55.75133040547371, 26.763833463191986, 22.875978983938694, 38.469470143318176, 55.816713497042656, 51.927523389458656, 50.70187255740166, 52.27628767490387, 54.454440996050835, 52.51630559563637, 47.14307092130184, 40.83121821284294, 48.58808398246765, 42.95604519546032, 50.95447540283203, 33.05050492286682, 41.527861431241035, 58.26494112610817, 60.67704789340496, 55.825665816664696, 47.41626866161823, 43.79800021648407, 49.59605969488621, 49.911769554018974, 50.44052638113499, 47.881663888692856, 57.762687876820564, 54.77748826146126, 60.06064496934414, 57.61744067072868, 61.879652962088585, 4.6499724593013525, 0.0975016770826187, 0.2715047827223316, 0.4207610705634579, 5.220221634954214, 47.68088646233082, 51.36436700820923, 55.401965752243996, 48.67848493158817, 58.774182200431824, 9.046162236481905, 9.06025093048811, 26.62584576755762, 19.842119179666042, 54.6679363399744, 48.48147690296173, 31.5170706063509, 43.84935066103935, 56.09471037983894, 52.65280567109585, 31.65214005857706, 0.5180965585168451, 0.3762835665838793, 0.024412279890384525, 0.20539876510156319, 0.041653713706182316, 0.16843905381392688, 0.08683307416504249, 0.15237568295560777, 0.06517074827570468, 0.10759528624475934, 0.11903988619451411, 0.02601713342301082, 0.07284735314897262, 0.11788561649154872, 0.14077305007958785, 0.287551618530415, 0.24388263991568238, 0.3958976687863469, 14.65626860037446, 73.11707496643066, 57.85363219678402, 35.02315767109394, 19.070055708289146, 60.08814409375191, 24.246559739112854, 17.978294491767883, 32.80308119952679, 12.852379996329546, 9.618895053863525, 62.72980414330959, 68.78237396478653, 66.1006298661232, 59.1941736638546, 49.670858681201935, 9.540132880210876, 0.5627198203001171, 0.1785642487811856, 0.5236140999477357, 0.9821972425561398, 0.4835927177919075, 29.640180319547653, 52.50812083482742, 60.99799007177353, 61.64780080318451, 61.2281209230423, 62.7708001434803, 59.129736721515656, 56.083736568689346, 49.87833134829998, 60.60188412666321, 62.93002299964428, 72.09595575928688, 46.68827712535858, 39.27404657006264, 77.77538180351257, 51.16183787584305, 51.10736399888992, 49.47757825255394, 52.47236855328083, 50.38794480264187, 50.01062884926796, 48.511381298303604, 48.37452784180641, 41.62252575159073, 41.5293775498867, 33.641681000590324, 41.675095930695534, 49.63484041392803, 62.89430491626263, 72.47090443968773, 71.21827885508537, 61.0890331864357, 55.897071585059166, 56.3926637917757, 58.4936660528183, 57.95181892812252, 56.53305105865002, 53.57849299907684, 53.22657108306885, 56.17140166461468, 61.38395816087723, 54.5383594930172, 50.159558057785034, 53.16518157720566, 58.154283463954926, 58.66233140230179, 58.99295926094055, 52.34099060297012, 52.42512948811054, 52.41431146860123, 52.188550382852554, 53.92147399485111, 51.33678048849106, 50.02700597047806, 44.84132543206215, 43.664103001356125, 43.14094327390194, 43.554691672325134, 41.70790337026119, 46.23561881482601, 45.112357288599014, 40.84252640604973, 43.964887261390686, 45.9073506295681, 48.040415570139885, 47.79257766902447, 48.662031814455986, 50.37397675216198, 45.028518587350845, 46.52422092854977, 45.959689021110535, 50.54530195891857, 50.62377914786339, 50.56928247213364, 44.97000552713871, 48.86093594133854, 46.751444935798645, 49.45419430732727, 53.47586050629616, 54.97837968170643, 51.275611370801926, 50.565250888466835, 48.24618972837925, 43.21440473198891, 53.240710124373436, 42.172192856669426, 24.502065628767014, 40.74803687632084, 53.68891507387161, 53.869716972112656, 53.31885673105717, 54.415895864367485, 56.10303193330765, 54.57457534968853, 52.67515227198601, 46.634616404771805, 50.88560409843922, 43.86486142873764, 47.91090331971645, 40.67111760377884, 48.034833669662476, 59.25318829715252, 63.17033730447292, 58.70612405240536, 50.11713333427906, 46.80619239807129, 51.380656734108925, 52.18578413128853, 52.70326316356659, 53.290806636214256, 60.81559605896473, 60.315402299165726, 63.82853418588638, 62.22986876964569, 67.00517132878304, 3.7441509403288364, 0.31473206472583115, 0.04867132112849504, 0.3966078447410837, 8.744667414575815, 54.35573369264603, 56.747180968523026, 64.82845813035965, 63.13534498214722, 64.10180792212486, 7.373907594010234, 14.214214570820332, 27.051574923098087, 25.068457536399364, 49.461771100759506, 56.63201294839382, 43.73477540910244, 41.516807824373245, 59.80749495327473, 64.4442455470562, 38.92910107970238, 0.7811438560020179, 0.6987993652001023, 0.033743636595318094, 0.23830936319427565, 0.01597759714059066, 0.15627929067704827, 0.09451396865188144, 0.36956914875190705, 0.17460720642702654, 0.1575376614346169, 0.2041037767776288, 0.18393814010778442, 0.3274213947588578, 0.2997774031246081, 0.2845096739474684, 0.36546646733768284, 0.5894880183041096, 0.9550417622085661, 18.781459294259548, 84.99250933527946, 66.30638882517815, 54.086575135588646, 28.98958683013916, 69.48364153504372, 61.426223292946815, 38.582669869065285, 39.47439841926098, 17.10309885442257, 14.989965744316578, 73.8315886259079, 73.42896983027458, 73.92961576581001, 63.46827171742916, 58.31488944590092, 11.037575528025627, 0.5235739052295685, 0.8197475282941014, 1.16387220332399, 1.5915782027877867, 1.380137954838574, 41.72637417912483, 59.35269735753536, 63.59601706266403, 69.06218335032463, 64.00273203849792, 65.66963419318199, 60.820668786764145, 57.71086625754833, 54.219473004341125, 65.93721583485603, 65.14351442456245, 71.04398220777512, 50.580419674515724, 46.43608085811138, 70.25105595588684, 49.46782797574997, 50.33430688083172, 48.471859619021416, 51.98228605091572, 50.2494802325964, 50.552149191498756, 49.91292469203472, 49.48017731308937, 43.41199792921543, 47.49098405241966, 42.370587810873985, 45.661298632621765, 49.541836604475975, 59.26375932991505, 64.06216084957123, 68.42953249812126, 60.58874823153019, 59.87944409251213, 58.29612985253334, 60.79681746661663, 60.48915937542915, 62.16532923281193, 61.58358044922352, 61.93004585802555, 62.49240808188915, 66.3609690964222, 61.86194971203804, 57.47529409825802, 58.391652926802635, 64.80993792414665, 62.9629672318697, 58.00019033253193, 56.277130991220474, 54.48711544275284, 58.22610341012478, 57.88420535624027, 62.31252193450928, 61.25848889350891, 65.30395701527596, 53.104476034641266, 47.70964711904526, 46.70069105923176, 48.66074748337269, 47.07799941301346, 50.89158497750759, 44.78551022708416, 45.999621078372, 50.366460755467415, 52.75120139122009, 54.62311774492264, 53.873737156391144, 55.767430141568184, 56.58803790807724, 52.341454178094864, 55.08087158203125, 54.322648867964745, 58.27898137271404, 58.633198365569115, 54.00845892727375, 48.11641149222851, 50.949015095829964, 52.26190164685249, 56.47274449467659, 56.55555345118046, 57.703810036182404, 55.62152557075024, 54.39852699637413, 49.07848186790943, 45.14840975403786, 55.87124057114124, 44.728824868798256, 41.19955524802208, 44.58784103393555, 61.626746132969856, 55.23289382457733, 57.32711724936962, 58.60560044646263, 58.44491466879845, 56.37290485203266, 58.54605384171009, 47.37501047551632, 50.70229813456535, 45.502349361777306, 50.60297526419163, 37.025665417313576, 42.605460807681084, 61.80306427180767, 64.78100627660751, 63.16566735506058, 53.72242547571659, 49.70431208610535, 55.917548686265945, 56.49740897119045, 58.32664221525192, 56.26779869198799, 65.03271237015724, 62.51595541834831, 68.85264739394188, 64.40080627799034, 71.07570290565491, 9.015718270093203, 0.2818095328984782, 0.46665815461892635, 0.4273265541996807, 8.567939847707748, 61.994106620550156, 61.04114055633545, 70.6995914876461, 60.041319206357, 71.44714817404747, 16.471736133098602, 16.778239086270332, 34.6442724019289, 29.914835281670094, 68.97001549601555, 71.81385889649391, 46.764238849282265, 55.64088933169842, 75.34841403365135, 72.62699246406555, 53.00454519689083, 0.9331888379529119, 0.6459433701820672, 0.1792089524678886, 0.2956849930342287, 0.2424714164226316, 0.24883938487619162, 0.3099232743261382], [0.29958756174892187, 0.11453869374236092, 0.11653898953227326, 0.057516289089107886, 0.10413525276817381, 0.07079152986989357, 0.24163789552403614, 0.22384681971743703, 0.3224604343995452, 0.30328678200021386, 0.2887892833678052, 7.637859955430031, 64.83568534255028, 49.31680127978325, 43.484007865190506, 45.371792167425156, 36.40526510775089, 59.70379091799259, 107.58094444870949, 17.277216911315918, 12.518293373286724, 25.44708251953125, 51.852215230464935, 64.71670612692833, 59.40020240843296, 48.45541790127754, 63.493958339095116, 22.736186385154724, 0.3134964779019356, 0.09562762061250396, 0.38067114364821464, 0.3752499329857528, 0.387632132624276, 26.14112477749586, 46.84441074728966, 56.1574450135231, 53.241344690322876, 61.87362268567085, 60.07557436823845, 58.59580837190151, 52.89497807621956, 49.627442210912704, 53.22192773222923, 60.82426719367504, 64.44120571017265, 62.02521935105324, 43.438725695014, 58.129508793354034, 89.87030759453773, 51.30587674677372, 53.450029492378235, 49.42821130156517, 49.6283845603466, 42.59330905973911, 38.58559191226959, 32.45866768062115, 29.52267922461033, 32.25331149995327, 45.66855624318123, 67.30119824409485, 81.62745550274849, 80.4194775223732, 67.90504664182663, 59.842544272542, 50.49523964524269, 52.28001907467842, 58.096264377236366, 52.84027241170406, 51.354707926511765, 57.42493160068989, 53.670068085193634, 58.09951700270176, 59.07431289553642, 50.54522216320038, 39.89130824804306, 38.345232009887695, 37.64416962862015, 44.615982323884964, 52.895164266228676, 53.39852325618267, 52.445454597473145, 57.807210087776184, 59.21667605638504, 58.40192757546902, 61.26813277602196, 53.582019209861755, 57.0572405308485, 42.156431302428246, 36.20405450463295, 29.706629253923893, 28.33699844777584, 20.67711867392063, 31.006389409303665, 38.64093214273453, 48.99345763027668, 52.84729443490505, 54.905890971422195, 57.6931744068861, 57.222117483615875, 47.7835151553154, 39.13373909890652, 24.79546308517456, 19.186340868473053, 18.507197611033916, 30.78499998897314, 48.659501150250435, 56.462382450699806, 51.33548095822334, 48.17643687129021, 44.642687290906906, 47.27160282433033, 47.736219093203545, 51.4420348405838, 52.44623355567455, 48.58771160244942, 51.80243030190468, 47.24874325096607, 63.03855657577515, 78.03507506847382, 45.47390028834343, 34.49946977198124, 39.526250436902046, 48.17843176424503, 52.28916518390179, 45.900837779045105, 43.93027111887932, 43.60885016620159, 44.16844233870506, 45.263752564787865, 45.761567652225494, 45.13324856758118, 52.383472323417664, 39.07699674367905, 36.31642587482929, 58.01135033369064, 57.43427149951458, 62.33469374477863, 47.93592117726803, 49.73067507147789, 49.35592778027058, 53.750015795230865, 48.860631957650185, 48.244624212384224, 53.54837581515312, 58.962082117795944, 59.16719891130924, 60.248867869377136, 41.68783664703369, 0.8796154533047229, 0.797910753171891, 0.022528280496771913, 0.12836842273827642, 8.716929852962494, 45.76716095209122, 49.94767762720585, 54.8521276563406, 44.0455037355423, 32.45629660785198, 2.213089596480131, 26.387853138148785, 21.65293861180544, 31.973141133785248, 34.79228965938091, 43.347412794828415, 25.79627238214016, 35.36902651190758, 46.66748084127903, 56.724815368652344, 21.31716202944517, 0.2301377383992076, 0.38445434533059597, 0.1501349758473225, 0.20492727868258953, 0.06464393474743702, 0.18773188028717414, 0.1459767817868851, 0.31344256829470396, 0.11611303387326188, 0.1475029342691414, 0.06041048691258766, 0.03501912498904858, 0.024597981937404256, 0.16110434895381331, 0.09755861465237103, 0.303655510651879, 0.37432771059684455, 0.15120130847208202, 7.448998689651489, 72.63884782791138, 60.96656575798988, 42.34591193497181, 42.6548657566309, 46.46340899169445, 51.36448100209236, 101.34094208478928, 21.535448916256428, 14.010926429182291, 29.50123507529497, 58.56412187218666, 67.75661900639534, 68.00556644797325, 55.382594391703606, 70.80179840326309, 27.57958699017763, 0.2966481226030737, 0.09234095283318311, 0.9518182289320976, 0.2296976002980955, 0.5264131247531623, 37.308928817510605, 51.95128731429577, 55.216870084404945, 57.116281762719154, 63.008446991443634, 64.04222711920738, 65.46605631709099, 57.03146271407604, 51.70401178300381, 54.89606849849224, 60.94713740050793, 66.51478484272957, 63.34057956933975, 48.85379992425442, 57.84208461642265, 79.3432004749775, 51.43687091767788, 51.064703688025475, 47.1856552362442, 50.75378157198429, 45.05985930562019, 42.349818125367165, 38.99269826710224, 36.39724753797054, 45.41121505200863, 62.693462893366814, 74.25498470664024, 79.38204199075699, 75.57023093104362, 60.99009029567242, 56.220175847411156, 52.63995476067066, 58.11093918979168, 59.71641384065151, 55.90553753077984, 51.505316644907, 57.075559347867966, 54.76938709616661, 55.673396587371826, 60.00561632215977, 55.82711733877659, 53.57818901538849, 50.07250092923641, 50.90587601065636, 58.96018221974373, 59.54299874603748, 60.5307899415493, 55.7801328599453, 53.309053257107735, 54.950884357094765, 54.80176895856857, 55.374892204999924, 53.26319731771946, 55.38426250219345, 45.56573376059532, 40.56508809328079, 37.05105945467949, 34.984350353479385, 33.312660455703735, 38.98898586630821, 44.96645271778107, 47.8121542185545, 49.70669835805893, 49.01106968522072, 54.44242604076862, 51.952552646398544, 51.14210173487663, 51.74836680293083, 41.572991609573364, 35.86919367313385, 33.0932754278183, 45.99705621600151, 54.1025722771883, 55.86636163294315, 51.817477494478226, 51.95767857134342, 51.38184607028961, 55.960303992033005, 54.78079408407211, 53.09202790260315, 53.2553431391716, 49.535886123776436, 54.86185133457184, 52.40912474691868, 55.44433727860451, 75.90522095561028, 51.044826954603195, 37.47909888625145, 43.98691847920418, 49.396247416734695, 52.47171878814697, 47.76334583759308, 47.299732714891434, 48.845573365688324, 48.600520715117455, 49.95696432888508, 46.44931174814701, 47.566740587353706, 48.29309441149235, 44.835466146469116, 43.37587706744671, 60.804736241698265, 62.76261158287525, 62.61463612318039, 50.91387078166008, 48.33066679537296, 51.23161733150482, 50.97293861210346, 52.28715889155865, 50.85190750658512, 61.81494243443012, 63.12674604356289, 61.58689767122269, 63.57810102403164, 48.24311949312687, 1.3061889354139566, 0.5136913480237126, 0.1043467277486343, 0.4087181808426976, 10.071211382746696, 54.42812740802765, 56.98305331170559, 65.48914387822151, 47.243085354566574, 34.3995351344347, 4.225255474448204, 28.88553511351347, 22.886255532503128, 35.09300172328949, 29.901194013655186, 52.50839442014694, 31.9497761875391, 34.752767980098724, 55.10222263634205, 65.51013395190239, 25.016305334866047, 0.20600107731297612, 0.6702720990870148, 0.09314069859101437, 0.28646716265939176, 0.07786470931023359, 0.19854642654536292, 0.08218363771447912, 0.6017374922521412, 0.2231861895415932, 0.18953509134007618, 0.12871984450612217, 0.24975605600047857, 0.10001104907132685, 0.3467591805383563, 0.23037080245558172, 0.6580431084148586, 0.5480486887972802, 0.849805815378204, 10.744103975594044, 85.46354725956917, 68.05687889456749, 60.18888808786869, 57.387917786836624, 62.97281250357628, 65.41434109210968, 120.742746591568, 24.149222262203693, 19.580748304724693, 34.455148950219154, 63.92756447196007, 75.18129900097847, 74.01159256696701, 60.19141495227814, 78.12335193157196, 31.46102551370859, 0.6265446392353624, 0.43842264160048217, 1.615484026260674, 1.4064851473085582, 1.3940589828416705, 46.703259721398354, 55.93673765659332, 59.24327462911606, 58.85107107460499, 65.54269060492516, 67.67306908965111, 65.32042533159256, 59.47558656334877, 55.77052317559719, 59.663429483771324, 67.35639408230782, 73.30624401569366, 65.33573850989342, 50.02875007688999, 69.03246894478798, 71.82493150234222, 47.78101108968258, 55.2495027333498, 50.421238616108894, 52.444451451301575, 44.694292321801186, 44.71778646111488, 39.83004793524742, 42.905181124806404, 52.05141194164753, 61.67783439159393, 64.16862353682518, 67.6310433447361, 68.16543146967888, 60.95001384615898, 59.355117827653885, 55.9921120852232, 61.59761309623718, 61.41171187162399, 59.75762642920017, 53.88192571699619, 60.099376291036606, 58.36532033979893, 59.08487632870674, 63.76076102256775, 62.057768404483795, 59.618994668126106, 60.306818559765816, 57.726380825042725, 62.54212461411953, 66.0778158903122, 61.02520801126957, 60.13175815343857, 55.23806154727936, 59.864811077713966, 59.76718671619892, 67.61550977826118, 60.22080257534981, 67.45737746357918, 56.408725529909134, 48.535187020897865, 43.25722463428974, 40.428865402936935, 35.76740473508835, 46.35964795947075, 49.229212179780006, 57.74518981575966, 57.563392370939255, 55.72789326310158, 58.782416358590126, 61.29999026656151, 58.71958673000336, 59.64621640741825, 48.56155000627041, 45.007585510611534, 39.27264824509621, 52.11611486971378, 58.077964559197426, 60.775975584983826, 55.67983344197273, 56.80713415145874, 55.68370923399925, 58.507751896977425, 60.156890004873276, 57.7229306101799, 59.54549141228199, 52.54636198282242, 58.53799447417259, 55.110528990626335, 56.051810681819916, 74.57952529191971, 67.5731572508812, 42.099696546792984, 46.33424252271652, 56.82383805513382, 59.49567228555679, 54.374314695596695, 55.322086438536644, 49.80178065598011, 46.44191354513168, 47.38744340837002, 48.2453727722168, 46.23911462724209, 55.11261127889156, 38.368049785494804, 41.02428965270519, 61.47935964167118, 63.89387547969818, 67.33385369181633, 51.941191256046295, 53.909265249967575, 57.83924236893654, 57.53870889544487, 55.36577269434929, 56.352480947971344, 65.29393315315247, 66.39462009072304, 65.43014824390411, 65.97917318344116, 56.36444270610809, 5.813146568834782, 0.8201432414352894, 0.13212639139965177, 0.4445353557821363, 12.93693020939827, 63.53895552456379, 59.61715556681156, 68.93811240792274, 49.555736258625984, 44.94749553501606, 7.062476305291057, 36.34324483573437, 27.56180964410305, 46.19123339653015, 43.507494404911995, 63.779220432043076, 36.78733840584755, 46.67117804288864, 64.25886869430542, 75.3265044093132, 36.96456849575043, 1.0585452988743782, 0.6940110283903778, 0.3113552037393674, 0.31726391636766493, 0.35702676395885646, 0.4659511550562456, 0.19203134957933798], [0.16057038854341954, 0.019955017014581244, 0.029568859245046042, 0.014430816663661972, 0.060646263518719934, 0.16910875303437933, 0.19792300765402615, 0.23874381644418463, 0.15140021889237687, 0.25178467214573175, 0.19178696034941822, 2.287246654741466, 55.06517842411995, 57.83902198076248, 33.18585366010666, 21.996206492185593, 42.7449931204319, 23.817880041897297, 19.236089698970318, 34.42127376794815, 9.901177156716585, 28.945564292371273, 67.44824275374413, 63.34872253239155, 60.18830671906471, 58.05621072649956, 58.62787485122681, 30.00313874334097, 0.8402178611140698, 0.02198066642449703, 0.25589685305021703, 0.4527017113287002, 0.15670368040446192, 29.72507156431675, 55.17202869057655, 51.314422488212585, 60.40306739509106, 58.35066832602024, 62.961276322603226, 61.015651524066925, 53.76375585794449, 46.97815977036953, 49.85782764852047, 53.118580877780914, 60.10377645492554, 61.550564020872116, 70.14628037810326, 36.172022223472595, 42.899865210056305, 64.45701286196709, 49.35744009912014, 52.25849322974682, 48.731902465224266, 50.28169870376587, 43.45011368393898, 54.885189682245255, 66.29926800727844, 77.79524713754654, 79.08956408500671, 72.99786776304245, 64.99380245804787, 58.5507769882679, 51.582593098282814, 52.66273833811283, 54.63347978889942, 52.05684185028076, 53.21536548435688, 52.33714900910854, 54.01861198246479, 54.35979187488556, 52.48655319213867, 61.447437554597855, 54.98698242008686, 44.15915563702583, 31.95969745516777, 30.01449253410101, 33.05170185863972, 41.20389461517334, 54.59615059196949, 55.77309563755989, 56.02767817676067, 55.769736617803574, 57.21468888223171, 54.22935247421265, 50.86662791669369, 44.31487888097763, 37.82305262982845, 30.04600804299116, 27.944827191531658, 19.529335163533688, 19.447489455342293, 9.726721867918968, 11.182867381721735, 39.58232022821903, 49.24289144575596, 52.59823679924011, 56.22834540903568, 54.740801230072975, 52.27169752120972, 45.36301463842392, 32.284443229436874, 17.465181425213814, 14.271307457238436, 10.991847831755877, 19.788682647049427, 38.092340379953384, 55.11454537510872, 54.86116737127304, 51.771993935108185, 52.191578820347786, 48.747698217630386, 48.944257870316505, 48.98856729269028, 49.01150286197662, 47.42152377963066, 48.42266745865345, 50.66399998962879, 52.92050510644913, 88.55267509818077, 78.45676884055138, 42.6434625685215, 40.82519173622131, 36.57863460481167, 43.45501162111759, 46.02222606539726, 46.0037362575531, 44.482571482658386, 50.27268558740616, 45.02025783061981, 53.79565894603729, 40.44732101261616, 73.46890568733215, 55.09595677256584, 32.6352746039629, 65.70168927311897, 56.41749545931816, 63.507215827703476, 50.82879714667797, 52.67690397799015, 48.182163164019585, 50.19976370036602, 47.54491835832596, 53.74726094305515, 54.168802723288536, 61.528525203466415, 55.47935999929905, 57.70445600152016, 30.665800385177135, 0.8965292363427579, 0.7928161765448749, 0.21230440470390022, 0.23766850383253768, 15.73670357465744, 53.45706671476364, 53.29621374607086, 51.98674701154232, 35.055558532476425, 39.44268152117729, 3.818484451621771, 26.21450264006853, 18.059045858681202, 37.167207822203636, 39.23894785344601, 43.86641554534435, 24.563698321580887, 50.20218797028065, 50.46941243112087, 63.16969133913517, 11.567466594278812, 0.12140583072323352, 0.31340649991761893, 0.036082993683521636, 0.1478303549811244, 0.08526922058081254, 0.09858956909738481, 0.19359826081199571, 0.0877562168170698, 0.019034592478419654, 0.09047025829204358, 0.11104296296252869, 0.24412600498180836, 0.08440434394287877, 0.10744759143562987, 0.08351508775376715, 0.17215883155586198, 0.17275778925977647, 0.055382796344929375, 2.958788895048201, 60.296243727207184, 67.18887627124786, 28.382580801844597, 23.47986537963152, 54.42353345453739, 26.786489747464657, 24.174390211701393, 37.73675546050072, 14.78465611115098, 24.310812391340733, 76.31888955831528, 71.77700087428093, 68.41289699077606, 61.16307981312275, 63.83662015199661, 33.816084042191505, 0.6246492534410208, 0.277138544479385, 0.721499347127974, 0.5329350591637194, 0.048857329311431386, 34.65503342449665, 59.82772886753082, 54.024866446852684, 63.78105193376541, 62.54446528851986, 64.90769907832146, 62.6088110357523, 57.168103381991386, 48.451177328825, 51.7345317453146, 56.26481965184212, 64.28907707333565, 63.61518323421478, 69.60708171129227, 41.184424459934235, 40.641091614961624, 63.09080757200718, 47.367494478821754, 52.63347610831261, 53.35430882871151, 54.84136663377285, 48.07480372488499, 59.148944690823555, 66.93840131163597, 74.81689095497131, 74.89910334348679, 67.71435767412186, 61.737810373306274, 55.567370876669884, 52.358082085847855, 56.217481791973114, 55.121187418699265, 52.8270111232996, 52.669163793325424, 52.30438716709614, 59.02171991765499, 58.51350858807564, 53.0610291659832, 57.79091656208038, 57.385850697755814, 53.08358855545521, 43.59747737646103, 46.526603400707245, 45.521720722317696, 52.01958104968071, 61.025375202298164, 57.815185859799385, 54.51695904135704, 55.01589886844158, 57.094877511262894, 54.44895789027214, 58.05865399539471, 54.38215747475624, 50.95584712922573, 44.02358651161194, 42.958940640091896, 33.753923177719116, 31.662682592868805, 28.980182334780693, 30.86959484964609, 46.94870375096798, 53.435461074113846, 52.56257951259613, 52.01012335717678, 57.557270899415016, 54.015047773718834, 51.202978268265724, 45.49808979034424, 35.189664736390114, 26.357692256569862, 23.443385437130928, 33.61742690205574, 49.764842838048935, 61.08509659767151, 55.812982097268105, 56.23782970011234, 53.15890051424503, 51.08869560062885, 49.0558160841465, 50.78663840889931, 48.95989403128624, 51.19877569377422, 51.11893817782402, 54.635318890213966, 48.98954004049301, 69.03806984424591, 76.7803367972374, 44.39510017633438, 41.557522639632225, 41.41871228814125, 46.81870512664318, 48.04739199578762, 49.85994793474674, 47.07535095512867, 50.53840532898903, 45.55863194167614, 51.063134372234344, 40.679252967238426, 65.12488782405853, 55.03159962594509, 38.65506358444691, 66.7051774263382, 57.29677587747574, 64.58864539861679, 52.34319068491459, 51.959156692028046, 47.702123522758484, 51.14805981516838, 50.13046681880951, 56.1445789039135, 58.74480597674847, 63.293203711509705, 57.84372612833977, 63.20210359990597, 34.51043978333473, 0.581393918255344, 0.42347115639131516, 0.12586199707584456, 0.0729555360157974, 21.933080479502678, 64.6405278146267, 58.30521896481514, 57.209277972579, 38.58514353632927, 43.4045085310936, 4.624928003177047, 33.585497215390205, 20.837827250361443, 38.13859149813652, 34.810445085167885, 56.1649876087904, 27.136855646967888, 49.35325652360916, 57.439439222216606, 70.75733318924904, 10.05703529343009, 0.15854275203309953, 0.3490421752212569, 0.048367808703915216, 0.06182601486216299, 0.01792488132196013, 0.04810066151549108, 0.17602249688934535, 0.2359982708003372, 0.14259805058827624, 0.12384141096845269, 0.19341420818818733, 0.30640439596027136, 0.19813244172837585, 0.440729622496292, 0.1862473919754848, 0.23331410076934844, 0.34595775010529906, 0.3451981768012047, 4.638716038316488, 79.51854586601257, 77.36984476447105, 49.52831692993641, 29.376848749816418, 71.93056583404541, 31.639956012368202, 22.15430460870266, 42.65449717640877, 18.654793091118336, 34.744655415415764, 82.59998291730881, 74.57380279898643, 75.52632048726082, 66.70958518981934, 69.40183952450752, 39.17916186153889, 2.0132074970752, 0.5600799713283777, 1.7324922163970768, 1.1879911716096103, 0.5884956184308976, 38.25557962059975, 58.39772880077362, 56.72519154846668, 65.59797763824463, 63.90037313103676, 69.49636325240135, 65.22672235965729, 60.30053749680519, 53.89441944658756, 57.71029628813267, 60.142070800065994, 62.55576208233833, 68.45284044742584, 69.95420828461647, 49.15616109967232, 52.82140262424946, 60.56568346917629, 51.71565055847168, 52.2779443860054, 55.150746032595634, 55.75590915977955, 52.61220484972, 57.47102692723274, 68.49998071789742, 65.3543347120285, 65.37095502018929, 67.26072281599045, 63.16698968410492, 59.846777245402336, 57.63020798563957, 57.40232281386852, 57.49797888100147, 53.77776950597763, 57.46088147163391, 56.128498166799545, 61.17863617837429, 61.418908685445786, 57.885185703635216, 62.19182901084423, 62.777654975652695, 63.166548907756805, 52.43003882467747, 56.00965194404125, 55.00053629279137, 59.73264656960964, 67.35786080360413, 62.29862987995148, 61.73776477575302, 59.77830491960049, 62.56592653691769, 61.25735655426979, 63.86375069618225, 58.855125457048416, 59.12170775234699, 53.7238883972168, 56.853332072496414, 40.03921911120415, 37.27186180651188, 34.62545581161976, 35.120181664824486, 58.507143929600716, 62.10608281195164, 60.354718789458275, 61.70372240245342, 61.250319331884384, 57.296525090932846, 56.35012127459049, 52.8682617098093, 44.570817947387695, 36.768058240413666, 29.314366802573204, 41.64592869579792, 53.784761130809784, 64.91102010011673, 61.45615428686142, 61.33626312017441, 57.67085440456867, 53.89171399176121, 56.52054212987423, 58.525310754776, 53.01588758826256, 55.301480144262314, 57.31590025126934, 56.307042986154556, 54.408056885004044, 65.41769251227379, 78.9439406991005, 49.61696617305279, 42.134187296032906, 44.48596470057964, 51.1564801633358, 49.99657340347767, 50.37859730422497, 47.52412587404251, 48.60715135931969, 45.58360040187836, 52.241990715265274, 46.46195366978645, 55.580115392804146, 51.225009486079216, 39.22215275466442, 66.9554015994072, 62.58813634514809, 66.84491872787476, 55.78414164483547, 55.84075480699539, 54.05744589865208, 55.25714412331581, 54.75316196680069, 58.594121262431145, 62.762091010808945, 65.09466424584389, 64.20856699347496, 65.81626832485199, 42.206527814269066, 2.232532915659249, 1.3428544742055237, 0.47563143249135464, 0.26912708999589086, 24.321311227977276, 72.56096720695496, 61.44292339682579, 65.13289779424667, 43.13995152711868, 49.51621077954769, 7.708989288657904, 35.10036192834377, 23.973477892577648, 51.56058847904205, 49.11469392478466, 66.6283455491066, 33.4957954287529, 66.87229245901108, 64.54489454627037, 85.05304768681526, 20.58040626347065, 0.5110894376412034, 0.4609681380679831, 0.18796984251821414, 0.18345564021728933, 0.23238913243403658, 0.16124693036545068, 0.2169653444434516], [0.037363951705629006, 0.06953067291760817, 0.1247051966493018, 0.20283483783714473, 0.15793739701621234, 0.3140894538955763, 0.061669028364121914, 0.11718892536009662, 0.08116419397993013, 0.05090732673124876, 0.12276764202397317, 0.6537301023490727, 43.46121288836002, 56.69592171907425, 41.12054988741875, 30.954235307872295, 30.970382541418076, 44.218299463391304, 30.52852515131235, 44.26215671002865, 18.604668080806732, 2.851628470234573, 43.343863785266876, 59.135155230760574, 67.51044541597366, 52.655590921640396, 60.833189114928246, 25.656510181725025, 0.47519656363874674, 0.05286524217808619, 0.20127407158724964, 0.22753624361939728, 0.11407056925236247, 27.367011196911335, 65.43957933783531, 59.67673256993294, 62.41231217980385, 57.249069437384605, 61.03344976902008, 54.26537074148655, 51.149777323007584, 50.60151994228363, 50.82985728979111, 53.77548962831497, 59.45197083055973, 61.39744743704796, 65.77608168125153, 52.00623996555805, 31.571723073720932, 44.662393033504486, 50.63664145767689, 50.80777287483215, 52.08788998425007, 58.05171936750412, 63.70603255927563, 64.76776018738747, 60.96719652414322, 58.971490412950516, 58.92211966216564, 54.37245659530163, 52.92870506644249, 54.37976360321045, 55.8550838381052, 51.48961588740349, 48.16374555230141, 51.49579055607319, 51.98908768594265, 54.261430352926254, 51.605825051665306, 57.00357601046562, 53.988456800580025, 60.59658721089363, 44.964864403009415, 34.54363100230694, 29.63324949145317, 29.604998007416725, 30.694570541381836, 42.60407768189907, 54.122411012649536, 62.508154436945915, 54.70905393362045, 52.850144281983376, 50.36274075508118, 46.03039562702179, 42.16782309114933, 32.939098700881004, 25.102268122136593, 22.47643042355776, 16.823887936770916, 10.568213313817978, 12.803917396813631, 9.397695623338223, 4.646452898159623, 22.930126078426838, 41.4503113925457, 45.639518201351166, 47.24220000207424, 51.18198059499264, 50.27646638453007, 45.88828705251217, 31.20056089013815, 20.235217586159706, 12.922245897352695, 10.119360499083996, 14.64527864009142, 28.5419974476099, 46.16831302642822, 51.14349626004696, 53.09510573744774, 50.40645360946655, 47.38080516457558, 48.46145197749138, 48.142907470464706, 45.271469950675964, 50.78245863318443, 50.32312788069248, 54.02684614062309, 49.58461090922356, 61.43479183316231, 77.88546949625015, 48.52305427193642, 38.359568640589714, 41.239829286932945, 41.715468764305115, 44.06687378883362, 44.42893736064434, 44.24095764756203, 40.94164788722992, 46.9747019559145, 41.389184072613716, 68.26024398207664, 104.17704150080681, 41.33726745843887, 47.086108177900314, 59.048649072647095, 57.01748326420784, 61.97754330933094, 47.49522462487221, 50.88814236223698, 46.7780739068985, 50.453840866684914, 44.71585996448994, 55.4778590798378, 54.28304359316826, 62.13296636939049, 52.40475118160248, 55.52315644919872, 22.66584075987339, 0.8385843643918633, 0.09378716858918779, 0.07646410595043562, 0.2038877079030499, 31.328805908560753, 58.02529938519001, 52.05809958279133, 46.79432563483715, 70.60262069106102, 24.56722643226385, 2.127134408801794, 38.581727519631386, 18.397341705858707, 42.60849304497242, 50.35722725093365, 42.03452244400978, 36.46421894431114, 53.881302550435066, 46.6895804554224, 55.70167846977711, 1.9720340939238667, 0.04347145229985472, 0.25644972338341177, 0.05715766477806028, 0.017963632562896237, 0.015919566758384462, 0.014464090854744427, 0.05544372666918207, 0.09050887223565951, 0.08470952248899266, 0.1015896639728453, 0.05544024228584021, 0.009407064117112895, 0.03534071242029313, 0.03186584712238982, 0.07622202479979023, 0.02685461182409199, 0.0701603406923823, 0.06421817946829833, 0.5732348060701042, 46.729577109217644, 67.53882229328156, 44.36348207294941, 32.08534151315689, 49.277910366654396, 39.8621030151844, 36.26219138503075, 45.818104818463326, 27.309546880424023, 3.492034231312573, 41.37290574610233, 69.32933941483498, 75.58248907327652, 58.36419180035591, 65.23343279957771, 29.765643887221813, 0.6510493461973965, 0.02579399002570426, 0.4746617720229551, 0.18181285180617124, 0.1498434750828892, 32.395682260394096, 68.80509674549103, 63.79068061709404, 67.05062448978424, 62.390220165252686, 64.44730818271637, 57.60302044451237, 51.63582444190979, 52.43565872311592, 51.84107802808285, 58.36813598871231, 59.9856635928154, 62.514739483594894, 63.68326798081398, 57.1692319214344, 40.48884518444538, 46.422226801514626, 50.55048868060112, 51.334599405527115, 51.77832819521427, 56.50872476398945, 60.379835441708565, 61.48176871240139, 53.87983962893486, 54.19644244015217, 57.7067206799984, 58.464704006910324, 59.89565022289753, 58.216478526592255, 57.24647797644138, 55.07294900715351, 52.69863121211529, 51.46062724292278, 55.622346326708794, 57.35903173685074, 52.55836173892021, 58.36948111653328, 54.110620245337486, 62.2429096698761, 56.107796877622604, 47.620652094483376, 38.366051092743874, 41.403323113918304, 45.58662123978138, 52.20061853528023, 55.77623426914215, 58.8403594493866, 52.96722359955311, 55.01035116612911, 55.0750844925642, 55.87496817111969, 53.53544890880585, 51.30672410130501, 42.18611530959606, 41.294968128204346, 33.746711164712906, 29.2258258536458, 27.95963689684868, 28.584705255925655, 19.220385141670704, 38.472943156957626, 55.6988400220871, 54.467690885066986, 56.739497780799866, 56.614685878157616, 55.88525041937828, 52.83556446433067, 42.26107768714428, 28.69149472564459, 26.464662216603756, 17.287711948156357, 23.5525668784976, 37.86074660718441, 53.57302509248257, 56.68263763189316, 55.809535682201385, 53.87984722852707, 49.90461453795433, 47.319370061159134, 50.117505714297295, 48.688767179846764, 52.22806066274643, 52.43125095963478, 54.04533214867115, 51.65847882628441, 49.14607644081116, 63.71623121201992, 49.63770166039467, 39.90011237561703, 40.11554181575775, 43.774190694093704, 44.51656065881252, 43.5605775564909, 44.44181486964226, 43.984900787472725, 47.05121845006943, 42.84715823829174, 57.51391902565956, 97.22198590636253, 48.9736644923687, 48.10172528028488, 59.67954821884632, 58.07596206665039, 64.17309209704399, 50.18508888781071, 49.833805337548256, 48.55413280427456, 55.191897824406624, 47.658304274082184, 57.86891497671604, 56.160663440823555, 66.51623636484146, 54.239908307790756, 62.887693271040916, 26.498102322220802, 0.5076330481097102, 0.10348321666242555, 0.0418279625591822, 0.609358933288604, 41.7923728376627, 62.76440508663654, 56.503336653113365, 50.50641104578972, 77.25400418043137, 22.92117565870285, 4.33042480610311, 44.336484521627426, 23.289047218859196, 38.143964409828186, 36.99757732450962, 54.45255629718304, 35.37214994430542, 54.152235612273216, 55.03168322145939, 61.38695240020752, 2.276280918158591, 0.11643649893812835, 0.09354546593385749, 0.011983976182818878, 0.1783223234815523, 0.022414167870010715, 0.12228051855345257, 0.055993650676100515, 0.32778688764665276, 0.18896337045589462, 0.1605974620906636, 0.2406500227516517, 0.3012424026383087, 0.23087455745553598, 0.15059690340422094, 0.15088375832419842, 0.15917445329250768, 0.19145674916217104, 0.2748366695595905, 0.990114533342421, 65.18475741147995, 77.22104474902153, 59.49520491063595, 41.25795431435108, 55.97222775220871, 62.472455352544785, 37.76263207197189, 54.299333319067955, 30.40481138974428, 7.206386458128691, 53.19386623799801, 68.32136750221252, 78.43102142214775, 63.93336296081543, 71.95231586694717, 34.51914891600609, 0.9757111093495041, 0.24787009548163041, 1.0667109419591725, 0.6212021259125322, 0.4694166878471151, 36.82719826698303, 70.76231092214584, 65.56023806333542, 70.17748430371284, 63.85293647646904, 66.5540823340416, 62.22321532666683, 55.81453621387482, 55.93650586903095, 55.948615819215775, 61.39864057302475, 61.803307458758354, 64.77279871702194, 68.95842611789703, 58.4623709321022, 40.59320278465748, 47.84752272069454, 50.868486016988754, 52.13798649609089, 55.27724124491215, 56.833960711956024, 59.045578837394714, 59.14277382194996, 50.73719926178455, 51.50670737028122, 59.13547821342945, 61.99770122766495, 61.928643733263016, 58.26797716319561, 59.118124544620514, 56.44507817924023, 53.2672630995512, 58.820908293128014, 59.594390988349915, 61.94587200880051, 59.6490890532732, 64.01563614606857, 58.22147525846958, 66.21574848890305, 61.07632286846638, 55.519839227199554, 49.29126285016537, 55.491352155804634, 58.696681559085846, 59.606481939554214, 64.85429674386978, 66.83387652039528, 60.19325025379658, 59.89189602434635, 57.6970311999321, 59.691908955574036, 61.396828070282936, 60.77849484980106, 46.902847811579704, 49.99628461897373, 43.91907311975956, 39.34181593358517, 34.04749162495136, 42.34786123037338, 27.994935102760792, 48.38208183646202, 64.05239537358284, 60.100919008255005, 61.12348973751068, 61.681455597281456, 59.41915579140186, 61.44802272319794, 52.8880700469017, 42.127480655908585, 37.270915657281876, 27.99778874963522, 32.819055542349815, 48.0508916079998, 60.33333733677864, 60.06229028105736, 57.46300555765629, 52.70431950688362, 51.9598900526762, 53.69488835334778, 57.10525095462799, 51.690100729465485, 55.91659873723984, 55.64263343811035, 57.97321557998657, 55.599984526634216, 53.431729674339294, 64.33252394199371, 52.440575659275055, 39.922337383031845, 40.65209202468395, 44.399690330028534, 44.31019373238087, 47.34278440475464, 46.04774169623852, 45.91784946620464, 47.348484098911285, 47.985740303993225, 44.34197522699833, 91.12136766314507, 64.0246644616127, 47.26135477423668, 64.01079520583153, 59.99184586107731, 69.21678185462952, 52.639460787177086, 57.474853321909904, 51.367555037140846, 60.177169516682625, 49.389711767435074, 62.381077855825424, 60.229272320866585, 70.35153016448021, 58.152482360601425, 67.0597591996193, 32.37230971455574, 0.9250952128786594, 0.9335096238646656, 0.2297321250080131, 0.7573751814197749, 42.78557874262333, 66.5356457233429, 61.42781540751457, 57.63916790485382, 77.78966903686523, 36.02040655910969, 6.1819704528898, 50.33443987369537, 26.592947132885456, 52.070547714829445, 63.98839920759201, 65.16144186258316, 46.54241055250168, 75.75907319784164, 61.45508274435997, 80.09606927633286, 7.114227628335357, 0.15864412940572947, 0.32125776924658567, 0.2003300448996015, 0.2390075015136972, 0.10016105938120745, 0.18764077423838899, 0.12422689731465653], [0.06459625175921246, 0.06384029271430336, 0.026859645440708846, 0.11181746085640043, 0.2465693629346788, 0.07449208598700352, 0.06043497036444023, 0.17522565292892978, 0.16649560653604567, 0.017042805411620066, 0.21336750156478956, 0.5215788341592997, 28.179238513112068, 62.026374489068985, 50.03660045564175, 30.885428600013256, 28.42206258326769, 46.22414343059063, 30.88570598512888, 34.473638758063316, 69.22123521566391, 9.079513996839523, 24.60807044059038, 56.92558899521828, 59.97948132455349, 62.849018946290016, 55.21839760243893, 32.34930954873562, 0.8539563207887113, 0.10946278212941252, 0.1782661725883372, 0.4084183234954253, 0.12919008411699906, 28.687136359512806, 74.45653349161148, 61.699101850390434, 61.39254949986935, 57.07575313746929, 58.725313022732735, 51.23506374657154, 50.61759687960148, 54.73296605050564, 57.35326364636421, 51.63146607577801, 52.17848852276802, 56.44088700413704, 61.685270592570305, 61.46802864968777, 59.96741697192192, 61.92798636853695, 50.02954423427582, 47.54963010549545, 47.042520716786385, 50.94016537070274, 46.1321047693491, 42.142641842365265, 45.84446780383587, 51.93846680223942, 60.12917049229145, 61.41765475273132, 57.5600865483284, 54.65039648115635, 48.68793502449989, 50.08863866329193, 51.42031520605087, 53.78951087594032, 52.655761912465096, 51.6761364787817, 57.70086519420147, 60.78014776110649, 60.553706511855125, 49.752459302544594, 43.869204595685005, 33.61314453184605, 28.72075505554676, 29.290072806179523, 35.946006551384926, 44.01646949350834, 50.64759626984596, 55.878334790468216, 51.022917330265045, 52.0320063829422, 44.60150510072708, 34.76207748055458, 31.24425284564495, 27.30172500014305, 20.19814297556877, 17.37464178353548, 13.302054516971111, 8.824105001986027, 8.706573508679867, 21.035032868385315, 17.335063107311726, 11.744798328727484, 30.44130653142929, 37.013213485479355, 43.41513656079769, 49.437228217720985, 50.218709483742714, 42.36956186592579, 32.85789705812931, 25.82619957625866, 18.07129070162773, 13.48877364769578, 14.720327463001013, 22.159721218049526, 38.322824612259865, 52.31008306145668, 53.31381060183048, 51.13373838365078, 49.805386662483215, 50.53938947618008, 48.36164653301239, 43.95027704536915, 50.3131990134716, 51.21523641049862, 47.97230802476406, 49.0901168435812, 50.92459000647068, 56.24745838344097, 46.79966814815998, 37.94449031352997, 44.356444850564, 47.648983374238014, 44.522967115044594, 42.433805018663406, 44.940055534243584, 40.710354298353195, 43.53349260985851, 66.72003462910652, 87.87910804152489, 34.384370148181915, 36.24846272170544, 53.52822549641132, 57.98385500907898, 57.76977449655533, 55.380561500787735, 48.38291399180889, 49.23884466290474, 51.6445791721344, 53.910241797566414, 47.56874307990074, 54.71307411789894, 54.69746835529804, 57.24504545331001, 48.17262567579746, 63.10552418231964, 15.150550827383995, 0.40900352178141475, 0.13440468086628243, 0.17257538420381024, 4.626686358824372, 50.69257825613022, 55.64117431640625, 50.28037257492542, 59.364218339324, 59.27196308970451, 7.680358774960041, 13.019193895161152, 42.411397621035576, 12.177423164248466, 39.07315514981747, 41.54691360890865, 40.30433848500252, 28.61551210284233, 41.87822163105011, 53.37321661412716, 44.15880985558033, 0.29591897735372186, 0.1202425810333807, 0.043687513752956875, 0.12014976804493926, 0.04514112872129772, 0.027567537435970735, 0.060078995520598255, 0.030078223026066553, 0.09268619993235916, 0.02635786269820528, 0.034001818639808334, 0.10242435746476986, 0.061427808104781434, 0.08354743797099218, 0.0737616716651246, 0.1750711229396984, 0.10748085449449718, 0.04478131697396748, 0.4858683800557628, 0.3075389319565147, 31.93535216152668, 70.05021393299103, 58.73322419822216, 23.1558358669281, 36.00401423871517, 49.54068146646023, 28.821742236614227, 39.00105781853199, 68.25696855783463, 16.941470727324486, 25.019873343408108, 60.06092615425587, 67.71056547760963, 73.21149989962578, 61.118189021945, 35.867852345108986, 1.0245137312449515, 0.1875753910280764, 0.3246380144264549, 0.16619439848000184, 0.06997119693551213, 30.673107393085957, 75.77266126871109, 64.13260906934738, 65.15824243426323, 61.10346861183643, 61.57958686351776, 52.71386839449406, 54.5029453933239, 56.27913348376751, 59.893039762973785, 52.06132560968399, 57.71800987422466, 59.421507865190506, 63.40435154736042, 61.587281450629234, 67.72765696048737, 65.99313363432884, 48.89153949916363, 48.41115787625313, 48.77096816897392, 50.82490615546703, 43.8306138664484, 43.24849270284176, 47.75943964719772, 55.691711604595184, 62.55908690392971, 63.32599215209484, 61.12652577459812, 58.11325706541538, 52.87224769592285, 51.649849489331245, 55.746808648109436, 52.57230319082737, 53.937581330537796, 52.6716298609972, 59.36546087265015, 60.54885037243366, 58.30863878130913, 56.77702836692333, 50.495646223425865, 43.49413812160492, 40.240889489650726, 39.41067963838577, 45.47868423163891, 49.02994327247143, 56.270348355174065, 57.560793310403824, 51.98476351797581, 55.16045831143856, 52.048372104763985, 49.96245123445988, 47.71609917283058, 42.85090483725071, 35.23245804011822, 33.63374322652817, 27.946316711604595, 22.90977817028761, 20.26061162352562, 28.156707622110844, 17.686027474701405, 30.64448732882738, 49.09090340137482, 50.930871069431305, 51.22845970094204, 52.68415778875351, 53.26865762472153, 50.33265396952629, 41.46434023976326, 33.47113095223904, 26.062955372035503, 18.006046302616596, 22.51191481947899, 30.907902494072914, 48.88625018298626, 55.837961956858635, 57.24554322659969, 54.6036209911108, 52.75240212678909, 49.89184722304344, 49.083577394485474, 47.287204787135124, 51.66770853102207, 53.5633660107851, 50.441803112626076, 51.03087030351162, 49.306275844573975, 48.71365204453468, 44.100897163152695, 40.59637941420078, 44.25936385989189, 45.05138576030731, 43.11354674398899, 44.03184726834297, 46.811960488557816, 42.02174372971058, 46.34025759994984, 57.95531094074249, 76.86297476291656, 38.550006821751595, 40.02738654613495, 53.727950379252434, 60.04015266895294, 59.199151396751404, 55.86008816957474, 50.704787001013756, 52.73674316704273, 54.76977467536926, 56.28273569047451, 51.85889147222042, 59.540677070617676, 56.64041429758072, 62.532628923654556, 53.62379036843777, 68.27146857976913, 18.79480417817831, 0.7804825727362186, 0.2048426293185912, 0.2751344785792753, 6.189094120636582, 61.703931391239166, 60.51932595670223, 58.060059919953346, 62.46845416724682, 62.23351277410984, 11.520276926457882, 13.808929268270731, 45.13488627970219, 17.440505549311638, 33.636235892772675, 35.58639384806156, 51.78166061639786, 25.476390346884727, 46.74805551767349, 61.52647711336613, 50.26726707816124, 1.3744820770807564, 0.1267613167874515, 0.02669733774382621, 0.07135266030672938, 0.020218535100866575, 0.046071726246736944, 0.008192214754672023, 0.06942810068721883, 0.14177978824591264, 0.1831740842317231, 0.1837072876514867, 0.1701453552232124, 0.2580410661175847, 0.09875673044007272, 0.2256158771342598, 0.278240900952369, 0.3933516569668427, 0.18040934664895758, 0.9523066808469594, 0.6587137724272907, 46.86424948275089, 83.31682205200195, 72.76654377579689, 40.86350508034229, 46.51153340935707, 71.4380894601345, 32.7887711673975, 46.90573185682297, 73.36859866976738, 17.013322971761227, 31.34671814739704, 68.55830758810043, 71.51061236858368, 77.05030471086502, 66.37870654463768, 43.32117900252342, 1.5903996722772717, 0.4545685986522585, 0.5446109420154244, 0.9942678886000067, 0.1968326442874968, 37.70011782646179, 77.27250918745995, 69.75058481097221, 67.7155964076519, 66.47770643234253, 65.42140111327171, 57.96308532357216, 57.36425265669823, 62.048052325844765, 62.79940500855446, 56.84906870126724, 56.2395966053009, 62.70375654101372, 67.16377481818199, 64.78075549006462, 68.96403461694717, 59.05866913497448, 51.722095012664795, 47.23283730447292, 49.65152531862259, 52.78568834066391, 45.34335069358349, 43.836378157138824, 47.34680838882923, 60.01795046031475, 66.64170563220978, 66.88468739390373, 62.420911118388176, 59.57804426550865, 54.44022595882416, 55.09895861148834, 57.61122800409794, 56.06732524931431, 59.69002045691013, 56.631887555122375, 64.96638312935829, 65.62540456652641, 63.78326341509819, 61.002299040555954, 58.983691558241844, 52.53967434167862, 54.30124841630459, 54.63968105614185, 59.43472735583782, 57.730625197291374, 62.159469947218895, 64.95934590697289, 58.58557552099228, 61.32080554962158, 58.77105876803398, 58.00366714596748, 56.87205746769905, 55.67184627056122, 43.00556033849716, 46.17302097380161, 41.361004784703255, 36.046644151210785, 30.070862509310246, 41.21676452457905, 28.99181541055441, 38.15617695450783, 59.54842485487461, 61.17614731192589, 59.915146976709366, 62.37228512763977, 61.19048394262791, 56.86550661921501, 51.999415531754494, 48.124581053853035, 42.704548090696335, 34.88263741135597, 36.11408673226833, 41.25654079020023, 54.12945203483105, 63.974073976278305, 61.93129979074001, 58.18171039223671, 55.400164648890495, 54.83593292534351, 53.983585461974144, 49.848742336034775, 55.14798358082771, 57.9340510815382, 53.69824357330799, 55.997074618935585, 53.88061858713627, 51.35058134794235, 45.279206335544586, 40.873650535941124, 44.873357713222504, 46.12016201019287, 45.6973434984684, 44.14907097816467, 46.922690346837044, 42.216278091073036, 44.435560405254364, 51.15773789584637, 80.50135552883148, 71.38375237584114, 45.33066317439079, 54.20844979584217, 61.770473420619965, 63.562369868159294, 60.0448302179575, 54.5561995357275, 53.64987216889858, 55.26069313287735, 57.863815650343895, 54.0730744600296, 61.4437023550272, 60.414367988705635, 66.33355736732483, 55.217272862792015, 73.14095288515091, 24.791085720062256, 0.40170188702177256, 0.8146784221753478, 0.6119633966591209, 6.183279482647777, 64.69204545021057, 62.84504055976868, 62.516077011823654, 65.83673402667046, 71.43105983734131, 16.39599859714508, 19.226852394640446, 52.87804998457432, 16.437007896602154, 48.445044457912445, 58.536881133913994, 61.470471918582916, 36.935667246580124, 60.16404502093792, 70.62231883406639, 68.89482513070107, 2.6984539395198226, 0.2527684037340805, 0.12768952088663355, 0.20332434360170737, 0.16810035245725885, 0.114352147502359, 0.20546052663121372, 0.13933792943134904], [0.08151318892487325, 0.060639825387625024, 0.040899068262660876, 0.10430964262923226, 0.0497338168497663, 0.13686006161151454, 0.058995237268391065, 0.07701859416556545, 0.05201295607548673, 0.07057416223688051, 0.39124377944972366, 0.3353177272947505, 12.644755337387323, 63.07385668158531, 46.56959429383278, 39.38536919653416, 40.488643795251846, 39.16964337229729, 41.44346036016941, 28.895872458815575, 99.266367405653, 52.482962384819984, 16.40645183622837, 59.71346899867058, 53.354373425245285, 60.49582041800022, 53.35547536611557, 42.43620648980141, 2.314625373110175, 0.44682078470941633, 0.13772037404123694, 0.10365034831920639, 0.005949733449597261, 28.687968514859676, 71.0242460668087, 62.702339217066765, 59.08600866794586, 57.78464689850807, 53.28281946480274, 45.91339610517025, 56.34466856718063, 62.52221368253231, 63.695465326309204, 58.38303878903389, 51.63443371653557, 51.624064072966576, 58.35714317858219, 59.98020328581333, 49.40595589578152, 53.48037466406822, 64.47626262903214, 51.040460988879204, 47.18912445008755, 42.10167624056339, 48.328113332390785, 53.312199488282204, 57.37738095223904, 57.045879140496254, 54.06978763639927, 55.356140211224556, 55.4766583442688, 54.32262606918812, 53.98800082504749, 50.49248479306698, 49.55528788268566, 51.87517359852791, 51.85639500617981, 51.951788887381554, 59.986286759376526, 61.38198606669903, 59.380242079496384, 50.89166857302189, 43.92283871769905, 35.11240728199482, 33.64386588335037, 33.12360160052776, 35.88981136679649, 40.720267966389656, 47.74905860424042, 49.31340046226978, 46.906279027462006, 43.587810695171356, 33.6311973631382, 28.380754999816418, 23.93492516130209, 21.414679996669292, 15.559293944388628, 12.463476564735174, 9.263686314225197, 9.37555231153965, 3.8708202308043838, 16.09281476587057, 23.162126429378986, 12.291032318025827, 23.97586416453123, 27.444555535912514, 30.80192808061838, 42.72896558046341, 48.28575700521469, 45.559699684381485, 38.485649675130844, 36.008038222789764, 22.883703969419003, 18.459114991128445, 19.420144222676754, 21.396089494228363, 32.83547066152096, 43.53032737970352, 51.412719413638115, 52.23461911082268, 49.70127984881401, 49.89098086953163, 48.32808293402195, 42.9543124884367, 44.89695064723492, 48.38382214307785, 48.340333476662636, 47.89447300136089, 55.16440249979496, 44.93952736258507, 35.23699879646301, 40.6668808311224, 44.03424493968487, 42.655017748475075, 45.59042863547802, 41.016986444592476, 41.43950097262859, 41.41450971364975, 54.28749695420265, 54.05785247683525, 16.776586174964905, 26.709904856979847, 50.36085985600948, 54.86763082444668, 61.16242244839668, 56.83440528810024, 55.34751087427139, 47.429784536361694, 54.54780958592892, 54.93858061730862, 59.26613800227642, 49.75432500243187, 56.43597386777401, 50.19096337258816, 58.1801600754261, 49.762578159570694, 62.11020939052105, 4.679150618612766, 0.7840008870698512, 0.1224564595031552, 0.24899688345612958, 17.484699077904224, 47.001676708459854, 38.73117730021477, 51.7670352011919, 55.62529496848583, 54.094626903533936, 9.772993884980679, 15.130238067358732, 30.794695168733597, 16.518663614988327, 35.23487091064453, 31.57547727227211, 41.01243808865547, 27.967259287834167, 48.1097162514925, 51.38438433408737, 31.25449139624834, 0.24876766372472048, 0.275133439572528, 0.08524564254912548, 0.01622453008167213, 0.05367837628000416, 0.04908798880933318, 0.07033369896817021, 0.08424061132245697, 0.029867946614103857, 0.09718405271996744, 0.012369564574328251, 0.14037788612768054, 0.08448913431493565, 0.2347126483800821, 0.08230505307437852, 0.06292333215242252, 0.03975892534072045, 0.09759090549778193, 0.4692635976243764, 0.3674892947310582, 17.18368873000145, 73.74002113938332, 53.85902814567089, 34.32643845677376, 47.99564257264137, 41.95489011704922, 34.37913402915001, 42.382420375943184, 95.69191440939903, 56.06653109192848, 18.371058516204357, 61.2497341632843, 58.67819555103779, 66.50995150208473, 57.95860156416893, 48.38331297039986, 2.5276941899210215, 0.5021735723130405, 0.5844198621343821, 0.8083929063286632, 0.04196550478809513, 32.67124347388744, 72.94893398880959, 65.57260259985924, 64.23556074500084, 62.166579365730286, 56.54627434909344, 50.6591210514307, 58.672807440161705, 64.61569994688034, 63.97228807210922, 63.030580803751945, 52.32112526893616, 54.38805475831032, 60.99205479025841, 63.287895396351814, 53.057012781500816, 62.22887322306633, 65.00941202044487, 52.97721326351166, 48.67270164191723, 44.35767598450184, 50.11337533593178, 54.99365486204624, 59.19932998716831, 57.20744267106056, 54.20699827373028, 58.0703953653574, 60.21120049059391, 57.569198459386826, 56.852997690439224, 54.826380237936974, 54.79554869234562, 55.357853919267654, 53.377483785152435, 53.00313927233219, 59.70366172492504, 61.83491036295891, 62.377692237496376, 57.3964711278677, 50.248062908649445, 43.55653837323189, 41.296108067035675, 41.84036046266556, 46.049755588173866, 51.88934683799744, 57.39545278251171, 55.66279135644436, 52.88757607340813, 52.802696228027344, 48.251433447003365, 45.531949773430824, 40.751471891999245, 36.097367629408836, 28.847421258687973, 28.82931523025036, 22.448610216379166, 21.191497072577477, 15.948071032762527, 24.48944840580225, 17.35834825783968, 22.872825153172016, 39.82287012040615, 45.64741797745228, 47.73606330156326, 48.88515204191208, 51.680069267749786, 50.381982922554016, 47.457561045885086, 40.59521667659283, 32.20971643924713, 22.048827968537807, 23.873797841370106, 28.53381458669901, 42.8936031460762, 52.41709291934967, 54.47569325566292, 56.2349646538496, 53.32179017364979, 50.372411236166954, 50.10197974741459, 46.672021597623825, 49.470997005701065, 51.434062868356705, 51.70484393835068, 48.47537823021412, 54.29877854883671, 45.37518158555031, 35.6200410425663, 39.532371908426285, 44.286669194698334, 43.632340505719185, 44.71131160855293, 39.827631264925, 43.136558309197426, 42.17962145805359, 54.461284428834915, 47.09790654480457, 22.726048529148102, 31.646546758711338, 53.54740686714649, 56.28443039953709, 62.469008937478065, 55.22717893123627, 57.44276404380798, 50.766381695866585, 58.47875565290451, 55.35826809704304, 61.03013634681702, 54.979774206876755, 60.77110804617405, 52.620628997683525, 62.47943937778473, 53.65567825734615, 67.42403045296669, 5.073559479787946, 1.128522225189954, 0.2547480084467679, 0.16119590029120445, 20.263590663671494, 58.40265713632107, 42.65619948506355, 54.65767689049244, 56.544146463274956, 62.55827374756336, 11.39588300138712, 18.760695308446884, 34.63654361665249, 21.804354786872864, 30.510004945099354, 32.6928149163723, 50.127255991101265, 28.96720413118601, 52.77508690953255, 62.95000992715359, 34.011879935860634, 0.5991420533973724, 0.24351851257961243, 0.22118377120932564, 0.05615270034468267, 0.07570420610136352, 0.03816231335804332, 0.07911798151326366, 0.16860438947333023, 0.16189050598768517, 0.2702643274096772, 0.15622088365489617, 0.2859397034626454, 0.1511848031077534, 0.4144922085106373, 0.18006562837399542, 0.18309148319531232, 0.3848195413593203, 0.18700172571698204, 0.6210924661718309, 0.5982709501404315, 25.159922428429127, 87.85128593444824, 64.54338982701302, 51.488403752446175, 57.157855331897736, 63.54783184826374, 46.9848246127367, 43.53096194565296, 96.99354976415634, 60.6496399641037, 22.984045185148716, 71.50003373622894, 64.72987622022629, 72.82801687717438, 64.95877593755722, 56.344208791852, 3.248177566565573, 0.6334413879085332, 0.40886497765313834, 1.1913370108231902, 0.11493387995869853, 40.23600295186043, 75.68372324109077, 71.31600201129913, 66.11894488334656, 66.1611758172512, 60.003686025738716, 55.178237557411194, 61.96631111204624, 69.53538715839386, 70.4217503964901, 67.4742865562439, 56.06238931417465, 56.85725346207619, 63.33731174468994, 64.79175969958305, 57.40297257900238, 68.96143555641174, 62.93782778084278, 53.91566410660744, 47.9696823656559, 46.8200958520174, 48.50703053176403, 56.16523079574108, 61.17755323648453, 62.868793085217476, 56.933321580290794, 61.47657819092274, 59.353187531232834, 59.68655124306679, 58.571406081318855, 55.85992477834225, 56.94846376776695, 60.04498600959778, 58.91647316515446, 53.477616012096405, 64.59661737084389, 66.5112130343914, 65.29742136597633, 65.02422362565994, 58.41464549303055, 54.18499365448952, 53.429886773228645, 56.0191248357296, 54.42835159599781, 56.01054109632969, 59.0019191801548, 60.09896591305733, 55.6636007130146, 58.51473592221737, 53.956918492913246, 55.44460326433182, 50.04329949617386, 45.50508141517639, 38.07896129786968, 42.476697117090225, 36.818599328398705, 37.16476075351238, 28.213911652565002, 31.48621816188097, 30.644506327807903, 32.31231853365898, 52.91709288954735, 57.56199784576893, 53.90256240963936, 58.28749671578407, 62.28479102253914, 60.94163529574871, 54.815490022301674, 51.35685861110687, 45.52959389984608, 41.872723326087, 38.38021673262119, 42.32751712203026, 52.5555194914341, 60.70436842739582, 59.71349559724331, 58.33769202232361, 53.840511739254, 51.73638604581356, 55.29381215572357, 49.25332188606262, 50.12235805392265, 56.18616007268429, 53.98566015064716, 53.20786088705063, 58.13452072441578, 49.71101872622967, 39.63646352291107, 40.41639067232609, 45.37298150360584, 43.39013010263443, 45.09109742939472, 38.94085764884949, 42.85933658480644, 41.10427536070347, 52.5747312605381, 59.709384217858315, 43.3599217236042, 34.23701785504818, 53.39603818953037, 59.0944480150938, 66.72299087047577, 60.53797535598278, 61.86267167329788, 51.21387608349323, 59.42420952022076, 58.390288800001144, 65.80844074487686, 56.298569440841675, 63.633973225951195, 54.80082280933857, 66.71026915311813, 55.5829044431448, 74.24892023205757, 8.885829839855433, 1.5810299688018858, 0.6229891581460834, 1.018788863439113, 20.3932948037982, 61.11238293349743, 47.61152118444443, 62.542060017585754, 64.86612930893898, 69.52902629971504, 15.32483322545886, 23.60728394240141, 38.835124522447586, 24.40465595573187, 44.77560415863991, 47.60940469801426, 57.71296754479408, 37.7582661062479, 63.50210890173912, 71.91651418805122, 54.18152064085007, 1.5180185437202454, 0.4208507516887039, 0.33350837125908583, 0.24412535189185292, 0.23191850690636784, 0.16012713342206553, 0.10755338458693586, 0.2793965139426291], [0.015188680245046271, 0.08017741958610713, 0.04182784752629232, 0.07210393639979884, 0.053077641132404096, 0.017633671850489918, 0.07303918348043226, 0.05387559831433464, 0.11256481098826043, 0.10997829274856485, 0.2860867674462497, 0.19591564661823213, 6.241049207746983, 63.85134056210518, 51.26721382141113, 46.24095752835274, 27.72014904767275, 53.370476961135864, 36.97138532996178, 24.603734873235226, 39.29456926882267, 28.40897038578987, 16.6146407648921, 51.91181503236294, 53.97709161043167, 57.573803812265396, 55.278852358460426, 55.346302539110184, 4.652720186859369, 0.15429974533617496, 1.542021024506539, 0.5616260133683681, 0.0342292535060551, 25.75788874179125, 75.25478705763817, 63.82145136594772, 64.82091173529625, 52.12931156158447, 47.635049521923065, 53.45108583569527, 62.66470983624458, 61.502017825841904, 63.93481448292732, 56.58735014498234, 56.06111258268356, 51.60077892243862, 63.01409348845482, 59.429457038640976, 63.303786143660545, 40.52984118461609, 41.273100301623344, 47.19254806637764, 48.1635669618845, 50.30963100492954, 53.30588422715664, 54.23590712249279, 52.13914543390274, 55.01265004277229, 56.57550238072872, 56.558414697647095, 58.06882984936237, 53.90471309423447, 50.18184766173363, 51.77572153508663, 53.33711475133896, 47.92958691716194, 49.936380833387375, 54.725742638111115, 60.2486626803875, 61.995580941438675, 58.20988588035107, 51.7837543040514, 44.08089503645897, 37.983814403414726, 35.06518341600895, 40.829762890934944, 41.23819537460804, 45.42249284684658, 46.50203011929989, 41.69230900704861, 43.050865307450294, 39.0523474663496, 30.722913220524788, 23.807869479060173, 19.456390477716923, 18.339691199362278, 13.96967014297843, 13.357895370572805, 9.273754823952913, 7.747705886140466, 3.2934951223433018, 13.90937877818942, 25.297047570347786, 14.719862937927246, 18.15248854458332, 21.253847926855087, 26.50836557149887, 37.36302271485329, 41.619976088404655, 43.523590341210365, 39.229600355029106, 39.22721028327942, 32.296131402254105, 28.20371489971876, 23.16890526562929, 24.57427315413952, 30.65143145620823, 41.67886532843113, 49.99296359717846, 51.19970664381981, 48.64242106676102, 50.13720765709877, 46.88510276377201, 44.03394095599651, 44.821137115359306, 49.19084183871746, 49.326118379831314, 51.811010241508484, 48.71365584433079, 51.60357557237148, 47.36484222114086, 39.55473750829697, 42.82670773565769, 44.17398244142532, 45.841891542077065, 45.340098068118095, 42.00248636305332, 43.944828137755394, 38.68067800998688, 22.79119223356247, 34.57262344658375, 55.47239877283573, 53.04663933813572, 55.858678445219994, 56.23263917863369, 55.332068502902985, 51.2372600287199, 51.67381480336189, 56.22438982129097, 58.24117340147495, 59.16471004486084, 56.14302098751068, 55.38150765001774, 56.60562336444855, 56.185772493481636, 54.2136213183403, 48.796928375959396, 0.7348284381441772, 2.26557950489223, 0.3194699058076367, 0.2650986233493313, 37.54138894379139, 71.14933535456657, 47.70900875329971, 54.97575402259827, 51.5297569334507, 49.405138939619064, 5.323552815243602, 22.482266910374165, 18.647381588816643, 22.282536327838898, 36.90315239131451, 35.53886219859123, 26.022981517016888, 31.9133323431015, 48.890980929136276, 55.56183457374573, 15.806309189647436, 0.22469028539489955, 0.2664365078089759, 0.0418787551461719, 0.2591623621992767, 0.0048343777962145396, 0.08355787256732583, 0.020520509424386546, 0.11191992176463827, 0.08016009043785743, 0.03994592800154351, 0.05889183383260388, 0.2281261025927961, 0.2164912159787491, 0.07386762808891945, 0.09360894182464108, 0.045760024222545326, 0.19164826779160649, 0.066718319139909, 0.48511308152228594, 0.09046672566910274, 6.760031059384346, 72.92907625436783, 61.12334534525871, 39.46495592594147, 35.80919109284878, 62.14916490018368, 22.875321619212627, 39.421778842806816, 51.1171218752861, 29.491528496146202, 16.75928570330143, 55.00418409705162, 57.599536031484604, 65.24720326066017, 59.07211281359196, 63.48990395665169, 5.690379906445742, 0.16577371949097142, 3.216250967234373, 1.3567815581336617, 0.0951797270681709, 27.53799632191658, 78.72046709060669, 64.68781247735023, 67.81097128987312, 57.69513130187988, 52.15894617140293, 57.04264171421528, 66.83840587735176, 65.42712360620499, 67.62837588787079, 61.1475994437933, 59.551677480340004, 53.67387168109417, 63.959307968616486, 60.89650511741638, 64.28739756345749, 44.24565799534321, 48.53032328188419, 51.04143373668194, 49.68670383095741, 50.39681352674961, 53.55943322181702, 53.180323764681816, 53.51929597556591, 56.42725333571434, 59.13410648703575, 60.142663568258286, 59.85063783824444, 58.471737429499626, 55.51128588616848, 55.67130669951439, 58.67570288479328, 51.58783681690693, 51.53136804699898, 55.79830728471279, 59.986560344696045, 62.9748909920454, 60.555773600935936, 57.287280187010765, 51.85988321900368, 46.35494761168957, 44.76402997970581, 47.47469052672386, 51.01505935192108, 51.970913261175156, 57.33566299080849, 50.56072153151035, 52.84151874482632, 50.9705675393343, 44.05154161155224, 37.8752314299345, 34.93899218738079, 30.09704690426588, 27.860528714954853, 26.77629679441452, 22.53191314637661, 21.056273728609085, 14.339076820760965, 17.108302675187588, 17.274857237935066, 23.341535702347755, 36.875600069761276, 40.467915907502174, 42.065859362483025, 48.324340134859085, 49.60607595741749, 51.188033670187, 46.71203725039959, 46.05600245296955, 38.471088856458664, 31.113425865769386, 28.644474148750305, 30.4849186912179, 40.10284289717674, 50.38377642631531, 53.90987701714039, 54.587331265211105, 54.18942801654339, 52.635387405753136, 48.171143755316734, 48.636348992586136, 48.22800770401955, 53.21899048984051, 54.369032979011536, 52.54710674285889, 51.59197099506855, 53.646779134869576, 47.926357090473175, 41.022678539156914, 42.86901466548443, 41.65050745010376, 47.138777151703835, 45.77523171901703, 43.66335444152355, 43.6573925614357, 41.659163385629654, 26.831663623452187, 36.85310907661915, 55.26230804622173, 57.41320542991161, 58.18978115916252, 58.44785951077938, 54.76076915860176, 55.33511593937874, 53.566428646445274, 60.104623809456825, 59.82780486345291, 61.61063879728317, 58.738844096660614, 59.82673332095146, 59.161335825920105, 60.016221553087234, 57.00889192521572, 53.70593436062336, 0.7753027975559235, 1.9014254515059292, 1.0768390609882772, 0.4696128820069134, 40.07529057562351, 72.8214356303215, 51.908604204654694, 61.39918014407158, 57.67255671322346, 53.73944476246834, 6.631841138005257, 29.415046200156212, 23.74689605087042, 27.159031257033348, 26.174604780972004, 42.06853821873665, 36.96928024291992, 32.2480183839798, 56.72716364264488, 62.40184374153614, 18.10227993875742, 0.5474331218283623, 0.2837574924342334, 0.14607109391363338, 0.17525143513921648, 0.035417101680650376, 0.1260349471704103, 0.02546330386394402, 0.3194347576936707, 0.23362305684713647, 0.1652599306544289, 0.14318888919660822, 0.3357528930064291, 0.2172687789425254, 0.1942033041268587, 0.15848425595322624, 0.21417210838990286, 0.3697509749326855, 0.1553168735699728, 0.7350538729224354, 0.5565831495914608, 11.824647244066, 86.95259615778923, 69.51831847429276, 61.106960624456406, 41.055926755070686, 86.44836321473122, 41.90953195095062, 34.32855874300003, 49.80744995176792, 35.07758975028992, 21.91165342926979, 62.69351229071617, 63.602203130722046, 72.37789303064346, 64.43454846739769, 70.43494328856468, 7.125724386423826, 0.27548539568670094, 3.9559337636455894, 2.14821211528033, 0.21247782977297902, 33.888922333717346, 80.62760755419731, 70.45793205499649, 70.2980138361454, 60.50656244158745, 52.85189598798752, 61.528422608971596, 69.53375324606895, 69.74552348256111, 68.76103430986404, 65.04067674279213, 60.24381794035435, 58.902562111616135, 69.3807202577591, 66.30239143967628, 64.23201933503151, 52.60998196899891, 58.549196273088455, 53.508443757891655, 50.14372430741787, 50.088642463088036, 54.178397208452225, 57.095675468444824, 55.18482640385628, 62.30255886912346, 63.79944294691086, 61.17481738328934, 61.21825285255909, 61.76809474825859, 57.80990034341812, 58.885360434651375, 59.36145968735218, 52.97779083251953, 54.827368184924126, 59.09234672784805, 67.0012879371643, 66.8713653087616, 67.10436880588531, 62.39167928695679, 58.18061985075474, 55.65684087574482, 52.43540033698082, 56.679909378290176, 57.621738240122795, 58.92320640385151, 60.71458987891674, 55.832988023757935, 57.306556552648544, 59.389882162213326, 53.85133735835552, 51.257645934820175, 47.51512795686722, 41.68421924114227, 38.90846438705921, 44.25647981464863, 37.327133640646935, 36.54776506125927, 27.482971474528313, 31.630883999168873, 31.776647977530956, 36.64242938160896, 53.57320748269558, 47.90803447365761, 50.13118118047714, 56.7312104254961, 58.56851443648338, 56.38963535428047, 51.78651675581932, 54.9882173538208, 51.6047079116106, 47.45554335415363, 42.835876643657684, 45.21912395954132, 50.233091711997986, 59.40189331769943, 57.321607545018196, 56.93777874112129, 53.633514046669006, 56.79058603942394, 55.54436691105366, 50.74191100895405, 50.82524053752422, 53.56032617390156, 56.11770674586296, 56.75380401313305, 55.917145907878876, 57.820938751101494, 52.75604613125324, 41.76696740090847, 43.74146685004234, 43.04939478635788, 47.72785574197769, 43.34526211023331, 41.50621399283409, 43.17530483007431, 45.76257839798927, 31.39887034893036, 33.096463456749916, 54.22470912337303, 57.01540857553482, 59.43082116544247, 61.32273964583874, 56.98265813291073, 58.1982509046793, 56.73619195818901, 60.60645908117294, 60.546125918626785, 66.85897797346115, 61.047345623373985, 60.99311113357544, 61.34167782962322, 63.70485842227936, 62.3629604279995, 61.487905383110046, 3.237586822360754, 3.98656795732677, 2.336669177748263, 0.5600485042668879, 45.67827612161636, 80.16609191894531, 56.42298996448517, 67.6761545240879, 60.91800056397915, 62.67246522009373, 10.166342128068209, 32.05668345093727, 27.60964147746563, 34.29241128265858, 44.98664103448391, 57.244027107954025, 42.86758974194527, 41.48233987390995, 67.49216839671135, 77.03268125653267, 32.314336225390434, 0.8927930274512619, 0.34061090264003724, 0.2211453131167218, 0.37019780720584095, 0.1883105922024697, 0.22495057142805308, 0.21247797820251435, 0.43131708225701004], [0.09296394127886742, 0.04640167397155892, 0.02736139478656696, 0.13295321812620386, 0.08452466092421673, 0.03446689290285576, 0.006220821906026686, 0.08379571605473757, 0.043503809938556515, 0.03809174624620937, 0.04991691210307181, 0.015078619744599564, 0.8677925658412278, 49.23754893243313, 58.12138482928276, 31.81948497891426, 19.065687842667103, 39.866385385394096, 53.216364830732346, 18.635427430272102, 40.02188444137573, 11.211097966879606, 7.369890734553337, 56.76989994943142, 58.5392028093338, 59.80701617896557, 52.14564688503742, 61.66358135640621, 16.062623485922813, 0.19845906092086807, 1.0914750443771482, 0.1733044403954409, 0.05181844288017601, 16.33589342236519, 73.14753413200378, 61.55701607465744, 61.91613480448723, 53.28485995531082, 52.57080987095833, 55.50926819443703, 61.719673946499825, 62.49517813324928, 65.04878550767899, 61.606181636452675, 59.416628926992416, 49.74758416414261, 59.106535166502, 57.92057320475578, 60.53142450749874, 49.88817662000656, 56.351265013217926, 58.898754715919495, 58.02194036543369, 53.6706380546093, 51.612402498722076, 57.67898216843605, 56.31698705255985, 58.514861315488815, 59.566728472709656, 56.12219050526619, 53.49276959896088, 54.33395706117153, 52.519554421305656, 54.71589356660843, 48.87504078447819, 53.66339944303036, 48.396114483475685, 53.07115562260151, 57.549226731061935, 60.383000671863556, 59.185954704880714, 47.46744051575661, 43.687076568603516, 42.058947533369064, 41.20037600398064, 43.52115087211132, 44.53770652413368, 44.102937653660774, 47.24800989031792, 45.11255867779255, 43.65971803665161, 37.34294459223747, 26.596555039286613, 19.95960507541895, 18.228537663817406, 15.934733748435974, 12.764209527522326, 14.494858961552382, 11.474186349660158, 9.90172527730465, 4.0922293625772, 8.99124188348651, 19.558101519942284, 16.350948214530945, 15.380092710256577, 21.620024777948856, 25.739687718451023, 34.935522973537445, 40.266306325793266, 39.096546694636345, 36.767742857337, 40.307165533304214, 40.1642931997776, 38.19681577384472, 30.638255663216114, 26.54246874153614, 30.607025139033794, 38.32220144569874, 45.70844270288944, 51.3546547293663, 49.30722959339619, 50.07185496389866, 46.62571348249912, 42.89647579193115, 46.10495522618294, 48.60053971409798, 48.382325023412704, 52.53916136920452, 50.47553010284901, 54.7559130191803, 55.4416698217392, 46.06077499687672, 45.683842822909355, 42.55596086382866, 42.24596209824085, 38.63150864839554, 39.326764941215515, 43.426106572151184, 46.686548218131065, 56.63329727947712, 51.53528943657875, 48.82352314889431, 60.57240150868893, 58.103312999010086, 56.8907068669796, 50.80044686794281, 51.27468802034855, 49.55552726984024, 55.69457285106182, 55.8206956833601, 60.60702905058861, 57.02759072184563, 58.74039061367512, 55.03213919699192, 54.778077229857445, 55.54448090493679, 29.24920979887247, 1.1617694911547005, 1.5778165287338197, 1.3708706083707511, 5.834128567948937, 31.048439852893353, 49.32232618331909, 55.09702451527119, 59.94545795023441, 56.315873712301254, 38.597188889980316, 3.9447212778031826, 26.219417676329613, 18.950964398682117, 29.21419657766819, 40.43153665959835, 39.28498238325119, 25.925970822572708, 25.838433019816875, 47.1158491820097, 52.72224694490433, 7.606335422024131, 0.058518878649920225, 0.1973592722788453, 0.13404913275735453, 0.07752860547043383, 0.05858802825969178, 0.0532832902536029, 0.03762450120120775, 0.07350684783887118, 0.06673368901829235, 0.02692363712412771, 0.029892205566284247, 0.06637592930928804, 0.07663256605155766, 0.06045838141290005, 0.003536475846885878, 0.1537365888361819, 0.07662731906748377, 0.14753340685274452, 0.03189101335010491, 0.03765725588891655, 1.0229205479845405, 53.89036126434803, 71.1397522687912, 32.43791699409485, 22.495053224265575, 58.892640843987465, 33.14982019364834, 27.298795357346535, 52.51261219382286, 15.762863270938396, 9.281378164887428, 59.92215760052204, 62.558524534106255, 66.85261711478233, 58.600295931100845, 69.72669169306755, 18.31501342356205, 0.1405320895719342, 2.422589692287147, 4.2736520525068045, 0.014917319513187977, 20.78971043229103, 76.12477317452431, 63.44685606658459, 65.26730418205261, 57.769694700837135, 55.7769638299942, 58.53506103157997, 66.56555771827698, 65.27000203728676, 68.4878745675087, 63.796646296978, 60.20914860069752, 49.78622429072857, 61.52841120958328, 60.50447255373001, 63.83109524846077, 53.9396446198225, 59.27058756351471, 56.8022096157074, 55.86356118321419, 52.413547709584236, 53.096561059355736, 57.515260353684425, 58.76216344535351, 58.72733071446419, 60.29180936515331, 57.170915231108665, 58.628680408000946, 57.81655378639698, 58.55596750974655, 57.00468935072422, 53.740162923932076, 55.11660486459732, 51.12116485834122, 54.88019295036793, 54.530930891633034, 60.082277208566666, 61.077307015657425, 52.78924874961376, 52.40654468536377, 47.45608672499657, 46.11861169338226, 49.33865390717983, 50.02719596028328, 52.05172352492809, 54.674943163990974, 49.19950917363167, 51.652927324175835, 48.364788964390755, 41.86062477529049, 37.88617864251137, 33.221488147974014, 28.95128108561039, 29.08582616597414, 27.12394393980503, 24.39638949930668, 17.61449821293354, 16.60716276615858, 13.630343601107597, 15.161504689604044, 24.196372032165527, 33.21923486888409, 37.45023563504219, 39.10115584731102, 47.796031683683395, 49.50351186096668, 46.66177734732628, 44.317987114191055, 47.024410888552666, 45.181285589933395, 42.29146085679531, 33.654406517744064, 32.35368691384792, 38.39370600879192, 46.75081416964531, 51.598449647426605, 56.423810720443726, 53.30363094806671, 51.48704342544079, 47.19344861805439, 46.143739745020866, 48.13050113618374, 52.22076125442982, 51.29790097475052, 55.600163117051125, 52.716585248708725, 55.29677979648113, 54.794712737202644, 45.89591704308987, 45.49287647008896, 41.4100943505764, 42.23287180066109, 39.96450372040272, 39.779465049505234, 43.5658098757267, 47.14863382279873, 55.382499396800995, 51.41740836203098, 51.72654077410698, 65.28518602252007, 59.90984246134758, 60.632700473070145, 52.98424668610096, 53.80068227648735, 52.07798011600971, 57.0587832480669, 59.29315835237503, 60.5988784879446, 60.358533784747124, 58.96210491657257, 57.72197686135769, 56.759279519319534, 61.92009799182415, 28.30227591097355, 1.501434096135199, 2.8764926735311747, 1.6088879364542663, 8.878149501979351, 39.354993626475334, 52.57699973881245, 59.66478981077671, 63.93997460603714, 63.69980849325657, 44.98451694846153, 4.539128607138991, 35.01778855919838, 23.31974197179079, 34.13600027561188, 26.25018272548914, 49.87417057156563, 30.514293015003204, 23.93216270953417, 53.4233283251524, 60.86223855614662, 11.036418490111828, 0.34941568330395967, 0.24232326890341938, 0.15588611568091437, 0.04727355277282186, 0.06202151140314527, 0.06294078746577725, 0.014017226112628123, 0.03978445893153548, 0.16305579658364877, 0.24793443968519568, 0.10206374048721045, 0.42243799776770175, 0.12851262203184888, 0.1823524822248146, 0.10318340384401381, 0.1955010977690108, 0.1713159744394943, 0.1621031906688586, 0.3501064149895683, 0.08505318139214069, 2.063874928280711, 72.97240152955055, 74.64181154966354, 47.172443345189095, 25.8201465010643, 69.86185044050217, 68.61142113804817, 25.418907031416893, 49.25815902650356, 19.133426807820797, 12.886228580027819, 65.2190999686718, 67.82581329345703, 71.33318468928337, 65.23053735494614, 73.36245819926262, 22.03531589359045, 0.485832400736399, 3.037626352161169, 3.042348073795438, 0.3067258349619806, 26.848895698785782, 79.48895305395126, 67.06290543079376, 68.46220314502716, 60.6962026655674, 59.05287824571133, 62.303429022431374, 72.0521593093872, 67.8094969689846, 74.35361981391907, 67.57811978459358, 65.87089419364929, 52.19137363135815, 65.38136646151543, 59.60776247084141, 64.34722155332565, 57.051077261567116, 59.266818165779114, 57.96725369989872, 55.24102918803692, 50.89489459991455, 52.76966840028763, 58.35874289274216, 59.948794171214104, 62.11777478456497, 64.84906062483788, 60.49034111201763, 60.18533527851105, 59.81868535280228, 60.69022178649902, 59.52523849904537, 56.47770702838898, 56.55368395149708, 54.61640730500221, 59.39344257116318, 59.82418365776539, 62.47758887708187, 63.53497713804245, 55.016442239284515, 55.255339220166206, 55.16715735197067, 51.55087240040302, 56.031880751252174, 58.47424529492855, 57.53542587161064, 62.304390370845795, 57.64361746609211, 58.529087752103806, 59.81803938746452, 51.043128445744514, 52.59266249835491, 44.685640186071396, 40.75519189238548, 40.11210300028324, 43.925285786390305, 43.23608636856079, 36.64654076099396, 32.74749778211117, 29.176172018051147, 27.4803439155221, 37.30744689702988, 49.80402633547783, 49.64702636003494, 49.26279477775097, 57.090283557772636, 59.019090458750725, 52.39551767706871, 46.30120329558849, 50.71162283420563, 53.204178884625435, 50.04353888332844, 48.60164165496826, 47.67337426543236, 48.997861593961716, 53.87897327542305, 52.93933689594269, 58.178700953722, 54.406016394495964, 55.30509755015373, 51.337111070752144, 48.315756395459175, 50.77030688524246, 52.492720261216164, 52.94537857174873, 58.185172006487846, 58.002417013049126, 55.91263175010681, 57.70274229347706, 48.73239263892174, 48.0068975687027, 41.3986037671566, 42.58577026426792, 43.01567159593105, 42.22949378192425, 44.399253353476524, 45.99707141518593, 51.7241545021534, 51.16112731397152, 54.30703930556774, 67.30157822370529, 64.4294947385788, 62.872273698449135, 57.17029206454754, 59.945613741874695, 54.68126222491264, 61.531500443816185, 60.82916893064976, 66.54953017830849, 63.23687553405762, 63.65244023501873, 60.15075333416462, 59.2894421517849, 65.38853287696838, 40.31845472753048, 1.1297182110138237, 5.480574639514089, 2.373805772513151, 9.111127350479364, 41.48466914892197, 57.838623002171516, 63.24748456478119, 72.02705025672913, 68.15353810787201, 52.982741966843605, 6.7314105201512575, 36.87376096844673, 26.078004464507103, 41.36005103588104, 52.29302577674389, 64.3917627632618, 37.74209037423134, 34.48030360043049, 61.83416560292244, 73.00362065434456, 17.1973679959774, 0.5567230295855552, 0.4166378465015441, 0.3958998655434698, 0.1649371112580411, 0.1240024421713315, 0.14656061452114955, 0.13138265552697703, 0.14067321637412533], [0.10672633521608077, 0.05532896837394219, 0.1005707991134841, 0.049091755208792165, 0.07621425451361574, 0.02217492728959769, 0.04030162454000674, 0.06743352685589343, 0.02945118430943694, 0.03935216162062716, 0.03939066795282997, 0.012225246537127532, 0.16816051094792783, 29.339114874601364, 68.82398933172226, 45.85695393383503, 25.897603444755077, 29.701921306550503, 58.50331753492355, 21.168730594217777, 24.319287836551666, 19.07418418675661, 5.741116208955646, 46.780308187007904, 68.06462287902832, 67.48576954007149, 59.72970552742481, 57.28549808263779, 28.76371745020151, 0.16885205899598077, 1.137967687100172, 1.3124593114480376, 0.30494331498630345, 7.099720006808639, 66.14203244447708, 60.60412980616093, 61.3788740336895, 57.01312109827995, 55.736765787005424, 60.04987254738808, 64.69082951545715, 66.57341569662094, 65.35352915525436, 60.12445494532585, 59.66805763542652, 53.297501876950264, 61.596704944968224, 57.95083098113537, 61.80335685610771, 57.51704625785351, 53.83825846016407, 57.85047456622124, 48.547551557421684, 57.573982402682304, 52.79807187616825, 52.86706857383251, 59.09999571740627, 56.98811464011669, 58.48767377436161, 56.58675737679005, 54.14071083068848, 53.87576624751091, 52.0501010119915, 52.79090166091919, 52.084679156541824, 54.19917829334736, 46.304934695363045, 48.75135742127895, 59.54577639698982, 58.52456979453564, 55.94326950609684, 47.03057415783405, 49.50192354619503, 45.74670284986496, 44.35226507484913, 44.65661734342575, 45.49710564315319, 45.775596499443054, 48.77805098891258, 41.64440117776394, 39.988993406295776, 31.017950288951397, 24.80905305594206, 22.47610554099083, 16.69171392917633, 16.173530034720898, 13.709901832044125, 15.568448603153229, 13.929110169410706, 12.215858101844788, 8.420798443257809, 5.394716821610928, 12.73041794076562, 16.72847505658865, 15.264426916837692, 22.632383555173874, 24.088657312095165, 34.364964589476585, 40.26229374110699, 44.988711923360825, 38.66803988814354, 44.12395052611828, 48.77285286784172, 41.359367072582245, 38.78909379243851, 34.88126568496227, 36.152658462524414, 37.56127707660198, 42.250423058867455, 48.387291356921196, 48.46914276480675, 49.33426134288311, 43.36529083549976, 41.64961449801922, 46.84729479253292, 47.41007499396801, 48.74070279300213, 52.849072739481926, 49.447955042123795, 51.250992491841316, 50.56525468826294, 47.52224877476692, 44.89787019789219, 49.19129021465778, 46.104138270020485, 43.46782073378563, 38.403946459293365, 44.57368679344654, 43.28091636300087, 44.29445497691631, 40.150093361735344, 34.051986783742905, 59.83275979757309, 55.68525195121765, 58.231510519981384, 52.04342097043991, 48.68256591260433, 53.41556154191494, 58.392116501927376, 59.52991984784603, 55.17419457435608, 57.43383452296257, 54.8177433013916, 57.836194932460785, 51.97333753108978, 58.769269064068794, 7.294963030144572, 1.8041671765968204, 1.7475872626528144, 0.5984540528152138, 16.22440930455923, 60.483843460679054, 51.202187910676, 61.546027064323425, 48.88895943760872, 63.92045885324478, 18.468682877719402, 7.516808426007628, 39.648436680436134, 9.851605016738176, 31.735401190817356, 37.05928221344948, 42.81401261687279, 24.64370872825384, 47.86633551120758, 48.34325172007084, 50.75066953897476, 3.635221947915852, 0.179734630510211, 0.18667691736482084, 0.05315167407388799, 0.09722009883262217, 0.05418702945462428, 0.05859028809936717, 0.11351280074450187, 0.07327323459321633, 0.049626535692368634, 0.08817259877105244, 0.06749215652234852, 0.026966325458488427, 0.0754981859063264, 0.09816971389227547, 0.03689974204462487, 0.04586784343700856, 0.10963866370730102, 0.04168692110397387, 0.08107665766146965, 0.1687786160618998, 0.03938441535865422, 35.26113510131836, 76.02415457367897, 49.84131373465061, 22.1108216419816, 47.55791746079922, 50.145726799964905, 20.01981094479561, 37.35315464437008, 21.971770003437996, 7.069325912743807, 46.703947484493256, 73.9519889652729, 74.17873799800873, 65.41671216487885, 65.79724654555321, 35.83766296505928, 0.611688505159691, 3.1243754597380757, 7.977922707796097, 0.10385910703917034, 7.406343128532171, 66.20195522904396, 64.10582050681114, 64.06369596719742, 60.24563044309616, 59.39573384821415, 64.80081841349602, 69.37376663088799, 64.79631945490837, 67.28189527988434, 63.171667233109474, 61.061967238783836, 58.14778581261635, 63.00424441695213, 61.1259900033474, 64.9931488931179, 59.35062646865845, 54.41327020525932, 55.537607073783875, 49.07687455415726, 56.00040324032307, 53.571497574448586, 51.69271878898144, 57.69988864660263, 58.23080375790596, 59.47504319250584, 58.08022543787956, 59.664398431777954, 56.1734763532877, 56.46758057177067, 55.50543040037155, 57.60159932076931, 57.158163115382195, 47.841693833470345, 51.90909057855606, 61.02535240352154, 62.420823723077774, 59.177997931838036, 51.138476729393005, 48.33458058536053, 49.76493023335934, 48.48002918064594, 51.15944780409336, 49.79635074734688, 54.06756855547428, 57.48982831835747, 50.63805118203163, 50.20802825689316, 46.7757598310709, 41.57252423465252, 34.04429979622364, 31.681985557079315, 27.814809568226337, 29.4223665073514, 29.167407788336277, 26.950230561196804, 22.73939721286297, 19.769989550113678, 9.563298337161541, 12.85426564514637, 27.068584710359573, 30.016111247241497, 36.31458297371864, 35.62849938869476, 46.28060840070248, 49.37062159180641, 50.007786601781845, 43.60350385308266, 50.48069782555103, 50.090477764606476, 46.89918480813503, 43.92839401960373, 38.26313741505146, 40.1926738768816, 44.573329612612724, 49.361551478505135, 53.75447675585747, 53.31130653619766, 52.45640181005001, 45.26025675237179, 45.12674331665039, 47.83294290304184, 51.66589602828026, 51.592848747968674, 53.26026387512684, 52.11381979286671, 54.31427411735058, 49.591864719986916, 48.85036110877991, 45.61065495014191, 48.03277038037777, 47.7733962982893, 45.06581358611584, 41.527295261621475, 47.98068657517433, 47.46876664459705, 49.0378088504076, 47.49702572822571, 43.33313316106796, 60.7391669601202, 61.059641763567924, 57.52693332731724, 55.08583791553974, 50.20348370075226, 56.61063149571419, 61.51122473180294, 62.09101282060146, 55.25302894413471, 60.08220121264458, 58.69333393871784, 59.69687528908253, 53.76862719655037, 59.64588202536106, 5.705297430977225, 4.648339496925473, 5.8231044095009565, 0.9910852031316608, 20.438018403947353, 63.863195925951004, 56.89389489591122, 64.82646703720093, 54.64163415133953, 73.01938980817795, 19.14465330541134, 11.266483794897795, 51.69715695083141, 13.634569924324751, 32.8617462515831, 25.64145538955927, 54.68032747507095, 27.373305559158325, 48.18452663719654, 57.38134413957596, 56.835951805114746, 4.165378762409091, 0.10430251059005968, 0.20436324644833803, 0.013556061112467432, 0.031766273168614134, 0.042298959160689265, 0.047667751932749525, 0.11327456391882151, 0.029839310846000444, 0.2749029581900686, 0.15892909927060828, 0.1934242420247756, 0.2016518692835234, 0.20370902842842042, 0.14867454796331003, 0.21694846800528467, 0.15880357241258025, 0.1408180539146997, 0.1775775634450838, 0.21514846303034574, 0.3991188865620643, 0.23112057941034436, 48.774091601371765, 84.42372545599937, 63.11125807464123, 32.876979634165764, 51.79034315049648, 81.18310734629631, 25.500159971415997, 36.759945675730705, 24.81161791831255, 12.149668503552675, 53.14226120710373, 79.34333726763725, 78.07463094592094, 69.06805783510208, 70.2872072160244, 38.026064336299896, 1.4921352826058865, 3.2058668369427323, 6.662951018661261, 0.4827084339922294, 13.037545010447502, 74.45392683148384, 65.1427012681961, 66.63694068789482, 65.10776594281197, 61.29840575158596, 66.57501921057701, 72.43029981851578, 69.85222175717354, 72.68883794546127, 66.35658413171768, 66.024831533432, 59.301008731126785, 67.40718975663185, 61.58580332994461, 63.208335265517235, 59.02665205299854, 57.50823073089123, 57.93677933514118, 47.24095366895199, 55.821455642580986, 56.74241602420807, 54.73308004438877, 61.751060262322426, 59.9861765652895, 64.14998933672905, 59.48972940444946, 61.99952132999897, 58.81840422749519, 59.35596898198128, 59.99495409429073, 57.77733229100704, 58.79592463374138, 51.030068546533585, 52.42081671953201, 65.13205423951149, 64.25051674246788, 62.716805040836334, 53.66974130272865, 57.20986694097519, 54.261422753334045, 51.563924700021744, 54.01134677231312, 52.53473460674286, 57.04572334885597, 64.1020131111145, 57.25826494395733, 57.33855843544006, 55.20572528243065, 53.329727947711945, 47.7475006878376, 46.23008631169796, 39.47785243391991, 44.314882680773735, 46.44522696733475, 44.77310389280319, 42.98885263502598, 38.340326473116875, 23.794629089534283, 21.61235298961401, 42.62177713215351, 45.138005912303925, 48.71800281107426, 47.07343205809593, 55.208689123392105, 58.033415749669075, 56.23518884181976, 47.72170767188072, 57.249745801091194, 57.17123441398144, 49.093996435403824, 52.90627487003803, 50.93041129410267, 49.77488569915295, 47.45275430381298, 51.13072894513607, 55.875762328505516, 52.345956936478615, 53.38260971009731, 48.19517366588116, 47.00725860893726, 49.645707830786705, 51.882237419486046, 52.71135292947292, 58.73219445347786, 53.2993333786726, 57.230230048298836, 53.033834025263786, 49.54156681895256, 47.74388328194618, 48.640593364834785, 48.68242911994457, 43.318891525268555, 40.78889228403568, 48.52882616221905, 50.509941056370735, 54.25285041332245, 49.134137481451035, 42.03876681625843, 65.41506305336952, 62.404009625315666, 61.440681517124176, 56.72449238598347, 55.264169946312904, 58.494691997766495, 62.770469561219215, 65.26299521327019, 59.24796737730503, 61.70238487422466, 58.76792773604393, 63.86548340320587, 56.016206592321396, 68.14113557338715, 13.679251726716757, 3.5992065304890275, 6.97515556588769, 1.8526146956719458, 23.553858809173107, 67.66556829214096, 61.7355152964592, 67.84920483827591, 58.405647575855255, 75.60429230332375, 27.092759013175964, 10.914929509162903, 55.041600689291954, 16.445718929171562, 42.70363233983517, 51.72255478799343, 70.07698729634285, 35.22187560796738, 63.73244494199753, 67.26134598255157, 76.64532244205475, 10.442174077033997, 0.3466531721642241, 0.3441249718889594, 0.12908015720313415, 0.2026446847594343, 0.16682345769368112, 0.19107993110083044, 0.203083056549076, 0.2703287161421031], [0.0327133723476436, 0.053489206547965296, 0.021470584615599364, 0.023508746635343414, 0.018454158780514263, 0.033194981660926715, 0.07850032168789767, 0.0929749695933424, 0.09722390605020337, 0.07307267660507932, 0.08212640328565612, 0.35942823509685695, 0.3794561588438228, 17.90214277803898, 63.851500153541565, 46.553160175681114, 43.11728574335575, 23.541851453483105, 39.39345136284828, 39.32790108025074, 25.340718626976013, 30.824932046234608, 5.024789096787572, 26.556165106594563, 61.6047453135252, 61.02653793990612, 47.229527682065964, 42.201124504208565, 48.429180309176445, 1.8347501917742193, 2.0829423051327467, 4.651666693389416, 0.5790367384906858, 0.9412416152190417, 40.29698207974434, 63.412870690226555, 57.84440629184246, 59.00273993611336, 58.83637346327305, 59.402478486299515, 63.0518102645874, 65.3633326292038, 64.1093847155571, 62.84877195954323, 54.54934850335121, 56.58494107425213, 59.27500292658806, 62.690814435482025, 58.47453787922859, 74.16397958993912, 50.805314406752586, 57.70759843289852, 54.0492345392704, 54.81116585433483, 56.43237166106701, 53.89848902821541, 55.88776208460331, 59.83318157494068, 54.58473980426788, 52.701655849814415, 49.903273209929466, 50.9829206764698, 51.39188893139362, 52.95078948140144, 51.35729178786278, 54.26199272274971, 47.50948905944824, 43.85146714746952, 50.428887605667114, 50.38174353539944, 45.76339915394783, 43.97739619016647, 46.553726345300674, 44.7770556807518, 43.5128141194582, 43.78042995929718, 44.692901596426964, 47.14058965444565, 48.02212335169315, 42.75684468448162, 39.446568712592125, 29.700617976486683, 25.864207036793232, 20.21992340683937, 17.645375356078148, 15.698721762746572, 17.94335726648569, 20.32952282577753, 18.294224739074707, 20.603041648864746, 5.997320311143994, 0.6158601469360292, 13.27229356393218, 19.45711813867092, 17.005742378532887, 24.146024733781815, 21.93360485136509, 34.738697335124016, 38.14306765794754, 42.437095642089844, 46.15019179880619, 49.70079347491264, 49.73827846348286, 45.53583316504955, 41.52815781533718, 39.201086685061455, 41.6298745572567, 43.71889986097813, 42.32894204556942, 45.764037519693375, 45.33490754663944, 45.274232402443886, 38.13426733016968, 41.75426848232746, 45.2163615077734, 45.80631025135517, 50.03585949540138, 50.504100769758224, 52.252238765358925, 51.756703555583954, 53.28004561364651, 49.89260718226433, 44.13654305040836, 45.17201028764248, 46.53948090970516, 45.39587527513504, 46.27416394650936, 44.93542738258839, 44.35792297124863, 44.995418563485146, 54.61443901062012, 53.57899837195873, 58.77017341554165, 57.30736970901489, 55.39083234965801, 50.22279046475887, 49.404299184679985, 54.633567184209824, 57.2803645581007, 59.93470832705498, 61.15617178380489, 56.393822729587555, 60.303155556321144, 52.2855743765831, 59.944610595703125, 27.716294154524803, 0.5283008515834808, 0.4802831547567621, 0.7472484279423952, 0.7321081997361034, 22.513075657188892, 63.11369754374027, 49.83638919889927, 57.09465712308884, 58.122760355472565, 56.816056072711945, 10.517333094030619, 17.270405776798725, 24.693582952022552, 12.999909929931164, 35.446329563856125, 34.46518421173096, 38.550128415226936, 20.363464504480362, 38.51547807455063, 54.149309769272804, 38.29279102385044, 0.8707764744758606, 0.018124724992958363, 0.07978781432029791, 0.1538389310007915, 0.061613853395101614, 0.09564333187881857, 0.019533213671820704, 0.13167819357477129, 0.04206434030493256, 0.09888141867122613, 0.038733982291887514, 0.032815892627695575, 0.04880379819951486, 0.015147467856877483, 0.031388434654218145, 0.09738279244629666, 0.051720954361371696, 0.010790743726829533, 0.18563638179330155, 0.19230621139286086, 0.5559158104006201, 0.5498929554596543, 22.440700940787792, 71.77488818764687, 56.35504961013794, 36.394032910466194, 27.86600422114134, 40.618403032422066, 27.16885942965746, 37.10187032818794, 39.702177196741104, 6.7033580504357815, 27.616454511880875, 69.17094871401787, 68.11835199594498, 53.763505071401596, 48.67239385843277, 59.320509284734726, 3.151747528463602, 1.107570268213749, 8.357786424458027, 1.0274684289470315, 0.8065958402585238, 44.02025029063225, 70.47416478395462, 61.502842381596565, 63.88013541698456, 62.454850897192955, 62.55089834332466, 66.39351055026054, 68.80884334445, 65.80376699566841, 65.99216088652611, 57.14973896741867, 57.88010537624359, 61.08964875340462, 63.4059664607048, 61.02282173931599, 76.25197514891624, 54.07360643148422, 58.683021292090416, 55.457317382097244, 55.605171248316765, 56.984626427292824, 55.539845153689384, 57.61664271354675, 61.08839862048626, 54.45011682808399, 54.849490597844124, 56.06168255209923, 52.59988211095333, 56.401407122612, 57.44536690413952, 53.93716715276241, 57.98205390572548, 48.90578493475914, 45.933637619018555, 49.43677604198456, 52.704589292407036, 49.09916415810585, 48.61548811197281, 51.49830602109432, 50.41197471320629, 50.259348303079605, 50.93886584043503, 51.14963673055172, 54.872300773859024, 53.978242948651314, 51.284297704696655, 49.61119048297405, 44.49677512049675, 37.636714428663254, 32.699012383818626, 31.0814106836915, 29.23085108399391, 32.85778686404228, 32.19414107501507, 32.2579700499773, 25.92105768620968, 20.190049409866333, 6.705537708476186, 16.861439421772957, 36.493796557188034, 30.519816018640995, 36.76411025226116, 32.8612294793129, 43.339292630553246, 47.9455004632473, 49.20637920498848, 49.28929075598717, 52.559737265110016, 54.304770827293396, 50.59833191335201, 45.762829184532166, 43.99586319923401, 43.592499643564224, 47.76366502046585, 49.18961450457573, 50.22236868739128, 50.647771060466766, 46.40670083463192, 42.6689326018095, 47.278982028365135, 47.67781622707844, 48.74074459075928, 51.654052063822746, 53.15148711204529, 50.00692404806614, 52.55413256585598, 53.13370406627655, 50.87009333074093, 46.1901618540287, 45.5023417621851, 48.20658825337887, 45.843590050935745, 47.51280628144741, 48.18224675953388, 47.03757718205452, 46.144279316067696, 56.70157961547375, 61.59894682466984, 59.711751490831375, 61.260096207261086, 55.98354734480381, 52.7888535708189, 51.52820661664009, 59.081175327301025, 58.99028040468693, 63.081285282969475, 61.98733538389206, 61.994604393839836, 60.73898836970329, 56.94390021264553, 60.60604490339756, 28.52684386074543, 0.7219947455450892, 3.5580732626840472, 2.011385257355869, 1.1816500243730843, 29.189666993916035, 66.4422619342804, 54.563825726509094, 64.38471034169197, 63.86498183012009, 62.12964914739132, 10.664405152201653, 24.034221433103085, 31.125910095870495, 18.019353188574314, 30.21209143102169, 27.46184080839157, 50.746444165706635, 17.165803089737892, 41.24381147325039, 62.5420144200325, 46.14649459719658, 1.3753529428504407, 0.058214241871610284, 0.09784034875337966, 0.024199233412218746, 0.02824315342877526, 0.09836916608037427, 0.07369985076365992, 0.1397101758630015, 0.07067254875437357, 0.26483723893761635, 0.15784799790708348, 0.11459825851488858, 0.20720265893032774, 0.14631110447226092, 0.20992920559365302, 0.13615549629321322, 0.2345339985913597, 0.12479300756240264, 0.2121526948758401, 0.257303430698812, 0.6578212359454483, 0.7689349330030382, 30.58977596461773, 83.74426871538162, 62.140767350792885, 54.3852087110281, 36.90000616014004, 63.983216285705566, 45.40918596088886, 36.025334894657135, 38.24775964021683, 9.211827646940947, 34.290146604180336, 72.42790594696999, 72.33735680580139, 58.8980745524168, 53.32232594490051, 60.95157936215401, 3.6968164052814245, 4.564204886555672, 9.827298671007156, 0.8232789044268429, 3.8843004824593663, 55.90390361845493, 72.33578369021416, 69.4877377152443, 65.87461799383163, 67.46669456362724, 65.57985261082649, 73.47611770033836, 71.60729438066483, 74.45710346102715, 68.98659020662308, 61.11022464931011, 59.75180134177208, 65.02535596489906, 64.6559701859951, 62.58676081895828, 72.36526250839233, 54.791444912552834, 56.94029040634632, 52.491074949502945, 55.388012900948524, 59.43328343331814, 58.155655190348625, 60.213100388646126, 64.80917796492577, 60.271522253751755, 58.46398964524269, 58.16527247428894, 55.90725123882294, 56.91822499036789, 58.21788065135479, 55.944208055734634, 62.06963896751404, 53.234980031847954, 47.75523707270622, 52.607132121920586, 54.737818390131, 50.34503370523453, 51.42909653484821, 53.48774626851082, 52.71077536046505, 50.76276049017906, 52.58298821747303, 56.00106820464134, 58.11453379690647, 60.23436404764652, 56.952016577124596, 57.30423867702484, 54.854088351130486, 50.178355649113655, 43.86736549437046, 44.2586874961853, 41.32002018392086, 49.07506965100765, 44.55730967223644, 49.583691358566284, 46.4391852915287, 32.94105939567089, 13.075034748762846, 19.503076672554016, 52.5165069848299, 46.68301060795784, 48.081422969698906, 40.72443634271622, 52.94179916381836, 56.21717020869255, 55.144502967596054, 55.4622533172369, 56.28952592611313, 57.60846175253391, 52.788959965109825, 48.661344051361084, 48.332486897706985, 47.48635210096836, 50.12186408042908, 48.90996851027012, 50.917013213038445, 50.028829872608185, 48.94378289580345, 43.17756570875645, 50.115575417876244, 48.64912010729313, 50.695249512791634, 54.74929757416248, 54.60470773279667, 56.295533403754234, 54.626013189554214, 57.33450025320053, 51.43228456377983, 48.06557781994343, 47.725758254528046, 49.3357964605093, 45.32368294894695, 46.43269903957844, 46.283918023109436, 47.134867161512375, 45.33565230667591, 60.00453718006611, 56.98590695858002, 64.55871820449829, 65.16028672456741, 60.507949367165565, 55.72907879948616, 56.396797969937325, 61.38880290091038, 62.90230728685856, 64.68566179275513, 64.35138612985611, 62.18809761106968, 64.56409871578217, 60.065409913659096, 63.68465110659599, 39.07964900135994, 1.434371613431722, 2.5621866015717387, 4.341700226068497, 3.4667321015149355, 28.460413925349712, 72.3353885114193, 59.014887884259224, 67.49262437224388, 68.98367956280708, 69.15209412574768, 15.76007517054677, 24.964305125176907, 36.63296788930893, 19.345654919743538, 45.3563117980957, 48.68680268526077, 61.76705360412598, 25.33253576606512, 53.42155762016773, 70.23477762937546, 61.83817058801651, 2.976132114417851, 0.14494291070150211, 0.22551531612407416, 0.17956852301722392, 0.16750978102209046, 0.17505166382761672, 0.1267267475486733, 0.3342109179357067, 0.17442725045839325], [0.08422533792327158, 0.085644168430008, 0.07793461962137371, 0.03366085373272654, 0.04275673069059849, 0.03256318763305899, 0.06342140230117366, 0.19427321443799883, 0.05287512016366236, 0.10869945355807431, 0.17467021476477385, 0.29792835703119636, 0.2549792022909969, 7.8361342661082745, 66.2153609097004, 63.75956788659096, 50.64568117260933, 42.99246244132519, 53.30335356295109, 44.90275293588638, 18.456498831510544, 36.943943202495575, 13.578405138105154, 17.215352430939674, 68.74889016151428, 76.77944004535675, 69.41243335604668, 44.64804120361805, 55.38508705794811, 14.972085803747177, 1.076571294106543, 6.563324639573693, 0.23308255069423467, 0.20123289723414928, 15.6337234005332, 59.934560135006905, 57.86240212619305, 56.689538061618805, 54.524809420108795, 65.65498977899551, 61.75277777016163, 66.77282899618149, 61.063137575984, 62.65931032598019, 57.66613505780697, 60.92162936925888, 58.72023269534111, 64.52119901776314, 61.184575259685516, 65.26253923773766, 65.7169796526432, 52.68731161952019, 51.493153497576714, 58.39493215084076, 59.28256832063198, 64.98055636882782, 59.23603981733322, 58.74246150255203, 53.657832741737366, 48.2238545268774, 50.66785678267479, 48.19850988686085, 50.914904326200485, 53.505476117134094, 54.43999037146568, 54.50825370848179, 44.78135704994202, 43.55298936367035, 45.54014213383198, 44.893656224012375, 46.50077238678932, 46.20899744331837, 49.37516234815121, 43.81020896136761, 43.52020092308521, 42.354260087013245, 47.40035131573677, 47.840683087706566, 48.79785172641277, 40.99288813769817, 35.966054275631905, 31.101918183267117, 24.102482870221138, 22.779182977974415, 17.598518170416355, 20.79428158700466, 22.156373597681522, 25.072753205895424, 24.576454237103462, 27.541199550032616, 8.408499453216791, 3.2561557134613395, 19.62646745145321, 18.7628535926342, 21.958466917276382, 22.847459614276886, 23.317792676389217, 30.32950133085251, 41.03644140064716, 45.69988556206226, 46.62616565823555, 50.20215757191181, 50.88418297469616, 45.93068517744541, 44.90138500928879, 45.85036128759384, 45.40460340678692, 46.509667709469795, 46.25225432217121, 44.02021609246731, 42.353830710053444, 40.76351724565029, 38.25668156147003, 41.620405465364456, 43.17499704658985, 50.58321252465248, 50.27835488319397, 51.051643788814545, 50.299652740359306, 52.646843791007996, 53.88924412429333, 52.76135064661503, 50.26562936604023, 47.49349571764469, 43.142071813344955, 44.42822679877281, 47.72984303534031, 47.184458300471306, 50.51481619477272, 48.37639354169369, 52.758808583021164, 57.349338456988335, 59.34224031865597, 58.296775817871094, 55.82257278263569, 53.29244814813137, 50.02186104655266, 56.90972104668617, 57.40845188498497, 59.86176744103432, 50.80559179186821, 54.07400161027908, 53.42111684381962, 53.9518191665411, 34.03418093919754, 4.681332651525736, 0.37471745687071234, 5.1105462200939655, 0.6238782510627061, 5.336843077093363, 48.516294434666634, 56.58887766301632, 51.5153519064188, 62.090800032019615, 50.37589944899082, 52.80434153974056, 7.888191947713494, 20.669918060302734, 18.22123445570469, 18.461337871849537, 38.907746225595474, 40.54030202329159, 25.68885214626789, 22.172190248966217, 43.783830776810646, 60.316884219646454, 34.937099888920784, 0.08400327991694212, 0.12547665915917605, 0.11496620791149326, 0.04400586542033125, 0.05345215853594709, 0.16036396758863702, 0.06493318680441007, 0.027012099271814805, 0.03124465096334461, 0.04156410679570399, 0.07976165361469612, 0.04440525961399544, 0.03369169367942959, 0.06383598825777881, 0.07667788158869371, 0.0517522915470181, 0.06992413735133596, 0.07723172413534485, 0.09164115952444263, 0.18822460697265342, 0.5651812569703907, 0.26274298725184053, 7.912053242325783, 73.7290321290493, 73.10591116547585, 50.61649113893509, 48.87081541121006, 64.44589465856552, 31.369224339723587, 26.44116047769785, 47.622924372553825, 18.576663583517075, 21.117549240589142, 71.97776690125465, 85.159502774477, 75.05639970302582, 49.985542595386505, 63.081995844841, 19.975131042301655, 0.892291454365477, 4.131356813013554, 1.9610695447772741, 0.508376561338082, 18.90243910253048, 66.49829372763634, 61.83571211993694, 63.97063136100769, 59.5042522251606, 68.12837585806847, 65.23321241140366, 68.96408021450043, 63.95773485302925, 64.9548089504242, 59.226354137063026, 64.13323223590851, 60.973633378744125, 66.74439892172813, 63.13238114118576, 64.31980222463608, 68.13616544008255, 59.155563935637474, 53.85076358914375, 58.31447906792164, 58.42153072357178, 63.7992225587368, 61.0002775490284, 60.70946015417576, 58.663418143987656, 52.35176682472229, 52.967314794659615, 52.31718488037586, 54.483433440327644, 56.80224001407623, 57.91984744369984, 56.05138510465622, 46.56376160681248, 45.56942716240883, 45.74899032711983, 47.63691522181034, 48.8862843811512, 48.92647102475166, 53.32262992858887, 46.469021290540695, 47.971711456775665, 49.55340698361397, 51.89622826874256, 55.8082627505064, 54.630892127752304, 52.06551678478718, 49.450322315096855, 42.23397754132748, 36.984582021832466, 31.3015328720212, 31.344155184924603, 31.342580169439316, 33.215556666255, 36.174370497465134, 35.57708814740181, 35.809035301208496, 14.899067021906376, 6.773356944322586, 32.047579139471054, 35.06986476480961, 32.853854075074196, 37.595315650105476, 34.2563284188509, 41.23882994055748, 49.68490272760391, 52.02659547328949, 50.71216620504856, 54.30182218551636, 54.504598304629326, 50.8188720792532, 50.04478521645069, 48.40565577149391, 48.283522725105286, 50.61149440705776, 51.03254221379757, 49.45304296910763, 47.678526788949966, 44.16995465755463, 40.69053076207638, 43.76271910965443, 46.749609634280205, 54.050917848944664, 51.76346719264984, 53.16374525427818, 49.763547107577324, 54.69966843724251, 55.03211259841919, 55.04070393741131, 51.412556022405624, 49.170205146074295, 44.12917524576187, 48.899511471390724, 49.67622019350529, 48.13639082014561, 51.94952420890331, 51.111798360943794, 54.847381711006165, 63.67285653948784, 61.63607843220234, 58.9603266119957, 58.32798734307289, 55.483190193772316, 51.95391297340393, 58.10226425528526, 60.46962462365627, 59.98846784234047, 53.418909162282944, 56.70752249658108, 59.62103895843029, 54.00088593363762, 36.19285270571709, 4.302008030936122, 0.29519232572056353, 2.744577289558947, 0.6303820770699531, 8.768813218921423, 53.76790903508663, 61.45070157945156, 59.30546969175339, 68.9021435379982, 56.93079471588135, 53.97907890379429, 7.6722371857613325, 30.47692772001028, 17.046233005821705, 25.744815543293953, 25.328756868839264, 39.28799942135811, 39.248139560222626, 18.428520932793617, 49.07474286854267, 65.34688711166382, 37.23789922893047, 0.34691829700022936, 0.10779073825688101, 0.11615313953370787, 0.04888386851234827, 0.06321482549537905, 0.14961462642531842, 0.05071961903013289, 0.08078889732132666, 0.016234441463893745, 0.19578976352931932, 0.14874474029056728, 0.1418609346728772, 0.10898888373048976, 0.15732163708889857, 0.10793184279464185, 0.15160181588726118, 0.3012476273579523, 0.12584427458932623, 0.40034458797890693, 0.31392416276503354, 0.7918130897451192, 0.5471695109736174, 13.464355207979679, 94.51170533895493, 79.12754684686661, 68.42655345797539, 52.00095824897289, 84.26889136433601, 56.23027190566063, 25.582626946270466, 45.86614944040775, 20.645977444946766, 22.783756032586098, 77.29397803544998, 82.63472825288773, 78.48574608564377, 54.880835115909576, 72.99861252307892, 20.568036027252674, 2.9271681793034077, 17.15876206755638, 1.23022471787408, 0.426005739136599, 28.17904282361269, 66.99890926480293, 69.24508273601532, 65.97889199852943, 63.144517689943314, 73.25892895460129, 69.21254888176918, 75.00713154673576, 68.36617469787598, 68.0493400990963, 61.78620457649231, 67.56902307271957, 63.452821746468544, 68.46908837556839, 64.00283083319664, 64.90766108036041, 65.08711785078049, 56.64291076362133, 55.98650738596916, 62.69624054431915, 57.70949073135853, 64.3558394908905, 63.96751552820206, 63.651630878448486, 60.57899035513401, 53.03800620138645, 54.70070958137512, 55.97591735422611, 57.4575300514698, 60.73888197541237, 58.40592496097088, 59.93246644735336, 46.505670323967934, 50.407133772969246, 49.0545317530632, 49.740436747670174, 51.230051815509796, 52.34073221683502, 57.17533439397812, 47.702613696455956, 48.320874720811844, 50.319366082549095, 56.417077481746674, 60.408656895160675, 60.72410836815834, 55.63788749277592, 56.285741329193115, 52.173054814338684, 48.2035294175148, 44.709590300917625, 43.776557967066765, 45.436320304870605, 50.20273894071579, 51.329180896282196, 51.804588586091995, 52.236564606428146, 22.08482913672924, 6.430029217153788, 33.2849333435297, 50.92998571693897, 48.328542709350586, 49.65353161096573, 42.251418605446815, 47.89093919098377, 58.88574801385403, 59.98268075287342, 54.39223073422909, 57.389813885092735, 56.14693097770214, 51.37554220855236, 50.64196117222309, 49.78728823363781, 48.24928276240826, 49.9984011054039, 50.69641225039959, 48.758561834692955, 49.40003201365471, 45.4256846755743, 41.6192427277565, 44.67844717204571, 48.15913259983063, 56.091073974967, 55.67676700651646, 57.7851826697588, 51.626199558377266, 57.177861258387566, 58.18445384502411, 56.35517880320549, 52.807396575808525, 50.598719492554665, 42.984323278069496, 48.239471688866615, 47.800070866942406, 48.72176080942154, 51.932375729084015, 50.4509986191988, 56.1843703687191, 64.92219150066376, 64.62797328829765, 62.906403467059135, 60.00618629157543, 60.39355270564556, 57.63149231672287, 63.35833981633186, 63.039137944579124, 64.33656692504883, 56.104350462555885, 57.15992622077465, 60.75890310108662, 53.59716139733791, 46.62142351269722, 8.944591786712408, 0.6598971714265645, 13.461139630526304, 5.509241251274943, 7.6600322406739, 56.208563670516014, 66.74175426363945, 56.56692624092102, 72.8373871743679, 59.14645962417126, 65.45896589756012, 11.578408107161522, 29.918437488377094, 26.983142495155334, 27.00262974947691, 48.632351607084274, 59.5537331700325, 44.831502959132195, 28.99108584970236, 61.37309834361076, 74.9653185904026, 55.35628840327263, 0.703279502922669, 0.2395316062029451, 0.2290399683988653, 0.13373971654800698, 0.162927909696009, 0.34039936086628586, 0.17317573714535683, 0.19084288913290948, 0.18661295907804742], [0.031177416094578803, 0.09489605596172623, 0.025846114767773543, 0.041184286747011356, 0.026407178411318455, 0.037436808343045413, 0.060306456362013705, 0.029871091464883648, 0.02384326042374596, 0.028328411353868432, 0.05157785715709906, 0.20866725768428296, 0.06383227751939557, 1.03774604620412, 44.67463977634907, 61.476927772164345, 43.428979218006134, 23.68589412420988, 44.71524439752102, 54.91045452654362, 24.68581046909094, 28.42715810984373, 13.177842032164335, 7.877964796498418, 39.72212612628937, 69.29817348718643, 73.82252991199493, 65.208810120821, 53.9038011431694, 49.01671998202801, 2.329202340915799, 4.354417193681002, 4.800943108275533, 0.3267079236684367, 2.0218643825501204, 36.765820160508156, 55.53435444831848, 51.244456842541695, 63.24455872178078, 55.07738336920738, 59.77614663541317, 63.461663872003555, 62.80538208782673, 60.25090076029301, 60.35749264061451, 63.02406035363674, 60.73065921664238, 61.004768908023834, 61.433100923895836, 58.33580732345581, 58.05900737643242, 60.169657319784164, 61.69196963310242, 60.4074751585722, 56.35470762848854, 59.50101479887962, 61.303744465112686, 59.646281003952026, 50.834082663059235, 50.43561324477196, 48.42972747981548, 47.988715544342995, 51.635262072086334, 51.744810193777084, 51.75761930644512, 51.84922859072685, 46.36693976819515, 42.84518614411354, 44.59638297557831, 43.77231739461422, 46.01509764790535, 48.238647133111954, 48.94415147602558, 49.187011644244194, 44.108375161886215, 42.824952229857445, 49.094254821538925, 47.91164427995682, 45.66824086010456, 41.83665186166763, 34.742512330412865, 30.932361781597137, 22.68602717667818, 19.895002841949463, 21.055825352668762, 23.76858338713646, 24.811049848794937, 30.818103812634945, 27.59558793157339, 31.80135615170002, 9.008929934352636, 5.690550422295928, 17.666281834244728, 23.508819825947285, 26.039339639246464, 25.885949470102787, 24.769202694296837, 30.359983295202255, 41.275262385606766, 43.55613939464092, 49.6220389008522, 51.688128635287285, 51.68269872665405, 47.356467470526695, 44.1906825453043, 43.97506311535835, 46.55176565051079, 47.99468882381916, 46.184120178222656, 44.349981397390366, 41.6543148458004, 42.56004184484482, 38.88819247484207, 39.842511266469955, 41.3027311116457, 46.22295029461384, 44.62277635931969, 51.777800023555756, 50.220366194844246, 52.20370016992092, 50.66422417759895, 56.203984916210175, 55.51183305680752, 50.3261449187994, 48.07720519602299, 51.86641126871109, 47.84037910401821, 48.78347709774971, 54.89353023469448, 54.28335137665272, 57.14302472770214, 60.491192266345024, 57.20937676727772, 57.86978133022785, 55.19037790596485, 51.05333849787712, 51.43750548362732, 56.83611519634724, 55.5836796015501, 60.07628872990608, 54.81823347508907, 49.49124611914158, 49.012464210391045, 34.423052072525024, 12.295747864991426, 0.08793051762040704, 0.19303934939671308, 2.6047906279563904, 6.218934869393706, 27.65053678303957, 55.69183699786663, 54.31175485253334, 60.015982165932655, 48.99272046983242, 67.58046805858612, 22.95476585626602, 7.191410036757588, 53.009557127952576, 18.546331711113453, 23.293215595185757, 38.479938581585884, 34.388074949383736, 22.98369560390711, 36.77432030439377, 44.62103225290775, 60.78570306301117, 11.168127972632647, 0.1740858328412287, 0.18089128250721842, 0.17483323492342606, 0.08110900045721792, 0.03311810258310288, 0.11066801511333324, 0.025278054527007043, 0.042515736786299385, 0.10412306670332327, 0.02967419226479251, 0.025981000108004082, 0.06110056921897922, 0.03377593857294414, 0.10882986374781467, 0.05012770059693139, 0.017793547158362344, 0.024298096759594046, 0.07135881271096878, 0.1547288551228121, 0.018715250043896958, 0.12092835517250933, 0.04967578832292929, 1.0223094932734966, 51.83806098997593, 71.64079338312149, 46.750673577189445, 27.751675955951214, 62.76160083711147, 39.14370596408844, 23.30536924302578, 39.27671782672405, 24.920166693627834, 10.532560776919127, 43.305033668875694, 72.95859307050705, 74.1350631415844, 66.45816788077354, 61.831950321793556, 60.76901815831661, 5.530012836679816, 2.9305053502321243, 3.1238465756177902, 0.11484967588330619, 1.7938192631118, 44.992074742913246, 59.208020120859146, 57.029965594410896, 66.29582539200783, 59.4194445759058, 62.323066368699074, 64.98082235455513, 64.43822667002678, 64.42840799689293, 60.92734046280384, 63.166609704494476, 63.22830319404602, 63.036763072013855, 63.16292770206928, 60.75663462281227, 61.79076433181763, 62.85692252218723, 63.42286795377731, 62.41323933005333, 58.84733967483044, 59.20010894536972, 62.083227038383484, 59.59522694349289, 53.57723146677017, 52.890961691737175, 50.4983326792717, 52.183010280132294, 53.58749471604824, 56.47440120577812, 54.315790235996246, 55.06285294890404, 47.561979442834854, 46.225313767790794, 45.853750705718994, 44.65820945799351, 50.10016344487667, 51.17212772369385, 53.97200368344784, 49.43706102669239, 47.82490633428097, 47.09444873034954, 54.205273166298866, 55.59463821351528, 51.96463979780674, 52.228733226656914, 46.06250770390034, 44.79341760277748, 37.381930500268936, 31.189784668385983, 30.488441102206707, 33.65056872367859, 36.85163855552673, 39.47504438459873, 39.90152209997177, 41.66651599109173, 16.016070283949375, 18.025168776512146, 48.04766558110714, 33.521474450826645, 39.80930104851723, 34.85240623354912, 35.60590960085392, 41.036760583519936, 50.052867382764816, 50.52044749259949, 55.75418405234814, 55.00694274902344, 54.35739420354366, 50.65315157175064, 46.63737125694752, 49.556165635585785, 51.904850006103516, 52.88062624633312, 51.74095340073109, 50.50714820623398, 45.07535107433796, 44.60688941180706, 42.29632079601288, 44.07777540385723, 44.97830048203468, 48.84159117937088, 46.49138689041138, 53.2575698196888, 52.5784170627594, 52.36722819507122, 53.8347702473402, 58.238859325647354, 54.86040361225605, 51.85393653810024, 49.97274488210678, 53.25255788862705, 49.31120038032532, 52.918384820222855, 56.438679322600365, 55.6315266340971, 58.21698009967804, 62.52364240586758, 60.186019241809845, 59.084226563572884, 56.10580958425999, 54.85716238617897, 54.9848697334528, 60.73128618299961, 57.36403986811638, 62.6645502448082, 55.63763290643692, 52.28718549013138, 48.68921935558319, 36.93561024963856, 15.56829946115613, 0.6035406142473221, 0.2301582068321295, 3.0567103531211615, 11.4755305275321, 37.322022914886475, 59.07083608210087, 59.68168370425701, 64.2136587202549, 56.48788668215275, 69.32283416390419, 20.301503129303455, 15.820460580289364, 57.723679170012474, 19.590329490602016, 26.689938828349113, 23.132241033017635, 43.912499472498894, 37.351786717772484, 28.382366113364697, 50.40253981947899, 64.02460366487503, 13.892947509884834, 0.3803447767859325, 0.15289229195332155, 0.09543492938973941, 0.054344873133231886, 0.06011847777699586, 0.0148978604011063, 0.05544512561755255, 0.05415520987298805, 0.07379067479632795, 0.12832767883082852, 0.12405277462676167, 0.14736723998794332, 0.14046269876416773, 0.3069750778377056, 0.23462722718250006, 0.21964880201267079, 0.11401741663576104, 0.1832030576770194, 0.35734101897105575, 0.131007440504618, 0.45942191791255027, 0.16845879494212568, 2.4830465856939554, 72.03561499714851, 77.76261448860168, 63.933195769786835, 28.432779908180237, 75.30932933092117, 72.60384410619736, 28.76918725669384, 38.05694907903671, 20.786944180727005, 12.965534124523401, 49.78438138961792, 70.09802296757698, 79.38511222600937, 71.09753653407097, 67.54515275359154, 59.20409493148327, 4.737754873931408, 14.917654674500227, 14.716263581067324, 0.19477680616546422, 4.607866918668151, 57.01139219105244, 63.067985996603966, 62.33839854598045, 75.05781322717667, 64.70456197857857, 67.61641412973404, 69.88036304712296, 70.72315022349358, 65.29618263244629, 66.85884118080139, 67.37614542245865, 65.90017542243004, 64.77412104606628, 66.05735018849373, 60.92699848115444, 62.08389960229397, 65.29907807707787, 67.17898160219193, 65.24625331163406, 61.10874652862549, 61.25079430639744, 63.98657530546188, 65.29489830136299, 55.10975383222103, 54.687961265444756, 53.59378717839718, 54.028195068240166, 56.93155847489834, 59.118390530347824, 59.469237104058266, 57.49569520354271, 50.90367592871189, 51.11269511282444, 51.47228121757507, 47.76744581758976, 54.02089945971966, 55.040931925177574, 56.16675831377506, 53.14192682504654, 48.934439197182655, 49.24307003617287, 60.26282072067261, 58.7937131524086, 56.20320215821266, 58.93307447433472, 52.8407321870327, 53.75117093324661, 47.03945808112621, 41.44493468105793, 45.6780519336462, 49.37422379851341, 49.04817849397659, 54.36810962855816, 49.88422483205795, 55.76720595359802, 17.37036321312189, 9.804738331586123, 54.22230005264282, 49.51152563095093, 54.18837167322636, 45.23973785340786, 42.89152845740318, 47.48798981308937, 57.48718746006489, 56.81304283440113, 58.96769441664219, 56.04070007801056, 56.30809932947159, 51.7348775267601, 48.76952424645424, 47.43770711123943, 50.78582525253296, 52.00861103832722, 49.38226416707039, 50.35047881305218, 46.15060977637768, 47.42534637451172, 44.02455545961857, 45.569142177700996, 46.524030938744545, 51.38808913528919, 48.939610719680786, 57.698794305324554, 55.69363050162792, 55.2730842679739, 54.565459638834, 61.489809080958366, 57.37497188150883, 54.89539973437786, 48.84788744151592, 53.476757258176804, 48.941780403256416, 52.8931275755167, 57.6593030244112, 56.40021398663521, 61.050560250878334, 64.84546601772308, 63.16645011305809, 61.29822716116905, 57.6970349997282, 60.06038658320904, 58.119587525725365, 64.54216629266739, 60.59916727244854, 67.32029601931572, 56.31022721529007, 55.918491035699844, 52.319863736629486, 42.88620874285698, 23.01449105143547, 0.5223357654176652, 0.34595757198985666, 10.130762737244368, 9.303769413381815, 35.290184542536736, 64.40815508365631, 62.43658907711506, 69.5611421763897, 61.6777203977108, 78.99412840604782, 31.96948193013668, 12.359232008457184, 65.3731133043766, 25.52063327282667, 30.90567011386156, 50.1299424469471, 55.39775937795639, 35.3645883500576, 48.0086986720562, 59.99099090695381, 79.53061401844025, 27.025810405611992, 0.8398685767315328, 0.31542882265057415, 0.5260902608279139, 0.25006588781252503, 0.18978990032337606, 0.20556576317176223, 0.2172658548806794, 0.13884205603972077, 0.26333168847486377], [0.01900547431432642, 0.06722097576130182, 0.058158391548204236, 0.0748301565181464, 0.01829096978326561, 0.06254928230191581, 0.03763043838262092, 0.05061704679974355, 0.03468082068138756, 0.050235037415404804, 0.045761905566905625, 0.12080345914000645, 0.1914742638473399, 0.22033999382983893, 28.93793050199747, 71.3332986831665, 47.87306495010853, 30.61992734670639, 30.477695278823376, 50.63763700425625, 32.89671577513218, 29.07223429530859, 15.27920812368393, 3.1671751756221056, 15.454191584140062, 54.1149216145277, 62.20284461975098, 73.0938658118248, 51.714316830039024, 53.01275655627251, 32.33584687113762, 1.338298637419939, 3.7469777511432767, 0.5266615957953036, 0.24341050040675327, 3.8773910282179713, 25.086850449442863, 37.049683928489685, 48.61133873462677, 62.109365835785866, 60.50338201224804, 61.260506585240364, 63.225202560424805, 60.99765948951244, 64.69516888260841, 63.8152576982975, 60.70705488324165, 63.71244661509991, 65.56713089346886, 60.96095725893974, 60.29742546379566, 58.035061061382294, 58.40886980295181, 55.59184916317463, 63.209330812096596, 59.35034528374672, 61.087030693888664, 57.130002826452255, 51.41995042562485, 48.26231226325035, 47.2498831897974, 48.09704773128033, 52.145871073007584, 51.97488784790039, 52.25268334150314, 46.48449786007404, 43.308001309633255, 43.467797935009, 44.31378073990345, 44.694961085915565, 46.44762083888054, 46.41434222459793, 50.96208639442921, 49.90461453795433, 45.11720962822437, 45.793417543172836, 51.274239644408226, 52.016548812389374, 43.597165793180466, 39.946013912558556, 34.515330120921135, 29.3024430423975, 24.72369633615017, 24.302504137158394, 24.707262217998505, 28.10310959815979, 30.03869343549013, 33.041537404060364, 35.01792915165424, 35.69019667804241, 11.722228489816189, 4.727588044479489, 27.785300351679325, 28.572530709207058, 29.76796366274357, 27.700069025158882, 26.57944455742836, 29.279262386262417, 41.92960247397423, 44.01431880891323, 48.04200388491154, 49.20664519071579, 55.15985794365406, 47.542969062924385, 44.029730781912804, 46.41146577894688, 49.16095644235611, 47.859495878219604, 49.36402514576912, 47.03754298388958, 43.607448041439056, 42.87075117230415, 39.4881346821785, 39.456489980220795, 38.69163282215595, 42.09709748625755, 44.12633679807186, 49.31474179029465, 47.617889642715454, 48.8953772932291, 53.749012649059296, 51.844969019293785, 53.746269196271896, 53.4804430603981, 46.79007366299629, 45.20822234451771, 46.08519248664379, 53.15079554915428, 53.640612065792084, 55.39948828518391, 53.53367820382118, 58.40195797383785, 56.65876351296902, 58.193839341402054, 55.91175019741058, 56.215380504727364, 53.182740435004234, 56.74721896648407, 54.82193447649479, 60.452681332826614, 43.97919349372387, 50.84512487053871, 28.82015962153673, 27.98842415213585, 2.3929479578509927, 0.5956425599288195, 3.2039415277540684, 16.418329998850822, 48.92597325146198, 59.73891623318195, 54.916644394397736, 48.86174909770489, 48.74091558158398, 53.833117336034775, 27.81562652438879, 1.7211820045486093, 34.81236018240452, 43.572915494441986, 10.263610258698463, 29.299885779619217, 38.96109156310558, 34.284332916140556, 13.16301902756095, 21.049738079309464, 50.43975502252579, 47.276641353964806, 3.108210889622569, 0.33694133860990405, 0.010405432713014307, 0.15232552861562, 0.09679158276412636, 0.058521138489595614, 0.09062167868250981, 0.06702461090753786, 0.1300224324222654, 0.032015686738304794, 0.035424204033915885, 0.05144576229213271, 0.01592751701537054, 0.03151149387122132, 0.029825514320691582, 0.11791980723501183, 0.1127319352235645, 0.04593187593854964, 0.06067185277061071, 0.031533409492112696, 0.029480209705070592, 0.070689759158995, 0.25436241819988936, 0.1986489468254149, 34.66469630599022, 82.47768267989159, 53.87073151767254, 25.00306684523821, 49.56496596336365, 38.57303738594055, 26.46691169589758, 38.448632061481476, 26.26131422817707, 7.8519775159657, 13.780530542135239, 56.62519611418247, 69.66765806078911, 79.89487007260323, 57.13044360280037, 56.760978028178215, 42.3420437425375, 5.117908325046301, 1.6097270976752043, 0.558429672382772, 0.3963353578001261, 4.054147806018591, 30.00127114355564, 45.151590183377266, 50.52979879081249, 64.43006470799446, 61.55676908791065, 61.8738354742527, 65.61515271663666, 64.23768103122711, 64.39818441867828, 68.82617801427841, 65.1595951616764, 67.57995128631592, 64.96886819601059, 63.94643425941467, 66.03088840842247, 62.19050668179989, 60.530261769890785, 57.61337108910084, 63.235621601343155, 60.95042422413826, 60.79513035714626, 60.288416147232056, 55.93765340745449, 50.95371924340725, 50.3865122795105, 52.88092643022537, 54.982415065169334, 54.77645471692085, 54.38568748533726, 49.42125007510185, 44.60316941142082, 44.10418778657913, 46.265960186719894, 45.92596963047981, 49.20738235116005, 51.37091785669327, 53.17220360040665, 50.629877820611, 47.74351470172405, 48.74259889125824, 55.812339931726456, 57.1240409463644, 53.15905250608921, 48.811006620526314, 44.6692630648613, 42.831788063049316, 35.632625967264175, 34.77783143520355, 34.24210578203201, 37.69903488457203, 40.212683603167534, 42.62384042143822, 43.92070323228836, 41.56038388609886, 19.257784634828568, 33.60368683934212, 43.75473953783512, 37.986470460891724, 41.14421121776104, 38.58855955302715, 37.30380669236183, 40.48110119998455, 50.797141045331955, 51.10184669494629, 54.57289583981037, 55.3983673453331, 57.6091343164444, 50.11563241481781, 48.258979842066765, 49.29525263607502, 50.594604313373566, 53.147504925727844, 50.83479702472687, 49.955983981490135, 46.661002188920975, 44.030760526657104, 42.678523287177086, 43.29323910176754, 40.837069898843765, 45.54707296192646, 46.124470978975296, 50.514341220259666, 49.77944165468216, 48.558407574892044, 55.844402611255646, 52.902022898197174, 55.383700132369995, 53.41539055109024, 46.59982167184353, 45.34332409501076, 48.19381333887577, 52.85686992108822, 53.521803840994835, 55.41365772485733, 53.59338819980621, 60.3692340105772, 57.56110869348049, 58.89196828007698, 55.373752266168594, 57.82020539045334, 56.25059321522713, 63.059041276574135, 54.66196306049824, 61.41209565103054, 46.72280587255955, 55.96235208213329, 31.76682360470295, 37.36596755683422, 1.1452745762653649, 0.4383989522466436, 6.421980299055576, 24.54189319163561, 57.174901217222214, 66.86914622783661, 58.006805777549744, 54.028263464570045, 56.611991822719574, 58.277997225522995, 20.258531235158443, 7.581432033330202, 50.823192447423935, 42.47608534991741, 13.972823973745108, 23.00974700599909, 26.00656069815159, 48.02772045135498, 14.630180150270462, 22.256065048277378, 57.36082524061203, 51.3556844741106, 4.968012543395162, 0.07149322307668626, 0.09422200033441186, 0.09259158352506347, 0.06985918458667584, 0.022589079089812003, 0.10180082725128159, 0.06476819253293797, 0.04435550974449143, 0.07737365245702676, 0.14120308012934402, 0.16217169089941308, 0.10484168829862028, 0.11705909404554404, 0.09186006340314634, 0.1714833138976246, 0.21930974442511797, 0.29754341987427324, 0.1378948678029701, 0.14058720145840198, 0.27127180772367865, 0.24339087802218273, 0.37064205680508167, 0.2314174236380495, 49.98523861169815, 92.36472174525261, 66.16904139518738, 36.389659345149994, 52.2527327388525, 74.76510733366013, 37.784233912825584, 39.91266310214996, 21.85899395495653, 7.191753918305039, 23.211322389543056, 67.79356062412262, 70.81148788332939, 83.88341724872589, 59.47530537843704, 73.31457316875458, 46.89701892435551, 4.425639621913433, 12.364936452358961, 0.7459772180300206, 0.4415366338798776, 11.012563370168209, 43.280988559126854, 53.11697356402874, 57.52820245921612, 67.19037339091301, 63.396998941898346, 67.40380793809891, 68.29229146242142, 67.54839017987251, 68.73841792345047, 69.37968671321869, 65.32629981637001, 68.36219251155853, 69.43789958953857, 64.77866560220718, 67.17183038592339, 64.51738402247429, 64.35640946030617, 59.77605544030666, 67.64293670654297, 64.79397878050804, 66.01827308535576, 65.06649255752563, 57.22424536943436, 51.19218684732914, 52.94506698846817, 54.18848566710949, 60.068746134638786, 58.05011585354805, 60.090192183852196, 51.549192890524864, 46.47552654147148, 49.2272324860096, 48.93972471356392, 49.65278685092926, 52.727080285549164, 53.37960407137871, 56.700762659311295, 53.72651405632496, 48.486257046461105, 51.45265907049179, 59.88874599337578, 62.71699883043766, 58.44743773341179, 56.89496263861656, 52.14728459715843, 53.175779208540916, 45.518316105008125, 44.11433704197407, 45.4184802621603, 50.18880508840084, 52.211455553770065, 52.69150659441948, 54.05116483569145, 48.94507482647896, 28.029368855059147, 33.62254522740841, 55.91767027974129, 50.58443605899811, 55.00204101204872, 49.979865700006485, 44.930202662944794, 45.859564393758774, 59.46585528552532, 57.02097147703171, 57.615487575531006, 56.65058635175228, 61.13215707242489, 50.06638325750828, 47.78740994632244, 49.54856984317303, 49.91458140313625, 51.111285388469696, 49.93628203868866, 51.603055000305176, 49.94595251977444, 46.86359591782093, 43.43353897333145, 44.260670989751816, 43.23525421321392, 47.869922518730164, 49.52442593872547, 54.10324864089489, 52.1132992208004, 54.66824032366276, 58.30803081393242, 56.49987503886223, 57.312301844358444, 53.92504960298538, 46.9097026437521, 45.57226940989494, 47.45167896151543, 54.32708702981472, 53.72695483267307, 58.73998783528805, 55.77053837478161, 65.45787155628204, 59.58327278494835, 61.35748878121376, 59.37952011823654, 62.16527983546257, 58.03040251135826, 65.32703697681427, 59.07891824841499, 66.93294480443001, 48.64391818642616, 63.94993767142296, 37.24464386701584, 45.41125684976578, 4.667080566287041, 1.0916713275946677, 5.315465424209833, 22.96029455959797, 60.06046637892723, 70.34555688500404, 62.81336925923824, 57.8504441678524, 58.270614221692085, 64.36297550797462, 35.46608850359917, 5.792846158146858, 43.76876078546047, 58.11658948659897, 15.113418269902468, 37.12915286421776, 54.16323222219944, 58.499692529439926, 17.815779112279415, 33.63269068300724, 65.0027547776699, 74.2109602689743, 8.740787822753191, 0.46527924423571676, 0.18963075417559594, 0.3163186280289665, 0.22239960206206888, 0.148492231965065, 0.1880961115239188, 0.2364106525783427, 0.19097022683126852, 0.24710388737730682], [0.04137106676353142, 0.027880133748112712, 0.02672202343092067, 0.06163759098853916, 0.04854792794503737, 0.037574165035039186, 0.016073378719738685, 0.07447687195963226, 0.06724842780386098, 0.06965295659028925, 0.09527072921628132, 0.1665601140120998, 0.19798257242655382, 0.3474429063498974, 11.192835196852684, 67.85162150859833, 55.000019520521164, 42.55050055682659, 29.73409228026867, 51.4992331713438, 54.6961460262537, 19.264597669243813, 45.591469779610634, 17.03911978751421, 2.7325675589963794, 23.402794115245342, 62.17605985701084, 72.23616823554039, 56.3183967769146, 57.704539597034454, 70.53032577037811, 56.48825526237488, 25.64903788268566, 2.253900831565261, 0.11177020089235157, 0.1674936615745537, 3.537197895348072, 12.551829423755407, 31.7405841127038, 37.46408589184284, 45.72011947631836, 52.23013535141945, 58.82544904947281, 63.995383232831955, 64.88841131329536, 65.22919222712517, 64.22028556466103, 61.49654231965542, 63.90750914812088, 60.69901071488857, 58.55158634483814, 57.580689042806625, 58.78334730863571, 59.148568511009216, 59.50161136686802, 59.89014811813831, 61.24487042427063, 56.227729842066765, 49.87774237990379, 47.11538940668106, 47.744031473994255, 48.197331950068474, 50.80616556107998, 49.500753208994865, 50.555929988622665, 42.14761957526207, 43.72971408069134, 44.341697841882706, 43.70917618274689, 48.25604259967804, 51.56592719256878, 50.39460964500904, 50.576414689421654, 49.03578735888004, 44.23457399010658, 49.54499423503876, 48.46432842314243, 45.38646697998047, 40.66032998263836, 37.115857377648354, 35.917356088757515, 29.468353539705276, 23.974085859954357, 25.70662759244442, 27.73275677114725, 33.98169815540314, 34.872339963912964, 34.641908928751945, 37.94534146785736, 32.997300177812576, 26.3122333958745, 26.26032628118992, 35.49931392073631, 32.272291481494904, 32.15504877269268, 29.588947668671608, 25.854650549590588, 31.992953270673752, 38.04436415433884, 42.81020142138004, 48.1428162753582, 51.86622887849808, 53.732624128460884, 47.8233902156353, 42.624626979231834, 46.132693737745285, 48.248363211750984, 51.66415952146053, 50.35900175571442, 47.15977102518082, 45.7165514677763, 44.68091703951359, 41.932961493730545, 41.03327617049217, 40.416972041130066, 40.89924976229668, 41.98856770992279, 44.131417125463486, 45.33913291990757, 47.818275690078735, 49.33093652129173, 51.903124898672104, 55.13478308916092, 53.009530529379845, 51.13291382789612, 50.7454714179039, 54.07508075237274, 53.04321572184563, 54.27303873002529, 52.48051531612873, 56.07036128640175, 53.48621115088463, 59.336141645908356, 56.21643304824829, 57.46698774397373, 53.27413693070412, 57.78234042227268, 52.69947096705437, 54.913866743445396, 53.30857068300247, 62.5252041220665, 29.798907302320004, 27.820408567786217, 10.681072007864714, 0.2302238275296986, 4.282604847103357, 36.32730469107628, 53.71549844741821, 51.89837135374546, 51.92066475749016, 44.87039767205715, 52.56567254662514, 56.48999936878681, 35.28849743306637, 2.486785347573459, 15.499761588871479, 70.71694895625114, 31.77249290049076, 14.220805317163467, 36.94707043468952, 39.657123014330864, 26.569863371551037, 35.964975133538246, 36.806097999215126, 49.214016795158386, 31.234675459563732, 0.9395265416242182, 0.04858625245105941, 0.024426933596259914, 0.1263924693921581, 0.0739809317747131, 0.02230346541182371, 0.023232070270751137, 0.1057867391500622, 0.03226881104637869, 0.07880265038693324, 0.0625704854610376, 0.0033656095638434635, 0.04965223997714929, 0.03822841645160224, 0.09343989542685449, 0.014998132901382633, 0.007695652557231369, 0.020569988409988582, 0.05241839506197721, 0.06907071947352961, 0.1503075400250964, 0.08344767105882056, 0.4611058806767687, 0.2584796160226688, 13.01274374127388, 72.89016634225845, 67.16182172298431, 30.69249965250492, 35.38501225411892, 56.093289256095886, 28.98865208029747, 25.104234516620636, 40.02169445157051, 32.244218587875366, 4.195544393733144, 18.997988775372505, 63.44665847718716, 81.16936728358269, 59.02668245136738, 62.759921327233315, 70.7332044839859, 59.9858383834362, 32.903650403022766, 3.3930550049990416, 0.13504965172614902, 0.4628719843458384, 2.734825350344181, 17.04371754080057, 43.35843600332737, 39.97839197516441, 47.1133679151535, 53.49403113126755, 63.824909180402756, 67.42417484521866, 65.11794939637184, 63.101025223731995, 68.41797351837158, 64.0992620587349, 67.69134610891342, 63.76678749918938, 63.361075669527054, 63.47634248435497, 60.801658406853676, 60.601838529109955, 61.39702565968037, 62.46177792549133, 64.37754392623901, 56.22642271220684, 53.60353745520115, 50.33431828022003, 51.52116559445858, 50.98498396575451, 54.25516448915005, 52.598719373345375, 52.41181880235672, 45.13300158083439, 44.98398497700691, 46.7460910230875, 45.96681363880634, 52.44200058281422, 54.561922028660774, 53.01884762942791, 52.71269425749779, 50.305576622486115, 47.56020873785019, 52.15802662074566, 55.99458195269108, 52.762718573212624, 50.63666045665741, 50.53785055875778, 46.3748699426651, 41.64240628480911, 34.53966021537781, 36.519000604748726, 37.84664176404476, 42.90488854050636, 43.67654733359814, 44.974348694086075, 46.5467993170023, 40.69130212068558, 28.976808115839958, 25.161003470420837, 45.21705687046051, 42.914692014455795, 44.71231855452061, 40.591192692518234, 35.459784641861916, 43.41382183134556, 49.83975201845169, 51.11863039433956, 53.311162143945694, 55.445614010095596, 57.34826311469078, 52.08913631737232, 44.62924741208553, 49.463819190859795, 51.96562394499779, 55.15373267233372, 54.004757925868034, 53.67826424539089, 48.628099635243416, 47.616407722234726, 44.66492369771004, 45.46517215669155, 43.8012870401144, 44.37655717134476, 44.09021973609924, 46.80513225495815, 49.17336657643318, 48.66145424544811, 52.30806536972523, 52.21514895558357, 58.666830360889435, 54.45587731897831, 53.34450915455818, 51.48750700056553, 55.92928245663643, 54.227000400424004, 54.89745922386646, 52.272537276148796, 56.59468375146389, 52.90854714810848, 61.33981212973595, 57.36114822328091, 57.96686232089996, 53.714658692479134, 60.06967328488827, 53.58424589037895, 58.217010498046875, 58.75267155468464, 62.99710839986801, 34.489715695381165, 32.39720977842808, 7.207510722801089, 0.25459064345341176, 6.5354863833636045, 45.29917426407337, 58.92623484134674, 57.0952232927084, 55.830252170562744, 51.875659972429276, 59.422089233994484, 62.38346792757511, 32.786229103803635, 4.418264217674732, 23.11100397258997, 69.1365073621273, 34.95283864438534, 19.55514907836914, 24.06276550143957, 33.819325268268585, 42.99207866191864, 24.534926265478134, 39.358288049697876, 58.236153870821, 33.744875863194466, 1.6410578414797783, 0.06513942964375019, 0.10505738609936088, 0.029507812032534275, 0.046908148942748085, 0.030218852589314338, 0.013284160468174377, 0.08798327689873986, 0.038386772212106735, 0.16640117566566914, 0.13131552084814757, 0.09492960103671066, 0.11598208191571757, 0.11514252735651098, 0.2057597308885306, 0.08457410280243494, 0.09363271281472407, 0.21857319254195318, 0.18528163520386443, 0.10979093014611863, 0.2161500952206552, 0.22238133038626984, 0.5740876228082925, 0.5281144834589213, 21.785874478518963, 88.01639467477798, 74.93004128336906, 54.59742732346058, 41.52987152338028, 85.71689486503601, 63.185730278491974, 28.78649912774563, 52.03545279800892, 31.2859708070755, 4.3162558414042, 30.622832290828228, 70.70965334773064, 84.4546177983284, 64.92023840546608, 72.75347247719765, 77.56523787975311, 71.65416866540909, 33.3944358676672, 3.6037574987858534, 0.1991400556289591, 0.31702055130153894, 7.30650301091373, 31.381898559629917, 54.93737608194351, 52.59518936276436, 53.21943126618862, 60.076034143567085, 66.09920874238014, 73.63277569413185, 70.04095003008842, 68.32595765590668, 67.62968301773071, 64.21731412410736, 69.52398777008057, 67.03397378325462, 63.89615535736084, 64.99659910798073, 63.44195052981377, 64.94922325015068, 68.29689681529999, 66.31870776414871, 69.98645335435867, 61.71688869595528, 55.23060254752636, 52.62998789548874, 54.2797339707613, 54.85612504184246, 57.202677726745605, 56.54386527836323, 57.81423591077328, 46.96441970765591, 48.9485402405262, 51.91566422581673, 49.87013138830662, 55.50728090107441, 59.56800140440464, 54.79885831475258, 54.665553867816925, 52.54164643585682, 49.13623496890068, 55.25564320385456, 58.93721245229244, 55.705596059560776, 53.94193209707737, 57.62583062052727, 54.902015179395676, 51.332429721951485, 42.58573606610298, 46.598814725875854, 47.08507463335991, 54.33016486465931, 54.44458432495594, 51.51121772825718, 53.11060890555382, 44.81003411114216, 40.524513870477676, 38.311600014567375, 54.48421999812126, 53.306507393717766, 53.747982904314995, 49.14956085383892, 41.843111515045166, 51.75179421901703, 55.501831993460655, 56.510522067546844, 56.51872582733631, 58.14863696694374, 58.6244398355484, 52.42676340043545, 46.41100600361824, 49.21678304672241, 52.26391173899174, 56.30197785794735, 55.51066271960735, 51.36730045080185, 50.497907102108, 50.15728957951069, 45.735953226685524, 46.18427976965904, 45.8489515632391, 46.38196416199207, 47.2188388556242, 49.650286585092545, 50.31401976943016, 51.180426478385925, 55.982555598020554, 55.87752923369408, 60.378224328160286, 56.44549995660782, 56.48531801998615, 52.529981061816216, 57.081312239170074, 55.349201783537865, 57.42180436849594, 55.28806306421757, 61.60796374082565, 55.49069099128246, 66.74532607197762, 61.08445443212986, 63.14436949789524, 57.90029749274254, 63.03267449140549, 56.390513107180595, 62.72652491927147, 60.79788900911808, 63.54737967252731, 36.3774847984314, 43.07398706674576, 15.343519672751427, 0.3654318832559511, 4.760935055091977, 45.96886172890663, 68.65110620856285, 62.42100991308689, 60.34099392592907, 57.53999702632427, 62.30786718428135, 66.17521226406097, 44.04736943542957, 7.656171647831798, 22.02070377767086, 82.34270632266998, 43.823523446917534, 22.572177685797215, 45.22493004798889, 57.43739493191242, 44.681274220347404, 45.324009731411934, 53.424939438700676, 65.80429896712303, 52.685689106583595, 2.357666613534093, 0.12188425622298382, 0.18432269134791568, 0.12014544132398441, 0.12092408040189184, 0.10893214654061012, 0.14665035501820967, 0.20583277306286618, 0.14565644116373733, 0.19416250084759668], [0.05510014569154009, 0.043158009939361364, 0.014364493708853843, 0.04550765690510161, 0.04182466000202112, 0.025153475762635935, 0.01587596929311985, 0.02395702053036075, 0.1473056714166887, 0.037329133847379126, 0.05474350291478913, 0.03086488286498934, 0.03286674829723779, 0.019952358270529658, 1.2675849068909883, 50.3083960711956, 56.566888242959976, 49.00182858109474, 36.75590269267559, 37.323094457387924, 59.0600598603487, 33.590136766433716, 57.01865740120411, 53.101705983281136, 8.959607630968094, 3.438769639469683, 37.82422676682472, 59.33654822409153, 72.20443233847618, 44.94023412466049, 52.354035302996635, 54.803665056824684, 63.4296315908432, 44.86471317708492, 0.8826971473172307, 0.1557080596103333, 0.33052146434783936, 1.0951673774980009, 4.887048862874508, 37.752197831869125, 63.795855939388275, 53.425437211990356, 55.44562540948391, 59.47787784039974, 64.49368849396706, 63.3131792396307, 59.3822255730629, 60.90962961316109, 64.13063317537308, 60.150517746806145, 59.58745256066322, 53.79902556538582, 49.61393393576145, 51.28198362886906, 55.748590752482414, 57.51627869904041, 57.96545259654522, 56.386815905570984, 50.78523628413677, 46.24211646616459, 46.72964930534363, 49.44039724767208, 47.400457710027695, 47.920972779393196, 45.772826448082924, 42.70918384194374, 44.364207834005356, 48.23352500796318, 50.14405108988285, 50.32111398875713, 51.27110481262207, 52.055679112672806, 52.07122787833214, 48.088676780462265, 44.12034071981907, 49.653930589556694, 49.862634390592575, 44.97988499701023, 41.95328280329704, 37.59477607905865, 33.59729178249836, 29.812584668397903, 24.826860800385475, 28.49234741181135, 33.85310545563698, 37.34057731926441, 38.01915630698204, 40.80633334815502, 38.70223045349121, 34.29323583841324, 29.42954622209072, 33.05221863090992, 37.11823605000973, 38.05995091795921, 35.681118965148926, 33.77064228057861, 26.839086525142193, 30.154634714126587, 40.05886785686016, 44.01658348739147, 48.38598422706127, 50.96441946923733, 53.87362316250801, 51.76849812269211, 41.9218622893095, 46.64787769317627, 50.15165448188782, 51.31199061870575, 50.82853876054287, 49.389643371105194, 48.25677216053009, 46.89554080367088, 44.479577243328094, 43.64608436822891, 41.22181445360184, 40.674381628632545, 40.971727073192596, 42.20410354435444, 43.9268247038126, 45.85793808102608, 46.02994725108147, 49.806458204984665, 55.12413986027241, 54.95797097682953, 53.36880885064602, 55.27159474790096, 52.84963510930538, 54.08229656517506, 51.601098105311394, 53.90073470771313, 48.29703859984875, 48.2794189453125, 57.381230145692825, 57.43234120309353, 57.23778784275055, 56.511278226971626, 52.24631868302822, 50.874599888920784, 53.53651285171509, 58.41318257153034, 34.92014139890671, 33.8658157736063, 7.548072198405862, 0.4685951303690672, 1.3768728612922132, 28.442879766225815, 57.681231647729874, 49.421508461236954, 59.6887893229723, 51.803387850522995, 58.20115774869919, 55.31078204512596, 50.27713134884834, 20.09384047240019, 6.508912984281778, 43.283690214157104, 75.98109528422356, 20.61074573546648, 11.659878585487604, 31.557998210191727, 34.46006588637829, 23.160047940909863, 31.698083393275738, 33.15479412674904, 55.902326703071594, 14.143508914858103, 0.3216179780429229, 0.064648098195903, 0.05809993999719154, 0.009613441470719408, 0.12366394861601293, 0.13980051007820293, 0.037624037358909845, 0.03941924063838087, 0.060062067132093944, 0.0599261873139767, 0.026356773596489802, 0.06999301607720554, 0.027133379189763218, 0.024554152550990693, 0.024030116510402877, 0.05891243214136921, 0.13154769432730973, 0.037437498540384695, 0.10155329131521285, 0.01684083734289743, 0.03740180494787637, 0.020412306148500647, 0.050615621876204386, 0.03161536114930641, 1.552471057511866, 52.93071135878563, 69.40239429473877, 47.64650970697403, 31.726270280778408, 57.092305049300194, 42.31747806072235, 32.93649964034557, 52.783412262797356, 52.39390656352043, 15.166710410267115, 4.0513768047094345, 41.90530277788639, 66.44984632730484, 76.58821150660515, 54.055591598153114, 57.39616334438324, 59.56887535750866, 69.68958288431168, 52.55791716277599, 2.265298794955015, 0.4441306774970144, 0.5144807556644082, 1.8920834152959287, 7.224978385493159, 45.360240787267685, 67.15499728918076, 56.683697775006294, 59.30052235722542, 61.920341178774834, 66.40307083725929, 68.25535744428635, 60.79101897776127, 64.37374413013458, 67.66470953822136, 61.86859555542469, 65.34016907215118, 57.732247710227966, 53.698916137218475, 56.06366604566574, 58.401163816452026, 60.80098204314709, 60.00303626060486, 59.61478069424629, 54.39981132745743, 48.47206100821495, 48.649709075689316, 50.06984867155552, 51.396452486515045, 50.00406660139561, 49.212481677532196, 42.346242517232895, 43.64791966974735, 49.08044636249542, 52.12508238852024, 53.22981230914593, 53.217307180166245, 57.073602452874184, 53.788937106728554, 50.21351516246796, 47.77510620653629, 52.56908856332302, 56.7065991461277, 52.46897533535957, 52.15823940932751, 48.415527641773224, 45.022568106651306, 41.26565270125866, 34.893736615777016, 35.5999743193388, 44.246991723775864, 46.58657178282738, 47.26703926920891, 47.32947751879692, 47.4678622931242, 39.87988606095314, 37.75907926261425, 37.19483993947506, 44.31226082146168, 48.16453590989113, 45.286604538559914, 43.51900398731232, 36.257517635822296, 39.925905391573906, 48.93266089260578, 52.09988974034786, 52.73245319724083, 56.805800423026085, 57.44658663868904, 53.04871402680874, 46.14160805940628, 46.99026212096214, 53.36225040256977, 55.20446375012398, 55.49620449542999, 53.19933034479618, 50.9681660681963, 50.30678115785122, 47.76886694133282, 47.123684361577034, 43.11336435377598, 42.85941258072853, 41.85093529522419, 44.8484842479229, 47.717147916555405, 47.82627806067467, 47.80018486082554, 52.312522530555725, 56.442418321967125, 56.59911051392555, 55.94318211078644, 55.71558952331543, 55.61714440584183, 55.53615555167198, 52.00112923979759, 54.644286409020424, 47.87739671766758, 48.213488683104515, 55.46541474759579, 58.15812885761261, 57.60614387691021, 57.5353916734457, 55.034939646720886, 55.38132905960083, 57.98769660294056, 56.60133719444275, 35.53973615169525, 42.25934877991676, 6.435369830578566, 0.9571542707271874, 3.0116545083001256, 34.27165299654007, 65.64076334238052, 55.256254971027374, 65.66890463232994, 56.81480213999748, 65.72133421897888, 57.207590863108635, 54.67251889407635, 21.886462680995464, 11.00932214409113, 48.96635748445988, 74.88866910338402, 26.918004490435123, 18.45297262072563, 23.010242879390717, 39.047916904091835, 34.99822720885277, 23.058458492159843, 37.224231362342834, 64.967500269413, 16.49607952684164, 0.42700018733739853, 0.056132012978196144, 0.1039769897761289, 0.028985781646042597, 0.014594859130738769, 0.026377548165328335, 0.028850766429968644, 0.03516493845381774, 0.006971109087317018, 0.011963947472395375, 0.18116540217306465, 0.09199165360769257, 0.12009733531158417, 0.13186070253141224, 0.1484798826277256, 0.12255862355232239, 0.21435673988889903, 0.1564765683724545, 0.2203743255813606, 0.18180848797783256, 0.2218370244372636, 0.13579185877460986, 0.18366128933848813, 0.30315729207359254, 4.126981822773814, 75.97150459885597, 77.78095230460167, 66.09277188777924, 43.03005002439022, 70.98929554224014, 76.68021216988564, 41.35534688830376, 68.65212455391884, 59.65213268995285, 15.821563471108675, 5.9915137477219105, 46.97366461157799, 71.0515969991684, 80.5215172469616, 58.720202296972275, 67.90393710136414, 67.5169126689434, 78.37708711624146, 54.52971875667572, 1.6752376011572778, 0.5852786160539836, 0.2827925223391503, 3.800227618776262, 17.67378643155098, 52.754761800169945, 67.90745571255684, 60.09939908981323, 60.276898965239525, 65.42041316628456, 66.11971244215965, 69.90750879049301, 60.579526126384735, 63.88868495821953, 69.23331096768379, 66.0736209154129, 66.018645465374, 58.84649991989136, 57.28599585592747, 58.891713693737984, 61.630963906645775, 63.99141624569893, 62.27390840649605, 63.841415494680405, 57.216345593333244, 50.753751173615456, 52.92304337024689, 54.70682345330715, 53.41418221592903, 54.83526796102524, 51.68722428381443, 46.00014925003052, 49.711197316646576, 54.67168673872948, 55.09367689490318, 57.514196410775185, 55.82238279283047, 57.80785605311394, 56.26307934522629, 54.53226462006569, 48.20992827415466, 55.69426506757736, 60.013348907232285, 58.08239512145519, 58.439150378108025, 56.33644200861454, 54.029901176691055, 48.735478073358536, 43.94848354160786, 45.439097955822945, 53.71367834508419, 54.948011711239815, 54.906559735536575, 57.68919602036476, 52.72826962172985, 43.5454011708498, 45.97697049379349, 44.85590144991875, 51.841032430529594, 56.18375480175018, 54.55382466316223, 52.556830421090126, 42.38758809864521, 45.42818494141102, 54.79443535208702, 59.04898725450039, 57.74441085755825, 60.51802262663841, 59.10460107028484, 56.01611539721489, 46.54806084930897, 48.08945193886757, 54.0862787514925, 55.49592711031437, 56.24060355126858, 53.6037540435791, 53.71418371796608, 52.9412329941988, 49.614838287234306, 48.76027174293995, 46.10820025205612, 45.79993799328804, 44.45751942694187, 48.00676837563515, 49.87775757908821, 52.25259594619274, 51.14569254219532, 55.728311240673065, 59.9932973831892, 58.45545530319214, 58.25563922524452, 59.274151772260666, 57.563555762171745, 56.234048902988434, 53.731457591056824, 54.84986677765846, 52.44946338236332, 55.647987350821495, 57.54844397306442, 61.511194333434105, 60.93352273106575, 63.815090507268906, 58.9161691814661, 60.452107563614845, 61.58660128712654, 61.55530996620655, 39.61698576807976, 50.13853378593922, 13.814582414925098, 0.6053806655108929, 2.2464202204719186, 34.50986981391907, 72.43051260709763, 60.74418269097805, 71.04196831583977, 62.586635425686836, 67.72324919700623, 61.59556120634079, 61.66561804711819, 26.759714484214783, 11.416941471397877, 47.91838891804218, 89.54121485352516, 29.087701365351677, 15.98690114915371, 39.58195924758911, 52.79095105826855, 35.74814736843109, 43.299124985933304, 47.0379039645195, 82.87881195545197, 30.42222585529089, 1.062495424412191, 0.27692857605870813, 0.2412902141804807, 0.16230196750257164, 0.1981716271257028, 0.17895982833579183, 0.1916224558954127, 0.10994226890034042, 0.1085250562755391, 0.16389546246500686], [0.14586499950382859, 0.06909107658430003, 0.022697794447594788, 0.10944455498247407, 0.0486623003234854, 0.02791270104353316, 0.06995547082624398, 0.15083896229043603, 0.029973394666740205, 0.08360462787095457, 0.06065287234378047, 0.09016384035930969, 0.05452129276818596, 0.08045012917136773, 0.5781168316025287, 20.948057435452938, 59.53659988939762, 54.118242636322975, 41.05106681585312, 44.95982587337494, 43.74225340783596, 28.25044859200716, 24.105893187224865, 52.32783570885658, 35.546917766332626, 6.531003573909402, 23.431566171348095, 70.18128409981728, 63.75615566968918, 62.26408213376999, 51.655465587973595, 54.899811297655106, 52.570171505212784, 54.43598158657551, 21.193710453808308, 0.2527443284634501, 0.6217561836820096, 0.1037079092930071, 2.414023051969707, 11.316194627434015, 22.717379294335842, 46.10645994544029, 49.16976436972618, 55.62256671488285, 55.392610654234886, 61.13423936069012, 57.549621909856796, 60.67088082432747, 64.23033222556114, 61.33478119969368, 55.31851463019848, 54.66615803539753, 51.41612783074379, 50.69128252565861, 50.1091917604208, 57.8187994658947, 52.83108450472355, 54.29180212318897, 48.716004118323326, 47.77709349989891, 47.00277864933014, 47.674290016293526, 44.57520671188831, 47.18654818832874, 42.141946479678154, 46.730804443359375, 52.51090608537197, 51.34797848761082, 53.300237730145454, 52.11506612598896, 54.33403305709362, 54.518121778964996, 53.19935314357281, 48.940211087465286, 44.65727090835571, 49.939150884747505, 49.194626435637474, 44.61165055632591, 39.81478035449982, 36.82098180055618, 33.73758405447006, 29.958297349512577, 28.39222088456154, 34.189695194363594, 37.40027591586113, 40.29795482754707, 40.63788838684559, 42.62207731604576, 41.97140023112297, 35.057120248675346, 40.599795430898666, 39.93407495319843, 39.06781643629074, 42.6805067807436, 38.349415585398674, 37.99917697906494, 30.70438541471958, 32.2146637737751, 37.64844439923763, 45.296989381313324, 49.34352144598961, 52.82935939729214, 54.4258589297533, 51.48657605051994, 43.139206767082214, 44.38365139067173, 48.621966764330864, 51.66700176894665, 51.64380021393299, 48.81054684519768, 47.37612761557102, 48.4180773049593, 46.00418843328953, 45.20746998488903, 41.54152549803257, 39.93094392120838, 42.1482465416193, 41.561922803521156, 44.49351869523525, 44.70242768526077, 47.838091626763344, 47.26212613284588, 53.65632422268391, 50.46129986643791, 51.82927966117859, 48.82487207651138, 50.834306851029396, 49.02954429388046, 51.913665533065796, 50.3490386903286, 55.21229512989521, 54.338581413030624, 49.41659912467003, 53.82894515991211, 52.35096126794815, 44.956238865852356, 49.05051536858082, 44.94071289896965, 44.928359761834145, 28.297949843108654, 45.6061901897192, 33.5742612183094, 2.8618197608739138, 3.8176230853423476, 11.705680377781391, 51.24460883438587, 49.93960306048393, 47.739521116018295, 49.81308124959469, 55.95762513577938, 51.58578112721443, 56.441415175795555, 45.89790813624859, 8.417895399034023, 10.344592463225126, 58.426896035671234, 45.41964299976826, 10.300673469901085, 18.31242386251688, 31.385206282138824, 32.93908730149269, 24.120041728019714, 18.334949053823948, 37.49516822397709, 40.678128227591515, 3.1763519207015634, 0.16684834932675585, 0.013181514950701967, 0.18421279411995783, 0.034776925094774924, 0.03139529952022713, 0.086892230756348, 0.022613436376559548, 0.03431644101510756, 0.07998400848009624, 0.03289492393378168, 0.13831955438945442, 0.11330511071719229, 0.03923758144082967, 0.0769223524548579, 0.04990577988792211, 0.03279222553828731, 0.0721316778799519, 0.07502413907786831, 0.1364030470722355, 0.050931672885781154, 0.036522604859783314, 0.09362863100250252, 0.05479228057083674, 0.386473432299681, 0.5452194437384605, 22.02065248042345, 69.19521421194077, 63.614791855216026, 36.048555448651314, 64.58549156785011, 45.91514781117439, 32.762613371014595, 39.63908538222313, 47.86012664437294, 47.05213040113449, 7.5874722842127085, 21.342698559165, 76.02049916982651, 71.32894411683083, 66.72786220908165, 56.73342950642109, 61.99176974594593, 58.90993371605873, 61.39672167599201, 27.829324789345264, 0.3137104242341593, 0.5112186900805682, 0.29502896417398006, 4.061190253123641, 21.034027822315693, 31.047423407435417, 51.31449468433857, 50.56963965296745, 58.88434208929539, 58.860768154263496, 62.330947145819664, 58.48970666527748, 63.132650926709175, 66.62967547774315, 64.46094945073128, 60.32861419022083, 57.493487522006035, 55.75302131474018, 52.83980503678322, 52.29059010744095, 57.93046787381172, 55.66611997783184, 56.69412821531296, 51.27981014549732, 49.46150131523609, 50.077752247452736, 50.455744564533234, 48.2037004083395, 51.266974434256554, 43.329234570264816, 46.029202491045, 52.44449324905872, 52.2230639308691, 56.16588436067104, 54.72417712211609, 57.3650012165308, 55.88340751826763, 54.46511082351208, 50.49042910337448, 46.90135449171066, 55.14901712536812, 56.272476240992546, 51.46394446492195, 49.23840008676052, 48.907358050346375, 44.78233739733696, 38.860788345336914, 37.08265855908394, 40.62016613781452, 47.154356315732, 47.28719338774681, 49.18441258370876, 50.12730538845062, 48.689454942941666, 41.9690253585577, 39.186294078826904, 43.82079899311066, 46.38988673686981, 53.35430882871151, 47.18998700380325, 45.75910538434982, 37.27379210293293, 39.558491706848145, 46.64921522140503, 51.72652557492256, 53.545419573783875, 55.198843851685524, 58.01170751452446, 55.04070773720741, 46.27414494752884, 47.93731950223446, 50.90035870671272, 54.37146104872227, 54.07079458236694, 53.22887375950813, 50.562439039349556, 49.86526384949684, 50.472440868616104, 47.71150141954422, 44.69944104552269, 43.234486654400826, 44.9111732840538, 42.885433584451675, 45.01170448958874, 46.644393280148506, 49.98112343251705, 49.7376324981451, 55.3946777433157, 51.65971376001835, 54.74035665392876, 53.80615018308163, 53.479458913207054, 53.138374015688896, 56.130933836102486, 50.8232456445694, 54.60401616990566, 54.94839929044247, 50.67941576242447, 55.8351045101881, 56.08317419886589, 48.807457610964775, 55.027374252676964, 49.9841670691967, 50.00404380261898, 29.55614782869816, 56.05561047792435, 29.061860851943493, 6.436615688726306, 11.003257669508457, 15.380355846136808, 59.406190887093544, 53.7557914853096, 52.70895905792713, 54.28527407348156, 62.23276801407337, 54.927173629403114, 64.03120011091232, 50.19901894032955, 7.7758619002997875, 19.408133067190647, 57.39971615374088, 48.99050138890743, 17.241552025079727, 20.434359200298786, 20.50923228263855, 44.20965492725372, 25.252884440124035, 16.226890571415424, 48.173537626862526, 47.33926959335804, 3.937754351645708, 0.09361035190522671, 0.018867273429350462, 0.11754727136576548, 0.05242464023467619, 0.038520648231497034, 0.05189387848076876, 0.15432839223649353, 0.07722778333118185, 0.051365881226956844, 0.03505953121930361, 0.27429816720541567, 0.1679499339661561, 0.2199385067797266, 0.1649322427692823, 0.16840924916323274, 0.13191844162065536, 0.1762179340585135, 0.215683774149511, 0.20996968232793733, 0.21241820562863722, 0.15173440799117088, 0.2984643657691777, 0.10985212022205815, 0.4980579181574285, 0.6872001907322556, 39.16877321898937, 83.56788218021393, 77.28054955601692, 53.09184171259403, 65.64887210726738, 67.04224973917007, 32.54602499306202, 37.44125671684742, 55.02447880804539, 45.8608715236187, 7.750689201056957, 29.358564130961895, 80.10008946061134, 74.75528106093407, 72.02331125736237, 64.53961282968521, 67.72697299718857, 65.41371792554855, 67.87281677126884, 28.773357532918453, 0.5562903278041631, 2.751237857155502, 0.36235075327567756, 8.380515854805708, 32.99495570361614, 36.237819492816925, 60.67827522754669, 56.40883952379227, 63.873280584812164, 62.05949731171131, 65.53424745798111, 61.17025002837181, 63.51505480706692, 67.56387054920197, 66.18524372577667, 60.5614010989666, 60.73437921702862, 56.56307324767113, 54.69327338039875, 53.7516725063324, 63.280804976820946, 58.527552634477615, 59.721406772732735, 52.93434776365757, 54.85286481678486, 55.001357048749924, 54.703593626618385, 49.66682709753513, 55.20273104310036, 46.17984540760517, 51.18990696966648, 58.187778666615486, 58.10054674744606, 60.057426542043686, 59.274698942899704, 61.9662769138813, 59.189693704247475, 58.06316815316677, 53.62382836639881, 52.176330238580704, 57.82807856798172, 62.39826813340187, 56.41106240451336, 55.76277919113636, 57.00760379433632, 54.599589407444, 45.84512896835804, 45.46425640583038, 50.32745964825153, 55.779589489102364, 54.02758710086346, 55.88670574128628, 56.95958577096462, 52.81691886484623, 45.0655248016119, 45.46079479157925, 50.175258815288544, 51.05585016310215, 60.949158892035484, 53.89338970184326, 55.66050007939339, 45.120162069797516, 46.10135301947594, 50.35529315471649, 58.6451905220747, 57.776340544223785, 58.14872436225414, 59.02736261487007, 56.390600502491, 46.86636596918106, 48.77111256122589, 51.17503456771374, 53.85855317115784, 57.16698244214058, 53.64063486456871, 52.089850679039955, 53.515218794345856, 53.39890703558922, 50.10663829743862, 45.58256685733795, 45.01348279416561, 48.34022708237171, 45.534453839063644, 50.203411504626274, 50.398797020316124, 53.086974173784256, 52.87987008690834, 57.916682213544846, 53.580818474292755, 56.54364489018917, 55.7863113284111, 56.66420482099056, 56.42165623605251, 56.397903710603714, 54.526272341609, 60.89556656777859, 61.737597584724426, 56.608108431100845, 61.43039166927338, 63.71207043528557, 55.50532020628452, 60.39652794599533, 53.49029593169689, 53.86665813624859, 36.43344059586525, 61.155856400728226, 40.22447817027569, 6.267952714115381, 11.58950351178646, 14.668778479099274, 61.72198422253132, 57.480093240737915, 58.12712252140045, 59.76793147623539, 66.18692323565483, 59.10633757710457, 65.8503220975399, 56.67829446494579, 12.942779045552015, 14.413871057331562, 66.52318239212036, 58.57559345662594, 15.077084619551897, 22.54483625292778, 41.59656174480915, 53.251136764883995, 32.083373218774796, 28.21696098893881, 51.2438602745533, 67.1984213590622, 8.925752397626638, 0.3844698116881773, 0.13277387071866542, 0.28439291927497834, 0.16177361772861332, 0.12023208706523292, 0.19767757941735908, 0.25465144019108266, 0.1686995624913834, 0.21222067560302094, 0.20192750293063], [0.014723151416546898, 0.09199967622407712, 0.01352535568003077, 0.03724073292687535, 0.05390320991864428, 0.02244507646537386, 0.057338229307788424, 0.051122148797730915, 0.03200912615284324, 0.1722029151278548, 0.03596256909077056, 0.04158666808507405, 0.07507848655222915, 0.12038229775498621, 0.1294636249076575, 2.4052386358380318, 42.15975232422352, 46.253390461206436, 47.14995615184307, 30.532919615507126, 44.98274624347687, 37.806382924318314, 10.621086526662111, 30.964857637882233, 48.76042753458023, 7.324748681858182, 1.2553341267630458, 17.15401992201805, 58.11820060014725, 59.58937905728817, 58.036295995116234, 51.14073000848293, 55.60612499713898, 56.0531672090292, 39.3961264193058, 0.9851313382387161, 0.4755966702941805, 0.9908985975198448, 2.7695782855153084, 20.4243391379714, 6.451205005869269, 21.02703619748354, 36.66494317352772, 43.54196235537529, 46.7165058106184, 50.51211453974247, 57.937869876623154, 56.301502883434296, 59.59005922079086, 63.202384784817696, 56.573017314076424, 55.903554037213326, 48.81318770349026, 46.96200683712959, 47.46115185320377, 48.81970815360546, 49.04107667505741, 49.28733766078949, 48.26709620654583, 44.30374167859554, 47.995859161019325, 44.71212476491928, 45.36970227956772, 42.305056527256966, 42.404922768473625, 51.054945811629295, 52.82059706747532, 56.17876946926117, 55.54224282503128, 55.97510799765587, 54.01337966322899, 56.08757056295872, 55.12211076915264, 43.60044501721859, 46.74605302512646, 54.74825643002987, 47.0508536696434, 43.95791843533516, 40.14301814138889, 38.04812215268612, 33.10903698205948, 28.318816423416138, 30.75000386685133, 35.948320627212524, 41.44906505942345, 41.43202677369118, 45.72974815964699, 45.73420152068138, 43.79878677427769, 39.495840668678284, 46.02121151983738, 40.589452385902405, 41.51019997894764, 40.932965353131294, 40.75890049338341, 42.99336679279804, 32.96502470970154, 32.64157086610794, 39.33996923267841, 45.443532317876816, 47.42537297308445, 51.88413731753826, 55.52015081048012, 54.22334499657154, 45.44339172542095, 41.603716760873795, 50.924954786896706, 53.96733373403549, 52.85683572292328, 48.0263677239418, 46.928333044052124, 47.60038398206234, 47.25293442606926, 47.2654889523983, 44.086799919605255, 43.11540484428406, 40.86053743958473, 40.30804328620434, 41.14676468074322, 43.080860897898674, 43.647235706448555, 46.14872507750988, 49.54774148762226, 51.50138005614281, 51.999506726861, 50.60584031045437, 49.369139671325684, 49.33052234351635, 47.22383178770542, 44.24044467508793, 42.512008622288704, 50.116992741823196, 34.303221702575684, 29.941528849303722, 26.582632586359978, 33.17823126912117, 28.826446384191513, 28.83387878537178, 20.010818727314472, 12.308364138007164, 18.532027378678322, 0.9751347871497273, 2.0379037968814373, 8.587753884494305, 33.437650948762894, 55.33155173063278, 49.350627064704895, 48.79947043955326, 57.293918430805206, 53.23293574154377, 60.71254938840866, 60.75509190559387, 20.202058665454388, 3.495052456855774, 27.094372026622295, 53.87455031275749, 19.19852301478386, 9.514166973531246, 29.898414462804794, 40.54530255496502, 30.690797343850136, 21.75314873456955, 32.13931001722813, 50.74001491069794, 29.796407036483288, 0.6806694692932069, 0.035100609093206, 0.15350946196122095, 0.10743077436927706, 0.037791042850585654, 0.03932957064535003, 0.027645069603750017, 0.05370239588955883, 0.04245332587743178, 0.03361170500284061, 0.030881814964232035, 0.00812785570815322, 0.0476134675409412, 0.02798397690639831, 0.06874919141409919, 0.042510768107604235, 0.055879226347315125, 0.029000411232118495, 0.11689513135934249, 0.04922913787595462, 0.022765396679460537, 0.06515948989544995, 0.05149013530171942, 0.05871368128282484, 0.5079640459734946, 0.11883372499141842, 3.6095006531104445, 45.13648219406605, 58.29797275364399, 46.37147292494774, 36.40558809041977, 49.129285141825676, 27.80470211058855, 23.910655863583088, 36.8479223549366, 57.69711099565029, 18.66988018155098, 2.8528085444122553, 14.439545329660177, 61.615263149142265, 67.86223813891411, 68.40570017695427, 58.28011371195316, 62.19027489423752, 63.374317958950996, 46.46836772561073, 2.1932988334447145, 0.4361979500390589, 2.5777071062475443, 5.641103200614452, 36.32047265768051, 14.072109796106815, 29.39776472747326, 43.378232941031456, 48.605502247810364, 51.95030316710472, 56.75998628139496, 58.85444149374962, 62.23595604300499, 62.97020964324474, 66.44932195544243, 61.32535770535469, 59.29514944553375, 52.658402770757675, 51.5992172062397, 48.82699616253376, 51.362246721982956, 50.504400953650475, 54.0822471678257, 52.47984655201435, 46.67595058679581, 49.206709787249565, 47.628027498722076, 48.31587798893452, 45.51039732992649, 42.30590768158436, 53.15840274095535, 56.47522956132889, 60.1837507635355, 60.14894463121891, 57.38636367022991, 58.875522762537, 57.726570814847946, 57.449299693107605, 48.12497243285179, 49.350421875715256, 55.90465597808361, 53.957526460289955, 50.89132659137249, 49.35718171298504, 49.58688698709011, 42.72037424147129, 39.820609241724014, 38.143671825528145, 44.54528331756592, 48.76363456249237, 49.49455954134464, 52.34840400516987, 51.27249173820019, 51.807161048054695, 43.08401092886925, 49.1151574999094, 47.61425703763962, 47.84985199570656, 49.821585193276405, 48.60900565981865, 49.87593747675419, 38.74584451317787, 40.72396136820316, 48.24333608150482, 52.68052138388157, 51.24213136732578, 57.26432941854, 58.505418822169304, 56.8295681476593, 47.95890994369984, 44.64186653494835, 53.17317254841328, 57.866996079683304, 54.67957131564617, 51.56486324965954, 49.58677299320698, 50.28242826461792, 53.04641515016556, 49.53793801367283, 47.84171663224697, 45.12677751481533, 42.89101928472519, 44.39442381262779, 44.495768174529076, 46.141843646764755, 45.59619292616844, 48.90814460813999, 49.848065972328186, 53.6430249363184, 54.86861877143383, 54.11244034767151, 51.63909986615181, 54.68293033540249, 49.34352524578571, 49.04212921857834, 45.03343552350998, 54.27800126373768, 39.2643266916275, 34.79089513421059, 31.0970601439476, 37.491683810949326, 32.0651113986969, 32.533690854907036, 20.835667066276073, 13.184703513979912, 17.4730584025383, 4.099286058917642, 5.593695994466543, 8.325025532394648, 41.84386767446995, 59.42951023578644, 55.598798990249634, 54.18177902698517, 64.38597947359085, 59.8127880692482, 70.7559272646904, 65.0622595846653, 14.640069119632244, 9.947791155427694, 34.65823285281658, 50.95567613840103, 26.965813525021076, 14.920844603329897, 23.92247322946787, 29.728025905787945, 47.97109968960285, 19.41939566284418, 31.24684240669012, 62.44714871048927, 31.801337152719498, 1.5611486043781042, 0.02265491129946895, 0.1644391450099647, 0.04739027775940485, 0.07979481277288869, 0.041571442925487645, 0.03606237682106439, 0.06060403902665712, 0.061099073791410774, 0.048102190339704975, 0.011024723407899728, 0.07177574385423213, 0.18494348303647712, 0.11073839297750965, 0.12070120603311807, 0.12677595193963498, 0.14558506140019745, 0.21692335372790694, 0.16771583090303466, 0.1201744147692807, 0.3060074063250795, 0.17661572521319613, 0.15910148533293977, 0.14512145658954978, 0.6774635694455355, 0.2655846410198137, 9.173744190484285, 73.89757588505745, 66.18082836270332, 64.70928892493248, 40.405215471982956, 71.88534066081047, 45.879733711481094, 16.64176370948553, 36.958777606487274, 60.38241550326347, 11.19743674993515, 2.032614005729556, 22.11502231657505, 69.48892325162888, 69.12206053733826, 69.58474650979042, 62.51212902367115, 71.70020699501038, 68.57564225792885, 52.49365121126175, 1.5870451647788286, 1.3857409916818142, 2.695749197155237, 11.332434006035328, 52.54362232983112, 23.982772193849087, 40.04081502556801, 52.467261627316475, 53.355581760406494, 57.083413526415825, 63.737973645329475, 62.91995733976364, 63.04360270500183, 64.2397253215313, 67.2879521548748, 62.67657659947872, 62.19255477190018, 52.87550412118435, 53.64479944109917, 51.387895345687866, 55.22406309843063, 52.52289444208145, 57.43826128542423, 54.48830857872963, 50.02442590892315, 54.34774272143841, 51.28280818462372, 50.934883654117584, 47.56941944360733, 46.06835559010506, 57.489053159952164, 59.39647860825062, 62.10359774529934, 63.77475947141647, 62.28252254426479, 60.34638963639736, 60.006171092391014, 59.897325932979584, 47.13143594563007, 53.106577321887016, 60.79415000975132, 56.840967535972595, 57.22458355128765, 57.33193539083004, 57.93162681162357, 51.58651068806648, 44.96568135917187, 45.6774515658617, 51.743104085326195, 56.06778882443905, 54.11307871341705, 58.74637149274349, 55.530714243650436, 57.53591984510422, 49.08144190907478, 51.58124037086964, 48.45395877957344, 52.44622215628624, 54.53260280191898, 53.341423720121384, 57.040624022483826, 46.455634608864784, 46.08856290578842, 52.7272816747427, 57.62353554368019, 55.520131811499596, 58.24104800820351, 61.54653623700142, 58.38011294603348, 49.781136363744736, 45.66476784646511, 52.95906163752079, 60.81187225878239, 56.13673232495785, 51.46053604781628, 50.33328853547573, 50.77387869358063, 55.728938207030296, 54.85465832054615, 49.15110357105732, 46.47835738956928, 46.05119191110134, 46.873425990343094, 46.83292776346207, 49.145449474453926, 50.378354117274284, 52.21018262207508, 53.35582114756107, 54.39545676112175, 56.464498937129974, 55.00366732478142, 54.22543108463287, 54.970263317227364, 52.20746956765652, 52.974656000733376, 51.90308690071106, 60.318453535437584, 46.70563839375973, 41.070932149887085, 39.547628089785576, 44.32796537876129, 40.10698467493057, 42.62067139148712, 29.71871830523014, 24.05648823827505, 31.731781885027885, 2.817088086158037, 7.966526644304395, 10.746183414012194, 42.281790375709534, 67.46643617749214, 61.541490107774734, 58.28566141426563, 68.28952521085739, 62.27973349392414, 70.28842315077782, 69.16695892810822, 28.072200156748295, 6.721963752061129, 30.941492691636086, 65.20478993654251, 29.810821563005447, 14.071095250546932, 36.94376461207867, 56.89937800168991, 50.49522064626217, 29.015704728662968, 46.245106905698776, 71.51239827275276, 52.93448455631733, 2.829007809050381, 0.11058306146878749, 0.20965060335583985, 0.20663813687860966, 0.24202845816034824, 0.12553500680951402, 0.14171008573612198, 0.2092280689976178, 0.13579828577348962, 0.10166568215936422, 0.1455007682670839], [0.09245738838217221, 0.017400639335392043, 0.04793793079443276, 0.036191863036947325, 0.046687207868671976, 0.040941411498351954, 0.044926239861524664, 0.10798442395753227, 0.0819550413871184, 0.21996935043716803, 0.024706483927730005, 0.04745065889437683, 0.03130464618152473, 0.0556991219491465, 0.08130235219141468, 0.5850208830088377, 13.7583083845675, 53.7796276062727, 47.906848937273026, 29.510156996548176, 40.942715629935265, 60.81075131893158, 19.321049340069294, 16.713072583079338, 64.35955569148064, 47.50680260360241, 5.248816050589085, 1.5927933063358068, 23.686241805553436, 62.37312488257885, 39.15616549551487, 44.44314859807491, 54.27923999726772, 58.61853115260601, 50.80833524465561, 9.604610670357943, 0.5853031959850341, 5.411325255408883, 10.608778987079859, 8.483315538614988, 6.752328397706151, 8.101218491792679, 41.19291700422764, 51.008185520768166, 57.89421781897545, 51.92905090749264, 59.884858801960945, 61.786877140402794, 61.02595657110214, 60.854129791259766, 56.02219507098198, 54.30413246154785, 50.90015351772308, 49.0106251090765, 46.693794429302216, 49.364948496222496, 46.85196854174137, 44.283283576369286, 47.19325102865696, 45.72010427713394, 43.92587095499039, 43.68546165525913, 44.407160729169846, 41.65358908474445, 49.340542405843735, 57.15964883565903, 56.88662588596344, 54.473709762096405, 54.97487246990204, 53.334770277142525, 55.17373479902744, 56.75473116338253, 54.03633423149586, 46.19565635919571, 47.21915043890476, 51.54241785407066, 45.367589592933655, 42.456786185503006, 41.20847336947918, 40.37939205765724, 34.97809588909149, 32.76015490293503, 33.19359004497528, 37.73591950535774, 42.365955859422684, 43.37347939610481, 45.4906801879406, 46.71983443200588, 47.68891543149948, 44.60192307829857, 46.32122062146664, 39.28520657122135, 45.18708787858486, 43.87847609817982, 45.33577390015125, 40.1115520298481, 35.792707577347755, 33.52455608546734, 39.59447957575321, 44.822071865200996, 50.037687197327614, 51.6421815007925, 52.871761322021484, 54.02576319873333, 45.31810484826565, 41.83852896094322, 45.77089615166187, 52.95473366975784, 52.69712269306183, 54.48979049921036, 51.38091892004013, 49.00795765221119, 47.84554302692413, 45.5597984790802, 45.923606157302856, 45.66480964422226, 43.62218365073204, 41.868440955877304, 43.120899349451065, 44.289260655641556, 44.48748081922531, 47.06770956516266, 48.82036171853542, 48.23433056473732, 51.00416153669357, 53.89240175485611, 51.02888680994511, 51.13282263278961, 41.67047917842865, 34.74332168698311, 25.869562849402428, 22.401196360588074, 18.551332242786884, 15.293882936239243, 17.01023943722248, 12.546049933880568, 10.531467385590076, 8.716542273759842, 5.728244874626398, 2.8987081814557314, 5.004354268312454, 3.7396044842898846, 1.0015126154758036, 25.43550454080105, 46.565175130963326, 52.20357097685337, 52.83700458705425, 51.72739192843437, 51.42472296953201, 56.59504093229771, 43.95242393016815, 16.808162480592728, 3.5984430089592934, 5.26137912645936, 61.640714183449745, 58.20032939314842, 19.52464621514082, 18.561889976263046, 36.1348944157362, 39.48467306792736, 27.694242037832737, 24.36870228499174, 33.325496166944504, 53.63846518099308, 12.24655570462346, 0.5235170864034444, 0.14998044585809112, 0.07164131122408435, 0.07265451349667273, 0.06236372311832383, 0.0715201259299647, 0.04887491821136791, 0.02489813614374725, 0.04748945837491192, 0.060490115647553466, 0.039740865177009255, 0.009426282031199662, 0.026576454874884803, 0.12289169200812466, 0.03357205576321576, 0.029397369326034095, 0.03109174627752509, 0.020041015231981874, 0.06276983374846168, 0.046899094741092995, 0.08089048991678283, 0.021969940535200294, 0.08234820896177553, 0.08134812786011025, 0.07734534694463946, 0.11964226519921795, 0.5460061796475202, 19.992308020591736, 71.30935236811638, 53.51664751768112, 25.820760168135166, 50.408281311392784, 37.25040055811405, 22.93173909187317, 26.253908425569534, 59.854338839650154, 51.60894848406315, 14.466630276292562, 3.221034435555339, 22.086117267608643, 65.78153818845749, 46.063191667199135, 53.84047374129295, 57.016552314162254, 68.11512976884842, 56.0424517840147, 13.227240331470966, 0.37095622275955975, 8.08003842830658, 15.119178760796785, 11.65071252733469, 13.775494862347841, 11.547588910907507, 48.46596233546734, 55.176653042435646, 65.07568806409836, 57.225856482982635, 64.56518545746803, 62.78422862291336, 66.22444242238998, 64.08763468265533, 62.319790944457054, 60.05568243563175, 56.8185069411993, 51.56326353549957, 50.40785193443298, 51.022453755140305, 52.415595799684525, 48.51998783648014, 49.78721983730793, 47.97417752444744, 46.99383772909641, 46.49875849485397, 46.73676252365112, 43.38319927453995, 49.55727517604828, 57.410830557346344, 58.21175538003445, 57.34937645494938, 56.02670542895794, 55.466113910079, 58.161100298166275, 58.391010761260986, 57.07555554807186, 49.45745453238487, 48.819856345653534, 56.6140741109848, 53.926330134272575, 50.808931812644005, 50.30587300658226, 49.46558989584446, 42.96424515545368, 41.2814636528492, 42.227415293455124, 46.72320105135441, 49.372863471508026, 50.271370857954025, 51.76358878612518, 53.88798639178276, 52.83223584294319, 51.016837656497955, 54.72540445625782, 48.44689875841141, 53.348335549235344, 49.57232616841793, 52.698407024145126, 48.757824674248695, 42.919304966926575, 40.272082015872, 47.92881555855274, 52.756065130233765, 54.511475935578346, 54.66447852551937, 58.07250805199146, 57.753667160868645, 47.94047333300114, 46.347123831510544, 48.285939395427704, 54.16100174188614, 54.69364196062088, 57.20123380422592, 52.75758504867554, 51.419030874967575, 50.88235527276993, 48.260138779878616, 49.67319555580616, 44.66880328953266, 44.86839517951012, 44.39009964466095, 45.611897483468056, 46.064126417040825, 46.84074014425278, 47.861365377902985, 52.59570233523846, 51.82115189731121, 54.48508255183697, 53.71313117444515, 53.81416395306587, 51.989615857601166, 45.03295294940472, 38.61056797206402, 29.38415765762329, 24.87956777215004, 20.9486673027277, 17.494859732687473, 18.967434614896774, 15.625587087124586, 11.797288712114096, 8.120618350803852, 6.324823312461376, 4.7619253769516945, 3.6769862193614244, 5.355861531570554, 2.782733654603362, 26.951862573623657, 52.73307256400585, 57.905765399336815, 59.076999351382256, 58.32028515636921, 55.883643105626106, 64.37952741980553, 50.68226180970669, 18.810877315700054, 5.347598874941468, 14.399578124284744, 55.65919294953346, 59.43513013422489, 25.604234486818314, 25.9157607704401, 24.310111328959465, 42.24919952452183, 40.42153179645538, 13.738687187433243, 36.147008165717125, 64.4273592531681, 12.994922697544098, 0.733503793599084, 0.024143646551237907, 0.13477020343998447, 0.10726644803071395, 0.033785122650442645, 0.04253898827300873, 0.10380637744674459, 0.028941918862983584, 0.0687774523976259, 0.025685719956527464, 0.06680063816020265, 0.14084068941883743, 0.15665674698539078, 0.1532261396641843, 0.11595198040595278, 0.11124297176138498, 0.17470604565460235, 0.10383662738604471, 0.2482358703855425, 0.164871713204775, 0.29013491584919393, 0.1329745919792913, 0.16261380311334506, 0.16040201007854193, 0.12025409174384549, 0.23860803310526535, 0.6081384269054979, 35.58547429740429, 82.45287001132965, 69.94006544351578, 37.703697234392166, 65.70367276668549, 82.42737337946892, 22.274172976613045, 24.28152546286583, 71.99748784303665, 58.933682441711426, 11.310458835214376, 3.181479745544493, 31.04754500091076, 72.32211202383041, 51.954387947916985, 58.4307262301445, 64.84994977712631, 75.89705139398575, 61.384341940283775, 14.81986977159977, 0.7144554750993848, 8.741791918873787, 14.39047571271658, 18.625870943069458, 21.165987141430378, 17.05093715339899, 57.48391203582287, 62.20838852226734, 70.77994957566261, 61.137932762503624, 69.39319118857384, 62.90125094354153, 66.41927316784859, 64.98146072030067, 63.80138844251633, 61.08247473835945, 58.963609635829926, 52.7330307662487, 54.051844999194145, 55.85219219326973, 55.44299595057964, 50.189048275351524, 54.364564418792725, 51.16554647684097, 48.347192108631134, 49.189781695604324, 51.0610368847847, 46.481378227472305, 53.533165231347084, 63.0646687746048, 62.466504871845245, 60.36793828010559, 59.107963889837265, 58.487138003110886, 60.264310240745544, 60.40386535227299, 57.74761788547039, 52.9669576138258, 52.65924632549286, 60.538484528660774, 56.28239370882511, 56.21933989226818, 57.2127927839756, 54.496193155646324, 50.67848861217499, 48.569829761981964, 46.34355582296848, 52.15433321893215, 52.307548597455025, 53.944200575351715, 55.56180417537689, 56.71821892261505, 57.665515691041946, 50.17178200185299, 56.61076448857784, 49.281459376215935, 56.9064000248909, 55.49714304506779, 56.809075847268105, 52.933811992406845, 47.49162621796131, 45.28581038117409, 52.460642382502556, 59.0792640298605, 58.82753133773804, 55.201906487345695, 57.49669075012207, 59.991731867194176, 51.26652605831623, 46.15221709012985, 49.3358838558197, 55.44897682964802, 55.677621960639954, 60.13915255665779, 54.1432186961174, 54.732244089245796, 52.857603281736374, 51.530182510614395, 53.112706393003464, 50.851421132683754, 48.08721765875816, 45.71969389915466, 46.86970978975296, 49.743909761309624, 48.38831350207329, 52.451834455132484, 53.67933578789234, 53.009693920612335, 55.84950193762779, 58.90519917011261, 55.72574257850647, 57.13226370513439, 46.63889117538929, 39.73360911011696, 31.657459773123264, 27.353482022881508, 23.770884163677692, 20.89239042252302, 23.664444275200367, 21.508854143321514, 17.32587520033121, 14.595469012856483, 7.993509471416473, 7.542605716735125, 5.272176247090101, 7.380094137042761, 4.186489479616284, 31.8467029184103, 58.36030460894108, 62.72463642060757, 63.774539083242416, 63.30149486660957, 61.35576367378235, 69.74867731332779, 52.29837588965893, 26.2408884242177, 6.189664090052247, 8.607903253287077, 69.67566043138504, 67.850481569767, 26.303436867892742, 24.613416753709316, 43.423568308353424, 59.849315509200096, 39.39210623502731, 30.705428458750248, 45.904671773314476, 75.05538135766983, 27.705394439399242, 1.1229956592433155, 0.2763541537569836, 0.3276417532470077, 0.28828598849941045, 0.17310950788669288, 0.15779089706484228, 0.1826816247194074, 0.1335361009114422, 0.19591530523030087, 0.1560553105082363, 0.12447930916096084], [0.0032861269392014947, 0.1193489832803607, 0.06465996513725258, 0.037293087734724395, 0.02857836298062466, 0.02560858669312438, 0.056699915512581356, 0.04215326072880998, 0.04027502967801411, 0.09069250925676897, 0.04685206484282389, 0.10353564939578064, 0.07295339863048866, 0.032951074826996773, 0.27358959428966045, 0.3003883984638378, 6.664216825738549, 55.961265340447426, 55.84877997636795, 39.575480595231056, 32.962364852428436, 54.892272502183914, 38.24008025228977, 13.999783527106047, 43.9628391712904, 92.430230230093, 38.01749959588051, 2.887578341178596, 18.628460504114628, 65.43563514947891, 56.98419705033302, 49.593346640467644, 55.68193852901459, 57.523319721221924, 53.39671075344086, 29.479635134339333, 0.3628693660721183, 4.253042433410883, 16.805065646767616, 12.842199392616749, 2.883810605853796, 1.523966055829078, 8.684600237756968, 35.78057482838631, 54.824905917048454, 59.79995995759964, 55.524117797613144, 61.62045747041702, 61.96358285844326, 59.00199897587299, 58.33174154162407, 55.77854074537754, 49.17454831302166, 49.97674986720085, 49.339831843972206, 46.11020654439926, 48.017195016145706, 49.31699886918068, 44.590550288558006, 45.22388890385628, 44.807020872831345, 46.61163903772831, 43.44079278409481, 48.10921847820282, 52.23044313490391, 57.45202034711838, 57.2015567868948, 55.98597161471844, 55.01009277999401, 54.61453400552273, 55.30708484351635, 56.166879907250404, 48.465643152594566, 43.00934113562107, 45.292737409472466, 52.87037059664726, 47.18322716653347, 46.36447750031948, 42.20858350396156, 40.04737727344036, 35.587374195456505, 33.53597067296505, 35.64841032028198, 37.82620646059513, 44.16242726147175, 43.95378425717354, 46.25331446528435, 48.151730597019196, 49.83379393815994, 47.434621676802635, 45.49160733819008, 44.385695680975914, 48.42224568128586, 43.13096880912781, 46.224375218153, 41.58645808696747, 36.67619816958904, 34.90393526852131, 41.78286574780941, 45.93475475907326, 48.46454121172428, 49.01061750948429, 55.67796774208546, 56.48062527179718, 46.58928103744984, 42.13463567197323, 43.29795844852924, 48.153410106897354, 53.46126928925514, 53.85000362992287, 54.113036915659904, 53.47407080233097, 51.879311576485634, 49.85818102955818, 47.31721557676792, 49.19907599687576, 45.37838101387024, 43.226974457502365, 41.31718933582306, 43.133066296577454, 44.453347250819206, 46.497474163770676, 47.51917853951454, 52.495946288108826, 51.91787950694561, 53.23685713112354, 51.955322697758675, 53.241823464632034, 44.70063418149948, 37.6095724850893, 26.91385891288519, 20.325770527124405, 18.04413925856352, 13.47430782392621, 7.962266597896814, 6.250845082104206, 2.8845318546518683, 1.6809486947022378, 4.150129230692983, 1.182498566340655, 0.8025256055407226, 1.5177746443077922, 4.967727083712816, 30.28257194906473, 54.403641521930695, 55.080540999770164, 49.62448976933956, 47.447647377848625, 45.17749719321728, 40.90591460466385, 39.38804045319557, 7.916340362280607, 2.3507970571517944, 36.80555462837219, 76.43637165427208, 42.68161252140999, 12.69780334085226, 18.58780838549137, 38.336123898625374, 31.411711759865284, 26.082062646746635, 32.206323221325874, 44.16011318564415, 52.52811536192894, 4.5878044702112675, 0.10483001431566663, 0.06651752366451547, 0.0489553262013942, 0.054404007460107096, 0.04792562969669234, 0.05784818124084268, 0.027150545065524057, 0.05923381548200268, 0.05118164677696768, 0.07613232883159071, 0.011176897078257753, 0.02825265848514391, 0.04432656227436382, 0.07864702201914042, 0.02366709682974033, 0.06663062697043642, 0.017846312002802733, 0.08193193090846762, 0.026961299263348337, 0.0836470490321517, 0.0360520387039287, 0.036293515004217625, 0.02817046748532448, 0.1320578614831902, 0.019647905173769686, 0.2146516545326449, 0.09665444129495881, 6.151687977835536, 64.73782539367676, 67.36074104905128, 29.654269963502884, 39.92833726108074, 47.30337671935558, 29.407226219773293, 23.80384359508753, 51.17383763194084, 85.55826857686043, 34.13783557713032, 5.80417999997735, 20.469668805599213, 67.69009217619896, 57.714092284440994, 52.54896104335785, 63.47220450639725, 64.81951341032982, 59.14206326007843, 33.18319380283356, 1.236149431206286, 4.846278475597501, 18.47868014127016, 16.699418015778065, 4.060416519641876, 2.057826602831483, 13.215815294533968, 40.12734018266201, 60.250737369060516, 66.09239190816879, 62.27783739566803, 62.874948754906654, 68.59268054366112, 63.52804630994797, 64.11044865846634, 59.81516294181347, 53.62936466932297, 51.94909483194351, 53.262954130768776, 47.19242267310619, 49.96535807847977, 49.3346831202507, 46.86205320060253, 45.967440605163574, 47.753713354468346, 45.93883574008942, 46.04417368769646, 47.086537554860115, 52.57502004504204, 59.50550615787506, 58.68435122072697, 57.5651478767395, 57.00273245573044, 57.60580189526081, 58.53687733411789, 59.601542204618454, 51.63392074406147, 44.042182713747025, 47.96595856547356, 57.92036421597004, 54.56583581864834, 53.18481132388115, 51.004644110798836, 48.65622192621231, 43.896639123559, 42.62447118759155, 42.38846965134144, 48.1799478828907, 48.899108693003654, 51.95789135992527, 53.55594880878925, 54.69860829412937, 55.54434411227703, 60.76581872999668, 51.23795919120312, 51.91987819969654, 54.22085613012314, 51.528715789318085, 51.76192827522755, 49.01858188211918, 43.65724816918373, 40.95592372119427, 48.29076133668423, 52.86168426275253, 54.50888067483902, 52.21728444099426, 58.197878524661064, 57.70083859562874, 49.497443586587906, 43.199463933706284, 46.00192375481129, 51.73349440097809, 54.00973565876484, 54.18679855763912, 56.38835482299328, 56.2114667147398, 51.651950776576996, 51.705657094717026, 51.57822333276272, 50.48938795924187, 46.92357189953327, 45.218424797058105, 43.449251130223274, 45.45433893799782, 46.47822439670563, 48.35747815668583, 49.34070959687233, 53.47877874970436, 51.66116528213024, 55.53331330418587, 55.77380619943142, 55.358249098062515, 45.90802699327469, 39.01820629835129, 29.455183446407318, 21.817124001681805, 19.81716211885214, 15.617982745170593, 11.562990434467793, 8.359739519655704, 5.081909531727433, 2.220457876101136, 6.7867744993418455, 0.3216307726688683, 0.7056205929256976, 1.786562839988619, 4.375269999727607, 33.4158743172884, 59.96917627751827, 60.14680914580822, 55.17029978334904, 53.64761509001255, 50.145384818315506, 45.90213730931282, 38.35142567753792, 9.019810650497675, 6.79266513325274, 35.8820977807045, 66.46511390805244, 49.7053874284029, 20.254511050879955, 22.46005330234766, 23.85183311998844, 43.718006908893585, 26.201522536575794, 19.375922195613384, 54.17583614587784, 61.050184071063995, 6.546702906489372, 0.15888553520198911, 0.09807552050915547, 0.12153736155596562, 0.008408773446717532, 0.011325671712256735, 0.0380620158102829, 0.1329211425036192, 0.06057008205971215, 0.012001681971014477, 0.09590955509338528, 0.009990981270675547, 0.09247237234376371, 0.14790425804676488, 0.14502144476864487, 0.08789986692136154, 0.09067125414730981, 0.1363839887198992, 0.16489126137457788, 0.1319424426765181, 0.11491451732581481, 0.20790965849300846, 0.17948920227354392, 0.19469796039629728, 0.13653657428221777, 0.0940743723185733, 0.5362448003143072, 0.2933697297703475, 12.954626809805632, 83.80389511585236, 72.0246259868145, 52.78567314147949, 49.17335897684097, 81.27907499670982, 44.33472901582718, 18.569244481623173, 54.023528918623924, 99.76271197199821, 44.903208911418915, 6.321334624662995, 20.957296639680862, 77.79739782214165, 67.63716861605644, 64.92678165435791, 67.8771485388279, 72.90501594543457, 65.77497974038124, 36.53585270047188, 1.679383534938097, 7.34385073184967, 27.596729770302773, 20.559760071337223, 6.292360229417682, 2.6524949306622148, 15.408109556883574, 40.14951579272747, 65.36212429404259, 71.57836273312569, 64.55542758107185, 64.20352846384048, 69.05104234814644, 64.86338585615158, 65.75343489646912, 61.13680802285671, 55.17033778131008, 54.028134271502495, 55.29257342219353, 49.78818118572235, 51.480446979403496, 53.07691991329193, 49.10708673298359, 48.56438085436821, 50.84513247013092, 49.447578862309456, 50.871411859989166, 52.963336408138275, 58.21966655552387, 65.21286830306053, 62.89253041148186, 61.33589453995228, 61.710558235645294, 60.67183457314968, 62.14437335729599, 61.49902358651161, 51.378126069903374, 46.18588328361511, 50.153770968317986, 60.72345860302448, 57.70662188529968, 59.7282388061285, 56.19883619248867, 55.39731480181217, 49.69606272876263, 49.39628541469574, 48.13942305743694, 51.190879717469215, 52.84307286143303, 54.39345046877861, 54.4205392152071, 55.90515375137329, 59.37220171093941, 58.87856639921665, 54.00971285998821, 51.83790899813175, 55.70485509932041, 54.471369087696075, 56.28625810146332, 51.55677728354931, 50.26921257376671, 45.37061423063278, 53.33495266735554, 57.2814778983593, 57.205789759755135, 55.042698830366135, 60.45289412140846, 61.72123186290264, 52.37296588718891, 46.70204758644104, 46.8458204716444, 52.77466133236885, 54.1972403973341, 55.49923673272133, 57.25577227771282, 58.725339621305466, 52.999445870518684, 52.353195548057556, 54.72954623401165, 54.3264676630497, 49.715817868709564, 48.72208759188652, 45.264782309532166, 48.176607862114906, 49.32282775640488, 52.34872318804264, 53.6862476170063, 57.61604994535446, 55.14703743159771, 56.695146560668945, 57.71650895476341, 56.546487137675285, 49.32934060692787, 43.08201603591442, 32.72167056798935, 24.938671700656414, 23.141107857227325, 19.665384963154793, 15.50326120108366, 10.977536849677563, 5.6854781694710255, 2.5581714045256376, 10.355737265199423, 2.126376824453473, 1.9221647386439145, 3.6604447569698095, 9.007570557296276, 35.523077845573425, 65.95174625515938, 65.39933949708939, 60.061131343245506, 58.788898810744286, 56.4074981957674, 52.27754920721054, 47.53709077835083, 12.801723014563322, 4.278625035658479, 42.83630222082138, 83.477393835783, 54.65874083340168, 16.563468910753727, 23.405073992908, 47.512981072068214, 51.49650111794472, 34.21742230653763, 41.6334767639637, 59.37001682817936, 78.63363415002823, 13.024384416639805, 0.5888889566995203, 0.25426786858588457, 0.23319209169130772, 0.14790164568694308, 0.15603384759742767, 0.19645711756311357, 0.19982447905931622, 0.13492546073393896, 0.11002914470736869, 0.15593684889608994, 0.08767107021412812], [0.05017406256229151, 0.05339007417205721, 0.09392757550813258, 0.032814389778650366, 0.030615413634222932, 0.0446571074280655, 0.031084421279956587, 0.008102298925223295, 0.08343906214577146, 0.11383809891412966, 0.0924105365993455, 0.04109847592189908, 0.0352693215245381, 0.021474501299962867, 0.04855439947277773, 0.16720796440495178, 0.5311606137547642, 37.485398948192596, 60.76109938323498, 48.911062851548195, 36.32266893982887, 43.87092210352421, 43.57894577085972, 19.732504561543465, 18.974773921072483, 58.64848114550114, 65.93476116657257, 10.867329463362694, 7.749741626903415, 49.74895589053631, 60.432607010006905, 56.58553384244442, 52.080066204071045, 54.0966521948576, 51.568058878183365, 41.87770485877991, 4.425879009068012, 1.3181136455386877, 1.9306114478968084, 6.324364487081766, 6.251983121037483, 8.950880449265242, 27.104027308523655, 31.305743046104908, 48.230956345796585, 61.686900705099106, 61.53160683810711, 58.014173582196236, 59.926466569304466, 60.76814040541649, 56.74132168292999, 58.110464215278625, 51.31933182477951, 48.26164349913597, 49.6806887537241, 46.81762218475342, 46.84665262699127, 46.879539862275124, 43.588829040527344, 44.586245119571686, 44.141767770051956, 45.34690350294113, 45.586822628974915, 51.7493661493063, 54.36670370399952, 56.90510429441929, 56.092894077301025, 58.52192893624306, 54.92108255624771, 53.42332452535629, 55.98252899944782, 51.62596397101879, 44.71286192536354, 43.68692457675934, 43.70235554873943, 50.53731478750706, 47.73929312825203, 45.42628884315491, 45.834645330905914, 40.404288321733475, 36.75826996564865, 36.50252848863602, 36.88101477921009, 39.52383756637573, 40.98841577768326, 44.188638255000114, 46.1509707570076, 47.818549275398254, 50.48436842858791, 48.867011815309525, 45.85579499602318, 47.790632173419, 51.60859130322933, 44.90018427371979, 48.0243082344532, 40.741919204592705, 36.77908904850483, 36.293353512883186, 42.98822186887264, 48.580419793725014, 48.822128623723984, 52.04320438206196, 53.588338270783424, 55.031713619828224, 45.86845591664314, 41.42172172665596, 42.62440659105778, 44.81986418366432, 50.92883437871933, 52.38117724657059, 56.5442680567503, 55.12865021824837, 54.042094722390175, 53.17707113921642, 52.40657888352871, 51.659846752882004, 51.83753661811352, 51.036687791347504, 48.06406170129776, 47.24656596779823, 45.11391140520573, 45.8820515871048, 47.36065484583378, 50.38623109459877, 52.28025086224079, 54.11942057311535, 53.87597903609276, 56.534403786063194, 46.48229777812958, 42.11472474038601, 33.59473451972008, 26.357435770332813, 22.668253630399704, 10.558245498687029, 13.874178417026997, 4.4834041222929955, 1.4249155833385885, 5.14307152479887, 2.3230034485459328, 0.2674255531746894, 0.48831758613232523, 0.1391624115058221, 7.943320814520121, 43.24151627719402, 55.81446021795273, 51.264154985547066, 44.34104047715664, 53.36160823702812, 57.89773643016815, 54.547517001628876, 34.310965687036514, 2.855199328623712, 14.491082914173603, 72.0031875371933, 63.38396184146404, 24.48770619928837, 10.287093948572874, 33.24447691440582, 40.93412809073925, 35.38478426635265, 28.396077677607536, 25.741498321294785, 43.19832779467106, 39.354917630553246, 0.83077970193699, 0.05671186409017537, 0.09024110535392538, 0.04946265464241151, 0.047554967750329524, 0.035972228142782114, 0.06849018187494949, 0.05631936073768884, 0.059785297999042086, 0.05374036787543446, 0.018892406260420103, 0.014845736586721614, 0.01208481549838325, 0.03433664969634265, 0.01103269500163151, 0.03893541972502135, 0.03444313304498792, 0.0902897234482225, 0.029935320635559037, 0.03094283620157512, 0.03816449527221266, 0.045070880732964724, 0.04962814615282696, 0.0656250688189175, 0.03279710144852288, 0.019428966043051332, 0.06385424509062432, 0.2685685793403536, 0.6336555420421064, 38.54135848581791, 74.59263458848, 45.82330673933029, 41.07512332499027, 54.17192995548248, 29.996808283030987, 26.477990001440048, 26.089945323765278, 61.49251073598862, 66.9897897541523, 12.828086949884892, 9.207141548395157, 49.78012941777706, 65.55323883891106, 61.727547124028206, 59.203585758805275, 57.36272893846035, 57.135653123259544, 47.35074497759342, 4.657563976943493, 1.2029518000781536, 1.1835483787581325, 9.72713889554143, 9.125560875982046, 12.315745241940022, 33.41113217175007, 36.72687605023384, 52.71346941590309, 64.48310986161232, 65.40676429867744, 61.78989797830582, 63.15025918185711, 64.86685886979103, 60.7852166891098, 62.31971114873886, 55.77798217535019, 50.8066101372242, 51.47785931825638, 48.63743953406811, 49.758155196905136, 47.58163198828697, 44.482810869812965, 46.58653758466244, 45.70740155875683, 47.14035786688328, 48.372867330908775, 51.85310438275337, 57.187087163329124, 59.8168158531189, 57.559482380747795, 60.16104318201542, 57.26991131901741, 58.606178015470505, 59.94219772517681, 54.17591594159603, 48.009219244122505, 44.877894669771194, 47.74965517222881, 56.906164437532425, 54.52372647821903, 51.71046003699303, 52.98836946487427, 48.18941317498684, 43.77243518829346, 42.88343109190464, 42.76268117129803, 45.912921130657196, 47.764740362763405, 49.092043340206146, 53.693968802690506, 53.48889380693436, 57.179035395383835, 57.593783140182495, 53.15267264842987, 56.7780315130949, 57.01139599084854, 51.78213179111481, 54.857124388217926, 48.013266026973724, 41.58349044620991, 40.96674554049969, 48.3140654861927, 53.08792792260647, 54.247006326913834, 54.09007854759693, 57.387351617217064, 57.302536368370056, 48.718215599656105, 43.544409424066544, 46.370861157774925, 48.79600502550602, 52.29719415307045, 54.20325167477131, 55.79269118607044, 57.00213968753815, 55.10983742773533, 54.36230354011059, 53.26287813484669, 52.304668352007866, 51.37001730501652, 52.37382084131241, 50.29841020703316, 48.44301916658878, 46.73753008246422, 47.86234192550182, 48.80228228867054, 51.61681406199932, 53.584660068154335, 54.38063755631447, 57.210892885923386, 56.6967386752367, 48.34419406950474, 45.183626264333725, 34.43999536335468, 29.367360658943653, 22.66937457025051, 14.663536660373211, 19.784050695598125, 5.121776042506099, 2.431895392946899, 7.139747058972716, 2.8203791845589876, 0.1844610573607497, 1.08884297311306, 0.4405585426138714, 10.653437040746212, 46.62189468741417, 61.74888677895069, 54.90100063383579, 51.62335351109505, 58.40436324477196, 62.63078145682812, 59.98684912919998, 35.9724835306406, 2.679259032011032, 19.35406766831875, 61.0939235240221, 63.54362167418003, 36.989605352282524, 17.419319786131382, 26.965604536235332, 29.945756122469902, 46.33880987763405, 21.46473091095686, 23.675368689000607, 56.20561882853508, 41.352428644895554, 2.008697376586497, 0.035621173738036305, 0.12091111508198082, 0.06513111758977175, 0.06005239694786724, 0.03010002175869886, 0.06471113621955737, 0.03246352091082372, 0.06094386844779365, 0.05500409322849009, 0.025514306107652374, 0.01878391169157112, 0.09783746922039427, 0.17011072661262006, 0.12084437374141999, 0.14259623974794522, 0.14746401604497805, 0.09022482263389975, 0.08936358251958154, 0.16429070063168183, 0.13492226949892938, 0.2087611096794717, 0.30963612254709005, 0.13775383005850017, 0.12562578631332144, 0.07923651734017767, 0.1819164407788776, 0.36815310129895806, 0.8743625320494175, 61.97259597480297, 82.52818197011948, 62.055256739258766, 50.286737233400345, 71.06071650981903, 56.61240220069885, 24.450426399707794, 24.789774790406227, 67.70369544625282, 69.44124341011047, 15.405211262404919, 11.4677475951612, 59.575224816799164, 71.21725291013718, 67.91525289416313, 66.07089266180992, 63.54970894753933, 61.71077862381935, 54.006996005773544, 6.438093334436417, 3.407180034555495, 2.366915554739535, 14.615637380629778, 10.741855446249247, 15.140171684324741, 39.09596532583237, 42.879817485809326, 56.44851319491863, 67.61870920658112, 70.30891925096512, 64.47093531489372, 62.99707420170307, 66.58901765942574, 63.45540560781956, 65.0937294960022, 57.98364222049713, 52.63283394277096, 56.192718520760536, 51.32954567670822, 54.66998443007469, 50.499085038900375, 48.434325233101845, 48.45678582787514, 48.97342510521412, 52.02024221420288, 51.20349124073982, 55.9934838116169, 60.31760238111019, 63.81815314292908, 61.66273020207882, 65.07333219051361, 60.49268938601017, 59.93214726448059, 61.38841912150383, 56.7042850703001, 47.93642275035381, 45.79078808426857, 49.63713549077511, 58.12191680073738, 58.88708174228668, 56.00074902176857, 57.39916518330574, 53.106885105371475, 48.79794292151928, 48.83993826806545, 49.230925887823105, 48.58403339982033, 49.5036980509758, 50.746512562036514, 55.41694454848766, 54.270143285393715, 57.837068885564804, 58.19682598114014, 56.13414466381073, 57.01584555208683, 59.073191955685616, 55.11500135064125, 57.44117572903633, 51.62805385887623, 44.973269551992416, 46.188208758831024, 51.993989422917366, 59.006794318556786, 56.473006680607796, 57.31416754424572, 59.03934717178345, 60.17426647245884, 52.17508390545845, 45.26006296277046, 49.345489740371704, 49.579173400998116, 53.45175080001354, 56.1418392509222, 59.15038861334324, 60.12078054249287, 57.51910574734211, 56.400107592344284, 56.752291694283485, 57.100744396448135, 53.88128735125065, 59.02756780385971, 52.73863546550274, 51.24968156218529, 50.7736849039793, 49.69236172735691, 52.709441632032394, 55.152117758989334, 56.732954531908035, 57.813745737075806, 58.87721747159958, 59.5872587710619, 48.98597203195095, 44.0533123165369, 37.246672958135605, 32.00478583574295, 24.300454147160053, 24.7248799726367, 25.43445009738207, 8.611694499850273, 3.072248906828463, 10.64585454761982, 4.996432168409228, 0.6818984658457339, 1.4942545001395047, 1.435320375021547, 11.952021159231663, 49.13100644946098, 67.02519625425339, 58.15072685480118, 55.040700137615204, 63.326740711927414, 67.14236676692963, 64.75373893976212, 44.03959885239601, 4.410270871594548, 19.25226353108883, 81.87438905239105, 71.96855619549751, 33.39466765522957, 14.068167507648468, 41.988845095038414, 56.29270255565643, 54.40334893763065, 36.53392620384693, 37.419943660497665, 62.71527752280235, 68.14989790320396, 4.150504935532808, 0.19591616612160578, 0.15882846404565498, 0.15997215814422816, 0.1362563986913301, 0.08148090550093912, 0.21730950800701976, 0.18282551231095567, 0.16344456322258338, 0.16833165020216256, 0.07916300761280581, 0.10975827564834617], [0.02824759703798918, 0.04420136567205191, 0.06289965022006072, 0.06628348739468493, 0.036958523851353675, 0.1338186365319416, 0.05871636043593753, 0.04629626673704479, 0.017623098101466894, 0.008820183011266636, 0.09812203832552768, 0.1420105664874427, 0.014559486517100595, 0.08254628817667253, 0.03947552140743937, 0.31930814730003476, 0.30809788790065795, 14.366951175034046, 64.73325803875923, 50.963036343455315, 47.48760983347893, 37.981918305158615, 53.833580911159515, 33.224987760186195, 13.949480876326561, 47.49636456370354, 67.5873152911663, 21.97416577488184, 4.346331227570772, 27.47090522199869, 60.63965030014515, 61.588637977838516, 57.706177309155464, 59.61156606674194, 56.530999168753624, 41.741649359464645, 5.692656934261322, 1.5129513968713582, 0.3607123583788052, 0.9861078264657408, 3.641017349436879, 5.4203882440924644, 16.737740859389305, 34.656047970056534, 44.40651096403599, 62.01657861471176, 62.783837243914604, 59.08287763595581, 62.3155427724123, 61.983182206749916, 61.87350869178772, 57.874998450279236, 53.65524888038635, 47.75724336504936, 49.49523210525513, 47.55717650055885, 48.55911813676357, 48.036710768938065, 45.40960393846035, 45.764740481972694, 47.19958148896694, 45.36151371896267, 48.20068717002869, 55.161070078611374, 54.499221593141556, 57.74274654686451, 56.928408443927765, 56.027472987771034, 55.4669688642025, 55.632921159267426, 49.368634298443794, 46.122951060533524, 45.74692323803902, 45.48168607056141, 44.15368013083935, 51.5503404289484, 50.68623639643192, 46.54729709029198, 44.39342066645622, 41.8521474301815, 37.156591191887856, 36.61683015525341, 37.86072000861168, 38.671816885471344, 41.02553978562355, 43.73730227351189, 46.74875847995281, 50.56986764073372, 52.356573566794395, 53.68850089609623, 46.923009529709816, 56.41304589807987, 50.923925042152405, 50.00674165785313, 49.0131101757288, 44.07132714986801, 36.57549977302551, 37.76225969195366, 42.42334797978401, 49.56658087670803, 49.58945944905281, 49.95539501309395, 53.87692518532276, 56.80445909500122, 43.53320762515068, 42.27915331721306, 41.36377863585949, 42.83353976905346, 46.543094515800476, 51.4660457521677, 54.599661603569984, 55.59473320841789, 54.551624581217766, 53.84692959487438, 54.186912551522255, 54.68080244958401, 53.22103098034859, 52.967728972435, 51.79749436676502, 49.90770377218723, 50.60371242463589, 47.69020736217499, 47.875850200653076, 49.19431485235691, 50.208617225289345, 53.47165413200855, 55.710877776145935, 53.465521261096, 53.15125532448292, 49.85397845506668, 42.878050580620766, 39.919369742274284, 29.068852476775646, 17.50295139849186, 8.755697272717953, 5.067498805001378, 6.851570997387171, 2.4257126497104764, 0.12793586938641965, 0.12400673178490251, 0.4827352403663099, 1.4240665663965046, 13.861496597528458, 45.04702739417553, 54.95842695236206, 53.86755868792534, 53.554702475667, 59.09014664590359, 59.73165862262249, 64.62108805775642, 24.649448320269585, 5.342830130830407, 27.85076703876257, 59.86767992377281, 43.30545164644718, 9.542620796710253, 24.46036856621504, 37.19398878514767, 42.320217713713646, 27.297189943492413, 26.932831294834614, 32.00641214847565, 52.1341373026371, 13.163168169558048, 0.6611328176222742, 0.020441843626031186, 0.14339479064801708, 0.08394063523155637, 0.04997809846827295, 0.030293191666714847, 0.022362160016200505, 0.043480836757225916, 0.06500939794932492, 0.04259324668964837, 0.03915309163858183, 0.03398692002519965, 0.021443247605930082, 0.045161029411247, 0.04026284361316357, 0.038363891799235716, 0.02853648729796987, 0.11523145149112679, 0.05026979590184055, 0.0903965778707061, 0.014086680930631701, 0.07693933279369958, 0.1491824589902535, 0.19272291247034445, 0.0332080211956054, 0.05021110686357133, 0.13821549044223502, 0.6397757667582482, 0.17896943172672763, 16.669646613299847, 78.80957990884781, 57.68815487623215, 47.6584866642952, 50.032603070139885, 42.20375396311283, 29.375070445239544, 21.157692186534405, 47.36869141459465, 72.55275204777718, 26.6438776999712, 6.942822150886059, 27.200602926313877, 64.45969551801682, 66.15112155675888, 66.17722615599632, 63.1533408164978, 64.43439647555351, 48.5644568502903, 7.6534737925976515, 0.2740137168439105, 0.3875617770245299, 2.6433606958016753, 4.592958418652415, 6.942618861794472, 21.755968183279037, 42.5239247828722, 46.55652679502964, 67.79793038964272, 66.9692100584507, 63.733375892043114, 64.72562804818153, 65.29187366366386, 65.9422467648983, 60.65140686929226, 56.7806039750576, 50.05470268428326, 51.62488102912903, 50.37695959210396, 49.09493498504162, 49.59996588528156, 46.9319124519825, 47.184929475188255, 48.13836671411991, 46.87304601073265, 48.90538215637207, 56.12833857536316, 56.39854207634926, 58.731126710772514, 58.95494230091572, 59.975567534565926, 57.3957833647728, 59.98374089598656, 54.07402440905571, 49.132036194205284, 47.71452605724335, 45.85682854056358, 48.12756009399891, 55.573777332901955, 55.78711688518524, 53.51244494318962, 52.69188277423382, 49.85984534025192, 45.17721600830555, 43.887238427996635, 42.78182074427605, 43.892117366194725, 46.89227297902107, 49.404975548386574, 49.73807327449322, 55.22770710289478, 58.884425684809685, 58.651695773005486, 49.163601100444794, 57.35371582210064, 56.35729908943176, 54.6533565223217, 54.9211585521698, 47.074875980615616, 41.282706186175346, 42.785301357507706, 48.22885885834694, 55.38238160312176, 54.46319952607155, 53.38487058877945, 55.9505233168602, 57.69834212958813, 47.30683073401451, 46.14323437213898, 45.32772593200207, 47.31955625116825, 49.40101996064186, 52.66593396663666, 54.782777577638626, 57.697946950793266, 54.63556207716465, 53.21501590311527, 56.82567335665226, 55.29584884643555, 54.41328540444374, 52.72738806903362, 52.99916848540306, 51.51019938290119, 52.93483793735504, 48.09704013168812, 49.24291804432869, 49.61600102484226, 51.900408044457436, 54.03449133038521, 57.85017438232899, 54.35908891260624, 54.38311122357845, 51.77381403744221, 43.37949827313423, 41.95593126118183, 29.39112838357687, 17.432689368724823, 13.11455737799406, 5.964634465053678, 7.40245783701539, 2.419792329892516, 0.2494189131539315, 0.2951385051710531, 1.0623221774585545, 1.5528025897219777, 17.882877811789513, 50.26053383946419, 59.967386573553085, 57.84008212387562, 58.25243219733238, 59.06304270029068, 64.05747950077057, 68.16312119364738, 28.3794953674078, 7.249344103038311, 29.676825553178787, 55.11772200465202, 50.08016511797905, 15.251130480319262, 29.4579553976655, 23.19234050810337, 43.15397657454014, 37.209431156516075, 23.12632095068693, 38.725017830729485, 64.21438068151474, 16.722537875175476, 1.0319571755826473, 0.20346937410067767, 0.20064795127836987, 0.056515989053878, 0.06966408138396218, 0.05785189940070268, 0.09366270300233737, 0.07884700855356641, 0.10069542055134661, 0.10489063293789513, 0.04136015348194633, 0.031137451442191377, 0.09221022351994179, 0.2048772876150906, 0.18643840594450012, 0.18076856096740812, 0.17278823215747252, 0.3468740946846083, 0.15451817424036562, 0.2143380674533546, 0.09350964246550575, 0.22927614947548136, 0.20943466806784272, 0.35732849151827395, 0.11224837406189181, 0.1933857097174041, 0.2042174292728305, 0.9242440585512668, 0.3865655476693064, 25.24073649197817, 89.78526055812836, 68.43313470482826, 56.221957951784134, 59.087247401475906, 74.82383698225021, 38.488309532403946, 19.506713077425957, 54.26804579794407, 76.8168756365776, 27.50346377491951, 8.09238776564598, 33.30930523574352, 72.71779999136925, 73.40580627322197, 72.24686846137047, 69.78760242462158, 70.33123165369034, 54.992731511592865, 8.212849851697683, 3.2943994738161564, 1.6734616714529693, 3.652839702554047, 8.146707750856876, 8.548314850777388, 26.92540269345045, 47.072406113147736, 53.47731962800026, 67.54378482699394, 70.31513571739197, 64.56453189253807, 67.08568900823593, 65.98389253020287, 67.84038931131363, 62.59250231087208, 60.608989745378494, 52.6616819947958, 54.93184357881546, 53.860962241888046, 52.937524393200874, 53.77357833087444, 50.87593361735344, 51.34140104055405, 52.81909994781017, 50.3319738060236, 55.07147468626499, 59.938188940286636, 59.911039397120476, 61.17421321570873, 62.082987651228905, 62.29622840881348, 60.54215133190155, 62.49858275055885, 54.764622151851654, 50.08390411734581, 48.60474228858948, 48.432223945856094, 50.173381716012955, 59.60842743515968, 58.94024848937988, 58.12447026371956, 54.966072142124176, 54.433295130729675, 48.51954326033592, 48.40426504611969, 49.382955729961395, 48.22476267814636, 49.28623951971531, 51.79165408015251, 52.53317289054394, 55.95886006951332, 59.00802165269852, 60.91510131955147, 52.58295401930809, 59.54491384327412, 57.30951279401779, 59.30624105036259, 57.50533528625965, 52.954992055892944, 44.471886456012726, 46.384057849645615, 51.57875910401344, 59.3332652002573, 57.4471528083086, 55.54349295794964, 59.709023237228394, 60.99124163389206, 48.50749030709267, 47.945059686899185, 46.51272274553776, 48.801051154732704, 50.046365931630135, 53.53207089006901, 57.79154732823372, 59.00401286780834, 56.77427351474762, 55.73648080229759, 59.40284326672554, 58.81803184747696, 56.55480869114399, 58.0717670917511, 56.489034220576286, 55.13436511158943, 54.75470468401909, 52.40549974143505, 51.53761871159077, 54.11728888750076, 52.64099970459938, 56.25713646411896, 60.89517138898373, 56.73197418451309, 56.88289448618889, 53.204152286052704, 47.60595828294754, 43.04244875907898, 33.795314356684685, 23.5098609700799, 14.314798973500729, 7.149070808663964, 10.705743134021759, 4.8215817008167505, 1.1850896710529923, 0.8135704847518355, 1.6815192578360438, 2.5247011380270123, 17.721441574394703, 53.57247792184353, 64.22839432954788, 64.11548718810081, 62.499707490205765, 64.01891157031059, 71.3845731317997, 73.13870340585709, 31.488034464418888, 6.518962970003486, 32.128324806690216, 66.73235356807709, 53.11859607696533, 13.365823645144701, 30.900162309408188, 45.261480286717415, 61.17745444178581, 42.35411949455738, 37.57019139826298, 45.82302935421467, 78.81938338279724, 33.79960812628269, 1.3513226760551333, 0.45184669783338904, 0.2896429906832054, 0.2764153660973534, 0.16083771013654768, 0.19214047497371212, 0.10434615629492328, 0.22025129233952612, 0.12950488831847906, 0.3403076314134523, 0.15369495435152203, 0.19877006532624364], [0.01972553011000855, 0.04439287688001059, 0.022153783502290025, 0.047880098936730064, 0.048080259875860065, 0.012943043420818867, 0.049653078604023904, 0.025331236829515547, 0.06417103824787773, 0.11637430696282536, 0.030179567002051044, 0.08694473028299399, 0.033553850880707614, 0.1159919673227705, 0.06327636438072659, 0.15701478871051222, 0.17522082896903157, 5.701925586909056, 70.50156131386757, 46.91512495279312, 65.07926747202873, 38.68074640631676, 41.88170604407787, 41.35279722511768, 20.568397007882595, 28.4708234667778, 64.21833246946335, 28.141438141465187, 13.020555172115564, 30.236892700195312, 60.3216415643692, 58.03289897739887, 59.489577412605286, 54.01242211461067, 58.39145913720131, 46.68926887214184, 10.790154654532671, 0.9102109365630895, 0.22581883968086913, 4.274764442816377, 0.730581097304821, 3.267623735591769, 20.272786170244217, 39.211197942495346, 51.14951893687248, 65.53256794810295, 63.36853466928005, 63.862185180187225, 62.40985371172428, 63.21452513337135, 63.1625135242939, 59.74749617278576, 53.54642651975155, 49.10620138049126, 47.99788825213909, 48.43938276171684, 46.058654710650444, 43.58635917305946, 45.41089966893196, 46.48487403988838, 47.68145643174648, 48.02564576268196, 51.14975072443485, 54.02626857161522, 59.672047421336174, 58.60870487987995, 55.325688645243645, 55.799561217427254, 54.607044607400894, 48.93557533621788, 44.78939361870289, 47.134859561920166, 43.22528354823589, 44.09049712121487, 43.210817724466324, 49.92891803383827, 50.86839102208614, 45.468314588069916, 43.97420436143875, 41.52281530201435, 38.23403097689152, 37.5264785438776, 37.28670381009579, 40.41275046765804, 43.95131818950176, 44.83106978237629, 47.79082976281643, 52.04287759959698, 55.50342410802841, 50.861368998885155, 50.755483880639076, 58.56317192316055, 50.404295325279236, 53.46594303846359, 49.88783843815327, 45.20536869764328, 37.280270755290985, 38.278328999876976, 42.69123360514641, 49.08058315515518, 49.723295867443085, 52.31682009994984, 53.04556019604206, 55.76338715851307, 44.03256542980671, 39.88917276263237, 43.69442157447338, 44.30007487535477, 43.939341232180595, 49.648683071136475, 52.66057625412941, 55.228163078427315, 55.930642783641815, 55.042254254221916, 55.258287861943245, 53.8228464871645, 54.91120308637619, 56.63886398077011, 56.66730925440788, 52.604137882590294, 53.58716793358326, 50.40000155568123, 46.834744065999985, 46.92595437169075, 53.52979861199856, 54.421580359339714, 54.79105353355408, 52.91761726140976, 54.07076418399811, 50.14003470540047, 50.31481772661209, 48.39191570878029, 43.38097259402275, 28.336700163781643, 17.941022291779518, 9.130216576159, 5.292508481070399, 1.4124325406737626, 0.4700662154937163, 0.35221200669184327, 0.451574003091082, 2.714118123985827, 23.546325713396072, 52.52213068306446, 54.661385491490364, 56.93771794438362, 56.65783256292343, 56.97823517024517, 57.97200344502926, 46.324313655495644, 12.62357622385025, 9.762990921735764, 58.604798689484596, 80.15679761767387, 35.53859621286392, 15.475582536309958, 30.516472198069096, 36.87609024345875, 39.31442320346832, 33.46453070640564, 29.613091573119164, 33.89350488781929, 48.6624725908041, 4.8472189251333475, 0.30733110092114657, 0.01976111609110376, 0.13491579797118902, 0.07450088785844855, 0.05648214340908453, 0.1015725574688986, 0.04181346099358052, 0.011372111603122903, 0.029042856513115112, 0.02212270235759206, 0.03217528559616767, 0.06840270492830314, 0.01767549001669977, 0.03213948068150785, 0.03764446868444793, 0.03527569286234211, 0.05775812533101998, 0.03841527068288997, 0.047167121374513954, 0.0370958916755626, 0.06574404251296073, 0.04574032762320712, 0.03192410942574497, 0.055820092020439915, 0.058173872748739086, 0.011235446963837603, 0.04583001616992988, 0.31121621432248503, 0.05058957249275409, 6.7602120246738195, 75.62743306159973, 60.726008266210556, 60.183104798197746, 48.219902738928795, 44.816341772675514, 28.943301513791084, 26.29275754094124, 34.301318004727364, 60.38146175444126, 26.918496564030647, 13.069126065820456, 33.339414820075035, 63.86694252490997, 62.38565281033516, 67.13812619447708, 59.74438413977623, 65.48918947577477, 49.40284006297588, 11.381530221551657, 1.1877254233695567, 0.45649637177120894, 4.3464224226772785, 0.7976977864746004, 3.7731621460989118, 21.367245241999626, 43.70591215789318, 56.07896402478218, 68.08781683444977, 67.07055822014809, 67.11626216769218, 64.44585666060448, 65.16937583684921, 65.18210515379906, 64.20529916882515, 57.435373440384865, 51.224382519721985, 49.63010586798191, 50.442582070827484, 48.137709349393845, 45.26030994951725, 46.157578602433205, 47.978235706686974, 49.195758774876595, 49.532386511564255, 53.407642766833305, 57.735469937324524, 62.25297912955284, 60.307855904102325, 57.353936210274696, 57.06021577119827, 57.156627997756004, 53.370879739522934, 49.07842867076397, 48.296548426151276, 46.822618916630745, 44.7960090637207, 46.46000437438488, 55.09952858090401, 57.22244046628475, 54.9606878310442, 49.275242909789085, 49.8028863966465, 45.02649329602718, 44.39190074801445, 43.82319286465645, 45.31289912760258, 49.05911810696125, 48.10596205294132, 53.13446022570133, 56.51382029056549, 59.85695689916611, 57.68865264952183, 52.21768341958523, 63.49280700087547, 57.908664643764496, 58.46585154533386, 53.62923547625542, 48.42214308679104, 40.69707401096821, 44.89374361932278, 48.14898334443569, 56.03312328457832, 53.736990094184875, 56.06753423810005, 57.724142745137215, 58.76741096377373, 47.92055860161781, 42.90896192193031, 44.41894389688969, 46.36924244463444, 47.3623913526535, 51.371472626924515, 55.629277154803276, 55.32879687845707, 54.45731744170189, 54.78285737335682, 55.08865736424923, 54.3184956908226, 56.30566745996475, 56.355482786893845, 57.65845946967602, 54.70174692571163, 54.45743903517723, 52.095329985022545, 47.80539058148861, 48.666986748576164, 53.46761494874954, 57.38110475242138, 57.891899943351746, 53.790263235569, 57.03927889466286, 52.346120327711105, 51.42444558441639, 49.6212637424469, 45.002774968743324, 30.925552546977997, 20.164110101759434, 9.867823496460915, 5.808000219985843, 1.4585499535314739, 0.5333820101805031, 0.5702298204414546, 0.8084579778369516, 3.8115956587716937, 26.792567521333694, 56.02911449968815, 58.18425625562668, 59.755646735429764, 61.778114810585976, 63.10869701206684, 64.45081919431686, 51.3855204731226, 13.311651851981878, 12.77105201035738, 53.59718419611454, 72.70485028624535, 41.308818385005, 19.151092059910297, 29.833546243607998, 22.15505886822939, 49.58671219646931, 36.60480000078678, 28.343167416751385, 41.66379913687706, 59.1290907561779, 7.135096108540893, 0.38290239579509944, 0.03170539108396042, 0.14291368599515408, 0.09074222572962753, 0.027920833126700018, 0.009152436959993793, 0.07128162935259752, 0.012261348310858011, 0.03494858756312169, 0.03848056112474296, 0.033464284788351506, 0.004185173911537277, 0.08512447951943614, 0.2352753299055621, 0.11907194697414525, 0.12818116403650492, 0.13076964154606685, 0.13734860258409753, 0.1857148713315837, 0.13378273142734542, 0.2013110156985931, 0.15858263504924253, 0.11207650750293396, 0.15993813809473068, 0.09229041999788024, 0.2371423359727487, 0.2620465855579823, 0.5176296585705131, 0.37787140638101846, 10.88099543005228, 93.67059007287025, 67.22776338458061, 76.52945145964622, 53.03734503686428, 69.43111315369606, 51.47460289299488, 24.752831272780895, 36.24209426343441, 69.9776454269886, 33.16920295357704, 18.67765076458454, 37.9127886146307, 72.00479105114937, 66.13490402698517, 72.92250260710716, 65.73137328028679, 73.24644282460213, 58.14356803894043, 15.757710747420788, 2.334283380769193, 1.0101652261801064, 5.73387854732573, 1.6126095992513, 4.76370083168149, 23.44700664281845, 45.225815400481224, 61.02009728550911, 69.39743176102638, 69.77335318922997, 68.40209797024727, 63.98833841085434, 66.614278703928, 68.65427523851395, 66.6376094520092, 58.34678493440151, 52.6626243442297, 51.92097634077072, 52.42504209280014, 51.691396459937096, 47.524198070168495, 50.458343625068665, 51.373908296227455, 53.429218009114265, 52.96492852270603, 56.42699874937534, 60.569449067115784, 67.26658210158348, 62.49632187187672, 60.220327600836754, 59.61185485124588, 59.17374595999718, 54.01953153312206, 48.543162792921066, 50.79918533563614, 46.43991865217686, 45.77516712248325, 48.53380009531975, 56.68180167675018, 62.503549084067345, 56.85262531042099, 49.561139568686485, 54.0819051861763, 46.11434452235699, 48.14096957445145, 46.82943195104599, 49.64688576757908, 51.380383148789406, 48.94795887172222, 54.91271160542965, 58.02847981452942, 59.32009890675545, 57.21652798354626, 57.387385815382004, 62.11064636707306, 57.86993332207203, 60.05197763442993, 56.08685240149498, 51.819859966635704, 43.36534783244133, 48.16132128238678, 51.91330075263977, 59.32082086801529, 58.0752819031477, 59.370442405343056, 60.25892212986946, 60.28633385896683, 50.08297696709633, 44.884996488690376, 47.258314937353134, 47.835013791918755, 49.82358008623123, 50.81251502037048, 56.83164283633232, 60.45002527534962, 57.71943099796772, 57.85762958228588, 57.472573444247246, 58.13425473868847, 58.52515496313572, 59.754240810871124, 60.40433272719383, 57.159029468894005, 57.89603412151337, 54.11009207367897, 51.73295482993126, 50.8162160217762, 56.866118386387825, 59.82048265635967, 59.02671664953232, 55.474845841526985, 60.167024061083794, 55.10390214622021, 55.88431566953659, 52.96294502913952, 48.56907360255718, 31.7657083645463, 20.328918658196926, 11.246874947100878, 7.426318656653166, 3.313938262872398, 1.3615745259448886, 0.9635094297118485, 1.5868454379960895, 4.009415181353688, 25.337648391723633, 61.459931284189224, 66.29070326685905, 65.43878138065338, 65.90182453393936, 67.64877319335938, 68.04135292768478, 56.53921812772751, 16.78686462342739, 11.383483316749334, 65.0582318007946, 86.30311980843544, 44.55923616886139, 18.824334293603897, 35.325632840394974, 48.286642357707024, 59.97982710599899, 42.74296782910824, 43.0225720256567, 47.14356869459152, 78.6124236881733, 13.623985592275858, 0.6517625204287469, 0.223449073091615, 0.16244183265371248, 0.18551702960394323, 0.31080488639418036, 0.1790360765880905, 0.1610356112360023, 0.12794173235306516, 0.10009271500166506, 0.11351496781571768, 0.11143117299070582, 0.18799008830683306], [0.08884778988431208, 0.07192688222858123, 0.04648516187444329, 0.039131688099587336, 0.054541404970223084, 0.03430820317589678, 0.041373590065632015, 0.06064912449801341, 0.17149073537439108, 0.10667129754438065, 0.179694524849765, 0.07835327254724689, 0.04352834905148484, 0.06148335414764006, 0.09854089905275032, 0.1611589710228145, 0.4716381139587611, 1.2716679065488279, 49.21293005347252, 59.04607281088829, 52.79174141585827, 42.64524847269058, 34.39546175301075, 44.934876412153244, 24.595020040869713, 16.248026937246323, 70.47998607158661, 84.66158509254456, 21.624928414821625, 14.546490591019392, 40.83631753921509, 55.450397953391075, 61.38677000999451, 58.463803455233574, 59.82088923454285, 49.28144797682762, 13.162572551518679, 0.6832127796951681, 0.2838025556411594, 0.9073213103692979, 0.6683083169627935, 6.306381952017546, 24.08410705626011, 46.75840616226196, 54.32764180004597, 63.075103014707565, 60.18739476799965, 67.80916258692741, 62.93370500206947, 65.1171362400055, 67.02581942081451, 61.64028860628605, 57.07551755011082, 50.01848682761192, 50.9682534635067, 47.16624207794666, 48.353625163435936, 49.67638358473778, 49.12105478346348, 49.41585436463356, 48.74927893280983, 49.12050761282444, 54.406153187155724, 55.40048383176327, 58.96091938018799, 58.35475690662861, 57.39783525466919, 57.447319999337196, 55.039833784103394, 49.02150772511959, 46.68234944343567, 45.16423210501671, 43.963249549269676, 45.40288969874382, 43.13458241522312, 49.37554992735386, 50.95149636268616, 46.667271852493286, 45.861331298947334, 41.858056113123894, 38.413506746292114, 38.638401478528976, 37.29136236011982, 41.06240160763264, 44.245783388614655, 45.18015705049038, 48.30079659819603, 50.37199705839157, 56.15168832242489, 52.39693500101566, 57.01100841164589, 61.12705014646053, 52.01729357242584, 53.310478180646896, 51.162829622626305, 51.43955357372761, 39.35414247214794, 40.41935071349144, 43.3282770216465, 48.014158979058266, 49.304930716753006, 51.6180831938982, 53.99948000907898, 54.593152552843094, 43.72885912656784, 42.11052976548672, 42.827756479382515, 45.28297193348408, 44.77966234087944, 47.357067838311195, 52.38092266023159, 52.0235176384449, 53.01396869122982, 56.821493580937386, 56.246364042162895, 54.42429341375828, 53.012102991342545, 52.26496048271656, 56.52389355003834, 55.674080550670624, 54.62990038096905, 53.99142824113369, 49.727677032351494, 50.36083325743675, 54.17948395013809, 56.439237892627716, 55.53571097552776, 55.0268916785717, 54.84359331429005, 48.65272991359234, 52.589364275336266, 45.331890508532524, 45.21191194653511, 33.00564453005791, 23.02682898938656, 12.969518210738897, 9.269031677395105, 2.9392159078270197, 0.7384128333069384, 0.08723165199626237, 1.0848590056411922, 4.924379959702492, 27.0532164350152, 51.419794633984566, 51.278259828686714, 56.841507107019424, 56.27567946910858, 55.76396092772484, 59.20990861952305, 36.39688275754452, 7.868070602416992, 39.836309999227524, 71.42557293176651, 44.01342585682869, 18.17354131489992, 17.972824685275555, 37.36649572849274, 41.83498755097389, 27.588132731616497, 26.45969208329916, 24.941116869449615, 45.5711180716753, 40.30276156961918, 1.2417491432279348, 0.1332055780221708, 0.051912862618337385, 0.053936231779516675, 0.017698863957775757, 0.021431215536722448, 0.030209026554075535, 0.11144958567456342, 0.029130591356079094, 0.05043024822953157, 0.05706037663912866, 0.012938507043145364, 0.06503483877168037, 0.0625719029631, 0.04501699339016341, 0.061689066351391375, 0.024358318332815543, 0.05064206830866169, 0.031045104151417036, 0.012940706583322026, 0.037310669213184156, 0.07505075991502963, 0.07236936551635154, 0.10290639722370543, 0.04571342476992868, 0.0779079319909215, 0.0726645695976913, 0.074909076502081, 0.11611390960752033, 0.5632600444369018, 1.026417191606015, 54.520014077425, 72.01712518930435, 54.749787747859955, 43.577570244669914, 51.4670716971159, 33.11070889234543, 30.498924739658833, 22.14227255433798, 60.676812306046486, 73.55801850557327, 24.39552314579487, 15.951832830905914, 41.93157456815243, 58.61988008022308, 66.7540580034256, 64.70392361283302, 65.65040722489357, 53.179689198732376, 17.770297452807426, 0.6391379947308451, 0.6139841163530946, 0.8406139304861426, 1.1444869497790933, 8.645782470703125, 27.20597393810749, 49.35464344918728, 59.93465892970562, 65.47754690051079, 64.86430540680885, 70.57162195444107, 66.86109066009521, 67.16325804591179, 70.70275291800499, 64.48750242590904, 58.7856537848711, 52.05953970551491, 54.31070230901241, 49.58914786577225, 49.24461655318737, 50.94761297106743, 49.90063235163689, 51.18888862431049, 51.29744499921799, 50.12139290571213, 56.59868873655796, 59.79750528931618, 60.17007529735565, 59.473952651023865, 57.821136340498924, 56.85908116400242, 57.38075137138367, 50.13089619576931, 48.426984027028084, 46.86939060688019, 46.971673518419266, 46.762893721461296, 45.030722469091415, 52.73023031651974, 54.942935183644295, 52.128327414393425, 52.490349188447, 48.53116683661938, 44.82805274426937, 44.19099032878876, 42.26750694215298, 47.26358525454998, 48.30897755920887, 49.41043585538864, 52.17486351728439, 56.65444314479828, 60.00981129705906, 56.44195094704628, 57.82294504344463, 62.14726120233536, 56.56483255326748, 58.18226896226406, 54.40018750727177, 53.64503122866154, 41.62642814218998, 45.765169858932495, 48.0568952858448, 54.83079180121422, 55.34770466387272, 55.43141417205334, 56.7553049325943, 57.96204797923565, 46.00022904574871, 44.37288276851177, 46.41783803701401, 47.19119533896446, 48.59417885541916, 48.32939766347408, 53.86210598051548, 54.56135965883732, 54.13653485476971, 57.020994275808334, 55.48768535256386, 54.79176789522171, 56.14184305071831, 52.80042015016079, 58.260856345295906, 56.07655495405197, 56.28638729453087, 55.136021822690964, 50.20522400736809, 51.47257000207901, 57.236343920230865, 60.23284412920475, 56.820395439863205, 56.388636007905006, 54.177891835570335, 51.28648638725281, 55.61135731637478, 50.06216548383236, 48.078333735466, 33.27317677438259, 22.72037923336029, 13.740094061940908, 10.464967153966427, 2.987361936829984, 1.4789491589181125, 0.8529849979095161, 1.0606267559342086, 5.3584681916981936, 28.67022156715393, 56.99680097401142, 56.57302491366863, 61.540787145495415, 60.3047476708889, 62.95648477971554, 63.87422293424606, 40.644754618406296, 8.569436967372894, 43.36079567670822, 55.23265063762665, 45.232126861810684, 24.449406154453754, 22.042962983250618, 27.824043072760105, 30.350896082818508, 39.95036467909813, 22.818974442780018, 30.015508979558945, 56.619728207588196, 49.66556176543236, 1.9311092211864889, 0.11452674516476691, 0.04138011725444812, 0.0905824635992758, 0.025176198469125666, 0.018587695267342497, 0.04218135843984783, 0.12027265285723843, 0.054866317223059013, 0.04178906659944914, 0.043432775273686275, 0.08052930890698917, 0.05075565029983409, 0.2409777551656589, 0.14269924984546378, 0.122398119274294, 0.18435295613016933, 0.156331671460066, 0.09954554436262697, 0.13694379071239382, 0.10914588507148437, 0.23552553757326677, 0.10454516319441609, 0.29273169056978077, 0.2092617773450911, 0.16994493082165718, 0.14190432062605396, 0.32338057877495885, 0.24207154725445434, 0.6023881479632109, 1.457593236118555, 70.39726451039314, 76.42874926328659, 73.09158593416214, 54.43390689790249, 60.76186314225197, 59.57466624677181, 29.820885322988033, 21.552036926150322, 75.51724657416344, 90.40679320693016, 26.33039642125368, 18.397294208407402, 51.69108487665653, 66.4437210559845, 73.1282539665699, 69.51936721801758, 72.36774757504463, 59.14906248450279, 20.89655689895153, 1.8081427132710814, 1.3940351153723896, 1.7967772856354713, 2.4226462142542005, 10.72715973481536, 30.470464266836643, 53.50753180682659, 61.9818826764822, 68.74026462435722, 66.6061395406723, 74.34212163090706, 68.81929278373718, 69.67189103364944, 72.71802797913551, 66.61910444498062, 61.90975494682789, 57.305956184864044, 56.14962123334408, 52.168065682053566, 51.73785276710987, 56.55658319592476, 52.26779893040657, 54.28634561598301, 55.61586007475853, 53.74493166804314, 59.50258031487465, 64.3544639647007, 64.15867567062378, 60.29802583158016, 62.11700342595577, 59.69885878264904, 61.075000539422035, 52.043500766158104, 51.746903881430626, 48.4989445656538, 46.21490992605686, 48.85518305003643, 46.67415328323841, 56.59372620284557, 56.30401834845543, 57.00100734829903, 56.689169481396675, 53.22590231895447, 48.23468394577503, 49.25063543021679, 43.6819202452898, 51.77984431385994, 50.01358509063721, 51.51164710521698, 51.25174105167389, 56.20640158653259, 60.29950015246868, 58.89302082359791, 59.89987939596176, 62.86257661879063, 57.19952769577503, 59.630785435438156, 56.43475033342838, 58.6753761023283, 45.06797567009926, 49.08991925418377, 52.76429168879986, 57.161438539624214, 57.62370653450489, 56.16955876350403, 61.2030840665102, 59.43169891834259, 48.22495646774769, 47.351227551698685, 47.90162421762943, 48.922287449240685, 48.84378746151924, 50.185541063547134, 54.77720707654953, 57.496325969696045, 55.62941014766693, 60.34567907452583, 58.195693641901016, 57.81517066061497, 57.944447323679924, 56.32312372326851, 61.42075918614864, 59.52283702790737, 59.122251123189926, 57.555177211761475, 53.79156656563282, 53.39745171368122, 60.374853909015656, 62.790988460183144, 60.26800364255905, 58.18611055612564, 57.49194100499153, 55.58928810060024, 60.975407883524895, 52.545852810144424, 52.34271951019764, 35.78146778047085, 25.392036773264408, 14.38977750018239, 11.575980987399817, 3.9175814716145396, 2.286984706297517, 1.9085932918824255, 1.9155630678869784, 7.300433311611414, 31.319840289652348, 61.8006855994463, 61.3198783993721, 67.00029239058495, 66.47760763764381, 69.01568904519081, 68.72821927070618, 44.69337657094002, 10.334021430462599, 46.3315636664629, 76.5261760354042, 54.724576100707054, 26.23648826032877, 21.74477968364954, 46.640635281801224, 55.75524799525738, 43.1373942643404, 35.60964100062847, 39.737503901124, 62.13971480727196, 70.13033643364906, 3.890467551536858, 0.40907378832343966, 0.1496380040771328, 0.21822516981046647, 0.11996381552307867, 0.07853131377487443, 0.09520484134554863, 0.2555427001789212, 0.18385341652901843, 0.13339438039110973, 0.1407453531282954, 0.1549231048556976, 0.1196228431945201], [0.015839116094866768, 0.060655558918369934, 0.005862185071237036, 0.0420045306236716, 0.026985393087670673, 0.05110966587380972, 0.06062918298994191, 0.006243195339266094, 0.09759718406712636, 0.10466304593137465, 0.04461356933461502, 0.05011002635001205, 0.17889103124616668, 0.07670526683796197, 0.0777181499870494, 0.020953337370883673, 0.36095005343668163, 0.1388673929614015, 22.11241375654936, 69.58047553896904, 39.525125697255135, 37.009337693452835, 33.72495353221893, 39.68769617378712, 33.218007534742355, 22.490231283009052, 62.70501807332039, 81.81497544050217, 48.25039990246296, 14.239733051508665, 18.848658688366413, 43.043850883841515, 62.23239183425903, 55.626541301608086, 54.635189697146416, 53.83435606956482, 22.843264639377594, 1.3700278848409653, 0.3126154892379418, 0.8151849824935198, 0.8377862884663045, 10.730357263237238, 34.12154585123062, 53.30030992627144, 59.41975615918636, 61.029809564352036, 60.21517887711525, 66.66772663593292, 69.72761884331703, 67.19168812036514, 64.70526874065399, 60.705683156847954, 57.552836537361145, 50.43738774955273, 49.81830596923828, 54.39880818128586, 54.769261702895164, 54.85688880085945, 54.52997334301472, 55.63188001513481, 55.54456070065498, 54.55763205885887, 56.7284631729126, 57.09862411022186, 60.895007997751236, 56.98324330151081, 57.08673074841499, 56.731651201844215, 55.53154639899731, 50.557909682393074, 48.36408220231533, 48.33019562065601, 43.589258417487144, 44.24777068197727, 40.61322771012783, 42.39802233874798, 46.88739784061909, 45.323359966278076, 43.859043940901756, 42.55921728909016, 39.61605101823807, 38.42608027160168, 39.908015951514244, 43.48222576081753, 45.59790663421154, 47.82639965415001, 50.91532990336418, 52.68415778875351, 55.31721509993076, 51.334504410624504, 60.978744104504585, 54.32820037007332, 53.96737553179264, 53.328192830085754, 53.043059930205345, 50.68641498684883, 42.296206802129745, 38.78924958407879, 42.69366927444935, 48.01081895828247, 50.89685529470444, 52.298064306378365, 54.97664697468281, 52.90972888469696, 42.270892560482025, 39.24195349216461, 43.49959462881088, 46.61423049867153, 46.311914920806885, 46.32472023367882, 48.07148650288582, 52.8085745126009, 53.32375466823578, 53.82444620132446, 57.07821920514107, 57.21023932099342, 56.434366554021835, 53.858241587877274, 47.62474067509174, 51.44752934575081, 54.445918053388596, 54.39423322677612, 50.09776197373867, 51.47912085056305, 53.628213331103325, 56.30100131034851, 53.415686935186386, 54.70031440258026, 49.516822546720505, 49.72126677632332, 47.97419652342796, 50.28038017451763, 47.199729681015015, 36.073166728019714, 28.652183935046196, 21.628815606236458, 15.897116716951132, 8.022463917732239, 2.228488507680595, 1.0755771724507213, 0.5937849939800799, 4.687812253832817, 26.3136488199234, 52.19444386661053, 53.032838478684425, 54.170755818486214, 54.26809139549732, 51.415899842977524, 55.549166053533554, 30.220171697437763, 16.693919710814953, 59.73451226949692, 57.730644196271896, 33.47138173878193, 13.271351214498281, 24.827702455222607, 41.45440377295017, 34.552210941910744, 27.145340591669083, 37.26855978369713, 25.870685689151287, 59.873641803860664, 15.539015382528305, 0.44702653773128986, 0.09278990764869377, 0.16062379349023104, 0.07699498644797131, 0.06158504693303257, 0.09342631412437186, 0.09712638784549199, 0.016992057353490964, 0.1118708064313978, 0.041250007634516805, 0.017593208103789948, 0.029126426052243914, 0.03480183157080319, 0.08116043129120953, 0.05715687068004627, 0.016078876178653445, 0.008557233595638536, 0.014967822662583785, 0.058065470948349684, 0.11660222793580033, 0.037713492129114456, 0.11413007465307601, 0.11652736749965698, 0.027721074802684598, 0.053999154770281166, 0.15808334777830169, 0.029711012066400144, 0.048223694757325575, 0.025427207656321116, 0.5489889008458704, 0.03091435442911461, 23.7233829125762, 79.11642104387283, 50.65919704735279, 34.820639938116074, 41.30182296037674, 31.67097944766283, 29.153086356818676, 28.603597842156887, 60.932120606303215, 75.69161921739578, 57.064376547932625, 24.63827881962061, 22.052409276366234, 44.304634630680084, 68.03354054689407, 62.187896221876144, 59.9821487814188, 60.449079126119614, 27.29481127113104, 1.9798204698599875, 0.30154172563925385, 0.7538753910921514, 1.5433912072330713, 11.408140193670988, 35.35385772585869, 57.53034174442291, 62.74536430835724, 62.70659498870373, 64.811442643404, 68.82345736026764, 71.65761888027191, 69.32216539978981, 65.23502871394157, 62.86504648625851, 60.647930055856705, 52.20392055809498, 50.722562447190285, 55.48803113400936, 58.878543600440025, 54.81710493564606, 55.59615433216095, 57.602898851037025, 55.38198262453079, 56.65127411484718, 60.05185604095459, 59.53304708003998, 63.14906224608421, 59.16994236409664, 58.38413693010807, 58.33886615931988, 57.42432743310928, 52.293854132294655, 49.92761850357056, 49.28150877356529, 46.09363943338394, 46.17629639804363, 44.11637753248215, 47.362486347556114, 52.24601089954376, 51.06028452515602, 49.2240596562624, 48.053118288517, 46.237370520830154, 43.739050179719925, 46.81195288896561, 46.82576134800911, 52.22087524831295, 50.954023227095604, 55.1246452331543, 57.482734099030495, 60.693018436431885, 55.1851873844862, 62.18685507774353, 57.264496609568596, 60.36195360124111, 57.25365199148655, 57.36502401530743, 53.83426107466221, 45.953206568956375, 42.64013774693012, 48.45661863684654, 53.44937592744827, 54.79423776268959, 54.99738246202469, 57.49213479459286, 56.7679962515831, 44.812990352511406, 44.598738849163055, 45.679701045155525, 49.833444356918335, 49.0433831512928, 48.889126628637314, 51.32825754582882, 53.86560179293156, 54.37430329620838, 54.51552651822567, 56.890763863921165, 57.345702052116394, 58.73895809054375, 55.578777864575386, 49.604385048151016, 52.66263574361801, 57.56822191178799, 54.444493129849434, 50.474637150764465, 52.57986858487129, 56.48330792784691, 56.7224632948637, 55.182774513959885, 56.791463792324066, 52.31705568730831, 51.9423121958971, 53.10541458427906, 53.81269343197346, 50.38118876516819, 40.05142405629158, 29.059554375708103, 21.823099181056023, 15.466308183968067, 9.7747265920043, 2.5849060574546456, 0.555268123280257, 0.8686665783170611, 6.1446863785386086, 30.218792371451855, 57.07616351544857, 57.742305770516396, 59.79114443063736, 55.92251881957054, 58.23737360537052, 60.675843358039856, 34.10816676914692, 17.41317931562662, 58.29648703336716, 61.24354809522629, 41.59381069242954, 18.469416238367558, 26.583605334162712, 23.15188217908144, 38.109576255083084, 33.20717051625252, 35.92547245323658, 33.234445452690125, 65.27227431535721, 20.011892169713974, 0.5654369120020419, 0.17292388190981, 0.19039620528928936, 0.11437933237175457, 0.08996046963147819, 0.019712019311555196, 0.11858320562168956, 0.010641104490787257, 0.10584620002191514, 0.012422093786881305, 0.0321641014306806, 0.03042937762074871, 0.015852595352043863, 0.2143570367479697, 0.13927867636084557, 0.08596608240623027, 0.21845176233910024, 0.11622843041550368, 0.13696296780835837, 0.29848205856978893, 0.10287845536367968, 0.20344610034953803, 0.28929308289662004, 0.199537297594361, 0.11980630952166393, 0.38376880867872387, 0.12286003198823892, 0.16505965468240902, 0.08859000488882884, 0.7421980239450932, 0.12184838080429472, 34.911736249923706, 92.46875256299973, 61.226008236408234, 50.31510651111603, 51.38351798057556, 60.18707558512688, 40.646187141537666, 28.70388776063919, 73.09971749782562, 89.90367740392685, 55.5776759237051, 21.919389814138412, 23.842360228300095, 53.05650360882282, 73.30014154314995, 68.27184855937958, 65.11512994766235, 66.26657456159592, 30.42388826608658, 2.3672827100381255, 0.7571978971827775, 2.1464563719928265, 2.3042094195261598, 13.192345853894949, 36.96693956851959, 60.507022216916084, 65.97147479653358, 66.53739362955093, 66.5823832154274, 75.12795746326447, 71.63984343409538, 69.25689250230789, 69.38590317964554, 65.17292484641075, 64.72639560699463, 55.5869360268116, 52.97747544944286, 59.52302321791649, 61.41881749033928, 58.62252853810787, 58.29183988273144, 61.300237253308296, 61.174087822437286, 61.355049312114716, 63.56380619108677, 65.28828665614128, 69.25686210393906, 61.124838665127754, 61.56627997756004, 61.102989837527275, 59.38293233513832, 54.333755671978, 52.54998318850994, 51.072713658213615, 47.050032913684845, 47.99587815999985, 45.23129090666771, 48.08698587119579, 53.32329869270325, 54.78894464671612, 52.787132263183594, 50.51854379475117, 48.008592277765274, 45.69765128195286, 49.95119623839855, 49.642269015312195, 53.823522850871086, 54.53246980905533, 55.29052913188934, 57.44093254208565, 61.25544525682926, 56.9779159873724, 60.780881121754646, 56.41055703163147, 60.74062988162041, 57.998575419187546, 59.053623005747795, 55.78720048069954, 49.22101601958275, 45.293542966246605, 52.2767436504364, 58.225252255797386, 57.652527987957, 57.04869098961353, 59.5219174772501, 59.167415499687195, 47.102211713790894, 44.53633859753609, 47.8586371243, 52.878904938697815, 52.38586999475956, 50.344585329294205, 53.806423768401146, 56.5411826223135, 56.388506814837456, 58.002998381853104, 61.45426958799362, 60.430061146616936, 62.066815719008446, 58.53951059281826, 50.12318640947342, 53.66887114942074, 60.25798738002777, 55.39731480181217, 54.236853271722794, 56.22498258948326, 60.77024169266224, 59.887868240475655, 57.0484934002161, 57.29424521327019, 55.20433835685253, 53.990995064377785, 55.9720491617918, 57.075593546032906, 52.61318899691105, 39.447932839393616, 31.420538686215878, 23.58590628951788, 18.922673016786575, 10.858062710613012, 3.7407847959548235, 2.237283610738814, 1.8066382315009832, 7.067713374271989, 33.001422956585884, 61.4457618445158, 65.22362172603607, 65.7342991232872, 64.49673593044281, 62.472455352544785, 64.95434537529945, 36.82271830737591, 21.55284058302641, 67.92058020830154, 74.66590225696564, 44.346945360302925, 17.534888684749603, 27.551591992378235, 52.9184228181839, 49.523434191942215, 37.8341556340456, 47.90496803820133, 38.92074532806873, 79.06908318400383, 37.84974239766598, 0.8083486743271351, 0.3683690959587693, 0.17571973032318056, 0.19402195292059332, 0.165302797104232, 0.1279590986086987, 0.22184257570188493, 0.0723535280849319, 0.20194912911392748, 0.17731117695802823, 0.22647184057859704, 0.10322927599190734, 0.13164729054551572], [0.053040923376102, 0.024666548961249646, 0.02555539696913911, 0.02507114375475794, 0.0008519913308191462, 0.024099768925225362, 0.07639263712917455, 0.07271431575645693, 0.008516095422237413, 0.012891831520391861, 0.08890446770237759, 0.02896029815019574, 0.1497643769835122, 0.007925215995783219, 0.22855688963318244, 0.09391223531565629, 0.22543382830917835, 0.051116593822371215, 4.687817003577948, 60.52431508898735, 56.15944750607014, 36.158190965652466, 58.319536596536636, 45.64150929450989, 42.000191286206245, 19.335043989121914, 35.42954966425896, 76.00593835115433, 66.56906872987747, 16.82194624096155, 7.550277980044484, 35.165140852332115, 60.602480694651604, 61.32711701095104, 54.86185133457184, 53.26758228242397, 31.99969030916691, 4.63920621201396, 0.6405570404604077, 0.09815249606617726, 1.6506378399208188, 15.53266117349267, 39.12243850529194, 57.25331760942936, 62.28346489369869, 60.691475719213486, 60.34555748105049, 64.59375992417336, 66.02526471018791, 65.9999580681324, 63.05709198117256, 60.26454582810402, 57.368006855249405, 53.089493438601494, 58.12866523861885, 58.95164407789707, 59.73204240202904, 61.478926464915276, 61.3705562800169, 61.18120104074478, 57.42490120232105, 57.47059375047684, 56.526207625865936, 60.58852404356003, 54.893507435917854, 51.919889599084854, 60.08348174393177, 59.190484061837196, 58.58151733875275, 48.346188962459564, 47.93836824595928, 45.29940985143185, 44.25281301140785, 43.309156447649, 41.66141666471958, 41.65425404906273, 47.06474952399731, 43.87059532105923, 42.287767454981804, 40.21630480885506, 39.204422906041145, 39.97880235314369, 42.53603473305702, 44.973421543836594, 46.42668396234512, 48.60050931572914, 51.60178206861019, 55.226901546120644, 55.63944920897484, 58.70019257068634, 60.18196105957031, 53.683181181550026, 55.774045586586, 53.707002103328705, 54.35328662395477, 51.7117253690958, 44.822584837675095, 39.92426007986069, 41.199148669838905, 46.52875028550625, 52.21250429749489, 50.148702040314674, 53.74610960483551, 49.81849975883961, 42.568606585264206, 42.44749188423157, 44.375098049640656, 48.154276460409164, 48.06997038424015, 46.89742550253868, 45.563833862543106, 52.174050360918045, 51.33532516658306, 54.478220120072365, 54.99830201268196, 55.475317016243935, 54.892428293824196, 55.16011632978916, 52.253302708268166, 48.97040046751499, 53.168035224080086, 54.78850767016411, 53.017608895897865, 52.48419351875782, 57.38857515156269, 54.89152014255524, 57.68430948257446, 55.51725156605244, 48.675091713666916, 51.263554617762566, 53.71240921318531, 50.950379222631454, 49.88956734538078, 40.826677456498146, 30.576584972441196, 27.984331771731377, 22.5122682005167, 12.425105273723602, 4.586869720369577, 1.0430072201415896, 0.9536760917399079, 6.833081664517522, 36.44929714500904, 48.76412853598595, 53.0779230594635, 51.875025406479836, 57.31255643069744, 54.77600634098053, 47.85449154675007, 36.09085477888584, 18.71652837842703, 40.93986578285694, 48.2459769397974, 22.776034846901894, 13.749585002660751, 34.464222863316536, 40.98504915833473, 26.911550536751747, 34.26813058555126, 43.182889223098755, 38.337282836437225, 57.78802111744881, 3.6439707409590483, 0.6320089835207909, 0.10156277596252039, 0.11681457122904249, 0.10602084221318364, 0.11966910125920549, 0.048436743090860546, 0.0601683315471746, 0.022665052747470327, 0.024076591653283685, 0.046578739274991676, 0.08738983335206285, 0.01819943885493558, 0.043208001006860286, 0.016854461318871472, 0.08787681581452489, 0.03871815228194464, 0.007443637296091765, 0.05420906010840554, 0.09035009716171771, 0.03409408986044582, 0.043054361594840884, 0.05404347582953051, 0.025056046615645755, 0.12592188839334995, 0.06812045874539763, 0.10845066339243203, 0.09506980757578276, 0.13051009766058996, 0.04578146857966203, 0.3442598943365738, 0.06888145697303116, 5.144416652619839, 67.56645441055298, 68.73929187655449, 37.09348417818546, 59.33587186038494, 44.41056154668331, 31.4927614107728, 25.86616013199091, 42.35916182398796, 78.30210953950882, 66.21428176760674, 23.699212409555912, 9.538908395916224, 39.35886561870575, 62.36853092908859, 68.61722722649574, 61.584511399269104, 59.290297105908394, 37.304547652602196, 6.405302044004202, 0.7788203994277865, 0.4505772393895313, 1.885453483555466, 16.7020645737648, 40.76459638774395, 60.006171092391014, 64.97602701187134, 66.44712567329407, 61.29217028617859, 67.17214956879616, 67.75014415383339, 68.03042471408844, 66.48069307208061, 65.09986236691475, 59.59937632083893, 56.14710956811905, 61.566872745752335, 61.042470484972, 61.05750247836113, 60.215919837355614, 63.9537450671196, 60.90478867292404, 60.02144247293472, 59.8343101143837, 61.074536964297295, 62.250349670648575, 58.92298981547356, 53.202514573931694, 61.406012177467346, 60.3586857765913, 60.382381305098534, 50.06835915148258, 49.507167264819145, 48.09803947806358, 45.88127642869949, 43.88538412749767, 42.567371651530266, 45.81520177423954, 49.65580388903618, 48.84874999523163, 48.173210844397545, 45.24177834391594, 44.16323661804199, 46.660831198096275, 46.599973663687706, 49.27548609673977, 51.18161961436272, 52.86122828722, 55.37511259317398, 59.82706770300865, 58.52012783288956, 59.53556254506111, 61.38850651681423, 58.81816104054451, 58.94997216761112, 57.28023536503315, 58.648652136325836, 55.70000655949116, 48.33622209727764, 43.066824451088905, 47.48874977231026, 51.68072663247585, 57.108856961131096, 54.77156437933445, 53.94176870584488, 53.21810893714428, 44.94627580046654, 46.267058327794075, 47.54469037055969, 50.14175981283188, 50.24569943547249, 49.4188068062067, 48.6623889952898, 51.45031839609146, 53.220274820923805, 54.674137607216835, 55.66594518721104, 58.76812532544136, 56.565368324518204, 54.47120949625969, 52.24335864186287, 51.58958472311497, 53.998712450265884, 55.361087545752525, 55.09396567940712, 55.53091563284397, 59.082486256957054, 54.35582108795643, 57.65640377998352, 54.88730616867542, 51.45814597606659, 52.09048144519329, 54.705360531806946, 55.65700426697731, 51.87014266848564, 43.733973652124405, 34.455920308828354, 29.188312366604805, 22.789011150598526, 13.614286612719297, 4.829158019274473, 1.2654780386947095, 1.3943284121342003, 7.957181045785546, 41.22646540403366, 53.16544756293297, 58.72603118419647, 56.20740853250027, 62.85836644470692, 59.72648710012436, 53.97649884223938, 36.02083593606949, 22.37444579601288, 42.81579852104187, 61.19511589407921, 32.101604640483856, 21.056402921676636, 28.04316971451044, 25.173356607556343, 39.29595239460468, 31.862358078360558, 46.440294831991196, 45.00975899398327, 69.52648803591728, 5.9397809486836195, 0.5841669975779951, 0.13246267335489392, 0.1612855665734969, 0.05900060299609322, 0.08988265544758178, 0.013630523571919184, 0.116570078098448, 0.02312036962393904, 0.06909303585416637, 0.10282833813107572, 0.02946265976788709, 0.08412406445131637, 0.045517805774579756, 0.10213892746833153, 0.09229735165718012, 0.14824681857135147, 0.20335659733973444, 0.1633298717206344, 0.16420250380178913, 0.17387402389431372, 0.1474688548478298, 0.09165166091406718, 0.09025613384437747, 0.280515524209477, 0.23338656406849623, 0.20310588501160964, 0.13648156629642472, 0.27742290578316897, 0.26869545690715313, 0.39941411290783435, 0.17179060756461695, 8.137962520122528, 88.50410610437393, 73.17088767886162, 55.452997013926506, 69.83038812875748, 71.23684465885162, 53.681011497974396, 22.597742713987827, 45.14202609658241, 86.05396717786789, 69.6763063967228, 23.321981951594353, 11.456311158835888, 45.7638019323349, 70.21085411310196, 76.48348912596703, 68.04204449057579, 66.4199647307396, 42.02406920492649, 9.2785026691854, 1.0353575181216002, 0.6210706767160445, 2.664194027893245, 18.53463973850012, 43.695565313100815, 63.70787926018238, 69.82790306210518, 71.18577539920807, 63.78939628601074, 72.40172535181046, 69.24067497253418, 68.49403783679008, 68.53372290730476, 67.73327305912971, 63.3254449814558, 60.174939036369324, 65.19511565566063, 65.00394031405449, 65.16449689865112, 66.05471312999725, 66.50517135858536, 66.75665706396103, 65.39625406265259, 63.53116974234581, 64.6062308549881, 66.97945430874825, 63.14535364508629, 56.87298461794853, 64.2567104101181, 61.652641743421555, 63.50985288619995, 51.61255069077015, 51.07503913342953, 49.80843789875507, 47.45537996292114, 46.18581108748913, 46.342203095555305, 47.347393557429314, 52.856558337807655, 52.34590753912926, 49.678663462400436, 46.291582211852074, 46.259880512952805, 49.966771602630615, 49.67362493276596, 51.64174072444439, 54.927310422062874, 55.169570222496986, 56.18460975587368, 57.93828405439854, 60.40174886584282, 62.015784457325935, 61.60880349576473, 57.84057229757309, 60.366072580218315, 59.461185336112976, 61.459733694791794, 59.574575051665306, 52.840523198246956, 46.38560816645622, 49.4308065623045, 54.53446090221405, 59.371308758854866, 56.991530656814575, 56.905666664242744, 53.41076619923115, 46.9895363599062, 47.6854158192873, 48.97190138697624, 52.951021268963814, 52.704889476299286, 50.99481403827667, 50.0448802113533, 54.94177244603634, 55.27822159230709, 57.69965685904026, 59.793910682201385, 61.80048041045666, 60.962108597159386, 59.083952978253365, 56.801195070147514, 54.004989713430405, 56.427146941423416, 59.1529306769371, 58.69437888264656, 57.622011825442314, 62.80920468270779, 58.27789083123207, 58.8264711946249, 58.12603957951069, 53.622870817780495, 55.3963952511549, 57.69961126148701, 55.48844151198864, 53.4320792555809, 48.01094435155392, 35.81326447427273, 31.262246780097485, 24.97889444231987, 14.680793434381485, 6.533034089952707, 2.2500297892838717, 2.1470394032076, 8.936440274119377, 44.649599120020866, 59.326725751161575, 64.70898494124413, 62.398332729935646, 69.4002816081047, 66.0300524532795, 57.828409150242805, 45.077421963214874, 23.676309138536453, 51.27491980791092, 66.11638382077217, 31.215706877410412, 18.315499797463417, 40.05254499614239, 53.95034484565258, 41.09175883233547, 44.69775773584843, 56.51442065834999, 50.77835105359554, 90.53717941045761, 11.29639483988285, 0.8452743210364133, 0.18407359690172598, 0.279659679508768, 0.3385714808246121, 0.18172618380049244, 0.1433973733219318, 0.33303416857961565, 0.21936815144727007, 0.135633276659064, 0.2173587866127491, 0.20000425691250712, 0.16913702886085957, 0.20438985986402258], [0.02354904339881614, 0.0882358594390098, 0.02775505588942906, 0.04672575872973539, 0.01025655046760221, 0.008839687579893507, 0.013102438188070664, 0.08183902144082822, 0.034115129747078754, 0.06464782360126264, 0.15074368537170812, 0.09392434716573916, 0.11695389461237937, 0.049182471630047075, 0.11686323385220021, 0.014233959209377645, 0.21850227290997282, 0.13410789601039141, 0.7044715702068061, 24.885187670588493, 72.37810581922531, 33.97445574402809, 62.36357979476452, 77.430679500103, 46.78288444876671, 24.45033710449934, 23.038224577903748, 41.017389222979546, 56.4212154597044, 32.67916984856129, 20.383633822202682, 39.978342577815056, 65.02578914165497, 68.26858073472977, 54.96685490012169, 55.26595965027809, 48.226423189044, 11.139552555978298, 1.2592956516891718, 0.329836254240945, 4.6382861863821745, 19.050414562225342, 43.359108567237854, 61.07628107070923, 69.7944724559784, 61.908079236745834, 59.97679866850376, 64.67841938138008, 69.08521011471748, 66.48538202047348, 63.38358946144581, 58.524816781282425, 59.034088253974915, 60.378273725509644, 61.419509053230286, 60.26458382606506, 63.422115594148636, 63.39365892112255, 62.15551435947418, 62.558155953884125, 61.42794460058212, 61.97071887552738, 62.062673941254616, 56.92671373486519, 55.79640358686447, 58.47468227148056, 60.970270559191704, 57.021294459700584, 54.6668191999197, 49.1435419768095, 45.30447877943516, 46.000156849622726, 46.3440003991127, 43.646969720721245, 44.564137905836105, 40.45566916465759, 42.25742228329182, 43.69485095143318, 42.63012148439884, 40.06623186171055, 40.84632620215416, 41.29955068230629, 44.89593230187893, 45.24425961077213, 46.88742823898792, 49.7152478992939, 52.64746315777302, 56.123326644301414, 56.58061310648918, 62.22124323248863, 58.634957671165466, 55.33672325313091, 55.75679451227188, 54.46831405162811, 55.10016694664955, 52.574708461761475, 46.800298914313316, 37.652331590652466, 40.902308598160744, 43.66158753633499, 50.03524012863636, 49.9209688603878, 51.77497297525406, 46.72918573021889, 42.04760894179344, 42.31191135942936, 44.89202991127968, 51.564293280243874, 52.82524421811104, 49.19692911207676, 48.51921647787094, 46.10107943415642, 51.025831773877144, 49.414760023355484, 52.35856465995312, 52.745604291558266, 55.341184213757515, 54.85677860677242, 56.62961907684803, 49.726495295763016, 45.89464791119099, 47.17419505119324, 51.333425268530846, 53.577174469828606, 54.415268898010254, 51.295951679348946, 54.5762624591589, 52.93877072632313, 53.234467059373856, 50.90627118945122, 56.09224051237106, 53.39293375611305, 52.092191353440285, 40.87943762540817, 36.15418218076229, 33.303107768297195, 28.563912771642208, 16.85634769499302, 8.453491888940334, 2.4295133957639337, 0.6524493335746229, 8.668890930712223, 31.23497374355793, 51.82778634130955, 54.187246933579445, 50.755388885736465, 57.37172305583954, 46.726689264178276, 57.15404033660889, 23.07756956666708, 29.219039417803288, 49.068366810679436, 31.573871858417988, 13.798558674752712, 13.78789834678173, 41.06215462088585, 31.972753554582596, 25.923801138997078, 43.775117844343185, 33.772374987602234, 51.135870069265366, 23.072428442537785, 1.723851717542857, 0.126428033108823, 0.29069841373711824, 0.03516586984915193, 0.13016652781516314, 0.06904400957864709, 0.18054058804409578, 0.023794336193532217, 0.036205644719302654, 0.02816822063323343, 0.02269905795401428, 0.05640512332320213, 0.05717634834581986, 0.05225288128713146, 0.05931444240559358, 0.11385228877770714, 0.06275277177337557, 0.03081203823967371, 0.019883152999682352, 0.047885631647659466, 0.03631134139141068, 0.02694785340281669, 0.07395065214950591, 0.06219158567546401, 0.0939897155330982, 0.14491165144136176, 0.11178071712492965, 0.12807782739400864, 0.05538508215977345, 0.02819041084876517, 0.1307874234043993, 0.3580713219707832, 0.44630620919633657, 31.933699250221252, 83.63075360655785, 42.42391414940357, 57.27838486433029, 95.86078494787216, 34.616457894444466, 26.82038962841034, 34.29171212017536, 47.970742508769035, 56.91157154738903, 29.55177616328001, 22.3150796815753, 45.16507565975189, 68.9101155102253, 72.78105899691582, 63.41626390814781, 61.90100021660328, 54.8616499453783, 14.941293206065893, 1.6816204274073243, 0.4402675316669047, 5.2465855702757835, 20.910986624658108, 43.354263827204704, 63.763656467199326, 72.12038844823837, 63.45437966287136, 61.8764079362154, 66.80862307548523, 70.06343722343445, 66.68628484010696, 65.81102460622787, 61.81951738893986, 60.431508868932724, 61.02864682674408, 61.741712763905525, 62.30676144361496, 64.36207875609398, 64.27757889032364, 64.10228669643402, 64.09115329384804, 65.07668361067772, 65.3445540368557, 63.1503389775753, 59.4538289308548, 57.718895226716995, 61.82215824723244, 62.68575310707092, 61.415530666708946, 57.20878779888153, 50.373311787843704, 47.502421438694, 47.81329795718193, 47.30434946715832, 47.69651502370834, 45.57527884840965, 45.24443820118904, 46.97660945355892, 49.915877133607864, 46.335925832390785, 45.31006067991257, 45.81033803522587, 47.30875343084335, 48.95215384662151, 51.802924275398254, 51.388871893286705, 53.057293966412544, 54.52179618179798, 58.04380439221859, 59.0807269513607, 64.17778864502907, 60.03513313829899, 59.402968659996986, 59.27991606295109, 58.82763773202896, 58.69976319372654, 57.294963374733925, 48.83635886013508, 43.36546942591667, 46.69251009821892, 49.35781627893448, 54.63754177093506, 55.053976625204086, 54.96845081448555, 52.144567742943764, 46.508740559220314, 45.89734576642513, 47.3942868411541, 53.835321217775345, 54.85902428627014, 52.284977808594704, 50.02821430563927, 47.473493590950966, 51.52858279645443, 53.13824862241745, 54.81316074728966, 53.025987446308136, 56.60427063703537, 55.943128913640976, 57.3255555331707, 52.01477810740471, 48.16525787115097, 51.18850864470005, 53.52610521018505, 54.72040392458439, 56.18116334080696, 51.89888812601566, 56.04131564497948, 54.33755546808243, 55.08847117424011, 53.00873637199402, 56.45990498363972, 54.627772495150566, 55.209658071398735, 46.34814977645874, 40.82198850810528, 37.52377688884735, 30.804152861237526, 16.8521736189723, 9.450120460242033, 2.320969607681036, 1.0471785650588572, 9.813228975981474, 35.80738238990307, 57.53619343042374, 59.80033993721008, 57.12022215127945, 63.11304397881031, 49.58358496427536, 58.96871656179428, 24.53365333378315, 33.89785945415497, 49.406142085790634, 38.567748069763184, 19.011649042367935, 20.980973169207573, 23.47001440823078, 32.0389574021101, 32.30702541768551, 38.582061901688576, 40.562090054154396, 58.29916208982468, 31.352716125547886, 2.1317407116293907, 0.07731531964964233, 0.33532942354213446, 0.04830760197364725, 0.10734582814620808, 0.03072087281907443, 0.0978253796347417, 0.04851506193517707, 0.02041917286987882, 0.03195704222889617, 0.02749579773080768, 0.02953208768303739, 0.05484692119352985, 0.01585061938385479, 0.13051947840722278, 0.15139348019147292, 0.17720735049806535, 0.15437887312145904, 0.13055257819360122, 0.13124571443768218, 0.1500988332554698, 0.1465936697786674, 0.2092671801801771, 0.15534704929450527, 0.24849675013683736, 0.2071505898493342, 0.3204933274537325, 0.2400885583483614, 0.1689983214600943, 0.08523149721440859, 0.2747789304703474, 0.5095419113058597, 1.1055591073818505, 53.067637011408806, 96.01579383015633, 54.60889510810375, 71.80231511592865, 99.63306292891502, 62.36770637333393, 28.92901998013258, 29.31108757853508, 50.02182684838772, 70.60035601258278, 41.168484315276146, 28.60181763768196, 48.841621577739716, 75.23133471608162, 80.18770515918732, 67.52724051475525, 69.81504455208778, 61.588208600878716, 18.183261193335056, 2.614652286283672, 0.9197278821375221, 6.820080187171698, 22.869135551154613, 45.655150562524796, 68.17731723189354, 77.7298754453659, 68.32242384552956, 65.67173168063164, 72.16085627675056, 74.26319986581802, 68.7260913848877, 68.55007722973824, 64.17219534516335, 63.992905765771866, 65.48371016979218, 66.1338172852993, 66.20803490281105, 67.68031150102615, 67.73392662405968, 66.7107555270195, 67.53313779830933, 66.78429678082466, 69.02651086449623, 68.18394407629967, 60.281606912612915, 58.655134588479996, 62.80114531517029, 66.0324615240097, 62.72401325404644, 60.18844351172447, 53.71247760951519, 48.288504257798195, 50.19092537462711, 50.758329927921295, 49.03374306857586, 49.10588599741459, 48.59666392207146, 48.97347450256348, 51.318693459033966, 50.54889276623726, 47.21382312476635, 46.63513317704201, 48.24313089251518, 51.669194251298904, 52.45026893913746, 52.62388162314892, 53.061960116028786, 57.062233462929726, 59.40623268485069, 59.82209376990795, 61.92874252796173, 59.34735484421253, 58.12115304172039, 60.436535999178886, 60.20456604659557, 61.53669096529484, 58.841704577207565, 52.23164387047291, 45.21287329494953, 48.51292781531811, 49.323846101760864, 58.407885655760765, 57.23707728087902, 57.068183943629265, 52.150898203253746, 48.486435636878014, 47.05887123942375, 48.0967665463686, 56.0504237562418, 57.002618461847305, 54.50559005141258, 53.06167513132095, 47.11363770067692, 53.35750065743923, 53.7651389837265, 57.39041805267334, 54.658915624022484, 60.74538342654705, 58.9819398522377, 60.33151723444462, 55.82454867660999, 50.46924144029617, 52.526880428195, 57.58832663297653, 61.68765686452389, 60.544522404670715, 54.86334465444088, 59.37507815659046, 59.98495303094387, 59.308099150657654, 55.22634297609329, 57.77512460947037, 58.99953670799732, 56.55011214315891, 47.395020201802254, 41.1315692961216, 39.40450496971607, 31.076318956911564, 19.764111265540123, 10.918694157153368, 3.907211828045547, 1.467675045132637, 11.764133591204882, 38.944285064935684, 64.44678381085396, 66.28965452313423, 62.34584994614124, 68.94187420606613, 56.04298755526543, 65.4021817445755, 30.141571015119553, 36.46294981241226, 57.85582847893238, 42.668746411800385, 18.987227752804756, 17.10152953863144, 51.004746705293655, 45.30711203813553, 37.83857859671116, 55.3785590082407, 46.22253991663456, 68.46465781331062, 52.31631852686405, 2.4691844545304775, 0.16753311414504424, 0.3442262305179611, 0.2602310251677409, 0.18207447370514274, 0.12041863330523483, 0.16578715236391872, 0.09902313919155858, 0.16584455006523058, 0.12748519278829917, 0.16051788901677355, 0.20160376327112317, 0.14201026962837204, 0.11202946276171133], [0.02595979138277471, 0.04680725025536958, 0.010384547749708872, 0.024785550485830754, 0.03711359189765062, 0.06635259618633427, 0.09139113739365712, 0.02987069070513826, 0.01726914746541297, 0.07684050098760054, 0.07344289697357453, 0.15788693097420037, 0.046045231574680656, 0.09713417297462001, 0.09615017421310768, 0.05947594116150867, 0.025726860912982374, 0.24270639522001147, 0.007114581540008658, 10.026047956198454, 68.32104071974754, 43.73262472450733, 41.82489529252052, 28.321886658668518, 46.41527697443962, 41.037429347634315, 15.44703371822834, 38.8519424200058, 78.54264423251152, 59.617930725216866, 33.44404220581055, 27.202584519982338, 64.51980069279671, 70.63934192061424, 62.35885664820671, 57.124208137393, 55.83123631775379, 22.113515697419643, 4.435806451365352, 0.5914744804613292, 6.922684656456113, 24.747686348855495, 50.96584439277649, 63.74726414680481, 67.74288654327393, 65.34169659018517, 60.15384256839752, 63.61074507236481, 67.08708733320236, 65.4899950325489, 63.112386614084244, 63.4826273471117, 62.37006604671478, 65.36509573459625, 59.57167200744152, 64.12755534052849, 62.24709324538708, 61.046327278018, 60.81157207489014, 62.7255217730999, 61.283214166760445, 62.75846220552921, 58.35651621222496, 57.05709233880043, 60.58000490069389, 59.30747218430042, 58.69540482759476, 60.87881326675415, 51.50301016867161, 47.881971672177315, 50.64456023275852, 47.37368814647198, 46.57207176089287, 43.653383776545525, 43.746569976210594, 41.505986005067825, 41.91190302371979, 42.48200163245201, 41.63937024772167, 41.85719355940819, 42.65925832092762, 44.271500408649445, 47.15582683682442, 44.451185166835785, 51.16912588477135, 49.28047522902489, 52.4964364618063, 56.27484351396561, 57.89927154779434, 55.59429623186588, 57.198064774274826, 56.04398690164089, 56.63601413369179, 55.688135996460915, 55.6189189106226, 54.66836951673031, 48.95312279462814, 40.229011327028275, 41.97204999625683, 45.65957732498646, 47.91227124631405, 50.66161751747131, 52.20532268285751, 46.38459362089634, 41.70034557580948, 43.38808961212635, 47.88211226463318, 52.99853391945362, 54.69108089804649, 52.705668434500694, 52.795803397893906, 48.91263596713543, 53.01533281803131, 53.049842566251755, 51.344991847872734, 50.45741647481918, 50.097602382302284, 49.89341653883457, 53.303703144192696, 54.753758534789085, 47.444181963801384, 37.7553478628397, 37.06482231616974, 38.95097270607948, 35.66099524497986, 34.58919435739517, 41.69257119297981, 42.04135827720165, 47.68810607492924, 50.65483868122101, 51.55071280896664, 49.63465042412281, 46.80396571755409, 48.31778168678284, 36.92025147378445, 37.53217823803425, 33.160964995622635, 20.698758512735367, 11.256626173853874, 2.2524763830006123, 1.1423894623294473, 12.129810769110918, 35.838267132639885, 51.730446964502335, 50.20581677556038, 55.14220029115677, 52.16213800013065, 56.890368685126305, 41.97049207985401, 27.23820760846138, 60.550575479865074, 55.11611469089985, 37.38166071474552, 11.64050817489624, 28.875195868313313, 41.95776656270027, 29.040576294064522, 39.91553954780102, 43.68639260530472, 42.347716838121414, 57.72290401160717, 12.062106002122164, 1.0970683442428708, 0.2126881989534013, 0.31551318999845535, 0.09871981601463631, 0.08265456752269529, 0.0819142974796705, 0.12124027241952717, 0.024951834238891024, 0.0533570114930626, 0.05491196672664955, 0.04041709158627782, 0.008353426856047008, 0.04153993504587561, 0.04339218350651208, 0.06380295526469126, 0.03045657362235943, 0.022365484837791882, 0.052866140176774934, 0.0750298090861179, 0.06463028665166348, 0.03534440831572283, 0.13492384285200387, 0.02574915131845046, 0.0741976463177707, 0.060349055638653226, 0.11468568351119757, 0.06393970339559019, 0.11108752893051133, 0.03811896822298877, 0.055418541887775064, 0.04350594732386526, 0.4140898457262665, 0.02299971311003901, 16.963969320058823, 83.26886102557182, 52.18635410070419, 45.091382414102554, 37.44037136435509, 48.6716452986002, 30.61660822480917, 26.518298238515854, 46.1903328448534, 83.07651534676552, 61.46028846502304, 37.71163120865822, 31.61072038114071, 71.19924947619438, 71.63275301456451, 67.8669422864914, 63.2024759799242, 62.28732168674469, 26.08113169670105, 4.917655745521188, 0.771304580848664, 8.329143561422825, 26.61276876926422, 52.9929406195879, 66.05742618441582, 71.59364551305771, 67.171161621809, 62.85571798682213, 66.31968051195145, 68.46305429935455, 66.23336434364319, 66.90477311611176, 66.05306401848793, 63.15431736409664, 67.10073620080948, 62.28149279952049, 65.62038123607635, 62.283784076571465, 63.42512123286724, 63.37652184069157, 64.8435129225254, 61.59906841814518, 67.5542114675045, 59.345823526382446, 61.35712020099163, 62.65973970293999, 61.63378715515137, 60.56593805551529, 62.33457215130329, 54.19271484017372, 50.0069772452116, 52.16893583536148, 51.33858539164066, 48.48364658653736, 45.105798840522766, 45.786813497543335, 44.39752824604511, 45.55107034742832, 45.95878466963768, 48.276242315769196, 45.659892708063126, 46.26721791923046, 46.40604726970196, 49.734813049435616, 47.91005216538906, 53.563787788152695, 52.734189704060555, 56.22988432645798, 59.218446761369705, 58.76268021762371, 58.51846732199192, 58.115848526358604, 57.52706632018089, 59.01098929345608, 58.14090438187122, 58.176896050572395, 57.90418088436127, 50.8590093255043, 43.91879193484783, 45.073367580771446, 49.34271588921547, 52.667697072029114, 54.56861726939678, 55.73842629790306, 52.379862517118454, 43.680825904011726, 46.49553246796131, 50.564692318439484, 55.26224344968796, 57.463723719120026, 54.811211451888084, 54.99581694602966, 51.028936207294464, 55.44945180416107, 53.87030214071274, 53.79033923149109, 51.23537912964821, 51.81052006781101, 52.586894407868385, 54.74723808467388, 54.742663130164146, 47.42055483162403, 41.06436990201473, 41.39891155064106, 43.631732538342476, 41.827532351017, 42.02867455780506, 44.5192851126194, 44.847967475652695, 48.096796944737434, 53.43654401600361, 55.38355953991413, 52.27660305798054, 48.17587070167065, 49.82422985136509, 42.00639635324478, 41.42101876437664, 34.87015128135681, 20.70294588804245, 13.70702538639307, 2.6875316631048918, 1.138839265331626, 14.102317225188017, 41.37967698276043, 57.17198297381401, 55.10024294257164, 60.17958998680115, 57.59263940155506, 62.37330347299576, 42.41099864244461, 31.861208640038967, 60.18917307257652, 60.34464552998543, 41.97533681988716, 16.947157122194767, 23.132676109671593, 24.84346590936184, 37.10376262664795, 37.629418820142746, 46.106513142585754, 45.871374160051346, 70.06100535392761, 15.331433471292257, 1.0658054030500352, 0.13135792716639116, 0.35010635561775416, 0.09963018630514853, 0.01934482505021151, 0.03781580460781697, 0.05543739614950027, 0.11136948567582294, 0.1359489862807095, 0.01246870715476689, 0.07942170544993132, 0.05166827671928331, 0.02983063142892206, 0.04879308158706408, 0.18418008025037125, 0.13347335974685848, 0.13456741900881752, 0.27828302525449544, 0.12076165396138094, 0.12914374441606924, 0.192107968905475, 0.14258589420933276, 0.1160790806170553, 0.22497518104501069, 0.21535749634495005, 0.18190036586020142, 0.27550050581339747, 0.14635423809522763, 0.17723895114613697, 0.1501897315029055, 0.18712570890784264, 0.3672840166836977, 0.11925882718060166, 23.144882954657078, 101.95335522294044, 59.77875329554081, 60.114381685853004, 41.84525839984417, 69.92973759770393, 52.48464949429035, 19.351413510739803, 52.015633061528206, 89.86852928996086, 71.51408538222313, 39.584242925047874, 34.052784740924835, 73.95540118217468, 77.94983044266701, 73.83190780878067, 70.57957872748375, 70.31322821974754, 30.81630650907755, 7.071656612679362, 1.3397408975288272, 10.103647392243147, 27.990717329084873, 55.606877356767654, 67.62536644935608, 75.78157559037209, 72.74020358920097, 66.168372631073, 69.45214882493019, 71.21622696518898, 68.27396884560585, 68.02769646048546, 66.61350354552269, 67.25498512387276, 70.95045402646065, 66.47285029292107, 69.1676276922226, 65.438621789217, 66.67537942528725, 65.27771562337875, 69.58971664309502, 67.23173797130585, 68.72449547052383, 62.07902446389198, 63.626548424363136, 67.83986493945122, 63.45991216599941, 64.13182631134987, 64.66822072863579, 56.00099220871925, 51.460954025387764, 56.41213774681091, 52.99435414373875, 50.7260924577713, 47.1463805437088, 49.50906716287136, 49.52068693935871, 47.2649721801281, 49.18359562754631, 51.30868099629879, 49.07747492194176, 49.936373233795166, 49.675224646925926, 53.179620802402496, 51.376480758190155, 54.86486077308655, 54.079860895872116, 55.78558176755905, 60.296836495399475, 59.91857819259167, 57.68928341567516, 58.51165048778057, 57.90888123214245, 60.37143789231777, 58.840701431035995, 61.18777468800545, 61.185756996273994, 53.13673250377178, 48.902950286865234, 48.1427326798439, 53.20954419672489, 54.23947513103485, 58.19983921945095, 58.07006098330021, 53.214924708008766, 44.463637098670006, 50.23298531770706, 52.75953434407711, 56.31043620407581, 58.94474744796753, 56.77846848964691, 56.30592964589596, 52.25778266787529, 58.13384436070919, 57.53152348101139, 55.120792239904404, 53.74607540667057, 54.03850011527538, 57.15303339064121, 59.890699088573456, 60.74816107749939, 51.51113413274288, 43.37915249168873, 42.42598123848438, 45.41990518569946, 44.46780167520046, 43.46197284758091, 46.77765592932701, 47.6518864184618, 50.605065152049065, 57.27498024702072, 58.343733698129654, 55.23249104619026, 51.87143459916115, 53.254207000136375, 46.20209701359272, 44.31988701224327, 39.213743805885315, 23.213072195649147, 15.224698148667812, 3.1830576108768582, 2.3844511387869716, 16.559019349515438, 45.936039090156555, 61.96688488125801, 59.10764470696449, 64.57351461052895, 59.74319480359554, 67.10797861218452, 48.40429924428463, 34.76618506014347, 69.65450316667557, 70.05479648709297, 48.33227030932903, 14.352606944739819, 33.67145620286465, 55.81767864525318, 41.809426322579384, 53.39831806719303, 57.81136326491833, 54.25833731889725, 88.09176743030548, 21.606501303613186, 1.2870314321480691, 0.21191416861256585, 0.39645297336392105, 0.22479547740658745, 0.22085382719524205, 0.16413707606261596, 0.2731512818718329, 0.22391677455743775, 0.20599657989805564, 0.2053201716626063, 0.2081959939096123, 0.16759244143031538, 0.2060824166983366, 0.17347883025649935], [0.016157599493453745, 0.04717803094536066, 0.03845042250759434, 0.025057217353605665, 0.06664443091722205, 0.07683449701289646, 0.036011098127346486, 0.030677789291075896, 0.02938547640951583, 0.04295166319934651, 0.05283766768116038, 0.15284660534234717, 0.11406736317439936, 0.11781483044615015, 0.0809621813823469, 0.056209671311080456, 0.0588228660490131, 0.353914582519792, 0.017300607105426025, 6.188754038885236, 49.797103106975555, 56.204406693577766, 75.35084590315819, 38.64684082567692, 37.41653524339199, 53.80650736391544, 15.87905153632164, 31.01924031972885, 55.24639070034027, 60.06453216075897, 47.57507734000683, 33.87863628566265, 55.82500085234642, 66.53681606054306, 62.21207432448864, 56.76166959106922, 58.47323454916477, 40.15289381146431, 9.419180620461702, 2.420992352999747, 9.59879033267498, 31.48010428994894, 51.488008573651314, 64.29017141461372, 68.59410166740417, 65.76095849275589, 60.59611603617668, 64.34703916311264, 65.91350510716438, 64.7570751607418, 61.06024593114853, 66.47072240710258, 64.58343207836151, 66.34717583656311, 66.5307591855526, 66.31119176745415, 62.07615561783314, 65.1507568359375, 58.87686409056187, 60.081205666065216, 59.227801859378815, 54.719233587384224, 53.39687414467335, 62.13824808597565, 59.38304252922535, 59.53909635543823, 55.10840870440006, 52.834245935082436, 47.83735826611519, 49.76683773100376, 47.37013153731823, 47.89624750614166, 47.684211283922195, 44.32267986238003, 43.12064476311207, 40.637474209070206, 40.52987918257713, 40.23327849805355, 39.75312486290932, 42.09716208279133, 41.85070350766182, 47.607839182019234, 45.14968268573284, 47.868235409259796, 51.44956223666668, 49.54226218163967, 54.622764363884926, 56.111733466386795, 57.342213839292526, 57.75881968438625, 55.145635306835175, 56.74400433897972, 59.332463443279266, 57.80706189572811, 56.72715984284878, 55.798523873090744, 48.835473507642746, 40.30053108930588, 41.28019832074642, 45.4147906601429, 48.80491554737091, 48.601919040083885, 49.31475318968296, 44.131846502423286, 41.99631929397583, 42.00422286987305, 46.14784732460976, 53.7049426138401, 55.349528566002846, 56.256653890013695, 54.05115723609924, 50.849236249923706, 53.54837201535702, 55.05162835121155, 54.364393427968025, 52.75749385356903, 52.08115294575691, 50.67722328007221, 49.77895528078079, 50.91475993394852, 49.75319646298885, 39.45299796760082, 24.41316369920969, 21.499645337462425, 21.149212941527367, 18.719790503382683, 17.914854995906353, 25.96452545374632, 36.50798499584198, 46.348856538534164, 47.85707160830498, 47.1551276743412, 36.90827451646328, 42.423591166734695, 48.044359758496284, 39.10849325358868, 34.838939756155014, 25.212249420583248, 14.774065129458904, 2.331798314116895, 0.9523692587390542, 12.812029011547565, 40.62911465764046, 53.8947082310915, 54.594053104519844, 54.46637615561485, 54.74218815565109, 59.61805611848831, 47.59236641228199, 60.76698146760464, 63.30510087311268, 49.37804639339447, 20.31668521463871, 12.922382690012455, 43.92181657254696, 30.186925381422043, 28.451062627136707, 38.72911021113396, 35.5576141923666, 45.270869582891464, 43.281813114881516, 4.388343198224902, 0.1970192647422664, 0.33066974545363337, 0.140067801985424, 0.20354499894892797, 0.0654017788474448, 0.147244963736739, 0.06013858255755622, 0.03078705569350859, 0.025571390251570847, 0.03069025737204356, 0.020901528041576967, 0.025165602455672342, 0.013602537183032837, 0.03464899738901295, 0.016217258889810182, 0.02082449496811023, 0.06409363224520348, 0.020983886024623644, 0.1059305079979822, 0.035668281561811455, 0.0937901297584176, 0.018142994813388214, 0.027045184215239715, 0.12293025400140323, 0.023562888163723983, 0.11183115348103456, 0.029428318739519455, 0.025704843246785458, 0.08279292611405253, 0.04456470262084622, 0.0756032888602931, 0.3840568213490769, 0.06387664310750552, 6.077095605432987, 65.52251368761063, 63.99196341633797, 80.01342371106148, 35.861582681536674, 45.148827731609344, 35.59280790388584, 20.559908263385296, 44.378715455532074, 59.25228014588356, 59.38300833106041, 46.97388119995594, 35.50066664814949, 60.76804541051388, 74.47586685419083, 68.89041736721992, 63.55149865150452, 64.2808923125267, 46.829728335142136, 10.873409137129784, 2.5542846880853176, 10.192215889692307, 33.026771396398544, 52.16525383293629, 67.00915351510048, 71.14801302552223, 68.55824679136276, 63.04155841469765, 65.48576205968857, 69.24448236823082, 66.6084498167038, 61.32940448820591, 68.98798853158951, 67.62168064713478, 68.05899918079376, 67.96911120414734, 68.48775297403336, 65.5105747282505, 67.08286955952644, 62.572845965623856, 65.56567177176476, 63.194648399949074, 58.407353684306145, 57.4696210026741, 64.29853856563568, 61.9280281662941, 62.244433388113976, 59.173521772027016, 55.04248224198818, 51.607960537075996, 52.237309366464615, 50.48692189157009, 50.30355513095856, 48.568860813975334, 46.454494670033455, 46.57574996352196, 44.2312453687191, 43.68791252374649, 45.012825429439545, 44.53809030354023, 44.72399152815342, 45.47972537577152, 49.3708685785532, 49.48019631206989, 49.18626308441162, 53.95244613289833, 51.957663372159004, 57.20367707312107, 57.43606120347977, 58.742317110300064, 57.678959369659424, 58.561028838157654, 59.56319846212864, 58.986556604504585, 57.8534460067749, 58.879512548446655, 57.868933975696564, 51.48898512125015, 44.38181608915329, 45.013562589883804, 48.802339285612106, 53.495786637067795, 51.46924138069153, 54.2425187677145, 48.45248445868492, 44.290940165519714, 44.63262923061848, 49.811276346445084, 55.65646089613438, 60.23052625358105, 58.748560175299644, 57.09461152553558, 54.39049802720547, 54.841910004615784, 56.39308176934719, 56.10260255634785, 53.653337582945824, 55.070224553346634, 54.35115493834019, 53.41631770133972, 54.91329677402973, 50.33988498151302, 40.1756925880909, 27.33564008027315, 26.05337418615818, 23.357907123863697, 19.897567704319954, 20.055061653256416, 28.111208863556385, 36.601269990205765, 47.0006013661623, 47.51275688409805, 48.43897618353367, 40.774350464344025, 48.267358392477036, 51.72761991620064, 42.87287525832653, 38.76677758991718, 28.744860962033272, 16.455070227384567, 2.847453919239342, 1.3987076771445572, 15.04151662811637, 46.57342068850994, 60.10120399296284, 59.9500785022974, 59.63615834712982, 61.81127183139324, 60.388909354805946, 52.91174657642841, 62.46091537177563, 64.84260097146034, 56.717253774404526, 25.457910038530827, 15.952769480645657, 24.66028343886137, 29.677380323410034, 33.37623104453087, 36.68594464659691, 40.682459995150566, 54.19280603528023, 54.49196018278599, 5.180700905621052, 0.1094338606344536, 0.19425452715950087, 0.09882626967737451, 0.16313606727635488, 0.015782354785187636, 0.019030141447728965, 0.04093957097211387, 0.030006269953446463, 0.01799671936169034, 0.027705808824975975, 0.019665601685119327, 0.07473433783161454, 0.10990555485477671, 0.03839392651570961, 0.07399748908937909, 0.14018093497725204, 0.09391322237206623, 0.17666331172222272, 0.1864215888781473, 0.18082827416947111, 0.2193912470829673, 0.11120032795588486, 0.08096443008980714, 0.21480091527337208, 0.1677497025229968, 0.2103098828229122, 0.17019424791214988, 0.1482405251590535, 0.15796393621712923, 0.21917767182458192, 0.18233024748042226, 0.5524774105288088, 0.23702287988271564, 8.501535560935736, 85.98459050059319, 71.23594030737877, 95.49914315342903, 50.525087043643, 61.97088986635208, 72.55339801311493, 18.178695738315582, 40.7775042951107, 62.735944613814354, 69.4202533364296, 55.67238964140415, 40.797761008143425, 66.66751384735107, 78.07903110980988, 72.4264620244503, 68.29292222857475, 71.91360354423523, 50.02212703227997, 13.813468124717474, 4.1180304531008005, 11.2421783991158, 35.04090651869774, 55.10002635419369, 72.45667800307274, 74.55455303192139, 72.59425342082977, 68.74502196907997, 69.0969742834568, 72.53094881772995, 66.98518440127373, 62.375590950250626, 70.60369223356247, 69.86261039972305, 69.73086386919022, 70.43887987732887, 70.29774785041809, 67.70254790782928, 72.26731896400452, 66.75857976078987, 66.65228426456451, 64.74162518978119, 59.23139646649361, 60.10694928467274, 70.38365364074707, 62.72273652255535, 65.57678997516632, 60.76804161071777, 55.61342440545559, 51.632252633571625, 56.08195826411247, 52.05553472042084, 55.36979667842388, 51.72120966017246, 50.33897303044796, 50.108811780810356, 45.71334823966026, 47.03323781490326, 47.43243299424648, 46.942054107785225, 48.72388869524002, 49.15276028215885, 53.79313588142395, 52.825191020965576, 51.89973168075085, 56.51738069951534, 53.581016063690186, 59.36388395726681, 59.26590621471405, 58.70780736207962, 55.02138577401638, 57.93286554515362, 58.62911358475685, 62.25758448243141, 59.03832882642746, 61.87609255313873, 59.33239504694939, 53.426113575696945, 45.51382854580879, 47.34850309789181, 52.00177900493145, 56.23534843325615, 53.98759424686432, 55.555914491415024, 48.5262119024992, 47.34279580414295, 46.85378484427929, 50.793504640460014, 58.72448846697807, 61.20641648769379, 61.435004621744156, 60.12804955244064, 53.54489140212536, 57.93986476957798, 59.615555852651596, 58.76261942088604, 59.13830146193504, 56.934290528297424, 57.15532086789608, 55.63862845301628, 59.79547619819641, 54.429548531770706, 44.95826795697212, 30.757795348763466, 28.231183625757694, 27.083016335964203, 22.730596885085106, 22.24677264690399, 30.441243834793568, 40.299850925803185, 52.130668088793755, 52.38261356949806, 51.89751259982586, 43.17520223557949, 51.03048652410507, 54.98760178685188, 47.70700246095657, 41.69955901801586, 30.57717014104128, 17.500992603600025, 3.4818025678396225, 2.6214634208008647, 18.063330128788948, 51.3736917078495, 65.16451969742775, 66.71622723340988, 64.24265116453171, 65.10135188698769, 66.33729636669159, 56.75799898803234, 68.01502794027328, 74.51038420200348, 63.507128432393074, 25.781082697212696, 16.80148433893919, 53.97550709545612, 43.705083802342415, 40.13131856918335, 52.676865980029106, 51.49069882929325, 62.19923101365566, 73.79235193133354, 7.522209836170077, 0.18479500897228718, 0.3818329906789586, 0.19392731424886733, 0.2507308224448934, 0.07580758727272041, 0.10851255850866437, 0.11119220886030234, 0.11156897497130558, 0.15717880334705114, 0.11868904330185615, 0.240784915513359, 0.19299863517517224, 0.18387351388810202, 0.21425227518193424], [0.11237903658184223, 0.02632773892401019, 0.043824384338222444, 0.06724902894347906, 0.045801450905855745, 0.01896486213809112, 0.04851300247537438, 0.03295772447017953, 0.03744947680388577, 0.05098620218632277, 0.19365369924344122, 0.10685760629712604, 0.009221066138707101, 0.05967632474494167, 0.03424561415158678, 0.056755019977572374, 0.03463708591880277, 0.0844178584520705, 0.2654154907213524, 0.500849224627018, 38.90248730778694, 65.22796869277954, 33.01292113959789, 40.25706522166729, 38.164544105529785, 54.123763740062714, 34.232606291770935, 18.831078931689262, 58.61798778176308, 83.88087898492813, 66.9062702357769, 38.43168877065182, 46.214955523610115, 60.33195421099663, 59.49161410331726, 52.83015355467796, 55.70540226995945, 53.93400192260742, 18.964713960886, 3.0024086544290185, 10.547026600688696, 28.89050904661417, 53.18833753466606, 69.01100769639015, 71.36189594864845, 65.70864289999008, 62.53613233566284, 64.02410969138145, 65.62874838709831, 66.7453184723854, 63.55941362679005, 64.632897824049, 64.79284644126892, 66.05361878871918, 63.676249757409096, 64.17968854308128, 64.785026460886, 60.845416858792305, 56.10680133104324, 50.103469267487526, 40.19561491906643, 43.10314290225506, 54.95172031223774, 61.77854798734188, 59.85501140356064, 60.262372344732285, 55.22273316979408, 50.710342302918434, 50.352690294384956, 49.78352643549442, 53.16599853336811, 55.553976595401764, 54.42625030875206, 47.78426751494408, 41.38353757560253, 42.667845860123634, 39.36174586415291, 40.857471004128456, 42.04407513141632, 42.03253895044327, 43.30954022705555, 45.53001947700977, 48.1513050198555, 51.17970831692219, 51.12641617655754, 52.01458811759949, 54.075597524642944, 55.91041646897793, 59.334484934806824, 58.18155840039253, 54.92848455905914, 57.76430279016495, 58.55477437376976, 58.197973519563675, 57.520507872104645, 55.07247403264046, 49.30836573243141, 43.698567152023315, 41.46081022918224, 45.57954601943493, 45.11353522539139, 46.314924359321594, 47.99572616815567, 42.395841255784035, 44.47180286049843, 43.26236575841904, 50.474576354026794, 57.61013746261597, 56.897451505064964, 54.495455995202065, 54.25350017845631, 52.45759874582291, 54.363432079553604, 51.383802965283394, 50.921181589365005, 52.3154141753912, 51.20118096470833, 49.27325561642647, 48.47798489034176, 46.2167414277792, 45.499484315514565, 40.37105530500412, 32.40635968744755, 18.88558130711317, 12.572590559720993, 6.9644116424024105, 6.947070322930813, 9.296200219541788, 17.581633776426315, 32.98637196421623, 29.19235534965992, 32.62973450124264, 38.92583325505257, 40.3255033493042, 47.79999867081642, 42.84416399896145, 38.44277277588844, 30.44719811528921, 16.731636486947536, 5.087654823437333, 3.1182798743247986, 19.83384132385254, 46.896357759833336, 55.53669132292271, 51.16670161485672, 52.47065104544163, 54.76021058857441, 61.27126380801201, 65.1421009004116, 61.61226511001587, 53.415694534778595, 44.8924744874239, 10.833074301481247, 27.92262688279152, 32.4246671050787, 23.394879139959812, 34.416801407933235, 36.84395916759968, 41.707416996359825, 44.1860543936491, 20.863795056939125, 1.4018097356893122, 0.07658525413717143, 0.3614650742383674, 0.044163586644572206, 0.04233123516314663, 0.08134216841426678, 0.0344605104328366, 0.006649916385867982, 0.05218979131313972, 0.12206865765620023, 0.04262897367880214, 0.05087854995508678, 0.050596407672856, 0.018750639355857857, 0.036218717650626786, 0.12731258408166468, 0.05064055061666295, 0.028192429490445647, 0.07402357558021322, 0.034978889452759176, 0.04413281349116005, 0.012934718379256083, 0.03626555087976158, 0.041499925864627585, 0.04176809350610711, 0.07719354805885814, 0.06649658767855726, 0.06442301964852959, 0.06649614981142804, 0.10995588731020689, 0.1179393999336753, 0.05047199774708133, 0.03863582212943584, 0.20548331056488678, 0.6039517046883702, 45.36423437297344, 74.80574995279312, 43.3407973498106, 33.36071267724037, 43.021599277853966, 48.375644981861115, 26.491851657629013, 33.82060579955578, 58.77892814576626, 83.10109242796898, 66.22049063444138, 40.78231863677502, 52.63704791665077, 65.55719822645187, 65.46497717499733, 60.25194950401783, 63.86547580361366, 59.388879016041756, 22.228037752211094, 3.6905486416071653, 11.14725474268198, 31.98591984808445, 53.94039697945118, 70.34307181835175, 73.82367745041847, 70.04022806882858, 64.82540309429169, 65.27007803320885, 66.62776038050652, 69.12728905677795, 66.46585866808891, 66.84016138315201, 65.8287924528122, 66.87404796481133, 68.22568103671074, 67.23978593945503, 67.57574871182442, 66.38193637132645, 63.06407980620861, 52.21566952764988, 46.449847519397736, 49.417017102241516, 59.16122563183308, 64.79887291789055, 60.63483215868473, 62.46621608734131, 56.385675966739655, 54.83372524380684, 52.71088935434818, 52.31838561594486, 55.00304415822029, 56.05267323553562, 54.48941811919212, 47.94232003390789, 45.03176361322403, 44.417716562747955, 42.270968556404114, 45.13555884361267, 46.01784870028496, 44.10565070807934, 46.09196372330189, 49.14663501083851, 49.53228771686554, 56.08019895851612, 53.344786539673805, 53.173419535160065, 56.13534539937973, 59.00136440992355, 58.20436857640743, 59.476627707481384, 57.574609369039536, 59.345223158597946, 59.789947494864464, 57.60284945368767, 59.21310804784298, 58.08212153613567, 53.39843966066837, 46.0763655602932, 44.91804711520672, 47.2141233086586, 50.2757254242897, 50.72484992444515, 50.683185160160065, 46.47431440651417, 45.61140350997448, 45.77607147395611, 52.98526503145695, 59.61617521941662, 58.71377684175968, 58.38027633726597, 56.244057565927505, 54.5102372020483, 56.248009353876114, 55.2254044264555, 54.29001621901989, 54.105277732014656, 53.80279116332531, 52.25965976715088, 51.64981909096241, 49.700907468795776, 47.74508401751518, 41.38300560414791, 33.66229489445686, 21.70397937297821, 14.943041112273932, 9.703875593841076, 8.39152006432414, 10.30882878229022, 18.856026493012905, 35.25369890034199, 30.276750661432743, 31.909350156784058, 39.266017600893974, 43.27098369598389, 49.643462151288986, 45.88571839034557, 42.23128728568554, 33.53325001895428, 18.934722170233727, 6.343046659603715, 4.097630297765136, 22.03727088868618, 52.7312296628952, 60.81167086958885, 57.319840639829636, 59.87973287701607, 60.62214843928814, 66.18170991539955, 69.97058540582657, 67.01451882719994, 62.40587152540684, 48.84043984115124, 15.777596980333328, 20.224078483879566, 23.290949016809464, 29.75249659270048, 33.465598449110985, 36.290480867028236, 49.66948315501213, 57.04731926321983, 24.961774460971355, 1.4939645281992853, 0.04880262189544737, 0.3186835558153689, 0.05776829275419004, 0.13249598094262183, 0.07270372530911118, 0.07058068571495824, 0.039840383469709195, 0.02941261303931242, 0.06449010979849845, 0.05839604949869681, 0.08926956725190394, 0.06682330335024744, 0.00802714441306307, 0.04544858566077892, 0.26104332064278424, 0.05547653330722824, 0.12420929357176647, 0.16402234003180638, 0.1866858231369406, 0.18552541587268934, 0.12523489713203162, 0.11054564980440773, 0.12351318131550215, 0.15046368789626285, 0.19397310476051643, 0.29751411988399923, 0.17134175664978102, 0.09959643342881463, 0.11581143247894943, 0.1823017341666855, 0.09460079250857234, 0.12446281863958575, 0.1861142655252479, 0.5261278431862593, 59.77930426597595, 86.52717858552933, 54.81823727488518, 52.72304110229015, 54.866411089897156, 79.56371024250984, 41.613296046853065, 28.688162304461002, 62.73438669741154, 96.7563208937645, 74.9154956638813, 47.89025142788887, 60.00132255256176, 70.44779419898987, 69.6360969543457, 64.4409929215908, 68.14014002680779, 67.30272576212883, 24.82844341546297, 5.353028308600187, 12.38693917170167, 32.99660861492157, 57.940297946333885, 71.91450029611588, 78.96892055869102, 74.04218092560768, 68.28420549631119, 70.31003639101982, 71.93176656961441, 72.98070788383484, 65.7384940981865, 67.82746240496635, 65.03021210432053, 67.09473252296448, 70.29651671648026, 70.4776605963707, 69.79777827858925, 68.67969587445259, 62.13762491941452, 55.231902077794075, 48.75330291688442, 53.62830452620983, 64.04380783438683, 67.02026411890984, 65.63415169715881, 65.6929649412632, 58.98717977106571, 54.860844388604164, 56.98613494634628, 55.516237020492554, 59.551438093185425, 59.428222104907036, 58.9587838947773, 51.59613937139511, 47.31035314500332, 49.64465148746967, 45.84959372878075, 47.610894218087196, 50.357603430747986, 49.504431411623955, 48.773764818906784, 51.73159450292587, 53.35957154631615, 56.828576400876045, 58.051388785243034, 55.7478953897953, 57.639213502407074, 59.34913694858551, 60.895691961050034, 59.62933391332626, 58.379561975598335, 60.321679562330246, 60.29058203101158, 60.10712027549744, 60.833033323287964, 59.69866879284382, 55.272540897130966, 48.4330864995718, 49.36538927257061, 50.726540833711624, 52.19625636935234, 52.7060142159462, 52.09813803434372, 47.703119069337845, 47.649446949362755, 48.49882297217846, 53.67635674774647, 62.39678241312504, 59.980473071336746, 59.52951326966286, 57.28477992117405, 56.674479469656944, 60.573750436306, 59.03048224747181, 56.85782343149185, 58.79887707531452, 56.515803784132004, 56.15153253078461, 55.68762682378292, 54.51209910213947, 52.20189526677132, 46.831069663167, 38.69935400784016, 25.836658515036106, 17.246358767151833, 13.278258293867111, 10.873601976782084, 13.559053726494312, 21.745571941137314, 42.02653907239437, 34.645552933216095, 35.05590811371803, 42.07970581948757, 47.76618428528309, 53.93090508878231, 48.46960633993149, 46.858359798789024, 35.72605535387993, 20.432563796639442, 7.113699456676841, 5.649078972637653, 24.798487722873688, 57.56588123738766, 66.3193841278553, 62.05633208155632, 64.62709173560143, 64.45149555802345, 71.81284815073013, 74.2160215973854, 73.67325872182846, 66.2189631164074, 55.03995917737484, 14.214171823114157, 33.77340853214264, 41.90204255282879, 33.53872932493687, 46.91394321620464, 50.98770461976528, 58.75147461891174, 74.95424598455429, 36.77975781261921, 2.027876847423613, 0.18773977673845366, 0.4751128196949139, 0.10575139807770029, 0.18659191176993772, 0.12782689242158085, 0.1560994831379503, 0.09753202350111678, 0.144887873029802, 0.2426187475793995, 0.1529853424290195, 0.210517120140139, 0.1491420267848298, 0.14057578722713515, 0.10090489173308015], [0.025982497390941717, 0.012698667178483447, 0.05828515408211388, 0.029405941131699365, 0.0751858382136561, 0.06519812610349618, 0.044888509073643945, 0.004336321098890039, 0.02158468239940703, 0.010472028407093603, 0.060903228441020474, 0.040478790033375844, 0.01821617057430558, 0.027848095232911874, 0.08983096486190334, 0.07525684690335765, 0.14859910123050213, 0.05718660482671112, 0.3537109965691343, 0.028100529343646485, 7.595631396397948, 59.767456501722336, 53.51171538233757, 41.241759583353996, 40.75727038085461, 36.857539638876915, 54.40405949950218, 13.129370883107185, 32.197697684168816, 61.44667759537697, 73.93264040350914, 65.96653506159782, 57.57761500775814, 64.7618705034256, 59.82242055237293, 53.40125910937786, 55.752622336149216, 56.34699024260044, 27.22869861871004, 5.4717339389026165, 8.955870531499386, 27.659825384616852, 55.422347858548164, 69.7488521039486, 69.74203526973724, 65.6943328678608, 63.000524416565895, 63.047489896416664, 62.12676130235195, 62.70418971776962, 56.78610607981682, 56.99682757258415, 60.940240770578384, 58.62979754805565, 59.97081778943539, 60.33854305744171, 57.55736969411373, 55.94198137521744, 49.99729536473751, 36.33492328226566, 29.56718433648348, 47.96870581805706, 63.62028256058693, 61.58632770180702, 61.14308908581734, 55.57379633188248, 54.93657432496548, 51.026519536972046, 50.328345000743866, 54.06968504190445, 59.417913258075714, 60.51545396447182, 59.12554174661636, 52.808331325650215, 45.64305581152439, 41.521120592951775, 40.77585518360138, 39.54292394220829, 40.69443315267563, 43.13184656202793, 44.316854774951935, 45.765128061175346, 48.85850787162781, 48.96771781146526, 50.24944223463535, 52.175653874874115, 52.66950957477093, 55.608971044421196, 58.04782457649708, 60.10926716029644, 54.57648664712906, 59.26973260939121, 57.90735751390457, 60.83757407963276, 58.04377779364586, 56.151513531804085, 53.579659536480904, 41.562564969062805, 42.09088861942291, 45.218519791960716, 44.33887839317322, 47.566140219569206, 48.07058595120907, 41.02576017379761, 40.49730733036995, 42.665607780218124, 53.393408730626106, 58.77145774662495, 58.814691826701164, 54.53719675540924, 50.07744066417217, 51.64184331893921, 51.193262189626694, 51.44536726176739, 50.51144577562809, 52.411720007658005, 52.39334799349308, 51.634920090436935, 47.111156433820724, 45.4603274166584, 42.61515408754349, 39.58418972790241, 34.31253120303154, 27.23297718912363, 18.556710854172707, 8.47539296373725, 3.6908371886238456, 1.0186567017808557, 6.15325016900897, 22.806566208600998, 14.231823775917292, 11.464183386415243, 25.375526659190655, 44.28266040980816, 51.6595883667469, 48.91193300485611, 41.344574466347694, 33.24174866080284, 18.778421357274055, 5.361610623076558, 3.851655009202659, 21.805228739976883, 51.12511284649372, 57.47538149356842, 56.24430075287819, 52.587639167904854, 54.96029645204544, 61.000790521502495, 62.78582073748112, 52.42848850786686, 56.35065324604511, 27.04881627112627, 8.807649984955788, 23.580098301172256, 23.97474892437458, 28.72518941760063, 35.037988275289536, 38.24633851647377, 47.44227446615696, 24.04212310910225, 4.593541212379932, 0.08479443160467781, 0.5280517274513841, 0.12601063441252336, 0.24754736514296383, 0.05966642820567358, 0.1270880101947114, 0.04199203656753525, 0.08872480117133819, 0.08141098776832223, 0.03836802927253302, 0.014294660395535175, 0.045935096859466285, 0.09755322666023858, 0.0316938655305421, 0.03376626467797905, 0.024023702499107458, 0.02492824878572719, 0.06227295845746994, 0.019609398841566872, 0.07305680206627585, 0.08569527271902189, 0.05341658368706703, 0.01864745485363528, 0.031196585769066587, 0.025410592825210188, 0.02230895173852332, 0.02651823338965187, 0.037060290851513855, 0.01361431506666122, 0.04897862221696414, 0.08122735816868953, 0.10147892811801285, 0.08887510834028944, 0.2682494558393955, 0.10200848017120734, 8.926282469183207, 71.54683202505112, 63.51305611431599, 44.54471714794636, 38.29170808196068, 46.758732944726944, 32.811140567064285, 20.682333894073963, 43.92638772726059, 65.83336740732193, 74.61731046438217, 67.13854417204857, 64.16230827569962, 68.92323240637779, 63.079176396131516, 61.288324892520905, 64.8372508585453, 63.50822277367115, 31.844122856855392, 7.270936919376254, 10.187240056693554, 29.99354425817728, 56.98667071759701, 74.05536621809006, 73.72213929891586, 69.17830511927605, 66.62164270877838, 66.87378197908401, 67.55048766732216, 66.12810999155045, 60.60635648667812, 58.37844863533974, 63.20939540863037, 62.385873198509216, 64.17237773537636, 63.038260191679, 60.214935690164566, 57.25470833480358, 53.07283893227577, 42.61181406676769, 35.456722006201744, 54.70629908144474, 65.53224116563797, 65.53146600723267, 64.44392636418343, 57.27195180952549, 57.237723246216774, 55.491036772727966, 51.094117909669876, 54.993829652667046, 60.422358959913254, 62.46237449347973, 59.92431968450546, 54.56089988350868, 45.989821404218674, 43.54284390807152, 43.594327345490456, 43.964860662817955, 44.29211810231209, 45.79332634806633, 46.65135830640793, 49.065562561154366, 53.86338651180267, 50.786516815423965, 51.23045079410076, 54.470939710736275, 56.52456611394882, 58.160841912031174, 59.83495607972145, 58.92396256327629, 56.00595474243164, 60.0428619235754, 60.04445023834705, 60.605216547846794, 59.8674101382494, 57.654230296611786, 54.32781659066677, 46.48555800318718, 44.76020738482475, 48.66316415369511, 49.79532100260258, 49.682923033833504, 49.59893614053726, 44.224303141236305, 44.61903735995293, 45.96999026834965, 55.8604871481657, 60.34081153571606, 60.24781912565231, 60.99913001060486, 52.66744248569012, 58.34935359656811, 54.92504194378853, 55.105862841010094, 53.29671531915665, 53.137139081954956, 54.91147667169571, 55.3647543489933, 51.6538392752409, 49.55973744392395, 47.07282029092312, 42.379429936409, 35.83998464047909, 30.527723394334316, 23.743348941206932, 14.40613942220807, 5.670392503961921, 2.6383684761822224, 7.677645245566964, 27.249386608600616, 15.687203630805016, 11.412820592522621, 25.835621170699596, 45.29369875788689, 55.24887956678867, 52.474378645420074, 44.62448246777058, 36.291354820132256, 20.46795889735222, 6.994625246152282, 5.8924107905477285, 25.097432881593704, 55.870153829455376, 64.3262466788292, 61.87090963125229, 56.329655572772026, 58.52083459496498, 66.06904596090317, 64.07930552959442, 61.213145926594734, 63.62650282680988, 32.58461952209473, 11.559855602681637, 19.44763384759426, 23.527607917785645, 31.765852756798267, 35.4614033550024, 42.61578105390072, 58.82729195058346, 36.957698464393616, 6.199130807071924, 0.04750977466756012, 0.41369843704160303, 0.07441508074407466, 0.248768569144886, 0.0755278866563458, 0.05390320991864428, 0.07106291843228973, 0.10053640799014829, 0.01977372889086837, 0.04579237815050874, 0.04631528056052048, 0.04809022691915743, 0.05037758543039672, 0.09575575983035378, 0.03279214390204288, 0.101561135816155, 0.14096805680310354, 0.14380709821125492, 0.12444505904568359, 0.21369204274378717, 0.11084230849519372, 0.1419316910323687, 0.12103888322599232, 0.08438783857855015, 0.11170481768203899, 0.14724287088029087, 0.12828717241063714, 0.11799240412074141, 0.11557390069356188, 0.14522902347380295, 0.15628513880074024, 0.2077972676488571, 0.26296753145288676, 0.5535081645939499, 0.1753524414380081, 15.48280119895935, 91.43529161810875, 72.60470286011696, 64.25716638565063, 55.22139944136143, 61.541885286569595, 72.76044890284538, 15.851686354726553, 43.151666298508644, 72.12296470999718, 83.84799554944038, 74.72082450985909, 70.92290550470352, 76.48643776774406, 71.2828753888607, 68.66158604621887, 69.69436302781105, 69.0907122194767, 34.07394580543041, 9.77322282269597, 11.889974288642406, 31.087387762963772, 59.43764939904213, 75.38152545690536, 78.148422986269, 72.9901921749115, 69.51331034302711, 69.18338924646378, 68.2825031876564, 67.89321407675743, 63.26973617076874, 61.8343061953783, 65.2216762304306, 65.46852618455887, 65.41623339056969, 65.24556934833527, 64.09418553113937, 59.29677575826645, 55.205413699150085, 47.088217064738274, 44.19835813343525, 59.60527740418911, 67.5806200504303, 68.60130608081818, 66.68266743421555, 60.70301190018654, 60.763865634799004, 56.967443749308586, 54.35487873852253, 59.024235382676125, 61.927879974246025, 64.37974020838737, 62.29190044105053, 57.60748900473118, 51.30483940243721, 46.499009281396866, 46.294078677892685, 47.87668615579605, 48.69577780365944, 50.15005476772785, 51.1325528472662, 52.354213893413544, 55.182234942913055, 52.275683507323265, 52.81318746507168, 57.0588668435812, 57.02853687107563, 57.91452392935753, 61.04479216039181, 60.68210922181606, 53.90755534172058, 61.73247165977955, 59.87251706421375, 62.68502734601498, 61.035889238119125, 57.969419583678246, 57.40091688930988, 47.613200694322586, 47.814829275012016, 52.81867057085037, 49.537497237324715, 52.36049875617027, 51.663817539811134, 46.51197038590908, 45.5514807254076, 48.523669838905334, 58.349839970469475, 61.21443025767803, 63.00296388566494, 61.09556883573532, 55.675881654024124, 58.683089688420296, 58.79818931221962, 57.797710597515106, 56.22258111834526, 55.1688102632761, 58.47725473344326, 57.130834981799126, 55.310964435338974, 52.053414434194565, 51.88944183290005, 45.199448615312576, 41.992971673607826, 35.22742711007595, 29.71096482127905, 20.836850702762604, 9.448326006531715, 7.9997857846319675, 12.543879300355911, 32.73837827146053, 20.352420397102833, 13.843753449618816, 30.15442382544279, 48.23154151439667, 56.98437564074993, 56.94980129599571, 47.77487821877003, 39.306888207793236, 21.89030047506094, 8.325309567153454, 8.05553164333105, 26.340944655239582, 61.49089202284813, 68.9587377011776, 67.9662461578846, 62.38052688539028, 65.37401765584946, 68.96430060267448, 72.84572392702103, 65.9544213116169, 69.35437247157097, 35.114709958434105, 14.413918554782867, 32.37994730472565, 32.70388372242451, 40.141460224986076, 48.10981884598732, 57.46200621128082, 67.26690888404846, 59.19017247855663, 8.531397208571434, 0.2183355123270303, 0.5043133324943483, 0.22333209577482194, 0.4484641074668616, 0.15449705271748826, 0.1521845650859177, 0.1644084497820586, 0.1752131403191015, 0.13161968265194446, 0.18023041484411806, 0.08829250757116824, 0.13666901795659214, 0.2264297756482847, 0.1551070684217848, 0.17134592751972377], [0.01223691495397361, 0.06455150025431067, 0.051064068320556544, 0.014870550294290297, 0.03113468694209587, 0.03504223917843774, 0.07904156256699935, 0.013532726134144468, 0.035857907714671455, 0.08229385406593792, 0.027103953034384176, 0.042667413217714056, 0.01354608015390113, 0.08738020027521998, 0.07463783636922017, 0.09015103089041077, 0.029481621641025413, 0.04743467303342186, 0.1985240136855282, 0.1422933692811057, 1.386887936387211, 35.40379844605923, 62.205588072538376, 39.04768131673336, 42.89823889732361, 32.93648824095726, 53.36116746068001, 31.23981848359108, 15.54205996915698, 51.89099594950676, 69.27408277988434, 69.04816210269928, 70.35219892859459, 71.7213186621666, 62.317416071891785, 56.18035778403282, 52.734387293457985, 58.70862811803818, 35.91821104288101, 7.267398834228516, 7.886127708479762, 25.015598572790623, 54.4944604486227, 69.16948199272156, 67.82588168978691, 63.512007370591164, 62.18501977622509, 69.96311500668526, 64.26415041089058, 58.20040538907051, 43.938980251550674, 39.290157705545425, 43.72100114822388, 49.67774011194706, 55.27569852769375, 57.16608569025993, 59.77064453065395, 58.04367519915104, 55.90744882822037, 50.02194084227085, 45.72102002799511, 59.58876349031925, 64.51014161109924, 59.83703836798668, 58.58363002538681, 55.82128465175629, 56.86505064368248, 53.11345875263214, 57.13072098791599, 58.671264722943306, 59.64667238295078, 60.038218572735786, 61.347871497273445, 54.405845403671265, 44.778928980231285, 41.56193420290947, 39.19630654156208, 40.44145032763481, 41.88545644283295, 42.57704593241215, 45.52852615714073, 47.30713091790676, 49.18226569890976, 50.231598392128944, 47.91267402470112, 52.751596570014954, 53.08001674711704, 56.873691380023956, 56.99887566268444, 58.83836455643177, 55.566610917449, 58.92655402421951, 57.685202434659004, 61.41612343490124, 57.46521703898907, 57.23796263337135, 51.52244992554188, 46.09153054654598, 42.12281070649624, 44.44198966026306, 45.02610191702843, 45.89203365147114, 44.470617324113846, 41.24552518129349, 43.99365931749344, 47.15792812407017, 54.2730463296175, 56.47456839680672, 55.85621617734432, 49.71013717353344, 39.57970216870308, 47.90738470852375, 50.15261583030224, 51.26265786588192, 48.11337925493717, 48.632344007492065, 47.66544409096241, 51.02112762629986, 47.56947264075279, 45.94553858041763, 39.99385714530945, 38.57658639550209, 32.349993512034416, 26.289282627403736, 24.948558770120144, 19.906626418232918, 9.262580573558807, 2.859700662083924, 1.867211137432605, 5.185309583321214, 6.4488709811121225, 10.761618185788393, 25.651937127113342, 43.63605670630932, 50.65428011119366, 52.51657918095589, 45.39417676627636, 36.44765563309193, 23.266860209405422, 7.420694483444095, 6.322143031284213, 27.6290375366807, 52.624497190117836, 56.4448843896389, 58.00986461341381, 56.43041096627712, 62.10925564169884, 62.23230443894863, 60.939374417066574, 55.09328171610832, 45.347446873784065, 13.400987908244133, 14.012211710214615, 20.336238965392113, 26.489832065999508, 39.280802607536316, 44.34619300067425, 36.66527755558491, 41.25519186258316, 15.991048626601696, 0.9679873113054782, 0.13066715095192194, 0.17640670674154535, 0.024764399277046323, 0.01947988293977687, 0.024067719277809374, 0.12466448242776096, 0.03639649170509074, 0.030428531572397333, 0.015851461721467786, 0.008419113419222413, 0.07974589039804414, 0.020089284516870975, 0.07339075367781334, 0.029330683646549005, 0.03691541620355565, 0.05904779987758957, 0.01342165445748833, 0.12366578914225101, 0.05561264690186363, 0.011859399273816962, 0.007979632118804147, 0.04133146576350555, 0.060413077007979155, 0.02835278348356951, 0.022073188119975384, 0.025222629083145875, 0.015567708978778683, 0.04463256831513718, 0.07409452489810064, 0.027448266882856842, 0.07446186573361047, 0.040074660937534645, 0.05207386042457074, 0.06243668365641497, 0.28064281737897545, 0.9130971785634756, 45.00233419239521, 75.82876905798912, 49.18120935559273, 42.456930577754974, 40.19302345812321, 44.1605007648468, 23.444804660975933, 29.120463207364082, 59.4393365085125, 75.1617756485939, 73.3386942744255, 78.52510437369347, 78.4724847972393, 68.56150701642036, 64.895129352808, 58.63363154232502, 65.64232125878334, 40.57394541800022, 8.842444717884064, 9.708686135709286, 26.32670871913433, 55.3884232789278, 71.1203733086586, 71.05686351656914, 68.10091093182564, 66.96999281644821, 72.86770194768906, 69.5674954354763, 61.74317188560963, 48.94311413168907, 44.96145598590374, 49.507433250546455, 52.33378238976002, 56.88468039035797, 59.87875632941723, 60.90910904109478, 58.70583526790142, 55.4600228369236, 52.45439551770687, 49.79178339242935, 60.649833753705025, 65.28760269284248, 62.68739841878414, 61.42341524362564, 58.408493623137474, 58.86342041194439, 56.16498380899429, 57.83761985599995, 59.876085072755814, 61.686976701021194, 60.66171571612358, 63.00017483532429, 56.35804384946823, 47.67460159957409, 44.624566063284874, 42.46056318283081, 43.713006377220154, 43.35645250976086, 46.304805502295494, 48.81474941968918, 51.34843826293945, 52.162122800946236, 51.51994585990906, 53.33692476153374, 55.846272110939026, 56.551761254668236, 59.7650246322155, 59.02504853904247, 60.947220996022224, 59.088087156414986, 59.763888493180275, 60.71508005261421, 60.55756710469723, 58.136515617370605, 59.0677734464407, 53.22642669081688, 47.470088973641396, 46.05563007295132, 49.09162536263466, 47.80221775174141, 49.00189317762852, 47.192141488194466, 44.91805851459503, 48.1383553147316, 46.98458522558212, 58.259062841534615, 59.854004457592964, 59.31472219526768, 53.635064363479614, 46.89292274415493, 51.7254426330328, 56.428758054971695, 54.474902898073196, 53.192714899778366, 50.824666768312454, 49.766807332634926, 55.01434475183487, 50.880063995718956, 49.474428221583366, 42.854818627238274, 40.099210292100906, 34.92480754852295, 31.571227200329304, 31.217640973627567, 26.477566324174404, 15.163551829755306, 7.900711325928569, 2.134118196554482, 9.595255572348833, 6.247910689562559, 11.551262363791466, 25.914254151284695, 43.081419467926025, 53.09825576841831, 54.29625928401947, 49.09493498504162, 39.51715372502804, 26.560996547341347, 11.331256069242954, 10.101610701531172, 30.218777172267437, 56.62418536841869, 63.734192848205566, 62.37186335027218, 61.466835513710976, 68.37923839688301, 67.7639602124691, 68.65346968173981, 61.161103919148445, 51.12319774925709, 20.48784703016281, 19.904547929763794, 19.383231103420258, 26.80722713470459, 35.28409726917744, 45.32565124332905, 44.513148441910744, 54.96974274516106, 22.29047980159521, 1.7784778238274157, 0.0983533583348617, 0.31151598261203617, 0.017144869270850904, 0.06333726501907222, 0.02008585764997406, 0.023358960825135, 0.05201229185331613, 0.05879732874745969, 0.07057232171064243, 0.023744471291138325, 0.019305008827359416, 0.04571194789605215, 0.030501488399750087, 0.0070172790219658054, 0.04682197446527425, 0.11932970970519818, 0.16482795617775992, 0.22835060226498172, 0.13298573903739452, 0.09590565881808288, 0.07154830527724698, 0.22956457774853334, 0.056029214392765425, 0.1295032407506369, 0.12163548832177185, 0.1244548182876315, 0.11411330211558379, 0.08234089880716056, 0.19469374499749392, 0.1534718944458291, 0.1825111682410352, 0.09845860971836373, 0.16717018908821046, 0.25693514733575284, 0.3436905483249575, 1.26288503408432, 60.80277934670448, 88.08137878775597, 60.31971126794815, 60.24146966636181, 46.75483055412769, 76.69462859630585, 35.51537945866585, 23.00099227577448, 61.58509276807308, 81.73446536064148, 80.93925923109055, 83.19784283638, 85.84511518478394, 72.4330660700798, 72.77389258146286, 65.57821869850159, 72.639379799366, 44.17775183916092, 11.936061065644026, 11.413964331150055, 26.14259149879217, 57.711219638586044, 73.94051358103752, 73.8189809024334, 72.30264946818352, 70.81485450267792, 75.80078735947609, 72.19309374690056, 66.4719307422638, 54.24213878810406, 49.567424431443214, 52.27717682719231, 56.69075399637222, 60.89989073574543, 62.47682511806488, 64.79440435767174, 64.29463997483253, 59.77654941380024, 58.381868451833725, 54.479584246873856, 64.94372874498367, 70.20804226398468, 66.80973261594772, 64.13731321692467, 62.616741210222244, 63.9718396961689, 57.32025481760502, 62.74857133626938, 62.297334149479866, 64.049963504076, 63.17459687590599, 65.44492185115814, 60.70244573056698, 52.09198236465454, 46.63496598601341, 46.998591274023056, 49.11866471171379, 48.326407223939896, 50.483923852443695, 54.30045425891876, 52.1965641528368, 57.63878032565117, 55.02090699970722, 53.738635405898094, 59.71515990793705, 58.118842765688896, 62.64640621840954, 59.719263687729836, 60.99858283996582, 58.93423721194267, 61.07575669884682, 60.92402704060078, 64.71305072307587, 60.108096823096275, 61.53499245643616, 56.90170347690582, 50.71493245661259, 48.22950482368469, 52.06314951181412, 51.599521189928055, 51.02086544036865, 50.35151615738869, 48.2735900580883, 50.66508673131466, 50.61232656240463, 60.32706767320633, 63.05374816060066, 59.15321946144104, 55.93476936221123, 47.23168596625328, 52.89283499121666, 57.53259502351284, 57.0367444306612, 55.45374937355518, 54.953962191939354, 55.88507182896137, 55.853525921702385, 54.44260463118553, 52.871727123856544, 46.31963990628719, 43.20661514997482, 40.36090984940529, 38.81244353950024, 40.25744900107384, 36.01820267736912, 21.699723601341248, 10.929597672075033, 6.311419531702995, 17.718150950968266, 10.101893786340952, 13.56577841565013, 28.744357489049435, 46.6235513985157, 57.613249495625496, 59.92044769227505, 56.29774488508701, 41.64214409887791, 27.741361409425735, 13.044795021414757, 13.477027527987957, 33.49684417247772, 61.955808475613594, 66.23421549797058, 68.17327424883842, 64.40877065062523, 70.69522932171822, 71.88328877091408, 74.40418750047684, 66.16217136383057, 58.60457070171833, 21.77359353750944, 22.326526567339897, 24.593703411519527, 40.70992112159729, 48.97325411438942, 62.53566116094589, 52.796867340803146, 70.87801471352577, 33.79767023026943, 2.700510579161346, 0.2065786166349426, 0.40102629514876753, 0.15456035791430622, 0.10724183841375634, 0.08679193691932596, 0.1691611486603506, 0.1303739580907859, 0.17869758303277194, 0.20674736617365852, 0.06687297529424541, 0.18770301074255258, 0.20658617169829085, 0.2037207395187579, 0.23465755133656785, 0.08181575511116534], [0.059405299834907055, 0.03733186866156757, 0.05803756990644615, 0.04770947176439222, 0.004342707743489882, 0.037957625318085775, 0.02512299204681767, 0.051917052041972056, 0.030721657640242483, 0.032568004171480425, 0.06325516864308156, 0.04680883474065922, 0.08230518666096032, 0.06877368228742853, 0.04362652776762843, 0.19680635741678998, 0.11716539185727015, 0.1360818010289222, 0.022201190040505026, 0.31090587785001844, 0.020503263767750468, 10.349717438220978, 64.82891410589218, 46.443011686205864, 43.11647638678551, 33.53381238877773, 34.296936839818954, 49.210277795791626, 13.908668216317892, 20.68139534443617, 65.38684576749802, 65.52188292145729, 66.49487391114235, 72.079768627882, 72.46924012899399, 64.57676723599434, 56.851462572813034, 57.26943254470825, 39.19904239475727, 14.063262920826674, 4.8614781349897385, 22.65162192285061, 56.62937968969345, 64.3268546462059, 71.11438482999802, 65.66125944256783, 62.477136701345444, 69.69686329364777, 64.70315605401993, 53.25843997299671, 38.06513763964176, 33.73465061187744, 40.41235528886318, 50.74109025299549, 56.5445302426815, 61.654135063290596, 62.11132653057575, 58.15204918384552, 58.1938773393631, 53.75440455973148, 54.858435317873955, 60.85786499083042, 59.487707912921906, 57.94602043926716, 57.51964531838894, 55.532891526818275, 56.982183158397675, 59.29085187613964, 59.11085933446884, 59.675520434975624, 62.82729931175709, 61.15007311105728, 61.02007448673248, 54.77187596261501, 44.622552171349525, 41.98678940534592, 40.030350387096405, 38.36387000977993, 39.965324476361275, 41.57461032271385, 45.193642526865005, 44.98048536479473, 47.73939572274685, 49.33177627623081, 47.53109470009804, 50.83616495132446, 53.29945117235184, 55.972755923867226, 55.28084345161915, 61.38979084789753, 53.77816468477249, 56.0079762339592, 60.07688909769058, 59.42564584314823, 58.03787671029568, 55.29628582298756, 51.31712794303894, 44.9396413564682, 43.74791130423546, 44.12661038339138, 44.88966263830662, 44.46710631251335, 43.81679780781269, 42.73257538676262, 42.11143031716347, 51.59730210900307, 55.34436084330082, 57.94045373797417, 56.696210503578186, 40.36498323082924, 27.38823875784874, 41.36429540812969, 50.275710225105286, 49.84007880091667, 48.42282325029373, 45.512065440416336, 46.23479425907135, 40.895354971289635, 44.651046842336655, 35.228175669908524, 32.36013136804104, 35.267484560608864, 31.38948105275631, 24.49369467794895, 18.287145718932152, 20.33509522676468, 12.346101813018322, 8.780413046479225, 1.4653775934129953, 6.300887446850538, 3.000465533696115, 13.0663769133389, 31.63032542914152, 46.32468603551388, 53.58067028224468, 57.02082708477974, 52.75097720324993, 43.74017491936684, 21.216104552149773, 12.046434693038464, 12.674085963517427, 32.67734594643116, 47.30645835399628, 51.68080262839794, 55.00886544585228, 52.85287633538246, 57.23197415471077, 60.10056182742119, 54.34393912553787, 61.58576913177967, 33.907168954610825, 10.046451911330223, 18.645755276083946, 27.273661606013775, 29.13559589534998, 53.776667565107346, 29.93034604936838, 38.581674322485924, 29.07171942293644, 10.194127187132835, 0.2116093982476741, 0.17784043215215206, 0.09110750339459628, 0.07124313415260985, 0.05923298798734322, 0.08170046989107504, 0.04361633808002807, 0.06056980375433341, 0.0592653716012137, 0.007572248241558555, 0.026377167814644054, 0.038121866309666075, 0.08662179214297794, 0.06428054955904372, 0.06055169535102323, 0.015084299957379699, 0.03612197127949912, 0.056158188526751474, 0.08871337951859459, 0.047497143314103596, 0.018404915426799562, 0.03418770807911642, 0.05802229650726076, 0.04938143400067929, 0.030485558199870866, 0.008882844394975109, 0.03773246884520631, 0.039965387113625184, 0.02655948937899666, 0.04300074142520316, 0.013376730403251713, 0.15022847161162645, 0.03513888535962906, 0.058936767163686454, 0.09765711991349235, 0.5002872704062611, 0.022897920134710148, 12.18609619885683, 77.61601835489273, 60.13512097299099, 44.285951033234596, 35.72317510843277, 34.82689060270786, 34.58668269217014, 20.223339423537254, 34.79843012988567, 69.61835190653801, 71.9519130885601, 71.86020880937576, 75.96230909228325, 73.35854440927505, 67.08654776215553, 61.986328437924385, 63.116718381643295, 45.83263523876667, 15.815965421497822, 6.717887995764613, 23.434429317712784, 56.444082632660866, 69.43178951740265, 74.1668750345707, 69.57862883806229, 67.97340497374535, 72.23154008388519, 68.1642535328865, 57.0965988188982, 41.46934077143669, 38.053966239094734, 45.08357763290405, 52.42975763976574, 56.61353074014187, 63.63025702536106, 62.15464420616627, 61.35837033390999, 56.83976300060749, 55.06165221333504, 56.253826841712, 62.83194646239281, 63.438184931874275, 60.561028718948364, 60.451609790325165, 59.901460111141205, 59.19541619718075, 59.91915576159954, 61.956606432795525, 63.548341020941734, 64.79023978114128, 61.14419102668762, 65.62744125723839, 57.12698578834534, 47.7009341865778, 44.906723722815514, 43.52056570351124, 44.029012620449066, 44.63588185608387, 45.34071743488312, 49.35518302023411, 49.653090834617615, 49.132438972592354, 52.06334330141544, 50.713883712887764, 53.661708533763885, 56.670903861522675, 58.23680363595486, 57.80875660479069, 64.4364483654499, 55.42103312909603, 57.93840944766998, 61.62127062678337, 61.46596156060696, 59.51969459652901, 57.993780076503754, 53.42439986765385, 47.92102977633476, 47.81117767095566, 45.441841408610344, 48.20451736450195, 47.7265790104866, 46.35364048182964, 45.54545044898987, 45.97983554005623, 54.43851985037327, 61.2500761449337, 59.36655521392822, 62.448581233620644, 48.00208322703838, 35.52479915320873, 46.88786901533604, 54.029327407479286, 57.09467612206936, 51.92471154034138, 49.656237065792084, 50.42798325419426, 46.24053955078125, 48.99123094975948, 42.75956153869629, 37.07330726087093, 36.34606048464775, 34.0420351177454, 28.359641432762146, 22.74890050292015, 23.75102262943983, 18.91139142215252, 12.798281349241734, 5.507024545222521, 5.232604220509529, 1.909203277900815, 12.54464115947485, 31.569633185863495, 46.2762538343668, 54.52677011489868, 59.04687836766243, 53.64101104438305, 46.88120797276497, 23.867488279938698, 14.644874911755323, 18.958524093031883, 39.19863201677799, 54.156282395124435, 60.75332120060921, 59.68849673867226, 60.77296234667301, 63.57613652944565, 66.83608800172806, 62.82012529671192, 68.22784692049026, 39.66230973601341, 18.133643455803394, 25.97654040902853, 20.57254258543253, 28.0157807841897, 50.32098859548569, 37.95637987554073, 44.89147134125233, 46.9831907004118, 12.76398153975606, 0.2518907398916781, 0.08695385127793998, 0.12032236190862022, 0.02038688016909873, 0.058547351145534776, 0.020476798781601246, 0.035330185055499896, 0.03207583038602024, 0.03150346383336, 0.05064041703008115, 0.040328527393285185, 0.006241455930648954, 0.02729002615524223, 0.0509176091873087, 0.07060931777232327, 0.04926559959130827, 0.20520896825473756, 0.14609991892939433, 0.21512066217837855, 0.10801246229675598, 0.18882481148466468, 0.15417197719216347, 0.13825051981257275, 0.16780606121756136, 0.07417662869556807, 0.1345113423303701, 0.27051834971643984, 0.12659112748224288, 0.13931281515397131, 0.19424391444772482, 0.08419060541200452, 0.2583469497039914, 0.257728414144367, 0.19696891744388267, 0.15011486364528537, 0.49599902238696814, 0.14631395431933925, 18.026576600968838, 98.17040741443634, 66.19825422763824, 64.2403256893158, 45.37204675376415, 55.985728427767754, 60.34841872751713, 19.563170447945595, 31.35726448148489, 68.87862280011177, 78.53879123926163, 77.28596806526184, 84.02495965361595, 82.11391299962997, 73.34982767701149, 67.30033189058304, 68.4133529663086, 48.95259842276573, 18.15132960677147, 7.379484744742513, 24.574518240988255, 60.00031940639019, 72.45208024978638, 78.19024354219437, 72.67749175429344, 70.20592197775841, 74.18870866298676, 72.98083707690239, 63.08246701955795, 46.57471261918545, 44.04620289802551, 50.08806869387627, 57.953194454312325, 60.33212140202522, 68.66445869207382, 69.76354971528053, 64.5285402238369, 60.62128588557243, 59.17237423360348, 62.82254196703434, 66.52225524187088, 64.92669805884361, 63.01032409071922, 61.71917237341404, 61.40744470059872, 61.586168110370636, 63.786371648311615, 62.643297985196114, 63.73512759804726, 64.60653483867645, 63.72300244867802, 65.91798886656761, 60.58197699487209, 50.13188034296036, 47.65976719558239, 47.07654409110546, 46.676729544997215, 48.48501071333885, 50.042360946536064, 52.97144517302513, 53.696480467915535, 53.72325383126736, 56.33641920983791, 52.130204513669014, 56.50178253650665, 57.89419122040272, 60.65275959670544, 60.05447030067444, 66.21534571051598, 52.6138349622488, 57.34577424824238, 62.36867152154446, 64.70808058977127, 61.729124039411545, 61.2490464001894, 56.99259839951992, 49.157247841358185, 50.31324841082096, 49.21991407871246, 51.749552339315414, 50.5530459433794, 50.82174852490425, 46.91342644393444, 48.80368061363697, 56.897185519337654, 64.34466049075127, 60.676485523581505, 62.65631228685379, 49.75770302116871, 39.80099469423294, 48.53935159742832, 55.88316433131695, 60.40041893720627, 54.1325868666172, 54.00363318622112, 51.81330531835556, 50.84685377776623, 51.54959946870804, 45.48857130110264, 39.210278391838074, 42.42310479283333, 39.362901002168655, 37.52983756363392, 29.231225363910198, 30.995877273380756, 26.883363649249077, 18.09512112289667, 9.641853421926498, 10.939711779356003, 5.327509352937341, 14.651073329150677, 34.93207275867462, 51.041798517107964, 58.24773944914341, 63.14239360392094, 58.89295242726803, 50.791232362389565, 26.283658929169178, 16.636632084846497, 22.87804987281561, 43.65532547235489, 57.18465909361839, 62.91980914771557, 64.30729329586029, 61.96392484009266, 67.7209085226059, 70.44814378023148, 66.75891414284706, 72.67138928174973, 42.6288865506649, 15.28866771608591, 24.928068369627, 32.89692856371403, 46.53836376965046, 67.32231751084328, 52.21895255148411, 54.45976071059704, 67.35422059893608, 18.999651186168194, 0.6565472355578095, 0.20266006205929443, 0.3270798287121579, 0.0977840791165363, 0.13300626684213057, 0.12072983066900633, 0.1953122063423507, 0.12708768364973366, 0.1972798179485835, 0.11220190819585696, 0.17720546544296667, 0.14558569964719936, 0.19482657458866015, 0.16338180721504614, 0.15671628207201138, 0.205539966118522], [0.046420865910477005, 0.05827120170579292, 0.06535247797728516, 0.04576692248519976, 0.06301264962530695, 0.07271599301020615, 0.030195781073416583, 0.030957278395362664, 0.02770839706499828, 0.06808843507315032, 0.03849584194540512, 0.05208716342167463, 0.07551993825472891, 0.0762182250036858, 0.027425881853559986, 0.07658682749024592, 0.07243468193337321, 0.029603923867398407, 0.11127270961878821, 0.09723572104121558, 0.1542721819714643, 1.157173162791878, 32.056421265006065, 61.22960664331913, 50.82802578806877, 49.73793648183346, 41.82055212557316, 40.20968936383724, 26.08452871441841, 12.916746642440557, 48.21891859173775, 69.48947802186012, 62.36560508608818, 74.60596427321434, 68.2104666531086, 72.0561034977436, 61.47486448287964, 60.58308653533459, 44.16083134710789, 20.149492286145687, 3.4142692666500807, 19.803771637380123, 53.45040567219257, 63.99735152721405, 69.78292867541313, 67.55842164158821, 66.83182463049889, 69.09907937049866, 67.78032213449478, 47.61267252266407, 37.41102173924446, 31.773596741259098, 41.49508818984032, 49.42281939089298, 48.88659976422787, 50.274551287293434, 53.61266456544399, 55.73087990283966, 54.774425625801086, 54.99786503612995, 57.85830594599247, 58.5577268153429, 56.93239063024521, 56.66941054165363, 57.788997665047646, 56.613785326480865, 62.21873536705971, 62.699405774474144, 62.41155602037907, 61.73977106809616, 62.47857302427292, 63.27366515994072, 63.71404252946377, 54.10898633301258, 44.840721264481544, 42.926611974835396, 41.07736140489578, 41.129673197865486, 40.750708132982254, 42.63487122952938, 43.144971057772636, 44.19165149331093, 46.97154812514782, 45.67674480378628, 46.698483377695084, 51.20078958570957, 53.17025050520897, 57.22285844385624, 56.18991047143936, 60.54926835000515, 58.58005441725254, 54.041684344410896, 62.054029405117035, 58.101116716861725, 57.879755795001984, 53.610738068819046, 50.32092399895191, 44.852367639541626, 42.52233646810055, 44.77866679430008, 44.957378804683685, 43.718151301145554, 41.96951933205128, 45.18320068717003, 45.38398191332817, 54.108021184802055, 59.93007257580757, 58.713548853993416, 51.70391298830509, 30.420002974569798, 17.978169098496437, 25.424260944128036, 42.51154884696007, 43.20251137018204, 38.4480506926775, 30.768172591924667, 28.866809718310833, 24.25509598106146, 27.82789606601, 31.49603683501482, 24.53985270112753, 25.952216014266014, 28.973154611885548, 26.677712984383106, 19.17140007019043, 14.737333450466394, 15.480008348822594, 11.760633029043674, 6.719475835561752, 3.4483432257547975, 1.4620772330090404, 14.411366991698742, 34.28129307925701, 43.66762161254883, 46.93833030760288, 51.78372770547867, 53.25373202562332, 44.1996044665575, 24.284443706274033, 15.044550765305758, 20.60369711369276, 42.25511580705643, 48.6404337733984, 51.05810724198818, 39.5746598392725, 60.83000868558884, 65.73844850063324, 59.551977664232254, 51.37229338288307, 60.09575508534908, 17.853811271488667, 11.313131991773844, 27.475711964070797, 34.855822250247, 45.622248128056526, 56.814745143055916, 48.93880136311054, 41.5767078101635, 21.606172621250153, 4.539427366107702, 0.0953533302526921, 0.2646381058730185, 0.03172685770550743, 0.15377580391941592, 0.10398524245829321, 0.08365167261217721, 0.03078960126003949, 0.008350909120053984, 0.05828528766869567, 0.013555013756558765, 0.09568668814608827, 0.025025453433045186, 0.022326687212625984, 0.059410784306237474, 0.023563337163068354, 0.04169054278463591, 0.03777894213271793, 0.021821583359269425, 0.03717038103786763, 0.0037934447118459502, 0.04065230044943746, 0.05112006707349792, 0.06957017743843608, 0.04930946794047486, 0.011786155791924102, 0.06081969229853712, 0.06777388320188038, 0.047148337616818026, 0.18391066580079496, 0.06916353988344781, 0.02924159252870595, 0.04789262267877348, 0.1005386641190853, 0.06705396284814924, 0.08178491887520067, 0.08211547887185588, 0.20652184233767912, 0.9714726742822677, 38.46909776329994, 75.10186806321144, 58.975605592131615, 50.18323838710785, 44.77453261613846, 34.00704279541969, 28.078984692692757, 18.23425255715847, 59.12086799740791, 70.75321421027184, 68.32913428544998, 80.82900434732437, 73.97086635231972, 78.74402582645416, 67.86941215395927, 67.68728032708168, 48.73479411005974, 22.8020653501153, 4.451979333534837, 20.97422093153, 55.32544545829296, 66.37276366353035, 74.35127153992653, 70.15750497579575, 69.07189562916756, 71.90959095954895, 70.6471998989582, 49.72788982093334, 41.40711151063442, 34.32091735303402, 43.055128678679466, 51.520356237888336, 52.96225726604462, 53.47170352935791, 56.67809307575226, 56.87651462852955, 57.712815552949905, 57.42909237742424, 60.95535255968571, 60.98197013139725, 58.165869042277336, 60.76209872961044, 58.00292618572712, 59.636272341012955, 64.04152035713196, 66.29653975367546, 64.52809184789658, 65.72788506746292, 62.94803403317928, 64.91375595331192, 64.62291955947876, 55.749217718839645, 48.25902543962002, 44.92073357105255, 44.427029862999916, 44.60518330335617, 46.12855575978756, 46.70180059969425, 48.61972488462925, 47.90814086794853, 51.33936434984207, 50.552764758467674, 50.532895624637604, 53.96042190492153, 55.29931806027889, 60.49885645508766, 59.199478179216385, 62.36456014215946, 61.857450753450394, 56.832718178629875, 63.00960212945938, 60.16803860664368, 59.815029948949814, 56.310497000813484, 54.03853811323643, 47.16030679643154, 46.022769436240196, 47.51239210367203, 50.917613580822945, 47.40516945719719, 46.16033725440502, 47.86615312099457, 50.04277132451534, 57.20762886106968, 62.91611194610596, 63.26304852962494, 57.21249260008335, 37.81006492674351, 25.55513922125101, 33.14214840531349, 48.60234081745148, 49.7161028534174, 45.28133802115917, 36.809920594096184, 33.953492268919945, 28.564990013837814, 35.516432002186775, 36.7935586720705, 30.758695900440216, 29.008595310151577, 31.293082125484943, 28.660476990044117, 21.548824198544025, 18.44113815575838, 17.484763674438, 15.86844440549612, 11.476735062897205, 3.9087759191170335, 2.5743226753547788, 15.350465700030327, 32.37801320850849, 44.43477384746075, 47.21042990684509, 55.48399955034256, 56.76660932600498, 47.34312638640404, 27.635292001068592, 19.55012384802103, 25.960989743471146, 48.57914686203003, 54.347963109612465, 56.71010635793209, 47.08499103784561, 66.01236060261726, 69.44081023335457, 64.77395385503769, 57.944112941622734, 64.45904955267906, 25.849271938204765, 21.58749472349882, 25.08249018341303, 24.13715410977602, 46.317857801914215, 63.44030521810055, 57.34594903886318, 50.39626255631447, 35.23815393447876, 6.4757687877863646, 0.2979757357388735, 0.4278395266737789, 0.07511250660172664, 0.05961583228781819, 0.04348252885392867, 0.05657392852299381, 0.043951076368102804, 0.01445710538973799, 0.012949893443874316, 0.06733686954248697, 0.04807703153346665, 0.043489397430676036, 0.04073861964570824, 0.06587503899936564, 0.01693033849733183, 0.033031130296876654, 0.13398339331615716, 0.1311504968907684, 0.10517849717871286, 0.1300294531392865, 0.14512743829982355, 0.1523766032187268, 0.08984764834167436, 0.09610281034838408, 0.1670313481008634, 0.13419245631666854, 0.1633172552101314, 0.12512278830399737, 0.2506760519463569, 0.15301027859095484, 0.1515155189554207, 0.14012220141012222, 0.21158603543881327, 0.1497051090700552, 0.2504727034829557, 0.20344926189864054, 0.4163535445695743, 1.434106221422553, 63.32868620753288, 88.80083218216896, 73.1556124985218, 61.29805237054825, 60.67649692296982, 57.38963909447193, 29.06480759382248, 19.571129120886326, 57.468773648142815, 79.44664612412453, 74.550791233778, 86.11920967698097, 82.43914514780045, 84.3832728266716, 73.86723071336746, 73.22425961494446, 54.294032603502274, 25.773087926208973, 6.255324091762304, 22.23768163472414, 56.426090598106384, 72.0244587957859, 76.26815468072891, 75.4587297141552, 74.23674568533897, 75.26559367775917, 74.77275252342224, 54.44520749151707, 48.95494669675827, 41.97086825966835, 47.93986536562443, 56.851591765880585, 58.7613844871521, 58.50710213184357, 61.74076661467552, 61.35406516492367, 58.22819709777832, 60.816770195961, 64.93204817175865, 64.47877809405327, 61.99944153428078, 65.53152680397034, 61.09201222658157, 64.2113408446312, 66.83099627494812, 68.8404044508934, 64.42580133676529, 65.62220513820648, 66.58251240849495, 66.14288359880447, 67.10497677326202, 59.458396285772324, 51.549998447299004, 47.47068554162979, 48.570791110396385, 48.87473680078983, 50.034806951880455, 51.43878221511841, 51.63942664861679, 52.781687155365944, 53.84833171963692, 53.115461245179176, 50.88391698896885, 55.02041682600975, 58.53487864136696, 62.34208054840565, 60.782385841012, 65.16214102506638, 60.86921498179436, 56.69667787849903, 68.56118023395538, 60.32450281083584, 60.95777302980423, 58.60193744301796, 57.07538075745106, 49.058460742235184, 47.41219148039818, 50.895730555057526, 53.21827232837677, 49.921649023890495, 49.46780137717724, 51.45896293222904, 52.19123683869839, 60.98504796624184, 65.25114744901657, 63.168194219470024, 58.61489474773407, 43.71234521269798, 34.28502827882767, 36.87907688319683, 46.597648188471794, 51.64489075541496, 47.03569248318672, 38.66365872323513, 35.573345348238945, 33.80735591053963, 39.486675560474396, 41.714165434241295, 34.376584365963936, 33.14917802810669, 37.467277720570564, 34.74982313811779, 27.827618680894375, 25.571392849087715, 25.222432874143124, 23.06180041283369, 16.669291332364082, 9.700743611901999, 4.014475084841251, 18.08885145932436, 36.088027730584145, 49.24543350934982, 53.050176948308945, 56.45567961037159, 60.97715578973293, 49.79246735572815, 29.95965387672186, 23.281525522470474, 31.639925613999367, 53.01246017217636, 56.46600365638733, 61.34739652276039, 48.67791496217251, 70.28598368167877, 75.52568212151527, 69.87322703003883, 62.359194830060005, 72.19229578971863, 26.30039133131504, 17.14050594717264, 31.380817517638206, 47.240049317479134, 65.73324277997017, 73.61162602901459, 68.16498309373856, 62.47524060308933, 53.40620644390583, 7.957105049863458, 0.4044056497514248, 0.3436761803459376, 0.18998521874891594, 0.2621580858249217, 0.1358496127068065, 0.09298430581111461, 0.11068503255955875, 0.1157939771655947, 0.09815048484597355, 0.07537523430073634, 0.23108998808311298, 0.09300237710704096, 0.16212324349908158, 0.15677111194236204, 0.11078045048634522, 0.10971473384415731], [0.04022709807031788, 0.03782003484957386, 0.09004316714708693, 0.09923937876010314, 0.023138986398407724, 0.058442611843929626, 0.04375877477286849, 0.11314574192510918, 0.035803593636956066, 0.024192934433813207, 0.0716023039421998, 0.05430916840850841, 0.09557131386827677, 0.07431359204929322, 0.08687576249940321, 0.03967939679569099, 0.1940154962358065, 0.04923101922031492, 0.09222813896485604, 0.11500601671286859, 0.22577647789148614, 0.07740139393717982, 6.943430593237281, 53.801689222455025, 57.27800488471985, 51.02786846458912, 37.931023836135864, 48.82929503917694, 31.108252443373203, 22.806545309722424, 38.98146227002144, 67.98371002078056, 58.005099669098854, 66.66832700371742, 67.32875436544418, 68.24927017092705, 62.24314145743847, 60.638377368450165, 43.93508166074753, 18.763047382235527, 7.492780890315771, 21.696805357933044, 47.82687082886696, 58.906859681010246, 74.04113218188286, 71.36387184262276, 68.73341739177704, 71.15554422140121, 68.5473945736885, 43.776231184601784, 31.34095385670662, 29.567900598049164, 34.77749325335026, 38.544964492321014, 39.35857683420181, 42.85479962825775, 43.964758068323135, 51.3235229998827, 49.16930839419365, 56.09925493597984, 58.91816407442093, 57.921621948480606, 52.82473884522915, 57.49357871711254, 57.53473050892353, 62.120734825730324, 61.287526935338974, 60.68342015147209, 61.154055297374725, 60.981350764632225, 64.9777141213417, 61.00089691579342, 59.88035224378109, 50.68050630390644, 43.673553094267845, 41.59580938518047, 41.47220581769943, 41.508900448679924, 39.55920606851578, 40.72626784443855, 41.978916227817535, 43.74612160027027, 43.44754882156849, 44.41377617418766, 47.163019850850105, 48.44950921833515, 53.70216116309166, 56.38303130865097, 59.597066044807434, 56.47595912218094, 64.01302188634872, 54.760883152484894, 60.06000280380249, 58.94522242248058, 56.85913436114788, 51.074814945459366, 47.779430374503136, 45.086898654699326, 44.2240409553051, 44.350657761096954, 44.45086978375912, 42.8285164386034, 41.44453950226307, 44.02765989303589, 48.16259801387787, 54.313954934477806, 59.822697937488556, 62.19800367951393, 52.36539289355278, 48.293383195996284, 38.62434223294258, 26.036202907562256, 24.80365164577961, 33.07340629398823, 25.885761380195618, 17.676843367516994, 12.256492171436548, 13.632303345948458, 16.28259938210249, 23.64206537604332, 27.376085110008717, 19.711271300911903, 21.80126365274191, 22.74153269827366, 17.35454846173525, 17.03248154371977, 8.775197826325893, 11.790531724691391, 6.877418635413051, 1.8177928891964257, 1.1150945769622922, 12.748198136687279, 31.513534896075726, 41.182444766163826, 43.08156006038189, 47.86187835037708, 48.00182484090328, 46.01343333721161, 23.139468245208263, 11.354947797954082, 22.24991697818041, 39.74205985665321, 53.49523186683655, 34.70088556408882, 42.999332472682, 65.09678453207016, 63.542356342077255, 55.417332127690315, 62.1699383854866, 48.60968202352524, 9.178903363645077, 25.213214568793774, 42.90396139025688, 38.9864856004715, 48.34556199610233, 35.22102825343609, 40.77146261930466, 43.15992325544357, 19.985312595963478, 1.6152396518737078, 0.12426002678694203, 0.10712975927162915, 0.12626842682948336, 0.09421025955816731, 0.1155077679140959, 0.14797974930843338, 0.020140216256550048, 0.06153009089757688, 0.0491418984165648, 0.015939476725179702, 0.0411864463967504, 0.06304137816186994, 0.03903823686414398, 0.03690175697556697, 0.03320174633699935, 0.10009783582063392, 0.020691637546406128, 0.031701825064374134, 0.018468587986717466, 0.055307193761109374, 0.05705462128389627, 0.09950339037459344, 0.07876362084061839, 0.014942480174795492, 0.019413961672398727, 0.06435267889173701, 0.026943673256027978, 0.02324748467799509, 0.07800257066264749, 0.0328392591472948, 0.0928396538074594, 0.02926710385509068, 0.13823935791151598, 0.05461013897729572, 0.12237843751790933, 0.02584082325483905, 0.2409115110640414, 0.03827609201835003, 9.864806458353996, 68.00413012504578, 66.79330989718437, 47.81929403543472, 46.13324850797653, 34.74590554833412, 29.7499393299222, 28.287367410957813, 43.76999571919441, 76.91405162215233, 61.058072447776794, 76.22350707650185, 72.1289835870266, 75.31140401959419, 67.62062430381775, 67.18915745615959, 49.45262499153614, 22.388700731098652, 8.584181126207113, 22.799753174185753, 49.2537322640419, 66.14767134189606, 75.0803916156292, 73.51060464978218, 71.42163634300232, 71.33460581302643, 69.66844081878662, 48.14405120909214, 34.407609701156616, 32.62946091592312, 38.26260544359684, 42.64327257871628, 44.34618540108204, 46.57407805323601, 46.95716969668865, 52.28538438677788, 54.65334512293339, 60.32368965446949, 59.813472032547, 59.57913100719452, 56.82865999639034, 59.64069150388241, 61.40193119645119, 64.54772159457207, 67.14466944336891, 60.96860244870186, 64.46162581443787, 65.1547010242939, 66.31486237049103, 64.54287305474281, 62.632571160793304, 55.422735437750816, 45.236637219786644, 44.40611578524113, 43.47090236842632, 46.53887674212456, 44.9162308126688, 47.6679215580225, 46.22725546360016, 47.73811139166355, 49.34629529714584, 49.93233785033226, 52.67659239470959, 52.14218907058239, 56.4501129090786, 60.23933418095112, 61.16713419556618, 59.51679915189743, 65.63716873526573, 60.13917915523052, 60.504278764128685, 63.19677248597145, 60.067347809672356, 56.65445454418659, 50.75831852853298, 48.82817029953003, 45.91844603419304, 47.908581644296646, 47.51359663903713, 46.48988217115402, 44.986344650387764, 46.632944494485855, 51.37038968503475, 58.45221407711506, 62.94422663748264, 66.98092862963676, 57.24633738398552, 52.553501799702644, 43.66362802684307, 31.367379538714886, 30.93883093446493, 38.769300654530525, 32.754800990223885, 21.927489079535007, 16.103642284870148, 15.859146304428577, 20.016687512397766, 26.353423185646534, 32.06095062196255, 24.85060952603817, 23.685497045516968, 24.756011702120304, 19.467958956956863, 16.558937653899193, 11.53702262789011, 13.36681729182601, 11.476669516414404, 6.7499791737645864, 2.1598102804273367, 15.179208889603615, 32.61177286505699, 42.28555977344513, 44.53716315329075, 50.05104348063469, 49.785456731915474, 50.347731560468674, 25.18852349370718, 13.39149696752429, 26.429094225168228, 44.33055683970451, 58.4906680136919, 39.54999916255474, 46.70117363333702, 68.79119709134102, 69.45282518863678, 60.31711220741272, 66.67160242795944, 55.78669510781765, 19.494492933154106, 28.23582697659731, 29.095428250730038, 31.652708128094673, 55.009564608335495, 42.74537689983845, 46.31490156054497, 63.48274514079094, 29.949643313884735, 2.294199806638062, 0.07168835596530698, 0.19178090442437679, 0.05926386875216849, 0.1200531329959631, 0.10112991090863943, 0.08303056922159158, 0.030184700808604248, 0.06222391362825874, 0.039080906644812785, 0.0335716475819936, 0.022813812538515776, 0.033517897536512464, 0.03591123844671529, 0.09433560087927617, 0.027023255606763996, 0.08516690810211003, 0.12343852125923149, 0.14920564368367195, 0.16746550449170172, 0.15110502223251387, 0.16499640885740519, 0.1439525294699706, 0.13517136394511908, 0.2240725513547659, 0.12793586938641965, 0.12381763255689293, 0.09549319540383294, 0.1585673468071036, 0.28814907709602267, 0.22182041517226025, 0.1834916789084673, 0.1854276898666285, 0.33768838446121663, 0.15689371473854408, 0.35705460933968425, 0.1513782364781946, 0.42178888572379947, 0.11400610630516894, 15.115834940224886, 89.38563600182533, 78.801509141922, 67.57459357380867, 49.90420415997505, 73.62449213862419, 37.3730693757534, 27.754303514957428, 45.97015365958214, 78.31742271780968, 69.38928499817848, 76.45511984825134, 78.93924415111542, 81.99292749166489, 72.10305377840996, 73.9319184422493, 55.65740704536438, 25.28857782483101, 10.369507726281881, 25.164801366627216, 51.89927950501442, 71.55261531472206, 80.87563544511795, 77.84592121839523, 74.23089399933815, 75.31717970967293, 74.39202055335045, 53.765739351511, 39.044151306152344, 40.55699832737446, 44.77878838777542, 46.114017739892006, 48.13301660120487, 49.63770925998688, 47.77823343873024, 54.37939502298832, 55.76380133628845, 62.649009078741074, 64.80535537004471, 65.0265870988369, 58.844911605119705, 64.00707140564919, 64.96993973851204, 68.56741189956665, 68.08483019471169, 64.94831889867783, 62.566610500216484, 64.86664608120918, 67.24408730864525, 64.10050079226494, 64.7366550564766, 57.08562880754471, 48.17412279546261, 48.188345432281494, 46.60886898636818, 50.131105184555054, 48.49495477974415, 51.34760610759258, 48.5584569722414, 51.680677235126495, 51.083569675683975, 52.399184480309486, 53.91021899878979, 52.67886847257614, 56.983577683568, 62.90358021855354, 62.01796554028988, 61.79196886718273, 65.81322088837624, 57.6976353675127, 63.512641936540604, 63.825790733098984, 61.39827959239483, 56.746478006243706, 53.76480460166931, 51.68837182223797, 50.657407343387604, 52.44287073612213, 51.25486448407173, 50.2937326580286, 49.21508453786373, 50.75513809919357, 52.56252631545067, 58.524489998817444, 63.194367215037346, 66.86903223395348, 60.401840060949326, 59.587840139865875, 51.387773752212524, 37.92818918824196, 31.430560648441315, 38.64649124443531, 34.88602302968502, 22.43811707943678, 18.3615343272686, 18.26434314250946, 25.580776445567608, 31.429318115115166, 36.85905955731869, 28.239906057715416, 30.263097994029522, 31.477020755410194, 25.031037144362926, 23.365951292216778, 17.526029460132122, 19.372236393392086, 16.876408718526363, 11.432717274874449, 6.157111711800098, 18.3367520570755, 37.19372659921646, 45.59330888092518, 50.77260576188564, 54.17971953749657, 52.71667644381523, 54.15525645017624, 27.714380957186222, 17.550274059176445, 30.922429114580154, 47.81928263604641, 62.33774118125439, 44.15387772023678, 50.49082048237324, 75.98383873701096, 73.11160326004028, 65.4781624674797, 73.41738805174828, 62.55226626992226, 15.281696990132332, 31.26175470650196, 51.641900315880775, 57.209399566054344, 64.33093562722206, 55.25054767727852, 61.192608028650284, 77.74647295475006, 42.23878428339958, 3.044615602120757, 0.20587378414347768, 0.39985987648833543, 0.1415639420156367, 0.2635723224375397, 0.16316940454998985, 0.16745921107940376, 0.2085022782557644, 0.26999014837201685, 0.16304240823956206, 0.07761170374578796, 0.12229307569214143, 0.09500184911303222, 0.15014365897513926, 0.18931522266939282, 0.07545192784164101, 0.2786227210890502], [0.049995598310488276, 0.05852973255969118, 0.036685205704998225, 0.009868438773992239, 0.06245924494578503, 0.09443792820093222, 0.07429543169564568, 0.021375816068029962, 0.13434375054202974, 0.03075173317483859, 0.08558842571801506, 0.06376904653734528, 0.060451716926763766, 0.022596036724280566, 0.03622122239903547, 0.05273449802189134, 0.05472798460687045, 0.11675750007270835, 0.056019941257545725, 0.014698517679789802, 0.08569349156459793, 0.13986552221467718, 1.5038419794291258, 46.55741214752197, 69.78780761361122, 38.533078730106354, 48.856189996004105, 52.32568122446537, 49.555162489414215, 14.463081266731024, 29.097742326557636, 63.059307262301445, 65.60804709792137, 56.68774455785751, 72.77561008930206, 69.52223226428032, 65.67935407161713, 59.858112037181854, 46.690750792622566, 16.01576630026102, 14.66269500553608, 13.571600653231144, 39.326799139380455, 62.14426316320896, 68.40224236249924, 71.8388919532299, 68.66415470838547, 69.53265130519867, 62.948129028081894, 35.91548278927803, 26.942195892333984, 33.667629808187485, 36.36073909699917, 34.45545293390751, 31.951159313321114, 32.452097833156586, 35.577658116817474, 36.69338084757328, 46.243510991334915, 54.58171136677265, 58.8958440721035, 52.23284460604191, 53.23664054274559, 54.420938193798065, 55.9088509529829, 58.545449674129486, 60.066625848412514, 59.518638253211975, 54.02689553797245, 64.24782648682594, 67.66952767968178, 61.44693598151207, 58.9220816642046, 48.4839391708374, 44.68490682542324, 44.99513737857342, 42.96304062008858, 41.343810707330704, 42.779187485575676, 42.90282905101776, 43.227172046899796, 43.542498126626015, 44.02110904455185, 44.89083297550678, 46.84164449572563, 51.62324711680412, 54.49858322739601, 57.887758165597916, 59.06081221997738, 54.47579964995384, 60.54152436554432, 62.28242374956608, 55.35927124321461, 60.74532262980938, 56.228467002511024, 52.649245262145996, 47.578968331217766, 44.771048203110695, 42.91712388396263, 42.88225695490837, 43.41112397611141, 41.408992409706116, 40.95368184149265, 42.46669605374336, 49.8323842138052, 54.566363990306854, 57.16512814164162, 58.45116913318634, 55.074890702962875, 61.42067179083824, 60.10938875377178, 41.68245993554592, 21.679862067103386, 15.952957570552826, 15.950512401759624, 10.1033291593194, 6.354765230789781, 4.9136255867779255, 7.144806487485766, 16.83868244290352, 29.69196204096079, 19.847222305834293, 15.3736169077456, 16.6889875754714, 13.966986536979675, 9.96232632547617, 6.963163409382105, 5.799066899344325, 4.975633034482598, 4.000286171212792, 0.7466329203452915, 8.660050705075264, 31.488606333732605, 32.712190076708794, 39.91403482854366, 39.15040880441666, 45.056173503398895, 41.47901125252247, 20.743098333477974, 7.628455935046077, 22.72693768143654, 45.61492972075939, 51.323940977454185, 41.41974963247776, 61.08342848718166, 64.04596611857414, 58.922267854213715, 50.119546204805374, 74.99057963490486, 22.419361285865307, 14.060023594647646, 40.38739822804928, 38.39348562061787, 38.687700033187866, 49.690572023391724, 27.326298281550407, 32.6700883358717, 22.861144579946995, 6.835241848602891, 0.20397612737724558, 0.18725038971751928, 0.11964369012275711, 0.09796523736440577, 0.05931094317929819, 0.03413548314711079, 0.06724177073920146, 0.05574031485593878, 0.06821081522502936, 0.08577560278354213, 0.04030858959595207, 0.07886929524829611, 0.068804429465672, 0.060278970922809094, 0.02376235705014551, 0.13152529631042853, 0.0693361708545126, 0.05586966377450153, 0.04416196134116035, 0.0248089782326133, 0.05247538458206691, 0.03231313210562803, 0.0355364983988693, 0.07622494886163622, 0.027164701532456093, 0.06038707957486622, 0.056420537730446085, 0.02815635183651466, 0.03237770637497306, 0.01565558854053961, 0.06229539358173497, 0.044672384537989274, 0.03302892240753863, 0.10306524651241489, 0.026092166408488993, 0.049129831095342524, 0.04406657310028095, 0.09157193941064179, 0.15840443054912612, 1.620806590653956, 57.16833896934986, 83.00706267356873, 42.34712406992912, 40.626530796289444, 48.46693508327007, 34.00440953671932, 24.544074274599552, 39.44335788488388, 69.14393216371536, 66.28215372562408, 62.33758918941021, 80.99059447646141, 76.27267643809319, 71.75525084137917, 67.32523575425148, 50.213625356554985, 19.412291944026947, 16.269366592168808, 14.602044560015202, 41.573721170425415, 65.09888961911201, 73.41403663158417, 75.88250577449799, 69.92712333798409, 70.07553577423096, 65.20544350147247, 38.27268250286579, 27.044216617941856, 35.244624987244606, 40.05699835717678, 38.191974833607674, 35.353838726878166, 35.36343701183796, 37.37504906952381, 40.190507993102074, 49.163525104522705, 58.0394422262907, 62.15951554477215, 54.422583505511284, 55.529057532548904, 57.335248813033104, 56.5726525336504, 60.911814495921135, 63.16410943865776, 65.48012316226959, 61.031686663627625, 66.70069366693497, 67.26876318454742, 63.24015475809574, 62.15685948729515, 50.08164703845978, 48.233194425702095, 47.466159984469414, 44.63542588055134, 46.629007905721664, 46.46313160657883, 46.75024040043354, 49.38015528023243, 47.248317673802376, 48.03584821522236, 49.271598905324936, 50.6315079331398, 53.05780693888664, 58.649757876992226, 60.98726324737072, 61.63225203752518, 58.92844632267952, 63.52308377623558, 69.13406029343605, 58.04931789636612, 64.38940688967705, 59.50892977416515, 58.31075146794319, 51.96692727506161, 48.02686549723148, 45.52716962993145, 47.045796141028404, 46.89199559390545, 44.24766808748245, 44.086910113692284, 45.63348792493343, 52.459278255701065, 57.941327691078186, 61.63425073027611, 62.36840933561325, 59.05659444630146, 59.997708946466446, 58.259397223591805, 44.3474393337965, 24.618679471313953, 20.05644667893648, 19.990174435079098, 13.80314502865076, 8.832752387970686, 8.34497731178999, 9.823725912719965, 18.642008677124977, 30.16549453139305, 24.547471292316914, 17.909514382481575, 17.750656306743622, 16.739693954586983, 11.863063182681799, 7.8140132781118155, 5.91398935765028, 7.59559434838593, 6.67926924303174, 3.6733825877308846, 12.118053250014782, 31.865831092000008, 35.79234279692173, 42.116856426000595, 42.226868122816086, 47.520698457956314, 44.52685050666332, 22.66266033053398, 8.650139886885881, 24.179529435932636, 51.24366268515587, 56.09794020652771, 48.724261075258255, 62.559820264577866, 68.57650861144066, 63.06487016379833, 56.6951085627079, 76.07513263821602, 32.89872206747532, 21.48334041237831, 35.37331648170948, 25.032053589820862, 38.863679990172386, 60.379235073924065, 30.9851960465312, 45.24821899831295, 39.100612476468086, 10.224559754133224, 0.23156536335591227, 0.11113880391349085, 0.13557326659793034, 0.09321151432232, 0.03864205616991967, 0.04333332006353885, 0.04009776770544704, 0.03182685097272042, 0.010469960598129546, 0.04856780265981797, 0.06343790024402551, 0.011237026810704265, 0.010574228635960026, 0.03920218841813039, 0.016663126370985992, 0.004216066272419994, 0.07682604395085946, 0.1020707908901386, 0.1109112762787845, 0.1457719341851771, 0.13704444078030065, 0.09246171510312706, 0.2821362263057381, 0.20086529664695263, 0.12009812198812142, 0.25666803354397416, 0.13729353522649035, 0.22002688172506168, 0.2090662214322947, 0.1609528172411956, 0.11648919142317027, 0.10308900265954435, 0.09287849039537832, 0.23669808637350798, 0.251051964587532, 0.09495403253822587, 0.165885531459935, 0.16151091229403391, 0.3367409290513024, 2.3843604186549783, 78.77237990498543, 92.22215339541435, 58.554443791508675, 59.20941844582558, 80.50757959485054, 67.0570233464241, 18.459935747087002, 39.929078221321106, 73.64575579762459, 75.2036190032959, 69.48737293481827, 85.50929680466652, 82.88392648100853, 75.18725708127022, 73.36613640189171, 56.13378748297691, 22.849095426499844, 17.884792909026146, 17.57513802498579, 43.81044074892998, 70.3847099840641, 77.13498696684837, 79.1405801475048, 75.73329538106918, 73.7959997355938, 69.59282487630844, 45.24389483034611, 35.632086396217346, 41.33877217769623, 45.9724373370409, 44.49569597840309, 39.61720235645771, 37.76747681200504, 38.50467525422573, 41.8428835272789, 52.66412526369095, 60.24808511137962, 65.98566323518753, 56.01409770548344, 59.63884100317955, 62.48529486358166, 60.78294061124325, 63.59412096440792, 66.88034042716026, 64.52885940670967, 58.26487272977829, 67.09954306483269, 69.16844844818115, 67.3864808678627, 63.6927180737257, 53.2905862480402, 51.27883739769459, 51.529787331819534, 49.009051993489265, 49.74570706486702, 50.41683845221996, 51.02159880101681, 54.63184207677841, 51.74801342189312, 51.60485230386257, 51.53606839478016, 52.230218946933746, 55.324487909674644, 61.828826889395714, 62.36001558601856, 63.19792382419109, 58.105619475245476, 65.1113985478878, 65.6742775440216, 59.57983396947384, 66.9877378642559, 59.86697696149349, 61.801190972328186, 54.65076506137848, 51.312097012996674, 49.320768266916275, 50.81121928989887, 50.768319591879845, 47.59968101978302, 47.091389894485474, 49.1792106628418, 56.39593921601772, 57.8353475779295, 61.53323695063591, 61.64480276405811, 63.42402309179306, 64.63729798793793, 65.68793401122093, 52.34941475093365, 28.850039318203926, 20.52841365337372, 22.46121224015951, 16.451644711196423, 11.784066371619701, 10.665952619165182, 12.612408623099327, 24.342808574438095, 37.09716998040676, 31.044189780950546, 22.73750301450491, 24.88505657762289, 23.146792352199554, 16.631528958678246, 14.823105297982693, 12.780277915298939, 11.663940567523241, 12.172847259789705, 6.9179577101022005, 15.635337363928556, 36.40439495444298, 39.563560634851456, 47.44679622352123, 44.656621143221855, 51.640528589487076, 47.278423458337784, 25.50293382257223, 10.405260007828474, 27.632121071219444, 53.251763731241226, 61.666104421019554, 49.64970521628857, 68.049256503582, 74.61449861526489, 68.66961881518364, 60.6143132597208, 86.21320903301239, 30.925337858498096, 19.097098857164383, 47.26537115871906, 50.51877178251743, 54.9884757399559, 66.83073788881302, 43.33715334534645, 59.678282886743546, 65.7502430677414, 13.294230736792088, 0.39051024068612605, 0.1716298286919482, 0.3517422272125259, 0.16554105619434267, 0.1141761768667493, 0.13340978737687692, 0.18950460391351953, 0.24965455988422036, 0.16021663643186912, 0.16406731418101117, 0.13669754611328244, 0.1476010907208547, 0.20425775757757947, 0.1414917755755596, 0.08862647402565926, 0.23276881518540904, 0.1904367413953878], [0.04070110408065375, 0.09193194782710634, 0.05538449215237051, 0.10275611974066123, 0.09870280598988757, 0.07495723446481861, 0.060915240101167, 0.023348446447926108, 0.018673209233384114, 0.043583679871517234, 0.059478067414602265, 0.04248647761414759, 0.010052920915768482, 0.0467644654418109, 0.019751184299821034, 0.052794968214584514, 0.07830297719920054, 0.09672837404650636, 0.04268396311090328, 0.12844713492086157, 0.22662697912892327, 0.36019116290844977, 0.46975009026937187, 20.83049174398184, 82.6662589609623, 51.61749802529812, 100.66424399614334, 89.38195779919624, 56.17118887603283, 25.777651481330395, 13.37290171533823, 50.37672020494938, 70.47996327280998, 86.26838967204094, 59.22038085758686, 65.28527721762657, 67.47433215379715, 59.46687363088131, 45.808757320046425, 28.695771396160126, 14.875936713069677, 13.055168464779854, 31.582558192312717, 56.50870956480503, 73.50155353546143, 72.30957269668579, 72.87207171320915, 69.18639868497849, 60.70877619087696, 31.65978714823723, 24.6960661187768, 29.7516131401062, 32.02760361135006, 28.850493393838406, 27.61085171252489, 21.812564246356487, 25.398952402174473, 31.710204742848873, 43.243712559342384, 54.0520653873682, 51.73617705702782, 50.52355572581291, 49.309741258621216, 51.60643681883812, 53.07268314063549, 53.04281674325466, 49.236568585038185, 33.20533521473408, 42.90152192115784, 66.26997157931328, 61.080745831131935, 61.683435291051865, 54.3078600615263, 49.3505434691906, 44.34873506426811, 42.49470815062523, 41.970666870474815, 43.408338725566864, 41.63285739719868, 42.510070726275444, 43.08004014194012, 41.01140834391117, 43.508600145578384, 46.75161972641945, 50.36942459642887, 54.5470230281353, 57.703631445765495, 57.991937175393105, 57.38341122865677, 57.82380759716034, 58.18533919751644, 65.34814104437828, 59.358849227428436, 57.43558622896671, 56.48576259613037, 50.79739183187485, 48.03266778588295, 45.29558725655079, 42.790841460227966, 44.56279657781124, 41.89161591231823, 41.45887233316898, 40.93684494495392, 45.433892235159874, 46.68988063931465, 50.48527657985687, 51.77718825638294, 54.32429797947407, 54.061868861317635, 61.36870577931404, 55.866456627845764, 50.82049839198589, 26.52432471513748, 9.475451800972223, 7.513351086527109, 10.003321375697851, 5.8103869669139385, 4.912073370069265, 4.50586661696434, 13.891531135886908, 24.59822326898575, 24.23275128006935, 10.022012572735548, 10.181547962129116, 7.873797370120883, 7.204073807224631, 5.429910058155656, 3.523206333629787, 3.3237932715564966, 3.8872609985992312, 2.2210926795378327, 3.933010306209326, 24.725005365908146, 31.28856986761093, 35.381303653120995, 36.990198120474815, 39.218793734908104, 36.546929106116295, 14.92205673828721, 5.347220320254564, 13.127486184239388, 52.9921730607748, 43.2376404851675, 44.92497034370899, 60.04468582570553, 60.66812217235565, 49.05746519565582, 66.22365206480026, 55.78825302422047, 12.759858760982752, 29.783586524426937, 42.2026976197958, 33.54530677199364, 42.37758703529835, 36.17259219288826, 27.896579280495644, 30.91487132012844, 7.466897629201412, 0.8973102131858468, 0.08350874981260858, 0.18562930170446634, 0.04200094233965501, 0.09286813001381233, 0.08009216908249073, 0.0789963806164451, 0.05461472173919901, 0.04085165244759992, 0.10429767920868471, 0.03374149549927097, 0.03623085547587834, 0.029682109125133138, 0.08858726636390202, 0.13885275780921802, 0.0027790494368673535, 0.02090087680699071, 0.03478990896837786, 0.06262164912186563, 0.05378432528232224, 0.0726184896484483, 0.07461261819116771, 0.025512035135761835, 0.05708477103326004, 0.05357393754820805, 0.024629057515994646, 0.05846336229296867, 0.048168096764129587, 0.07424962634104304, 0.03357259753101971, 0.023391305476252455, 0.03849218686809763, 0.04914861485303845, 0.045835868004360236, 0.028686011501122266, 0.05204552893701475, 0.03096188898780383, 0.0629002513596788, 0.12114817189285532, 0.5153490090742707, 0.20820274745346978, 22.539499439299107, 97.10225433111191, 59.44383546710014, 94.13961410522461, 107.57814019918442, 46.633381471037865, 23.837524987757206, 24.067101068794727, 61.89726881682873, 78.079654276371, 87.06248626112938, 70.19057840108871, 70.58907061815262, 73.37066575884819, 65.10091871023178, 52.298554480075836, 31.77224401384592, 16.82149786502123, 13.888117019087076, 35.36949388682842, 57.91325859725475, 75.80693542957306, 73.80696594715118, 73.80816668272018, 71.02821305394173, 60.658957064151764, 33.154782727360725, 25.427175387740135, 32.81662367284298, 38.27906996011734, 35.35586781799793, 32.43735082447529, 24.178102612495422, 26.606502905488014, 33.43171186745167, 45.470415875315666, 57.5804078578949, 53.91857475042343, 51.24417185783386, 52.73132845759392, 53.02908048033714, 58.44515785574913, 59.109438210725784, 55.64536169171333, 40.3437689691782, 49.0757992118597, 69.17342618107796, 64.95825156569481, 63.17504525184631, 56.2985048443079, 52.98263177275658, 48.84234733879566, 46.58261239528656, 46.137530878186226, 46.805022060871124, 44.20635290443897, 45.86232304573059, 47.11106523871422, 46.090006828308105, 47.526170164346695, 48.989114463329315, 53.51446643471718, 55.67808173596859, 60.891268998384476, 60.72252005338669, 60.90237580239773, 62.86113649606705, 60.67769765853882, 67.81733974814415, 63.3739759773016, 59.69741106033325, 61.12794689834118, 52.96280823647976, 51.406981721520424, 49.11251284182072, 45.062629356980324, 46.8985540419817, 46.57589815557003, 45.19416309893131, 44.81679014861584, 47.83756725490093, 50.2406495064497, 54.04815919697285, 56.13202057778835, 56.41942195594311, 60.15946626663208, 62.886861115694046, 60.87779872119427, 53.75229947268963, 30.78752875328064, 10.924288406968117, 10.90125784277916, 14.210022445768118, 8.115103896707296, 7.3911249451339245, 7.034331215545535, 14.790425151586533, 24.32650364935398, 26.386749297380447, 12.59833987802267, 10.03431536257267, 7.468602787703276, 7.453662464395165, 7.7158531453460455, 3.282145131379366, 3.4072840539738536, 5.029211109504104, 2.555037997663021, 6.411985410377383, 27.140566147863865, 35.13536565005779, 38.21696609258652, 38.458431735634804, 42.45199464261532, 39.752539694309235, 15.163257345557213, 6.080057546496391, 14.644366689026356, 60.53645543754101, 48.904880583286285, 49.90746058523655, 64.87942859530449, 63.69552232325077, 54.7337906062603, 70.06429597735405, 62.79346592724323, 21.758656539022923, 33.35546135902405, 31.35513849556446, 25.023317858576775, 46.78409658372402, 43.51797804236412, 31.682403534650803, 46.00456461310387, 10.261020697653294, 2.8923083748668432, 0.03357693909492809, 0.19112529116682708, 0.03738961888302583, 0.08333879057317972, 0.04610102252627257, 0.054106955431052484, 0.043698070803657174, 0.10226711863651872, 0.08815141787636094, 0.07624486068380065, 0.055624532396905124, 0.03427367475524079, 0.08846537602948956, 0.15548307012068108, 0.033611114995437674, 0.008433003640675452, 0.050296123590669595, 0.22409110504668206, 0.12975640216609463, 0.18621401017298922, 0.19373668619664386, 0.1471585629042238, 0.2882611710811034, 0.20542603160720319, 0.11919830503757112, 0.23775420704623684, 0.11896269541466609, 0.14549248589901254, 0.17949025612324476, 0.18851588509278372, 0.1937411242397502, 0.1879949716385454, 0.15885895147221163, 0.14299020142061636, 0.16902631527045742, 0.17399300500983372, 0.24771270080236718, 0.2155308026704006, 0.6133643339853734, 0.3061925870133564, 32.78341345489025, 110.60154676437378, 68.28324034810066, 112.01016917824745, 109.46849316358566, 81.22004896402359, 34.950615763664246, 20.584979318082333, 60.588402450084686, 80.77532842755318, 94.3632473051548, 71.7317833006382, 79.02169212698936, 81.03369936347008, 69.29698035120964, 56.98335349559784, 38.29966105520725, 18.931446745991707, 15.85552604869008, 38.304558992385864, 61.02728269994259, 80.84848210215569, 76.64080828428268, 78.52516517043114, 75.47370851039886, 64.74778845906258, 39.73722271621227, 29.71870120614767, 37.79477834701538, 44.95605267584324, 42.38725371658802, 37.90645435452461, 29.812261685729027, 30.95442719757557, 35.04694439470768, 47.53270961344242, 61.442387625575066, 57.488771975040436, 54.71942737698555, 54.70365822315216, 57.17443384230137, 61.747450456023216, 60.74550502002239, 55.8616004884243, 38.70957925915718, 52.28163778781891, 70.25791078805923, 65.22554442286491, 66.76453784108162, 58.841199204325676, 56.22720927000046, 50.36059767007828, 49.44332309067249, 47.33122542500496, 49.58884768188, 47.22755938768387, 48.0233658850193, 52.909759283065796, 48.26993465423584, 52.18822360038757, 53.141581043601036, 56.55972942709923, 58.88865865767002, 61.67852595448494, 62.185152769088745, 63.281249552965164, 62.832535430788994, 61.23211070895195, 64.9061867594719, 61.03718876838684, 59.78069119155407, 63.2063327729702, 54.90343250334263, 55.68204112350941, 51.17419481277466, 48.86507011950016, 51.76644243299961, 51.45135574042797, 49.077721908688545, 47.1468061208725, 50.36249376833439, 52.36222766339779, 53.374474346637726, 57.10719645023346, 57.627578526735306, 60.792884677648544, 68.37471663951874, 65.45533329248428, 62.161605432629585, 36.23834766447544, 13.724762834608555, 13.96365126594901, 17.087428495287895, 10.901085902005434, 10.46445608139038, 10.10016392916441, 20.14790967106819, 32.369714453816414, 34.54543590545654, 18.70772995054722, 18.79044011235237, 14.798315428197384, 15.868040677160025, 12.575577199459076, 9.433752838522196, 8.843215126544237, 9.770819451659918, 7.805061908438802, 11.256914958357811, 32.3261421918869, 40.77204018831253, 42.566034123301506, 42.71508872509003, 46.33757874369621, 44.564301297068596, 16.924223452806473, 7.616567322984338, 16.265040524303913, 61.62943638861179, 53.65849010646343, 50.924362018704414, 68.72435107827187, 69.90427136421204, 59.061469584703445, 74.01237532496452, 69.86827969551086, 17.08573568612337, 37.342834398150444, 49.22022946178913, 46.470795795321465, 56.24073654413223, 52.954916059970856, 46.806652173399925, 69.54521343111992, 20.029255338013172, 4.01901631616056, 0.11765304967411794, 0.3906432929215953, 0.15231565805152059, 0.14150278904708102, 0.14939429762307554, 0.23741807352053002, 0.17835597245721146, 0.17751492618117481, 0.27243326883763075, 0.14481876423815265, 0.1281283824937418, 0.14587953075533733, 0.13736047694692388, 0.26395357854198664, 0.07859327568439767, 0.07948635393404402, 0.15162747935391963], [0.021620709958369844, 0.023335625846812036, 0.0725863769184798, 0.09049571395735256, 0.04303447203710675, 0.03747965252841823, 0.01800625595933525, 0.05571847716055345, 0.024240279744844884, 0.02312118413101416, 0.05610471678664908, 0.023561600537505, 0.0611526939610485, 0.022189861156221014, 0.06353573757223785, 0.03893473323842045, 0.09240603918442503, 0.09744731476530433, 0.022290444430836942, 0.03407608535781037, 0.02677634864085121, 0.18591752217616886, 0.09743414164404385, 4.048479935154319, 58.35031874477863, 56.33138068020344, 34.61414381861687, 36.18406757712364, 40.88371619582176, 55.64102992415428, 14.112912006676197, 28.33978369832039, 60.219651237130165, 70.4942961037159, 45.17985686659813, 68.69138404726982, 69.2051088809967, 69.18740183115005, 63.232973143458366, 35.01829773187637, 13.774645607918501, 9.691208023577929, 24.613336957991123, 48.121450021862984, 67.621179074049, 67.22771018743515, 68.58331024646759, 64.91244122385979, 47.22076155245304, 29.378820843994617, 20.211010985076427, 28.202206380665302, 27.298888452351093, 22.839652933180332, 26.130502447485924, 21.586915254592896, 19.625023528933525, 24.179124757647514, 40.75620263814926, 47.67324507236481, 40.53627423942089, 41.1020714789629, 45.51489248871803, 41.65192477405071, 45.565574169158936, 35.22367671132088, 25.470548160374165, 24.782555177807808, 51.11090540885925, 65.09942919015884, 59.38639774918556, 58.72546501457691, 53.95656891167164, 49.36304099857807, 46.47771142423153, 45.710209608078, 43.14899504184723, 43.92289951443672, 42.0696971565485, 41.977544501423836, 42.982453778386116, 44.043083265423775, 44.79012317955494, 50.967839285731316, 53.3541264384985, 59.28872399032116, 56.753868609666824, 58.029840141534805, 49.568127393722534, 58.60224902629852, 60.56555427610874, 60.947882160544395, 60.774516463279724, 55.904583781957626, 55.08051060140133, 50.162852481007576, 47.610122859478, 43.876948580145836, 43.54414723813534, 44.68005068600178, 41.603040397167206, 41.594688445329666, 42.31239773333073, 46.19022265076637, 47.65928842127323, 47.391566187143326, 48.6264543235302, 52.925254851579666, 58.39459776878357, 59.378725960850716, 58.90340566635132, 54.37899224460125, 28.2210685685277, 13.389428928494453, 9.425676371902227, 10.6447659060359, 7.070140019059181, 3.729128446429968, 3.6320555303245783, 8.954529203474522, 15.604273080825806, 20.915939658880234, 10.06140885874629, 4.567688349634409, 4.234808161854744, 2.3043637862429023, 3.0375539185479283, 1.2961328937672079, 3.2287667831405997, 3.9882921148091555, 3.427959932014346, 5.14397207647562, 13.355450201779604, 26.77781291306019, 28.44596330076456, 27.89135456085205, 31.22851599007845, 32.91956774890423, 11.08691493049264, 1.7337788036093116, 8.102344181388617, 52.15680688619614, 41.407286301255226, 44.66370016336441, 64.7224286198616, 50.03543771803379, 48.91094125807285, 74.07954052090645, 27.306660935282707, 14.396185856312513, 40.13258010149002, 36.71753615140915, 33.436013236641884, 39.44598734378815, 31.368870958685875, 29.5963154733181, 13.461807444691658, 3.7033050321042538, 0.6875399162527174, 0.07195372571004555, 0.13054281153017655, 0.023928510927362368, 0.10737739910837263, 0.04399624347570352, 0.03163663852319587, 0.052349583129398525, 0.030751738740946166, 0.03032424683624413, 0.02296139602549374, 0.02676790300029097, 0.037543547732639126, 0.04349165355961304, 0.03332654217956588, 0.10408444533823058, 0.0036801048463530606, 0.034370673456578515, 0.02058808382571442, 0.022124060487840325, 0.07134359126212075, 0.017617741650610697, 0.019286610986455344, 0.02711553795961663, 0.025925400259438902, 0.022081841561885085, 0.03815183794358745, 0.0446157438273076, 0.024089030048344284, 0.0333442201372236, 0.05994622901198454, 0.013278316055220785, 0.0697648873028811, 0.05942581279668957, 0.1075580452743452, 0.048573613676126115, 0.011466541545814835, 0.11939148607780226, 0.02122097066603601, 0.18190418049925938, 0.12671402713749558, 3.9972895570099354, 73.33351895213127, 64.02004390954971, 41.525418162345886, 46.1893031001091, 44.344502091407776, 39.922679364681244, 20.220991149544716, 41.398573368787766, 68.72767969965935, 74.8474033176899, 53.45753028988838, 76.50534555315971, 78.66701915860176, 70.95271870493889, 68.58217790722847, 39.884134232997894, 15.126182734966278, 10.458691790699959, 27.41308942437172, 50.48220254480839, 69.74785655736923, 72.0203398168087, 71.12757012248039, 65.54509967565536, 49.650947749614716, 32.21916653215885, 24.25372425466776, 29.575646482408047, 31.431189514696598, 27.77133610099554, 29.409348405897617, 24.59482055157423, 21.507455818355083, 26.87867470085621, 45.045488476753235, 50.559668987989426, 42.008372247219086, 42.63288773596287, 48.21700729429722, 48.6310862749815, 50.814840495586395, 42.85165339708328, 31.501092463731766, 28.75692341476679, 55.01143030822277, 68.13270002603531, 63.88739302754402, 61.33120559155941, 56.57713629305363, 50.71504645049572, 49.56226050853729, 49.313495457172394, 45.84523916244507, 48.26384738087654, 46.62871532142162, 46.83050349354744, 48.15602816641331, 46.94259747862816, 47.61392645537853, 53.820399418473244, 57.537743747234344, 61.235279738903046, 61.232441291213036, 63.21536108851433, 55.05434140563011, 60.221323147416115, 63.857382237911224, 61.44067771732807, 65.93851536512375, 58.798253908753395, 59.1281446069479, 54.6898003667593, 50.6564611941576, 49.533879831433296, 46.559764221310616, 47.11175300180912, 46.02266304194927, 46.76611214876175, 44.63442273437977, 49.517928287386894, 49.78683985769749, 51.72592140734196, 54.80028323829174, 55.71701064705849, 60.486742705106735, 62.37773023545742, 60.559178218245506, 59.686558842659, 33.981215581297874, 16.57071892172098, 11.677313949912786, 13.597349971532822, 8.294815253466368, 5.4971507750451565, 3.8280770368874073, 7.89326467551291, 14.9311164021492, 20.23713268339634, 12.623142097145319, 5.3792668506503105, 4.751892015337944, 1.825408274307847, 5.606630500406027, 3.239799253642559, 3.182310238480568, 3.850535494275391, 3.604412251152098, 4.30988073348999, 15.321118924766779, 28.960803374648094, 30.583819784224033, 29.262991659343243, 33.07883620262146, 35.35910524427891, 13.556334972381592, 2.0645534293726087, 8.90829898416996, 57.92185753583908, 46.66843079030514, 48.71111758053303, 69.93280783295631, 56.5716227889061, 54.626408368349075, 77.25387498736382, 39.67529743909836, 20.67123468965292, 36.527018174529076, 29.265985898673534, 27.295924611389637, 49.49568048119545, 37.671478763222694, 41.62912979722023, 31.721712425351143, 6.961077796295285, 0.7058367657009512, 0.025425368985452224, 0.21668813744327053, 0.014365046608872944, 0.1155856711557135, 0.04442230303538963, 0.05177740953513421, 0.05288070111419074, 0.040223673058790155, 0.09780511900316924, 0.017890428971440997, 0.04944608248479199, 0.05010673121432774, 0.029190206223574933, 0.013448539684759453, 0.13646198844071478, 0.043063749762950465, 0.10318000480765477, 0.12353376849205233, 0.08878829190507531, 0.13730966951698065, 0.12427532987203449, 0.11017684693797491, 0.09981283626984805, 0.1879528324934654, 0.15402607095893472, 0.13079892669338733, 0.11187767129740678, 0.07127961813239381, 0.1098107454890851, 0.16495762421982363, 0.11415193090215325, 0.15091541834408417, 0.18898372014518827, 0.17247825191589072, 0.12675346486503258, 0.29343696834985167, 0.16433405689895153, 0.17206538032041863, 0.3249941859394312, 0.14379445201484486, 6.938535505905747, 96.97300806641579, 72.37702667713165, 54.58086401224136, 49.877400398254395, 60.70642791688442, 76.52720957994461, 19.838809557259083, 38.87759484350681, 72.39144310355186, 79.15662288665771, 57.98835016787052, 83.60213354229927, 84.09714818000793, 77.58479163050652, 75.82672476768494, 43.950641825795174, 17.68208708614111, 11.6565309651196, 30.01660142093897, 54.285030886530876, 74.53594163060188, 75.84747925400734, 73.74819070100784, 70.09676143527031, 52.6225820928812, 39.243568405508995, 28.513916954398155, 36.924271658062935, 40.168290585279465, 36.399280428886414, 35.33626466989517, 27.213514633476734, 25.173326209187508, 29.79835443198681, 47.40860067307949, 56.866847947239876, 46.91014342010021, 45.26831232011318, 49.812442883849144, 51.8327184766531, 53.57766844332218, 43.50157432258129, 32.995008900761604, 32.68807277083397, 60.88564909994602, 72.5284181535244, 65.23789376020432, 62.90176771581173, 59.01354655623436, 54.88290600478649, 54.71650913357735, 53.650062158703804, 48.15981276333332, 50.30288636684418, 48.8293444365263, 50.23966535925865, 51.24508000910282, 51.71617113053799, 50.44262766838074, 55.56012846529484, 59.52816814184189, 63.70313711464405, 63.269751369953156, 64.36085522174835, 54.7527439892292, 61.63292460143566, 64.66507449746132, 62.54671476781368, 66.37647226452827, 59.465608298778534, 61.14659629762173, 56.67157642543316, 54.34462308883667, 52.03060805797577, 50.27810409665108, 51.23404920101166, 49.060064256191254, 49.11614924669266, 48.09064507484436, 51.660747304558754, 52.66325131058693, 52.805990651249886, 55.63033349812031, 59.42925564944744, 62.805165499448776, 62.14018978178501, 63.07688511908054, 64.77826282382011, 42.4994008988142, 20.076268315315247, 15.506283938884735, 17.015866935253143, 12.559186778962612, 8.952033687382936, 8.373149000108242, 12.31923345476389, 20.57256158441305, 29.012115821242332, 20.1383987814188, 13.526228237897158, 13.124707583338022, 9.701383877545595, 11.459732875227928, 9.121059067547321, 10.222814697772264, 9.405687544494867, 10.115078128874302, 9.939372707158327, 21.70252975076437, 36.97801597416401, 33.92702668905258, 34.9156728386879, 34.67322684824467, 38.335952907800674, 15.106407646089792, 2.9150883900001645, 9.578107092529535, 62.470319867134094, 49.69153717160225, 50.34096412360668, 73.35624933242798, 60.2369175106287, 58.33234950900078, 84.78171944618225, 38.94316032528877, 17.9841385781765, 49.080294370651245, 48.27818401157856, 44.5478405803442, 57.37985461950302, 50.6271343678236, 55.51803432404995, 55.668430253863335, 9.879943896085024, 0.9354913956485689, 0.09240209838026203, 0.30719413014594465, 0.17105742503190413, 0.2787586231715977, 0.17026987276040018, 0.10605157454847358, 0.158411362208426, 0.11326709791319445, 0.22861949721118435, 0.18435544974636286, 0.13872081879526377, 0.12724349013296887, 0.16940697765676305, 0.07355670531978831, 0.1459499160409905, 0.07034848997136578, 0.19360626116394997], [0.04471008935070131, 0.03194824035745114, 0.011845226108562201, 0.08607333016698249, 0.04220027578412555, 0.05265594540105667, 0.04625862871762365, 0.039864206410129555, 0.09401888935826719, 0.08736582487472333, 0.029339405737118796, 0.02760146657237783, 0.0671424565371126, 0.07378850772511214, 0.03132681784336455, 0.0678845151560381, 0.03546850653947331, 0.022123910202935804, 0.10692947587813251, 0.058422677757334895, 0.1333128332043998, 0.034548043040558696, 0.46725252585019916, 0.6407108728308231, 27.597968503832817, 73.97572249174118, 43.38284209370613, 47.66582027077675, 49.041612446308136, 47.02708974480629, 26.26565359532833, 11.91227339208126, 54.49016287922859, 67.70076960325241, 68.72423708438873, 64.71938118338585, 59.915428161621094, 66.13311812281609, 62.78154976665974, 46.03568874299526, 13.241501916199923, 6.795635623857379, 20.485825538635254, 42.36167348921299, 65.35339996218681, 57.68748231232166, 62.627331241965294, 55.6852937489748, 44.71723549067974, 23.906555883586407, 16.738985292613506, 26.690290309488773, 24.38768606632948, 23.916330859065056, 21.431729681789875, 19.05075464397669, 17.09893047809601, 21.529865115880966, 37.14905619621277, 31.876257732510567, 27.70391631871462, 33.22143495082855, 32.2082307189703, 31.949027627706528, 25.5231012403965, 18.899608254432678, 15.83379976451397, 42.81020142138004, 57.226654440164566, 59.78248469531536, 61.093881726264954, 59.96399715542793, 58.304683193564415, 53.93330655992031, 45.26663281023502, 43.62636722624302, 43.9337707310915, 42.78717465698719, 40.74704132974148, 42.899660021066666, 42.26176545023918, 41.54709219932556, 49.85540337860584, 57.1561074256897, 56.451902613043785, 60.05051851272583, 58.662183210253716, 58.06776970624924, 49.94942173361778, 60.02343736588955, 62.458263114094734, 58.23118753731251, 58.81087303161621, 53.9538786560297, 53.188185542821884, 48.26197788119316, 45.97399145364761, 42.71014139056206, 44.220434948801994, 41.62603676319122, 43.72079215943813, 41.67711742222309, 45.46451099216938, 44.01441380381584, 47.57629707455635, 49.46889951825142, 51.03220023214817, 55.372775718569756, 57.16608949005604, 60.75192287564278, 60.405115485191345, 57.66082674264908, 33.28061677515507, 22.78363063931465, 13.66576625034213, 11.484840977936983, 8.102324232459068, 3.18925270345062, 1.5904211648739874, 3.728834674693644, 8.686229400336742, 12.420028746128082, 8.749502655118704, 5.152078941464424, 4.024019697681069, 3.6181041039526463, 1.534649538807571, 1.2379362853243947, 1.0593227134086192, 4.09558885730803, 2.006882498972118, 5.658057415857911, 0.48607520177029073, 19.34201091527939, 21.967736519873142, 21.965114660561085, 19.739895164966583, 19.563805013895035, 9.856180921196938, 0.5579335615038872, 3.4802261274307966, 42.4762487411499, 40.14949679374695, 61.275926157832146, 63.483968675136566, 43.18192407488823, 64.81224820017815, 64.27833124995232, 10.800207015126944, 32.23346896469593, 45.758299827575684, 34.80759523808956, 43.105696365237236, 36.28951571881771, 31.658345125615597, 28.385719433426857, 13.214085437357426, 0.9485038567800075, 0.04349944239947945, 0.2536927635082975, 0.03556346062396187, 0.16864194214576855, 0.03859776850731578, 0.04066061992489267, 0.0435099883179646, 0.059391811300884, 0.00965218065175577, 0.07902211087639444, 0.015882101288298145, 0.016608971855021082, 0.01857903440395603, 0.04421752593771089, 0.032536377548240125, 0.05387655197409913, 0.037447447029990144, 0.06453594483900815, 0.028528685470519122, 0.044049837670172565, 0.03735736885573715, 0.008182110414054478, 0.004499121860135347, 0.013885713833587943, 0.04164670412137639, 0.07941300005768426, 0.04682868719100952, 0.04928940397803672, 0.07390533661236987, 0.018506385567889083, 0.06342492008116096, 0.014616873086197302, 0.017736973240971565, 0.010330941495340085, 0.018642165196069982, 0.05567470157984644, 0.13983773620566353, 0.07922445744043216, 0.15978409792296588, 0.024659947557665873, 0.38107374391984195, 0.38536445586942136, 32.82784067094326, 87.08508744835854, 47.09223344922066, 42.87623807787895, 47.54689425230026, 42.548239678144455, 27.906812131404877, 26.88062209635973, 69.7920709848404, 71.73293083906174, 66.9169932603836, 72.86414533853531, 69.7471421957016, 70.22058919072151, 66.77630200982094, 50.118972435593605, 14.234924409538507, 8.189782239496708, 22.15011153370142, 44.102527275681496, 65.14195650815964, 61.11431322991848, 64.28143948316574, 57.209931537508965, 46.27802453935146, 25.857433900237083, 19.750458598136902, 28.28380510210991, 27.225415594875813, 27.316451109945774, 25.743023939430714, 21.964628286659718, 19.282557405531406, 26.359633952379227, 41.36148735880852, 31.323543190956116, 26.870119459927082, 31.873633973300457, 37.01053462922573, 35.366229861974716, 32.71954268217087, 23.6707329377532, 19.323992282152176, 41.3915741443634, 58.71998190879822, 62.0380512624979, 63.93210902810097, 63.037766218185425, 58.360817581415176, 56.07722371816635, 51.03232182562351, 48.79370994865894, 47.90235377848148, 46.791183203458786, 45.002801567316055, 45.951234474778175, 47.868072018027306, 46.06401242315769, 53.96835207939148, 60.72027437388897, 59.06489320099354, 60.59116870164871, 63.361505046486855, 63.250311613082886, 54.669532254338264, 62.337524592876434, 64.4607138633728, 58.997241631150246, 59.644916877150536, 58.71183134615421, 56.321850791573524, 52.053878009319305, 50.70911876857281, 46.48465745151043, 48.9828409999609, 49.02265526354313, 46.733718886971474, 45.77165611088276, 49.554296135902405, 46.18896871805191, 52.73574002087116, 53.321083411574364, 52.92369693517685, 58.053250685334206, 61.46758407354355, 66.05716779828072, 63.984698206186295, 61.71532317996025, 38.561729192733765, 23.684416003525257, 15.83038279786706, 13.364260978996754, 9.592934846878052, 4.038067543879151, 0.47735184954945, 3.5246925288811326, 8.566361982375383, 12.958974726498127, 8.890805672854185, 3.8564014295116067, 4.9231345765292645, 2.8654927387833595, 1.8749149865470827, 3.348146639764309, 3.089219508692622, 4.986433954909444, 3.1501860497519374, 5.045457612723112, 3.415957326069474, 19.89368051290512, 22.221811786293983, 25.10635480284691, 20.09974155575037, 20.711514428257942, 10.188077911734581, 0.5033750203438103, 4.172925632447004, 47.60474994778633, 46.12702064216137, 59.7546511888504, 67.87659376859665, 51.07808656990528, 71.99875697493553, 69.48082208633423, 21.615677811205387, 30.825074538588524, 39.45362113416195, 26.171354055404663, 44.25338298082352, 48.515542075037956, 38.438007831573486, 47.31132969260216, 24.156210087239742, 1.3452241220511496, 0.008997438490041532, 0.16909180238144472, 0.05611415319435764, 0.22131164325401187, 0.045927649407531135, 0.041074233668041416, 0.014296460103651043, 0.07627990489709191, 0.05956432352832053, 0.03800377577135805, 0.024396646549575962, 0.018212079485238064, 0.09407387507962994, 0.07190539705334231, 0.015130333522392903, 0.035435599711490795, 0.02381241491093533, 0.06301342145889066, 0.17895901197334751, 0.13185331074055284, 0.08497602029819973, 0.2393067502998747, 0.12167396867880598, 0.2062515521538444, 0.0729163209325634, 0.2034630806883797, 0.13877094344934449, 0.19953489303588867, 0.0933951216575224, 0.11786551913246512, 0.16514151357114315, 0.12702115753199905, 0.1908807980362326, 0.18521764723118395, 0.11874281932250597, 0.16858455928741023, 0.2996065013576299, 0.14974539284594357, 0.24008845444768667, 0.14085986651480198, 0.4453214386012405, 0.7080084679182619, 50.07662370800972, 103.39937523007393, 65.46065300703049, 62.99590766429901, 70.23685231804848, 66.80796191096306, 38.076966404914856, 20.15774544328451, 67.39455923438072, 76.69534295797348, 76.82486280798912, 78.51577967405319, 73.33241701126099, 77.51706406474113, 73.96772012114525, 53.650765120983124, 16.966708973050117, 9.575203098356724, 26.68889008462429, 48.11860777437687, 69.13608938455582, 65.89674040675163, 69.85979855060577, 60.396858528256416, 49.877134412527084, 32.538596391677856, 24.453162252902985, 32.42352716624737, 33.50088715553284, 33.964941054582596, 32.69519358873367, 28.853238746523857, 23.58718302100897, 29.367330260574818, 45.480352342128754, 37.19838134944439, 32.091896161437035, 34.73755739629269, 40.41171312332153, 40.3798708319664, 33.13077561557293, 24.33799423277378, 23.592324145138264, 47.082498371601105, 60.65400592982769, 64.81227099895477, 67.23638892173767, 65.47462105751038, 63.51034685969353, 59.89782750606537, 53.243214190006256, 51.65694750845432, 48.07699240744114, 48.98646220564842, 48.01168151199818, 48.611969500780106, 51.17427080869675, 48.5204666107893, 56.502736285328865, 64.21856805682182, 61.4458492398262, 63.42665635049343, 62.84765101969242, 64.8420538008213, 56.10152721405029, 63.74050050973892, 66.78616628050804, 60.97743317484856, 59.6812429279089, 58.027001693844795, 58.11763443052769, 52.63477943837643, 52.66573257744312, 50.22045359015465, 53.48554618656635, 51.54750198125839, 52.279464304447174, 48.60487908124924, 52.300963550806046, 49.36236843466759, 54.014447405934334, 53.94819416105747, 56.0197290033102, 61.34184882044792, 63.566834628582, 66.0313367843628, 65.59617653489113, 63.78406137228012, 41.400940641760826, 26.95157378911972, 19.675644412636757, 16.558204293251038, 13.909134641289711, 8.93655901774764, 6.034634783864021, 9.87586671486497, 12.31422247365117, 17.728039920330048, 15.793727114796638, 14.336980283260345, 13.672228753566742, 10.245356038212776, 7.963253119960427, 7.176005188375711, 7.287424709647894, 10.034641195088625, 8.751602992415428, 11.268284898251295, 11.384211927652359, 29.186828546226025, 29.043205752968788, 28.187662661075592, 22.79108963906765, 26.067691817879677, 14.220242947340012, 1.5560942818410695, 5.856954418122768, 52.17028856277466, 47.487359046936035, 65.09195119142532, 72.57089987397194, 53.3588457852602, 74.18332815170288, 75.6957533955574, 18.766554594039917, 40.3162432461977, 58.69094006717205, 46.482749953866005, 60.27798190712929, 55.216896682977676, 50.395924374461174, 65.42145431041718, 42.32141084969044, 2.944367006421089, 0.2375187087454833, 0.34242839261423796, 0.14195834897691384, 0.25150998844765127, 0.16425369714852422, 0.1791282810154371, 0.24025460646953434, 0.11728517449228093, 0.16006602498237044, 0.2216534616309218, 0.07164914088207297, 0.17766167846275494, 0.19026312336791307, 0.2078326532500796, 0.14690917159896344, 0.190704537963029, 0.1709597435547039, 0.13332963542779908], [0.024643930155434646, 0.06269023841014132, 0.1481828751275316, 0.07626872073160484, 0.04186815727734938, 0.027586196883930825, 0.0030474886580122984, 0.07873370486777276, 0.01573698358697584, 0.0508650020492496, 0.06369690978317522, 0.023041718668537214, 0.09692081293906085, 0.045116474575479515, 0.047783475019969046, 0.014125074085313827, 0.05663629119226243, 0.03623718599556014, 0.09485409493208863, 0.09265464381314814, 0.13135227200109512, 0.016079759334388655, 0.14834265952231362, 0.10008342331275344, 7.245335318148136, 58.11777502298355, 51.79731957614422, 50.30846066772938, 65.53759127855301, 39.22194376587868, 40.03717102110386, 10.424013901501894, 18.58225118368864, 71.17863178253174, 69.20883268117905, 77.38390401005745, 61.82466231286526, 73.8891251385212, 64.23850178718567, 54.60373118519783, 11.337633077055216, 2.0429677376523614, 15.38907827809453, 32.36563727259636, 55.19383952021599, 47.939075008034706, 47.98075117170811, 52.395426481962204, 39.138728231191635, 24.937560260295868, 16.489940956234932, 17.115203104913235, 17.62395780533552, 18.542074039578438, 15.922279916703701, 15.457963831722736, 17.00096793472767, 27.28949535638094, 27.951060757040977, 18.459225185215473, 14.475724138319492, 13.955171070992947, 14.082155507057905, 19.68816664069891, 12.876073624938726, 11.978668179363012, 29.653625898063183, 49.68790076673031, 53.24211984872818, 58.488904908299446, 60.35581313073635, 61.58334106206894, 66.60961255431175, 56.12410180270672, 48.48160229623318, 45.9956768900156, 45.60541883111, 44.49009507894516, 43.52394372224808, 42.98182301223278, 41.3635278493166, 48.327923342585564, 54.97009612619877, 59.10146623849869, 58.45798596739769, 61.91200442612171, 59.95445966720581, 58.57432812452316, 49.65748339891434, 59.76123243570328, 61.86967849731445, 57.16719143092632, 56.47747904062271, 51.163388192653656, 50.88298223912716, 47.55598336458206, 46.11644200980663, 44.46390688419342, 44.19595666229725, 42.91428543627262, 42.517704516649246, 44.165288507938385, 43.06119695305824, 44.37965780496597, 48.27565714716911, 49.39922645688057, 53.657908737659454, 56.8805918097496, 58.245094791054726, 62.79025509953499, 64.05658274888992, 57.36557498574257, 34.160824343562126, 26.005709543824196, 15.316956248134375, 7.801809282973409, 6.270531350746751, 1.7236600653268397, 1.3341733650304377, 0.5337994534056634, 2.9193009389564395, 6.0857615154236555, 6.169641064479947, 3.2227519433945417, 4.273560857400298, 4.559816597029567, 4.976298473775387, 4.646968245506287, 2.2141164913773537, 2.062431718222797, 2.57723284419626, 1.3072250923141837, 1.8336462322622538, 6.429704809561372, 19.514126479625702, 14.93266861885786, 12.52679256722331, 6.027751453220844, 2.2808781964704394, 0.1249903891584836, 2.9375157365575433, 36.83245338499546, 42.13826447725296, 70.39206638932228, 54.308483228087425, 45.41390910744667, 82.1611900627613, 41.14660128951073, 17.693813256919384, 65.50958678126335, 40.23071363568306, 40.20335130393505, 37.93815605342388, 40.251316130161285, 26.623508892953396, 25.25594137609005, 7.040816992521286, 1.0420850571244955, 0.10724415391450748, 0.1406057848362252, 0.0832255239947699, 0.15794698556419462, 0.019649621390271932, 0.0640235141327139, 0.0307718936164747, 0.03209214279195294, 0.04765397767187096, 0.019881538828485645, 0.020203124404361006, 0.07635722926352173, 0.031954637670423836, 0.0793616657028906, 0.06170807646412868, 0.015094787431735313, 0.04300170250644442, 0.03052712774660904, 0.014510195851471508, 0.020697086765721906, 0.08002552422112785, 0.03938044857932255, 0.055002660883474164, 0.009237047361239092, 0.037086856027599424, 0.05071691019111313, 0.044238016635063104, 0.09464722868870012, 0.061341477776295505, 0.01168349079307518, 0.02690033183171181, 0.08330180193297565, 0.12333136255620047, 0.016524732527614105, 0.02429374035273213, 0.09635773807531223, 0.1160242359037511, 0.04389891080791131, 0.05670747057592962, 0.005030855363656883, 0.22498315171105787, 0.025085238994506653, 8.62158726900816, 75.33595070242882, 59.905506893992424, 53.12085695564747, 64.56355154514313, 33.77996698021889, 35.36800816655159, 16.107077300548553, 41.36489577591419, 79.29360553622246, 74.5905826985836, 79.94372025132179, 67.01874420046806, 78.43533799052238, 68.15197259187698, 61.49399645626545, 12.289393655955791, 3.007387574762106, 14.988915100693703, 32.91009485721588, 56.59866213798523, 51.38774715363979, 50.341268107295036, 54.008086547255516, 41.606676802039146, 26.834414675831795, 19.091287069022655, 18.57853688299656, 19.010816887021065, 20.569732636213303, 18.111690133810043, 18.534565642476082, 19.106465354561806, 32.28499040007591, 33.96123245358467, 18.463684245944023, 13.999447245150805, 15.453993044793606, 19.066639691591263, 22.311973348259926, 15.780922751873732, 14.99289158731699, 31.247644163668156, 48.91164042055607, 56.00820802152157, 64.69488769769669, 64.41516190767288, 64.28469210863113, 68.14115077257156, 59.17788773775101, 53.150635957717896, 48.875895738601685, 47.88978025317192, 48.02333168685436, 47.741785794496536, 46.39754332602024, 46.98599494993687, 49.80210743844509, 60.34323960542679, 62.88316011428833, 61.80636249482632, 63.87573525309563, 63.117618933320045, 61.83844417333603, 54.068317115306854, 62.63640135526657, 63.02521549165249, 59.19227376580238, 61.20595671236515, 56.61552183330059, 54.7236717492342, 52.461079359054565, 50.69733940064907, 49.50375884771347, 48.21639932692051, 47.11796186864376, 45.40395364165306, 46.408737525343895, 46.653995364904404, 48.1373293697834, 50.21288059651852, 53.05693678557873, 55.31225636601448, 60.16964592039585, 62.12185576558113, 64.62548062205315, 65.69186300039291, 63.01562860608101, 37.895522341132164, 29.352613650262356, 17.48181313276291, 9.133248813450336, 6.19929657317698, 2.492206944152713, 2.2395570762455463, 0.32785074203275144, 3.7881654035300016, 5.804495858028531, 7.820452032610774, 3.421360873617232, 4.589028004556894, 6.0220693331211805, 6.161780711263418, 4.176727328449488, 4.153208015486598, 3.570298869162798, 3.24864209163934, 2.724208957515657, 1.078000848647207, 6.423121187835932, 15.950265415012836, 14.31576032191515, 13.795260451734066, 7.026260923594236, 3.488720809109509, 0.6770274240989238, 3.9202976133674383, 39.19888660311699, 44.31042172014713, 68.8887606561184, 58.23822095990181, 49.30171608924866, 85.2245020866394, 49.75068099796772, 20.09509440511465, 51.39198012650013, 34.43519242107868, 28.74601799994707, 47.24810108542442, 46.26616157591343, 39.07711073756218, 38.82833048701286, 13.059243746101856, 1.1537160607986152, 0.10818140479386784, 0.2780881669605151, 0.06207250808074605, 0.2871404984034598, 0.04770492982061114, 0.09036098446813412, 0.019493796353344806, 0.0498844913818175, 0.03233437608287204, 0.04686638087150641, 0.07245071974466555, 0.08508394341333769, 0.03694128376082517, 0.07859294171794318, 0.02596881218778435, 0.05144464535987936, 0.04572027479298413, 0.0010810338744704495, 0.09821075465879403, 0.19521299604093656, 0.15324089355999604, 0.2660915575688705, 0.206447197124362, 0.18902752170106396, 0.14493894763290882, 0.1276912575121969, 0.17694100853987038, 0.14055117761017755, 0.2193399943644181, 0.07665537224966101, 0.20700220484286547, 0.1495720716775395, 0.16177449346287176, 0.19074301089858636, 0.10470229070051573, 0.12822826072806492, 0.2517407073173672, 0.17482661496615037, 0.20244608604116365, 0.2312339944182895, 0.31135570839978755, 0.19098943361314014, 12.578244656324387, 96.5076394379139, 75.5427660048008, 71.01283147931099, 84.9849933385849, 59.79403227567673, 55.931387543678284, 15.812897086143494, 29.23903774470091, 84.05402809381485, 78.32726418972015, 91.20622470974922, 73.64965438842773, 87.36080825328827, 74.67154875397682, 68.14116597175598, 13.908686265349388, 4.598403051495552, 17.85772506147623, 35.64734257757664, 59.76114884018898, 57.106953263282776, 53.52577082812786, 58.21949936449528, 47.408604472875595, 33.60863417387009, 26.379628479480743, 24.060238637030125, 26.70713860541582, 28.99083126336336, 25.81462349742651, 25.269896127283573, 22.83297099173069, 40.05776971578598, 40.69147691130638, 23.325817845761776, 16.582486890256405, 19.365641847252846, 24.660648219287395, 24.30732987821102, 16.342885047197342, 17.885201387107372, 34.72911424934864, 53.845732659101486, 58.50621297955513, 63.987570852041245, 66.10911101102829, 66.31437599658966, 69.49681162834167, 60.2448932826519, 55.530866235494614, 51.55992351472378, 49.756456688046455, 52.86102309823036, 51.52018904685974, 50.0178674608469, 48.340819850564, 54.2425187677145, 61.50677137076855, 66.93106010556221, 63.51407065987587, 66.50497376918793, 64.75139066576958, 60.461428463459015, 51.50441229343414, 62.96267844736576, 64.88241523504257, 60.774869844317436, 60.1881243288517, 56.79326869547367, 56.04679115116596, 53.07531639933586, 53.114370703697205, 54.11803364753723, 51.987658962607384, 50.90070828795433, 49.056788831949234, 50.48162877559662, 48.909451737999916, 51.31608299911022, 53.237818479537964, 52.829032614827156, 58.88193301856518, 64.12169605493546, 63.525565043091774, 66.3685230910778, 66.65773317217827, 62.50796064734459, 40.14329552650452, 31.59176129847765, 20.37415523082018, 14.397114906460047, 11.332198418676853, 8.300045672804117, 6.530611719936132, 6.751278229057789, 9.330004155635834, 10.554157868027687, 13.45205906778574, 10.647404864430428, 13.40180866420269, 13.659706525504589, 11.733341943472624, 9.249480776488781, 7.855243440717459, 6.4181396551430225, 6.67917899787426, 5.601545898243785, 3.5764535889029503, 14.435853827744722, 23.04444294422865, 20.583846978843212, 15.921610202640295, 8.688308838754892, 4.869274841621518, 1.356800557114184, 4.691019281744957, 45.372590124607086, 45.54382413625717, 78.5057558119297, 64.42738205194473, 53.59529189765453, 95.94891741871834, 52.38459326326847, 23.409457057714462, 79.14253324270248, 53.30506347119808, 55.27828238904476, 58.90397943556309, 55.856440365314484, 51.17159195244312, 60.66230848431587, 18.35860848426819, 1.442894081119448, 0.24060559779172763, 0.25927407026756555, 0.1823555101873353, 0.36573660909198225, 0.14017986628459767, 0.1674497264320962, 0.15113467845367268, 0.21199768991209567, 0.1489188481355086, 0.0744753802428022, 0.2345903721288778, 0.22097227396443486, 0.20407588686794043, 0.20181612140731886, 0.1138303434709087, 0.08679526174091734, 0.15183486510068178, 0.1106880976294633], [0.054259114258456975, 0.03224600855901372, 0.05305188489728607, 0.05306521758029703, 0.0655171085963957, 0.05415210769569967, 0.12676219252170995, 0.02141727614798583, 0.021242697039269842, 0.1491134095704183, 0.019209629863325972, 0.03421191322559025, 0.06652608804870397, 0.037598169801640324, 0.06736074443324469, 0.03335852874442935, 0.04908316484943498, 0.06869511111290194, 0.043909809246542864, 0.03594898407754954, 0.045722415889031254, 0.10929329786449671, 0.04045268127811141, 0.1316560775740072, 0.7947013503871858, 33.03922712802887, 63.312799260020256, 37.927516624331474, 64.29582551121712, 65.80447375774384, 34.01485897600651, 45.811819955706596, 9.78052033111453, 36.32116042077541, 65.34885540604591, 74.36946496367455, 75.61517491936684, 65.37657111883163, 65.11262968182564, 57.86145217716694, 17.970863990485668, 0.36079399462323636, 4.00977473706007, 20.307816490530968, 39.91917595267296, 37.37132906913757, 38.90665948390961, 43.48422825336456, 25.279671102762222, 17.827949859201908, 7.906807623803616, 9.628238752484322, 9.837071746587753, 10.370906051248312, 11.768225971609354, 11.631061881780624, 18.251117952167988, 33.09775538742542, 20.567477457225323, 9.010089822113514, 5.321812983602285, 5.881056049838662, 4.208007724955678, 8.815343622118235, 7.74289439432323, 17.058909125626087, 34.32716801762581, 45.92988722026348, 51.044990345835686, 48.841355592012405, 56.33204184472561, 65.61455234885216, 63.12862694263458, 60.867265686392784, 53.650115355849266, 48.53073365986347, 44.29475516080856, 44.8270495980978, 42.7867566794157, 43.78999784588814, 43.928587809205055, 51.7967040091753, 58.31945680081844, 59.987977668643, 56.327751874923706, 59.12697806954384, 55.9420345723629, 59.264511689543724, 51.8668482452631, 59.86382693052292, 61.64508014917374, 60.185950845479965, 54.06191445887089, 50.16931213438511, 48.493400663137436, 48.36068518459797, 47.55248375236988, 45.775459706783295, 44.03969004750252, 43.00215192139149, 40.54326206445694, 43.45428206026554, 44.86321985721588, 47.3905174434185, 53.35645191371441, 51.28946162760258, 60.44613428413868, 63.27558785676956, 59.14522849023342, 58.78820724785328, 63.61364811658859, 54.28911566734314, 34.06729616224766, 26.11855398863554, 15.585294049233198, 7.4205168429762125, 2.3629179317504168, 0.9684158570598811, 4.199395962059498, 1.4048620406538248, 1.4102683193050325, 2.899114047177136, 6.6223392728716135, 1.6936935670673847, 2.758193858899176, 3.8767434004694223, 4.489631988108158, 6.131331520155072, 5.618910016492009, 3.5293028689920902, 2.8071642061695457, 2.3368456307798624, 3.0730093410238624, 0.6495830998755991, 6.624908884987235, 7.253603199496865, 7.98181464895606, 1.7507232818752527, 0.9199267777148634, 0.0999904099444393, 2.2927257232367992, 32.540268301963806, 50.16306906938553, 68.0772154033184, 54.535726234316826, 53.998670652508736, 83.22225272655487, 22.905695289373398, 53.55076588690281, 63.65436673164368, 32.835656851530075, 38.64353880286217, 41.840383261442184, 62.541357055306435, 27.333234809339046, 19.9667239934206, 6.599139142781496, 0.6095469638239592, 0.09904483216814697, 0.037101925336173736, 0.0832157202239614, 0.0653029618842993, 0.1948462860309519, 0.049162548675667495, 0.13298035104526207, 0.014912942697264953, 0.03599978408601601, 0.11869453519466333, 0.011642997360468144, 0.033979602449107915, 0.040919874372775666, 0.039475087251048535, 0.10358156607253477, 0.027480118005769327, 0.015489182333112694, 0.021511573431780562, 0.013827089733240427, 0.017150468775071204, 0.014908965713402722, 0.04684039828134701, 0.03518429737596307, 0.05207966401940212, 0.043415768959675916, 0.04000107328465674, 0.031127165275393054, 0.036959073040634394, 0.022191206298884936, 0.045898924581706524, 0.05436479608761147, 0.06182290155265946, 0.06835237247287296, 0.073316464695381, 0.049981126430793665, 0.06185981597809587, 0.03406714247830678, 0.048677881713956594, 0.03486597168375738, 0.1605933951213956, 0.03616421061451547, 0.04209050472127274, 1.0929040051996708, 44.668575301766396, 80.65753474831581, 39.3672251701355, 68.75658094882965, 52.56480619311333, 30.34221924841404, 42.27692663669586, 19.535386338829994, 53.23445565998554, 68.8676717877388, 83.85328486561775, 77.40120068192482, 75.46680808067322, 71.48569330573082, 65.59080362319946, 19.781634025275707, 1.0632058675400913, 4.692970477044582, 23.15307341516018, 40.440690368413925, 39.93825852870941, 39.799565970897675, 43.394036293029785, 27.398329116404057, 17.908144555985928, 9.849947355687618, 9.40129877999425, 11.1174082942307, 13.340434357523918, 13.285523504018784, 15.048287864774466, 21.07083074748516, 36.829155161976814, 23.604175709187984, 8.781845569610596, 3.4713217802345753, 5.065024187788367, 4.948756126686931, 9.528933931142092, 10.079678278416395, 20.113035142421722, 35.87413340806961, 48.77612069249153, 51.68554477393627, 54.04985010623932, 62.6401137560606, 68.04767578840256, 66.4191135764122, 64.35723781585693, 56.14691577851772, 50.788257122039795, 46.82046063244343, 49.260355308651924, 46.57858461141586, 48.17329064011574, 47.48361624777317, 55.825510025024414, 62.283415496349335, 63.365836814045906, 60.83147540688515, 62.61915788054466, 60.205029621720314, 61.81788727641106, 56.09384782612324, 63.56547050178051, 64.14170578122139, 63.80973279476166, 56.45711973309517, 54.27183799445629, 50.63841216266155, 52.061561197042465, 51.99439600110054, 51.48618087172508, 48.9363618940115, 48.01515832543373, 44.24798347055912, 45.98406471312046, 47.776770517230034, 50.092449858784676, 53.142823576927185, 52.895996421575546, 60.41972950100899, 62.62237250804901, 62.12347827851772, 63.87036234140396, 67.74681553244591, 57.51742623746395, 37.48691126704216, 28.007824011147022, 18.75146370381117, 7.768190586939454, 5.062177190557122, 1.2478759582154453, 1.6787649993784726, 1.9009828940033913, 1.458679384086281, 2.74686714168638, 6.6217403300106525, 2.9482641723006964, 5.407818043604493, 6.410763775929809, 6.90008251927793, 7.512483783066273, 6.641981843858957, 5.259078349918127, 4.514273665845394, 4.37622707337141, 3.2394591718912125, 1.8783346842974424, 5.638268077746034, 7.529504019767046, 8.003349993377924, 0.7826781424228102, 1.640260478015989, 0.3134384419536218, 2.3156387312337756, 35.78941695392132, 52.84153014421463, 71.96737065911293, 59.55538988113403, 54.433602914214134, 86.75961971282959, 28.807263113558292, 41.19292840361595, 61.77871897816658, 25.857450999319553, 34.39614191651344, 50.11255457997322, 67.19880133867264, 46.13852262496948, 32.88086302578449, 9.838443472981453, 0.5708901537582278, 0.07615715367137454, 0.176367565873079, 0.1097125667729415, 0.10235170120722614, 0.21758438466349617, 0.03601456766773481, 0.07529034002800472, 0.0594816223019734, 0.08584598064771853, 0.07641496835276484, 0.051773706218227744, 0.08646569622214884, 0.0657949538435787, 0.049399694544263184, 0.08673114018165506, 0.06404696599929594, 0.09516230144072324, 0.04693115180998575, 0.22207685688044876, 0.1269073862931691, 0.15077749761985615, 0.17813791462685913, 0.15136324509512633, 0.1644085388397798, 0.22620166913839057, 0.10679092432837933, 0.12945323484018445, 0.2278963930439204, 0.13648118037963286, 0.12327338597970083, 0.1084319018991664, 0.1467681783833541, 0.20889028790406883, 0.13000095466850325, 0.14079103973926976, 0.21586730726994574, 0.10444977495353669, 0.0797114399028942, 0.19173784501617774, 0.20515559299383312, 0.1512266305508092, 0.35409189644269645, 1.46993069909513, 62.31790244579315, 95.87777003645897, 57.06888310611248, 79.72956374287605, 83.90510648488998, 49.626834243535995, 62.41675414144993, 16.762969605624676, 44.97022591531277, 73.85162115097046, 90.82681506872177, 83.71001735329628, 80.7680556178093, 74.6506042778492, 72.70038172602654, 22.208711989223957, 1.3268870185129344, 6.0269777197390795, 25.258339047431946, 43.68317797780037, 45.43884716928005, 44.0161807090044, 48.578371703624725, 32.55319520831108, 23.780231662094593, 15.568903628736734, 14.59006380289793, 17.7298429235816, 19.51510302722454, 19.746113531291485, 21.463604271411896, 25.87953731417656, 44.59070987999439, 30.466882959008217, 12.877983022481203, 6.715312208980322, 8.33379166200757, 8.511690516024828, 11.79133728146553, 11.929070390760899, 22.42054872214794, 39.08620744943619, 52.57834106683731, 54.92040619254112, 54.31450590491295, 61.54850833117962, 68.99136275053024, 65.87784022092819, 65.41405230760574, 58.63646999001503, 53.06381441652775, 48.291540294885635, 51.40337571501732, 48.89825373888016, 52.191293835639954, 53.018380254507065, 58.99365082383156, 63.60741265118122, 65.87180614471436, 60.83897240459919, 63.8630211353302, 59.93104912340641, 63.4508116543293, 54.20402683317661, 65.13400733470917, 66.03707447648048, 66.11642941832542, 56.92154601216316, 53.759731873869896, 51.95444114506245, 53.59383277595043, 54.44083012640476, 55.219776928424835, 50.00983089208603, 51.683986857533455, 46.04348972439766, 50.61012268066406, 50.86054064333439, 52.804531529545784, 55.65541215240955, 55.94814844429493, 63.64842765033245, 67.1264000236988, 65.46807020902634, 65.46128377318382, 67.8582027554512, 56.655898466706276, 38.21792744100094, 31.387729346752167, 22.282310239970684, 11.970140486955643, 9.26952850073576, 6.16794778034091, 8.624021038413048, 5.984177766367793, 8.439536187797785, 9.224612060934305, 13.931184858083725, 9.8687544465065, 12.847753744572401, 12.653524316847324, 10.25862967595458, 11.707142349332571, 11.212753728032112, 7.691219067201018, 6.225669058039784, 7.4479038733989, 3.893886893056333, 7.076395908370614, 10.688458811491728, 10.466159339994192, 10.4282202757895, 3.606536337174475, 2.572849066928029, 0.32118533563334495, 3.9680275646969676, 39.61837649345398, 54.82962906360626, 76.54247716069221, 64.35449436306953, 59.92764450609684, 96.1557175219059, 31.85693956911564, 61.94334514439106, 73.12723562121391, 42.649838626384735, 58.91107365489006, 58.338881358504295, 73.30937504768372, 58.368249982595444, 50.604464784264565, 13.550115656107664, 0.7888385618571192, 0.17300372215686366, 0.29285978525877, 0.22960294678341597, 0.20236364827724174, 0.348367533297278, 0.21032276650657877, 0.16507567022927105, 0.17483719799201936, 0.1751058257650584, 0.18738247716100886, 0.11383091492461972, 0.20979634631657973, 0.10366102782427333, 0.19126249942928553, 0.16555422189412639, 0.194901768991258, 0.16139013518113643, 0.09531503543257713], [0.01647614782996243, 0.02376062227995135, 0.06309077551122755, 0.05324567449861206, 0.088609226513654, 0.029479567747330293, 0.04106775842956267, 0.050789937522495165, 0.09368535334942862, 0.027481644974614028, 0.04826533295272384, 0.02826748474035412, 0.08515515248291194, 0.048325647294404916, 0.04338050581282005, 0.035388343458180316, 0.1335765776457265, 0.04981015787052456, 0.064267606503563, 0.06521264251205139, 0.1173212577123195, 0.08319537053466775, 0.04043074710352812, 0.3487225767457858, 0.1548063798691146, 13.233642037957907, 68.06197062134743, 49.55462671816349, 34.743473678827286, 80.61082005500793, 40.003740414977074, 43.202724158763885, 32.594745978713036, 9.452671073377132, 61.88074350357056, 75.29457092285156, 74.75474908947945, 61.040304601192474, 57.8597916662693, 58.761585876345634, 26.86916571110487, 0.6026962876785547, 2.307939869351685, 8.769292943179607, 17.50929895788431, 28.167316652834415, 30.11654745787382, 28.519424758851528, 12.968134135007858, 6.240398017689586, 4.064800059422851, 3.0058410577476025, 2.3387742647901177, 3.8499142276123166, 8.294750656932592, 8.939629253000021, 20.801649391651154, 28.768782578408718, 12.700952421873808, 3.0756611237302423, 1.6966255847364664, 0.98074791720137, 2.509695505723357, 2.535548130981624, 5.4936084151268005, 15.172427203506231, 25.43768372386694, 39.3379857391119, 45.03322273492813, 41.117726638913155, 30.345642864704132, 57.661845088005066, 67.69245564937592, 61.97966739535332, 61.31613180041313, 51.18470124900341, 44.97443228960037, 42.38489404320717, 45.12996554374695, 43.44746522605419, 46.08663260936737, 56.47717505693436, 57.66440235078335, 60.76059401035309, 61.31412170827389, 60.6203169375658, 56.98978275060654, 59.57553260028362, 48.275239169597626, 47.29189373552799, 63.150821551680565, 59.596663266420364, 58.122323378920555, 50.107542648911476, 46.96831829845905, 48.74177433550358, 48.24227973818779, 45.84398902952671, 42.433512434363365, 42.43539333343506, 41.66874647140503, 44.22400675714016, 44.750871285796165, 50.08344054222107, 52.30892412364483, 57.404982671141624, 62.24214971065521, 71.1429212987423, 66.5354785323143, 63.20434927940369, 60.15152849256992, 46.270770728588104, 32.21336804330349, 25.986809358000755, 12.665532622486353, 4.98726706020534, 0.7323354156687856, 0.8590064279269427, 3.7830316415056586, 2.4283839063718915, 0.990821176674217, 2.667224365286529, 4.312863573431969, 0.5663830018602312, 1.0261896788142622, 6.302103856578469, 6.718227127566934, 6.1401380226016045, 7.500723889097571, 6.432828241959214, 3.501548208296299, 3.484054896980524, 2.2331579821184278, 2.2994010150432587, 1.7976400768384337, 0.769426531624049, 2.1172074414789677, 0.4043809213908389, 0.4819667019182816, 1.2185732368379831, 0.7317915104795247, 22.263375855982304, 50.942335054278374, 71.26930251717567, 66.3057504594326, 62.78164856135845, 66.2751393020153, 20.421221405267715, 67.91048794984818, 35.50699710845947, 42.704377099871635, 43.29424224793911, 74.81112286448479, 60.60699485242367, 33.61296974122524, 31.646527759730816, 3.8678853632882237, 0.08704221138032153, 0.32166648481506854, 0.0394912512274459, 0.10949511008220725, 0.0954861672653351, 0.15336389711592346, 0.09590582951204851, 0.07515214470913634, 0.11406212361180224, 0.05149333766894415, 0.023165575694292784, 0.060865059786010534, 0.029141794075258076, 0.028308501387073193, 0.06537729539559223, 0.022477296806755476, 0.05446182818559464, 0.15440849965671077, 0.023240822047227994, 0.07241369399707764, 0.019657165321405046, 0.05692076752893627, 0.017947553933481686, 0.07212657932541333, 0.109178502461873, 0.05859645163582172, 0.09156949032330886, 0.06444959595683031, 0.041558269804227166, 0.01799287503672531, 0.029216235197964124, 0.05287640778988134, 0.03238671975850593, 0.04333947246777825, 0.03200035025656689, 0.057662844701553695, 0.027292119011690374, 0.06200411546160467, 0.022565623512491584, 0.02974318416818278, 0.0325012591201812, 0.03138355503324419, 0.32442914438433945, 0.03621607189415954, 16.845470778644085, 85.80871313810349, 57.33761988580227, 46.10235996544361, 82.22947239875793, 25.33347811549902, 41.433003321290016, 37.94072471559048, 26.117229759693146, 69.68946889042854, 80.98044902086258, 79.71866592764854, 69.60259795188904, 66.06000244617462, 68.8025812804699, 29.86362922936678, 0.5014808813575655, 2.6121885934844613, 9.44914961233735, 18.959766626358032, 29.06588863581419, 30.812145732343197, 29.534392096102238, 14.4804035872221, 6.715011075139046, 4.783081216737628, 3.0886255530640483, 3.5959900030866265, 4.41753750666976, 9.440201092511415, 10.463411137461662, 25.312934517860413, 32.62280747294426, 16.539402902126312, 2.5728816026821733, 0.1335913612274453, 0.7574300409760326, 2.59833762422204, 3.01476891618222, 8.274306803941727, 19.15603369474411, 30.385071448981762, 41.27585135400295, 49.9557825922966, 47.163464426994324, 40.64808323979378, 63.4982331097126, 68.22503507137299, 65.5350910127163, 62.56423182785511, 52.931178733706474, 49.51725572347641, 45.92372015118599, 48.059828728437424, 46.69835418462753, 48.975727781653404, 59.0486528724432, 62.52767398953438, 65.32367795705795, 65.64081653952599, 62.858203053474426, 59.29063528776169, 60.508352145552635, 53.21038015186787, 54.936110749840736, 66.49610504508018, 64.50517907738686, 61.518774926662445, 54.852982610464096, 51.29737660288811, 53.52565683424473, 51.45796358585358, 50.973250195384026, 49.501224383711815, 46.11236862838268, 44.802784100174904, 45.97200036048889, 48.819841146469116, 52.37336106598377, 55.81437662243843, 60.33777169883251, 65.02117618918419, 69.7159306704998, 65.66670075058937, 62.82847724854946, 63.84584605693817, 47.999742552638054, 35.319252982735634, 27.44705770164728, 15.44540360569954, 6.285335831344128, 3.5890558501705527, 1.8341367621906102, 3.615660835057497, 3.648523846641183, 0.5091820587404072, 3.4309351723641157, 4.202324179932475, 2.9393565002828836, 4.611068721860647, 9.685100801289082, 7.134506665170193, 7.499203970655799, 9.091945979744196, 8.11815608292818, 4.976567784324288, 5.415701670572162, 3.8539325119927526, 1.9143535452894866, 1.5008968999609351, 1.1206934577785432, 1.3645031000487506, 0.40402439364697784, 1.9370333408005536, 2.69766500685364, 0.5229556665290147, 21.501968912780285, 54.441673681139946, 74.80284690856934, 68.26298743486404, 62.81224451959133, 76.51055127382278, 21.112335920333862, 66.67407989501953, 35.9218892455101, 28.90769362449646, 50.11237978935242, 78.03195923566818, 67.75747776031494, 50.83215616643429, 43.345448300242424, 4.360354850068688, 0.20060971583006904, 0.1767650304827839, 0.06826870274380781, 0.11536396195879206, 0.09835562188527547, 0.18156107078539208, 0.01568571045936551, 0.1291503050015308, 0.025961090141208842, 0.08118837315123528, 0.06080323888454586, 0.03153088990075048, 0.03477236459730193, 0.04761004995089024, 0.019584776237024926, 0.00918431869649794, 0.0470574913197197, 0.024144433227775153, 0.01690417037025327, 0.16450509225251153, 0.14041094138519838, 0.1153561397222802, 0.11003471081494354, 0.27472573332488537, 0.21519872127100825, 0.09906426159432158, 0.22817652410594746, 0.19324813038110733, 0.12584942509420216, 0.1734417674015276, 0.17108644300606102, 0.19911289302399382, 0.09163068782072514, 0.1939185569062829, 0.19444411620497704, 0.283587392186746, 0.11803803878137842, 0.07629284053109586, 0.19761736155487597, 0.26651176158338785, 0.1909847283968702, 0.15006334375357255, 0.49492035526782274, 0.38938677753321826, 22.32788309454918, 101.92615628242493, 71.20238050818443, 53.96201401948929, 104.36799645423889, 58.74994330108166, 58.68842080235481, 47.32625909149647, 17.254680320620537, 71.85881048440933, 87.28438675403595, 86.30954906344414, 75.97424045205116, 68.28700974583626, 71.31084188818932, 34.16612505912781, 1.5977895632386208, 3.5244816401973367, 12.522121667861938, 18.923497572541237, 33.02102990448475, 34.12330515682697, 35.035640001297, 18.240060545504093, 10.961828492581844, 11.112593952566385, 8.204686939716339, 8.828794900327921, 10.57008946314454, 17.894123308360577, 16.21980395168066, 30.94816703349352, 40.96709132194519, 22.824655137956142, 5.4817364271730185, 2.849708148278296, 2.253826023079455, 5.764403734356165, 5.239377832040191, 10.237323269248009, 23.654409013688564, 32.70785830914974, 45.02763323485851, 52.50408545136452, 50.22988088428974, 42.42799513041973, 63.82557034492493, 69.59274888038635, 68.4913095831871, 67.31700539588928, 56.17576003074646, 51.85323737561703, 48.366590067744255, 50.475803688168526, 49.97986190021038, 51.41520068049431, 62.49852955341339, 63.02670881152153, 66.18041038513184, 67.12735757231712, 62.77069754898548, 60.3450521081686, 60.512322932481766, 48.86189728975296, 52.862045243382454, 69.28263232111931, 64.94166925549507, 62.54820428788662, 54.11125101149082, 50.308149084448814, 54.74614754319191, 53.19678068161011, 53.247500360012054, 50.521997809410095, 47.506088241934776, 48.44249479472637, 50.64913138747215, 52.39918828010559, 56.26644216477871, 60.568696707487106, 64.36404705047607, 71.51600807905197, 74.80470880866051, 70.79346925020218, 66.9785575568676, 63.87625962495804, 48.53640295565128, 37.26190634071827, 31.2340484932065, 19.425101056694984, 10.382988452911377, 6.644607977941632, 6.121605467051268, 8.426402192562819, 9.053608886897564, 6.791823003441095, 10.320652797818184, 9.456013944000006, 9.962319675832987, 11.469298861920834, 17.18091867864132, 13.170588221400976, 9.960605967789888, 13.071852419525385, 11.40006372705102, 5.631667831912637, 6.92219590768218, 4.522816082462668, 4.816673314198852, 4.4761161133646965, 3.51925240829587, 3.588662096299231, 1.1545767146162689, 2.426133477129042, 3.3737385040149093, 1.4719158550724387, 27.04697147011757, 59.99068692326546, 79.32090327143669, 69.41135421395302, 73.98833781480789, 78.92024517059326, 28.600540906190872, 74.16222408413887, 39.03170697391033, 59.015951827168465, 65.05742624402046, 81.1099536716938, 77.3917543888092, 64.17795583605766, 55.74098736047745, 3.9996767789125443, 0.27577415050473064, 0.379656805889681, 0.22203866596100852, 0.1687517503160052, 0.21118051110533997, 0.1865531419753097, 0.16081105219200253, 0.13617516320664436, 0.20621114963432774, 0.16010768915293738, 0.13300729100592434, 0.12929364340379834, 0.1243953499943018, 0.11161335540236905, 0.11393407345167361, 0.0715824514918495, 0.10714052041294053, 0.23194442270323634, 0.13309048576047644], [0.03822372978902422, 0.02276478069688892, 0.06067336675187107, 0.05875381662917789, 0.014315848711703438, 0.03271281202614773, 0.0690142197709065, 0.06020745757268742, 0.036828826123382896, 0.03319836956507061, 0.039599771771463566, 0.046517352529917844, 0.05465510199428536, 0.09054246183950454, 0.02273664216772886, 0.11035941526643, 0.019165162229910493, 0.10545980083406903, 0.05690932732250076, 0.035179551341570914, 0.022036203190509696, 0.01767324316460872, 0.014480147219728678, 0.059917311227764, 0.012367124763841275, 2.4575288174673915, 66.66511237621307, 62.78397783637047, 44.77638691663742, 53.94388899207115, 78.97693052887917, 36.38607993721962, 56.18342041969299, 10.383113846182823, 35.77409237623215, 79.97908875346184, 70.73375165462494, 69.84571650624275, 51.54182128608227, 56.883517652750015, 14.1949581541121, 0.11673981469357386, 0.5327988602221012, 3.5695265606045723, 9.941263105720282, 11.867875624448061, 17.953383028507233, 13.85522598400712, 7.019535759463906, 1.6873659566044807, 0.35555523354560137, 1.0017838259227574, 1.1765211308375, 1.48137271637097, 3.9887784887105227, 7.14404652826488, 18.90792790800333, 26.5852240473032, 4.465556954964995, 2.3745947051793337, 2.5424613850191236, 1.4384913048706949, 1.320836793165654, 0.417851940728724, 1.9947685115039349, 9.069834016263485, 18.641172721982002, 32.54820227622986, 39.17418412864208, 33.983290269970894, 19.2917263135314, 36.519000604748726, 67.94488370418549, 68.280960470438, 62.8291954100132, 59.18986089527607, 48.60103748738766, 44.816942140460014, 44.686772525310516, 42.866928577423096, 47.282128259539604, 56.333299577236176, 57.18395233154297, 60.75395956635475, 57.95331224799156, 61.228633895516396, 55.75683631002903, 65.17466515302658, 42.267024368047714, 37.59523965418339, 65.51697358489037, 58.023768067359924, 59.43481855094433, 47.62515105307102, 46.9784751534462, 47.87089146673679, 47.784677892923355, 47.118429243564606, 42.69692949950695, 44.14456441998482, 41.88655078411102, 42.91946455836296, 44.397152066230774, 49.393587559461594, 48.56878861784935, 54.63004857301712, 51.000338941812515, 52.3648951202631, 60.627616345882416, 60.56501470506191, 53.035737723112106, 33.605168759822845, 30.495067946612835, 23.771750517189503, 11.298788711428642, 2.562631177715957, 0.5223013297654688, 1.8785576848313212, 2.9806334478780627, 3.3301424933597445, 2.380520487204194, 1.9998486014083028, 3.4800283005461097, 1.301280192565173, 2.431471240706742, 5.8937587682157755, 11.644807644188404, 9.868543557822704, 8.319300189614296, 8.31392727792263, 7.056137295439839, 5.62849547713995, 3.7477068370208144, 2.4439357593655586, 0.30698564602062106, 0.15678499010391533, 0.38150086475070566, 0.3418950556078926, 1.727556400001049, 1.1256660846993327, 0.425168359070085, 16.159687377512455, 48.07768777012825, 75.79692676663399, 89.50552716851234, 77.00498074293137, 49.63192977011204, 26.89896561205387, 36.54935337603092, 34.53337535262108, 46.323971673846245, 50.09123772382736, 67.63965368270874, 34.10127393901348, 54.39964033663273, 10.254514496773481, 0.609686131356284, 0.1664362198789604, 0.27619972766842693, 0.15729468228528276, 0.06382635518093593, 0.042830782185774297, 0.08881791101885028, 0.10596577485557646, 0.08826841745758429, 0.07385156059172004, 0.08694383970578201, 0.018968882723129354, 0.058392932478454895, 0.03626554345828481, 0.024496279875165783, 0.0740142838913016, 0.026242302883474622, 0.0042682341518229805, 0.054456577490782365, 0.02325072044186527, 0.051969699998153374, 0.03846415595035069, 0.09591898779035546, 0.0035303399090480525, 0.08275096508441493, 0.026540260332694743, 0.022517246616189368, 0.016622473376628477, 0.047185552612063475, 0.08316867548273876, 0.05968577228486538, 0.05605624712188728, 0.04866239309194498, 0.033607901495997794, 0.03841376041236799, 0.062431844853563234, 0.03372173581738025, 0.06844324103440158, 0.06399540900019929, 0.02761258765531238, 0.03824676234216895, 0.054468329399242066, 0.03929376201995183, 0.11298709301627241, 0.014044903582544066, 3.5644550202414393, 78.51946547627449, 74.63229686021805, 47.11120203137398, 71.88119888305664, 64.73635867238045, 25.759649947285652, 48.531919196248055, 17.740094773471355, 49.66326288878918, 82.08610609173775, 76.41098901629448, 72.80164629220963, 60.857807993888855, 66.6055391728878, 17.851651087403297, 0.04846708208788186, 1.6722628357820213, 5.276947366073728, 10.825147926807404, 15.174561738967896, 19.790301360189915, 13.156303837895393, 6.275838240981102, 1.468156788032502, 0.25817061541602015, 0.6016129301860929, 1.2935173278674483, 1.8574710725806653, 4.439335511997342, 9.058430828154087, 23.09758309274912, 29.561361148953438, 7.457318343222141, 0.7333499018568546, 3.02170948125422, 3.5768984025344253, 2.507710587233305, 1.521981731057167, 5.718207713216543, 13.443733714520931, 18.696218468248844, 34.005731865763664, 42.6630999147892, 39.956045374274254, 26.13042265176773, 42.98016630113125, 69.82661113142967, 68.41418132185936, 64.07660007476807, 59.272324070334435, 50.69981686770916, 47.107573226094246, 48.293538987636566, 45.9098394960165, 48.168571293354034, 59.53027322888374, 60.213468968868256, 63.07794526219368, 62.87131614983082, 64.46266695857048, 59.173160791397095, 67.09545448422432, 46.60272851586342, 42.3201759159565, 65.12478902935982, 61.82610623538494, 64.68652054667473, 52.4441322684288, 51.44567124545574, 51.29142612218857, 52.736864760518074, 51.83329984545708, 48.45200948417187, 47.613732665777206, 44.665607661008835, 46.400890946388245, 49.38488222658634, 54.0504352748394, 53.83583799004555, 61.23038940131664, 61.875416189432144, 66.88565254211426, 70.02154067158699, 64.98779878020287, 59.66961935162544, 40.63278906047344, 32.589840441942215, 24.909567162394524, 12.063206043094397, 4.503132188692689, 2.272898149676621, 2.585961688309908, 2.472867644391954, 4.223872823640704, 2.453391789458692, 1.791307122912258, 3.2517168391495943, 4.406843455508351, 5.287905028089881, 8.70408559218049, 9.222754910588264, 8.228405267000198, 9.349997732788324, 10.287196543067694, 7.180652813985944, 7.9882315546274185, 5.546751888468862, 3.3019548933953047, 0.9803962579462677, 0.5897169560194016, 0.9965243143960834, 0.7256833382416517, 2.1945252176374197, 3.040417064912617, 0.27099923172499985, 13.999968767166138, 52.976525500416756, 79.61815372109413, 86.96254402399063, 76.38971015810966, 61.96216553449631, 26.25809010118246, 44.249488189816475, 27.326587066054344, 46.0892316699028, 56.93784713745117, 73.81336480379105, 43.683208376169205, 68.03462728857994, 12.903368510305882, 0.8294538699556142, 0.11196074730833061, 0.228476025222335, 0.20326596626546234, 0.05647711906931363, 0.08582650669268332, 0.1566352543886751, 0.13891080860048532, 0.03842344172880985, 0.03271051878982689, 0.05402122995292302, 0.037067341254442, 0.04766147707414348, 0.029470261215465143, 0.016837386356201023, 0.07286605527042411, 0.03491497198410798, 0.04184980396530591, 0.02890413426939631, 0.048989680217346177, 0.15039680554764345, 0.1525420427788049, 0.2707609726348892, 0.2665377367520705, 0.1296343485591933, 0.15729061531601474, 0.1591399879544042, 0.12311199854593724, 0.13307583576533943, 0.26819943508598953, 0.21447923878440633, 0.16083512746263295, 0.10512754874071106, 0.13766940333880484, 0.1216098248551134, 0.19821596302790567, 0.18838262505596504, 0.3024496097350493, 0.24038075673161075, 0.2071524749044329, 0.1596792769851163, 0.1992685956065543, 0.18309032544493675, 0.16772867005784065, 0.17552488687215373, 5.0808189902454615, 94.77984175086021, 85.92139229178429, 61.59115344285965, 76.51961758732796, 103.3400908112526, 52.32141025364399, 74.66951206326485, 16.89163450151682, 43.56025457382202, 90.27583703398705, 81.57967686653137, 84.52631995081902, 60.46985261142254, 71.5427814424038, 18.57722595334053, 0.1491743844235316, 1.7737265350297093, 7.552982484921813, 11.187016759067774, 17.257277481257915, 23.914733044803143, 18.648808412253857, 11.26853758469224, 4.201213689520955, 2.821200890466571, 4.9427268002182245, 6.919511826708913, 5.477950880303979, 9.394597839564085, 14.654464647173882, 28.504843041300774, 37.79398798942566, 13.52494865655899, 4.195544868707657, 6.0429297387599945, 4.936292320489883, 3.9816548209637403, 3.8293898664414883, 9.13825124502182, 18.720527663826942, 24.113986752927303, 37.72888608276844, 45.493541434407234, 43.851744532585144, 34.482298493385315, 45.06380349397659, 70.12593626976013, 71.87783226370811, 67.52838805317879, 63.67193318903446, 54.510282799601555, 51.82038813829422, 50.25633126497269, 49.44183737039566, 52.49419458210468, 62.40358404815197, 62.69457623362541, 65.02636671066284, 65.02325847744942, 62.91302651166916, 59.17901627719402, 68.29002678394318, 45.43049521744251, 44.90166999399662, 66.53173953294754, 62.18027763068676, 64.4872896373272, 54.1971568018198, 52.9723609238863, 53.29653672873974, 54.943964928388596, 52.66869641840458, 49.907490983605385, 50.78592024743557, 48.53524021804333, 48.41500326991081, 51.78326033055782, 57.24039450287819, 58.14818099141121, 66.31463438272476, 68.83449956774712, 75.8680209517479, 76.76093503832817, 69.97240170836449, 59.84981328248978, 41.638507694005966, 37.010641023516655, 29.691785350441933, 16.27563625574112, 8.931517638266087, 6.576081030070782, 5.637339977547526, 6.392928957939148, 7.5237976759672165, 7.459380207583308, 8.197343833744526, 9.16347999125719, 11.63551714271307, 13.52085342630744, 18.6623090878129, 19.398464486002922, 14.185490012168884, 13.154658526182175, 13.521826174110174, 9.141102991998196, 9.296188820153475, 6.164223030209541, 4.2700678948313, 1.8957795482128859, 1.7294818279333413, 1.3217042153701186, 1.3939719437621534, 4.39018752425909, 4.262413680553436, 0.6509585666935891, 19.09706275910139, 56.830917075276375, 83.19284230470657, 90.88938251137733, 85.7878902554512, 62.38994657993317, 29.044963158667088, 39.348913952708244, 44.0409629791975, 68.13849851489067, 62.08697743713856, 82.71944850683212, 52.33996465802193, 83.97776618599892, 21.25599291175604, 0.8646048931404948, 0.23836625623516738, 0.5471223697531968, 0.2744899381650612, 0.2021546001196839, 0.2877746190642938, 0.19657632132293656, 0.1965720613952726, 0.13634683680720627, 0.08733135211514309, 0.1586452723131515, 0.11078849536716007, 0.10676307152607478, 0.09592635731678456, 0.15583602071274072, 0.2577701228437945, 0.15951236797263846, 0.10898868335061707, 0.1408518513198942, 0.1463517890078947], [0.016433385280834045, 0.050616100561455823, 0.049867032357724383, 0.054975557650323026, 0.04720655910205096, 0.09595998402801342, 0.058557217998895794, 0.042417480144649744, 0.022954273263167124, 0.02042807864199858, 0.18016329500824213, 0.06568562806933187, 0.032278859725920483, 0.11864697837154381, 0.145574047928676, 0.020089562822249718, 0.07261690887389705, 0.07187398194218986, 0.03736120204848703, 0.13531903648981825, 0.1142842706758529, 0.02875647842301987, 0.20436565100681037, 0.0798228733765427, 0.3451679565478116, 0.18546634091762826, 38.670137375593185, 62.55568228662014, 58.852655589580536, 43.57123598456383, 64.974195510149, 55.86581066250801, 53.77732113003731, 51.81777007877827, 20.045214481651783, 75.7363960146904, 73.79818081855774, 68.71402323246002, 54.80802342295647, 63.96835908293724, 4.754389431327581, 0.01552261794131482, 0.35419558931607753, 1.4089145231992006, 2.5750106759369373, 4.974394775927067, 5.8487767819315195, 4.371880106627941, 1.1728599085472524, 1.3818215020000935, 1.42233207821846, 1.9518305780366063, 2.7955919271335006, 2.9047130467370152, 3.2961796782910824, 6.0805795434862375, 21.728583052754402, 17.57440846413374, 2.764786030165851, 2.1051236148923635, 3.22174072265625, 3.709774659946561, 3.5348942689597607, 2.414115909487009, 2.370485938154161, 4.150350093841553, 9.708085767924786, 22.408725656569004, 34.10635806620121, 36.2340272963047, 19.99624650925398, 24.813236631453037, 44.88883428275585, 72.20031335949898, 66.8536202609539, 65.61348080635071, 54.52099062502384, 49.19601336121559, 44.05510202050209, 47.18741834163666, 49.224648624658585, 56.18569269776344, 58.292858228087425, 62.81733624637127, 63.0171637237072, 66.74373775720596, 58.898952305316925, 63.81855592131615, 44.86078418791294, 45.15972554683685, 64.11986455321312, 58.10238964855671, 65.60394331812859, 50.746531561017036, 47.963701486587524, 47.23384045064449, 49.36352737247944, 47.27820307016373, 44.06170226633549, 44.4723766297102, 43.314476162195206, 44.232655093073845, 45.56068763136864, 49.66997712850571, 49.86679136753082, 46.602416932582855, 29.91741344332695, 21.5807443857193, 27.036155350506306, 38.646221458911896, 33.999146819114685, 22.426691092550755, 26.650016270577908, 20.348512306809425, 11.512353401631117, 0.8551368105690926, 0.34311680879909545, 3.089514705352485, 3.6504493933171034, 4.946527546271682, 2.1628235187381506, 2.617106717079878, 3.825963162817061, 3.1293748039752245, 2.659282791428268, 7.298369547352195, 13.054341059178114, 16.01935900747776, 9.022958781570196, 11.657135132700205, 11.013365127146244, 8.244967628270388, 6.40153787098825, 3.6906578857451677, 1.507189362309873, 0.7333917589858174, 0.19530539342667907, 0.693845262285322, 2.081611664034426, 2.584874709136784, 0.32661708479281515, 5.502120908349752, 48.32275941967964, 65.29929086565971, 74.55927237868309, 65.05195453763008, 38.2336699962616, 15.788475796580315, 27.13125854730606, 45.665201023221016, 47.68603898584843, 50.40793552994728, 34.348663464188576, 53.5860013961792, 29.419472962617874, 1.6882028616964817, 0.26920617325231433, 0.2719010895816609, 0.08179991025826894, 0.04591773060383275, 0.03450975564192049, 0.1626170685631223, 0.1178740464092698, 0.06967043416807428, 0.05481762120325584, 0.009492934314039303, 0.0271003183661378, 0.04894701785815414, 0.057736050148378126, 0.010793361652758904, 0.08678928003064357, 0.043785436428152025, 0.04647377361834515, 0.035237873016740195, 0.016477476274303626, 0.09387037076521665, 0.010060259828605922, 0.04474379398743622, 0.0786366690590512, 0.08830915394355543, 0.08466618848615326, 0.06927586393430829, 0.05030638749303762, 0.05482764019689057, 0.08407747984165326, 0.024542625142203178, 0.045616162606165744, 0.026287518230674323, 0.03484675005893223, 0.06225189630640671, 0.06992011491092853, 0.0020231506914569763, 0.038849464181112126, 0.057293670761282556, 0.03171079391904641, 0.03588734871300403, 0.13180192443542182, 0.03732560493517667, 0.12929561751661822, 0.07121595670469105, 0.24155073770089075, 0.3526203363435343, 47.235728949308395, 79.4912101328373, 62.388058081269264, 51.75942040979862, 74.84709173440933, 36.656519025564194, 46.792786717414856, 37.60850474238396, 37.32347823679447, 85.44485986232758, 78.01735281944275, 74.84348952770233, 60.887830182909966, 66.0727621614933, 5.078321574255824, 0.4639740736456588, 3.183667240664363, 2.417264278046787, 4.406194165349007, 5.677454425022006, 7.067107781767845, 4.305349476635456, 0.8923039818182588, 1.187698943540454, 2.1819267561659217, 1.9533539400435984, 2.650977149605751, 3.0169279128313065, 1.4539197832345963, 8.552971500903368, 23.837162107229233, 21.804744265973568, 4.630052978172898, 0.7657916110474616, 3.3617228362709284, 3.5572066716849804, 3.7633790960535407, 1.617243094369769, 1.1447294242680073, 4.865349652245641, 9.080943670123816, 21.08984872698784, 34.411664083600044, 39.18394200503826, 24.638375714421272, 26.237548403441906, 53.72328422963619, 72.18151956796646, 66.87863051891327, 64.16562169790268, 58.20433437824249, 51.57845892012119, 47.39204116165638, 49.74969305098057, 52.41036728024483, 60.4890263825655, 59.853605479002, 64.9834594130516, 66.70605137944221, 68.3388389647007, 59.89455588161945, 64.47611063718796, 47.89771422743797, 46.87076613306999, 67.34752535820007, 61.25859148800373, 67.62377813458443, 53.81700240075588, 50.610981434583664, 50.084774270653725, 53.52517805993557, 52.205444276332855, 49.19446684420109, 48.03137965500355, 48.03473487496376, 49.03779365122318, 52.850357070565224, 55.206724628806114, 56.88892476260662, 58.33713345229626, 49.7148185223341, 43.522663190960884, 45.15658311545849, 50.05243040621281, 41.35259963572025, 31.271841265261173, 32.06534318625927, 23.010797649621964, 10.901238843798637, 2.050144365057349, 1.8207269255071878, 2.7947471849620342, 4.600798822939396, 5.228093862533569, 4.139594295993447, 2.021258077584207, 3.723329482600093, 6.201536078006029, 5.100998757407069, 7.797878393903375, 13.250092305243015, 12.166922427713871, 7.681401344016194, 12.8467239998281, 10.768125336617231, 9.251470919698477, 7.303395252674818, 3.9949536323547363, 1.5993144689127803, 0.8879673457704484, 0.5715789261739701, 1.9045105297118425, 3.3714697882533073, 4.6598870772868395, 0.5112707591615617, 4.486676696687937, 46.53289586305618, 72.30396419763565, 75.42213767766953, 74.6073853969574, 51.075688898563385, 19.583930633962154, 29.307916648685932, 41.4305030554533, 51.14442341029644, 58.71492438018322, 43.446800261735916, 64.74462702870369, 40.00173032283783, 2.1960976207628846, 0.0720174539310392, 0.22105658194050193, 0.09453612176002935, 0.0720967969391495, 0.04521959228441119, 0.1249791233567521, 0.03347056335769594, 0.10916123268543743, 0.04539462781394832, 0.027541512172319926, 0.04864143113081809, 0.038047091220505536, 0.023456271228496917, 0.0668856585980393, 0.10991376300808042, 0.0718886245158501, 0.061192384018795565, 0.09154511077213101, 0.0442562326497864, 0.04019707448605914, 0.12280068986001424, 0.14276092231739312, 0.1466008834540844, 0.15410062711453065, 0.17822768480982631, 0.3263741947012022, 0.09670506318798289, 0.22130640369141474, 0.1645820084377192, 0.12094354693545029, 0.22582309960853308, 0.1593625728855841, 0.1751362983486615, 0.21793767664348707, 0.24146708281477913, 0.10161540165427141, 0.19222096831072122, 0.18390661367448047, 0.16694047953933477, 0.2582994819385931, 0.29416905250400305, 0.17614670272450894, 0.2824961976148188, 0.255451564444229, 0.3530360874719918, 0.6058284477330744, 57.00949989259243, 92.49557912349701, 79.46395799517632, 59.671800434589386, 95.9199021756649, 75.65804421901703, 75.60592621564865, 65.45364618301392, 30.395988263189793, 87.55760729312897, 85.2587154507637, 82.7659960091114, 67.24488526582718, 75.306266695261, 7.847035881131887, 0.5050088139250875, 2.2096460312604904, 3.0286032613366842, 6.147502977401018, 6.0359761118888855, 10.107752121984959, 7.944612270221114, 2.6747346622869372, 1.7894177930429578, 2.9456254513934255, 5.659931190311909, 5.026305690407753, 4.972192319110036, 5.285379588603973, 16.63801711052656, 31.67701542377472, 30.071533173322678, 9.727020151913166, 5.846436582505703, 3.7256461707875133, 4.6490025613456964, 5.405791327357292, 2.7241545729339123, 5.807486297562718, 11.520780399441719, 15.669832862913609, 27.616900987923145, 40.052731186151505, 45.61314381659031, 30.68667646497488, 29.897037036716938, 54.19216766953468, 81.9235660135746, 74.29894834756851, 69.5471741259098, 64.38844934105873, 56.25815100967884, 48.93074959516525, 53.19046542048454, 56.11440472304821, 62.98675775527954, 61.82211644947529, 64.99146178364754, 68.51713299751282, 67.83860340714455, 61.291832104325294, 61.52912937104702, 47.84396231174469, 50.418787747621536, 66.56391620635986, 61.629257798194885, 70.30642658472061, 54.81584720313549, 51.54413156211376, 52.201294898986816, 54.84095625579357, 53.75549890100956, 51.41343377530575, 50.43701536953449, 49.05599847435951, 53.18967126309872, 56.93938605487347, 61.62974037230015, 62.90796898305416, 67.57263287901878, 57.91142329573631, 55.64783155918121, 48.026584312319756, 52.0323521643877, 43.91434237360954, 34.448837488889694, 34.17291909456253, 26.569443494081497, 17.28365946561098, 8.454282246530056, 7.064670212566853, 5.10794335976243, 7.305212505161762, 7.870878651738167, 7.246430609375238, 6.4787996001541615, 9.272652883082628, 14.216840229928493, 13.236696124076843, 17.15361524373293, 24.89397469907999, 22.56969641894102, 12.584810703992844, 13.963335882872343, 14.658861961215734, 9.826623257249594, 7.674799673259258, 4.6618083491921425, 1.6167633701115847, 1.2655954761430621, 0.9661059372592717, 1.4529220992699265, 7.161961141973734, 5.783095406368375, 0.7415770541410893, 5.634066928178072, 60.44264607131481, 73.3284044265747, 85.9691633284092, 74.2089007794857, 54.43583719432354, 15.331965442746878, 35.605142042040825, 62.25810885429382, 62.59402222931385, 68.7062868475914, 55.58117933571339, 71.58209413290024, 56.733984276652336, 1.8446407048031688, 0.27287778561003506, 0.3661268897121772, 0.44232488377019763, 0.21131875837454572, 0.13499495544238016, 0.27510007261298597, 0.2569984080037102, 0.13508503732737154, 0.08823131749522872, 0.11142733608721755, 0.11052336310967803, 0.11567256922717206, 0.14136154350126162, 0.1466692055691965, 0.2482929712277837, 0.16313335101585835, 0.13663508696481586, 0.15003508277004585, 0.2913119026925415, 0.13284072338137776], [0.10864593728911132, 0.08814398155664094, 0.03144720903947018, 0.0597377782833064, 0.05163188550795894, 0.038193832369870506, 0.025479857467871625, 0.10190526969381608, 0.030428624340856913, 0.07940871044411324, 0.01799763962480938, 0.1178281223110389, 0.010264071206620429, 0.0531778310687514, 0.026821267128980253, 0.029582878414657898, 0.02535677413106896, 0.04656670535041485, 0.06648050533840433, 0.03747873968677595, 0.0934120945748873, 0.02797944423946319, 0.10276581218931824, 0.10994160096743144, 0.1239699509460479, 0.1455682740197517, 3.705225116573274, 77.35346764326096, 55.51629401743412, 53.48868101835251, 58.57133388519287, 69.09676909446716, 34.49027806520462, 64.97108727693558, 15.066315047442913, 47.34335817396641, 79.43533033132553, 63.74387092888355, 74.44795355200768, 62.16970659792423, 5.214666333049536, 0.34827693190891296, 1.0862757358700037, 0.662639377405867, 2.2944109328091145, 1.062403516843915, 0.7452253927476704, 0.41654718574136496, 1.0426696320064366, 1.6805919888429344, 1.9591115810908377, 4.8309410735964775, 4.639251809567213, 2.6986045064404607, 4.114615861326456, 4.062162525951862, 16.1463500931859, 11.946622598916292, 2.574880770407617, 2.714313338510692, 5.369520373642445, 5.840611970052123, 4.470349447801709, 3.106281068176031, 1.2468925234861672, 1.4214821113273501, 4.30541692301631, 11.925554629415274, 20.745893083512783, 26.766797304153442, 16.191047094762325, 16.550606600940228, 12.689415290951729, 45.2920838445425, 64.63566407561302, 65.40396764874458, 61.36120118200779, 54.13353681564331, 47.53025874495506, 44.27512161433697, 50.0907551497221, 55.858739241957664, 59.06448282301426, 62.57135644555092, 63.27202744781971, 64.14390206336975, 59.86397132277489, 63.45554620027542, 43.025003895163536, 45.46913154423237, 65.0523193180561, 59.470977410674095, 60.34476712346077, 50.60610629618168, 46.84395857155323, 46.71961024403572, 49.19741168618202, 46.93749435245991, 45.96622087061405, 44.77081261575222, 45.30324384570122, 45.27645908296108, 47.364390045404434, 49.45194102823734, 51.5451917052269, 39.8616698384285, 22.365463078022003, 8.853467926383018, 16.748359389603138, 26.977395303547382, 21.58693615347147, 24.459884092211723, 28.362819962203503, 17.662765122950077, 7.626445842906833, 1.4531626738607883, 1.8640981544740498, 4.723646705970168, 4.402166856452823, 6.430630059912801, 2.26368126925081, 3.552519860677421, 4.625690812245011, 4.126288834959269, 4.563597394153476, 8.25655510649085, 9.130772296339273, 16.690843775868416, 17.26012732833624, 14.387545119971037, 12.00734619051218, 11.775828413665295, 7.549949772655964, 5.032862713560462, 3.1989884935319424, 1.421353630721569, 1.2443436915054917, 0.643460025312379, 2.647836855612695, 3.047656388953328, 0.8619754342362285, 1.3012706930749118, 36.12487435340881, 66.13351330161095, 70.10509818792343, 59.86256159842014, 20.77778097242117, 23.731396682560444, 43.92095781862736, 39.219781681895256, 46.72416999936104, 30.223407223820686, 48.63300897181034, 56.39157325029373, 4.80782026425004, 1.152581584174186, 0.07688609111937694, 0.5116952676326036, 0.049204480019398034, 0.1504482512245886, 0.06405570849892683, 0.10320055487682112, 0.07738228363450617, 0.057656796197989024, 0.024296157898788806, 0.06693739371257834, 0.04088868932740297, 0.01196472116134828, 0.02255963994684862, 0.03273514324973803, 0.06229967577382922, 0.07410270336549729, 0.02446105754643213, 0.05368656959035434, 0.07285046274773777, 0.04321106607676484, 0.07061130672809668, 0.012178089546068804, 0.020047293801326305, 0.06168535561300814, 0.012549344282888342, 0.015024664680822752, 0.12192981666885316, 0.11810644253273495, 0.05370838873204775, 0.01979007283807732, 0.05412095233623404, 0.07442484740749933, 0.03836560244963039, 0.0283621252674493, 0.012692718864855124, 0.03401924797799438, 0.053776328641106375, 0.010835618613782572, 0.10064070200314745, 0.0413593630946707, 0.027055336795456242, 0.041153736237902194, 0.08666761976201087, 0.17161123047117144, 0.37703340291045606, 0.369587613386102, 7.4746824614703655, 87.6339527964592, 69.73915502429008, 53.2527706772089, 69.1043458878994, 53.42142842710018, 30.604403279721737, 56.50629669427872, 16.818691715598106, 73.25523555278778, 79.82833564281464, 72.59678408503532, 72.56019204854965, 68.85893225669861, 5.413266476243734, 1.8834780645556748, 3.269983883947134, 2.8048534551635385, 3.001480079255998, 1.8099378794431686, 0.36856763530522585, 0.4010354384081438, 1.3339635450392962, 2.8013056330382824, 3.393231458030641, 5.441156504675746, 5.3447015304118395, 4.05750397592783, 2.2099181916564703, 6.859094118699431, 18.36339622735977, 13.740085512399673, 4.5359657518565655, 1.1126424022950232, 4.123709723353386, 5.527998944744468, 4.5221202448010445, 1.7184298834763467, 1.051450960803777, 3.338529118336737, 4.73293530754745, 12.355620302259922, 22.408168986439705, 28.60853187739849, 18.30677356570959, 19.698547683656216, 24.98373158276081, 55.44095925986767, 67.31302320957184, 65.6784725189209, 62.82622776925564, 55.51654100418091, 48.483718782663345, 46.85686647891998, 54.859567657113075, 59.19645354151726, 60.70453941822052, 67.91765436530113, 66.91130116581917, 67.86410003900528, 61.866524666547775, 66.05161249637604, 45.00983498990536, 48.12816046178341, 66.97765320539474, 64.02360811829567, 65.72773307561874, 54.27516661584377, 51.3860372453928, 49.155112355947495, 51.85113228857517, 49.559099078178406, 49.30129811167717, 47.80930817127228, 49.34675507247448, 49.61270660161972, 52.08754040300846, 55.53310051560402, 60.65914325416088, 53.27397733926773, 40.92257671058178, 20.858693830668926, 15.259410236030817, 33.092063292860985, 28.118481673300266, 30.21466389298439, 31.069726310670376, 19.24656953662634, 8.66268016397953, 2.6869704807177186, 1.20540824951604, 4.163071811199188, 4.729086114093661, 6.557876206934452, 6.784263784065843, 2.5737676676362753, 2.545766495168209, 6.482112547382712, 7.32704708352685, 8.326622396707535, 9.903781916946173, 16.064762771129608, 13.653378915041685, 13.550442438572645, 14.402408972382545, 12.542735561728477, 8.460037987679243, 5.642679166048765, 3.950128387659788, 2.517087534070015, 2.509197019971907, 3.7567213783040643, 4.968180684372783, 7.438460905104876, 2.02562736812979, 0.48619747802149504, 33.898646011948586, 70.24076610803604, 76.61082789301872, 66.98143020272255, 28.95687248557806, 20.515539944171906, 39.97646927833557, 43.132089748978615, 52.43703804910183, 36.569344103336334, 55.5735569447279, 68.28915283083916, 6.300392998382449, 0.7681707583833486, 0.06031882054230664, 0.44977530429605395, 0.03349123217049055, 0.13763789174845442, 0.09667177044320852, 0.05815132630232256, 0.026183908848906867, 0.057230402671848424, 0.07889809057815, 0.04445248989213724, 0.08685116030392237, 0.0138550482915889, 0.054763151274528354, 0.0679444732668344, 0.06580616769497283, 0.0741629434924107, 0.018201062302978244, 0.019076906028203666, 0.03692533129651565, 0.04064828171976842, 0.14210486377123743, 0.16259425494354218, 0.1253545461804606, 0.185470511787571, 0.25315782346297055, 0.23772649525199085, 0.16373780061258003, 0.23325683665461838, 0.12744314270094037, 0.19370472931768745, 0.24547959328629076, 0.18258542753756046, 0.11409514918341301, 0.07831138573237695, 0.05229502414294984, 0.17411617183825, 0.13449513382511213, 0.15965230733854696, 0.32345877145417035, 0.12142298917751759, 0.151449631084688, 0.22373802086804062, 0.3760954469908029, 0.29852676554583013, 0.46847341815009713, 0.45795605750754476, 11.502291541546583, 104.37192544341087, 78.46635192632675, 65.60670956969261, 74.09135788679123, 92.17039257287979, 50.30815668404102, 88.00295099616051, 19.734288565814495, 63.559653013944626, 87.15767115354538, 80.45093223452568, 81.5664991736412, 76.93788394331932, 8.224178943783045, 2.379742953926325, 5.483116703107953, 2.8043333580717444, 4.236103417351842, 3.0704178800806403, 1.2755326554179192, 2.987460494041443, 2.6434338418766856, 2.798617514781654, 3.340527336113155, 7.637542197480798, 8.233016319572926, 5.495077036321163, 5.028818780556321, 15.53761325776577, 25.73567133396864, 22.76975568383932, 9.427585769444704, 3.4019037801772356, 5.308378329500556, 8.920963704586029, 5.023922743275762, 3.5723604960367084, 7.713727159425616, 9.557527396827936, 8.891698624938726, 17.37277988344431, 28.244878090918064, 32.30236306786537, 20.833069905638695, 20.646631009876728, 26.674485057592392, 58.2609361410141, 71.83398261666298, 69.58140268921852, 66.30161628127098, 60.69777958095074, 53.95260192453861, 49.472729712724686, 57.061572298407555, 61.48512773215771, 62.55923129618168, 67.98040419816971, 67.68698394298553, 66.9881634414196, 60.21612502634525, 66.58983081579208, 45.69068245589733, 50.471236333251, 66.7774647474289, 63.734603226184845, 63.82268249988556, 56.35452143847942, 50.79648368060589, 49.15199652314186, 52.14908950030804, 49.85755406320095, 50.970274955034256, 48.80046598613262, 52.43341684341431, 53.81663382053375, 55.99188409745693, 59.3989484757185, 67.59289339184761, 62.109373435378075, 57.12508209049702, 35.9982081502676, 23.31245396286249, 38.44264358282089, 31.848861202597618, 38.0624245852232, 33.37031476199627, 24.704104587435722, 13.481670878827572, 9.772087633609772, 7.912836000323296, 8.083053566515446, 9.490126613527536, 10.311766024678946, 8.428381886333227, 7.442927565425634, 6.336867241188884, 14.79503620415926, 16.706937812268734, 19.39342025667429, 20.280226171016693, 27.402349300682545, 24.218116365373135, 18.60362883657217, 15.557644832879305, 16.021625585854053, 10.911504942923784, 7.016419926658273, 4.427603641524911, 2.024209094233811, 2.1177823981270194, 4.165637623518705, 7.020278619602323, 7.768713533878326, 2.2594309598207474, 1.602492998354137, 41.39626309275627, 78.90783503651619, 76.47168695926666, 71.84361129999161, 27.985238023102283, 25.382575280964375, 58.769740238785744, 54.744935408234596, 65.01027837395668, 46.5895926207304, 65.6221367418766, 85.23914650082588, 11.413504555821419, 1.4572731032967567, 0.26748290634714067, 0.6165656028315425, 0.19338498241268098, 0.26825049484614283, 0.2331001841230318, 0.1850753033068031, 0.13720898976316676, 0.13944766338681802, 0.11799847488873638, 0.20601977943442762, 0.21670036803698167, 0.10233133667497896, 0.130161288252566, 0.1562208984978497, 0.20423927810043097, 0.258321983856149, 0.1537736368482001, 0.1348896892159246, 0.15140335075557232, 0.21564227325143293], [0.05363984026189428, 0.055308960072579794, 0.05774087039753795, 0.08848972589476034, 0.04551399855699856, 0.04232790663081687, 0.02182861149776727, 0.017466130157117732, 0.016323480631399434, 0.037066795775899664, 0.013735135780734709, 0.033837588780443184, 0.020309114224801306, 0.016946658324741293, 0.021020360727561638, 0.08896763931261376, 0.021303868561517447, 0.1367200628737919, 0.04783349948411342, 0.14253177680075169, 0.08428168919635937, 0.13201861671404913, 0.05299113268847577, 0.16577521862927824, 0.06729862667270936, 0.8081640279851854, 0.24628906860016286, 37.13628888130188, 79.6099841594696, 43.41786861419678, 50.47331102192402, 75.64390897750854, 46.40147611498833, 34.73991706967354, 49.44954335689545, 18.423320911824703, 69.73545402288437, 59.12962272763252, 67.13254049420357, 50.977160185575485, 1.9748042640276253, 0.9742014622315764, 5.159325152635574, 0.3297173324972391, 1.2670249119400978, 0.15305587614420801, 0.20898265560390428, 1.102653332054615, 2.9461700096726418, 4.107818976044655, 5.184533949941397, 5.436214869841933, 5.960061410441995, 4.223303804174066, 6.07720484957099, 3.490529037080705, 11.579962223768234, 9.328755922615528, 2.5772402063012123, 3.6480635963380337, 5.982887260615826, 6.728517450392246, 6.542146475985646, 5.255743553861976, 2.8057516319677234, 0.525893383892253, 1.8965197959914804, 4.9663278087973595, 9.989364724606276, 12.744509484618902, 9.962792750447989, 9.741990398615599, 7.4473172798752785, 24.1041661798954, 57.721099108457565, 65.80689802765846, 63.624051958322525, 58.98318998515606, 52.48387053608894, 46.35665372014046, 50.56937746703625, 59.129512533545494, 59.495296105742455, 66.01272538304329, 62.24966570734978, 66.06213793158531, 58.13998483121395, 62.26918525993824, 40.17395608127117, 45.95492787659168, 66.54896780848503, 61.00421033799648, 58.48179928958416, 48.63413751125336, 49.925764203071594, 47.60186590254307, 47.92306646704674, 48.30615811049938, 46.1420526355505, 46.25778682529926, 46.947594210505486, 48.121142238378525, 52.99177028238773, 56.99859067797661, 55.7462652772665, 42.71948888897896, 22.230232134461403, 13.044049311429262, 20.93000080436468, 28.373259902000427, 26.85279618948698, 29.365439862012863, 29.021231532096863, 16.684368923306465, 6.176018547266722, 5.3506382368505, 3.0254439683631063, 4.728596890345216, 6.614625686779618, 5.917003070935607, 2.561398381367326, 3.1262185983359814, 3.7667127046734095, 3.519437648355961, 6.815799716860056, 7.969250623136759, 9.990921691060066, 10.034470204263926, 16.703694686293602, 15.536701306700706, 16.10038585960865, 13.452773429453373, 12.90240241214633, 5.247867526486516, 4.571993043646216, 1.5672285156324506, 0.9728477254975587, 4.642284046858549, 3.8062597950920463, 3.289554021321237, 3.380539664067328, 0.24123471637722105, 23.55535212904215, 66.03183075785637, 67.83587515354156, 52.320574298501015, 16.400622949004173, 34.71475102007389, 31.422240994870663, 48.787451684474945, 41.34825646877289, 38.65125998854637, 55.98255939781666, 12.484722174704075, 1.0845356667414308, 0.2131221178569831, 0.10522730080992915, 0.04852090263739228, 0.03286318598838989, 0.048959578707581386, 0.032221666115219705, 0.047128036167123355, 0.11124548022053204, 0.13979636889416724, 0.059457513634697534, 0.020894158515147865, 0.0358123287151102, 0.038221751965465955, 0.11293405172182247, 0.07611987559357658, 0.04498765258176718, 0.07054987174342386, 0.01374405454043881, 0.10713395982747898, 0.06687438537483104, 0.0597588033269858, 0.022308233710646164, 0.04885129936155863, 0.04403571831062436, 0.16499485034728423, 0.05415020408690907, 0.06346523354295641, 0.08309794138767757, 0.0526691296545323, 0.05316275804943871, 0.09767433773959056, 0.011557972284208518, 0.06522067997138947, 0.0498732923733769, 0.05552379698201548, 0.018172536001657136, 0.0634580866608303, 0.039232386407093145, 0.1407598695368506, 0.046758561657043174, 0.08871378769981675, 0.031892356637399644, 0.08395371929509565, 0.07241733794216998, 0.150061518070288, 0.14661360386526212, 0.6222304457332939, 0.42526887555141, 49.9358032643795, 92.01295182108879, 49.80573624372482, 57.52554640173912, 79.86381813883781, 35.83241164684296, 37.669677659869194, 33.05641360580921, 35.48911526799202, 82.06004709005356, 67.33256176114082, 73.0012495815754, 51.0998860001564, 2.4074152065441012, 2.171592260710895, 6.5800803154706955, 2.583031333051622, 2.940561748109758, 0.7348544429987669, 0.4514582874253392, 1.3101707655005157, 4.35993212275207, 3.512754994444549, 6.16414655931294, 7.916604923084378, 6.2285958509892225, 5.319220572710037, 4.457153705880046, 5.404290882870555, 15.329415779560804, 11.871072202920914, 6.811895901337266, 1.9899168843403459, 4.444364542141557, 6.929950816556811, 6.216340083628893, 4.236307656392455, 2.720812652260065, 1.8697351519949734, 1.9495654245838523, 5.736042056232691, 8.959180153906345, 14.858579244464636, 11.719313096255064, 12.099484596401453, 6.591074075549841, 36.3445595651865, 62.981221452355385, 65.28762549161911, 65.11957570910454, 62.86752015352249, 54.55317109823227, 49.23290178179741, 52.59279169142246, 61.33866839110851, 62.48176485300064, 70.09729340672493, 66.30333378911018, 69.04790371656418, 62.07174405455589, 63.60039822757244, 42.837848737835884, 47.45341166853905, 70.01482263207436, 64.33540418744087, 64.51865315437317, 51.9318475574255, 53.051978051662445, 48.88788789510727, 50.44322423636913, 50.6222440302372, 49.76609297096729, 50.720529556274414, 50.73319807648659, 50.1929734647274, 55.39946548640728, 62.00277395546436, 61.857032775878906, 52.25588656961918, 40.002326890826225, 14.876711871474981, 18.935748115181923, 32.649121060967445, 30.871707536280155, 32.39123649895191, 31.86627946794033, 18.122781738638878, 8.181664925068617, 2.9457700811326504, 3.22209766600281, 4.722299203276634, 7.202527290210128, 6.210081819444895, 6.902225604280829, 2.9825361957773566, 2.880043345503509, 4.749095365405083, 8.081696089357138, 9.787477757781744, 12.142064161598682, 10.527990572154522, 14.647722858935595, 15.802760180085897, 16.203138045966625, 14.794197399169207, 12.597694862633944, 6.959306616336107, 4.70461780205369, 2.92803097050637, 2.06525354180485, 5.024834219366312, 8.006118144840002, 7.586098657920957, 4.651988726109266, 0.33615754160564393, 22.35752910375595, 74.78773891925812, 72.23810613155365, 64.59586501121521, 17.96460572630167, 33.62706698477268, 37.01312229037285, 48.89065034687519, 46.920486465096474, 42.69848361611366, 68.72011050581932, 16.262399666011333, 0.5017042974941432, 0.10570345533778891, 0.08723652048502117, 0.06756104266969487, 0.056824952553142793, 0.04559239161608275, 0.03580240620067343, 0.07081078860210255, 0.08132499511702918, 0.05710704288503621, 0.03119271175819449, 0.06767513303202577, 0.05301439901813865, 0.02684255192434648, 0.0486360505601624, 0.024812872652546503, 0.05311113425705116, 0.06985485786572099, 0.06039026709913742, 0.041248022389481775, 0.026611341381794773, 0.07140403176890686, 0.12692078948020935, 0.20560683362418786, 0.08850937796523795, 0.24578785174526274, 0.1637146604480222, 0.26660794392228127, 0.1521506637800485, 0.13589938113000244, 0.15862694126553833, 0.14940131834009662, 0.06117220502346754, 0.1832795434165746, 0.18124056688975543, 0.21660080150468275, 0.16525945567991585, 0.23002347734291106, 0.09462301983148791, 0.2837467164499685, 0.16652073565637693, 0.3618589468533173, 0.18925151671282947, 0.20776580058736727, 0.18585918936878443, 0.21115777170052752, 0.2445670633460395, 0.6817524111829698, 0.6637071794830263, 64.81828987598419, 103.39502066373825, 65.26378557085991, 66.73608496785164, 99.76085007190704, 62.02665567398071, 55.37677310407162, 61.98203846812248, 33.74626278877258, 79.64823290705681, 74.64242711663246, 82.2575680911541, 62.46542952954769, 2.959002871066332, 3.1686361972242594, 15.069561023265123, 1.4897992392070591, 2.673935992643237, 0.9451709606219083, 0.9901073493529111, 1.919563659466803, 5.467972615733743, 3.2053963746875525, 6.732597006484866, 7.711082026362419, 8.045085053890944, 6.6278822254389524, 7.085132589563727, 14.068009816110134, 22.49056376516819, 18.22434078902006, 12.089244145900011, 3.8134924694895744, 8.546399753540754, 8.035706207156181, 8.975901156663895, 6.972309518605471, 6.858214465901256, 7.2914838418364525, 8.112853467464447, 11.851388309150934, 14.20970231294632, 17.32604619115591, 12.37139230594039, 12.38444460555911, 8.378148581832647, 39.74565826356411, 70.46835869550705, 69.0802551805973, 71.80386543273926, 68.69156643748283, 60.945343896746635, 53.80951680243015, 56.2660925835371, 64.15432870388031, 64.74949076771736, 71.6607803106308, 66.32337391376495, 68.63265439867973, 60.89878499507904, 64.12278279662132, 44.425502344965935, 50.711208656430244, 67.79462456703186, 66.1493356525898, 65.03769770264626, 52.501699179410934, 53.99417169392109, 51.94776490330696, 53.39109845459461, 51.13170929253101, 51.581323966383934, 52.355038449168205, 52.28859521448612, 54.4864808768034, 61.08895719051361, 66.6228586435318, 67.25221127271652, 61.6486519575119, 58.01459915935993, 34.12397392094135, 27.620037719607353, 39.62081976234913, 35.20194947719574, 39.85338248312473, 35.83473712205887, 24.919060952961445, 15.095419585704803, 12.228656765073538, 9.586441945284605, 9.219632428139448, 13.124319054186344, 11.939094252884388, 10.693238954991102, 7.172132721170783, 6.252449546009302, 10.520499274134636, 19.57637093961239, 18.766414001584053, 21.87557816505432, 20.78251361846924, 26.04146372526884, 23.21557816118002, 21.501189954578876, 16.821068488061428, 16.148945353925228, 8.210618421435356, 4.703163905069232, 3.1276100361719728, 3.486953666433692, 7.481991844251752, 13.30999894067645, 12.34601916745305, 7.278221603482962, 0.4625664569903165, 27.472166754305363, 80.68523526191711, 74.32958990335464, 71.08230695128441, 18.387367241084576, 48.17876234650612, 47.54792779684067, 65.37188977003098, 63.56319822371006, 55.01978226006031, 85.61831295490265, 35.09913459420204, 1.0635534301400185, 0.2907306526321918, 0.238680214388296, 0.17600472987396643, 0.13370658707572147, 0.14870760322082788, 0.21479843650013208, 0.16081313020549715, 0.18335761735215783, 0.21062701736809686, 0.11059641270549037, 0.1737994677387178, 0.18058125773677602, 0.09937554059433751, 0.1715201689512469, 0.12964288325747475, 0.198221514292527, 0.2114117643213831, 0.14881138515193015, 0.19879434839822352, 0.10361410182667896, 0.2434984003775753], [0.043541566701605916, 0.16514896473381668, 0.08190849388483912, 0.008841318449412938, 0.030857116289553232, 0.025002170405059587, 0.08201047239708714, 0.061926360649522394, 0.04507531877607107, 0.019414082271396182, 0.021353336414904334, 0.056819122983142734, 0.016131162337842397, 0.054589603751082905, 0.03488549016765319, 0.03378323759534396, 0.06381672210409306, 0.03779723236220889, 0.024475167629134376, 0.06809342972701415, 0.055662793820374645, 0.06413356721168384, 0.090853978326777, 0.05550060115638189, 0.08927652117563412, 0.3791352245025337, 0.4557272989768535, 4.3147126492112875, 71.81958138942719, 50.50396777689457, 48.07812474668026, 58.378927409648895, 56.02895870804787, 27.645663544535637, 36.783192828297615, 16.564386561512947, 45.202705040574074, 53.32142539322376, 74.25734058022499, 48.01645785570145, 1.1667617107741535, 3.0611036298796535, 1.766667701303959, 4.176411470398307, 0.5699542164802551, 1.2518313084729016, 0.7555592944845557, 1.6645206324756145, 3.139462787657976, 8.125296849757433, 6.546372324228287, 8.391105886548758, 7.7070580422878265, 7.172328410670161, 5.198530498892069, 3.8875756692141294, 5.380961084738374, 10.382288340479136, 0.6526314269285649, 4.542459128424525, 6.254209326580167, 8.227839097380638, 8.117324877530336, 5.1890267338603735, 3.468607538379729, 2.2540756221860647, 2.9051125003024936, 1.7787987878546119, 2.406022106297314, 2.59557849727571, 3.0264834500849247, 4.304054696112871, 3.0526419589295983, 17.523405700922012, 47.04397223889828, 65.90201452374458, 67.28618904948235, 61.21394768357277, 57.50676780939102, 49.79509301483631, 49.195261001586914, 56.10545240342617, 62.1803992241621, 63.21084313094616, 62.6224485039711, 62.39244684576988, 57.55464904010296, 60.92184975743294, 37.54252128303051, 38.59638713300228, 68.10530349612236, 56.14262580871582, 58.91862004995346, 46.54692471027374, 48.94701272249222, 45.94150699675083, 48.56243535876274, 47.922644689679146, 47.687520906329155, 46.39078348875046, 47.9443871229887, 55.279562920331955, 60.46528525650501, 61.21134102344513, 54.57818515598774, 46.81833274662495, 24.956373050808907, 13.056654185056686, 22.924756966531277, 33.88799898326397, 34.46482703089714, 30.472804941236973, 29.720378816127777, 14.116814397275448, 5.239812433719635, 3.13469166867435, 3.847721270285547, 6.047589713707566, 8.21244042366743, 8.583245426416397, 3.673708657734096, 2.990721194073558, 4.230929519981146, 2.3501066816970706, 5.552569851279259, 6.360705262050033, 10.092998463660479, 11.402380652725697, 11.932527255266905, 17.030473351478577, 16.14126406610012, 17.221699990332127, 13.339254520833492, 7.703348966315389, 7.102209823206067, 7.066390095278621, 3.3238811418414116, 5.90496389195323, 7.033347068354487, 8.358220551162958, 4.264699732884765, 0.582806789316237, 14.784427173435688, 54.850957319140434, 72.00831726193428, 36.425282433629036, 25.324119217693806, 30.692552849650383, 37.94840790331364, 59.78678986430168, 30.081144757568836, 50.13383723795414, 20.762443095445633, 1.0396866733208299, 0.05776950987637974, 0.04405483603477478, 0.04543309332802892, 0.05616884576738812, 0.06882629313622601, 0.08136437347275205, 0.06577552441740409, 0.030655489608761854, 0.07012548201601021, 0.009416833563591354, 0.054519337209057994, 0.06478198163677007, 0.029260706542117987, 0.09980623115552589, 0.03178632970957551, 0.010243603701383108, 0.0733300088904798, 0.12273326574359089, 0.041827580353128724, 0.045666884689126164, 0.05412833299487829, 0.06340980995446444, 0.05643351047183387, 0.03622512609581463, 0.0731257550069131, 0.10415886048576795, 0.042954765376634896, 0.008755772942095064, 0.03740292930160649, 0.05991634643578436, 0.020921623545291368, 0.01551029272377491, 0.03835591742245015, 0.13121798780048266, 0.05983053932141047, 0.06000987930747215, 0.07407405646517873, 0.060750119664589874, 0.01674412993452279, 0.05064262491941918, 0.010366176811658079, 0.05906680256885011, 0.07182347137131728, 0.07813154850737192, 0.024902520381147042, 0.02858111634850502, 0.11301441147224978, 0.3264756314456463, 0.28382695745676756, 6.85902239754796, 86.68994665145874, 62.0410531014204, 52.53066122531891, 72.01263383030891, 50.49193002283573, 28.579396940767765, 41.25141866505146, 23.328432105481625, 58.31876903772354, 57.83493719995022, 79.94944274425507, 49.11509670317173, 1.2196623533964157, 4.272140683606267, 5.766002023592591, 7.329395357519388, 2.1008633309975266, 2.704041302204132, 2.60136891156435, 2.5735643785446882, 4.3146423529833555, 7.787894904613495, 6.900559393689036, 10.436876211315393, 7.867082180455327, 8.71118076145649, 5.45414705760777, 8.898919187486172, 9.740384984761477, 12.41334680467844, 4.817801853641868, 2.5282874330878258, 6.271378230303526, 7.93107739649713, 6.817221315577626, 3.92425533849746, 1.7843638267368078, 0.8810587821062654, 0.8744009456131607, 2.907858327962458, 3.6229469440877438, 3.846706012263894, 4.104011580348015, 6.0421631298959255, 8.283888939768076, 22.163135334849358, 54.734995141625404, 66.4151693880558, 68.05924996733665, 64.46708992123604, 59.2404817789793, 51.66844569146633, 50.75599305331707, 58.99544432759285, 64.4954364001751, 68.3295750617981, 65.7720310986042, 67.54877015948296, 63.10665652155876, 65.23480072617531, 40.13417221605778, 42.56821520626545, 71.17195174098015, 61.88899286091328, 63.74235861003399, 50.81704057753086, 53.86087104678154, 49.678310081362724, 52.480184733867645, 51.32336340844631, 51.47521086037159, 51.53043329715729, 52.52378739416599, 59.380439668893814, 65.01671522855759, 66.85286030173302, 63.65913927555084, 55.88560000061989, 41.891680508852005, 17.35781818628311, 25.05777820944786, 38.646092265844345, 40.3811551630497, 34.44684639573097, 31.840247064828873, 15.689161475747824, 6.527611305937171, 2.7643153304234147, 2.4983117915689945, 4.472424136474729, 5.9305094461888075, 6.523625794798136, 6.453877212479711, 4.019942991435528, 3.6855704337358475, 4.292178908362985, 8.323523662984371, 8.984688185155392, 10.47578327357769, 12.031243108212948, 12.847433611750603, 17.23534505814314, 17.149484865367413, 15.912359599024057, 13.640609700232744, 8.61176859587431, 8.456474728882313, 4.290680838748813, 2.876044772565365, 5.591699201613665, 6.114421002566814, 7.924837656319141, 5.940056433901191, 0.26324123551603407, 13.565044105052948, 61.400050297379494, 74.8408904671669, 57.247097343206406, 26.664710082113743, 35.135008469223976, 38.191100880503654, 64.13732841610909, 34.83124516904354, 56.8943090736866, 29.886690191924572, 1.9785406510345638, 0.054954499209998176, 0.09448053489904851, 0.11728095167200081, 0.02236409516626736, 0.06047948067134712, 0.0474351071898127, 0.020848280801146757, 0.019704696169355884, 0.024996611718961503, 0.057603365276008844, 0.04166379207163118, 0.045797788407071494, 0.07037207542452961, 0.09516988618997857, 0.06447393097914755, 0.04695846284448635, 0.053409863539854996, 0.06599797576200217, 0.04833418941416312, 0.09229667630279437, 0.0294092529657064, 0.08060226944508031, 0.16569184575928375, 0.208494441176299, 0.2342245972249657, 0.1930647308472544, 0.10138787401956506, 0.17372581700328737, 0.132559152552858, 0.1223112954176031, 0.1520360613358207, 0.1742369934800081, 0.1317375950748101, 0.19292301032692194, 0.1501449354691431, 0.18844063131837174, 0.17367772583384067, 0.17365880106808618, 0.12934075493831187, 0.1707944821100682, 0.1137398682476487, 0.16894736560061574, 0.1655384141486138, 0.3023452340858057, 0.18446116126142442, 0.10724569016019814, 0.33091878052800894, 0.4498405836056918, 0.3444802825106308, 10.430535301566124, 108.29826235771179, 72.0949374139309, 67.85384818911552, 77.9581367969513, 81.11435383558273, 41.93754404783249, 53.7244925647974, 26.958635710179806, 58.64845834672451, 65.27382463216782, 91.5217749774456, 58.772202506661415, 2.529479144141078, 9.699140097945929, 8.558842185884714, 11.56933419406414, 1.9535577041096985, 2.35396062489599, 2.1796285919845104, 3.7587882298976183, 3.5553435841575265, 8.703470025211573, 7.162665529176593, 10.00488594174385, 8.9464071393013, 9.722629487514496, 9.05946722254157, 14.639371857047081, 16.370733752846718, 17.90507812052965, 11.013941746205091, 5.925236279144883, 10.506680365651846, 12.73540137335658, 11.783170569688082, 7.952038496732712, 7.88023279979825, 7.45392607524991, 6.133837485685945, 5.222017988562584, 5.902497824281454, 4.14346438832581, 3.9006479177623987, 6.703664883971214, 11.767539158463478, 25.56483630090952, 58.063916712999344, 71.67581230401993, 69.19388428330421, 66.96734815835953, 63.68510328233242, 53.47394920885563, 52.85641774535179, 61.07140213251114, 66.9695596396923, 67.65030071139336, 67.83921137452126, 64.31554645299911, 63.664569184184074, 64.40089747309685, 41.8596900254488, 43.80252577364445, 71.97581380605698, 62.695324793457985, 66.15860715508461, 50.313860177993774, 53.57629291713238, 49.389943554997444, 54.10278506577015, 51.97157442569733, 52.769949585199356, 52.05125615000725, 55.96856474876404, 61.4493602514267, 69.23478528857231, 70.66555291414261, 67.16816738247871, 66.28545954823494, 58.508557453751564, 37.807978838682175, 36.603998243808746, 45.289127603173256, 44.715635776519775, 38.09436187148094, 36.1906374245882, 21.174232698976994, 15.591532364487648, 8.054520897567272, 8.171944096684456, 10.946563761681318, 14.82750166207552, 15.716785993427038, 14.189739134162664, 9.520446136593819, 7.853964809328318, 9.739304892718792, 19.53752562403679, 18.370568342506886, 22.92939841747284, 22.91580844670534, 24.396247006952763, 26.31645116955042, 25.595274567604065, 22.75406252592802, 18.925766050815582, 11.829618327319622, 14.63377095758915, 11.924721524119377, 7.945801131427288, 8.16333755850792, 14.115912895649672, 19.480678774416447, 13.371673431247473, 0.5729001865256578, 18.593504279851913, 67.92314127087593, 84.79742780327797, 50.90817108750343, 29.140651524066925, 48.93228091299534, 52.617326974868774, 86.64001733064651, 45.03881223499775, 77.01370507478714, 56.79833382368088, 3.284715455956757, 0.39388149103615433, 0.16499737364938483, 0.36516675841994584, 0.19600175059167668, 0.23132355679990724, 0.2102466073120013, 0.23399675788823515, 0.15426055993884802, 0.21042294159997255, 0.17536633444251493, 0.13430297694867477, 0.13101314019877464, 0.11309621841064654, 0.19847504678182304, 0.21129541040863842, 0.12838028225814924, 0.2004781924188137, 0.22843440558062866, 0.22818721103249118, 0.1452299882657826, 0.24511196301318705, 0.3028622141573578], [0.019407547661103308, 0.060981907226960175, 0.04703490776591934, 0.07909817359177396, 0.06422030201065354, 0.01097748478059657, 0.04434569855220616, 0.03659643742139451, 0.01590152514836518, 0.01497602803283371, 0.0193024669715669, 0.08484935053274967, 0.0764947195420973, 0.1099246800004039, 0.051017891892115586, 0.0796554893895518, 0.03357961824804079, 0.025579650355211925, 0.01666143798502162, 0.01901456191262696, 0.03207390080206096, 0.009720997222757433, 0.13409137580310926, 0.027953682438237593, 0.05979011082672514, 0.031594228494213894, 0.46724644023925066, 0.7705794728826731, 35.4094335436821, 78.46914857625961, 42.53536976873875, 60.596762001514435, 61.74237012863159, 39.25439402461052, 26.119739525020123, 26.167599856853485, 34.258520901203156, 66.87484592199326, 80.98425641655922, 39.49082873761654, 0.0620425290253479, 2.1513436222448945, 2.283633998595178, 10.212549548596144, 1.7258797399699688, 1.2461706809699535, 1.5671240212395787, 3.134197457693517, 5.949102798476815, 9.419634696096182, 12.125299461185932, 13.357205707579851, 10.30263226479292, 10.565768145024776, 7.275563646107912, 7.273687021806836, 3.2209909753873944, 7.636163821443915, 2.7026786003261805, 4.811395397409797, 6.776764886453748, 8.258476853370667, 7.82610802911222, 7.9702613689005375, 5.8869519084692, 4.032542165368795, 3.2753708073869348, 2.658925373107195, 0.696613829350099, 0.19971287489170209, 1.357156669255346, 2.133420458994806, 1.9394698413088918, 16.547268480062485, 43.659626841545105, 56.12163953483105, 70.25243908166885, 63.10615874826908, 63.896862119436264, 54.925038143992424, 53.723432421684265, 57.11238697171211, 61.76857732236385, 65.01167669892311, 64.62263077497482, 64.95582729578018, 53.36592100560665, 67.57681265473366, 31.171171367168427, 29.434651248157024, 67.86460161209106, 56.88597992062569, 62.32405051589012, 55.38520485162735, 54.356881231069565, 49.073982909321785, 49.879243299365044, 47.50266082584858, 48.3121769875288, 50.28156951069832, 58.78715470433235, 65.47820046544075, 64.2717196047306, 62.05566331744194, 56.769219785928726, 50.226392671465874, 26.44104078412056, 25.114678256213665, 34.41889509558678, 39.906841814517975, 40.15040874481201, 35.96338301897049, 29.02820985764265, 12.153815031051636, 3.0271890247240663, 4.571986868977547, 6.1525035090744495, 6.55334684997797, 8.019899055361748, 7.894131978973746, 6.785885822027922, 1.768810786306858, 4.623477905988693, 2.548012649640441, 6.906510349363089, 5.805025929585099, 9.798014592379332, 11.3491740077734, 9.38459012657404, 14.190544690936804, 16.40965886414051, 17.622401788830757, 13.824667073786259, 11.26109093427658, 7.332514990121126, 4.162365524098277, 2.37122998572886, 4.450079910457134, 6.572927199304104, 5.611995812505484, 3.6544059310108423, 0.43325723439920694, 7.537604235112667, 67.01853141188622, 67.47219666838646, 21.525806933641434, 24.068786278367043, 31.983480378985405, 64.46468085050583, 27.84630797803402, 29.772137738764286, 31.485855281352997, 0.5432586302049458, 0.5050323845352978, 0.040891594835557044, 0.026395497006888036, 0.026484252302907407, 0.04603699744620826, 0.1439172774553299, 0.029911020865256432, 0.02108168995619053, 0.07358503309660591, 0.035455589459161274, 0.027593694430834148, 0.04149210362811573, 0.03983988252002746, 0.01079028173990082, 0.07277321259607561, 0.028541097890411038, 0.05878769195987843, 0.037037328802398406, 0.053682101861340925, 0.12826127145672217, 0.025581759909982793, 0.017615741562622134, 0.052093018966843374, 0.0657127980957739, 0.07969437050633132, 0.0446422125241952, 0.04667251334467437, 0.07124932366423309, 0.07514713521231897, 0.07183435867773369, 0.03591753928049002, 0.032783609203761443, 0.013387412691372447, 0.04863298549025785, 0.026443393362569623, 0.044351075412123464, 0.08664249064167961, 0.011076178361690836, 0.02362122653721599, 0.04320112871937454, 0.0029098033337504603, 0.04140267112234142, 0.052102407134952955, 0.06550572405103594, 0.06485813340987079, 0.0455521004187176, 0.1190402201609686, 0.0246415942456224, 0.0989272388687823, 0.34269227064214647, 1.008900012820959, 44.99289929866791, 91.06133088469505, 49.960931316018105, 65.03458186984062, 63.94967928528786, 41.198179721832275, 29.246116764843464, 22.63756837695837, 45.198719054460526, 69.09360766410828, 89.80661541223526, 42.81504236161709, 0.07271493173902854, 3.159690289758146, 6.194963380694389, 9.983039014041424, 4.591014822944999, 4.324748860672116, 3.077626805752516, 5.035675512626767, 6.357736671343446, 9.878984447568655, 14.257960673421621, 14.129895195364952, 11.77980775013566, 11.677157208323479, 9.117002785205841, 11.256612874567509, 8.889165110886097, 13.282781951129436, 5.664951670914888, 2.2624520352110267, 6.492753876373172, 6.096164882183075, 7.0321050100028515, 4.9680030439049006, 3.172018490731716, 2.633845768868923, 3.929911097511649, 2.301317537203431, 0.9803203213959932, 0.47973150154575706, 1.5628528129309416, 3.493787362240255, 5.793900126591325, 18.752850629389286, 46.092605888843536, 61.808007806539536, 72.78371125459671, 65.46912655234337, 65.94403266906738, 57.494148686528206, 54.75756973028183, 59.85976494848728, 65.53637534379959, 69.50304329395294, 66.03436142206192, 69.46774318814278, 56.81393578648567, 68.85700196027756, 34.92075316607952, 32.636163756251335, 73.33794191479683, 61.770997792482376, 67.60065257549286, 59.08199228346348, 56.06482498347759, 50.56218825280666, 53.887895196676254, 51.81430086493492, 52.52167470753193, 51.701378524303436, 62.27763220667839, 71.63301900029182, 69.09177616238594, 68.12633916735649, 63.239428997039795, 60.91533310711384, 39.168792217969894, 28.66508424282074, 40.27839347720146, 45.90440958738327, 46.7412880808115, 41.1251400411129, 30.87823748588562, 14.901871271431446, 3.6941743595525622, 3.7129287282004952, 3.185316827148199, 5.270136706531048, 6.412566779181361, 6.52553946711123, 7.128888666629791, 5.237852688878775, 4.934810874983668, 4.627041639760137, 10.503834318369627, 7.632353575900197, 10.492322836071253, 12.925374079495668, 11.771860476583242, 13.973611481487751, 16.072805039584637, 16.286224387586117, 13.223730269819498, 8.716581221669912, 7.454978143796325, 3.077346570789814, 2.291227891109884, 5.651987716555595, 9.007735848426819, 2.9745967593044043, 6.564187193289399, 0.19504907046211883, 8.272831533104181, 71.28878027200699, 80.78177288174629, 32.68333062529564, 22.756870575249195, 34.101524725556374, 61.9706504791975, 40.32496377825737, 34.36383605003357, 52.931684106588364, 6.42433712258935, 0.28564127103891224, 0.02284091206092853, 0.11513654564623721, 0.11322570833726786, 0.04859883927565534, 0.026700783164415043, 0.09468266624026, 0.031012303079478443, 0.009487447987339692, 0.017040326638380066, 0.0729099681484513, 0.03651507577160373, 0.10392372583737597, 0.005765809773947694, 0.027158725388289895, 0.08493739151163027, 0.044798056114814244, 0.06688225214020349, 0.029837626170774456, 0.10635670114425011, 0.016951068537309766, 0.00549206535652047, 0.0366880444198614, 0.12489560205722228, 0.17858574137790129, 0.08404901105677709, 0.20571140223182738, 0.20081347989616916, 0.2160030757659115, 0.17509746918221936, 0.23150547203840688, 0.12311011349083856, 0.1278872587135993, 0.11872421368025243, 0.2482509656692855, 0.2495144127169624, 0.3118523536249995, 0.14630818041041493, 0.19892567885108292, 0.11852574854856357, 0.09885363266221248, 0.17443032294977456, 0.09756142739206553, 0.18751814175629988, 0.16246522514848039, 0.2482014792622067, 0.23910634074127302, 0.07972977837198414, 0.2291817928198725, 0.5275337083730847, 1.2234968226402998, 56.782021299004555, 104.1908423602581, 67.47487172484398, 74.32328224182129, 84.63842153549194, 59.662616327404976, 46.188132762908936, 35.29217563569546, 48.05556155741215, 83.0669778585434, 101.19846493005753, 51.95978745818138, 0.17332753603113815, 5.98336698487401, 10.50331374630332, 21.313383132219315, 7.163053108379245, 3.6529026366770267, 2.9298871709033847, 3.9372371044009924, 5.83358614705503, 11.124128233641386, 16.51788655668497, 16.43981594592333, 13.362552970647812, 14.681786131113768, 12.92312839999795, 15.87020181119442, 14.468416180461645, 19.163234308362007, 11.793618109077215, 6.966398460790515, 11.694982051849365, 11.566126216202974, 12.824495192617178, 10.984287187457085, 10.124013349413872, 6.141229514032602, 6.903358893468976, 6.710671233013272, 3.574533979408443, 1.2421630835160613, 1.7938675917685032, 4.388038739562035, 9.493216797709465, 25.654553286731243, 49.36638101935387, 64.27011609077454, 76.7308558523655, 71.5710899233818, 70.83465903997421, 60.551434233784676, 58.382708206772804, 61.87043085694313, 65.80540090799332, 72.25728750228882, 66.97433218359947, 71.1673691868782, 59.58602763712406, 69.89141285419464, 36.73397406935692, 35.69544039666653, 73.04742470383644, 63.267691880464554, 67.61686250567436, 60.52771970629692, 58.737130388617516, 51.083896458148956, 55.85618957877159, 52.638062462210655, 54.654363468289375, 53.53288784623146, 63.87647241353989, 72.44522541761398, 72.08773300051689, 70.81400334835052, 67.78754934668541, 69.05766159296036, 57.581821382045746, 44.37254838645458, 48.544910699129105, 47.85165309906006, 50.576099306344986, 43.32919277250767, 36.07411287724972, 19.68017566949129, 8.935979548841715, 8.973952811211348, 10.5620576441288, 11.833528317511082, 15.639603585004807, 16.285941302776337, 15.791002660989761, 11.305312011390924, 8.498294334858656, 11.900430377572775, 18.98086689412594, 17.63837993144989, 21.74079369753599, 24.217643290758133, 22.2984441742301, 24.19786535203457, 25.5139247328043, 22.860641106963158, 19.369002766907215, 14.996496643871069, 12.241677716374397, 7.760728262364864, 5.3627063892781734, 11.027560215443373, 16.69643897563219, 12.640205081552267, 10.224717445671558, 0.33094974292907864, 10.12631792575121, 86.18904232978821, 83.56450036168098, 28.516257628798485, 33.30919124186039, 52.702727392315865, 83.45257356762886, 54.63638283312321, 46.433185413479805, 79.34120938181877, 17.987431101500988, 1.4016244956292212, 0.31885867298115045, 0.2385883216629736, 0.2238388787372969, 0.1477222834364511, 0.23014808393782005, 0.17288073344388977, 0.13911494374042377, 0.1236699303262867, 0.14725407731020823, 0.14987068221671507, 0.17189630423672497, 0.14259116345783696, 0.0899859401397407, 0.138285786670167, 0.26675764995161444, 0.16433004930149764, 0.08491223270539194, 0.15113547997316346, 0.19466082332655787, 0.13942848629085347, 0.19407243380555883, 0.2578050928423181], [0.024825867658364587, 0.028224605302966665, 0.015807689851499163, 0.09774876773008145, 0.08394822740228847, 0.05242186089162715, 0.059497793699847534, 0.05344174991478212, 0.05301409102685284, 0.04891546173894312, 0.08776707443757914, 0.1046030803991016, 0.05814496980747208, 0.0467917987407418, 0.019947892396885436, 0.0544634312245762, 0.056633240965311415, 0.1158086048963014, 0.033366428906447254, 0.02770917632005876, 0.047358973970403895, 0.10197326526395045, 0.06436649025999941, 0.0805966959160287, 0.017702956902212463, 0.07228579226648435, 0.12246523168869317, 0.10915885039139539, 4.7322494443506, 90.28817877173424, 49.89064648747444, 57.09180347621441, 50.257949978113174, 57.57179751992226, 42.32372112572193, 35.06890341639519, 22.761740013957024, 71.24816805124283, 102.66720771789551, 20.019951537251472, 0.5499360000248998, 1.5523665631189942, 5.250508384779096, 4.281587926670909, 2.742795660160482, 2.225484293885529, 4.039268279448152, 6.688517946749926, 9.97029734775424, 13.192701134830713, 14.986654222011566, 17.549493201076984, 14.266975689679384, 13.650222234427929, 9.226738046854734, 10.921482257544994, 9.481887705624104, 9.114636462181807, 0.7186144113074988, 6.134975999593735, 8.051164727658033, 8.459532614797354, 6.5693544410169125, 8.649284932762384, 5.424783658236265, 5.507950270548463, 5.232850732281804, 4.510066341608763, 2.692589429207146, 0.17811336438171566, 0.8569688466377556, 0.8862129680346698, 2.532170112244785, 17.346680983901024, 39.353690296411514, 47.8916497528553, 63.946692645549774, 64.39703688025475, 59.54218938946724, 58.98008555173874, 54.85436953604221, 56.987894251942635, 62.24853716790676, 65.60987859964371, 63.17765951156616, 64.25042554736137, 58.2803189009428, 64.7459265589714, 35.620295628905296, 19.369378946721554, 62.936775237321854, 57.066151052713394, 59.56730604171753, 57.85176269710064, 58.0711705237627, 49.752983674407005, 48.01330782473087, 47.57166512310505, 52.29827709496021, 57.156722992658615, 63.19317027926445, 65.34588396549225, 64.40811708569527, 63.32281552255154, 57.34935365617275, 45.66220298409462, 36.34059637784958, 46.16830162703991, 49.6848039329052, 41.550147235393524, 41.40579678118229, 37.27159962058067, 27.28848271071911, 16.105245798826218, 3.3213122421875596, 3.6901323264464736, 5.606957757845521, 6.4491084683686495, 7.239621374756098, 7.241060072556138, 5.939002940431237, 3.4120941208675504, 3.9022785052657127, 4.03145257383585, 4.4013104774057865, 7.285460215061903, 8.539162091910839, 8.0843435972929, 11.088479496538639, 15.363377407193184, 16.79645150899887, 17.09920596331358, 14.709470495581627, 10.101746544241905, 6.4468969870358706, 3.0622763419523835, 1.391379414126277, 4.627764550969005, 4.00169019587338, 5.6856634095311165, 2.111335569061339, 0.27841877890750766, 2.0773699041455984, 77.56095930933952, 51.94833107292652, 28.111123368144035, 38.95462051033974, 60.40981203317642, 47.690317556262016, 25.239775143563747, 41.562435775995255, 15.29503047466278, 1.0414715087972581, 0.024345590500161052, 0.038776811634306796, 0.07779655046761036, 0.05946387012954801, 0.045318182892515324, 0.06483224729890935, 0.0397044925193768, 0.03639401664258912, 0.1225434614752885, 0.020041306524944957, 0.017278049526794348, 0.04729036612843629, 0.021150461070646998, 0.05492432348546572, 0.021553087317442987, 0.04114745395781938, 0.048948446492431685, 0.05846394858963322, 0.03861390279780608, 0.06103774270741269, 0.03374925836396869, 0.03550951762008481, 0.12220654127304442, 0.046071600081631914, 0.030657346833322663, 0.03420246568566654, 0.05188378898310475, 0.031855234410613775, 0.04682605627749581, 0.04479783718124963, 0.04588726915244479, 0.09966540121240541, 0.02228593217296293, 0.042330081123509444, 0.013260461837489856, 0.05040029143856373, 0.11139497844851576, 0.052647677875938825, 0.045977625632076524, 0.03991032346675638, 0.04154015397944022, 0.012906572428619256, 0.057338344340678304, 0.07316597941098735, 0.07227999609312974, 0.0422320471261628, 0.11133343956316821, 0.013143887135811383, 0.07567609354737215, 0.20583681034622714, 0.02545243511121953, 6.369467591866851, 102.27594271302223, 60.27325876057148, 61.58692046999931, 62.312837317585945, 55.88284894824028, 42.23704397678375, 32.08550490438938, 33.463333770632744, 76.17781832814217, 105.98660320043564, 22.572855949401855, 0.1795828909962438, 4.261970529332757, 6.181705417111516, 8.920370936393738, 3.3347746822983027, 4.533152477815747, 4.890080625191331, 8.522709924727678, 10.847968552261591, 13.98040171712637, 12.103457283228636, 16.93632200360298, 15.875948052853346, 17.481216564774513, 11.281925216317177, 13.52089237421751, 13.485830705612898, 13.298877887427807, 2.2638693591579795, 4.133184514939785, 7.504791095852852, 6.464549889788032, 5.9806563053280115, 6.394009524956346, 3.309895754791796, 4.792924588546157, 4.427219862118363, 3.0937985004857183, 2.313327742740512, 0.07937710237456486, 0.6232648808509111, 1.2030358705669641, 4.401215482503176, 22.634023167192936, 49.12569433450699, 51.22232303023338, 67.40601181983948, 64.2772901058197, 61.400635465979576, 61.7707584053278, 56.40281684696674, 59.417381286621094, 65.82319915294647, 70.9314626455307, 67.36840903759003, 68.00556644797325, 61.989638060331345, 70.4840138554573, 39.90576647222042, 23.027140572667122, 67.87038490176201, 62.081676721572876, 66.30330339074135, 62.793093547225, 64.36825722455978, 54.13733661174774, 52.33684502542019, 50.318226143717766, 55.316067561507225, 62.01373636722565, 67.99140080809593, 70.82854896783829, 68.73935267329216, 67.91124790906906, 66.55209124088287, 57.934735044837, 45.84412582218647, 50.50883151590824, 58.772210106253624, 52.61595904827118, 48.533952087163925, 43.41199412941933, 31.55891016125679, 18.58211439102888, 5.347831612452865, 2.708060536533594, 3.6057792278006673, 3.5162690933793783, 5.640431586652994, 3.989705163985491, 6.7215661983937025, 5.550876567140222, 5.850296700373292, 6.071679946035147, 8.073693718761206, 8.04233305156231, 9.348711501806974, 9.949602708220482, 12.886447068303823, 15.320110078901052, 16.95288721472025, 16.81340429931879, 12.705395333468914, 10.154210329055786, 4.882879536598921, 2.739588632248342, 3.015052000992, 6.85586666688323, 6.914658062160015, 5.881550973281264, 3.456494975835085, 0.22108508041128516, 2.9901535995304585, 79.45731595158577, 69.75154995918274, 23.143387734889984, 32.80841991305351, 58.7332583963871, 53.88115435838699, 31.3904595002532, 53.33933003246784, 22.949487939476967, 1.3168636313639581, 0.08276200082036667, 0.1180062600178644, 0.044469288404798135, 0.013004491393076023, 0.09872227994492278, 0.00033489906741124287, 0.021995923125359695, 0.046459171862807125, 0.017579905106686056, 0.04331573116360232, 0.03388939439901151, 0.05318336006894242, 0.04083894316863734, 0.05062208969320636, 0.03031797197763808, 0.021686631225747988, 0.023720460958429612, 0.0495188055356266, 0.05203255619562697, 0.04684845429437701, 0.018674619313969743, 0.021427634674182627, 0.08538402340491302, 0.22236029792111367, 0.09533574135275558, 0.08887050702469423, 0.18679595785215497, 0.1521056896308437, 0.20240624755388126, 0.14084465248743072, 0.09370976258651353, 0.2040359444799833, 0.19004119152668864, 0.30628253531176597, 0.20094556733965874, 0.10402603089460172, 0.19433677196502686, 0.17568737268447876, 0.13237882551038638, 0.13301846774993464, 0.21708640357246622, 0.11923269616090693, 0.1332878228276968, 0.16343669645721093, 0.23201537202112377, 0.21705762308556587, 0.15248314593918622, 0.1386581370024942, 0.13414589397143573, 0.6645886728074402, 0.37983138870913535, 8.330241702497005, 117.62779533863068, 72.45359256863594, 74.30388808250427, 70.68026572465897, 76.67499125003815, 62.818172201514244, 47.92300567030907, 40.02322196960449, 87.12978824973106, 115.03728434443474, 28.785777166485786, 0.660818147007376, 3.653522953391075, 15.01731002703309, 17.37714394927025, 10.773992221802473, 5.429556202143431, 5.651112338528037, 9.55699922516942, 12.740289811044931, 16.199374347925186, 15.835461225360632, 22.245087437331676, 16.70110322535038, 22.283503375947475, 16.94849845021963, 19.030205346643925, 20.76217330992222, 19.903717674314976, 8.998666685074568, 10.16653971746564, 13.425756879150867, 13.177737537771463, 11.708264239132404, 12.180888578295708, 9.688801802694798, 8.736276514828205, 9.798108637332916, 7.532195225358009, 4.489736007526517, 0.6001874129287899, 2.2006234154105186, 1.532777426764369, 8.752036169171333, 33.800022304058075, 55.50610676407814, 54.13976088166237, 69.90994065999985, 68.95587265491486, 65.84025263786316, 65.01913189888, 59.20608602464199, 61.768835708498955, 67.13858217000961, 70.66984668374062, 69.0435491502285, 72.04090431332588, 64.42558854818344, 70.57247310876846, 41.93150237202644, 25.241984724998474, 66.46525830030441, 64.85967725515366, 66.57913818955421, 65.81177696585655, 65.01236826181412, 54.162027686834335, 53.01128223538399, 51.4591871201992, 57.058467864990234, 62.73689456284046, 69.34074640274048, 70.88588029146194, 70.45084923505783, 69.29172903299332, 69.7680638730526, 64.38163250684738, 60.92057302594185, 57.96068385243416, 61.643328443169594, 53.358583599328995, 49.94692146778107, 43.024437725543976, 33.33026871085167, 24.414066150784492, 10.734246354550123, 10.713995341211557, 10.476391240954399, 11.220875792205334, 14.020017441362143, 14.884138572961092, 17.501592971384525, 14.196163639426231, 10.45961894094944, 11.020780429244041, 17.40212570875883, 19.19644072651863, 20.673415772616863, 19.91373773664236, 23.308538272976875, 25.854373164474964, 24.67854715883732, 23.512575924396515, 18.984072022140026, 17.667640261352062, 10.367927011102438, 8.536663725972176, 4.882445884868503, 15.208338126540184, 12.079165186733007, 14.197794701904058, 6.248217523097992, 1.0367372003383934, 3.529975670389831, 86.21340662240982, 67.12377816438675, 36.648056879639626, 57.92677067220211, 81.07713103294373, 73.59977826476097, 41.78161181509495, 70.64010187983513, 50.332494378089905, 2.5443897815421224, 0.2257737616309896, 0.3313477715710178, 0.32846616057213396, 0.19971199915744364, 0.19493757019517943, 0.13649842789163813, 0.07751627839752473, 0.18194254953414202, 0.2901020832359791, 0.15547201212029904, 0.15652624773792922, 0.17289001028984785, 0.10837082314537838, 0.11022654114640318, 0.10562283583567478, 0.1300541072851047, 0.18171622417867184, 0.16889341146452352, 0.06320902190054767, 0.23029019037494436, 0.15041639824630693, 0.23405210726195946, 0.30974857276305556], [0.07273080627783202, 0.04239347908878699, 0.009907901549013332, 0.0361073249951005, 0.027218651957809925, 0.02192768079112284, 0.013841137661074754, 0.06554982246598229, 0.020601477735908702, 0.07667903191759251, 0.00489669454509567, 0.026481370914552826, 0.01647606804908719, 0.06193555956997443, 0.012895943018520484, 0.029515853202610742, 0.05528358604351524, 0.04220357834128663, 0.05159717155038379, 0.031366070033982396, 0.11568474787054583, 0.02893130986194592, 0.01949727888131747, 0.10513640256249346, 0.09202329136314802, 0.08409025220316835, 0.021856352977920324, 0.1367528212722391, 0.13769508164841682, 37.628259882330894, 86.86310335993767, 47.499784380197525, 39.65571328997612, 69.16741490364075, 47.581780180335045, 36.834421679377556, 25.22125493735075, 56.722440496087074, 101.29053398966789, 8.67894234135747, 0.14406637492356822, 2.2858119942247868, 3.8069435209035873, 5.38150018081069, 2.1919107204303145, 4.40835339948535, 5.847637318074703, 13.305611126124859, 16.452146284282207, 15.121753122657537, 18.482909314334393, 18.1283313408494, 19.645700119435787, 17.264170311391354, 13.07093856856227, 12.264791876077652, 17.9789100587368, 6.649729153141379, 4.493274567648768, 6.709861401468515, 6.763176815584302, 6.585979498922825, 7.059741877019405, 10.763093456625938, 6.251530470326543, 5.175153678283095, 6.996660036966205, 5.815377524122596, 1.6946445847861469, 0.14255050860811025, 0.7091453194152564, 0.8540104678831995, 0.9303312725387514, 7.5920025911182165, 16.445312350988388, 30.874014012515545, 48.62685330212116, 59.84063297510147, 61.78847685456276, 63.16216394305229, 56.33019894361496, 58.21944996714592, 62.164744064211845, 66.55522987246513, 67.52113044261932, 62.60953299701214, 63.19217473268509, 58.07921089231968, 41.57102711498737, 17.815264239907265, 58.38780753314495, 53.607873022556305, 59.945321157574654, 58.506988137960434, 62.50216595828533, 53.3378367125988, 45.798399075865746, 48.74134115874767, 54.313327968120575, 62.01361857354641, 62.72593595087528, 66.1519955098629, 63.120259791612625, 63.28875035047531, 55.45523129403591, 53.02135929465294, 49.74564626812935, 56.38486661016941, 53.13854120671749, 47.29924634099007, 44.88456331193447, 35.86702398955822, 26.1021825671196, 17.963186502456665, 6.420286539942026, 2.0617883652448654, 4.276947900652885, 6.60829427652061, 7.203629706054926, 8.778579644858837, 6.498957518488169, 0.937011610949412, 3.929808265529573, 4.610220892354846, 4.119776459410787, 7.84591494128108, 8.598402813076973, 8.98996040225029, 12.353602610528469, 15.178113598376513, 17.7748629078269, 17.819896191358566, 14.726851712912321, 8.579215742647648, 6.024199593812227, 1.987731526605785, 0.7507108140271157, 4.326522890478373, 4.292021216824651, 0.23968736815731972, 4.050879031419754, 0.1141058212670032, 3.6635503778234124, 69.92031410336494, 27.475974150002003, 40.14171101152897, 48.61857734620571, 58.92891749739647, 31.338033713400364, 36.34390980005264, 23.877761028707027, 4.972942303866148, 0.4599672183394432, 0.1071183747262694, 0.051064424551441334, 0.09316869240137748, 0.10753949158242904, 0.045996632034075446, 0.06796652989578433, 0.011708212659868877, 0.0961704645305872, 0.028916630180901848, 0.04191535415884573, 0.06120021738752257, 0.057941372724599205, 0.04420047138410155, 0.010138749366888078, 0.03171460113662761, 0.022985105788393412, 0.03680040557810571, 0.12073781617800705, 0.031239185045706108, 0.11912506248336285, 0.05048024671850726, 0.022356068839144427, 0.061974767231731676, 0.07720968234934844, 0.06070772447856143, 0.02561331417382462, 0.032826772512635216, 0.0651576642121654, 0.029591730381071102, 0.06498657690826803, 0.03476776328170672, 0.013795513204968302, 0.05500730672792997, 0.03798827972786967, 0.031210285815177485, 0.0382752348377835, 0.017906220018630847, 0.028850345261162147, 0.017910223905346356, 0.046537895177607425, 0.09727155935252085, 0.014140849361865548, 0.01756772460794309, 0.050383177513140254, 0.04028294097224716, 0.03833811329968739, 0.16038853267673403, 0.04772299369506072, 0.145138451771345, 0.045382334137684666, 0.21485895122168586, 0.0995258848706726, 44.58930395543575, 100.45616716146469, 55.023183077573776, 44.79953147470951, 71.15845486521721, 51.96328327059746, 31.0531098023057, 31.072623655200005, 66.97044119238853, 102.31097683310509, 11.074299607425928, 0.18687979085370898, 3.2735003577545285, 8.61588567495346, 10.45972628518939, 3.616890306584537, 6.315526161342859, 5.666932789608836, 10.999455973505974, 16.588876247406006, 15.175970513373613, 17.632953822612762, 17.822966426610947, 21.236085779964924, 19.32191949337721, 18.38891375809908, 12.787090949714184, 19.18008830398321, 10.711506474763155, 2.4236272741109133, 6.052733212709427, 6.599322957918048, 5.688470983877778, 5.322244735434651, 7.742405170574784, 5.841639339923859, 4.210199257358909, 5.0534438341856, 4.556770110502839, 0.5548931902740151, 0.22348658123519272, 1.6248930338770151, 1.3001700583845377, 3.478272082284093, 16.937465742230415, 28.96670065820217, 45.52470736205578, 59.175638258457184, 66.01017192006111, 65.27988910675049, 65.84036663174629, 58.39697644114494, 60.95389723777771, 64.56010892987251, 68.80024820566177, 69.46245387196541, 67.07281529903412, 65.0521369278431, 64.00748178362846, 47.72912487387657, 20.923263765871525, 64.65058967471123, 58.44777591526508, 67.28039056062698, 61.577059999108315, 69.2004807293415, 57.611250802874565, 50.16065999865532, 53.33529844880104, 58.281299248337746, 65.40557876229286, 67.14313432574272, 70.11755391955376, 68.44576522707939, 67.78963923454285, 65.21765604615211, 60.83574637770653, 60.315273106098175, 65.49800500273705, 64.08826544880867, 56.22456081211567, 54.45412941277027, 42.16909222304821, 30.73144756257534, 20.69732028990984, 8.68815304711461, 2.6551799615845084, 5.151001224294305, 3.759416383691132, 5.91472651809454, 5.265485281124711, 6.181355835869908, 3.2783163618296385, 6.818935973569751, 8.91250915825367, 6.289015458896756, 8.374143596738577, 8.138867821544409, 10.13654412701726, 11.762863509356976, 13.069994319230318, 15.633747149258852, 15.520228240638971, 10.625315699726343, 9.015091303735971, 4.007268771529198, 4.486044980585575, 4.0043761767446995, 5.401338916271925, 4.645892903208733, 2.6235946314409375, 2.225355338305235, 0.08345616864971817, 3.697257419116795, 82.16559782624245, 29.354654140770435, 29.069810025393963, 44.21967878937721, 61.97201460599899, 41.05441063642502, 39.401248544454575, 38.5030223429203, 2.2478574933484197, 0.055888510614749976, 0.07129286546842195, 0.06243231240659952, 0.052854173045489006, 0.06971612820052542, 0.050149556846008636, 0.08351510259672068, 0.05746451686718501, 0.02589680159871932, 0.04049626018968411, 0.032018031924963, 0.03362740513694007, 0.10695496122934856, 0.04117554424738046, 0.024891300963645335, 0.03590260726923589, 0.014352313210110879, 0.08446699604974128, 0.03986780582636129, 0.013492575944837881, 0.07375541536021046, 0.013146513410902116, 0.030888926594343502, 0.036898918260703795, 0.20265676692361012, 0.14833032502792776, 0.14071796787902713, 0.13550914503866807, 0.11028750115656294, 0.10597651373245753, 0.17110691143898293, 0.125907936017029, 0.12864065734902397, 0.19967600499512628, 0.14639196888310835, 0.11843766304082237, 0.12968794646440074, 0.11757622254663147, 0.1280900283018127, 0.068056856689509, 0.18089390970999375, 0.17676900839433074, 0.13775247934972867, 0.19585290545364842, 0.24769295967416838, 0.20183243381325155, 0.1221018390788231, 0.23012712568743154, 0.22038136114133522, 0.1851835084380582, 0.11344619299052283, 0.3133807622361928, 0.39748868497554213, 59.12805341184139, 112.23526909947395, 72.09731608629227, 62.5185202807188, 87.17739969491959, 72.04744756221771, 50.696066468954086, 35.105921030044556, 72.01055154204369, 117.78410375118256, 12.534755039960146, 0.20702620589872822, 6.706775017082691, 15.520927403122187, 13.018727470189333, 11.073933877050877, 12.637507226318121, 9.081026315689087, 21.78197778761387, 23.404255136847496, 22.559170983731747, 23.375156298279762, 21.81628804653883, 25.90402130037546, 25.614758022129536, 23.054445907473564, 21.225900426506996, 26.61799918860197, 21.208974234759808, 12.66720263287425, 12.813393138349056, 11.45476559177041, 12.146153692156076, 10.143921431154013, 15.41076846420765, 11.244174242019653, 12.316671442240477, 9.99841583892703, 8.930805176496506, 3.89230546541512, 0.32550858333706856, 5.623023295775056, 1.4664512732997537, 6.872509773820639, 24.166727922856808, 29.483702816069126, 52.037645280361176, 63.722288087010384, 74.08099964261055, 70.97582146525383, 70.38236930966377, 59.94041942059994, 63.24939966201782, 65.89307740330696, 71.00121170282364, 70.72251185774803, 68.18892180919647, 65.11484876275063, 64.35981407761574, 48.35855349898338, 24.666674695909023, 62.689203321933746, 60.874770283699036, 68.11872437596321, 64.39938515424728, 70.74822887778282, 59.270222783088684, 52.06540659070015, 54.542748257517815, 59.15727764368057, 66.5019491314888, 67.798340767622, 71.16320461034775, 69.07042130827904, 72.5342470407486, 70.72603806853294, 68.89004498720169, 67.56577804684639, 70.85837736725807, 62.28102162480354, 59.535703137516975, 56.963575556874275, 44.124110117554665, 33.99585619568825, 25.859278701245785, 13.472162839025259, 8.108398206532001, 10.476994458585978, 9.328470937907696, 12.282701265066862, 16.18815165013075, 14.853773452341557, 10.516647230833769, 11.719393841922283, 12.686524596065283, 18.01532920449972, 17.451897338032722, 22.603866085410118, 21.8993116915226, 24.29563980549574, 20.895688645541668, 24.547190107405186, 20.696184150874615, 19.4221980124712, 17.383527606725693, 10.841645691543818, 5.712024969980121, 6.714897081255913, 11.348008420318365, 17.840690575540066, 4.960068594664335, 8.996793385595083, 0.2579805365530774, 4.513295693323016, 84.4424432516098, 37.0651300996542, 54.24694932997227, 68.87214794754982, 81.86606749892235, 57.55163200199604, 55.791878029704094, 70.77608898282051, 12.151115275919437, 1.1228120815940201, 0.698560809250921, 0.19498534966260195, 0.4577693034661934, 0.29017665423452854, 0.14912696118699387, 0.361696564941667, 0.21985375351505354, 0.15590088441967964, 0.10283226409228519, 0.11025846091797575, 0.21373493887949735, 0.190030088997446, 0.17809895187383518, 0.07285754283657297, 0.08874158855178393, 0.09818985578021966, 0.16135583311552182, 0.24569919478381053, 0.08413248040596955, 0.15952749294228852, 0.12932370038470253, 0.0839633152645547, 0.13873389543732628], [0.06408137196558528, 0.04274976563465316, 0.04059349637827836, 0.028787526171072386, 0.04988894426787738, 0.04581566303386353, 0.060081990086473525, 0.015090504311956465, 0.0373934112576535, 0.07343839955865405, 0.04313258767069783, 0.058230903086951, 0.03548167966073379, 0.05399847941589542, 0.0960462364309933, 0.06276943298871629, 0.08254221378592774, 0.028780626053048763, 0.045320869467104785, 0.04172921610006597, 0.053773575273226015, 0.014283052278187824, 0.04896357888355851, 0.0892112789733801, 0.06454645365010947, 0.054114818485686556, 0.05623087075946387, 0.1495001872535795, 0.3445868252310902, 1.7181985708884895, 57.493795305490494, 78.36129516363144, 46.729029938578606, 61.58387303352356, 69.40262988209724, 40.789279863238335, 30.709036365151405, 35.5197112262249, 103.9306703209877, 3.8878252683207393, 0.02004808047786355, 2.381565193645656, 5.056361127644777, 5.435442561283708, 0.7894690905231982, 3.698147521354258, 7.322551449760795, 7.886565160006285, 18.009070940315723, 20.120345950126648, 19.0538077801466, 20.197092331945896, 21.839890480041504, 20.672910399734974, 16.154424659907818, 15.667443741112947, 18.898833096027374, 10.996667873114347, 5.587616320699453, 6.87570920214057, 9.50545784085989, 8.714364990592003, 7.5884863547980785, 9.281044732779264, 5.102456454187632, 6.257120445370674, 7.825561808422208, 2.4851820711046457, 0.44589936383999884, 1.3236545794643462, 3.7553104665130377, 5.042648138478398, 4.358245488256216, 4.661225080490112, 6.104381941258907, 8.066902533173561, 27.564534097909927, 41.41826011240482, 53.35447981953621, 58.997120037674904, 55.601588040590286, 59.54388789832592, 59.96944226324558, 65.36653965711594, 66.31939932703972, 62.964730337262154, 58.6718612909317, 60.16778402030468, 41.15793228149414, 17.08378069102764, 59.25683990120888, 51.46253854036331, 60.03278486430645, 55.513998940587044, 60.76937913894653, 51.82313919067383, 44.33285191655159, 50.64769126474857, 57.41972967982292, 59.87868033349514, 60.312332063913345, 66.34457677602768, 61.84211477637291, 60.1305878162384, 54.47205685079098, 52.65688665211201, 55.1755852997303, 62.06779606640339, 59.67973440885544, 50.99718131124973, 48.04509311914444, 36.97405658662319, 27.367277182638645, 18.555105440318584, 10.59154026210308, 1.1943363561294973, 2.2297241538763046, 7.204985283315182, 7.109862612560391, 8.225896451622248, 9.231951367110014, 0.6964378512930125, 6.358208321034908, 7.2511110082268715, 7.5420808698982, 8.730677515268326, 7.73240078240633, 13.24361840263009, 13.039043080061674, 17.445646673440933, 20.059482716023922, 17.178925685584545, 13.200842197984457, 8.157384227961302, 5.520977871492505, 0.4052190436050296, 3.1528663309291005, 3.564346726052463, 5.892839217558503, 3.1906807143241167, 2.9921803157776594, 0.10754272734629922, 5.809873519465327, 48.3735740929842, 37.477183789014816, 47.84409910440445, 56.34381741285324, 46.219036504626274, 24.190837629139423, 27.170673832297325, 8.515606205910444, 1.2003453774377704, 0.19913962518330663, 0.0535807875712635, 0.04120723024243489, 0.06363474749377929, 0.051958018593722954, 0.042841636095545255, 0.07118600362446159, 0.02251733010780299, 0.02059425663901493, 0.05390179612732027, 0.054150749565451406, 0.04462665710889269, 0.005391680606408045, 0.048965797905111685, 0.005792429219582118, 0.05404104529588949, 0.020356058776087593, 0.005456458502521855, 0.08104945052764378, 0.06815205197199248, 0.04127121821511537, 0.028825782028434332, 0.06972329734708183, 0.07819667938747443, 0.10428317764308304, 0.05352044725441374, 0.06885304013849236, 0.09916952039930038, 0.07035002621705644, 0.14260409167036414, 0.07998780827620067, 0.0648800193448551, 0.019731586035049986, 0.06260195994400419, 0.002301674771842954, 0.06417738361051306, 0.06257514614844695, 0.052082680849707685, 0.0329569563473342, 0.10763054568087682, 0.032370726476074196, 0.023813568950572517, 0.0980655089369975, 0.007589655315314303, 0.06493843378848396, 0.0814441469265148, 0.07249697038787417, 0.04669287787692156, 0.042432846312294714, 0.06020001012075227, 0.05664946431352291, 0.1427471183706075, 0.3787695534992963, 2.2230317629873753, 75.30819699168205, 88.98204445838928, 53.058023527264595, 67.98522993922234, 72.46519714593887, 44.144081845879555, 29.593233838677406, 55.812879502773285, 107.97379776835442, 3.923887233249843, 0.05612210159597453, 3.9262917917221785, 4.319054866209626, 8.466785475611687, 5.6832400895655155, 2.6979618659242988, 4.930421160534024, 7.095294669270515, 16.68189335614443, 19.25074551254511, 17.550891526043415, 20.019318871200085, 21.72080297023058, 21.56832095235586, 18.188115432858467, 14.830148220062256, 20.602534376084805, 9.250709060579538, 1.8855691398493946, 5.568354204297066, 7.7877590619027615, 6.144954264163971, 5.925628133118153, 5.2302982192486525, 2.9561941092833877, 3.1819948554039, 5.4724392760545015, 1.5640645916573703, 0.32445366494357586, 1.233941987156868, 5.1307369116693735, 5.848652813583612, 4.095393642783165, 12.625980544835329, 20.984516479074955, 33.367172330617905, 49.647945910692215, 58.897477984428406, 62.803406193852425, 66.08258083462715, 56.10838204622269, 61.24566838145256, 64.15779411792755, 70.12295722961426, 68.03335055708885, 67.03139752149582, 63.12936030328274, 66.24179989099503, 45.7478541880846, 19.930016063153744, 64.79314282536507, 56.48139663040638, 65.25978818535805, 61.79791174829006, 65.82488626241684, 57.35460117459297, 50.45157238841057, 56.90429113805294, 62.68130734562874, 64.50021654367447, 67.01290771365166, 68.29615965485573, 67.8625801205635, 66.13513961434364, 62.273091450333595, 63.01552601158619, 62.58139930665493, 71.34108066558838, 70.7721371948719, 62.013648971915245, 55.632347390055656, 43.359195962548256, 32.4459383636713, 21.32148999720812, 14.084058254957199, 3.651534472592175, 4.587647253647447, 0.5309156456496567, 4.211092684417963, 4.30808580480516, 4.633814776316285, 2.583251721225679, 8.553469274193048, 14.317824561148882, 8.48622428253293, 7.473843181505799, 7.77995903044939, 9.856691993772984, 11.790045350790024, 15.49050908535719, 15.128443613648415, 11.812852676957846, 7.0417028199881315, 7.264387020841241, 4.674336751922965, 4.003029624000192, 6.914109941571951, 4.910290315747261, 10.784501507878304, 1.718023899011314, 3.1569266505539417, 0.13205606548581272, 7.775607313960791, 56.44998751580715, 35.93815237283707, 48.69406409561634, 60.37340618669987, 54.44298081099987, 32.84452557563782, 42.54651077091694, 6.525151887908578, 0.9850093885324895, 0.16751116141676903, 0.16171528492122889, 0.03487611684249714, 0.0854826919385232, 0.017558904182806145, 0.07578059536172077, 0.07703955241595395, 0.027666998212225735, 0.06276355517911725, 0.06742057637893595, 0.05011589302739594, 0.01815526808059076, 0.02476560155628249, 0.019252726378908847, 0.08057262806687504, 0.07073913424392231, 0.019917046884074807, 0.047222585781128146, 0.03373769941390492, 0.035685150578501634, 0.026659504910639953, 0.03025759826414287, 0.07203404835308902, 0.06021181026881095, 0.23895586287835613, 0.28110205836128443, 0.1525759292417206, 0.34583060536533594, 0.14332335151266307, 0.3073554433649406, 0.23451243177987635, 0.11168521756189875, 0.153837802936323, 0.12346214381977916, 0.06877139647258446, 0.21077811863506213, 0.15045209554955363, 0.1673816714901477, 0.12154600757639855, 0.24252593459095806, 0.13379662443185225, 0.1234706785180606, 0.15433985099662095, 0.1449546217918396, 0.18209899426437914, 0.19241039408370852, 0.15467499004444107, 0.1845416842843406, 0.11933879359276034, 0.16879967821296304, 0.12771889509167522, 0.15662443387554958, 0.6436940690036863, 3.5150655079632998, 96.31972432136536, 104.58614274859428, 72.57683515548706, 82.71914452314377, 90.9861633181572, 61.2837765365839, 41.38550586998463, 49.46237526834011, 119.40591752529144, 5.441927388310432, 0.12487301108194515, 6.7017364874482155, 15.278850942850113, 19.855464063584805, 8.07051993906498, 13.668219968676567, 12.243692558258772, 11.02665776386857, 25.635417513549328, 29.18796468526125, 22.398777790367603, 26.625266298651695, 28.302171416580677, 29.27482232451439, 24.422478899359703, 24.684573635458946, 30.791676230728626, 21.817870661616325, 13.388181645423174, 14.121855776757002, 16.910042613744736, 14.664582554250956, 12.27920450270176, 15.986650362610817, 10.87115965783596, 10.90815732255578, 11.24735752120614, 7.098425701260567, 1.1861029104329646, 1.009756273124367, 9.247043207287788, 9.319326728582382, 13.361953552812338, 27.963047213852406, 29.379316717386246, 39.067793637514114, 55.989931002259254, 66.00808203220367, 67.02490746974945, 70.27153685688972, 60.53974226117134, 63.73798884451389, 63.32281172275543, 70.92739686369896, 68.64672124385834, 66.66588753461838, 63.68743255734444, 67.67179995775223, 47.45549015700817, 23.864193856716156, 63.814026564359665, 57.28588566184044, 68.06058749556541, 63.50568450987339, 68.65061983466148, 59.65823516249657, 51.560580879449844, 56.03445701301098, 65.07413014769554, 66.76969036459923, 67.15391054749489, 70.27725175023079, 67.84904524683952, 67.13626429438591, 65.56872680783272, 65.81605553627014, 68.54911208152771, 72.47104123234749, 72.48272940516472, 66.13281413912773, 58.89428235590458, 42.89468228816986, 33.35494078695774, 24.951150231063366, 19.50996570289135, 9.147599693387747, 10.920188426971436, 11.259127389639616, 11.755385510623455, 16.896055564284325, 18.979215882718563, 11.876050885766745, 14.965294618159533, 18.691801205277443, 20.024942569434643, 17.15764682739973, 18.248817175626755, 23.437845334410667, 25.83949316293001, 25.01367587596178, 24.043019860982895, 22.173168696463108, 18.74160323292017, 12.565923817455769, 11.368897799402475, 5.115711092948914, 7.773065250366926, 11.805431675165892, 15.620915237814188, 9.021673500537872, 7.938981922343373, 0.24957924673799425, 7.329717390239239, 63.55659417808056, 49.02047038078308, 68.43011006712914, 69.93215426802635, 75.40407344698906, 42.9470244795084, 67.61726528406143, 31.68032694607973, 2.620099293999374, 0.507930857129395, 0.25900303793605417, 0.1953879202483222, 0.17467349505750462, 0.1436408719746396, 0.20783416723133996, 0.13128104066709056, 0.08286532261990942, 0.1306858382304199, 0.20608455408364534, 0.1578510258696042, 0.09278449739213102, 0.09083254510187544, 0.21065265114884824, 0.21734253357863054, 0.16793828224763274, 0.09926263024681248, 0.1319404982496053, 0.12410796814947389, 0.19784837728366256, 0.11799700543633662, 0.12787654210114852, 0.09647494545788504, 0.26946420315653086], [0.1427076361142099, 0.06770695632440038, 0.049481230598757975, 0.05115804277011193, 0.008556705743103521, 0.02644823216542136, 0.03552470567228738, 0.048889493991737254, 0.08506888523697853, 0.14909111545421183, 0.00389236557566619, 0.04131989939196501, 0.025237833833671175, 0.09630077081965283, 0.06691252434393391, 0.06972201343160123, 0.008000057878234657, 0.011998743066214956, 0.04119789031392429, 0.12965790432645008, 0.04672708717407659, 0.03541857484378852, 0.02163269749871688, 0.06779373565223068, 0.11375281130312942, 0.09889181616017595, 0.14804611215367913, 0.15345298452302814, 0.4187930136686191, 0.22982299356954172, 6.952295992523432, 55.41486606001854, 55.29920406639576, 39.313834235072136, 76.79811224341393, 52.86350056529045, 37.59517885744572, 26.503344140946865, 62.59230472147465, 2.8730303468182683, 0.2233716077171266, 2.014843071810901, 5.142204696312547, 11.51104437187314, 1.7440959624946117, 3.377325749024749, 4.241254515945911, 8.278186395764351, 16.23335212469101, 17.456905469298363, 20.94496250152588, 22.537871226668358, 22.22765777260065, 25.729363672435284, 22.794224470853806, 14.135996717959642, 22.91537147015333, 12.909051105380058, 8.153412491083145, 7.753359982743859, 9.215469751507044, 7.337465649470687, 6.392371812835336, 9.47608731687069, 6.041028890758753, 5.96617148257792, 5.946630081161857, 1.0842605377547443, 2.0272869290784, 4.405912030488253, 8.43852449208498, 11.990094166249037, 13.580264188349247, 12.005344647914171, 13.254944644868374, 13.982985578477383, 17.113994769752026, 30.279589109122753, 45.92892587184906, 54.289510846138, 57.96270914375782, 56.84309542179108, 63.86735290288925, 68.93535375595093, 67.61435464024544, 68.48906010389328, 58.7998878210783, 55.787333473563194, 42.424389123916626, 20.090675242245197, 58.13379116356373, 52.582889422774315, 58.469814732670784, 55.506068766117096, 56.54210977256298, 44.84001450240612, 49.634156450629234, 55.35853028297424, 58.78811985254288, 60.611391216516495, 59.557320177555084, 61.5568982809782, 56.44712246954441, 51.460372656583786, 49.565186351537704, 48.60071450471878, 59.43913891911507, 64.84049588441849, 63.919174522161484, 50.93689754605293, 41.472456604242325, 37.96040005981922, 27.120360732078552, 18.866909109055996, 15.849892850965261, 8.377698305994272, 9.49756471440196, 7.205891534686089, 10.126431919634342, 10.799428056925535, 12.76354456320405, 7.49613088555634, 4.910110300406814, 10.01285221427679, 8.123078718781471, 8.219995368272066, 9.51561089605093, 12.0475385338068, 14.37611248344183, 17.54679534584284, 15.565764047205448, 13.963674064725637, 10.837609358131886, 6.7194425873458385, 3.107369947247207, 5.670823305845261, 3.679740596562624, 3.028551251627505, 1.1057935073040426, 1.8703495315276086, 0.9121875429991633, 0.14826416998403147, 2.787919663824141, 39.18601669371128, 38.77951070666313, 37.17423364520073, 58.408193439245224, 25.857813879847527, 24.356968514621258, 13.287452850490808, 2.8655117377638817, 0.307394836563617, 0.09354303911095485, 0.07151447818614542, 0.07353930937824771, 0.029342754678509664, 0.10970066272420809, 0.02831889702065382, 0.023024896036076825, 0.05486419839144219, 0.028339215168671217, 0.1070759238791652, 0.024149138444045093, 0.0916497313301079, 0.10171450805501081, 0.01754469019942917, 0.04420020792167634, 0.03219917904061731, 0.033902541545103304, 0.039419774984708056, 0.02149279895093059, 0.059090347203891724, 0.01274965179618448, 0.033302429801551625, 0.0780270466930233, 0.05077284215076361, 0.12353967598755844, 0.029041439011052717, 0.01841347610024968, 0.022043285134714097, 0.01577736755280057, 0.03474039287539199, 0.06297940883086994, 0.09139562738710083, 0.08080123923718929, 0.05156129613169469, 0.04631023766705766, 0.1020335424982477, 0.021058534948679153, 0.034137460970669053, 0.014387823121069232, 0.041989160745288245, 0.05672409097314812, 0.033199872414115816, 0.040135851013474166, 0.0452974955260288, 0.015847170252527576, 0.0864062576147262, 0.055465171026298776, 0.05679210138623603, 0.11896165640791878, 0.06584231028682552, 0.04933961768983863, 0.17306491965427995, 0.26008832501247525, 0.4522468341747299, 10.062579195946455, 77.79980689287186, 62.550430968403816, 52.18312427401543, 83.73492121696472, 56.80936083197594, 39.09823000431061, 30.382966361939907, 83.39563742280006, 2.089750589802861, 0.11481586363515817, 2.5348226074129343, 4.786007534712553, 5.216821767389774, 8.129060547798872, 2.9841883946210146, 1.3749739131890237, 7.986066620796919, 10.713075790554285, 13.680072482675314, 19.25330277532339, 18.706681206822395, 20.8154084533453, 22.796897627413273, 20.72211965918541, 16.204409077763557, 23.72553739696741, 6.8234895542263985, 2.8695015236735344, 1.3243924523703754, 7.789744455367327, 4.942377218976617, 5.281110992655158, 1.9734017830342054, 1.2748580728657544, 1.6512139840051532, 1.4279162348248065, 1.1349054076708853, 2.045224579051137, 4.7864877339452505, 10.597379598766565, 14.875487387180328, 13.496539480984211, 18.59720528125763, 24.21392899006605, 26.07329461723566, 37.01634831726551, 46.87670901417732, 63.07515241205692, 63.482612147927284, 63.2270834594965, 61.997442841529846, 66.33199945092201, 71.9972750544548, 70.7537841796875, 75.03464967012405, 62.92458929121494, 62.51679517328739, 47.063974365592, 24.41173117607832, 60.89697249233723, 59.363291189074516, 66.04281216859818, 60.240994691848755, 62.118196561932564, 47.296791672706604, 55.199736803770065, 59.87833075225353, 63.25908534228802, 64.89483296871185, 64.46721151471138, 65.41969120502472, 61.68914258480072, 59.11055915057659, 57.00461335480213, 60.34716099500656, 69.63646933436394, 72.27052599191666, 73.39430049061775, 61.08442783355713, 52.12423503398895, 43.188068345189095, 32.409281730651855, 22.729817926883698, 17.298860549926758, 11.311326138675213, 10.697512775659561, 7.112845927476883, 2.907166527584195, 1.0897322441451252, 3.0056054703891277, 7.934672003611922, 7.7621840592473745, 11.532061044126749, 4.312548665329814, 5.6155462469905615, 6.183071443811059, 10.179283283650875, 11.678038761019707, 14.217821527272463, 11.83717992156744, 10.057542566210032, 8.490758389234543, 2.9418776649981737, 3.6851427191868424, 6.098980531096458, 6.680705565959215, 2.663639970123768, 1.8637762404978275, 0.6499344622716308, 1.7178398463875055, 0.19128305691992864, 3.136523882858455, 37.721309289336205, 50.12955106794834, 41.824819296598434, 66.08979284763336, 35.19688814878464, 32.199764773249626, 19.81141682714224, 0.7861470594070852, 0.38894347788300365, 0.08455814662738703, 0.04410194756928831, 0.038054319738876075, 0.0511703772644978, 0.05244848915026523, 0.029418245940178167, 0.019156913258484565, 0.038573804558836855, 0.06147645959572401, 0.06045662994438317, 0.011425283701100852, 0.07073602464515716, 0.037757360478281043, 0.03747591210412793, 0.06166080536786467, 0.05214847966271918, 0.056181521649705246, 0.042085888562723994, 0.02751049596554367, 0.019202473704353906, 0.10003329865867272, 0.022290025117399637, 0.10934853591606952, 0.07687778648687527, 0.21453666617162526, 0.11397410489735194, 0.10326054267352447, 0.1162216323427856, 0.08532330830348656, 0.07223890337627381, 0.2569521573605016, 0.16797608725028113, 0.24807604146189988, 0.21372245595557615, 0.19690967921633273, 0.17711887165205553, 0.16185151354875416, 0.1738385047065094, 0.15398574265418574, 0.2188885904615745, 0.13946917082648724, 0.12577411194797605, 0.13409642240731046, 0.2304724173154682, 0.08144096311298199, 0.23262424481799826, 0.1082054058497306, 0.15126982354559004, 0.18204656895250082, 0.1247957386658527, 0.23656133824260905, 0.3083461511414498, 0.5055645341053605, 0.7258109876420349, 18.038029186427593, 97.83927798271179, 84.6480730175972, 69.76889982819557, 104.4281168282032, 74.325090944767, 54.6031042188406, 34.301971569657326, 82.81257390975952, 3.211513333953917, 0.3930737671907991, 6.635796250775456, 14.436262305825949, 23.105408772826195, 9.80643019080162, 8.792015723884106, 10.631459970027208, 12.729591485112906, 23.100109957158566, 25.62500987201929, 29.56212680786848, 28.411090672016144, 30.04540767520666, 32.73074448108673, 31.032038033008575, 23.246934078633785, 37.532372027635574, 22.835841737687588, 18.67486171424389, 16.075111515820026, 17.04128187149763, 12.354601956903934, 12.405025251209736, 17.70897824317217, 12.607335895299911, 10.474058166146278, 10.089274663478136, 4.8422302678227425, 2.955281683243811, 4.9846157524734735, 12.29155384004116, 20.85974257439375, 20.35721953958273, 29.536565579473972, 42.0548627525568, 41.74908936023712, 50.37295460700989, 60.85623487830162, 70.64892500638962, 69.97595831751823, 65.70189446210861, 64.4571116566658, 67.63531431555748, 71.48423418402672, 73.24802353978157, 74.21358972787857, 64.73106175661087, 64.48740363121033, 49.026048481464386, 28.72783787548542, 63.34933049976826, 62.59637430310249, 69.97934013605118, 65.2487763762474, 65.74580490589142, 50.44643886387348, 58.797714337706566, 61.641143560409546, 65.80123633146286, 65.65121278166771, 65.73063611984253, 65.6616698205471, 64.27344471216202, 58.27653810381889, 61.75343133509159, 64.61155816912651, 73.34376320242882, 71.96347966790199, 74.35969948768616, 63.89453664422035, 56.718659698963165, 45.088380575180054, 34.867195039987564, 25.777075812220573, 21.887433528900146, 13.021290432661772, 17.774387933313847, 14.10175770521164, 15.224605053663254, 16.48773517459631, 21.978697031736374, 15.65181327983737, 15.35871410742402, 23.437442556023598, 16.476843059062958, 16.75476584583521, 18.56981635093689, 21.464064046740532, 21.843707375228405, 22.43746541440487, 22.10895214229822, 17.6563548669219, 17.343768440186977, 11.408594269305468, 6.271746810525656, 10.785358361899853, 14.767565578222275, 10.524521358311176, 3.2886852929368615, 5.731696039438248, 2.949316003359854, 0.3332905954448506, 4.904956351965666, 58.51694740355015, 56.71944245696068, 49.96303640305996, 83.9433704316616, 47.876431569457054, 45.72188638150692, 52.575411424040794, 3.5266254376620054, 0.338881520438008, 0.24783772299997509, 0.2125604753382504, 0.4038172453874722, 0.1308184748631902, 0.1718188833910972, 0.16738593141781166, 0.0947768818878103, 0.1284840196603909, 0.09732609978527762, 0.19104522827547044, 0.0972650655603502, 0.2060221988358535, 0.1805698880343698, 0.0996633009344805, 0.1713292588829063, 0.16641702794004232, 0.1496088970452547, 0.14149600581731647, 0.16805384948384017, 0.12179166587884538, 0.2782414649846032, 0.08083931141300127, 0.19559931359253824, 0.2008853791630827], [0.054931169797782786, 0.051089475746266544, 0.01962291706149699, 0.018578923081804533, 0.019457288253761362, 0.02046463869191939, 0.03955735061026644, 0.022477042621176224, 0.08389881520997733, 0.07157572021242231, 0.10352821307606064, 0.13453001476591453, 0.022775300640205387, 0.029643350462720264, 0.04998888929549139, 0.07692650848184712, 0.056357306748395786, 0.03323169941722881, 0.07058162824250758, 0.11053730806452222, 0.026354827314207796, 0.06222652598808054, 0.08125054286210798, 0.006988999484747183, 0.03731425749720074, 0.03909509279765189, 0.07704760471824557, 0.06943339962163009, 0.05355945082555991, 0.2261005886248313, 1.3031329493969679, 17.240383587777615, 67.3418028652668, 39.62509833276272, 50.664721950888634, 80.97113952040672, 48.46334807574749, 41.28503166139126, 39.08781856298447, 2.669509705156088, 0.09016479772981256, 4.220885233953595, 0.3559026774019003, 4.699653843417764, 5.878963312134147, 1.520608935970813, 2.557072313502431, 8.806705735623837, 10.91603809967637, 16.447292044758797, 17.71739289164543, 19.86872535198927, 25.39072774350643, 19.80646189302206, 25.55313292890787, 12.640195582062006, 10.37230247631669, 11.481924634426832, 5.942316362634301, 8.278234843164682, 8.376558367162943, 8.041610140353441, 7.994824200868607, 6.69741184450686, 3.860167027451098, 6.054281629621983, 4.21859348192811, 1.659186074975878, 2.3283623484894633, 5.906725572422147, 10.732784382998943, 15.692236460745335, 21.83574680238962, 23.063124641776085, 18.685352951288223, 19.657941162586212, 21.178925447165966, 30.21033402532339, 39.04671996831894, 53.83326932787895, 58.616399466991425, 54.197958558797836, 60.063840597867966, 68.80767300724983, 67.49251037836075, 67.82106354832649, 61.784741654992104, 57.54897214472294, 47.276751548051834, 30.203076414763927, 54.66845691204071, 54.81927081942558, 53.96372772753239, 53.05381715297699, 47.84387871623039, 43.73609393835068, 54.23456199467182, 56.21004939079285, 58.27227473258972, 56.85790702700615, 57.25419156253338, 59.98269595205784, 59.894970059394836, 59.855205193161964, 56.45699433982372, 55.36510393023491, 61.68171018362045, 66.03598773479462, 60.73341026902199, 51.779642924666405, 40.29031343758106, 27.684753946959972, 26.78345561027527, 21.58906403928995, 16.217740662395954, 10.797121580690145, 8.767101410776377, 6.363660553470254, 8.332613725215197, 7.933040466159582, 10.543139409273863, 10.103888679295778, 9.153099898248911, 10.210547056049109, 10.185448452830315, 9.985420536249876, 13.197185844182968, 12.956531457602978, 16.105646677315235, 13.96620662882924, 14.043925758451223, 11.992306597530842, 4.538976140320301, 6.250138795003295, 0.9949270938523114, 4.935770323500037, 6.5942521300166845, 2.749515362083912, 6.350259622558951, 1.5442201565019786, 0.2526855206815526, 0.11345031933160499, 0.35317005997058004, 23.975362591445446, 30.421401299536228, 51.30074702203274, 42.64016434550285, 16.444643586874008, 20.125606767833233, 5.273291962221265, 0.8038776798639446, 0.21974260947899893, 0.15986791608156636, 0.13736231747316197, 0.06378745922120288, 0.06796120127546601, 0.03390775884327013, 0.06588822696357965, 0.10380127889220603, 0.03345606179209426, 0.018355080210312735, 0.05956546272500418, 0.1317139354068786, 0.03834815455775242, 0.0038572863422814407, 0.012345339946477907, 0.043472550678416155, 0.03364290860190522, 0.009916312865243526, 0.018675732535484713, 0.044373696073307656, 0.003952237411795068, 0.04747964718262665, 0.01766760840837378, 0.2179795189294964, 0.08929118601372465, 0.0920227867027279, 0.015453426585736452, 0.06791877269279212, 0.05950878119620029, 0.019578334395191632, 0.03462417997070588, 0.014278959333751118, 0.06068063979910221, 0.05252035130979493, 0.07541969636804424, 0.05108058110636193, 0.01735124384140363, 0.06467216604505666, 0.03059067043068353, 0.07846157415769994, 0.004019768675789237, 0.10002869734307751, 0.033877238020068035, 0.037154309829929844, 0.09981337061617523, 0.05167309696844313, 0.042105329121113755, 0.06959892823942937, 0.04529043028014712, 0.037179053033469245, 0.07240345235913992, 0.09056872644578107, 0.03943094430724159, 0.035597076202975586, 0.27340827276930213, 1.2709516449831426, 25.494327284395695, 90.94967007637024, 46.4020536839962, 65.87457239627838, 76.79111301898956, 48.25619079172611, 39.23780791461468, 49.49042156338692, 3.3011536113917828, 0.39782517473213375, 1.7848716932348907, 0.49667577201034874, 6.993797365576029, 6.622877418994904, 7.150860987603664, 2.380866981111467, 5.274022473022342, 8.891944661736488, 9.539467915892601, 14.027056563645601, 16.086856685578823, 21.782859340310097, 18.63720953464508, 22.835366763174534, 12.778390366584063, 14.546444043517113, 11.82672193273902, 8.096535243093967, 5.0722661241889, 6.539858998730779, 3.8648747373372316, 5.076063545420766, 0.4269672359805554, 2.4715712014585733, 1.2032239604741335, 1.331153952050954, 2.402764493599534, 2.7044939529150724, 6.9260745495557785, 12.791235577315092, 21.88625179231167, 25.479460582137108, 23.384076319634914, 29.52167607843876, 30.16616329550743, 36.51609756052494, 46.574119850993156, 52.51747213304043, 60.44912472367287, 63.545339182019234, 56.26755550503731, 65.10086551308632, 71.29326403141022, 73.77394571900368, 72.72788465023041, 68.1495027244091, 62.67988622188568, 54.37385872006416, 34.451307356357574, 61.41675040125847, 61.08152478933334, 61.31906904280186, 58.56716550886631, 53.60934354364872, 50.23632913827896, 58.861676305532455, 62.61814333498478, 62.55880571901798, 65.22016391158104, 63.402143865823746, 63.103795275092125, 65.69464445114136, 64.5053082704544, 63.40918868780136, 63.90477329492569, 68.18761467933655, 73.64320993423462, 70.42150720953941, 61.826486214995384, 50.032998248934746, 35.469173938035965, 32.682829052209854, 24.351247921586037, 18.07721648365259, 10.386634357273579, 8.321998994797468, 4.723585434257984, 4.709765575826168, 2.0106438221409917, 5.403418354690075, 9.547225199639797, 11.106918007135391, 12.944921180605888, 1.8002544553019106, 3.387022353708744, 9.448375403881073, 9.040582235902548, 12.21371216699481, 8.770398683845997, 9.800215624272823, 8.206778727471828, 4.102511610835791, 3.826157902367413, 3.034425023943186, 7.358989594504237, 5.649931076914072, 5.349124493077397, 3.973698760382831, 1.8140326347202063, 0.7661582319997251, 0.2718636259669438, 0.719545598840341, 34.03713338077068, 38.61915931105614, 48.43685209751129, 52.286429330706596, 22.771543487906456, 34.48878854513168, 2.1094351960346103, 0.13986437930725515, 0.13849375129211694, 0.06228908532648347, 0.11311687238048762, 0.030256121390266344, 0.04386839740618598, 0.07024859689408913, 0.0241023942726315, 0.025232625812350307, 0.07429010307532735, 0.0984622462419793, 0.1507374068023637, 0.09557047524140216, 0.025123249943135306, 0.02322148167877458, 0.046564701551687904, 0.06863101923954673, 0.037586269463645294, 0.03757261023565661, 0.020297648043197114, 0.03834133793134242, 0.01935996115207672, 0.06331261829473078, 0.01643271549255587, 0.05998710650601424, 0.13963609468191862, 0.24987138574942946, 0.19017753889784217, 0.1602938346331939, 0.13331575726624578, 0.13601705606561154, 0.11447775599663146, 0.08029111661016941, 0.171590747195296, 0.1342545889201574, 0.14604117051931098, 0.17536869447212666, 0.16445110843051225, 0.13965579128125682, 0.1570480814552866, 0.17950747394934297, 0.18659308436326683, 0.2628013794310391, 0.22550520807271823, 0.11938102179556154, 0.18615330249303952, 0.22431649529607967, 0.1833933888701722, 0.1514813504763879, 0.14925291849067435, 0.17914269352331758, 0.1363194070290774, 0.1788360974751413, 0.12747370434226468, 0.23580982466228306, 0.3049391589593142, 1.3732805103063583, 40.84243141114712, 112.19564482569695, 67.46416389942169, 80.57152256369591, 103.2868404686451, 70.10067522525787, 57.154895290732384, 55.74649326503277, 3.9394143875688314, 0.9159679245203733, 7.100832397118211, 7.497449414804578, 16.78547389805317, 14.683183506131172, 6.965791918337345, 6.305047748610377, 15.08108390495181, 16.198946870863438, 20.74338711798191, 20.929921008646488, 26.254970468580723, 33.2360527664423, 25.983651727437973, 33.53865712881088, 18.98127917200327, 22.374535091221333, 22.89172723889351, 19.02301613241434, 17.286047637462616, 14.468321185559034, 13.906010258942842, 14.94287297129631, 13.045705072581768, 11.945674549788237, 11.886792909353971, 8.49441284313798, 5.927444910630584, 2.8568142419680953, 8.032478280365467, 13.180498089641333, 23.035030849277973, 29.16775356978178, 31.616798155009747, 43.17826487123966, 46.718352511525154, 51.38969264924526, 57.85821855068207, 60.06028778851032, 65.77522292733192, 68.36698025465012, 60.12928828597069, 62.59934574365616, 71.58311247825623, 73.5113874077797, 74.00091513991356, 69.9235287308693, 66.09315946698189, 54.29454557597637, 40.168119594454765, 62.89967782795429, 65.16204982995987, 64.56028372049332, 61.884018927812576, 57.55505561828613, 55.099783167243004, 62.39254184067249, 63.56127172708511, 65.5041454732418, 66.6925773024559, 63.82908895611763, 66.39433890581131, 67.23432183265686, 66.4492991566658, 67.75686219334602, 69.51391831040382, 70.3478367626667, 73.90076771378517, 71.79872810840607, 65.91271474957466, 53.576581701636314, 36.23940780758858, 32.51774311065674, 25.100305527448654, 21.434780918061733, 14.968406651169062, 13.948459681123495, 12.25634777918458, 14.008509758859873, 12.357459403574467, 16.94699753075838, 17.78566762804985, 17.88335468620062, 25.600959062576294, 18.904946967959404, 20.246212296187878, 21.29905980080366, 17.53735665231943, 22.149389572441578, 19.236557073891163, 20.170260071754456, 18.886365965008736, 9.074775651097298, 9.385752864181995, 5.450989427044988, 12.312220931053162, 14.028975460678339, 15.626644380390644, 17.67039891332388, 3.2693554926663637, 2.6503539830446243, 0.2131320329499431, 1.1588502977974713, 32.2430482506752, 47.04127058386803, 63.420390486717224, 75.58987587690353, 31.00803092122078, 61.900327652692795, 19.970837272703648, 1.2696991371922195, 0.7310070900712162, 0.2497326338198036, 0.24186931201256812, 0.23168760992120951, 0.19684089696966112, 0.24525307497242466, 0.10930888296570629, 0.1175066981522832, 0.12632943136850372, 0.17923745093867183, 0.12837351387133822, 0.15893567469902337, 0.17429863626603037, 0.1597703088191338, 0.09474901424255222, 0.21936638513579965, 0.15151241677813232, 0.07427642529364675, 0.12822529213735834, 0.16005098907044157, 0.06909797113621607, 0.12084927933756262, 0.08310189703479409, 0.3292416752083227, 0.19692121219122782], [0.03893950895871967, 0.10679742554202676, 0.023745629041513894, 0.03545295483490918, 0.049870019502122886, 0.017556566417624708, 0.0390773628896568, 0.04399989113153424, 0.02359088568482548, 0.06470171094406396, 0.005870027252967702, 0.03261688943894114, 0.047158631205093116, 0.07397020774078555, 0.056392684928141534, 0.02928648504166631, 0.028443835726648103, 0.02248606899229344, 0.042292866128263995, 0.04050702504173387, 0.10737253061961383, 0.07769044561428018, 0.05057535665400792, 0.05371757652028464, 0.046499255258822814, 0.18437663064105436, 0.04823448558454402, 0.09168216318357736, 0.16658077540341765, 0.3814549703383818, 1.0358606348745525, 4.160175891593099, 38.64403277635574, 55.0799710303545, 48.967068046331406, 79.78406801819801, 79.251199811697, 53.374193161726, 38.65281790494919, 0.6690108636394143, 0.3562071657506749, 0.5814582773018628, 2.0107789523899555, 1.4523104508407414, 8.49832758307457, 4.672835357487202, 0.29297924134880304, 6.4422256126999855, 11.455063875764608, 12.013226374983788, 18.169726319611073, 19.101981595158577, 21.28763761371374, 20.60736581683159, 23.70568536221981, 15.054829213768244, 11.648963671177626, 13.080364912748337, 0.48839070252142847, 2.6234440645202994, 5.479978546500206, 6.995025649666786, 6.287525463849306, 4.531950792297721, 2.954840906895697, 4.204646805301309, 2.817839258350432, 0.7506036479026079, 4.229230536147952, 6.400844883173704, 11.38633506372571, 17.386291958391666, 21.767517663538456, 23.28275665640831, 23.63247849047184, 29.991380274295807, 25.52952479571104, 35.76783791184425, 42.90285184979439, 58.63296277821064, 62.2849278151989, 61.65785126388073, 54.21625837683678, 64.73258927464485, 71.78998857736588, 63.607545644044876, 64.38374519348145, 53.33918184041977, 53.19242611527443, 43.01268495619297, 52.14832194149494, 52.14198388159275, 50.746573358774185, 46.13925978541374, 43.19472178816795, 48.9295906573534, 52.09379866719246, 58.60259860754013, 57.9289061576128, 58.14300946891308, 57.90342852473259, 58.8822066038847, 60.738809779286385, 63.44460278749466, 57.925429344177246, 59.90020237863064, 69.06329289078712, 61.29603087902069, 54.05936859548092, 45.50263054668903, 44.88311178982258, 31.450044102966785, 28.000640496611595, 20.692899227142334, 13.262478690594435, 7.7542168367654085, 6.200693948194385, 3.951128921471536, 3.08280355297029, 0.7797830540221184, 1.1636258102953434, 1.84297010069713, 5.230755619704723, 10.739071145653725, 7.5028223264962435, 7.664465177804232, 8.766027018427849, 12.131022904068232, 11.505227833986282, 10.648095477372408, 9.502892028540373, 6.253916742280126, 6.097539458423853, 0.6213278160430491, 0.9983482165262103, 5.031125256791711, 3.668339070864022, 1.3105519325472414, 1.1955414852127433, 0.12310324862482958, 1.012666798196733, 0.3100229299161583, 3.2285440200939775, 20.326644480228424, 37.45637610554695, 60.805431604385376, 24.045128747820854, 23.726850226521492, 11.183797381818295, 0.5797142302617431, 0.013001678653381532, 0.09873456248897128, 0.06574780520168133, 0.08270251026260667, 0.05146046794834547, 0.05960393194982316, 0.04551533071207814, 0.0788707795436494, 0.0833371801127214, 0.03313305685878731, 0.04002523019153159, 0.10179594391956925, 0.012634967715712264, 0.036943974046153016, 0.030301494443847332, 0.05754234589403495, 0.0677224004175514, 0.053473528678296134, 0.04316448146710172, 0.10748208645964041, 0.03179497201927006, 0.07474992293282412, 0.01208212428537081, 0.1478316166321747, 0.022049552571843378, 0.16371997422538698, 0.03260395009419881, 0.04767826074385084, 0.050992139367735945, 0.0733907388348598, 0.03200972358172294, 0.05196424150199164, 0.07222477288451046, 0.043872917085536756, 0.05923152966715861, 0.06103801730205305, 0.040832772210706025, 0.05813546660647262, 0.04511339466262143, 0.13144783093594015, 0.025271087615692522, 0.061543278861790895, 0.07951753155793995, 0.038216976245166734, 0.07042127981549129, 0.05593628637143411, 0.07517765974625945, 0.09467752315686084, 0.021308328869054094, 0.08877035419573076, 0.07737756357528269, 0.17239287524716929, 0.0748583729728125, 0.07498317994759418, 0.1415868298499845, 0.251238095224835, 1.0270288400352001, 6.929718079045415, 64.39692288637161, 72.9153361916542, 60.34549668431282, 95.81012606620789, 70.9863393008709, 56.43327981233597, 42.949558943510056, 1.0616524633951485, 0.31262807606253773, 0.6021522043738514, 2.5791733525693417, 3.302575210109353, 6.067064618691802, 5.232575722038746, 3.7563784467056394, 6.975068170577288, 5.4439199063926935, 13.008742555975914, 13.064736351370811, 15.383485928177834, 19.20662797987461, 16.525073871016502, 22.71489802747965, 15.04586549475789, 21.23383440077305, 18.236908614635468, 4.559820396825671, 8.549201153218746, 2.7101900847628713, 4.914572685956955, 2.30250331107527, 1.2196768401190639, 3.045482193119824, 2.140443194657564, 2.5951248966157436, 1.7275832360610366, 4.603432081639767, 9.081909768283367, 15.46817198395729, 23.50399598479271, 25.057894103229046, 31.999918296933174, 35.848325192928314, 37.76199750602245, 37.52164900302887, 48.18750187754631, 55.407220870256424, 64.97836768627167, 67.48351246118546, 64.08951938152313, 59.839797019958496, 67.64251112937927, 77.6887920498848, 67.9761104285717, 72.33072996139526, 62.64566145837307, 60.99613577127457, 49.06024284660816, 62.431835532188416, 59.63006727397442, 58.296954408288, 53.1586117297411, 49.46524031460285, 53.429981768131256, 59.68096934258938, 64.462431371212, 64.32555511593819, 64.16929990053177, 65.50355270504951, 63.83585259318352, 65.88669374585152, 71.52892738580704, 66.64967760443687, 66.85613572597504, 77.0722371339798, 73.20146083831787, 67.81165525317192, 54.89532373845577, 51.90789744257927, 38.513939157128334, 33.05908866226673, 21.423877403140068, 13.578568529337645, 7.695579808205366, 7.183865066617727, 2.1035011019557714, 0.8816802268847823, 3.7125988584011793, 2.299402439966798, 4.58130681887269, 1.9409804977476597, 7.489832723513246, 2.2523512272164226, 3.4498403454199433, 2.700418196618557, 8.027235511690378, 9.248007405549288, 8.046597372740507, 7.938695512712002, 4.098843382671475, 2.0919050741940737, 3.334866827353835, 4.857011949643493, 5.898926965892315, 6.2758691143244505, 1.9819895597174764, 3.9005374861881137, 0.23850220284657553, 1.462523234076798, 0.6211152649484575, 6.410147259011865, 39.71983104944229, 36.334341913461685, 69.18028861284256, 36.6747010499239, 31.041332334280014, 17.097838036715984, 3.1944600865244865, 0.13091677974443883, 0.16729221300920472, 0.08397534547839314, 0.08135443611536175, 0.023205007855722215, 0.08464298894978128, 0.03278775038779713, 0.04957802149874624, 0.00664096237414924, 0.0918878048832994, 0.08401456798310392, 0.13529644551454112, 0.019341570732649416, 0.0378203799482435, 0.0558323114819359, 0.07739366075838916, 0.03588962339563295, 0.08919237647205591, 0.061943196269567125, 0.06681842744001187, 0.03963291979744099, 0.07309228414669633, 0.024067958620435093, 0.16960752080194652, 0.018891697509388905, 0.09108476398978382, 0.1621956325834617, 0.22377499466529116, 0.22972449572989717, 0.2595440932782367, 0.11139683381770737, 0.17032182309776545, 0.08080885367235169, 0.19097966694971547, 0.11005378401023336, 0.23202306067105383, 0.19429170875810087, 0.1699500367976725, 0.11271778988884762, 0.2422950227628462, 0.18979171116370708, 0.24785127461655065, 0.1690991793293506, 0.14120104664471, 0.22795536409830675, 0.17921172810019925, 0.22683892166242003, 0.2577918232418597, 0.1366963586769998, 0.2257703774375841, 0.15142459102207795, 0.2897019172087312, 0.20033120264997706, 0.24831723945681006, 0.3331435314612463, 0.552827229257673, 1.0461330274119973, 10.614810213446617, 93.5848818719387, 98.12186121940613, 81.45234569907188, 113.26226279139519, 99.37232851982117, 73.2526820898056, 64.0532161295414, 2.4449023324996233, 0.6227270315866917, 1.3699549762532115, 5.3171169105917215, 5.704820556566119, 19.50055740773678, 14.5154975540936, 5.163390459492803, 10.752111095935106, 16.587812304496765, 16.987235471606255, 26.902706511318684, 22.93923418968916, 26.937239058315754, 24.318911656737328, 27.379366233944893, 20.79936381429434, 20.93691263347864, 23.19715864956379, 8.947644922882318, 13.305499982088804, 11.367304734885693, 10.617710407823324, 10.801157914102077, 12.10777385160327, 10.720996465533972, 7.417374886572361, 6.119015431031585, 3.7242713570594788, 5.336641212925315, 12.579933665692806, 17.15132776647806, 25.85801526904106, 26.525115072727203, 34.353037029504776, 40.99176339805126, 48.72218258678913, 48.4323151409626, 62.60139763355255, 64.84174221754074, 70.45436784625053, 72.13263899087906, 67.77909860014915, 58.449432626366615, 68.03333535790443, 78.64186450839043, 69.13586899638176, 70.47203689813614, 64.1239683330059, 64.07903954386711, 53.04835684597492, 65.73551505804062, 63.65212105214596, 63.62795054912567, 57.61209435760975, 54.690712317824364, 59.52791355550289, 62.92243480682373, 68.4205649793148, 67.40977361798286, 68.29597726464272, 67.67158716917038, 68.9029186964035, 67.98075377941132, 74.41107273101807, 73.41057121753693, 72.61560067534447, 80.79259470105171, 72.90250808000565, 68.86572629213333, 60.20016968250275, 57.37774193286896, 40.497679710388184, 33.126956820487976, 23.33853766322136, 19.54858873039484, 12.848033029586077, 13.346032407134771, 9.779816418886185, 8.858244270086288, 8.46250120550394, 11.647832281887531, 11.054850351065397, 12.386791929602623, 17.93142020702362, 16.334003023803234, 14.068994913250208, 12.59497420862317, 16.594697535037994, 18.34551438689232, 13.635967299342155, 12.992992401123047, 8.643579538911581, 11.835360769182444, 2.7389899268746376, 8.582570012658834, 12.695432268083096, 11.935529094189405, 4.715399723500013, 3.2213947037234902, 1.015494440216571, 2.6213591638952494, 0.39998779306188226, 4.776512794196606, 44.566949754953384, 49.779798835515976, 92.56059363484383, 52.70423971116543, 48.37319791316986, 48.938744366168976, 7.208590339869261, 0.38673754781484604, 0.4757081111893058, 0.30292140785604715, 0.2606953721260652, 0.19542093097697943, 0.17802023969125003, 0.11941409189603291, 0.14971033378969878, 0.13938858843175694, 0.22266536514507607, 0.1992882922058925, 0.13937948970124125, 0.09442569760722108, 0.16489869769429788, 0.11148788791615516, 0.176749742240645, 0.11543021348188631, 0.16953266778727993, 0.14831561566097662, 0.17593737255083397, 0.13209385564550757, 0.18650959274964407, 0.10440786587423645, 0.3041239542653784, 0.15632197901140898, 0.17204186908202246], [0.10664197528967634, 0.020846072911808733, 0.050686322574620135, 0.04619267405360006, 0.0538745222002035, 0.05393957515479997, 0.03934945649234578, 0.010702571016736329, 0.04380290658446029, 0.0982291302352678, 0.053055113239679486, 0.1254037654143758, 0.08437545213382691, 0.05317436152836308, 0.007980200789461378, 0.018196520359197166, 0.040330167539650574, 0.06222136064025108, 0.06550786885782145, 0.07386184675851837, 0.059078929261886515, 0.07042990357149392, 0.07898360083345324, 0.026369837250967976, 0.07241287021315657, 0.06221842173545156, 0.02037546037172433, 0.07439974797307514, 0.06541436567204073, 0.16014773544156924, 0.2976314089028165, 0.6606123049277812, 15.295648891478777, 51.75021730363369, 47.16373801231384, 38.91455926001072, 79.08375799655914, 54.84316013753414, 35.9733422845602, 0.5557401885744184, 0.13969337363960221, 0.5913426156621426, 0.4353402054402977, 3.0396858416497707, 2.1496246894821525, 4.16169723495841, 1.1457132152281702, 2.9666805965825915, 6.235489631071687, 8.378033638000488, 12.770489640533924, 15.617715809494257, 19.47834949940443, 19.94459968060255, 22.603372111916542, 21.296823620796204, 6.167737366631627, 7.1413790713995695, 2.2038610791787505, 1.0183170950040221, 4.810149064287543, 5.941639048978686, 5.389391407370567, 2.2436696430668235, 1.9720805226825178, 2.89769624825567, 1.6288572899065912, 0.9645967651158571, 3.771118330769241, 5.156749365851283, 6.977795949205756, 18.23402836918831, 22.647426947951317, 24.263932406902313, 24.02492333203554, 30.39563488215208, 33.156196251511574, 42.7714017033577, 49.66592654585838, 59.98687192797661, 67.6878122985363, 65.63501045107841, 57.9644950479269, 54.78962101042271, 63.44796180725098, 63.78406897187233, 59.36644122004509, 59.34538275003433, 53.95476020872593, 32.776668816804886, 47.56538026034832, 51.438995003700256, 49.49185408651829, 46.45488604903221, 45.85847765207291, 49.27886411547661, 54.3527090549469, 56.84212647378445, 58.32879289984703, 61.44891947507858, 60.642321556806564, 66.251550167799, 68.98143768310547, 66.34646907448769, 66.49046614766121, 70.68358674645424, 65.51429092884064, 55.111756324768066, 45.625162571668625, 36.997299939394, 33.3242080360651, 29.479853622615337, 20.64316749572754, 13.194045312702656, 6.824556821957231, 5.914647672325373, 3.893321673385799, 0.6087399227544665, 0.12265197830856778, 0.12851757957832888, 0.8248498826287687, 0.6356671778485179, 3.652123915962875, 2.3967781523242593, 4.772038059309125, 9.296792037785053, 8.758567068725824, 7.57045584730804, 9.004437625408173, 7.112364303320646, 5.231442907825112, 4.164355667307973, 0.8886413346044719, 3.2412726245820522, 2.1428080927580595, 4.258442418649793, 5.25207057595253, 1.4118151925504208, 2.882208516821265, 2.096145646646619, 0.3208402666496113, 1.155377165414393, 21.836033686995506, 28.978158943355083, 56.47552974522114, 30.28409756720066, 13.993282075971365, 14.3115377984941, 10.165433026850224, 0.7651272998191416, 0.31345830182544887, 0.044170047040097415, 0.07398437533993274, 0.035141234257025644, 0.056370446473010816, 0.024638224895170424, 0.07501543368562125, 0.10856060514925048, 0.0623377924785018, 0.044149734458187595, 0.01838437277910998, 0.08661255240440369, 0.02467394446284743, 0.028351846522127744, 0.07068371065543033, 0.06948460038984194, 0.02478617574524833, 0.03754949975700583, 0.046971873453003354, 0.04624643894203473, 0.006369015809468692, 0.0576081335748313, 0.009097425263462355, 0.02550638368120417, 0.09883490085485391, 0.008702454269950977, 0.10271221428411081, 0.03883969009621069, 0.06835020540165715, 0.013991787145641865, 0.02802736657031346, 0.030545520021405537, 0.009066884031199152, 0.028874157069367357, 0.0147582522185985, 0.03577133618819062, 0.052814167574979365, 0.06078426587919239, 0.05486041714902967, 0.08293296938063577, 0.014352766847878229, 0.02435972841340117, 0.02414402875729138, 0.059409270324977115, 0.09770032775122672, 0.07279628596734256, 0.029038294160272926, 0.1702452779863961, 0.13325832987902686, 0.05743312030972447, 0.07009193694102578, 0.007758900237604394, 0.06416778021957725, 0.08615578277385794, 0.07897470248281024, 0.18799522396875545, 0.29443806619383395, 0.982204070314765, 28.351412974298, 77.02720195055008, 62.61655122041702, 59.64954882860184, 84.77410465478897, 55.59543997049332, 52.683356031775475, 0.4141723131760955, 0.2466531959362328, 0.31867343292105943, 0.3132867766544223, 4.0215526800602674, 2.1508826594799757, 5.32486516982317, 7.9776823706924915, 5.295484671369195, 4.716717777773738, 5.123231364414096, 12.096972931176424, 15.232609324157238, 16.1327563226223, 15.658959746360779, 18.559760190546513, 15.45629857107997, 11.298588272184134, 23.69870513677597, 9.233091305941343, 7.300211498513818, 10.948157776147127, 3.5365635668858886, 1.7720778984948993, 0.30713107727933675, 0.5810793663840741, 0.929885390214622, 0.34086513274814934, 0.45276420016307384, 3.2485706079751253, 6.64878205396235, 9.82623852789402, 22.839880920946598, 28.664987348020077, 26.41793992370367, 33.25477056205273, 41.33271150290966, 43.39445427060127, 52.019379660487175, 60.08052550256252, 66.9950258731842, 70.98448500037193, 67.66040816903114, 60.718100890517235, 61.51198849081993, 68.22018653154373, 66.78241208195686, 66.40057817101479, 66.50539174675941, 61.99810780584812, 40.59494309127331, 55.48613503575325, 58.918228670954704, 57.63231307268143, 53.40667761862278, 51.78947679698467, 56.136789321899414, 63.32732208073139, 63.73530238866806, 64.95288625359535, 65.10683119297028, 65.05597472190857, 70.38312926888466, 72.7581538259983, 72.06345230340958, 70.94153970479965, 77.11565360426903, 77.36292913556099, 67.10689187049866, 54.922431483864784, 44.78458307683468, 40.01254454255104, 33.4526639431715, 23.141434639692307, 13.107526805251837, 7.589001227170229, 5.1013364642858505, 1.5808431850746274, 0.38535029569175094, 0.3969762765336782, 2.4738468043506145, 0.8174504328053445, 0.6032424489967525, 2.173711834475398, 3.8218978559598327, 3.3341410662978888, 4.764036638662219, 5.853179795667529, 5.108391735702753, 7.202106937766075, 2.8232648922130466, 4.1042029950767756, 4.065087419003248, 2.9185785027220845, 6.159217273816466, 3.8721090741455555, 4.9959928169846535, 1.2033348670229316, 2.5832187104970217, 1.6617020149715245, 1.9768219557590783, 0.3846193989738822, 1.4342883741483092, 45.15217915177345, 32.491243332624435, 61.83203011751175, 44.77069102227688, 23.73243972659111, 29.920692667365074, 2.5712493527680635, 0.3735293971840292, 0.4268866387428716, 0.0783518550451845, 0.10434208932565525, 0.06914871177286841, 0.05480102678120602, 0.019879115716321394, 0.04667072105803527, 0.13375196198467165, 0.053760457813041285, 0.15224871633108705, 0.03137357685773168, 0.2127688704058528, 0.03513442505209241, 0.060098217145423405, 0.022909727704245597, 0.017418760726286564, 0.008980219736258732, 0.04331878881203011, 0.059791802923427895, 0.0226921262947144, 0.023926588764879853, 0.07783376917359419, 0.06819980175350793, 0.0362102163489908, 0.09346847553388216, 0.07651051986613311, 0.19673269183840603, 0.08078082275460474, 0.1645314830238931, 0.21155259426450357, 0.2610517217544839, 0.1839138867217116, 0.2000149735249579, 0.1468763389857486, 0.12439301222912036, 0.16095817554742098, 0.13220808701589704, 0.18709032330662012, 0.33799224940594286, 0.21043025917606428, 0.1108829707663972, 0.17233770398888737, 0.14314078318420798, 0.1590699440566823, 0.25294933933764696, 0.16288805636577308, 0.1393366529373452, 0.2621037606149912, 0.24699934845557436, 0.13881559105357155, 0.1366356955259107, 0.23973523668246344, 0.22402070491807535, 0.21000456326873973, 0.1748784168739803, 0.3151098178932443, 0.3488086361903697, 1.3110964908264577, 45.61071954667568, 99.63291093707085, 85.61189889907837, 71.76580667495728, 110.35057783126831, 69.98914361000061, 57.9963905364275, 1.6685943701304495, 0.2748973178677261, 1.4254663162864745, 1.3562464993447065, 8.265800960361958, 9.147834330797195, 13.67752281948924, 10.434117559343576, 7.253819787874818, 11.148574221879244, 11.505670510232449, 13.100468683987856, 22.258367724716663, 22.81921572983265, 22.848812341690063, 22.776462323963642, 22.994821406900883, 10.786919128149748, 19.865451827645302, 10.689330864697695, 9.40620431676507, 14.93980748578906, 11.964914817363024, 10.136846210807562, 4.419583696871996, 3.9112593233585358, 5.268135638907552, 4.7338206600397825, 2.2672685142606497, 3.083521951921284, 8.386617377400398, 11.661446001380682, 24.632161147892475, 28.20555780082941, 30.514085926115513, 41.1696470528841, 46.88373863697052, 54.11111421883106, 59.224860817193985, 63.25943112373352, 69.16450425982475, 73.85434180498123, 69.54721972346306, 61.13841533660889, 57.987616807222366, 67.89921015501022, 68.48809495568275, 68.46550896763802, 70.50246566534042, 66.460622549057, 45.46742923557758, 60.98686806857586, 65.10502249002457, 64.3751348555088, 58.51023316383362, 58.64897511899471, 62.23352797329426, 68.38816791772842, 68.56510922312737, 70.37812113761902, 69.55409735441208, 67.36865222454071, 76.74108490347862, 76.48332953453064, 73.68119269609451, 75.74633628129959, 80.60420081019402, 77.44081735610962, 71.15280836820602, 64.7969502210617, 57.063631787896156, 49.129000157117844, 40.30383691191673, 28.9984118565917, 18.94985105842352, 12.359393499791622, 13.184690214693546, 7.763043288141489, 1.312208406161517, 1.445335925091058, 6.169179864227772, 0.5990784068126231, 0.28567350993398577, 4.049142999574542, 14.037823285907507, 8.9006157964468, 13.568025045096874, 14.916154704988003, 11.665857564657927, 12.669726647436619, 12.13629512116313, 7.022327184677124, 10.336957722902298, 2.422920987010002, 9.316309690475464, 4.413235662505031, 14.146435707807541, 12.89082633331418, 6.31385900080204, 7.138931527733803, 6.950175706297159, 0.6453895498998463, 1.6749954828992486, 47.2663439065218, 41.13212026655674, 84.75845709443092, 63.7799271941185, 35.84172494709492, 61.35495811700821, 19.74324658513069, 1.451939851976931, 1.0868857218883932, 0.1956747454823926, 0.39062191906850785, 0.19872811913955957, 0.3014112263917923, 0.1083368253603112, 0.14957161154597998, 0.2122785334358923, 0.16840172378579155, 0.2812663104850799, 0.11892181792063639, 0.29026675096247345, 0.11640322103630751, 0.2171352517325431, 0.1831751232384704, 0.23276045860257, 0.13922525657108054, 0.13258667138870806, 0.1875976999872364, 0.1047380176896695, 0.10028410004451871, 0.24323054443811998, 0.20202272047754377, 0.1390979188727215, 0.14908436191035435, 0.26769836666062474], [0.06092549658205826, 0.052981714834459126, 0.04690662754001096, 0.019937044053222053, 0.010454509083501762, 0.07551877308287658, 0.14230804896214977, 0.028631020213651937, 0.02373351904680021, 0.06177826508064754, 0.04408480766869616, 0.032214448729064316, 0.02034506014751969, 0.0303485317635932, 0.010003309271269245, 0.08402086881687865, 0.029218637901067268, 0.08915277547203004, 0.014443545424001059, 0.05563747545238584, 0.04770802457642276, 0.027940652180404868, 0.044366374786477536, 0.01966507847100729, 0.05305105740262661, 0.04314242483815178, 0.050466286920709535, 0.06733352245646529, 0.04998934571631253, 0.01697265761322342, 0.052397470208234154, 0.5413965519983321, 1.0701745748519897, 21.733938865363598, 41.33182995021343, 28.099571987986565, 54.5858683437109, 64.26867976784706, 42.32852406799793, 10.158471800386906, 0.3682252677390352, 0.3240978199755773, 1.022524181753397, 2.422083131968975, 1.092576035298407, 3.3363045752048492, 3.2199792796745896, 7.827037554234266, 2.150940131396055, 9.824187587946653, 9.214097075164318, 14.031052999198437, 18.223905712366104, 18.973248302936554, 18.70247483253479, 17.41431165486574, 12.264404296875, 4.433462452143431, 5.459340428933501, 5.370563892647624, 5.111844325438142, 2.7808211697265506, 4.029826736077666, 3.275261325761676, 4.504623608663678, 3.163699312135577, 1.7376955621875823, 0.508349072188139, 1.4912026701495051, 5.445689661428332, 10.13742757961154, 19.508916959166527, 21.12585749477148, 22.61503178626299, 29.132983535528183, 36.60432502627373, 40.16184613108635, 50.95092639327049, 61.03557765483856, 68.25249999761581, 71.86532333493233, 72.64649301767349, 70.0602225959301, 60.44200390577316, 55.08359603583813, 55.78513339161873, 58.091092854738235, 51.89490593969822, 53.313358426094055, 34.06221963465214, 38.9288616925478, 48.60725395381451, 45.42217366397381, 49.14674520492554, 47.42067642509937, 50.4309356957674, 56.654910519719124, 58.74874256551266, 60.14999337494373, 60.95064081251621, 63.181117326021194, 65.66636636853218, 68.59368368983269, 71.63266181945801, 72.41307154297829, 71.54797196388245, 68.29840913414955, 50.756186842918396, 34.94621179997921, 28.279161751270294, 22.19992496073246, 19.249985553324223, 10.978381354361773, 5.665198182687163, 2.291788123548031, 0.5402773933019489, 0.29865756165236235, 0.09578296696417965, 0.3669326542876661, 0.12045616371324286, 0.09448426790186204, 0.11923552374355495, 0.19940385944209993, 1.178684877231717, 2.71412406116724, 4.894638955593109, 4.728597840294242, 6.497723534703255, 5.718384403735399, 5.020892405882478, 4.521224917843938, 1.7468379903584719, 0.3477238240884617, 5.687190927565098, 5.02461620606482, 3.478845851495862, 1.140679435338825, 1.5677721239626408, 4.716642731800675, 0.3888722020201385, 0.2709011791739613, 18.43031443655491, 25.265883542597294, 47.17890299856663, 44.01152975857258, 13.801338225603104, 6.796760363504291, 4.427676312625408, 3.0013166880235076, 0.08846652635838836, 0.06921757565578446, 0.058949242666130885, 0.0377850574295735, 0.013437380566756474, 0.02916018449468538, 0.040061795807559974, 0.05165413880604319, 0.11930078821023926, 0.08342062719748355, 0.04530082776909694, 0.12094341334886849, 0.1118670882715378, 0.04175417823716998, 0.011947998718824238, 0.05510236100235488, 0.007393963960566907, 0.08935073594329879, 0.017172560656035785, 0.07226579138659872, 0.03197228965291288, 0.06609033604036085, 0.01771500381437363, 0.031744643274578266, 0.12023204253637232, 0.12638699234230444, 0.07061515105306171, 0.09591496534994803, 0.1292373292380944, 0.033898055262397975, 0.014861761410429608, 0.04814156127395108, 0.046291613471112214, 0.05721216439269483, 0.026139567380596418, 0.041894024834618904, 0.11662913078907877, 0.015298609941964969, 0.043902098332182504, 0.07262786297360435, 0.03769017384911422, 0.06671048206044361, 0.05424800801847596, 0.09987330646254122, 0.058468145434744656, 0.01946736290847184, 0.06298230320680887, 0.1377515887725167, 0.09728102915687487, 0.04215330525767058, 0.015622854261891916, 0.020504475323832594, 0.01862664874352049, 0.03727710929524619, 0.02844770046067424, 0.18530112400185317, 0.06625654001254588, 0.12223935904330574, 0.7924344157800078, 1.70541285071522, 43.42841684818268, 68.27779144048691, 40.291601568460464, 74.261634349823, 66.83079108595848, 56.30994603037834, 16.913599222898483, 0.36471107974648476, 0.9159662027377635, 0.883719886187464, 0.6171986251138151, 2.098514582030475, 0.9581004199571908, 3.0205144453793764, 4.110108353197575, 2.656576386652887, 0.981528953416273, 3.084323708899319, 12.34232671558857, 10.490001160651445, 13.442661222070456, 14.119668994098902, 11.885896157473326, 8.185181636363268, 7.700942745432258, 14.189240410923958, 12.202026844024658, 7.458070702850819, 1.4526633569039404, 2.995746899396181, 2.2327445168048143, 3.669199487194419, 1.9786772062070668, 1.7469658772461116, 0.4975333088077605, 2.517512636259198, 7.677735490724444, 11.289535257965326, 23.500418476760387, 24.323384016752243, 26.231586523354053, 32.638443633913994, 41.23350262641907, 50.039351508021355, 61.988695710897446, 68.68411883711815, 77.05576121807098, 78.01640287041664, 76.88154056668282, 72.86328658461571, 64.55614194273949, 62.036664336919785, 63.32571096718311, 67.0615603029728, 61.62143021821976, 62.62017622590065, 42.87401519715786, 46.796841099858284, 58.69677655398846, 54.02440287172794, 57.267479449510574, 56.0476803034544, 58.342293575406075, 63.914949148893356, 62.31441803276539, 64.80013445019722, 66.26197680830956, 69.473936855793, 70.025325268507, 73.21508690714836, 72.83028915524483, 74.97273579239845, 76.89451307058334, 77.50758737325668, 64.48586851358414, 48.61229628324509, 34.371188655495644, 25.610924027860165, 19.144066236913204, 12.953141089528799, 7.251522811129689, 1.1753969849087298, 0.2261508468654938, 0.09469750177231617, 0.12936423649080098, 0.06637165453867055, 0.6855874741449952, 1.9856447260826826, 1.8921584612689912, 1.6134399734437466, 1.3137244060635567, 1.2538371258415282, 4.381618509069085, 2.588135884143412, 2.203848729841411, 1.1845394130796194, 0.5156963935587555, 3.7485437421128154, 2.8282300382852554, 2.2012223582714796, 8.143642265349627, 3.9254848100245, 3.9430360682308674, 3.6716610426083207, 1.4216690137982368, 1.6760726063512266, 0.3676304215332493, 0.18877032300224528, 46.83770790696144, 34.45605710148811, 49.91262450814247, 55.21632671356201, 30.57979390025139, 23.096325360238552, 9.114882498979568, 0.5238947505131364, 0.2597820555092767, 0.18576735601527616, 0.039626622674404643, 0.04621357293217443, 0.1317056530388072, 0.035512029789970256, 0.09759979642694816, 0.055904886103235185, 0.05520406863070093, 0.07123206130927429, 0.07277959506609477, 0.013910853158449754, 0.03501428247545846, 0.04465564910788089, 0.05245067848591134, 0.015250132855726406, 0.037493775598704815, 0.04019213178253267, 0.019944634368584957, 0.04733066103653982, 0.07023265556199476, 0.10588396791717969, 0.019159085895807948, 0.025063468092412222, 0.07079410512233153, 0.12308710691286251, 0.06517495625303127, 0.19643933570478112, 0.2450088638579473, 0.11653784662485123, 0.08542821087758057, 0.2056819834979251, 0.2960712363710627, 0.21516735811019316, 0.1874191392562352, 0.10492966248420998, 0.2521650673588738, 0.09777628656593151, 0.24931904976256192, 0.16585121455136687, 0.11653600609861314, 0.12710923561826348, 0.09734555147588253, 0.12576014472870156, 0.2919356035999954, 0.09796493308385834, 0.1376187294954434, 0.23138211225159466, 0.21359735954320058, 0.19478483620332554, 0.1292011421173811, 0.18567009014077485, 0.09581775142578408, 0.23633256379980594, 0.2853119355859235, 0.3253533854149282, 0.2012928033946082, 0.18650907324627042, 1.0929684829898179, 5.192682137712836, 71.80014923214912, 96.637904047966, 66.34593710303307, 89.26686957478523, 94.62304696440697, 68.78229036927223, 19.51096124947071, 0.8731676742900163, 1.003627439495176, 1.9371722708456218, 6.143678007647395, 5.9701246954500675, 10.458058174699545, 12.551183458417654, 14.820315297693014, 4.82980920933187, 16.557204946875572, 17.8037603572011, 18.589079417288303, 21.04911871254444, 24.822992607951164, 25.59991791844368, 22.184571884572506, 16.00786842405796, 7.4910220596939325, 13.379031736403704, 13.216860238462687, 16.094300486147404, 8.882788103073835, 6.872573895379901, 3.6353934137150645, 6.518454747274518, 6.245539616793394, 3.0041427863761783, 0.34448909922502935, 2.424913505092263, 9.42535338923335, 13.585256170481443, 26.790646724402905, 23.662553876638412, 30.790268406271935, 39.002691730856895, 48.1939235329628, 55.294929295778275, 67.3393101990223, 71.35015457868576, 77.93947979807854, 76.29542961716652, 75.44682875275612, 74.53328177332878, 65.30043840408325, 62.41996876895428, 65.17958208918571, 69.20266941189766, 66.90767616033554, 68.96990910172462, 49.36412774026394, 55.45026496052742, 68.44252020120621, 60.767494440078735, 66.35764047503471, 64.33270633220673, 65.00443428754807, 69.42476749420166, 67.99957036972046, 70.84482729434967, 70.86824923753738, 75.2710273861885, 74.83230292797089, 76.13285154104233, 75.13516947627068, 75.14202430844307, 76.9917194545269, 76.42391592264175, 70.07719248533249, 59.845515713095665, 54.00566227734089, 42.962721437215805, 35.015280693769455, 21.493204683065414, 14.060719907283783, 7.958858655765653, 2.276736181229353, 0.3035496507072821, 0.5056459328625351, 1.1247945064678788, 1.717096867505461, 3.31306217238307, 3.456897991709411, 1.8749707960523665, 0.7751662423834205, 4.453145870938897, 12.418229542672634, 7.334199249744415, 10.441547110676765, 10.438342932611704, 9.350110776722431, 10.872561782598495, 5.193350901827216, 1.9004858331754804, 13.65027828142047, 14.31761747226119, 9.576588124036789, 6.830153446644545, 6.798273157328367, 10.879893489181995, 1.198781286366284, 0.27452657057438046, 43.778685852885246, 42.192301377654076, 70.38850218057632, 81.69979602098465, 39.70309294760227, 49.98012028634548, 34.92817036807537, 5.359513135626912, 0.26899228629190475, 0.4098406049888581, 0.23038655082928017, 0.1745881183887832, 0.22615685826167464, 0.0792602586443536, 0.1781773375114426, 0.21851592842722312, 0.19408200751058757, 0.24148863478330895, 0.17599595768842846, 0.22524751955643296, 0.17908617155626416, 0.08947633701609448, 0.18899736081948504, 0.13265260378830135, 0.10017971697379835, 0.10584763236693107, 0.13278757076477632, 0.16975428792648017, 0.1088287950551603, 0.21971329464577138, 0.12238555471412838, 0.12209872948005795, 0.2625928062479943, 0.23724476719507948, 0.10542024436290376], [0.05373341766244266, 0.10905719100264832, 0.03815670272160787, 0.015757856490381528, 0.04844291404879186, 0.055021047592163086, 0.010913278802036075, 0.08180185468518175, 0.037125347516848706, 0.04326363981817849, 0.02352891635382548, 0.012008190606138669, 0.061313866171985865, 0.0664195156423375, 0.057223689946113154, 0.06741612349287607, 0.08967270186985843, 0.025407731845916715, 0.048265329241985455, 0.018996668732143007, 0.033210325564141385, 0.003871212975354865, 0.01542255973618012, 0.038654320160276257, 0.14205890998709947, 0.04895137426501606, 0.06987629851209931, 0.10815834626555443, 0.06348235488985665, 0.02139791537047131, 0.11166317577590235, 0.13236294355010614, 0.5532623652834445, 10.463584028184414, 9.323013480752707, 40.95424421131611, 39.69671308994293, 67.67782643437386, 61.53867065906525, 38.829960599541664, 11.385192275047302, 0.5652076180558652, 0.6444822298362851, 1.198985525406897, 1.3838230445981026, 1.550821946002543, 7.94998518191278, 2.802672372199595, 1.451456209179014, 0.7466304861009121, 4.911880055442452, 11.98851440101862, 9.916456136852503, 10.66212622448802, 16.27898197621107, 11.680509578436613, 14.124181251972914, 12.75753328576684, 4.565704381093383, 8.416120894253254, 18.462563306093216, 0.9131275175604969, 1.7901152931153774, 0.7400161097757518, 0.5009844736196101, 0.3022770752431825, 0.9159654309041798, 0.49231520912144333, 2.7738309698179364, 2.702874052338302, 7.964815786108375, 13.610711954534054, 18.98295108228922, 27.045286260545254, 30.544091016054153, 40.464564487338066, 45.992789044976234, 55.07965564727783, 61.49637892842293, 64.48559492826462, 69.4753959774971, 74.56301897764206, 75.97184658050537, 76.32327452301979, 63.38827840983868, 54.67982590198517, 56.876279041171074, 47.55881801247597, 50.31570307910442, 26.656164340674877, 14.435736984014511, 55.5046172440052, 50.08322015404701, 57.97813631594181, 57.68808647990227, 59.08721320331097, 62.440829649567604, 60.628547295928, 64.24867004156113, 64.98981267213821, 68.23742240667343, 73.7086272239685, 73.23597058653831, 61.57022036612034, 60.28414137661457, 64.55627113580704, 56.6912517696619, 41.16543307900429, 27.689256705343723, 16.156943924725056, 9.864583220332861, 5.390619691461325, 5.348053425550461, 1.1966005596332252, 0.40010086668189615, 0.16587753110798076, 0.3123923105886206, 0.3819834388559684, 0.19528499920852482, 0.3272928547812626, 0.2047991839936003, 0.5353087442927063, 0.458960302057676, 0.1504419429693371, 0.23810108687030151, 0.06887577212182805, 0.8314010873436928, 2.220351956784725, 2.6592452684417367, 0.5083430162630975, 2.4367175716906786, 1.5325823309831321, 5.562823126092553, 5.356902200728655, 3.2999322144314647, 2.561975000426173, 0.6480405014008284, 0.7166901708114892, 0.7137838611379266, 0.42924438253976405, 19.180831164121628, 19.698281697928905, 40.50191268324852, 60.11450707912445, 22.713134922087193, 10.891547463834286, 10.665665734559298, 8.304114304482937, 0.33912589482497424, 0.2762198547134176, 0.06066842033760622, 0.11066382940043695, 0.06794591303332709, 0.08371318923309445, 0.060668802543659694, 0.035302020551171154, 0.04023584428068716, 0.050739467769744806, 0.05337586575478781, 0.08068142691627145, 0.05841730460815597, 0.047749495788593777, 0.04336025631346274, 0.026317079828004353, 0.030421351293625776, 0.023166883729572874, 0.04110690671950579, 0.0457764071325073, 0.030931308792787604, 0.12337692300206982, 0.019916343699151184, 0.05908079576329328, 0.019588089926401153, 0.12092143835616298, 0.019106684703729115, 0.02355632201215485, 0.05680521142494399, 0.12081897002644837, 0.029546852711064275, 0.03148298055748455, 0.03688749289722182, 0.08532325635314919, 0.026207984119537286, 0.0460497364110779, 0.024894443959055934, 0.02093313425575616, 0.05964699506876059, 0.04982965408999007, 0.07579241035273299, 0.06292166232015006, 0.046025802148506045, 0.027999552730761934, 0.023114794239518233, 0.020956074040441308, 0.05808426583826076, 0.019835889324895106, 0.06446619037888013, 0.06536593311466277, 0.0644037831807509, 0.050390580436214805, 0.11651894412352704, 0.0813303905306384, 0.016708046714484226, 0.08259293957962655, 0.0560934250097489, 0.10154162475373596, 0.056582760080345906, 0.07535606462624855, 0.6865485257003456, 20.071115791797638, 29.91419691592455, 62.99275003373623, 57.84943722188473, 85.00706255435944, 64.58764985203743, 62.22986117005348, 15.321188271045685, 0.6898243655450642, 1.2622984405606985, 1.2696162541396916, 0.4633993247989565, 1.011033479589969, 2.4838388431817293, 1.428259047679603, 2.1316176932305098, 3.150512119755149, 3.8465711195021868, 3.6220428301021457, 7.156429113820195, 4.588373014703393, 10.456312168389559, 12.447609566152096, 12.470892816781998, 7.291055414825678, 8.951433319598436, 6.126644471660256, 10.826025679707527, 6.918983655050397, 2.4344816291704774, 0.9797786129638553, 0.580501559888944, 0.34992901200894266, 0.39993186481297016, 0.9688150137662888, 4.307047985494137, 1.6265458264388144, 7.278247252106667, 14.875778071582317, 24.651135429739952, 31.487164311110973, 36.240623742341995, 46.229858323931694, 52.07444250583649, 61.00403934717178, 70.60861676931381, 72.54664957523346, 76.02429896593094, 79.24146473407745, 80.97492411732674, 79.39552366733551, 70.11319935321808, 61.6147767752409, 64.61477279663086, 55.79655937850475, 64.94739174842834, 33.251810520887375, 18.193207159638405, 66.8516443669796, 60.03865174949169, 65.34649953246117, 63.93233701586723, 65.89990943670273, 67.48105019330978, 66.19496360421181, 69.00903180241585, 68.85845348238945, 72.77643084526062, 73.48209857940674, 76.02129712700844, 61.54667682945728, 61.91035911440849, 67.71536082029343, 65.7922688126564, 53.39765690267086, 35.572076216340065, 23.31609796732664, 14.470009244978428, 8.635363429784775, 3.841037666425109, 2.287952941842377, 0.20817758864723146, 0.08895764258340932, 0.16619147441815585, 0.3435015381546691, 0.6154330261051655, 0.9461432334501296, 1.0058105411008, 1.3530286657623947, 0.8933023188728839, 1.1644820705987513, 0.8029477985110134, 0.7091827830299735, 3.1436295015737414, 2.018958250992, 2.8465179819613695, 4.31822651065886, 2.8519464656710625, 3.283403101377189, 5.8070635702461, 8.567396476864815, 3.7675315607339144, 0.33838748757261783, 1.108847118448466, 0.5538006301503628, 1.012114759068936, 0.30632471898570657, 41.50594420731068, 31.93235032260418, 39.67967480421066, 69.1759492456913, 40.2864870429039, 22.5709655508399, 23.079003989696503, 14.683551136404276, 1.0625192918814719, 0.6571958726271987, 0.04910050512989983, 0.10883547438425012, 0.10377047234214842, 0.00697460321134713, 0.042034936413983814, 0.1104402203054633, 0.0469849649380194, 0.04027056565973908, 0.07726092022494413, 0.05199623548833188, 0.018885602621594444, 0.027519216200744268, 0.05042589924414642, 0.006426126392398146, 0.04317392158554867, 0.056575138223706745, 0.0985737242444884, 0.04640003011445515, 0.06432852940633893, 0.014250892236304935, 0.011388470393285388, 0.06700323705445044, 0.03255405550589785, 0.09300274075940251, 0.05625313147902489, 0.055675428884569556, 0.14528419473208487, 0.23336881189607084, 0.09253716925741173, 0.08995723386760801, 0.10726008040364832, 0.14331253099953756, 0.07029179731034674, 0.162150242831558, 0.08793183122179471, 0.12293693333049305, 0.13604648964246735, 0.15129394334508106, 0.1350873231422156, 0.24641998345032334, 0.3332380810752511, 0.14342591632157564, 0.17048947425791994, 0.1928635939839296, 0.1343332714168355, 0.10065054288133979, 0.19233013823395595, 0.13654727605171502, 0.1915614661993459, 0.12067301926435903, 0.1400600391207263, 0.12937562103616074, 0.18231153051601723, 0.18071904487442225, 0.13653188390890136, 0.1678876084042713, 0.2501072105951607, 0.17106395593145862, 0.49649014603346586, 28.836798928678036, 52.893165573477745, 95.02375066280365, 80.0660888850689, 103.28291907906532, 88.66970881819725, 63.89801725745201, 20.607270821928978, 1.1205310164950788, 1.4031952363438904, 2.924505234695971, 3.6584064038470387, 4.07740255817771, 14.91732219234109, 10.754080340266228, 7.472576899453998, 2.9088631365448236, 7.547035329043865, 21.517344787716866, 15.876821056008339, 15.57415684685111, 23.164562098681927, 15.848340634256601, 20.22001650184393, 16.69072598218918, 12.031358052045107, 11.69049259275198, 32.24969409406185, 9.880179483443499, 2.314277454279363, 0.6245572865009308, 0.40408735745586455, 0.2970889880089089, 1.3705560564994812, 1.6684295539744198, 7.51682884991169, 1.9365982641465962, 9.615175053477287, 20.10818660259247, 26.061395555734634, 34.46934498846531, 39.156803861260414, 46.228410601615906, 52.468025386333466, 61.889103055000305, 66.64004132151604, 71.39296308159828, 75.48546507954597, 75.5953399837017, 78.37483003735542, 78.46072062849998, 71.76268324255943, 62.04777494072914, 69.9550898373127, 62.32585921883583, 75.30864536762238, 38.080473616719246, 23.625450767576694, 79.48634639382362, 65.42741999030113, 73.50428938865662, 69.27569389343262, 73.3451235294342, 71.16176068782806, 71.10480174422264, 73.46170887351036, 76.09673827886581, 80.41792720556259, 81.6643363237381, 80.32288670539856, 64.31819871068001, 61.21717371046543, 68.83284285664558, 69.05703842639923, 61.26178711652756, 52.411343827843666, 37.11719110608101, 28.26048195362091, 22.80546996742487, 16.52109168469906, 7.327003860846162, 0.9251265018247068, 0.6427017285022885, 0.7369121513329446, 0.7963859662413597, 1.2883060262538493, 1.1818797932937741, 2.0329310512170196, 1.8839742941781878, 1.523311659693718, 1.0690237116068602, 0.639191132504493, 0.5548754974734038, 4.323667343705893, 9.204866420477629, 7.926510041579604, 4.664570325985551, 5.992332128807902, 5.276800598949194, 12.120848000049591, 14.45694649592042, 7.533003157004714, 6.305012600496411, 3.266245359554887, 2.986766081303358, 2.017529527656734, 0.4659508285112679, 38.88381510972977, 38.73381435871124, 56.67734831571579, 92.79400750994682, 50.373440980911255, 37.167523205280304, 48.38936984539032, 22.33051635324955, 0.6777750339824706, 0.8924286032561213, 0.16854072804562747, 0.19513640640070662, 0.2447789316647686, 0.1804751603049226, 0.10087290516821668, 0.20780068152816966, 0.1933059436851181, 0.10220875614322722, 0.29796855174936354, 0.15597100253216922, 0.17380110046360642, 0.21075677446788177, 0.3135200188262388, 0.14543219382176176, 0.10389983610366471, 0.103121746215038, 0.15080461569596082, 0.1210757382796146, 0.1925449603004381, 0.1708712795516476, 0.12923630507430062, 0.17760531976819038, 0.1262959308223799, 0.2158500300720334, 0.09002182297990657, 0.1213965612987522], [0.040177218324970454, 0.053732950109406374, 0.057051381809287705, 0.048607444477966055, 0.10014731480623595, 0.07978471214300953, 0.04928423491946887, 0.023223216448968742, 0.040528009267291054, 0.07306391926249489, 0.08297989537823014, 0.029640634202223737, 0.12385166002786718, 0.04892181452305522, 0.04328381139202975, 0.0398942299943883, 0.04911764874123037, 0.10998195153661072, 0.08004311312106438, 0.09729605764732696, 0.04771871892444324, 0.020162233922746964, 0.016118434505187906, 0.08602034824434668, 0.08765069826040417, 0.08351372220204212, 0.1391402806621045, 0.04937263955071103, 0.14099811378400773, 0.01826930278184591, 0.1739146193722263, 0.11757467887946405, 0.9371833736076951, 2.497678413055837, 13.663091193884611, 6.074171187356114, 39.4379735738039, 30.100856199860573, 69.37795400619507, 43.029077276587486, 46.74337036907673, 15.58133751153946, 0.471903535653837, 0.29585052165202796, 0.34044460218865424, 0.025151694608211983, 0.4201943665975705, 2.150368974544108, 1.4148698723874986, 0.97720104502514, 0.29590021586045623, 2.9927414981648326, 4.189117513597012, 6.24728562310338, 4.607200529426336, 5.881730988621712, 5.913912886753678, 5.446752654388547, 6.695636389777064, 6.035125432536006, 1.2735683983191848, 0.7763615751173347, 0.692513493122533, 0.13155527907656506, 0.2601507247891277, 0.479627808672376, 0.37160373176448047, 0.39759988838341087, 0.21309537085471675, 0.7216258684638888, 1.1803286452777684, 2.462578509002924, 6.465089460834861, 11.321097314357758, 18.372422643005848, 29.01154775172472, 37.01749585568905, 47.46872864663601, 54.3605100363493, 66.5138728916645, 75.37000447511673, 74.81598660349846, 79.12047922611237, 74.93235155940056, 72.42128670215607, 61.41288220882416, 55.74431598186493, 46.658053547143936, 43.7672408670187, 32.785123363137245, 2.359721353277564, 38.417211547493935, 59.56083118915558, 63.04342031478882, 70.06128653883934, 65.06121084094048, 70.5224221944809, 72.27516934275627, 71.68267473578453, 77.55418047308922, 79.4157537817955, 64.86330226063728, 35.64166188240051, 13.914664294570684, 10.909497700631618, 21.957095190882683, 27.581152506172657, 26.062974371016026, 19.57325890660286, 10.41197994723916, 2.7531503420323133, 0.505679656052962, 0.9951370325870812, 0.25927267502993345, 0.234371883852873, 0.4260901955422014, 0.1340818911558017, 0.29821476666256785, 0.8053632220253348, 0.8004498481750488, 0.1767715613823384, 0.388828266877681, 0.22681736969389021, 0.2257245423970744, 0.12746954831527546, 0.39766463334672153, 0.4359578207368031, 1.4768287539482117, 1.2346665607765317, 2.040067780762911, 1.699994697701186, 3.382213949225843, 2.8573996480554342, 4.263100493699312, 1.5147503628395498, 1.3316263142041862, 1.5563095640391111, 0.6629579071886837, 0.24652962834807113, 25.320963487029076, 23.065824396908283, 37.61566735804081, 64.3319995701313, 32.37746983766556, 12.04644039273262, 11.660976726561785, 16.934944577515125, 2.564532500691712, 0.47607752261683345, 0.09322635727585293, 0.07883074809797108, 0.11241866726777516, 0.06471813467214815, 0.02817382013745373, 0.053297940248739906, 0.06328001574729569, 0.014053751838218886, 0.09657394795794971, 0.026274269039276987, 0.10533233697060496, 0.01693827762210276, 0.07407162222079933, 0.07028701787930913, 0.06076694044168107, 0.005417288411990739, 0.12065324102877639, 0.088932483777171, 0.02982521189551335, 0.06912466618814506, 0.05410140787716955, 0.07835471231373958, 0.08059292580583133, 0.05869597734999843, 0.004809147558262339, 0.05064450997451786, 0.02489692829840351, 0.047349827000289224, 0.1263226629816927, 0.08275965563370846, 0.08768466635956429, 0.08899879467207938, 0.06869871052913368, 0.0781618058681488, 0.04994573711883277, 0.014485289375443244, 0.05752108707383741, 0.03958664688980207, 0.04217330984829459, 0.04631716561561916, 0.04653094496461563, 0.024380974246014375, 0.03772224205022212, 0.0397459897067165, 0.05480473751958925, 0.043235876073595136, 0.07567756299977191, 0.0675870623672381, 0.04753858484036755, 0.04171857741312124, 0.06605354035855271, 0.04168701016169507, 0.07394214713713154, 0.12919847038574517, 0.04050722171086818, 0.056266853789566085, 0.0774737459141761, 0.18957464781124145, 0.01888415357825579, 1.1403496842831373, 5.309130689129233, 21.77858456969261, 39.746767804026604, 60.360395684838295, 49.277720376849174, 85.78526079654694, 45.92873968183994, 76.89585819840431, 17.897909805178642, 0.6655947875697166, 1.1678891815245152, 0.42980381345842034, 0.4494423174764961, 0.5602301226463169, 1.1315537500195205, 1.0631094477139413, 2.0738023705780506, 3.2080505322664976, 3.7155059399083257, 1.8875747197307646, 2.031818898394704, 1.6365692135877907, 6.458596559241414, 5.96350260078907, 5.712289055809379, 9.173986427485943, 5.429450757801533, 0.6561794271692634, 1.4768680580891669, 1.012797534931451, 0.18314313667360693, 0.29383707500528544, 1.0170054528862238, 1.2061007623560727, 0.21049825474619865, 0.46744040795601904, 1.638781288638711, 0.39453900419175625, 1.7443826096132398, 6.853091865777969, 12.588778641074896, 22.287827543914318, 37.10131175816059, 44.38653543591499, 55.2486477792263, 62.43222691118717, 72.4339172244072, 84.13192391395569, 80.67040845751762, 83.20736512541771, 78.49488079547882, 79.04885306954384, 69.22359108924866, 68.43190357089043, 60.95693327486515, 57.770534455776215, 44.248587638139725, 2.862457651644945, 47.42765665054321, 66.19146019220352, 67.32308506965637, 74.44799154996872, 65.66545441746712, 71.57501891255379, 72.43827179074287, 74.865163564682, 77.3773455619812, 79.68212708830833, 65.21625012159348, 37.126698195934296, 17.668687105178833, 12.957795839756727, 20.16341283917427, 30.877287536859512, 29.14387185126543, 21.879748441278934, 13.399747274816036, 6.66330867446959, 3.7265101494267583, 0.9307877824176103, 0.24036012502619997, 0.14515577349811792, 0.1463676115963608, 0.12694976292550564, 0.43959342408925295, 0.8108894317410886, 0.4828585556242615, 0.9298391395714134, 0.8189977810252458, 0.6034264422487468, 0.7805858203209937, 0.21551846817601472, 0.6016088335309178, 1.1238420638255775, 2.6853187568485737, 2.329947338439524, 5.3931209072470665, 4.71862337552011, 5.67874445579946, 5.15320273116231, 3.6989129427820444, 1.7032485106028616, 1.1162281036376953, 0.5250063689891249, 1.2690173112787306, 0.17072118760552257, 45.69942578673363, 39.89913962781429, 33.47278006374836, 70.23505121469498, 46.48172400891781, 26.930416524410248, 21.088570095598698, 23.949653171002865, 6.883566230535507, 0.2139832466491498, 0.1551871164701879, 0.15888960217125714, 0.0375650885689538, 0.021011922508478165, 0.07999466572073288, 0.011850136343127815, 0.06006957766658161, 0.0038574417294512386, 0.11598625278566033, 0.04022866029117722, 0.11636410985374823, 0.06452290530432947, 0.008967044759629061, 0.028759892302332446, 0.03895262270816602, 0.03749135248654056, 0.054018684386392124, 0.0524335126101505, 0.03615339010138996, 0.023574422993988264, 0.0037983876472935663, 0.03575138354790397, 0.09724328352604061, 0.06850951482192613, 0.03037916019820841, 0.03793416603002697, 0.018237260555906687, 0.21629797556670383, 0.2534445299534127, 0.17296830686973408, 0.1663684766390361, 0.17735583940520883, 0.14902619237545878, 0.21041400614194572, 0.15287053218344226, 0.12994321557926014, 0.2123071506503038, 0.20457800914300606, 0.20031825959449634, 0.2878988248994574, 0.23343775741523132, 0.168248692934867, 0.1984083722345531, 0.1384679987677373, 0.14306164055597037, 0.11751664293115027, 0.19794455962255597, 0.151705612661317, 0.17965142091270536, 0.17114406335167587, 0.18337284622248262, 0.20462749555008486, 0.17667374631855637, 0.23195399640826508, 0.15827853261725977, 0.27831668907310814, 0.25428538327105343, 0.2774502761894837, 0.2682024036766961, 1.4099345309659839, 6.039587818086147, 37.87990517914295, 67.78751894831657, 89.46489214897156, 66.40206009149551, 110.14489486813545, 65.91088324785233, 74.15780112147331, 26.136384531855583, 0.6568022968713194, 1.3692125910893083, 1.8909269711002707, 1.9155915663577616, 1.3139186706393957, 7.4247821141034365, 8.72138986364007, 5.924844425171614, 3.8050201116129756, 6.579934023320675, 6.468543475493789, 15.114953387528658, 8.761643003672361, 11.636922117322683, 9.909848291426897, 7.379552666097879, 11.60814056172967, 9.471116233617067, 7.475346475839615, 2.1097213681787252, 1.0683934204280376, 0.2622124704066664, 0.6347939965780824, 1.4373297546990216, 3.140093316324055, 1.6688715177588165, 2.229956891387701, 2.9694577725604177, 1.3699915492907166, 3.752359924837947, 8.42025887221098, 12.289849631488323, 21.93134967237711, 36.9052042812109, 44.136106073856354, 52.562910094857216, 60.84416672587395, 69.7847905755043, 80.34880891442299, 79.99173447489738, 80.46336516737938, 75.83610266447067, 80.08652418851852, 70.1289913058281, 71.55555635690689, 67.8287923336029, 68.42987447977066, 50.00315085053444, 4.629953233525157, 60.93841306865215, 75.83061575889587, 74.79653924703598, 78.42139273881912, 72.58337840437889, 76.32121503353119, 80.74086427688599, 80.25667145848274, 86.91994071006775, 87.9894009232521, 69.88368406891823, 39.54652614891529, 18.432343527674675, 13.673419039696455, 22.390313744544983, 38.71214412152767, 42.45925985276699, 38.41647818684578, 33.716020211577415, 18.461638055741787, 11.059929728507996, 3.8750885892659426, 0.8636573783587664, 0.567733176285401, 1.2370578199625015, 0.298335617990233, 1.5064998180605471, 0.935194002231583, 1.4017446641810238, 1.6677989065647125, 1.787339304573834, 0.39346286037471145, 0.6669567769858986, 0.2660484239459038, 1.322491248138249, 1.709704245440662, 3.6382178496569395, 3.2597184972837567, 5.216153003275394, 7.636263091117144, 8.19428974762559, 11.613958049565554, 10.77335860580206, 4.661717154085636, 5.254267808049917, 8.046709466725588, 2.9303079983219504, 0.3795179649023339, 48.707332983613014, 50.74872404336929, 54.14914257824421, 96.34425580501556, 58.09625297784805, 38.01527291536331, 52.810193225741386, 36.181035339832306, 11.112374514341354, 0.8967024239245802, 0.3262594883562997, 0.38900157320313156, 0.23208927508676425, 0.20996937062591314, 0.2930595714133233, 0.122235759627074, 0.2449089559377171, 0.10406049623270519, 0.23970877169631422, 0.14064033923204988, 0.24418855318799615, 0.22796756500611082, 0.19499532412737608, 0.1584322314010933, 0.14073732309043407, 0.10767785017378628, 0.18809158442309126, 0.2549444400938228, 0.14594822394428775, 0.0950100424233824, 0.178599352366291, 0.19635465665487573, 0.20806644461117685, 0.15804218826815486, 0.17403078032657504, 0.20440296619199216, 0.14317392749944702], [0.06345614223391749, 0.06578385873581283, 0.10208370425971225, 0.044769242231268436, 0.06714636023389176, 0.03945437762013171, 0.04059508828504477, 0.036156863352516666, 0.08198245632229373, 0.06742559329723008, 0.024800810897431802, 0.10041485162219033, 0.04108701345103327, 0.032137020461959764, 0.04841023728658911, 0.0215340289651067, 0.021699219905713107, 0.06620076019316912, 0.017296582809649408, 0.056763031461741775, 0.0366569039033493, 0.083997817710042, 0.04063699736434501, 0.02303827139257919, 0.08702379127498716, 0.06003530899761245, 0.04994050868845079, 0.010122690218850039, 0.04910981537250336, 0.09682312404038385, 0.06240002156118862, 0.04770127103256527, 0.1561593744554557, 0.42980241822078824, 2.650196528993547, 15.279944334179163, 23.757655173540115, 27.83074401319027, 34.932623729109764, 76.70405969023705, 42.04996861517429, 44.76071655750275, 32.314928993582726, 0.5399152846075594, 0.19799740053713322, 0.29180976503994316, 0.8166743244510144, 0.38719423580914736, 0.5559132574126124, 4.2713075783103704, 3.133831489831209, 1.0635512927547097, 0.519192562205717, 0.718888946576044, 2.992189102806151, 9.379186816513538, 5.527987545356154, 4.137253146618605, 4.6259387489408255, 3.9437333308160305, 0.6891604699194431, 0.5863984872121364, 0.23896836064523086, 0.19081902166362852, 0.545861431164667, 0.6426746549550444, 0.23930158495204523, 0.05538648481888231, 0.10700245125917718, 0.4187861265381798, 0.20012570195831358, 0.5956802016589791, 1.3274198211729527, 1.4758720365352929, 1.5719648427329957, 2.3078572237864137, 8.9408328384161, 14.308822844177485, 20.034246370196342, 26.19375005364418, 30.90942621231079, 57.87064768373966, 80.99976718425751, 83.10135081410408, 78.74315947294235, 73.29570338129997, 60.5536875128746, 55.332592874765396, 42.4776166677475, 54.458240792155266, 2.229886120185256, 27.50300209969282, 81.83329045772552, 74.96183797717094, 79.54860225319862, 77.51978471875191, 79.02445837855339, 78.65574136376381, 72.67782613635063, 64.78071749210358, 47.96608775854111, 27.298409678041935, 10.542621687054634, 2.615093537606299, 0.49187003925908357, 1.9644422200508416, 2.445235764607787, 3.8048453209921718, 4.393295757472515, 2.9879661044105887, 1.0200758068822324, 0.16116710496135056, 0.20148582116235048, 0.04693453600339126, 0.15656417148420587, 0.18726726615568623, 0.07304664206458256, 0.11278919933829457, 0.32791587291285396, 0.0957946632115636, 0.2481657374300994, 0.2746896055759862, 0.14417658385355026, 0.19697976764291525, 0.098153839353472, 0.0898586840776261, 0.533966941293329, 0.828823281917721, 5.094465482980013, 7.973837926983833, 2.9423481272533536, 2.708998373709619, 2.9352493956685066, 5.941511280834675, 2.447755029425025, 0.213432825403288, 1.6261239303275943, 0.9523640340194106, 28.414656780660152, 25.397622473537922, 28.685162365436554, 65.21565735340118, 37.245438024401665, 13.551656473428011, 12.794657293707132, 18.99529092013836, 3.766549788415432, 0.04718620941275731, 0.1668256099219434, 0.03953858540626243, 0.0615845534048276, 0.059677423123503104, 0.11074018155341037, 0.13240616623079404, 0.0771366104891058, 0.02385361338383518, 0.08783890691120178, 0.024803983578749467, 0.02818870205373969, 0.06950354742002673, 0.06527904246468097, 0.02530216319428291, 0.08434703529928811, 0.05192685581278056, 0.029499935990315862, 0.0873671830049716, 0.11961243086261675, 0.04156579889240675, 0.0358866251190193, 0.01625893790333066, 0.10500454518478364, 0.03448827417741995, 0.02035340559814358, 0.015591836199746467, 0.047955000190995634, 0.013864435532013886, 0.030315303956740536, 0.004251433319950593, 0.02095841551636113, 0.018097664433298633, 0.05147155563463457, 0.07487862618290819, 0.03293785346613731, 0.07142938353354111, 0.021632567622873466, 0.03640806178736966, 0.07247645742609166, 0.00999502875856706, 0.0584114119556034, 0.030711247163708322, 0.04293180332751945, 0.07864210158004425, 0.03234307034290396, 0.04204773846140597, 0.09808850809349678, 0.04349713803094346, 0.08275476488051936, 0.059023501962656155, 0.06943438667804003, 0.09977399968192913, 0.06345283967675641, 0.2332377337734215, 0.1151394251792226, 0.055951177564566024, 0.025581323898222763, 0.09792692770133726, 0.012379400814097608, 0.050260515345144086, 0.17079283454222605, 1.0173232108354568, 9.266093485057354, 41.91385231912136, 50.827436819672585, 47.01531417667866, 59.48140785098076, 83.41234892606735, 43.09821076691151, 78.43322530388832, 33.07684510946274, 0.8029967208858579, 0.6324900139588863, 0.5520513583905995, 0.03943251023883931, 0.3604798880405724, 0.4239259148016572, 1.2843878427520394, 1.4577894005924463, 4.045667136088014, 1.700026283506304, 1.99353595264256, 3.064235611818731, 2.835339456796646, 4.193975077942014, 3.3224248699843884, 4.725420260801911, 3.4256202075630426, 1.3092896877788007, 0.35194682248402387, 0.20551502995658666, 0.26866681000683457, 0.40864987357053906, 0.884085379075259, 1.8021049560047686, 0.08348153525730595, 0.029409393973764963, 0.26375753281172365, 0.42438135598786175, 1.0448305285535753, 1.609443062916398, 1.8307526875287294, 2.412038608454168, 4.448325829580426, 12.114661931991577, 18.718654364347458, 26.34933650493622, 32.6344158500433, 39.067485854029655, 64.61783543229103, 86.56421139836311, 88.68572115898132, 84.6958440542221, 83.05844351649284, 71.2142738699913, 65.674619525671, 52.56917975842953, 64.08311292529106, 2.10770723875612, 29.972052611410618, 86.2089304625988, 75.02253592014313, 81.91237941384315, 77.938332259655, 81.37254998087883, 77.91624784469604, 72.51012593507767, 70.60354024171829, 53.68911266326904, 32.689193710684776, 14.153695218265057, 3.2365670520812273, 1.2767531024292111, 2.1360914781689644, 2.1948878606781363, 3.073329236358404, 0.5990300781559199, 1.6528134606778622, 0.9319749812129885, 0.33037232235074043, 0.2115252535440959, 0.14316009386675432, 0.08198395546060055, 0.24274276045616716, 0.05583243393630255, 0.31605329539161175, 0.1545195101061836, 0.25882326008286327, 0.14969828131143004, 0.14353664475493133, 0.7583812368102372, 0.21215392684098333, 0.05218983213126194, 0.06252110295463353, 1.6982254176400602, 3.207085859030485, 5.709376512095332, 4.585217759013176, 6.676016142591834, 4.082675250247121, 2.568048262037337, 2.0281758438795805, 0.9078070311807096, 0.3344360855408013, 0.9934435703326017, 0.7441864453721792, 48.61683703958988, 48.87708127498627, 30.77296793460846, 65.40496319532394, 53.06929372251034, 31.21858712285757, 27.44511790573597, 20.529785379767418, 11.783230416476727, 0.061987758526811376, 0.2825471683172509, 0.057408748180023395, 0.01815722178434953, 0.03649933853012044, 0.048034435967565514, 0.07197491402621381, 0.0719180358282756, 0.035037849374930374, 0.09214181976858526, 0.10192025365540758, 0.040509911996196024, 0.028862599974672776, 0.013679558196599828, 0.03782959742238745, 0.055519106608699076, 0.060475116843008436, 0.017820021421357524, 0.09444206196349114, 0.15422496653627604, 0.09643975281505845, 0.0311403235537, 0.05379411421017721, 0.07496599180740304, 0.06434035181882791, 0.01569687792652985, 0.09382112184539437, 0.04951859031280037, 0.03924665419617668, 0.1222570073150564, 0.15085067338077351, 0.19036038924241439, 0.180378666264005, 0.22312407178105786, 0.23538423265563324, 0.11628248103079386, 0.23969820351339877, 0.13116210408043116, 0.14303382486104965, 0.11031487156287767, 0.2671095763798803, 0.19415374350501224, 0.08124753716401756, 0.18480501312296838, 0.16441008250694722, 0.11446289077866822, 0.21050992130767554, 0.20819344092160463, 0.13557118858443573, 0.2151438914006576, 0.16434566408861428, 0.19288413663161919, 0.1441304519539699, 0.19729624909814447, 0.29432327079121023, 0.23867089301347733, 0.14073058438953012, 0.12144454114604741, 0.16265056910924613, 0.13769235054496676, 0.1899306708946824, 0.28711764025501907, 0.8665707532782108, 14.872914925217628, 77.06139251589775, 78.88565182685852, 75.81787124276161, 66.13738149404526, 114.1456849873066, 62.830700129270554, 75.11622369289398, 47.40942142903805, 0.5631850578356534, 1.0779649880714715, 0.7711072883103043, 2.751966705545783, 1.1610259185545146, 4.804782327264547, 10.861299186944962, 10.17142815515399, 6.226087510585785, 6.665309267118573, 3.00143139436841, 5.734748700633645, 17.956624254584312, 10.047903433442116, 8.156797159463167, 6.209159418940544, 13.002344649285078, 3.3561055501922965, 0.7483597495593131, 0.21257635729853064, 0.559059310471639, 1.0329398978501558, 1.821256522089243, 3.8275894755497575, 0.2577064762590453, 0.4539062170078978, 0.8036481484305114, 1.2199972104281187, 1.4281128742732108, 1.90740728052333, 2.2056472208350897, 2.5999990850687027, 5.448069283738732, 11.843377389013767, 17.955174632370472, 26.88123006373644, 33.2276476174593, 38.90374884009361, 61.1342241615057, 82.54702895879745, 85.15654653310776, 82.78105840086937, 82.4405662715435, 74.21080827713013, 74.22720819711685, 62.614993304014206, 72.2105348110199, 2.8453146340325475, 32.1237650513649, 88.49892318248749, 78.56941759586334, 89.00948658585548, 82.18302369117737, 85.17087936401367, 82.4177522957325, 80.37821933627129, 75.9556594491005, 59.44257773458958, 33.92732307314873, 14.494104702025652, 3.706431076861918, 1.6138384770601988, 2.495201895944774, 3.415135145187378, 10.59578938409686, 10.986200384795666, 5.47926988452673, 3.3755707181990147, 0.3643696621293202, 0.4811793426051736, 0.1939062075689435, 0.43557683180551976, 0.4401992540806532, 0.2213715048856102, 0.30390142870601267, 0.5666420410852879, 0.3526119649177417, 0.21317427599569783, 0.8478877495508641, 0.7896846102084965, 0.3570046182721853, 0.4211585351731628, 0.803512780694291, 1.9051350024528801, 3.697811239399016, 13.849080763757229, 21.02857891470194, 10.836088489741087, 11.712219826877117, 8.043075911700726, 9.135363399982452, 6.929271603003144, 0.6565845804288983, 2.6281099766492844, 1.5599684114567935, 54.012999683618546, 50.17389848828316, 44.92266766726971, 94.29343745112419, 65.78421324491501, 38.68019923567772, 49.84538711607456, 42.75776043534279, 17.135978490114212, 0.1555437926435843, 0.5255828099325299, 0.17279274441534653, 0.2325383189599961, 0.145815379510168, 0.1782688740058802, 0.22906209924258292, 0.18071281083393842, 0.20911029016133398, 0.21285809139953926, 0.17297066689934582, 0.16897446883376688, 0.11803613146184944, 0.11948587984079495, 0.10838684611371718, 0.21482418902451172, 0.08056343285716139, 0.09689971368061379, 0.2007186334230937, 0.19222432281821966, 0.17996212845901027, 0.1257638554670848, 0.16843246354255825, 0.16753626085119322, 0.21381344326073304, 0.0935723539441824, 0.17994973459281027, 0.1880290955887176, 0.11224932401091792], [0.023571395031467546, 0.05054438683146145, 0.018424385671096388, 0.024502259730070364, 0.06443027043133043, 0.06309470147243701, 0.08143973114783876, 0.014445898959820624, 0.05380924660130404, 0.01936311527970247, 0.007001930944170454, 0.058194400553475134, 0.02169116760342149, 0.06216434143425431, 0.03512229464831762, 0.034700906908256, 0.03162776614772156, 0.07871665773564018, 0.058602997378329746, 0.04196996509563178, 0.04204460659821052, 0.032832509314175695, 0.03022905711986823, 0.10425114654935896, 0.1143423882604111, 0.03537389013217762, 0.05327687809767667, 0.1179889976629056, 0.08401018189033493, 0.07498113162000664, 0.10821882387972437, 0.05866950123163406, 0.20502418832620606, 0.42919151193927974, 0.3990644426085055, 5.624192683026195, 14.21371204778552, 33.14331494271755, 29.4377176836133, 44.331544786691666, 81.0006183385849, 44.158000499010086, 43.606254905462265, 44.29923892021179, 2.7267037611454725, 0.138834040844813, 0.33630243851803243, 0.4553082527127117, 0.11752194186556153, 0.04669795416702982, 1.0979190235957503, 4.632728034630418, 1.1797248339280486, 0.46579476969782263, 1.7834614939056337, 1.4605970936827362, 2.3049584543332458, 5.2719140611588955, 6.918166223913431, 5.3287148382514715, 0.2847520000068471, 0.3514830395579338, 0.17715744848828763, 0.4286737600341439, 0.0649914750829339, 0.37712578545324504, 0.5428970558568835, 0.0673517570248805, 0.2776303212158382, 0.10780952201457694, 0.19293393474072218, 0.5533300491515547, 0.6578613712918013, 0.6322518142405897, 0.4653028742177412, 0.9024593525100499, 0.017148511360574048, 0.8892008545808494, 0.2971533767413348, 1.7291681072674692, 7.279562931507826, 15.252148825675249, 34.56774830818176, 51.94691754877567, 71.42988950014114, 76.70306414365768, 69.30132731795311, 58.509655594825745, 55.28667613863945, 43.48049685359001, 0.6746241718064994, 16.56270705163479, 66.29009529948235, 85.6283064186573, 83.6191414296627, 82.93590009212494, 74.9283617734909, 67.82543331384659, 56.35802865028381, 33.034310191869736, 13.852215595543385, 4.416697276756167, 3.192797200754285, 0.48870163271203637, 1.7892870563082397, 0.67467131302692, 0.8582978253252804, 0.6533352797850966, 0.21801350929308683, 1.1518776719458401, 0.43805076624266803, 0.18460196151863784, 0.10690557872294448, 0.03615471112425439, 0.039585771155543625, 0.029618187945743557, 0.05303405108861625, 0.0872206014173571, 0.2853893564315513, 0.1518870677682571, 0.4509200225584209, 0.21414957678643987, 0.13193083548685536, 0.06687629269436002, 0.10501985569135286, 0.3823174349963665, 0.33922086004167795, 2.805533381178975, 3.0277677811682224, 4.8482415452599525, 3.4517328813672066, 4.648161381483078, 3.5547517659142613, 1.4876942709088326, 0.8672418922651559, 2.703631636686623, 2.171072163619101, 33.16356025636196, 25.587883964180946, 20.417869985103607, 52.787417247891426, 40.38658507168293, 23.15005637705326, 15.01325374469161, 18.793949224054813, 12.239891812205315, 1.7812696052715182, 0.7638376846443862, 0.0595398957375437, 0.15357393975136802, 0.058697613785625435, 0.04070703012985177, 0.06989762041484937, 0.06332012140774168, 0.07590070454170927, 0.04267114993126597, 0.030966586782597005, 0.07979646034073085, 0.04143283571465872, 0.050845353689510375, 0.01927157321915729, 0.07895814516814426, 0.04521314302110113, 0.03545937441231217, 0.040066259825835004, 0.0667057916871272, 0.03625020326580852, 0.015647120635549072, 0.02212019760918338, 0.07020094359177165, 0.06150181878183503, 0.08402148479945026, 0.02759077222435735, 0.05301742326992098, 0.11235756624955684, 0.04272618389222771, 0.027940268118982203, 0.020157441504125018, 0.045793565586791374, 0.04886561910097953, 0.035600953924586065, 0.039046411620802246, 0.0698421968263574, 0.034652815738809295, 0.05557335760386195, 0.054328289843397215, 0.038096963544376194, 0.04896302598353941, 0.0440206823986955, 0.03394120001757983, 0.04515899963735137, 0.02464394685375737, 0.022640606403001584, 0.045350291911745444, 0.08246642566518858, 0.03843611390038859, 0.056465753077645786, 0.030056654359214008, 0.030814283236395568, 0.048952910510706715, 0.26449056691490114, 0.1409112973487936, 0.05293091853673104, 0.07459206812200136, 0.014428604135900969, 0.08563454277464189, 0.07572442962555215, 0.029997547862876672, 0.19819622189970687, 0.7260251417756081, 1.5494761057198048, 24.141153395175934, 45.16564942896366, 56.87078833580017, 50.257478803396225, 75.99569410085678, 89.7223587334156, 42.25634314119816, 81.37223079800606, 55.79793490469456, 1.6561477817595005, 0.392842513974756, 0.3118423791602254, 0.1650762787903659, 0.10465229221154004, 0.11256700032390654, 1.639614156447351, 2.519768765196204, 2.083805096335709, 1.9359653606079519, 2.921966970898211, 4.2029530461877584, 6.534122731536627, 6.479616556316614, 5.75125596486032, 3.4401556150987744, 0.4753748275106773, 0.4353327245917171, 0.3251188073772937, 0.31810171203687787, 0.18135082034859806, 0.8556588075589389, 0.842806234722957, 0.6073798926081508, 0.7749346329364926, 0.18063819530652836, 0.19499893096508458, 1.2404145835898817, 1.1819416587240994, 1.2343540275469422, 1.0113067086786032, 1.1852094833739102, 0.49748774094041437, 0.9146637038793415, 1.2267992016859353, 2.4857724644243717, 8.19242024794221, 18.417511023581028, 39.17417272925377, 57.682458981871605, 74.24433767795563, 80.9068089723587, 78.26443836092949, 67.49896243214607, 67.03974187374115, 44.275034219026566, 0.4398889176081866, 17.785259149968624, 70.36388710141182, 85.92496410012245, 84.93755668401718, 83.26716631650925, 80.09678363800049, 71.98085233569145, 59.01559464633465, 39.687145203351974, 20.03956228494644, 9.27398281171918, 5.518787764012814, 1.9000306888483465, 2.00817062985152, 1.2248443253338337, 1.3230236945673823, 0.9653180732857436, 0.8005118323490024, 0.2678430260857567, 0.2537334925727919, 0.28300358913838863, 0.19067164597800002, 0.10189713575528003, 0.10181728808674961, 0.029983404383528978, 0.1480693116900511, 0.1473669579718262, 0.513966002035886, 0.2911197755020112, 0.5666570621542633, 0.5799184693023562, 0.38321454310789704, 0.19835002458421513, 0.05374024171032943, 0.38556824962142855, 1.1159014399163425, 4.528657793998718, 3.545262962579727, 2.6761125633493066, 3.5231904219835997, 1.8687913776375353, 1.283355604391545, 0.9402493934612721, 0.43122321541886777, 1.869340210687369, 0.9677580767311156, 55.95722235739231, 47.59448289871216, 19.92888182401657, 53.27887907624245, 58.893302008509636, 36.266709342598915, 26.627375185489655, 20.83047654479742, 24.347664713859558, 2.367952661588788, 0.9367266262415797, 0.09840497470577247, 0.15736290049972013, 0.03808070679951925, 0.036147189457551576, 0.04856997344177216, 0.03342449082992971, 0.016736756697355304, 0.10958557046251372, 0.07121650589397177, 0.08044846676057205, 0.08702370221726596, 0.02155473302991595, 0.04911243144306354, 0.045181334571680054, 0.05513602482096758, 0.09197715204209089, 0.029742963379248977, 0.1559468827326782, 0.05856071722519118, 0.042183466139249504, 0.05421411042334512, 0.10892168967984617, 0.0608135436050361, 0.04674798976338934, 0.05968954981653951, 0.06443157661124133, 0.1311364257708192, 0.025115615098911803, 0.1787415033322759, 0.11131460385513492, 0.07941154544823803, 0.2064718512701802, 0.18540864635724574, 0.1645256794290617, 0.23139743017964065, 0.12021960414131172, 0.23089533759048209, 0.22762559819966555, 0.11554004391655326, 0.12539071845822036, 0.09180866225506179, 0.12932433863170445, 0.11976860841969028, 0.13085859536658973, 0.07513702716096304, 0.17757800873368979, 0.14789027598453686, 0.10323906491976231, 0.1485957021941431, 0.22695386549457908, 0.12545196048449725, 0.22149385535158217, 0.3978656663093716, 0.18737628764938563, 0.09598376243957318, 0.28850465489085764, 0.2636723342584446, 0.16939342604018748, 0.24185751186450943, 0.1383686697226949, 0.3270170430187136, 0.6884290685411543, 2.0247137546539307, 39.196268543601036, 77.77419626712799, 82.81594812870026, 77.14608237147331, 83.77981960773468, 117.18989163637161, 63.56776177883148, 75.78523859381676, 68.52958872914314, 3.6541843554005027, 0.6832488777581602, 0.27690889430232346, 0.7629388547502458, 0.33512764843180776, 0.5677812080830336, 9.122551437467337, 14.06259510666132, 6.226887842640281, 10.657299533486366, 5.817757621407509, 5.558387814089656, 9.431051183491945, 11.690596137195826, 14.7294488735497, 13.428702671080828, 2.2062910487875342, 0.5281096149701625, 0.45311051595490426, 0.476011976134032, 0.0877176845096983, 1.165486047975719, 1.2494114320725203, 0.8805098896846175, 1.218673693947494, 0.4001530248206109, 0.4608233895851299, 1.7650789115577936, 1.8166922545060515, 2.604283355176449, 2.442185953259468, 2.4194814590737224, 1.5094542782753706, 2.1719511039555073, 1.9090546108782291, 2.575591094791889, 8.190614394843578, 19.037487655878067, 39.194330647587776, 56.32216237485409, 75.49877196550369, 83.96949782967567, 83.6872261762619, 73.17219480872154, 74.83078300952911, 49.097496047616005, 0.6724754464812577, 19.578810408711433, 77.08006471395493, 95.34357190132141, 89.19869363307953, 88.95312801003456, 83.94305124878883, 75.18565356731415, 62.57843166589737, 38.49655129015446, 18.81491269916296, 10.21326296031475, 7.288283938542008, 5.098503241315484, 4.090765491127968, 1.856903003063053, 3.395360056310892, 2.6082752784714103, 1.7878862377256155, 1.2369640124961734, 0.7891037163790315, 0.44693661911878735, 0.3780490468489006, 0.2791552565759048, 0.2980070246849209, 0.09608940716134384, 0.18712084041908383, 0.33936673658899963, 0.5150908010546118, 0.4275873745791614, 0.6105483288411051, 1.0212277388200164, 0.766171709401533, 0.3875212260754779, 0.15326682419981807, 0.6575716962106526, 1.7884416016750038, 13.153520487248898, 10.938489194959402, 14.185507111251354, 11.757800281047821, 8.536666575819254, 7.9856495931744576, 4.594058459624648, 1.8913833028636873, 3.7594106839969754, 2.851598784327507, 60.93860685825348, 41.6844168305397, 34.17611852288246, 79.43909972906113, 76.30778655409813, 43.19713085889816, 47.82678723335266, 44.213222935795784, 33.28317403793335, 2.0747280959039927, 1.249227854423225, 0.1419161949888803, 0.25315782346297055, 0.19190135499229655, 0.12825963873183355, 0.170462014793884, 0.225147032761015, 0.26276531105395406, 0.18095187144353986, 0.15223424445139244, 0.12824129284126684, 0.1341418715310283, 0.10366250469814986, 0.13879216887289658, 0.1901723735500127, 0.14715109689859673, 0.1924819074338302, 0.0839381713012699, 0.3151875949697569, 0.19685956940520555, 0.17326160363154486, 0.10937216589809395, 0.2186636158148758, 0.3233578393701464, 0.2729365340201184, 0.13528964744182304, 0.0957205449230969, 0.23507431178586558, 0.2241724741179496], [0.009388966846017865, 0.016645915966364555, 0.0291278676741058, 0.02308472612639889, 0.07530527203925885, 0.09966479265131056, 0.05097843190014828, 0.037699157546740025, 0.042746455656015314, 0.04364282161986921, 0.0621251263510203, 0.05494923367223237, 0.012261153497092891, 0.08165228966390714, 0.0493580823240336, 0.03925866956706159, 0.028299898040131666, 0.0374163399101235, 0.02476786325132707, 0.04990311186702456, 0.054562155419262126, 0.027319617438479327, 0.035281548407510854, 0.07051679422147572, 0.10352914818213321, 0.06825593038229272, 0.02442438060825225, 0.08298443732201122, 0.008153013586706948, 0.019601964377216063, 0.13681548822205514, 0.07284437713678926, 0.11577744211535901, 0.08089953669696115, 0.9084154735319316, 1.8469786481000483, 9.159190021455288, 19.01486936956644, 38.79683017730713, 29.802948385477066, 43.28294925391674, 79.13591399788857, 51.04064337909222, 41.79557606577873, 52.36374758183956, 9.29483799263835, 0.15435824141604826, 0.33513729635160416, 0.3540718287695199, 0.13181663380237296, 0.41924061777535826, 2.272295169532299, 1.0284284711815417, 1.0730907996185124, 2.765704868361354, 2.687040064483881, 4.387699607759714, 0.5517981969751418, 4.734866078943014, 1.6441371012479067, 0.6368803221266717, 0.2369208197342232, 0.004026687347504776, 0.06802084026276134, 0.1416423573391512, 0.13327496882993728, 0.262442150269635, 0.03245699001126923, 0.06215955829247832, 0.06176103983307257, 0.11181849986314774, 0.06864017734187655, 0.12376059108646587, 0.5347090889699757, 0.6127046537585557, 0.7993473729584366, 1.4406291651539505, 0.4173769959015772, 1.4885112270712852, 0.634028100175783, 0.9386587631888688, 3.6618445068597794, 14.309015683829784, 20.638320855796337, 33.5892666131258, 68.13336879014969, 65.28944179415703, 56.9753435254097, 38.649135902523994, 5.828103516250849, 0.3416300198296085, 4.452766366302967, 29.139519184827805, 63.72980408370495, 73.7401731312275, 77.95381262898445, 68.44425290822983, 56.27290561795235, 31.194895394146442, 18.796764872968197, 5.669667217880487, 2.214103192090988, 1.142128820065409, 0.9869537560734898, 0.7619510858785361, 0.7618898141663522, 0.48695013450924307, 0.29069232812616974, 0.10468657201272435, 0.06740865006577224, 0.11100535091827624, 0.08487460581818596, 0.08855450054397807, 0.03872684283123817, 0.06694708616123535, 0.10247979589621536, 0.040691137037356384, 0.007958005935506662, 0.05631602478388231, 0.09387031881487928, 0.0814073215587996, 0.04842826405365486, 0.24464721529511735, 0.05904863850446418, 0.45721417700406164, 0.33922148344572634, 1.1425807583145797, 2.0643738890066743, 2.556738406419754, 1.285556755028665, 3.66299394518137, 0.7153630326502025, 0.9314117801841348, 0.1661139793577604, 1.7818705667741597, 6.047223983332515, 41.881569251418114, 21.31391130387783, 22.04237211495638, 68.49777683615685, 53.4536013007164, 13.53193648159504, 16.44143655896187, 15.642328038811684, 9.091834835708141, 2.6393060758709908, 0.31552631116937846, 0.14730734867043793, 0.06228048383491114, 0.03685163232148625, 0.09749763979925774, 0.0474021966510918, 0.07594796450575814, 0.058911337473546155, 0.05183366061828565, 0.04698729528172407, 0.0191515493861516, 0.04479097973671742, 0.02387854769040132, 0.07456600389559753, 0.06281828857026994, 0.0154967503840453, 0.03414717568375636, 0.044062346569262445, 0.03615824374719523, 0.019254453727626242, 0.08007846161490306, 0.09261626735678874, 0.04500058450503275, 0.08726870742975734, 0.025249554200854618, 0.07124070732970722, 0.06431464382330887, 0.029910531047789846, 0.04527059638348874, 0.028560519895108882, 0.04963752318872139, 0.07247036439366639, 0.0848979908914771, 0.08798113951343112, 0.057593910314608365, 0.048453326380695216, 0.07382897703791969, 0.031010989478090778, 0.035252997986390255, 0.053684844097006135, 0.04018590145278722, 0.03961649978009518, 0.014691534070152557, 0.04552862257696688, 0.040544421863160096, 0.015584459251840599, 0.018778703670250252, 0.023965943000803236, 0.0633382001251448, 0.12010576610919088, 0.03164554058457725, 0.045178121072240174, 0.027438973338576034, 0.08553039719117805, 0.0576656537305098, 0.060751474084099755, 0.11222587214433588, 0.056595027781440876, 0.09072471104445867, 0.09274715994251892, 0.07916337126516737, 0.12328344950219616, 0.10013663530116901, 0.13953363377368078, 1.18782160570845, 3.0060980189591646, 22.81121525913477, 50.9595937281847, 59.69670809805393, 48.78249675035477, 71.23681426048279, 86.21481254696846, 46.28844358026981, 71.09506666660309, 69.20274540781975, 5.121859638020396, 0.06942713589523919, 0.6245639361441135, 0.04019149353553075, 0.2734363853232935, 0.7100556080695242, 0.20866762875812128, 1.443336638621986, 2.5281268917024136, 3.209212082438171, 3.205216834321618, 7.064658338204026, 5.936240488663316, 7.326430566608906, 11.576119679957628, 5.125356875360012, 0.5301184009294957, 0.08544887226889841, 0.2246692232438363, 0.1740117368171923, 0.5388819181825966, 0.4373545723501593, 0.09918238924001344, 0.44189102423842996, 0.14765353087568656, 0.18721194646786898, 0.17209101410117, 0.20160921063506976, 0.26116437977179885, 0.8446467609610409, 2.411550572142005, 2.1853026375174522, 1.4714940777048469, 1.2622993905097246, 0.7408717763610184, 1.4902610331773758, 5.652255602180958, 15.522574614733458, 23.00119176506996, 34.819355607032776, 69.00343090295792, 67.18493968248367, 58.26341360807419, 36.176129803061485, 5.692906295880675, 0.9641618665773422, 4.955441867932677, 34.737314209342, 72.72551357746124, 80.3366419672966, 83.38582634925842, 72.5490054488182, 60.32826840877533, 35.95197983086109, 21.90851479768753, 6.4759711269289255, 2.391874990426004, 1.5259170136414468, 1.4936270588077605, 1.2836756184697151, 1.2837786879390478, 1.4454872044734657, 0.3321874374523759, 0.09040345015819184, 0.030531011034327094, 0.1061390143877361, 0.08967319910880178, 0.03593680543417577, 0.047870803537080064, 0.05624432960757986, 0.033400627071387134, 0.03075451066251844, 0.09769468000740744, 0.1776947040343657, 0.09325919731054455, 0.0721188164607156, 0.3239702299470082, 0.3211481688776985, 0.3648767271079123, 0.4260808741673827, 0.36114200251176953, 1.24113405123353, 3.8681173883378506, 2.7706049429252744, 1.7673331405967474, 1.6996710025705397, 0.8562907017767429, 0.8463046594988555, 0.352178995963186, 2.0877941697835922, 2.9489633347839117, 70.27349755167961, 46.6897514462471, 18.709975630044937, 53.63192193210125, 70.78477531671524, 26.17500565946102, 26.52269270271063, 29.817689694464207, 23.190227821469307, 5.014410903677344, 0.5925708997529, 0.15754769527120516, 0.07634390771272592, 0.06303826114162803, 0.05260846279270481, 0.0858099567994941, 0.027569179437705316, 0.09770082499017008, 0.03670337719086092, 0.03510606016789097, 0.068383260659175, 0.08633602818008512, 0.010935388309007976, 0.04925896479107905, 0.018238049087813124, 0.03630253209848888, 0.036236733285477385, 0.010990168084390461, 0.03380605863640085, 0.020897843278362416, 0.03890631269314326, 0.03981208908953704, 0.03237469325540587, 0.08460533237666823, 0.028576865697687026, 0.031726430970593356, 0.050476684409659356, 0.05321064883901272, 0.03530007612425834, 0.030173225350154098, 0.12496726383687928, 0.11655769907520153, 0.23222020477987826, 0.15572024567518383, 0.1213595800800249, 0.1644128729822114, 0.14301950141089037, 0.12116408353904262, 0.16465991910081357, 0.1862050747149624, 0.15433435910381377, 0.2090214699273929, 0.08890470518963411, 0.2125482150586322, 0.13121234747814015, 0.20511372102191672, 0.251395846134983, 0.2532696502748877, 0.21372431132476777, 0.23193861910840496, 0.17468882782850415, 0.06603365822229534, 0.11309426656225696, 0.133458947238978, 0.30202349822502583, 0.20356779772555456, 0.23143335012719035, 0.17542814050102606, 0.15713902423158288, 0.24353182670893148, 0.180574934638571, 0.17385633109370247, 0.19099575671134517, 0.24621397809823975, 1.3628742936998606, 2.761369301006198, 46.00054442882538, 76.88203454017639, 86.25895097851753, 69.38320532441139, 80.62072992324829, 120.78552469611168, 71.13321661949158, 67.96154201030731, 85.52894935011864, 13.746461570262909, 0.34329884278122336, 0.5031090939883143, 0.7330326782539487, 0.45301780686713755, 0.8710171678103507, 5.124757932499051, 8.072795066982508, 5.6703459564596415, 12.02736446633935, 7.318555014207959, 11.554669830948114, 5.770491482689977, 12.009358182549477, 13.66073627024889, 6.134209390729666, 0.7966441148892045, 0.15167174104135484, 0.27026352589018643, 0.5813796690199524, 0.6048855639528483, 0.40029614057857543, 0.17037641548085958, 0.24495517689501867, 0.19658641453133896, 0.5669523181859404, 0.5268621537834406, 0.49265107547398657, 1.2892786553129554, 2.213749811053276, 3.467289009131491, 3.515305845066905, 3.1402201345190406, 3.6873059906065464, 3.703106017783284, 3.5392559599131346, 8.545299712568521, 17.113196812570095, 24.863620027899742, 37.396935895085335, 73.34972888231277, 75.20904511213303, 62.06254854798317, 40.955638736486435, 7.418547598645091, 0.8411994553171098, 5.66451801918447, 36.128613352775574, 76.32778868079185, 83.72232109308243, 83.28686445951462, 72.90896013379097, 59.69069302082062, 34.93307210505009, 21.75853304564953, 7.965637492015958, 4.313550386577845, 2.1662575844675303, 2.0959328580647707, 0.9048566676210612, 2.0890832506120205, 1.9987613847479224, 1.0047918395139277, 0.20931794308125973, 0.2225724927848205, 0.3313521057134494, 0.17661498306551948, 0.1403686686535366, 0.18012314481893554, 0.12607245531398803, 0.21523671923205256, 0.08793934175628237, 0.18245157378260046, 0.21251210215268657, 0.16955413069808856, 0.4406334104714915, 0.6229031283874065, 0.4184572957456112, 0.6275658344384283, 0.6628432602155954, 0.6546369474381208, 2.8425158467143774, 10.70814935490489, 9.701856952160597, 4.847243623808026, 9.52029224485159, 7.654464114457369, 2.948857652954757, 0.9027711732778698, 3.498057145625353, 11.914021298289299, 68.89123812317848, 40.287493988871574, 36.72193631529808, 93.67801487445831, 82.97181576490402, 29.346199594438076, 40.150830522179604, 59.62312124669552, 35.33552750945091, 6.3277957029640675, 1.0842506820335984, 0.35058691108133644, 0.2886637416668236, 0.18067582219373435, 0.15602210682118312, 0.24359369213925675, 0.19253989885328338, 0.1494366000406444, 0.11883695333381183, 0.17039299505995587, 0.1732590506435372, 0.11568396119400859, 0.12693420751020312, 0.20665909512899816, 0.12390714298817329, 0.17066827247617766, 0.2330501188407652, 0.08727697495487519, 0.21251930098515004, 0.13804593938402832, 0.13816929917084053, 0.21187032252782956, 0.17432182095944881, 0.18907218414824456, 0.12603188952198252, 0.15426995552843437, 0.18438163271639496, 0.17816993087762967, 0.1468239285168238, 0.12840582698117942], [0.034964521473739296, 0.043637938288156874, 0.07285490821232088, 0.06667027249932289, 0.013110946911183419, 0.016727821239328478, 0.03647527068096679, 0.022592969799006823, 0.049136911184177734, 0.03985297029430512, 0.015870134157012217, 0.01862123106548097, 0.12658714957069606, 0.043207826602156274, 0.0206728092598496, 0.05525995235075243, 0.04382108549179975, 0.0163420565877459, 0.013948084852017928, 0.015469004265469266, 0.060531564595294185, 0.08393198178964667, 0.012974735909665469, 0.1166207816277165, 0.04804494477866683, 0.09116049273870885, 0.03253840361139737, 0.051897852681577206, 0.0585521046014037, 0.04383175757538993, 0.1677564115379937, 0.13501337554771453, 0.13486038922565058, 0.09808534654439427, 0.03821789279754739, 1.357947145588696, 1.6403481108136475, 5.906339893117547, 30.77436625957489, 34.15247619152069, 29.648800157010555, 49.67936262488365, 68.44959542155266, 54.07555192708969, 39.602037370204926, 48.50731171667576, 16.303218975663185, 0.23589401389472187, 0.057507565143168904, 0.10274257554556243, 0.8351934025995433, 0.10760806602775119, 1.2175662908703089, 2.9682945599779487, 3.4994751820340753, 6.108727483078837, 8.259243462234735, 9.721082970499992, 3.69843321852386, 2.523720790632069, 1.9947511749342084, 0.3998458053683862, 0.1398901318316348, 0.010616679483064217, 0.1368826674297452, 0.1807110890513286, 0.15925227489788085, 0.08808498823782429, 0.14393695921171457, 0.0009461004685817898, 0.022793464704591315, 0.039150505253928714, 0.057383882522117347, 0.0711485771171283, 0.04981585756468121, 0.038778989837737754, 0.022092402323323768, 0.2221087395446375, 0.3497733094263822, 0.880851277615875, 1.2064144830219448, 1.949354773387313, 3.5682431794703007, 5.285788541659713, 4.89313043653965, 21.98504839092493, 18.209601379930973, 6.4597901701927185, 1.078573192935437, 0.3379517875146121, 0.6421396555379033, 0.8189901814330369, 6.885453779250383, 40.41042499244213, 53.326357528567314, 58.60207423567772, 47.20045164227486, 29.536637775599957, 11.499984115362167, 2.024785950779915, 0.8378702402114868, 0.39893940556794405, 0.23731004650471732, 0.10157229771721177, 0.1345995391602628, 0.04870151911745779, 0.028652412620431278, 0.05505789151357021, 0.044308743308647536, 0.05138843509485014, 0.07806324123521335, 0.04728630658064503, 0.037857568968320265, 0.05304985141265206, 0.03100473688391503, 0.012934178466821322, 0.012422104919096455, 0.05431359903013799, 0.02926414268586086, 0.059739633652498014, 0.04758991548442282, 0.11025929954485036, 0.01527724814877729, 0.22326277918182313, 0.36537853768095374, 0.4747252998640761, 2.264765161089599, 1.9484874699264765, 0.5399476422462612, 0.6639545224606991, 1.4688099967315793, 0.20201851992169395, 0.6559621263295412, 1.8220441485755146, 13.966445066034794, 36.70409247279167, 10.966523140668869, 23.839151300489902, 78.18162560462952, 52.28367827832699, 33.345836475491524, 11.550324764102697, 21.09092026948929, 8.16254435107112, 4.693232662975788, 0.5017950769979507, 0.044779443051083945, 0.2815104473847896, 0.05428341217339039, 0.08665015702717938, 0.013151411585567985, 0.04556413434329443, 0.1042300027620513, 0.12927031028084457, 0.020440235020942055, 0.04776637222676072, 0.1160343291121535, 0.04096645898243878, 0.031861075112828985, 0.02823333295964403, 0.033765440894057974, 0.052060542584513314, 0.04329647243139334, 0.02900348186813062, 0.03676997381262481, 0.01969509834452765, 0.04578188047162257, 0.04567678493913263, 0.031577545014442876, 0.10555924120126292, 0.10628633812302724, 0.07017974043264985, 0.03857912575767841, 0.02484496682882309, 0.04903365617792588, 0.028880246391054243, 0.0493723575345939, 0.013349668915907387, 0.01766715940902941, 0.06301782239461318, 0.02041879437456373, 0.037162759181228466, 0.027225800695305225, 0.1298972766380757, 0.10296377266058698, 0.059491886204341426, 0.02585094429377932, 0.0370858207315905, 0.11178706248756498, 0.04519528694800101, 0.09317085947259329, 0.019033644384762738, 0.06759241325198673, 0.007320717231777962, 0.10412386822281405, 0.03214792632206809, 0.045377558417385444, 0.01498153013017145, 0.032700032243155874, 0.09163388647721149, 0.035621106944745407, 0.09113941574469209, 0.014764556763111614, 0.07786471673171036, 0.05658202906488441, 0.08563947063521482, 0.19325584871694446, 0.08681557432282716, 0.07753351848805323, 0.08435931042185985, 0.10804538396769203, 1.3869207096286118, 4.324357956647873, 38.798756673932076, 55.26951625943184, 52.292353212833405, 45.80474853515625, 73.6003178358078, 76.30687460303307, 48.260807543992996, 70.03807738423347, 84.02372851967812, 12.227769512683153, 0.14327150507597253, 0.1797244482440874, 0.06355078832712024, 0.2560003678081557, 0.1356566691538319, 0.6747735512908548, 2.220884165726602, 2.4640309810638428, 2.8405736759305, 1.8611314636655152, 2.1796492533758283, 7.661813870072365, 7.401344021782279, 5.285025257617235, 3.520633396692574, 0.8187010406982154, 0.257569772657007, 0.11805189467850141, 0.7150291255675256, 0.731627584900707, 0.1947550315526314, 0.2639178070239723, 0.12386654008878395, 0.037992695506545715, 0.02782260431558825, 0.042670533948694356, 0.02251217589218868, 0.11623542886809446, 0.06673818643321283, 0.2524700900539756, 0.1134869220550172, 0.6899968406651169, 0.3273136052303016, 1.8498207768425345, 2.2112008603289723, 4.417791618034244, 5.626308219507337, 4.688277253881097, 22.89909314364195, 19.83721934258938, 5.768366446718574, 1.2503186333924532, 0.1516697817714885, 1.5209264564327896, 0.6564090179745108, 8.468987457454205, 47.438204884529114, 59.18696545064449, 62.880222871899605, 50.686247795820236, 35.27285747230053, 13.462896086275578, 2.3765717865899205, 1.3977281609550118, 1.447891762945801, 0.7951185561250895, 0.1938257142319344, 0.29711365699768066, 0.1708614535164088, 0.006688216308248229, 0.04267670119588729, 0.02589607800473459, 0.029268805228639394, 0.15508121199673042, 0.14242860343074426, 0.014830769323452841, 0.11062531935749575, 0.08384635279071517, 0.01667628650466213, 0.044648483672062866, 0.047538132130284794, 0.07751817087410018, 0.13414911489235237, 0.26614178612362593, 0.13035544892773032, 0.019121442310279235, 0.2940835867775604, 0.5539473379030824, 0.6543531501665711, 1.808538248296827, 1.4279126725159585, 1.0709823877550662, 0.675608734600246, 1.4717475953511894, 0.12749628047458827, 0.5045368080027401, 2.641851701773703, 8.64428535103798, 70.729860663414, 33.79920914769173, 16.269330494105816, 62.81309187412262, 72.10742354393005, 45.23130990564823, 24.657465890049934, 26.152856647968292, 32.68673524260521, 6.1722890473902225, 0.22604298312216997, 0.45898698968812823, 0.1235945058579091, 0.20093308441573754, 0.03512899995257612, 0.04554080864181742, 0.059931794239673764, 0.17742319672834128, 0.06907374743605033, 0.10259793096338399, 0.03475867568340618, 0.15866971865762025, 0.06590448741917498, 0.0579594328883104, 0.024051941218203865, 0.04598667241225485, 0.04214114145725034, 0.056958394416142255, 0.028884174207632896, 0.043988384131807834, 0.09897056545014493, 0.03198339960363228, 0.06759685129509307, 0.04405404564749915, 0.049697399663273245, 0.03351279527123552, 0.03413836268009618, 0.10086519425385632, 0.009618912954465486, 0.04590251286572311, 0.0805483598378487, 0.11364017555024475, 0.1400041554006748, 0.12424678687239066, 0.16488646710058674, 0.07361316049355082, 0.13099776289891452, 0.1649228174937889, 0.13905784289818257, 0.1840556220849976, 0.12481859681429341, 0.11539965926203877, 0.15715596004156396, 0.23194804438389838, 0.11384509736672044, 0.24198122788220644, 0.22632442036410794, 0.14301822491688654, 0.1311741120298393, 0.15716468769824132, 0.0768888444872573, 0.19162061536917463, 0.24749260948738083, 0.11653246605419554, 0.2117031314992346, 0.22302929952275008, 0.1926446901052259, 0.13885390071664006, 0.12454418028937653, 0.30096056463662535, 0.14515087532345206, 0.3097763884579763, 0.21664041734766215, 0.24996020598337054, 0.21320897882105783, 0.22277974494500086, 1.4178574620746076, 4.9735279474407434, 65.10761395096779, 84.87984538078308, 77.77577698230743, 66.52905687689781, 88.9129413664341, 108.85569244623184, 74.9431049823761, 62.075046077370644, 89.1608476638794, 26.077176108956337, 0.3647706296760589, 0.22452805191278458, 0.18030477804131806, 1.3442086265422404, 0.21194698638282716, 2.091864226385951, 6.638972880318761, 6.81987214833498, 13.706560861319304, 15.67808697000146, 21.14295657724142, 11.2143942900002, 10.784266870468855, 5.608832957223058, 3.232249296270311, 1.0663852281868458, 0.30122037569526583, 0.21805885451612994, 0.635655956575647, 0.4348348919302225, 0.6029778288211673, 0.5565797060262412, 0.181640361843165, 0.14816209499258548, 0.2717800601385534, 0.22987249481957406, 0.2972640161169693, 0.3572627966059372, 0.1293233738397248, 0.282433174434118, 0.4505998006789014, 2.17427515424788, 2.9486857121810317, 4.659197414293885, 3.37616253644228, 6.703271130099893, 7.2880208026617765, 7.2372132539749146, 28.352684006094933, 24.940256215631962, 7.8185260109603405, 2.7573441294953227, 0.794950652634725, 4.11968526430428, 2.061145012266934, 9.63589059188962, 51.24184638261795, 60.08312076330185, 61.981647089123726, 50.043432489037514, 37.063712775707245, 16.580001823604107, 3.910540211945772, 2.449521697126329, 1.719469246454537, 0.8836799289565533, 0.3208271157927811, 0.281998275895603, 0.16572178399655968, 0.12083227673429064, 0.20633260952308774, 0.10269066973705776, 0.31438928155694157, 0.3537971153855324, 0.2549479727167636, 0.13118666916852817, 0.2516385877970606, 0.30201963905710727, 0.10971193594741635, 0.18435025471262634, 0.18643224611878395, 0.1541510783135891, 0.24357735004741699, 0.22177921113325283, 0.18178395257564262, 0.15524668124271557, 0.2843370503978804, 0.7630375900771469, 1.1661023274064064, 3.6968430038541555, 10.742838643491268, 6.5685788076370955, 3.743805158883333, 6.42235885374248, 0.3431654640007764, 1.5318451705388725, 1.9764841301366687, 24.258798882365227, 65.51335617899895, 27.08263635635376, 39.893781915307045, 102.21750944852829, 82.20418095588684, 52.43722043931484, 34.90009747445583, 48.37913319468498, 49.58973303437233, 10.009624287486076, 0.4079324542544782, 0.5200379574671388, 0.30452480306848884, 0.37157122569624335, 0.1258880167733878, 0.098012326634489, 0.1376456397701986, 0.28681766416411847, 0.14364829345140606, 0.27286650496535003, 0.10006334821810015, 0.23629462521057576, 0.1145044807344675, 0.18760540348012, 0.1298406656133011, 0.09637098541134037, 0.11258401034865528, 0.10959928535157815, 0.19584575115004554, 0.10639821688528173, 0.13709173043025658, 0.15518803673330694, 0.1323214574949816, 0.09356346301501617, 0.25954177777748555, 0.15353766357293352, 0.0976505593280308, 0.10856163673452102, 0.18392323778243735, 0.13040373305557296, 0.20678649219917133], [0.08516631438396871, 0.01944983894645702, 0.04727839528641198, 0.00702550665664603, 0.02210560327512212, 0.10083979796036147, 0.07619605705258437, 0.017826849179982673, 0.08308839736855589, 0.0388782854861347, 0.0785115132748615, 0.08065967456786893, 0.06436088704504073, 0.043543655847315677, 0.01601523701538099, 0.05171696531760972, 0.04795126347744372, 0.03287728308350779, 0.038631770003121346, 0.026301876932848245, 0.017576096033735666, 0.032462014351040125, 0.05275082898151595, 0.05994497849314939, 0.016112029770738445, 0.039759893843438476, 0.040520298352930695, 0.011587354838411557, 0.13658482872415334, 0.09367866659886204, 0.1172092008346226, 0.06038209605321754, 0.1478350898833014, 0.1406344465794973, 0.0491853437415557, 0.16847044666064903, 1.4387494535185397, 2.9930777801200747, 15.431194268167019, 28.570435121655464, 37.64178715646267, 26.415578350424767, 54.704304188489914, 88.81826564669609, 48.49287249147892, 30.764192305505276, 49.00261893868446, 24.752069413661957, 1.3912116293795407, 0.04428049345733598, 0.4883155378047377, 0.15213136794045568, 0.6027072120923549, 0.9076175163500011, 0.7369351875968277, 1.1031685606576502, 5.29138564132154, 4.807625999674201, 7.290221359580755, 11.318541001528502, 3.737389203161001, 0.7627160323318094, 0.5807533557526767, 0.16012507025152445, 0.3206824860535562, 0.20797044038772583, 0.15121267817448825, 0.5639713781420141, 0.3597514552529901, 0.30264022294431925, 0.07866549407481216, 0.07202585504273884, 0.009448995460843435, 0.0051115653150191065, 0.03051973781111883, 0.07344541285419837, 0.0945117644732818, 0.04405948187923059, 0.06083572639909107, 0.2815328602446243, 0.4348060075426474, 0.08137916447594762, 0.34251513483468443, 0.2652661706088111, 0.7958332146517932, 1.463371894787997, 1.1916191456839442, 0.328701896360144, 1.4116522762924433, 3.0117590026929975, 1.2896315613761544, 0.5470894183963537, 0.4491736303316429, 12.427095416933298, 28.813549876213074, 27.572882249951363, 14.965624250471592, 3.1654733419418335, 0.41713559010531753, 0.22777512611355633, 0.13318234879989177, 0.05677264969563112, 0.08383971799048595, 0.005409575178418891, 0.01803196395485429, 0.06199120951350778, 0.047972845131880604, 0.12761726538883522, 0.03128467498754617, 0.008798761846264824, 0.040927882146206684, 0.01212349994602846, 0.06692335970001295, 0.06678545381873846, 0.10781627555843443, 0.03443834990321193, 0.10618151718517765, 0.05506464876816608, 0.0772233452880755, 0.05558975535677746, 0.09682673087809235, 0.06172014749608934, 0.29141900944523513, 0.7939753518439829, 0.0780799172935076, 0.17674940085271373, 0.3188934351783246, 0.5080936546437442, 1.9165543396957219, 0.3600118006579578, 0.5147342733107507, 2.515449821949005, 0.17732553009409457, 28.254202790558338, 31.441458463668823, 12.526076305657625, 44.67514134943485, 82.16337874531746, 52.38395869731903, 19.98397696763277, 21.54719978570938, 20.531841069459915, 17.26486187428236, 2.8984721191227436, 0.16521191369974986, 0.41136028594337404, 0.10061204768135212, 0.14559859817381948, 0.05327887447492685, 0.09261568848160096, 0.08886065872502513, 0.09064730504178442, 0.01381842886985396, 0.12666170572629198, 0.040489406455890276, 0.1469500787789002, 0.0522451035794802, 0.042678382160374895, 0.03593947345507331, 0.044576747677638195, 0.05738115884014405, 0.11303389284876175, 0.05613883331534453, 0.0505995506682666, 0.02660335030668648, 0.032732887120801024, 0.061365597575786524, 0.052319114256533794, 0.054262316625681706, 0.08646611182484776, 0.00402780845433881, 0.0389304287818959, 0.03649557213066146, 0.04794645436049905, 0.06240932067157701, 0.048807364219101146, 0.05488992865139153, 0.015477292199648218, 0.027760981938627083, 0.03461666201474145, 0.03190122159139719, 0.053020273116999306, 0.05138453510880936, 0.04065647874085698, 0.0800346749019809, 0.056462595239281654, 0.04983620725397486, 0.05545304433326237, 0.05480162421008572, 0.03276229472248815, 0.03990975201304536, 0.03153748759359587, 0.0633531172934454, 0.04256773536326364, 0.0678872165735811, 0.016510216119058896, 0.03020426938746823, 0.02976370455144206, 0.015392834866361227, 0.02377974371484015, 0.08596237166784704, 0.03341523253766354, 0.07177988503826782, 0.1407130845473148, 0.12906151445349678, 0.06548676959937438, 0.1226438517915085, 0.026794919031090103, 0.15687446342781186, 0.1395856137969531, 0.2861225389642641, 0.3301904664840549, 2.098093517124653, 10.769786797463894, 51.29991486668587, 53.00715945661068, 58.98907206952572, 51.173788234591484, 77.75434613227844, 82.89897367358208, 41.28197282552719, 51.37021489441395, 81.58371224999428, 23.21369156241417, 0.23110992216970772, 0.307104597450234, 0.8866133121773601, 0.582005922915414, 0.2733635064214468, 0.1603089744457975, 0.9283567441161722, 2.387860268354416, 3.6016763979569077, 7.214839579537511, 7.41503088735044, 7.787879230454564, 9.36820350587368, 2.0641914987936616, 0.9048509679269046, 0.30104294302873313, 0.7738664746284485, 0.6738310237415135, 0.8942902064882219, 3.1161237275227904, 2.896224302239716, 0.6708675983827561, 0.05960856666206382, 0.06140964032965712, 0.05197112863243092, 0.04924563952954486, 0.058724260597955436, 0.06379479164024815, 0.029230387954157777, 0.013181977865315275, 0.07861509482609108, 0.08727517153602093, 0.12386259186314419, 0.03588282532291487, 0.18192032963270321, 0.6656495877541602, 0.912700752960518, 2.232675882987678, 1.5541109070181847, 0.6138853216543794, 2.3920298321172595, 4.273873390629888, 2.4586946424096823, 1.791508630849421, 2.3728372994810343, 16.22021432965994, 33.11029091477394, 30.367417596280575, 17.64752984046936, 2.919455305673182, 1.1075854673981667, 0.5376104707829654, 0.29708625690545887, 0.05392392326029949, 0.15129331994103268, 0.040861048037186265, 0.01964694409252843, 0.11646608094451949, 0.03181696927640587, 0.10057344115921296, 0.11776434213970788, 0.1141053759783972, 0.004651228273360175, 0.0767808397358749, 0.151375713176094, 0.01621919403987704, 0.09626021244912408, 0.08929950548917986, 0.10005620133597404, 0.0268740412502666, 0.028696785630017985, 0.046575444139307365, 0.07649123144801706, 0.07896972267189994, 0.13745971693424508, 0.33062008093111217, 0.04552457045065239, 1.05620521819219, 1.8639231263659894, 0.293431268655695, 0.2716508670710027, 0.7886890042573214, 0.1903336273971945, 1.138371059205383, 0.654916885541752, 27.004822231829166, 68.41332256793976, 26.116699688136578, 21.5170731022954, 68.12539681792259, 71.04838997125626, 33.808837831020355, 35.2896411716938, 29.431107938289642, 35.115952491760254, 15.795776154845953, 0.29217142844572663, 0.9715170250274241, 0.10999657184584066, 0.19015919300727546, 0.019823950024147052, 0.1086366901290603, 0.11418317531934008, 0.13379788608290255, 0.032712036481825635, 0.1182160057942383, 0.021941469894954935, 0.14145674620522186, 0.027887596043001395, 0.013942361965746386, 0.03784987289691344, 0.03639520778961014, 0.03030452055099886, 0.030397663795156404, 0.029794509246130474, 0.044275083200773224, 0.029067750001559034, 0.09743685790454037, 0.03643382544396445, 0.0723792435019277, 0.06196267393534072, 0.04977244192559738, 0.03144527203403413, 0.05954811873380095, 0.035028795173275284, 0.04471558495424688, 0.022459058527601883, 0.0316206526622409, 0.2576289960416034, 0.09486451468546875, 0.17896619596285746, 0.25624857167713344, 0.13825233065290377, 0.17809636919992045, 0.21022679196903482, 0.14484561514109373, 0.1515228216885589, 0.1577706215903163, 0.1684729105909355, 0.1420656783739105, 0.162348099402152, 0.12433640120434575, 0.11790229997131974, 0.10449134264490567, 0.23574591090437025, 0.09388217091327533, 0.25002385256811976, 0.12465631880331784, 0.1449473190587014, 0.13949070795206353, 0.12508294981671497, 0.09851499809883535, 0.17454939312301576, 0.09517690690699965, 0.19110387278487906, 0.183760158251971, 0.24219662882387638, 0.22286068357061595, 0.1663504127645865, 0.13728416932281107, 0.32046456180978566, 0.22511808900162578, 0.48882809467613697, 0.2505674015264958, 1.6828647418878973, 13.975568376481533, 77.2514659166336, 79.55000057816505, 86.46716460585594, 64.0751713514328, 88.87776285409927, 132.3183238506317, 66.74681559205055, 47.5710229575634, 91.53388112783432, 45.40719486773014, 1.0437993588857353, 0.6467045762110502, 1.8124369578436017, 1.3452717382460833, 1.710604322142899, 2.6081220991909504, 1.5286762593314052, 3.6499140970408916, 8.352478109300137, 10.650210063904524, 13.073109202086926, 22.170818522572517, 17.406263686716557, 3.643083251081407, 2.99491616897285, 0.7619051320943981, 1.271351098548621, 0.4251517349621281, 0.2883207506965846, 1.377272552344948, 1.6500640707090497, 0.5221502284985036, 0.22353419743012637, 0.21545624651480466, 0.11933342786505818, 0.1337340020108968, 0.22512421914143488, 0.15906495682429522, 0.1956537872320041, 0.08401726197917014, 0.19423270801780745, 0.3535377496154979, 0.5232710496056825, 0.2869911486050114, 0.5280061298981309, 0.9540562494657934, 1.6273620701394975, 2.9243674920871854, 2.3588927602395415, 1.1558647267520428, 2.664096658118069, 7.312340447679162, 4.998342040926218, 4.870201041921973, 6.7352525889873505, 18.08905854821205, 34.88865628838539, 32.11439475417137, 18.864213153719902, 3.468165099620819, 2.1064563933759928, 0.938282108400017, 0.34557159582618624, 0.16075887921033427, 0.2643114124657586, 0.09909877146128565, 0.0905268470523879, 0.1496691000647843, 0.21321706823073328, 0.17914254509378225, 0.1589899108512327, 0.20488187408773229, 0.13106351718306541, 0.2134266062057577, 0.3355465462664142, 0.17763398151146248, 0.22647816367680207, 0.12733253301121294, 0.1603829814121127, 0.15453052357770503, 0.13811053591780365, 0.16035632346756756, 0.3137279982911423, 0.24455946375383064, 0.47255347890313715, 0.8510161691810936, 0.4348296078387648, 1.2111087748780847, 3.6425303807482123, 3.438341449946165, 3.013174426741898, 3.5623639449477196, 1.5141507075168192, 4.482504520565271, 0.2909105195431039, 47.47138470411301, 54.34059910476208, 25.546583980321884, 66.55381634831429, 105.90290889143944, 78.47113206982613, 34.74860340356827, 44.45751942694187, 59.749620258808136, 55.67806273698807, 22.831276282668114, 0.2310176138416864, 0.9874791966285557, 0.37849771964829415, 0.29193118039984256, 0.09164529328700155, 0.23073564225342125, 0.25592431251425296, 0.2003707888070494, 0.08915716156479903, 0.21746725891716778, 0.05457023740746081, 0.2610823279246688, 0.14043378469068557, 0.1940904086222872, 0.09280808284529485, 0.114222011907259, 0.11598462748224847, 0.2237042976776138, 0.11516045764437877, 0.15916205942630768, 0.1332539808936417, 0.24504102853825316, 0.17847694252850488, 0.1810161117464304, 0.1986364193726331, 0.16645796480588615, 0.10892289195908234, 0.21313087519956753, 0.16016522044083104, 0.14777300180867314, 0.12995158700505272, 0.16046227246988565], [0.02881105410779128, 0.031643666661693715, 0.027800805582955945, 0.04495814107940532, 0.023674943186051678, 0.03254031835240312, 0.07816463345079683, 0.04388880646729376, 0.061584809445776045, 0.055998378156800754, 0.025103232364926953, 0.042297708641854115, 0.02630253558891127, 0.001724618773550901, 0.07070503255818039, 0.11897492600837722, 0.03813788927800488, 0.043147063261130825, 0.03364801828865893, 0.02631721526995534, 0.03326506266603246, 0.0363893522444414, 0.05667812976753339, 0.03233922972867731, 0.03300662458059378, 0.028970656676392537, 0.016050791455199942, 0.019647754888865165, 0.03435187856666744, 0.08637969614937901, 0.10342948517063633, 0.14057372405659407, 0.09706228855066001, 0.07009549182839692, 0.15811555698746815, 0.3546425700187683, 0.7730064739007503, 2.0757060684263706, 3.5114986868575215, 20.879254527390003, 27.595850117504597, 31.61595080047846, 33.062709867954254, 72.65435099601746, 100.38146317005157, 64.10572931170464, 28.915604799985886, 47.201135605573654, 32.534367218613625, 3.920395220629871, 0.3503353230189532, 0.28035456722136587, 0.18572017026599497, 0.49384340993128717, 0.8728586439974606, 0.8697931584902108, 1.7648775223642588, 1.9671149016357958, 5.271979607641697, 3.67061419878155, 5.545021556317806, 1.6622322052717209, 0.8522105519659817, 0.2409202090348117, 0.04977105782018043, 0.6234638358000666, 0.43770459888037294, 3.169303061440587, 2.937738737091422, 0.8117934863548726, 0.16182387596927583, 0.055177403264679015, 0.11703220603521913, 0.04604686429956928, 0.029296839857124723, 0.08326667608343996, 0.022855270763102453, 0.03547712658473756, 0.02355655022256542, 0.1188232607091777, 0.04692030532169156, 0.04184282777714543, 0.013863754611520562, 0.09223616900271736, 0.3054515377152711, 0.24001201323699206, 0.18320390372537076, 0.20409283752087504, 0.0604007388028549, 0.1672998719732277, 0.8525826944969594, 0.3849153674673289, 3.756614034064114, 1.4813492051325738, 2.7482830407097936, 1.3914561225101352, 0.3737988858483732, 0.433810698450543, 0.4564900486730039, 0.2817312511615455, 0.10230196246993728, 0.015564829445793293, 0.047578701633028686, 0.08223835626267828, 0.02899364655604586, 0.10866059470572509, 0.07336655224207789, 0.04146751256485004, 0.06516159017337486, 0.02802469112793915, 0.05969540907244664, 0.051405749400146306, 0.04450279266166035, 0.030205172952264547, 0.01991023396840319, 0.07949892591568641, 0.023912248616397846, 0.026097875379491597, 0.057174355679308064, 0.06882320580189116, 0.1470032165525481, 0.1805327064357698, 0.21117126394528896, 0.9591608599293977, 0.4422082775272429, 1.2163144955411553, 1.4495742414146662, 1.1297649960033596, 1.080525575671345, 0.6065309944096953, 2.050634538754821, 5.033787013962865, 39.73511762917042, 21.41625501215458, 13.833586145192385, 64.52410206198692, 77.10061401128769, 46.184066981077194, 21.598476134240627, 21.569774374365807, 22.082009688019753, 18.05234681814909, 2.5662979809567332, 0.11406831312342547, 0.636415797052905, 0.22909663879545406, 0.12902180955279619, 0.11365469195879996, 0.07303288264665753, 0.11793183002737351, 0.1503000591765158, 0.1847689299029298, 0.028629296575672925, 0.019091212780040223, 0.032585711815045215, 0.010003588504332583, 0.055303716799244285, 0.029112130432622507, 0.010953649780276464, 0.08807534773950465, 0.009796104423003271, 0.10230921325273812, 0.09492499229963869, 0.03752951743081212, 0.01706555409327848, 0.07046796832582913, 0.07397023000521585, 0.06927500304300338, 0.056130740194930695, 0.03409310651477426, 0.15921267389785498, 0.011319821733195568, 0.03050275561690796, 0.00801493422841304, 0.04200683870294597, 0.030726318327651825, 0.009747730309754843, 0.044077920538256876, 0.0024592334193584975, 0.05111949190904852, 0.005555110801651608, 0.03627625264925882, 0.03057041350984946, 0.03403642498597037, 0.06933773678611033, 0.022044754587113857, 0.037286731239873916, 0.02977317064505769, 0.04050939249282237, 0.04398374199809041, 0.017212109705724288, 0.06171030290715862, 0.02046929752395954, 0.06610400640056469, 0.015213427159324056, 0.04141624871408567, 0.030667735045426525, 0.07000274563324638, 0.04254897386999801, 0.03335498127853498, 0.024810200920910574, 0.0820713878783863, 0.0309639540137141, 0.10670790026779287, 0.07978186971740797, 0.11831851865281351, 0.09558104342431761, 0.10979329017573036, 0.15760300011606887, 0.02903740172769176, 0.09767543611815199, 0.3911788563709706, 1.3221436855383217, 3.169486401602626, 7.3530172649770975, 59.60191838443279, 57.52984777092934, 54.104692563414574, 61.11596994102001, 103.51103603839874, 87.3079226911068, 45.83079233765602, 49.428180903196335, 85.05675628781319, 37.73372322320938, 2.2994743986055255, 0.24128491524606943, 0.2642122615361586, 0.544028504518792, 0.1737238428904675, 0.7768433180171996, 0.752027384005487, 0.5684455193113536, 2.265049433335662, 4.273408390581608, 3.4433270199224353, 1.4892735611647367, 3.2454609498381615, 0.29182448924984783, 0.4716501070652157, 0.11341855541104451, 2.2135211108252406, 0.7760700595099479, 2.758428258821368, 1.4899731986224651, 0.35216254997067153, 0.12544045719550923, 0.10773791960673407, 0.08369076153030619, 0.060038463125238195, 0.06333531317068264, 0.019406386199989356, 0.03494009739370085, 0.03527117689372972, 0.020254481023584958, 0.049472773825982586, 0.004622915339496103, 0.0442808867956046, 0.0421656731487019, 0.22353449428919703, 0.0247922019843827, 0.3452359966468066, 0.195891244802624, 0.318464117590338, 0.04411960697325412, 0.2562188857700676, 0.503858900628984, 1.4230476273223758, 5.150930928066373, 2.2172175999730825, 3.950801189057529, 2.039403528906405, 0.5099943245295435, 0.9662722377106547, 0.7059984351508319, 0.4074267251417041, 0.08502878699800931, 0.008439080902462592, 0.07002786733210087, 0.01396517465764191, 0.0902119315287564, 0.041486808404442854, 0.02830257533787517, 0.06253738567465916, 0.029757876836811192, 0.04342115324106999, 0.12170078247436322, 0.08183482830645517, 0.0941620125377085, 0.019364380641491152, 0.03529735615302343, 0.04333091179432813, 0.0532666030630935, 0.07310794346267357, 0.07245012602652423, 0.08412712952122092, 0.15109761559870094, 0.1931744796456769, 0.3217740368563682, 0.32298816076945513, 0.21419183467514813, 1.9622495002113283, 1.3180013140663505, 0.5629150348249823, 0.8075945929158479, 0.3433878708165139, 2.211469220928848, 3.080852832645178, 51.381249502301216, 56.794009655714035, 20.68289626389742, 34.249234199523926, 76.16305232048035, 67.19365641474724, 38.562929928302765, 30.187706239521503, 34.055957570672035, 39.90162469446659, 18.476035483181477, 0.24169432843336836, 1.301442040130496, 0.2786619361722842, 0.2648630953626707, 0.01777258705260465, 0.06418723933165893, 0.055482989992015064, 0.07767235205392353, 0.07135395164368674, 0.16272859851596877, 0.04464748177269939, 0.13846077024936676, 0.06775731104426086, 0.08357402912224643, 0.04382074039313011, 0.08710213238373399, 0.12304090821999125, 0.03337075191666372, 0.10429068075609393, 0.05677989305695519, 0.062050288179307245, 0.12207834268338047, 0.06280144923948683, 0.033556548587512225, 0.026978648820659146, 0.07451348952599801, 0.009642784134484828, 0.029961553700559307, 0.02036271027463954, 0.033345589399687015, 0.03018923533090856, 0.08269207566627301, 0.030892852555552963, 0.18259023665450513, 0.18445077119395137, 0.1654940188745968, 0.2016605672542937, 0.10075451034936123, 0.16112321434775367, 0.13646332430653274, 0.14324722200399265, 0.22922865202417597, 0.11380961528629996, 0.10904727590968832, 0.10830640472704545, 0.1339895382989198, 0.10475347662577406, 0.23682589904638007, 0.2251800286467187, 0.12544081342639402, 0.20322851749369875, 0.12582484516315162, 0.20661150861997157, 0.1160727278329432, 0.17403055768227205, 0.16682650049915537, 0.09080481104319915, 0.11807654882431962, 0.27072413242422044, 0.2212668175343424, 0.22210940747754648, 0.2191990753635764, 0.27419233694672585, 0.289595018257387, 0.25475373782683164, 0.16041633352870122, 0.15006540692411363, 0.23400941892759874, 0.7691404782235622, 0.9420885541476309, 2.249304265715182, 12.313033137470484, 85.52721664309502, 82.93887913227081, 77.73140296339989, 75.03675475716591, 108.54054495692253, 132.60555803775787, 91.77776724100113, 42.1405291557312, 86.44235953688622, 73.45529481768608, 5.194526938721538, 0.46089056879282, 0.4900764167541638, 0.4922328901011497, 0.3221246867906302, 1.586548222694546, 1.31823725765571, 2.651612190529704, 4.195508770644665, 11.676299404352903, 9.948481768369675, 15.279389563947916, 8.942359406501055, 4.088342171162367, 1.5969384089112282, 0.15694499714300036, 2.129287230782211, 0.2653213863959536, 4.203685931861401, 7.096843086183071, 3.062134087085724, 0.6502682506106794, 0.1374907832359895, 0.30924631690140814, 0.14361136418301612, 0.09919161413563415, 0.16250420274445787, 0.1795220052008517, 0.15518061525654048, 0.13242995948530734, 0.18030793959042057, 0.15338975354097784, 0.15918245364446193, 0.10485149949090555, 0.3702911693835631, 0.6052800302859396, 0.6632792274467647, 0.6938360002823174, 0.5556739296298474, 0.12827313097659498, 0.3748651739442721, 2.9154574451968074, 3.849564171396196, 7.279538232833147, 4.3395918142050505, 5.4160089790821075, 3.761933036148548, 2.2921925643458962, 1.6776494029909372, 1.5510192979127169, 0.7325995608698577, 0.20248556829756126, 0.10582203569356352, 0.22508693364216015, 0.09723681199830025, 0.18162790860515088, 0.2524383261334151, 0.19584350986406207, 0.1031290266837459, 0.1835334172938019, 0.19147500599501655, 0.1893559962627478, 0.2066053487942554, 0.2037734171608463, 0.1688989033573307, 0.12122215659474023, 0.19475149892969057, 0.13744349358603358, 0.20311464235419407, 0.17768722318578511, 0.14933468832168728, 0.2104795674677007, 0.21018107567215338, 0.9014708711765707, 1.239500257652253, 0.5678816058207303, 4.099713061004877, 5.373518709093332, 1.6888962057419121, 2.1879824437201023, 1.6228900663554668, 3.363164383918047, 10.294225215911865, 63.68646740913391, 39.228346422314644, 30.36870002746582, 88.51757258176804, 99.11768138408661, 69.81173872947693, 39.58978682756424, 44.026079177856445, 58.57276640832424, 61.77060641348362, 23.930450901389122, 0.26099555601831526, 1.5518534719012678, 0.39356854220386595, 0.45718944864347577, 0.17842040571849793, 0.14904385549016297, 0.2123571268748492, 0.25851844518911093, 0.22911813139216974, 0.21334240213036537, 0.18461543892044574, 0.21610712487017736, 0.20775912125827745, 0.2002619008999318, 0.1708391890861094, 0.14158936799503863, 0.2451223085517995, 0.1578471518587321, 0.20933563588187099, 0.19495781598379835, 0.12014074352919124, 0.19557988416636363, 0.21698331926018, 0.13145482196705416, 0.15491556463530287, 0.11309840774629265, 0.17105990380514413, 0.3174059634329751, 0.14204489823896438, 0.11664104225928895, 0.1330297187087126, 0.11998576825135387, 0.12730311427731067], [0.006585493792954367, 0.044501775919343345, 0.036021573541802354, 0.046667021451867186, 0.052537773226504214, 0.03617969181505032, 0.012822714379581157, 0.0378977970831329, 0.03183425389579497, 0.07018190750386566, 0.05919241106312256, 0.07745002687443048, 0.02559971617301926, 0.04481239811866544, 0.06238034722628072, 0.05881153716472909, 0.04268992255674675, 0.0594191223353846, 0.011819677674793638, 0.07470787284546532, 0.06769215047825128, 0.10452537011587992, 0.05370134203985799, 0.07762841691146605, 0.0512515793525381, 0.028046888764947653, 0.11878457255079411, 0.03078773104789434, 0.006116018594184425, 0.11937036455492489, 0.07986553202499636, 0.16334795043803751, 0.08196201015380211, 0.19624094478785992, 0.155622519669123, 0.2640247653471306, 0.15612903545843437, 1.2714067893102765, 0.5124906718265265, 3.8305965391919017, 21.605830639600754, 31.924480944871902, 39.93851691484451, 32.58909568190575, 41.41563065350056, 105.92647522687912, 59.124967977404594, 24.768414236605167, 29.810684770345688, 47.13992848992348, 12.521259114146233, 0.27420661586802453, 0.7859469170216471, 0.21967217966448516, 0.4386937926756218, 0.8979880018159747, 1.6555969300679862, 2.672213022597134, 2.7352718263864517, 2.1377099538221955, 3.3012481313198805, 3.207714012823999, 2.5446799909695983, 0.7609026390127838, 2.0637397980317473, 1.976069239899516, 8.215712998062372, 7.113832924515009, 1.760639799758792, 0.16042685718275607, 0.021538071814575233, 0.011524602541612694, 0.061707634886261076, 0.04104210980585776, 0.0365232282638317, 0.056605031932122074, 0.047654716108809225, 0.11491658791783266, 0.0897964475734625, 0.056354642438236624, 0.022902653181517962, 0.015171794530033367, 0.05881788252736442, 0.004721119103123783, 0.054095333398436196, 0.07178503554314375, 0.04674951116612647, 0.019844401758746244, 0.05214351098402403, 0.08929813993745483, 0.05556647047342267, 0.5766150215640664, 0.19876605772878975, 0.26496284001041204, 0.5278509319759905, 1.5195784787647426, 0.8514121198095381, 0.29796593938954175, 0.24208345130318776, 0.07922735923784785, 0.012317053915467113, 0.021634244876622688, 0.0419549328944413, 0.006861724868940655, 0.02945663538412191, 0.006662485120614292, 0.04487751044507604, 0.03187455622537527, 0.09040137214469723, 0.05391976723331027, 0.05080685477878433, 0.03146624883811455, 0.1013036105723586, 0.03600844866014086, 0.03513091098284349, 0.01639005684410222, 0.006061048179617501, 0.06286116986302659, 0.03174312187184114, 0.11143267955048941, 0.11419946546084248, 0.2972441562451422, 0.6805015658028424, 0.3888145223027095, 0.8359286037739366, 0.5870611954014748, 0.4939322004793212, 0.5019848886877298, 0.8972162869758904, 0.4193857521750033, 18.579785116016865, 34.238944351673126, 15.46950476244092, 29.97438758611679, 77.82000660896301, 78.9827062189579, 48.58998008072376, 25.050509199500084, 26.510134376585484, 42.48055770993233, 24.290789365768433, 2.252158150076866, 0.5424755159765482, 0.9107429080177099, 0.335211125202477, 0.11766334326239303, 0.13905579457059503, 0.1461509193177335, 0.21794091240735725, 0.24811417300952598, 0.18797811004333198, 0.1890497564454563, 0.05567662374232896, 0.1246914520743303, 0.09307798711233772, 0.09826149529544637, 0.0266881109928363, 0.06513215659651905, 0.11859234145958908, 0.08151444315444678, 0.07491209704312496, 0.03762881307920907, 0.03246409607527312, 0.021366210821724962, 0.04952591531036887, 0.0661614783166442, 0.04990595058188774, 0.05756838043453172, 0.07797065089107491, 0.012960544190718792, 0.041419239569222555, 0.039869475658633746, 0.0656102407083381, 0.052934788836864755, 0.03545068757375702, 0.03181392647093162, 0.07083982884068973, 0.0539849166671047, 0.08242531810537912, 0.01485883085479145, 0.023241109629452694, 0.05106603872263804, 0.01080030537195853, 0.048479535325895995, 0.053717550545115955, 0.06471805303590372, 0.08874908424331807, 0.04225042270263657, 0.07471844844985753, 0.03046359990548808, 0.03284832077042665, 0.024524750515411142, 0.011377283444744535, 0.03593910609197337, 0.04673646420997102, 0.07258673314936459, 0.02534170667786384, 0.0751585494435858, 0.03938589223253075, 0.04540706620900892, 0.04035651007143315, 0.010982728053932078, 0.0917538620706182, 0.04798387715709396, 0.07106888529960997, 0.14206826104782522, 0.09007576227304526, 0.304835406714119, 0.14168844470987096, 0.30569843540433794, 0.1972000816022046, 0.3219504898879677, 0.12843269272707403, 1.6700451797805727, 1.5351891098544002, 16.847860850393772, 59.78417940437794, 51.49283431470394, 60.77180340886116, 74.02223959565163, 79.71574008464813, 105.90933814644814, 38.65431122481823, 39.3261531740427, 70.69870233535767, 54.405081644654274, 7.054923260584474, 0.2138306907727383, 0.812082092743367, 0.1349620783003047, 0.31502545054536313, 0.4499762482009828, 0.8794295601546764, 3.030494134873152, 2.6567466650158167, 1.89812675351277, 0.5020360078196973, 0.963148211594671, 0.7794303854461759, 1.9908743142150342, 0.9634638915304095, 0.7833726739045233, 2.246371298097074, 1.9478595536202192, 0.5779840762261301, 0.1632356338086538, 0.029484983570000622, 0.07063755649141967, 0.015559361672785599, 0.04153453221078962, 0.04449243970157113, 0.0125309176837618, 0.026030657209048513, 0.03190598617948126, 0.03567844156350475, 0.04498115878959652, 0.06398329715011641, 0.05446123817819171, 0.06414251009118743, 0.006339779829431791, 0.08055893544224091, 0.12888761440990493, 0.046932008990552276, 0.016443563836219255, 0.07767126851831563, 0.03809261084825266, 0.11821664404124022, 1.0291338083334267, 0.6867743167094886, 0.15327492845244706, 0.31308164703659713, 1.5532211610116065, 0.47848297166638076, 0.28936177608557045, 0.22122561349533498, 0.1287790827336721, 0.1589440312818624, 0.038263238020590506, 0.007094461916494765, 0.016789731198514346, 0.07909142746939324, 0.03934281427063979, 0.05628332575724926, 0.06693337127217092, 0.05225878507189918, 0.04954665091645438, 0.040874232290661894, 0.023703408260189462, 0.037277929368428886, 0.026129717225558124, 0.04902393775410019, 0.008823876123642549, 0.04477841517655179, 0.035441900545265526, 0.054526257736142725, 0.057609090945334174, 0.01918712423503166, 0.18929717363789678, 0.9931269998196512, 0.5101949418894947, 0.8182601456064731, 0.8754017762839794, 0.4805537121137604, 0.41637429501861334, 0.5610108620021492, 0.5301828787196428, 12.956951335072517, 63.4599881619215, 42.993309795856476, 21.064618080854416, 47.72698558866978, 86.73489823937416, 66.80143386125565, 39.504306614398956, 34.32194709777832, 49.8560531437397, 46.57129280269146, 20.635362714529037, 0.5430525506380945, 1.2354839919134974, 0.32257065817248076, 0.20563913189107552, 0.10662256812793203, 0.0923894447623752, 0.1603273648652248, 0.2435656834859401, 0.18077519576763734, 0.16363752161851153, 0.11823513093986548, 0.13459262234391645, 0.014139371560304426, 0.03052046140510356, 0.05611058346403297, 0.09138154142419808, 0.1269032747950405, 0.10429414658574387, 0.05552663940761704, 0.023600208915013354, 0.029195902206993196, 0.0299450446254923, 0.0590694817219628, 0.05063464312115684, 0.02508731329726288, 0.029478018514055293, 0.06748843836248852, 0.026429383469803724, 0.00943085273320321, 0.0800819719734136, 0.04412042333569843, 0.04056902776937932, 0.049483995098853484, 0.04825600415642839, 0.1687247064546682, 0.17688904335955158, 0.13352238602237776, 0.18699866806855425, 0.1812779117608443, 0.11507934090332128, 0.15400606265757233, 0.12788627907866612, 0.17780945490812883, 0.1263891890994273, 0.21577290608547628, 0.2693203155649826, 0.12920103821670637, 0.15860332612646744, 0.12322670489083976, 0.1813919353298843, 0.10736743206507526, 0.21425525861559436, 0.07431716177961789, 0.2731720026349649, 0.21264334354782477, 0.1482405696879141, 0.15058324788697064, 0.1617374602938071, 0.13859818631317466, 0.11118341441033408, 0.20699237880762666, 0.13630713190650567, 0.20572842709952965, 0.2189468193682842, 0.20825315412366763, 0.31141214130911976, 0.22760811320040375, 0.37312816246412694, 0.25414108007680625, 0.35963965812698007, 0.5068328347988427, 1.8212455976754427, 1.3773445109836757, 23.434379920363426, 83.03837299346924, 77.06763178110123, 83.32326650619507, 85.9304130077362, 74.77070823311806, 147.63828098773956, 88.34451466798782, 35.57474747300148, 56.935783848166466, 94.06169548630714, 25.97800523042679, 0.24579880584497005, 1.6024688933975995, 0.3126286104088649, 0.5172703403513879, 1.6125049861148, 1.6018289839848876, 8.573863729834557, 8.115048799663782, 7.177761644124985, 9.747799336910248, 11.361675336956978, 10.932203382253647, 6.054323902353644, 6.802406385540962, 8.5419368930161, 11.911803167313337, 15.311738178133965, 6.690437318757176, 0.5798857554327697, 0.12581742368638515, 0.22757179249310866, 0.23417911841534078, 0.13250672724097967, 0.12212092711706646, 0.1446499998564832, 0.1318810967495665, 0.1874047119054012, 0.1292347168782726, 0.1315772466477938, 0.13289524154970422, 0.15772791841300204, 0.09482721434324048, 0.13497165200533345, 0.19064454274484888, 0.1803276065038517, 0.1875824117450975, 0.14270830404711887, 0.27102410851512104, 0.16093056765384972, 0.24407970980973914, 1.0868187504820526, 1.2506534904241562, 0.5897450388874859, 0.8734302164521068, 2.3041799711063504, 1.7521554487757385, 1.1070215539075434, 0.29738626268226653, 0.28978248476050794, 0.3100315388292074, 0.12339251552475616, 0.10202604680671357, 0.11943840465391986, 0.17639803845668212, 0.12172750721219927, 0.17049183428753167, 0.1711857720511034, 0.19505677395500243, 0.2518587978556752, 0.16464270127471536, 0.1633164833765477, 0.15534835547441617, 0.11589254922000691, 0.16743797081289813, 0.1347020297544077, 0.1191753133025486, 0.17470785649493337, 0.14141361258225515, 0.16010034189093858, 0.2677132986718789, 0.46282223076559603, 1.8964158953167498, 0.7147977536078542, 1.28946912009269, 2.15412222314626, 0.8083009987603873, 0.6570426933467388, 0.9493303124327213, 0.30304881976917386, 29.915323555469513, 50.79707644879818, 29.850187450647354, 46.615940406918526, 100.29551938176155, 104.11346331238747, 71.64004102349281, 43.59519749879837, 52.2192907333374, 71.84889301657677, 69.92166683077812, 25.71969699114561, 0.4038913414115086, 1.4399157534353435, 0.38412961119320244, 0.3338423080276698, 0.22100005997344851, 0.1903850879170932, 0.21442535886308178, 0.3897141240304336, 0.3158212109701708, 0.3143381327390671, 0.18111239798599854, 0.2503178914776072, 0.3954415745101869, 0.16480799240525812, 0.15117220144020393, 0.13498490676283836, 0.23354539851425216, 0.21075076307170093, 0.18636379041709006, 0.2248880677507259, 0.10524088953388855, 0.1535829939530231, 0.10427539251395501, 0.192814419278875, 0.18542644305853173, 0.13927006744779646, 0.2650575974257663, 0.1043377180758398, 0.23446532024536282, 0.19063204497797415, 0.11730555386748165, 0.2362978016026318, 0.12260554212843999, 0.10547570505877957], [0.05990912533889059, 0.03702952140884008, 0.05362828502256889, 0.009944814119080547, 0.013559871113102417, 0.07268261862918735, 0.03127699746983126, 0.05997258267598227, 0.050042015936924145, 0.05264480205369182, 0.03486327397695277, 0.04567074014630634, 0.09721069582155906, 0.01662865175603656, 0.06978147430345416, 0.03871649729262572, 0.027057151346525643, 0.06593281519599259, 0.021112242320668884, 0.04453882764209993, 0.03456189151620492, 0.04229236517858226, 0.10060352040454745, 0.029817643844580743, 0.08401839004363865, 0.0539038036367856, 0.037165776011534035, 0.01709459062112728, 0.03740709275007248, 0.07084562501404434, 0.01785592652595369, 0.10404655869933777, 0.23882493318524212, 0.10451480193296447, 0.12280526148970239, 0.08399015132454224, 0.30406758072786033, 0.18098056287271902, 0.5803421465680003, 0.9332476754207164, 9.690448064357042, 29.735188521444798, 34.52876999974251, 35.16042910516262, 24.8751600086689, 32.527918964624405, 92.55797177553177, 98.13326820731163, 32.21770741045475, 19.67017650604248, 44.28049832582474, 37.42492899298668, 7.957063727080822, 0.2272465091664344, 0.6192860787268728, 0.061737435826216824, 0.8790219132788479, 0.9221985808108002, 0.451075547025539, 0.4309289687080309, 1.2739761639386415, 0.9308610472362489, 0.05759858584497124, 0.30479963519610465, 0.22712355013936758, 0.021561568210017867, 0.25300250679720193, 0.6082425056956708, 0.17058819474186748, 0.06604875350603834, 0.04886151131358929, 0.039462337153963745, 0.06395010830601677, 0.09595691895810887, 0.046089285460766405, 0.16575972258578986, 0.08286060998216271, 0.13885001186281443, 0.015588611568091437, 0.07244963620905764, 0.07974571228260174, 0.04386971842905041, 0.037553588990704156, 0.10604943716316484, 0.02829665485478472, 0.046364681620616466, 0.046628567070001736, 0.06040166648745071, 0.023452389796148054, 0.029472216774593107, 0.04884079797193408, 0.12855827895691618, 0.05865447274118196, 0.07883340498665348, 0.074047925445484, 0.10173303206101991, 0.13409930194029585, 0.09826286826864816, 0.05783996937680058, 0.042574941617203876, 0.026780437874549534, 0.07395319771603681, 0.06883501337142661, 0.07752386314678006, 0.1172216614941135, 0.023424592654919252, 0.02838396110746544, 0.06009374941640999, 0.07882180521846749, 0.024323511606780812, 0.0878516941156704, 0.12163295017671771, 0.02873222874768544, 0.017891928109747823, 0.09310653011198156, 0.049373830697732046, 0.10335846163798124, 0.05929829698288813, 0.055394455484929495, 0.03520101796311792, 0.18280268384842202, 0.2833042776910588, 0.38970275432802737, 0.9944768773857504, 0.24646532867336646, 0.5148584791459143, 0.3608666657237336, 0.4238907666876912, 8.131731804460287, 38.3130819350481, 31.44696816802025, 21.51794135570526, 62.12824322283268, 99.13873225450516, 69.67809230089188, 36.63231052458286, 25.46330764889717, 33.782520443201065, 45.61175309121609, 49.637758657336235, 9.049658998847008, 0.1562494711834006, 1.555965207517147, 0.3305121429730207, 0.540507280966267, 0.13586791406851262, 0.12727614463074133, 0.18575013818917796, 0.3618058981373906, 0.1347811278537847, 0.09446871248655953, 0.07189068768639117, 0.1422149984864518, 0.16534593072719872, 0.0567844053148292, 0.05805274311569519, 0.10010377300204709, 0.044220732015674, 0.049310826070723124, 0.025181577184412163, 0.03855804134218488, 0.061041546214255504, 0.02737121711106738, 0.03243773870053701, 0.07934506385936402, 0.024071645239018835, 0.03944924937968608, 0.03863241938233841, 0.04847155352763366, 0.06742989033227786, 0.044793295237468556, 0.011672195305436617, 0.03109716395556461, 0.007734565215287148, 0.015989905659807846, 0.022535364296345506, 0.05539431447687093, 0.022411895042750984, 0.021577175575657748, 0.039528221313958056, 0.034177959969383664, 0.036570770243997686, 0.09566537366481498, 0.0881266820942983, 0.09522988882963546, 0.04448027961188927, 0.048385835470980965, 0.05025349462812301, 0.0785509287379682, 0.02077330162137514, 0.039485128509113565, 0.03844389531877823, 0.032547083028475754, 0.03686383322929032, 0.05085426317236852, 0.04898798440990504, 0.03272340247349348, 0.01371482505419408, 0.05629702951409854, 0.04339568273280747, 0.08968661713879555, 0.04492780950386077, 0.01921421633596765, 0.03872818240779452, 0.018145334433938842, 0.12916471750941128, 0.07687728924793191, 0.17876504425657913, 0.27102568186819553, 0.11224792877328582, 0.16916653665248305, 0.1745618908898905, 0.2803067135391757, 0.39639321563299745, 1.7345188139006495, 1.763548543676734, 9.674061443656683, 50.19226290285587, 60.80234996974468, 48.67347680032253, 44.80957053601742, 84.79131773114204, 99.64509308338165, 48.248990178108215, 34.09937024116516, 60.64780466258526, 78.64711582660675, 24.339240565896034, 3.5338279511779547, 0.08882069407263771, 0.5931956099811941, 0.05575950308411848, 0.390221337438561, 0.5451706401072443, 2.0531383669003844, 0.9781498659867793, 1.1560402298346162, 0.3610160748939961, 0.26105783705133945, 0.1215666467032861, 0.6735745375044644, 0.3958990046521649, 0.2676532737677917, 0.3544702136423439, 0.14109258918324485, 0.09865429921774194, 0.04436853814695496, 0.04842555892537348, 0.04531790458713658, 0.07497429643990472, 0.007876382678659866, 0.11669486280879937, 0.013303424766490934, 0.017420818330720067, 0.043837687335326336, 0.06837387991254218, 0.033959174834308214, 0.04527478580712341, 0.11225581038161181, 0.09611556044546887, 0.09068072395166382, 0.07038056559395045, 0.04836431318835821, 0.03264831939304713, 0.0586239890253637, 0.07835270851501264, 0.17321612482191995, 0.15831587748834863, 0.11088976883911528, 0.045824769185855985, 0.0315517331182491, 0.13691636093426496, 0.13542053260607645, 0.06051322241546586, 0.0324877817183733, 0.01937375211127801, 0.04212671781715471, 0.04002695939561818, 0.06293500613537617, 0.12432071220246144, 0.12249697334482335, 0.1979179313639179, 0.0523169212101493, 0.0895524219959043, 0.017508230339444708, 0.1112667575944215, 0.2009851683396846, 0.11071792454458773, 0.130808470712509, 0.045722909417236224, 0.13064433733234182, 0.06350818162900396, 0.12991767085622996, 0.0847280836023856, 0.16093775164335966, 0.14430926501518115, 0.23489788844017312, 0.3062560851685703, 0.5682495923247188, 0.28711965889669955, 0.2901648392435163, 0.8673606358934194, 0.7032133627217263, 0.3930067957844585, 6.304843984544277, 39.34248089790344, 57.043238282203674, 29.578370936214924, 28.21266531944275, 73.40114772319794, 83.41628551483154, 59.55292381346226, 44.181855618953705, 41.73648543655872, 51.72919303178787, 65.46522036194801, 30.339709483087063, 0.2743158006342128, 1.5371019509620965, 0.49740251270122826, 0.6088096846360713, 0.11529371768119745, 0.13898008066462353, 0.17650253284955397, 0.4029622912639752, 0.10181191493757069, 0.09781784683582373, 0.13973990629892796, 0.10199335520155728, 0.10078579187393188, 0.10646236813045107, 0.07637286631506868, 0.05194522025703918, 0.055669944413239136, 0.08636135768028907, 0.034665220737224445, 0.03359755966812372, 0.05192710814299062, 0.09371264211949892, 0.018448603805154562, 0.02155879257770721, 0.06158689117000904, 0.043738284075516276, 0.05523294188606087, 0.08336562663316727, 0.0363848808046896, 0.04991101202904247, 0.0570646180131007, 0.02795231503114337, 0.0604758998088073, 0.0866651780961547, 0.07081594652845524, 0.274847712717019, 0.12239228599355556, 0.22229580528801307, 0.10075036174384877, 0.16719695093343034, 0.11715272339642979, 0.1319011941086501, 0.15365193947218359, 0.14674184698378667, 0.12762505793944, 0.12650898657739162, 0.11873155352077447, 0.20246211643097922, 0.16261681623291224, 0.0985007562849205, 0.16078878776170313, 0.07747377560008317, 0.1088718841492664, 0.09576427226420492, 0.19779727299464867, 0.09758792206412181, 0.10436429438414052, 0.18779402773361653, 0.10550136852543801, 0.22920600167708471, 0.2003834053175524, 0.08849438658216968, 0.10940873151412234, 0.25163505517411977, 0.23643916589207947, 0.19322935404488817, 0.27127988229040056, 0.4288069606991485, 0.31050093239173293, 0.14816389098996297, 0.2437703826581128, 0.4779185832012445, 0.3714860271429643, 1.7456127936020494, 1.2806355440989137, 11.055160984396935, 73.05795013904572, 89.29356694221497, 79.52679142355919, 57.24999658763409, 71.35591506958008, 130.76729267835617, 136.94791942834854, 50.796643272042274, 39.81095016002655, 88.12275856733322, 64.7556160390377, 15.685148891061544, 0.24170226941350847, 0.7462465285789222, 0.15818632818991318, 0.5327229830436409, 1.8727185856550932, 2.507360768504441, 0.7307240052614361, 4.912011623382568, 5.8387590944767, 1.0297071025706828, 0.4491191863780841, 1.0760749457404017, 0.5975459609180689, 0.3898176387883723, 1.0152905574068427, 0.3974063362693414, 0.16507764434209093, 0.3281274443725124, 0.12621177127584815, 0.15042904444271699, 0.13193830149248242, 0.21208339312579483, 0.31278398644644767, 0.18354646424995735, 0.21529828780330718, 0.16524173319339752, 0.2096589599386789, 0.20676765649113804, 0.19823187467409298, 0.1594293216476217, 0.16675617458531633, 0.2238701528403908, 0.22337920730933547, 0.12302349743549712, 0.12653111742110923, 0.11071474815253168, 0.1546686521032825, 0.4607870540348813, 0.3360738867195323, 0.3522151830838993, 0.21760403673397377, 0.3509451309219003, 0.34983333433046937, 0.39823020924814045, 0.18720085878157988, 0.1986714339000173, 0.10721274622483179, 0.11100394825916737, 0.11762852911488153, 0.14463923871517181, 0.26916119910310954, 0.2761391387321055, 0.2600514848018065, 0.08363009095774032, 0.17043391708284616, 0.23792539082933217, 0.08791128115262836, 0.16346325050108135, 0.2965997939463705, 0.20723333931528032, 0.17229362041689456, 0.23781283671269193, 0.15607615001499653, 0.1976053387625143, 0.2013191199512221, 0.2921460766810924, 0.32302170584443957, 0.23665896034799516, 0.6354845501482487, 1.6856622230261564, 1.2050704238936305, 0.40510513877961785, 1.558011278975755, 0.8579874888528138, 0.30458087974693626, 12.58403079584241, 54.53811630606651, 45.6142533570528, 36.98076702654362, 84.70525234937668, 120.01483485102654, 91.63904428482056, 54.276146963238716, 46.34321764111519, 59.9281270802021, 73.92440244555473, 88.22188764810562, 35.93787878751755, 0.2428490953752771, 1.8603419372811913, 0.42529556318186224, 0.7233883207663894, 0.16243996244156733, 0.2377235415042378, 0.2679730800446123, 0.5223233567085117, 0.17414952395483851, 0.21869367279578, 0.20273813599487767, 0.21703313221223652, 0.21894854115089402, 0.22616614995058626, 0.14375529630342498, 0.13211922225309536, 0.175363662710879, 0.14487276290310547, 0.15063778089825064, 0.23587295174365863, 0.1910653107916005, 0.14111859403783455, 0.10803392520756461, 0.17613335890928283, 0.07459269894752651, 0.13793978258036077, 0.16023867821786553, 0.19133208319544792, 0.161664180632215, 0.14176329772453755, 0.22587089391890913, 0.300661597866565, 0.12137034864281304, 0.13015232310863212, 0.1807218205067329], [0.04603929439326748, 0.021860060005565174, 0.030689066225022543, 0.0467607027530903, 0.02295935140864458, 0.04719202042906545, 0.023179873169283383, 0.007356742007686989, 0.06449376858654432, 0.047542299289489165, 0.1066136104054749, 0.057490421531838365, 0.031720085607958026, 0.08430555666564032, 0.05505268905835692, 0.031624192706658505, 0.05157558618520852, 0.05284540085995104, 0.03763003020139877, 0.02983553145895712, 0.04821085931325797, 0.01542531495942967, 0.04985448635125067, 0.03738901774340775, 0.06586777337361127, 0.09731026235385798, 0.038155927177285776, 0.05179950698220637, 0.09346893566544168, 0.03210393922927324, 0.12252051426912658, 0.09730655161547475, 0.1165613578632474, 0.3532323706895113, 0.4133476089918986, 0.19778269721427932, 0.21172423817915842, 0.28619034157600254, 0.4182159493211657, 1.145995231345296, 2.4514111457392573, 11.037206947803497, 22.277963273227215, 40.56107930839062, 39.737104922533035, 26.750878058373928, 27.53197554498911, 85.71684926748276, 118.39299827814102, 69.26893025636673, 30.495263636112213, 42.20467731356621, 59.47793863713741, 43.79112258553505, 8.802140280604362, 0.23484504752559587, 0.3495862288400531, 0.6001380155794322, 0.46403213927987963, 1.078843215946108, 0.37298483890481293, 0.5221926199737936, 0.2663837559521198, 0.10162221456994303, 0.2918282593600452, 0.05784142769698519, 0.030672957909700926, 0.12120105733629316, 0.11996223474852741, 0.07017963653197512, 0.07975172367878258, 0.09296588570578024, 0.05061300580564421, 0.04393250041175634, 0.08993536277557723, 0.04387007837067358, 0.0317508995794924, 0.032700032243155874, 0.058148981115664355, 0.040414089598925784, 0.0893190610804595, 0.06661513834842481, 0.06339049185044132, 0.01350327493128134, 0.028801936823583674, 0.01938727404194651, 0.0667419565434102, 0.03592097542423289, 0.040237065113615245, 0.054878644295968115, 0.15362946724053472, 0.3188757720636204, 0.036114883769187145, 0.04716276867839042, 0.021349857597670052, 0.03550046341842972, 0.05004336664569564, 0.02694649712793762, 0.05290426059218589, 0.023595106649736408, 0.09951582876965404, 0.020601271789928433, 0.04735125934530515, 0.04882857851043809, 0.04134913258894812, 0.0377001371816732, 0.11405571887735277, 0.25740543147549033, 0.839494118699804, 0.3576353844255209, 0.1392417767783627, 0.0521310800104402, 0.07220554383820854, 0.13033018622081727, 0.009170396933768643, 0.06611863413127139, 0.06390109687345102, 0.05530393202207051, 0.20589612278854474, 0.2404458579258062, 0.06903069544932805, 0.5044039338827133, 1.3227388286031783, 0.18525675841374323, 0.5887553107459098, 0.7327323162462562, 8.867673464119434, 39.79112662374973, 57.47662402689457, 34.2093363404274, 41.32746018469334, 97.79703944921494, 95.67548409104347, 61.166351437568665, 29.27399206906557, 24.556577503681183, 35.55993586778641, 53.059087470173836, 42.932425662875175, 11.675679087638855, 0.4361191933276132, 1.6273662261664867, 0.4318473319290206, 0.34935271949507296, 0.24373416585149243, 0.2163761979318224, 0.22181946522323415, 0.19057108496781439, 0.02405675590125611, 0.16940783854806796, 0.08784381992882118, 0.10193376074312255, 0.12440666032489389, 0.07302376165171154, 0.054061591654317454, 0.07939437957247719, 0.12985840294277295, 0.07633665692992508, 0.009859531146503286, 0.028334242779237684, 0.08272340171970427, 0.07473090168787166, 0.11067329920479096, 0.07691790699027479, 0.12473669339669868, 0.059417808733996935, 0.031117146281758323, 0.0816178391687572, 0.036630535396398045, 0.02085516978695523, 0.0406869513244601, 0.03755904377612751, 0.05742478599131573, 0.0261618800504948, 0.012795299444405828, 0.039517627155873924, 0.021330248200683855, 0.017135904126917012, 0.06928516304469667, 0.04119855824683327, 0.07417561195325106, 0.06214015855221078, 0.018441122956573963, 0.0019465909690552508, 0.03238201083149761, 0.022179326369951013, 0.0767288077622652, 0.03680926311062649, 0.04064673063112423, 0.028677037080342416, 0.010881200396397617, 0.06290436285780743, 0.05384843942010775, 0.01792893344827462, 0.06934734017704614, 0.03988163203757722, 0.04827145938179456, 0.017656528143561445, 0.04472026790608652, 0.047509077048744075, 0.029048428186797537, 0.1429330708924681, 0.030647385356132872, 0.049490218007122166, 0.10127814006409608, 0.06979743047850206, 0.12638288084417582, 0.15390533837489784, 0.18784433050313964, 0.41771360440179706, 0.2846871659858152, 0.23202798853162676, 0.17806806368753314, 0.18966802483191714, 0.6630586611572653, 1.8568024272099137, 4.985988428816199, 6.575682051479816, 61.52693688869476, 68.25085088610649, 51.61558672785759, 42.45303958654404, 74.62061628699303, 115.93084439635277, 75.78371867537498, 33.1351225823164, 46.472828686237335, 78.13944026827812, 63.59232746064663, 15.862070247530937, 2.4095613788813353, 0.14228294952772558, 0.9608579438645393, 0.39241663995198905, 0.24824931810144335, 0.8751015923917294, 0.2377746457932517, 0.15954846603563055, 0.2246354109956883, 0.12116435071220621, 0.5236176028847694, 0.10666078131180257, 0.13674554822500795, 0.24992395949084312, 0.10487938197911717, 0.020798256337002385, 0.023924603519844823, 0.08320745269884355, 0.05429073717095889, 0.08319631306221709, 0.02562010668043513, 0.03795617070863955, 0.01596550198883051, 0.061372061682050116, 0.01009796649668715, 0.061449556742445566, 0.04423112579388544, 0.022946679237065837, 0.09794660945772193, 0.03544827188306954, 0.04645398053980898, 0.03216484357835725, 0.06296426159678958, 0.033621939219301566, 0.03207198235031683, 0.08896712723071687, 0.18719115148996934, 0.13472698075929657, 0.04839628119952977, 0.0313298829132691, 0.011272082156210672, 0.054324478915077634, 0.012716526034637354, 0.07200573541922495, 0.05875950890185777, 0.07280165911652148, 0.1017484835756477, 0.03341014882607851, 0.05480326435645111, 0.07263229359523393, 0.05477615741256159, 0.13581722538219765, 0.07882138961576857, 0.28527883579954505, 1.0523842857219279, 1.3357389997690916, 0.2768003923119977, 0.12446549037122168, 0.036852879129583016, 0.1169725447834935, 0.08907309107598849, 0.08386841684114188, 0.13529898365959525, 0.22149624506710097, 0.1604480529204011, 0.055337376907118596, 0.16303123149555176, 0.3323218849254772, 1.7059865011833608, 0.1926534771337174, 0.48179882811382413, 0.6099743221420795, 8.152607884258032, 30.2129577845335, 61.90508879721165, 57.81898945569992, 34.1300193965435, 55.73157526552677, 90.8197170495987, 91.73394039273262, 54.63508330285549, 40.99933259189129, 40.306067392230034, 56.871331706643105, 67.34385475516319, 37.019756734371185, 0.8379746158607304, 2.594673908315599, 0.5042641726322472, 0.3075893979985267, 0.28366736602038145, 0.19859992054989561, 0.20048274920554832, 0.18527715263189748, 0.07800504201441072, 0.2081681930576451, 0.1995264770812355, 0.0694813794689253, 0.044068658535252325, 0.1006722507008817, 0.0584379919746425, 0.06997636228334159, 0.034798169072018936, 0.10187073014094494, 0.027054537131334655, 0.026123466486751568, 0.07473050092812628, 0.05910095620492939, 0.023100773214537185, 0.030059838172746822, 0.12230463835294358, 0.06756058253813535, 0.006273936023717397, 0.10987013956764713, 0.020017648712382652, 0.0175156685145339, 0.057996536561404355, 0.024750619450060185, 0.0426191995939007, 0.013557191032305127, 0.012374696525512263, 0.0045859730835218215, 0.1922425944940187, 0.13079637370537966, 0.15783762268256396, 0.10507478946237825, 0.15067856933455914, 0.13939177966676652, 0.08305405077408068, 0.05666545017447788, 0.12362302659312263, 0.14776952855754644, 0.29486643383279443, 0.09721056965645403, 0.22223613661481068, 0.1825194209231995, 0.18471599993063137, 0.13255425437819213, 0.16075631137937307, 0.2747224975610152, 0.1038057985715568, 0.16075246705440804, 0.1031045729178004, 0.147520998143591, 0.10900967128691263, 0.17531531921122223, 0.15639196353731677, 0.29518092633225024, 0.13103942706948146, 0.183182381442748, 0.1650452718604356, 0.1129972975468263, 0.2807816880522296, 0.2504228608449921, 0.23830440564779565, 0.537744591711089, 0.5384555691853166, 0.28082336706575006, 0.2733470901148394, 0.2585032460046932, 0.6274710176512599, 1.995418039150536, 3.5614688554778695, 6.418419415131211, 85.13337537646294, 106.34810820221901, 82.9333770275116, 55.978869795799255, 63.931250274181366, 122.40206435322762, 150.7504963874817, 93.80429729819298, 48.58421579003334, 71.94769531488419, 87.78835371136665, 55.945435389876366, 12.642640750855207, 0.3653220453998074, 1.238085546065122, 0.5476315424311906, 0.6200778612401336, 2.9718905920162797, 1.1903951363638043, 1.9655994954518974, 0.46110638533718884, 0.5070044787134975, 0.49623707367572933, 0.11264528206083924, 0.34666172170545906, 0.39774733828380704, 0.6548037228640169, 0.19025763147510588, 0.1499670575140044, 0.21460607182234526, 0.11778408326790668, 0.24580552970292047, 0.10334234961192124, 0.09161315829260275, 0.0567522257915698, 0.1395558239892125, 0.14233660680474713, 0.12798694398952648, 0.14400453917915002, 0.14665589143987745, 0.1871131666121073, 0.09108001424465328, 0.11168769633513875, 0.19642631843453273, 0.18063530093058944, 0.1818899906356819, 0.15322453662520275, 0.0828400970203802, 0.33527236722875386, 0.5341099679935724, 0.14092115306993946, 0.11435565786086954, 0.04926087582134642, 0.09567690663971007, 0.12680234271101654, 0.11227089824387804, 0.18173724180087447, 0.1703169842949137, 0.3047821798827499, 0.08143167142407037, 0.12235833273734897, 0.15906277491012588, 0.14011577441124246, 0.18042929557850584, 0.32844686473254114, 0.42032753757666796, 1.587344636209309, 0.761827117530629, 0.2183990104822442, 0.16078592307167128, 0.1937217838712968, 0.2412303673918359, 0.12872162566054612, 0.25717189244460315, 0.2664805023232475, 0.2763526397757232, 0.1460493341437541, 0.5120161129161716, 0.20969532517483458, 1.035866690799594, 2.408980722539127, 0.1383916020859033, 0.9399560373276472, 0.4859052796382457, 10.675252620130777, 51.789700984954834, 75.82293257117271, 52.97640010714531, 59.389308393001556, 117.48277992010117, 114.29912075400352, 85.40280371904373, 46.577532067894936, 47.0060008764267, 58.76128189265728, 76.80397912859917, 85.54858669638634, 33.06742921471596, 0.2671194024151191, 3.162419255822897, 0.32863931846804917, 0.4655595088843256, 0.23691430367762223, 0.28870084905065596, 0.2451398826087825, 0.30572871502954513, 0.24838268203893676, 0.3047733334824443, 0.25774836307391524, 0.1578220969531685, 0.16150533134350553, 0.18113488506060094, 0.14827830047579482, 0.12417682461091317, 0.2497289824532345, 0.23564879345940426, 0.07206337060779333, 0.12281628238270059, 0.18061943381326273, 0.24183508416172117, 0.13335112802451476, 0.15703945769928396, 0.18086000840412453, 0.10037364016170613, 0.10632823235937394, 0.1894736711983569, 0.1426115576759912, 0.1773158079595305, 0.12703692074865103, 0.1798218477051705, 0.1780408268678002, 0.08791044994723052, 0.07451234661857598, 0.13784440176095814], [0.059200203613727354, 0.018196470264228992, 0.022343331729643978, 0.05608191801002249, 0.0320309341623215, 0.08563096562284045, 0.04366209148429334, 0.06611838180106133, 0.033520929209771566, 0.05126609205035493, 0.025751106877578422, 0.04939290018228348, 0.02929996800958179, 0.06472043532994576, 0.045548007474280894, 0.03332792257424444, 0.004224028125463519, 0.10722056846134365, 0.06296399442362599, 0.06008140007907059, 0.04617781625711359, 0.06013440797687508, 0.05100652590044774, 0.025189774205500726, 0.04939455888234079, 0.031405752670252696, 0.0378425998496823, 0.05375300293962937, 0.05148631695192307, 0.0288455751069705, 0.06544241143274121, 0.09247945985407569, 0.21256096515571699, 0.30187972937710583, 0.33706981921568513, 0.3153680555988103, 0.2680746355326846, 0.312429002369754, 0.19937448523705825, 0.6203286477830261, 0.9831975982524455, 3.6755620082840323, 2.7666579047217965, 12.838942017406225, 30.428782403469086, 53.83003570139408, 34.32033598423004, 36.57928816974163, 68.53556200861931, 117.23466083407402, 127.45629474520683, 80.23350030183792, 48.67624685168266, 58.22213642299175, 67.09942907094955, 45.004678666591644, 8.986811321228743, 0.23380108323181048, 0.5999455915298313, 0.6653697683941573, 1.560093923471868, 0.7342788332607597, 0.3134410543134436, 0.2984990389086306, 0.10516517562791705, 0.12403095548506826, 0.34247033880092204, 0.33137374673970044, 0.1849332413985394, 0.011597356206038967, 0.07066160207614303, 0.07558426761534065, 0.013955933063698467, 0.0441302122635534, 0.048900362744461745, 0.17957305011805147, 0.06187460327055305, 0.10369106996222399, 0.07876243340433575, 0.15977370785549283, 0.1201573305297643, 0.1147921074880287, 0.06325829308480024, 0.11511886026710272, 0.049357429234078154, 0.0856402053614147, 0.046484876147587784, 0.03413637001358438, 0.10998223355272785, 0.05994779865432065, 0.06800970804761164, 0.2510358748259023, 0.04910958159598522, 0.03207272449799348, 0.02109804132487625, 0.041623003635322675, 0.08971160525106825, 0.016310489336319733, 0.0605700041342061, 0.02399825239990605, 0.13024886167841032, 0.059647473754012026, 0.10521563424845226, 0.08709268484381028, 0.07956600122270174, 0.13003844796912745, 0.015399376898130868, 0.21706831001210958, 0.45731974008958787, 3.427373575977981, 0.5926291435025632, 0.03993353784608189, 0.03843182428681757, 0.06430606459616683, 0.05431733574368991, 0.07968936843099073, 0.14489841152681038, 0.24007429427001625, 0.1486666515120305, 0.05817292279971298, 0.40033309953287244, 0.49424013239331543, 1.5798819554038346, 0.12090524469385855, 2.8981529362499714, 19.894959144294262, 41.3409798592329, 66.46247684955597, 45.006042793393135, 64.29296046495438, 98.45105275511742, 76.82954415678978, 38.56077164411545, 17.602325566112995, 33.72815676033497, 48.00674557685852, 62.630101293325424, 56.03217713534832, 5.092275850474834, 0.7401518931146711, 1.4387689274735749, 0.18931939353933558, 0.6080209300853312, 0.12701091589406133, 0.24056411173660308, 0.09503780616796575, 0.1065789521089755, 0.09885346196824685, 0.06975527649046853, 0.1337343582417816, 0.09154795319773257, 0.07366235746303573, 0.12014651743811555, 0.12059663000400178, 0.0914783397456631, 0.10238290851702914, 0.04920635765301995, 0.07775990321533754, 0.02200160797656281, 0.0333826411224436, 0.038576787992496975, 0.021680857316823676, 0.03037472029973287, 0.08544398151570931, 0.029139391372154932, 0.042150900699198246, 0.01739503612043336, 0.05911048167035915, 0.043037689247285016, 0.08320752691361122, 0.014344335122586926, 0.07150111210648902, 0.04096540513273794, 0.02190080391301308, 0.03883832825522404, 0.11476037325337529, 0.020335542103566695, 0.02492754745617276, 0.028896517978864722, 0.04237310713506304, 0.042442969206604175, 0.07172873622039333, 0.021586827206192538, 0.04470165113161784, 0.04073897587659303, 0.0264510115084704, 0.06280709698330611, 0.01925585267599672, 0.07917275201180018, 0.10218692215858027, 0.027876042659045197, 0.0775990798138082, 0.09739058499690145, 0.0695047051704023, 0.08960815728642046, 0.05968545316136442, 0.020866515369561967, 0.037754425284219906, 0.04296154118492268, 0.07437400287017226, 0.08844121912261471, 0.12532708671642467, 0.08899918801034801, 0.0820989215571899, 0.06962177154491656, 0.06954919692361727, 0.005403933464549482, 0.08655545156216249, 0.17852331191534176, 0.2424055285518989, 0.38636965036857873, 0.17738757363986224, 0.33728899026755244, 0.38315261830575764, 0.2314820498577319, 0.7482912938576192, 2.1673096530139446, 4.496394200250506, 8.700050208717585, 48.644537553191185, 60.683097168803215, 58.6652572453022, 46.62653423845768, 73.40682461857796, 110.61701193451881, 104.69705879688263, 70.0148606300354, 56.267380714416504, 68.68671029806137, 89.82584998011589, 63.574039041996, 17.98594158142805, 1.1656488454900682, 0.31367803690955043, 1.2483447580598295, 0.6047756073530763, 1.1558091547340155, 0.6166328710969537, 0.41745174501556903, 0.3664912545355037, 0.11003241015714593, 0.13662192126503214, 0.04788137914147228, 0.17322508996585384, 0.13541846943553537, 0.04137444353546016, 0.07092243729857728, 0.03833208334981464, 0.08264878619229421, 0.04682423430494964, 0.06302011563093401, 0.04031658623716794, 0.008619467316748342, 0.052917563589289784, 0.050925398027175106, 0.09931684413459152, 0.05893094130442478, 0.1064029814733658, 0.06528362893732265, 0.09039573182235472, 0.16757468925788999, 0.052746060682693496, 0.026752464473247528, 0.027858077119162772, 0.06402387036359869, 0.11926146922633052, 0.5095797905232757, 1.223205307032913, 0.033222604397451505, 0.06237462526769377, 0.014247577619244112, 0.018714925354288425, 0.03405120856768917, 0.031742416831548326, 0.032911611124291085, 0.028102559117542114, 0.06280831410549581, 0.07163512171246111, 0.05967296652670484, 0.0255505748646101, 0.16558039002120495, 0.07177676059654914, 0.01747485039231833, 0.07810591472662054, 0.14531686407281086, 0.42632619850337505, 0.9057888644747436, 0.05740101871197112, 0.10205043377936818, 0.02432447454339126, 0.029965082612761762, 0.023879907676018775, 0.05984574221656658, 0.3006630524760112, 0.23369231406832114, 0.08695576601894572, 0.5048934544902295, 1.2679537246003747, 1.432889336720109, 0.2946283231722191, 3.979030824266374, 24.25562985241413, 48.09949479997158, 86.19219616055489, 61.752336993813515, 48.85908544063568, 82.27218970656395, 95.39140373468399, 68.19404393434525, 40.98097197711468, 41.924780532717705, 42.18152515590191, 64.83524456620216, 72.88479343056679, 24.301544688642025, 0.5558210529852659, 1.6889982065185905, 0.3716470138169825, 0.5251372838392854, 0.08035002829274163, 0.13342477875994518, 0.21694984839996323, 0.1534434998757206, 0.16397996339946985, 0.14172957453411072, 0.08499388379277661, 0.10785140140797012, 0.03114622362772934, 0.02956653817818733, 0.01978070507902885, 0.10633659636368975, 0.08243723699706607, 0.061478645220631734, 0.04890075608273037, 0.03123123293335084, 0.039078657937352546, 0.002362222658121027, 0.072526975418441, 0.03416621548240073, 0.04159580021223519, 0.0363198352715699, 0.03965963711380027, 0.03214607095287647, 0.07860422978410497, 0.08230886029195972, 0.05073885549791157, 0.018613115680636838, 0.06400672675226815, 0.055260534936678596, 0.0391373840830056, 0.05483402266690973, 0.026490204327274114, 0.1916469616116956, 0.07157243991969153, 0.11744344490580261, 0.1788407433195971, 0.10699095539166592, 0.15278350794687867, 0.1390774207538925, 0.16560887364903465, 0.12228965439135209, 0.13015236763749272, 0.18880775693105534, 0.07766507158521563, 0.18067971104755998, 0.1866829881328158, 0.10577059001661837, 0.17569742136402056, 0.19924555934267119, 0.1879113761242479, 0.18719944870099425, 0.12416863130056299, 0.14885451877489686, 0.13417366513749585, 0.12661514338105917, 0.23629048402654007, 0.14591009239666164, 0.18937882472528145, 0.14938185922801495, 0.14236978080589324, 0.123114707384957, 0.13817473169183359, 0.15624711115378886, 0.2591314888559282, 0.3040378651348874, 0.36076380405575037, 0.4508667957270518, 0.3649076004512608, 0.5554755090270191, 0.3183476300910115, 0.44860149384476244, 0.5879131809342653, 1.768410145305097, 3.480621068738401, 9.432706944644451, 58.21208596229553, 92.98227220773697, 101.708063185215, 68.43729168176651, 67.69808694720268, 107.80501082539558, 142.0086246728897, 154.42828863859177, 94.28129330277443, 71.60473331809044, 86.52632743120193, 95.66723853349686, 61.501067876815796, 13.11415459960699, 0.3272043610922992, 1.6351283784024417, 1.5773024875670671, 3.362187361344695, 1.9670758349820971, 0.40671913186088204, 0.42501826712395996, 0.23270171019248664, 0.2508290234254673, 0.45189930126070976, 0.5160380783490837, 0.39914406021125615, 0.09541767445625737, 0.11487894618767314, 0.19530920806573704, 0.20741043059388176, 0.2193176408763975, 0.21394901879830286, 0.22356925648637116, 0.18803492886945605, 0.14487541979178786, 0.21088711044285446, 0.23850720492191613, 0.3355966560775414, 0.295527835842222, 0.16126079368405044, 0.22532557864906266, 0.2967692707898095, 0.1407254338846542, 0.19717616960406303, 0.1894988151616417, 0.24167069845134392, 0.22081781818997115, 0.6654887495096773, 1.5760854841209948, 0.1917564877658151, 0.12110858573578298, 0.12088315095752478, 0.13797500490909442, 0.22579216689337045, 0.08886822120985016, 0.12926968687679619, 0.13819000509101897, 0.21972169575747102, 0.1663099360303022, 0.1627584476955235, 0.13473486236762255, 0.16966757539194077, 0.24790598574327305, 0.3097206976963207, 0.3506600868422538, 0.9023761132266372, 5.13173958286643, 2.04201256390661, 0.14439440419664606, 0.1512229346553795, 0.12680212006671354, 0.19740611664019525, 0.1301158094429411, 0.3359441296197474, 0.29896709660533816, 0.3837164130527526, 0.0860070415365044, 0.9446337644476444, 1.1754843802191317, 1.0719775781035423, 0.2969479205785319, 3.989767860621214, 29.84706971794367, 49.01723675429821, 81.23450338840485, 64.41235765814781, 83.10557618737221, 116.92000731825829, 97.41582110524178, 56.91945992410183, 37.63851933181286, 61.42968110740185, 65.72789266705513, 90.0555020570755, 84.42319348454475, 19.317285642027855, 0.45866908330935985, 1.656519330572337, 0.2794667211128399, 0.6593688810244203, 0.18137654318707064, 0.2282903844024986, 0.2419031539466232, 0.21059118647826836, 0.24220995779614896, 0.3170252713607624, 0.2972982736537233, 0.2093689434695989, 0.1724620137247257, 0.19325142551679164, 0.2593956340570003, 0.17596949270227924, 0.21846270159585401, 0.11758950699004345, 0.1477915109717287, 0.10764541089884005, 0.1768994631129317, 0.0838888407452032, 0.1553966396022588, 0.19109428423689678, 0.17805779236368835, 0.14676859398605302, 0.15788886055815965, 0.0647287251194939, 0.13128055084962398, 0.1419056416489184, 0.1361529136192985, 0.13206287840148434, 0.16462273750221357, 0.11987097284873016, 0.24375543580390513, 0.20141797402175143, 0.1561641538864933], [0.024463267291139346, 0.02504473814042285, 0.029532416083384305, 0.06823352494393475, 0.05461416883917991, 0.04727937492134515, 0.05232977891864721, 0.027446248241176363, 0.045572327653644606, 0.05453248435514979, 0.0307315690224641, 0.0200285490063834, 0.033075072860810906, 0.02682590184122091, 0.05910272251639981, 0.04412871312524658, 0.12725759093882516, 0.07531350987846963, 0.07955319917527959, 0.10539036549744196, 0.061027063202345744, 0.046274262058432214, 0.03923344767827075, 0.06083503249101341, 0.11911597117432393, 0.037441261229105294, 0.05067113452241756, 0.002255816771139507, 0.08952255055191927, 0.09745394956553355, 0.09295157709857449, 0.027215746449655853, 0.1566138953785412, 0.1971571409376338, 0.39327646256424487, 0.5024876492097974, 0.3660552279325202, 0.5051099241245538, 0.37724025431089103, 0.25872874015476555, 0.4312710394151509, 1.1630463413894176, 2.879444877617061, 10.502466391772032, 22.066981494426727, 45.332578271627426, 61.852134838700294, 51.16932347416878, 46.45381070673466, 59.39172886312008, 87.71437928080559, 120.01904502511024, 110.1316487789154, 64.31437611579895, 60.953353866934776, 75.79308897256851, 80.04387527704239, 42.8804824501276, 5.05780172534287, 0.7695113739464432, 0.4062975029228255, 0.3952003171434626, 0.10376026039011776, 0.38672371418215334, 0.4008794389665127, 0.12194071139674634, 0.03337665199069306, 0.11851061615743674, 0.1050656610459555, 0.16512347938260064, 0.025291760139225516, 0.08601178386015818, 0.09588058164808899, 0.10339687520172447, 0.03919347931514494, 0.01846033159381477, 0.04404791550769005, 0.04473582703212742, 0.0659967066894751, 0.09749887918587774, 0.07165380156948231, 0.07723887101747096, 0.09878670578473248, 0.03550508328771684, 0.02608252219943097, 0.02152969296730589, 0.04691393769462593, 0.01814358667616034, 0.185910145228263, 0.09497253427980468, 0.4644472966901958, 0.8441703021526337, 0.08826711869915016, 0.07778740720823407, 0.03820992955297697, 0.04997073265258223, 0.005250129388514324, 0.029056447092443705, 0.030556913843611255, 0.04407126718433574, 0.14743256382644176, 0.025097840662056115, 0.02889695027988637, 0.05090206861495972, 0.050632364727789536, 0.09945857949787751, 0.0788386890781112, 0.025536603934597224, 0.2104248563409783, 0.16500982688739896, 1.041331747546792, 0.23726896120933816, 0.05311784327204805, 0.11565633103600703, 0.08747650135774165, 0.0586493073933525, 0.02873260909836972, 0.043652651365846395, 0.3453467844519764, 0.4596350627252832, 1.2679841229692101, 2.004916579462588, 0.3410372219514102, 6.921830177307129, 38.080781400203705, 60.02852529287338, 54.64336685836315, 55.55245667695999, 78.84763106703758, 88.15998136997223, 52.045799642801285, 23.813588172197342, 21.554400399327278, 42.64893427491188, 60.8208891749382, 80.47951430082321, 46.27315320074558, 4.009449379518628, 1.6360850958153605, 0.7344624702818692, 0.3120003081858158, 0.2517879969673231, 0.27545710501726717, 0.13285463122883812, 0.17972213274333626, 0.08286358599434607, 0.08660233303089626, 0.026305721257813275, 0.1212787527765613, 0.13547508046030998, 0.08710731999599375, 0.0867955363355577, 0.08058929670369253, 0.22471686912467703, 0.08038294996367767, 0.07000845274887979, 0.021881864304305054, 0.0377820257563144, 0.041545300773577765, 0.016013153435778804, 0.06179716016049497, 0.014090398162807105, 0.02591171691165073, 0.04626540081517305, 0.07697456996538676, 0.01613407897821162, 0.09972512183594517, 0.05174074372916948, 0.012848695114371367, 0.05260691912553739, 0.06740410070051439, 0.07204087611171417, 0.04180955729680136, 0.05251947557553649, 0.008771653047006112, 0.04481132571527269, 0.01050894747095299, 0.0353015901055187, 0.048493892172700725, 0.07019208234851249, 0.04439532225660514, 0.030721841321792454, 0.05780627216154244, 0.042142948586842977, 0.04360522441857029, 0.041852872745948844, 0.03800623970164452, 0.05288465676130727, 0.04424035440024454, 0.04857769177760929, 0.10689762289985083, 0.12681239139055833, 0.03238171026168857, 0.0380775526718935, 0.0440480156976264, 0.06414201285224408, 0.048618817891110666, 0.03166661386785563, 0.040138051481335424, 0.04317928360251244, 0.07964526259456761, 0.09323745980509557, 0.022802654348197393, 0.08135607626172714, 0.07253455274621956, 0.06689610803732648, 0.04966844106093049, 0.008501543761667563, 0.1955924858339131, 0.2924361970508471, 0.2589116053422913, 0.7447986875195056, 0.3085334989009425, 0.3787180781364441, 0.24284493934828788, 0.32086484658066183, 0.45237394922878593, 2.9062296403571963, 2.4299031123518944, 11.481245420873165, 48.32652881741524, 77.36685052514076, 67.56643161177635, 62.16126345098019, 73.65304380655289, 98.42785120010376, 122.45099812746048, 113.57691630721092, 78.14900055527687, 59.61722016334534, 78.31944420933723, 97.09020137786865, 70.47181650996208, 21.53121404349804, 0.8579949103295803, 0.9361554100178182, 0.4277926229406148, 0.4258899937849492, 0.08378781218198128, 0.2581436309264973, 0.30263882770668715, 0.23249812424182892, 0.22158516920171678, 0.2118639400578104, 0.08293748163850978, 0.07060804127831943, 0.042148180727963336, 0.25608132127672434, 0.09391714091179892, 0.067631969723152, 0.041823773135547526, 0.11138481844682246, 0.10222883865935728, 0.02074179003102472, 0.016940593122853898, 0.07982144103152677, 0.03899292503774632, 0.01769041089573875, 0.09692851643194444, 0.060729038959834725, 0.03976373445766512, 0.027841313858516514, 0.08244719661888666, 0.02089989160594996, 0.11565274646272883, 0.049053449256462045, 1.5318640507757664, 1.6411655419506133, 0.13233033358119428, 0.04472349624847993, 0.027366801332391333, 0.04594911602907814, 0.07769178890157491, 0.03940656846680213, 0.03093288585660048, 0.08324519090820104, 0.04316024009312969, 0.02388886354310671, 0.011572980365599506, 0.0517097330885008, 0.02075669792247936, 0.034571658179629594, 0.03429670730838552, 0.043951124607701786, 0.17212786915479228, 0.09500224245130084, 0.5431868496816605, 0.4603771213442087, 0.11213625039090402, 0.22451086377259344, 0.2937154221581295, 0.027922261760977563, 0.06506510355393402, 0.13076300674583763, 0.43467170849908143, 0.30254169541876763, 0.5597314587794244, 0.577112379251048, 0.5207523191347718, 11.203218139708042, 48.000677302479744, 71.2339036166668, 61.528095826506615, 60.25246627628803, 67.60835856199265, 90.25068238377571, 77.63454616069794, 53.7842633575201, 36.25076539814472, 40.15844151377678, 54.942369014024734, 84.27814766764641, 72.57284536957741, 15.500773284584284, 0.7658068102318794, 1.056363028474152, 0.368299096589908, 0.29203095473349094, 0.23614959471160546, 0.1031468456494622, 0.22480542218545452, 0.08775522976065986, 0.10663656503311358, 0.03784904911299236, 0.23934445140184835, 0.17282903543673456, 0.09027076899656095, 0.05646064710163046, 0.06203884055139497, 0.16225555358687416, 0.10950500291073695, 0.03118824773991946, 0.03289534324721899, 0.07048632905934937, 0.04673451607231982, 0.058300724340369925, 0.004423452946866746, 0.11006015163729899, 0.04558541171718389, 0.07280542180524208, 0.013152733536117012, 0.041747677023522556, 0.07505900517571718, 0.03825712272373494, 0.05041354990680702, 0.009639161526138196, 0.041225253298762254, 0.011125822475150926, 0.03280573262600228, 0.027164679268025793, 0.016562073687964585, 0.026466140188858844, 0.11444476011092775, 0.09351701941341162, 0.11078556388383731, 0.21905912115471438, 0.17820963577833027, 0.20853953406913206, 0.13964357553049922, 0.24480596068315208, 0.16168988862773404, 0.15402898017782718, 0.1510248999693431, 0.15580894716549665, 0.20211315859341994, 0.251055586268194, 0.32614273368380964, 0.2370005115517415, 0.2019588660914451, 0.15981550561264157, 0.14480547979474068, 0.189145389595069, 0.14864683616906404, 0.11394139102776535, 0.12945562455570325, 0.10319494424038567, 0.18662870745174587, 0.17960810917429626, 0.11045020961319096, 0.1551669745822437, 0.2434828004334122, 0.1932253612903878, 0.26062296819873154, 0.10693112344597466, 0.3717053169384599, 0.3519791504368186, 0.7233518071006984, 0.7273800659459084, 0.46511451713740826, 0.4735586140304804, 0.2686709363479167, 0.36600606807041913, 0.6187328521627933, 2.149072769097984, 2.998075936920941, 12.94482808560133, 62.30035498738289, 103.42913523316383, 107.11173042654991, 86.97677046060562, 80.61284154653549, 88.280518501997, 117.38672867417336, 144.2428743839264, 126.0245543718338, 81.28665938973427, 83.37733760476112, 97.98055440187454, 101.33353248238564, 59.489509016275406, 10.945453271269798, 1.8438066495582461, 1.3545639021322131, 0.7233762089163065, 0.18829788663424551, 0.46212363231461495, 0.3681790764676407, 0.25989670248236507, 0.24927840975578874, 0.18058973306324333, 0.3397679713089019, 0.18462471576640382, 0.1124730592709966, 0.3234557434916496, 0.22310349944746122, 0.18523860548157245, 0.09280550759285688, 0.2234430320095271, 0.18735944089712575, 0.11640005206572823, 0.07919216659502126, 0.22559675941010937, 0.16272151842713356, 0.23747140425257385, 0.17934806062839925, 0.09365991994854994, 0.08709788729902357, 0.20798648562049493, 0.1775268153869547, 0.17682076577330008, 0.3219590394292027, 0.21009434829466045, 1.8320598173886538, 2.1593887405470014, 0.2239927853224799, 0.13470501318806782, 0.10203570214798674, 0.12703742540907115, 0.12443752624676563, 0.12312743521761149, 0.07633214467205107, 0.2364160554134287, 0.32970433006994426, 0.14483724371530116, 0.0991355226142332, 0.16823686310090125, 0.16503753868164495, 0.2228116721380502, 0.2771049697184935, 0.16068534721853212, 0.35731875454075634, 0.6522458663675934, 3.8410671148449183, 0.7347787439357489, 0.1798487876658328, 0.1923984455061145, 0.2752913982840255, 0.29697546910028905, 0.10386971232946962, 0.19290528784040362, 0.6026756856590509, 0.7131217466667295, 1.9765807874500751, 1.836592499166727, 0.3732588398270309, 12.482150662690401, 53.09380620718002, 68.25957521796227, 72.26392954587936, 74.59524884819984, 94.25726339221, 102.35970541834831, 70.60241550207138, 40.5483727902174, 43.20184640586376, 65.63317894935608, 77.33633056282997, 105.78573077917099, 72.80101552605629, 7.762187859043479, 1.409608698450029, 1.2985324650071561, 0.32447106088511646, 0.29242304619401693, 0.25380108738318086, 0.13884904707083479, 0.28377183072734624, 0.18223430262878537, 0.20794283249415457, 0.10743582097347826, 0.24848129862220958, 0.27615917671937495, 0.25744847604073584, 0.214937440759968, 0.16509869165020064, 0.20657083892729133, 0.13517252169549465, 0.1356072718044743, 0.17553913610754535, 0.1874802476959303, 0.16090911958599463, 0.23238775203935802, 0.13231198769062757, 0.21787002246128395, 0.20039383991388604, 0.16675880178809166, 0.1065344009839464, 0.11621703102719039, 0.18110816774424165, 0.10672167452867143, 0.1522320180083625, 0.15649302920792252, 0.1924043381586671, 0.21951767936116084, 0.15367139858426526, 0.1595256375730969, 0.0931531518290285, 0.10551277533522807], [0.04032705423014704, 0.021054751850897446, 0.011542830616235733, 0.08284960393211804, 0.00522128349984996, 0.004344803382991813, 0.052149804396322, 0.02695164948818274, 0.02046745143161388, 0.042579060536809266, 0.016673907921358477, 0.020753875905938912, 0.021434664668049663, 0.10543834534473717, 0.042939629274769686, 0.06724033839418553, 0.06412828312022611, 0.052203302111593075, 0.038887002010596916, 0.07449972268659621, 0.08080231535132043, 0.08761949095060118, 0.037595049070660025, 0.03981141373515129, 0.03328299666463863, 0.050442541905795224, 0.03932089493901003, 0.08672146999742836, 0.07962178104207851, 0.09295211144490167, 0.03150921176711563, 0.048305230811820365, 0.03931673891202081, 0.195756500470452, 0.1818355466821231, 0.19360887352377176, 0.3711765515618026, 0.49697583715897053, 0.3483069146750495, 0.08370982730411924, 0.21094795170938596, 0.429927603690885, 0.7556430681142956, 2.919931705109775, 7.721889121457934, 27.33773186802864, 62.19110704958439, 78.1434528529644, 68.11387583613396, 47.17332109808922, 41.91745072603226, 67.67798602581024, 110.05980223417282, 119.76351633667946, 113.45353692770004, 82.30332523584366, 64.72330257296562, 69.47307050228119, 59.179669842123985, 18.891947865486145, 1.2802797881886363, 0.7879181206226349, 0.2638702798867598, 0.05330835629138164, 0.030893375769665, 0.08959645361755975, 0.3963831521105021, 0.32122570846695453, 0.4106672090711072, 0.06776246897061355, 0.11994285727269016, 0.07571432157419622, 0.08223680517403409, 0.08415022515691817, 0.04532436498266179, 0.13460376940201968, 0.04208088277664501, 0.06600148612051271, 0.05306568513333332, 0.046299131427076645, 0.04325552443333436, 0.07438267857651226, 0.071033069252735, 0.022935606393730268, 0.05133332320838235, 0.11227319890167564, 0.016215175310207997, 0.05844734303536825, 0.09788305193069391, 0.03857779360259883, 1.4458306110464036, 1.0626263986341655, 0.04570461547700688, 0.026951530744554475, 0.02313360953849042, 0.09138417604845017, 0.03282912883150857, 0.10462752674357034, 0.08294902203488164, 0.0406967996241292, 0.03735948397661559, 0.034945448278449476, 0.045874975476181135, 0.061322129986365326, 0.12462985381716862, 0.10313145350664854, 0.04292278623324819, 0.05949039077677298, 0.04765415578731336, 0.1220287152682431, 0.1488479581894353, 0.5114485777448863, 0.33700848813168705, 0.17249362921575084, 0.07874877788708545, 0.26729549921583384, 0.09983505617128685, 0.24635044421302155, 0.6414730881806463, 0.42041677341330796, 0.3322305710753426, 0.5135116295423359, 9.32460654526949, 21.37423686683178, 39.25253592431545, 55.43729245662689, 74.91538166999817, 84.1746336221695, 74.84670415520668, 29.32069916278124, 10.81815155223012, 34.282110035419464, 51.143579855561256, 59.23705816268921, 81.87224596738815, 33.28335262835026, 0.9823255450464785, 1.6099619725719094, 0.5341902980580926, 0.2979124750709161, 0.3048604022478685, 0.07851796995964833, 0.18140633299481124, 0.24870330467820168, 0.06419784462195821, 0.04124296465306543, 0.08743209866224788, 0.07588855558424257, 0.1554398622829467, 0.04561571360682137, 0.03672971230116673, 0.07062685472192243, 0.042085046225111, 0.03088194669544464, 0.058090982274734415, 0.0051617275403259555, 0.031856818895903416, 0.08118530808133073, 0.017653845279710367, 0.04872128622082528, 0.010431163900648244, 0.11542075852048583, 0.037710449323640205, 0.05868628490134142, 0.1040997781092301, 0.06660047351033427, 0.0830532937834505, 0.061045186448609456, 0.04759063165693078, 0.09978525806218386, 0.01573631936480524, 0.09465349241509102, 0.03432129095017444, 0.021532221835514065, 0.01742144173476845, 0.012575798136822414, 0.05812101699120831, 0.013365810627874453, 0.017185850665555336, 0.037137500185053796, 0.041397160675842315, 0.0170306249128771, 0.005707113778044004, 0.037356674947659485, 0.043196753758820705, 0.012439853380783461, 0.033019185430021025, 0.11763456277549267, 0.07302606230950914, 0.05003418627893552, 0.029415101089398377, 0.12121111343731172, 0.08141317710396834, 0.05156627594260499, 0.04590197480865754, 0.0971831992501393, 0.036278115439927205, 0.08269737460068427, 0.05836715026816819, 0.014847237580397632, 0.05201061088882852, 0.04073020369105507, 0.1570987404556945, 0.05472105294757057, 0.04585029535519425, 0.058552397749735974, 0.049248630384681746, 0.07640601063030772, 0.05724013964936603, 0.15632160793757066, 0.18752335163298994, 0.40311567834578454, 0.5097665742505342, 0.3024870139779523, 0.24466441827826202, 0.16855717403814197, 0.4191978997550905, 0.5442352371755987, 2.56119841709733, 4.7937230207026005, 15.889338534325361, 44.98123772442341, 88.86568710207939, 78.57798993587494, 73.44037681818008, 68.59100103378296, 72.91522979736328, 104.12306159734726, 123.97760421037674, 99.92424130439758, 87.79616609215736, 79.49767738580704, 88.25260519981384, 93.73909279704094, 65.28420567512512, 16.436802707612514, 0.7217016268987209, 1.2437562667764723, 0.2968748041894287, 0.09252310555893928, 0.07054576766677201, 0.04831335732887965, 0.07997295790119097, 0.31386381131596863, 0.3202775999670848, 0.08402323626796715, 0.15622943319613114, 0.07269996262039058, 0.10767228406621143, 0.048167566128540784, 0.07157467378419824, 0.0345144905440975, 0.05680665861291345, 0.09596505289664492, 0.03268062137067318, 0.044551870887517, 0.04488103193580173, 0.025155794974125456, 0.03727637085830793, 0.0843573956808541, 0.09319120916188695, 0.0012598945954778173, 0.1698449783725664, 0.07930358522571623, 0.390574659104459, 0.04358310099632945, 1.892805139068514, 1.9995930651202798, 0.009181086643366143, 0.038359735772246495, 0.007003985765550169, 0.04040497602545656, 0.02603677065053489, 0.03509444184601307, 0.07417582717607729, 0.04725981933006551, 0.021456276008393615, 0.1297683804295957, 0.10386992755229585, 0.09075456764549017, 0.1392356466385536, 0.07266406493727118, 0.16683775145793334, 0.08328939322382212, 0.07864788291044533, 0.018909462669398636, 0.028037493175361305, 0.6552005640696734, 0.31189539819024503, 0.14834132365649566, 0.2923395100515336, 0.7949620520230383, 0.4851004056399688, 0.26973164349328727, 0.2998277801088989, 0.8306324598379433, 0.774229058297351, 2.7194910356774926, 27.205470465123653, 58.71265970170498, 74.72201764583588, 72.66195818781853, 74.42206934094429, 83.71982082724571, 88.69531944394112, 55.21269790828228, 34.938266426324844, 35.52840895950794, 45.594034641981125, 58.699056431651115, 87.63991847634315, 56.60769805312157, 5.303203957155347, 1.1523141735233366, 1.0943398531526327, 0.36048716108780354, 0.35841107717715204, 0.13146258483175188, 0.10834383123437874, 0.2577399619622156, 0.060571729627554305, 0.07535538185038604, 0.14998878759797662, 0.08452060137642547, 0.10628082396578975, 0.06997409873292781, 0.0766979121544864, 0.14651353267254308, 0.14003038289956748, 0.06709640627377667, 0.028673294800682925, 0.015127710958040552, 0.06837056251242757, 0.028080663905711845, 0.04505027871346101, 0.04523571173194796, 0.08206677914131433, 0.06893631652928889, 0.033388337105861865, 0.0404414637159789, 0.07888308435212821, 0.04054117867781315, 0.15512842743191868, 0.08606935225543566, 0.072889893053798, 0.04299399530282244, 0.055392102876794524, 0.03799333375354763, 0.04112947171961423, 0.001777225911610003, 0.03000424574565841, 0.06653024407569319, 0.16159808496013284, 0.12949044612469152, 0.06863926450023428, 0.16212321381317452, 0.08030035634874366, 0.08248081590863876, 0.18776673154206946, 0.08565135241951793, 0.1338854298228398, 0.10711304610595107, 0.1884530103416182, 0.14505637023830786, 0.12863203359302133, 0.23306352202780545, 0.22482923028292134, 0.10965636392938904, 0.28130775201134384, 0.159918678982649, 0.13385610014665872, 0.12788886175258085, 0.20303530676756054, 0.3236697491956875, 0.10626492716255598, 0.13974220695672557, 0.19396626215893775, 0.28687620477285236, 0.28749571996740997, 0.12518791918409988, 0.14333141123643145, 0.1584370998898521, 0.1626316295005381, 0.232482390711084, 0.21713982336223125, 0.29001192713622004, 0.329757853760384, 0.3739675908582285, 0.5301486211828887, 0.37990794866345823, 0.3403453028295189, 0.17958617128897458, 0.3614441159879789, 0.4300224798498675, 1.3831420498900115, 3.4069689083844423, 11.394311785697937, 50.00476576387882, 108.68023306131363, 106.83449730277061, 96.29893183708191, 77.31086432933807, 67.51996770501137, 95.66126525402069, 139.2013505101204, 138.31444770097733, 130.2771645784378, 97.13959872722626, 80.13929575681686, 87.92701587080956, 85.94200998544693, 37.58060663938522, 5.1571055967360735, 2.676161485724151, 0.5854452133644372, 0.15681362216128036, 0.10493105030036531, 0.15901774138910696, 0.4988120589405298, 0.361147613148205, 0.7404201349709183, 0.13810986798489466, 0.34252677171025425, 0.2975397981936112, 0.17770923528587446, 0.2346913338988088, 0.24001606536330655, 0.22326399630401284, 0.20494296768447384, 0.23854178900364786, 0.14103241584962234, 0.17022382991854101, 0.2462508628377691, 0.20238362689269707, 0.20503304956946522, 0.25379526894539595, 0.27666719164699316, 0.20636168686905876, 0.23766219557728618, 0.12844459677580744, 0.38503135030623525, 0.23835907224565744, 2.6286381483078003, 2.413202770985663, 0.10704923624871299, 0.17077693773899227, 0.08037598119699396, 0.1886623998871073, 0.12709819246083498, 0.18624509131768718, 0.18932861101347953, 0.16472841933136806, 0.10929688985925168, 0.1658688925090246, 0.28508255258202553, 0.12017808097880334, 0.23034561396343634, 0.32016669341828674, 0.3040010842960328, 0.12785178405465558, 0.13611631089588627, 0.1543804761604406, 0.19637828663690016, 1.4097248297184706, 1.3725522556342185, 0.3235234570456669, 0.1815170465852134, 0.7353038876317441, 0.7404467335436493, 0.7112930354196578, 0.7458503998350352, 0.9319523011799902, 2.506757788360119, 4.254018506035209, 23.796234503388405, 58.38571384549141, 73.206886947155, 79.36260223388672, 88.69320675730705, 99.05205890536308, 93.55158045887947, 43.907073363661766, 28.037652410566807, 55.67816533148289, 68.23818236589432, 75.70968344807625, 108.16062614321709, 47.096690610051155, 1.900173299945891, 1.8017579871229827, 0.8807635260745883, 0.2872511377790943, 0.42429125925991684, 0.17872508702566847, 0.1363076810957864, 0.20952151418896392, 0.16622726077912375, 0.22442980640335009, 0.2794965554494411, 0.24579329910920933, 0.30884413223247975, 0.12656547885853797, 0.21659434481989592, 0.2721948316320777, 0.2369747738703154, 0.12853481224738061, 0.1324402159661986, 0.10969655864755623, 0.182476153713651, 0.16542755212867633, 0.09373147782753222, 0.20018590497784317, 0.20604314224328846, 0.14459481375524774, 0.14321726892376319, 0.12245556892594323, 0.20186568202916533, 0.10487486229976639, 0.31855537206865847, 0.1827549934387207, 0.23781587951816618, 0.33689844247419387, 0.11536203237483278, 0.14044111710973084, 0.18815380608430132, 0.18815763556631282, 0.11475963852717541, 0.14325753785669804], [0.0028933452813362237, 0.09433027225895785, 0.015912607268546708, 0.02018233313719975, 0.07610504006152041, 0.0333090534695657, 0.03601851589337457, 0.05217970552621409, 0.014375228874996537, 0.06081719868234359, 0.04475913417991251, 0.07800704581313767, 0.037016051428508945, 0.02898339749663137, 0.11216506056371145, 0.006634739465880557, 0.04454623056517448, 0.06942102801986039, 0.07678177484194748, 0.07295045972568914, 0.019392203757888637, 0.02011275864788331, 0.029222446974017657, 0.03104093328147428, 0.030847878406348173, 0.04441604301973712, 0.06863453701953404, 0.035702112363651395, 0.09547097550239414, 0.05985798023175448, 0.027353466794011183, 0.020550163790176157, 0.02501644932635827, 0.017955906805582345, 0.06792361891712062, 0.17835582402767614, 0.315056502004154, 0.5127499485388398, 0.3406037186505273, 0.23787637939676642, 0.10572113329544663, 0.13799764041323215, 0.13902362989028916, 0.22300013311905786, 1.598852437455207, 3.4628779208287597, 27.517937198281288, 74.20492619276047, 88.80846977233887, 77.74490743875504, 46.94323964416981, 39.37303125858307, 45.20227566361427, 76.91129297018051, 100.41213512420654, 121.27523481845856, 125.80962270498276, 102.74796098470688, 85.38204163312912, 59.56360884010792, 37.25864991545677, 9.266312923282385, 0.0834451848641038, 0.7503557705786079, 0.3448309621307999, 0.10866202705074102, 0.05151367251528427, 0.3716419968986884, 0.8689190866425633, 0.6830368016380817, 0.060725435832864605, 0.09420286776730791, 0.13536626676796004, 0.06180853357363958, 0.0936526023724582, 0.08875235711457208, 0.06680185528239235, 0.11678426191792823, 0.07758189909509383, 0.14164292137138546, 0.06791618259740062, 0.12249690655153245, 0.042117240591323934, 0.03272208516136743, 0.07756664796033874, 0.1137645891867578, 0.07143399227061309, 0.02742318043601699, 0.11199681568541564, 0.3022012871224433, 1.1129631288349628, 1.124317750800401, 0.03777997742872685, 0.024057392292888835, 0.04763743891089689, 0.045975480825291015, 0.06721238169120625, 0.023514292333857156, 0.035276661365060136, 0.08776518196100369, 0.036555047845467925, 0.09020387180498801, 0.023215930414153263, 0.018739805855148006, 0.0161623455278459, 0.01482237934396835, 0.021381257865868974, 0.06016635372361634, 0.0037478956301129074, 0.021352560870582238, 0.02506385400920408, 0.09442205366212875, 0.1997431693598628, 0.13708053884329274, 1.6597144841216505, 0.7325485011097044, 1.5517196478322148, 0.7931270473636687, 0.16388297954108566, 1.2335519143380225, 6.370304971933365, 16.02408215403557, 15.72612589225173, 25.88297612965107, 43.62293601036072, 55.82151263952255, 62.80374437570572, 52.01357737183571, 28.523916117846966, 24.500986486673355, 46.847693771123886, 57.677640840411186, 66.42748072743416, 63.349919468164444, 11.885550376027822, 0.3475596016505733, 1.0206848429515958, 0.46733775408938527, 0.34706580627243966, 0.23186890175566077, 0.1242400481714867, 0.28771875018719584, 0.28883957129437476, 0.12596528918948025, 0.14611011603847146, 0.059929868366452865, 0.06664934393484145, 0.16926588054047897, 0.03303692275949288, 0.028986605429963674, 0.1865026610903442, 0.05206262801948469, 0.1400094840209931, 0.06120226200437173, 0.046679333681822754, 0.03076566328672925, 0.0686383071297314, 0.0338984486006666, 0.023970340225787368, 0.04364039850770496, 0.0349915875995066, 0.036426908627618104, 0.04723093123175204, 0.09817421872867271, 0.05708223288820591, 0.024383594027312938, 0.08478049407131039, 0.019396300413063727, 0.06949424088816158, 0.042790776715264656, 0.026606892206473276, 0.053300567451515235, 0.08595993000199087, 0.07143517228541896, 0.07634936991962604, 0.018280776384926867, 0.008558434947190108, 0.0566828869341407, 0.03453264347626828, 0.11491194949485362, 0.00728255785361398, 0.028874006784462836, 0.058877840638160706, 0.05609781110251788, 0.0481873258104315, 0.014348796357808169, 0.0517933694209205, 0.03875036520184949, 0.0959932099794969, 0.1782540458953008, 0.05590071152255405, 0.0433345260535134, 0.018757673060463276, 0.02115032562869601, 0.044690218346659094, 0.019195323111489415, 0.16215999465202913, 0.06250752907362767, 0.026060395066451747, 0.05472143144288566, 0.04160598247835878, 0.046229094950831495, 0.13142028241418302, 0.0895807275082916, 0.10439376506838016, 0.024456176070088986, 0.012886796976090409, 0.04026735958177596, 0.0687670474871993, 0.023896477978269104, 0.09617683957912959, 0.17774665437173098, 0.2635711943730712, 0.4784983489662409, 0.23672992450883612, 0.14741129387402907, 0.0500344794272678, 0.46804549579974264, 0.18732784024905413, 0.9685005806386471, 3.6078596161678433, 8.836091458797455, 56.094205006957054, 99.28576916456223, 94.23219233751297, 71.88867688179016, 57.87346713244915, 65.25349572300911, 88.54411795735359, 109.54331874847412, 115.75510382652283, 114.21001553535461, 91.34316936135292, 84.01982992887497, 89.03585717082024, 84.4804336130619, 49.39557105302811, 9.526199977844954, 1.1742070550099015, 0.4944592440733686, 0.19419105869019404, 0.1633956705336459, 0.19917288824217394, 0.40090069407597184, 0.21345930523239076, 0.6579244835302234, 0.28231716190930456, 0.3465420281281695, 0.08804039258393459, 0.1105999453284312, 0.028915318434883375, 0.0777253636624664, 0.030825662215647753, 0.06245966054848395, 0.03818201737885829, 0.04820707064936869, 0.07991769016371109, 0.08813359891064465, 0.05335534908226691, 0.16907247685594484, 0.10115527751622722, 0.02046131201495882, 0.07335852962569334, 0.017529824981465936, 0.05924981989664957, 0.2741998474812135, 1.757372331339866, 4.572488442063332, 0.11959973271586932, 0.10101340114488266, 0.04647703535738401, 0.021127309773874003, 0.03550802590325475, 0.04004202128271572, 0.06500061092083342, 0.12251341933733784, 0.05325184545654338, 0.04710911882284563, 0.001303120523061807, 0.06023327317961957, 0.0840485880326014, 0.05303015481331386, 0.025183905672747642, 0.030640433287771884, 0.040535204389016144, 0.054506657616002485, 0.06233286461792886, 0.21187452308367938, 0.3609654604224488, 1.493140091188252, 1.066948666702956, 0.7255920837633312, 1.9548465474508703, 1.449959920719266, 0.8750822965521365, 1.1702614417299628, 12.424413710832596, 30.782286934554577, 34.42815139889717, 45.80167829990387, 50.593703761696815, 53.83743770420551, 71.7960150539875, 71.93097621202469, 58.65348167717457, 34.49785105884075, 30.000239498913288, 58.09968039393425, 75.88455766439438, 81.9264842569828, 29.860608391463757, 1.305524802301079, 0.5418997874949127, 0.9244396293070167, 0.26634234411176294, 0.3268198692239821, 0.057553711885702796, 0.15957540599629283, 0.1496719944407232, 0.1125064113875851, 0.1256890469812788, 0.07072219101246446, 0.07810512062860653, 0.13835274323355407, 0.037143077424843796, 0.02777720714220777, 0.014405416659428738, 0.03607414728321601, 0.05901126023672987, 0.007434606750393868, 0.042459426331333816, 0.06575568681000732, 0.06119977209891658, 0.13016510289162397, 0.04982043661584612, 0.10657059552613646, 0.04278265761968214, 0.03757961239898577, 0.03408935124753043, 0.02076958531688433, 0.09398292488185689, 0.08340637796209194, 0.12447153887478635, 0.015900682810752187, 0.11137699621031061, 0.018256734510941897, 0.044993845804128796, 0.11854091062559746, 0.0660748771042563, 0.06394353287760168, 0.03101624759437982, 0.06259110974497162, 0.10737071235780604, 0.16644163755699992, 0.10651270800735801, 0.20419195876456797, 0.16305541066685691, 0.10069995507365093, 0.08714048657566309, 0.1546914508799091, 0.12801882665371522, 0.09823086686083116, 0.24734397215070203, 0.12508401850936934, 0.22165502014104277, 0.24471166339935735, 0.22420584107749164, 0.17007422778988257, 0.25324584217742085, 0.24770048505160958, 0.1538457439164631, 0.23963307263329625, 0.31038515735417604, 0.11303283157758415, 0.24640825751703233, 0.1526787760667503, 0.21035159152233973, 0.1394906040513888, 0.2049449269543402, 0.22960254602367058, 0.21109442197484896, 0.2379918278893456, 0.16390576347475871, 0.30483944399748, 0.20388886565342546, 0.08837052213493735, 0.2786953921895474, 0.14419123384868726, 0.30123088450636715, 0.4520318191498518, 0.35347508266568184, 0.3631596942432225, 0.17781472415663302, 0.5049486109055579, 0.39310208754613996, 0.2979474450694397, 2.531903414055705, 4.085569744929671, 52.91930817067623, 117.27081969380379, 118.05993854999542, 98.47480908036232, 71.968465000391, 65.94321951270103, 69.47952255606651, 98.67286205291748, 116.38402327895164, 137.3227161169052, 136.58544927835464, 121.49972677230835, 99.73484426736832, 93.36935743689537, 69.01904046535492, 21.46640282124281, 4.345075869932771, 2.6493368251249194, 0.34360359830316156, 0.14821278367890045, 0.44113079784438014, 0.4669389536138624, 1.4633816317655146, 1.1964913154952228, 0.3045485814800486, 0.42826643970329314, 0.23147311439970508, 0.44147462002001703, 0.15622505452483892, 0.1790798781439662, 0.09840749800787307, 0.20680560992332175, 0.17912029550643638, 0.20651298109441996, 0.1581660527153872, 0.1824982845573686, 0.11452788807218894, 0.1554412129917182, 0.1499500178033486, 0.17007274349452928, 0.21801830356707796, 0.1883902246481739, 0.13519658212317154, 0.39704648370388895, 2.004969301633537, 5.236315671354532, 0.2254432238987647, 0.18635562679264694, 0.22309490537736565, 0.07397677574772388, 0.14264799712691456, 0.09340459888335317, 0.11098642615252174, 0.22376858250936493, 0.1497240041499026, 0.12894036626676098, 0.14252435532398522, 0.10280642993166111, 0.1846570140332915, 0.12672167125856504, 0.10095912788528949, 0.18388694676104933, 0.106882713153027, 0.15941505756927654, 0.12947600393090397, 0.2194000341114588, 0.8605347177945077, 2.751882397569716, 3.8143186876550317, 3.1323619186878204, 1.421328813303262, 2.2301540058106184, 2.1792170265689492, 1.3645534473471344, 11.950382497161627, 36.57172277569771, 53.33254359662533, 59.36716318130493, 63.71017053723335, 62.80488811433315, 85.28346732258797, 69.38709631562233, 45.56352607905865, 39.48635637760162, 62.90022499859333, 75.76556324958801, 95.216134339571, 88.13665822148323, 16.455446407198906, 0.3678688587388024, 1.3814619462937117, 0.7937830465380102, 0.4078514117281884, 0.35265916550997645, 0.1508581987582147, 0.30793227022513747, 0.295874864095822, 0.117251518095145, 0.23333253571763635, 0.2060564118437469, 0.30778713582549244, 0.43197756400331855, 0.2326461678603664, 0.12274766340851784, 0.2440734312403947, 0.13542928994866088, 0.22619227354880422, 0.1270219887373969, 0.2121986635029316, 0.21574020705884323, 0.23017592931864783, 0.2873835962964222, 0.10243297379929572, 0.1315310553763993, 0.1282852131407708, 0.14988062699558213, 0.16228106862399727, 0.13339487020857632, 0.24529678747057915, 0.15531546348938718, 0.18817590724211186, 0.09552900402923115, 0.20584239129675552, 0.1289658367750235, 0.08451824134681374, 0.24533634394174442, 0.23717700911220163, 0.12842185737099499, 0.22522227169247344, 0.09625846840208396], [0.050892060753540136, 0.06807189260143787, 0.002602451454549737, 0.04639634906197898, 0.024967491699499078, 0.07103443480446003, 0.03961177229939494, 0.07233435841044411, 0.05939059046795592, 0.04132588110223878, 0.050353031474514864, 0.0414604176330613, 0.02984832608490251, 0.019965711362601724, 0.027700849423126783, 0.030007227323949337, 0.02764066495728912, 0.04030175812658854, 0.02989153392263688, 0.07709530254942365, 0.04833940300159156, 0.0657529037562199, 0.12812293512979522, 0.05834290059283376, 0.02634524989844067, 0.09274888172512874, 0.04602798406267539, 0.019415740971453488, 0.05543780433072243, 0.1059704800718464, 0.016265127414953895, 0.0944759781123139, 0.03632987281889655, 0.14194081944879144, 0.08915843805880286, 0.09020030949614011, 0.1780608796980232, 0.1740895287366584, 0.26141852082218975, 0.32562147884164006, 0.6392747873906046, 0.29255200177431107, 0.3351924824528396, 0.3204369836021215, 0.24965919088572264, 1.2404426070861518, 1.3360978430137038, 8.927238117903471, 44.8641774058342, 74.85638603568077, 73.21084633469582, 70.52726313471794, 57.96095743775368, 42.23738595843315, 48.54054473340511, 71.06357395648956, 81.27214416861534, 121.40224680304527, 124.5314472913742, 112.97857761383057, 80.79897835850716, 46.082065254449844, 12.844374775886536, 3.6024969164282084, 0.43135692074429244, 0.1942741495440714, 1.054129817057401, 0.3637022338807583, 0.09421710958122276, 1.021183447446674, 0.6631140550598502, 0.1825954465311952, 0.197759571892675, 0.03345326018461492, 0.20161765627563, 0.2532883227104321, 0.1838558359304443, 0.14794896502280608, 0.10637813436915167, 0.24469628609949723, 0.07811557006789371, 0.07908974279416725, 0.07770299533149227, 0.010937188017123844, 0.1228121857275255, 0.06611435193917714, 0.18825687555363402, 0.05122217546158936, 0.07879392273025587, 0.147205748653505, 1.2356110475957394, 2.5997074507176876, 0.05598361683951225, 0.04103756044059992, 0.12904576607979834, 0.08112681200145744, 0.001302215798659745, 0.07119254936696962, 0.1093677501194179, 0.09566467604599893, 0.07938554059364833, 0.018010356325248722, 0.010386085850768723, 0.0864089812966995, 0.07044368525384925, 0.0980756912031211, 0.04974891955498606, 0.07751445271424018, 0.0373938528355211, 0.1491212911787443, 0.1698008948005736, 0.2996906905900687, 0.40707052394282073, 0.7833419786766171, 0.3109604702331126, 1.0309543856419623, 3.2207368640229106, 0.6934268097393215, 7.233649045228958, 20.69607775658369, 19.067962020635605, 40.35059720277786, 62.54297576844692, 58.503549322485924, 56.53161473572254, 65.07225304841995, 33.261655792593956, 17.747399881482124, 31.977852880954742, 54.086480140686035, 64.20664429664612, 62.74385578930378, 22.329912185668945, 1.8254112428985536, 0.5329948465805501, 0.40940169885288924, 0.011019164721801644, 0.2078880916815251, 0.12856111396104097, 0.16135246376506984, 0.2601634303573519, 0.14361848880071193, 0.058702890455606394, 0.09653893343056552, 0.10874500658246689, 0.058332432599854656, 0.09474157792283222, 0.04590416785504203, 0.05305951046466362, 0.03467364782409277, 0.08634891928522848, 0.052857304908684455, 0.035750036549870856, 0.011796510607382515, 0.0306779210222885, 0.015498876637138892, 0.017190967773785815, 0.030599648562201764, 0.06166857936477754, 0.0784311535244342, 0.0393616240035044, 0.06999907200224698, 0.049797663814388216, 0.03387125630979426, 0.03326818339701276, 0.03453060628089588, 0.034334007650613785, 0.03777660436753649, 0.06727164960466325, 0.08918598658055998, 0.015583487038384192, 0.02526875541661866, 0.08444966690149158, 0.05680293674231507, 0.0280348604064784, 0.06353401578962803, 0.036756069675902836, 0.03483916159893852, 0.017928376837517135, 0.06705259729642421, 0.020305451726017054, 0.06819997986895032, 0.11152527731610462, 0.03426566698180977, 0.053209094039630145, 0.04649798618629575, 0.09189732663799077, 0.059841790280188434, 0.020447853166842833, 0.033842742996057495, 0.04209085353068076, 0.06587161027709953, 0.06061623622372281, 0.0863044052675832, 0.1054618640046101, 0.07120876529370435, 0.059489129125722684, 0.07718409309745766, 0.10596770443953574, 0.027066287184425164, 0.013185886200517416, 0.13237113686045632, 0.06311485820333473, 0.06870494456961751, 0.030949502543080598, 0.15116584865609184, 0.1035085238981992, 0.0433972041355446, 0.04043213863042183, 0.10016945307143033, 0.05801936502393801, 0.07347333987127058, 0.20703036192571744, 0.12472970236558467, 0.23306334391236305, 0.36679630691651255, 0.2963458013255149, 0.2165767113910988, 0.4498089384287596, 0.25906490336637944, 0.448391733225435, 2.4912838311865926, 5.2450694516301155, 32.372853085398674, 86.68830513954163, 95.24936735630035, 71.48752480745316, 65.43515637516975, 57.79426798224449, 73.83205220103264, 81.38475492596626, 100.97743079066277, 109.71062377095222, 120.54797664284706, 107.56700679659843, 92.79611259698868, 99.93260085582733, 75.14979109168053, 26.677849777042866, 9.342689774930477, 2.139861825853586, 0.5179176712408662, 0.5770634568762034, 1.002399274148047, 0.5119656468741596, 0.5755153368227184, 1.2667977553792298, 0.6286535260733217, 0.17538432410219684, 0.2017514209728688, 0.1111221946484875, 0.12963044486241415, 0.1890422310680151, 0.03138285370368976, 0.17291390744503587, 0.10479756019776687, 0.20184735098155215, 0.011142457715322962, 0.08139598154230043, 0.05397894979978446, 0.14308038720628247, 0.03858956777548883, 0.03994599108409602, 0.07142162066884339, 0.14729820541106164, 0.05963991497992538, 0.7687996840104461, 3.7407456105574965, 0.13779577624518424, 0.008421003112744074, 0.04996114410459995, 0.11723795905709267, 0.09435321946511976, 0.0896464149991516, 0.038328795635607094, 0.13575970893725753, 0.046595586027251557, 0.059517464324017055, 0.05280062337988056, 0.04588356212479994, 0.07612649555085227, 0.06326780741801485, 0.13952716224594042, 0.04228162630170118, 0.11515135149238631, 0.13124541757861152, 0.209662611305248, 0.27364213834516704, 0.3377572854515165, 0.3801946551539004, 0.26939420378766954, 1.4450667332857847, 3.044812954030931, 0.8005885407328606, 11.331522054970264, 33.04931178689003, 43.906275406479836, 69.87463295459747, 76.94958731532097, 64.11865621805191, 67.51221612095833, 75.2478638291359, 59.61394473910332, 39.66540277004242, 32.37882636487484, 40.851433128118515, 69.53805461525917, 79.1814811527729, 44.882139042019844, 6.482601296156645, 0.9879270975943655, 0.5998241167981178, 0.39150768716353923, 0.1724827493308112, 0.3002408891916275, 0.1614360889652744, 0.19632897834526375, 0.03473252239928115, 0.07095263528754003, 0.07487318624043837, 0.20734224206535146, 0.11111875850474462, 0.11285123546258546, 0.06933350654435344, 0.042286209063604474, 0.0789554808579851, 0.09704402429633774, 0.03500057500787079, 0.05377127090469003, 0.025100595885305665, 0.03088971698161913, 0.02993838941620197, 0.06838850764324889, 0.10046216353657655, 0.053193716739770025, 0.06387903282302432, 0.03136625928163994, 0.05672829895047471, 0.037040620227344334, 0.05553975686780177, 0.062121942537487485, 0.06178695934067946, 0.02535614145017462, 0.014459018275374547, 0.06852118138340302, 0.03601477546908427, 0.0686831031634938, 0.04818516616069246, 0.09480837863520719, 0.02621339252073085, 0.04306100381654687, 0.04049192233651411, 0.1988267950946465, 0.19032135227462277, 0.05128999662701972, 0.10781972654513083, 0.10566152399405837, 0.3690037509659305, 0.12471833266317844, 0.15070138295413926, 0.091654622083297, 0.1832525440840982, 0.1390478535904549, 0.2557421597884968, 0.10670513947843574, 0.11155470347148366, 0.18969754746649414, 0.15237194253131747, 0.10986961264279671, 0.2525248605525121, 0.22303243138594553, 0.15257290127919987, 0.18156777980038896, 0.23306739603867754, 0.26109461789019406, 0.12680229818215594, 0.1422325725434348, 0.2646569861099124, 0.15865774039411917, 0.11754969076719135, 0.17111008783103898, 0.20991759840399027, 0.07781376829370856, 0.2740074828034267, 0.22004589554853737, 0.29735170828644186, 0.13764868257567286, 0.15474794316105545, 0.24979714129585773, 0.21593994868453592, 0.29049435281194746, 0.3498713322915137, 0.603967378847301, 0.3246700158342719, 0.4763205611379817, 0.5095476110000163, 0.2210833883145824, 2.0457408763468266, 1.5358153637498617, 17.87850234657526, 85.46587273478508, 116.67644798755646, 96.26587361097336, 91.22343018651009, 74.85957026481628, 65.49190253019333, 69.07000333070755, 90.6630590558052, 98.11760544776917, 135.82500368356705, 141.99936836957932, 116.6056501865387, 123.454569876194, 98.93608152866364, 37.89316266775131, 16.475990004837513, 3.3177133603021502, 0.9460948454216123, 2.418549321591854, 4.228275362402201, 0.4512512282235548, 1.2084591295570135, 1.4513540896587074, 0.4400198324583471, 0.41022839199285954, 0.3388438787078485, 0.1819744915701449, 0.2997730392962694, 0.29581590788438916, 0.25490688742138445, 0.4346117132809013, 0.36212246865034103, 0.4283925157506019, 0.19884126697434112, 0.2916537062264979, 0.17385606392053887, 0.37152138305827975, 0.21174727444304153, 0.2432822424452752, 0.27949934592470527, 0.35363188362680376, 0.18137473234673962, 1.5641777543351054, 6.987779438495636, 0.23941084393300116, 0.19355845201062039, 0.2521536679705605, 0.2810442302143201, 0.11649714724626392, 0.24236071767518297, 0.18077298416756094, 0.34833244455512613, 0.12924865441164002, 0.2213926412514411, 0.13470715057337657, 0.12759302684571594, 0.2696006989572197, 0.1983834063867107, 0.17563447239808738, 0.18770587543258443, 0.17131972970673814, 0.18700999324209988, 0.5119680217467248, 0.41690700862091035, 0.2864084142493084, 0.4734519525663927, 0.5518389260396361, 3.1141171976923943, 6.161501901224256, 0.6884775159414858, 9.94145879521966, 44.08755607903004, 64.45525735616684, 105.43062463402748, 98.67091655731201, 75.88857024908066, 85.54923266172409, 89.9218100309372, 46.32465943694115, 33.252213299274445, 54.40048389136791, 72.79093846678734, 92.08337724208832, 92.70589023828506, 33.29474441707134, 1.6512655187398195, 0.8796482859179378, 0.6591967621352524, 0.34083449689205736, 0.2301575685851276, 0.2515377150848508, 0.1805587558192201, 0.24581002711784095, 0.23028177442029119, 0.15215407765936106, 0.14464449312072247, 0.2855527773499489, 0.3361582837533206, 0.21482292737346143, 0.11169818288180977, 0.17750128550687805, 0.15348823653766885, 0.16586368263233453, 0.1188344819820486, 0.1477215116028674, 0.13942189601948485, 0.17700296302791685, 0.11761023517465219, 0.12880191119620577, 0.18394720915239304, 0.25539231137372553, 0.28404874086845666, 0.10192995352554135, 0.1819323078962043, 0.17849135503638536, 0.18100883869919926, 0.147971912228968, 0.24001493729883805, 0.1415211200946942, 0.11357373849023134, 0.17476664943387732, 0.17661864927504212, 0.16995658254018053, 0.11413138825446367, 0.15994032000890002, 0.1461305102566257, 0.11582364822970703, 0.16511893743881956], [0.054298626200761646, 0.046396664474741556, 0.05652724743413273, 0.012054793769493699, 0.02626966030220501, 0.06340937950881198, 0.0990078657923732, 0.03948912868509069, 0.0226309974459582, 0.04070337876328267, 0.04469276020245161, 0.025049228133866563, 0.05885448154003825, 0.02441058779368177, 0.019340717262821272, 0.03017743889358826, 0.007859155575715704, 0.04485153898713179, 0.03842092213744763, 0.08925554066081531, 0.05948210098722484, 0.021852623685845174, 0.10682418738724664, 0.050489226705394685, 0.04585734575812239, 0.039413704216713086, 0.12950488831847906, 0.015829095245862845, 0.026813123913598247, 0.02671121033927193, 0.07861021891585551, 0.07426126321661286, 0.09883121980237775, 0.0631396533572115, 0.08173694644938223, 0.05071742969448678, 0.045225173234939575, 0.08311650992254727, 0.2703746996121481, 0.25395949138328433, 0.2993019833229482, 0.4514310951344669, 0.3008698741905391, 0.14722329302458093, 0.3319595684297383, 0.03736256760021206, 0.10610047465888783, 1.5416093403473496, 2.784491772763431, 17.096175625920296, 71.68360948562622, 80.05244761705399, 85.55851176381111, 80.67181438207626, 55.91822884976864, 38.94610896706581, 50.09683482348919, 69.14741277694702, 97.89550736546516, 109.25701931118965, 101.67164593935013, 91.26649707555771, 54.700120612978935, 26.260768957436085, 16.917701102793217, 7.37477014772594, 1.320411334745586, 0.35418983025010675, 0.6341731455177069, 0.1574365809210576, 1.8865314382128417, 0.6743719009682536, 0.9761786030139774, 0.29756063770037144, 0.09396837878739461, 0.21068514237413183, 0.0891963395406492, 0.06030061937053688, 0.03376951157406438, 0.23603092529810965, 0.1941012588213198, 0.047132177351159044, 0.06232343192095868, 0.1484131783945486, 0.12084261485142633, 0.2939604199491441, 0.12323887611273676, 0.058160020562354475, 0.08124255735310726, 0.04781767689564731, 0.5829608591739088, 1.8434854480437934, 0.08568389559513889, 0.03529988316586241, 0.04169935949903447, 0.03305039273982402, 0.048178895012824796, 0.03612780084949918, 0.09916001348756254, 0.09949433617293835, 0.11999845155514777, 0.1167087558133062, 0.10691570903873071, 0.038147882296470925, 0.12576351407915354, 0.04666767083108425, 0.018599745890242048, 0.043000837904401124, 0.16391575278248638, 0.41030204272828996, 0.2574185229605064, 0.4680962290149182, 0.568863971857354, 1.5750617953017354, 0.28341601544525474, 1.074879434891045, 9.452666323632002, 26.966301798820496, 36.86813347041607, 50.292140543460846, 64.93640273809433, 58.535706996917725, 60.17991676926613, 64.14633393287659, 56.04364112019539, 26.03736374527216, 18.704211339354515, 50.83299212157726, 58.86509232223034, 52.52160631120205, 31.376067772507668, 5.412408197298646, 0.3996630589244887, 0.2703976765042171, 0.21822033100761473, 0.028695590772258583, 0.18133513134671375, 0.1481063597020693, 0.06805217373766936, 0.23826312739402056, 0.086872177926125, 0.1304881597752683, 0.0744991512328852, 0.018455516910762526, 0.10587734053842723, 0.14858514885418117, 0.04277073130651843, 0.09030556830111891, 0.08635688995127566, 0.05051176201959606, 0.021065032451588195, 0.03927033241780009, 0.0385207669751253, 0.06908552531967871, 0.040192469459725544, 0.036756837798748165, 0.028286745327932294, 0.042724365630419925, 0.09287450506235473, 0.039187493894132785, 0.032535653954255395, 0.0102725539545645, 0.00834233174828114, 0.025308493713964708, 0.054131687502376735, 0.023155673588917125, 0.046286451834021136, 0.03974033454142045, 0.06400550963007845, 0.031187208733172156, 0.06037963954440784, 0.11223940891795792, 0.05786056397482753, 0.02845141676516505, 0.046734486386412755, 0.006827471970609622, 0.011072152210545028, 0.020003666650154628, 0.02199651498813182, 0.06838081899331883, 0.07213696197140962, 0.057781666255323216, 0.04104088897292968, 0.02304952791746473, 0.034985887905349955, 0.13328267232282087, 0.09414110623765737, 0.016277372851618566, 0.010522851607674966, 0.013621803336718585, 0.029001596813031938, 0.14370588411111385, 0.023458182258764282, 0.021680454701709095, 0.09386556906974874, 0.031777887779753655, 0.03041997832042398, 0.07839252473786473, 0.04283553564164322, 0.04648067188099958, 0.025782774318940938, 0.013253398446977371, 0.1292911052587442, 0.032789739343570545, 0.033784042825573124, 0.06201876174600329, 0.02885609690565616, 0.11055744995246641, 0.05700824076484423, 0.08003906099474989, 0.04010961238236632, 0.01677552834735252, 0.07694147017900832, 0.09001167039969005, 0.19510829384671524, 0.4257635318208486, 0.453839156543836, 0.8168253069743514, 0.1745889792800881, 0.13394125417107716, 0.20259735058061779, 0.3455556248081848, 0.6786878756247461, 3.313522422686219, 8.242280222475529, 50.7099699229002, 93.28366443514824, 92.86443293094635, 79.12243232131004, 61.289252042770386, 58.550662994384766, 63.1416792422533, 70.38398802280426, 96.2430976331234, 117.80636295676231, 118.92141312360764, 97.41100296378136, 94.47204306721687, 79.70976680517197, 57.498203068971634, 30.43699376285076, 13.873288314789534, 2.554982900619507, 0.5246176617220044, 0.04708153319370467, 0.38602870772592723, 1.4106276375241578, 5.1169351022690535, 1.4932591910474002, 0.3384097816888243, 0.10542293835896999, 0.1741889023105614, 0.061774365094606765, 0.1252009512973018, 0.07545542335719801, 0.07251101182191633, 0.04397934477310628, 0.15118910756427795, 0.06978938559768721, 0.15588142530759797, 0.15645724284695461, 0.2849999663885683, 0.22481524822069332, 0.04561638525046874, 0.056517473349231295, 0.19699369033332914, 0.9978601802140474, 2.096145646646619, 0.22518670797580853, 0.07867663371143863, 0.09109887221711688, 0.07728213822701946, 0.08554934422136284, 0.025718713986861985, 0.071437331935158, 0.019758564958465286, 0.05324196376022883, 0.09548865346005186, 0.03129831937258132, 0.023417816846631467, 0.08322017311002128, 0.028861186183348764, 0.03859526004816871, 0.02740667692705756, 0.16882284806342795, 0.1218887981667649, 0.12225508515257388, 0.630029171006754, 0.25557921384461224, 1.3344541937112808, 0.724277354311198, 1.160046758595854, 10.845337193459272, 36.771907433867455, 57.004890739917755, 79.31986212730408, 88.88489127159119, 78.08950334787369, 82.70693197846413, 88.31805288791656, 82.66321912407875, 56.689237877726555, 29.533744230866432, 37.9935646802187, 61.21782347559929, 77.32020422816277, 63.927982449531555, 15.568624343723059, 1.2218549544923007, 0.3548805619357154, 0.5020452104508877, 0.1640622378909029, 0.14916556770913303, 0.15011171693913639, 0.023535922227893025, 0.14114360441453755, 0.06541726746945642, 0.0951268564676866, 0.07149954617489129, 0.03715877755894326, 0.0666908077255357, 0.06107269415224437, 0.05258891833364032, 0.0738744781119749, 0.09963237564079463, 0.07733696809737012, 0.04161088065302465, 0.03391030812053941, 0.09937453127349727, 0.1712819395470433, 0.05093708685308229, 0.029943365516373888, 0.029868861311115324, 0.04672615948948078, 0.11038969489163719, 0.07739481108728796, 0.04654411066439934, 0.03950125908886548, 0.021267603515298106, 0.027726340340450406, 0.09973238746169955, 0.057358875856152736, 0.0393017363967374, 0.06572588215931319, 0.05237708712229505, 0.01850667871622136, 0.010150212765438482, 0.03935020977223758, 0.08810993924271315, 0.0633875974745024, 0.033358695727656595, 0.06182128367072437, 0.08180931326933205, 0.15162839961703867, 0.12066805429640226, 0.08116083205095492, 0.1327622783719562, 0.1766423534718342, 0.196010225918144, 0.13301198137924075, 0.08433217008132488, 0.17890976305352524, 0.12741770187858492, 0.1217127607378643, 0.16764611355029047, 0.10287114520906471, 0.11329617525916547, 0.3359324036864564, 0.166659576643724, 0.08430761241470464, 0.15801428351551294, 0.17336177872493863, 0.102029623958515, 0.19645224907435477, 0.1342446292983368, 0.12770293891662732, 0.1254131758469157, 0.1306744833709672, 0.22664624528260902, 0.15889674163190648, 0.0907931147958152, 0.18507604545447975, 0.12907444266602397, 0.2049694920424372, 0.14489207358565181, 0.2509357442613691, 0.15697082388214767, 0.10920688218902797, 0.11772219557315111, 0.15637391450582072, 0.37140813132282346, 0.45430477999616414, 0.4568265681155026, 0.763065138598904, 0.26597815740387887, 0.2790082816500217, 0.469991258578375, 0.20329642400611192, 0.3188546060118824, 2.3802934493869543, 2.755871945992112, 37.35489875078201, 114.543067663908, 117.48628333210945, 110.70056185126305, 97.4713285267353, 76.42745733261108, 64.1846738755703, 66.81162491440773, 85.28446286916733, 117.03471556305885, 133.51521402597427, 118.19059073925018, 122.01072335243225, 109.14100393652916, 75.84477379918098, 39.22821722924709, 16.990890875458717, 1.4416717342101038, 0.3318359859986231, 0.8110733656212687, 0.37829915061593056, 5.434781396761537, 10.471420157700777, 0.8974416030105203, 0.6775509647559375, 0.23969755042344332, 0.30145195545628667, 0.17571110656717792, 0.2589230047306046, 0.207555431406945, 0.2930136473150924, 0.4333965800469741, 0.14923672482836992, 0.17791703663533553, 0.26328950480092317, 0.28086495702154934, 0.45618882577400655, 0.20300899021094665, 0.11382759010302834, 0.2649355586618185, 0.5628224741667509, 1.1505570053122938, 6.56184509396553, 0.29412113944999874, 0.2929117949679494, 0.18645347154233605, 0.16634457948384807, 0.16488339460920542, 0.1498377011739649, 0.20630565471947193, 0.16455419274279848, 0.17591319337952882, 0.28487953066360205, 0.16113189747557044, 0.08854560219333507, 0.1986652592313476, 0.12054695806000382, 0.09802578919334337, 0.11607835331233218, 0.19602052692789584, 0.26101862196810544, 0.21137290546903387, 0.46646142611280084, 0.3420739428838715, 4.220927031710744, 0.8162588998675346, 0.7539977564010769, 10.323222409933805, 41.64160832762718, 76.42374873161316, 109.00845184922218, 106.42863348126411, 83.4580908715725, 94.51517075300217, 105.41945323348045, 77.9175853729248, 41.3320617377758, 37.15301178395748, 72.6236866414547, 88.00289019942284, 97.92509257793427, 56.797414273023605, 6.481142174452543, 0.6020399322733283, 0.6189497967716306, 0.6294338498264551, 0.12670007476117462, 0.28905630810186267, 0.4071214946452528, 0.14952945755794644, 0.2088816196192056, 0.13409931678324938, 0.31304483651183546, 0.12167906723334454, 0.1541411632206291, 0.2612172206863761, 0.2908255287911743, 0.2567960094893351, 0.12510061293141916, 0.10772905094199814, 0.23515088658314198, 0.14303851523436606, 0.08635472288005985, 0.2176770195364952, 0.3148284845519811, 0.14259376097470522, 0.19852258876198903, 0.10305918316589668, 0.13848493457771838, 0.19572610210161656, 0.15623286191839725, 0.1786705243284814, 0.16906193835893646, 0.20857417752267793, 0.10748099550255574, 0.1392575103091076, 0.10722121412982233, 0.14656089653726667, 0.1425535068847239, 0.15288936789147556, 0.16627572302240878, 0.114824353804579, 0.1446487382054329, 0.2070203874609433, 0.2308058345806785, 0.16080593137303367, 0.151697953697294], [0.0698222998471465, 0.060067314116167836, 0.06255830681766383, 0.020973223217879422, 0.030049511187826283, 0.06129275578132365, 0.020105839976167772, 0.019759952774620615, 0.04325296402384993, 0.028544099877763074, 0.04968326546077151, 0.08937895981944166, 0.06120843296230305, 0.024587241205153987, 0.033080223365686834, 0.05673213214322459, 0.025676778932393063, 0.028123649099143222, 0.03469223862339277, 0.051020634127780795, 0.03370903024915606, 0.034876513891504146, 0.15258759580319747, 0.12708441819995642, 0.03863534715492278, 0.04304994952690322, 0.0625620769278612, 0.03997129460913129, 0.015131313157326076, 0.1233948978187982, 0.027246901809121482, 0.10024627277744003, 0.10565471849986352, 0.0533769084722735, 0.10830647894181311, 0.03855392242257949, 0.030456651547865476, 0.024194342659029644, 0.026115865039173514, 0.009207080365740694, 0.21595991245703772, 0.21478712616954, 0.43067892431281507, 0.411160618532449, 0.08842738548992202, 0.21709633350837976, 0.11200708700926043, 0.03126813251583371, 0.16665932431351393, 1.4572523231618106, 3.60532158985734, 34.003664776682854, 79.3066768348217, 96.51389390230179, 93.64937961101532, 80.30276298522949, 57.21694976091385, 37.637934163212776, 55.833656787872314, 77.42746487259865, 99.690842628479, 98.89332622289658, 87.93807327747345, 88.83166372776031, 64.37654078006744, 40.24711735546589, 12.831112537533045, 5.708095980808139, 1.0068404045887291, 0.5934246664401144, 0.5785192537587136, 2.3672375874593854, 1.6944395145401359, 1.3720638630911708, 0.10192329646088183, 0.44694801850710064, 0.49270317424088717, 0.1923240823089145, 0.2233270343276672, 0.2819975931197405, 0.31819575699046254, 0.07280283170985058, 0.07793113894877024, 0.19427348161116242, 0.20842410041950643, 0.18092132464516908, 0.15422950848005712, 0.015739902082714252, 0.3760912612779066, 0.39013293280731887, 0.6241160945501179, 0.5862855026498437, 0.24413894803728908, 0.06605807488085702, 0.0476655663078418, 0.15929600223898888, 0.05177824816200882, 0.02643728363182163, 0.08316045990795828, 0.10332127261790447, 0.05074691151094157, 0.11536178746609949, 0.16135412617586553, 0.13754485611571, 0.22646386991254985, 0.23812842759070918, 0.16793707996839657, 0.015760309288452845, 0.3587306459667161, 0.7976535544730723, 0.5710112128872424, 0.4643906856654212, 1.998520572669804, 0.14699833322083578, 6.264769434928894, 30.72001587599516, 51.363584250211716, 63.12832675874233, 71.38690620660782, 71.4264240860939, 62.406665682792664, 72.5380240380764, 44.66392435133457, 27.75813940912485, 18.33135824650526, 37.9870518296957, 58.431201204657555, 55.905723720788956, 41.20177432894707, 8.26163923367858, 0.2799669583328068, 0.50233019515872, 0.23253163963090628, 0.07186572926002555, 0.054618718204437755, 0.05802666404633783, 0.11883129074703902, 0.025604113398003392, 0.18607684643939137, 0.12096990802092478, 0.08408357287407853, 0.010953858509310521, 0.0637171407288406, 0.06857125408714637, 0.029484562401194125, 0.0234287208513706, 0.03878621835610829, 0.019446172736934386, 0.07793694254360162, 0.0953522467170842, 0.056917631955002435, 0.062295386160258204, 0.07094193351804279, 0.04959829697327223, 0.018947666576423217, 0.010389501585450489, 0.11990885206614621, 0.08392148782149889, 0.05882925965124741, 0.016561992051720154, 0.10473002475919202, 0.0645702840120066, 0.0323878775088815, 0.06165299426356796, 0.08677091187564656, 0.11832112359115854, 0.047245996829587966, 0.015759669186081737, 0.03274897317169234, 0.07716329069808125, 0.017429332619940396, 0.008080637489911169, 0.06946741967112757, 0.06570864949026145, 0.028392313979566097, 0.007812223084329162, 0.03986471849202644, 0.02155909314751625, 0.015508237902395194, 0.022152579367684666, 0.015859345185162965, 0.03575720940716565, 0.023859318644099403, 0.08339196545421146, 0.0177886656820192, 0.021643111685989425, 0.10875380845391192, 0.04590378935972694, 0.10966493573505431, 0.07415644227876328, 0.027993634103040677, 0.09213671379256994, 0.06976649776333943, 0.0329916814371245, 0.011417361274652649, 0.015963392434059642, 0.033790711022447795, 0.04280394612578675, 0.04812740851775743, 0.15356224350398406, 0.046512936751241796, 0.051717061796807684, 0.06287961223279126, 0.03748446535610128, 0.037790181959280744, 0.029948426963528618, 0.04832655642530881, 0.032011304356274195, 0.08486346618155949, 0.04676068048866, 0.021901100772083737, 0.008253326905105496, 0.05815559736220166, 0.040200239745900035, 0.07135332823963836, 0.10636172548402101, 0.22776783822337165, 0.21396884898422286, 0.3813336737221107, 0.2304686323623173, 0.0993496025330387, 0.08290563608170487, 0.09415231266757473, 0.20193384087178856, 1.9020078890025616, 4.438373688608408, 18.143087849020958, 67.3611818253994, 101.31076410412788, 99.4936104118824, 78.38654860854149, 61.467067301273346, 62.51488767564297, 64.3926291167736, 78.60401093959808, 102.23701000213623, 109.90299984812737, 99.19276535511017, 91.05337411165237, 94.19737100601196, 87.12079033255577, 68.29533889889717, 28.67228865623474, 13.78513304516673, 2.123241755180061, 0.8820128871593624, 0.5378778220620006, 1.4052030723541975, 4.037834806367755, 1.1311034741811454, 0.24060736410319805, 0.23563824011944234, 0.3562503290595487, 0.24711387668503448, 0.27519254421349615, 0.24693107086932287, 0.26083047268912196, 0.058377967070555314, 0.11033517672331072, 0.19880665320670232, 0.4357427463401109, 0.30229553987737745, 0.2863002981757745, 0.034124336089007556, 0.6471105013042688, 0.3651874198112637, 1.6844435571692884, 5.949726440012455, 1.4147117058746517, 0.09291004651458934, 0.07720856912783347, 0.3835727629484609, 0.14162963692797348, 0.27182025485672057, 0.14292471430962905, 0.02069035548629472, 0.08781010415987112, 0.17085418046917766, 0.12685545079875737, 0.12336210973444395, 0.23981917358469218, 0.29939320811536163, 0.15628984401701018, 0.09035332550411113, 0.37515475996769965, 0.8235901908483356, 0.39674597326666117, 0.67194466246292, 1.7968093464151025, 0.8391631802078336, 11.230049449950457, 40.519547536969185, 64.25556287169456, 80.92342928051949, 95.00242620706558, 88.96802321076393, 74.31913286447525, 80.19099578261375, 70.02833470702171, 54.8030798882246, 38.61927330493927, 28.3730661123991, 47.091921865940094, 76.60337269306183, 71.8910251557827, 29.390258230268955, 1.8667062395252287, 0.40084912965539843, 0.23664934211410582, 0.06564194525708444, 0.03732420598680619, 0.06407739405403845, 0.20349545317003503, 0.021440356940729544, 0.12024285562802106, 0.06974375093705021, 0.039662416456849314, 0.08960050574387424, 0.08721787031390704, 0.08822444520774297, 0.06305651055299677, 0.16490962210809812, 0.016235556540777907, 0.04440294040250592, 0.017573682198417373, 0.0410526149062207, 0.03888804101734422, 0.02793144027236849, 0.05431238932942506, 0.04774531007569749, 0.08750875509576872, 0.04826168529689312, 0.11648717278148979, 0.014205858715286013, 0.02540692476031836, 0.034277110898983665, 0.0630849422304891, 0.0008428635521795513, 0.09956127789337188, 0.04705458210082725, 0.030726707955182064, 0.03486974921543151, 0.029410210336209275, 0.050298557835048996, 0.03178583618137054, 0.03113732898782473, 0.040063265259959735, 0.05295026632666122, 0.03325224948639516, 0.06466388367698528, 0.13616429816465825, 0.0018729736302702804, 0.13939529744675383, 0.153163131326437, 0.1508922633365728, 0.09457714768359438, 0.09984211399569176, 0.14020582661032677, 0.17322623287327588, 0.12108265509596094, 0.19512992003001273, 0.13621837104437873, 0.1968509456492029, 0.11188673292053863, 0.17715363384922966, 0.15495657571591437, 0.16330704325810075, 0.12214496528031304, 0.12036689819069579, 0.1235236604406964, 0.06628186209127307, 0.14513181697111577, 0.1826443985919468, 0.08847325763781555, 0.3980230016168207, 0.25493523746263236, 0.24618996219942346, 0.15951664274325594, 0.19489295227685943, 0.15226317336782813, 0.0958370250009466, 0.2041825928608887, 0.14621688140323386, 0.30954534304328263, 0.17131070519099012, 0.19338734244229272, 0.12388791394187137, 0.12507402920164168, 0.21422659687232226, 0.12136096047470346, 0.18517001619329676, 0.1447740275762044, 0.28788858326151967, 0.2896967518609017, 0.4014582250965759, 0.5497420916799456, 0.17644344305153936, 0.541771900607273, 0.3522868745494634, 0.17390241846442223, 1.3629678636789322, 1.848014211282134, 5.6238663755357265, 58.91770049929619, 124.15665820240974, 132.4019953608513, 110.90277940034866, 89.29963141679764, 77.76389881968498, 60.62628261744976, 71.84019148349762, 93.7769615650177, 119.27157953381538, 125.25882706046104, 108.627560287714, 114.9119670689106, 115.49983352422714, 87.23887279629707, 32.300546765327454, 14.200483057647943, 1.2897777347825468, 0.6620222073979676, 1.086040148511529, 5.5479853972792625, 7.696256646886468, 2.8317980468273163, 0.44155679061077535, 0.5748648592270911, 0.8746045909356326, 0.392689275322482, 0.5984900915063918, 1.0967935714870691, 0.7468265912029892, 0.14239827927667648, 0.20247741951607168, 0.19164829747751355, 1.0916760773397982, 0.3828396397875622, 0.26652045955415815, 0.08163467849954031, 0.6236354203429073, 0.7473932951688766, 1.0072975675575435, 4.07669342122972, 1.8313513929024339, 0.11375003567081876, 0.22715179627994075, 0.5555161787196994, 0.21714440983487293, 0.25448243832215667, 0.3138456732267514, 0.18539850861998275, 0.12633422564249486, 0.3109314671019092, 0.17079467506846413, 0.24626062950119376, 0.3891179716447368, 0.3074546536663547, 0.23822127026505768, 0.11955590889556333, 0.35323180665727705, 0.5044709052890539, 0.3557283023837954, 0.9538292116485536, 5.235832622274756, 0.34334120457060635, 7.0138531643897295, 43.83699752390385, 84.19072955846786, 113.18910151720047, 112.76923924684525, 94.33996215462685, 90.24373635649681, 107.02286839485168, 64.69306379556656, 39.4881346821785, 36.47112317383289, 55.9040480107069, 83.68583545088768, 95.04211127758026, 80.67434504628181, 17.392677515745163, 0.3764664911432192, 0.6185417936649173, 0.5068103328812867, 0.1379772016662173, 0.11302803730359301, 0.17483182484284043, 0.20473314769333228, 0.18725980015005916, 0.2388640443678014, 0.20120376051636413, 0.21204653807217255, 0.10991144008585252, 0.16223512968281284, 0.18459822109434754, 0.19601901294663548, 0.23903271969174966, 0.07283633967745118, 0.1367694156942889, 0.18769667280139402, 0.17447646969230846, 0.12635053804842755, 0.08393172203795984, 0.18158516089897603, 0.17923578852787614, 0.1393269159598276, 0.10307914693839848, 0.1948083474417217, 0.11100730276666582, 0.12303042167332023, 0.09465370763791725, 0.18845073936972767, 0.1221254096890334, 0.15952407906297594, 0.1602827469469048, 0.2548978035338223, 0.21405847073765472, 0.12213491660077125, 0.14374518825206906, 0.21589555341051891, 0.1692910393467173, 0.1239093545882497, 0.11019328550901264, 0.18514435272663832, 0.15656552219297737, 0.20617724832845852, 0.09584852086845785], [0.03841310361167416, 0.0694937733351253, 0.061393520882120356, 0.0415583514404716, 0.035091428726445884, 0.060483985507744364, 0.011975630732194986, 0.1041357648500707, 0.0464079191442579, 0.017116350391006563, 0.06419415614800528, 0.013992231506563257, 0.04970149260770995, 0.027524088400241453, 0.03258396034652833, 0.06517091154819354, 0.027524305478436872, 0.06370292117935605, 0.09420355796464719, 0.03920721275790129, 0.04582900684908964, 0.019584176952776033, 0.030871027847751975, 0.07053047942463309, 0.01508989482317702, 0.05640241448418237, 0.01662379439949291, 0.08006823481991887, 0.06803992087952793, 0.00939237423153827, 0.06453457186580636, 0.046088298404356465, 0.025424289160582703, 0.06715869472827762, 0.07460651031578891, 0.02383724902756512, 0.08050623553572223, 0.04594130121404305, 0.03995826991740614, 0.0506404949555872, 0.031621576636098325, 0.05336540889402386, 0.17315402190433815, 0.11426064811530523, 0.39209074806421995, 0.07262848637765273, 0.1882740785367787, 0.11519521242007613, 0.02598258273792453, 0.08570590769522823, 1.0339362756349146, 1.5237703663296998, 1.0139437671750784, 25.345464572310448, 84.05936300754547, 86.7336443066597, 90.0122831761837, 72.85029128193855, 51.24564237892628, 49.5769315212965, 50.822953060269356, 87.47151151299477, 97.82473996281624, 96.4559318125248, 101.11982434988022, 79.7363805770874, 56.2627487629652, 44.83515456318855, 27.47422244399786, 14.103884641081095, 3.580739996396005, 0.4388473281869665, 1.2660931306891143, 1.3341383356601, 1.2025509215891361, 1.0863486444577575, 0.36515954474452883, 0.21614586497889832, 0.37128820025827736, 0.5179664155002683, 0.595120859798044, 0.5393031612038612, 0.36259162472561, 1.0863260831683874, 2.9515077732503414, 2.7672537602484226, 0.3231917764060199, 0.3467353724408895, 0.6559820752590895, 0.4756337479921058, 0.8382307458668947, 6.672308491542935, 0.9567262593191117, 0.44460256467573345, 0.5103062640409917, 0.1877494395012036, 0.25275937921833247, 0.1130817539524287, 0.3576352063100785, 0.01691887046035845, 0.1340093684848398, 0.06658990532741882, 0.22795861470513046, 0.18877413764130324, 0.33163667481858283, 0.2737024304224178, 0.3266642556991428, 0.027359411396901123, 0.20503018487943336, 1.5981560060754418, 3.3191620325669646, 0.2643999655265361, 4.714214187115431, 21.366589777171612, 62.78969272971153, 86.13685593008995, 87.0126785337925, 78.2568995654583, 64.47240203619003, 59.90027837455273, 70.2876403927803, 35.38611799478531, 22.525299601256847, 34.67623248696327, 53.02397735416889, 57.85066835582256, 61.7509538680315, 20.870216712355614, 0.8173921296838671, 0.48789738211780787, 0.4014357825508341, 0.10527223043027334, 0.03242892569687683, 0.1001851272303611, 0.10478232390596531, 0.05037624214310199, 0.06530507700517774, 0.12927399133332074, 0.033843833953142166, 0.05538593191886321, 0.12893390958197415, 0.004776954583576298, 0.008654757366457488, 0.07080393115757033, 0.05520252867427189, 0.09451333782635629, 0.059147726351511665, 0.08829675265587866, 0.04298868152545765, 0.06804066302720457, 0.0551338280638447, 0.05940391572949011, 0.0370474220108008, 0.0848888921609614, 0.09865736428764649, 0.1451166474726051, 0.027305347794026602, 0.009295343061239691, 0.05229821537795942, 0.01742602078593336, 0.07184062240412459, 0.05455604012240656, 0.048414846023661084, 0.0014992592537055316, 0.04936536650347989, 0.0799880680278875, 0.06751762703061104, 0.03136342056677677, 0.053934268798911944, 0.04656769611756317, 0.03352059895405546, 0.08662251944770105, 0.02593676996184513, 0.03147211922623683, 0.0865168524615001, 0.008843151554174256, 0.006751423634341336, 0.03318960480100941, 0.036907720132148825, 0.09278302051825449, 0.04738285999337677, 0.052214089228073135, 0.09409314123331569, 0.07273791605257429, 0.010347890292905504, 0.02116516487149056, 0.028575338728842326, 0.08136877440847456, 0.043200779909966514, 0.012672823741013417, 0.024666328172315843, 0.01951943755557295, 0.06418389966711402, 0.011934009235119447, 0.027759759250329807, 0.03463432512944564, 0.012737719916913193, 0.024333280125574674, 0.09144856478087604, 0.038959068260737695, 0.03157538907544222, 0.038210712518775836, 0.022897528651810717, 0.054304340737871826, 0.025148369786620606, 0.06513120664749295, 0.029343318710743915, 0.026341722841607407, 0.03072487856115913, 0.0416492459771689, 0.13267897971672937, 0.10431490445625968, 0.10211339016677812, 0.04937380101182498, 0.020309431492933072, 0.045617665455210954, 0.024211007585108746, 0.11103193464805372, 0.18850755819585174, 0.14645508112153038, 0.3874908870784566, 0.07338061594055034, 0.1968479176866822, 0.12055040162522346, 0.004117190401302651, 0.19560127286240458, 1.3927104114554822, 6.376451617106795, 20.62551934272051, 67.2098359465599, 113.6332368850708, 104.69228625297546, 80.32329708337784, 59.25586335361004, 62.140706554055214, 66.74838870763779, 83.18988606333733, 111.97923883795738, 101.76666364073753, 96.6982752084732, 105.3225128352642, 91.045683324337, 73.34934130311012, 68.69647577404976, 48.83773818612099, 27.243221439421177, 8.727436289191246, 1.2565495865419507, 1.5960574499331415, 2.5995212607085705, 1.8099201866425574, 1.6273417649790645, 0.6762940634507686, 1.060815320815891, 0.7041363569442183, 1.392548088915646, 1.3079354166984558, 1.6874956246465445, 2.202038364484906, 0.7366245542652905, 4.904175493866205, 5.250186827033758, 1.6731502069160342, 0.8714856114238501, 2.4174160324037075, 5.767340026795864, 5.007534697651863, 3.713630740530789, 0.5687138205394149, 0.2448961464688182, 0.6153011019341648, 0.43682910210918635, 0.5058109271340072, 0.49165974429342896, 0.08960152248619124, 0.2690964541397989, 0.2705453638918698, 0.28586076863575727, 0.6329547765199095, 0.578946255845949, 0.858509010868147, 0.6619932933244854, 0.07518036116380244, 0.022017367482476402, 0.15514347818680108, 1.2286780821159482, 2.657940750941634, 2.9104326898232102, 10.037730429321527, 38.78615275025368, 87.09636524319649, 100.8214795589447, 92.00545862317085, 84.25471052527428, 77.17328131198883, 72.00957119464874, 88.13301041722298, 71.36786922812462, 43.27732555568218, 32.95639157295227, 41.151282638311386, 72.69215896725655, 84.81720194220543, 50.44980548322201, 6.212187856435776, 1.2329521402716637, 0.4615594516508281, 0.28530163457617164, 0.04694996154285036, 0.10002186958445236, 0.1534843328408897, 0.05837607088324148, 0.1492729119490832, 0.09492120734648779, 0.04728680753032677, 0.03796365897869691, 0.0368807913037017, 0.011804754012700869, 0.03731370459718164, 0.0629118288634345, 0.18680851499084383, 0.07607119070598856, 0.06747668274329044, 0.06569266362930648, 0.07510846931836568, 0.1046301465248689, 0.048670159667381085, 0.034103151483577676, 0.02656955475686118, 0.012568062174977968, 0.04248508237651549, 0.037783836596645415, 0.08791374508291483, 0.04605857167916838, 0.03551404472091235, 0.03675620326248463, 0.03363405849086121, 0.10416127246571705, 0.08911481461836956, 0.0450898760027485, 0.012140235376136843, 0.03415096434764564, 0.04688586595875677, 0.10875671767280437, 0.015356232142949011, 0.0337236060295254, 0.0246400450123474, 0.034633341783774085, 0.036084904713789, 0.013544128305511549, 0.028076346461602952, 0.05659743976138998, 0.14507133193546906, 0.12852736108470708, 0.09150832251179963, 0.11775780381867662, 0.20976199972210452, 0.16490341775352135, 0.23977877106517553, 0.25938714388757944, 0.14640471898019314, 0.09008601133245975, 0.14057033986318856, 0.11293705741991289, 0.15610693430062383, 0.1685109085519798, 0.08611609271611087, 0.12530442152637988, 0.11068712541600689, 0.1375472013023682, 0.22328685445245355, 0.14225543069187552, 0.10751196532510221, 0.15308152476791292, 0.22878242831211537, 0.22502542444271967, 0.13009934860747308, 0.09931564185535535, 0.09637776121962816, 0.20646831864723936, 0.12733603594824672, 0.14408504735911265, 0.1342133106663823, 0.15429630177095532, 0.1806037299684249, 0.1479511320940219, 0.25847382727079093, 0.25705047708470374, 0.1387373241595924, 0.15028765046736225, 0.13937782729044557, 0.13169480283977464, 0.08152799477102235, 0.3563365072477609, 0.24700899637537077, 0.1911708590341732, 0.6491295585874468, 0.21476046822499484, 0.298432512790896, 0.43429264915175736, 0.08784350080532022, 0.18560947151854634, 1.2033897265791893, 1.830473521258682, 6.513710226863623, 50.85929811000824, 130.5524978041649, 132.90701866149902, 114.68891143798828, 87.47338101267815, 73.65695759654045, 75.14527693390846, 72.0709303021431, 115.16143888235092, 126.89658477902412, 125.00456750392914, 142.18616634607315, 113.12358543276787, 86.92326933145523, 79.14358198642731, 51.82638421654701, 27.08483263850212, 7.167735882103443, 0.8750421018339694, 9.797969944775105, 8.194339144974947, 2.354091005399823, 1.614631328266114, 0.44314026657957584, 0.9356847102753818, 1.0407577408477664, 1.9830415095202625, 1.012239083647728, 1.227707234211266, 1.7201314796693623, 1.6488170251250267, 6.339653441682458, 3.7915405724197626, 0.6832824822049588, 0.39253440394531935, 1.125197047367692, 4.555382709950209, 2.341512255370617, 10.259048603475094, 2.8408028511330485, 0.9222586650867015, 1.510605972725898, 0.8909381926059723, 0.49300932500045747, 0.4849751607980579, 0.5112531257327646, 0.4091226513264701, 0.2548836136702448, 0.26564062864053994, 0.3345264494419098, 0.3230355097912252, 0.6833244580775499, 0.5818081554025412, 0.4511127434670925, 0.12217159353895113, 0.6652773858513683, 2.531041572801769, 4.961018543690443, 1.518003463279456, 6.37133376672864, 41.158946827054024, 103.27383756637573, 123.79644513130188, 108.66707816720009, 94.92434039711952, 81.93372666835785, 89.48474988341331, 96.96016475558281, 57.72568166255951, 42.13408850133419, 59.79891501367092, 78.51557448506355, 96.51171281933784, 108.61590251326561, 39.29234258830547, 1.3440990261733532, 0.8205679873935878, 0.7170399301685393, 0.24606740393210202, 0.16428391740191728, 0.18958137166919187, 0.30293185729533434, 0.15427856444148347, 0.13348866283195093, 0.2750395133625716, 0.19041464023757726, 0.1480626323609613, 0.18257036193972453, 0.24029463791521266, 0.06694275201880373, 0.15004508692072704, 0.33713233773596585, 0.13160504749976099, 0.17181529139634222, 0.15600187587551773, 0.212996783957351, 0.21897375932894647, 0.18806034000590444, 0.1381486377795227, 0.16077603766461834, 0.1288536685751751, 0.2158203738508746, 0.21960250684060156, 0.17374316841596738, 0.18041765870293602, 0.11374941226677038, 0.08104476015432738, 0.24650521168950945, 0.25071672163903713, 0.1994545481284149, 0.1256793545326218, 0.10449386594700627, 0.21153993322513998, 0.18016952904872596, 0.2309690328547731, 0.08146086009219289, 0.16835194051964208, 0.12126452580559999, 0.1256674059550278, 0.17878407292300835, 0.16029989055823535, 0.2111110312398523, 0.10744941711891443], [0.03820707970589865, 0.06967113178689033, 0.06585036258911714, 0.031479447934543714, 0.07957512221764773, 0.1393222255865112, 0.12988810369279236, 0.033783193066483364, 0.027442107057140674, 0.024996671090775635, 0.05177806262508966, 0.07770183015963994, 0.03492453455692157, 0.020026855054311454, 0.07184059271821752, 0.02599899162305519, 0.015495653860853054, 0.046514324567397125, 0.06688154709991068, 0.053724537865491584, 0.0201075821678387, 0.025238403432013, 0.008656086738483282, 0.037237716096569784, 0.044370987234287895, 0.05883518941118382, 0.019610653071140405, 0.00326035980378947, 0.027948203533014748, 0.07343441422563046, 0.0773118315555621, 0.0612795975030167, 0.06647205227636732, 0.08604364425991662, 0.028208530384290498, 0.0493947555514751, 0.018027564874500968, 0.04045120811497327, 0.050877347675850615, 0.031616411288268864, 0.009383717078890186, 0.05119763263792265, 0.04356670324341394, 0.012001881423202576, 0.03376361150003504, 0.21703295409679413, 0.12440764738130383, 0.06729527216521092, 0.08803159813396633, 0.15763914270792156, 0.08859174893586896, 0.029340721193875652, 0.7827201182954013, 1.383971949107945, 1.864022989757359, 20.792379789054394, 71.29330962896347, 97.85698503255844, 79.1963079571724, 64.11123901605606, 55.816181525588036, 44.33448202908039, 43.08447830379009, 50.85196830332279, 72.31574356555939, 95.77038019895554, 89.71668183803558, 93.28048780560493, 85.8290496468544, 65.82804769277573, 42.734748870134354, 23.071776777505875, 8.256193175911903, 0.6319217663258314, 1.3776654750108719, 1.3632650789804757, 0.9284928836859763, 0.749027623096481, 0.6233471108134836, 2.1823290595784783, 1.194168571382761, 0.7113645190838724, 4.17744786478579, 0.7393985241651535, 0.9755686763674021, 3.203749875538051, 3.6659430619329214, 6.0855587013065815, 6.527679702267051, 5.780690610408783, 8.21619937196374, 2.524499036371708, 0.1941149143385701, 0.2809339767554775, 0.2728572429623455, 0.2901123248739168, 0.5500414443667978, 0.7542689074762166, 0.9719375555869192, 0.6223442021291703, 1.9350912887603045, 1.7567185289226472, 2.845823331736028, 1.9243060424923897, 0.8856206154450774, 1.330682896077633, 0.36727781232912093, 1.424774753395468, 1.2524404632858932, 0.8148279797751456, 7.290243208408356, 16.935632340610027, 32.3148187994957, 62.453555166721344, 84.40259099006653, 96.27995565533638, 84.15067970752716, 74.0051557123661, 51.94906443357468, 47.05773890018463, 37.89853557944298, 44.16140131652355, 52.04094350337982, 61.54168389737606, 57.04218193888664, 39.288956969976425, 3.8437362341210246, 0.3064521012129262, 0.5368284846190363, 0.25956683268304914, 0.02004245870921295, 0.02317065383977024, 0.2517112292116508, 0.13964877056423575, 0.05746161506976932, 0.0353728103073081, 0.02476686320733279, 0.02219958700152347, 0.012333452596067218, 0.09987361816456541, 0.06831372884334996, 0.03662365568743553, 0.04296564526157454, 0.07783099354128353, 0.027177408956049476, 0.03362369068781845, 0.06580323621165007, 0.02733660705416696, 0.07796714795404114, 0.04979204946721438, 0.04861044275457971, 0.007327708726734272, 0.04215742417727597, 0.023771162632328924, 0.07722810245468281, 0.04276645282516256, 0.06361264633596875, 0.013044618390267715, 0.04508187194005586, 0.009791607008082792, 0.047188858879962936, 0.14547017693985254, 0.05242104081844445, 0.11805945716332644, 0.0726917025167495, 0.023011442754068412, 0.10353371239034459, 0.0649877791875042, 0.035967511794297025, 0.04866626339207869, 0.07011239795247093, 0.073762643878581, 0.044325174458208494, 0.10197108334978111, 0.09518792037852108, 0.029515079513657838, 0.03809280380664859, 0.0753866411105264, 0.08207847538869828, 0.02273949943628395, 0.04508646954491269, 0.007572987142339116, 0.08629772593849339, 0.027955821678915527, 0.05836204429215286, 0.04578548359859269, 0.10877642169361934, 0.0028653006802414893, 0.041491157389828004, 0.03070929531531874, 0.1634068027487956, 0.08841177070280537, 0.0160142388267559, 0.04657075747672934, 0.03891437612765003, 0.006521960849568131, 0.08862112314091064, 0.08596330677391961, 0.0402027259406168, 0.004393042054289253, 0.057569330383557826, 0.008338049556186888, 0.07520731596741825, 0.06281153502641246, 0.030353194306371734, 0.03698396838444751, 0.06758516989066266, 0.06873588470625691, 0.02951179922092706, 0.028938065261172596, 0.044400984843377955, 0.08322115274495445, 0.01725708571029827, 0.062404556083492935, 0.07866511557949707, 0.13135990127921104, 0.03751117896172218, 0.09209641517372802, 0.005789056622234057, 0.01995745682506822, 0.10897147294599563, 0.12851760926423594, 0.12961524567799643, 0.1005162661022041, 0.10622136309393682, 0.1149410119978711, 0.1336609004647471, 0.13056445255642757, 0.6873005884699523, 4.077381659299135, 16.736933402717113, 55.07529728114605, 100.2256791293621, 104.2667318880558, 76.85060262680054, 68.85143905878067, 62.1966927498579, 70.2146615087986, 88.23914632201195, 99.79645416140556, 98.49240973591805, 96.96500569581985, 87.53904148936272, 87.38027840852737, 89.77545708417892, 87.04844981431961, 70.45667812228203, 48.5252695530653, 26.147407740354538, 6.433518854901195, 2.819367963820696, 1.3294954597949982, 2.0929941907525063, 2.5563465524464846, 0.5185980128590018, 0.8791203517466784, 0.2882637537550181, 1.5224859165027738, 0.857296638423577, 0.5914235988166183, 0.4327571456087753, 0.9126432810444385, 1.9522111513651907, 4.753051428124309, 7.1683737728744745, 7.982702851295471, 5.805878508836031, 1.30227395799011, 0.38274253718554974, 0.3151847154367715, 0.4786819563014433, 0.3375477920053527, 0.6994238973129541, 1.503345393575728, 1.091058966703713, 1.097633563913405, 1.997584872879088, 1.5491554979234934, 1.8189683323726058, 1.554731223732233, 1.0881939204409719, 0.96100969822146, 0.9030984900891781, 1.8134307232685387, 2.1414389787241817, 2.526294202543795, 15.499803386628628, 35.25674253702164, 59.93026256561279, 86.86624199151993, 94.21580761671066, 98.76359358429909, 91.38536229729652, 90.0831949710846, 71.40179380774498, 80.66167652606964, 66.94644927978516, 44.065722450613976, 42.81948432326317, 71.39971151947975, 86.6520094871521, 71.75178542733192, 18.739868625998497, 1.3069993606768548, 0.20240520854713395, 0.41038382740225643, 0.09937433831510134, 0.06347058442770503, 0.20851560722803697, 0.11266972840530798, 0.03365869779372588, 0.08034153812332079, 0.07563007296994328, 0.011943037461605854, 0.019847808216582052, 0.06130054833192844, 0.04790528371813707, 0.04186772683169693, 0.058982394402846694, 0.06929173847311176, 0.085901738202665, 0.06042892186087556, 0.04082149527675938, 0.04104258106963243, 0.0491623037669342, 0.04595100850565359, 0.08785282960161567, 0.021298102074069902, 0.04022106440970674, 0.05318096293194685, 0.011776731444115285, 0.025919134677678812, 0.09845080974628218, 0.021261120855342597, 0.011697209392877994, 0.036336366611067206, 0.04418201788212173, 0.0728977301332634, 0.04551951271423604, 0.034336831522523426, 0.029200995195424184, 0.03976210915425327, 0.07428242184687406, 0.0425113506935304, 0.06134047216619365, 0.04069735994562507, 0.040469758096151054, 0.06257831511902623, 0.06422471778932959, 0.07302860045456327, 0.03164502850268036, 0.05172171506274026, 0.14710202609421685, 0.17322228464763612, 0.31131144671235234, 0.11287518456811085, 0.15691002714447677, 0.25185075297486037, 0.205983221239876, 0.08728841145057231, 0.12417317324434407, 0.15436738467542455, 0.15086014318512753, 0.11863376072142273, 0.12123240565415472, 0.0734080457186792, 0.23331478354521096, 0.23059767700033262, 0.11762366062612273, 0.157461324124597, 0.14058862638194114, 0.1363630304695107, 0.148293930105865, 0.1525795806082897, 0.14251089276513085, 0.14668076822999865, 0.19013395998626947, 0.19789315847447142, 0.11148900113767013, 0.16060531401308253, 0.12839853909099475, 0.2301291294861585, 0.2032161533134058, 0.23348742193775252, 0.15105687169125304, 0.27997921861242503, 0.1454678169102408, 0.160538817581255, 0.1767149503575638, 0.13689850486116484, 0.2165620168671012, 0.1951696100877598, 0.18552790948888287, 0.19391925452509895, 0.15577942453091964, 0.1483943426865153, 0.16489071218529716, 0.41928482009097934, 0.4692440642975271, 0.13126750389346853, 0.30699321592692286, 0.5975219747051597, 0.15862618427490816, 0.13631578534841537, 1.5531264035962522, 1.1640256200917065, 4.191961186006665, 38.6820687353611, 108.52168276906013, 137.26334810256958, 108.34316834807396, 89.44231376051903, 84.32015061378479, 71.7619688808918, 74.7270941734314, 82.734434902668, 93.67859244346619, 118.6223691701889, 111.51255548000336, 112.12684571743011, 112.72856622934341, 101.06685519218445, 78.41003134846687, 46.26339912414551, 21.59255225211382, 2.9123594239354134, 3.0386793706566095, 7.0147608406841755, 5.696164621040225, 4.924895307049155, 3.7757353205233812, 5.77993112616241, 5.2413057535886765, 9.259847570210695, 7.973447497934103, 0.7015319529455155, 0.87868842179887, 3.5945014329627156, 6.0275776125490665, 7.308980002999306, 9.102016389369965, 20.947652757167816, 31.511726193130016, 7.156807668507099, 0.9910897153895348, 1.1286761169321835, 1.2370820436626673, 1.1691429954953492, 2.4596633529290557, 3.1969040678814054, 2.1319335512816906, 2.952713971026242, 3.874954883940518, 3.306678752414882, 5.342631591483951, 5.244634849950671, 4.383768243715167, 2.7839569514617324, 2.7320975717157125, 2.3798279743641615, 2.0897774258628488, 0.9151026397012174, 12.32855150476098, 40.21530166268349, 74.40137565135956, 103.7701441347599, 114.37276840209961, 120.29165759682655, 106.13927900791168, 98.75576600432396, 76.43036037683487, 80.20454585552216, 71.68722689151764, 70.01518741250038, 71.9227534532547, 93.89299213886261, 112.26375997066498, 73.41725885868073, 6.747550154104829, 0.30743654526304454, 0.34352653368841857, 0.6583142594899982, 0.13202663190895692, 0.1095639294362627, 0.3183147084200755, 0.28694023727439344, 0.1790809171507135, 0.09915261427522637, 0.2510944748064503, 0.1606619992526248, 0.1714565372094512, 0.09556384044117294, 0.16921989707043394, 0.16630134196020663, 0.2200102576171048, 0.2625708980485797, 0.2084661356639117, 0.14383846137207001, 0.12040001282002777, 0.12842742347856984, 0.1636436369153671, 0.180232418642845, 0.2677017805399373, 0.13100534764816985, 0.09456940708332695, 0.1218366326065734, 0.10757838012068532, 0.19263388443505391, 0.3076370735652745, 0.13815650454489514, 0.15037354663945735, 0.1574690721463412, 0.1559772514156066, 0.2388853588490747, 0.14400915533769876, 0.24190465308493003, 0.23484449833631516, 0.06895062513649464, 0.28639131516683847, 0.29566118493676186, 0.11685585690429434, 0.16989535535685718, 0.2701419621007517, 0.16273119603283703, 0.13691781554371119, 0.16688845498720184, 0.17833059100667015, 0.08741430938243866], [0.02470710733177839, 0.05699419562006369, 0.07913967448985204, 0.03930932856746949, 0.057886795184458606, 0.12580592039739713, 0.09533178570563905, 0.06346138921799138, 0.07156800929806195, 0.025420583988307044, 0.01613175234524533, 0.04100825302884914, 0.04652674440876581, 0.04047582144266926, 0.058502915053395554, 0.027612797312031034, 0.023781250274623744, 0.039764895918779075, 0.0502408372994978, 0.013366531438805396, 0.024206591806432698, 0.02080273519823095, 0.040706941072130576, 0.09805390916881151, 0.03846763291221578, 0.01876554910268169, 0.015683281781093683, 0.10230541345663369, 0.05390775186242536, 0.027315828774590045, 0.012140883827669313, 0.034886807479779236, 0.048464191422681324, 0.05697074004274327, 0.020207425150147174, 0.06685014683171175, 0.027630170989141334, 0.026085294121003244, 0.07512461845180951, 0.08496259484672919, 0.054595377660007216, 0.043609925924101844, 0.1079869175737258, 0.04584546768455766, 0.0900132957031019, 0.06497957103420049, 0.05787052730738651, 0.07310484870686196, 0.1377105776919052, 0.0389198049379047, 0.09872737107798457, 0.052790767658734694, 0.04135035342187621, 0.04769472900079563, 0.16937133972533047, 1.3309765490703285, 2.664726236835122, 22.450760900974274, 58.341199234128, 90.2798344194889, 77.28151470422745, 63.58622118830681, 54.68617156147957, 45.37462301552296, 33.55886824429035, 52.46784299612045, 80.87558224797249, 89.06572356820107, 105.89089393615723, 114.18738394975662, 90.87716996669769, 55.133099779486656, 33.01041707396507, 23.973833173513412, 23.254676163196564, 14.188345558941364, 4.660640386864543, 1.1418502475135028, 0.3859473089687526, 0.4220430861460045, 0.7116016501095146, 0.4849503730656579, 0.9220635099336505, 1.286378817167133, 0.5074020323809236, 0.7153570954687893, 0.7200358912814409, 0.4293859249446541, 1.9781142426654696, 3.460995596833527, 1.371839556377381, 1.1367477150633931, 0.7217286410741508, 0.7582074555102736, 0.3931347420439124, 0.13368258601985872, 0.1472958008525893, 0.3129957360215485, 0.2585638052551076, 0.1328451614244841, 0.6054627173580229, 0.6420443044044077, 0.6432487803976983, 0.23882640263764188, 0.2910626004450023, 1.3994089770130813, 3.9778934977948666, 6.774139702320099, 16.602468118071556, 26.357215382158756, 42.984562665224075, 65.12304112315178, 82.03760549426079, 101.96860760450363, 107.39455685019493, 81.21939539909363, 57.08573900163174, 43.137998431921005, 46.4739116281271, 48.263463601469994, 53.99425148963928, 60.46177804470062, 65.95825910568237, 51.9311635941267, 9.962061289697886, 0.08365303074242547, 0.28862126113381237, 0.3353228629566729, 0.0824444877798669, 0.09580799960531294, 0.24016399023821577, 0.18484543048543856, 0.044984298074268736, 0.1263092301087454, 0.06855330895632505, 0.04319555519032292, 0.01023108552544727, 0.11482438349048607, 0.050505843391874805, 0.054770773131167516, 0.07002090598689392, 0.05710605953936465, 0.06158669821161311, 0.08137196564348415, 0.026725159004854504, 0.014073301863390952, 0.04238468834955711, 0.036226083466317505, 0.05354277847800404, 0.07108508638339117, 0.0603115474950755, 0.06678802164969966, 0.07191301890998147, 0.008461938123218715, 0.02280850432725856, 0.03275405317253899, 0.02880392763472628, 0.008602488833275856, 0.04719602431578096, 0.019407030013098847, 0.01000394102447899, 0.1696173765230924, 0.04389903326227795, 0.10685181012377143, 0.024557032083976083, 0.041388414465473033, 0.06109575639129616, 0.020092390404897742, 0.027080376858066302, 0.035140673935529776, 0.024196062586270273, 0.08798614901024848, 0.010106516965606716, 0.006260680802370189, 0.10591997692245059, 0.053857200473430566, 0.07968069272465073, 0.07268400644534267, 0.030645674705738202, 0.09457557433051988, 0.02544083534303354, 0.17051947186701, 0.054969817138044164, 0.021924187130935024, 0.020573849433276337, 0.009754743605299154, 0.012139750197093235, 0.043769910698756576, 0.02874880090530496, 0.05540129066503141, 0.07006720858043991, 0.08398451842367649, 0.0575981739530107, 0.04738629242638126, 0.033347014323226176, 0.046660156585858203, 0.03920159098925069, 0.022045316763978917, 0.0342665909556672, 0.001344015875019977, 0.09202976289088838, 0.024529917718609795, 0.02846187177055981, 0.033995358244283125, 0.024498727107129525, 0.02075511158182053, 0.03007723411428742, 0.09325947190518491, 0.06981015831115656, 0.07566243060864508, 0.038797272645751946, 0.04075207849382423, 0.04392476723296568, 0.06279642489971593, 0.043961933988612145, 0.034047494118567556, 0.10976772318826988, 0.06735810238751583, 0.06894593476317823, 0.03057063244341407, 0.061220088391564786, 0.06223349104402587, 0.12956382968695834, 0.10188797765295021, 0.01905152643303154, 0.057423817488597706, 0.18615723587572575, 0.09090634426684119, 0.20672195503721014, 0.2289216997451149, 0.43949611368589103, 4.659157516434789, 12.040569707751274, 54.6733358502388, 91.32331922650337, 96.65783017873764, 84.14508640766144, 63.52945603430271, 56.74281880259514, 53.97441275417805, 66.61223441362381, 90.4312638938427, 103.85758504271507, 107.62771993875504, 108.01148414611816, 118.65668132901192, 108.2232391834259, 83.85910615324974, 67.43702575564384, 51.75524063408375, 49.18234929442406, 33.58855605125427, 13.294268734753132, 3.044229685328901, 2.231569904834032, 3.681633132509887, 2.063788245432079, 1.8413346447050571, 2.6637506391853094, 4.358651591464877, 3.3177689323201776, 1.8606859375722706, 2.475709654390812, 2.1883125510066748, 6.279907347634435, 6.531140366569161, 2.5677979504689574, 6.45340271294117, 4.99125019647181, 4.153136294335127, 2.5851620687171817, 1.433715911116451, 0.9508428093977273, 0.8653043524827808, 1.3342197937890887, 1.9334044167771935, 1.4791402174159884, 1.1291900393553078, 1.3847709749825299, 0.9202004817780107, 0.6894582195673138, 3.951995512470603, 9.988600015640259, 19.28445540368557, 35.7209712266922, 51.25853508710861, 69.53117698431015, 92.29255601763725, 102.09079384803772, 98.28849747776985, 99.09517139196396, 90.64173460006714, 84.20004665851593, 73.36309656500816, 63.838938027620316, 58.706447035074234, 61.0631337761879, 70.76572313904762, 81.67457297444344, 77.31613084673882, 33.06926071643829, 0.5871890229173005, 0.4217713116668165, 0.3794792841654271, 0.04131626286834944, 0.07791346099111252, 0.16059251938713714, 0.1844895409885794, 0.06603947666008025, 0.05615174668491818, 0.087107884028228, 0.039819955854909495, 0.04277766667655669, 0.03621012358053122, 0.020337354799266905, 0.046792841458227485, 0.016555936126678716, 0.06331490410957485, 0.04426817380590364, 0.0819401687476784, 0.009818585003813496, 0.05667141333105974, 0.010577304838079726, 0.02910361985414056, 0.05787912508822046, 0.06907425209647045, 0.0532616009877529, 0.04809483565622941, 0.05987837816064712, 0.015271180163836107, 0.0659620929218363, 0.08045427777688019, 0.08739488737774082, 0.02819565597746987, 0.03147313225781545, 0.01807615513826022, 0.014413139633688843, 0.11480873159598559, 0.04651595729228575, 0.09678452493972145, 0.03395829538931139, 0.0606474435335258, 0.07507168847951107, 0.04244151459715795, 0.06842390066594817, 0.05386451433878392, 0.05141176450706553, 0.08524280754500069, 0.055874636163935065, 0.05166751972865313, 0.013072317196929362, 0.0075909800489171175, 0.16262521734461188, 0.13434219203190878, 0.13370911037782207, 0.23764211306115612, 0.2742477605352178, 0.29827209014911205, 0.1847101963358, 0.13324768748134375, 0.10756204545032233, 0.18134820798877627, 0.06421547062927857, 0.2072677601245232, 0.11736196451238357, 0.21155271300813183, 0.16837018250953406, 0.17049092886736616, 0.10963655600789934, 0.15281521249562502, 0.1558493496850133, 0.19789415295235813, 0.23007223644526675, 0.12105995279853232, 0.17349483096040785, 0.13500516739441082, 0.14761971862753853, 0.09125510172452778, 0.13478224107529968, 0.17853244033176452, 0.06540098474943079, 0.13406262500211596, 0.1372770595480688, 0.2055682271020487, 0.24072621163213626, 0.11240824751439504, 0.1644563183072023, 0.11449820958659984, 0.09792626718990505, 0.12882818322395906, 0.17849769297754392, 0.15419900621054694, 0.1314664736855775, 0.2023750773514621, 0.16611104045296088, 0.11614847884629853, 0.23829633108107373, 0.27921495493501425, 0.16353636689018458, 0.43395274551585317, 0.25829541496932507, 0.22207992937183008, 0.4071387421572581, 0.3652246162528172, 0.19232667982578278, 0.09567793822498061, 0.5537010636180639, 1.417629118077457, 2.48217168264091, 31.88034251332283, 98.86869594454765, 136.39871209859848, 116.0108833014965, 98.30276191234589, 84.93770107626915, 74.31483909487724, 69.24990847706795, 89.61822912096977, 107.33786389231682, 114.57069978117943, 118.6093282699585, 138.54868233203888, 132.446848154068, 104.71399068832397, 87.29342266917229, 61.84025287628174, 46.717778742313385, 26.14144016057253, 6.329305171966553, 0.7147842168342322, 0.698374678613618, 1.80781937437132, 0.9373540082015097, 0.4951988090761006, 1.287343727890402, 1.9420132110826671, 1.1763108358718455, 0.5965646635740995, 0.588640010682866, 0.46822874690406024, 1.8956555798649788, 2.5490224454551935, 0.574103593826294, 2.7769330283626914, 1.97794942650944, 2.8443430736660957, 1.315099576022476, 1.0364366602152586, 0.34769081335980445, 0.39703944814391434, 0.8295573550276458, 1.6243356512859464, 1.3059221184812486, 1.0006130137480795, 1.010758588090539, 0.3181589167797938, 0.27635706297587603, 1.6742769652046263, 6.823614947497845, 17.18838907778263, 37.54663646221161, 58.23304943740368, 86.33315339684486, 120.32660812139511, 127.83989936113358, 125.49502238631248, 116.13200560212135, 100.02899408340454, 83.42077687382698, 71.78017750382423, 73.76482620835304, 76.12376242876053, 80.65693438053131, 96.24261885881424, 114.55344870686531, 91.2068022787571, 19.999288246035576, 0.15591529692756012, 0.30495768296532333, 0.5851919925771654, 0.3307010343996808, 0.25589542812667787, 0.44377542624715716, 0.3270242566941306, 0.11980216091615148, 0.34764349402394146, 0.24140912108123302, 0.16527578292880207, 0.10461733705596998, 0.24864837090717629, 0.0957861433562357, 0.2365216036560014, 0.08866406380548142, 0.16610186750767753, 0.26167456177063286, 0.13081578828860074, 0.1537122018635273, 0.0994950560561847, 0.12696178571786731, 0.12249335908563808, 0.322194448672235, 0.16561987227760255, 0.18405073875328526, 0.1724746747640893, 0.12203503094497137, 0.19324988184962422, 0.14219925011275336, 0.10446061030961573, 0.11676156704197638, 0.06614155165152624, 0.11548806389328092, 0.1391576766036451, 0.08561193695641123, 0.24075604596873745, 0.16291656967950985, 0.2420039227581583, 0.16883338656043634, 0.1231890483177267, 0.12228851148393005, 0.16504185798112303, 0.21651944727636874, 0.14231340726837516, 0.11440491420216858, 0.14996779966168106, 0.08988224726635963, 0.11216261889785528, 0.24240876431576908, 0.17254028061870486], [0.06284143615630455, 0.0435513741831528, 0.04100553305761423, 0.03670461657748092, 0.09594799092155881, 0.07131826918339357, 0.08220838833949529, 0.0497301654831972, 0.0297380225310917, 0.02133435042196652, 0.0395066990313353, 0.0840101670473814, 0.0892573143937625, 0.024914335372159258, 0.03841216108412482, 0.038989477761788294, 0.034846434646169655, 0.025885517243295908, 0.037018749135313556, 0.05642224467010237, 0.037168677808949724, 0.043230859155301005, 0.017866147754830308, 0.08685919034178369, 0.024437583415419795, 0.06616751197725534, 0.0511343905236572, 0.05472386568726506, 0.06943632368347608, 0.06065309498808347, 0.04214406551909633, 0.13766466843662784, 0.026630689171724953, 0.10116777528310195, 0.015166669072641525, 0.03815550786384847, 0.03032974429515889, 0.1147057734488044, 0.04284465663658921, 0.006479110634245444, 0.025914963807736058, 0.017161074065370485, 0.07098753107129596, 0.05393328545324039, 0.04684113671828527, 0.06277278749621473, 0.1561871456215158, 0.036561474844347686, 0.13625953055452555, 0.11215942024136893, 0.1130852049391251, 0.06885974915348925, 0.21942330786259845, 0.3110740485135466, 0.09243462671292946, 0.13641645025927573, 0.4280849400674924, 1.6349639184772968, 1.3486542692407966, 14.596811290830374, 54.214138090610504, 101.76531851291656, 88.64254787564278, 72.00543701648712, 56.48499883711338, 52.503260895609856, 52.42729917168617, 65.5359497666359, 74.4032147526741, 78.58517915010452, 66.1014886200428, 70.65329477190971, 70.08872106671333, 57.06940367817879, 41.27925977110863, 26.98976743966341, 32.15141996741295, 44.512601271271706, 48.35558965802193, 51.93482659757137, 52.71600008010864, 53.474819362163544, 61.313699930906296, 65.60138985514641, 63.1276123970747, 55.39842054247856, 46.96026653051376, 36.14562124013901, 31.451828107237816, 32.62083537876606, 31.51529610157013, 20.10104488581419, 12.857103142887354, 11.605888232588768, 10.687704551964998, 15.683649871498346, 13.871298171579838, 12.619907520711422, 13.093070480972528, 16.756257265806198, 23.88175841420889, 28.43745555728674, 31.31671115756035, 36.81745558977127, 41.23530752956867, 43.446078300476074, 43.74534644186497, 44.67125415802002, 50.12667842209339, 70.33950760960579, 74.10645827651024, 83.15347641706467, 79.47688490152359, 84.66638803482056, 69.93621245026588, 56.82546056807041, 53.34713861346245, 51.38790674507618, 55.86072653532028, 66.71579405665398, 71.76838293671608, 52.38544821739197, 17.10875105112791, 0.36297472135629505, 0.8435290271881968, 0.3014635626459494, 0.0490568891109433, 0.11524330358952284, 0.04448729661817197, 0.14529559412039816, 0.10577889464912005, 0.1370214342023246, 0.3438960638595745, 0.09056134207639843, 0.1055252508376725, 0.040996497409651056, 0.03039844861632446, 0.03939718772016931, 0.03318052833492402, 0.08714067953405902, 0.015702549790148623, 0.05982537397358101, 0.09370268991915509, 0.05171872049686499, 0.029617128529935144, 0.1574752913438715, 0.022916599991731346, 0.05191432464926038, 0.0627639633603394, 0.04057960708450992, 0.032440106151625514, 0.07037827977910638, 0.04850375531532336, 0.06321394233964384, 0.08005849784240127, 0.05599997006356716, 0.11493295969557948, 0.13151052757166326, 0.009308146964031039, 0.04983609222108498, 0.05883692603674717, 0.03615295223426074, 0.1211721877916716, 0.13603850413346663, 0.04589928823406808, 0.03975360785261728, 0.04830909369047731, 0.048657788065611385, 0.04365699292975478, 0.06420476885978132, 0.025048851493920665, 0.041629003899288364, 0.02896981248341035, 0.06573552265763283, 0.029813459987053648, 0.04844258008233737, 0.04759212337376084, 0.02509731744794408, 0.017693732006591745, 0.09018093944177963, 0.05633709064568393, 0.10785474849399179, 0.06080012557504233, 0.00944218440054101, 0.04476565765799023, 0.08493460845784284, 0.062120669754222035, 0.05444498143333476, 0.14214070950401947, 0.06148596650746185, 0.09230475829099305, 0.08260761183919385, 0.08097423386061564, 0.029361877968767658, 0.12525784433819354, 0.041085076445597224, 0.04339067323599011, 0.053282010048860684, 0.020797131983272266, 0.03633825166616589, 0.015442253552464535, 0.08173482390702702, 0.04380363017844502, 0.04179273651971016, 0.08925809364882298, 0.04774365508637857, 0.05432290185126476, 0.034330667986068875, 0.03870886801450979, 0.017735251458361745, 0.00910442464373773, 0.08652592150610872, 0.033513871385366656, 0.027282580558676273, 0.058014047535834834, 0.07624888312420808, 0.10288704943377525, 0.040959085745271295, 0.05366717727156356, 0.09283535677241161, 0.1449401053832844, 0.011220454653084744, 0.0756702157377731, 0.08307389580295421, 0.07676469060243107, 0.14007210644194856, 0.0181385716132354, 0.06231396211660467, 0.24151636142050847, 0.2723459922708571, 0.05603687335678842, 0.21726187696913257, 0.7608221308328211, 5.094403736293316, 7.316361581906676, 47.49827966094017, 87.86773905158043, 107.86600515246391, 90.01544460654259, 75.55896833539009, 57.992605939507484, 63.334055319428444, 73.02314400672913, 92.71994188427925, 108.70017439126968, 108.64133074879646, 99.64044213294983, 95.78817084431648, 96.10011890530586, 102.23780035972595, 77.09112212061882, 71.60757556557655, 72.08548352122307, 79.18269708752632, 81.01131856441498, 82.38762751221657, 81.12988740205765, 70.63734322786331, 84.38955008983612, 85.56374788284302, 82.87754282355309, 90.96657916903496, 85.4314997792244, 71.64197131991386, 62.863553166389465, 68.2007771730423, 59.20359715819359, 43.245186880230904, 40.57172253727913, 37.90486603975296, 40.459924936294556, 41.287934705615044, 40.32278649508953, 38.986219614744186, 35.627249255776405, 39.13224957883358, 45.418791845440865, 47.037178203463554, 53.87553445994854, 59.521203115582466, 67.33326092362404, 70.97222685813904, 68.61600369215012, 75.46943753957748, 74.80188176035881, 98.20713624358177, 97.41141334176064, 100.22592231631279, 93.19550916552544, 102.06433966755867, 94.01722267270088, 84.69329059123993, 62.31124520301819, 52.037284299731255, 59.032682329416275, 76.98275193572044, 94.44817274808884, 85.96752941608429, 44.85481470823288, 6.897772243246436, 1.264613822568208, 0.2296225691679865, 0.007669383776374161, 0.03876358285197057, 0.008277437427750556, 0.16720297717256472, 0.12149904447142035, 0.06352611191687174, 0.14676710969069973, 0.029893205610278528, 0.03659446330857463, 0.021975315539748408, 0.03551037108991295, 0.03031365824426757, 0.06832364393630996, 0.03962872666306794, 0.01613100463146111, 0.07170221928390674, 0.027308451826684177, 0.08324590336997062, 0.06249911311897449, 0.10595513987937011, 0.03673340077511966, 0.024104136464302428, 0.06990273381234147, 0.044576781074283645, 0.08207336941268295, 0.051653704649652354, 0.02503078205336351, 0.06588648291653953, 0.06502350617665797, 0.01652265080338111, 0.06742695884895511, 0.059369346490711905, 0.03138341402518563, 0.018640723574208096, 0.016869983337528538, 0.04994174436433241, 0.135811525688041, 0.10373007724410854, 0.04048638591484632, 0.04543577990261838, 0.0037624878768838244, 0.03174834288074635, 0.00828114352771081, 0.05882583835045807, 0.057514211075613275, 0.017165322860819288, 0.018227857544843573, 0.06634549383306876, 0.060510817856993526, 0.03226634340535384, 0.13922047714004293, 0.10610553610604256, 0.1258985701133497, 0.16352526436094195, 0.22248328663408756, 0.27211711392737925, 0.1681330960127525, 0.09287027482059784, 0.11757611864595674, 0.22494178439956158, 0.14034003659617156, 0.17459490161854774, 0.20081494934856892, 0.14781620964640751, 0.15174260130152106, 0.16852935834322125, 0.17691556771751493, 0.057367670306121, 0.2494538831524551, 0.08994281393825077, 0.17022212297888473, 0.10261557923513465, 0.08714902127394453, 0.13677818787982687, 0.1244211322045885, 0.20681432273704559, 0.0936898284999188, 0.13067178195342422, 0.11567484762053937, 0.11500344888190739, 0.07107080004061572, 0.15263317851349711, 0.10391112416982651, 0.17931047827005386, 0.08461999721475877, 0.29478076030500233, 0.13111865875544026, 0.3095507755642757, 0.21561674337135628, 0.19183920754585415, 0.2110878613893874, 0.18947197910165414, 0.2431380728376098, 0.13958868628833443, 0.2036716538714245, 0.20765217777807266, 0.22302346624201164, 0.13579598511569202, 0.22644815122475848, 0.22460051521193236, 0.1989336495171301, 0.24363972013816237, 0.44952333031687886, 0.6049977766815573, 0.16830279550049454, 0.17768616933608428, 0.35950651683378965, 1.904641028959304, 1.3139306637458503, 27.289252169430256, 96.89750611782074, 144.3373829126358, 127.82427459955215, 102.62298569083214, 75.67052274942398, 79.65752720832825, 85.08590072393417, 101.82337179780006, 117.36176401376724, 111.9679306447506, 93.10864582657814, 99.84616309404373, 117.03369721770287, 119.9895130097866, 107.81472310423851, 99.49864894151688, 90.83116203546524, 92.95591682195663, 86.88983872532845, 83.90558525919914, 75.24423882365227, 70.4453395307064, 77.54542574286461, 87.54806980490685, 92.22686514258385, 102.65311807394028, 94.65628758072853, 81.14038243889809, 77.65282317996025, 79.65363621711731, 70.8294989168644, 52.341875955462456, 45.37836201488972, 44.26013141870499, 49.33939106762409, 50.24650499224663, 47.660439759492874, 41.8477700650692, 37.10958391427994, 38.66512544453144, 42.34683148562908, 42.41737090051174, 49.467660784721375, 55.621559768915176, 66.59349381923676, 81.49640053510666, 84.59100767970085, 99.13296416401863, 108.92683982849121, 130.82781583070755, 117.84145027399063, 107.98334285616875, 96.4523296058178, 107.58324712514877, 102.24034622311592, 95.85231140255928, 80.35401463508606, 71.8563862144947, 77.90382251143456, 99.7128738462925, 122.52812638878822, 96.35878622531891, 30.507409684360027, 1.6334454249590635, 0.6674723024480045, 0.2472139775636606, 0.15695179521571845, 0.2427169485599734, 0.11949812527745962, 0.2775163570186123, 0.10822879092302173, 0.26451437501236796, 0.30640650365967304, 0.1263648466556333, 0.1948238434852101, 0.14387127914233133, 0.17686297913314775, 0.214152337575797, 0.23530023638159037, 0.16246053477516398, 0.07489853058359586, 0.15541706350632012, 0.19480628427118063, 0.29486613697372377, 0.15383863414172083, 0.2556600485695526, 0.12523716810392216, 0.15741114009870216, 0.15789696481078863, 0.12685509456787258, 0.13150990416761488, 0.15543195098871365, 0.1598453993210569, 0.13335918774828315, 0.17730978172039613, 0.16228832682827488, 0.29759073921013623, 0.18966285948408768, 0.19365322426892817, 0.15584314533043653, 0.18059789668768644, 0.1457623901660554, 0.20775570737896487, 0.14102459361311048, 0.2643474511569366, 0.19934880692744628, 0.17900462436955422, 0.1372559231822379, 0.113053270324599, 0.1521836596657522, 0.1441689397324808, 0.11486544652143493, 0.11300382102490403, 0.1628580884425901, 0.21080882870592177, 0.11400811010389589], [0.020293575507821515, 0.0767142690892797, 0.15779678971739486, 0.03922849384252913, 0.04844124792725779, 0.022380967893695924, 0.008899857202777639, 0.07578869961434975, 0.010339891796320444, 0.056280557546415366, 0.05238572572125122, 0.06790559215005487, 0.09195118429488502, 0.11320776320644654, 0.10373236305895261, 0.06097559155023191, 0.0602495558996452, 0.025344788446091115, 0.027994435622531455, 0.07782257758663036, 0.011718189907696797, 0.05300962700857781, 0.08584912735386752, 0.04232556515489705, 0.03641934243205469, 0.0414119924971601, 0.14216229115845636, 0.0764040884678252, 0.02360018108447548, 0.0060937490616197465, 0.05133294471306726, 0.022559690041816793, 0.12534853478427976, 0.05787695430626627, 0.06909445335622877, 0.013291155210026773, 0.17996665555983782, 0.028639749725698493, 0.07615351714775898, 0.05981381873425562, 0.0493855046806857, 0.05393793500843458, 0.061254342217580415, 0.010973599637509324, 0.0728058151435107, 0.013483924358297372, 0.021677100194210652, 0.0334850463696057, 0.07613860740093514, 0.10577823413768783, 0.20726467279018834, 0.06311631281278096, 0.06793304419261403, 0.0596014457551064, 0.06469877946074121, 0.11568557907594368, 0.07854494702769443, 0.24872933921869844, 0.09439866858883761, 1.4747866010293365, 0.8263135165907443, 13.168249446898699, 66.63447842001915, 110.22144556045532, 107.07393765449524, 81.66497468948364, 62.30099335312843, 61.2842933088541, 65.3703698515892, 68.29366698861122, 72.31975615024567, 72.16111466288567, 75.73257341980934, 57.39650912582874, 53.58592540025711, 63.2553843408823, 64.51189711689949, 76.55348896980286, 76.69474259018898, 80.52436709403992, 97.0818418264389, 114.89907056093216, 106.22507080435753, 108.84762927889824, 109.68281686306, 68.97551000118256, 66.22919976711273, 76.66416183114052, 88.15555080771446, 81.82123750448227, 78.50739732384682, 48.98912966251373, 35.86892768740654, 46.388936787843704, 39.81096535921097, 34.44917567074299, 38.612023293972015, 54.56813469529152, 62.47380048036575, 68.75574499368668, 74.9461068212986, 82.72144719958305, 79.51049789786339, 82.67538607120514, 75.08679047226906, 76.26304775476456, 83.04496943950653, 73.66885855793953, 87.81847089529037, 78.21204677224159, 74.88055273890495, 75.41522204875946, 65.49431160092354, 70.6373356282711, 60.87769232690334, 58.63544784486294, 71.99610471725464, 80.89815303683281, 82.9466763138771, 56.51883602142334, 10.894339364022017, 0.31358087493572384, 0.3490964410593733, 0.04604810368618928, 0.25256864726543427, 0.20048398117069155, 0.0662586625549011, 0.04530437523499131, 0.07665027369512245, 0.026171663412242197, 0.10464400984346867, 0.06825140328146517, 0.15093998343218118, 0.08220591698773205, 0.05353287451725919, 0.058473674434935674, 0.08160329307429492, 0.10305972493370064, 0.07016984760412015, 0.04842022288357839, 0.045533502197940834, 0.024814588869048748, 0.053639272518921643, 0.057129140332108364, 0.05633396991470363, 0.09114599859458394, 0.03354988781211432, 0.06208883904037066, 0.06197742412041407, 0.043003858445445076, 0.06907189206685871, 0.023593911791977007, 0.035028750644414686, 0.04120026518648956, 0.02495205873856321, 0.0637298240326345, 0.15149304672377184, 0.018437649705447257, 0.12780409364495426, 0.04259438588633202, 0.05994934974296484, 0.11719240603270009, 0.04862836191023234, 0.05636697322188411, 0.034496367297833785, 0.06330282194539905, 0.027175035938853398, 0.09336607399745844, 0.09499745559878647, 0.04912402007903438, 0.03216604585759342, 0.021934874057478737, 0.005817154797114199, 0.05833915274706669, 0.05559213394008111, 0.06287788302870467, 0.060322282661218196, 0.05328587292751763, 0.05537859207834117, 0.025553485938871745, 0.08377668738830835, 0.04107382548681926, 0.06275461229961365, 0.025471161352470517, 0.006695336287521059, 0.03348885729792528, 0.0749812726280652, 0.04168070561718196, 0.09125101991230622, 0.05642357311444357, 0.012898144414066337, 0.06751859924406745, 0.034974091468029656, 0.045418447043630295, 0.0639591773506254, 0.04165554681094363, 0.04436731731402688, 0.06005418181302957, 0.08773812325671315, 0.05900905976886861, 0.03899363007803913, 0.02160100222681649, 0.07170555152697489, 0.13361764809815213, 0.09009660920128226, 0.09843968495260924, 0.06974619260290638, 0.02030061477853451, 0.005659104708684026, 0.021746288766735233, 0.014945256734790746, 0.026256442652083933, 0.06002483729389496, 0.0379697483003838, 0.06044621761247981, 0.06381223211064935, 0.05199400162382517, 0.028074479960196186, 0.03506580978864804, 0.038813132341601886, 0.09137287313933484, 0.14416770776733756, 0.04603156492521521, 0.12282755560590886, 0.16418454382801428, 0.08615352664492093, 0.110860350105213, 0.1262532128021121, 0.03297769195341971, 0.07908543091616593, 0.06168413849081844, 0.06211942665686365, 0.10370038391556591, 0.6602352939080447, 0.556220862781629, 3.9556107809767127, 6.605725614354014, 50.71876645088196, 99.02210891246796, 118.72086748480797, 99.5548403263092, 85.05799502134323, 70.1863606274128, 68.93906995654106, 78.08238252997398, 80.7064913213253, 84.04711246490479, 94.46729332208633, 105.58718383312225, 86.69883817434311, 94.05237838625908, 119.2963770031929, 109.94203135371208, 115.59227496385574, 108.8274447619915, 114.8030649125576, 124.19933751225471, 145.29297083616257, 134.7138673067093, 126.27947509288788, 128.0868101119995, 88.56353491544724, 84.81284737586975, 94.46584939956665, 104.98543292284012, 111.50773733854294, 116.12189054489136, 84.88664701581001, 67.25728780031204, 94.76366221904755, 78.18240076303482, 86.503224670887, 74.26174074411392, 91.48509934544563, 98.29184889793396, 102.00749471783638, 111.195477694273, 115.7553318142891, 111.17649391293526, 120.0931866466999, 109.57209080457687, 97.74260357022285, 111.45141676068306, 102.43915915489197, 106.91235512495041, 94.32574331760406, 88.64414379000664, 83.84815514087677, 74.33588996529579, 83.6253958940506, 71.14099100232124, 65.68937793374062, 75.51182046532631, 92.85745650529861, 103.98836642503738, 87.45869860053062, 36.3186601549387, 4.386147391051054, 1.4800036023370922, 0.029690450865018647, 0.20432772726053372, 0.1098167420423124, 0.033932550286408514, 0.17936561984242871, 0.05653817926940974, 0.034660433884710073, 0.14240709599107504, 0.03183399043336976, 0.13984922465169802, 0.05202952081162948, 0.035205556196160614, 0.05740187218179926, 0.0161920908067259, 0.04469165069167502, 0.07534571166615933, 0.03772246098378673, 0.05723585003579501, 0.047461267895414494, 0.036664032231783494, 0.016114634709083475, 0.0232170065282844, 0.02169375027733622, 0.03713625708769541, 0.056391493781120516, 0.08090554067166522, 0.013225144884927431, 0.06380996856023557, 0.008799499355518492, 0.04833512823097408, 0.01072617873433046, 0.025892432204273064, 0.041026550679816864, 0.06497080627013929, 0.03482968808384612, 0.08887379473890178, 0.03940271672036033, 0.030557761747331824, 0.09920423064613715, 0.03870353568345308, 0.016333842868334614, 0.08401551051065326, 0.04427876425324939, 0.041966358257923275, 0.04879533029452432, 0.03230504640669096, 0.03513182011374738, 0.01359767426038161, 0.04474095156183466, 0.06501623312942684, 0.03977593165473081, 0.00974788152234396, 0.08894023922039196, 0.14325842843391, 0.11653939771349542, 0.2516542619559914, 0.15457052533747628, 0.19347825553268194, 0.1373032870469615, 0.2400965290144086, 0.09778246865607798, 0.1797702387557365, 0.16490421927301213, 0.14793538372032344, 0.11052843197830953, 0.11394052271498367, 0.18576778646092862, 0.2675876975990832, 0.2857647347263992, 0.11689120539813302, 0.15980741620296612, 0.22190726129338145, 0.16332990140654147, 0.1307825994445011, 0.17572553391801193, 0.16580644820351154, 0.1912545139202848, 0.16657943953759968, 0.10626012546708807, 0.23350015719188377, 0.2109071335871704, 0.19507630728185177, 0.16937594104092568, 0.1824526276323013, 0.15275627112714574, 0.09967531630536541, 0.1753474838915281, 0.13530325843021274, 0.1145483268192038, 0.23502169351559132, 0.20619651448214427, 0.1547211516299285, 0.20815335010411218, 0.15147186582908034, 0.15068321517901495, 0.16418019484262913, 0.10159381999983452, 0.2501658402616158, 0.23956624965649098, 0.12962493812665343, 0.24497174163116142, 0.2256313880207017, 0.20632996747735888, 0.3766065195668489, 0.15741418290417641, 0.20975258928956464, 0.13831477495841682, 0.2097747498191893, 0.27709321409929544, 0.24670410726685077, 0.396648544119671, 0.3482774959411472, 2.0165202068164945, 1.3004295132122934, 28.067309819161892, 98.46909418702126, 148.57620745897293, 145.66348135471344, 112.7790579199791, 87.42247134447098, 81.89635947346687, 86.06107279658318, 98.24011087417603, 107.54646509885788, 108.66436511278152, 107.65539765357971, 80.12322261929512, 81.82420134544373, 110.81861391663551, 108.19556146860123, 129.5212483406067, 123.57452183961868, 127.07920297980309, 143.53746503591537, 153.047716319561, 137.42400348186493, 138.48445057868958, 136.66322350502014, 91.25742316246033, 97.64340609312057, 111.56012132763863, 120.49997001886368, 130.45754849910736, 130.11181265115738, 87.84589022397995, 69.77041214704514, 114.42341208457947, 91.24685972929001, 94.65402290225029, 87.50019237399101, 102.1928183734417, 108.28718215227127, 112.3508132994175, 116.508147418499, 129.30999487638474, 125.04964828491211, 129.42645102739334, 113.76201957464218, 114.43909764289856, 108.43735009431839, 95.6286934018135, 106.74755796790123, 93.67927640676498, 96.78794279694557, 97.73121178150177, 89.89347115159035, 96.0097673535347, 78.85011613368988, 78.46835821866989, 98.22194024920464, 122.34132081270218, 128.1315717101097, 87.59607642889023, 22.663530483841896, 0.8912286988925189, 0.4694122646469623, 0.19629733316833153, 0.21480271127074957, 0.27292433311231434, 0.1978174297255464, 0.20739414787385613, 0.11603861130424775, 0.09196899583912455, 0.21089994959766045, 0.1614876979147084, 0.23951493756612763, 0.2758912614081055, 0.10378773469710723, 0.2264797518728301, 0.13402234122622758, 0.20238097000401467, 0.1934826045180671, 0.14822694385657087, 0.17743521952070296, 0.16388869407819584, 0.17533624777570367, 0.1642261486267671, 0.23773299646563828, 0.179357189044822, 0.1371878237114288, 0.126031652034726, 0.1448642133618705, 0.07611987559357658, 0.14877592533593997, 0.25071933399885893, 0.14149293332593516, 0.08275539570604451, 0.07680340844672173, 0.14268471859395504, 0.14315957436338067, 0.14738825761014596, 0.24452750687487423, 0.18541789351729676, 0.1278939825715497, 0.20379260909976438, 0.13516107777832076, 0.1705429534194991, 0.26714042003732175, 0.19320852938108146, 0.06947897491045296, 0.2102855997509323, 0.24687428172910586, 0.10984555221511982, 0.15796929452335462, 0.1162041028146632, 0.10863722447538748, 0.1613349639228545, 0.10004601164837368, 0.22760564927011728], [0.039079392663552426, 0.006073574240872404, 0.011904281582246767, 0.06806102013797499, 0.043451343808555976, 0.03615398381953128, 0.011035934476240072, 0.041764245470403694, 0.11472319165477529, 0.034501265472499654, 0.009843335628829664, 0.09859929865342565, 0.04307340510422364, 0.014174820244079456, 0.024100607552099973, 0.042912051067105494, 0.049954650312429294, 0.002886058086915, 0.030380084172065835, 0.08211504842620343, 0.04361250488727819, 0.0306965786148794, 0.06182301658554934, 0.052495025520329364, 0.06291271944064647, 0.06185193436976988, 0.06469223371823318, 0.08517577676684596, 0.03238268618588336, 0.07041070421109907, 0.10736271942732856, 0.034120124400942586, 0.03607192455092445, 0.05746003058447968, 0.022871959808981046, 0.044752703470294364, 0.1014917746942956, 0.04353678355982993, 0.0338369876408251, 0.0516235289251199, 0.038404862061725, 0.027136429416714236, 0.03285629514721222, 0.021977456635795534, 0.05433238278783392, 0.04481299183680676, 0.021087385939608794, 0.043364197117625736, 0.022058621616452, 0.04161397540883627, 0.09053437985130586, 0.02815575440763496, 0.08354139688890427, 0.027815954672405496, 0.057270029647042975, 0.13506247603800148, 0.07778656858135946, 0.37424916168674827, 0.06750642802217044, 0.11593271425226703, 0.05861180667125154, 0.6179226050153375, 0.12791079963790253, 6.941357329487801, 43.12655724585056, 81.36774703860283, 111.63368538022041, 116.0601058602333, 88.8824214041233, 81.74642711877823, 74.70191672444344, 64.94015693664551, 80.08623540401459, 73.99672016501427, 73.095583319664, 60.005262941122055, 61.31548583507538, 70.68676337599754, 63.0703304708004, 64.68513742089272, 67.56203144788742, 59.2439965903759, 47.63778157532215, 63.12900312244892, 71.75636038184166, 61.870358660817146, 69.47038024663925, 65.66285535693169, 82.79750391840935, 74.20303389430046, 67.08700373768806, 33.85506995022297, 43.86299952864647, 53.85087378323078, 63.570277243852615, 131.08960658311844, 37.227540984749794, 40.45354887843132, 49.755153357982635, 52.620731592178345, 55.8745463937521, 68.73013436794281, 67.7867665886879, 53.319001123309135, 46.24887630343437, 80.29690369963646, 64.21342313289642, 66.86942741274834, 77.9879803955555, 80.39099425077438, 70.64317971467972, 66.91601291298866, 67.97197625041008, 77.30512663722038, 93.41276630759239, 99.32786330580711, 83.51744368672371, 35.62937334179878, 9.190336000174284, 0.4748202650807798, 0.14476838725386187, 0.13267973670735955, 0.05666514589393046, 0.0590726469818037, 0.15129440347664058, 0.042903111898340285, 0.1022071902116295, 0.05982274677080568, 0.05034330562921241, 0.0763968079991173, 0.06836890010163188, 0.02103490496665472, 0.021546693715208676, 0.045687486708629876, 0.10088202616316266, 0.0573640189395519, 0.07318998788832687, 0.03355424421897624, 0.022322108161461074, 0.04069028356752824, 0.015328791232604999, 0.04209477578115184, 0.15055660478537902, 0.11161345930304378, 0.052333010971779004, 0.014234497266443213, 0.09001409722259268, 0.06399452584446408, 0.006347533881125855, 0.04318953266192693, 0.047195675506372936, 0.0298902240319876, 0.012249742976564448, 0.025059204454009887, 0.0373934335220838, 0.0435446020856034, 0.07841501181246713, 0.08315716477227397, 0.09474659484112635, 0.11886714390129782, 0.09080867763259448, 0.09387037818669342, 0.05473556193464901, 0.024000003868422937, 0.02289078438479919, 0.06878438405692577, 0.007959250888234237, 0.005372608802645118, 0.02377694025199162, 0.02547357518778881, 0.06557262124260888, 0.04258277498593088, 0.06011327161104418, 0.09044831298524514, 0.08127923429128714, 0.06846312317065895, 0.014636509386036778, 0.04422000842168927, 0.08745900893700309, 0.06652354248217307, 0.06958167330594733, 0.026448660755704623, 0.013274044067657087, 0.02576513903477462, 0.0790544982010033, 0.03984176386438776, 0.055005117392283864, 0.07557378106866963, 0.09277386983740143, 0.07080758252413943, 0.011622220936260419, 0.025210669373336714, 0.07937446775031276, 0.018441523716319352, 0.010638340918376343, 0.02928692105342634, 0.0250079443139839, 0.03648320052889176, 0.0741567910881713, 0.04237461740558501, 0.022807923596701585, 0.04776737041538581, 0.034150600695284083, 0.0535373645107029, 0.0392155099689262, 0.05907573431613855, 0.05184668902074918, 0.06805656725191511, 0.025173641770379618, 0.039490086055593565, 0.030313704628497362, 0.03210257367754821, 0.057220580347348005, 0.06131122041551862, 0.051465696378727444, 0.027062882581958547, 0.05419979068392422, 0.1118270048755221, 0.046630103315692395, 0.041189092153217643, 0.06562377006048337, 0.030998005604487844, 0.01024836828946718, 0.01861124546849169, 0.06399276695447043, 0.014532881450577406, 0.02399921719188569, 0.028997759909543674, 0.020604375822586007, 0.07727782634901814, 0.06542810282553546, 0.10690285504097119, 0.08418258279561996, 0.0941599567886442, 0.02979604178108275, 0.5976062233094126, 0.4427551513072103, 2.2474523400887847, 4.296956676989794, 36.175297647714615, 82.87106797099113, 111.47810652852058, 115.29702320694923, 111.78028151392937, 88.70312422513962, 88.13584506511688, 84.28012356162071, 80.74546203017235, 79.03691411018372, 74.52400267124176, 66.56302705407143, 58.20127934217453, 64.59527224302292, 83.47655788064003, 79.6697473526001, 75.87234511971474, 80.08515626192093, 74.42858219146729, 59.10477586090565, 73.30748274922371, 77.86091521382332, 57.43892624974251, 55.3470890969038, 64.2409260571003, 79.16101545095444, 75.98437830805779, 72.64734417200089, 42.56452180445194, 52.64266021549702, 69.9790133535862, 76.98294952511787, 136.41140341758728, 47.456858083605766, 45.52291005849838, 51.01755581796169, 50.83198517560959, 53.31723041832447, 74.6126139163971, 70.4348748922348, 57.11792327463627, 55.20726799964905, 81.92702382802963, 63.27110789716244, 62.71374240517616, 76.26912742853165, 78.65800604224205, 76.13497942686081, 78.48180189728737, 79.16891142725945, 84.73599269986153, 93.31324204802513, 101.6193151473999, 107.20402747392654, 68.22641059756279, 27.087819278240204, 2.5748831452801824, 0.48896500607952476, 0.12357547719147988, 0.2588598331203684, 0.02032235228398349, 0.09046354185556993, 0.10016640284447931, 0.04833684259210713, 0.028754443083016668, 0.07356992296990938, 0.0686865541501902, 0.07464166585123166, 0.021515137595997658, 0.08437563767074607, 0.019715175294550136, 0.045643670309800655, 0.032307655055774376, 0.0173325714058592, 0.0027897089967154898, 0.04554717626888305, 0.05950646198471077, 0.010613342601573095, 0.0393326320045162, 0.06493903492810205, 0.0144938862285926, 0.0167768827668624, 0.006465869328167173, 0.05287778447382152, 0.04749246407300234, 0.03940734030038584, 0.06853932689409703, 0.009607360498193884, 0.04544345742033329, 0.03368254299857654, 0.10628443080349825, 0.05054296190792229, 0.02192325202486245, 0.021254391431284603, 0.0348546131135663, 0.04363891050161328, 0.014046412925381446, 0.04052365657116752, 0.022611493805015925, 0.05436075880425051, 0.015459083606401691, 0.024557553442718927, 0.022335088324325625, 0.0420826787740225, 0.04313761572120711, 0.03985457333328668, 0.044087583301006816, 0.07768715047859587, 0.0224865643758676, 0.07143384384107776, 0.06235380802536383, 0.019438990602793638, 0.1288701590965502, 0.13576539378846064, 0.1402911587501876, 0.1677171073970385, 0.1375084908795543, 0.27192673820536584, 0.0911264430033043, 0.09221529981005006, 0.10233472828986123, 0.13179223198676482, 0.18879343348089606, 0.14545007958076894, 0.17371891502989456, 0.25828603422269225, 0.09354698733659461, 0.20613065629731864, 0.1824127891450189, 0.15960308810463175, 0.08903867768822238, 0.10506744962185621, 0.17943900340469554, 0.15329628746258095, 0.11614893155638129, 0.13037746102781966, 0.13751721853623167, 0.24169826181605458, 0.1249458157690242, 0.1778010537964292, 0.16779245022917166, 0.20795783872017637, 0.1939305500127375, 0.22785455075791106, 0.13251529162516817, 0.20831273373914883, 0.24827928602462634, 0.11024540654034354, 0.13687625527381897, 0.18276962859090418, 0.1794639098807238, 0.12190355206257664, 0.14506545412587002, 0.1719747789320536, 0.3015570138813928, 0.1686127608991228, 0.1417027533170767, 0.19156479102093726, 0.287579107680358, 0.21123357466422021, 0.06982139442698099, 0.12356196268228814, 0.1333958943723701, 0.09310960260336287, 0.14529853302519768, 0.23203171411296353, 0.15080954355653375, 0.17385067592840642, 0.21725821075960994, 0.20004920137580484, 0.6572995358146727, 0.2082283070194535, 0.570325527805835, 0.2251353216706775, 1.254210218321532, 0.5737151834182441, 15.548370480537415, 60.24235501885414, 122.84004405140877, 151.24799609184265, 162.86065936088562, 121.68291494250298, 106.90756738185883, 98.52652430534363, 84.52638074755669, 106.0354533791542, 101.11730128526688, 98.51313382387161, 77.05297216773033, 78.84325370192528, 90.98834440112114, 87.51968532800674, 82.29841589927673, 83.31965669989586, 81.8466429412365, 65.21827921271324, 89.2863929271698, 106.49867132306099, 83.4973655641079, 89.4055013358593, 84.24834206700325, 109.68588709831238, 101.99977353215218, 105.99400520324707, 66.23686015605927, 76.80704176425934, 95.30961692333221, 100.10147139430046, 166.38413429260254, 67.19424918293953, 75.9077288210392, 80.70351228117943, 79.49950128793716, 79.08949568867683, 99.39382776618004, 90.83994716405869, 74.83100339770317, 65.7831721007824, 99.38740611076355, 82.06726670265198, 84.09622102975845, 98.7883910536766, 93.66564273834229, 87.86139339208603, 89.84073758125305, 93.23011010885239, 106.1083410680294, 125.96071779727936, 140.02485752105713, 119.57099586725235, 57.58034706115723, 13.797191698104143, 0.42656511068344116, 0.30784793256316334, 0.14548496052157134, 0.34911416354589164, 0.1673229824518785, 0.352786963339895, 0.15102685923920944, 0.3006256482331082, 0.15751961240312085, 0.1803703690529801, 0.17726133432006463, 0.19231507263612002, 0.13060111465165392, 0.1148110767826438, 0.17320432467386127, 0.16740711231250316, 0.14803781494265422, 0.12191133719170466, 0.11122069248813204, 0.2039992081699893, 0.11759789325878955, 0.06329483643639833, 0.10381367275840603, 0.24568589549744502, 0.10044994036434218, 0.16286130936350673, 0.07082270007231273, 0.21358502504881471, 0.11117657923023216, 0.20677662163507193, 0.17610537994187325, 0.05467407128890045, 0.11318980323267169, 0.10210009830188937, 0.31279253598768264, 0.1590723783010617, 0.19637322518974543, 0.11930453605600633, 0.13714886095840484, 0.18287651269929484, 0.20261366298655048, 0.3074668545741588, 0.2437641634605825, 0.12321966933086514, 0.128141088061966, 0.21410129265859723, 0.1812257684650831, 0.1749717493657954, 0.10665210560546257, 0.10284836869686842, 0.10112200703588314, 0.13692623149836436, 0.13540552638005465, 0.2414194369339384, 0.13688198465388268, 0.18379502434981987, 0.20629619975807145], [0.03718913510965649, 0.07498366976506077, 0.01788510591723025, 0.05129331773787271, 0.09938656890881248, 0.04522739596723113, 0.01524489329312928, 0.039732523437123746, 0.03287255560280755, 0.05611398992186878, 0.007764348529235576, 0.0369447087723529, 0.06092718496802263, 0.026582471837173216, 0.02550755441916408, 0.07747941592242569, 0.03169865609379485, 0.021912904630880803, 0.04691883958003018, 0.03568382584489882, 0.045772303055855446, 0.06812699706642888, 0.08512158514349721, 0.029957045153423678, 0.06499059934867546, 0.03500519487715792, 0.10536974121350795, 0.0719851185567677, 0.06211803512996994, 0.014182834511302644, 0.03395865162019618, 0.036251676428946666, 0.04300235188566148, 0.07304546947125345, 0.054818177814013325, 0.03475188132142648, 0.09881465506623499, 0.10167377156903967, 0.051655793795362115, 0.018550548920757137, 0.04478758441109676, 0.09144240495515987, 0.07096681030816399, 0.0702424296468962, 0.029213999478088226, 0.06101774182752706, 0.011087970160588156, 0.07988111712620594, 0.0458360090124188, 0.09550120317726396, 0.09629516018321738, 0.03394399049284402, 0.05126104173541535, 0.08542020310414955, 0.04017541119537782, 0.07277940210769884, 0.018568245432106778, 0.14464422594755888, 0.00708853169271606, 0.19324900611536577, 0.04490285849897191, 0.031721324994578026, 0.05780502535344567, 0.6423536315560341, 0.3779614734230563, 0.9942462772596627, 14.78680869564414, 49.4121989607811, 87.46717974543571, 122.53824144601822, 133.1906658411026, 105.37903860211372, 90.35950094461441, 73.90084370970726, 72.64039054512978, 69.05971348285675, 80.51653951406479, 82.9961496591568, 76.27660542726517, 69.30204927921295, 84.1280709207058, 79.53347146511078, 80.44410020112991, 74.52624455094337, 74.38067436218262, 77.11053907871246, 96.55151188373566, 94.51037541031837, 87.13978931307793, 73.78840014338493, 71.37340933084488, 69.12199214100838, 64.69597443938255, 69.73831906914711, 79.41382348537445, 78.8949765264988, 62.34678469598293, 72.3365968465805, 68.95789414644241, 77.13682606816292, 70.6097187101841, 77.91075333952904, 74.99339908361435, 72.72094622254372, 71.14875018596649, 80.72837054729462, 75.94327971339226, 70.76092019677162, 77.07520857453346, 85.91288074851036, 97.84233301877975, 111.19493052363396, 81.71663671731949, 63.03994730114937, 40.96197299659252, 17.60306842625141, 1.9556404673494399, 0.09860250473138876, 0.20039024791913107, 0.02230040219728835, 0.08170792105374858, 0.05347722086298745, 0.019891246120096184, 0.03770591851207428, 0.11885752566740848, 0.060412353413994424, 0.005576953599302215, 0.10408719870611094, 0.13627038075355813, 0.0750495279498864, 0.02511195074475836, 0.05118877139466349, 0.043360972485970706, 0.02626774185046088, 0.023618549239472486, 0.02481772258761339, 0.03356350993271917, 0.0358778158260975, 0.056152774559450336, 0.06835243926616386, 0.07954954780871049, 0.02560164390160935, 0.009217102142429212, 0.10661745473043993, 0.08727180218556896, 0.03886785460053943, 0.05141442139574792, 0.03817200209596194, 0.03694064180308487, 0.04551698570139706, 0.01816790500015486, 0.06663965148618445, 0.0817738460318651, 0.03488120055408217, 0.023952894189278595, 0.03540566518495325, 0.015333904630097095, 0.03967099939472973, 0.004444246997081791, 0.03279513846791815, 0.04853674749028869, 0.056695829989621416, 0.020062834373675287, 0.060638701033894904, 0.042773332534125075, 0.09762466579559259, 0.024694422172615305, 0.023484496960008983, 0.046002276067156345, 0.04472377826459706, 0.04549144097836688, 0.026779276413435582, 0.050044873205479234, 0.034651932583074085, 0.016448064961878117, 0.04354734432126861, 0.007455423065039213, 0.032853923985385336, 0.04435147617186885, 0.06539798647281714, 0.06713145790854469, 0.026107836856681388, 0.009227710215782281, 0.044163575512357056, 0.031104457411856856, 0.06048364411981311, 0.04758648676215671, 0.002980016070068814, 0.04324509354773909, 0.09407411256688647, 0.04011487792013213, 0.025030182769114617, 0.03136136852845084, 0.1210866923793219, 0.02945447944512125, 0.0444773295748746, 0.07060630465275608, 0.028200279557495378, 0.008716414067748701, 0.02615900793898618, 0.07938235678011551, 0.010387217625975609, 0.04291697892767843, 0.008766245573497145, 0.009240674608008703, 0.05977888955385424, 0.08531302213668823, 0.09292293761973269, 0.01219785201101331, 0.0767746873316355, 0.053563740439130925, 0.06702908605802804, 0.07092454499797896, 0.04212397929222789, 0.09298243559896946, 0.08303905196953565, 0.03258608659962192, 0.04778003887622617, 0.02539547156629851, 0.025223256197932642, 0.00837607627545367, 0.024879042539396323, 0.021874953054066282, 0.06713260823744349, 0.0529899972025305, 0.03081392886087997, 0.03203732405381743, 0.05036436406953726, 0.07102286472218111, 0.03542630060110241, 0.07327616607653908, 0.05211456722463481, 0.0410729757277295, 0.023811949213268235, 0.015831687196623534, 0.2009036359959282, 0.08191199682187289, 0.2658053854247555, 0.2234696305822581, 0.8841860736720264, 2.6571774668991566, 10.85480248555541, 44.131614714860916, 87.35696285963058, 116.66145399212837, 137.21539467573166, 130.67258656024933, 108.4471307694912, 100.47436818480492, 89.31585654616356, 85.06139203906059, 79.69234853982925, 81.39666348695755, 83.08651641011238, 73.6028864979744, 73.13311010599136, 77.88880571722984, 72.76112526655197, 72.94447302818298, 75.01319602131844, 80.4634715616703, 89.6570098400116, 113.2587593793869, 113.15347462892532, 98.9024305343628, 88.34270596504211, 79.36697959899902, 74.84763130545616, 74.3232898414135, 76.53349444270134, 80.3291867673397, 72.46315285563469, 64.1602411866188, 76.92439466714859, 73.64915281534195, 85.1846194267273, 71.96225613355637, 79.73116725683212, 76.02170750498772, 73.07669833302498, 70.22676765918732, 87.50616565346718, 81.55506178736687, 80.85986629128456, 87.62610241770744, 95.66473066806793, 107.80847623944283, 121.52915239334106, 111.88568025827408, 98.7929280102253, 73.22650909423828, 40.05159504711628, 9.610840436071157, 0.5855245341081172, 0.2039267003419809, 0.07040426979074255, 0.05605448081041686, 0.07194208141299896, 0.06695658565149643, 0.064943294855766, 0.025461897494096775, 0.05209087787079625, 0.04418761367560364, 0.0887340483313892, 0.03716859246196691, 0.03710350239998661, 0.019799093643086962, 0.050511212830315344, 0.02548533822846366, 0.042743160520331, 0.019435899557720404, 0.05817093013320118, 0.05287384738039691, 0.024222898646257818, 0.027387681657273788, 0.04093052790267393, 0.04277550702681765, 0.010746187963377452, 0.04588133939250838, 0.042419020101078786, 0.05813214920635801, 0.07171755947638303, 0.014909223609720357, 0.06478242692537606, 0.040105645603034645, 0.029692421267100144, 0.11353881302056834, 0.04065342480316758, 0.06370270595652983, 0.03559829332516529, 0.03124875875073485, 0.04053373864735477, 0.033667726020212285, 0.018696642546274234, 0.0291641865260317, 0.04763255186844617, 0.032955082424450666, 0.03521077349432744, 0.009322030691691907, 0.07786073139868677, 0.025387773639522493, 0.056383011033176444, 0.024822490886435844, 0.062344538600882515, 0.014156680299493019, 0.0826515321386978, 0.018625674674694892, 0.05326973863702733, 0.022023775927664246, 0.04528111261606682, 0.029635455866809934, 0.041625011144788004, 0.10069333511637524, 0.12614095554454252, 0.09853188195847906, 0.16463088628370315, 0.23936126846820116, 0.12348351767286658, 0.1065365903195925, 0.1438199818949215, 0.13913171627791598, 0.22907427046447992, 0.10051810662844218, 0.11966737947659567, 0.22430129611166194, 0.20001635391963646, 0.13674450921826065, 0.085820955428062, 0.16176986246136948, 0.17699769377941266, 0.09963193035218865, 0.215574708126951, 0.3324265871196985, 0.12476115458412096, 0.20068540005013347, 0.12607754644704983, 0.22151738143293187, 0.09766555071109906, 0.1638262052438222, 0.12765793508151546, 0.13028739398578182, 0.12992384552489966, 0.15055207768455148, 0.16537618066649884, 0.2053464882192202, 0.09466903298744, 0.15900711383437738, 0.18493744195438921, 0.23283945280127227, 0.2051801877678372, 0.18130235810531303, 0.23885555419838056, 0.07099175389157608, 0.1626504206797108, 0.20917292742524296, 0.07551899572717957, 0.10496472154045478, 0.17429580126190558, 0.11405918470700271, 0.15773306891787797, 0.2071452167001553, 0.16411518270615488, 0.1960948752821423, 0.20247338223271072, 0.219812267459929, 0.28334147413261235, 0.2046338186482899, 0.18133643752662465, 0.1056194219563622, 0.28471055848058313, 0.09981423150748014, 0.7103537733200938, 0.15987986465916038, 0.18766734312521294, 0.2085877736681141, 1.370073719881475, 0.558952916180715, 2.690392197109759, 22.31988452374935, 64.91523027420044, 113.5946537554264, 160.49796134233475, 174.38229471445084, 141.4704367518425, 121.42333567142487, 97.58484363555908, 95.59068024158478, 91.34638398885727, 102.73906946182251, 104.7820982336998, 98.28674957156181, 88.7498389184475, 103.39638859033585, 95.67518010735512, 98.37862104177475, 96.55839711427689, 95.00702396035194, 103.50984290242195, 135.96707046031952, 139.33653205633163, 115.28227239847183, 102.66035288572311, 92.10140347480774, 87.11863204836845, 89.7390778362751, 92.26994723081589, 99.23837810754776, 93.4499891102314, 73.44606131315231, 86.4783664047718, 83.29483643174171, 96.26325935125351, 81.50888666510582, 89.3716299533844, 83.16918477416039, 83.97357121109962, 79.28475961089134, 104.58966135978699, 92.24132716655731, 92.12777405977249, 103.83731693029404, 119.75968614220619, 139.7476851940155, 155.2318239212036, 133.88149917125702, 99.45044472813606, 58.72048728168011, 23.067807890474796, 2.979362178593874, 0.22845922299893573, 0.3636927640764043, 0.09773694531759247, 0.2198243496241048, 0.27759383723605424, 0.35751070361584425, 0.1285613069194369, 0.19007107039215043, 0.1259679757640697, 0.1804709152202122, 0.3004048147704452, 0.20848811807809398, 0.247322331124451, 0.10022117334301583, 0.14014082931680605, 0.1811190921580419, 0.12248673912836239, 0.06267170698265545, 0.1701644729473628, 0.15661831857869402, 0.09313877642853186, 0.19061303115449846, 0.18219674995634705, 0.14554814697476104, 0.16830166743602604, 0.12340336572378874, 0.1428667377331294, 0.24921244767028838, 0.13953872490674257, 0.22324015852063894, 0.13567909685662016, 0.12013805695460178, 0.10564780168351717, 0.16334710438968614, 0.10404468106571585, 0.21575626713456586, 0.151594067865517, 0.08299746943521313, 0.10293720377376303, 0.10213445973931812, 0.10875406078412198, 0.12231582251843065, 0.09612540132366121, 0.11582623090362176, 0.16273052809992805, 0.15184743708232418, 0.26048537401948124, 0.18944101670058444, 0.33505580853670835, 0.09512109740171582, 0.13138117123162374, 0.12556617701193318, 0.1092639756097924, 0.14826258178800344, 0.07431382211507298, 0.11468590615550056, 0.12453491828637198, 0.06891812648973428, 0.1559782904223539], [0.04149599248194136, 0.07604343438288197, 0.018851235618058126, 0.07861772945034318, 0.018439332525304053, 0.009478380798100261, 0.05546392050746363, 0.007969268954184372, 0.02347631107113557, 0.09660202340455726, 0.06472491048043594, 0.044525532066472806, 0.05318628413078841, 0.06113652998465113, 0.07719098764937371, 0.06778257375117391, 0.04578203632263467, 0.022155343867780175, 0.04197882262815256, 0.06627762442803942, 0.013645644830830861, 0.0776039037737064, 0.047423054711543955, 0.024056746624410152, 0.06313042104011402, 0.06288547519943677, 0.06760079952073283, 0.04861712208366953, 0.043588570624706335, 0.020614142486010678, 0.02425693724944722, 0.01860780561401043, 0.018292214735993184, 0.025159600336337462, 0.0611675443360582, 0.04295979713788256, 0.03111772886768449, 0.020423494024726097, 0.060387198318494484, 0.011779696324083488, 0.04749361440190114, 0.036329412687337026, 0.04160773765761405, 0.06151551511720754, 0.07920875359559432, 0.041981895119533874, 0.005060726343799615, 0.03053869597351877, 0.06609930118429475, 0.05438644082460087, 0.04568079995806329, 0.06000695524562616, 0.08061261498369277, 0.0038912398304091766, 0.005126087289681891, 0.08119460719171911, 0.05997594089421909, 0.1569142277003266, 0.050676808241405524, 0.05919123475905508, 0.09796597951208241, 0.16469117836095393, 0.08768689280259423, 0.05800642567919567, 0.08771758803050034, 0.2050351127400063, 0.42001236230134964, 0.24957586254458874, 0.5078188225161284, 5.185824455693364, 23.4374862536788, 45.70830211043358, 92.89777994155884, 109.15018424391747, 119.41787168383598, 114.43548783659935, 109.9436804652214, 99.7857691347599, 95.2650985121727, 94.6363690495491, 95.44244259595871, 85.63352733850479, 99.0746296942234, 96.73546001315117, 111.67679786682129, 107.30876505374908, 54.78056609630585, 63.94569709897041, 94.1452606022358, 114.12847951054573, 122.86342799663544, 106.57970577478409, 106.14318519830704, 99.25142660737038, 107.93488025665283, 107.92119339108467, 117.26169258356094, 111.33781045675278, 119.84426960349083, 97.56490990519524, 102.12931618094444, 115.6141085922718, 111.02505683898926, 99.54731673002243, 102.8151185810566, 110.02802073955536, 117.77088046073914, 110.03261849284172, 108.7204273045063, 78.41395273804665, 45.190435498952866, 14.124088156968355, 1.1666589975357056, 0.15655272756703198, 0.23297673527849838, 0.4759883461520076, 0.029276887216838077, 0.038447672850452363, 0.043804268425446935, 0.023630781688552815, 0.06499373863334768, 0.06666705157840624, 0.024131627469614614, 0.038335040808306076, 0.053430691914400086, 0.07667510595638305, 0.06766843885998242, 0.14741687482455745, 0.03391418584214989, 0.052878467249684036, 0.024553397415729705, 0.01985716855415376, 0.12807174178306013, 0.06280823246925138, 0.060194536781637, 0.09964397540898062, 0.07518243175582029, 0.04996764902898576, 0.02729111525695771, 0.04462583332497161, 0.002933696546278952, 0.0052287110065663, 0.038266670453595, 0.058341394033050165, 0.05505073720996734, 0.03794346142967697, 0.051499471519491635, 0.07057898619677871, 0.06378118065185845, 0.030683431468787603, 0.011592394021135988, 0.09135823798715137, 0.014838125862297602, 0.06950509850867093, 0.026685912380344234, 0.02586108759714989, 0.03669994846859481, 0.06088070796977263, 0.0222963853229885, 0.0750342768151313, 0.0354329650872387, 0.017277210899919737, 0.08349303112481721, 0.061327581061050296, 0.03740912623470649, 0.024658136717334855, 0.03187232978234533, 0.038168758910615, 0.0999065101495944, 0.009549571313982597, 0.051688385210582055, 0.026519012644712348, 0.04135509945626836, 0.04288567142793909, 0.03599729789129924, 0.033081440487876534, 0.04925828201521654, 0.02143974281352712, 0.021021609391027596, 0.08510836749337614, 0.039726085306028835, 0.07450733712175861, 0.03385603857168462, 0.020231320449966006, 0.0748075135925319, 0.07214968980406411, 0.06353745935484767, 0.05760265652497765, 0.0492411606683163, 0.010255902943754336, 0.03740187174116727, 0.01785272415872896, 0.020701272478618193, 0.03309372674266342, 0.031091525488591287, 0.02585187197837513, 0.049596285753068514, 0.044039451313437894, 0.05395613989094272, 0.056353358522756025, 0.0529330522113014, 0.040080650069285184, 0.054875683126738295, 0.06901819026097655, 0.029412679832603317, 0.056435098667861894, 0.021576494655164424, 0.023886963645054493, 0.042114568859688006, 0.01251077301276382, 0.018315156376047526, 0.01313343027504743, 0.015352129921666346, 0.026578339929983485, 0.06611965829506516, 0.05105826843646355, 0.06418806311558001, 0.047144274358288385, 0.01095394292860874, 0.054017114744056016, 0.046366793030756526, 0.016607589604973327, 0.0639120806590654, 0.06836217624368146, 0.05352891887014266, 0.07527240231866017, 0.028561696199176367, 0.10485751088708639, 0.04488354410568718, 0.06555023806868121, 0.09123039562837221, 0.10374910591053776, 0.03834443268715404, 0.1276698539732024, 0.03434441998251714, 0.058462360393605195, 0.058119762761634775, 0.0953147979453206, 0.08090604533208534, 0.3293349186424166, 0.3716655378229916, 0.44234400149434805, 0.6395590596366674, 1.4929866744205356, 6.153048304840922, 22.400067821145058, 52.33653724193573, 84.83473420143127, 119.0069617331028, 127.9332983493805, 132.56093323230743, 134.44245547056198, 133.76037687063217, 119.22150582075119, 115.77597990632057, 113.41075122356415, 117.56428554654121, 109.28961396217346, 115.90042322874069, 118.08379366993904, 123.98130521178246, 130.04928320646286, 74.82969626784325, 84.36488181352615, 120.4753777384758, 136.79702192544937, 146.45163506269455, 131.6308343410492, 126.1955451965332, 117.81457051634789, 127.78218805789948, 130.58548003435135, 139.10830110311508, 128.77056062221527, 137.228541970253, 128.51893812417984, 128.31966161727905, 132.53787606954575, 125.23424997925758, 118.22350457310677, 119.28902819752693, 127.3917818069458, 127.68520206212997, 126.57591998577118, 121.98258966207504, 102.13720455765724, 68.98476630449295, 35.56511498987675, 10.810183379799128, 1.005563079379499, 1.0010784887708724, 0.3141239786054939, 0.023624491986993235, 0.12437187586328946, 0.07052590779494494, 0.13026410539168864, 0.08808335551293567, 0.08001174253877252, 0.03499051890685223, 0.009500832620688016, 0.01686025563685689, 0.06953619449632242, 0.03862824851239566, 0.05658425921865273, 0.044236331959837116, 0.035841599019477144, 0.013634234310302418, 0.01250989449545159, 0.052157021782477386, 0.05502961568708997, 0.026411173021188006, 0.03703846799908206, 0.044445613893913105, 0.05049243649409618, 0.05432300204120111, 0.01702105306321755, 0.04838354594539851, 0.04549442070128862, 0.02221076745627215, 0.04387828281323891, 0.02673707604117226, 0.023055056917655747, 0.0023491636420658324, 0.04362253130238969, 0.09300662219175138, 0.07703624985879287, 0.03382600756594911, 0.05157738960406277, 0.06275556967011653, 0.08491091168252751, 0.02335114601009991, 0.02240464797068853, 0.004809683296116418, 0.05467141068947967, 0.05447794763313141, 0.018322807918593753, 0.06219528899237048, 0.03795480515691452, 0.05413631479314063, 0.037063263152958825, 0.02024771263677394, 0.039006005390547216, 0.039009092724882066, 0.015280752941180253, 0.016142890126502607, 0.029517244729504455, 0.028266228655411396, 0.027499003808770794, 0.04151431239733938, 0.01938485092978226, 0.03331723564770073, 0.02641778926772531, 0.1335305644897744, 0.14335256244521588, 0.17185423930641264, 0.2661633084062487, 0.09838215366471559, 0.17801176436478272, 0.1552834769245237, 0.09206815419020131, 0.09868038570857607, 0.2420962756150402, 0.1588691188953817, 0.10871422971831635, 0.16017654561437666, 0.15965748752932996, 0.1670020035817288, 0.1285786138032563, 0.08210816129576415, 0.12737916957121342, 0.09766352464794181, 0.14125041430816054, 0.13146429177140817, 0.12558697198983282, 0.17991572938626632, 0.11003698178683408, 0.19807302538538352, 0.1951309887226671, 0.16638152359519154, 0.1363875510287471, 0.09599817494745366, 0.08855009960825555, 0.0829404205433093, 0.15271647716872394, 0.0915294662991073, 0.10161791011341847, 0.14996465295553207, 0.15597695455653593, 0.08787038139416836, 0.08168922635377385, 0.24399756890488788, 0.09369360603159294, 0.14701268635690212, 0.2033491907059215, 0.14394987258128822, 0.11667163358652033, 0.22664738819003105, 0.1896751346066594, 0.12246314625372179, 0.21777866408228874, 0.14708400674862787, 0.12769315741024911, 0.16857259586686268, 0.1803678012220189, 0.16764727130066603, 0.19405233644647524, 0.14559641625965014, 0.15479000809136778, 0.14197417156537995, 0.21762882446637377, 0.1341984825558029, 0.23621566069778055, 0.2351125472341664, 0.39141111890785396, 0.27649578521959484, 0.3728290769504383, 0.22254222800256684, 0.5152609013020992, 0.6081584945786744, 0.3799268585862592, 1.2560540693812072, 8.190407305955887, 30.060504265129566, 68.04806336760521, 122.8049111366272, 154.7037586569786, 173.2969969511032, 179.51452732086182, 168.1068554520607, 151.5044367313385, 141.97349935770035, 151.93955898284912, 148.71781826019287, 141.8088921904564, 151.35113775730133, 154.50224786996841, 155.7750579714775, 160.4900273680687, 92.63763070106506, 94.73083198070526, 135.90691208839417, 162.85036951303482, 174.83276814222336, 159.68287467956543, 155.91305136680603, 145.19279301166534, 155.97225219011307, 158.18405270576477, 170.18990367650986, 159.18466061353683, 166.39633923768997, 156.34717047214508, 163.36284041404724, 165.58263570070267, 164.81142908334732, 153.79867762327194, 152.52378523349762, 157.81659722328186, 158.0043375492096, 150.9172922372818, 140.56172311306, 100.83471044898033, 55.98289757966995, 21.878205724060535, 4.330769162625074, 0.2921028540004045, 0.3708769613876939, 0.549361458979547, 0.21316676546121016, 0.3500636969693005, 0.2476683649001643, 0.22071605490054935, 0.26768687821459025, 0.17275701742619276, 0.17618867859710008, 0.13486844894941896, 0.18845293612685055, 0.20866675302386284, 0.16755079210270196, 0.25523809308651835, 0.1276368135586381, 0.08684828819241375, 0.09307512242230587, 0.1400171429850161, 0.23586272494867444, 0.16618218272924423, 0.13006927678361535, 0.24466153874527663, 0.12016359425615519, 0.19278357562143356, 0.10071194818010554, 0.17180173977976665, 0.11571004768484272, 0.12357070518191904, 0.11707391473464668, 0.11836012345156632, 0.15438000118592754, 0.09798008773941547, 0.13030179165070876, 0.0919695821357891, 0.24888072250178084, 0.1530330625246279, 0.14090926386415958, 0.23379336489597335, 0.11486132018035278, 0.17343914019875228, 0.20651194208767265, 0.12219819953315891, 0.0881107481836807, 0.15777695953147486, 0.09526214998913929, 0.12973183707799762, 0.14239327720133588, 0.09757546140463091, 0.20189792092423886, 0.15456991677638143, 0.0995471102942247, 0.1661924392101355, 0.14836430054856464, 0.12938108324306086, 0.26719076733570546, 0.13031200360273942, 0.21422353922389448, 0.11136954504763708, 0.2166636465699412, 0.12298212270252407, 0.11726731841918081, 0.1147724331531208], [0.05105829441163223, 0.08326999348355457, 0.013429372793325456, 0.07496550941141322, 0.01089085573767079, 0.07335106362006627, 0.025545357566443272, 0.04173743167484645, 0.02632465158967534, 0.12888708006357774, 0.06620858242968097, 0.029735467687714845, 0.018328568839933723, 0.03881234566506464, 0.06319452033494599, 0.008516280031471979, 0.12205307997646742, 0.031840235606068745, 0.02842628393409541, 0.04667810171667952, 0.06153187576273922, 0.07186230053775944, 0.10523725301027298, 0.02945648695458658, 0.04922903397527989, 0.028105314340791665, 0.03445866619586013, 0.01734262750687776, 0.03402001610083971, 0.04338985316280741, 0.05594294714683201, 0.023928622249513865, 0.022860450953885447, 0.049368368490831926, 0.035267766725155525, 0.03791412433201913, 0.0678163711563684, 0.0332109192822827, 0.009657633581809932, 0.07086224912200123, 0.016598335023445543, 0.04609405375958886, 0.06131813352112658, 0.040766053134575486, 0.02163186072721146, 0.020133338402956724, 0.06729648928740062, 0.06399716789019294, 0.024530815717298537, 0.05307619023369625, 0.025867338335956447, 0.06778871873393655, 0.040021482345764525, 0.09622929457691498, 0.0666650477796793, 0.07419467772706412, 0.021861349487153348, 0.025096508506976534, 0.04854202787100803, 0.008122934341372456, 0.03112744729151018, 0.09899773547658697, 0.03097952427197015, 0.06383337589795701, 0.08091277661151253, 0.006600644273930811, 0.14102947694482282, 0.0014780596893615439, 0.0416933109954698, 0.14030870312126353, 0.194541901582852, 0.3672073082998395, 0.17287279246374965, 2.714803987182677, 12.35795147716999, 21.91570971161127, 23.32010105252266, 43.26383627951145, 43.741622641682625, 49.88428182899952, 49.09197874367237, 55.96890673041344, 46.21027797460556, 34.67288486659527, 30.51837209612131, 8.153766822069883, 0.26397088542580605, 0.8888888556975871, 1.8650517845526338, 9.278599563986063, 26.81863982230425, 18.912787847220898, 32.71320462226868, 43.06791879236698, 34.53624039888382, 31.25897705554962, 32.631482407450676, 18.259851783514023, 13.321963548660278, 1.9453647499904037, 6.2042709812521935, 15.539466608315706, 22.59316585958004, 21.633363962173462, 22.086221762001514, 11.299791857600212, 7.853128854185343, 3.126541106030345, 1.432772136759013, 0.050356530700810254, 0.750413954956457, 0.5857673054561019, 0.23676473123487085, 0.0887192202208098, 0.04183763645414729, 0.042601414024829865, 0.052876767731504515, 0.12126477071433328, 0.13998294482007623, 0.04266146490408573, 0.0192726771638263, 0.08697523997398093, 0.09195754450047389, 0.05861132427526172, 0.07840407997719012, 0.026350177759013604, 0.010959610153804533, 0.03388498233107384, 0.06717969750752673, 0.021450001149787568, 0.04633405689673964, 0.06142580801679287, 0.025589333527022973, 0.013198809774621623, 0.027916686376556754, 0.056947458870126866, 0.03954082298150752, 0.05863889506144915, 0.009392275896971114, 0.025790227336983662, 0.0440702355990652, 0.02827668551617535, 0.014306715656857705, 0.022036802474758588, 0.007741393437754596, 0.05189953364606481, 0.022570217406610027, 0.039609308369108476, 0.04524310723354574, 0.022081670867919456, 0.04843578200961929, 0.07079009010340087, 0.02646427739819046, 0.0847476020862814, 0.07148520788177848, 0.014315522166725714, 0.01080630749129341, 0.02242891805508407, 0.009590550853317836, 0.023787922182236798, 0.04104790226847399, 0.07059759183903225, 0.09162774149444886, 0.03904831894033123, 0.028841289204137865, 0.019516365064191632, 0.019068102301389445, 0.012734910887957085, 0.06997152348048985, 0.018601306255732197, 0.010124247801286401, 0.027076768164988607, 0.026080876486958005, 0.04131385459913872, 0.01259082198885153, 0.04363874722912442, 0.0332588360470254, 0.06386903609381989, 0.03375109517946839, 0.05183272922295146, 0.04260143999999855, 0.03748613889911212, 0.08733084745472297, 0.03371677084942348, 0.043469370575621724, 0.020362415270938072, 0.07057330876705237, 0.09195088743581437, 0.0693003399646841, 0.02600350202556001, 0.02460204705130309, 0.020852076886512805, 0.08426197033259086, 0.03305123507743701, 0.06091580042266287, 0.014556391761288978, 0.12628608994418755, 0.044820413313573226, 0.03305294943857007, 0.044220104900887236, 0.012946354327141307, 0.015253834317263681, 0.044663181906798854, 0.07016356903477572, 0.014599028145312332, 0.018554875641711988, 0.050456086100894026, 0.024131041172950063, 0.04777452471898869, 0.06046631868230179, 0.04617274367774371, 0.001875786022083048, 0.12357153638731688, 0.037395348263089545, 0.01644624484470114, 0.051395615373621695, 0.09249429538613185, 0.03785697525017895, 0.0497956525941845, 0.018551522989582736, 0.0727746523625683, 0.041225746826967224, 0.01996468719880795, 0.05536151526030153, 0.029168121764087118, 0.057905029752873816, 0.03301647288026288, 0.039993080354179256, 0.06091203773394227, 0.05368874408304691, 0.09431021942873485, 0.041609622712712735, 0.011764051851059776, 0.04954747098963708, 0.037571912616840564, 0.04078747893800028, 0.02480713214026764, 0.11787631738116033, 0.05864227183337789, 0.11394979213946499, 0.04827398639463354, 0.02751036052359268, 0.3158932883525267, 0.37664986099116504, 0.03921923183952458, 0.13822271896060556, 0.3410491260001436, 1.010887543670833, 3.379012383520603, 14.751514289528131, 34.834516793489456, 47.26046562194824, 55.62498718500137, 81.79080113768578, 84.16796877980232, 80.85677325725555, 79.40737143158913, 82.39496111869812, 74.0164715051651, 59.7454746812582, 48.975849375128746, 16.047568693757057, 0.36641309154219925, 0.5037838546559215, 3.9706973964348435, 15.400091037154198, 37.115747183561325, 32.03463703393936, 49.921915009617805, 58.70293602347374, 52.632856741547585, 53.153269216418266, 46.90817892551422, 31.023446694016457, 24.426048807799816, 6.741163171827793, 12.413848377764225, 32.83200144767761, 42.448278442025185, 43.74201022088528, 42.33361579477787, 25.927536338567734, 20.251114033162594, 10.99239120259881, 6.602410292252898, 0.4700302064884454, 0.7709529215935618, 0.3331029211403802, 0.16847279184730724, 0.14008029975229874, 0.03790483264310751, 0.061496512425947, 0.08345889233169146, 0.04547635682683904, 0.03722158551681787, 0.017172863081214018, 0.031194967887131497, 0.0758414069423452, 0.02685264884348726, 0.05720942957850639, 0.024973341678560246, 0.019907152200175915, 0.03689856945129577, 0.04482685144466814, 0.033908222685568035, 0.062429870740743354, 0.09576672135153785, 0.03534977775416337, 0.07062740391120315, 0.008466262988804374, 0.010180866247537779, 0.039656334556639194, 0.06103804327722173, 0.06817104353103787, 0.036094389361096546, 0.0929327413905412, 0.053979944277671166, 0.0684253552753944, 0.0326817902532639, 0.02519766137993429, 0.061495310146710835, 0.05568390050029848, 0.05343544537026901, 0.04881179855146911, 0.04333365031925496, 0.0817814604670275, 0.08806294645182788, 0.04304390473407693, 0.07135356572689489, 0.07949111852212809, 0.052203532177372836, 0.018726690250332467, 0.027971002309641335, 0.027545599550649058, 0.008509698109264718, 0.0518726233713096, 0.040948491587187164, 0.05061602634668816, 0.08782465767581016, 0.07326012084376998, 0.028503190842457116, 0.023097351913747843, 0.05339055285730865, 0.1043933791515883, 0.0890825386159122, 0.02381254107604036, 0.024432675963907968, 0.08507388731231913, 0.018178781174356118, 0.02971578222059179, 0.037043766933493316, 0.00783020996095729, 0.1418136598658748, 0.2653507754439488, 0.13287554495036602, 0.21002097957534716, 0.20158284954959527, 0.17500470072263852, 0.14742891245987266, 0.13619098579511046, 0.11094858404248953, 0.2032545965630561, 0.21188157348660752, 0.14535962662193924, 0.12277786881895736, 0.13565019762609154, 0.1842161189415492, 0.11978069058386609, 0.21024132322054356, 0.1395901557407342, 0.19154504989273846, 0.08933938108384609, 0.2590091829188168, 0.14694801560835913, 0.1774300541728735, 0.1328357361489907, 0.07155438346671872, 0.11629289336269721, 0.09834658994805068, 0.12262684176675975, 0.1710811589146033, 0.09652518885559402, 0.25393277406692505, 0.1170395161898341, 0.10701381354010664, 0.15436400048201904, 0.2400816563749686, 0.09170641656965017, 0.1917577494168654, 0.11188835080247372, 0.09563022555084899, 0.22201687650522217, 0.1747455427539535, 0.11621292695053853, 0.07631814776686952, 0.19619932514615357, 0.16457645717309788, 0.10195056296652183, 0.1987194805406034, 0.1995991333387792, 0.11839476690511219, 0.14476383046712726, 0.10586707663605921, 0.14570855477359146, 0.18506212276406586, 0.21299945568898693, 0.19403602404054254, 0.1575687574222684, 0.16680842178175226, 0.13849133189069107, 0.20645257027354091, 0.11369713538442738, 0.1091363187879324, 0.4881338600534946, 0.13949594751466066, 0.21636994904838502, 0.18438495753798634, 0.14441214152611792, 0.5998194264248013, 0.2347028668737039, 0.11618309261393733, 0.34398429037537426, 0.18949019140563905, 0.39210755028761923, 0.6152494484558702, 4.966745786368847, 18.29347997903824, 31.583774127066135, 44.1165941208601, 72.84533634781837, 81.75150364637375, 72.41660535335541, 73.4033516049385, 80.2491706609726, 69.43730682134628, 55.87524935603142, 41.91956341266632, 14.94848906993866, 0.37657071836292744, 0.9432700532488525, 3.316277749836445, 14.001587480306625, 34.92307864129543, 35.26049293577671, 58.01608867943287, 66.04937821626663, 57.30681873857975, 58.177374824881554, 44.99398984014988, 29.922655262053013, 21.634032726287842, 5.444979099556804, 9.374666959047318, 26.764627620577812, 31.985235884785652, 32.99281641840935, 29.17799971997738, 16.677158810198307, 10.947184078395367, 4.8909408040344715, 2.1715419134125113, 0.24293430877150968, 0.9054521075449884, 0.779109065188095, 0.3076355595840141, 0.16366886993637308, 0.1713716800441034, 0.1478102130931802, 0.16609872080152854, 0.21520488109672442, 0.26225886947941035, 0.11626564912148751, 0.2010395232355222, 0.24950138060376048, 0.19912168005248532, 0.17154575820313767, 0.15898069337708876, 0.1499899008194916, 0.14839665818726644, 0.12708777270745486, 0.11612963571678847, 0.162129744712729, 0.18507699540350586, 0.31122767308261245, 0.14727016707183793, 0.16540398151846603, 0.10675562778487802, 0.20079964626347646, 0.19021434942260385, 0.11979922943282872, 0.15218827582430094, 0.13326656771823764, 0.14986130147008225, 0.21942485152976587, 0.17374647839460522, 0.08897042978787795, 0.12921418907353655, 0.11774846017942764, 0.22420729568693787, 0.14987336879130453, 0.20414210128365085, 0.16017635265598074, 0.21444468438858166, 0.19874523306498304, 0.14986192487413064, 0.20862281788140535, 0.23021820205030963, 0.12995888973819092, 0.07494979814509861, 0.135603308735881, 0.05494016091688536, 0.12800058466382325, 0.10922953253611922, 0.12874706648290157, 0.20140311622526497, 0.18995930295204744, 0.09062060998985544, 0.1073499396443367, 0.12558496819110587, 0.18026519188424572, 0.20105638483073562, 0.14724831824423745, 0.11860325845191255, 0.16813861759146675, 0.08768253639573231, 0.08684399857884273, 0.11892609269125387, 0.18826685001840815], [0.011348524294589879, 0.02436195114569273, 0.05737259074521717, 0.05260372046905104, 0.047362636469188146, 0.025467393097642343, 0.03606782789574936, 0.03133590544166509, 0.00795223666500533, 0.014230604701879201, 0.008783616467553657, 0.05128823402628768, 0.11733034902135842, 0.08481852913973853, 0.008667155871080467, 0.03650037011539098, 0.03478109967545606, 0.07927633356302977, 0.07762225708574988, 0.03559130600478966, 0.022827694410807453, 0.03041031741304323, 0.04434934620803688, 0.04363003812613897, 0.06034506659489125, 0.0400535357039189, 0.019908899957954418, 0.019674859977385495, 0.018240678145957645, 0.06021915382007137, 0.009135760901699541, 0.029919893240730744, 0.012743675652018283, 0.047229710398823954, 0.03249878776841797, 0.018106288189301267, 0.07443139315000735, 0.029609970515593886, 0.0481997419410618, 0.06152376408863347, 0.025642126202001236, 0.0146999787830282, 0.04366843313619029, 0.0715031084837392, 0.03595477654016577, 0.04277277963410597, 0.030760863446630538, 0.0077514156782854116, 0.02880695745261619, 0.08002375048818067, 0.09346633072709665, 0.01768715286743827, 0.0435217847552849, 0.06761495227692649, 0.06619553547352552, 0.10092088501551189, 0.03239160309021827, 0.03875396461808123, 0.022697963286191225, 0.04542310030956287, 0.05248237190244254, 0.08786594335106201, 0.07933456989121623, 0.0370455406664405, 0.08480654345476069, 0.05081806120870169, 0.10107937065185979, 0.09494287063716911, 0.07366223871940747, 0.028892725604237057, 0.03398244487470947, 0.1551154992193915, 0.03635888337157667, 0.12290372964343987, 0.2834857179550454, 0.6130259146448225, 0.5736295692622662, 0.7744036708027124, 0.7039317616727203, 0.40455633541569114, 0.454971287981607, 0.6273698480799794, 0.5771899782121181, 0.7557463750708848, 0.8098443690687418, 0.1873871823772788, 0.11628272593952715, 0.16383883659727871, 0.11067641622503288, 0.39189556322526187, 0.80064055044204, 0.31100309919565916, 0.46054033446125686, 0.44530600192956626, 0.4680902324616909, 0.5310718528926373, 0.8579341135919094, 0.4286159318871796, 0.2781455498188734, 0.1825111682410352, 0.10186663348576985, 0.7922717370092869, 0.4820614296477288, 0.753436217783019, 1.0973922768607736, 0.5776019592303783, 0.5297129508107901, 0.2442724900902249, 0.07661287687369622, 0.17725989455357194, 0.33709632873069495, 0.17117045412305743, 0.060757901082979515, 0.21316428668797016, 0.08021505389478989, 0.09713478895719163, 0.017033005351549946, 0.06708483619149774, 0.0704618010786362, 0.05733969133871142, 0.03729355528776068, 0.0739029394753743, 0.04538440472970251, 0.011443499715824146, 0.02963955994346179, 0.0667308243282605, 0.06397812438081019, 0.012392041444400093, 0.07622920136782341, 0.06874001846881583, 0.08513404580298811, 0.017707448751025368, 0.050664919035625644, 0.027281059155939147, 0.05711224162951112, 0.0329488335410133, 0.04366762419522274, 0.05207593843806535, 0.037579200507025234, 0.1055523392278701, 0.023956348886713386, 0.09094716981053352, 0.009919818585331086, 0.017599744569452014, 0.04104922329133842, 0.05587868457951117, 0.01393720867781667, 0.009379156581417192, 0.022763086744816974, 0.018986659015354235, 0.01889477927761618, 0.06052252894733101, 0.039146868730313145, 0.02281014261825476, 0.028157760061731096, 0.04766051599290222, 0.012536493995867204, 0.025836856475507375, 0.08428600107436068, 0.022089658232289366, 0.014929426724847872, 0.06512305786600336, 0.00785980031650979, 0.033513021626276895, 0.032070839442894794, 0.012442993593140272, 0.023600437125423923, 0.024391073020524345, 0.026173294281761628, 0.028782383087673225, 0.03229378802643623, 0.012858784612035379, 0.024663103540660813, 0.035774122952716425, 0.011538438957359176, 0.015460432459803997, 0.0625323984422721, 0.045097516413079575, 0.10530502593610436, 0.009905685310513945, 0.020235725096426904, 0.020436978848010767, 0.04635145283828024, 0.047782577021280304, 0.053690317436121404, 0.08656716265249997, 0.044629581170738675, 0.023009104988886975, 0.039105211981222965, 0.062410122191067785, 0.009363240296806907, 0.024699583809706382, 0.06443277146900073, 0.056222109706141055, 0.06825469099567272, 0.029168199689593166, 0.04889019903203007, 0.025810359948081896, 0.050556598871480674, 0.02122698391758604, 0.0507527262379881, 0.021583211091638077, 0.05597977993602399, 0.02866330734832445, 0.015304741937143262, 0.09112647268921137, 0.03726464492501691, 0.018131716024072375, 0.04923166117805522, 0.07727819742285646, 0.06670525734080002, 0.025743928454176057, 0.03949774873035494, 0.028367570776026696, 0.026462332971277647, 0.01899555922136642, 0.020981180896342266, 0.037158959385124035, 0.042103551677428186, 0.040818667694111355, 0.02707853818719741, 0.05820467929879669, 0.017454886619816534, 0.05002766651159618, 0.01225945397891337, 0.039195171411847696, 0.09807219568756409, 0.043148840704816394, 0.037671913305530325, 0.02402815724053653, 0.013991715713927988, 0.04915218458336312, 0.013231410466687521, 0.027334031801728997, 0.05477503676956985, 0.06375732802553102, 0.036842722838628106, 0.09223316330462694, 0.0447476271801861, 0.05046527017839253, 0.06564087656443007, 0.044195762457093224, 0.12342870264546946, 0.14651449746452272, 0.09975408043828793, 0.06291867888648994, 0.06518863403471187, 0.1290024840272963, 0.010337572584830923, 0.24952643550932407, 0.1300838970928453, 0.6363947200588882, 0.8503691351506859, 1.756992470473051, 1.4870863035321236, 0.5112139997072518, 0.33517817384563386, 0.47818439081311226, 0.45225817419122905, 0.36483466217759997, 0.6486855167895555, 0.37513300019782037, 0.048866001307033, 0.08018859633011743, 0.1379966310923919, 0.39163020090200007, 0.7503129635006189, 0.4661065310938284, 0.2238852481241338, 0.047035965326358564, 0.18058713554637507, 0.3760263678850606, 0.30224786431062967, 0.34138140035793185, 0.34950563160236925, 0.13382917502894998, 0.08496620168443769, 0.8070192206650972, 0.33927521493751556, 0.23758974712109193, 0.32088936713989824, 0.41347508027683944, 0.5009575781878084, 0.35641796537674963, 0.21800895250635222, 0.2115328234503977, 0.08740586374187842, 0.053985992781235836, 0.030513720848830417, 0.04184626763162669, 0.05428379437944386, 0.12634086044272408, 0.10191468754783273, 0.07257114062667824, 0.020788617694051936, 0.05285928273224272, 0.04826440155738965, 0.010683205600798829, 0.023020630542305298, 0.025895083526847884, 0.06808742575231008, 0.06589558164705522, 0.04903318862488959, 0.03741783162695356, 0.03265463135903701, 0.06682848354103044, 0.08012941005290486, 0.04128784603381064, 0.012950415730301756, 0.08751286659389734, 0.05509020833414979, 0.10311146004823968, 0.01934864340000786, 0.008702521063241875, 0.004148506250203354, 0.034066096050082706, 0.017994522604567464, 0.02174421817471739, 0.03413239581277594, 0.014831264707027003, 0.04102534097910393, 0.027075525067630224, 0.02626449495437555, 0.027143932529725134, 0.010354392434237525, 0.04721490455267485, 0.037348537298385054, 0.06048129522241652, 0.031547142934869044, 0.06092133313359227, 0.09928491694154218, 0.05741815119108651, 0.03998429703642614, 0.03903946511854883, 0.04863970563746989, 0.04102419065020513, 0.0033421516673115548, 0.007367343587247888, 0.060753403668059036, 0.013371721834118944, 0.02854722803022014, 0.04390749745653011, 0.03238844525185414, 0.016505141684319824, 0.05645982702844776, 0.03962169481383171, 0.022460485306510236, 0.04153088084422052, 0.011138331374240806, 0.1118617522297427, 0.04440682183485478, 0.03256736592447851, 0.15930409164866433, 0.10655127000063658, 0.16876384732313454, 0.09041919111041352, 0.08524824006599374, 0.14076402556383982, 0.16444836248410866, 0.08746282357606106, 0.1143944647628814, 0.17747306905221194, 0.1275460934266448, 0.14181950798956677, 0.2778004214633256, 0.0951726469793357, 0.06654727636487223, 0.1538153158617206, 0.1258901838446036, 0.1218169582716655, 0.11907100444659591, 0.12271900166524574, 0.1024907203100156, 0.11830791336251423, 0.1782906783046201, 0.070314447657438, 0.2265526307746768, 0.1315575500484556, 0.08929949064622633, 0.10258719950797968, 0.0841925127315335, 0.24069300794508308, 0.09503499342827126, 0.13364944170461968, 0.12239026735187508, 0.18234427407151088, 0.1556163895293139, 0.12517913215560839, 0.11933738351217471, 0.0855362304719165, 0.19702451914781705, 0.17785334552172571, 0.10609101227601059, 0.18130727112293243, 0.08118570884107612, 0.14786156971240416, 0.09710828686365858, 0.2788698859512806, 0.10545054625254124, 0.16656771360430866, 0.09443771297810599, 0.14184306375682354, 0.23030699259834364, 0.13401591422734782, 0.1377416291506961, 0.1653872535098344, 0.09778106599696912, 0.1460352778667584, 0.08692036557476968, 0.113279855431756, 0.14713088079588488, 0.23983898892765865, 0.12724558298941702, 0.1825188272050582, 0.08631506992969662, 0.18444922752678394, 0.17012752883601934, 0.14232287707272917, 0.2554824674734846, 0.26599766104482114, 0.12290648301132023, 0.12948096147738397, 0.15628323890268803, 0.28976716683246195, 0.09287354027037509, 0.2411604719236493, 0.35037798166740686, 0.4329860833240673, 0.8237867709249258, 1.0197113826870918, 1.03219905635342, 0.5980119109153748, 0.39194896817207336, 0.5994701420422643, 0.6349972856696695, 0.8952544641215354, 1.0505996877327561, 0.46263877185992897, 0.1385698511148803, 0.40072795178275555, 0.21204073447734118, 0.4905551910633221, 1.0036673373542726, 0.7260370755102485, 0.5131066543981433, 0.656989139970392, 0.5795629508793354, 0.5686520144809037, 0.7563136727549136, 0.6890898174606264, 0.47832670505158603, 0.23850266297813505, 0.12120887215132825, 1.0643833293579519, 0.4697549290722236, 0.8661673811729997, 1.0237510409206152, 0.7351887063123286, 0.4991011996753514, 0.2699418197153136, 0.18044917029328644, 0.27278656081762165, 0.42930666357278824, 0.16597200650721788, 0.15985096542863175, 0.21986712701618671, 0.1884629254345782, 0.19569631229387596, 0.12086707603884861, 0.15189293073490262, 0.13533583871321753, 0.15311170049244538, 0.13705628545721993, 0.16618475056020543, 0.1224997935059946, 0.06822589566581883, 0.17014660203130916, 0.2038476467714645, 0.14191613561706617, 0.1057821155700367, 0.22571441950276494, 0.18178321042796597, 0.21433561836602166, 0.06410277550457977, 0.10605267292703502, 0.18561019882326946, 0.14452341914875433, 0.27920720691327006, 0.14551388943800703, 0.10163676808588207, 0.13744135620072484, 0.19118660740787163, 0.0764647516189143, 0.17889922455651686, 0.14076880499487743, 0.12367638701107353, 0.15331409900682047, 0.15355397597886622, 0.08660139050334692, 0.14608675322961062, 0.13422865828033537, 0.13560161663917825, 0.12038606786518358, 0.21246206655632704, 0.15271292970282957, 0.2037635911256075, 0.18262211931869388, 0.1159438538888935, 0.1495405749301426, 0.09729516707011499, 0.16900915681617334, 0.10295793195837177, 0.08262036935775541, 0.1924489115481265, 0.11493143087136559, 0.1197007241717074, 0.12131672847317532, 0.1290735075599514, 0.09744086550199427, 0.1044643581553828, 0.09809446011786349, 0.15233813028316945, 0.11127163350465707, 0.10720084959757514, 0.12727905384963378, 0.2032384622725658, 0.1190207016770728, 0.12358210457023233], [0.018112518519046716, 0.04445693535672035, 0.014591951767215505, 0.011380727009964176, 0.0007680528051423607, 0.06555627915076911, 0.04648743284633383, 0.039306842372752726, 0.02810137168125948, 0.02407258034509141, 0.015752611361676827, 0.062394997221417725, 0.05766636990301777, 0.023894559526524972, 0.11603787657804787, 0.059669552647392265, 0.029823382501490414, 0.044294627659837715, 0.015345193623943487, 0.04185673933534417, 0.022049034923838917, 0.04885716232820414, 0.06511209634481929, 0.03514795440423768, 0.04132996662519872, 0.04424858852871694, 0.03430891563766636, 0.05112935134093277, 0.018009742198046297, 0.0680234155151993, 0.07881712968810461, 0.06164279344375245, 0.03744908346561715, 0.019043294159928337, 0.02854486428987002, 0.04086861794348806, 0.009276572291128105, 0.06856893116491847, 0.07182053246651776, 0.06673480966128409, 0.045984568423591554, 0.022358890855684876, 0.02341197985515464, 0.0648662079765927, 0.03543505794368684, 0.02507883054931881, 0.047903888480504975, 0.0046135067623254145, 0.004522588569670916, 0.07720427209278569, 0.09036245392053388, 0.019579332583816722, 0.015762120128783863, 0.061138081073295325, 0.03640834751422517, 0.06920144878677092, 0.010484759022801882, 0.03462301850959193, 0.015557949736830778, 0.04659136691770982, 0.07301625853870064, 0.03340830087836366, 0.029224281934148166, 0.03509630463668145, 0.05331778527761344, 0.04422460973728448, 0.07990377489477396, 0.0740872741152998, 0.0523064086883096, 0.006395651489583543, 0.07332482127822004, 0.07665366531000473, 0.14318972040200606, 0.06666504035820253, 0.14637096610385925, 0.2348724179319106, 0.19530343415681273, 0.3694261220516637, 0.31244384532328695, 0.2714773529442027, 0.17275587451877072, 0.2361505149747245, 0.18690423719817773, 0.29452077113091946, 0.29494667483959347, 0.07271643087733537, 0.032989280589390546, 0.19569821219192818, 0.10850014237803407, 0.056422155612381175, 0.2171699545579031, 0.11256251033046283, 0.09615887960535474, 0.2431009357678704, 0.1518359041074291, 0.29263636912219226, 0.1945085494662635, 0.16812834626762196, 0.05104768541059457, 0.03869319385557901, 0.0690427033987362, 0.20397091750055552, 0.2273121298640035, 0.314114568172954, 0.2668690314749256, 0.12469026463804767, 0.1251995115308091, 0.013972600772831356, 0.15038062672829255, 0.13056385883828625, 0.14021203096490353, 0.15560288244159892, 0.0888621059129946, 0.05118615532410331, 0.03465136484010145, 0.06825422344263643, 0.017295601319347043, 0.034483030904084444, 0.03795132819504943, 0.07506223351811059, 0.03340857176226564, 0.012634450995392399, 0.015903963103482965, 0.04465443198569119, 0.018374129285803065, 0.03881995638948865, 0.05786153247754555, 0.04911256874038372, 0.06987628366914578, 0.0320812629070133, 0.045556594122899696, 0.04083562205778435, 0.06106840453867335, 0.039646467703278176, 0.012987376539967954, 0.0952367611171212, 0.05592569592408836, 0.061405005617416464, 0.02304002471646527, 0.022211238720046822, 0.03448116440267768, 0.015556403286609566, 0.03144583235553, 0.026792327080329414, 0.04997101095796097, 0.03242549326387234, 0.09727523298352025, 0.01104359251257847, 0.033570586310816, 0.04525787597231101, 0.09114439555560239, 0.023319435895245988, 0.09438130233320408, 0.06177143361128401, 0.01655162610404659, 0.039654108113609254, 0.06358801445458084, 0.03923197822587099, 0.02720332475291798, 0.05615702335489914, 0.07406898759654723, 0.06764256017049775, 0.0832442483806517, 0.007298569225895335, 0.026196621838607825, 0.05168187286471948, 0.02764868757367367, 0.013006907083763508, 0.023084681597538292, 0.08026734562008642, 0.04088658533873968, 0.053624782085535116, 0.010009110083046835, 0.04543920120340772, 0.0648194452514872, 0.0744409668550361, 0.03043550404981943, 0.0431442579429131, 0.004061884628754342, 0.032725417404435575, 0.018392263664281927, 0.029943508379801642, 0.02460937204887159, 0.059375636192271486, 0.009084850498766173, 0.008131043232424418, 0.05478576822497416, 0.07744079455733299, 0.024224171429523267, 0.015285947047232185, 0.062034417351242155, 0.061826200399082154, 0.06208837148733437, 0.036936994147254154, 0.02807403838232858, 0.0437032213085331, 0.018160103172704112, 0.09757133506354876, 0.0443584375170758, 0.05056301844888367, 0.043360386189306155, 0.08135055468301289, 0.03411627636523917, 0.016780504447524436, 0.035084693736280315, 0.024172978082788177, 0.07729614255367778, 0.025245017823181115, 0.01586091297212988, 0.020985609662602656, 0.05407828626630362, 0.04510599173954688, 0.04516741188126616, 0.06608573472476564, 0.0009219259936799062, 0.0555641623941483, 0.012846499284933088, 0.0540232708590338, 0.014932641151972348, 0.05124447699927259, 0.07831867362256162, 0.03176502636051737, 0.06857067521195859, 0.06732283552992158, 0.07045988633763045, 0.022820441772637423, 0.1767510929494165, 0.03322860095067881, 0.030003277242940385, 0.02640054175572004, 0.019774459906329866, 0.04237379733240232, 0.012119658404117217, 0.06199312054377515, 0.05088357429485768, 0.04274797705875244, 0.09624758851714432, 0.09146349679213017, 0.033579028240637854, 0.04109456109290477, 0.07938495429698378, 0.045510473355534486, 0.05523608488147147, 0.08633195378934033, 0.053750060324091464, 0.020550221306621097, 0.11487519834190607, 0.06252909588511102, 0.12059614760801196, 0.04879892600001767, 0.08055973696173169, 0.07247823858051561, 0.24688149540452287, 0.2776740485569462, 0.1519993250258267, 0.10798950024764054, 0.0652789014566224, 0.10980618870235048, 0.07282868071342818, 0.1585096967755817, 0.2468037628568709, 0.10389139788458124, 0.11790739110438153, 0.14373706915648654, 0.04573522164719179, 0.025374936340085696, 0.031469937312067486, 0.11393416250939481, 0.09271157396142371, 0.04547627890133299, 0.057895674981409684, 0.1697727377177216, 0.10246782505419105, 0.07217158316052519, 0.07729386416031048, 0.04152873974817339, 0.08095624420093372, 0.11589191839448176, 0.08157031945302151, 0.1970123330829665, 0.10299978166585788, 0.11342678582877852, 0.15078079275554046, 0.04664612999476958, 0.1072978186130058, 0.08002774324268103, 0.1123924991406966, 0.19720818585483357, 0.02153116056433646, 0.03367758916283492, 0.01334408425464062, 0.031874500564299524, 0.055249699580599554, 0.01507054239482386, 0.007544231702922843, 0.0762331199075561, 0.033158453152282164, 0.04517165696597658, 0.025770155953068752, 0.020038673756062053, 0.02431011769658653, 0.04588473471812904, 0.02784805812552804, 0.009556137465551728, 0.04080346479895525, 0.014243315836210968, 0.01620319890207611, 0.004931343564749113, 0.01564514466736, 0.04939531958370935, 0.035068065917585045, 0.05194640027184505, 0.05664204654749483, 0.06058167440642137, 0.05383316231018398, 0.04508810969127808, 0.018419686020934023, 0.09677061709226109, 0.08123365900246426, 0.007656444895474124, 0.029084863926982507, 0.0009773244187272212, 0.06753346446203068, 0.02499334997992264, 0.04019129686639644, 0.0507533236668678, 0.01675230098044267, 0.0374861871387111, 0.048411691896035336, 0.05026417042245157, 0.06962243947782554, 0.01391139863699209, 0.036244744769646786, 0.07687586432439275, 0.04963684783433564, 0.05626907281111926, 0.029913063626736403, 0.04458883355255239, 0.104921780875884, 0.0695221011119429, 0.02240603578684386, 0.020556690978992265, 0.03427143346925732, 0.016417022779933177, 0.03286385763203725, 0.03948077210225165, 0.016689698968548328, 0.04012728662928566, 0.017417899834981654, 0.03438600993831642, 0.006483573724835878, 0.03851701541861985, 0.10763928075903095, 0.2536936540855095, 0.07281541853444651, 0.091764927492477, 0.23013674392132089, 0.12098017934476957, 0.1980600823299028, 0.18617204914335161, 0.14474039344349876, 0.0850674751563929, 0.10317596010281704, 0.15330966096371412, 0.18779111851472408, 0.09217221813742071, 0.21464978432049975, 0.2207551512401551, 0.13912692200392485, 0.10610053403070197, 0.10398019585409202, 0.17109095526393503, 0.12023469942505471, 0.26174693601205945, 0.11737989480025135, 0.1868183261831291, 0.14269401028286666, 0.16234262235229835, 0.13012343872105703, 0.12921338755404577, 0.07085034507326782, 0.08162861515302211, 0.265863302629441, 0.13966958038508892, 0.1452437328407541, 0.16582564014242962, 0.14434757467824966, 0.1819142440217547, 0.12220020333188586, 0.11023196624591947, 0.14268931990955025, 0.15685625112382695, 0.12716425844701007, 0.12563921918626875, 0.09141365415416658, 0.12673678138526157, 0.1550089119700715, 0.09252130214008503, 0.1701644729473628, 0.10853473388124257, 0.20579332049237564, 0.11770816156058572, 0.2275559402187355, 0.0941548656555824, 0.11165167990839109, 0.10383853470557369, 0.09758576983585954, 0.147128906683065, 0.11657601527986117, 0.1741054403828457, 0.13392682682024315, 0.1456643673009239, 0.20667810895247385, 0.21943497442407534, 0.16813268041005358, 0.20130436605541036, 0.15081184421433136, 0.11457879198133014, 0.22387926641386002, 0.1537049881881103, 0.16445385437691584, 0.1802375097759068, 0.19075752730714157, 0.34016721707303077, 0.24644530552905053, 0.10424204781884328, 0.1496635636431165, 0.15736298955744132, 0.5010542355012149, 0.6646089779678732, 0.4591265431372449, 0.32238794141449034, 0.1446536066941917, 0.4329586832318455, 0.38419830438215286, 0.3695372067159042, 0.3887800866505131, 0.29028963879682124, 0.2851452789036557, 0.22806940251030028, 0.13664094993146136, 0.17269626521738246, 0.3233129542786628, 0.27067776303738356, 0.20525958272628486, 0.4350479773711413, 0.18799752462655306, 0.3518570226151496, 0.15391552064102143, 0.4293901997152716, 0.19903173175407574, 0.07667970727197826, 0.18356341490289196, 0.23018994106678292, 0.3841338859638199, 0.3982904419535771, 0.3519747272366658, 0.22457982413470745, 0.2937923086574301, 0.08895078513887711, 0.1354892406379804, 0.2106796801672317, 0.18834624497685581, 0.3374065167736262, 0.2616561861941591, 0.14823923382209614, 0.11160455353092402, 0.2594416175270453, 0.09059183692443185, 0.13658894022228196, 0.14785465289605781, 0.19263930211309344, 0.159403316793032, 0.13134490989614278, 0.12224171907291748, 0.14488294516922906, 0.06332679331535473, 0.1543463225243613, 0.14620763424318284, 0.11797053302871063, 0.1482093846425414, 0.1887445556349121, 0.14526562619721517, 0.08679211503476836, 0.09916846654959954, 0.19561503228032961, 0.2103978570085019, 0.1971536676865071, 0.16570060310186818, 0.15716689929831773, 0.12535144400317222, 0.12005471377051435, 0.09505059337243438, 0.13925292383646592, 0.18180384213337675, 0.11868138433783315, 0.11066547696827911, 0.06890833756187931, 0.26473114150576293, 0.12314842315390706, 0.10200374526903033, 0.17283979657804593, 0.15261705906596035, 0.128659151669126, 0.17663686157902703, 0.1310233521508053, 0.07156995372497477, 0.10664432789781131, 0.08400234481086954, 0.14112775214016438, 0.15704545425251126, 0.13383962446823716, 0.12631078861886635, 0.1149531832197681, 0.17098496173275635, 0.13269371876958758, 0.1146941959450487, 0.15760258451336995, 0.0886387936770916, 0.13404224562691525, 0.14045941847143695, 0.165722155070398, 0.10482668207259849, 0.13129598752129823, 0.10293378989445046, 0.12471572030335665, 0.1323497184785083, 0.16978364728856832], [0.03296265975222923, 0.002401336623734096, 0.055707801366224885, 0.06828695215517655, 0.04257496017089579, 0.0139640261841123, 0.05904780358832795, 0.04386972213978879, 0.04484828095883131, 0.03908636143023614, 0.049230484873987734, 0.01974270897335373, 0.028439247398637235, 0.04697245232819114, 0.026985415352100972, 0.012838544389524031, 0.02629348138725618, 0.05169970296265092, 0.03833995382592548, 0.030155758904584218, 0.016339063877239823, 0.06581269859452732, 0.0386806478491053, 0.05079576338175684, 0.02838818578311475, 0.044776678550988436, 0.043097751258756034, 0.03133787955448497, 0.0464471824670909, 0.051778849301626906, 0.01326388499364839, 0.02877075177821098, 0.039494791271863505, 0.040525200238334946, 0.01451540758353076, 0.07149751269025728, 0.052181531209498644, 0.0548278108908562, 0.037619239374180324, 0.07027417130302638, 0.00881082452906412, 0.044244224700378254, 0.03488914524496067, 0.06872406229376793, 0.030525918045896105, 0.02917787729529664, 0.04768869905092288, 0.022265094521571882, 0.013143599553586682, 0.024862711579771712, 0.03153392157400958, 0.03959669928008225, 0.031014861633593682, 0.06740078330039978, 0.02769753016764298, 0.010296201562596252, 0.014404623489099322, 0.027941615117015317, 0.03308887309685815, 0.05768417402578052, 0.02998726355144754, 0.029578546127595473, 0.019237358355894685, 0.11009888432454318, 0.04296836894354783, 0.07383664342341945, 0.048367304043495096, 0.03369714475411456, 0.0166690116020618, 0.010729533241828904, 0.04418774726218544, 0.06668233982054517, 0.030468833901977632, 0.08823281663353555, 0.09258860751288012, 0.1183387718629092, 0.23427776468452066, 0.2647401363356039, 0.17868297756649554, 0.13546322094043717, 0.2983732003485784, 0.15047559194499627, 0.21064378990558907, 0.2021500581759028, 0.19254439626820385, 0.12246290876646526, 0.07923257653601468, 0.12052567326463759, 0.08071169912000187, 0.17604931810637936, 0.08974501673947088, 0.0679667822259944, 0.21368036133935675, 0.14081248780712485, 0.10040530018159188, 0.16695443191565573, 0.26872728019952774, 0.08514990549883805, 0.0759654123976361, 0.024762178400123958, 0.03213089032215066, 0.08721109450561926, 0.1440517694572918, 0.13104067387757823, 0.1820067601511255, 0.11729606179869734, 0.04625642453902401, 0.09276074866647832, 0.043337079041521065, 0.10830096478457563, 0.11107745056506246, 0.07165069197071716, 0.04089652640686836, 0.05614852205326315, 0.06490943065728061, 0.016213082453759853, 0.03200493301847018, 0.057790189821389504, 0.027776318420364987, 0.02664135754457675, 0.027619452521321364, 0.07365311772446148, 0.02572674216935411, 0.01821759549784474, 0.15185401251073927, 0.00672021678838064, 0.07467999777873047, 0.08495149231748655, 0.02145378053683089, 0.05295929826388601, 0.021826540905749425, 0.08932990385801531, 0.04825774820346851, 0.07083435921231285, 0.04708840177045204, 0.0531709921779111, 0.010005275962612359, 0.04004659662314225, 0.05955569606157951, 0.0684971283772029, 0.019748340018850286, 0.03242669554310851, 0.02806276701448951, 0.016169909868040122, 0.025232026528101414, 0.07934546461910941, 0.08100523336906917, 0.054687433657818474, 0.0224277825691388, 0.0652556648128666, 0.028258144811843522, 0.03877500079397578, 0.037417163694044575, 0.03318238741485402, 0.03464539797278121, 0.02233223662187811, 0.024256000288005453, 0.0385304816882126, 0.013094050063955365, 0.012336704130575527, 0.04805456301255617, 0.0251857962939539, 0.025524740703986026, 0.027916745748370886, 0.030591971044486854, 0.04089465248398483, 0.060406857810448855, 0.028313694565440528, 0.08520160350599326, 0.018528342006902676, 0.023874814687587786, 0.02589186446130043, 0.05553468428843189, 0.04624083943781443, 0.02795121108647436, 0.016736654652049765, 0.04195271758362651, 0.06202070617291611, 0.05421926834969781, 0.06990901980316266, 0.047830408439040184, 0.055500779271824285, 0.0626981422828976, 0.04249209196132142, 0.053161437026574276, 0.024662073810759466, 0.029276851964823436, 0.043851261216332205, 0.08694870077306405, 0.0413282003137283, 0.0875530242046807, 0.017146244099421892, 0.06008753764035646, 0.051516255189199, 0.03184621731634252, 0.042365644840174355, 0.012532068940345198, 0.02857337203749921, 0.02637619931192603, 0.04682129168941174, 0.007885981431172695, 0.06574607599759474, 0.02339540955290431, 0.0318623107887106, 0.04415693700138945, 0.029778662537864875, 0.0232645021242206, 0.034116807000827976, 0.06242731775273569, 0.06438290656660683, 0.06975739903282374, 0.05722463989513926, 0.03988748758274596, 0.011269196129433112, 0.03121843830740545, 0.03660909103928134, 0.023546696356788743, 0.055301341926679015, 0.023972078706719913, 0.025522419637127314, 0.03234148214687593, 0.05898106966924388, 0.029976804835314397, 0.06471711050835438, 0.01577493701915955, 0.06052764234482311, 0.048376150443800725, 0.024960259470390156, 0.0707446484011598, 0.07233071446535178, 0.07651650157640688, 0.011632461646513548, 0.033637279411777854, 0.06538033077958971, 0.01976842810108792, 0.044741608362528495, 0.04344872031651903, 0.03167689261317719, 0.036060877682757564, 0.06820279260864481, 0.06635584679315798, 0.04551342710328754, 0.03209928596334066, 0.05274762661429122, 0.02641396535182139, 0.03553288413968403, 0.049652792877168395, 0.0088086825053324, 0.06149660890514497, 0.034871808675234206, 0.11080659634899348, 0.07383305885014124, 0.10080931795528159, 0.10016157146310434, 0.03172313954564743, 0.03685139483422972, 0.16512442933162674, 0.12427845431375317, 0.15542947221547365, 0.20347734476672485, 0.25982355640735477, 0.16283693723380566, 0.08016290317755193, 0.09168498334474862, 0.04550157500489149, 0.15553748438833281, 0.1285019944771193, 0.02630316641443642, 0.08661023690365255, 0.12012715480523184, 0.18032545427558944, 0.19457234448054805, 0.21351630217395723, 0.07473312070942484, 0.07408388250041753, 0.06214712731889449, 0.05839491401275154, 0.18080173496855423, 0.1426651407382451, 0.14669420110294595, 0.21544374874792993, 0.11915734590729699, 0.12514012487372383, 0.07485455833375454, 0.04166989994700998, 0.14257649861974642, 0.10089904360938817, 0.025132914561254438, 0.017417168819520157, 0.0843323407752905, 0.058309938103775494, 0.022249513131100684, 0.013969522715342464, 0.03017219562025275, 0.027429657529864926, 0.031273045533453114, 0.010283465380780399, 0.09206809481838718, 0.04567257325106766, 0.016924401315918658, 0.03246655258408282, 0.05739720778365154, 0.04750831634737551, 0.013236020131444093, 0.08815923269139603, 0.049632561931503005, 0.00315106789003039, 0.0202748993615387, 0.053158657683525234, 0.09405935124959797, 0.03288311265350785, 0.0372396382590523, 0.024877589785319287, 0.03147540694044437, 0.011723349689418683, 0.038634649536106735, 0.045486728340620175, 0.023782305979693774, 0.04187321501376573, 0.02999581309268251, 0.03595112146285828, 0.08513129243510775, 0.05876549432286993, 0.03531058864609804, 0.019106306208414026, 0.03615349029132631, 0.0350964493554784, 0.04383993233204819, 0.03524113846651744, 0.08405215776292607, 0.07683337636990473, 0.0459493238304276, 0.042797693531611, 0.008737788848520722, 0.03962515322200488, 0.0169990428184974, 0.03884135621774476, 0.0500046450906666, 0.061162122947280295, 0.06986119580687955, 0.031077823587111197, 0.07508886177674867, 0.022719780572515447, 0.06036529754055664, 0.015492306774831377, 0.05235507502220571, 0.02208534635428805, 0.0431498797115637, 0.017563084329594858, 0.0053106937411939725, 0.02554067275923444, 0.012686854042840423, 0.14484896964859217, 0.12339318345766515, 0.14930344390450045, 0.13779078901279718, 0.1368827564874664, 0.1386159533285536, 0.10044408481917344, 0.11554267111932859, 0.14660726592410356, 0.12425702851032838, 0.13083020079648122, 0.09892464135191403, 0.18622257455717772, 0.12877034023404121, 0.1335961406584829, 0.11187219424755313, 0.184352807700634, 0.1458319739322178, 0.11135658714920282, 0.1741744452738203, 0.17534601443912834, 0.14303167263278738, 0.07660609364393167, 0.10902596142841503, 0.14600446389522403, 0.19664234278025106, 0.1218117335520219, 0.15470901009393856, 0.2552572701824829, 0.1777799619594589, 0.08549855163437314, 0.1773625038913451, 0.14083227346418425, 0.17603508371394128, 0.15745914221042767, 0.1731443591415882, 0.1304266060469672, 0.06891515047755092, 0.1380522476392798, 0.1263422259944491, 0.12426353714545257, 0.19264857895905152, 0.16923013870837167, 0.15297363133868203, 0.13243776687886566, 0.11103420561994426, 0.1257464595255442, 0.16495565010700375, 0.11763700444134884, 0.16685424197930843, 0.13617905206046999, 0.058378404937684536, 0.1579489596770145, 0.16451212781248614, 0.13724621589062735, 0.05974091385724023, 0.07578788325190544, 0.15649601264158264, 0.12241394928423688, 0.12184914521640167, 0.11293357674730942, 0.28831641655415297, 0.16436831443570554, 0.14848365273792297, 0.18663743510842323, 0.15722069016192108, 0.14047326694708318, 0.11992658939561807, 0.15744907868793234, 0.08301027890411206, 0.12187497937702574, 0.16939882887527347, 0.15434914268553257, 0.131596943247132, 0.33273742825258523, 0.26868298882618546, 0.41445578390266746, 0.37634926149621606, 0.5584977124817669, 0.3076723701087758, 0.3925384412286803, 0.409885638509877, 0.4373790038516745, 0.43574488372541964, 0.41190107411239296, 0.24515252880519256, 0.10948986309813336, 0.1885388619848527, 0.2898491593077779, 0.30889352958183736, 0.26998955465387553, 0.28030516987200826, 0.4155939712654799, 0.2533911546925083, 0.3665175859350711, 0.432633503805846, 0.29977850150316954, 0.3531860013026744, 0.2935796685051173, 0.09922483266564086, 0.19723871781025082, 0.3189619502518326, 0.3486764745321125, 0.39756640268024057, 0.30614096322096884, 0.32598427031189203, 0.1682103832717985, 0.19463317090412602, 0.15617478144122288, 0.21860798442503437, 0.19479507784126326, 0.2750121132703498, 0.1161100875469856, 0.2755943429656327, 0.12012611579848453, 0.14175123040331528, 0.15853397984756157, 0.27758306125178933, 0.13499516324372962, 0.09201529101119377, 0.15932597016217187, 0.305722807534039, 0.11592070630285889, 0.10469890650711022, 0.23914447228889912, 0.07197039434686303, 0.1235855184495449, 0.1712778874207288, 0.2355465551954694, 0.23257857304997742, 0.08633887060568668, 0.12526054575573653, 0.108224968862487, 0.139150655886624, 0.16975986887700856, 0.19219753128709272, 0.09953847169526853, 0.14873512205667794, 0.16683971072779968, 0.14794592221733183, 0.14856974186841398, 0.13930570537922904, 0.09651730724726804, 0.1266643774579279, 0.0630456158251036, 0.16579901188379154, 0.20391062542330474, 0.10645674265106209, 0.08760854427237064, 0.15050042420625687, 0.14899917820002884, 0.15242692083120346, 0.12968034687219188, 0.15566498535918072, 0.09848895613686182, 0.12745071260724217, 0.16509446140844375, 0.08542339433915913, 0.1302344343275763, 0.10640006483299658, 0.0894236148451455, 0.1422187834396027, 0.1515175969689153, 0.19444466539425775, 0.20765159890288487, 0.21196490182774141, 0.10109337497851811, 0.12250154497451149, 0.12675836303969845, 0.11936251263250597, 0.16109305346617475, 0.1383094018092379, 0.10113775540958159, 0.10906170326052234, 0.09755874823895283, 0.10202390942140482], [0.05151960227522068, 0.022705470109940507, 0.05887820429052226, 0.09481573331868276, 0.032016673794714734, 0.046698499645572156, 0.05852450784004759, 0.04477999966184143, 0.01850131113315001, 0.04984068240446504, 0.03098934659647057, 0.022422565270971972, 0.050646651070564985, 0.03425058283028193, 0.04873802907241043, 0.02527473527152324, 0.06027663315762766, 0.039684703151579015, 0.05498717226146255, 0.02584128153102938, 0.014412838136195205, 0.01176469288111548, 0.040921503386925906, 0.035102045148960315, 0.03046137346245814, 0.052431876174523495, 0.017155953246401623, 0.012752763250318822, 0.09269713918911293, 0.03006986458785832, 0.045615268318215385, 0.052751979310414754, 0.042175321068498306, 0.0673826081037987, 0.01752230145939393, 0.03362583549460396, 0.01961914138519205, 0.03242630591557827, 0.032006023975554854, 0.043543908177525736, 0.01656465079577174, 0.05493130338436458, 0.04869483978836797, 0.10204303456703201, 0.03094133335252991, 0.056163134941016324, 0.06851896978332661, 0.04766194833791815, 0.045478579559130594, 0.03917355265002698, 0.034770568599924445, 0.038864566886331886, 0.0462642393540591, 0.05400172631198075, 0.05810413684230298, 0.013569609945989214, 0.08346064380020835, 0.06649980117799714, 0.03382876835530624, 0.07471975462976843, 0.01281240038224496, 0.017066865839296952, 0.02101259415212553, 0.07411738304654136, 0.016746617984608747, 0.013599430367321474, 0.08819449212751351, 0.061596902742167, 0.024705084979359526, 0.022987647644185927, 0.02033941611443879, 0.09790495270863175, 0.13645783241372555, 0.05604834695986938, 0.06000565648719203, 0.11177872816915624, 0.07541821949416772, 0.08306623683893122, 0.1895537637756206, 0.06891198892844841, 0.10269622842315584, 0.09487631483352743, 0.1379419199656695, 0.18184452666901052, 0.09215334532200359, 0.028706702578347176, 0.06864653754746541, 0.12336816565948538, 0.08785426936810836, 0.06358158745570108, 0.13100828655296937, 0.04204875891446136, 0.0623425051162485, 0.13362879515625536, 0.04406181222293526, 0.059972374874632806, 0.06540623173350468, 0.06439320015488192, 0.023552470265713055, 0.07217987295007333, 0.02241486363345757, 0.07043096484267153, 0.04593633995682467, 0.08539195696357638, 0.07568096203613095, 0.05955608568910975, 0.05756005353759974, 0.058952511826646514, 0.09282412065658718, 0.07127604098059237, 0.08660744642838836, 0.11074395166360773, 0.06613016710616648, 0.08101105180685408, 0.042850129975704476, 0.04655899443605449, 0.09911764427670278, 0.040718232849030755, 0.02889223393140128, 0.021037732549302746, 0.03875068432535045, 0.036859417450614274, 0.054507611275766976, 0.04944798980432097, 0.057538675973773934, 0.02245275583845796, 0.04527453718765173, 0.01797354023437947, 0.04323921944887843, 0.02073281561024487, 0.009898841781250667, 0.016718290207791142, 0.04577314910420682, 0.01807625903893495, 0.08932175507652573, 0.03846416708256584, 0.037808498163940385, 0.05319426221831236, 0.029479630829882808, 0.03764325156225823, 0.025643434237281326, 0.024004807419260032, 0.016001896910893265, 0.08879057771991938, 0.007920234329503728, 0.023191927502921317, 0.002673213612069958, 0.059417901502456516, 0.016762861741881352, 0.042743379453895614, 0.02943509454780724, 0.04202448697469663, 0.039955015599844046, 0.045830038434360176, 0.02599875228042947, 0.029695384291699156, 0.05117523091030307, 0.02758948645350756, 0.012299420486669987, 0.031002708965388592, 0.07016716102953069, 0.040716499934205785, 0.032543572669965215, 0.035195997334085405, 0.018795474352373276, 0.05746458366047591, 0.010334623475500848, 0.08092182339169085, 0.03166485497786198, 0.02650330694450531, 0.0991143417195417, 0.04930034694552887, 0.04545505347778089, 0.06248182849958539, 0.038766354773542844, 0.042625526402844116, 0.03039676394109847, 0.02646972661750624, 0.059585767885437235, 0.05978534994937945, 0.02003394256462343, 0.07442061716574244, 0.012199155407870421, 0.06886328919790685, 0.07021023528068326, 0.0019020237255062966, 0.018282642886333633, 0.07678890688112006, 0.05856311436218675, 0.01245425939487177, 0.03725385409779847, 0.04790107945154887, 0.028112845284340438, 0.0777059787651524, 0.0249762508974527, 0.041333744156872854, 0.0632373645203188, 0.03754833829589188, 0.03728316893102601, 0.02194215452618664, 0.10628400777932256, 0.036711644715978764, 0.01659461315284716, 0.02807126089464873, 0.04438552219653502, 0.027253401167399716, 0.04652158277167473, 0.09610719644115306, 0.021735412592533976, 0.025963709922507405, 0.03294221358373761, 0.047171655896818265, 0.052746884466614574, 0.028519276893348433, 0.03224401218176354, 0.0319200981175527, 0.05113608633109834, 0.004036439167975914, 0.007803175376466243, 0.06950984825380147, 0.07083202886860818, 0.10557336427154951, 0.011880980928253848, 0.04910205621854402, 0.08162875616108067, 0.03755293961148709, 0.029775471302855294, 0.056356501518166624, 0.01886659436422633, 0.02733013367105741, 0.060916267975699157, 0.0575045112054795, 0.07107906756573357, 0.03758354207093362, 0.028934458423464093, 0.04158875352004543, 0.01947804426890798, 0.05106470656755846, 0.044356712023727596, 0.06058269485947676, 0.024681499526195694, 0.026617267430992797, 0.15507867385167629, 0.023005078837741166, 0.08201876960811205, 0.03926018354832195, 0.051647715517901815, 0.063566336320946, 0.0865996241918765, 0.09421670882147737, 0.04879501859250013, 0.07455692742951214, 0.04376090844743885, 0.12212725021527149, 0.15516010229475796, 0.039528644338133745, 0.0568383186327992, 0.06770975422114134, 0.044728309076162986, 0.0564372434746474, 0.1449030573712662, 0.08489831743645482, 0.06741878780303523, 0.1351181519567035, 0.1398473247536458, 0.04183565491985064, 0.07021532641374506, 0.10915478342212737, 0.03933047235477716, 0.05101245937112253, 0.010182498972426401, 0.12619802670087665, 0.12193657763418742, 0.06313200181466527, 0.07985923861269839, 0.0656000139133539, 0.015769534184073564, 0.08663995249662548, 0.10916684332187288, 0.045015063806204125, 0.06337933737086132, 0.08097248981357552, 0.07954133965540677, 0.038325066343531944, 0.03556862968252972, 0.021562377150985412, 0.05738259118515998, 0.023200501163955778, 0.049950761458603665, 0.01826885563787073, 0.03840861361823045, 0.0158881312381709, 0.0254674246389186, 0.036819207889493555, 0.044127644432592206, 0.038107453801785596, 0.031876396751613356, 0.06534548694617115, 0.08773342546191998, 0.015950774068187457, 0.028587786400748882, 0.019572710771171842, 0.033651521225692704, 0.08739677985431626, 0.0552821128803771, 0.03541772508469876, 0.04387631983263418, 0.0775545509532094, 0.06347900780383497, 0.02885151970986044, 0.07180016051279381, 0.028722593815473374, 0.04729238848085515, 0.05844787367095705, 0.08031786361243576, 0.030985851080913562, 0.043028004220104776, 0.03862509438476991, 0.04427179919730406, 0.06744646991137415, 0.026662200762075372, 0.027781355747720227, 0.01939386987942271, 0.04396130687382538, 0.016289236082229763, 0.026199733292742167, 0.043066985526820645, 0.1110451745626051, 0.052894441978423856, 0.033620607064221986, 0.03683297472889535, 0.06848410368547775, 0.03440707580011804, 0.028210578711878043, 0.06191640844917856, 0.030505694521707483, 0.028010491987515707, 0.028501914348453283, 0.07859119024942629, 0.025055326732399408, 0.017050735259545036, 0.07984870011569001, 0.01642116767470725, 0.00605853415436286, 0.034720636904239655, 0.032188031982514076, 0.03984499962825794, 0.017851683296612464, 0.024436696548946202, 0.003686570112222398, 0.02408985197689617, 0.03097878954577027, 0.19265729177277535, 0.12179519108030945, 0.19857759674778208, 0.1413409414817579, 0.17770503473002464, 0.11699089809553698, 0.09797225808142684, 0.1268244587117806, 0.1154887318261899, 0.09802713990211487, 0.08522658419678919, 0.17387788306223229, 0.19890216761268675, 0.11636540861218236, 0.10814145498443395, 0.07696170112467371, 0.12814831658033654, 0.14075982500799, 0.11251553980400786, 0.20269878732506186, 0.1468800794100389, 0.11908284912351519, 0.18302029639016837, 0.13032653485424817, 0.24150166689651087, 0.14978613675339147, 0.09200101951137185, 0.11090608124504797, 0.13047610729699954, 0.1568378013325855, 0.1302684098482132, 0.1592356656328775, 0.13447714416543022, 0.13322943064849824, 0.14219041855540127, 0.16398625681176782, 0.12795381451724097, 0.0862502507516183, 0.10237363909254782, 0.09124965436058119, 0.10232958520646207, 0.0787037740519736, 0.16291049891151488, 0.27834043779876083, 0.14569151506293565, 0.17038441583281383, 0.14340979687403888, 0.1050283458607737, 0.16183123807422817, 0.15748501347843558, 0.289504891843535, 0.09570596914272755, 0.261511022108607, 0.13374742004089057, 0.18672376172617078, 0.11457514061476104, 0.17718737188261002, 0.21714724483899772, 0.10079084589960985, 0.19419042044319212, 0.13021764694713056, 0.18231807625852525, 0.12913384416606277, 0.21682917518774047, 0.17159704060759395, 0.16330055688740686, 0.25253124302253127, 0.1919060156797059, 0.16276647773338482, 0.13026973087107763, 0.08633624340291135, 0.18363329552812502, 0.1936244437820278, 0.20779369049705565, 0.2076322288485244, 0.22420408960897475, 0.28084729390684515, 0.30559370352420956, 0.3796294948551804, 0.17055398173397407, 0.2580129832495004, 0.2408583732903935, 0.19710036664037034, 0.30850520823150873, 0.26796188845764846, 0.1770409313030541, 0.13816147693432868, 0.27452247391920537, 0.1914496987592429, 0.23813887702999637, 0.144517867884133, 0.21063832769868895, 0.16829460219014436, 0.28687742189504206, 0.15244143723975867, 0.2090339528513141, 0.25431780028156936, 0.2492614887887612, 0.13853094773367047, 0.28579266916494817, 0.07395774708129466, 0.2952627110062167, 0.277217865223065, 0.2829661255236715, 0.08769271124037914, 0.18102875794284046, 0.35824522201437503, 0.14492414920823649, 0.2268549965810962, 0.11278945908998139, 0.140083565202076, 0.22115356579888612, 0.1323282258817926, 0.1485926445457153, 0.10590825841063634, 0.26494004123378545, 0.1949871753458865, 0.13713522028410807, 0.16926028474699706, 0.06392619630787522, 0.1703354192432016, 0.20279862103052437, 0.20614003704395145, 0.11242010703426786, 0.09756071493029594, 0.09278964789700694, 0.10840701026609167, 0.30622966471128166, 0.2147000574041158, 0.1554118684725836, 0.1480452364194207, 0.15625263273250312, 0.18791769922245294, 0.11093262786744162, 0.1568148986552842, 0.09454384009586647, 0.22698451619362459, 0.15686477097915486, 0.1253336769877933, 0.2569195325486362, 0.13813257770380005, 0.15254369034664705, 0.1556187347159721, 0.19345726759638637, 0.0696397092542611, 0.11470314624602906, 0.09002427206723951, 0.11758710985304788, 0.07778680606861599, 0.25340172287542373, 0.22260885802097619, 0.17191490245750174, 0.18441569729475304, 0.15165876829996705, 0.09930404950864613, 0.14555825502611697, 0.0767288522911258, 0.11403159165638499, 0.13589942565886304, 0.1201644774118904, 0.22796063334681094, 0.11651555993012153, 0.14921097230399027, 0.16786010441137478, 0.09956299225450493, 0.15257389575708658, 0.11930897409911267, 0.19843376852804795, 0.11365029102307744, 0.1158002631564159, 0.19956732488935813, 0.09929311025189236, 0.14022433577338234, 0.1954854532959871, 0.1427610410610214, 0.18142056738724932], [0.032341738187824376, 0.0295026058665826, 0.02885755522584077, 0.06809725178754888, 0.05781170468253549, 0.02195096752984682, 0.051488075841916725, 0.005843970911882934, 0.0420695093635004, 0.04603021050570533, 0.022790323564549908, 0.041049386563827284, 0.08038884261623025, 0.04168496554484591, 0.03853430003800895, 0.05745522888901178, 0.042000304092653096, 0.0617512731696479, 0.055935629570740275, 0.026763847163238097, 0.08225321405916475, 0.015479391549888533, 0.04593652549374383, 0.016575753325014375, 0.01433911133062793, 0.04543835515505634, 0.03185904904967174, 0.02806335516652325, 0.032881064325920306, 0.019282341781945433, 0.022436590006691404, 0.03576908005925361, 0.08623195681138895, 0.09907177212880924, 0.0341184174612863, 0.04735035392513964, 0.008377347203349927, 0.033462173378211446, 0.002801318737510883, 0.005004178401577519, 0.006237478019102127, 0.013604088271677028, 0.01529247052530991, 0.009004618768813089, 0.036436515729292296, 0.04189087812846992, 0.007172149007601547, 0.03703163281898014, 0.019634099371614866, 0.03142404661048204, 0.026445679177413695, 0.023752386296109762, 0.027418189492891543, 0.0911798702145461, 0.03908523707650602, 0.03185846646374557, 0.02940921956906095, 0.11422332550864667, 0.008554531250410946, 0.02971966179757146, 0.005303958287186106, 0.043954590437351726, 0.014305548629636178, 0.039102410373743623, 0.012442092811397742, 0.04740039323223755, 0.01893680153443711, 0.07546271124738269, 0.04208881262456998, 0.09407273959368467, 0.040289520111400634, 0.03382793343917001, 0.05502616098965518, 0.03407961798075121, 0.05872693975106813, 0.14346912415931, 0.09205747468513437, 0.05001063422241714, 0.037411794255604036, 0.10833659529453143, 0.07884693433879875, 0.17843949375674129, 0.1223017365555279, 0.07448604490491562, 0.13184424169594422, 0.06142681733763311, 0.05134933875524439, 0.019276167113275733, 0.015718133035989013, 0.0627727726532612, 0.03332273867272306, 0.023542041235486977, 0.0886114603781607, 0.03641154617071152, 0.11705696408171207, 0.0722715504525695, 0.0900619880121667, 0.037619985232595354, 0.05444192007416859, 0.03772784897591919, 0.021609384784824215, 0.050493679591454566, 0.029489746302715503, 0.040245547861559317, 0.030801217726548202, 0.1041542443272192, 0.03399141372938175, 0.03156486913212575, 0.04989317822037265, 0.06420154793886468, 0.12969069241080433, 0.04090383285074495, 0.04280409455532208, 0.07175974315032363, 0.0317651079967618, 0.058909697327180766, 0.02516135366022354, 0.031317147659137845, 0.016247855783149134, 0.039589478183188476, 0.03054260894714389, 0.04456819442566484, 0.05113917366543319, 0.03927563135221135, 0.02128964344592532, 0.009690928181953495, 0.02451012649544282, 0.04204610944725573, 0.05657632937072776, 0.04534250678261742, 0.06366815156070516, 0.027384533095755614, 0.04214414344460238, 0.05594062422460411, 0.015058634635352064, 0.022141389636090025, 0.052281969765317626, 0.04159227501077112, 0.008526486417395063, 0.04227506200550124, 0.0472353878285503, 0.08631779361166991, 0.07883899335865863, 0.039514528689323924, 0.11745310024707578, 0.029181669669924304, 0.012177804746897891, 0.020957404340151697, 0.03157908497087192, 0.057526066884747706, 0.005348594295355724, 0.03239278310502414, 0.02655345571838552, 0.03233422394259833, 0.06555754822329618, 0.05810036302136723, 0.029201215984357987, 0.017108079155150335, 0.03479832492303103, 0.026954445529554505, 0.08704186999239028, 0.016344631840183865, 0.04006623385066632, 0.06715121387969702, 0.07716475272900425, 0.05599548007012345, 0.05839472847583238, 0.05340701369277667, 0.019747607148019597, 0.028119793641963042, 0.07425427960697562, 0.06624845060287043, 0.014083535152167315, 0.05113955216074828, 0.04811421313206665, 0.03618322443799116, 0.0072328873011429096, 0.03874676207487937, 0.033037935791071504, 0.06505599740194157, 0.0077239409074536525, 0.022892613778822124, 0.061837996836402453, 0.039722756773699075, 0.04403813771205023, 0.041817286764853634, 0.055014390527503565, 0.11385881967726164, 0.03120012210274581, 0.036044847292941995, 0.05877188792510424, 0.06288721182500012, 0.02316899142897455, 0.004895584570476785, 0.011038324191758875, 0.0830879075510893, 0.03747266891878098, 0.04826832009712234, 0.08055007419898175, 0.044651144271483645, 0.03444809059146792, 0.019493751824484207, 0.07567493579699658, 0.10013219725806266, 0.031359654167317785, 0.03204807035217527, 0.05984174946206622, 0.002320079106539197, 0.011351042958267499, 0.03857851348584518, 0.014635411935159937, 0.0757485197391361, 0.01030302746585221, 0.054496627490152605, 0.011505126731208293, 0.01684751667198725, 0.059436937590362504, 0.002164623520002351, 0.01710560594801791, 0.03817756449279841, 0.04572716563416179, 0.07490354008041322, 0.017497556400485337, 0.006680652431896306, 0.012837625054089585, 0.005057377866251045, 0.06567244010511786, 0.015143007549340837, 0.05841549005708657, 0.03055362427403452, 0.04148973246628884, 0.06411211172235198, 0.013431975876301294, 0.13640963734360412, 0.02877617131161969, 0.055046191555447876, 0.019098398624919355, 0.05982817187032197, 0.02283318630361464, 0.016596464811300393, 0.025042023735295516, 0.025902770321408752, 0.09455418563447893, 0.03298453084426001, 0.006172507628434687, 0.076376732904464, 0.10453499577124603, 0.03715397586347535, 0.06934152916073799, 0.039643035270273685, 0.01846378258051118, 0.06915859717992134, 0.03902914184436668, 0.04863972048042342, 0.059832071856362745, 0.011980911112914328, 0.046944710848038085, 0.07211021496914327, 0.07074576162267476, 0.07593563001137227, 0.09263571904739365, 0.0634409133635927, 0.02623676831717603, 0.12581359420437366, 0.0502686789695872, 0.038852332581882365, 0.08155632254783995, 0.008774086363700917, 0.021341291358112358, 0.0388777103216853, 0.06905886737513356, 0.08686918707098812, 0.07787777110934258, 0.013852956362825353, 0.04607971175573766, 0.019924794905819, 0.03947919874917716, 0.08729641922400333, 0.06812359803006984, 0.10030505087343045, 0.02618274182168534, 0.040746634840616025, 0.0444862056610873, 0.07923017939901911, 0.07828646441339515, 0.01489346039306838, 0.026549969479674473, 0.07734963655821048, 0.047981339012039825, 0.0572281725180801, 0.0921651825774461, 0.0272694723753375, 0.08982897590612993, 0.04293136174965184, 0.020267271938791964, 0.022265558363869786, 0.01864454006863525, 0.022756479775125626, 0.03837224838207476, 0.03358955931616947, 0.07107811761670746, 0.06515390894492157, 0.030930837529012933, 0.04073585143487435, 0.047357712319353595, 0.026949601160595194, 0.057830425357678905, 0.013601706905319588, 0.027642052773444448, 0.09041186611284502, 0.036689016633317806, 0.03717687854077667, 0.014836310383543605, 0.060728352473233826, 0.0254194429362542, 0.032214563761954196, 0.024470004136674106, 0.025720114790601656, 0.024403246097790543, 0.04995764858904295, 0.05779723280284088, 0.04269689503416885, 0.02302934335602913, 0.02541502715757815, 0.01817474574636435, 0.04460095282411203, 0.0172587611086783, 0.011863068266393384, 0.02104769959260011, 0.032812760764500126, 0.029622687216033228, 0.021777191795990802, 0.028916008632222656, 0.05527183042431716, 0.04521822673268616, 0.03713940008310601, 0.01626368579309201, 0.034358691482339054, 0.03180126543156803, 0.020997738211008254, 0.04656135817640461, 0.009212571330863284, 0.03981190726335626, 0.0317557012749603, 0.03144683054415509, 0.023475800844607875, 0.015013637294032378, 0.025985478969232645, 0.026946218822558876, 0.019571762677514926, 0.030328636639751494, 0.016226749103225302, 0.10402499930933118, 0.10439814373967238, 0.10482837416930124, 0.11120245049824007, 0.15250515803927556, 0.09744367082021199, 0.22101856913650408, 0.18545675236964598, 0.12338211803580634, 0.12895480846054852, 0.16304420423693955, 0.17868815775727853, 0.16199315985431895, 0.17502828617580235, 0.11584289954043925, 0.1410230647888966, 0.15134077286347747, 0.12186491585453041, 0.0981026237423066, 0.266541120945476, 0.2057417857577093, 0.13170201651519164, 0.2762523607816547, 0.10066435424960218, 0.13954552297946066, 0.11526419504662044, 0.1294636249076575, 0.22008266154443845, 0.15991983673302457, 0.10828382117324509, 0.08615318525698967, 0.07316442832234316, 0.22780482686357573, 0.2583124546799809, 0.12025775795336813, 0.1663546430063434, 0.10559321672189981, 0.14199389785062522, 0.11172864804393612, 0.08344816087628715, 0.1337125539430417, 0.0872144490131177, 0.10502205244847573, 0.2199478875263594, 0.1388084515929222, 0.20123325346503407, 0.16253421519650146, 0.10139268313650973, 0.06642171982093714, 0.0919322001573164, 0.13565264671342447, 0.13977676135255024, 0.1215491839684546, 0.23479299328755587, 0.2111445614718832, 0.13407592428848147, 0.08940509083913639, 0.18973701487993822, 0.1269470911938697, 0.16717887221602723, 0.1265197922475636, 0.14945334289222956, 0.1188752036250662, 0.18036682158708572, 0.1362811864237301, 0.11768157040933147, 0.16580454830545932, 0.16293892316753045, 0.07700533940806054, 0.1590833769296296, 0.12660283857258037, 0.3108234697720036, 0.13338572694920003, 0.15366612933576107, 0.16023584321374074, 0.3120570973260328, 0.25153106544166803, 0.27527239930350333, 0.1628921678639017, 0.21586518472759053, 0.26579674682579935, 0.4172879975521937, 0.14733513467945158, 0.23510313680162653, 0.285494682029821, 0.2740659937262535, 0.12269430299056694, 0.26006430911365896, 0.13221228757174686, 0.13275003293529153, 0.15542506385827437, 0.12208334475872107, 0.16049817757448182, 0.17147712438600138, 0.23171481705503538, 0.40655274235177785, 0.2003671374404803, 0.10682382373488508, 0.16960995504632592, 0.13461831549648196, 0.18322049814742059, 0.13914274459239095, 0.15158790803980082, 0.28497972059994936, 0.05930681312747765, 0.16643550741719082, 0.20108952914597467, 0.1709323879913427, 0.11763100046664476, 0.10061615175800398, 0.17194665153510869, 0.28222896507941186, 0.08960028309957124, 0.20843984879320487, 0.18071876285830513, 0.14931804937077686, 0.16355753294192255, 0.09849466325249523, 0.10074802397866733, 0.14417468395549804, 0.09003478829981759, 0.11336967014358379, 0.14043292379938066, 0.13473603496095166, 0.1569995895260945, 0.14864273951388896, 0.18199590995209292, 0.17897606652695686, 0.11782632631366141, 0.14885662647429854, 0.11791809287387878, 0.10310161174857058, 0.11940304873860441, 0.222538918023929, 0.13346754130907357, 0.18275137175805867, 0.08050406846450642, 0.13640761870192364, 0.07084083816152997, 0.11798488616477698, 0.12873244617367163, 0.15307909052353352, 0.15932785521727055, 0.16951389145106077, 0.18250974331749603, 0.17790725512895733, 0.06176521070301533, 0.07572094153147191, 0.05611656517430674, 0.0879518840520177, 0.11083982230047695, 0.11680523501127027, 0.18477317498764023, 0.07146565229049884, 0.15181024064077064, 0.17283936613239348, 0.11757821150240488, 0.10593645260087214, 0.11730467071174644, 0.09217243336024694, 0.14745917724212632, 0.17604278720682487, 0.1270148195908405, 0.18917914247140288, 0.16153437900356948, 0.18323407944990322, 0.12187454893137328, 0.1805767009500414, 0.11780988032114692, 0.08287255113827996, 0.12472403235733509, 0.24018836236791685, 0.1187281619058922, 0.1323582828626968, 0.1558170365751721, 0.11414813852752559], [0.06921920838067308, 0.07603772726724856, 0.11364241683622822, 0.0015582865489705, 0.049632962691248395, 0.07147243552026339, 0.04208399237541016, 0.06256339052924886, 0.05211012547079008, 0.024284355895360932, 0.01485059765400365, 0.004518913083302323, 0.059102867235196754, 0.02877558315958595, 0.09431207479792647, 0.021215447231952567, 0.02281939534441335, 0.012261033825780032, 0.049719445160008036, 0.020475548262766097, 0.034609003050718457, 0.03879517607856542, 0.055737387083354406, 0.03625252618803643, 0.05185496396734379, 0.035137334270984866, 0.03459765561274253, 0.08112014751532115, 0.019520365240168758, 0.045691857958445325, 0.006554686315212166, 0.01656034633924719, 0.02921698847785592, 0.03137929139484186, 0.019522116708685644, 0.05057629547081888, 0.08311493656947277, 0.03317730370326899, 0.04505147357122041, 0.07333935995120555, 0.051087731699226424, 0.035031860243179835, 0.030647138592030387, 0.0324808760342421, 0.02441548596834764, 0.05778884282335639, 0.014873162654112093, 0.04756865666422527, 0.005161096714800806, 0.10943834320642054, 0.039673478167969733, 0.058313381668995135, 0.01639914815314114, 0.027616782645054627, 0.02777284516923828, 0.03062545118154958, 0.07510830604587682, 0.046182777514331974, 0.017440275587432552, 0.03410958219319582, 0.03107984593953006, 0.07735664985375479, 0.06035857368260622, 0.059426862935652025, 0.01582160883117467, 0.010178453339904081, 0.04438078358361963, 0.05904304271098226, 0.0783901201793924, 0.021791398357891012, 0.024395501786784735, 0.027127852044941392, 0.048519058400415815, 0.07266864398843609, 0.13632745190989226, 0.050173194249509834, 0.03071041966904886, 0.017773844992916565, 0.10426579654449597, 0.09707103105029091, 0.0892918168392498, 0.115482913388405, 0.07097176785464399, 0.0511983747855993, 0.042930586205329746, 0.03653618616226595, 0.04300879743823316, 0.04110443907848094, 0.10677184371161275, 0.03333588581881486, 0.012566341320052743, 0.03355749482579995, 0.01493083031164133, 0.019101929392491, 0.1317136237048544, 0.0130609549159999, 0.03258274322433863, 0.017987915634876117, 0.053071076836204156, 0.018956559360958636, 0.052770169349969365, 0.07011376350419596, 0.08593955804826692, 0.07170757759013213, 0.09422257178812288, 0.029945862843305804, 0.06613149555050768, 0.024636777707200963, 0.021413359463622328, 0.07985184682183899, 0.010962545347865671, 0.10380653329775669, 0.029079741252644453, 0.011048491614928935, 0.037978431428200565, 0.02689516833925154, 0.030921864963602275, 0.049758589739212766, 0.0604431228566682, 0.021355405151552986, 0.06486811529612169, 0.041318240691907704, 0.10031696234364063, 0.02765411638392834, 0.03617223323090002, 0.04588653442624491, 0.03258169308537617, 0.03638325179053936, 0.035771013353951275, 0.06725117375026457, 0.030243246983445715, 0.06821002854849212, 0.027489652748045046, 0.07506731722969562, 0.0269979799122666, 0.03358811583893839, 0.06761631040717475, 0.037062183328089304, 0.03917047273716889, 0.015887301888142247, 0.039015356451272964, 0.08141774131217971, 0.06085394983529113, 0.026383581825939473, 0.030735005166206975, 0.010737600387074053, 0.037319526745704934, 0.03958285080443602, 0.04566050964058377, 0.044194270740263164, 0.024451845638395753, 0.0190964634748525, 0.018363145500188693, 0.03900864743627608, 0.028362026932882145, 0.026905792183242738, 0.03889602281560656, 0.05703894712496549, 0.044117554934928194, 0.09595680763595738, 0.03199302525899839, 0.03834960545646027, 0.06787270758650266, 0.024120521229633596, 0.045565314358100295, 0.0186942379878019, 0.03318994618894067, 0.029312321057659574, 0.04288612413802184, 0.034332274735788815, 0.019927796893171035, 0.010613683989504352, 0.05258898512693122, 0.07669518105103634, 0.04858581458393019, 0.026491683056519832, 0.0075146501603740035, 0.07172541139880195, 0.06278409782680683, 0.06794289249228314, 0.02684249255253235, 0.024240955099230632, 0.04130183551751543, 0.0330752064473927, 0.015560511073999805, 0.03831857626209967, 0.010912579327850835, 0.043026063503930345, 0.07715729414485395, 0.060850602749269456, 0.005217944299147348, 0.05488500821229536, 0.03769122398807667, 0.013346492523851339, 0.06354819823172875, 0.04924727967591025, 0.027547807439987082, 0.02174681383621646, 0.0435340895637637, 0.03722990499227308, 0.022496598212455865, 0.025354612625960726, 0.0213245503618964, 0.02540998797485372, 0.06029333148035221, 0.10559461938100867, 0.0397603762394283, 0.027265286662441213, 0.03599437382945325, 0.04999776909244247, 0.021610787443933077, 0.013189086712372955, 0.024164267124433536, 0.07871907713706605, 0.04139312339248136, 0.006056603642718983, 0.05323695055267308, 0.047971583480830304, 0.039827277141739614, 0.01875234258477576, 0.07790461459080689, 0.008037638381210854, 0.07111198181519285, 0.03549230721546337, 0.07588464446598664, 0.07277305674506351, 0.011678078681143234, 0.003878393022205273, 0.02722898636420723, 0.03646620534709655, 0.07551401591626927, 0.02429483316518599, 0.07875981362303719, 0.03916306610335596, 0.029977400408824906, 0.03732905592187308, 0.0907435393310152, 0.0503943431249354, 0.05307592306053266, 0.032345534273190424, 0.049771362100727856, 0.06971364942728542, 0.10785411024698988, 0.030889963745721616, 0.024636675661895424, 0.056832032641978, 0.058352400083094835, 0.03205076063750312, 0.05103725823573768, 0.09595274066668935, 0.02376784152147593, 0.014281717340054456, 0.033664442016743124, 0.09239521124982275, 0.08331514574820176, 0.03426532188314013, 0.03291815686679911, 0.052621821450884454, 0.04184716563031543, 0.13022114988416433, 0.02481617335433839, 0.040630280927871354, 0.03857937437715009, 0.06105066720920149, 0.036323375315987505, 0.015275531004590448, 0.017739977083692793, 0.030563774998881854, 0.05084730182716157, 0.011620927743933862, 0.053609070819220506, 0.013720330862270202, 0.019561216759029776, 0.06233371066628024, 0.02182449257816188, 0.04371604562038556, 0.04287683615984861, 0.08930625903303735, 0.04804320815310348, 0.04134888025873806, 0.022291058558039367, 0.02071113747661002, 0.02336111676413566, 0.033686064489302225, 0.09819131038966589, 0.03513763484079391, 0.04663301995606162, 0.012113336233596783, 0.009429327619727701, 0.06332890101475641, 0.019412651781749446, 0.032436952023999766, 0.027478431475174148, 0.011889149191119941, 0.07355200010351837, 0.04200758827209938, 0.04542838069028221, 0.04677456236095168, 0.03612437212723307, 0.08894279962987639, 0.018023703851213213, 0.051965629318146966, 0.09990866979933344, 0.05721153356716968, 0.04740174023027066, 0.1342927649966441, 0.0667950052593369, 0.09601632045814767, 0.03299077601695899, 0.059644605353241786, 0.021143321609997656, 0.05314971480402164, 0.04074461990967393, 0.052798100077779964, 0.01607299280294683, 0.023554479630547576, 0.0482853264111327, 0.022684803152515087, 0.05461045810079668, 0.008445565417787293, 0.025596404339012224, 0.026402016774227377, 0.03381732072739396, 0.035730146992136724, 0.043174652601010166, 0.01589536161191063, 0.0411621225066483, 0.03223523628548719, 0.03113588179985527, 0.10803019962622784, 0.08164540995494463, 0.04430641667568125, 0.041529671143507585, 0.06464492922532372, 0.024373090782319196, 0.0176417983675492, 0.02160022297175601, 0.04265110081178136, 0.08178362011676654, 0.026865907311730552, 0.04990289293345995, 0.02990447883348679, 0.03066069391934434, 0.10781521428725682, 0.03943365314626135, 0.028728536562994123, 0.03419531509280205, 0.019644519124994986, 0.008004281626199372, 0.09595638461178169, 0.0521658496290911, 0.06956890094443224, 0.09883321617962793, 0.161624520260375, 0.1956259715370834, 0.19114293943857774, 0.20853747089859098, 0.2711940306471661, 0.1943486463278532, 0.11589480534894392, 0.12256030822754838, 0.1523598752100952, 0.17723068362101912, 0.09408879966940731, 0.16634440136840567, 0.20043372293002903, 0.26733524864539504, 0.10613957099849358, 0.12966112524736673, 0.06124003732111305, 0.10594824532745406, 0.11673285334836692, 0.17964022932574153, 0.10082618697197177, 0.1301410424639471, 0.17768498189980164, 0.1320574013516307, 0.0872691156109795, 0.15683127043303102, 0.14340411202283576, 0.14566668280167505, 0.1573493637260981, 0.11991298582870513, 0.14317974593723193, 0.08421808714047074, 0.11894434952409938, 0.09887359643471427, 0.14047248027054593, 0.23530718288384378, 0.13034725561738014, 0.12936107494169846, 0.11135892491438426, 0.13355894421692938, 0.09366380880237557, 0.2079946344019845, 0.11179607958183624, 0.13984244142193347, 0.15392102737678215, 0.08671951814903878, 0.17008049151627347, 0.10392256066552363, 0.20199836319079623, 0.10786674902192317, 0.07452320423908532, 0.12925969756906852, 0.10039268367108889, 0.07531063034548424, 0.1558317756280303, 0.21731307031586766, 0.09153037171927281, 0.11622270845691673, 0.2060263548628427, 0.14397529856069013, 0.1644528895849362, 0.17327782697975636, 0.22172024007886648, 0.10929156866041012, 0.14274395682150498, 0.21010254160501063, 0.15732402680441737, 0.1707565732067451, 0.09709204867249355, 0.2092245512176305, 0.09897484764223918, 0.16467813140479848, 0.11522464599693194, 0.21270467463182285, 0.1643501318176277, 0.2308500517392531, 0.24781265325145796, 0.1744503460940905, 0.18835365161066875, 0.09460536413826048, 0.2744841790990904, 0.2114942911430262, 0.4173100838670507, 0.14713626878801733, 0.2363905552192591, 0.171293294406496, 0.23181521479273215, 0.22498377511510625, 0.08673607546370476, 0.0749266950879246, 0.12906716961879283, 0.13235829770565033, 0.2384276912198402, 0.22155879327328876, 0.1589348731795326, 0.07792188436724246, 0.22144315182231367, 0.12288855272345245, 0.17245122289750725, 0.2173065987881273, 0.17504951159935445, 0.18091111269313842, 0.14595160813769326, 0.1695226042647846, 0.13497341831680387, 0.18466295121470466, 0.13380468415562063, 0.1391212668386288, 0.13353146990993991, 0.13539950014092028, 0.2503369498299435, 0.0910209615540225, 0.10259986796882004, 0.15100916643859819, 0.12264955148566514, 0.20633114007068798, 0.13489936682162806, 0.1694570726249367, 0.1265642320504412, 0.15956473391270265, 0.11987044592387974, 0.1403789993491955, 0.19601286796387285, 0.11022479709936306, 0.122496253461577, 0.14997905062045902, 0.16239958960795775, 0.10455537514644675, 0.255744059686549, 0.14632762467954308, 0.22998245141934603, 0.0907953931891825, 0.24980946094729006, 0.09026565559906885, 0.10708028770750389, 0.15877672150963917, 0.11426427721744403, 0.07832438073819503, 0.09555679745972157, 0.18966009869473055, 0.1596383994910866, 0.14799549768213183, 0.1120973915385548, 0.14531750231981277, 0.14027811179403216, 0.1922158178058453, 0.11647305713267997, 0.23243521980475634, 0.1317326820571907, 0.11476861851406284, 0.1338479365222156, 0.10252981664962135, 0.17652343172812834, 0.18365446157986298, 0.1958339213160798, 0.1231321255909279, 0.16932969039771706, 0.14673910103738308, 0.140477467502933, 0.08719752062461339, 0.1252341252984479, 0.18709810101427138, 0.17332167306449264, 0.1564374126610346, 0.10387454371084459, 0.09510390926152468, 0.22308567306026816, 0.12121904699597508, 0.18525235005654395, 0.10780186305055395, 0.10090345938806422, 0.19485020457068458, 0.1480623206589371, 0.1765809184871614, 0.19237727945437655], [0.03753506127395667, 0.010623325415508589, 0.0923029326077085, 0.011822837368526962, 0.025992766859417316, 0.02668525186891202, 0.09901652665575966, 0.04086644716153387, 0.03435855047428049, 0.014624807572545251, 0.04667630200856365, 0.05185851885471493, 0.053537093626800925, 0.06139880497357808, 0.01964420185686322, 0.021402670681709424, 0.06367721318383701, 0.06336770791676827, 0.03985677751188632, 0.05632917564071249, 0.03539164972607978, 0.04039155799546279, 0.0332532588072354, 0.04099934725672938, 0.03157295112032443, 0.06258687208173797, 0.0832005358824972, 0.0727179968089331, 0.01256771429325454, 0.03872483903251123, 0.06347475529764779, 0.03726507165993098, 0.013558069549617358, 0.04587157643982209, 0.06500043280539103, 0.023512555708293803, 0.03626632642408367, 0.029656948463525623, 0.015337659897340927, 0.04365698550827801, 0.020622619667847175, 0.10782621291582473, 0.03826957967248745, 0.05168331634195056, 0.04121271842450369, 0.01341248522294336, 0.02533724080421962, 0.03058107631659368, 0.043075167704955675, 0.0770399160683155, 0.01488144966060645, 0.044972672330914065, 0.03930845283321105, 0.040842216039891355, 0.043960304974461906, 0.06829646648839116, 0.05969676349195652, 0.0693883586791344, 0.04029309355246369, 0.03317088041512761, 0.030484715862257872, 0.0877187903097365, 0.031091801938600838, 0.11887155967997387, 0.05753280558565166, 0.010945675403490895, 0.023726227445877157, 0.01585156005603494, 0.04047441507282201, 0.04535973574093077, 0.01657480708672665, 0.055765191646059975, 0.03638058005890343, 0.00288568399810174, 0.04422826852533035, 0.0356745564204175, 0.07146586751332507, 0.06892398945637979, 0.02742309694440337, 0.02256263636809308, 0.05793482698209118, 0.05720501751056872, 0.018854367481253576, 0.08352909208042547, 0.08581855829106644, 0.029116982223058585, 0.05786765519587789, 0.06240973627427593, 0.019495987544360105, 0.04084555941517465, 0.018704221729421988, 0.026056021961267106, 0.048366164846811444, 0.015264425692294026, 0.049945414284593426, 0.024077751259028446, 0.024077827329165302, 0.027953957032877952, 0.05529556430701632, 0.055231798978638835, 0.0090170321163896, 0.049034836192731746, 0.0754942228377331, 0.011037304666388081, 0.04401226273330394, 0.03895453373843338, 0.03815292890067212, 0.08011483427253552, 0.010958834609482437, 0.0391511063935468, 0.11150200356496498, 0.09527262169285677, 0.021220588459982537, 0.04052260272146668, 0.016124121211760212, 0.0390302439336665, 0.06852734120911919, 0.01574813992192503, 0.01533891876533744, 0.026130442674912047, 0.07693925115745515, 0.021487809863174334, 0.04323865541664418, 0.09035143302753568, 0.05623119359370321, 0.04283647445845418, 0.07014111906755716, 0.029587852659460623, 0.10573071442195214, 0.0032654748247296084, 0.03945760225178674, 0.02611004289065022, 0.040092264680424705, 0.01768056445143884, 0.012442592833394883, 0.03740367144928314, 0.02789625505101867, 0.07154250910389237, 0.02530009631300345, 0.07752062738290988, 0.03701970279507805, 0.025304643822892103, 0.009709115438454319, 0.026083620577992406, 0.008644358949823072, 0.027138208715768997, 0.025916104859788902, 0.021146935869182926, 0.021041921972937416, 0.029800969641655684, 0.08003793293028139, 0.014264291712606791, 0.023534094689239282, 0.036055875607416965, 0.031025132957438473, 0.03742371314729098, 0.10944160865619779, 0.10163960309000686, 0.06287610929575749, 0.05773407232481986, 0.042171751338173635, 0.07975681481184438, 0.04293499456252903, 0.02875127967854496, 0.07557107222964987, 0.07121367088984698, 0.07838993464247324, 0.08013847167603672, 0.046895903506083414, 0.04419696102559101, 0.012599545007105917, 0.025997895099862944, 0.020467995054787025, 0.027599047170951962, 0.04047106427606195, 0.03780613813432865, 0.020432347846508492, 0.008511842916050227, 0.06787077800254337, 0.05212271229538601, 0.07625021156854928, 0.06065115056117065, 0.04401585101732053, 0.04109726993192453, 0.025692814888316207, 0.059196188594796695, 0.06728008782374673, 0.07080698880599812, 0.043393437736085616, 0.020835528848692775, 0.022842247926746495, 0.03737859056855086, 0.019131112494505942, 0.04665295775339473, 0.04482828007894568, 0.03592014792957343, 0.019217377885070164, 0.06431708548916504, 0.03176566831825767, 0.06292007412412204, 0.028377769740473013, 0.012230843258294044, 0.0496254373138072, 0.01987572410143912, 0.030133409127302002, 0.03908328893885482, 0.0295083816308761, 0.029128277710697148, 0.020053056578035466, 0.022709234654030297, 0.07312532456126064, 0.047820690015214495, 0.027460365745355375, 0.017837498999142554, 0.01673460817983141, 0.034585328539833426, 0.035699793152161874, 0.08915699829231016, 0.03502558538457379, 0.039717602558084764, 0.05183820998354349, 0.02113034701324068, 0.04932192117848899, 0.01957169959496241, 0.017187513076351024, 0.015499903583986452, 0.00876474365213653, 0.049366301609552465, 0.04127549669647124, 0.09883688238915056, 0.00690487658175698, 0.020969942925148644, 0.03507422203256283, 0.04237492168613244, 0.06852316291769966, 0.03866003098664805, 0.02022682489041472, 0.16720167099265382, 0.004798876234417548, 0.08920934196794406, 0.018993844860233366, 0.009129794962063897, 0.08620700580650009, 0.03640698567323852, 0.04246623924700543, 0.05449693177070003, 0.016158193211595062, 0.03650733517133631, 0.02135312675818568, 0.05382743664085865, 0.08823905809549615, 0.058247742417734116, 0.08298750239191577, 0.04454244932276197, 0.046812385917291977, 0.028847005596617237, 0.090734774566954, 0.03613053195294924, 0.030931895089452155, 0.021323765540728346, 0.1534086189349182, 0.09408356010681018, 0.016819777047203388, 0.04424546779773664, 0.06182313161843922, 0.09585211286321282, 0.020962163362128194, 0.02335041313926922, 0.0477045847219415, 0.0023985159987205407, 0.02189333419664763, 0.047806325746933, 0.058134086211794056, 0.025247196026612073, 0.03299923278973438, 0.06690350724966265, 0.01947220542206196, 0.0760398201236967, 0.04181580246950034, 0.05283881058858242, 0.09216694888891652, 0.06805728713516146, 0.00877621261679451, 0.1157556675025262, 0.01969693330465816, 0.04530767779215239, 0.04189871149719693, 0.04468388040550053, 0.04403506150993053, 0.04498843554756604, 0.06477376606198959, 0.018423365218041, 0.06525714168674313, 0.06470695050666109, 0.0654937161016278, 0.03933003819838632, 0.06310181866865605, 0.05136356943694409, 0.037874449117225595, 0.08780537667917088, 0.03099686640780419, 0.04124679784581531, 0.04265834046236705, 0.034309576149098575, 0.05292122979881242, 0.013460975296766264, 0.05122076167026535, 0.057070202674367465, 0.035815423470921814, 0.038975707211648114, 0.02767624166153837, 0.029071351273159962, 0.027627543786366004, 0.025480840813543182, 0.050414221550454386, 0.031038550987432245, 0.012986868168809451, 0.060818964993814006, 0.007812771345925285, 0.02075080898066517, 0.03329538682010025, 0.03846546955173835, 0.05167157556570601, 0.03982080932473764, 0.05426095478469506, 0.06383642612490803, 0.0435230464063352, 0.04107156193640549, 0.061788836974301375, 0.01629842572583584, 0.021011132121202536, 0.11976515001151711, 0.06633742668782361, 0.028352820590953343, 0.053828865275136195, 0.036171402025502175, 0.009678196638560621, 0.032183189468923956, 0.010978653663187288, 0.06747402585460804, 0.01892344473162666, 0.02020132840698352, 0.05795002245577052, 0.04949922767991666, 0.008248295143857831, 0.01616264238691656, 0.07968196921865456, 0.040790666462271474, 0.0568024432141101, 0.04560361288895365, 0.023669041256653145, 0.06448894462664612, 0.1399434031918645, 0.11917405907297507, 0.18534790899138898, 0.14139681035885587, 0.1552327288663946, 0.1498480318696238, 0.1858140222611837, 0.1073178937076591, 0.14962411107262596, 0.1453461343771778, 0.14787111373152584, 0.13239634019555524, 0.13112922693835571, 0.13121436611982062, 0.07473030796973035, 0.2001544230733998, 0.18125397007679567, 0.20435379148693755, 0.18560555297881365, 0.14756632852368057, 0.19790011981967837, 0.1774211335578002, 0.09483370813541114, 0.12598810280906036, 0.2046631186385639, 0.12312645558267832, 0.12344653645413928, 0.1380001488723792, 0.09082081916858442, 0.08181645272998139, 0.1853703218512237, 0.239701914251782, 0.11832209580461495, 0.19790003076195717, 0.19763613789109513, 0.20427754323463887, 0.14941264351364225, 0.07204015622846782, 0.09450337078305893, 0.12297833774937317, 0.1307466349680908, 0.2242261462379247, 0.12228997351485305, 0.19996211776742712, 0.16040426620747894, 0.07975302985869348, 0.16998116247123107, 0.1513461460126564, 0.10211854809313081, 0.1430410088505596, 0.066564635199029, 0.1571294802124612, 0.15654281247407198, 0.19059023237787187, 0.08924432680942118, 0.1028031125315465, 0.16798799129901454, 0.15531963435932994, 0.16354985913494602, 0.1503182269516401, 0.1801557102589868, 0.28355779533740133, 0.14623534603742883, 0.26598920056130737, 0.09536997662507929, 0.13695413625100628, 0.19154396635713056, 0.08869532306562178, 0.13441265153232962, 0.14602343318983912, 0.10789702864713036, 0.19391159556107596, 0.10803764336742461, 0.1853607629891485, 0.1465125530376099, 0.19678248994750902, 0.2346404967829585, 0.21992477704770863, 0.20807288645301014, 0.224365996546112, 0.19051558716455474, 0.1669531108927913, 0.08576363936299458, 0.10879518318688497, 0.3375707095256075, 0.2236332296160981, 0.23424344777595252, 0.1270260408637114, 0.13490488840034232, 0.2147539670113474, 0.13657288014655933, 0.10183368212892674, 0.1638643813203089, 0.12109281509765424, 0.12929183256346732, 0.17541628098115325, 0.11227930677705444, 0.08653527998831123, 0.16391996818128973, 0.1806018449133262, 0.07082926807925105, 0.2702837419928983, 0.119698735215934, 0.11055042181396857, 0.2002870597061701, 0.294113599229604, 0.17805883137043566, 0.1891929464181885, 0.09705215823487379, 0.09918178810039535, 0.2027289630495943, 0.16957937856204808, 0.13552530901506543, 0.19596697355154902, 0.11370800042641349, 0.10894169798120856, 0.17166156292660162, 0.15655887254979461, 0.11958540926571004, 0.24224926193710417, 0.19308696559164673, 0.18933992134407163, 0.10919402819126844, 0.15050609421450645, 0.16318089299602434, 0.11133289779536426, 0.17837350198533386, 0.06894206075230613, 0.1502777502173558, 0.08518091985024512, 0.21403504855697975, 0.13155103399185464, 0.09364601952256635, 0.10040058012236841, 0.13676821341505274, 0.09218333550961688, 0.13129036204190925, 0.1059493437060155, 0.08911402052035555, 0.14311516424641013, 0.1256677325000055, 0.13937804993474856, 0.14718715043272823, 0.1879463906516321, 0.10749940076493658, 0.08284576702862978, 0.16121957480208948, 0.08800692172371782, 0.1256455125985667, 0.10740378245827742, 0.17547924479003996, 0.06685001324512996, 0.11454607069026679, 0.09726746269734576, 0.10814309513079934, 0.22315159061690792, 0.21516781824175268, 0.11940914177102968, 0.16306749283103272, 0.1498318975791335, 0.11148215111461468, 0.14918639237293974, 0.11840469684102573, 0.14299989386927336, 0.13597080542240292, 0.14345065952511504, 0.1970494701527059, 0.17059809499187395, 0.1684703872888349, 0.10110141985933296, 0.1908867500605993, 0.21868025476578623, 0.10382712047430687, 0.1810460796696134, 0.12198762997286394, 0.12241472111782059], [0.024133948536473326, 0.06828543817391619, 0.0124720468193118, 0.038413144429796375, 0.0679455122735817, 0.034499109533498995, 0.050440627164789476, 0.10261267001624219, 0.04783565913385246, 0.019762177362281363, 0.018101807472703513, 0.021334908888093196, 0.04687670043495018, 0.06850938123534434, 0.03899641313182656, 0.031668213196098804, 0.04969552202965133, 0.05251983180642128, 0.0822884141234681, 0.02017201728449436, 0.06263246963499114, 0.041412044447497465, 0.03671855040010996, 0.02415457653114572, 0.02721470929827774, 0.012329596211202443, 0.03482156898826361, 0.020319834547990467, 0.06489419436547905, 0.026671798586903606, 0.014295348737505265, 0.022451798467955086, 0.037104404109413736, 0.03494565979053732, 0.025095475066336803, 0.05689763849659357, 0.01904678596474696, 0.051251182303531095, 0.01845094342570519, 0.02575179336417932, 0.0912218312441837, 0.031146791370701976, 0.021262655245664064, 0.09586697065969929, 0.053810319004696794, 0.053874986042501405, 0.048674349091015756, 0.05512050280231051, 0.048281029376084916, 0.029402532818494365, 0.029142398925614543, 0.01568070652865572, 0.0826196643174626, 0.04529183293925598, 0.044578295055544004, 0.04162531913607381, 0.05382869087043218, 0.05232770461589098, 0.09733447863254696, 0.05301911536662374, 0.019541429246601183, 0.021469458406500053, 0.03361745664733462, 0.08307871976285242, 0.02370256963331485, 0.01516803369668196, 0.06498848422779702, 0.024556406824558508, 0.0663375825388357, 0.07931681029731408, 0.010714890668168664, 0.022553138733201195, 0.028019165838486515, 0.054526762396562845, 0.033261003118241206, 0.047693137094029225, 0.03086784217884997, 0.0297321799735073, 0.03343229451274965, 0.07733938749879599, 0.03188445647538174, 0.11540623469045386, 0.03763856118894182, 0.034690524262259714, 0.015385923616122454, 0.05679201232851483, 0.03709772106958553, 0.021695555551559664, 0.027192864181415644, 0.03477830920019187, 0.06816025270381942, 0.10285144118824974, 0.07331604167120531, 0.06253789775655605, 0.035705210830201395, 0.040674579722690396, 0.060784915258409455, 0.01116195857321145, 0.004749259487653035, 0.03807516666711308, 0.05528935253096279, 0.05045950740168337, 0.03856492847262416, 0.03413462225580588, 0.05474235258589033, 0.11714556909282692, 0.12843116390286013, 0.03295387272373773, 0.07760025982861407, 0.052579971743398346, 0.07066461519571021, 0.03368562291143462, 0.07785358451656066, 0.053982374811312184, 0.035553950001485646, 0.07427007250953466, 0.03402602749702055, 0.06257857487071306, 0.05629169347230345, 0.07171542951255105, 0.029146465894882567, 0.037304817378753796, 0.05026802587963175, 0.061557394510600716, 0.05468598646984901, 0.026905374725174624, 0.009327299012511503, 0.046384600864257663, 0.04099315032362938, 0.03113985228992533, 0.047194640210364014, 0.04354621625680011, 0.044691825096379034, 0.05257783806882799, 0.06812622523284517, 0.1070129600702785, 0.03344780168845318, 0.0766633206512779, 0.019862191038555466, 0.02001228855078807, 0.04495081608183682, 0.0037824715946044307, 0.0410269848362077, 0.06362389729474671, 0.030420503389905207, 0.08457131974864751, 0.028607609165192116, 0.04732959976536222, 0.041781826948863454, 0.029161900711187627, 0.04821401344088372, 0.02994999103975715, 0.07078901398926973, 0.04156415132456459, 0.058131444166065194, 0.03150174205075018, 0.0141869608523848, 0.023592798570462037, 0.022441458495450206, 0.06541657727211714, 0.032168520920095034, 0.04414880677359179, 0.11163478862727061, 0.0608695163828088, 0.028146605582151096, 0.009645143236411968, 0.024174135833163746, 0.04630149145668838, 0.048853863481781445, 0.03881977827404626, 0.12278673006221652, 0.03256914707890246, 0.04267749158316292, 0.04609953823091928, 0.024609090032754466, 0.00928823235881282, 0.018934183608507738, 0.08659854807774536, 0.045778752319165505, 0.021729660948039964, 0.024676139364601113, 0.0743343573412858, 0.026098847592948005, 0.033812860419857316, 0.010075122263515368, 0.0351261501054978, 0.024733752288739197, 0.017646394117036834, 0.03822654623945709, 0.018584311073936988, 0.03809741996519733, 0.03562977894034702, 0.020681915411842056, 0.015022344541648636, 0.06583032460184768, 0.02998892596224323, 0.03963990711781662, 0.01796449530957034, 0.031395169644383714, 0.018685154100239743, 0.01317524658588809, 0.046121635677991435, 0.0019078426271335047, 0.006063622504370869, 0.04435154296515975, 0.011796025428338908, 0.05855145151144825, 0.034505892763263546, 0.011949055351578863, 0.0353622977854684, 0.02333597465622006, 0.022136411680548918, 0.03990048629930243, 0.05507771056727506, 0.03166074719047174, 0.07824620290193707, 0.06343629720504396, 0.07426112963003106, 0.02769397342490265, 0.023792117171979044, 0.041890113716362976, 0.03030438325367868, 0.05229865695582703, 0.011740803147404222, 0.03805094296694733, 0.024992036378534976, 0.029445720247167628, 0.03191138159309048, 0.030781554523855448, 0.038577923478442244, 0.03619371469540056, 0.013754218252870487, 0.01708711719402345, 0.06005030038068071, 0.06311246848781593, 0.01350541046122089, 0.01477120362324058, 0.04789937622263096, 0.10790232758154161, 0.04900321699096821, 0.011086872709711315, 0.050824239588109776, 0.05815164542582352, 0.019810251833405346, 0.025945015222532675, 0.0741432246286422, 0.02281639892316889, 0.04328347000409849, 0.02119055003277026, 0.03366120254213456, 0.027264878481219057, 0.05029619780543726, 0.043884839687962085, 0.030936730181565508, 0.03160549429594539, 0.05806041692267172, 0.0513792361743981, 0.1064933676389046, 0.017761300841812044, 0.11172733444254845, 0.10532603613683023, 0.0711732535273768, 0.06512351057608612, 0.03544118437275756, 0.015645606654288713, 0.0059558018983807415, 0.023586045026604552, 0.016417182341683656, 0.02814746090734843, 0.02993581787450239, 0.025650132120063063, 0.013389602027018555, 0.03249863933888264, 0.03377865854417905, 0.05452185680042021, 0.042139697980019264, 0.04904315195744857, 0.01742252155963797, 0.09456178522668779, 0.0395210410351865, 0.026464418406249024, 0.05198738908802625, 0.06046549118764233, 0.02059063124761451, 0.008856063068378717, 0.017809451383072883, 0.052847597617073916, 0.1040331184049137, 0.053426535887410864, 0.02262766705825925, 0.02792881306959316, 0.08344549656612799, 0.02947541172034107, 0.00953722754275077, 0.029118644633854274, 0.03154742866172455, 0.010612403784762137, 0.07328588078962639, 0.01745825597026851, 0.010233124576188857, 0.05134122337040026, 0.04527213633991778, 0.078721080935793, 0.0808490632334724, 0.09271794158848934, 0.07648648170288652, 0.01510055762992124, 0.05568102467805147, 0.02296655766258482, 0.12294898580876179, 0.01133884576120181, 0.035868568666046485, 0.03627390746260062, 0.053180128015810624, 0.024409010729868896, 0.10694600350689143, 0.06615148900891654, 0.04115744697628543, 0.04255275511241052, 0.04089676389412489, 0.10477649062522687, 0.037465280838659965, 0.0677473662653938, 0.01721028773317812, 0.008458981592411874, 0.0675474910531193, 0.07940836905618198, 0.027943652312387712, 0.08371515592443757, 0.02541739089792827, 0.06412325135897845, 0.048596334527246654, 0.004968951434420887, 0.014061331949051237, 0.04227799719956238, 0.05710013349016663, 0.06456078452174552, 0.023698639961367007, 0.006697362814520602, 0.03102894017501967, 0.007111877803254174, 0.0657343129569199, 0.03744820773135871, 0.049804573209257796, 0.018161403786507435, 0.043858604767592624, 0.036565512127708644, 0.03484961845970247, 0.04093740019015968, 0.023060491294017993, 0.024134256527759135, 0.0071530595778313, 0.0970143532322254, 0.15752602455904707, 0.13484685245202854, 0.14149091468425468, 0.1496235915692523, 0.12440073798643425, 0.24564914434449747, 0.16318441077601165, 0.13668491475982592, 0.09194292419124395, 0.0949083236628212, 0.1350843842374161, 0.14936248917365447, 0.1178231647645589, 0.1074157829862088, 0.14568957063602284, 0.10505769037990831, 0.09216839607688598, 0.12208006446599029, 0.15521778201218694, 0.21525274962186813, 0.0882881363213528, 0.10610937300953083, 0.07737985681160353, 0.07911118344054557, 0.21633310883771628, 0.11784338828874752, 0.1447301369626075, 0.17175657267216593, 0.16245462727965787, 0.16800859331851825, 0.14353223639773205, 0.07621936791110784, 0.19875519268680364, 0.08523560129106045, 0.14074303762754425, 0.11886629043146968, 0.12799405376426876, 0.07394786167424172, 0.12078490544809029, 0.1950290473178029, 0.16900218062801287, 0.10302235779818147, 0.12569433107273653, 0.16882240277482197, 0.1456142426468432, 0.11882017337484285, 0.14301715622423217, 0.15467215504031628, 0.09075864945771173, 0.11298209094093181, 0.18237176322145388, 0.16217068157857284, 0.17938610311830416, 0.182454290043097, 0.08042831002967432, 0.1083254705008585, 0.13397537812124938, 0.15632208291208372, 0.17307556205196306, 0.11282250692602247, 0.1962985354475677, 0.16177704645087942, 0.16617157001746818, 0.09960679381038062, 0.11698113885358907, 0.25125872693024576, 0.12067806586856022, 0.12658777297474444, 0.12635130988201126, 0.13587100140284747, 0.19393939641304314, 0.177810657187365, 0.1271432705107145, 0.1733472920022905, 0.09483105124672875, 0.13741106173256412, 0.11870280271978118, 0.1046862528892234, 0.17264658585190773, 0.21456753951497376, 0.2510127198183909, 0.1356558527913876, 0.1260461684432812, 0.1895592556684278, 0.1191110655781813, 0.12198894357425161, 0.17956277879420668, 0.12442416016710922, 0.0806066110089887, 0.16174773161765188, 0.12970727198990062, 0.22837354947114363, 0.18585780897410586, 0.15232275298330933, 0.1048061394249089, 0.18035898450762033, 0.0733524291717913, 0.15908400033367798, 0.13147211400792003, 0.12031959369778633, 0.11304152954835445, 0.1612338240374811, 0.1779926021117717, 0.10841033508768305, 0.2755161502864212, 0.23093232623068616, 0.16921768547035754, 0.16015983244869858, 0.05633169894281309, 0.22469191811978817, 0.16732022166252136, 0.2085470297606662, 0.07370518680545501, 0.1673093714634888, 0.14710469782585278, 0.15157592977629974, 0.11000842394423671, 0.19577310973545536, 0.16712555632693693, 0.09664943921961822, 0.14990302501246333, 0.12392961521982215, 0.12474013696191832, 0.1907448365818709, 0.14519243559334427, 0.19485517696011811, 0.17356009542709216, 0.16257084760582075, 0.15326821943745017, 0.1429685900802724, 0.1421842142008245, 0.13047358399489895, 0.15792037214851007, 0.17269553791265935, 0.18817581818439066, 0.1075211753777694, 0.14696694037411362, 0.1229228473675903, 0.16600862407358363, 0.15433038119226694, 0.1186151550791692, 0.12514178728451952, 0.11646192491753027, 0.16692660137778148, 0.2166265540290624, 0.3274312801659107, 0.09423242008779198, 0.05979877169011161, 0.17197084554936737, 0.15701524884207174, 0.10772819747217, 0.28490449651144445, 0.16577444679569453, 0.12200619108625688, 0.14489798108115792, 0.06420862060622312, 0.15320673992391676, 0.0971175340237096, 0.22602628479944542, 0.15969496598700061, 0.18605317192850634, 0.2187298153876327, 0.10961225067148916, 0.11668121471302584, 0.14017639303347096, 0.0835578577243723, 0.18426567956339568, 0.18035678775049746, 0.12071961871697567, 0.18054426909657195, 0.13344440114451572, 0.13687785831280053, 0.17790627549402416, 0.093048932030797, 0.14712265779962763], [0.07779054649290629, 0.023612324475834612, 0.03994159014837351, 0.013794040041830158, 0.0981983459496405, 0.01578777617396554, 0.02291887838509865, 0.05061718780780211, 0.026335674338042736, 0.07428527911542915, 0.01413894111465197, 0.03337019159516785, 0.005110125548526412, 0.008513390293956036, 0.045335671602515504, 0.033134470650111325, 0.03393860621144995, 0.04980106656148564, 0.028453543018258642, 0.026473385405552108, 0.03776848527195398, 0.07432555546984076, 0.03365932861925103, 0.011362054574419744, 0.027324827315169387, 0.07393054736894555, 0.026191282086074352, 0.02465127927280264, 0.06160269520478323, 0.023446179875463713, 0.05189512528886553, 0.0286690070424811, 0.03338319031172432, 0.04273093363735825, 0.09572757306159474, 0.023189274324977305, 0.022797288620495237, 0.03184528963174671, 0.031127005713642575, 0.005309854650477064, 0.035075799096375704, 0.03572795023501385, 0.04957157223543618, 0.07220618950668722, 0.019910029877792113, 0.03061492752749473, 0.0751723608118482, 0.03309235005872324, 0.019153274879499804, 0.049186820615432225, 0.05973166298645083, 0.0456363564444473, 0.043388973717810586, 0.04892153250693809, 0.06790901345084421, 0.01354573041680851, 0.027802551485365257, 0.0163849044838571, 0.040725680300965905, 0.05290261673508212, 0.022562183658010326, 0.019957683180109598, 0.0480497538956115, 0.045987841294845566, 0.058547351145534776, 0.03428137082664762, 0.08083882901701145, 0.015572321426589042, 0.05416102460003458, 0.010671176314644981, 0.05886375096451957, 0.04627628070011269, 0.06718902630382217, 0.03629113642091397, 0.07698185785557143, 0.039754153331159614, 0.04453376248420682, 0.02227993190899724, 0.009606006078684004, 0.055998574825935066, 0.04168878760538064, 0.03207689165719785, 0.02661118738615187, 0.009212253135046922, 0.006121685819380218, 0.02436811468214728, 0.02140922013495583, 0.008968444635684136, 0.03030673586181365, 0.041928304635803215, 0.02923891708633164, 0.01756964120431803, 0.011065114795201225, 0.010199388398177689, 0.056339599104830995, 0.07643675780855119, 0.027731023292290047, 0.03634043358033523, 0.050511639565229416, 0.018703325586102437, 0.039483532891608775, 0.03123444643279072, 0.011690453065966722, 0.10378686638432555, 0.080596495536156, 0.05351580140995793, 0.019587243878049776, 0.06037878978531808, 0.06165772916574497, 0.04844001596211456, 0.062293011287692934, 0.007300725164895994, 0.023712970833003055, 0.04591132215864491, 0.058893919267575257, 0.10248372185742483, 0.03936748697014991, 0.023038518156681675, 0.03737454586371314, 0.03359804206411354, 0.07011981200776063, 0.04684006060415413, 0.07184343514381908, 0.048843569893506356, 0.007908580755611183, 0.03948492812924087, 0.030310762012959458, 0.06376484598149545, 0.07655097433598712, 0.04296250226616394, 0.04395751078845933, 0.024300215591210872, 0.016453892676508985, 0.009924318783305353, 0.025030813594639767, 0.05121030109876301, 0.030881323291396257, 0.04445149541425053, 0.10520588984945789, 0.03432946570683271, 0.02808864570397418, 0.05200637322559487, 0.014821700278844219, 0.05522036619368009, 0.06224370299605653, 0.0925559233292006, 0.019352565650478937, 0.09196400860673748, 0.02287686540512368, 0.036045674787601456, 0.027863428003911395, 0.012737691158690723, 0.011778420757764252, 0.020998452528147027, 0.06396297714672983, 0.0018550715208220936, 0.016974383106571622, 0.04946396453306079, 0.005933690072197351, 0.015668470368837006, 0.027426395790826064, 0.010938051691482542, 0.051856689460691996, 0.04565616065519862, 0.02987661489896709, 0.013464134062814992, 0.03063924770685844, 0.04528018493147101, 0.011064080426876899, 0.008822136715025408, 0.11685374920489267, 0.015055489784572273, 0.03672725579235703, 0.08510449348250404, 0.030686862046422902, 0.04309299409214873, 0.03663777875772212, 0.039961542788660154, 0.029523510311264545, 0.008065452220762381, 0.03317723690997809, 0.0438186178507749, 0.026681581948651, 0.04178820570814423, 0.023990663939912338, 0.12809888954507187, 0.02098921835568035, 0.03921709816495422, 0.03135357968858443, 0.018005376514338423, 0.027159883138665464, 0.04951777395035606, 0.0741207375540398, 0.051606251727207564, 0.08523352327756584, 0.07224999106256291, 0.02876997066778131, 0.031600403162883595, 0.07543978630565107, 0.11394746921723709, 0.031335452731582336, 0.04823034811124671, 0.07347711740294471, 0.03778541737119667, 0.05649817750963848, 0.04536010310403071, 0.01665085495915264, 0.0451523314404767, 0.03809711568464991, 0.030345286722877063, 0.054626154524157755, 0.03107382155576488, 0.0019011433528248745, 0.01938603279995732, 0.07679581627598964, 0.020244283914507832, 0.09776186663657427, 0.026913916844932828, 0.0501076255022781, 0.03037368500372395, 0.059502647345652804, 0.04575776067213155, 0.032310820315615274, 0.043100909097120166, 0.028180605222587474, 0.04872198012890294, 0.07380973314866424, 0.05799031365313567, 0.040780406270641834, 0.019009313073183876, 0.08458213284029625, 0.029660557156603318, 0.020307854429120198, 0.033462826468166895, 0.03519102494465187, 0.12919263710500672, 0.014646854924649233, 0.024029532069107518, 0.04831247788388282, 0.04125975203351118, 0.04160877666436136, 0.054321506613632664, 0.019149591971654445, 0.06878151936689392, 0.04478273076529149, 0.05140863635460846, 0.017747003366821446, 0.006933858840056928, 0.08200246462365612, 0.040210251318058, 0.0933997229731176, 0.05904734345676843, 0.09328403699328192, 0.035618234833236784, 0.09605288607417606, 0.06298702326603234, 0.05365607845305931, 0.013061728604952805, 0.029822248870914336, 0.011895061325049028, 0.07331918095587753, 0.08368315451662056, 0.017723753735481296, 0.0141177101249923, 0.06500423260149546, 0.07654223925783299, 0.05614580579276662, 0.05998073516821023, 0.017237628453585785, 0.03420705957978498, 0.009427331242477521, 0.040275946230394766, 0.029885086514696013, 0.017383677550242282, 0.030993153814051766, 0.023205338111438323, 0.011249499530094909, 0.022610232153965626, 0.022765341018384788, 0.0505563057231484, 0.03794596988882404, 0.06839267109171487, 0.06342527631204575, 0.05229112044617068, 0.0016627513718958653, 0.006097299774410203, 0.05664107062330004, 0.05791629555460531, 0.047542781685478985, 0.05960117116046604, 0.01052815796356299, 0.05811137278215028, 0.031525398007943295, 0.06230855928151868, 0.0918295314477291, 0.04102338913071435, 0.01942853930813726, 0.009348148723802296, 0.06445044942665845, 0.02698192354728235, 0.010778595697047422, 0.0144426066071901, 0.0364934161916608, 0.03962522743677255, 0.02413944785075728, 0.06307698640739545, 0.03305394762719516, 0.029979029422975145, 0.08671298724948429, 0.03431929086218588, 0.03131609380943701, 0.037289725805749185, 0.041438657863182016, 0.024264724233944435, 0.026255835946358275, 0.03525955857185181, 0.037011220047133975, 0.0486039823590545, 0.03392099133634474, 0.04618937149643898, 0.035239513163105585, 0.033074037564801984, 0.061551438775495626, 0.02434536043438129, 0.020360238922876306, 0.035678541753441095, 0.03279714597738348, 0.06179989497468341, 0.011359330892446451, 0.023179533636721317, 0.022379852816811763, 0.042476740636629984, 0.048521685603191145, 0.06308209238341078, 0.033911380523932166, 0.02370531186898006, 0.023277179861906916, 0.023405699430441018, 0.010177564618061297, 0.011730787864507874, 0.019259836153651122, 0.02197030233219266, 0.07086947764037177, 0.03303851466625929, 0.07985780626768246, 0.01529948382085422, 0.10363344961660914, 0.018285388832737226, 0.04120361598324962, 0.0191522136083222, 0.04105542764591519, 0.07417861765134148, 0.10993425370543264, 0.13525720074540004, 0.13765435258392245, 0.18527488166000694, 0.1172641123412177, 0.13018205354455858, 0.07753792684525251, 0.13530750351492316, 0.11776521787396632, 0.2457772390334867, 0.23510114784585312, 0.09956394220353104, 0.16370050027035177, 0.14513981732307002, 0.15044269995996729, 0.12140197897679172, 0.14273610489908606, 0.12323112809099257, 0.14876313070999458, 0.17911694099893793, 0.08243210133514367, 0.17601372470380738, 0.12912719452288002, 0.13275886449264362, 0.16339740715920925, 0.12694842705968767, 0.16723836277378723, 0.16985165770165622, 0.18685369694139808, 0.12522753502707928, 0.17072914342861623, 0.15020941325929016, 0.14207522239303216, 0.11502934983582236, 0.18391174933640286, 0.18647566175786778, 0.08182509875041433, 0.12633958394872025, 0.16678388637956232, 0.1506130228517577, 0.1997143295011483, 0.10272981802700087, 0.13630684989038855, 0.19224621617468074, 0.20233201794326305, 0.17109435430029407, 0.15221051056869328, 0.13936032744823024, 0.16339532914571464, 0.15737680834718049, 0.25156775722280145, 0.11676122565404512, 0.1517640196834691, 0.13103631004923955, 0.18537912372266874, 0.15304830623790622, 0.11709029393387027, 0.1669282341026701, 0.08002688235137612, 0.15563659078907222, 0.19155638990923762, 0.1675813685869798, 0.20990376477129757, 0.09038564603542909, 0.15826811286387965, 0.164812222647015, 0.16163375257747248, 0.1183424454939086, 0.10556669236393645, 0.0980062855524011, 0.10440326455864124, 0.11156356471474282, 0.1718382237595506, 0.12248419356183149, 0.24297741270856932, 0.1279369677649811, 0.12546076235594228, 0.14271636377088726, 0.1759212531032972, 0.18471450079232454, 0.302487785811536, 0.20844154088990763, 0.10088579627336003, 0.12501538469223306, 0.13492776139173657, 0.144406991021242, 0.06456511866417713, 0.08072322467342019, 0.13786766066914424, 0.16482947015902027, 0.1292064558947459, 0.14463166880887002, 0.09557581870467402, 0.2603754767915234, 0.1514819441945292, 0.2794773189816624, 0.2516514714807272, 0.08988075554952957, 0.12791649933205917, 0.07898409065091982, 0.09490121388807893, 0.19994387577753514, 0.1696323382202536, 0.20125985203776509, 0.2241804002551362, 0.21178640046855435, 0.14348162192618474, 0.2305263714515604, 0.1489770770422183, 0.08729448221856728, 0.16834269335959107, 0.15772567712701857, 0.11530269766808487, 0.1320886902976781, 0.1893075488624163, 0.189754722523503, 0.0926262121356558, 0.07897211238741875, 0.12089723692042753, 0.17481543822214007, 0.13004998094402254, 0.1738847850356251, 0.17128277075244114, 0.09464405971812084, 0.09510645482805558, 0.07541804137872532, 0.08650785021018237, 0.12067808071151376, 0.1633368627517484, 0.2380694862222299, 0.18901340605225414, 0.10994026510161348, 0.12914693565107882, 0.07860167679609731, 0.1705532692722045, 0.15252742246957496, 0.10682599080610089, 0.13640092452988029, 0.22413462458644062, 0.07164276583353058, 0.11778491447330453, 0.16147140035172924, 0.07666923556826077, 0.13950167689472437, 0.16454412922030315, 0.10582313407212496, 0.1620908413315192, 0.14610814192565158, 0.14503676269669086, 0.08858002300257795, 0.20555145456455648, 0.1330205606063828, 0.07581017736811191, 0.0825215969234705, 0.17375161405652761, 0.11347744482918642, 0.2197565173264593, 0.14289240119978786, 0.08737460448173806, 0.2380781396641396, 0.15621991886291653, 0.09390179329784587, 0.16334137500962242, 0.21808563120430335, 0.2147210601833649, 0.10961867767036892, 0.1071491144830361, 0.16463759529870003, 0.13333242590306327, 0.1046318312000949, 0.2588267927058041, 0.15151011612033471, 0.1347216372960247, 0.16774858930148184, 0.13123775861458853, 0.14491512469248846], [0.05625614459859207, 0.06716039424645714, 0.04895966034382582, 0.013430843173409812, 0.03516375472827349, 0.001643793905259372, 0.07096770088537596, 0.0038618081089225598, 0.013385720594669692, 0.08271819184301421, 0.05985273324768059, 0.021120552519278135, 0.026137982895306777, 0.07187191135017201, 0.0312407361343503, 0.0063177482479659375, 0.03234382362279575, 0.018521937272453215, 0.061432639486156404, 0.025866130490612704, 0.01642498045839602, 0.03675344989460427, 0.010506907492526807, 0.06709317793138325, 0.0395700413355371, 0.02452165947033791, 0.043077553709736094, 0.03349240105308127, 0.06342907610815018, 0.06592230638489127, 0.03785661159781739, 0.017842755260062404, 0.01623052106879186, 0.05479313404066488, 0.042047111346619204, 0.04864349430135917, 0.019408453081268817, 0.06646731737419032, 0.04819291418243665, 0.042227879966958426, 0.04328607494244352, 0.02030080959229963, 0.05598186908173375, 0.013980112235003617, 0.016773630304669496, 0.03745244910533074, 0.009333623038401129, 0.025005760544445366, 0.07795015277224593, 0.021101941310917027, 0.048552967127761804, 0.074656241631601, 0.036103773818467744, 0.03830916582955979, 0.013233743593445979, 0.06146513071144, 0.014075784347369336, 0.053278544219210744, 0.0442165500135161, 0.027997786419291515, 0.0740492538898252, 0.1274540671147406, 0.025760357748367824, 0.05910625142860226, 0.016049197693064343, 0.03957097644160967, 0.007966423745529028, 0.03839325116132386, 0.025483256504230667, 0.031152402007137425, 0.030934641035855748, 0.05527803848963231, 0.01900205486890627, 0.02710501430556178, 0.05247652377875056, 0.01921929077070672, 0.06156030372949317, 0.04947826200805139, 0.01604298591701081, 0.03766264759178739, 0.049591832867008634, 0.11240036590606906, 0.008868155437085079, 0.03920489725715015, 0.02453683082421776, 0.024806354740576353, 0.014090492786635878, 0.08548227633582428, 0.067099827574566, 0.02085325504594948, 0.06774237903300673, 0.025521317547827493, 0.0050573607040860225, 0.02331430765480036, 0.003088198473051307, 0.046438365752692334, 0.10797140668728389, 0.05001213707146235, 0.04603271525411401, 0.037213685354799964, 0.030761023008381017, 0.024207653077610303, 0.028312087815720588, 0.040572638317826204, 0.03048569920792943, 0.038088610672275536, 0.0031836115294936462, 0.05861050791281741, 0.009075970701815095, 0.10619577384204604, 0.0625655056501273, 0.06294902530498803, 0.03698805390740745, 0.06326632312266156, 0.05575083108851686, 0.12745390384225175, 0.05196290192543529, 0.049163535732077435, 0.06530003040097654, 0.03270973953476641, 0.02433228935842635, 0.1334847739781253, 0.03014790141605772, 0.06753848880180158, 0.03585135083994828, 0.08945108173065819, 0.03188988528563641, 0.025170001536025666, 0.06676866643829271, 0.025749583619472105, 0.04844359682465438, 0.0479307727800915, 0.08918449486372992, 0.05140688117535319, 0.03001659508299781, 0.02556835115683498, 0.02743329034274211, 0.1263671473134309, 0.06504203760414384, 0.0012286652531656728, 0.046313061538967304, 0.047228597177308984, 0.03532730552251451, 0.022188271104823798, 0.05762512133514974, 0.034983513032784685, 0.05455872669699602, 0.013436414847092237, 0.02899385435739532, 0.05480014733620919, 0.0603141821193276, 0.027024782575608697, 0.04737473347631749, 0.006400508382284897, 0.03297079369076528, 0.04741328062664252, 0.046905532872187905, 0.04079061822267249, 0.04108582972548902, 0.025174729016725905, 0.02209789050539257, 0.0681650840851944, 0.07824161642929539, 0.04494978449656628, 0.10513902976526879, 0.01166724796348717, 0.017726414334902074, 0.06538004876347259, 0.03412655882129911, 0.10756539995782077, 0.061316827341215685, 0.0759247352834791, 0.10439533842145465, 0.024806286091916263, 0.08773568159085698, 0.059183668563491665, 0.053606361980200745, 0.07951448133098893, 0.02478052985679824, 0.0740193527599331, 0.03231303933716845, 0.02742686334386235, 0.02682779246242717, 0.1011829670460429, 0.07390107668470591, 0.12021212329273112, 0.11299414341920055, 0.025432189322600607, 0.03928315301891416, 0.032063885519164614, 0.029019154171692207, 0.0644249640754424, 0.04759749281220138, 0.03148899937514216, 0.0583872216520831, 0.03675624779134523, 0.04274176899343729, 0.04436438211996574, 0.020484838096308522, 0.0058182708016829565, 0.018361219626967795, 0.07032475608866662, 0.00516265615260636, 0.03467334354354534, 0.0657677541312296, 0.04674104697187431, 0.03526725464325864, 0.03518417492159642, 0.040356736426474527, 0.105304751341464, 0.06469791114795953, 0.01941668535437202, 0.044583575436263345, 0.06892894700285979, 0.04062269246787764, 0.019416366230871063, 0.03678036759083625, 0.011328273867547978, 0.011526136004249565, 0.048118439663085155, 0.08590374942286871, 0.02966380590805784, 0.02814885985571891, 0.027414499163569417, 0.03884142672177404, 0.006970278345761471, 0.03805171851126943, 0.03415973282244522, 0.03336676658364013, 0.015737440007796977, 0.06491717125754803, 0.056517254415666685, 0.028797430131817237, 0.09055319329490885, 0.013198806991567835, 0.01359946005322854, 0.11041345103876665, 0.05555936440941878, 0.03484374065010343, 0.054545019229408354, 0.02498548692528857, 0.07636306254426017, 0.05200539730140008, 0.02266659455926856, 0.02933649651822634, 0.021270783618092537, 0.011377944883861346, 0.04781935414939653, 0.027741105368477292, 0.0472020134475315, 0.011252841977693606, 0.04027783499623183, 0.03566324608982541, 0.045333218804444186, 0.020969573706679512, 0.04380928905447945, 0.0031636201583751244, 0.09594853268936276, 0.048463987332070246, 0.01064674945155275, 0.0412608095939504, 0.04237555622239597, 0.05951138613454532, 0.08650355317513458, 0.05706266616471112, 0.03746150330698583, 0.12360517052002251, 0.01796577180357417, 0.06301615256234072, 0.03356152468768414, 0.0260236884423648, 0.012400383184285602, 0.0925716345955152, 0.07790787261910737, 0.09528096343274228, 0.027489591520861723, 0.011824141693068668, 0.032434907407150604, 0.04821951275516767, 0.11110018996987492, 0.07108955411240458, 0.011719316116796108, 0.005156465249456232, 0.029676735975954216, 0.09441630201763473, 0.07675462707993574, 0.05889272069907747, 0.04120894089282956, 0.06952754105441272, 0.01701818280707812, 0.0394331336428877, 0.005051009775343118, 0.04430566339578945, 0.048785007020342164, 0.060988723853370175, 0.03234062125557102, 0.046135625161696225, 0.11859181453473866, 0.05764057656051591, 0.011211414366698591, 0.05677981142071076, 0.04032338430988602, 0.03948078694520518, 0.07002098762313835, 0.002859385067495168, 0.03316520669613965, 0.06533082952955738, 0.026074447632709052, 0.07036195995169692, 0.05352050662622787, 0.02087439141178038, 0.007451515657521668, 0.0668905048223678, 0.061877623811597005, 0.038213246953091584, 0.018558554838818964, 0.02159185525670182, 0.05616618145722896, 0.022066276869736612, 0.02403487182164099, 0.016053953004302457, 0.08840466834953986, 0.10449367298861034, 0.02533156151912408, 0.015131883683352498, 0.011378000544937095, 0.012468823115341365, 0.01719035364658339, 0.017982587014557794, 0.028971550964342896, 0.04674483192502521, 0.06755730966688134, 0.042356085978099145, 0.14329739118693396, 0.006383294730767375, 0.060031360771972686, 0.02009204345085891, 0.04341291911259759, 0.03872198176395614, 0.052429742499953136, 0.03988316086179111, 0.02464845725626219, 0.024354589040740393, 0.016254191868938506, 0.06601832545129582, 0.07392985717160627, 0.060646367419394664, 0.045693086212850176, 0.07346836748183705, 0.06132639362476766, 0.09027483596582897, 0.07055027250316925, 0.1282862966763787, 0.1889332095743157, 0.11093676163000055, 0.15394346992252395, 0.1310623891185969, 0.13954593858215958, 0.14822351513430476, 0.18008073850069195, 0.12187666405225173, 0.20765370660228655, 0.2496270410483703, 0.14495595765765756, 0.1356282745837234, 0.16103722911793739, 0.08460706158075482, 0.17040408274624497, 0.1957874628715217, 0.0749078593798913, 0.15474181302124634, 0.14074441802222282, 0.18258812895510346, 0.1139135827543214, 0.09537611418636516, 0.0889821037708316, 0.11672196604195051, 0.16280296171316877, 0.1151093904627487, 0.09043047175509855, 0.17333446769043803, 0.1689344522310421, 0.21901668515056372, 0.13318594079464674, 0.20226566994097084, 0.2889271447202191, 0.10608903816319071, 0.1565362370456569, 0.1143510862311814, 0.16618828318314627, 0.23626437527127564, 0.15009573107818142, 0.11258371348958462, 0.08009784651221707, 0.1661012737895362, 0.09279569640057161, 0.18125683476682752, 0.1676582105574198, 0.1122510309505742, 0.15877170459134504, 0.23817415873054415, 0.14778196695260704, 0.21376005315687507, 0.16806208732305095, 0.13588866451755166, 0.10847916928469203, 0.13725250930292532, 0.13057784090051427, 0.21443344827275723, 0.27147435466758907, 0.13595802563941106, 0.1980375952553004, 0.2291319056530483, 0.24467010312946513, 0.20699404121842235, 0.17325363296549767, 0.07707850032602437, 0.15811597259016708, 0.13084189704386517, 0.17246795090613887, 0.10194193178904243, 0.15949081600410864, 0.08895237333490513, 0.2974252699641511, 0.3282946057152003, 0.20110181911149994, 0.12300652451813221, 0.1623044314328581, 0.11520224055857398, 0.21771010447992012, 0.18229670240543783, 0.11736704080249183, 0.13830255920765921, 0.1645239576464519, 0.1192879638983868, 0.09738034335896373, 0.1251228922046721, 0.09075821901205927, 0.17437448375858366, 0.2084635678329505, 0.2409030802664347, 0.10034310078481212, 0.16797196090919897, 0.1367881178157404, 0.1339264409034513, 0.13585323438746855, 0.12733334937365726, 0.08711523871170357, 0.16538962838239968, 0.17973415553569794, 0.143494579824619, 0.08109792761388235, 0.11637062591034919, 0.17613579315366223, 0.1391579140909016, 0.27854559710249305, 0.22576908610062674, 0.15521674300543964, 0.07317547147977166, 0.17784966446924955, 0.22198143153218552, 0.19555735256290063, 0.14531876397086307, 0.1434369446360506, 0.15792970836628228, 0.09581514648743905, 0.13626503729028627, 0.20170096977381036, 0.13824447873048484, 0.13028311921516433, 0.15000551560660824, 0.16897106979740784, 0.10606503710732795, 0.2931053173961118, 0.17793783161323518, 0.16183932748390362, 0.09006684907944873, 0.1373124006204307, 0.10055678736534901, 0.14448962174355984, 0.08639378211228177, 0.10147149179829285, 0.18145126261515543, 0.11774253041949123, 0.23150124179665, 0.12110183961340226, 0.1298657650477253, 0.2471484904526733, 0.0684165459824726, 0.4599595000036061, 0.18363512121140957, 0.12684930581599474, 0.14708733157021925, 0.10888859731494449, 0.07564873056253418, 0.11959899798966944, 0.13382840319536626, 0.14179084624629468, 0.17822747700847685, 0.09832211391767487, 0.13419168448308483, 0.1614345601410605, 0.07987186254467815, 0.10473559828824364, 0.09865642918157391, 0.09312413385487162, 0.09581001824699342, 0.21888725459575653, 0.11733788924175315, 0.15858024533372372, 0.1345938691520132, 0.17785094096325338, 0.08333844918524846, 0.13654328329721466, 0.13615245348773897, 0.1033201816608198, 0.129834312829189, 0.07740048109553754, 0.10882696195039898, 0.12457857141271234, 0.14284236560342833, 0.2066687578917481, 0.14294827007688582, 0.11501215427415445, 0.2225297747645527, 0.18134463083697483, 0.26653470878954977, 0.1577063070726581], [0.01360811163976905, 0.042492451902944595, 0.07821980470907874, 0.038653366500511765, 0.024843239480105694, 0.042441971017979085, 0.08128654444590211, 0.07426770505844615, 0.03248074986913707, 0.020007199273095466, 0.04784304721397348, 0.05309535990818404, 0.05396793261752464, 0.04530624544713646, 0.04403634542541113, 0.004074997914358391, 0.029364872534642927, 0.0038497600371556473, 0.07567211563582532, 0.04875079401244875, 0.04164104895608034, 0.0131069671442674, 0.08129011417622678, 0.039633186970604584, 0.06437616786570288, 0.08569037454435602, 0.037095153238624334, 0.005099696054458036, 0.025325305214209948, 0.043624338431982324, 0.04105694533791393, 0.017533567261125427, 0.0462715866160579, 0.06233232285012491, 0.03515708653139882, 0.0629525950353127, 0.057021465836442076, 0.07192455930635333, 0.029948185765533708, 0.028369049505272415, 0.14278979186201468, 0.038198133115656674, 0.06667019086307846, 0.05435069899249356, 0.037617358029820025, 0.0367425329022808, 0.0441768005839549, 0.11290381662547588, 0.06472835404565558, 0.029734668023593258, 0.04252608974638861, 0.13234870915766805, 0.024513176722393837, 0.03603378187108319, 0.012364502199488925, 0.027027945980080403, 0.025346660513605457, 0.04797038120159414, 0.041567401931388304, 0.037304665238480084, 0.052013664826517925, 0.0785338890273124, 0.03274074275395833, 0.023695788258919492, 0.006910227930347901, 0.041253621893702075, 0.047355875503853895, 0.03537124808644876, 0.0060214615587028675, 0.07793606680934317, 0.04598703235387802, 0.02895698075008113, 0.010502355344215175, 0.03800094447797164, 0.03192259173374623, 0.03388489698409103, 0.02493174801202258, 0.07841046986868605, 0.0104757252302079, 0.021256669824651908, 0.051411107706371695, 0.024707151860638987, 0.027665439702104777, 0.07109998128726147, 0.03614851048041601, 0.03193066630046815, 0.06775636109523475, 0.03589079969970044, 0.048096360769704916, 0.04643820990168024, 0.07437249631038867, 0.04018001251097303, 0.009260496444767341, 0.042121485676034354, 0.01592559856362641, 0.013794233927910682, 0.06406894841347821, 0.04478146911424119, 0.04826789336220827, 0.044459510609158315, 0.054411224846262485, 0.07046237995382398, 0.13834466866683215, 0.02812454338709358, 0.05565848194237333, 0.0631606338720303, 0.0814034920767881, 0.061578898239531554, 0.04273700440535322, 0.05926076657488011, 0.09925480058882385, 0.05035895010223612, 0.034540443448349833, 0.0473191577475518, 0.02990186090755742, 0.017706565595290158, 0.12316599721089005, 0.02768705104244873, 0.07907058054115623, 0.030718149137101136, 0.0736178360239137, 0.012409214741637697, 0.010830169394466793, 0.04621701278665569, 0.06543061128468253, 0.07483762994525023, 0.042682686616899446, 0.03700798799400218, 0.019020591862499714, 0.01665846382820746, 0.056434835205436684, 0.0526405124401208, 0.011985248966084328, 0.0744384658173658, 0.040796659304760396, 0.015067160984472139, 0.021867936047783587, 0.026577211865514982, 0.03626081226684619, 0.03710393655637745, 0.010526900023251073, 0.01482151195887127, 0.06378664285875857, 0.04084551859705243, 0.04794606473296881, 0.05880369266378693, 0.06032778197550215, 0.06863393587991595, 0.05259685931378044, 0.013034432413405739, 0.034232619145768695, 0.02285087353811832, 0.03294643640401773, 0.009980284139601281, 0.019555079197743908, 0.017137510876636952, 0.01594579611264635, 0.00598216576690902, 0.024862381324055605, 0.05383459836593829, 0.03890856882208027, 0.028340064927760977, 0.043791692733066157, 0.05099290006910451, 0.013797006777167553, 0.01708404099190375, 0.019429851054155733, 0.02836244624631945, 0.10058772008051164, 0.05782437314337585, 0.038915103432373144, 0.012529784980870318, 0.018286075319338124, 0.028323103142611217, 0.039014807261992246, 0.054464941495098174, 0.0038578394742216915, 0.026466509407327976, 0.04470167710678652, 0.04925133180222474, 0.045383918622974306, 0.03766555309994146, 0.00263010016624321, 0.013869411632185802, 0.043749390315497294, 0.04212890344206244, 0.014974232035456225, 0.047535850026179105, 0.0934172970301006, 0.03225073232897557, 0.016235851544479374, 0.017772240098565817, 0.05423466791398823, 0.028032389054715168, 0.04696594740380533, 0.006693844106848701, 0.053786013668286614, 0.005903532437514514, 0.0391851672611665, 0.04528699042566586, 0.046095860889181495, 0.03931307641323656, 0.060663718832074665, 0.025145236068055965, 0.03646429431682918, 0.07799779123160988, 0.04690546607889701, 0.05300595708831679, 0.036915364253218286, 0.036628353482228704, 0.1289681819616817, 0.02179076567699667, 0.03782076215429697, 0.07013876645942219, 0.04823466369998641, 0.04294725484214723, 0.11186178933712654, 0.03638224246969912, 0.049530449832673185, 0.01814605617255438, 0.025807521233218722, 0.03661670918518212, 0.07335627349675633, 0.0667107714980375, 0.0719330420542974, 0.014848059508949518, 0.044353761986712925, 0.05772912591055501, 0.032122574557433836, 0.0574382262857398, 0.02530836940422887, 0.04384449654025957, 0.01574649977555964, 0.06981029931921512, 0.004297823579690885, 0.03623979464464355, 0.03183453962265048, 0.03175776444550138, 0.03128307937004138, 0.03664352298073936, 0.01736476391670294, 0.032622893413645215, 0.01873101882665651, 0.023143157268350478, 0.04410197725519538, 0.03273558853834402, 0.022121453694126103, 0.07652412343304604, 0.03424703907512594, 0.020921471405017655, 0.059472397406352684, 0.03248529552365653, 0.015557427450403338, 0.08755478309467435, 0.035241947407484986, 0.04824930627364665, 0.054037987647461705, 0.051690337058971636, 0.014416605463338783, 0.05414741732238326, 0.05230636044871062, 0.06966432629269548, 0.02284973434143467, 0.031254076238838024, 0.029392953547358047, 0.04895478814432863, 0.05132136349857319, 0.07163151487475261, 0.027440706253401004, 0.02170123298128601, 0.03238702774979174, 0.02481499148416333, 0.053262595465639606, 0.054829332293593325, 0.0679997558472678, 0.023625091271242127, 0.0390971708111465, 0.02630768980452558, 0.01755207085807342, 0.008925024358177325, 0.06327316572424024, 0.057984855156973936, 0.03308524399471935, 0.08928418013965711, 0.013881339800718706, 0.04439047603227664, 0.017588571536180098, 0.03854176604363602, 0.044827927558799274, 0.02290510783495847, 0.018518209835747257, 0.026530771974648815, 0.10327485870220698, 0.03194497861841228, 0.034947170061059296, 0.014281603234849172, 0.022367106430465356, 0.03319847346574534, 0.019794496038230136, 0.07441229769028723, 0.024874396694940515, 0.03968710399931297, 0.00856030237628147, 0.0374459070735611, 0.04115157287742477, 0.007912554956419626, 0.03835121591691859, 0.0322248313750606, 0.028825958288507536, 0.05503759748535231, 0.006837709897808963, 0.014705603334732587, 0.02809703568345867, 0.017635512376728002, 0.03343990152643528, 0.03564383150660433, 0.019530746030795854, 0.04710706307378132, 0.025221478754247073, 0.051696359587367624, 0.04729070009489078, 0.01234730014402885, 0.025207285179931205, 0.011023421866411809, 0.05149690368853044, 0.02845474529749481, 0.027393930540711153, 0.04180391326372046, 0.04993678681785241, 0.014490096637018723, 0.04304319969378412, 0.050543574179755524, 0.06925424517248757, 0.022277215648500714, 0.055298024526564404, 0.020710296994366217, 0.06496731817605905, 0.0326983438571915, 0.02913951382652158, 0.04628930539183784, 0.10321319365175441, 0.01789837551768869, 0.01751109131873818, 0.019737265320145525, 0.051017891892115586, 0.057553756414563395, 0.05404334966442548, 0.04215677108732052, 0.03496234327030834, 0.04457642113266047, 0.02932787832833128, 0.07168112744693644, 0.07308248037588783, 0.13866484601749107, 0.24527015921194106, 0.133714706171304, 0.09712216502521187, 0.1278388113132678, 0.12344094066065736, 0.14174180512782186, 0.07776445258059539, 0.157206010480877, 0.14544197532813996, 0.1708155294181779, 0.1967444919864647, 0.0775632934528403, 0.19663233862956986, 0.11111164130852558, 0.12058310807333328, 0.11269020425970666, 0.1589593492099084, 0.09435329367988743, 0.15042160812299699, 0.12906442367238924, 0.1828943390864879, 0.13517157174646854, 0.23756666632834822, 0.1470870792400092, 0.11485131602967158, 0.09566990818711929, 0.0693586356646847, 0.15419878356624395, 0.10844793228898197, 0.25416996446438134, 0.09107042569667101, 0.18031951709417626, 0.18719688087003306, 0.2449710143264383, 0.20661241404013708, 0.14094763289904222, 0.1323003656580113, 0.07164966780692339, 0.2084669074974954, 0.159579087048769, 0.10110646646353416, 0.1762945979135111, 0.16429589566541836, 0.14584128046408296, 0.18679117842111737, 0.1971329320804216, 0.215988885902334, 0.093692618975183, 0.17767656594514847, 0.20645178359700367, 0.14578389760572463, 0.1392660746932961, 0.1613734071725048, 0.12168811401352286, 0.10842722636880353, 0.13622896891320124, 0.1572217291686684, 0.15078290045494214, 0.09223886299878359, 0.13861614628694952, 0.265159776317887, 0.15315714961616322, 0.0889212847687304, 0.139648889307864, 0.1253277694922872, 0.11723004776285961, 0.10950381547445431, 0.09918355441186577, 0.07584479113575071, 0.22647535835858434, 0.12465585867175832, 0.11651807581074536, 0.1337612239876762, 0.14684611873235554, 0.09511299314908683, 0.2125658336444758, 0.13466089993016794, 0.10649655145243742, 0.16534561902517453, 0.15537246043095365, 0.09117544701439328, 0.11096917121903971, 0.1991568281664513, 0.1538526310469024, 0.19850538577884436, 0.1450274116359651, 0.1695637934608385, 0.2012838827795349, 0.17356929805828258, 0.18822672951500863, 0.10143154941033572, 0.11590756286750548, 0.15571886528050527, 0.09635868060286157, 0.20600131480023265, 0.19898994883988053, 0.18052961910143495, 0.10909160439041443, 0.10925249458523467, 0.27851030055899173, 0.16360200243070722, 0.10878274479182437, 0.14668156974948943, 0.1911567136994563, 0.24798928439849988, 0.20145750080700964, 0.18197659926954657, 0.07238472055178136, 0.1577087413170375, 0.13465260271914303, 0.12320316396653652, 0.1902490819338709, 0.09525029789074324, 0.061082330939825624, 0.19643074163468555, 0.10897875341470353, 0.17973127600271255, 0.15009506314527243, 0.17211786500411108, 0.08677367266500369, 0.10995875200023875, 0.16232533031143248, 0.14286126068327576, 0.22537761804414913, 0.13713421096326783, 0.09311294226790778, 0.09667957783676684, 0.07898428360931575, 0.16504344617715105, 0.21036956633906811, 0.16507043066667393, 0.11896979034645483, 0.08464679616736248, 0.0869873963529244, 0.15238372783642262, 0.10476213006768376, 0.11214483703952283, 0.13909186294768006, 0.10283426789101213, 0.12595979729667306, 0.11112395353848115, 0.12549040373414755, 0.1389208869659342, 0.09656005495344289, 0.23738831339869648, 0.16162475774763152, 0.1544349201139994, 0.14029185636900365, 0.18066068238113075, 0.17363665538141504, 0.10153496768907644, 0.2406006699311547, 0.09688022488262504, 0.18057364330161363, 0.12278535708901472, 0.10304517883923836, 0.11187561554834247, 0.12758370547089726, 0.16974784608464688, 0.16200334212044254, 0.19741687778150663, 0.11500508160679601, 0.18217280827229843, 0.07078614187776111, 0.10248843449517153, 0.0740837118064519, 0.20366586511954665, 0.1667768953484483, 0.16855650610523298, 0.09363094650325365, 0.136200470442418, 0.14895844913553447, 0.07735371094895527, 0.09916806578985415], [0.007623415149282664, 0.0243062956360518, 0.07890288485214114, 0.038969076122157276, 0.07076450827298686, 0.030052752517804038, 0.036846073635388166, 0.008874017476045992, 0.0766296123038046, 0.016161280545929912, 0.05087184836156666, 0.012983124033780769, 0.018690527249418665, 0.036614000346162356, 0.0613204972614767, 0.09401760544278659, 0.03034214001672808, 0.03310080312076025, 0.023622883381904103, 0.005728518244723091, 0.08662674226798117, 0.03887004764692392, 0.02692529025807744, 0.03173654273268767, 0.03247142107284162, 0.07836725460947491, 0.029794948968628887, 0.05187852344533894, 0.023128438624553382, 0.021370995818870142, 0.06886463248520158, 0.029040379595244303, 0.08105248591164127, 0.04977649405191187, 0.0881157725234516, 0.068537738698069, 0.048127746194950305, 0.023386819193547126, 0.010679243459890131, 0.05200406885705888, 0.05760066385846585, 0.048060544722829945, 0.09392874810146168, 0.08760772048844956, 0.02945135500340257, 0.01868232651759172, 0.037430281154229306, 0.06966684959479608, 0.009192521283694077, 0.040478033042745665, 0.04530252357653808, 0.023319213250942994, 0.03614789449784439, 0.06315503807854839, 0.046737425291212276, 0.026520905121287797, 0.07436725674779154, 0.032580639235675335, 0.006265220890782075, 0.06681339567876421, 0.013804878180962987, 0.04360640814411454, 0.026189267155132256, 0.006096159186199657, 0.005609299178104266, 0.05250920796243008, 0.045607991560245864, 0.004016943412352703, 0.024743411340750754, 0.021370884496718645, 0.020304568570281845, 0.03682142691104673, 0.08611287921667099, 0.018563098637969233, 0.033248917243327014, 0.03861322744342033, 0.00845855300212861, 0.024031660177570302, 0.03251117050240282, 0.06492149055702612, 0.025364286520925816, 0.0429547208477743, 0.021338858969102148, 0.043258207297185436, 0.05308379724738188, 0.0505356999929063, 0.056536991833127104, 0.044351398246362805, 0.014830276722932467, 0.025407915527466685, 0.07368377584498376, 0.051409408188192174, 0.03172240853018593, 0.07655867782887071, 0.025664103050075937, 0.0061670871673413785, 0.046195297545637004, 0.03752270822587889, 0.045708693578490056, 0.016430494615633506, 0.05400348891271278, 0.009712993160064798, 0.05641154290060513, 0.022202772670425475, 0.05405721669376362, 0.051520344422897324, 0.061325573551584966, 0.06423809871193953, 0.016693344769009855, 0.036768530335393734, 0.040195638430304825, 0.05977462220471352, 0.04860469853156246, 0.038001601278665476, 0.02804747135087382, 0.02752160406089388, 0.04345045694208238, 0.0561683633713983, 0.01796872184058884, 0.09064971702173352, 0.011515299720485928, 0.0467737608414609, 0.04224576201522723, 0.039353686734102666, 0.04305593865865376, 0.03272728390584234, 0.04206732744933106, 0.00900594628546969, 0.04486597375944257, 0.039467973765567876, 0.01770367678545881, 0.061750312088406645, 0.05859409531694837, 0.06308315365458839, 0.0078048748946457636, 0.06543230338138528, 0.08922767301555723, 0.02036956029769499, 0.01973941569303861, 0.04247701523127034, 0.03260454010160174, 0.04669530469982419, 0.049036799173336476, 0.03383087234396953, 0.014722923206136329, 0.08948372880695388, 0.041257373450207524, 0.09424741889233701, 0.06754861169611104, 0.046138975958456285, 0.05961562077573035, 0.04060273240611423, 0.06714169954648241, 0.04162932302278932, 0.02580233362095896, 0.09550522561767139, 0.03167510403727647, 0.044289132056292146, 0.023259069603227545, 0.05986180971376598, 0.054849129082867876, 0.07281828322447836, 0.039373286854242906, 0.04727355277282186, 0.07245417815283872, 0.07394409898552112, 0.08734859962714836, 0.03578162235498894, 0.04733826805022545, 0.036274545709602535, 0.031237251751008444, 0.0043454601836856455, 0.013234247326181503, 0.022160943372000474, 0.013368074178288225, 0.05160027743841056, 0.03334211614856031, 0.02130388154910179, 0.03169646304741036, 0.029373121506068856, 0.06105575834226329, 0.042688939211075194, 0.061354684294201434, 0.03269064778578468, 0.029150859409128316, 0.05530763904971536, 0.06009925244143233, 0.021199055045144632, 0.012977972601220245, 0.015441234954778338, 0.059453487483551726, 0.04636801757442299, 0.0681487716792617, 0.0019848737292704755, 0.10833984590135515, 0.025433623522985727, 0.06029582509654574, 0.038063362808316015, 0.037136431492399424, 0.03969297067669686, 0.026108003839908633, 0.0748869233939331, 0.011583170053199865, 0.046149625777616166, 0.042877210944425315, 0.06931097494089045, 0.06213651460711844, 0.03737885403097607, 0.013941628167231102, 0.11118826063466258, 0.030131772691674996, 0.02459389084833674, 0.02548350141296396, 0.033635824802331626, 0.028972422987862956, 0.07264475425472483, 0.10246944293612614, 0.029126854642527178, 0.05302336416207254, 0.05125782823597547, 0.02060738523141481, 0.044102281535742804, 0.02687789485207759, 0.032392679204349406, 0.03150397591525689, 0.08317079802509397, 0.09717379623907618, 0.054229988672886975, 0.009051058659679256, 0.044748617947334424, 0.002418253880023258, 0.07513594362535514, 0.007575534564239206, 0.08160969780874439, 0.024801905565254856, 0.061217023321660236, 0.022386405980796553, 0.05439282700535841, 0.04291655219276436, 0.0369141879491508, 0.024503614149580244, 0.05224389758950565, 0.052426002075662836, 0.033824152196757495, 0.08178471107385121, 0.003326095766169601, 0.04459265561308712, 0.028420194612408523, 0.05632997716020327, 0.03409682467463426, 0.019981971818197053, 0.028298712459218223, 0.03375090964254923, 0.01199147187435301, 0.08370942654437385, 0.017094861505029257, 0.01062654540874064, 0.039673559804214165, 0.04844130729907192, 0.06791521780542098, 0.03012104865774745, 0.09330218250397593, 0.03250507746997755, 0.06590115517610684, 0.01038947468259721, 0.04590320306306239, 0.016639405475871172, 0.04448815008800011, 0.07648506420082413, 0.02670006884727627, 0.03201695581083186, 0.035205337262596004, 0.049838804770843126, 0.0569281964271795, 0.012808247138309525, 0.06060596489987802, 0.0644239250686951, 0.018900280447269324, 0.012375355181575287, 0.02809302808600478, 0.0437280090409331, 0.06997466276516207, 0.08921710483264178, 0.04212609441310633, 0.04986615291272756, 0.004031912994832965, 0.06090671653510071, 0.017997045906668063, 0.03326659520098474, 0.03938051908335183, 0.031905737560009584, 0.012334719813225092, 0.015359655299107544, 0.0313219159579603, 0.057403927930863574, 0.07276445525349118, 0.03909810591721907, 0.049908804139704444, 0.054376028492697515, 0.03455155710980762, 0.07244059685035609, 0.04321649488701951, 0.01690541161224246, 0.02483015170582803, 0.0905080336087849, 0.062272171780932695, 0.06013693870045245, 0.04989999484678265, 0.024844699655659497, 0.0402338664571289, 0.03679416040540673, 0.05212713920627721, 0.06023005596944131, 0.025918205137713812, 0.01915456621645717, 0.07708237433689646, 0.03437800958636217, 0.014837479266134324, 0.037638850626535714, 0.03671505117381457, 0.05666047778504435, 0.02935818578407634, 0.05566995925619267, 0.03751342024770565, 0.01279187072213972, 0.027245549244980793, 0.06404096202459186, 0.02462284202920273, 0.0781285873381421, 0.022600419106311165, 0.022358094902301673, 0.06569247809238732, 0.07200193562312052, 0.07436995074385777, 0.01662423226662213, 0.04294067941373214, 0.031105296038731467, 0.1033612595347222, 0.03921753974282183, 0.029415247663564514, 0.003526653058543161, 0.05530002461455297, 0.012481186367949704, 0.019436897746345494, 0.011162209975736914, 0.07601023811730556, 0.020984910188417416, 0.025138881428574678, 0.013308249654073734, 0.08084197572316043, 0.04106151325686369, 0.0333993505773833, 0.1119906261737924, 0.11803921137470752, 0.09370319457957521, 0.1769642229191959, 0.15193895873380825, 0.1569693099008873, 0.12846506520872936, 0.17571652424521744, 0.14641000307165086, 0.09718859466374852, 0.1480159512721002, 0.10737132091890089, 0.19296758371638134, 0.1185853430069983, 0.1334577746456489, 0.19078072684351355, 0.1710504191578366, 0.13051910733338445, 0.18157845188397914, 0.08542559851775877, 0.1357323830598034, 0.17404543032171205, 0.09701971895992756, 0.1215182215673849, 0.13250251184217632, 0.24365291552385315, 0.11178168191690929, 0.14366321061970666, 0.15023952961200848, 0.15873339492827654, 0.2518926694756374, 0.08408651920035481, 0.17383645637892187, 0.15627851884346455, 0.11068255378631875, 0.20320079085649922, 0.11454036357463337, 0.13933490146882832, 0.09156364962109365, 0.18989630945725366, 0.1978154556127265, 0.19119724980555475, 0.1704949958366342, 0.11499714804813266, 0.10819642586284317, 0.1242427050601691, 0.05093168030725792, 0.13280100363772362, 0.20647354336688295, 0.22875254944665357, 0.18273311492521316, 0.1347094215452671, 0.14554446592228487, 0.08102441046503372, 0.12717191741103306, 0.14350980869494379, 0.18950460391351953, 0.14411347161512822, 0.11760188601328991, 0.08893709251424298, 0.13750553713180125, 0.1216494629625231, 0.11312178539810702, 0.07506659734644927, 0.08376157726161182, 0.16549156978726387, 0.12346715331659652, 0.13578834099462256, 0.20841745077632368, 0.11070575332269073, 0.1447410910623148, 0.1295243771164678, 0.1537489827023819, 0.12587118486408144, 0.10922146539087407, 0.1833318202989176, 0.09086859121453017, 0.17014885816024616, 0.27607525466009974, 0.2588618517620489, 0.12233764166012406, 0.1176691245927941, 0.14123882196145132, 0.08386911445995793, 0.16731529380194843, 0.19596871017711237, 0.09318051481386647, 0.24833806412061676, 0.09643508470617235, 0.1440761415869929, 0.20687641081167385, 0.2570206130621955, 0.1797494140919298, 0.15663978148950264, 0.11771581310313195, 0.09868954381090589, 0.15357719035819173, 0.11666716585750692, 0.1470914579113014, 0.10877498192712665, 0.13361459044972435, 0.08245906356023625, 0.15815017075510696, 0.14837776310741901, 0.13690668332856148, 0.21594744437607005, 0.23746180086163804, 0.1491984151653014, 0.1317540559102781, 0.2367928289459087, 0.0981511156714987, 0.26515746081713587, 0.14606561686377972, 0.20841774763539433, 0.18940166803076863, 0.08355087411473505, 0.1578691491158679, 0.1546664850320667, 0.15381917502963915, 0.17573117424035445, 0.10604442766634747, 0.13130311213899404, 0.23002142901532352, 0.06749246822437271, 0.1516082280431874, 0.17772643826901913, 0.182761657924857, 0.09495426260400563, 0.1653773384168744, 0.09836276134592481, 0.10122231571585871, 0.2595209679566324, 0.12439892714610323, 0.15186012780759484, 0.12256913978490047, 0.19951305905124173, 0.213457613135688, 0.07483724402845837, 0.10631019074935466, 0.08365199915715493, 0.14394942729268223, 0.07528030619141646, 0.1408902500406839, 0.2854301151819527, 0.3037477150792256, 0.25019861350301653, 0.25602432433515787, 0.19653216353617609, 0.20385410345625132, 0.09752098776516505, 0.19904718326870352, 0.09684601187473163, 0.17902757157571614, 0.14757533819647506, 0.1286906038876623, 0.1757271369569935, 0.16563993995077908, 0.12024513402138837, 0.12359213098534383, 0.11973517466685735, 0.1261335489107296, 0.22924116463400424, 0.23297937732422724, 0.12986254412680864, 0.14878722082357854, 0.15397195355035365, 0.17276326630963013, 0.18077190063195303, 0.1423634577076882, 0.17223954753717408, 0.07263509149197489, 0.12920819252030924, 0.09086404927074909, 0.2064183572656475, 0.15011241455795243, 0.14095389662543312], [0.05090761616884265, 0.041359956812812015, 0.04162579782132525, 0.015934374459902756, 0.04587673436617479, 0.02284492707985919, 0.03205224122211803, 0.01661952705035219, 0.0872415819321759, 0.021693984053854365, 0.012855341046815738, 0.0459251557913376, 0.07562155311461538, 0.021796912515128497, 0.034815898980014026, 0.02593858265754534, 0.018417231367493514, 0.022182118700584397, 0.06601309331017546, 0.06270146710448898, 0.015174777963693487, 0.08120119746308774, 0.020579679003276397, 0.026624260317476, 0.07931920001283288, 0.057394187242607586, 0.026878097087319475, 0.06924876812263392, 0.08584647046518512, 0.09443697825190611, 0.010124603104486596, 0.05673632156685926, 0.01723055393085815, 0.06261310700210743, 0.022028056264389306, 0.02537553562433459, 0.05415431929577608, 0.06681960003334098, 0.028367756312945858, 0.017967005624086596, 0.06303247238975018, 0.024865162522473838, 0.05754338861152064, 0.0234649061167147, 0.017717922310112044, 0.04697058211604599, 0.011885880958288908, 0.023474439003621228, 0.02784008003800409, 0.04919637576676905, 0.016993584322335664, 0.1084938712301664, 0.04390953836264089, 0.04740106487588491, 0.052463283864199184, 0.0905825303925667, 0.030928696432965808, 0.05117801767482888, 0.04419212222273927, 0.012596023516380228, 0.05830571899423376, 0.005821249133077799, 0.016399313280999195, 0.014174291463859845, 0.04804322299605701, 0.04093862102308776, 0.049221983572351746, 0.06571735488250852, 0.03500513921608217, 0.06205133089679293, 0.03181929590937216, 0.07448500589816831, 0.08702165388967842, 0.037742821805295534, 0.03777963975153398, 0.11250264127738774, 0.034942899001180194, 0.0888517455314286, 0.07257559351273812, 0.03151369804982096, 0.02759483177214861, 0.05027949948271271, 0.022806903143646196, 0.02808941382681951, 0.06336542952340096, 0.025872158585116267, 0.012252005599293625, 0.013664637317560846, 0.00792431057561771, 0.056065568496705964, 0.06316103463177569, 0.09767630443093367, 0.04636516772734467, 0.10905437826295383, 0.12199712204164825, 0.06527495323098265, 0.015558436771243578, 0.11817085352959111, 0.026847659755731, 0.040676160497241654, 0.029751381189271342, 0.00798280294475262, 0.012875848442490678, 0.07554947573225945, 0.02342411025892943, 0.09611895206035115, 0.04176268324954435, 0.019861422915710136, 0.025816495653998572, 0.06625046924455091, 0.019328553462401032, 0.0453389259200776, 0.043396651235525496, 0.021090725604153704, 0.016693149955244735, 0.06669163893093355, 0.026017281852546148, 0.04458585011889227, 0.06260792681132443, 0.03334420900500845, 0.02825692768965382, 0.024759380503383, 0.028048541898897383, 0.032734723936300725, 0.008264184525614837, 0.06932027405127883, 0.025939311817637645, 0.03972716142015997, 0.018077806416840758, 0.013994971886859275, 0.05557870848861057, 0.09939666953869164, 0.04653150157537311, 0.013679565618076595, 0.020793938892893493, 0.018613453357829712, 0.07444763876264915, 0.04283329064492136, 0.08253450287156738, 0.08561219670809805, 0.02624526034196606, 0.038482550080516376, 0.12309783094679005, 0.04233045219734777, 0.008871613845258253, 0.013170225956855575, 0.029462309103109874, 0.04184987075859681, 0.05666738346917555, 0.03128680866211653, 0.013634982951771235, 0.018241897123516537, 0.05335557914804667, 0.017776739368855488, 0.017196062617585994, 0.10544257558649406, 0.03909583865606692, 0.049929999877349474, 0.0639591996150557, 0.04474411682167556, 0.06952383773750626, 0.1613318914314732, 0.009948140796041116, 0.026325675753469113, 0.0802057993132621, 0.04425346814969089, 0.013772835955023766, 0.03361425428010989, 0.062436067673843354, 0.05651834166201297, 0.02426950552035123, 0.05916497757425532, 0.045972831358085386, 0.025675257529655937, 0.11439678026363254, 0.008615007009211695, 0.008486364986310946, 0.023706026186118834, 0.03550880886905361, 0.08217936294386163, 0.06062909393222071, 0.013433879485091893, 0.04327152142650448, 0.0483795197942527, 0.023130138142732903, 0.07718214124906808, 0.08342563669430092, 0.023939615311974194, 0.05938828609941993, 0.012650098251469899, 0.010846812983800191, 0.10957175167277455, 0.023492718100897036, 0.05097633162222337, 0.030930390385037754, 0.040230040685855784, 0.03532633701979648, 0.033908419354702346, 0.015017485329735791, 0.015481172704312485, 0.046250175655586645, 0.051365743929636665, 0.010865633848879952, 0.040389992063865066, 0.06512498744996265, 0.035160296320100315, 0.016900507871469017, 0.03189605995430611, 0.025300549023086205, 0.07704587551415898, 0.0438222246884834, 0.032484186012879945, 0.1127517654094845, 0.047022988874232396, 0.035772916962741874, 0.02247878295747796, 0.11049309090594761, 0.055393516668118536, 0.07700591086177155, 0.030203486421669368, 0.037545451341429725, 0.06587789626792073, 0.026956328729283996, 0.046135554657666944, 0.027725934014597442, 0.05597430659690872, 0.1078422878345009, 0.044721099111484364, 0.02838640833942918, 0.11661487413221039, 0.023608417068317067, 0.04981161990144756, 0.04002298148407135, 0.016793048598628957, 0.005002701063858694, 0.01708487961877836, 0.03314679030154366, 0.04117008204048034, 0.057299693289678544, 0.003325342022435507, 0.022757121732865926, 0.03658838882984128, 0.04130224740947597, 0.1276858992059715, 0.058845215826295316, 0.06984259758610278, 0.055193481894093566, 0.010713790434238035, 0.04357705620350316, 0.07720908120973036, 0.04933151343720965, 0.02856375380360987, 0.017747172205417883, 0.09316453637438826, 0.07204212291981094, 0.030501035689667333, 0.024359988165087998, 0.03240571131755132, 0.02775519504211843, 0.10153825540328398, 0.022171890050231013, 0.03589378684409894, 0.02187996626162203, 0.07891245113569312, 0.02238501445390284, 0.06423507074941881, 0.017752222520357464, 0.1032558671431616, 0.04724070902739186, 0.020313095847086515, 0.020126163690292742, 0.04387175933516119, 0.031038875677040778, 0.03900422794686165, 0.001778502289653261, 0.016704052104614675, 0.05426332223578356, 0.09427444048924372, 0.039900159754324704, 0.0347233939828584, 0.003759013466151373, 0.041220295752282254, 0.031403823086293414, 0.06348090770188719, 0.035053055980824865, 0.046791026907158084, 0.015360848301497754, 0.042711938367574476, 0.0433989073644625, 0.05500590777955949, 0.027590974459599238, 0.00767408481806342, 0.024439062144665513, 0.029173491202527657, 0.02933539257355733, 0.022172775061335415, 0.06792294356273487, 0.024214619988924824, 0.04952875402523205, 0.024025995735428296, 0.05427053962193895, 0.07085262346663512, 0.030292933770397212, 0.015008353202574654, 0.05206699555856176, 0.03758711180125829, 0.014757043445570162, 0.029152096940379124, 0.03565721242921427, 0.01540279356049723, 0.03543736231222283, 0.005039153038524091, 0.03760925006645266, 0.019126444385619834, 0.032871616785996594, 0.08080777755822055, 0.04163830672041513, 0.04504358825215604, 0.056389898163615726, 0.07176991057349369, 0.014700831325171748, 0.02393611051957123, 0.01398901522406959, 0.03434603786445223, 0.042008107775473036, 0.036945372994523495, 0.015246722687152214, 0.03368351150129456, 0.06182548793731257, 0.03157515900966246, 0.032776781445136294, 0.04091102797247004, 0.01882772437966196, 0.04680796271713916, 0.016253479407168925, 0.09891901587252505, 0.018124129419447854, 0.05114795327244792, 0.07939242772408761, 0.03356072316819336, 0.07221741077955812, 0.06025330745615065, 0.029299231428012718, 0.011584800922719296, 0.0536086292413529, 0.033653335776762106, 0.012767207299475558, 0.01963791215530364, 0.029855747561668977, 0.024436370003968477, 0.039111820806283504, 0.07079562652506866, 0.16355054191080853, 0.09501704829744995, 0.13576539378846064, 0.144560229673516, 0.07683732459554449, 0.1587359033874236, 0.13511340221157297, 0.1079810546070803, 0.16318264446454123, 0.27686133747920394, 0.157233276986517, 0.07335646645515226, 0.13467194308759645, 0.12345498209469952, 0.13265919405966997, 0.251154737197794, 0.10029510609456338, 0.12977167556528002, 0.10783817633637227, 0.15555939258774742, 0.10298847875674255, 0.26900413096882403, 0.07033651912934147, 0.1917320562642999, 0.14155463548377156, 0.15113303088583052, 0.10679864266421646, 0.1954119955189526, 0.22301176999462768, 0.1758828543825075, 0.09230101044522598, 0.12335687759332359, 0.20635790191590786, 0.16237714706221595, 0.1484675778192468, 0.08032538898987696, 0.15583446220261976, 0.22920791641809046, 0.1181688645738177, 0.17224529176019132, 0.27249457023572177, 0.16690199176082388, 0.13736939756199718, 0.11177935899468139, 0.09400492956046946, 0.10752543530543335, 0.13335477939108387, 0.1537018414819613, 0.14381975925061852, 0.17579468723852187, 0.12334519618889317, 0.12342042769887485, 0.14078590407734737, 0.2035765105392784, 0.1480757090030238, 0.166597829957027, 0.12935052160173655, 0.12822294695070013, 0.11487858253531158, 0.12517721741460264, 0.22079313435824588, 0.09187350369757041, 0.1861366635421291, 0.08635762467747554, 0.11921849887585267, 0.11339255797793157, 0.06776041322154924, 0.22527095658006147, 0.11318624092382379, 0.19884411682141945, 0.16231517773121595, 0.21793883439386263, 0.21132255817065015, 0.1581015600822866, 0.10308587821782567, 0.13729147205594927, 0.10447845153976232, 0.2517622889718041, 0.26259440928697586, 0.1435003982624039, 0.09782635926967487, 0.07454058533767238, 0.14411259588086978, 0.1341142487945035, 0.2150867015006952, 0.16423598950495943, 0.22369445679942146, 0.15738926158519462, 0.10779506497783586, 0.1636558526661247, 0.13606266846181825, 0.24355700035812333, 0.1515192148508504, 0.13456266926368698, 0.11610302972258069, 0.16312560299411416, 0.18736938567599282, 0.2171914916834794, 0.10317560387193225, 0.07204785229987465, 0.19598199462052435, 0.1511796229169704, 0.10757268042652868, 0.21777510177344084, 0.10677018130081706, 0.2149865115643479, 0.12272938431124203, 0.12659984029596671, 0.17575707519426942, 0.15516874089371413, 0.1399873531772755, 0.10697605306631885, 0.08857755165081471, 0.11338138865539804, 0.08389940892811865, 0.19199857633793727, 0.08979933452792466, 0.11564118380192667, 0.3665872587589547, 0.1414678487344645, 0.1507989308447577, 0.12976655474631116, 0.20253443130059168, 0.13441890041576698, 0.09225147950928658, 0.1085041425540112, 0.119916867261054, 0.15477074193768203, 0.11584194959141314, 0.18369251891272143, 0.1416408730437979, 0.1750647701555863, 0.077031351684127, 0.0692607686505653, 0.08324076028657146, 0.14938322477973998, 0.18125395523384213, 0.08362900742213242, 0.11440164133091457, 0.17574573517777026, 0.10359205261920579, 0.14161946950480342, 0.23195266054244712, 0.13498367479769513, 0.15035226184409112, 0.0786228576907888, 0.13079632917651907, 0.1142346729466226, 0.14898083230946213, 0.14447997382376343, 0.08201707008993253, 0.11950984378927387, 0.16793390357634053, 0.1669819062226452, 0.15440795046743006, 0.2230778508237563, 0.11116701294668019, 0.09886709522106685, 0.15122982178581879, 0.23752256791340187, 0.11079392788815312, 0.15369804168585688, 0.21515667118364945, 0.11166795520693995, 0.17934828327270225, 0.16372772224713117, 0.1312217430677265, 0.1048200175864622, 0.1979791882331483, 0.2458599884994328, 0.11617826865403913, 0.13773429673165083, 0.19273411890026182, 0.066735447908286, 0.2099575407919474, 0.1267540140543133], [0.018225876010546926, 0.03238633384171408, 0.05132669954036828, 0.047805724607314914, 0.05901267402805388, 0.048624016635585576, 0.0618034164654091, 0.05225611705100164, 0.047877701799734496, 0.028709480066027027, 0.013840452102158451, 0.018642894356162287, 0.09802628643228672, 0.02271506793476874, 0.06522290641441941, 0.014576003941328963, 0.05989801909890957, 0.036809407829423435, 0.08576204374548979, 0.01995026170334313, 0.05235098578850739, 0.08428749279119074, 0.07657125723198988, 0.052158546895952895, 0.06517919391626492, 0.08175507711712271, 0.04748732841107994, 0.022205334935279097, 0.028224468005646486, 0.010370793897891417, 0.014871096700517228, 0.03584048208722379, 0.049749888057704084, 0.05651804480294231, 0.027460569835966453, 0.035810536428471096, 0.06914888246683404, 0.0398179631883977, 0.040697690201341175, 0.05853130962350406, 0.013248977102193749, 0.04734966372780036, 0.05203843400522601, 0.03561736652045511, 0.023986680462257937, 0.05322400378645398, 0.053031553761684336, 0.047509444411844015, 0.04004755028290674, 0.02302106840943452, 0.03896064903528895, 0.01752283023961354, 0.01578453855472617, 0.061327384391915984, 0.025576462830940727, 0.027623745845630765, 0.055348483147099614, 0.016644145944155753, 0.05324108060449362, 0.008847660101309884, 0.04830560188565869, 0.055499309819424525, 0.0389602408540668, 0.01761346502462402, 0.0804526153660845, 0.02113121718139155, 0.009345404632767895, 0.024636067100800574, 0.012753047121805139, 0.026730177778517827, 0.017677376927167643, 0.0629611148906406, 0.045847812871215865, 0.038709791988367215, 0.1072359606041573, 0.02689494940568693, 0.09382400879985653, 0.006945505456315004, 0.010329165907023707, 0.08149915491230786, 0.05625566220260225, 0.08709443631232716, 0.025799953182286117, 0.06287160445936024, 0.01183423119073268, 0.028803304230677895, 0.03403514107048977, 0.02336677749553928, 0.013093567667965544, 0.04968569970515091, 0.009377104543091264, 0.012580673119373387, 0.051722260541282594, 0.04425415463629179, 0.017666715975792613, 0.048102650471264496, 0.012764915918523911, 0.04098224817425944, 0.05048272178100888, 0.03743483423022553, 0.03266602332587354, 0.044613034988287836, 0.06927153721335344, 0.005204548069741577, 0.05064957513241097, 0.015922270031296648, 0.03531001348164864, 0.06118896271800622, 0.037323029682738706, 0.04804674819752108, 0.015241353248711675, 0.016599795198999345, 0.01804340601665899, 0.018001120297412854, 0.015509521817875793, 0.026878351272898726, 0.019968373817391694, 0.02143747184163658, 0.05293017267831601, 0.05433635327790398, 0.04829845500353258, 0.04688550972787198, 0.04012870784208644, 0.026388428050267976, 0.018293498651473783, 0.04725896957097575, 0.05128835648065433, 0.06951309143914841, 0.03722349283634685, 0.04270713296136819, 0.07295845265616663, 0.03618067144998349, 0.05305368089466356, 0.01926345968968235, 0.03443047571636271, 0.015737770263513085, 0.05418336695584003, 0.05799527119961567, 0.04009206058981363, 0.07281504003913142, 0.024044519741437398, 0.024830272304825485, 0.022704952461936045, 0.04376310891530011, 0.022225666070880834, 0.040066879519145004, 0.03678053086332511, 0.04632351468899287, 0.037365005555329844, 0.011511270786286332, 0.019015235411643516, 0.052997849124949425, 0.07587277752463706, 0.0573619372153189, 0.046521942713297904, 0.005090488784844638, 0.08228729348047636, 0.02646088949404657, 0.01883425713458564, 0.01105616356653627, 0.04782539894222282, 0.028561028266267385, 0.01104268523704377, 0.1136046860483475, 0.018341146387683693, 0.04059228296682704, 0.0048908682219916955, 0.02651373597473139, 0.03854524671623949, 0.025324036141682882, 0.05380970673286356, 0.018450423922331538, 0.07549702073447406, 0.02963315706438152, 0.026579785262583755, 0.04899903869954869, 0.013167122851882596, 0.048844935445231386, 0.02967203447042266, 0.03247880173148587, 0.04651910399843473, 0.05439109409053344, 0.020135290251346305, 0.010059898031613557, 0.019886706031684298, 0.006563202923643985, 0.12869291938841343, 0.04448929670616053, 0.015242827339534415, 0.09958362395991571, 0.052647024785983376, 0.031147982517722994, 0.04587373237882275, 0.10212363180471584, 0.06459079697378911, 0.07596722323796712, 0.031049876160977874, 0.030228613686631434, 0.07904007827164605, 0.07414033025270328, 0.09946275036782026, 0.03944267395127099, 0.0415599878760986, 0.016595123379374854, 0.059279238630551845, 0.05326602047716733, 0.048371285665780306, 0.05720300629036501, 0.02869805470254505, 0.07119563670130447, 0.04352444164396729, 0.023331197080551647, 0.03274569287896156, 0.014407012276933528, 0.027391720796003938, 0.028893230264657177, 0.02055554807157023, 0.06916131344041787, 0.05695517349522561, 0.01859679770859657, 0.0529189105873229, 0.03459798215772025, 0.08164727274561301, 0.03336114852572791, 0.014889935191604309, 0.06482863303972408, 0.02165659094316652, 0.037507972883759066, 0.07216396872536279, 0.040726645092945546, 0.018729892617557198, 0.02036819474596996, 0.05756983875471633, 0.03455725309322588, 0.012687119360634824, 0.007157082018238725, 0.06457782423240133, 0.037232506219879724, 0.05387250355852302, 0.002638407117956376, 0.07022985024377704, 0.022272785026871134, 0.026863992570724804, 0.023208826205518562, 0.055662608283455484, 0.004022938110210816, 0.01728700353851309, 0.021082936764287297, 0.032224556780420244, 0.03968137832998764, 0.06056120226276107, 0.04634517797967419, 0.035117619117954746, 0.053513007223955356, 0.05946343226241879, 0.028727508688461967, 0.004445267913979478, 0.013903498474974185, 0.032946588544291444, 0.04792996754986234, 0.0680718629155308, 0.03971948019170668, 0.006986429798416793, 0.025828217876551207, 0.052941538669983856, 0.03569262029486708, 0.022773929522372782, 0.04061784995428752, 0.07196923659648746, 0.06382506384397857, 0.03806508830166422, 0.011774847316701198, 0.05218911224801559, 0.03985187933722045, 0.03099229848885443, 0.04153620946453884, 0.013563234897446819, 0.004920464607494068, 0.017978894829866476, 0.017081133628380485, 0.007118429111869773, 0.04678956487623509, 0.04835233121411875, 0.005370828112063464, 0.03013802157511236, 0.029384736117208377, 0.024190652329707518, 0.016442921878478955, 0.03961564631026704, 0.13282613275805488, 0.04954102172632702, 0.02037261423538439, 0.03404593931918498, 0.03338786955282558, 0.04832266757148318, 0.02398550044745207, 0.07600349199492484, 0.048627467622281983, 0.08158352968166582, 0.07163140355260111, 0.053290663490770385, 0.03321923504699953, 0.018158798848162405, 0.06313953461358324, 0.052358236571308225, 0.040356550889555365, 0.0521956839656923, 0.011902359419764252, 0.018614831897139084, 0.05010881293856073, 0.03803863815846853, 0.06708453191095032, 0.042429450986674055, 0.012379809923004359, 0.09115834793192334, 0.046727933222427964, 0.02057703139143996, 0.038828131146146916, 0.00836727440400864, 0.028859865160484333, 0.0491623037669342, 0.03880722484609578, 0.04126860214455519, 0.017988980616792105, 0.04384953201224562, 0.08274310574051924, 0.05194634090003092, 0.020002666606160346, 0.0912618255824782, 0.03216213473933749, 0.04870823184319306, 0.026234063188894652, 0.06970888483920135, 0.03620152208895888, 0.0490694388281554, 0.0646149464591872, 0.020449988696782384, 0.02431223838357255, 0.020460809209907893, 0.0819610824692063, 0.06082682804844808, 0.02368137389566982, 0.047834564466029406, 0.02119134227541508, 0.00679749477058067, 0.023069538074196316, 0.05328525694494601, 0.04020007276267279, 0.009838063597271685, 0.015704273428127635, 0.02421438621240668, 0.008733815575396875, 0.09176909094094299, 0.12144466731115244, 0.1715536101255566, 0.14222304336726665, 0.16904932184843346, 0.1746282388921827, 0.1806649868376553, 0.08894695565686561, 0.18034182605333626, 0.14955899503547698, 0.3722686070250347, 0.12129450115025975, 0.10817705580848269, 0.15232497942633927, 0.2946997177787125, 0.18482714396668598, 0.1253755489597097, 0.1922825665678829, 0.17847355833509937, 0.10310973084415309, 0.07895905800978653, 0.2784233505371958, 0.23897051287349313, 0.17480915965279564, 0.23133366485126317, 0.3016234509414062, 0.09029413922689855, 0.15593018440995365, 0.10578598215943202, 0.1335470550111495, 0.18517118878662586, 0.16062303649960086, 0.15391111228382215, 0.2048811616259627, 0.14670942997327074, 0.10148751476663165, 0.128411719633732, 0.09922235389240086, 0.10585126889054663, 0.19980625191237777, 0.09526549707516097, 0.16069625678937882, 0.19164754048688337, 0.12006526711047627, 0.09118503556237556, 0.25953159551136196, 0.1576898610801436, 0.11106616249890067, 0.18562237004516646, 0.1274139911402017, 0.09418254776392132, 0.18537986587034538, 0.12165266904048622, 0.17109390901168808, 0.11656098678940907, 0.11456950771389529, 0.1563842303585261, 0.09017572956508957, 0.1394696903298609, 0.11221574182854965, 0.12516752496594563, 0.22486344329081476, 0.1115486104390584, 0.08570408943342045, 0.21763216413091868, 0.10631679586367682, 0.11064788064686581, 0.12980688305106014, 0.10829504244611599, 0.11836290650535375, 0.10490242566447705, 0.2589010074734688, 0.17450913903303444, 0.15463276184163988, 0.24256143893580884, 0.14205289859091863, 0.16170755174243823, 0.14130318100797012, 0.12166417975095101, 0.16368967975722626, 0.12016801745630801, 0.1690469915047288, 0.09778676569112577, 0.15498689986998215, 0.12369172720354982, 0.1272615243215114, 0.07279195182491094, 0.10003813746152446, 0.13746442215051502, 0.14225725637516007, 0.10722201564931311, 0.08689109527040273, 0.12261030671652406, 0.2032677474198863, 0.2758043707581237, 0.1917675309232436, 0.16248636151431128, 0.09358053241157904, 0.11424608717788942, 0.1334182033315301, 0.1482762224623002, 0.28584087907802314, 0.1543686314835213, 0.13127525191521272, 0.09220053849276155, 0.15420017880387604, 0.14554394641891122, 0.14494819479295984, 0.17118406511144713, 0.07762198991258629, 0.14991078787716106, 0.15464615018572658, 0.14684412977658212, 0.2536498080007732, 0.09200721644447185, 0.10575917578535154, 0.0959457793214824, 0.12277620640816167, 0.12659801461268216, 0.09404396652826108, 0.21513120067538694, 0.1364131402806379, 0.17678465286735445, 0.17974542133742943, 0.080359550047433, 0.12494795315433294, 0.11816767713753507, 0.11688028840580955, 0.12860999180702493, 0.13435728731565177, 0.21897879109019414, 0.07372725827735849, 0.12304467090871185, 0.08077035847236402, 0.10365687179728411, 0.12579535221448168, 0.14160461170831695, 0.128190886171069, 0.24750671029323712, 0.15278517035767436, 0.10882008966291323, 0.1566836127312854, 0.09777106926776469, 0.1554772665258497, 0.16930105834035203, 0.09207278519170359, 0.16356099135009572, 0.15746617777040228, 0.2096274186624214, 0.17156499467091635, 0.09572480485076085, 0.19325142551679164, 0.31571104656904936, 0.13993690197821707, 0.14544675475917757, 0.08671539922943339, 0.09314103255746886, 0.1641370909055695, 0.11166486045112833, 0.20978329936042428, 0.12812312808819115, 0.13056549156317487, 0.09672596206655726, 0.20223528641508892, 0.15485105715924874, 0.12158982397522777, 0.08031177058001049, 0.083904641069239, 0.22270753397606313, 0.1734955285792239, 0.11666029357002117, 0.16689927550032735, 0.1658582204254344, 0.09809736933675595, 0.0856277669663541, 0.13809561874950305], [0.07403506402624771, 0.0182231152211898, 0.011329685803502798, 0.025168110914819408, 0.05462554967380129, 0.029114408825989813, 0.05096679502457846, 0.013282742966111982, 0.03423040754569229, 0.0219839708370273, 0.031151233124546707, 0.03519049430906307, 0.021637274694512598, 0.06598432024475187, 0.03590243657527026, 0.013325862673809752, 0.022342927259160206, 0.01627741366974078, 0.00827787900561816, 0.09980341099435464, 0.025735879862622824, 0.02216847802628763, 0.020288063205953222, 0.04371268740214873, 0.03478942657238804, 0.011675061850837665, 0.016074799932539463, 0.025246689510822762, 0.07064493343932554, 0.04483606149733532, 0.037435409394674934, 0.03761160267458763, 0.0489057284721639, 0.07903897989308462, 0.04131070789298974, 0.07567498032585718, 0.08877982400008477, 0.032750101236160845, 0.027825040415336844, 0.022627719008596614, 0.05893969122553244, 0.005478532757479115, 0.05322049342794344, 0.10051924953586422, 0.028226150825503282, 0.02970169069158146, 0.08968594920588657, 0.06388583831721917, 0.052077745567657985, 0.003151407190671307, 0.026897884599748068, 0.043254225674900226, 0.03798615718551446, 0.026284724044671748, 0.009108392350754002, 0.020655142434407026, 0.02086485481413547, 0.051781394868157804, 0.06550819540279917, 0.10721833459683694, 0.052726493959198706, 0.025833320141828153, 0.025878088345052674, 0.05161596644029487, 0.02805478150548879, 0.013139128113834886, 0.026770847471198067, 0.07046273618470877, 0.029971709991514217, 0.09632831191993318, 0.025515170709695667, 0.09164130795397796, 0.06108356661570724, 0.01766087156283902, 0.024256658944068477, 0.08344501417013817, 0.09643734083510935, 0.026530608702159952, 0.09680997318355367, 0.05005635423003696, 0.05930230086960364, 0.07440038622007705, 0.05046761536505073, 0.1131983898812905, 0.05726420749851968, 0.07982363036717288, 0.018463797423464712, 0.06681662402115762, 0.06211329651705455, 0.08466610684990883, 0.04226382588967681, 0.0347609726304654, 0.05283841353957541, 0.07026511710137129, 0.04979990881111007, 0.04712033267423976, 0.08654417091747746, 0.023536747867183294, 0.06406482207239605, 0.00910680601009517, 0.0352549572562566, 0.015037750599731226, 0.040461690950905904, 0.06906310503836721, 0.031499348624492995, 0.03136541694402695, 0.030817537553957663, 0.010090012528962689, 0.05162605593795888, 0.05434810518636368, 0.010467659940331941, 0.036281878128647804, 0.015719400253146887, 0.06662129075266421, 0.03237930199247785, 0.021270377292239573, 0.008232513373513939, 0.023915630954434164, 0.024707114753255155, 0.05846259788086172, 0.0705236368230544, 0.07507863498176448, 0.07027495797956362, 0.07262672748765908, 0.056262630969285965, 0.06931435913429596, 0.02481585423083743, 0.01998296815145295, 0.07224436558317393, 0.03139963737339713, 0.03341634204844013, 0.07738071028143167, 0.04658342964830808, 0.08031625315197743, 0.03782190506171901, 0.01582358108862536, 0.03557420692231972, 0.039332798987743445, 0.033057524778996594, 0.05100611029774882, 0.0504844435636187, 0.052136237936792895, 0.07004360828432254, 0.040841344016371295, 0.054235154020716436, 0.05538299672480207, 0.026806600435520522, 0.03313145753054414, 0.06692583847325295, 0.08169189066393301, 0.05913205961405765, 0.014543857814715011, 0.04174793677520938, 0.031100631640583742, 0.0734947805176489, 0.07998857268830761, 0.043518868114915676, 0.030968764986027963, 0.04311126576794777, 0.0052582271473511355, 0.0332208789041033, 0.04243224517267663, 0.045321522557060234, 0.07267285938723944, 0.02451775948429713, 0.034433492546668276, 0.02972283818962751, 0.04877527375356294, 0.022979016466706526, 0.06181288255902473, 0.05550788533582818, 0.023362226274912246, 0.04962252809491474, 0.06456786461058073, 0.00490280520352826, 0.08001592083019204, 0.05001169549359474, 0.008149070927174762, 0.04542759772448335, 0.025178595606121235, 0.0017808736834012961, 0.024298564312630333, 0.029095578684064094, 0.03458182189206127, 0.012716551082121441, 0.035678586282301694, 0.009432445567654213, 0.02330797342438018, 0.026570766312943306, 0.058217032346874475, 0.010767604489956284, 0.022704104558215477, 0.0394118414260447, 0.04077821322425734, 0.009716758631839184, 0.0825871508277487, 0.03560401528375223, 0.1100211740413215, 0.01130707998527214, 0.04532786420895718, 0.031008610894787125, 0.030113120665191673, 0.059590243035927415, 0.05034509791585151, 0.03889818617608398, 0.01499263358709868, 0.0243156133001321, 0.015507726748182904, 0.03324705074192025, 0.030029547415324487, 0.02745484045590274, 0.05773746393970214, 0.014122994216450024, 0.010485430666449247, 0.0314130108745303, 0.02321620129805524, 0.03334840956085827, 0.026124368196178693, 0.0325534914736636, 0.045677660673391074, 0.09536962781567127, 0.0614743593177991, 0.04350955045083538, 0.03133481448458042, 0.032516684659640305, 0.035181365892640315, 0.05066607307526283, 0.09978234142181464, 0.08229029917856678, 0.014980863124947064, 0.04191519088635687, 0.010270948132529156, 0.08601718669524416, 0.04914908611681312, 0.002591611460047716, 0.03857557829178404, 0.04124188482819591, 0.01950788417161675, 0.014270629653765354, 0.07848582754377276, 0.029214201713330112, 0.02469315495545743, 0.026681928902689833, 0.020290649590606336, 0.026935672904073726, 0.046890292869647965, 0.0035464048551148153, 0.03829224115179386, 0.042206339130643755, 0.05553395327297039, 0.0218457124356064, 0.04556413805403281, 0.08689367794431746, 0.0149661593241035, 0.0626786683278624, 0.0300476038682973, 0.05908323742914945, 0.005246158434601966, 0.049067757863667794, 0.05885868209588807, 0.08496155583998188, 0.027095668810943607, 0.08137501587043516, 0.027314190483593848, 0.07039608390186913, 0.060643280085059814, 0.05375876942707691, 0.018361980328336358, 0.006576782370757428, 0.03669685000204481, 0.011106244619440986, 0.025715971751196776, 0.024298822208947968, 0.031463428676943295, 0.03267052074079402, 0.05599582887953147, 0.002681023092918622, 0.02873139197618002, 0.060320334523567, 0.06488575614639558, 0.06612440061871894, 0.04345681343693286, 0.01909326296299696, 0.057249928577221, 0.04875498343608342, 0.032100837051984854, 0.019510526217345614, 0.01219070141814882, 0.04293341007723939, 0.01836852421547519, 0.02074538202577969, 0.0808999671426136, 0.098501884349389, 0.04471147716685664, 0.012950470463692909, 0.01145473304859479, 0.01650346071983222, 0.07585533705423586, 0.07649264895007946, 0.0401941615564283, 0.00795263278632774, 0.04361798564787023, 0.050205878433189355, 0.028072008608432952, 0.03846593710477464, 0.06475061847595498, 0.010701039409468649, 0.0646914321987424, 0.053575295678456314, 0.08713319126400165, 0.029522877630370203, 0.03371211758349091, 0.05575495742959902, 0.06968311747186817, 0.03164826426655054, 0.03973792998294812, 0.08350903182872571, 0.04324839239416178, 0.02292937791935401, 0.023087347763066646, 0.02475839344697306, 0.018312310239707585, 0.03126668532786425, 0.05224582717346493, 0.010610872177494457, 0.021072466915939003, 0.05334344874427188, 0.07618838324560784, 0.03854905393382069, 0.04143879144976381, 0.016015840010368265, 0.027137587167089805, 0.005716055266020703, 0.007408885767290485, 0.02849016058462439, 0.03563082907930948, 0.05516483128303662, 0.0547229713993147, 0.06279456210904755, 0.023286647810891736, 0.016154430522874463, 0.02331015348318033, 0.06570209632627666, 0.045799662329955027, 0.054387769268942066, 0.10857645742362365, 0.07661488809389994, 0.06713910202961415, 0.02039657632849412, 0.030012951137905475, 0.03936298584449105, 0.10598525623208843, 0.12375151462038048, 0.08227563434047624, 0.150852469378151, 0.13143285439582542, 0.10667626251233742, 0.13508877775166184, 0.11201345463632606, 0.1524467213312164, 0.14538193558109924, 0.11468402110040188, 0.1497681619366631, 0.09037926356540993, 0.08618995125289075, 0.15930947964079678, 0.08369988994672894, 0.08118680721963756, 0.10723813509684987, 0.060364696400938556, 0.12187693864689209, 0.10744707193225622, 0.13059185264864936, 0.20118228276260197, 0.11627815430983901, 0.11287958550383337, 0.09611746034352109, 0.0880637405498419, 0.1934552044258453, 0.11091348045738414, 0.194563987897709, 0.1628667864133604, 0.1441629877081141, 0.09453457809286192, 0.16681869310559705, 0.107357175584184, 0.09796982383704744, 0.18031729065114632, 0.2422595481039025, 0.05913774075452238, 0.14581969880964607, 0.06573072838364169, 0.17850956734037027, 0.09022120095323771, 0.10423429979709908, 0.18281742290128022, 0.18863614270230755, 0.19630499213235453, 0.1503604996833019, 0.10117387573700398, 0.15368900232715532, 0.11944564801524393, 0.14686240145238116, 0.149027424340602, 0.12892782397102565, 0.12595121806953102, 0.15843954897718504, 0.10840390066732652, 0.17112711269874126, 0.11641748511465266, 0.2366368443472311, 0.17055960721336305, 0.14390097989235073, 0.17821779940277338, 0.12696830177446827, 0.1480215322226286, 0.1301601156592369, 0.17420289921574295, 0.0983059722057078, 0.08885066941729747, 0.08129727590130642, 0.21400641649961472, 0.1701879099709913, 0.2706538065103814, 0.1961546330130659, 0.17862439242890105, 0.09292786548030563, 0.19054482778301463, 0.25090466311667114, 0.13209194090450183, 0.20268936204956844, 0.1643961004447192, 0.2616806176956743, 0.07743740294245072, 0.1456719372072257, 0.203471556014847, 0.18097232503350824, 0.20021382457343861, 0.25532281666528434, 0.07693986714002676, 0.16684266447555274, 0.15971739368978888, 0.14007102290634066, 0.14554550492903218, 0.17069353518309072, 0.09630164655391127, 0.1396877778461203, 0.17906632652739063, 0.10442313185194507, 0.15831549157155678, 0.1714104349957779, 0.1189644394617062, 0.13554757344536483, 0.09492292170762084, 0.07811539195245132, 0.12720673898002133, 0.1935509711620398, 0.1524117513326928, 0.25031462602782995, 0.12198748896480538, 0.15832355129532516, 0.1429945504060015, 0.15915673080598935, 0.09965040240786038, 0.1213719962106552, 0.18318843736778945, 0.13022454892052338, 0.15864871587837115, 0.1541942564654164, 0.2076021273387596, 0.14198594202753156, 0.17423219920601696, 0.1602871553041041, 0.1732431389973499, 0.1765104738296941, 0.21077123150462285, 0.11458003136795014, 0.13707541802432388, 0.21123985323356465, 0.08947552065365016, 0.2843673597089946, 0.12477424606913701, 0.08302587884827517, 0.11572900213650428, 0.2362973414710723, 0.22788325703004375, 0.12346507530310191, 0.1202524738619104, 0.16944767703535035, 0.1720353975542821, 0.09196591592626646, 0.09461550187552348, 0.15198602573946118, 0.180634647840634, 0.1701284639420919, 0.11685027595376596, 0.11907320120371878, 0.1657826846349053, 0.11030054811271839, 0.14208994660293683, 0.1315576836350374, 0.12269204686162993, 0.11218473489861935, 0.1372008558246307, 0.10824572673300281, 0.10126552355359308, 0.1354479623842053, 0.13942835270427167, 0.1461111698881723, 0.08667248082929291, 0.1552986167371273, 0.15346028725616634, 0.2734015043824911, 0.15853849210543558, 0.1590543144266121, 0.17128701583715156, 0.09857187629677355, 0.1238771973294206, 0.10409952577902004, 0.21170571417314932, 0.1183124107774347, 0.23392733739456162, 0.16283726377878338, 0.22934717300813645, 0.0968915426346939, 0.1925190445035696, 0.10352675846661441, 0.20982370187994093], [0.05727813761041034, 0.0471388492587721, 0.021218109686742537, 0.058433383237570524, 0.02333153475774452, 0.06526198791107163, 0.030704534437973052, 0.022850192617624998, 0.029678285209229216, 0.030950222426326945, 0.02500994440197246, 0.02763905078609241, 0.04669560898037162, 0.049199685745406896, 0.017124888800026383, 0.003805127739724412, 0.049256845959462225, 0.028453799059207086, 0.07484182307962328, 0.035379229884711094, 0.04088765774213243, 0.04551512291072868, 0.07687857316341251, 0.03572369401808828, 0.03152864861476701, 0.021837031163158827, 0.005051188354627811, 0.0250313813376124, 0.026074338165926747, 0.023764577927067876, 0.05415957741206512, 0.03543302074831445, 0.030966314043325838, 0.02908366164774634, 0.07752028599497862, 0.04482746742723975, 0.06909213785547763, 0.03796668694121763, 0.02505685741198249, 0.025119309138972312, 0.07782659260556102, 0.017730843101162463, 0.060057718146708794, 0.05648862606904004, 0.07234541641082615, 0.026766758237499744, 0.016238092830462847, 0.010698641344788484, 0.03864169251755811, 0.017477139917900786, 0.060138875705888495, 0.023778979302733205, 0.03502011204545852, 0.08022335852729157, 0.04051725925819483, 0.03599630712415092, 0.04257550936017651, 0.04251246020430699, 0.07785256777424365, 0.05517192621482536, 0.029884661635151133, 0.07660170012968592, 0.0255182394903386, 0.039906794554553926, 0.02128985866875155, 0.06666818706435151, 0.020740656400448643, 0.01958462224138202, 0.01139200208854163, 0.04302437882870436, 0.028439464476832654, 0.054691589684807695, 0.010697903835534817, 0.0468561800516909, 0.024608802450529765, 0.05089501821203157, 0.042479186013224535, 0.09273852134356275, 0.022514279880851973, 0.020373666229716036, 0.06066185604140628, 0.0302918075612979, 0.01874224381026579, 0.06886793504236266, 0.031461191101698205, 0.013349367418413749, 0.09721157897729427, 0.05750318647187669, 0.06829776524682529, 0.008542270043108147, 0.029831954307155684, 0.001385522571126785, 0.042428946326253936, 0.03195701996446587, 0.038420087221311405, 0.012413196363922907, 0.10160709702176973, 0.024263347550004255, 0.052393362420843914, 0.0600823054992361, 0.04045701913128141, 0.043205785696045496, 0.08123065330437385, 0.04738475246995222, 0.07849445129977539, 0.06304547481704503, 0.0049756952375901164, 0.01175221274024807, 0.03540945013810415, 0.07198782739578746, 0.03920246301277075, 0.03402949703740887, 0.07387215518974699, 0.06151443529233802, 0.0019864276009684545, 0.06860616471385583, 0.017368830885970965, 0.021590654832834844, 0.053388656669994816, 0.05660413022269495, 0.05219009559368715, 0.015893335548753385, 0.03346783225424588, 0.013775086517853197, 0.05124135255755391, 0.01402949010298471, 0.0126861731223471, 0.03350449806021061, 0.06260366688366048, 0.05756810955062974, 0.0456276139448164, 0.013467315093294019, 0.02516848013328854, 0.030284317435871344, 0.021865433154744096, 0.09359634015709162, 0.02278029529406922, 0.013777183085039724, 0.013904633033234859, 0.00756855327381345, 0.05571274406975135, 0.06175090209580958, 0.03230634145438671, 0.019341045663168188, 0.06947870773728937, 0.028317729993432295, 0.030634269751317333, 0.051089694679831155, 0.044590518227778375, 0.03243171617214102, 0.04859244196268264, 0.027412432282289956, 0.040008973446674645, 0.011301226295472588, 0.04241563590767328, 0.050268916456843726, 0.02877490594983101, 0.01252481351912138, 0.03909653998562135, 0.03740709646081086, 0.06223109761776868, 0.04120730074646417, 0.019971624424215406, 0.008938205828599166, 0.021018403313064482, 0.011410800689191092, 0.026216895457764622, 0.024670866405358538, 0.04221374576445669, 0.040489395323675126, 0.042365600311313756, 0.014041216963960323, 0.026734374623629265, 0.0345311999990372, 0.06490546016721055, 0.012722368592221756, 0.012462640097510302, 0.058184396402793936, 0.042282836002414115, 0.025799533868848812, 0.002461297981426469, 0.009990306843974395, 0.06824129523010924, 0.019687990425154567, 0.06128069588157814, 0.050201128688058816, 0.030110933184914757, 0.038900037834537216, 0.03195854507794138, 0.06241240800591186, 0.0830522770411335, 0.03651301631180104, 0.03515633325150702, 0.04311799333663657, 0.05018823758291546, 0.03392030484974384, 0.08672490614117123, 0.009631625016481848, 0.06077915990317706, 0.02031762109254487, 0.12545259873149917, 0.043292795089655556, 0.016384487025788985, 0.05009466018236708, 0.04054977274790872, 0.01979455912078265, 0.016774802897998597, 0.012710904265986755, 0.06019755732268095, 0.04107894259504974, 0.013431766219582641, 0.10252534892060794, 0.007397808749374235, 0.004186001406196738, 0.010598536755423993, 0.016432683951279614, 0.06390821406967007, 0.010713386891438859, 0.026728673074103426, 0.05364321332308464, 0.022819376790721435, 0.059152743269805796, 0.022577204726985656, 0.031504306170972995, 0.021095399279147387, 0.0059960921680612955, 0.04020897853479255, 0.02630882714584004, 0.02590764623164432, 0.08363452900084667, 0.010859624308068305, 0.026369356710347347, 0.026093021733686328, 0.04544147217529826, 0.04075863165780902, 0.04224085270834621, 0.030972208551247604, 0.10366945862188004, 0.0728019633970689, 0.030989649021648802, 0.05096801214676816, 0.019004631976713426, 0.03756825011805631, 0.01319849621722824, 0.07277598822838627, 0.021745593003288377, 0.0546561781084165, 0.04486754711251706, 0.040598483610665426, 0.04904310742858797, 0.04580267544952221, 0.051396383496467024, 0.023843564704293385, 0.057338585538673215, 0.002936152359325206, 0.056150087984860875, 0.049474002080387436, 0.04834565188502893, 0.03588151543226559, 0.013036801719863433, 0.025695403128338512, 0.03165555215673521, 0.035363292263355106, 0.03336501140438486, 0.04757600021548569, 0.04133433416427579, 0.026529961178312078, 0.055843822192400694, 0.03745417830941733, 0.035502608225215226, 0.04562666770652868, 0.05452742290799506, 0.011958749655605061, 0.07824809537851252, 0.028281832310312893, 0.04339265848102514, 0.02132605321094161, 0.014111591117398348, 0.01825866780563956, 0.02362999686738476, 0.15097021852852777, 0.014596213550248649, 0.06610030308365822, 0.061989639871171676, 0.03885841819283087, 0.006746528706571553, 0.04387787834275514, 0.014794733415328665, 0.014292912637756672, 0.03284065438492689, 0.03705717754201032, 0.13648368883877993, 0.06001160109008197, 0.07533251628046855, 0.050016482346109115, 0.040145213206415065, 0.06769579442334361, 0.07926809572381899, 0.01256456016562879, 0.05993580554786604, 0.018539967750257347, 0.025600122498872224, 0.040688888329896145, 0.020455899903026875, 0.05295549846778158, 0.0136336405921611, 0.011236450718570268, 0.06964411761146039, 0.05161463799595367, 0.03620568924816325, 0.02995707112859236, 0.03308546663902234, 0.05467112125188578, 0.020231045855325647, 0.007714740595474723, 0.01416827913999441, 0.06522363371914253, 0.028244205423106905, 0.039578965661348775, 0.009565840118739288, 0.03458851235336624, 0.08178670002962463, 0.03599419942474924, 0.06979534504353069, 0.051778366905637085, 0.07042484954581596, 0.04327685746829957, 0.03335025750857312, 0.09509809824521653, 0.0298456506425282, 0.027664486042340286, 0.010142037081095623, 0.016374883634853177, 0.052044972326257266, 0.08818108894047327, 0.024056737347564194, 0.019158865106874146, 0.04675721465901006, 0.04560150147881359, 0.04694561255746521, 0.08279285932076164, 0.0014481974062618974, 0.008594858627475332, 0.04101971921045333, 0.07624047459103167, 0.0808193402190227, 0.0168608512103674, 0.073332354077138, 0.05438868953206111, 0.008083510529104387, 0.020937442423019093, 0.056470042691216804, 0.14090479613514617, 0.13778900785837322, 0.1311435058596544, 0.15067094005644321, 0.08076648446149193, 0.11529375478858128, 0.1156366195937153, 0.1799354556715116, 0.12710714276181534, 0.18527606909628958, 0.12759690085658804, 0.1077022371464409, 0.09945137324393727, 0.11584462132304907, 0.23980042693438008, 0.12490195484133437, 0.07519021688494831, 0.11204319991520606, 0.15050572314066812, 0.11253756674705073, 0.142200437549036, 0.08417055258178152, 0.16050534672103822, 0.10880025205551647, 0.16094446065835655, 0.14512123394524679, 0.13345856132218614, 0.09546529807266779, 0.10805101686855778, 0.11544977649464272, 0.09552203526254743, 0.08823474621749483, 0.15011814393801615, 0.1892578843398951, 0.13376236689509824, 0.22493127558846027, 0.17072166258003563, 0.10121531726326793, 0.10734665193012916, 0.0701855291845277, 0.2996618062024936, 0.07900869284640066, 0.0919546427030582, 0.15123982593649998, 0.18188573070801795, 0.13205481867771596, 0.11336518757161684, 0.0892249567550607, 0.11385137593606487, 0.168831204646267, 0.12984712229808792, 0.09108149854000658, 0.06601201719604433, 0.19242266920628026, 0.07040776530629955, 0.11457101427367888, 0.1501882917364128, 0.10305927222361788, 0.196317371155601, 0.17404988320777193, 0.12761339137796313, 0.18556243419880047, 0.05882776793441735, 0.12001399212749675, 0.08276709937490523, 0.10683259592042305, 0.13266559137264267, 0.12004535528831184, 0.09502705244813114, 0.12628370022866875, 0.1357176440069452, 0.1213532495603431, 0.19119782868074253, 0.15136202797293663, 0.18730067764408886, 0.12386301488731988, 0.21497784327948466, 0.26469180767890066, 0.1127481140429154, 0.11702637275448069, 0.21465450437972322, 0.12767549429554492, 0.12344680362730287, 0.20127898460486904, 0.09897072130115703, 0.09852873525233008, 0.21829196310136467, 0.13552222168073058, 0.15693558671046048, 0.08964104927144945, 0.09791032585781068, 0.2026660882984288, 0.16532939567696303, 0.12576539913425222, 0.11355174123309553, 0.13434217718895525, 0.20608887338312343, 0.17003513145027682, 0.1210903660103213, 0.11197222091141157, 0.2025977661833167, 0.1498980080941692, 0.12759216595441103, 0.08629072006442584, 0.2549203054513782, 0.22374299325747415, 0.09321634570369497, 0.09086841309908777, 0.12359227941487916, 0.12805366306565702, 0.20275713497539982, 0.12196531359222718, 0.09409628793946467, 0.1951903011649847, 0.14201697864336893, 0.3121511125937104, 0.1043251683586277, 0.20358424371806905, 0.19293427612865344, 0.15184651681920514, 0.24775932251941413, 0.1205647547612898, 0.09056067414348945, 0.15701478871051222, 0.1359471309115179, 0.073393529310124, 0.10549015467404388, 0.11770330049330369, 0.15166295401286334, 0.1628504740074277, 0.18446009256877005, 0.19471756793791428, 0.12823773053241894, 0.08267928846180439, 0.13757615990471095, 0.15681948512792587, 0.10135942007764243, 0.2064013620838523, 0.08427281311014667, 0.06920666608493775, 0.20952139544533566, 0.12319376095547341, 0.08486512117087841, 0.18695167527766898, 0.13036249933065847, 0.16944748407695442, 0.09499459833023138, 0.13972310407552868, 0.1756172248860821, 0.11030088207917288, 0.1486077398294583, 0.11819938910775818, 0.20708669093437493, 0.1478553208289668, 0.17293712182436138, 0.1321995968464762, 0.10731458372902125, 0.1654196556773968, 0.17498856643214822, 0.14464248932199553, 0.1421676791505888, 0.11710550053976476, 0.16100506443763152, 0.13966391037683934, 0.104739591042744, 0.1193615775264334, 0.16194799274671823, 0.12180031932075508, 0.11252345851971768, 0.1689059240743518, 0.10234994973870926, 0.14674928330350667, 0.1422617834759876, 0.13439814996672794, 0.2689806494163349, 0.13724741816986352], [0.032990115505526774, 0.07012182322796434, 0.0472343042929424, 0.01750414667185396, 0.05878238189325202, 0.016075299026852008, 0.04323212822782807, 0.021096015261719003, 0.03928973586880602, 0.0518144167290302, 0.07200592837762088, 0.06908686118549667, 0.12012342922389507, 0.042363785760244355, 0.012254032590135466, 0.0025479091664237785, 0.07093233012710698, 0.09587445150827989, 0.08288585784612224, 0.036905564193148166, 0.10646567810908891, 0.0381532220490044, 0.027847475539601874, 0.03387276658031624, 0.0451751710352255, 0.0231839197294903, 0.04728018757305108, 0.06618732732022181, 0.049920325982384384, 0.0288660695150611, 0.04838343091250863, 0.07511327843531035, 0.0630951244966127, 0.04659720761992503, 0.031140928404056467, 0.021304289730323944, 0.024389444006374106, 0.01915879089210648, 0.05107209464767948, 0.04202090611215681, 0.052923612092854455, 0.016997213424474467, 0.019963761369581334, 0.09933604349498637, 0.044594637147383764, 0.0537282300501829, 0.018848558320314623, 0.0442436384037137, 0.014250012791308109, 0.017396169751009438, 0.010662694494385505, 0.04266171723429579, 0.034956625022459775, 0.04278082451492082, 0.056046473036985844, 0.020624066855816636, 0.035742013933486305, 0.021433748115669005, 0.0905549299204722, 0.07679522997932509, 0.058820012491196394, 0.022220281789486762, 0.061445790342986584, 0.06295594212133437, 0.05277705276967026, 0.05249019784969278, 0.010968436145049054, 0.011432181036070688, 0.07246110239066184, 0.03908304774085991, 0.00941424254051526, 0.029436877557600383, 0.04434118258359376, 0.016487079665239435, 0.030296978475234937, 0.06586732066352852, 0.021790897408209275, 0.03923901007510722, 0.04306225062464364, 0.012847216385125648, 0.034542027933639474, 0.04695837007602677, 0.025277894965256564, 0.12270463368622586, 0.0495136476092739, 0.034579395069158636, 0.05540286030736752, 0.013358838150452357, 0.035664656170411035, 0.01714978599920869, 0.06829912337707356, 0.03949227168050129, 0.03891793101502117, 0.006345588062686147, 0.05551632355491165, 0.08092176401987672, 0.06805137963965535, 0.04878662119153887, 0.04446462400665041, 0.10236336034722626, 0.06516547160572372, 0.042007877709693275, 0.06622753688134253, 0.019271432211098727, 0.011311338985251496, 0.00896984265637002, 0.032126381775015034, 0.05780708110250998, 0.026787258211697917, 0.03091895574470982, 0.04529005178483203, 0.033250457199756056, 0.0415910393348895, 0.03637873953266535, 0.017162599178845994, 0.021468567829288077, 0.022156826307764277, 0.05903278251935262, 0.02287584495206829, 0.0032676973251000163, 0.062026532032177784, 0.050970724696526304, 0.05186781796510331, 0.05441747744043823, 0.028040547113050707, 0.03789531459915452, 0.0795887851563748, 0.027568240620894358, 0.022685328221996315, 0.045902906203991733, 0.02227606346423272, 0.030605500396632124, 0.028974157758057117, 0.10910341195994988, 0.041029456187970936, 0.038243107264861465, 0.015834876576263923, 0.017015835765050724, 0.024108758188958745, 0.049220651417272165, 0.0567404738831101, 0.030166174947225954, 0.0382858586817747, 0.06286138508585282, 0.014463119568972616, 0.03970601021137554, 0.024715580802876502, 0.022782536580052692, 0.048251948319375515, 0.011856491910293698, 0.057185257828678004, 0.02628134170663543, 0.033371972749591805, 0.10050706347101368, 0.037139678388484754, 0.09311624482506886, 0.03565708997484762, 0.03811988477536943, 0.015570085706713144, 0.06004322771332227, 0.017099321812565904, 0.03311231754196342, 0.010989818347297842, 0.01168412161860033, 0.06335910642519593, 0.09947570084477775, 0.023425357067026198, 0.014817745559412288, 0.03386579039215576, 0.025614206606405787, 0.05807488880236633, 0.07035965929389931, 0.0873582623898983, 0.016037013483582996, 0.006172894009068841, 0.0401116087596165, 0.008105242468445795, 0.06648429771303199, 0.05170570693735499, 0.03159304476866964, 0.011868190013046842, 0.017345753803965636, 0.004553623793981387, 0.05609397419902962, 0.05994304890919011, 0.027425996886449866, 0.09712319661048241, 0.08853168692439795, 0.0376456041703932, 0.05692927254131064, 0.05165930044313427, 0.05879596319573466, 0.07974958629347384, 0.09602299236576073, 0.028250081377336755, 0.021909821007284336, 0.06016256877046544, 0.009177816555165919, 0.007253859930642648, 0.019741592041100375, 0.02972911675897194, 0.05275040224660188, 0.02799843579850858, 0.05033756882767193, 0.07542423089034855, 0.04776593064889312, 0.04214434011373669, 0.0462078027339885, 0.08877676635165699, 0.029533360466302838, 0.018711331504164264, 0.031331103746197186, 0.052786199739784934, 0.019514301893650554, 0.07126475291443057, 0.06711073714541271, 0.08401703933486715, 0.04135454655624926, 0.028895143150293734, 0.07926730904728174, 0.03321645941468887, 0.05273042363114655, 0.02722400469792774, 0.05067848920589313, 0.016920601519814227, 0.03557753916538786, 0.02743256674875738, 0.040947252200567164, 0.02169865030737128, 0.03859986878524069, 0.0781741106766276, 0.01292886747251032, 0.05949869169853628, 0.05808150504890364, 0.006451569997807383, 0.0957662018481642, 0.04508901511144359, 0.16747537505580112, 0.009165919000224676, 0.05630110019410495, 0.019607229914981872, 0.036627436929848045, 0.03603849821956828, 0.005528949168365216, 0.02549301574617857, 0.04636991747247521, 0.009696318957139738, 0.029189820306783076, 0.09164075876469724, 0.02165648889786098, 0.024088620011752937, 0.06773334709578194, 0.02273204085213365, 0.03454066609265283, 0.041311861932626925, 0.021458687988342717, 0.05378249588829931, 0.009383741198689677, 0.03514537544106133, 0.06948017718968913, 0.023840258436393924, 0.007506410465794033, 0.048552866937825456, 0.00899774648132734, 0.026826731191249564, 0.06768318533431739, 0.0410792171896901, 0.025636929312895518, 0.024994769337354228, 0.04764871584484354, 0.044243950105737895, 0.038109839806566015, 0.08687959940289147, 0.024785943824099377, 0.045058156611048616, 0.021973862785671372, 0.048923751528491266, 0.07725427058176138, 0.05943937554548029, 0.029902614187449217, 0.045318988122744486, 0.043828744455822743, 0.02880118725443026, 0.012296185650484404, 0.03730944466951769, 0.025076186648220755, 0.05046557816967834, 0.021802855262649246, 0.09290544519899413, 0.04051495860039722, 0.02969908204249805, 0.030245898306020536, 0.022094187188486103, 0.048964042725856416, 0.054060352267697453, 0.007258157893375028, 0.004553755061351694, 0.05850415072927717, 0.05922255710174795, 0.06495264591649175, 0.026625414357113186, 0.031648924777982756, 0.01798835350200534, 0.014210622375685489, 0.02857068360754056, 0.12425281311152503, 0.015324251144193113, 0.030169178789947182, 0.036842849003733136, 0.03181625681463629, 0.06972768343985081, 0.0018453534448781284, 0.013665557580679888, 0.11203497691894881, 0.03262965437897947, 0.01828097490943037, 0.04923888969642576, 0.020222594648657832, 0.03021167231054278, 0.08282207025331445, 0.030894791416358203, 0.02973531369207194, 0.04396146643557586, 0.010300053309038049, 0.051105131351505406, 0.012110989191569388, 0.057218491201638244, 0.007038085132080596, 0.08103662621579133, 0.04033223813166842, 0.02535536405048333, 0.029311981525097508, 0.03267654697992839, 0.07835774769773707, 0.02204144089773763, 0.06099528443883173, 0.03628742939326912, 0.037618734713760205, 0.06129425120889209, 0.034290662515559234, 0.0801252169185318, 0.02720349915762199, 0.04255065483448561, 0.02639885336975567, 0.023915796082292218, 0.014474018007604172, 0.022585407314181793, 0.047610844048904255, 0.03778756217798218, 0.045057247480144724, 0.010145371179532958, 0.038306360511342064, 0.17946675972780213, 0.13489135162672028, 0.12901763868285343, 0.09489180345553905, 0.07206899608718231, 0.06552257080329582, 0.1313681242754683, 0.09810649033170193, 0.09021164951263927, 0.16005651064915583, 0.19769666745560244, 0.24887043633498251, 0.1327651579049416, 0.2086159901227802, 0.09641906173783354, 0.22281380952335894, 0.14683048910228536, 0.2935539901955053, 0.12708060356089845, 0.1414314834983088, 0.2293542234110646, 0.10964463799609803, 0.16531177709111944, 0.11011084774509072, 0.18637888570083305, 0.13922886340878904, 0.1529462164035067, 0.09861381506198086, 0.15511607809457928, 0.10726238106144592, 0.15622410457581282, 0.12760623707436025, 0.18218006647657603, 0.07454307153238915, 0.10153469309443608, 0.06810214996221475, 0.1492990058613941, 0.13534999889088795, 0.1598281369660981, 0.08513897366356105, 0.18532359623350203, 0.08284707320854068, 0.1210498224827461, 0.32540910586249083, 0.12089300667867064, 0.1371791257406585, 0.1963120573782362, 0.14541024109348655, 0.08004543604329228, 0.08871887883287854, 0.09487637420534156, 0.10005839067162015, 0.14073558646487072, 0.11374705223715864, 0.13439259870210662, 0.09003389772260562, 0.1495573326246813, 0.0801688403589651, 0.1482546704937704, 0.26095589564647526, 0.09403292337083258, 0.43738556443713605, 0.10573539737379178, 0.18017318041529506, 0.15501398826017976, 0.2280131180305034, 0.07183924943092279, 0.2249663940165192, 0.14450887305429205, 0.0918257464945782, 0.08450622597592883, 0.15279689629096538, 0.19580009422497824, 0.15910489921225235, 0.09882223981549032, 0.16221761499764398, 0.11923309692065232, 0.20744847308378667, 0.12990082410397008, 0.10222791097476147, 0.18452219548635185, 0.1269437515293248, 0.1060459935979452, 0.2738223614869639, 0.12640250322874635, 0.15289088187273592, 0.16954195947619155, 0.12093274868675508, 0.21638636535499245, 0.1333672771579586, 0.10517468996113166, 0.13563384069129825, 0.1777088493690826, 0.09919565141899511, 0.19536384497769177, 0.14480835932772607, 0.18355100619373843, 0.11928127714782022, 0.1462622414692305, 0.14431803720071912, 0.14476191572612152, 0.3240780491614714, 0.14834767644060776, 0.09190434735501185, 0.11325001367367804, 0.11689857492456213, 0.08457140138489194, 0.14697649923618883, 0.1073647900193464, 0.2223824881366454, 0.21356543235015124, 0.07963778174598701, 0.16252042609266937, 0.12177570970379747, 0.1950859700446017, 0.06749991196556948, 0.05888383719138801, 0.1729275332763791, 0.12857200868893415, 0.3259785706177354, 0.32685139565728605, 0.15056724718306214, 0.14266515558119863, 0.21719147684052587, 0.127730056992732, 0.13583129650214687, 0.118465100240428, 0.10504672143724747, 0.10831753694219515, 0.16279991890769452, 0.08043963520321995, 0.0839108825311996, 0.11439659472671337, 0.15018118196167052, 0.24694822932360694, 0.08623501445981674, 0.1460282423067838, 0.1572576045873575, 0.20270850945962593, 0.10185429899138398, 0.13999182090628892, 0.1129327158560045, 0.0985306796792429, 0.3448723739711568, 0.07489131690817885, 0.22500011720694602, 0.11278696547378786, 0.07333579022088088, 0.16609447571681812, 0.09950048857717775, 0.241749603592325, 0.14323810843052343, 0.17056414915714413, 0.22030995169188827, 0.08494749214150943, 0.19169650739058852, 0.1420503159170039, 0.11521539883688092, 0.09322722558863461, 0.20597772934706882, 0.11003030987922102, 0.12430014729034156, 0.1437215434270911, 0.122202296188334, 0.12531077431049198, 0.21994949056534097, 0.17715611262246966, 0.08744589518755674, 0.10274524727719836, 0.1034512894693762, 0.09216973936418071, 0.2021688493550755, 0.21387247368693352, 0.11351254841429181, 0.12298757006647065, 0.088384674891131], [0.04230351965816226, 0.058087713114218786, 0.004113410550417029, 0.02419821666990174, 0.03589306696085259, 0.011145462485728785, 0.018220356287201867, 0.052569711551768705, 0.05892182030947879, 0.0489796055626357, 0.029935263119114097, 0.04665839398512617, 0.015596309494867455, 0.05120416353747714, 0.023845434916438535, 0.03680749679915607, 0.005924722609051969, 0.022063735013944097, 0.056649078396731056, 0.033923796654562466, 0.012724789849016815, 0.02216136268543778, 0.051764240124612115, 0.012917418916913448, 0.07419717134325765, 0.03929225917090662, 0.021636708806909155, 0.06983549523283727, 0.021188800419622567, 0.015034483294584788, 0.02009261675993912, 0.032455038162879646, 0.08394947421038523, 0.003474863210612966, 0.033274335801252164, 0.029489230510080233, 0.04527494907961227, 0.1012130017625168, 0.04256295593222603, 0.05363896081689745, 0.03681728201627266, 0.02196556371927727, 0.13681084237759933, 0.056926697288872674, 0.07064816920319572, 0.05997554755595047, 0.021409578221209813, 0.0482278285198845, 0.01588129420269979, 0.038907232956262305, 0.03515550575684756, 0.01437594968592748, 0.04944414547935594, 0.020504200729192235, 0.012109380586480256, 0.046422955056186765, 0.06983833765843883, 0.017681683239061385, 0.04713682319561485, 0.07186479415395297, 0.011501877052069176, 0.001425084028596757, 0.008149259247147711, 0.07865675157518126, 0.045160598965594545, 0.05011735134758055, 0.01629986920306692, 0.036410314205568284, 0.003554030886334658, 0.005501419664142304, 0.0440181590965949, 0.04367011038993951, 0.04706815227109473, 0.019271886776550673, 0.03501545506878756, 0.011548425482033053, 0.02733994300797349, 0.01879932238807669, 0.045070353808114305, 0.06724861334078014, 0.03193756456312258, 0.04438194875547197, 0.019144601028528996, 0.06225259021448437, 0.04085939304786734, 0.09653095534304157, 0.055200561982928775, 0.05274213101074565, 0.07618101371917874, 0.02516556534828851, 0.0229235372171388, 0.0090170543808199, 0.009329490203526802, 0.024386230506934226, 0.026550294169283006, 0.06401638209354132, 0.01693294158030767, 0.019054977419727948, 0.006933219201528118, 0.020481333303905558, 0.06230256272829138, 0.006058334702174761, 0.056843246493372135, 0.02919191130786203, 0.07590162480482832, 0.02440432035655249, 0.028219477062521037, 0.023435082912328653, 0.02115387123922119, 0.03181184103596024, 0.003961204874940449, 0.013750454636465292, 0.0455302998307161, 0.02931091468781233, 0.028744030751113314, 0.028594643845281098, 0.059000907276640646, 0.006816797103965655, 0.03241805694415234, 0.05385219839808997, 0.024071205516520422, 0.04100018959434237, 0.023151265231717844, 0.013816635655530263, 0.08289872668683529, 0.03201877036190126, 0.04604904250300024, 0.05780300671176519, 0.05109078934765421, 0.008710375768714584, 0.023286510513571557, 0.010656217400537571, 0.062118306013871916, 0.026780384068842977, 0.06049162220733706, 0.03954024410631973, 0.04501896008150652, 0.05762254979345016, 0.015229212640406331, 0.038501048111356795, 0.016421323525719345, 0.033920950518222526, 0.021468269114848226, 0.008975652744993567, 0.008343983954546275, 0.07288567765499465, 0.10769635933684185, 0.04238220215484034, 0.06239159076358192, 0.02922527455666568, 0.03177239588694647, 0.057992940855911, 0.05420530113042332, 0.05599981050181668, 0.0351894256164087, 0.0385734631709056, 0.003410588815313531, 0.048244248537230305, 0.03421233996050432, 0.03825928237347398, 0.03461395688646007, 0.023684336920268834, 0.010831539584614802, 0.034069194516632706, 0.01492544324719347, 0.03585294274671469, 0.0282604510357487, 0.008305983210448176, 0.0057385469790460775, 0.04694617658969946, 0.04070537142979447, 0.026764633839775342, 0.019305339083075523, 0.06748401516233571, 0.013096507500449661, 0.011807396986114327, 0.027354867597750854, 0.16534364491235465, 0.05118926121213008, 0.04391705631860532, 0.013561105861299438, 0.0033445650387875503, 0.06549762721988373, 0.061538354711956345, 0.09146805357886478, 0.04771136795170605, 0.04956890050380025, 0.012123450778744882, 0.02996347215230344, 0.043560728954616934, 0.06563430113601498, 0.04448500709258951, 0.03408137316000648, 0.04245934840582777, 0.06238055502763018, 0.06253675484913401, 0.09556745470035821, 0.02838349355442915, 0.04880811378825456, 0.024168616109818686, 0.03943840660213027, 0.04145516693824902, 0.042788594801095314, 0.023814964188204613, 0.0316685026336927, 0.017300436411460396, 0.039562530801049434, 0.017767510762496386, 0.10078756560687907, 0.11057066760258749, 0.0593336937163258, 0.040100227924995124, 0.037499649697565474, 0.02853065772796981, 0.0701183573983144, 0.04104336774616968, 0.022887259183335118, 0.08328052455908619, 0.016436448495369405, 0.04437893563590478, 0.08029700184124522, 0.035059115616604686, 0.002365330169595836, 0.05386125259974506, 0.03694675338920206, 0.029770604669465683, 0.01987821771763265, 0.012223305820953101, 0.04038429236970842, 0.06685551998089068, 0.036266133465687744, 0.0059929552026005695, 0.03789117712585721, 0.014227325336833019, 0.04608425369951874, 0.05775615863967687, 0.03842424324830063, 0.03868773164867889, 0.015017475125205237, 0.027219522125960793, 0.062253592113847844, 0.06094045456848107, 0.06076043922803365, 0.021209215046837926, 0.05581412144238129, 0.012425329550751485, 0.031190511290333234, 0.07938856855616905, 0.033921970971277915, 0.02782715739158448, 0.05389716141507961, 0.054096973544801585, 0.02484259195625782, 0.01537343790914747, 0.04798350237251725, 0.037374931780504994, 0.010244874629279366, 0.05665583936206531, 0.05665069256792776, 0.06340389503748156, 0.02541323672630824, 0.0547087629820453, 0.03285290353232995, 0.07563023624243215, 0.08451660862192512, 0.021100136036693584, 0.027794629058917053, 0.0671596743632108, 0.037579122581519186, 0.09633352921810001, 0.07110695747542195, 0.025643367443990428, 0.0551902646839153, 0.09011207555886358, 0.04505716213316191, 0.012103263434255496, 0.05365317665564362, 0.02695073479117127, 0.0244103818477015, 0.05248247580311727, 0.05671402373991441, 0.036824061535298824, 0.13047677522990853, 0.04494621476624161, 0.01278897820156999, 0.009495386184426025, 0.05002223770134151, 0.05914131419558544, 0.0483317366160918, 0.07288503940799274, 0.06265486765187234, 0.05876783579878975, 0.05981144015095197, 0.039036173693602905, 0.025978395169659052, 0.10159145997022279, 0.04191622247162741, 0.020327530619397294, 0.018132935001631267, 0.027607348092715256, 0.05309905951435212, 0.06695999210933223, 0.041651164428913034, 0.021835986590303946, 0.028431412174541038, 0.017789899502531625, 0.0348645727353869, 0.04887357492407318, 0.059512117150006816, 0.026462765272299293, 0.04954831332725007, 0.05661909563059453, 0.052758784804609604, 0.06880758359329775, 0.058491370946285315, 0.05125776515342295, 0.021689577552024275, 0.0647522734652739, 0.004223185324008227, 0.01359943129500607, 0.04806391407328192, 0.07289620873052627, 0.031175861295196228, 0.020285886857891455, 0.03820942860329524, 0.01967648342542816, 0.06683479179628193, 0.06161983510537539, 0.03461444670392666, 0.006178736102810944, 0.045131106016924605, 0.08099599363049492, 0.05438861531729344, 0.053330668961280026, 0.036201180701027624, 0.051392862005741335, 0.0243998693258618, 0.04014903897768818, 0.03603024553740397, 0.03343323704029899, 0.02497004283213755, 0.04665392254537437, 0.07926179489004426, 0.04503740987274796, 0.006181244098115712, 0.0720124963845592, 0.021334702942112926, 0.04393976603751071, 0.05544301420741249, 0.027544399126782082, 0.02017976345086936, 0.03347091216710396, 0.10424706473713741, 0.28061497199814767, 0.11609125926042907, 0.06820754235377535, 0.1551724664750509, 0.07943761709611863, 0.17909933725604787, 0.10884311108384281, 0.23476459871744737, 0.17149658349808306, 0.13715184439206496, 0.13737640343606472, 0.1418222687789239, 0.12539796181954443, 0.156051570083946, 0.1438229059567675, 0.07616450093337335, 0.09806075919186696, 0.20742107299156487, 0.12786161008989438, 0.15028003603219986, 0.14321539871161804, 0.12129200011258945, 0.12206014522234909, 0.14487225824268535, 0.0881964439759031, 0.11523510285769589, 0.1970849744975567, 0.15077078860485926, 0.08998735022032633, 0.13317197357537225, 0.09728340402944013, 0.24724269867874682, 0.3019085247069597, 0.11575404219911434, 0.12483002588851377, 0.10109789465786889, 0.16166127141332254, 0.10398659316706471, 0.1263802536414005, 0.11289330781437457, 0.14252586930524558, 0.1962316530989483, 0.14039743429748341, 0.15739530266728252, 0.07929793748189695, 0.08352838704013266, 0.14393011661013588, 0.1304853247711435, 0.18465572269633412, 0.09160794099443592, 0.18375039158854634, 0.14361872628796846, 0.1727378848590888, 0.15033258008770645, 0.16746192733990029, 0.12752402195474133, 0.11266349436482415, 0.13529286836273968, 0.17473289655754343, 0.13728176476433873, 0.15606719971401617, 0.08045133887208067, 0.18867748032789677, 0.2243312491918914, 0.1359816556214355, 0.14992088108556345, 0.06456252114730887, 0.23200072202598676, 0.08466215862426907, 0.14441171108046547, 0.15947469655657187, 0.09951124971848913, 0.10474126087501645, 0.17416395130567253, 0.20201969251502305, 0.11511920165503398, 0.15803239191882312, 0.1799087383551523, 0.22616895526880398, 0.14534015266690403, 0.0919373135548085, 0.16629469231702387, 0.24365750199649483, 0.15933588525513187, 0.18564706871984527, 0.14172727387631312, 0.19412554189329967, 0.2091655059484765, 0.09010644265799783, 0.09736124047776684, 0.12258570452104323, 0.13307779503520578, 0.14895369939040393, 0.21068040747195482, 0.10951907403068617, 0.11416107416152954, 0.21100202458910644, 0.18531805981183425, 0.1104401535121724, 0.13602098944829777, 0.21988894615788013, 0.10460937381139956, 0.12857698107836768, 0.15719265182269737, 0.11476949424832128, 0.13001797953620553, 0.21341513260267675, 0.08121045204461552, 0.1612155672046356, 0.2626143879024312, 0.1444509855355136, 0.1643602695548907, 0.17399321281118318, 0.09264475098461844, 0.1687323654186912, 0.1745314331492409, 0.11626763807726093, 0.1601069766911678, 0.19924328837078065, 0.12167891880380921, 0.21140673256013542, 0.11730718659237027, 0.11249092276557349, 0.12738990102661774, 0.17913046292960644, 0.12052366946591064, 0.13801603083265945, 0.1337629309273325, 0.11537974001839757, 0.10432088616653346, 0.19193101121345535, 0.21150036191102117, 0.11971295476541854, 0.14154742180835456, 0.1469748219824396, 0.17215518018929288, 0.2549813693622127, 0.13411224499577656, 0.09989521466195583, 0.08580683235777542, 0.13698518770979717, 0.13032085000304505, 0.11934111651498824, 0.12707705609500408, 0.246744999603834, 0.2186481939861551, 0.1444883897784166, 0.14897614193614572, 0.12666131980950013, 0.12095612633856945, 0.1384184678317979, 0.18147336377296597, 0.14773161965422332, 0.2177278121234849, 0.12357048253761604, 0.10345252143451944, 0.1479378921794705, 0.18439653504174203, 0.12676296435529366, 0.13275553967105225, 0.17833157064160332, 0.10807169310282916, 0.21472616615938023, 0.12598602479556575, 0.07848063251003623, 0.1554528795531951, 0.13522012304747477, 0.054259767348412424, 0.15643897117115557, 0.122095931583317, 0.07483670226065442, 0.12593860155902803, 0.1453820097958669, 0.10431347211124375, 0.10575376552878879], [0.06395957811037078, 0.027546350975171663, 0.03967332602769602, 0.03285740465798881, 0.002050278508249903, 0.030823257657175418, 0.07922065022285096, 0.03474988123343792, 0.05275373448967002, 0.015459882342838682, 0.005146408684595372, 0.032443835443700664, 0.09396475710673258, 0.032542619010200724, 0.031107798931770958, 0.05770100964582525, 0.005719329992643907, 0.04138790609431453, 0.05079001544800121, 0.015366932057077065, 0.056284286838490516, 0.08692758667166345, 0.029732632683590055, 0.073176414007321, 0.019639858437585644, 0.048176724230870605, 0.04078141188074369, 0.06523216841742396, 0.04386783708469011, 0.03904181401594542, 0.031690132527728565, 0.028261868537811097, 0.03242000508180354, 0.08520563336787745, 0.03140556342259515, 0.015103123605513247, 0.0631386143504642, 0.07654001281480305, 0.01739007671858417, 0.018811471345543396, 0.025255704749724828, 0.04439250951691065, 0.0213205000909511, 0.04057169579027686, 0.005010386930734967, 0.0417796042165719, 0.02778525944449939, 0.03593780362280086, 0.027639870859275106, 0.02756755413429346, 0.08391091221710667, 0.06660743485554121, 0.02196528726926772, 0.04921556399494875, 0.026572092901915312, 0.0053531826233665925, 0.010307805041520623, 0.024455693674099166, 0.04508225043537095, 0.01634681932046078, 0.02214763851952739, 0.013636665771628032, 0.034945815641549416, 0.023887492425274104, 0.03831375972367823, 0.021697932279494125, 0.025714559815241955, 0.03909530059900135, 0.11219198568142019, 0.04553087870590389, 0.07078372989781201, 0.03603204895625822, 0.01111351859435672, 0.03970554636907764, 0.02577226365247043, 0.06589428288862109, 0.016341282898792997, 0.066822650260292, 0.014966984035709174, 0.02283498972246889, 0.04810598271433264, 0.05737784886150621, 0.03786638568271883, 0.00908385509319487, 0.058355888177175075, 0.04470198509807233, 0.033752267772797495, 0.053540882290690206, 0.06186676248034928, 0.018426907117827795, 0.014498072869173484, 0.022598767827730626, 0.04481795309402514, 0.10434476847876795, 0.0569771744630998, 0.024377519548579585, 0.027140672646055464, 0.029736091091763228, 0.03607883394579403, 0.029193078335083555, 0.0463435378333088, 0.008227820217143744, 0.052317244044388644, 0.007529138274549041, 0.05597635492449626, 0.03565371691365726, 0.03182011227181647, 0.006339327119349036, 0.008337683120771544, 0.04953614952682983, 0.03879612231685314, 0.013186744308768539, 0.004229482447044575, 0.032288017828250304, 0.06746388811734505, 0.03261958343500737, 0.06699114746879786, 0.048175737174460664, 0.04644758693757467, 0.05630727857351303, 0.04309071198804304, 0.03215458709746599, 0.04187163052847609, 0.021022661385359243, 0.10110775780049153, 0.06042318505933508, 0.08291935839224607, 0.03413587277464103, 0.02244583716674242, 0.005816834282086347, 0.0489591556834057, 0.042812959509319626, 0.017382658952556085, 0.018326321987842675, 0.014902539642207557, 0.09636884802603163, 0.02035526282270439, 0.04281973160686903, 0.03228148321795743, 0.031149095739237964, 0.013545207202696474, 0.018142180306313094, 0.0787187134847045, 0.01676180232607294, 0.018806038824550342, 0.020473986041906755, 0.059441691046231426, 0.014126509213383542, 0.11420017050113529, 0.02090617759677116, 0.02832016980391927, 0.05821204511448741, 0.0559608551702695, 0.02576551567472052, 0.027652248027152382, 0.03559154720278457, 0.07971200393512845, 0.06965073014725931, 0.014732713061675895, 0.05777279016911052, 0.04266709780495148, 0.01911838466185145, 0.09267419940442778, 0.025170595254166983, 0.031133696174947545, 0.035350141406524926, 0.02014472851442406, 0.022343532109516673, 0.06731021159794182, 0.03150927856040653, 0.033163184343720786, 0.00986230585112935, 0.025359572027809918, 0.03277796888141893, 0.109566430473933, 0.054922950512263924, 0.034715289730229415, 0.03407058604352642, 0.04617476603016257, 0.07315474329516292, 0.008511130454280647, 0.026781152191688307, 0.0683521646715235, 0.04670375034038443, 0.06359408522257581, 0.0484924152988242, 0.05676610024238471, 0.07734150261967443, 0.06321325956378132, 0.03993518170318566, 0.025563298986526206, 0.010310455436410848, 0.03054952947422862, 0.02035999215877382, 0.09781592467334121, 0.03228711611882318, 0.030154782980389427, 0.08208308412577026, 0.03334332584927324, 0.07564765444840305, 0.03052709434996359, 0.11493788013467565, 0.05982548900647089, 0.05014822098019067, 0.009051593006006442, 0.06311463555903174, 0.07294539827853441, 0.011206312101421645, 0.07385076649370603, 0.0238604262995068, 0.028984182317799423, 0.013769280139968032, 0.0032583339725533733, 0.08350013347808272, 0.05932051317358855, 0.03724451788002625, 0.041468451381661, 0.030572346804547124, 0.060749993499484845, 0.025776807451620698, 0.016184650776267517, 0.09771874043508433, 0.021824277355335653, 0.010878315297304653, 0.06269418663578108, 0.048696253579691984, 0.05603913690720219, 0.062489591364283115, 0.037905285353190266, 0.04793664316821378, 0.04557529995508958, 0.04108305038243998, 0.020330664337961935, 0.005314201780493022, 0.07580894540296867, 0.014963074772822438, 0.01875631307484582, 0.05501816063770093, 0.029718368605244905, 0.05607765808235854, 0.06868043885333464, 0.018403360627416987, 0.01817748798202956, 0.09118028581724502, 0.009951018473657314, 0.06337118858937174, 0.07226734989671968, 0.021495255459740292, 0.04070594659424387, 0.03581190940167289, 0.04070105584105477, 0.01627125941013219, 0.026721682042989414, 0.016708519833628088, 0.05127929114678409, 0.040382221777690575, 0.01886414898763178, 0.03189541428582743, 0.03489957241981756, 0.1189024701307062, 0.06595102007850073, 0.06355733406962827, 0.02824189363309415, 0.023567986718262546, 0.017657272146607284, 0.032385814338340424, 0.0409296929865377, 0.04024665366159752, 0.04548070581222419, 0.026158818691328634, 0.020780730519618373, 0.044796816728194244, 0.04635162353224587, 0.0705374036624562, 0.04866685711022001, 0.011816067126346752, 0.05183993918763008, 0.01669281227805186, 0.03149757860228419, 0.0690414417476859, 0.06854158302303404, 0.025629040283092763, 0.03044039294763934, 0.00266490921148943, 0.02397167423623614, 0.04337137368565891, 0.029161999045754783, 0.04784715500136372, 0.031152502197073773, 0.02278005409607431, 0.05322343233274296, 0.07158917534979992, 0.04759899195050821, 0.015990464125934523, 0.025159925025945995, 0.06304845082922839, 0.023758032184559852, 0.0646506437624339, 0.004123199478271999, 0.0656190277368296, 0.06914801415405236, 0.04184415622148663, 0.0771440913376864, 0.017442617063352372, 0.010466578260093229, 0.032947371510090306, 0.08608677788288333, 0.019093903065368067, 0.02757918173301732, 0.0327710038254736, 0.03941713664971758, 0.019712054563569836, 0.060755444574169815, 0.005205621864661225, 0.04504850869125221, 0.009009782261273358, 0.018480590370018035, 0.026066822065331507, 0.029555892069765832, 0.026433710190758575, 0.03725883761944715, 0.03468160364718642, 0.028711912455037236, 0.028252962765691336, 0.03384744079085067, 0.08817190857371315, 0.041793371055973694, 0.034689778403844684, 0.028901419864268973, 0.05033076333347708, 0.027216818853048608, 0.0482995125639718, 0.04648220812669024, 0.03718055217177607, 0.005157482455615536, 0.09286260101362132, 0.018446097201376688, 0.02349184978811536, 0.060245440690778196, 0.060201624291948974, 0.029952764816698618, 0.035242656158516183, 0.05683739094820339, 0.04393023315060418, 0.0934791105100885, 0.03262305668613408, 0.037236261487123556, 0.04399362740514334, 0.01481330102251377, 0.04284635615476873, 0.08634193567559123, 0.023727095758658834, 0.14698001701617613, 0.14445006527239457, 0.22485419613076374, 0.1680873945588246, 0.111426972434856, 0.15715153684141114, 0.1617762746172957, 0.1366300997324288, 0.12983604945475236, 0.16419665567809716, 0.09079749346710742, 0.07928322811494581, 0.21882546338019893, 0.13612061535241082, 0.14218712341971695, 0.15433228109031916, 0.08045576207223348, 0.07434766404912807, 0.22029105661204085, 0.08426398155279458, 0.1754288826487027, 0.23524953285232186, 0.11057974406867288, 0.1252363814273849, 0.11039733901270665, 0.14086900977417827, 0.18966222123708576, 0.11817541773780249, 0.09211106516886503, 0.1862915646051988, 0.1848770905053243, 0.07672647741856053, 0.14864394179312512, 0.15033906645840034, 0.236211578885559, 0.07902180659584701, 0.16840969445183873, 0.1438046936527826, 0.15271499287337065, 0.1400203342200257, 0.1538467829232104, 0.14549952145898715, 0.19978959811851382, 0.16637784254271537, 0.13093099929392338, 0.2287201621220447, 0.11692772648530081, 0.09418772053322755, 0.12249697334482335, 0.140799708024133, 0.16730699659092352, 0.19705493235960603, 0.13735727086896077, 0.10307996330084279, 0.15403491735924035, 0.1488196081481874, 0.12293199804844335, 0.09767056020791642, 0.21547431038925424, 0.07099235503119417, 0.05274972689221613, 0.15242579276673496, 0.08717579054064117, 0.08798675757134333, 0.12650598830077797, 0.08206458238419145, 0.09210428193910047, 0.32210013654548675, 0.21069214824819937, 0.2089277218328789, 0.11309019959298894, 0.20737036946229637, 0.1551231581834145, 0.1803254839614965, 0.13111422071233392, 0.1286435517249629, 0.1486667405697517, 0.1459215659997426, 0.20135140337515622, 0.117917068710085, 0.15017822821391746, 0.15090768516529351, 0.07110803358955309, 0.1412308364524506, 0.16226914973231032, 0.15214365790598094, 0.20898047368973494, 0.12444548949133605, 0.14487167936749756, 0.11969126921030693, 0.10044651164207608, 0.1519275296595879, 0.10410327362478711, 0.16366035008104518, 0.15721562871476635, 0.12030927784508094, 0.11610472924076021, 0.14172647235682234, 0.08909709955332801, 0.17144677054602653, 0.12949086172739044, 0.14334376057377085, 0.1973595394520089, 0.11184280519955792, 0.14467063156189397, 0.11706918725394644, 0.13407826947513968, 0.11685537450830452, 0.15399625146528706, 0.27777334791608155, 0.08788968465523794, 0.11727191973477602, 0.10767784275230952, 0.2066266632755287, 0.16763857332989573, 0.20482965657720342, 0.2231066461536102, 0.10502916964469478, 0.15446960809640586, 0.18040820374153554, 0.13929368258686736, 0.15626783191692084, 0.10063561829156242, 0.09193818186759017, 0.13622162165120244, 0.19264710950665176, 0.16831860324600711, 0.23216782399686053, 0.18501863291021436, 0.11319609664496966, 0.15475769498152658, 0.11730989543139003, 0.1456712544313632, 0.13624802726553753, 0.1886538355029188, 0.1527911372249946, 0.1067510932625737, 0.1216223523078952, 0.10543662356212735, 0.1903979864437133, 0.09977801470085979, 0.23558973334729671, 0.137998026330024, 0.10657989463652484, 0.0707815182977356, 0.07679407965042628, 0.14689134521177039, 0.09235049685230479, 0.19322516833199188, 0.20013532019220293, 0.10794390269438736, 0.1657981361495331, 0.14942178677301854, 0.24458235158817843, 0.09120767848799005, 0.21025051100878045, 0.19228154240408912, 0.17075428739190102, 0.1258383522508666, 0.19020398904103786, 0.23727007443085313, 0.07073745699017309, 0.260329790180549, 0.25330586708150804, 0.10821483112522401, 0.16469349386170506, 0.12149235772085376, 0.1851494438597001, 0.2577418024884537, 0.18220203404780477, 0.11678747541736811, 0.14735241187736392, 0.13941735407570377, 0.11954557077842765, 0.23592000390635803, 0.11394335771910846], [0.023667974419367965, 0.042747305415105075, 0.020183164342597593, 0.05414938030298799, 0.01202497520353063, 0.04415895564306993, 0.03128187709080521, 0.05451678422105033, 0.03916804591426626, 0.048857214278541505, 0.07992623228346929, 0.05344910459825769, 0.03050486702704802, 0.08943134060245939, 0.035193715229979716, 0.02319785169675015, 0.043578677796176635, 0.002608100126053614, 0.01235899917446659, 0.04617481055902317, 0.012489848159020767, 0.01709408224996878, 0.01838466963818064, 0.030207004201656673, 0.036586340502253734, 0.09121970128035173, 0.03497789126413409, 0.01392575548379682, 0.0492291861155536, 0.019088322114839684, 0.05375853565055877, 0.025950015442504082, 0.05266298838250805, 0.019109632885374594, 0.05492903612321243, 0.03605330777645577, 0.008070650037552696, 0.09141938353423029, 0.03502157036564313, 0.0361524290201487, 0.015851827229198534, 0.05499220031197183, 0.030475420462607872, 0.04275976236385759, 0.028506025846581906, 0.03663188610516954, 0.04294753685826436, 0.030480771347356495, 0.018038311172858812, 0.04003181304142345, 0.06841110604000278, 0.05478253246110398, 0.047979732262319885, 0.05325853962858673, 0.01676185984251788, 0.05186013673665002, 0.03793435527768452, 0.022959887610340957, 0.04482580872718245, 0.07658410380827263, 0.06764345816918649, 0.027059826788899954, 0.028118671143602114, 0.022793306998210028, 0.044141069884062745, 0.04055791039718315, 0.04542176073300652, 0.0638079053896945, 0.032408950792159885, 0.031626600975869223, 0.030817450351605657, 0.014423218926822301, 0.05605144542641938, 0.03246107553422917, 0.04875531369179953, 0.04845466966798995, 0.0655630994879175, 0.03874437607009895, 0.019789493962889537, 0.09884183993563056, 0.023477329668821767, 0.03365002579812426, 0.02285248956468422, 0.01699870885204291, 0.015568820344924461, 0.036209032623446546, 0.0693164742551744, 0.031280355688068084, 0.042332114608143456, 0.03917679583537392, 0.02470964547683252, 0.021541112764680292, 0.0479759881272912, 0.03038673567061778, 0.0376498084369814, 0.044277458073338494, 0.030019300211279187, 0.0622966923401691, 0.05174171594262589, 0.05153629317646846, 0.02398745229584165, 0.004483302518565324, 0.041557442309567705, 0.03660576621768996, 0.01575976380991051, 0.036003936402266845, 0.02276566570799332, 0.05424313581897877, 0.06918697690707631, 0.04857745429035276, 0.015566619877063204, 0.023703274673607666, 0.027144082814629655, 0.023157731193350628, 0.01349757152638631, 0.04708459084213246, 0.06547396755195223, 0.020082614464627113, 0.02697905514651211, 0.022801804589107633, 0.05769102033809759, 0.037585386307910085, 0.06435630799387582, 0.01701321412838297, 0.044143997656647116, 0.04718102180049755, 0.07362332791672088, 0.02354333999392111, 0.038268926582532004, 0.028836621095251758, 0.06595142825972289, 0.03520040940202307, 0.024306436644110363, 0.04166901679127477, 0.0652705151878763, 0.009328723936050665, 0.07590963257825933, 0.053684888625866733, 0.004562168696793378, 0.04857209227338899, 0.037900097740930505, 0.05304438920575194, 0.042680526967160404, 0.043488124647410586, 0.046405340181081556, 0.03993668084149249, 0.02803515726554906, 0.03366616751009133, 0.010560765149421059, 0.023857567175582517, 0.006393985831891769, 0.017441277486796025, 0.06152217960334383, 0.06321578286588192, 0.04021472646854818, 0.04813537176232785, 0.041337829679832794, 0.03709335724124685, 0.02793320658383891, 0.03626805933890864, 0.025110592614510097, 0.030610047906520776, 0.04696275616879575, 0.006493636319646612, 0.03058614889596356, 0.09432627208298072, 0.024019513075472787, 0.037249846500344574, 0.06231726467376575, 0.04447232007805724, 0.04237835782987531, 0.049653412570478395, 0.009175169871014077, 0.04162588687904645, 0.06537534354720265, 0.05240685095486697, 0.04242963652359322, 0.06797599227866158, 0.04313546349294484, 0.021699461103708018, 0.07078836832079105, 0.06665972658083774, 0.05824026156915352, 0.011926203696930315, 0.036319749924587086, 0.050859962866525166, 0.1231854414800182, 0.041918801434803754, 0.03866110710077919, 0.03200607592589222, 0.05751718708779663, 0.028207320683577564, 0.0246630404581083, 0.013357823263504542, 0.008991962367872475, 0.019574191355786752, 0.026882720667344984, 0.01463390166463796, 0.019802583592536394, 0.037477537407539785, 0.01151622647739714, 0.08811556472210214, 0.042373277829028666, 0.07792244097799994, 0.02645115993800573, 0.04251784077496268, 0.011768270032916917, 0.07979748450452462, 0.02782314422802301, 0.010354808036936447, 0.026712204817158636, 0.06123730621766299, 0.03760296407563146, 0.009189680713461712, 0.02883419056161074, 0.019244807663199026, 0.06980659600230865, 0.02862974928575568, 0.021996539107931312, 0.022955418025958352, 0.03277723786595743, 0.06938269609236158, 0.04914832170470618, 0.07796389734721743, 0.05825543477840256, 0.017844304493337404, 0.031632374884793535, 0.050741096783895046, 0.07120755559299141, 0.017507627344457433, 0.03776696015847847, 0.049911524110939354, 0.024640174888190813, 0.061227372571011074, 0.03096344749792479, 0.051357480115257204, 0.08901254666852765, 0.06376702047418803, 0.05839442048454657, 0.011552397827472305, 0.05408843884652015, 0.0657106532889884, 0.030583054140151944, 0.03810618101852015, 0.03889885781973135, 0.05450544420455117, 0.018504851177567616, 0.008371745843760436, 0.04327002970967442, 0.03630657680332661, 0.024230283015640453, 0.03653149207821116, 0.039781972736818716, 0.011898832362930989, 0.033613846098887734, 0.03646833160019014, 0.016544479221920483, 0.03123513663013, 0.056376353968516923, 0.01151265210864949, 0.026024105900432914, 0.06012695681420155, 0.02609806277177995, 0.03627929916547146, 0.10852584295207635, 0.03658726447611116, 0.007494396022593719, 0.03202728650649078, 0.05831172296893783, 0.05264318417175673, 0.010448404918861343, 0.0843311681819614, 0.007535668710261234, 0.02157285256544128, 0.021952303395664785, 0.052108900927123614, 0.04874801466939971, 0.029670592848560773, 0.049560848201508634, 0.07989783029188402, 0.051265045622130856, 0.011583120885916287, 0.04343215929111466, 0.016211017427849583, 0.023585913295391947, 0.060109174955869094, 0.04998802840418648, 0.01983041969651822, 0.07640753945452161, 0.01722704171697842, 0.03128127966192551, 0.03927283345547039, 0.04704556500655599, 0.00888507733179722, 0.036347498826216906, 0.026419689165777527, 0.05697645086911507, 0.015185019601631211, 0.08856778498739004, 0.024486090187565424, 0.04030762109323405, 0.026246045163134113, 0.08136962045682594, 0.01948714485479286, 0.020412300582393073, 0.0411318020633189, 0.07404401432722807, 0.024000048397283535, 0.02399727833108045, 0.12487857718952, 0.0581337670882931, 0.04448892563232221, 0.07405733587802388, 0.01145189989983919, 0.011387133599782828, 0.04615132900653407, 0.013967096820124425, 0.04261737391061615, 0.06700969373923726, 0.051500343543011695, 0.024720217370486353, 0.03488871479930822, 0.025680198377813213, 0.046763485806877725, 0.022400801790354308, 0.07771931515890174, 0.04280473651306238, 0.010848027322936105, 0.017351099122606684, 0.036097187257837504, 0.04508902995439712, 0.013821493012073915, 0.025561141192156356, 0.007290395396921667, 0.05355803332349751, 0.04032204102259129, 0.0598591268499149, 0.04056355814100243, 0.0665037939324975, 0.028697635389107745, 0.035281344316899776, 0.05042377299105283, 0.024785390924080275, 0.028747208998538554, 0.033329651778331026, 0.048895746585913, 0.02916187102528056, 0.03865600854624063, 0.05054837587522343, 0.04983676757547073, 0.0685268291272223, 0.04275976607459597, 0.13803274399833754, 0.11884720239322633, 0.12716623255982995, 0.11678066992317326, 0.12714690703433007, 0.19583133864216506, 0.20040388859342784, 0.17514150822535157, 0.11492232471937314, 0.1679835977847688, 0.18162148160627112, 0.08437456155661494, 0.08806545491097495, 0.23928928014356643, 0.1122450121329166, 0.15899893536698073, 0.142299811122939, 0.09317430303781293, 0.14366110292030498, 0.10684045526431873, 0.15311208640923724, 0.12961070373421535, 0.12117687074351124, 0.16569071769481525, 0.06775582674890757, 0.14797063573496416, 0.15825454640435055, 0.16985514579573646, 0.1260908308904618, 0.09465818278840743, 0.11339990523993038, 0.10295415442669764, 0.11875100521137938, 0.06727328975102864, 0.09908823296427727, 0.18062485149130225, 0.15929503744700924, 0.20802733342861757, 0.15732487285276875, 0.12172941453172825, 0.10604803450405598, 0.13082494639093056, 0.08768864427111112, 0.0839455185632687, 0.11806532755144872, 0.12923784874146804, 0.13598817167803645, 0.11641240140306763, 0.13156883069314063, 0.15276440506568179, 0.11569443289772607, 0.16619597183307633, 0.13125659432262182, 0.087818052561488, 0.10646739247022197, 0.12983509950572625, 0.09449829449295066, 0.17598947131773457, 0.11252470532781444, 0.1450944721000269, 0.14933850296074525, 0.1682377388351597, 0.12063640169799328, 0.10036081584985368, 0.18017006339505315, 0.2023596703656949, 0.17691935267066583, 0.1606582142994739, 0.17473303014412522, 0.13892893184674904, 0.14282954129157588, 0.10525214049266651, 0.21862621157197282, 0.09444762807106599, 0.1222769933519885, 0.11875668264110573, 0.09174557970254682, 0.16249559383140877, 0.09999918212997727, 0.10455608760821633, 0.11508686628076248, 0.116969954688102, 0.1400471999659203, 0.09152730664936826, 0.14973798621213064, 0.2016391043434851, 0.09964290671632625, 0.09409093705471605, 0.11924392485525459, 0.12220507182064466, 0.12302816554438323, 0.13727478857617825, 0.20489293208811432, 0.09513762503047474, 0.1573815432493575, 0.17128369101556018, 0.17202172719407827, 0.12966988258995116, 0.11777105857618153, 0.1473310380242765, 0.1525465550366789, 0.14273582288296893, 0.16618080233456567, 0.11001541497535072, 0.1439315266907215, 0.11803504050476477, 0.15003453358076513, 0.1335205158102326, 0.08971227318397723, 0.3600311261834577, 0.11942813333007507, 0.1456100124050863, 0.17511918442323804, 0.12333678023424, 0.13665677251992747, 0.13776620908174664, 0.27495873800944537, 0.1106286293361336, 0.1491998994606547, 0.13877486198907718, 0.1553361545666121, 0.10828559490619227, 0.27718173747416586, 0.09685496217571199, 0.11061312587116845, 0.13117241993313655, 0.1430243847426027, 0.08654045275761746, 0.10623660680721514, 0.1748842204688117, 0.18003306293394417, 0.1947639521677047, 0.15661631477996707, 0.176764614880085, 0.19100430625258014, 0.11609591994783841, 0.13005444867303595, 0.11031785499653779, 0.12785144266672432, 0.09085647194297053, 0.17433228524168953, 0.17565382760949433, 0.1718881109263748, 0.10754105009255, 0.10988516805809923, 0.16081961657619104, 0.17584421817446128, 0.1288584480062127, 0.06368495378410444, 0.107334866625024, 0.09941580952727236, 0.0988427601987496, 0.1358423545025289, 0.12443116604117677, 0.11133911699289456, 0.14109088224358857, 0.15543631481705233, 0.13086474034935236, 0.10000215072068386, 0.15730796672869474, 0.234525790438056, 0.1340747220092453, 0.16023180593037978, 0.1287024634075351, 0.09492540790233761, 0.22373763495124876, 0.1330080776824616, 0.16026934375986457, 0.16195195581531152, 0.09565850137732923, 0.13378363684751093, 0.13434158347081393, 0.12801428470993415, 0.12125785389798693, 0.1040961935359519, 0.12924725917400792], [0.018106284478562884, 0.03392888407688588, 0.03864913996949326, 0.03684694194816984, 0.035920448499382474, 0.03391308004211169, 0.051749296981142834, 0.07561212783912197, 0.029341758345253766, 0.007882281825004611, 0.11318368051433936, 0.030570981252822094, 0.02934641161118634, 0.046865516269463114, 0.02402985675871605, 0.02780782073386945, 0.0475131440180121, 0.0223986569835688, 0.02611988933495013, 0.06419018565793522, 0.07836595585104078, 0.05715894127206411, 0.029110809409758076, 0.0021045582616352476, 0.0708718154055532, 0.024526772867830005, 0.07411554994178005, 0.010863428742595715, 0.04407118925882969, 0.013220983291830635, 0.06930395422386937, 0.04882937631919049, 0.02480801715137204, 0.06918351849890314, 0.006319393496596604, 0.05626303915050812, 0.05325490310497116, 0.035030435319640674, 0.030493532576656435, 0.048324979361495934, 0.0633664611086715, 0.06446868399507366, 0.02325130859389901, 0.014702581866004039, 0.04186217556707561, 0.052500339297694154, 0.051796349143842235, 0.025778985655051656, 0.015212650687317364, 0.018194523981946986, 0.06541262162500061, 0.048363148016505875, 0.08781345124589279, 0.05246106484264601, 0.012489292475947877, 0.0724056491162628, 0.024847822242008988, 0.01871016633231193, 0.03876801347360015, 0.019570289514376782, 0.07598895332193933, 0.02574371508671902, 0.05790919691207819, 0.0352811179618584, 0.03080660757404985, 0.041937540663639084, 0.012026677504763938, 0.033129568764707074, 0.03525774031004403, 0.02832618120010011, 0.01823554433940444, 0.05173276564164553, 0.10104707980644889, 0.06861547866719775, 0.04066339555720333, 0.01751012652675854, 0.009134170850302326, 0.019629917369456962, 0.04276837127690669, 0.038894931858521886, 0.00768658722336113, 0.044923419700353406, 0.009042262354341801, 0.01353041527181631, 0.055175566449179314, 0.047439155605388805, 0.023421987716574222, 0.05934002052526921, 0.027390960094635375, 0.040094765718095005, 0.0616230189189082, 0.07845458312658593, 0.03207773399481084, 0.09983744588680565, 0.04747736507852096, 0.031122510154091287, 0.02262430698465323, 0.05634388871840201, 0.018584281388029922, 0.05329529449227266, 0.0036474651915341383, 0.04856329411268234, 0.028546547109726816, 0.06314627331448719, 0.07894624111941084, 0.03426742216106504, 0.06221774638106581, 0.046421645165537484, 0.03897920272720512, 0.10391214091214351, 0.034624562176759355, 0.022207355432328768, 0.05815922275360208, 0.0030883153613103786, 0.06669025111477822, 0.058933958134730347, 0.03059329763345886, 0.07813364136382006, 0.011762987796828384, 0.04036793172417674, 0.020325489713286515, 0.005970091951894574, 0.02883640587242553, 0.015606981578457635, 0.01859419462562073, 0.01735975998599315, 0.05061406336608343, 0.0248535961509333, 0.009697388577478705, 0.05593532900093123, 0.03537155978847295, 0.09549390786560252, 0.04475408757571131, 0.07135697960620746, 0.027217470087634865, 0.05695419014955405, 0.023197157788672484, 0.011642301597021287, 0.021860017332073767, 0.10319470675312914, 0.03980128341936506, 0.05475565187225584, 0.012373833778838161, 0.04754323068482336, 0.0491120418155333, 0.03674780215078499, 0.027121460298076272, 0.0115431478843675, 0.025318464468000457, 0.02503251682355767, 0.022463641289505176, 0.09414820116944611, 0.06231973602552898, 0.053295806574169546, 0.020635137843783014, 0.026386387144157197, 0.02876506136090029, 0.11340978322550654, 0.008293243317893939, 0.046485647981171496, 0.04089429996383842, 0.05345296005543787, 0.0054766824905527756, 0.042365173576399684, 0.01793648294551531, 0.009321038996858988, 0.03372424056578893, 0.023381071259791497, 0.08327123287017457, 0.056071134604280815, 0.07845288360840641, 0.04810164486116264, 0.04219985275994986, 0.029762999511149246, 0.04680086036387365, 0.06770651103579439, 0.019335340402903967, 0.043855840267497115, 0.009591287434886908, 0.05176893049792852, 0.03266004532633815, 0.03713100639288314, 0.05415651234216057, 0.05171460528799798, 0.018645838827069383, 0.03153911660774611, 0.023584475384268444, 0.03617928363382816, 0.007975926946528489, 0.08654690202092752, 0.038593657009187154, 0.049592133436817676, 0.019582928289310075, 0.07364427132415585, 0.051283922148286365, 0.009786659666133346, 0.05339052317140158, 0.03281173288996797, 0.0022732546904080664, 0.055856550025055185, 0.012971462110726861, 0.031087360184756108, 0.06527231860673055, 0.022102463990449905, 0.0432439617725322, 0.03934636915801093, 0.01918852503877133, 0.04422908488777466, 0.10341099085053429, 0.031015232707432006, 0.06276797837927006, 0.010917123127001105, 0.04823252260393929, 0.08357086015166715, 0.0305416552873794, 0.05791569441498723, 0.03506645545712672, 0.09328776999609545, 0.00227105399062566, 0.021110509405843914, 0.0435632596781943, 0.04162329307291657, 0.07161397050367668, 0.020989053227822296, 0.031609539000783116, 0.07943047021399252, 0.03264542872784659, 0.04161933742580004, 0.038939111909712665, 0.04194528126390651, 0.021824377545272, 0.024723109891056083, 0.002895139191423368, 0.04032024873595219, 0.057818113127723336, 0.04190994761302136, 0.02520012902095914, 0.18797876313328743, 0.07180144442827441, 0.030846904337522574, 0.04743831326777581, 0.0337756825319957, 0.02510765742044896, 0.03114105827989988, 0.024116652784869075, 0.00699016419275722, 0.02298020390298916, 0.033434034849051386, 0.05848507753398735, 0.047020428464747965, 0.03776467805437278, 0.05236593264271505, 0.037562802754109725, 0.07220440835226327, 0.014303119951364351, 0.051138594790245406, 0.0717235411866568, 0.026768697098304983, 0.028253810669411905, 0.017340946542390157, 0.023749898246023804, 0.07689150879741646, 0.03712712124979589, 0.042134339673793875, 0.028697924826701637, 0.022157694620545954, 0.0475026982894633, 0.05139390101248864, 0.046715561620658264, 0.07932712615001947, 0.0015960328755681985, 0.015157296675170073, 0.048486214654985815, 0.07550724752945825, 0.04210136605252046, 0.03807529283221811, 0.010167787750106072, 0.010306901476724306, 0.023143576581787784, 0.014354276190715609, 0.03161581757012755, 0.07507754402467981, 0.11069045023759827, 0.10527291320613585, 0.028335691822576337, 0.06980791702517308, 0.02952170132630272, 0.048267774618580006, 0.018007914659392554, 0.012649236432480393, 0.05461352317070123, 0.00850098900627927, 0.04834950734220911, 0.01752069470967399, 0.02605649693578016, 0.041615923546487466, 0.05218259248067625, 0.0471722459042212, 0.03516064884024672, 0.05875453651242424, 0.07103062758687884, 0.04372027215140406, 0.02599294497485971, 0.014731535829923814, 0.022281243655015714, 0.07254952928633429, 0.02746054386079777, 0.012350699180387892, 0.05859156088263262, 0.06225685385288671, 0.022268276479735505, 0.029092435688653495, 0.015087837218743516, 0.04468334234843496, 0.018253769630973693, 0.04398104800202418, 0.042496522582951, 0.08447423198958859, 0.031150936265476048, 0.03185100416885689, 0.030248961520555895, 0.041037178234546445, 0.05101510512758978, 0.0697268225485459, 0.025471549124631565, 0.046379955019801855, 0.020772299722011667, 0.01949951831193175, 0.04217087560391519, 0.042804892364074476, 0.030263090156950057, 0.052771512637264095, 0.001588211334819789, 0.06486905040219426, 0.006026187647876213, 0.02774403870716924, 0.03648914884252008, 0.04451491935469676, 0.023502688854932785, 0.020022966200485826, 0.01879460789496079, 0.021351835421228316, 0.06099293183069676, 0.022609337866015267, 0.056970283621922135, 0.03894369467161596, 0.039784967302693985, 0.05048695944424253, 0.06003209920891095, 0.059731336441473104, 0.030937906485632993, 0.03412671467231121, 0.07782544227666222, 0.1601999084232375, 0.13536306068999693, 0.1419707280001603, 0.16370680852560326, 0.20103625778574497, 0.29433152347337455, 0.18507506581954658, 0.11327469750540331, 0.0835765375813935, 0.26108853227924556, 0.11542872176505625, 0.09999637681175955, 0.11959754338022321, 0.12059452972607687, 0.16838578245369717, 0.11442775750765577, 0.1321425405330956, 0.12690462550381199, 0.13995867659104988, 0.10394232405815274, 0.2062980699702166, 0.10667244787327945, 0.06859653163701296, 0.1639085984788835, 0.13506440562196076, 0.20971393823856488, 0.10463560873176903, 0.10238517948891968, 0.2040912938537076, 0.15518073400016874, 0.14793384005315602, 0.2085024118423462, 0.11208686788449995, 0.23053947777953, 0.14770577807212248, 0.07947513266117312, 0.27641097258310765, 0.24142878799466416, 0.1918802928412333, 0.1408507232554257, 0.15904149011475965, 0.060642582466243766, 0.14337178407004103, 0.1742928772000596, 0.16489476431161165, 0.14530874497722834, 0.09559719997923821, 0.14398574799997732, 0.2039193085511215, 0.10785788777866401, 0.13604525767732412, 0.1538980653276667, 0.17668943532044068, 0.09639347248594277, 0.16304601507727057, 0.14245964004658163, 0.1555942141567357, 0.1551554267643951, 0.14911321661202237, 0.131869830947835, 0.24849504319718108, 0.16252839675871655, 0.09233100063283928, 0.23484926292439923, 0.1183881914766971, 0.09003894432680681, 0.09260256731067784, 0.108161760144867, 0.15503751434152946, 0.13894799019908533, 0.0738320717937313, 0.15943421982228756, 0.14008549478603527, 0.1773535239044577, 0.16502281447174028, 0.1444970877491869, 0.147478191065602, 0.18689604388782755, 0.1719804637832567, 0.19260222441516817, 0.10403674008557573, 0.23867432173574343, 0.1559150594403036, 0.17611146555282176, 0.22158411535201594, 0.15633796487236395, 0.1699476025532931, 0.1046577692613937, 0.14267934544477612, 0.17916547745699063, 0.19038615660974756, 0.1459569516009651, 0.17881291278172284, 0.13288397574797273, 0.1472963797277771, 0.15565287350909784, 0.27911328070331365, 0.13268867216538638, 0.09879872857709415, 0.07623411438544281, 0.1621039179735817, 0.10433592207846232, 0.21942543040495366, 0.11032318361685611, 0.1177810256194789, 0.1429302804172039, 0.24156691652024165, 0.10410351111204363, 0.1775299324071966, 0.18526962725445628, 0.08099587488686666, 0.1369506778428331, 0.0756988552166149, 0.19426668353844434, 0.18021009484073147, 0.11350900836987421, 0.1683624048018828, 0.09190412471070886, 0.23662094754399732, 0.14036338456207886, 0.13381799828493968, 0.1617344026453793, 0.1324298555846326, 0.07776481623295695, 0.13435507571557537, 0.13868305832147598, 0.27977055637165904, 0.09854436488240026, 0.15085830265888944, 0.10171565096243285, 0.20341055147582665, 0.2680180541938171, 0.1632283310755156, 0.08956376943388022, 0.12123458756832406, 0.06268962984904647, 0.11236302845645696, 0.09176728752208874, 0.2344229881418869, 0.10993733361829072, 0.1454154954990372, 0.07081829171511345, 0.19202535302611068, 0.21544015675317496, 0.07914142595836893, 0.13974665984278545, 0.14844341349089518, 0.12747449101880193, 0.09496580300037749, 0.17103778780438006, 0.1652553293388337, 0.16143884975463152, 0.18289459141669795, 0.172624172992073, 0.16715133853722364, 0.13570997019996867, 0.15824129164684564, 0.13080646691378206, 0.1564141537528485, 0.14556637412169948, 0.11606691681663506, 0.1506662496831268, 0.08767358609475195, 0.10777563555166125, 0.07551999020506628, 0.1411948719760403, 0.10078118313685991, 0.20772720890818164, 0.15269152616383508, 0.15878638427238911, 0.21547901560552418, 0.14752206683624536, 0.15734983870061114, 0.15982154669472948, 0.1125935246818699]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.053222003698465414, 0.027223423967370763, 0.023140858465922065, 0.006571026087840437, 0.06635672994889319, 0.1197913997748401, 0.0327022846613545, 0.012478481239668326, 0.04005306072940584, 0.004593614885379793, 0.029302979273779783, 0.06528860874823295, 0.035117563456879, 0.01693792139121797, 0.07113154482794926, 0.04717099538538605, 0.008004181436263025, 0.10259058370138519, 0.11854036143631674, 0.02500707229046384, 0.02095708521665074, 0.03731043543666601, 0.015017124460428022, 0.027917539846384898, 0.027782263023254927, 0.05441634566523135, 0.03268078464316204, 0.036996885464759544, 0.042783455428434536, 0.009550477661832701, 0.016826866412884556, 0.04499599432165269, 0.04142837911786046, 0.03403350092412438, 0.009136217322520679, 0.09913595305988565, 0.06051870688679628, 0.05588934182014782, 0.008169286102202022, 0.007299861490537296, 0.03060457827814389, 0.015883721025602426, 0.030918421398382634, 0.05797108089609537, 0.05368017969885841, 0.024665699202159885, 0.026347676721343305, 0.06794915621867403, 0.06865596282295883, 0.0852735695661977, 0.030544351138814818, 0.008062649685598444, 0.07164714450482279, 0.06831055987277068, 0.07733420730801299, 0.040201638694270514, 0.005532827817660291, 0.0682662907638587, 0.031886185679468326, 0.03000390435772715, 0.024481991677021142, 0.010617193420330295, 0.024987884062284138, 0.012494449474615976, 0.1243591628735885, 0.060115420128568076, 0.02454512989061186, 0.03910544575774111, 0.010301815909770085, 0.042021763292723335, 0.03294088142865803, 0.024130347264872398, 0.021724577236454934, 0.032018005949794315, 0.040469735831720755, 0.02044904431386385, 0.018517951939429622, 0.03631142302765511, 0.010111655410582898, 0.01303445189478225, 0.07402862218441442, 0.027643275461741723, 0.02281819863128476, 0.021696601979783736, 0.028662947406701278, 0.02542647664085962, 0.05082701150968205, 0.04929756760247983, 0.062082501099212095, 0.021142421755939722, 0.0517828791635111, 0.04426049628818873, 0.008609523465565871, 0.06546510630869307, 0.022612688662775327, 0.05392999402829446, 0.04280438028217759, 0.026868753448070493, 0.05117683394928463, 0.006306964378381963, 0.05927575795794837, 0.017626276348892134, 0.0352413462678669, 0.025860334317258094, 0.06669045891612768, 0.03167223563650623, 0.0456643762299791, 0.029017384149483405, 0.055641104554524645, 0.04220899601932615, 0.036170129242236726, 0.0182901088919607, 0.004384485555419815, 0.0862935179611668, 0.04733944435429294, 0.06449790977058001, 0.018884721321228426, 0.04344192595453933, 0.060848569264635444, 0.10100748622789979, 0.044180878685438074, 0.048166200576815754, 0.052870685831294395, 0.029097736478433944, 0.036217763990862295, 0.03020364969415823, 0.04727315201307647, 0.03355448541697115, 0.024123525072354823, 0.09653499262640253, 0.030395279645745177, 0.020929219426761847, 0.05629651372146327, 0.07048897110507824, 0.021092413990118075, 0.023120236037357245, 0.010458217038831208, 0.05859233271621633, 0.030686657955811825, 0.07557336546597071, 0.051961302597192116, 0.018684562237467617, 0.015940320918161888, 0.03765077322896104, 0.019337958328833338, 0.02498135501809884, 0.04542724149359856, 0.11135695080156438, 0.031093137804418802, 0.018834568836609833, 0.020730628129967954, 0.016916237691475544, 0.05201412866881583, 0.040724210848566145, 0.020262449834262952, 0.0485624629072845, 0.01777949644747423, 0.0017527246018289588, 0.05473582539707422, 0.03339057839184534, 0.05574526498094201, 0.09205823167576455, 0.053976385679561645, 0.010627702231431613, 0.055724440317135304, 0.04665986343752593, 0.018444523848302197, 0.02977500931592658, 0.0666810039547272, 0.022728452568117063, 0.04547846081550233, 0.03254934286815114, 0.049942267578444444, 0.015295784214686137, 0.05121489870361984, 0.05313713540090248, 0.10231643434963189, 0.0671781538403593, 0.05017231480451301, 0.01281634211409255, 0.006459434907810646, 0.06402415980119258, 0.061063981338520534, 0.010982637140841689, 0.047049220083863474, 0.050416986050549895, 0.030667608880321495, 0.07801492742146365, 0.0456929043866694, 0.024591334149590693, 0.02773381376755424, 0.02317015103471931, 0.04656828983570449, 0.022954570122237783, 0.011603669099713443, 0.02346263328945497, 0.048345867107855156, 0.01712371435132809, 0.021438546100398526, 0.0295858878234867, 0.03939766269468237, 0.02815897903928999, 0.05271550646284595, 0.05080255774373654, 0.04848821845371276, 0.07722062160610221, 0.01241835243490641, 0.07703460229095072, 0.022083298026700504, 0.0038442929599113995, 0.07917892668046989, 0.05909558676648885, 0.04058126207382884, 0.016224105202127248, 0.024435023005935363, 0.010158395871258108, 0.031028708253870718, 0.01031873223837465, 0.04248327895766124, 0.08436546282609925, 0.07450827964930795, 0.026822231920959894, 0.050574469787534326, 0.042643838896765374, 0.04866500916250516, 0.029282334580784664, 0.07090323793818243, 0.03161674896546174, 0.08030325072468258, 0.060943694043089636, 0.047357218791148625, 0.00811970228824066, 0.042857325097429566, 0.010400608753116103, 0.03938125752029009, 0.09875588439172134, 0.014911313683114713, 0.01899928851344157, 0.0021331768675736384, 0.01664246869040653, 0.006019747197569814, 0.08038504282012582, 0.017254105987376533, 0.04196357520413585, 0.009638884148444049, 0.017888679358293302, 0.05433093188912608, 0.03248588182032108, 0.052407043913262896, 0.02393236823991174, 0.02570573939010501, 0.034559653940959834, 0.05932255779043771, 0.03020301701326389, 0.04459375770238694, 0.053426179656526074, 0.014030286984052509, 0.11153765633935109, 0.0412749289534986, 0.04962173399690073, 0.0722603069152683, 0.07860005891416222, 0.015089469015947543, 0.020610845494957175, 0.03151529737806413, 0.007657154574189917, 0.02731521464738762, 0.04886279522906989, 0.04498376372794155, 0.047764720948180184, 0.010568346187938005, 0.011237746693950612, 0.021242559741949663, 0.018905688848462887, 0.021194834080233704, 0.04910189665679354, 0.05004429061955307, 0.04650380462408066, 0.03342357427754905, 0.050890190541394986, 0.09909293075907044, 0.03120258974377066, 0.015953883666952606, 0.027106359448225703, 0.057193406610167585, 0.06398831406841055, 0.06654051539953798, 0.022914074834261555, 0.03950013473513536, 0.018130189055227675, 0.031496443116338924, 0.01794519390386995, 0.031490535620832816, 0.02330107516172575, 0.028540374296426307, 0.07099167225533165, 0.029996711091371253, 0.0565718727739295, 0.04090053400432225, 0.05395434760430362, 0.021038580453023314, 0.03195307916030288, 0.06861066955025308, 0.036590633826563135, 0.026687346580729354, 0.01965331357496325, 0.02974260158225661, 0.02905948433181038, 0.03938536530768033, 0.030649365035060328, 0.06259915462578647, 0.02911445335485041, 0.01367669165119878, 0.05873102527402807, 0.05658961381413974, 0.03841279562038835, 0.049377593386452645, 0.020777184909093194, 0.028223994886502624, 0.01632686296943575, 0.044261520451982506, 0.008894754937500693, 0.053482998482650146, 0.12572119681863114, 0.14934451435692608, 0.01930532424012199, 0.036475463639362715, 0.023842358714318834, 0.026057188988488633, 0.02286116712639341, 0.018886478355852887, 0.030102511664154008, 0.07179849068052135, 0.05674424028256908, 0.04102865837921854, 0.016011374136724044, 0.018239429482491687, 0.04600307387590874, 0.06225191486009862, 0.013315563519427087, 0.06137911950645503, 0.04944529209751636, 0.02140914963092655, 0.013936731847934425, 0.011410489914851496, 0.015386547020170838, 0.018478618112567347, 0.04868518815783318, 0.027161547404830344, 0.0063027346004673745, 0.02465651326929219, 0.02218923775217263, 0.16974377911537886, 0.2355080674169585, 0.1556653415900655, 0.06715383366099559, 0.16332368220901117, 0.1553859972045757, 0.1278806387563236, 0.13988186430651695, 0.11877184471813962, 0.12208816871861927, 0.12663409783272073, 0.18842090503312647, 0.14892094099195674, 0.1633855327963829, 0.13189081888413057, 0.15548232797300443, 0.09569511152221821, 0.19413937552599236, 0.25386841502040625, 0.09436269669095054, 0.16980381886241958, 0.13073529495159164, 0.09990009799366817, 0.13156243338016793, 0.13770811376161873, 0.08997068158350885, 0.12971883465070277, 0.19773358188103884, 0.14868096011923626, 0.14013780135428533, 0.08525824421667494, 0.16566980397328734, 0.2189303288469091, 0.17580951534910128, 0.15388130763312802, 0.2722273377003148, 0.0985887304705102, 0.20993251557229087, 0.12115095494664274, 0.06451140201534145, 0.12306839736993425, 0.09389063881826587, 0.11125234508654103, 0.1373656274517998, 0.21156150003662333, 0.08688569985679351, 0.16057261498644948, 0.21816058811964467, 0.140536290127784, 0.12737982266116887, 0.10108645816217177, 0.1343097453354858, 0.1523014236590825, 0.14506591425742954, 0.13986564095830545, 0.14624644856667146, 0.09320661614765413, 0.2196902732248418, 0.14011380029842257, 0.19153373956214637, 0.1492833168595098, 0.10350069424021058, 0.1258834303007461, 0.1399575188406743, 0.21862279769266024, 0.22478691302239895, 0.2034604683285579, 0.2184715331532061, 0.09431491722352803, 0.13966738362796605, 0.15199362533167005, 0.10677284561097622, 0.1096370309824124, 0.11167841948918067, 0.1550421305000782, 0.12346511983196251, 0.1653111685300246, 0.14096885832259431, 0.1275386571069248, 0.13066798215731978, 0.13250933960080147, 0.2573225484229624, 0.1281499196193181, 0.12678971135756, 0.1704808950307779, 0.11666473161312751, 0.16248414991423488, 0.1165251262136735, 0.10728866793215275, 0.10669893512385897, 0.168811374460347, 0.21163135097594932, 0.11528172457474284, 0.08785821017227136, 0.15834446501685306, 0.10797520648338832, 0.22307017701677978, 0.08857586697558872, 0.12604213115992025, 0.1295017564552836, 0.16308463644236326, 0.14273892506025732, 0.12600818532519042, 0.28172798571176827, 0.1720713175018318, 0.13732421561144292, 0.10309000455890782, 0.06709253226290457, 0.10939206287730485, 0.16223783110035583, 0.2092070216895081, 0.09997103246860206, 0.08443248618277721, 0.14308834302937612, 0.14470523048657924, 0.11774497950682417, 0.05227163164818194, 0.1256697066128254, 0.1873072679154575, 0.14499368844553828, 0.09296224918216467, 0.17551313125295565, 0.1311052852543071, 0.1348198828054592, 0.09100237817619927, 0.20865674887318164, 0.14722289226483554, 0.18600288400193676, 0.13039928016951308, 0.2064374601468444, 0.13507452851627022, 0.15895780554274097, 0.2007425602641888, 0.14301901159342378, 0.10084147521411069, 0.06701555670588277, 0.1168661579140462, 0.18342607305385172, 0.09315904448158108, 0.10861481903702952, 0.15726287383586168, 0.10544635311816819, 0.12626624491531402, 0.1250720996176824, 0.13312520342878997, 0.06616351922275499, 0.1419959164923057, 0.27417657373007387, 0.20262249454390258, 0.14694807498017326, 0.07812270952854306, 0.1577269090921618, 0.15479266498005018, 0.12234309644554742, 0.13309783302247524, 0.18725493166130036, 0.10150569738470949, 0.254331158939749, 0.1706200180342421, 0.11050335480831563, 0.12194762079161592, 0.1460074621718377, 0.08293028280604631, 0.1268384704599157, 0.158994096564129, 0.12928209558594972, 0.1282239265856333, 0.06594891980057582, 0.09514572186162695, 0.08997876357170753, 0.11188829143065959, 0.10805958867422305, 0.13789474905934185, 0.13581906590843573, 0.0937682660878636, 0.12199003453133628], [0.0605819118936779, 0.01173218310213997, 0.020498666162893642, 0.01596443329617614, 0.07675823391764425, 0.012232207882334478, 0.008740828870941186, 0.02582030287157977, 0.04123447077290621, 0.036673283102572896, 0.021258035376376938, 0.04202365948003717, 0.032939211596385576, 0.025832646642811596, 0.030669948500872124, 0.06134627947176341, 0.04957003227900714, 0.08266122458735481, 0.041547182117938064, 0.03453549703408498, 0.0075441537774167955, 0.04899022569588851, 0.02822338261466939, 0.026786850030475762, 0.021733223256887868, 0.0861854018876329, 0.06654988130321726, 0.08024012364330702, 0.03695475374115631, 0.04609541188983712, 0.018254710303153843, 0.06308991461992264, 0.06501421448774636, 0.031004102347651497, 0.0193548533206922, 0.004364868273114553, 0.050632524289540015, 0.03727742841874715, 0.049623448358033784, 0.02896098834753502, 0.035392451245570555, 0.03236702315916773, 0.02825255272909999, 0.011236216014367528, 0.041463067100266926, 0.07315748924156651, 0.10992990472004749, 0.08365622939891182, 0.03984130744356662, 0.01874197849247139, 0.06449055508710444, 0.06718896693200804, 0.053930940266582184, 0.055998778916546144, 0.03623383519880008, 0.04846193529374432, 0.03426067974942271, 0.06704342435114086, 0.031129632916417904, 0.14528379397233948, 0.0272775951816584, 0.037561596764135174, 0.024476095313730184, 0.023160887176345568, 0.004792742847712361, 0.0023498464179283474, 0.03667836310341954, 0.05190344476432074, 0.06276706553762779, 0.04537365472060628, 0.023405350621032994, 0.04198547969281208, 0.04125073493923992, 0.032406449754489586, 0.04270152232493274, 0.04755586945975665, 0.04942081977787893, 0.022323084085655864, 0.04553130915155634, 0.051085301165585406, 0.048703129577916116, 0.05648100050166249, 0.05427363437775057, 0.04574885490001179, 0.013911345758970128, 0.04893440876912791, 0.06878124477225356, 0.09293964336393401, 0.08970206865342334, 0.03226613189326599, 0.06271806894801557, 0.05036063106672373, 0.009887634423648706, 0.05441209315904416, 0.05224517408350948, 0.09079044306417927, 0.03895222194842063, 0.013983957487653242, 0.0471920538257109, 0.021670227906724904, 0.08652603282826021, 0.04249719793733675, 0.07102739182300866, 0.054532822032342665, 0.027378716513339896, 0.042135233961744234, 0.09811685813474469, 0.04163509693171363, 0.024605544422229286, 0.02513591283786809, 0.05930312465352472, 0.033108580828411505, 0.07968185789650306, 0.01508986142653157, 0.05108946090331301, 0.024663888361828867, 0.06941682746401057, 0.034861181120504625, 0.027292855593259446, 0.08292727710795589, 0.04249894940585364, 0.028865846870758105, 0.031169181966106407, 0.1217141559754964, 0.01676370779023273, 0.045528626287705265, 0.06572602316737175, 0.011412349922466092, 0.022441503024310805, 0.009461214922339423, 0.06922857428435236, 0.044598529711947776, 0.04113336428417824, 0.01966836989595322, 0.056120754597941414, 0.02041892053966876, 0.049127500751637854, 0.018376942025497556, 0.10444573767017573, 0.009690793667687103, 0.016938745175139047, 0.0336765093379654, 0.010528229395276867, 0.01417096385921468, 0.08883850561687723, 0.03981823778303806, 0.025796591253310908, 0.09454127226490527, 0.021460300304170232, 0.0386546429945156, 0.03871054526825901, 0.02387725264270557, 0.017584532397449948, 0.04922072563203983, 0.04068542992172297, 0.053534421895164996, 0.007290399571502348, 0.014272814350988483, 0.011540574487298727, 0.019115358554699924, 0.02136431463441113, 0.028488498173828702, 0.08423649240285158, 0.04206435885862447, 0.05773302218585741, 0.11619252531090751, 0.003016645696334308, 0.02225389365776209, 0.026045828562928364, 0.0063570463589712745, 0.038071259259595536, 0.10554036096436903, 0.004346022824393003, 0.06623863941058517, 0.04173182474914938, 0.08498942348523997, 0.005991568777972134, 0.08533837390132248, 0.04095458090887405, 0.018864466255763546, 0.0033828169534899644, 0.02530251756979851, 0.0641673497739248, 0.05303199533955194, 0.01778075995389372, 0.030696456160512753, 0.04612245575117413, 0.04568716016365215, 0.03926420227799099, 0.04374105228635017, 0.10766812803922221, 0.04059447230247315, 0.03109590230451431, 0.015539832984359236, 0.026860908947128337, 0.02558400676207384, 0.025214663983206265, 0.03907512531441171, 0.033594613341847435, 0.031027602453832515, 0.02875778645829996, 0.025582975176803302, 0.038070847367635, 0.05164967478776816, 0.08175444629159756, 0.031206352432491258, 0.05315466863976326, 0.0759532411757391, 0.058528266818029806, 0.018842853060050402, 0.0634508952498436, 0.054587366175837815, 0.03622480697231367, 0.051505082155927084, 0.04472857996006496, 0.0992359574593138, 0.05953975472948514, 0.04625311084964778, 0.037580395364784636, 0.03065506101847859, 0.04756406277010683, 0.03207342582754791, 0.0942488141299691, 0.03259550445363857, 0.006899498330312781, 0.005452297373267356, 0.007260345373651944, 0.022802906678407453, 0.025772740482352674, 0.055596646197955124, 0.06697295742924325, 0.016180238708329853, 0.04432565314345993, 0.05018454168748576, 0.019738757036975585, 0.061204421654110774, 0.009803529610508122, 0.04989189801563043, 0.01389927008858649, 0.019837978470604867, 0.0053174231652519666, 0.01516529795480892, 0.026757524065033067, 0.012843655931646936, 0.05251741240499541, 0.08426535452599637, 0.015869722265051678, 0.08471026463666931, 0.02395048963080626, 0.031798671625438146, 0.039456210724893026, 0.022840195888420567, 0.01952852886461187, 0.05574049297138117, 0.03318672526802402, 0.04842391877900809, 0.02067945148155559, 0.03851969457173254, 0.021770185921923257, 0.02222179577074712, 0.010978424525092123, 0.04219113994622603, 0.018355243482801598, 0.025050638214452192, 0.020815733914787415, 0.03074917276535416, 0.04505163313297089, 0.04776668021804653, 0.014645764895249158, 0.022206501962500624, 0.07254548458149657, 0.0575864443089813, 0.05535779338970315, 0.04444044483534526, 0.024512395611964166, 0.07044348487397656, 0.060030774475308135, 0.03821450118266512, 0.021187922829994932, 0.046585589298047125, 0.01261543717191671, 0.017815831997722853, 0.03046597292268416, 0.02708125815843232, 0.04711482222774066, 0.03302033946965821, 0.07719067594734952, 0.09149555015028454, 0.042755097965709865, 0.00849771984576364, 0.11631003697402775, 0.06057101345504634, 0.035546009021345526, 0.023109537978598382, 0.04253845021594316, 0.04476298221561592, 0.03962958755437285, 0.00611349668361072, 0.05180214902793523, 0.015639541452401318, 0.07870933273807168, 0.05401031667133793, 0.014115482754277764, 0.017911003160406835, 0.06678507532342337, 0.04892040815320797, 0.036043136642547324, 0.05203628177696373, 0.029531657237384934, 0.027500117030285764, 0.06265384348807856, 0.03899147413903847, 0.024233374060713686, 0.050274823952349834, 0.022524096639244817, 0.04092075381777249, 0.07416351494612172, 0.12915354076540098, 0.08827356796246022, 0.040990723500726745, 0.04815311651327647, 0.027017134743800852, 0.011267802747170208, 0.014529054751619697, 0.04247107804985717, 0.01990824686799897, 0.025686972330731805, 0.04854974991758354, 0.016702419379726052, 0.01274094733162201, 0.008302650039695436, 0.036363989347591996, 0.023925733439682517, 0.09051797838765197, 0.04556727362796664, 0.027816182882816065, 0.053896938770776615, 0.023958645833772607, 0.07282270642463118, 0.05295364680932835, 0.029650788637809455, 0.03985001654655207, 0.02626472316478612, 0.010516484908293933, 0.04405143699841574, 0.02704842740058666, 0.023779211223882157, 0.0871474553423468, 0.07595059170853347, 0.04772613669047132, 0.034515403385739774, 0.03398303117137402, 0.10852360908756964, 0.1057645860419143, 0.12528147432021797, 0.0720346494927071, 0.20401414018124342, 0.09508061324595474, 0.1372122997418046, 0.10251160434563644, 0.09694456908619031, 0.08594811501097865, 0.1362796575995162, 0.15542874491075054, 0.07506276786443777, 0.12421007282682694, 0.19361003127414733, 0.1937250790069811, 0.1940433119307272, 0.09381476906128228, 0.15950772212818265, 0.13744745665462688, 0.0978277470858302, 0.14586578618036583, 0.13524556386983022, 0.15525624010479078, 0.11812564931460656, 0.2104555070400238, 0.16502302227308974, 0.16700040054274723, 0.23739166790619493, 0.21054319920949638, 0.14295125351054594, 0.12667389179114252, 0.21881047199713066, 0.11008240122464485, 0.1519301420194097, 0.12624268914805725, 0.24872307549230754, 0.16360425855964422, 0.16828486521262676, 0.20877748145721853, 0.15389496315037832, 0.07456205566995777, 0.10771174405817874, 0.1504818259854801, 0.22604363621212542, 0.11888596476637758, 0.21610197436530143, 0.15736071858555079, 0.09529815157293342, 0.11686040626955219, 0.09938394170603715, 0.158694165002089, 0.13066807121504098, 0.18562133103841916, 0.12293394989683293, 0.10287448487360962, 0.10493536217836663, 0.14114853227511048, 0.15053319744765759, 0.2170167604344897, 0.11852036797790788, 0.14554161607520655, 0.1397620519855991, 0.11271906638285145, 0.09552423944114707, 0.08776525617577136, 0.11238847670028917, 0.11835316210635938, 0.16775071184383705, 0.27353185520041734, 0.11528848554007709, 0.1648962337640114, 0.07164100694353692, 0.1373421013704501, 0.13182723167119548, 0.11037526011932641, 0.13337040902115405, 0.10745064166258089, 0.1059058315877337, 0.2054984652204439, 0.17876425758004189, 0.09723471172037534, 0.15729671576991677, 0.1044866671145428, 0.14124244364211336, 0.09812556352699175, 0.1590929357917048, 0.2620559959905222, 0.2177375936298631, 0.12031538572045974, 0.14699641847983003, 0.1484282736782916, 0.11996141096460633, 0.13168975623557344, 0.13046798820141703, 0.18421522836433724, 0.13866465305909514, 0.07391042774543166, 0.13234107987955213, 0.17966420069569722, 0.17064634943380952, 0.18899541639257222, 0.15937254735035822, 0.1548596067004837, 0.1942110076197423, 0.07440902481903322, 0.15311159659177065, 0.1612510863924399, 0.11454518011305481, 0.08400666411034763, 0.1564610278001055, 0.3739181935088709, 0.1721902095596306, 0.1279399957275018, 0.2947766933357343, 0.1829300809185952, 0.14418960112379864, 0.12391560347168706, 0.1556765628629364, 0.2390862730680965, 0.15902185288723558, 0.06010571654769592, 0.11662852964946069, 0.18354449013713747, 0.20356436900328845, 0.17416171001968905, 0.14237037452403456, 0.10385308080003597, 0.1976628552074544, 0.10628355506923981, 0.14140720042632893, 0.14916739339241758, 0.0885579886380583, 0.07141258131014183, 0.1878723836853169, 0.1052524521946907, 0.1336988538969308, 0.10961592430248857, 0.18411481578368694, 0.10219488540315069, 0.13713052991079167, 0.20981470705009997, 0.22090294252848253, 0.10689340007957071, 0.14530127897160128, 0.11731473423424177, 0.10626936520566233, 0.1536875031888485, 0.1037972341873683, 0.08932330616516992, 0.14509200816974044, 0.1667377693229355, 0.09174082253593951, 0.10149322188226506, 0.0866160033911001, 0.10661582942702807, 0.06656900644884445, 0.16409245814429596, 0.11206380935618654, 0.13873707182938233, 0.12147503599408083, 0.1014853773813229, 0.21529692225158215, 0.16520023229531944, 0.2736699837259948, 0.21782098134281114, 0.13452106446493417, 0.0848517328267917, 0.14185992535203695, 0.13937782729044557, 0.20837611315073445, 0.20297621696954593, 0.16798546799691394, 0.12044515024172142, 0.13071191729977727, 0.1615372288506478], [0.020385429270390887, 0.023907174181658775, 0.04534042134764604, 0.06393331350409426, 0.06650421695667319, 0.058303444311604835, 0.013420493924058974, 0.021949167821730953, 0.05227979156188667, 0.07216506710392423, 0.06727494474034756, 0.06846270756796002, 0.026319775679439772, 0.008627307179267518, 0.01837855434132507, 0.08962031366536394, 0.019126906372548547, 0.01967640178918373, 0.051400721349637024, 0.04373862917418592, 0.010751545341918245, 0.010311492587788962, 0.029606747739308048, 0.04127329993934836, 0.021422571371658705, 0.10575092310318723, 0.058139808170381, 0.0284731394276605, 0.019136765804432798, 0.022813109353592154, 0.0245027606797521, 0.15003644832177088, 0.009221972486557206, 0.048516579627175815, 0.06433911985368468, 0.09029157881741412, 0.06988251028815284, 0.03566527215298265, 0.04363501793704927, 0.04519795867963694, 0.010637858522386523, 0.037359005291364156, 0.00881264186318731, 0.039495307064498775, 0.020211135888530407, 0.03063427902816329, 0.050187792294309475, 0.017941755904757883, 0.03477200465567876, 0.057969500121544115, 0.0389550383988535, 0.028346593971946277, 0.02907186706579523, 0.03818085962848272, 0.03822172227955889, 0.068647027364932, 0.057019825690076686, 0.03020449945324799, 0.023851388796174433, 0.046519638344761916, 0.006288120785029605, 0.08140741061652079, 0.006721022482452099, 0.0778233419987373, 0.04006706134532578, 0.041424839073442854, 0.012474087725422578, 0.07950481114676222, 0.06496982663520612, 0.03809695612289943, 0.09415652064490132, 0.08183097656001337, 0.023457371462427545, 0.043429539509816095, 0.02592727974843001, 0.02894734210713068, 0.021195156914473046, 0.021060980325273704, 0.024334430454473477, 0.025296352177974768, 0.04667928173148539, 0.03905335070157889, 0.014390973537956597, 0.033016740053426474, 0.0294495552952867, 0.025670908544270787, 0.02496041346603306, 0.024320107004314195, 0.011576961987884715, 0.04212174913845956, 0.011655796624836512, 0.03390227066120133, 0.07943628865177743, 0.03913001826731488, 0.08393068303121254, 0.0420950058469316, 0.021420973898784723, 0.05264417122816667, 0.05054699919128325, 0.057636761921457946, 0.05905398567847442, 0.009338609343103599, 0.05612915199890267, 0.019244750146754086, 0.03404393923119642, 0.0382226054352941, 0.015134830009628786, 0.047547234571538866, 0.044066558257327415, 0.03303959449112881, 0.018019158196693752, 0.006058856060917606, 0.07914463203633204, 0.029666006375919096, 0.024040272801357787, 0.02043142943875864, 0.08554955944418907, 0.029160438680264633, 0.05014515591028612, 0.04534759420494083, 0.020695101520686876, 0.04880282227532007, 0.038928105859667994, 0.031190956578939222, 0.03318487732030917, 0.06776172682293691, 0.05043375858804211, 0.061752089532092214, 0.0030455862088274444, 0.05738639840274118, 0.023236287524923682, 0.04344012624642346, 0.022349521241267212, 0.034792855294654146, 0.02079184603644535, 0.02007287748710951, 0.047254750461434014, 0.0649457513645757, 0.02581712462415453, 0.016348502140317578, 0.0771023529523518, 0.0369769328244729, 0.01951006237504771, 0.0017980898860514571, 0.01321356367043336, 0.031256373185897246, 0.026883412720053457, 0.02831104695360409, 0.03922113544831518, 0.0725218620209489, 0.06650967174209654, 0.012550908359116875, 0.03322596261568833, 0.053003712091594934, 0.03792787261772901, 0.058823389263125136, 0.021706309271394275, 0.020189010610920377, 0.035683213573065586, 0.04054667428135872, 0.038137440278660506, 0.01232180644365144, 0.025713587601785548, 0.03499950260447804, 0.06973973591811955, 0.00631510295534099, 0.04310924712626729, 0.06362143336446024, 0.01760644245223375, 0.03434360362007283, 0.0077941221024957485, 0.028282212660997175, 0.050789006127160974, 0.046357267565326765, 0.029361091292230412, 0.06563611939782277, 0.00887226507984451, 0.033732229785528034, 0.05395573542045895, 0.043982324496028014, 0.046854465690557845, 0.025428398803342134, 0.008393398002226604, 0.006483385868705227, 0.0568178687535692, 0.04385055617603939, 0.04824051182367839, 0.03819552446657326, 0.022012550944054965, 0.01757993479259312, 0.02723691435676301, 0.04592826539010275, 0.1005507017544005, 0.02052837433438981, 0.07134476385544986, 0.05627886544971261, 0.03702410373080056, 0.03552429378032684, 0.08721211124793626, 0.06003919042996131, 0.029725114727625623, 0.057762522556004114, 0.10298734327079728, 0.0029861770553907263, 0.0667304680973757, 0.02102741113048978, 0.048623623297316954, 0.0466087888344191, 0.015898144665698055, 0.05210156108660158, 0.03924361881217919, 0.03629178951086942, 0.036223938659531996, 0.006708997834721231, 0.016423264241893776, 0.04419117598445155, 0.0655627877858933, 0.05032427696278319, 0.01652455255680252, 0.02113718775945017, 0.004507830499278498, 0.02733504297793843, 0.07666571778827347, 0.06189102328789886, 0.06612532088183798, 0.06300963650573976, 0.13637444470077753, 0.039995258557610214, 0.034974399459315464, 0.043820139253512025, 0.022367097153619397, 0.051080788907711394, 0.06478000010247342, 0.007989772639120929, 0.05752083845436573, 0.0717767680180259, 0.01095856187021127, 0.01243044758666656, 0.01967779331607744, 0.0628322409465909, 0.07301870020455681, 0.037555433227680624, 0.050369889358989894, 0.05732373145292513, 0.04804664429684635, 0.044189843829371966, 0.08015108076506294, 0.03324584846268408, 0.04872244768193923, 0.04784836470207665, 0.03793522730120458, 0.019527222684700973, 0.08750877736019902, 0.04795472930709366, 0.045439598252414726, 0.04150352528085932, 0.058419289853191, 0.05695126237696968, 0.045545346874860115, 0.04504336931859143, 0.01293542713028728, 0.048980703941197135, 0.03396308595256414, 0.01982084970222786, 0.022396473214030266, 0.023894405530882068, 0.019784762771450914, 0.03598944596888032, 0.01997818315430777, 0.041112550752586685, 0.02441589971567737, 0.016515860152139794, 0.008946733105403837, 0.03416680920054205, 0.06393884250428528, 0.023933715237944853, 0.002602508507152379, 0.02284063561091898, 0.02436566002870677, 0.05701179936295375, 0.0593967020540731, 0.02958815879537724, 0.04557751897664275, 0.05892239547392819, 0.0766497987206094, 0.03147391522361431, 0.038177831665962, 0.053167288861004636, 0.05700286761566531, 0.03498747610137798, 0.013732265524595277, 0.10691428411519155, 0.03392760758288205, 0.012426215489540482, 0.06885642433189787, 0.045720215421169996, 0.007620641836183495, 0.013571432846219977, 0.022888027306180447, 0.04027580151159782, 0.04171276268607471, 0.06082473890273832, 0.07440559609676711, 0.044101973544456996, 0.0774254988937173, 0.008250798036897322, 0.03475891317066271, 0.06579215594683774, 0.050896409738925286, 0.018021776122623123, 0.0529814773472026, 0.0774924925644882, 0.02614139306388097, 0.03144389163935557, 0.06953981617698446, 0.06737719042575918, 0.03060206425288925, 0.024781893553154077, 0.009078413295355858, 0.045930621708976105, 0.05325450976670254, 0.03860797303786967, 0.037605606121360324, 0.02090422760375077, 0.06470980777521618, 0.03182319589541294, 0.029764272294414695, 0.04633790122170467, 0.034171351144323125, 0.025655015451775398, 0.06429199347621761, 0.01874048863101052, 0.04253113263985142, 0.00340790224072407, 0.034366001636954024, 0.0244581872902927, 0.04454481306311209, 0.032797988314996473, 0.04766541416756809, 0.06307798088528216, 0.042873069760389626, 0.049264616245636716, 0.049006489862222224, 0.04082290906808339, 0.025247507728636265, 0.02201170675107278, 0.07508479480748065, 0.10350171098252758, 0.03702342095493805, 0.05674701962561812, 0.04255191648553591, 0.04331840289523825, 0.2928608242655173, 0.1065182666934561, 0.11847152723930776, 0.12112268654163927, 0.14178240060573444, 0.1617244875524193, 0.10144840358407237, 0.09033507609274238, 0.10896735402639024, 0.15830560616450384, 0.16268170962575823, 0.1392454281449318, 0.06419900979381055, 0.1359515541116707, 0.11462784794275649, 0.15611676033586264, 0.22978195280302316, 0.06761414333595894, 0.20497029356192797, 0.13314317824551836, 0.10012591126724146, 0.16413940640632063, 0.10119021782884374, 0.14973561133956537, 0.1814339408883825, 0.23372568102786317, 0.202951458923053, 0.09884575847536325, 0.08165442704921588, 0.2249523822683841, 0.1574120158329606, 0.13226701354142278, 0.10118722697370686, 0.19578915496822447, 0.1791207556379959, 0.16791929811006412, 0.11461145390057936, 0.10383501692558639, 0.18352261162362993, 0.09856110031250864, 0.15600472572259605, 0.1317479702993296, 0.12890075042378157, 0.20097215106943622, 0.09330434215371497, 0.1520981642534025, 0.17225489515112713, 0.08302466172608547, 0.18048225523671135, 0.19015413156012073, 0.18095749692292884, 0.10677682352252305, 0.20826933294301853, 0.08649003124446608, 0.10242842443403788, 0.13822962093399838, 0.12155656833783723, 0.1227988641767297, 0.13305740081705153, 0.08290103476610966, 0.0761999236419797, 0.1467325701378286, 0.210049522574991, 0.1524411849095486, 0.17213830375112593, 0.12726245942758396, 0.21968981309328228, 0.19918004254577681, 0.11462677925010212, 0.1467668722034432, 0.21269291901262477, 0.21886507922317833, 0.1812188368057832, 0.102250457421178, 0.11650649830698967, 0.07762693261611275, 0.16463303851196542, 0.113053047680296, 0.15223883092403412, 0.12556647387100384, 0.11608604938373901, 0.1287522615166381, 0.10169796558329836, 0.12112210766645148, 0.06993972245254554, 0.13146684475941584, 0.14868005469907075, 0.1695331872906536, 0.14122562657576054, 0.14794653077842668, 0.13663689780514687, 0.12865524797234684, 0.22621882759267464, 0.2415775292320177, 0.28142548631876707, 0.09554093034239486, 0.07332421271712519, 0.1795123572810553, 0.24280428449856117, 0.0892872155236546, 0.15185009397100657, 0.13882736151572317, 0.17392947716871276, 0.09677591602667235, 0.17185374948894605, 0.16868271573912352, 0.09605194354662672, 0.1616167277097702, 0.13457819499308243, 0.10361373075284064, 0.11142231916892342, 0.17829943564720452, 0.14256768190534785, 0.11835880242870189, 0.17004433408146724, 0.19965877232607454, 0.16317820642143488, 0.14777824137127027, 0.10913461184827611, 0.12334213111898862, 0.061484994294005446, 0.1862380260718055, 0.13701941556064412, 0.14912123180693015, 0.12240124371601269, 0.23043547320412472, 0.2144879219122231, 0.10723141123889945, 0.2142850632662885, 0.16212615271797404, 0.12164374100393616, 0.16994236299069598, 0.14877217006869614, 0.17771494982298464, 0.1679263633559458, 0.2089424608857371, 0.1201747042068746, 0.22114537248853594, 0.14686027891002595, 0.13687677477719262, 0.17443997086957097, 0.10808874023496173, 0.08299172521219589, 0.1080839236965403, 0.2059092142735608, 0.1527847399120219, 0.11645681152003817, 0.0653164838149678, 0.1847486395854503, 0.1927011230145581, 0.2733652282040566, 0.13279895531013608, 0.1306093079620041, 0.09362005177536048, 0.19819873035885394, 0.15988927509170026, 0.1730827015126124, 0.16385339753469452, 0.13120149727910757, 0.11431373393861577, 0.27799851552117616, 0.1220437660231255, 0.1524327095830813, 0.17647986765950918, 0.23078658326994628, 0.12026565440464765, 0.19808596844086424, 0.13043049490079284, 0.11081635559094138, 0.09880755271296948, 0.1832259158254601, 0.1977108424762264, 0.08649730429169722, 0.12714487354969606, 0.11115902743767947, 0.13588495377916843], [0.03537559707183391, 0.06463194906245917, 0.05407296877820045, 0.027924443675146904, 0.030394771274586674, 0.05096924782264978, 0.006298341550063924, 0.044245326789678074, 0.038286014532786794, 0.04896250648016576, 0.011092970380559564, 0.06264404713874683, 0.0340105462964857, 0.04700670986494515, 0.04289536387659609, 0.023849290373618715, 0.0569858056405792, 0.017156491303467192, 0.05453773133922368, 0.033197267475770786, 0.06125977473857347, 0.020037781323480885, 0.08153614355251193, 0.02078028894175077, 0.028172476850159, 0.06137297452369239, 0.04497002657444682, 0.043673639302141964, 0.06017367501044646, 0.04754182060423773, 0.013525608937925426, 0.02933574880444212, 0.02392204311036039, 0.034114190930267796, 0.03658225497929379, 0.06551012498675846, 0.03653074621979613, 0.09054428010131232, 0.008952359512477415, 0.04146572027821094, 0.03536352232913487, 0.021790266582684126, 0.0013571756608143914, 0.016267871505988296, 0.028801992484659422, 0.03325851692352444, 0.06142847232695203, 0.06971439899643883, 0.03676447449834086, 0.08424887142609805, 0.05276090363622643, 0.061597192179760896, 0.03133322999929078, 0.10428072113427334, 0.026785809168359265, 0.03334181186801288, 0.05485775283887051, 0.04791294639289845, 0.036234083818271756, 0.0805669283727184, 0.021075706390547566, 0.0526213464763714, 0.0406428417772986, 0.050787677682819776, 0.15750132588436827, 0.03364522410265636, 0.04830257392313797, 0.08941683903685771, 0.04978542208846193, 0.03961480026191566, 0.04020361651782878, 0.02287594514200464, 0.077875819260953, 0.06817421250161715, 0.019674151226354297, 0.013914772625867045, 0.019752748376049567, 0.023893837787909433, 0.047966362471925095, 0.018181749765062705, 0.027390435025154147, 0.01781338291038992, 0.02313318651431473, 0.019861213258991484, 0.04404439030622598, 0.03922156218322925, 0.09546306420816109, 0.04377366967673879, 0.04531173733994365, 0.058531057293294, 0.049455615371698514, 0.029742607148364186, 0.02407440417300677, 0.0492564971500542, 0.008822031886666082, 0.09663919016020373, 0.03647563804406673, 0.061539890957647, 0.026257923236698844, 0.015880594728514552, 0.09434695573872887, 0.016764334905019496, 0.04218412665068172, 0.032504795453860424, 0.03320910102047492, 0.04497489135246724, 0.02514788182452321, 0.04431712215591688, 0.024377447189181112, 0.05418800537881907, 0.062499150226358324, 0.013822206401528092, 0.06998183191171847, 0.024548918554501142, 0.028933784924447536, 0.01414182064763736, 0.045705168377025984, 0.021474647874129005, 0.028738692853949033, 0.01388119508192176, 0.01448735532903811, 0.02290983531565871, 0.02401431618636707, 0.03723526329849847, 0.03154525416903198, 0.01507106931967428, 0.03041921205294784, 0.021326541173039004, 0.035531756075215526, 0.04724899510620162, 0.01119227252274868, 0.08088566595688462, 0.03926192759536207, 0.04463565564947203, 0.03164218236634042, 0.035537745206966065, 0.036412863482837565, 0.018934719810204115, 0.048248987150145695, 0.07186635266407393, 0.03391535843547899, 0.03973570725065656, 0.02265757375425892, 0.02436997376207728, 0.05883463651116472, 0.051768177218036726, 0.05028365179896355, 0.029532208282034844, 0.030623916791228112, 0.03027687555004377, 0.021829810066265054, 0.05428357544587925, 0.05438199164927937, 0.019717917530215345, 0.011653931978798937, 0.012004998443444492, 0.07116012493497692, 0.04400365382025484, 0.050142922045779414, 0.01625824770599138, 0.0035057270451943623, 0.029065640446788166, 0.015118531518965028, 0.03727895353222266, 0.06819232090492733, 0.03396553875063546, 0.02795915392198367, 0.017168421327369288, 0.03649722711998038, 0.10547287747613154, 0.026362000171502586, 0.024554545889259316, 0.027941385051235557, 0.0136795424259617, 0.03556369440048002, 0.01447680477212998, 0.07523754364228807, 0.09914261012454517, 0.020546388113871217, 0.05411935671872925, 0.013968070888950024, 0.03796303928538691, 0.006563602755704778, 0.05171526951016858, 0.04138823635003064, 0.019180326162313577, 0.0522661731520202, 0.06696340598864481, 0.02143918249203125, 0.03454250290815253, 0.058403582297614776, 0.017288170565734617, 0.011834415799967246, 0.010140242011402734, 0.035897853813366964, 0.007762945870126714, 0.02791416864056373, 0.014954145808587782, 0.09052573383087292, 0.019424743222771212, 0.09099115690332837, 0.010692463893064996, 0.04512715408054646, 0.014768479941267287, 0.03287913845269941, 0.07407359633361921, 0.03502285799186211, 0.03318407580081839, 0.05901936077862047, 0.03917851019650698, 0.1571028371108696, 0.06710664049023762, 0.008347697475983296, 0.054861775279277936, 0.03660902424599044, 0.012112951244489523, 0.0364437294047093, 0.012668785529967863, 0.004791979827132309, 0.030807006478426047, 0.023185235186247155, 0.059959680438623764, 0.046644586327602156, 0.0638413465640042, 0.009926190850819694, 0.12229942105477676, 0.04747339087771252, 0.06561016649357043, 0.02297644121426856, 0.05783088177850004, 0.019760260765906423, 0.08082162603386678, 0.020037438080180436, 0.03885023972543422, 0.048890688849496655, 0.05477125923789572, 0.044737133212038316, 0.016361580637749285, 0.04437953306478448, 0.05454090402054135, 0.0396363485197071, 0.06018344538460951, 0.07919852680061013, 0.03377948232810013, 0.008574971852794988, 0.06456434683059342, 0.04462662742298562, 0.02866024042305071, 0.06572499900357798, 0.05413380262325518, 0.02284673049871344, 0.025056263693841174, 0.0722456569201313, 0.03442626402829774, 0.029938129664515145, 0.07796806821716018, 0.04346455403720029, 0.018966357565659564, 0.06865985167678446, 0.01530690715298988, 0.0762108109483961, 0.045086970494594425, 0.1150415136362426, 0.0542526909703156, 0.01900528877740726, 0.009301136451540515, 0.039518925914308056, 0.026146050040551927, 0.03315729169116821, 0.11011616894393228, 0.054108758849906735, 0.010519549978198484, 0.06653676013229415, 0.043015484188799746, 0.015717676615167875, 0.04177922943199519, 0.030932550034776796, 0.05807662913866807, 0.07076979236444458, 0.04896241742244456, 0.04566648021864239, 0.07526886227424257, 0.046004524774616584, 0.02355829612497473, 0.02638189158460591, 0.010088536582770757, 0.08810400948277675, 0.0676752591971308, 0.12495813542045653, 0.04099953279364854, 0.01684621791355312, 0.022105595853645355, 0.012572944579005707, 0.023494864763051737, 0.058201469510095194, 0.02334792137844488, 0.034020364910247736, 0.010127594887308078, 0.010149556892429246, 0.08379260645597242, 0.008010408982954687, 0.030045646453800146, 0.057296067898278125, 0.014567549023922766, 0.025123056984739378, 0.11157534259837121, 0.021787932528241072, 0.027307509299134836, 0.045993073435965925, 0.009693253887235187, 0.03333580418257043, 0.030779394874116406, 0.027745322622649837, 0.04892858662060462, 0.08412334456807002, 0.03296417373348959, 0.02476604684488848, 0.09660625364631414, 0.06920687388628721, 0.06017745254212059, 0.011130904331366764, 0.03672927443403751, 0.08941023392253555, 0.009571817190590082, 0.06511714294902049, 0.08268540375865996, 0.04058363694639411, 0.03020650881808251, 0.09190842174575664, 0.04581645713187754, 0.032712841712054797, 0.006684688787572668, 0.05424064220278524, 0.016126985901792068, 0.0582961267355131, 0.0338443794316845, 0.011225978087168187, 0.03512779025186319, 0.04308046663936693, 0.10253873726469465, 0.0119730823826103, 0.014169014793878887, 0.023371636707452126, 0.0666042287775781, 0.04190697902231477, 0.0011895825969077123, 0.045268655667314306, 0.013338019052753225, 0.06397117045708, 0.05046076905273367, 0.061869122509961016, 0.022092355939093977, 0.14294166496256366, 0.23099208396160975, 0.12479133030865341, 0.081719602458179, 0.10087001079227775, 0.15947417705319822, 0.05767050737631507, 0.18272701447131112, 0.12373880905215628, 0.1605959184234962, 0.15071218862431124, 0.14254253794206306, 0.1353149546775967, 0.0672387724625878, 0.13067099527688697, 0.144362595747225, 0.16177971818251535, 0.09533675809507258, 0.18010172643698752, 0.10564472177065909, 0.1731632839073427, 0.08574176084948704, 0.3827919939067215, 0.07535144846769981, 0.20254468778148293, 0.12420950137311593, 0.11282042149105109, 0.09320566619862802, 0.1392490349826403, 0.15694682282628492, 0.13151330320397392, 0.1788763515651226, 0.10639846921549179, 0.13551585405366495, 0.16890861064894125, 0.11076556300395168, 0.09335442970041186, 0.1644211108214222, 0.1229028613306582, 0.11230367890675552, 0.09564817810314707, 0.11940835509449244, 0.08998243720270693, 0.1357983154593967, 0.16727266483940184, 0.11081484903115779, 0.13755370251601562, 0.1499100012006238, 0.12721036066068336, 0.23203466786071658, 0.13824096095049754, 0.15015618642792106, 0.13514632388250902, 0.15064846782479435, 0.08680997110786848, 0.10522118551307358, 0.15186918200924993, 0.13680806674528867, 0.13954307389212772, 0.20574028661940247, 0.11262547413934954, 0.11479680528282188, 0.18791858979966491, 0.28714314044918865, 0.18449682887876406, 0.1354554432327859, 0.10745251929620281, 0.14487224339973181, 0.2355383915710263, 0.16389969270676374, 0.1347415565396659, 0.12047532596625388, 0.17241267574718222, 0.14356579631567, 0.1161680938093923, 0.1050379492517095, 0.17756983026629314, 0.1054174464661628, 0.1862063808948733, 0.22610993968555704, 0.10249636063235812, 0.07888218635343947, 0.20789264846825972, 0.06848292367067188, 0.14713187527377158, 0.09949895233148709, 0.3271844715345651, 0.09759647160535678, 0.3001818439224735, 0.10117007594089955, 0.1280399481765926, 0.21075779863167554, 0.13627085572807118, 0.198411934543401, 0.1799799845321104, 0.20443373563466594, 0.16136951831867918, 0.11382138574845158, 0.08360542196896859, 0.14374156657140702, 0.230234143382404, 0.12864500633440912, 0.14192573900800198, 0.11037799122277647, 0.13090497959638014, 0.1362146157771349, 0.1540259225293994, 0.06278891436522827, 0.15022001112811267, 0.1279133526259102, 0.17325250490102917, 0.1414301773183979, 0.1834215607959777, 0.13012682291446254, 0.13511794415535405, 0.07421832255204208, 0.27637104503810406, 0.09647788436268456, 0.15236895909765735, 0.09115998807828873, 0.086320873524528, 0.13934293150668964, 0.06592569799977355, 0.17182676499942318, 0.09443502640351653, 0.11271050199866295, 0.11520147614646703, 0.10023702561738901, 0.15748900623293594, 0.18693782680202276, 0.12135451863287017, 0.14485322957625613, 0.2101346172275953, 0.11961819735006429, 0.12060807392117567, 0.10845679353224114, 0.1616845600074157, 0.1663299443316646, 0.19770861603319645, 0.1162253505026456, 0.14039863657671958, 0.13803465873934329, 0.1212886901339516, 0.15121566160814837, 0.15936620940919966, 0.12246998885530047, 0.15593851130688563, 0.11850070848595351, 0.16643941111396998, 0.14254195906687528, 0.13082098332233727, 0.17592885269550607, 0.13308913505170494, 0.27800869778729975, 0.13792081328574568, 0.13104580953950062, 0.18388703581877053, 0.09077099879505113, 0.21688400505809113, 0.08686127577675506, 0.11662446268019266, 0.1630340813426301, 0.14327867422252893, 0.23443269543349743, 0.18691706151003018, 0.1356687513180077, 0.1092437891929876, 0.16408052440965548, 0.15471386373974383, 0.26857793040107936, 0.16304901335388422, 0.1343232227372937, 0.1437087933300063, 0.12808225059416145, 0.1660521881422028, 0.18381810514256358], [0.03778903163038194, 0.05302011355524883, 0.053568263829220086, 0.06358296042890288, 0.03956977045163512, 0.03876949405821506, 0.01616417121113045, 0.045320260906009935, 0.03189627517713234, 0.03214693926565815, 0.0619118627946591, 0.03299061645520851, 0.02196518522396218, 0.02201412986323703, 0.013275066376081668, 0.03394398678210564, 0.031924421127769165, 0.06939149054232985, 0.009096516132558463, 0.04792924766661599, 0.04177515133051202, 0.08180500139133073, 0.05446742397907656, 0.03771484654862434, 0.058004959937534295, 0.04851295052503701, 0.015519232820224715, 0.05820397054776549, 0.012643938425753731, 0.14318173489300534, 0.028439371708373073, 0.03309430190711282, 0.02584752299298998, 0.033392582190572284, 0.04584915986924898, 0.0196384743321687, 0.04195760833681561, 0.029468370594258886, 0.08763681267737411, 0.06270292171393521, 0.06435189221519977, 0.0511412962077884, 0.042861328984145075, 0.03390461584785953, 0.0898857502033934, 0.06333422963507473, 0.05529015776119195, 0.03303743855212815, 0.10955589197692461, 0.07727505813818425, 0.03459280567767564, 0.038790845646872185, 0.05179113184567541, 0.04584456968586892, 0.02254683418868808, 0.06369320646626875, 0.05876611030544154, 0.03805629756243434, 0.030371232205652632, 0.0071576905793335754, 0.00841779054098879, 0.053719936549896374, 0.005644388847940718, 0.06194006069563329, 0.019675065923365764, 0.015896398763288744, 0.12256024143425748, 0.07457480576704256, 0.010065176556963706, 0.07736407875199802, 0.04925624481984414, 0.030659343210572843, 0.05816694851091597, 0.014933363818272483, 0.0217773253825726, 0.010615992068778723, 0.023246872406161856, 0.051563975284807384, 0.013618054563266924, 0.05179447151022032, 0.043150035562575795, 0.014741879513167078, 0.011770095716201467, 0.03356909830472432, 0.03545482504705433, 0.06174088310217485, 0.041201293061021715, 0.04731153960165102, 0.053158590890234336, 0.062489865958923474, 0.06465426544309594, 0.029170515190344304, 0.083122810756322, 0.03662032715510577, 0.005008684165659361, 0.0896901052328758, 0.05302657766151242, 0.018953607468574774, 0.019609057453635614, 0.018394840772089083, 0.04171446220425423, 0.031405363042722456, 0.019166462843713816, 0.04622605956683401, 0.05241961218416691, 0.0729345332365483, 0.038774848653702065, 0.011475127266749041, 0.049126480298582464, 0.021690310422854964, 0.04507393838139251, 0.05167318602616433, 0.05579679971560836, 0.03484746994217858, 0.027953411554335617, 0.018817371419572737, 0.06303174508502707, 0.07445911978720687, 0.023204839017125778, 0.019318009399285074, 0.025455275681451894, 0.05428930111520458, 0.043817326513817534, 0.06723152910126373, 0.011208766754862154, 0.052046037308173254, 0.04381592385470867, 0.08704847510671243, 0.03283278019807767, 0.10221603661193512, 0.015803181304363534, 0.012447458539099898, 0.02328659400518518, 0.02741741580393864, 0.04182495686109178, 0.09133648563874885, 0.028811529082304332, 0.01769420883647399, 0.0847798929316923, 0.021433646070363466, 0.04242825241817627, 0.045281012426130474, 0.03267654697992839, 0.0388875140924938, 0.044229329796507955, 0.042209174134768546, 0.05250477363006212, 0.05453994665003847, 0.03190334784449078, 0.020764917207998224, 0.03223548119422048, 0.06006765921483748, 0.03677066029922571, 0.046190685097826645, 0.06277315114857629, 0.029252808235469274, 0.01762869203957962, 0.017447695208829828, 0.017362164544465486, 0.008411278195126215, 0.027266013967164326, 0.0697403444792144, 0.019363890824024566, 0.04517079607467167, 0.04030425174278207, 0.023183882622106466, 0.05781909647339489, 0.019443382261670195, 0.019820335764961783, 0.05498035563505255, 0.05312310880981386, 0.06057795253582299, 0.01325933470070595, 0.01674385719525162, 0.07134003637474962, 0.034469182428438216, 0.04571249337459449, 0.0652692090079654, 0.033311428342130966, 0.011826523059426108, 0.09115759836276993, 0.028225006062712055, 0.008141343314491678, 0.03572185720258858, 0.034079521501553245, 0.02183847092965152, 0.02926700923126191, 0.021396900483523495, 0.035768901943811215, 0.04756224079756066, 0.042999520592275076, 0.01800830985303037, 0.040319770050700754, 0.016824526792333927, 0.04031964759633411, 0.01653471997997258, 0.03180646788678132, 0.030882423525326885, 0.0327797685895348, 0.045041172561468557, 0.027962783024122473, 0.025368900824105367, 0.027462018879305106, 0.04284072325390298, 0.04025763744721189, 0.022308593652269337, 0.05512957555765752, 0.044971893075853586, 0.06115415228123311, 0.061680472281295806, 0.046428702989942394, 0.06001740097417496, 0.022491123017971404, 0.05560207129747141, 0.04853360078413971, 0.03045941048185341, 0.01983677804673789, 0.0170403414813336, 0.026597505893732887, 0.04414360060764011, 0.042188642619294114, 0.013709211634704843, 0.04581526969559491, 0.04364775319118053, 0.04136301817197818, 0.029881589143769816, 0.07862840153393336, 0.0255886637387448, 0.06355616889777593, 0.03568061605619732, 0.06459242969867773, 0.055187823018059134, 0.0474548928468721, 0.07134162457077764, 0.07053653534967452, 0.005544808400372858, 0.024057703994913027, 0.0456049079366494, 0.05183607259823475, 0.045857119403081015, 0.00974597141976119, 0.014993032491474878, 0.057935669319704175, 0.05898814975807909, 0.029741527323494665, 0.04743793106172234, 0.12074290731106885, 0.018785245702019893, 0.023442294732376467, 0.03409412325709127, 0.02062766256130999, 0.05946246747043915, 0.043801192223327234, 0.030706651414220687, 0.040900363310356624, 0.04220426853862591, 0.12008874866296537, 0.02397005635430105, 0.02536414365749806, 0.03552014888555277, 0.061898671119706705, 0.024789910603431053, 0.01747543483361369, 0.041716966952662915, 0.01418139010638697, 0.09739341257954948, 0.10781813834910281, 0.019918178659281693, 0.031383213645312935, 0.017681429053482134, 0.030740927504666615, 0.06294319202424958, 0.015578269740217365, 0.08279839574242942, 0.05332569286110811, 0.03325889912957791, 0.056738414423307404, 0.05263237850158475, 0.016985114561975934, 0.12212360627017915, 0.02401786550763063, 0.007999691442819312, 0.0622669693257194, 0.03969740129832644, 0.09460186120122671, 0.031711294868728146, 0.032328424058505334, 0.04485333127377089, 0.04461117961909622, 0.0412149522890104, 0.048924656948656775, 0.021127424806763884, 0.019008374256372917, 0.07473858291632496, 0.04893526966043282, 0.03170363590470515, 0.082591113896342, 0.039138686552178115, 0.024057067603280302, 0.02429525433399249, 0.02315463458216982, 0.030276753095677122, 0.09548683519824408, 0.05620721109153237, 0.040291861587320454, 0.10228021012153476, 0.046359549669432454, 0.013340971872821683, 0.041109381782007404, 0.013013947282161098, 0.04068414600624237, 0.0422054003138328, 0.039765022083884105, 0.07055470312479883, 0.037423520188895054, 0.0306079402071191, 0.047560775055899285, 0.05170123178686481, 0.01857873754488537, 0.062045204467722215, 0.012708826252492145, 0.019562877314456273, 0.03720988184795715, 0.004502721740209381, 0.04535854088317137, 0.015497216081712395, 0.038892612647032365, 0.07703599010710604, 0.034919992613140494, 0.06462275385274552, 0.07733358390396461, 0.023001073095656466, 0.03949345169530716, 0.03468336995865684, 0.02805152347718831, 0.10351970806368627, 0.040999009579536505, 0.04474370121897664, 0.03375736632733606, 0.045532837975770235, 0.017161793948616832, 0.13502199930371717, 0.057643886539153755, 0.05612420558463782, 0.05201681895414367, 0.024559063713240903, 0.0421091252064798, 0.028582439226738643, 0.031964048102963716, 0.048710406335885637, 0.04263884424290154, 0.029000368558627088, 0.10986892244545743, 0.12605560856172815, 0.18653142673429102, 0.10704331391025335, 0.21242961985990405, 0.17097094998462126, 0.09449996432522312, 0.10989648581016809, 0.0961937902320642, 0.13111027248669416, 0.10496442468138412, 0.14398188883205876, 0.14528694067848846, 0.11776228639064357, 0.1268371197511442, 0.17223179951542988, 0.15679904638091102, 0.1637132652103901, 0.14039275876712054, 0.13754101179074496, 0.10065800146549009, 0.14002928452100605, 0.09447943652048707, 0.10095838573761284, 0.18497079407097772, 0.17617140139918774, 0.09754017228260636, 0.15047968860017136, 0.09013546063215472, 0.16766518674558029, 0.21720459801144898, 0.13479945890139788, 0.10912870435277, 0.21137171803275123, 0.13885900669265538, 0.156623498769477, 0.1620494294911623, 0.1414114306680858, 0.14256444614147767, 0.09779032799997367, 0.18214819865534082, 0.1287567737745121, 0.14666611823486164, 0.12554544140584767, 0.20486599212745205, 0.1178678940050304, 0.11178845030372031, 0.08263162773801014, 0.2806660911301151, 0.19107182684820145, 0.13164050731575117, 0.09483059111516923, 0.16931745980400592, 0.16594923741649836, 0.1363693387247622, 0.17580013460246846, 0.14175234362483025, 0.16306746314512566, 0.23820155882276595, 0.09935005524312146, 0.1499367185169831, 0.14539853000314906, 0.1910216873511672, 0.11437925073551014, 0.07823418010957539, 0.13966088241431862, 0.2729006437584758, 0.16582933603785932, 0.07198721141321585, 0.15814076032256708, 0.19367535511264578, 0.10021945156040601, 0.15751317056128755, 0.13674162968527526, 0.134048449981492, 0.1530899407225661, 0.10370864401920699, 0.1223871429101564, 0.09827633082750253, 0.3050328476820141, 0.26564549712929875, 0.1354165843804367, 0.16225340135861188, 0.11870542250107974, 0.20874516834737733, 0.24321945675183088, 0.20123905705986544, 0.16276729409582913, 0.19767144927754998, 0.23834687133785337, 0.274092354811728, 0.13913504109950736, 0.12809369451133534, 0.15073688729899004, 0.08136159041896462, 0.16392124467529356, 0.15718867391115054, 0.13385002937866375, 0.13280069193569943, 0.11961355150560848, 0.1027819093724247, 0.10063967783935368, 0.07123560877516866, 0.1650352677097544, 0.14343436196213588, 0.15260344807757065, 0.21409108070656657, 0.11634764901828021, 0.20508632092969492, 0.13333493436221033, 0.14099211723078042, 0.14406233764020726, 0.10614463986712508, 0.16568476567044854, 0.09183727946947329, 0.1758078529383056, 0.16967811388894916, 0.1355546386912465, 0.18294483481440693, 0.13073412235826254, 0.10810621039127, 0.12478720396757126, 0.1431614742614329, 0.1208998789661564, 0.11516844315337949, 0.1135665767651517, 0.1666432197089307, 0.261875179130584, 0.11426889337599277, 0.2609364513773471, 0.1637741510057822, 0.08360806401469745, 0.1632912948844023, 0.08221939438953996, 0.11192739519174211, 0.174421506235376, 0.17158604197902605, 0.21741740143625066, 0.16426856978796422, 0.11977101297816262, 0.09779703701497056, 0.14603006799006835, 0.12056020539603196, 0.2074213995365426, 0.12043401060509495, 0.06321968656266108, 0.07671793529880233, 0.1421043591108173, 0.1509949320461601, 0.11138913032482378, 0.11053111113142222, 0.17067930079065263, 0.15458658541319892, 0.13489013450453058, 0.20351494196802378, 0.0909544354362879, 0.09598758450010791, 0.14562205004040152, 0.11509738251334056, 0.208750200108625, 0.09619404256227426, 0.19561627908842638, 0.10969582392135635, 0.20886432757833973, 0.1810956551344134, 0.14070158125832677, 0.2186329205869697, 0.17811934609198943, 0.20072454091859981, 0.09981688839616254, 0.10997945792041719, 0.17661842663073912, 0.10462127043865621, 0.11226485716179013, 0.14687464688904583, 0.0911676989926491], [0.0715253506496083, 0.014788105108891614, 0.016430466785095632, 0.023288594093173742, 0.05200018742471002, 0.025464155478402972, 0.017485743264842313, 0.017364541272399947, 0.038949197696638294, 0.08283287592348643, 0.07129003788577393, 0.041120617897831835, 0.04145625789533369, 0.03462997614406049, 0.04952392635459546, 0.023154788577812724, 0.06571653109858744, 0.048295694214175455, 0.037040690731373616, 0.060592376175918616, 0.009416457851330051, 0.029271104031067807, 0.036263780857552774, 0.05801992163469549, 0.039348005593637936, 0.03193844771885779, 0.027994365118502174, 0.10273749925545417, 0.027771887798735406, 0.05578657663136255, 0.013625492738356115, 0.06406387212336995, 0.06860111068817787, 0.013175755884731188, 0.05832446193380747, 0.027571012542466633, 0.04984129838703666, 0.04490632432862185, 0.012975623703823658, 0.06366892339428887, 0.024966317250800785, 0.02836728690454038, 0.05665198761562351, 0.03539939774782397, 0.0818733086634893, 0.027833949898194987, 0.01770794598996872, 0.029912989411968738, 0.05385589429351967, 0.02961970749311149, 0.08503690609359182, 0.026557788005447946, 0.03601375501602888, 0.021473430751939304, 0.0932722442667, 0.048004876225604676, 0.03487120753561612, 0.06176459100970533, 0.01669674751610728, 0.07806723398971371, 0.02608736471302109, 0.03051327556022443, 0.013979129817016656, 0.06479657226009294, 0.024657272115291562, 0.09347614934085868, 0.03743635563296266, 0.02801857583108358, 0.04842251983063761, 0.018280316253367346, 0.009126745662797475, 0.07588267035316676, 0.00806849780929042, 0.0348467129515484, 0.008358037448488176, 0.024699392706679646, 0.062412393162958324, 0.052438748462009244, 0.04767790080222767, 0.022201926622074097, 0.07483446839614771, 0.04629691982700024, 0.03915713634341955, 0.04198783601168543, 0.10201186436461285, 0.011477541102067335, 0.055841228386270814, 0.036356274722493254, 0.0875528015603777, 0.02265850514959311, 0.03891349297191482, 0.049546825321158394, 0.023957781231729314, 0.017926417567650788, 0.055978963573579676, 0.057061883198912255, 0.050843943608924747, 0.030900730453140568, 0.05339690193068236, 0.034682319819694385, 0.034978600015165284, 0.0017399436592313577, 0.039387858923873864, 0.10584088624455035, 0.015116007289179834, 0.051562450171331875, 0.014514967861032346, 0.026482320863578934, 0.035953718979726546, 0.030745345138711855, 0.041430646379012614, 0.04606962967955042, 0.04256228799931705, 0.047419028560398147, 0.03656894084997475, 0.0440603205061052, 0.05041142736445181, 0.051344744861125946, 0.021698789460060652, 0.04631971118215006, 0.027254941123828758, 0.04938465492159594, 0.030271107207227033, 0.06779614021070302, 0.05149984630406834, 0.057834844847093336, 0.05226105233305134, 0.04127643922402058, 0.040924876448116265, 0.014435205539484741, 0.031823103126953356, 0.015613809337082785, 0.030956851660448592, 0.05920901661738753, 0.04949497517372947, 0.012428229492797982, 0.12447827015421353, 0.043715503852581605, 0.06642281077802181, 0.013318227829586249, 0.033298574344371445, 0.09577176795573905, 0.04720816956250928, 0.02616719382785959, 0.049871385053847916, 0.014657842421001988, 0.04326320195104927, 0.02319330975296907, 0.08339727923157625, 0.004473376757232472, 0.0362527970719384, 0.039086094257072546, 0.05769782954303082, 0.02291202465130482, 0.06859457236714661, 0.02982817306474317, 0.024729974757065065, 0.027989170084765647, 0.04464151119464077, 0.04507163401285652, 0.1435523634427227, 0.034145516983699054, 0.020045193523401394, 0.025259729045501444, 0.04410762499901466, 0.044466245599323884, 0.04156397691986058, 0.0503083616058575, 0.0583116413326934, 0.09573916540830396, 0.02148926447262056, 0.022138081512821373, 0.035342875780770555, 0.019434600799286272, 0.12119396982598118, 0.04075864650076255, 0.004952427516400348, 0.006271182655837038, 0.0037525804373217397, 0.009583889150235336, 0.04701380479673389, 0.04044561232149135, 0.029481955607479904, 0.026832339972315822, 0.027904847265745047, 0.019269478507339954, 0.04716943687526509, 0.028792852936021518, 0.030152298641041853, 0.040556081003160216, 0.043577761243795976, 0.08624795009382069, 0.03487390153168235, 0.036833405174547806, 0.01603203923878027, 0.02939517256891122, 0.06776974201784469, 0.0366366321395617, 0.04289781296392903, 0.02121838799212128, 0.043914124835282564, 0.011153527775604744, 0.037574302332359366, 0.03613639120885637, 0.01258354059245903, 0.012581211176438956, 0.06388133348082192, 0.03902972071955446, 0.0909219664754346, 0.040888073344831355, 0.019511663558660075, 0.028036194416927174, 0.030906155552656855, 0.06081864958105143, 0.050997475409531035, 0.01720316311548231, 0.04205111152259633, 0.03783867388847284, 0.0603530224179849, 0.045008328816038556, 0.05008307896787301, 0.0212380363518605, 0.10561188173596747, 0.020972731545043644, 0.0347215126384981, 0.030065278115216643, 0.046248765575001016, 0.057795321772573516, 0.04909757735731546, 0.017661558049439918, 0.05188241972064134, 0.04526235854427796, 0.012375033275020542, 0.050617135857464746, 0.025241611365345307, 0.04344324697740376, 0.03387153090443462, 0.013947540301160188, 0.02364146119361976, 0.07202887558378279, 0.019913443757104687, 0.03115030915068928, 0.038631217103102244, 0.01549240789245232, 0.05089671401947271, 0.038080291196820326, 0.02964504441479221, 0.06311076154815964, 0.07980201160535216, 0.032299736340064555, 0.025250776889151894, 0.02306661586771952, 0.07240924853249453, 0.06023533635016065, 0.06058092854800634, 0.029640942193509545, 0.02832667472830508, 0.05435953054984566, 0.0697824836242944, 0.018310451159777585, 0.05062966331024654, 0.04660977218009066, 0.06300193301285617, 0.03258499193179887, 0.13674182264367118, 0.03557002120942343, 0.009798688952287193, 0.024123196672007907, 0.026686025557864923, 0.043748462630901486, 0.02467779992002761, 0.019011207405128516, 0.054897821391932666, 0.040777905232971534, 0.055535378196509555, 0.04458568313566502, 0.06464067671913654, 0.05020016018534079, 0.031217213763738982, 0.049064076811191626, 0.056317141716135666, 0.01656132226344198, 0.026324241553083993, 0.04558986460324377, 0.05988868659187574, 0.057594299942138605, 0.04807835255633108, 0.02699467549973633, 0.023078725862433203, 0.04200832299829926, 0.07604919344885275, 0.054957334214122966, 0.011300890473648906, 0.02902559415815631, 0.030505570211971644, 0.026914211848634295, 0.10138256766367704, 0.07171629782533273, 0.044703807070618495, 0.06831861959653907, 0.04145557511947118, 0.043174274105695076, 0.03852688598271925, 0.03807653221883811, 0.061095058772480115, 0.017431846645195037, 0.04618439910700545, 0.0337032229435863, 0.03831888796412386, 0.03582757242838852, 0.012416053632477997, 0.024692895203770604, 0.059707854888984, 0.05282517733576242, 0.03887781422236003, 0.03795880533289164, 0.0206078082555905, 0.03472412870905828, 0.05027687227993738, 0.04771134568727575, 0.02072666506137466, 0.015060360128700268, 0.008608727512182668, 0.0312982785544591, 0.027848162026202772, 0.041783433698583394, 0.008563987139496021, 0.018232623988296837, 0.0711511004192289, 0.03542401849699672, 0.08114525437122211, 0.046809665946057066, 0.04149004045757465, 0.08886829542461783, 0.033281360229011625, 0.06595375118195079, 0.02286808394273976, 0.04184480188996531, 0.019333859818289056, 0.030932904410292394, 0.005505680519490852, 0.02959066168841673, 0.034272427947144024, 0.039125190596678294, 0.1038778388465289, 0.020951389233232476, 0.0672650667547714, 0.05166338596609421, 0.03803265644819476, 0.02861327175196493, 0.027353181067155674, 0.019352916315256152, 0.17650811380008236, 0.09975966881029308, 0.1272878557210788, 0.19027750618988648, 0.17123545141657814, 0.17955793999135494, 0.15010220260592178, 0.12210721222800203, 0.16025463439291343, 0.1834384520770982, 0.1891827047802508, 0.1407163351541385, 0.18363696173764765, 0.10386024994659238, 0.15864800341660157, 0.13458560162689537, 0.11969187777140178, 0.19239713932620361, 0.2396999252960086, 0.11188523378223181, 0.17353223520331085, 0.1257073928718455, 0.14911554695572704, 0.12179542114608921, 0.15031098359031603, 0.09650221196352504, 0.12134648859500885, 0.23888866882771254, 0.11718892536009662, 0.132631259621121, 0.1621073466958478, 0.12470660672988743, 0.21036123944213614, 0.09230240568285808, 0.24163599562598392, 0.19748919265111908, 0.12775310809956864, 0.17394604190485552, 0.09668647238868289, 0.14159573562210426, 0.13859931437764317, 0.14052270882530138, 0.14598671172279865, 0.11040968092856929, 0.1474031450925395, 0.1184117843513377, 0.15082242724020034, 0.1711086035356857, 0.14087607502005994, 0.11431103252107278, 0.1384121150476858, 0.14265449834056199, 0.12078618936357088, 0.10952953831292689, 0.15940711658913642, 0.11310804082313552, 0.0914103961258661, 0.20215994358295575, 0.07825968030374497, 0.19775160122662783, 0.09738312641275115, 0.15978984214598313, 0.04209408929455094, 0.22802143008448184, 0.19038358877878636, 0.11468945362139493, 0.09452970960410312, 0.07027813437161967, 0.15024758933577687, 0.11953731809626333, 0.10915500606643036, 0.12340701709035784, 0.10735819974797778, 0.14754792326129973, 0.08633109289803542, 0.09473727346630767, 0.14460109232459217, 0.14429255184950307, 0.11899395467480645, 0.10845757278730161, 0.18646699347300455, 0.14146801200695336, 0.1498430743231438, 0.08755335074965842, 0.22184631612617522, 0.11745928233722225, 0.15614931093296036, 0.139465682732407, 0.3169333341065794, 0.17654403374763206, 0.14413511264137924, 0.19172994856489822, 0.08709338988410309, 0.26273731724359095, 0.11721547940396704, 0.13549097726354375, 0.1648485878831707, 0.09802518805372529, 0.11593559378525242, 0.14046296593733132, 0.16069037897977978, 0.1085807841445785, 0.09910905762808397, 0.24634011351736262, 0.15388190135126933, 0.09620588723919354, 0.07626841645105742, 0.17923011851962656, 0.19120373617624864, 0.12403209097101353, 0.13412342173978686, 0.16311172483256087, 0.11785616065026261, 0.19145615544402972, 0.22763796237995848, 0.21942255087196827, 0.2562407642835751, 0.12125990964705124, 0.15293610835215077, 0.16054696636274457, 0.17051828443072736, 0.1799863818450831, 0.1404347940115258, 0.15854836266953498, 0.12298120986088179, 0.14182409446220845, 0.11749244891689159, 0.16830848035169765, 0.3083648532629013, 0.16660087276250124, 0.11831963929580525, 0.17413141555152833, 0.09658741051680408, 0.10615039893309586, 0.0828857762098778, 0.1046338201558683, 0.244161895243451, 0.09104862139793113, 0.09283385763410479, 0.09580028869095258, 0.21132205351023003, 0.15324663778301328, 0.2074261789675802, 0.15384437836473808, 0.12108291484764777, 0.055132993147708476, 0.22087411751272157, 0.1542002975475043, 0.1363939928705804, 0.09787145958398469, 0.15918554097879678, 0.08745371000259183, 0.13461064168950543, 0.17365595122100785, 0.16278126131510362, 0.14187444176059216, 0.1123083767015487, 0.19240260153310373, 0.12427463967469521, 0.18020826915744692, 0.21923339227214456, 0.1578226312994957, 0.11850355833303183, 0.09584701430867426, 0.19916184508474544, 0.13464611634844914, 0.11091621898231097, 0.11748007731512189, 0.1605162414489314, 0.20339860289823264, 0.18999958672793582, 0.09607134328689426, 0.11053696667659096, 0.21147673192899674, 0.31302343297284096, 0.0883413408882916], [0.04711058456450701, 0.03052848216611892, 0.07960767281474546, 0.014949988853913965, 0.03598925301048439, 0.06831301638158038, 0.04001290682936087, 0.011147037694172468, 0.02801234179059975, 0.02839647186192451, 0.04103501116333064, 0.03336404661240522, 0.026410300997667946, 0.03580243959731888, 0.05790207229438238, 0.043141842252225615, 0.01712661800411297, 0.0191106718921219, 0.0552889517712174, 0.02948738070699619, 0.04832572893064935, 0.01854192145401612, 0.034204469484393485, 0.039710778510198, 0.023658699428779073, 0.022785675864724908, 0.010936802100331988, 0.03475580728263594, 0.04195687361061573, 0.05424555893114302, 0.09572490132995881, 0.040603660090710036, 0.048302236245945096, 0.04483667005843017, 0.012828128346882295, 0.023181003089121077, 0.05378630681661889, 0.0035698796818905976, 0.02143731042451691, 0.020657001514337026, 0.03142802081129048, 0.014969203057262348, 0.03589011321309954, 0.023854086502979044, 0.09005424741189927, 0.04310301308578346, 0.07816564277163707, 0.016514060444023926, 0.033773786344681866, 0.05278066331811715, 0.05759184714406729, 0.07038359355647117, 0.0005450646210647392, 0.021839402324985713, 0.0234190265473444, 0.020636230656236876, 0.0632587012660224, 0.03720939945196733, 0.005505994076884235, 0.03340648261655588, 0.02581320051831426, 0.04140366188948974, 0.054655729109072126, 0.02397324758931063, 0.016051188504206948, 0.028020074969390407, 0.01682488487858791, 0.02622646545205498, 0.004612327211361844, 0.05815003125462681, 0.04767597492900677, 0.07072451393469237, 0.04303660200093873, 0.09279980047722347, 0.05986136071442161, 0.041255113610532135, 0.03094272302405443, 0.022789663053117692, 0.0715577305527404, 0.07257819845108315, 0.03889771120157093, 0.036106712723267265, 0.06865726900286973, 0.013238834726507775, 0.026125589029106777, 0.033117508864961565, 0.05412212492956314, 0.05051844134868588, 0.026598674776323605, 0.02935381453426089, 0.036119863580097444, 0.009963565407815622, 0.06617169769015163, 0.022197870785021223, 0.041150444812956266, 0.039670531841693446, 0.02830340468790382, 0.029984949906065594, 0.013818573588650906, 0.0451257736858679, 0.045713157596765086, 0.04205376098980196, 0.049536520600668155, 0.00917506968107773, 0.07347664242843166, 0.007863037008064566, 0.05610128435364459, 0.07142622940591536, 0.018359028435952496, 0.011026885840692557, 0.030172473925631493, 0.05914139954256825, 0.03163352521369234, 0.012513315796240931, 0.009662561442382867, 0.07531109789852053, 0.05496899706486147, 0.05614184643491171, 0.03204824846761767, 0.040109478795784526, 0.009608203763491474, 0.03512504059472121, 0.07112951876479201, 0.049759610192268156, 0.014491105957858963, 0.04124968108953908, 0.04646895336918533, 0.09563733532559127, 0.07368366452283226, 0.0357322324271081, 0.03203776563168503, 0.13228072843048722, 0.010050177752418676, 0.03252910821174737, 0.0241132389055565, 0.020398632077558432, 0.04251775171724148, 0.02471943440468749, 0.017739106915541925, 0.06611311255255714, 0.010244916375086177, 0.04576567196636461, 0.047430502163479105, 0.05496982827025931, 0.026705172967922408, 0.05116288157296367, 0.0860927595931571, 0.018052109553536866, 0.015130563588172663, 0.018565818609204143, 0.06158352924103383, 0.10613059843308292, 0.01040574163198471, 0.0623139992239885, 0.0643234679591842, 0.012991121602681233, 0.042137508644373156, 0.026113781459571328, 0.031880734604783356, 0.10944871843094006, 0.030637986055808142, 0.03307346982182935, 0.04872265177255031, 0.03747221991943661, 0.029257272253744304, 0.014471011381829157, 0.04958446334057953, 0.06497025708085857, 0.09031215857248753, 0.0052622551538661355, 0.06509806975373067, 0.020925466014887206, 0.03797227531322278, 0.02124852289853152, 0.01992431250982918, 0.0467564316932112, 0.03784413238463458, 0.02499035541404737, 0.06739327276591212, 0.05082689647679217, 0.09430801525013521, 0.011850950850202935, 0.032459936337545514, 0.04279173779650591, 0.02694569375307765, 0.03828990338661242, 0.016724763590900693, 0.03393995692022145, 0.0459524445614079, 0.060703505369019695, 0.0036251244591767318, 0.0681423966307193, 0.02369928562984569, 0.07709973317105323, 0.042245977238053456, 0.055747450605849735, 0.08726520449272357, 0.005875889291928615, 0.09049454136402346, 0.03379918263817672, 0.008169969805749133, 0.01643753203097731, 0.05082734547613654, 0.048242229895549826, 0.03886549086018931, 0.04457573093532119, 0.05526081324205734, 0.12124982386012562, 0.02644380339916097, 0.04270108445780352, 0.09688655540230684, 0.03085971751715988, 0.030922968908271287, 0.02658293382410193, 0.036568714494933374, 0.0441557087469846, 0.0584726280067116, 0.05254820782283787, 0.03731635777512565, 0.009679582599346759, 0.03215925891709048, 0.06566911528352648, 0.05045211561082397, 0.04456986796867568, 0.07490874995710328, 0.06215943954885006, 0.02160321753763128, 0.02121864032233134, 0.06855268555227667, 0.027366081449144986, 0.0056926595243567135, 0.029519812560465652, 0.0326264371688012, 0.04564068316540215, 0.02607094284030609, 0.01844952035753522, 0.02822123595251469, 0.01593576784216566, 0.012662971730605932, 0.08103275220491923, 0.0467854236921994, 0.032413815570180304, 0.023345438894466497, 0.025623891633586027, 0.04778287016961258, 0.0887181812140625, 0.05615198788291309, 0.06340070380247198, 0.016071345235104673, 0.026333254936616868, 0.017305486726399977, 0.08084199056611396, 0.01740899035212351, 0.017634927935432643, 0.09410054786712863, 0.01830006109230453, 0.10131593022379093, 0.007961643386806827, 0.02567032781371381, 0.04753937522764318, 0.03246952859626617, 0.028030769317410886, 0.015032113060442498, 0.016646719341224525, 0.07846093591069803, 0.08160693701938726, 0.024674822052475065, 0.04251158447004855, 0.04589073498209473, 0.014026832286617719, 0.022097050023148768, 0.03427981231652666, 0.03386150077858474, 0.02134750313416589, 0.01864324316557031, 0.08997959477710538, 0.026990936930815224, 0.029235492074803915, 0.05322705772414338, 0.01087112759705633, 0.04858673855778761, 0.01582258104463108, 0.044547852157847956, 0.02954478211904643, 0.026852314877032768, 0.06594291582587175, 0.052949535311199725, 0.08438462507911026, 0.05144234841282014, 0.03295023620012216, 0.01773967651388375, 0.007852394610381452, 0.049531989789102226, 0.0660650288045872, 0.02646636283316184, 0.015264928497344954, 0.017298909442615695, 0.00841357421450084, 0.09003227984067053, 0.03107937653112458, 0.03163487221172545, 0.03322763986943755, 0.047360191092593595, 0.08645616704598069, 0.05685359203198459, 0.043603283702395856, 0.01164671644801274, 0.08493901681504212, 0.06295005689025857, 0.05217008729232475, 0.015921223603072576, 0.02891774525778601, 0.06695416625007056, 0.02003107416385319, 0.06226879500900395, 0.03959564171964303, 0.0020947062512277626, 0.020984819275327027, 0.0726978771854192, 0.02112141712132143, 0.0071321950235869735, 0.05285447361529805, 0.039083489318727516, 0.028864987834822387, 0.04435429633304011, 0.02114980798069155, 0.012762242331518792, 0.06897516796016134, 0.05639897091896273, 0.03315254194603767, 0.015125761892704759, 0.023188628656498622, 0.01100700648748898, 0.06838176894234493, 0.059011887351516634, 0.03803971798333805, 0.03845325751171913, 0.02217230008682236, 0.03544522165611852, 0.005961077176834806, 0.013068786429357715, 0.025413227449462283, 0.02693074133276241, 0.05180555919650942, 0.0557574399135774, 0.04036790574900806, 0.032879709906410426, 0.049009269205271266, 0.08722879472770728, 0.05044773693953175, 0.05894450776395388, 0.0654079757805448, 0.23399806406814605, 0.1552801817888394, 0.16187079454539344, 0.3058031969703734, 0.15230831078952178, 0.2020614902721718, 0.13666361512150615, 0.12250904066604562, 0.09569295929395594, 0.1018674646911677, 0.15630195586709306, 0.13327110966201872, 0.09540139915770851, 0.13011042145080864, 0.17263411777094007, 0.12681004620390013, 0.10169588756980374, 0.12572934560012072, 0.13095415430143476, 0.12769465654855594, 0.13296375662321225, 0.11988594196736813, 0.15238463325658813, 0.155996369139757, 0.2052898920373991, 0.08964096763520502, 0.08331751319929026, 0.15245801681885496, 0.07596213210490532, 0.27170085813850164, 0.19275532948086038, 0.1984305476071313, 0.12193533082609065, 0.1310949694016017, 0.12282731069717556, 0.10502885794267058, 0.09280677666538395, 0.1338523448794149, 0.10857088389457203, 0.09774275633390062, 0.16664004331687465, 0.08944849163526669, 0.09923393881763332, 0.08923913919716142, 0.19597953069023788, 0.17758562316885218, 0.11656055634375662, 0.141009958460927, 0.11708405989338644, 0.16320090129738674, 0.22127619828097522, 0.20073018124094233, 0.17292213044129312, 0.12842786876717582, 0.14969117153668776, 0.12085243346518837, 0.16574556240811944, 0.09619182354072109, 0.10466581414220855, 0.14185441861627623, 0.12180756268207915, 0.12578597146784887, 0.12713647243799642, 0.11939138959860429, 0.10676976569811814, 0.14297207817435265, 0.12837441929150373, 0.15806366602191702, 0.1639966171933338, 0.14787320658797398, 0.10931658645858988, 0.14841636962955818, 0.16257717070402578, 0.1414495028438978, 0.13615433854283765, 0.14671113691292703, 0.10446292581036687, 0.14198497723555192, 0.158728422538843, 0.21695125848054886, 0.2095667109824717, 0.07785789639456198, 0.14519175281748176, 0.11284909807727672, 0.13125971134286374, 0.10194296337431297, 0.15224208153085783, 0.19775508932070807, 0.11513808189192787, 0.22210100636584684, 0.11451855185441673, 0.16263400437310338, 0.18439533276250586, 0.0549430738465162, 0.1111382844101172, 0.2524342591641471, 0.09765359471202828, 0.07495312296668999, 0.0951177354727406, 0.22101856913650408, 0.15249478281475604, 0.24605526239611208, 0.1371612399816513, 0.14022167888469994, 0.10079785919515416, 0.15284550696378574, 0.16766971384640783, 0.1433110170182772, 0.09957089612726122, 0.23010806733509526, 0.10129123897058889, 0.30607936496380717, 0.09539446749840863, 0.08959074650192633, 0.10528619022807106, 0.19831532175885513, 0.10890284655033611, 0.1143435163248796, 0.13185412710299715, 0.18557275005150586, 0.1143869839143008, 0.18411282682791352, 0.1774089178070426, 0.1312517109909095, 0.10195721260970458, 0.11952512460993603, 0.11414938533562236, 0.22385222255252302, 0.2784423198318109, 0.15698155533755198, 0.1779034998617135, 0.13814069679938257, 0.1019231702957768, 0.10733689268818125, 0.14298552589025348, 0.10992575611453503, 0.19815975276287645, 0.11858010344440117, 0.14444956061197445, 0.13621017773402855, 0.08816116969683208, 0.17914647847646847, 0.194760033627972, 0.1638186353375204, 0.16681937588145956, 0.12887999997474253, 0.07244381034979597, 0.18629730882821605, 0.10888165823416784, 0.24887463689083233, 0.14209851098712534, 0.18061086942907423, 0.09444153503864072, 0.09443771297810599, 0.1547619845950976, 0.11921706653083675, 0.1304706302471459, 0.1463058649096638, 0.16771311464253813, 0.254278882057406, 0.16841944627230987, 0.11071934204665013, 0.094609765073983, 0.11020376463420689, 0.1146772452921141, 0.07217808437417261, 0.15014598931884393, 0.20177570404484868, 0.14376736362464726, 0.08009058830793947, 0.1573095697676763, 0.1168192393379286, 0.11968763268669136, 0.1516640672343783, 0.15123872755793855, 0.16166677814908326], [0.006941661131349974, 0.013306208747962955, 0.01969253979041241, 0.040640919614816085, 0.04040266423544381, 0.012504903552326141, 0.046225239493651316, 0.02886622165533481, 0.05681001683115028, 0.0530464783514617, 0.005492476320796413, 0.024635870431666262, 0.010476562929397915, 0.0014165860898174287, 0.030505353133776225, 0.049335866133333184, 0.05370831822801847, 0.018100842680723872, 0.03311765358375851, 0.048957808685372584, 0.018142124645237345, 0.05559551813348662, 0.025394248878001235, 0.03892747132340446, 0.0615076891699573, 0.0026854690213440335, 0.05186167669307906, 0.020566804596455768, 0.015450245555257425, 0.004469001332836342, 0.06374468182912096, 0.09756040322827175, 0.03125390183413401, 0.031901722541078925, 0.014073497604840668, 0.030327018757816404, 0.04423170095833484, 0.03843116377538536, 0.039324583412962966, 0.04885682836174965, 0.023729418680886738, 0.03559086071618367, 0.0908651773352176, 0.026559964353509713, 0.05338817798474338, 0.0219117988308426, 0.06044516747351736, 0.028600503101188224, 0.022027262166375294, 0.05998351451125927, 0.01787793491530465, 0.07566358093754388, 0.024614364847366232, 0.04870396449405234, 0.05529140085855033, 0.05463295630761422, 0.06172722016344778, 0.009231847689079586, 0.04089022186235525, 0.03752507567696739, 0.009270340106013464, 0.03203244072210509, 0.03389635203348007, 0.029200470125942957, 0.010353303332522046, 0.0009284985810609214, 0.0319820674485527, 0.02051313618721906, 0.02264055630803341, 0.012989663282496622, 0.045190733872004785, 0.018507573004171718, 0.04632698051864281, 0.03182001208188012, 0.0312927013146691, 0.008100690320134163, 0.0384691988438135, 0.021414448565337807, 0.03481753170490265, 0.01937934048328316, 0.03814995288848877, 0.06991526868660003, 0.025070204937946983, 0.04255868487234693, 0.02666021180630196, 0.027544115255295765, 0.08160723387845792, 0.021208480320638046, 0.04178420924290549, 0.05469904455821961, 0.045753905214951374, 0.054014532070141286, 0.013507850271707866, 0.048381085725850426, 0.0388546258182032, 0.04568244010442868, 0.019408267544349656, 0.049877166384248994, 0.028624708247662056, 0.042320429492974654, 0.013087583174637984, 0.035047708806814626, 0.035461582301650196, 0.0256961137347389, 0.028880663849122357, 0.006619241567022982, 0.019812762147921603, 0.03746801565284841, 0.03727449322468601, 0.0268197958212113, 0.06484619225375354, 0.02099139655911131, 0.025917991770256776, 0.0437837591744028, 0.0560010684421286, 0.032166261080419645, 0.026904699370788876, 0.05576007824856788, 0.03846046747639775, 0.010060328477266012, 0.033132485405076295, 0.018657394066394772, 0.042148258653469384, 0.036500021305982955, 0.06788512371713296, 0.01588902552612126, 0.06105828164436389, 0.06704568048007786, 0.027417367564339656, 0.021235399872239213, 0.021050363902759273, 0.014164941330818692, 0.08573001265176572, 0.1195298224047292, 0.034448858714313246, 0.10220862255664542, 0.009014424394990783, 0.0073770898416114505, 0.015356562398665119, 0.0598435899883043, 0.045175323175499216, 0.047286814951803535, 0.02223464605776826, 0.05311192093358841, 0.055335666256723925, 0.09890244371490553, 0.022680539514112752, 0.028716474807879422, 0.02628077767440118, 0.03933714426239021, 0.028671754844253883, 0.10439230303745717, 0.060606684783124365, 0.01139748192144907, 0.028667088590736967, 0.052280270247138105, 0.012561553539853776, 0.005555199859372806, 0.03287609193648677, 0.07343463686993346, 0.026876299234572798, 0.04359965831099544, 0.027915597274841275, 0.05788087655673735, 0.10375963698606938, 0.0394905870052753, 0.013865199016436236, 0.05027384431741666, 0.015409972911584191, 0.009245388173440006, 0.05020213429816067, 0.041919651193893515, 0.051792434314847924, 0.04938836565997917, 0.056507317058276385, 0.06896075545228086, 0.048087614559335634, 0.06565180097823031, 0.0005957936616596271, 0.013551173142332118, 0.09700808208435774, 0.037816724870936014, 0.07140901900129393, 0.04669162735808641, 0.05710407058359124, 0.02380279667704599, 0.0053588034643325955, 0.020073766208952293, 0.03248548477131408, 0.014792678593948949, 0.06186587561387569, 0.02403504437097581, 0.040417210329906084, 0.025913804201991297, 0.021095558840897866, 0.03773361546336673, 0.055582404384040274, 0.03039241495571332, 0.023318341227422934, 0.060080442708567716, 0.05963481271464843, 0.03636780027591158, 0.04344221539213322, 0.01207445326144807, 0.0427809840766713, 0.0818532558332663, 0.04066782246809453, 0.0335407074453542, 0.014248154639062705, 0.04456777511222754, 0.10797489478136413, 0.031095629565243144, 0.036854990539723076, 0.044391322080628015, 0.029594027328130323, 0.0837721825519111, 0.00813588296296075, 0.15945026505505666, 0.06428512861020863, 0.033112803648691624, 0.039680688132648356, 0.04176106536760926, 0.054616113266092725, 0.0447859591076849, 0.026938515329675283, 0.01800918373191962, 0.05715342711482663, 0.06143375641840976, 0.03956289074267261, 0.03875025759043638, 0.05191663272853475, 0.07722475536866114, 0.019616462232079357, 0.08831633793306537, 0.028833379765274003, 0.07927714992547408, 0.03383046787348576, 0.02499302900105249, 0.012484975959523581, 0.007130466283342685, 0.02108202392264502, 0.02413092428469099, 0.0269967182612163, 0.04638237442122772, 0.02933046100224601, 0.047856068194960244, 0.014366593986778753, 0.01001302862277953, 0.044211692656972446, 0.04309875315811951, 0.03862258592562284, 0.009561170154483989, 0.018544029153417796, 0.052839645504718646, 0.023173188274085987, 0.04734224967251066, 0.010551537470746553, 0.06332708275294863, 0.07332079883781262, 0.009291293717978988, 0.026820855237019714, 0.037601075309794396, 0.12451948161469772, 0.013978626084281132, 0.04115343566809315, 0.07143399227061309, 0.0797946569218766, 0.0383466331550153, 0.05419033201178536, 0.018087209427903872, 0.0073652089849929325, 0.024227967514889315, 0.028958654293091968, 0.050018972251564264, 0.04282315661839675, 0.05049088169471361, 0.08638466853881255, 0.03736428938282188, 0.03792594674450811, 0.040178539347834885, 0.052604047014028765, 0.06024062415235676, 0.07004976068856195, 0.012677218182943761, 0.01897373265819624, 0.03222390740120318, 0.05482247855979949, 0.039376956774503924, 0.02116106636094628, 0.029934353988210205, 0.023575413761136588, 0.03940239017538261, 0.04173744651779998, 0.05428257725725416, 0.04072006595379207, 0.024428082069789525, 0.01809724697523052, 0.011404072192817694, 0.00173245040286929, 0.012566940604301635, 0.034189667348982766, 0.026232391501253005, 0.03165380439895671, 0.0320905583066633, 0.025330221942567732, 0.06008403841406107, 0.03203368753020186, 0.10287375014740974, 0.05426088799140416, 0.03893384266120847, 0.012740176425722893, 0.024278142263938207, 0.07368395396042615, 0.002204063566750847, 0.07411165366647765, 0.04196419118670747, 0.010803861187014263, 0.01710219577944372, 0.029923167967353947, 0.021853670114069246, 0.05151809942617547, 0.01905749144498259, 0.05280100929667242, 0.049281737592536956, 0.03787070127145853, 0.02415155599010177, 0.028373739878588822, 0.04683973776991479, 0.017029138762154616, 0.0569573220127495, 0.05236748744209763, 0.1251052290899679, 0.013529668485716684, 0.04479539180465508, 0.05393317784182727, 0.05947364050371107, 0.030646209052065387, 0.042820945018320344, 0.007410547714243876, 0.02838220778357936, 0.0835612641822081, 0.03166725953633431, 0.007447648604284041, 0.033671076816972345, 0.028988783633394632, 0.03820868274488021, 0.04784261676832102, 0.026583124927128665, 0.07759291256661527, 0.07648545011761598, 0.15766415308462456, 0.03103891092905542, 0.10381791784311645, 0.2397271027439274, 0.17001595435431227, 0.13611503440188244, 0.1638852059841156, 0.12484945531468838, 0.18354312458541244, 0.1469253801042214, 0.15682273573474959, 0.17701152741210535, 0.13219097309047356, 0.11618767908657901, 0.09379782582982443, 0.0835055140487384, 0.10875975305680186, 0.1478238686104305, 0.12793389527359977, 0.097997453995049, 0.15240425564115867, 0.1262176490854472, 0.165437318792101, 0.11793177807703614, 0.14026678662048653, 0.11948354207561351, 0.13398609473370016, 0.10454379764269106, 0.11168558121426031, 0.12807935621822253, 0.12505221005994827, 0.19004619360202923, 0.208187741227448, 0.1710788582568057, 0.09284602143452503, 0.09340479926322587, 0.20121846988331527, 0.12092749428120442, 0.12031044301693328, 0.14399386709555984, 0.08215401117922738, 0.1711430391878821, 0.09841851147939451, 0.22634156397543848, 0.320870783762075, 0.15084613143699244, 0.1204657596827019, 0.10055464998004027, 0.1702927309088409, 0.11920354460016824, 0.12025227348203771, 0.20376326458062977, 0.10525165809667669, 0.21133789094164968, 0.12874679930973798, 0.10607468502712436, 0.08286891461466439, 0.17045977350790054, 0.1672543931636028, 0.237292546662502, 0.18135567399440333, 0.17212497477885336, 0.06442912752390839, 0.08513958964613266, 0.15525720489677042, 0.12101798434741795, 0.12121061619836837, 0.0999569687701296, 0.10302971990313381, 0.1308060809969902, 0.12883342278655618, 0.17648527049459517, 0.12120367711759172, 0.06681529557681642, 0.13364270300371572, 0.09883461141726002, 0.12187958069262095, 0.12300523318117484, 0.12480118602979928, 0.0886844506021589, 0.11285870146821253, 0.12028330267639831, 0.13048130233073607, 0.143004005367402, 0.18415763770462945, 0.10583555762423202, 0.12527587852673605, 0.08329124859301373, 0.2691133157350123, 0.127566012670286, 0.22858268668642268, 0.21617964754113927, 0.1878810816560872, 0.11361822282196954, 0.15220647328533232, 0.16894579224754125, 0.12114094337448478, 0.0850032942253165, 0.09274025054764934, 0.10980132763506845, 0.11161195274326019, 0.169599179062061, 0.11536768754012883, 0.10549747967161238, 0.1051647451822646, 0.10126935303560458, 0.09396697612828575, 0.10162191771087237, 0.1482329997816123, 0.1123354873561766, 0.15733725187601522, 0.16185078624403104, 0.08082886197371408, 0.1273537435918115, 0.1760264451149851, 0.08590586454374716, 0.10216141454293393, 0.11065637081628665, 0.11057973664719611, 0.15693371649831533, 0.13379994925344363, 0.19213063409551978, 0.15421312185935676, 0.13685569778317586, 0.12115573437768035, 0.11959519077208824, 0.18794042378431186, 0.18262918456457555, 0.15271702635800466, 0.17714845365844667, 0.10670931776985526, 0.13278492871904746, 0.09959573580999859, 0.21605376445222646, 0.15339919365942478, 0.16030484810471535, 0.062268512992886826, 0.17604416760150343, 0.11468398399301805, 0.1507260964717716, 0.07741782508674078, 0.13717185269342735, 0.10222471973975189, 0.06616711121750996, 0.13438428664812818, 0.19258034590166062, 0.11213392004719935, 0.1977970651932992, 0.19549109361832961, 0.16140447347424924, 0.11765642644604668, 0.11072804743889719, 0.10750559027655981, 0.15323323459597304, 0.13446709548588842, 0.13089913147268817, 0.14756843622308224, 0.13965151651063934, 0.09935875321389176, 0.23128349566832185, 0.18933601764729246, 0.17620174039620906, 0.21387005428550765, 0.09222145963576622, 0.11319633413222618, 0.1238933984132018, 0.23302162036998197, 0.11357160110492259, 0.09767326162545942, 0.14755289565073326, 0.10209928936092183, 0.12666448135860264, 0.1560533363954164, 0.1242912415182218, 0.15531368233496323, 0.16170750721357763, 0.34877227095421404, 0.1218577021791134], [0.0258539147398551, 0.03364900163433049, 0.10070319825899787, 0.045519675986724906, 0.0332748367509339, 0.07261867518536747, 0.0933439283107873, 0.02935749558673706, 0.016203480918193236, 0.03579722972062882, 0.04593485195073299, 0.030879304649715777, 0.0509919055912178, 0.09110063110711053, 0.04023727662570309, 0.03455760561337229, 0.04261859845428262, 0.03650804021162912, 0.014896382599545177, 0.021335628771339543, 0.0295069437197526, 0.011861645198223414, 0.03502331812342163, 0.03993170103058219, 0.04123087506741285, 0.06096683791838586, 0.013265977850096533, 0.056425346847390756, 0.042358241917099804, 0.02177486145228613, 0.0027400528233556543, 0.006217253567228909, 0.04193430861050729, 0.03435439815802965, 0.05169585121620912, 0.00840496066302876, 0.1005421818990726, 0.013971636908536311, 0.06645177680184133, 0.07741486391751096, 0.01499816444265889, 0.02668387518497184, 0.04253164843248669, 0.061856680404162034, 0.048015741267590784, 0.04795031352841761, 0.02224184303486254, 0.06079939084884245, 0.02736303493293235, 0.022839125340397004, 0.032597452591289766, 0.03219532729417551, 0.05836982199980412, 0.034310529808863066, 0.028201826935401186, 0.03159205400152132, 0.03470677729637828, 0.04855132327065803, 0.03733864075911697, 0.08032912941416726, 0.06068324844818562, 0.03608447797887493, 0.056707429757807404, 0.00847517432703171, 0.01582287048222497, 0.02470312756486237, 0.0070412490003946004, 0.05728744043153711, 0.04611475596902892, 0.02679077413631603, 0.007183418056229129, 0.08243532967753708, 0.08179673386621289, 0.043334759830031544, 0.025133515700872522, 0.06378370395395905, 0.013314158077264437, 0.02494361124263378, 0.03287083382019773, 0.1144117048534099, 0.042146804044023156, 0.022713017751812004, 0.04168226041656453, 0.033781634556362405, 0.058682466551545076, 0.025797658090596087, 0.04019957923446782, 0.06377480560331605, 0.04658333316911012, 0.04583056164847221, 0.039062356663635, 0.02124986804119544, 0.04013784367998596, 0.051798746280837804, 0.025329385171062313, 0.031156851182458922, 0.016090167955553625, 0.04049166258482728, 0.01099630100725335, 0.02222188482846832, 0.03427574905799702, 0.10668265982531011, 0.021226015414868016, 0.036980866207159124, 0.021501521041500382, 0.05458597093820572, 0.04063368367496878, 0.07155173399951309, 0.03113008562650066, 0.03826517131528817, 0.02405572060524719, 0.011157814606121974, 0.030720822724106256, 0.013022748225921532, 0.021743399956903886, 0.028391232299327385, 0.06108247194788419, 0.031580951472278684, 0.05447436677059159, 0.06328695482807234, 0.06124974832346197, 0.027546042983885854, 0.07774021403747611, 0.0567360469722189, 0.05501987870957237, 0.02851995224773418, 0.023499731396441348, 0.06860266919829883, 0.034444268530933186, 0.013009259691898478, 0.051676907896762714, 0.05574723538302351, 0.012790855835191905, 0.013142333264113404, 0.010243862525385339, 0.025467487721471116, 0.013959060288470937, 0.011771431582019432, 0.10427419023471884, 0.014987449685577303, 0.03737773709872272, 0.04637532772903796, 0.03894097841111943, 0.02589411502412986, 0.05132121135829948, 0.03458349914581049, 0.04954397176334169, 0.019288021067040972, 0.01352507923002122, 0.08729886831133626, 0.057417216085013933, 0.07029979024082422, 0.03602498742111493, 0.03959498862968758, 0.04359476384706795, 0.08739870201679878, 0.03141358232824132, 0.045115569155314006, 0.025485193509666715, 0.013701568441319978, 0.06336244608974084, 0.042392083851154894, 0.021305668269633316, 0.050136279824073426, 0.05171862772840541, 0.034863808323279954, 0.06404776751878671, 0.011293219449726166, 0.07231194555060938, 0.01945177780726226, 0.06607009025174193, 0.046425159234786406, 0.05057074420619756, 0.06241114635486156, 0.031088582873053383, 0.029058766303933226, 0.053987644059816375, 0.06063099754101131, 0.06275306863244623, 0.06233723586774431, 0.004104734844077029, 0.034443956828908995, 0.01349291269434616, 0.04812641032913234, 0.01990993339859415, 0.033007466918206774, 0.028388430691848043, 0.04246206095558591, 0.06230157567188144, 0.052738943486474454, 0.06077222824387718, 0.06097078985476401, 0.04986376690794714, 0.009221937234542565, 0.04730696797196288, 0.01768925128999399, 0.023134717193897814, 0.0210373225127114, 0.031434362463187426, 0.024956485649454407, 0.07381590039585717, 0.04987337400962133, 0.07171311401179992, 0.007679405553062679, 0.04423637277795933, 0.013894519415771356, 0.043900424789171666, 0.022992851954768412, 0.019177949434379116, 0.03632068131992128, 0.02514053827326279, 0.01920408416481223, 0.06222752788744401, 0.03730988253664691, 0.046138872057781555, 0.025148607273877133, 0.011069868251070147, 0.047408894533873536, 0.042453548521734774, 0.056253988659591414, 0.0896058492071461, 0.0173988117967383, 0.00825890971100307, 0.03892218352120835, 0.0727695834939368, 0.019144038851663936, 0.047306381675298326, 0.018080502268276177, 0.1057408818451222, 0.04145580889598932, 0.014476850228675175, 0.03734404359420296, 0.00494237698148936, 0.08366091977222823, 0.05931473926466424, 0.07014030270511284, 0.08978492944152094, 0.012984399600100005, 0.06177936716994736, 0.05642583666485734, 0.018621424023876898, 0.018953583348775283, 0.015950855704431888, 0.050151011455454864, 0.02225268766778754, 0.018162806445616297, 0.028459602654038463, 0.050279325078008696, 0.10200091768638231, 0.0653993446030654, 0.024147806288965512, 0.035563701821956784, 0.010594629347906448, 0.011078401093982393, 0.03611428262956906, 0.0344370066159172, 0.056540884397691116, 0.03555710041837301, 0.032625921376165934, 0.006064865601729252, 0.008994460622488987, 0.09878008582745679, 0.02975689905724721, 0.06254128937143832, 0.04700175231846515, 0.03383985604159534, 0.041455571408732794, 0.022530085770995356, 0.043685068376362324, 0.04459867443074472, 0.011527561855473323, 0.04874059319263324, 0.009092348973354092, 0.039187954025692306, 0.017124033474829048, 0.03704473543621134, 0.06333337616524659, 0.018317277063033544, 0.024469391864840873, 0.03928933881979901, 0.05485944864631165, 0.054470292379846796, 0.040366213652305305, 0.09736672494909726, 0.07092473053489812, 0.02548235293943435, 0.06440888915676624, 0.021930996335868258, 0.05451565244584344, 0.04830341997148935, 0.008014512131921947, 0.09010082460008562, 0.029348480347834993, 0.03253938695706893, 0.014669317879452137, 0.04357362005976029, 0.06834305109805427, 0.013114373778080335, 0.052807180254603736, 0.011925840972253354, 0.07494877398130484, 0.03056013105378952, 0.024673994557815604, 0.027497100199980196, 0.017948427812370937, 0.010995500415447168, 0.08857381122652441, 0.043371770734665915, 0.019843884110741783, 0.032482085734955035, 0.07596030642162077, 0.06819128931965679, 0.05118216999107972, 0.06398697078111582, 0.022678064451611135, 0.016495319359819405, 0.019819773588096723, 0.05683666735421866, 0.047823502754908986, 0.002706976924855553, 0.02004742553253891, 0.031193828690447845, 0.05581845558481291, 0.022706477575411554, 0.026665703699109145, 0.06699822755763307, 0.03905273842974566, 0.024373959095100872, 0.019721014141396154, 0.04009809796116315, 0.011104274217359489, 0.03151194287056569, 0.009491391574556474, 0.038309403316816315, 0.014360002787725534, 0.008510116495017428, 0.03521094418829307, 0.05313807421771344, 0.012568113197630737, 0.04845152667257935, 0.029845322242181282, 0.04082240440766327, 0.012248231778357876, 0.04140299395658076, 0.10472116351593286, 0.030496387989842333, 0.07006834406638518, 0.013554119468608405, 0.12481837416999042, 0.02900648756622104, 0.03851849600323476, 0.026451028206793126, 0.16236181429121643, 0.09307751213782467, 0.17884093627799302, 0.13955380534753203, 0.09237420104909688, 0.15616467338986695, 0.09224601730238646, 0.1015651434136089, 0.16365845018299296, 0.0880203842825722, 0.16208757588174194, 0.09708792975288816, 0.13402634882368147, 0.1741857556044124, 0.2273681471706368, 0.12359634638414718, 0.1089132959896233, 0.1577645359793678, 0.14782971673412248, 0.08294332234072499, 0.10634131642291322, 0.10467866813996807, 0.10387940477812663, 0.11105791723821312, 0.1388539600884542, 0.15927930391626433, 0.2024754454032518, 0.17372495611198246, 0.18622791802044958, 0.10954457422485575, 0.193828460178338, 0.10728022229159251, 0.14875618420774117, 0.2029166670399718, 0.13445970369502902, 0.088237187883351, 0.11110626073786989, 0.08309589306009002, 0.20630865299608558, 0.13748828961979598, 0.10901775327511132, 0.1668127707671374, 0.10966085392283276, 0.23094547708751634, 0.17045005137333646, 0.09345853817649186, 0.1321921159978956, 0.13941091223387048, 0.11610955320065841, 0.10681467305403203, 0.16510360466782004, 0.16245372185949236, 0.19247651944169775, 0.19956634525442496, 0.10845770637388341, 0.1190613565267995, 0.08239217379014008, 0.19739314389880747, 0.18009921797784045, 0.22512243798701093, 0.22301936958683655, 0.10071477576275356, 0.1233711490931455, 0.23126745043555275, 0.07922761156805791, 0.12466284970287234, 0.10992396753863432, 0.12504415033617988, 0.1259556264267303, 0.08615351922344416, 0.13461599999573082, 0.1433519390411675, 0.17137323855422437, 0.22381042479537427, 0.11497099476400763, 0.16883157572010532, 0.15148528385907412, 0.08952418327680789, 0.10123980071512051, 0.22757575556170195, 0.14171841263305396, 0.07786503585521132, 0.22799028956796974, 0.09230918891262263, 0.09036967501742765, 0.18713494122494012, 0.11454054911155254, 0.15621600032318383, 0.18265667371451855, 0.09420686052180827, 0.09752945567015558, 0.10698915197281167, 0.1691101779579185, 0.16051965532824397, 0.1263250081683509, 0.0996622173988726, 0.16260816279100254, 0.10984515145537443, 0.09878994154860266, 0.13829737901687622, 0.12271655999938957, 0.20018424256704748, 0.10418737379950471, 0.11121189061668701, 0.10944560141069815, 0.2101418754318729, 0.13481450965628028, 0.1473796190111898, 0.13891925424104556, 0.13029583962634206, 0.12878288252977654, 0.19548548298189417, 0.1534068229375407, 0.1740692532621324, 0.1154085724556353, 0.1916055052424781, 0.11555598524864763, 0.08842525552609004, 0.125692282745149, 0.16614311607554555, 0.13947066996479407, 0.108538533677347, 0.10185123392147943, 0.10379766463302076, 0.25451957539189607, 0.1759129558922723, 0.1060705364216119, 0.15710889303591102, 0.12873045721789822, 0.07588290784042329, 0.22358916088705882, 0.11315004638163373, 0.11552336043678224, 0.10067711176816374, 0.21960584650514647, 0.18127319170162082, 0.15643097081920132, 0.1406642363872379, 0.129180139338132, 0.1581512691336684, 0.10738929573562928, 0.13995898829307407, 0.12426927394699305, 0.11864250322105363, 0.13055916846496984, 0.14847716636722907, 0.16322384850354865, 0.099748707289109, 0.10218554176390171, 0.16677006758982316, 0.12183223909232765, 0.22582390112802386, 0.10159695186302997, 0.11288938927464187, 0.09281563790864311, 0.2376455714693293, 0.07346666796365753, 0.1367302896687761, 0.14484383398666978, 0.09361647462355904, 0.15203895571175963, 0.153039192664437, 0.07433564867824316, 0.16162129933945835, 0.1478382365894504, 0.16786387452157214, 0.14134965429548174, 0.14335760904941708, 0.20784461667062715, 0.10283911411534064, 0.13402965880231932, 0.18539129494456574, 0.1387303925002925, 0.19652701303130016, 0.16323352610925213, 0.07364692079136148], [0.057751620406634174, 0.03758904138521757, 0.041793337659328245, 0.06197921640705317, 0.029777252457279246, 0.048015537176979706, 0.03542393686075229, 0.08722440121346153, 0.06340727923088707, 0.07227804424474016, 0.031221599856507964, 0.04936027908115648, 0.01961076068255352, 0.05514415133802686, 0.07772194978315383, 0.08018778738914989, 0.033544681646162644, 0.01711695338599384, 0.05366062781831715, 0.08130132060614415, 0.008376915830012877, 0.09907165338518098, 0.03827322361757979, 0.0913844580645673, 0.06016953011567239, 0.007057368911773665, 0.06096650024119299, 0.0492007470165845, 0.029475051778717898, 0.023694480223639403, 0.02486818306351779, 0.035215942552895285, 0.05043387362093199, 0.07655613968381658, 0.011238186416449025, 0.0682391801092308, 0.07302214376977645, 0.07066167629091069, 0.028440750247682445, 0.03389104938833043, 0.032217547195614316, 0.01692930320132291, 0.07753616795525886, 0.027529778817552142, 0.020760015322593972, 0.15097312774742022, 0.016963564448815305, 0.12795100919902325, 0.03755596757400781, 0.026952378648275044, 0.029178610166127328, 0.06857342857983895, 0.016396307582908776, 0.05958737834589556, 0.07985421427292749, 0.0442555684276158, 0.021444325575430412, 0.0385808326973347, 0.032146041266969405, 0.08190761072910391, 0.05061937714344822, 0.0663056924531702, 0.011384560202714056, 0.010892403115576599, 0.03249288769438863, 0.04483212069317233, 0.030264101333159488, 0.02586625294497935, 0.05990042736812029, 0.020529791836452205, 0.02259404591313796, 0.035699577929335646, 0.036491378996288404, 0.060044096026103944, 0.028791199802071787, 0.06296323743299581, 0.03543667582562193, 0.04967519831552636, 0.03663747076643631, 0.05289147709845565, 0.061248375350260176, 0.06459098993218504, 0.0780811344156973, 0.07889250220614485, 0.10033187209046446, 0.013069197393633658, 0.05281089099298697, 0.05166963113879319, 0.02824249106197385, 0.03503089916193858, 0.027762716708821245, 0.02597925420559477, 0.0546438065066468, 0.05157193110790104, 0.038089033696451224, 0.030999966729723383, 0.014964467227400746, 0.01608414913789602, 0.028578095807461068, 0.05543095430766698, 0.017070355788746383, 0.0020203994108669576, 0.02660739130078582, 0.04304770453018136, 0.028181419729662593, 0.049688954022713006, 0.064573957643006, 0.05071074665465858, 0.010593640436127316, 0.07568950415588915, 0.019598090366343968, 0.0043840411944984226, 0.0579899759759428, 0.01291229253183701, 0.05194433710130397, 0.021341116953408346, 0.01809381639759522, 0.02779896320134867, 0.06892500619869679, 0.07349193809204735, 0.027484277743496932, 0.04139477096032351, 0.0300795403381926, 0.03130094657535665, 0.13504705420928076, 0.014133796175883617, 0.014583749180019367, 0.018396874256723095, 0.015059909273986705, 0.0961144694883842, 0.036432430206332356, 0.04184599303698633, 0.12290445694816299, 0.0538355483149644, 0.012202216767036589, 0.060472556433524005, 0.05440109453047626, 0.08932252691010945, 0.040513299900339916, 0.05645672485115938, 0.06825006741564721, 0.08605622366303578, 0.021320691193977837, 0.04626620233466383, 0.033821925753727555, 0.01814661649405025, 0.03787140631175134, 0.035474295291351154, 0.03352573832671624, 0.08193703688448295, 0.07441525885951705, 0.0506870164826978, 0.022524562336911913, 0.04950938768160995, 0.05446243674668949, 0.07381180374068208, 0.003840103768197878, 0.012764966013492085, 0.04740931013657246, 0.03729989693965763, 0.09835121352807619, 0.0320979946263833, 0.009684826800366864, 0.012496528415795183, 0.03330381390696857, 0.050244874582858756, 0.04304318856156897, 0.030571075876650866, 0.03517208904668223, 0.04659863996494096, 0.024943375610746443, 0.03478088816336822, 0.03550297929905355, 0.016868923921720125, 0.04546382566331886, 0.006123960038166842, 0.018459186831023544, 0.09187815696350299, 0.011046712315874174, 0.05457057508465368, 0.017628057503316086, 0.011939874057134148, 0.012807043003704166, 0.027557117682590615, 0.024276602307509165, 0.028533960285130888, 0.0652938854182139, 0.026687879071687348, 0.008683202959218761, 0.017226277304871473, 0.0570936100120889, 0.03406581403396558, 0.04035875877889339, 0.023361504536296707, 0.011084825309808366, 0.06621840104344301, 0.00974445558313164, 0.04378839017590508, 0.052887209749314934, 0.05834206567669753, 0.04363539643236436, 0.016218327582464553, 0.03947100543882698, 0.02840452787495451, 0.015453566666110419, 0.05377004265028518, 0.017136013593699317, 0.029479443437594455, 0.034741673080134206, 0.07800394363584928, 0.004114679159101797, 0.041233483716496266, 0.03371440339833498, 0.060061172844143584, 0.08805568082607351, 0.06406399828847498, 0.06287686628638767, 0.03909433580702171, 0.025251630358980037, 0.03182347791153006, 0.06390832539182156, 0.013272207252157386, 0.02969427663629176, 0.014948447969800327, 0.011734443869499955, 0.07663822121685371, 0.018054703359666746, 0.11480971123091877, 0.12247927312273532, 0.0045403231160889845, 0.08547404591809027, 0.04751244639919605, 0.01565247708640527, 0.009133577132161008, 0.03772616801143158, 0.018716751037572976, 0.05925388315517921, 0.04595537975546904, 0.00987926763627911, 0.016689762051100843, 0.05426229807198979, 0.05443783084047027, 0.04096863718586974, 0.031480182660743594, 0.0110527487595391, 0.031076699233381078, 0.027593991289904807, 0.03999774846306536, 0.018031637409876566, 0.014693974808324128, 0.042675228032749146, 0.02955922802357236, 0.03590579850424547, 0.01734224530082429, 0.07079684364725836, 0.04743036857689731, 0.07190202770289034, 0.029575716689578258, 0.03429212454648223, 0.05223492131335661, 0.06020351676852442, 0.009052050354512176, 0.014531708857248304, 0.02382634502282599, 0.027727305132430047, 0.03069362857786473, 0.016374241677112877, 0.0319175748154521, 0.060447045107139274, 0.0431435269274516, 0.04464125515369233, 0.0151003674545791, 0.020234498697391246, 0.0462941182195209, 0.027263832052994985, 0.027286298718536273, 0.013861063398508122, 0.013213142501626862, 0.019776487824856304, 0.0277088794609881, 0.022944174488657154, 0.023621753462066408, 0.004928807275064173, 0.09102465002797544, 0.0210149244958302, 0.03814952986431308, 0.04292005512979813, 0.04501303774304688, 0.006661380712102982, 0.048904069772106595, 0.020619933093257714, 0.06269061690545641, 0.04905922687612474, 0.05098870322399307, 0.04127087311644573, 0.02145295304217143, 0.012089769334124867, 0.023659892431169283, 0.035919476285926066, 0.03766937144973781, 0.02357454544835491, 0.056594189154566266, 0.007727416477791849, 0.030094717258180026, 0.026857547018153127, 0.04003279267635662, 0.019128507556160912, 0.0135142169710889, 0.0849423416366335, 0.0431380610098131, 0.04876011167652905, 0.035051300801569596, 0.07019643133389764, 0.03562089543265756, 0.051426266072667204, 0.015115333790163277, 0.022158523970574606, 0.06068703340133652, 0.049314499701722525, 0.026034251059172675, 0.025102328800130635, 0.03885038444423117, 0.02079080331895966, 0.005751893577325973, 0.03004304708156269, 0.10801800613990054, 0.055684297549305484, 0.028854074553237297, 0.030961401025706436, 0.03744992951396853, 0.03862716497678775, 0.03396367967070546, 0.01796710024791537, 0.032278392172884196, 0.018499964135116898, 0.02510879476176342, 0.10610593686578795, 0.03944160525861662, 0.05282476544380188, 0.015509493987337919, 0.04362247193057556, 0.014075168364797719, 0.0308052902619238, 0.06462226403527893, 0.03377832457772456, 0.040558730470365845, 0.005166490736883134, 0.054284703510347754, 0.01262839321498177, 0.0026893277254202985, 0.055606631794944406, 0.0330035001388751, 0.16482761478982866, 0.18663274473510683, 0.14609064208343625, 0.18685687333345413, 0.07516269062762149, 0.18973248777911067, 0.11277089797658846, 0.16705669986549765, 0.11791659373557195, 0.13752711878623813, 0.13088629231788218, 0.08701170911081135, 0.09349197192932479, 0.16316817258484662, 0.2585422829724848, 0.14756928227143362, 0.08494500594679266, 0.07830907765310258, 0.13125372963258997, 0.12316987122176215, 0.09477984305704013, 0.21835157240275294, 0.1340263191377744, 0.13365980208618566, 0.18896276189479977, 0.17717720445943996, 0.1820767149911262, 0.12568137317430228, 0.13420333620160818, 0.10950483963824809, 0.14847165963146836, 0.16496169118909165, 0.2737728750798851, 0.12339459353825077, 0.12046556672430597, 0.10692882278817706, 0.134830154129304, 0.15153301879763603, 0.22804204694693908, 0.2842154569225386, 0.1648039254359901, 0.1666131181991659, 0.18343681935220957, 0.10785868187667802, 0.13151325867511332, 0.2304088301025331, 0.14362053712829947, 0.19485689874272794, 0.1007417231448926, 0.12464720522984862, 0.08160937868524343, 0.2088449426810257, 0.22829623252619058, 0.13124471995979548, 0.18568353785667568, 0.20105481147766113, 0.10927473675110377, 0.10431796210468747, 0.08501147269271314, 0.1276585436426103, 0.14922053116606548, 0.12550886836834252, 0.0848296019830741, 0.08684672226081602, 0.12498363561462611, 0.16757434786995873, 0.14435364544624463, 0.10427057597553357, 0.28058760159183294, 0.1398125773994252, 0.12787768500857055, 0.11356789036653936, 0.09951340936822817, 0.18349822465097532, 0.16368840326322243, 0.14820493175648153, 0.09380602656165138, 0.10686910958611406, 0.19578688399633393, 0.1851702091516927, 0.1662627057521604, 0.18975734972627833, 0.23688869958277792, 0.16032218467444181, 0.2953572606202215, 0.10871460821363144, 0.12393930766847916, 0.11521244508912787, 0.10962490428937599, 0.10450180692714639, 0.1636134463478811, 0.09461404726607725, 0.1237681758357212, 0.13906266685808077, 0.20699898392194882, 0.12730238697258756, 0.10381203261204064, 0.11005237392964773, 0.19670395588036627, 0.12760132405674085, 0.07556533542810939, 0.1136335036426317, 0.15686432569054887, 0.10214792229817249, 0.2547808410599828, 0.10658973551471718, 0.18090287485392764, 0.20998366439016536, 0.10099063947563991, 0.12635861261514947, 0.1706482344889082, 0.12631895224330947, 0.1737984287319705, 0.12157488454249687, 0.1803427463164553, 0.18859625968616456, 0.11326267471304163, 0.14585535158403218, 0.1202353673579637, 0.27285970689263195, 0.09482414185185917, 0.07711313635809347, 0.12320100431679748, 0.1579117335495539, 0.2455790707608685, 0.20177487283945084, 0.17947294923942536, 0.227393469249364, 0.13840668252669275, 0.23071720730513334, 0.1196711792727001, 0.13370857603149489, 0.2546400111168623, 0.13183005183236673, 0.1709181535989046, 0.17982989258598536, 0.15394937741803005, 0.22637604415649548, 0.2046441048150882, 0.15212785016046837, 0.17927133740158752, 0.15915732452413067, 0.1833573798649013, 0.14086200390011072, 0.09362335433252156, 0.12104378140065819, 0.08834424268570729, 0.18871810549171641, 0.11196368621313013, 0.22310479078441858, 0.17957002215553075, 0.13425077428109944, 0.17485901713371277, 0.1493946390110068, 0.13910551846493036, 0.21216850262135267, 0.16427087044576183, 0.10774008667794988, 0.16797534510260448, 0.14882327435771003, 0.22542112274095416, 0.08833125510136597, 0.15825496200704947, 0.06532141167554073, 0.10079487576149404, 0.0893541646655649, 0.12101322718081065, 0.10489244377822615, 0.15434371016453952, 0.10899932574830018, 0.14435226505156606, 0.13280389801366255, 0.1244223047979176, 0.08594878294388764, 0.16536068462301046, 0.15887009853031486], [0.04394339142891113, 0.012156581178714987, 0.01559772699692985, 0.04628682661859784, 0.02396798947302159, 0.05798535610665567, 0.048649386953911744, 0.023403396917274222, 0.02718952080613235, 0.016470052942167968, 0.03402128888410516, 0.008574795592721784, 0.04671038142987527, 0.010537584166740999, 0.03390835627214983, 0.008548153418814763, 0.018961414862133097, 0.013607920536742313, 0.007664179929633974, 0.025279640867665876, 0.018473189302312676, 0.06855442959931679, 0.028458706510718912, 0.07191374621470459, 0.05156178223842289, 0.05595173417532351, 0.01956159896508325, 0.09171627971227281, 0.05576155141170602, 0.036638546880567446, 0.03807952678471338, 0.025783188066270668, 0.01640423186472617, 0.009630276163079543, 0.03869546853820793, 0.03205847897334024, 0.02737837512540864, 0.024511761075700633, 0.006004081387800397, 0.026916837196040433, 0.011401971914892783, 0.01595213034306653, 0.05791533818410244, 0.020314222056185827, 0.033952784942812286, 0.08187940911739133, 0.042444390419404954, 0.06694842202705331, 0.03430844437389169, 0.07012472502538003, 0.07120008216588758, 0.053748442442156374, 0.04642749328922946, 0.06438114025513642, 0.04296048733522184, 0.03233145202102605, 0.047123549884418026, 0.02884586083382601, 0.02221245213149814, 0.052634790481533855, 0.0794075898011215, 0.042774364119395614, 0.09560174192301929, 0.03380847803782672, 0.061096528224879876, 0.026464188340469263, 0.015202039830910508, 0.04717116607935168, 0.012967578823008807, 0.04507882913458161, 0.06357406949973665, 0.02281876080814982, 0.028140336289652623, 0.0198599701616331, 0.028031214606016874, 0.03973842351115309, 0.0467527580622118, 0.041065569093916565, 0.049448342324467376, 0.0805738971394021, 0.06520749200717546, 0.06467652987339534, 0.03456568760157097, 0.025472165107203182, 0.009087786620511906, 0.05193956138100475, 0.06346245048916899, 0.01574418056407012, 0.12400344407069497, 0.024226705863839015, 0.0457919439941179, 0.02020971653109882, 0.024757445353316143, 0.026536731420492288, 0.020511766924755648, 0.04334774741437286, 0.01657747881836258, 0.052469699730863795, 0.01761466915922938, 0.057138472839142196, 0.043066009602625854, 0.03176094083755743, 0.053932079463265836, 0.045393214022624306, 0.025152729904220905, 0.07843793675419874, 0.05381675342505332, 0.05042652635893319, 0.05438183950900566, 0.011984806460532127, 0.03917483285476919, 0.026213871205982286, 0.04020272222987842, 0.05124699659063481, 0.024010212109715212, 0.10400342507637106, 0.065461581107229, 0.048235387293971144, 0.011924858554266393, 0.03891823158483021, 0.047204236179823056, 0.07530658564064652, 0.011413107840780867, 0.022656581131741405, 0.03939512826036662, 0.05302678546286188, 0.060025360508007, 0.005469748048199108, 0.027283170566079207, 0.025579559442121536, 0.05840600912051741, 0.016361560228688177, 0.020273884474590886, 0.04359448925242759, 0.0426713874185225, 0.08629395582829602, 0.0541762683133129, 0.044737248244928196, 0.05649933897075243, 0.030027677203179337, 0.042526857869233936, 0.037689220189349726, 0.012684204575634794, 0.019346236986166332, 0.05001554724003654, 0.013892498918721685, 0.020084410462004598, 0.06175634574901778, 0.024879459997464437, 0.030989409679023083, 0.030451072452706285, 0.0774556226679124, 0.05649205108056776, 0.08417540622758679, 0.024127293327182997, 0.02637541820149636, 0.02661437862116145, 0.030717134250153322, 0.10188236701651476, 0.08769377251155674, 0.04178963805316016, 0.0529355309845414, 0.05321041877323296, 0.03584693135053385, 0.09059392235940322, 0.022614558874920476, 0.07340523297898471, 0.034534788283053786, 0.028304853731242474, 0.024160775319614913, 0.01993452817259822, 0.04398046170535963, 0.016935244093474466, 0.07275205396581441, 0.0642761040944606, 0.03921196250303183, 0.03451295429840684, 0.005056835170762497, 0.09101001487579197, 0.0878369773272425, 0.013026628730585799, 0.020602464792318642, 0.006479048015535227, 0.008145943702402292, 0.055432201115763746, 0.04019532301754225, 0.03680366360640619, 0.022720229571859818, 0.03327329679450486, 0.0245037347485777, 0.017088321328628808, 0.050580377283040434, 0.034880298844655044, 0.03634166183474008, 0.07223866588901728, 0.023889674339443445, 0.016992704877338838, 0.09859397003310733, 0.006849612555015483, 0.06148032989585772, 0.034305542576476, 0.051034245116170496, 0.057250945319538005, 0.08303688489831984, 0.04392247399664484, 0.039597177965333685, 0.06020549459208269, 0.029964435088913888, 0.022639279814029578, 0.055405713865184225, 0.04500956449192017, 0.018408863652439322, 0.06536664557643235, 0.0734865055710543, 0.02021145872276975, 0.008326457209477667, 0.05218055157456547, 0.029706744717259426, 0.0659882758918684, 0.048246601145365275, 0.042849105811910704, 0.05232980118307751, 0.09077014532522298, 0.02174380628275685, 0.029342192501644604, 0.026016177907877136, 0.07941256219055504, 0.0588056482229149, 0.013501067969627911, 0.04052137446706183, 0.0548803289711941, 0.03683112307044212, 0.059443639183882624, 0.038713202156941406, 0.005711163121304708, 0.02214990949141793, 0.13324756873771548, 0.03066199082240928, 0.03486962305032648, 0.05083194308099337, 0.0631335454818327, 0.03479168641206343, 0.012304261144890916, 0.026807522554008756, 0.0226154828487779, 0.03791720424487721, 0.0025685668470032397, 0.023089399801392574, 0.04959841571690049, 0.047881304926704615, 0.05439935048343614, 0.03362222123541869, 0.04097742050362285, 0.024651294115756173, 0.009520808453089558, 0.041362413321621716, 0.056979141154442914, 0.022374221771315206, 0.015034150255814893, 0.03403280701604672, 0.04827456898055971, 0.006990995398155064, 0.02408142860076623, 0.021758717884949874, 0.03187235204677563, 0.08900346278096549, 0.03274123999290168, 0.02146480885130586, 0.03692758742545266, 0.011292363196844235, 0.022811159360571764, 0.03667468947242014, 0.04844381575821899, 0.12464419211028144, 0.03811128328379709, 0.034000590385403484, 0.0821173565054778, 0.030119664552330505, 0.07601683581015095, 0.0234153083874844, 0.07640686410013586, 0.021032806544099003, 0.05521760540432297, 0.005863488004251849, 0.07110464939614758, 0.08334548474522308, 0.031375124235637486, 0.10334706224966794, 0.037801566504640505, 0.010075793907162733, 0.01590591866261093, 0.055565078946528956, 0.05087060526420828, 0.020726370057673194, 0.023852171761973295, 0.042960305509041063, 0.0323693757673027, 0.05847973778145388, 0.029470025583577808, 0.022430895878642332, 0.06598480264074169, 0.04092929222679231, 0.03240198944695294, 0.03902090771589428, 0.030451087295659818, 0.07250376103911549, 0.0745746202301234, 0.07721484027570114, 0.017647483218752313, 0.1102282184001524, 0.033355103732901625, 0.07971457918756641, 0.053772495448356494, 0.06440186101826839, 0.05631547930533998, 0.014917852931830566, 0.05203027409152128, 0.031016301400086377, 0.020278871706977952, 0.03799724487180356, 0.07982141134561971, 0.006628511919188895, 0.02524975086998893, 0.05466984846862033, 0.07186719129094854, 0.04654906450014096, 0.003100799444837321, 0.03734893434739206, 0.0689791161858011, 0.026796071215358097, 0.08402315463172272, 0.04039975130581297, 0.029543147538788617, 0.07133360195439309, 0.03389640027307905, 0.059746175684267655, 0.030737619381397963, 0.02129760669049574, 0.03339182891068049, 0.028009434427076485, 0.07180064290878363, 0.03736392573046032, 0.06827721517765895, 0.021945555417914875, 0.06847343902336434, 0.029796023227390833, 0.041368654783582315, 0.11117818226921372, 0.04757060480187647, 0.046905210037948564, 0.029353677236940712, 0.007645181412954116, 0.14369777985848486, 0.11649993030005135, 0.16266472928691655, 0.23309098149184138, 0.173405431851279, 0.1348299760138616, 0.11109157363534905, 0.058035117108374834, 0.17044500476913527, 0.13907514978200197, 0.11314862145809457, 0.11313372655422427, 0.11157929824548773, 0.11350236614816822, 0.13414485496468842, 0.11406676203478128, 0.10394887722213753, 0.07856571974116378, 0.13361678720684722, 0.15483398776268587, 0.1342263279366307, 0.16212904709391296, 0.0921813168679364, 0.2554338419577107, 0.09101638992433436, 0.295352985849604, 0.1392749507795088, 0.18868978513637558, 0.13447678793454543, 0.0812160552595742, 0.14265289530158043, 0.15312974952394143, 0.09369387320475653, 0.2592066238867119, 0.18831774650607258, 0.11905856605153531, 0.16731447743950412, 0.16774826275650412, 0.05587187537457794, 0.16027970414143056, 0.14096991217229515, 0.21695020463084802, 0.11370809690561146, 0.17950783018022776, 0.089481754694134, 0.11336367359035648, 0.2570847643073648, 0.17642251448705792, 0.13284315762575716, 0.20647152472520247, 0.19732011656742543, 0.14818980678683147, 0.13667642459040508, 0.27166998479515314, 0.17373677110299468, 0.13854821008862928, 0.16608724719844759, 0.10940049367491156, 0.0795105256838724, 0.07076194044202566, 0.18091702018864453, 0.17246090050321072, 0.18461532017681748, 0.14894326479407027, 0.17709914536681026, 0.18444756511598825, 0.1538023876491934, 0.13510244811186567, 0.13907780667068437, 0.1230540442338679, 0.1523980958154425, 0.11694354165229015, 0.10856700246222317, 0.10364130896050483, 0.14456103119300678, 0.09456898405915126, 0.13806514616589993, 0.0886213754711207, 0.12594112486112863, 0.098984228388872, 0.2184147885418497, 0.10637957413564436, 0.08327813484356739, 0.10656539307092316, 0.17583396169357002, 0.1977261752472259, 0.08478896197630093, 0.17211295198649168, 0.17075106647098437, 0.14280865725595504, 0.17578273866092786, 0.17077668540878221, 0.1528634669375606, 0.0849348830524832, 0.11544304521521553, 0.08440055898972787, 0.209803901379928, 0.1784379649325274, 0.09469445154536515, 0.1891006826190278, 0.16603216499788687, 0.12604884017491713, 0.11350773187587038, 0.18447477224981412, 0.21476221969351172, 0.17567358358064666, 0.20260918041458353, 0.12485402694437653, 0.1824771481915377, 0.26788630813825876, 0.10058674786705524, 0.1647926596342586, 0.13931380963185802, 0.14206106221536174, 0.13296875869855285, 0.1303366874344647, 0.16799051460111514, 0.12943165318574756, 0.1274368492886424, 0.14911753591150045, 0.18717659055255353, 0.19826671108603477, 0.09311608897405677, 0.08553352163289674, 0.23264843883225694, 0.1412374564097263, 0.13091296510538086, 0.11072707522544079, 0.18413274607155472, 0.11507961549796164, 0.14369159034686163, 0.20751704752910882, 0.08528974838554859, 0.13533196470234543, 0.11301036676741205, 0.1716302294516936, 0.21066880028229207, 0.08868505174177699, 0.1515356608433649, 0.06039465690264478, 0.17779815942049026, 0.10077956525492482, 0.07994661908014677, 0.13683888071682304, 0.11219803418498486, 0.1387953304219991, 0.1385738141834736, 0.23102867184206843, 0.14370485994732007, 0.1354813590296544, 0.2040423863218166, 0.07683752497541718, 0.15872275253059343, 0.18086529249558225, 0.2944762125844136, 0.21877366147236899, 0.08138459699694067, 0.3320615098346025, 0.1769355166470632, 0.19994728965684772, 0.15370077278930694, 0.0864002833259292, 0.13529757357900962, 0.07462518275133334, 0.14278302347520366, 0.10295353844412602, 0.2251608663937077, 0.08192696594051085, 0.16250423243036494, 0.12915925530251116, 0.10826055484358221, 0.24037495313677937, 0.1494803125387989, 0.11730415862984955, 0.2130744422902353, 0.11672879380057566], [0.027766902421717532, 0.04415669209265616, 0.05208129674429074, 0.07841087062843144, 0.03627841972047463, 0.041623426659498364, 0.06020405111485161, 0.04750957799842581, 0.04307405077270232, 0.07027676881989464, 0.0319114224112127, 0.05436505583929829, 0.03655976048321463, 0.0205504420955549, 0.020377209984872025, 0.05604668454907369, 0.05365418968722224, 0.020719293679576367, 0.039268339751288295, 0.007464421141776256, 0.09195732927764766, 0.029914963524788618, 0.027821151561511215, 0.007930573374324013, 0.008293268365378026, 0.03974663537519518, 0.10266326964483596, 0.027069584175478667, 0.0034692903773247963, 0.08469493928714655, 0.02604228851851076, 0.04607795286574401, 0.05704582312318962, 0.10113885378814302, 0.02965370898891706, 0.03666661861643661, 0.0439995905617252, 0.08473461450194009, 0.08775733746006154, 0.03397911634237971, 0.033317521374556236, 0.02727114777371753, 0.014325217398436507, 0.09467985350056551, 0.05983061724691652, 0.03297904637292959, 0.047188409880618565, 0.02860145119484514, 0.07548994064563885, 0.027273528212390374, 0.03499950260447804, 0.07253539879457094, 0.017389277054462582, 0.04405907369800843, 0.04016268707346171, 0.010776135477499338, 0.02148454441339709, 0.04164153135207016, 0.03512469178531319, 0.041720158187672496, 0.0667061033891514, 0.08652880846057087, 0.017240615597984288, 0.03698249151057098, 0.06792620901251212, 0.04248447381542064, 0.05191186814045068, 0.043733244892791845, 0.035790338879451156, 0.029369928415690083, 0.07044020458124578, 0.12286990997381508, 0.021873513287573587, 0.015219099022942828, 0.014977986375015462, 0.005044251129220356, 0.029121882253093645, 0.057307188981212676, 0.018485755717847496, 0.021643326908815652, 0.0543467507668538, 0.03246415544708725, 0.04433802474522963, 0.06650354160228744, 0.03432143566897139, 0.036371755923028104, 0.01901267871289747, 0.07190328935394064, 0.011528928334882949, 0.011511498069012305, 0.05158315609151032, 0.021617294223688077, 0.04326947309891693, 0.04901732892903965, 0.034621129743754864, 0.06359657883876935, 0.04284408518287819, 0.057036015641642734, 0.04236334047163837, 0.02015467700402951, 0.016186712091439404, 0.04641015671950299, 0.06584472968825139, 0.012868778558186023, 0.014803818230575416, 0.05380483824410476, 0.05858063646883238, 0.05478534149006009, 0.05898441304452717, 0.07804090259014629, 0.04017571176518686, 0.04925927278236486, 0.0625943009799812, 0.03065261564188404, 0.035658514898386784, 0.04817580025701318, 0.03790640228544362, 0.03726044436916709, 0.035690865115611814, 0.08113329095067456, 0.03034068169654347, 0.015652345355192665, 0.03188539900293108, 0.05880141798115801, 0.021580422471743077, 0.0635638352832757, 0.03778914295253344, 0.04106172105821315, 0.012160634232714074, 0.035750322276726365, 0.021725883416365832, 0.02610942319734022, 0.016113419442262966, 0.003473111046332633, 0.051894958305638283, 0.04770257721247617, 0.043870438312296756, 0.052290897801867686, 0.07439978508045897, 0.07451803146977909, 0.028374569228617474, 0.03914914712368045, 0.04631883915863, 0.07744119531707838, 0.047790451208129525, 0.05265941123070661, 0.024869839908205904, 0.028699769063678104, 0.008082573567662621, 0.10662875763955526, 0.0791311175271403, 0.05748643248807639, 0.09940624324372038, 0.019818411747110076, 0.029181051831983496, 0.052534114438458346, 0.05866723025974352, 0.03889054947649129, 0.032271334348479286, 0.027232203574385494, 0.09080083313165233, 0.08636992206447758, 0.06136739728390239, 0.056292123917955905, 0.040799950729706325, 0.04834281688090414, 0.031592610612278804, 0.028386619851517025, 0.02504596453945851, 0.00614992129158054, 0.03962996604968794, 0.04999024371500127, 0.13066247542155907, 0.05005662140320055, 0.01540345963803702, 0.01909495134896133, 0.02571109955169959, 0.05985986157611478, 0.03155767029966228, 0.10129116475582123, 0.026112731320608873, 0.032131328189279884, 0.027578476692724507, 0.02156659811589634, 0.051092518551740795, 0.06978580102440901, 0.0081526258145459, 0.07416958571411669, 0.06521800081827678, 0.044940529915038496, 0.06331115626380779, 0.03016187605680898, 0.07679583854041994, 0.07767299030092545, 0.027766650091507472, 0.03724546040757559, 0.02012048069445882, 0.08207641963963397, 0.051021368853980675, 0.015767804979986977, 0.03936268527468201, 0.07612082554260269, 0.05840940444613807, 0.025301189125457313, 0.008329098327521933, 0.01999178115511313, 0.08452140289591625, 0.021704611608583946, 0.06361709922202863, 0.06310803044470958, 0.05300390504999086, 0.027313531827530824, 0.042581216475809924, 0.037000547963543795, 0.06826708486187272, 0.05956952227279544, 0.026391331703052856, 0.09788762356038205, 0.0434373060852522, 0.047623720311094075, 0.015843162655073684, 0.047621779594919644, 0.02114429011271568, 0.033688279800117016, 0.025415808268007822, 0.012097927392460406, 0.017982102763198782, 0.014445209690165939, 0.05065991324954666, 0.042619878659024835, 0.038776845030952245, 0.026816519239218906, 0.08041481778491288, 0.07019261669483967, 0.05071096558822319, 0.06269229415920563, 0.03010366013768362, 0.06284294271608815, 0.04213587591948453, 0.033237900061067194, 0.10356545404647477, 0.01835089820815483, 0.036973225796828046, 0.046194852257031016, 0.03891558211762458, 0.025461899349465966, 0.06817930363467894, 0.07221406369353645, 0.0176361543344683, 0.047104936820687726, 0.036973752721678466, 0.031408506038133055, 0.06100663558754604, 0.0619937068404397, 0.0531803988997126, 0.006850555546407122, 0.0852904311614111, 0.017927168992173392, 0.06106630797148682, 0.03232371513149701, 0.04669945330533665, 0.027317402127664536, 0.04196055837383028, 0.05623102289973758, 0.010307664961146656, 0.07416004169499502, 0.023912844189908355, 0.021958235010970384, 0.027077291379100643, 0.03667573590064421, 0.04434648151800502, 0.09686191609944217, 0.0238817834542715, 0.07112001927453093, 0.03669698358862661, 0.13991083775181323, 0.023968406931089703, 0.0855052012775559, 0.03307751452666707, 0.048538246628595516, 0.06492650747532025, 0.03441361783188768, 0.011073335008404683, 0.0729705867706798, 0.0487458253337536, 0.011818503226095345, 0.049010734946932644, 0.03526719527144451, 0.05399277601100039, 0.0425963377347216, 0.038624333683401346, 0.023145335471781436, 0.02250886034744326, 0.06064610766770784, 0.009703111463750247, 0.05420845525804907, 0.01748579892591806, 0.0695185833319556, 0.02381454858550569, 0.07289278742973693, 0.04841540263441857, 0.04525496675341856, 0.05152378427737858, 0.01631746181374183, 0.04430871733347885, 0.020390820973261725, 0.02741739539487753, 0.025581292356946506, 0.042580919616739266, 0.0522896769689396, 0.027231294443481602, 0.035367466844036244, 0.047799872772884555, 0.05177283790544607, 0.045920246484456584, 0.029255609842948616, 0.12146659777499735, 0.03138294647214934, 0.07404950622003525, 0.012375527730910107, 0.07156595354899764, 0.03288072664872743, 0.04524209420196712, 0.028755797502526548, 0.04921553801978007, 0.015344047005783068, 0.04449168271094095, 0.03837316493445542, 0.05197964848775882, 0.04184422672551591, 0.14953414793126285, 0.020936791188432835, 0.02895762270782143, 0.03862695717543829, 0.03403722650546115, 0.02972013120597694, 0.02441432636260288, 0.08673016054672189, 0.03905947713064961, 0.024546155909774825, 0.04075282435223926, 0.040669321606401354, 0.033498835473437794, 0.05375535925850272, 0.05249417205050122, 0.024398379464400932, 0.021951342314423528, 0.0478061921603512, 0.08083706270554103, 0.01927421155414777, 0.04229379010212142, 0.03057335241464898, 0.17993529239902273, 0.1697243793751113, 0.08660851512104273, 0.16093381826067343, 0.15135560097405687, 0.2800750150345266, 0.19676331285154447, 0.1308995916042477, 0.14107010210864246, 0.19568333955248818, 0.15001244726590812, 0.138342353166081, 0.1943480080808513, 0.1329493144294247, 0.175650755118113, 0.11036584226530977, 0.18364245363045484, 0.11287077621091157, 0.12764045008225366, 0.10599701185128652, 0.1682682114187628, 0.24281252233777195, 0.1376838010037318, 0.07384519296465442, 0.1320857513928786, 0.186765544640366, 0.1596322248224169, 0.09346736973384395, 0.17286784976022318, 0.11747309370548464, 0.07999090303201228, 0.1362612226512283, 0.11407561585656367, 0.17138417781097814, 0.2598653541645035, 0.16891607665456831, 0.09635844311560504, 0.2025103263440542, 0.21564525668509305, 0.11514550336869434, 0.12789714412065223, 0.24868074338883162, 0.14337987347971648, 0.19203265575924888, 0.14070063130930066, 0.12278700465685688, 0.16948656557360664, 0.09003732644487172, 0.1427659095497802, 0.15068202774273232, 0.1366155536379665, 0.16476965305628255, 0.16051049722591415, 0.1519399235257879, 0.11774677550420165, 0.10161517900996841, 0.13384152436628938, 0.21101392863783985, 0.14166618027957156, 0.13227335148258135, 0.18998119630850852, 0.1848706041346304, 0.09371696141897701, 0.1412316973437555, 0.1523804327007383, 0.096383772615809, 0.14878958085319027, 0.12758112279698253, 0.1950790680712089, 0.16855951922480017, 0.13316495285835117, 0.19364513485925272, 0.09681869341875426, 0.17804333532694727, 0.11038366123102605, 0.10528872095164843, 0.12634215177968144, 0.2111574896844104, 0.14166021341225132, 0.07819291669875383, 0.12036635642289184, 0.15181404043687508, 0.18354888365138322, 0.09758551750564948, 0.20735187514219433, 0.1335597160505131, 0.14014755317475647, 0.20395981497131288, 0.15234575956128538, 0.19188550271792337, 0.12149729300290346, 0.1916610327316448, 0.1363919593859464, 0.13133368862327188, 0.14474998199148104, 0.13557386031607166, 0.11153664701851085, 0.2360713723464869, 0.08821745417662896, 0.17333730269456282, 0.11410688995965756, 0.238439773384016, 0.1153773206169717, 0.09001245707622729, 0.14902622206136584, 0.19904344284441322, 0.142011382849887, 0.13960709155071527, 0.16154067241586745, 0.14414342469535768, 0.11272520394413732, 0.12363971007289365, 0.16203043051064014, 0.13706663099583238, 0.13536840415326878, 0.12027807795675471, 0.12314128369325772, 0.16685560753103346, 0.1399656676221639, 0.1516666350653395, 0.11104189426987432, 0.12995022145332769, 0.17976575618376955, 0.13116939197061583, 0.12043120528687723, 0.1882140091038309, 0.15704931342042983, 0.10826688536326401, 0.09664322002208792, 0.13247006514575332, 0.13573665783042088, 0.22468991432106122, 0.12721196369966492, 0.13310851994901896, 0.2088961360277608, 0.142426228558179, 0.1388877723366022, 0.15748694306239486, 0.13064732076600194, 0.1897128505515866, 0.2013496370636858, 0.18501291837310418, 0.1051769164041616, 0.16498336190124974, 0.1284994711750187, 0.12777764350175858, 0.14556015492416918, 0.08431927897618152, 0.15289122326066718, 0.2182515012100339, 0.17281128326430917, 0.0829083746066317, 0.2781240572221577, 0.1629236646112986, 0.2492477442137897, 0.09652370456024073, 0.2138306907727383, 0.09840044760494493, 0.1059232275292743, 0.08675775359733962, 0.13200429326388985, 0.24121844850014895, 0.12820749543607235, 0.12870911305071786, 0.2039302181219682, 0.12703831598628312, 0.15176575630903244, 0.15730964398244396, 0.13019073667237535, 0.1441466753021814, 0.06786875193938613, 0.10327015348593704, 0.2315308089600876, 0.10382409993326291, 0.06516730471048504, 0.11919612312340178], [0.05676954009686597, 0.051905392901971936, 0.0037526245023400406, 0.08719527191715315, 0.0634174540755339, 0.0171713398231077, 0.05127426680701319, 0.037170733558014035, 0.08941683161538094, 0.028029505810991395, 0.011678735481837066, 0.05137122097949032, 0.02529361179767875, 0.04125948857108597, 0.050357347063254565, 0.04192249361949507, 0.05089329642942175, 0.009329781496489886, 0.024037860821408685, 0.06938302263733931, 0.052865924953948706, 0.03928784339223057, 0.015413387718581362, 0.0030303682387966546, 0.02713026959099807, 0.047212314457283355, 0.06196882633958012, 0.03112758644419955, 0.06725894403643906, 0.06627662252867594, 0.009389830520376563, 0.008006292846403085, 0.017267692855966743, 0.0777081903652288, 0.07657666748855263, 0.01822631758841453, 0.1365069329040125, 0.04449030231626239, 0.021220183989498764, 0.03364163581863977, 0.03865334052534308, 0.03925032782717608, 0.02344872544199461, 0.08949566254159436, 0.08387207562918775, 0.07994107523700222, 0.09368829225422814, 0.10811959131387994, 0.019160377232765313, 0.08500031821313314, 0.017168295162264258, 0.030259275517892092, 0.04651935632864479, 0.043888765649171546, 0.02321300264156889, 0.025009625278471503, 0.04980168254405726, 0.04031016294902656, 0.07076138383126818, 0.03944783558836207, 0.028312661124800798, 0.022302166653389577, 0.026251349663652945, 0.025198678122251295, 0.04540137393632904, 0.021908474009251222, 0.05801455961773172, 0.058302501784055494, 0.023824712297937367, 0.052676090999739245, 0.0770138666848652, 0.07986904980498366, 0.05676783686794806, 0.017393078705936205, 0.02485526041709818, 0.04959990372299217, 0.01689826287474716, 0.032993481145240366, 0.004751306887555984, 0.052137499587843195, 0.045126849799999036, 0.06615709222387522, 0.008740733319427818, 0.0498626240005251, 0.01410901679264498, 0.06029982898326125, 0.01446459273211076, 0.042729887209134176, 0.05479069979628548, 0.0313304803421488, 0.0920500309439376, 0.05009070082451217, 0.03221578830562066, 0.0363899051444605, 0.021956008567940444, 0.02141336317436071, 0.10022714021033607, 0.01571277287439443, 0.016920542148000095, 0.016464779982925393, 0.04849571043450851, 0.0047296626144088805, 0.04363102147181053, 0.018450956413289532, 0.018863354889617767, 0.05739633576013148, 0.0022327545320877107, 0.033310908838757314, 0.03195769160811324, 0.03829002955171745, 0.08232647145632654, 0.021665745334757958, 0.047268268681364134, 0.06545484982780181, 0.026184446905972436, 0.030704768214491196, 0.05893467059649993, 0.02876750488212565, 0.019096834548690822, 0.026316539915569592, 0.030652161076432094, 0.012021608636132441, 0.027665699453791603, 0.01086098893210874, 0.03032974615052808, 0.01813439703255426, 0.014112578173808288, 0.0203521402363549, 0.04248149038176052, 0.05914566689170897, 0.0267798256027163, 0.02495472119335318, 0.11245765228522941, 0.039534496172564104, 0.0261256279918598, 0.028337734584056307, 0.0048400088417110965, 0.020020129340991843, 0.0016391949088756519, 0.060215925477677956, 0.02594454024801962, 0.018201995553681627, 0.03155975202389527, 0.05659983689838555, 0.09535712262731977, 0.01718330695439363, 0.0018203693912255403, 0.015655993011023384, 0.04486829297093209, 0.09214292556862347, 0.010251407384203048, 0.053664004590245895, 0.0865635038644541, 0.030499659005727153, 0.021833689643244725, 0.027151895774295554, 0.0474628820666112, 0.00925939435546752, 0.021117455908097327, 0.01349150075839134, 0.05474123565363698, 0.021610945150314365, 0.03676276384794619, 0.04170275111391675, 0.04736362723633647, 0.04449661799299065, 0.060175326289027, 0.04860480243223719, 0.04518073714280035, 0.09931412045261823, 0.04649262788007036, 0.0015344610574175022, 0.03782869200222194, 0.040155380629585125, 0.015602463754476048, 0.04189164625131525, 0.020818305456486996, 0.0685394456377253, 0.028647588660533074, 0.06875152917928062, 0.007690022903261706, 0.0029609380044348654, 0.034017288708128035, 0.02284793277794961, 0.006555312038472039, 0.03544909195625223, 0.02822263675625436, 0.08504513651132584, 0.1218613535456825, 0.07536958655691706, 0.018309098595636897, 0.02732461394771235, 0.03504995380353648, 0.026420535214128904, 0.019213284940633457, 0.059656264493241906, 0.005697025671906886, 0.018220478741568513, 0.03218563484551851, 0.0567050400422886, 0.02665530064405175, 0.020707324692921247, 0.05557766948186327, 0.04178958981356118, 0.06241899827728048, 0.06090537324780598, 0.005156145662112976, 0.021616514968627598, 0.033225209335796535, 0.03334334811370354, 0.04589152165863197, 0.05664006501319818, 0.05603468402114231, 0.0831956006004475, 0.08345037989784032, 0.113375288201496, 0.05193339042307343, 0.017359110606776085, 0.010936798389593605, 0.03651348015409894, 0.04688111992436461, 0.038334640048560686, 0.062264817097457126, 0.033730430077412166, 0.02481653144059237, 0.025711357448017225, 0.02974894694489194, 0.02090801626764005, 0.0458049352891976, 0.029443421444739215, 0.029161286583985202, 0.019587470233091153, 0.018772237708617467, 0.034704662175499834, 0.08474995469441637, 0.06705267151119187, 0.07551393428002484, 0.031919612010824494, 0.021469688472279813, 0.02663960422069067, 0.038199717600946315, 0.06945462504518218, 0.06191779255459551, 0.058165553273283876, 0.09038660340593196, 0.025545754615450278, 0.04503720578213688, 0.05364024473237805, 0.0350766414339887, 0.033415581347071566, 0.010252286829199875, 0.016520107092219405, 0.029217532101029065, 0.010901375680987258, 0.05114649124152493, 0.0954377421294339, 0.0515813675156096, 0.05694510997273028, 0.023613793928234372, 0.04199225179036148, 0.018646779499249533, 0.02693197144253645, 0.10829093094798736, 0.02496831919415854, 0.1542777183931321, 0.023205043107736856, 0.06790732135414146, 0.02135258499038173, 0.01953600971319247, 0.032163162613869645, 0.041237405966967344, 0.0066204498762090225, 0.08811267776763998, 0.015986886974133085, 0.037876204296480864, 0.029869044992665295, 0.007324813886953052, 0.0639642016903963, 0.14502004953101277, 0.049333699062117375, 0.016865265133674257, 0.009811713644012343, 0.05122234986629337, 0.03724349742697086, 0.05763076536823064, 0.026995829539373517, 0.03644261618319433, 0.0602291282848455, 0.049643074453342706, 0.04118278018722776, 0.029987519592395984, 0.028719515757984482, 0.04284690905478783, 0.03628171114542056, 0.0009668582231370237, 0.03706107381731272, 0.01775846027157968, 0.04510872655373532, 0.015564052046102006, 0.021153822999622207, 0.03601524302212056, 0.020494940581556875, 0.013906290805607568, 0.023908289258542936, 0.03480392442725133, 0.06518948750454001, 0.03812032264249865, 0.0446961926354561, 0.027349455485818908, 0.0371744814037811, 0.018571134241938125, 0.011795437276305165, 0.02397123822447611, 0.017793411716411356, 0.02544917522754986, 0.040524933065171354, 0.01822116522816941, 0.0732977848383598, 0.06374590637278743, 0.058181424101348966, 0.039895755107863806, 0.04182405515166465, 0.02126897277776152, 0.03631052873970475, 0.022068223152018618, 0.0365163893729914, 0.037334195294533856, 0.08052673365455121, 0.04808457917533815, 0.021055590477772057, 0.03712331032147631, 0.041070148145081475, 0.06112700080848299, 0.02586422131571453, 0.023806357130524702, 0.08990603309939615, 0.02327027603314491, 0.047724418618599884, 0.03944918258639518, 0.028103423719585408, 0.007380198976534302, 0.01723499568470288, 0.03507297151372768, 0.035124984933645464, 0.02609644303447567, 0.026472739737073425, 0.06344103952869773, 0.028388998434820678, 0.07995979962288402, 0.03459377046965528, 0.019428381601755973, 0.035089881348540075, 0.1525627338560298, 0.22048386657843366, 0.12980539875570685, 0.18278741044923663, 0.1434575763414614, 0.09355506190331653, 0.14843036653473973, 0.14072577527258545, 0.15817607170902193, 0.0940418810932897, 0.1284989813575521, 0.22921863303054124, 0.15288193157175556, 0.14910864498233423, 0.13775558152701706, 0.08971753501100466, 0.21858025778783485, 0.08684962405823171, 0.09413217820110731, 0.14531618129694834, 0.17590076982742175, 0.0857293744047638, 0.12636603409191594, 0.2097618067637086, 0.07226551679195836, 0.0970267248339951, 0.1570693514076993, 0.18839335651136935, 0.17333293886622414, 0.13608457666123286, 0.11231150856474414, 0.12230804481077939, 0.09089603583561257, 0.16979929176159203, 0.14737127727130428, 0.09544451793772168, 0.19865100999595597, 0.20008495805086568, 0.12286469267564826, 0.18134017795091495, 0.09220735882990994, 0.1698513311566785, 0.100424395641312, 0.2016562331118621, 0.12378578700008802, 0.23184144229162484, 0.13246096641523764, 0.14632734266342595, 0.1124756716308184, 0.12657008017413318, 0.16953501297393814, 0.1533225001185201, 0.1251251928624697, 0.17947045562323183, 0.14396321639651433, 0.15651680761948228, 0.16828761115903035, 0.19852953526424244, 0.2736181818181649, 0.14564560580765828, 0.16597179870586842, 0.14299483242211863, 0.1963608164805919, 0.16510688496055081, 0.10267261328408495, 0.16318426234647632, 0.14627807890065014, 0.10496374932699837, 0.20764855609741062, 0.09064640704309568, 0.15240890148561448, 0.12638993124710396, 0.1505744460155256, 0.14526535902405158, 0.09758225205587223, 0.08658199818455614, 0.11564313565031625, 0.07515929901273921, 0.1295332532026805, 0.20499177131569013, 0.15519766981014982, 0.14209068875061348, 0.07217927181045525, 0.1719732055789791, 0.10349840100388974, 0.11541621657670476, 0.19434680580161512, 0.14221532503142953, 0.346131679834798, 0.07183117486420088, 0.1766033610329032, 0.1847078511491418, 0.15836202423088253, 0.12067767995176837, 0.1537225177162327, 0.12672285869484767, 0.21563692978816107, 0.06477503513451666, 0.1635714407893829, 0.09957689268048853, 0.1467691728612408, 0.12552803062135354, 0.27096426172647625, 0.08083764900220558, 0.1241524302167818, 0.0954127762815915, 0.1425458479207009, 0.13484677823726088, 0.15453142899787053, 0.09911198168992996, 0.1328996499069035, 0.10436693642986938, 0.10610042270855047, 0.185654386295937, 0.1258216390851885, 0.17035628843586892, 0.17743182048434392, 0.1290575959137641, 0.07898938958533108, 0.14308636891655624, 0.1534345792606473, 0.13231807330157608, 0.0761763085029088, 0.25231207197066396, 0.13222733832662925, 0.08902566783945076, 0.1466499245725572, 0.1393724838271737, 0.13421068346360698, 0.1614931007497944, 0.16190711525268853, 0.0655318253848236, 0.19592755066696554, 0.12085464506526478, 0.0754683070408646, 0.12742056656861678, 0.12107498128898442, 0.16379007749492303, 0.10053952501039021, 0.20547440479276702, 0.11893522852915339, 0.15063629660289735, 0.11350105254678056, 0.17460757750086486, 0.16553298162762076, 0.20884224126348272, 0.13825426023686305, 0.13157579203834757, 0.0976627528143581, 0.2640526700997725, 0.12352346748230048, 0.20801308419322595, 0.12556705274619162, 0.11444731309893541, 0.10878042186959647, 0.21309508883859962, 0.10623273279634304, 0.07220747342216782, 0.16765684500569478, 0.22890774736879393, 0.11830878909677267, 0.14227315317839384, 0.145383627677802, 0.07484668414690532, 0.1788516083615832, 0.08126528933644295, 0.20170037605566904, 0.17001720116240904, 0.08381121951970272, 0.22897746472153813, 0.1092303117911797, 0.10756987510831095, 0.18795700336340815, 0.17222316091647372, 0.09089222861803137, 0.1701238180976361], [0.014583566426153993, 0.029304760428203736, 0.025059412255359348, 0.033915774038177915, 0.022413212354877032, 0.02810507870890433, 0.015343880950240418, 0.10298639332177117, 0.041699467110447586, 0.023866101873863954, 0.025844428237178363, 0.06225218945473898, 0.03254998111515306, 0.03233799405279569, 0.01979133448912762, 0.033813973641372286, 0.014011664643476252, 0.009821555449889274, 0.03881891738274135, 0.06796565416152589, 0.014327474455058109, 0.04637782505596988, 0.02727148174017202, 0.02202757943450706, 0.07026165127172135, 0.05958082518191077, 0.028971231840841938, 0.025566364056430757, 0.029842101321264636, 0.03757754180696793, 0.028274338474147953, 0.038689319844706915, 0.04506718854827341, 0.003606373170441657, 0.031495482035097666, 0.06844916337286122, 0.026449848191987257, 0.05875333052244969, 0.0188568184239557, 0.0902577665692661, 0.015317030974983936, 0.0558311166241765, 0.05030762687965762, 0.08185065831639804, 0.05094575884868391, 0.028654186353378464, 0.02274120823130943, 0.03713341095135547, 0.030828912822471466, 0.042192557448288426, 0.023359107399301138, 0.008658097031002399, 0.048466603402630426, 0.016177876823348925, 0.014602391001972137, 0.07384191267192364, 0.038099074954516254, 0.06716938165482134, 0.06852415739558637, 0.017707925580907613, 0.03106402149569476, 0.026384097618574742, 0.053206203374429606, 0.0588867835176643, 0.035287322316435166, 0.05974977510049939, 0.046176098185242154, 0.03105615844106069, 0.030725557626283262, 0.04864193208049983, 0.0006936836359727749, 0.08227447659010068, 0.04991588422853965, 0.01361874383292161, 0.018615830085764173, 0.025530373604851775, 0.0431070540798828, 0.05939798225881532, 0.020944648676959332, 0.08352898817975074, 0.02259554690681398, 0.031622378155589104, 0.06494880901300348, 0.03624091899837367, 0.038650371934636496, 0.06448340078350157, 0.019732274377020076, 0.03197010031726677, 0.018935489788418636, 0.051271687843836844, 0.053207234959700145, 0.018319715018151328, 0.06936294754268602, 0.04627085188985802, 0.013150769627827685, 0.05243074811005499, 0.029085871392453555, 0.03474351360637229, 0.025769664280232973, 0.024175479120458476, 0.019118030286335852, 0.031228063962771557, 0.024460821914544795, 0.01508743367594434, 0.03222287952667102, 0.036056231838301755, 0.029685712252103258, 0.029079028790874872, 0.08262307819677517, 0.011471235629869625, 0.0211249423227855, 0.03748358220036607, 0.031138794729486108, 0.049612123184488155, 0.021779256821901072, 0.002110492659994634, 0.034922322956845164, 0.028634563968807925, 0.023921367755974643, 0.02940369984571589, 0.013633863236464094, 0.026956009605783038, 0.04395613039378077, 0.06569981051143259, 0.05225881475780625, 0.03440853783104103, 0.058695238913060166, 0.03675945015856996, 0.003252249057368317, 0.1477768164477311, 0.03669460871606134, 0.06983855288126506, 0.01573502431710949, 0.022222370935196523, 0.04105822183191776, 0.043487857474246994, 0.031572045700158924, 0.04427689404110424, 0.0359802878665505, 0.07142481190385297, 0.01582978729857132, 0.035619763657450676, 0.01773127354681492, 0.04164135694736615, 0.01231326803463162, 0.044237304173293523, 0.0339492857165169, 0.06032250530552119, 0.05198004553676583, 0.026079154704348184, 0.04375308250018861, 0.026241881714668125, 0.04523400479229167, 0.06597174826310948, 0.04275001796486322, 0.06064807435905095, 0.07695097709074616, 0.033414397621527314, 0.02340369192097569, 0.08172887930413708, 0.030097954877419397, 0.03155678714392707, 0.06834104729932733, 0.048340449429815635, 0.005478109733303427, 0.019666588741529267, 0.006329997859211289, 0.01605348730663536, 0.018365798678132705, 0.09227370683220215, 0.017302365995419677, 0.08038519124966115, 0.0043288342203595676, 0.0440237586008152, 0.0547862914390862, 0.04148690488364082, 0.05176311206014361, 0.04827254291740246, 0.021479518218257, 0.020200680883135647, 0.07865403531468473, 0.043792987780761905, 0.027340625783836003, 0.06405477339285426, 0.008751369223318761, 0.03240306556108408, 0.013604697760456474, 0.028495934493548702, 0.05022614277550019, 0.0441917400166858, 0.05267640641250182, 0.02183251333917724, 0.015357311040133936, 0.03350597122334875, 0.042938148690154776, 0.022991176556388382, 0.03603190052672289, 0.026711778082244564, 0.006351945021378924, 0.02254745388199808, 0.03667094533739146, 0.052844005622318946, 0.03867921179335099, 0.07293386530363932, 0.044606849187402986, 0.04621821135515347, 0.03471232485026121, 0.02017166290897876, 0.049155353553942405, 0.059285847455612384, 0.03207688423572108, 0.07228982212836854, 0.04205475917842705, 0.030088011953921523, 0.02212080617027823, 0.012504415590228746, 0.01173039267087006, 0.021754470944870263, 0.05639607654302381, 0.048538072223891504, 0.05766557209426537, 0.05858170516148675, 0.03452886965533253, 0.012975349109183298, 0.08282942493679002, 0.04627995804185048, 0.06950568480533548, 0.059942718653474, 0.0672724140167702, 0.06853782033431344, 0.04089921298145782, 0.02258448334032437, 0.014702385196869727, 0.03975924446422141, 0.028969196500838734, 0.03081243714404991, 0.03361412811500486, 0.016308138583553955, 0.018925025506177917, 0.08204418074456044, 0.036058962941751815, 0.06143622777017299, 0.023638987986487336, 0.010491210141481133, 0.027794354464276694, 0.03804518019023817, 0.09239105522283353, 0.05458385210658889, 0.04222491508699022, 0.04222111158014741, 0.07669270969927311, 0.07619736323249526, 0.06186083272041287, 0.08219888142775744, 0.022182025932124816, 0.06667212044703774, 0.035168582398910075, 0.0158428045688197, 0.03399832683498971, 0.027730197652999777, 0.04637733523850329, 0.041383505158592016, 0.05015448099584319, 0.03993292557424866, 0.04218907306494657, 0.05892450317332987, 0.04029160554637201, 0.05089369718916714, 0.018865685233322438, 0.043952972555416636, 0.020333649626991246, 0.07017503521637991, 0.06770671883714385, 0.03030438510904787, 0.010270534385199426, 0.05026851940783672, 0.04374630669190083, 0.016848130799189676, 0.03249128094466869, 0.05128383309056517, 0.010411230741738109, 0.02646150918735657, 0.02830715624440927, 0.0065979127066384535, 0.04550085883238353, 0.04828511118830647, 0.03657590590592008, 0.036019209801452234, 0.012795633410860319, 0.026456013583811, 0.05168423289433122, 0.0332134648488136, 0.035217478798585944, 0.024694902713235933, 0.0654884245886933, 0.05103684634377714, 0.019370041372894775, 0.04843319191422779, 0.03292562658316456, 0.027536367233551573, 0.02367942019191105, 0.03990622310084291, 0.018762879226414952, 0.038343968844856136, 0.005906192109250696, 0.10126507084351033, 0.04321351145335939, 0.0741396177909337, 0.016314762251568027, 0.025497578099020757, 0.0022587624016523478, 0.05306496153934859, 0.03684503462864086, 0.04564671682601329, 0.04074112068337854, 0.04808443074580282, 0.0046063167428656016, 0.04540855050436221, 0.016342819144483656, 0.044655137025984004, 0.03523061110172421, 0.10249743674648926, 0.0086179273603193, 0.029003261079196818, 0.05323324723576661, 0.03465813322691247, 0.025763155645108782, 0.026711674181569833, 0.02682497230125591, 0.029268461985338945, 0.018114743106707465, 0.07584604536532424, 0.036328217829577625, 0.0239781457639765, 0.013535503621824319, 0.05179114297789056, 0.024159996064554434, 0.0643927177588921, 0.04404537736263592, 0.09013859991682693, 0.001579998195211374, 0.018755793571472168, 0.050140777238993905, 0.05357115078368224, 0.03130373705062084, 0.06739066040609032, 0.020978828288207296, 0.05754841295129154, 0.03082933213590877, 0.05747267678088974, 0.02276646908285329, 0.01510477395640919, 0.15073446789756417, 0.11543239539605565, 0.08851629478158429, 0.10291902115568519, 0.12320202848059125, 0.17556310747750103, 0.13612873444799334, 0.24006820865906775, 0.19065945991314948, 0.1373978515039198, 0.09885108709568158, 0.1626580351148732, 0.10742491140263155, 0.1426839764462784, 0.21811009239172563, 0.0965198602352757, 0.09646705642808229, 0.26191121782176197, 0.1306958423811011, 0.18076173320878297, 0.13470679434249178, 0.07060803385684267, 0.13631951092975214, 0.15001954219769686, 0.19453574175713584, 0.11557369289221242, 0.17678497941233218, 0.12210486704134382, 0.1190996216610074, 0.12705220899078995, 0.11396919187973253, 0.11378596303984523, 0.13288001267937943, 0.09677207170170732, 0.10597366388537921, 0.19821887224679813, 0.15733955253381282, 0.2225067385006696, 0.20421695429831743, 0.13627530861413106, 0.12481540557928383, 0.19834569044178352, 0.12627014861209318, 0.12560309143736959, 0.17069156107027084, 0.20269654603907838, 0.10363307112129405, 0.15767353383125737, 0.16506725427461788, 0.0980680099746678, 0.0973750815319363, 0.1169155775278341, 0.21443453180836514, 0.13253587880171835, 0.14818415162153542, 0.13937186042312533, 0.09884071929263882, 0.14342383830808103, 0.16823232115712017, 0.1269386158674024, 0.13365331571549177, 0.15519011474680156, 0.08997911980259232, 0.16875415487447754, 0.1909714291105047, 0.12517555500380695, 0.08945560883148573, 0.0829575938405469, 0.1626862960983999, 0.19259946362581104, 0.32602155581116676, 0.17525857459986582, 0.13930279616033658, 0.1535523432539776, 0.12524862686404958, 0.15059714089147747, 0.14791501918807626, 0.17399310891050845, 0.15162694500759244, 0.2313462516758591, 0.14040619164006785, 0.11121167539386079, 0.18406480987323448, 0.08483326077111997, 0.13543316395953298, 0.1677654212107882, 0.14100912725552917, 0.09160279048956, 0.1784287771442905, 0.1482182161998935, 0.12753859773511067, 0.130677318375092, 0.15849007439101115, 0.119620653858874, 0.16065407311543822, 0.2242109173675999, 0.10821154341101646, 0.12136281584389508, 0.09983994692447595, 0.10475149509147741, 0.08929107469157316, 0.10125765678822063, 0.1491491959313862, 0.1496554890763946, 0.14489541325019673, 0.1082723772560712, 0.1196697617706377, 0.22522685816511512, 0.1769840976339765, 0.12288714264286682, 0.12478304794058204, 0.13604398118332028, 0.1267662298050709, 0.17004371067741886, 0.18443062930600718, 0.07256022363435477, 0.16825909784529358, 0.17680219723843038, 0.07829537018551491, 0.1169751571433153, 0.11969074228545651, 0.1456225843867287, 0.0745967288094107, 0.18599314702441916, 0.20850204076850787, 0.08439950514002703, 0.1059618043655064, 0.16531620029127225, 0.14884175383485854, 0.26662637887056917, 0.1400435485993512, 0.13667372317286208, 0.07504969122237526, 0.09171956742648035, 0.07205542962765321, 0.09761540379258804, 0.072446192643838, 0.14059787354199216, 0.1465726669994183, 0.15936770854750648, 0.08312916354043409, 0.07111003738828003, 0.23612421326106414, 0.13777339307125658, 0.10155970347113907, 0.15814902784768492, 0.11329150715027936, 0.1280121027957648, 0.15416175039717928, 0.16996167367324233, 0.15177320747170597, 0.11819048333563842, 0.12576078297570348, 0.1717872530571185, 0.24702655558940023, 0.19819328299490735, 0.18328007776290178, 0.09726300238980912, 0.1094660846865736, 0.23974595329491422, 0.1084941829321906, 0.19644806336145848, 0.2348156733205542, 0.20360407390398905, 0.12420392042258754, 0.0879097003780771, 0.11294956260826439, 0.1610091610928066, 0.22564928862266243, 0.19721709162695333, 0.07630065534613095, 0.17154949862742797, 0.19894102646503597, 0.18548464227933437, 0.11138865535031073, 0.1385691831819713], [0.03690479235956445, 0.02723442630667705, 0.0965014698158484, 0.055354427749989554, 0.016973735582723748, 0.01624809327040566, 0.08164246362866834, 0.02611075349705061, 0.04643685548217036, 0.0055613791664654855, 0.04626393136277329, 0.05202642234507948, 0.038419270858867094, 0.009633488734834827, 0.05385992415540386, 0.057048810267588124, 0.019289950651000254, 0.06289590237429366, 0.031368916170322336, 0.0810710470250342, 0.06723689482896589, 0.04408704895467963, 0.014443375657720026, 0.037132587167434394, 0.04961799357261043, 0.009029416705743643, 0.03232114730053581, 0.02532873950258363, 0.017983175166591536, 0.0985168683109805, 0.034118769981432706, 0.022142810848890804, 0.023070120660122484, 0.02682318001461681, 0.03666085212898906, 0.009513102177152177, 0.03687412310682703, 0.027928796371270437, 0.04599550768034533, 0.04465495891054161, 0.06268635697779246, 0.0540684862062335, 0.012681785174208926, 0.056796105272951536, 0.06847524244221859, 0.033549386862432584, 0.04880663691437803, 0.028156029002275318, 0.061528658552560955, 0.015801309236849193, 0.05019366639317013, 0.0455124623113079, 0.05377615423640236, 0.037729945543105714, 0.07849504501791671, 0.05104583746287972, 0.02491922612534836, 0.03469227202003822, 0.03517609293339774, 0.03525727275700774, 0.06429714398109354, 0.06806407036492601, 0.05118989203765523, 0.03539713790814858, 0.0745077601459343, 0.03519223835610319, 0.05809435162518639, 0.035847807084792294, 0.06837148277554661, 0.017826068069553003, 0.019346891931490973, 0.0374857232964132, 0.017832289122452494, 0.035985620197607204, 0.08015603089006618, 0.024801098479656503, 0.01926221102621639, 0.05856653937371448, 0.07903204823378474, 0.015914672294456977, 0.07936743961181492, 0.043224947949056514, 0.02762199437711388, 0.06408836299669929, 0.033455802040407434, 0.035838478288496844, 0.03846932129818015, 0.020651426129916217, 0.04274402883311268, 0.027411422961449716, 0.05553748589591123, 0.04874049671343528, 0.02281977383972844, 0.05181271721085068, 0.014390451251529157, 0.0355003780714469, 0.039982337766559795, 0.037374334351625293, 0.020814388772123493, 0.04725810496893246, 0.03661614144220948, 0.03655910739325918, 0.040855448532965966, 0.016718737351766322, 0.04908255999907851, 0.04464498815650586, 0.0483492216153536, 0.03662644245196134, 0.03545617204508744, 0.06894614256452769, 0.07218272279715165, 0.04147076317167375, 0.03796050114033278, 0.006288096201387816, 0.03980334658990614, 0.019781206028710585, 0.04673338058637455, 0.026863153943850193, 0.047299783982452936, 0.03950942642404698, 0.07683558796998113, 0.024812024748825934, 0.029204848797235172, 0.022661559087282512, 0.056738451530691236, 0.06752064757165499, 0.026304220264137257, 0.04806695687875617, 0.05411722304415889, 0.009384575187141309, 0.01644333005970111, 0.02695295937883202, 0.01973580143385334, 0.06125282452558167, 0.05172340715944301, 0.0613850344234379, 0.03602210046665277, 0.06097477147704922, 0.019585097215895075, 0.05116863321745768, 0.040046730209724046, 0.03997667889052536, 0.026015717776317615, 0.01519069239293458, 0.03589130436012056, 0.03811798116657883, 0.013638404252560576, 0.007147346432248014, 0.06539820911712013, 0.022966357282712124, 0.039185979912872426, 0.048770802313811146, 0.042097091281902976, 0.07052099477732554, 0.037100110785104334, 0.05380915383284446, 0.02395530987996608, 0.08703389932634309, 0.03785427012189757, 0.03403593887924217, 0.04563185902952682, 0.013649463180627208, 0.0542060581210535, 0.015650625427952036, 0.0491306994081242, 0.01348368130493327, 0.029763079292024486, 0.012723176605504705, 0.020690075325546786, 0.00799590277893003, 0.014903586998116225, 0.12096590042347088, 0.02077408273180481, 0.06779970994102769, 0.026157813081226777, 0.02452012322464725, 0.05252607697912026, 0.023289002274395898, 0.06656060533714481, 0.02870651147532044, 0.01688314718194306, 0.058925820485455915, 0.0061097743491700385, 0.024728726093599107, 0.05030311833252199, 0.02719345604418777, 0.05731241741159465, 0.028893994676764123, 0.038734546324121766, 0.08168292551999912, 0.0955666383379139, 0.028920147960889153, 0.023639078899577726, 0.04039200699480716, 0.013614099843834992, 0.038429727719631046, 0.07661073948838748, 0.01257744106624159, 0.052409704512683675, 0.06018265870807227, 0.029070115597278345, 0.12207329607917927, 0.01966723255463876, 0.0672080549702514, 0.02335228335141437, 0.02996457424160326, 0.01699495544016827, 0.006036462218617089, 0.048889883619267493, 0.007607316110807005, 0.030033363909751642, 0.01974277947738301, 0.07199061787105165, 0.0833432879881002, 0.09046624327311292, 0.02396820655121701, 0.025993188028223813, 0.06516932335216552, 0.00425579390139319, 0.03704617891344242, 0.011800431930168997, 0.05793891250505112, 0.029168750734243076, 0.05493941134773195, 0.04436478287971113, 0.04089420719537884, 0.07055307782138698, 0.048114881064975634, 0.02187020145356655, 0.041731060337042436, 0.06873829668620601, 0.04465630219783634, 0.03740283282240853, 0.0066215148581250105, 0.047752419850439765, 0.046735658979741856, 0.006834686573711224, 0.049168493278557435, 0.0755412527360022, 0.07116825887351297, 0.0675524708640296, 0.07627591214259155, 0.006590110879187705, 0.032552753036725335, 0.026796139864018187, 0.046353653306141496, 0.0075626337184075965, 0.024205207701015752, 0.024195511541620363, 0.0348787366237957, 0.04570459321257658, 0.048958454353851266, 0.08409137284616008, 0.03792164228798356, 0.010408700018160744, 0.027988734073005617, 0.01689153901679674, 0.03971120524511207, 0.021165778998692986, 0.00866897227751906, 0.03197019308572635, 0.046593036749982275, 0.04365477019746322, 0.018845014565158635, 0.0454554950556485, 0.06378316960763186, 0.06067021262424532, 0.006939637851246516, 0.006168169775264687, 0.026687578501878306, 0.06809880287619308, 0.16076592961326241, 0.01497013445259654, 0.032306081702699885, 0.08923424102249555, 0.1169476902578026, 0.024003649668884464, 0.05412304890342057, 0.015426242644025479, 0.03663797913759481, 0.037562435391009785, 0.014942019115551375, 0.041671636572573334, 0.046701779938302934, 0.02022020678850822, 0.050416299563948996, 0.03280340228229761, 0.14348886528750882, 0.007006413979979698, 0.06428733278880827, 0.025247485464205965, 0.08808630926068872, 0.005886331309739035, 0.055376862874254584, 0.06450490822317079, 0.07356738482485525, 0.019580310363380704, 0.02777829438855406, 0.0010890840894717257, 0.03975752639234997, 0.07147417956730351, 0.0683533595292829, 0.03473923512501642, 0.030495475148200057, 0.050879036061814986, 0.02200237795477733, 0.011640808024822036, 0.01595339570485521, 0.0038037271679058904, 0.02353441381274024, 0.0564851157105295, 0.08773574096267112, 0.07057176509988494, 0.014683763783978065, 0.04193572611256968, 0.059443123391247354, 0.04834645711525809, 0.013992010717629455, 0.026259058722644113, 0.014054708281037165, 0.05226835135545116, 0.06173511290398892, 0.04386820444779005, 0.026818020232894924, 0.02783920801448403, 0.07299443939700723, 0.024487815680913627, 0.07422679045703262, 0.02357717265113024, 0.033046496464521624, 0.016845195605128538, 0.06552887163707055, 0.01572693305206485, 0.05775709003501106, 0.0395483075408265, 0.06109212728915736, 0.025013862941705156, 0.013956577804492554, 0.011298707631794969, 0.04875235252256971, 0.04682500984927174, 0.05747571587562561, 0.03859724529320374, 0.05903156168642454, 0.05317635048413649, 0.03449108320637606, 0.06602136825677007, 0.0892376845877152, 0.022520526908920147, 0.019579291765694506, 0.03846471998258494, 0.016891095583559945, 0.14703168533742428, 0.14978301973314956, 0.24522980122128502, 0.16680463682860136, 0.051320357888471335, 0.10311859208741225, 0.15419057541294023, 0.15882690553553402, 0.1011446796474047, 0.09106809535296634, 0.18467993155354634, 0.08513428329024464, 0.11371495435014367, 0.2288232315913774, 0.2034047181950882, 0.17680454242508858, 0.13109185238135979, 0.11722536481101997, 0.10524808836635202, 0.18705329013755545, 0.1495072673424147, 0.1329238439211622, 0.11474453582195565, 0.15164413314778358, 0.1551190169993788, 0.23373106901999563, 0.09145033109234646, 0.1570797266322188, 0.0991414301097393, 0.1628853104193695, 0.16878578520845622, 0.10419291764264926, 0.09627875871956348, 0.20935879088938236, 0.11608501779846847, 0.07514461191021837, 0.10604635725030676, 0.11605571038671769, 0.21110221452545375, 0.08390283765038475, 0.11918787044123746, 0.13470661622704938, 0.05972171820758376, 0.0728690906544216, 0.13820271065924317, 0.11817200385848992, 0.11634907394181937, 0.12626428564544767, 0.13100882089929655, 0.12296911285375245, 0.20710960845462978, 0.16519224678631872, 0.1327172596938908, 0.14979539875639603, 0.17607406130991876, 0.11732877566828392, 0.1572081627091393, 0.1631723582977429, 0.18523951090173796, 0.14056171610718593, 0.17268026451347396, 0.24150282464688644, 0.18469035130692646, 0.18263029778609052, 0.23451614251825958, 0.10689293252653442, 0.15439371607499197, 0.16876347624929622, 0.1616550373728387, 0.11173811784829013, 0.14938518404960632, 0.1157899250392802, 0.1061835432483349, 0.12648663308937103, 0.11928775609703735, 0.12875327083747834, 0.15598453930579126, 0.18861893971916288, 0.11396749236155301, 0.14968116738600656, 0.17419497307855636, 0.07512963537010364, 0.10313330145436339, 0.16787459113402292, 0.10454353046952747, 0.17152957938378677, 0.1371094083879143, 0.096801223262446, 0.12327883334364742, 0.1532386225881055, 0.17745947290677577, 0.14776862313738093, 0.09895323630189523, 0.09678938600700349, 0.1045448292279616, 0.18579647789010778, 0.0866704696090892, 0.1587408609339036, 0.19953416573116556, 0.15819839551113546, 0.1554474767181091, 0.18921987153589725, 0.07073755346937105, 0.1598353951703757, 0.12042752423440106, 0.18773615505779162, 0.1496691445936449, 0.16123137495014817, 0.25038029125425965, 0.20609809085726738, 0.10576250060694292, 0.2024723432259634, 0.09934802175848745, 0.09175884930300526, 0.21779800445074216, 0.14411403564736247, 0.1193367897940334, 0.17420426476746798, 0.1127953220566269, 0.13559610990341753, 0.1406773872440681, 0.08018754990189336, 0.09199555730447173, 0.1199487350822892, 0.17927469190908596, 0.1658874610438943, 0.15591212053550407, 0.15094924543518573, 0.14687417191453278, 0.11780190223362297, 0.151866064989008, 0.16960474516963586, 0.055729627929395065, 0.13749924371950328, 0.15600487415213138, 0.24166237155441195, 0.11652131157461554, 0.15963071084115654, 0.1326802116818726, 0.16358900000341237, 0.12563763099024072, 0.16646336764097214, 0.08944582732510753, 0.1112608723633457, 0.14536477712681517, 0.14762032718863338, 0.12578779715113342, 0.17258895066333935, 0.15030675334855914, 0.17765281721949577, 0.09191637014737353, 0.14615788066294044, 0.11218849016586319, 0.08852888902765699, 0.11070404638303444, 0.2267497155116871, 0.10075094804051332, 0.11625056868069805, 0.12251347870915197, 0.11608168555540033, 0.22362928139045835, 0.13306808774359524, 0.11052519621443935, 0.15954987611621618, 0.1493286175536923, 0.14434712938964367, 0.12304078947636299, 0.16262394085060805, 0.11897162345121615, 0.1513813980272971, 0.19008520088391379, 0.1808531954884529, 0.17483396222814918, 0.2109960131929256, 0.11101833108114079, 0.11377555812941864], [0.07438618151354603, 0.035438193517620675, 0.0270042659030878, 0.09107291931286454, 0.06158079442684539, 0.02058809310256038, 0.06747430787072517, 0.013686051061085891, 0.0354683543991996, 0.047705141332698986, 0.08714067953405902, 0.03643846757768188, 0.06785549718188122, 0.015611067101417575, 0.05247604138276074, 0.035458435595501214, 0.033120744628831744, 0.022090817838034127, 0.053373943592305295, 0.04520930982835125, 0.04270773410098627, 0.025176929484587163, 0.04817326211195905, 0.03805112108238973, 0.04281755340343807, 0.038241281581576914, 0.005982726088404888, 0.023828565899748355, 0.08941988926380873, 0.11784804897615686, 0.05408616045315284, 0.044594292048714124, 0.09780379055882804, 0.03981937697972171, 0.019986918232461903, 0.08396430232096463, 0.03668081961222924, 0.04165081190876663, 0.08866511765518226, 0.07985509000718594, 0.04175822665274609, 0.027324515613145195, 0.02586625294497935, 0.005790141085526557, 0.07935271540191025, 0.042655613069655374, 0.11811681775725447, 0.06933828597539105, 0.05484362234710716, 0.01797193348465953, 0.03556325282261241, 0.035998540988657624, 0.0166559757781215, 0.05068602200481109, 0.051719232578761876, 0.03901704112649895, 0.023649164686503354, 0.0528116145869717, 0.023165245438576676, 0.058139192187809385, 0.036767854981007986, 0.01296977372476249, 0.0016407984116995067, 0.07737263571470976, 0.02860382606741041, 0.09998004214139655, 0.06888054413138889, 0.02091414455207996, 0.02644039694132516, 0.09260315360734239, 0.009555823908158345, 0.0293063838762464, 0.04683381172071677, 0.02791723185509909, 0.04774961082148366, 0.003005036883223511, 0.01886920115794055, 0.05900359756196849, 0.023505256685893983, 0.043748956159106456, 0.01915897271828726, 0.0211900546491961, 0.039936606626724824, 0.02232047358120326, 0.03686931770062074, 0.061435155366780236, 0.026416477521706838, 0.06850446079624817, 0.07507703936425969, 0.06121958373114467, 0.049127007223432884, 0.050092622986994684, 0.017438490722270217, 0.07395955050014891, 0.04484395423787646, 0.024080263428913895, 0.044594154751393944, 0.04149220752879046, 0.05154322483576834, 0.03531514172209427, 0.0690796400886029, 0.04041693944600411, 0.03438969470153097, 0.02965291860164143, 0.04858341002545785, 0.049280015809927136, 0.05041034753958229, 0.007839021109248279, 0.022008556334185414, 0.0458068834268488, 0.04641061314032413, 0.05596292205154896, 0.020436322047316935, 0.02701110850466648, 0.033753243696992286, 0.0366013096208917, 0.048571305596851744, 0.036689198459498584, 0.04402713166200556, 0.0586140071391128, 0.005541653808904812, 0.10256840832880698, 0.057156362308887765, 0.07863874707254581, 0.062111808510962874, 0.07009106120676734, 0.11631743618636392, 0.04697271579061635, 0.02802780258207349, 0.03556808420398738, 0.0633493100758642, 0.026904652986559086, 0.04845815034059342, 0.05301040997437667, 0.04295320686651394, 0.05750250369601417, 0.0804290002270136, 0.02127948529960122, 0.002226530928055581, 0.032284474073094316, 0.043511350158951245, 0.0315109669463709, 0.010998165653290926, 0.051674384594662115, 0.03299930329376366, 0.06922717904672027, 0.07101745446561836, 0.03777942081796937, 0.053090780857019126, 0.13118131086230278, 0.08036962841288187, 0.030305229302030057, 0.009613250367692672, 0.03159701154800132, 0.016681364650139585, 0.06354773067869246, 0.027870428311871365, 0.03859896336507518, 0.032340394900529645, 0.04857712774537504, 0.030945585858717095, 0.07852960683521815, 0.04804828073247336, 0.04743527417303994, 0.027643013854685705, 0.07769247167743742, 0.009739866327436175, 0.0180846360308351, 0.09473768906900659, 0.05873798290849663, 0.03339385126309935, 0.041637059912318364, 0.011661487969831796, 0.05600111668172758, 0.01919576468935702, 0.046440169171546586, 0.06225810066098347, 0.031844413897488266, 0.029504266422009096, 0.021516004053410143, 0.021859024709556252, 0.03069755639444338, 0.037234331903164275, 0.030922276855562814, 0.042604709160514176, 0.037583976227324456, 0.011918242307729088, 0.03580105920264032, 0.0377563956863014, 0.010768417141662212, 0.033856754744192585, 0.018096510393661447, 0.042168215004494414, 0.038975491988821886, 0.07352918648393825, 0.013884921590943122, 0.03754916207981296, 0.04793863954546396, 0.052964638016419485, 0.04525917844148353, 0.03348160651512444, 0.03997605548647698, 0.03687220094434451, 0.019307621187181212, 0.06254497784539126, 0.05788131813460495, 0.0497016373265069, 0.06538120651384816, 0.015234300062729744, 0.035867258775397204, 0.040317784805665724, 0.048784101600176655, 0.02337220445042476, 0.04151285036641639, 0.015454384883923922, 0.0337569804105442, 0.031209042717819102, 0.02385451880400069, 0.01723546509310836, 0.05182131128094625, 0.052183267835062, 0.0654627759649884, 0.10298846391378902, 0.055457170674344525, 0.008160658635461004, 0.005892232311452972, 0.027944392604695167, 0.034331758943153545, 0.035691599841811694, 0.038476638874271885, 0.04299965417885687, 0.025661963809398003, 0.07229155133245513, 0.024742941932345275, 0.04844729643082246, 0.07785767375025898, 0.014380984230228933, 0.04362262407084927, 0.05706128205929417, 0.05240846883680206, 0.04579999629640952, 0.04880294101894833, 0.0297514127305476, 0.03666293385322206, 0.019211316393921152, 0.028159502253402025, 0.01755616751324851, 0.05569211978581734, 0.035979768363176845, 0.01826967014494585, 0.03738544059160631, 0.06164531674585305, 0.013027963668719167, 0.02481427160091698, 0.03742068147403188, 0.06342529857647605, 0.05379568385251332, 0.07599595177453011, 0.07159117914852686, 0.02389721827057656, 0.035036598856095225, 0.04073532451002393, 0.045519445920945145, 0.01012946881019161, 0.060098035319242626, 0.11905150080565363, 0.04411161775351502, 0.024192414930439554, 0.05980077177810017, 0.09340249860542826, 0.032407355174655095, 0.030088253151916433, 0.07195525453425944, 0.01732719083520351, 0.03583107907616068, 0.05293413945764769, 0.009707151530164992, 0.061083410764695145, 0.012307412489462877, 0.02042814729065867, 0.026525265238888096, 0.03790840979490895, 0.010954375229630386, 0.058556071380735375, 0.03803964747930877, 0.04784726261277683, 0.1027337068808265, 0.06130102701717988, 0.057452286273473874, 0.03392505459487438, 0.036894098011543974, 0.000905379115465621, 0.06633758996031247, 0.06377510988386348, 0.015915843032416888, 0.0330636326543754, 0.035097499494440854, 0.05525547720026225, 0.02847481668140972, 0.040572237558080815, 0.04877414939983282, 0.012633521455427399, 0.09831657749600708, 0.020292625558795407, 0.02448997533065267, 0.03597224298573565, 0.06058063911041245, 0.012164688214397756, 0.06642233580350876, 0.02111992725986056, 0.05703903989342507, 0.04079700440343004, 0.03312901586468797, 0.04861337052716408, 0.021754320659965742, 0.034810184442903847, 0.02444116984406719, 0.013049831977696158, 0.043604912716546096, 0.032193572114920244, 0.027605053001025226, 0.048207226500380784, 0.016939383422140963, 0.028287695276958402, 0.03905146193574183, 0.05543473926081788, 0.06144704086182173, 0.023460477350454312, 0.032024388419813477, 0.05401150410762057, 0.0158475635907962, 0.01712494075036375, 0.06401820777682588, 0.007258780833581113, 0.04562156173051335, 0.03468309536401648, 0.024893391964724287, 0.08763257501414046, 0.015506685886066407, 0.031946236558724195, 0.10052034791442566, 0.05475945908983704, 0.0889858664595522, 0.013237101811682805, 0.11340346754877828, 0.04587282324791886, 0.023322911001741886, 0.03513073286740109, 0.01128997626437922, 0.05745539958297741, 0.028816583107982296, 0.035296365385875106, 0.17937317490577698, 0.09237518068403006, 0.13313715200638399, 0.1441552842152305, 0.17901931889355183, 0.21315653866622597, 0.16010375577025115, 0.15060312260175124, 0.12922410416649655, 0.1332265808014199, 0.14432680938625708, 0.12142183884861879, 0.25087028683628887, 0.11140941322082654, 0.17729649727698416, 0.10680729610612616, 0.13590861344709992, 0.11292025519651361, 0.12590521975653246, 0.17331478593405336, 0.1473196386359632, 0.08236411318648607, 0.2832411654526368, 0.11885616011568345, 0.1202697584812995, 0.08128693036269397, 0.09927008883096278, 0.06923524619196542, 0.15038116107461974, 0.2165559312561527, 0.11215322330826893, 0.10483857127837837, 0.22988371609244496, 0.18607827136293054, 0.09050475331605412, 0.16664365015458316, 0.08467040388495661, 0.11931552726309747, 0.16481333586852998, 0.15475209918804467, 0.13129077764460817, 0.15019213606137782, 0.09405879463884048, 0.11367147191776894, 0.1563075665035285, 0.14952438126783818, 0.20738576160511002, 0.15915031865006313, 0.19186458899639547, 0.09124506046646275, 0.11602408005273901, 0.13957517920061946, 0.07926161677460186, 0.20842892437940463, 0.20874120527878404, 0.1006822993804235, 0.13238593528512865, 0.14932444668374956, 0.13896367920096964, 0.20399649190949276, 0.1497728523099795, 0.08548392390366644, 0.18638933514012024, 0.18323263968341053, 0.16706386901205406, 0.13849241542629898, 0.19372720154933631, 0.09869938468909822, 0.08862454444169998, 0.12782058416632935, 0.11607816035393625, 0.08252184925368056, 0.1979611540446058, 0.13390448817517608, 0.09981259136111476, 0.09575282834703103, 0.15737241483293474, 0.10002878640079871, 0.09438465684070252, 0.13186411641072482, 0.18996587838046253, 0.09151546939392574, 0.10807776387082413, 0.06322649205685593, 0.12950040574651212, 0.19498111942084506, 0.11566433138796128, 0.12014350431854837, 0.1770812744507566, 0.2642121131066233, 0.11864060332300141, 0.08451525791315362, 0.16186948836548254, 0.17250097647774965, 0.16658441192703322, 0.11671409927657805, 0.15335226024035364, 0.12636572238989174, 0.1458165521034971, 0.13941799232270569, 0.1001245086081326, 0.12257365204277448, 0.14736860553966835, 0.10777599920402281, 0.1641930636833422, 0.13071672641672194, 0.08075291058048606, 0.10050457727629691, 0.19672442431328818, 0.12844052980653942, 0.13492577243596315, 0.1501962327165529, 0.15528493153396994, 0.1944643768365495, 0.1493488484993577, 0.07486574992071837, 0.15272090036887676, 0.14675119804451242, 0.08217102862545289, 0.12108197232009843, 0.1719875290291384, 0.19943673658417538, 0.1642694603651762, 0.17721662734402344, 0.1205772599496413, 0.19328431750182062, 0.29029085591901094, 0.23744275735225528, 0.05112293176352978, 0.1561668998328969, 0.20706041890662163, 0.13077424286166206, 0.1796215568901971, 0.11296242402750067, 0.12172465736512095, 0.15473286272026598, 0.13128414284437895, 0.1543174232938327, 0.07292020236491226, 0.11052125541027635, 0.10905837843893096, 0.17664220504229888, 0.0839070975780487, 0.10517123155295849, 0.10099452090798877, 0.1697537090512924, 0.18271457607625052, 0.11028557157260366, 0.1576368568930775, 0.21133769798325375, 0.2837367122992873, 0.1282438013004139, 0.0796468804765027, 0.1286732524749823, 0.13627110805828124, 0.14580947201466188, 0.10978152713505551, 0.0884900672826916, 0.14357293577631935, 0.07097990179318003, 0.11365020196535625, 0.16871398984221742, 0.14008691970957443, 0.08436761505436152, 0.1860212892643176, 0.20703600224805996, 0.11783678317442536, 0.13697484217118472, 0.19253439211752266, 0.1405805815011263, 0.2158325450727716, 0.13644546823343262, 0.0864944099157583, 0.14461032464168966, 0.14457039709668607, 0.14420754625461996], [0.023248486577358562, 0.012003626397927292, 0.054429069787147455, 0.024579034907219466, 0.017854345751402434, 0.04990334935428109, 0.028349197054922115, 0.047700825743959285, 0.0827831520291511, 0.029199282689660322, 0.022416436986532062, 0.006949288554096711, 0.07207262518932112, 0.030826087095192634, 0.013125559798936592, 0.075857429910684, 0.08917470593587495, 0.05684887197276112, 0.012764162638632115, 0.06188559447764419, 0.047187010932248086, 0.06344879497191869, 0.04443633333721664, 0.06189798463310581, 0.020182581756671425, 0.0552944844821468, 0.06475306756328791, 0.04123489008634351, 0.07822170460713096, 0.039948121047928, 0.06867209711344913, 0.028272410745557863, 0.0348918392410269, 0.021451619031722657, 0.06653957287198864, 0.028516096790554002, 0.053449282713700086, 0.07107709345291369, 0.04151209708652459, 0.021138557021913584, 0.03267586049332749, 0.020218555509927683, 0.0842196901794523, 0.08738377742702141, 0.019166611273249146, 0.08685691936989315, 0.04079297825228423, 0.026647133308870252, 0.015867195252212696, 0.008100034447124926, 0.03336518580908887, 0.035399360640440136, 0.03185522698913701, 0.08159000863088295, 0.039484931839979254, 0.04648665359127335, 0.012283497708267532, 0.08507899328833446, 0.04657911405956838, 0.05285108942189254, 0.027362773325876333, 0.012708221402135678, 0.06628673800150864, 0.01775329677911941, 0.023519144124293234, 0.035960212771897204, 0.07798904873197898, 0.04998451804567594, 0.05222369632974733, 0.02577401141024893, 0.002619967763166642, 0.03012246987054823, 0.07784779576468281, 0.011147085006086854, 0.04374061441922095, 0.021840688095835503, 0.020218948848196305, 0.0303935040574288, 0.019935763848479837, 0.01147376635344699, 0.020058257177879568, 0.05376343382522464, 0.03311719345219899, 0.055764928183634765, 0.02246357635158347, 0.027917515726585407, 0.03245654843340162, 0.029479050099325832, 0.059288111006026156, 0.064759642991703, 0.028044502760167234, 0.01734823814331321, 0.02995995066157775, 0.05907918530283496, 0.015154303964663995, 0.0436053542944137, 0.07009541761362925, 0.008528385387762683, 0.014083610294619575, 0.07521670413552783, 0.012401463009155123, 0.01735314930556342, 0.050674711674219, 0.04563849011901766, 0.00775209335188265, 0.050402792476234026, 0.043025937338825315, 0.02429561242024647, 0.026152842547162436, 0.05984284412988927, 0.05772934484411962, 0.12344910428510047, 0.03339127972139977, 0.05677092420228291, 0.007399720707326196, 0.0486943907890236, 0.009498059771431144, 0.011999994512734702, 0.0228169499678188, 0.007953800741233863, 0.006572672264155699, 0.07414724706904963, 0.020320162948337384, 0.00847596656967653, 0.04235190026520286, 0.017198083114635665, 0.07007184700341895, 0.05205840148846619, 0.02682613932847744, 0.08258507281425409, 0.045279442783794366, 0.01211566286656307, 0.07540986291132867, 0.04131012530706357, 0.0738212290161755, 0.029811072126904037, 0.06927496593561955, 0.07836337317712605, 0.09890688917948864, 0.024936113695730455, 0.0231159519898938, 0.010674173663574038, 0.030384820929612033, 0.01914839154778747, 0.031314839579863474, 0.05158562744327355, 0.04876366656390019, 0.020673156213888433, 0.061854190498706885, 0.01837852094467962, 0.08130444504786283, 0.019284189729660284, 0.027995535856462084, 0.014181484730215743, 0.02942681032436667, 0.021351514442358166, 0.031128541959333234, 0.04759904390084557, 0.04486408128286712, 0.03104420244198991, 0.02369469359109644, 0.0990996026666835, 0.04918985599942971, 0.017943544480658602, 0.022301866083580535, 0.0450272424495779, 0.010434164032631088, 0.055601811545784585, 0.05780758205219172, 0.06924916146090254, 0.06007079849950969, 0.06106161017669365, 0.123061413760297, 0.06958703161217272, 0.012583515544974944, 0.04508198326220736, 0.03379280387889594, 0.060710129037033767, 0.07475689169950783, 0.0030574659058402176, 0.01641391689190641, 0.05765765337855555, 0.02509128193196375, 0.062032009082031436, 0.046576063832617365, 0.020054537162650377, 0.028226312242622953, 0.010779369386000326, 0.043496165817487054, 0.032892916424316354, 0.016907124118006323, 0.03676480846479535, 0.08137165394145995, 0.067030644568149, 0.026519495040702168, 0.028047716259607114, 0.018456563338986598, 0.03622809468652122, 0.02134971844498068, 0.03693625571031589, 0.014027981687831925, 0.05603039811830968, 0.06208355494891293, 0.030705365643370897, 0.02098487864714116, 0.04511092702159658, 0.029743981976935174, 0.028105627898185048, 0.02873760931834113, 0.02905854180426104, 0.037520548576139845, 0.05846533640578855, 0.03400236782908905, 0.026346424347138964, 0.03127952077193186, 0.014890717229718575, 0.03526300955854822, 0.030389882376766764, 0.0565793313580798, 0.014678013994853245, 0.008590965135226725, 0.059804334086948074, 0.018904217540693935, 0.042449796965229325, 0.047732062739669345, 0.03968633587646764, 0.03785873042943422, 0.011004873740603216, 0.030298375568236224, 0.10594955892884172, 0.039034132787492126, 0.030378473711607512, 0.05336033631465398, 0.10271475242916495, 0.02884387744416017, 0.04934418931952678, 0.0075458194351085695, 0.019919165715691634, 0.056823394043021835, 0.03446500042628031, 0.05187279406527523, 0.05489870825840626, 0.06976771488552913, 0.14418753795325756, 0.05074016909929924, 0.01138400823037955, 0.036967648557038046, 0.06695257063256577, 0.04075558885233477, 0.060024588674423285, 0.05150661840161774, 0.025425385683774948, 0.0842422217829153, 0.010104885168402689, 0.03815903306531254, 0.022821143102191854, 0.05317913353792392, 0.02195750770624727, 0.02969503362692194, 0.09080263655050658, 0.027539372931641992, 0.06317306484561414, 0.07346551763475873, 0.02194806387706194, 0.06623057226534002, 0.02639475671458058, 0.029227849809103645, 0.04726355975435581, 0.015328448916989146, 0.1637237740214914, 0.05866503721335903, 0.07604206140968017, 0.04627769078069832, 0.016061836467997637, 0.03501124709146097, 0.0493599414039636, 0.01707586066913791, 0.04082010746060405, 0.01735497313347878, 0.0577177302329801, 0.016941220237640664, 0.03674277781101409, 0.017898679798236117, 0.03338044436532073, 0.026937025468214415, 0.061072185781085864, 0.04414314047608059, 0.030918529009795748, 0.027584796080191154, 0.08710669659194537, 0.02961480560770724, 0.03267843203502707, 0.011723008301487425, 0.03991358520579524, 0.003925060427718563, 0.03945500102418009, 0.01932984851009678, 0.054209538793656975, 0.048161506492760964, 0.032182202412514016, 0.028521011663542595, 0.05592949572019279, 0.00943636781812529, 0.023090963877621107, 0.01652631144679617, 0.04252331411407795, 0.029557513662439305, 0.007775770645821467, 0.03553041649865918, 0.022183719884196762, 0.04200128372758627, 0.03915605280781165, 0.048138384881895036, 0.12919247383251786, 0.04421598969202023, 0.0646319193765521, 0.06457602081354707, 0.0683247200504411, 0.0719205146015156, 0.018392677411611658, 0.036492414292297326, 0.04245093987265136, 0.05866805775440298, 0.024209339608205482, 0.03977612090238836, 0.055205256066983566, 0.05552010850806255, 0.024136067368090153, 0.03637075402366463, 0.024160326320270542, 0.060040058742742985, 0.04258154302078765, 0.017960706645681057, 0.021159042153158225, 0.02594540113932453, 0.03832076188700739, 0.06356393918395042, 0.11023900180589408, 0.027160376666870434, 0.02039432576566469, 0.03338619600981474, 0.06558597247931175, 0.054688387317582965, 0.0776027534448076, 0.021242036527837627, 0.03995800645498093, 0.017571917742316145, 0.016831222819746472, 0.02149963784177089, 0.0396146592538571, 0.04383176128612831, 0.08318876542034559, 0.13713556167203933, 0.13939739030320197, 0.1753549202112481, 0.0725420039088931, 0.07854142924770713, 0.13345108047360554, 0.10986521912855096, 0.15466581709915772, 0.19123763748211786, 0.12692165037151426, 0.13074470538413152, 0.12569347018143162, 0.23147494008298963, 0.12810792890377343, 0.18575104360934347, 0.2964394900482148, 0.22043807606678456, 0.17744690092513338, 0.0902639857667964, 0.14481316844467074, 0.1452165108639747, 0.10279508991516195, 0.15999271563487127, 0.09289546331274323, 0.061025241229799576, 0.24171970988390967, 0.09923205376253463, 0.17690566746750847, 0.1533339885645546, 0.13454044936224818, 0.20578065945301205, 0.135021242313087, 0.1294615468941629, 0.08408418143517338, 0.13195439125411212, 0.15770191355841234, 0.10178594719036482, 0.12359907006612048, 0.14769722853088751, 0.19276003469713032, 0.15769762394484133, 0.08625128233688883, 0.20619835500838235, 0.1312211641925387, 0.13520833774236962, 0.13217531377449632, 0.135370526695624, 0.16962254187092185, 0.1526295716757886, 0.07316961593460292, 0.16894773667445406, 0.06655853474512696, 0.13749458303209394, 0.38609131530392915, 0.11751036436180584, 0.09168107964796945, 0.18606728757731616, 0.227589069691021, 0.22512922121677548, 0.14616455999203026, 0.15236594597809017, 0.06677324548945762, 0.17224696901394054, 0.11051085049984977, 0.12920042965561152, 0.16232766065513715, 0.150721539685037, 0.17835309292422608, 0.15154596185311675, 0.11186735544470139, 0.1131682438426651, 0.14986619964474812, 0.16371231526136398, 0.20380521076731384, 0.15198160253930837, 0.08876940424670465, 0.1255013726768084, 0.1163910943432711, 0.08894245824194513, 0.12915870611323044, 0.1691176142776385, 0.23633778851944953, 0.15784130373504013, 0.17544592235935852, 0.12145279382821172, 0.12607585435034707, 0.15265293448464945, 0.12420636950992048, 0.12855410808697343, 0.11980329640209675, 0.16933954611886293, 0.08426316519035026, 0.12096208578441292, 0.29946009046398103, 0.09960984403733164, 0.11703321535605937, 0.15390389860840514, 0.09972206418751739, 0.07637297021574341, 0.1629070405033417, 0.12465937645174563, 0.12823483615648001, 0.16131121519720182, 0.16066124226199463, 0.08409993723034859, 0.17552304634591565, 0.129819885478355, 0.15820550528587773, 0.16443911532405764, 0.3323621390154585, 0.11271240189671516, 0.23332423850661144, 0.1376199911464937, 0.1928995139314793, 0.13468433695379645, 0.11934309062780812, 0.09100551003939472, 0.18236074974993244, 0.14279843046097085, 0.14195520227076486, 0.11189452547114342, 0.1195274994825013, 0.10032426507677883, 0.1018612454936374, 0.1311745127895847, 0.16617591900285333, 0.21182456170208752, 0.15422432828927413, 0.09808898306800984, 0.15347235457738861, 0.20199714606860653, 0.23187353275716305, 0.14765370899112895, 0.08422193146543577, 0.13089239277178422, 0.0797263570711948, 0.148643214488402, 0.2056593183078803, 0.1730855365167372, 0.1680258705164306, 0.20226788154104725, 0.21977949421852827, 0.12142576480982825, 0.09438961438718252, 0.08906017770641483, 0.10531180916586891, 0.19687231950229034, 0.21912273805355653, 0.19358589663170278, 0.1729423613869585, 0.23463795863790438, 0.06080456732888706, 0.09090701962122694, 0.1315924755181186, 0.15395617549074814, 0.09258580961613916, 0.11576041724765673, 0.10478720723767765, 0.18935571424663067, 0.13414225744782016, 0.09996601555030793, 0.3203720605233684, 0.06022908004524652, 0.11668154125800356, 0.05674936852301471, 0.17116708477260545, 0.14180819765897468, 0.1190452890296001, 0.1033451697730925, 0.1613730806275271, 0.16608047881163657, 0.1895519529352896, 0.22465429123258218, 0.12509676860645413, 0.12858796486398205, 0.18274093716172501], [0.04388213455968071, 0.023014576472633053, 0.01918648042192217, 0.019585564768931363, 0.026830705392058007, 0.04929519272991456, 0.026280404745193664, 0.06907102375407703, 0.04202832387818489, 0.03653267951449379, 0.08845309348544106, 0.1339212161838077, 0.035758675148827024, 0.0595691103808349, 0.02265595772769302, 0.012594094860105542, 0.02369239849940641, 0.044027643743902445, 0.0550732984993374, 0.04854481463553384, 0.0327566395571921, 0.04499604627199005, 0.05550659028813243, 0.03119191766018048, 0.02296794733410934, 0.08215151014155708, 0.03725038826814853, 0.0025413527555429027, 0.05832172711961903, 0.041011678040376864, 0.042839973684749566, 0.03540079669619445, 0.012820778301829705, 0.06290983248618431, 0.07757547209621407, 0.037072892519063316, 0.016385748676839285, 0.08108152615022846, 0.01766936173225986, 0.060446518182288855, 0.015869751950958744, 0.018859234114643186, 0.04363738167739939, 0.033862261479953304, 0.035032008672715165, 0.023436771298293024, 0.02396591517026536, 0.03832358946965542, 0.008561262529838132, 0.04269357392331585, 0.06259302448597737, 0.019544368151400704, 0.06777897433494218, 0.03895678986737039, 0.011584067124204012, 0.048134540556930006, 0.06632544100284576, 0.03336592795676552, 0.07008185115410015, 0.047451939099119045, 0.006809627957409248, 0.02709678574319696, 0.019497811372275464, 0.038723035613656975, 0.05578091033385135, 0.0818087715015281, 0.039217743833432905, 0.0506082931678975, 0.016554041794734076, 0.05030196800362319, 0.020589100568031427, 0.07826989225577563, 0.034221568566863425, 0.06296141917118803, 0.026602153593557887, 0.018970424534927588, 0.025949950504582375, 0.05254358795355074, 0.01244562357896939, 0.04240229580318555, 0.029830800267518498, 0.019848785996146034, 0.06543201394379139, 0.029471580382960383, 0.05496791723999195, 0.044626401067944244, 0.047049427885212936, 0.013145527282176772, 0.037894372071605176, 0.08923291999963112, 0.05249474721495062, 0.033371846584486775, 0.01755716384650441, 0.08783280645729974, 0.01440712267140043, 0.14869351725792512, 0.03774621713091619, 0.03222974810341839, 0.028955600355402566, 0.04009862488601357, 0.02172591495764209, 0.07740637374809012, 0.09798297469387762, 0.015343198174377903, 0.062283452425617725, 0.04711799861979671, 0.0894393038470298, 0.023075217359291855, 0.040557698885095306, 0.021292420933605172, 0.03484125445538666, 0.015126736889214953, 0.0016292734380840557, 0.023056641402945388, 0.04098857127246447, 0.056510070426156744, 0.028006771972286515, 0.08357716840691864, 0.07074288951116614, 0.0361542435712181, 0.05802490886708256, 0.011799356743722456, 0.022428213014791254, 0.03599947980546858, 0.0814826792338863, 0.020722551707876846, 0.03594819369027391, 0.04925068613374606, 0.013610400237666909, 0.02060784536297433, 0.027923276647925377, 0.05994010629365221, 0.05750607713707723, 0.08031885809032246, 0.025943306427507196, 0.010418159617984202, 0.057503973148413934, 0.033124763358500786, 0.07356736256042495, 0.09048093037563376, 0.08076218742644414, 0.02750841980741825, 0.008036472281673923, 0.015488662829739042, 0.10766397943370976, 0.07043273115414195, 0.03322580305393785, 0.03888669773004949, 0.04465789039386436, 0.027456610478111543, 0.053836060396861285, 0.026978235073329415, 0.06846832562587224, 0.009620612472645007, 0.028826633642893285, 0.04209975559206214, 0.03485645735054277, 0.011407244874135358, 0.039953464511199854, 0.0264076997700613, 0.08174663889803924, 0.039939463895279914, 0.05268786146189086, 0.02467597609211225, 0.03820534679107368, 0.011935221718886169, 0.024002927930268925, 0.011435335163696436, 0.01021746989863459, 0.02599317318527028, 0.11543992819497362, 0.04800339935172815, 0.030948224193707574, 0.023379924641631078, 0.019229220706620254, 0.028854762895207386, 0.02028542116022436, 0.05483649772941135, 0.03182822394592222, 0.05904082368942909, 0.07419250323437154, 0.026435112849867437, 0.02699377935641678, 0.06796811809181236, 0.052396442333702, 0.010811159281729488, 0.022572625675820746, 0.03789396017964464, 0.054424089976237155, 0.029526744219765533, 0.014267826190916821, 0.05416110252554063, 0.039830961904954165, 0.04455376336409245, 0.030955938818806317, 0.026185194619756658, 0.08434043018496595, 0.007418815703204018, 0.028001845967082772, 0.005837195567437448, 0.05445830298413057, 0.06894491802086122, 0.0675539774238132, 0.034069513640133664, 0.03660197013232391, 0.028537871403386816, 0.15078150521731004, 0.011615154762694146, 0.04670448135584593, 0.10503113633603789, 0.0494895908923354, 0.07365475787082687, 0.030363653022504877, 0.07535772703704424, 0.09825605535297655, 0.014208695574779995, 0.00848690860948409, 0.011171815222041914, 0.03941386748920195, 0.04527189514192287, 0.10311620237189345, 0.030916721880203113, 0.03366555152751971, 0.009071658823813777, 0.06677158307866193, 0.06068252114346251, 0.042449143875273876, 0.09252479765564203, 0.0224627952411538, 0.01496528080679127, 0.08370120354811661, 0.043141359856235795, 0.0508729467401281, 0.030939385214878712, 0.033937737898668274, 0.0695137371076271, 0.03067364068556344, 0.022151829798531253, 0.026201993132417556, 0.027586289652390406, 0.033493592200102285, 0.04253727020113729, 0.06480373398517258, 0.06953400516067632, 0.04011315242678393, 0.06792848740587942, 0.03873242749250494, 0.02849112166586565, 0.027529417020559777, 0.007764015490465681, 0.09957010202924721, 0.048899731918936595, 0.0218376564225764, 0.03594237154175062, 0.034461297109373845, 0.061438391130650416, 0.06750708111212589, 0.08229481885791756, 0.0469732130295597, 0.00788603338151006, 0.019939513549616095, 0.0548841361887753, 0.0148663887011935, 0.03017783037648769, 0.025302858957729768, 0.0626811471011024, 0.040903795743361115, 0.025712312963150907, 0.03355028115038294, 0.042465656661079265, 0.04865991802944336, 0.0917783158365637, 0.1166504378488753, 0.043820781211252324, 0.006232478262973018, 0.07653673994354904, 0.05346040750737302, 0.048857433212106116, 0.02512937266146764, 0.024893020890885964, 0.050073082238668576, 0.04118787132028956, 0.05684153213223908, 0.11504382913699374, 0.03506670778733678, 0.08432606962742284, 0.021827149466844276, 0.054250586981652305, 0.03572604662622325, 0.011863507988891797, 0.05092164647066966, 0.04645473753043916, 0.019716553833859507, 0.025303326510766055, 0.044435765594244, 0.058871435903711244, 0.10824216442415491, 0.030263090156950057, 0.02420859003905207, 0.01641085182200186, 0.048130866925930604, 0.029863664422009606, 0.052548597450368106, 0.03598557195800822, 0.032579674443695694, 0.0052332209452288225, 0.02687634932954097, 0.05689430996426381, 0.028026082654832862, 0.046024069233681075, 0.04161201242823154, 0.011301994418317918, 0.03408728807698935, 0.018030577994068153, 0.06533505977131426, 0.03391132486285642, 0.0541026361315744, 0.03797489880525973, 0.0052177865927660605, 0.0321952864760533, 0.03871503897244111, 0.027898097432625946, 0.015898523161013145, 0.03443190063990187, 0.04001882916782051, 0.005735500926675741, 0.04552599166345317, 0.018359805835643783, 0.021560269451583736, 0.06038168787199538, 0.024361633877560962, 0.016081833637144882, 0.0787145945650991, 0.06325962152914144, 0.02364021809626138, 0.02347385456232587, 0.08981578794191591, 0.010527104113862151, 0.04361988183518406, 0.009811277632252313, 0.03075331394938985, 0.04757005561259575, 0.006600935103051597, 0.032091541652334854, 0.031451357644982636, 0.04434924601810053, 0.05144476410350762, 0.046317043161252514, 0.06796756890253164, 0.09018051641760394, 0.04723390724393539, 0.015729163205833174, 0.050804602360585704, 0.10902041758527048, 0.11732611135812476, 0.10619315406074747, 0.16330962593201548, 0.1981080844416283, 0.11440831323852763, 0.1516435097437352, 0.11593711518798955, 0.10934963429463096, 0.12813966313842684, 0.22952757426537573, 0.1945652940776199, 0.16500555211678147, 0.14539443334797397, 0.11695153458276764, 0.15014116535894573, 0.09241873733117245, 0.11910545494174585, 0.0995607212826144, 0.21652511728461832, 0.1297096913913265, 0.1264358256594278, 0.12317409404204227, 0.12131508090533316, 0.14492400077870116, 0.20827286556595936, 0.11626294028246775, 0.12671763397520408, 0.13398392766248435, 0.1615636344649829, 0.1174212027399335, 0.13728041405556723, 0.255844546481967, 0.2184952373499982, 0.1206479272514116, 0.09845180422416888, 0.17986793507589027, 0.17919510399224237, 0.18337885761866346, 0.1390464583528228, 0.09335939466836862, 0.07466338851372711, 0.0894013058859855, 0.16494937153765932, 0.1240681741910521, 0.0953647964342963, 0.14118232968030497, 0.1200654600688722, 0.09975097826099955, 0.09585739695467055, 0.17413603171007708, 0.19845347997033969, 0.1285105143324472, 0.2238238725112751, 0.19826012081466615, 0.156445472384803, 0.11921556739252992, 0.12164449799456634, 0.18271125125465915, 0.10803488257806748, 0.08611447483417578, 0.12280931361601688, 0.07981732211192138, 0.14695836114697158, 0.17633302632020786, 0.19473483029287308, 0.19104476814391091, 0.10619757726090029, 0.1477991254068911, 0.13421292474959046, 0.24437469866825268, 0.12889862788142636, 0.11338198979501612, 0.19975367817096412, 0.1293270252062939, 0.1327882832265459, 0.2054743008920923, 0.14532764005707577, 0.17280504922382534, 0.19995615090010688, 0.13582525542005897, 0.1436980173457414, 0.14576178160496056, 0.11171272155479528, 0.11223223977140151, 0.0726409544586204, 0.1721265778178349, 0.15709114086348563, 0.15653776586987078, 0.1004567755444441, 0.09245963708963245, 0.10646843889844604, 0.16822050616610795, 0.13293035997776315, 0.19743929064134136, 0.19333660922711715, 0.12578460591612384, 0.09346254577394575, 0.18179149279603735, 0.15914779534796253, 0.13081127603072673, 0.1752772173495032, 0.15607094013830647, 0.10012509490479715, 0.13070240296656266, 0.16553860710700974, 0.22879946802277118, 0.12890536658233032, 0.16388823394663632, 0.10456225485540926, 0.13584575353888795, 0.1097474922426045, 0.13031427457462996, 0.17405322287231684, 0.09731033656862564, 0.20205224311212078, 0.13860391569323838, 0.08471031658700667, 0.22170833603013307, 0.1338589796796441, 0.12141595361754298, 0.09426319695194252, 0.10174750394071452, 0.15048075729282573, 0.0899215365643613, 0.13111153413774446, 0.17628478672122583, 0.19437076232861727, 0.10445954903843813, 0.05743364352383651, 0.1669446800951846, 0.11537935410160571, 0.2196264039957896, 0.1018798362929374, 0.1941244286717847, 0.13899667508667335, 0.09540469429339282, 0.10327944517484866, 0.1607449713628739, 0.1945160748437047, 0.20115740597248077, 0.06865064162411727, 0.1498970581451431, 0.18944898736663163, 0.1399034756468609, 0.19202722323825583, 0.11599805293371901, 0.19747359270695597, 0.1622168134781532, 0.1259856388787739, 0.08376269048312679, 0.1651437400141731, 0.1062120268761646, 0.11619275537668727, 0.09918308685882948, 0.1274912487133406, 0.1013877330115065, 0.18541456869570538, 0.09666676094639115, 0.1812102724215947, 0.057505134609527886, 0.16293504915665835, 0.08556428365409374, 0.0915666478977073, 0.12759209173964337, 0.09538217753288336, 0.10941929969703779, 0.12612446502316743, 0.1629021720145829, 0.2217940244008787, 0.14258950104704127, 0.19246393261710182, 0.22425636649131775, 0.14414560660952702, 0.06774631983716972], [0.0439989263395546, 0.055217134140548296, 0.051978479605168104, 0.026609714223013725, 0.0248018072306877, 0.04451554275874514, 0.01183215317723807, 0.08098563324892893, 0.019275213453511242, 0.05977318614895921, 0.024020409218792338, 0.014936822226445656, 0.03790376766119152, 0.04747831502754707, 0.06454632006352767, 0.07047743070870638, 0.027410068541939836, 0.03960260306484997, 0.07114105916116387, 0.04714124268502928, 0.024149841628968716, 0.03811635586316697, 0.07302087469724938, 0.05032962784753181, 0.09773267796845175, 0.07149875207687728, 0.08400057849939913, 0.019697133684530854, 0.06692571972962469, 0.029062000212434214, 0.02270044577016961, 0.024872582143871114, 0.019750809515244327, 0.034125471574952826, 0.03671822756587062, 0.027808733575511724, 0.04717053525382653, 0.03189400791598018, 0.03170200689055491, 0.05205503955949098, 0.03239178491639905, 0.03370376471139025, 0.04184875011560507, 0.03893803579558153, 0.02940335474704625, 0.03251346373872366, 0.08854749466991052, 0.07426026131724939, 0.15423580189235508, 0.0471462187852012, 0.0675774589763023, 0.058400713896844536, 0.05900458090764005, 0.0046884567200322635, 0.011004245698131854, 0.03086355256527895, 0.06738925774698146, 0.02931410592282191, 0.009251948758901563, 0.014593607684219023, 0.05097871020552702, 0.08639666164526716, 0.02115123290423071, 0.03568505781004205, 0.0036445121395445312, 0.05401904803875368, 0.0722840333764907, 0.04265020281309262, 0.027280680660624057, 0.02608604740089504, 0.0916696505737491, 0.025235460816475097, 0.03280211836681701, 0.02458631537592737, 0.07627162252902053, 0.07197451326646842, 0.06805672310292721, 0.02445146528771147, 0.02291093740495853, 0.02636521923705004, 0.05766279275121633, 0.02109476103214547, 0.024303583086293656, 0.051120805510436185, 0.011693380838551093, 0.024343334371224046, 0.05826983986480627, 0.08668561684316956, 0.024663508011144586, 0.012039342254865915, 0.019841305147565436, 0.033431979099987075, 0.02289142634253949, 0.042456038427189924, 0.026346583908889443, 0.04879796120803803, 0.06661402512690984, 0.03458641207544133, 0.01847266794356983, 0.08643608452985063, 0.09477642175625078, 0.07050566942780279, 0.06790042680222541, 0.053668502005166374, 0.019114761125820223, 0.04354790835350286, 0.010339594937249785, 0.025915583501046058, 0.04254777901223861, 0.04572195204673335, 0.01457882224713103, 0.04503958436544053, 0.08405968314036727, 0.01498582159911166, 0.031291899795178324, 0.06700171565171331, 0.016363306131097488, 0.01747655918734381, 0.013440983693726594, 0.04096647382539231, 0.012516496826719958, 0.02910006311140023, 0.009730210986163002, 0.03638397167378571, 0.08151344867656007, 0.03708934222231619, 0.04123199199966621, 0.04406966414535418, 0.011201266424905043, 0.006732853244102444, 0.0426671163586434, 0.05818410325446166, 0.013035156935075065, 0.03131042009044904, 0.09710793805425055, 0.0547030744201038, 0.021193639222474303, 0.06398970188456587, 0.08703056708327495, 0.08184277670807205, 0.08273034080048092, 0.04854095175687689, 0.0429466203058837, 0.07434971979819238, 0.043140717898495495, 0.037114538135938346, 0.03958209010306746, 0.03533078619511798, 0.020100195943086874, 0.020239467376086395, 0.021621986452373676, 0.011344374761392828, 0.0838465457491111, 0.1294752024114132, 0.0528171918267617, 0.02804075862513855, 0.024262638798973057, 0.04029150906717405, 0.08249450111179613, 0.049633122252998874, 0.03970178739109542, 0.025098404694290366, 0.0696140606305562, 0.1123914156050887, 0.06303147049038671, 0.014511227436742047, 0.0005339024301065365, 0.011077444651164114, 0.04134833478019573, 0.09961115021724254, 0.02106608073518146, 0.04053386852319818, 0.04256346801412292, 0.03786871973716188, 0.04984888313629199, 0.04643807631509844, 0.1091002875182312, 0.06145910076156724, 0.13843849097611383, 0.03888511695549823, 0.038156546870595776, 0.08747700601816177, 0.08795767280389555, 0.09584436484146863, 0.025509830957162194, 0.0433765761408722, 0.03624546094215475, 0.04151613808062393, 0.0916484028857667, 0.0850030715810135, 0.04121341604331974, 0.03681901493109763, 0.08267536250059493, 0.020816155083593912, 0.10859278467250988, 0.04752158223709557, 0.03783910804486368, 0.00929405543502071, 0.03630995728599373, 0.04991505673388019, 0.038803766437922604, 0.09418762405402958, 0.022005793689459097, 0.008816980644041905, 0.020674757397500798, 0.040353118456550874, 0.05013096975744702, 0.03915079098078422, 0.017694739472062793, 0.03597046925278846, 0.030172611222951673, 0.016165885572263505, 0.042834188643610105, 0.036611543837352656, 0.03871454915497452, 0.0384154191124253, 0.003813920102402335, 0.031380942673422396, 0.02901508163631661, 0.006227835201570997, 0.02024993907980388, 0.014552612374245655, 0.027231778694840614, 0.06552565813763067, 0.09297761163907126, 0.1472708795336075, 0.03225655818823725, 0.0189129897262319, 0.07372392603429034, 0.04616930011252407, 0.012332446058280766, 0.0357782233186299, 0.011877974302478833, 0.05559898025239818, 0.07438615924911574, 0.016616261600574944, 0.045707728786510415, 0.05754761143180076, 0.02802129580231849, 0.031894594212644733, 0.04357915648142807, 0.03829992238024715, 0.0173709701266489, 0.03978096712671686, 0.03232585251680575, 0.04866368442890234, 0.014346057832881343, 0.0531381484324811, 0.028625914237636607, 0.07006343104876578, 0.0190186251711566, 0.07791518277372234, 0.02980890691105742, 0.03979219211032614, 0.08606824645539746, 0.06651471834629774, 0.10572416125796735, 0.028056130358891096, 0.07438815562636591, 0.07866927902796306, 0.08426365500781685, 0.027928885428991634, 0.06176355200295802, 0.05075703811598942, 0.010698776786739472, 0.01758610575052444, 0.05115494801430032, 0.009469880424148869, 0.07320935794268735, 0.05857835065398831, 0.0451945819077082, 0.032650044886395335, 0.05514792515896261, 0.046956266087363474, 0.00814975091998349, 0.030817021761322394, 0.11177777079865336, 0.04738251489470713, 0.008790588017291157, 0.050692404474830255, 0.05392462458985392, 0.023710414134257007, 0.056040632334770635, 0.04189019906334579, 0.0472169083514018, 0.09294853429310024, 0.02383273676969111, 0.06656234938418493, 0.021096198943268973, 0.043985575102851726, 0.07339648305787705, 0.07193386583821848, 0.013908745459048077, 0.03949017140257638, 0.04803333758900408, 0.02170737239794107, 0.022182148386491463, 0.005522421979549108, 0.028211625140102115, 0.027525225741555914, 0.036262727007851936, 0.009488930427323794, 0.06804042553994805, 0.051473500061547384, 0.020791530623682775, 0.0475025201740209, 0.007639916339030606, 0.04267848235031124, 0.04089460795512423, 0.04874149861279875, 0.03285033941210713, 0.04594429577991832, 0.02888037997763604, 0.04887687748123426, 0.07993151637492701, 0.052492661779979244, 0.04607911432685796, 0.015265999973053113, 0.016659603024891112, 0.017499560199212283, 0.041649628183222376, 0.043093209314974956, 0.04200890558422543, 0.04619177234417293, 0.03140347056614701, 0.020073604791832622, 0.06504246062831953, 0.04053662189107854, 0.05566342835663818, 0.04934325050271582, 0.05555078518227674, 0.0207949556352105, 0.014682074470329098, 0.05730859535105992, 0.009959811995940981, 0.017520149231131654, 0.04296997569326777, 0.03005635935551254, 0.07946630110382102, 0.045931527129141614, 0.02767757381661795, 0.0021120238034200156, 0.036402510522748344, 0.021702249723603018, 0.026407488257973455, 0.08655412311782129, 0.060699683308484964, 0.03736470127478242, 0.08261620590928942, 0.032038570861914195, 0.0030591522045142483, 0.044457903859438375, 0.11763476315536536, 0.13642899255501106, 0.22470264957519248, 0.14055432431632653, 0.12286167955608107, 0.22583945654332638, 0.17733029468217865, 0.22864308266434819, 0.15007811249233782, 0.06828207624494098, 0.15070056659169495, 0.12174607574706897, 0.2048021525843069, 0.2186736644944176, 0.21341942221624777, 0.18778194556944072, 0.18966268136864528, 0.12573504529427737, 0.19031560805160552, 0.14216580893844366, 0.18849661893909797, 0.07557452321634628, 0.12250483268871903, 0.08460974073386751, 0.09605966188246384, 0.21993394999299198, 0.12343198293820024, 0.20081713126273826, 0.19466022960841656, 0.134009012253955, 0.1355937498738058, 0.14890168968122452, 0.1125930793932639, 0.13840402563801035, 0.1476935326354578, 0.19503862102283165, 0.09428569886949845, 0.1283502104342915, 0.06549321886268444, 0.12884056224720553, 0.12855704699177295, 0.16432280594017357, 0.12254985878826119, 0.11565915861865506, 0.20479621540289372, 0.14220168435713276, 0.22045943507691845, 0.2211476137745194, 0.24708077689865604, 0.17096329102059826, 0.10421503364341334, 0.1655239867977798, 0.23429349821526557, 0.10680932959076017, 0.08164494240190834, 0.20591518114088103, 0.182498462672811, 0.1743718862417154, 0.15183191135292873, 0.1546629672520794, 0.13374825124628842, 0.18716225225944072, 0.13940564298536628, 0.10905270100920461, 0.13861365267075598, 0.10364162066252902, 0.17687235987978056, 0.09705710093840025, 0.10706567481975071, 0.1039671414764598, 0.12274846492800862, 0.12691483745584264, 0.08696144344867207, 0.1513109088409692, 0.125622877094429, 0.2574589551659301, 0.13907938002375886, 0.08975309872766957, 0.1876298795104958, 0.2495961677050218, 0.22673068684525788, 0.10062237837701105, 0.11160675770952366, 0.22196543082827702, 0.290810062433593, 0.1441986404825002, 0.17793106322642416, 0.15364560153102502, 0.09448755561606959, 0.14433660573558882, 0.10272847473970614, 0.09201952125295065, 0.2349657949525863, 0.12927120085805655, 0.11120550814666785, 0.17887451103888452, 0.156807373277843, 0.12818824412534013, 0.1365567310131155, 0.25662074389401823, 0.22284431179286912, 0.10323717244318686, 0.1410750299692154, 0.18752131814835593, 0.11104002405772917, 0.19812261569313705, 0.16395747632486746, 0.1702730343095027, 0.13735721149714664, 0.16126215923577547, 0.0989532214589417, 0.15577262645820156, 0.19719196250662208, 0.13446881726849824, 0.12662260938668624, 0.1674318703589961, 0.11182662638020702, 0.14511097746435553, 0.10954700846923515, 0.17438975715776905, 0.15860654704738408, 0.16367361968150362, 0.10157870245166123, 0.08749518863623962, 0.1366445716121234, 0.12648001313209534, 0.2259909882559441, 0.20543277030810714, 0.10409430848085321, 0.2189515542704612, 0.18014699744526297, 0.08815648674499243, 0.17095986229833215, 0.18073108250973746, 0.18447288719471544, 0.22647972218692303, 0.22017698851414025, 0.15341624821303412, 0.1529371622018516, 0.12962003995198756, 0.23253472696524113, 0.1060236846387852, 0.16960428503807634, 0.15810580516699702, 0.18014797708019614, 0.17138346534920856, 0.1261081823031418, 0.08111363145872019, 0.08397872967179865, 0.13786044699372724, 0.17194153071613982, 0.06608099240111187, 0.21357634192099795, 0.24416772852418944, 0.1561388318077661, 0.23052693548379466, 0.11888854744029231, 0.12008247751509771, 0.1535589186823927, 0.10173464252147824, 0.1481132468325086, 0.09749627424753271, 0.15454576729098335, 0.3100886842003092, 0.17444898054236546, 0.09380460163811222, 0.11156505643157288, 0.13527382485335693, 0.17667074804194272, 0.24418656423222274, 0.12778260104823858, 0.1497773200389929, 0.23501243151258677, 0.13651214278070256, 0.19014467659872025, 0.14099171647103503], [0.09302256352384575, 0.012573479853017488, 0.08672313982970081, 0.0662720954278484, 0.06328387491521426, 0.010954111767205177, 0.04450001702934969, 0.07382582291029394, 0.018013870394497644, 0.02054497988865478, 0.07593941496452317, 0.0397819987119874, 0.04506272824073676, 0.07632643013494089, 0.020757872371177655, 0.051228023585281335, 0.06536763263284229, 0.02544724935432896, 0.0768577262351755, 0.027355925158190075, 0.03760182487894781, 0.08877113345079124, 0.04844800518185366, 0.012188434156996664, 0.03668418896268122, 0.023108645546017215, 0.03080543869145913, 0.05084642980364151, 0.03618262329837307, 0.03374306143086869, 0.050276605106773786, 0.03778369187784847, 0.06788973245420493, 0.03528443907271139, 0.04064381399075501, 0.01654326024436159, 0.056256148309330456, 0.007466552960977424, 0.015489190682274057, 0.025384777218278032, 0.04222628063871525, 0.06522356692585163, 0.06445937746320851, 0.09821112573263235, 0.026072967048094142, 0.09189839533064514, 0.1114306460658554, 0.015868972695898265, 0.025123778723354917, 0.02658149962371681, 0.018946709205920342, 0.08535921340808272, 0.0417088478570804, 0.05505233282747213, 0.04301897599361837, 0.06584204311366193, 0.03789040900301188, 0.031770303030498326, 0.05857682182977442, 0.026625403224898037, 0.05732942001486663, 0.07519556034822017, 0.05480886386067141, 0.048046165611594915, 0.017709374624246266, 0.05588593536231201, 0.013650927066919394, 0.026131635677302256, 0.03107513144641416, 0.04482253956666682, 0.03277977230027318, 0.02280673430504976, 0.03172454220475629, 0.04568241041852161, 0.08228118560509756, 0.048067784373415634, 0.05011516943341121, 0.023575241211801767, 0.08690094357007183, 0.044499196956167, 0.06096455210354179, 0.010074777164845727, 0.027763570178649388, 0.15598611265886575, 0.060860343437525444, 0.004248923469276633, 0.06623573761316948, 0.04039629660837818, 0.09435897110961378, 0.023906509959488176, 0.13316899014171213, 0.007138463852243149, 0.06779459654353559, 0.07094801912899129, 0.03179307212121785, 0.026968778256559744, 0.032607894609100185, 0.016541219338250812, 0.024484752466378268, 0.0069708929368061945, 0.021797597146360204, 0.046823102529742755, 0.05302986908645835, 0.022080748749431223, 0.13122135715093464, 0.04720611010270659, 0.0397880397940753, 0.043476829159772024, 0.06048911003745161, 0.013135550962033449, 0.05621746757242363, 0.018265549369971268, 0.03157888459099922, 0.05984492214338388, 0.02677594788110582, 0.036451202831813134, 0.021828650460520294, 0.03660853071778547, 0.04094186420843471, 0.11545347981154919, 0.007467871200788068, 0.007759541731502395, 0.03578162235498894, 0.027326554663886782, 0.05190450603549834, 0.06702171653159894, 0.061315357888815925, 0.031567559417453595, 0.06365906025166623, 0.045403288677334785, 0.0599279796006158, 0.09383073265780695, 0.01690110715571791, 0.0693922772188671, 0.010753721689980011, 0.0398190467240056, 0.03773436132178176, 0.05670731843565591, 0.012293339514144463, 0.08239791059168056, 0.04106424436031375, 0.0648291377001442, 0.02056480079772882, 0.053509838253376074, 0.0718834443250671, 0.01924545333167771, 0.04714738766779192, 0.06038350984454155, 0.03354837012011558, 0.06887154188007116, 0.08396824312512763, 0.03970445541199297, 0.05049946834333241, 0.030731767546967603, 0.0592857546871528, 0.025399378973816056, 0.024939794748206623, 0.024675695931364316, 0.08160633587976918, 0.04655246724723838, 0.015610664486302994, 0.07367614656686783, 0.026245761291647796, 0.047425214361283, 0.07157974265282974, 0.013519001968234079, 0.0720409800123889, 0.003526386349221866, 0.005139293807587819, 0.031054227001732215, 0.06813210304244421, 0.003544904557202244, 0.01939983674674295, 0.06021565459377598, 0.020593447698047385, 0.05707784308469854, 0.05633075641526375, 0.027638419960567262, 0.07563079285318963, 0.037146658287383616, 0.06694461480947211, 0.013687088212464005, 0.04338407554314472, 0.025431656831642613, 0.011299140860501211, 0.034585143002914265, 0.06614475030801259, 0.032366948944400065, 0.0318140192393912, 0.02393178379861638, 0.009775138751138002, 0.03199277292878833, 0.014300499242381193, 0.05587444691627752, 0.06575248815352097, 0.045020778343314305, 0.01611645482626045, 0.037517438977374695, 0.054424409099738114, 0.10500211094040424, 0.01862743913079612, 0.02013839428400388, 0.059511300787562504, 0.027110044211440254, 0.027799773997685406, 0.011692975440382725, 0.018239900746266358, 0.08428359651588835, 0.05179752544790972, 0.05390886879467871, 0.05207697002333589, 0.017555519989400636, 0.06927558933966793, 0.029952121003589127, 0.007604999218528974, 0.01606352856470039, 0.029164299703552388, 0.016998540013446473, 0.06541618393384852, 0.08397323777899146, 0.05669296529958956, 0.03208603862731252, 0.09267969129723497, 0.03873191169986967, 0.04283337970264256, 0.07571374269900844, 0.013813963923894335, 0.0612083105079364, 0.02999444754095748, 0.0017357703541165392, 0.02764526998362271, 0.05329343170160428, 0.01712728408165276, 0.1039425095950719, 0.01590937336004572, 0.05503327076439746, 0.02711261204240145, 0.020542922284221277, 0.030791764620516915, 0.07789829891407862, 0.059283379814587533, 0.06949337999685667, 0.07320673073991202, 0.0384505635156529, 0.010228578921669396, 0.02627325044159079, 0.011575189182622125, 0.0214493740350008, 0.07943285992951132, 0.0069420090130734025, 0.0424508433934534, 0.052626355973188765, 0.027805087775050197, 0.017203422867169138, 0.06407058113836683, 0.0276454054255737, 0.028391874257067684, 0.01852919733210001, 0.054556852774112485, 0.018947089556604624, 0.14741620689164847, 0.020722310509881936, 0.009350393720524153, 0.041506501293042675, 0.06068533017241862, 0.025844879091891926, 0.0653225248970557, 0.010965128021780401, 0.04673182949773036, 0.02619218565087067, 0.05057597634731792, 0.07357024209341034, 0.05390364407503512, 0.01663806218857644, 0.0294740777098923, 0.06366113084368408, 0.009501306667516474, 0.026445337789482437, 0.0505674602027284, 0.005506712568603689, 0.039234338255482726, 0.06300662338617258, 0.06162192796182353, 0.1002299677929841, 0.02801954062306322, 0.02410807355772704, 0.04750505460833665, 0.03429239914112259, 0.015067366002767812, 0.03269136024755426, 0.040277289517689496, 0.040345533707295544, 0.034621177983353846, 0.05930092418566346, 0.018923003153759055, 0.058728906442411244, 0.03641085226263385, 0.07778495812090114, 0.07106620614649728, 0.03497197634715121, 0.04420072371431161, 0.08010215839021839, 0.06335774829494767, 0.00998780024019652, 0.00969683846051339, 0.028003109473502263, 0.08334867598023266, 0.03396412495931145, 0.011535233807080658, 0.048591803715680726, 0.04214208398479968, 0.012474422619561665, 0.0853872146399226, 0.05655596854921896, 0.08405522283283062, 0.07683553601964377, 0.02113835664204089, 0.024679456764715724, 0.08016995358048007, 0.047259696875698864, 0.0742635564529337, 0.020916200301144272, 0.015836600214242935, 0.07370909792371094, 0.10964220375171863, 0.05940765615378041, 0.057280712862848304, 0.04567873678752221, 0.04040722102217842, 0.024764171066635754, 0.052132601413177326, 0.027926002185267862, 0.033567795835551806, 0.04031327254779171, 0.12316607884713449, 0.03894815868989099, 0.033660256303846836, 0.03085045922489371, 0.007412341856252169, 0.014880047929182183, 0.04509511185460724, 0.04083111351064872, 0.06644832581514493, 0.008844460517138941, 0.009528910850349348, 0.07410271820845082, 0.050697729384410195, 0.04778494818310719, 0.04001165631052572, 0.040818623165250756, 0.04098386605619453, 0.034545504895504564, 0.23199049523100257, 0.08255439242930152, 0.187836152035743, 0.1461181609192863, 0.12525348050985485, 0.15890177339315414, 0.15320215345127508, 0.09955840578186326, 0.08439855519100092, 0.09448201177292503, 0.14682760956929997, 0.10155079769901931, 0.13948996580438688, 0.2198265166953206, 0.12730893271509558, 0.14142746105790138, 0.11432027225964703, 0.10836173183633946, 0.11076997878262773, 0.07244211083161645, 0.16474820498842746, 0.1710374909453094, 0.11754508945159614, 0.21303029934642836, 0.08968663940322585, 0.06492506770882756, 0.09047764266142622, 0.1527860460919328, 0.22071888990467414, 0.09476954946876504, 0.17137675633421168, 0.246266596368514, 0.15504783019423485, 0.13729890837566927, 0.10229923136648722, 0.13185619027353823, 0.15124098368687555, 0.15840190724702552, 0.11545802175533026, 0.11072137553128414, 0.1663802916300483, 0.16994303092360497, 0.1382556851604022, 0.17349788860883564, 0.14199630240909755, 0.18489868700271472, 0.33821611083112657, 0.07303482707357034, 0.14412129385164008, 0.1480053088744171, 0.07974435415235348, 0.17574606172274798, 0.17959660588530824, 0.15584216569550335, 0.09969516875571571, 0.11848684516735375, 0.08074790850514546, 0.23251428821822628, 0.13352381094591692, 0.21575890918029472, 0.1791598816635087, 0.19380140147404745, 0.15728922007838264, 0.16757701960159466, 0.11258648912189528, 0.10372367993113585, 0.09845550011959858, 0.20915372064337134, 0.08427367400145158, 0.11567099587409757, 0.13819677347783, 0.15326731401728466, 0.24864198843715712, 0.08463454330922104, 0.14801945420913398, 0.11971681393333711, 0.09343423284008168, 0.10541462630499154, 0.22468109760666266, 0.10330782490200363, 0.3161562461173162, 0.25340510706882924, 0.17246189498109743, 0.18300943134818226, 0.17848513583885506, 0.13248196919448674, 0.08239593647886068, 0.14091221761191264, 0.16522215533768758, 0.16700644162483513, 0.1934157666983083, 0.22999103064648807, 0.18377050379058346, 0.2177977966493927, 0.12304051488172263, 0.12249688428710215, 0.19935737131163478, 0.08394629781832919, 0.11903259088285267, 0.14199680706951767, 0.16395238519180566, 0.09654080364271067, 0.15154478925978765, 0.11736971995560452, 0.32798225060105324, 0.3357277490431443, 0.20418222178705037, 0.22058978589484468, 0.1489711695467122, 0.08957186626503244, 0.18950374302221462, 0.15169005724601448, 0.07466214170563035, 0.09437205517315306, 0.1838954072445631, 0.12449688321794383, 0.1202017480682116, 0.1313898098305799, 0.18393454811302945, 0.229914604278747, 0.17776828055502847, 0.20593272551195696, 0.12521392403868958, 0.14266229089116678, 0.13369106134632602, 0.18806146807037294, 0.10765770828584209, 0.10988415131578222, 0.15109740779735148, 0.15114220383111387, 0.17625599139137194, 0.1463567910832353, 0.16122092551086098, 0.16172220173757523, 0.18648430035682395, 0.14089819102082402, 0.14159916434437037, 0.26547432818915695, 0.16576383408391848, 0.13376934308325872, 0.10870876751141623, 0.1711545276339166, 0.17644752486376092, 0.1570466862176545, 0.15108658728422597, 0.16794233437394723, 0.13195413892390206, 0.2249857343849726, 0.24672464991454035, 0.23595688864588737, 0.17736774345394224, 0.16319116431986913, 0.13650424632942304, 0.06812953521148302, 0.1583420456154272, 0.10702678628149442, 0.08967565561761148, 0.0811008590972051, 0.24272634414955974, 0.12986678921151906, 0.07980040114489384, 0.15008381218649447, 0.11951548411161639, 0.1109449178329669, 0.2146059085498564, 0.09811354815610684, 0.1545189312309958, 0.1373460644390434, 0.08478516960167326, 0.16982422792352736, 0.20407508534844965, 0.08605933326180093, 0.1074266702926252, 0.19262757617980242, 0.09554129399475642, 0.12762765545630828], [0.023578517793794163, 0.05447881965665147, 0.023200302639452275, 0.06879872235003859, 0.009597753396519693, 0.033755722470232286, 0.0029889988400100265, 0.027968588474323042, 0.055719126539770514, 0.019499444097164087, 0.010959059109154623, 0.03014212750713341, 0.06629617811995558, 0.022683183415210806, 0.02682368467503693, 0.08668486727401614, 0.03726285634911619, 0.018800248217303306, 0.008139870151353534, 0.05033765046391636, 0.024328758590854704, 0.05691527563612908, 0.027179186399735045, 0.06858072389150038, 0.01653959960094653, 0.035956680148956366, 0.0319273340574, 0.0452336003218079, 0.027860361078637652, 0.024469141390000004, 0.041010635322891176, 0.08071578093222342, 0.05033998080762103, 0.05017400690121576, 0.031254235800588503, 0.07256452809087932, 0.04341389503679238, 0.06794821369112469, 0.06259490954107605, 0.0761612132191658, 0.11649100226350129, 0.013099341576889856, 0.03338727583468426, 0.06630276096984744, 0.038832031132187694, 0.04843797505600378, 0.004922281477774959, 0.003886634108312137, 0.017837589912232943, 0.06620189567911439, 0.027639316103886813, 0.07555057411082089, 0.032032500093919225, 0.05535912554478273, 0.0391554219822865, 0.07620614283951, 0.046494071357301436, 0.027344117588654626, 0.045235132856760174, 0.027616437546384986, 0.01895491364848567, 0.013063208261883119, 0.06740898403222673, 0.04922041393001564, 0.020071196522621904, 0.053170799219515175, 0.021090154150442686, 0.04557843923976179, 0.10020439338404685, 0.027391833973524626, 0.0728144685854204, 0.01372224374790676, 0.030985415069153532, 0.02096735839586472, 0.09574418232659809, 0.05265025312837679, 0.02574233840277884, 0.10909463977441192, 0.04665250133257359, 0.028677307964244392, 0.05313643778208643, 0.008317063475260511, 0.05063480268290732, 0.05542505794437602, 0.016919488298299257, 0.07454274498741142, 0.031197309363051318, 0.020039773989992682, 0.06399272242560983, 0.045508280309149995, 0.029830076673533767, 0.0536457885755226, 0.08198865325539373, 0.12733524927170947, 0.043767947718151845, 0.01689938722847728, 0.06292456411756575, 0.026936752728943247, 0.002902756177718402, 0.005258998980934848, 0.05627087994071189, 0.03291614935733378, 0.045596265626954846, 0.03447617345955223, 0.06621176624321379, 0.06882747315103188, 0.009220206175086787, 0.046191842848202214, 0.032271230447804555, 0.03819153913354967, 0.009262516941817012, 0.05975714462692849, 0.01988270214496879, 0.05817585428303573, 0.03524379906593822, 0.05326307415089104, 0.055053924734238535, 0.0485523696988821, 0.030425859840761404, 0.014208792053977959, 0.030534283905581106, 0.0618392696196679, 0.02839885786670493, 0.038269984142971225, 0.029009292884438764, 0.050786724023055285, 0.04947625449858606, 0.017141492498922162, 0.021359911843319423, 0.02516452077543363, 0.0485561101231724, 0.020000907716166694, 0.04793307343788911, 0.04403180719236843, 0.02254019938845886, 0.04932303068926558, 0.07228953269077465, 0.06418821154511534, 0.04355337798187975, 0.0763112457934767, 0.06723225640598685, 0.10193771639023907, 0.029639263084391132, 0.031056728039402515, 0.022612850079894997, 0.05569569693761878, 0.04243024879542645, 0.027058873129135463, 0.023899363077362068, 0.042558413988444954, 0.05249285473837517, 0.05314275716955308, 0.02557290794356959, 0.07249039495945908, 0.047086746781133115, 0.03736923579708673, 0.043342107092030346, 0.020549269502225798, 0.0367479988199193, 0.03688295095344074, 0.058556598305585794, 0.07668514721444808, 0.09021467747515999, 0.004498132484513917, 0.06147425541712437, 0.030227789902710356, 0.019975734066974837, 0.042678048193920404, 0.06062321241188329, 0.0473996956134215, 0.020063702686456963, 0.05720882472814992, 0.019858239102177322, 0.018613609208841808, 0.09357999064377509, 0.0661419153038878, 0.03688849479658529, 0.02263184720504796, 0.04833824896195438, 0.03130897290247958, 0.04235635315126274, 0.019302311120554805, 0.048077217070385814, 0.016838751907926053, 0.04458624345716089, 0.015954789087118115, 0.03015720794792287, 0.034079324832418934, 0.0060870312336192, 0.019162893113389146, 0.014119157312961761, 0.04089128313353285, 0.02563581980211893, 0.0668582139769569, 0.016485625055793207, 0.05011912508052774, 0.043855357871507294, 0.04319466832384933, 0.044695751057588495, 0.11609437628067099, 0.054765526147093624, 0.06947211004444398, 0.039376878848997876, 0.04276561419828795, 0.03575815193471499, 0.036005439251312055, 0.020176485013507772, 0.06187674807733856, 0.01692324542091228, 0.042499175760895014, 0.030157363798934966, 0.047490278448094614, 0.031013037805678323, 0.04212401639961172, 0.044565982825588435, 0.04261928494088352, 0.050217274110764265, 0.0049919478078663815, 0.027954773395322263, 0.02975268551381305, 0.018387578857073095, 0.010875996085815132, 0.05050424035289325, 0.017369701054121833, 0.01268809621251421, 0.05185729060031008, 0.05121237911225762, 0.03918213929864578, 0.03737156243005302, 0.06832849016063847, 0.06278067652601749, 0.027807787337224, 0.0072702702073002, 0.032392378634540364, 0.01544410057249479, 0.043797900798381306, 0.021741828459198587, 0.0064143540748773376, 0.035089859084109776, 0.02916939825809095, 0.03613595705246553, 0.04600988679158036, 0.07912537330412306, 0.0442617876251461, 0.07626967810210772, 0.02546829666243866, 0.03793540541664697, 0.036907067042193376, 0.04918075726891402, 0.03945015851058997, 0.0035978723326479667, 0.03782205720199272, 0.07851946167647839, 0.028741900787281338, 0.06860554130980745, 0.055462161617469974, 0.03166133348713629, 0.026911458480753936, 0.03802814047958236, 0.06212325613887515, 0.12124802044127136, 0.020493231786531396, 0.0634349390747957, 0.06474583162344061, 0.02041206680587493, 0.013343415394047042, 0.05230016351561062, 0.06604858281207271, 0.029027646196482237, 0.05810971408209298, 0.04870680320891552, 0.01467016485548811, 0.020575914459186606, 0.05349407874746248, 0.01603112083103042, 0.042614130725269206, 0.030566815948986914, 0.053911329014226794, 0.04726531864434946, 0.014691021060571074, 0.04309368428948801, 0.00999908552330453, 0.03337028807436582, 0.06964830332435668, 0.06753605455742218, 0.025684393367555458, 0.041274921532021835, 0.0563969634094974, 0.026442098314873874, 0.049321190163027495, 0.0564082292112289, 0.04309275289415382, 0.0452149649936473, 0.029010005346208345, 0.015778545712237246, 0.018685113282117527, 0.03784344960877206, 0.03365568467415869, 0.025467599043622613, 0.06915115343872458, 0.03144450020045042, 0.047518175779259764, 0.02734332905674819, 0.05583803715126123, 0.0754944232176058, 0.03175880716298707, 0.021164031240914483, 0.0503882129851263, 0.060340847485349514, 0.02627007219416555, 0.0329557169607142, 0.06077554193325341, 0.024276591175294016, 0.005685215319317649, 0.020369053781905677, 0.015027798399387393, 0.04198845570499543, 0.05835487514559645, 0.021803460113005713, 0.013563950142270187, 0.04193355533061549, 0.05372838961193338, 0.02704139184061205, 0.044461840952862985, 0.05065251032647211, 0.05294872637023218, 0.025044534049811773, 0.02739141466008732, 0.029532677690440323, 0.013048592591076158, 0.024861199453880545, 0.0794858047447633, 0.012525756974355318, 0.049618435150478035, 0.05427401287306566, 0.04604774003382772, 0.0775336817605421, 0.02016636211919831, 0.11503026267746463, 0.00678114804031793, 0.014836824320809683, 0.03781374514801428, 0.009802782824408496, 0.02383892071520677, 0.07274128540302627, 0.027524696961336304, 0.05271083093248308, 0.08558194676879793, 0.03967773067415692, 0.04370353672129568, 0.17427473911084235, 0.03436660648731049, 0.1551104971440509, 0.16030827682698146, 0.1407056927564554, 0.11216153536224738, 0.09325837352662347, 0.11311213747831061, 0.1188099614228122, 0.09907416926580481, 0.16050662321504205, 0.09760266111698002, 0.04919281716865953, 0.12531378743005916, 0.10616950181429274, 0.0878899147210177, 0.12544207507744431, 0.16849576873937622, 0.13579427817603573, 0.15093343768967316, 0.09631003282265738, 0.15444293530890718, 0.08536952183931135, 0.17699187534162775, 0.22040678712073714, 0.3603837650734931, 0.13816542515996844, 0.11184048227733001, 0.09287062363000587, 0.11866732806083746, 0.11457465821877122, 0.08739675758988596, 0.22493875643704087, 0.15691654320107773, 0.0956434580439236, 0.1939183342619799, 0.12346343515673652, 0.13825877249473706, 0.12085449663572945, 0.16988949239021167, 0.13078409858280793, 0.16174384276382625, 0.2339309293893166, 0.10873800070839934, 0.14422016276512295, 0.1635580524452962, 0.19349246023921296, 0.14464661566307768, 0.1403249561553821, 0.09657150629209355, 0.20626329293008894, 0.1894894047291018, 0.20408701908309013, 0.23913921788334846, 0.14484833140159026, 0.15885268774582073, 0.13911057991208509, 0.23566286457935348, 0.11961298747337423, 0.13227857620222494, 0.17518121312605217, 0.15823286084923893, 0.15277589351171628, 0.10794057045131922, 0.2309937760583125, 0.20038885268149897, 0.14031881117261946, 0.1952471793629229, 0.1109867898048833, 0.12039437991916202, 0.17229065182618797, 0.0783229929220397, 0.2044348043273203, 0.1625732670072466, 0.13076612376607955, 0.14450220856815577, 0.13917762553319335, 0.11931048065889627, 0.16701604501577094, 0.26547901856247336, 0.20680902380263433, 0.23015305632725358, 0.17832126963185146, 0.1597004133509472, 0.10159704092075117, 0.1967109617544338, 0.1804548699874431, 0.14742398459929973, 0.25944307213649154, 0.16345293464837596, 0.10872145823668689, 0.22492711956147105, 0.2493399486411363, 0.12763443868607283, 0.15274392178980634, 0.2172523774788715, 0.14549956598784775, 0.211006106401328, 0.08294099941849709, 0.1530778585583903, 0.12094039280782454, 0.07244311273097992, 0.15052641421789303, 0.10458465287229046, 0.14433633856242523, 0.09698201043647714, 0.1612378761637956, 0.12738728866679594, 0.08749774904572405, 0.14195417810697109, 0.31867263140156865, 0.2851340576307848, 0.14234649221180007, 0.18485393549781293, 0.13448311103275046, 0.16907198703847826, 0.18366164556937292, 0.15675907430704683, 0.19870306423399597, 0.1802018570015207, 0.18756145349470899, 0.15675528935389593, 0.14174756419379264, 0.21144634840311483, 0.08897307183360681, 0.2801037806784734, 0.1356308869435452, 0.12654943362576887, 0.18237633485114202, 0.1332993558025919, 0.16821703291498125, 0.11211253877263516, 0.2084362567984499, 0.15565070643788204, 0.13672843429958448, 0.10578161090961657, 0.17441265983507037, 0.12540098978206515, 0.20513978524832055, 0.1201881148153916, 0.21655441727489233, 0.1170717402419541, 0.1558500769897364, 0.17207355878781527, 0.13478344335453585, 0.1892447186401114, 0.12521585362264886, 0.22314740490401164, 0.07398700254270807, 0.15835130761843175, 0.23498973663663492, 0.13506731484085321, 0.14635757775977254, 0.12853349122451618, 0.09824015854974277, 0.22186170826898888, 0.16328702011378482, 0.19973804854089394, 0.24804090819088742, 0.13460059300996363, 0.1301564642926678, 0.18657298700418323, 0.13818144070683047, 0.13160273199900985, 0.1821554865455255, 0.09833074509515427, 0.1911654116702266, 0.11274665201199241, 0.05564831451920327, 0.15470135112991557, 0.1556381641421467, 0.13532950077205896, 0.15994196757674217, 0.24054294568486512, 0.09784703550394624, 0.14047052100067958, 0.2404134112293832, 0.1718180818716064], [0.0762680008483585, 0.06003740185406059, 0.08248136509791948, 0.04707269792561419, 0.06181246324558742, 0.0292875054947217, 0.023530036996817216, 0.049527054507052526, 0.06406743443221785, 0.024556781609135214, 0.017282658263866324, 0.026463800568308216, 0.05704899951524567, 0.04112757924303878, 0.06326662740320899, 0.057756429523578845, 0.0203862233684049, 0.028165114745206665, 0.054010743406252004, 0.035006990874535404, 0.027166102336195763, 0.03146307615679689, 0.04085545595444273, 0.05610569642158225, 0.029459809920808766, 0.04653708623663988, 0.0409538387611974, 0.04990646266378462, 0.06535819251439534, 0.018376632178842556, 0.01554685462906491, 0.042509747654548846, 0.13938444724772125, 0.037996962855686434, 0.06156272313091904, 0.042954557575285435, 0.04388701046991628, 0.049759966423152946, 0.06280688918195665, 0.024077120433503296, 0.08117525198031217, 0.016977646700979676, 0.0545674061140744, 0.02597553604573477, 0.026216177429887466, 0.021817885608470533, 0.029878973073209636, 0.059014447761001065, 0.021863800429855473, 0.04903360422758851, 0.04060544495587237, 0.04600046151608694, 0.02874972858990077, 0.036236629384802654, 0.05399250512709841, 0.012197974465379957, 0.052778351528104395, 0.027785454258264508, 0.05140741552168038, 0.056178582744905725, 0.18253277958137915, 0.03777072655793745, 0.03339341710670851, 0.051256666774861515, 0.09594943810952827, 0.027758204450947233, 0.039691015117568895, 0.06437537376768887, 0.03152416233206168, 0.0904633934260346, 0.02792903014778858, 0.027829767896037083, 0.02653195013408549, 0.029529729508794844, 0.011248432692809729, 0.004026778260595165, 0.029614859413413797, 0.026935954920190852, 0.11929826490813866, 0.055089933739509434, 0.043676945570041426, 0.04129618035221938, 0.030392348162422422, 0.06815518383518793, 0.06394079435267486, 0.08212554239435121, 0.04830553138162941, 0.06108166300691664, 0.052370021876413375, 0.017525442599435337, 0.04084576721652411, 0.08731874302611686, 0.09708238590974361, 0.07086323617841117, 0.11948631770792417, 0.08066474343650043, 0.09266789857065305, 0.021964478328300174, 0.019211975049984176, 0.01062146819094778, 0.029635873324878048, 0.05409438344941009, 0.02805379444907885, 0.04228088786476292, 0.03462047294306103, 0.04570431119645946, 0.05542243074160069, 0.047667395701864734, 0.02725144375290256, 0.047847232926869765, 0.025147518172161654, 0.09217765807989053, 0.03883154502545949, 0.04290516393666621, 0.015669809945393354, 0.07738901491393335, 0.0407840650586877, 0.04781912408361677, 0.06687641885946505, 0.005248759662208613, 0.020568222098518163, 0.03314489411422983, 0.10193926747888327, 0.054475684082717635, 0.04846277763135731, 0.05577141455432866, 0.04457466224266682, 0.03209425791283138, 0.09323101796326227, 0.04369670896267053, 0.03925859164155554, 0.045555774049717, 0.06831313512520865, 0.019078978475590702, 0.016919499430514406, 0.06369180380715989, 0.046059517917456105, 0.0036191905246596434, 0.021304128313204274, 0.06179299671202898, 0.06252021237742156, 0.03187936163158156, 0.06514679917017929, 0.08964058913988993, 0.04613071956555359, 0.07777976308716461, 0.021764482517028227, 0.05049544961366337, 0.04767846112372354, 0.039186484573292546, 0.06146291168988682, 0.026859612044063397, 0.012143113981437637, 0.015179491529124789, 0.06744116355548613, 0.02699386099266121, 0.03855835304420907, 0.026683615433285013, 0.01286416889342945, 0.025231818726751953, 0.004490460069064284, 0.05171683544176631, 0.02676873977179639, 0.05810808877868112, 0.08061907166847959, 0.03594994886952918, 0.014601278708141763, 0.04074255302839447, 0.0380999061599141, 0.0555938631441677, 0.02055371496680891, 0.04248185403412208, 0.09896053161355667, 0.026859517420234624, 0.06332400284009054, 0.05942930460150819, 0.050554799163364805, 0.028906388542964123, 0.0602249240182573, 0.0111762226515566, 0.027918283849430736, 0.05404692310548853, 0.03444450601818971, 0.017399112366547342, 0.03841654346615542, 0.026201865111943334, 0.0451765440084273, 0.0127982049525599, 0.003131096696051827, 0.022364922660926823, 0.03938720212318003, 0.024892078363336623, 0.07379391056019813, 0.05105384152557235, 0.04495936562307179, 0.06110131878813263, 0.02825908548402367, 0.053967754502082244, 0.022695701591146644, 0.06297145300777629, 0.006127800188551191, 0.03345307464769576, 0.04261249057890382, 0.05479898587509524, 0.11370223393896595, 0.04096601369383279, 0.0369302999752108, 0.07465877977665514, 0.03286634382675402, 0.01824919985665474, 0.04604889778420329, 0.0056645645963726565, 0.08905778056941926, 0.0347164437698666, 0.11179424647707492, 0.025555606625857763, 0.0504353987344075, 0.050076214101864025, 0.04828559729503468, 0.031023038245621137, 0.02667531636689091, 0.040002869282034226, 0.012183226135675795, 0.10843331197975203, 0.00362459591087827, 0.014120148080110084, 0.04277731786714867, 0.013629301811306505, 0.00320494363677426, 0.05856352254340891, 0.019523096343618818, 0.06406733795301989, 0.029439797908707988, 0.040262943803099915, 0.006481363052444067, 0.05335681482392829, 0.04161340024438687, 0.08603913942351937, 0.05645102515700273, 0.006642360394835123, 0.015557441365672275, 0.06651225441601127, 0.077136699546827, 0.07577408672659658, 0.04988627624697983, 0.06919658029801212, 0.013144617223588284, 0.0451950457500061, 0.04658329977246467, 0.01337967023573583, 0.03372217368450947, 0.043762118148151785, 0.039307083570747636, 0.04331177922722418, 0.009673599033703795, 0.08144148261635564, 0.05987106058455538, 0.015924735816952307, 0.07317966461414471, 0.0703442597296089, 0.04870545250014402, 0.04269798599125352, 0.05649719045322854, 0.08893791629816405, 0.07578507793368772, 0.031165137261268683, 0.005870242011951632, 0.025512589891150128, 0.04794929307536222, 0.06406914137187414, 0.12691514915786684, 0.04062258485646453, 0.09834762153332122, 0.03274325863458216, 0.022328078739519697, 0.07298719603568316, 0.026732908881967887, 0.08831025232211687, 0.04059349637827836, 0.045818998987670057, 0.06507533777039498, 0.025530457096465398, 0.07364819728536531, 0.03130067198071629, 0.03755047939193901, 0.10248802631394938, 0.009138369550782954, 0.06783224569517188, 0.006698596635033027, 0.06884727365104482, 0.04400500452902634, 0.0316200997622218, 0.020662207680288702, 0.023514004751632456, 0.062215724028646946, 0.02636864981468534, 0.05002852740290109, 0.0161611506700865, 0.08041429086006247, 0.04106295673409477, 0.025212140681105666, 0.010250768209516536, 0.02866339826141484, 0.052680362059618346, 0.04140424818615429, 0.026751356817840133, 0.04833872393646743, 0.08449058892438188, 0.0562005206302274, 0.03347887541167438, 0.033447267342126, 0.04363600499345921, 0.019641556100395974, 0.03356405170052312, 0.052588383987313136, 0.07569291061372496, 0.038340113387675956, 0.02690109067771118, 0.007042912338874885, 0.07531373252277263, 0.07021565295872279, 0.03505533437419217, 0.03703803013195284, 0.027531181476661004, 0.040417729833279736, 0.03775831042730715, 0.03944706004403997, 0.03126681891444605, 0.04286367788154166, 0.023425525905622635, 0.09569963862304576, 0.037275736322044395, 0.0642404067912139, 0.016887735509953927, 0.08464631377137266, 0.02063449031993514, 0.06752265137038194, 0.046419340797001496, 0.022372874773282092, 0.02320495776075404, 0.0795823210501112, 0.01794342759239953, 0.015367289215646451, 0.05642271964461543, 0.03969527875597123, 0.03854865688481368, 0.05894578054721933, 0.06659618389676325, 0.022605558478971943, 0.009272540573874721, 0.03848561886115931, 0.04184272016573232, 0.17949384811799973, 0.14752662362297997, 0.18483015708625317, 0.17854765435913578, 0.10070627817185596, 0.12124607601435855, 0.12406231122440659, 0.14423389249714091, 0.1369201607303694, 0.16040171321947128, 0.14093422971200198, 0.1439605001360178, 0.17439777235267684, 0.15334963303757831, 0.17461753712268546, 0.17782596027245745, 0.12105720685212873, 0.10960309256915934, 0.1661299800616689, 0.1272475571022369, 0.09252007759641856, 0.12155132877524011, 0.15647989319404587, 0.1857373138773255, 0.1340376294683665, 0.09126187753281556, 0.1519391220062971, 0.10148748508072458, 0.18704043613979593, 0.15781026711920276, 0.08269709258456714, 0.11685294026392512, 0.16787672851933166, 0.14294705295469612, 0.183432737539988, 0.1292880327673629, 0.275333997560665, 0.14721272484166548, 0.20476964651606977, 0.13790116121526808, 0.12924231647048146, 0.15704800724051893, 0.270351218059659, 0.16532443813048303, 0.09537959485896863, 0.08076729340245947, 0.13030115340370685, 0.17404715210432187, 0.11773309030104429, 0.11912904781638645, 0.0866631223470904, 0.17259025684325024, 0.08162733123754151, 0.17024299217155203, 0.09463768466957845, 0.08473906738799997, 0.11003375344444066, 0.17548157513374463, 0.0938670607865788, 0.14083037356613204, 0.17357198463287205, 0.2472169609973207, 0.2236710791476071, 0.09549572612741031, 0.1464101515011862, 0.1472135857329704, 0.20092331775231287, 0.21082756051328033, 0.12140577877289616, 0.18949406541651115, 0.11753855113056488, 0.19907585985492915, 0.12258354487130418, 0.0926621543476358, 0.11664037432637997, 0.12655957136303186, 0.09423741474165581, 0.2172017184784636, 0.3303345321910456, 0.18876842310419306, 0.1704749875352718, 0.12723265477688983, 0.12478001997806132, 0.16451845091069117, 0.1629148775828071, 0.17897222220199183, 0.15145360899623483, 0.2302293639513664, 0.10785773934912868, 0.19890032708644867, 0.16816462244605646, 0.13557917409343645, 0.31538402661681175, 0.1971630335901864, 0.27869883575476706, 0.16287866077618673, 0.17985165235586464, 0.1559793739579618, 0.09464804505114444, 0.11708108388120309, 0.10083834335091524, 0.24886633967980742, 0.25063009816221893, 0.10525199206313118, 0.14465423009824008, 0.14864351134747267, 0.25467275467235595, 0.14325433177873492, 0.09168487202259712, 0.11814649624284357, 0.14819906878983602, 0.28421904891729355, 0.15564669884042814, 0.2157242805697024, 0.11441200171248056, 0.1493428074172698, 0.12546490353997797, 0.11739567285985686, 0.11382904471247457, 0.1258922618580982, 0.10402617190266028, 0.11500029475428164, 0.2665432880166918, 0.1386664787423797, 0.19095179188298061, 0.17697939241770655, 0.1440093037672341, 0.18716749182203785, 0.17052736831828952, 0.18267648905748501, 0.0977682342636399, 0.22923102689674124, 0.13918884680606425, 0.132152856385801, 0.07477088118321262, 0.1475313733681105, 0.12886981770861894, 0.2527802484109998, 0.1441256725229323, 0.18359989888267592, 0.15772521699545905, 0.12877976550953463, 0.1318105185055174, 0.18511309346649796, 0.21659679390722886, 0.2078641499974765, 0.10272105326293968, 0.12295452965190634, 0.15332226263126358, 0.21244098956231028, 0.13662986224517226, 0.11527035487233661, 0.1623074445524253, 0.1445830729790032, 0.15390885615488514, 0.07704957883106545, 0.13016775978030637, 0.1404269866179675, 0.1076573520549573, 0.21427792380563915, 0.1406642809160985, 0.22618957213126123, 0.11412765525165014, 0.17470963764935732, 0.24468567338772118, 0.14394944213563576, 0.1389020957867615, 0.15430295141413808, 0.10041999470558949, 0.1428596131154336, 0.15398115618154407, 0.15156444133026525, 0.32046378997620195, 0.0944137638725806, 0.1572716757073067, 0.21530311176320538], [0.040427644926239736, 0.05860047407622915, 0.05964334370219149, 0.051912988783442415, 0.006811346029280685, 0.11585503365495242, 0.020733875026053283, 0.04223503055982292, 0.00954673538217321, 0.03822161837888416, 0.08246732366387732, 0.03260593904997222, 0.05792965050204657, 0.025560163412592374, 0.01574173704284476, 0.045132471568649635, 0.030547069254680537, 0.03199296217644587, 0.03702023343066685, 0.051846199203282595, 0.03161862288834527, 0.01618045207578689, 0.05232577874267008, 0.010026948530139634, 0.010274772048433078, 0.036131878950982355, 0.04741610449855216, 0.00817065443698084, 0.035082856920780614, 0.048496931267436594, 0.04486206635192502, 0.038689308712491766, 0.036583702167263255, 0.05286085979605559, 0.034675180359045044, 0.03782107014558278, 0.08755076807574369, 0.051901559709222056, 0.037616541667375714, 0.029703957952733617, 0.019771116531046573, 0.08324653419549577, 0.0442512083100155, 0.07185557667980902, 0.043602916339295916, 0.06625990936299786, 0.009059808580786921, 0.0686766835860908, 0.028276696648390498, 0.03537985328875948, 0.05606689323030878, 0.026559981051832438, 0.12470565678086132, 0.06367719091940671, 0.031566594625473954, 0.01799960075004492, 0.026702772120188456, 0.013329152243386488, 0.03982082416769117, 0.04650231661798898, 0.024585578794358298, 0.03849833556159865, 0.03929570644686464, 0.08775378999416716, 0.0488419668545248, 0.021560117311310023, 0.04841810034122318, 0.03194578384864144, 0.0630910723702982, 0.05639630289806519, 0.031240398457157426, 0.0576079999882495, 0.04184416735370178, 0.057744621954043396, 0.1057408150518313, 0.023666115339437965, 0.02514914347557351, 0.00961614567131619, 0.06032075754774269, 0.010669503699318739, 0.027216585076530464, 0.084987070877105, 0.03520592726999894, 0.04110743735509459, 0.03835481533315033, 0.024056830116023775, 0.029445417821989395, 0.034100568809662946, 0.060486946676974185, 0.024473790945194196, 0.03717152765602805, 0.006742590685462346, 0.024020535383897368, 0.029440037251333706, 0.052260369557188824, 0.03036890000657877, 0.029120744911779184, 0.07905365215265192, 0.04913077733363025, 0.02665843621798558, 0.006034524749338743, 0.043211949232500046, 0.06530703627504408, 0.022442022527684458, 0.0647819296864327, 0.05310161992383655, 0.028291116577747744, 0.09198339350405149, 0.0367015440860996, 0.01649449928663671, 0.03693907958222553, 0.04562310168694239, 0.046745700237806886, 0.045269434922374785, 0.028568087946041487, 0.0015845125403757265, 0.025698791032482404, 0.06894370089867152, 0.08530591978342272, 0.027031541685573757, 0.05752448611019645, 0.07854067967855372, 0.025498526192677673, 0.04075640892551746, 0.05858384996827226, 0.05762350345321465, 0.036163219847367145, 0.05065772020316217, 0.023536645821877755, 0.08531312603736296, 0.014054081166250398, 0.0065577337591093965, 0.04469880870601628, 0.055710324668325484, 0.05038778625021223, 0.049922645193873905, 0.041115890417131595, 0.019357614110049326, 0.02998227260832209, 0.02317208804015536, 0.01684610473603243, 0.020002013516204897, 0.03968475510191638, 0.04153768633841537, 0.020479106860875618, 0.008237199108407367, 0.05120622299727984, 0.03389498648175504, 0.0045237458562041866, 0.011554289376363158, 0.04156461145612411, 0.09389544051373377, 0.04055861172673758, 0.09691264189314097, 0.09668659113231115, 0.053006053567514755, 0.0315320587833412, 0.06683424260700122, 0.005890890415685135, 0.0334088018280454, 0.038535992134711705, 0.017085953877540305, 0.029949067065899726, 0.02800660498905927, 0.005009592368878657, 0.023570990560983773, 0.04284774397092406, 0.037260841418174095, 0.02141366188880056, 0.011480544017103966, 0.02464258130203234, 0.01811162608646555, 0.03198646467353683, 0.0450952083338052, 0.038190834093256854, 0.017940818943316117, 0.030811643046035897, 0.01991802651900798, 0.03527206376020331, 0.03594409332436044, 0.02964923198305769, 0.04533634324616287, 0.029849263046344277, 0.11110768566140905, 0.04226883167575579, 0.02846057301212568, 0.030322948077809997, 0.055647449917159975, 0.02017405076912837, 0.039211728726513684, 0.09032294939970598, 0.015862554973864462, 0.09067325794603676, 0.003849906843242934, 0.040113208087859675, 0.05225245826295577, 0.025663552005426027, 0.033767622808227316, 0.013077889798296383, 0.023170800413936377, 0.02519569097785279, 0.027056188409915194, 0.028566857836267445, 0.07422160284477286, 0.030264303568401374, 0.01476048515542061, 0.04727016857941635, 0.023039928237267304, 0.02768903814285295, 0.010328170501452405, 0.012142040650360286, 0.011627510593825718, 0.02740294763498241, 0.04829222467378713, 0.02858530577213969, 0.019128323874610942, 0.041038094786927104, 0.05505482644366566, 0.024240418897534255, 0.12307562588830478, 0.016686908493284136, 0.024776266218395904, 0.10124256150447764, 0.10214234876912087, 0.03415773644519504, 0.03239388519432396, 0.08745501618250273, 0.014821181703155162, 0.02026890837441897, 0.042644540226319805, 0.03803035579039715, 0.05312782886903733, 0.015593812167935539, 0.020256792813597713, 0.04019954954856075, 0.0586350767116528, 0.006831471218902152, 0.08486357750371099, 0.09651154818129726, 0.013478662531269947, 0.09056240334757604, 0.031487092055613175, 0.036446141384658404, 0.08983629348222166, 0.016869805222086143, 0.04363569329143502, 0.02566080234828405, 0.03746256457816344, 0.027256959765509237, 0.013949280637461925, 0.015910481015453115, 0.004877744731857092, 0.05134470033226535, 0.033015066510415636, 0.08099377460894175, 0.04732388522825204, 0.018941824018838815, 0.04647781832318287, 0.060418939974624664, 0.03194884520780761, 0.034251966935698874, 0.05970328325929586, 0.07626005986821838, 0.002883516463043634, 0.021009375086578075, 0.015464605185115943, 0.04561503454169724, 0.07524313943576999, 0.06552052247570828, 0.06328565606963821, 0.03684248535137158, 0.06879867782117799, 0.019046726592932828, 0.020557600109896157, 0.028742227332259063, 0.07325741200475022, 0.03894248868164141, 0.016010548497433774, 0.07432675774907693, 0.10366826376412064, 0.1086935683269985, 0.08958955164416693, 0.01976384904992301, 0.09573710223776288, 0.017609336828172673, 0.04242527640599292, 0.05838203403982334, 0.027916495273530018, 0.013932344827480847, 0.02189346221712185, 0.05361078889109194, 0.030535705118381884, 0.04181670788966585, 0.03269184264354408, 0.07604035447002389, 0.1377846737159416, 0.039221220795297995, 0.049586096065468155, 0.0621145470358897, 0.0331280584941851, 0.050966891503776424, 0.12223227895447053, 0.024201643536798656, 0.01902540840092115, 0.061848257028032094, 0.030782823596382514, 0.05575828967266716, 0.037553414586000144, 0.09129822792601772, 0.04688483808422461, 0.033738716156221926, 0.02921127208537655, 0.07614193222252652, 0.00941119973504101, 0.012994282224099152, 0.058715562627185136, 0.052534492933773436, 0.02619281647639582, 0.014032379840500653, 0.08585556177422404, 0.0021894005840294994, 0.043794479497591965, 0.005938916183367837, 0.04327097223722376, 0.03396200241695624, 0.023668592257308774, 0.016349476209143177, 0.07630590975168161, 0.036695176459033974, 0.06495099092717282, 0.04048692026117351, 0.08699428348336369, 0.09966381301637739, 0.055858179039205424, 0.03168245129927527, 0.03178152059263084, 0.01544072751130443, 0.04615049409039784, 0.01763172371283872, 0.056687866745051, 0.0271768727543531, 0.030858613572490867, 0.09587441440089606, 0.022674288775306195, 0.030820190731901675, 0.04378544013889041, 0.06023358859238215, 0.01869750900368672, 0.020841746190853883, 0.054357437693397515, 0.08593334627221338, 0.01902032283396693, 0.08917330327676609, 0.14317765308078378, 0.14938405598513782, 0.13402223732555285, 0.1259568880777806, 0.24008009786484763, 0.10050218756077811, 0.15539435378741473, 0.08062355424044654, 0.12830893218051642, 0.1510486932238564, 0.10278567948262207, 0.1596339762909338, 0.15920032456051558, 0.22103185357991606, 0.0878788938280195, 0.09183958012727089, 0.11728841025615111, 0.16643242008285597, 0.1099926904134918, 0.12559046008391306, 0.06209072038473096, 0.13452403305564076, 0.07215927835204639, 0.09557759985909797, 0.15760809124913067, 0.12267356738448143, 0.16349192708730698, 0.08696427845279686, 0.1516484672902152, 0.17420266172848642, 0.06745016580680385, 0.21927533845882863, 0.10892435399000533, 0.10605319243040867, 0.12952917139045894, 0.17163581040222198, 0.12975987541722134, 0.2132356961374171, 0.07327765037189238, 0.28831885079853237, 0.18745326320640743, 0.10787543214973994, 0.30455635918769985, 0.07611065069795586, 0.1711688659270294, 0.20340127462986857, 0.12920891982503235, 0.14611348538892344, 0.09874455921817571, 0.287455614306964, 0.08860606496455148, 0.1574294563033618, 0.15490456600673497, 0.19769346137763932, 0.1429441585787572, 0.07399214562610723, 0.09758561398484744, 0.18931565311504528, 0.1712830676115118, 0.0935076609312091, 0.2081334902322851, 0.17623363790335134, 0.1767142378957942, 0.21228000288829207, 0.1040116480726283, 0.13469763624016196, 0.2015906569431536, 0.2571271260967478, 0.19810940546449274, 0.10238960268907249, 0.22156118298880756, 0.1441171081387438, 0.09850641887169331, 0.2519988262793049, 0.10129557311302051, 0.29062707850243896, 0.3072594985133037, 0.33258181472774595, 0.1727492397185415, 0.22442766901804134, 0.1815699171856977, 0.20258909789845347, 0.13059157063253224, 0.1456905057420954, 0.20699669810710475, 0.11281866260105744, 0.20024839381221682, 0.16546311584534124, 0.1183212423347868, 0.16381404886487871, 0.17713243811158463, 0.23354646720690653, 0.14072571590077132, 0.20389106241054833, 0.1005829925998114, 0.22569672670215368, 0.1721296354662627, 0.16273664339678362, 0.20271400135243312, 0.08587696531321853, 0.11172101134434342, 0.26228644768707454, 0.12312621809542179, 0.17660515703028068, 0.2122419307124801, 0.1576418589684181, 0.23960951686603948, 0.16340999398380518, 0.12360557870124467, 0.18172002397477627, 0.21677752170944586, 0.17780287947971374, 0.10543299445998855, 0.15734722634078935, 0.10937204715446569, 0.1713030759128742, 0.16257945651886985, 0.11287920700851828, 0.23220549541292712, 0.10456983218318783, 0.1750224083662033, 0.1033946784446016, 0.14972802659031004, 0.2831359289120883, 0.1742470421595499, 0.1450504775857553, 0.1328122991253622, 0.12002983698039316, 0.12323904680670239, 0.14905866875778884, 0.12625101604498923, 0.13804959075059742, 0.17549303389387205, 0.2125986068858765, 0.1558168584597297, 0.09571929811500013, 0.09617332922061905, 0.1616553490748629, 0.24194760859245434, 0.08797707254416309, 0.11980693292571232, 0.12710988870821893, 0.20726778981043026, 0.12088400442735292, 0.09903165904688649, 0.1282861185609363, 0.09314258364611305, 0.1425272348569706, 0.07131471429602243, 0.20091749931452796, 0.13945201237220317, 0.18287272774614394, 0.17513883649371564, 0.19948950328398496, 0.10800446194480173, 0.17685621074633673, 0.14339441957417876, 0.13311104325111955, 0.2568200253881514, 0.19126597268041223, 0.12020824186038226, 0.07733759892289527, 0.10276630200678483, 0.1171760936267674, 0.06023411922797095, 0.2060442851507105, 0.11334521637763828, 0.08422815808444284, 0.21780411974759772, 0.1227165748423431, 0.1808930339757353, 0.15157941787037998, 0.14061936613870785, 0.21154496498638764, 0.06815595566877164], [0.020627165322366636, 0.047005589221953414, 0.07408082485198975, 0.006880888513478567, 0.030148574915074278, 0.026825241329788696, 0.02047678022790933, 0.0554550073138671, 0.06323918278212659, 0.0402667324669892, 0.03229228517739102, 0.07301925681531429, 0.007220810703074676, 0.06169436157506425, 0.015458221787412185, 0.04558717802865431, 0.050475007155910134, 0.005749122583438293, 0.09536597644910216, 0.025409373847651295, 0.0491108469577739, 0.03764390836295206, 0.06288079224759713, 0.06576223255251534, 0.06082590036385227, 0.015265800520865014, 0.035620472408481874, 0.03649751284683589, 0.051195250343880616, 0.07182653644122183, 0.03445717076829169, 0.09680035494966432, 0.035751123796217144, 0.03797154800849967, 0.06468330568168312, 0.021584825262834784, 0.025222604963346384, 0.054791909496998414, 0.005993288241370465, 0.03726762835867703, 0.017656170057307463, 0.023887421921244822, 0.017445515150029678, 0.036766155462828465, 0.004325301597418729, 0.029805151643813588, 0.06374153512297198, 0.06799759619752876, 0.06660459985141642, 0.04601147498760838, 0.0036933324690835434, 0.016589477490924764, 0.008353529829037143, 0.03888671628374141, 0.04087267749127932, 0.04051880292536225, 0.03914492059266195, 0.07025622617220506, 0.05234017640759703, 0.09741225570905954, 0.0651153246872127, 0.05087544035632163, 0.07089496299158782, 0.07368235834292136, 0.03767118229006883, 0.04781893854669761, 0.08906394039513543, 0.02335011442482937, 0.08679123930050991, 0.0717226580309216, 0.08116264289128594, 0.04105554638954345, 0.06126640582806431, 0.023042202919896226, 0.01413608848451986, 0.01186644411063753, 0.06305366070591845, 0.07949825056130067, 0.08862661503371783, 0.07772389421006665, 0.0926253735087812, 0.06626820657402277, 0.012700064271484734, 0.06100064274505712, 0.060172695375513285, 0.1197789836442098, 0.0561529155675089, 0.03057959387660958, 0.08394358897930942, 0.16219805198488757, 0.041883846279233694, 0.04073909090948291, 0.05069247126812115, 0.07687195320613682, 0.19688134401803836, 0.026591132700559683, 0.023658217032789253, 0.017305095243500546, 0.024934440152719617, 0.031051460646267515, 0.044685182874673046, 0.015005538607510971, 0.053379888195195235, 0.0516570146282902, 0.048946691313176416, 0.08397686688113026, 0.0461663055466488, 0.037014010522398166, 0.005688655173798907, 0.05839511439262424, 0.10442112805321813, 0.07884122722316533, 0.02626934860018082, 0.01469527356675826, 0.057105399027932435, 0.02050336952379439, 0.0029290653128555277, 0.012817232691304525, 0.036887478054268286, 0.024468020747008268, 0.008161284822563175, 0.015042986451589968, 0.024295332259498537, 0.05253821480437182, 0.05588711537711788, 0.03264784441853408, 0.05867184641829226, 0.0343321003310848, 0.038647570327157155, 0.04796852583240252, 0.019450703548500314, 0.060333563305903226, 0.033634043647907674, 0.016216572403209284, 0.019648086999950465, 0.042873618949670345, 0.02142350462236209, 0.1106023573083803, 0.07927342434413731, 0.03956846798246261, 0.049375526505173184, 0.037899017916060984, 0.04702313359302934, 0.019796093511104118, 0.03415827450226061, 0.023192771695903502, 0.0510903922986472, 0.08133531096973456, 0.041729579752427526, 0.015505465980822919, 0.06369574461132288, 0.040168360792449676, 0.02343439271498937, 0.025469897846051026, 0.025740163910086267, 0.06280058092670515, 0.03685438568936661, 0.043925921272602864, 0.04301372900954448, 0.05468766001285985, 0.0471207890950609, 0.07104994569090195, 0.04460474148800131, 0.0343630849965848, 0.04557626474706922, 0.03529076217091642, 0.015915933945507277, 0.03592793676943984, 0.07139981637010351, 0.00237070958064578, 0.0801315697026439, 0.04295016777177807, 0.03462602791842073, 0.013763179686065996, 0.02427673218335258, 0.005296224644553149, 0.022323440316540655, 0.047488215277553536, 0.06311070217634551, 0.015220910790958442, 0.014105152058618842, 0.054334431115421467, 0.04671644106565509, 0.062369393126573414, 0.0313057594030397, 0.005725621085730381, 0.01375677402393194, 0.014569165050488664, 0.06724657243466936, 0.07523344698711298, 0.014383392499439651, 0.05489543538715225, 0.03488616552203894, 0.12572551611810923, 0.0949355456396006, 0.019246278970967978, 0.05354395107133314, 0.01808718530810438, 0.029304107338248286, 0.12462295184377581, 0.03905710967956111, 0.014165376414894126, 0.04579562504659407, 0.10395013145171106, 0.024249979614978656, 0.07993830702616833, 0.06644356122706085, 0.028157060587545857, 0.06363364169374108, 0.0099681073515967, 0.029248221762827598, 0.011976753230555914, 0.02777329231321346, 0.051607984642032534, 0.010421741408208618, 0.14715177967445925, 0.026024590151791926, 0.026659679315343965, 0.010769192685984308, 0.019074542287853546, 0.016986880873446353, 0.09510634350590408, 0.14976995793404058, 0.03700426241266541, 0.046035568811930716, 0.02308214345248416, 0.0303782547780429, 0.025740655582922045, 0.051582543819677085, 0.0357055188214872, 0.08005434181541204, 0.09218031496857293, 0.05185249632631894, 0.03990118762885686, 0.05450850927445572, 0.032866867040866055, 0.07417074346449226, 0.014942763118597213, 0.06141839396150317, 0.07897514777141623, 0.012792005236406112, 0.08081537715042941, 0.059842020345968194, 0.07734469385468401, 0.05514826283615548, 0.07024164297035895, 0.03520826132444199, 0.047036918986123055, 0.03899477669619955, 0.05091279264888726, 0.035787585511570796, 0.04620785839506425, 0.03275764516729396, 0.0971880009456072, 0.08878070715581998, 0.09503494889941067, 0.10118356076418422, 0.05988993711071089, 0.022103566079749726, 0.08014829028979875, 0.0827754708006978, 0.0374911669496214, 0.08463140402454883, 0.07797410187777132, 0.028146761433163192, 0.07010562214418314, 0.12245762467500754, 0.008763471796555677, 0.015940376579237636, 0.09086352234589867, 0.12241961187100969, 0.02532169466576306, 0.0585273613978643, 0.02174751145503251, 0.021912014053668827, 0.015465259202755988, 0.044516578054754063, 0.03016205973835895, 0.05068833379482385, 0.014883937710692408, 0.07505778063205071, 0.062280135025503114, 0.01917804776894627, 0.00763646952691488, 0.0232784452236956, 0.01609445571375545, 0.037526367013924755, 0.09649971092585474, 0.051661107572726905, 0.028792990233341698, 0.029351716111705173, 0.02221184357040329, 0.06996551208430901, 0.026950912906613667, 0.031268856109818444, 0.03561763740435708, 0.03415556195250247, 0.08164356942870654, 0.021499146168935113, 0.012593618030223297, 0.020529765861283522, 0.05144956950971391, 0.057530323101673275, 0.037448723523993976, 0.03947081619116943, 0.020328404498286545, 0.020592859546013642, 0.1441729473299347, 0.07312064903089777, 0.014083322712394875, 0.05075205088360235, 0.007773460247335606, 0.01794635350961471, 0.021445128950290382, 0.07382768570096232, 0.017194838073919527, 0.057785796307143755, 0.036857858940493315, 0.0559607661125483, 0.03797100252995733, 0.05941150047874544, 0.05248750756436493, 0.03075399301451398, 0.06255136773688719, 0.02521725222322857, 0.08269102181657217, 0.04594381709466688, 0.09110826038522646, 0.05128220778715331, 0.03367577461176552, 0.01951197711605346, 0.04001372690254357, 0.009794030120247044, 0.023205319557746407, 0.028459005225158762, 0.09033710215589963, 0.029103679225954693, 0.06895622835145332, 0.03060346320125973, 0.012521723401732743, 0.07097330410033464, 0.030463867078651674, 0.04378967780212406, 0.052372660211403854, 0.02275955783261452, 0.019756214205699507, 0.06379592712619342, 0.00952210257310071, 0.02387914326391183, 0.04300978820538148, 0.020939956448273733, 0.014385243230208289, 0.15231455967295915, 0.22014299815054983, 0.12363993271719664, 0.07316551185795106, 0.1483361583086662, 0.1606083122896962, 0.05937601839832496, 0.13455319945933297, 0.14158132311422378, 0.1158546403166838, 0.1370772288646549, 0.0901855481788516, 0.08893945254385471, 0.2447335864417255, 0.08240684604970738, 0.14152785879559815, 0.16683338762959465, 0.1889366382965818, 0.2691121579846367, 0.10562193041550927, 0.17977556737605482, 0.1274367602309212, 0.15897880832199007, 0.15028900117613375, 0.11052289555664174, 0.17178082605823874, 0.22401993308449164, 0.22613901703152806, 0.12284656942938454, 0.19397243682760745, 0.15407839237013832, 0.23315130325499922, 0.12686134345130995, 0.12076443701516837, 0.14632183592766523, 0.10440166151965968, 0.11066155100706965, 0.1360408790060319, 0.067894719686592, 0.23669017507927492, 0.18602258060127497, 0.10648383104125969, 0.12338472297415137, 0.10677046331693418, 0.08053503828705288, 0.08491806598613039, 0.31123515393119305, 0.1213607304089237, 0.18960943969432265, 0.16316630237270147, 0.07256745215272531, 0.12599331268575042, 0.10853312342078425, 0.18962667236337438, 0.16575740708503872, 0.23885261529358104, 0.1828477025264874, 0.3049164789263159, 0.14729744842043146, 0.2290469891158864, 0.1393069967161864, 0.21252866688882932, 0.16295357316266745, 0.15150180406635627, 0.13579668273450807, 0.13985556259285659, 0.15822291607037187, 0.190097461163532, 0.25785149191506207, 0.25441294361371547, 0.24657245026901364, 0.15477227076189592, 0.22115660860436037, 0.16058304958278313, 0.07775666745146737, 0.09026258310768753, 0.13996065070386976, 0.1777679836959578, 0.20799015183001757, 0.20940835151122883, 0.36782991082873195, 0.22021287877578288, 0.13547647569794208, 0.27750362176448107, 0.2295769122429192, 0.2659878646954894, 0.3272675920743495, 0.20924678596202284, 0.174377110961359, 0.3355060250032693, 0.42138785880524665, 0.1638652422116138, 0.1924612608854659, 0.2813281462294981, 0.30683475255500525, 0.09730664809467271, 0.13438160007353872, 0.15131402586121112, 0.11124211829155684, 0.14544259873218834, 0.12182348917121999, 0.12697009777184576, 0.14151813666103408, 0.08681022343807854, 0.1415234652813524, 0.20088692283025011, 0.0956235165358521, 0.15830006974283606, 0.12006004239083268, 0.1809877171763219, 0.13886258384445682, 0.19456624402664602, 0.13747614808380604, 0.22512439725687727, 0.18433744524372742, 0.07729947479674593, 0.14934562757844105, 0.1200692450220231, 0.14814391237450764, 0.10353111487347633, 0.1751346656237729, 0.14550336578395218, 0.08405594271607697, 0.12647086987271905, 0.2261740612448193, 0.14424698398215696, 0.25335612532217056, 0.13943293917691335, 0.207721063925419, 0.20327132457168773, 0.09743854257976636, 0.2925526845501736, 0.14301767572760582, 0.05281327699776739, 0.16739571292418987, 0.10161382830119692, 0.3005699871573597, 0.13523380825063214, 0.18356432032305747, 0.1579861858044751, 0.17251452809432521, 0.12271557294297963, 0.14034304971573874, 0.1117700376198627, 0.13039457495324314, 0.12800279626389965, 0.14515154325636104, 0.23472677887184545, 0.12376116254017688, 0.12039172303047962, 0.25814757915213704, 0.1948657154571265, 0.09230524810845964, 0.18623354349983856, 0.06682854291284457, 0.13299460028065369, 0.04647603345802054, 0.16052790801040828, 0.08400920967687853, 0.20429284631973132, 0.14762423088541254, 0.1709072440280579, 0.09712322629638948, 0.09990978302084841, 0.15379686607047915, 0.10143627689103596, 0.25537506386172026, 0.13603124592918903, 0.1045954214350786, 0.16597068548435345, 0.17071360285626724, 0.0796124448243063, 0.19029785587918013, 0.14942530455300584, 0.08744446284254082, 0.08098898033495061], [0.05206039786571637, 0.022593376124859788, 0.034393910100334324, 0.0430748300277628, 0.07767802206217311, 0.12858673289883882, 0.04768170430907048, 0.018704620633798186, 0.1190589000179898, 0.08280234396806918, 0.03130247539957054, 0.072566413145978, 0.02626621673698537, 0.04003139001724776, 0.01884108489321079, 0.07930880252388306, 0.06329747848212719, 0.042190846797893755, 0.02110122142767068, 0.06748599669663236, 0.061808459358871914, 0.01935550826601684, 0.004300536593291326, 0.020735459511342924, 0.04256568332493771, 0.0455867141863564, 0.020988956748624332, 0.013752997419942403, 0.03803106825216673, 0.00796868080215063, 0.0590442746761255, 0.022017849878466222, 0.013383934801822761, 0.07937377013149671, 0.019404595768719446, 0.014363966784003424, 0.01755064778990345, 0.03138499851047527, 0.025913434983522166, 0.006969692976781516, 0.0497622782131657, 0.04581587083521299, 0.031460363607038744, 0.037388153141364455, 0.0709403824293986, 0.07031195404124446, 0.06794841407099739, 0.029970285067975055, 0.013869142603653017, 0.025173111134790815, 0.007889922235335689, 0.028058868883817922, 0.030553778269677423, 0.07202120177680627, 0.034143865705118515, 0.019939498706662562, 0.041607648599892855, 0.04700741861597635, 0.03872098728606943, 0.09026474275742657, 0.04963963830959983, 0.059357446152716875, 0.07123795396182686, 0.06472151886555366, 0.023342923013842665, 0.028425417476682924, 0.03930332088202704, 0.013386857008299557, 0.018701575972954743, 0.022501602143165655, 0.035608423640951514, 0.15291143936337903, 0.12357309489743784, 0.0882273618481122, 0.05770154770289082, 0.0058770025134435855, 0.03242436519940384, 0.08002689719432965, 0.06752216155291535, 0.08106352906906977, 0.02604425335448468, 0.12400732550304383, 0.02783403153443942, 0.07476254686480388, 0.042980135694961064, 0.024731818994041532, 0.10103370630531572, 0.05398162153142039, 0.06008759330143221, 0.05429855940747075, 0.1460136368405074, 0.035781169644906186, 0.09523823799099773, 0.05013279544073157, 0.11796228776802309, 0.04863296322582755, 0.037795347307110205, 0.06818498848588206, 0.03211142378859222, 0.05672479601344094, 0.09530327981337905, 0.08731184847420081, 0.009796089580049738, 0.062498326442437246, 0.08300702829728834, 0.07665456330869347, 0.006683312103632488, 0.047766030838829465, 0.04414629831444472, 0.02293944144184934, 0.014025194923306117, 0.019789627549471334, 0.05319628085999284, 0.021002961075282656, 0.01778935587935848, 0.028199209009471815, 0.05801187675388064, 0.027353127261449117, 0.07281630911165848, 0.054645398413413204, 0.009153103037533583, 0.04087176093889866, 0.01807913857192034, 0.06357019548886456, 0.027759759250329807, 0.052589794067898765, 0.029130073708074633, 0.060091712221037596, 0.017214274921570905, 0.06005197392369155, 0.048976596153806895, 0.04189934603346046, 0.041005781677085906, 0.04498324793530628, 0.09807022899622098, 0.04466536753170658, 0.031647685391362756, 0.0389761525002541, 0.022861284014652483, 0.0416232411225792, 0.04980374942533672, 0.025859970664896537, 0.0446929828467546, 0.030728414894838352, 0.07056016533169895, 0.03681025387777481, 0.020314583853178192, 0.03259227982198354, 0.018378272325207945, 0.020703521186078433, 0.006522179319290444, 0.025322349611087702, 0.004176525571892853, 0.028588400527951308, 0.06284161427174695, 0.01946019005117705, 0.05334260640665889, 0.019260205372120254, 0.032471803278895095, 0.02560048615123378, 0.0431831872992916, 0.05329969171725679, 0.021132098481757566, 0.018775657154037617, 0.019267732604930643, 0.05853523558471352, 0.023056927129800897, 0.07131354170269333, 0.02976982170366682, 0.06823010364314541, 0.062010939509491436, 0.029972019838169217, 0.05616521666524932, 0.06520287584862672, 0.07263650157256052, 0.018369938006799202, 0.02101469257468125, 0.08939778810599819, 0.036870779731543735, 0.04343224463809747, 0.046383361477637663, 0.053891075804131106, 0.013526058864954393, 0.04804549396794755, 0.06040422689693514, 0.055512312246719375, 0.020816563264816068, 0.09564915031660348, 0.05026101258408744, 0.01708571639028378, 0.055368083267239854, 0.014979060633777408, 0.03540123827406205, 0.05783884502307046, 0.01110916497054859, 0.04592105913616251, 0.04903379718598444, 0.058341542462585494, 0.0320537737570703, 0.021175875917833764, 0.014501687128358753, 0.05872036061191466, 0.04548331075056922, 0.01012964599794941, 0.013899938949180068, 0.012237228511366993, 0.04460152056708466, 0.06104706408223137, 0.055702706522424705, 0.08246357581811026, 0.02427617000648752, 0.029934630438219756, 0.04369643807876855, 0.04534621381026227, 0.03618829701736104, 0.04683355196902994, 0.04271238736691885, 0.02856762224837439, 0.04732121720735449, 0.041876157629303634, 0.08659481507493183, 0.0485592308541527, 0.052222271406208165, 0.054343014053301886, 0.04430966728250496, 0.05985631039948203, 0.012805431615561247, 0.008385971887037158, 0.05018467527406756, 0.1047828582522925, 0.01116250961786136, 0.06783318080124445, 0.02258191365399398, 0.05320458178175613, 0.11147073688334785, 0.018816562478605192, 0.059213632775936276, 0.05293252528645098, 0.1261618544231169, 0.1341694497386925, 0.020028105573146604, 0.029247678139654454, 0.07662325209821574, 0.09189069925923832, 0.0714808440534398, 0.05957627952739131, 0.09208491188474, 0.08793425804469734, 0.05602729223028291, 0.033705215610098094, 0.14394173864275217, 0.07506272333557718, 0.03471109659585636, 0.03936145702027716, 0.12890551501186565, 0.07965941535076126, 0.12853690510382876, 0.13751390855759382, 0.029659391984750982, 0.0434429055894725, 0.06447174906497821, 0.05007868916436564, 0.09531275703920983, 0.05573358357651159, 0.03039964532945305, 0.06821469665737823, 0.07046721875667572, 0.06419281286071055, 0.13940694916527718, 0.04757540278660599, 0.13616322947200388, 0.009705308220873121, 0.024927669910539407, 0.009134589236055035, 0.042320581633248366, 0.039637458030483685, 0.0709214131347835, 0.026421030597703066, 0.0077908881939947605, 0.034406730701448396, 0.12048393487930298, 0.07327418454224244, 0.0565444726817077, 0.011103396627731854, 0.03761873842449859, 0.04767080958117731, 0.056306584665435366, 0.08802718235529028, 0.03402143731364049, 0.049945744540309533, 0.03569968925148714, 0.006913434008311015, 0.01619813931029057, 0.05547347565880045, 0.03808477376878727, 0.025359191677125636, 0.01862416997028049, 0.09231391639332287, 0.04417283009388484, 0.020279565615055617, 0.02738847761065699, 0.04214093365590088, 0.027007614844478667, 0.014044102063053288, 0.018748685652099084, 0.05354328684916254, 0.08533907152013853, 0.04777759349963162, 0.03448172843491193, 0.02897380523791071, 0.11023392551578581, 0.07017176976660267, 0.06723813421558589, 0.01127456371250446, 0.040202866948675364, 0.04858011117903516, 0.03401959307666402, 0.03549746885255445, 0.018128912561223842, 0.030119989241939038, 0.03688080243591685, 0.0491270703059854, 0.055418463962269016, 0.03552439025952481, 0.06938369799172506, 0.03803131316090003, 0.04119781980989501, 0.007151974186854204, 0.04507253943302203, 0.031176143311313353, 0.038117840158520266, 0.030260264429671224, 0.028365999278321397, 0.022453321726061404, 0.015407426417368697, 0.04288078438548837, 0.038751322572352365, 0.007446433337463532, 0.0394087874883553, 0.020197901540086605, 0.09903594123898074, 0.027872881109942682, 0.009501701861154288, 0.03675544627185445, 0.018449735580361448, 0.025725005543790758, 0.06418617063900456, 0.04976289419573732, 0.04736454749945551, 0.03495476223179139, 0.0710478528344538, 0.023121314006857574, 0.13104238081723452, 0.16364798590075225, 0.11056806266424246, 0.1265784219140187, 0.14681938657304272, 0.27754173846915364, 0.0838094086793717, 0.12129419686971232, 0.3302776243072003, 0.37246399966534227, 0.1284718039096333, 0.243863997166045, 0.14966771967010573, 0.20216116070514545, 0.08351929573109373, 0.11091450462117791, 0.1810715501778759, 0.1226262999989558, 0.08567149430746213, 0.23813733336282894, 0.13844135566614568, 0.2597095922101289, 0.18391822086414322, 0.10232141416054219, 0.1257119793444872, 0.24343168130144477, 0.10772031586384401, 0.11535064040799625, 0.12710044858977199, 0.09908246647682972, 0.21242351940600201, 0.11720642520231195, 0.10197376992437057, 0.1969746022950858, 0.10075194251840003, 0.10622678077197634, 0.10847925834241323, 0.15151620173128322, 0.18520188401453197, 0.11680696421535686, 0.13397476956015453, 0.1988346321741119, 0.1564058565418236, 0.21127658954355866, 0.24360148468986154, 0.18239162309328094, 0.1673483639024198, 0.13722288276767358, 0.1163726148661226, 0.1461437501711771, 0.0723535280849319, 0.22299913864117116, 0.18360346119152382, 0.16351083701010793, 0.08613388941739686, 0.1607606455218047, 0.10014507352025248, 0.11438846820965409, 0.23874933802289888, 0.20816875708987936, 0.2710991841740906, 0.25309833290521055, 0.1900013381964527, 0.30295836681034416, 0.10416939898277633, 0.19256425614003092, 0.17020738392602652, 0.215925105731003, 0.1944707296206616, 0.17113247100496665, 0.17909144080476835, 0.37397468579001725, 0.2523645863402635, 0.2117759213433601, 0.30515613325405866, 0.1956352186971344, 0.07983321891515516, 0.17700811353279278, 0.19120306824333966, 0.14044352166820318, 0.224587052653078, 0.18625386350322515, 0.23374812357360497, 0.10972775853588246, 0.255726485629566, 0.18193266412708908, 0.19250032753916457, 0.1928028417751193, 0.1502310245996341, 0.2107015735236928, 0.25847347103990614, 0.1812600260018371, 0.23622385400813073, 0.2416729397373274, 0.19699456606758758, 0.16822276229504496, 0.13137888541677967, 0.2099791818181984, 0.14924954914022237, 0.1161669880093541, 0.2260133862728253, 0.19668835593620315, 0.11062250661780126, 0.14938252716092393, 0.1560931748826988, 0.26735124934930354, 0.12834739027312025, 0.12840382318245247, 0.12715256219962612, 0.13767103606369346, 0.12790455075446516, 0.21044254914158955, 0.16917139029828832, 0.10498451461899094, 0.13715457549551502, 0.1998279374674894, 0.17736732785124332, 0.09422479823115282, 0.1179111389501486, 0.13993494270835072, 0.16473397059598938, 0.1518405944807455, 0.11133100531878881, 0.20615458313841373, 0.12309671772527508, 0.13588198518846184, 0.14601236034650356, 0.11048595144529827, 0.10003208153648302, 0.14535198250086978, 0.20106025884160772, 0.2071619001799263, 0.1325006564729847, 0.16194290161365643, 0.17651090427534655, 0.11690769591950811, 0.11406725927372463, 0.11032682014047168, 0.2485000155866146, 0.28714367479551584, 0.11277267913101241, 0.1450075814500451, 0.1363812873023562, 0.253319374169223, 0.16096880310215056, 0.10117521160282195, 0.13881663006031886, 0.14845451602013782, 0.0958728113619145, 0.10156908421777189, 0.12800383527064696, 0.07925924190203659, 0.13995122542837635, 0.11574934440432116, 0.31361774483229965, 0.12528813880635425, 0.14693787787109613, 0.15014546981547028, 0.13256286329124123, 0.17476564011303708, 0.10267403820762411, 0.12085406619007699, 0.11136573040857911, 0.14392891433089972, 0.10986851426423527, 0.10133455813047476, 0.10115044613485225, 0.09291606533224694, 0.1291292576934211, 0.11888715220266022, 0.19056100660236552, 0.09103305113967508, 0.13891040784073994, 0.14033588056918234, 0.2180861061788164, 0.12004635718767531], [0.04294357007893268, 0.04224194366543088, 0.025182977988151833, 0.030542393724317662, 0.01739147752232384, 0.016017903180909343, 0.06373048454406671, 0.020912728905386757, 0.017443988181184977, 0.07266190528753214, 0.030020062768016942, 0.04830111560295336, 0.033751028386177495, 0.05377884452173021, 0.0234589967658394, 0.06372326344717294, 0.043166091927560046, 0.014257459315558663, 0.025481408556515817, 0.06939359824173152, 0.05834614748891909, 0.06078324171539862, 0.06300913184531964, 0.0009659003887918516, 0.013311376878846204, 0.03351717765326612, 0.0545487485214835, 0.09476199440541677, 0.03877652590745129, 0.014000809806020698, 0.07308028361876495, 0.07336154274526052, 0.018017794500337914, 0.1121559766761493, 0.06015718448907137, 0.030882755636412185, 0.07033596251858398, 0.06338636550935917, 0.056011462220340036, 0.021691473739338107, 0.12777739117154852, 0.0968732635374181, 0.03274753711593803, 0.008230672847275855, 0.03797864294028841, 0.04059473947563674, 0.05034290115872864, 0.03293793139164336, 0.03987264462921303, 0.02910405586590059, 0.05762637185398489, 0.06393649731762707, 0.05903129080252256, 0.04398717072035652, 0.021008287840231787, 0.037153897937969305, 0.02591537941043498, 0.07021421319223009, 0.009038233420142205, 0.07993452207301743, 0.04234128013195004, 0.013283845055411803, 0.09251411815057509, 0.053370603927760385, 0.038168020473676734, 0.0306834982620785, 0.08882908776286058, 0.013569705497502582, 0.08037563238758594, 0.0423386566399131, 0.060474586207419634, 0.12345994706265628, 0.035626647077151574, 0.06699047953588888, 0.08420784550253302, 0.21895477519137785, 0.15116994531126693, 0.19423634454142302, 0.44132328126579523, 0.19048845424549654, 0.36591324023902416, 0.22430990502471104, 0.011051475048589054, 0.2966567315161228, 0.2584300999296829, 0.3177875460823998, 0.3456369641935453, 0.48847388243302703, 0.3828691178932786, 0.6175184017047286, 0.6059715338051319, 0.3998509410303086, 0.49340367258992046, 0.4473098006565124, 0.741919451393187, 0.20409449993167073, 0.33986578637268394, 0.04228144076478202, 0.035565828075050376, 0.025959082631743513, 0.1112617777835112, 0.009703131872811355, 0.0933489303861279, 0.10086172842420638, 0.12326035386649892, 0.1203258425812237, 0.01821456567995483, 0.04103481820493471, 0.03942064329748973, 0.05642028911097441, 0.026219209103146568, 0.02530621346522821, 0.07140285917557776, 0.012480718814913416, 0.10605043164105155, 0.03888509098032955, 0.007326273598664557, 0.01951892176293768, 0.04683676546846982, 0.024166133625840303, 0.039826212159823626, 0.01597892744030105, 0.02321039399248548, 0.02785525139188394, 0.058677772467490286, 0.02710074324568268, 0.04442092264071107, 0.037747790483990684, 0.025738924523466267, 0.036449952312977985, 0.0495194252289366, 0.061547282748506404, 0.01461281446609064, 0.06776603870093822, 0.030034057817829307, 0.0643494950782042, 0.03716004663147032, 0.07328479725401849, 0.011274914377281675, 0.0531877684261417, 0.024713035236345604, 0.03254701252444647, 0.014080462660785997, 0.009140329748333897, 0.08205514968722127, 0.051094114169245586, 0.048904964060056955, 0.056055022578220814, 0.036948263659724034, 0.03527365566696972, 0.02482668587617809, 0.01337045461696107, 0.023278970293176826, 0.028736926542478614, 0.03589361615013331, 0.03412756443140097, 0.06449035470723175, 0.030963556964707095, 0.06362148531479761, 0.047431351922568865, 0.024294571558129974, 0.06663294989266433, 0.01283220830373466, 0.025734310220286716, 0.009634085236029932, 0.021018121296947356, 0.022076778259361163, 0.07192870791186579, 0.03808365683653392, 0.06748742162017152, 0.10498010626179166, 0.023051268253766466, 0.01574950361828087, 0.027049959935538936, 0.07098306334228255, 0.09903491707518697, 0.02129514832631685, 0.06394861658918671, 0.04588339514157269, 0.009291791884606937, 0.04663568797695916, 0.034259588792338036, 0.05670679522154387, 0.07791116033331491, 0.04105458901904058, 0.021195084555074573, 0.03137466781481635, 0.018307625432498753, 0.016311008839693386, 0.07804621636751108, 0.025342380176880397, 0.022740482781955507, 0.03366990422364324, 0.022158060128276702, 0.06754592512152158, 0.006104704552853946, 0.021324489134713076, 0.06045891946996562, 0.026371570165792946, 0.01458450338759576, 0.01107376081563416, 0.0372153366333805, 0.02951454331196146, 0.03104426181380404, 0.05113152212288696, 0.02945760017610155, 0.0736857796437107, 0.008992758321255678, 0.029955013524158858, 0.04078019475855399, 0.014507663272524951, 0.09200918313581496, 0.06587470503291115, 0.04433010231878143, 0.04864033646299504, 0.05156475453986786, 0.1031798860640265, 0.03671975639008451, 0.013559488907048944, 0.004810561349586351, 0.07200372419902124, 0.08035572798689827, 0.11806179492850788, 0.01506120061094407, 0.05083064432255924, 0.01868385534180561, 0.011101002273790073, 0.06570962170371786, 0.02274439018947305, 0.05520890743355267, 0.053570326999761164, 0.08362355263670906, 0.08181887955288403, 0.06361004881910048, 0.010693687509046867, 0.0628808219335042, 0.06529499121825211, 0.05487039532454219, 0.11558465441339649, 0.09193894627969712, 0.04025541842565872, 0.07387946534436196, 0.066428302670829, 0.0378935260232538, 0.03065937289647991, 0.032682866367395036, 0.10812052641995251, 0.08003915747394785, 0.07470246258890256, 0.08999696845421568, 0.10537746697082184, 0.254197750473395, 0.08059072904870845, 0.2574472292326391, 0.3490357333794236, 0.22468921670224518, 0.4693425621371716, 0.21220985508989543, 0.05381217066315003, 0.31711551651824266, 0.10656594968168065, 0.2268402129993774, 0.2512368484167382, 0.39946662727743387, 0.26307582564186305, 0.2787750691641122, 0.4152756789699197, 0.36642900318838656, 0.5107229354325682, 0.32627005653921515, 0.7111191947478801, 0.17019812192302197, 0.34237388928886503, 0.20204390137223527, 0.033479350386187434, 0.15105752478120849, 0.11157884553540498, 0.05435588289401494, 0.039083489318727516, 0.06844252115115523, 0.13927907712059096, 0.056889378392952494, 0.06238643283722922, 0.04926708759739995, 0.030643483514722902, 0.03682484821183607, 0.03701447436469607, 0.060750635457225144, 0.041820444603217766, 0.0173548358361586, 0.024934150715125725, 0.015870659226493444, 0.008792885892034974, 0.05340588933904655, 0.04640906576241832, 0.022737842591595836, 0.026345919686718844, 0.07801995176123455, 0.027367953516659327, 0.05371187311538961, 0.03561509925930295, 0.0593497612135252, 0.05657705296471249, 0.03688402706757188, 0.029103981651132926, 0.04400101177452598, 0.026396343055239413, 0.008161800615198445, 0.049319171521347016, 0.05463774316012859, 0.02324995231901994, 0.050806576473405585, 0.05642733951390255, 0.020168625669612084, 0.016383961956307758, 0.04948556103045121, 0.02037302798271412, 0.031493827045778744, 0.04611893054971006, 0.08288382436148822, 0.0464359834586503, 0.022032644592400175, 0.036458193862927146, 0.04134292452363297, 0.027648030772979837, 0.031599575668224134, 0.01582200773555087, 0.021756036876467988, 0.02731177108216798, 0.04751342974486761, 0.043967006567982025, 0.021415687951957807, 0.054589340288657695, 0.09291336391470395, 0.009922727804223541, 0.05796126599307172, 0.03256677220633719, 0.04937495876220055, 0.034113560104742646, 0.05499814491486177, 0.01462780213842052, 0.06587481635506265, 0.04045187604788225, 0.04686281485192012, 0.0676627985376399, 0.03894875611877069, 0.047064656755537726, 0.04014683479908854, 0.02039527942542918, 0.05246711334621068, 0.030958068782638293, 0.0216650941001717, 0.11844152220874093, 0.166459018655587, 0.11736508895410225, 0.1101734627445694, 0.06781275689718314, 0.132023514888715, 0.2131812967127189, 0.22684466588543728, 0.08240342474891804, 0.19586148468079045, 0.14060367713682353, 0.13746979529969394, 0.18543226149631664, 0.23399647587211803, 0.13050454639596865, 0.2572876971680671, 0.13907126092817634, 0.06107575180067215, 0.1353645746712573, 0.1378536192351021, 0.129271853948012, 0.19412110385019332, 0.17027071880875155, 0.05792900483356789, 0.10015037245466374, 0.17376146977767348, 0.08979372389148921, 0.14545423560775816, 0.1452556368894875, 0.12740875157760456, 0.1826704034465365, 0.14056230982532725, 0.14205349230905995, 0.2506085758795962, 0.1147699766443111, 0.21318172715837136, 0.1784364806371741, 0.14378985069924966, 0.17528193740872666, 0.12199695876915939, 0.2588365296833217, 0.1699410122819245, 0.16748533467762172, 0.06870236189570278, 0.1368947050650604, 0.161616416007746, 0.2032442213385366, 0.12366788199869916, 0.13380377873545513, 0.17812422942370176, 0.1352924230741337, 0.1344768176204525, 0.15416691574500874, 0.10852876701392233, 0.10145050386199728, 0.16491440153913572, 0.12041164227412082, 0.2577012515394017, 0.09272747076465748, 0.2820940426317975, 0.09831648843828589, 0.14471069269347936, 0.25836309883743525, 0.11853821662953123, 0.2517831284785643, 0.1820917657460086, 0.3080522903474048, 0.17275335121667013, 0.1997850858606398, 0.11916505682165734, 0.17038125428371131, 0.21508475707378238, 0.13502213289029896, 0.19255732448073104, 0.3086281969444826, 0.432220691582188, 0.3138212417252362, 0.6095951143652201, 0.7824667787645012, 0.45548859459813684, 0.4721975448774174, 0.3535008797189221, 0.10238183982437477, 0.3601755481213331, 0.27148174645844847, 0.4390370211331174, 0.4240107868099585, 0.8653317822609097, 0.6217763700988144, 0.6730752799194306, 0.7763397262897342, 0.7007976423483342, 0.6886530190240592, 0.8001231250818819, 1.161080659367144, 0.556335331639275, 0.6365112669300288, 0.3468810411868617, 0.16531596280401573, 0.20539713237667456, 0.30782887421082705, 0.1640786838834174, 0.25359426566865295, 0.194453333679121, 0.26682886644266546, 0.24930405837949365, 0.20112688886001706, 0.1336769902263768, 0.16289218270685524, 0.29421601560898125, 0.1447710589854978, 0.17412019427865744, 0.11598778160987422, 0.16983319306746125, 0.2654835901921615, 0.14713058393681422, 0.10357447114074603, 0.16170781891560182, 0.16049185447627679, 0.07005923049291596, 0.14115328202024102, 0.3009331942303106, 0.07721283647697419, 0.10281895738444291, 0.1820112724089995, 0.1957721301005222, 0.06967083492781967, 0.1102729921694845, 0.08494683163007721, 0.1568387364386581, 0.11788694493588991, 0.13263385713798925, 0.2243796520633623, 0.1611214628792368, 0.07582857520901598, 0.1810199857573025, 0.17614545591641217, 0.16023676347685978, 0.0699361230363138, 0.16980962245725095, 0.06463483601692133, 0.20149057090748101, 0.07809461923898198, 0.250148355262354, 0.13299715326866135, 0.09167137977783568, 0.1004197497968562, 0.09836045326665044, 0.10257394475047477, 0.1207347956369631, 0.09513903511106037, 0.16737840604037046, 0.08005800802493468, 0.11317514581605792, 0.12597029126482084, 0.11996296947472729, 0.15917253855150193, 0.1893647387623787, 0.11628271851805039, 0.1613849401473999, 0.16063875518739223, 0.19847722869599238, 0.12087224138667807, 0.21884878166019917, 0.09649947343859822, 0.1479196798754856, 0.094733926380286, 0.25278018903918564, 0.15946311905281618, 0.1812922055250965, 0.24513820535503328, 0.10228332714177668, 0.1785517658572644, 0.1317019571433775, 0.11717819390469231, 0.15656857984140515], [0.009429731162526878, 0.026669356921047438, 0.05139453183801379, 0.050910603313241154, 0.08556215369026177, 0.04767955579154659, 0.02127861513145035, 0.023232801286212634, 0.018698993299040012, 0.057701792611624114, 0.029923219917691313, 0.05195756217290182, 0.013997926562296925, 0.0346246178378351, 0.053735703477286734, 0.013224354497651802, 0.06112356095400173, 0.04536094915238209, 0.04884807101916522, 0.022002133046044037, 0.09969166581868194, 0.09729290351970121, 0.0343302412511548, 0.02428575298836222, 0.007953013137012022, 0.06326344358967617, 0.03241260586946737, 0.07730713376076892, 0.026192144832748454, 0.039535861724289134, 0.029797848910675384, 0.04626702982932329, 0.03311780572403222, 0.05157898893230595, 0.09168269010842778, 0.04519756534136832, 0.06474385751062073, 0.06741239049006253, 0.025872210535453632, 0.0652840593829751, 0.11069770844187587, 0.023425811632478144, 0.02638581754581537, 0.010820026091096224, 0.022893554451002274, 0.05550314672291279, 0.0857271850691177, 0.045293510193005204, 0.07919316849438474, 0.05320147960446775, 0.015332933344325284, 0.023210850413306616, 0.03352132625877857, 0.03832853588392027, 0.04313156350690406, 0.047698977796244435, 0.04986222324077971, 0.10262976167723536, 0.04764019227877725, 0.09924609519657679, 0.04345217501395382, 0.05894438530958723, 0.15025235392386094, 0.06410970716387965, 0.04561745765386149, 0.04046816990012303, 0.02666837357537588, 0.05978986962873023, 0.13363639474846423, 0.3046356205595657, 0.3431753790937364, 0.33030725084245205, 0.23118183627957478, 0.15669085609260947, 0.5466631287708879, 2.8293611900880933, 2.5937688443809748, 8.3204828761518, 18.25688224285841, 32.19590038061142, 33.09964768588543, 28.963924907147884, 42.10260719060898, 45.019266083836555, 47.04478919506073, 38.37723009288311, 29.199683256447315, 30.840999484062195, 36.396305188536644, 32.64349736273289, 37.1068100631237, 28.457387387752533, 24.32252526283264, 19.550368934869766, 17.335918061435223, 6.457318402826786, 5.562072191387415, 0.5266679485794157, 0.10365321300923824, 0.6053665350191295, 0.4308138764463365, 0.25699012563563883, 0.13995582674397156, 0.016886952544155065, 0.07058930947096087, 0.0251560510150739, 0.05600947326456662, 0.005599154947049101, 0.0817294062289875, 0.14075633691390976, 0.012893660914414795, 0.033934847233467735, 0.11030865978682414, 0.009643850971770007, 0.03558142430847511, 0.06424224731745198, 0.07310828485060483, 0.06836264379671775, 0.021123268779774662, 0.06040169988409616, 0.0339732533757342, 0.07899796881247312, 0.047421195631613955, 0.03680735579109751, 0.028110629973525647, 0.034167473422712646, 0.01963121241715271, 0.09771163808181882, 0.0205036329862196, 0.047438432011404075, 0.059452429923112504, 0.05048918959801085, 0.03293298497737851, 0.019479753063933458, 0.04397519245685544, 0.05863668346137274, 0.028535112469398882, 0.017677286014077254, 0.020261819008737803, 0.04819150039111264, 0.10225620906567201, 0.029482495519914664, 0.06287932279519737, 0.0447594013530761, 0.011036181240342557, 0.020199638165649958, 0.05879650496353861, 0.052268588842707686, 0.04536100852419622, 0.033802544567151926, 0.04103360108274501, 0.019889787799911574, 0.01525118113931967, 0.05603583063930273, 0.04167287966993172, 0.027755625487770885, 0.020146821370872203, 0.03061546743992949, 0.06941369560081512, 0.02544534574553836, 0.04296635772334412, 0.02418936841422692, 0.011069446154579055, 0.10448329034261405, 0.012451205457182368, 0.02160940148314694, 0.08840257549309172, 0.048115445097209886, 0.0491505741229048, 0.020763173160958104, 0.07412263003061526, 0.028619600416277535, 0.03952636965550482, 0.07645472520380281, 0.03250557099818252, 0.027040005879825912, 0.03846640094707254, 0.012213919508212712, 0.11034670227672905, 0.05437485218863003, 0.060713869461324066, 0.015470332709810464, 0.0397032308683265, 0.017179100832436234, 0.022797667115810327, 0.031621472735423595, 0.0023848145610827487, 0.034285567671759054, 0.019282100583950523, 0.03350116952788085, 0.06211131869349629, 0.02711241537326714, 0.031003438125480898, 0.015044599695102079, 0.020436737650015857, 0.036886353700538166, 0.044324922127998434, 0.0762541226868052, 0.02017813629208831, 0.016942864094744436, 0.0368058529420523, 0.04867521740379743, 0.04608741895935964, 0.10755037146736868, 0.02252305392175913, 0.07587954591144808, 0.03690402052598074, 0.059511174622457474, 0.07928735445602797, 0.04718938951555174, 0.07312712055863813, 0.037068209567223676, 0.022310992644634098, 0.051507390235201456, 0.020761341911565978, 0.026393198204459623, 0.08592998434323817, 0.019487309982650913, 0.04214438835333567, 0.04937183432048187, 0.051764421950792894, 0.10111579525982961, 0.10090969342854805, 0.08208494691643864, 0.03193536038452294, 0.04323705237766262, 0.006707989905407885, 0.031159125865087844, 0.06090790768212173, 0.038593256249441765, 0.03470990544883534, 0.05572694506554399, 0.07979475340107456, 0.11746423246222548, 0.019664620194816962, 0.14126025518635288, 0.05857716692844406, 0.07119626752682962, 0.1768745417939499, 0.011526620255608577, 0.07802767751854844, 0.09268742447602563, 0.047166538788587786, 0.05647638805385213, 0.14931226061889902, 0.3154991188785061, 0.4091076896293089, 0.3017629450187087, 0.1558817073237151, 0.25258049194235355, 0.8617099234834313, 4.1292051784694195, 3.449787860736251, 11.467037983238697, 25.677443258464336, 41.104461550712585, 41.554820984601974, 39.751475751399994, 56.26895383000374, 60.566542223095894, 62.08904832601547, 51.62538640201092, 39.28977772593498, 42.206090837717056, 51.20687685906887, 48.081962540745735, 52.173252403736115, 40.425153002142906, 34.47906866669655, 27.274757847189903, 24.494895413517952, 10.755416918545961, 9.556893780827522, 1.6158875171095133, 0.06187829174450599, 0.5331817490514368, 0.5111245857551694, 0.21678914374206215, 0.11911826441064477, 0.06920682193594985, 0.1298186238273047, 0.013394951984082581, 0.060254713825997896, 0.04738327188533731, 0.018003202021645848, 0.08627427407191135, 0.052002695883857086, 0.01689119206275791, 0.1292853758786805, 0.0639888781006448, 0.04000580818683375, 0.030300603866635356, 0.058268730354029685, 0.06488556318799965, 0.03545842075254768, 0.019957289841840975, 0.058519164376775734, 0.076198261231184, 0.04037797298224177, 0.08472547866404057, 0.06449044376495294, 0.060829269714304246, 0.01855434871686157, 0.01961548074177699, 0.01160347057520994, 0.04550371610093862, 0.03414784361666534, 0.03212934665498324, 0.022912076601642184, 0.10293067287420854, 0.03894801026035566, 0.09401188348419964, 0.05328130500856787, 0.13134013046510518, 0.03305322774394881, 0.011106231631856645, 0.042243828720529564, 0.018051938859571237, 0.014689727868244518, 0.1224268923397176, 0.03289598891569767, 0.09805518566281535, 0.013341489520826144, 0.027326406234351452, 0.04078431367815938, 0.0457628629374085, 0.06822481213021092, 0.014888858149788575, 0.04056932091771159, 0.05900559022848029, 0.037200571605353616, 0.05958667701634113, 0.03831355934380554, 0.01938489731401205, 0.05827284556289669, 0.05179763677006122, 0.03887556551489979, 0.07603515201481059, 0.03866230195853859, 0.08326289855176583, 0.009697276327642612, 0.10013471313868649, 0.04450830310815945, 0.04661038074118551, 0.11328639375278726, 0.020548406755551696, 0.034617136989254504, 0.023535254294984043, 0.033036536842701025, 0.009759422846400412, 0.04355644676252268, 0.05060364361270331, 0.10850157472305, 0.16329150268575177, 0.20151307282503694, 0.13401395495748147, 0.21538874076213688, 0.07550631984486245, 0.09283780585974455, 0.10521887743379921, 0.1297402975615114, 0.11439323279773816, 0.09089073690120131, 0.0736401004542131, 0.09786310300114565, 0.08089021532214247, 0.24192322161979973, 0.1030909619294107, 0.11458864770247601, 0.15401346929138526, 0.11841909450595267, 0.10534902045037597, 0.16182910068891943, 0.19994988717371598, 0.1032306341221556, 0.10443868726724759, 0.14958894811570644, 0.12429877431713976, 0.13844435394275934, 0.11229480282054283, 0.16314638312906027, 0.16962047870038077, 0.08609690819866955, 0.18174355005612597, 0.15991861961083487, 0.14588741236366332, 0.20005512371426448, 0.19427555962465703, 0.13109381165122613, 0.19482354662613943, 0.24872320907888934, 0.2010302315466106, 0.1780319062527269, 0.14780855068238452, 0.17624098516535014, 0.12913856422528625, 0.17737123154802248, 0.3011168312514201, 0.1570753479609266, 0.1901946825091727, 0.1041405442811083, 0.1590374083025381, 0.123958729673177, 0.18210466427262872, 0.19425786682404578, 0.09083098659175448, 0.11408418024075218, 0.2113886093138717, 0.20849776599789038, 0.23059864179231226, 0.10330501216230914, 0.26695351756643504, 0.13025171152548864, 0.16626340337097645, 0.29251985193695873, 0.14687546325149015, 0.17386054649250582, 0.2145769796334207, 0.1575382551527582, 0.21097251679748297, 0.2133455191506073, 0.561808462953195, 0.5572798184584826, 0.5550839519128203, 0.27520201401785016, 0.4698604327859357, 1.4624821487814188, 5.124794505536556, 4.747518924996257, 14.322628453373909, 31.096034198999405, 50.903987511992455, 52.846739664673805, 51.18922680616379, 68.7212884426117, 71.91627860069275, 74.03341859579086, 62.86757715046406, 45.77699102461338, 51.036706790328026, 57.67728365957737, 53.54717127978802, 59.95063327252865, 44.21484924852848, 39.37341123819351, 33.12077455222607, 27.850263565778732, 12.962313797324896, 11.148114446550608, 1.901122536510229, 0.11623427111771889, 0.7710524881258607, 0.9408023825380951, 0.5829527252353728, 0.26573274401016533, 0.12257381531526335, 0.2268362499307841, 0.11886689899256453, 0.14967904484365135, 0.1922547211870551, 0.21652275725500658, 0.29033205995801836, 0.22476775076938793, 0.11203465037397109, 0.3091541718458757, 0.1152238147915341, 0.13050729234237224, 0.15273865254130214, 0.2184971669339575, 0.16564298275625333, 0.22812320821685717, 0.20052913343533874, 0.20842258643824607, 0.24871621804777533, 0.12462281825719401, 0.21284741931594908, 0.10895366140175611, 0.1581684869597666, 0.1048718937090598, 0.2116022736299783, 0.1000873270095326, 0.09535256584058516, 0.19907648325897753, 0.11331598318065517, 0.1848820035229437, 0.24642097792821005, 0.1322390791028738, 0.19613459502579644, 0.16064332681708038, 0.18711937096668407, 0.09351661123218946, 0.043422355520306155, 0.29182134254369885, 0.1120541688578669, 0.16106169030535966, 0.2029481192585081, 0.18400468106847256, 0.13014264550292864, 0.11445644151535816, 0.12700935738394037, 0.09406261669937521, 0.17452631233027205, 0.15852666227146983, 0.13872905663447455, 0.14356253086589277, 0.20799230405827984, 0.08986886634374969, 0.1835183665389195, 0.09061551885679364, 0.15110724867554381, 0.16281629068544134, 0.1459975916077383, 0.13280695566209033, 0.11532695847563446, 0.10871212944039144, 0.23850659636082128, 0.09447161428397521, 0.15467595483642071, 0.20670038822572678, 0.1232561087817885, 0.24815484270220622, 0.15608550107572228, 0.13705302000744268, 0.12617074535228312, 0.17312932322965935, 0.11500007210997865, 0.08836411740048788, 0.17008286638883874], [0.02381009569944581, 0.030256041609391104, 0.005438701227831189, 0.04294837919587735, 0.04687612898123916, 0.022213813972484786, 0.03064211425225949, 0.05854213384736795, 0.04027246555779129, 0.03804708379902877, 0.03542482743796427, 0.043288089873385616, 0.032393677392974496, 0.03595933332690038, 0.045085018646204844, 0.07986786979017779, 0.011724239338946063, 0.0019041716632273165, 0.07191384269390255, 0.045447309166775085, 0.011384794906916795, 0.017221759480889887, 0.02016086466028355, 0.0455249452352291, 0.018106251081917435, 0.04633575270418078, 0.013120891690050485, 0.05238208919763565, 0.035066700365860015, 0.02698071941267699, 0.01958041055331705, 0.038946214262978174, 0.062497933104168624, 0.043386862307670526, 0.056245301821036264, 0.08459768825559877, 0.03561546662240289, 0.059795613851747476, 0.13303296931553632, 0.004366745442894171, 0.006081264746171655, 0.04611335330992006, 0.045049169202684425, 0.013763987699348945, 0.06022161403961945, 0.027493589841469657, 0.0749401502253022, 0.021778535083285533, 0.014737878409505356, 0.018577845112304203, 0.020368855257402174, 0.07376113731879741, 0.043421746959211305, 0.01586507642059587, 0.04243011149810627, 0.03519223093462642, 0.026592754293233156, 0.06879695603856817, 0.03619371840613894, 0.17122624878538772, 0.008506439153279644, 0.06286545947659761, 0.17816197505453601, 0.06679235579213127, 0.13793630932923406, 0.30657443683594465, 0.12373346558888443, 0.2605150896124542, 1.603661198168993, 7.19167317263782, 16.02033745497465, 21.5684824436903, 34.306782111525536, 65.82396671175957, 72.8069432079792, 88.17257389426231, 96.85686349868774, 97.20582917332649, 118.34240779280663, 120.56930869817734, 114.17727649211884, 131.36161118745804, 125.6036813557148, 124.1827704012394, 127.6476600766182, 123.53176653385162, 131.52285933494568, 130.02577006816864, 136.89384073019028, 132.47327953577042, 132.50968158245087, 129.1065689921379, 128.33311289548874, 133.29938560724258, 128.46706330776215, 125.07945388555527, 117.7656215429306, 93.446554094553, 54.48869235813618, 23.685303255915642, 10.571680627763271, 2.720185210928321, 0.5644326377660036, 0.2911275828955695, 0.5569028668105602, 0.5254565260838717, 0.054442669643322006, 0.0560591860266868, 0.04994980037736241, 0.08311804616823792, 0.01737886472255923, 0.12542997807031497, 0.21137471630936489, 0.03230819682357833, 0.04480049778067041, 0.014986597143433755, 0.017647601962380577, 0.058023138844873756, 0.033269678824581206, 0.027825365104945377, 0.03984553397458512, 0.10067458846606314, 0.0034418425093463156, 0.018210769594588783, 0.05400082089181524, 0.08717650300241075, 0.040711115652811714, 0.02805028223519912, 0.09077552589587867, 0.03486263201921247, 0.025849387639027555, 0.011547952362889191, 0.0065838967839226825, 0.018630151680554263, 0.03981854206358548, 0.047435541346203536, 0.05189322539081331, 0.04730891982035246, 0.08307132055051625, 0.027889512639376335, 0.06499515613541007, 0.06341784741380252, 0.04314010562666226, 0.019062020401179325, 0.04244316587573849, 0.052498951481538825, 0.03856931085465476, 0.007427101782013779, 0.009693872652860591, 0.04793076164787635, 0.09986139499233104, 0.0681152859760914, 0.034048481174977496, 0.07232153409859166, 0.05830120302562136, 0.026044438891403843, 0.05533078663574997, 0.029725062777288258, 0.02199842045229161, 0.038127514053485356, 0.01690266752120806, 0.022558215023309458, 0.059334851466701366, 0.03058316360693425, 0.012586153879965423, 0.031450656315428205, 0.026532586525718216, 0.022195785350049846, 0.01117846022680169, 0.03367688041180372, 0.03567540246876888, 0.05009907967178151, 0.08696378121385351, 0.03440801832766738, 0.03993052843725309, 0.013620641875604633, 0.05107213917654008, 0.015200117668427993, 0.0433196088852128, 0.01460525847505778, 0.03278041425801348, 0.011246464146097424, 0.05070545885246247, 0.025230800129065756, 0.040152248766389675, 0.05216840632783715, 0.055565179136465304, 0.024758224608376622, 0.02075823416817002, 0.037759048864245415, 0.020270290624466725, 0.03884933059453033, 0.01710108441329794, 0.05275362687825691, 0.06996463635005057, 0.08141239784890786, 0.04606621580023784, 0.019554941900423728, 0.029275699780555442, 0.03392035680008121, 0.023028543691907544, 0.027290883335808758, 0.015404485657199984, 0.08703060419065878, 0.05106427983264439, 0.04998046220862307, 0.024524397995264735, 0.06515530418255366, 0.06301748842815869, 0.013035056745138718, 0.018802576705638785, 0.03768318652873859, 0.04320342566643376, 0.057919360624509864, 0.07312474568607286, 0.012102617765776813, 0.03621754876803607, 0.0023857450287323445, 0.04376704600872472, 0.035080723246210255, 0.014510623514070176, 0.04668442110414617, 0.06085465858632233, 0.03924135155102704, 0.023327076305577066, 0.04035771977214608, 0.033705434543662705, 0.09760757413459942, 0.049219686625292525, 0.01396333784214221, 0.09368827741127461, 0.053567299037240446, 0.021634254153468646, 0.06145730476418976, 0.06225934004760347, 0.14261869713664055, 0.0532374106842326, 0.048314466839656234, 0.14400456886505708, 0.08837254077661783, 0.15783012699102983, 0.40285842027515173, 0.1999396603787318, 0.6400017358828336, 2.9140201723203063, 10.266441106796265, 22.19406757503748, 28.47675684839487, 44.52040985226631, 85.48225745558739, 92.51447930932045, 107.25344762206078, 116.48376032710075, 121.36115580797195, 142.21454322338104, 148.28809171915054, 136.72394424676895, 150.90719997882843, 156.37612491846085, 145.152028799057, 150.3220921754837, 153.130202293396, 153.34539234638214, 155.08006006479263, 159.69583958387375, 156.51951402425766, 155.86447477340698, 154.33259457349777, 149.8669221997261, 160.29515862464905, 153.98093104362488, 152.86613166332245, 144.9778613448143, 119.60258737206459, 75.96369221806526, 36.372423470020294, 17.394453920423985, 6.078770840540528, 1.355738751590252, 0.08932027078117244, 0.4412111279089004, 0.5439188447780907, 0.09379485723911785, 0.06853133396361955, 0.05808005043945741, 0.07179028252721764, 0.044911734585184604, 0.10850329650565982, 0.28097420115955174, 0.02765486224234337, 0.10086737616802566, 0.0445547689741943, 0.045744680319330655, 0.10257262372761033, 0.0336015487118857, 0.011495287708385149, 0.040406694097328, 0.05793917596747633, 0.02478803482517833, 0.042314314196119085, 0.03340910239785444, 0.043534980140975676, 0.030180854628270026, 0.0300529380547232, 0.06132408925623167, 0.02216055003373185, 0.011810374853666872, 0.04769528561155312, 0.017117211282311473, 0.08643813285743818, 0.0779735972173512, 0.04866721705184318, 0.014061309684620937, 0.08400209990213625, 0.044841434646514244, 0.026300440877093934, 0.011805735503003234, 0.05501885825651698, 0.01389327910146676, 0.04495700188272167, 0.05272373316984158, 0.05664544187311549, 0.0546802570897853, 0.04679641861002892, 0.021201799136179034, 0.041736808270798065, 0.035353996863705106, 0.06431171233998612, 0.04168844621744938, 0.04937570462061558, 0.03243368657422252, 0.020747532398672774, 0.026397402471047826, 0.03038679133169353, 0.0715178030077368, 0.036376624411786906, 0.022820384256192483, 0.020712028053821996, 0.03355201035446953, 0.04650285096431617, 0.03566499384760391, 0.02780755727144424, 0.023700359888607636, 0.059592321049422026, 0.040848906501196325, 0.09164069197140634, 0.04699870209151413, 0.06619134976062924, 0.15713872737251222, 0.015141712501645088, 0.09125704615144059, 0.04635769430024084, 0.08678387719555758, 0.13493684527929872, 0.17704755126032978, 0.18210368463769555, 0.07018857941147871, 0.10504776044399478, 0.1419198018265888, 0.2698543353471905, 0.11110921448562294, 0.16891885228687897, 0.1206134915992152, 0.3049172507598996, 0.11838037666166201, 0.1630195352481678, 0.11930901862797327, 0.15200159599771723, 0.11667774146189913, 0.14127082336926833, 0.13339957542484626, 0.19746663136174902, 0.14629881450673565, 0.14122277672868222, 0.06293793019722216, 0.14017024805070832, 0.12610372941708192, 0.16252195491688326, 0.06857561791548505, 0.1823374759987928, 0.18213789764558896, 0.16275789850624278, 0.12881705100880936, 0.13912785710999742, 0.16568917402764782, 0.10902062538661994, 0.10114175558555871, 0.15797349507920444, 0.15878684440394863, 0.14236344286473468, 0.2210220869164914, 0.08955216224421747, 0.09064510086318478, 0.2053076442098245, 0.09664754674304277, 0.10888717239140533, 0.16363474598620087, 0.1701930901617743, 0.1624906511278823, 0.14313368825241923, 0.13952220469946042, 0.12369238029350527, 0.15910972317215055, 0.1647573779337108, 0.2550501812947914, 0.2229933498892933, 0.10050367927760817, 0.11892883863765746, 0.0855930641409941, 0.17397571296896785, 0.11057860116125084, 0.4085283988388255, 0.18165980611229315, 0.15060396865010262, 0.3799061378231272, 0.19597074366174638, 0.3391054709209129, 0.5554815649520606, 0.3642404096899554, 0.7989972573705018, 3.4968711342662573, 12.33811179175973, 26.49693388491869, 34.86124835908413, 55.385003462433815, 96.6719426214695, 105.16700237989426, 125.35598784685135, 133.61387193202972, 135.56338012218475, 154.39561039209366, 160.35961836576462, 151.2022465467453, 169.30389761924744, 163.03055584430695, 157.02432453632355, 162.63061970472336, 159.6398001909256, 169.4288957118988, 169.0083646774292, 175.81194519996643, 172.76114970445633, 170.760617852211, 167.9610800743103, 171.2301206588745, 176.82694673538208, 170.58599442243576, 167.41199433803558, 163.23247700929642, 133.81703943014145, 82.15255692601204, 39.54751789569855, 19.203734435141087, 7.449574358761311, 1.9020788976922631, 0.22897489689057693, 0.6455131026450545, 0.6807761010713875, 0.21832187165273353, 0.18514251220040023, 0.10810952779138461, 0.162578847957775, 0.15539739659288898, 0.3575487609487027, 0.4660792794311419, 0.15509356133406982, 0.28158786823041737, 0.17693211761070415, 0.12171860886155628, 0.19481542753055692, 0.06031129516486544, 0.15413285116665065, 0.13558070291765034, 0.1771303007262759, 0.11859435267979279, 0.13106641155900434, 0.11025949992472306, 0.20537314616376534, 0.16033085295930505, 0.196446044719778, 0.2391290059313178, 0.14039243222214282, 0.09273069168557413, 0.13751996448263526, 0.08394938515266404, 0.12399308368912898, 0.29710941191297024, 0.11341727149556391, 0.17718156828777865, 0.17491700855316594, 0.19320535298902541, 0.08083801265456714, 0.14455831493251026, 0.25781943113543093, 0.1981601832085289, 0.13641771191032603, 0.06993167015025392, 0.14317232446046546, 0.18980647990247235, 0.11698628193698823, 0.1026568203815259, 0.13506312912795693, 0.2860025782138109, 0.17256839317269623, 0.14713383454363793, 0.11856847399030812, 0.18601180461701006, 0.09433774568606168, 0.24981242953799665, 0.2426682339864783, 0.146052673808299, 0.13245802751043811, 0.09472462726989761, 0.08466647050227039, 0.13145924516720697, 0.13138356094714254, 0.09382521850056946, 0.2203239337541163, 0.09802016371395439, 0.16705805057426915, 0.15232595906127244, 0.19728836748981848, 0.14715649973368272, 0.1699653101968579, 0.24022848287131637, 0.14612602768465877, 0.18105458468198776, 0.09546333880280145], [0.0484389435587218, 0.006126236576164956, 0.031221173121593893, 0.020048729857080616, 0.014421564865187975, 0.02439003401377704, 0.03469741510343738, 0.025275631414842792, 0.04946129280142486, 0.043386379911680706, 0.035594630826381035, 0.06965037391637452, 0.03364931333635468, 0.04274516802979633, 0.040655161428730935, 0.023315727012231946, 0.05948851685388945, 0.04381295897474047, 0.1518123780260794, 0.021516892775252927, 0.018420274172967765, 0.0758925334957894, 0.008400636725127697, 0.038997500378172845, 0.03384157411346678, 0.01434857927961275, 0.02561799712566426, 0.03615670379076619, 0.01834629689255962, 0.07064132660161704, 0.051705770019907504, 0.10431907532620244, 0.011271635012235492, 0.02781966726615792, 0.08987150838947855, 0.0414697352971416, 0.08792878841632046, 0.013088713094475679, 0.06994620140176266, 0.0164012372988509, 0.0483945037558442, 0.02161581549444236, 0.020421657209226396, 0.04822253329621162, 0.028810809199057985, 0.022078205038269516, 0.09006709398818202, 0.08963498592493124, 0.029153989416954573, 0.05333824628905859, 0.03641077804786619, 0.02936293552920688, 0.02215798776887823, 0.053975639821146615, 0.0193456247143331, 0.07041319040581584, 0.037190196380834095, 0.09134079751675017, 0.022391929414879996, 0.20429219322977588, 0.01709105428744806, 0.2966012782417238, 0.503717833198607, 0.22324357239995152, 3.1081728916615248, 8.347743563354015, 34.588005021214485, 52.761749625205994, 76.42278358340263, 91.30469262599945, 111.41829773783684, 110.16563415527344, 110.17698794603348, 96.22498780488968, 102.94034466147423, 96.47568315267563, 84.00608986616135, 82.97000706195831, 79.5549251139164, 64.78693395853043, 75.88923901319504, 76.6878953576088, 55.37994593381882, 67.06941828131676, 68.74308407306671, 67.64781564474106, 72.71390900015831, 74.17198196053505, 84.47791814804077, 79.43536072969437, 89.78459179401398, 93.75376001000404, 83.01521703600883, 94.65586200356483, 94.08590018749237, 97.98864796757698, 104.69967305660248, 113.8999217748642, 122.82172903418541, 130.65519869327545, 112.92384535074234, 108.08550417423248, 82.35409811139107, 52.006988525390625, 27.505910843610764, 11.024203095585108, 2.046189489774406, 0.28747701784595847, 0.32006041787099093, 0.4178526235045865, 0.031610362784704193, 0.11008211178705096, 0.10239178460324183, 0.0692298285139259, 0.0997735840792302, 0.05027651604905259, 0.017747506171872374, 0.09455964041990228, 0.013155793039913988, 0.037509876492549665, 0.03821586673439015, 0.05472047778312117, 0.013741842012677807, 0.0026586802732708747, 0.07774402867653407, 0.015360082034021616, 0.031647982250433415, 0.039521356447949074, 0.05374240136006847, 0.035217011245549656, 0.018305599369341508, 0.03057471796637401, 0.061968603695277125, 0.03915853529179003, 0.05405179530498572, 0.06139894969237503, 0.01133062833105214, 0.022652749794360716, 0.07875363153289072, 0.030580872225982603, 0.031092254648683593, 0.09450003111851402, 0.0343447168415878, 0.03524869724060409, 0.07788056158460677, 0.09920765936840326, 0.004845393586947466, 0.05033888985053636, 0.03813012641330715, 0.034251417746418156, 0.04760856936627533, 0.01776177767169429, 0.040384782187175006, 0.08739198558032513, 0.04598731436999515, 0.018004612102231476, 0.025044936664926354, 0.0805781051167287, 0.0035073764684057096, 0.012911347221233882, 0.020861279517703224, 0.04236800115904771, 0.034146585676353425, 0.07785857917042449, 0.0816353019035887, 0.031975900201359764, 0.03616372821852565, 0.0684277672553435, 0.030208935640985146, 0.03174174518790096, 0.0506695537478663, 0.09997982691857032, 0.011848575977637665, 0.01733443234115839, 0.021308432769728824, 0.041187600436387584, 0.01786728695151396, 0.017190620819746982, 0.040498746384400874, 0.02575418122432893, 0.03034783228940796, 0.01979255161131732, 0.066849694121629, 0.01742589276545914, 0.04632591924746521, 0.05407390388427302, 0.03909355655196123, 0.022845300009066705, 0.03126537543721497, 0.0458973141212482, 0.026566497108433396, 0.024893412373785395, 0.05981729940685909, 0.03170562857121695, 0.10081135886139236, 0.037290586697054096, 0.03454474048339762, 0.015674140377086587, 0.03216320343199186, 0.03794592907070182, 0.06186895552673377, 0.026198041196039412, 0.021519763031392358, 0.023420477446052246, 0.03557342024578247, 0.01743657969200285, 0.040611690128571354, 0.09148022480076179, 0.05927705300564412, 0.0037604110229949583, 0.030436717461270746, 0.02353982035856461, 0.05262186226900667, 0.0379262139176717, 0.050313256069784984, 0.030069100175751373, 0.04150409673457034, 0.05144437818671577, 0.046921195898903534, 0.056289426211151294, 0.05124777955643367, 0.05459328480355907, 0.05524526153749321, 0.05222744417551439, 0.000769229399111282, 0.016921839051065035, 0.02711049692152301, 0.027689138332789298, 0.06267736956942827, 0.08787562837824225, 0.02477879879734246, 0.12711793358903378, 0.038284396650851704, 0.10001417351304553, 0.01948173088749172, 0.24410264217294753, 0.01699787208053749, 0.214786458236631, 0.4015124909346923, 0.7114388525951654, 5.003689778968692, 14.429388474673033, 47.47887410223484, 68.73967185616493, 91.15854486823082, 111.81124225258827, 133.67513984441757, 137.08889186382294, 130.76673030853271, 117.52480566501617, 120.89123502373695, 126.66570916771889, 105.40333449840546, 107.47885152697563, 109.8268823325634, 103.28690886497498, 109.90660205483437, 108.54491472244263, 90.13472780585289, 108.54169249534607, 94.08823326230049, 97.26047024130821, 108.28547224402428, 96.04885965585709, 105.1082119345665, 103.08706998825073, 118.13945308327675, 116.35308533906937, 109.6307672560215, 118.66156786680222, 119.67920646071434, 114.26045402884483, 121.45495757460594, 129.94019865989685, 142.63407111167908, 155.2678307890892, 136.66050285100937, 134.02412831783295, 110.33003613352776, 74.1474124789238, 45.35443849861622, 20.058242082595825, 4.942208603024483, 0.3411533235339448, 0.1765054272254929, 0.5315090075600892, 0.09563478975906037, 0.09232798751327209, 0.22077490721130744, 0.020745281835843343, 0.06677568715531379, 0.04363835018011741, 0.07634141409653239, 0.05974086561764125, 0.04721052588138264, 0.06626520087593235, 0.03675475607451517, 0.0725568320194725, 0.009233317141479347, 0.04980033183528576, 0.0013408880704446346, 0.027476457362354267, 0.03851337147352751, 0.06519043745356612, 0.015949840817484073, 0.0527557531313505, 0.025285299743700307, 0.003135391179966973, 0.13496359228156507, 0.04479393348447047, 0.022190607014636043, 0.03428571981203277, 0.061297112188185565, 0.01610105340660084, 0.07581218858831562, 0.010400010396551806, 0.037472360927495174, 0.050263498778804205, 0.049367529863957316, 0.034872253963840194, 0.04605782582075335, 0.03185897854564246, 0.008762267661950318, 0.014169239293551072, 0.08409400747041218, 0.08773356646997854, 0.03666967255412601, 0.015017720961623127, 0.026509576237003785, 0.018003625045821536, 0.08755719507462345, 0.037607936465064995, 0.012828175658796681, 0.10234649133053608, 0.020637798443203792, 0.03855661641864572, 0.05002266443625558, 0.0018828540510185121, 0.005985317111480981, 0.054186643537832424, 0.05416480955318548, 0.016209857822104823, 0.03791077353525907, 0.14526485436363146, 0.05803892432595603, 0.07055543785099871, 0.016266606144199613, 0.01737107588269282, 0.05786175883258693, 0.04450852575246245, 0.05419300745415967, 0.05838993420184124, 0.15352022310253233, 0.08604397822637111, 0.17501175112556666, 0.1404573256149888, 0.0922630941204261, 0.1602867545443587, 0.13946792401839048, 0.06470157735748217, 0.19222904287744313, 0.11803677713032812, 0.1484452688600868, 0.1412645447999239, 0.14855601213639602, 0.15707576356362551, 0.16921485046623275, 0.1610031645395793, 0.22041472810087726, 0.1590683261747472, 0.23981777834706008, 0.0805131449305918, 0.07744020826066844, 0.17138741357484832, 0.13005765475099906, 0.12764600134687498, 0.11283835920039564, 0.0894781255919952, 0.21185531630180776, 0.08992743663839065, 0.15605493943439797, 0.16739418409997597, 0.19414375419728458, 0.23182161210570484, 0.18543583864811808, 0.17451716907089576, 0.15969398635206744, 0.1321862530312501, 0.11114952794741839, 0.09706070035463199, 0.21036052698036656, 0.11232598786591552, 0.12484255334129557, 0.14044816751265898, 0.13463177805533633, 0.13117057940689847, 0.12315347717958502, 0.13678556482773274, 0.174421283591073, 0.13826282462105155, 0.15532319666817784, 0.23044577421387658, 0.13926024141255766, 0.2424943636287935, 0.14636994194006547, 0.21659055986674502, 0.11705170967616141, 0.19783522642683238, 0.1297301598242484, 0.19640684447949752, 0.09118995600147173, 0.33376625273376703, 0.12672406097408384, 0.4076137760421261, 0.558695598738268, 0.8972805272787809, 6.38182120397687, 16.066793762147427, 53.73592995107174, 77.34931066632271, 105.53026288747787, 124.36262235045433, 147.23092764616013, 144.14731711149216, 141.6738474369049, 124.62402552366257, 132.5270238518715, 126.79088205099106, 111.69323578476906, 112.49315366148949, 108.85769873857498, 89.07550424337387, 105.07171869277954, 104.77485582232475, 81.33185416460037, 91.66773274540901, 94.4266203045845, 94.61854800581932, 103.59148532152176, 104.10957992076874, 110.09141653776169, 105.66186502575874, 117.22200751304626, 119.79497104883194, 111.32090136408806, 117.98353224992752, 122.12021827697754, 124.30459946393967, 131.09740376472473, 143.18833976984024, 161.00993067026138, 171.567724943161, 155.24556398391724, 146.0465919971466, 121.13423958420753, 81.30137979984283, 48.05021144449711, 21.646672748029232, 5.089227939024568, 0.39603063196409494, 0.3369538957485929, 0.6615507358219475, 0.15429725171998143, 0.2818473824299872, 0.34552095166873187, 0.13258478633360937, 0.18221246864413843, 0.17724990524584427, 0.12523608456831425, 0.14855961897410452, 0.1382074158755131, 0.12567363999551162, 0.1936955118435435, 0.24920754949562252, 0.13147334597306326, 0.13544278219342232, 0.18187488050898537, 0.08257780718849972, 0.1456549865542911, 0.1402964279986918, 0.16803747770609334, 0.14593042724300176, 0.12305333919357508, 0.08963804357335903, 0.27485602477099746, 0.10623740832670592, 0.1715751620940864, 0.11383340111933649, 0.1366770183085464, 0.08313301528687589, 0.1356963740545325, 0.04333750948717352, 0.07395519409328699, 0.19203353149350733, 0.13292972173076123, 0.15404551522806287, 0.19044808141188696, 0.2830978122074157, 0.1316673879045993, 0.13274807366542518, 0.12048164164298214, 0.2201525866985321, 0.22244663938181475, 0.12113486518501304, 0.0870657894120086, 0.23432901740306988, 0.21553541882894933, 0.12949779338669032, 0.10192878093221225, 0.30743123148567975, 0.11719110727426596, 0.15593496384099126, 0.10290621168678626, 0.21738651324994862, 0.11287141445791349, 0.1450017184833996, 0.1484242660808377, 0.05988879049255047, 0.19782434654189274, 0.15008308488177136, 0.10414262971607968, 0.12471143068978563, 0.1558612537337467, 0.14658422966022044, 0.09055811373400502, 0.0899516826029867, 0.13014466414460912, 0.09600264267646708], [0.06400084152119234, 0.09719203080749139, 0.05108779849251732, 0.025998986056947615, 0.06312985700787976, 0.031094078476598952, 0.03621534830017481, 0.03546352301782463, 0.022228619818633888, 0.02561602301284438, 0.05286229956254829, 0.03263342448917683, 0.07181144115747884, 0.04613533201336395, 0.02678907461813651, 0.03319933435705025, 0.030184719362296164, 0.03868569074256811, 0.06740148091921583, 0.06087423644203227, 0.021003278343414422, 0.03020978911081329, 0.008064756457315525, 0.05996347281325143, 0.051601446321001276, 0.03441475702857133, 0.05177753570023924, 0.021768315709778108, 0.04418675278429873, 0.045957992115290835, 0.10938188061118126, 0.08397552359383553, 0.03620865412813146, 0.01663500639551785, 0.11616608258918859, 0.06165920975035988, 0.019212865627196152, 0.03817902281298302, 0.043311682748026215, 0.07802053063642234, 0.044110452581662685, 0.02116203115292592, 0.05198934093641583, 0.03629990118497517, 0.037573990630335175, 0.057550461278879084, 0.03903569871908985, 0.03039530747628305, 0.027216353155381512, 0.03659920934296679, 0.025274369763792492, 0.005279842662275769, 0.08357576574780978, 0.08561845301301219, 0.025543928932165727, 0.14928889781003818, 0.028648867009906098, 0.09642587465350516, 0.07537573153967969, 0.5112291988916695, 0.9450515045318753, 8.670667335391045, 23.013005331158638, 48.520497009158134, 80.84303319454193, 87.48497799038887, 100.40682300925255, 107.96450346708298, 85.91987237334251, 74.80495199561119, 66.65601566433907, 63.86838644742966, 52.913832664489746, 51.67127273976803, 55.81473000347614, 57.084048092365265, 74.43952560424805, 53.94676923751831, 68.38392734527588, 48.84390525519848, 48.15088704228401, 46.61621779203415, 73.88358503580093, 45.87423540651798, 69.77113410830498, 51.967440247535706, 47.3846011608839, 55.80031357705593, 64.9708440899849, 67.02747613191605, 52.57445767521858, 74.43500384688377, 68.75171720981598, 62.35268197953701, 61.090857088565826, 93.5918278992176, 73.98518398404121, 76.56209170818329, 70.1506881415844, 84.74812924861908, 103.13294872641563, 100.74169903993607, 110.02606764435768, 120.24777755141258, 112.45512530207634, 108.6961618065834, 95.88230699300766, 58.69003191590309, 34.44426633417606, 9.208431579172611, 0.5402135686017573, 0.4068770312005654, 0.6351254694163799, 0.03983726644946728, 0.012918825286760693, 0.062141932285157964, 0.09848995061474852, 0.050042223738273606, 0.03797301746089943, 0.061904304020572454, 0.013137272744643269, 0.03715551953064278, 0.05698972789105028, 0.04875755126704462, 0.034521199559094384, 0.012892389986518538, 0.019190998245903756, 0.10710788817959838, 0.019962553524237592, 0.06309526550467126, 0.03573241796402726, 0.0006492270767921582, 0.037241860991343856, 0.02411211269645719, 0.03331055260787252, 0.026746082003228366, 0.07461992092430592, 0.031011666687845718, 0.06300913926679641, 0.0855846110789571, 0.018473770032869652, 0.028892365662613884, 0.025432890652155038, 0.06412904753233306, 0.0678586216235999, 0.027179486969544087, 0.05096587476145942, 0.011974501740041887, 0.030477099571726285, 0.047263622836908326, 0.0207837566267699, 0.031722757339593954, 0.04940392107528169, 0.0617947184946388, 0.06996475509367883, 0.0686097789730411, 0.035308380756760016, 0.04176259048108477, 0.036867280505248345, 0.02411062097962713, 0.009276312539441278, 0.019051110830332618, 0.024845957595971413, 0.034895434946520254, 0.026462889582035132, 0.030515448197547812, 0.03317470989713911, 0.021496908593690023, 0.05582708305155393, 0.01040953307892778, 0.03508307956508361, 0.06755711670848541, 0.04072631483722944, 0.045060987904435024, 0.026825504792213906, 0.03781242041441146, 0.06439653981942683, 0.08066347436397336, 0.03105470197624527, 0.02267229796416359, 0.038187312602531165, 0.01543665312055964, 0.035106130671920255, 0.05586182298429776, 0.0169135474061477, 0.03841371588350739, 0.02818102639139397, 0.06132958114903886, 0.04257762077031657, 0.05664044350851327, 0.025452188347117044, 0.011510794884088682, 0.03870221094985027, 0.04372550429252442, 0.027568693330977112, 0.03812585535342805, 0.024080697585304733, 0.007847391607356258, 0.02041539719357388, 0.012473158185457578, 0.036939268829883076, 0.047359307936858386, 0.03740245432709344, 0.016877658999874257, 0.014496421590592945, 0.11777875464758836, 0.07798964987159707, 0.06431854752008803, 0.04056198107718956, 0.01095404682928347, 0.049977463932009414, 0.019332997071614955, 0.03573385030904319, 0.05365604505641386, 0.02723177498410223, 0.05603219411568716, 0.021696425719710533, 0.01598925442522159, 0.0477832635078812, 0.08171799199772067, 0.007148464756028261, 0.04200234128802549, 0.06807638259488158, 0.02533524442696944, 0.014161686085572, 0.03326134821691085, 0.03964979623560794, 0.10772654990432784, 0.11675113244564272, 0.06558649940416217, 0.00804695697297575, 0.04078477752045728, 0.03699182401760481, 0.11138976115034893, 0.030488999909721315, 0.45337691728491336, 1.558652613312006, 13.872140776365995, 34.562056213617325, 67.14895561337471, 96.07205361127853, 102.89832651615143, 117.21433192491531, 123.92061486840248, 115.44976741075516, 103.68271082639694, 102.36770778894424, 97.38397881388664, 83.12929451465607, 88.72476026415825, 100.59009477496147, 93.67384269833565, 104.61973294615746, 85.32835051417351, 107.35004603862762, 76.77818611264229, 81.10336482524872, 80.98421081900597, 95.07453873753548, 70.01776367425919, 105.72741150856018, 93.75556111335754, 84.02100026607513, 99.83392775058746, 109.52602967619896, 105.80930471420288, 101.93893119692802, 122.70954385399818, 111.40446648001671, 111.98833554983139, 98.34326013922691, 139.44073766469955, 121.5447087585926, 111.58212974667549, 111.00101172924042, 109.11250546574593, 131.84388130903244, 115.08633971214294, 123.29855024814606, 139.1345652937889, 137.0924636721611, 133.27559888362885, 125.33923834562302, 81.16448074579239, 52.149629071354866, 17.564048320055008, 1.3602345040999353, 0.12434125485015102, 0.6583454296924174, 0.0401289156434359, 0.01104138184018666, 0.02913184744102182, 0.08731837195227854, 0.05561850615777075, 0.05786051202449016, 0.07814407596015371, 0.01852419154602103, 0.01548882239148952, 0.03705475442984607, 0.016162692481884733, 0.040600891879876144, 0.01633969099202659, 0.010109926206496311, 0.06004155417031143, 0.030218642932595685, 0.014073104266572045, 0.06411278707673773, 0.019309773415443487, 0.030364912818185985, 0.036502834045677446, 0.021809740537719335, 0.048161747690755874, 0.010637975410645595, 0.046607920521637425, 0.019362527127668727, 0.0762305298121646, 0.052513159898808226, 0.02675452022231184, 0.05052721724496223, 0.027596984000410885, 0.06887388706672937, 0.050399096580804326, 0.020924098607792985, 0.045100306888343766, 0.03801207298238296, 0.019426040125836153, 0.020656610031437594, 0.012099881096219178, 0.11711314466083422, 0.039794296098989435, 0.039460329644498415, 0.009701688395580277, 0.03756640217034146, 0.011383276287233457, 0.025118225603364408, 0.0038331431187543785, 0.04037125654576812, 0.02598909879452549, 0.018917275629064534, 0.030314899486256763, 0.017207059390784707, 0.03486796063953079, 0.06570955491042696, 0.03368459132616408, 0.035121623004670255, 0.023422392187057994, 0.07843364714062773, 0.03910638086381368, 0.045348076600930654, 0.030377135990420356, 0.03407342104765121, 0.02620609349833103, 0.15676146402256563, 0.1903105911333114, 0.13914419920183718, 0.15239824424497783, 0.11182901609572582, 0.09552504838211462, 0.15087514941114932, 0.1109110981633421, 0.21330483461497352, 0.10566663739155047, 0.1349901017965749, 0.14260670403018594, 0.15220478118862957, 0.13595030730357394, 0.15757033077534288, 0.08509065984981135, 0.17472586099756882, 0.10775833608931862, 0.14185645210091025, 0.15323903819080442, 0.15311173017835245, 0.07416417545755394, 0.1771347684552893, 0.13516275503206998, 0.15225690964143723, 0.10275989727233537, 0.1635451687616296, 0.10420661768876016, 0.10325173338060267, 0.1307587171322666, 0.22052159736631438, 0.17630857997573912, 0.11358980598743074, 0.1219446596223861, 0.15035742719192058, 0.20727581984829158, 0.08588284312281758, 0.09402045528986491, 0.16595057328231633, 0.17694819252938032, 0.19681463978486136, 0.11382878496078774, 0.13181314570829272, 0.24244694039225578, 0.17497921537142247, 0.16181078448425978, 0.209810892411042, 0.1189396962581668, 0.12505298189353198, 0.15504842391237617, 0.13459373556543142, 0.16479406971484423, 0.16967851464869455, 0.17695515387458727, 0.08839784059091471, 0.30310379806905985, 0.12240826443303376, 0.1821109131560661, 0.10000380571000278, 0.7505362015217543, 1.6975014377385378, 16.04721151292324, 38.83622646331787, 78.73570427298546, 110.04221677780151, 119.94626373052597, 131.9966635107994, 139.74925071001053, 113.03900957107544, 100.3554193675518, 91.95011839270592, 85.85811048746109, 77.24569782614708, 70.0646835565567, 79.79363590478897, 79.17455792427063, 106.2312188744545, 76.38446643948555, 95.05514457821846, 67.93647095561028, 66.41469061374664, 68.0057792365551, 103.5379309952259, 59.44420404732227, 98.00899967551231, 73.69188532233238, 68.36375042796135, 83.62958326935768, 93.52058932185173, 92.20691621303558, 74.45413202047348, 99.62291747331619, 96.11684560775757, 91.48134514689445, 88.64143833518028, 125.89680522680283, 110.54869920015335, 107.2990071773529, 99.50324669480324, 111.22068554162979, 129.34910237789154, 127.00859516859055, 136.84081077575684, 151.89782202243805, 152.92025595903397, 150.2527078986168, 137.45572417974472, 89.29378733038902, 58.745216354727745, 19.4318038970232, 1.2551651545800269, 0.5333522649016231, 0.9590913355350494, 0.1712932053487748, 0.09030075176269747, 0.2086543443147093, 0.34284648892935365, 0.16480070451507345, 0.22315873007755727, 0.1960040512494743, 0.0850887896376662, 0.18683169968426228, 0.1270190646755509, 0.13656541414093226, 0.09309309723903425, 0.128332398890052, 0.06225055672985036, 0.2731349546229467, 0.1117927918676287, 0.14314415253465995, 0.13918185577495024, 0.06806775883887894, 0.08756049021030776, 0.13232735014753416, 0.19301460619317368, 0.13619913457660004, 0.10655620528268628, 0.10602256399579346, 0.21030759700806811, 0.20248884859029204, 0.18633072031661868, 0.14658029627753422, 0.10247687183436938, 0.16579951654421166, 0.2265332904062234, 0.09704027645057067, 0.1588017912581563, 0.16414311714470387, 0.17711438908008859, 0.09451364952838048, 0.12066130817402154, 0.12428651403752156, 0.20822214719373733, 0.11095705194748007, 0.15939077449729666, 0.10965142122586258, 0.15524720074608922, 0.14110021846136078, 0.16529438114957884, 0.10895237748627551, 0.18701308057643473, 0.05293629910738673, 0.08136395787005313, 0.11599921068409458, 0.11214366444619372, 0.13892772956751287, 0.17487806064309552, 0.08441048150416464, 0.1042471760592889, 0.06763753583072685, 0.15450042206794024, 0.17328495159745216, 0.1295147291966714, 0.07603438760270365, 0.07689315636525862, 0.1804101630114019], [0.017789187040762044, 0.051731006751651876, 0.058363395000924356, 0.013633689759444678, 0.09852096496615559, 0.04531521801254712, 0.02493044925358845, 0.022472417185781524, 0.02303826026036404, 0.08168636166374199, 0.05476444261148572, 0.05641399198793806, 0.05520255464944057, 0.030453358267550357, 0.05423762537247967, 0.017089761095121503, 0.04895140395092312, 0.06063728353183251, 0.019995002076029778, 0.021850608754903078, 0.02979388584208209, 0.027729370158340316, 0.03579148178687319, 0.06737003612215631, 0.1285033451858908, 0.06311892517260276, 0.03892885913955979, 0.01550752172988723, 0.05179011139262002, 0.06282280824962072, 0.02926480505266227, 0.04630980722140521, 0.030869044458086137, 0.05106478449306451, 0.020642275449063163, 0.09480745837208815, 0.045768425334244967, 0.019224595271225553, 0.031699839819339104, 0.06357565769576468, 0.04580705412081443, 0.015588377791573294, 0.02532721438910812, 0.06057429374777712, 0.051398038485785946, 0.052066557691432536, 0.011605624658841407, 0.01394609033013694, 0.05198823142563924, 0.03558432239515241, 0.03958308829169255, 0.08257202585809864, 0.05758439227065537, 0.025758686060726177, 0.03339788854646031, 0.06445978564443067, 0.07803232336300425, 0.17809115932323039, 2.7528138225898147, 20.52068866789341, 56.95290572941303, 92.5591953098774, 88.88643398880959, 98.15932720899582, 79.55130010843277, 68.3287163078785, 69.38936099410057, 65.43337807059288, 47.803722470998764, 48.903455659747124, 59.83930304646492, 38.54021094739437, 39.667363464832306, 37.61138878762722, 46.186707839369774, 57.95221410691738, 58.67788016796112, 40.08662536740303, 53.92438463866711, 60.78004516661167, 54.483767822384834, 48.88970799744129, 47.89832979440689, 75.91611117124557, 28.87832310050726, 43.30354794859886, 43.15601326525211, 31.70958537608385, 26.916383877396584, 39.23872746527195, 54.47535127401352, 37.212896570563316, 43.956979885697365, 39.428990855813026, 47.34764814376831, 49.21894133090973, 40.018852204084396, 61.75639517605305, 49.47336047887802, 77.88087174296379, 53.85163374245167, 86.17218643426895, 77.36615136265755, 71.43522441387177, 87.79009401798248, 84.46481645107269, 89.31530937552452, 104.69002157449722, 103.94597589969635, 101.42464399337769, 69.24090296030045, 43.097712993621826, 13.158595114946365, 0.7933198870159686, 0.2343583619222045, 0.2742406656034291, 0.05564170569414273, 0.05942844371020328, 0.03331760301080067, 0.019333453492436092, 0.04190208455838729, 0.041567620864952914, 0.03659560992673505, 0.17861830681795254, 0.03472837750450708, 0.025888855052471627, 0.025254482061427552, 0.06342670865706168, 0.015066978230606765, 0.05386792079661973, 0.03872725101246033, 0.10880926914978772, 0.06062555388780311, 0.02358418409130536, 0.050557047870825045, 0.04607557799317874, 0.04055389166751411, 0.06299474160186946, 0.012706728757621022, 0.10044244467280805, 0.030047045402170625, 0.013623820123029873, 0.006082754607632523, 0.06483394681708887, 0.02991253484651679, 0.053974307666067034, 0.14322081638965756, 0.08138668243191205, 0.0616516806621803, 0.02064000076643424, 0.028212163197167683, 0.00847530698592891, 0.06874222264741547, 0.026327032028348185, 0.06775434987503104, 0.0740764536021743, 0.03243858845962677, 0.03809300789725967, 0.029336364787013736, 0.05255462368950248, 0.04890299365797546, 0.05706427662516944, 0.015322823437600164, 0.02489815840817755, 0.06571569247171283, 0.03174618323100731, 0.0747334843617864, 0.05530301918042824, 0.0814392339088954, 0.01314983452175511, 0.03665632502816152, 0.028428003861336038, 0.04204849174129777, 0.03659094923932571, 0.0393975662154844, 0.03301891825685743, 0.05048772756708786, 0.10953752382192761, 0.03957836081099231, 0.03555202412826475, 0.10821099422173575, 0.0694254957488738, 0.060908920713700354, 0.03144937611068599, 0.029499997217499185, 0.06333956567686982, 0.006291613053690526, 0.02414974514977075, 0.03566037768905517, 0.0404085309128277, 0.023685394480708055, 0.021538372384384274, 0.04201716939860489, 0.009598836932127597, 0.04626235429896042, 0.028859508929599542, 0.021515408479899634, 0.04154566442593932, 0.08464722661301494, 0.012877804929303238, 0.10217535949777812, 0.0702425854979083, 0.00719804485925124, 0.02550456913013477, 0.05414180297520943, 0.05512683703273069, 0.037151719734538347, 0.044623050271184184, 0.019368755602044985, 0.03939824899134692, 0.022549511486431584, 0.006956559745958657, 0.055844490125309676, 0.07456923965946771, 0.01628799112950219, 0.0533341941627441, 0.1037699231528677, 0.029956239923194516, 0.07808874142938294, 0.03511358183459379, 0.04997454729164019, 0.050721793522825465, 0.04491220213822089, 0.05789829476270825, 0.08971881892648526, 0.03286257742729504, 0.029204269922047388, 0.024556228709116112, 0.03771824558498338, 0.10275687673129141, 0.01282547795199207, 0.06849885758128949, 0.09206036906107329, 0.09277062665205449, 5.073747569695115, 29.075581915676594, 76.43608286976814, 110.81967025995255, 106.09680488705635, 111.53346195816994, 94.6341347694397, 88.79858270287514, 94.36441004276276, 92.16391012072563, 69.37365263700485, 73.13797384500504, 74.73647966980934, 56.013865917921066, 56.70523501932621, 38.43665890395641, 46.13524340093136, 48.313525915145874, 60.551802814006805, 31.566999927163124, 43.14966380596161, 40.65262779593468, 25.962600857019424, 28.837670981884003, 34.824466332793236, 37.67393343150616, 23.148276172578335, 24.09222722053528, 20.86010355502367, 25.28667412698269, 25.965471602976322, 28.926443718373775, 40.41819177567959, 33.290484845638275, 44.03566986322403, 45.51367275416851, 48.083634451031685, 67.1016937494278, 59.530668407678604, 83.13510820269585, 75.27247130870819, 107.22001701593399, 94.71459925174713, 124.6239723265171, 116.42807051539421, 111.26564472913742, 110.00571593642235, 105.32381996512413, 101.99428662657738, 122.09767028689384, 119.79811728000641, 126.13793268799782, 94.4490011036396, 63.522882387042046, 23.2809042558074, 2.6262449892237782, 0.15488328121136874, 0.18985178059665486, 0.043645007244776934, 0.03644073112809565, 0.03368714802491013, 0.035395330778555945, 0.05412933860498015, 0.09307380139944144, 0.024175377075152937, 0.048166512278839946, 0.06075699195207562, 0.018396462364762556, 0.04108517663553357, 0.01658584653341677, 0.07201337954029441, 0.050971392629435286, 0.04771780608280096, 0.025875698629533872, 0.03858133735775482, 0.036048828915227205, 0.06250292775803246, 0.0959323909773957, 0.04566228708426934, 0.04346939655079041, 0.06713795912219211, 0.03809829941019416, 0.04667190478357952, 0.06744241778505966, 0.056493030715500936, 0.07795827928930521, 0.020911363353661727, 0.06999337230809033, 0.0027505382104209275, 0.01886935886432184, 0.05657213994709309, 0.005414200149971293, 0.08083864348009229, 0.07220408922876231, 0.12391082404064946, 0.0392880140861962, 0.0734852216555737, 0.08629915086203255, 0.007167995299823815, 0.04051430551044177, 0.06397350822226144, 0.04970006768417079, 0.05822940023790579, 0.09462969173910096, 0.017433128705306444, 0.07863725535571575, 0.04532849503448233, 0.036355287666083314, 0.0032417281863672542, 0.04645142013032455, 0.06308183263172396, 0.022335440844472032, 0.0245219266435015, 0.04876402279478498, 0.04298257736081723, 0.029961967447889037, 0.038624767839792185, 0.025243654126825277, 0.09663913820986636, 0.23347679438302293, 0.11660280681098811, 0.09713003179058433, 0.1641769293928519, 0.14110530959442258, 0.19435372261796147, 0.11523652778123505, 0.12438910111086443, 0.17549180192872882, 0.1478811475681141, 0.0911451005958952, 0.12279827045858838, 0.12744925799779594, 0.12858035042881966, 0.14271517633460462, 0.1723726443015039, 0.1602475839899853, 0.09509128532954492, 0.10631182347424328, 0.08962751249782741, 0.10873528444790281, 0.1588510550209321, 0.33529445354361087, 0.30020449426956475, 0.17218734486959875, 0.07549754023784772, 0.19086982909357175, 0.1381039753323421, 0.15759054687805474, 0.15067389380419627, 0.17702104174531996, 0.09739535700646229, 0.14006792072905228, 0.18294011475518346, 0.1191630530229304, 0.1620514184469357, 0.12742426246404648, 0.1541252515744418, 0.24604610429378226, 0.2712389751104638, 0.09003788305562921, 0.22751429089112207, 0.1586390085867606, 0.18471288291038945, 0.15766039781738073, 0.26210726355202496, 0.1844060345320031, 0.1435401922208257, 0.1616865786490962, 0.14542443095706403, 0.12340544373728335, 0.16296537331072614, 0.22362058341968805, 0.12531829968793318, 0.2867517911363393, 0.28946214413736016, 0.29193536611273885, 4.514127848669887, 32.88321129977703, 87.52309754490852, 125.90405523777008, 118.63870069384575, 125.17482876777649, 105.0207482278347, 94.29831638932228, 95.55574491620064, 88.41247022151947, 65.12539699673653, 69.88839581608772, 77.28595286607742, 56.38873100280762, 53.840732127428055, 48.11811380088329, 61.043865010142326, 81.62658914923668, 82.17607766389847, 62.09806904196739, 76.63620293140411, 89.68601748347282, 87.51271650195122, 78.6858357489109, 72.69667312502861, 119.30681124329567, 43.97242225706577, 65.84336087107658, 67.75020495057106, 50.08266918361187, 43.40100131928921, 59.31042082607746, 75.49408301711082, 51.85395173728466, 64.35434997081757, 56.6885919123888, 69.357138723135, 67.47573047876358, 58.17769780755043, 83.43651562929153, 71.32003739476204, 105.25856226682663, 80.22642508149147, 115.5952388048172, 108.08046564459801, 94.59783151745796, 109.2203588783741, 107.0212496817112, 113.09087678790092, 132.64027297496796, 136.43547892570496, 140.85116118192673, 104.17704150080681, 68.05369466543198, 24.61693536490202, 2.491772104986012, 0.2832923736423254, 0.5094222177285701, 0.18051507300697267, 0.1825565134640783, 0.12468466884456575, 0.14789364533498883, 0.14642655296484008, 0.17573418735992163, 0.08561204085708596, 0.3390839189523831, 0.1355297173722647, 0.12494860624428838, 0.15268253133399412, 0.13276539539219812, 0.15361763740656897, 0.19366739928955212, 0.1722966186935082, 0.17073870229069144, 0.1555798016488552, 0.1337752802646719, 0.10664835033821873, 0.26389147562440485, 0.09736227206303738, 0.11756991429137997, 0.0711921114998404, 0.22164837049786001, 0.1504244134412147, 0.12668716139160097, 0.2208199555752799, 0.09720195332192816, 0.1179025523015298, 0.09692911015008576, 0.1612979604396969, 0.17311320378212258, 0.1692517352057621, 0.0955306738615036, 0.10226371217868291, 0.13414311833912507, 0.23581868590554222, 0.12542889453470707, 0.15224426344502717, 0.23342905944446102, 0.10329936441848986, 0.11336644180119038, 0.16088899254100397, 0.12259156748768874, 0.12127227382734418, 0.17843150824774057, 0.1216630071576219, 0.12955505750142038, 0.1781622422276996, 0.16075038904091343, 0.11584997220779769, 0.1487870723940432, 0.14257105125579983, 0.10028280128608458, 0.13457599823595956, 0.093094789335737, 0.08173944748705253, 0.07053536275634542, 0.11167517630383372, 0.0634705250558909], [0.040597737752250396, 0.006895800579513889, 0.02935361600975739, 0.05105250937049277, 0.017127849969256204, 0.06506168967462145, 0.0414875060232589, 0.051472561244736426, 0.026572291426418815, 0.03030359286640305, 0.06309528776910156, 0.025486855920462403, 0.07278353587025777, 0.06504789314931259, 0.06770749067072757, 0.015412345001095673, 0.04595031088683754, 0.01578567775140982, 0.07657199937966652, 0.00963129476076574, 0.018001133284997195, 0.06534041807753965, 0.021244470772217028, 0.02142357512639137, 0.009639475083531579, 0.04054010998515878, 0.015856552854529582, 0.08387627618503757, 0.057444816557108425, 0.009813088472583331, 0.07132737533538602, 0.05716124192986172, 0.017511954065412283, 0.04530663136392832, 0.021173640197957866, 0.032152112034964375, 0.029948870396765415, 0.055321814070339315, 0.07293852599104866, 0.04110094356292393, 0.06270991274504922, 0.04893915851425845, 0.023763772696838714, 0.020358552392281126, 0.03958302520914003, 0.0338096320774639, 0.10096506506670266, 0.042466265222174115, 0.055004245368763804, 0.02748331295151729, 0.07803469823556952, 0.03300796415715013, 0.07764388326904736, 0.10051927922177128, 0.0371150353748817, 0.15489816869376227, 3.2241457561030984, 31.32075034081936, 74.66739937663078, 86.17652580142021, 79.04216542840004, 69.00576397776604, 78.14432680606842, 68.08753564953804, 79.72646310925484, 45.13041391968727, 56.194337233901024, 56.09390862286091, 58.45403417944908, 56.624280363321304, 65.67037895321846, 56.743415370583534, 59.85258713364601, 87.8370974957943, 92.70753175020218, 76.27901449799538, 55.36101534962654, 65.08229210972786, 87.25479394197464, 97.57069319486618, 81.64554253220558, 73.68151187896729, 72.41551101207733, 76.5933108329773, 91.85469031333923, 115.78124642372131, 88.20676445960999, 98.54410976171494, 101.28207564353943, 101.18630558252335, 130.79712867736816, 106.85465142130852, 91.56364873051643, 109.23966944217682, 80.17196640372276, 82.35346734523773, 86.06690928339958, 61.0404983907938, 58.26408997178078, 43.62493470311165, 45.346185341477394, 51.269033923745155, 37.52085484564304, 48.02309229969978, 52.35869765281677, 63.725985288619995, 71.80787041783333, 61.97431728243828, 77.96930819749832, 76.76290333271027, 90.15381038188934, 96.28491818904877, 100.27706757187843, 82.84087479114532, 49.08461093902588, 9.68119841068983, 0.43521104205865413, 0.21568592637777328, 0.165905584290158, 0.11052286587073468, 0.05929772181843873, 0.06358769533107989, 0.009887061114568496, 0.04972223934601061, 0.05750235155574046, 0.06833173334598541, 0.024151771212927997, 0.015510104403801961, 0.038038255952415057, 0.02828728152962867, 0.05905321755562909, 0.07427192045724951, 0.03342756332131103, 0.04238777939463034, 0.03883070639858488, 0.035053204410360195, 0.023294462625926826, 0.09833811462158337, 0.06558097040397115, 0.016846188227646053, 0.0875518293469213, 0.04962966013408732, 0.03781834646360949, 0.0599596062238561, 0.0702102055947762, 0.03331067877297755, 0.026499325322220102, 0.01321493571595056, 0.09533162243315019, 0.07861391481128521, 0.04038911632960662, 0.03892419103067368, 0.012467418600863311, 0.013079196905891877, 0.004726984388980782, 0.052917322391294874, 0.07288101696758531, 0.0533311179606244, 0.007768752248011879, 0.045142204835428856, 0.040958614481496625, 0.04844456161663402, 0.055595006051589735, 0.048643019326846115, 0.060118425826658495, 0.01721390384773258, 0.04111594978894573, 0.14263266435591504, 0.024763389956206083, 0.00688309222823591, 0.040831944716046564, 0.02738911956839729, 0.02961073121696245, 0.035302918549859896, 0.012968871087650768, 0.013927182262705173, 0.014256448139349231, 0.049249617441091686, 0.006064694907763624, 0.01707983115920797, 0.023334499637712725, 0.023870898003224283, 0.060205101253814064, 0.07354022964136675, 0.030267682195699308, 0.050081401714123785, 0.03172034535964485, 0.044350685784593225, 0.06144504077383317, 0.07837217504857108, 0.06124273131717928, 0.021697871052310802, 0.03771696538024116, 0.03683175760670565, 0.0368186438572593, 0.060325091690174304, 0.028133165287727024, 0.055008538693073206, 0.03189920666045509, 0.03669377008918673, 0.05123758615809493, 0.048401851017843, 0.04630220020771958, 0.01861414912127657, 0.01931503153173253, 0.03174545221554581, 0.015130014398891944, 0.03807584202149883, 0.03231817499909084, 0.046864210089552216, 0.05877660798432771, 0.03999981163360644, 0.044827560195699334, 0.06454739617765881, 0.049552495329407975, 0.03875502588925883, 0.058344733697595075, 0.028040587931172922, 0.023021845809125807, 0.04633599761291407, 0.05060834882897325, 0.03212742449250072, 0.058238331985194236, 0.024912428052630275, 0.015885615357547067, 0.05585401930147782, 0.08274332096334547, 0.02088091117911972, 0.1361113681923598, 0.07375945264357142, 0.06365897119394504, 0.08568187695345841, 6.47421894595027, 46.43814034759998, 93.01605999469757, 99.29048091173172, 93.08906927704811, 85.18731728196144, 99.16979938745499, 96.11521169543266, 106.55594944953918, 65.92735156416893, 66.99417471885681, 55.398903116583824, 45.00047229230404, 42.293565943837166, 44.37005952000618, 30.56215714663267, 33.61082665622234, 45.22428788244724, 55.89810512959957, 55.685719326138496, 48.424145579338074, 50.275976210832596, 63.95547777414322, 63.424722254276276, 70.25884553790092, 58.781762793660164, 54.740269258618355, 69.45949003100395, 59.89321455359459, 74.90421786904335, 60.073400884866714, 62.4078132212162, 56.12087197601795, 71.00000336766243, 74.32069078087807, 54.73048098385334, 51.769790053367615, 47.90564440190792, 47.18040391802788, 40.49794189631939, 41.470150128006935, 35.23940786719322, 30.656711272895336, 36.28020241856575, 28.08546334505081, 50.22198110818863, 46.56673684716225, 57.339109405875206, 83.17419290542603, 108.44048872590065, 125.6447571516037, 90.09998247027397, 105.83764359354973, 95.75419306755066, 100.85701525211334, 110.6564462184906, 121.6439214348793, 111.31808191537857, 69.42947164177895, 19.185949489474297, 0.5961829028092325, 0.08910066186217591, 0.2289805223699659, 0.11904131853953004, 0.05170648619241547, 0.08348534247488715, 0.04082517261849716, 0.05107521908939816, 0.023689253648626618, 0.023442914425686467, 0.025867048898362555, 0.03603309167374391, 0.00449865198788757, 0.026321087425458245, 0.03910700055712368, 0.06307280069449916, 0.02152317319996655, 0.05712457983463537, 0.04495105356909335, 0.014905112111591734, 0.0870766321895644, 0.03239658290112857, 0.04185938509181142, 0.02657019856997067, 0.03646295845101122, 0.03604778248700313, 0.013173047973396024, 0.009297328306274721, 0.06686774315312505, 0.044075475161662325, 0.05982675436825957, 0.010343007888877764, 0.05693845661880914, 0.038174080109456554, 0.013176274460420245, 0.026617232178978156, 0.015453160340257455, 0.02603530305350432, 0.04265671886969358, 0.13042120321188122, 0.07452721925801598, 0.028869522357126698, 0.035486403430695646, 0.056439588661305606, 0.06697328397422098, 0.08226122925407253, 0.04526654796791263, 0.04611699354427401, 0.056863718637032434, 0.029033217870164663, 0.03470078074315097, 0.037244246996124275, 0.01939687743288232, 0.033375779967173, 0.052260039301472716, 0.009619922275305726, 0.050158748344983906, 0.014218851865734905, 0.05087816774903331, 0.012222648092574673, 0.11103387165348977, 0.37418812746182084, 0.10144331245101057, 0.10594601146294735, 0.11386725047486834, 0.14398582221474499, 0.19910361617803574, 0.13259090163046494, 0.18297521834028885, 0.10391907999292016, 0.1460978706018068, 0.11256642144871876, 0.15522358560701832, 0.24520087230484933, 0.15185986063443124, 0.08489200918120332, 0.12405498622683808, 0.10857754095923156, 0.06352600801619701, 0.23356870195129886, 0.0707147918001283, 0.1440542927593924, 0.17724894045386463, 0.06325232621748, 0.1260736130643636, 0.17025958659360185, 0.16147932648891583, 0.09581741745932959, 0.10204252990661189, 0.10625165014062077, 0.18706194357946515, 0.12091815064195544, 0.13589911395683885, 0.24809793481836095, 0.18492626521037892, 0.1616747339721769, 0.2573244780069217, 0.10833562308107503, 0.15844648063648492, 0.1634760748129338, 0.19855527294566855, 0.12716890429146588, 0.2064916814561002, 0.1254152093315497, 0.1368347098468803, 0.10642227731295861, 0.24271691887406632, 0.15538209350779653, 0.15979284042259678, 0.13598852790892124, 0.18513608520152047, 0.11175732463016175, 0.1790040306514129, 0.23527218319941312, 0.2024914015782997, 0.2867673762375489, 6.265476671978831, 49.81470376253128, 105.92893749475479, 112.71341264247894, 103.71840611100197, 89.41590517759323, 102.11157113313675, 90.12284964323044, 104.76819097995758, 66.87010377645493, 82.8840708732605, 78.34249377250671, 80.64396947622299, 79.61974203586578, 92.37016305327415, 85.02888098359108, 86.28393083810806, 122.38605201244354, 134.64512139558792, 112.73735895752907, 84.33475703001022, 98.1023682653904, 127.75584787130356, 134.00652766227722, 121.71310812234879, 109.00114104151726, 107.58936479687691, 123.66936475038528, 131.89302027225494, 183.57916921377182, 131.14636033773422, 147.45692431926727, 142.6502886414528, 138.3806249499321, 185.08571237325668, 147.8795224428177, 126.44592136144638, 155.21008908748627, 111.80611252784729, 107.4364686012268, 121.28088891506195, 89.99959945678711, 84.8994143307209, 62.231407687067986, 61.28856047987938, 68.24147298932076, 53.11183623969555, 67.80865341424942, 75.98348155617714, 90.20045667886734, 103.62773537635803, 84.94767174124718, 105.39971709251404, 97.9945756494999, 115.46706408262253, 124.282416254282, 134.6701392531395, 120.7674452662468, 76.9376939535141, 20.486137121915817, 0.6383571960031986, 0.3134219959611073, 0.47816230449825525, 0.22706944757374004, 0.2011536358622834, 0.1633200456853956, 0.1990122874849476, 0.10726247011916712, 0.10704316548071802, 0.19869202107656747, 0.11747703450964764, 0.15678527212003246, 0.09965832854504697, 0.10263494186801836, 0.17100124445278198, 0.15362845791969448, 0.13517871120711789, 0.27645567955914885, 0.10960906685795635, 0.10192539673880674, 0.24062038137344643, 0.21930771094048396, 0.1453167898580432, 0.14576654619304463, 0.21520845824852586, 0.11661333788651973, 0.17002681939629838, 0.20576571259880438, 0.17956754338229075, 0.15933195187244564, 0.12108280352549627, 0.08502228578436188, 0.1206973468651995, 0.1403705240227282, 0.1426584762521088, 0.10533642620430328, 0.1393013118649833, 0.11128588274004869, 0.16284418059512973, 0.15977430157363415, 0.09939384937752038, 0.1604577898979187, 0.06755392547347583, 0.24685742013389245, 0.1313277069129981, 0.2481589838862419, 0.18605952471261844, 0.13446958910208195, 0.2163099538302049, 0.05184509340324439, 0.14173169707646593, 0.1544523605844006, 0.07801506842952222, 0.21972374408505857, 0.13244426809251308, 0.13388528139330447, 0.12401547428453341, 0.13789145392365754, 0.12284214622923173, 0.1171770658402238], [0.032429871935164556, 0.024991160644276533, 0.05230550326814409, 0.034596434779814444, 0.034106717503163964, 0.036203362615196966, 0.04576633989927359, 0.012608587148861261, 0.0649557555152569, 0.023911779207992367, 0.03217701851099264, 0.015466572804143652, 0.03145068229059689, 0.015764105373818893, 0.01722294691717252, 0.028459895802370738, 0.047801902546780184, 0.01983589489100268, 0.029896584237576462, 0.02967929824080784, 0.02683179820451187, 0.05437396903289482, 0.0338220927369548, 0.09784667185158469, 0.04461089018150233, 0.023571933088533115, 0.03871474211337045, 0.02689500877750106, 0.09994281601393595, 0.06404732965165749, 0.012597756431205198, 0.011756234252970899, 0.03167152688547503, 0.010412517440272495, 0.089958695898531, 0.017077612137654796, 0.04631584830349311, 0.03569494321709499, 0.03346524958033115, 0.01879562649264699, 0.11310009242151864, 0.059738579802797176, 0.02374911156948656, 0.029921451750851702, 0.0849484495120123, 0.026259414953528903, 0.013309126316016773, 0.04964701896824408, 0.055159536059363745, 0.06690032343612984, 0.09377740934723988, 0.045330487700994126, 0.16606125718681142, 0.047738649300299585, 5.25297730229795, 28.851198256015778, 66.03076681494713, 86.73581779003143, 67.00406938791275, 74.52861562371254, 65.65983831882477, 57.39383026957512, 44.45057339966297, 48.327873945236206, 48.80363121628761, 53.19404482841492, 66.08092412352562, 54.976027607917786, 50.00962570309639, 67.92839258909225, 64.76518392562866, 86.8766762316227, 76.10932320356369, 57.78062291443348, 41.030080541968346, 38.51996183395386, 34.51164811849594, 28.678527921438217, 32.60631635785103, 37.72709257900715, 24.088383726775646, 25.73311597108841, 24.554375521838665, 18.687326945364475, 19.41857110708952, 15.89967967942357, 20.437855012714863, 23.148732148110867, 32.52870552241802, 33.42299893498421, 41.26329302787781, 59.28465820848942, 65.39764478802681, 71.43780067563057, 59.507782235741615, 86.1429812014103, 101.94968461990356, 105.8187586069107, 102.95985281467438, 84.74328070878983, 95.24717107415199, 77.43633359670639, 72.29751974344254, 61.593129336833954, 45.761913433671, 38.428257554769516, 20.885653384029865, 48.17555531859398, 45.04608504474163, 53.494722694158554, 71.22960224747658, 76.39152646064758, 85.65140917897224, 82.11548611521721, 96.62601068615913, 93.39400291442871, 59.11319620907307, 29.051977582275867, 9.965630248188972, 0.8884045004379004, 0.17553149198647588, 0.31768649525474757, 0.07785093504935503, 0.0463616647903109, 0.10367140304879285, 0.05791963150841184, 0.03679443871078547, 0.07355027832090855, 0.011182247963006375, 0.05506899033207446, 0.04250116471666843, 0.042686026281444356, 0.05292140420351643, 0.04282013978809118, 0.018048552810796537, 0.052504161358228885, 0.08244135591667145, 0.0465605418139603, 0.04538805238553323, 0.08492027016473003, 0.008199551812140271, 0.034229750744998455, 0.04665682434279006, 0.09282400933443569, 0.024624079560453538, 0.06320939297438599, 0.0630057773378212, 0.03065031869482482, 0.05440769593406003, 0.029505939965019934, 0.08061838889261708, 0.01543250358736259, 0.03783825828577392, 0.019029898394364864, 0.006371973267960129, 0.0689542839245405, 0.05019605981942732, 0.01632916919334093, 0.006913229453857639, 0.033515166433062404, 0.02758924340014346, 0.015129076509765582, 0.00815247738501057, 0.015289358143490972, 0.08469416003208607, 0.034091997003997676, 0.02218492216343293, 0.016731008763599675, 0.05603466175671201, 0.023913489858387038, 0.10981776620610617, 0.06314455153187737, 0.05788615693745669, 0.04370451264549047, 0.054017801230656914, 0.01612023050256539, 0.05951020240900107, 0.0599602704460267, 0.056697184409131296, 0.022914829969522543, 0.04151133638515603, 0.028099692572141066, 0.025157398013107013, 0.026458115717105102, 0.06827205725130625, 0.021998995616741013, 0.0386712856561644, 0.07830728907720186, 0.017305557230429258, 0.050290958242840134, 0.027646052949421573, 0.0339032502961345, 0.0672314697294496, 0.015297989320970373, 0.009319183627667371, 0.007661870922675007, 0.031822023302083835, 0.04668284775107168, 0.035043333846260794, 0.03455052923527546, 0.10552326930337586, 0.05478188308188692, 0.04606031201547012, 0.019915746270271484, 0.04527668941591401, 0.09017580377985723, 0.033593785847187974, 0.04952846087689977, 0.015376032642961945, 0.08242490992415696, 0.05736605242418591, 0.016595154920651112, 0.13664360682014376, 0.05979361005302053, 0.04372714814962819, 0.02298871819220949, 0.1003240498539526, 0.00652319606160745, 0.02566050177847501, 0.01868420044047525, 0.057960034027928486, 0.05354201035515871, 0.07291745641850866, 0.058835964955505915, 0.05218871890974697, 0.0567484853672795, 0.12283390839002095, 0.08339589141542092, 0.09508516261121258, 0.1189448319200892, 9.188039973378181, 42.300793156027794, 85.21074682474136, 96.82496801018715, 77.92492657899857, 96.83746173977852, 97.0440262556076, 90.46597123146057, 70.45420065522194, 61.21841624379158, 51.49098761379719, 50.99207438528538, 56.07204459607601, 54.095527455210686, 45.496045500040054, 60.52606299519539, 60.79509615898132, 76.06632471084595, 69.27786737680435, 60.73535576462746, 47.85649783909321, 46.086260229349136, 43.31719681620598, 36.215404495596886, 39.06436622142792, 42.82082945108414, 28.216005340218544, 27.48165674507618, 27.62120995670557, 20.840428210794926, 20.876839756965637, 19.07970529049635, 21.790337339043617, 28.369406908750534, 36.88184693455696, 38.97795505821705, 48.56638714671135, 63.91299605369568, 67.53075152635574, 69.83142927289009, 57.76617988944054, 81.88765794038773, 93.30728396773338, 102.37729847431183, 85.85592940449715, 67.50539168715477, 65.42347580194473, 55.07467411458492, 39.22423504292965, 35.16185782849789, 26.835640110075474, 31.391227059066296, 28.551432341337204, 71.00845411419868, 79.34757024049759, 81.39159455895424, 106.1175137758255, 100.16999691724777, 105.7739970088005, 88.25875326991081, 110.9010922908783, 111.23354405164719, 82.15359807014465, 42.694900408387184, 18.332315795123577, 1.6813699970953166, 0.04056306461279746, 0.4711300693452358, 0.11216762839467265, 0.012420807088346919, 0.10901115558226593, 0.08730185916647315, 0.051035851865890436, 0.0644621679384727, 0.00673079795888043, 0.12018462672131136, 0.04376573982881382, 0.04487841215450317, 0.07948768979986198, 0.011381182503100717, 0.02024047298618825, 0.07680972412345, 0.043464297996251844, 0.013012770050409017, 0.019215717329643667, 0.011016453099728096, 0.010007121127273422, 0.030970592524681706, 0.025881294423015788, 0.044236766116227955, 0.011872549202962546, 0.05796042736619711, 0.01920084840094205, 0.009441804977541324, 0.011275067445239983, 0.06499247698229738, 0.10713188181398436, 0.056909460909082554, 0.04018938583612908, 0.009447227294003824, 0.014772352096770192, 0.006316686976788333, 0.006969301957724383, 0.11312418253510259, 0.017578530278115068, 0.02736908158112783, 0.043138595356140286, 0.06925278314156458, 0.006353685821522959, 0.02731018659687834, 0.0266481407743413, 0.02222126699052751, 0.06140503901406191, 0.03527038650645409, 0.020429447904461995, 0.05455305668874644, 0.014890176389599219, 0.09144541807472706, 0.05689196477760561, 0.02248108732601395, 0.09211415992467664, 0.042366713532828726, 0.1494641782483086, 0.11299350517219864, 0.12487894826335832, 0.13792007113806903, 0.2111118327593431, 0.12794312759069726, 0.16717888705898076, 0.23151405126554891, 0.11430387079599313, 0.09816775462240912, 0.1782681912300177, 0.10697793069994077, 0.14210182096576318, 0.1809945300919935, 0.07900884127593599, 0.08690743736224249, 0.1548285997705534, 0.16063992778072134, 0.15422829135786742, 0.12095102778403088, 0.16236154711805284, 0.1702043559635058, 0.10674652905436233, 0.21980656776577234, 0.1919753768015653, 0.09698778434540145, 0.15150883962633088, 0.10123788597411476, 0.15586852678097785, 0.18068649427732453, 0.09170390068902634, 0.08335015285410918, 0.23080806102370843, 0.12629144825041294, 0.2508271235274151, 0.1008372449723538, 0.2894730685511604, 0.19606465502874926, 0.1427927307668142, 0.12751177651807666, 0.3048998845042661, 0.1589766560937278, 0.11927461266168393, 0.12813538836780936, 0.20427901268703863, 0.08340154658071697, 0.13924931699875742, 0.0882282004749868, 0.15558686689473689, 0.20613879023585469, 0.1854993071174249, 0.20549371547531337, 0.31913742364849895, 0.08760460346820764, 9.160539899021387, 45.89470110833645, 97.83047765493393, 113.10227617621422, 86.545250415802, 96.35367929935455, 91.15452468395233, 80.73446542024612, 64.43341612815857, 65.15939757227898, 66.75375401973724, 81.88895747065544, 88.62994775176048, 80.46544745564461, 78.94769489765167, 99.57351252436638, 97.53870651125908, 123.39194923639297, 113.51754069328308, 86.54793307185173, 61.680733636021614, 59.33169588446617, 56.538640558719635, 49.06551316380501, 54.69265781342983, 57.14603416621685, 36.77479527890682, 37.35155113041401, 39.11809153854847, 27.663376294076443, 31.25083029270172, 24.586119018495083, 30.79677175730467, 37.79622606933117, 48.68582993745804, 50.870860889554024, 62.256968915462494, 87.80043706297874, 94.38334822654724, 104.93675753474236, 87.21611961722374, 123.66147637367249, 138.56921643018723, 150.1414042711258, 142.87116318941116, 117.84378334879875, 138.53865087032318, 113.67308154702187, 108.60853090882301, 87.79657647013664, 64.75122347474098, 50.97894228994846, 27.57570169866085, 60.25827996432781, 64.25028875470161, 75.29466971755028, 98.81588637828827, 103.73586237430573, 108.03805232048035, 99.9498899281025, 119.96520951390266, 125.46792984008789, 88.57021495699883, 46.207511723041534, 19.87997654825449, 1.7891630879603326, 0.20055589528055862, 0.6064763129688799, 0.2366673614596948, 0.162641039933078, 0.28011322079692036, 0.1637386466609314, 0.13644683378515765, 0.1793881514458917, 0.13884845335269347, 0.18218101642560214, 0.14283610187703744, 0.21513608400709927, 0.18561944598332047, 0.13403863878920674, 0.08831860148347914, 0.2556011517299339, 0.1478505413979292, 0.15920670703053474, 0.11446706907008775, 0.11292624432826415, 0.06786648096749559, 0.09303457889473066, 0.21309213509084657, 0.20316016569267958, 0.15148348786169663, 0.15848876821110025, 0.10318183049093932, 0.08736241099541076, 0.15734741929918528, 0.1385306954034604, 0.24013797054067254, 0.09806780217331834, 0.21545323339523748, 0.0902106030844152, 0.08911340453778394, 0.1597001907066442, 0.15943834616336972, 0.3223576914751902, 0.1135824438824784, 0.157147187856026, 0.12150544920586981, 0.09335126072983257, 0.09280045356717892, 0.12907300289953128, 0.16102945141028613, 0.1321870248648338, 0.10980307910358533, 0.21450966683914885, 0.18644541181856766, 0.1197743600641843, 0.13157430774299428, 0.1679944628267549, 0.14420727908145636, 0.18850018124794587, 0.2216703083831817, 0.12978720129467547], [0.02780977443762822, 0.060923726559849456, 0.034977486793650314, 0.029271065068314783, 0.052323029085528105, 0.06746175815351307, 0.054145402391441166, 0.027529378057806753, 0.058632557120290585, 0.017709810636006296, 0.04833595943637192, 0.03208843576430809, 0.05265176710963715, 0.020555358823912684, 0.01174839717350551, 0.0803896960860584, 0.007850452966522425, 0.06530780068715103, 0.05248867644695565, 0.013327474061952671, 0.018986041177413426, 0.018167667512898333, 0.025015239625645336, 0.028739099179801997, 0.011664482535707066, 0.018571041473478545, 0.037199940779828466, 0.06624499219469726, 0.046593712104368024, 0.053006810558144934, 0.0077493293156294385, 0.049365418453817256, 0.047704703465569764, 0.05042451142799109, 0.02555702783865854, 0.027046978357248008, 0.09027561522088945, 0.034415988993714564, 0.04117866868909914, 0.023356853125733323, 0.07174439553637058, 0.07013553811702877, 0.029943200388515834, 0.06610935728531331, 0.0959796880488284, 0.011060609031119384, 0.09779491447261535, 0.040017604624154046, 0.04033090968732722, 0.03993446924141608, 0.1283776550553739, 0.13322411687113345, 9.749737232923508, 42.39524848759174, 79.714425355196, 91.13392978906631, 76.82743906974792, 75.76707556843758, 71.54167950153351, 45.24821899831295, 31.277637854218483, 38.044113367795944, 37.479532063007355, 53.66305746138096, 37.68980138003826, 51.26428797841072, 84.20860379934311, 45.58936849236488, 45.785304978489876, 35.1952238380909, 25.343002304434776, 9.79405615478754, 5.564730623736978, 1.2845658394508064, 0.9946608706377447, 0.5732688261196017, 0.6311150221154094, 0.5421221943106502, 0.7620746386237442, 0.5218499852344394, 0.47920036129653454, 0.17709117470076308, 0.2211605419870466, 0.17027444439008832, 0.167576500098221, 0.1487066681147553, 0.05864514394488651, 0.10927348252153024, 0.25245210039429367, 0.22401769179850817, 0.20338739646831527, 0.5647806753404438, 1.5462575596757233, 1.3791755377314985, 1.9216073560528457, 2.286969982087612, 6.19066153652966, 11.461236644536257, 26.254700683057308, 40.70976532995701, 41.408958211541176, 51.89539611339569, 73.06678846478462, 84.83182355761528, 107.51903057098389, 112.96348482370377, 104.21230360865593, 38.58274206519127, 31.69291567057371, 36.183976382017136, 28.666334375739098, 39.696150720119476, 54.64861057698727, 77.50830173492432, 74.74552318453789, 78.5479411482811, 85.0436469912529, 101.38288423418999, 89.83152687549591, 63.253123462200165, 28.5227020829916, 4.433733187615871, 0.3331367630744353, 0.08023615315323696, 0.09174967635772191, 0.01760895647748839, 0.030337035896081943, 0.2112922488595359, 0.010942134431388695, 0.028641198769037146, 0.02582608605735004, 0.05846942192874849, 0.09623602585634217, 0.06538018977153115, 0.04193236418359447, 0.06364522661897354, 0.061392040297505446, 0.01819872824853519, 0.02811125337757403, 0.034183514944743365, 0.012524890516942833, 0.036456713278312236, 0.047593169801984914, 0.051218394219176844, 0.07733026650385, 0.0469793654337991, 0.026767428025777917, 0.12546120764454827, 0.051017398363910615, 0.022137569430924486, 0.03570486202079337, 0.020239010955265258, 0.03874670641380362, 0.023385394270007964, 0.018790906433423515, 0.048954940284602344, 0.02349972397496458, 0.044182622732478194, 0.030212505371309817, 0.04653179472370539, 0.07290984940482304, 0.010815932218974922, 0.03841677724267356, 0.012450113572413102, 0.07420774694764987, 0.027380458705010824, 0.08264887525001541, 0.02420859189442126, 0.019298925071780104, 0.02382061935350066, 0.016418566447100602, 0.03128897202259395, 0.050116071142838337, 0.06036817707354203, 0.06272477054153569, 0.0266227333486313, 0.014496182247967226, 0.060482367625809275, 0.07048381317872554, 0.06049656862160191, 0.07107192068360746, 0.02064964868623065, 0.0291440242290264, 0.10964097178657539, 0.03149953416141216, 0.04483145647100173, 0.03625960998761002, 0.00827932433821843, 0.005712602423955104, 0.05666787699738052, 0.03306589991552755, 0.10091867341543548, 0.023599064152222127, 0.0647511008719448, 0.034186175544164144, 0.05074523425719235, 0.053801851099706255, 0.04433199850609526, 0.039426740040653385, 0.06296806139289401, 0.018771111499518156, 0.00923353793041315, 0.042526420002104715, 0.06063130553229712, 0.043406095064710826, 0.010449581222928828, 0.04055286379298195, 0.05611503635009285, 0.0394793879968347, 0.03854443035379518, 0.05013993490138091, 0.05009451546357013, 0.11053669950342737, 0.045978475391166285, 0.021745349949924275, 0.07586970503325574, 0.056493650408810936, 0.0304691066412488, 0.044486973783932626, 0.060937025846214965, 0.04427765103173442, 0.026649740102584474, 0.13993284985190257, 0.07309624721528962, 0.046170305722625926, 0.12243046207004227, 0.12316431995714083, 0.3065309766680002, 16.19310088455677, 60.41976749897003, 101.11648052930832, 106.00542739033699, 93.02623584866524, 103.32136541604996, 96.73511043190956, 70.41139215230942, 48.51697079837322, 48.83109614253044, 28.35513487458229, 34.91403512656689, 29.685563184320927, 50.18638841807842, 92.11155652999878, 53.95999252796173, 57.304379269480705, 43.51232014596462, 28.56637503951788, 11.196405105292797, 6.080633215606213, 1.2791728600859642, 0.8991965744644403, 0.4452149849385023, 0.5832131300121546, 0.6008069578092545, 0.48974197532515973, 0.5190127843525261, 0.7452966982964426, 0.2949700673343614, 0.17594181059394032, 0.0365590591536602, 0.3797273099189624, 0.07826664164895192, 0.11842118736240081, 0.22159039392136037, 0.3376936091808602, 0.12671049451455474, 0.020916142784699332, 0.43072817323263735, 1.3801549351774156, 0.973619855940342, 1.7537474445998669, 2.0974150160327554, 5.394720146432519, 11.918664649128914, 25.356028005480766, 41.864986941218376, 46.86981998383999, 58.141060173511505, 80.12066915631294, 80.79663768410683, 89.7864992916584, 71.55127018690109, 41.30664870142937, 20.024309903383255, 20.778993107378483, 34.268974140286446, 45.64806014299393, 64.39917236566544, 88.13249364495277, 117.81345337629318, 98.42958390712738, 92.69181579351425, 99.72043544054031, 117.57677167654037, 109.27547872066498, 82.09311291575432, 42.386349365115166, 9.29240707308054, 0.21847552590770647, 0.05977156455628574, 0.15578126505715773, 0.06824401891208254, 0.031626292984583415, 0.14872856147121638, 0.04376730204967316, 0.10590735299047083, 0.0669252299121581, 0.01901729487144621, 0.02594981877336977, 0.0605879975046264, 0.07266439890372567, 0.06904605048475787, 0.04412976326420903, 0.09267497865948826, 0.010802698798215715, 0.06030214819475077, 0.042948646369040944, 0.026767676645249594, 0.037036775902379304, 0.04334890145401005, 0.09057139075594023, 0.04409996974573005, 0.01958738674147753, 0.01960401270480361, 0.04906128262518905, 0.0394046054861974, 0.053782366012455896, 0.0380011968081817, 0.024123352523020003, 0.04604273053701036, 0.029510006934287958, 0.09431185957510024, 0.038492279636557214, 0.0047086551967367996, 0.0789282143523451, 0.03734471894858871, 0.06561071568285115, 0.010313090060662944, 0.038364979045582004, 0.05926715275563765, 0.017873077558760997, 0.04459851486899424, 0.025974819873226807, 0.02526242118619848, 0.03488744201604277, 0.017223720606125426, 0.0300844978846726, 0.024353676199098118, 0.046419455829891376, 0.015501175439567305, 0.006723001697537256, 0.04298921216104645, 0.2816905517829582, 0.30026024440303445, 0.14367933006724343, 0.1413363401661627, 0.2184269152348861, 0.14679985324619338, 0.21541449328651652, 0.15232800738886, 0.0928641966311261, 0.13214430684456602, 0.23570543417008594, 0.08180497912690043, 0.10180335797485895, 0.09746158626512624, 0.10687952191801742, 0.11297577526420355, 0.1253314208588563, 0.22175277583301067, 0.11055705661419779, 0.19574392848880962, 0.1006227420293726, 0.12003504685708322, 0.14316907385364175, 0.1378811677568592, 0.12035296065732837, 0.15179054404143244, 0.18103962298482656, 0.19031571195228025, 0.172601418744307, 0.23476827976992354, 0.1097742911952082, 0.08256690503912978, 0.13002695952309296, 0.1821066383854486, 0.1172901394602377, 0.09967253325157799, 0.17051389091648161, 0.17020373255945742, 0.18572690896689892, 0.1783088015508838, 0.26062721328344196, 0.27449638000689447, 0.21399605611804873, 0.1923578351852484, 0.17691169370664284, 0.1934166275896132, 0.26936644746456295, 0.20333060732809827, 0.15477943990845233, 0.25203943660017103, 0.26272523507941514, 0.36558230174705386, 17.30698261409998, 66.59929990768433, 111.9506947696209, 119.00210559368134, 95.84200635552406, 97.41202890872955, 97.85420358181, 62.90333703160286, 41.09543323516846, 52.72216334939003, 58.24838161468506, 83.80812808871269, 60.85677444934845, 75.50647035241127, 111.24503463506699, 70.55203780531883, 75.29644042253494, 57.35773220658302, 39.07929942011833, 16.784723438322544, 8.644815422594547, 2.563903396949172, 2.0852817920967937, 1.3431183225475252, 1.2171574565581977, 1.1771888262592256, 1.1334600602276623, 1.140983181539923, 2.0874873362481594, 0.6761204008944333, 0.36033199285157025, 0.37450080912094563, 0.42343775974586606, 0.16715788427973166, 0.42703610728494823, 0.3447209461592138, 0.5503642489202321, 0.6701489025726914, 0.931963047478348, 1.3013265025801957, 3.395151305012405, 2.792192059569061, 4.404141800478101, 4.854871239513159, 9.282808788120747, 18.159075491130352, 36.62430055439472, 59.244368970394135, 62.89345756173134, 78.02111461758614, 110.46094670891762, 121.39291450381279, 153.29319834709167, 152.02257692813873, 143.745359480381, 55.619070902466774, 48.90510857105255, 49.312226325273514, 38.70850391685963, 52.77895510196686, 73.56227427721024, 107.41131395101547, 98.1671091914177, 96.43061757087708, 107.28135332465172, 131.24577820301056, 120.7890585064888, 92.66892582178116, 44.72881346940994, 9.638213217258453, 0.39683660434093326, 0.19226874777814373, 0.2283027782686986, 0.14844302757410333, 0.1250581323984079, 0.2833062666468322, 0.12770688714226708, 0.2871898957528174, 0.11977473113802262, 0.1413874444551766, 0.2160555456066504, 0.2245904813753441, 0.15460178459761664, 0.20187620568322018, 0.1385155407479033, 0.13095045840600505, 0.07975909320521168, 0.09910880529787391, 0.11874735384481028, 0.12221893513924442, 0.16906217584619299, 0.20779333426617086, 0.1697670528665185, 0.1817890437087044, 0.10320796151063405, 0.18960632267408073, 0.13731241546338424, 0.13226978917373344, 0.1521778857568279, 0.12076187660568394, 0.14355396648170426, 0.06861694811959751, 0.21649605478160083, 0.27780098549555987, 0.08291989273857325, 0.1309572861646302, 0.151199497631751, 0.1873165596043691, 0.21248946664854884, 0.09619417614885606, 0.11642863959423266, 0.14531955064740032, 0.15366773237474263, 0.06483614357421175, 0.22930065519176424, 0.13074552174657583, 0.1074729060928803, 0.13301472732564434, 0.0986220157938078, 0.12048297008732334, 0.11176880565471947, 0.15067301806993783, 0.12603558541741222, 0.12344747898168862], [0.06239252586965449, 0.04426317915203981, 0.07028194158920087, 0.009039394881256158, 0.046627969641122036, 0.047400849653058685, 0.015836635466257576, 0.042807508434634656, 0.05170676449779421, 0.050007691606879234, 0.06648473558016121, 0.005841288048031856, 0.05895194779441226, 0.07089960883604363, 0.038989455497357994, 0.017416441514797043, 0.05432348443719093, 0.03400141416932456, 0.07738952699583024, 0.07461848115781322, 0.07623704586876556, 0.02497936049621785, 0.005398530629463494, 0.04622923595889006, 0.07624519465025514, 0.10115365221281536, 0.11786330011091195, 0.02466060806909809, 0.00535700097316294, 0.03088694877078524, 0.020463907676457893, 0.012104611359973205, 0.053641075937775895, 0.07356595990131609, 0.03444266920269001, 0.04526716766122263, 0.01936361066327663, 0.011219130847166525, 0.018084639741573483, 0.04755179877975024, 0.028443345909181517, 0.05278265227389056, 0.07339214891544543, 0.0427730393857928, 0.03309809428174049, 0.011442893010098487, 0.031907140219118446, 0.10542579562752508, 0.06879149383166805, 0.16015770990634337, 6.619538348168135, 43.97196248173714, 82.36829414963722, 94.91584405303001, 71.6254498064518, 62.503104507923126, 55.57573422789574, 41.77460119128227, 42.84153833985329, 47.61048763990402, 51.99615530669689, 52.33294643461704, 61.503811329603195, 59.08082954585552, 49.695401564240456, 47.714936435222626, 24.70481514930725, 16.635359153151512, 3.8279364444315434, 0.9095873543992639, 0.3761961712734774, 0.1284460662282072, 0.10015774198109284, 0.1396637174184434, 0.014145518398436252, 0.02749943425442325, 0.04116989279282279, 0.12763881735736504, 0.05000514975108672, 0.10304047362296842, 0.07335374277317896, 0.0912714067089837, 0.09742396679939702, 0.26008440647274256, 0.14407327689696103, 0.2262779322336428, 0.12857597175752744, 0.1413177271024324, 0.2570679917698726, 0.05931101739406586, 0.14772397553315386, 0.12132130752434023, 0.09746991316205822, 0.19579803105443716, 0.0810426301904954, 0.17515029525384307, 0.1762349737691693, 0.32201784721110016, 0.3218729799846187, 0.25521366158500314, 0.08596310639404692, 0.9329971263650805, 1.3087157998234034, 5.086540058255196, 12.528224140405655, 35.22227458655834, 76.36383354663849, 102.49928712844849, 90.99854305386543, 53.003048077225685, 50.64449943602085, 34.001350700855255, 35.97960814833641, 20.65141875296831, 56.36802591383457, 67.66415476799011, 68.96209672093391, 62.94587194919586, 69.97222691774368, 84.86581653356552, 93.81903290748596, 74.46063727140427, 18.910521268844604, 0.17056132899597287, 0.2559570857556537, 0.02022770062467316, 0.07240756385726854, 0.11859520614962094, 0.032032203234848566, 0.02493835869245231, 0.09216660750098526, 0.012025860214635031, 0.038179464390850626, 0.07857335644075647, 0.060332242283038795, 0.09176480874884874, 0.025037194209289737, 0.047685700774309225, 0.018306870297237765, 0.02331033902009949, 0.023423492420988623, 0.04726687715447042, 0.08101028739474714, 0.012394512796163326, 0.017018169819493778, 0.020192726915411185, 0.05095623426313978, 0.042904915317194536, 0.03886751692334656, 0.01605532226676587, 0.10763945145299658, 0.016148166796483565, 0.012030941143166274, 0.0669476279290393, 0.013410366391326534, 0.039510398637503386, 0.011284260799584445, 0.07129256118787453, 0.03012314893567236, 0.02723679932387313, 0.032688762730685994, 0.0682526575110387, 0.015133017313928576, 0.06197115668328479, 0.040703991035115905, 0.03221046339604072, 0.030108541614026763, 0.018591322514112107, 0.06909248666488566, 0.010320294459233992, 0.022171877062646672, 0.025579984321666416, 0.013841692416463047, 0.05462731969601009, 0.017886974274006207, 0.049701128955348395, 0.03188759204931557, 0.02801708225888433, 0.012712482257484226, 0.060853768009110354, 0.04019855507067405, 0.014042202165001072, 0.06463295838329941, 0.0758526059507858, 0.07175915685365908, 0.06286263189394958, 0.01741365103953285, 0.019839227134070825, 0.07072340813465416, 0.01509173163867672, 0.020760423503816128, 0.04774707638716791, 0.04243536590365693, 0.021671023860108107, 0.05765402427641675, 0.07071295869536698, 0.04224547628837172, 0.05956347747996915, 0.00968586766248336, 0.04315700432925951, 0.08615892948000692, 0.051065894003841095, 0.05563353835896123, 0.04413777474837843, 0.02916101941082161, 0.04613196637365036, 0.03432910205447115, 0.020127898460486904, 0.04292833378713112, 0.04352679425210226, 0.04530130645434838, 0.043178864289075136, 0.023883616559032816, 0.04393765462737065, 0.01235463905686629, 0.026996345332008786, 0.03973280545324087, 0.037271858600433916, 0.03450084615906235, 0.022113479317340534, 0.03123130343738012, 0.035621574497781694, 0.07698118992266245, 0.09854103263933212, 0.006824304855399532, 0.25458393443841487, 11.525889225304127, 59.4047811627388, 101.33629873394966, 104.31771755218506, 84.00606706738472, 87.8090626001358, 86.92826986312866, 72.40051701664925, 59.36305560171604, 42.81723864376545, 29.878659322857857, 30.53887579590082, 52.12005525827408, 63.0482954531908, 64.83280509710312, 52.81033381819725, 31.588115394115448, 18.09632185846567, 4.765244498848915, 0.5545528116635978, 0.2954162465175614, 0.11265579829341732, 0.12263073062058538, 0.036935918033123016, 0.031020099340821616, 0.0566926907049492, 0.04821146787435282, 0.07781900043482892, 0.12105533663998358, 0.16774778778199106, 0.04481672112888191, 0.08769655556534417, 0.30098466959316283, 0.2254256498417817, 0.3191943612182513, 0.24370829458348453, 0.053715175672550686, 0.33352689526509494, 0.49096393631771207, 0.05943132324318867, 0.14908982411725447, 0.1863081887131557, 0.03474119810562115, 0.053912650037091225, 0.035795971780316904, 0.04567698160826694, 0.12257840920938179, 0.2438133381656371, 0.4784805671079084, 0.293561500729993, 0.07822332248906605, 0.42542451876215637, 1.471706866286695, 5.740403272211552, 13.501749001443386, 37.89261929690838, 72.50016286969185, 73.09004321694374, 61.3865078240633, 35.62408022582531, 24.775453358888626, 21.913027055561543, 37.583000510931015, 39.00124780833721, 91.1973711848259, 99.22472923994064, 101.5134908258915, 81.20568573474884, 80.88101595640182, 96.92202240228653, 105.36324664950371, 93.9753869175911, 31.53113555163145, 0.25955065386369824, 0.3328909637639299, 0.06229180158698, 0.04165071542956866, 0.10776505994726904, 0.017309010072494857, 0.11128357466077432, 0.0379901536507532, 0.08177600568160415, 0.05385204254707787, 0.0654277391731739, 0.05184807312616613, 0.02630940973176621, 0.04217823028739076, 0.037630568258464336, 0.03396400992642157, 0.0072369686495221686, 0.04883565488853492, 0.0924503973510582, 0.018693570054892916, 0.0565754573472077, 0.04204861048492603, 0.028308976361586247, 0.04851178906392306, 0.03545664330886211, 0.01895712710393127, 0.007974281234055525, 0.0830084086919669, 0.02584499969088938, 0.013573307696788106, 0.027214254732825793, 0.026215450125164352, 0.03188123184372671, 0.03454366436926648, 0.05912498694669921, 0.0399207432201365, 0.056765992630971596, 0.02205497210525209, 0.10241105817840435, 0.03286937550001312, 0.04904468820313923, 0.04682701364799868, 0.020346407145552803, 0.03827324959274847, 0.02811748556268867, 0.03301534852653276, 0.015697224880568683, 0.012109551280445885, 0.02386669559200527, 0.024145143834175542, 0.020571916138578672, 0.023254767002072185, 0.04867563671723474, 0.15296886675059795, 0.17572860640939325, 0.1611583327758126, 0.12823449476854876, 0.10974158474709839, 0.1235363660089206, 0.11058073854655959, 0.14113058714428917, 0.22295916656730697, 0.17430962005164474, 0.08208859828300774, 0.13196354935644194, 0.22829068126156926, 0.14767073385883123, 0.1718123970204033, 0.10386784953880124, 0.14606439974159002, 0.2006188442464918, 0.21064981614472345, 0.23988905420992523, 0.21282053872710094, 0.1280469837365672, 0.10754987422842532, 0.1046600031259004, 0.3284854267258197, 0.19120568060316145, 0.15556608675979078, 0.1491509919287637, 0.15124131023185328, 0.11179674009326845, 0.0738222902873531, 0.1264071639161557, 0.10916859479038976, 0.15100625721970573, 0.20785781205631793, 0.11779446591390297, 0.2426630983245559, 0.0962047888606321, 0.11343613688950427, 0.2155288285575807, 0.09416230939677916, 0.1843082343111746, 0.14209952030796558, 0.0761374867579434, 0.11110509556601755, 0.15738062298623845, 0.17866889160359278, 0.24015118076931685, 0.1189796460676007, 0.3195779328234494, 11.858242191374302, 67.23073482513428, 116.06745466589928, 116.79034307599068, 91.1933434009552, 79.33844313025475, 77.97337397933006, 53.664015009999275, 57.199615091085434, 66.88328146934509, 77.57471457123756, 81.41947746276855, 94.11325871944427, 92.24992990493774, 79.98978897929192, 73.35734367370605, 41.97573959827423, 29.840285181999207, 7.432655766606331, 2.646917779929936, 0.7479339349083602, 0.48647032119333744, 0.19906958128558472, 0.2958326507359743, 0.09686097357189283, 0.203288572083693, 0.18241271493025124, 0.29449138208292425, 0.2601824887096882, 0.4763999115675688, 0.11737312641344033, 0.26352488435804844, 0.47242292028386146, 0.7442442141473293, 0.6593728589359671, 0.699192228494212, 0.2716407738626003, 0.6052956450730562, 0.6860696920193732, 0.5237774318084121, 0.333549456554465, 0.27253859443590045, 0.1713188985013403, 0.3850201587192714, 0.2018695411970839, 0.35017246613278985, 0.23943166859680787, 0.4610577004496008, 0.4337825265247375, 0.3264775313436985, 0.8482169662602246, 2.108360091224313, 2.8951206989586353, 9.825846198946238, 19.702286683022976, 57.10170194506645, 105.9055307507515, 137.24199324846268, 127.40696579217911, 77.91541948914528, 76.11643642187119, 49.397345557808876, 48.6827939003706, 28.171175345778465, 75.74648067355156, 91.78367972373962, 92.94343069195747, 79.63443964719772, 88.56123223900795, 106.59882634878159, 119.44594457745552, 106.41974955797195, 34.499089792370796, 0.19437750102952123, 0.5546515469904989, 0.22074596345191821, 0.2040272019803524, 0.3016656939871609, 0.09612310808734037, 0.16137229395098984, 0.156934013357386, 0.12148623500252143, 0.1343951071612537, 0.2893071837024763, 0.14871659805066884, 0.23183618788607419, 0.1691443464369513, 0.11399858092772774, 0.144845733884722, 0.08751706714974716, 0.13535458536352962, 0.1640426303492859, 0.16434385324828327, 0.10293496990925632, 0.15678068564739078, 0.09597204392775893, 0.14585331809939817, 0.09899228069116361, 0.09793863879167475, 0.10773722940939479, 0.15994976012734696, 0.08741186029510573, 0.0897853821516037, 0.11331381610943936, 0.08330543103511445, 0.13458423607517034, 0.1119659052346833, 0.17645457526668906, 0.1415109378285706, 0.15806218172656372, 0.18390358571195975, 0.20031126856338233, 0.09827754052821547, 0.14862301322864369, 0.10378023158409633, 0.12392439050017856, 0.1057709610904567, 0.16721682564821094, 0.1176343995030038, 0.11360804055584595, 0.13738339446717873, 0.08098124715615995, 0.06704706829623319, 0.17519734741654247, 0.06945621324121021, 0.11555270495591685], [0.052580981064238586, 0.061303182956180535, 0.08959747035987675, 0.01765589175192872, 0.06463789366534911, 0.0031580804898112547, 0.06688086432404816, 0.03597922288463451, 0.044719058205373585, 0.050165910070063546, 0.014750078389624832, 0.02206681307143299, 0.02228200806712266, 0.04858759944909252, 0.041537025826983154, 0.035037530251429416, 0.07465359958587214, 0.05285157552862074, 0.05025375066907145, 0.07385166449239478, 0.0762680231127888, 0.05499649363628123, 0.04645244429411832, 0.03823917759291362, 0.03415393293835223, 0.03252383154176641, 0.04466174214030616, 0.05640480048896279, 0.07166868163039908, 0.08315378057886846, 0.024235312921518926, 0.03373758438101504, 0.02288470248458907, 0.05005971986975055, 0.07402104485663585, 0.15569992567179725, 0.09699162124888971, 0.07885901650297455, 0.043206795016885735, 0.030407267186092213, 0.049070444438257255, 0.06977700657444075, 0.040125442392309196, 0.055145316509879194, 0.011054854603571584, 0.021739012008765712, 0.06793722990551032, 0.20585379068506882, 0.7411415025126189, 20.362328365445137, 75.02262711524963, 92.67772614955902, 74.40163403749466, 65.75930938124657, 73.85798200964928, 45.70217303931713, 39.62547451257706, 57.7700936794281, 46.926516741514206, 45.58356620371342, 73.86552840471268, 68.70024517178535, 45.25108024477959, 21.187987960875034, 9.078835733234882, 2.043631514534354, 0.15831213706405833, 0.3727195062674582, 0.15996366797480732, 0.04361718412837945, 0.16749228117987514, 0.07222643529530615, 0.08256396613433026, 0.15334832685766742, 0.20220327016431838, 0.2528861380415037, 0.21567537303781137, 0.2028253977186978, 0.19586436421377584, 0.05811045994050801, 0.17607360117835924, 0.08406551642110571, 0.08575209896662273, 0.09400875904248096, 0.08747552914428525, 0.12876269611297175, 0.049658255084068514, 0.0200068152116728, 0.22186170826898888, 0.03226203152735252, 0.08372081851121038, 0.22763132757972926, 0.112547600583639, 0.21971728740027174, 0.09148158293101005, 0.10412129297037609, 0.25586194242350757, 0.10433342846226878, 0.20744663255754858, 0.19057731900829822, 0.04205245852062944, 0.06388933383277617, 0.08195378715754487, 0.10827010628418066, 0.21135677117854357, 0.12820029660360888, 0.4080866725416854, 10.732676088809967, 33.71252439916134, 54.866718873381615, 73.02496030926704, 73.77993419766426, 59.23830829560757, 57.15973623096943, 31.081097200512886, 36.57490700483322, 28.410026729106903, 64.25874710083008, 82.3761673271656, 72.34073862433434, 72.16885104775429, 84.1485746204853, 85.01813516020775, 49.90353159606457, 7.444477882236242, 0.5880889215040952, 0.19995098555227742, 0.12343522612354718, 0.02112063972163014, 0.166166078124661, 0.046845044125802815, 0.03031977168575395, 0.1287076435983181, 0.10119147205841728, 0.024857295757101383, 0.009776271454029484, 0.03499680489767343, 0.03521806138451211, 0.014482077731372556, 0.0467892086453503, 0.06614146259380504, 0.024692067709111143, 0.03835299336060416, 0.04746757615066599, 0.05738449479395058, 0.03012227320141392, 0.031003747972135898, 0.015418886105180718, 0.018667657968762796, 0.0533805598388426, 0.036227723612682894, 0.05922340315009933, 0.03977718959504273, 0.03860597666061949, 0.04542267728538718, 0.016825524980959017, 0.07901813296484761, 0.0696895073633641, 0.04293769598007202, 0.07867888984037563, 0.016371132078347728, 0.012533979970612563, 0.017847141352831386, 0.06885200855322182, 0.027584178242250346, 0.0179928991565248, 0.06802154530305415, 0.007559121504527866, 0.02547833792050369, 0.04340205778134987, 0.01706366347207222, 0.07312999267014675, 0.022865968821861316, 0.09455227831494994, 0.026917540380964056, 0.03172956654452719, 0.04472378939681221, 0.05897902505239472, 0.040306975424755365, 0.044650294512393884, 0.04604124995239545, 0.03685556570417248, 0.04361158462415915, 0.08953409094829112, 0.06926839050720446, 0.011782261371990899, 0.022812458119005896, 0.054958788823569193, 0.026545319924480282, 0.029570881597464904, 0.01452282813261263, 0.0659668723528739, 0.044992472830927, 0.032177474931813776, 0.04143636462686118, 0.06398563491529785, 0.06390978742274456, 0.0983098462165799, 0.0018093046651301847, 0.02717951294471277, 0.04445541766472161, 0.049403780067223124, 0.02779213358735433, 0.02996321982209338, 0.09841468199738301, 0.021591951735899784, 0.04041797845275141, 0.08184319973224774, 0.0704442047572229, 0.027797786897281185, 0.035382936912355945, 0.08120366881485097, 0.027945500260102563, 0.030062023797654547, 0.04147611034568399, 0.04201191128231585, 0.08900989720132202, 0.009938701605278766, 0.07076810026774183, 0.04260552923369687, 0.05452769750263542, 0.05907698112423532, 0.024678827794559766, 0.15493129816604778, 2.163775130175054, 34.874106869101524, 91.9565324485302, 103.16640213131905, 89.67224702239037, 93.45468565821648, 110.78522130846977, 69.85662192106247, 52.01044254004955, 40.14848604798317, 32.856270745396614, 37.56928704679012, 61.606858000159264, 61.32721200585365, 48.915402218699455, 26.642306484282017, 10.134933963418007, 2.449859641492367, 0.2972516370937228, 0.2860024297842756, 0.26179467095062137, 0.1318749666097574, 0.06070090785215143, 0.11576133751077577, 0.28106126992497593, 0.09487675270065665, 0.19727131293620914, 0.2491326816380024, 0.06409035937394947, 0.20362981158541515, 0.10858050212846138, 0.1819346085540019, 0.22121575777418911, 0.27969156217295676, 0.5778085137717426, 0.37879404437262565, 0.23637958627659827, 0.1842891759588383, 0.4639274370856583, 0.29220013471785933, 0.3545161377405748, 0.2158838720060885, 0.0754983640217688, 0.271454494795762, 0.29125636036042124, 0.139066377596464, 0.11818151077022776, 0.0917105280677788, 0.33243350393604487, 0.12277773523237556, 0.23372869414743036, 0.37516764365136623, 0.1011506539362017, 0.03992715537606273, 0.16631657083053142, 0.18596858193632215, 0.2615972002968192, 0.2917027473449707, 0.19098584161838517, 12.030155416578054, 34.712946116924286, 55.45406095683575, 62.754776403307915, 56.11492149531841, 35.11018820106983, 37.59313836693764, 37.113440707325935, 51.45819917321205, 53.628486916422844, 107.20447584986687, 115.71332886815071, 96.81134954094887, 91.5347246825695, 92.21766963601112, 98.02875101566315, 68.02572816610336, 15.237209927290678, 0.21429667045595124, 0.32767452648840845, 0.0720336772792507, 0.03618838236434385, 0.08077708975179121, 0.13443142786854878, 0.03781987528782338, 0.1142730271385517, 0.03185594316164497, 0.020090293837711215, 0.03698756408994086, 0.035336597211426124, 0.029032763304712716, 0.025795565234147944, 0.037429119693115354, 0.01323142623732565, 0.014802308887738036, 0.0280184607981937, 0.025711841699376237, 0.026205368048977107, 0.00942898715948104, 0.03849927808914799, 0.053723829114460386, 0.07097545632859692, 0.025549626770953182, 0.002754616311904101, 0.020524741521512624, 0.04812964238226414, 0.03721068336744793, 0.029664833782589994, 0.03713673577294685, 0.053716530092060566, 0.02799081394186942, 0.012451589518605033, 0.03118249609542545, 0.026448441822140012, 0.03998355859948788, 0.0725506350863725, 0.11798568026279099, 0.0460572840529494, 0.025104553387791384, 0.013080059652565978, 0.02563122776336968, 0.020219880243530497, 0.07728596770903096, 0.012675992711592698, 0.08707575645530596, 0.05293026544677559, 0.07056618414935656, 0.02536365940613905, 0.016058194378274493, 0.15003928332589567, 0.1494626939529553, 0.23426519270287827, 0.08722474260139279, 0.15751232451293617, 0.14578858797904104, 0.17817154875956476, 0.1773130174842663, 0.09585471780155785, 0.22126628318801522, 0.11795767903095111, 0.12051097874063998, 0.0815023313043639, 0.15416454087244347, 0.11376863389159553, 0.16046596836531535, 0.14376194594660774, 0.22063575452193618, 0.08409793343162164, 0.1591421995544806, 0.19555166771169752, 0.28164946648757905, 0.11535245124832727, 0.12215512528200634, 0.19022864318685606, 0.14944627764634788, 0.1098129570891615, 0.12513111520092934, 0.14643982256529853, 0.20562890509609133, 0.12208166750497185, 0.14106391259701923, 0.13589154405053705, 0.09686316290753894, 0.15009403898147866, 0.22841144353151321, 0.14105689187999815, 0.1926097646355629, 0.14391598611837253, 0.13600340054836124, 0.1418840599944815, 0.1809355293517001, 0.13299408077728003, 0.10572641738690436, 0.2541488577844575, 0.14192949427524582, 0.07214956363895908, 0.39015279267914593, 1.9066480337642133, 36.45746670663357, 106.920745074749, 116.18117496371269, 93.46918568015099, 85.69657355546951, 97.25448936223984, 62.262201234698296, 49.1544283926487, 76.13372549414635, 67.5952036678791, 74.52346310019493, 106.49592787027359, 95.96188232302666, 65.71751922369003, 35.430389419198036, 17.273168228566647, 3.8792339293286204, 0.9620976867154241, 0.4698857548646629, 0.2693567401729524, 0.19587582297390327, 0.38032610435038805, 0.2766679634805769, 0.5427038599736989, 0.39678346656728536, 0.6385474826674908, 0.6929656688589603, 0.4928753525018692, 0.4533061757683754, 0.51152867032215, 0.4817655502120033, 0.6631104927510023, 0.27918372536078095, 0.3939340350916609, 0.4888202279107645, 0.3751623001880944, 0.17131256056018174, 0.45901376637630165, 0.23051022231811658, 0.42591543460730463, 0.3984009032137692, 0.4109937243629247, 0.5271308112423867, 0.4818617325508967, 0.39920346171129495, 0.5278476665262133, 0.2563548175385222, 0.7428171532228589, 0.2865504613146186, 0.3767124388832599, 0.6959036830812693, 0.22870782762765884, 0.14744345855433494, 0.4281747102504596, 0.40596288337837905, 0.33295642118901014, 0.3777546517085284, 1.0689817951060832, 19.08985074609518, 52.500422447919846, 80.46238481998444, 105.87426602840424, 103.37699443101883, 86.94495096802711, 82.9545646905899, 45.01808434724808, 47.09567226469517, 39.80684258043766, 84.72497329115868, 105.2810038626194, 92.69570678472519, 91.92468255758286, 103.44522356987, 110.71040332317352, 73.70778366923332, 15.19990162923932, 0.6924092362169176, 0.5075214290991426, 0.26542074512690306, 0.0949071955983527, 0.20086369360797107, 0.14423206681385636, 0.10767976491479203, 0.170469673757907, 0.28328216169029474, 0.11836390098324046, 0.07584166669403203, 0.1371743463096209, 0.14851455576717854, 0.11869612339069135, 0.2057193432119675, 0.17854513105703518, 0.11114457782241516, 0.08754644135478884, 0.22328050166834146, 0.36719872907269746, 0.17305108602158725, 0.10937942410237156, 0.15640723693650216, 0.11945287653361447, 0.11550793860806152, 0.14204145467374474, 0.12739813886582851, 0.16775111260358244, 0.18729778326814994, 0.15992418571840972, 0.16246895072981715, 0.16727447567973286, 0.13887675886508077, 0.09079620213015005, 0.16035149950766936, 0.12097101382096298, 0.05431387362477835, 0.1221976058150176, 0.20141320943366736, 0.14085673465160653, 0.1309978519566357, 0.11248270719079301, 0.11642761543043889, 0.12494787893956527, 0.10556686305790208, 0.08329824704560451, 0.14741512335604057, 0.17756793036824092, 0.19882434600731358, 0.08556262866477482, 0.11714529449818656], [0.09420847840374336, 0.095683073886903, 0.05059575087216217, 0.021811336155224126, 0.020620760587917175, 0.024267596345453057, 0.06072254145692568, 0.03902418800862506, 0.07680412090849131, 0.023772940076014493, 0.026245757580909412, 0.03963027775171213, 0.030730598664376885, 0.023527910743723623, 0.035025088145630434, 0.026916907700069714, 0.039759006976964884, 0.018345224489166867, 0.03980820023571141, 0.04070753479027189, 0.045337820120039396, 0.04236652428517118, 0.01799823519831989, 0.042345035399193875, 0.022098892404756043, 0.034081094854627736, 0.01887703823740594, 0.05558353615924716, 0.030864817927067634, 0.054672471960657276, 0.05995076724502724, 0.017103856334870216, 0.04104099658434279, 0.046484486520057544, 0.045539643469965085, 0.037737222301075235, 0.033426461232011206, 0.0246468171098968, 0.014910002864780836, 0.04081811479409225, 0.036013139033457264, 0.01139310881626443, 0.021138056072231848, 0.014306036591733573, 0.03986654046457261, 0.10889796321862377, 0.2037210957496427, 19.092683494091034, 69.54324513673782, 86.06116399168968, 79.69880819320679, 73.66869896650314, 76.73407047986984, 51.91688396036625, 30.88098093867302, 37.3475993424654, 47.866810485720634, 71.76392197608948, 77.36318752169609, 47.40568242967129, 31.848217137157917, 13.544973582029343, 2.625309289433062, 0.19872449745889753, 0.20443107874598354, 0.10125071770744398, 0.054126488757901825, 0.29806978069245815, 0.18193575146142393, 0.076161302276887, 0.11267254114500247, 0.03519332931318786, 0.045573529932880774, 0.057277937230537646, 0.1472111069597304, 0.18066734686726704, 0.06513068714411929, 0.09483063564402983, 0.02268333555548452, 0.010262252017128048, 0.07628012011991814, 0.05313566594850272, 0.07293632923392579, 0.2151860305457376, 0.14862408192129806, 0.11996355577139184, 0.11954682500800118, 0.04705323510279413, 0.18825651932274923, 0.1483229926088825, 0.032248394563794136, 0.05812277959194034, 0.09041240788064897, 0.06870894474559464, 0.11069550426327623, 0.20737210608785972, 0.2577171038137749, 0.042068503753398545, 0.23817464854801074, 0.15273976576281711, 0.04364840257039759, 0.08103901593131013, 0.10515048110391945, 0.09666598169133067, 0.01946877113368828, 0.018745783854683395, 0.3390682447934523, 0.27383156411815435, 0.1139009662438184, 2.2590809036046267, 16.03212632238865, 40.38229890167713, 64.09990802407265, 65.37266492843628, 65.60834348201752, 50.01041226089001, 45.15969894826412, 17.481492049992085, 25.288121849298477, 48.28926041722298, 50.56978024542332, 73.31741541624069, 69.36047494411469, 84.14656072854996, 67.54038020968437, 17.369114980101585, 1.4816213655285537, 0.7122755795717239, 0.051371139343245886, 0.19868580187903717, 0.033302337033092044, 0.015676548646297306, 0.07105904442141764, 0.06462869103415869, 0.1299993961583823, 0.035360950787435286, 0.05274830567941535, 0.06279063614783809, 0.050123689288739115, 0.08424104918958619, 0.016807572428660933, 0.0438341101835249, 0.019025219153263606, 0.020831096371694002, 0.021973042712488677, 0.05849765322636813, 0.03828164699370973, 0.05074947934190277, 0.0762729138659779, 0.015490825262531871, 0.04689074557973072, 0.020762225067301188, 0.0012132790243413183, 0.0321425457514124, 0.06174588888825383, 0.009509973097010516, 0.06632383796386421, 0.014257052062021103, 0.05262117578240577, 0.014129982464510249, 0.0433445747330552, 0.007406517852359684, 0.009551720759191085, 0.08599587963544764, 0.02730726067966316, 0.03246552099881228, 0.06953991265618242, 0.027371471296646632, 0.04094812793482561, 0.01821921337977983, 0.029633977137564216, 0.040459408846800216, 0.08713212999282405, 0.0067572977332019946, 0.0345484846184263, 0.06078623628127389, 0.07821974533726461, 0.06650449897279032, 0.04358062593382783, 0.057230907332268544, 0.015183876694209175, 0.027940364598180167, 0.09068610452231951, 0.03290389649919234, 0.06959075719350949, 0.07996489075594582, 0.014386972434294876, 0.02987855190440314, 0.07209620322100818, 0.008836194847390288, 0.023247167409863323, 0.07364096134551801, 0.0695369960158132, 0.06225510980584659, 0.02829728568030987, 0.04551830672426149, 0.03789214933931362, 0.03139188564091455, 0.03480966865026858, 0.055920975864864886, 0.03863483878376428, 0.025806712292251177, 0.02434891717712162, 0.06569426666828804, 0.049815070888143964, 0.039915559318615124, 0.04444225938641466, 0.04131783251068555, 0.042002634436357766, 0.0457442276092479, 0.008167308278643759, 0.017044872292899527, 0.024457639956381172, 0.010911698027484817, 0.04707171829068102, 0.10464107093866915, 0.048907327800407074, 0.06639888393692672, 0.03283336649474222, 0.03919734219380189, 0.05047161925176624, 0.12603080598637462, 1.100090250838548, 31.575591266155243, 91.73850014805794, 97.78473570942879, 89.93637844920158, 101.21988818049431, 113.6273244023323, 75.80789297819138, 48.31531561911106, 37.84304715692997, 25.404602698981762, 48.666849955916405, 71.88677698373795, 48.359043672680855, 36.30312278866768, 15.89110353961587, 3.5799389518797398, 0.02583915898867417, 0.28791245073080063, 0.22927752987015992, 0.033793787224567495, 0.28886323096230626, 0.01805439907911932, 0.08309537355671637, 0.13564019347541034, 0.06845172378234565, 0.10549921629717574, 0.32697889662813395, 0.11743539260351099, 0.41305080929305404, 0.4968527000164613, 0.2648394653806463, 0.613700378453359, 0.3228360798675567, 0.5647546704858541, 0.876306127756834, 1.3039249693974853, 1.6043267562054098, 1.093637840822339, 1.2114296201616526, 0.6513850344344974, 0.9245088568422943, 1.2568086851388216, 1.0112423496320844, 0.8121696067973971, 0.5503086175303906, 0.4865895991679281, 0.32084255246445537, 0.49437935929745436, 0.6606031022965908, 0.5392579198814929, 0.43907080369535834, 0.6164175888989121, 0.511306026019156, 0.2619699068600312, 0.11459414701675996, 0.09563608109601773, 0.03184850313118659, 0.0964453189226333, 0.16529506392544135, 0.173841250652913, 0.5109714064747095, 0.19203921634471044, 1.953749000094831, 16.109009496867657, 40.59329777956009, 58.04225027561188, 48.28644096851349, 41.34642876684666, 39.18988488614559, 22.399361059069633, 24.47301048785448, 50.13399302959442, 84.60800796747208, 75.2883468568325, 92.02847018837929, 82.89203524589539, 92.7505150437355, 87.52854645252228, 34.352280870079994, 5.444030100479722, 0.25455246737692505, 0.13850414135959, 0.18106132338289171, 0.08401318758842535, 0.030523635941790417, 0.05464902380481362, 0.04343887201684993, 0.02309108262124937, 0.052307306686998345, 0.02957000400783727, 0.037549937624135055, 0.02080080932501005, 0.02694369923119666, 0.010058172538265353, 0.05955133223324083, 0.017705656464386266, 0.03679083558381535, 0.016369634795410093, 0.03316916605399456, 0.07554959447588772, 0.007931950058264192, 0.018785050888254773, 0.030488601005345117, 0.09212993056280538, 0.01177914249637979, 0.07796674719429575, 0.04565437579003628, 0.015166857392614475, 0.03486871763016097, 0.047720151269459166, 0.016630679674562998, 0.03441696120717097, 0.11966330508585088, 0.0569157802965492, 0.015168403842835687, 0.06870466997497715, 0.04790926905116066, 0.035738915466936305, 0.024787264846963808, 0.06162584279081784, 0.019616413992480375, 0.04306215785618406, 0.010073894009110518, 0.06338337465422228, 0.05586199367826339, 0.055665810650680214, 0.04458150113350712, 0.060593945818254724, 0.05175411351956427, 0.2181782660773024, 0.16332258383044973, 0.1810361200477928, 0.17282633401919156, 0.11750454592402093, 0.1362303493078798, 0.2542390435701236, 0.11719328176695853, 0.1848490966949612, 0.21375598618760705, 0.08734280345379375, 0.07839559722924605, 0.2094920360832475, 0.0991427140252199, 0.11544976165168919, 0.10685644854675047, 0.15648127358872443, 0.16228681284701452, 0.1620962144806981, 0.17685815517324954, 0.15955462586134672, 0.10025434734416194, 0.1188666392408777, 0.12195985880680382, 0.11418269292335026, 0.10820688272360712, 0.11483910027891397, 0.2125236054416746, 0.11038146447390318, 0.15181105700321496, 0.24214761739131063, 0.1195532371639274, 0.18603239179356024, 0.19234781619161367, 0.14282899210229516, 0.11229834286496043, 0.08458677868475206, 0.10894072576775216, 0.17272320517804474, 0.19788315432379022, 0.24176719249226153, 0.1351357705425471, 0.17559592524776235, 0.10433549905428663, 0.1633460505399853, 0.3347604931332171, 0.8916787966154516, 31.946702152490616, 102.23016276955605, 111.69470250606537, 98.1235559284687, 95.40720328688622, 97.51656129956245, 66.26494064927101, 37.62520484626293, 52.23431892693043, 70.97503110766411, 106.36564046144485, 106.65867313742638, 71.75955981016159, 49.44649592041969, 23.435774445533752, 6.215817136690021, 0.9696098242420703, 0.5482154048513621, 0.3198976500425488, 0.2408203308004886, 0.7136626832652837, 0.6287896656431258, 0.3435120469657704, 0.4723775899037719, 0.48740851460024714, 0.6367475667502731, 0.5183134437538683, 0.3850991529179737, 0.8542714070063084, 0.43433266575448215, 0.24807770387269557, 0.4039494664175436, 0.378231288632378, 0.1603031560080126, 0.18927112425444648, 0.6703811651095748, 0.903727178229019, 0.6486453814432025, 0.5232781742233783, 0.5032702290918678, 0.6491676752921194, 0.6362991908099502, 0.37660331348888576, 0.38731312786694616, 0.24822804814903066, 0.2771279466105625, 0.2007670362945646, 0.31850164057686925, 0.4991364071611315, 0.5050455057062209, 0.20495792938163504, 0.6723635306116194, 0.38872219913173467, 0.3907346067717299, 0.3399730415549129, 0.3076563694048673, 0.3050244168844074, 0.28128634847234935, 0.44082411273848265, 0.397756333113648, 0.7514569989871234, 0.43739574670325965, 4.781892830505967, 26.55926764011383, 62.87254348397255, 93.24104592204094, 99.66547518968582, 90.44954851269722, 71.06974482536316, 63.82116258144379, 23.585121631622314, 34.619877710938454, 64.43353772163391, 71.42013162374496, 94.86583113670349, 88.93880277872086, 105.19561484456062, 100.89398726820946, 39.4179904460907, 4.587791170924902, 0.9070551465265453, 0.18524823855841532, 0.23951225099153817, 0.2121404791250825, 0.1903685528668575, 0.178765430173371, 0.15182965522399172, 0.2578904101392254, 0.13537984807044268, 0.1359669610974379, 0.2646037592785433, 0.07676980399992317, 0.09532161086099222, 0.15034489973913878, 0.21020359243266284, 0.18200854130554944, 0.14194024057360366, 0.08914470090530813, 0.15513549267780036, 0.2561851032078266, 0.16449453891254961, 0.1282921151141636, 0.12865440192399547, 0.22174375131726265, 0.05953063002380077, 0.16172707022633404, 0.18523266830015928, 0.22399618435883895, 0.08485927304718643, 0.1584492265828885, 0.054903498821659014, 0.16818204807350412, 0.1539413770660758, 0.12234192385221832, 0.08765342936385423, 0.14508666470646858, 0.10999935489962809, 0.16626015276415274, 0.1037725577771198, 0.14962422981625423, 0.17902957537444308, 0.09759794847923331, 0.07423366274451837, 0.21891606476856396, 0.22284239705186337, 0.1729899033671245, 0.13522893976187333, 0.0785066447861027, 0.17800193832954392], [0.05245132044365164, 0.03586334394640289, 0.075424883980304, 0.01688203396042809, 0.01629624566703569, 0.04082245264726225, 0.07169351389165968, 0.08405310771195218, 0.02320731964573497, 0.07010649787844159, 0.02559902597567998, 0.01580266180098988, 0.012395092599035706, 0.05259331926936284, 0.03984159317042213, 0.033653139107627794, 0.055627701367484406, 0.0634707922290545, 0.03737307641131338, 0.07033890884486027, 0.021154797068447806, 0.03540896032063756, 0.04039154315250926, 0.012441686485544778, 0.06276326574152336, 0.03908859158400446, 0.013082133955322206, 0.04133412636292633, 0.05317852497682907, 0.07429146862705238, 0.06576258878340013, 0.021154758105694782, 0.048746727043180726, 0.013528831714211265, 0.09671710824477486, 0.08972763564088382, 0.030978442591731437, 0.07880066143115982, 0.06166149185446557, 0.03567306470358744, 0.03326914447825402, 0.10487612395081669, 0.15085597231518477, 0.06522655778098851, 0.25286586256697774, 9.24632029607892, 66.54368609189987, 86.7652890086174, 81.46451264619827, 71.10755279660225, 69.17267382144928, 44.92319963872433, 37.61241093277931, 42.98995077610016, 52.152380123734474, 61.949291825294495, 76.19279712438583, 46.06123857200146, 21.09960090368986, 6.0564228147268295, 0.2430744410958141, 0.38560093380510807, 0.13353423069929704, 0.06874761063954793, 0.029859781134291552, 0.07522227766457945, 0.030388698651222512, 0.16531029279576614, 0.061928015638841316, 0.18818371463567019, 0.044539647715282626, 0.22614339570282027, 0.39793213305529207, 0.21542664966546, 0.015804982867848594, 0.17649545276071876, 0.09101105388253927, 0.08161978359567001, 0.03321830365166534, 0.2896998095093295, 0.2513586200075224, 0.8447364124003798, 1.4049623790197074, 0.9306837629992515, 0.5254685191903263, 0.14825140504399315, 0.7108386629261076, 0.8036331867333502, 0.5166670039761811, 0.33792711852584034, 0.1424895485979505, 0.18765690852887928, 0.5430782586336136, 0.12443187850294635, 0.03433594094531145, 0.09962330659618601, 0.05895053029234987, 0.04736000184493605, 0.09309275585110299, 0.06234733649762347, 0.0712672687950544, 0.1064659898111131, 0.10328599091735668, 0.18360855232458562, 0.08101370869553648, 0.07708844510489143, 0.2112452412256971, 0.2580629149451852, 0.04290167213184759, 0.15270592382876202, 0.11797335318988189, 1.7141235270537436, 16.2885669618845, 50.55211879312992, 71.38701260089874, 64.01504337787628, 84.03334200382233, 83.32111582159996, 46.69033661484718, 24.99780222773552, 39.07479666173458, 48.90419282019138, 61.95005178451538, 80.53611606359482, 77.77402147650719, 94.81020212173462, 66.73359230160713, 23.71954131871462, 0.7185059983748943, 0.5148922617081553, 0.03657661465695128, 0.04095318938198034, 0.052570134575944394, 0.06525395045173354, 0.04233193278196268, 0.036188111480441876, 0.0223518033453729, 0.07858054043026641, 0.019569560354284476, 0.06036684862920083, 0.05568266482441686, 0.030038378972676583, 0.00770113007092732, 0.04573847967549227, 0.028476256447902415, 0.026351888409408275, 0.043227371061220765, 0.03051539995794883, 0.07199060302809812, 0.04173841130977962, 0.01295548552661785, 0.013888742723793257, 0.0032493525941390544, 0.028036437470291276, 0.02080501915770583, 0.08499353498336859, 0.06130722395027988, 0.08314767270348966, 0.035759446982410736, 0.03490118288027588, 0.08999528377898969, 0.10431866714498028, 0.02793603045574855, 0.05161972912901547, 0.013433329368126579, 0.016557186645513866, 0.046030666926526465, 0.06693867020658217, 0.03606574246077798, 0.035968383817817084, 0.05818035169795621, 0.02082752478600014, 0.03307841994683258, 0.03531741269398481, 0.049660826625768095, 0.09229770046658814, 0.015169886282819789, 0.03843514539767057, 0.04289756434445735, 0.04427289015438873, 0.01904313830891624, 0.001100639792639413, 0.02642384704813594, 0.08019424407393672, 0.045627213185071014, 0.0220974415060482, 0.06431539339246228, 0.04789193990291096, 0.025353840792377014, 0.04534738640359137, 0.06152855094114784, 0.03542572543665301, 0.053548752766801044, 0.07818550264346413, 0.017474072992627043, 0.006400956917786971, 0.008920186483010184, 0.0319194561598124, 0.03082093102420913, 0.04108764427655842, 0.014624375271523604, 0.07117907196516171, 0.012135929991927696, 0.027902171823370736, 0.014188220648065908, 0.028551504656206816, 0.007364662578766001, 0.009202849196299212, 0.03489215094305109, 0.038055124969105236, 0.07748021744191647, 0.06947156827664003, 0.061648556220461614, 0.08028028867556714, 0.05337578782928176, 0.08002075221156701, 0.03824605359113775, 0.06812177234678529, 0.059345994814066216, 0.07970979975652881, 0.24062465614406392, 15.988536961376667, 89.12503078579903, 101.72724455595016, 85.19676357507706, 91.5852315723896, 104.05613958835602, 75.21300449967384, 50.63094176352024, 42.13633418083191, 23.10287620872259, 31.926103457808495, 63.05422693490982, 53.00473138689995, 25.750397443771362, 7.30718744918704, 0.45012921968009323, 0.6140251422766596, 0.40430228342302144, 0.08606118863099255, 0.037665842537535354, 0.13665450154803693, 0.034784958843374625, 0.38250962155871093, 0.22948000259930268, 0.5637215415481478, 0.5831218755338341, 1.0835936735384166, 1.2955301511101425, 1.118736919015646, 1.0547691327519715, 1.527514352928847, 1.38005958404392, 1.5403702505864203, 0.9727732138708234, 1.8060191022232175, 3.1260590068995953, 4.373631337657571, 7.434955593198538, 4.704325217753649, 4.459436908364296, 3.064802256412804, 5.620388612151146, 3.0625508772209287, 4.315118752419949, 4.472363814711571, 1.046522269025445, 2.180818640626967, 3.0726101249456406, 1.731320929247886, 0.7191118283662945, 1.4468142832629383, 0.8460321428719908, 0.9841055714059621, 0.1828761861543171, 0.6132916628848761, 0.719169300282374, 0.7817793125286698, 0.714379835408181, 0.6698804232291877, 0.420837274286896, 0.485782825271599, 0.12235572779900394, 0.20579155418090522, 0.12520534481154755, 0.274699876899831, 0.09498247905867174, 0.988486201968044, 15.960017591714859, 43.46649840474129, 57.30030208826065, 45.12941837310791, 62.60730631649494, 46.29866123199463, 25.93703582882881, 26.089116968214512, 64.81604799628258, 88.34075286984444, 87.16808259487152, 99.0736873447895, 87.15377256274223, 110.58980539441109, 90.97211167216301, 41.4355605840683, 2.970914994366467, 0.6881049578078091, 0.002540131458772521, 0.031053488564793952, 0.08610475269961171, 0.07763253583107144, 0.015950384440657217, 0.006776575482945191, 0.05641730567731429, 0.021914522512815893, 0.0217050643186667, 0.04724179256299976, 0.04109425310161896, 0.02889347331802128, 0.0597364275745349, 0.08505500707542524, 0.02743694913078798, 0.02461409767420264, 0.07458123276592232, 0.02411424822639674, 0.08095718672848307, 0.07378686757874675, 0.10411829469376244, 0.04036637692479417, 0.03615575384174008, 0.05254310184682254, 0.05545289961446542, 0.08711589922313578, 0.03851571666018572, 0.033257273826166056, 0.046640567597933114, 0.05056779787992127, 0.008679252878209809, 0.002912472978096048, 0.009791709053388331, 0.013354040165722836, 0.033503117665532045, 0.03109819554083515, 0.037888920996920206, 0.10773527013952844, 0.019772624946199358, 0.015118014798645163, 0.02444877871312201, 0.04982599159120582, 0.04422694750246592, 0.015172412367974175, 0.05391285041696392, 0.07899540098151192, 0.20686131552793086, 0.0788797001587227, 0.1592641047318466, 0.09124545380473137, 0.2175971496035345, 0.11485616225400008, 0.1622947389842011, 0.14470594294834882, 0.14437709731282666, 0.13940447039203718, 0.15822769550140947, 0.16859891242347658, 0.10097419348312542, 0.12139403057517484, 0.16725265653803945, 0.2007809589849785, 0.16091692697955295, 0.1612619959632866, 0.1332713323063217, 0.19329172413563356, 0.16727618261938915, 0.07733269332675263, 0.151216403755825, 0.11011990194674581, 0.11739322377252392, 0.12252907123183832, 0.0843103880470153, 0.11048630767618306, 0.18184241896960884, 0.19972345791757107, 0.11263745240285061, 0.10429177913465537, 0.13754525687545538, 0.09114793560001999, 0.14506184728816152, 0.15635562798706815, 0.10179137228988111, 0.26502224151045084, 0.1339419517898932, 0.21738673589425161, 0.08352938151801936, 0.12658422550885007, 0.25120742968283594, 0.21406284940894693, 0.3643699293024838, 15.819048006087542, 99.62012842297554, 116.3017500936985, 99.75299209356308, 91.5240852534771, 92.15123400092125, 60.5084091424942, 49.01117227971554, 60.17021209001541, 76.39356315135956, 89.87577930092812, 110.15235006809235, 70.14326333999634, 34.70573790371418, 12.25692629814148, 1.409965285565704, 1.3162985304370522, 0.6265226716641337, 0.2377071400405839, 0.18431270204018801, 0.32144514669198543, 0.16664301190758124, 0.2730559604242444, 0.41577538184355944, 0.48339497996494174, 0.311639386927709, 0.4477475193561986, 0.7489781070034951, 0.510121617699042, 0.2961487165885046, 0.43797491875011474, 0.3272955265128985, 0.3805348853347823, 0.3193931083660573, 0.7939487532712519, 1.6266179038211703, 2.436236422508955, 4.47968459688127, 2.2073782654479146, 2.8463909262791276, 1.2189998826943338, 2.4068181635811925, 2.3325708601623774, 2.563493731431663, 1.9958210550248623, 0.41878348449245095, 1.2743293074890971, 1.367769856005907, 0.4318669839994982, 0.22908604092663154, 0.36475065106060356, 0.255557929049246, 0.2841882349457592, 0.1164508520741947, 0.2790057583479211, 0.18836328468751162, 0.3385444963350892, 0.3773075225763023, 0.5440542125143111, 0.4040559794520959, 0.36753691092599183, 0.39543059072457254, 0.7517622294835746, 0.35454505181405693, 0.5099502706434578, 0.3389738139230758, 3.080470715649426, 27.393243089318275, 78.46684589982033, 105.14158174395561, 94.99033525586128, 116.71820014715195, 110.63493177294731, 61.127403527498245, 35.56720107793808, 53.26281353831291, 64.3972572684288, 80.72419837117195, 98.3799509704113, 94.7312043607235, 120.93570783734322, 99.86293539404869, 39.59825657308102, 2.0325655583292246, 0.9149628190789372, 0.13069702981738374, 0.16249905223958194, 0.2348617310053669, 0.28419069887604564, 0.08489501487929374, 0.12802396231563762, 0.1309503841912374, 0.220746319682803, 0.11758010397898033, 0.1368828900740482, 0.12100539010134526, 0.11561247010831721, 0.12670675409026444, 0.21960863698041067, 0.13447928155073896, 0.07074671157170087, 0.2338536866591312, 0.10385619039880112, 0.1661700411932543, 0.15665913670090958, 0.2038843385525979, 0.11709680256899446, 0.0847462736419402, 0.11926884617423639, 0.18646739423274994, 0.1329554000403732, 0.11263060237979516, 0.16890481085283682, 0.11789756506914273, 0.19025702291401103, 0.14867713063722476, 0.20022091950522736, 0.11182359099620953, 0.1251434051664546, 0.1696366723626852, 0.15478355140658095, 0.08516678935848176, 0.18306080281035975, 0.07364034536294639, 0.21305838221451268, 0.17720993317198008, 0.14175869640894234, 0.14126257068710402, 0.09947910730261356, 0.1238632078457158, 0.27157430711667985], [0.05423237838840578, 0.07223109598271549, 0.0061927761453262065, 0.05635574081679806, 0.025612629542592913, 0.061951207753736526, 0.038031884614611045, 0.028935629161424004, 0.03145857874187641, 0.008864889987307834, 0.022693165301461704, 0.07025820028502494, 0.02803444665914867, 0.05743919107771944, 0.04115516487217974, 0.018324418379052076, 0.03633486005128361, 0.003462319523350743, 0.05957943736575544, 0.061097916041035205, 0.03282610829046462, 0.04155543851084076, 0.013222262568888254, 0.08380227664019912, 0.029513931040128227, 0.04917244892567396, 0.04056830417539459, 0.030244371337175835, 0.06399386533303186, 0.020072849656571634, 0.02244745319330832, 0.05760587002441753, 0.06038485684257466, 0.06835937092546374, 0.04097267817996908, 0.07396358778350987, 0.02379629175266018, 0.048361541266785935, 0.05009158398024738, 0.0321847071609227, 0.08644583635032177, 0.018422018220007885, 0.05968420264252927, 2.523170057684183, 32.34022043645382, 93.64736571907997, 79.2358486354351, 74.86120417714119, 78.72478365898132, 54.54407438635826, 34.814244881272316, 44.37785670161247, 55.00737212598324, 48.29706519842148, 77.29422122240067, 68.62200736999512, 36.45609878003597, 9.569286815822124, 0.23410094057908282, 0.2745279954979196, 0.02220639435108751, 0.17228855896973982, 0.07136787433410063, 0.1078633574070409, 0.14795344759477302, 0.1177425155765377, 0.20862525212578475, 0.19932488008635119, 0.11042767800972797, 0.08753706802963279, 0.15304778673453256, 0.11209259726456366, 0.3182361595099792, 0.2766328153666109, 0.4914901783922687, 0.7179916009772569, 2.146684597246349, 1.3864965573884547, 2.975453375838697, 2.162482487037778, 7.791207376867533, 10.077124815434217, 5.7469232473522425, 6.581148533150554, 4.524906445294619, 5.444644717499614, 1.2618776131421328, 3.072179560549557, 3.910383232869208, 4.985862085595727, 4.755005948245525, 5.275625986978412, 1.3015154236927629, 1.8758563860319555, 1.1833731131628156, 1.6401584772393107, 1.989066086243838, 1.9025129056535661, 0.8200723514892161, 0.4337242530891672, 0.2573329384904355, 0.039121220106608234, 0.07410992446239106, 0.0819189655885566, 0.0650389280053787, 0.05210894545598421, 0.06529205973492935, 0.06416237738449126, 0.08323095651576295, 0.3025128704030067, 0.11645139384199865, 0.21879208157770336, 0.23287480871658772, 1.3774873595684767, 21.454019285738468, 64.0392404794693, 50.71786969900131, 59.97164614498615, 81.43431946635246, 80.92647671699524, 38.74774821102619, 23.43182645738125, 39.8104789853096, 49.90945927798748, 57.35265947878361, 61.586939468979836, 75.74221730232239, 87.76562333106995, 59.00170259177685, 8.231544848531485, 0.36782320181373507, 0.10750686677056365, 0.01818151598854456, 0.09741828936967067, 0.07404949137708172, 0.019595056837715674, 0.06875784485600889, 0.0364890338096302, 0.013825694495608332, 0.026888782158493996, 0.028875168245576788, 0.03360901100677438, 0.03438121566432528, 0.026174860213359352, 0.060441994792199694, 0.050783373226295225, 0.016687800925865304, 0.020625502911570948, 0.01859715393948136, 0.027959330182056874, 0.016511958310729824, 0.015293476135411765, 0.02355439428356476, 0.014120432879280997, 0.02589108706160914, 0.0678426209196914, 0.05857639880559873, 0.03136072657071054, 0.033270424682996236, 0.06071077841625083, 0.06400700134690851, 0.05972303551970981, 0.041670927821542136, 0.05792586183815729, 0.03299037896795198, 0.00988407025943161, 0.03473100470728241, 0.0359734489757102, 0.025874451821437106, 0.011793237736128503, 0.015535317943431437, 0.05555174997425638, 0.033075692554120906, 0.01971256293472834, 0.07008262298768386, 0.02396100029727677, 0.02977001651743194, 0.011560151415324071, 0.004765993990076822, 0.0443955968512455, 0.04310311698645819, 0.031011648134153802, 0.06690622351015918, 0.032331466863979585, 0.021238637491478585, 0.012217496660014149, 0.035330608079675585, 0.08766243161517195, 0.022874176975165028, 0.03272622634540312, 0.008451287376374239, 0.06722086443915032, 0.06444613754865713, 0.04238834713760298, 0.005002631951356307, 0.04838078886677977, 0.06961509221582673, 0.01222041330038337, 0.00969341715972405, 0.11310113884974271, 0.05337497146683745, 0.04889036230451893, 0.00566193461054354, 0.07103836818714626, 0.0429681314562913, 0.011367623465048382, 0.026764741451188456, 0.03163166984450072, 0.04533414277830161, 0.049030234877136536, 0.035499724981491454, 0.032185230375034735, 0.06753731620847248, 0.04151831257331651, 0.054947255848674104, 0.052525115897879004, 0.09839688529609703, 0.0254327440779889, 0.008179190062946873, 7.13336625136435, 49.66248773038387, 113.59542891383171, 89.24613788723946, 100.26978716254234, 115.16384795308113, 76.56448557972908, 46.427706107497215, 34.93605114519596, 31.179050244390965, 31.421443037688732, 59.116395637393, 68.53566840291023, 42.04856649041176, 11.540611535310745, 0.36393716814927757, 0.33934263163246214, 0.052738520462298766, 0.29170547844842076, 0.08164433384081349, 0.056458357576048, 0.1843260755413212, 0.35588148166425526, 0.9230719995684922, 0.92728674528189, 0.8139652479439974, 1.1521094595082104, 2.0890697138383985, 1.2438703794032335, 2.485643746331334, 3.186597120948136, 3.5385437356308103, 2.5554319890215993, 5.261935321614146, 8.287380002439022, 5.581843480467796, 5.88687876239419, 6.744711706414819, 11.355538666248322, 8.515052385628223, 10.03262160345912, 7.902137199416757, 14.358933605253696, 8.721884787082672, 8.409709688276052, 9.778931066393852, 11.201604176312685, 7.442859169095755, 12.695192880928516, 9.281768593937159, 5.646969610825181, 7.73363096639514, 7.0685916021466255, 3.237992925569415, 9.205590281635523, 5.212719412520528, 4.419443579390645, 2.0404327986761928, 2.1180650079622865, 0.7826681085862219, 0.42756166658364236, 0.2432454764493741, 0.23777008900651708, 0.043584425729932263, 0.4160332039464265, 0.3309397684643045, 0.1541324207209982, 0.13128685910487548, 0.13283103093272075, 0.23612722638063133, 1.3820131542161107, 18.691586516797543, 55.5593229085207, 50.218610689044, 49.93476592004299, 62.633600905537605, 43.39763090014458, 22.948879972100258, 24.45117685943842, 68.4381352365017, 86.89874544739723, 81.54582068324089, 75.56016907095909, 83.08501169085503, 99.44015488028526, 81.42868056893349, 16.689399853348732, 0.161517933011055, 0.19150507781887427, 0.11075160320615396, 0.0602764030918479, 0.04590939999616239, 0.011787004623329267, 0.00865481024447945, 0.04612103082763497, 0.11739861918613315, 0.03773386779357679, 0.030364808917511255, 0.014653268008260056, 0.08359784464119002, 0.03756321835680865, 0.10244397242786363, 0.05054104716691654, 0.016695088816049974, 0.03417125466512516, 0.029335327635635622, 0.07295802963199094, 0.04292253761377651, 0.041131623947876506, 0.018546303836046718, 0.006765987354810932, 0.052687957941088825, 0.0390684645390138, 0.016844570345710963, 0.027192580309929326, 0.02992901238030754, 0.04010502962046303, 0.08381228079088032, 0.04321282867749687, 0.03880733987898566, 0.0465052777872188, 0.05522713086975273, 0.03733713419933338, 0.04421725505380891, 0.03497732352116145, 0.02351758932491066, 0.037595668763970025, 0.05811251568957232, 0.050900331989396363, 0.02397896212642081, 0.03181396357831545, 0.01918188096169615, 0.047158148809103295, 0.10265765158692375, 0.14518422744004056, 0.11692475789459422, 0.14812725858064368, 0.1364731800276786, 0.13377813011175022, 0.17061093414667994, 0.14767146116355434, 0.16620282927760854, 0.13356120034586638, 0.1545290689682588, 0.31367904623039067, 0.09062964192708023, 0.18568475497886539, 0.15681408229283988, 0.1210534961137455, 0.14737562625668943, 0.08571910308091901, 0.1552024789270945, 0.14631814003223553, 0.11138769055833109, 0.13010369759285823, 0.12843260366935283, 0.176144030992873, 0.15409795538289472, 0.16543593839742243, 0.14784249651711434, 0.1270241112797521, 0.10823396369232796, 0.10748912944109179, 0.07837100987671874, 0.254008473129943, 0.13994346256367862, 0.15834767109481618, 0.15642470709281042, 0.21273778926115483, 0.2417678158963099, 0.17187599907629192, 0.2360738065908663, 0.11404895049054176, 0.17714601941406727, 0.17640416859649122, 0.13945943384896964, 7.684440705925226, 53.73105861246586, 127.59155988693237, 99.35030490159988, 92.6692146062851, 101.60704180598259, 72.71434217691422, 44.03716318309307, 57.88115032017231, 81.57219886779785, 73.00843879580498, 112.37922817468643, 102.88099184632301, 56.495448276400566, 17.59807739406824, 1.16495740134269, 0.5850600684061646, 0.23721960838884115, 0.6295265292283148, 0.5520119948778301, 0.37051048886496574, 0.4533387708943337, 0.2658185065956786, 0.42475064867176116, 0.7771641039289534, 0.3785810776753351, 0.3234747424721718, 0.7150610676035285, 0.4095736099407077, 0.8265848457813263, 1.9717862759716809, 1.9597423472441733, 1.6506972117349505, 3.623624970205128, 6.895227329805493, 12.023575119674206, 6.090990984812379, 20.683080554008484, 21.849091686308384, 13.632813468575478, 19.125855714082718, 16.56119853258133, 22.990464940667152, 10.186405051499605, 12.675314247608185, 17.354436367750168, 14.426888208836317, 11.866996921598911, 11.312556322664022, 7.725439555943012, 5.149125549942255, 6.330107403919101, 5.226601017639041, 3.420756943523884, 6.027746228501201, 2.3162082256749272, 1.190995266661048, 0.6197058968245983, 0.5779184109997004, 0.2793177869170904, 0.18574590794742107, 0.17001703788992018, 0.2755076898029074, 0.08970626920927316, 0.36209723562933505, 0.2902033715508878, 0.7629442575853318, 0.2767800277797505, 0.3509001567726955, 0.41741736873518676, 2.8238723846152425, 31.679525189101696, 93.81273284554482, 69.20377895236015, 87.67623692750931, 113.20829048752785, 115.42452916502953, 50.809627175331116, 30.365228913724422, 55.33160872757435, 67.7648189663887, 79.30802196264267, 77.01709449291229, 95.7091198861599, 114.84767451882362, 91.02855384349823, 14.57294287160039, 0.38895104778930545, 0.3144162957323715, 0.19500390335451812, 0.23653243901208043, 0.12185837753349915, 0.1434172035078518, 0.1784815438441001, 0.1557776879053563, 0.18323309981497005, 0.09889950481010601, 0.12785074504790828, 0.16188836860237643, 0.22374453692464158, 0.191760718007572, 0.23181349301012233, 0.08103553525870666, 0.08732324786251411, 0.11825751411379315, 0.08039121748879552, 0.13174604071537033, 0.11758476466638967, 0.18189306312706321, 0.09635577138396911, 0.08403427200391889, 0.18227847525849938, 0.1999570117914118, 0.10961154563119635, 0.13530272408388555, 0.11036530049750581, 0.17435959627619013, 0.12539741263026372, 0.11226564383832738, 0.1393377364729531, 0.13873644842533395, 0.14086238981690258, 0.10765431667095982, 0.15584550536004826, 0.1999777919263579, 0.11740630041458644, 0.1507930233492516, 0.29122608073521405, 0.1753764128079638, 0.1162340707378462, 0.14456349512329325, 0.1798693896853365, 0.09410755374119617], [0.004848817670790595, 0.04119513323530555, 0.0796714900934603, 0.051639347802847624, 0.05031182743550744, 0.03387180549907498, 0.07169614851591177, 0.07503621382056735, 0.10633974306983873, 0.04673299095884431, 0.028157869528513402, 0.035229657441959716, 0.029137649180484004, 0.05750683412770741, 0.04077927820617333, 0.08295256950077601, 0.039306107646552846, 0.01449735205824254, 0.034384878163109533, 0.013821598768117838, 0.02815068182826508, 0.06694821422570385, 0.03740446554729715, 0.07224508546642028, 0.0833073012472596, 0.011168368873768486, 0.05980001107673161, 0.003778050945584255, 0.044407033346942626, 0.03318558978207875, 0.07470978758647107, 0.005388460613175994, 0.03579947471735068, 0.029631323959620204, 0.007249766522363643, 0.19302036525914446, 0.0409031797607895, 0.024217809368565213, 0.07032632944174111, 0.13359088625293225, 0.3830440866295248, 1.38023532461375, 33.28979708254337, 82.69943878054619, 88.49107280373573, 78.10873031616211, 71.61587432026863, 61.226498410105705, 43.496877774596214, 42.47879080474377, 52.939599081873894, 60.17324052751064, 56.05865031480789, 63.200085908174515, 31.973475515842438, 6.064961431547999, 0.4551149677718058, 0.6823470199014992, 0.042060562773258425, 0.014739926737092901, 0.1212976775423158, 0.09297417549532838, 0.0759007416490931, 0.1110585851711221, 0.13868261303287, 0.05951246595941484, 0.11331033543683589, 0.438002971932292, 0.36350589129142463, 1.913048552814871, 2.4641304882243276, 5.9458710718899965, 3.4367823461070657, 4.31540516205132, 11.428244914859533, 8.485368378460407, 10.601504277437925, 13.098514638841152, 5.1275203842669725, 4.6443582605570555, 6.677837194874883, 8.736591897904873, 13.330337349325418, 10.732349306344986, 8.731719609349966, 10.902977250516415, 15.37027783691883, 4.669492961838841, 11.278854981064796, 11.71845244243741, 3.479579924605787, 9.75910373032093, 11.261775847524405, 10.939102862030268, 10.924936272203922, 12.109380215406418, 5.739914048463106, 6.990513866767287, 3.467060783877969, 4.920428646728396, 9.589649923145771, 5.07856666110456, 1.5566681697964668, 0.9762872534338385, 0.6764382182154804, 0.694633066887036, 0.42141534795518965, 1.4078106824308634, 0.0733289698837325, 0.10331746540032327, 0.04755777306854725, 0.1928293364471756, 0.27499094721861184, 0.0882010675559286, 0.21387020271504298, 3.1750305416062474, 35.15932336449623, 71.52755945920944, 70.2595067024231, 68.09917822480202, 80.49362674355507, 85.68106278777122, 33.76885637640953, 17.315338365733624, 34.05648574233055, 53.79445441067219, 64.01318147778511, 69.36398595571518, 77.3400467634201, 79.43708583712578, 24.648811854422092, 0.40005817834753543, 0.2730973722646013, 0.07182608373113908, 0.02754391302005388, 0.008524241420673206, 0.026579553341434803, 0.05868615131475963, 0.0074341220351925585, 0.019021879488718696, 0.09011204587295651, 0.03598616567614954, 0.02365560838370584, 0.017260857675864827, 0.06896019142004661, 0.049942924379138276, 0.0269013300203369, 0.043965926743112504, 0.014476363194262376, 0.04164723104622681, 0.03304129400930833, 0.03105406187387416, 0.030330510562635027, 0.04142607474932447, 0.02439047002553707, 0.02929793823568616, 0.0498533063364448, 0.05621733398584183, 0.05690610640158411, 0.01890126193757169, 0.0306162615379435, 0.09772935314686038, 0.049381508215446956, 0.040555654268246144, 0.018339808666496538, 0.07222342217573896, 0.05875707836821675, 0.015038081783131929, 0.05266862870485056, 0.038943219697102904, 0.02433857534924755, 0.02700969656871166, 0.026869649591390043, 0.04214331594994292, 0.02278404685057467, 0.0582402652798919, 0.054572975932387635, 0.042276824606233276, 0.04587801086017862, 0.04618328959622886, 0.006296007959463168, 0.023087208610377274, 0.05237732460955158, 0.01169571860373253, 0.05033700850617606, 0.03421844041440636, 0.0045474013495550025, 0.05413221813796554, 0.056092653176165186, 0.0166027712111827, 0.03054857581446413, 0.05976679996820167, 0.03206392262654845, 0.023587449541082606, 0.06052881493815221, 0.05739069172705058, 0.03641500457888469, 0.07550493202870712, 0.006478364311988116, 0.05937891277426388, 0.08123513587634079, 0.09745519637363032, 0.03008137529832311, 0.12783717858837917, 0.022307421058940236, 0.06025681781466119, 0.08954814722528681, 0.0406006135744974, 0.03771215255255811, 0.04139817370742094, 0.019321627369208727, 0.0914237844699528, 0.02710597724217223, 0.08222554679377936, 0.0472254282067297, 0.09756883402587846, 0.2514836867339909, 5.180446319282055, 51.94337993860245, 102.06418767571449, 105.41446030139923, 92.52403199672699, 92.88671493530273, 81.30620554089546, 66.20223641395569, 42.76277236640453, 31.30614012479782, 33.64298813045025, 44.345436841249466, 59.44578096270561, 35.439983904361725, 7.53580360673368, 0.46343340422026813, 0.7047348248306662, 0.10736236319644377, 0.03531782087520696, 0.2096166426781565, 0.22415093699237332, 0.7971742458175868, 0.886246869340539, 0.6571994349360466, 0.44898972613736987, 1.3272013328969479, 1.9332132395356894, 2.651093043386936, 2.9768182151019573, 2.526681306771934, 6.1873409897089005, 3.0800847988575697, 1.8633412825874984, 2.734544640406966, 3.343115234747529, 8.90074783936143, 14.224474970251322, 12.979740612208843, 9.827493410557508, 11.406918559223413, 13.649937249720097, 16.318627148866653, 13.540384378284216, 16.891305819153786, 19.06850539147854, 13.75773461535573, 8.353663645684719, 4.970515659078956, 6.611442407593131, 3.1068923603743315, 6.1271393951028585, 10.170082077383995, 18.822797276079655, 9.452890511602163, 12.92704788967967, 10.909543298184872, 10.460030268877745, 6.348439995199442, 8.023483213037252, 4.082715148106217, 3.125271974131465, 0.7928687206003815, 1.3024666788987815, 0.7685370231047273, 0.5861500755418092, 0.22395775595214218, 2.619076198898256, 0.31307268189266324, 0.27572493127081543, 0.05379723123041913, 0.18465272441972047, 0.2525710518239066, 0.04465311096282676, 0.2689562476007268, 1.4443736267276108, 31.46538957953453, 59.4227010011673, 68.62446203827858, 65.9903521835804, 54.705257937312126, 42.623479440808296, 30.631265938282013, 28.309820406138897, 57.91276082396507, 94.26853358745575, 91.87571838498116, 84.49310973286629, 89.06542718410492, 96.11486211419106, 43.35991032421589, 1.0466737858951092, 0.27385094901546836, 0.026361972340964712, 0.041646507452242076, 0.07083096759743057, 0.1081210162374191, 0.01967917927686358, 0.020117699496040586, 0.01191310293506831, 0.05803678694064729, 0.03796053082623985, 0.043689465601346456, 0.051394765614531934, 0.045636349022970535, 0.02965151594253257, 0.031709194590803236, 0.0390705239988165, 0.06905857793753967, 0.15679300529882312, 0.0261442855844507, 0.04921594991174061, 0.03300271346233785, 0.045736427637166344, 0.080328565381933, 0.0131105749096605, 0.024567982472945005, 0.07329800006118603, 0.038750072053517215, 0.014063514790905174, 0.04623440130671952, 0.012513217461673776, 0.017304026550846174, 0.05111532846058253, 0.024627139064250514, 0.061090067829354666, 0.031227488798322156, 0.028287650748097803, 0.040799869093461893, 0.031084695874596946, 0.02627871264849091, 0.05773285520263016, 0.010845468768820865, 0.03852416230074596, 0.055498059300589375, 0.04723246005596593, 0.23960913094924763, 0.16311420360580087, 0.18923290364909917, 0.12304692703764886, 0.15529659809544683, 0.11748072298360057, 0.10746697633294389, 0.13079297466902062, 0.14067429990973324, 0.120071567944251, 0.10986925641191192, 0.13912818365497515, 0.0931943410250824, 0.14367699972353876, 0.13397272123256698, 0.09523550688754767, 0.09601732977898791, 0.2311155921779573, 0.07700829315581359, 0.07173445075750351, 0.14311431819805875, 0.14748595393029973, 0.08506841768394224, 0.12811122403945774, 0.22801656159572303, 0.1315637692459859, 0.1372730519506149, 0.1604848337592557, 0.14942269219318405, 0.16063185321399942, 0.21403307444415987, 0.13998542359331623, 0.16042825242038816, 0.12482523161452264, 0.1039685144496616, 0.23054905148455873, 0.2141314238542691, 0.1984910771716386, 0.22950297949137166, 0.4935408808523789, 0.366370165720582, 5.733540840446949, 60.27254819869995, 116.6872850060463, 116.24880373477936, 95.4229724407196, 94.94293659925461, 77.10566014051437, 55.03433547914028, 61.984287947416306, 75.64192548394203, 86.2157852947712, 80.66937491297722, 90.94486713409424, 48.76487709581852, 10.707547087222338, 1.54423784930259, 1.0928560327738523, 0.12815055786632001, 0.38501481525599957, 0.2903195028193295, 0.3426339675206691, 0.6884801876731217, 0.35330139042343944, 0.28547672205604613, 0.30155244225170463, 0.7477326050866395, 1.0589022422209382, 1.434627624694258, 5.140044512227178, 5.954688498750329, 14.562679622322321, 9.832639284431934, 10.045448765158653, 26.09380591660738, 19.951517209410667, 26.935707740485668, 30.05525104701519, 20.296504497528076, 21.737710162997246, 23.852239698171616, 24.613331258296967, 33.110355511307716, 30.806252248585224, 28.79852168262005, 40.29534436762333, 39.30316060781479, 22.875929586589336, 30.161913223564625, 26.84311430901289, 16.94650735706091, 25.21791871637106, 24.49921578168869, 29.196966402232647, 19.665894135832787, 24.08565167337656, 16.392394490540028, 17.03382097184658, 10.202720426023006, 16.85303807258606, 26.30312718451023, 11.358147226274014, 7.681179530918598, 4.595597852021456, 3.040975397452712, 2.0989154605194926, 0.8829282224178314, 2.613897076807916, 0.5269521020818502, 0.20107952499529347, 0.18719885498285294, 0.31677178340032697, 0.3522191313095391, 0.165000832057558, 0.370810316526331, 5.1321471109986305, 52.65965670347214, 97.93808788061142, 87.22453996539116, 93.784941136837, 114.23639371991158, 119.16984379291534, 46.118759885430336, 24.517954476177692, 44.2758359760046, 71.89160272479057, 83.70035827159882, 86.9147501885891, 97.5701992213726, 108.36597472429276, 41.643986999988556, 0.8362119854427874, 0.4846282512880862, 0.1481482168310322, 0.13652358669787645, 0.16953764017671347, 0.22824650863185525, 0.12366158116492443, 0.07929506537038833, 0.16853548848303035, 0.12666458525927737, 0.1833932107547298, 0.11680098250508308, 0.09578546058037318, 0.21370664821006358, 0.08888248528819531, 0.12685531721217558, 0.19573764991946518, 0.1741595281055197, 0.20710886630695313, 0.08604993767221458, 0.1326135074486956, 0.11199542044778354, 0.13331272930372506, 0.22031578497262672, 0.1346017062314786, 0.14067174692172557, 0.1077740325126797, 0.2211145288310945, 0.10404160115285777, 0.06447760461014695, 0.30024920124560595, 0.08567155367927626, 0.14746848377399147, 0.13398063252680004, 0.15565048379357904, 0.10017257009167224, 0.20621296047465876, 0.11594958326895721, 0.15388617612188682, 0.11407987578422762, 0.2151248330483213, 0.11008627523551695, 0.14076380291953683, 0.1094362503499724, 0.1717068487778306], [0.019672383059514686, 0.020130232514929958, 0.029693044671148527, 0.04567078467516694, 0.02200011811510194, 0.0448288960615173, 0.05773606499133166, 0.04610310053976718, 0.022456835795310326, 0.07842418475775048, 0.01865502847067546, 0.008772487035457743, 0.03963854156609159, 0.026560012593108695, 0.05989326935377903, 0.05580301891313866, 0.13250752876047045, 0.015318076475523412, 0.015037294178910088, 0.03004816604516236, 0.05910580985073466, 0.1191044901497662, 0.035492440802045166, 0.05616483074845746, 0.018190527516708244, 0.03666073709609918, 0.08145493033225648, 0.03376606800884474, 0.04566958981740754, 0.02791890910884831, 0.03848380431008991, 0.02006034632358933, 0.03566946157661732, 0.05858458469447214, 0.060136467436677776, 0.020033280197822023, 0.04584409842209425, 0.031890200698398985, 0.13104018406011164, 2.0638174563646317, 20.27447707951069, 72.74062156677246, 93.02781656384468, 81.8776036798954, 79.18160274624825, 69.33491751551628, 44.00326520204544, 45.22470586001873, 56.792466938495636, 45.03498964011669, 55.372251346707344, 56.74560405313969, 43.335595428943634, 12.947438545525074, 0.06345951158436947, 0.3102940513053909, 0.18134008889319375, 0.31494992959778756, 0.09668734812294133, 0.21221279399469495, 0.07717798522207886, 0.26951170060783625, 0.29966691217850894, 0.436526543344371, 0.4104010749142617, 1.5247646067291498, 4.4481695629656315, 1.1877939384430647, 5.564840342849493, 5.0242656748741865, 9.490656685084105, 4.607642255723476, 10.826311614364386, 6.109189633280039, 8.727500885725021, 4.033445566892624, 9.451825618743896, 10.194444470107555, 5.028205588459969, 6.124760722741485, 2.8521523671224713, 8.232249710708857, 6.851849807426333, 6.4422612357884645, 5.085599133744836, 12.693567518144846, 9.617713317275047, 9.306464418768883, 4.517727205529809, 12.276049721986055, 5.930027822032571, 12.857937198132277, 15.299387890845537, 8.68547324091196, 10.003638658672571, 11.729545947164297, 5.793917700648308, 17.134692259132862, 15.240745637565851, 20.079490542411804, 7.908034957945347, 9.52110730111599, 7.802975820377469, 2.853210847824812, 0.6999396008905023, 1.5041301702149212, 0.5703257652930915, 2.3802051041275263, 1.4967039437033236, 2.555917175486684, 2.064791629090905, 0.15497486223466694, 0.21964149927953258, 0.1358425326179713, 0.3332599002169445, 0.23403321218211204, 0.33908528450410813, 6.135829528793693, 58.86284664273262, 88.30435082316399, 54.10887233912945, 44.131417125463486, 66.35543659329414, 65.08822739124298, 29.323911890387535, 15.129748843610287, 32.5989181548357, 52.35410749912262, 68.24303850531578, 70.67587316036224, 83.43984425067902, 50.340466350317, 4.483127687126398, 0.5267988634295762, 0.054472734045702964, 0.01302684766415041, 0.04123953593079932, 0.07627597151440568, 0.02932607490947703, 0.07954039712785743, 0.07216043610242195, 0.02956253243610263, 0.03890799365763087, 0.0187531088522519, 0.004062818343300023, 0.020355088418000378, 0.03613979395595379, 0.05063762284407858, 0.03494826843962073, 0.05353652588382829, 0.0663712018285878, 0.019079900594078936, 0.02982561636599712, 0.02111128495016601, 0.038372085109585896, 0.04506209741521161, 0.045386004057945684, 0.0926365502527915, 0.03637991954747122, 0.0365361527656205, 0.00579695260967128, 0.017421892589482013, 0.025020486609719228, 0.046560790433431976, 0.05203321670705918, 0.016548989624425303, 0.007308752419703524, 0.07573834489448927, 0.08207608567317948, 0.016167345747817308, 0.009333448633697117, 0.046250598679762334, 0.020132607387495227, 0.0462338298530085, 0.04011376098787878, 0.04622159925929736, 0.05060488299932331, 0.032857790574780665, 0.03395897445443552, 0.08370096606086008, 0.02467139518557815, 0.0462246235110797, 0.08056854625465348, 0.026199182248092256, 0.03140114393318072, 0.04236313638102729, 0.05921379975916352, 0.02998064173880266, 0.021306618218659423, 0.027699316888174508, 0.09134067135164514, 0.06470831605838612, 0.023165438396972604, 0.04903691049548797, 0.012462704107747413, 0.05260769838059787, 0.0729220948414877, 0.10001596208894625, 0.05601512471912429, 0.04361571838671807, 0.016662771995470393, 0.04635457727999892, 0.0929179132799618, 0.030501069086312782, 0.06699810881400481, 0.061418364275596105, 0.044242688454687595, 0.024186641021515243, 0.021034177661931608, 0.05395345331635326, 0.05532069342734758, 0.03215380413166713, 0.15773606719449162, 0.05899277704884298, 0.2634017472155392, 6.258096043020487, 35.153692066669464, 94.26239311695099, 108.3285391330719, 96.65752619504929, 105.87710827589035, 105.6382454931736, 80.81761255860329, 49.23279158771038, 32.299733608961105, 39.61680717766285, 50.55044308304787, 59.05795857310295, 48.20408418774605, 14.077164474874735, 0.1567599203553982, 0.4733556811697781, 0.13800117303617299, 0.05554654009756632, 0.20051598257850856, 0.2717617736198008, 0.04340618412243202, 0.320996978553012, 0.5557712994050235, 1.1908093141391873, 0.9886423498392105, 0.9525484428741038, 1.141579037066549, 0.5084500042721629, 1.6721819713711739, 1.927354666404426, 2.5424148375168443, 1.730113544035703, 1.5827194531448185, 2.1389800356701016, 3.9551068330183625, 2.969078505411744, 1.9151135045103729, 2.574006342329085, 6.632846659049392, 11.024309489876032, 8.868284281343222, 13.369651939719915, 10.640779919922352, 14.721073172986507, 10.923724137246609, 5.4130384884774685, 3.3871988067403436, 0.30049387249164283, 1.0093116969801486, 1.6136892163194716, 0.13211871759267524, 4.247082453221083, 4.042321890592575, 9.383459687232971, 17.345535345375538, 10.751274190843105, 4.351739762350917, 1.4940183190628886, 0.7001421775203198, 1.4083272172138095, 2.57288730237633, 1.4199712174013257, 1.8279407196678221, 5.424445951357484, 5.789876617491245, 5.634510079398751, 1.3290476775728166, 0.920398011803627, 0.9436735440976918, 5.9339734353125095, 1.9145557656884193, 0.14990729978308082, 0.28608691587578505, 0.08494119872921146, 0.20970288023818284, 0.17897326120873913, 0.40946160501334816, 6.288860617205501, 47.36276373267174, 80.57809621095657, 55.43384224176407, 42.8062192350626, 27.43631187826395, 39.41379927098751, 29.956273958086967, 14.712478034198284, 54.92971569299698, 84.57344502210617, 96.19644373655319, 85.81397965550423, 95.71806460618973, 73.26782047748566, 12.724136877804995, 0.39538484474178404, 0.03842782411084045, 0.02552323971031001, 0.053057050245115533, 0.02020446027017897, 0.045767312112729996, 0.05378189103794284, 0.037653151812264696, 0.02032440617767861, 0.026361708878539503, 0.03484520268102642, 0.014823159526713425, 0.015677005067118444, 0.05713806465792004, 0.045642349286936224, 0.03283178200945258, 0.04553181381197646, 0.036797704160562716, 0.02611792449897621, 0.08426784072071314, 0.031384178437292576, 0.06315786566119641, 0.06797276393626817, 0.07713979430263862, 0.017167152254842222, 0.015347783719334984, 0.056036706373561174, 0.019141764169035014, 0.014032885428605368, 0.03284095124399755, 0.04069334863743279, 0.023355500561592635, 0.033300181094091386, 0.038637529069092125, 0.018592188971524592, 0.040634047327330336, 0.0639105295704212, 0.00430863388828584, 0.013055213476036442, 0.017917259465320967, 0.017845404727268033, 0.02393360948190093, 0.07626185586559586, 0.13942922843853012, 0.09585979409166612, 0.10379361992818303, 0.1821500391815789, 0.16150412906426936, 0.17140929208835587, 0.16118505009217188, 0.16143292741617188, 0.14591677172575146, 0.24119835114106536, 0.12083648471161723, 0.14044309122255072, 0.12346575065748766, 0.08364157940377481, 0.2641708793817088, 0.11721901944838464, 0.1858282566536218, 0.07206772701465525, 0.14876048866426572, 0.1132041637902148, 0.15898127225227654, 0.15340554644353688, 0.14149513008305803, 0.20931587991071865, 0.10146294225705788, 0.19021871325094253, 0.24245017615612596, 0.12902292277431116, 0.21931094670435414, 0.14156720746541396, 0.11026603824575432, 0.09124080796027556, 0.13583463616669178, 0.08855591804604046, 0.1895231576054357, 0.24020489741815254, 0.3057613695273176, 0.15269710711436346, 0.3667880839202553, 6.721473103389144, 38.15520040690899, 109.87719163298607, 121.69252842664719, 99.80523928999901, 99.7457192838192, 92.41689294576645, 55.188409611582756, 57.722334042191505, 80.38364544510841, 67.64623492956161, 82.06789746880531, 82.40532696247101, 64.8110930621624, 22.91458871215582, 1.5946109150536358, 0.7521013612858951, 0.433061663643457, 0.7991621922701597, 0.28161805879790336, 0.4264466045424342, 0.11690822284435853, 0.4995771835092455, 1.0248111840337515, 1.6524628107436001, 2.2989623760804534, 5.968016283586621, 11.866137217730284, 7.176612680777907, 16.4192970469594, 22.74551298469305, 27.430804073810577, 23.564163856208324, 29.44413173943758, 22.50034064054489, 26.277197375893593, 18.45129121094942, 32.289607152342796, 28.041106425225735, 15.106409545987844, 15.34978173673153, 14.25770228728652, 25.695083811879158, 25.616473630070686, 23.317059315741062, 20.126484520733356, 31.11181665211916, 27.78878476470709, 26.608970873057842, 24.673588424921036, 27.90145631879568, 20.7596293464303, 38.1438922137022, 34.04558792710304, 25.16555182635784, 31.285535730421543, 32.50735066831112, 16.24770775437355, 35.52355282008648, 28.988769873976707, 45.482807010412216, 27.829284891486168, 27.305416502058506, 20.74929390102625, 11.73685010522604, 7.129266746342182, 6.077804742380977, 0.8589530526660383, 3.861392461694777, 5.100909462198615, 7.831706553697586, 3.078075419180095, 0.3480054542887956, 0.394410434528254, 0.27627198316622525, 0.3980604949174449, 0.5187873495742679, 0.5041414510924369, 11.294830273836851, 84.87401649355888, 104.57956150174141, 72.88238435983658, 66.8666535615921, 92.72471442818642, 82.93991267681122, 39.32749830186367, 22.351658418774605, 42.84271627664566, 70.0721463561058, 87.84372434020042, 89.26465049386024, 109.93234947323799, 78.02668511867523, 10.314128547906876, 0.5246994167100638, 0.12207474326714873, 0.08415599906584248, 0.16523186262929812, 0.25483017903752625, 0.08155286413966678, 0.19326270616147667, 0.16961817804258317, 0.12787070882041007, 0.0926571745367255, 0.1426883996464312, 0.15760611713631079, 0.09512644086498767, 0.20451955759199336, 0.20555234514176846, 0.1136011237394996, 0.15497373417019844, 0.11135744804050773, 0.15631403803126886, 0.1734088605735451, 0.12932925164932385, 0.14453401701757684, 0.09991510421968997, 0.1264454735792242, 0.1656871405430138, 0.06729011423885822, 0.11961504322243854, 0.1502015464939177, 0.1681407995056361, 0.10190918081207201, 0.1686750864610076, 0.10830363651621155, 0.10091029456816614, 0.0914684246527031, 0.12679085426498204, 0.17614875105209649, 0.1580490605556406, 0.1228021815768443, 0.23191904125269502, 0.11889648099895567, 0.14110832271398976, 0.13230225071310997, 0.21293831756338477], [0.058907459751935676, 0.046572241772082634, 0.061893587408121675, 0.13082515419228002, 0.0295763493704726, 0.015632643189746886, 0.0494194542261539, 0.013675355785380816, 0.018090768026013393, 0.006891866732985363, 0.010552299099799711, 0.0544868682482047, 0.019860040665662382, 0.03655771586636547, 0.021858499640075024, 0.016946235300565604, 0.0139114403827989, 0.07051280888845213, 0.09053986432263628, 0.03285529695858713, 0.02304311390616931, 0.045885795989306644, 0.01912073541461723, 0.05240336657152511, 0.04219703630951699, 0.025049851537914947, 0.013235819751571398, 0.07597028830787167, 0.0396165628626477, 0.0514939017011784, 0.03723114808963146, 0.021401568592409603, 0.03531046990246978, 0.01674565690336749, 0.021970615889586043, 0.08595860897912644, 0.07188616058556363, 0.6665100040845573, 27.702497094869614, 85.09321913123131, 100.60978531837463, 86.08577147126198, 80.75801655650139, 64.21119645237923, 50.03774419426918, 35.80979906022549, 31.435861364006996, 55.592080950737, 72.0346650481224, 76.18585109710693, 43.80162142217159, 13.656120467931032, 0.5771605891641229, 0.5324500508140773, 0.18495102325687185, 0.03873305831803009, 0.15932844893541187, 0.12518144765635952, 0.16737401252612472, 0.052512150577967986, 0.32791361678391695, 0.8116677962243557, 1.165875408332795, 3.4000554168596864, 3.9125386672094464, 0.32695871021132916, 2.8212602622807026, 7.886421242728829, 8.568052891641855, 7.545487387105823, 8.775524608790874, 21.839077323675156, 24.042197205126286, 34.715028405189514, 40.65480127930641, 33.196876868605614, 8.414637073874474, 7.441479843109846, 8.88339702039957, 6.0834787879139185, 8.843027036637068, 10.738725364208221, 10.558698624372482, 8.248195555061102, 11.841759625822306, 11.447260994464159, 4.758877465501428, 2.7406898606568575, 0.8969117689412087, 1.7215359793044627, 0.7031593343708664, 1.3142529339529574, 5.92901517637074, 16.512941122055054, 4.041617028415203, 7.018890269100666, 7.264084937050939, 11.472949516028166, 5.214369473978877, 6.403567912057042, 3.9697265485301614, 13.998676836490631, 33.03258128464222, 60.29630832374096, 83.48857283592224, 81.11091122031212, 56.503663435578346, 25.006399266421795, 3.4226026944816113, 0.711519360775128, 0.33136599871795624, 0.3617278835736215, 0.1872809513588436, 0.07051602980936877, 0.16957747866399586, 0.015196601743809879, 0.45274190604686737, 1.0807998734526336, 0.1338840345852077, 7.704968154430389, 56.59873813390732, 67.60901972651482, 78.07371899485588, 60.07469281554222, 117.24869728088379, 138.0196139216423, 29.995529651641846, 25.787126272916794, 38.559164330363274, 62.26803012192249, 58.27805042266846, 78.905099183321, 68.46682369709015, 17.046497091650963, 0.26912058878224343, 0.12872164050349966, 0.034104698861483485, 0.056713055237196386, 0.0806223668041639, 0.03741995416930877, 0.07526836503529921, 0.028628623076656368, 0.034535200175014324, 0.06012237034155987, 0.05683002142177429, 0.08150672481860965, 0.01283365363633493, 0.05214745920966379, 0.02598276456410531, 0.04998174983484205, 0.03795395539782476, 0.01181071624159813, 0.02384138835623162, 0.033807613435783423, 0.05805091743241064, 0.034925547588500194, 0.14648602867964655, 0.050053159284288995, 0.042411112517584115, 0.03560647550330032, 0.07941318559460342, 0.046096836813376285, 0.0346097451983951, 0.02410563003650168, 0.04381446182378568, 0.026124906253244262, 0.0635650746698957, 0.12339547669398598, 0.0704987600329332, 0.01770083064911887, 0.04276825624401681, 0.03848374864901416, 0.04863392059633043, 0.02182158707000781, 0.021060742838017177, 0.028351412365736905, 0.02114402479492128, 0.06098947342252359, 0.04258854147337843, 0.08350296106073074, 0.04350506416813005, 0.017714907335175667, 0.03778981088544242, 0.019520732603268698, 0.044300019362708554, 0.074477992602624, 0.04883167697698809, 0.056818425364326686, 0.021017570252297446, 0.026553218231128994, 0.04464630546863191, 0.06413017559680156, 0.019012361444765702, 0.05291934474371374, 0.0275247637546272, 0.010597343753033783, 0.013714634878851939, 0.03258538155932911, 0.01214066118336632, 0.03953470768465195, 0.1247521152254194, 0.02884277535486035, 0.018366750482528005, 0.04954762312991079, 0.05993492610286921, 0.012923390422656666, 0.023160827804531436, 0.0165060767903924, 0.05126617368659936, 0.05131443183927331, 0.04269437544280663, 0.018161598600272555, 0.06348542738123797, 1.6956498683430254, 43.59287582337856, 103.84461253881454, 118.20916414260864, 99.51089948415756, 106.10574200749397, 92.37510278820992, 83.61226379871368, 46.94159813225269, 18.695612400770187, 42.21807539463043, 58.710281029343605, 73.7448088824749, 49.01513546705246, 15.78543120995164, 0.584457681979984, 0.6945634237490594, 0.08454682887531817, 0.12877280416432768, 0.07757167230010964, 0.6746518984436989, 0.3205038659507409, 0.0799320061923936, 0.3911211766535416, 0.06754093046765774, 0.8609252655878663, 2.009910698980093, 3.5108280228450894, 4.480754239484668, 6.694422829896212, 7.567663472145796, 12.935971710830927, 13.599006682634354, 16.595022417604923, 27.54948690533638, 35.45834071934223, 47.29452319443226, 52.919475361704826, 40.835637375712395, 13.670111317187548, 2.081767455674708, 1.0114496760070324, 5.285791866481304, 7.633787048980594, 8.102606367319822, 11.63947083055973, 10.786895379424095, 6.236134646460414, 1.199233818333596, 2.142957947216928, 1.2533500394783914, 1.033047242090106, 1.7033601296134293, 0.2769454970257357, 1.356944355648011, 1.6086654108949006, 2.898227507248521, 3.524735039100051, 1.6438256367109716, 4.753822311758995, 4.001698270440102, 1.8855806579813361, 5.343484645709395, 8.630457893013954, 23.48133970052004, 48.67574527859688, 78.11220332980156, 102.40063682198524, 98.55957493185997, 74.73484575748444, 38.18537838757038, 8.364566210657358, 1.7661538976244628, 0.11629002125118859, 0.15680666081607342, 0.06991546164499596, 0.12120378101826645, 0.20667965261964127, 0.03542850477970205, 0.20424883696250618, 1.2624657503329217, 0.4210025357315317, 6.89185643568635, 49.696039929986, 66.96767494082451, 74.7694618999958, 34.93746466934681, 68.31154882907867, 87.00671285390854, 26.437736861407757, 46.47167354822159, 64.9684502184391, 95.91400489211082, 76.62621706724167, 85.06890803575516, 87.40083530545235, 32.796819135546684, 0.3449137561256066, 0.32959995442070067, 0.022764660097891465, 0.06139155048003886, 0.008617208404757548, 0.051021906911046244, 0.10580494403257035, 0.02488679798261728, 0.06079618848161772, 0.04356459554401226, 0.01651218281040201, 0.09849776542978361, 0.026842845072678756, 0.012799430423910962, 0.05532638941076584, 0.021515890875889454, 0.03768854483496398, 0.0765652755217161, 0.05933774584264029, 0.02158812596462667, 0.05139161519764457, 0.0269311198280775, 0.08738779986742884, 0.03430071119510103, 0.05467929600854404, 0.01783523544872878, 0.07785755500663072, 0.05940144808846526, 0.052298241353128105, 0.02238565641164314, 0.05598143492534291, 0.04730482316517737, 0.05182635417440906, 0.0262815921814763, 0.04748716513859108, 0.039172335527837276, 0.02996261126099853, 0.015290101218852215, 0.010770846747618634, 0.01357093004116905, 0.03335453227919061, 0.04560471497825347, 0.18173066637245938, 0.1934777805581689, 0.19701126439031214, 0.24417967710178345, 0.12425874287146144, 0.13010148599278182, 0.15278074715752155, 0.1204969892569352, 0.11678484821459278, 0.21533716149860993, 0.12916443549329415, 0.17475686792749912, 0.15635194693459198, 0.08670205541420728, 0.11186716990778223, 0.1139665646769572, 0.09869640867691487, 0.11814019540906884, 0.15954193513607606, 0.07236507590278052, 0.1681504919542931, 0.11880914506036788, 0.10834625805728137, 0.26041935256216675, 0.23026755487080663, 0.16132583550643176, 0.11028738983441144, 0.19998181436676532, 0.264993475866504, 0.16982234286842868, 0.15532226156210527, 0.10301167829311453, 0.11767133619287051, 0.11936819748370908, 0.16825476370286196, 0.17370968271279708, 0.21599716827040538, 2.6267403876408935, 51.453795209527016, 120.08073091506958, 132.6107257604599, 107.61434465646744, 103.0307038128376, 83.85394603013992, 63.52412112057209, 47.467645704746246, 44.808153212070465, 80.46798571944237, 100.35800322890282, 100.76357826590538, 67.45068982243538, 23.416750766336918, 2.371457261033356, 0.9812608896754682, 0.4604941135039553, 0.29197564988862723, 0.502517216373235, 0.27473627182189375, 0.23463911638827994, 0.2891002729302272, 1.2918520672246814, 2.421982199884951, 6.336114406585693, 14.96563469991088, 13.452248107641935, 8.320947401225567, 11.332808285951614, 18.413384445011616, 19.606149941682816, 15.05705114454031, 18.57293028384447, 28.67748487740755, 29.749504253268242, 40.85312783718109, 46.06398582458496, 39.796427339315414, 13.855099640786648, 17.648538686335087, 27.467209920287132, 12.569232489913702, 17.824037969112396, 33.218315318226814, 26.898534335196018, 29.36522327363491, 30.201940275728703, 27.63948317617178, 16.021281704306602, 10.60050018131733, 6.247458513826132, 6.4324957598000765, 5.734469415619969, 9.170112535357475, 20.916251242160797, 39.12348344922066, 22.74692840874195, 24.546692334115505, 28.33630308508873, 26.43790975213051, 18.39010499417782, 14.516705889254808, 8.505674488842487, 18.388976454734802, 36.82415843009949, 63.28773580491543, 93.37671384215355, 87.25661024451256, 61.694523096084595, 28.02446521818638, 4.409302873536944, 2.142584854736924, 0.4513542976928875, 0.4990264505613595, 0.2241792721906677, 0.3144040354527533, 0.43672202504239976, 0.15722426731372252, 0.488512622541748, 2.013195385225117, 0.3027720283716917, 13.333989903330803, 77.44490593671799, 89.64206904172897, 104.31395575404167, 84.67317447066307, 133.38676571846008, 154.27599281072617, 37.866016924381256, 34.79649603366852, 48.376784920692444, 81.85903787612915, 74.55063924193382, 98.22186425328255, 98.69897425174713, 30.892766006290913, 0.3123156912624836, 0.3453936584992334, 0.20213604642776772, 0.13323161256266758, 0.1482943308656104, 0.16378798463847488, 0.24189424817450345, 0.14904023380950093, 0.16451897041406482, 0.1254166045691818, 0.1673772482899949, 0.24975632317364216, 0.09282148603233509, 0.267673697671853, 0.12834298191592097, 0.14483026752714068, 0.1557056253659539, 0.13994720298796892, 0.10541822572122328, 0.1727998541900888, 0.15760291105834767, 0.2061167187639512, 0.3079561673803255, 0.13001867715502158, 0.16421872715000063, 0.13411864230874926, 0.14221045654267073, 0.2194974187295884, 0.13127685495419428, 0.07769096511765383, 0.09824149441556074, 0.18654266285011545, 0.1258079390390776, 0.19278455525636673, 0.17657845455687493, 0.1952386149787344, 0.17531595745822415, 0.1611879889969714, 0.13634989445563406, 0.08047776675084606, 0.09136911045061424, 0.0590324559743749], [0.0819735208642669, 0.0010186964846070623, 0.033645817820797674, 0.07707789918640628, 0.017996808419411536, 0.049342935089953244, 0.010937333663605386, 0.08484635967761278, 0.0628670773585327, 0.06020953558618203, 0.039970886427909136, 0.07132787257432938, 0.06869818360428326, 0.05256240510789212, 0.0644360962905921, 0.07193944678874686, 0.03091545466304524, 0.005630805690088891, 0.04570824828988407, 0.052784455692744814, 0.05589914559095632, 0.03842346399324015, 0.02093767063342966, 0.04415647315909155, 0.04900286818156019, 0.039033338689478114, 0.01610700914170593, 0.02773877131403424, 0.04851735517149791, 0.0949915406818036, 0.0652569487283472, 0.07587421729112975, 0.056479464255971834, 0.026290995192539413, 0.035475156182656065, 0.1525322612724267, 11.907993871718645, 65.85078567266464, 99.85442385077477, 98.0823965370655, 76.2592251598835, 75.66558301448822, 50.726875215768814, 38.36050719022751, 28.02270781248808, 52.882453948259354, 93.8139259815216, 86.84218168258667, 71.98725879192352, 18.827214539051056, 0.6924789387267083, 0.862258697161451, 0.09131681130384095, 0.07275264768395573, 0.2383755033952184, 0.14326191652799025, 0.07564070794614963, 0.22688940254738554, 0.45745403913315386, 1.7983169155195355, 11.52986666187644, 26.939822919666767, 44.76729780435562, 58.06626498699188, 56.90635822713375, 63.96349534392357, 65.98317056894302, 66.99469149112701, 79.19908940792084, 86.02308243513107, 65.9245017170906, 104.53574985265732, 101.05090364813805, 100.29716089367867, 101.65264695882797, 86.52395635843277, 57.893134877085686, 13.130560219287872, 2.100373157300055, 6.393279489129782, 7.55314682610333, 7.245274996384978, 6.785744754597545, 10.234681461006403, 7.607293920591474, 1.346952198073268, 1.0174252116121352, 5.761472191661596, 15.01055208966136, 20.662679448723793, 14.680182617157698, 6.231874600052834, 1.084974780678749, 4.303950676694512, 12.52090573310852, 6.135438149794936, 5.064810924232006, 6.5188252273947, 16.527604535222054, 38.44118446111679, 68.40048685669899, 97.50909850001335, 115.98440632224083, 126.60935059189796, 115.61688244342804, 121.54812097549438, 122.56095662713051, 118.51791277527809, 84.7786720097065, 38.752843737602234, 16.004235818982124, 13.294715210795403, 4.529052497819066, 0.4804029077058658, 0.058697754793684, 0.05362011397664901, 0.1375602334155701, 0.2322820998961106, 0.15973575442330912, 0.7318887021392584, 0.11405741097405553, 9.48052167892456, 41.80860936641693, 82.23900228738785, 98.167884349823, 52.2017964720726, 61.155864000320435, 43.67758087813854, 29.130384474992752, 31.279142573475838, 46.30785673856735, 63.85086178779602, 75.30470877885818, 77.12722778320312, 35.53778685629368, 1.3151954021304846, 0.6097750109620392, 0.05370530881918967, 0.0698221217317041, 0.04902584136289079, 0.04983427767001558, 0.061835659071221016, 0.056944197131088004, 0.08792534485110082, 0.024800920364214107, 0.03370596888998989, 0.019251494413765613, 0.0031650348773837322, 0.04183734330581501, 0.034675618226174265, 0.05180046435270924, 0.06059650251700077, 0.035894387983717024, 0.03306256767245941, 0.01583506953465985, 0.010515503417991567, 0.08576286752941087, 0.01959440745849861, 0.05127133532369044, 0.006344150615404942, 0.021852052232134156, 0.04653461859561503, 0.052602291834773496, 0.01194510341520072, 0.03420865519728977, 0.007467476934834849, 0.0752958319208119, 0.036736113324877806, 0.034087280655512586, 0.054372139638871886, 0.04291434430342633, 0.008117538927763235, 0.0653879897436127, 0.04090636357432231, 0.05126776930410415, 0.046765953447902575, 0.0434206856880337, 0.034526342642493546, 0.030683425902680028, 0.06692676615784876, 0.004092769104317995, 0.025546038486936595, 0.023308773088501766, 0.013617572167277103, 0.05926181671384256, 0.04855163126194384, 0.029047109019302297, 0.0491765121842036, 0.03910776867996901, 0.07359620984061621, 0.0077014960425003665, 0.04467878185096197, 0.053623357161995955, 0.025945345478248782, 0.020838911186729092, 0.10107454669196159, 0.031695594734628685, 0.06064688692276832, 0.028851041024609003, 0.021296632621670142, 0.04701041318185162, 0.029383552391664125, 0.03987089316069614, 0.009203005974995904, 0.046294897474581376, 0.04950110160280019, 0.02493281299393857, 0.06734084003255703, 0.0630407250719145, 0.009003523173305439, 0.062005625732126646, 0.07672976513276808, 21.659677550196648, 87.28150650858879, 113.25963333249092, 110.90446650981903, 99.04534846544266, 104.90512043237686, 93.10068145394325, 60.652474611997604, 19.637106880545616, 24.492995515465736, 56.19347468018532, 76.27439394593239, 76.85308769345284, 23.021623268723488, 0.6495240842923522, 1.115097664296627, 0.2647166547831148, 0.2670367865357548, 0.19747711048694327, 0.3266297606751323, 0.4047687677666545, 0.0779846403747797, 0.1457430052687414, 3.2853096490725875, 18.395514003932476, 39.16018187999725, 61.80162414908409, 75.39391279220581, 76.66736885905266, 82.39490792155266, 84.46993097662926, 89.79317933320999, 94.9968633055687, 102.48057693243027, 84.12615582346916, 118.24472263455391, 113.6520154774189, 107.0920018851757, 110.5207023024559, 95.32439813017845, 70.25610968470573, 18.1880584359169, 2.1551614673808217, 0.4335902805905789, 6.068673357367516, 10.540016926825047, 8.282440267503262, 4.290200164541602, 0.8073020679876208, 0.5973401782102883, 2.7315399516373873, 10.943921003490686, 22.275630198419094, 29.60066244006157, 22.260334119200706, 11.822203025221825, 2.9692836944013834, 1.4197771903127432, 0.6384160928428173, 0.5021704849787056, 11.187331192195415, 13.9121687784791, 25.24161994457245, 51.88756853342056, 83.60107719898224, 102.72095963358879, 117.21953764557838, 126.39289900660515, 117.20166340470314, 120.4785467684269, 127.42881461977959, 124.61324170231819, 100.93584582209587, 57.718465849757195, 29.072950556874275, 23.694301173090935, 10.818990357220173, 2.1711137238889933, 0.05775069643277675, 0.08775729293120094, 0.1482254298753105, 0.28552784118801355, 0.12302069953875616, 1.1133953556418419, 0.15709348605014384, 7.9936424642801285, 43.26322831213474, 76.14542126655579, 90.50752580165863, 55.29070012271404, 30.03159161657095, 26.91012941300869, 34.579789862036705, 54.2532379925251, 70.26726588606834, 85.5144265294075, 86.61510586738586, 91.21934920549393, 57.54590950906277, 5.098049640655518, 0.4644574789563194, 0.01780943839548854, 0.03971832244133111, 0.08160255092661828, 0.0790938691352494, 0.03883975688950159, 0.03968149336287752, 0.029930305572634097, 0.060791880314354785, 0.0320271937380312, 0.05944904944044538, 0.07251868562889285, 0.06910663199960254, 0.04616558566340245, 0.016870079816726502, 0.03966685078921728, 0.06076173798646778, 0.03129880176857114, 0.059400386817287654, 0.014031439168320503, 0.054683878770447336, 0.0496886237669969, 0.08952706280979328, 0.034819524371414445, 0.08345826150616631, 0.035528817170416005, 0.04921771622321103, 0.008653917811898282, 0.023005169750831556, 0.04530332880676724, 0.10803355413372628, 0.021269579483487178, 0.054549268024857156, 0.0987633726617787, 0.01509231793534127, 0.031551918655168265, 0.024167638330254704, 0.040097693490679376, 0.04240839996782597, 0.0035366446854823153, 0.13218971143942326, 0.09374899993417785, 0.17051083326805383, 0.2634698763722554, 0.15278423525160179, 0.14986594731453806, 0.19123380800010636, 0.13835964520694688, 0.11978443842963316, 0.14108040311839432, 0.21882970846490934, 0.1592794226598926, 0.12382826011162251, 0.1547213297453709, 0.184813859523274, 0.1668313393020071, 0.16023771342588589, 0.09249011709471233, 0.11050200409954414, 0.1510532945394516, 0.10037398897111416, 0.10795981434057467, 0.08444432343821973, 0.13332435133634135, 0.17279931984376162, 0.21379615121986717, 0.10959023114992306, 0.08778243689448573, 0.2640203124610707, 0.16673981765052304, 0.13858169579179958, 0.11512663797475398, 0.18380159977823496, 0.11127452045911923, 0.15124013763852417, 0.23501143703470007, 26.157448701560497, 104.68962639570236, 129.33648705482483, 118.25339376926422, 97.77657374739647, 97.09096893668175, 67.02470228075981, 52.42508389055729, 39.88180495798588, 81.35753318667412, 136.31225913763046, 112.22371771931648, 94.31733056902885, 30.08654236793518, 1.9886300596408546, 1.5332535887137055, 0.48597394314128906, 0.5053874873556197, 0.6515714025590569, 0.5176112533081323, 0.3008278686320409, 0.4577293462352827, 1.1025782860815525, 3.865292714908719, 14.485325273126364, 31.330177634954453, 52.586860209703445, 66.2187959253788, 65.44974759221077, 72.1278740465641, 77.17924699187279, 81.21934980154037, 89.66027766466141, 96.4776286482811, 85.54899707436562, 120.18410056829453, 116.55702039599419, 116.48093327879906, 117.50668823719025, 100.39673075079918, 68.44295337796211, 15.663851983845234, 6.976526817306876, 22.95948900282383, 26.287559419870377, 30.233379788696766, 25.946121141314507, 30.155552364885807, 22.07257479429245, 5.928123649209738, 3.183971461839974, 8.799218237400055, 23.120277374982834, 30.20503330975771, 22.816624268889427, 9.074232280254364, 2.5460217939689755, 15.405044071376324, 28.2057211920619, 20.41203159838915, 21.811509802937508, 15.476237051188946, 19.9758131057024, 44.760499969124794, 78.43539878726006, 104.11214098334312, 119.37960013747215, 140.74151426553726, 128.13085734844208, 134.38713043928146, 136.5352463722229, 131.88146889209747, 96.62249967455864, 46.15562550723553, 19.933515675365925, 15.154360122978687, 6.006532441824675, 1.2433353206142783, 0.1685486690257676, 0.31306597287766635, 0.37115384184289724, 0.8805998973548412, 0.28150020574685186, 1.2245819019153714, 0.1240629494714085, 17.759849913418293, 61.763983368873596, 110.41062980890274, 121.9775739312172, 69.72322627902031, 81.70706883072853, 53.81903909146786, 37.815654426813126, 39.922998547554016, 60.91722920536995, 83.68487030267715, 93.39358493685722, 107.62651920318604, 59.273517206311226, 3.7253060890361667, 0.6970236136112362, 0.1483858228311874, 0.1297363344929181, 0.18025097233476117, 0.16635673586279154, 0.13493816630216315, 0.20457946375245228, 0.1696495115174912, 0.14850017294520512, 0.10134013908100314, 0.258280512643978, 0.13269722170662135, 0.10045864575658925, 0.18742172193014994, 0.11859714315505698, 0.1964483899064362, 0.20295030117267743, 0.23112473543733358, 0.1838629605481401, 0.09967015837901272, 0.22299090080196038, 0.1574775029439479, 0.13114831497659907, 0.09503341265372, 0.13544068933697417, 0.11426688215578906, 0.15230204706313089, 0.12004128089756705, 0.1814997842302546, 0.11854263982968405, 0.33797702053561807, 0.12322630413109437, 0.11356829112628475, 0.1194021210540086, 0.11744938950869255, 0.12362819194095209, 0.1903773844242096, 0.19618026679381728, 0.12330610727076419, 0.12249154082383029], [0.06867470205179416, 0.0035070077137788758, 0.027449567496660165, 0.027735027179005556, 0.01681125162576791, 0.03765027227927931, 0.038649488778901286, 0.017462723699281923, 0.04225921344186645, 0.025855885141936596, 0.011668705355987186, 0.0642354715091642, 0.0412155942467507, 0.035172393327229656, 0.01477878837249591, 0.0449311009288067, 0.005252476430541719, 0.07048009501886554, 0.04925253779219929, 0.06758580813766457, 0.10431383576360531, 0.017578827137185726, 0.0676975681562908, 0.02747704365901882, 0.07720775276538916, 0.03163758847222198, 0.035752997719100676, 0.02108813921950059, 0.062100642899167724, 0.015190074554993771, 0.10202382778516039, 0.08050096628721803, 0.0719592472887598, 0.057459666932118125, 0.12872953695477918, 30.353930220007896, 94.33043226599693, 103.50031301379204, 84.6070808172226, 72.02774181962013, 63.64638715982437, 32.32040449976921, 19.21653214842081, 34.57696281373501, 78.69212821125984, 80.16863778233528, 77.88957327604294, 45.33285565674305, 4.125079549849033, 0.8130410662852228, 0.020295514368626755, 0.1269098650664091, 0.22934929555049166, 0.22515182703500614, 0.04328117676777765, 0.039955794854904525, 0.12148348163464107, 3.195404098369181, 4.307758072391152, 34.51112374663353, 80.0650705397129, 102.53163859248161, 112.35181644558907, 117.4792917072773, 121.76558330655098, 119.41929280757904, 116.64554804563522, 111.78619399666786, 108.98613184690475, 108.22275280952454, 105.76406434178352, 101.78814768791199, 107.22706943750381, 94.1331696510315, 96.82494521141052, 94.15708556771278, 92.11171612143517, 55.717755407094955, 12.333737276494503, 2.077617128379643, 4.926743432879448, 2.3205511551350355, 6.119754491373897, 5.068697165697813, 2.143332939594984, 2.0664587896317244, 26.294305957853794, 48.71679447591305, 52.826904729008675, 62.12562896311283, 62.52527631819248, 51.26223988831043, 40.229740887880325, 7.305052438750863, 2.7126725390553474, 7.075244570150971, 23.13666969537735, 49.581487476825714, 81.92792057991028, 102.60523304343224, 116.365807056427, 98.62297832965851, 96.78611129522324, 100.49736455082893, 99.02387961745262, 95.69528862833977, 97.13475778698921, 100.66589310765266, 109.21017542481422, 113.77658799290657, 110.58406010270119, 117.57197633385658, 103.04599419236183, 70.21040573716164, 22.74024836719036, 1.1158787598833442, 0.0855722172127571, 0.1079075077723246, 0.08979700418421999, 0.45705526834353805, 0.13832593685947359, 0.855264994315803, 0.13133394095348194, 16.242061257362366, 50.041726380586624, 57.28219226002693, 70.8022391796112, 86.62812396883965, 59.005696177482605, 27.83308658748865, 30.37470180541277, 45.53362928330898, 49.838494285941124, 59.948049411177635, 73.27356576919556, 59.72171075642109, 8.46635039895773, 0.4027708765352145, 0.1118059353029821, 0.09434734907699749, 0.08221960961236618, 0.039131042431108654, 0.03920047034625895, 0.020394988132466096, 0.09421253795153461, 0.01022953165374929, 0.027505879806994926, 0.032407399703515694, 0.1821711755474098, 0.033248939507757314, 0.059247381941531785, 0.0471771811862709, 0.12501948134740815, 0.08018121938221157, 0.0864560557238292, 0.03890128464263398, 0.12400277613778599, 0.0741543791082222, 0.04018656567495782, 0.020780066297447775, 0.01980190267204307, 0.04448848034371622, 0.051393400062806904, 0.0698703687521629, 0.08678069338202477, 0.04976759941200726, 0.029538588896684814, 0.07247046829434112, 0.03389172474271618, 0.0178921544647892, 0.03360906666785013, 0.012991581734240754, 0.052455676850513555, 0.03643333933723625, 0.06307989562628791, 0.03422285990382079, 0.026675409135350492, 0.039461108899558894, 0.05097519242553972, 0.04244700277922675, 0.017757504756445996, 0.04119794597500004, 0.007319150372495642, 0.05557943579333369, 0.0497764643660048, 0.02670745692739729, 0.07359952724073082, 0.06084853215725161, 0.024716373045521323, 0.024698325869394466, 0.004667959528887877, 0.06647855349001475, 0.08703271931153722, 0.09928653482347727, 0.05793964352051262, 0.04533403887762688, 0.06259822694119066, 0.03531083726556972, 0.06175494308990892, 0.02089142184559023, 0.023417369702656288, 0.020224930558470078, 0.04766987076436635, 0.09381609750562347, 0.07381336225080304, 0.025078457620111294, 0.1079795257828664, 0.024612049346615095, 0.04627064408850856, 0.021528012002818286, 0.40516923065297306, 48.13765235245228, 114.42085102200508, 120.1122236251831, 107.95523196458817, 100.80517083406448, 96.0046224296093, 58.653101697564125, 22.780985981225967, 18.620463833212852, 44.30761367082596, 69.526077657938, 87.33483284711838, 53.75093914568424, 4.6857271157205105, 0.8655318652745336, 0.17913119023432955, 0.24127548997057602, 0.20464005268877372, 0.3455626900540665, 0.23688218352617696, 0.2595494070556015, 0.04513095387665089, 0.8077474753372371, 7.471194248646498, 49.102333188056946, 94.77712109684944, 112.7102892100811, 117.09232807159424, 119.30154472589493, 122.919991761446, 122.7955636382103, 115.32596245408058, 113.29598218202591, 111.39274030923843, 108.78000810742378, 111.16503372788429, 105.56040287017822, 110.81231385469437, 99.22115743160248, 101.15347534418106, 102.81368985772133, 98.20008382201195, 67.13183373212814, 19.520071260631084, 2.7003274764865637, 1.701124543324113, 3.7385574029758573, 3.2942353701218963, 0.5033341725356877, 1.245932481251657, 3.819984421133995, 37.460650876164436, 59.24213469028473, 65.62944754958153, 75.66125124692917, 81.70456856489182, 66.9300265610218, 55.459091886878014, 12.850795481353998, 5.653021261096001, 14.125901609659195, 40.9823627024889, 70.71993559598923, 96.47931575775146, 109.47967976331711, 113.7503769993782, 105.64110293984413, 103.11054512858391, 106.813043653965, 104.80277672410011, 102.20243945717812, 104.13953751325607, 104.75188985466957, 113.55385914444923, 116.12568274140358, 119.03951078653336, 127.33309015631676, 116.14785835146904, 86.08301281929016, 34.427383840084076, 2.4865758838132024, 0.09971530322218314, 0.3957188408821821, 0.3057626757072285, 0.4798719158861786, 0.0387246906029759, 0.9698178037069738, 0.28178409207612276, 16.27247292548418, 54.07085157930851, 60.632890462875366, 62.480662912130356, 40.3201000392437, 21.625314094126225, 26.40327461063862, 45.152456536889076, 78.14507156610489, 80.56785196065903, 77.83256873488426, 86.91496297717094, 84.28842231631279, 23.624508418142796, 0.41122364171314985, 0.2461005630902946, 0.09119340698816814, 0.1301335616153665, 0.04437569616129622, 0.028928148312843405, 0.05589403590420261, 0.08853899707901292, 0.06879390581161715, 0.04861920380790252, 0.014065470350033138, 0.13186926691560075, 0.11871892958879471, 0.05934049178904388, 0.029174444862292148, 0.11168282784637995, 0.10787759922095574, 0.06951925126486458, 0.04887468814558815, 0.03529974215780385, 0.05958668814855628, 0.06116644224675838, 0.009097846432268852, 0.021817625856783707, 0.057342615400557406, 0.03345319339132402, 0.0723246659617871, 0.07459588276105933, 0.029843361116945744, 0.027550562663236633, 0.059574223778326996, 0.05621214266284369, 0.03821820821030997, 0.03726928334799595, 0.06270624653552659, 0.02631146362546133, 0.026735176143120043, 0.013292867715790635, 0.04742457611428108, 0.13397996459389105, 0.04782033007359132, 0.06456881455960684, 0.14616733562434092, 0.07864079540013336, 0.172570085269399, 0.18993784004123881, 0.11512755823787302, 0.11440262096584775, 0.17373306036461145, 0.18738580198260024, 0.19085192849161103, 0.1398403782513924, 0.11853650226839818, 0.1124954350234475, 0.22976176638621837, 0.14842349424725398, 0.1965094092884101, 0.1995403997716494, 0.13884040847187862, 0.22002545680152252, 0.17668784712441266, 0.18763174972264096, 0.11088190207374282, 0.13942293502623215, 0.1347880595130846, 0.12125247332733124, 0.16516158124431968, 0.20185420842608437, 0.20960377383744344, 0.2972513699205592, 0.09500894404482096, 0.14776540221646428, 0.24670244485605508, 0.7957617903593928, 58.51960726082325, 131.68901681900024, 129.64437693357468, 107.00519934296608, 95.54436832666397, 82.7778209745884, 40.49425609409809, 28.451260216534138, 50.62941424548626, 119.68913152813911, 109.82557520270348, 96.80261760950089, 64.24042448401451, 7.2632727306336164, 1.415890355128795, 0.26628433784935623, 0.396885615773499, 0.6386261503212154, 0.4520915768807754, 0.17321505612926558, 0.2151223988039419, 0.19501533242873847, 7.5993086490780115, 7.81988681294024, 42.55863592028618, 96.70486405491829, 121.83048382401466, 125.94063207507133, 129.32940423488617, 133.3583128452301, 132.39296704530716, 128.73168110847473, 122.11828798055649, 123.35619315505028, 118.43693152070045, 118.60322579741478, 111.91123768687248, 118.10055077075958, 104.82761219143867, 106.5231192111969, 106.35975077748299, 102.63621658086777, 67.7011875808239, 18.96958339959383, 6.1149064265191555, 16.89930249005556, 17.243231534957886, 20.348132327198982, 13.230495806783438, 5.6871439050883055, 3.6858024587854743, 40.408069118857384, 71.90696910023689, 75.35549685359001, 85.9676206111908, 94.39535558223724, 86.83968141674995, 64.56840768456459, 9.266610257327557, 6.23524121940136, 10.63362680375576, 39.609283581376076, 71.09102368354797, 98.3431689441204, 114.97992262244225, 123.2003103196621, 108.76756757497787, 107.5102150440216, 110.17565801739693, 108.5844174027443, 107.40020334720612, 108.07005420327187, 112.85041809082031, 122.54280880093575, 129.73397612571716, 126.59396901726723, 132.0826604962349, 113.78897532820702, 76.95066645741463, 25.892192535102367, 1.5256582712754607, 0.15791382640600204, 0.5643502296879888, 0.3125451039522886, 0.9659601794555783, 0.15038323908811435, 1.2622352689504623, 1.0536284814588726, 27.06279382109642, 68.8485512137413, 75.20211428403854, 98.29297363758087, 119.92929384112358, 73.65188106894493, 36.65536768734455, 38.74682106077671, 59.986567944288254, 67.001713514328, 77.35227450728416, 101.23904675245285, 96.10209479928017, 23.007987700402737, 0.44613124046009034, 0.25319644482806325, 0.18607698002597317, 0.32887267938349396, 0.1171485154191032, 0.14019730675499886, 0.15780029265442863, 0.24978538567665964, 0.13167393364710733, 0.15004909451818094, 0.26303521532099694, 0.3144140396034345, 0.17631128139328212, 0.1876918043126352, 0.11103718163212761, 0.1620390691095963, 0.16330354032106698, 0.1093073318770621, 0.17542652261909097, 0.2826815564185381, 0.13727763842325658, 0.21817197266500443, 0.1005024324695114, 0.08049104377278127, 0.14881047973176464, 0.18471310555469245, 0.13265787303680554, 0.14508049003779888, 0.10475168062839657, 0.16235281946137547, 0.15113588073290884, 0.10180151744862087, 0.107350978651084, 0.11696213245159015, 0.1370076005696319, 0.15603383275447413, 0.12032133032334968, 0.12082760862540454, 0.14577506604837254], [0.0430177069210913, 0.019962646292697173, 0.12264218938071281, 0.023179546624305658, 0.08275408952613361, 0.01686039107880788, 0.03058605427213479, 0.12679656880209222, 0.08570105404942296, 0.052678399079013616, 0.008833806059556082, 0.022669782083539758, 0.07178836778621189, 0.0397634747059783, 0.048929543991107494, 0.07584761129692197, 0.04668790177674964, 0.0379703902581241, 0.08615573082352057, 0.11090349114965647, 0.04387701745145023, 0.164619546267204, 0.16198073630221188, 0.09971106555894949, 0.11719495159923099, 0.04133121343329549, 0.07064856254146434, 0.045303551451070234, 0.19670710258651525, 0.01025325069349492, 0.10279532740241848, 0.0685675062413793, 0.06977258337428793, 0.40571325458586216, 41.37248016893864, 105.74479177594185, 88.3831737935543, 74.63367238640785, 74.61736366152763, 61.07756160199642, 32.45689317584038, 38.55943791568279, 77.8462328016758, 80.31617626547813, 59.06268171966076, 78.73892650008202, 21.015754602849483, 0.2602221193956211, 0.677671548910439, 0.059119680590811186, 0.12188724707812071, 0.2471642239834182, 0.2840180753264576, 0.1872525122598745, 0.24625346035463735, 0.5504734336864203, 1.8397730472497642, 1.6896128235384822, 41.71464800834656, 84.10488456487656, 90.42957678437233, 90.09043738245964, 95.36781460046768, 99.04514327645302, 98.95784676074982, 100.04359290003777, 99.72566395998001, 99.65273067355156, 101.01044341921806, 102.64004677534103, 97.65651538968086, 93.01225259900093, 89.49900671839714, 88.22687298059464, 95.7384467124939, 107.43348196148872, 104.27662655711174, 88.81868362426758, 63.70594896376133, 19.632638320326805, 2.548199789598584, 4.3311757408082485, 3.242557905614376, 0.2540820644935593, 1.041421398986131, 27.828836515545845, 57.774007469415665, 60.59591844677925, 74.18487846851349, 85.84167256951332, 94.14086803793907, 82.84092038869858, 68.4682448208332, 66.26799568533897, 51.25986121594906, 54.213495925068855, 75.97877740859985, 87.36987456679344, 96.07994198799133, 101.99418783187866, 100.53473174571991, 108.57621744275093, 112.72073864936829, 107.54246771335602, 108.08987393975258, 101.17467060685158, 96.82030946016312, 103.10228437185287, 106.63697630167007, 99.74207147955894, 101.93458423018456, 99.36193987727165, 100.16944974660873, 106.51268497109413, 106.64878606796265, 43.763026893138885, 0.8000245084986091, 0.1511281475541182, 0.03411665114981588, 0.24955368717201054, 0.025851530590443872, 0.3444171405863017, 0.14541861251927912, 0.3383892390411347, 5.417507523670793, 42.132496386766434, 77.36411467194557, 80.2558659017086, 73.97888392210007, 75.80163091421127, 40.50229266285896, 15.447357650846243, 25.626009218394756, 46.59193329513073, 64.79326441884041, 79.43097576498985, 77.32370004057884, 29.773917943239212, 0.47292493865825236, 0.2778703020885587, 0.012824082714359974, 0.0725069671170786, 0.0507893994654296, 0.04418069314851891, 0.07715098588960245, 0.034422646058374085, 0.07571194670163095, 0.09996324733947404, 0.322115573217161, 0.11405404904508032, 0.13259712082799524, 0.18166283407481387, 0.15172538347542286, 0.10025068855611607, 0.023866576848377008, 0.05187052309338469, 0.07585076542454772, 0.012183061007817741, 0.08986749337054789, 0.07545452535850927, 0.0573123617505189, 0.026318411983083934, 0.020955658437742386, 0.06404747065971605, 0.14574337634257972, 0.1059429909219034, 0.023533543644589372, 0.027331135570420884, 0.06292401492828503, 0.007054137322484166, 0.02210425998782739, 0.09304095394327305, 0.061501469972427, 0.06936259873327799, 0.044614237267524004, 0.04264419141691178, 0.060444829796324484, 0.06471510670962743, 0.018172111122112256, 0.04242003684339579, 0.048822923345142044, 0.04805209537153132, 0.019432018125371542, 0.04211770443362184, 0.06841031194198877, 0.0814827905560378, 0.039224983484018594, 0.05765492969658226, 0.025706047381390817, 0.07833371695596725, 0.03333136613946408, 0.04785247991094366, 0.049088586238212883, 0.05457516526803374, 0.11729560166713782, 0.09211570359184407, 0.04257444066752214, 0.09069863197510131, 0.09900351680698805, 0.050350771634839475, 0.13364798709517345, 0.0418805919616716, 0.09390770079335198, 0.11843073880299926, 0.29468125314451754, 0.0161000218213303, 0.1796473836293444, 0.05572684858634602, 0.14353130129165947, 0.4794373142067343, 61.60259462893009, 120.025185495615, 102.12000668048859, 98.4734259545803, 104.73621189594269, 88.49313229322433, 53.055219277739525, 30.388591960072517, 25.567627251148224, 48.1339855492115, 63.18761117756367, 90.66981509327888, 21.534527465701103, 0.5542187264654785, 0.7228637114167213, 0.1845693663926795, 0.06497605325421318, 0.4610376921482384, 0.3331104019889608, 0.5235359072685242, 0.5822203739080578, 0.42432507150806487, 1.8622325733304024, 3.9304114831611514, 52.2394410520792, 94.69640582799911, 95.17581850290298, 96.84145912528038, 103.30612823367119, 106.64747133851051, 103.43494892120361, 106.56142875552177, 106.24263346195221, 107.34433874487877, 106.12255990505219, 110.32188177108765, 102.15169697999954, 99.74886551499367, 90.71068570017815, 90.56930288672447, 99.19306933879852, 112.16191783547401, 110.06697624921799, 95.7190677523613, 71.66638121008873, 29.130428172647953, 3.489134511910379, 1.6209558513946831, 0.43591430119704455, 0.5520892969798297, 3.1106496462598443, 39.40876454114914, 69.65828776359558, 77.25158751010895, 88.98500829935074, 97.57191672921181, 107.97812193632126, 100.50217509269714, 86.96398794651031, 85.8469694852829, 67.57322564721107, 68.70322421193123, 91.1996054649353, 97.14227378368378, 102.66028448939323, 105.2977305650711, 106.27241626381874, 106.8521435558796, 114.67337027192116, 112.27871596813202, 108.9150832593441, 104.1254934668541, 99.25793185830116, 106.33363097906113, 112.33664765954018, 107.0466323196888, 105.41609421372414, 101.94982141256332, 99.5022663474083, 108.78315433859825, 116.21254608035088, 59.26215581595898, 1.6106588789261878, 0.10046335097285919, 0.13638386997627094, 0.4765766020864248, 0.09170028642984107, 0.211876155808568, 0.08969451359007508, 0.41990451340097934, 5.362100321799517, 45.369527488946915, 81.6394704580307, 85.2849568426609, 47.82437816262245, 21.040512174367905, 32.56177134811878, 27.30057366192341, 44.90948997437954, 79.01567324995995, 84.1461731493473, 89.50792104005814, 95.40115401148796, 51.74992851912975, 1.6071118880063295, 0.6347711978014559, 0.07988449389813468, 0.09854561169049703, 0.14832360116997734, 0.10989067479385994, 0.12911848170915619, 0.05270622961688787, 0.03971888276282698, 0.16402548673795536, 0.48954774043522775, 0.19253908249083906, 0.28597707801964134, 0.26334380032494664, 0.22390546422684565, 0.12872405990492553, 0.06092126634030137, 0.020202777450322174, 0.0396475252637174, 0.05966980868834071, 0.0846920523326844, 0.0797311365022324, 0.039786551787983626, 0.02332920441403985, 0.054777771583758295, 0.05312238521582913, 0.2257779918727465, 0.1749225746607408, 0.031309228943428025, 0.01572235214553075, 0.06729871573043056, 0.03341613795782905, 0.055117237352533266, 0.10111228490131907, 0.051016099605476484, 0.06391143499058671, 0.05036102440499235, 0.0762703015061561, 0.12464738334529102, 0.1740437382250093, 0.1208626751031261, 0.13489561155438423, 0.18663663358893245, 0.09878442739136517, 0.08604112095781602, 0.17540176457259804, 0.19872752542141825, 0.1815234884270467, 0.10418993420898914, 0.17408112762495875, 0.18851837870897725, 0.17530320736113936, 0.15389095555292442, 0.10085821806569584, 0.17840706190327182, 0.13456097716698423, 0.2408348472090438, 0.3526068292558193, 0.14988487208029255, 0.18416152655845508, 0.24564201972680166, 0.22330189036438242, 0.3357178339501843, 0.30345527920871973, 0.1587630363064818, 0.16469331574626267, 0.3859277459559962, 0.07668833844945766, 0.24513900687452406, 0.20853380468906835, 0.3217926202341914, 0.8394619985483587, 75.01706421375275, 135.0282320380211, 111.25975504517555, 99.13966700434685, 96.88160017132759, 76.47297129034996, 43.93109567463398, 51.2344291806221, 108.43233436346054, 115.03032311797142, 77.41401359438896, 101.79689481854439, 30.562320537865162, 1.4052867866121233, 0.9627802250906825, 0.31062285241205245, 0.27648943243548274, 0.5810130480676889, 0.5649105808697641, 0.4322835069615394, 0.6428757472895086, 2.4485700856894255, 4.4235459342598915, 3.221736685372889, 50.48510938882828, 101.85147508978844, 105.04754438996315, 102.6362393796444, 109.9723157286644, 109.83953565359116, 106.41890600323677, 107.32290789484978, 107.2582657635212, 112.48342618346214, 109.35279697179794, 114.95479837059975, 108.95279243588448, 103.92075285315514, 99.90373760461807, 96.7498916387558, 106.06402784585953, 117.29985773563385, 114.69594106078148, 98.99750143289566, 71.89706683158875, 27.073019072413445, 5.121349515393376, 12.960486095398664, 9.496177788823843, 3.719449653290212, 2.244313471019268, 40.884335562586784, 82.44343891739845, 84.60403338074684, 93.72446358203888, 100.22535234689713, 107.51960813999176, 101.39144137501717, 97.7981261909008, 106.1046476662159, 66.68035715818405, 72.89237022399902, 99.95361372828484, 104.61820542812347, 113.1468477845192, 114.5638981461525, 111.24413788318634, 113.90648022294044, 119.2425186932087, 120.89945778250694, 117.93748632073402, 115.03384932875633, 109.86079171299934, 114.26520377397537, 117.75904789566994, 110.5326260626316, 109.98754531145096, 107.94425815343857, 107.40939885377884, 120.39463967084885, 123.53204011917114, 53.04484583437443, 0.8438866829965264, 0.2890197647502646, 0.16911776270717382, 0.640495412517339, 0.19677104603033513, 0.42031981924083084, 0.3200567071326077, 0.5987436685245484, 12.609493229538202, 66.15487575531006, 94.75386634469032, 103.0654339492321, 108.50074589252472, 95.95208644866943, 51.07778258621693, 19.676043391227722, 31.79994072765112, 64.27894681692123, 80.7395039498806, 97.12183088064194, 111.65422707796097, 54.938090443611145, 1.09271259047091, 0.6264443602412939, 0.2042462839744985, 0.2876713121077046, 0.23312130564590916, 0.25478330499026924, 0.16186107241082937, 0.20738105638884008, 0.1194370687881019, 0.211410591728054, 0.4721753695048392, 0.34417469578329474, 0.39282995683606714, 0.4209800931857899, 0.21522462222492322, 0.2110803805408068, 0.28023404243867844, 0.10610790355713107, 0.21170663443626836, 0.16418506333138794, 0.2504867152310908, 0.2532299008453265, 0.20455942576518282, 0.07822581610525958, 0.13394419307587668, 0.13774486491456628, 0.2825822273734957, 0.20853116264333948, 0.1761679578339681, 0.08637072358396836, 0.2980146836489439, 0.09832886004005559, 0.11082753233495168, 0.20990898949094117, 0.08133137758704834, 0.15595143951941282, 0.10542800722760148, 0.15573243174003437], [0.022730764358129818, 0.08888494921848178, 0.06553989253006876, 0.06585306400666013, 0.07143644135794602, 0.025106605426117312, 0.02067625096970005, 0.02205073815275682, 0.030780289162066765, 0.04758451264933683, 0.05407951080997009, 0.11405262412154116, 0.04102765647985507, 0.06088217000069562, 0.07695583073655143, 0.11780736444052309, 0.01931563081598142, 0.1106151519343257, 0.025987512453866657, 0.09135337691986933, 0.07625754398759454, 0.04644589113013353, 0.046617056359536946, 0.023908324510557577, 0.004262624443072127, 0.14258616138249636, 0.06632112170336768, 0.33131867938209325, 0.008482568900944898, 0.07670799794141203, 0.020089293793716934, 0.1327272193157114, 0.09828557798755355, 36.953530088067055, 101.36288210749626, 84.41715180873871, 79.5703598856926, 81.0363744199276, 64.46962058544159, 35.221453830599785, 41.93022184073925, 90.52116706967354, 79.61937725543976, 79.47167918086052, 85.90961292386055, 7.252051932737231, 0.751517202006653, 0.06559898974956013, 0.1199998616357334, 0.2188209511223249, 0.18450034665875137, 0.08133798270137049, 0.11338218275341205, 0.615916372044012, 1.8200288317166269, 1.7018431797623634, 6.552074868232012, 48.29292722046375, 96.15643188357353, 96.90163269639015, 99.50155198574066, 98.86982828378677, 103.03466320037842, 106.5753436088562, 105.75468644499779, 102.94918298721313, 101.59476846456528, 100.48180818557739, 98.54499891400337, 95.92836052179337, 89.50253292918205, 78.92391577363014, 81.0925430059433, 90.88872134685516, 99.54476326704025, 106.15175753831863, 103.83258998394012, 102.28777527809143, 95.6642746925354, 68.59960377216339, 26.94294825196266, 7.379757380113006, 0.7247564848512411, 1.1934892390854657, 30.83981204777956, 54.23375643789768, 70.23130461573601, 95.64811795949936, 102.72792845964432, 107.3672667145729, 117.01510101556778, 112.64203727245331, 102.04270362854004, 83.56659024953842, 88.39995369315147, 86.1488176882267, 93.27661201357841, 104.66561168432236, 95.87896317243576, 97.03540831804276, 101.80888697504997, 100.03735363483429, 102.04199686646461, 109.34937715530396, 105.49810141324997, 100.78938648104668, 92.36500293016434, 91.19594246149063, 101.60016417503357, 110.64069986343384, 104.70221132040024, 101.19081974029541, 90.56818574666977, 91.24847084283829, 87.97753036022186, 99.22995015978813, 31.86154682189226, 0.1454038140946068, 0.13859836442861706, 0.2609092590864748, 0.046158438781276345, 0.09459328197408468, 0.11197191663086414, 0.06489390492788516, 0.6222233211155981, 0.5716708931140602, 9.42977825179696, 37.828155755996704, 45.04955045878887, 70.37910908460617, 69.72340866923332, 59.90267984569073, 37.093510776758194, 22.675336450338364, 48.72240297496319, 62.933518812060356, 62.491287142038345, 79.0339806675911, 37.15760573744774, 1.8106527160853148, 0.20311237138230354, 0.07970728387590498, 0.007186776274465956, 0.25448638654779643, 0.07904266094556078, 0.19934148935135454, 0.12743379164021462, 0.08027967269299552, 0.19650078553240746, 0.26464606169611216, 0.1511523118824698, 0.161188256170135, 0.280743126058951, 0.19481999916024506, 0.052945197458029725, 0.050994388075196184, 0.04472212698601652, 0.06302785623120144, 0.12416040830430575, 0.09110295402933843, 0.027412089038989507, 0.047483784655923955, 0.01461726735215052, 0.10875625754124485, 0.11035597170121036, 0.08021257512154989, 0.09177843458019197, 0.04486342819291167, 0.006237465031517786, 0.12570169317768887, 0.04605765512678772, 0.013722661205974873, 0.007836754775780719, 0.026965483120875433, 0.07983155650435947, 0.06821024377131835, 0.06573248727363534, 0.08366572146769613, 0.052357546373968944, 0.06213489672518335, 0.048025463402154855, 0.0832765614904929, 0.11358891541021876, 0.06003614762448706, 0.047182383641484194, 0.0905948797299061, 0.030646366758446675, 0.043775372905656695, 0.01910885919642169, 0.014069625449337764, 0.1171597366919741, 0.07739515989669599, 0.05283397920720745, 0.09994549516704865, 0.029048463438812178, 0.054189088914426975, 0.032173983126995154, 0.045736487008980475, 0.0159423989316565, 0.01288811150516267, 0.08815074994345196, 0.26883052778430283, 0.09318573953351006, 0.2533100824803114, 0.03214131749700755, 0.18871132226195186, 0.03326681784528773, 0.19467486476060003, 0.0749339978210628, 55.070019364356995, 118.11760425567627, 104.63921830058098, 106.93556427955627, 104.99535799026489, 100.70702970027924, 48.91722612082958, 27.18464568257332, 44.82606545090675, 68.76127749681473, 91.56420350074768, 91.92991107702255, 7.469052113592625, 0.4642656783107668, 0.2668456092942506, 0.09188077674480155, 0.3534681658493355, 0.4373768367804587, 0.19774201267864555, 0.020548942957248073, 0.8278210856951773, 1.619557763915509, 3.24967872351408, 12.694688457995653, 58.97433266043663, 103.58488887548447, 103.75923112034798, 104.74125802516937, 104.22655284404755, 105.39821237325668, 110.2877140045166, 108.1303645670414, 106.82673811912537, 105.28693914413452, 100.51663711667061, 101.52869001030922, 97.41411119699478, 93.77380773425102, 79.64957803487778, 85.84690868854523, 96.83211922645569, 105.44072449207306, 108.11654850840569, 104.6987535059452, 106.88912317156792, 102.58365780115128, 78.74978631734848, 37.911086305975914, 10.541799031198025, 1.2558944779448211, 3.9846813585609198, 43.304562494158745, 64.12545025348663, 83.04701372981071, 106.0403399169445, 113.86153623461723, 112.1032489836216, 120.58844447135925, 117.48211115598679, 109.22508582472801, 96.23207822442055, 98.85495588183403, 93.73698011040688, 97.78387695550919, 109.48639780282974, 101.83828979730606, 99.66996654868126, 106.21635407209396, 108.4455880522728, 105.54858550429344, 111.8062037229538, 109.76523444056511, 106.56806319952011, 96.99723556637764, 96.76683872938156, 103.85035783052444, 112.62114599347115, 108.04595589637756, 103.82406324148178, 95.63916563987732, 95.1086913049221, 92.33235508203506, 105.8365948498249, 43.551572039723396, 0.3545132582075894, 0.2741124224849045, 0.2378274273360148, 0.05009549138776492, 0.31038028886541724, 0.07772913377266377, 0.06228561949683353, 0.7119383476674557, 0.6319256848655641, 9.445548355579376, 40.39304852485657, 53.180331364274025, 60.830555856227875, 37.67749384045601, 27.54836406558752, 34.150583893060684, 35.68130895495415, 80.11106327176094, 94.93956238031387, 76.35102823376656, 89.5842133462429, 57.38130234181881, 6.669742204248905, 0.09310741326771677, 0.14651599660282955, 0.050507965934230015, 0.2975144167430699, 0.08282797032734379, 0.2366451860871166, 0.2533269440755248, 0.10640877764672041, 0.2978607622208074, 0.5138755193911493, 0.16119492065627128, 0.3371343563776463, 0.2608794841216877, 0.2684541401686147, 0.05108533085149247, 0.029728513763984665, 0.10208389721810818, 0.0698531954549253, 0.03848134037980344, 0.03392950377019588, 0.035475030017551035, 0.02286691691551823, 0.03277895964856725, 0.10942603097646497, 0.0503970000136178, 0.14592802268452942, 0.06149290929897688, 0.04953402327373624, 0.06201091724506114, 0.05811474213260226, 0.03776817728066817, 0.03722472480149008, 0.07742489775409922, 0.031586435943609104, 0.07673386920941994, 0.034613110838108696, 0.10204133504885249, 0.22217136196559295, 0.22099247522419319, 0.19974468334112316, 0.1731502072652802, 0.12476764095481485, 0.2884355460992083, 0.10798451301525347, 0.1262487896019593, 0.1902016141684726, 0.0878972619830165, 0.17697311384836212, 0.08849547753925435, 0.2855305722914636, 0.15120748314075172, 0.19770613725995645, 0.1378058100817725, 0.2910213964059949, 0.11232075572479516, 0.21549608500208706, 0.15944164129905403, 0.20390890364069492, 0.1753946251119487, 0.17914083815412596, 0.19047533307457343, 0.36336550663691014, 0.28508097922895104, 0.40271349367685616, 0.13505597482435405, 0.22418415552238002, 0.15573580109048635, 0.4132723552174866, 0.15181620750809088, 62.55302242934704, 134.9900060892105, 107.45549038052559, 107.79700085520744, 99.7503550350666, 82.25109323859215, 48.694839254021645, 60.92425882816315, 125.84027945995331, 109.71510753035545, 100.23070245981216, 111.45079359412193, 12.44569256901741, 0.9694178751669824, 0.3522372693987563, 0.4168611142085865, 0.502468115882948, 0.4468049621209502, 0.45508284762036055, 0.3706410771701485, 1.2107095587998629, 7.837711181491613, 6.1376439314335585, 9.213057830929756, 55.572360008955, 110.84289461374283, 109.5366083085537, 109.26833510398865, 112.78684750199318, 113.4004233777523, 115.7032822072506, 114.720229357481, 116.68155491352081, 112.48384416103363, 107.29469820857048, 108.43759328126907, 105.77515974640846, 100.48459723591805, 87.52662375569344, 90.15093013644218, 100.79792842268944, 109.9700054526329, 113.45932021737099, 112.8144796192646, 112.65835359692574, 105.98453611135483, 80.23600816726685, 35.08693724870682, 9.957019910216331, 2.6061737537384033, 2.9189900681376457, 40.41841596364975, 80.05020573735237, 90.76684668660164, 113.32071125507355, 119.44089084863663, 118.81017029285431, 125.35870090126991, 120.65029755234718, 109.48023453354836, 102.53432124853134, 115.62389686703682, 102.35484927892685, 107.25789338350296, 118.96977692842484, 112.97647252678871, 109.37004804611206, 115.12319013476372, 114.34825971722603, 111.0534793138504, 117.56359398365021, 116.53354525566101, 108.28817769885063, 99.36710000038147, 99.91522818803787, 110.85447639226913, 123.51412028074265, 116.07192322611809, 111.42224192619324, 100.34103333950043, 98.365458548069, 95.86858972907066, 115.03213182091713, 39.46736499667168, 0.6086029519792646, 0.36659497709479183, 0.521805218886584, 0.10841308845556341, 0.4316870280308649, 0.21645210479618981, 0.1567624881863594, 1.8453113688156009, 1.1855812696740031, 20.809340178966522, 56.80758252739906, 63.16436402499676, 107.92076781392097, 97.41794139146805, 73.20325434207916, 46.522324830293655, 25.619215182960033, 61.83605410158634, 81.14893198013306, 76.96663320064545, 103.64471286535263, 65.09625256061554, 4.847410814836621, 0.25703664345201105, 0.3192279953509569, 0.2004612417658791, 0.3188645211048424, 0.2556752477539703, 0.28667128295637667, 0.354212925885804, 0.2180318403407, 0.30634499446023256, 0.43102806026581675, 0.17888789938297123, 0.4135962581494823, 0.34155761590227485, 0.311458213836886, 0.21839304361492395, 0.08881278277840465, 0.1860705530270934, 0.22590403823414817, 0.15509642602410167, 0.1375931254005991, 0.17013425269396976, 0.13377302413573489, 0.06502248943434097, 0.28709392121527344, 0.25426979816984385, 0.17251200479222462, 0.21219026239123195, 0.21115046896738932, 0.21207962301559746, 0.29027598327957094, 0.13357203570194542, 0.09924694866640493, 0.12542136915726587, 0.11798049265053123, 0.21642210718709975, 0.1750315961544402], [0.02862046501832083, 0.07352822911343537, 0.02972625763504766, 0.04427013307576999, 0.015909722169453744, 0.05106403121317271, 0.031940236294758506, 0.10209231317276135, 0.06403676146874204, 0.07147084732423536, 0.03203647800546605, 0.04397066906676628, 0.04604127963830251, 0.02299065890838392, 0.04060719642438926, 0.052827170002274215, 0.023453503017663024, 0.04525812830252107, 0.07319671174627729, 0.053522291491390206, 0.034276031074114144, 0.024080319089989644, 0.10647830946254544, 0.04707644948211964, 0.16011604573577642, 0.0789220174192451, 0.1518428060808219, 0.05058146452938672, 0.20968349534086883, 0.06138464479590766, 0.12390066403895617, 0.10007697404944338, 12.499226946383715, 92.53613814711571, 89.21061739325523, 76.19029685854912, 66.13353610038757, 48.07153210043907, 39.428466483950615, 48.56374628841877, 82.33763739466667, 80.966055393219, 85.9229502081871, 73.99937242269516, 2.3396161571145058, 0.24053145723883063, 0.48642890935298055, 0.06297947562416084, 0.15508164244238287, 0.14534972637193277, 0.14960601751226932, 0.2707649802323431, 0.6167050672229379, 6.140057276934385, 30.478696525096893, 75.53777307271957, 110.05393534898758, 118.52327048778534, 111.39423742890358, 112.44614258408546, 99.75674629211426, 94.17207956314087, 91.72214582562447, 93.58691096305847, 92.95972421765327, 91.24251276254654, 91.07439458370209, 92.77326062321663, 87.90610179305077, 83.82673189043999, 80.39968818426132, 88.0702605843544, 95.62727987766266, 102.91403487324715, 105.18370628356934, 107.63542592525482, 95.10742217302322, 97.47455075383186, 97.427326887846, 104.10127356648445, 83.60842600464821, 42.39497870206833, 21.493977941572666, 28.45745388418436, 58.98824751377106, 60.51093600690365, 93.47540214657784, 89.73331734538078, 101.16198688745499, 102.66456305980682, 100.76064482331276, 109.54541623592377, 127.85497695207596, 121.01353526115417, 83.26277375221252, 87.75458112359047, 96.94818779826164, 103.54996874928474, 97.1852494776249, 94.29202392697334, 97.4190965294838, 114.94774594902992, 98.72987419366837, 102.98231720924377, 114.83578115701675, 120.09217590093613, 107.17748209834099, 97.2757226228714, 93.86279135942459, 98.82063612341881, 91.07057958841324, 81.64364263415337, 85.40088102221489, 98.98318380117416, 103.07921960949898, 96.14098951220512, 81.75378352403641, 29.270281568169594, 1.5911658061668277, 0.5928389634937048, 0.05054288027167786, 0.056901438292698, 0.06990904948906973, 0.15013617812655866, 0.19123428297461942, 0.10611584453727119, 0.17251268756808713, 2.8288494050502777, 29.4164502248168, 60.47266446053982, 76.25428542494774, 86.90615504980087, 74.8840257525444, 51.50486446917057, 22.61576134711504, 33.284541964530945, 61.2530779838562, 66.15529373288155, 67.16057538986206, 70.42900800704956, 16.497892029583454, 0.590026758145541, 0.17530479555716738, 0.05369007994886488, 0.616667662980035, 0.09861833474133164, 0.2569100627442822, 0.20543444756185636, 0.17474264837801456, 0.09449517005123198, 0.1557264945586212, 0.3025298804277554, 0.24442783644190058, 0.03731168224476278, 0.11829768656753004, 0.013808177027385682, 0.07557826364063658, 0.01800763264327543, 0.05668503545166459, 0.07709605954005383, 0.04929075097606983, 0.03772700292756781, 0.04090865681064315, 0.1020721415989101, 0.10716928605688736, 0.09068160710739903, 0.07230122151668184, 0.030255395940912422, 0.030317873643070925, 0.03215947042917833, 0.036389370798133314, 0.03362603216373827, 0.03276826530054677, 0.10817769405548461, 0.013178624285501428, 0.02166282127291197, 0.024322669269167818, 0.05288751402986236, 0.029685779045394156, 0.06381735292961821, 0.03630763436376583, 0.013411579802777851, 0.07963835319969803, 0.13550466246670112, 0.003645533984126814, 0.06186885904753581, 0.07734841201454401, 0.046187241532607004, 0.02856131955923047, 0.026315782924939413, 0.03233953771996312, 0.0608583173743682, 0.008491518274240661, 0.05615359092189465, 0.06002994326991029, 0.046683133477927186, 0.021276761617627926, 0.011950507177971303, 0.1099566814082209, 0.013814363755955128, 0.18960780696943402, 0.054632006358588114, 0.09849732756265439, 0.04232613660860807, 0.4866338608553633, 0.10061387336463667, 0.25735104689374566, 0.10541817377088591, 23.55418559163809, 114.4520853459835, 104.67976212501526, 102.67641082406044, 95.86392357945442, 78.98028194904327, 40.008235573768616, 27.489805407822132, 44.49128821492195, 82.28381708264351, 97.61113062500954, 79.36865150928497, 3.000169387087226, 0.38224808871746063, 0.44671682466287166, 0.17354694457026199, 0.21295405109412968, 0.06218312890268862, 0.1763313787523657, 0.4738247481873259, 0.9851024835370481, 12.062186747789383, 43.67015227675438, 92.33464255928993, 121.3171161711216, 122.12183699011803, 113.27241584658623, 113.01422730088234, 101.34477227926254, 100.08672058582306, 95.21507039666176, 99.23400834202766, 97.5668554008007, 95.28046488761902, 95.10123610496521, 99.09696489572525, 91.5749341249466, 86.88382744789124, 81.16690501570702, 93.24613764882088, 101.11344069242477, 105.94737410545349, 107.94032156467438, 110.0320029258728, 99.85319271683693, 100.69165572524071, 101.81091606616974, 111.66052713990211, 91.00744977593422, 52.74976506829262, 33.88402059674263, 39.7833826392889, 72.09505900740623, 72.58328720927238, 104.6141928434372, 95.63725054264069, 104.43141505122185, 108.98468032479286, 103.72161313891411, 114.37032133340836, 128.654226064682, 121.49297833442688, 90.8339510858059, 91.54654204845428, 99.6814039349556, 105.55044740438461, 101.88508808612823, 95.7554242014885, 99.56089720129967, 116.45976841449738, 103.52496609091759, 105.54278701543808, 118.43252375721931, 121.37751013040543, 111.37025311589241, 99.74787756800652, 98.88890326023102, 100.33961981534958, 93.1959879398346, 84.23549875617027, 91.72580882906914, 103.4659856557846, 110.22795841097832, 100.26043206453323, 90.40955185890198, 47.59634479880333, 5.1459213718771935, 0.37873283203225583, 0.15246726397890598, 0.12658651132369414, 0.20957814005669206, 0.13441116723697633, 0.17391896835761145, 0.057326514506712556, 0.18804147461196408, 1.992443511262536, 34.27503481507301, 69.91392284631729, 76.98549538850784, 57.90943220257759, 28.022447526454926, 26.346572153270245, 26.321780383586884, 58.39289166033268, 93.12113955616951, 81.83766782283783, 81.86346083879471, 90.17939820885658, 33.69924411177635, 0.8154079830273986, 0.21029581170296296, 0.12592081970069557, 0.8341719699092209, 0.12712413794361055, 0.21455280046211556, 0.28300468751695007, 0.24806764035020024, 0.24560464516980574, 0.24726861447561532, 0.354341822094284, 0.3245889733079821, 0.07029352651443332, 0.10293509607436135, 0.05472691591421608, 0.05489880102686584, 0.028057416129740886, 0.02663514020241564, 0.05388850055169314, 0.11878681383677758, 0.08034499653149396, 0.044126015418441966, 0.07424679133691825, 0.11281811341177672, 0.04368670481198933, 0.03408134347409941, 0.030331653470057063, 0.06887779076350853, 0.025306261704827193, 0.05644109893182758, 0.04181543139566202, 0.006251019431147142, 0.043534497744985856, 0.0449248817312764, 0.04938496291288175, 0.11802344073657878, 0.14715048833750188, 0.09926250408170745, 0.14441512495977804, 0.12786290142685175, 0.16459851380204782, 0.17878857033792883, 0.18826355488272384, 0.1480756199453026, 0.27515775233041495, 0.07795846482622437, 0.1384571337257512, 0.18274018017109483, 0.1017780730035156, 0.1188801834359765, 0.16680710075888783, 0.07404563963063993, 0.17545058304676786, 0.2542415668722242, 0.23025205882731825, 0.09958710463251919, 0.17681794561212882, 0.1870106760179624, 0.14902352064382285, 0.3438738588010892, 0.14579177921405062, 0.2190819347742945, 0.20278622716432437, 0.5780161963775754, 0.18250122346216813, 0.2754465368343517, 0.2903263602638617, 30.149656981229782, 133.3327478170395, 115.16465350985527, 104.64646071195602, 83.75643566250801, 63.59201207756996, 53.37797395884991, 66.61262959241867, 112.75963336229324, 113.19457322359085, 102.1544936299324, 101.13180130720139, 5.945929018780589, 0.663629996124655, 0.9738629835192114, 0.3731084510218352, 0.3036398661788553, 0.24310673936270177, 0.3358632355229929, 0.8293925982434303, 1.7982081463560462, 10.156930033117533, 36.336545795202255, 85.70456832647324, 118.22646841406822, 126.66428044438362, 118.1984107196331, 120.6864184141159, 107.45723068714142, 103.87697920203209, 101.53302177786827, 101.88663080334663, 100.98056182265282, 98.45208629965782, 99.17590945959091, 105.1438008248806, 93.73029246926308, 92.75116860866547, 87.50856712460518, 97.86862760782242, 105.94368070363998, 111.8940170109272, 111.79628625512123, 118.80877196788788, 106.89455687999725, 105.12162521481514, 106.89791589975357, 116.87640845775604, 93.97920951247215, 55.18152058124542, 29.67188011854887, 36.96306377649307, 83.01395550370216, 83.6819976568222, 109.59044381976128, 101.20908915996552, 111.31186544895172, 115.56732550263405, 111.2830401957035, 118.78069907426834, 133.18618208169937, 125.02030625939369, 99.0673340857029, 102.12381407618523, 108.42369362711906, 113.45070227980614, 111.70222610235214, 104.37553524971008, 109.1516737639904, 129.14058476686478, 112.58546590805054, 109.15420442819595, 119.54037711024284, 128.0385223031044, 118.51636245846748, 107.39972457289696, 103.6732417345047, 106.28553315997124, 98.27419504523277, 88.67671564221382, 96.3385409116745, 110.55585041642189, 117.86015287041664, 103.75003561377525, 92.19490885734558, 39.200288727879524, 2.8332809172570705, 1.1047761118970811, 0.2997823606710881, 0.2087350602960214, 0.3541118750581518, 0.3432642586994916, 0.4283593565924093, 0.16111139935674146, 0.4697881476022303, 6.54594199731946, 51.338045820593834, 72.72742107510567, 106.26960441470146, 124.3286369740963, 94.15370374917984, 64.30150240659714, 26.54282782226801, 43.528606072068214, 81.90767526626587, 82.2341613471508, 88.45387279987335, 103.43258544802666, 33.03697004914284, 0.78924092464149, 0.3810087020974606, 0.17629363312153146, 1.0424326197244227, 0.17326681350823492, 0.3769120469223708, 0.2817358821630478, 0.4020532494178042, 0.3064909897511825, 0.26330838503781706, 0.4069226881256327, 0.2969898370793089, 0.1495533250272274, 0.30916830233763903, 0.13076058734441176, 0.24688459758181125, 0.07688514117035083, 0.21994398382958025, 0.1845214978675358, 0.16981078020762652, 0.21088457229780033, 0.15235111786751077, 0.1465639244997874, 0.2839323424268514, 0.1734971909900196, 0.1624785244348459, 0.09333770169178024, 0.20301457116147503, 0.11533935234183446, 0.19090948946541175, 0.14617181819630787, 0.23488243692554533, 0.170353171415627, 0.19831946294289082, 0.17881380335893482], [0.07252414041431621, 0.07621158278197981, 0.0168679776834324, 0.05584440106758848, 0.08542663752450608, 0.03484938097244594, 0.026279911216988694, 0.10197164738201536, 0.03950503290980123, 0.04525346761511173, 0.03456796970567666, 0.06989421395701356, 0.04116875359613914, 0.0710206976509653, 0.04042503627715632, 0.02712468121899292, 0.008738114465813851, 0.034211286110803485, 0.06477280127000995, 0.011898740522156004, 0.014319749625428813, 0.03914531393093057, 0.03964625248045195, 0.027315474399074446, 0.04304908121412154, 0.16824033635202795, 0.10691029878216796, 0.2641761931590736, 0.030621783116657753, 0.24367814854485914, 0.11975119021371938, 1.5611648722551763, 65.37631273269653, 90.42487263679504, 70.32701388001442, 79.46176171302795, 49.057620987296104, 31.54325120151043, 75.69164961576462, 80.79745084047318, 85.11939212679863, 97.96604678034782, 59.553368389606476, 1.7138639534823596, 0.04624206769221928, 0.07212354394141585, 0.2491088438546285, 0.023842739065003116, 0.06514678432722576, 0.21491486462764442, 0.6271274923346937, 5.469793668016791, 56.5266901999712, 101.53106108307838, 117.41882935166359, 110.28633087873459, 102.86581546068192, 102.58920550346375, 107.55360871553421, 106.67368993163109, 109.63024288415909, 99.44406867027283, 93.421521037817, 86.67489185929298, 88.81314352154732, 86.87517151236534, 85.05219653248787, 83.6040486395359, 82.61296302080154, 77.60370701551437, 90.35947054624557, 98.48275825381279, 109.5837713778019, 105.44781491160393, 104.58926618099213, 95.64105793833733, 94.8480024933815, 86.93775415420532, 94.32820558547974, 98.37193340063095, 89.33670222759247, 65.28522402048111, 74.25002977252007, 57.71457105875015, 66.40113294124603, 84.9049924314022, 98.26320603489876, 99.58738937973976, 93.57847541570663, 100.58978319168091, 103.89902561903, 112.00674936175346, 117.14970499277115, 106.37705504894257, 90.26708990335464, 81.48218929767609, 96.16664573550224, 108.12080428004265, 98.78378570079803, 92.09933638572693, 86.01729914546013, 82.38584160804749, 87.85182550549507, 100.38945034146309, 103.20093467831612, 105.80955550074577, 96.23395532369614, 90.17176821827888, 91.37836307287216, 92.08881095051765, 85.98424091935158, 94.20995593070984, 101.25923126935959, 96.98550179600716, 95.17169192433357, 100.71075350046158, 97.28152111172676, 104.50706899166107, 81.28682658076286, 17.622432187199593, 0.2455054348683916, 0.11464407871244475, 0.02431657809211174, 0.0437286064698128, 0.12887012941064313, 0.2703612222103402, 0.04533675884886179, 0.3498173039406538, 0.3820402279961854, 21.649858877062798, 82.34595894813538, 82.61245384812355, 86.08457073569298, 76.16955757141113, 80.34082934260368, 32.98193760216236, 28.543224781751633, 48.38671378791332, 51.929427087306976, 69.29682075977325, 71.63996502757072, 45.438771173357964, 2.4304899433627725, 0.7439486018847674, 0.12362058492726646, 0.32818185864016414, 0.06816109133069403, 0.09561251048580743, 0.12378596511553042, 0.09511936819762923, 0.14588287041988224, 0.08225400815717876, 0.11182275236933492, 0.13696975103812292, 0.09813943426706828, 0.05055801637354307, 0.06363703330862336, 0.03214133976143785, 0.0759370623563882, 0.033847596641862765, 0.0208398388713249, 0.09156746426015161, 0.01879985302366549, 0.019353127827343997, 0.046464634069707245, 0.03090894973865943, 0.01364416424621595, 0.09123360912781209, 0.037455261845025234, 0.09350866283057258, 0.04962167833582498, 0.10889013356063515, 0.018000467207457405, 0.01995079048356274, 0.05228011439612601, 0.013553586977650411, 0.06725161161739379, 0.04393564711790532, 0.07066015488817357, 0.03095830812526401, 0.06547217897605151, 0.029168385226512328, 0.03834042880043853, 0.08762447818298824, 0.016492883260070812, 0.11483164169476368, 0.03907935555616859, 0.004955128933943342, 0.03813593371887691, 0.03544387836882379, 0.03185732726706192, 0.059667841996997595, 0.11433811348979361, 0.04846337134949863, 0.06932327232789248, 0.049962249904638156, 0.022518949845107272, 0.047462292059208266, 0.023280346977117006, 0.031979080304154195, 0.06908533236128278, 0.3522875573253259, 0.17543943598866463, 0.24127586104441434, 0.038846091119921766, 0.3223408298799768, 0.11113780943560414, 4.490239480510354, 92.83285662531853, 106.0659809410572, 104.7423903644085, 102.42639943957329, 86.49209886789322, 25.71268256753683, 30.277153439819813, 51.18303693830967, 88.25007453560829, 108.2748632133007, 67.67658770084381, 1.7203960404731333, 0.12643361405935138, 0.10234149667667225, 0.1452969596721232, 0.1433788493159227, 0.21630239876685664, 0.24585725739598274, 0.7204983977135271, 11.53379375115037, 74.44508090615273, 113.44530656933784, 122.11766481399536, 111.39450341463089, 106.01038992404938, 105.11271849274635, 109.30734381079674, 113.06044042110443, 114.84449028968811, 102.91462764143944, 94.37802851200104, 89.38412368297577, 90.72200909256935, 89.3884326517582, 88.10106173157692, 83.2483421266079, 82.96010479331017, 80.03980189561844, 93.88376623392105, 103.19608613848686, 111.18027091026306, 112.34259814023972, 107.23229795694351, 99.99298721551895, 95.60393393039703, 90.2378086745739, 99.22746509313583, 104.66467693448067, 95.21718308329582, 74.31622982025146, 82.53138899803162, 70.90053230524063, 80.49970641732216, 94.92634668946266, 101.50484248995781, 105.04229307174683, 99.54413250088692, 105.33344104886055, 108.29409018158913, 114.21646758913994, 119.86357256770134, 108.75337913632393, 98.20193812251091, 87.98937812447548, 100.60426041483879, 113.34797099232674, 104.21153604984283, 93.61296996474266, 87.66907051205635, 85.57706996798515, 92.09355309605598, 104.1586808860302, 106.4890730381012, 109.59668308496475, 98.84127661585808, 94.85033556818962, 94.36709269881248, 94.155383259058, 89.61771234869957, 101.26325145363808, 105.98506048321724, 102.09502682089806, 100.0437068939209, 104.04264271259308, 102.13783532381058, 109.67866748571396, 94.6365362405777, 29.1473201662302, 0.8185596170369536, 0.3201414307113737, 0.240758539584931, 0.0684077144251205, 0.16190428024856374, 0.25391763425432146, 0.053195000655250624, 0.40198517963290215, 0.31359070097096264, 21.05798553675413, 86.40411078929901, 86.60066664218903, 76.76562398672104, 52.22836844623089, 41.49069182574749, 19.257951825857162, 38.884920850396156, 84.4819687306881, 73.32604095339775, 86.0695007443428, 85.07078513503075, 71.60842671990395, 7.437696671113372, 0.5850664211902767, 0.20369746576761827, 0.3504177607828751, 0.021208855105214752, 0.08789316532784142, 0.06321728942566551, 0.2888397790957242, 0.13432071427814662, 0.05967096643871628, 0.10943911504000425, 0.17649656598223373, 0.14780823898036033, 0.03744945825019386, 0.09740540568600409, 0.058854978778981604, 0.05666927223501261, 0.06870591678307392, 0.05521339742699638, 0.023659068647248205, 0.03221519829821773, 0.03786124259931967, 0.02814230669173412, 0.01646873748541111, 0.030109922008705325, 0.10981656392687, 0.034528750911704265, 0.05962892377283424, 0.11093175955465995, 0.03649073332780972, 0.03812643793935422, 0.025172786445182282, 0.0347307857737178, 0.046654660982312635, 0.18568159342976287, 0.19752517197048292, 0.21390395559137687, 0.13747276389040053, 0.19740038726013154, 0.16570486302953213, 0.07221165171358734, 0.22424328984925523, 0.17378336313413456, 0.2876172837568447, 0.22334270848659799, 0.0858917563164141, 0.1473803017870523, 0.2373282439657487, 0.1539974834304303, 0.12223776342580095, 0.16648914985125884, 0.10938737992546521, 0.12179191078757867, 0.1380896073533222, 0.1025157084222883, 0.1676129989209585, 0.1512945073773153, 0.2205879453686066, 0.14146976347547024, 0.3659322689054534, 0.22177465434651822, 0.500442290212959, 0.183108686178457, 0.46307889511808753, 0.2569307538215071, 7.325455918908119, 111.7122195661068, 120.76348587870598, 100.9629687666893, 98.84955257177353, 66.61676377058029, 48.16694118082523, 104.3522273004055, 114.80266213417053, 117.60796800255775, 115.08956953883171, 82.65423640608788, 5.157934902235866, 0.2929565019439906, 0.3752309043193236, 0.45577969460282475, 0.29642387526109815, 0.3202451829565689, 0.4596901894547045, 1.2983618304133415, 8.689262587577105, 67.68324494361877, 113.74568045139313, 133.5443812608719, 122.85613998770714, 112.8627522289753, 110.13602614402771, 118.1339205801487, 116.73108145594597, 122.19546183943748, 109.98563781380653, 100.49820810556412, 93.4517066180706, 99.24648687243462, 95.592070966959, 93.26194480061531, 89.84041839838028, 89.75566014647484, 85.19455969333649, 98.1547674536705, 108.39884296059608, 114.86606553196907, 113.94944071769714, 113.60611394047737, 105.37998095154762, 104.05386731028557, 95.65737426280975, 105.72637796401978, 109.99215826392174, 101.64393022656441, 83.32853302359581, 93.6194296181202, 80.86336210370064, 92.8086519241333, 103.71889248490334, 110.71966722607613, 111.13349542021751, 106.47524937987328, 114.14764568209648, 118.65095123648643, 120.07564678788185, 124.1778914630413, 115.46076402068138, 107.14918121695518, 95.33142015337944, 107.34366238117218, 117.14059308171272, 110.5951327085495, 99.81172934174538, 94.28917407989502, 89.70667317509651, 96.61283299326897, 111.22068554162979, 115.22545024752617, 116.30938768386841, 104.10944312810898, 97.64956176280975, 99.23694178462029, 99.29841488599777, 95.18564477562904, 106.67685136198997, 114.30902302265167, 106.37650787830353, 103.45571100711823, 108.30382525920868, 104.0730182826519, 115.31219199299812, 90.14695554971695, 21.196879483759403, 0.6890818022657186, 0.8106334204785526, 0.23229308368172497, 0.27722270402591676, 0.25622099346946925, 0.410194342257455, 0.1226486312225461, 0.738928240025416, 1.3509637140668929, 38.81938956677914, 97.27162644267082, 101.00374817848206, 124.4149075448513, 108.03837150335312, 107.73117318749428, 41.82570844888687, 32.994769513607025, 67.03237026929855, 68.0825275182724, 84.21010091900826, 101.55944555997849, 79.80673760175705, 6.80957137607038, 1.1829683161340654, 0.34748927573673427, 0.5743882223032415, 0.14453438809141517, 0.1312336471164599, 0.18027231650194153, 0.34713227301836014, 0.14155536278849468, 0.2326670370530337, 0.1600514492020011, 0.26193618366960436, 0.23241810587933287, 0.13920248748036101, 0.30057325260713696, 0.18072450708132237, 0.14329845987958834, 0.10196153190918267, 0.13449946796754375, 0.19876736390870064, 0.12343691822024994, 0.22164198802784085, 0.09636578295612708, 0.17405400954885408, 0.08296863699797541, 0.2814417245099321, 0.14399855746887624, 0.22937457310035825, 0.12624438124476, 0.13000865816138685, 0.13173514598747715, 0.07110715785529464, 0.14105197886237875, 0.1678255500155501], [0.10494908448890783, 0.04984358420188073, 0.03088311928877374, 0.05870163251529448, 0.049657750423648395, 0.05382226387155242, 0.028178894572192803, 0.000573446203588901, 0.06920423926203512, 0.040589095442555845, 0.04550342295260634, 0.029861519615224097, 0.052732805925188586, 0.0396264111623168, 0.037996665996615775, 0.04664958469220437, 0.035902328963857144, 0.1181749501847662, 0.04809971898794174, 0.039946258257259615, 0.058045689002028666, 0.018723254106589593, 0.08798130278591998, 0.03931191124138422, 0.08532847365131602, 0.026386936333437916, 0.04215793625917286, 0.06060600200726185, 0.13790081982733682, 0.14123197935987264, 1.3449333189055324, 47.695359885692596, 95.6412099301815, 86.79955556988716, 72.91542738676071, 43.2154306769371, 38.55229049921036, 89.84805598855019, 72.64751136302948, 89.60803806781769, 97.3374617099762, 47.728364914655685, 2.287007267586887, 0.20838501892285421, 0.1356744658551179, 0.19226101459935308, 0.23679714824538678, 0.15471365593839437, 0.08912311925087124, 0.6616223976016045, 26.710089147090912, 100.38301348686218, 113.36006194353104, 92.23647862672806, 84.20558676123619, 89.53144177794456, 100.93035131692886, 109.82888102531433, 107.6930384337902, 108.99255350232124, 102.80962407588959, 84.83034923672676, 75.8873163163662, 78.34759309887886, 81.77946254611015, 84.45319667458534, 83.06309446692467, 82.31513500213623, 79.1710165143013, 78.62161159515381, 88.16251963376999, 101.01292848587036, 100.80935820937157, 104.3362757563591, 104.66174349188805, 89.53363806009293, 78.10062915086746, 77.6036462187767, 89.86155286431313, 96.41087383031845, 92.81486839056015, 71.24361589550972, 70.3423422574997, 81.95576548576355, 89.02752801775932, 96.17952704429626, 96.69643610715866, 87.4566999077797, 87.77700752019882, 94.2630086839199, 97.58652314543724, 98.77333626151085, 103.75122874975204, 101.05705931782722, 87.08327114582062, 89.55425575375557, 94.03132751584053, 104.66885671019554, 96.34816959500313, 94.257772564888, 87.84180164337158, 87.70445421338081, 89.99911308288574, 88.95328760147095, 87.1307609975338, 84.06374797224998, 83.70614916086197, 86.95416927337646, 90.04048526287079, 84.78912144899368, 81.87850043177605, 94.36517000198364, 93.23561981320381, 97.97347158193588, 102.95595422387123, 97.24907085299492, 100.01237377524376, 93.0026163160801, 95.42341321706772, 96.36628702282906, 28.6959632858634, 0.326133441994898, 0.44601772155147046, 0.11424484779126942, 0.04190320891211741, 0.09404961427208036, 0.07501426851376891, 0.06910022726515308, 0.029532221269619185, 0.47122702351771295, 9.07522402703762, 76.03979453444481, 73.18448334932327, 73.39303135871887, 92.89175346493721, 104.70465078949928, 45.41112765669823, 15.50429379567504, 34.60532069206238, 44.082597345113754, 60.472242683172226, 74.58682850003242, 55.46529695391655, 3.7086261715739965, 0.6830412545241416, 0.02053600732324412, 0.15406920458190143, 0.10567845238256268, 0.11821166423032992, 0.06357818841934204, 0.04545500523818191, 0.032035895419539884, 0.1006574225903023, 0.032371149500249885, 0.23841265530791134, 0.04427493848197628, 0.01695398888841737, 0.06439067685278133, 0.03904545425029937, 0.06426917985663749, 0.11164402836584486, 0.04952377792506013, 0.00047099886273826996, 0.08699020167114213, 0.021140737080713734, 0.04732312081614509, 0.03461954525846522, 0.04525487027422059, 0.04229036880133208, 0.02138300747901667, 0.023888598225312307, 0.0632947993290145, 0.027865697120432742, 0.02314656743692467, 0.04382680002890993, 0.009959523486031685, 0.047058608251973055, 0.017879832957987674, 0.016968199161055963, 0.02556593175540911, 0.10813502056407742, 0.004044132456328953, 0.05939912145549897, 0.0281902049027849, 0.028912600319017656, 0.025384061045770068, 0.05501104715222027, 0.04913789452984929, 0.04286064991902094, 0.06572332917130552, 0.07249928588862531, 0.03868020256049931, 0.011897713575308444, 0.02673946390132187, 0.029079917512717657, 0.01298185774430749, 0.03995436993136536, 0.05419750486908015, 0.03335447661811486, 0.026319170829083305, 0.14265081728808582, 0.006940118391867145, 0.027557247558434028, 0.06363632826833054, 0.3026302781654522, 0.2505361719522625, 4.382473463192582, 73.25050860643387, 109.28448423743248, 108.8421043753624, 104.10369783639908, 73.15270185470581, 28.68347905576229, 51.16472192108631, 59.90391097962856, 92.34103381633759, 108.4318707883358, 58.056218326091766, 2.298510200344026, 0.22004273399943486, 0.09726779666380025, 0.27142914303112775, 0.10997009943821467, 0.3459904046030715, 0.0940568205260206, 1.200779266655445, 39.8567833006382, 112.30990469455719, 116.03275492787361, 95.08462339639664, 90.86330831050873, 98.03936764597893, 107.03498214483261, 113.26423868536949, 111.50049492716789, 109.20300900936127, 104.21885445713997, 87.16483756899834, 79.88024845719337, 83.18804696202278, 87.5483737885952, 91.42108798027039, 87.71312534809113, 85.60615360736847, 84.00341480970383, 82.02927634119987, 91.77041083574295, 104.54401060938835, 102.05289468169212, 104.66328620910645, 105.7499822974205, 92.23356038331985, 78.8824599981308, 78.36567252874374, 92.29745775461197, 102.47508242726326, 98.14995691180229, 77.80869081616402, 76.08653202652931, 93.73883441090584, 101.26186072826385, 105.27030363678932, 106.54030948877335, 94.01414483785629, 93.76240834593773, 100.50258547067642, 101.88134908676147, 101.76493853330612, 106.93760856986046, 109.86321598291397, 94.06231105327606, 94.08177360892296, 95.06991818547249, 108.00880149006844, 102.43149876594543, 98.60226184129715, 90.9131920337677, 91.36705487966537, 93.7088768184185, 94.44704800844193, 89.8364970088005, 85.84613353013992, 86.7496794462204, 87.32681527733803, 91.56675696372986, 88.6562043428421, 85.03116846084595, 95.05742445588112, 96.73047468066216, 102.17179790139198, 107.37889409065247, 101.41589686274529, 101.84644415974617, 98.47315236926079, 96.95718571543694, 103.78544971346855, 38.91326352953911, 1.160685361828655, 0.1286634709686041, 0.3684588958276436, 0.1846223557367921, 0.09115474109421484, 0.18667348864255473, 0.018868861625378486, 0.09134977008216083, 0.454456148436293, 7.516540065407753, 77.58321091532707, 81.71102061867714, 68.12348932027817, 90.46726316213608, 65.93892574310303, 25.73406022042036, 20.100587010383606, 59.85795244574547, 74.18483287096024, 74.89427760243416, 83.86108204722404, 75.02171516418457, 10.239024627953768, 0.9132019698154181, 0.03533478266035672, 0.133337264705915, 0.18639736517798156, 0.01978498912649229, 0.09497871636995114, 0.11508765295729972, 0.08585905728978105, 0.060987770193605684, 0.06918829792994075, 0.056229605397675186, 0.06780396986869164, 0.016205681386054493, 0.026422325645398814, 0.08532131934771314, 0.07057156472001225, 0.03608024773711804, 0.033882195566548035, 0.028656448048423044, 0.010827429014170775, 0.12471864436520264, 0.034938472090289, 0.047077165654627606, 0.04651155635656323, 0.056167027505580336, 0.015341668422479415, 0.018000992276938632, 0.059788051366922446, 0.057999037599074654, 0.06860471752588637, 0.010538158403505804, 0.04920870655041654, 0.16093224490759894, 0.17277874751016498, 0.09248349713743664, 0.11225056339753792, 0.14239614189136773, 0.17250657227123156, 0.174324611434713, 0.14400873973499984, 0.14842637378023937, 0.15801135945366696, 0.22962295508477837, 0.1625610957853496, 0.12441307248082012, 0.1366945478366688, 0.16530451888684183, 0.13956066279206425, 0.19441443029791117, 0.18313877284526825, 0.1782763993833214, 0.1828091702191159, 0.1094300088880118, 0.1391989697003737, 0.2085500131943263, 0.08171673776814714, 0.25094996381085366, 0.10463747894391418, 0.20008819381473586, 0.14957884006435052, 0.4690604272764176, 0.3675845864927396, 5.5141429882496595, 91.8318459391594, 129.8769548535347, 109.62072059512138, 95.47567561268806, 56.55000574886799, 57.37327717244625, 126.58581465482712, 99.81628149747849, 119.81140896677971, 114.58140760660172, 77.01198756694794, 5.495402868837118, 0.6031812366563827, 0.3608133498346433, 0.4672609269618988, 0.4035679728258401, 0.40325368812773377, 0.5580679792910814, 1.230383834335953, 34.1844666749239, 110.13504579663277, 127.16495677828789, 105.4851745069027, 97.45180517435074, 101.36161297559738, 110.49150466918945, 120.04417687654495, 115.92278122901917, 116.16037487983704, 112.29564025998116, 93.58837008476257, 84.27130803465843, 88.12869384884834, 91.30661532282829, 93.19607153534889, 91.98081314563751, 91.12340435385704, 88.86881813406944, 85.94982236623764, 99.0642562508583, 111.56216561794281, 106.48737072944641, 109.9881836771965, 110.9769058227539, 98.37276175618172, 84.95299145579338, 83.99054110050201, 97.33898162841797, 109.70740914344788, 105.40010467171669, 87.80364409089088, 88.76892149448395, 101.66438832879066, 109.8648650944233, 107.40065932273865, 111.41403436660767, 101.17359146475792, 102.11098596453667, 106.04936063289642, 109.42817732691765, 110.07697731256485, 116.85376927256584, 117.98466458916664, 100.22599831223488, 100.80217659473419, 104.93366450071335, 116.38434246182442, 108.09950262308121, 105.17688184976578, 95.65703228116035, 94.91616323590279, 96.75445139408112, 97.89824321866035, 96.15513995289803, 93.03831160068512, 93.387391269207, 92.53147959709167, 97.55601838231087, 91.68746888637543, 89.28478941321373, 103.12345683574677, 105.06615579128265, 109.32573482394218, 116.33617624640465, 105.42278185486794, 108.3510111272335, 103.78183230757713, 109.13485586643219, 107.27364733815193, 32.028036788105965, 0.6664866115897894, 0.9153491514734924, 0.36454139510169625, 0.27141174708958715, 0.1529570814454928, 0.35108412033878267, 0.31247759819962084, 0.22821587277576327, 1.0674769571051002, 17.19997275620699, 97.02196463942528, 85.47898963093758, 94.64654490351677, 120.23985877633095, 150.11931985616684, 58.93984951078892, 17.968646809458733, 44.82499770820141, 62.085818499326706, 75.38625240325928, 93.45748990774155, 88.44939664006233, 10.48429386690259, 1.1124044400639832, 0.08058103660005145, 0.2032576542114839, 0.29638454143423587, 0.20050976338097826, 0.15477813372854143, 0.14552427950548008, 0.18808947672368959, 0.2873318240744993, 0.19737208174774423, 0.2730051678372547, 0.19633117510238662, 0.1340417261235416, 0.1060026595951058, 0.09367958686198108, 0.13328849076060578, 0.15651006891857833, 0.19614194228779525, 0.14880166301736608, 0.18477621779311448, 0.5305875570047647, 0.14022190152900293, 0.09539359176415019, 0.11672456355881877, 0.18159173632739112, 0.1248660052078776, 0.12241322940099053, 0.12482205522246659, 0.14139639475615695, 0.1750993393943645, 0.21678760007489473, 0.1335212728008628], [0.00821874467874295, 0.027769154839916155, 0.039422769550583325, 0.03166317772411276, 0.07099554626620375, 0.06703682665829547, 0.049191318030352704, 0.04700253528426401, 0.03948431956814602, 0.0063914449037838494, 0.09178030479233712, 0.026517955084273126, 0.053705167811131105, 0.02672819624422118, 0.06906142036314122, 0.04719838063465431, 0.013607286928163376, 0.061214396118884906, 0.03387243632460013, 0.02522170325391926, 0.03792126750340685, 0.12284238371648826, 0.1051685078709852, 0.12690060306340456, 0.14062810863833874, 0.06748379993950948, 0.05704377850634046, 0.051941023411927745, 0.5713745683897287, 2.494570417329669, 64.61063861846924, 95.45974686741829, 71.50213122367859, 74.02102366089821, 60.80291993916035, 40.33414788544178, 110.46724677085876, 88.28034371137619, 98.97623777389526, 104.44651544094086, 41.76586925983429, 3.595470618456602, 0.07338558832998388, 0.3740183240734041, 0.1193056938063819, 0.24732938152737916, 0.31635187624488026, 0.1625633519142866, 0.17227055446710438, 38.77529293298721, 118.66026073694229, 95.73457092046738, 88.26164871454239, 89.08297464251518, 90.76360166072845, 89.22039046883583, 91.30220755934715, 93.5793873667717, 95.26464253664017, 88.82046952843666, 81.9995391368866, 77.87255018949509, 82.09837943315506, 91.66742116212845, 95.04572108387947, 97.27125406265259, 93.4017089009285, 88.40059965848923, 88.55307027697563, 85.24515777826309, 89.84252348542213, 100.08432671427727, 93.13183978199959, 98.34566920995712, 98.41009095311165, 79.33761477470398, 73.09041559696198, 70.12149810791016, 81.75607100129128, 92.04061433672905, 95.8578211069107, 79.23302158713341, 62.57587820291519, 79.70792010426521, 95.94664514064789, 119.26187485456467, 103.85581433773041, 97.97548547387123, 96.1163592338562, 100.18297702074051, 100.67654773592949, 94.64246392250061, 96.11177667975426, 93.85735005140305, 93.50982829928398, 92.14814096689224, 87.59816631674767, 100.62740117311478, 104.33171600103378, 99.98106345534325, 96.08317941427231, 95.26233226060867, 93.1023533642292, 95.98444551229477, 94.04359325766563, 86.48579880595207, 76.92634016275406, 77.09236085414886, 81.64511695504189, 83.89107763767242, 83.14037472009659, 84.84263017773628, 89.06577676534653, 87.30976179242134, 83.55103388428688, 88.44026193022728, 88.5587927699089, 89.57278355956078, 91.5038551390171, 91.61509796977043, 83.21039736270905, 21.081055998802185, 0.2928450907347724, 0.3923784935614094, 0.11321924423100427, 0.09373665801831521, 0.0750806239375379, 0.13880968355806544, 0.17721735464874655, 0.13016697310376912, 0.43760951492004097, 6.2174733728170395, 82.29780793190002, 96.4269545674324, 95.64367219805717, 105.08290529251099, 116.29792749881744, 70.51403984427452, 20.12533888220787, 25.04890378564596, 41.73979505896568, 57.944869101047516, 68.5604278743267, 61.589074954390526, 12.281499579548836, 0.4509416635846719, 0.056244314764626324, 0.05131456542585511, 0.09143468661932275, 0.04769766419485677, 0.03598549032176379, 0.049252047974732704, 0.04775034925842192, 0.08644458212074824, 0.04898930543276947, 0.04046027715958189, 0.02845600694854511, 0.025667919544503093, 0.030391413056349847, 0.012334838556853356, 0.03298585186712444, 0.0667767484264914, 0.037765097367810085, 0.11003140083630569, 0.05173519988602493, 0.027573778897931334, 0.04703550148406066, 0.03724557544046547, 0.04322511864302214, 0.051600963925011456, 0.027885516174137592, 0.09313220100011677, 0.0959755468647927, 0.02655834090546705, 0.02513857343728887, 0.04718661388324108, 0.06642661057412624, 0.03391347338038031, 0.09038453281391412, 0.06767859886167571, 0.06450488595874049, 0.026434602623339742, 0.06287071388214827, 0.01639533722482156, 0.00871375625138171, 0.029277857574925292, 0.10737191463704221, 0.02575119593529962, 0.03507307541440241, 0.04032664975966327, 0.08596459068940021, 0.06750866188667715, 0.058444274254725315, 0.05722431335016154, 0.023529446989414282, 0.02786719996947795, 0.02279075029946398, 0.05079718459455762, 0.03540024008543696, 0.05319419542502146, 0.09498469808022492, 0.021303783214534633, 0.04249147226801142, 0.05442094327008817, 0.2635294263018295, 8.554272931069136, 94.87616658210754, 111.63731038570404, 99.82335671782494, 106.25722467899323, 90.38190454244614, 25.237063989043236, 49.12480138242245, 86.48101106286049, 100.71731954813004, 116.14877790212631, 46.836047396063805, 2.773987236432731, 0.2008313953410834, 0.10904973983997479, 0.06855325700598769, 0.40304374939296395, 0.46519018651451916, 0.041322660181322135, 0.7505015283823013, 53.687459751963615, 125.51272183656693, 98.42731162905693, 95.38622081279755, 97.40036353468895, 96.06975093483925, 91.5600237250328, 94.57611948251724, 95.78531339764595, 95.96853956580162, 92.34946176409721, 85.71119517087936, 81.68471843004227, 85.25120705366135, 97.02410772442818, 98.71621772646904, 102.28536620736122, 100.15490412712097, 91.24090164899826, 91.58202454447746, 88.70744079351425, 93.89132022857666, 100.88823437690735, 95.25341793894768, 99.45358335971832, 102.40661770105362, 83.32430005073547, 76.7011034488678, 72.88629814982414, 85.3458371758461, 96.47611632943153, 101.51245728135109, 83.56771498918533, 67.2929222881794, 83.8817985355854, 99.80172827839851, 119.07207503914833, 110.38901656866074, 107.36209899187088, 102.34898239374161, 106.70115485787392, 106.39516487717628, 102.23060354590416, 104.11929219961166, 100.56136071681976, 97.65733614563942, 95.67835673689842, 92.25900381803513, 101.89417719841003, 107.99294114112854, 103.86266157031059, 102.56784304976463, 98.55290248990059, 99.15453940629959, 100.62087312340736, 100.07923498749733, 94.77739468216896, 80.70959955453873, 78.6321522295475, 83.95135760307312, 86.19015946984291, 85.08261770009995, 86.57074704766273, 93.16182017326355, 89.81224671006203, 87.12779715657234, 89.84529733657837, 92.34280452132225, 92.25474044680595, 95.96868395805359, 97.83897399902344, 91.24707251787186, 29.937052689492702, 1.1026105843484402, 0.09341153054265305, 0.18289892555912957, 0.5360364052467048, 0.16672818077495322, 0.14986079680966213, 0.05004853941500187, 0.10074239849927835, 0.37120594060979784, 4.773515230044723, 86.36802032589912, 95.92499390244484, 92.14479714632034, 112.19197422266006, 91.94147765636444, 22.968429923057556, 14.482236988842487, 39.45025451481342, 66.6646260023117, 90.22067159414291, 79.42515447735786, 81.83123096823692, 20.65285887569189, 0.37797150725964457, 0.15093946392880753, 0.03754472032596823, 0.14936430001398548, 0.07015565774054267, 0.05552226815780159, 0.146241728507448, 0.08883170754415914, 0.04624070585123263, 0.04472856882784981, 0.012658978976105573, 0.028004749619867653, 0.03342826836160384, 0.021569273558270652, 0.08910685137379915, 0.04507697747612838, 0.06387977497070096, 0.006221880857992801, 0.06970237620407715, 0.0041165419497701805, 0.015068397588038351, 0.11029028421035036, 0.05759107159974519, 0.07968096731929109, 0.06255242158658803, 0.0737813237356022, 0.10935430982499383, 0.06371861018124036, 0.04806792909221258, 0.015033251329441555, 0.10019914639997296, 0.11579925383557566, 0.11111856554634869, 0.1826494897250086, 0.11047526451875456, 0.12889056815765798, 0.19023737084353343, 0.14964192261686549, 0.16629657737212256, 0.13977199676446617, 0.1254174209316261, 0.2964721742318943, 0.1307998617994599, 0.10498621413717046, 0.11153127386933193, 0.26301197125576437, 0.2016419541905634, 0.13786666619125754, 0.20895320718409494, 0.1827708160271868, 0.1437134837033227, 0.1423407331458293, 0.19910545670427382, 0.14515893504722044, 0.2082103322027251, 0.17113811132730916, 0.12075757957063615, 0.09556441931636073, 0.23600365879246965, 0.6478265253826976, 9.73434615880251, 114.54869896173477, 125.48068195581436, 99.7876538336277, 98.17977771162987, 75.93975350260735, 58.745748326182365, 160.0864890217781, 111.5693624317646, 117.24428191781044, 125.77882155776024, 65.36687403917313, 8.465959019958973, 0.5681573878973722, 0.3721541678532958, 0.28320013952907175, 0.6833875109441578, 0.4993674822617322, 0.40135729301255196, 1.1811363394372165, 49.788097590208054, 132.04341620206833, 109.96711760759354, 100.997524112463, 101.2100999057293, 103.07884722948074, 99.55082014203072, 101.21753990650177, 104.92452219128609, 104.63252305984497, 97.71992638707161, 90.01976117491722, 86.20022892951965, 89.88628193736076, 102.87931233644485, 104.79643106460571, 109.4146728515625, 103.74410793185234, 96.0430459678173, 99.90112334489822, 92.00622618198395, 98.64617228507996, 105.3424921631813, 97.81205624341965, 106.47856280207634, 106.8181961774826, 85.34082144498825, 81.07529953122139, 76.55312418937683, 88.08737486600876, 101.31721615791321, 109.2278216779232, 90.66549092531204, 77.75161027908325, 94.18223261833191, 108.3486096560955, 123.75305905938148, 113.84146571159363, 113.3235003054142, 108.27132940292358, 111.98511332273483, 115.73197826743126, 109.71019819378853, 112.14352682232857, 108.52402344346046, 108.65684151649475, 103.18688303232193, 95.35432532429695, 106.64646819233894, 111.04219391942024, 107.01221376657486, 106.32071167230606, 102.94029146432877, 102.0657379925251, 105.08856698870659, 102.80450195074081, 97.36774608492851, 82.95904085040092, 83.90039473772049, 88.8646611571312, 92.32132807374, 91.69717356562614, 91.70901373028755, 98.2271383702755, 94.23887997865677, 91.97461187839508, 96.15109696984291, 98.70862573385239, 98.22618842124939, 100.4031828045845, 102.30769380927086, 95.63073009252548, 26.670643463730812, 1.2601946596987545, 0.7922574877738953, 0.15115303918719292, 0.3952144179493189, 0.21870208875043318, 0.4349077114602551, 0.5250421108212322, 0.25532029336318374, 0.8756437757983804, 11.51329955086112, 106.45067989826202, 109.74106773734093, 102.9435820877552, 117.66425058245659, 156.1716502904892, 92.6922033727169, 27.307432293891907, 30.880593359470367, 60.67126840353012, 79.96531069278717, 88.86040538549423, 93.32572057843208, 22.595595829188824, 0.39879721007309854, 0.2824487001635134, 0.09059178497409448, 0.33015659486409277, 0.2524801535764709, 0.21259749366436154, 0.20186367823043838, 0.14181386766722426, 0.16279398172628134, 0.12170449321274646, 0.09887204534607008, 0.08809735983959399, 0.12265751473023556, 0.12500794837251306, 0.13932746514910832, 0.1683304033940658, 0.20712140860268846, 0.14739888516487554, 0.25108601432293653, 0.11805694870417938, 0.0966561037057545, 0.17526362120406702, 0.20148133859038353, 0.11465135175967589, 0.10184319646214135, 0.18709534022491425, 0.28958964510820806, 0.13820590189425275, 0.1409945366322063, 0.13194011233281344, 0.1969668988022022], [0.10757093637948856, 0.06743052857927978, 0.07204453489976004, 0.06408817003830336, 0.03738519568287302, 0.020160512140137143, 0.024945648438006174, 0.012405088400555542, 0.09177692059893161, 0.020290530846978072, 0.049798294639913365, 0.015385585011244984, 0.01744480639899848, 0.011847257737827022, 0.030532714263244998, 0.05250773851003032, 0.0891071704973001, 0.010769300297397422, 0.033729569186107256, 0.022349877472152002, 0.04432307789102197, 0.07581634461530484, 0.16942247370025143, 0.08497412782162428, 0.11341916397213936, 0.023843113849579822, 0.1156673148216214, 0.10917225357843563, 8.774242177605629, 69.6627639234066, 81.83493956923485, 80.05987241864204, 51.382621228694916, 27.657693699002266, 45.761955231428146, 101.30735948681831, 98.93420442938805, 103.11782553792, 113.12139675021172, 42.02878475189209, 1.7948124348185956, 0.403442638926208, 0.3162825002800673, 0.10617538704536855, 0.41051260486710817, 0.22458328254288062, 0.20318409253377467, 0.8029221498873085, 27.254178151488304, 119.99203607439995, 88.22931244969368, 97.37634122371674, 89.52020958065987, 74.31936085224152, 76.75829038023949, 82.502730935812, 83.16841721534729, 79.74442094564438, 79.15227591991425, 78.57184186577797, 77.02101588249207, 78.48514571785927, 87.37639501690865, 95.56615635752678, 94.97727915644646, 95.29817953705788, 101.28586784005165, 97.07019165158272, 96.72677367925644, 96.15453958511353, 93.23614418506622, 102.88876622915268, 101.58886358141899, 101.57982766628265, 86.96432992815971, 77.99829304218292, 82.4114066362381, 84.42338347434998, 77.72134110331535, 88.1473508477211, 98.67689743638039, 84.5613768696785, 62.99045115709305, 72.27406740188599, 79.28157538175583, 100.89267253875732, 120.82359865307808, 104.2362043261528, 103.00616472959518, 94.72677379846573, 96.43734320998192, 100.68600162863731, 103.3056190609932, 91.48057758808136, 82.45269522070885, 81.80631190538406, 93.13027426600456, 88.52324187755585, 99.90806177258492, 102.97375246882439, 101.98286443948746, 99.34888377785683, 96.48649737238884, 94.85458374023438, 96.19693771004677, 96.82133540511131, 90.38578793406487, 78.62908959388733, 77.32873097062111, 80.01402407884598, 78.65754246711731, 79.3418401479721, 80.48615634441376, 78.6682502925396, 81.5440271794796, 74.41776037216187, 76.96879908442497, 78.06963801383972, 84.91617143154144, 94.41911950707436, 87.08275437355042, 57.69826613366604, 10.014787260442972, 0.3988643002230674, 0.5835245351772755, 0.3785842837532982, 0.01952548605913762, 0.12863543262938038, 0.06431113346479833, 0.2886304637650028, 0.10832047584699467, 0.25450158573221415, 4.53518251888454, 63.37789736688137, 89.26854148507118, 108.41837391257286, 115.63274279236794, 115.92026576399803, 101.54057577252388, 52.46098816394806, 25.77054586261511, 28.0134230107069, 52.23802372813225, 70.2477577328682, 77.79399320483208, 35.073257982730865, 2.384622604586184, 0.3904423787025735, 0.06422864375053905, 0.09455571445869282, 0.037746484304079786, 0.015334145828092005, 0.0939414685126394, 0.0837472834973596, 0.043022553145419806, 0.05929918013862334, 0.03246654516260605, 0.03429960168432444, 0.043767810420831665, 0.02713218618737301, 0.018356490290898364, 0.03532593997078948, 0.06067509595595766, 0.06329356736387126, 0.09535964592942037, 0.022431187171605416, 0.05995576560962945, 0.03806148888543248, 0.04479325813008472, 0.029392905307759065, 0.04061884814291261, 0.02754798926616786, 0.016114300742628984, 0.04488292441237718, 0.035870861902367324, 0.09584760060533881, 0.07271196314832196, 0.18059362191706896, 0.07096737434039824, 0.05074739019619301, 0.039404316048603505, 0.07284035469638184, 0.013576687251770636, 0.075126191804884, 0.02774163043795852, 0.023426559346262366, 0.005821544600621564, 0.0758104445412755, 0.04595037396939006, 0.018418736071907915, 0.04455460570170544, 0.05693463084753603, 0.08023193033295684, 0.0144308769631607, 0.025489646395726595, 0.08225119541748427, 0.039312853768933564, 0.09455415594857186, 0.27694080665241927, 0.07327620318392292, 0.18024637101916596, 0.058812372080865316, 0.22833777795312926, 0.03416424508031923, 20.326224602758884, 96.10679134726524, 95.76827511191368, 108.40765848755836, 88.42162773013115, 52.460152208805084, 29.186496064066887, 56.579792350530624, 98.6369539797306, 107.48591914772987, 124.62341755628586, 46.28486417233944, 0.9394767880439758, 0.46190784545615315, 0.20533280301606283, 0.2584072417812422, 0.13518743886379525, 0.4701391240814701, 0.22578729840461165, 1.228812262415886, 39.20686237514019, 125.61250448226929, 93.57319369912148, 105.34576758742332, 92.68575131893158, 78.34476605057716, 81.55567735433578, 88.8395369052887, 86.78884014487267, 83.03479358553886, 80.97045555710793, 82.61934667825699, 79.99326199293137, 81.59810587763786, 92.637919485569, 100.84758415818214, 101.3621373474598, 99.36336100101471, 103.98214235901833, 102.64690920710564, 102.21484199166298, 99.06713649630547, 97.3930299282074, 105.1173086464405, 102.26980224251747, 101.69615462422371, 87.79180392622948, 80.93735933303833, 86.78944811224937, 88.59502002596855, 80.58820366859436, 90.98354145884514, 100.86551159620285, 90.58257937431335, 71.02650314569473, 75.45202687382698, 84.76348802447319, 100.27861788868904, 122.46685087680817, 113.34398120641708, 110.48338830471039, 104.25074234604836, 102.97058343887329, 107.24931344389915, 108.8308797776699, 97.29393884539604, 88.32865431904793, 88.77096578478813, 93.84769096970558, 90.17069667577744, 102.30491235852242, 107.63902053236961, 105.04091754555702, 104.2653639614582, 101.85741797089577, 100.58207720518112, 99.40298527479172, 100.13309329748154, 97.06921130418777, 83.07249516248703, 80.64773127436638, 84.2767645418644, 82.65360563993454, 82.09801465272903, 82.8478892147541, 83.66426780819893, 86.91326066851616, 79.33458253741264, 79.35250237584114, 82.72712409496307, 88.23732241988182, 96.624186784029, 90.72012439370155, 66.58248960971832, 14.764019418507814, 0.6317812332417816, 0.23208602447994053, 0.0592634457279928, 0.25194999296218157, 0.1486872386885807, 0.022037650378479157, 0.35920680791605264, 0.02049448601610493, 0.2326472513959743, 2.6706334948539734, 69.69452261924744, 93.83192181587219, 104.11865383386612, 119.62203472852707, 110.96651718020439, 46.03691227734089, 30.980362705886364, 47.51633249223232, 53.41471418738365, 73.06827038526535, 76.20570123195648, 94.29681926965714, 49.080165177583694, 4.648014139384031, 0.4415406711632386, 0.10868561250390485, 0.0909581981250085, 0.04138758697081357, 0.04123165432247333, 0.19259377877460793, 0.042733512600534596, 0.04216101617203094, 0.08592501937528141, 0.04023367349873297, 0.024256258184323087, 0.047360432290588506, 0.04337372629379388, 0.04060323706653435, 0.052137202728772536, 0.041451452489127405, 0.06557402390171774, 0.06664437896688469, 0.020876564049103763, 0.07249173082527705, 0.041425414237892255, 0.07280261648702435, 0.003706174870785617, 0.021238617082417477, 0.020593666631611995, 0.07295546180102974, 0.08051444368902594, 0.010812706659635296, 0.04046083748107776, 0.15902931889286265, 0.20601722644641995, 0.1700917721609585, 0.15330134890973568, 0.10731758942711167, 0.15534483769442886, 0.16034256404964253, 0.15529296157183126, 0.13083193742204458, 0.10521245043491945, 0.13533335993997753, 0.1682770875049755, 0.1930299834930338, 0.13053280737949535, 0.1533825695514679, 0.18523453851230443, 0.28736812993884087, 0.16911293874727562, 0.11979683971730992, 0.1537862978875637, 0.1532734590000473, 0.13303092098794878, 0.42203180550131947, 0.2532670379150659, 0.3001413226593286, 0.24067371210549027, 0.32595989818219095, 0.13202488044044003, 24.89412099123001, 119.71405059099197, 110.47939851880074, 107.11393430829048, 78.14700186252594, 38.29013876616955, 64.27952438592911, 149.9446052312851, 126.49819135665894, 119.7580674290657, 135.6049346923828, 60.85126854479313, 4.2065585777163506, 1.0000114585272968, 0.5482580338139087, 0.5005263607017696, 0.5971463886089623, 0.44066086993552744, 0.7979236962273717, 2.47716355137527, 37.71779827773571, 134.63353961706161, 101.33592635393143, 109.95915323495865, 102.47125223279, 83.66063520312309, 87.92570114135742, 92.93497234582901, 94.13423359394073, 90.31163111329079, 86.06038123369217, 86.54119983315468, 83.68197485804558, 86.2771824002266, 97.59507268667221, 105.02200216054916, 105.77197551727295, 103.65580826997757, 109.80414435267448, 105.24196475744247, 107.69640505313873, 102.97336488962173, 103.17441210150719, 110.66495776176453, 103.05897429585457, 108.25655579566956, 94.39742267131805, 86.35733529925346, 90.61975657939911, 91.00122570991516, 84.5188419520855, 97.71887764334679, 106.22005507349968, 96.6692827641964, 77.14880302548409, 82.85845264792442, 91.815385222435, 107.9745501279831, 123.15090537071228, 119.70461949706078, 115.0746363401413, 112.97087162733078, 112.40427643060684, 113.28293368220329, 118.13467293977737, 108.89695823192596, 96.54428467154503, 96.6975000500679, 97.0417919754982, 90.19258350133896, 104.47049975395203, 111.47522628307343, 108.23096796870232, 109.41018909215927, 107.43146046996117, 106.75205692648888, 104.43293496966362, 103.49254623055458, 102.48401194810867, 87.98632308840752, 84.75863188505173, 87.80139461159706, 86.01998940110207, 85.91093525290489, 89.3446134030819, 87.29003325104713, 91.66623562574387, 81.71926617622375, 83.96654158830643, 88.23248147964478, 95.10978564620018, 103.77636060118675, 95.91914221644402, 70.99113464355469, 13.735578004270792, 0.9401439491193742, 1.7599892034195364, 0.4064625268802047, 0.19539192784577608, 0.44294359744526446, 0.41185351728927344, 0.5032278376165777, 0.17301800107816234, 0.5919247562997043, 9.387671761214733, 84.39214155077934, 107.34446793794632, 110.88492035865784, 121.62562921643257, 146.67064011096954, 125.46465441584587, 67.0305235683918, 31.712743006646633, 38.9377798140049, 72.13099747896194, 86.90680861473083, 108.1885090470314, 57.835491970181465, 6.326992521062493, 0.4647453728830442, 0.2265240580891259, 0.1155646238476038, 0.1907651120563969, 0.09710945203551091, 0.3020772594027221, 0.16230732580879703, 0.10917785679339431, 0.15175107662798837, 0.15348237357102334, 0.15625174215529114, 0.18345843069255352, 0.15464049502043054, 0.09852603383478709, 0.11412190360715613, 0.13923629972850904, 0.21652789291692898, 0.15074202296091244, 0.18265661434270442, 0.10926669187028892, 0.1858815280138515, 0.16423560358816758, 0.10039905871963128, 0.16032996238209307, 0.09123974668909796, 0.1666812621988356, 0.19419377495069057, 0.12728697998682037, 0.22984555485891178], [0.02020985568378819, 0.019157725910190493, 0.027066641559940763, 0.015316715562221361, 0.07571216192445718, 0.020639657523133792, 0.02911651652539149, 0.07740039203781635, 0.05285706742142793, 0.043524616048671305, 0.012379501004033955, 0.07627951155882329, 0.08383251173654571, 0.02725090569583699, 0.025722361642692704, 0.038376949887606315, 0.03796877237618901, 0.032660498036420904, 0.03641679686552379, 0.03733071462193038, 0.047928538915584795, 0.04816606699023396, 0.07373465006821789, 0.030901439204171766, 0.25587892276234925, 0.4409072926500812, 4.168759156018496, 34.35676082968712, 84.17906418442726, 80.43861329555511, 84.72775474190712, 61.918566673994064, 40.275908410549164, 40.794827565550804, 100.36834627389908, 92.35298797488213, 107.03156992793083, 107.98559993505478, 47.61929176747799, 2.9677585512399673, 0.3184359159786254, 0.08639105100883171, 0.38443166529759765, 0.026637316550477408, 0.12064838738297112, 0.11685184188536368, 1.0308535723015666, 5.788302076980472, 104.34160307049751, 94.67498257756233, 100.40809214115143, 87.43576303124428, 75.3100436925888, 79.7219717502594, 81.69674098491669, 80.56675761938095, 70.4947292804718, 74.8026417195797, 82.12640672922134, 83.4172734618187, 79.3481858074665, 84.37929823994637, 97.72844552993774, 101.30044385790825, 96.75986990332603, 94.65033710002899, 98.04074317216873, 102.11158633232117, 103.0586551129818, 96.26116186380386, 95.57811051607132, 98.30653131008148, 96.56654387712479, 92.42378577589989, 74.54962849617004, 73.48062425851822, 89.0305906534195, 96.260766685009, 87.31697380542755, 77.21520826220512, 92.14148372411728, 91.28206863999367, 75.06407529115677, 58.12705412507057, 75.71434959769249, 80.55413469672203, 91.32723301649094, 101.80538356304169, 95.81483781337738, 92.78598234057426, 94.86653789877892, 99.12243112921715, 84.68011289834976, 82.18707427382469, 80.36547482013702, 87.15866670012474, 93.53393420577049, 88.97199019789696, 85.23184329271317, 91.10665485262871, 98.38379636406898, 92.92702317237854, 90.6528452038765, 95.65315648913383, 93.8239574432373, 98.44553545117378, 96.12646669149399, 84.40895944833755, 72.94307470321655, 77.14971497654915, 84.63966026902199, 82.74596348404884, 87.00484335422516, 88.65085422992706, 84.06508550047874, 85.92143788933754, 85.04629924893379, 80.47945350408554, 85.05880057811737, 85.21260872483253, 94.19916450977325, 78.4526726603508, 37.217672914266586, 3.6849593790248036, 0.6748851109296083, 0.5214330169837922, 0.17230830009793863, 0.3389953955775127, 0.10978125996189192, 0.03504741194774397, 0.24034753820160404, 0.09713051418657415, 0.08904356844141148, 3.5410874616354704, 63.47961790859699, 84.50024574995041, 102.20547169446945, 79.46113094687462, 104.37470689415932, 140.0057217478752, 35.04691779613495, 30.80656573176384, 51.11592493951321, 66.33746355772018, 68.57792973518372, 78.94224599003792, 66.50419101119041, 14.995915275067091, 0.7471206004265696, 0.0552151414740365, 0.11045541206840426, 0.09473692465689965, 0.04477729082282167, 0.0790827814489603, 0.057475318826618604, 0.09260468985303305, 0.05272383335977793, 0.06013843783875927, 0.038254584578680806, 0.04182454496913124, 0.10003006289480254, 0.03886519029038027, 0.07660423085326329, 0.02785524025966879, 0.06546270175022073, 0.07519543418311514, 0.02552710815507453, 0.03483466789475642, 0.10407568057416938, 0.030231129567255266, 0.048983127053361386, 0.07251999923028052, 0.04943726948113181, 0.029796164235449396, 0.02584867146651959, 0.026776298545883037, 0.02588909996120492, 0.009690164697531145, 0.023122069142118562, 0.03288283805886749, 0.08949356226366945, 0.008104476200969657, 0.02911847950599622, 0.0353456328593893, 0.006714074124829494, 0.051923007777077146, 0.04420060868142173, 0.05350918145268224, 0.018501784252293874, 0.038183984070201404, 0.04287108080461621, 0.05765406880527735, 0.01578741066623479, 0.033053394727176055, 0.023457185925508384, 0.04119788660318591, 0.0040488831291440874, 0.04899875297269318, 0.09854314033873379, 0.08002959119039588, 0.3273646649904549, 0.31793039466720074, 8.693817593157291, 50.68093568086624, 113.48553881049156, 104.89363744854927, 119.4547601044178, 91.77078321576118, 65.35830929875374, 31.336595490574837, 61.79857671260834, 96.57697051763535, 115.69717213511467, 116.97261929512024, 53.25035400688648, 2.826557890512049, 0.382238797028549, 0.07468135590897873, 0.5508122686296701, 0.06301252346020192, 0.8226546098012477, 0.39650637831073254, 1.6009514685720205, 10.263686254620552, 117.44966089725494, 98.92177909612656, 108.37811887264252, 91.70263007283211, 81.11949115991592, 85.52976250648499, 87.04591915011406, 84.54545572400093, 77.44090095162392, 79.48663517832756, 85.94174399971962, 88.27462881803513, 82.01530069112778, 88.94567281007767, 101.90003648400307, 104.01478260755539, 101.82041555643082, 98.03815931081772, 101.11793205142021, 104.31194946169853, 105.89235305786133, 98.36958512663841, 98.86054158210754, 99.66944977641106, 99.68472495675087, 93.39821308851242, 79.26135286688805, 76.86443388462067, 91.9525046646595, 98.33730205893517, 91.76884531974792, 80.3416197001934, 93.5528039932251, 96.06337487697601, 80.23105323314667, 61.84470623731613, 78.07443335652351, 84.55056264996529, 89.57260876893997, 105.02782344818115, 101.16913810372353, 98.31758111715317, 100.29330030083656, 100.72209969162941, 89.4346533715725, 85.30968591570854, 88.84553298354149, 93.07251736521721, 96.32235378026962, 91.24510422348976, 84.97831329703331, 91.72745794057846, 99.83385175466537, 98.13571527600288, 94.74598556756973, 100.34868612885475, 97.81730756163597, 101.12371534109116, 101.36332288384438, 89.11589607596397, 78.05214375257492, 80.09343981742859, 88.96613851189613, 85.95362216234207, 91.9254957139492, 93.22439521551132, 87.74713352322578, 89.76239338517189, 92.01465412974358, 83.95860761404037, 90.41400521993637, 89.93301942944527, 99.87310364842415, 85.05690068006516, 46.698141396045685, 6.03353189304471, 0.6408692768309265, 0.20598264236468822, 0.20680614426964894, 0.8474746404681355, 0.282319625839591, 0.044601349873119034, 0.26573612820357084, 0.06136318559583742, 0.08354898905963637, 2.469948213547468, 65.32107129693031, 93.26737850904465, 101.05632215738297, 89.86310318112373, 108.81834045052528, 94.42013785243034, 20.704500004649162, 39.145484268665314, 76.82683110237122, 87.48864099383354, 79.50567215681076, 90.19974991679192, 84.89689886569977, 25.73479738086462, 0.6185919628478587, 0.03367455006809905, 0.05725734634324908, 0.09143048606347293, 0.056631816041772254, 0.13728461461141706, 0.05761287218774669, 0.12916443549329415, 0.09355517322546802, 0.0735554881975986, 0.017871663767436985, 0.034015763594652526, 0.06920492203789763, 0.011430636441218667, 0.023639607679797336, 0.11370558102498762, 0.05401327412982937, 0.022162572386150714, 0.06196741625899449, 0.019972451918874867, 0.1358819258166477, 0.021125669627508614, 0.02772043655568268, 0.03261298574216198, 0.018795574542309623, 0.01606268993782578, 0.03987088944995776, 0.009868410943454364, 0.06974489384447224, 0.0931926563498564, 0.14020095812156796, 0.14720666891662404, 0.16144876484759152, 0.1472738481243141, 0.13075809372821823, 0.11396526591852307, 0.11515115111251362, 0.21647192013915628, 0.17973525391425937, 0.11630343928118236, 0.1971063928795047, 0.12255860870936885, 0.1611708156997338, 0.1999235706171021, 0.09204712914652191, 0.13483144546626136, 0.14089139294810593, 0.12112584066926502, 0.1685309613822028, 0.13228087686002254, 0.21103277918882668, 0.15061060345033184, 0.4013216699240729, 0.6211489287670702, 12.360791824758053, 61.98346719145775, 139.81523036956787, 111.38454794883728, 120.2718834578991, 86.29643216729164, 52.84660667181015, 59.26311336457729, 156.80762976408005, 120.7875157892704, 121.56392812728882, 130.81558048725128, 70.99831625819206, 6.872816132381558, 0.6192031956743449, 0.48601847200188786, 0.9302909590769559, 0.30890059482771903, 0.7204035215545446, 0.781538262963295, 3.809504583477974, 9.03570044785738, 125.17204731702805, 104.46707993745804, 113.7993411719799, 100.92134580016136, 85.61946049332619, 88.8011285662651, 90.6120277941227, 92.89908707141876, 83.57125639915466, 83.6152732372284, 90.65549746155739, 95.76061472296715, 88.82030233740807, 95.22251799702644, 108.36048021912575, 108.78155082464218, 108.00149068236351, 105.99947690963745, 106.22188657522202, 111.24431267380714, 112.4664942920208, 103.28221991658211, 103.60188916325569, 103.38392525911331, 104.61815983057022, 100.6029836833477, 83.14283698797226, 80.71988180279732, 98.29783737659454, 102.42868691682816, 96.39901846647263, 85.29653862118721, 100.45212417840958, 100.5579636991024, 83.79383325576782, 74.43104445934296, 88.95695060491562, 96.38723909854889, 104.00330722332001, 113.7535460293293, 111.67587831616402, 108.01632508635521, 108.0122821033001, 108.57503950595856, 99.43947851657867, 94.63699981570244, 97.01149240136147, 98.98102551698685, 99.57024469971657, 91.4587439596653, 83.98790404200554, 92.49714463949203, 105.18665492534637, 100.84132209420204, 97.02771753072739, 103.09520155191422, 101.93743407726288, 103.59536111354828, 104.7485764324665, 95.59861421585083, 83.02276343107224, 84.29697945713997, 93.83632197976112, 90.97727939486504, 96.11031755805016, 94.16156932711601, 89.30418357253075, 94.76377621293068, 95.13725817203522, 87.95437440276146, 93.54339569807053, 94.32936832308769, 106.37722983956337, 87.60933011770248, 48.040791749954224, 5.909877028316259, 2.4895499367266893, 2.7294885367155075, 0.6748395727481693, 0.6785802938975394, 0.5540036817546934, 0.23455534275854006, 0.4162381257629022, 0.2541717159328982, 0.2142020020983182, 7.400852423161268, 80.90377673506737, 104.30624976754189, 109.47157099843025, 88.70760038495064, 129.3490719795227, 158.04943352937698, 48.711030185222626, 38.86601686477661, 66.6490164399147, 85.91012209653854, 87.30337053537369, 102.65773102641106, 99.37906935811043, 30.443024039268494, 0.8390772098209709, 0.13490206823917106, 0.2832608768949285, 0.138392151275184, 0.09579550183843821, 0.19478992733638734, 0.1611070058424957, 0.2334778185468167, 0.19118746829917654, 0.21503206458874047, 0.16733018128434196, 0.22071865241741762, 0.1519092876696959, 0.12846027093473822, 0.1698453346034512, 0.19231646787375212, 0.19729114312212914, 0.17744296754244715, 0.16336311993654817, 0.13340717501705512, 0.1806750355171971, 0.13295762648340315, 0.24125079129589722, 0.1631214321241714, 0.20954802370397374, 0.11062627672799863, 0.10182949641603045, 0.1171648278250359], [0.038219351117732, 0.046771289489697665, 0.0581115026579937, 0.021647499634127598, 0.03255644151067827, 0.06190663065353874, 0.10598358639981598, 0.04101851322047878, 0.05764982372056693, 0.07922782679088414, 0.016215160467254464, 0.05973433842882514, 0.03299824944406282, 0.03340092021971941, 0.06534925705636851, 0.06828154932009056, 0.03964254916354548, 0.11883703497005627, 0.06884587841341272, 0.06194492547365371, 0.022154332691570744, 0.11145966404001229, 0.406434740871191, 0.3489450429333374, 17.669855542480946, 47.66128711402416, 88.45162332057953, 93.4495635330677, 69.72438141703606, 62.672541216015816, 51.728398874402046, 40.93962639570236, 43.81832912564278, 104.18484628200531, 83.64304214715958, 114.49595779180527, 99.85981196165085, 49.96475011110306, 4.735869700089097, 0.2701202023308724, 0.08793281827820465, 0.1798286457778886, 0.13738709036260843, 0.12122263156925328, 0.029434307871269993, 0.38938348239753395, 1.5042975987307727, 51.64270207285881, 117.98878356814384, 93.311418145895, 94.49826925992966, 76.28406822681427, 84.56057131290436, 74.57462355494499, 77.29435041546822, 77.23033145070076, 83.09312805533409, 79.64730575680733, 84.53569024801254, 82.64618083834648, 79.9683429300785, 83.86768609285355, 90.26335090398788, 88.26312303543091, 87.97861710190773, 91.44534587860107, 97.99619436264038, 95.6643658876419, 99.05937731266022, 98.73552069067955, 96.73678994178772, 97.6163287460804, 93.24261903762817, 78.39375302195549, 72.24859356880188, 70.15522509813309, 82.57816448807716, 90.48240154981613, 94.49358031153679, 84.89977151155472, 87.36445605754852, 97.66310423612595, 86.23588621616364, 60.207320898771286, 54.42033402621746, 51.301457583904266, 34.09549064934254, 57.52902701497078, 82.20763117074966, 83.04244637489319, 82.54810810089111, 76.80913165211678, 74.5745399594307, 80.59557527303696, 82.21919015049934, 87.91595846414566, 92.77139112353325, 91.6374483704567, 89.9158139526844, 79.57137823104858, 82.63221278786659, 93.78813296556473, 93.11464190483093, 89.23703357577324, 87.61524260044098, 89.41423326730728, 96.06133818626404, 94.2089755833149, 78.2970330119133, 70.68240121006966, 77.16771841049194, 81.16378918290138, 85.10801553726196, 89.30773258209229, 89.43142354488373, 92.14718341827393, 92.82949760556221, 87.26885318756104, 90.0939179956913, 90.82808420062065, 96.13847404718399, 97.2117568552494, 79.34382364153862, 35.167147144675255, 4.755708435550332, 0.618242856580764, 1.4533404330722988, 0.09059198535396717, 0.4274606751278043, 0.1641006811405532, 0.07186470509623177, 0.08197162838769145, 0.04889739786449354, 0.025122615406871773, 3.2045449828729033, 63.47037300467491, 80.59576526284218, 90.98141357302666, 85.49842938780785, 128.42154175043106, 113.52541387081146, 55.42205527424812, 21.931801848113537, 49.90622565150261, 63.80417749285698, 63.687303364276886, 70.16214832663536, 83.17440569400787, 21.26866903156042, 0.768611712846905, 0.08768457730184309, 0.1677058861241676, 0.02839775577740511, 0.043810981151182204, 0.03661327304143924, 0.030453818399109878, 0.029894971921748947, 0.028771549586963374, 0.06117495468060952, 0.04709210879809689, 0.05131585676281247, 0.017327079513052013, 0.035229011773481034, 0.019552778539946303, 0.06902409775648266, 0.015819386098883115, 0.01647024033445632, 0.044690541180898435, 0.06905771704623476, 0.07079613118548878, 0.010769332766358275, 0.07750618518912233, 0.10780778538901359, 0.026978073656209745, 0.028576565127877984, 0.009448624387005111, 0.09869341040030122, 0.06740464988979511, 0.051247705341666006, 0.04296823906770442, 0.09134272710070945, 0.03829270870483015, 0.012585930307977833, 0.008185529859474627, 0.06459576194174588, 0.06234536238480359, 0.024169245079974644, 0.12247827122337185, 0.032196741085499525, 0.02919101887528086, 0.11294499840005301, 0.18167718721088022, 0.04911586387606803, 0.043845683976542205, 0.033182669430971146, 0.03586011560400948, 0.06256624037632719, 0.09450759360333905, 0.5235269421245903, 1.3262934191152453, 25.418101474642754, 63.31906512379646, 109.78205233812332, 113.94757881760597, 91.55490159988403, 108.97277936339378, 65.0469084084034, 55.95692217350006, 36.29279114305973, 61.968621388077736, 87.68100947141647, 122.5005854666233, 110.89312791824341, 57.831084206700325, 4.433938376605511, 0.29286503966432065, 0.17453060194384307, 0.032245066031464376, 0.18676606414373964, 0.1250752166379243, 0.08170702305505984, 0.7349140523001552, 1.1115110130049288, 61.44266501069069, 121.82920709252357, 100.44307306408882, 96.715769469738, 82.42022216320038, 86.40986368060112, 78.51164549589157, 84.432662576437, 82.36766338348389, 87.12576046586037, 82.3883418738842, 87.96166241168976, 86.12142875790596, 85.60239180922508, 87.350282818079, 95.51393195986748, 90.0210303068161, 92.65100598335266, 95.46701207756996, 101.54029458761215, 100.18517330288887, 102.49128475785255, 100.9922955930233, 97.84678637981415, 100.81400156021118, 95.97930058836937, 82.46625289320946, 74.17572855949402, 73.7557826936245, 85.00106647610664, 94.66948807239532, 97.95122757554054, 89.73536923527718, 88.67537811398506, 100.03404021263123, 90.98585173487663, 68.30841019749641, 62.006231769919395, 57.65341334044933, 41.75714872777462, 58.61009560525417, 88.51533830165863, 86.9623464345932, 84.998968988657, 81.04227930307388, 83.20076867938042, 86.39623761177063, 89.98198360204697, 90.88298365473747, 96.27464354038239, 95.28546541929245, 94.76738601922989, 82.81137317419052, 85.37673711776733, 95.11831998825073, 94.35866475105286, 92.3717437684536, 89.75672408938408, 92.35272198915482, 100.26536419987679, 97.1993239223957, 83.11879187822342, 74.77013826370239, 80.07988974452019, 83.10588017106056, 87.81483069062233, 92.45904788374901, 94.3453274667263, 95.63044890761375, 96.54993876814842, 92.63240218162537, 92.17559069395065, 95.65410643815994, 99.24978509545326, 98.78106504678726, 87.0733080804348, 45.42603425681591, 11.52834389358759, 0.5053360119927675, 0.9227876679506153, 0.4173539893236011, 0.38561417371965945, 0.4931449005380273, 0.04006478295195848, 0.19761406641919166, 0.06653477117652074, 0.1628953145700507, 2.363034775480628, 62.68145553767681, 89.4970840215683, 93.88973951339722, 88.09802949428558, 127.11045250296593, 62.56571374833584, 31.08899887651205, 42.626386284828186, 68.61892953515053, 84.40529644489288, 73.73403266072273, 75.94020187854767, 95.27283489704132, 35.31588636338711, 0.621641892939806, 0.12694038217887282, 0.14349722187034786, 0.02658292269188678, 0.045615899143740535, 0.059528641068027355, 0.09316996147390455, 0.0486025648569921, 0.027632009660010226, 0.09128925536060706, 0.03957425302360207, 0.029134621217963286, 0.007906446153356228, 0.015850519193918444, 0.0817072753852699, 0.0899738802399952, 0.0268716070058872, 0.030060494973440655, 0.07319955417187884, 0.022702711175952572, 0.011371316577424295, 0.027281231705273967, 0.1107141915417742, 0.0731181405717507, 0.01968716849660268, 0.06091123621445149, 0.026235200530209113, 0.15428788581630215, 0.10639752668794245, 0.18335153174120933, 0.16372739570215344, 0.1687584148021415, 0.1589900889666751, 0.2824450784828514, 0.18127191520761698, 0.18401780223939568, 0.2054626343306154, 0.11899509758222848, 0.21002569963457063, 0.117220756073948, 0.1861266593914479, 0.19977451767772436, 0.24614198977360502, 0.0984712113859132, 0.1443783292779699, 0.17206561780767515, 0.1311127661028877, 0.22919025330338627, 0.23774654808221385, 0.7381631154567003, 2.2543518198654056, 35.19774690270424, 84.80273991823196, 129.23507809638977, 130.89949518442154, 95.02372786402702, 89.90939229726791, 75.16698136925697, 58.7528083473444, 64.5298321545124, 155.1287430524826, 106.54528722167015, 134.75642502307892, 122.69813686609268, 78.41178685426712, 10.291330721229315, 0.5941522086504847, 0.5018212599679828, 0.33243736310396343, 0.3176088962936774, 0.43382429459597915, 0.10545439057750627, 1.8281037546694279, 2.7594157308340073, 62.156658098101616, 128.13555389642715, 104.5873510837555, 105.81269413232803, 84.64737385511398, 93.31759661436081, 85.50513982772827, 90.16351506114006, 87.64311030507088, 91.04160994291306, 90.77603459358215, 95.98382234573364, 92.50507861375809, 89.65383321046829, 94.96275633573532, 101.68235376477242, 97.54347145557404, 98.13800275325775, 100.7740581035614, 106.65785998106003, 107.13390603661537, 109.13920283317566, 106.45498886704445, 101.68768867850304, 104.08251777291298, 103.48123043775558, 87.61267393827438, 77.23674550652504, 76.7025625705719, 89.67340975999832, 98.55092659592628, 101.04701265692711, 93.24917748570442, 95.72377949953079, 108.47813710570335, 96.6268390417099, 71.45959630608559, 70.83229556679726, 69.23126667737961, 54.61924575269222, 73.07459324598312, 96.69994711875916, 94.45763424038887, 92.79010891914368, 93.45300614833832, 94.40467268228531, 95.60302197933197, 95.1939283311367, 96.03439763188362, 99.02961730957031, 97.02372774481773, 96.12623110413551, 83.61173942685127, 85.58591589331627, 95.73743596673012, 95.76051592826843, 93.40564548969269, 90.83392828702927, 97.36467584967613, 105.8108702301979, 103.30213844776154, 86.27766877412796, 78.23110654950142, 86.21786758303642, 89.51184242963791, 93.63391444087029, 97.46906384825706, 97.15749576687813, 98.100316375494, 101.48947611451149, 97.09409236907959, 99.0890385210514, 101.97171583771706, 104.41329002380371, 104.95251148939133, 89.08117353916168, 45.002372190356255, 10.505128148943186, 0.8291270874906331, 3.9307328034192324, 1.108664134517312, 0.5050655140075833, 0.7783942285459489, 0.12519250565674156, 0.2136404931661673, 0.1942655851598829, 0.2985099039506167, 7.302744537591934, 80.71807309985161, 96.14220544695854, 105.73246523737907, 89.8683089017868, 144.03323203325272, 141.7637202143669, 71.60280302166939, 29.512009397149086, 62.85227157175541, 82.4031762778759, 78.63639280200005, 84.63779076933861, 112.48195186257362, 47.123349979519844, 0.962063844781369, 0.1664556938339956, 0.2319666277617216, 0.10090112162288278, 0.10125417611561716, 0.17080790014006197, 0.27671667805407196, 0.13631360343424603, 0.11294286843622103, 0.15216580359265208, 0.14138175960397348, 0.16503632155945525, 0.0789665685442742, 0.1374617058900185, 0.17761878232704476, 0.14645656541688368, 0.14568906597560272, 0.15767518139909953, 0.18332229112274945, 0.14607070799684152, 0.1302684989059344, 0.15968785621225834, 0.2890195569489151, 0.247426662244834, 0.11419139831559733, 0.12926486291689798, 0.14603597548557445], [0.02681969006516738, 0.04826853531994857, 0.0626027317775879, 0.02413037138467189, 0.04748674953589216, 0.06831991093349643, 0.031672725453972816, 0.03606096302974038, 0.021653342191712, 0.016754649877839256, 0.007499013108827057, 0.031921092595439404, 0.024573880691605154, 0.013639895969390636, 0.08422264392720535, 0.021647623943863437, 0.032346027801395394, 0.011523274097271496, 0.047536892743664794, 0.07999340406968258, 0.07181794237112626, 0.14892543840687722, 14.493618328124285, 69.88993093371391, 115.77266648411751, 114.5735040307045, 102.64560967683792, 75.43289110064507, 80.97987905144691, 44.99768704175949, 77.95619890093803, 66.09566733241081, 85.99076896905899, 92.16397851705551, 105.62534898519516, 108.25320437550545, 49.13414888083935, 5.342306708917022, 0.6944841623771936, 0.11697437046677805, 0.14670389355160296, 0.031048135824676137, 0.2687519195023924, 0.05032779474277049, 0.6757065199781209, 1.989986824337393, 2.129400037229061, 97.34316140413284, 105.16630321741104, 96.63065403699875, 90.69139033555984, 80.34047216176987, 76.00439563393593, 79.83565405011177, 81.54348000884056, 82.18497678637505, 77.12174087762833, 76.18984088301659, 77.45917037129402, 80.18593445420265, 83.13211396336555, 81.96732446551323, 84.0973761677742, 78.78393888473511, 78.55307847261429, 81.74889698624611, 91.41419515013695, 91.65253356099129, 93.55538785457611, 88.43054965138435, 99.00986596941948, 96.63459062576294, 87.88602367043495, 76.75468817353249, 70.17403408885002, 68.75745490193367, 80.58766409754753, 92.9151526093483, 95.31117483973503, 83.45397189259529, 81.13538950681686, 89.95217800140381, 94.6446830034256, 80.28325483202934, 71.00625783205032, 70.2347320318222, 60.22837936878204, 44.37288276851177, 69.41257774829865, 81.94279298186302, 65.3622230887413, 65.19724354147911, 65.24833559989929, 77.71905362606049, 84.19904351234436, 89.68194410204887, 86.36632561683655, 91.28541246056557, 88.64713042974472, 91.62616297602654, 91.55835941433907, 94.65187981724739, 93.19791063666344, 94.82952788472176, 91.57501012086868, 92.06237196922302, 88.98275882005692, 91.53101608157158, 79.44283112883568, 71.36586293578148, 68.19877848029137, 75.58508813381195, 82.35966101288795, 88.11420142650604, 90.30261039733887, 93.96669298410416, 92.79740452766418, 95.20979627966881, 90.31914710998535, 94.28215205669403, 94.35006961226463, 92.74379700422287, 86.85276791453362, 89.84965950250626, 70.10728687047958, 28.909413032233715, 0.6394065928179771, 1.8178161629475653, 0.4413836030289531, 0.03959522240620572, 0.23949528549565002, 0.10713193376432173, 0.1753564935643226, 0.13622133963508531, 0.32246883551124483, 4.338627615943551, 62.40448459982872, 84.26086619496346, 91.82815253734589, 43.734513223171234, 44.675186946988106, 69.82736349105835, 44.889506846666336, 24.16234865784645, 36.550660505890846, 50.69154091179371, 70.81090271472931, 69.26216661930084, 78.20130854845047, 20.66314872354269, 0.6478120386600494, 0.05076199566246942, 0.07038641371764243, 0.06793507767724805, 0.03517294622724876, 0.03226974615245126, 0.07907211678684689, 0.05380209600843955, 0.025528764999762643, 0.0472707548760809, 0.07432236423483118, 0.05532650444365572, 0.0259675616689492, 0.08014443854335696, 0.08203008736018091, 0.03117094085610006, 0.03017835544596892, 0.006266091986617539, 0.0029880314968977473, 0.013954485875729006, 0.060290218170848675, 0.02390408128121635, 0.08402869847486727, 0.07526400120696053, 0.02826829739206005, 0.0178243648406351, 0.05248222347290721, 0.024445238668704405, 0.0355103376932675, 0.03282768535427749, 0.019568549178075045, 0.06915930222021416, 0.07113150029908866, 0.019237759115640074, 0.031136085890466347, 0.06499438430182636, 0.024927425001806114, 0.02292711807967862, 0.06970255431951955, 0.10126068475074135, 0.034408036881359294, 0.03022000106284395, 0.011850900755234761, 0.03925496625015512, 0.018185729531978723, 0.02990406323078787, 0.11240919004194438, 0.20895185647532344, 18.514639511704445, 87.31507390737534, 130.77942162752151, 129.26720917224884, 118.07742521166801, 99.22058746218681, 119.9447514116764, 65.77041998505592, 69.95386630296707, 43.57340566813946, 46.982290148735046, 87.65416011214256, 116.35626956820488, 113.0034738779068, 60.05035512149334, 4.175281031057239, 0.4697382159065455, 0.15253052464686334, 0.212021958141122, 0.22051298845326528, 0.781681586522609, 0.2328770054737106, 0.43387832294683903, 0.7196303817909211, 3.0493472982198, 106.89591720700264, 109.66599896550179, 103.81069555878639, 91.99300289154053, 86.95704951882362, 82.43561893701553, 86.28019943833351, 85.31018748879433, 85.116276293993, 82.71242648363113, 82.23094671964645, 80.96161723136902, 85.2731242775917, 84.33232516050339, 85.00911444425583, 85.66047549247742, 83.17069709300995, 80.36167502403259, 83.94223049283028, 92.7906484901905, 91.57015398144722, 95.80541431903839, 92.26623103022575, 102.94058784842491, 99.15886357426643, 90.55776670575142, 78.31682994961739, 72.6397293806076, 71.4113312959671, 84.0994280576706, 97.02827230095863, 99.45876628160477, 87.61185318231583, 83.37351500988007, 94.33996975421906, 99.18393462896347, 85.9386357665062, 81.53488487005234, 83.57425823807716, 72.34907537698746, 53.775200843811035, 74.1574439406395, 89.51937362551689, 70.81182226538658, 69.84149873256683, 72.59018763899803, 85.56722089648247, 90.22608250379562, 93.09470057487488, 90.42854323983192, 94.15515527129173, 88.93115758895874, 94.60287004709244, 93.72994288802147, 95.52221551537514, 95.66102966666222, 98.21605056524277, 94.32700484991074, 93.91029641032219, 91.88468590378761, 95.74519515037537, 84.73945811390877, 73.51672992110252, 72.34219774603844, 79.03678491711617, 85.92393815517426, 91.90218016505241, 94.79883313179016, 98.78306373953819, 96.19753047823906, 96.82502880692482, 94.8450842499733, 96.45212441682816, 96.5834453701973, 94.90302354097366, 90.97642824053764, 93.27146708965302, 82.62599632143974, 41.09174743294716, 2.106537139043212, 1.1368083930574358, 0.2464237090316601, 0.22989931603660807, 0.46406595152802765, 0.09268772875657305, 0.05887759201868903, 0.12584225594764575, 0.4012913309270516, 3.845223616808653, 65.97147479653358, 86.46066695451736, 97.99307093024254, 52.188303396105766, 46.56736381351948, 33.99669975042343, 33.99251237511635, 44.59565341472626, 55.77431157231331, 73.20366472005844, 87.22936570644379, 78.51601526141167, 92.05224931240082, 34.00306060910225, 0.4724347946466878, 0.03770391100260895, 0.03109867979219416, 0.04589801174006425, 0.030298878373287152, 0.035812774003716186, 0.08077214704826474, 0.03103621507762, 0.09497409278992563, 0.02101363686961122, 0.021732531204179395, 0.04036642516439315, 0.07151596248149872, 0.05046200843935367, 0.04992843765649013, 0.03141194589261431, 0.009598408341844333, 0.020150324307905976, 0.012514533846115228, 0.08280316775199026, 0.06424758335924707, 0.010629348871589173, 0.03498873775242828, 0.04747220344142988, 0.02045217432169011, 0.016817929099488538, 0.12677825259743258, 0.1475605694577098, 0.14129996008705348, 0.10616178347845562, 0.15050190850161016, 0.15070307505084202, 0.12529624305898324, 0.15645339852198958, 0.17957402975298464, 0.16429227398475632, 0.12782125209923834, 0.13510253716958687, 0.12297743975068443, 0.1703421282581985, 0.13601517101051286, 0.09153215287369676, 0.15366779174655676, 0.1057497801957652, 0.14704542991239578, 0.11647727253148332, 0.22712163539836183, 0.3670009021880105, 26.95202026516199, 107.55667135119438, 157.54766285419464, 140.8861345052719, 131.23377084732056, 98.27864080667496, 110.43068513274193, 56.48985877633095, 100.1268920302391, 88.99463698267937, 127.38351345062256, 120.03725364804268, 127.72786617279053, 128.3383110165596, 74.20176476240158, 11.302427016198635, 1.2760958564467728, 0.36150155821815133, 0.250798684428446, 0.29487207415513694, 0.7854014087934047, 0.1613117050146684, 2.991215167567134, 5.568738933652639, 3.2762081874534488, 113.6545917391777, 113.39101508259773, 110.74601501226425, 98.204924762249, 93.75666305422783, 84.1420465707779, 91.9351775944233, 89.48918044567108, 92.37444922327995, 88.15664514899254, 84.98412698507309, 86.5541723370552, 92.72536799311638, 91.34088948369026, 91.74105361104012, 91.42930313944817, 87.39704310894012, 84.69436973333359, 91.44426673650742, 99.75269570946693, 97.79138535261154, 102.7905111014843, 97.96565920114517, 105.20078256726265, 105.2474744617939, 98.03811371326447, 84.89711165428162, 75.12099623680115, 76.16625934839249, 89.31714087724686, 102.09405407309532, 103.18273365497589, 93.00884038209915, 88.45002740621567, 98.69050830602646, 103.89506623148918, 92.1742531657219, 83.8025651872158, 87.94539168477058, 74.89726424217224, 61.899400502443314, 83.28226670622826, 96.78209111094475, 83.10589537024498, 82.02296108007431, 83.5613465309143, 91.15099087357521, 94.63446915149689, 97.88432076573372, 93.83599519729614, 99.89377453923225, 91.30051285028458, 96.28274470567703, 96.51406109333038, 100.37962406873703, 98.28889265656471, 102.90259748697281, 94.86862778663635, 96.22979074716568, 94.73492056131363, 99.29839208722115, 88.02236795425415, 76.95968717336655, 76.05584487318993, 83.60990792512894, 90.5177852511406, 98.72593760490417, 99.13790389895439, 101.98808535933495, 101.02647855877876, 101.41502290964127, 98.05540278553963, 101.26983270049095, 102.11279466748238, 100.0692643225193, 95.2601283788681, 94.32059079408646, 79.9347223341465, 36.7131207883358, 1.2822737311944366, 3.9892534632235765, 1.6570390714332461, 0.17194348998600617, 0.7546137389726937, 0.29202050529420376, 0.39570203865878284, 0.23691779177170247, 0.8059226826298982, 10.544921513646841, 83.9522847533226, 94.54270407557487, 111.38763338327408, 62.304929941892624, 68.98356556892395, 96.03685230016708, 57.79138393700123, 30.643356889486313, 49.30720679461956, 70.64060345292091, 94.85158190131187, 84.9371387064457, 106.68904110789299, 44.11784425377846, 0.8138038159813732, 0.16696179402060807, 0.19764073920669034, 0.23559434950584546, 0.10748772678198293, 0.17814738443121314, 0.18807543528964743, 0.18847787228878587, 0.18938632041681558, 0.16914476203965023, 0.11981840652879328, 0.14115357887931168, 0.20388407137943432, 0.15475745749427006, 0.19956526171881706, 0.13540972693590447, 0.1789326805737801, 0.08633815072244033, 0.07383645046502352, 0.14818808500422165, 0.14148943038890138, 0.1425568465492688, 0.202592036803253, 0.1707688334863633, 0.11980792740359902, 0.08084705943474546], [0.07379985516308807, 0.08923486442654394, 0.08296965374029242, 0.05965132178971544, 0.035142451379215345, 0.016362541718990542, 0.025894244899973273, 0.004505001988945878, 0.0027649994217426865, 0.05320421441865619, 0.010653592053131433, 0.044209533007233404, 0.04963895553373732, 0.05615295267489273, 0.022109614583314396, 0.028905963663419243, 0.031312212377088144, 0.038356292207026854, 0.03178213657520246, 0.05826749467814807, 0.0264516312017804, 35.67952685058117, 112.25412368774414, 101.73257187008858, 98.12932401895523, 66.81755259633064, 73.44384983181953, 61.70265845954418, 41.36775702238083, 68.87662410736084, 149.02228832244873, 127.29926437139511, 84.16719362139702, 104.18731614947319, 108.70811596512794, 60.825084149837494, 7.0558561105281115, 0.3527188638690859, 0.25580883433576673, 0.22760320018278435, 0.16667611169395968, 0.33544600009918213, 0.23476320347981527, 1.0792939667589962, 9.510481171309948, 1.1131532373838127, 6.449676537886262, 115.52884876728058, 100.66441878676414, 103.15029859542847, 94.64284390211105, 90.38326486945152, 86.54032588005066, 78.78128662705421, 78.52654069662094, 81.22325599193573, 83.72472256422043, 81.39329686760902, 79.57785308361053, 74.98835295438766, 74.65696513652802, 77.26129978895187, 76.2013466656208, 75.01854613423347, 70.72818115353584, 69.90463614463806, 72.55304083228111, 76.53357803821564, 82.30745181441307, 90.29273852705956, 97.50381678342819, 98.04187551140785, 84.17452722787857, 73.79941195249557, 68.46335828304291, 72.213194668293, 85.04863232374191, 92.4574139714241, 96.94766342639923, 83.2574312388897, 72.17574387788773, 79.99342158436775, 90.51594614982605, 87.02296078205109, 91.39866158366203, 88.70982706546783, 91.64562553167343, 73.0882877111435, 60.02611622214317, 69.03278812766075, 53.48140060901642, 53.19944053888321, 76.05218186974525, 86.63750186562538, 81.65254175662994, 84.91663500666618, 84.41707581281662, 86.19416445493698, 84.36196357011795, 88.03928464651108, 92.70547226071358, 93.20420309901237, 90.7880799472332, 92.13962182402611, 93.97808477282524, 91.74450382590294, 91.1917094886303, 92.62022763490677, 85.27545735239983, 74.92682665586472, 67.79832556843758, 67.10670188069344, 69.9108450114727, 79.47177037596703, 88.17717164754868, 88.81247475743294, 89.2948816716671, 91.99060142040253, 92.54551604390144, 91.4469949901104, 94.67617571353912, 89.64985102415085, 87.9824548959732, 89.19750049710274, 90.76376125216484, 95.58318704366684, 66.47070720791817, 3.412613505497575, 1.9972649775445461, 0.4461596201872453, 0.21941879560472444, 0.06899868662003428, 0.10991577422828414, 0.13279079168569297, 0.03915246452379506, 0.1320336971548386, 10.854856632649899, 53.40095892548561, 70.17805427312851, 97.43469849228859, 55.67724198102951, 51.96695387363434, 79.04390573501587, 27.98136033117771, 22.500310242176056, 17.44426354765892, 47.53162667155266, 66.72334045171738, 70.5444686114788, 72.58207887411118, 9.305426124483347, 0.5914757866412401, 0.023380251186608803, 0.10140757061890326, 0.06085721899580676, 0.06516382403788157, 0.0750841417175252, 0.01168954393506283, 0.060958370013395324, 0.029509598753065802, 0.027332412064424716, 0.11928066858672537, 0.05886406637728214, 0.0359852008841699, 0.030229979238356464, 0.05245906475465745, 0.04882374341832474, 0.028102733522246126, 0.02798181911202846, 0.044082692547817715, 0.12756181211443618, 0.01785792104783468, 0.010540743860474322, 0.019238686800235882, 0.07947718841023743, 0.06920774962054566, 0.011668413135339506, 0.07412295657559298, 0.058788478636415675, 0.06636222926317714, 0.042415094139869325, 0.02148413252143655, 0.06415910451323725, 0.031079614018381108, 0.02644201482326025, 0.06346233916701749, 0.004894177736787242, 0.04224389180308208, 0.025903597816068213, 0.06971572001930326, 0.031002920477476437, 0.02327578462427482, 0.05192087410250679, 0.09105927863856778, 0.04763605851621833, 0.0949023939028848, 0.1840604015160352, 42.75597833096981, 133.3300119638443, 113.55547025799751, 112.71956831216812, 86.42077669501305, 112.76888206601143, 107.79463738203049, 71.11914977431297, 84.00063335895538, 158.09186965227127, 107.24622800946236, 75.6724302470684, 119.7969089448452, 116.15937173366547, 70.95097079873085, 5.879075406119227, 0.3492964943870902, 0.32180529611650854, 0.5298536026384681, 0.06764609279343858, 1.1296590766869485, 0.7846323656849563, 1.736473215278238, 9.473054129630327, 1.703168477397412, 8.592506479471922, 119.89881187677383, 105.2615413069725, 109.20870870351791, 100.13859540224075, 94.98372361063957, 89.63957637548447, 84.92899954319, 81.3745866715908, 86.0646142065525, 88.2229819893837, 87.42217496037483, 84.46449726819992, 78.33465099334717, 76.85354366898537, 81.09526365995407, 80.00142395496368, 75.85354372859001, 74.84639257192612, 74.20339107513428, 75.27294248342514, 79.62822318077087, 84.73297566175461, 93.98419484496117, 99.14209887385368, 101.17942035198212, 87.25221008062363, 75.62884658575058, 70.24863168597221, 76.92334592342377, 89.4477778673172, 95.94261735677719, 99.8101258277893, 87.74810627102852, 77.27817088365555, 83.18764418363571, 91.1251750588417, 93.61595660448074, 93.09150114655495, 92.48368576169014, 93.87491270899773, 81.06191664934158, 66.90392956137657, 75.0180521607399, 62.59622611105442, 62.70178824663162, 84.42795842885971, 92.26773574948311, 87.23147079348564, 89.08387139439583, 90.06251648068428, 90.67621394991875, 88.00285220146179, 89.09483760595322, 95.71811780333519, 96.75756722688675, 92.15939596295357, 93.39772671461105, 95.70538088679314, 93.37211608886719, 93.92348170280457, 95.49677968025208, 89.41830664873123, 81.57676622271538, 71.07107475399971, 71.19877070188522, 71.82875409722328, 81.78733572363853, 90.52103027701378, 90.75248345732689, 91.52050584554672, 93.27004596590996, 95.72031408548355, 94.12998542189598, 94.02865245938301, 92.16191902756691, 94.18429210782051, 92.72630274295807, 94.42532077431679, 101.96634292602539, 81.3095873594284, 9.574703425168991, 1.4379074424505234, 0.19761405157623813, 0.4255334660410881, 0.5423479853197932, 0.2524194458965212, 0.25639388419222087, 0.03952614701120183, 0.2587980270618573, 10.100086033344269, 58.58001261949539, 75.5883939564228, 106.56598091125488, 63.153367415070534, 50.108579993247986, 37.05494664609432, 21.504106298089027, 33.86904940009117, 35.69548599421978, 66.30760475993156, 80.68739354610443, 76.80802211165428, 90.29501840472221, 15.887693222612143, 0.7387376565020531, 0.13526518625440076, 0.10755073511973023, 0.026671501727832947, 0.009343076144432416, 0.055193433654494584, 0.035947280848631635, 0.0634791562333703, 0.024596714720246382, 0.022196024692675564, 0.07355439724051394, 0.029199299387983046, 0.03234570496715605, 0.03261582816776354, 0.008410604696109658, 0.037212045208434574, 0.019755236426135525, 0.005110702568345005, 0.06982733160839416, 0.021498676760529634, 0.030139526279526763, 0.0620587523735594, 0.036978194475523196, 0.06210209750861395, 0.06789538019802421, 0.14683191402582452, 0.2548735501477495, 0.2606978954281658, 0.19233770814025775, 0.10273783322190866, 0.11409491169615649, 0.0964615200064145, 0.16730333038140088, 0.11439128094934858, 0.14562332653440535, 0.06987709261011332, 0.12458363285986707, 0.1376787989283912, 0.1977615014766343, 0.15255776146659628, 0.04588313910062425, 0.14688252849737182, 0.1661325924214907, 0.09649406318203546, 0.1207965868525207, 0.24517140904208645, 58.134551122784615, 153.6703509092331, 133.02950888872147, 119.70940724015236, 93.20360273122787, 98.23377281427383, 84.88540068268776, 54.933606684207916, 92.54765152931213, 145.51914989948273, 147.33206301927567, 120.58151364326477, 126.15310147404671, 126.6445443034172, 87.01172098517418, 13.92934100702405, 0.9874262369703501, 0.7970959937665612, 0.5464030208531767, 0.5802908493205905, 1.2388755474239588, 0.9387090511154383, 2.7345695765689015, 18.853788413107395, 4.366897149011493, 9.74089415743947, 124.2848253250122, 104.80855241417885, 114.73401501774788, 107.20949918031693, 98.57864990830421, 94.781544059515, 91.1555278301239, 88.71569395065308, 92.02523276209831, 90.31242907047272, 93.17263439297676, 90.0534425675869, 82.21118777990341, 80.81518068909645, 86.28225892782211, 86.4971449971199, 81.2352329492569, 78.75664114952087, 78.02378967404366, 79.72061902284622, 84.43881824612617, 89.84604209661484, 100.36067828536034, 101.97002112865448, 108.34516704082489, 92.12062284350395, 79.06044244766235, 75.74220970273018, 79.94154676795006, 93.95048305392265, 99.94790643453598, 103.49585205316544, 93.90308439731598, 79.72856819629669, 89.90485534071922, 96.86092928051949, 98.51197868585587, 100.35227313637733, 99.78402122855186, 103.56023579835892, 85.96686825156212, 75.34225076436996, 83.84773716330528, 72.76440069079399, 73.71458530426025, 90.29001787304878, 96.43971428275108, 91.01870477199554, 92.82386630773544, 92.3743200302124, 93.78711462020874, 87.75770455598831, 92.27782040834427, 96.92728891968727, 101.67475417256355, 99.58103612065315, 101.3925053179264, 103.67511123418808, 96.5135595202446, 97.44632586836815, 100.28757780790329, 92.2827297449112, 84.66739118099213, 72.73195043206215, 74.10360842943192, 76.61803990602493, 87.85044237971306, 95.98265200853348, 96.24576508998871, 96.52669921517372, 100.70000007748604, 102.97716468572617, 99.72339928150177, 99.65024560689926, 98.9129027724266, 96.79621875286102, 99.5243963599205, 95.97623035311699, 106.38261795043945, 80.06462216377258, 6.875138282775879, 5.286295339465141, 1.7981862975284457, 0.4561431391630322, 0.5674706934951246, 0.27192854904569685, 0.4488195665180683, 0.14829425665084273, 0.22820140089606866, 20.539075881242752, 76.52276381850243, 81.77096620202065, 119.9559760093689, 70.37039995193481, 82.08587810397148, 104.46360692381859, 34.77749705314636, 32.52485632896423, 25.885259807109833, 58.82440410554409, 88.01554352045059, 87.59389534592628, 103.80688816308975, 25.407000370323658, 0.9127872576937079, 0.2878985577262938, 0.2780607668682933, 0.24725196068175137, 0.17516267427708954, 0.11630765467998572, 0.09243286040145904, 0.18002127762883902, 0.1394468024955131, 0.07103886542608961, 0.1489588647382334, 0.15955891547491774, 0.13291183597175404, 0.13682616030564532, 0.15847638918785378, 0.10405990251456387, 0.13869614980649203, 0.10892206817516126, 0.1799192323233001, 0.19841770845232531, 0.13077373820124194, 0.1680653973016888, 0.06227392324944958, 0.1460154031519778, 0.17576216632733122], [0.039594951522303745, 0.04330725583713502, 0.08661266372655518, 0.07375436151050963, 0.05485109577421099, 0.030035328745725565, 0.0215008753730217, 0.08907908020773903, 0.0404084863839671, 0.02237862270703772, 0.033678683830657974, 0.04485894191020634, 0.021399158467829693, 0.009376253856316907, 0.019687485764734447, 0.045327044135774486, 0.052477514545898885, 0.03645781907835044, 0.10293491795891896, 0.28025918640196323, 25.331169739365578, 118.40861544013023, 92.34222695231438, 99.81854617595673, 78.47158804535866, 82.55699962377548, 43.464378118515015, 28.73846210539341, 33.0591456592083, 51.98743477463722, 62.373026087880135, 51.19641602039337, 105.00210642814636, 109.31166797876358, 72.3253646492958, 8.171825353056192, 0.3267459513153881, 0.27040874934755266, 0.10934556732536294, 0.11427916469983757, 0.5481574579607695, 0.05136638217663858, 1.558586829341948, 5.542472368106246, 0.1328369532711804, 1.3576526613906026, 38.13964784145355, 111.025520414114, 107.53100752830505, 102.62853339314461, 100.99589020013809, 97.35979691147804, 90.11154904961586, 89.49349701404572, 85.86868152022362, 87.69477993249893, 83.46160188317299, 81.98611065745354, 80.55341273546219, 80.29688850045204, 73.26943159103394, 72.5896480679512, 73.5255378484726, 75.31322032213211, 74.31806892156601, 72.9555456340313, 68.83596628904343, 74.92539033293724, 84.13329944014549, 93.486687541008, 98.42560172080994, 92.78350487351418, 80.46298518776894, 73.7627287209034, 66.76647573709488, 75.51537707448006, 90.83605617284775, 91.92611888051033, 90.05806311964989, 83.37676003575325, 73.97323742508888, 68.71384844183922, 75.13229683041573, 80.61333552002907, 79.39643561840057, 82.68560752272606, 82.99239546060562, 81.95451155304909, 72.24107757210732, 72.24198192358017, 58.97054806351662, 64.60654243826866, 86.32809206843376, 80.85111916065216, 78.49674269556999, 81.27890020608902, 85.13894587755203, 90.70174098014832, 91.96027904748917, 87.72814974188805, 89.80409234762192, 81.04851096868515, 79.36843872070312, 81.19312360882759, 85.62314629554749, 90.76645150780678, 85.47358632087708, 88.10788616538048, 87.49919682741165, 82.85106584429741, 81.32029518485069, 76.3743057847023, 71.41892328858376, 67.77530640363693, 69.7878760099411, 77.7200035750866, 82.50454723834991, 86.7605696618557, 88.39532554149628, 88.48155051469803, 88.50574761629105, 82.50305011868477, 88.54203566908836, 88.2970704138279, 87.49643057584763, 83.56163531541824, 91.29980608820915, 83.27900648117065, 7.00049308128655, 2.151110884733498, 0.2712875709403306, 0.3127662342740223, 0.11826603396912105, 0.15565649518975988, 0.0827879982534796, 0.08760045486269519, 0.19024143781280145, 7.023259559646249, 30.79048689454794, 66.50101438164711, 100.01577079296112, 66.53458938002586, 79.85752567648888, 93.2679408788681, 49.554862305521965, 41.52123458683491, 30.170067586004734, 65.18789604306221, 63.89408826828003, 70.88067457079887, 61.843475103378296, 8.529997933655977, 0.17155936919152737, 0.12977301143109798, 0.12905421172035858, 0.0939738706802018, 0.04186207537713926, 0.07966003875480965, 0.05019051968702115, 0.09671859254012816, 0.014409501254704082, 0.021863700239919126, 0.009687670153653016, 0.022499307051475625, 0.03007976854860317, 0.010134582207683707, 0.036826117284363136, 0.06145800609374419, 0.06949832270038314, 0.0770217928220518, 0.08442748410743661, 0.020369074190966785, 0.012993341551919002, 0.004672603517974494, 0.020169371528027114, 0.05485522953676991, 0.04835733700019773, 0.01781484308594372, 0.04133292408369016, 0.05299522934365086, 0.03985201292380225, 0.024531867711630184, 0.00449014001787873, 0.10205335784121417, 0.037869732768740505, 0.052097104489803314, 0.05055000488937367, 0.033340702357236296, 0.059252580686006695, 0.031002297073428053, 0.059958637721138075, 0.022886121842020657, 0.1000850708805956, 0.1573640137212351, 0.08253230611444451, 0.34022160165477544, 34.34496246278286, 137.0037916302681, 99.63712871074677, 112.36263826489449, 104.76575911045074, 112.64025896787643, 67.5358584523201, 51.412309035658836, 39.539017751812935, 13.662041500210762, 63.856371492147446, 66.54659673571587, 114.04018744826317, 115.2666400372982, 80.58708652853966, 7.836739383637905, 0.5772919789887965, 0.13832847500452772, 0.27051478740759194, 0.16967441799351946, 1.2647718703374267, 0.2527366694994271, 3.5377740394324064, 1.1316259461455047, 0.3781850083032623, 1.8617935781367123, 47.69438333809376, 113.81053537130356, 107.39615276455879, 106.80192545056343, 103.96024033427238, 102.18725547194481, 96.95399388670921, 95.39772659540176, 88.91919583082199, 92.42400616407394, 89.02934432029724, 86.63652911782265, 85.627022087574, 87.10104659199715, 75.41166543960571, 76.06072381138802, 75.7757543027401, 79.74431455135345, 76.45038530230522, 75.30106857419014, 70.54245471954346, 77.36510261893272, 90.17698153853416, 95.31613737344742, 101.23597651720047, 96.97783380746841, 86.9488799571991, 76.75171673297882, 69.70567122101784, 81.08459383249283, 94.2144700884819, 94.80159178376198, 92.02134177088737, 87.29699447751045, 76.18960529565811, 71.07879593968391, 77.6735320687294, 82.64590725302696, 84.0359714627266, 87.62678638100624, 87.7578717470169, 87.74300694465637, 78.23574990034103, 79.45883587002754, 67.23402544856071, 70.19893035292625, 91.15112006664276, 86.14099770784378, 83.86847645044327, 87.8292927145958, 89.0485180914402, 95.50561800599098, 95.59293732047081, 91.8024431169033, 89.9886104464531, 85.68907275795937, 81.83160334825516, 84.89930033683777, 88.2704946398735, 92.99895331263542, 88.03378254175186, 90.95753565430641, 91.65313392877579, 89.09578755497932, 86.30756556987762, 80.74257418513298, 75.97078263759613, 70.5951426923275, 73.16909417510033, 79.8190489411354, 86.63524478673935, 88.45943570137024, 90.51226034760475, 90.01770168542862, 90.98060801625252, 87.21534445881844, 92.76574462652206, 91.9586831331253, 92.33021959662437, 86.424340903759, 92.9662598669529, 94.00687962770462, 13.907952904701233, 0.990781516302377, 0.09983303752960637, 0.6735387956723571, 0.16670539684128016, 0.24123499839333817, 0.033442766216467135, 0.10020516521763057, 0.10090874347952195, 6.2485400307923555, 35.93168891966343, 70.75047075748444, 103.78544971346855, 78.34678754210472, 69.21407639980316, 37.70778961479664, 30.792968161404133, 48.746512681245804, 47.155378460884094, 83.51834043860435, 77.19766080379486, 78.37242856621742, 79.21627968549728, 13.509416040033102, 0.22509162401547655, 0.16432400821940973, 0.08273816303699277, 0.10150738948141225, 0.04879027997958474, 0.06761149386875331, 0.06971589071326889, 0.06290143879596144, 0.05036662390921265, 0.04104485204152297, 0.049745412907213904, 0.018641029710124712, 0.038309737283270806, 0.010286758661095519, 0.0166094987798715, 0.029328948876354843, 0.06789175109588541, 0.07765379836200736, 0.10312504135072231, 0.040430053195450455, 0.028947405189683195, 0.03166516667988617, 0.056881908676587045, 0.05331279433448799, 0.20614824519725516, 0.11789891577791423, 0.18073715327773243, 0.11915396171389148, 0.11378143593901768, 0.16294238157570362, 0.09338522140751593, 0.2796512487111613, 0.11789107869844884, 0.12643618189031258, 0.15001547522842884, 0.1472711912356317, 0.152823094103951, 0.18055482243653387, 0.18061547074466944, 0.22176619386300445, 0.115515137440525, 0.2217538742115721, 0.15062434802530333, 0.5821894411928952, 47.075244560837746, 160.18674284219742, 114.66954007744789, 125.22502407431602, 106.11372157931328, 104.52663034200668, 56.46651662886143, 35.99669203162193, 51.53166063129902, 79.155832529068, 84.43067908287048, 77.96039387583733, 134.18425172567368, 121.41314461827278, 104.24781650304794, 16.219518966972828, 0.9587991668377072, 0.44446957181207836, 0.45509006129577756, 0.35249669454060495, 2.486531473696232, 0.22533905605087057, 6.171405594795942, 11.596181653439999, 0.4327559284865856, 1.851753091905266, 49.010731503367424, 117.00787380337715, 113.68741437792778, 109.38695713877678, 109.93271425366402, 109.45574104785919, 101.77648231387138, 98.5354234278202, 93.79384025931358, 97.34933227300644, 94.58797484636307, 89.9201001226902, 90.14264658093452, 90.53287044167519, 79.73959520459175, 82.02094718813896, 78.4246301651001, 82.50478282570839, 82.53833502531052, 80.23514941334724, 74.25173968076706, 81.969353556633, 95.06235659122467, 101.33902698755264, 107.13626191020012, 102.89790853857994, 91.61689147353172, 81.28700137138367, 73.8507167994976, 84.7847592830658, 98.53299915790558, 98.4856840968132, 97.06852734088898, 92.72731348872185, 79.8744423687458, 75.92854410409927, 81.99583053588867, 89.99312460422516, 88.09293016791344, 91.669951826334, 92.41708293557167, 96.10134243965149, 84.93154540657997, 84.43716913461685, 74.77419644594193, 77.09227725863457, 94.6033564209938, 91.28823190927505, 88.46406385302544, 92.42817834019661, 91.65877282619476, 100.67696571350098, 101.0440032184124, 96.57292753458023, 96.5601298213005, 88.3628448843956, 86.65563449263573, 88.6651262640953, 95.30790701508522, 99.7904884815216, 91.468266248703, 96.07218280434608, 96.06312409043312, 92.92757794260979, 89.52116712927818, 84.32652667164803, 80.66637307405472, 74.77579236030579, 78.85732814669609, 87.01815783977509, 93.23915362358093, 94.67081040143967, 96.18980169296265, 95.35184785723686, 98.1616298854351, 92.02790021896362, 97.9091714322567, 95.24101540446281, 97.43789792060852, 92.9405352473259, 98.49445402622223, 96.18996128439903, 10.912281051278114, 5.6992890033870935, 1.200077016837895, 0.9037616138812155, 0.7069601397961378, 0.3684846038231626, 0.25390486931428313, 0.24613888759631664, 0.24422448797849938, 15.791911762207747, 55.77695623040199, 85.54072871804237, 120.07421806454659, 85.69105625152588, 111.9048236310482, 124.49467286467552, 61.452916860580444, 52.861539870500565, 44.12298537790775, 82.07001015543938, 86.83590441942215, 90.05133748054504, 94.7362732887268, 20.584082566201687, 0.6602892035152763, 0.2689651830587536, 0.31800962635315955, 0.2125613807584159, 0.14846290228888392, 0.2226528525352478, 0.14899300353135914, 0.1456854591378942, 0.10786352810100652, 0.10518461247556843, 0.19774756394326687, 0.09794957062695175, 0.1457441778620705, 0.13363694393774495, 0.13625659164972603, 0.11030682668206282, 0.1460099409450777, 0.28998912835959345, 0.2487122846650891, 0.16093600017484277, 0.06171251450723503, 0.12364370282739401, 0.10056487677502446, 0.12769462686264887], [0.08252607207396068, 0.03836789197521284, 0.014699562252644682, 0.024940620387496892, 0.08923093846533448, 0.0601592587918276, 0.014255151236284291, 0.056151260578189977, 0.05299783057125751, 0.03108860328211449, 0.03309036110294983, 0.010832229781954084, 0.0718747908831574, 0.09751148827490397, 0.08237846632255241, 0.10719410347519442, 0.02854977545212023, 0.12314454914303496, 0.5409762589260936, 10.803494788706303, 106.77363976836205, 84.2398153245449, 91.89870715141296, 59.59476716816425, 42.77090013027191, 31.252371110022068, 42.082582265138626, 54.65535141527653, 90.65515547990799, 158.4020698070526, 93.56211349368095, 91.87348410487175, 116.51491865515709, 65.89115470647812, 9.910409711301327, 0.3429432353004813, 0.3276681143324822, 0.2363064995734021, 0.22802680323366076, 0.22021755430614576, 0.18470626295311376, 0.620361955370754, 0.8832373120822012, 1.0155440750531852, 3.818561160005629, 57.937235310673714, 102.54762813448906, 101.09559684991837, 97.01910719275475, 107.21490249037743, 98.1208048760891, 102.05648928880692, 95.9758959710598, 94.97666358947754, 90.17090946435928, 89.11646604537964, 88.51915329694748, 88.64836156368256, 83.19915756583214, 79.90747779607773, 74.18776631355286, 69.85802784562111, 71.46658033132553, 74.51332524418831, 71.51546090841293, 71.11256092786789, 70.58191940188408, 76.41415044665337, 89.21173453330994, 95.85933342576027, 94.30756509304047, 92.55895212292671, 78.90906617045403, 71.93837061524391, 66.49104371666908, 75.73479250073433, 89.32654157280922, 90.94521671533585, 91.31334856152534, 86.91067680716515, 81.35895431041718, 76.95100843906403, 76.41095101833344, 73.61733332276344, 73.91415059566498, 79.9652498960495, 85.25401890277863, 83.72310385107994, 75.03131344914436, 76.94838657975197, 69.65858414769173, 74.54310804605484, 85.73424473404884, 78.3969296514988, 74.44609925150871, 78.67709621787071, 83.76553997397423, 85.94842404127121, 84.90770548582077, 83.92048805952072, 83.60968753695488, 79.85955476760864, 72.35698655247688, 73.61341193318367, 83.67189019918442, 86.85145318508148, 87.28191688656807, 83.1724525988102, 86.7068937420845, 86.41955316066742, 86.93580105900764, 82.85005509853363, 84.40021231770515, 75.61892911791801, 70.91725900769234, 67.03354820609093, 70.09980887174606, 70.6503613293171, 75.15712469816208, 76.25449061393738, 77.63671964406967, 82.08909273147583, 82.06618756055832, 82.52169191837311, 88.57141569256783, 86.75352483987808, 85.55931732058525, 87.33670994639397, 88.11769723892212, 8.194356244057417, 1.6110846935771406, 0.3114992694463581, 0.6049200589768589, 0.027753053946071304, 0.06214292305230629, 0.05850950903550256, 0.015729417391412426, 0.4620662791421637, 0.1123254832054954, 16.05744246393442, 56.946142092347145, 91.76613226532936, 94.3012498319149, 86.2124490737915, 77.9484549164772, 51.65061704814434, 28.275635540485382, 29.5021166279912, 61.41492269933224, 82.93999627232552, 70.53373038768768, 61.340051516890526, 2.6575695583596826, 0.13662405865034088, 0.11889029148733243, 0.037943854767945595, 0.009568170462443959, 0.0016404525013058446, 0.07688572004553862, 0.04443974721652921, 0.10727515342296101, 0.07835501659428701, 0.05967852892354131, 0.02407405907433713, 0.065608845470706, 0.028511575255834032, 0.02650289319717558, 0.026379082555649802, 0.027507898448675405, 0.052485997293842956, 0.013880562401027419, 0.047571595569024794, 0.07109681231668219, 0.019305353926029056, 0.06110811315011233, 0.008685954471729929, 0.022650892569799908, 0.039529620262328535, 0.07229662762256339, 0.01351781545963604, 0.048619482113281265, 0.008413455470872577, 0.028141885522927623, 0.033837017326732166, 0.02734362962655723, 0.03516365453833714, 0.06529537713504396, 0.06648253140156157, 0.049203337111976, 0.12209361608256586, 0.10523826975258999, 0.04553252998448443, 0.09956285124644637, 0.08196285620215349, 0.7124632538761944, 15.305288974195719, 124.53252643346786, 94.2406202852726, 108.02238956093788, 84.51492056250572, 64.8422209918499, 60.880747362971306, 63.603050485253334, 42.091842368245125, 30.29522716999054, 116.57842844724655, 98.88419151306152, 101.6726566851139, 124.14160341024399, 76.52123630046844, 8.864190001040697, 0.43316782044712454, 0.2133949610288255, 0.21631016163155437, 0.11672246328089386, 0.6615264527499676, 1.1452817008830607, 1.402623129542917, 0.30787010793574154, 0.4606295406119898, 6.1189342103898525, 69.7159306704998, 113.58915165066719, 104.37641680240631, 99.84129935503006, 111.2717168033123, 104.68198880553246, 107.31834053993225, 101.15630999207497, 97.58147701621056, 96.47870019078255, 94.60898771882057, 94.44226786494255, 90.77493265271187, 87.8685750067234, 84.47921767830849, 77.59689018130302, 72.10097149014473, 73.24643522500992, 77.91167289018631, 75.38191303610802, 73.96670177578926, 73.82015883922577, 81.89881414175034, 95.04689142107964, 97.57381662726402, 93.5601755976677, 96.68186008930206, 82.89572104811668, 73.8063807785511, 68.7791745364666, 78.6650812625885, 91.25617682933807, 92.31941297650337, 93.51675912737846, 93.95912379026413, 86.3322414457798, 82.04435393214226, 81.26294106245041, 77.99877181649208, 78.09708014130592, 82.5214259326458, 88.18136662244797, 91.77613332867622, 80.60308367013931, 81.97512164711952, 76.04454427957535, 80.03571331501007, 90.67850142717361, 84.06906008720398, 78.54943826794624, 82.80821934342384, 92.24540814757347, 91.369988322258, 88.41727316379547, 86.81164652109146, 87.90258318185806, 84.08628076314926, 76.47491678595543, 75.64285263419151, 84.87982258200645, 91.2715432047844, 92.05648988485336, 85.50231277942657, 90.02527847886086, 90.78677281737328, 91.04385942220688, 85.2806630730629, 89.43778440356255, 81.47177785634995, 76.25972673296928, 70.51015645265579, 73.307383954525, 73.44842478632927, 78.48006159067154, 79.84184011816978, 79.7941754758358, 82.39537909626961, 88.22167485952377, 86.0005496442318, 90.5642719566822, 91.70326083898544, 89.97761383652687, 88.48012179136276, 98.76482471823692, 16.273677460849285, 0.8237001474481076, 0.2835542627144605, 0.9693438385147601, 0.49476509797386825, 0.05648990627378225, 0.0783204918843694, 0.04554127619485371, 0.42878499312791973, 0.33899334724992514, 19.33816932141781, 61.41005136072636, 96.94421321153641, 101.00753277540207, 80.69069176912308, 48.43939796090126, 35.37874259054661, 42.353686317801476, 50.99802866578102, 69.25469622015953, 94.07518476247787, 78.82547065615654, 78.6125148832798, 5.610669208690524, 0.20324615092249587, 0.09804299959796481, 0.05779262035503052, 0.04901313208392821, 0.10803461540490389, 0.01432355684301001, 0.025667247900855727, 0.06421195284929127, 0.05868640364496969, 0.06004554692481179, 0.08538287307601422, 0.0077435971525119385, 0.03994529717601836, 0.032584127329755574, 0.10656399783329107, 0.0356338347773999, 0.025401857747056056, 0.05767162801930681, 0.045086421305313706, 0.09427532364497893, 0.03276592011388857, 0.028359832031128462, 0.01246282656211406, 0.25865829549729824, 0.13055765448370948, 0.12733189476421103, 0.08166344414348714, 0.36284974368754774, 0.12389103838359006, 0.1496447279350832, 0.1449244757532142, 0.2352851114119403, 0.07004935250733979, 0.1284382736776024, 0.1567606773460284, 0.22943127318285406, 0.21205645316513255, 0.2521617425372824, 0.20705433329567313, 0.18133725388906896, 0.3766431222902611, 1.1036004312336445, 21.76209345459938, 147.21496850252151, 108.05752247571945, 123.29175621271133, 87.56627842783928, 62.07382254302502, 44.506658390164375, 57.980438992381096, 81.92716062068939, 114.43905964493752, 196.37028604745865, 123.50099578499794, 116.66193276643753, 133.20013493299484, 95.32508209347725, 17.227796763181686, 0.7292959943879396, 0.4613210738170892, 0.4443883808562532, 0.46702320221811533, 1.6055817576125264, 0.6550274358596653, 1.6571110300719738, 5.433821948245168, 2.9036160930991173, 4.987042872235179, 70.80209478735924, 116.8135218322277, 108.16866651177406, 103.94697144627571, 117.40568965673447, 109.47244495153427, 111.81068748235703, 104.80124920606613, 106.15257069468498, 101.20517536997795, 98.97927761077881, 98.02454844117165, 97.23286852240562, 92.22067147493362, 87.90824487805367, 82.60358512401581, 76.3324548304081, 78.43668311834335, 82.2784061729908, 78.7877082824707, 77.71456226706505, 76.0489672422409, 84.72179666161537, 99.7062774002552, 101.31533145904541, 98.75521883368492, 101.10592469573021, 86.06781363487244, 78.05998653173447, 72.82844245433807, 83.28525334596634, 98.1388159096241, 95.97502961754799, 95.50002470612526, 96.47252172231674, 90.72769358754158, 86.13442406058311, 87.32535615563393, 83.11892107129097, 82.05368623137474, 87.88685962557793, 97.31992945075035, 94.12521287798882, 89.14725199341774, 88.08047443628311, 83.58317255973816, 85.17696663737297, 96.96831151843071, 88.55254590511322, 84.02418449521065, 88.66533145308495, 94.76426258683205, 96.13735690712929, 92.40485519170761, 92.51285299658775, 92.02218532562256, 89.5577135682106, 80.43335437774658, 81.33692309260368, 92.01325580477715, 95.48475712537766, 93.75641226768494, 89.34289589524269, 94.60765019059181, 94.23308908939362, 95.45875892043114, 89.18917894363403, 92.77275145053864, 86.52755096554756, 78.86129513382912, 75.12161180377007, 78.24067443609238, 79.64094489812851, 85.99139213562012, 83.4107606112957, 84.46917861700058, 89.60206478834152, 91.19344979524612, 90.35222053527832, 95.90886756777763, 96.17574244737625, 96.14823192358017, 92.92309418320656, 104.74552899599075, 13.400164302438498, 4.135721828788519, 1.1383640533313155, 1.5366186643950641, 0.8430485310964286, 0.2208406466525048, 0.221281957346946, 0.1808929894468747, 0.7384839013684541, 3.5362638579681516, 32.768248468637466, 74.16355401277542, 108.36897656321526, 112.31339290738106, 111.24313473701477, 110.38243532180786, 62.14863292872906, 36.98406904935837, 41.272321343421936, 76.0338744521141, 102.95710176229477, 85.99359601736069, 100.05465030670166, 13.293861206620932, 0.5022182199172676, 0.16642277216305956, 0.10282565897796303, 0.19999774085590616, 0.1904587386525236, 0.2235383979859762, 0.13791569246677682, 0.13238051760708913, 0.1996737637091428, 0.20393116807099432, 0.1533583755372092, 0.15665410493966192, 0.15591212053550407, 0.20560741249937564, 0.125322054955177, 0.09837577119469643, 0.1660250552231446, 0.1531818334478885, 0.17995126341702417, 0.1989443216007203, 0.14689760893816128, 0.12799617630662397, 0.080231893225573], [0.0442915106395958, 0.03590661857742816, 0.038966734646237455, 0.09762974208570085, 0.01383352971970453, 0.025594107391953003, 0.030389153216674458, 0.06437787480535917, 0.04818187102500815, 0.08782413075095974, 0.04523169300227892, 0.01006705047984724, 0.03872987079375889, 0.03532354654453229, 0.015530949476669775, 0.1269322630832903, 0.024209616058215033, 0.1358361353049986, 0.9742598247248679, 81.80572673678398, 96.3683845102787, 108.12714993953705, 73.34895372390747, 50.03419518470764, 37.44005598127842, 46.322102174162865, 44.30451303720474, 101.42509236931801, 173.1999957561493, 97.17278614640236, 109.38657715916634, 114.28858011960983, 71.39307707548141, 8.722167871892452, 0.28552044939715415, 0.14245837839553133, 0.11445463067502715, 0.05774887446023058, 0.20893073495244607, 0.08106662382488139, 0.26022496924269944, 1.0466590616852045, 2.2336887661367655, 1.3703572796657681, 71.86425939202309, 113.1820110976696, 102.04434514045715, 104.7195839881897, 100.83268135786057, 92.61616945266724, 103.293786495924, 105.7111331820488, 95.73783874511719, 97.72750318050385, 100.46267241239548, 98.54873791337013, 91.26890614628792, 84.88725498318672, 80.45320451259613, 79.1258293390274, 75.60261279344559, 66.81445196270943, 74.01774063706398, 74.95487675070763, 72.18104839324951, 70.68352594971657, 72.03933879733086, 85.51498889923096, 93.73204797506332, 89.19476464390755, 85.85766211152077, 90.12690022587776, 80.78715339303017, 70.20659074187279, 65.60042470693588, 70.1389391720295, 86.06243312358856, 87.55654335021973, 95.24947375059128, 91.99576914310455, 86.68614685535431, 85.0529032945633, 81.47125348448753, 85.03749892115593, 76.29598438739777, 72.96071335673332, 79.24078077077866, 84.78083789348602, 79.49526071548462, 75.52698165178299, 68.5258649289608, 82.5245949625969, 80.151926279068, 75.4946605861187, 73.16165417432785, 71.92526131868362, 75.86340799927711, 79.94422942399979, 81.75035610795021, 83.48457545042038, 81.29753440618515, 72.35354393720627, 64.41278323531151, 64.04832199215889, 72.40098059177399, 83.40737879276276, 87.54538714885712, 87.9406875371933, 85.70513069629669, 86.50864318013191, 89.6017076075077, 88.00444811582565, 86.1941796541214, 83.7079806625843, 76.58166825771332, 74.41464453935623, 65.00504225492477, 68.68555516004562, 67.15193465352058, 74.02252838015556, 75.88952019810677, 75.32293260097504, 80.65719276666641, 82.27071538567543, 81.30454123020172, 79.95755910873413, 86.18040159344673, 85.53541660308838, 84.34126228094101, 87.39827424287796, 3.5661150561645627, 0.9059842571150512, 0.546310757054016, 0.5448243243154138, 0.16948319622315466, 0.1369780779350549, 0.06710965360980481, 0.112635597033659, 0.047191267149173655, 0.15013681637356058, 9.347197283059359, 49.50741425156593, 87.10857018828392, 87.92166575789452, 70.0624492764473, 81.5979690849781, 37.19087295234203, 27.485424242913723, 37.97945983707905, 47.239931523799896, 78.4579011797905, 74.46813806891441, 53.58645737171173, 3.760045012459159, 0.04019929350761231, 0.10919028034550138, 0.042772104279720224, 0.07833978030248545, 0.0540903313230956, 0.01955197145434795, 0.10440346493851393, 0.008949353814386996, 0.09260783655918203, 0.05199652863666415, 0.06763762488844804, 0.04649037917261012, 0.042944664746755734, 0.05571911911829375, 0.052455435652518645, 0.00980783035629429, 0.12456346128601581, 0.02530059911805438, 0.019822256072075106, 0.033930865611182526, 0.06825851305620745, 0.024987479591800366, 0.04127537795284297, 0.049337083255522884, 0.05128943259478547, 0.044900364882778376, 0.017449875267629977, 0.015229369419103023, 0.12183615763206035, 0.01675281677307794, 0.03017875991645269, 0.08056492457399145, 0.02666885411599651, 0.03315233043394983, 0.04201711002679076, 0.08280586174805649, 0.01428690216926043, 0.022839841512904968, 0.003945151756852283, 0.12939346226630732, 1.368366542737931, 97.40363895893097, 106.99836730957031, 117.36592099070549, 86.57027587294579, 62.50946916639805, 60.98855137825012, 57.20512479543686, 24.858049526810646, 45.28457544744015, 145.83223789930344, 108.08827042579651, 120.9326907992363, 121.1488763988018, 84.29900854825974, 8.909334428608418, 0.3644998645177111, 0.09877575168502517, 0.15102883335202932, 0.07864745988626964, 0.6991257320623845, 1.2409281497821212, 1.0231746593490243, 0.25477148999925703, 1.6997348866425455, 3.2057746918872, 87.86350607872009, 116.68975487351418, 106.44464582204819, 109.21395242214203, 105.49157336354256, 93.23544502258301, 107.85455256700516, 108.63206684589386, 102.39199608564377, 102.91616275906563, 104.53385755419731, 102.31744408607483, 93.91720443964005, 87.37049013376236, 86.6478981077671, 83.11749994754791, 75.67818313837051, 71.36914595961571, 77.80293792486191, 77.77199998497963, 74.63642343878746, 72.05056339502335, 75.39125293493271, 89.14304181933403, 94.38426777720451, 91.90819904208183, 89.89233881235123, 94.50149908661842, 84.47561547160149, 74.54044058918953, 67.56341457366943, 72.84538954496384, 88.75552341341972, 89.03594076633453, 94.51980650424957, 98.39902594685555, 91.53820529580116, 90.14196261763573, 87.26763725280762, 90.00874176621437, 83.22900876402855, 76.60704329609871, 82.41665035486221, 91.78805708885193, 85.84320768713951, 79.673091173172, 73.86248096823692, 86.23321875929832, 85.97137480974197, 78.97827565670013, 77.53811493515968, 75.00381052494049, 80.61812326312065, 81.99138477444649, 85.31320452690125, 88.26614767313004, 84.1335578262806, 76.05092793703079, 68.57818812131882, 65.84744185209274, 75.38538604974747, 84.97473388910294, 89.82855543494225, 90.15168249607086, 85.78103542327881, 90.87437331676483, 92.0810517668724, 92.65324026346207, 91.8343386054039, 88.68726387619972, 80.51401644945145, 78.26638385653496, 68.12320813536644, 72.44531661272049, 70.62495589256287, 77.00305804610252, 77.64416724443436, 79.03756007552147, 83.25488537549973, 86.36665999889374, 83.63142997026443, 84.32369202375412, 88.11980992555618, 90.60948193073273, 86.70438587665558, 94.65961620211601, 8.370892871171236, 1.4782583084888756, 0.4920688457787037, 2.095683258958161, 0.5092696321662515, 0.09573431176249869, 0.06737713105394505, 0.04640267958166078, 0.03649032885732595, 0.20273966481909156, 11.112744994461536, 55.609339624643326, 90.50323203206062, 97.27865606546402, 73.1218247115612, 39.279677867889404, 20.72766736149788, 38.241087198257446, 61.9877989590168, 61.704600155353546, 86.46044656634331, 82.56484240293503, 70.5979697406292, 4.963210076093674, 0.10225203077425249, 0.12472464091842994, 0.03454864418017678, 0.01857123257650528, 0.014662887169833994, 0.03999130662123207, 0.0916558169410564, 0.09137561908573844, 0.030013166360731702, 0.03182786029356066, 0.023610515490872785, 0.10561620845692232, 0.09393273343448527, 0.0050581302184582455, 0.020191901276120916, 0.031125206005526707, 0.007515348243032349, 0.06931517549674027, 0.08649594616144896, 0.031080732806003653, 0.050757769131450914, 0.023019263135211077, 0.17512559657916427, 0.21480088558746502, 0.1874195845448412, 0.21775346074718982, 0.062365756602957845, 0.19718267081771046, 0.32942638092208654, 0.11919043827219866, 0.17811168712796643, 0.19430751650361344, 0.12124593500629999, 0.16798710072180256, 0.13486669748090208, 0.184585589740891, 0.09434728970518336, 0.2572252380196005, 0.186757440387737, 0.3919613768812269, 2.8096172120422125, 122.15284332633018, 120.32078683376312, 136.68289124965668, 93.46573546528816, 71.39679327607155, 56.6482038795948, 61.01330325007439, 59.2724646627903, 140.16490280628204, 208.98225009441376, 113.02464634180069, 132.6008614897728, 131.94299519062042, 101.21855825185776, 16.065798215568066, 0.6988563621416688, 0.22927344805793837, 0.36312588199507445, 0.2042531265760772, 1.2957581388764083, 1.3852936844341457, 0.981314858654514, 4.775976547971368, 8.05944163352251, 2.5049089500680566, 90.57536736130714, 124.8443529009819, 111.6886380314827, 113.30260902643204, 111.05113863945007, 96.2830638885498, 109.20515969395638, 111.18927642703056, 103.94768580794334, 105.62430024147034, 109.60861444473267, 107.07497879862785, 100.54683789610863, 91.78686395287514, 90.6386947631836, 87.50595286488533, 83.06412041187286, 75.68243131041527, 81.05737209320068, 82.11464256048203, 78.33079040050507, 77.71866604685783, 78.9483180642128, 92.09472343325615, 100.81052854657173, 94.68357771635056, 93.12718123197556, 99.57771509885788, 88.84182438254356, 77.92751803994179, 70.85996568202972, 77.39915639162064, 93.61575901508331, 95.6443789601326, 101.848184466362, 100.35565495491028, 96.3459125161171, 94.51602950692177, 89.88757386803627, 96.53146415948868, 86.86137065291405, 82.04759135842323, 86.58261761069298, 97.42619454860687, 89.70019072294235, 86.31539314985275, 82.11817637085915, 90.5746454000473, 90.98474219441414, 86.08919128775597, 84.29816499352455, 80.74832707643509, 86.65572568774223, 86.63539677858353, 90.2090822160244, 94.90754529833794, 89.69437703490257, 81.13118693232536, 72.50675931572914, 70.23497521877289, 78.13003957271576, 90.12972727417946, 93.86036708950996, 93.33027273416519, 89.93738919496536, 93.4056530892849, 96.34091198444366, 94.6260716021061, 96.09606832265854, 93.34946930408478, 83.05107951164246, 82.50774666666985, 71.22683599591255, 76.48060888051987, 75.22182762622833, 80.91991066932678, 82.9391299188137, 84.20081421732903, 89.14168909192085, 91.43972977995872, 87.98471197485924, 89.46618407964706, 94.7305279970169, 96.56532034277916, 90.07626414299011, 102.13644459843636, 6.478568287566304, 4.842207944020629, 1.7392717651091516, 1.3401605375111103, 0.40922827378381044, 0.3503148694289848, 0.20786021661479026, 0.16812990477774292, 0.10643845613230951, 0.3513899148674682, 20.875456631183624, 69.33102652430534, 101.67323425412178, 103.32699671387672, 93.42672675848007, 110.33251360058784, 45.7033471763134, 35.308320969343185, 52.93298743665218, 66.33002355694771, 103.74592423439026, 92.13205263018608, 92.95910865068436, 8.461461011320353, 0.297258019563742, 0.21608584007481113, 0.37898688402492553, 0.0988651582156308, 0.17854332021670416, 0.14722333755344152, 0.15517086343606934, 0.1838482660241425, 0.12470436544390395, 0.10317208609194495, 0.20210134360240772, 0.14395169826457277, 0.20231199479894713, 0.1450427740928717, 0.11127472826046869, 0.05733490448619705, 0.19640326732769608, 0.11967296784860082, 0.13997316331369802, 0.08979250676929951, 0.14546990976668894, 0.1711920357774943], [0.09111602324992418, 0.049583409490878694, 0.003798828529397724, 0.04073552860063501, 0.039614369816263206, 0.05655741202645004, 0.013506277846317971, 0.06731913221301511, 0.07659138427698053, 0.04128579770622309, 0.0923225401493255, 0.02394187329628039, 0.088897780951811, 0.046746420121053234, 0.052826205210294574, 0.06330369025818072, 0.08655742567498237, 0.24632711109006777, 15.331994891166687, 96.57959997653961, 100.17374351620674, 74.4846823811531, 51.625428199768066, 42.70481027662754, 34.306782111525536, 58.01844835281372, 117.27003693580627, 106.16610556840897, 65.10935425758362, 107.45914578437805, 109.77283403277397, 81.08977675437927, 10.777032058686018, 0.2881052903831005, 0.21117467782460153, 0.17155067122075707, 0.18043254618532956, 0.37632560182828456, 0.22654044470982626, 0.09651099899201654, 3.251636568456888, 1.528349476866424, 0.9665518195834011, 63.540813624858856, 104.87069427967072, 98.05519759654999, 105.05944535136223, 98.33237752318382, 105.85038810968399, 100.0978235900402, 101.24720111489296, 102.5262200832367, 105.32951205968857, 99.71491053700447, 97.46710315346718, 93.07572439312935, 91.04661047458649, 79.61316838860512, 72.4250940978527, 70.37909388542175, 67.78738975524902, 64.16755199432373, 73.59103873372078, 73.0986687541008, 68.6094756424427, 67.8796412050724, 72.59717926383018, 91.62992477416992, 89.98693853616714, 92.9919920861721, 93.067706823349, 84.16023999452591, 80.51018625497818, 69.24133613705635, 67.7130277454853, 66.391671448946, 73.86233657598495, 82.28533700108528, 85.03217920660973, 90.99507763981819, 89.94474560022354, 86.95707231760025, 85.29171288013458, 84.1195897758007, 80.5445896089077, 72.16855466365814, 78.51020157337189, 88.99620249867439, 79.11701381206512, 70.1176755130291, 62.76845946907997, 75.22337034344673, 80.4356038570404, 76.30096971988678, 72.7150109410286, 64.13267746567726, 65.2672053873539, 63.4181410074234, 67.77415126562119, 71.60640522837639, 68.13592985272408, 69.22883480787277, 66.2098740041256, 65.21100640296936, 67.1257996559143, 71.35502591729164, 80.69286525249481, 86.46110773086548, 90.07860481739044, 85.01275464892387, 85.79086929559708, 86.84433996677399, 88.0681174993515, 87.51826420426369, 84.99791264533997, 77.12088972330093, 72.2878910601139, 69.8322956264019, 65.73410913348198, 70.45878320932388, 67.67016604542732, 74.21406090259552, 75.20460695028305, 78.96648108959198, 81.31011173129082, 81.78647696971893, 76.73791587352753, 84.48774442076683, 85.0398775935173, 85.91760009527206, 51.470962688326836, 0.5083394539542496, 2.600665711797774, 2.4256604025140405, 0.14002134354086593, 0.035978358282591216, 0.0682181550655514, 0.1178105927829165, 0.05172974138986319, 0.032004970125854015, 0.08085235094767995, 4.2093162797391415, 44.1137632727623, 88.56658235192299, 93.35383906960487, 85.13847470283508, 105.79477429389954, 38.118228390812874, 15.862834006547928, 31.547275185585022, 58.641113340854645, 68.66230800747871, 75.28338432312012, 35.075898841023445, 1.1712617380544543, 0.07327647777856328, 0.08362170468899421, 0.017708148225210607, 0.049706580030033365, 0.09880920028081164, 0.03350088751176372, 0.01916349425300723, 0.028891964902868494, 0.04148692714807112, 0.030457714674412273, 0.021336088902899064, 0.03054286313272314, 0.02708089079533238, 0.01978552718355786, 0.05500839768501464, 0.05295811082760338, 0.005587786172327469, 0.06293543658102863, 0.052749801106983796, 0.028207055365783162, 0.045674150314880535, 0.16460108163300902, 0.049770809200708754, 0.02426943501632195, 0.022534345698659308, 0.015345823521784041, 0.04507024248596281, 0.034824103422579356, 0.03435286933381576, 0.012057515596097801, 0.034118551047868095, 0.051054750656476244, 0.08746325402171351, 0.07893211804912426, 0.03836278599919751, 0.02363185594731476, 0.2261386311147362, 0.11856352386530489, 0.5019896978046745, 21.908984072506428, 111.38393238186836, 106.12539455294609, 90.78703120350838, 76.68911889195442, 74.04718145728111, 43.54878678917885, 31.376812532544136, 57.945306077599525, 90.54661050438881, 77.0420591533184, 117.85106375813484, 117.77202799916267, 93.90263602137566, 13.83284518495202, 0.44127361674327403, 0.021662095823558047, 0.16597562818787992, 0.2089015833917074, 0.29790451924782246, 0.12980575498659164, 1.6594237997196615, 1.0604486404918134, 0.9920963051263243, 2.448916817083955, 75.99726721644402, 111.95151552557945, 101.9775827229023, 109.75407063961029, 100.69375321269035, 109.82473164796829, 106.67544543743134, 104.48723405599594, 103.79956975579262, 108.201884329319, 102.57814809679985, 102.55035638809204, 97.63266786932945, 93.82053002715111, 84.19895991683006, 76.59799218177795, 73.40037256479263, 71.10341101884842, 68.16595584154129, 76.34111076593399, 73.96889045834541, 70.49402251839638, 71.01552933454514, 75.15198737382889, 95.45923009514809, 92.80494332313538, 95.66330194473267, 96.95178240537643, 89.02331784367561, 83.69850397109985, 70.61879262328148, 68.84114921092987, 67.68125385046005, 75.49173474311829, 84.85690981149673, 87.24857747554779, 92.593674659729, 93.22401523590088, 89.12386044859886, 88.03197383880615, 91.07033640146255, 84.0147989988327, 77.27351993322372, 84.34481129050255, 90.86110442876816, 81.00335419178009, 74.10726383328438, 69.88686829805374, 77.84016072750092, 86.4895910024643, 82.72461622953415, 76.70125544071198, 68.14454779028893, 68.80878254771233, 66.14912286400795, 70.86072564125061, 72.5490814447403, 71.09963402152061, 73.23959559202194, 68.97231817245483, 68.06759431958199, 70.17712712287903, 75.24149537086487, 85.09426027536392, 88.13126251101494, 91.59501984715462, 87.32703566551208, 89.17901828885078, 87.98816218972206, 88.12722712755203, 90.1116706430912, 88.18699792027473, 81.43316432833672, 73.37046816945076, 73.96651178598404, 70.27286678552628, 73.78089934587479, 71.25962823629379, 77.985670119524, 79.14781495928764, 82.21459239721298, 83.96139666438103, 87.31258884072304, 83.65144729614258, 87.8255233168602, 91.92250907421112, 88.15302774310112, 63.55528324842453, 1.2078981846570969, 2.1079114777967334, 4.973591594025493, 0.10822234908118844, 0.12305775497225113, 0.07757594707072712, 0.18665497947949916, 0.08207035629311576, 0.022391999918909278, 0.09501557884505019, 4.356749318540096, 51.00717097520828, 92.23107531666756, 103.65260124206543, 79.64688017964363, 51.58290468156338, 33.847690746188164, 28.507170416414738, 45.000229105353355, 77.91838333010674, 76.11801713705063, 87.73802921175957, 46.92592017352581, 1.2245349981822073, 0.05124468108988367, 0.07571829948574305, 0.022692653219564818, 0.043127381504746154, 0.010816526864800835, 0.028762970359821338, 0.08590354904299602, 0.01066205810275278, 0.033994738550973125, 0.11329771892633289, 0.0535504448635038, 0.019385142222745344, 0.11498623105580918, 0.03442185196036007, 0.06030575874319766, 0.10983142914483324, 0.03640154202003032, 0.02053553605946945, 0.06800724411732517, 0.006599862699658843, 0.030249544106482062, 0.38531775993760675, 0.16076201107352972, 0.1314413148793392, 0.1529003368341364, 0.0811494400841184, 0.15491209138417616, 0.10595057567115873, 0.2057466097176075, 0.21865154849365354, 0.1395393186248839, 0.16318360925652087, 0.1657313428586349, 0.14472881593974307, 0.13955399830592796, 0.16396679769968614, 0.2464889586553909, 0.28630225744564086, 0.6590974924620241, 33.46901446580887, 129.6305152773857, 122.00388371944427, 99.04828950762749, 75.90182393789291, 65.82835927605629, 46.26747250556946, 78.63271459937096, 161.13880455493927, 140.04315733909607, 85.25847226381302, 138.3862030506134, 128.80802661180496, 111.2806387245655, 25.046091936528683, 0.7290740625467151, 0.3198636299930513, 0.5451136431656778, 0.43596927949693054, 0.9734415030106902, 1.2335354089736938, 1.8822700856253505, 9.875715672969818, 7.312091561034322, 2.079874207265675, 76.51919960975647, 112.28879302740097, 104.8960693180561, 116.06287971138954, 108.4075976908207, 113.22387725114822, 110.69939151406288, 106.94991990923882, 108.54089453816414, 110.94893172383308, 106.22652232646942, 106.32214039564133, 102.04250603914261, 97.44932010769844, 89.97265130281448, 80.35369545221329, 78.12183201313019, 74.29481416940689, 71.67893573641777, 81.05339750647545, 79.13178741931915, 74.79147031903267, 73.88230830430984, 79.32057648897171, 98.59064966440201, 96.52012556791306, 98.68662491440773, 100.89866861701012, 94.14155200123787, 87.5254762172699, 74.47843551635742, 73.3088506758213, 72.83091992139816, 81.67795479297638, 90.12721940875053, 93.47205832600594, 98.99717465043068, 93.56408938765526, 97.06735700368881, 95.85396811366081, 93.24301421642303, 89.73277017474174, 80.78759416937828, 88.38320419192314, 97.00048819184303, 87.18973383307457, 83.85695546865463, 76.78729802370071, 83.54550138115883, 91.88764214515686, 85.12152001261711, 82.90545612573624, 71.29906252026558, 73.34770739078522, 70.91236487030983, 75.6083656847477, 78.22806671261787, 74.68076705932617, 76.9063076376915, 71.52282491326332, 72.4584411084652, 74.0046389400959, 80.26351869106293, 89.77480351924896, 94.30121183395386, 95.92141449451447, 91.49875581264496, 92.83877670764923, 91.58795222640038, 93.30643281340599, 94.9342730641365, 91.59769490361214, 82.58852273225784, 77.49871864914894, 77.24736973643303, 72.68226429820061, 77.3754532635212, 76.33497029542923, 83.79430443048477, 83.26598078012466, 88.19306999444962, 88.20389941334724, 93.56903672218323, 86.2809593975544, 94.12729516625404, 97.12168648838997, 92.87663787603378, 70.56080013513565, 0.9778327611275017, 9.117913786321878, 5.126678254455328, 0.18822134152287617, 0.5130476981867105, 0.2174476216896437, 0.41337895730976015, 0.3315105097135529, 0.19520122557878494, 0.24490229145158082, 9.64494550600648, 65.53810805082321, 102.58604407310486, 109.93497133255005, 109.94013905525208, 143.2325541973114, 46.94575510919094, 23.339195027947426, 49.54035088419914, 80.92046543955803, 90.5014081299305, 95.25633618235588, 66.72671467065811, 2.303465371951461, 0.2090090315323323, 0.1483931700931862, 0.05426206800621003, 0.20922936033457518, 0.2087366781779565, 0.12482224818086252, 0.14562331169145182, 0.13524489593692124, 0.16471939481562003, 0.16497732081916183, 0.1545201483531855, 0.08287000557174906, 0.11916461895452812, 0.15157588524743915, 0.2360955366748385, 0.18866489350330085, 0.31634718587156385, 0.1401885345694609, 0.13381635071709752, 0.04783981516084168, 0.07973651707288809], [0.02927955152699724, 0.021422832978714723, 0.06495467197964899, 0.022751351534679998, 0.01906886671349639, 0.03609227052947972, 0.02500905939086806, 0.038263868846115656, 0.053642660423065536, 0.03810805494140368, 0.03129002587229479, 0.042761832955875434, 0.022299641495919786, 0.09671488180174492, 0.010682889260351658, 0.03692024758493062, 0.049755732470657676, 0.18407711468171328, 38.60690876841545, 105.51646202802658, 83.10974836349487, 85.36522373557091, 34.502008035779, 39.73956719040871, 81.28808811306953, 107.30544403195381, 76.98338270187378, 62.785243168473244, 118.68512660264969, 114.16273847222328, 81.26129195094109, 23.669684194028378, 0.2595841098809615, 0.04580805230943952, 0.045644646233995445, 0.26185077731497586, 0.1278075372101739, 0.7130490161944181, 0.38509250327479094, 1.8780340254306793, 1.2571583851240575, 2.62748870998621, 66.2403255701065, 111.58981293439865, 111.34849548339844, 100.87736696004868, 98.73233646154404, 95.14003962278366, 100.35426422953606, 102.71450757980347, 103.48534181714058, 98.70796456933022, 96.46479293704033, 98.11858579516411, 99.72345247864723, 90.72485893964767, 82.17342540621758, 67.84022971987724, 67.57679745554924, 68.40583696961403, 68.68376925587654, 71.55645310878754, 73.73032405972481, 71.89064517617226, 70.18537268042564, 66.85941874980927, 74.04421761631966, 88.98376196622849, 90.82157894968987, 88.17724004387856, 90.95706447958946, 79.51010271906853, 77.23389565944672, 65.86614444851875, 66.49187207221985, 61.161806881427765, 65.75018987059593, 69.08112153410912, 81.11542537808418, 77.76143655180931, 95.52224591374397, 65.7264943420887, 73.88918593525887, 91.03572025895119, 73.85753363370895, 73.56589928269386, 75.38845628499985, 86.28613471984863, 77.88583427667618, 71.56589180231094, 71.22178986668587, 67.4768628180027, 77.94336318969727, 72.94195756316185, 74.77552637457848, 67.49610498547554, 65.19239500164986, 65.06102845072746, 62.880713045597076, 62.096803709864616, 65.93679785728455, 63.889513313770294, 62.98410549759865, 62.05126315355301, 62.011703476309776, 62.268075719475746, 66.9343051314354, 73.45053747296333, 76.47855699062347, 81.27437844872475, 82.93239668011665, 83.30198764801025, 83.02880510687828, 86.91693127155304, 84.43083107471466, 85.03594860434532, 78.5446049273014, 73.51579517126083, 71.9673402607441, 67.55178719758987, 70.01986116170883, 69.33412715792656, 75.42850613594055, 74.94767993688583, 82.16083288192749, 75.83164930343628, 83.62190768122673, 75.74577391147614, 83.66106078028679, 82.68825218081474, 83.54244634509087, 18.01976926624775, 0.7019365718588233, 4.792325170710683, 1.1856015748344362, 0.03742656670510769, 0.20614198147086427, 0.11575457654544152, 0.08224364777561277, 0.1212494082574267, 0.08224197794334032, 0.19082850631093606, 1.3257912523113191, 37.190728560090065, 83.25202032923698, 87.79925912618637, 76.7809371650219, 90.10842561721802, 42.993849366903305, 18.4952624514699, 35.52754260599613, 60.25993287563324, 73.80034670233727, 63.790589421987534, 20.56730456650257, 0.533305776771158, 0.021425716222438496, 0.08469467953545973, 0.010258562615490519, 0.05386568693211302, 0.012122529587941244, 0.031443691259482875, 0.05718290893128142, 0.05422510905191302, 0.05443679925519973, 0.022196308564161882, 0.01598024846316548, 0.0573533728311304, 0.01389793329508393, 0.10104716144269332, 0.01430541968147736, 0.0228826374586788, 0.043923386838287115, 0.09275658521801233, 0.01683140464592725, 0.06769516359781846, 0.04008508811239153, 0.03653451261925511, 0.0641188133158721, 0.012273762586119119, 0.02029031191341346, 0.029603769871755503, 0.027012320060748607, 0.06527469347929582, 0.04810140737390611, 0.0535318317997735, 0.012441319122444838, 0.026446204246894922, 0.035193715229979716, 0.02533737068006303, 0.03665117452328559, 0.024238595069618896, 0.02381224050623132, 0.13069012784399092, 50.7525048404932, 114.84067529439926, 93.89938339591026, 95.05022764205933, 55.993662402033806, 52.06729508936405, 37.9520633071661, 55.762380212545395, 73.57274651527405, 71.00184246897697, 123.22073802351952, 123.38357448577881, 92.86851391196251, 29.898697547614574, 0.33809914835728705, 0.04518989153439179, 0.13795711915008724, 0.11554575103218667, 0.29420933627989143, 0.653578822966665, 0.6590688158757985, 1.2560264021158218, 1.290746326558292, 5.2005980629473925, 79.95268777012825, 117.62692898511887, 114.67899397015572, 108.8090917468071, 100.40863931179047, 99.71986547112465, 103.6743588745594, 105.04945188760757, 106.5283553302288, 101.9160944223404, 99.4176296889782, 103.11550006270409, 101.68556839227676, 94.84830647706985, 86.11192926764488, 71.43202498555183, 71.02444365620613, 71.03969603776932, 72.26701498031616, 74.42403763532639, 76.33376196026802, 74.36713188886642, 72.9793931543827, 70.3299169242382, 77.74037048220634, 90.8797462284565, 92.86459252238274, 91.78175702691078, 92.64103531837463, 83.59533190727234, 79.49950888752937, 70.84001675248146, 69.07779291272163, 64.5385716855526, 66.93882688879967, 72.38308355212212, 82.38374412059784, 82.34108000993729, 96.9791029393673, 73.74150305986404, 76.8738953769207, 92.3407830297947, 79.10185262560844, 79.11495432257652, 80.07513999938965, 91.04637488722801, 83.18416357040405, 77.92969152331352, 74.60426956415176, 70.56213766336441, 83.7587459385395, 79.87645626068115, 78.79066452383995, 71.60738557577133, 66.81038618087769, 67.4521641433239, 66.8978650867939, 65.86441934108734, 69.62958410382271, 67.59704276919365, 66.82404264807701, 65.90356484055519, 63.70124861598015, 65.87095499038696, 70.80970957875252, 74.45580393075943, 78.69102627038956, 79.53119918704033, 85.02191975712776, 87.88898751139641, 86.77959904074669, 91.05421006679535, 87.41572290658951, 86.16999015212059, 81.95060536265373, 77.33778208494186, 75.3560896217823, 71.27451583743095, 74.19529750943184, 73.94441977143288, 79.6886095404625, 80.02340957522392, 83.39100167155266, 78.30158516764641, 86.63006946444511, 83.69257628917694, 86.7978684604168, 89.28963795304298, 87.48410403728485, 24.569392316043377, 0.7516882522031665, 2.642115312628448, 0.3487282764399424, 0.06996713738772087, 0.09097374611883424, 0.042818822475965135, 0.07083075979608111, 0.06406267726561055, 0.1253057870781049, 0.2864400594262406, 1.368272379040718, 42.865925431251526, 88.8661202788353, 99.15970712900162, 77.26896777749062, 38.19992780685425, 36.949791088700294, 38.72989296913147, 43.76811482012272, 71.92405298352242, 83.31748321652412, 76.16144880652428, 26.03289518505335, 0.3729390335502103, 0.041944312761188485, 0.025880403845803812, 0.02285735434270464, 0.02418287276668707, 0.049261710737482645, 0.04107766610104591, 0.03741608757991344, 0.07021681813057512, 0.040223316827905364, 0.05156325911229942, 0.014419389444810804, 0.06560847439686768, 0.02031565996730933, 0.012599728688655887, 0.04637058540538419, 0.05325174526660703, 0.08238968017394654, 0.033776150085031986, 0.14667573646875098, 0.024152804653567728, 0.11490771183161996, 0.18536435498390347, 0.09313800459494814, 0.09031440727994777, 0.11186637580976821, 0.1243085484020412, 0.14114036865066737, 0.11141032606246881, 0.11739522757125087, 0.081156698288396, 0.06328171526547521, 0.15345489926403388, 0.1084183354396373, 0.1648137960000895, 0.16103976726299152, 0.14995999226812273, 0.21368381974752992, 0.2810821688035503, 71.2219874560833, 133.8359472155571, 105.09906962513924, 107.14149802923203, 47.99122340977192, 55.829617604613304, 107.96782448887825, 147.62796074151993, 105.18505901098251, 83.46329659223557, 145.081367790699, 129.63682293891907, 106.60419926047325, 49.635246992111206, 1.5719839604571462, 0.1360980689059943, 0.30438676360063255, 0.38185276149306446, 0.4270269343396649, 1.7302758665755391, 1.8880350887775421, 4.835762539878488, 5.134172402322292, 3.575288001447916, 79.23252001404762, 121.06572926044464, 118.41565266251564, 114.83502879738808, 107.53890350461006, 104.20159578323364, 107.73124158382416, 110.33346354961395, 111.31694197654724, 107.84718096256256, 107.12412536144257, 108.0386146903038, 105.66869705915451, 97.94200167059898, 91.59986078739166, 76.67035549879074, 75.67044675350189, 74.57503393292427, 76.08201786875725, 78.54666441679001, 79.75693747401237, 77.91501671075821, 78.73392596840858, 72.77456134557724, 80.64637094736099, 94.53703477978706, 99.56617891788483, 97.84758433699608, 95.77122375369072, 90.635616928339, 83.72077077627182, 75.17439097166061, 73.2543919980526, 68.3460433781147, 70.73724746704102, 79.43332403898239, 90.32367646694183, 87.95909374952316, 100.8585275709629, 80.14869645237923, 84.50019255280495, 98.33628371357918, 85.15943437814713, 84.11876901984215, 83.55615600943565, 94.50295820832253, 86.40940770506859, 83.2568308711052, 77.6561290025711, 74.06841471791267, 89.49646085500717, 83.98481860756874, 82.511136084795, 77.24994599819183, 70.89401185512543, 70.6121201813221, 70.45247554779053, 67.95400321483612, 73.91173392534256, 70.72976186871529, 69.98039647936821, 68.85713115334511, 66.77076190710068, 69.55027475953102, 75.41348174214363, 79.69311609864235, 85.29400795698166, 88.12705233693123, 90.97216486930847, 92.9264684021473, 90.22488176822662, 96.07346713542938, 90.79773902893066, 91.70462876558304, 85.20200729370117, 80.30990660190582, 78.87022465467453, 73.34766939282417, 79.5763635635376, 77.19491735100746, 84.0990936756134, 82.52892673015594, 90.9119077026844, 82.26172506809235, 93.35701569914818, 87.08835527300835, 93.11072051525116, 92.26037174463272, 92.61288642883301, 26.99461217969656, 1.7373009771108627, 12.627069186419249, 1.0662687406875193, 0.17615753808058798, 0.4975487751653418, 0.2779829007340595, 0.22697452688589692, 0.3875921753933653, 0.1923108720802702, 0.4347729671280831, 3.5380450123921037, 56.677652299404144, 95.99000841379166, 103.32141101360321, 99.81215491890907, 122.62850940227509, 56.187322810292244, 29.060411229729652, 49.10232938826084, 87.41343542933464, 95.64081475138664, 91.75657197833061, 41.52933195233345, 0.8912054251413792, 0.13616296229884028, 0.1789169173571281, 0.16331450926372781, 0.12764597166096792, 0.2901959797600284, 0.09786678405362181, 0.19212959508877248, 0.13102323340717703, 0.19569830124964938, 0.1503886716091074, 0.07288922512088902, 0.09642770033678971, 0.08776092203333974, 0.15652059257263318, 0.09201845256029628, 0.19482589181279764, 0.17800011264625937, 0.1150314426922705, 0.2112534939078614, 0.13681541400728747], [0.04676518903579563, 0.03894289315212518, 0.0300308721489273, 0.027058832311013248, 0.008152638802130241, 0.0750717255868949, 0.045274748699739575, 0.03555443610821385, 0.08751627305173315, 0.0027379323682907852, 0.014067679167055758, 0.044320194647298194, 0.084752604161622, 0.06431332280044444, 0.040926516594481654, 0.11582401930354536, 0.16926415875786915, 5.248623685911298, 87.27391451597214, 93.33819910883904, 72.38352432847023, 44.26680766046047, 35.235885456204414, 82.26928666234016, 133.96650820970535, 89.02130395174026, 103.28355744481087, 127.2890505194664, 111.5409703552723, 80.76125398278236, 18.439031168818474, 1.118275006301701, 0.1751760032493621, 0.22608994622714818, 0.1125137809140142, 0.13919088029069826, 0.12522805453045294, 0.16299217968480662, 0.1925112519529648, 2.231330517679453, 3.2812571665272117, 83.468297123909, 113.50595891475677, 98.37640956044197, 99.54277977347374, 92.03267276287079, 89.95056688785553, 86.56236469745636, 94.24937501549721, 95.102429240942, 90.45402467250824, 89.21550393104553, 89.61841151118279, 82.54494667053223, 79.29782330989838, 75.16135767102242, 70.14270856976509, 68.6647854745388, 68.75271275639534, 71.56171962618828, 73.41928035020828, 75.72944238781929, 74.04592752456665, 73.22311967611313, 68.40128481388092, 66.05452314019203, 68.87575775384903, 85.57335376739502, 86.36363536119461, 85.1516143977642, 87.68819868564606, 72.99304962158203, 70.06550431251526, 65.64956367015839, 63.46228323876858, 61.823469176888466, 66.12162753939629, 65.79296037554741, 71.34791269898415, 80.14462307095528, 88.8529197871685, 79.01922225952148, 68.69114845991135, 88.30815821886063, 71.07982188463211, 74.09122109413147, 77.52027109265327, 82.95673057436943, 86.36178106069565, 92.33327463269234, 79.4769760966301, 63.664390593767166, 72.8384131193161, 76.52866870164871, 75.5321341753006, 74.20269951224327, 64.2478720843792, 63.062787875533104, 59.42031852900982, 66.51684433221817, 62.56909556686878, 63.492852598428726, 63.02177667617798, 66.25033423304558, 64.45972591638565, 66.23227000236511, 61.82265982031822, 60.718708857893944, 64.08200338482857, 66.97089716792107, 70.06635546684265, 72.95545443892479, 75.20721361041069, 87.54727944731712, 83.99727433919907, 84.77608814835548, 78.86333182454109, 76.2576824426651, 70.18673300743103, 71.17685347795486, 65.4808983206749, 69.6203126013279, 67.68313854932785, 74.17140439152718, 73.40180888772011, 78.88748332858086, 73.25138255953789, 83.74378234148026, 80.45581117272377, 82.16434389352798, 84.53115329146385, 50.32684788107872, 1.0073067108169198, 0.82420599530451, 0.6241175788454711, 0.19584043737268075, 0.09220301726600155, 0.09044017904670909, 0.14578803878976032, 0.05218449980020523, 0.04441430268343538, 0.21197708789259195, 0.30090707063209265, 1.3645471539348364, 29.907271787524223, 77.62947723269463, 90.5002073943615, 98.84838983416557, 70.9085650742054, 23.84263001382351, 33.16399343311787, 47.92956791818142, 66.02905690670013, 69.55023676156998, 78.11398163437843, 13.046403285115957, 0.5358315131161362, 0.046941623513703234, 0.0387860402406659, 0.02642207888129633, 0.09843003703281283, 0.0165469765488524, 0.05364484604797326, 0.05849682573170867, 0.025533854277455248, 0.056199054888566025, 0.054062808776507154, 0.0366601582209114, 0.045315934185055085, 0.009526504436507821, 0.05022187171562109, 0.09538114594761282, 0.05236670818703715, 0.0348341187054757, 0.09420952483196743, 0.0612066963367397, 0.018178161481046118, 0.004767039490616298, 0.044928262213943526, 0.04152779350988567, 0.023969406975083984, 0.09770142612978816, 0.026525493449298665, 0.024406665543210693, 0.0431535310781328, 0.025518566035316326, 0.049638792261248454, 0.0990860139427241, 0.08480298856738955, 0.07138610890251584, 0.15562976303044707, 0.1613341030315496, 0.32226248877123, 6.898973453789949, 103.77594262361526, 103.1977504491806, 87.57918253540993, 58.68269830942154, 36.14793911576271, 82.75119200348854, 114.39020186662674, 88.97769749164581, 110.34449055790901, 128.27882140874863, 122.80700102448463, 89.95634257793427, 22.938820011913776, 1.4687645179219544, 0.20244017854565755, 0.15960380056640133, 0.12160543134086765, 0.20632400061003864, 0.0716927791654598, 0.2068678761133924, 0.49543297151103616, 1.5951823093928397, 5.779087096452713, 96.65622666478157, 113.49545627832413, 107.20197558403015, 103.4296216070652, 95.35800352692604, 93.25436800718307, 88.2193797826767, 94.67609971761703, 99.40509036183357, 93.07342931628227, 92.66076385974884, 92.33985587954521, 86.26779690384865, 82.45828852057457, 76.86202481389046, 74.11837443709373, 73.71124908328056, 71.75660356879234, 76.70312494039536, 77.32630670070648, 80.36832466721535, 77.91147530078888, 76.22588574886322, 72.530986815691, 68.4501425921917, 71.38134330511093, 87.24205702543259, 91.82091772556305, 88.62360209226608, 88.78744170069695, 77.55006909370422, 72.53378346562386, 69.9973663687706, 66.09991550445557, 65.714752972126, 69.69156637787819, 69.63812604546547, 75.46042442321777, 85.28686434030533, 92.24398702383041, 83.11520487070084, 75.87005764245987, 91.07617288827896, 76.04212000966072, 75.51762655377388, 82.88283213973045, 88.92137691378593, 86.60229295492172, 94.1218538582325, 80.87152406573296, 66.34951651096344, 79.5957501232624, 82.13535904884338, 80.41971310973167, 79.71491172909737, 68.73127430677414, 66.90057814121246, 64.02245298027992, 69.01059731841087, 66.92678913474083, 66.59530252218246, 64.62662056088448, 67.38483175635338, 64.38324362039566, 68.11902835965157, 63.25308546423912, 64.17851820588112, 66.69919654726982, 69.13687974214554, 70.21355956792831, 75.49193993210793, 77.1134801208973, 88.28345194458961, 87.37930566072464, 89.14262384176254, 81.53959661722183, 79.23492148518562, 75.20976707339287, 74.67347905039787, 69.43513333797455, 72.2462908923626, 72.28070944547653, 77.40960583090782, 77.59882047772408, 82.92706176638603, 78.02503600716591, 85.88629737496376, 83.65705579519272, 85.96288606524467, 89.22976836562157, 58.25989119708538, 1.350952077191323, 0.4707804584177211, 0.5870611360296607, 0.07049129402730614, 0.14739113714313135, 0.08817438734695315, 0.2734224032610655, 0.09453713850234635, 0.23556763218948618, 0.041023270387086086, 0.18146312213502824, 0.905172941274941, 37.344825491309166, 83.8684156537056, 98.68742287158966, 85.52400201559067, 42.51121066510677, 27.790876552462578, 46.722178906202316, 64.04297947883606, 73.71083110570908, 79.6065491437912, 90.61300054192543, 17.045248858630657, 0.6283415271900594, 0.03855080169159919, 0.08807883583358489, 0.051819737927871756, 0.06064731736842077, 0.05705438008590136, 0.03573662965209223, 0.04716050883871503, 0.01173218310213997, 0.06504395976662636, 0.03668572520837188, 0.04074527299962938, 0.08763291640207171, 0.043416444314061664, 0.07689483361900784, 0.039829722518334165, 0.04028693372674752, 0.012872348288510693, 0.0678242082358338, 0.060757626488339156, 0.09783352099475451, 0.13244685076642781, 0.15282143169315532, 0.10163647864828818, 0.1226249492901843, 0.1674091606400907, 0.17057790857506916, 0.06508457008749247, 0.1851478111348115, 0.13077523733954877, 0.13054925337200984, 0.11834018936497159, 0.18102369649568573, 0.28493919933680445, 0.3775674820644781, 0.3034298383863643, 0.7429678982589394, 12.561214920133352, 127.37158209085464, 114.87905323505402, 99.14779856801033, 65.74118435382843, 55.08950471878052, 102.80873492360115, 156.15795582532883, 117.22988829016685, 127.52886325120926, 149.51848089694977, 132.5289237499237, 109.29022952914238, 38.07628624141216, 4.380701808258891, 0.40584084461443126, 0.5784744280390441, 0.32096049457322806, 0.5568352423142642, 0.23885369882918894, 0.310764602618292, 1.2652958859689534, 5.768514163792133, 4.622356491163373, 95.62550157308578, 117.76206493377686, 108.51457715034485, 111.2649455666542, 99.60022509098053, 98.67258846759796, 96.08821794390678, 102.20595806837082, 105.99794179201126, 98.28618720173836, 97.24045291543007, 98.97965759038925, 92.73432791233063, 88.15244257450104, 81.76411896944046, 78.33376944065094, 76.27850532531738, 76.82514399290085, 79.71135511994362, 80.78087612986565, 87.26068362593651, 82.97037944197655, 80.47458216547966, 75.34731969237328, 71.52817502617836, 73.53993147611618, 91.64529874920845, 94.88777115941048, 95.85941702127457, 93.17814409732819, 80.98842859268188, 76.23197302222252, 72.81710386276245, 70.27982041239738, 69.50957134366035, 73.0148908495903, 73.9716187119484, 76.83433189988136, 89.89312157034874, 97.2709272801876, 86.57925859093666, 80.18768236041069, 97.55789548158646, 81.35345980525017, 81.56982779502869, 86.44916877150536, 91.94020852446556, 84.95340183377266, 91.59419909119606, 80.09153231978416, 70.19249349832535, 85.69365531206131, 87.57282927632332, 86.10247537493706, 83.60451221466064, 71.87878221273422, 70.9875400364399, 66.16392686963081, 73.03870037198067, 70.92407584190369, 68.84504020214081, 67.96081244945526, 71.22264102101326, 67.98988088965416, 72.5974452495575, 67.60484755039215, 67.6575431227684, 69.47987213730812, 74.49688732624054, 75.27327686548233, 80.9795294702053, 82.60724052786827, 95.72972998023033, 92.01343819499016, 92.6705901324749, 84.89500656723976, 84.34303298592567, 78.25909584760666, 79.25785705447197, 72.23790094256401, 75.39311483502388, 75.81807643175125, 82.59376645088196, 81.8417564034462, 89.53874498605728, 79.73470106720924, 92.87337765097618, 88.22016254067421, 92.16047510504723, 92.93823257088661, 66.18419498205185, 1.8015569541603327, 4.690685849636793, 3.306356482207775, 0.339673362323083, 0.20124392554862425, 0.3255909320432693, 0.7776079082395881, 0.37395093706436455, 0.26916710659861565, 0.3562799852807075, 0.36480423412285745, 2.471035667695105, 50.6670930236578, 94.39221695065498, 106.52919888496399, 128.22310119867325, 95.04715740680695, 29.597854390740395, 48.011723309755325, 66.23966440558434, 89.11685362458229, 89.44998934864998, 109.36367198824883, 29.55664750188589, 0.8750038663856685, 0.20240731624653563, 0.17105138394981623, 0.12267203113879077, 0.15865931374719366, 0.17632269562454894, 0.21149274747585878, 0.11044527433114126, 0.1516638891189359, 0.14271153981098905, 0.17684706748696044, 0.08928279974497855, 0.21426594554213807, 0.08538218287867494, 0.2865991758881137, 0.21220851922407746, 0.18489686131943017, 0.05615002861304674, 0.21692733163945377, 0.1408033148618415], [0.11018233140930533, 0.01931357506691711, 0.029285366254043765, 0.03586568542232271, 0.03261113779444713, 0.05114351894007996, 0.027542213501874357, 0.09741015543113463, 0.0570812829391798, 0.15375045215478167, 0.019700208031281363, 0.03930800754460506, 0.04539211564406287, 0.049485282725072466, 0.06645526489592157, 0.09853334398940206, 0.1330141632934101, 36.45799107849598, 89.67223182320595, 87.48580634593964, 52.10562743246555, 64.47737216949463, 87.7524608373642, 39.856437519192696, 44.474158734083176, 83.30975443124771, 111.78052470088005, 105.16814231872559, 87.63206049799919, 13.602403700351715, 0.22812956100096926, 0.37697165622375906, 0.1359277163282968, 0.12133802811149508, 0.10253559055854566, 0.2940693375421688, 0.23398516554152593, 0.25359349383506924, 0.2367730878177099, 2.1003904938697815, 74.45722505450249, 113.38793724775314, 93.1732727587223, 105.45712441205978, 92.54620760679245, 91.07222869992256, 75.26158109307289, 76.79109022021294, 74.63975206017494, 76.5498335659504, 73.92592996358871, 74.25493150949478, 68.81873041391373, 70.27548864483833, 69.07327875494957, 69.87882792949677, 69.46037918329239, 74.72824171185493, 72.65555173158646, 77.95014962553978, 77.55234137177467, 81.84008449316025, 74.61362466216087, 72.31071263551712, 67.50603765249252, 69.64917585253716, 67.34367996454239, 79.39927786588669, 88.81863802671432, 85.08093819022179, 81.26493215560913, 73.32031086087227, 65.73527947068214, 66.28700226545334, 67.58205637335777, 68.87390345335007, 71.2792655825615, 77.14248016476631, 76.83593541383743, 81.27826943993568, 84.33604896068573, 81.68280333280563, 77.69820034503937, 82.89911806583405, 73.49761694669724, 75.09804546833038, 75.80468595027924, 78.47958281636238, 89.81909394264221, 104.039656072855, 78.53294715285301, 55.014169961214066, 63.85328605771065, 78.20693984627724, 75.56571677327156, 75.95201924443245, 70.54852679371834, 66.99804291129112, 69.09773424267769, 65.02631351351738, 64.97826889157295, 61.686144545674324, 64.91737335920334, 65.23733898997307, 63.440586403012276, 65.59157118201256, 70.0742894411087, 65.71365103125572, 65.1674835383892, 64.44657862186432, 63.90525206923485, 63.26576538383961, 65.6755542755127, 74.90685492753983, 78.61917212605476, 83.48191559314728, 79.82705891132355, 77.22542211413383, 70.87372854351997, 68.70537489652634, 66.87476992607117, 63.321759179234505, 66.14673659205437, 68.88804629445076, 69.85305771231651, 71.10997706651688, 73.62794995307922, 79.25860181450844, 79.42605882883072, 86.75281807780266, 81.23410820960999, 76.56470596790314, 4.404667122289538, 0.6519479979760945, 0.4405822022818029, 0.20016920665511861, 0.19567683833884075, 0.199995870643761, 0.08577475673519075, 0.1340226677712053, 0.12262195101357065, 0.16959600267000496, 0.053012502830824815, 0.5947187345009297, 2.0686707459390163, 33.404775112867355, 56.91202372312546, 43.881405740976334, 80.55579900741577, 65.50523981451988, 18.633347041904926, 25.637526400387287, 55.80853633582592, 58.77976790070534, 73.82093399763107, 48.848404213786125, 2.5219303742051125, 0.021078181453049183, 0.00917398057936225, 0.054996545586618595, 0.019230907237215433, 0.034711972330114804, 0.022477580678241793, 0.017525277471577283, 0.0427066876727622, 0.04590711418131832, 0.04587687908497173, 0.024544230036553927, 0.06576563901035115, 0.009559350037307013, 0.05123253955389373, 0.015065724001033232, 0.0451547211559955, 0.019000720858457498, 0.012179749173810706, 0.030812375916866586, 0.07430703146383166, 0.04286896568373777, 0.07651038627955131, 0.036204498101142235, 0.04084195999894291, 0.07242139748996124, 0.0026306651261620573, 0.012325182287895586, 0.10852313411305659, 0.07110317252227105, 0.008811298575892579, 0.031184807885438204, 0.04117865384614561, 0.10359071675338782, 0.07125509015168063, 0.03168460723827593, 0.31788568769115955, 44.408403262495995, 106.72801181674004, 97.48913437128067, 68.08597013354301, 61.97152443230152, 75.14308825135231, 38.05544055998325, 51.66126407682896, 90.0322625041008, 128.30190896987915, 115.65347447991371, 100.16332447528839, 16.2352729216218, 0.3248414519475773, 0.9960197727195919, 0.19613576761912555, 0.04298078507417813, 0.14358800137415528, 0.10324322094675153, 0.23183703393442556, 0.3464426990831271, 0.7293538225349039, 3.463118257932365, 86.90166369080544, 114.0310451388359, 98.51786836981773, 107.49591261148453, 97.15070933103561, 92.69272774457932, 77.92711526155472, 80.69283485412598, 78.69996339082718, 79.19868662953377, 75.99326223134995, 77.02901065349579, 73.53866994380951, 74.9090664088726, 71.85564145445824, 71.9146902859211, 72.74332702159882, 78.47648978233337, 75.5463682115078, 81.77943974733353, 81.61319866776466, 83.70383888483047, 77.89568334817886, 73.64005610346794, 71.42938792705536, 71.77741885185242, 69.19525220990181, 80.78002497553825, 89.25496101379395, 89.13551822304726, 84.11335811018944, 78.00232842564583, 70.1504297554493, 68.11430141329765, 71.60618484020233, 70.84902226924896, 75.3059171140194, 79.73584860563278, 79.99250203371048, 87.70301789045334, 87.1130919456482, 87.08067208528519, 83.57966914772987, 86.29191040992737, 76.81727841496468, 79.91861879825592, 80.3609910607338, 81.97718873620033, 91.01684287190437, 101.25421553850174, 82.49751761555672, 61.5280806273222, 64.6877820789814, 81.39711946249008, 82.02184394001961, 79.96360078454018, 75.50429686903954, 74.37673017382622, 73.47153514623642, 70.50643265247345, 70.8032651245594, 66.16953536868095, 68.02864640951157, 67.61016726493835, 65.73982402682304, 69.41500961780548, 73.32243874669075, 69.87983107566833, 65.55222809314728, 66.19434803724289, 65.96113935112953, 68.29935908317566, 69.87353101372719, 74.03230145573616, 80.46439111232758, 82.80051335692406, 83.72818797826767, 78.46692949533463, 73.40740218758583, 72.83984944224358, 69.87540051341057, 67.34295800328255, 69.05725121498108, 71.73860013484955, 73.6305870115757, 73.46338838338852, 76.548982411623, 82.74889692664146, 81.91265299916267, 91.47745415568352, 86.59213989973068, 80.10580435395241, 6.62148954346776, 0.450121916946955, 0.2900373382726684, 0.1747734475065954, 0.20104301132960245, 0.09585416861227714, 0.11836571924504824, 0.26048056490253657, 0.021536591229960322, 0.236753984936513, 0.012216718332638266, 0.46838762587867677, 2.0523537090048194, 42.58773095905781, 65.69891542196274, 50.0150366127491, 65.0954470038414, 50.07829561829567, 28.772852160036564, 34.11897338926792, 68.48685622215271, 68.17226350307465, 83.3888053894043, 60.03296345472336, 3.1335377180948853, 0.07960919421748258, 0.07826225555618294, 0.021110284906171728, 0.10572645449428819, 0.04645784341846593, 0.021662153340002988, 0.040865593691705726, 0.15308473084587604, 0.05811017792439088, 0.015124112469493411, 0.01313718832534505, 0.007098448177202954, 0.03094807205343386, 0.03743429246242158, 0.08229426966863684, 0.013910281704738736, 0.03130229357338976, 0.02330287858058, 0.031233867557602935, 0.27439592289738357, 0.1715408600284718, 0.1698217194643803, 0.14774169801967219, 0.19030809751711786, 0.17597198631847277, 0.14332642400404438, 0.16992477409075946, 0.21389064146205783, 0.2238938570371829, 0.12470608722651377, 0.16382678411900997, 0.15586064517265186, 0.19205670134397224, 0.14137390768155456, 0.0903222369379364, 0.472612910089083, 62.17617005109787, 122.27637469768524, 109.57111045718193, 71.23641148209572, 80.01684352755547, 106.96818932890892, 53.11124347150326, 66.0749052464962, 110.11333376169205, 140.92546999454498, 125.32594665884972, 118.69523406028748, 22.027873992919922, 0.44146310188807547, 2.0603007450699806, 0.3215303155593574, 0.24228711146861315, 0.31574046530295163, 0.5729773105122149, 0.5655057833064348, 0.6547493976540864, 0.885635755257681, 3.855623658746481, 84.54582050442696, 123.35693791508675, 103.21880891919136, 114.01862740516663, 101.33056864142418, 100.56497812271118, 79.90934729576111, 83.60782563686371, 83.25278788805008, 84.03919368982315, 81.7673259973526, 83.44335526227951, 77.0807258784771, 79.80688199400902, 75.15584036707878, 77.4002355337143, 76.64259418845177, 80.25161772966385, 79.1210187971592, 85.37973895668983, 84.92242589592934, 91.14582315087318, 81.20960712432861, 79.79290634393692, 74.52836483716965, 76.52913227677345, 71.58270210027695, 84.40088868141174, 93.98718148469925, 93.75984728336334, 89.91543397307396, 83.09241369366646, 74.01581794023514, 72.3707266151905, 74.72755014896393, 75.98729655146599, 78.10582727193832, 84.77609574794769, 83.17156344652176, 92.82124444842339, 93.3159551024437, 88.53817507624626, 87.41161912679672, 91.95514172315598, 84.39129039645195, 84.7632372379303, 86.91589012742043, 89.67255100607872, 84.32219490408897, 96.05560049414635, 79.27158951759338, 66.09993070363998, 69.27428796887398, 85.33224150538445, 86.56104236841202, 85.53579658269882, 77.63552650809288, 78.02234575152397, 77.24499866366386, 72.30524852871895, 71.89564570784569, 67.58420705795288, 71.85536786913872, 71.29202529788017, 68.77048820257187, 73.52445110678673, 76.05329900979996, 73.19422602653503, 71.26331403851509, 71.2035584449768, 70.71008652448654, 71.73099294304848, 73.94767239689827, 81.7940005660057, 85.56392267346382, 89.31779444217682, 87.82716482877731, 84.10274907946587, 78.45237627625465, 75.76570004224777, 74.70916673541069, 72.13183343410492, 72.5910159945488, 75.56526079773903, 79.26352635025978, 77.46642798185349, 80.75059175491333, 88.82981702685356, 88.1939135491848, 97.99523681402206, 86.96761295199394, 88.77499356865883, 7.16383159160614, 2.0436915988102555, 0.9270223625935614, 0.32022268103901297, 0.3369260800536722, 0.692215149756521, 0.2211669838288799, 0.5793884571176022, 0.32696749723982066, 0.4363924224162474, 0.3535377199295908, 0.7336251495871693, 4.464350044727325, 57.6565595716238, 72.56235033273697, 59.08840253949165, 106.07774510979652, 85.89384377002716, 24.554048739373684, 39.48409549891949, 80.17280235886574, 80.21162867546082, 90.85889294743538, 81.23603090643883, 6.073758909478784, 0.21261972840875387, 0.19628657202702016, 0.13443340198136866, 0.2860953763592988, 0.15597875055391341, 0.0860406162973959, 0.1119671668857336, 0.2730008336948231, 0.12332364422036335, 0.14430818147957325, 0.16193433722946793, 0.19328361988300458, 0.07958719696034677, 0.09390488063218072, 0.16969953227089718, 0.10073546683997847, 0.18142657878343016, 0.11784122863900848, 0.13386463484494016], [0.04611857802956365, 0.042427202279213816, 0.012983480264665559, 0.0410209437541198, 0.05794726537715178, 0.04042425331135746, 0.027356593091099057, 0.02112924677931005, 0.08723486549570225, 0.06394568510586396, 0.07662049873033538, 0.074603393295547, 0.08179364653187804, 0.05512178671779111, 0.026775265105243307, 0.10227175705949776, 2.230657716281712, 75.02724006772041, 85.01760318875313, 71.81620717048645, 57.08603158593178, 103.16106721758842, 76.87137991189957, 79.32437628507614, 74.36503440141678, 109.44690272212029, 114.3316850066185, 94.62483286857605, 17.91784543544054, 0.3862744179787114, 0.31374925340060145, 0.14806622435571626, 0.015053608440211974, 0.10690911134588532, 0.2645728859351948, 0.2598188363481313, 0.12416964804288, 0.25022571673616767, 0.5028915556613356, 36.90858989953995, 106.20202884078026, 94.88934427499771, 101.30334690213203, 85.07765516638756, 80.03949031233788, 74.50240463018417, 78.35694059729576, 74.43248838186264, 76.33851930499077, 68.2854974269867, 68.61083596944809, 67.87791609764099, 73.96586582064629, 71.47153526544571, 73.3388614654541, 68.41184064745903, 72.8174914419651, 75.54589703679085, 81.31268799304962, 82.3967470228672, 80.65754994750023, 79.41011488437653, 73.49770054221153, 67.13871136307716, 64.88906487822533, 68.46417903900146, 65.65830320119858, 76.20304897427559, 82.48490989208221, 84.23501998186111, 76.37257307767868, 68.53320613503456, 65.28498843312263, 64.72333297133446, 69.7829894721508, 73.7102535367012, 75.31273394823074, 78.0847156047821, 78.96532595157623, 81.46451264619827, 84.55301731824875, 81.45103096961975, 81.28821730613708, 75.63879445195198, 72.6046572625637, 78.9462585747242, 72.85207718610764, 67.78983682394028, 83.25081199407578, 89.13611099123955, 64.41280603408813, 49.93439733982086, 53.56343060731888, 73.51710230112076, 79.93507191538811, 79.88869920372963, 74.67656448483467, 67.69648343324661, 77.91985765099525, 70.64154580235481, 72.64541387557983, 67.53221824765205, 64.29329484701157, 64.26398321986198, 65.43460920453072, 71.22933626174927, 78.03249880671501, 75.14162912964821, 72.11853414773941, 63.36095787584782, 61.825270280241966, 59.90421876311302, 59.92485925555229, 61.355193704366684, 62.994239553809166, 69.37859997153282, 71.1787685751915, 69.7470586001873, 65.49915254116058, 60.705778151750565, 63.93634960055351, 60.02514727413654, 59.25981894135475, 60.482669323682785, 69.87473174929619, 74.00593087077141, 73.88414740562439, 77.55413487553596, 77.73413881659508, 79.94957953691483, 87.41383820772171, 84.36960875988007, 19.41959325224161, 0.6714339461177588, 0.1446615922031924, 0.07992407263373025, 0.04098209603398573, 0.058936459172400646, 0.13289723050547764, 0.11801454980741255, 0.34957791678607464, 0.10507951694307849, 0.20054617314599454, 0.12255549168912694, 0.16952189180301502, 9.005668759346008, 48.95553566515446, 40.68179503083229, 70.64512521028519, 81.09353095293045, 38.60718995332718, 21.144111715257168, 33.420912846922874, 58.06590400636196, 67.11275115609169, 70.40307059884071, 37.18249440193176, 2.8266243869438767, 0.07596581315738149, 0.14778437151107937, 0.07287718006409705, 0.017416653026884887, 0.024977532957564108, 0.06356700425385498, 0.033576779533177614, 0.06682920342427678, 0.07488984745577909, 0.13809643511194736, 0.044531921957968734, 0.06048663497494999, 0.08023676913580857, 0.02545617924624821, 0.022396206040866673, 0.07116426611901261, 0.00821548479507328, 0.0668757435050793, 0.010847864978131838, 0.09163544498733245, 0.008861715450620977, 0.029441311889968347, 0.04392806607938837, 0.0456276139448164, 0.03095935269811889, 0.08828566496958956, 0.023926544236019254, 0.020779424339707475, 0.10712985575082712, 0.032013141171773896, 0.02840107503288891, 0.07207269940408878, 0.053714704408776015, 0.08498128954670392, 2.965876702219248, 90.40087312459946, 93.83345693349838, 86.918094009161, 60.95441780984402, 105.84211215376854, 86.2151013314724, 43.67279313504696, 69.25720408558846, 125.75762629508972, 118.09615820646286, 107.61493742465973, 22.249785885214806, 0.4725877067539841, 0.6671260460279882, 0.2594005025457591, 0.11170897370902821, 0.17214857507497072, 0.5028309370391071, 0.2757389430189505, 0.2249545938684605, 0.301393503905274, 1.7634454742074013, 47.57970169186592, 110.47085657715797, 100.08696377277374, 104.41915690898895, 88.27421844005585, 84.02280136942863, 76.74239203333855, 82.65525475144386, 78.08058902621269, 79.62418019771576, 72.83965185284615, 74.48412001132965, 71.95740759372711, 76.60654932260513, 74.25756856799126, 76.9582812488079, 72.33829155564308, 76.69633090496063, 80.66806018352509, 85.04115432500839, 86.2414339184761, 85.41209802031517, 83.31382021307945, 76.7202240228653, 68.52360025048256, 69.13500264286995, 71.5348094701767, 66.97314664721489, 78.15935879945755, 86.0259322822094, 85.94842404127121, 81.3155834376812, 73.89122262597084, 69.49215307831764, 69.30010378360748, 71.94473907351494, 75.9534327685833, 80.97456693649292, 82.73753553628922, 83.29261735081673, 86.38732329010963, 87.59882748126984, 85.72439566254616, 86.12598091363907, 80.55666536092758, 78.69334414601326, 81.85738116502762, 80.13342127203941, 74.29891794919968, 88.0279840528965, 92.03660175204277, 72.75159537792206, 60.04652872681618, 57.64370106160641, 74.28090691566467, 83.42271476984024, 84.751146286726, 81.64373382925987, 75.68236291408539, 83.14168184995651, 76.35370329022408, 76.34275987744331, 73.04317653179169, 69.76602718234062, 66.20475187897682, 67.17781886458397, 73.19696947932243, 83.04079726338387, 78.45556810498238, 74.61251512169838, 64.77200835943222, 64.70617309212685, 62.15470880270004, 63.31779979169369, 65.35389393568039, 67.44954988360405, 70.73060542345047, 72.34633192420006, 72.83734917640686, 66.77568644285202, 64.19838353991508, 66.80621400475502, 63.26539680361748, 63.76928776502609, 65.3887152671814, 71.81730151176453, 75.63891604542732, 76.69128477573395, 79.92397651076317, 81.59847065806389, 83.83494704961777, 87.84107208251953, 89.0877015888691, 22.766755744814873, 0.9036507073324174, 0.04584412439726293, 0.16226190637098625, 0.058852663278230466, 0.08405096290516667, 0.032501971581950784, 0.10540902309003286, 0.21258867694996297, 0.10257084999466315, 0.28572068084031343, 0.14090807642787695, 0.3226287238067016, 10.852073282003403, 58.6185197532177, 47.082034796476364, 71.67889013886452, 47.857831567525864, 33.63080218434334, 32.76598758995533, 45.74206329882145, 69.01049852371216, 76.21979087591171, 81.1004389822483, 43.06114375591278, 2.3499998124316335, 0.018730454794422258, 0.04466782404051628, 0.04199625567707699, 0.06687349479761906, 0.04341121959441807, 0.069953340862412, 0.08956773250247352, 0.06234137705178, 0.049854434400913306, 0.033059350462281145, 0.04000430533778854, 0.027578678927966394, 0.013143702526576817, 0.043100760667584836, 0.05449889104056638, 0.033749306603567675, 0.07996020038262941, 0.047470448262174614, 0.1555015644407831, 0.19836148334434256, 0.1191382430261001, 0.1963605493074283, 0.14022325223777443, 0.14729234244441614, 0.15480847272556275, 0.15280547551810741, 0.3058134682942182, 0.16984762041829526, 0.19998886476969346, 0.13845553068676963, 0.14941773464670405, 0.20782109058927745, 0.22054559842217714, 0.48312501632608473, 5.713402396067977, 109.81028482317924, 105.35846650600433, 95.49180954694748, 72.15550616383553, 120.01381650567055, 83.7363651394844, 110.05804672837257, 109.5701377093792, 134.30807948112488, 134.4495838880539, 123.38438764214516, 32.23981462419033, 0.663011638680473, 1.486149535048753, 0.9181219933088869, 0.2487387793371454, 0.4505436646286398, 0.6818058458156884, 0.40981106751132756, 0.4703185457037762, 0.7392353704199195, 4.526281021535397, 48.8777082413435, 116.80951684713364, 105.55114656686783, 110.036631077528, 92.03531742095947, 90.83089604973793, 81.5256741642952, 85.04775077104568, 81.26820757985115, 81.78168922662735, 74.77111861109734, 77.62280479073524, 75.54720416665077, 83.38885858654976, 80.44954910874367, 81.96784123778343, 74.25708219408989, 79.85903799533844, 83.05717438459396, 89.32254418730736, 90.07105082273483, 87.62579843401909, 86.48338213562965, 83.59532430768013, 72.80134990811348, 72.0166540145874, 74.76819276809692, 69.40972030162811, 82.11210429668427, 88.05214315652847, 91.11760586500168, 84.86443340778351, 76.22143998742104, 73.26914280653, 72.4475584924221, 76.8666909635067, 79.61710497736931, 84.9920305609703, 85.80309703946114, 88.1481260061264, 90.02965584397316, 90.90493127703667, 84.87985298037529, 89.94758784770966, 85.58424398303032, 82.8083561360836, 90.22402301430702, 85.28122544288635, 78.3639170229435, 79.56415101885796, 87.37027734518051, 70.14032229781151, 67.33456805348396, 61.74381785094738, 81.6855163872242, 88.06950822472572, 89.26704436540604, 84.6523667871952, 75.07257923483849, 86.29495024681091, 77.54014402627945, 80.7235600054264, 74.00955587625504, 72.4341756105423, 68.23207229375839, 71.28153786063194, 77.08179742097855, 86.73909321427345, 81.32505252957344, 76.59879013895988, 70.0836369395256, 68.24396565556526, 66.60284131765366, 65.66927701234818, 68.27976733446121, 69.73625957965851, 78.43083143234253, 77.479218095541, 78.99834617972374, 69.96468812227249, 69.0554729104042, 70.39220318198204, 67.51298367977142, 66.59483134746552, 68.81060644984245, 76.55958384275436, 82.30859935283661, 79.82858642935753, 87.02730774879456, 82.45444312691689, 90.33674776554108, 89.70869466662407, 93.16875860095024, 27.040990591049194, 1.2412030412815511, 0.27101158106233925, 0.3003990260185674, 0.31957692350260913, 0.1882057564216666, 0.29132992203813046, 0.32418815419077873, 0.5549063114449382, 0.21127440762938932, 0.5791734717786312, 0.3187756414990872, 0.46652804128825665, 15.987495817244053, 72.78656110167503, 57.214810475707054, 89.45845529437065, 97.49304056167603, 51.02867782115936, 32.71812155842781, 49.77741256356239, 80.17603978514671, 86.5859766304493, 91.56777530908585, 61.067248955368996, 5.05301303230226, 0.1455858926055953, 0.18873633263865486, 0.2228670660406351, 0.25061225693207234, 0.09132382459938526, 0.19817610969766974, 0.16787328495411202, 0.1774660631781444, 0.1330079886247404, 0.32228009251412004, 0.13845512992702425, 0.07735316175967455, 0.19542241527233273, 0.144369141489733, 0.092361295101, 0.1432115098577924, 0.15296579425921664, 0.09867018117802218], [0.020187594964227173, 0.07255574106238782, 0.02478764519764809, 0.028093369473936036, 0.03968228375015315, 0.11479821536340751, 0.022623542572546285, 0.039660327311139554, 0.030746732954867184, 0.08892485449905507, 0.07136393352993764, 0.02797568897221936, 0.032322264232789166, 0.08297614011098631, 0.12316679873038083, 0.10458496457431465, 33.664430379867554, 101.25856250524521, 89.49217468500137, 59.048075303435326, 50.401430279016495, 59.1931439191103, 72.16297656297684, 76.91233411431313, 80.10214895009995, 107.00192391872406, 94.99334469437599, 29.922647662460804, 0.4780939972260967, 0.09311596280895174, 0.20652423205319792, 0.028121745490352623, 0.26769521995447576, 0.13422987540252507, 0.3064488951349631, 0.3406166913919151, 0.09819683196838014, 0.3484891267726198, 2.955379053018987, 85.57631760835648, 98.79957765340805, 97.02033072710037, 83.40521290898323, 76.57029166817665, 75.77813297510147, 84.0516722202301, 81.63315519690514, 79.07134786248207, 73.14020052552223, 69.39745455980301, 76.46020397543907, 74.03946787118912, 76.36615142226219, 79.07940343022346, 80.83689272403717, 78.66967901587486, 79.0520752966404, 83.20868745446205, 83.04290995001793, 85.96883654594421, 82.21532195806503, 78.3129009604454, 67.82954469323158, 67.1264000236988, 67.1174705028534, 68.96094918251038, 67.82025799155235, 75.08298307657242, 78.58283087611198, 78.65026205778122, 72.8409893810749, 66.82038724422455, 67.29701846837997, 67.66460314393044, 65.00833287835121, 70.71194842457771, 72.00705572962761, 75.70796594023705, 76.7232258617878, 81.08886480331421, 81.27318531274796, 83.21482792496681, 82.10243001580238, 76.88464879989624, 71.63279101252556, 71.22426733374596, 73.34422677755356, 65.27412861585617, 64.66983184218407, 64.00240525603294, 54.32395599782467, 56.55039332807064, 59.85406905412674, 58.33410881459713, 67.58359149098396, 78.91246318817139, 77.68397390842438, 75.18078222870827, 76.49703159928322, 70.20253255963326, 70.88259726762772, 69.31445941329002, 68.60163286328316, 67.90556341409683, 63.576030135154724, 72.73775652050972, 80.59950426220894, 81.4099931716919, 83.48889201879501, 73.08049812912941, 67.04481080174446, 59.050013199448586, 59.29588280618191, 61.05363808572292, 57.03590087592602, 60.28723441064358, 59.65112194418907, 60.67473761737347, 61.457583010196686, 59.60268214344978, 62.400175631046295, 58.63274618983269, 60.49955941736698, 61.36553294956684, 64.78042110800743, 70.49551203846931, 73.30990701913834, 74.63000938296318, 79.64850649237633, 84.97026532888412, 79.71654564142227, 83.56458395719528, 55.68321906030178, 0.3428665566025302, 0.1660009502666071, 0.1139149334630929, 0.15003980282926932, 0.06489026098279282, 0.18014401401160285, 0.14324993826448917, 0.3109374636551365, 0.2741412475006655, 0.026404846212244593, 0.16693402285454795, 0.07717145432252437, 0.4238831374095753, 34.81183581054211, 47.269429340958595, 74.73359942436218, 96.7934601008892, 69.67569842934608, 21.99940402060747, 27.283379584550858, 32.48202882707119, 49.81569550931454, 71.52235373854637, 69.13598299026489, 37.95601889491081, 3.9037782372906804, 0.05940289527643472, 0.01977329287910834, 0.040236664353869855, 0.12195027768029831, 0.07609050881001167, 0.0015841588606235746, 0.03272806316090282, 0.02430111915600719, 0.023277304171642754, 0.03892138942319434, 0.03453944897046313, 0.024805751745589077, 0.03473132754152175, 0.06660589118837379, 0.011872461072925944, 0.1360907661728561, 0.04671851536841132, 0.008986254324554466, 0.033861882984638214, 0.03926735640561674, 0.04330707401095424, 0.020499222773651127, 0.0347728135966463, 0.0733836364815943, 0.014306171105999965, 0.10120083054061979, 0.06013474936480634, 0.004534705985861365, 0.05113700659421738, 0.09846650616964325, 0.1109821216959972, 0.10533388805924915, 0.4507324076257646, 37.992903515696526, 112.85443067550659, 93.83968859910965, 72.10195943713188, 65.2089849114418, 72.3039186000824, 58.277602046728134, 69.8688268661499, 93.6320449411869, 115.04048377275467, 107.0243427157402, 39.2323400080204, 0.3095747617771849, 0.045556052355095744, 0.2475362626137212, 0.10077158716740087, 0.3221246867906302, 0.10785981736262329, 0.1805788531783037, 0.4453657893463969, 0.27745953819248825, 1.1004148959182203, 3.6678175488486886, 94.57550391554832, 104.50493350625038, 103.24552908539772, 88.47661837935448, 81.2562458217144, 79.2764076590538, 90.27946203947067, 85.878446996212, 86.49677261710167, 76.4089523255825, 73.16309809684753, 78.4956407546997, 78.34109544754028, 79.76169481873512, 84.88204926252365, 84.68784928321838, 84.85100492835045, 84.59935963153839, 88.18879902362823, 87.41372421383858, 90.27180165052414, 85.6778633594513, 81.59754350781441, 70.82370042800903, 69.12223532795906, 70.53455874323845, 69.96746957302094, 68.98802652955055, 76.7294879257679, 82.53745347261429, 81.80147096514702, 76.91528275609016, 71.7474764585495, 69.81502935290337, 73.35884839296341, 68.47603440284729, 72.49782979488373, 76.90635323524475, 78.33801001310349, 79.92776110768318, 87.40025013685226, 84.37621280550957, 84.36187237501144, 85.18467262387276, 82.16394111514091, 77.07497298717499, 76.26551762223244, 75.93846157193184, 72.37087860703468, 70.73202654719353, 73.59957307577133, 60.72163090109825, 64.93807464838028, 65.43112099170685, 62.983759716153145, 70.94216287136078, 81.61202073097229, 80.91713681817055, 79.41380068659782, 78.27716767787933, 74.33595836162567, 73.53978708386421, 72.40504637360573, 72.83753916621208, 69.79633435606956, 66.20765492320061, 77.15025454759598, 83.77337515354156, 85.13848230242729, 85.7324056327343, 76.88125178217888, 69.9935057759285, 63.13988573849201, 63.305218666791916, 64.14472281932831, 59.10066828131676, 62.67004854977131, 63.87137308716774, 63.98533657193184, 63.60793702304363, 64.74075123667717, 66.33521407842636, 64.06502589583397, 63.72182831168175, 64.06473711133003, 68.03361654281616, 71.61294087767601, 75.16652539372444, 78.07935789227486, 80.65758794546127, 88.40938478708267, 83.7457962334156, 89.53657910227776, 61.646132692694664, 0.6438288430217654, 0.07443938608048484, 0.09641770360758528, 0.024221332714660093, 0.13863171654520556, 0.06249722064239904, 0.19387450302019715, 0.15538782288786024, 0.4934324085479602, 0.27700178150553256, 0.33845122321508825, 0.06766189311747439, 0.44369088078383356, 38.9902625977993, 56.95938818156719, 75.76298698782921, 72.81308367848396, 43.27455550432205, 31.262043491005898, 37.07611531019211, 42.035255804657936, 61.501409858465195, 82.49275267124176, 81.27377048134804, 46.83880604803562, 2.920742011629045, 0.05952996951236855, 0.05104166288219858, 0.03061648974835407, 0.07162519919802435, 0.03437783889239654, 0.0388410816231044, 0.0014274140244197042, 0.04899484927591402, 0.03226226159313228, 0.0666639642440714, 0.026107465782843065, 0.04245320713380352, 0.05072281768661924, 0.046805910678813234, 0.014961098804633366, 0.050923653980134986, 0.03225275097065605, 0.15960402321070433, 0.12841566785937175, 0.14813465037150308, 0.20287537394324318, 0.12342344081844203, 0.16275018017040566, 0.11812713360995986, 0.11303660168778151, 0.1863276626681909, 0.15357563184807077, 0.13423789059743285, 0.20073081948794425, 0.21023565321229398, 0.1868727256078273, 0.20738463354064152, 0.5896886356640607, 55.01955807209015, 127.34029456973076, 108.10739859938622, 82.11284905672073, 70.74815288186073, 72.83930227160454, 83.71105089783669, 105.38083970546722, 106.34985610842705, 125.54743677377701, 121.2268178164959, 53.3284892141819, 0.7126229046843946, 0.21439815172925591, 0.4852994793327525, 0.326581402332522, 0.5133984668646008, 0.3310307557694614, 0.51596071687527, 0.8298388367984444, 0.4633294144878164, 1.5840115025639534, 4.828919107094407, 100.80786868929863, 108.02227556705475, 107.35835239291191, 91.02079465985298, 84.46591079235077, 81.5175350010395, 93.87653142213821, 87.52697333693504, 88.94514843821526, 80.05270600318909, 76.79134100675583, 84.02561321854591, 81.87253475189209, 83.54287192225456, 85.29866650700569, 87.52167642116547, 88.23620527982712, 87.95688226819038, 89.41208258271217, 89.32988539338112, 92.94925957918167, 89.66938957571983, 86.03367626667023, 74.0244510769844, 72.56590694189072, 74.36632633209229, 74.34750214219093, 71.49781465530396, 83.17952021956444, 86.1498512327671, 87.93526902794838, 81.69042572379112, 75.15732988715172, 73.60511317849159, 76.53985530138016, 71.3792534172535, 78.87493640184402, 80.05557864904404, 83.10879081487656, 83.54456663131714, 89.8057870566845, 88.2538591325283, 87.47654244303703, 90.38863018155098, 86.54212698340416, 79.83417212963104, 82.34185516834259, 82.56435602903366, 80.31444355845451, 70.98629370331764, 74.25887569785118, 61.14011384546757, 71.43957138061523, 68.94136503338814, 64.60729479789734, 74.20590654015541, 86.04275017976761, 82.64346778392792, 82.34728127717972, 85.57130187749863, 79.94782403111458, 78.33990231156349, 75.88714152574539, 78.55712905526161, 74.88261982798576, 71.41146048903465, 81.39600992202759, 88.23012560606003, 87.6745118200779, 90.73284611105919, 79.1191416978836, 74.47879269719124, 65.84018424153328, 65.47476544976234, 69.7967903316021, 62.14178189635277, 67.52559900283813, 67.40969002246857, 68.03247660398483, 65.96826016902924, 68.33813980221748, 68.90433982014656, 67.17319071292877, 66.41684129834175, 68.04895251989365, 71.73192769289017, 77.3305244743824, 80.81074252724648, 84.5524549484253, 85.28025269508362, 92.96565189957619, 87.97598764300346, 92.56484180688858, 64.82686221599579, 0.8741510496474802, 0.16395455226302147, 0.4638965934282169, 0.2296401432249695, 0.21943598374491557, 0.3244947799248621, 0.42002426635008305, 0.4025749198626727, 0.5602514964994043, 0.34361953963525593, 0.4398078453959897, 0.1948146111681126, 0.9172887692693621, 49.095960929989815, 65.47388389706612, 88.82355496287346, 118.10380339622498, 89.12853419780731, 29.62095145136118, 39.160801246762276, 51.74063041806221, 69.160947650671, 91.46623715758324, 90.88394120335579, 64.43603798747063, 5.582819078117609, 0.19636687240563333, 0.13964646990643814, 0.2417660495848395, 0.16967187984846532, 0.1786090002860874, 0.08862815870088525, 0.16298921109410003, 0.1988809570320882, 0.12154208161518909, 0.18525423511164263, 0.10193709298619069, 0.1901065747370012, 0.15129293402424082, 0.13906262232922018, 0.09092007399885915, 0.23174877773271874, 0.10438024313771166], [0.09076537331566215, 0.04701177873357665, 0.039565343540743925, 0.04291828510758933, 0.07228107220726088, 0.06279726352659054, 0.02871865301131038, 0.03772079857299104, 0.04810732600162737, 0.08580686204368249, 0.06621555861784145, 0.023501371542806737, 0.04045019508339465, 0.1580051550990902, 0.30799579806625843, 5.446885172277689, 77.83124640583992, 89.85207617282867, 68.40482622385025, 50.5033104121685, 31.936746686697006, 34.72509786486626, 85.22557362914085, 76.69292628765106, 97.42915838956833, 118.10137152671814, 52.65754021704197, 3.251268700696528, 0.1096370532468427, 0.11444245945313014, 0.5754758545663208, 0.07499296887544915, 0.13180106354411691, 0.3090817976044491, 0.1992487208917737, 0.030547160167770926, 0.30704106960911304, 0.6748906325083226, 11.80731637403369, 98.0842736363411, 90.50468355417252, 93.32776486873627, 80.19191533327103, 83.52190464735031, 89.70645278692245, 95.60568943619728, 92.90070578455925, 93.38165357708931, 80.60084939002991, 76.21668264269829, 77.07941114902496, 84.78865027427673, 89.5937280356884, 92.2832465171814, 89.40368503332138, 86.28492638468742, 85.70199966430664, 90.97770497202873, 87.39401087164879, 86.5689991414547, 79.60594117641449, 71.4167346060276, 63.15557889640331, 69.13610458374023, 66.27537488937378, 68.04244726896286, 70.86261034011841, 67.30032429099083, 72.33288064599037, 73.74736994504929, 70.22067278623581, 72.0572130382061, 67.23585695028305, 63.207229524850845, 61.05355069041252, 67.84187123179436, 65.3829699754715, 68.73359978199005, 75.89961245656013, 77.96947538852692, 81.40600338578224, 80.58937400579453, 74.0045553445816, 75.13397634029388, 72.09334909915924, 73.45682233572006, 70.83142161369324, 54.27598737180233, 37.493294924497604, 39.41552057862282, 33.034386187791824, 55.811139196157455, 67.9406127333641, 60.71751952171326, 59.684396758675575, 65.6981098651886, 71.84125542640686, 73.97084355354309, 69.53863218426704, 70.99446326494217, 67.10645109415054, 71.7808310687542, 63.86594697833061, 67.5915938615799, 63.17505285143852, 68.88521924614906, 78.77190113067627, 80.41774481534958, 78.99044260382652, 81.11075922846794, 79.35111165046692, 70.17515122890472, 66.12571612000465, 68.41645359992981, 61.80722124874592, 58.94534781575203, 59.788970947265625, 60.837494283914566, 60.38481317460537, 62.14667983353138, 61.63127548992634, 64.29105296730995, 60.83860382437706, 56.974990144371986, 64.54095035791397, 69.40812438726425, 72.55158171057701, 71.930733025074, 78.16318139433861, 77.22775518894196, 86.52958765625954, 76.1046190559864, 82.85893142223358, 16.31823007017374, 0.1492141783819534, 0.13868549256585538, 0.17699335963698104, 0.1431361967115663, 0.18255409406265244, 0.09357368981000036, 0.4620675853220746, 0.10696774101234041, 0.25036072824150324, 0.044521776799228974, 0.09934820729540661, 0.09292689326684922, 1.542319308500737, 26.795782148838043, 54.368603602051735, 78.57836231589317, 83.52075710892677, 53.30792471766472, 15.185737889260054, 32.41371609270573, 41.91487446427345, 56.19184456765652, 70.31426176428795, 62.81156815588474, 37.845479026436806, 4.097193321213126, 0.10395185323432088, 0.031720426995889284, 0.056140633023460396, 0.02941082631878089, 0.043772148274001665, 0.10936878912616521, 0.03516340962960385, 0.007252255963976495, 0.012365259190119104, 0.03954878251533955, 0.0771468595485203, 0.04078827303601429, 0.010445387160871178, 0.012834482058678987, 0.03575420741981361, 0.03177442937158048, 0.041565843421267346, 0.07787014183122665, 0.02005177637329325, 0.047657079849159345, 0.03955497202696279, 0.07726670155534521, 0.08807378180790693, 0.030135086381051224, 0.06010890407196712, 0.06018407621013466, 0.039381628594128415, 0.053699063646490686, 0.09783060435438529, 0.22906868951395154, 0.4273335897596553, 4.920040592551231, 89.70480367541313, 98.2868179678917, 82.2015742957592, 56.60656951367855, 43.63202892243862, 46.17476508021355, 71.81468725204468, 75.80162331461906, 110.75714841485023, 128.0977839231491, 65.67618504166603, 3.554320726543665, 0.11211815683054738, 0.16730555682443082, 0.6070109561551362, 0.07242809908348136, 0.18316332309041172, 0.3675270255189389, 0.16423069057054818, 0.18761043524136767, 0.304470804403536, 1.2418192019686103, 13.862717282027006, 107.3763558268547, 95.72475984692574, 98.92057836055756, 84.7255888581276, 89.52912390232086, 94.98084336519241, 101.14574655890465, 99.18265029788017, 99.5702674984932, 86.2629483640194, 81.12025871872902, 79.41105723381042, 89.64125588536263, 93.89115303754807, 94.11214917898178, 91.34536564350128, 92.39012718200684, 90.90398132801056, 93.94349902868271, 91.43629476428032, 90.11213421821594, 81.4384688436985, 72.22024708986282, 66.95982456207275, 70.59734657406807, 68.83915051817894, 69.77476671338081, 73.42980578541756, 69.61821511387825, 74.91605043411255, 77.67781063914299, 73.68167147040367, 76.51033088564873, 70.50907731056213, 65.90984210371971, 65.38255199790001, 73.36846187710762, 69.58602324128151, 71.46742388606071, 79.64345276355743, 82.34525978565216, 85.42633205652237, 80.58166041970253, 79.96208846569061, 80.69098055362701, 76.04993239045143, 78.64585429430008, 74.24407929182053, 62.231483682990074, 45.85494004189968, 50.89381165802479, 42.09168277680874, 61.9065061211586, 71.14007905125618, 66.76758527755737, 64.60804715752602, 67.33352690935135, 72.60911822319031, 77.48019084334373, 74.07378003001213, 74.39282611012459, 71.27806484699249, 74.7522184252739, 67.94674560427666, 69.41453084349632, 65.83167269825935, 69.6602712571621, 81.30682870745659, 82.3071326315403, 81.67559891939163, 84.9834506213665, 81.10436037182808, 73.86592358350754, 70.35799741744995, 73.1403449177742, 66.16178378462791, 63.98103520274162, 63.4457541257143, 64.85468432307243, 63.88233169913292, 64.15612980723381, 63.1725449860096, 65.8527235686779, 63.19460280239582, 61.145881935954094, 69.5278787612915, 73.06375622749329, 75.47636836767197, 75.44201821088791, 82.59483799338341, 80.39753749966621, 89.04995441436768, 79.35076206922531, 90.30517905950546, 22.499459087848663, 0.13703436241485178, 0.08641794644063339, 0.24037936149397865, 0.35545174847356975, 0.3249595424858853, 0.05914070563449059, 0.38418022566474974, 0.3125196334440261, 0.08249016696936451, 0.31918293214403093, 0.2832325268536806, 0.19843160145683214, 0.8813542756251991, 34.418568313121796, 61.91744193434715, 87.77058586478233, 60.320125445723534, 30.271237157285213, 26.022858023643494, 42.3364732414484, 49.317758828401566, 66.3655212521553, 77.61401206254959, 76.02894231677055, 45.52601829171181, 4.412571648135781, 0.1855090886238031, 0.06407099674106576, 0.042824433112400584, 0.029533456945500802, 0.012672790344367968, 0.06868228680104949, 0.03705219402036164, 0.05985469622828532, 0.0045683215648750775, 0.06298366133705713, 0.006516690673379344, 0.032317098884959705, 0.06439707416575402, 0.04136476964049507, 0.050767190696205944, 0.018247611660626717, 0.22638158057816327, 0.1298435451462865, 0.08747008178033866, 0.1426921845995821, 0.26408378093037754, 0.24399900867138058, 0.21749108185758814, 0.15405324840685353, 0.24813839670969173, 0.14334110368508846, 0.25515440851449966, 0.17162862641271204, 0.36820392357185483, 0.5846448219381273, 0.625825171591714, 8.470039051026106, 109.71093535423279, 109.24250409007072, 92.63665795326233, 69.30983886122704, 51.007592752575874, 40.66391319036484, 105.86465254426003, 99.59866717457771, 126.10512524843216, 137.74531424045563, 84.53875288367271, 6.128009548410773, 0.16687736730091274, 0.8078905020374805, 1.1585492826998234, 0.7909748191013932, 0.2096820852602832, 0.8156357926782221, 0.32830986427143216, 0.537046913523227, 0.45202689128927886, 2.120448905043304, 18.244377113878727, 112.36941710114479, 98.09922203421593, 106.2682592868805, 90.26600316166878, 93.46246764063835, 99.01482090353966, 103.23713913559914, 101.39840260148048, 101.97922423481941, 88.248790204525, 85.21305710077286, 83.98003086447716, 92.01931267976761, 97.894846200943, 100.66561192274094, 93.8230986893177, 93.98511439561844, 90.78184068202972, 99.01136308908463, 94.17660132050514, 94.76560771465302, 86.69851899147034, 78.15921440720558, 71.42854437232018, 75.13834610581398, 73.21712359786034, 74.72646340727806, 77.56348237395287, 72.6475341618061, 79.15401622653008, 82.15524718165398, 77.32762902975082, 82.81833440065384, 74.76712122559547, 70.7211971282959, 68.12897622585297, 76.79607555270195, 73.78439515829086, 77.13618010282516, 82.78771564364433, 85.38738414645195, 89.06570076942444, 87.21741914749146, 84.5072677731514, 83.41029703617096, 80.00831678509712, 84.11760628223419, 82.80188888311386, 70.99213778972626, 48.88973459601402, 55.57718575000763, 43.63713204860687, 71.77906796336174, 78.16755875945091, 67.49988198280334, 62.12852440774441, 72.73557543754578, 75.88021829724312, 81.79856792092323, 77.78296619653702, 78.69117066264153, 75.46072840690613, 78.24065163731575, 71.11931696534157, 74.17127519845963, 70.10672450065613, 74.70836117863655, 86.92164301872253, 87.68579721450806, 86.06091320514679, 89.74629744887352, 85.71717604994774, 75.49725204706192, 70.63757881522179, 76.48390710353851, 69.43947270512581, 66.38832002878189, 67.02918604016304, 68.1984592974186, 67.39701390266418, 67.39902779459953, 67.15813592076302, 70.90061590075493, 66.8007954955101, 64.41640064120293, 73.93081650137901, 75.98745614290237, 82.1026200056076, 80.63250169157982, 87.65405371785164, 85.63569322228432, 96.30901649594307, 81.5574936568737, 96.57845243811607, 21.84024006128311, 0.32806243223603815, 0.18175837816670537, 0.5612702574580908, 0.8997534227091819, 0.4926067841006443, 0.2555932552786544, 0.8808015240356326, 0.39971391088329256, 0.5006594723090529, 0.49930336070246994, 0.4027544899145141, 0.3270008641993627, 3.0849867733195424, 47.137568816542625, 71.41890808939934, 92.53233835101128, 109.96960267424583, 66.86825707554817, 23.476854041218758, 48.049025908112526, 58.66887845098972, 77.34248623251915, 90.18324360251427, 90.02766475081444, 60.77639356255531, 7.2480174992233515, 0.3393791156122461, 0.20376785105327144, 0.1172072118788492, 0.05495299265021458, 0.2168733478174545, 0.19771372200921178, 0.13446115830447525, 0.11431037943111733, 0.16856147849466652, 0.13807961804559454, 0.1743855417589657, 0.13968952931463718, 0.15538139588898048, 0.14799091120949015, 0.13064968079561368, 0.10612612328259274], [0.04477912763832137, 0.041667105761007406, 0.013819095875078347, 0.08802125259535387, 0.020361912465887144, 0.07482781133148819, 0.028060546137567144, 0.055954769559320994, 0.037838287971680984, 0.043446775889606215, 0.057891292599379085, 0.10351554461522028, 0.17938415869139135, 0.227648782893084, 0.3055555571336299, 13.227168135344982, 81.28465309739113, 82.73777112364769, 69.8635983467102, 40.96576899290085, 31.7067963257432, 42.61757455766201, 60.01870661973953, 90.43860509991646, 110.06599590182304, 75.05267590284348, 13.095900379121304, 0.06572475409484468, 0.08391997384023853, 0.09363131015561521, 0.07214942263090052, 0.12284492186154239, 0.18174074473790824, 0.22375981032382697, 0.30408147373236716, 0.12195242990856059, 0.21723069192375988, 0.7631914224475622, 22.296511977910995, 94.34538826346397, 92.78710708022118, 90.93095988035202, 87.94940426945686, 100.25891214609146, 95.15311852097511, 103.63304749131203, 97.82465636730194, 96.8719182908535, 87.52184361219406, 84.36437264084816, 86.36497288942337, 92.7042107284069, 90.6882593035698, 93.34299445152283, 90.76230213046074, 92.74996027350426, 90.2390930056572, 88.52438941597939, 89.22213837504387, 81.2368592619896, 69.28821802139282, 63.9890755712986, 64.95423138141632, 65.51866069436073, 62.071538865566254, 67.24832028150558, 69.91649150848389, 64.89037200808525, 65.90617910027504, 67.05294996500015, 66.34231969714165, 65.30282467603683, 67.42045104503632, 60.35896696150303, 60.63567191362381, 63.9666947722435, 66.4540944993496, 63.744482696056366, 72.84217491745949, 74.003005027771, 81.15893304347992, 74.35504853725433, 83.08153867721558, 74.12018314003944, 75.41365653276443, 70.49420490860939, 74.0096166729927, 53.98746505379677, 22.740379460155964, 20.56144718080759, 22.78915174305439, 49.732943549752235, 61.06096409261227, 62.058513164520264, 66.44581854343414, 61.72545723617077, 65.97556337714195, 77.40816950798035, 73.6484232544899, 72.1758958697319, 70.07726088166237, 65.04237905144691, 62.37176075577736, 62.3725701123476, 59.85750786960125, 62.20075473189354, 71.522376537323, 77.28470653295517, 76.22928276658058, 83.36960881948471, 77.19813197851181, 80.94604566693306, 75.2696518599987, 77.79377281665802, 73.57609793543816, 68.6631591618061, 60.68304017186165, 60.32653950154781, 59.622870460152626, 61.352108269929886, 62.18937814235687, 60.087061151862144, 59.81677785515785, 66.08163088560104, 65.82161083817482, 69.62278246879578, 68.74846458435059, 70.89224874973297, 74.60281804203987, 80.83063066005707, 76.8664401769638, 82.09381967782974, 77.61057704687119, 67.70218312740326, 5.4685435350984335, 0.2054783233324997, 0.06939770973986015, 0.20089468569494784, 0.2733854443067685, 0.380107942619361, 0.10363130480982363, 0.739028281532228, 0.2976571465842426, 0.34135625639464706, 0.14593020459869877, 0.03026191199751338, 0.3366229869425297, 5.508562987670302, 34.96157057583332, 71.01737603545189, 92.17514231801033, 100.61474785208702, 40.366917327046394, 15.491519831120968, 35.64399875700474, 49.691157191991806, 64.68823045492172, 69.19106483459473, 63.41293528676033, 45.68708784878254, 4.375251950696111, 0.17175922956084833, 0.07915687747299671, 0.08232197404140607, 0.029464802719303407, 0.061704272957285866, 0.04193977452814579, 0.03605420206440613, 0.05116128966619726, 0.04454391135368496, 0.03761279753234703, 0.017473418047302403, 0.03566324237908702, 0.06958930258406326, 0.016585865087108687, 0.056126539639080875, 0.030651496854261495, 0.06631614189245738, 0.09257159006665461, 0.03771911760850344, 0.02236790238384856, 0.01541894547699485, 0.06160102908324916, 0.06270347090321593, 0.0898003883776255, 0.1020807950408198, 0.07526990870246664, 0.053556786515400745, 0.0504167634062469, 0.2599440811900422, 0.5132702831178904, 19.216490350663662, 94.77088183164597, 90.3424246609211, 80.82056879997253, 64.70833137631416, 37.748766615986824, 29.467992559075356, 62.2399078309536, 97.69491612911224, 123.51678773760796, 85.48303261399269, 19.27412375807762, 0.16576039051869884, 0.045983295640326105, 0.10728034103522077, 0.25326228816993535, 0.4128864681115374, 0.16522691992577165, 0.3167027933523059, 0.49628169159404933, 0.2466206601820886, 0.2576709125423804, 1.7099722498096526, 27.560817897319794, 103.75860035419464, 95.61261266469955, 97.3762272298336, 94.2410534620285, 104.73601430654526, 99.58129450678825, 106.24722361564636, 103.48213478922844, 102.28344351053238, 91.13272905349731, 88.2914087176323, 89.30622786283493, 97.8112430870533, 96.3778156042099, 97.25379779934883, 92.61917129158974, 96.68993845582008, 93.01996618509293, 90.21729737520218, 91.42098918557167, 86.29483625292778, 71.81723311543465, 67.75014415383339, 67.66638904809952, 67.93445706367493, 65.27199313044548, 70.56912168860435, 70.27371793985367, 69.25926357507706, 67.2676308453083, 70.9612226486206, 68.16638141870499, 66.75175532698631, 69.11711320281029, 66.26532062888145, 66.71694159507751, 68.48536670207977, 71.94681376218796, 69.23565924167633, 74.31732416152954, 79.28273811936378, 84.68935400247574, 77.13391542434692, 84.95959550142288, 77.3288145661354, 79.36760276556015, 75.95898047089577, 76.95586457848549, 61.861474737524986, 32.67551824450493, 32.09191516041756, 31.716035529971123, 55.55258587002754, 67.26263791322708, 64.74069803953171, 66.34608149528503, 65.53597256541252, 69.26066190004349, 79.16327252984047, 76.97212010622025, 75.40272071957588, 71.84048786759377, 67.75661140680313, 66.09338745474815, 65.03450587391853, 62.73551143705845, 64.12674978375435, 72.53564536571503, 82.34226554632187, 81.32832035422325, 87.44444936513901, 78.85409072041512, 84.60737720131874, 80.10285571217537, 82.86833211779594, 76.60256713628769, 73.60745385289192, 64.28131029009819, 64.12681058049202, 61.97345852851868, 63.811093121767044, 65.05212172865868, 62.724454030394554, 65.03836646676064, 69.92157563567162, 69.62320804595947, 71.41797333955765, 71.75564602017403, 74.89895135164261, 77.41668865084648, 86.09483018517494, 79.38161641359329, 87.94702559709549, 82.91771426796913, 79.25770506262779, 8.894962649792433, 0.12212160989292897, 0.13860786391887814, 0.28470019809901714, 0.32212771475315094, 0.4291563341394067, 0.3790741309057921, 0.4535070899873972, 0.47972586122341454, 0.3219234460266307, 0.7175362785346806, 0.07915157111710869, 0.22056305373553187, 4.9506940227001905, 42.813366651535034, 78.30902516841888, 96.82550758123398, 58.57270561158657, 24.97255638241768, 25.590209439396858, 46.21910870075226, 58.09050388634205, 74.12674158811569, 79.19734910130501, 76.13763928413391, 52.54027470946312, 4.727773759514093, 0.11890336812939495, 0.03535785974236205, 0.05478419116116129, 0.062305212195497006, 0.06226648692972958, 0.06288096294156276, 0.033605055359657854, 0.04658210491470527, 0.06898736886796542, 0.024945190161815844, 0.012776837593264645, 0.05379355017794296, 0.05745110254792962, 0.02662437535036588, 0.022642814292339608, 0.23062527005095035, 0.31308728735893965, 0.2105656120693311, 0.26915980386547744, 0.11663588433293626, 0.20805467414902523, 0.20867228944553062, 0.12347355062956922, 0.20434878941159695, 0.20530328038148582, 0.3169960604282096, 0.24996213556732982, 0.3691438981331885, 0.46028055308852345, 0.9454177098814398, 28.000828586518764, 106.99128448963165, 101.70075237751007, 91.55685469508171, 63.9422544836998, 49.459745809435844, 53.618094474077225, 79.77285861968994, 115.63944563269615, 129.3534341454506, 99.21664327383041, 26.14202532917261, 0.27532595267985016, 0.4634510673349723, 0.3518362721661106, 0.4953439731616527, 0.9297691995743662, 0.38250629673711956, 0.6726683455053717, 0.8349530654959381, 0.8806014410220087, 0.5695867049507797, 3.5339203337207437, 30.29905926436186, 109.74950328469276, 102.252247184515, 101.37469947338104, 98.27182397246361, 107.75628224015236, 101.85061633586884, 111.83709606528282, 107.22932651638985, 105.99357962608337, 96.70268297195435, 90.49434050917625, 94.3592195212841, 103.06463599205017, 101.42778262495995, 99.21674206852913, 96.63211315870285, 100.44422060251236, 95.31630456447601, 93.59457895159721, 94.69231724739075, 91.3503585755825, 75.6202058494091, 70.4305051267147, 70.5470372736454, 71.50920644402504, 68.07410717010498, 74.56847548484802, 75.85220620036125, 72.3176434636116, 71.10702082514763, 76.1599212884903, 73.49027574062347, 71.56972959637642, 76.30591705441475, 69.47984173893929, 70.15864491462708, 71.56454667448997, 75.73431372642517, 71.76136091351509, 79.96095612645149, 81.35602846741676, 88.35095152258873, 83.62332880496979, 90.4166878759861, 81.55194595456123, 83.44346165657043, 81.28464549779892, 86.1018218100071, 69.7408877313137, 35.17426796257496, 34.72414791584015, 31.978069469332695, 64.925656914711, 73.88815239071846, 67.34392315149307, 68.0932505428791, 69.79349210858345, 74.17102441191673, 83.45004290342331, 80.1138599216938, 79.38690572977066, 76.00629553198814, 72.72724628448486, 68.141348361969, 67.99741968512535, 66.10280334949493, 68.54158088564873, 76.98427185416222, 85.2378697693348, 85.77782079577446, 90.27045652270317, 84.2542165517807, 89.24448117613792, 84.12512987852097, 85.33637568354607, 77.59226202964783, 76.2959311902523, 68.36943492293358, 66.45600959658623, 65.54987221956253, 66.63242653012276, 67.15778633952141, 66.9717027246952, 69.0664391219616, 72.32765972614288, 71.07990548014641, 75.47705993056297, 76.91624030470848, 78.83990228176117, 80.28865054249763, 91.26278087496758, 83.79433482885361, 91.31512686610222, 87.22093775868416, 85.09426027536392, 8.343369998037815, 0.2860997698735446, 0.41536016506142914, 0.5719738674815744, 0.867573186988011, 0.5368321062996984, 0.7278686366043985, 1.5452725812792778, 1.6988976253196597, 1.029609851539135, 0.8143316907808185, 0.1210533625271637, 0.5587629857473075, 9.856673944741488, 56.811340525746346, 87.97214984893799, 111.56450629234314, 134.2609468102455, 56.044530272483826, 22.439450807869434, 50.06672903895378, 65.69196939468384, 87.72698700428009, 90.11421650648117, 87.06586048007011, 66.20180323719978, 8.193316999822855, 0.25803937402088195, 0.20959857880370691, 0.15292316529667005, 0.16683617810485885, 0.12320994719630107, 0.1137484103674069, 0.10876799089601263, 0.17290881631197408, 0.3101032006088644, 0.23021104774670675, 0.0805540446890518, 0.11078389405156486, 0.23196095775347203, 0.10828401413164102, 0.11349219872499816], [0.027072946104453877, 0.02153823137632571, 0.019689914443006273, 0.05351996485842392, 0.07648611805052496, 0.09504884190391749, 0.026762006637000013, 0.03046052370336838, 0.03516811484587379, 0.06324138696072623, 0.05888387058803346, 0.05898524424992502, 0.0488896387105342, 0.0878096217638813, 0.03896454531059135, 38.247816637158394, 89.84099596738815, 73.52049171924591, 65.58584868907928, 29.534268602728844, 28.292307145893574, 59.79544959962368, 74.1152586042881, 111.71905159950256, 91.32495313882828, 51.05806544423103, 1.198039019946009, 0.10195853363256902, 0.14788252796279266, 0.11401767638744786, 0.10897855303483084, 0.10210193140665069, 0.4213491780683398, 0.141245887207333, 0.21080755221191794, 0.13855919387424365, 0.056839160970412195, 0.37641510483808815, 40.026208609342575, 94.90141242742538, 90.90725675225258, 96.85389205813408, 96.14681839942932, 94.52288433909416, 101.90728649497032, 96.54604777693748, 89.96543928980827, 97.55788788199425, 94.07602831721306, 87.3110993206501, 87.405516654253, 92.97474101185799, 93.64263877272606, 89.90490853786469, 90.21565586328506, 93.00822481513023, 88.66994440555573, 87.63608828186989, 82.87272468209267, 66.70453906059265, 61.28405012190342, 62.16854006052017, 63.91691744327545, 66.05367958545685, 63.57002645730972, 63.10513660311699, 62.05397240817547, 64.41172689199448, 60.519474148750305, 61.491625383496284, 59.26536664366722, 61.75668776035309, 64.05358850955963, 65.59391185641289, 64.3645030260086, 67.71401569247246, 68.49283710122108, 68.71275410056114, 70.77054888010025, 79.57728311419487, 80.25881454348564, 74.31469470262527, 79.47181597352028, 69.039346575737, 71.68509900569916, 69.48196962475777, 66.39023512601852, 53.61237198114395, 29.478316605091095, 24.34854816645384, 29.174369014799595, 47.60512612760067, 56.27060294151306, 65.34757867455482, 53.18649083375931, 59.0018355846405, 57.917753756046295, 73.0226120352745, 69.4992282986641, 72.45838031172752, 64.11253854632378, 62.46615529060364, 65.31561478972435, 62.972542718052864, 60.74898183345795, 58.04995246231556, 61.58893436193466, 73.15660044550896, 80.84028974175453, 81.45292326807976, 76.01729974150658, 78.10429215431213, 76.90633803606033, 78.14390122890472, 77.5967001914978, 76.19631573557854, 66.78333163261414, 61.601827070117, 59.83730435371399, 60.45323610305786, 58.58145274221897, 59.84872654080391, 67.96605616807938, 73.70275273919106, 71.03465750813484, 73.992380797863, 63.97302523255348, 63.919448107481, 67.5441724061966, 73.26851963996887, 74.30335611104965, 76.51277795433998, 73.97618606686592, 78.14991250634193, 53.32446902990341, 0.8645488461479545, 0.21211739833233878, 0.02932815292297164, 0.06293439015280455, 0.047541657331748866, 0.18058293499052525, 0.43359562405385077, 0.2705443248851225, 0.02120007364283083, 0.33159259124659, 0.09845414941082709, 0.0967578669951763, 0.21925818000454456, 12.641681302338839, 47.405207455158234, 79.24166232347488, 89.56081420183182, 87.25458115339279, 27.314564511179924, 15.798005685210228, 27.088033966720104, 39.60745207965374, 61.14598073065281, 60.35742424428463, 63.872064650058746, 48.954186737537384, 5.022284556180239, 0.02862788092897972, 0.051612415263662115, 0.047342906473204494, 0.0257528824658948, 0.053605720022460446, 0.0059074407727166545, 0.056682953727431595, 0.03346566889376845, 0.0366674609540496, 0.033773151808418334, 0.138248159782961, 0.03123099173535593, 0.02296614762599347, 0.07463260422809981, 0.02842858088115463, 0.03392422710021492, 0.03487397203571163, 0.058142105117440224, 0.077998073247727, 0.057985382081824355, 0.010514362365938723, 0.019720348063856363, 0.08573433937272057, 0.07719670218648389, 0.035655601968755946, 0.04316024009312969, 0.07818103491445072, 0.06697795208310708, 0.0017192422615153191, 47.143314108252525, 97.11572840809822, 84.37853068113327, 76.18806257843971, 44.26149554550648, 31.113175079226494, 54.549128115177155, 82.32603281736374, 120.03509536385536, 103.77113208174706, 63.90858069062233, 1.0728910728357732, 0.05135261904797517, 0.1602182097849436, 0.17453118081903085, 0.17728343547787517, 0.21134115639142692, 0.8431139588356018, 0.40889490104746073, 0.08300757748656906, 0.23758327559335157, 0.0790394919749815, 1.4163522678427398, 45.57983860373497, 101.121526658535, 93.76340389251709, 100.89834943413734, 100.65216824412346, 100.11034771800041, 105.08525356650352, 98.23425158858299, 92.77311623096466, 99.53973233699799, 98.23010981082916, 93.87813493609428, 93.86944100260735, 96.83062970638275, 98.1436188519001, 96.17677599191666, 93.97328943014145, 93.68019595742226, 91.30229875445366, 89.43335384130478, 85.14238089323044, 68.8901361823082, 64.68604177236557, 64.5309416949749, 67.34727457165718, 68.44056710600853, 66.92107424139977, 66.38826683163643, 64.82642903923988, 65.87108418345451, 62.813783437013626, 64.47047173976898, 60.438481494784355, 65.77234268188477, 67.02319756150246, 69.03153419494629, 68.51424515247345, 73.48418846726418, 69.93406176567078, 73.18955227732658, 73.83112505078316, 82.32298538088799, 82.58398577570915, 79.84003901481628, 81.84877842664719, 74.07157614827156, 75.12049466371536, 73.04889142513275, 69.45456549525261, 60.924847796559334, 35.85201859474182, 32.37483277916908, 36.891171634197235, 56.364598497748375, 59.768372252583504, 69.67496886849403, 57.07046382129192, 62.7729432284832, 65.13039752840996, 74.07935813069344, 76.4608271420002, 77.65174403786659, 67.67613172531128, 65.96280366182327, 68.01454156637192, 67.84308716654778, 64.49925899505615, 59.92859065532684, 64.7695004940033, 73.38546216487885, 82.99344420433044, 81.57947927713394, 76.55209824442863, 78.73339399695396, 76.93741276860237, 80.6034104526043, 80.90939283370972, 79.85461503267288, 71.45601689815521, 65.48305660486221, 62.601348236203194, 63.05828131735325, 62.074027732014656, 64.13712322711945, 71.45912513136864, 77.51144796609879, 75.90080559253693, 78.21844562888145, 69.13671255111694, 66.11088171601295, 71.07481375336647, 76.6130393743515, 78.41706097126007, 80.71032911539078, 80.81483110785484, 84.67724025249481, 64.36223834753036, 2.0758065255358815, 0.25275816209614277, 0.281706225941889, 0.36030346469487995, 0.09499214924289845, 0.3843829210381955, 0.6488961086142808, 0.15907605935353786, 0.2953667601104826, 0.7160795910749584, 0.48338767723180354, 0.1383342785993591, 0.08156309835612774, 15.02137390896678, 60.8661675453186, 89.67474728822708, 92.32191324234009, 59.92077447474003, 24.677247628569603, 26.758053973317146, 41.6135810315609, 53.10567297041416, 72.36388698220253, 71.17488518357277, 75.65796822309494, 57.86492899060249, 5.446858573704958, 0.06835143736680038, 0.0761624971346464, 0.031233693152898923, 0.028800803193007596, 0.012546470316010527, 0.02691654775844654, 0.06078697842895053, 0.019300650565128308, 0.030300325561256614, 0.06564676179550588, 0.03150678123347461, 0.025445002502237912, 0.041791434050537646, 0.03094244842941407, 0.14414709090488032, 0.1296809851191938, 0.1804444205481559, 0.19394233531784266, 0.20676260988693684, 0.36238423897884786, 0.1286248050746508, 0.09655650006607175, 0.1601949954056181, 0.24268159264465794, 0.14850576873868704, 0.15949960303260013, 0.14853408909402788, 0.19924793421523646, 0.08914068588637747, 63.6412650346756, 111.42314627766609, 96.70601159334183, 86.6669350862503, 44.52459342777729, 40.06015978753567, 86.1413548886776, 97.86520779132843, 132.30326145887375, 115.25276318192482, 81.23634248971939, 2.320915935561061, 0.19585173286031932, 0.24778516410151497, 0.3825101559050381, 0.6162346643395722, 0.5357894778717309, 1.5929689281620085, 0.8479491400066763, 0.4756929713767022, 0.3560800803825259, 0.7445187494158745, 2.3575946548953652, 49.113926365971565, 108.42691585421562, 97.94897809624672, 105.82133486866951, 106.19930058717728, 100.25204971432686, 106.75470918416977, 100.96482306718826, 94.95041459798813, 104.52646315097809, 101.1740930378437, 97.42431744933128, 96.66678249835968, 98.64181771874428, 101.26862436532974, 100.45924499630928, 98.09037610888481, 98.55287209153175, 95.86567148566246, 94.49473544955254, 90.7602046430111, 73.03338825702667, 67.62033551931381, 69.08384218811989, 71.73017218708992, 69.9905875325203, 69.75823760032654, 67.99308031797409, 69.55443173646927, 69.39088091254234, 68.59689831733704, 67.78637140989304, 64.45053040981293, 69.34666648507118, 71.03570625185966, 71.84902980923653, 71.20887815952301, 76.96197465062141, 73.98026704788208, 76.7150790989399, 77.70098179578781, 85.55170252919197, 89.03716430068016, 85.73187366127968, 85.75963497161865, 78.38418513536453, 81.453478038311, 80.98397523164749, 77.37448051571846, 65.03445267677307, 36.49880848824978, 31.423418931663036, 37.97268480062485, 65.93862175941467, 70.4982402920723, 74.66193526983261, 58.986161425709724, 68.45463395118713, 69.89826008677483, 79.89857107400894, 79.08817335963249, 80.46524986624718, 70.87413132190704, 67.98722863197327, 70.98618730902672, 71.31283298134804, 69.27987366914749, 63.56016218662262, 68.98255482316017, 80.33971980214119, 88.752331584692, 87.42937177419662, 77.40888386964798, 80.88677644729614, 81.78177282214165, 83.89235436916351, 83.10247555375099, 83.99326175451279, 73.09524893760681, 69.11851912736893, 65.53224116563797, 67.1872727572918, 64.46358650922775, 65.52035540342331, 73.19443881511688, 82.56642311811447, 77.4582128226757, 81.63171127438545, 71.59467905759811, 70.18595784902573, 75.2324366569519, 80.44543772935867, 81.40250757336617, 84.05222699046135, 84.95992228388786, 90.10169237852097, 66.86746671795845, 1.708168771583587, 0.34483977884519845, 0.7268726150505245, 0.8588860218878835, 0.19007675524335355, 0.3540465363766998, 1.7503757192753255, 0.3775827999925241, 0.7428089599125087, 1.4052971173077822, 0.3847924678120762, 0.1835128598031588, 0.6833189958706498, 22.452136427164078, 71.04297146201134, 96.12074419856071, 107.46402472257614, 117.62442111968994, 37.80127599835396, 27.41716280579567, 41.92902110517025, 59.589375257492065, 82.46163994073868, 80.14887884259224, 84.67794701457024, 72.09505900740623, 8.428390435874462, 0.1274621713673696, 0.19092381291557103, 0.1859833358321339, 0.10157128839637153, 0.21218555717496201, 0.09068478349945508, 0.1315380760934204, 0.1153687562327832, 0.16471606999402866, 0.17217104730661958, 0.17647151107667014, 0.2714105893392116, 0.1370192671311088, 0.11222856614040211], [0.009460129531362327, 0.07979025598615408, 0.0381766813370632, 0.028185655537527055, 0.07402431772788987, 0.07348810118855909, 0.0301115213369485, 0.05727200004912447, 0.034225516792503186, 0.03691910838824697, 0.02632989486301085, 0.020288155974412803, 0.08342833811184391, 0.3091692819725722, 4.098933627828956, 76.11292541027069, 79.96277242898941, 78.0547808110714, 55.201511308550835, 42.470146268606186, 33.15493851900101, 34.34176683425903, 82.4124325811863, 102.52832517027855, 66.33510008454323, 12.102320194244385, 0.23112029739422724, 0.03696521060192026, 0.14966800168622285, 0.02113028764142655, 0.0715154578210786, 0.19249528093496338, 0.5886091967113316, 0.019581629530875944, 0.35594201122876257, 0.20202649058774114, 0.11731002159649506, 3.06150047108531, 49.503428265452385, 93.1559456884861, 97.32067421078682, 100.27497008442879, 99.20782774686813, 103.20980340242386, 99.1885855793953, 96.00836902856827, 97.38312765955925, 89.8216550052166, 92.92402893304825, 94.63589787483215, 91.67019501328468, 94.37455549836159, 91.37281537055969, 91.45118236541748, 88.09850826859474, 88.09167623519897, 86.73542261123657, 79.21533733606339, 66.33776754140854, 60.54077200591564, 62.14985266327858, 61.50309316813946, 67.85482853651047, 74.19446915388107, 75.35499528050423, 78.79083171486855, 72.16575041413307, 67.88852512836456, 63.32819603383541, 59.924536272883415, 58.37049946188927, 61.56180001795292, 66.57199457287788, 67.33997896313667, 66.32428586483002, 66.91974431276321, 66.58776372671127, 70.54458260536194, 71.91167324781418, 81.59202620387077, 75.93693405389786, 76.97880014777184, 75.38549244403839, 70.60111597180367, 67.53336578607559, 66.34795859456062, 55.01247525215149, 59.191855788230896, 47.90146842598915, 42.59378403425217, 44.506453201174736, 54.02819126844406, 48.37776906788349, 58.85779291391373, 62.9130645096302, 56.72204151749611, 58.47212500870228, 62.67300859093666, 71.13953948020935, 68.54016736149788, 67.01233774423599, 62.861075699329376, 60.02803131937981, 65.43679028749466, 61.97208680212498, 57.887233793735504, 58.39430518448353, 63.764591217041016, 73.50434258580208, 74.76469695568085, 71.11867100000381, 80.32230153679848, 77.0899061858654, 77.8807121515274, 75.28703212738037, 72.63407528400421, 64.77257072925568, 61.477691531181335, 59.25387226045132, 56.12851336598396, 60.470612570643425, 66.75176292657852, 73.51194217801094, 79.1308830678463, 80.60875296592712, 68.9476802945137, 67.90580660104752, 58.538769632577896, 59.720935598015785, 60.077345073223114, 68.86805936694145, 68.30572754144669, 81.12514525651932, 72.10450530052185, 84.92178753018379, 31.383720561861992, 0.20222915627527982, 0.09963596021407284, 0.42039207473862916, 0.3984137572115287, 0.17669014778221026, 0.3808996657608077, 0.27374093304388225, 0.27132458926644176, 0.3567865159129724, 0.2549148432444781, 0.1428521767957136, 0.22457400569692254, 2.4476740462705493, 27.078293189406395, 64.54314664006233, 83.03385883569717, 87.813181579113, 79.09888118505478, 23.129258193075657, 14.89811422303319, 24.669834226369858, 37.08416327834129, 58.62402185797691, 56.28311187028885, 66.70725211501122, 43.484384045004845, 1.8716496555134654, 0.03421691159019247, 0.09804779387195595, 0.025006116775330156, 0.06911457297974266, 0.04585813243465964, 0.03731176759174559, 0.030798430962022394, 0.023868790303822607, 0.07023762052995153, 0.06613790770643391, 0.05935690438491292, 0.04904419467493426, 0.020092197446501814, 0.032805662121973, 0.11822809537989087, 0.03949403799197171, 0.09033399997861125, 0.046520855466951616, 0.05323021185176913, 0.03313224791781977, 0.12156448705354705, 0.03077568228036398, 0.07068066042847931, 0.019622126674221363, 0.052232208763598464, 0.08708861045306548, 0.12491887580836192, 3.5236618341878057, 85.680181235075, 91.90833583474159, 83.56469795107841, 60.34544728696346, 36.05278842151165, 37.965727373957634, 41.83521553874016, 91.94879606366158, 112.88216158747673, 81.20929554104805, 16.261820197105408, 0.26106941455509514, 0.07037999414023943, 0.3868783777579665, 0.0958270208502654, 0.2019958250457421, 0.18095939682098106, 1.1463794857263565, 0.18412067875033244, 0.25088032067287713, 0.252564461552538, 0.32084700535051525, 4.29640855640173, 52.791274040937424, 97.81251981854439, 103.2451719045639, 102.25872963666916, 101.69876128435135, 106.52836292982101, 101.98802456259727, 99.56845879554749, 97.36716851592064, 93.94311144948006, 93.56640726327896, 95.59840142726898, 95.36586910486221, 98.97358551621437, 93.89921620488167, 95.94830945134163, 91.38581827282906, 91.27285033464432, 86.18205830454826, 81.76402777433395, 67.33581438660622, 64.32234808802605, 66.66996091604233, 65.75396686792374, 72.37616792321205, 77.10200473666191, 82.93536812067032, 83.39381352066994, 77.82431557774544, 68.5493628680706, 67.41678804159164, 61.70772358775139, 62.58772596716881, 64.4667099416256, 69.4078280031681, 71.42837718129158, 72.4904353916645, 69.60620775818825, 70.94394877552986, 74.32832077145576, 75.67826673388481, 82.85075426101685, 81.17560654878616, 80.35249471664429, 77.75357097387314, 74.47871670126915, 72.40153536200523, 68.46816882491112, 60.3539702296257, 63.60402703285217, 51.93599313497543, 47.6536875218153, 51.76833473145962, 59.97499756515026, 55.52049659192562, 59.7976116836071, 66.68861031532288, 61.99185714125633, 64.00686621665955, 69.61591243743896, 73.97573009133339, 71.85460790991783, 72.45499089360237, 65.65030843019485, 65.68152755498886, 67.00323343276978, 65.7379849255085, 62.357386127114296, 62.24982909858227, 65.71760281920433, 77.05684795975685, 75.84346666932106, 73.17226320505142, 80.81392675638199, 79.52850133180618, 79.7958017885685, 79.20991882681847, 75.19239440560341, 67.75816172361374, 64.23049941658974, 62.98376351594925, 59.47306349873543, 64.05875623226166, 71.16292342543602, 77.31778755784035, 80.97046315670013, 83.62116292119026, 73.2392992079258, 72.68730282783508, 62.093535885214806, 62.37415462732315, 63.44336785376072, 72.9565791785717, 70.86495861411095, 85.4176153242588, 77.74939879775047, 91.68683052062988, 40.86681470274925, 0.09417968307388946, 0.048123638407560065, 0.6536962010432035, 0.9557550551835448, 0.8335270138923079, 0.8019380620680749, 0.5672026297543198, 0.12276124471100047, 0.6273680669255555, 0.8205929235555232, 0.34045505162794143, 0.4738701676251367, 1.2847519107162952, 33.02446112036705, 74.95021060109138, 93.03807601332664, 81.20269909501076, 51.17687746882439, 26.69460117816925, 27.02419549226761, 34.0729046612978, 47.512544095516205, 69.32110145688057, 64.3856754899025, 76.99376374483109, 53.22009243071079, 2.0502557465806603, 0.05873770460311789, 0.060790295829065144, 0.010045960498246131, 0.04556209714792203, 0.012454734369384823, 0.0474474119982915, 0.02289672713231994, 0.033920341957127675, 0.025146278785541654, 0.03026153350219829, 0.007522030355175957, 0.022686109332425985, 0.0684649933828041, 0.09623655278119259, 0.22252315480727702, 0.21890001953579485, 0.13141674979124218, 0.14323646086268127, 0.1851428981171921, 0.14122814987786114, 0.20793861709535122, 0.10998972924426198, 0.19254825543612242, 0.1640367228537798, 0.15609520836733282, 0.1683076046174392, 0.5926656571682543, 5.895548472180963, 101.56655117869377, 101.9175611436367, 97.64973655343056, 74.02855485677719, 58.11875157058239, 46.15650326013565, 51.595387011766434, 106.42181664705276, 120.93599662184715, 95.02452582120895, 22.910403236746788, 0.48165894811972976, 0.17419240524759516, 0.4561350942822173, 0.22919224225915968, 0.45117508387193084, 0.7299689739011228, 2.1009381394833326, 0.5971119529567659, 0.6503822444938123, 0.4549587902147323, 0.5511951574590057, 5.934048956260085, 57.0020142942667, 103.31700325012207, 108.03975462913513, 108.04811418056488, 105.89920029044151, 112.24185794591904, 106.3065992295742, 102.47704312205315, 99.16824147105217, 97.087921500206, 95.87305828928947, 101.32223948836327, 96.33754536509514, 103.99002313613892, 100.56949988007545, 100.98622351884842, 95.18760547041893, 96.05355620384216, 93.446044921875, 87.66656264662743, 74.0090163052082, 68.03631439805031, 69.52329620718956, 69.22784686088562, 74.9731157720089, 79.49625626206398, 85.15429705381393, 85.72435766458511, 79.4185808300972, 71.91298797726631, 70.62581464648247, 65.69572359323502, 66.76381587982178, 68.89066055417061, 74.06171947717667, 75.93908473849297, 75.51055893301964, 72.76939362287521, 75.18078982830048, 77.34893828630447, 78.61501514911652, 87.90720373392105, 86.12975031137466, 82.81464859843254, 84.01067242026329, 79.89496886730194, 80.21700918674469, 72.72217735648155, 65.24243831634521, 67.80512720346451, 54.818020686507225, 50.664379969239235, 54.77756425738335, 66.06355905532837, 63.88673186302185, 71.9537901878357, 73.1528690457344, 67.59797751903534, 65.74366942048073, 74.97250780463219, 81.15833267569542, 77.51202553510666, 75.44816628098488, 70.68394392728806, 66.02521151304245, 71.78826346993446, 68.66309076547623, 65.08911654353142, 65.3205469250679, 67.68557041883469, 81.97396650910378, 80.17410948872566, 73.53611648082733, 82.6340214908123, 82.51760333776474, 83.26972737908363, 82.03965738415718, 78.63279819488525, 73.6838373541832, 67.25341200828552, 67.98067018389702, 62.48622961342335, 67.46898204088211, 73.90014454722404, 81.8370446562767, 81.84855043888092, 88.80425199866295, 77.17967256903648, 78.4607282280922, 64.52958896756172, 66.00739046931267, 65.8218540251255, 77.79039099812508, 76.39534145593643, 92.52460196614265, 83.01720052957535, 99.26193684339523, 39.26752232015133, 0.30698095564730465, 0.2452413341961801, 0.8452177396975458, 1.2879197532311082, 0.48812168883159757, 0.7812728709541261, 0.6707185751292855, 1.0111420112662017, 2.6181661477312446, 1.0105237131938338, 0.3695117658935487, 0.5044570716563612, 4.846830395981669, 45.75073063373566, 84.87030789256096, 97.29250252246857, 106.15634009242058, 107.2939458489418, 33.6459481716156, 23.69973488152027, 39.51187960803509, 56.19706928730011, 77.71634817123413, 76.82662591338158, 87.29159876704216, 65.82730293273926, 2.9088994720950723, 0.12866917066276073, 0.28942702570930123, 0.1069356950756628, 0.20448319235583767, 0.12489426619140431, 0.13659875141456723, 0.0744347921863664, 0.1383163928403519, 0.13575368269812316, 0.16243573219981045, 0.12266610137885436, 0.14663656591437757, 0.15386734041385353], [0.05964296891761478, 0.025697026576381177, 0.0246685286401771, 0.06242546980502084, 0.03983548529504333, 0.028116294415667653, 0.029403944754449185, 0.06967814508243464, 0.03601662341679912, 0.08955277080531232, 0.05726628180127591, 0.05139577122463379, 0.2815387677401304, 0.39956450171303004, 22.202786207199097, 84.5275130867958, 69.29987579584122, 59.23324316740036, 35.03424547612667, 32.87453256547451, 28.813207894563675, 56.67382590472698, 107.40135848522186, 90.28054878115654, 36.330827102065086, 0.8431434072554111, 0.09795312551432289, 0.017726299302012194, 0.2612336666788906, 0.05286971732857637, 0.06816498760599643, 0.0974679019418545, 0.6455475382972509, 0.46935577236581594, 0.4451581957982853, 0.17203254770720378, 0.36325234395917505, 6.420282265171409, 59.18687425553799, 101.6073077917099, 99.1331921517849, 102.03922301530838, 102.3879075050354, 98.97119924426079, 97.83442944288254, 93.77382293343544, 94.30272415280342, 94.535613656044, 88.98976564407349, 89.95667695999146, 90.41169494390488, 86.06924995779991, 89.2301407456398, 81.91356495022774, 81.24168500304222, 77.80855402350426, 70.30699655413628, 65.24453580379486, 60.95811881124973, 60.835058614611626, 62.82609857618809, 72.33447656035423, 77.74920880794525, 85.37888020277023, 88.06132346391678, 82.58678242564201, 80.66004261374474, 77.29903936386108, 70.63632488250732, 64.30508181452751, 58.367531821131706, 58.65956895053387, 61.10114313662052, 66.08031615614891, 67.76384621858597, 69.86526265740395, 68.63866567611694, 75.03887504339218, 75.2209460735321, 79.23977762460709, 71.23831897974014, 74.88312900066376, 66.90972805023193, 68.76275181770325, 63.025014102458954, 64.46964338421822, 57.96295613050461, 58.58815558254719, 62.26104609668255, 54.7208447009325, 50.80348290503025, 53.67925979197025, 56.79790064692497, 48.255343437194824, 61.946958750486374, 57.08488404750824, 60.6896898150444, 65.23194327950478, 64.47149768471718, 63.96023511886597, 68.88898104429245, 66.6075150668621, 72.63380169868469, 67.56670519709587, 64.1902519762516, 61.583842635154724, 58.10230605304241, 61.86792679131031, 73.469118475914, 72.7744397521019, 76.54364749789238, 76.46352499723434, 74.63569387793541, 70.12811735272408, 71.80293068289757, 68.92770856618881, 63.002530708909035, 57.94568985700607, 57.27911442518234, 57.21248500049114, 61.41760915517807, 69.34070840477943, 78.44515666365623, 73.57130259275436, 69.95493784546852, 78.00371155142784, 64.47673380374908, 64.22818914055824, 56.34473696351051, 57.06325940787792, 58.69658276438713, 64.1691555082798, 67.66167730093002, 75.41652157902718, 70.2673950791359, 78.72521683573723, 12.286266423761845, 0.4406321339774877, 0.09338675765320659, 0.6814882659818977, 0.5633726727683097, 0.5560219078324735, 0.37233415350783616, 0.2583910629618913, 0.8387183072045445, 1.1776286526583135, 0.06683024243102409, 0.11258654107223265, 0.41640332783572376, 8.469284791499376, 42.59649708867073, 78.83566930890083, 85.06213679909706, 83.86577859520912, 53.64767208695412, 26.441587954759598, 16.33183714002371, 28.85317984968424, 37.937532886862755, 62.49876134097576, 60.74741251766682, 59.26351994276047, 27.28502679616213, 0.07725183633738197, 0.07837837940314785, 0.07074907902278937, 0.016929529556364287, 0.0561318237305386, 0.031529138432233594, 0.04728429536044132, 0.07019303971901536, 0.02749668088654289, 0.05678120294760447, 0.042055994854308665, 0.027046032118960284, 0.005217995321800117, 0.07689647376537323, 0.045211172619019635, 0.018177515812567435, 0.08313131576869637, 0.04210363331367262, 0.05136299798323307, 0.05306537714204751, 0.02341618041100446, 0.02978015982080251, 0.09359474453958683, 0.08878602093318477, 0.03719020380231086, 0.2525299071567133, 0.5056540668010712, 25.106275007128716, 97.23184257745743, 77.2591795027256, 75.4032526910305, 49.67926383018494, 48.19497987627983, 30.67876148968935, 56.405149921774864, 121.30132421851158, 101.25330358743668, 45.920304134488106, 1.293578005861491, 0.07707867844146676, 0.5076750239823014, 0.45236872450914234, 0.36425255122594535, 0.2167665824526921, 0.02184962355386233, 1.3113774382509291, 0.5869280244223773, 0.4710753879044205, 0.18855931557482108, 0.3200992470374331, 7.647782173007727, 65.39389058947563, 102.91875422000885, 103.19621533155441, 106.52637183666229, 106.3177478313446, 102.02831000089645, 100.55082008242607, 97.68878325819969, 99.1891099512577, 97.81002715229988, 91.73784658312798, 92.43437960743904, 94.4282466173172, 90.8457000553608, 91.45270988345146, 84.48159635066986, 83.45520302653313, 81.26630768179893, 72.8308667242527, 68.731669485569, 65.57224541902542, 62.81775802373886, 65.30473217368126, 75.64048156142235, 83.55014473199844, 89.1165192425251, 88.58137875795364, 85.78281372785568, 83.90015915036201, 81.9448372721672, 72.5064705312252, 67.83114060759544, 62.151950150728226, 62.04692758619785, 62.798595651984215, 69.47060823440552, 70.37033915519714, 73.53990107774734, 72.24673926830292, 77.22138673067093, 78.07203948497772, 83.57415184378624, 73.22908535599709, 76.940528601408, 71.78645476698875, 70.67980974912643, 65.94588696956635, 66.23287796974182, 62.537739649415016, 63.147204145789146, 65.48029035329819, 56.79954215884209, 56.449972316622734, 59.80674259364605, 60.86099982261658, 56.143237575888634, 64.98085275292397, 61.998985558748245, 65.63428089022636, 67.78644740581512, 72.50476822257042, 67.88751438260078, 72.78903856873512, 68.93195673823357, 74.69701498746872, 70.0757485628128, 67.07376524806023, 65.02730146050453, 63.59107732772827, 65.54632321000099, 75.69884642958641, 75.60303077101707, 79.50694888830185, 78.69001552462578, 76.5635584294796, 73.2894717156887, 74.24698233604431, 72.67036333680153, 65.15817403793335, 62.52485454082489, 60.79853117465973, 59.44839522242546, 63.14649738371372, 73.77120986580849, 80.81486910581589, 78.83944630622864, 75.82173183560371, 81.08951836824417, 69.68981087207794, 66.91036641597748, 60.06983667612076, 60.32314248383045, 62.141401916742325, 68.51204127073288, 71.26721262931824, 80.91119393706322, 76.99414372444153, 87.78957724571228, 17.98755269497633, 0.220094402320683, 0.22473714459920302, 1.075025845784694, 0.7677942817099392, 1.276601110585034, 0.9829342248849571, 0.4232408828102052, 0.640302513493225, 1.2470214790664613, 1.0641166311688721, 0.2068047341890633, 0.43145509203895926, 8.324315920472145, 51.24500401318073, 87.23707929253578, 96.05192229151726, 72.23838731646538, 37.43105046451092, 28.445818908512592, 25.8576200902462, 41.19749575853348, 47.00439356267452, 74.73508134484291, 70.45667052268982, 72.36252665519714, 33.49684797227383, 0.06500206553027965, 0.0938040524488315, 0.07902893863501959, 0.08633323770482093, 0.07327753904974088, 0.015048260338517139, 0.07441078370902687, 0.04669686692068353, 0.0571791054244386, 0.08358227438293397, 0.04043381959490944, 0.04194551132968627, 0.010606215200823499, 0.2051435998873785, 0.1727331499569118, 0.10509904284845106, 0.16027620120439678, 0.12297119828872383, 0.14456055621849373, 0.1283402953413315, 0.2218716382049024, 0.06106592947617173, 0.22752098506316543, 0.3514036297565326, 0.34428931307047606, 0.3164262691279873, 0.7685147586744279, 31.96785181760788, 112.72170379757881, 88.57994243502617, 82.3554128408432, 54.730382189154625, 44.9700815230608, 42.20913827419281, 79.99333038926125, 127.95892417430878, 116.26679196953773, 55.652892887592316, 2.7044488303363323, 0.27520192496012896, 0.43611471075564623, 0.5757376248948276, 0.4574728896841407, 0.7324192486703396, 0.17245018389075994, 2.716683461330831, 0.9216903580818325, 1.710089212283492, 0.7716661551967263, 0.8786657417658716, 10.890939496457577, 70.28092995285988, 109.5126847922802, 105.1606947183609, 112.78898298740387, 108.26360821723938, 109.3795171380043, 105.88659256696701, 102.87136316299438, 106.34097218513489, 102.85278216004372, 92.48507648706436, 94.48563873767853, 98.51301223039627, 92.96290084719658, 96.59069538116455, 88.9986115694046, 89.80101451277733, 87.57439479231834, 77.04594254493713, 73.82004484534264, 69.68730300664902, 66.33285820484161, 69.6975776553154, 79.60241496562958, 86.61920964717865, 90.13175636529922, 92.2988560795784, 88.9074544608593, 87.28158250451088, 83.2534870505333, 76.93226784467697, 69.94073420763016, 66.22964054346085, 65.28835505247116, 66.69288128614426, 73.68819192051888, 75.88461846113205, 78.64162892103195, 78.65153878927231, 82.82706633210182, 83.5808926820755, 88.68133619427681, 79.63602796196938, 80.8049288392067, 76.48495584726334, 77.00605988502502, 72.92684197425842, 68.45693662762642, 65.53534179925919, 65.67270442843437, 66.75084337592125, 60.206830725073814, 57.713191732764244, 62.585381492972374, 65.29095411300659, 63.962249010801315, 71.92868113517761, 66.7351958155632, 70.60041680932045, 72.63909101486206, 75.50245776772499, 74.02577340602875, 78.9043240249157, 73.17513585090637, 77.94368237257004, 72.44943559169769, 70.03133654594421, 68.85143905878067, 66.82819962501526, 69.25452142953873, 77.70787462592125, 78.3261850476265, 79.95382010936737, 82.74230048060417, 80.31988486647606, 79.38673853874207, 77.69861072301865, 78.20509314537048, 69.20516207814217, 65.9106096625328, 63.0779604613781, 62.158337607979774, 65.72160020470619, 78.83854955434799, 84.3849067389965, 80.98316207528114, 78.35151448845863, 85.51833271980286, 72.3431096971035, 70.99885582923889, 62.646687403321266, 64.44475471973419, 65.64169809222221, 73.88555333018303, 76.2318666279316, 86.41623213887215, 82.04565346240997, 93.45252737402916, 15.445196516811848, 0.3301214170642197, 0.8548103843349963, 2.3739957623183727, 2.004938190802932, 1.1970754154026508, 1.7668416607193649, 0.5572517355903983, 3.7647852580994368, 3.806085716933012, 1.0997019591741264, 0.25708995934110135, 0.7546426530461758, 14.483597315847874, 64.32623147964478, 95.54578185081482, 104.00362640619278, 104.628084897995, 73.24129790067673, 37.02094987034798, 26.887264139950275, 43.776926547288895, 56.69602431356907, 84.74955797195435, 76.54432386159897, 84.15547505021095, 39.59675945341587, 0.1616858661873266, 0.3078464779537171, 0.150914883997757, 0.23326510417973623, 0.15018340840470046, 0.08534472668543458, 0.24085527111310512, 0.176608229521662, 0.1638540209387429, 0.16242522338870913, 0.19622504798462614, 0.11371332162525505, 0.1275217064539902], [0.038505731063196436, 0.016395021812058985, 0.020032500942761544, 0.02969574608869152, 0.0913571470300667, 0.022255121912166942, 0.05046422375016846, 0.06007534415402915, 0.025056783197214827, 0.04233841544191819, 0.0337837385450257, 0.011996621451544343, 0.07843321669497527, 0.13260795618407428, 44.82372097671032, 81.9409766793251, 71.15745931863785, 57.3219533264637, 31.122247092425823, 30.088168680667877, 64.35025379061699, 81.04620829224586, 94.99507740139961, 69.95892763137817, 8.617340046912432, 0.14942306326702237, 0.04664926185796503, 0.6905867590103298, 0.49794523045420647, 0.04182493830739986, 0.142200660193339, 0.08810823972453363, 0.9383389865979552, 0.17817150423070416, 0.07496144986362197, 0.03443017885729205, 0.536526816431433, 8.841902296990156, 79.94549095630646, 104.17413845658302, 100.96274837851524, 99.84100297093391, 96.47597953677177, 95.19279599189758, 92.3830595612526, 90.54012045264244, 85.41781291365623, 88.14839199185371, 92.22053468227386, 96.71665862202644, 90.03971010446548, 87.39013507962227, 78.89439895749092, 72.92125627398491, 70.09439036250114, 67.07677468657494, 64.80648770928383, 61.4259535074234, 62.01426073908806, 65.62047243118286, 74.13076937198639, 82.01185047626495, 85.41570022702217, 79.89082708954811, 80.10535597801208, 89.0092433989048, 86.60603955388069, 81.05520620942116, 78.60652640461922, 69.28952515125275, 62.5567614287138, 59.90462154150009, 59.63985174894333, 61.16171948611736, 64.84697833657265, 66.3159491121769, 66.17980241775513, 70.96528083086014, 74.21435728669167, 77.86443382501602, 61.800932586193085, 64.285778850317, 64.88597944378853, 62.51261919736862, 61.43826104700565, 64.14568796753883, 59.76330332458019, 67.15115189552307, 77.44403198361397, 67.998316437006, 61.19913227856159, 58.77008222043514, 58.533666506409645, 53.36209461092949, 54.384501948952675, 60.89620113372803, 56.13402307033539, 57.33218237757683, 70.47443836927414, 68.53618517518044, 65.93751221895218, 65.67353278398514, 70.24984002113342, 68.84972155094147, 66.5546903014183, 67.94791594147682, 66.20501026511192, 65.83635404706001, 70.40595844388008, 74.14757207036018, 75.48024415969849, 75.78976795077324, 67.6963010430336, 67.5260017812252, 63.94457995891571, 60.768531784415245, 55.458510518074036, 55.99393218755722, 53.84392395615578, 57.85679742693901, 62.07894466817379, 70.71907684206963, 72.28851422667503, 68.80891174077988, 77.81192064285278, 75.25040209293365, 70.36547541618347, 61.374755054712296, 59.03255693614483, 59.65184770524502, 58.58030900359154, 61.40446186065674, 64.04620170593262, 74.09823551774025, 74.62680995464325, 76.8745793402195, 63.33752453327179, 2.118979333899915, 1.4102144096978009, 0.5953888641670346, 2.1383511694148183, 1.0811797343194485, 0.3464291029376909, 0.2531815425027162, 0.4098748625256121, 1.1137804412283003, 1.0340886237099767, 0.1656390939024277, 0.0018376082061877241, 0.7728388672694564, 22.46650155633688, 59.01888906955719, 80.87084010243416, 76.84421896934509, 90.45231476426125, 63.82988691329956, 30.12275442481041, 16.85053590685129, 36.339562833309174, 36.44761763513088, 51.74374245107174, 63.90559405088425, 59.01111088693142, 3.710475484840572, 0.14020738512044773, 0.10682233201805502, 0.012394975710776635, 0.014270158389990684, 0.06573561171535403, 0.004197971320536453, 0.03440354688791558, 0.0370666770322714, 0.027375757199479267, 0.041395702355657704, 0.016827506515255664, 0.0602372288267361, 0.04789210688613821, 0.0375898540369235, 0.06389613190549426, 0.10181854231632315, 0.03931795603421051, 0.01904918495711172, 0.02017883391090436, 0.015811597259016708, 0.07948792728711851, 0.0760696321958676, 0.04088104520633351, 0.04402180675242562, 0.07921908429125324, 0.20990357181290165, 50.84887906908989, 92.212935090065, 79.76858764886856, 64.34693276882172, 39.395761638879776, 32.40245349705219, 30.495316833257675, 84.86419782042503, 105.85293397307396, 83.23296055197716, 11.839543394744396, 0.1587487425422296, 0.08143646569806151, 1.3479091529734433, 1.267269286327064, 0.19493789674015716, 0.13178470660932362, 0.13906101929023862, 1.0576859512366354, 0.4001837794203311, 0.18871829845011234, 0.14919758395990357, 1.547164167277515, 10.406795125454664, 86.36487409472466, 105.69571360945702, 103.37001040577888, 102.96882033348083, 98.5565958917141, 97.87468448281288, 95.46536296606064, 92.73303598165512, 88.78446266055107, 92.02966332435608, 95.86183369159698, 98.88006493449211, 93.17793890833855, 91.95624366402626, 82.17304542660713, 75.96423178911209, 73.66410881280899, 70.56352078914642, 66.15883514285088, 64.75528165698051, 65.28833225369453, 70.23388087749481, 79.51989859342575, 85.31927660107613, 87.94895589351654, 82.65276968479156, 85.52941292524338, 90.87049752473831, 89.80177447199821, 80.78035935759544, 82.47230216860771, 74.26828399300575, 65.9146298468113, 62.16603599488735, 62.649765238165855, 63.858051002025604, 67.80533999204636, 68.99127155542374, 72.27772280573845, 75.18748506903648, 80.18013596534729, 79.1128720343113, 65.75647473335266, 65.87332606315613, 70.05071550607681, 66.56080037355423, 63.914151191711426, 64.14682790637016, 64.15549144148827, 71.19516089558601, 77.70117178559303, 70.61608716845512, 64.93573397397995, 60.53588546812534, 59.154192209243774, 61.753606125712395, 63.82929414510727, 66.01233020424843, 61.10448315739632, 60.987088456749916, 75.0785981118679, 74.68301653862, 71.04858756065369, 70.23217096924782, 74.57919850945473, 73.1009030342102, 69.73414689302444, 69.56504076719284, 70.41292726993561, 70.18705978989601, 73.61589699983597, 75.11693805456161, 80.19184693694115, 76.68595746159554, 71.62585258483887, 69.89867806434631, 65.5987223982811, 64.16850954294205, 59.18152414262295, 59.378528371453285, 56.89923360943794, 60.921169593930244, 65.27316346764565, 72.993885576725, 75.88061347603798, 72.63675034046173, 80.47686204314232, 77.94920727610588, 73.6555440723896, 65.79397112131119, 61.93753905594349, 61.41782574355602, 64.19423416256905, 63.668976947665215, 68.0525167286396, 77.44401678442955, 81.8816390633583, 81.66238322854042, 74.55856561660767, 4.044765634462237, 0.6241187662817538, 0.34263767825905234, 1.0251946072094142, 1.5402981732040644, 0.2890036749886349, 0.07583091297419742, 0.3483602008782327, 1.8352680327370763, 1.4264928549528122, 0.5386585020460188, 0.09345145808765665, 0.5637937970459461, 24.933956153690815, 69.31629851460457, 89.8211382329464, 85.44336274266243, 70.44191971421242, 38.85579541325569, 28.05845059454441, 23.75686291605234, 42.57169581949711, 46.91552773118019, 63.22687827050686, 71.10007479786873, 73.14932003617287, 4.20743253082037, 0.1259032604866661, 0.08892037192708813, 0.09208677467540838, 0.055816659587435424, 0.07546506385551766, 0.07268246277817525, 0.02939703164884122, 0.0676006288267672, 0.01939663437951822, 0.03457396254816558, 0.05487792441272177, 0.03390037076314911, 0.15087540174135938, 0.10547943064011633, 0.13651120767463, 0.2045139469555579, 0.26993255771230906, 0.15002326777903363, 0.14927268930478022, 0.11003532679751515, 0.14538635878125206, 0.2032607267028652, 0.20629156875656918, 0.08528804886736907, 0.19034342374652624, 0.39525324711576104, 59.385235011577606, 105.55507555603981, 89.8482383787632, 78.0497194826603, 47.8338548541069, 40.044113248586655, 88.4948118031025, 105.36771520972252, 109.09368887543678, 97.56183966994286, 15.813680794090033, 0.35161781357601285, 0.259837627527304, 1.409573550336063, 2.9186167381703854, 0.5155204748734832, 0.43928371102083474, 0.22859546646941453, 1.9920859741978347, 1.004751822911203, 0.7920705259311944, 0.27883470815140754, 2.0283164363354445, 12.707121390849352, 87.26695328950882, 109.88719269633293, 107.40298479795456, 106.85657411813736, 102.30116575956345, 104.9544569849968, 99.9118235707283, 101.37222200632095, 93.26658055186272, 97.78129309415817, 97.59656980633736, 103.98607894778252, 96.52866750955582, 95.15203177928925, 86.62435457110405, 79.7736793756485, 76.49132430553436, 74.50118869543076, 70.8126050233841, 67.9649618268013, 69.9101610481739, 72.36088514328003, 81.55515298247337, 87.57361963391304, 90.77754691243172, 86.12177073955536, 86.34574592113495, 91.58424362540245, 90.05864828824997, 87.34011456370354, 83.45687493681908, 78.23474675416946, 68.79727676510811, 67.26536616683006, 66.14447951316833, 69.40248548984528, 70.78158348798752, 74.63398396968842, 73.06806519627571, 79.25680831074715, 82.74317443370819, 84.84691634774208, 67.74676233530045, 69.69932556152344, 75.63515424728394, 71.42865836620331, 68.67261305451393, 66.5776714682579, 65.01584887504578, 74.77282851934433, 80.01599997282028, 72.10224822163582, 66.3305251300335, 62.9606531560421, 64.389368891716, 62.88572117686272, 68.4546947479248, 69.53592672944069, 67.2473931312561, 65.66824346780777, 80.80684393644333, 77.93517842888832, 75.3497363626957, 77.13760882616043, 77.14130222797394, 75.25895163416862, 74.02749851346016, 73.06442499160767, 72.23345518112183, 70.56542068719864, 77.32294768095016, 76.64354413747787, 83.57228994369507, 82.39816054701805, 73.5626770555973, 75.04421755671501, 70.06956249475479, 66.67760610580444, 62.82753109931946, 60.133882239460945, 59.39162626862526, 63.21086972951889, 68.67553889751434, 76.37985348701477, 77.01132640242577, 75.7099798321724, 82.52438217401505, 81.41782075166702, 79.01831030845642, 66.77259340882301, 66.75486356019974, 63.80817487835884, 66.58827289938927, 67.27652236819267, 70.21615102887154, 82.93229028582573, 87.33386009931564, 87.86223694682121, 78.6244386434555, 3.5585767356678843, 1.7938709165900946, 2.588244890794158, 4.792585456743836, 3.544834773056209, 0.7387598615605384, 0.638590349117294, 1.7273907526396215, 5.29326131567359, 2.442378792911768, 0.5912019044626504, 0.18594838067656383, 1.7539304285310209, 37.35416539013386, 78.86999666690826, 96.8060602247715, 91.4893551170826, 116.16730570793152, 83.77424910664558, 43.710357919335365, 28.348012156784534, 53.097374215722084, 52.941597774624825, 72.34010025858879, 82.37451061606407, 84.54367741942406, 5.372182130813599, 0.20940566493663937, 0.275265037198551, 0.20610479987226427, 0.15633538219844922, 0.10940527310594916, 0.12805173348169774, 0.1406668932759203, 0.11508017953019589, 0.10636255668941885, 0.14650486438767985, 0.10513191999052651, 0.0959506700746715], [0.10295392436091788, 0.047030952118802816, 0.023248293618962634, 0.02017969665757846, 0.04392005088448059, 0.081087515281979, 0.058097728397115134, 0.02687966487428639, 0.02090577683702577, 0.03296346498245839, 0.10195894181379117, 0.06258169189095497, 0.019611985226219986, 0.5648237792775035, 59.841639921069145, 73.98681789636612, 62.43242830038071, 57.34631381928921, 34.67043399810791, 53.68414252996445, 67.98158213496208, 82.25806206464767, 100.34943088889122, 37.68750250339508, 0.7489354186691344, 0.09032729096361436, 0.08558193934732117, 1.2715262454003096, 0.8556251437403262, 0.27200142794754356, 0.05748646588472184, 0.160845517530106, 0.2099593071034178, 0.24822794424835593, 0.06741293225786649, 0.9507452021352947, 2.054783678613603, 33.04612755775452, 115.97299173474312, 95.16013294458389, 103.2515099644661, 90.70033505558968, 95.2397994697094, 84.73428279161453, 86.67849406599998, 79.0288357436657, 85.24157837033272, 84.67676907777786, 90.60519576072693, 92.2749325633049, 89.19517502188683, 86.08713179826736, 79.64915245771408, 66.58483788371086, 67.03274264931679, 63.08768793940544, 62.60719232261181, 62.90462516248226, 65.26054814457893, 72.69525960087776, 80.76801761984825, 84.79757979512215, 81.85226663947105, 88.35972145199776, 89.3257512152195, 83.05381536483765, 89.60468664765358, 86.57934978604317, 76.16004288196564, 71.89737841486931, 68.03572922945023, 61.17648929357529, 58.72848965227604, 61.491556987166405, 65.51330298185349, 69.60452064871788, 73.37168410420418, 75.83759218454361, 79.31236132979393, 69.06917497515678, 60.56367717683315, 61.36634610593319, 63.28173592686653, 59.43399779498577, 61.03332057595253, 66.78390920162201, 69.13252517580986, 75.15922218561172, 75.87691247463226, 79.65948790311813, 72.0507001876831, 63.94109934568405, 58.19472849369049, 56.855938732624054, 61.88287138938904, 60.879580825567245, 62.45003655552864, 58.54864150285721, 58.61378140747547, 69.64716956019402, 66.93668380379677, 66.4540944993496, 71.21220678091049, 80.03631368279457, 70.15481472015381, 66.34529873728752, 69.07514825463295, 67.99691051244736, 71.60031795501709, 69.43289905786514, 76.0036812722683, 70.91299563646317, 68.42826336622238, 61.747081875801086, 57.51428000628948, 56.05039335787296, 56.71394795179367, 55.84105119109154, 56.907528564333916, 68.27019184827805, 70.61136022210121, 73.11154246330261, 69.56472158432007, 74.36657711863518, 74.73926872015, 75.26914268732071, 70.03056138753891, 63.16657170653343, 60.39763368666172, 56.21545650064945, 61.80113397538662, 58.085244968533516, 62.429871037602425, 64.80461820960045, 76.30845531821251, 72.31835782527924, 81.73470094799995, 43.78008417785168, 0.05230991533608176, 0.660540999379009, 0.6995927507523447, 0.5379161168821156, 0.18954847968416288, 0.6586550537031144, 0.4394845064962283, 1.4520107419230044, 0.16654734907206148, 0.13384170248173177, 0.015675398317398503, 0.11455937739810906, 3.7957792449742556, 36.022025272250175, 77.1362940967083, 79.55592066049576, 94.88965585827827, 94.68300014734268, 68.81363868713379, 35.93572050333023, 53.31007540225983, 49.84849914908409, 35.33054977655411, 59.46632646024227, 60.581635013222694, 20.89180525392294, 0.5304945807438344, 0.3192530502565205, 0.1636728923767805, 0.13286202301969752, 0.037527420863625593, 0.014901803988323081, 0.010224591733276611, 0.07281693993718363, 0.027533509964996483, 0.011035425177396974, 0.03787137662584428, 0.01614183627680177, 0.050509650609456, 0.04985205581760965, 0.03085723874391988, 0.04600416483299341, 0.01976216251932783, 0.05146926239831373, 0.031116561840462964, 0.01416943689036998, 0.08923024084651843, 0.03991229757957626, 0.07646253259736113, 0.02413720099866623, 0.028848851688962895, 0.6064978649374098, 71.3796029984951, 81.13655224442482, 69.74126011133194, 64.65283915400505, 40.73887936770916, 44.732674062252045, 55.22597439587116, 93.8590295612812, 108.38398575782776, 47.83418923616409, 1.0311655118130147, 0.08386449830140918, 0.5289200996048748, 1.719003771431744, 0.926658947719261, 1.095096725039184, 1.2330729025416076, 0.062018672688282095, 0.32698079652618617, 0.4010376054793596, 0.20167731010587886, 2.7217089291661978, 3.575929217040539, 37.054452672600746, 118.44627141952515, 93.73015567660332, 106.04040831327438, 94.74251255393028, 97.85063937306404, 89.6225380897522, 91.06885448098183, 82.5850497186184, 89.26408812403679, 88.82558405399323, 93.13541918992996, 96.35444685816765, 93.90309199690819, 89.59821939468384, 82.33300924301147, 68.53724911808968, 69.80231523513794, 64.63498011231422, 65.26508510112762, 66.40800297260284, 72.48474329710007, 76.45876005291939, 84.54085797071457, 85.17505913972855, 88.67122113704681, 92.15020805597305, 91.6015174984932, 84.96634393930435, 90.28809517621994, 91.21651455760002, 77.01878160238266, 76.993178576231, 71.9338108599186, 64.74422425031662, 62.95824408531189, 65.4011482000351, 69.11126151680946, 73.68339657783508, 75.91386169195175, 81.14203914999962, 81.6067998111248, 70.6083507835865, 65.46994730830193, 65.47652095556259, 67.15258821845055, 64.59452748298645, 63.99007871747017, 67.92416721582413, 72.73286998271942, 79.07408371567726, 77.62373194098473, 83.57688009738922, 74.73823517560959, 63.9323066174984, 62.70720675587654, 59.213009253144264, 66.76144480705261, 66.29558220505714, 67.03469574451447, 65.05826979875565, 61.828614100813866, 71.27936437726021, 73.15609127283096, 72.8512716293335, 74.33247774839401, 85.57176545262337, 72.68530413508415, 71.65472343564034, 73.76514539122581, 72.70518466830254, 75.52797719836235, 72.44963318109512, 78.21417465806007, 73.45284014940262, 71.77205353975296, 64.31771993637085, 62.26279400289059, 58.81126821041107, 59.368401914834976, 58.114305809140205, 61.782761961221695, 73.79987552762032, 74.1786240041256, 75.44169142842293, 73.39501485228539, 78.72928261756897, 76.30641862750053, 80.49763932824135, 77.45162397623062, 67.86405444145203, 63.06420899927616, 59.86006513237953, 64.16423857212067, 62.05264247953892, 64.77733567357063, 68.27720627188683, 80.80049067735672, 76.56016901135445, 86.63684070110321, 52.62094438076019, 0.0959557834721636, 0.20061838411493227, 0.4883119458099827, 0.8729025791399181, 0.4700170556316152, 0.1168115803739056, 0.1869176106993109, 1.2447378016076982, 1.677426639944315, 0.592996358172968, 0.21753550681751221, 0.427258187555708, 3.4110719757154584, 42.774392142891884, 85.46114578843117, 88.44193384051323, 91.26021221280098, 67.05406710505486, 48.85278917849064, 31.77756752818823, 58.0489569157362, 54.92327883839607, 48.65936055779457, 67.1267420053482, 71.81654155254364, 24.28311947733164, 0.5168887577019632, 0.247389703290537, 0.15385135455289856, 0.0696290000632871, 0.08047466457355767, 0.06847338707302697, 0.06596891325898468, 0.015312231134885224, 0.01017767222947441, 0.01285162010390195, 0.05311902328685392, 0.0269695408132975, 0.24672445695614442, 0.10295735308318399, 0.17668505664914846, 0.1565556219429709, 0.21491759573109448, 0.11488480915431865, 0.15595333941746503, 0.21314778132364154, 0.17309804912656546, 0.1058188518800307, 0.24652612541103736, 0.11658513627480716, 0.1302767070592381, 0.8736129628960043, 82.64557287096977, 95.05416423082352, 79.43134814500809, 77.92304188013077, 48.485356494784355, 75.36693423986435, 101.18991538882256, 101.28734976053238, 121.20509058237076, 60.52831247448921, 2.216409193351865, 0.21763078373624012, 0.21370541624492034, 2.9250877909362316, 2.478899583220482, 1.4076959760859609, 0.7686996425036341, 0.19387539359740913, 0.3187604126287624, 0.8556773909367621, 0.7307009096257389, 2.6042710058391094, 6.4255331084132195, 38.78782086074352, 124.9413312971592, 101.9331707060337, 111.96668431162834, 99.82355430722237, 106.49436235427856, 92.6572148501873, 96.24794617295265, 87.62779712677002, 98.07515412569046, 92.93846815824509, 97.25702002644539, 100.9001961350441, 97.53046855330467, 93.9992344379425, 87.42261573672295, 74.50914546847343, 73.00650849938393, 68.1726586818695, 69.92323234677315, 70.47016739845276, 74.91363376379013, 79.42156746983528, 88.17274868488312, 91.22358217835426, 94.29479777812958, 96.95109084248543, 93.59845474362373, 92.33886793255806, 86.22495040297508, 91.88048332929611, 83.15091535449028, 76.71185687184334, 74.84582260251045, 66.84017658233643, 65.72342410683632, 66.74709677696228, 74.11989435553551, 76.23530164361, 81.88378974795341, 83.81766557693481, 87.10777223110199, 76.86970040202141, 66.224624812603, 68.400669246912, 73.60283330082893, 69.95112285017967, 66.67930841445923, 68.6666701734066, 74.08201038837433, 83.97207409143448, 81.57109692692757, 87.4891197681427, 76.3542352616787, 64.45656448602676, 63.58334854245186, 61.056305542588234, 71.33524417877197, 73.63986611366272, 69.91934135556221, 70.4239846765995, 68.53460446000099, 76.9721657037735, 74.80130419135094, 77.69167989492416, 81.08110561966896, 84.2110888659954, 77.66115233302116, 74.96785685420036, 76.26057028770447, 73.09400260448456, 78.19175586104393, 74.00375738739967, 81.51997447013855, 77.0207878947258, 77.23875939846039, 67.29562014341354, 65.60174703598022, 60.23703150451183, 61.920702159404755, 61.644023805856705, 62.635846585035324, 75.47626957297325, 77.15818092226982, 80.2715514600277, 76.06790542602539, 81.65007188916206, 78.90553995966911, 83.10216397047043, 82.41889983415604, 69.29534643888474, 66.87423795461655, 63.35211955010891, 68.93831759691238, 63.44054080545902, 70.44959530234337, 72.28596836328506, 86.53190553188324, 81.90010607242584, 95.31042248010635, 53.3796002715826, 0.17487449833424762, 2.581287701614201, 2.2369976760819554, 1.9621061766520143, 0.8099935110658407, 1.0424788109958172, 1.2628896650858223, 4.320739600807428, 3.8074353570118546, 1.3728593266569078, 0.15367053769296035, 0.638954951427877, 7.131996424868703, 55.53077504038811, 94.24659356474876, 92.93549671769142, 109.979178160429, 117.00676426291466, 88.69090408086777, 49.531615152955055, 67.19193890690804, 63.963054567575455, 54.89079438149929, 76.30670741200447, 81.3935324549675, 27.387752383947372, 0.6550154427532107, 0.574882848886773, 0.2798491943394765, 0.18094424216542393, 0.16015738336136565, 0.16423361463239416, 0.08524386881617829, 0.2013911379617639, 0.14498620759695768, 0.06182419660035521, 0.16697417304385453, 0.18234314600704238], [0.061246067270985804, 0.016128381139424164, 0.02818915105308406, 0.011537763602973428, 0.016743254200264346, 0.04823118673812132, 0.00949486946410616, 0.03543475366313942, 0.029387463509920053, 0.03981286834459752, 0.009426281103515066, 0.017897069337777793, 0.0671001170121599, 1.3325269846245646, 66.46364718675613, 67.75522828102112, 68.74818339943886, 51.493985652923584, 37.60152071714401, 43.682478815317154, 57.672674506902695, 91.95790797472, 75.55861875414848, 12.396487109363079, 0.19298959581647068, 0.06141802288766485, 0.22044102981453761, 1.7079657199792564, 0.7292018900625408, 0.42544081632513553, 0.7146832253783941, 0.029069646188872866, 0.09062206459930167, 0.2939782611792907, 0.736828496446833, 4.838447570800781, 3.7211075518280268, 88.29764798283577, 98.42503935098648, 93.4202367067337, 94.25881370902061, 87.27457568049431, 82.2767798602581, 82.59978532791138, 74.149821549654, 71.84828504920006, 75.27370244264603, 82.65673667192459, 90.12193009257317, 91.51227548718452, 92.22816467285156, 88.30609872937202, 83.36519345641136, 68.14609050750732, 62.36479952931404, 64.7005569934845, 60.08936382830143, 66.96332037448883, 72.33501613140106, 78.37872862815857, 80.48981174826622, 82.83363237977028, 90.6659696996212, 86.54805466532707, 78.73799934983253, 80.60465678572655, 72.29138687252998, 87.76563853025436, 80.22590830922127, 77.53312960267067, 73.44169914722443, 66.72821179032326, 69.05969068408012, 69.75719645619392, 69.48358073830605, 71.97766050696373, 73.69225010275841, 77.09214806556702, 70.81414014101028, 63.386245518922806, 60.29984213411808, 62.42838531732559, 59.686532244086266, 61.84493042528629, 67.92544394731522, 65.35356715321541, 74.48741063475609, 70.75265944004059, 72.43320286273956, 70.3675577044487, 71.84717550873756, 70.90259179472923, 70.53869292140007, 64.28170546889305, 59.87569749355316, 60.08238360285759, 60.99663354456425, 62.479291185736656, 62.62363784015179, 61.28390192985535, 66.80973261594772, 66.20159804821014, 65.46475678682327, 67.97598883509636, 79.78744223713875, 70.86745887994766, 71.99309527873993, 72.28474482893944, 72.86349177360535, 70.97677141427994, 70.76408922672272, 69.51092407107353, 65.62613412737846, 59.16069746017456, 54.96623553335667, 54.20541375875473, 56.49801313877106, 55.77209249138832, 68.10553908348083, 74.43261757493019, 73.9025916159153, 74.10395801067352, 77.77529060840607, 74.86709386110306, 73.57893258333206, 71.54009878635406, 69.61804032325745, 69.68224167823792, 63.059865832328796, 57.93449565768242, 56.390976682305336, 61.347210332751274, 58.89336660504341, 64.87642675638199, 70.38965731859207, 80.43280720710754, 74.35040518641472, 81.53052270412445, 16.43577106297016, 0.6354879937134683, 0.2818315598415211, 0.9600964409764856, 0.15802513371454552, 0.02134954589564586, 0.1638931766501628, 1.6112934448756278, 1.1017420934513211, 0.5081675725523382, 0.22673830128042027, 0.07367693324340507, 0.046035097548156045, 14.614932518452406, 47.960091680288315, 82.00315654277802, 82.6196962594986, 57.76941351592541, 71.48434817790985, 65.60838907957077, 43.2710824906826, 49.11220125854015, 32.744176760315895, 48.75639595091343, 63.321664184331894, 31.312898062169552, 0.17508768767584115, 0.14325131865916774, 0.17241092427866533, 0.03621822041168343, 0.03209459187928587, 0.0545079378207447, 0.02939773112302646, 0.033466292297816835, 0.03142258457955904, 0.0399454641592456, 0.0012095789543309365, 0.041186513190041296, 0.10997717952704988, 0.02650385427841684, 0.025030928627529647, 0.0487035971309524, 0.02535369792894926, 0.03936708249966614, 0.025775176582101267, 0.034404422622174025, 0.03392082064237911, 0.04240281159582082, 0.0700885675905738, 0.040293089841725305, 0.17277105886023492, 1.6653236956335604, 76.23799189925194, 74.48545753955841, 77.06456914544106, 47.621157467365265, 33.32584574818611, 34.422641694545746, 58.56434606015682, 103.24629664421082, 86.9459693133831, 15.949989929795265, 0.24525708256987855, 0.5707923090085387, 1.332386035937816, 3.3837227057665586, 0.9270969335921109, 1.0237740771844983, 1.0937190614640713, 0.7957627403084189, 0.20958499750122428, 0.3172172204358503, 1.738299373537302, 5.4124922677874565, 4.68149034306407, 95.18351688981056, 101.98899731040001, 98.32584947347641, 95.13327598571777, 91.66732996702194, 84.36374947428703, 85.46653389930725, 76.81019559502602, 74.44058954715729, 76.73970177769661, 88.83183851838112, 91.69686958193779, 95.75706571340561, 93.57560276985168, 92.17033177614212, 82.84524455666542, 71.8382079899311, 66.39668717980385, 66.64003372192383, 62.99324780702591, 67.72367477416992, 73.75384479761124, 81.64960071444511, 83.17958861589432, 85.94838604331017, 92.26491630077362, 83.43207746744156, 77.43491247296333, 84.84848946332932, 75.99808797240257, 91.59928321838379, 83.4274797141552, 78.97414147853851, 78.5805281996727, 71.34921222925186, 72.03949838876724, 71.91779091954231, 74.38647285103798, 75.71044340729713, 78.22858348488808, 79.97867077589035, 74.18973460793495, 67.16368362307549, 64.51324984431267, 67.2072596848011, 63.18058915436268, 67.90243998169899, 72.26794213056564, 65.61959847807884, 74.98269125819206, 74.05123203992844, 73.56973707675934, 70.97548708319664, 72.94339388608932, 72.18493938446045, 72.02718704938889, 67.67500698566437, 61.54614865779877, 64.08574998378754, 64.04822319746017, 67.01669231057167, 67.39272773265839, 65.13070911169052, 68.90987992286682, 72.4293802678585, 69.19237196445465, 70.206598341465, 81.61427021026611, 73.88960391283035, 77.02322736382484, 74.51916173100471, 72.59957313537598, 74.42622631788254, 74.46448266506195, 72.38500624895096, 66.61397472023964, 62.045411467552185, 57.56027653813362, 57.203114703297615, 58.27370345592499, 59.31759104132652, 71.7787791788578, 77.69275143742561, 77.62005373835564, 76.89664095640182, 77.97918766736984, 77.42254793643951, 73.37299883365631, 71.80641129612923, 72.8602847456932, 72.1718680858612, 67.0403878390789, 62.447904869914055, 57.500330954790115, 63.68108689785004, 61.61672607064247, 68.09855505824089, 75.27936413884163, 85.84323808550835, 77.9060035943985, 88.79064872860909, 22.6746391877532, 0.20810309186344966, 0.09229257222614251, 0.6197140307631344, 0.7152454764582217, 0.15547827584668994, 0.2725719317095354, 1.2368244887329638, 1.7015999928116798, 1.6446016263216734, 0.765135136898607, 0.28641227341722697, 0.1316697776201181, 15.977413058280945, 56.1486940830946, 90.94498872756958, 92.93724462389946, 64.6828043460846, 65.8257070183754, 52.44292393326759, 46.33697837591171, 52.74661123752594, 35.206961408257484, 55.45791395008564, 70.92263951897621, 38.394796550273895, 0.1766628961195238, 0.10782058743643574, 0.04498702546698041, 0.04991216606867965, 0.0655434251530096, 0.10215614529442973, 0.05313434863637667, 0.012075559061486274, 0.03435736674873624, 0.05342010146705434, 0.03398444125195965, 0.019937376164307352, 0.21074981312267482, 0.09747950913151726, 0.12446472595911473, 0.08963624757598154, 0.1768518766039051, 0.2080566037329845, 0.0635425430664327, 0.1165524595126044, 0.05442114736069925, 0.12929514254210517, 0.12830054591177031, 0.14641760266385972, 0.2128369253478013, 1.9274451490491629, 89.35744151473045, 87.2425889968872, 89.54512864351273, 70.13392344117165, 55.06378389894962, 61.84460364282131, 79.86057311296463, 108.68647992610931, 102.76025712490082, 20.783503465354443, 0.5883134657051414, 0.3806427342351526, 1.2274910020641983, 5.188554134219885, 2.6791298389434814, 0.9743785683531314, 1.1234793020412326, 2.059251763857901, 0.20531420479528606, 0.6045999261550605, 1.5758648584596813, 9.392666593194008, 5.523945037275553, 100.5978387594223, 105.40306091308594, 102.7313406765461, 100.69035619497299, 97.10839480161667, 87.8533910214901, 90.80570340156555, 81.14051163196564, 80.04284933209419, 81.07173532247543, 92.30124235153198, 97.88802176713943, 98.70238646864891, 94.88416895270348, 96.71994924545288, 86.95687472820282, 74.39919456839561, 66.93835571408272, 71.20969131588936, 65.70923566818237, 72.84848257899284, 78.27029764652252, 86.67245239019394, 85.67462593317032, 88.7743704020977, 93.42170342803001, 85.07397696375847, 81.73957988619804, 88.64431098103523, 82.37638771533966, 89.67141106724739, 87.22814977169037, 84.57500293850899, 81.50739714503288, 74.4236272573471, 75.41504725813866, 75.89062973856926, 76.97425559163094, 79.16273295879364, 81.40483304858208, 84.73608389496803, 79.69586715102196, 70.78475251793861, 67.66172289848328, 73.4932091832161, 66.73505902290344, 68.66348594427109, 72.4079342186451, 67.47828394174576, 79.37237530946732, 78.04413378238678, 77.81332656741142, 76.87452614307404, 75.20371779799461, 73.23193520307541, 72.59389623999596, 69.39459711313248, 66.05340600013733, 69.17248383164406, 70.45345589518547, 72.91290432214737, 73.58783170580864, 70.03277286887169, 74.283756762743, 76.40781998634338, 74.5074887573719, 74.8348031938076, 81.41846671700478, 76.16331830620766, 77.15642541646957, 78.32046255469322, 78.67838054895401, 76.72547534108162, 75.94536200165749, 77.68302395939827, 70.83569258451462, 65.75010627508163, 60.16518495976925, 61.76267243921757, 61.17723785340786, 62.54365973174572, 73.66020262241364, 81.00565686821938, 80.09150192141533, 81.60380557179451, 82.18194454908371, 80.14625698328018, 79.20550346374512, 76.59613028168678, 75.85539042949677, 75.46819880604744, 68.24651151895523, 64.05406728386879, 60.91356620192528, 66.74388214945793, 65.13054952025414, 72.59584173560143, 79.42618042230606, 92.32593342661858, 84.85807254910469, 96.44843101501465, 25.10069690644741, 0.8639858826063573, 1.6251008352264762, 2.3897492419928312, 1.5583928022533655, 0.21454474073834717, 0.649937252746895, 3.668173304758966, 3.197019724175334, 2.601035716943443, 0.7796317746397108, 0.14768483466468751, 0.40595575876068324, 24.288750775158405, 68.50178182125092, 98.39535534381866, 100.76973393559456, 82.50740468502045, 98.37498843669891, 90.20073786377907, 57.051875218749046, 60.503617599606514, 46.39039970934391, 66.272654235363, 83.92233476042747, 44.069689437747, 0.36010326293762773, 0.37310022802557796, 0.23184276331448928, 0.20943297597113997, 0.11543849584995769, 0.1714078671648167, 0.1886082676355727, 0.12489509739680216, 0.12107363800168969, 0.12743143161060289, 0.1278328147600405, 0.13770625839242712], [0.049300833052257076, 0.05222212668741122, 0.056956995467771776, 0.03428774216445163, 0.08860762347467244, 0.01515109603133169, 0.056486395915271714, 0.02153089710191125, 0.06673099502222613, 0.03879454525304027, 0.06860180830699392, 0.13218239386333153, 0.12666755384998396, 2.685514921322465, 65.86329460144043, 69.49736639857292, 61.43683612346649, 49.03305530548096, 45.82156263291836, 45.643325597047806, 67.85491213202477, 94.59634959697723, 46.273806765675545, 1.704734112136066, 0.0411783013259992, 0.15879937185673043, 1.6789818252436817, 1.2602021405473351, 0.12523557990789413, 1.5029440401121974, 2.4675453174859285, 0.5622227594722062, 0.6854293076321483, 1.0429385863244534, 1.8965076841413975, 1.163610729854554, 36.099579110741615, 115.01415118575096, 89.92950841784477, 97.0411080121994, 82.32118427753448, 88.43121841549873, 80.18955945968628, 79.65096116065979, 71.48026719689369, 71.52559116482735, 72.49855935573578, 82.9830327630043, 85.37321090698242, 91.98164910078049, 89.64914426207542, 88.93403023481369, 84.76167932152748, 75.28677374124527, 61.4825514703989, 63.82025063037872, 60.574320405721664, 65.21636411547661, 69.40300986170769, 77.8619259595871, 77.04713568091393, 77.79061898589134, 80.77994138002396, 70.52380532026291, 73.11049371957779, 81.05657413601875, 79.75974932312965, 70.56928887963295, 80.42407527565956, 75.80844014883041, 74.33767586946487, 70.02608522772789, 74.75344195961952, 71.20396122336388, 77.05430209636688, 76.34965270757675, 75.16120567917824, 72.0325219631195, 62.8386265039444, 67.30676114559174, 63.72038058936596, 62.37455740571022, 63.889642506837845, 74.63180288672447, 68.40858042240143, 67.46265158057213, 73.25358644127846, 69.63925838470459, 75.27550354599953, 70.3474947810173, 70.96846505999565, 72.34153658151627, 69.92294356226921, 65.42124152183533, 63.77960041165352, 63.8404655456543, 65.43859139084816, 61.954907923936844, 62.06169359385967, 58.67045536637306, 63.20942580699921, 62.01336778700352, 69.2416325211525, 57.77337670326233, 63.00454840064049, 66.71550527215004, 61.18339732289314, 61.38619244098663, 64.58533957600594, 67.52390429377556, 69.47185456752777, 65.31765908002853, 59.67933543026447, 56.99467308819294, 56.577109694480896, 54.51941750943661, 54.432763159275055, 55.59537157416344, 71.82757616043091, 74.3668507039547, 71.14422082901001, 76.71453192830086, 74.08166840672493, 73.09277147054672, 67.28247284889221, 58.76800373196602, 68.59055265784264, 72.49118775129318, 68.17499935626984, 63.31879913806915, 59.947715029120445, 58.7997168302536, 58.34421627223492, 63.39154623448849, 69.13406029343605, 75.5422492325306, 73.92176538705826, 74.4306568801403, 60.29372826218605, 4.238940440118313, 0.550653567770496, 0.5494753341190517, 0.3169810393592343, 0.257200212799944, 0.05780695493740495, 0.5962005956098437, 1.9859804143197834, 0.33718651451636106, 0.515588455600664, 0.2623950981069356, 0.165236315515358, 2.8924157191067934, 23.41889575123787, 68.23054477572441, 77.33984157443047, 78.93789142370224, 95.59675991535187, 68.1313169002533, 54.47375535964966, 30.27938771992922, 47.606266066432, 56.16710029542446, 63.92434984445572, 37.29972191154957, 0.10092203534441069, 0.07405150259728543, 0.059941724175587296, 0.09599328419426456, 0.029581188173324335, 0.049579394471948035, 0.03058274058275856, 0.02944652547739679, 0.03359109556186013, 0.014285813995229546, 0.044959740407648496, 0.050235909438924864, 0.12804659781977534, 0.020303883939050138, 0.06423609491321258, 0.012731033166346606, 0.022340335308399517, 0.050304224132560194, 0.06300657143583521, 0.03424233014811762, 0.07732834434136748, 0.007519289974879939, 0.039048018370522186, 0.033739335849531926, 0.23265358933713287, 3.2711625332012773, 79.36643242835999, 76.3010685145855, 72.92406052350998, 62.854730039834976, 60.43255761265755, 38.56910079717636, 76.38315930962563, 108.69852527976036, 55.76139606535435, 2.528151827864349, 0.0713726389221847, 1.0948006971739233, 2.447768566198647, 2.0709589356556535, 0.5082138231955469, 2.1534802950918674, 1.6483076149597764, 2.1830818941816688, 5.471394332125783, 1.9348916807211936, 2.9502431536093354, 0.24207309092162177, 42.28065423667431, 116.68470874428749, 94.72750335931778, 100.30517846345901, 86.89230099320412, 93.42785149812698, 83.15190330147743, 82.53897339105606, 75.88055267930031, 74.72260281443596, 73.66769582033157, 87.30133384466171, 88.90862479805946, 93.37917611002922, 93.34182411432266, 93.00076961517334, 86.7694079875946, 78.6815495789051, 64.05219778418541, 65.7940623164177, 64.26572352647781, 68.1612440943718, 72.81249091029167, 80.8697609603405, 77.4441459774971, 78.90648990869522, 78.44216242432594, 76.09639629721642, 77.39781886339188, 83.6833655834198, 81.24939858913422, 78.14254850149155, 85.4110948741436, 79.75937694311142, 78.43424364924431, 76.15082457661629, 78.72286856174469, 76.22384905815125, 80.01844704151154, 81.49469822645187, 78.0004133284092, 72.25936219096184, 67.93689653277397, 70.37651762366295, 68.61875474452972, 70.09948968887329, 69.52309101819992, 77.32127577066422, 69.06466081738472, 69.79095384478569, 77.18021973967552, 72.80117511749268, 77.22564250230789, 75.13435631990433, 75.01112893223763, 73.62472012639046, 70.09629786014557, 66.35571777820587, 66.21054276823997, 68.3297498524189, 69.45669338107109, 66.53020441532135, 66.65992185473442, 63.751694709062576, 67.16932252049446, 66.94629728794098, 72.7104739844799, 66.2934011220932, 67.95214131474495, 67.66102373600006, 60.4563557356596, 61.45686484873295, 66.92649275064468, 70.55400609970093, 73.0283497273922, 68.36520195007324, 64.1542375087738, 59.73334953188896, 58.356151431798935, 57.09655322134495, 56.801521852612495, 58.79125088453293, 74.59257379174232, 76.6592600941658, 74.47595804929733, 78.80651727318764, 77.44030818343163, 76.11873909831047, 70.28440296649933, 64.12649139761925, 70.3277662396431, 77.4944780766964, 73.04234057664871, 68.41043472290039, 62.597635835409164, 61.7053335160017, 62.41179920732975, 68.74262049794197, 72.74440616369247, 80.01602277159691, 79.40092697739601, 81.6599589586258, 70.0321877002716, 8.260223809629679, 0.6293670565355569, 0.142988687439356, 0.5784922395832837, 0.3381545125739649, 0.5457035021390766, 0.8444559993222356, 2.374984659254551, 0.6193554843775928, 1.643320620059967, 1.4577948627993464, 0.5558957427274436, 1.9927885802462697, 31.01560391485691, 74.15831789374352, 89.26395133137703, 86.3477674126625, 103.13612535595894, 63.83190840482712, 59.3330068141222, 33.62199425697327, 44.23857897520065, 62.174133360385895, 72.4307481944561, 43.77482146024704, 0.05156347433512565, 0.09504595494945534, 0.03527259068505373, 0.06728757609380409, 0.04521082009887323, 0.012868571684521157, 0.03191591611539479, 0.03522978731780313, 0.030143639633024577, 0.010550228507781867, 0.018407572315481957, 0.03391964804905001, 0.17204146832227707, 0.12488601350924, 0.14379322004970163, 0.09733045619213954, 0.15418236725963652, 0.16250847751507536, 0.09318231081124395, 0.20889187610009685, 0.27135513606481254, 0.1364920157357119, 0.2540231676539406, 0.32908517110627145, 0.3436906967544928, 3.6363200889900327, 90.0574779510498, 88.52815881371498, 81.67473256587982, 69.72723126411438, 66.56838476657867, 66.12641528248787, 96.43551170825958, 114.01282131671906, 72.72430524230003, 3.8760204892605543, 0.14228848594939336, 0.656255423091352, 5.515833422541618, 5.961873913183808, 1.8882582080550492, 5.813150843605399, 6.6934909299016, 3.5406894329935312, 4.355927137658, 3.0294159427285194, 8.691207133233547, 1.3002088875509799, 43.93508546054363, 121.92224130034447, 101.28236442804337, 106.18920832872391, 92.39903390407562, 99.151461571455, 86.06592133641243, 87.17884361743927, 79.14570227265358, 78.88483867049217, 80.65214663743973, 91.79887890815735, 90.98414182662964, 98.45984548330307, 96.38907819986343, 95.33569112420082, 90.71663618087769, 84.04531136155128, 66.54399007558823, 69.53890576958656, 66.03082001209259, 73.3856749534607, 76.5084157884121, 84.35149893164635, 82.86588504910469, 85.60942903161049, 82.95017212629318, 81.02780967950821, 82.2455683350563, 87.1350471675396, 86.71523049473763, 76.4479610323906, 86.72912254929543, 83.38883578777313, 79.03024926781654, 79.10483166575432, 82.32669398188591, 79.46798577904701, 83.40162590146065, 85.95910906791687, 81.20183274149895, 76.86817288398743, 71.60806193947792, 77.74332672357559, 73.15105274319649, 75.6685620546341, 71.23586431145668, 80.3809703886509, 70.66170752048492, 72.27154433727264, 82.47994735836983, 74.7331054508686, 82.32774272561073, 79.27728921175003, 76.30112931132317, 77.96426206827164, 71.7675469815731, 69.43271666765213, 67.84042730927467, 72.07100629806519, 70.7099649310112, 71.64710864424706, 69.87600088119507, 69.39788773655891, 72.61053174734116, 69.85132500529289, 75.52979350090027, 70.31534850597382, 72.08562031388283, 70.95141917467117, 62.997951954603195, 64.09894287586212, 66.47989511489868, 73.21534529328346, 75.92614263296127, 73.34424197673798, 67.52458065748215, 65.53268954157829, 61.68120101094246, 58.95067512989044, 59.8113289475441, 62.85414107143879, 78.20582270622253, 80.20178720355034, 76.50428920984268, 82.33819216489792, 81.12662717700005, 76.87661603093147, 71.18915721774101, 66.65079474449158, 72.8114801645279, 82.87975430488586, 75.55353462696075, 70.4879504442215, 66.08413115143776, 64.31695237755775, 64.66705039143562, 70.8391959965229, 76.44229173660278, 84.0012489259243, 85.8084699511528, 84.14236575365067, 74.04506877064705, 7.977997753769159, 0.7915801147464663, 2.586704548448324, 1.2336146109737456, 0.7792221684940159, 0.7512797741219401, 0.7237292337231338, 4.3553144205361605, 4.517363850027323, 1.6612332151271403, 0.7210298941936344, 0.3996323933824897, 4.534099576994777, 43.552324399352074, 80.6368638575077, 95.53439766168594, 96.04361593723297, 108.55024203658104, 94.15710836648941, 67.53117710351944, 39.82860021293163, 70.60649648308754, 70.94627425074577, 87.65096828341484, 51.56712792813778, 0.17103651131037623, 0.22340074443491176, 0.11980411276454106, 0.17531010933453217, 0.20489682094193995, 0.17578968516318128, 0.18969733966514468, 0.14113728131633252, 0.12331488687777892, 0.11703310403390788, 0.08089114300673828, 0.13064539118204266], [0.04354662443802226, 0.04831170605029911, 0.04398547862365376, 0.02498643872968387, 0.14062396745430306, 0.051957940668216906, 0.010548290574661223, 0.07878832693677396, 0.0372557948139729, 0.006966481796553126, 0.051418566290521994, 0.013317039465619018, 0.05801283041364513, 0.797771941870451, 48.40899959206581, 68.56219097971916, 59.24444116652012, 21.926086954772472, 24.071161150932312, 49.65087175369263, 80.20589858293533, 78.73039215803146, 16.37347910553217, 0.35829488653689623, 0.08588717726524919, 2.5044862227514386, 1.5911948983557522, 2.67324585467577, 0.4988521942868829, 1.9661884638480842, 1.077456884086132, 7.573284320533276, 16.993220150470734, 0.873019244754687, 0.8541998045984656, 17.82345660030842, 108.31194162368774, 97.36347511410713, 93.81287723779678, 86.99140727519989, 85.46765863895416, 82.50681191682816, 84.95916232466698, 81.76221907138824, 75.66670015454292, 65.12146800756454, 65.96261367201805, 74.24239978194237, 86.55461311340332, 86.45096987485886, 91.2186348438263, 89.23594683408737, 84.65400069952011, 78.29848453402519, 71.384656727314, 61.17147736251354, 63.30113768577576, 61.603916957974434, 69.28324028849602, 68.96832078695297, 71.81272655725479, 67.80119821429253, 69.22913119196892, 70.29539957642555, 72.02914774417877, 75.65326407551765, 80.85602089762688, 76.6056601703167, 73.70489582419395, 71.66093990206718, 77.16242909431458, 76.51590898633003, 76.20817869901657, 79.15118917822838, 79.02709543704987, 76.59878253936768, 69.95993837714195, 64.99157577753067, 65.78337728977203, 62.03081265091896, 65.46370044350624, 64.64906975626945, 75.86295202374458, 73.34222048521042, 68.88091027736664, 69.38439086079597, 72.39754557609558, 70.96444487571716, 71.46862462162971, 71.4193944633007, 73.42464566230774, 67.4398984014988, 67.75171726942062, 67.77786746621132, 68.49170476198196, 65.12166559696198, 61.90344728529453, 63.585867807269096, 67.25259125232697, 61.01522594690323, 58.76787453889847, 59.909846261143684, 61.78841985762119, 69.7341088950634, 67.57242009043694, 68.44051390886307, 64.8263530433178, 53.699448108673096, 55.957001969218254, 76.37735322117805, 68.79901707172394, 64.3911699950695, 59.35702532529831, 55.82912743091583, 54.665280282497406, 57.41838075220585, 54.288838282227516, 53.22199612855911, 67.21155345439911, 73.16014185547829, 71.54897511005402, 74.10768941044807, 70.45875281095505, 72.611945271492, 74.34272959828377, 74.09138828516006, 74.47451412677765, 73.28248009085655, 71.11741706728935, 67.35333904623985, 62.23870329558849, 61.01667366921902, 61.68079063296318, 66.13542079925537, 65.14498874545097, 73.31103175878525, 75.0107641518116, 74.00538370013237, 78.7447401881218, 45.0129584223032, 1.4800392254255712, 0.5092202941887081, 0.43317556846886873, 0.024907457518565934, 0.08758401629165746, 0.026857541452045552, 1.8902705563232303, 0.5252941441722214, 2.3902208916842937, 1.1347467661835253, 0.12296733912080526, 0.05127801836351864, 7.481758631765842, 49.35297913849354, 78.20725902915001, 106.33975625038147, 93.40834334492683, 92.83259063959122, 23.066943436861038, 20.542372204363346, 50.220263600349426, 50.402338430285454, 65.93652427196503, 36.093799620866776, 0.04516085500654299, 0.05873043897736352, 0.03863863857986871, 0.10823406017152593, 0.0713492241629865, 0.01673838014539797, 0.07108996229362674, 0.03233988652937114, 0.010734401730587706, 0.0563666874950286, 0.057023747940547764, 0.05631404696032405, 0.023543050556327216, 0.04366322697023861, 0.02331725954718422, 0.059150160595891066, 0.050493126691435464, 0.057899463645298965, 0.018672383594093844, 0.025742134312167764, 0.09465168899623677, 0.020821687794523314, 0.052701097665703855, 0.03918984279152937, 0.05190782714635134, 1.1536934995092452, 60.474951937794685, 77.03161731362343, 68.61440017819405, 34.59272436797619, 32.2867801040411, 41.41976863145828, 92.28302612900734, 91.51098355650902, 20.25891311466694, 0.1558267290238291, 0.08030540295294486, 5.3689029067754745, 2.696082629263401, 2.569814929738641, 0.0989099097205326, 1.0822154162451625, 1.4868520223535597, 9.490678533911705, 17.172752916812897, 0.4592022718861699, 0.5442493676673621, 23.76265000551939, 112.59926676750183, 102.15023025870323, 98.40298533439636, 91.62145122885704, 91.4793312549591, 87.30468526482582, 90.82697466015816, 86.76946118474007, 79.265426248312, 68.90511497855186, 70.04012167453766, 76.68377637863159, 90.08615881204605, 89.2357948422432, 94.84209761023521, 90.1734933257103, 88.58299747109413, 84.3075580894947, 74.06343698501587, 63.7138107419014, 65.6951916217804, 63.62464852631092, 71.12527504563332, 71.4559181034565, 74.47252303361893, 71.30572736263275, 71.18667975068092, 72.56789043545723, 72.83872470259666, 80.04565358161926, 82.5985237956047, 85.33423259854317, 73.09931471943855, 72.8878864645958, 81.08617454767227, 82.03451246023178, 81.40528902411461, 80.86689591407776, 81.39202773571014, 78.60180705785751, 71.96115419268608, 67.50614404678345, 69.13117244839668, 67.63483554124832, 69.44115981459618, 69.95474025607109, 78.59233796596527, 76.53168573975563, 68.34171161055565, 73.36112067103386, 74.81814488768578, 73.61863285303116, 75.28390109539032, 72.92209982872009, 76.01315036416054, 72.86976903676987, 71.48808717727661, 69.91285890340805, 71.56041249632835, 67.70960032939911, 65.6939072906971, 66.2475223839283, 73.72840896248817, 65.13862788677216, 64.0693348646164, 64.99887138605118, 65.8566677570343, 74.32891353964806, 71.24901160597801, 72.1626041829586, 67.169269323349, 55.67907728254795, 61.21793366968632, 79.71643924713135, 71.33769124746323, 67.85146191716194, 63.175337836146355, 59.50052082538605, 56.512247174978256, 58.98958504199982, 57.69290842115879, 55.10276980698109, 67.88419336080551, 77.08591639995575, 75.6806606054306, 76.312475502491, 72.45967984199524, 74.46468785405159, 76.18722662329674, 78.34978178143501, 75.91520681977272, 77.00940370559692, 75.21670550107956, 71.65721610188484, 65.41981279850006, 64.64463159441948, 65.91912880539894, 68.2832783460617, 68.76327618956566, 77.77392268180847, 79.39638242125511, 80.63586831092834, 83.06971371173859, 54.579553082585335, 3.4032472455874085, 0.11171641745022498, 0.3434832813218236, 0.434253285638988, 0.2557623165193945, 0.7490789797157049, 1.52401925297454, 1.1935594165697694, 1.776187615469098, 2.029441650956869, 0.582797764800489, 0.15437805675901473, 7.768115540966392, 56.16495721042156, 87.85166591405869, 110.61255097389221, 102.2629702091217, 98.87584716081619, 32.0792618393898, 21.625384390354156, 53.003587648272514, 55.29874429106712, 74.3036524951458, 42.997356578707695, 0.020589646046573762, 0.02994982776726829, 0.04351040392066352, 0.03690489997097757, 0.02975558916659793, 0.0392626511893468, 0.1159398908203002, 0.03132248741167132, 0.0705247648875229, 0.024251838694908656, 0.031215900162351318, 0.05728676878788974, 0.22521507286000997, 0.3369705198565498, 0.19718549097888172, 0.129552177968435, 0.2665988897206262, 0.16862030111951753, 0.08482314529828727, 0.18139123771106824, 0.14921123947715387, 0.059917704566032626, 0.2129033624078147, 0.13201498019043356, 0.2160366059979424, 1.496142167598009, 71.747567653656, 87.69980326294899, 79.16935220360756, 36.920388266444206, 35.17424896359444, 73.38721767067909, 99.97122958302498, 103.34788039326668, 28.091373927891254, 1.0474755428731441, 0.17207064956892282, 8.201460912823677, 5.686487015336752, 7.051387075334787, 3.2686126325279474, 8.568886946886778, 6.840511215850711, 11.821450665593147, 24.776899181306362, 3.2760336343199015, 1.3973338133655488, 22.81396061182022, 113.52067932486534, 106.53374344110489, 103.61096307635307, 95.21694749593735, 96.1162680387497, 89.88377407193184, 94.17737647891045, 88.97316813468933, 83.64410609006882, 72.74306863546371, 72.027118653059, 80.86707830429077, 95.7825319468975, 92.42631644010544, 99.34968933463097, 91.42845958471298, 91.85601264238358, 85.94786927103996, 78.89656484127045, 66.66344046592712, 69.72534656524658, 65.62891557812691, 76.53659507632256, 75.56245654821396, 79.7181947529316, 73.71983662247658, 76.49488091468811, 74.20551896095276, 78.87978494167328, 85.65905436873436, 89.59726184606552, 79.70376312732697, 80.48432484269142, 82.56715267896652, 83.80720093846321, 85.35906046628952, 84.69414174556732, 84.37470808625221, 83.71904566884041, 83.2661023736, 78.42802718281746, 72.76999399065971, 72.16084867715836, 70.63735082745552, 75.2547262609005, 72.56539776921272, 83.00501078367233, 79.37445759773254, 71.97236359119415, 75.20983546972275, 79.12492498755455, 78.29944208264351, 77.59258881211281, 76.25157237052917, 78.27541217207909, 75.14071717858315, 73.21164429187775, 72.88699731230736, 75.13129368424416, 70.47391399741173, 68.63295078277588, 69.31266590952873, 78.9232774078846, 70.16337186098099, 70.06773859262466, 69.73673075437546, 71.59503623843193, 79.24894273281097, 75.07472231984138, 75.91360330581665, 70.77628657221794, 56.77702836692333, 62.36384958028793, 77.58188098669052, 75.73952704668045, 72.93015539646149, 67.33694672584534, 62.166887149214745, 58.60462009906769, 64.36620533466339, 61.51858493685722, 60.60038320720196, 73.04069146513939, 79.26576063036919, 78.91068488359451, 79.82906520366669, 78.05706828832626, 78.69711354374886, 78.82427752017975, 79.46335762739182, 79.6567976474762, 80.87980762124062, 77.40522086620331, 74.3841777741909, 69.09179136157036, 66.07395529747009, 68.21947976946831, 73.63453879952431, 72.24454298615456, 83.00401523709297, 85.22054269909859, 86.76445305347443, 87.71184101700783, 57.670273035764694, 3.20940088480711, 0.9643137396778911, 1.1800253740511835, 0.5927369033452123, 0.18410286720609292, 0.8610212698113173, 4.416516311466694, 4.589848285540938, 5.677949348464608, 3.683949583210051, 0.3871940280077979, 0.2924203150905669, 13.538856860250235, 68.31270396709442, 93.37154611945152, 116.31904676556587, 100.079987347126, 109.66179639101028, 32.00219437479973, 30.13448629528284, 66.50712445378304, 65.19712954759598, 88.14772322773933, 51.29010759294033, 0.187392006337177, 0.13795222097542137, 0.11788220261223614, 0.1873800132307224, 0.2161512678139843, 0.11592777897021733, 0.26637060509528965, 0.11808313167421147, 0.12817850714782253, 0.1027211794280447, 0.18302381417015567, 0.18077982676913962], [0.025843123912636656, 0.04800184826308396, 0.010005178555729799, 0.024742220193729736, 0.006074637831261498, 0.11233381010242738, 0.0034707955455814954, 0.029923210640845355, 0.10913603677181527, 0.02638864141772501, 0.05953525360382628, 0.03862853052851278, 0.10373562850872986, 0.19443632365437225, 46.91161014139652, 65.66185221076012, 49.61513467133045, 54.411590695381165, 58.13897408545017, 66.43867492675781, 88.68873059749603, 53.17967779934406, 4.870418105274439, 0.05117995468026493, 0.3830966603709385, 3.185180746950209, 0.7577761786524206, 1.2150625814683735, 0.4898889205651358, 1.2153613404370844, 1.1377705726772547, 5.063432073220611, 2.0484444312751293, 0.158426457492169, 18.97969275712967, 104.58436444401741, 90.97577467560768, 89.68591868877411, 92.19808548688889, 88.06976661086082, 84.71016928553581, 88.33804741501808, 90.15086933970451, 84.00706261396408, 81.27152100205421, 69.14504170417786, 65.97892239689827, 69.93576407432556, 80.1818610727787, 86.40715822577477, 88.95382717251778, 89.41718950867653, 89.76959019899368, 81.52766525745392, 72.58574187755585, 64.07535374164581, 61.4478175342083, 60.075209587812424, 60.01503601670265, 61.91757872700691, 62.941167801618576, 62.032248973846436, 61.67012080550194, 61.13418236374855, 67.45037823915482, 76.41807183623314, 86.01029232144356, 68.0615146458149, 56.38735927641392, 63.122995644807816, 68.68291050195694, 77.26411923766136, 79.95261937379837, 75.78260153532028, 73.71304258704185, 73.3254861831665, 68.56722190976143, 69.84940990805626, 65.02793222665787, 68.16101610660553, 68.75827565789223, 70.54426342248917, 73.42193260788918, 70.81353217363358, 68.57435792684555, 68.91630157828331, 70.40728837251663, 68.38976383209229, 70.49398452043533, 69.89164844155312, 68.16928446292877, 68.16224724054337, 72.0896328985691, 73.30391094088554, 65.37964895367622, 66.00309669971466, 68.35352137684822, 64.14181217551231, 60.56609384715557, 61.95302702486515, 60.76963372528553, 60.6053077429533, 61.845792979002, 59.582634419202805, 62.750395238399506, 63.826588690280914, 70.59656381607056, 71.30068123340607, 59.27255965769291, 66.3346517086029, 74.47950705885887, 60.087866708636284, 59.44023706018925, 56.73418566584587, 55.74465796351433, 55.10598063468933, 55.13783812522888, 52.634562849998474, 54.96816962957382, 62.4015511572361, 67.37837970256805, 66.5120641887188, 68.83595868945122, 68.77408280968666, 71.3144288957119, 71.99097499251366, 71.80565133690834, 71.65163800120354, 71.62772208452225, 69.88403365015984, 65.58115214109421, 62.39970825612545, 64.96626153588295, 56.88241571187973, 61.28138266503811, 66.11012935638428, 70.08128106594086, 75.22765651345253, 72.55813255906105, 75.4413190484047, 30.57211071252823, 0.20748654525959864, 0.6626705476082861, 0.7687227381393313, 0.2610647538676858, 1.311971393879503, 0.9037023014388978, 0.49832402262836695, 1.7190727614797652, 4.119623517617583, 0.5853316944558173, 0.038286073904600926, 0.6343678256962448, 24.87589716911316, 65.44884324073792, 77.83031925559044, 95.01666784286499, 50.809874162077904, 21.18539460003376, 42.72537477314472, 46.86358831822872, 55.042767226696014, 67.19918131828308, 43.88141334056854, 0.20318358787335455, 0.10666802467312664, 0.05817472250782885, 0.04170229840383399, 0.07136215237551369, 0.028037834563292563, 0.025803932949202135, 0.045453524653567, 0.05106618344143499, 0.020325040713942144, 0.05784773966297507, 0.02702799978578696, 0.01353236712020589, 0.0449663789186161, 0.05594727015704848, 0.014982211978349369, 0.04292409241315909, 0.08377523277886212, 0.0586665920127416, 0.05046525904617738, 0.047730663791298866, 0.06673141062492505, 0.010244688164675608, 0.10102208427269943, 0.04170793872617651, 0.39216989069245756, 54.0966521948576, 77.6228503882885, 51.52826741337776, 48.68767663836479, 40.898827984929085, 50.1744494587183, 104.39137279987335, 63.470247611403465, 5.889721484854817, 0.053600383980665356, 1.1434404621832073, 4.93032094091177, 2.3618397396057844, 2.5504827545955777, 0.6809941143728793, 0.7389993080869317, 1.1291586910374463, 7.288520950824022, 1.8107816716656089, 0.27694264717865735, 26.01011160761118, 108.0585104227066, 96.63339748978615, 96.96996822953224, 97.2102977335453, 91.15010172128677, 90.27641460299492, 88.67362260818481, 92.83662602305412, 89.25699770450592, 85.70190086960793, 72.88173079490662, 69.82844263315201, 72.34906777739525, 86.65830194950104, 89.51816529035568, 92.06613376736641, 89.97202813625336, 90.0797675549984, 84.4635397195816, 77.80923798680305, 65.45214146375656, 64.32807058095932, 63.29129621386528, 62.86685138940811, 62.335974276065826, 64.36582535505295, 64.12448510527611, 62.71327883005142, 66.0575021803379, 74.06301900744438, 79.86773952841759, 88.77459079027176, 74.55951556563377, 61.882696598768234, 69.32428568601608, 69.23274099826813, 77.40680918097496, 79.95615318417549, 79.50543656945229, 76.1810253560543, 75.80622866749763, 74.6656134724617, 72.51609161496162, 69.48595941066742, 75.03321334719658, 71.82260602712631, 75.44357612729073, 76.01481467485428, 72.76560142636299, 70.82883015275002, 70.77027529478073, 72.40497797727585, 71.29903212189674, 71.88462629914284, 72.41456106305122, 71.85014694929123, 72.45864629745483, 76.17556124925613, 75.48348158597946, 69.00905460119247, 69.71317201852798, 71.34911343455315, 68.93820360302925, 62.828378453850746, 65.24109318852425, 66.16895779967308, 63.46940405666828, 63.8479283452034, 65.68608731031418, 66.16975575685501, 67.32254549860954, 72.76019051671028, 73.60243052244186, 62.0305048674345, 71.53439909219742, 76.82851061224937, 65.46063020825386, 64.07558932900429, 59.34865437448025, 58.454113975167274, 59.07787710428238, 60.31189128756523, 55.50004608929157, 56.666898876428604, 62.726950496435165, 69.4625374674797, 69.81049999594688, 71.97487905621529, 70.71900084614754, 73.9832004904747, 74.88212585449219, 74.52790886163712, 74.15426731109619, 74.76751640439034, 74.21401530504227, 67.76096597313881, 67.36387968063354, 67.19142213463783, 61.62774547934532, 65.86220785975456, 69.16613057255745, 71.86843916773796, 81.4225172996521, 78.2567247748375, 82.37145557999611, 39.95425567030907, 0.38891566218808293, 0.6424265401437879, 0.6760605541057885, 0.7669393275864422, 2.6266976399347186, 1.325466251000762, 0.5954534013289958, 1.3712457194924355, 5.376462126150727, 1.9708288460969925, 0.3139335731975734, 0.2680497587425634, 28.040589652955532, 73.59659403562546, 89.82232376933098, 101.64241030812263, 65.40478840470314, 26.1260224878788, 40.24480327963829, 52.41537161171436, 61.70154131948948, 73.64592298865318, 50.598145723342896, 0.12781901081325486, 0.0373351600865135, 0.03476997859252151, 0.026035675982711837, 0.013648939966515172, 0.04342157997598406, 0.009560480884829303, 0.1010515920643229, 0.047172216218314134, 0.019367983768461272, 0.10334301754483022, 0.06290325705776922, 0.10917142979451455, 0.2001225552521646, 0.09876804077066481, 0.15701796510256827, 0.18116088991519064, 0.15122499782592058, 0.09581420395988971, 0.19551585166482255, 0.19058192032389343, 0.13532022392610088, 0.10789850552100688, 0.21068857109639794, 0.2176664216676727, 0.6970939692109823, 67.62348175048828, 88.70041877031326, 62.795730605721474, 70.21555826067924, 76.65592387318611, 98.99420320987701, 107.31016337871552, 79.85153719782829, 8.537746667861938, 0.2330220359726809, 0.6778366619255394, 10.875214990228415, 5.305977808311582, 5.311249075457454, 3.1623396975919604, 3.6526789236813784, 1.6273885499686003, 11.81220006197691, 4.920278079807758, 0.8417556504718959, 27.77938786894083, 107.49186962842941, 98.48085075616837, 100.35462141036987, 100.74947342276573, 94.68211859464645, 92.15495020151138, 94.14004728198051, 96.87504172325134, 92.92551845312119, 89.2720676958561, 76.44298329949379, 75.61886072158813, 75.66812887787819, 87.64296591281891, 93.41918036341667, 97.92353466153145, 93.97981747984886, 94.30960938334465, 87.24114507436752, 82.58362859487534, 68.94921541213989, 66.56578570604324, 66.77633240818977, 67.16477796435356, 68.12005430459976, 69.60504502058029, 67.75891408324242, 67.74596437811852, 68.65969374775887, 75.01516431570053, 83.49497929215431, 91.34836748242378, 76.99572443962097, 63.73886659741402, 70.52180662751198, 68.80750581622124, 81.30365207791328, 82.24175333976746, 82.10635900497437, 78.40772107243538, 81.00428894162178, 78.67504432797432, 76.23226940631866, 73.33913505077362, 78.78364250063896, 76.74058333039284, 78.47230240702629, 79.75604832172394, 73.71692597866058, 73.89457404613495, 74.02364552021027, 75.89826732873917, 74.34830009937286, 75.40542617440224, 75.14253348112106, 75.75434625148773, 75.01940488815308, 79.1193924844265, 81.24297693371773, 71.35092973709106, 70.57299748063087, 74.14960876107216, 70.34819394350052, 68.3348035812378, 69.910419434309, 70.13867318630219, 68.94351571798325, 68.86302083730698, 69.44291532039642, 71.90359488129616, 70.39395108819008, 77.51425981521606, 77.22872793674469, 65.35761773586273, 75.13903006911278, 76.21876493096352, 68.76097351312637, 66.57053545117378, 63.58546502888203, 60.38803920149803, 62.4933086335659, 63.418486788868904, 56.62415497004986, 60.84345996379852, 66.71229064464569, 74.0469078719616, 72.51674517989159, 77.76076018810272, 73.82879197597504, 78.64842295646667, 77.68856406211853, 78.9675222337246, 77.11587399244308, 77.98855036497116, 76.45798489451408, 72.33682483434677, 68.32085072994232, 70.5033928155899, 62.87561371922493, 68.49740445613861, 73.55584502220154, 77.86217674612999, 84.34032753109932, 84.95076477527618, 84.95207950472832, 42.605692595243454, 0.6060328055173159, 1.4909997372888029, 1.7418423271737993, 0.6119966448750347, 2.8848676616325974, 3.05040102917701, 0.9159805707167834, 6.454533627256751, 10.089317411184311, 1.4128002896904945, 0.31376011844258755, 1.5565838618203998, 40.79744182527065, 83.16666170954704, 92.3610283434391, 107.6208271086216, 70.90609520673752, 33.705198392271996, 57.31100991368294, 62.30008140206337, 69.7209919989109, 86.2575526535511, 59.63091462850571, 0.2779744699364528, 0.1726751436945051, 0.11369093845132738, 0.11344227445079014, 0.12309780126088299, 0.10562546303845011, 0.1150549242447596, 0.3216671972768381, 0.08897312378394417, 0.11618998716585338, 0.16375210921978578, 0.17613012314541265], [0.039144022593973204, 0.06825250908150338, 0.07610974527779035, 0.05688984594598878, 0.05309192005370278, 0.06556692154845223, 0.06857657528598793, 0.014618011355196359, 0.04079884492966812, 0.06287127049290575, 0.014705260091432137, 0.10200555610936135, 0.09556925811921246, 0.1183052861597389, 39.922439977526665, 69.34190914034843, 64.40212860703468, 64.1640941798687, 51.28463588654995, 67.539202272892, 81.21480524539948, 31.51500541716814, 0.34723976568784565, 0.1444548595463857, 2.191871772520244, 2.4513021390885115, 1.0095038241706789, 0.25501725962385535, 0.15157003712374717, 0.2513086289400235, 0.46258919639512897, 2.730984231457114, 0.9739836270455271, 13.812865857034922, 91.16660803556442, 77.51541495323181, 80.56685641407967, 89.21079218387604, 92.08386361598969, 89.45546105504036, 92.90153414011002, 89.13785129785538, 92.17484593391418, 87.71903023123741, 87.4549899995327, 73.92319411039352, 67.82223388552666, 65.9110352396965, 77.6964220404625, 81.5939337015152, 86.89729392528534, 88.2379911839962, 85.27953833341599, 84.99812543392181, 76.99302658438683, 61.1927106231451, 59.20434191823006, 59.874610751867294, 60.01506261527538, 59.13558840751648, 60.349581465125084, 58.996641263365746, 61.82047113776207, 68.38566765189171, 71.28479048609734, 75.92128649353981, 76.10325112938881, 60.94484992325306, 76.20765432715416, 72.50062644481659, 76.87562048435211, 74.5019942522049, 74.61207434535027, 71.79971605539322, 70.31037837266922, 69.22015607357025, 73.21817234158516, 70.2558209002018, 67.23100081086159, 66.75470396876335, 67.12532848119736, 70.26871740818024, 70.27241840958595, 67.00143992900848, 69.23975542187691, 68.08118999004364, 68.43373507261276, 70.73722466826439, 69.78219911456108, 69.51992198824883, 67.86144018173218, 71.9990685582161, 59.66689869761467, 66.46348759531975, 74.40107926726341, 66.5716601908207, 64.73470956087112, 62.77806155383587, 62.46413379907608, 60.92374965548515, 59.93323780596256, 58.27142737805843, 63.26405547559261, 60.777278915047646, 60.320307835936546, 59.01168845593929, 66.97096556425095, 69.20182585716248, 68.31646576523781, 58.75471204519272, 74.13578510284424, 67.06922069191933, 60.63542112708092, 57.869397550821304, 54.2502361536026, 54.21009510755539, 56.290688663721085, 59.04586762189865, 56.45923621952534, 55.82245498895645, 59.785798117518425, 61.03282280266285, 67.25120812654495, 61.7000176012516, 68.95003616809845, 72.4583575129509, 73.34722861647606, 70.75885310769081, 74.5443619787693, 71.05139940977097, 70.47598108649254, 66.66246771812439, 69.41108822822571, 64.36779364943504, 69.70269218087196, 64.4527418911457, 65.38515105843544, 74.0307967364788, 73.32316070795059, 78.67364600300789, 73.27083751559258, 8.935228139162064, 0.6206560833379626, 0.8058903249911964, 1.9350418914109468, 1.008587598334998, 1.378622786141932, 0.07261774007929489, 0.5251161474734545, 2.370944288559258, 2.197636063210666, 0.0897173940029461, 0.06460906122811139, 5.056043369695544, 39.40980188548565, 75.53473323583603, 69.49553489685059, 32.73901663720608, 36.95636473596096, 34.572380259633064, 51.05723328888416, 53.72050277888775, 60.95702067017555, 42.67516426742077, 0.1184885817929171, 0.04235259417328052, 0.008942630884121172, 0.04586743896652479, 0.06640391569817439, 0.04589771488099359, 0.0383420726575423, 0.026002301601693034, 0.004760200135933701, 0.0196610931379837, 0.03682122282043565, 0.04060527426190674, 0.030263906519394368, 0.030247905815485865, 0.03705559305672068, 0.03730514021299314, 0.09270657188608311, 0.033535260081407614, 0.005079120010123006, 0.07053920708131045, 0.012386172911647009, 0.031073715799720958, 0.04955550844897516, 0.06654257857007906, 0.09787653587409295, 0.11195380822755396, 46.81044057011604, 80.52736893296242, 63.324871212244034, 59.313038885593414, 34.72234681248665, 67.91491091251373, 94.98889893293381, 37.483974024653435, 0.21788165933685377, 0.3845334582729265, 4.192614275962114, 4.5169738959521055, 3.1615716638043523, 1.9452593056485057, 0.7388545002322644, 0.2874829253414646, 1.5799343213438988, 3.884500446729362, 0.8661423856392503, 19.002738520503044, 100.23583218455315, 81.02722451090813, 91.4894387125969, 94.14113402366638, 98.0687552690506, 93.84234085679054, 96.63588255643845, 92.76941522955894, 95.77297925949097, 93.31812098622322, 90.7792416214943, 77.13656008243561, 68.12336012721062, 68.63257840275764, 80.04424765706062, 85.26632264256477, 89.51327875256538, 90.03811419010162, 85.03872245550156, 88.97955179214478, 80.9327007830143, 64.28875789046288, 60.6196291744709, 62.05909073352814, 61.23306445777416, 61.804029420018196, 63.559850603342056, 62.49420538544655, 64.57577928900719, 71.66794672608376, 73.77390012145042, 80.52137285470963, 80.6811086833477, 67.29820400476456, 77.76251569390297, 73.87294560670853, 80.81066653132439, 78.40784266591072, 77.02909424901009, 76.14133268594742, 73.40750098228455, 73.57676669955254, 74.75626900792122, 72.79232919216156, 70.77500224113464, 69.75446820259094, 72.57058069109917, 72.49545112252235, 70.76748624444008, 67.85029157996178, 72.81755223870277, 71.71533778309822, 72.36185789108276, 73.45129743218422, 72.75889098644257, 73.70112642645836, 70.33406630158424, 73.95746067166328, 60.664257779717445, 67.7938038110733, 74.84541222453117, 68.56100544333458, 65.31556159257889, 65.53823724389076, 65.63942581415176, 63.312601670622826, 63.342262879014015, 62.947384268045425, 66.20767012238503, 65.06772369146347, 65.13998821377754, 63.132977709174156, 70.1845595240593, 71.34829267859459, 72.72897139191628, 64.27337631583214, 76.91657468676567, 69.61029633879662, 63.36670696735382, 61.844124868512154, 58.68465140461922, 58.26761998236179, 61.029919758439064, 61.80048421025276, 59.023068845272064, 58.373660892248154, 61.13180369138718, 62.256702929735184, 67.66132771968842, 65.38148805499077, 70.52989259362221, 73.510452657938, 74.82714280486107, 73.7305748462677, 77.20456883311272, 74.73477736115456, 73.60035583376884, 69.9463427066803, 73.58280077576637, 67.9723410308361, 72.77972906827927, 67.36049026250839, 71.44586384296417, 78.5522349178791, 77.53488510847092, 81.09112188220024, 79.06241074204445, 13.765347506850958, 0.5436308321077377, 0.889688772149384, 0.9696202736813575, 1.6922944108955562, 2.2210615687072277, 0.8430439000949264, 0.20278503972804174, 2.7286490192636847, 3.5296144522726536, 0.888808110030368, 0.3360476443776861, 5.37943166680634, 46.9659548252821, 82.85244137048721, 78.91172602772713, 39.04400311410427, 28.800223991274834, 35.79269617795944, 56.08132369816303, 59.90061275660992, 70.42772367596626, 50.689299032092094, 0.05272802649415098, 0.02900889583543176, 0.012615792475116905, 0.035674048049259, 0.06247107477975078, 0.04534504121693317, 0.07844287203624845, 0.060864796323585324, 0.05172885823412798, 0.028875750831502955, 0.03114864302915521, 0.029045327864878345, 0.1972344727255404, 0.19355398428160697, 0.15514788654400036, 0.11925355793209746, 0.13256786536658183, 0.14721005311002955, 0.10380402483860962, 0.1731822086730972, 0.19086124986642972, 0.14630151592427865, 0.16842030716361478, 0.2261153722065501, 0.2089853273355402, 0.3517723287222907, 59.55149509012699, 89.38528642058372, 78.70227366685867, 82.97775864601135, 72.85265475511551, 88.90023484826088, 100.65209224820137, 49.17189605534077, 0.3504003648413345, 0.2626271528424695, 4.747245339676738, 7.907475912943482, 5.129886232316494, 2.897524069994688, 0.8082799811381847, 0.25724536506459117, 4.155422821640968, 4.505949262529612, 1.3728171726688743, 22.992326840758324, 102.21225813031197, 85.2111268043518, 96.08864352107048, 95.13858810067177, 99.97363865375519, 97.33802407979965, 100.16057342290878, 94.7164535522461, 100.05763694643974, 96.1785314977169, 92.46005102992058, 81.67509734630585, 72.33889952301979, 72.77371019124985, 85.69108664989471, 89.7843562066555, 93.53309065103531, 95.1296965777874, 89.58645522594452, 93.10856983065605, 85.84984213113785, 67.4088616669178, 65.38638979196548, 66.11377716064453, 66.72381162643433, 66.20545864105225, 66.7687252163887, 66.956267952919, 68.570626527071, 73.56848314404488, 78.79814252257347, 86.97738602757454, 79.9207466840744, 71.8651333451271, 80.71706235408783, 73.55772972106934, 82.90857955813408, 80.74068188667297, 79.83851909637451, 79.44239795207977, 79.4682365655899, 76.72301307320595, 80.79701006412506, 74.85811114311218, 73.82863238453865, 76.3187375664711, 76.12226530909538, 75.93720003962517, 73.06345984339714, 71.91513866186142, 75.41861146688461, 76.35615035891533, 75.01596987247467, 77.25636005401611, 76.6931314766407, 75.9923654794693, 72.63984337449074, 77.51664608716965, 62.47986115515232, 71.061552464962, 80.14729052782059, 71.1035630106926, 69.18471917510033, 70.88641226291656, 69.30960327386856, 69.2789389193058, 66.90976604819298, 67.6777732372284, 72.70809531211853, 68.3407312631607, 68.9627654850483, 67.19600468873978, 73.67876082658768, 75.10898128151894, 74.78665977716446, 68.68251532316208, 77.9081466794014, 70.54357185959816, 68.06583881378174, 63.595420494675636, 61.50687016546726, 60.0142190605402, 63.33947382867336, 65.10493129491806, 64.72802951931953, 60.97327999770641, 65.39700642228127, 66.09635129570961, 75.30980810523033, 69.08495172858238, 73.62487211823463, 76.80986881256104, 79.14050415158272, 76.93702518939972, 80.64237356185913, 76.83341234922409, 76.61367014050484, 73.34169611334801, 75.57164445519447, 70.52755951881409, 75.440893471241, 71.00905448198318, 73.97386819124222, 83.89467224478722, 82.60224759578705, 89.55756157636642, 82.9561074078083, 14.627555441111326, 0.5306621873751283, 3.1852543679997325, 6.363528985530138, 3.5089323995634913, 3.381989048793912, 1.3072634465061128, 2.627944448031485, 7.364533022046089, 5.277503086254001, 0.815428881905973, 0.22789823357015848, 9.380102567374706, 61.136716827750206, 85.28447046875954, 83.63564774394035, 47.94714197516441, 51.03835590183735, 47.70279608666897, 66.42004072666168, 67.96814605593681, 80.71161344647408, 63.26684072613716, 0.34265635069459677, 0.09041040408192202, 0.09985476019210182, 0.11628747568465769, 0.13827397167915478, 0.18911652005044743, 0.20867929531959817, 0.12607628479599953, 0.104234938044101, 0.09499288396909833, 0.14630635472713038, 0.12264914330444299], [0.03071936997002922, 0.04611805852619, 0.03803341343882494, 0.06777653266908601, 0.01674761988397222, 0.06058208629838191, 0.04926982983306516, 0.044215767047717236, 0.027190353866899386, 0.02369466019445099, 0.050652283971430734, 0.048592249004286714, 0.0503691583435284, 0.0941996171604842, 30.74117884039879, 70.9858301281929, 60.943740382790565, 67.05308675765991, 54.85567666590214, 77.25141271948814, 68.69906723499298, 12.111339010298252, 0.029506238679459784, 0.19599516032030806, 3.783880895934999, 2.0252338517457247, 2.062915242277086, 0.9482456487603486, 0.27411951741669327, 0.42039679479785264, 0.659548124531284, 1.021327602211386, 8.10566995292902, 72.71694883704185, 60.258435755968094, 69.72729206085205, 87.28877171874046, 95.6322880089283, 92.71413579583168, 95.75368389487267, 90.88904812932014, 92.00960040092468, 91.62790328264236, 88.64050358533859, 89.93338420987129, 80.16737625002861, 65.09049966931343, 67.02867686748505, 68.24855580925941, 79.2168952524662, 80.17581939697266, 84.65679734945297, 85.63097387552261, 82.81513497233391, 75.90886116027832, 64.36549097299576, 60.95105119049549, 60.00732243061066, 58.86665403842926, 59.66831982135773, 58.75271715223789, 63.66209551692009, 68.47829148173332, 72.58322641253471, 72.57677435874939, 77.93688833713531, 67.40143686532974, 67.57491275668144, 77.7272155880928, 76.34029760956764, 76.00253373384476, 74.76247027516365, 69.79614436626434, 70.01110643148422, 73.70713770389557, 71.7053671181202, 69.47674870491028, 72.1117553114891, 63.99289056658745, 65.89693799614906, 69.00769427418709, 66.5582013130188, 69.77819412946701, 70.55177941918373, 69.13600578904152, 74.10670906305313, 68.79498168826103, 73.24991583824158, 70.00625029206276, 70.31253665685654, 67.89176255464554, 55.727786868810654, 57.64937035739422, 61.88847988843918, 64.89891394972801, 69.39284160733223, 67.28063374757767, 66.84323161840439, 63.105493783950806, 58.85524705052376, 56.42145484685898, 56.232171803712845, 65.16450449824333, 61.96172095835209, 62.264234125614166, 57.917719557881355, 61.27945616841316, 63.22795361280441, 69.65755060315132, 64.17917177081108, 65.73850929737091, 74.61463540792465, 58.84549677371979, 61.356918811798096, 53.48441004753113, 58.56842704117298, 56.58091329038143, 58.84448602795601, 58.89742858707905, 61.145444959402084, 58.32186207175255, 61.153584122657776, 57.17966616153717, 61.05366848409176, 62.67833590507507, 68.98440912365913, 67.56307259202003, 75.40292590856552, 72.36830234527588, 72.48152107000351, 69.35726791620255, 72.25225657224655, 68.3948403596878, 71.94595500826836, 71.72307416796684, 72.47982636094093, 72.53645092248917, 76.13463744521141, 72.7703207731247, 72.50069484114647, 75.56450843811035, 55.10284960269928, 0.16719991952413693, 0.2833135990658775, 1.5359063213691115, 3.105731997638941, 1.0977285588160157, 0.9595091943629086, 0.7773445348720998, 3.111850619316101, 3.1178452726453543, 1.0577949578873813, 0.15631078742444515, 0.3620519646210596, 19.969165362417698, 44.122069627046585, 81.03848710656166, 41.62646234035492, 56.84692561626434, 39.47659470140934, 42.91730247437954, 51.399135142564774, 57.96717390418053, 31.304181329905987, 0.07105693672201596, 0.015986449107003864, 0.08069362040259875, 0.03590209147660062, 0.036005762085551396, 0.038894779718248174, 0.02459810068103252, 0.03387926779396366, 0.06491804699180648, 0.011459043071226915, 0.09515058292890899, 0.028138788911746815, 0.03840714787656907, 0.053001255582785234, 0.021122686193848494, 0.05293201691529248, 0.04558682179776952, 0.03488104841380846, 0.14586139266612008, 0.03478492915746756, 0.10103551714564674, 0.04635224693629425, 0.0702347929473035, 0.018410505654173903, 0.17081492085708305, 0.10074157471535727, 39.28225412964821, 78.76140609383583, 66.16730108857155, 61.30644232034683, 42.731260657310486, 84.09518748521805, 81.22796773910522, 12.411051727831364, 0.07833540163119324, 0.2750823798123747, 3.1633371440693736, 2.641749819740653, 6.517167091369629, 3.0482168588787317, 1.3993016327731311, 1.4882674464024603, 1.2873383844271302, 0.8506549510639161, 13.403597418218851, 79.12378504872322, 67.55345910787582, 82.0373623073101, 92.1437256038189, 101.2335978448391, 96.90307661890984, 96.60079523921013, 93.9585842192173, 97.50309482216835, 95.21336808800697, 91.90866261720657, 94.12001475691795, 83.733439296484, 68.5755966603756, 71.21419787406921, 73.60521197319031, 81.53515085577965, 83.86637896299362, 87.93514743447304, 85.77573850750923, 86.65568768978119, 79.60840344429016, 67.3900754749775, 61.0286658257246, 62.39835552871227, 61.39834798872471, 63.502918258309364, 61.11075662076473, 66.22706428170204, 71.56056448817253, 77.07817241549492, 78.86517852544785, 80.43346837162971, 71.65919199585915, 72.61043295264244, 79.73484545946121, 80.42853623628616, 76.81259706616402, 77.43305057287216, 72.5295352935791, 71.98292702436447, 77.54006043076515, 73.84071573615074, 70.44022500514984, 74.98679503798485, 67.8466285765171, 71.00373476743698, 69.52314421534538, 67.87937521934509, 71.78517803549767, 74.36346888542175, 72.10202783346176, 74.56865787506104, 73.71149227023125, 76.71641662716866, 70.55127784609795, 72.79739052057266, 68.90654370188713, 58.097841292619705, 60.23246794939041, 64.70507115125656, 64.6749995648861, 71.03727176785469, 70.80465584993362, 70.92612013220787, 65.94568938016891, 63.25017102062702, 61.24881461262703, 61.37187860906124, 68.866296261549, 66.42355933785439, 66.97880074381828, 61.91605120897293, 63.40419955551624, 67.61477261781693, 72.58146330714226, 65.69832265377045, 71.60020396113396, 75.88990777730942, 63.02034795284271, 63.73236894607544, 56.92150801420212, 60.89670650660992, 59.72132697701454, 62.70907625555992, 61.852727606892586, 63.210710138082504, 61.5624687820673, 64.05571639537811, 61.397409439086914, 64.33044165372849, 64.62000891566277, 70.53878411650658, 71.25978022813797, 76.70785948634148, 74.6147646009922, 75.71320205926895, 73.2897301018238, 74.50640961527824, 71.32510632276535, 76.11226424574852, 75.3848160803318, 76.11734077334404, 77.00006380677223, 80.9789291024208, 76.77054852247238, 80.36816507577896, 80.22700265049934, 61.2631930410862, 1.7629371327348053, 0.31877988658379763, 0.6279101909603924, 1.656733900308609, 1.1846202774904668, 0.2990431518992409, 0.6043658824637532, 2.3113962588831782, 3.4543414413928986, 4.701208434998989, 0.5112464167177677, 0.16020732990000397, 23.75674892216921, 53.37664023041725, 89.4055925309658, 49.56239730119705, 48.13157267868519, 45.66873103380203, 50.486066937446594, 56.671496629714966, 66.98830783367157, 38.6062666028738, 0.07472388839232735, 0.06366321627865545, 0.04441370896529406, 0.027462317593744956, 0.0876866998441983, 0.04635915633116383, 0.04417854092025664, 0.013360219472815515, 0.029354977850744035, 0.0319360320281703, 0.01637312103412114, 0.03152985831547994, 0.14852479740511626, 0.09278889090637676, 0.1820803218288347, 0.154660310363397, 0.18208633322501555, 0.12260204661288299, 0.30695886933244765, 0.21602361841360107, 0.23280326568055898, 0.1520550306304358, 0.14382479101186618, 0.1926665092469193, 0.3881660633487627, 0.24297865951666608, 48.56914959847927, 89.10819008946419, 77.25159510970116, 81.07862055301666, 80.34176409244537, 95.07633224129677, 93.73510301113129, 20.003849901258945, 0.2512613689759746, 0.24788608134258538, 8.042720630764961, 8.01838293671608, 7.078088242560625, 8.835891969501972, 1.8099509412422776, 2.290832712315023, 3.2309687649831176, 2.0689961034804583, 14.23388421535492, 79.31094780564308, 69.66531738638878, 87.6028248667717, 93.67999076843262, 104.23672869801521, 97.80501142144203, 102.54781052470207, 97.89693608880043, 98.69423970580101, 99.34338927268982, 96.67774870991707, 96.63744807243347, 87.55605697631836, 72.54221901297569, 73.81702780723572, 75.72717010974884, 85.4297898709774, 87.85706162452698, 90.88119015097618, 90.7634724676609, 89.89730894565582, 82.82196700572968, 72.34376326203346, 66.43438875675201, 66.48421168327332, 65.59753686189651, 67.13081538677216, 65.15386506915092, 72.58306682109833, 75.65413042902946, 80.77701553702354, 81.26263707876205, 84.50184926390648, 74.19061616063118, 76.72908514738083, 83.76798704266548, 84.50824052095413, 81.9290529191494, 83.59033137559891, 78.34182500839233, 76.4236119389534, 83.61646637320518, 78.78043547272682, 72.4774780869484, 80.31707301735878, 69.06206175684929, 73.9238552749157, 74.58662331104279, 69.80821251869202, 74.19240206480026, 76.42928883433342, 76.34518414735794, 79.20106530189514, 76.67181462049484, 76.85299649834633, 74.05564740300179, 75.5621449649334, 72.68357902765274, 57.50753916800022, 59.824404045939445, 64.40578401088715, 69.14236664772034, 75.60227081179619, 72.35933482646942, 72.14203968644142, 71.93881899118423, 67.26356506347656, 62.155871540308, 65.83918869495392, 71.34654477238655, 69.87404778599739, 70.52631318569183, 63.73880960047245, 68.08935195207596, 69.69410464167595, 76.9479002058506, 72.27550372481346, 71.78999617695808, 79.42868828773499, 65.65170675516129, 68.12458366155624, 61.74438402056694, 66.6623005270958, 65.2848668396473, 66.3112373650074, 65.78820303082466, 67.57425159215927, 65.59106200933456, 66.89325973391533, 65.23180648684502, 67.36986815929413, 69.73052188754082, 75.32765954732895, 74.76536571979523, 81.61689966917038, 78.98804113268852, 78.093371540308, 76.42969161272049, 78.30969393253326, 73.90677139163017, 77.1522456407547, 76.25645130872726, 78.80297586321831, 80.39705112576485, 83.87569606304169, 79.74828153848648, 86.4167033135891, 85.98630800843239, 66.90139129757881, 1.521553541533649, 0.5858515540603548, 5.237468434497714, 7.557283854112029, 3.3667570911347866, 3.3907789271324873, 1.7452226020395756, 9.94386501610279, 9.891929402947426, 4.452639548107982, 0.22976604115683585, 0.6286174873821437, 34.983442202210426, 63.85782301425934, 98.85208323597908, 59.442285150289536, 78.53512823581696, 50.82748241722584, 59.612063840031624, 65.33671885728836, 77.94340118765831, 49.649291038513184, 0.22174750658450648, 0.13492332334863022, 0.1595483472920023, 0.14966975315473974, 0.18963274313136935, 0.16607753990683705, 0.12794777343515307, 0.1865494906087406, 0.1968106915592216, 0.16683689056662843, 0.14998446829849854, 0.18905153759988025], [0.06907289396622218, 0.04682166276325006, 0.03554980139597319, 0.06885623137350194, 0.01262658515770454, 0.017248751391889527, 0.029491174936993048, 0.03800618775130715, 0.043815066674142145, 0.04212560088490136, 0.08303103677462786, 0.03371707512997091, 0.11430441256379709, 0.055957467266125605, 37.68154442310333, 63.851492553949356, 52.89362534880638, 37.7706116437912, 44.39321167767048, 82.03472524881363, 48.05985152721405, 2.0560570852831006, 0.0606073638482485, 0.9171729942318052, 3.877937961369753, 3.2878894731402397, 3.2579323556274176, 2.8225374687463045, 0.5332091194577515, 3.0025335727259517, 0.27931333403103054, 18.190161623060703, 91.15897044539452, 80.8036521077156, 79.2013692855835, 83.32179218530655, 87.77962177991867, 91.84897541999817, 91.76185369491577, 94.05867084860802, 92.37102180719376, 90.50887852907181, 89.49731200933456, 91.1104242503643, 86.94881156086922, 79.70690175890923, 64.89104077219963, 65.48601284623146, 68.74249890446663, 77.08691954612732, 80.56685641407967, 83.21984365582466, 83.50428879261017, 81.59927621483803, 76.95781767368317, 62.392929419875145, 59.79985736310482, 60.617102310061455, 58.10402736067772, 59.63805444538593, 57.81349115073681, 66.12795040011406, 70.52141904830933, 73.31192091107368, 73.58252719044685, 71.48025959730148, 72.92340695858002, 71.14505678415298, 74.80094701051712, 78.14719945192337, 71.63991183042526, 70.41732743382454, 68.68756905198097, 71.70787498354912, 72.89704397320747, 70.63471376895905, 74.2145548760891, 68.07014018297195, 69.31710407137871, 66.49394676089287, 64.56593781709671, 71.76520630717278, 71.77812561392784, 70.6946973502636, 66.3488781452179, 70.82090377807617, 70.83611816167831, 68.40105682611465, 61.17042861878872, 62.06573277711868, 57.30113044381142, 70.74929282069206, 69.68933209776878, 69.44498240947723, 62.582140266895294, 63.21292921900749, 65.44992998242378, 65.41287437081337, 65.73706537485123, 61.93990632891655, 58.21607954800129, 57.816523388028145, 63.463841155171394, 65.94562098383904, 60.59255562722683, 61.38613544404507, 60.00511854887009, 60.24499587714672, 66.09224751591682, 69.43765640258789, 64.61896017193794, 71.27049565315247, 62.952297404408455, 59.75139856338501, 55.574404299259186, 54.79312442243099, 52.82566599547863, 55.973800867795944, 59.40897613763809, 59.10845786333084, 61.338155418634415, 60.996485352516174, 59.37023341655731, 60.60405761003494, 61.13708920776844, 64.29843977093697, 69.76537361741066, 71.17091819643974, 74.30312812328339, 73.73543098568916, 71.98798075318336, 74.69079852104187, 73.71105909347534, 74.18792590498924, 72.31212615966797, 75.66071927547455, 73.79957154393196, 77.67084941267967, 74.54420998692513, 77.31703519821167, 62.63092204928398, 69.39034134149551, 48.17409239709377, 0.34191960585303605, 0.8292015991173685, 1.7497501778416336, 1.6953291418030858, 0.2946522500133142, 0.16152925818460062, 2.3553679743781686, 2.070054109208286, 2.522714794613421, 0.26811765041202307, 0.5144340300466865, 9.953523147851229, 33.94152671098709, 66.75664946436882, 57.12015375494957, 21.27308439463377, 29.43959478288889, 53.00664648413658, 48.14039200544357, 58.06358613073826, 20.047273971140385, 0.08736236646655016, 0.19056134799029678, 0.07998381552170031, 0.11249524948652834, 0.05490150615514722, 0.11348211293807253, 0.06519293106975965, 0.01979825130547397, 0.022112507103884127, 0.06542998788063414, 0.016487697503180243, 0.05719687986129429, 0.01207406177854864, 0.07939989372971468, 0.12477399373892695, 0.1159949136490468, 0.10553301370237023, 0.019349227841303218, 0.057951080016209744, 0.03316230118798558, 0.0596237324498361, 0.042487082464504056, 0.015175785429164534, 0.040707182270125486, 0.06783669115975499, 0.10698362297262065, 49.28812801837921, 69.59257408976555, 62.29722775518894, 47.62244179844856, 37.238982170820236, 91.28238782286644, 57.11813226342201, 2.7862425288185477, 0.4076477960916236, 1.188944207970053, 4.196461094543338, 3.61358804628253, 2.769905305467546, 1.3653648225590587, 1.7900867946445942, 1.7113030096516013, 0.07326544204261154, 27.387144416570663, 96.2772274017334, 87.64686450362206, 90.08275419473648, 89.35117185115814, 88.708086758852, 93.99006173014641, 92.79309555888176, 96.70214340090752, 95.98702937364578, 94.93387028574944, 91.95065036416054, 93.30977663397789, 89.46812197566032, 82.86287561058998, 69.07646298408508, 68.94606918096542, 72.39292502403259, 81.5744711458683, 85.3165103495121, 88.37996676564217, 83.20518404245377, 85.45784756541252, 80.4662150144577, 65.05329206585884, 62.43213951587677, 64.69436332583427, 60.69553390145302, 61.783103942871094, 62.13560722768307, 69.01578783988953, 73.89100223779678, 77.78858229517937, 76.09814420342445, 75.79897105693817, 75.47512203454971, 77.44382679462433, 77.27926522493362, 80.01478403806686, 75.89341878890991, 73.25558513402939, 71.9258464872837, 74.1013665497303, 74.2757847905159, 74.02467906475067, 75.97705990076065, 70.8260715007782, 70.31029477715492, 67.57746621966362, 70.49700915813446, 74.90981876850128, 75.2530087530613, 70.86318030953407, 73.3341497182846, 74.25512909889221, 73.62361058592796, 71.08060464262962, 63.7538605928421, 62.40107998251915, 57.00538091361523, 75.84131598472595, 71.59806087613106, 72.20313280820847, 67.03487053513527, 65.95344856381416, 66.41770765185356, 69.19882401823997, 68.99274587631226, 66.77655279636383, 60.4815673828125, 61.584796383976936, 67.23256632685661, 66.45258218050003, 62.80308321118355, 64.51333343982697, 61.875974759459496, 62.43921473622322, 71.08653232455254, 70.25200590491295, 69.31227833032608, 76.38831183314323, 66.64286077022552, 62.84827798604965, 57.71976538002491, 57.780945897102356, 56.44569754600525, 59.43832576274872, 60.632468685507774, 62.47475802898407, 64.6473902463913, 65.21906957030296, 61.85056932270527, 63.39742831885815, 63.6433245241642, 67.61660411953926, 73.0812580883503, 73.92981335520744, 75.21685749292374, 74.70412820577621, 75.23144870996475, 75.05591332912445, 75.93249589204788, 77.15039134025574, 76.9173726439476, 78.75106304883957, 78.12882363796234, 80.25430798530579, 78.45252066850662, 80.8867384493351, 69.92824047803879, 74.94900226593018, 59.6583491563797, 1.0427195043303072, 0.6763730873353779, 0.664438046514988, 0.5457763513550162, 0.4988825332839042, 0.11932715671719052, 1.6688952664844692, 1.1095682485029101, 6.293438896536827, 0.7957592373713851, 0.703099190723151, 8.7296686694026, 41.88365153968334, 74.43749651312828, 61.63076251745224, 22.044638693332672, 31.32208026945591, 55.29093191027641, 54.36673790216446, 64.50818851590157, 25.869424156844616, 0.18073409562930465, 0.13229588308604434, 0.05413991792011075, 0.12549720180686563, 0.04676635049690958, 0.14677825674880296, 0.02123861893778667, 0.04401765443617478, 0.08849140314850956, 0.04715096853033174, 0.04245584175805561, 0.04522655734035652, 0.12799368269043043, 0.17314324592007324, 0.19752618129132316, 0.19009159819688648, 0.14108770585153252, 0.12130501738283783, 0.1019357868062798, 0.16138829465489835, 0.15302142564905807, 0.19461997551843524, 0.23087806039256975, 0.08610496792243794, 0.14002100215293467, 0.20597900584107265, 59.91990052163601, 79.90082055330276, 74.98554110527039, 49.03465121984482, 65.14450997114182, 99.97418582439423, 70.7126247882843, 3.7708088848739862, 0.6344624049961567, 1.8606130289845169, 12.39055372774601, 8.984681535512209, 8.682797234505415, 10.433402247726917, 3.3560984255746007, 8.726061712950468, 1.3338774559088051, 27.370355017483234, 96.46427616477013, 88.37841644883156, 91.57057195901871, 91.71032845973969, 92.5622047483921, 96.04847207665443, 98.8828007876873, 100.11249840259552, 100.19844979047775, 99.44666013121605, 96.44397005438805, 95.92525228857994, 94.75233122706413, 87.62004554271698, 72.89951384067535, 74.09002795815468, 74.87693533301353, 85.30681326985359, 89.61144268512726, 91.35758578777313, 88.87132599949837, 87.5933101773262, 84.89194393157959, 70.83682492375374, 65.18407344818115, 67.88730159401894, 64.51888874173164, 66.29981517791748, 65.52993088960648, 73.00595372915268, 79.39379096031189, 80.44353783130646, 79.33292582631111, 80.42440965771675, 79.10546243190765, 80.26376947760582, 82.16834887862206, 82.70180985331535, 78.14949452877045, 77.35879495739937, 76.62300243973732, 79.26669538021088, 78.58223050832748, 78.02041545510292, 80.18800154328346, 74.91176426410675, 74.51556712388992, 72.92701676487923, 70.40544167160988, 78.81324291229248, 80.00950992107391, 77.54683166742325, 74.72428992390633, 77.53071293234825, 75.25930121541023, 71.53949081897736, 66.8090258538723, 67.78355196118355, 60.93576081097126, 76.139607578516, 73.05423393845558, 76.84338301420212, 67.67381384968758, 65.5730813741684, 68.97341251373291, 72.53349468111992, 73.11711296439171, 70.00586271286011, 65.33665806055069, 67.68937021493912, 71.44086331129074, 72.21058800816536, 67.90212079882622, 69.63774606585503, 64.43783149123192, 64.97601941227913, 73.64580899477005, 75.87491378188133, 73.19426402449608, 77.47139051556587, 70.8982752263546, 64.64555114507675, 61.19311720132828, 60.426116958260536, 58.851249665021896, 62.25791126489639, 65.81224054098129, 65.80760478973389, 68.43137919902802, 66.86049029231071, 64.67924773693085, 69.4202533364296, 68.34697812795639, 70.78472211956978, 76.08316540718079, 77.72571846842766, 80.71532964706421, 79.06547337770462, 78.99469077587128, 78.91047969460487, 80.66485315561295, 81.07670545578003, 78.42801958322525, 82.88230016827583, 79.32414069771767, 83.70509281754494, 79.96571347117424, 83.73266413807869, 72.73166924715042, 80.18804714083672, 61.06052711606026, 0.7376617204863578, 1.6311246994882822, 6.270068250596523, 3.303913213312626, 3.4714538231492043, 0.4887463100021705, 5.253296485170722, 10.001966748386621, 7.034615250304341, 0.9402579430025071, 0.588040177244693, 14.867997989058495, 53.1836561858654, 78.37785467505455, 72.11967408657074, 32.31591694056988, 39.53248970210552, 66.6954955458641, 61.302688121795654, 74.73963350057602, 32.60825805366039, 0.29529067513067275, 0.32107564620673656, 0.19254209561040625, 0.2631567494245246, 0.09883438877295703, 0.19466068973997608, 0.14510872133541852, 0.10231225605821237, 0.20617040572687984, 0.2080673203454353, 0.12458550307201222, 0.18602167518110946], [0.03550736168108415, 0.04244506206305232, 0.051221908288425766, 0.0943854583601933, 0.0579985626245616, 0.036215734216966666, 0.06553699073265307, 0.0069311249535530806, 0.04273859260138124, 0.07286449676030315, 0.03614374218159355, 0.08945866647991352, 0.055033601020113565, 0.3172841027844697, 46.70189559459686, 67.9659877717495, 54.23760183155537, 33.05015154182911, 59.0898122638464, 81.25792533159256, 25.421380698680878, 0.1058402776834555, 0.14779174845898524, 1.4840787649154663, 1.404956323094666, 1.4384628063999116, 6.886863503605127, 2.656148197129369, 0.9887946385424584, 0.2138399230898358, 38.112980872392654, 109.20231744647026, 95.17473176121712, 99.63525921106339, 93.22834700345993, 93.01926702260971, 83.65768656134605, 87.20766127109528, 86.18876874446869, 88.96933034062386, 90.14567121863365, 89.73571121692657, 88.2431361079216, 87.18613162636757, 82.03285574913025, 75.82272738218307, 65.78424364328384, 64.89148914813995, 69.49921309947968, 74.09020274877548, 80.33514484763145, 82.8647831082344, 81.58511057496071, 82.00136303901672, 71.63794353604317, 58.79399813711643, 59.190586656332016, 60.868192836642265, 58.21622394025326, 57.738274186849594, 58.46242032945156, 63.82582873106003, 67.4851767718792, 71.078871935606, 69.96949106454849, 70.20989656448364, 72.79944241046906, 76.09090179204941, 74.92888614535332, 75.84393784403801, 74.04405802488327, 68.04799497127533, 68.85577082633972, 71.8948857486248, 73.26282754540443, 73.38656410574913, 68.86834815144539, 69.88293930888176, 63.77940282225609, 66.01489126682281, 72.24350944161415, 71.23203411698341, 67.10151895880699, 68.13877210021019, 71.82394355535507, 70.8331847190857, 66.23084127902985, 65.63778430223465, 54.332938715815544, 53.84692579507828, 54.35269385576248, 64.18789610266685, 67.9690808057785, 66.2422102689743, 67.45341047644615, 69.13832366466522, 69.25933957099915, 63.40811714529991, 61.043272241950035, 62.20501810312271, 56.64527043700218, 54.44656401872635, 60.54471619427204, 65.69437846541405, 60.79964831471443, 61.352906227111816, 58.06793689727783, 57.84129045903683, 63.79230692982674, 69.0600174665451, 60.9157320857048, 67.83080622553825, 64.25957545638084, 61.763827577233315, 58.502933755517006, 53.57327587902546, 51.843141317367554, 55.97967155277729, 56.526283621788025, 58.7230559438467, 59.60604876279831, 58.253644332289696, 56.12404480576515, 58.2160909473896, 57.854023575782776, 63.49471069872379, 67.03414857387543, 71.95974826812744, 70.32834380865097, 69.633779078722, 68.85887905955315, 65.47864884138107, 68.86339321732521, 71.85896247625351, 72.66568198800087, 73.52120608091354, 76.30720138549805, 72.8257218003273, 76.26426368951797, 69.41173419356346, 74.06180307269096, 51.55447840690613, 69.28060322999954, 51.545241102576256, 0.7310206862166524, 0.4999788338318467, 1.008158577606082, 0.0782088580308482, 0.41438073792960495, 0.826783444499597, 1.459325230680406, 6.494536930695176, 1.8562271143309772, 0.04929833572532516, 0.5545040674041957, 22.963360995054245, 45.219188556075096, 62.22221598029137, 30.475206412374973, 48.573998138308525, 54.70848396420479, 48.83474014699459, 52.20224864780903, 9.5549245364964, 0.4569346545031294, 0.14162790030241013, 0.10403979773400351, 0.06828819154179655, 0.07417230197461322, 0.14985908987000585, 0.017591412106412463, 0.048851637038751505, 0.08391628536628559, 0.028383176286297385, 0.014248202878661687, 0.06475443311501294, 0.03302782402897719, 0.03362345691130031, 0.07239699567435309, 0.08258289090008475, 0.09800523170270026, 0.059219588511041366, 0.04328989700297825, 0.061095081036910415, 0.03810838519711979, 0.0419666180096101, 0.03340789640787989, 0.047775600833119825, 0.04948039939336013, 0.5758414068259299, 58.3823624253273, 73.65603804588318, 66.11403554677963, 28.64926379173994, 53.31523172557354, 94.83507558703423, 30.311951972544193, 0.030847678026475478, 0.2741722989594564, 2.7101549366489053, 2.4774720473214984, 3.4686070634052157, 3.286838117055595, 3.4578878385946155, 0.6971325015183538, 0.3050983347930014, 51.697586327791214, 114.54030901193619, 98.472650796175, 104.78263020515442, 95.23261785507202, 97.99722790718079, 90.24293079972267, 89.74247485399246, 87.7347081899643, 90.1090943813324, 92.39869952201843, 94.33594956994057, 91.23435840010643, 88.29361259937286, 86.74372896552086, 80.28580069541931, 70.98858118057251, 68.83719742298126, 71.75317615270615, 76.74126729369164, 82.88306012749672, 86.79165959358215, 84.67986971139908, 84.83352586627007, 74.84352752566338, 61.06659539043903, 61.27936117351055, 64.00893330574036, 61.12158603966236, 61.58998690545559, 60.96291035413742, 66.35236635804176, 70.23590236902237, 73.84607344865799, 72.45095551013947, 72.77470573782921, 75.92583864927292, 78.21447864174843, 78.72058108448982, 76.18544071912766, 74.88665521144867, 71.16099312901497, 72.62063160538673, 74.43351432681084, 75.65152376890182, 75.85831627249718, 72.96128332614899, 73.14933523535728, 64.73053738474846, 68.84082242846489, 74.7737404704094, 72.31685310602188, 69.70422729849815, 71.02194339036942, 75.9762467443943, 72.30109915137291, 68.658607006073, 65.7333491742611, 55.481860265135765, 54.80759024620056, 54.661016911268234, 63.10704790055752, 69.2804816365242, 68.55272948741913, 69.64629560709, 74.03480172157288, 71.7985001206398, 65.09972557425499, 63.29996354877949, 64.77301150560379, 61.74129098653793, 59.76266875863075, 64.13050398230553, 67.5871405005455, 64.40336734056473, 62.84938372671604, 61.47565484046936, 61.231050565838814, 67.27570161223412, 73.3684466779232, 66.7323611676693, 71.78577080368996, 67.5084239244461, 63.51940557360649, 61.336525306105614, 56.57305531203747, 54.38602186739445, 56.62646144628525, 60.142739564180374, 60.66330023109913, 60.733201280236244, 59.84724082052708, 60.78047834336758, 59.927845895290375, 61.18290714919567, 66.28500357270241, 70.82463517785072, 74.7486238181591, 75.99798157811165, 73.18795636296272, 69.91173416376114, 69.48108047246933, 69.38697472214699, 72.71282225847244, 76.04323714971542, 76.48684054613113, 78.15865963697433, 76.37450337409973, 78.33307787775993, 72.41586819291115, 74.5194961130619, 60.78783094882965, 71.49630233645439, 62.10243880748749, 2.928414512425661, 0.8429565641563386, 0.3862186084734276, 0.4496962804114446, 0.2369465128867887, 1.9805621425621212, 3.301274492405355, 7.138963351026177, 1.5455778711475432, 0.20967877528164536, 0.7295423874165863, 22.944626100361347, 52.29685217142105, 67.79898673295975, 29.848981015384197, 45.61628244817257, 63.2625887542963, 54.39485639333725, 60.54227292537689, 13.850501887500286, 0.38787526020314544, 0.1540627924259752, 0.04394782205054071, 0.07668044199817814, 0.015277044985850807, 0.05933645079494454, 0.07318605450564064, 0.022940994385862723, 0.05047162667324301, 0.05095518041343894, 0.05545999083551578, 0.06192777073010802, 0.11462798152933829, 0.178383476450108, 0.17828411771915853, 0.17855688667623326, 0.18654974293895066, 0.12145066386437975, 0.1510159793542698, 0.3246006992412731, 0.12092034739907831, 0.14704727043863386, 0.11621542798820883, 0.19865662063239142, 0.23140617267927155, 1.0319587192498147, 70.22530853748322, 85.29128730297089, 72.84436360001564, 45.622597709298134, 81.59859985113144, 103.10109883546829, 42.74506151676178, 0.3302841552067548, 0.26365968806203455, 4.905864978209138, 6.881902394816279, 5.443165171891451, 17.400850877165794, 11.031921431422234, 5.8626042399555445, 0.6354086135979742, 49.6781200915575, 114.91696000099182, 98.36302667856216, 107.58277595043182, 98.86518493294716, 101.38581767678261, 93.75926971435547, 92.37889498472214, 90.68035572767258, 93.92684072256088, 96.92635416984558, 98.34275096654892, 96.42269119620323, 93.53597089648247, 91.00092932581902, 83.17267298698425, 74.98094335198402, 71.32881492376328, 76.90924108028412, 79.42851349711418, 87.07127898931503, 90.33687695860863, 89.06668111681938, 91.55884578824043, 79.0032023191452, 61.32661923766136, 66.0954013466835, 67.14053526520729, 65.03522783517838, 66.3322502374649, 64.7036424279213, 70.8294229209423, 74.43506464362144, 79.52847093343735, 75.53686112165451, 77.02755153179169, 81.32084235548973, 83.71710777282715, 84.74223956465721, 82.32433050870895, 80.48107221722603, 75.68584352731705, 75.82131385803223, 76.71827092766762, 77.02741473913193, 81.21933460235596, 75.13415113091469, 76.26785829663277, 67.89782702922821, 69.28487420082092, 81.18117704987526, 75.74558392167091, 73.58832567930222, 73.18446055054665, 79.05595868825912, 74.96529579162598, 70.9938856959343, 68.08592453598976, 58.178009390830994, 57.648450806736946, 54.345356449484825, 67.46015891432762, 72.60768190026283, 73.62802594900131, 74.4599837064743, 75.07723778486252, 73.7424910068512, 67.62331455945969, 64.70962330698967, 67.50048995018005, 64.69459131360054, 63.85261729359627, 67.01339408755302, 72.19855025410652, 68.79694238305092, 67.79670685529709, 65.57367414236069, 66.17658019065857, 69.84057918190956, 76.63366466760635, 67.51614511013031, 73.13954696059227, 71.37519523501396, 67.6324188709259, 65.9198659658432, 60.68323016166687, 57.47046075761318, 61.18262216448784, 64.59356233477592, 64.85283002257347, 66.48508563637733, 64.02512043714523, 62.88588456809521, 65.22408530116081, 64.55856621265411, 71.10711202025414, 73.91127794981003, 79.21836957335472, 78.44200283288956, 75.14720723032951, 73.42097505927086, 71.71950995922089, 72.61547148227692, 74.87017929553986, 78.15590098500252, 77.87810549139977, 81.49536699056625, 78.97636815905571, 81.12817749381065, 74.1656818985939, 77.24600180983543, 64.04089719057083, 75.89490830898285, 62.95595280826092, 2.547470941208303, 2.2351671243086457, 3.7942244159057736, 0.5754726484883577, 1.0572541994042695, 2.5275611970573664, 5.483769318088889, 21.46668780595064, 3.9864401891827583, 0.22259959601797163, 1.762767091859132, 36.76270812749863, 63.23554180562496, 75.85616558790207, 45.04320479929447, 65.14742061495781, 68.00705596804619, 61.83990329504013, 70.65231442451477, 20.022201016545296, 0.7121608138550073, 0.2237056929152459, 0.29648030817043036, 0.25416378979571164, 0.27544739772565663, 0.17533920152345672, 0.17184620926855132, 0.07486356800654903, 0.1672106361365877, 0.1918448627111502, 0.0829130427155178, 0.17022495798300952], [0.047809283205424435, 0.03319751238450408, 0.08982111656223424, 0.08049804964684881, 0.14311489707324654, 0.05248857996775769, 0.0834712342475541, 0.03321745760331396, 0.011525093286763877, 0.019883349668816663, 0.04424946426297538, 0.04848526470595971, 0.16663950897054747, 1.8515735515393317, 59.900852143764496, 52.24927492439747, 50.13298988342285, 62.76633158326149, 67.99698650836945, 71.85564145445824, 8.491412904113531, 0.043726725125452504, 0.26522288855630904, 1.0232366435229778, 2.2664273343980312, 1.2691890145651996, 2.736401315778494, 0.2238962467527017, 0.24528911366360262, 45.44735871255398, 115.24534597992897, 89.88037705421448, 98.01089957356453, 89.4291664659977, 99.44438025355339, 92.41347312927246, 96.48910403251648, 82.13747173547745, 91.89053758978844, 90.53179129958153, 88.94763350486755, 86.28678068518639, 81.35358899831772, 80.24332657456398, 77.43097588419914, 69.72745165228844, 64.03053894639015, 64.9935744702816, 69.12127777934074, 79.4214990735054, 80.22957131266594, 81.8899530172348, 80.33794909715652, 77.77685612440109, 64.96552437543869, 58.245641961693764, 58.35319899022579, 59.82560858130455, 59.61886927485466, 56.854627802968025, 59.97774101793766, 59.15608450770378, 63.7375670671463, 63.4842574596405, 66.34582310914993, 66.67930081486702, 72.92453929781914, 73.39319854974747, 75.4117414355278, 76.17794752120972, 71.67170852422714, 67.19304084777832, 68.03911864757538, 70.82484796643257, 71.84946298599243, 69.08739879727364, 73.16763505339622, 62.57249638438225, 61.28777772188187, 69.2428408563137, 73.44188913702965, 67.1724383533001, 67.99081563949585, 71.78919821977615, 70.50380319356918, 64.47875529527664, 64.03886809945107, 54.80569414794445, 53.066109493374825, 54.38251465559006, 56.398291289806366, 48.61636966466904, 56.449037566781044, 70.52927702665329, 65.26348158717155, 62.623136267066, 63.877885937690735, 69.54735651612282, 66.2062793970108, 63.377224802970886, 57.38315664231777, 54.15871046483517, 62.152919098734856, 64.69034314155579, 63.66065539419651, 64.08959537744522, 62.3189739882946, 58.09035189449787, 61.65810585021973, 68.50067988038063, 65.01096233725548, 66.584442704916, 66.6271448135376, 58.58998328447342, 57.74315692484379, 54.96701069176197, 50.80268494784832, 50.55076226592064, 53.61700013279915, 53.1123112142086, 54.8697055131197, 55.83487272262573, 54.20205853879452, 53.75778637826443, 57.39247754216194, 62.72342808544636, 67.78926685452461, 68.47757712006569, 72.59179875254631, 70.13283669948578, 59.89575281739235, 65.02518877387047, 66.86488285660744, 73.89374569058418, 74.49273034930229, 75.39803937077522, 71.97268277406693, 73.70333790779114, 69.7282800078392, 72.81366884708405, 64.7722515463829, 65.71424379944801, 55.071527883410454, 63.16951274871826, 57.346663400530815, 1.6060788184404373, 1.1284109624102712, 0.09899780969135463, 0.22019802097929642, 0.6142439867835492, 0.4118804424069822, 5.946054412052035, 2.716725734062493, 0.17912025097757578, 0.04287800504243933, 12.170972060412169, 33.87749634683132, 55.0447279214859, 34.00628283619881, 30.207552574574947, 38.83710041642189, 47.6101266592741, 49.319765120744705, 13.666046485304832, 0.26470757089555264, 0.1608199134352617, 0.01519984585684142, 0.07788333721691743, 0.030583345433115028, 0.08032132202060893, 0.05862496494955849, 0.11055816983571276, 0.016435337129223626, 0.04318087922001723, 0.010520149262447376, 0.07361434792983346, 0.02182116590120131, 0.040732749257585965, 0.04551782061753329, 0.01429054704203736, 0.07322869831114076, 0.06735023562214337, 0.027244768134551123, 0.05319367592164781, 0.008821200681268238, 0.08139996687532403, 0.10150895541300997, 0.13575206481618807, 0.2260032930644229, 3.226040666922927, 72.31135860085487, 59.013645350933075, 56.86456046998501, 45.36975547671318, 75.21461561322212, 82.30123534798622, 8.981911484152079, 0.14406750298803672, 1.0628469055518508, 0.9837119362782687, 4.16946591809392, 3.3496734453365207, 4.231882793828845, 0.5148131784517318, 0.5100570211652666, 57.64571875333786, 116.18202611804008, 93.73887240886688, 102.8399008512497, 94.29520055651665, 100.44656127691269, 95.49672648310661, 97.44754940271378, 86.28181055188179, 92.84176334738731, 93.2931487262249, 91.94159165024757, 88.28255519270897, 85.70867970585823, 85.24407863616943, 80.4597781598568, 73.70365709066391, 67.0294064283371, 68.73296901583672, 73.20725172758102, 80.18741637468338, 83.23457926511765, 85.41758492588997, 82.68479436635971, 81.70016080141068, 69.25196796655655, 61.33431762456894, 62.44203798472881, 62.93862193822861, 62.850637659430504, 60.99545940756798, 60.51305249333382, 62.50355288386345, 66.41054883599281, 65.87648749351501, 68.78548219799995, 68.10280323028564, 75.51294520497322, 78.3803017437458, 78.28093707561493, 77.28900030255318, 74.10411760210991, 71.1298044025898, 72.33225747942924, 74.86585512757301, 72.90858015418053, 70.10724887251854, 77.02371373772621, 64.72739115357399, 63.80639657378197, 75.43400064110756, 77.53481671214104, 68.44778671860695, 72.17358559370041, 74.15181264281273, 72.52157852053642, 63.27683798968792, 65.85814967751503, 55.82088567316532, 54.81499224901199, 57.35406160354614, 58.06098327040672, 49.95520882308483, 54.83363024890423, 75.89635223150253, 70.70260092616081, 65.29109850525856, 65.59026405215263, 71.89481735229492, 70.53282603621483, 67.18183904886246, 61.71906217932701, 59.907205402851105, 65.40481120347977, 67.11870923638344, 66.702950745821, 67.43001893162727, 65.18809363245964, 60.25028899312019, 65.03385230898857, 70.90923383831978, 67.41961508989334, 71.59729331731796, 69.16187480092049, 64.78859826922417, 60.39455585181713, 57.960113883018494, 53.34918670356274, 52.30693303048611, 54.688329845666885, 55.696214362978935, 56.357994452118874, 58.34431126713753, 56.00040324032307, 56.81476414203644, 60.386523082852364, 65.68689286708832, 70.83332151174545, 71.5042895078659, 75.31669333577156, 70.98127037286758, 63.30963782966137, 68.02482381463051, 69.80369836091995, 76.88663229346275, 76.93741276860237, 77.09395676851273, 74.21988978981972, 74.3612802028656, 71.59644976258278, 72.30305224657059, 66.57671391963959, 70.43373495340347, 64.61611032485962, 65.8721025288105, 68.82740154862404, 3.880108594894409, 0.886701182462275, 0.22337139991577715, 0.5476945359259844, 1.2546646501868963, 1.7126584681682289, 4.61768701672554, 3.020222573541105, 0.4197019070852548, 0.025690575457701925, 11.33316831663251, 40.333672910928726, 65.6006146967411, 37.817026153206825, 25.915371291339397, 44.356061071157455, 53.17694574594498, 58.06457407772541, 17.41342630237341, 0.31190302746836096, 0.0635117365163751, 0.11318461562041193, 0.05361366471333895, 0.05228625195741188, 0.07730115205049515, 0.010803230361489113, 0.07253949544974603, 0.06210736304637976, 0.06094260679674335, 0.03178471924911719, 0.045790340955136344, 0.1903664303245023, 0.24145416944520548, 0.14381161046912894, 0.1595625519985333, 0.17374343558913097, 0.18277063791174442, 0.12347943586064503, 0.12461005331715569, 0.09146153010078706, 0.15555173362372443, 0.18258766882354394, 0.3560900845332071, 0.40954475523903966, 3.9061718713492155, 86.92177221179008, 69.62380081415176, 66.06754124164581, 88.27741026878357, 85.39266586303711, 91.64846017956734, 15.341273043304682, 0.19097991927992553, 1.2614897964522243, 4.643321391195059, 8.194122556596994, 7.99032524228096, 9.627393297851086, 3.3902521803975105, 0.7356842828448862, 58.07081714272499, 119.1619174182415, 92.82028689980507, 107.62418612837791, 96.41848862171173, 105.45780837535858, 99.43064019083977, 103.24313521385193, 89.95827287435532, 99.06807124614716, 96.58886387944221, 95.95355316996574, 93.39944422245026, 89.87028479576111, 89.69806283712387, 85.9858900308609, 79.20994162559509, 71.4288255572319, 72.0961381494999, 78.5235084593296, 84.14995774626732, 87.09421455860138, 87.7911427617073, 85.8058100938797, 85.3241403400898, 72.76807129383087, 64.54851195216179, 64.85986724495888, 66.9472624361515, 68.19663539528847, 63.02399955689907, 65.58373600244522, 67.0733092725277, 72.54283457994461, 69.13832366466522, 73.40568467974663, 73.21291342377663, 79.06310230493546, 80.76922595500946, 83.55751633644104, 79.38287794589996, 78.4146898984909, 74.96980234980583, 76.34054839611053, 79.29159924387932, 76.17951303720474, 73.81585747003555, 79.79397788643837, 67.51157015562057, 64.07507255673409, 76.58450290560722, 80.50041317939758, 74.50827151536942, 75.96680045127869, 77.00184971094131, 74.7549694776535, 68.72603818774223, 68.12931060791016, 57.03897871077061, 55.62417022883892, 59.11895290017128, 57.77277633547783, 49.7913084179163, 57.42372706532478, 78.38096290826797, 71.98079913854599, 68.35698679089546, 69.56130176782608, 74.8317101597786, 72.04414933919907, 68.84325429797173, 65.2498859167099, 66.10366970300674, 69.9263633787632, 70.22311225533485, 70.04623174667358, 70.99197819828987, 69.84870314598083, 63.48002828657627, 67.4465860426426, 74.55016806721687, 71.15777090191841, 70.15118971467018, 73.05594384670258, 67.22606107592583, 64.42643970251083, 61.04569651186466, 56.978805139660835, 56.93651340901852, 59.58968684077263, 60.863348096609116, 61.02503702044487, 63.35893638432026, 59.20931205153465, 60.342388451099396, 64.46340411901474, 69.0425156056881, 74.30084824562073, 74.30552959442139, 77.48533576726913, 76.085065305233, 64.77940276265144, 66.92829385399818, 73.16348567605019, 80.14757931232452, 79.16027069091797, 79.07149985432625, 76.56114175915718, 77.63298824429512, 73.95850941538811, 74.59314376115799, 72.80996784567833, 74.64570254087448, 63.93130347132683, 70.2069403231144, 66.50755763053894, 3.258254863321781, 2.157777389511466, 1.6413690685294569, 0.7615093002095819, 1.071727266535163, 0.9208052430767566, 12.455278504639864, 6.032963348552585, 0.46081768989097327, 0.1446285072597675, 18.87974862009287, 51.82003855705261, 69.34147596359253, 50.11506624519825, 42.71731920540333, 49.27684262394905, 60.287678986787796, 68.58043760061264, 21.457258611917496, 0.4504088906105608, 0.3380233602365479, 0.1859901042189449, 0.2228737305267714, 0.11375711575965397, 0.1751096107182093, 0.1421098064747639, 0.22213851450942457, 0.14016376168001443, 0.14127903152257204, 0.16288159968098626, 0.2691013226285577], [0.02771463852695888, 0.07253988878801465, 0.060315603332128376, 0.01813601305912016, 0.07887178886448964, 0.041096323693636805, 0.06990683788899332, 0.029694272925553378, 0.03010540604009293, 0.003169442306898418, 0.05795337325253058, 0.1290319176041521, 0.33884494740050286, 8.02006434649229, 63.98613452911377, 43.3857299387455, 29.35367189347744, 29.40591339021921, 78.68983313441277, 48.36676485836506, 1.982536967843771, 0.038830609919386916, 0.9151445562019944, 1.9109444157220423, 0.5022079485934228, 4.1738523077219725, 1.206594379618764, 0.5488070449791849, 27.275438010692596, 106.54570519924164, 90.9939680993557, 100.82366824150085, 89.95270997285843, 93.13291892409325, 87.12610244750977, 92.04097911715508, 90.28405979275703, 92.27547213435173, 84.4312110543251, 89.61119949817657, 88.5927477478981, 83.40562328696251, 80.11845007538795, 73.66255089640617, 69.31017324328423, 65.33978909254074, 63.25836718082428, 64.20111179351807, 72.79641777276993, 78.02689790725708, 78.48080635070801, 79.84092056751251, 79.52592507004738, 78.67230087518692, 61.362500712275505, 57.267969623208046, 58.2515924423933, 61.19234964251518, 61.7158817499876, 60.158493518829346, 58.55465658009052, 58.434940204024315, 58.63363154232502, 60.84165886044502, 62.68068037927151, 64.62206080555916, 68.7523327767849, 73.93875807523727, 74.0392778813839, 73.13901498913765, 70.38639709353447, 65.24180755019188, 70.05346655845642, 70.66141113638878, 71.06725975871086, 74.1557264328003, 65.81449761986732, 61.196768805384636, 68.9991295337677, 71.40245497226715, 67.18531206250191, 66.04209020733833, 70.73511198163033, 68.30148696899414, 62.122767716646194, 57.765655517578125, 59.71780836582184, 56.90294601023197, 59.6929918974638, 58.20536412298679, 57.52195559442043, 58.53211238980293, 54.88555446267128, 62.4520580470562, 69.07943442463875, 71.49199336767197, 63.64274315536022, 63.48884381353855, 66.23588740825653, 62.59002484381199, 59.271913692355156, 52.18014903366566, 57.494129687547684, 63.00026223063469, 60.501972287893295, 64.61448401212692, 63.352210745215416, 62.23489589989185, 60.30281737446785, 66.39028072357178, 66.07518643140793, 65.019641071558, 66.75960570573807, 61.320379972457886, 59.868428483605385, 56.61354213953018, 54.42644029855728, 51.34524263441563, 50.29567815363407, 49.58901107311249, 49.51786749064922, 51.57916948199272, 52.21242070198059, 54.059828370809555, 55.619956254959106, 61.47196903824806, 66.81218728423119, 71.00916087627411, 71.02830424904823, 59.98876802623272, 71.66882827877998, 73.58995959162712, 73.33018273115158, 72.48053312301636, 72.70553424954414, 73.95642712712288, 71.83801040053368, 71.8562114238739, 69.99741956591606, 64.24837365746498, 66.99121087789536, 70.21353676915169, 77.60084196925163, 65.82775890827179, 70.04678651690483, 56.0524832457304, 0.27686202025506645, 0.6749781465623528, 0.6410374771803617, 1.1410623835399747, 2.3676778888329864, 2.857035817578435, 1.8857890530489385, 0.3742221475113183, 0.27064314926974475, 2.747302455827594, 26.14396322518587, 46.8039695173502, 49.665877148509026, 39.5936132222414, 43.49903225898743, 39.673940911889076, 49.21300604939461, 13.242479413747787, 0.22017450974090025, 0.10806136240717024, 0.04537145796348341, 0.058785105575225316, 0.026035169466922525, 0.05501404913957231, 0.019608285620051902, 0.013890315149183152, 0.03600047799409367, 0.047626841042074375, 0.029581661292468198, 0.09041194774908945, 0.04774253444338683, 0.03636962966993451, 0.01356212353130104, 0.027033901715185493, 0.044825775330537, 0.06239326059585437, 0.09157463340670802, 0.056860494005377404, 0.03490507915557828, 0.024735485203564167, 0.03934835440304596, 0.16553491121158004, 0.38580707274377346, 12.474077995866537, 75.73027074337006, 52.59820260107517, 43.873749151825905, 30.478303246200085, 87.69643664360046, 55.38281477987766, 2.1518347458913922, 0.10561047165538184, 0.7944586384110153, 2.2585940547287464, 2.4522905610501766, 3.549749096855521, 1.0719518107362092, 0.3470734949223697, 36.53679125010967, 111.09672099351883, 93.90195965766907, 104.0020152926445, 93.50159794092178, 96.50992691516876, 89.38498243689537, 95.5644616484642, 92.21234992146492, 96.78982749581337, 88.73236745595932, 90.31285464763641, 91.19229465723038, 86.81594789028168, 83.53419318795204, 77.00487434864044, 72.85777688026428, 67.31294721364975, 66.92999616265297, 67.38863155245781, 75.55610328912735, 80.2971924841404, 81.09043791890144, 83.19350346922874, 84.35167372226715, 80.11892884969711, 64.88807693123817, 60.83317391574383, 62.118428349494934, 65.1691022515297, 64.98487293720245, 62.72802583873272, 60.3249853849411, 59.70866225659847, 61.811651811003685, 62.22468964755535, 64.13703203201294, 67.90136843919754, 70.9443211555481, 78.23075696825981, 76.67813748121262, 75.98750174045563, 72.94112920761108, 68.636993765831, 75.01225367188454, 73.2597953081131, 73.9121063053608, 76.35076224803925, 67.06569448113441, 63.4430106729269, 73.55597421526909, 74.53045472502708, 68.92768576741219, 71.21688812971115, 76.08688160777092, 69.9466846883297, 64.21190321445465, 60.59847950935364, 60.94639264047146, 58.71598832309246, 60.710752084851265, 61.08434043824673, 62.80010797083378, 60.61614856123924, 57.25791536271572, 62.243430241942406, 69.88711908459663, 74.83821541070938, 69.02489975094795, 65.88739290833473, 68.9328382909298, 66.49494230747223, 63.07913079857826, 56.36509247124195, 60.25493614375591, 67.98302605748177, 63.30601282417774, 68.41677278280258, 66.23729333281517, 65.31035587191582, 61.311564445495605, 70.37871390581131, 70.20872622728348, 70.69680243730545, 67.8563180565834, 64.67777341604233, 63.138525411486626, 59.15816679596901, 58.90444681048393, 54.98068615794182, 51.74840100109577, 53.53514112532139, 51.15002050995827, 53.91260527074337, 54.51077297329903, 57.5329902023077, 57.5052934885025, 63.37138831615448, 67.54730343818665, 73.44376623630524, 72.45572805404663, 62.437124848365784, 71.36571854352951, 73.98412764072418, 75.0348548591137, 75.19585981965065, 74.99399185180664, 75.52017241716385, 72.55994886159897, 72.51050591468811, 69.68156531453133, 67.9622183740139, 71.71425864100456, 75.59462562203407, 77.9749470949173, 72.56474420428276, 72.32083529233932, 67.2753444314003, 1.9295856216922402, 0.6667164992541075, 0.07998083208804019, 1.0524241835810244, 2.501756069250405, 4.325239509344101, 2.949415985494852, 1.8914128700271249, 0.33506278472486883, 2.459029736928642, 27.90395088493824, 54.39791142940521, 51.10329441726208, 31.308425702154636, 51.023080721497536, 45.611863285303116, 58.768421709537506, 15.925884023308754, 0.18267696403199807, 0.09383790180436336, 0.03492434159852564, 0.08549270351068117, 0.05927678954321891, 0.0449768691760255, 0.08647016395116225, 0.05934059197898023, 0.06794683329644613, 0.020038792499690317, 0.02268013689899817, 0.05549381792661734, 0.13225693517597392, 0.15507609117776155, 0.09450691082747653, 0.10060648899525404, 0.15585951710818335, 0.21100005047628656, 0.23509589344030246, 0.15749432001030073, 0.13507043186109513, 0.10212378023425117, 0.27611663681454957, 0.33377780055161566, 0.6083812576252967, 14.212866593152285, 89.81262668967247, 60.31061075627804, 42.50368706882, 45.44439107179642, 97.52979978919029, 68.35685759782791, 3.2816675445064902, 0.10452147384057753, 1.2960042944177985, 7.8041081596165895, 4.707349855452776, 14.08891249448061, 7.173869227990508, 0.9152920951601118, 38.37144300341606, 109.2645201086998, 97.61192098259926, 109.41193699836731, 98.16932827234268, 100.3484657406807, 93.94556611776352, 100.9194914996624, 96.96398735046387, 97.26253733038902, 94.43678095936775, 97.35115617513657, 96.28256231546402, 89.84264507889748, 89.56402122974396, 81.10964968800545, 74.97674077749252, 72.4414636194706, 73.20077687501907, 71.59959599375725, 79.31504398584366, 84.02828067541122, 85.03904163837433, 87.21919745206833, 87.00438737869263, 85.99246367812157, 67.29852318763733, 62.938500344753265, 65.02004384994507, 68.05488780140877, 70.82670986652374, 66.24202787876129, 67.0296648144722, 66.00413784384727, 65.8463703095913, 65.42760998010635, 69.1070057451725, 71.59122124314308, 75.30210211873055, 82.7105113863945, 78.53145763278008, 81.70227348804474, 74.94508847594261, 73.79451021552086, 78.86606007814407, 78.16920787096024, 76.77181765437126, 78.47319915890694, 71.43238216638565, 63.87356176972389, 75.31604737043381, 78.35187926888466, 73.12994867563248, 71.71668291091919, 77.52004310488701, 73.59981626272202, 68.81637454032898, 60.58531701564789, 63.22932913899422, 60.77593378722668, 63.79967853426933, 63.14812749624252, 63.42841185629368, 63.15043397247791, 56.9061454385519, 64.59513545036316, 74.08484503626823, 78.87511119246483, 70.83308592438698, 69.65650945901871, 72.84358084201813, 70.5502139031887, 64.53853368759155, 62.55509711802006, 63.92045125365257, 71.24015048146248, 68.65858420729637, 69.33546468615532, 70.32576754689217, 69.47483360767365, 65.9493599832058, 73.80788549780846, 72.83100351691246, 72.66109943389893, 73.25461238622665, 67.65122026205063, 66.49773135781288, 61.18202179670334, 62.37959213554859, 58.255658224225044, 56.05160929262638, 55.89582145214081, 55.20944528281689, 57.4414037168026, 57.67091140151024, 60.22318124771118, 61.543796584010124, 66.91593691706657, 70.62160447239876, 77.14379489421844, 77.63204589486122, 65.29381915926933, 74.5248994231224, 77.13682606816292, 78.97091925144196, 76.90977305173874, 77.64327809214592, 79.85105082392693, 76.36625781655312, 73.22244331240654, 75.17676204442978, 71.1269773542881, 74.0528355538845, 77.6261106133461, 84.28948625922203, 73.74105468392372, 78.72350692749023, 67.79566571116447, 1.9559349515475333, 2.018005927093327, 2.1682230290025473, 1.8371072527952492, 5.061958702281117, 7.663328088819981, 5.45450328849256, 1.4964225213043392, 0.3049134212778881, 3.69362885132432, 43.38369704782963, 61.369359344244, 68.6991660296917, 54.99666050076485, 54.71185818314552, 51.97636976838112, 68.58606889843941, 20.928957760334015, 0.42307422612793744, 0.228801635093987, 0.16818354721181095, 0.1973549826652743, 0.20329787861555815, 0.2673901675734669, 0.23626847192645073, 0.2006976306438446, 0.1826733720372431, 0.12449215573724359, 0.0849771335197147, 0.22613904671743512], [0.007391529252345208, 0.05314200388966128, 0.029231369444460142, 0.1080158464901615, 0.009086451682378538, 0.03539984303642996, 0.03787128756812308, 0.04244199699314777, 0.059795361521537416, 0.026732432052085642, 0.07357694368693046, 0.10006934477132745, 0.23992889269720763, 22.421694360673428, 60.66848695278168, 48.91351751983166, 29.7128951177001, 35.39879411458969, 88.67451936006546, 24.820729829370975, 0.12005997559754178, 0.09164521165075712, 0.49880196573212743, 0.5043775134254247, 2.359046177007258, 2.4195959279313684, 3.176427916623652, 5.206613140180707, 88.49869519472122, 93.98787304759026, 98.42038840055466, 86.9375641644001, 90.4364924132824, 84.26534995436668, 86.85767725110054, 86.03962674736977, 90.46776473522186, 90.7855036854744, 92.3340953886509, 82.10423871874809, 89.42293480038643, 80.60872256755829, 76.49235025048256, 70.63754081726074, 65.17023459076881, 61.5574112534523, 62.57984519004822, 65.2706328034401, 72.29155406355858, 75.10016575455666, 79.86142426729202, 78.16277861595154, 79.2572794854641, 68.64465415477753, 58.19965682923794, 56.307008787989616, 58.155886977910995, 59.5293802767992, 63.70175398886204, 61.85319498181343, 58.58249008655548, 55.71833297610283, 57.26035103201866, 59.377620220184326, 60.76508156955242, 61.634900495409966, 69.77697059512138, 70.46007513999939, 73.64420548081398, 72.51198783516884, 69.07834008336067, 66.47889956831932, 71.53259798884392, 70.48808723688126, 74.32291746139526, 65.2691812813282, 62.8875944763422, 67.62653678655624, 69.75218832492828, 68.51945847272873, 68.37394148111343, 72.06977516412735, 65.79435110092163, 60.621373280882835, 57.88561888039112, 61.24297812581062, 62.61148229241371, 61.375518813729286, 60.378361120820045, 59.850223660469055, 60.30628278851509, 65.84473639726639, 70.23250535130501, 63.96577522158623, 58.663786724209785, 58.69785949587822, 64.28830191493034, 67.065170109272, 63.93721595406532, 62.67922505736351, 61.08402505517006, 54.860012233257294, 50.092544853687286, 63.799655735492706, 59.891580641269684, 66.21786877512932, 62.649009078741074, 61.94567061960697, 59.395198076963425, 66.61690056324005, 65.01296862959862, 63.780025988817215, 64.15048331022263, 63.14652018249035, 60.34936107695103, 59.69067022204399, 57.48551554977894, 58.08766923844814, 55.07380396127701, 51.63985222578049, 50.74548661708832, 53.97978566586971, 51.778742372989655, 53.74674417078495, 53.03815819323063, 61.20276868343353, 68.86995166540146, 71.86906233429909, 66.08764216303825, 69.27836894989014, 69.26889225840569, 68.62438604235649, 70.3481787443161, 68.70827034115791, 71.78448647260666, 68.76359537243843, 69.9494357407093, 69.36627343297005, 64.24798607826233, 70.28348341584206, 71.9610857963562, 79.05279725790024, 71.78764790296555, 78.25126066803932, 66.84374079108238, 67.37947404384613, 42.04162046313286, 0.10469700660905801, 0.7670068927109241, 3.8873633556067944, 6.127646192908287, 2.1956618316471577, 1.2216972629539669, 1.6506714443676174, 0.1147218409460038, 0.2614171849563718, 25.4583603143692, 37.081514820456505, 62.452286034822464, 29.30461272597313, 29.528025537729263, 37.72973723709583, 42.71713301539421, 16.97184629738331, 0.17483295290730894, 0.1253140249173157, 0.14929171797120944, 0.07955615292303264, 0.07953172142151743, 0.07634988200152293, 0.014551478743669577, 0.0490947794605745, 0.021516349152079783, 0.023673301184317097, 0.013099363841320155, 0.08480157106532715, 0.039525534739368595, 0.04401236663397867, 0.014521740886266343, 0.05437356827314943, 0.04107252672838513, 0.06399421414243989, 0.03391696147446055, 0.04707722873718012, 0.0400893888581777, 0.04333871547714807, 0.15926273918012157, 0.23687091772444546, 0.26714294333942235, 32.35636956989765, 68.29695001244545, 60.53938888013363, 39.22007046639919, 38.10662381350994, 102.03608438372612, 26.331344470381737, 0.10425506508909166, 1.1334442673251033, 1.567971019539982, 3.0005446169525385, 2.5836977222934365, 3.621109980158508, 2.08178645465523, 8.911982886493206, 99.28007706999779, 98.93556475639343, 104.06603425741196, 90.33833608031273, 95.84569975733757, 87.54058420658112, 92.40359365940094, 87.3959943652153, 92.71684885025024, 91.66961744427681, 94.4386276602745, 86.55778974294662, 93.04049268364906, 82.64725998044014, 78.37339371442795, 72.05833777785301, 68.06355893611908, 65.59655651450157, 66.15318104624748, 68.26231107115746, 73.86643275618553, 78.99784460663795, 82.88837984204292, 81.1182752251625, 80.46350196003914, 72.53503739833832, 62.445898577570915, 60.37673860788345, 60.39028488099575, 63.12889292836189, 64.99129459261894, 64.63615044951439, 61.4545089751482, 58.549264669418335, 61.12068168818951, 62.21263289451599, 65.01547649502754, 65.65432861447334, 72.89195224642754, 72.50752687454224, 77.20021426677704, 74.5880064368248, 74.46876883506775, 69.50941935181618, 74.03144270181656, 74.75569143891335, 76.60211116075516, 67.15049833059311, 66.81622266769409, 73.03136676549911, 72.80750557780266, 69.89919483661652, 71.49319410324097, 73.067966401577, 69.81869995594025, 61.64872795343399, 59.36066932976246, 61.28927484154701, 63.446597680449486, 62.67736315727234, 63.45176160335541, 63.264382258057594, 60.37666641175747, 68.92802774906158, 72.44546860456467, 67.07704067230225, 61.620818451046944, 59.1230832785368, 64.2483052611351, 71.59537822008133, 67.01722428202629, 66.42958581447601, 61.53615899384022, 58.43230314552784, 55.37914797663689, 64.24296274781227, 65.6692086160183, 68.96666407585144, 67.34415873885155, 65.1277756690979, 66.13123342394829, 65.50264835357666, 71.22607603669167, 68.70000958442688, 66.85213074088097, 66.68203666806221, 62.844550386071205, 62.675018683075905, 63.19426842033863, 61.88137806952, 59.72439341247082, 53.83935660123825, 54.46782007813454, 55.28933599591255, 53.95948715507984, 57.812750190496445, 55.26268042623997, 63.825456351041794, 71.18712812662125, 74.22927528619766, 68.96401181817055, 69.7189325094223, 72.29178965091705, 71.6142176091671, 72.99180328845978, 72.51460209488869, 74.8731355369091, 72.6748850941658, 74.3370071053505, 71.98949307203293, 70.65214723348618, 73.06223630905151, 74.15609881281853, 80.72360560297966, 77.47900530695915, 80.0820404291153, 73.64743530750275, 72.45560646057129, 53.65427993237972, 0.05236206605331972, 0.5555094103328884, 2.0440150564536452, 6.158301047980785, 5.8238358702510595, 2.5400839000940323, 1.76138254115358, 0.30524320201948285, 0.2196230791741982, 27.23261620849371, 42.42387235164642, 68.86391758918762, 26.7944161221385, 30.31129650771618, 43.99413429200649, 50.883476212620735, 21.350932717323303, 0.1313724584178999, 0.04223291914968286, 0.05544062820263207, 0.017982746576308273, 0.03701172841829248, 0.09083716126042418, 0.03708874479343649, 0.004800419437742676, 0.021484536991920322, 0.06507527097710408, 0.10008798009948805, 0.053549981021205895, 0.13651718938490376, 0.19912930933060125, 0.15447651006979868, 0.2536077133845538, 0.1955695089418441, 0.11334044436807744, 0.08980821803561412, 0.16321639734087512, 0.2152543526608497, 0.15828632516786456, 0.24522362655261531, 0.42372547555714846, 0.490205847308971, 37.07407481968403, 80.93719974160194, 65.21295189857483, 39.85880099236965, 51.11625172197819, 109.25117522478104, 37.619600147008896, 0.3066262090578675, 0.8794026647228748, 4.171096505597234, 6.240610331296921, 8.118141833692789, 15.755766201764345, 5.7892349269241095, 7.478601476177573, 103.81289944052696, 103.03391844034195, 111.85883849859238, 93.0243131518364, 100.31814336776733, 91.31275579333305, 95.75390428304672, 93.20616379380226, 99.75362285971642, 96.23004913330078, 99.74459454417229, 91.3128013908863, 98.75068947672844, 88.1088437139988, 84.43475246429443, 75.3282979130745, 71.83656647801399, 68.79806712269783, 70.3654146194458, 72.93026179075241, 78.89771237969398, 81.5835602581501, 86.9136406481266, 84.70750942826271, 86.54733270406723, 77.15733736753464, 64.02983978390694, 63.53048577904701, 63.89273554086685, 67.75953724980354, 70.98680287599564, 69.15918454527855, 66.83709114789963, 61.542459055781364, 64.87736150622368, 64.90159660577774, 69.97997090220451, 69.04714375734329, 76.79802104830742, 77.1149392426014, 79.21374902129173, 79.11515951156616, 76.09169214963913, 72.45256662368774, 79.32820647954941, 79.44763407111168, 82.05611810088158, 70.23385807871819, 68.13437193632126, 74.45907175540924, 74.63664382696152, 75.39360880851746, 75.6534768640995, 76.64488926529884, 72.46465757489204, 64.31781873106956, 58.88381011784077, 62.561252787709236, 66.32582858204842, 65.31263574957848, 65.72446525096893, 66.592847853899, 63.46885308623314, 72.39165589213371, 77.32979491353035, 67.93207079172134, 63.98707687854767, 61.649537310004234, 68.99291306734085, 75.06257817149162, 68.57356756925583, 68.63114967942238, 67.24890545010567, 61.810914650559425, 59.56514775753021, 70.69459855556488, 69.76528242230415, 73.18363219499588, 69.27459955215454, 70.60232430696487, 66.94413900375366, 70.85644707083702, 72.66139581799507, 70.46613201498985, 72.50399306416512, 68.66147965192795, 65.23923128843307, 64.59563702344894, 66.1042320728302, 64.1627262532711, 61.21726110577583, 57.36701890826225, 59.90426056087017, 59.08793896436691, 57.14015208184719, 59.88787584006786, 57.66378678381443, 65.64593106508255, 75.92038974165916, 75.92189446091652, 72.95268058776855, 72.36775517463684, 77.05176383256912, 76.05305582284927, 77.19240188598633, 75.12716710567474, 79.14455473423004, 75.80381959676743, 75.72132602334023, 78.00269320607185, 72.77106553316116, 75.01780897378922, 76.63689449429512, 85.34440085291862, 80.79750403761864, 83.95075723528862, 75.60023412108421, 74.88657921552658, 52.793496921658516, 0.23313159181270748, 2.0425490476191044, 8.234032765030861, 14.424733724445105, 8.160982634872198, 5.7811532355844975, 2.997756516560912, 0.6866121129132807, 0.4196633450919762, 38.190834894776344, 51.56091146171093, 82.04279601573944, 44.3081646412611, 36.57633192837238, 50.07748246192932, 60.36376230418682, 28.186800107359886, 0.38674277253448963, 0.27525123325176537, 0.26064122503157705, 0.27758442680351436, 0.19765472126891837, 0.21197719179326668, 0.1103248460276518, 0.14878874964779243, 0.15995885885786265, 0.11719528556568548, 0.2976583340205252, 0.18843827128876], [0.08993839815957472, 0.023183791709016077, 0.011654345726128668, 0.07954614135087468, 0.019387671090953518, 0.06364059561747126, 0.04468879342311993, 0.009980304548662389, 0.021669814159395173, 0.017729258615872823, 0.03549976579961367, 0.03584541736927349, 0.0633927331364248, 41.42951510846615, 53.50041478872299, 36.48710511624813, 35.80998905003071, 55.66425047814846, 76.93489730358124, 8.939064983278513, 0.03381843023817055, 0.2505975920939818, 1.9372672657482326, 1.9697907892987132, 2.8280433733016253, 3.246518955565989, 0.4412137105828151, 44.043049067258835, 103.32839503884315, 89.9035482108593, 92.83205106854439, 86.05174049735069, 88.35055634379387, 81.60513550043106, 81.01983770728111, 81.02886602282524, 89.2897367477417, 86.15883395075798, 91.22248023748398, 85.90604111552238, 85.51691919565201, 81.63921967148781, 73.96110847592354, 68.94876703619957, 62.25592777132988, 63.90205264091492, 62.20772735774517, 63.59597906470299, 70.87518006563187, 76.09067380428314, 77.45688289403915, 75.66168442368507, 75.64183428883553, 60.433541759848595, 56.67583219707012, 57.68334053456783, 56.50292627513409, 61.95783756673336, 59.375731721520424, 61.82210125029087, 59.824069663882256, 55.63284136354923, 56.08191266655922, 58.22439730167389, 58.52424681186676, 63.55083368718624, 67.03525051474571, 71.33943155407906, 72.67756775021553, 74.63184848427773, 66.44161596894264, 70.01730769872665, 66.20459988713264, 72.95403331518173, 70.77506303787231, 64.61584433913231, 67.12751716375351, 66.46028056740761, 66.83516085147858, 69.5888502895832, 71.81973338127136, 62.08399459719658, 60.122486650943756, 60.74820287525654, 61.2400408834219, 62.463392838835716, 61.753142550587654, 60.51748685538769, 62.14838594198227, 61.469856351614, 63.15240986645222, 62.071899846196175, 64.57412257790565, 64.87564399838448, 67.50398576259613, 62.100926488637924, 54.054493457078934, 62.15629331767559, 64.13453176617622, 64.37551483511925, 58.5124446451664, 58.22600081562996, 54.744205847382545, 55.25814346969128, 55.250604674220085, 59.451176673173904, 62.57650136947632, 65.75848862528801, 60.376826003193855, 69.25477221608162, 67.19880133867264, 54.38210807740688, 64.64006423950195, 62.435779720544815, 63.3412217348814, 61.44785933196545, 63.328310027718544, 60.78844651579857, 61.54015637934208, 55.111627131700516, 50.22849015891552, 49.15799260139465, 51.01999148726463, 50.68250499665737, 52.35949940979481, 60.19257389008999, 67.2974744439125, 67.56403014063835, 69.51262637972832, 69.08741399645805, 69.84025999903679, 67.3775589466095, 67.38747641444206, 63.98639291524887, 69.50528517365456, 68.94127383828163, 72.82275035977364, 65.13042032718658, 73.46734777092934, 70.42001008987427, 75.58176711201668, 69.30948927998543, 82.00365051627159, 71.72600001096725, 78.62088963389397, 67.05322355031967, 82.35822468996048, 18.400801420211792, 0.42755958857014775, 1.5178612084127963, 1.8762618955224752, 4.3120865151286125, 1.081480155698955, 3.132495149038732, 0.055747313308529556, 0.693963827798143, 10.184056777507067, 44.84147362411022, 43.814707919955254, 53.628315925598145, 38.36618788540363, 46.44502177834511, 39.92632336914539, 18.623235784471035, 0.321465244051069, 0.026908649451797828, 0.015289091898011975, 0.03142951994959731, 0.013787572224828182, 0.13903903687605634, 0.027570385427679867, 0.10448352782987058, 0.04765917270560749, 0.06952288036700338, 0.05718031883588992, 0.04820244706934318, 0.09585148203768767, 0.0612771855230676, 0.038426536484621465, 0.04677756434830371, 0.03494348158710636, 0.044147496882942505, 0.05266840977128595, 0.029827373400621582, 0.08890881668776274, 0.06790962943341583, 0.012612117916432908, 0.10097593010868877, 0.1069892336090561, 53.12496833503246, 60.915819481015205, 48.65682229399681, 33.000909984111786, 56.23711533844471, 93.67347791790962, 10.438544321805239, 0.03218789097445551, 0.6856160319875926, 1.2596381083130836, 2.1764075523242354, 2.7152632875368, 5.695853037759662, 1.0994201805442572, 51.18423767387867, 107.25821256637573, 94.07171934843063, 97.04252153635025, 89.69905078411102, 90.98617851734161, 85.95229223370552, 83.95855441689491, 85.74007362127304, 91.6277588903904, 90.29548197984695, 91.23829498887062, 87.26252272725105, 89.93555769324303, 84.0434418618679, 76.74074292182922, 71.36198714375496, 66.18617087602615, 66.73942878842354, 64.93394806981087, 68.35626482963562, 74.02915522456169, 79.05609548091888, 81.53445929288864, 78.08853819966316, 77.77161240577698, 64.68877762556076, 60.061499923467636, 59.82732988893986, 60.626579001545906, 63.997982293367386, 62.40717485547066, 66.24543249607086, 63.99856746196747, 58.5780481249094, 59.15300667285919, 61.32576048374176, 63.20319414138794, 65.79308956861496, 70.30636578798294, 76.88568234443665, 74.5002007484436, 77.75544807314873, 71.01948112249374, 70.79243570566177, 69.55028995871544, 74.63626384735107, 72.67362356185913, 67.42473721504211, 69.73621398210526, 67.97310099005699, 69.67746153473854, 75.0638473033905, 73.41214433312416, 64.24388989806175, 60.23960016667843, 62.24837377667427, 64.01164636015892, 64.46357890963554, 63.11567343771458, 66.05446234345436, 64.16926190257072, 62.952570989727974, 66.53065279126167, 63.211534693837166, 66.84545069932938, 67.74065226316452, 68.94014149904251, 66.66622191667557, 57.14505761861801, 61.538841649889946, 66.56361222267151, 66.35795205831528, 59.861885234713554, 59.93571147322655, 58.79490248858929, 60.50207108259201, 59.42380674183369, 60.442357286810875, 65.13653799891472, 70.27627900242805, 62.39139050245285, 69.88518878817558, 72.64925166964531, 57.66400717198849, 65.43930575251579, 64.22690480947495, 65.52578911185265, 67.01190456748009, 67.17787206172943, 64.66293901205063, 63.64573359489441, 58.878475204110146, 53.276963979005814, 53.63193713128567, 52.529483288526535, 53.40284742414951, 55.665565207600594, 63.15465174615383, 70.75465813279152, 70.76591312885284, 72.03707411885262, 69.10501465201378, 71.94808289408684, 69.02830436825752, 70.26481121778488, 66.63504838943481, 72.36426696181297, 72.43860617280006, 76.1266502737999, 70.19411221146584, 77.42173478007317, 72.96939969062805, 78.5290789604187, 72.77310982346535, 84.53207284212112, 74.91494849324226, 84.40922543406487, 73.00180435180664, 88.74285489320755, 26.603170484304428, 0.13213590573286638, 0.3244566929060966, 3.8234541099518538, 8.162296414375305, 5.494267204776406, 4.412093823775649, 0.5278159619774669, 0.6250340421684086, 9.554203525185585, 52.74011358618736, 50.870423913002014, 48.515044301748276, 29.703296832740307, 53.973888382315636, 46.63630351424217, 27.174980901181698, 0.2499778987839818, 0.13954596826806664, 0.06302858353592455, 0.05026037062634714, 0.07832355695427395, 0.08569407786126249, 0.05052896129200235, 0.03360473994689528, 0.03953941290092189, 0.027802989352494478, 0.0798079339438118, 0.03961733098549303, 0.18279633106430992, 0.16109110903926194, 0.11576547869481146, 0.18038319336483255, 0.14157513360260054, 0.10844527540029958, 0.1615241967374459, 0.0979291096155066, 0.17761710507329553, 0.1488344362587668, 0.16419385035987943, 0.26209405332338065, 0.31029877136461437, 61.35937348008156, 74.70434859395027, 47.743655294179916, 52.32937842607498, 70.48377826809883, 101.55813843011856, 16.190617717802525, 0.19259548571426421, 0.42753322748467326, 4.728996343910694, 6.927516097202897, 9.59427997469902, 12.316473852843046, 1.72403066419065, 53.339007049798965, 112.94507101178169, 98.2924796640873, 101.5572340786457, 96.42145246267319, 95.77745541930199, 90.56133091449738, 88.2303535938263, 90.45567378401756, 96.15941852331161, 95.810566842556, 96.30315721035004, 92.82758250832558, 93.9439246058464, 87.27752432227135, 79.60426166653633, 76.03873059153557, 70.48410505056381, 71.92015439271927, 70.76057821512222, 71.20697066187859, 77.360710054636, 83.43548208475113, 84.65732932090759, 81.66609942913055, 83.61627638339996, 67.48975172638893, 61.73178009688854, 64.47278961539268, 63.636648282408714, 66.64663776755333, 67.79250428080559, 69.65799137949944, 68.50724592804909, 61.65278613567352, 62.65058219432831, 64.4484481215477, 66.36854588985443, 68.40042605996132, 74.07694146037102, 79.8997414112091, 79.40671026706696, 82.20286622643471, 73.55275958776474, 75.78849121928215, 73.18724200129509, 78.02225455641747, 76.12709105014801, 68.57330158352852, 71.0925056040287, 71.34878665208817, 72.29703336954117, 76.23457208275795, 77.77153640985489, 67.84741893410683, 60.95471419394016, 65.2430234849453, 66.13339930772781, 68.02097842097282, 67.20155999064445, 70.64236655831337, 65.08399441838264, 63.377429991960526, 68.62795025110245, 65.55605068802834, 73.13368007540703, 73.09304505586624, 72.65186592936516, 65.71305826306343, 57.076957672834396, 65.00243559479713, 69.02207270264626, 69.80944365262985, 62.80497930943966, 65.17355561256409, 65.31207337975502, 61.27578556537628, 63.653181195259094, 65.73122888803482, 70.22661566734314, 73.713338971138, 65.31062185764313, 73.3563481271267, 72.38993838429451, 60.63214190304279, 69.16278675198555, 66.49558827280998, 68.49039003252983, 67.56746515631676, 69.06334608793259, 66.4011861383915, 67.32434660196304, 61.29970908164978, 56.29852004349232, 55.566667914390564, 55.64901329576969, 55.72605416178703, 58.649157509207726, 66.48729711771011, 74.8456934094429, 75.4841123521328, 74.37204122543335, 73.66844058036804, 76.45770370960236, 73.45662474632263, 73.06603610515594, 71.5927791595459, 75.49344465136528, 76.31151035428047, 78.60425412654877, 75.23621365427971, 78.70250165462494, 78.47638338804245, 81.89942970871925, 75.06836146116257, 86.5920639038086, 79.2563371360302, 88.55722725391388, 77.90920302271843, 90.52726194262505, 26.77112527191639, 0.6229811429511756, 5.042683761566877, 7.200872953981161, 12.04263299703598, 7.160278307273984, 7.221129667013884, 0.7693574822042137, 0.7734366226941347, 14.620622713118792, 64.34071630239487, 58.4740325063467, 75.50157621502876, 49.463458210229874, 56.63322128355503, 57.608507350087166, 33.413666635751724, 0.38359668978955597, 0.23058565420797095, 0.23835668253013864, 0.16621504502836615, 0.19973130983999, 0.28432532446458936, 0.1696725923102349, 0.16670125565724447, 0.12791081448085606, 0.13506575633073226, 0.14597408036934212, 0.09306087318691425], [0.061343600318650715, 0.04677207616623491, 0.08356648148037493, 0.014717435951752122, 0.045018863602308556, 0.02280516280734446, 0.04466298523766454, 0.06680310951196589, 0.011881830687343609, 0.01700333243206842, 0.06177863986522425, 0.09545947963488288, 1.051657812204212, 52.51291997730732, 50.58163940906525, 33.947412595152855, 35.39553388953209, 76.15935131907463, 52.54649117588997, 1.7572860047221184, 0.037087924720253795, 1.9998668879270554, 0.7556262658908963, 0.5959635833278298, 4.019351648166776, 2.7274321345612407, 8.338156677782536, 81.56899943947792, 92.25464925169945, 90.86177319288254, 86.9860115647316, 84.74533259868622, 84.50225964188576, 80.99871084094048, 75.37233754992485, 74.91142228245735, 84.34892266988754, 88.09114426374435, 86.46299242973328, 86.37234449386597, 85.85961520671844, 78.54199826717377, 70.93053549528122, 65.56656092405319, 59.124120622873306, 60.418106988072395, 62.14983366429806, 66.35178878903389, 74.01751264929771, 78.51301342248917, 77.72569566965103, 78.48747119307518, 69.95018050074577, 60.26833802461624, 57.75771774351597, 56.96935884654522, 56.35171718895435, 59.07762631773949, 60.10607913136482, 62.01076112687588, 58.987696543335915, 56.73504061996937, 56.85707487165928, 59.698186218738556, 61.48967228829861, 63.625689670443535, 66.15106835961342, 69.43430498242378, 73.04110184311867, 71.33817002177238, 69.12387683987617, 67.82909631729126, 70.4386518895626, 70.89679330587387, 66.87209486961365, 72.00844645500183, 66.59932270646095, 66.38381347060204, 70.07623493671417, 68.15467044711113, 62.86783553659916, 62.13711954653263, 64.262455701828, 70.4102598130703, 63.948615342378616, 66.37519553303719, 64.65677574276924, 66.87646463513374, 61.639559045434, 63.82360205054283, 66.56219109892845, 65.0290721654892, 62.6637826859951, 63.43222685158253, 65.9021133184433, 65.00698015093803, 65.41631698608398, 57.438819855451584, 61.34852886199951, 61.968860775232315, 62.54447288811207, 55.06431587040424, 54.9395115673542, 60.670044869184494, 54.906696528196335, 51.25592842698097, 57.79763840138912, 65.30090197920799, 63.883433640003204, 67.45643511414528, 47.393640875816345, 55.06815746426582, 60.92954434454441, 62.11088575422764, 61.73728220164776, 63.193930238485336, 61.95824794471264, 64.42506417632103, 62.07445330917835, 61.12137705087662, 52.39682100713253, 49.45598401129246, 49.76122923195362, 51.21146321296692, 52.00304053723812, 61.79312780499458, 66.23848646879196, 69.17575925588608, 67.85928189754486, 70.12146770954132, 66.02594867348671, 61.905164793133736, 60.463837534189224, 64.84861984848976, 64.68316912651062, 70.17407968640327, 71.21130242943764, 69.15885016322136, 72.51179784536362, 69.4704258441925, 72.51094669103622, 76.87564328312874, 73.05359557271004, 73.42425808310509, 74.0755507349968, 75.62927216291428, 76.44672989845276, 66.47736445069313, 3.5442621912807226, 1.6945817694067955, 3.3870005048811436, 3.7987020006403327, 2.151256939396262, 1.0309165064245462, 0.39954639330971986, 0.08366051159100607, 0.8690623508300632, 47.16991268098354, 41.30571015179157, 48.28875884413719, 29.304103553295135, 27.460488080978394, 53.123144432902336, 22.18044340610504, 0.020926803736074362, 0.04449113352166023, 0.06205917910847347, 0.06829839607235044, 0.02723562858591322, 0.022114273415354546, 0.021057364210719243, 0.05413452992797829, 0.0438556435983628, 0.014423599277506582, 0.024915969952417072, 0.011843251068057725, 0.05397904627898242, 0.04250706479069777, 0.012939469052071217, 0.01853494341048645, 0.014480318841378903, 0.07316868082853034, 0.07697516368352808, 0.025891927543852944, 0.14658752479590476, 0.007475561242245021, 0.06454696573200636, 0.09020778292324394, 2.1881227986887097, 64.00256484746933, 58.50297175347805, 43.01540561020374, 29.247927367687225, 83.86800527572632, 62.26165406405926, 1.552836075425148, 0.05163651279872283, 2.252163849771023, 2.322235652245581, 2.317515118047595, 4.688276303932071, 2.2323111025616527, 11.075773928314447, 89.34477299451828, 94.90178480744362, 96.95076406002045, 88.87739047408104, 89.31768044829369, 88.47924783825874, 82.78172716498375, 80.87316557765007, 77.89070561528206, 86.67824327945709, 90.22302746772766, 88.54923248291016, 92.75858581066132, 88.77953812479973, 82.30915412306786, 73.64775449037552, 68.78999635577202, 64.3010388314724, 64.01829600334167, 62.98534423112869, 70.45020326972008, 75.56339129805565, 81.52749046683311, 81.21863543987274, 81.75704374909401, 72.43773221969604, 61.51636205613613, 59.53568033874035, 60.948353335261345, 57.98339903354645, 62.82981477677822, 64.1825383901596, 64.72510367631912, 63.02861250936985, 58.419752418994904, 61.09873026609421, 63.3672921359539, 63.32270912826061, 65.67983284592628, 68.10240045189857, 71.05594396591187, 76.88034743070602, 75.73486089706421, 71.92124873399734, 71.14716187119484, 73.07768628001213, 73.5299988090992, 68.70390057563782, 72.67459630966187, 66.191186606884, 67.75501549243927, 71.51609927415848, 69.03521239757538, 63.026112243533134, 63.507850393652916, 68.49020004272461, 74.07413721084595, 67.69902929663658, 68.10840412974358, 69.13051888346672, 68.58029320836067, 63.80697414278984, 68.67855593562126, 67.92271569371223, 67.2826400399208, 66.69668108224869, 70.21467670798302, 69.93584766983986, 68.29109072685242, 67.66682222485542, 61.11805982887745, 61.909941136837006, 63.76896098256111, 65.31210377812386, 59.79413107037544, 58.20732481777668, 64.07675206661224, 56.07725791633129, 52.81265929341316, 55.77329322695732, 66.81078895926476, 65.3284353017807, 71.3323563337326, 50.63706323504448, 56.43849693238735, 64.0369302034378, 64.06631782650948, 64.14859861135483, 64.96351808309555, 64.96503800153732, 67.91588366031647, 66.13992735743523, 65.18562376499176, 54.93092402815819, 51.28404311835766, 51.67989447712898, 53.31000320613384, 53.96929822862148, 65.80742239952087, 70.28719961643219, 72.66998335719109, 71.24303072690964, 73.51300612092018, 69.47283491492271, 64.36204835772514, 63.31432297825813, 67.6016329228878, 68.52485418319702, 72.87978529930115, 72.9595810174942, 73.47462818026543, 76.09677627682686, 74.59551483392715, 73.53671684861183, 78.94423708319664, 75.8520770072937, 77.27929562330246, 77.44756579399109, 79.67190563678741, 79.63790506124496, 76.57524660229683, 7.3295834474265575, 0.8071120188105851, 1.8652543611824512, 3.692783871665597, 4.648608807474375, 2.857667771168053, 1.2302185432054102, 0.05828744360769633, 0.4810135765001178, 50.01296192407608, 52.03169099986553, 48.38624641299248, 27.68155451864004, 33.96910183131695, 60.623713955283165, 28.808929324150085, 0.02499899401300354, 0.04564674280118197, 0.006546075082951575, 0.04714201822935138, 0.029291437022038735, 0.032724051852710545, 0.009306439096690156, 0.03051180981856305, 0.039769415598129854, 0.04468878971238155, 0.07999685505637899, 0.015309515802073292, 0.15944052807753906, 0.1312462636269629, 0.1261350480490364, 0.10239151743007824, 0.17633059207582846, 0.13417663372820243, 0.19210700411349535, 0.0865650994819589, 0.19427699939114973, 0.14213849790394306, 0.24843611667165533, 0.37567824125289917, 3.0015195021405816, 76.11930906772614, 69.18985649943352, 45.957724526524544, 54.078660160303116, 92.53376707434654, 71.9938476383686, 3.261963939294219, 0.21667149849236012, 6.244704611599445, 4.948599860072136, 6.695832554250956, 12.049209494143724, 6.169544169679284, 10.391908474266529, 94.1270063817501, 99.785335958004, 103.09031501412392, 93.81913930177689, 93.89721751213074, 91.13543450832367, 91.73852294683456, 82.70534366369247, 82.12185457348824, 91.6338461637497, 96.18883654475212, 92.33991667628288, 94.23080921173096, 92.09463223814964, 87.12109431624413, 76.80942803621292, 74.42166656255722, 67.3172789812088, 68.47042590379715, 66.86839386820793, 72.93056577444077, 79.87706422805786, 86.62881553173065, 87.15309619903564, 86.36023074388504, 77.57040560245514, 65.80841034650803, 63.37461434304714, 64.50007975101471, 60.157668963074684, 65.27231991291046, 68.01205649971962, 71.33721247315407, 67.0820640027523, 63.27443651854992, 64.81770470738411, 66.76648333668709, 65.08268728852272, 72.2553800046444, 72.99266204237938, 76.77958443760872, 79.55124691128731, 77.40161865949631, 74.42915216088295, 72.57342293858528, 76.41925737261772, 78.5114099085331, 70.50194129347801, 76.10034808516502, 69.80172246694565, 70.80169960856438, 76.0277871787548, 72.90199130773544, 65.062175989151, 64.81944501399994, 68.70836153626442, 74.86007943749428, 68.58664646744728, 72.10838109254837, 71.39411821961403, 73.91327664256096, 67.40471228957176, 71.30326509475708, 71.76940888166428, 70.36664575338364, 67.6807750761509, 71.33103400468826, 73.19578394293785, 72.3166099190712, 70.61693832278252, 62.16340273618698, 63.363211154937744, 67.41899952292442, 65.99027618765831, 63.57924096286297, 64.09241482615471, 66.7639222741127, 58.51394936442375, 55.58912090957165, 64.16723281145096, 72.06202358007431, 68.84716808795929, 71.51950389146805, 53.95392045378685, 62.39124611020088, 64.77864280343056, 67.96766728162766, 67.76991069316864, 71.54746279120445, 68.5448107123375, 70.16808360815048, 67.87781730294228, 68.73594805598259, 57.01759345829487, 55.59178836643696, 53.97554889321327, 57.59971462190151, 56.93459831178188, 68.03653478622437, 71.90659672021866, 74.54417958855629, 73.60704347491264, 76.37245148420334, 72.14479833841324, 67.90075287222862, 68.1148561835289, 71.14276170730591, 72.25018948316574, 77.0209550857544, 78.330387622118, 77.69271343946457, 78.86254906654358, 76.75989389419556, 77.51762643456459, 83.3118899166584, 79.1304498910904, 79.94308948516846, 81.1665478348732, 81.97077468037605, 85.9410372376442, 75.5498032271862, 7.3087135422974825, 2.926085237413645, 10.689561702311039, 11.016684249043465, 7.704917332157493, 5.453701531514525, 1.532709386665374, 0.13219645014032722, 1.4318462926894426, 63.002701699733734, 57.48632870614529, 63.63195553421974, 40.534469336271286, 38.57797712087631, 72.47874721884727, 34.44920226931572, 0.19756647991016507, 0.22322773496853188, 0.11764642971684225, 0.15214285638649017, 0.1540093429503031, 0.23600284243002534, 0.0819424471410457, 0.13497720326995477, 0.15690633124904707, 0.07276492280652747, 0.15478084998903796, 0.15743132651550695], [0.057202586976927705, 0.04604762129019946, 0.06404265412129462, 0.057624368055257946, 0.043500744868651964, 0.05567214859183878, 0.07940721872728318, 0.06108981178840622, 0.06456664748839103, 0.02473408996593207, 0.11864873726153746, 0.22088153898948804, 5.530835967510939, 64.34646919369698, 43.44990089535713, 39.61467169225216, 45.01341439783573, 73.94631206989288, 31.49135358631611, 0.16736644261982292, 0.06363689972204156, 0.9472798474598676, 0.663330762181431, 0.8587552851531655, 1.591597676742822, 0.7609337498433888, 32.83022314310074, 101.084995418787, 88.8332748413086, 91.65338471531868, 82.96918630599976, 89.55547168850899, 80.77348172664642, 79.42576244473457, 71.29346162080765, 74.83946934342384, 74.2982491850853, 82.72188037633896, 83.51939678192139, 87.8115476667881, 85.08118137717247, 80.41421100497246, 73.11241641640663, 65.37492960691452, 58.95525388419628, 61.11185476183891, 58.79650980234146, 67.47413456439972, 71.01197272539139, 77.90952980518341, 74.51337844133377, 76.43592327833176, 64.6673695743084, 55.585765689611435, 53.611653819680214, 57.14962497353554, 57.04337127506733, 58.69006231427193, 58.77838857471943, 61.34975619614124, 58.200614377856255, 59.44504380226135, 60.66735461354256, 61.25940464437008, 61.44144907593727, 61.405385211110115, 64.60387498140335, 69.51043769717216, 73.78986686468124, 71.95527210831642, 68.78782287240028, 66.63156017661095, 65.74297025799751, 66.12864956259727, 68.70996505022049, 70.21964684128761, 64.15386512875557, 67.57264047861099, 67.85213068127632, 62.135690823197365, 66.10117703676224, 70.0059463083744, 76.96582764387131, 71.40994057059288, 67.76757761836052, 67.65061229467392, 63.90879347920418, 67.65115946531296, 62.99002557992935, 65.47288075089455, 64.08407807350159, 67.42950215935707, 66.42188742756844, 63.86502742767334, 66.52061372995377, 64.01709526777267, 67.7269957959652, 63.88949811458588, 62.95238479971886, 62.30305664241314, 64.3947722017765, 55.64026236534119, 53.956530913710594, 54.26908694207668, 54.47476610541344, 48.117490634322166, 53.686661794781685, 52.452640011906624, 57.18786992132664, 41.968892365694046, 46.29573918879032, 64.8638266324997, 61.98470592498779, 63.2102807611227, 60.26251673698425, 64.09970283508301, 64.13355901837349, 62.73990400135517, 60.77453166246414, 62.51677617430687, 52.94955834746361, 49.44243773818016, 49.83773432672024, 51.448657885193825, 52.84492336213589, 62.459197863936424, 66.86444967985153, 69.3609993159771, 67.1920756995678, 69.26842108368874, 63.26403267681599, 60.16177274286747, 58.52221392095089, 64.17514398694038, 61.716159135103226, 69.50005665421486, 68.883798122406, 66.54670313000679, 71.61513715982437, 74.03966546058655, 70.93716233968735, 73.50448697805405, 70.44124335050583, 76.3177040219307, 72.77620285749435, 76.8364217877388, 72.03432306647301, 84.97387513518333, 34.18138884007931, 0.04561509020277299, 4.24223106354475, 7.525385990738869, 6.598751563578844, 1.6842890717089176, 1.1211119103245437, 0.21442240511532873, 0.5511416040826589, 26.274225935339928, 47.23739705979824, 43.630805388092995, 38.7286314368248, 24.609035588800907, 56.67528122663498, 23.90549574047327, 0.07648458922631107, 0.03767736066947691, 0.05242867751803715, 0.05763183035014663, 0.012004178370261798, 0.043589119813987054, 0.030424978540395387, 0.13413949665846303, 0.07021927463938482, 0.032112243861774914, 0.04489217899390496, 0.027675490237015765, 0.017380115241394378, 0.033552797031006776, 0.042601814784575254, 0.03971009573433548, 0.06348772803903557, 0.05038475828769151, 0.058352823107270524, 0.12358190419035964, 0.06368496862705797, 0.06913579840329476, 0.09593537441105582, 0.3210603282786906, 8.222787268459797, 73.47372382879257, 50.02556584775448, 48.10325279831886, 37.152517810463905, 85.46072781085968, 34.56465907394886, 0.10248221529764123, 0.7547936355695128, 2.453580591827631, 1.1721177608706057, 2.3830079287290573, 2.582888603210449, 1.2365518533624709, 38.89744117856026, 103.3120559155941, 92.78731986880302, 94.66780856251717, 86.09773322939873, 93.43222126364708, 84.14397686719894, 83.18778857588768, 75.34466743469238, 77.07051202654839, 79.24746841192245, 84.91946205496788, 87.13989570736885, 91.31830349564552, 86.83353334665298, 84.33998554944992, 75.61547890305519, 70.1428073644638, 61.92576348781586, 64.4207552075386, 64.63214546442032, 70.82661107182503, 75.85038989782333, 80.79183474183083, 80.29938116669655, 80.47912672162056, 70.10743126273155, 57.59865067899227, 57.17628434300423, 59.00864101946354, 59.53853778541088, 61.24802425503731, 61.407828480005264, 65.47178640961647, 63.64363610744476, 61.86130374670029, 63.74818369746208, 64.37508165836334, 66.31279528141022, 65.01837193965912, 67.25452914834023, 72.87930652499199, 75.15441164374352, 76.1484307050705, 72.866280823946, 68.98956164717674, 68.36298286914825, 68.3885782957077, 71.30657851696014, 72.91539698839188, 64.10699844360352, 69.58769515156746, 69.23900306224823, 65.18275111913681, 68.53766709566116, 72.3622378706932, 77.33594298362732, 72.37333327531815, 68.20723682641983, 68.0387994647026, 67.00758799910545, 68.08394104242325, 66.40133813023567, 66.73543900251389, 67.25830614566803, 68.43777805566788, 67.34263122081757, 64.9048188328743, 67.25312322378159, 66.1170981824398, 68.60473349690437, 67.54851177334785, 66.28470718860626, 64.61049422621727, 66.62995666265488, 58.13669800758362, 57.66872651875019, 57.34578564763069, 58.36832217872143, 55.95737814903259, 58.29819314181805, 53.791973143815994, 57.55679592490196, 44.353898987174034, 51.77815340459347, 68.7372475862503, 66.74927026033401, 67.97981902956963, 65.80946668982506, 66.9388496875763, 67.43162244558334, 68.76497089862823, 66.45182982087135, 64.88939926028252, 56.15156292915344, 52.58432574570179, 51.966649889945984, 53.70333530008793, 56.619667410850525, 67.01228454709053, 68.9933842420578, 71.56444028019905, 70.95436781644821, 71.43641754984856, 66.48146823048592, 63.29024747014046, 62.25380748510361, 66.51561319828033, 64.70442518591881, 73.35439503192902, 71.4064447581768, 70.99776908755302, 74.28848370909691, 76.45541623234749, 74.59496766328812, 75.14500334858894, 73.87196525931358, 78.02796185016632, 75.43743565678596, 79.66380447149277, 74.04025822877884, 85.57125627994537, 45.01948267221451, 0.19628462760010734, 0.8053544943686575, 4.041318744421005, 5.971511146053672, 2.879111682996154, 2.476000338792801, 0.2517293969867751, 0.610959300538525, 25.10830409824848, 57.80741527676582, 46.47037781774998, 36.031114384531975, 30.7386576756835, 64.42604452371597, 30.331993997097015, 0.06522292867884971, 0.035170716073480435, 0.04878700339759234, 0.019682949387060944, 0.03906627149262931, 0.041673451123642735, 0.0187224117689766, 0.0599346849048743, 0.011268626531091286, 0.07023609170573764, 0.03330939856823534, 0.051783038725261576, 0.16535839880816638, 0.11230350079131313, 0.09060384487383999, 0.09763328213011846, 0.1742379434290342, 0.19249827921157703, 0.13796186889521778, 0.17766356351785362, 0.24764629342826083, 0.10124968612217344, 0.36737972404807806, 0.5386634892784059, 10.259583424776793, 86.41984954476357, 58.53498503565788, 49.73075486719608, 60.5834399163723, 94.85202267765999, 48.264964520931244, 0.3429975901963189, 0.5648643895983696, 6.093978099524975, 3.9006747538223863, 6.518342178314924, 7.617513472214341, 2.020440883934498, 37.648592591285706, 111.16681963205338, 98.51231306791306, 101.79494932293892, 89.678455889225, 100.28662785887718, 87.46814489364624, 89.00798946619034, 78.90808582305908, 83.30055132508278, 82.88079544901848, 90.92831522226334, 90.42830765247345, 97.73460879921913, 93.19843500852585, 88.55598852038383, 82.18626871705055, 74.5886068046093, 64.04639169573784, 68.49656090140343, 66.69545754790306, 76.47571474313736, 78.47080528736115, 85.14678865671158, 81.66826531291008, 84.35316324234009, 74.8007570207119, 60.63448637723923, 59.11800295114517, 61.94548822939396, 63.65211345255375, 64.96834382414818, 64.94039252400398, 69.08135712146759, 65.30572012066841, 63.20148043334484, 67.88792476058006, 67.6262404024601, 67.77960017323494, 66.67924761772156, 71.56637817621231, 77.31095552444458, 79.68927070498466, 78.10247585177422, 76.39692977070808, 73.8640084862709, 70.36440387368202, 72.42574766278267, 75.90475738048553, 76.88704267144203, 65.8465526998043, 72.70831570029259, 71.74412503838539, 64.61182415485382, 69.55972105264664, 74.2140381038189, 82.49617248773575, 76.76127701997757, 71.72110587358475, 71.38118371367455, 70.42472183704376, 72.79410749673843, 69.03055384755135, 70.2336072921753, 69.5495679974556, 71.21370390057564, 70.78031435608864, 70.69637686014175, 69.20781433582306, 68.56732830405235, 73.77575442194939, 71.2660650908947, 66.36975422501564, 67.90009930729866, 67.65834867954254, 63.23981277644634, 62.300187796354294, 60.83763487637043, 64.86041441559792, 59.822979122400284, 60.9411945194006, 58.78937378525734, 60.807935670018196, 46.18841394782066, 51.99003003537655, 71.60872310400009, 69.48582261800766, 72.20953926444054, 67.92279168963432, 70.45467182993889, 71.27746447920799, 71.29804417490959, 68.3806899189949, 65.82743972539902, 59.524410143494606, 55.604073107242584, 55.034517869353294, 56.47239491343498, 60.447031036019325, 72.14264765381813, 73.06739643216133, 74.43346872925758, 72.7863559126854, 74.96160998940468, 70.1095287501812, 65.62448501586914, 64.30462583899498, 69.58417654037476, 67.1091565489769, 76.31494536995888, 75.71016982197762, 72.06423506140709, 77.22197949886322, 80.28645426034927, 77.32605591416359, 77.8989739716053, 77.52055987715721, 82.73952662944794, 81.05895280838013, 83.00066381692886, 77.95695886015892, 89.89581942558289, 44.81361731886864, 0.2493634301936254, 10.904568415135145, 16.73936527222395, 14.320277329534292, 8.262985311448574, 3.5241524828597903, 0.4024429660057649, 0.6902795692440122, 35.927980318665504, 62.13390491902828, 63.17991279065609, 52.53141738474369, 35.87870076298714, 76.09515756368637, 36.55595362186432, 0.14698295592097566, 0.1223699028196279, 0.15252381563186646, 0.121776169835357, 0.1480199143406935, 0.1126107202435378, 0.11861868028063327, 0.18705857422901317, 0.16731315641663969, 0.15651260706363246, 0.1056875659560319, 0.10649519332218915], [0.04114914976526052, 0.05928090104134753, 0.03976131876697764, 0.010130933624168392, 0.022089676785981283, 0.030209510805434547, 0.14140675513772294, 0.029068751900922507, 0.032079837983474135, 0.14665381342638284, 0.22256198397371918, 0.4684203100623563, 13.95872388035059, 67.95701265335083, 40.25929570198059, 33.354317620396614, 40.515268966555595, 68.09401050209999, 12.03541623428464, 0.04923671520373318, 0.38436896866187453, 0.6192863162141293, 1.3214167370460927, 2.029677713289857, 6.283458732068539, 2.0072375424206257, 63.367113545536995, 98.22453930974007, 86.46667823195457, 86.83769032359123, 79.03262794017792, 82.23179027438164, 77.83961355686188, 77.62432470917702, 73.08656260371208, 75.31027927994728, 71.84940978884697, 73.50182712078094, 74.80188935995102, 81.32560729980469, 78.48862633109093, 77.16652527451515, 68.52233111858368, 63.726680651307106, 60.19305646419525, 61.54186248779297, 63.53556610643864, 70.83860322833061, 73.92692551016808, 77.40711316466331, 74.8014409840107, 76.47143617272377, 61.1936491727829, 57.09125630557537, 56.89306654036045, 54.222585037350655, 54.94637779891491, 56.28820739686489, 58.310299292206764, 62.68975809216499, 60.728580728173256, 60.413064658641815, 61.91417030990124, 60.74775069952011, 61.7935723811388, 63.389391750097275, 64.27279114723206, 67.15724676847458, 70.15698060393333, 71.37710273265839, 70.02312138676643, 66.17521226406097, 62.21226431429386, 64.70216810703278, 70.00612109899521, 66.07878103852272, 66.36111348867416, 71.9061179459095, 64.13737401366234, 66.20561823248863, 71.07009440660477, 68.67243826389313, 63.9582896232605, 58.58973629772663, 59.30285923182964, 58.58787439763546, 63.92555058002472, 67.3773081600666, 65.84609672427177, 64.783134162426, 68.7009747326374, 60.195879712700844, 54.78159584105015, 49.70429688692093, 55.98400332033634, 60.94752497971058, 63.55346694588661, 62.47777886688709, 66.13529160618782, 62.65533193945885, 64.88937646150589, 56.870921328663826, 51.229930222034454, 55.608617663383484, 49.07062768936157, 60.15942066907883, 59.66496840119362, 56.584561094641685, 44.17582154273987, 50.56081272661686, 65.7136282324791, 62.913683876395226, 62.2187315672636, 63.34405638277531, 65.43797582387924, 66.32755368947983, 65.33682525157928, 62.63441026210785, 63.82514476776123, 64.36479941010475, 58.4589359164238, 48.94998416304588, 51.71629652380943, 50.56029975414276, 53.78823794424534, 61.3665284961462, 67.54615589976311, 68.22484508156776, 65.87850898504257, 68.85019272565842, 65.06779208779335, 58.891979679465294, 58.65652531385422, 63.136492520570755, 65.02096340060234, 69.4467531144619, 62.68946170806885, 70.39021208882332, 72.1049764752388, 74.61443021893501, 71.41605824232101, 72.15057402849197, 72.52955049276352, 71.9419652223587, 69.84776079654694, 73.05522188544273, 73.89966577291489, 75.5701245367527, 74.04874697327614, 5.206239335238934, 2.529263743199408, 1.328495282214135, 4.1265301220119, 1.937604141421616, 0.6944106600712985, 0.30909052526112646, 0.331902660545893, 5.487055191770196, 65.25109425187111, 37.913951352238655, 49.003572687506676, 33.34531590342522, 50.16898915171623, 28.269591964781284, 0.1179555787530262, 0.07981485818163492, 0.04949245929310564, 0.06752355679054745, 0.01747725866152905, 0.016001344010874163, 0.006046921862434829, 0.028788054951291997, 0.031119142659008503, 0.02655398078786675, 0.031011445898911916, 0.060219944207347, 0.11216902363230474, 0.08232589258113876, 0.10646092836395837, 0.042044001747854054, 0.050122334869229235, 0.07490387404686771, 0.15794087026733905, 0.031561752111883834, 0.024497532249370124, 0.1772253104718402, 0.1890609777183272, 0.5927782854996622, 19.29752480238676, 77.31592565774918, 51.057347282767296, 36.963873133063316, 38.99989128112793, 79.185341745615, 11.13298935815692, 0.06625750480452552, 0.9629337606020272, 2.526486092247069, 2.67709837295115, 3.0351044749841094, 6.269603725522757, 3.5076399939134717, 66.88116118311882, 100.72805777192116, 91.26238569617271, 90.16146317124367, 84.72912266850471, 86.2501734495163, 80.76775163412094, 80.6743298470974, 75.43285310268402, 78.2113628089428, 75.60578182339668, 78.17600950598717, 75.71209251880646, 85.503711104393, 81.23802959918976, 79.24895793199539, 73.27307179570198, 65.72198778390884, 62.60670214891434, 66.69319286942482, 66.33037313818932, 75.35108909010887, 76.58153906464577, 81.15614399313927, 78.44758853316307, 78.91254678368568, 63.54446142911911, 60.1419036090374, 58.07852692902088, 59.297296330332756, 56.85766004025936, 59.42157246172428, 63.27808812260628, 65.84314048290253, 63.404982313513756, 63.51068124175072, 64.28479090332985, 63.13190616667271, 68.18677872419357, 67.60430037975311, 68.8703240454197, 70.69133833050728, 70.28657644987106, 73.71729075908661, 72.09026366472244, 69.60452064871788, 67.01033145189285, 68.59396487474442, 69.506865888834, 69.6088220179081, 69.92112725973129, 72.80876711010933, 66.07723832130432, 68.516084253788, 75.32985582947731, 70.9871144592762, 63.883699625730515, 60.262364745140076, 58.704433143138885, 59.4570055603981, 66.65451854467392, 68.63273799419403, 66.28536835312843, 66.90117090940475, 68.74766662716866, 63.591552302241325, 54.150905683636665, 53.25715184211731, 58.12429167330265, 62.6490318775177, 64.69152107834816, 65.92479050159454, 68.4089908003807, 66.76780566573143, 67.44514212012291, 60.99761389195919, 55.480727925896645, 58.88930842280388, 56.026393845677376, 64.77515459060669, 64.37742993235588, 63.48453864455223, 49.721050187945366, 54.719001799821854, 69.5179232954979, 66.12244829535484, 63.08254301548004, 66.35363548994064, 66.24608606100082, 67.68817707896233, 67.16495275497437, 66.04452967643738, 67.53858670592308, 67.07021623849869, 61.3915691524744, 52.71265625953674, 54.05401088297367, 52.35959440469742, 55.63718073070049, 62.94994153082371, 69.91801142692566, 68.34890082478523, 69.33085933327675, 70.42152240872383, 67.34906047582626, 61.14157676696777, 61.61611430346966, 64.98644605278969, 68.53691473603249, 69.75266709923744, 66.62592127919197, 72.93731421232224, 75.47655075788498, 74.81477826833725, 73.87192726135254, 73.6143010854721, 77.45662450790405, 72.20431074500084, 74.11325231194496, 73.83376210927963, 79.79282274842262, 75.918527841568, 81.4132533967495, 8.205273058265448, 1.4217154425568879, 1.9882689602673054, 3.6301789060235023, 4.663168676197529, 3.8552538910880685, 0.9508573554921895, 0.5773582973051816, 5.7020467054098845, 68.11672568321228, 46.26196280121803, 44.10425238311291, 41.882401406764984, 58.32954525947571, 35.90189851820469, 0.17530911485664546, 0.027142876824655104, 0.019092225811618846, 0.06234928092453629, 0.043660132214426994, 0.023874779435573146, 0.027605245959421154, 0.042415012503624894, 0.028872522489109542, 0.030690413223055657, 0.03783964610192925, 0.03977281834522728, 0.18515374831622466, 0.14551485422998667, 0.13940369855845347, 0.2566631353693083, 0.16320087161147967, 0.10824568220414221, 0.29514123627450317, 0.10273456035065465, 0.05659182912495453, 0.37030779349152, 0.31354905164334923, 0.8864324656315148, 21.26466404646635, 93.53134274482727, 54.84031029045582, 45.44016569852829, 54.41028356552124, 89.37036082148552, 20.438079200685024, 0.1930071847164072, 1.7288387124426663, 4.542468627914786, 5.593124600127339, 10.189126655459404, 10.989680998027325, 4.082458661869168, 69.06229734420776, 107.08795890212059, 94.93662133812904, 98.59783887863159, 88.5863944888115, 90.65637901425362, 83.80981519818306, 86.876759827137, 79.88546937704086, 81.63970604538918, 79.40943852066994, 83.26835185289383, 81.07943370938301, 89.97248411178589, 84.85081493854523, 83.39651137590408, 77.03435316681862, 72.67338797450066, 68.37332591414452, 70.65090090036392, 71.69286578893661, 78.95263463258743, 80.8877719938755, 83.99491086602211, 80.90763732790947, 83.00588473677635, 68.46940755844116, 64.41908329725266, 60.153895765542984, 61.46611735224724, 62.05204211175442, 63.516810312867165, 66.64828687906265, 69.9945393204689, 66.4857468008995, 68.77995729446411, 67.55997955799103, 66.83005392551422, 67.8508235514164, 72.46965050697327, 72.44217798113823, 74.81246799230576, 73.79346907138824, 80.54417163133621, 77.63131633400917, 71.49757906794548, 70.05744874477386, 71.21177360415459, 74.84163522720337, 71.22933626174927, 74.82559248805046, 78.47638338804245, 67.96455144882202, 70.63871875405312, 78.37786227464676, 74.56203103065491, 69.70995739102364, 63.560424372553825, 63.632464706897736, 63.28185372054577, 68.74775782227516, 74.10983249545097, 70.22593170404434, 71.3194066286087, 73.37867572903633, 67.55766168236732, 58.304588198661804, 55.968758538365364, 62.297710329294205, 66.30579605698586, 68.39160293340683, 68.11415702104568, 69.80312839150429, 69.58323419094086, 69.31399583816528, 63.47127355635166, 59.722075536847115, 64.65822726488113, 60.38189873099327, 65.15682131052017, 67.29259550571442, 64.7789391875267, 49.558335319161415, 53.0579399317503, 72.50073283910751, 69.41951617598534, 67.27858185768127, 69.56685706973076, 69.81221750378609, 71.44392594695091, 72.88100123405457, 67.71947979927063, 70.65755814313889, 70.61360210180283, 66.52241483330727, 55.5483490973711, 56.72986529767513, 55.10609082877636, 58.6922661960125, 66.80806830525398, 72.67676219344139, 72.94116720557213, 71.78338453173637, 74.46346431970596, 69.51540783047676, 64.34871107339859, 65.51351577043533, 67.64005646109581, 70.51938995718956, 74.1798247396946, 70.45974835753441, 76.51556700468063, 79.31374445557594, 78.55513796210289, 75.26436254382133, 78.55101138353348, 79.16650995612144, 76.97097256779671, 75.91582238674164, 77.68927082419395, 82.55346581339836, 81.73280864953995, 83.85506317019463, 8.737350907176733, 4.19496207498014, 8.757373932749033, 12.556535471230745, 7.439117794856429, 5.453320601955056, 0.7553573709446937, 0.5268904741387814, 9.05974555760622, 81.37144044041634, 54.148728400468826, 67.49896243214607, 45.763908326625824, 67.84639298915863, 43.64451885223389, 0.29396813828498125, 0.21872090961551294, 0.12655136320972815, 0.22023080906365067, 0.10484220780199394, 0.14395212871022522, 0.10332343968912028, 0.14168486755806953, 0.1072955179552082, 0.10452898437506519, 0.1427021887502633, 0.2347057464066893], [0.02710550597839756, 0.06573255406692624, 0.041194992227246985, 0.05557727985433303, 0.019720474228961393, 0.0018496036318538245, 0.023745029757265, 0.016774331634223927, 0.1107636111555621, 0.0638089889253024, 0.02208890680776676, 0.1301081950077787, 25.14082845300436, 68.80120575428009, 31.55743394047022, 36.68085291981697, 46.24917268753052, 49.70712013542652, 3.420929596759379, 0.06295236496953294, 1.3042825064621866, 1.171448640525341, 0.6277093954849988, 4.988602688536048, 4.298609113320708, 6.232515815645456, 79.02538552880287, 91.24541580677032, 88.36125656962395, 81.83380722999573, 81.10869973897934, 77.84971341490746, 77.24522665143013, 74.057038128376, 68.45879092812538, 71.88480108976364, 72.68215790390968, 69.30836454033852, 68.59220176935196, 68.91083747148514, 70.93714714050293, 68.31597939133644, 66.17886006832123, 58.09154883027077, 60.4969147592783, 59.315713942050934, 64.03739377856255, 68.65082502365112, 72.72112861275673, 76.39864727854729, 76.48651376366615, 70.85456997156143, 61.037412956357, 54.97963361442089, 55.52944891154766, 55.11425659060478, 57.68619418144226, 57.79829956591129, 60.49643978476524, 60.40074571967125, 59.844254180788994, 62.91333809494972, 61.39278128743172, 63.02646562457085, 64.87942099571228, 62.93216988444328, 64.23382043838501, 68.16149488091469, 71.5266627073288, 67.96944558620453, 67.76494055986404, 64.6407026052475, 61.38638623058796, 65.83550289273262, 63.5247290879488, 63.495200872421265, 62.93633446097374, 63.82582113146782, 66.52790933847427, 70.7899658381939, 63.2565812766552, 56.44284389913082, 59.86481487751007, 66.18188470602036, 65.36576449871063, 50.92476099729538, 51.70209288597107, 57.17512920498848, 55.21627351641655, 57.11674913764, 53.18366378545761, 56.35791465640068, 54.459851905703545, 62.04635001718998, 61.417947337031364, 60.32186195254326, 59.66594874858856, 65.27557253837585, 62.890307530760765, 62.542181611061096, 64.729283452034, 61.75970859825611, 54.55381706357002, 49.55915607511997, 55.21723486483097, 64.9480377137661, 60.24320997297764, 64.09041613340378, 59.03577156364918, 60.825916305184364, 63.268087059259415, 59.68183949589729, 59.324153289198875, 58.96610230207443, 60.61957597732544, 62.997419983148575, 61.50774031877518, 61.799401268363, 62.146151661872864, 63.54447282850742, 56.36657439172268, 49.175015687942505, 51.35475732386112, 50.49839727580547, 54.00234505534172, 57.581597194075584, 66.99160605669022, 66.3842922449112, 68.25179323554039, 66.93955644965172, 65.81247612833977, 58.16088750958443, 59.041273668408394, 59.09077741205692, 65.34715309739113, 62.51552604138851, 68.30799221992493, 68.6441145837307, 72.58692741394043, 74.10686105489731, 71.9796971976757, 69.66388866305351, 74.32233229279518, 69.21751141548157, 71.46427005529404, 68.91969859600067, 76.44781664013863, 71.61760702729225, 85.19870147109032, 36.37639805674553, 0.16543568606721237, 2.015194552950561, 2.3528373101726174, 1.2201862502843142, 0.9919748897664249, 0.6712345161940902, 0.09704749754746445, 0.24107779667247087, 51.63113549351692, 46.389639750123024, 44.68526780605316, 33.02561245858669, 35.86552307009697, 38.060631081461906, 0.17263303423533216, 0.05535545191378333, 0.08526519814040512, 0.05075787674286403, 0.02674288520211121, 0.011689748953358503, 0.02839379827491939, 0.037256848663673736, 0.04430575616424903, 0.036386572901392356, 0.07757592480629683, 0.037770893541164696, 0.018295600784767885, 0.05129654236952774, 0.03041845320694847, 0.052403989975573495, 0.031583062882418744, 0.02273415226227371, 0.009504208464932162, 0.032291954921674915, 0.05690679659892339, 0.11299399498966523, 0.05338326867786236, 0.14805040176725015, 33.74376252293587, 74.11698371171951, 41.65264293551445, 30.90327624231577, 46.53672605752945, 58.61385740339756, 3.1154293147847056, 0.05444874783279374, 2.5480625219643116, 3.0069164000451565, 3.061024071648717, 5.967200752347708, 3.0397924734279513, 8.148145973682404, 83.73493641614914, 94.56988781690598, 91.25881388783455, 84.9217039346695, 83.99288937449455, 82.32790231704712, 81.41204506158829, 77.25833594799042, 71.22011035680771, 74.84896883368492, 75.3939887881279, 71.04245468974113, 72.90887653827667, 73.78486633300781, 72.83085912466049, 70.60275748372078, 68.7604795396328, 60.46074070036411, 63.07134121656418, 62.3684511333704, 67.8153258562088, 71.45122155547142, 74.04731065034866, 78.8687351346016, 79.85696330666542, 75.24863138794899, 63.35467681288719, 57.247526720166206, 57.17439204454422, 58.5973434895277, 58.82110968232155, 58.771233558654785, 61.776157915592194, 63.36697295308113, 65.91537460684776, 64.66489970684052, 63.41412462294102, 62.78816521167755, 69.64251101016998, 66.28693386912346, 67.01143339276314, 70.94958007335663, 75.66121324896812, 70.40148228406906, 68.43638733029366, 68.63743454217911, 65.16824349761009, 68.18179339170456, 65.5322639644146, 62.735500037670135, 63.59601706266403, 64.51331824064255, 70.33161163330078, 71.46756067872047, 63.55239540338516, 60.92683508992195, 64.5426906645298, 71.66711077094078, 69.76404368877411, 54.146927297115326, 54.38761778175831, 61.66404873132706, 59.22539658844471, 60.89215435087681, 60.10058082640171, 57.04659350216389, 59.81164813041687, 67.61082082986832, 66.98217496275902, 63.0853358656168, 62.45271921157837, 66.37933731079102, 64.5072689652443, 64.0121403336525, 66.24208867549896, 63.73117960989475, 60.07698029279709, 53.239482790231705, 60.68715535104275, 65.81163257360458, 62.97428302466869, 65.47547981142998, 63.4599007666111, 64.03395116329193, 65.27326986193657, 63.48639294505119, 63.059717640280724, 62.55125172436237, 64.97601941227913, 64.32515233755112, 66.15258827805519, 65.10027274489403, 64.68198359012604, 65.29780894517899, 60.7747520506382, 52.54446588456631, 52.81662628054619, 53.596914410591125, 55.624405816197395, 62.36265264451504, 68.1233449280262, 69.89554703235626, 71.21226757764816, 68.59135061502457, 67.14190319180489, 62.63088025152683, 59.39510688185692, 63.220099434256554, 69.12782102823257, 67.17807725071907, 69.97351884841919, 71.85914486646652, 74.17037084698677, 75.04424035549164, 73.85732844471931, 72.87543073296547, 77.1998418867588, 71.87698110938072, 74.25341159105301, 71.53561502695084, 79.57830905914307, 76.98017567396164, 87.06408977508545, 46.06397822499275, 0.09177106505376287, 0.6164706079289317, 0.7750814594328403, 4.566878993064165, 3.3072480093687773, 1.3953101844526827, 0.05142481888469774, 0.14202141668647528, 51.96615591645241, 58.02901938557625, 41.689956933259964, 33.917261213064194, 44.04396481812, 45.67264102399349, 0.0847219089337159, 0.022705019255226944, 0.0433468976552831, 0.04199484930722974, 0.016366937088605482, 0.035703433386515826, 0.08517625174135901, 0.012482890524552204, 0.07028023464954458, 0.003455571545600833, 0.037933160419925116, 0.027075940670329146, 0.17590121511602774, 0.18690741359023377, 0.12662301014643162, 0.12058992841048166, 0.1113586057908833, 0.13240674510598183, 0.2429674382437952, 0.25244957709219307, 0.2118535351473838, 0.22647238976787776, 0.1795255675096996, 0.28493189660366625, 36.11480109393597, 91.93896979093552, 42.30832055211067, 54.43296454846859, 63.65216284990311, 72.82619297504425, 6.734816087409854, 0.3164822270628065, 6.187742343172431, 4.8535550851374865, 4.4125203508883715, 13.638060037046671, 10.759477000683546, 8.263953309506178, 87.41795718669891, 98.20288807153702, 96.3966777920723, 88.72114285826683, 93.36802750825882, 86.8540370464325, 87.8733779489994, 83.4241434931755, 75.90463578701019, 79.3715849518776, 79.77620244026184, 76.30300641059875, 78.33284988999367, 78.58878895640373, 77.69532009959221, 75.21786823868752, 73.65115150809288, 64.62425708770752, 68.76575365662575, 64.94054451584816, 72.57495805621147, 75.44740632176399, 77.68222600221634, 83.07728290557861, 84.77484941482544, 79.0878389775753, 68.0932505428791, 60.2610120177269, 59.74514789879322, 61.0174298286438, 64.73711103200912, 64.28093791007996, 68.02502140402794, 67.5374011695385, 69.54375430941582, 69.85248774290085, 66.37266486883163, 66.72894895076752, 71.53397351503372, 66.70637056231499, 73.11310797929764, 75.15168339014053, 80.25173932313919, 74.9907848238945, 74.00317221879959, 69.46556210517883, 69.59503635764122, 69.7353096306324, 70.31441375613213, 68.0558529496193, 66.4261431992054, 68.81200477480888, 72.00892522931099, 74.70802679657936, 67.37188965082169, 62.95461528003216, 67.4039751291275, 73.35409864783287, 70.36710932850838, 56.581867039203644, 59.26913224160671, 63.035767525434494, 62.29632340371609, 61.96965113282204, 63.08992601931095, 62.374268621206284, 59.65926490724087, 66.07408449053764, 68.11994031071663, 65.60966581106186, 65.27773842215538, 70.20532160997391, 67.76458337903023, 67.17620015144348, 68.26005399227142, 67.73078039288521, 63.26114483177662, 57.65825428068638, 62.44999095797539, 70.20164340734482, 66.486856341362, 69.72728446125984, 65.23550748825073, 62.88376048207283, 70.13976752758026, 67.33894541859627, 66.14733695983887, 66.37835696339607, 66.67724132537842, 68.50951820611954, 67.70722925662994, 68.98111090064049, 69.00040626525879, 68.3450174331665, 63.252481296658516, 54.625868797302246, 56.49300120770931, 55.95210783183575, 59.848354160785675, 63.609251752495766, 72.65966311097145, 71.79008737206459, 74.32091876864433, 71.59028649330139, 72.18679368495941, 64.75759953260422, 64.35325562953949, 66.22756585478783, 71.85778453946114, 70.74108526110649, 74.18028831481934, 73.6077806353569, 78.0805054306984, 78.4157158434391, 76.90937787294388, 75.38189023733139, 80.70123240351677, 75.06199300289154, 77.39296272397041, 75.26053234934807, 84.60028678178787, 79.4676285982132, 93.29513221979141, 46.01287856698036, 0.2119464668794535, 4.843677515164018, 7.304484369233251, 6.089137634262443, 5.249175606295466, 1.5332779311574996, 0.16094180376967415, 0.7772246631793678, 65.39759919047356, 61.05694390833378, 62.96215407550335, 45.15352427959442, 48.85365553200245, 57.653466537594795, 0.41220731392968446, 0.13934999675257131, 0.17698228679364547, 0.18687501142267138, 0.10127267043571919, 0.1993834800668992, 0.12820112780900672, 0.1387440034886822, 0.14307011588243768, 0.09195371501846239, 0.12770596687914804, 0.0921873579500243], [0.03900071758835111, 0.03220330909243785, 0.0428200247552013, 0.013793318303214619, 0.030802369910816196, 0.00744768849472166, 0.05060077521193307, 0.06381327853887342, 0.05994752405968029, 0.023597986182721797, 0.017221663001691923, 0.039791346061974764, 38.905010372400284, 54.516970440745354, 34.060475528240204, 40.819070264697075, 45.513349771499634, 31.08718067407608, 0.4916302365018055, 0.028663852826866787, 0.7653835485689342, 2.1169490553438663, 5.161429764702916, 2.0148036489263177, 0.33792860282119364, 12.438970729708672, 88.47752273082733, 90.61406448483467, 87.61479422450066, 82.75711208581924, 76.024010181427, 75.55650606751442, 73.67760568857193, 68.41822430491447, 66.73969477415085, 67.03794077038765, 68.07110533118248, 68.05512338876724, 64.019435942173, 62.99897409975529, 65.17692983150482, 61.98558367788792, 59.13154922425747, 60.409215465188026, 57.7941919863224, 56.63059942424297, 62.34034784138203, 69.20823991298676, 71.64612829685211, 74.85502570867538, 72.44228437542915, 68.76900628209114, 59.281979352235794, 55.799587815999985, 56.22850500047207, 55.543523356318474, 56.59893572330475, 51.12762451171875, 56.10705591738224, 58.19223202764988, 59.16980937123299, 60.875910222530365, 59.44864600896835, 60.03732942044735, 66.08916968107224, 62.58758157491684, 63.687250167131424, 68.97892981767654, 70.06310284137726, 67.00903192162514, 64.5101872086525, 65.02020344138145, 62.60992057621479, 61.07786178588867, 57.447832971811295, 52.706956565380096, 59.68366339802742, 68.90299469232559, 69.86109808087349, 60.22378921508789, 58.51741097867489, 66.3569413125515, 70.81385135650635, 68.62220495939255, 69.2647048830986, 58.36511895060539, 61.721543446183205, 66.17335796356201, 60.28971567749977, 65.6854185461998, 63.34326222538948, 64.49832424521446, 68.92447873950005, 63.652683421969414, 69.43991348147392, 67.16564431786537, 61.87665872275829, 59.39685858786106, 61.79182827472687, 62.39435814321041, 59.24783058464527, 62.00075626373291, 57.35101796686649, 54.91872288286686, 53.825726732611656, 61.39128036797047, 57.56116949021816, 59.146311432123184, 60.61767987906933, 61.42327845096588, 64.38226327300072, 58.67368519306183, 58.810584247112274, 52.9426047205925, 58.57535406947136, 59.62687164545059, 62.15780943632126, 63.431197106838226, 62.32299417257309, 63.84971424937248, 60.67265912890434, 50.16515135765076, 48.04939068853855, 48.72098945081234, 51.01323164999485, 58.74313406646252, 66.62763118743896, 67.8281843662262, 68.18072184920311, 65.6393726170063, 64.32134494185448, 57.611550986766815, 56.08034335076809, 56.90791234374046, 64.37586441636086, 63.64784628152847, 66.66717186570168, 69.37886595726013, 69.6188534796238, 69.4018243253231, 73.47656607627869, 71.36533856391907, 70.99447086453438, 65.65842479467392, 69.63877201080322, 67.62854307889938, 75.23178309202194, 71.69731914997101, 80.80143302679062, 68.48489552736282, 10.640539582818747, 1.0259442357346416, 1.6125528397969902, 2.636006190441549, 3.217254588380456, 0.6136483687441796, 0.09736835767398588, 0.22185771551448852, 25.67610763013363, 67.50381857156754, 39.219215512275696, 38.80182310938835, 29.677672907710075, 39.883936643600464, 0.04141866440477315, 0.004626686377378064, 0.035698520368896425, 0.01712371435132809, 0.01394661911035655, 0.02686500745767262, 0.057083320134552196, 0.05410678102634847, 0.006225720080692554, 0.025905941147357225, 0.056371422397205606, 0.01844140682806028, 0.04845034665777348, 0.04012506018625572, 0.07897597897681408, 0.027393693053454626, 0.08707508110092022, 0.025457546653342433, 0.017937765005626716, 0.02364705884247087, 0.01758273454470327, 0.06021057459292933, 0.04488680213398766, 0.18227837135782465, 51.70422837138176, 61.29609927535057, 45.653889030218124, 33.36815267801285, 49.18583370745182, 36.594084575772285, 0.1750004556379281, 0.0338940439542057, 2.9424927569925785, 5.304385218769312, 13.003043811768293, 1.380302533507347, 0.5797256890218705, 15.604199934750795, 94.15681958198547, 92.3340953886509, 92.93251767754555, 85.42393818497658, 82.75747686624527, 79.22387167811394, 77.81633600592613, 69.56383243203163, 68.97888422012329, 70.16144916415215, 69.94430601596832, 70.86831763386726, 67.1612137556076, 67.69701540470123, 67.07976892590523, 64.52368408441544, 63.64593118429184, 63.45900781452656, 60.82667626440525, 60.86202196776867, 65.3730297088623, 72.19440847635269, 73.67493823170662, 78.6312098801136, 75.95981642603874, 70.84813311696053, 63.09218689799309, 58.06825987994671, 57.83127039670944, 59.24666024744511, 59.22622874379158, 55.64921848475933, 58.76702718436718, 59.5799745619297, 65.79230681061745, 62.748559936881065, 64.79709461331367, 63.09215649962425, 69.41013067960739, 67.11219638586044, 67.4946990609169, 71.91694736480713, 72.21780002117157, 71.40031948685646, 68.21795225143433, 71.04376181960106, 66.26248598098755, 64.5630955696106, 60.919866263866425, 54.1297560185194, 60.85761420428753, 72.4323745071888, 72.0836292207241, 62.59207673370838, 60.99332012236118, 71.55921176075935, 72.41266116499901, 67.51402482390404, 70.00311926007271, 62.984067499637604, 64.28647801280022, 67.95361563563347, 65.63696354627609, 68.12683314085007, 66.9556675851345, 68.63503307104111, 71.02195858955383, 65.31836584210396, 70.54748564958572, 71.62058606743813, 63.37053336203098, 64.71517100930214, 63.69374781847, 66.24877631664276, 63.37030157446861, 62.807034999132156, 61.60579785704613, 60.08607320487499, 56.052718833088875, 63.64434286952019, 59.949660524725914, 63.14683556556702, 64.2690521478653, 65.46192973852158, 67.16246768832207, 60.152292251586914, 60.94637744128704, 55.17165631055832, 60.73174215853214, 62.58676841855049, 63.36782790720463, 65.26160448789597, 64.42105919122696, 66.46025776863098, 64.00770977139473, 54.464662447571754, 50.8738399296999, 52.20023475587368, 52.93268345296383, 60.226924046874046, 68.95156368613243, 70.44824257493019, 69.44390326738358, 70.40649801492691, 65.10603323578835, 61.29789657890797, 58.55725184082985, 59.681968688964844, 66.45008951425552, 67.74490043520927, 69.49919790029526, 72.43262529373169, 71.55458360910416, 72.18145877122879, 72.93887212872505, 73.17522704601288, 74.36139419674873, 69.39792573451996, 72.58538469672203, 72.59911715984344, 76.26597359776497, 76.17897346615791, 78.98202985525131, 77.16644927859306, 15.960925742983818, 0.8857258222997189, 1.570502039976418, 1.271682393271476, 1.0704250051639974, 1.1787710851058364, 0.32619367470033467, 0.5389471084345132, 25.504860319197178, 73.91972869634628, 44.90011587738991, 30.81827860325575, 38.18032085895538, 48.7172694504261, 0.5653377610724419, 0.015983612247509882, 0.07989280595211312, 0.03110644822299946, 0.015841934400668833, 0.02509957914298866, 0.0164087626762921, 0.05067372832854744, 0.037019138762843795, 0.051391930610407144, 0.02742384465818759, 0.012368282514216844, 0.24306955776410177, 0.16633245279081166, 0.1578649930888787, 0.1373125787358731, 0.1757961863768287, 0.09090825900784694, 0.0905525179405231, 0.18225015490315855, 0.13060843222774565, 0.2196416922379285, 0.149208820075728, 0.27915475191548467, 59.70128685235977, 73.85340705513954, 47.77885660529137, 55.476551949977875, 64.5689244568348, 46.845258101820946, 1.0016382462345064, 0.09185974427964538, 4.354395344853401, 7.151700742542744, 14.453008007258177, 6.449933024123311, 0.6794326356612146, 17.46157731860876, 98.2556976377964, 98.22600603103638, 97.34683960676193, 89.5874735713005, 87.57449358701706, 83.32373768091202, 82.14666724205017, 74.05716732144356, 74.54258367419243, 73.70509341359138, 76.00924417376518, 75.95782533288002, 71.52180656790733, 71.307482868433, 70.09784057736397, 68.79071831703186, 66.76119402050972, 68.20551171898842, 63.467416763305664, 62.41319753229618, 68.61392140388489, 77.01343908905983, 77.75181546807289, 82.28099003434181, 77.76259168982506, 74.33483362197876, 65.77836155891418, 61.80170014500618, 63.39999318122864, 63.86641055345535, 63.202255591750145, 58.610483184456825, 63.09890113770962, 64.4704033434391, 68.93289148807526, 68.6197654902935, 68.54397475719452, 68.26235666871071, 70.86352229118347, 70.86530059576035, 71.15237519145012, 74.91115629673004, 77.55402088165283, 73.66933733224869, 72.03638255596161, 72.37258851528168, 70.66488415002823, 69.95922401547432, 64.20564875006676, 57.25866012275219, 64.12759333848953, 76.1144757270813, 76.7275196313858, 66.00250393152237, 63.05881328880787, 71.86640247702599, 76.20688676834106, 73.42911422252655, 71.92161351442337, 65.17190650105476, 66.908238530159, 71.5730582177639, 66.37837216258049, 71.487737596035, 69.49301183223724, 69.11290302872658, 73.62918868660927, 69.22539219260216, 75.47580599784851, 74.00783836841583, 67.9555307328701, 66.92218378186226, 66.51325732469559, 67.55539700388908, 65.51765754818916, 69.04220402240753, 63.882620483636856, 63.30838769674301, 59.761813804507256, 66.59432977437973, 61.42634868621826, 66.89515963196754, 67.14068725705147, 64.84837666153908, 71.37808308005333, 64.01825040578842, 64.71560418605804, 59.681250527501106, 64.20548155903816, 65.27315586805344, 66.03275790810585, 69.56872656941414, 68.73610764741898, 69.41235736012459, 68.05178716778755, 55.178556740283966, 54.38034117221832, 54.69053752720356, 56.26337952911854, 62.057175636291504, 74.0560045838356, 72.96411037445068, 72.35036730766296, 72.72817343473434, 69.46135193109512, 63.210531547665596, 61.464563235640526, 64.07513335347176, 68.44063550233841, 71.82449832558632, 74.45795461535454, 76.25850319862366, 74.74646553397179, 75.90329065918922, 75.12259975075722, 77.53329679369926, 78.37379649281502, 72.7806106209755, 76.39794811606407, 74.3006506562233, 83.28128635883331, 79.98324573040009, 86.23419150710106, 76.58038392663002, 16.667501628398895, 2.495610611513257, 8.276347294449806, 9.60215125232935, 11.417224556207657, 2.067524869926274, 0.2657255600206554, 0.569040603004396, 34.40815307199955, 82.50715389847755, 55.77480174601078, 52.143515199422836, 44.41274642944336, 60.232813730835915, 0.6029850721824914, 0.15492077451199293, 0.1264998730039224, 0.11267068577581085, 0.14736021927092224, 0.14271538413595408, 0.16815510811284184, 0.13725653174333274, 0.17199367401190102, 0.13533031713450328, 0.09820239807595499, 0.13493343139998615], [0.05193302305997349, 0.01451646328860079, 0.02298666429851437, 0.06314167199889198, 0.04690668320108671, 0.05360770155675709, 0.015058456519909669, 0.014905741081747692, 0.0278988599893637, 0.09452629572479054, 0.16401408734964207, 3.5767195746302605, 61.29592828452587, 46.743343770504, 31.95959486067295, 36.550934091210365, 47.15645760297775, 17.709500715136528, 0.060550533889909275, 0.20872220629826188, 2.0394740626215935, 2.5545594608411193, 3.4702773112803698, 0.22686480777338147, 0.5488586390856653, 24.722482301294804, 95.62275812029839, 90.6160631775856, 88.71884018182755, 82.97097980976105, 78.04379940032959, 75.01459434628487, 68.28363552689552, 65.11605709791183, 60.374314337968826, 64.37829628586769, 64.86473098397255, 66.2153609097004, 65.02793982625008, 63.34108494222164, 61.707617193460464, 61.33616432547569, 59.69543136656284, 59.45120707154274, 59.081885889172554, 57.662779837846756, 59.62219029664993, 62.37937554717064, 67.34856650233269, 71.45188271999359, 72.0159624516964, 64.60015878081322, 57.27019250392914, 56.88069440424442, 55.14929451048374, 54.068909883499146, 53.895612582564354, 51.878232434391975, 54.07885015010834, 55.01752898097038, 58.53048227727413, 60.56341879069805, 60.1938696205616, 61.309086978435516, 64.2764313519001, 62.15212494134903, 65.81305369734764, 66.560427993536, 68.30939814448357, 65.30614569783211, 65.50900921225548, 66.69650629162788, 65.9600830078125, 65.67901968955994, 64.39505338668823, 61.10698722302914, 61.756417974829674, 68.3056591451168, 60.690084993839264, 58.97371329367161, 70.39698332548141, 72.0074737071991, 63.73251713812351, 64.54770639538765, 66.86651676893234, 60.38135156035423, 60.11540003120899, 59.71166029572487, 63.75826835632324, 60.66317863762379, 61.026078164577484, 66.47633090615273, 63.34644265472889, 57.65705734491348, 55.401828959584236, 63.885964304208755, 65.8197869360447, 64.95425418019295, 57.108343988657, 62.60434627532959, 62.63480544090271, 60.27648478746414, 58.1117295473814, 53.81670601665974, 58.1431120634079, 57.90853165090084, 59.9711749702692, 60.27334235608578, 60.46771712601185, 59.137549102306366, 68.08676809072495, 60.36632336676121, 58.94829645752907, 51.32331781089306, 52.453859746456146, 54.858625307679176, 60.691243931651115, 60.47897592186928, 62.20657981932163, 62.029178738594055, 62.575460225343704, 51.983851566910744, 48.755164816975594, 49.11154009401798, 50.890251249074936, 58.770469799637794, 64.28086951375008, 68.50321054458618, 66.26354232430458, 64.66391935944557, 61.70919790863991, 59.08642664551735, 55.302483290433884, 53.688523694872856, 62.947023287415504, 63.38388204574585, 63.18213187158108, 66.5395975112915, 68.28108966350555, 68.16224724054337, 69.3272115290165, 67.2506533563137, 69.55485731363297, 66.04058548808098, 71.6481725871563, 67.09237664937973, 70.6840655207634, 74.71386328339577, 73.06684166193008, 81.71456202864647, 47.782344818115234, 0.3662632964551449, 0.30043491628021, 2.7493424713611603, 3.7620833655819297, 0.9622250986285508, 0.1549217541469261, 0.14893202867824584, 5.622216314077377, 72.28138580918312, 36.97161331772804, 50.2337034791708, 38.08623410761356, 43.97854372859001, 0.7913137727882713, 0.13697751390282065, 0.050142257823608816, 0.04477134993067011, 0.022155496008053888, 0.04116813019209076, 0.062488285184372216, 0.04157231123826932, 0.02267299929371802, 0.07538750200183131, 0.09052656503627077, 0.05617317248834297, 0.057447328726993874, 0.07840198712074198, 0.04341795458458364, 0.057232540057157166, 0.044036582912667654, 0.09202473855111748, 0.0663005790556781, 0.13640889519592747, 0.06256806605961174, 0.1627059036400169, 0.3679882554570213, 5.243825018405914, 71.7882938683033, 56.10473424196243, 42.12773524224758, 28.781889975070953, 55.23969545960426, 18.854288086295128, 0.11252020791289397, 0.42168842861428857, 3.562525436282158, 5.237663174048066, 7.060200702399015, 1.9070514058694243, 0.6114959029946476, 29.675090946257114, 99.56996351480484, 92.83376097679138, 94.68230858445168, 86.52658581733704, 84.49322372674942, 77.75014355778694, 73.3323410153389, 67.70716086030006, 65.15377387404442, 68.29251185059547, 68.69330674409866, 70.7504403591156, 69.74855571985245, 66.67005211114883, 65.3988379240036, 63.51037725806236, 62.02310286462307, 61.77347905933857, 61.89058117568493, 59.546961933374405, 63.05808372795582, 64.53973442316055, 69.83320757746696, 74.33098822832108, 73.06732803583145, 66.52969524264336, 59.4587192684412, 60.90765751898289, 58.682196736335754, 56.164505034685135, 56.87607005238533, 56.17814630270004, 57.068784311413765, 58.574407920241356, 61.7594426125288, 62.66256295144558, 62.33739919960499, 63.287690207362175, 71.99224412441254, 66.29158481955528, 69.54772889614105, 69.99180346727371, 71.01890355348587, 70.22058919072151, 65.65661609172821, 68.93228352069855, 68.01329523324966, 66.3145811855793, 67.08663135766983, 64.45374503731728, 65.43531596660614, 69.70088347792625, 64.42562654614449, 63.49348336458206, 73.98668870329857, 72.15101480484009, 66.97063118219376, 67.07249611616135, 68.67706641554832, 63.56227107346058, 62.79784709215164, 63.161411583423615, 65.77198550105095, 61.63461171090603, 62.93246626853943, 65.95147266983986, 67.15929105877876, 59.95901942253113, 58.012855052948, 65.95370694994926, 68.70467573404312, 67.31583505868912, 61.11264131963253, 64.2949515581131, 64.03438434004784, 61.08000487089157, 61.075327321887016, 57.41427317261696, 61.959615871310234, 60.98654128611088, 63.6098825186491, 62.05932252109051, 63.54139119386673, 60.43605722486973, 72.35737413167953, 62.25481443107128, 62.67342656850815, 56.59163251519203, 53.778134286403656, 58.78249995410442, 62.105436846613884, 64.08367529511452, 65.28086185455322, 64.82914209365845, 63.3946468681097, 56.27540208399296, 51.83831937611103, 51.39074519276619, 53.58381651341915, 60.65613001585007, 66.13109663128853, 69.65045258402824, 69.29886505007744, 66.8949544429779, 64.64378044009209, 61.894787549972534, 58.056533709168434, 57.93261855840683, 64.54235628247261, 68.54495510458946, 66.83700755238533, 69.21742022037506, 70.30729293823242, 71.69239461421967, 70.78370377421379, 69.68947649002075, 69.89716574549675, 69.1280110180378, 73.40263724327087, 69.12919655442238, 73.68585124611855, 76.89724132418633, 78.54002997279167, 81.58717006444931, 59.864928871393204, 0.4731163533870131, 0.31346180476248264, 0.31902443908620626, 1.1443793680518866, 0.4622493521310389, 0.086526389059145, 0.19954724237322807, 4.84939050860703, 79.16480764746666, 43.43504749238491, 42.910713627934456, 48.07123191654682, 54.80932295322418, 1.356303971260786, 0.041747112991288304, 0.02983151458465727, 0.07158461114158854, 0.018865516394726, 0.07833263342035934, 0.04333665230660699, 0.0672031196882017, 0.0761564337881282, 0.06807475729146972, 0.08332781420904212, 0.01781907703843899, 0.11943649733439088, 0.3035066358279437, 0.22168544819578528, 0.1516747838468291, 0.10749096254585311, 0.10018090441008098, 0.11938966781599447, 0.18417295563267544, 0.08831194441881962, 0.3898983547696844, 0.45848262612707913, 5.7563362922519445, 86.74233064055443, 62.25339710712433, 44.79437135159969, 49.24347661435604, 67.47386857867241, 26.459574289619923, 0.1585291262017563, 0.6569412862882018, 5.41833302937448, 8.331140354275703, 11.252960320562124, 4.516699835658073, 1.6513917432166636, 34.79071654379368, 104.42788884043694, 99.22536760568619, 99.21669647097588, 91.30951836705208, 90.32723307609558, 81.94464728236198, 76.06136217713356, 72.76993319392204, 69.55379337072372, 70.64111262559891, 72.44929119944572, 75.05777522921562, 74.49521541595459, 71.01967871189117, 70.08573442697525, 69.15612190961838, 66.1168397963047, 68.28367352485657, 65.72312772274017, 63.34539011120796, 67.81847968697548, 70.59828132390976, 75.25239318609238, 78.74043881893158, 78.84578436613083, 70.76213613152504, 62.56874218583107, 65.43532356619835, 62.57276996970177, 61.41520768404007, 59.57777447998524, 59.57810126245022, 62.00952239334583, 61.374093890190125, 65.24695247411728, 66.55876368284225, 67.37480789422989, 66.20539024472237, 72.8850670158863, 69.66075763106346, 74.67138916254044, 73.13267692923546, 73.71071711182594, 73.45480844378471, 71.53252199292183, 74.8153406381607, 73.70653733611107, 69.7372855246067, 71.7665134370327, 67.39259853959084, 70.49735873937607, 73.10000628232956, 66.8889507651329, 65.18367826938629, 75.85312575101852, 76.52362257242203, 70.90221181511879, 69.31519657373428, 71.41864210367203, 66.1009718477726, 66.36389493942261, 65.41219040751457, 69.62315484881401, 65.0508525967598, 63.69934871792793, 70.78257903456688, 68.57707098126411, 62.29232221841812, 57.952586486935616, 71.01957991719246, 71.3107430934906, 71.02311372756958, 65.2198675274849, 70.88895052671432, 64.12389993667603, 67.98494875431061, 65.19850507378578, 61.998548582196236, 63.67229796946049, 65.90439319610596, 67.03184589743614, 65.02794742584229, 66.81741580367088, 65.42577847838402, 72.7466556429863, 67.39669471979141, 65.39430856704712, 58.50774809718132, 56.93680219352245, 62.6576954126358, 65.42330861091614, 67.34061732888222, 69.41638514399529, 69.08168390393257, 67.49259397387505, 57.96690411865711, 55.232160463929176, 53.61212499439716, 56.646121591329575, 64.83474299311638, 69.17971104383469, 73.76165717840195, 72.58082494139671, 71.1809952557087, 67.77406007051468, 64.38238486647606, 60.57503096759319, 60.69938689470291, 68.66866126656532, 71.67815297842026, 71.54669523239136, 71.63491889834404, 73.40185448527336, 74.00916829705238, 74.25309240818024, 73.82937714457512, 75.31631335616112, 72.58023977279663, 78.64820256829262, 71.68302431702614, 77.83201396465302, 81.9117334485054, 82.8355398774147, 86.61627620458603, 61.083059906959534, 0.4515438718954101, 1.4868889516219497, 9.723300151526928, 9.58911320194602, 4.521920755505562, 0.7304463826585561, 0.3353964543202892, 8.116031996905804, 87.02771812677383, 50.433150976896286, 69.3272115290165, 51.478946059942245, 66.25278890132904, 1.8191084498539567, 0.20644727133912966, 0.30962786986492574, 0.18246508087031543, 0.12061545829055831, 0.13003087806282565, 0.17644617415498942, 0.1442488096654415, 0.1650574876111932, 0.16435688536148518, 0.20209527283441275, 0.14537828421453014], [0.06199969968292862, 0.042813590334844775, 0.03643139119958505, 0.028740761590597685, 0.008896438685042085, 0.04784679877047893, 0.048197678770520724, 0.03324397453980055, 0.04436887211340945, 0.11484476286568679, 0.27518583519849926, 8.417342528700829, 68.36349204182625, 40.25702342391014, 35.959264039993286, 55.07725037634373, 41.61868795752525, 6.391138778999448, 0.05825580585224088, 0.1921239696093835, 3.4227565862238407, 5.442708721384406, 9.80524180456996, 4.181523621082306, 0.20423589390702546, 37.23889857530594, 95.77405080199242, 87.89214134216309, 87.4320924282074, 84.39054563641548, 81.77344366908073, 76.22660011053085, 68.59390407800674, 64.81185302138329, 64.61040303111076, 64.22088593244553, 61.795248091220856, 62.27310284972191, 65.35255640745163, 67.11655095219612, 63.51845182478428, 60.20260155200958, 57.97879748046398, 58.620104268193245, 59.20398473739624, 58.00869047641754, 55.890038162469864, 56.10671393573284, 60.70642031729221, 63.55282858014107, 63.79295289516449, 59.05972547829151, 56.492583230137825, 53.14121626317501, 50.87164744734764, 52.56336987018585, 55.871369764208794, 54.72392253577709, 53.39024730026722, 54.93229575455189, 60.949983447790146, 61.903397887945175, 58.780862241983414, 65.89974224567413, 60.29727727174759, 59.93173688650131, 66.73528701066971, 64.19836074113846, 65.26831492781639, 67.53694519400597, 64.71911519765854, 64.01261150836945, 59.70824047923088, 63.40779796242714, 68.3669650554657, 55.65952353179455, 63.999053835868835, 67.6848940551281, 61.80064380168915, 67.11257636547089, 70.54158836603165, 62.15728886425495, 64.05560240149498, 66.93796813488007, 65.79315036535263, 63.93357574939728, 61.968097016215324, 66.99401512742043, 64.18009132146835, 64.45289388298988, 65.51955744624138, 59.48290877044201, 68.21365088224411, 68.57433512806892, 61.18958719074726, 56.35775126516819, 59.28544856607914, 64.17170137166977, 63.15246306359768, 55.50476923584938, 59.21302065253258, 60.035858899354935, 58.11493277549744, 54.5501122623682, 59.31762903928757, 59.29361812770367, 60.536436438560486, 56.40283204615116, 61.95626825094223, 53.963047564029694, 58.96055079996586, 66.5999686717987, 59.34784881770611, 54.72692437469959, 51.36229611933231, 54.71953757107258, 55.302973464131355, 59.0811563283205, 61.894418969750404, 64.68681693077087, 60.80389268696308, 56.60826422274113, 48.67484472692013, 48.899367079138756, 49.17899787425995, 56.978797540068626, 64.03769016265869, 68.89591187238693, 69.11443054676056, 67.53946825861931, 61.26937910914421, 59.6664959192276, 53.235040828585625, 56.842878833413124, 61.583774238824844, 63.81110832095146, 62.314148247241974, 65.54858788847923, 66.61281198263168, 68.93177434802055, 66.0765315592289, 66.5392555296421, 65.60787990689278, 65.01173749566078, 67.69299522042274, 68.3167165517807, 68.11917275190353, 71.34748712182045, 76.42123326659203, 75.21136298775673, 70.03009021282196, 13.796401340514421, 0.6192457058932632, 0.23996107222046703, 0.47375077090691775, 1.565585460048169, 0.09764122311025858, 0.06432441048673354, 0.46876223233994097, 57.520842254161835, 49.47996832430363, 35.79253278672695, 28.006224296987057, 48.56786526739597, 3.6703137774020433, 0.33188514586072415, 0.03185608045896515, 0.06351565505610779, 0.10175210525630973, 0.07906871032901108, 0.02412082365481183, 0.07241128201712854, 0.0451820544549264, 0.04918659426039085, 0.08181234865332954, 0.07589661530801095, 0.02559436899900902, 0.009225111771229422, 0.029590698795800563, 0.03910350875230506, 0.013441919727483764, 0.06555506202857941, 0.05783062944828998, 0.1114491923362948, 0.07315206414205022, 0.1358278826228343, 0.5452575604431331, 13.766428548842669, 75.7463438808918, 53.639225140213966, 45.86494490504265, 49.24426697194576, 51.08054883778095, 7.902271142229438, 0.18751799332676455, 0.37593621178530157, 4.513805340975523, 7.518846541643143, 6.041855346411467, 3.3580263471230865, 0.27586789859924465, 44.988138154149055, 98.67517992854118, 89.87028479576111, 91.65086925029755, 87.30837106704712, 87.94851511716843, 78.26972007751465, 71.938446611166, 67.868492603302, 68.37435945868492, 65.76226562261581, 66.06536775827408, 63.85181173682213, 70.27845248579979, 69.68706741929054, 66.96746975183487, 63.43996323645115, 60.52433028817177, 60.126001462340355, 63.62160488963127, 61.474613696336746, 59.57412667572498, 59.554918706417084, 64.62186321616173, 65.12234196066856, 67.01619073748589, 62.94700048863888, 59.870237186551094, 57.07595072686672, 55.73569804430008, 55.57798370718956, 58.38890187442303, 58.26936788856983, 56.64877764880657, 59.93633083999157, 63.2370313256979, 66.15064278244972, 63.11235621571541, 70.31282544136047, 64.93330210447311, 65.09797006845474, 70.14776229858398, 69.27063256502151, 68.442003428936, 71.3928870856762, 67.57514834403992, 65.91390788555145, 65.10907307267189, 65.70418193936348, 71.21409147977829, 57.21762232482433, 65.51975503563881, 69.99529168009758, 65.59444382786751, 68.64181190729141, 72.24237710237503, 64.1800457239151, 67.97153547406197, 68.62995654344559, 70.12051776051521, 68.36161494255066, 64.05260056257248, 68.60472589731216, 66.07299774885178, 66.45894303917885, 67.39138260483742, 62.84132815897465, 68.50109025835991, 68.74819099903107, 65.38852527737617, 59.94808740913868, 59.43697303533554, 66.62161991000175, 67.69177168607712, 59.79159280657768, 60.35947993397713, 64.64704066514969, 60.15984624624252, 57.368212044239044, 60.952692702412605, 63.49995821714401, 63.141698241233826, 59.61717836558819, 63.94256606698036, 58.89168329536915, 60.45144259929657, 68.86812776327133, 62.59375624358654, 58.64495873451233, 53.667480424046516, 55.77041298151016, 56.68189287185669, 61.9627621024847, 63.344869539141655, 65.50793007016182, 63.41313287615776, 60.178096666932106, 51.88377633690834, 51.89630426466465, 51.59833945333958, 59.451716244220734, 68.47100347280502, 69.51507344841957, 71.45298466086388, 71.66736155748367, 64.54448416829109, 61.73083394765854, 56.64286896586418, 58.52821759879589, 64.90591317415237, 65.67121490836143, 64.27894681692123, 68.5752622783184, 69.09366846084595, 68.68607953190804, 66.85634091496468, 67.74822905659676, 67.01323449611664, 67.46569901704788, 71.45792439579964, 69.34570893645287, 72.97267511487007, 72.3667824268341, 78.71372625231743, 77.99738869071007, 73.65188106894493, 21.48279894143343, 2.236149371601641, 1.528710932470858, 0.1649800519226119, 1.0156365763396025, 0.08603861249866895, 0.01676138115726644, 0.3033929388038814, 60.885892286896706, 59.600926637649536, 35.63291095197201, 32.55511410534382, 61.319240033626556, 6.6463905572891235, 0.30245860456489027, 0.1063681005325634, 0.07185788475908339, 0.07082654439727776, 0.09146617594524287, 0.047978756338125095, 0.0330078379920451, 0.012429587623046245, 0.02134107613528613, 0.015314163501898292, 0.031971057687769644, 0.10276366738253273, 0.12521683325758204, 0.20812540082260966, 0.23585818300489336, 0.15250943280989304, 0.3315143985673785, 0.146181347372476, 0.27134094620123506, 0.10948875729809515, 0.3900304273702204, 0.6012724922038615, 14.20668052509427, 93.96924644708633, 52.733745127916336, 49.99237842857838, 67.31060653924942, 64.1427393257618, 11.766724102199078, 0.32108487852383405, 1.3847416453063488, 7.643685517832637, 15.899365246295929, 24.713146202266216, 7.188164060935378, 0.7104560709558427, 54.922226294875145, 100.30704036355019, 98.69996979832649, 94.54462677240372, 92.81595513224602, 91.06469750404358, 82.67318218946457, 75.55413499474525, 72.08376601338387, 72.6871508359909, 70.96609398722649, 69.1028867661953, 69.46806997060776, 73.81295442581177, 74.45581153035164, 70.65444231033325, 69.44339409470558, 63.36970120668411, 66.20149925351143, 67.41828516125679, 64.45980951189995, 60.33658616244793, 62.02536754310131, 68.97438526153564, 69.7503112256527, 71.01324185729027, 65.3713957965374, 63.1485378742218, 61.46876581013203, 57.960911840200424, 58.02902318537235, 62.095918357372284, 62.24982909858227, 61.52057982981205, 63.56862433254719, 69.7550381720066, 70.29385685920715, 63.866805732250214, 71.36995151638985, 67.05731973052025, 69.42322477698326, 72.61411115527153, 71.65724650025368, 70.25335103273392, 75.48399835824966, 70.58500483632088, 70.38141936063766, 66.76994875073433, 70.59406355023384, 75.74363082647324, 62.539658546447754, 70.34310981631279, 72.798712849617, 66.46606385707855, 72.45065912604332, 77.04743966460228, 66.18693843483925, 71.13703161478043, 73.00495058298111, 72.01466292142868, 71.47842809557915, 68.0631485581398, 71.90367847681046, 69.21221449971199, 69.70592200756073, 70.5016677081585, 66.34703904390335, 71.61285728216171, 74.46831285953522, 65.7023960351944, 60.1039132475853, 62.153622061014175, 70.84152907133102, 70.33919602632523, 62.27715723216534, 64.89025801420212, 66.4434702694416, 64.1554382443428, 60.99356330931187, 64.84152942895889, 67.66341760754585, 67.18224182724953, 62.81913734972477, 65.08795380592346, 62.83801093697548, 62.18858778476715, 68.98186326026917, 67.39017426967621, 61.20629109442234, 56.52762874960899, 60.1034040749073, 61.77115358412266, 64.57859873771667, 65.75603395700455, 70.67691430449486, 65.72314292192459, 65.35393193364143, 54.70671705901623, 53.50932151079178, 54.03582885861397, 62.38616578280926, 70.76453000307083, 73.36197942495346, 74.71600636839867, 74.7577129304409, 67.06915229558945, 66.15163072943687, 59.085016921162605, 62.21480257809162, 68.58917713165283, 68.52000564336777, 69.73999857902527, 71.14967733621597, 72.09131240844727, 73.7322923541069, 70.24110808968544, 73.02429914474487, 70.90631559491158, 70.48287391662598, 75.48817053437233, 72.53940716385841, 77.21710816025734, 77.5458437204361, 84.38459515571594, 82.98160403966904, 75.8428966999054, 21.708358637988567, 2.510279486887157, 3.3348620776087046, 0.6376173044554889, 5.702384887263179, 0.9294147498439997, 0.09820546314585954, 1.0626468225382268, 69.24294725060463, 64.75237861275673, 54.02491204440594, 37.083555310964584, 71.92737400531769, 6.643048636615276, 0.5649576627183706, 0.2633916540071368, 0.15803694870555773, 0.3371634188806638, 0.20176537334918976, 0.13450360915157944, 0.12178067467175424, 0.13003200612729415, 0.14139842824079096, 0.16886702069314197, 0.12282150710234419], [0.03797717719862703, 0.053848936659051105, 0.02874722569686128, 0.06520824157632887, 0.07108749836334027, 0.0985463909455575, 0.04242850103764795, 0.044866337411804125, 0.08973971780505963, 0.10377807193435729, 0.3280077804811299, 24.173039384186268, 65.3762899339199, 23.4797627851367, 32.92264178395271, 52.88517840206623, 25.87821688503027, 0.7153475366067141, 0.027971978233836126, 0.6770569318905473, 2.901688409037888, 3.5770971793681383, 1.5612123697064817, 0.5787960451561958, 3.6628923006355762, 69.41481962800026, 92.33884513378143, 93.29491183161736, 85.13098910450935, 86.37569591403008, 79.98790428042412, 79.65738281607628, 68.65916177630424, 65.83174109458923, 62.92315676808357, 66.03155717253685, 64.82953727245331, 61.345143243670464, 66.35555058717728, 67.46589660644531, 69.8454201221466, 63.9397694170475, 60.7152434438467, 57.426223531365395, 59.30944047868252, 56.2947316467762, 56.525375470519066, 55.82514524459839, 56.04809448122978, 58.43866780400276, 58.74891355633736, 57.59236961603165, 56.21108293533325, 53.1870836019516, 53.15622925758362, 54.35011379420757, 54.12936083972454, 55.586426854133606, 53.72392259538174, 55.28805546462536, 58.96390601992607, 59.419345781207085, 65.97338229417801, 64.69296500086784, 56.018984243273735, 63.69948551058769, 65.00258758664131, 71.05874821543694, 70.92256352305412, 64.10614728927612, 58.00326816737652, 61.745280772447586, 61.83716744184494, 64.23517316579819, 61.241898983716965, 56.53862155973911, 69.15787741541862, 62.33532831072807, 65.26495590806007, 67.909826785326, 61.93931356072426, 62.140474766492844, 63.90383094549179, 65.68455219268799, 67.76912033557892, 57.56321378052235, 61.887978315353394, 56.010392904281616, 59.894514083862305, 56.50486037135124, 56.74402713775635, 54.45505276322365, 53.804219886660576, 59.829548969864845, 64.9707680940628, 65.16660958528519, 58.598536625504494, 56.9136880338192, 59.35285694897175, 65.46503037214279, 55.45181147754192, 58.124561458826065, 55.19074268639088, 55.79296097159386, 58.54791194200516, 60.52146144211292, 58.899184092879295, 58.92870470881462, 58.17433498799801, 62.598836570978165, 51.0923358052969, 55.122251361608505, 60.41437178850174, 56.6903930157423, 52.60247357189655, 48.03412310779095, 51.79676480591297, 54.92020860314369, 59.06556576490402, 60.839405581355095, 58.25457148253918, 57.111866399645805, 49.70601059496403, 49.182562083005905, 47.796031683683395, 53.53526271879673, 60.68775191903114, 65.81510558724403, 66.08935207128525, 66.44771084189415, 60.89424043893814, 57.68222339451313, 50.81866689026356, 55.57234100997448, 58.78864802420139, 63.4915454685688, 61.34936481714249, 62.86219663918018, 62.51006953418255, 66.19310170412064, 62.59782202541828, 63.843208998441696, 61.84439845383167, 64.61503118276596, 67.786515802145, 68.14444899559021, 65.45562207698822, 72.06301912665367, 70.13318628072739, 75.91652154922485, 73.26291874051094, 46.09467297792435, 2.1917570661753416, 0.4395491920877248, 0.23036170372506604, 0.030910610294085927, 0.05228897563938517, 0.1519668338005431, 0.26845687127206475, 35.94719208776951, 65.52803099155426, 39.84244666993618, 28.677188493311405, 44.661500081419945, 16.469802036881447, 0.44231974810827523, 0.056411943660350516, 0.03552847949322313, 0.10073403449496254, 0.08171797715476714, 0.09308284075814299, 0.07610086177010089, 0.031164465617621318, 0.08783737808698788, 0.07879415279603563, 0.015187076278380118, 0.02420766049908707, 0.0487903764587827, 0.03179946572345216, 0.07231374154798687, 0.0281299833295634, 0.07942630676552653, 0.009004881303553702, 0.13265018438687548, 0.03815745600149967, 0.23571974277729169, 0.4079673648811877, 33.513095900416374, 75.06713032722473, 38.74676026403904, 31.48191299289465, 50.419300720095634, 35.915159806609154, 0.4310535010881722, 0.05690519727068022, 0.8891285990830511, 4.467894779518247, 5.818679071962833, 1.376776322722435, 1.4019118552096188, 9.627180509269238, 75.34535899758339, 94.7160355746746, 95.92145249247551, 90.47812297940254, 89.10742253065109, 83.51813524961472, 81.5068119764328, 74.07450959086418, 68.24072062969208, 66.99111208319664, 68.3313761651516, 67.26764604449272, 64.67788740992546, 69.45179924368858, 70.90815469622612, 72.59861558675766, 70.76117098331451, 63.69798079133034, 60.79870216548443, 62.17223346233368, 58.3803903311491, 60.38079299032688, 57.75816611945629, 59.3320606648922, 59.81073617935181, 61.2631968408823, 58.4657147526741, 59.414793625473976, 54.828800708055496, 56.090792790055275, 58.58890414237976, 58.363929614424706, 57.385147735476494, 57.375929430127144, 58.64319942891598, 62.6184169203043, 63.5477976500988, 70.63022240996361, 68.22614461183548, 60.207028314471245, 67.25737139582634, 68.31578940153122, 73.64681214094162, 76.22970074415207, 65.56990474462509, 59.39002275466919, 64.26696985960007, 64.97972801327705, 67.78958603739738, 64.33019086718559, 60.139258950948715, 72.19379290938377, 62.13978700339794, 66.51384249329567, 70.32437682151794, 63.72023619711399, 65.67012056708336, 68.7902395427227, 68.21520119905472, 68.82786512374878, 60.07628872990608, 62.72550657391548, 57.703794836997986, 61.888373494148254, 58.58590990304947, 60.400810316205025, 55.77789098024368, 55.63566081225872, 62.996827214956284, 65.46896696090698, 69.2048428952694, 63.66834998130798, 57.37857028841972, 61.678126975893974, 67.65026271343231, 60.45998454093933, 63.06370362639427, 59.77732457220554, 58.79800692200661, 62.15069621801376, 61.34698234498501, 60.4334581643343, 60.25550611317158, 60.43088190257549, 64.85460072755814, 54.41117651760578, 57.73584611713886, 62.520416378974915, 58.588581159710884, 56.56791418790817, 49.956694543361664, 54.96383026242256, 57.15446591377258, 59.94689427316189, 63.93834829330444, 61.247644275426865, 59.68599647283554, 52.484258115291595, 50.68503186106682, 51.05254054069519, 57.395669370889664, 63.62297661602497, 67.6070362329483, 69.10905003547668, 68.68179336190224, 64.35654625296593, 60.996272563934326, 53.22556413710117, 58.13178487122059, 62.29528225958347, 65.13545885682106, 64.31114628911018, 66.00241273641586, 66.34016901254654, 68.73128950595856, 64.1346837580204, 65.89496970176697, 63.806008994579315, 67.39048585295677, 70.76622471213341, 70.21866649389267, 69.96360138058662, 76.29033789038658, 71.61699146032333, 79.12260711193085, 76.20072349905968, 55.056461691856384, 4.23761336132884, 0.4370121454121545, 0.3396085283020511, 0.3652223007520661, 0.04847752410569228, 0.1028096879599616, 0.3263027110369876, 34.63761895895004, 77.31163188815117, 42.61472471058369, 28.653941340744495, 55.532469749450684, 25.005327723920345, 0.5117246566805989, 0.1508872167323716, 0.0993298836692702, 0.023226995836012065, 0.1576159431715496, 0.03733680765435565, 0.07433051301632077, 0.029479719887604006, 0.10435805292217992, 0.027563925032154657, 0.03583814803278074, 0.08209145555156283, 0.21455893060192466, 0.13084778969641775, 0.19236069987528026, 0.22305520047666505, 0.1970373434596695, 0.0926758098648861, 0.271609989576973, 0.25333706696983427, 0.32162792282179, 0.5454388819634914, 35.27109436690807, 90.78494891524315, 33.3169162273407, 44.22656401991844, 66.66521117091179, 45.4037294536829, 2.050298019312322, 0.27736623538658023, 2.959607751108706, 6.320607913658023, 15.167498867958784, 10.189373642206192, 2.4960065027698874, 10.408525932580233, 84.20338287949562, 97.89043083786964, 103.68559867143631, 93.96410912275314, 94.80665311217308, 87.65610560774803, 87.79371902346611, 76.40924111008644, 72.72678270936012, 68.69799569249153, 73.54656592011452, 71.96741625666618, 67.9585249722004, 73.66749063134193, 76.22108280658722, 76.76392167806625, 73.97598087787628, 66.00927516818047, 64.87024828791618, 65.60608640313148, 61.40628196299076, 63.73536318540573, 60.163535848259926, 63.06619629263878, 63.42267796397209, 66.17278799414635, 63.554591685533524, 63.995649218559265, 58.97716350853443, 57.857633382081985, 62.32933223247528, 62.261308282613754, 61.01112976670265, 59.29370552301407, 62.21642129123211, 65.15660852193832, 67.07557395100594, 72.60270416736603, 71.8515756726265, 64.868895560503, 69.22598496079445, 70.40761515498161, 78.6211708188057, 76.61051630973816, 68.3930392563343, 60.84980182349682, 66.2017272412777, 68.67720320820808, 71.6048701107502, 67.34687939286232, 61.11156977713108, 74.30986896157265, 67.14733690023422, 67.92245730757713, 73.1561216711998, 64.84233498573303, 65.6023322045803, 70.7055951654911, 70.01747488975525, 72.40572273731232, 62.29570783674717, 67.20639333128929, 60.565634071826935, 65.36449536681175, 61.00018635392189, 63.52732054889202, 61.064649894833565, 57.55831204354763, 64.85649302601814, 71.99548915028572, 72.78882578015327, 64.80031684041023, 58.9327172935009, 65.33373221755028, 70.97534269094467, 63.80929961800575, 65.35556584596634, 61.396630480885506, 62.22715951502323, 64.36246633529663, 66.74525767564774, 65.47882363200188, 63.84993463754654, 65.28780028223991, 66.9559183716774, 57.78901286423206, 59.863557144999504, 63.98317068815231, 60.52957780659199, 59.79677192866802, 53.92054304480553, 57.33448505401611, 62.07567684352398, 63.94780978560448, 67.11205959320068, 63.32929417490959, 63.46138648688793, 54.17986772954464, 52.775573283433914, 54.18913163244724, 60.645589381456375, 66.73360750079155, 70.71113526821136, 71.32372319698334, 71.47483348846436, 66.64907723665237, 63.335351049900055, 57.14380368590355, 61.386656016111374, 65.3119669854641, 69.52462613582611, 67.92067900300026, 70.86179718375206, 68.65096941590309, 73.48310172557831, 68.44890385866165, 70.44429078698158, 67.25756138563156, 70.3190267086029, 74.65859144926071, 75.77434837818146, 73.4867799282074, 81.65341570973396, 75.18335089087486, 82.37536177039146, 78.90931695699692, 55.944363847374916, 6.00503247231245, 2.605766225606203, 1.032748008146882, 1.129898107610643, 0.18094741855747998, 0.4284734989050776, 0.6591670762281865, 45.11304125189781, 79.2525677382946, 57.97291159629822, 41.58933833241463, 65.008325278759, 28.44291966408491, 0.764546524733305, 0.3081891720648855, 0.2354366728104651, 0.2518165251240134, 0.3078289335826412, 0.22544217004906386, 0.1417776063317433, 0.09784161040442996, 0.1290112710557878, 0.14600820431951433, 0.10950699186651036], [0.04715503549959976, 0.046345389491762035, 0.039258287361008115, 0.08919950108975172, 0.041580211400287226, 0.06245369368116371, 0.05606403967249207, 0.057174793546437286, 0.11616343312198296, 0.11376896043657325, 0.08239536502514966, 40.16342304646969, 61.61091238260269, 33.426384553313255, 59.403721019625664, 52.01430693268776, 9.723229855298996, 0.12851740146288648, 0.044545154451043345, 0.27596520900260657, 2.6866999827325344, 5.36786176264286, 1.6890030750073493, 1.612884015776217, 31.149656921625137, 91.5498934686184, 88.4275934100151, 94.67776402831078, 87.61236995458603, 86.74549207091331, 82.50619634985924, 80.38977071642876, 74.31752935051918, 70.30840247869492, 63.18861432373524, 61.50530844926834, 61.40181340277195, 64.4300951063633, 68.21361288428307, 70.4607667028904, 68.24870020151138, 72.32002973556519, 64.18413430452347, 59.31935794651508, 57.528764829039574, 58.18699210882187, 55.670668333768845, 55.88891722261906, 55.90754762291908, 56.451431438326836, 56.5245471149683, 54.8486964404583, 54.67174753546715, 52.397964745759964, 53.70618894696236, 53.30651879310608, 55.818814784288406, 54.00499351322651, 55.78891038894653, 56.17110148072243, 60.0929394364357, 60.45657232403755, 60.509431287646294, 52.42107130587101, 62.44549199938774, 66.022247672081, 64.89612489938736, 66.27979785203934, 70.79754263162613, 62.43829518556595, 58.536580950021744, 64.01397183537483, 65.8021254837513, 60.40947765111923, 56.072261184453964, 55.50208657979965, 64.53921765089035, 63.46363216638565, 69.68484833836555, 63.24748836457729, 61.55840680003166, 68.61219629645348, 69.18571472167969, 67.5574716925621, 54.01015363633633, 49.73545901477337, 61.01072698831558, 58.02170857787132, 63.51070024073124, 61.19491830468178, 59.61791172623634, 51.05646193027496, 52.000103294849396, 58.72198820114136, 56.240386962890625, 57.5754339247942, 64.90149021148682, 62.39830993115902, 58.01990367472172, 58.80761280655861, 65.01199588179588, 54.98016178607941, 54.848540648818016, 59.93861831724644, 65.40820822119713, 62.024778574705124, 58.55928473174572, 58.44834588468075, 56.97266846895218, 60.221752524375916, 61.47082529962063, 55.860779732465744, 55.54744854569435, 57.512152120471, 52.171812281012535, 48.093882501125336, 50.411822721362114, 56.134175062179565, 56.47056341171265, 57.282443046569824, 59.52394276857376, 55.929366052150726, 52.252375558018684, 47.52928599715233, 47.31566146016121, 51.147136464715004, 61.91855527460575, 62.92539484798908, 64.49194058775902, 65.15346229076385, 58.756345957517624, 57.11466684937477, 51.98291301727295, 54.627453312277794, 56.32830664515495, 59.92028430104256, 56.758998334407806, 62.054002806544304, 60.48464521765709, 62.74471454322338, 58.771868124604225, 59.225932359695435, 56.68642982840538, 62.0983312278986, 64.29539233446121, 66.62087514996529, 66.28026142716408, 69.40291866660118, 70.64825624227524, 77.6789353787899, 72.35406830906868, 61.92455895245075, 7.811576183885336, 0.14163233834551647, 0.21531048871111125, 0.3772005345672369, 0.030742352428205777, 0.08542455951101147, 0.2753074583597481, 15.658528469502926, 80.45455724000931, 38.47747631371021, 37.4015336483717, 37.48399682343006, 26.69033020734787, 0.15180470421910286, 0.0487117422017036, 0.05038790128310211, 0.008199126004910795, 0.1295849512098357, 0.06330240634270012, 0.03352093663124833, 0.022683812385366764, 0.03711132834723685, 0.01866989925474627, 0.055392036083503626, 0.09951062631444074, 0.03539110053679906, 0.06191336193296593, 0.10736827069194987, 0.04545250420051161, 0.02640685186634073, 0.007093363537933328, 0.019247009986429475, 0.12058174994308501, 0.05697938977391459, 0.04294302088965196, 50.853454023599625, 72.20877930521965, 45.31457103788853, 34.671710729599, 58.70644323527813, 14.620921947062016, 0.28073822788428515, 0.14118848950602114, 0.9123461251147091, 2.9749033553525805, 2.8081222297623754, 2.0999772660434246, 1.666260464116931, 38.24502758681774, 92.28046506643295, 90.91240927577019, 97.84962102770805, 87.85291984677315, 89.51118126511574, 87.48240932822227, 83.70655953884125, 78.58131855726242, 72.46914893388748, 65.21351426839828, 64.97704535722733, 64.53126087784767, 66.96210443973541, 71.8953113257885, 71.3096259534359, 72.87094697356224, 75.34135401248932, 66.85617372393608, 62.080620378255844, 60.7792130112648, 61.4882967621088, 59.12065900862217, 58.9819398522377, 59.00873601436615, 60.49274638295174, 58.26369099318981, 57.213662937283516, 56.33356936275959, 55.23504450917244, 55.89959844946861, 58.006596788764, 59.08193148672581, 57.855961471796036, 59.30406756699085, 61.195207089185715, 61.98171928524971, 66.2153685092926, 64.62890043854713, 56.26914381980896, 66.30954265594482, 69.406368881464, 68.87964874505997, 69.36406955122948, 72.71865874528885, 63.192797899246216, 58.56798246502876, 68.31692174077034, 66.92768588662148, 64.36259552836418, 58.094026297330856, 55.93036539852619, 66.695237159729, 65.74576690793037, 74.09458771348, 64.84155222773552, 62.4632902443409, 70.34692481160164, 72.91441664099693, 66.54312372207642, 54.34668257832527, 55.319301187992096, 64.499471783638, 63.21092672646046, 66.29458665847778, 65.26409715414047, 64.28857550024986, 57.37766593694687, 54.509538039565086, 65.37809863686562, 57.893537655472755, 57.62977480888367, 65.03067567944527, 65.52569031715393, 60.44221289455891, 59.75122757256031, 65.63059508800507, 58.50355312228203, 56.748560294508934, 62.53221854567528, 67.77095183730125, 64.86103758215904, 62.51470148563385, 61.37216739356518, 60.317974761128426, 64.28412973880768, 64.95933830738068, 58.221760243177414, 60.57416081428528, 59.969351068139076, 53.8944498449564, 54.89041820168495, 52.25456424057484, 57.04296849668026, 58.38893227279186, 60.58883182704449, 60.16262769699097, 58.31314913928509, 55.23369938135147, 51.396623477339745, 48.499282747507095, 51.74798682332039, 63.69001641869545, 66.35743528604507, 68.27490359544754, 68.3813738822937, 60.20179979503155, 58.7700442224741, 54.756065011024475, 57.156620398163795, 58.7046155333519, 62.31926277279854, 60.94382017850876, 64.0868367254734, 61.478694677352905, 64.08423006534576, 62.044647708535194, 62.9567089676857, 58.838368356227875, 64.83453780412674, 65.73467910289764, 70.41942492127419, 66.35457023978233, 72.83587485551834, 74.93115082383156, 79.42243382334709, 74.23140317201614, 70.8692979812622, 14.12374522536993, 0.07082253679982387, 0.22504304302856326, 0.11873756491695531, 0.07669330341741443, 0.1552898742374964, 0.3681768203387037, 15.194770004600286, 90.49795791506767, 43.566250652074814, 35.06078705191612, 48.12442906200886, 36.3977225124836, 0.0496886237669969, 0.05208099988522008, 0.03214703574485611, 0.07024503458524123, 0.11334878610796295, 0.02583738896646537, 0.044153567650937475, 0.04228364865412004, 0.04644874468795024, 0.03598714531108271, 0.015382555193355074, 0.2484223572537303, 0.11318102362565696, 0.1771425610058941, 0.18378644512267783, 0.11828249480458908, 0.13962880679173395, 0.16801512421807274, 0.18594943452626467, 0.21725835918914527, 0.14345768024213612, 0.22107348806457594, 60.1437047123909, 82.25767448544502, 45.218854174017906, 76.57656133174896, 75.13181805610657, 20.165768712759018, 0.7080132770352066, 0.17040059465216473, 1.3731742347590625, 8.567706160247326, 13.252675216645002, 6.625703517347574, 2.9770053550601006, 42.74861052632332, 96.40949070453644, 96.52536928653717, 103.42932522296906, 92.63396769762039, 96.76012828946114, 92.09804445505142, 88.45081776380539, 82.65415281057358, 77.36789166927338, 71.21060326695442, 68.70146110653877, 67.96328991651535, 72.74081155657768, 76.61142066121101, 77.8326903283596, 74.87945839762688, 79.7386984527111, 69.61566165089607, 66.97164192795753, 65.86004957556725, 64.77010846138, 60.84050752222538, 62.89875827729702, 63.89582097530365, 62.40771062672138, 63.01019869744778, 58.499897718429565, 60.82482576370239, 59.15392242372036, 59.83451530337334, 60.99192179739475, 62.941217198967934, 62.60723032057285, 63.112747594714165, 62.501801177859306, 66.06073960661888, 67.78955563902855, 68.52926954627037, 62.066644728183746, 68.14245030283928, 73.35045084357262, 72.05102697014809, 72.39650443196297, 76.82922497391701, 63.241735473275185, 62.542265206575394, 70.25303944945335, 73.87622103095055, 67.43033811450005, 63.11976581811905, 59.51427988708019, 70.43180465698242, 68.34575459361076, 77.95476257801056, 67.75705978274345, 64.09242242574692, 74.0951044857502, 75.42042016983032, 72.42247223854065, 59.73846025764942, 57.15899907052517, 67.64568775892258, 64.14811223745346, 68.726866543293, 66.35927438735962, 64.12728935480118, 58.301612958312035, 56.81480973958969, 67.26790443062782, 60.977201387286186, 63.49432311952114, 70.3963677585125, 67.43628099560738, 61.49013206362724, 63.215152099728584, 72.17418596148491, 60.50860673189163, 59.838467091321945, 66.60267412662506, 68.72212439775467, 64.700648188591, 66.52165487408638, 64.0232889354229, 63.13846081495285, 66.63643911480904, 68.35369616746902, 61.45225949585438, 62.08571970462799, 62.39568047225475, 56.98619954288006, 55.60870885848999, 56.03468880057335, 59.79440085589886, 61.935631558299065, 63.638749569654465, 63.7827542424202, 61.806936264038086, 57.69021436572075, 52.1855865418911, 52.20971904695034, 56.424118503928185, 67.181785851717, 68.11807081103325, 70.78099831938744, 71.32839694619179, 63.754833340644836, 64.028350263834, 57.179601565003395, 61.08921937644482, 61.79298721253872, 66.62159711122513, 62.78839699923992, 67.86020144820213, 64.37663957476616, 68.29204827547073, 64.66099351644516, 66.8153715133667, 60.972930416464806, 68.32721158862114, 68.6430886387825, 76.5353487432003, 71.7001461982727, 79.66912418603897, 78.70919689536095, 87.59049072861671, 76.82100981473923, 74.80657070875168, 16.034267507493496, 0.23294691578485072, 0.7485537172760814, 0.7307372451759875, 0.27895270963199437, 0.43468770920298994, 0.39344875956885517, 21.43480371683836, 95.67043796181679, 52.791456431150436, 52.98202380537987, 52.51897305250168, 44.43826965987682, 0.33447387570049614, 0.22603657096624374, 0.23291461751796305, 0.15732062776805833, 0.20129261043621227, 0.11713788786437362, 0.15346465108450502, 0.12809084466425702, 0.16291789070237428, 0.1290736411465332, 0.1621989722480066], [0.03472248856269289, 0.017451064559281804, 0.06344236797303893, 0.020678508954006247, 0.02998798714543227, 0.03602507276809774, 0.09742374415509403, 0.04231783197610639, 0.03449644151260145, 0.04853735976212192, 0.639547185273841, 59.18082877993584, 43.23483243584633, 37.49548360705376, 53.03280808031559, 38.513460382819176, 4.835355011746287, 0.019927008361264598, 0.16734564764192328, 0.04985574429156259, 4.58629310131073, 0.6311420362908393, 23.653379268944263, 4.577950648963451, 66.61826848983765, 94.88816633820534, 91.14177256822586, 93.70111763477325, 87.37865969538689, 85.8394230902195, 84.41478833556175, 79.61300879716873, 76.72489777207375, 72.98559442162514, 65.17344921827316, 61.23059839010239, 59.433332830667496, 60.209866762161255, 67.79422178864479, 69.15383443236351, 70.54778203368187, 72.21479058265686, 70.66121354699135, 67.18292579054832, 57.42188796401024, 56.55495308339596, 56.26184441149235, 57.542307302355766, 55.639472007751465, 54.996968284249306, 56.38155698776245, 53.98547016084194, 52.02116556465626, 51.58797360956669, 54.693577364087105, 53.96690055727959, 54.23135496675968, 56.1123376339674, 55.00943921506405, 57.02841527760029, 62.22070746123791, 62.027670219540596, 62.009773179888725, 61.18539981544018, 59.47820842266083, 66.43296003341675, 64.19813275337219, 69.30079534649849, 61.51199609041214, 60.67436523735523, 63.30249801278114, 66.31194412708282, 60.24754174053669, 66.1696569621563, 50.84426611661911, 55.329830422997475, 63.310063406825066, 67.1337640285492, 67.06646963953972, 60.897151082754135, 64.91249442100525, 67.78678178787231, 61.126863956451416, 58.28802868723869, 51.846982911229134, 60.83725109696388, 65.51405534148216, 61.506246998906136, 63.757584393024445, 62.37405203282833, 61.673574820160866, 62.28093042969704, 52.677097767591476, 62.5902034342289, 65.00954121351242, 58.90191234648228, 56.368174105882645, 61.07912331819534, 62.807016000151634, 55.40597453713417, 61.15087106823921, 57.62132786214352, 58.0218605697155, 55.70684999227524, 55.67492410540581, 67.6463109254837, 60.717568919062614, 60.89599594473839, 56.563259437680244, 60.76918534934521, 60.9494286775589, 61.92184969782829, 61.109738275408745, 54.691878855228424, 52.6332101225853, 48.54844070971012, 47.38731801509857, 51.366095915436745, 52.22659394145012, 56.02517031133175, 56.9510780274868, 54.40839126706123, 53.9699137955904, 50.95579773187637, 47.56400853395462, 46.537615209817886, 54.79453034698963, 63.399681597948074, 62.69063584506512, 62.858940213918686, 56.037652641534805, 54.08103123307228, 50.798117592930794, 52.740227580070496, 55.019675865769386, 56.507554426789284, 58.860870748758316, 60.94784416258335, 57.91923187673092, 58.48575867712498, 54.30246815085411, 54.66790214180946, 56.46480672061443, 64.23249050974846, 66.06602132320404, 66.62265345454216, 67.84995719790459, 66.56681925058365, 67.87120565772057, 76.60419344902039, 74.59936782717705, 75.47546401619911, 28.8612924143672, 0.293085576267913, 0.06688674955512397, 0.5244407337158918, 0.06042224253178574, 0.044003831935697235, 0.3922281047562137, 4.887820221483707, 77.01373547315598, 50.08439429104328, 23.140629082918167, 27.723302878439426, 39.69185695052147, 0.1750115878530778, 0.04157493844104465, 0.04902421234874055, 0.05225670705840457, 0.05078416732430924, 0.03870039639878087, 0.035288446670165285, 0.05169457472220529, 0.011199980654055253, 0.02583043504273519, 0.06770133826648816, 0.018616028610267676, 0.04669080357416533, 0.05808005043945741, 0.04235007458191831, 0.05451670629554428, 0.031408929062308744, 0.021951958296995144, 0.06352432334097102, 0.04974359464540612, 0.13328774861292914, 1.9872424216009676, 70.435900837183, 54.12144586443901, 44.520755633711815, 43.84411074221134, 49.82160039246082, 3.6657784832641482, 0.16771007183706388, 0.09612526031560265, 0.015186787768470822, 3.0551063641905785, 5.048587694764137, 35.08822537958622, 8.760877344757318, 74.46385189890862, 96.12455919384956, 95.97072064876556, 94.26562294363976, 90.3723518550396, 87.18711957335472, 86.49456113576889, 83.78188669681549, 79.6900762617588, 73.38140398263931, 67.79555171728134, 65.5078236758709, 62.457096576690674, 62.805678471922874, 71.69467449188232, 71.42764762043953, 74.09837990999222, 74.63916689157486, 73.52263480424881, 71.30942836403847, 60.148074477910995, 59.46246586740017, 59.245527908205986, 59.21275846660137, 58.58401000499725, 59.289879128336906, 59.10144343972206, 57.973029389977455, 57.43978500366211, 54.92520533502102, 56.67834386229515, 57.146577537059784, 58.52098658680916, 59.35568779706955, 57.64577195048332, 62.27153353393078, 64.95177671313286, 62.59762443602085, 63.379367887973785, 67.50459372997284, 63.618082478642464, 69.18622389435768, 68.30230012536049, 71.11867859959602, 63.35457421839237, 64.6470558643341, 64.49713110923767, 69.21032220125198, 64.74794805049896, 66.52701258659363, 51.13762177526951, 58.71626190841198, 66.45208060741425, 69.58240583539009, 68.75457465648651, 61.99095658957958, 68.48926529288292, 68.1290066242218, 61.98158249258995, 60.642990320920944, 56.36525206267834, 63.3064915984869, 68.18528920412064, 63.93388733267784, 65.01017197966576, 64.53198283910751, 63.082288429141045, 64.71500381827354, 56.62688322365284, 61.96717746555805, 68.47292616963387, 62.35607899725437, 57.57419899106026, 61.32190369069576, 65.21020084619522, 57.44249425828457, 63.16366106271744, 58.20817217230797, 61.925410106778145, 55.26355437934399, 57.61872500181198, 68.69408190250397, 63.71281899511814, 61.27192497253418, 59.45908024907112, 63.35233233869076, 62.556776627898216, 64.41871851682663, 64.50222283601761, 58.39856095612049, 55.94003587961197, 50.98080798983574, 52.47197337448597, 54.08501721918583, 53.97065855562687, 57.31850691139698, 59.58184406161308, 57.50506550073624, 57.06796735525131, 53.41705106198788, 50.31594626605511, 50.18282040953636, 57.173514291644096, 66.30337938666344, 66.28347605466843, 66.49989724159241, 60.09927749633789, 55.28922580182552, 52.71359480917454, 56.88607111573219, 55.742400884628296, 57.95605190098286, 60.371217504143715, 63.503416031599045, 60.48686809837818, 61.386682614684105, 56.81995086371899, 57.969514578580856, 58.473580330610275, 65.0439065694809, 68.03444489836693, 70.71923643350601, 69.11354139447212, 70.39120003581047, 69.21511754393578, 79.04218062758446, 76.66635051369667, 80.24349376559258, 38.41279238462448, 0.32138755603227764, 0.23548314609797671, 0.4212750226724893, 0.09521694577415474, 0.2261437667766586, 0.6002260639797896, 5.262123411521316, 84.0715603530407, 56.90161608159542, 26.16819452494383, 41.43256634473801, 53.055656254291534, 0.499015407403931, 0.08709707093657926, 0.04016810104076285, 0.056810276582837105, 0.057880230888258666, 0.01080142972568865, 0.008399716462008655, 0.03926711891836021, 0.03249665038310923, 0.028934519650647417, 0.03348788508446887, 0.08234255379647948, 0.08809003484202549, 0.15765039366669953, 0.25958612852264196, 0.1469641795847565, 0.12565777287818491, 0.20441867003683, 0.1314747115247883, 0.133727100037504, 0.18393230682704598, 2.18717023730278, 85.14553472399712, 58.165869042277336, 52.65224330127239, 67.406285405159, 60.36317713558674, 6.869549257680774, 0.3977334452793002, 0.509579909266904, 0.28841984225437045, 8.655692338943481, 9.430585708469152, 32.875436916947365, 9.675927143543959, 81.7681011557579, 99.3918214738369, 100.42214378714561, 99.72386285662651, 96.22263953089714, 90.5204527080059, 92.48703718185425, 87.37954124808311, 86.21388539671898, 78.3818444609642, 71.53902724385262, 69.62092816829681, 66.6460981965065, 68.28611299395561, 74.95049938559532, 75.63364192843437, 79.25260573625565, 79.33781996369362, 76.99799671769142, 75.07651582360268, 63.50158452987671, 62.09410585463047, 63.18234086036682, 62.28260613977909, 62.56304249167442, 63.23169261217117, 63.92883360385895, 60.95438741147518, 59.131769612431526, 58.97046446800232, 60.84116868674755, 59.577858075499535, 61.2791483849287, 64.34741914272308, 61.30445882678032, 65.27677327394485, 69.05909031629562, 65.76231122016907, 67.47200667858124, 71.71971514821053, 67.42254853248596, 71.42612770199776, 71.26335963606834, 73.32330510020256, 68.71536836028099, 62.87748321890831, 67.29079440236092, 73.71731355786324, 66.61440029740334, 71.42382502555847, 57.06107072532177, 61.25888407230377, 68.19727376103401, 74.22358319163322, 71.93974614143372, 63.785908073186874, 70.27450829744339, 72.60924741625786, 66.75150454044342, 62.73396871984005, 56.72879375517368, 67.24141225218773, 70.64793705940247, 65.77903032302856, 68.14406901597977, 65.44552221894264, 66.89871624112129, 66.87666982412338, 59.18856516480446, 67.92655348777771, 71.34421929717064, 64.07333984971046, 61.42769381403923, 64.15133446455002, 67.70868837833405, 59.15869116783142, 66.56814157962799, 62.19321593642235, 64.50946524739265, 58.94817866384983, 64.81949061155319, 71.09965682029724, 65.36853075027466, 66.76463663578033, 64.21204760670662, 66.59334942698479, 65.67197486758232, 67.66977086663246, 65.71203991770744, 60.502477660775185, 59.47635792195797, 55.54122067987919, 54.95123013854027, 57.9893609136343, 57.06666022539139, 61.84426546096802, 65.27556493878365, 60.55295795202255, 60.953771844506264, 56.98019206523895, 54.93823863565922, 53.313065841794014, 61.22707597911358, 69.09955814480782, 69.9866433441639, 70.5857115983963, 62.60268576443195, 58.99697944521904, 55.906905457377434, 60.31676262617111, 59.844546765089035, 62.28957876563072, 65.11256128549576, 67.61829122900963, 63.973063230514526, 65.00745132565498, 59.12687927484512, 60.01296512782574, 62.220893651247025, 70.10621532797813, 72.27899953722954, 74.65541481971741, 72.87937492132187, 75.64444854855537, 71.35922089219093, 85.52055180072784, 82.07301199436188, 87.14669734239578, 43.8299261033535, 0.6585627899039537, 0.8837199455592781, 1.842954782769084, 0.16822699253680184, 0.41565429302863777, 0.6279131001792848, 7.736897841095924, 91.04079678654671, 64.92146953940392, 36.039793118834496, 41.784628853201866, 63.75712841749191, 0.6162307457998395, 0.15613601164659485, 0.1298218744341284, 0.1269469576072879, 0.16869687591679394, 0.11017205266398378, 0.12951551587320864, 0.08498770912410691, 0.13068712956737727, 0.08618131265393458, 0.1259691038285382], [0.04595004742441233, 0.07158153865020722, 0.015020735008874908, 0.0500045115040848, 0.02948974259197712, 0.07490895775845274, 0.008154540555551648, 0.031652424004278146, 0.04570300872728694, 0.2860042406246066, 4.6102778892964125, 64.93908539414406, 35.6391654163599, 40.13073340058327, 38.98080490529537, 40.397832468152046, 1.4734706841409206, 0.03055903267522808, 0.18451642157742754, 0.138669996522367, 4.367290902882814, 3.301083790138364, 26.881769634783268, 17.90218837559223, 92.10183665156364, 83.11333537101746, 94.8542645573616, 86.03386625647545, 89.9363100528717, 84.43067148327827, 83.97078976035118, 77.30296835303307, 76.93414494395256, 70.48688650131226, 66.1735251545906, 62.47136481106281, 64.40984219312668, 61.85344576835632, 66.38550817966461, 67.35369622707367, 73.41468259692192, 71.02895021438599, 75.63539743423462, 72.99057215452194, 65.54142147302628, 56.56481735408306, 57.07418382167816, 56.053756177425385, 55.95042072236538, 56.26102365553379, 53.600094839930534, 53.5225486010313, 53.36481526494026, 52.159326151013374, 57.11324192583561, 55.35458989441395, 56.55726335942745, 56.661685556173325, 56.16026446223259, 57.115537002682686, 59.19232316315174, 60.9429956227541, 61.78142063319683, 69.75224912166595, 64.13246467709541, 63.186828419566154, 65.64552828669548, 66.61329075694084, 67.85105913877487, 50.69390058517456, 60.22861875593662, 67.17649653553963, 66.64499625563622, 58.91690254211426, 48.03573802113533, 58.18580277264118, 65.38046211004257, 61.32714740931988, 62.86714397370815, 68.00343096256256, 67.48171135783195, 57.268243208527565, 63.70362728834152, 65.31747668981552, 55.21435461938381, 62.59189434349537, 59.221558794379234, 57.30729751288891, 59.495417699217796, 59.7510451823473, 58.50403569638729, 56.63168616592884, 58.3160749822855, 48.11161994934082, 64.73375201225281, 64.5201426744461, 60.88960088789463, 53.708700612187386, 60.64763747155666, 54.4929139316082, 56.746914982795715, 56.22317388653755, 54.37032490968704, 57.19231188297272, 49.43727381527424, 56.82696908712387, 61.61893755197525, 57.71779328584671, 55.93099616467953, 58.96917253732681, 62.96527370810509, 58.13887149095535, 59.07161504030228, 57.414322569966316, 53.54577295482159, 50.763406455516815, 47.95095317065716, 48.26079234480858, 49.61212523281574, 52.38227158784866, 53.420330286026, 55.901752933859825, 51.607409566640854, 53.31438437104225, 49.42851148545742, 48.38312678039074, 48.71407762169838, 52.407285645604134, 60.08551463484764, 57.822036892175674, 55.478489845991135, 50.73634430766106, 50.79471677541733, 50.512505918741226, 51.35875090956688, 55.88072866201401, 54.898481369018555, 58.479770198464394, 55.45558087527752, 53.3204260468483, 53.98335747420788, 54.91140067577362, 58.33340585231781, 63.27371075749397, 65.31053066253662, 64.67152655124664, 67.11623176932335, 66.78216889500618, 69.73386570811272, 69.92712333798409, 77.3596841096878, 75.17338022589684, 55.483722165226936, 2.8055654419586062, 0.07997521403012797, 0.14464900537859648, 0.11743574883439578, 0.04452237793884706, 0.33230852626729757, 1.7258303426206112, 67.32678607106209, 60.338056683540344, 34.186659157276154, 19.943839721381664, 41.501688435673714, 1.1181527003645897, 0.1603955088648945, 0.008167683990905061, 0.03785736487770919, 0.020688487129518762, 0.04877280611253809, 0.06560777677805163, 0.01743980246828869, 0.06072915770346299, 0.029155768716009334, 0.03579260614060331, 0.06157227457151748, 0.10142984247067943, 0.054782662336947396, 0.050836952577810735, 0.0739645303110592, 0.016459252838103566, 0.03359650952916127, 0.018229775996587705, 0.129531457205303, 0.461343961651437, 8.10553316026926, 72.43696466088295, 45.53740628063679, 41.87195956707001, 38.62670190632343, 47.089736983180046, 0.80702587030828, 0.08896051469491795, 0.07930424573714845, 0.22803138970630243, 3.477696175687015, 4.865760505199432, 22.54663735628128, 24.377221427857876, 97.52950340509415, 83.97050097584724, 95.60409352183342, 88.52951154112816, 92.20130011439323, 86.30614444613457, 86.17193564772606, 80.66477715969086, 80.37604585289955, 73.94852355122566, 68.86245846748352, 66.11799493432045, 67.3362323641777, 63.87703478336334, 68.22212442755699, 71.18599578738213, 77.55050987005234, 73.34830015897751, 78.07058036327362, 76.27897650003433, 69.43904712796211, 60.412825271487236, 60.61712510883808, 58.44791270792484, 59.03746247291565, 58.14856857061386, 58.14147815108299, 57.09443673491478, 56.13138601183891, 56.16572096943855, 59.31164816021919, 59.36474651098251, 60.2163378149271, 59.10830967128277, 60.11315815150738, 60.833101719617844, 62.446799129247665, 63.47910113632679, 65.39226427674294, 70.03876134753227, 70.61367809772491, 65.16898065805435, 67.09651842713356, 66.81581988930702, 68.83926451206207, 54.674703776836395, 62.98166982829571, 66.51236817240715, 70.32668709754944, 60.81005595624447, 51.04627847671509, 59.393757954239845, 67.70109638571739, 63.83909001946449, 64.39728766679764, 71.43656194210052, 68.40436264872551, 60.01763887703419, 68.24445962905884, 67.02432230114937, 58.08701567351818, 64.7701008617878, 62.475810572505, 61.48689843714237, 63.056058436632156, 63.18710960447788, 62.45868869125843, 59.69212554395199, 61.20995789766312, 52.5983963906765, 63.67353290319443, 67.0402130484581, 65.13859748840332, 59.21305865049362, 64.01786282658577, 56.272544637322426, 60.23793965578079, 59.261228665709496, 55.37474401295185, 58.557248041033745, 51.87767766416073, 59.823647886514664, 65.03111645579338, 61.06839269399643, 59.05475914478302, 60.72745978832245, 64.75872427225113, 59.81474496424198, 61.80352404713631, 59.380766451358795, 56.72011122107506, 52.77395457029343, 51.449634432792664, 51.17990590631962, 52.833447977900505, 54.50378894805908, 56.504537388682365, 58.21682810783386, 55.050313621759415, 55.36151312291622, 51.8820284307003, 50.08525684475899, 52.03634575009346, 54.52127940952778, 61.7104784399271, 61.50004953145981, 56.74317978322506, 53.923799470067024, 52.1120984852314, 52.83592164516449, 53.81513670086861, 58.244923800230026, 57.30680353939533, 60.37790134549141, 58.803896605968475, 54.76117193698883, 55.08780241012573, 56.80252879858017, 61.159473806619644, 64.99772384762764, 68.94530162215233, 67.55989596247673, 70.04262194037437, 68.87855440378189, 71.91974401473999, 72.85948678851128, 79.98440846800804, 76.16140320897102, 65.95196664333344, 4.621937088668346, 0.12043055961839855, 0.04416857387695927, 0.095753941568546, 0.13191820413339883, 0.46850280719809234, 1.8820949387736619, 72.60258257389069, 68.2613155245781, 36.146366000175476, 25.824976041913033, 58.328572511672974, 3.2694481126964092, 0.20639159542042762, 0.014611105671065161, 0.020742597116623074, 0.02437044502585195, 0.03523000625136774, 0.06248616264201701, 0.02523659073631279, 0.06320847271126695, 0.01975724950170843, 0.02072564275295008, 0.15163243690039963, 0.1793796761194244, 0.19341451989021152, 0.07330882057431154, 0.17277558596106246, 0.15238216932630166, 0.12079131018253975, 0.10448916073073633, 0.15711529034888372, 0.41305107646621764, 7.95830768533051, 89.43801239132881, 47.557966858148575, 57.514504194259644, 53.28768700361252, 60.58966018259525, 1.961722041014582, 0.1731160091003403, 0.32354304974433035, 0.8151781547348946, 9.40775653347373, 7.051681084558368, 32.1003545075655, 29.078864939510822, 101.01653069257736, 88.44365134835243, 101.81948840618134, 93.2857771217823, 96.07360392808914, 92.96611547470093, 90.6549046933651, 86.41126960515976, 85.85813328623772, 77.91707620024681, 74.98428717255592, 69.28162157535553, 71.56260877847672, 69.39665660262108, 73.01524043083191, 73.63484278321266, 81.58163756132126, 77.5134314596653, 81.62462085485458, 78.92595246434212, 73.49151447415352, 64.94047611951828, 64.5353190600872, 63.4244030714035, 62.302460074424744, 61.24512501060963, 62.10894025862217, 58.17523933947086, 59.73204620182514, 59.485340639948845, 64.47481870651245, 63.307266756892204, 66.02569788694382, 63.554610684514046, 64.30789366364479, 63.34678463637829, 65.86844712495804, 66.60964295268059, 68.66242200136185, 71.8503825366497, 71.1196893453598, 70.36251917481422, 70.29165297746658, 70.16853958368301, 67.36946538090706, 56.27965405583382, 67.69247084856033, 71.47284239530563, 73.04734110832214, 63.26075345277786, 55.956264808773994, 60.282404869794846, 69.76408168673515, 65.23831933736801, 65.23807615041733, 73.4479384124279, 73.04436966776848, 65.11288806796074, 69.91740345954895, 70.0858636200428, 60.37470571696758, 68.04324522614479, 66.14493548870087, 64.18260678648949, 67.0470754802227, 63.90088990330696, 66.11125409603119, 60.8597306907177, 63.66804599761963, 52.67066851258278, 69.37407061457634, 69.81676205992699, 66.90660461783409, 59.99934285879135, 68.04538831114769, 57.24749632179737, 63.36984179913998, 64.76891532540321, 60.69444715976715, 62.52181090414524, 55.034286081790924, 62.183256670832634, 66.82405024766922, 64.06662181019783, 62.95838087797165, 63.72691623866558, 68.01689743995667, 64.24652695655823, 66.2144185602665, 63.28626908361912, 59.34902675449848, 55.984881073236465, 54.041631147265434, 54.018984362483025, 56.83073088526726, 58.68153557181358, 59.71665322780609, 62.91634753346443, 58.531257435679436, 57.9109825193882, 53.74968521296978, 53.81903149187565, 53.174415081739426, 57.75055132806301, 65.44201120734215, 65.0503434240818, 59.94429141283035, 55.70086911320686, 55.835165306925774, 55.36545731127262, 57.560922503471375, 61.54881991446018, 59.439591094851494, 65.47700732946396, 62.526496052742004, 58.014686554670334, 60.19610770046711, 60.40799953043461, 64.58767265081406, 69.13201600313187, 72.7363657951355, 71.45134314894676, 76.32043987512589, 75.0954920053482, 79.69605714082718, 78.42870354652405, 85.54704397916794, 82.72977635264397, 72.58721619844437, 5.387654900550842, 0.31652654812205583, 0.47617293312214315, 0.31995996076148003, 0.6276192096993327, 0.7856768346391618, 3.0717430589720607, 81.74867659807205, 73.82021963596344, 49.36106890439987, 29.323759898543358, 67.75278881192207, 3.6260627768933773, 0.4215573356486857, 0.08364916415303014, 0.10107658759807236, 0.08755058253882453, 0.2748073101975024, 0.2264370783814229, 0.15540113701717928, 0.18382475478574634, 0.08821016628644429, 0.08855491614667699], [0.06425938350730576, 0.05629604616842698, 0.05363542448321823, 0.012130975228501484, 0.06037333499989472, 0.07448762567946687, 0.1264676044229418, 0.021907570444454905, 0.04515689935942646, 0.3459650825243443, 13.882108591496944, 67.82834395766258, 24.221089705824852, 47.52502262592316, 48.36682565510273, 36.009812727570534, 0.3390747163211927, 0.1604605803731829, 0.1254803253686987, 0.11452060018200427, 1.492471327073872, 0.5591361375991255, 0.5109321023337543, 47.633256018161774, 89.07666698098183, 86.76335871219635, 90.79252570867538, 87.9135113954544, 88.44305098056793, 84.78765472769737, 84.64979812502861, 75.63944041728973, 75.20373299717903, 68.35542127490044, 64.31249141693115, 59.6917949616909, 60.46294078230858, 63.12961868941784, 66.6840049624443, 68.48699301481247, 72.04933986067772, 73.39093387126923, 74.03162509202957, 71.04495495557785, 71.42953991889954, 60.6346345692873, 56.33415453135967, 55.350007340312004, 53.094254583120346, 57.230606228113174, 54.10987928509712, 53.62782575190067, 52.689572498202324, 53.23483943939209, 54.92023900151253, 56.619393825531006, 55.57117447257042, 55.773734003305435, 54.83734264969826, 58.42210069298744, 61.74542136490345, 60.48030965030193, 60.108567997813225, 63.35154578089714, 68.17724883556366, 67.63545110821724, 65.49013182520866, 67.61345028877258, 60.884733349084854, 62.27675825357437, 62.63529561460018, 66.38852521777153, 61.065892428159714, 53.66657227277756, 48.9493153989315, 53.11841368675232, 65.81731706857681, 60.10044403374195, 67.78151527047157, 65.48437893390656, 53.20900842547417, 60.08413910865784, 70.79283848404884, 56.87123291194439, 51.359484270215034, 58.20166312158108, 60.31843073666096, 61.193603575229645, 60.56164808571339, 64.52470242977142, 59.91763584315777, 58.45984406769276, 57.53441892564297, 51.533655524253845, 48.99712063372135, 62.691088020801544, 61.367611438035965, 63.20592999458313, 56.76502101123333, 59.88420523703098, 54.46853443980217, 58.104384541511536, 55.566918700933456, 56.63944534957409, 53.55945222079754, 55.1460874825716, 61.19545787572861, 59.082881435751915, 58.166872188448906, 61.547091007232666, 59.142257049679756, 60.76407462358475, 58.10647062957287, 58.30401062965393, 53.87144587934017, 50.907528921961784, 50.41830137372017, 50.035304725170135, 48.04490692913532, 49.46557469666004, 51.01089857518673, 53.3528421074152, 52.50860720872879, 53.55232000350952, 49.66994673013687, 49.188512563705444, 49.67017471790314, 46.12866975367069, 50.45829802751541, 50.87786391377449, 51.35558567941189, 48.84341508150101, 51.4149384945631, 49.03409264981747, 50.826365277171135, 52.54395291209221, 56.36020973324776, 52.794800251722336, 54.65464845299721, 52.72493340075016, 54.18473906815052, 55.501292422413826, 62.73367613554001, 64.18243199586868, 66.95603996515274, 65.00473067164421, 66.52125209569931, 62.19932600855827, 67.61446103453636, 70.08204862475395, 78.41054052114487, 74.06314060091972, 73.79150077700615, 14.943907465785742, 0.2103622636059299, 0.019380379490030464, 0.05318878887919709, 0.07681167597183958, 0.1827858222532086, 0.4619811399606988, 60.83010748028755, 65.4709580540657, 47.158270105719566, 35.76295517385006, 47.40938723087311, 8.389442525804043, 0.3681413159938529, 0.1198288485466037, 0.18369473051279783, 0.054143472807481885, 0.08028989206650294, 0.04714608148788102, 0.11576962730032392, 0.049297241057502106, 0.06034530408214778, 0.010811820720846299, 0.08181568089639768, 0.02420676435576752, 0.014496249041258125, 0.014682245164294727, 0.1143623742973432, 0.0424296402343316, 0.02630695322295651, 0.024274884235637728, 0.06938442529644817, 0.35620538459625095, 19.098556078970432, 78.46333488821983, 33.455547988414764, 37.51788720488548, 51.095824018120766, 42.18359224498272, 0.061972804251126945, 0.07027648680377752, 0.21667684195563197, 0.03690144898428116, 0.6158624030649662, 0.4627526766853407, 0.7956703577656299, 54.30819824337959, 92.23367437720299, 90.36054208874702, 93.27961385250092, 91.42835319042206, 91.4352460205555, 87.0217752456665, 86.70988038182259, 79.98845145106316, 77.62623980641365, 74.42554995417595, 67.04583674669266, 62.770040184259415, 63.11804451048374, 67.0430400967598, 69.60815325379372, 69.39594984054565, 74.87944319844246, 75.85453167557716, 76.13291233778, 76.05785116553307, 74.73277106881142, 63.56626085937023, 57.51771502196789, 57.38639406859875, 58.61590549349785, 58.27387824654579, 56.78359441459179, 56.83273337781429, 54.56220701336861, 55.29505468904972, 54.11479242146015, 59.65078376233578, 59.117892757058144, 59.32240158319473, 57.45601773262024, 59.34744983911514, 62.87202671170235, 63.35507959127426, 63.70620355010033, 62.45575524866581, 70.46575203537941, 69.71387878060341, 66.85542896389961, 69.219601303339, 66.36652439832687, 65.34380927681923, 62.81760983169079, 69.04507666826248, 61.67982928454876, 58.441190868616104, 51.126153990626335, 59.77690279483795, 68.78822565078735, 62.43373163044453, 68.78562659025192, 66.60411804914474, 56.42775870859623, 63.58413890004158, 71.82701379060745, 56.79917737841606, 55.30864655971527, 61.21078625321388, 64.33858841657639, 63.676891922950745, 60.98275288939476, 67.33115583658218, 61.87088683247566, 62.073830142617226, 62.26636201143265, 57.103712037205696, 51.96708686649799, 64.1973727941513, 64.9935744702816, 65.69446966052055, 60.158159136772156, 62.82411888241768, 58.37722510099411, 62.63393148779869, 57.899548932909966, 58.64185810089111, 57.302741557359695, 57.94200785458088, 62.97184355556965, 62.16596379876137, 62.01850511133671, 62.7418152987957, 60.335210636258125, 60.99537581205368, 61.32161870598793, 61.60032615065575, 56.923556104302406, 55.003184750676155, 54.61233772337437, 52.08382800221443, 49.76365730166435, 50.37702798843384, 54.00621324777603, 55.90975910425186, 54.35229867696762, 56.01866886019707, 53.50797638297081, 49.440906420350075, 52.750927805900574, 49.50131177902222, 52.098802998661995, 52.77926288545132, 52.679069861769676, 51.66424311697483, 53.35462801158428, 51.63407273590565, 53.600463420152664, 56.0168981552124, 59.55121770501137, 54.13629926741123, 55.603465139865875, 53.54788564145565, 56.82469680905342, 57.77976036071777, 64.1280797123909, 67.32509896159172, 69.46389019489288, 69.12066981196404, 69.12915855646133, 67.36627355217934, 70.88056057691574, 73.66337165236473, 81.4051066339016, 73.75247687101364, 80.80363690853119, 21.383016295731068, 0.15791884332429618, 0.043978079411317594, 0.19207500270567834, 0.11215461854590103, 0.5411895224824548, 0.46226992446463555, 66.22305929660797, 73.23045328259468, 50.820251405239105, 36.71055592596531, 61.696384996175766, 14.297200217843056, 0.5882783175911754, 0.16092412581201643, 0.16300761635648087, 0.04928001952066552, 0.028941711061634123, 0.028011473477818072, 0.005072287149232579, 0.04936015291605145, 0.004650502824006253, 0.04242677183356136, 0.23595901118824258, 0.11827309179352596, 0.15377837175037712, 0.09242869695299305, 0.18204383784905076, 0.14567186299245805, 0.1717790449038148, 0.1005309606262017, 0.388833224424161, 0.33670031873043627, 21.615649312734604, 92.13646039366722, 33.76302748918533, 66.66174575686455, 66.1134883761406, 49.844824746251106, 1.1675647739320993, 0.38500638445839286, 0.6825953128281981, 0.24204420653404668, 3.9658151334151626, 3.638309994712472, 1.7434761207550764, 59.80631321668625, 97.25108474493027, 95.64763158559799, 96.8076865375042, 94.34348076581955, 96.72923594713211, 92.81657829880714, 92.77842834591866, 84.61022704839706, 82.01647862792015, 76.96692958474159, 69.67670917510986, 66.26360312104225, 68.4928523004055, 71.59418508410454, 74.41883191466331, 73.82322147488594, 79.70759332180023, 80.81084132194519, 79.92030590772629, 78.01245868206024, 77.69807115197182, 66.87329560518265, 62.154670804739, 61.49132899940014, 60.95858618617058, 63.64911921322346, 60.957545042037964, 59.19121362268925, 56.77509427070618, 58.997241631150246, 59.68892231583595, 63.25489416718483, 62.86464370787144, 62.163501530885696, 62.24677786231041, 62.2363094240427, 68.00246581435204, 67.24644318223, 66.9363722205162, 67.68241658806801, 70.85570991039276, 74.14952516555786, 73.09204190969467, 73.11088129878044, 69.19931799173355, 67.18107908964157, 66.1814971268177, 70.74445188045502, 67.36128821969032, 58.87621812522411, 54.10837076604366, 61.017160043120384, 70.4982478916645, 62.857496291399, 70.62776014208794, 71.30469381809235, 59.6883637458086, 65.86399376392365, 76.30052894353867, 62.48032093048096, 55.223994702100754, 64.9254897236824, 67.76156634092331, 65.22230699658394, 64.99678909778595, 71.18360951542854, 65.79753533005714, 66.44533216953278, 63.28686185181141, 59.19882081449032, 56.23063288629055, 68.64053517580032, 65.83751678466797, 70.66334903240204, 63.515833765268326, 65.68131476640701, 58.886656165122986, 64.18657377362251, 60.85314944386482, 63.60179275274277, 61.65095083415508, 61.88508287072182, 64.90239456295967, 65.24306148290634, 65.12155160307884, 66.87107652425766, 62.56591893732548, 65.35203203558922, 64.43577960133553, 64.77007806301117, 61.468644216656685, 56.6630344837904, 57.8384368121624, 56.05506330728531, 51.99614770710468, 54.285543859004974, 56.99387513101101, 58.86868312954903, 59.38404567539692, 58.8118039816618, 55.95173545181751, 54.63720738887787, 55.09608596563339, 50.94813734292984, 55.6783477216959, 54.71729949116707, 55.834713131189346, 54.34943363070488, 57.68380030989647, 53.42892162501812, 57.06214226782322, 59.75118577480316, 63.08171086013317, 56.02849133312702, 61.57788835465908, 57.195834293961525, 61.509625017642975, 62.407497838139534, 69.3529437482357, 69.87520292401314, 74.97743993997574, 72.13844507932663, 74.08210158348083, 70.77773809432983, 76.84969067573547, 79.90166410803795, 86.79516300559044, 77.5793731212616, 87.68118426203728, 23.59578385949135, 0.3312758426181972, 0.20445053785806522, 0.2863747801166028, 0.18933288578409702, 1.335720238275826, 1.3168442761525512, 74.23397943377495, 79.19163420796394, 65.14191091060638, 50.90716414153576, 66.6815122961998, 15.710955206304789, 0.9098457999061793, 0.5012582370545715, 0.36025056440848857, 0.20344377000583336, 0.18286826001713052, 0.14135306817479432, 0.20961818634532392, 0.17144351993920282, 0.16753514762967825, 0.19467657170025632], [0.044757293653674424, 0.01911217474116711, 0.053246687530190684, 0.021855139566469006, 0.078909467702033, 0.03358276866492815, 0.0858234787301626, 0.0989185186335817, 0.06271175327128731, 0.2755242842249572, 23.039087131619453, 57.04421862959862, 45.345809161663055, 44.47450451552868, 42.33316741883755, 33.127940967679024, 0.04648712114430964, 0.4943762125913054, 0.12103901681257412, 0.09492266195593402, 0.31618714914657176, 0.22177809791173786, 5.867588147521019, 64.99789863824844, 90.96955060958862, 84.89308387041092, 87.55405068397522, 88.05607974529266, 85.30432060360909, 84.16972428560257, 79.6788364648819, 77.7367302775383, 72.64200925827026, 67.85026878118515, 64.13432657718658, 60.69049917161465, 59.29009951651096, 62.901798114180565, 65.47224998474121, 67.09429934620857, 70.00490516424179, 73.71572524309158, 71.68734088540077, 73.2681092619896, 72.81461119651794, 66.89334332942963, 56.0076342523098, 55.533921271562576, 54.69267301261425, 57.01609253883362, 53.83253216743469, 54.37870346009731, 50.00690884888172, 53.663688227534294, 54.48812998831272, 55.21599993109703, 54.58144538104534, 53.9584194123745, 54.04816299676895, 57.33793146908283, 56.28549434244633, 58.13077412545681, 57.20804683864117, 60.05878686904907, 61.890003606677055, 65.72242856025696, 65.54764553904533, 67.05459147691727, 68.59050706028938, 62.857378497719765, 62.795080840587616, 67.02119126915932, 59.150772392749786, 62.059698700904846, 47.29381263256073, 60.795244351029396, 63.07419866323471, 64.35907691717148, 66.02357760071754, 58.02929677069187, 62.01977804303169, 68.800438195467, 59.10467706620693, 54.020766466856, 61.68188877403736, 63.07082064449787, 64.58215534687042, 62.63881042599678, 59.37598630785942, 62.27064438164234, 60.412103310227394, 61.162536442279816, 60.3734327852726, 59.80879828333855, 55.158490017056465, 51.213587298989296, 59.313073083758354, 59.65372480452061, 59.01532106101513, 58.86528231203556, 61.865658313035965, 56.197863444685936, 56.10210858285427, 54.09437231719494, 53.347951769828796, 52.9560711979866, 59.10128764808178, 58.42693783342838, 56.25362165272236, 60.001147761940956, 61.11497439444065, 58.91249097883701, 57.70686887204647, 58.176424875855446, 55.477889478206635, 54.85441133379936, 51.77533395588398, 51.650278866291046, 48.16478289663792, 47.46522903442383, 47.87460766732693, 50.43918885290623, 51.395551934838295, 51.0516057908535, 51.11886218190193, 47.50741817057133, 48.91688033938408, 47.88683161139488, 49.754363000392914, 48.023658469319344, 50.583516508340836, 51.6236536949873, 51.45542532205582, 49.5696397125721, 52.86036193370819, 54.17367026209831, 57.11957238614559, 52.88279213011265, 55.36684803664684, 53.94882872700691, 55.158224031329155, 58.18087063729763, 61.45246088504791, 64.62019130587578, 66.71048954129219, 65.88555380702019, 64.84761670231819, 63.21613244712353, 68.2861889898777, 66.87669262290001, 76.38773426413536, 73.13573196530342, 74.97246220707893, 36.8009302765131, 0.09028319997014478, 0.080990397837013, 0.10493592621060088, 0.18395914288703352, 0.21240998263237998, 0.020435424048628192, 48.65900717675686, 74.02220159769058, 46.13378047943115, 38.09696473181248, 45.776060074567795, 18.461145982146263, 0.36760352610144764, 0.12672042445046827, 0.039789512957213446, 0.13060715573374182, 0.02613052616652567, 0.05294317510561086, 0.07717616696027108, 0.04116058997169603, 0.05287088621116709, 0.10900610155658796, 0.0327758500498021, 0.0021845065839443123, 0.030565404013032094, 0.019207924779038876, 0.030272587791841943, 0.014360896147991298, 0.05731558638217393, 0.13984021497890353, 0.059086250548716635, 0.2665598230669275, 33.64352770149708, 63.7138145416975, 52.10730694234371, 35.68301126360893, 52.42215804755688, 35.63935920596123, 0.109045442804927, 0.3988148138159886, 0.11653048451989889, 0.02817752530972939, 0.21931051625870168, 0.14191517082508653, 8.046889957040548, 72.54410371184349, 93.65487411618233, 87.0735664665699, 90.95586374402046, 90.78563287854195, 88.64461496472359, 86.28631711006165, 83.18417876958847, 80.03265827894211, 75.25518223643303, 70.62643021345139, 67.43204042315483, 64.66606244444847, 62.20985524356365, 65.78957855701447, 66.75429359078407, 69.9072428047657, 71.20294287800789, 74.1505891084671, 73.21118831634521, 77.3999847471714, 73.14588502049446, 68.2268513739109, 59.46535371243954, 57.73593731224537, 56.91342204809189, 58.39309684932232, 56.66053421795368, 56.85864418745041, 52.93185509741306, 56.51629775762558, 57.26678028702736, 57.89189234375954, 57.741568610072136, 57.210163325071335, 57.271355241537094, 61.70923590660095, 58.79734955728054, 61.92177750170231, 63.35384465754032, 63.041075840592384, 63.520515114068985, 66.78343042731285, 66.71695679426193, 68.91597479581833, 70.23803785443306, 65.0797538459301, 68.89086574316025, 68.42357441782951, 62.447699680924416, 64.91520747542381, 50.87457709014416, 65.75392886996269, 64.17444482445717, 66.9263331592083, 66.32657334208488, 60.37677280604839, 67.84245640039444, 71.98298782110214, 58.92983324825764, 58.16468730568886, 65.5567954480648, 64.5896865427494, 67.3405109345913, 64.99970734119415, 62.68501974642277, 67.64624252915382, 65.70159047842026, 64.45974111557007, 62.54224240779877, 62.75997072458267, 59.82849262654781, 52.90343262255192, 62.17189148068428, 62.18456380069256, 63.74735914170742, 61.07804037630558, 61.949831396341324, 59.96930167078972, 57.51524895429611, 56.231579035520554, 56.877779960632324, 55.15416584908962, 61.751626431941986, 60.89236333966255, 58.74738223850727, 62.271582931280136, 64.60192948579788, 60.02564124763012, 59.97539274394512, 59.92351412773132, 58.11692386865616, 56.55468709766865, 52.759108766913414, 53.31497713923454, 50.767016261816025, 49.69009704887867, 50.794868767261505, 53.63726444542408, 54.13595348596573, 54.17638711631298, 52.34844960272312, 50.053741335868835, 50.811694264411926, 50.69809935986996, 52.034480050206184, 51.33357346057892, 52.45237022638321, 53.378760516643524, 53.49658839404583, 52.917571663856506, 55.458852499723434, 56.995680034160614, 58.84421244263649, 55.61493672430515, 59.270876348018646, 55.3354275226593, 57.23753705620766, 59.058235958218575, 63.89100283384323, 66.12401381134987, 69.10024210810661, 68.41525286436081, 67.9153060913086, 66.01617559790611, 70.15843972563744, 68.69114086031914, 79.60773468017578, 73.84503230452538, 81.11857160925865, 45.22622957825661, 0.21381776256021112, 0.06820028414949775, 0.25843250448815525, 0.31872517545707524, 0.4949483787640929, 0.17659224366070703, 53.426242768764496, 80.21251782774925, 51.163996160030365, 36.31202571094036, 55.08516915142536, 24.299314208328724, 0.2553602505940944, 0.10422305625979789, 0.07198849532869644, 0.04798372130608186, 0.04352818948973436, 0.04531505474005826, 0.009234407170879422, 0.02088160879793577, 0.01608185404620599, 0.03334937435283791, 0.2220919224782847, 0.0897927739424631, 0.18044979369733483, 0.11129139689728618, 0.2967309165978804, 0.09822206498938613, 0.25226249650586396, 0.4722971410956234, 0.35387557523790747, 0.47435689775738865, 42.852512151002884, 75.54387554526329, 58.48430335521698, 61.43005728721619, 64.42436501383781, 41.48584708571434, 0.33635278581641614, 1.621521427296102, 0.5902255943510681, 0.21850518212886527, 1.4371044980362058, 1.266592328902334, 10.020831786096096, 82.66109123826027, 95.99126234650612, 93.4545336663723, 96.25220194458961, 96.94020822644234, 93.30422893166542, 91.10514253377914, 87.36491203308105, 85.91271355748177, 80.09219348430634, 75.29899388551712, 69.95259717106819, 68.50753471255302, 67.86410003900528, 70.5851112306118, 71.36271670460701, 73.45431447029114, 76.76100343465805, 79.43091496825218, 77.58044466376305, 80.68423971533775, 76.36128768324852, 72.84522235393524, 61.00264482200146, 61.58152095973492, 58.990569189190865, 62.65646427869797, 59.47473160922527, 61.39069899916649, 54.47647601366043, 61.034019738435745, 61.81590378284454, 63.71959403157234, 59.53278109431267, 60.918760523200035, 60.19491836428642, 67.10901975631714, 61.120096519589424, 64.95094075798988, 67.38588809967041, 66.3364528119564, 67.26141437888145, 72.61200606822968, 71.97246238589287, 72.4067410826683, 70.99056467413902, 71.08120501041412, 69.693633466959, 70.37796154618263, 64.05728191137314, 67.11874723434448, 55.61981946229935, 66.05539709329605, 67.05374792218208, 70.3121566772461, 71.0138726234436, 62.066112756729126, 66.92805826663971, 74.4833904504776, 64.43308934569359, 59.8089312762022, 68.53330492973328, 67.80085623264313, 68.55387702584267, 69.06374126672745, 66.82650491595268, 70.91159731149673, 66.82775884866714, 68.22575703263283, 65.3268013894558, 66.47381544113159, 60.07703348994255, 56.15242928266525, 66.276765614748, 65.26602745056152, 64.61208254098892, 66.21113553643227, 64.68391388654709, 61.42834357917309, 62.13003292679787, 60.217815935611725, 60.73056422173977, 58.09433788061142, 64.45749923586845, 64.42705526947975, 62.195366621017456, 65.76247081160545, 66.79194957017899, 63.921507596969604, 62.923502549529076, 65.42975306510925, 62.75670289993286, 60.15737257897854, 58.503241539001465, 57.137325033545494, 53.861501812934875, 52.85015568137169, 55.074685513973236, 56.63064882159233, 58.964715376496315, 58.9651295542717, 56.94231949746609, 52.60118164122105, 54.47466351091862, 52.02954411506653, 55.239045694470406, 54.80226673185825, 55.57256519794464, 56.58554144203663, 57.814524695277214, 54.162198677659035, 59.43077936768532, 60.034228786826134, 62.446438148617744, 58.09016190469265, 62.41690993309021, 60.73355846107006, 60.34001737833023, 65.06729051470757, 67.75818452239037, 69.01194244623184, 73.1855396926403, 73.53708162903786, 73.00664529204369, 71.25670239329338, 74.7513672709465, 73.51938977837563, 83.58580201864243, 76.50926694273949, 85.86156830191612, 49.60273213684559, 0.5131706572137773, 0.22536776232300326, 0.6268214900046587, 0.5909452401101589, 1.0810595657676458, 0.35177725658286363, 62.64433152973652, 85.06329193711281, 61.97008430957794, 53.043420910835266, 66.9176772236824, 27.155565842986107, 0.5201783124357462, 0.29488626401871443, 0.2433748179464601, 0.2480811919667758, 0.15590515919029713, 0.15278836159268394, 0.24656321795191616, 0.13594609190477058, 0.11188517441041768, 0.17202986113261431], [0.08367363276192918, 0.04339925988460891, 0.022953744482947513, 0.04312955970817711, 0.04637310870748479, 0.08571856131311506, 0.038678258133586496, 0.06285889889113605, 0.038858195548527874, 0.023165219463407993, 34.55991692841053, 42.93481953442097, 27.023097351193428, 40.05240060389042, 49.66793283820152, 27.999301068484783, 0.543137036729604, 0.4526485735550523, 0.0796628143871203, 0.03349379629071336, 0.0692232753499411, 0.08989587309770286, 9.60809888318181, 71.01803719997406, 84.73334044218063, 88.24286252260208, 87.06564009189606, 89.30353000760078, 87.2453248500824, 83.32146540284157, 79.71289783716202, 75.81328868865967, 71.28653079271317, 67.42966175079346, 61.00959084928036, 61.07725761830807, 59.32012550532818, 62.91679970920086, 63.73193196952343, 64.80910196900368, 64.43701073527336, 66.93269401788712, 69.71308842301369, 69.92297396063805, 71.09180644154549, 67.68389090895653, 58.41917484998703, 56.04367531836033, 53.20901982486248, 55.13695277273655, 53.23440246284008, 52.511620447039604, 52.28590115904808, 52.21644848585129, 53.09120334684849, 54.89923372864723, 53.71893726289272, 53.00426781177521, 55.41491165757179, 56.2919881939888, 56.78065337240696, 57.91734337806702, 58.77198971807957, 59.91805002093315, 63.745466843247414, 63.933195769786835, 66.88160955905914, 67.98497915267944, 64.14033025503159, 61.11066162586212, 64.83336746692657, 62.40801081061363, 65.68326786160469, 58.703730180859566, 48.5212379693985, 66.44575014710426, 61.154758259654045, 65.17672464251518, 57.104886174201965, 61.86874754726887, 66.97372421622276, 64.41471353173256, 53.817560970783234, 58.89183908700943, 60.82068778574467, 62.38432668149471, 64.69386175274849, 61.985066905617714, 59.00297172367573, 59.922871962189674, 62.664763033390045, 60.5645777285099, 63.19080300629139, 54.070384204387665, 58.634570091962814, 57.51803420484066, 54.54737640917301, 57.559516578912735, 60.01803405582905, 58.8277593255043, 61.162844225764275, 57.702122926712036, 49.96387615799904, 54.18584480881691, 53.658296316862106, 55.41047349572182, 60.05646139383316, 57.857538387179375, 58.88033330440521, 60.25897152721882, 60.26586435735226, 60.2750750631094, 58.11629690229893, 57.420307248830795, 52.783910036087036, 55.43467819690704, 52.35649757087231, 54.455356746912, 49.7981708496809, 48.74274328351021, 46.50481536984444, 49.67883065342903, 49.5045530050993, 51.50744453072548, 47.101808935403824, 46.09085038304329, 47.93051786720753, 48.955113887786865, 50.434401109814644, 49.34468038380146, 51.170315220952034, 51.7951612919569, 50.630105808377266, 51.80930033326149, 54.859833642840385, 56.89101845026016, 54.30575877428055, 52.28341609239578, 52.339466884732246, 52.1209292113781, 54.350467175245285, 56.74653880298138, 63.41549634933472, 64.67863216996193, 66.4026452600956, 65.15544578433037, 64.61291089653969, 64.46172460913658, 63.82475718855858, 67.87926122546196, 76.66435182094574, 76.92928120493889, 74.39993172883987, 58.520340621471405, 2.2214945079758763, 0.15252417186275125, 0.1955414260737598, 0.29608607932459563, 0.23247680976055562, 0.06209767430846114, 39.88254971802235, 80.53080394864082, 53.10216195881367, 36.797856241464615, 31.281034871935844, 24.065664745867252, 0.2161893548327498, 0.14497685653623194, 0.03889960738888476, 0.1022542869031895, 0.01877144732134184, 0.05469773095683195, 0.026788256400323007, 0.07001004836638458, 0.07717380693065934, 0.021183345634199213, 0.045019516692264006, 0.033508167980471626, 0.05310761647706386, 0.027508905914146453, 0.01673803690209752, 0.06954016498639248, 0.050090890072169714, 0.09236438243533485, 0.024503881322743837, 0.2858156163711101, 50.13593852519989, 51.86205670237541, 32.71506652235985, 36.173420548439026, 61.622053384780884, 31.805748715996742, 0.49459464149549603, 0.25580533139873296, 0.1301951301866211, 0.09957106682122685, 0.04228598641930148, 0.0760928911040537, 12.311228234320879, 77.14273855090141, 87.76221111416817, 93.22728306055069, 89.2514880001545, 91.21167361736298, 87.67270311713219, 85.84550276398659, 81.63162007927895, 78.42560291290283, 73.94688203930855, 69.4555002450943, 64.99085381627083, 63.77831608057022, 61.458027586340904, 66.46312281489372, 67.69324600696564, 67.3646092414856, 69.3159793317318, 68.92882570624352, 71.44889608025551, 72.74137392640114, 73.63169655203819, 69.65005740523338, 62.309964671730995, 55.48230484127998, 56.749153062701225, 56.942376494407654, 55.549534633755684, 54.325076937675476, 55.289176404476166, 54.288564696908, 57.841510847210884, 57.28195667266846, 57.66311801970005, 56.43331401050091, 59.425554648041725, 58.8764651119709, 59.941635355353355, 60.002348497509956, 59.375287145376205, 62.93353781104088, 69.01236042380333, 67.84861207008362, 70.3816169500351, 69.23049911856651, 66.28649309277534, 64.10043239593506, 67.42719948291779, 66.64865165948868, 68.09926941990852, 60.07611393928528, 54.51283246278763, 68.68799462914467, 63.29836763441563, 65.96365481615067, 60.867284685373306, 64.09350156784058, 69.75528135895729, 65.71564212441444, 56.461462900042534, 61.37116804718971, 64.15842488408089, 61.314874067902565, 65.81125259399414, 64.55493360757828, 60.756516829133034, 60.68389132618904, 62.50678651034832, 63.75279664993286, 65.63295096158981, 57.0282518863678, 60.136222913861275, 62.510966286063194, 57.73117996752262, 60.82770220935345, 63.12914751470089, 59.5213209092617, 60.64769446849823, 58.61537732183933, 52.284343242645264, 57.71506503224373, 57.46514484286308, 57.25545309484005, 61.993308663368225, 61.81980237364769, 61.45380601286888, 62.30407878756523, 61.25034213066101, 63.16472880542278, 61.82368956506252, 61.09308376908302, 56.125754714012146, 55.70263981819153, 55.34539818763733, 56.98664031922817, 51.82441212236881, 51.80277608335018, 48.237138614058495, 53.299492970108986, 53.32228794693947, 54.41836193203926, 49.25672270357609, 47.85764157772064, 49.69024904072285, 51.61437839269638, 52.95723773539066, 51.00638061761856, 52.51697055995464, 54.68901000916958, 52.084884345531464, 53.60436201095581, 58.14230650663376, 58.77084977924824, 57.39400885999203, 55.59603653848171, 54.88005995750427, 54.20480199158192, 57.43779391050339, 59.66640092432499, 66.36557444930077, 66.2802766263485, 67.87636578083038, 66.82289510965347, 67.91915148496628, 66.2199054658413, 67.30642676353455, 71.65121242403984, 78.90591993927956, 80.06561771035194, 77.15269401669502, 66.57245054841042, 3.988032778725028, 0.21326429850887507, 0.4115565988468006, 0.41807117115240544, 1.2193428142927587, 0.08943946711951867, 42.565399557352066, 84.24132004380226, 60.743776112794876, 36.13671071827412, 42.92797990143299, 35.25443606078625, 0.14286666351836175, 0.09409847727511078, 0.09090673018363304, 0.04420569610374514, 0.02944160132756224, 0.08736023650271818, 0.07647827354958281, 0.0222374254008173, 0.07402824368909933, 0.0207224069890799, 0.17722979304380715, 0.10964564731693827, 0.1314383462886326, 0.1879428728716448, 0.14381309476448223, 0.2204357457230799, 0.1085512615100015, 0.20662249240558594, 0.1415121104218997, 0.3586177504621446, 63.37222047150135, 58.58153633773327, 39.56855736672878, 55.89792273938656, 73.87633502483368, 37.46905982494354, 0.8390602294821292, 1.0311586246825755, 0.25804364879149944, 0.2291150440578349, 0.2499030902981758, 0.3716118063312024, 15.17229326069355, 82.68901214003563, 93.25073540210724, 97.87989780306816, 95.0028745830059, 98.14674988389015, 94.29703205823898, 90.52497446537018, 86.99515387415886, 83.07586938142776, 80.08986800909042, 73.77265378832817, 68.69896844029427, 66.63327008485794, 65.2666050195694, 70.8418482542038, 72.5389663875103, 73.7899200618267, 71.39493897557259, 74.02042329311371, 76.06230452656746, 76.95859283208847, 78.9708660542965, 72.59449660778046, 64.2944423854351, 62.56531096994877, 60.51174536347389, 61.127395927906036, 60.05082629621029, 58.64387959241867, 59.2116679251194, 58.46729926764965, 59.86059710383415, 61.293325424194336, 60.52095986902714, 59.847446009516716, 61.093247160315514, 62.63427346944809, 63.36192302405834, 63.48221316933632, 62.14536130428314, 66.30283981561661, 72.25300893187523, 67.8989365696907, 75.97816944122314, 72.77456134557724, 69.90002319216728, 65.99729061126709, 69.94527116417885, 69.62750941514969, 69.42944124341011, 65.61542630195618, 56.936125829815865, 71.10079675912857, 63.58268357813358, 68.4270778298378, 62.67019294202328, 65.75148940086365, 73.3856825530529, 69.97259929776192, 59.45293217897415, 62.92886786162853, 65.52867695689201, 66.97096556425095, 70.94847053289413, 68.82896706461906, 64.24711972475052, 63.42835485935211, 67.24243819713593, 67.74167060852051, 69.02387380599976, 59.87692482769489, 64.7231961786747, 63.611318841576576, 59.658884927630424, 62.703642547130585, 65.93189612030983, 64.77805003523827, 64.69954624772072, 62.490986958146095, 58.9508955180645, 64.0107724070549, 58.65072302520275, 61.023961678147316, 65.67002937197685, 63.537314012646675, 63.81908029317856, 66.28333166241646, 64.07998189330101, 66.98025226593018, 65.52862375974655, 63.75635325908661, 58.95686499774456, 58.90775263309479, 57.79394879937172, 60.09467974305153, 53.837920278310776, 55.01077674329281, 52.61541947722435, 56.12369902431965, 56.12786740064621, 58.619899079203606, 51.43070384860039, 49.583554565906525, 52.10365913808346, 55.020489022135735, 55.169851407408714, 53.21419134736061, 56.42137125134468, 59.36184726655483, 55.93441978096962, 57.170345261693, 62.1692506223917, 63.05477790534496, 60.7455126196146, 58.274661004543304, 58.527712225914, 57.03874692320824, 60.79049080610275, 62.21234031021595, 69.82412606477737, 68.24865460395813, 75.09039267897606, 71.65530860424042, 72.59462580084801, 71.12426429986954, 72.08897173404694, 78.1283600628376, 85.9312641620636, 83.5649411380291, 82.02662408351898, 71.406269967556, 4.954670034348965, 0.3048230870626867, 0.8133290789555758, 0.7852076191920787, 2.4623737949877977, 0.26323699043132365, 52.30662904679775, 90.59721618890762, 70.6639190018177, 49.71630424261093, 51.1106014251709, 43.48702110350132, 0.39290212327614427, 0.2632273128256202, 0.24551680457079783, 0.19528035336406901, 0.10517086790059693, 0.19035154284210876, 0.19146224105497822, 0.21387950924690813, 0.2291791804600507, 0.1272317790426314], [0.08285554111353122, 0.03229959162126761, 0.04956169424986001, 0.05824195366585627, 0.046448763241642155, 0.01933454259415157, 0.06129081506514922, 0.08515996159985662, 0.046000060756341554, 0.9978395188227296, 42.06299051642418, 34.41064953804016, 41.659592762589455, 45.80656863749027, 58.16434532403946, 26.79451871663332, 0.3002220980124548, 0.47540086205117404, 0.07244967331644148, 0.08554510655812919, 0.1681098371045664, 0.31498525582719594, 19.549962356686592, 72.06889361143112, 89.20920386910439, 86.34507715702057, 88.80334004759789, 83.71122568845749, 86.79424345493317, 81.45017221570015, 75.94809785485268, 78.09084087610245, 70.29356047511101, 66.11067652702332, 62.44339071214199, 59.82736028730869, 59.447737857699394, 60.58265335857868, 58.339610919356346, 62.87560231983662, 59.788841754198074, 60.72952687740326, 62.11346961557865, 69.01498228311539, 68.71765583753586, 66.85441821813583, 59.143233597278595, 55.652421712875366, 53.49224142730236, 53.120142593979836, 51.49586655199528, 51.52335807681084, 51.31621599197388, 52.47566297650337, 51.19303800165653, 53.1912861764431, 55.558110773563385, 54.23010863363743, 54.18812468647957, 54.27257515490055, 55.78033424913883, 59.11829553544521, 60.8490152657032, 63.01807947456837, 62.5372950732708, 66.55668139457703, 66.39686957001686, 60.77299654483795, 68.42489674687386, 64.47858810424805, 66.32014408707619, 62.55648024380207, 62.52355881035328, 53.31011340022087, 51.98963865637779, 64.35793697834015, 63.7987057864666, 60.937094539403915, 59.29712913930416, 63.935202062129974, 61.749962121248245, 56.542208567261696, 57.151053696870804, 65.67276522517204, 57.67459340393543, 56.4385387301445, 56.56215749680996, 56.23815268278122, 51.97454586625099, 55.20733259618282, 55.47028988599777, 57.715954184532166, 59.710953533649445, 61.78598038852215, 53.75074915587902, 60.90525224804878, 60.11940121650696, 54.013695046305656, 58.60450990498066, 56.4851014316082, 60.911480113863945, 54.16027218103409, 45.09009808301926, 49.35265615582466, 57.01014205813408, 52.470632046461105, 59.22453783452511, 58.82629260420799, 55.18946975469589, 58.95668260753155, 58.964388594031334, 58.72876703739166, 57.46851906180382, 58.783324509859085, 55.19687935709953, 54.6055056899786, 54.22206826508045, 54.57953028380871, 54.11772586405277, 50.44830456376076, 47.73269668221474, 47.255237102508545, 48.46514917910099, 48.759325593709946, 48.62138159573078, 48.23023438453674, 47.45544835925102, 48.31507243216038, 49.70803588628769, 49.05682682991028, 49.200690910220146, 49.98852163553238, 49.017780125141144, 54.2289724946022, 56.03663049638271, 56.74797132611275, 53.92998553812504, 52.42455571889877, 53.98731306195259, 52.742902636528015, 53.64197239279747, 59.82528939843178, 63.763466477394104, 64.35224488377571, 63.52396532893181, 64.28691878914833, 61.71273171901703, 64.97149005532265, 64.68269795179367, 68.43438103795052, 70.0149442255497, 77.65486747026443, 71.7239861190319, 76.12372443079948, 11.25633928924799, 0.5386336252558976, 0.4573992983205244, 0.6006933795288205, 0.19538168620783836, 0.06322747911326587, 32.69488960504532, 80.99611178040504, 55.62255531549454, 40.61137720942497, 35.77748939394951, 30.328158102929592, 0.09078766001039185, 0.031071730554685928, 0.07522307176259346, 0.11769397169700824, 0.05547884509724099, 0.04596965867676772, 0.029333036254683975, 0.0028271338806007407, 0.007496515781895141, 0.041705983167048544, 0.030950220570957754, 0.04323957567976322, 0.012616737785720034, 0.03944248841435183, 0.07815032484359108, 0.03847290587145835, 0.04769721890625078, 0.058308264560764655, 0.044454141170717776, 2.54945894703269, 55.92058092355728, 46.98872700333595, 46.72355443239212, 47.08477824926376, 69.85871940851212, 30.216109715402126, 0.48264351091347635, 0.18049684586003423, 0.12570981227327138, 0.09236576283001341, 0.3592373844003305, 0.4870028863660991, 23.763427063822746, 79.87179011106491, 91.37264057993889, 89.65432718396187, 90.05834430456161, 89.12994012236595, 89.84154313802719, 85.65785363316536, 77.18025013804436, 82.62790381908417, 73.33454489707947, 69.7362519800663, 65.63938021659851, 63.67664493620396, 62.60781168937683, 61.78517483174801, 60.33974379301071, 63.95873039960861, 61.3807625323534, 63.648971021175385, 64.10936191678047, 70.23392647504807, 68.71497318148613, 69.54603418707848, 62.112375274300575, 57.69747957587242, 56.491716876626015, 54.84838865697384, 54.95016239583492, 53.799846321344376, 54.512547478079796, 54.649286940693855, 55.148781538009644, 57.946206629276276, 57.86318488419056, 56.078067272901535, 57.632799446582794, 57.57772900164127, 59.10253398120403, 60.51841780543327, 64.36474621295929, 65.93949571251869, 65.48983544111252, 67.15224623680115, 68.8519786298275, 66.85433462262154, 70.58923780918121, 66.92411407828331, 67.55496382713318, 65.04495531320572, 65.46239331364632, 57.53913827240467, 58.127563297748566, 66.66733145713806, 67.15643361210823, 63.638947159051895, 62.96904690563679, 66.32160320878029, 61.679456904530525, 59.525223299860954, 60.033544823527336, 65.16640439629555, 59.57923740148544, 60.56863971054554, 60.190168619155884, 58.180635049939156, 55.7252562046051, 57.83511959016323, 58.854601085186005, 61.675125136971474, 60.408520102500916, 64.17245373129845, 58.242332339286804, 61.57944247126579, 63.38727906346321, 58.53047087788582, 62.15635411441326, 59.33860391378403, 63.571382984519005, 57.108693569898605, 49.485265240073204, 53.03048260509968, 59.419277384877205, 56.30531407892704, 62.45459631085396, 62.47500121593475, 59.801210090518, 61.735503897070885, 61.703707203269005, 59.69469800591469, 60.19649147987366, 58.429905474185944, 57.795206531882286, 57.75470830500126, 56.95795185863972, 59.13801647722721, 56.23155243694782, 52.776105254888535, 49.464419558644295, 51.095292046666145, 52.670862302184105, 50.9288115799427, 51.48229368031025, 49.8723466694355, 53.28272067010403, 52.338839918375015, 52.93920770287514, 52.31380686163902, 50.64581036567688, 52.27591909468174, 51.706838831305504, 57.95393921434879, 58.311526626348495, 58.3937656134367, 57.13529214262962, 53.71305137872696, 56.87009297311306, 54.54790078103542, 54.6450387686491, 62.28408806025982, 67.32882276177406, 65.8166255056858, 65.19289657473564, 68.32750037312508, 64.89351063966751, 66.75308525562286, 66.94654807448387, 72.23526388406754, 73.1622089445591, 80.11097207665443, 73.60693708062172, 80.82504495978355, 15.76675046235323, 0.33182434912305325, 0.6807287223637104, 1.0427304287441075, 0.7139725447632372, 0.295353876426816, 38.45599986612797, 83.969437032938, 65.4657219350338, 41.93304888904095, 49.03370887041092, 40.75716018676758, 0.05401919646828901, 0.07949105915031396, 0.07383292526355945, 0.06339327490422875, 0.06161993158457335, 0.06440974262659438, 0.04174589957983699, 0.024371676990995184, 0.011372372282494325, 0.013455172629619483, 0.12534464593045413, 0.1382753372308798, 0.19563745998311788, 0.18938559311209247, 0.1842413074336946, 0.19136556889861822, 0.17220631416421384, 0.16488869354361668, 0.17055356613127515, 3.265396817587316, 78.33990231156349, 52.99362078309059, 58.65115240216255, 60.497940704226494, 79.39866229891777, 35.322650000452995, 0.5678452702704817, 0.7473644404672086, 0.2466581089538522, 0.5786797951441258, 0.7766868139151484, 0.9195310645736754, 27.71328281611204, 87.24907144904137, 97.08102107048035, 95.88076427578926, 96.10453426837921, 94.19706702232361, 94.73911553621292, 92.51577123999596, 82.62478038668633, 87.28565588593483, 76.86342313885689, 76.98557898402214, 72.50254154205322, 67.84166604280472, 67.01068863272667, 66.81297764182091, 63.891504406929016, 69.65942770242691, 66.24234706163406, 68.5575932264328, 68.15926820039749, 74.7912423312664, 73.30995261669159, 73.71186465024948, 65.45068234205246, 61.744927391409874, 60.004670172929764, 58.21819603443146, 58.18956457078457, 57.44656763970852, 57.29145236313343, 59.892070814967155, 57.91313700377941, 61.32475733757019, 62.2212128341198, 59.48431469500065, 61.127772107720375, 60.07154278457165, 61.26334883272648, 64.42216113209724, 66.954884827137, 69.56507116556168, 68.76574605703354, 71.51936709880829, 71.06494948267937, 69.21542152762413, 70.9884063899517, 72.35746532678604, 71.83827638626099, 67.06316381692886, 67.39345729351044, 61.91906824707985, 61.57014437019825, 70.05210623145103, 68.74709665775299, 67.41721361875534, 64.9599614739418, 69.82588157057762, 63.511665388941765, 62.421492487192154, 62.12582655251026, 69.38832744956017, 63.938409090042114, 61.992845088243484, 58.6302725225687, 60.14268636703491, 57.800986021757126, 58.949512392282486, 58.991872519254684, 64.02018070220947, 64.23958092927933, 65.19557163119316, 59.71647463738918, 66.25812381505966, 66.68213546276093, 63.48554939031601, 64.146858304739, 61.64563111960888, 64.69075351953506, 60.32551735639572, 51.69550783932209, 55.91945618391037, 62.87499815225601, 60.53169049322605, 65.63523843884468, 64.19749438762665, 61.37529842555523, 65.71868196129799, 64.90601196885109, 64.35552030801773, 64.51977789402008, 63.564661145210266, 60.45213036239147, 60.16222111880779, 59.21318784356117, 62.41186000406742, 59.51267257332802, 56.57369367778301, 53.77040170133114, 53.88161413371563, 56.33272960782051, 54.026435762643814, 56.594653353095055, 51.62409067153931, 55.153911262750626, 53.82238291203976, 56.147842928767204, 53.924821615219116, 54.27596837282181, 55.65688267350197, 55.6316140294075, 60.96845045685768, 61.1566049605608, 62.266008630394936, 59.94830399751663, 57.47683301568031, 60.69505512714386, 56.31518214941025, 59.56497676670551, 66.48521482944489, 70.3220209479332, 70.75131431221962, 69.14896309375763, 72.90218889713287, 68.49614292383194, 73.49457710981369, 73.53544011712074, 76.56136214733124, 78.73001977801323, 83.20043429732323, 78.78548920154572, 86.15536853671074, 17.558422721922398, 0.639216365525499, 1.4016237831674516, 1.8851834605447948, 2.462593945674598, 0.48888874298427254, 45.058909356594086, 90.87169826030731, 74.653689712286, 53.84443312883377, 56.73323951661587, 47.589197382330894, 0.20755457051564008, 0.17511364800157025, 0.25402002094779164, 0.3687467600684613, 0.12960417283466086, 0.1553890251670964, 0.11976811118074693, 0.10748019398306496, 0.11666722522932105, 0.09404939162777737], [0.04166903905570507, 0.019831570025417022, 0.09881458827294409, 0.01636794640944572, 0.055353730131173506, 0.04768090650031809, 0.04770873703819234, 0.04304931499063969, 0.29963072505779564, 3.6147795198485255, 40.43577343225479, 24.452083110809326, 30.877335034310818, 38.6790668964386, 61.53486326336861, 33.59560467302799, 0.678985744016245, 0.6629336241167039, 0.19050093716941774, 0.13582449842942879, 0.059800385861308314, 0.33912129350937903, 24.545535296201706, 77.96367689967155, 79.13102746009827, 85.81605434417725, 85.75408726930618, 88.87117400765419, 90.61009749770164, 81.80422961711884, 78.15658494830132, 78.46214935183525, 70.2356667816639, 69.12282049655914, 66.25847339630127, 62.42328219115734, 59.21731062233448, 57.508622109889984, 56.534730568528175, 58.80836136639118, 59.72774863243103, 56.217295601964, 59.26210641860962, 62.61306680738926, 64.32404279708862, 65.1476638019085, 59.76212538778782, 53.951591178774834, 52.77848392724991, 53.286843448877335, 49.7131884098053, 49.774585515260696, 49.861125871539116, 52.40503616631031, 49.97139975428581, 54.42715846002102, 55.076023042201996, 56.83276757597923, 55.91431885957718, 57.5217542052269, 58.314509466290474, 61.323955580592155, 61.04776360094547, 60.84280639886856, 64.04220432043076, 64.53023493289948, 67.12572365999222, 65.96336603164673, 62.86285400390625, 64.19395297765732, 65.73195844888687, 63.069289326667786, 62.880481258034706, 52.99091912806034, 53.52507546544075, 60.08386932313442, 62.24230170249939, 60.09466074407101, 61.39838218688965, 63.985161781311035, 57.013637870550156, 57.00443476438522, 62.99630284309387, 56.71098791062832, 62.487540543079376, 59.53359805047512, 59.316975474357605, 63.41790921986103, 59.56354424357414, 61.54123932123184, 63.155822083353996, 58.23248326778412, 55.838562324643135, 61.385405883193016, 56.93873628973961, 56.652999222278595, 56.315968707203865, 58.92772056162357, 54.80531416833401, 58.822306618094444, 58.2299830019474, 58.88466127216816, 52.46784679591656, 50.01027926802635, 55.56510239839554, 55.72543479502201, 53.94267685711384, 62.58716739714146, 60.67549377679825, 58.667388930916786, 61.0481283813715, 58.78161460161209, 59.8525795340538, 57.60576389729977, 54.8682501912117, 54.23053041100502, 55.51050312817097, 55.38878805935383, 51.3634018599987, 49.57231856882572, 47.02940382063389, 46.694592386484146, 48.851303458213806, 48.148899748921394, 45.88880382478237, 48.32239843904972, 48.24767544865608, 48.10120850801468, 48.673769384622574, 47.55508281290531, 48.567223101854324, 48.52207012474537, 49.06650871038437, 56.25687047839165, 55.62314808368683, 56.33454591035843, 53.40082213282585, 52.62870356440544, 52.12745726108551, 52.262752801179886, 54.530056938529015, 61.92558489739895, 61.25266380608082, 63.714992478489876, 64.51221629977226, 61.9428663700819, 61.30817122757435, 61.24902360141277, 62.145201712846756, 68.10351759195328, 69.56289768218994, 76.50123417377472, 75.1574894785881, 76.87871351838112, 36.21921569108963, 0.16304095363011584, 0.18721556814853102, 1.1227031936869025, 0.3443954698741436, 0.16157794307218865, 27.854435741901398, 79.66065064072609, 60.02514347434044, 41.52391344308853, 29.308391623198986, 34.794922918081284, 0.7803433458320796, 0.1557591193704866, 0.11744711111532524, 0.062242233543656766, 0.01208517636769102, 0.0637766090221703, 0.05491515054018237, 0.020667458375100978, 0.06514963417430408, 0.01384222305205185, 0.05304205515130889, 0.01656938940868713, 0.09464351052884012, 0.025714218427310698, 0.06267647899221629, 0.041753413825063035, 0.05647529709676746, 0.0325795631215442, 0.3623873559990898, 10.571741424500942, 57.44180269539356, 37.36396886408329, 38.15350189805031, 43.70148539543152, 72.98952341079712, 37.74544179439545, 0.74131237459369, 0.5348952196072787, 0.12713780830381438, 0.18956836924189702, 0.04560927547572646, 0.7232012401800603, 28.00717804580927, 82.83272802829742, 82.78186395764351, 92.14171171188354, 87.27389931678772, 91.20155856013298, 93.56485694646835, 86.32737010717392, 80.13470560312271, 83.71302679181099, 72.68512174487114, 72.83229544758797, 68.94393369555473, 65.71069478988647, 62.407026663422585, 61.151790618896484, 60.202578753232956, 61.44595563411713, 61.82072192430496, 58.69288556277752, 61.05229675769806, 65.93535393476486, 67.89214253425598, 68.00998941063881, 61.2770015001297, 57.871137857437134, 54.51641567051411, 53.90890046954155, 54.144286438822746, 51.34136684238911, 52.80397675931454, 54.78991739451885, 54.136873036623, 57.47186668217182, 59.27989326417446, 59.865590035915375, 58.1826451420784, 60.007189437747, 58.599988147616386, 63.05125169456005, 62.98823207616806, 62.46925972402096, 67.55957677960396, 67.67129078507423, 68.0604887008667, 67.26430982351303, 63.92300471663475, 66.03480219841003, 65.5910012125969, 65.68183153867722, 66.76384627819061, 56.64329834282398, 57.954737171530724, 62.143168821930885, 64.1592076420784, 65.82010611891747, 64.70310285687447, 66.44952714443207, 58.18352669477463, 59.88509438931942, 66.41931116580963, 59.68185469508171, 64.7645303606987, 61.574780121445656, 62.86002315580845, 64.69289660453796, 65.05722865462303, 62.69807204604149, 63.79417642951012, 59.619028866291046, 57.129402458667755, 62.243027463555336, 61.55699707567692, 60.58237977325916, 59.5051945745945, 62.21143215894699, 58.7400296330452, 61.67109735310078, 59.54611457884312, 61.84924699366093, 55.017582178115845, 54.92404259741306, 57.87235379219055, 57.45570234954357, 56.2888153642416, 61.86096176505089, 61.858643889427185, 60.73384344577789, 61.71241633594036, 61.9948323816061, 62.00070686638355, 59.592753276228905, 57.17903159558773, 56.76211416721344, 58.75793047249317, 58.51972125470638, 55.338243171572685, 53.07026647031307, 49.41483601927757, 48.57883147895336, 50.516750290989876, 48.832832649350166, 48.17516013979912, 49.55263562500477, 52.51440949738026, 49.841822907328606, 50.77602177858353, 48.08125577867031, 52.460779175162315, 50.38941152393818, 52.87874914705753, 59.60074044764042, 56.99590042233467, 56.87708839774132, 55.137256756424904, 54.55937996506691, 54.619135558605194, 53.962139412760735, 56.70781888067722, 63.61137583851814, 64.61527436971664, 67.24898904561996, 67.445218116045, 66.07600718736649, 64.91856649518013, 66.24757558107376, 65.38721814751625, 69.79714751243591, 74.06231224536896, 77.62790411710739, 78.75600278377533, 78.2594758272171, 44.66347597539425, 0.1314560094033368, 0.31842659460380673, 1.283176657743752, 0.8905379078350961, 0.37773235759232193, 32.23963603377342, 82.61572167277336, 70.15365958213806, 42.08717621862888, 38.22482407093048, 53.68274800479412, 1.8370718671940267, 0.2199913328513503, 0.025643194894655608, 0.05794036711449735, 0.054975557650323026, 0.04461537646420766, 0.01622736508579692, 0.09635508118662983, 0.021655967539118137, 0.01898887803690741, 0.15009129303507507, 0.10225217178231105, 0.1574503254960291, 0.13615669857244939, 0.1756448921514675, 0.1908677807659842, 0.20659199013607576, 0.18806345702614635, 0.47729550569783896, 12.829294335097075, 79.55545708537102, 39.027052223682404, 46.88615530729294, 56.50615990161896, 84.73498195409775, 42.108865454792976, 1.0460603563115, 2.1689789509400725, 0.32659437507390976, 0.4467668751021847, 0.2226762005011551, 1.1156987445428967, 32.56207533180714, 92.5918659567833, 90.99367931485176, 97.3462088406086, 94.03514251112938, 96.45617499947548, 98.15569460391998, 94.26581293344498, 86.23073369264603, 87.92853578925133, 76.32870063185692, 79.29556623101234, 73.5633610188961, 71.54126912355423, 65.60353294014931, 65.16176104545593, 63.87272581458092, 64.15095448493958, 66.94832637906075, 63.052190244197845, 64.79273244738579, 68.74103218317032, 70.80659374594688, 71.93460121750832, 65.27494937181473, 58.709441274404526, 57.51373663544655, 57.18425251543522, 58.552471697330475, 55.3068682551384, 55.14578349888325, 58.92798654735088, 58.70832413434982, 59.51884724199772, 62.56870038807392, 64.0949758887291, 61.81514762341976, 63.19839119911194, 61.51089794933796, 66.69826939702034, 67.58308991789818, 65.63915982842445, 70.08352294564247, 68.66711854934692, 74.11647453904152, 67.93198719620705, 65.85279956459999, 68.53882983326912, 71.53854086995125, 68.0694106221199, 68.09926941990852, 61.48261606693268, 61.35826013982296, 66.18233308196068, 66.62287384271622, 68.24335768818855, 65.86167588829994, 68.81961956620216, 61.57688520848751, 62.85605236887932, 68.95510509610176, 62.44458384811878, 67.85280704498291, 63.00015963613987, 65.5369833111763, 67.93440386652946, 66.14517867565155, 64.86393302679062, 69.71881091594696, 63.26742209494114, 58.854205906391144, 67.0540215075016, 65.8436344563961, 61.955439895391464, 59.89118166267872, 64.97060850262642, 62.467310428619385, 65.22840946912766, 64.22925308346748, 63.12086395919323, 55.69735050201416, 60.468982458114624, 61.98293522000313, 61.47803731262684, 61.49428904056549, 64.48588371276855, 63.016122579574585, 63.200146704912186, 66.57027706503868, 64.14134100079536, 63.496872782707214, 64.03987124562263, 60.74212320148945, 59.3208322674036, 60.99529221653938, 61.66415132582188, 57.126761600375175, 57.83443182706833, 53.65535527467728, 52.70307317376137, 54.147972241044044, 53.180433958768845, 51.66070930659771, 52.39544168114662, 52.834014147520065, 53.40178348124027, 52.680954560637474, 51.78583279252052, 54.83136557042599, 54.289951622486115, 55.44820547103882, 62.29571543633938, 60.13947173953056, 61.35566487908363, 58.58258508145809, 58.25497426092625, 57.56698317825794, 57.97821991145611, 62.192577570676804, 67.84690976142883, 66.037857234478, 70.29189616441727, 72.91339069604874, 69.52335700392723, 70.53298562765121, 70.5104224383831, 71.46619275212288, 76.32008269429207, 79.19333651661873, 82.13342115283012, 84.73499715328217, 81.90797924995422, 45.98130606114864, 0.20146637689322233, 0.9677972027566284, 2.4235170800238848, 1.7783101578243077, 0.4194141022162512, 38.69175061583519, 91.26447558403015, 76.2363275885582, 56.35242395102978, 43.75804916024208, 60.55162042379379, 0.8712020516395569, 0.37379021756350994, 0.168811374460347, 0.15000832092482597, 0.09513498298474588, 0.12468214554246515, 0.08728127941139974, 0.22983031114563346, 0.1998494894360192, 0.1487634572549723], [0.021807642115163617, 0.11343383623170666, 0.02240110236016335, 0.04833210397919174, 0.04180860734777525, 0.08796113863354549, 0.06140010373201221, 0.05249827241641469, 0.3624249086715281, 13.00429679453373, 39.14791613817215, 17.49773807823658, 31.810889840126038, 38.58067877590656, 62.21817299723625, 39.71103452146053, 0.47046739084180444, 0.546170580200851, 0.3054728818824515, 0.1481388063984923, 0.10602479786030017, 0.9660711453761905, 32.74082534015179, 66.81187570095062, 76.56918972730637, 78.21692571043968, 84.2013081908226, 90.38829579949379, 83.45841005444527, 84.13120955228806, 78.26600387692451, 78.92304942011833, 76.24112293124199, 74.79933589696884, 68.10112372040749, 69.14438053965569, 64.14570316672325, 61.87303751707077, 57.715661600232124, 59.28192615509033, 57.48283289372921, 58.028742000460625, 56.803364753723145, 62.62161634862423, 61.334621608257294, 61.436710730195045, 55.88935039937496, 54.6055892854929, 51.21240556240082, 51.4735921472311, 50.677637457847595, 49.14557866752148, 50.090477764606476, 50.789723843336105, 51.26912511885166, 52.69811064004898, 56.93518728017807, 55.01666262745857, 54.86466698348522, 57.51840278506279, 58.405708372592926, 61.635774448513985, 60.674247443675995, 65.51287740468979, 61.997613832354546, 68.12430247664452, 67.504563331604, 62.86455251276493, 65.38996160030365, 61.521708369255066, 61.45520433783531, 64.50563505291939, 59.76307533681393, 54.26057539880276, 51.963838040828705, 52.880835235118866, 63.559292033314705, 61.64386421442032, 60.823678225278854, 62.01056733727455, 53.896315544843674, 62.241526544094086, 56.258318200707436, 60.55011950433254, 63.09703543782234, 60.76393783092499, 58.001911640167236, 59.68718960881233, 57.44791276752949, 58.214711621403694, 58.115206360816956, 59.52691800892353, 57.92491637170315, 58.61817017197609, 58.06466907262802, 57.90593259036541, 61.60782314836979, 58.33559833467007, 57.64834441244602, 58.295259699225426, 56.44733905792236, 57.44839534163475, 50.93790829181671, 52.17456713318825, 50.751254707574844, 55.68564333021641, 56.539206728339195, 54.5172668248415, 61.72358773648739, 58.30443240702152, 58.01158972084522, 60.45072443783283, 56.04641877114773, 55.51411293447018, 55.50208657979965, 56.805466040968895, 56.074586659669876, 55.7526945322752, 54.32088576257229, 47.6125281304121, 46.24599605798721, 47.74336650967598, 45.70635661482811, 47.25973226130009, 47.135794311761856, 47.77383707463741, 47.25430615246296, 50.24490147829056, 48.39950770139694, 48.18061284720898, 48.17760720849037, 48.654527217149734, 54.02140863239765, 56.26855865120888, 57.84319415688515, 55.55415138602257, 54.8503265529871, 52.288940995931625, 54.08259674906731, 51.48915231227875, 56.72588311135769, 60.04974715411663, 62.23543167114258, 62.56774663925171, 61.4312694221735, 60.10599933564663, 62.44651414453983, 60.93391411006451, 66.67145043611526, 63.441015779972076, 69.28196355700493, 74.20539736747742, 76.22824162244797, 72.6149471104145, 72.13986620306969, 2.199596045538783, 0.07081656993250363, 0.9336733119562268, 0.21308591589331627, 0.07748852949589491, 23.317192308604717, 79.3532395362854, 61.402922943234444, 48.37710030376911, 25.531730577349663, 38.96905213594437, 5.329995369538665, 0.2522686414886266, 0.029797932402289007, 0.05620538169750944, 0.07099920505424961, 0.026284547784598544, 0.044312324171187356, 0.08051175711443648, 0.03363004347193055, 0.014769482768315356, 0.009812046682782238, 0.055598460749024525, 0.04070841423526872, 0.04275721679732669, 0.08681129213073291, 0.02720755870541325, 0.07082560186972842, 0.06315438498859294, 0.46580239897593856, 20.504066459834576, 55.949352979660034, 24.36449211090803, 27.907247208058834, 44.0311025083065, 73.21881830692291, 44.12802770733833, 0.35242571553681046, 1.640985645353794, 0.37766283319797367, 0.21576974453637376, 0.13564394874265417, 1.3722729706205428, 34.70169872045517, 76.97709783911705, 85.4303066432476, 86.07966139912605, 86.87278524041176, 94.07497957348824, 87.78101250529289, 85.7113927602768, 79.59967911243439, 81.48671865463257, 80.34807935357094, 77.39639014005661, 72.86587804555893, 71.67028740048409, 67.996606528759, 64.40642237663269, 60.83468243479729, 63.034395799040794, 59.61661599576473, 61.71715088188648, 58.426459059119225, 66.04752391576767, 62.38064467906952, 63.43372017145157, 58.80944050848484, 55.64708299934864, 56.00804843008518, 55.40553756058216, 52.13264778256416, 51.620659455657005, 53.71755413711071, 53.96268658339977, 53.39896023273468, 57.52084605395794, 58.22617180645466, 59.66909117996693, 58.2394140958786, 61.178134605288506, 62.67401933670044, 62.06789866089821, 64.22413855791092, 66.39822229743004, 61.81952878832817, 69.02135074138641, 70.73651790618896, 66.02467194199562, 68.78016248345375, 63.45871143043041, 65.50449505448341, 65.97915798425674, 61.34515844285488, 56.70080445706844, 54.91917885839939, 56.33693978190422, 65.26255443692207, 64.67752262949944, 63.98801922798157, 63.22187773883343, 56.478930562734604, 63.66411320865154, 58.21628473699093, 63.83554860949516, 63.473815619945526, 61.55866518616676, 60.75835593044758, 64.09339517354965, 61.5156476944685, 62.458624094724655, 59.79029327630997, 62.7911252528429, 59.5141164958477, 60.1915517449379, 60.429734364151955, 58.22932183742523, 63.707890659570694, 61.55640050768852, 60.4152837395668, 59.345169961452484, 56.76197737455368, 58.317948281764984, 52.109598219394684, 52.779517471790314, 54.57585968077183, 58.41929644346237, 59.63107421994209, 57.381674721837044, 62.25386068224907, 60.62937945127487, 60.98188653588295, 60.03898613154888, 59.98376749455929, 55.867349579930305, 55.99698722362518, 61.78444527089596, 58.69581900537014, 57.55559518933296, 57.27395810186863, 50.86889639496803, 49.21674504876137, 49.73096765577793, 48.45537610352039, 48.769778832793236, 49.24536511301994, 51.30718007683754, 52.209244072437286, 52.078033313155174, 49.91324007511139, 49.023791402578354, 50.62151446938515, 51.323097422719, 55.148876532912254, 57.68092006444931, 59.94498297572136, 57.0219936221838, 57.45940715074539, 53.82832199335098, 55.327748134732246, 52.93011859059334, 58.96269768476486, 61.57117411494255, 66.67812287807465, 65.12987315654755, 65.07309660315514, 63.861394822597504, 68.20273026823997, 65.84282889962196, 72.83588245511055, 66.4649923145771, 75.08321106433868, 74.4802214205265, 81.72684296965599, 74.02407869696617, 78.2982337474823, 3.498694561421871, 0.021264540300762746, 1.7375597194768488, 0.4186471668072045, 0.3534985345322639, 28.996793143451214, 84.61743906140327, 69.44751307368279, 52.43252769112587, 26.408529728651047, 51.8689077347517, 8.77899382263422, 0.6979521294124424, 0.2131515069049783, 0.09144685041974299, 0.13837852544384077, 0.14047240605577826, 0.03766328212805092, 0.029098836712364573, 0.11612100453930907, 0.03747989372641314, 0.11316644042381085, 0.2059555985033512, 0.17609519767574966, 0.15973958390532061, 0.1896307393326424, 0.17590608360478655, 0.2027912886114791, 0.21561899950029328, 0.5987595801707357, 25.327806919813156, 73.87959524989128, 28.757443986833096, 46.39917343854904, 57.06664502620697, 82.36515551805496, 50.77316053211689, 1.0346293821930885, 4.131387211382389, 1.0339538496918976, 0.7551578222773969, 0.5360494670458138, 2.098617651499808, 38.03753972053528, 87.33795627951622, 93.15485134720802, 95.56945458054543, 93.2386976480484, 97.79513195157051, 91.94788411259651, 90.77772930264473, 84.05376970767975, 86.07765510678291, 83.51175919175148, 84.35114935040474, 75.19875526428223, 76.56515434384346, 72.75835141539574, 68.26081395149231, 62.395870462059975, 66.63197815418243, 63.58599320054054, 64.67568352818489, 62.61625483632088, 70.74999198317528, 66.97884634137154, 65.9403544664383, 62.70071290433407, 59.69871059060097, 57.644377425312996, 59.34571713209152, 56.46092712879181, 53.970122784376144, 57.68522523343563, 57.55562178790569, 55.98312936723232, 59.03308890759945, 64.90549519658089, 63.21805514395237, 60.24126447737217, 65.02469480037689, 64.5503282546997, 67.37407073378563, 67.49108165502548, 69.27890092134476, 64.93818864226341, 73.33306297659874, 70.47398999333382, 68.51561307907104, 71.47242441773415, 67.33646035194397, 66.81077376008034, 70.28322502970695, 65.95072790980339, 62.73584581911564, 57.62281358242035, 57.971999645233154, 69.51369792222977, 66.81625306606293, 66.48146823048592, 66.45100146532059, 60.28936989605427, 66.43305122852325, 62.804280146956444, 64.63308021426201, 67.04269051551819, 64.05703112483025, 61.938865184783936, 68.10378357768059, 61.78260236978531, 65.40336728096008, 62.58579947054386, 64.92157593369484, 61.88488908112049, 63.43341238796711, 59.99680079519749, 62.59800061583519, 66.38376027345657, 66.47203713655472, 64.33074563741684, 61.75025850534439, 58.44049170613289, 57.849494218826294, 54.766149669885635, 61.22665800154209, 57.530094757676125, 60.824400186538696, 61.031986847519875, 61.15868724882603, 64.27671253681183, 62.742575258016586, 61.15297995507717, 66.14217683672905, 60.956944674253464, 59.766897931694984, 56.933921948075294, 64.31144267320633, 60.31059555709362, 61.60885289311409, 59.16917860507965, 55.26033215224743, 52.83612683415413, 52.86455310881138, 50.694462954998016, 51.5509369969368, 52.09514379501343, 53.92531558871269, 55.082668885588646, 55.00099606812, 53.51109981536865, 53.28370861709118, 54.49604116380215, 54.549017921090126, 59.027203023433685, 62.4586620926857, 62.09416285157204, 60.399738773703575, 59.71725359559059, 56.36114448308945, 60.70838861167431, 56.20286777615547, 62.63629116117954, 64.07330185174942, 71.0054598748684, 67.35354423522949, 70.37589445710182, 66.81420117616653, 73.65856871008873, 70.05409732460976, 80.19674867391586, 70.07419064640999, 81.49570897221565, 79.0302112698555, 86.79675132036209, 77.09821254014969, 82.00261697173119, 3.5160254314541817, 0.10415771015686914, 3.7534243427217007, 1.0618507652543485, 0.4163031082134694, 32.78746783733368, 95.30810460448265, 76.23417690396309, 71.31349414587021, 33.520942479372025, 68.60086530447006, 10.157595947384834, 0.9694836591370404, 0.31337185646407306, 0.22240193240577355, 0.3594860335579142, 0.3045606042724103, 0.18079098867019638, 0.2634374296758324, 0.22505632747197524, 0.12487779051298276], [0.0550837219634559, 0.11572241928661242, 0.05008735373849049, 0.11604834086028859, 0.04958744677423965, 0.057946170709328726, 0.07648030703421682, 0.06634744568145834, 0.46527636470273137, 17.7231552824378, 30.374998189508915, 31.573096700012684, 59.31271210312843, 43.30310717225075, 66.66238412261009, 48.20585869252682, 0.3242502867942676, 0.3513872134499252, 0.06666800152743235, 0.10646000810083933, 0.05479507475683931, 1.0860555851832032, 34.04388561844826, 62.86604203283787, 70.5252568423748, 72.87024021148682, 80.69203689694405, 80.37030056118965, 81.8391877412796, 83.87283101677895, 80.25933891534805, 80.19997850060463, 73.57251092791557, 76.41731947660446, 73.49545106291771, 74.77068543434143, 70.09048417210579, 68.35486650466919, 59.482304602861404, 57.42445282638073, 58.055967539548874, 56.04820467531681, 55.535729974508286, 57.34665960073471, 57.27779969573021, 58.14156174659729, 56.90098151564598, 54.33863081037998, 53.23299653828144, 51.564141288399696, 47.527405098080635, 50.179822370409966, 52.97136537730694, 49.05626446008682, 51.76518850028515, 54.9813549220562, 55.21675609052181, 56.30330018699169, 59.51040029525757, 59.60894800722599, 61.44997961819172, 62.80128210783005, 62.94219754636288, 66.27051115036011, 77.3554815351963, 65.01616805791855, 66.9157925248146, 65.33720523118973, 62.6592381298542, 60.62328077852726, 61.39035701751709, 63.320094868540764, 62.251447811722755, 54.45213072001934, 54.073796421289444, 61.910385712981224, 60.33639997243881, 62.46111296117306, 58.36828798055649, 55.992837846279144, 61.807346642017365, 60.74227139353752, 60.128247141838074, 62.805404886603355, 61.65856182575226, 62.26453050971031, 55.930335000157356, 56.98257073760033, 56.7931205034256, 57.39300191402435, 57.92117357254028, 58.40318910777569, 58.63521605730057, 58.46645951271057, 56.39569602906704, 53.92949536442757, 55.85321053862572, 59.62344042956829, 54.878304451704025, 59.257763251662254, 54.05167020857334, 51.913262754678726, 47.96796105802059, 49.26637418568134, 55.375192388892174, 60.295559763908386, 57.38608628511429, 57.06492751836777, 54.795218110084534, 61.09275698661804, 64.57016319036484, 51.61950811743736, 54.550363048911095, 59.151072576642036, 59.87356960773468, 58.43680590391159, 57.61577256023884, 55.175665095448494, 51.542246863245964, 48.74998949468136, 47.01407544314861, 44.56882685422897, 46.16310350596905, 47.29833818972111, 45.88169440627098, 46.45508363842964, 46.84526190161705, 46.2832872569561, 47.675524950027466, 47.1293992549181, 49.2396654188633, 52.308414950966835, 53.545096591115, 55.043933764100075, 57.515723928809166, 56.236503571271896, 53.32221195101738, 51.23462677001953, 54.25313159823418, 53.20553541183472, 58.86186629533768, 60.10163336992264, 62.28900879621506, 61.850850507617, 63.508663550019264, 63.31127554178238, 62.87656366825104, 62.564038038253784, 66.79769486188889, 64.17777344584465, 71.44774854183197, 68.93237471580505, 78.51431295275688, 72.39397376775742, 89.92612659931183, 15.365443546324968, 0.13488531054463238, 0.3896091546630487, 0.25776097958441824, 0.2139504734077491, 24.036689400672913, 75.81316709518433, 58.39440777897835, 45.484410524368286, 36.54328890144825, 23.81387885659933, 7.80109254643321, 0.4329558927565813, 0.050945502807735465, 0.10089155533933081, 0.026640194228093605, 0.01373730006889673, 0.14200247707776725, 0.05596470691671129, 0.05005440238164738, 0.059720011267927475, 0.11381294010789134, 0.014843754124740371, 0.08841342569212429, 0.11748869364964776, 0.045494739824789576, 0.06138294527772814, 0.11317516808048822, 0.048344085953431204, 1.3005246268585324, 33.84625822305679, 44.25382375717163, 35.605484023690224, 53.54746386408806, 52.30793997645378, 75.00486686825752, 55.24183474481106, 0.28593124297913164, 0.9740346274338663, 0.2850272477371618, 0.27184646751265973, 0.08924334717448801, 1.655094288289547, 35.998185351490974, 70.32705947756767, 79.30493652820587, 81.11602574586868, 85.49699306488037, 85.02746745944023, 82.44927540421486, 88.6315056681633, 81.94300577044487, 84.09775614738464, 77.45868399739265, 79.47383746504784, 74.40202921628952, 79.76578339934349, 71.94108366966248, 72.36375018954277, 61.04759640991688, 59.37140375375748, 60.92531517148018, 59.625990092754364, 56.98758266866207, 59.723610654473305, 59.8118457198143, 59.04555983841419, 59.181702733039856, 55.90780980885029, 53.8045846670866, 52.91626073420048, 49.769189804792404, 52.15162396430969, 53.092187494039536, 51.69523425400257, 54.16214168071747, 58.376594334840775, 58.94853204488754, 58.999118730425835, 62.407851219177246, 60.815789848566055, 62.85816505551338, 63.29682111740112, 64.32614788413048, 68.7952932715416, 77.75032594799995, 68.16180646419525, 68.71957093477249, 66.67727172374725, 67.19031259417534, 62.98288196325302, 63.1720320135355, 64.82645943760872, 65.2748429775238, 58.23258966207504, 56.553030386567116, 67.17797845602036, 63.43025855720043, 63.451552614569664, 61.32250405848026, 58.14076378941536, 64.9841357767582, 63.17745812237263, 62.612789422273636, 64.28695678710938, 63.2724492251873, 64.17726427316666, 57.949653044342995, 58.905571550130844, 59.4080413877964, 58.348563238978386, 59.315672144293785, 60.46500027179718, 60.638103783130646, 59.593695625662804, 59.64349955320358, 58.41638199985027, 58.3401694893837, 61.35596126317978, 56.93699598312378, 63.57364006340504, 59.31987091898918, 52.95781530439854, 50.431821048259735, 53.058392107486725, 58.33010382950306, 60.7285313308239, 60.960041508078575, 60.40429472923279, 56.692000329494476, 63.566245660185814, 63.05057153105736, 53.74124586582184, 56.13837003707886, 58.875446766614914, 62.022198513150215, 59.98153701424599, 61.08094722032547, 55.84843419492245, 53.387207463383675, 52.08896532654762, 49.63638313114643, 49.47366826236248, 48.27344946563244, 49.64682497084141, 47.01738886535168, 47.2847805172205, 49.90352779626846, 50.04570096731186, 49.42756913602352, 49.072086811065674, 51.521180793643, 53.80694434046745, 56.528529301285744, 57.90860004723072, 59.74465772509575, 56.55755214393139, 56.14837110042572, 51.80106997489929, 57.292022332549095, 55.9181984513998, 62.29898326098919, 61.45886734127998, 68.83213609457016, 64.66860830783844, 66.7073281109333, 64.05301854014397, 68.40155839920044, 66.18696123361588, 71.1223416030407, 66.14654660224915, 74.75417912006378, 70.98275229334831, 82.29750394821167, 72.26942405104637, 92.86586925387383, 18.417180441319942, 0.16029886639444157, 0.5054586741607636, 0.3072388074360788, 0.26969697035383433, 27.623803317546844, 83.19523617625237, 66.62570089101791, 55.944671630859375, 33.670358061790466, 39.50796581804752, 12.519127428531647, 0.523829204030335, 0.25366370100528, 0.040850880614016205, 0.06919328516232781, 0.11787291092332453, 0.1703121158061549, 0.0830683000094723, 0.07525468725361861, 0.039322527663898654, 0.19438944960711524, 0.2501966245472431, 0.2471653520478867, 0.24710687081096694, 0.2614224987337366, 0.2174979096162133, 0.2375188423320651, 0.180158723378554, 2.137180119752884, 46.004298627376556, 62.07047492265701, 49.432964846491814, 79.87327203154564, 65.62250152230263, 85.84091261029243, 64.79495912790298, 0.4576929216273129, 3.137546028010547, 0.7973795535508543, 0.600923445308581, 0.29892345832195133, 2.4299382604658604, 42.910094261169434, 84.8844963312149, 92.25518882274628, 91.77512258291245, 93.988336622715, 91.65533781051636, 87.64388546347618, 94.98930171132088, 86.78288206458092, 87.43189483880997, 80.28192490339279, 85.11860176920891, 78.89867752790451, 81.0494913160801, 77.57366582751274, 77.74575099349022, 65.91054126620293, 62.18146696686745, 62.940008863806725, 62.479967549443245, 61.0832004994154, 64.47249323129654, 63.426831141114235, 62.70122207701206, 62.0642014592886, 57.0658964663744, 56.21752358973026, 57.22120553255081, 54.94450069963932, 54.73751060664654, 58.40651012957096, 54.132070094347, 57.763159051537514, 61.59744590520859, 59.11757357418537, 61.42814598977566, 66.39052391052246, 64.76025938987732, 65.94324991106987, 66.75293326377869, 67.84417390823364, 73.62605005502701, 76.35819464921951, 64.40605759620667, 73.76820802688599, 68.31825166940689, 69.00421366095543, 67.21844628453255, 66.73642694950104, 66.42750352621078, 66.1308154463768, 62.36718960106373, 59.91890497505665, 66.19142979383469, 67.26144477725029, 66.35821804404259, 64.32468876242638, 61.93333648145199, 67.38576650619507, 68.30337926745415, 66.19665071368217, 66.81371480226517, 65.4718092083931, 68.52584213018417, 62.352575585246086, 62.3126283288002, 63.12207989394665, 59.71763737499714, 63.694154396653175, 64.23811420798302, 64.05396088957787, 63.15639965236187, 62.40735724568367, 60.86799144744873, 61.414345130324364, 63.431041315197945, 60.092103481292725, 65.043655782938, 59.06303130090237, 52.895612642169, 53.25097717344761, 57.790901362895966, 59.56277668476105, 64.8842391371727, 62.280972227454185, 62.19230018556118, 60.58416187763214, 61.36826120316982, 65.36558210849762, 55.5877073854208, 57.50324159860611, 60.31800515949726, 61.68148599565029, 62.663357108831406, 65.32284960150719, 59.327858090400696, 55.520097613334656, 56.03699907660484, 53.5813694447279, 51.568222269415855, 49.696138724684715, 54.0679257363081, 48.83711501955986, 52.73730933666229, 52.478281036019325, 51.8009939789772, 50.67221514880657, 51.85297518968582, 53.12632866203785, 57.05390051007271, 59.129280745983124, 60.35429321229458, 61.85522027313709, 61.75297535955906, 59.83115628361702, 55.77603667974472, 60.23257814347744, 59.468036368489265, 65.11162653565407, 65.59814482927322, 70.11108666658401, 66.26403629779816, 70.84393814206123, 69.24419358372688, 74.90823045372963, 71.81389689445496, 78.27298790216446, 70.81271141767502, 82.18689948320389, 73.00566494464874, 87.23216235637665, 76.85756385326385, 99.04333457350731, 19.831884428858757, 0.18581237469334155, 1.4402504917234182, 0.4447409900603816, 0.3586154943332076, 33.14600519835949, 94.24249738454819, 71.71084642410278, 73.04965898394585, 43.36344413459301, 56.381097212433815, 18.167463541030884, 1.1960265529341996, 0.32890200905967504, 0.26449724624399096, 0.21820746216690168, 0.23993533453904092, 0.2380046818871051, 0.158240549499169, 0.10879301611566916, 0.19845751725370064], [0.10742858503363095, 0.05132309270265978, 0.10713639407185838, 0.020017444621771574, 0.022172945755301043, 0.03189540686435066, 0.05355571040126961, 0.025557636399753392, 1.3314407179132104, 26.08884148299694, 30.169809199869633, 37.567094564437866, 52.483091577887535, 44.09342676401138, 68.21191817522049, 53.417005464434624, 0.0891530278022401, 0.1761421756236814, 0.21741419535828754, 0.23917184269521385, 0.15332074865000322, 1.7591816280037165, 41.1398034542799, 58.044769540429115, 62.681322544813156, 69.82579797506332, 77.78569445014, 82.16045290231705, 80.49407511949539, 83.36482107639313, 80.21004036068916, 82.14754119515419, 77.13249430060387, 74.38173070549965, 72.99108132719994, 75.84362626075745, 76.11138269305229, 75.51314279437065, 66.55285879969597, 58.35781954228878, 57.241815626621246, 59.06098321080208, 56.1006760597229, 56.81574068963528, 55.77183410525322, 54.899408519268036, 52.25396387279034, 52.35034570097923, 50.17169080674648, 48.36548052728176, 47.29750983417034, 48.26516970992088, 49.342050924897194, 51.63906566798687, 53.23429226875305, 55.452309250831604, 55.42550548911095, 56.71079412102699, 61.89809337258339, 61.83917373418808, 64.20117259025574, 63.77290517091751, 63.5355357080698, 62.707347348332405, 66.1180329322815, 88.55541095137596, 65.87811380624771, 59.571736603975296, 67.32420980930328, 60.637237429618835, 60.04035785794258, 62.2666621953249, 65.14743581414223, 55.10365515947342, 48.444041311740875, 61.366076320409775, 64.16110754013062, 61.501409858465195, 58.18089723587036, 56.67756110429764, 60.63522733747959, 57.43939362466335, 61.521054804325104, 59.21233668923378, 59.48785990476608, 60.9909338504076, 52.04852029681206, 55.363701805472374, 54.1120033711195, 57.37249821424484, 52.20976084470749, 53.61362211406231, 60.40613383054733, 59.72728505730629, 57.51331105828285, 55.4841173440218, 57.494293078780174, 56.823070496320724, 55.11408179998398, 55.16936123371124, 57.49880723655224, 55.36986507475376, 47.92461298406124, 49.11554507911205, 55.0826308876276, 56.08706898987293, 57.76687145233154, 57.33454965054989, 60.05868047475815, 61.589956507086754, 48.38020093739033, 59.91767764091492, 62.78154216706753, 57.24765591323376, 55.076657608151436, 57.432405799627304, 54.91102069616318, 53.470567390322685, 51.24125361442566, 47.831396386027336, 45.320726707577705, 47.26401463150978, 45.44679254293442, 45.32718636095524, 46.25462159514427, 46.60165697336197, 46.81334361433983, 48.30860897898674, 45.68907134234905, 48.207272216677666, 50.03909692168236, 52.76454247534275, 53.94215628504753, 54.46016348898411, 56.296065375208855, 54.60599586367607, 51.98960825800896, 51.95055395364761, 52.146087661385536, 53.20523902773857, 60.22511154413223, 63.15761178731918, 65.04276663064957, 62.92856767773628, 62.88614675402641, 62.34972953796387, 64.33600455522537, 61.55015364289284, 64.9443519115448, 62.30863094329834, 68.76949265599251, 68.07731419801712, 77.97601103782654, 71.80746763944626, 87.9828728735447, 37.933064326643944, 0.149493656354025, 0.12740599078824744, 0.177235804439988, 0.2496182540198788, 19.27377797663212, 77.49687194824219, 60.9875026345253, 48.04826594889164, 40.518973767757416, 23.953907042741776, 10.251863189041615, 0.2792021899949759, 0.08949086826760322, 0.1290023059118539, 0.025516076129861176, 0.10292811988620088, 0.06563698028912768, 0.07145139563363045, 0.19489221012918279, 0.06828112629591487, 0.13251560332719237, 0.03862292360281572, 0.05580436591117177, 0.03959492554713506, 0.006125859008534462, 0.028005039057461545, 0.05135496423463337, 0.14156158198602498, 3.334931186400354, 47.420258447527885, 48.32739517092705, 45.18945135176182, 51.041027158498764, 52.68210589885712, 75.13821691274643, 63.538856729865074, 0.06477109433035366, 0.5707610200624913, 0.6536285171750933, 0.2654753078240901, 0.039047892205417156, 1.764766259584576, 42.15041622519493, 71.91269159317017, 78.11449080705643, 79.65992107987404, 82.94021666049957, 85.87710946798325, 82.65457078814507, 84.11633715033531, 83.2884755730629, 84.97940763831139, 78.91991838812828, 77.39470303058624, 75.3500859439373, 80.57711586356163, 78.88774931430817, 79.0097227692604, 71.7100028693676, 61.11312009394169, 58.94355431199074, 58.277731239795685, 58.36485296487808, 59.582832008600235, 56.998271495103836, 58.817119896411896, 54.65587958693504, 53.230469673871994, 52.75426782667637, 50.33711113035679, 50.82060098648071, 51.41439892351627, 50.478307753801346, 53.402771428227425, 55.43763063848019, 58.05684149265289, 57.85632245242596, 59.64920684695244, 65.42369619011879, 66.94015681743622, 66.39873906970024, 67.30474725365639, 66.95936098694801, 64.02182221412659, 68.73967945575714, 82.18208894133568, 65.44414669275284, 62.8071565926075, 68.29406216740608, 64.1119609773159, 61.759473010897636, 64.54452216625214, 66.24835833907127, 60.331711024045944, 53.90119068324566, 60.942737236618996, 66.3247798383236, 64.37558323144913, 61.155468821525574, 60.15398696064949, 63.21557767689228, 59.11874771118164, 65.34067064523697, 60.41992329061031, 59.692490324378014, 64.56326276063919, 56.77072450518608, 60.27208462357521, 58.66488106548786, 61.34401090443134, 55.848320201039314, 60.422693341970444, 63.035623133182526, 61.188861429691315, 60.44062077999115, 61.204915568232536, 57.818461284041405, 59.49300102889538, 58.24892498552799, 59.510312899947166, 59.07020151615143, 56.568294167518616, 48.161796256899834, 52.56218433380127, 57.03332081437111, 59.2415077239275, 59.32907022535801, 58.719370141625404, 61.948254480957985, 59.8104739934206, 47.76686064898968, 61.030375733971596, 62.10240840911865, 61.624188870191574, 57.913714572787285, 59.96804013848305, 56.1824856698513, 57.37433731555939, 52.04950824379921, 49.97206471860409, 48.984554708004, 50.91732479631901, 47.58075803518295, 48.34219537675381, 48.439006581902504, 48.88335853815079, 48.79203803837299, 50.281558111310005, 48.81239354610443, 50.18241003155708, 52.43136115372181, 53.60925994813442, 55.6725150346756, 57.80154839158058, 59.767893478274345, 56.57636113464832, 54.719355180859566, 52.489376440644264, 52.73584641516209, 55.226764753460884, 63.01891542971134, 64.56062570214272, 66.24018117785454, 64.83328387141228, 67.10202053189278, 67.12642282247543, 69.16363790631294, 66.39255300164223, 69.72409263253212, 66.27852872014046, 74.8117308318615, 70.68376153707504, 82.2495885193348, 74.03524249792099, 89.24173012375832, 43.32158178091049, 0.17072062357328832, 0.44544656469952315, 0.3760684031294659, 0.4110763699281961, 23.946349248290062, 84.16403979063034, 68.41999500989914, 61.25229902565479, 38.51596064865589, 42.357003539800644, 15.056515373289585, 0.5128922034054995, 0.22916380316019058, 0.019272120553068817, 0.03744928755622823, 0.07788371571223252, 0.10872195547563024, 0.14867107471218333, 0.18498490971978754, 0.055667740234639496, 0.298579428344965, 0.14696176018333063, 0.17923427454661578, 0.18367274809861556, 0.0929625757271424, 0.10957284262985922, 0.22012583969626576, 0.14502257283311337, 5.90274291113019, 68.26862633228302, 63.23453865945339, 52.111262530088425, 68.52828159928322, 64.84478205442429, 86.97391301393509, 76.14186465740204, 0.37792029906995595, 1.8363019335083663, 1.3362180115655065, 0.7269020040985197, 0.3033240674994886, 3.2720438484102488, 49.41629134118557, 90.33476427197456, 90.34103393554688, 90.37071794271469, 88.72953280806541, 91.4878199994564, 88.50187942385674, 91.57677322626114, 87.2529624402523, 89.7545126080513, 84.40921023488045, 81.20980471372604, 78.57105150818825, 86.1802040040493, 83.27471271157265, 82.88743749260902, 74.196467846632, 64.62437868118286, 61.72472767531872, 63.97056296467781, 61.16988144814968, 64.1441148519516, 60.92812322080135, 62.070854902267456, 56.81580528616905, 57.537743747234344, 56.39610640704632, 52.89970502257347, 53.11426430940628, 54.38621565699577, 54.2144762724638, 57.944139540195465, 60.13933874666691, 60.551578626036644, 59.926808550953865, 63.12297284603119, 67.58884280920029, 67.4231792986393, 69.45560663938522, 67.55459144711494, 69.2172834277153, 67.91393056511879, 80.56438654661179, 84.48957592248917, 58.90519917011261, 65.07170587778091, 70.43197184801102, 65.5334646999836, 63.57753485441208, 67.99852162599564, 70.66028639674187, 65.68547934293747, 54.86154355108738, 63.78906950354576, 67.5825883448124, 66.69994130730629, 63.773285150527954, 61.24963536858559, 65.49650028347969, 62.97605372965336, 66.60768985748291, 62.89924085140228, 62.61537708342075, 70.39952158927917, 57.7032096683979, 63.05374816060066, 60.81543266773224, 64.59899604320526, 58.74953672289848, 61.26538172364235, 66.96370795369148, 63.97297963500023, 64.35273125767708, 62.004765048623085, 61.92304663360119, 61.71634912490845, 59.77083072066307, 63.722170293331146, 62.06898920238018, 56.219541281461716, 51.47228121757507, 58.65636572241783, 57.69542768597603, 62.744486555457115, 62.7293785661459, 61.81084245443344, 62.2378521412611, 61.474682092666626, 55.067085921764374, 60.8781673014164, 63.511099219322205, 67.4094620347023, 62.1090542525053, 62.82095365226269, 58.50174821913242, 61.25909686088562, 55.17348401248455, 53.64669553935528, 50.92541456222534, 54.067416563630104, 50.97067393362522, 51.74767144024372, 50.971749275922775, 52.19379410147667, 52.40261569619179, 54.18066568672657, 50.55043928325176, 53.92551317811012, 54.71379987895489, 57.56495788693428, 59.49452094733715, 60.67320629954338, 62.296980768442154, 59.32264856994152, 59.666286930441856, 55.87398402392864, 58.06144304573536, 59.398036524653435, 64.8230168223381, 69.66066643595695, 71.56384751200676, 68.7515576183796, 72.1763214468956, 70.4141204059124, 76.90531969070435, 70.48930317163467, 76.06598272919655, 71.29065737128258, 79.76885363459587, 76.18111655116081, 87.84854248166084, 78.33955273032188, 94.37700256705284, 45.5266148597002, 0.15628993307473138, 0.9043566382024437, 0.8386150002479553, 0.5478246789425611, 27.795506604015827, 95.03844067454338, 73.98322328925133, 74.76159632205963, 49.53866757452488, 56.362702399492264, 18.41558262705803, 1.183424647897482, 0.2835838298778981, 0.2002883213572204, 0.12307497279834934, 0.3107641276437789, 0.23672809882555157, 0.33780169556848705, 0.3620316891465336, 0.32030808739364147], [0.012149594786023954, 0.03424998911214061, 0.009929238294716924, 0.03628036043664906, 0.04671286020311527, 0.11425663309637457, 0.054833462345413864, 0.37749169394373894, 1.6329185594804585, 31.745535247027874, 26.330200731754303, 19.498404823243618, 48.896638825535774, 47.80443303287029, 75.6764580309391, 56.253070682287216, 0.08912272591260262, 0.1299326473963447, 0.0923400919418782, 0.5168649496044964, 0.04708016764197964, 3.638107655569911, 46.812997832894325, 53.816010653972626, 53.719735220074654, 71.65825724601746, 78.01469296216965, 81.7866213619709, 73.71510207653046, 75.25268197059631, 77.89718046784401, 75.73711797595024, 77.01880440115929, 76.6873861849308, 75.95633581280708, 78.61841216683388, 75.77083736658096, 73.97557809948921, 71.56931921839714, 62.293131574988365, 57.488445192575455, 56.57820783555508, 56.59976787865162, 56.08337938785553, 55.072626024484634, 51.93915456533432, 52.156385108828545, 49.78172533214092, 49.29748311638832, 49.62774999439716, 48.949471190571785, 49.41836602985859, 49.753679037094116, 52.652357295155525, 54.257657155394554, 56.39481067657471, 59.34609331190586, 62.3355221003294, 64.28311139345169, 64.60266664624214, 62.17745818197727, 65.38943722844124, 63.85882616043091, 62.89817690849304, 56.95454344153404, 53.310793563723564, 80.86258694529533, 70.49025312066078, 61.4801499992609, 62.29139506816864, 57.74304673075676, 60.38383662700653, 64.93105262517929, 58.53455185890198, 50.21556705236435, 53.33399511873722, 58.546650409698486, 59.908276945352554, 59.72065061330795, 59.35961678624153, 61.89914971590042, 59.25916537642479, 60.562932416796684, 57.265663146972656, 57.46608719229698, 59.77817192673683, 60.08182883262634, 56.895205825567245, 58.16038213670254, 59.50276270508766, 59.90112952888012, 62.124800607562065, 56.47060140967369, 56.58621020615101, 56.378395557403564, 53.22461798787117, 52.74111293256283, 59.17134828865528, 58.893902376294136, 58.106288239359856, 55.409861728549004, 55.8049189299345, 47.76582710444927, 48.45485173165798, 56.546787321567535, 57.80732408165932, 58.56154941022396, 60.45138940215111, 63.59254404902458, 45.25053687393665, 49.998929277062416, 58.92310380935669, 54.18536223471165, 55.33412419259548, 56.59157931804657, 55.64493231475353, 54.22893449664116, 53.37509751319885, 49.39578004181385, 48.65452341735363, 48.88674795627594, 47.24389091134071, 47.45462380349636, 45.93010760843754, 48.38231362402439, 46.38220734894276, 47.12759055197239, 45.108207911252975, 46.884247809648514, 48.182565942406654, 47.51586131751537, 47.742686346173286, 53.81295181810856, 54.40492205321789, 55.882620960474014, 51.79343618452549, 54.77244973182678, 50.585059225559235, 50.91681942343712, 53.488000854849815, 60.55880203843117, 62.79741391539574, 63.92048165202141, 61.51076875627041, 62.485275864601135, 61.61212831735611, 62.03605256974697, 61.44544646143913, 61.59178800880909, 61.91440209746361, 64.66904908418655, 68.90447661280632, 75.64561888575554, 73.71381774544716, 85.30173674225807, 63.14821109175682, 1.045466756913811, 0.3157196851680055, 0.41871921450365335, 0.5089156574103981, 17.63375747948885, 73.72005701065063, 62.21582852303982, 51.87650352716446, 27.786896266043186, 12.84761505201459, 15.153597313910723, 0.43207864451687783, 0.06966912056668662, 0.0645798651385121, 0.09175883446005173, 0.07777723978506401, 0.03703662376210559, 0.06135696268756874, 0.10416965873446316, 0.04817476867174264, 0.04048595917993225, 0.12009659316390753, 0.04481445015699137, 0.035480228762025945, 0.052184102751198225, 0.17084687773603946, 0.042726510437205434, 0.6239069870207459, 6.240231301635504, 49.944037422537804, 39.999720230698586, 29.566032998263836, 47.054877653717995, 57.535000294446945, 85.16894146800041, 63.316914439201355, 0.1687714469153434, 0.1901491591706872, 0.7781354268081486, 0.8924741414375603, 0.07271672773640603, 3.855085037648678, 50.22182151675224, 72.30342462658882, 72.09233075380325, 82.21250250935555, 83.68475630879402, 82.71888613700867, 78.24847921729088, 78.3863814175129, 79.67923924326897, 77.0556928217411, 78.24510499835014, 80.80409288406372, 78.3851046860218, 82.51189604401588, 80.17565220594406, 75.65517917275429, 74.67917114496231, 65.28930500149727, 58.198342099785805, 58.47342073917389, 58.278700187802315, 59.071124866604805, 58.284848257899284, 55.07633462548256, 52.96937048435211, 52.261156886816025, 50.2324191480875, 51.05851002037525, 52.19284035265446, 50.27414470911026, 52.47504360973835, 56.20982140302658, 55.82036890089512, 57.84890905022621, 61.79553307592869, 65.11712864041328, 68.60436111688614, 66.87568187713623, 66.71665281057358, 67.46392831206322, 66.73420786857605, 66.24771237373352, 60.0320553034544, 56.42366252839565, 73.38457301259041, 68.78609776496887, 64.00055855512619, 63.694933354854584, 59.68660444021225, 64.01446580886841, 68.0693194270134, 60.63968449831009, 55.32201424241066, 54.36108000576496, 60.05507446825504, 62.44711451232433, 64.13526892662048, 63.22257690131664, 64.98913630843163, 61.659124195575714, 60.51512338221073, 59.82883080840111, 59.962576031684875, 62.70067110657692, 62.268691286444664, 59.34802360832691, 60.06851814687252, 61.380773931741714, 63.39363992214203, 65.49424320459366, 59.415701776742935, 57.090967521071434, 58.74051980674267, 57.315611466765404, 55.486841797828674, 60.1271566003561, 60.40063552558422, 59.6404293179512, 57.55180299282074, 57.90705353021622, 50.05819469690323, 53.61737251281738, 58.517604768276215, 60.68631559610367, 60.281204134225845, 62.601135447621346, 62.02244929969311, 50.09683482348919, 53.97621385753155, 58.98830071091652, 55.80921269953251, 58.642914444208145, 59.745322689414024, 58.4429045766592, 56.830290108919144, 55.1857003569603, 51.79592125117779, 51.974367275834084, 51.0897633433342, 51.05566397309303, 50.40761634707451, 49.99655060470104, 50.03600388765335, 49.424776285886765, 48.540134355425835, 47.4322734028101, 48.95740896463394, 51.67789198458195, 50.069305300712585, 52.00393348932266, 56.660279631614685, 57.253287211060524, 57.14511841535568, 54.198737516999245, 55.81417143344879, 52.516499385237694, 53.356037735939026, 57.613884061574936, 63.038605973124504, 66.3068675994873, 65.80267265439034, 64.78875786066055, 67.8287923336029, 65.8358296751976, 66.68924108147621, 64.704759567976, 65.73848649859428, 66.70602098107338, 68.94199579954147, 71.46851062774658, 81.03692159056664, 76.03736266493797, 85.86792916059494, 67.75573745369911, 1.6670079552568495, 0.6137231178581715, 0.4101054329657927, 0.6864272884558886, 20.841119773685932, 81.32455855607986, 67.94735357165337, 66.18813917040825, 28.12247335910797, 19.21995386481285, 20.369468182325363, 1.182027154136449, 0.11729077770723961, 0.19126813975162804, 0.04155273338255938, 0.06729786968207918, 0.010395254157629097, 0.04019947904453147, 0.04599315507221036, 0.009421449722140096, 0.14331546990433708, 0.16576626832829788, 0.13149510574294254, 0.07121712187654339, 0.1294274823158048, 0.20495910197496414, 0.24146225885488093, 0.5499941250309348, 13.959347046911716, 74.61735606193542, 53.9360424131155, 35.049315467476845, 63.59382838010788, 71.20282128453255, 94.67302948236465, 75.5084690451622, 0.39982526272069663, 1.0184290702454746, 2.040553679689765, 1.5825965534895658, 0.1751293518464081, 4.875718345865607, 59.221285209059715, 91.21516183018684, 87.35488817095757, 92.76376873254776, 90.3787887096405, 95.02975434064865, 85.30490577220917, 82.05824598670006, 87.19684705138206, 82.373416274786, 81.9263930618763, 87.1167853474617, 81.33367046713829, 85.30269429087639, 86.79400786757469, 80.29386386275291, 76.47987172007561, 69.56563353538513, 62.3999248445034, 62.62364163994789, 60.62566705048084, 61.12507425248623, 60.90401731431484, 58.69184821844101, 56.19792424142361, 55.92437691986561, 53.406168445944786, 54.74384106695652, 54.58461061120033, 55.09582377970219, 56.219146102666855, 58.88613939285278, 58.10656562447548, 61.01060539484024, 64.45786401629448, 68.4486910700798, 68.55438619852066, 70.65888807177544, 67.78495028614998, 69.3522521853447, 66.82838201522827, 67.54663467407227, 62.85248436033726, 70.85618868470192, 78.78858223557472, 67.04829141497612, 68.67671683430672, 66.85685008764267, 62.405217960476875, 64.64097619056702, 72.85142362117767, 65.91346710920334, 58.244372829794884, 53.91219489276409, 62.58603125810623, 63.85488957166672, 66.58305197954178, 66.12013801932335, 69.58211705088615, 65.06172001361847, 65.257348716259, 62.736142203211784, 61.96706347167492, 64.85377237200737, 65.48282101750374, 63.079389184713364, 61.59170441329479, 64.55886259675026, 66.785619109869, 67.32898995280266, 61.428761556744576, 58.49199794232845, 61.16584986448288, 58.96843917667866, 58.906669691205025, 63.61932501196861, 64.91520747542381, 63.18956807255745, 61.58985011279583, 58.746656477451324, 53.50389540195465, 55.99247686564922, 62.66654133796692, 63.697034642100334, 60.63685745000839, 64.31704357266426, 65.83281263709068, 54.620260298252106, 57.20025345683098, 61.43703751266003, 58.560618460178375, 59.93847392499447, 61.722117215394974, 63.75085115432739, 59.167639687657356, 59.25681330263615, 54.71112862229347, 57.29139916598797, 56.06399282813072, 54.71531219780445, 53.29171098768711, 53.74148905277252, 53.790130242705345, 52.63781927525997, 52.1419382840395, 51.36104978621006, 53.29921938478947, 53.914444372057915, 53.856459483504295, 53.8547495752573, 60.083990916609764, 59.83480788767338, 61.29488714039326, 57.21489407122135, 59.26875986158848, 56.056921407580376, 55.538230240345, 61.43576838076115, 65.79664617776871, 70.89072123169899, 69.25908878445625, 67.62228101491928, 70.78913748264313, 71.18230998516083, 71.59161642193794, 71.14735186100006, 71.50761052966118, 73.5149060189724, 75.85511684417725, 76.50501117110252, 87.00532972812653, 83.38568195700645, 91.36995032429695, 72.36133351922035, 1.8467361736111343, 0.7634596643038094, 0.648367996327579, 0.6564588309265673, 24.663950242102146, 93.8314962387085, 75.71869656443596, 83.2518683373928, 39.23690736293793, 34.722301214933395, 29.38550278544426, 1.500181588344276, 0.23514460801379755, 0.2621041762176901, 0.18205240223323926, 0.18251196976052597, 0.07861844191211276, 0.37504881096538156, 0.15758563386043534, 0.2334714657627046], [0.021391629379650112, 0.023596366445417516, 0.06219543000042904, 0.042580656154314056, 0.03306018537841737, 0.03625693454523571, 0.10427126617287286, 0.40313325240276754, 3.169668079353869, 30.94464272260666, 19.944369792938232, 18.348043151199818, 34.16044056415558, 46.23332753777504, 75.17332702875137, 56.41996532678604, 0.24898419273085892, 0.07500605293898843, 0.3130505362059921, 0.9972541127353907, 0.0496574609860545, 6.93199273198843, 52.18308627605438, 45.41349112987518, 48.055318370461464, 68.1161481142044, 71.84525281190872, 79.14086893200874, 79.46957409381866, 75.72383388876915, 77.59863808751106, 75.77564030885696, 73.15691962838173, 71.21102124452591, 75.08112117648125, 72.38936081528664, 76.67318254709244, 75.05247831344604, 75.0153923034668, 67.55252435803413, 58.52624550461769, 55.486894994974136, 55.192361399531364, 53.13749626278877, 55.20485132932663, 53.156191259622574, 51.4758188277483, 48.38968142867088, 47.73366183042526, 47.938208654522896, 49.22049544751644, 48.524501994252205, 50.08199281990528, 52.8439886122942, 55.37513539195061, 61.890098601579666, 63.318251967430115, 63.51218596100807, 64.76223528385162, 66.01519525051117, 64.17015105485916, 65.81908777356148, 66.21846154332161, 63.017384111881256, 65.81213414669037, 54.49650473892689, 38.722772151231766, 64.21507984399796, 65.93764141201973, 63.75655084848404, 59.18359883129597, 61.34882144629955, 61.42079718410969, 57.25306682288647, 54.29100036621094, 56.60297870635986, 57.004221975803375, 59.517661705613136, 57.68872484564781, 58.17442998290062, 58.86762298643589, 55.82381911575794, 60.48469841480255, 58.468279615044594, 58.62517699599266, 64.36919957399368, 59.103050753474236, 58.50305154919624, 54.254408329725266, 58.2668562233448, 55.62519617378712, 58.79053272306919, 58.285053446888924, 57.6969438046217, 56.995235458016396, 58.40198837220669, 55.18082521855831, 51.72864966094494, 57.50008016824722, 56.30651481449604, 55.71523994207382, 50.05556903779507, 46.775387451052666, 50.65844088792801, 57.600995153188705, 58.6998125910759, 58.30934554338455, 58.820163533091545, 50.797680616378784, 54.88630682229996, 60.602875873446465, 56.02869652211666, 56.4044963568449, 57.95016601681709, 58.359624445438385, 57.37153306603432, 54.98683422803879, 52.36160829663277, 51.8048469722271, 49.83997240662575, 49.32832986116409, 49.19041246175766, 47.81471908092499, 46.54129721224308, 47.4050060659647, 44.880372136831284, 44.82211746275425, 44.63541828095913, 46.97032459080219, 47.43670016527176, 48.25592860579491, 50.17072185873985, 51.03401653468609, 52.458780482411385, 53.10166038572788, 51.77151136100292, 52.011901661753654, 50.425878167152405, 55.258246064186096, 54.45575192570686, 61.919725611805916, 61.090271919965744, 61.29749000072479, 62.67128348350525, 59.85881879925728, 57.5937033444643, 57.16100916266441, 55.81729866564274, 55.88884502649307, 56.513592302799225, 60.37125550210476, 64.65967878699303, 71.22454851865768, 77.06756338477135, 76.50415241718292, 79.71964627504349, 5.0913335010409355, 0.4566957720089704, 0.40528663841541857, 0.5190635472536087, 16.85261059552431, 71.44456431269646, 62.529456093907356, 51.33239172399044, 37.15433031320572, 20.97016464918852, 13.8380148075521, 0.3359078534413129, 0.042202001277473755, 0.04435802191437688, 0.05367113662941847, 0.04218698391923681, 0.08828631805954501, 0.06933781100087799, 0.21464323857799172, 0.11359816999174654, 0.023334050638368353, 0.04067627181939315, 0.020520819271041546, 0.032172825376619585, 0.07606034792843275, 0.01808697565138573, 0.05305660124577116, 1.004294422455132, 10.11694572865963, 50.591226294636726, 32.052157893776894, 28.722618855535984, 41.84218816459179, 55.15924237668514, 86.3652540743351, 66.14360556006432, 0.47977178532164544, 0.04930057330057025, 0.6156221847049892, 1.1232989304699004, 0.020959274552296847, 6.609708750620484, 58.49878437817097, 67.5839714705944, 70.45205757021904, 81.12631559371948, 80.17195880413055, 80.07308810949326, 84.9954503774643, 79.30285423994064, 81.84643015265465, 76.38007387518883, 77.22689643502235, 75.05662769079208, 76.33155807852745, 75.78265473246574, 78.0571822822094, 79.16788548231125, 77.07174316048622, 70.28070196509361, 60.39481423795223, 59.18186232447624, 58.22463668882847, 56.0980162024498, 56.266901940107346, 56.65331080555916, 55.23507110774517, 50.684617683291435, 48.97998735308647, 49.72173035144806, 51.80472157895565, 51.7479982227087, 51.92033037543297, 55.19001692533493, 58.16246062517166, 64.55935657024384, 65.40951535105705, 66.62833794951439, 68.39436158537865, 67.83428683876991, 65.35728335380554, 67.09255903959274, 66.38629853725433, 66.11968964338303, 68.94144102931023, 62.02759802341461, 47.39332929253578, 56.31624989211559, 65.51334857940674, 64.13361981511116, 60.80719850957394, 62.88578197360039, 64.91930365562439, 59.25289951264858, 58.45618486404419, 61.88122607767582, 58.25807489454746, 64.34792071580887, 60.76287768781185, 63.022073060274124, 62.58892670273781, 58.6355884373188, 63.817507177591324, 59.462401270866394, 60.18744416534901, 69.44590955972672, 59.968397319316864, 60.286751836538315, 57.35988289117813, 60.4344043135643, 59.04142186045647, 62.21839338541031, 57.14709050953388, 59.26152125000954, 60.457225888967514, 61.07425957918167, 57.57773660123348, 54.51396860182285, 59.660051465034485, 59.0586843341589, 56.434210762381554, 52.15133897960186, 50.09875372052193, 54.25459071993828, 58.995216339826584, 58.10706339776516, 60.9045796841383, 60.86783945560455, 52.78025463223457, 58.27835440635681, 61.032526418566704, 59.43139113485813, 59.27459254860878, 60.167917013168335, 59.360787123441696, 58.789369985461235, 57.912342846393585, 56.13547079265118, 53.885512724518776, 52.31710508465767, 54.11166898906231, 52.670535519719124, 50.361992195248604, 49.72251310944557, 49.769326597452164, 48.14834877848625, 48.06848086416721, 47.91715398430824, 48.47938321530819, 48.77267047762871, 52.507710456848145, 52.259526774287224, 53.34330081939697, 55.37002086639404, 55.66657595336437, 54.59508664906025, 53.119986802339554, 51.89502753317356, 56.753431633114815, 57.95539453625679, 63.49888667464256, 63.58890384435654, 63.81685361266136, 64.04628530144691, 62.95635558664799, 61.31108187139034, 61.4942130446434, 59.63203176856041, 60.2070739120245, 63.4063084423542, 65.36255747079849, 69.99328538775444, 75.19199922680855, 78.75559240579605, 79.54277336597443, 81.2430377304554, 5.873606549575925, 0.6125634082127362, 0.654787989333272, 0.7174989336635917, 23.8322451710701, 77.51552134752274, 71.34678035974503, 64.22498971223831, 42.495836690068245, 27.962576039135456, 13.403584118932486, 0.8617292193230242, 0.05074623986729421, 0.056025288431555964, 0.017176000510517042, 0.026548718960839324, 0.1277529151411727, 0.08782237928244285, 0.19646689906949177, 0.10032633566879667, 0.09961837131413631, 0.0987272968632169, 0.1797809256822802, 0.2160410737269558, 0.1955298930988647, 0.1179793942719698, 0.17326429020613432, 1.409754753112793, 22.277133017778397, 78.89381378889084, 43.79893496632576, 33.52704495191574, 53.94514672458172, 69.2019322514534, 97.69672483205795, 79.52071934938431, 0.7876301079522818, 0.2411977871088311, 1.6603356320410967, 2.115664961747825, 0.1428823673631996, 8.439711928367615, 71.69623240828514, 84.49741870164871, 85.19453689455986, 87.78986603021622, 86.62155032157898, 88.93605932593346, 91.18001371622086, 85.83458974957466, 85.80403938889503, 80.90467348694801, 79.74562928080559, 79.03933838009834, 80.52492186427116, 80.22118136286736, 84.37125787138939, 84.96743068099022, 80.30587121844292, 74.5963203907013, 64.57718521356583, 61.15291155874729, 60.217815935611725, 60.3421338647604, 60.33456087112427, 58.573351576924324, 58.99102136492729, 54.50581043958664, 53.08072730898857, 53.56928989291191, 55.79168803989887, 54.32815097272396, 53.72232288122177, 56.37964949011803, 60.24110868573189, 67.56811872124672, 69.57218438386917, 67.97781273722649, 72.28121101856232, 73.7010732293129, 68.76521408557892, 69.47048664093018, 70.0124591588974, 66.52285560965538, 68.3855764567852, 58.460820615291595, 57.439317628741264, 66.40229567885399, 66.75360202789307, 68.75269755721092, 63.52076590061188, 66.05307921767235, 67.82765999436378, 63.655043095350266, 62.02051140367985, 60.020602717995644, 60.70300430059433, 66.51855424046516, 63.45975637435913, 64.17109340429306, 66.82819202542305, 62.44136542081833, 66.81902691721916, 62.019797042012215, 63.855900317430496, 73.04932460188866, 64.04785081744194, 65.53158760070801, 59.63105522096157, 63.76696228981018, 62.106740176677704, 65.03133684396744, 60.85428938269615, 62.05161273479462, 62.06537939608097, 64.44499030709267, 60.570148229599, 56.251208782196045, 61.718226224184036, 61.59680753946304, 58.23413237929344, 53.41877616941929, 54.13846515119076, 56.299017816782, 62.62822799384594, 62.722284346818924, 59.40526373684406, 62.735344246029854, 56.72799579799175, 58.46017085015774, 63.00197213888168, 61.70204669237137, 63.04883502423763, 63.617079332470894, 64.79818135499954, 62.04888068139553, 61.93629652261734, 59.51040789484978, 58.028666004538536, 55.33001661300659, 55.98098248243332, 55.99688082933426, 53.67335110902786, 51.42719283699989, 52.2789741307497, 51.27273492515087, 50.35474978387356, 50.21896407008171, 53.281409740448, 52.90105015039444, 55.84268510341644, 56.354745626449585, 55.87281368672848, 59.57836724817753, 59.250011667609215, 58.51447753608227, 56.88971132040024, 56.00714787840843, 60.800852850079536, 59.18674886226654, 66.87356159090996, 65.55591389536858, 66.83808669447899, 68.28688815236092, 67.00423657894135, 65.72886541485786, 66.46616265177727, 64.01680648326874, 65.5633082985878, 67.94700399041176, 70.79987570643425, 76.03253692388535, 78.22506487369537, 85.19847348332405, 82.26234063506126, 88.90460461378098, 6.275476310402155, 0.625045916531235, 0.6853289098944515, 0.5796942219603807, 25.126218236982822, 93.14064010977745, 76.61908864974976, 80.50586968660355, 56.43935188651085, 46.61682575941086, 27.713972479104996, 0.8535255782771856, 0.10790803469717503, 0.15712476015323773, 0.11613546899752691, 0.14231596025638282, 0.38473033520858735, 0.31548510713037103, 0.35053365456406027, 0.2728027693228796], [0.029631303550559096, 0.05384535950724967, 0.143147774215322, 0.012953734985785559, 0.03549503831891343, 0.046359965272131376, 0.12236688970006071, 1.0782011691480875, 5.064345449209213, 27.269424833357334, 24.0325191244483, 22.207516953349113, 36.417914628982544, 51.808471977710724, 76.6343866288662, 62.35194481909275, 0.8538192312698811, 0.04246211661666166, 0.26435807871166617, 0.30259308172389865, 0.2950977464206517, 12.617661841213703, 58.680859208106995, 34.136410653591156, 54.09635581076145, 63.94333362579346, 71.40664994716644, 78.75463485717773, 78.06566342711449, 76.28526136279106, 76.03432282805443, 77.07279190421104, 78.22556644678116, 74.57177370786667, 71.06267720460892, 71.43805146217346, 72.9790435731411, 75.91687113046646, 71.39638289809227, 65.29920727014542, 58.23843754827976, 56.38954795897007, 56.34916752576828, 54.106125086545944, 54.508071318268776, 52.58892349898815, 49.72877137362957, 48.41590762138367, 47.0318166911602, 49.14492130279541, 49.118531718850136, 47.89066180586815, 50.4211550205946, 52.691331803798676, 60.77726751565933, 64.40903663635254, 62.918357625603676, 65.67884489893913, 66.33984223008156, 65.41558742523193, 61.4726036041975, 62.715725898742676, 63.624291345477104, 66.55919685959816, 64.71952557563782, 70.50722301006317, 61.442190036177635, 46.31569191813469, 56.48757129907608, 63.32250773906708, 62.58981205523014, 59.706013798713684, 63.49804311990738, 58.74700225889683, 57.769299522042274, 54.99105580151081, 58.409447371959686, 59.77455072104931, 56.27987444400787, 61.30552276968956, 58.93721625208855, 56.67422108352184, 62.118857726454735, 56.51146441698074, 61.44003175199032, 57.8863712400198, 60.01449264585972, 61.07542611658573, 61.53741292655468, 59.51148323714733, 63.387788236141205, 53.50608788430691, 45.44100545346737, 46.01194001734257, 54.02631416916847, 58.97494062781334, 57.26123258471489, 56.15634307265282, 57.48306468129158, 57.82848134636879, 54.84292834997177, 47.083794102072716, 48.80179211497307, 49.947742223739624, 57.45827481150627, 59.37216371297836, 61.62390388548374, 52.032131776213646, 53.89890320599079, 58.71993251144886, 55.649093091487885, 57.23978653550148, 54.212302789092064, 53.078998401761055, 57.39169478416443, 55.47195039689541, 55.51714517176151, 54.66910667717457, 54.215247631073, 52.824203073978424, 51.42134875059128, 51.16982884705067, 49.97214451432228, 47.34624221920967, 46.897136718034744, 45.54295398294926, 43.67513760924339, 44.82631243765354, 45.70229083299637, 47.39413484930992, 45.974652618169785, 49.35360990464687, 48.688391000032425, 51.22644580900669, 51.38719618320465, 51.29554130136967, 51.067663729190826, 54.267312437295914, 54.03434693813324, 58.53788048028946, 60.57310067117214, 60.39060786366463, 61.37690953910351, 61.0393812507391, 57.54964850842953, 57.051377445459366, 54.476343020796776, 54.413023218512535, 53.142147213220596, 54.520428255200386, 58.86761538684368, 67.5510348379612, 69.99191746115685, 74.24906462430954, 77.80866041779518, 84.93480563163757, 12.893965914845467, 0.7866554602514952, 0.8712465211283416, 0.34771655104123056, 37.40753352642059, 71.73318922519684, 63.35394345223904, 54.0059282630682, 31.32266353815794, 14.948377925902605, 11.232696957886219, 1.0990688181482255, 0.08348667834070511, 0.045352692759479396, 0.08277227956568822, 0.011888554545294028, 0.09819486527703702, 0.10218572730082087, 0.20353670173790306, 0.32476581225637347, 0.06549153418745846, 0.022348478523781523, 0.0658752690651454, 0.07386937955743633, 0.03296320894150995, 0.021261482652334962, 0.17305427725659683, 2.299369666725397, 18.223390839993954, 47.724223136901855, 37.63699561357498, 30.869621448218822, 43.8599406927824, 61.059907749295235, 84.3622675538063, 71.16157829761505, 0.7386220002081245, 0.05760779218690004, 0.6545966933481395, 0.8725339395459741, 0.5164141394197941, 16.149920001626015, 70.48362627625465, 60.21970823407173, 70.21495029330254, 76.03022664785385, 80.752362459898, 82.42714539170265, 82.62531995773315, 80.81193566322327, 79.1506876051426, 79.77425694465637, 79.24516573548317, 76.51223838329315, 76.47830620408058, 75.9903135895729, 75.67245304584503, 77.41607308387756, 76.64089947938919, 70.34247145056725, 60.41162833571434, 58.68447661399841, 58.37369129061699, 57.47901789844036, 56.983520686626434, 56.93510748445988, 53.401433899998665, 50.22019900381565, 51.381352096796036, 51.87978655099869, 50.83375588059425, 52.42515228688717, 51.95039816200733, 54.380352571606636, 62.87508174777031, 67.47445374727249, 66.67835086584091, 66.84482753276825, 68.263458609581, 67.56108149886131, 62.86415733397007, 65.08929133415222, 62.65051759779453, 68.59809905290604, 66.8338917195797, 70.72921469807625, 66.89191460609436, 53.50529372692108, 57.75606483221054, 66.16131260991096, 61.50283098220825, 63.56033697724342, 68.09897303581238, 61.492962911725044, 59.96420614421368, 58.64286884665489, 62.18702606856823, 61.28382593393326, 59.809679836034775, 65.01814395189285, 59.791870191693306, 61.08074203133583, 64.36106041073799, 60.50415337085724, 66.33792713284492, 58.070357367396355, 60.75308181345463, 63.78177389502525, 63.10762546956539, 61.37404069304466, 65.85447907447815, 56.62800796329975, 45.9814428538084, 44.800470024347305, 55.16586162149906, 61.82253822684288, 58.58981989324093, 60.34501791000366, 58.457613587379456, 60.96534222364426, 55.5849639326334, 51.863105446100235, 53.20555441081524, 54.27132502198219, 57.707815021276474, 61.178879365324974, 63.70268113911152, 54.0696432441473, 58.26638504862785, 61.533601731061935, 59.42614361643791, 57.95175813138485, 55.63229039311409, 55.064961835742, 59.76522982120514, 59.523251205682755, 59.06274251639843, 56.59082315862179, 57.36244775354862, 56.86324954032898, 56.01279437541962, 52.30260506272316, 52.521971091628075, 49.67429369688034, 49.288637191057205, 49.03558976948261, 48.800785169005394, 47.45524317026138, 48.68340186774731, 49.86872546374798, 48.73703218996525, 50.38838557898998, 51.03120468556881, 52.43116356432438, 52.651232555508614, 52.708970457315445, 54.155089259147644, 55.73315978050232, 56.98032505810261, 59.82261434197426, 64.8786610364914, 61.88367314636707, 63.21185387670994, 63.13749946653843, 60.01350089907646, 61.88781872391701, 58.16097490489483, 58.548595905303955, 58.70107412338257, 60.59302680194378, 63.192436918616295, 71.19013756513596, 72.88810685276985, 80.84195405244827, 80.15386417508125, 87.01299011707306, 14.556476455181837, 0.7369077578186989, 0.9658071189187467, 0.40604419307783246, 40.8244089782238, 79.3885700404644, 72.2592481970787, 67.81071290373802, 41.082859709858894, 20.05433589220047, 9.712772816419601, 1.3866521115414798, 0.26116933731827885, 0.046616321633337066, 0.05731283672503196, 0.02315818204806419, 0.10737664211774245, 0.04742921453726012, 0.21918423241004348, 0.09344771766336635, 0.2268951022415422, 0.15566369402222335, 0.2903542947024107, 0.24119762383634225, 0.21407999302027747, 0.21595483616692945, 0.2776010805973783, 2.8487325506284833, 34.981648698449135, 68.98837611079216, 48.742705285549164, 34.71970595419407, 53.361190259456635, 74.69904407858849, 93.47176194190979, 86.25224813818932, 0.9869778016582131, 0.18142868648283184, 1.0827321885153651, 1.7460244777612388, 0.9747156221419573, 20.91622084379196, 88.31692814826965, 75.22835567593575, 87.14838445186615, 82.24336445331573, 87.83313810825348, 88.11892077326775, 90.86633294820786, 85.00558823347092, 88.01773980259895, 84.99793544411659, 83.40562328696251, 80.44155433773994, 79.84950050711632, 80.08780092000961, 80.34921929240227, 81.7229899764061, 80.41109517216682, 73.68097990751266, 62.5909785926342, 61.32634945213795, 61.54025137424469, 59.67886425554752, 60.69189369678497, 60.22707223892212, 56.824442222714424, 56.17561183869839, 54.449972435832024, 53.902345821261406, 54.699220061302185, 54.102378487586975, 55.89796453714371, 59.0816655009985, 65.73315158486366, 71.36190354824066, 68.40554818511009, 69.02466416358948, 72.24645048379898, 68.49657610058784, 63.806677758693695, 66.43157690763474, 68.65118980407715, 71.75218060612679, 69.73850145936012, 76.75515934824944, 65.1894311606884, 56.246139854192734, 63.47860336303711, 68.05421903729439, 67.26263031363487, 64.95408698916435, 69.88967254757881, 65.02148017287254, 64.38442155718803, 60.44998347759247, 61.84823624789715, 66.66052982211113, 63.136287331581116, 65.74105516076088, 62.20173507928848, 62.88287132978439, 66.65284663438797, 63.51123981177807, 69.00541439652443, 62.95562222599983, 64.61142137646675, 66.18279665708542, 65.79864487051964, 65.2516870200634, 67.89816901087761, 57.86215893924236, 47.552495151758194, 50.108880177140236, 58.94190140068531, 61.43281973898411, 64.00863692164421, 62.862550020217896, 62.95441009104252, 65.07461652159691, 57.61661231517792, 53.90203803777695, 54.927097633481026, 57.22039997577667, 62.35724553465843, 61.73409417271614, 62.7593931555748, 57.85278484225273, 59.81653846800327, 64.42028403282166, 62.828747034072876, 60.61213977634907, 57.60331302881241, 55.61554089188576, 61.53752692043781, 60.15590585768223, 61.89136013388634, 59.811678528785706, 61.30602814257145, 58.39380361139774, 59.4342827796936, 57.466090992093086, 54.47019875049591, 52.64036513864994, 53.463062793016434, 51.44221343100071, 50.79581491649151, 51.89500853419304, 52.66952097415924, 53.45040187239647, 50.90393051505089, 53.8678664714098, 54.16561469435692, 57.862177938222885, 55.91146141290665, 56.44583813846111, 57.417708188295364, 58.44969101250172, 59.296695962548256, 63.698896542191505, 66.4504922926426, 65.87830379605293, 65.27805000543594, 67.32661128044128, 62.58847452700138, 65.20056456327438, 62.347875237464905, 62.99574427306652, 63.05804952979088, 64.63923588395119, 66.80050671100616, 78.24265792965889, 79.07033711671829, 85.25765150785446, 82.77481153607368, 94.09105271100998, 15.088598001748323, 0.8296436222735792, 1.6101408004760742, 0.5759242898784578, 46.737826466560364, 89.71640825271606, 78.76010656356812, 82.75667890906334, 51.630614921450615, 31.402440257370472, 24.66313138604164, 1.5517951687797904, 0.31889990670606494, 0.11592357099289075, 0.15188438119366765, 0.1135475184128154, 0.4631162399891764, 0.4119025880936533, 0.5144207901321352, 0.33843451004941016], [0.08390749091631733, 0.0651514227502048, 0.007731719078947208, 0.09079989060410298, 0.1071479864185676, 0.022202485088200774, 0.4233465052675456, 1.526896886061877, 10.386156532913446, 32.7137365937233, 21.642206087708473, 24.382822327315807, 39.20623920857906, 50.822531282901764, 73.94172191619873, 62.95862406492233, 1.6647648881189525, 0.033423681888962165, 0.11130572776892222, 0.1523898876621388, 0.7622605911456048, 3.859136807732284, 38.78166139125824, 28.47203180193901, 49.79573518037796, 65.41672736406326, 70.52172303199768, 76.11498489975929, 75.17074316740036, 72.13994219899178, 75.05112558603287, 74.753677546978, 77.15248122811317, 75.0598955154419, 72.88640454411507, 73.22325646877289, 71.08642593026161, 71.70952409505844, 70.03129094839096, 66.777213960886, 58.20563770830631, 56.395821422338486, 55.37011206150055, 52.000566869974136, 54.83178734779358, 51.274520829319954, 49.92831006646156, 47.489673122763634, 48.22172664105892, 47.16802038252354, 50.341036319732666, 47.02523924410343, 49.680601358413696, 58.53411868214607, 68.94002750515938, 64.44961085915565, 64.37322735786438, 61.14893697202206, 61.20403401553631, 59.79557119309902, 63.94131973385811, 63.32837462425232, 63.16899977624416, 62.52176910638809, 63.40393356978893, 62.21976511180401, 64.05945539474487, 63.411525562405586, 54.53861027956009, 59.23589162528515, 61.4889807254076, 62.64384515583515, 60.357530638575554, 57.976578399538994, 59.15299907326698, 52.55434915423393, 59.365441873669624, 58.64266745746136, 59.6612635999918, 60.65467469394207, 55.56124560534954, 57.715380415320396, 58.77082318067551, 61.77518516778946, 56.25473499298096, 48.54819752275944, 45.90283267199993, 57.66672022640705, 49.05827075242996, 53.98542456328869, 51.44712656736374, 57.66352839767933, 51.045822501182556, 40.501582100987434, 46.953468695282936, 59.346826672554016, 56.710889115929604, 59.21035699546337, 55.62208414077759, 55.33979348838329, 54.5306421071291, 49.05327782034874, 51.446890980005264, 52.99202486872673, 56.526618003845215, 60.98376363515854, 53.37841473519802, 52.973584458231926, 57.553805485367775, 56.541083827614784, 59.97029721736908, 56.430593356490135, 55.34349448978901, 58.95532988011837, 56.42946481704712, 56.83293096721172, 56.83208741247654, 55.55790178477764, 57.19409018754959, 58.44408631324768, 56.21545650064945, 52.1717818826437, 51.00042633712292, 48.824024721980095, 46.474663987755775, 44.80897776782513, 47.73991249501705, 43.60068820416927, 44.88353356719017, 44.875812381505966, 46.750149205327034, 47.95378781855106, 52.301693111658096, 49.596185088157654, 50.99823385477066, 50.562446638941765, 51.673792004585266, 54.40995678305626, 53.65182526409626, 59.50680568814278, 63.36794950067997, 60.07131099700928, 61.39719285070896, 60.32425582408905, 56.85408443212509, 56.72295346856117, 55.53261034190655, 55.09361609816551, 55.70782274007797, 58.48438315093517, 61.61042220890522, 68.88032510876656, 68.28551262617111, 77.41860374808311, 72.93640986084938, 85.94745129346848, 19.737009219825268, 0.4895079613197595, 0.8599233068525791, 0.855527714593336, 15.900318045169115, 72.05261528491974, 62.012740820646286, 55.103719756007195, 27.3032259196043, 10.193833652883768, 10.816295351833105, 0.7347104663494974, 0.5031551665160805, 0.10377557089668699, 0.06330393516691402, 0.05760722444392741, 0.13856357254553586, 0.21635742159560323, 0.18869143270421773, 0.1278511606506072, 0.032655622126185335, 0.01513249873823952, 0.03389629637240432, 0.011163458639202872, 0.13494146143784747, 0.021386551234172657, 0.3442460607038811, 2.032073959708214, 26.1417593434453, 50.728410333395004, 33.667063638567924, 24.308448918163776, 44.26954351365566, 60.633471831679344, 84.06445473432541, 73.7310004234314, 2.1862943843007088, 0.03173060926201288, 0.32151948020327836, 0.04498593450989574, 0.6284764793235809, 9.9161322042346, 63.535471111536026, 52.30912171304226, 67.14479863643646, 76.94350764155388, 83.05508449673653, 81.20193153619766, 83.41471999883652, 77.83725008368492, 78.92071634531021, 78.12074527144432, 79.19715911149979, 78.45237627625465, 78.42087596654892, 78.52515757083893, 73.86787667870522, 75.36267846822739, 72.47350350022316, 69.84778359532356, 58.897990956902504, 58.4294380992651, 57.42853380739689, 55.075825452804565, 58.390193805098534, 52.98752970993519, 50.73676988482475, 50.58146841824055, 51.18247836828232, 49.78944651782513, 51.2806499004364, 50.23000627756119, 51.169612258672714, 60.17097964882851, 69.35056507587433, 65.8922566473484, 65.05861178040504, 61.50777071714401, 62.67628401517868, 60.94003938138485, 66.89564600586891, 65.3235487639904, 65.94745248556137, 63.544070050120354, 64.71434265375137, 63.20755250751972, 64.49191018939018, 66.12880915403366, 60.05339115858078, 63.58922302722931, 64.1536295413971, 63.64901281893253, 62.484873086214066, 61.29739120602608, 59.449975937604904, 55.069924369454384, 62.796296775341034, 61.61471977829933, 62.17281863093376, 64.12700057029724, 58.944914638996124, 60.79517215490341, 62.51459129154682, 64.32750061154366, 54.33147579431534, 48.49932834506035, 46.27207025885582, 60.09304963052273, 49.67393271625042, 55.25623977184296, 50.126211047172546, 56.5214578807354, 52.82013729214668, 39.8620992153883, 46.038907170295715, 59.136553555727005, 60.28580568730831, 60.08988060057163, 57.91522689163685, 56.44036643207073, 55.752998515963554, 51.94836527109146, 52.730443105101585, 55.52946411073208, 59.4311897456646, 64.55777585506439, 53.768159821629524, 56.31649307906628, 57.00981147587299, 57.831179201602936, 60.32715506851673, 57.83448122441769, 60.48280991613865, 59.655370116233826, 57.53147788345814, 59.962154254317284, 59.745117500424385, 58.259602412581444, 60.2197690308094, 60.59700518846512, 59.16577398777008, 54.955128729343414, 53.94392319023609, 50.05426950752735, 50.56610964238644, 47.81836308538914, 49.39745955169201, 47.920182421803474, 48.34479443728924, 48.57855789363384, 49.9727638810873, 51.001915857195854, 54.05934579670429, 51.10534630715847, 52.67134867608547, 52.16970719397068, 53.44716064631939, 55.6407905369997, 55.65809480845928, 62.427537962794304, 64.9730783700943, 63.43299821019173, 65.47491744160652, 62.55805715918541, 61.87915898859501, 60.07761865854263, 58.9256876707077, 57.82709822058678, 62.271195352077484, 64.53493908047676, 67.37803012132645, 73.56744199991226, 73.21561127901077, 80.6623300909996, 76.29853025078773, 86.71593725681305, 22.242391481995583, 0.6402038969099522, 0.6593247083947062, 0.8060169056989253, 15.596937574446201, 78.67352440953255, 70.1770131289959, 69.87204149365425, 35.82680694758892, 18.52364882826805, 8.603821322321892, 2.5052022468298674, 0.5218135309405625, 0.046375468737096526, 0.06228095880942419, 0.06293521393672563, 0.19264981092419475, 0.4001222108490765, 0.32661040546372533, 0.17739858711138368, 0.17906502034747973, 0.08518008864484727, 0.1972494344227016, 0.14807429892243817, 0.23546692274976522, 0.1699569684569724, 0.5442938965279609, 2.796724266372621, 41.13193787634373, 71.34098187088966, 40.93554921448231, 37.07186333835125, 56.60037204623222, 74.26307827234268, 90.64257815480232, 86.813994795084, 3.0318114766851068, 0.0892868592927698, 0.6527524266857654, 0.3295164479641244, 1.0976828425191343, 13.04252179339528, 83.47157254815102, 65.86522489786148, 79.56832319498062, 84.40878465771675, 93.23276996612549, 86.02958768606186, 89.86981362104416, 81.95169970393181, 83.48797246813774, 80.06679564714432, 83.71295839548111, 81.0115085542202, 81.34232640266418, 82.29826390743256, 75.88154062628746, 76.89460426568985, 75.35760954022408, 74.39162537455559, 61.55583433806896, 60.795381143689156, 61.235682517290115, 56.513782292604446, 61.322051882743835, 55.28039887547493, 53.61231118440628, 54.30799685418606, 53.134703412652016, 53.065262138843536, 54.646824672818184, 53.643477112054825, 54.75551404058933, 63.580225110054016, 72.92760193347931, 70.07232874631882, 67.66790136694908, 63.278205916285515, 65.15046045184135, 61.85298219323158, 67.87525624036789, 65.99418237805367, 68.71783822774887, 69.21833217144012, 66.35011687874794, 68.95958125591278, 70.96297055482864, 63.42353291809559, 62.285053208470345, 67.37873688340187, 70.03566071391106, 66.7075788974762, 66.36377334594727, 66.92129462957382, 61.16368778049946, 57.14623935520649, 63.27314838767052, 64.70226690173149, 63.97142931818962, 67.91814833879471, 62.53408804535866, 63.09181831777096, 65.64901649951935, 65.33634647727013, 60.911704301834106, 50.3412377089262, 47.43212141096592, 64.95247587561607, 55.40135398507118, 57.70808480679989, 56.380523443222046, 59.95551601052284, 52.80310280621052, 41.77939273416996, 47.37341456115246, 64.02964979410172, 61.990204229950905, 63.77830848097801, 61.20705485343933, 59.24086935818195, 57.392162159085274, 53.857223242521286, 57.7083507925272, 58.64971607923508, 61.19420774281025, 62.980286702513695, 58.45492713153362, 58.88617739081383, 61.92956328392029, 59.48163963854313, 62.812780290842056, 61.91578522324562, 61.76812134683132, 62.985021248459816, 62.02420860528946, 62.139927595853806, 63.55333015322685, 60.82084737718105, 63.81635203957558, 65.72159260511398, 62.35937722027302, 56.407407000660896, 56.773608550429344, 54.88260582089424, 52.962109073996544, 50.13025023043156, 53.496611192822456, 49.98463824391365, 49.80437591671944, 51.54526010155678, 52.258789613842964, 53.44953931868076, 57.92455539107323, 54.23028342425823, 56.46574147045612, 53.28579470515251, 56.19844861328602, 60.16910634934902, 58.537542298436165, 65.02531036734581, 68.02535578608513, 65.78951016068459, 69.27270725369453, 66.89620837569237, 64.26732704043388, 65.71552813053131, 63.37641164660454, 63.75158071517944, 66.26600459218025, 68.93800601363182, 71.65337070822716, 77.95004323124886, 76.43686562776566, 86.22305810451508, 80.0000712275505, 90.42977437376976, 23.234354853630066, 0.5719071929343045, 1.5811750735156238, 0.8108487026765943, 22.122656106948853, 89.78355064988136, 77.26041063666344, 83.14415171742439, 47.824929133057594, 29.12030551582575, 30.45067112892866, 1.5194877586327493, 0.8086099103093147, 0.36032198870088905, 0.1301753890584223, 0.1941091998014599, 0.6457707763183862, 0.5548692040611058, 0.7283669442404062, 0.2831999910995364], [0.033850223844638094, 0.055385460655088536, 0.061962692489032634, 0.09470435179537162, 0.07916797258076258, 0.04206808443996124, 0.19818842934910208, 1.4179756119847298, 25.8736115321517, 34.099605828523636, 18.805149123072624, 41.88736394047737, 47.891182377934456, 51.458674147725105, 71.73416197299957, 68.60699817538261, 3.128411080688238, 0.04661742743337527, 0.11111096595413983, 0.09720137444674037, 0.34954181872308254, 0.8004149375483394, 11.102525442838669, 22.505567260086536, 53.952586725354195, 59.139194414019585, 70.5919736623764, 73.10974895954132, 74.33705270290375, 71.97706773877144, 72.07124188542366, 76.06462240219116, 76.91905975341797, 73.79045203328133, 75.65818101167679, 72.47337430715561, 72.97300189733505, 66.96398913860321, 68.21485921740532, 66.44871398806572, 59.19926919043064, 55.013071820139885, 54.76962648332119, 52.63896681368351, 54.50439311563969, 49.5005252212286, 47.7932046353817, 46.830199509859085, 49.49295602738857, 48.98431532084942, 50.5010799318552, 45.63984498381615, 50.96104145050049, 61.63168206810951, 65.9497095644474, 62.59708106517792, 56.757334023714066, 59.99496929347515, 58.91376011073589, 67.12899908423424, 64.69673439860344, 63.91084536910057, 61.672913655638695, 59.131040051579475, 58.5766763985157, 60.128247141838074, 63.47273647785187, 59.89252679049969, 63.61414209008217, 59.158299788832664, 59.087220802903175, 58.24488580226898, 62.062518149614334, 55.07593184709549, 53.60836699604988, 56.12842217087746, 52.692144960165024, 60.67760266363621, 59.69991512596607, 60.52099406719208, 59.10437688231468, 60.959106758236885, 58.63852567970753, 56.65024816989899, 41.96710266172886, 52.522864043712616, 43.402859419584274, 44.317291751503944, 42.70887605845928, 45.72798125445843, 39.26900804042816, 47.81763732433319, 47.03513391315937, 37.52068765461445, 41.43108822405338, 44.57410477101803, 58.08652549982071, 57.06699460744858, 57.5812704116106, 53.589573204517365, 52.124322429299355, 46.347674801945686, 45.8449237793684, 43.214283138513565, 60.01961097121239, 56.069225147366524, 53.3163146674633, 57.320080026984215, 54.77151498198509, 57.05454267561436, 56.66482038795948, 57.936395555734634, 55.57964041829109, 54.51607368886471, 57.176721319556236, 57.88506790995598, 60.14995537698269, 59.8295983672142, 60.34030236303806, 57.35229089856148, 57.60024659335613, 56.798109635710716, 54.979010447859764, 49.86478507518768, 47.1793969720602, 44.577839970588684, 43.85639548301697, 44.5395228266716, 43.051902651786804, 45.57762712240219, 46.202040016651154, 46.626728028059006, 48.37041646242142, 48.3424461632967, 51.90797723829746, 51.559201553463936, 54.520238265395164, 54.71603415906429, 53.170402497053146, 63.04178640246391, 63.16554956138134, 61.15193881094456, 60.52966520190239, 60.741845816373825, 57.88513630628586, 58.119245544075966, 53.93092788755894, 56.35085463523865, 57.777978256344795, 66.12675726413727, 64.97414991259575, 72.97276630997658, 73.52448150515556, 72.39452093839645, 70.51328748464584, 87.92912855744362, 24.537183344364166, 0.34329964430071414, 0.5629890121053904, 0.5719193047843874, 9.921029191464186, 70.58652475476265, 62.87173792719841, 55.24852238595486, 38.438460007309914, 11.54855690896511, 9.153484627604485, 1.776412515901029, 1.1413614987395704, 0.14944451133487746, 0.25429859349969774, 0.029911208257544786, 0.18525396793847904, 0.20151005970546976, 0.16405116504756734, 0.07468945274013095, 0.05398894652898889, 0.04133043788897339, 0.06635689322138205, 0.06409910187358037, 0.008177010004146723, 0.05759168016084004, 0.23810543585568666, 1.8987546698190272, 42.36257404088974, 48.985143676400185, 24.77066371589899, 39.48156863451004, 54.017373248934746, 62.85361289978027, 80.48133820295334, 79.91152077913284, 3.8371958350762725, 0.07949738224851899, 0.4644847603049129, 0.046843070012982935, 0.6109812681097537, 1.0981319309212267, 38.79181444644928, 46.985797360539436, 70.4327242076397, 74.79276224970818, 79.21197071671486, 80.15619724988937, 79.51240539550781, 77.68412590026855, 77.09746778011322, 77.95056760311127, 78.80259588360786, 77.06524550914764, 77.4861641228199, 74.31404873728752, 77.39490821957588, 71.36360585689545, 73.45397248864174, 67.0340345799923, 61.850360333919525, 56.82273991405964, 57.79095835983753, 54.8452690243721, 57.13146574795246, 54.115104004740715, 51.502588391304016, 47.45151177048683, 50.97828112542629, 51.31004512310028, 51.030737310647964, 47.48474098742008, 54.79651764035225, 65.12956917285919, 68.36247369647026, 64.93118941783905, 60.6127705425024, 63.00574153661728, 63.39274697005749, 68.3824910223484, 67.00798317790031, 65.95128268003464, 60.94974026083946, 62.47914299368858, 60.24302378296852, 61.99382923543453, 64.2280675470829, 61.844520047307014, 66.19775265455246, 63.71540665626526, 62.217283844947815, 60.634759962558746, 65.96518993377686, 59.18672986328602, 55.901289358735085, 58.7955142557621, 59.59676206111908, 65.57521685957909, 63.8119974732399, 63.00828360021114, 60.90962961316109, 64.3054161965847, 60.85200950503349, 56.505445539951324, 43.32952335476875, 53.37495692074299, 46.98743127286434, 44.44040134549141, 45.265055894851685, 45.5766885727644, 43.492454811930656, 51.2189070135355, 45.29192045331001, 37.27323353290558, 41.17649808526039, 45.83305321633816, 56.88751123845577, 59.61471989750862, 60.98531395196915, 55.40549196302891, 51.90995313227177, 49.82085183262825, 47.844524681568146, 47.16069057583809, 61.669406443834305, 54.46908161044121, 57.49928221106529, 59.57366690039635, 59.01727415621281, 58.3064728975296, 58.544777110219, 60.79896055161953, 57.244756668806076, 57.80298471450806, 60.042041167616844, 58.56233976781368, 60.189233869314194, 59.63658392429352, 61.33087880909443, 59.79706451296806, 60.54071120917797, 58.674418553709984, 58.25044110417366, 53.847754150629044, 50.46609900891781, 46.20131425559521, 46.63993611931801, 46.57240994274616, 46.9383455067873, 46.51262015104294, 47.88166008889675, 49.340063631534576, 50.77998496592045, 52.00985737144947, 51.69995740056038, 52.782443314790726, 57.13994689285755, 54.841370433568954, 57.043530866503716, 65.32044813036919, 67.177674472332, 64.61488679051399, 64.63488131761551, 64.57394018769264, 60.60673266649246, 60.58964118361473, 59.071801230311394, 60.59560686349869, 61.35068714618683, 71.34871825575829, 71.11030384898186, 79.09227713942528, 76.99494168162346, 77.01087042689323, 74.70513135194778, 86.32138162851334, 27.360049970448017, 0.41831400187220424, 0.5413476889953017, 0.6875210953876376, 11.797753237187862, 79.60831984877586, 71.12852767109871, 70.68705216050148, 43.748158290982246, 20.779228694736958, 7.248523347079754, 2.1316269552335143, 0.8777341386303306, 0.10211445143795572, 0.1663520306465216, 0.04506325516558718, 0.1604053794289939, 0.3603216918418184, 0.4705151851521805, 0.20001626486191526, 0.11474090671981685, 0.16510051733348519, 0.16001245676307008, 0.12588902609422803, 0.13935627532191575, 0.14181958220433444, 0.3058418777072802, 3.4352016309276223, 56.4748115837574, 67.83166497945786, 32.08702102303505, 60.469370037317276, 66.45660996437073, 73.59453454613686, 85.11132135987282, 91.52508839964867, 4.93676302023232, 0.15560231840936467, 0.8419245039112866, 0.2613986312644556, 0.77384551637806, 1.640750770457089, 51.977722495794296, 61.93464741110802, 83.6985495686531, 85.03616139292717, 89.50281411409378, 84.69870150089264, 86.92925781011581, 84.10464137792587, 80.65687358379364, 79.0460716187954, 82.5546133518219, 80.66048339009285, 81.37107565999031, 77.6710470020771, 82.15833261609077, 72.13358893990517, 77.4005775153637, 71.79302081465721, 67.46601819992065, 59.36557486653328, 61.257899925112724, 55.79935982823372, 60.773547515273094, 57.37922005355358, 53.66282567381859, 52.026325687766075, 54.595554023981094, 55.91070145368576, 54.20004844665527, 50.68526364862919, 56.8487761169672, 69.14992824196815, 69.7862496972084, 70.64771667122841, 63.904932886362076, 64.12887766957283, 62.35895164310932, 71.8549194931984, 67.60400399565697, 66.60178497433662, 64.78685036301613, 63.75794917345047, 64.6044297516346, 64.4144931435585, 64.79607626795769, 65.0663785636425, 69.20696318149567, 66.44138798117638, 65.32857969403267, 64.28990542888641, 67.4745525419712, 62.70546264946461, 59.31078560650349, 61.288651674985886, 63.17784570157528, 65.37195056676865, 67.15816631913185, 69.7299975156784, 62.41241097450256, 68.07225286960602, 61.18302494287491, 60.310857743024826, 47.51866556704044, 53.78189228475094, 47.49914601445198, 45.77330142259598, 44.0054614841938, 46.20015151798725, 46.5921650826931, 53.37279483675957, 47.83866159617901, 38.25670436024666, 44.62001010775566, 46.874011158943176, 60.42716570198536, 60.221615731716156, 63.033951222896576, 58.24776604771614, 53.26675772666931, 49.41120721399784, 48.51479351520538, 49.711934477090836, 63.40630084276199, 57.21115507185459, 60.66710002720356, 61.79078713059425, 61.810990646481514, 61.279535964131355, 60.94810254871845, 62.85356730222702, 60.45167438685894, 61.53257958590984, 62.11048297584057, 62.61371277272701, 64.12948563694954, 62.66689471900463, 66.33836030960083, 62.42036394774914, 63.65736477077007, 63.77646937966347, 60.83006948232651, 54.39219273626804, 52.02706664800644, 49.6421018242836, 49.79832664132118, 51.26415878534317, 50.42858362197876, 52.124314829707146, 48.69896963238716, 50.78959845006466, 53.626609817147255, 55.05974091589451, 55.201135128736496, 56.28715105354786, 60.19911713898182, 58.306647688150406, 58.30292768776417, 68.81224796175957, 68.89359399676323, 65.90138375759125, 68.29242825508118, 65.18808603286743, 64.22065794467926, 64.82129171490669, 60.33546902239323, 63.16544696688652, 65.2973073720932, 77.34829232096672, 75.34568578004837, 82.77017578482628, 83.67355450987816, 82.89052292704582, 78.81221696734428, 89.28375586867332, 29.770842008292675, 0.3627314750337973, 0.8652451587840915, 0.747827006271109, 12.851207759231329, 88.04468795657158, 77.98544213175774, 82.4847275018692, 59.249016121029854, 37.41269364953041, 27.667337581515312, 2.942078341729939, 2.0505768293514848, 0.3090911189792678, 0.38032551063224673, 0.16870141786057502, 0.6163782253861427, 0.5217564152553678, 0.9828199935145676, 0.424561282270588], [0.06140560675703455, 0.055896451594890095, 0.024957558052847162, 0.031969165211194195, 0.036769220532733016, 0.026248112044413574, 0.1551142375683412, 0.7932517281733453, 32.68331162631512, 34.66062292456627, 27.740609049797058, 27.401671037077904, 43.739711344242096, 53.06371562182903, 72.11227208375931, 71.43363609910011, 7.956546954810619, 0.18344281590543687, 0.4294315818697214, 0.05758532366598956, 0.25229832739569247, 0.6357077287975699, 10.090028923004866, 31.76240634173155, 57.50452592968941, 60.421450808644295, 67.69633144140244, 69.44695830345154, 72.97358706593513, 70.73942095041275, 73.28404560685158, 74.86981451511383, 77.71900042891502, 73.30298379063606, 73.67743849754333, 72.56650730967522, 72.94694289565086, 68.37836444377899, 69.76466685533524, 67.40180924534798, 57.249582409858704, 54.09004054963589, 54.95457395911217, 53.03592771291733, 54.12454269826412, 48.20534951984882, 45.03131523728371, 44.85275141894817, 49.397223964333534, 50.79818598926067, 49.89397130906582, 47.3337446898222, 51.838418170809746, 63.32371987402439, 64.67505276203156, 56.94058299064636, 64.3070501089096, 68.58892634510994, 63.97301763296127, 64.29410800337791, 62.87999868392944, 60.624743700027466, 58.20950590074062, 57.66437195241451, 57.369747161865234, 53.97374019026756, 56.32128842175007, 62.57163763046265, 62.676990777254105, 62.96788036823273, 59.8918504267931, 57.36049085855484, 57.31201685965061, 64.62697014212608, 61.31863586604595, 51.832114309072495, 52.704794481396675, 52.81078219413757, 59.278327748179436, 57.09013916552067, 61.79938606917858, 53.299561366438866, 43.691716119647026, 46.94121055305004, 52.8479366004467, 48.84021185338497, 43.43462951481342, 43.8551377505064, 43.56215827167034, 44.82835292816162, 39.75668907165527, 41.52232512831688, 41.95646323263645, 37.850992530584335, 34.14033964276314, 39.98034127056599, 39.91893656551838, 54.184803664684296, 59.1179421544075, 54.70981769263744, 48.479706197977066, 46.542638540267944, 42.350057512521744, 53.728482350707054, 57.88794055581093, 48.128388449549675, 57.69621804356575, 54.14084002375603, 57.099714651703835, 54.62108485400677, 57.83748686313629, 57.42644391953945, 58.92272002995014, 56.18112914264202, 59.93954926729202, 56.356991305947304, 57.278472259640694, 52.389449402689934, 57.30982057750225, 61.046171486377716, 58.977098912000656, 58.659173771739006, 54.87602457404137, 52.53180876374245, 47.22532510757446, 44.691229686141014, 42.3091147094965, 43.319389298558235, 45.09604476392269, 44.12409491837025, 46.40307202935219, 47.434682473540306, 47.86611892282963, 49.41901579499245, 50.463017374277115, 50.8383422344923, 53.430316150188446, 52.708533480763435, 55.27944892644882, 62.435943111777306, 62.914155051112175, 63.410393223166466, 57.85188049077988, 60.944538339972496, 56.36123187839985, 58.067245334386826, 53.8147035241127, 57.52104364335537, 59.81543652713299, 71.1782594025135, 69.8581950366497, 72.85443305969238, 66.08306720852852, 73.23625937104225, 72.62633129954338, 83.87086272239685, 50.541498363018036, 0.09498627885477617, 0.5160691891796887, 0.1971352327382192, 12.389274146407843, 72.05655187368393, 62.3947761207819, 55.006486773490906, 40.099252089858055, 12.631090320646763, 3.549173902720213, 2.82360996119678, 1.4804883138276637, 0.13974323112051934, 0.1538389755296521, 0.053703011872130446, 0.1969094862579368, 0.20589149178704247, 0.1849965169094503, 0.003969873623645981, 0.0304120948567288, 0.013411984273261623, 0.10479061369551346, 0.02106275405822089, 0.059947872869088314, 0.05566785897826776, 0.16188666166272014, 1.4644785854034126, 46.62807695567608, 47.532808408141136, 38.087693229317665, 39.62707422673702, 49.57676813006401, 65.5717134475708, 78.05171057581902, 83.8587261736393, 9.046096689999104, 0.15272893040673807, 0.4453170154010877, 0.13837977225193754, 0.15900745522230864, 0.5452965083532035, 26.19867268949747, 50.052745789289474, 74.57590028643608, 73.02085652947426, 80.50909951329231, 75.34522220492363, 79.85353589057922, 75.41233420372009, 79.52657863497734, 76.06547355651855, 81.7096982896328, 75.17585769295692, 77.61342689394951, 76.91607311367989, 76.96980983018875, 72.03578978776932, 74.60888251662254, 70.38656428456306, 60.00945031642914, 55.42299002408981, 58.086814284324646, 58.065554425120354, 56.53090417385101, 51.70329362154007, 47.96964056789875, 50.81171706318855, 51.52417503297329, 52.50780165195465, 50.87550804018974, 49.545917585492134, 55.035521015524864, 64.10490095615387, 66.12051799893379, 64.8849231004715, 65.80899551510811, 66.90740257501602, 64.0852028131485, 65.31884461641312, 66.70662894845009, 62.63979457318783, 59.58004295825958, 59.12440940737724, 59.42418672144413, 54.92072157561779, 57.10655428469181, 64.45243030786514, 61.5264543145895, 64.29690465331078, 61.75560101866722, 60.58548800647259, 59.90621745586395, 69.1599977016449, 65.06422027945518, 55.795180052518845, 58.29559788107872, 56.03468880057335, 60.602997466921806, 60.169725716114044, 64.47747856378555, 54.604928120970726, 43.94651144742966, 48.37552338838577, 55.02111978828907, 50.71112126111984, 44.16977606713772, 43.78488332033157, 45.05276508629322, 46.01962320506573, 42.00088284909725, 41.58756002783775, 43.57317388057709, 41.633465364575386, 37.979790419340134, 39.46733079850674, 41.23641327023506, 53.661142364144325, 61.15059368312359, 57.081639021635056, 51.48626446723938, 46.97396479547024, 46.94817937910557, 57.50636503100395, 58.46918776631355, 49.76971037685871, 60.779995769262314, 57.08209499716759, 58.97771827876568, 55.63207760453224, 60.349969044327736, 59.52762097120285, 60.82821138203144, 59.10567261278629, 60.0252840667963, 59.21262167394161, 58.77168953418732, 55.00077947974205, 59.74109351634979, 63.53034898638725, 59.492457658052444, 61.66499488055706, 60.255487114191055, 53.087555542588234, 49.87665943801403, 47.11300313472748, 46.44214913249016, 45.46570412814617, 47.20883019268513, 46.23281456530094, 49.85557436943054, 48.21083642542362, 50.76005503535271, 50.953115075826645, 53.455345407128334, 52.71071836352348, 53.43793474137783, 53.44516195356846, 58.293287605047226, 64.37749832868576, 64.94573503732681, 64.60755318403244, 63.76107260584831, 63.56523111462593, 59.46157671511173, 59.22934077680111, 58.585469126701355, 60.984094217419624, 66.62101194262505, 73.68697598576546, 75.14558851718903, 76.39281079173088, 73.66303727030754, 78.00646260380745, 79.18180793523788, 82.63066247105598, 56.24426655471325, 0.02205088472692296, 0.6884896277915686, 0.2959561737952754, 12.692542523145676, 77.82819136977196, 67.99733608961105, 70.40860310196877, 47.08239197731018, 25.394848622381687, 13.291089255362749, 4.818104412406683, 0.8558130555320531, 0.09016670504934154, 0.0977469197823666, 0.06463071709731594, 0.2346169707016088, 0.22278632037341595, 0.2632804505992681, 0.05071613464679103, 0.1660626524244435, 0.1303488586563617, 0.20519590645562857, 0.1873648288892582, 0.15076304058311507, 0.1252021684194915, 0.35370479221455753, 2.6354119973257184, 63.26185919344425, 65.61121612787247, 44.38399717211723, 43.301895037293434, 62.540988475084305, 74.25149649381638, 86.99931845068932, 96.99809432029724, 11.390363797545433, 0.3440811258042231, 0.7727803266607225, 0.20714177313493565, 0.9476120921317488, 1.1576150078326464, 47.29510456323624, 65.98861187696457, 88.81429105997086, 80.07583916187286, 90.50760939717293, 80.43254122138023, 84.95315864682198, 78.97180840373039, 81.58574894070625, 79.91416543722153, 85.06650656461716, 78.85027572512627, 81.17253631353378, 78.68310749530792, 79.72894817590714, 73.51558238267899, 77.21105128526688, 74.86375004053116, 61.99917174875736, 58.090002313256264, 60.819992423057556, 60.26751346886158, 57.18338996171951, 54.70389001071453, 52.061321809887886, 52.98983618617058, 53.746972158551216, 56.12173832952976, 54.60870511829853, 51.80737763643265, 57.19725921750069, 66.59281745553017, 68.72359111905098, 65.30989229679108, 65.5603900551796, 70.49931943416595, 66.2506154179573, 68.14630329608917, 69.33066174387932, 64.37891945242882, 62.725818157196045, 60.94592526555061, 63.623341396450996, 58.50048288702965, 64.12399113178253, 66.31193652749062, 67.22639545798302, 67.5945197045803, 65.86001917719841, 63.81300821900368, 63.17004092037678, 68.49675089120865, 64.15070369839668, 58.439184576272964, 60.97451873123646, 58.76924626529217, 65.80320462584496, 61.45695224404335, 68.36669147014618, 55.362751856446266, 46.635053381323814, 48.66191402077675, 55.47201879322529, 53.892207965254784, 44.38913829624653, 42.52638325095177, 46.74050532281399, 48.10557447373867, 43.05105149745941, 43.50905232131481, 41.9785400480032, 40.37936545908451, 36.41799822449684, 40.04996493458748, 42.503219693899155, 57.12800793349743, 63.4544138610363, 60.04665032029152, 50.280562564730644, 47.384148985147476, 46.85894496738911, 57.015001997351646, 60.813859552145004, 53.10076743364334, 61.05715669691563, 58.64737540483475, 61.12188242375851, 59.58419993519783, 60.65438210964203, 62.28734068572521, 63.829392939805984, 61.72757372260094, 62.980852872133255, 61.41003616154194, 60.95240771770477, 57.701324969530106, 63.84927347302437, 63.03667567670345, 63.002264723181725, 67.37091690301895, 62.578899040818214, 56.292748153209686, 52.295013070106506, 49.84836995601654, 48.75389948487282, 48.41398112475872, 52.15594433248043, 49.47063222527504, 50.70425122976303, 52.65672706067562, 52.90917031466961, 52.62882135808468, 56.250847801566124, 56.31533794105053, 57.67347626388073, 56.46153889596462, 60.997249111533165, 67.74237737059593, 64.87868383526802, 68.95993083715439, 65.89926347136497, 64.99741986393929, 62.588580921292305, 64.33006167411804, 62.37784422934055, 67.34037414193153, 70.54946914315224, 79.34953093528748, 81.42399922013283, 81.30293011665344, 79.08327922224998, 79.6378442645073, 80.91961428523064, 86.27740278840065, 58.36754322052002, 0.2180667212815024, 1.1916926479898393, 0.2512803382705897, 14.987262189388275, 87.43421271443367, 75.89948326349258, 79.81234610080719, 61.81501843035221, 40.43940983712673, 35.810312032699585, 8.382341656833887, 1.8960417341440916, 0.2721362019656226, 0.24269229441415519, 0.21089125162689015, 0.3801128111081198, 0.34975264803506434, 0.5638847546651959, 0.20939745678333566], [0.07952450774610043, 0.06986483233049512, 0.00947372011069092, 0.06330628035357222, 0.13049451255938038, 0.058506874411250465, 0.28739241301082075, 1.2726503913290799, 41.294873133301735, 35.281635001301765, 12.966067045927048, 28.056672289967537, 55.783526077866554, 53.85086618363857, 73.96291717886925, 75.09329572319984, 11.836950983852148, 0.19501729169860482, 0.5362946132663637, 0.08824348871712573, 0.9581819374579936, 0.2971843391424045, 26.525553949177265, 41.75659015774727, 59.269288033246994, 62.19656355679035, 70.58723911643028, 65.69434806704521, 71.39784201979637, 69.2380303144455, 72.06855922937393, 73.20858925580978, 77.18823730945587, 70.44050619006157, 72.47467383742332, 72.49150693416595, 74.26063120365143, 69.74668622016907, 68.88787910342216, 67.04633072018623, 57.79555231332779, 53.61616037786007, 55.820152312517166, 53.660439401865005, 54.08661313354969, 46.13789185881615, 46.27939246594906, 47.17105261981487, 48.77821438014507, 51.7582880705595, 51.59808486700058, 49.00329150259495, 54.38157990574837, 60.909405425190926, 61.08134999871254, 67.54880055785179, 64.12980481982231, 59.851090013980865, 62.94438622891903, 60.560815930366516, 58.841643780469894, 56.09678506851196, 53.99942681193352, 53.52012813091278, 50.90274877846241, 52.24850736558437, 52.98574760556221, 50.84927424788475, 55.0293805450201, 59.18700724840164, 59.66736987233162, 60.484478026628494, 57.10897855460644, 54.67740163207054, 65.18063083291054, 58.916761949658394, 47.25314721465111, 56.85979172587395, 55.52359722554684, 62.90588669478893, 53.82232591509819, 47.0563405752182, 43.61516162753105, 46.846705824136734, 47.91997343301773, 44.934260845184326, 43.47460716962814, 46.41863979399204, 51.93272531032562, 47.295343950390816, 42.59960912168026, 43.92111361026764, 49.18677605688572, 47.371602058410645, 44.42897915840149, 39.714287146925926, 41.78212098777294, 43.24696138501167, 54.6763376891613, 58.49497698247433, 49.41293612122536, 46.042216792702675, 52.93831095099449, 62.155404165387154, 51.49832122027874, 55.02285249531269, 60.03439977765083, 57.40214042365551, 56.64613679051399, 55.401031002402306, 56.51343271136284, 58.94136942923069, 56.31931632757187, 55.12404106557369, 57.024862468242645, 57.116376757621765, 53.22583772242069, 53.53357940912247, 56.18652865290642, 59.17526587843895, 53.9152879267931, 57.59002514183521, 58.88732872903347, 55.96011020243168, 47.439432218670845, 43.94907630980015, 44.66460071504116, 41.97026789188385, 43.16768243908882, 42.122008949518204, 47.56011374294758, 45.520383194088936, 47.437023147940636, 49.913091883063316, 51.06440730392933, 48.72117184102535, 53.51642332971096, 50.31900890171528, 55.515655651688576, 62.67469950020313, 62.218484580516815, 62.45406813919544, 62.70566023886204, 57.256083860993385, 57.498298063874245, 54.12447810173035, 57.03273184597492, 59.154279604554176, 65.29989883303642, 68.83890733122826, 71.75740152597427, 68.7583364546299, 74.01382684707642, 72.7791590988636, 81.10768899321556, 70.78049674630165, 87.23500460386276, 9.076468460261822, 0.5120178940705955, 0.11445049691246822, 8.851536680012941, 77.68859446048737, 60.32302089035511, 57.65790469944477, 40.14579959213734, 15.899368096143007, 4.4103786908090115, 7.915465934202075, 0.7197437819559127, 0.029656768492714036, 0.2271880576154217, 0.015737360226921737, 0.20813694864045829, 0.06480112904682755, 0.01657237284234725, 0.11547088317456655, 0.046954959907452576, 0.038869765630806796, 0.05153053411049768, 0.08231275656726211, 0.09961189978639595, 0.15177755645709112, 0.2592626411933452, 2.56785589735955, 57.29153215885162, 51.484649553895, 19.774059131741524, 28.549638837575912, 63.01233418285847, 65.09633615612984, 82.0543321967125, 87.44114354252815, 15.001574121415615, 0.10504894788027741, 0.6046364398207515, 0.0424532108445419, 1.0326012410223484, 0.4654369654599577, 42.38053187727928, 57.86130018532276, 75.39105534553528, 74.36289891600609, 78.41874048113823, 73.97714361548424, 79.59201112389565, 72.45882868766785, 76.18686944246292, 76.00767105817795, 80.51107540726662, 73.85064840316772, 74.81031730771065, 75.53936898708344, 75.95388874411583, 73.59510451555252, 72.63851344585419, 68.61325263977051, 59.41345229744911, 56.13520100712776, 58.9150520414114, 55.27503736317158, 57.11735710501671, 49.46487553417683, 49.40741501748562, 50.292121544480324, 52.50454522669315, 53.839523792266846, 53.33133526146412, 49.189508110284805, 56.829613745212555, 65.37306770682335, 65.24699047207832, 69.52344819903374, 65.6716100871563, 63.71270880103111, 65.5384424328804, 64.75112468004227, 60.0237375497818, 58.432941511273384, 55.75549878180027, 56.12908713519573, 55.34474842250347, 54.854149147868156, 52.04939804971218, 53.30805391073227, 58.110771998763084, 61.562928557395935, 61.794955506920815, 63.15760798752308, 59.29007291793823, 56.266662552952766, 65.44415429234505, 62.864829897880554, 47.585682570934296, 59.39875848591328, 58.37588757276535, 65.19342094659805, 54.184381887316704, 47.42875479161739, 47.91220284998417, 46.9997464120388, 46.54511600732803, 46.50378942489624, 46.471232771873474, 49.270971938967705, 54.22275982797146, 50.447658598423004, 42.52722680568695, 44.93833802640438, 49.69668969511986, 48.39205630123615, 44.41238924860954, 40.86147978901863, 42.596303299069405, 42.78742544353008, 57.50883869826794, 59.163239523768425, 50.758903697133064, 46.87512069940567, 55.79532444477081, 62.200355753302574, 52.46690824627876, 56.911206766963005, 60.96962459385395, 58.24150778353214, 58.02659511566162, 57.82023198902607, 60.741956010460854, 60.25610268115997, 58.02608594298363, 57.16744601726532, 57.092966213822365, 58.482559248805046, 55.61614505946636, 58.07234846055508, 57.63181909918785, 59.369507655501366, 55.6286995857954, 60.49522764980793, 61.638871282339096, 58.91244538128376, 50.49460507929325, 46.73847243189812, 46.120876371860504, 45.264292135834694, 44.492542147636414, 45.220731273293495, 49.51582320034504, 48.9609731733799, 49.503101482987404, 52.12113060057163, 52.01906807720661, 51.113128289580345, 55.356242805719376, 54.03145909309387, 57.43298716843128, 64.6793769299984, 65.88411748409271, 64.39192235469818, 64.5317168533802, 61.18872843682766, 62.03894421458244, 57.94801913201809, 61.18520222604275, 61.38710059225559, 71.53743132948875, 72.89571404457092, 77.3074597120285, 74.38359260559082, 81.24009668827057, 75.93798279762268, 87.17926919460297, 75.42953208088875, 94.50557246804237, 12.43887573480606, 0.4515812761383131, 0.13153184205293655, 8.186834547668695, 87.41853475570679, 65.86528569459915, 72.90497034788132, 47.20904678106308, 30.503469295799732, 18.2733391597867, 5.4098922573029995, 0.3301577823003754, 0.051094526061206125, 0.121304757631151, 0.05288720603857655, 0.3026905405567959, 0.03893697452440392, 0.03713133293786086, 0.010292505667166552, 0.17616850702324882, 0.16908849240280688, 0.1836299113347195, 0.23133541631978005, 0.2455450061825104, 0.2809573395643383, 0.6044885446317494, 3.9210806088522077, 70.5574183166027, 69.40532013773918, 24.91869807243347, 40.75690560042858, 77.56070852279663, 75.62812462449074, 90.31886592507362, 97.43431851267815, 18.882585167884827, 0.1847161483601667, 1.063273788895458, 0.1710892334813252, 1.584107803646475, 1.003369172103703, 69.4181102514267, 71.55709907412529, 88.2197293639183, 79.51606839895248, 86.51512563228607, 78.02563637495041, 85.6967331469059, 77.04451382160187, 79.24460336565971, 79.0758316218853, 85.16992181539536, 74.56659838557243, 79.41256195306778, 78.44189643859863, 80.37998244166374, 77.21935003995895, 77.2515495121479, 72.56645411252975, 63.71530406177044, 59.88827861845493, 62.457415759563446, 58.211025819182396, 60.50991006195545, 51.574731320142746, 53.69004741311073, 53.01248677074909, 55.34671671688557, 57.83891178667545, 57.10227191448212, 51.79155148565769, 59.940427020192146, 69.25253793597221, 68.37560579180717, 71.16859272122383, 67.7996326982975, 66.836376786232, 68.03113907575607, 67.76500895619392, 60.749418810009956, 60.973701775074005, 57.582231760025024, 60.301578640937805, 57.70508676767349, 56.22505098581314, 54.948517084121704, 55.20884111523628, 61.56210020184517, 65.95255181193352, 64.19151350855827, 66.02423876523972, 63.807749301195145, 63.881830126047134, 64.77247953414917, 56.77621901035309, 49.15129356086254, 60.957168862223625, 61.895422115921974, 67.03039437532425, 57.39957556128502, 50.228125378489494, 47.22026377916336, 47.58995734155178, 52.03864462673664, 46.61425329744816, 47.25663162767887, 50.26523418724537, 55.55407539010048, 48.43597054481506, 44.44659501314163, 45.079352259635925, 52.65073858201504, 49.79775287210941, 44.2979621887207, 41.95051275193691, 43.81775535643101, 44.374942258000374, 62.25995555520058, 60.867653265595436, 53.72404798865318, 50.33902622759342, 57.445955872535706, 64.1636610031128, 58.88809248805046, 60.23085303604603, 63.667346835136414, 61.52537137269974, 59.60600696504116, 61.05860821902752, 63.4016764909029, 62.78651610016823, 60.25153152644634, 58.256627172231674, 59.87677663564682, 59.9739184230566, 58.67039456963539, 59.952396377921104, 59.02801238000393, 62.871312350034714, 59.86169524490833, 62.64477610588074, 64.06097531318665, 62.457799538969994, 51.732821837067604, 50.08031331002712, 50.541642755270004, 47.001076340675354, 48.117266446352005, 48.3325020968914, 53.11087869107723, 51.2597244232893, 53.60607951879501, 54.85263302922249, 54.38067555427551, 54.000779539346695, 57.68031969666481, 54.05215658247471, 59.886694103479385, 67.79407739639282, 68.95790174603462, 65.98385453224182, 67.01701149344444, 64.4708289206028, 64.36960235238075, 60.158425122499466, 63.311537727713585, 67.2900116443634, 75.60069769620895, 76.24644264578819, 80.25395080447197, 76.96641281247139, 84.91323798894882, 82.21197813749313, 89.83680859208107, 76.21798977255821, 96.05492413043976, 11.63467263802886, 1.1285395617596805, 0.27916615130379796, 10.20710539072752, 96.49193868041039, 72.91428744792938, 84.79988247156143, 59.8620980232954, 45.02924054861069, 40.56769475340843, 11.735713966190815, 1.3719045091420412, 0.234544952691067, 0.37520501820836216, 0.16427648108219728, 0.37970249250065535, 0.21031338575994596, 0.33984132518526167, 0.2413936992525123], [0.10464381688507274, 0.03708997304784134, 0.025338339182781056, 0.11104464021627791, 0.09674766246462241, 0.03867338222335093, 0.43855180498212576, 3.0156222078949213, 48.974956423044205, 28.7505891546607, 23.049175590276718, 43.506293669342995, 47.04705387353897, 57.91162848472595, 73.49833130836487, 75.16961842775345, 33.73130299150944, 0.05142523077665828, 0.4960747214499861, 0.2520397334592417, 1.2492163362912834, 6.278519947081804, 47.3458394408226, 49.722965285182, 66.44104599952698, 63.847016394138336, 68.63812610507011, 67.08219319581985, 67.89898216724396, 68.34378629922867, 74.38850954174995, 69.96086552739143, 75.32481729984283, 72.19469726085663, 72.65401661396027, 70.87093189358711, 74.02408629655838, 67.25957527756691, 71.78429648280144, 64.06155288219452, 56.28729164600372, 56.080442145466805, 52.74867072701454, 51.77511736750603, 53.11184003949165, 46.01314075291157, 43.75638484954834, 46.69440999627113, 49.12978671491146, 52.509777545928955, 48.315456211566925, 46.93498648703098, 51.93556375801563, 57.868557795882225, 62.83918507397175, 60.05273759365082, 58.02867740392685, 58.78250755369663, 56.095903515815735, 54.71709430217743, 54.19450834393501, 51.3876673579216, 53.642850145697594, 50.15175707638264, 51.07438176870346, 50.0396478921175, 50.71991018950939, 52.40612670779228, 51.835948303341866, 52.739000245928764, 55.80068215727806, 59.09275330603123, 60.48926196992397, 57.93063506484032, 49.56420220434666, 51.984805315732956, 53.82194593548775, 61.471490263938904, 60.26983894407749, 51.824792101979256, 42.61187866330147, 45.55081196129322, 49.989942759275436, 51.6023900359869, 47.99747787415981, 51.864477172493935, 48.87862019240856, 48.94441366195679, 48.63105207681656, 50.08419670164585, 45.89694678783417, 46.882860884070396, 49.62673544883728, 46.07664294540882, 46.744806692004204, 43.588984832167625, 39.80729855597019, 38.08353245258331, 48.837745785713196, 54.397295862436295, 44.70023140311241, 48.97601276636124, 60.2205365896225, 56.71187326312065, 49.04608480632305, 58.30823980271816, 56.54077984392643, 57.88711600005627, 54.18633498251438, 52.12191715836525, 55.26025615632534, 54.187623113393784, 55.84480158984661, 56.26852445304394, 56.223512068390846, 54.76647265255451, 58.5358589887619, 60.03090016543865, 56.52553506195545, 48.89446534216404, 54.49392467737198, 58.55349004268646, 60.65509267151356, 58.30865778028965, 50.776971727609634, 42.95984499156475, 45.90185612440109, 44.919707626104355, 44.722794592380524, 41.709594279527664, 44.182319194078445, 45.76314076781273, 48.69869604706764, 46.8266125023365, 50.826623663306236, 50.53858391940594, 51.7431078851223, 52.01081871986389, 56.65528289973736, 62.11552530527115, 62.16481626033783, 63.372285068035126, 63.549670949578285, 56.97247847914696, 57.863276079297066, 54.31675158441067, 54.85028475522995, 57.73681126534939, 66.49109691381454, 70.95337986946106, 70.58653235435486, 70.04535019397736, 76.52928426861763, 70.73814421892166, 79.00861322879791, 71.12481907010078, 86.27012237906456, 50.96395589411259, 0.17731160740368068, 0.1566435070708394, 8.339114226400852, 77.42860481142998, 59.09455820918083, 54.5119509100914, 40.757483169436455, 18.81018005311489, 7.368221674114466, 13.676323983818293, 0.45033984119072556, 0.04808485748071689, 0.04771705651364755, 0.0939228777133394, 0.1460054880590178, 0.07604460697621107, 0.06816518798586912, 0.14377384999534115, 0.00451292487923638, 0.06496123256511055, 0.0511759322398575, 0.06365865207044408, 0.04125939951336477, 0.04628778398910072, 0.4865477420389652, 6.329735973849893, 64.76740300655365, 41.059107184410095, 26.212904825806618, 42.68019139766693, 56.84460014104843, 66.02863132953644, 81.06902986764908, 84.82303082942963, 37.67425261437893, 0.07186893533798866, 0.4228579642949626, 0.23218621441628784, 1.6313509061001241, 6.502469005063176, 65.15724688768387, 63.66291247308254, 81.66119009256363, 72.77612686157227, 76.9577644765377, 73.26932519674301, 74.75775852799416, 71.89623847603798, 76.52284741401672, 72.17792496085167, 79.34281289577484, 75.48766136169434, 75.65967813134193, 72.84203812479973, 77.08590120077133, 69.77131649851799, 76.98936358094215, 66.80804550647736, 57.8153682500124, 59.40242528915405, 56.1985170096159, 56.07354171574116, 56.403546407818794, 50.65520726144314, 47.245745211839676, 49.65724401175976, 54.47893068194389, 55.891223698854446, 51.19940645992756, 48.651122599840164, 52.65781760215759, 61.37977838516235, 63.614370077848434, 63.08041512966156, 63.29579137265682, 60.38420520722866, 56.859096363186836, 56.83592140674591, 56.23445928096771, 53.291080221533775, 55.23932307958603, 53.578109219670296, 54.75629299879074, 52.3136168718338, 52.09338828921318, 54.83533635735512, 53.98221753537655, 56.57782405614853, 56.840538159012794, 62.150722816586494, 63.5665762424469, 61.74834720790386, 51.74063801765442, 56.457955688238144, 58.334234207868576, 61.74677789211273, 61.92909210920334, 50.5646201223135, 44.67083998024464, 46.424274891614914, 50.973782166838646, 53.04074965417385, 52.85427086055279, 54.340887889266014, 53.12487713992596, 51.359244883060455, 49.72349725663662, 50.73984012007713, 47.16375321149826, 50.87468348443508, 51.33675768971443, 49.97934512794018, 46.20615139603615, 43.92860300838947, 41.50500945746899, 37.36846782267094, 48.529080748558044, 56.53883054852486, 46.91633328795433, 50.70412963628769, 61.81229777634144, 58.475560024380684, 51.53734892606735, 59.34802360832691, 57.534810304641724, 58.37187498807907, 55.51986962556839, 54.775497168302536, 57.75840550661087, 55.82892224192619, 57.72539287805557, 56.551639661192894, 59.67819169163704, 60.32875098288059, 62.720065265893936, 58.32012176513672, 56.99776232242584, 52.36731179058552, 57.343756556510925, 60.44405959546566, 63.04986096918583, 60.33465966582298, 50.445986688137054, 45.282713547348976, 47.68154002726078, 46.87639743089676, 47.34923265874386, 45.57487986981869, 46.26315973699093, 48.44426169991493, 50.72304502129555, 47.39865280687809, 52.36520290374756, 51.00176006555557, 54.051715806126595, 51.71264871954918, 60.02269260585308, 64.24398109316826, 65.04251584410667, 67.35379502177238, 67.09521889686584, 60.53900130093098, 62.26250521838665, 58.27197454869747, 59.97347004711628, 60.53708240389824, 70.59541627764702, 74.14251074194908, 76.49228185415268, 75.04293322563171, 81.16711020469666, 75.68780422210693, 83.58941182494164, 75.28771609067917, 91.45372822880745, 58.62694010138512, 0.31441748316865414, 0.13711602834519, 9.732785392552614, 85.76034933328629, 65.82573741674423, 68.1434914469719, 48.91358211636543, 30.491973012685776, 27.931951582431793, 5.640946459025145, 0.8565734897274524, 0.15295875869924203, 0.0668263016268611, 0.1037415731116198, 0.06291227415204048, 0.06187796519952826, 0.0948004524980206, 0.11325012499582954, 0.13871897826902568, 0.1384509590570815, 0.13188710814574733, 0.21506617369595915, 0.18110680219251662, 0.2465315134031698, 0.7698597083799541, 9.682947266846895, 83.9734648168087, 55.52349843084812, 38.597701862454414, 59.997089579701424, 69.37767282128334, 76.04094207286835, 87.17857003211975, 94.78814050555229, 46.41195975244045, 0.12305382901104167, 0.7506279903464019, 0.4451566224452108, 1.44143745303154, 11.989464350044727, 85.2783527970314, 73.09039279818535, 93.24554488062859, 76.2599167227745, 82.06713750958443, 75.81933796405792, 78.05955335497856, 74.72425952553749, 81.80735304951668, 73.1196816265583, 80.29438823461533, 80.2119554579258, 78.63349735736847, 75.34741088747978, 80.32984033226967, 72.4067410826683, 79.07517805695534, 69.05617967247963, 62.34258212149143, 62.86628141999245, 60.4068747907877, 60.8662511408329, 59.17688459157944, 54.59515884518623, 52.03058145940304, 53.52661058306694, 55.41416309773922, 57.86497838795185, 53.42359811067581, 51.43617935478687, 54.991967752575874, 65.33670365810394, 69.77614983916283, 66.31536394357681, 64.10303145647049, 61.84860102832317, 59.48218300938606, 61.77280269563198, 59.837334752082825, 56.147071570158005, 57.65937902033329, 56.65535129606724, 56.66601352393627, 54.6984601020813, 58.02556537091732, 57.66092173755169, 56.73607796430588, 60.81142008304596, 61.47631600499153, 63.66710364818573, 64.55754026770592, 63.17455507814884, 61.51963368058205, 50.75502410531044, 55.333466827869415, 67.60670945048332, 65.95593363046646, 57.301274836063385, 44.45572592318058, 47.421835362911224, 51.7112921923399, 56.67309254407883, 53.30168925225735, 57.28845812380314, 55.906168296933174, 53.80327373743057, 51.65013067424297, 53.77188362181187, 47.68312834203243, 50.373972952365875, 53.13172437250614, 51.02599896490574, 47.967801466584206, 44.5878030359745, 41.86458796262741, 38.87918695807457, 51.5810389816761, 58.40452283620834, 48.68028223514557, 52.27069437503815, 63.28014761209488, 62.9537945240736, 53.009530529379845, 63.67996595799923, 58.91973339021206, 63.92563417553902, 59.89856846630573, 57.403918728232384, 58.79325717687607, 57.1860346198082, 59.99328978359699, 60.27954742312431, 62.47223116457462, 63.84584605693817, 63.94918531179428, 61.15456826984882, 59.07499685883522, 59.723774045705795, 60.21244302392006, 63.73292751610279, 66.17284879088402, 63.938203901052475, 53.71750473976135, 47.974686697125435, 53.239775374531746, 50.57090498507023, 50.54750584065914, 46.66142016649246, 49.94075819849968, 52.722965106368065, 54.85006056725979, 51.69242240488529, 55.343996062874794, 54.68874782323837, 55.50602696835995, 54.95202049612999, 62.1967763453722, 66.64767131209373, 66.3694654405117, 70.82136735320091, 70.89984074234962, 62.518744468688965, 64.88172367215157, 59.93653982877731, 61.72370173037052, 62.32097268104553, 76.47816181182861, 77.54934713244438, 80.79491257667542, 77.86586254835129, 88.07415917515755, 78.77309426665306, 87.83404245972633, 77.02312096953392, 94.55930918455124, 56.66213773190975, 0.5613967194221914, 0.1928141075768508, 11.397987138479948, 97.39435225725174, 72.44962558150291, 79.05436277389526, 61.15124724805355, 39.57401007413864, 48.411651849746704, 22.19769638031721, 1.7229335918091238, 0.574523649411276, 0.20170517032966018, 0.14946236740797758, 0.27166814426891506, 0.1993376004975289, 0.23370908660581335, 0.2508853969629854], [0.054028439917601645, 0.1396199900773354, 0.040833863167790696, 0.028519551487988792, 0.0854569987859577, 0.07013767550233752, 0.5296450888272375, 11.428836733102798, 49.15953151881695, 26.352676525712013, 20.902837961912155, 30.10267250239849, 47.38961689174175, 62.29909345507622, 70.65976202487946, 71.64590790867805, 31.755532510578632, 0.25522731710225344, 0.7794736081268638, 0.21100790239870548, 1.0459614428691566, 22.76478175073862, 56.902262046933174, 60.69944769144058, 68.91360372304916, 63.7289073318243, 69.08416137099266, 67.31490030884743, 68.65364447236061, 67.95571312308311, 67.70986631512642, 70.12035056948662, 70.23695111274719, 71.84097424149513, 72.90811657905579, 69.81212630867958, 70.43117389082909, 69.77881729602814, 69.06605154275894, 60.12416996061802, 54.207260459661484, 54.71756547689438, 53.31033378839493, 51.65665112435818, 52.57521763443947, 45.6169968098402, 45.40994592010975, 47.23064102232456, 51.385433077812195, 49.756688475608826, 48.576475605368614, 48.15717950463295, 51.253891736269, 56.37212209403515, 59.156361892819405, 60.72607286274433, 60.12694001197815, 54.31568764150143, 51.47836849093437, 48.08250971138477, 52.75564715266228, 51.803859025239944, 53.89250434935093, 57.221114337444305, 53.04980456829071, 51.07229948043823, 49.454300701618195, 52.476977705955505, 50.706432312726974, 50.09192168712616, 51.49677850306034, 53.214100152254105, 55.612751841545105, 62.141838893294334, 49.56083558499813, 41.35335199534893, 51.320973336696625, 59.84379440546036, 45.62116138637066, 40.23905798792839, 49.00715209543705, 45.58051496744156, 51.140114441514015, 56.40850894153118, 57.50849291682243, 53.964445888996124, 57.98864275217056, 48.7429104745388, 43.034727573394775, 42.00338691473007, 49.9824533611536, 59.05624486505985, 54.17935475707054, 53.025729060173035, 55.66603258252144, 47.77968496084213, 46.107250303030014, 38.38693097233772, 44.67631548643112, 42.86028653383255, 47.59026512503624, 52.50264912843704, 57.31613203883171, 53.90855848789215, 58.76723237335682, 57.465505823493004, 58.46317648887634, 53.08586843311787, 55.87228171527386, 56.89749710261822, 51.21678292751312, 56.36542685329914, 56.079066619277, 56.27205826342106, 56.25757344067097, 62.31890559196472, 60.42660713195801, 55.02262070775032, 50.61546139419079, 55.39996325969696, 59.48747992515564, 56.46859511733055, 58.393685817718506, 57.28011377155781, 48.945158421993256, 41.64397940039635, 44.643390253186226, 42.67434351146221, 43.992515578866005, 41.85696557164192, 44.160941541194916, 44.270770847797394, 46.851371973752975, 47.416629642248154, 50.107310861349106, 48.71102258563042, 52.91101701557636, 49.03859160840511, 57.06254504621029, 62.133391946554184, 62.52713441848755, 61.97595879435539, 61.448569893836975, 56.6621795296669, 58.1825615465641, 54.63742397725582, 55.93568131327629, 58.4181223064661, 65.05437880754471, 69.79888021945953, 73.1742998957634, 71.62636935710907, 71.91428750753403, 72.9975637793541, 73.53320583701134, 76.2863177061081, 75.36599949002266, 78.36935073137283, 5.1024555042386055, 1.0981443990021944, 10.279862936586142, 70.63345223665237, 61.15761570632458, 54.658007472753525, 44.292809665203094, 28.696145676076412, 14.520709924399853, 12.006061859428883, 0.2803162724012509, 0.03153599216602743, 0.10369004579843022, 0.06401649341569282, 0.034336497556068935, 0.06280345303821377, 0.02596055950562004, 0.11124741722596809, 0.032374834263464436, 0.10319017223082483, 0.003809951235780318, 0.034856015772675164, 0.09569632864440791, 0.08445099534583278, 0.5206423625349998, 13.49180018529296, 65.43241292238235, 41.13974645733833, 27.94106349349022, 30.2733251452446, 53.85867856442928, 72.03933879733086, 79.75166335701942, 80.1606734097004, 37.703302055597305, 0.23262335424078628, 0.6421645323280245, 0.09988710298785008, 1.3559457217343152, 25.992947928607464, 75.51530107855797, 72.54186183214188, 81.5339957177639, 71.33291870355606, 76.13282114267349, 72.10459649562836, 74.73065838217735, 73.1251685321331, 73.05761575698853, 73.41943994164467, 74.97789591550827, 72.85635575652122, 75.5969662964344, 72.27677285671234, 75.13556465506554, 71.6601799428463, 73.2291005551815, 62.52740040421486, 57.628110498189926, 57.341062501072884, 55.103590562939644, 56.237822100520134, 55.536261945962906, 49.247793182730675, 46.37642405927181, 49.42800611257553, 54.1516200453043, 52.936247661709785, 51.03188864886761, 52.159481942653656, 53.476115092635155, 58.170782178640366, 60.043466091156006, 61.008800491690636, 60.67993953824043, 56.53925232589245, 54.01926174759865, 52.64040693640709, 55.90554893016815, 54.86092418432236, 58.31021189689636, 59.89804409444332, 57.40192383527756, 55.05879856646061, 51.57428674399853, 53.510176464915276, 53.505312725901604, 52.435491532087326, 54.13439556956291, 55.69286674261093, 57.57945030927658, 61.05448544025421, 51.96742884814739, 47.98526532948017, 55.15082962810993, 59.7054286301136, 46.78085915744305, 43.265246003866196, 51.31402350962162, 49.11590985953808, 53.9541370421648, 58.74282628297806, 58.73575106263161, 56.41979053616524, 62.879158928990364, 52.65447378158569, 42.82727390527725, 43.24948064982891, 51.698513478040695, 63.436015248298645, 54.8649025708437, 56.863108947873116, 56.4356242865324, 50.157646760344505, 45.743963196873665, 39.533926025033, 44.366274923086166, 44.35962527990341, 47.96748988330364, 53.20999637246132, 58.65772224962711, 56.95077404379845, 61.02145381271839, 57.968355640769005, 57.356611266732216, 54.85520929098129, 58.187486082315445, 56.22780963778496, 53.05206924676895, 55.093866884708405, 57.62724794447422, 57.39007607102394, 59.68131132423878, 61.736362650990486, 60.20476743578911, 57.37086050212383, 55.14026239514351, 58.949083015322685, 60.23457683622837, 59.64275859296322, 61.11791543662548, 61.460866034030914, 52.06732168793678, 45.765211656689644, 48.89122411608696, 46.92628875374794, 46.335454657673836, 44.25241783261299, 46.67842045426369, 45.795963406562805, 50.044720619916916, 49.820787236094475, 52.717785984277725, 52.11918890476227, 54.250061362981796, 51.4761608093977, 58.004028126597404, 63.97690862417221, 63.575832545757294, 65.70507869124413, 66.08920767903328, 60.56282602250576, 59.45214182138443, 57.145798578858376, 60.177443102002144, 62.67824091017246, 70.4263025522232, 74.55435544252396, 76.79902419447899, 77.9418432712555, 76.05953827500343, 78.00723016262054, 76.69002324342728, 81.45116776227951, 79.6328741312027, 83.78883272409439, 6.548202401027083, 1.2848467868752778, 11.709779407829046, 82.25360870361328, 68.07324841618538, 67.67847239971161, 53.716881573200226, 34.47307638823986, 34.52750466763973, 6.886049872264266, 0.7403469295240939, 0.09042186284204945, 0.09249143811757676, 0.030528960851370357, 0.025935343182936776, 0.0766222650418058, 0.03433959231188055, 0.07123696690541692, 0.23384975327644497, 0.3138047660468146, 0.15774932195199654, 0.10786401791847311, 0.222491598688066, 0.23759031115332618, 0.6951586855575442, 19.719317369163036, 84.6641081571579, 56.181638315320015, 37.923872619867325, 42.00749829411507, 67.1831613779068, 82.39414796233177, 86.76338911056519, 87.07906857132912, 44.882602617144585, 0.3287168877432123, 1.4825267856940627, 0.32885139458812773, 1.1714158672839403, 30.992028079926968, 86.00127920508385, 78.30513417720795, 86.31795421242714, 73.34874093532562, 83.4466002881527, 75.64072474837303, 78.88852447271347, 75.06445527076721, 75.09805306792259, 76.83589741587639, 76.3847704231739, 78.05815503001213, 76.9088762998581, 72.78745025396347, 78.19419533014297, 76.41722828149796, 78.25113907456398, 66.31838858127594, 60.70502199232578, 60.73420822620392, 59.280033856630325, 60.05103148519993, 56.72559432685375, 50.99390968680382, 51.900347247719765, 51.660534515976906, 56.27121850848198, 53.57570394873619, 55.16621120274067, 53.21362517774105, 57.04311668872833, 60.5553138256073, 64.88802373409271, 64.59527984261513, 65.91110363602638, 58.89105632901192, 58.172195702791214, 52.81678207218647, 58.52840378880501, 56.127468422055244, 57.268235608935356, 63.29955317080021, 60.94901829957962, 56.44576594233513, 52.726745903491974, 57.050750479102135, 56.84737779200077, 52.857287898659706, 58.65622892975807, 58.28501544892788, 62.583094015717506, 67.57895573973656, 56.73888221383095, 42.84683905541897, 53.23539040982723, 65.60151144862175, 49.63730648159981, 43.506628051400185, 52.3409678041935, 48.81929397583008, 56.6500049829483, 64.84387010335922, 62.25848503410816, 62.173567190766335, 64.14330929517746, 54.62613858282566, 42.70104467868805, 43.77647437155247, 52.301993295550346, 64.3910863995552, 56.99530005455017, 59.769960567355156, 60.41897714138031, 52.261647060513496, 46.98656491935253, 40.17236776649952, 46.30922466516495, 47.3328061401844, 47.689390406012535, 55.14905892312527, 62.34162077307701, 59.97773341834545, 64.99130979180336, 61.901323199272156, 62.419588789343834, 57.15488389134407, 61.76100812852383, 61.82762995362282, 56.0271842032671, 62.365677282214165, 63.23479324579239, 60.031622126698494, 62.19150982797146, 64.98400658369064, 63.74662958085537, 62.3068830370903, 60.34538269042969, 60.962108597159386, 63.57692688703537, 61.5761898458004, 63.55497166514397, 65.40155097842216, 53.06480996310711, 47.20298230648041, 50.948046147823334, 46.45414888858795, 50.162122920155525, 47.87618838250637, 49.92951840162277, 47.54776440560818, 52.73359313607216, 53.2151222974062, 55.83307541906834, 55.989364832639694, 58.67287963628769, 54.185514226555824, 59.14113610982895, 67.30771109461784, 64.0717439353466, 68.70802715420723, 69.1917335987091, 63.64767529070377, 63.010814264416695, 60.902432799339294, 63.51728528738022, 64.8887000977993, 71.28349095582962, 78.27082201838493, 81.89328923821449, 80.34434795379639, 78.94809767603874, 80.65914586186409, 81.57529190182686, 84.79037538170815, 81.33082821965218, 85.88054448366165, 6.14143137820065, 1.2674066727049649, 13.26957480981946, 90.81541568040848, 75.39022698998451, 78.55927973985672, 65.07985264062881, 49.64422211050987, 52.03422926366329, 28.616887629032135, 1.325258449651301, 0.20370818238006905, 0.34570681513287127, 0.07574693896458484, 0.15928577544400468, 0.16102018940728158, 0.14663517067674547, 0.23850134195527062], [0.10417330267955549, 0.05428901167761069, 0.16573958069784567, 0.06227605321328156, 0.015412778229801916, 0.011457731325208442, 0.19814591913018376, 11.763793509453535, 36.639780923724174, 32.26756073534489, 15.725681316107512, 44.581734761595726, 52.095725163817406, 61.619841903448105, 72.50618934631348, 75.10417833924294, 17.74813324213028, 0.36035808676388115, 0.4369782441062853, 0.10617035528412089, 1.3495304784737527, 42.322858572006226, 64.96675550937653, 67.56770074367523, 71.57610565423965, 65.11126175522804, 68.3032500743866, 65.06539061665535, 68.72553661465645, 65.55003941059113, 70.13364985585213, 68.5514223575592, 70.16547694802284, 67.75976523756981, 69.94539275765419, 68.42051178216934, 70.77802687883377, 68.65012586116791, 64.02104705572128, 55.22310175001621, 53.986777290701866, 52.539936527609825, 49.800842106342316, 51.99385643005371, 51.74994371831417, 43.00120957195759, 43.89996774494648, 46.76494941115379, 51.32829934358597, 52.45830550789833, 52.053148448467255, 47.9479893296957, 50.89494399726391, 52.67871268093586, 56.51257395744324, 55.06271995604038, 51.251969039440155, 50.70078581571579, 49.709301218390465, 51.186008378863335, 53.99780049920082, 54.80552315711975, 57.78130687773228, 60.860509648919106, 59.02595669031143, 54.86345484852791, 53.07504661381245, 50.9915766119957, 53.62112671136856, 46.798676401376724, 49.92598459124565, 50.954676792025566, 61.771510764956474, 52.84952111542225, 51.117167472839355, 43.42554800212383, 42.85486802458763, 44.79610025882721, 37.23405763506889, 43.955102786421776, 47.90018789470196, 49.160815849900246, 49.89544562995434, 50.528883039951324, 48.89171048998833, 52.155218571424484, 57.44635485112667, 58.89846593141556, 44.62391249835491, 41.583703234791756, 53.75688962638378, 58.26418496668339, 54.014447405934334, 48.23836974799633, 50.230450853705406, 50.359712317585945, 51.25684417784214, 48.032842576503754, 36.15527272224426, 39.05754178762436, 39.17178265750408, 45.71014501154423, 56.044735461473465, 57.19862714409828, 53.97647984325886, 54.11623254418373, 53.390475288033485, 53.57368245720863, 52.15633571147919, 49.31220352649689, 51.46423324942589, 52.8265817463398, 55.747409015893936, 54.613014087080956, 53.34407217800617, 55.56140519678593, 53.17278876900673, 52.25185498595238, 50.66960468888283, 57.36999034881592, 60.030208602547646, 60.24781912565231, 58.426459059119225, 55.15138439834118, 50.223254039883614, 45.68723224103451, 45.95915324985981, 43.317990973591805, 43.86694371700287, 42.25841023027897, 42.621925324201584, 44.89757381379604, 47.31215424835682, 48.40919718146324, 50.302137807011604, 50.989688113331795, 50.78104890882969, 52.275307327508926, 55.74018940329552, 62.472291961312294, 60.05897305905819, 60.455759167671204, 58.222653195261955, 55.07692739367485, 52.246596068143845, 51.86483435332775, 53.26860822737217, 57.487844824790955, 57.82596968114376, 63.15038837492466, 70.29406204819679, 69.95022609829903, 67.22410798072815, 68.82410332560539, 69.29106026887894, 76.7994573712349, 74.74271893501282, 89.43158313632011, 17.150360718369484, 2.015731274150312, 13.703668266534805, 70.70646151900291, 59.748753905296326, 58.514663726091385, 43.48476402461529, 35.49897573888302, 19.31366253644228, 5.718475598841906, 0.4227377363713458, 0.08400579579756595, 0.024538983052480035, 0.13574106618762016, 0.030627616397396196, 0.021171048247197177, 0.04495568457059562, 0.07151373603846878, 0.07146916264900938, 0.04388792331155855, 0.10997140561812557, 0.09527716363663785, 0.05734362101065926, 0.06574552680831403, 0.2509159140754491, 16.76799863576889, 55.43329507112503, 46.13537259399891, 22.825071215629578, 42.318314015865326, 61.60702519118786, 71.02637395262718, 78.82957443594933, 83.10317471623421, 20.809737257659435, 0.46629390853922814, 0.4866579658119008, 0.16044892865465954, 1.7298974306322634, 48.41392792761326, 78.41684058308601, 74.69737976789474, 80.28670504689217, 73.07237416505814, 75.80553710460663, 70.4674619436264, 73.89476403594017, 70.04043325781822, 73.40173289179802, 69.42189484834671, 72.24353983998299, 71.25936985015869, 74.00880351662636, 68.88135865330696, 73.15147072076797, 69.94046822190285, 67.7788858115673, 57.90735371410847, 57.30456925928593, 55.26835352182388, 52.26925805211067, 55.20800895988941, 53.82081739604473, 47.151365876197815, 45.861167907714844, 50.05558803677559, 54.34192143380642, 53.19761283695698, 53.36063928902149, 51.55628331005573, 54.24007169902325, 54.00590166449547, 59.19955417513847, 60.29991813004017, 54.326042085886, 54.891938120126724, 51.21766448020935, 54.44656401872635, 56.9948972761631, 56.827968433499336, 59.78576771914959, 63.100759238004684, 62.081589326262474, 58.927868753671646, 55.8449649810791, 54.67123456299305, 55.94414725899696, 49.20947603881359, 54.27179999649525, 53.16034443676472, 62.100345119833946, 56.215277910232544, 52.8176674246788, 50.669798478484154, 45.48971503973007, 44.55250293016434, 42.55646623671055, 44.77594994008541, 47.86982752382755, 53.22405181825161, 52.11231127381325, 54.26076918840408, 49.990755915641785, 55.61054416000843, 62.666993513703346, 61.38339199125767, 45.55664844810963, 43.39151322841644, 58.68698067963123, 59.02129054069519, 57.13272348046303, 51.27943776547909, 53.973193019628525, 52.93646425008774, 53.83456505835056, 47.911325097084045, 35.44006370007992, 39.57797326147556, 40.221936106681824, 47.9824610799551, 58.2570793479681, 57.50814713537693, 56.71387955546379, 56.572709530591965, 55.14518693089485, 54.10255327820778, 54.77551996707916, 51.10251925885677, 54.17430482804775, 55.7140202075243, 54.812370389699936, 54.34167064726353, 55.447988882660866, 55.737495347857475, 54.51651446521282, 55.75117461383343, 54.18879345059395, 57.87868805229664, 61.00826092064381, 61.62896901369095, 61.14847719669342, 56.93427912890911, 51.74640230834484, 48.476806953549385, 49.58998762071133, 45.550378784537315, 46.83259338140488, 43.701181411743164, 46.4146576076746, 47.53969743847847, 48.656335920095444, 50.8805313706398, 51.46516039967537, 54.34517785906792, 53.340971544384956, 55.13195604085922, 56.266274973750114, 64.26968291401863, 62.531101405620575, 64.62733492255211, 60.83196558058262, 58.74153435230255, 55.83189368247986, 55.17994746565819, 57.99115061759949, 60.71590840816498, 62.116661444306374, 67.86539196968079, 73.4608045220375, 75.88556081056595, 72.4269787967205, 72.39779636263847, 72.08198770880699, 82.07935005426407, 76.81780278682709, 94.71897661685944, 18.916688337922096, 1.9161278125829995, 15.985176041722298, 81.05886161327362, 69.66195076704025, 68.10949847102165, 55.4621697217226, 39.32100065052509, 42.3320996761322, 19.153934307396412, 0.3666062874253839, 0.05904335070226807, 0.05630169762298465, 0.02840293040208053, 0.046190250941435806, 0.0376629110542126, 0.12056344115990214, 0.11824520188383758, 0.2013004178297706, 0.15454535168828443, 0.3041740640765056, 0.2329634508350864, 0.2909800736233592, 0.24971333798021078, 0.244720064511057, 22.32417829334736, 75.83573028445244, 61.84480883181095, 29.143619164824486, 63.42272736132145, 73.53363901376724, 81.1549660563469, 85.74448138475418, 94.2294792830944, 24.705033637583256, 0.453847260796465, 1.1043260735459626, 0.5647398869041353, 2.482026577927172, 56.09675846993923, 84.97283399105072, 78.34081426262856, 84.98583689332008, 72.95261219143867, 79.57008630037308, 71.98325380682945, 75.92587664723396, 70.70675790309906, 78.06862726807594, 73.48711431026459, 76.69171035289764, 73.41159716248512, 77.69408136606216, 70.92458501458168, 78.52537035942078, 73.99130165576935, 70.62888488173485, 62.34056442975998, 63.08780953288078, 59.25861060619354, 54.62113045156002, 56.461918875575066, 57.87193201482296, 49.43694703280926, 52.649116069078445, 51.998936757445335, 58.566424548625946, 56.96482188999653, 60.23095943033695, 53.362349197268486, 58.9518416672945, 55.29807172715664, 61.13835074007511, 60.79343564808369, 57.1541353315115, 54.40023310482502, 54.11193497478962, 55.69041587412357, 58.930638805031776, 57.531329691410065, 61.6837202757597, 65.90615630149841, 64.5558987557888, 61.75371252000332, 60.77579699456692, 56.49835892021656, 58.82748953998089, 51.00431352853775, 55.77795557677746, 54.90694731473923, 66.74540966749191, 58.34502562880516, 54.18543063104153, 46.80265858769417, 43.982028141617775, 50.543736442923546, 41.23461216688156, 45.0060997903347, 49.2281786352396, 55.817253068089485, 56.60832121968269, 57.53458991646767, 53.24381075799465, 57.723971754312515, 65.00670656561852, 64.28602203726768, 46.393644735217094, 42.1290347725153, 58.118557780981064, 61.675159335136414, 59.32770989835262, 53.53053577244282, 57.073663249611855, 57.51330725848675, 57.53170967102051, 50.09009398519993, 36.436997205019, 40.6598512083292, 41.104195564985275, 47.30525001883507, 62.01946645975113, 62.27048099040985, 59.95661415159702, 59.24441076815128, 58.547763749957085, 57.62409791350365, 58.877472057938576, 54.14050184190273, 56.820258647203445, 59.055629298090935, 59.80228543281555, 59.139752984046936, 58.00138346850872, 60.59216044843197, 59.50525537133217, 60.32847359776497, 54.669669046998024, 61.75769090652466, 66.88110798597336, 64.87278655171394, 65.14112815260887, 57.53628462553024, 55.65654069185257, 51.551894545555115, 51.35899409651756, 46.7244815826416, 50.09711220860481, 46.70902781188488, 49.37466457486153, 50.477319806814194, 52.03319951891899, 54.804387018084526, 54.85879249870777, 57.69339099526405, 56.46574147045612, 57.946153432130814, 59.73551541566849, 67.410579174757, 63.80832687020302, 67.02437549829483, 63.98417383432388, 60.21181985735893, 57.395053803920746, 59.20044332742691, 60.10317228734493, 63.08989182114601, 64.73728582262993, 70.18429353833199, 77.4875320494175, 79.99456912279129, 74.13505554199219, 76.01906284689903, 72.99118012189865, 85.36339223384857, 80.07097542285919, 96.92719012498856, 19.63552426546812, 2.0952009223401546, 17.740341760218143, 90.3143897652626, 74.74746868014336, 78.73853132128716, 66.73918560147285, 51.22355416417122, 57.503177002072334, 35.232412442564964, 0.6403585604857653, 0.3560515819117427, 0.2578228747006506, 0.13490025739884004, 0.20557837968226522, 0.1150711030641105, 0.20017331815324724, 0.19560814514989033], [0.07944889031932689, 0.043349116676836275, 0.027794645757239778, 0.13153674022760242, 0.018824527578544803, 0.015472392169613158, 0.45705292315687984, 7.744807591661811, 34.86059479415417, 30.6671854108572, 19.32138752192259, 54.21688914299011, 48.74728783965111, 57.5675493478775, 68.83292645215988, 74.61652010679245, 33.12460854649544, 0.1735736322007142, 0.37969875207636505, 0.05442756322736386, 1.3628855743445456, 57.25569248199463, 64.2596210539341, 74.58471581339836, 68.79660800099373, 70.83543419837952, 68.0572284758091, 67.38130554556847, 68.16654101014137, 66.04708313941956, 65.56435704231262, 67.65423730015755, 66.0110154747963, 63.05901847779751, 65.27320146560669, 63.37627485394478, 64.07634168863297, 61.96969673037529, 56.65786296129227, 51.464282646775246, 51.676843240857124, 49.70050469040871, 52.775007113814354, 50.40588743984699, 50.37143848836422, 40.90851366519928, 43.93749073147774, 46.19270011782646, 49.958529844880104, 49.96167607605457, 51.43618695437908, 49.483688324689865, 53.42458225786686, 54.104042798280716, 53.31851474940777, 55.510123148560524, 52.27816857397556, 48.81408825516701, 48.07182468473911, 56.87831573188305, 56.440214440226555, 59.17413353919983, 58.76141868531704, 61.69900685548782, 62.302623465657234, 59.370810985565186, 57.316633611917496, 52.55627945065498, 49.54404428601265, 46.73441044986248, 50.15432953834534, 45.58781437575817, 54.42492797970772, 58.3553496748209, 59.03970055282116, 38.59708249568939, 43.14592480659485, 46.65632463991642, 43.54053743183613, 46.55988961458206, 51.27208516001701, 48.96094657480717, 49.862129017710686, 51.198323518037796, 49.27083894610405, 51.546886414289474, 55.318533629179, 61.90388046205044, 48.40061344206333, 51.687091290950775, 59.59417060017586, 56.325023621320724, 51.82459831237793, 48.548322916030884, 49.73241537809372, 45.03866784274578, 44.12654958665371, 50.266054943203926, 35.101049691438675, 36.551378667354584, 36.022523045539856, 42.23233982920647, 54.82204087078571, 58.115548342466354, 56.61250099539757, 54.923898205161095, 53.376693427562714, 49.717907756567, 50.28518311679363, 48.675030916929245, 51.619690507650375, 51.39488697052002, 52.16322474181652, 52.250274270772934, 50.264664217829704, 50.03911592066288, 52.38348372280598, 51.0100132226944, 51.8053637444973, 51.67563870549202, 54.08346310257912, 54.83390383422375, 55.33864974975586, 56.71909287571907, 49.23838868737221, 43.989867120981216, 47.83464141190052, 45.000194907188416, 43.831088840961456, 42.077813521027565, 42.89417691528797, 43.58512423932552, 46.93262681365013, 50.34688800573349, 47.48557694256306, 50.37495329976082, 48.82584102451801, 53.00283908843994, 54.82153169810772, 56.6578059643507, 58.563791289925575, 58.269181698560715, 55.93336723744869, 54.96752366423607, 54.06623862683773, 53.26631315052509, 51.17951452732086, 54.71608355641365, 53.54490280151367, 57.51306787133217, 60.45356668531895, 63.37267264723778, 61.19221284985542, 65.0118438899517, 69.48798090219498, 77.95828878879547, 75.92092171311378, 87.41927191615105, 25.460795983672142, 1.5360260149464011, 18.641398809850216, 75.39230927824974, 59.27447095513344, 54.55998793244362, 48.03630419075489, 37.72385135293007, 32.812975868582726, 12.935988809913397, 0.2548789232969284, 0.058557140073389746, 0.07140103349229321, 0.07041265605948865, 0.02878719777072547, 0.05839867670147214, 0.01011087801089161, 0.08427781518548727, 0.044377573794918135, 0.04395744028443005, 0.04426764317031484, 0.09265333763323724, 0.10459742523380555, 0.10685538727557287, 0.4226191114867106, 12.605544291436672, 51.055124402046204, 45.09773187339306, 20.38470346480608, 56.530820578336716, 62.976004332304, 64.86310467123985, 77.97824531793594, 81.09172224998474, 37.9422028362751, 0.14805874350713566, 0.6650011288002133, 0.14690878568217158, 1.770809122826904, 64.71939638257027, 76.08261823654175, 81.62538081407547, 77.73994490504265, 77.02223181724548, 74.7516256570816, 72.6230862736702, 71.91598981618881, 71.5212593972683, 69.98682573437691, 69.97676387429237, 69.20102030038834, 67.86709427833557, 69.55150589346886, 67.59723275899887, 67.67219513654709, 66.88733965158463, 62.08772599697113, 54.767392203211784, 54.70464996993542, 52.88743928074837, 54.44422334432602, 53.2606590539217, 55.12416645884514, 42.70191863179207, 45.897569954395294, 48.83649945259094, 52.511962428689, 52.196199372410774, 55.82218900322914, 51.09878025949001, 54.71990995109081, 56.425475031137466, 57.06757977604866, 58.66127505898476, 56.19091361761093, 52.04322338104248, 52.571022659540176, 59.0099823474884, 59.5866584032774, 60.639585703611374, 59.974514991045, 63.14794510602951, 63.20303834974766, 62.39976905286312, 58.71333986520767, 55.5643842369318, 53.181471303105354, 50.294583812355995, 53.18568527698517, 50.193885415792465, 55.78563116490841, 60.92221833765507, 59.641519859433174, 44.8381108045578, 45.308833345770836, 50.906164795160294, 43.22476677596569, 49.958754032850266, 55.46370483934879, 53.220651000738144, 51.83367982506752, 54.45187993347645, 53.37824374437332, 54.258455112576485, 55.77107794582844, 63.02790954709053, 51.1853814125061, 52.26674258708954, 62.30643466114998, 58.53055827319622, 54.716558530926704, 52.15090960264206, 54.03506889939308, 49.45442609488964, 46.46148629486561, 52.455839440226555, 36.4556960016489, 37.17560917139053, 37.515367940068245, 44.79928828775883, 58.16132828593254, 61.15544602274895, 56.57133400440216, 55.95677778124809, 54.89501215517521, 50.44248707592487, 53.70015487074852, 52.34655350446701, 52.26086810231209, 54.14629653096199, 53.840390145778656, 55.401038601994514, 51.32068455219269, 53.91869254410267, 53.8761006295681, 53.91390860080719, 54.30044665932655, 54.71503861248493, 56.72904074192047, 56.68656662106514, 56.23862765729427, 57.53130689263344, 51.84618875384331, 47.22605846822262, 50.61025187373161, 46.204441487789154, 46.518817618489265, 43.65082651376724, 44.72964942455292, 45.514216125011444, 50.1302008330822, 50.80964997410774, 50.70819541811943, 51.81622356176376, 50.95858298242092, 54.87646535038948, 56.48555740714073, 60.13152256608009, 61.84633634984493, 61.58608831465244, 57.22433276474476, 58.06155323982239, 57.17430844902992, 56.90068133175373, 55.418935641646385, 58.62890839576721, 58.971463814377785, 60.148477256298065, 64.09814491868019, 67.55765408277512, 64.90485683083534, 68.99791359901428, 74.42402243614197, 83.21453154087067, 78.36626529693604, 92.38487586379051, 27.23873198032379, 1.3133706687949598, 21.090504191815853, 86.54219537973404, 66.59994587302208, 64.37027871608734, 60.63451297581196, 40.14164641499519, 49.17779713869095, 26.53215989470482, 0.12611420854227617, 0.020050900639034808, 0.04908276037895121, 0.02675312127394136, 0.04289498909201939, 0.031702136766398326, 0.012030870639136992, 0.09322007128503174, 0.13335031166207045, 0.18838894815417007, 0.1721355874906294, 0.2303796191699803, 0.14597476314520463, 0.322613583994098, 0.5315166665241122, 17.887038588523865, 74.4838996231556, 61.29091635346413, 31.63835059851408, 67.4509710073471, 69.95218679308891, 74.67192113399506, 83.41502398252487, 88.71007785201073, 43.016788735985756, 0.12691419920884073, 1.0587882483378053, 0.6281560496427119, 2.6341533148661256, 69.98737290501595, 80.21715357899666, 84.30324912071228, 81.18048548698425, 77.5858099758625, 78.98136869072914, 73.84766936302185, 76.24418556690216, 72.89643600583076, 74.14447903633118, 73.84246364235878, 72.26212084293365, 69.23989221453667, 72.20098972320557, 69.49463814496994, 68.9942429959774, 67.46347233653069, 65.94230756163597, 59.52863551676273, 56.95480942726135, 54.57655884325504, 55.95602162182331, 54.310531318187714, 56.63466900587082, 46.8174359947443, 50.591739267110825, 52.52877652645111, 54.95790258049965, 55.744407176971436, 58.18168759346008, 54.432994946837425, 57.68901363015175, 60.12603186070919, 57.19318583607674, 61.39429360628128, 57.39554397761822, 55.79125486314297, 52.884057462215424, 61.02415166795254, 60.495634227991104, 61.53158023953438, 61.69331096112728, 65.74669405817986, 64.583340883255, 64.842988550663, 60.133924037218094, 58.866562843322754, 56.81845374405384, 51.248427629470825, 56.81113913655281, 50.04053324460983, 59.89106006920338, 64.38578188419342, 60.051962435245514, 40.23520119488239, 45.64464032649994, 48.3527360111475, 43.28578010201454, 50.21839790046215, 57.681121453642845, 54.656069576740265, 54.09114629030228, 57.954250797629356, 55.85491664707661, 53.69944430887699, 61.15070387721062, 65.94079524278641, 50.13565734028816, 53.267369493842125, 64.42274630069733, 60.77015809714794, 58.107367381453514, 55.051909536123276, 56.68127350509167, 50.20599916577339, 50.36621756851673, 54.850022569298744, 37.490490674972534, 38.15467603504658, 38.10214005410671, 42.937331199645996, 59.063646867871284, 62.62726664543152, 59.72902536392212, 58.95976044237614, 59.282211139798164, 54.08793166279793, 58.48852872848511, 54.424574598670006, 55.423043221235275, 57.136287689208984, 57.21595801413059, 58.7518659979105, 52.843342646956444, 56.439477279782295, 57.11790427565575, 56.19444362819195, 56.41104340553284, 56.88277289271355, 58.603879138827324, 59.65039238333702, 60.37500210106373, 61.56548961997032, 55.27541734278202, 48.87554235756397, 52.670159339904785, 49.551396891474724, 50.84507927298546, 47.83566735684872, 49.33985844254494, 48.45188409090042, 53.18196527659893, 56.23991198837757, 53.969378024339676, 54.61297228932381, 54.0827639400959, 57.25443854928017, 60.267707258462906, 62.423415184020996, 63.022966012358665, 64.62700054049492, 61.05557978153229, 62.91586495935917, 60.140364691615105, 60.26668131351471, 58.09246838092804, 62.32187323272228, 60.75026996433735, 63.7426245957613, 66.77852109074593, 70.72904750704765, 68.06840747594833, 72.2685956954956, 76.48267596960068, 85.4616017639637, 81.29074797034264, 94.4407631456852, 28.646052964031696, 1.3866548426449299, 22.905378006398678, 93.77753913402557, 74.82414856553078, 74.8143070936203, 73.02625223994255, 49.77881468832493, 66.7628887295723, 35.879719108343124, 0.44752327201422304, 0.16305814177030697, 0.19634934287751094, 0.25768323219381273, 0.16712429467588663, 0.1450870803091675, 0.20756139827426523, 0.20685261755716056], [0.02956573665869655, 0.022806992201367393, 0.05669121012033429, 0.10865093936445192, 0.06504977820441127, 0.05778624159574974, 0.20954538165824488, 9.428938496857882, 24.33440152555704, 33.32306809723377, 26.909629739820957, 36.52406193315983, 44.14602734148502, 51.58887416124344, 61.846416145563126, 77.28818714618683, 35.83148069679737, 0.1591006392845884, 0.33472869952674955, 0.2288666769163683, 2.4405672401189804, 65.67233204841614, 69.54075247049332, 76.65853813290596, 74.11797925829887, 71.7981505393982, 67.84072369337082, 67.85308822989464, 68.20779159665108, 68.32463532686234, 66.27488851547241, 64.0318688750267, 63.84431853890419, 65.18430143594742, 59.92965079843998, 61.85438811779022, 60.870069935917854, 57.845671623945236, 53.154013976454735, 51.06348395347595, 51.12769290804863, 50.75831852853298, 51.467155292630196, 51.55732445418835, 51.292091086506844, 40.859553292393684, 42.6842837780714, 45.816208720207214, 48.63312676548958, 52.234968692064285, 50.81258721649647, 53.282838463783264, 51.407316103577614, 50.278624668717384, 52.97499418258667, 52.93629705905914, 52.10863687098026, 50.887249410152435, 59.09125238656998, 59.50336307287216, 60.775607004761696, 60.69360360503197, 61.988361328840256, 58.04240986704826, 60.72157010436058, 59.015309661626816, 58.648918122053146, 55.3285650908947, 51.02052725851536, 47.169870883226395, 47.38427437841892, 48.662305399775505, 54.92554731667042, 57.828374952077866, 63.770268112421036, 35.7654744386673, 50.63079357147217, 54.14340868592262, 41.50885485112667, 52.59210392832756, 49.33249443769455, 50.94204626977444, 52.69042365252972, 49.2143701761961, 48.81685830652714, 48.07467833161354, 51.573640778660774, 54.97002772986889, 55.947646871209145, 55.224526673555374, 52.86464810371399, 52.92247720062733, 49.2247474193573, 48.66966560482979, 50.49660377204418, 53.14490586519241, 48.19584622979164, 53.0969600379467, 42.24340483546257, 36.59234806895256, 41.3572733849287, 40.30478686094284, 53.48096743226051, 57.44422696530819, 55.66343352198601, 51.51314802467823, 49.50196914374828, 48.781569600105286, 47.14229576289654, 50.246649384498596, 49.45788390934467, 48.714176416397095, 52.09746927022934, 50.06034538149834, 52.76050329208374, 51.348533257842064, 48.76201964914799, 48.53139862418175, 48.733342587947845, 48.08333806693554, 49.90001678466797, 51.71717427670956, 51.958658918738365, 52.28058144450188, 47.99533858895302, 45.22344812750816, 46.4768298715353, 45.457903146743774, 45.03138743340969, 42.80325159430504, 40.39383128285408, 40.55255636572838, 45.522123500704765, 49.166458547115326, 47.71294914186001, 48.69573600590229, 49.0739943087101, 49.659660682082176, 51.20632588863373, 56.31773181259632, 55.59086501598358, 55.42015917599201, 54.52981375157833, 53.08243341743946, 51.22519187629223, 53.86532060801983, 52.73617699742317, 54.41610865294933, 54.34867367148399, 58.44451189041138, 56.319483518600464, 59.24839295446873, 60.014276057481766, 70.7716204226017, 72.31711909174919, 79.35154482722282, 76.68812334537506, 89.12316888570786, 27.303110025823116, 1.557921152561903, 25.061289221048355, 75.09027868509293, 59.82911579310894, 57.99375727772713, 46.731233820319176, 28.60058080404997, 36.05783075094223, 21.51835933327675, 0.09852466086158529, 0.04503126117924694, 0.06727328232955188, 0.05204201486776583, 0.036263012734707445, 0.08287787975859828, 0.04589358111843467, 0.057281321423943155, 0.02357176610530587, 0.06446145547670312, 0.026918147086689714, 0.061692049785051495, 0.10974018950946629, 0.03449670868576504, 0.33617796550970525, 12.900585159659386, 40.77093444764614, 48.10004197061062, 26.979633383452892, 46.03474259376526, 54.977570325136185, 58.4704302996397, 72.01866790652275, 84.85640823841095, 40.66939249634743, 0.10573643638053909, 0.56893604923971, 0.21537481807172298, 2.6414498733356595, 77.91373997926712, 78.30671489238739, 82.47407287359238, 80.29219195246696, 74.67467218637466, 73.38942155241966, 73.31443637609482, 70.89511379599571, 70.43009474873543, 71.42289787530899, 67.37547665834427, 67.33378529548645, 68.22829529643059, 63.75802516937256, 64.26801100373268, 64.26201492547989, 58.95630642771721, 55.630295500159264, 54.43250097334385, 55.94816364347935, 54.09865848720074, 53.462652415037155, 53.12108114361763, 53.64188499748707, 45.41611298918724, 46.631314381957054, 48.646680638194084, 52.09450542926788, 54.82301741838455, 54.26621429622173, 54.21397849917412, 53.72128173708916, 52.78333246707916, 54.85817313194275, 56.58391892910004, 54.623098745942116, 52.7296831458807, 62.3648527264595, 61.46181218326092, 63.758389949798584, 62.186885476112366, 65.68369343876839, 60.66935330629349, 63.44203792512417, 60.655039474368095, 61.1528317630291, 56.673647314310074, 55.40117919445038, 49.39907066524029, 51.598176062107086, 48.89696180820465, 57.758340910077095, 57.7041482180357, 63.5470262914896, 41.27559296786785, 54.96401645243168, 51.56058467924595, 43.10650572180748, 54.294480979442596, 51.625401601195335, 54.9230432510376, 53.788636922836304, 52.663049921393394, 50.68012252449989, 50.34407235682011, 53.446393087506294, 55.74492774903774, 57.02344514429569, 57.52096004784107, 55.14062337577343, 55.3250502794981, 52.022328302264214, 49.51024129986763, 52.063430696725845, 54.870887249708176, 51.73189468681812, 54.799515679478645, 43.441104367375374, 37.476822808384895, 41.461342200636864, 40.60696944594383, 56.08557187020779, 59.31426241993904, 56.44255891442299, 51.74267090857029, 49.52802054584026, 50.397144109010696, 49.31732565164566, 51.05202756822109, 53.9643394947052, 50.87244540452957, 55.594482421875, 54.42197933793068, 54.77996192872524, 52.30139672756195, 50.3038477152586, 50.74112065136433, 50.56219965219498, 49.77014735341072, 53.54285471141338, 52.59591892361641, 53.701864778995514, 55.45415215194225, 50.908060893416405, 45.57535104453564, 49.071068465709686, 48.681881949305534, 47.734239399433136, 44.200052842497826, 43.586522564291954, 43.361551836133, 48.58811058104038, 50.969689786434174, 49.185495525598526, 51.036079823970795, 52.33605466783047, 52.20971904695034, 54.31150406599045, 57.98030599951744, 59.04195003211498, 60.213176384568214, 56.682550236582756, 56.794154047966, 55.19741512835026, 56.147337555885315, 56.82079441845417, 57.53602623939514, 57.37016513943672, 62.58798435330391, 58.8360732793808, 62.336050271987915, 63.33527885377407, 77.92497977614403, 76.70773029327393, 84.61344167590141, 79.81480076909065, 94.69376116991043, 28.870695009827614, 1.4882499910891056, 28.706283532083035, 85.32103970646858, 67.14615896344185, 67.84441709518433, 57.77547799050808, 34.270140677690506, 49.944254010915756, 32.11312562227249, 0.15361523284809664, 0.10204854130279273, 0.1905160621390678, 0.08531236162525602, 0.041112457984127104, 0.021983573788020294, 0.05182201632123906, 0.040389669229625724, 0.3683008480584249, 0.1589187388890423, 0.14515725779347122, 0.1398967221030034, 0.14446893066633493, 0.14194807765306905, 0.37575871974695474, 17.2995825111866, 64.710254073143, 66.38281792402267, 45.49425199627876, 48.15607376396656, 61.72329135239124, 68.9154352247715, 78.92556488513947, 90.81165388226509, 44.37575921416283, 0.2019405795726925, 1.1782804364338517, 0.5390169890597463, 4.345333781093359, 82.88078024983406, 84.85484272241592, 82.3867991566658, 85.76263681054115, 76.58594682812691, 76.81945189833641, 74.00888711214066, 73.71560364961624, 72.27627888321877, 76.05883151292801, 70.40144428610802, 71.21360510587692, 69.400365203619, 66.43820375204086, 70.33864885568619, 66.7139245569706, 61.48666664958, 60.220278203487396, 55.167313143610954, 56.235937401652336, 56.435282304883, 57.74069085717201, 57.729527056217194, 57.69821293652058, 49.712835028767586, 51.50549903512001, 52.22176440060139, 55.96294865012169, 57.93163061141968, 55.335077941417694, 58.48439835011959, 55.42294442653656, 54.298622757196426, 56.323385909199715, 60.40152467787266, 55.9631310403347, 54.29771840572357, 63.56234706938267, 64.48739603161812, 65.88932320475578, 62.66118362545967, 67.13896214962006, 62.81821019947529, 66.50493577122688, 64.1856238245964, 64.10575971007347, 60.40867209434509, 55.61687842011452, 53.57043743133545, 52.59276129305363, 52.97560974955559, 61.78411848843098, 62.69446223974228, 60.86891859769821, 42.56958693265915, 54.77184556424618, 52.94016905128956, 42.29478947818279, 56.34600609540939, 54.03967425227165, 59.93047535419464, 57.63943009078503, 53.904918283224106, 54.7905557602644, 53.31614747643471, 57.82086655497551, 59.96977664530277, 59.62069317698479, 60.503583401441574, 59.12478178739548, 58.74232850968838, 54.57601547241211, 53.582319393754005, 56.712321639060974, 58.36619809269905, 54.66604024171829, 57.51828119158745, 45.50013028085232, 37.80096061527729, 44.6305051445961, 40.537881553173065, 58.5166472196579, 62.11212448775768, 60.25357201695442, 57.0173654705286, 53.32838661968708, 53.37379418313503, 53.12031738460064, 54.93229955434799, 57.87271097302437, 55.26510089635849, 57.830613031983376, 57.11017549037933, 56.73827804625034, 55.59720307588577, 53.57959493994713, 54.533153772354126, 53.82881976664066, 53.71786572039127, 57.419433295726776, 56.09118416905403, 58.24722647666931, 59.02063697576523, 55.35950683057308, 48.136079236865044, 51.978759840130806, 49.674495086073875, 51.93863019347191, 46.80518925189972, 47.25598946213722, 45.1210930198431, 53.132704719901085, 54.293793216347694, 51.84724509716034, 53.16198214888573, 53.789795860648155, 53.392215594649315, 54.216060787439346, 63.06043580174446, 62.609616592526436, 61.911217868328094, 59.98724430799484, 60.388316586613655, 58.058634996414185, 58.9292860776186, 58.43718208372593, 59.16609697043896, 58.96798700094223, 64.89604890346527, 60.97296841442585, 65.96115455031395, 65.87997570633888, 78.82754534482956, 78.47752332687378, 86.35198518633842, 82.4863538146019, 94.58154559135437, 32.10343234241009, 1.7179685644805431, 32.17802993953228, 91.49366408586502, 75.21640911698341, 75.42431876063347, 67.81613901257515, 39.16304312646389, 63.91905292868614, 39.79354329407215, 0.2980648528318852, 0.16579485585680231, 0.2737275743857026, 0.2796361385844648, 0.17982618184760213, 0.11527525304700248, 0.16390441276598722, 0.14722822088515386], [0.06691394926747307, 0.03906190766429063, 0.1054893531545531, 0.05072782347269822, 0.06443436708650552, 0.017859843210317194, 0.16047907469328493, 4.274312742054462, 21.017736196517944, 28.848261013627052, 29.608970694243908, 25.74613407254219, 40.237629264593124, 53.34907650947571, 58.50296035408974, 78.60049232840538, 39.58518907427788, 0.10790691405418329, 0.11679416958941147, 0.1931548721040599, 4.013243950903416, 64.53363195061684, 71.60994663834572, 76.89745411276817, 73.53083476424217, 70.7772821187973, 67.86612913012505, 69.83429431915283, 66.87116011977196, 66.20000973343849, 65.37559077143669, 64.09122169017792, 62.25138321518898, 61.16615004837513, 59.10848826169968, 57.77783766388893, 56.99070230126381, 53.54586035013199, 51.70656904578209, 51.19301900267601, 50.22554911673069, 51.20101377367973, 51.5590001642704, 48.79229262471199, 48.881462439894676, 43.414418399333954, 41.88709035515785, 44.98317942023277, 49.496953412890434, 51.940617486834526, 53.59862431883812, 50.23617334663868, 50.763235464692116, 51.185974180698395, 51.03175185620785, 56.74105949699879, 53.827106058597565, 55.863652378320694, 61.48288585245609, 62.507329881191254, 62.44345910847187, 58.435035198926926, 60.228010788559914, 58.09214539825916, 56.065102368593216, 56.94526053965092, 61.22484929859638, 57.18317337334156, 50.83071604371071, 49.80259761214256, 49.59382921457291, 49.60797965526581, 52.6124632358551, 73.03056120872498, 48.53121243417263, 38.51034075021744, 56.6849897056818, 40.30991658568382, 51.73874571919441, 44.212820157408714, 52.01402194797993, 48.05853679776192, 49.51532542705536, 48.81739407777786, 49.46634225547314, 47.35484875738621, 49.98282954096794, 48.95830191671848, 54.38385598361492, 53.8175343722105, 50.75939767062664, 47.404170110821724, 46.41905777156353, 47.14522920548916, 49.71957206726074, 48.93783241510391, 50.461748242378235, 49.94207292795181, 46.47327706217766, 37.201557978987694, 40.19423559308052, 39.133685901761055, 48.20754960179329, 54.54877473413944, 52.79150202870369, 49.84474875032902, 49.05721440911293, 46.60285010933876, 47.87814907729626, 48.571999445557594, 48.56894440948963, 48.515808060765266, 48.0464306473732, 47.62409470975399, 48.04383918642998, 47.62410990893841, 49.99382995069027, 49.007980450987816, 48.064160495996475, 47.17088922858238, 47.6573733240366, 46.88204772770405, 51.07668064534664, 50.735109373927116, 46.47507056593895, 46.591424122452736, 45.517844930291176, 43.63528914749622, 43.150123581290245, 40.63598468899727, 40.262411534786224, 40.88207088410854, 47.30543240904808, 47.58515439927578, 48.26737359166145, 50.77916041016579, 49.1404527425766, 49.82919238507748, 53.26109983026981, 53.62869210541248, 53.385106176137924, 55.22657476365566, 55.53237095475197, 52.29711055755615, 51.26505933701992, 52.421375289559364, 51.484151780605316, 50.35802140831947, 51.475207060575485, 56.24958246946335, 55.240280628204346, 62.65556752681732, 67.95772701501846, 78.61353322863579, 74.78020012378693, 82.32338815927505, 74.02774170041084, 85.37569597363472, 20.989192128181458, 1.1626351322047412, 33.07331509888172, 73.45324292778969, 58.116388097405434, 58.690035715699196, 50.56672900915146, 32.49991826713085, 46.01996898651123, 21.874022148549557, 0.5552799382712692, 0.07866106345318258, 0.16719913284759969, 0.028135185784776695, 0.09796075479243882, 0.05801592888019513, 0.0979997323884163, 0.08119671489112079, 0.031329931152868085, 0.06173678644699976, 0.062090891078696586, 0.03167712638969533, 0.06429540735553019, 0.054312040520017035, 0.23365931818261743, 7.420742455869913, 36.56117454171181, 44.802107736468315, 30.96127063035965, 25.44467344880104, 48.62998813390732, 58.950481340289116, 69.46417897939682, 87.0357508957386, 44.81314994394779, 0.08556877364753745, 0.36060771555639803, 0.29133942152839154, 5.303988140076399, 74.29960951209068, 78.83371621370316, 81.72425150871277, 75.38032472133636, 76.59742221236229, 72.75885298848152, 74.38860073685646, 71.62715211510658, 71.69608041644096, 69.8082809150219, 68.07900130748749, 65.02698227763176, 64.7316925227642, 61.50169864296913, 61.28569923341274, 60.16849838197231, 55.73472149670124, 54.56105187535286, 53.6967958509922, 53.785464093089104, 54.2390875518322, 53.12871873378754, 51.85888007283211, 50.298417806625366, 45.91083504259586, 47.29583792388439, 47.90893502533436, 51.63990542292595, 52.15822421014309, 56.560189202427864, 53.65052193403244, 53.85192632675171, 53.42918761074543, 52.98699773848057, 60.49531504511833, 55.68835638463497, 58.14424440264702, 64.58388805389404, 62.845048159360886, 63.549378365278244, 60.90573102235794, 61.42178513109684, 61.260970160365105, 60.06862074136734, 58.279042169451714, 62.849121540784836, 58.643549010157585, 54.4327137619257, 55.18262252211571, 51.4837945997715, 52.898945063352585, 54.9067535251379, 70.9456966817379, 50.48447862267494, 40.64163118600845, 55.98882146179676, 42.1070871502161, 52.99331679940224, 46.11424572765827, 54.326790645718575, 51.698505878448486, 53.795043379068375, 50.713317543268204, 51.94165103137493, 48.61095875501633, 54.5061220228672, 50.581088438630104, 55.12241095304489, 54.99544836580753, 52.41106644272804, 50.182155445218086, 49.81211610138416, 50.55862784385681, 51.86329543590546, 53.29994134604931, 51.23992748558521, 51.94431088864803, 47.74608336389065, 39.0795312076807, 42.17196486890316, 42.261271476745605, 50.542440712451935, 56.532063111662865, 54.45791020989418, 51.28660798072815, 51.121506839990616, 49.62767019867897, 48.91523502767086, 50.67137159407139, 50.83010047674179, 49.4855160266161, 51.06923684477806, 50.30147664248943, 51.433823481202126, 50.94552308320999, 53.30882526934147, 50.8335354924202, 51.36119417846203, 50.92058502137661, 49.825631976127625, 49.73426587879658, 54.210767671465874, 53.980336636304855, 47.86492578685284, 49.73723731935024, 48.76033253967762, 46.57457962632179, 44.84666034579277, 43.194474801421165, 42.70647078752518, 44.60439674556255, 48.15415106713772, 48.64804856479168, 50.287945568561554, 54.21021290123463, 51.38139769434929, 52.83660560846329, 55.08978970348835, 55.67702919244766, 55.01604326069355, 57.72654041647911, 58.17965090274811, 57.25236006081104, 55.208928510546684, 56.22185155749321, 55.861406698822975, 55.6394150108099, 55.48406034708023, 60.08136905729771, 60.22347763180733, 66.60619273781776, 73.59258145093918, 82.36982926726341, 79.16155502200127, 84.69886109232903, 77.79345363378525, 88.55687007308006, 21.00823100656271, 0.9869531623553485, 39.286582097411156, 82.91114822030067, 63.60778883099556, 67.94591724872589, 59.31031823158264, 34.518236964941025, 56.34077377617359, 26.279393658041954, 0.5518034216947854, 0.16636697750072926, 0.05817308607220184, 0.06629640818573534, 0.06398717116098851, 0.04325598456489388, 0.03916980109352153, 0.02590775940916501, 0.13415739726042375, 0.16378241853090003, 0.23685436783125624, 0.15054707560921088, 0.2095931165968068, 0.2942981861997396, 0.3629807772813365, 10.61459457501769, 61.90942816436291, 68.18139061331749, 49.40078817307949, 36.407487988471985, 60.22494435310364, 71.58671468496323, 76.07552021741867, 93.542939722538, 48.85897144675255, 0.25684217107482255, 1.0492943390272558, 0.31556623871438205, 6.666666744276881, 80.06557211279869, 80.78583106398582, 82.30079457163811, 77.45524138212204, 79.82009768486023, 75.47291815280914, 76.48547261953354, 74.11462783813477, 71.66953504085541, 73.12629327178001, 69.09138858318329, 68.52443620562553, 67.13014662265778, 64.17914897203445, 64.15596261620522, 63.05059053003788, 58.674882128834724, 59.10388670861721, 56.94822818040848, 56.09780341386795, 57.55428425967693, 56.60443402826786, 54.50521007180214, 53.77498805522919, 49.10778969526291, 47.87652276456356, 50.63873514533043, 53.751121535897255, 55.610205978155136, 60.423688888549805, 55.87416261434555, 56.23709633946419, 54.880637526512146, 53.28932851552963, 63.00165295600891, 58.785057216882706, 58.184704631567, 66.6698469221592, 65.6314842402935, 65.14412999153137, 61.90799944102764, 65.44952720403671, 62.986769154667854, 61.76983505487442, 60.61441205441952, 65.27757123112679, 60.20583137869835, 56.399910002946854, 57.7331330627203, 54.87196259200573, 56.511859595775604, 57.54106476902962, 66.60203576087952, 55.81708587706089, 42.620990574359894, 56.177591532468796, 43.28932911157608, 53.286482468247414, 46.907890141010284, 57.98493035137653, 53.384068831801414, 56.45852945744991, 54.27441045641899, 55.99051617085934, 51.95886790752411, 55.58370620012283, 53.45902740955353, 58.73647682368755, 60.14292575418949, 56.94696664810181, 52.855049818754196, 52.06496961414814, 52.6405893266201, 55.4784594476223, 55.34293971955776, 56.2243328243494, 55.62532156705856, 49.31901656091213, 38.27220752835274, 42.2862209379673, 41.0909228771925, 52.7455472946167, 58.18309731781483, 59.12681087851524, 54.97888125479221, 52.758424803614616, 51.66707016527653, 54.26386222243309, 52.28244334459305, 55.644943714141846, 52.667396888136864, 54.76411297917366, 51.6374621540308, 53.51863481104374, 53.408379927277565, 55.343695878982544, 52.527203410863876, 53.11120927333832, 52.52699062228203, 53.66213411092758, 51.860137805342674, 56.39570742845535, 57.239885330200195, 51.37690253555775, 51.42724223434925, 50.85054337978363, 48.127788081765175, 49.03950735926628, 45.82379311323166, 45.72928458452225, 48.78479182720184, 51.921082735061646, 50.96566200256348, 53.216843605041504, 57.95611649751663, 53.26686792075634, 56.594877541065216, 59.3145702034235, 57.53832511603832, 58.5335411131382, 60.98326586186886, 60.67315690219402, 58.75019408762455, 57.84608580172062, 59.31094139814377, 57.157262563705444, 57.00658544898033, 57.10057720541954, 62.54206761717796, 61.05073884129524, 70.00526994466782, 74.81403350830078, 84.44811254739761, 80.70728927850723, 88.43271553516388, 80.46019613742828, 91.01221472024918, 25.632067993283272, 1.0410751425661147, 41.545207500457764, 89.78908315300941, 72.62191593647003, 75.09217098355293, 73.05465951561928, 41.61051079630852, 74.06299620866776, 35.14627866446972, 0.652004104340449, 0.20916422945447266, 0.35308186314068735, 0.16820852790260687, 0.20718346699140966, 0.14021020528161898, 0.24194891477236524, 0.20591317734215409], [0.053169455932220444, 0.06510771767352708, 0.07645184567081742, 0.00597140740865143, 0.053237451502354816, 0.05430796241853386, 0.15478579269256443, 2.4538643890991807, 12.614717949181795, 27.577685192227364, 28.90307877212763, 47.462747767567635, 46.67195700109005, 50.98332725465298, 55.57000033557415, 77.12585985660553, 43.001559153199196, 0.010234440032945713, 0.4113548237364739, 0.15765322867082432, 4.955150233581662, 64.56004053354263, 72.11609467864037, 75.93009442090988, 75.70763155817986, 72.41997957229614, 70.53383678197861, 69.06445562839508, 66.38543218374252, 66.12180233001709, 64.82977285981178, 61.577865555882454, 62.4559186398983, 60.95418602228165, 57.53023535013199, 56.74927465617657, 51.932375729084015, 50.60873955488205, 49.47016105055809, 50.33518083393574, 50.5540718883276, 50.185343474149704, 48.1989848613739, 49.34946432709694, 49.169931560754776, 43.99798348546028, 41.302145943045616, 43.79518076777458, 47.966061159968376, 48.865932673215866, 53.620590940117836, 51.55909135937691, 48.596884310245514, 47.924358397722244, 53.87022614479065, 56.12882114946842, 51.56229458749294, 59.62378241121769, 62.05418139696121, 58.74326325953007, 62.53167897462845, 63.10220696032047, 61.561583429574966, 60.182607024908066, 59.61387634277344, 54.81796368956566, 55.588972717523575, 56.13612435758114, 54.741606786847115, 52.234326526522636, 52.212356105446815, 54.29387301206589, 69.74049255251884, 59.66491140425205, 32.57159002125263, 46.30420133471489, 43.48326310515404, 43.83985877037048, 43.78828413784504, 46.05486251413822, 51.56743571162224, 49.56537254154682, 52.24821478128433, 47.53840930759907, 48.189375177025795, 44.44602884352207, 47.274403274059296, 45.99691942334175, 48.779912889003754, 47.340629920363426, 46.50436319410801, 45.700417533516884, 46.53967849910259, 49.355745390057564, 48.06403890252113, 49.92291435599327, 49.3008953332901, 49.95897062122822, 46.39615640044212, 42.882834523916245, 42.5830952078104, 42.03566238284111, 47.09487810730934, 55.34441404044628, 54.51381281018257, 50.10692708194256, 48.19878347218037, 46.86591759324074, 47.170600444078445, 43.96648317575455, 46.73906899988651, 46.074682250618935, 47.53897547721863, 50.09320601820946, 52.121107801795006, 52.42557406425476, 53.57510358095169, 50.762935280799866, 52.21443459391594, 51.7949903011322, 49.065106585621834, 46.136208549141884, 48.85396331548691, 51.543269008398056, 50.147090926766396, 48.84780764579773, 47.911264300346375, 45.27181953191757, 41.39663927257061, 41.22132048010826, 40.78658580780029, 40.53196147084236, 43.84406514465809, 46.29573538899422, 47.12539426982403, 48.47324274480343, 48.71299467980862, 50.12194387614727, 51.06948383152485, 53.79974752664566, 51.8294620513916, 52.500722631812096, 50.92370085418224, 52.20021575689316, 49.31553974747658, 52.75975853204727, 53.10302831232548, 55.94075784087181, 54.91462670266628, 57.094474732875824, 57.2626157104969, 70.46873867511749, 72.86518648266792, 79.9026520550251, 77.49915182590485, 78.48532050848007, 69.70693275332451, 81.40762209892273, 8.632995206862688, 0.4167714627692476, 43.632245510816574, 73.68215024471283, 60.65519526600838, 60.618835017085075, 43.48950237035751, 36.13723888993263, 45.33233128488064, 18.636922650039196, 0.6140520970802754, 0.24915031506679952, 0.16458959318697453, 0.07881964556872845, 0.07031479646684602, 0.047237447288352996, 0.04669717120123096, 0.057823400929919444, 0.035864620440406725, 0.038652516741422005, 0.03227542358217761, 0.022063959513616282, 0.011541546700755134, 0.06591162687982433, 0.33220355689991266, 4.115821346640587, 25.93532022088766, 46.03191554546356, 29.126590378582478, 28.77790968865156, 52.55570188164711, 59.80920106172562, 62.79199540615082, 85.13235703110695, 47.33230836689472, 0.07245669403346255, 0.29945964517537504, 0.3988344658864662, 5.560483876615763, 76.23352333903313, 79.21763241291046, 80.69616347551346, 80.88552251458168, 77.65730693936348, 77.27754011750221, 75.5394221842289, 69.92692574858665, 69.3447133898735, 68.38894307613373, 64.00115132331848, 65.88281035423279, 61.63840010762215, 62.14281924068928, 59.53470379114151, 55.28078645467758, 53.96530844271183, 52.79419228434563, 52.79128924012184, 54.583865851163864, 53.771059066057205, 51.91639758646488, 51.23225949704647, 51.745349764823914, 47.52370409667492, 44.48123775422573, 47.473440393805504, 50.40291219949722, 50.65347075462341, 54.796111062169075, 52.610236555337906, 49.10535402595997, 49.275208711624146, 56.868364065885544, 59.481996819376945, 58.34246076643467, 61.10337741672993, 62.45988942682743, 64.33899879455566, 64.27619576454163, 65.09343311190605, 63.895851373672485, 60.172666758298874, 62.11269065737724, 58.2222656160593, 58.520777598023415, 59.84072797000408, 56.385246589779854, 52.95984819531441, 57.688496857881546, 57.889369279146194, 66.74880668520927, 55.81253372132778, 38.00253599882126, 48.08899976313114, 43.27748894691467, 46.09284147620201, 46.71381175518036, 49.32094305753708, 55.19961521029472, 53.49670238792896, 55.82134164869785, 50.25999806821346, 50.61977416276932, 47.25380077958107, 50.49426309764385, 50.17615556716919, 52.48387053608894, 48.715342953801155, 47.35224209725857, 47.27022349834442, 49.293918907642365, 52.501228004693985, 51.619500517845154, 54.21464346349239, 53.54210615158081, 53.074590638279915, 48.20595368742943, 42.37673208117485, 43.44692565500736, 43.08746874332428, 48.58839936554432, 56.58565543591976, 57.56393574178219, 50.50585627555847, 50.20613215863705, 49.15070079267025, 49.33722138404846, 46.95388667285442, 48.806788846850395, 48.98426212370396, 50.03974288702011, 53.39831046760082, 55.27430020272732, 55.29487989842892, 57.38624207675457, 55.2142596244812, 54.93293412029743, 54.48719143867493, 52.03533500432968, 48.108648508787155, 52.41297774016857, 53.06298986077309, 52.03992135822773, 50.33798508346081, 49.32071126997471, 47.56861388683319, 43.70417185127735, 44.809217154979706, 43.223509043455124, 42.59178154170513, 47.06615164875984, 50.46066530048847, 48.06271657347679, 51.21533900499344, 51.342943757772446, 51.732719242572784, 51.98228985071182, 57.053117752075195, 55.87949752807617, 58.359324261546135, 54.942027032375336, 55.03790348768234, 52.763516530394554, 55.593885853886604, 57.150582522153854, 57.64350727200508, 57.70153395831585, 60.16170434653759, 60.44007360935211, 73.5850578546524, 75.46560734510422, 83.9300787448883, 79.13837626576424, 82.23885789513588, 73.84190127253532, 83.22609052062035, 7.822265960276127, 0.1528521566069685, 49.378924146294594, 83.11820670962334, 66.48579239845276, 70.50299003720284, 51.56497724354267, 40.142170786857605, 57.04558655619621, 21.63306187838316, 0.6765090487897396, 0.26822535088285804, 0.1402651093667373, 0.09817629674216732, 0.05339082003047224, 0.0769734567438718, 0.04148977328441106, 0.09633295034291223, 0.13607182656414807, 0.14978334627812728, 0.26331108645536005, 0.12541369535028934, 0.1206319042830728, 0.1342558505712077, 0.40861448796931654, 5.640915110707283, 47.62597180902958, 64.15687456727028, 46.65540128946304, 59.89403910934925, 67.84792050719261, 67.01485320925713, 70.28357461094856, 89.80232924222946, 51.354776322841644, 0.2065623042290099, 0.8271838480141014, 0.45606678701005876, 7.614463660866022, 79.67727094888687, 80.92413604259491, 80.36818787455559, 80.88016480207443, 79.53452780842781, 79.68905791640282, 77.93820306658745, 71.28126427531242, 72.31256693601608, 71.23756662011147, 67.60179251432419, 68.73519569635391, 66.33591324090958, 66.33719757199287, 62.409203946590424, 56.09811119735241, 56.93753935396671, 54.663745164871216, 53.6459431797266, 58.10553967952728, 57.45792903006077, 54.60381478071213, 55.21326407790184, 55.171454921364784, 51.6233991086483, 48.431357592344284, 49.051712304353714, 53.03146295249462, 52.971654161810875, 59.77858230471611, 55.11159673333168, 51.774771586060524, 52.80817933380604, 56.48281775414944, 60.92465400695801, 58.1672977656126, 63.775276243686676, 64.71389427781105, 67.08859205245972, 66.25922575592995, 68.85079309344292, 66.19923457503319, 65.4395717382431, 65.0506018102169, 60.02239242196083, 61.6349270939827, 61.79804854094982, 57.57649406790733, 57.97150947153568, 57.233908250927925, 59.750555008649826, 66.11962124705315, 66.13104343414307, 42.7377013117075, 46.591621711850166, 46.752440482378006, 44.83823999762535, 48.210650235414505, 51.10921069979668, 57.607067227363586, 55.289039611816406, 60.22460997104645, 52.34189875423908, 51.494741812348366, 48.73560346662998, 53.139023780822754, 53.07454124093056, 55.70403814315796, 51.96534276008606, 51.78620897233486, 50.87037831544876, 51.85030773282051, 56.252702102065086, 55.444584265351295, 57.23503679037094, 56.10634535551071, 55.8026884496212, 50.68019092082977, 44.136767238378525, 44.29372541606426, 44.74073722958565, 49.7021310031414, 57.832224145531654, 60.529197826981544, 55.250331088900566, 53.89484502375126, 52.47598975896835, 54.109100326895714, 49.57262635231018, 52.327212542295456, 52.25946217775345, 53.7685701996088, 54.41493071615696, 55.58965668082237, 57.50798374414444, 60.55620677769184, 56.885113567113876, 58.74082379043102, 57.1085187792778, 55.468731969594955, 50.30678875744343, 55.03069907426834, 56.10938139259815, 55.17022378742695, 53.085119873285294, 51.980663537979126, 50.96455246210098, 46.50647968053818, 46.6274081915617, 48.28769490122795, 47.69915588200092, 51.41572505235672, 51.993989422917366, 52.59071700274944, 54.514116793870926, 54.59450148046017, 54.097035974264145, 54.4025319814682, 60.62079571187496, 58.82712475955486, 59.304911121726036, 56.63089580833912, 58.5941706597805, 54.87093284726143, 57.37437151372433, 60.49969241023064, 62.97795742750168, 60.542360320687294, 62.48177245259285, 62.407627031207085, 76.4961576461792, 76.66904076933861, 86.78644627332687, 80.76357185840607, 87.91775956749916, 76.5682701766491, 87.94063434004784, 11.25869706273079, 0.3608413436450064, 56.31782680749893, 86.97146594524384, 77.73804500699043, 77.2681774199009, 63.42702113091946, 43.80255617201328, 76.63166597485542, 26.47969800978899, 0.7533391448669136, 0.4119489574804902, 0.2736991352867335, 0.2989901031833142, 0.21846590767381713, 0.13826913287630305, 0.10122740684892051, 0.1582550213788636], [0.07740946108242497, 0.02803332045004936, 0.026231940646539442, 0.027162441692780703, 0.03396502295800019, 0.1075754634803161, 0.12934801314258948, 1.5463388990610838, 6.742490250617266, 21.202157400548458, 30.747169218957424, 46.7354591935873, 44.98732499778271, 56.726472079753876, 54.25161927938461, 75.36313444375992, 39.497995153069496, 0.06607525559957139, 0.09232449199771509, 0.08798876137007028, 3.9217543601989746, 63.90511527657509, 71.10594168305397, 79.99121010303497, 71.2671746313572, 74.4471175968647, 70.76598912477493, 67.77663633227348, 64.15635019540787, 65.01582607626915, 61.18892602622509, 62.98696294426918, 59.804310724139214, 55.67959405481815, 56.26030929386616, 54.5916136354208, 50.91639384627342, 51.58066660165787, 50.33152922987938, 50.38203991949558, 50.350581407547, 50.55446706712246, 50.630945563316345, 49.44192856550217, 49.1946492344141, 47.69439093768597, 42.03130781650543, 45.301062762737274, 47.23227493464947, 49.580906108021736, 50.48759825527668, 51.995790526270866, 46.867973282933235, 48.300329223275185, 51.88767112791538, 55.00060848891735, 54.87293154001236, 59.782689884305, 60.11765331029892, 59.1133937984705, 59.01420772075653, 59.58239123225212, 58.84727507829666, 58.313403725624084, 58.15552219748497, 58.90994131565094, 57.14064225554466, 55.66266216337681, 52.0563630759716, 56.27053074538708, 58.91934581100941, 49.136162772774696, 55.86049474775791, 37.19618506729603, 43.81256103515625, 44.93830382823944, 43.32007326185703, 47.34105169773102, 49.808464497327805, 45.9039194136858, 49.66178476810455, 52.53218114376068, 50.103005692362785, 47.34720356762409, 45.71996748447418, 47.492728158831596, 44.41048555076122, 44.84962798655033, 46.57684810459614, 45.58621846139431, 43.040016889572144, 44.59471106529236, 44.10375460982323, 48.513474985957146, 47.01529137790203, 50.03976188600063, 49.64288458228111, 49.495418295264244, 42.34317988157272, 39.47050742805004, 42.57218599319458, 36.56163051724434, 37.322117909789085, 43.08635540306568, 57.2275397926569, 51.6522129625082, 48.41211922466755, 46.87306880950928, 47.1261428296566, 47.66111992299557, 47.31987923383713, 47.928184792399406, 51.333554461598396, 53.356079533696175, 52.48010113835335, 55.44646516442299, 56.132468953728676, 59.026405066251755, 56.19331128895283, 56.54163099825382, 56.133472099900246, 47.8829900175333, 47.68294595181942, 51.929073706269264, 52.412844747304916, 48.42054717242718, 47.16952510178089, 43.889837488532066, 41.90755985677242, 41.15907981991768, 40.14014929533005, 39.48131404817104, 44.3806267529726, 47.47428014874458, 46.732666343450546, 48.81478361785412, 45.613132417201996, 48.81407305598259, 49.15570132434368, 52.464962750673294, 53.34026098251343, 51.97824686765671, 50.651259273290634, 49.18550692498684, 53.160222843289375, 51.972079798579216, 53.78714740276337, 52.70143166184425, 54.37117986381054, 58.201944306492805, 60.736134722828865, 69.31315988302231, 74.53111588954926, 76.37612968683243, 78.27597454190254, 74.51282367110252, 75.11406540870667, 69.4172514975071, 2.241886588744819, 0.033373508995282464, 48.329743444919586, 71.29411518573761, 59.11803334951401, 56.57366707921028, 42.81927913427353, 42.02198311686516, 51.04144513607025, 16.614260785281658, 0.7136942096985877, 0.14322567003546283, 0.14334043575217947, 0.04002847337687854, 0.03681593130750116, 0.01503251753092627, 0.0746404635719955, 0.035108505544485524, 0.07912181099527515, 0.10326524788979441, 0.05138404529134277, 0.10766924868221395, 0.03975786406954285, 0.05164919981325511, 0.1080886585987173, 2.3252436658367515, 14.680404905229807, 41.569655388593674, 35.47264315187931, 43.57919655740261, 55.6544204056263, 63.922358751297, 62.00268656015396, 83.54338109493256, 45.69956637918949, 0.15032642026199028, 0.5198317591566592, 0.5667170276865363, 5.140741774812341, 73.97063076496124, 76.53565272688866, 82.40904316306114, 75.67149549722672, 78.49054902791977, 74.97831389307976, 74.06966865062714, 68.6187395453453, 68.51397156715393, 66.31649628281593, 67.01083302497864, 63.01317773759365, 58.9372618496418, 58.61932530999184, 57.89538435637951, 54.49443764984608, 52.878372967243195, 53.449223935604095, 53.14691975712776, 53.62462252378464, 53.833417519927025, 52.54950061440468, 51.92908890545368, 52.08578109741211, 48.35095390677452, 45.08829317986965, 48.33328105509281, 49.9885406345129, 52.14570768177509, 54.749111384153366, 53.570775613188744, 48.76318238675594, 48.31413388252258, 55.41885584592819, 57.46536523103714, 57.76605449616909, 60.87973661720753, 62.659249529242516, 62.37707667052746, 63.98497939109802, 63.95075082778931, 59.12220932543278, 62.538123428821564, 58.7177400290966, 61.78555481135845, 58.412988781929016, 60.00921092927456, 54.9696097522974, 62.15999431908131, 57.408011108636856, 52.70662218332291, 54.251269698143005, 40.837001502513885, 45.38611359894276, 47.00027458369732, 46.01500265300274, 47.76271887123585, 52.47196577489376, 48.67674842476845, 54.773703664541245, 53.12724821269512, 51.978235468268394, 49.6655997633934, 50.957815423607826, 48.66613559424877, 46.4541070908308, 46.352724730968475, 48.62209975719452, 46.89540021121502, 45.048034340143204, 45.52779279649258, 47.18734234571457, 49.019984006881714, 51.38053514063358, 52.62758642435074, 51.37430727481842, 51.78909681737423, 45.859393402934074, 38.10223504900932, 42.594304606318474, 34.63199146091938, 36.92071884870529, 45.94294331967831, 59.83747534453869, 55.398595333099365, 48.70390176773071, 49.384551644325256, 50.66762499511242, 48.71694266796112, 48.20572569966316, 51.51136212050915, 54.597750306129456, 57.28382237255573, 55.326881781220436, 57.49943420290947, 59.82503481209278, 60.74661836028099, 57.598791271448135, 57.72100791335106, 56.965642645955086, 50.42030766606331, 49.51985478401184, 53.035711124539375, 52.78539575636387, 50.46243600547314, 49.242716655135155, 47.89082519710064, 43.83219838142395, 45.086476877331734, 42.20975004136562, 44.66275781393051, 47.00906351208687, 49.78588230907917, 50.94785615801811, 50.863006711006165, 48.593171909451485, 51.97538182139397, 51.904352232813835, 54.32660445570946, 55.18534317612648, 57.33759708702564, 53.363796919584274, 51.48846834897995, 57.61417664587498, 55.94509340822697, 56.22823901474476, 56.26136563718319, 59.315577149391174, 59.47813622653484, 65.080187022686, 75.39675503969193, 76.22927516698837, 80.57646989822388, 80.31412437558174, 79.0989799797535, 78.70510071516037, 73.09649527072906, 2.346788984723389, 0.06526169105200097, 49.843924194574356, 81.71513199806213, 63.77871885895729, 64.13054198026657, 51.7321340739727, 43.01209218800068, 66.42118826508522, 13.688550777733326, 0.4496124474098906, 0.12158400553744286, 0.0793504444300197, 0.10024785355199128, 0.034974573864019476, 0.0610893293924164, 0.012485016777645797, 0.07976969849551097, 0.2188769684289582, 0.22974738356424496, 0.2231792578822933, 0.22510812937980518, 0.14249535219278187, 0.1252681008190848, 0.44134815805591643, 3.245280934497714, 31.8491442874074, 65.65282389521599, 57.823127433657646, 63.180919736623764, 63.78534570336342, 74.42108139395714, 67.86534637212753, 89.78988111019135, 48.6122240871191, 0.2848723466740921, 0.9535268309991807, 0.5015449435450137, 6.526367822661996, 79.7342298924923, 78.92944067716599, 84.61848020553589, 76.18828296661377, 80.69411918520927, 77.98715963959694, 74.82490852475166, 69.18680146336555, 69.41523760557175, 65.94549179077148, 70.15211686491966, 66.55637741088867, 62.101245671510696, 63.21286082267761, 61.70884072780609, 57.52768948674202, 57.34838850796223, 56.39426350593567, 56.07935920357704, 56.29217818379402, 57.08003930747509, 55.310082882642746, 54.565961211919785, 57.17458963394165, 54.29751321673393, 48.018840327858925, 51.46416865289211, 54.73022639751434, 55.660044103860855, 56.312427297234535, 57.106960862874985, 50.962872952222824, 49.86532464623451, 58.23914431035519, 59.99787613749504, 60.73635511100292, 62.9754039645195, 65.23157849907875, 64.85795214772224, 66.15368261933327, 67.52809166908264, 63.37854713201523, 62.45061032474041, 63.791045397520065, 64.38227847218513, 59.321409836411476, 61.62375949323177, 57.49487444758415, 61.166590824723244, 65.68638369441032, 57.026636973023415, 64.20994251966476, 48.02176237106323, 44.37886744737625, 48.58287066221237, 47.32715964317322, 48.24239753186703, 52.229386791586876, 51.77671328186989, 56.84872291982174, 58.33789721131325, 55.81927075982094, 52.326612174510956, 54.9777527153492, 50.853343829512596, 47.627898305654526, 49.7883103787899, 50.19229710102081, 49.88998532295227, 47.502733021974564, 49.954912438988686, 48.970917239785194, 52.396216839551926, 53.29381227493286, 55.78132599592209, 56.03756904602051, 55.91214917600155, 47.382518872618675, 39.692548513412476, 44.45818819105625, 38.689086958765984, 41.84329770505428, 49.74650502204895, 60.75518690049648, 55.54319277405739, 52.358872443437576, 51.8689077347517, 53.07122781872749, 51.617855206131935, 50.995133221149445, 52.90908671915531, 56.35892540216446, 59.26144525408745, 57.61127360165119, 59.84807677567005, 60.9471146017313, 63.02990064024925, 59.16979797184467, 60.998123064637184, 60.53371958434582, 51.55715726315975, 51.40980117022991, 54.15349334478378, 56.54760427772999, 51.465654373168945, 52.1241058409214, 50.65206103026867, 47.19490773975849, 48.27468439936638, 46.88382603228092, 46.21085934340954, 50.10629251599312, 52.97965653240681, 52.626879662275314, 53.881815522909164, 49.83496807515621, 54.66481290757656, 53.663243651390076, 57.91290521621704, 57.85345360636711, 59.84833136200905, 56.01546563208103, 54.503944739699364, 59.945416152477264, 57.76934511959553, 58.46199095249176, 59.33616064488888, 60.752660036087036, 65.1647324860096, 67.33042627573013, 75.40395185351372, 80.39699792861938, 85.84875538945198, 81.58318787813187, 84.21171203255653, 78.46290171146393, 78.80207151174545, 3.658768334425986, 0.15529070544289425, 56.51278294622898, 89.92050290107727, 72.83310860395432, 72.50039085745811, 62.0227836817503, 50.45680470764637, 85.39597928524017, 22.868022210896015, 0.6915457325521857, 0.24515779805369675, 0.19300414191093296, 0.18675603030715138, 0.13861883286153898, 0.12051192868966609, 0.23062197491526604, 0.1926750291022472], [0.0517815507191699, 0.05139068380231038, 0.05600883872830309, 0.03590568347135559, 0.04542858849163167, 0.033127902643173, 0.03001234999828739, 0.3014359250664711, 0.5178004712797701, 16.794523112475872, 18.188894391059875, 14.63657995685935, 44.18071188032627, 44.175209775567055, 52.04502448439598, 71.60265102982521, 49.73938800394535, 0.15992869797628373, 0.13273498218040913, 0.21872701006941497, 3.1631003692746162, 64.8504589498043, 69.27652224898338, 76.27661302685738, 74.05359551310539, 73.96831288933754, 71.07721522450447, 68.76724317669868, 64.03816133737564, 64.06055733561516, 61.557054072618484, 61.176477894186974, 59.02986288070679, 56.46731838583946, 52.07746334373951, 50.04194296896458, 49.784085005521774, 51.74642130732536, 50.40242962539196, 48.53750869631767, 50.55574759840965, 50.208959206938744, 48.73753376305103, 48.40113781392574, 48.062066808342934, 45.50891540944576, 44.48548212647438, 42.98591159284115, 45.98633699119091, 49.79016847908497, 53.72352361679077, 52.30325862765312, 46.013019159436226, 44.71639193594456, 54.69924286007881, 58.59091803431511, 57.34701678156853, 60.52946001291275, 60.33837206661701, 59.86549884080887, 59.876970425248146, 57.37052612006664, 58.9038198441267, 61.57079793512821, 55.89997082948685, 58.943508714437485, 55.56390166282654, 55.291482880711555, 56.68859951198101, 54.45359744131565, 35.4994735121727, 47.53323018550873, 40.87412931025028, 44.002600237727165, 47.088243663311005, 42.56756164133549, 44.52411845326424, 47.29888916015625, 50.66583529114723, 46.419749334454536, 50.499951392412186, 50.096591636538506, 53.2833856344223, 47.947537153959274, 47.455398961901665, 44.37529183924198, 45.47895401716232, 43.76652270555496, 44.68483082950115, 41.506122797727585, 42.15386264026165, 42.636375948786736, 46.798942387104034, 45.232795625925064, 46.20428949594498, 49.87921290099621, 53.20459306240082, 48.6428352445364, 47.5507016479969, 42.563408464193344, 41.50900684297085, 31.185346506536007, 36.40388198196888, 37.36129380762577, 46.62697121500969, 59.187919199466705, 48.97360369563103, 49.70865525305271, 45.67772515118122, 45.68831518292427, 49.627947583794594, 48.65958854556084, 53.27116549015045, 56.012072414159775, 55.5253641307354, 54.23811860382557, 55.57348474860191, 56.587030962109566, 59.189686104655266, 55.25971658527851, 56.019877195358276, 54.137142822146416, 49.361878260970116, 52.5313375890255, 55.19600920379162, 50.035483315587044, 47.53121629357338, 46.55467249453068, 45.1548770070076, 39.61120247840881, 39.604480639100075, 40.04796624183655, 43.666812255978584, 46.74258381128311, 47.87016190588474, 46.66463479399681, 48.99918012320995, 49.49228726327419, 47.81254939734936, 49.25533577799797, 49.86198842525482, 48.27321007847786, 49.366757199168205, 49.34743903577328, 50.327281057834625, 53.34781877696514, 52.33447775244713, 52.62382462620735, 55.85240118205547, 53.49515587091446, 62.58225426077843, 69.73955780267715, 72.91114121675491, 73.19792702794075, 72.84963771700859, 76.3366574048996, 79.01200264692307, 60.52433028817177, 1.4709237520582974, 0.043427609925856814, 43.733836859464645, 71.45468696951866, 51.98693700134754, 52.78007224202156, 43.24576444923878, 37.442290261387825, 47.137603014707565, 7.556746657937765, 0.6278244580607861, 0.0936145821469836, 0.14267371996538714, 0.025181165292451624, 0.05167278526641894, 0.06751260269084014, 0.04168640902207699, 0.10631797587848268, 0.04778566806635354, 0.07375010900432244, 0.015513944090344012, 0.106139081181027, 0.02976553951157257, 0.07291776069905609, 0.05598823670879938, 0.6492722290568054, 3.386977231130004, 41.76168568432331, 22.349256947636604, 20.137585625052452, 60.33342093229294, 50.804258063435555, 62.739204838871956, 79.77329939603806, 55.351208075881004, 0.30925934901461005, 0.32816947961691767, 0.6188441743142903, 4.088046737015247, 75.72074085474014, 75.96752241253853, 78.62017527222633, 76.69417262077332, 77.59987682104111, 73.9483791589737, 73.15284624695778, 65.9491091966629, 67.92898535728455, 64.92423579096794, 64.40703794360161, 61.23392701148987, 60.136952474713326, 55.081741735339165, 52.534225434064865, 54.90264214575291, 52.91892059147358, 55.07584065198898, 52.15439401566982, 52.31435023248196, 54.13531132042408, 52.20966584980488, 52.13738612830639, 50.156719610095024, 48.65848660469055, 47.03024737536907, 48.255404233932495, 49.917917624115944, 51.38605244457722, 56.53589330613613, 54.042968675494194, 49.234999269247055, 45.983331352472305, 59.81675885617733, 60.463339760899544, 58.48510891199112, 61.88398852944374, 62.079309448599815, 61.6101448237896, 62.32427850365639, 59.964377135038376, 62.238498106598854, 61.83457978069782, 58.774850964546204, 61.117155477404594, 58.33883196115494, 55.63448667526245, 60.81931225955486, 49.56536874175072, 42.433683425188065, 53.790327832102776, 42.219450920820236, 47.062184661626816, 45.07019095122814, 45.80947168171406, 47.118531838059425, 49.67291817069054, 51.85687378048897, 49.2020208388567, 52.16057628393173, 53.382689505815506, 54.52784925699234, 51.533963307738304, 50.278358682990074, 47.20652751624584, 47.06693060696125, 48.24791103601456, 48.16437251865864, 44.09168265759945, 43.84920246899128, 46.061056181788445, 49.25872139632702, 47.955778911709785, 49.90524150431156, 51.34850285947323, 55.377080887556076, 51.315501630306244, 49.53270569443703, 44.09348376095295, 42.88113221526146, 32.577217519283295, 36.71145647764206, 38.322851210832596, 49.09070961177349, 61.58616051077843, 53.50217029452324, 53.59975665807724, 49.77469190955162, 47.616346925497055, 50.77206999063492, 53.70252974331379, 56.00743666291237, 57.318468913435936, 56.01268798112869, 59.17001836001873, 58.57060432434082, 57.85478733479977, 61.999920308589935, 57.47453413903713, 58.08289669454098, 55.66169701516628, 50.260488241910934, 55.59032164514065, 55.34199737012386, 51.130253970623016, 49.7197088599205, 48.950440138578415, 46.96967862546444, 43.180548548698425, 41.19670920073986, 43.54037024080753, 45.568883791565895, 50.80396927893162, 48.960900977253914, 50.56212365627289, 49.594281390309334, 51.757740899920464, 49.8463598638773, 52.1474289894104, 52.19106204807758, 52.90885113179684, 52.63146601617336, 52.39620923995972, 53.916184678673744, 56.074252277612686, 56.05906829237938, 57.434902265667915, 59.217641204595566, 57.08613038063049, 65.91212958097458, 75.37607654929161, 76.25414103269577, 77.1538795530796, 76.46791756153107, 81.43667533993721, 80.16600832343102, 70.94307482242584, 2.1769091254100204, 0.02898400791309541, 46.47644229233265, 82.29480609297752, 59.74055394530296, 62.61126570403576, 47.32755862176418, 41.13613665103912, 60.324130430817604, 11.289451662451029, 0.4178047104505822, 0.18865291523979977, 0.09842061917879619, 0.043272608672850765, 0.08532042877050117, 0.042260126283508725, 0.05978442226478364, 0.07318419171497226, 0.19011741009308025, 0.17846098635345697, 0.18570593587355688, 0.15854628465604037, 0.22367713507264853, 0.17986382357776165, 0.24731580022489652, 1.117996908724308, 13.839128147810698, 67.03783437609673, 38.396065682172775, 26.97225607931614, 59.88233953714371, 61.91030591726303, 68.42727541923523, 84.57531452178955, 60.10253392159939, 0.40196953515987843, 0.9281832596752793, 0.7460700161755085, 6.047002170234919, 81.93818002939224, 76.20148345828056, 80.79969272017479, 78.04693803191185, 78.29658463597298, 76.7886583507061, 74.99607414007187, 68.24246853590012, 69.59663987159729, 67.57337763905525, 68.30853179097176, 64.28447932004929, 63.28371562063694, 57.65594780445099, 54.9964515119791, 57.12414354085922, 56.79479241371155, 57.89854198694229, 53.701583594083786, 55.11266067624092, 56.227927431464195, 54.99564215540886, 53.69635507464409, 52.43207171559334, 51.22727416455746, 51.48138552904129, 51.630383133888245, 51.56974218785763, 54.10920672118664, 59.782625287771225, 57.11872883141041, 49.900202974677086, 46.21104933321476, 59.59320925176144, 65.20174250006676, 60.38703605532646, 64.60120752453804, 64.07428979873657, 65.55352002382278, 64.18326795101166, 61.896987631917, 66.15755081176758, 67.16803058981895, 60.19970990717411, 63.515233397483826, 60.280672162771225, 59.895038455724716, 58.30660969018936, 57.174532637000084, 44.41186487674713, 51.441035494208336, 41.50628238916397, 47.98806197941303, 45.68943992257118, 45.162427201867104, 48.55687625706196, 49.31381084024906, 55.821163058280945, 53.14237900078297, 56.940260007977486, 55.426979809999466, 59.68714401125908, 53.00126977264881, 53.67452144622803, 49.489296823740005, 51.815984174609184, 50.00930272042751, 51.71830661594868, 47.06307761371136, 45.986648574471474, 47.370701506733894, 52.675011679530144, 49.976084902882576, 50.49295596778393, 54.638206735253334, 60.08101187646389, 54.4164202362299, 52.64919586479664, 43.62072832882404, 43.45940798521042, 34.413499385118484, 37.174290642142296, 39.28744465112686, 54.94632460176945, 64.12649139761925, 56.61436289548874, 55.88605597615242, 52.473831474781036, 51.20257169008255, 55.434765592217445, 53.46047133207321, 58.98110389709473, 60.16929633915424, 58.956439420580864, 59.744646325707436, 60.38180373609066, 61.456526666879654, 62.693060114979744, 59.208164513111115, 61.08825042843819, 59.102279394865036, 53.45528841018677, 56.396231800317764, 57.44744539260864, 53.35826441645622, 52.75821961462498, 53.95046263933182, 50.598058328032494, 47.007524594664574, 44.01590332388878, 45.62884457409382, 48.10485251247883, 52.364591136574745, 51.32746338844299, 53.07250455021858, 53.47790479660034, 54.57451455295086, 51.21275894343853, 54.706793054938316, 54.5876694470644, 54.88895148038864, 54.464198872447014, 55.06970018148422, 55.291543677449226, 60.73549635708332, 57.15154767036438, 59.597890600562096, 63.581133261322975, 59.80932645499706, 67.76381582021713, 76.91276729106903, 80.1256088912487, 81.6641691327095, 77.0122991502285, 85.84614872932434, 83.5388745367527, 75.46136677265167, 2.599930688738823, 0.16640487156109884, 51.97414688766003, 90.03975570201874, 61.81284114718437, 72.56102800369263, 56.66819840669632, 50.484026446938515, 82.72729128599167, 14.746820591390133, 0.6739432958420366, 0.2182005305076018, 0.18969214463140815, 0.19768336816923693, 0.14920840447302908, 0.18005688587436453, 0.2102571606519632, 0.1680889233830385], [0.0605055337655358, 0.04154172733251471, 0.04644159780582413, 0.05681160131643992, 0.050580009919940494, 0.17953656613826752, 0.06851094716694206, 0.2166004601167515, 0.8995914564002305, 12.713359706103802, 32.89686776697636, 26.56458355486393, 34.3432829529047, 50.02056531608105, 50.34727558493614, 66.8289215862751, 58.628558814525604, 1.199807112570852, 0.4477729008067399, 0.6335487321484834, 2.8223945014178753, 62.487574741244316, 70.34108832478523, 74.87340152263641, 73.66930693387985, 75.15082463622093, 70.39091885089874, 70.42621895670891, 66.14475309848785, 62.46295586228371, 60.17200939357281, 58.63169364631176, 56.35384887456894, 51.2392321228981, 51.01251348853111, 52.10766792297363, 52.05458477139473, 50.76524555683136, 50.15201546251774, 51.92153491079807, 49.45495426654816, 50.55088385939598, 49.44279111921787, 48.79290819168091, 48.417226150631905, 45.698677226901054, 44.28471989929676, 44.53024372458458, 46.63931295275688, 46.30072072148323, 50.08657157421112, 53.11545744538307, 48.81563477218151, 48.17182011902332, 60.43402053415775, 62.522312477231026, 57.73042380809784, 60.52553862333298, 58.602534011006355, 57.157467752695084, 56.900058165192604, 56.817762181162834, 58.466436713933945, 55.98288998007774, 54.387572184205055, 56.807069554924965, 62.44395308196545, 55.19471727311611, 48.044462352991104, 39.50334906578064, 50.946564227342606, 59.767756685614586, 46.44892416894436, 45.481872260570526, 45.836773216724396, 42.247105836868286, 45.005134642124176, 46.725135147571564, 45.78840561211109, 44.416918605566025, 47.69996903836727, 53.303847536444664, 51.354441940784454, 50.09942248463631, 46.58802330493927, 43.85619029402733, 42.12986692786217, 44.00422275066376, 40.810315534472466, 38.316676542162895, 41.891680508852005, 42.02001862227917, 43.82248230278492, 45.71402460336685, 49.6296650916338, 52.78333246707916, 50.289248898625374, 50.956766679883, 40.55443726480007, 46.539553105831146, 42.34826020896435, 42.704240307211876, 39.254097640514374, 40.273902118206024, 35.990870743989944, 49.031330198049545, 58.10992084443569, 50.5486723780632, 51.62877582013607, 53.705140203237534, 48.98450531065464, 52.29722075164318, 52.97648370265961, 54.35852274298668, 56.86082147061825, 58.59651133418083, 58.43993313610554, 56.195366978645325, 55.54984241724014, 55.26492990553379, 56.8366851657629, 58.53004150092602, 49.83048051595688, 52.85006448626518, 52.993058413267136, 50.95922514796257, 49.71839413046837, 45.06085105240345, 43.319047316908836, 42.02439598739147, 41.20374642312527, 41.68195076286793, 44.1559524089098, 47.098833695054054, 47.055348828434944, 45.26079632341862, 47.36780606210232, 48.09774309396744, 49.19463783502579, 47.53854990005493, 48.52386362850666, 51.59300833940506, 50.679077580571175, 49.09926675260067, 49.13128383457661, 53.020720928907394, 52.24146634340286, 53.9350126683712, 52.83522628247738, 57.360091879963875, 64.74303871393204, 70.73300689458847, 72.37129658460617, 74.88021835684776, 73.62270623445511, 76.77024453878403, 73.50175112485886, 69.26249340176582, 3.0288585601374507, 0.06604830821743235, 46.110122948884964, 72.91851282119751, 53.06278847157955, 49.76472124457359, 48.46142157912254, 40.02786532044411, 42.63475343585014, 6.1066665686666965, 0.7227336871437728, 0.06006580384564586, 0.1621044523199089, 0.02289716685481835, 0.050037036126013845, 0.017535277911520097, 0.04228896243148483, 0.10866275435546413, 0.10132658004295081, 0.005669173333444633, 0.07164157839724794, 0.1290745910955593, 0.07434047263814136, 0.12872110615717247, 0.1066175066807773, 0.5420822370797396, 1.1184310354292393, 31.592452861368656, 42.043881341814995, 21.360806487500668, 47.45068721473217, 60.460527911782265, 58.18764187395573, 77.38316684961319, 64.4402177631855, 1.2775580654852092, 0.6363360013347119, 0.9572864917572588, 3.3231686800718307, 70.52098587155342, 74.31065171957016, 79.70080688595772, 77.38696664571762, 79.52123612165451, 74.85183387994766, 75.78811123967171, 68.88202741742134, 67.08473145961761, 61.3248485326767, 61.726475581526756, 60.4705897718668, 56.800894886255264, 54.638997092843056, 56.366133615374565, 55.75880840420723, 55.510123148560524, 53.97113732993603, 56.15831896662712, 54.28294479846954, 54.94347095489502, 52.404595389962196, 52.13392071425915, 50.94331920146942, 49.87064056098461, 45.953848734498024, 47.129448652267456, 49.05803516507149, 49.751319363713264, 54.05399948358536, 56.714586317539215, 49.44217935204506, 48.11411641538143, 60.28088495135307, 65.61097294092178, 61.582771092653275, 64.46784988045692, 59.63728688657284, 60.8033113181591, 58.38284119963646, 58.41652259230614, 60.56964285671711, 62.1195150911808, 58.621415197849274, 60.066591650247574, 61.5878514200449, 54.96629633009434, 46.69203132390976, 43.9373729377985, 55.84913335740566, 53.26905660331249, 48.88300135731697, 46.132986322045326, 48.87775003910065, 45.26568666100502, 47.143880277872086, 48.09978738427162, 49.20813471078873, 46.85867138206959, 51.37466445565224, 55.32260321080685, 53.19263890385628, 51.50988779962063, 48.70871610939503, 46.10463224351406, 43.53102274239063, 45.473801493644714, 42.95489385724068, 42.29990400373936, 44.155359640717506, 44.902669340372086, 45.43640770018101, 47.443437203764915, 51.45681984722614, 54.22929547727108, 54.65398348867893, 51.86871774494648, 42.98361271619797, 49.47529837489128, 43.005229756236076, 45.421622693538666, 40.775353610515594, 40.956881269812584, 37.882781624794006, 50.545149967074394, 59.22405906021595, 51.61280907690525, 53.24406534433365, 55.87511636316776, 51.94049209356308, 55.28561979532242, 57.37382814288139, 56.47885836660862, 58.114947974681854, 60.42671352624893, 59.181402549147606, 59.668961986899376, 55.904291197657585, 58.95568326115608, 57.77177318930626, 59.6462582051754, 51.31120786070824, 56.61764971911907, 55.14364041388035, 54.421530961990356, 52.33947068452835, 47.1168827265501, 46.28527455031872, 45.37553496658802, 44.43126283586025, 42.92208641767502, 48.003815934062004, 48.84689949452877, 50.327376052737236, 48.898139744997025, 50.61419986188412, 52.64788493514061, 50.85092715919018, 52.21711345016956, 51.75945080816746, 54.004210755228996, 54.688793420791626, 52.88474902510643, 53.497614338994026, 56.34477876126766, 56.157190427184105, 57.174122259020805, 56.595846489071846, 59.97221611440182, 67.94663161039352, 75.31462624669075, 74.48993369936943, 79.43764060735703, 76.99259340763092, 80.90753853321075, 74.55849722027779, 77.64347568154335, 4.234719816595316, 0.12861198076279834, 48.53166840970516, 84.54675525426865, 60.817803740501404, 55.04120171070099, 55.07352277636528, 46.165862157940865, 57.98499874770641, 9.048858191817999, 0.3861450171098113, 0.09693678395706229, 0.0460002500039991, 0.016777046039351262, 0.06682567080133595, 0.08910544129321352, 0.03480336410575546, 0.05201940533879679, 0.302423782995902, 0.1028316629526671, 0.2643300255294889, 0.2911966620013118, 0.14547584694810212, 0.3457020950736478, 0.5816511169541627, 1.2792431563138962, 5.965429097414017, 56.611991822719574, 65.51716357469559, 40.462136417627335, 45.92131108045578, 71.73438236117363, 64.37520325183868, 81.42102017998695, 70.54323747754097, 1.977266175672412, 1.206670613028109, 1.5759465540759265, 4.81091994792223, 75.05088239908218, 75.4369492828846, 81.17810681462288, 79.95603159070015, 80.89208856225014, 75.7314182817936, 76.39753013849258, 71.9019989669323, 68.9373904466629, 63.133251294493675, 64.06045094132423, 62.99750737845898, 57.06509850919247, 55.51847890019417, 58.28805908560753, 57.34662540256977, 58.01936790347099, 56.414866000413895, 58.604137524962425, 55.84190234541893, 56.42608679831028, 55.546688586473465, 54.76757079362869, 54.406111389398575, 52.79361851513386, 49.94685687124729, 51.25246301293373, 52.860133945941925, 52.8414161503315, 56.594277173280716, 58.8441326469183, 51.46243594586849, 49.45913404226303, 63.67656134068966, 67.40531265735626, 61.724879667162895, 64.61791902780533, 64.39040243625641, 62.62394942343235, 61.576425433158875, 60.47641105949879, 63.98019164800644, 65.52230089902878, 61.4156598597765, 61.55298829078674, 62.26355396211147, 55.74179291725159, 52.46285766363144, 41.935328766703606, 51.14641830325127, 53.708579018712044, 51.89147852361202, 49.225644171237946, 50.254400968551636, 48.65905277431011, 48.90173815190792, 51.738988906145096, 52.538693994283676, 49.99558165669441, 53.59747678041458, 59.314744994044304, 55.21385684609413, 55.4944109916687, 50.7872349768877, 49.872916638851166, 47.30404928326607, 49.020379185676575, 45.409763529896736, 46.2177711725235, 46.51048846542835, 46.72262728214264, 48.535563200712204, 51.11996032297611, 56.43713280558586, 56.865491420030594, 57.626275196671486, 55.63496544957161, 46.10342390835285, 51.170607805252075, 44.930092468857765, 45.521815717220306, 40.60716323554516, 42.60357990860939, 40.03014139831066, 52.52783037722111, 62.211709544062614, 56.74899347126484, 56.557780131697655, 59.04468968510628, 55.65920814871788, 58.887632712721825, 59.19883981347084, 58.34150321781635, 60.731358379125595, 64.39714327454567, 62.78517097234726, 62.5239197909832, 58.0257211625576, 59.89853426814079, 60.789799243211746, 63.40772196650505, 53.273175582289696, 57.52822145819664, 56.512323170900345, 55.814885795116425, 55.91028727591038, 50.15697039663792, 48.65423083305359, 49.96895268559456, 47.67989471554756, 46.87418594956398, 51.58914014697075, 50.43174125254154, 53.67769047617912, 50.53113251924515, 52.529183104634285, 55.73171965777874, 54.01923514902592, 52.842202708125114, 54.26489196717739, 57.55197398364544, 56.694614589214325, 56.15604668855667, 54.91170845925808, 60.95399983227253, 60.31017757952213, 61.759883388876915, 58.347328305244446, 64.92006361484528, 71.57490491867065, 78.40582877397537, 77.48045682907104, 83.48275154829025, 79.09813642501831, 83.520947098732, 75.2672427892685, 81.68978735804558, 4.939733510836959, 0.3218399692559615, 55.529125928878784, 89.71259325742722, 66.80975541472435, 66.15307465195656, 66.21730640530586, 55.75736828148365, 73.05452272295952, 14.779290799051523, 1.1449545621871948, 0.29121076280716807, 0.3258160105906427, 0.20937982335453853, 0.21808932709973305, 0.26978976849932224, 0.17766429082257673, 0.18171815376263112], [0.02230595902801724, 0.12426621629856527, 0.019660321304399986, 0.04099590369150974, 0.019621718492999207, 0.1101475692121312, 0.09284068539272994, 0.05110587349918205, 1.8172890599817038, 14.339640140533447, 36.029066294431686, 26.10788606107235, 37.35904052853584, 50.26571676135063, 57.84471407532692, 59.416929110884666, 68.73334139585495, 3.5908215679228306, 0.7079008861910552, 0.3094118752051145, 1.7818386247381568, 56.79188936948776, 70.25534212589264, 73.58746692538261, 73.23613777756691, 74.96809244155884, 71.20826259255409, 66.72191932797432, 65.27563333511353, 60.19326165318489, 58.3196771889925, 52.92260259389877, 54.10062298178673, 51.839687302708626, 54.716250747442245, 55.83898030221462, 57.10526615381241, 57.77662932872772, 53.739433363080025, 54.21770989894867, 50.71649797260761, 50.76761282980442, 49.0933732688427, 50.17129182815552, 48.014801144599915, 47.644773200154305, 45.216418504714966, 43.377735167741776, 44.28173325955868, 48.03023211658001, 51.110350638628006, 52.22559079527855, 51.496147736907005, 49.316934272646904, 56.30947485566139, 62.1749085187912, 61.40908621251583, 58.111098781228065, 56.90447352826595, 58.43822702765465, 57.90768049657345, 57.41351701319218, 55.32509207725525, 57.858815118670464, 56.67011350393295, 52.72854320704937, 54.53088529407978, 58.77214930951595, 36.74255780875683, 69.53376844525337, 58.35526987910271, 45.04480071365833, 45.349247977137566, 43.37830513715744, 46.36666238307953, 41.95020116865635, 42.31727287173271, 43.038800954818726, 47.37018093466759, 44.10565070807934, 46.303433775901794, 52.684112191200256, 50.870382115244865, 48.61473195254803, 47.514174208045006, 42.12806962430477, 38.3344291895628, 41.589570119977, 40.247018560767174, 38.545230478048325, 40.05938082933426, 41.02760307490826, 42.0634388923645, 43.39219719171524, 46.92125782370567, 52.4249242991209, 50.757790356874466, 44.19249504804611, 40.48349887132645, 45.41478306055069, 45.524771958589554, 40.95542214810848, 40.60889594256878, 41.02505341172218, 38.20196069777012, 36.681362092494965, 50.07509998977184, 54.713043719530106, 49.86564762890339, 50.19507095217705, 52.641980051994324, 53.735815957188606, 54.994164034724236, 53.29518020153046, 53.50318863987923, 56.745140478014946, 55.506479144096375, 56.81530371308327, 57.012737318873405, 57.403500750660896, 58.68642970919609, 57.77470663189888, 51.82884268462658, 50.85290305316448, 52.898112908005714, 52.41802766919136, 49.01599422097206, 45.02029202878475, 44.26950931549072, 40.8954955637455, 39.91717346012592, 40.179317593574524, 43.902878388762474, 48.058844581246376, 46.72017641365528, 47.21034251153469, 46.268627643585205, 47.24538043141365, 48.15668933093548, 48.49540315568447, 50.13344205915928, 48.29992264509201, 47.81128786504269, 51.72891944646835, 50.60138314962387, 50.9521347284317, 51.12066328525543, 51.477042362093925, 53.053117990493774, 52.42996662855148, 62.20191366970539, 72.00976878404617, 70.30875205993652, 71.71029925346375, 71.84278294444084, 72.61153489351273, 74.84420388936996, 74.60002899169922, 5.86582456715405, 0.1870959042571485, 41.52021624147892, 71.49672031402588, 44.0776652097702, 52.005787789821625, 41.24529339373112, 29.429645016789436, 43.91226388514042, 5.183353638276458, 0.402791389496997, 0.07448825650499202, 0.13438171881716698, 0.05172368917556014, 0.03162532448186539, 0.02896067479014164, 0.0354837576742284, 0.06974214047659189, 0.04240867456246633, 0.04606407099345233, 0.09262072024284862, 0.07645867342944257, 0.05964551819488406, 0.11348289961460978, 0.055056047276593745, 0.1643069091369398, 2.8072090912610292, 20.16496505588293, 47.22798116505146, 24.76181399077177, 47.36180618405342, 59.8205928504467, 63.68124648928642, 67.8254409134388, 74.37579542398453, 4.258574936538935, 0.9076700010336936, 1.1785808578133583, 2.039663102477789, 67.29911595582962, 75.65606832504272, 79.02075737714767, 77.62503147125244, 80.69395959377289, 74.60635185241699, 71.61740943789482, 68.36622029542923, 64.98321622610092, 61.33567415177822, 59.282948300242424, 55.52565671503544, 55.434309616684914, 58.1586342304945, 59.86640319228172, 59.40427578985691, 59.39604923129082, 54.93799164891243, 59.50998231768608, 52.15993411839008, 55.30111536383629, 53.9492467045784, 53.31568390130997, 51.13432355225086, 51.571205109357834, 48.37647333741188, 46.03525556623936, 48.4890802949667, 51.02450184524059, 53.826437294483185, 54.24264796078205, 51.45676665008068, 52.16971859335899, 59.16176900267601, 64.77279111742973, 63.1083170324564, 61.711827367544174, 58.62348608672619, 61.68788105249405, 58.54668080806732, 58.07167589664459, 56.58678017556667, 60.7821274548769, 58.816219344735146, 55.686456486582756, 52.88536839187145, 52.00330652296543, 43.308901861310005, 72.14898571372032, 51.630417332053185, 46.82852379977703, 46.072409972548485, 43.774544075131416, 47.04282850027084, 43.57530176639557, 45.03658935427666, 46.90910987555981, 49.57775987684727, 47.908992022275925, 47.91762135922909, 53.9663115888834, 52.58968725800514, 52.474234253168106, 49.89055909216404, 45.40561035275459, 40.95742464065552, 43.18311721086502, 43.005613535642624, 40.36724030971527, 43.71092788875103, 43.240429535508156, 43.44321325421333, 44.9536208063364, 48.56217697262764, 54.14614833891392, 53.23911800980568, 48.342537358403206, 43.92403565347195, 47.13992469012737, 47.36982375383377, 40.99101863801479, 42.761993408203125, 42.86692097783089, 39.964416325092316, 37.03878231346607, 52.265899032354355, 57.538644298911095, 54.15781371295452, 50.847005769610405, 56.066705882549286, 55.340625643730164, 56.60405024886131, 56.7842061817646, 54.345896020531654, 58.058464005589485, 56.115103885531425, 58.47289636731148, 58.83302204310894, 58.80064398050308, 58.011608719825745, 60.91033637523651, 56.16982474923134, 52.02775441110134, 52.745376303792, 55.64728058874607, 49.779361858963966, 48.31430487334728, 47.68476985394955, 43.453522101044655, 43.04977856576443, 43.34556229412556, 45.94215676188469, 50.245783030986786, 48.96227270364761, 50.03758080303669, 49.62935350835323, 51.1260399967432, 49.697339460253716, 51.8895710259676, 52.01831951737404, 51.54346279799938, 52.739102840423584, 55.749080926179886, 54.19719099998474, 55.323974937200546, 54.555937349796295, 55.7682166993618, 54.99449081718922, 56.78244307637215, 66.56577810645103, 75.72843924164772, 72.35757932066917, 74.67876836657524, 74.28733617067337, 79.47810083627701, 76.61727234721184, 83.8472431898117, 7.147535216063261, 0.22770529001718387, 42.624182403087616, 83.40163350105286, 47.043447867035866, 61.277400478720665, 47.97999881207943, 42.129418551921844, 60.87162405252457, 8.819299209862947, 0.6316073331981897, 0.0655297696357593, 0.09589310910087079, 0.06499738999991678, 0.08902427260181867, 0.013743701092607807, 0.06438569704187103, 0.07412434439174831, 0.2723589650122449, 0.1455150917172432, 0.15383075253339484, 0.20876202994259074, 0.08860992413247004, 0.25420719059184194, 0.25395233707968146, 0.32542795641347766, 3.1471443129703403, 47.53655880689621, 62.61428654193878, 43.53961408138275, 49.69563715159893, 68.83281245827675, 72.10306897759438, 73.17643538117409, 80.07474482059479, 4.7465732507407665, 1.749360105022788, 1.006159766111523, 2.8034548927098513, 76.77791252732277, 77.75150388479233, 80.64892441034317, 75.27199253439903, 82.73998260498047, 74.06284421682358, 75.61998546123505, 69.90229547023773, 66.2140765786171, 63.80029410123825, 59.989957362413406, 58.21872420608997, 57.95422799885273, 60.25039918720722, 63.76995652914047, 61.22358776628971, 62.41986997425556, 58.98930385708809, 62.66394227743149, 56.68136849999428, 57.88017377257347, 56.50267168879509, 56.41740806400776, 53.89392927289009, 53.63078959286213, 51.70721501111984, 48.00931803882122, 51.6092486679554, 54.73637826740742, 56.84745378792286, 56.949041336774826, 54.36350807547569, 52.192889750003815, 59.867683723568916, 68.18442285060883, 64.00616705417633, 65.12158960103989, 62.217986807227135, 63.628220334649086, 63.92092242836952, 60.71549043059349, 58.74354064464569, 63.683495968580246, 62.26732335984707, 57.60215029120445, 59.48447808623314, 53.63054260611534, 43.46123568713665, 66.72493636608124, 49.15101617574692, 48.10496650636196, 48.36810998618603, 46.13481782376766, 46.843901574611664, 47.531041502952576, 48.41009013354778, 49.87846814095974, 51.153972297906876, 51.653330102562904, 51.73725239932537, 58.646197468042374, 52.9306011646986, 54.855467677116394, 55.1329629868269, 47.17365927994251, 44.61290068924427, 44.762772247195244, 47.71738350391388, 43.10479201376438, 46.693235859274864, 46.85221552848816, 46.521834656596184, 47.300249487161636, 51.56758010387421, 56.550636515021324, 55.60568422079086, 54.201233983039856, 46.56737521290779, 51.12554982304573, 52.04471290111542, 45.02064920961857, 44.677672013640404, 42.50391885638237, 39.720948189496994, 40.147049725055695, 55.65966412425041, 60.050358921289444, 55.05871497094631, 53.93305957317352, 59.25439663231373, 59.26535904407501, 60.66858574748039, 59.85245034098625, 57.80512019991875, 60.42869322001934, 58.16759414970875, 61.57741338014603, 61.2143998593092, 61.23012721538544, 61.55340626835823, 62.466907650232315, 56.18495173752308, 53.293618485331535, 55.08139215409756, 57.52988576889038, 54.196020662784576, 52.336867824196815, 51.01106956601143, 46.09742023050785, 45.718538761138916, 45.22412449121475, 49.2168590426445, 52.77820274233818, 51.67367801070213, 52.16613158583641, 50.97230404615402, 53.41086879372597, 53.86493302881718, 54.91045452654362, 56.1169657856226, 54.96054723858833, 55.66048488020897, 57.65508145093918, 56.09137035906315, 58.118379190564156, 58.128771632909775, 60.1576841622591, 58.381363078951836, 58.396702855825424, 68.5709761083126, 81.33802503347397, 73.807832300663, 77.73576512932777, 78.0050490796566, 80.79011723399162, 78.59812125563622, 85.20844414830208, 8.154166750609875, 0.24691976053873077, 49.93082173168659, 88.82326617836952, 56.895179226994514, 70.65167605876923, 53.28130714595318, 43.029316663742065, 79.77296501398087, 12.574695646762848, 0.9151869476772845, 0.2425617357948795, 0.2268275964888744, 0.26630526641383767, 0.2111805704771541, 0.10865157018997706, 0.11972459906246513, 0.14329068217193708], [0.0482294649555115, 0.009746849009388825, 0.09022871890920214, 0.050029644335154444, 0.011108603721368127, 0.10583618102828041, 0.08825169687042944, 0.2505331439897418, 0.6559361808467656, 7.301338138058782, 37.81435489654541, 21.512182764708996, 33.778747245669365, 50.40517307817936, 52.46115155518055, 60.270484909415245, 67.89960533380508, 3.5679311212152243, 0.3371000097831711, 1.1342162196524441, 0.7752360636368394, 57.28268623352051, 65.45681521296501, 73.62302541732788, 71.28622680902481, 75.67260503768921, 70.34605085849762, 69.86092329025269, 59.41933438181877, 58.0489607155323, 54.879649579524994, 57.2225696593523, 55.0914616137743, 58.00266019999981, 57.720627933740616, 64.03694540262222, 62.36223466694355, 57.339124605059624, 55.10961703956127, 55.03673695027828, 53.53569209575653, 51.55460000038147, 51.04758940637112, 50.93572340905666, 48.59845742583275, 48.57683278620243, 46.162655130028725, 43.84104050695896, 42.41864003241062, 46.406328454613686, 48.47174562513828, 51.848141849040985, 49.533997625112534, 53.17808948457241, 55.05005523562431, 62.486510798335075, 60.54252751171589, 59.72766503691673, 53.748385682702065, 59.56151135265827, 56.12538993358612, 54.30895060300827, 55.53301692008972, 57.214647084474564, 57.389745488762856, 52.30987407267094, 48.014861941337585, 43.132253140211105, 58.81370767951012, 52.5073304772377, 52.41297774016857, 53.777465522289276, 39.201516062021255, 46.81003399193287, 44.87122602760792, 41.68315529823303, 44.56820368766785, 44.9389573931694, 46.508535370230675, 45.31121201813221, 46.47789001464844, 47.89972431957722, 46.1689779907465, 47.94040493667126, 44.5456974953413, 40.794048607349396, 40.92372044920921, 39.46399837732315, 42.432771474123, 40.127165392041206, 39.802894592285156, 38.9051965624094, 39.90595266222954, 43.111741840839386, 46.39543443918228, 47.76051878929138, 47.88013257086277, 44.269570112228394, 40.28239466249943, 44.89604249596596, 41.162001863121986, 40.91316841542721, 40.79487696290016, 41.03440850973129, 44.248724430799484, 38.07992644608021, 38.494431003928185, 49.2517601698637, 51.858431696891785, 56.07491724193096, 52.86889247596264, 54.538101106882095, 52.38264016807079, 54.80141557753086, 53.1356305629015, 57.57231429219246, 53.05857829749584, 54.537637531757355, 57.35741302371025, 54.666693806648254, 54.67730663716793, 56.763713881373405, 57.347468957304955, 51.76370657980442, 53.73620733618736, 49.8024608194828, 46.57514959573746, 45.732867792248726, 43.9327409863472, 39.808974266052246, 39.1420416533947, 42.96070374548435, 45.805550292134285, 45.79298436641693, 46.53609909117222, 48.34790267050266, 48.108948692679405, 46.161944568157196, 47.784970477223396, 48.53791147470474, 48.717588633298874, 49.086313247680664, 48.553555235266685, 49.039279371500015, 49.83842968940735, 50.52370011806488, 50.532785430550575, 49.55278001725674, 50.99530041217804, 53.126332461833954, 61.29511512815952, 69.16563659906387, 69.80508148670197, 72.77376338839531, 72.88756728172302, 74.12454530596733, 74.36426684260368, 81.2787102162838, 9.10308888182044, 0.5813653604127467, 38.1932819634676, 76.09464839100838, 51.53788469731808, 55.43850839138031, 40.30130244791508, 24.939769841730595, 48.58670085668564, 6.124761672690511, 0.16197870281757787, 0.09129760452196933, 0.13562690903199837, 0.03707934549311176, 0.04063337568368297, 0.05730017197492998, 0.044172444177092984, 0.09751091682119295, 0.04200379589747172, 0.06589460943359882, 0.12879986286861822, 0.07330436026677489, 0.022328028644551523, 0.11589607442147098, 0.14936766936443746, 0.41120327718090266, 1.3609610963612795, 18.52039810270071, 55.7227673381567, 20.015914253890514, 41.330709010362625, 63.78105953335762, 56.78992107510567, 67.57874295115471, 70.64279213547707, 5.4794104769825935, 1.2657957966439426, 0.6558937299996614, 0.9234811901114881, 65.37546917796135, 68.6770436167717, 79.15413022041321, 74.04214292764664, 79.91950035095215, 74.60881412029266, 73.86063426733017, 62.54737213253975, 63.66076558828354, 58.44052590429783, 61.45771600306034, 58.16632121801376, 61.60005256533623, 58.792311027646065, 67.43421390652657, 65.76695457100868, 61.875948160886765, 58.13159488141537, 56.584329307079315, 56.98163978755474, 55.667529702186584, 56.096762269735336, 54.379486218094826, 51.25223882496357, 51.48491553962231, 48.01742680370808, 47.170060873031616, 45.716832652688026, 49.70754191279411, 51.96525156497955, 54.909508377313614, 51.459574699401855, 53.19922395050526, 57.51792401075363, 63.054857701063156, 63.829058557748795, 61.265051141381264, 57.20050424337387, 61.115491166710854, 57.541619539260864, 55.36144472658634, 57.27969579398632, 60.52670136094093, 59.9788885563612, 56.35994374752045, 50.94555348157883, 43.28686684370041, 56.91647708415985, 47.709856107831, 50.395719185471535, 52.141516506671906, 41.251190677285194, 48.639419227838516, 46.50677226483822, 44.76438336074352, 44.248716831207275, 46.1163280159235, 50.28330221772194, 48.59131760895252, 48.87606292963028, 49.46376599371433, 48.64448055624962, 49.34135176241398, 45.72466783225536, 43.18758577108383, 43.31761099398136, 41.668845266103745, 44.84899342060089, 44.73977208137512, 42.40150675177574, 40.35159274935722, 41.87953636050224, 43.60899455845356, 47.872726768255234, 49.122209921479225, 49.87456955015659, 46.532553881406784, 42.5276979804039, 48.01578149199486, 43.486356139183044, 44.29054878652096, 43.42066906392574, 43.46091270446777, 46.27519749104977, 40.60506194829941, 40.18705777823925, 49.06770944595337, 51.15422308444977, 61.021320819854736, 54.91348676383495, 57.512532100081444, 53.90086770057678, 57.635964676737785, 55.08302606642246, 58.762684017419815, 57.29120917618275, 59.52790975570679, 60.032883659005165, 57.7995914965868, 56.01236879825592, 57.888263538479805, 58.4161502122879, 52.52290964126587, 54.77141618728638, 54.842776358127594, 48.91462706029415, 47.907517701387405, 47.655800208449364, 43.113755732774734, 42.46573470532894, 45.64521789550781, 47.806158140301704, 48.06854926049709, 48.743605837225914, 50.39316192269325, 50.61529420316219, 49.946423694491386, 50.37755236029625, 51.78455986082554, 53.0798115581274, 53.399925380945206, 51.94681495428085, 52.70507946610451, 54.093760550022125, 54.480165615677834, 53.70818383991718, 53.6245883256197, 54.900274872779846, 57.22264565527439, 64.76342841982841, 73.70669692754745, 73.07514801621437, 77.94187366962433, 76.77123248577118, 79.95926141738892, 76.27745658159256, 88.01635667681694, 11.595083512365818, 0.7305687479674816, 42.81718164682388, 84.08435806632042, 55.35191483795643, 59.640885293483734, 53.06561931967735, 36.004318222403526, 59.78438459336758, 7.577385250478983, 0.46171841968316585, 0.02786205688607879, 0.13608497742097825, 0.11501392800710164, 0.06541874434333295, 0.05678014538716525, 0.027956402409472503, 0.05089400518045295, 0.18278358096722513, 0.23779174487572163, 0.22695425141137093, 0.11810886935563758, 0.16121341497637331, 0.22675911110127345, 0.2324607942136936, 0.45411378087010235, 1.531463647261262, 38.77512574195862, 72.4653947353363, 34.57631304860115, 46.47587992250919, 69.9646957218647, 66.66482359170914, 73.46858650445938, 81.01337805390358, 5.940871015191078, 3.9422623347491026, 2.771245208568871, 1.1060027335770428, 71.59573540091515, 72.65572652220726, 81.98571547865868, 74.3918989598751, 83.6434069275856, 75.83425596356392, 76.15479156374931, 64.50430512428284, 65.95701277256012, 61.56828626990318, 64.26206052303314, 60.94990745186806, 62.60616257786751, 63.253328651189804, 68.34210678935051, 68.36625829339027, 65.26144489645958, 60.08862666785717, 61.55678428709507, 58.93941253423691, 57.45178855955601, 59.13712352514267, 55.525721311569214, 53.94665904343128, 52.68722042441368, 52.08092115819454, 50.451260805130005, 47.821311727166176, 54.422910287976265, 55.96470795571804, 58.775401934981346, 54.02186460793018, 57.3524808883667, 58.59774626791477, 67.23897278308868, 67.00670644640923, 64.85238924622536, 60.49199782311916, 64.47447672486305, 62.18853458762169, 58.516328036785126, 60.4302853345871, 61.0438422113657, 61.4727707952261, 57.04100400209427, 55.237920954823494, 48.57899866998196, 50.51171936094761, 54.17707107961178, 54.02756430208683, 53.019881173968315, 43.95003765821457, 51.366935670375824, 50.19419699907303, 46.56351841986179, 47.1456053853035, 49.00538519024849, 54.55668970942497, 50.57750903069973, 54.063362181186676, 52.90708802640438, 51.190989911556244, 53.63982550799847, 49.37379442155361, 44.8274751752615, 45.873946622014046, 44.988369941711426, 49.1624915599823, 44.9447026848793, 46.397049352526665, 43.2655081897974, 44.389856457710266, 46.426915749907494, 50.813803151249886, 51.461710184812546, 53.40030916035175, 50.04754766821861, 47.09841191768646, 50.08478567004204, 45.9767235070467, 45.21081380546093, 46.766974702477455, 46.36282838881016, 48.7384495139122, 40.60535453259945, 43.27436551451683, 51.80677346885204, 55.04582606256008, 62.189131155610085, 56.750627383589745, 59.889764338731766, 56.653892174363136, 60.976635217666626, 57.17425525188446, 62.211572751402855, 59.05050717294216, 61.83436319231987, 60.50725780427456, 60.49902364611626, 57.90154002606869, 60.40446192026138, 60.69350481033325, 53.56412976980209, 55.788773596286774, 55.920250341296196, 51.64376221597195, 50.53890310227871, 49.86043430864811, 45.39096973836422, 43.32856200635433, 49.021321535110474, 51.20949871838093, 48.74547153711319, 50.729679465293884, 53.59287142753601, 54.20548975467682, 51.95892110466957, 52.07289218902588, 54.118645414710045, 56.90140329301357, 57.70038641989231, 54.748947992920876, 56.987491473555565, 56.21792636811733, 57.390516847372055, 56.34824797511101, 56.65225066244602, 57.64932096004486, 61.52546636760235, 66.89250737428665, 77.79479116201401, 76.4514872431755, 79.44723129272461, 78.74700486660004, 83.59997525811195, 80.73769524693489, 92.63850465416908, 13.225632067769766, 0.6743998057208955, 47.850114181637764, 91.30515620112419, 67.44966387748718, 73.74879106879234, 56.2095782160759, 40.28842493891716, 77.22201749682426, 13.128147348761559, 0.9823729831259698, 0.26420344482176006, 0.40718095551710576, 0.19940190017223358, 0.1238028118677903, 0.17337813565973192, 0.14113769691903144, 0.296724415384233], [0.014125346824584994, 0.07369565762928687, 0.032815387967275456, 0.016176279350474942, 0.04275646722817328, 0.0638438921305351, 0.1288498390931636, 0.12780566699802876, 0.5287148512434214, 11.652150750160217, 47.13914953172207, 44.60097312927246, 28.0831815674901, 43.01464945077896, 54.33754026889801, 61.524220034480095, 76.5594394505024, 9.485678002238274, 0.7861783483531326, 2.0072427671402693, 2.9953505331650376, 59.79565478861332, 67.04952254891396, 74.8968006670475, 71.69573843479156, 72.59112238883972, 69.824658036232, 67.87431389093399, 58.98359656333923, 56.005031391978264, 53.04790087044239, 52.95261338353157, 55.41338033974171, 57.31906548142433, 59.729751124978065, 57.097974345088005, 56.559212654829025, 58.23754079639912, 54.36083301901817, 57.05143824219704, 53.58630158007145, 54.90180239081383, 52.69935317337513, 50.732073336839676, 46.62204287946224, 47.707219049334526, 45.99080555140972, 48.23447495698929, 45.58911770582199, 46.35011427104473, 47.45684668421745, 51.798653304576874, 50.11447727680206, 57.64056622982025, 57.09487371146679, 59.30774576961994, 60.771602019667625, 59.487373530864716, 58.71079780161381, 51.85250781476498, 56.81909590959549, 53.73917877674103, 52.75427922606468, 55.59631012380123, 57.619097381830215, 55.61874412000179, 49.17425572872162, 47.672754898667336, 55.82674115896225, 44.19149190187454, 43.52494686841965, 50.14102265238762, 38.76431532204151, 44.643337056040764, 39.90169309079647, 43.65482769906521, 41.269927471876144, 46.09074018895626, 43.2643036544323, 45.842526108026505, 48.16671699285507, 42.268312498927116, 44.72644619643688, 44.08820204436779, 41.89169950783253, 39.43439036607742, 39.120884388685226, 40.667994171381, 40.144880041480064, 43.09010960161686, 39.64319296181202, 37.452203929424286, 37.750164940953255, 39.398041516542435, 42.53903277218342, 44.95493173599243, 41.66911505162716, 43.6528480052948, 41.780289486050606, 44.55827862024307, 44.118057042360306, 40.56224964559078, 39.79948617517948, 39.49146710336208, 41.925920471549034, 43.93407851457596, 34.53212521970272, 32.355507016181946, 30.31288482248783, 39.29901883006096, 54.716482535004616, 54.109829887747765, 57.03703701496124, 52.72595174610615, 54.932679533958435, 55.17170190811157, 53.79744105041027, 53.1484966725111, 56.79922677576542, 55.49568772315979, 53.93375113606453, 54.73619967699051, 58.31725671887398, 55.02363905310631, 50.9625081717968, 48.606900572776794, 45.19490025937557, 43.93666997551918, 43.699372708797455, 41.929883658885956, 40.719777792692184, 42.83482789993286, 46.36493727564812, 47.07290768623352, 43.96047189831734, 47.85681702196598, 48.69284816086292, 46.781303733587265, 46.89307853579521, 49.09824840724468, 50.97450792789459, 48.19000594317913, 48.249746337533, 47.898941561579704, 50.14951519668102, 50.574093014001846, 49.91969592869282, 50.34239664673805, 52.046039029955864, 52.21408121287823, 60.19224710762501, 70.15371277928352, 68.23952749371529, 72.00634896755219, 71.89867794513702, 76.68476432561874, 67.85140112042427, 82.18084260821342, 9.623603001236916, 0.6902440648991615, 44.73962388932705, 76.74637421965599, 55.208928510546684, 54.51902233064175, 35.308191776275635, 20.05443088710308, 46.530300602316856, 4.296849807724357, 0.1424100052099675, 0.021107216125528794, 0.0784778717206791, 0.0016287455855490407, 0.026363968718214892, 0.09621401375625283, 0.07184016227256507, 0.04606119888194371, 0.037123247238923796, 0.025307213509222493, 0.027141789578308817, 0.037734502329840325, 0.0853973523771856, 0.06448307423852384, 0.049797674946603365, 0.12751983624184504, 0.5130478763021529, 20.93365240842104, 63.90355736017227, 41.179271936416626, 27.49759878963232, 52.36890770494938, 59.76012669503689, 70.5059614777565, 80.85026800632477, 12.166110221296549, 0.7265800307504833, 3.0219094455242157, 4.738047933205962, 68.1679393351078, 70.7185372710228, 78.083256483078, 74.48446199297905, 76.87695801258087, 73.64495784044266, 71.65500462055206, 63.488410636782646, 61.147614642977715, 56.11505068838596, 56.53899013996124, 57.63842694461346, 62.96657703816891, 63.62492971122265, 62.37167336046696, 59.50929455459118, 61.377027332782745, 55.85616298019886, 60.177264511585236, 55.584291368722916, 59.599725902080536, 54.365054592490196, 55.674741715192795, 51.31080888211727, 51.74572214484215, 48.90916295349598, 48.40368367731571, 46.924476251006126, 48.5028051584959, 51.007189974188805, 53.41957412660122, 52.17956006526947, 59.052251279354095, 58.458780124783516, 60.956028923392296, 62.18832179903984, 61.83527134358883, 60.531367510557175, 57.520412877202034, 56.69677287340164, 57.42797903716564, 55.465163961052895, 56.42908863723278, 57.33351990580559, 57.239094972610474, 52.42098391056061, 49.37387801706791, 53.45013588666916, 48.65721747279167, 45.61088673770428, 48.63025791943073, 40.80649673938751, 44.62616577744484, 44.34423230588436, 45.5277281999588, 44.17119339108467, 47.737917602062225, 46.454821452498436, 48.589493706822395, 50.9927811473608, 44.20678228139877, 45.61564028263092, 46.33380174636841, 43.77209320664406, 40.62650039792061, 41.34982578456402, 42.03998275101185, 44.22946706414223, 43.63660767674446, 42.538515999913216, 40.16150414943695, 41.61586090922356, 41.75634317100048, 43.78557488322258, 47.155070677399635, 43.327133283019066, 44.73675884306431, 46.94547392427921, 46.71185865998268, 45.5656311661005, 42.51102067530155, 41.880626901984215, 42.8097378462553, 43.22621449828148, 46.22405603528023, 36.303711757063866, 36.42597779631615, 30.230685733258724, 38.830294981598854, 56.23683035373688, 56.10330171883106, 58.49208913743496, 54.67497356235981, 56.62211827933788, 56.30709618330002, 56.242925226688385, 59.08326141536236, 58.738467916846275, 58.09216819703579, 58.34210358560085, 56.56009800732136, 58.90945874154568, 55.35251520574093, 51.58926174044609, 52.46435858309269, 49.492667242884636, 47.006342858076096, 47.13654667139053, 44.94858607649803, 43.56308922171593, 46.21791556477547, 48.005746230483055, 48.50608438253403, 47.440032586455345, 49.6343844383955, 50.8091825991869, 50.88047817349434, 51.056059151887894, 52.15469419956207, 52.090914621949196, 52.44880981743336, 50.55293954908848, 53.218010142445564, 52.84899294376373, 56.559178456664085, 53.65775674581528, 56.03897877037525, 55.79241760075092, 57.461930215358734, 65.52204251289368, 75.35953223705292, 71.5004289150238, 75.94173699617386, 75.03627598285675, 81.5847609937191, 74.4405971467495, 86.83811590075493, 10.47315476462245, 0.5157818889711052, 51.06040231883526, 83.44783902168274, 58.90871778130531, 63.49434591829777, 39.890248104929924, 22.6756689324975, 63.85020822286606, 8.023567758500576, 0.3460423252545297, 0.02558962853072444, 0.10498148665647022, 0.0344250543275848, 0.10104306478751823, 0.02021806940319948, 0.11815013276645914, 0.0869640706514474, 0.2170555153861642, 0.1260821329196915, 0.179662078153342, 0.13447709963656962, 0.1919723636819981, 0.138127145182807, 0.2970126655418426, 0.2604117529699579, 0.8928221196401864, 34.26128715276718, 73.57498079538345, 58.42624247074127, 38.22016552090645, 59.17905427515507, 69.56700906157494, 72.18821480870247, 88.13470512628555, 12.731449585407972, 2.389155523851514, 6.198096787557006, 6.380902603268623, 73.64498063921928, 74.08767968416214, 80.06657525897026, 77.34815552830696, 78.45831155776978, 73.66516515612602, 74.0120181441307, 65.87112978100777, 62.89194904267788, 58.21260653436184, 58.70304621756077, 59.85984854400158, 64.83455300331116, 64.76968288421631, 67.52502143383026, 63.43082472681999, 63.874671310186386, 57.59343355894089, 64.36151638627052, 59.47648711502552, 62.51139186322689, 57.55098983645439, 57.42498479783535, 53.33285138010979, 54.845702201128006, 50.763999223709106, 53.26304152607918, 52.11008459329605, 51.196184232831, 54.49386388063431, 54.74192216992378, 54.40326914191246, 62.13206961750984, 61.88307657837868, 64.89134475588799, 64.58880499005318, 65.0193902850151, 63.09139274060726, 59.42967362701893, 61.29254646599293, 56.90895348787308, 58.17468076944351, 60.870123133063316, 60.94130091369152, 59.42455530166626, 55.87257809937, 47.2952451556921, 56.95804305374622, 49.577611684799194, 50.79763501882553, 55.254275277256966, 43.21257323026657, 48.44379812479019, 46.34219169616699, 47.74174779653549, 48.337058052420616, 51.5163816511631, 48.87752205133438, 51.912077218294144, 55.178666934370995, 46.70242376625538, 48.66026110947132, 48.42250406742096, 47.5398076325655, 42.09424003958702, 43.00049141049385, 43.902107030153275, 46.399150639772415, 45.236302837729454, 46.15780659019947, 42.18751363456249, 44.01617310941219, 42.75586053729057, 46.323979273438454, 49.1842719912529, 46.53294526040554, 48.72623696923256, 49.97822418808937, 49.11802634596825, 49.624474570155144, 43.575332164764404, 43.59468072652817, 43.28228808939457, 46.95393607020378, 47.014421224594116, 37.21402131021023, 37.36458443105221, 30.220093801617622, 47.48343005776405, 60.74286416172981, 57.708783969283104, 60.774645656347275, 55.967557802796364, 58.38593043386936, 60.297376066446304, 59.62640427052975, 59.786672070622444, 62.19533622264862, 59.900920540094376, 60.13856738805771, 60.01082964241505, 62.79197260737419, 58.38908426463604, 55.47413907945156, 52.84498415887356, 51.3998419046402, 50.743126943707466, 49.83237661421299, 48.5900142788887, 46.242534443736076, 48.571022897958755, 49.879828467965126, 51.183701902627945, 48.874182030558586, 52.412183582782745, 53.93161945044994, 53.77362012863159, 53.734596222639084, 55.257413908839226, 57.565733045339584, 55.07363677024841, 52.08747960627079, 55.414227694272995, 56.685935854911804, 59.211629927158356, 57.01559856534004, 58.73155228793621, 59.031986966729164, 59.7227519005537, 68.17305386066437, 77.46132105588913, 73.85049641132355, 79.51957181096077, 78.06501746177673, 87.03957349061966, 75.16065090894699, 91.51887193322182, 13.125505540519953, 0.624012075131759, 55.599349960684776, 92.34912738204002, 68.99222150444984, 73.14093768596649, 45.82764610648155, 30.46975940465927, 81.39924734830856, 10.453083291649818, 0.7379329903051257, 0.11905760868103243, 0.17180920578539371, 0.11398705537430942, 0.1674688738421537, 0.11898445518454537, 0.19370097405044362, 0.2381664700806141], [0.07101419643731788, 0.013357377047213959, 0.05583601108810399, 0.07288289460120723, 0.06704278610413894, 0.09561652550473809, 0.10415353186544962, 0.12320116016780958, 0.7035383046604693, 11.098089180886745, 60.69506652653217, 42.21902534365654, 53.77311855554581, 45.65656028687954, 43.03259588778019, 53.55807289481163, 81.63490310311317, 16.190860904753208, 0.41428532742429525, 1.1529323528520763, 7.392211211845279, 65.67783415317535, 62.99130231142044, 76.23723953962326, 70.70832341909409, 74.42316368222237, 69.07024651765823, 62.932154685258865, 56.34513594210148, 57.24089227616787, 54.18433628976345, 57.214829474687576, 60.60789540410042, 58.73073533177376, 57.02381752431393, 56.946852654218674, 60.29251992702484, 58.35515208542347, 55.81517077982426, 58.39107155799866, 53.95158737897873, 55.918586030602455, 52.15167336165905, 50.981172770261765, 49.27167870104313, 47.84635238349438, 46.4908929169178, 44.40141923725605, 42.305159121751785, 42.98087686300278, 45.48568345606327, 47.43561342358589, 49.268338680267334, 55.41729412972927, 58.9686443656683, 57.456640899181366, 59.02559570968151, 58.5343998670578, 57.911750078201294, 55.45449413359165, 50.49455948174, 53.39720092713833, 52.442479357123375, 54.5959036052227, 54.24064926803112, 48.823511749506, 51.057047098875046, 52.69072003662586, 43.67036506533623, 43.2613930106163, 46.64326474070549, 42.22789026796818, 39.41823363304138, 40.10850839316845, 40.40700517594814, 41.05762906372547, 42.63505361974239, 46.12315244972706, 45.750601440668106, 47.38327503204346, 49.399180859327316, 46.48894742131233, 44.0557973831892, 44.436795338988304, 40.431977435946465, 38.97618815302849, 41.41840070486069, 41.02596916258335, 43.718907460570335, 45.4983975738287, 41.91094547510147, 41.71454541385174, 42.25932218134403, 42.8807370364666, 45.20986005663872, 45.82009591162205, 42.05402299761772, 44.28337097167969, 46.691419556736946, 42.98315294086933, 44.55146558582783, 41.202800273895264, 42.97816760838032, 38.49484518170357, 41.08410604298115, 42.636622935533524, 43.92091602087021, 38.98569144308567, 47.46095806360245, 33.68637800216675, 36.31873235106468, 56.024832129478455, 48.63854147493839, 52.14952267706394, 51.328227147459984, 54.633517786860466, 55.67866690456867, 57.744878232479095, 54.47706498205662, 57.5616330653429, 52.743829786777496, 52.07606501877308, 57.3242712020874, 55.69111883640289, 52.47359588742256, 48.62001746892929, 47.63239346444607, 42.906640246510506, 44.44032534956932, 40.64788185060024, 43.40161308646202, 46.10262215137482, 47.34569884836674, 48.1288406252861, 45.244783982634544, 46.78374320268631, 50.219507440924644, 47.98873454332352, 48.418331891298294, 48.43070022761822, 48.73463451862335, 48.5709773004055, 48.082365319132805, 48.251159861683846, 48.02973434329033, 51.33655250072479, 49.39397133886814, 53.50696183741093, 50.63500374555588, 51.78369350731373, 59.47018705308437, 67.2189250588417, 66.51039227843285, 73.22324126958847, 70.96088826656342, 75.63727453351021, 73.61939281225204, 81.41422614455223, 8.904904816299677, 0.36744218319654465, 54.348692670464516, 70.82136735320091, 57.082683965563774, 54.86572712659836, 34.52569976449013, 40.60459837317467, 55.12106962502003, 5.633295094594359, 0.17555267288116738, 0.12191402376629412, 0.03734469668415841, 0.062153157268767245, 0.0988897678325884, 0.025492136301181745, 0.042123712119064294, 0.042434742499608546, 0.08575980988098308, 0.01476302608352853, 0.03309783081931528, 0.06289092256338336, 0.004363496227597352, 0.0420045083592413, 0.14525639388011768, 0.16120305459480733, 0.6490650807972997, 13.114338889718056, 75.29386416077614, 43.02732937037945, 46.50099277496338, 53.844797909259796, 51.47673457860947, 60.53870491683483, 90.01250356435776, 19.22015145421028, 0.56719099287875, 1.9643003214150667, 10.84808349609375, 75.2593544125557, 69.33222725987434, 79.94320347905159, 74.83725786209106, 79.00899320840836, 72.74632886052132, 66.62117153406143, 60.35381443798542, 60.87876006960869, 56.6018121689558, 62.074943482875824, 62.7052004635334, 62.275390326976776, 60.87236501276493, 61.6986458748579, 61.29112534224987, 63.99388611316681, 59.69741106033325, 61.35660722851753, 57.74511381983757, 58.60238961875439, 55.491105169057846, 55.23801974952221, 50.48610493540764, 50.17582878470421, 48.81184637546539, 47.64049082994461, 45.09174719452858, 46.15591809153557, 47.123581767082214, 49.693744853138924, 53.19614991545677, 57.13011682033539, 59.98363830149174, 61.47851228713989, 60.303755924105644, 60.9445421397686, 58.767589554190636, 59.453004375100136, 53.50489854812622, 55.09344130754471, 55.83520710468292, 58.05205374956131, 57.03921049833298, 52.486864775419235, 51.813772693276405, 49.904660135507584, 46.225948333740234, 45.11133134365082, 48.95244263112545, 45.777724385261536, 42.59164094924927, 43.09321403503418, 41.81903600692749, 43.01410607993603, 43.754648342728615, 47.77607895433903, 47.9958401620388, 51.414254531264305, 52.12738886475563, 48.5533956438303, 45.624330416321754, 47.33110003173351, 40.74265256524086, 41.47369533777237, 42.29977861046791, 41.31313495337963, 46.03343166410923, 47.168464958667755, 44.446682408452034, 42.983354330062866, 43.07700030505657, 43.80049288272858, 46.97864234447479, 48.8945185393095, 45.19896984100342, 47.47028276324272, 49.13395129144192, 47.46015630662441, 47.29843698441982, 43.63524354994297, 43.41433860361576, 39.18811038136482, 43.34009438753128, 44.50116008520126, 43.24300579726696, 44.26607809960842, 55.345933958888054, 38.190724700689316, 37.845425829291344, 55.18874019384384, 50.66686883568764, 53.98477099835873, 55.06536461412907, 57.44778737425804, 55.8639981597662, 59.44306790828705, 57.45173916220665, 59.23251360654831, 56.5133111178875, 55.48328898847103, 60.19002042710781, 56.40593647956848, 53.1563014537096, 49.51543562114239, 49.635547176003456, 47.57586769759655, 47.27528102695942, 43.80884863436222, 46.27605244517326, 47.989486902952194, 49.37162093818188, 52.047558948397636, 48.42023178935051, 49.909352883696556, 51.462610736489296, 51.694269105792046, 50.56141309440136, 51.594786643981934, 52.00321152806282, 53.241694271564484, 52.15182155370712, 52.41517402231693, 51.84591896831989, 54.9676338583231, 55.301635935902596, 56.9481635838747, 56.10523201525211, 55.5781053006649, 64.03475672006607, 73.08463230729103, 73.11288759112358, 78.38069692254066, 75.78779965639114, 80.30300617218018, 76.39430791139603, 86.1012290418148, 10.379845071583986, 0.22537209646543488, 60.419839695096016, 78.52452680468559, 64.03370797634125, 62.72081382572651, 42.26362735033035, 42.252148166298866, 64.36468541622162, 10.605560559779406, 0.5606171081308275, 0.14493652823148295, 0.0982713807024993, 0.05297367737512104, 0.1141624100273475, 0.03352307030581869, 0.018624424155859742, 0.05201295978622511, 0.2288211535778828, 0.19292737415526062, 0.21331071242457256, 0.1947959090466611, 0.15886951965512708, 0.2546748920576647, 0.2673411264549941, 0.3691178042208776, 1.0686394572257996, 24.18491754680872, 87.94213145971298, 55.80520011484623, 71.02418527007103, 61.94352753460407, 60.93154303729534, 64.82975766062737, 97.64723628759384, 21.13155908882618, 1.0237465286627412, 4.209029395133257, 13.302858173847198, 78.53534862399101, 71.36840119957924, 82.28849083185196, 76.83107167482376, 79.65096116065979, 74.97601121664047, 68.9343810081482, 61.84554599225521, 64.35424357652664, 59.982186779379845, 63.54915417730808, 65.47548741102219, 64.14226815104485, 64.7825337946415, 63.707043305039406, 64.04263749718666, 64.03845772147179, 62.51009613275528, 64.88901928067207, 59.28803242743015, 61.34595260024071, 59.80880968272686, 57.75490589439869, 54.49096083641052, 53.0624844878912, 50.948175340890884, 49.34339605271816, 48.14076818525791, 47.52654254436493, 49.463614001870155, 51.36808700859547, 55.3749606013298, 59.33070033788681, 63.009700924158096, 64.47206765413284, 63.506991639733315, 64.03810814023018, 62.68815077841282, 61.1559171974659, 57.53899767994881, 59.321580827236176, 57.47370198369026, 58.49870838224888, 59.69807982444763, 53.70227515697479, 52.94194355607033, 52.70494647324085, 49.71916928887367, 47.050675079226494, 51.81298993527889, 51.27982534468174, 47.95825257897377, 47.792395278811455, 44.75795790553093, 45.818978771567345, 46.552878990769386, 50.74226438999176, 50.32746724784374, 54.843703508377075, 56.659952849149704, 51.584052219986916, 47.768008187413216, 49.45943042635918, 43.388598784804344, 42.82266095280647, 45.49799099564552, 45.66736310720444, 49.75870616734028, 49.248454347252846, 46.33254401385784, 45.413947105407715, 47.057947888970375, 47.02880345284939, 48.89252744615078, 49.27317962050438, 46.25142976641655, 51.87787525355816, 52.94974833726883, 51.7196099460125, 50.009853690862656, 47.2894998639822, 47.091621682047844, 40.24428270757198, 46.58383212983608, 46.526979580521584, 45.71621708571911, 44.71054784953594, 48.799945414066315, 31.962155923247337, 38.81023585796356, 60.12014217674732, 54.68060106039047, 55.99195249378681, 57.213997319340706, 57.187121361494064, 58.06958220899105, 62.844755575060844, 59.19342890381813, 62.41018809378147, 57.80263893306255, 59.119386076927185, 61.642344295978546, 58.16197045147419, 56.2133552134037, 52.64209404587746, 53.46536546945572, 49.997667744755745, 50.53791895508766, 46.2007100880146, 48.331852331757545, 51.28821909427643, 53.533321022987366, 53.65385055541992, 50.997500494122505, 51.51293903589249, 55.18897198140621, 52.657939195632935, 53.73444423079491, 53.47575791180134, 55.038625448942184, 55.17270885407925, 54.40502464771271, 53.569723069667816, 55.33074617385864, 58.02701689302921, 56.88640169799328, 59.614670500159264, 58.6416757106781, 58.23533691465855, 66.21267065405846, 74.67443659901619, 75.46335026621819, 81.23152434825897, 78.45046117901802, 84.57410618662834, 78.25436130166054, 91.12993240356445, 11.88634928315878, 0.4520016285823658, 64.7270567715168, 82.90104076266289, 73.1822718679905, 73.39304655790329, 51.303703263401985, 62.92466528713703, 78.97336632013321, 14.173122625797987, 0.968854317907244, 0.33849296160042286, 0.3018889616942033, 0.12468443135730922, 0.2365324686979875, 0.23585125134559348, 0.14020533679286018, 0.19267884374130517], [0.01742053631460294, 0.07526949309976771, 0.11775413018767722, 0.08549291131203063, 0.08049913318245672, 0.031636701605748385, 0.04282275585865136, 0.14888678735587746, 0.3103549964725971, 4.283456951379776, 58.6187819391489, 41.041571125388145, 30.821145549416542, 40.45428603887558, 50.264998599886894, 49.963059201836586, 84.58413764834404, 21.919460110366344, 0.18985547649208456, 0.6814310909248888, 8.59425913542509, 67.39853382110596, 63.51381987333298, 77.91630864143372, 71.33910477161407, 73.93718495965004, 66.53141275048256, 60.75696900486946, 53.75910110771656, 57.581015825271606, 56.90386936068535, 58.2067434489727, 58.704243153333664, 59.11779396235943, 60.581156238913536, 61.61721244454384, 57.652239203453064, 57.86426402628422, 56.17251880466938, 56.709673181176186, 52.82552920281887, 54.67619709670544, 50.98867356777191, 49.92146663367748, 47.50101551413536, 45.21443501114845, 47.229786068201065, 47.48917534947395, 44.58602853119373, 44.42909695208073, 46.22994191944599, 47.5886046141386, 46.40098974108696, 54.817883893847466, 56.272654831409454, 51.53261058032513, 59.5042560249567, 60.270245522260666, 58.1345397233963, 55.65993390977383, 54.77819882333279, 46.2652762234211, 49.61207963526249, 53.52852188050747, 53.644829839468, 53.188238739967346, 50.8335354924202, 41.61745302379131, 41.42071098089218, 48.439359962940216, 38.76987062394619, 40.02652399241924, 38.71185913681984, 39.98638674616814, 40.06270945072174, 41.51756018400192, 45.06044827401638, 43.68435591459274, 48.48660662770271, 51.48197449743748, 51.4392913877964, 51.69325836002827, 46.102261170744896, 44.59266297519207, 41.01284846663475, 39.63966675102711, 40.39339430630207, 38.69701713323593, 44.36420023441315, 47.87551961839199, 39.63860660791397, 40.0042799860239, 40.334812849760056, 42.30153411626816, 43.95732566714287, 45.41509844362736, 48.18505860865116, 50.52142024040222, 46.88461259007454, 47.99142859876156, 42.115226313471794, 42.910345047712326, 40.66943809390068, 41.70262545347214, 41.17894135415554, 39.6001298725605, 40.94708539545536, 39.440249651670456, 46.29629395902157, 64.30758967995644, 49.300636947155, 42.066467329859734, 47.04046502709389, 43.824116215109825, 56.13176979124546, 55.05974471569061, 53.518923595547676, 48.87238472700119, 53.83714511990547, 58.7200503051281, 49.556997790932655, 54.09834310412407, 56.03727266192436, 57.11155481636524, 52.172944620251656, 46.126142889261246, 45.18000885844231, 45.08383221924305, 41.884761080145836, 41.7878282815218, 44.93556037545204, 47.23185695707798, 46.89571179449558, 45.79300716519356, 47.60122373700142, 48.71843218803406, 48.43087501823902, 48.15959617495537, 47.69907608628273, 49.44751426577568, 47.93916240334511, 49.46412317454815, 47.80828982591629, 49.65707682073116, 49.765177220106125, 50.62270000576973, 51.338175013661385, 50.313396602869034, 52.620002031326294, 53.06290626525879, 59.3229715526104, 69.17802393436432, 69.6314612030983, 74.60335001349449, 72.81970292329788, 76.91826939582825, 68.35218384861946, 69.65783938765526, 8.562159407883883, 0.21015812846599147, 59.08666983246803, 65.60525804758072, 58.32647882401943, 49.5591788738966, 34.732583463191986, 32.08065636456013, 52.22009629011154, 8.90185832977295, 0.3880815178854391, 0.1195210353762377, 0.028204639675095677, 0.04016961873276159, 0.07344142009969801, 0.03776929421292152, 0.021957717362965923, 0.05878695723367855, 0.05783435874036513, 0.056934237509267405, 0.09136110267718323, 0.05451305492897518, 0.008874681698216591, 0.035656140025821514, 0.03202341620635707, 0.11174232582561672, 0.24473668861901388, 5.215516537427902, 70.99293574690819, 42.52811215817928, 31.62725329399109, 53.070372864603996, 52.851208224892616, 57.74165980517864, 91.43080025911331, 26.19493369013071, 0.27341382403392345, 0.9057144715916365, 9.134978670626879, 74.20550376176834, 68.79496648907661, 81.54699102044106, 76.9972063601017, 77.66863033175468, 71.28707036376, 63.115251660346985, 57.93647915124893, 59.74730618298054, 59.084382355213165, 62.24412180483341, 62.472481951117516, 61.08238734304905, 63.70724469423294, 65.13023793697357, 60.39496622979641, 59.518509060144424, 60.04132300615311, 60.438386499881744, 57.13559612631798, 58.41980941593647, 54.85603764653206, 54.32850815355778, 47.476066052913666, 47.729273065924644, 49.49302062392235, 49.95190680027008, 48.1995852291584, 47.98075497150421, 48.15435245633125, 49.20268960297108, 50.164566189050674, 57.74233236908913, 56.69291988015175, 54.80488479137421, 62.25965157151222, 60.55176481604576, 61.07824556529522, 59.08169209957123, 59.130500480532646, 52.536558508872986, 53.01471345126629, 55.74981048703194, 56.449124962091446, 53.91712702810764, 50.535692274570465, 46.464647725224495, 47.16638647019863, 48.680871203541756, 42.33370698988438, 41.43584556877613, 39.785871505737305, 43.6327812820673, 43.61075006425381, 44.82839472591877, 45.76900765299797, 46.2447839230299, 50.18235303461552, 55.25356471538544, 53.34323242306709, 53.86136122047901, 48.65434102714062, 45.317097902297974, 43.20334352552891, 40.88815435767174, 41.89808316528797, 41.1509520560503, 46.56048998236656, 50.61889261007309, 43.51665951311588, 44.24769848585129, 42.72200055420399, 43.15725199878216, 44.51730161905289, 47.32024401426315, 51.78573399782181, 52.31717728078365, 50.959829315543175, 50.77930100262165, 44.659296199679375, 44.543695002794266, 42.18598231673241, 43.97525690495968, 43.33413630723953, 42.346200719475746, 42.69443303346634, 39.354925230145454, 44.422869086265564, 62.073727548122406, 52.61153228580952, 45.59010945260525, 49.14095051586628, 44.17083241045475, 56.923537105321884, 58.72943200170994, 56.165910959243774, 50.30372232198715, 55.97469002008438, 57.08640396595001, 54.20928195118904, 58.10977645218372, 58.836164474487305, 59.19167719781399, 54.681547209620476, 49.42997060716152, 48.40423844754696, 46.829203963279724, 43.70523199439049, 45.43529435992241, 46.96873627603054, 48.972152173519135, 49.33575086295605, 50.73410242795944, 50.326441302895546, 52.53786563873291, 53.41580092906952, 51.14913895726204, 52.560953199863434, 52.25437045097351, 50.13155356049538, 53.878163918852806, 52.85996675491333, 53.14166843891144, 52.772324457764626, 53.54940935969353, 54.34009753167629, 55.4351531714201, 55.76096668839455, 58.207594603300095, 62.69083343446255, 74.42201614379883, 73.3817307651043, 78.77174153923988, 75.14673605561256, 82.31636613607407, 71.62377789616585, 78.84928777813911, 10.72746941819787, 0.09723946146550588, 63.54998253285885, 72.88878321647644, 64.92156833410263, 59.07406210899353, 41.21139161288738, 35.6481671333313, 67.22859174013138, 12.748931497335434, 0.7341917348094285, 0.1399153796955943, 0.0665125364321284, 0.07190789066953585, 0.017422631026420277, 0.040869263611966744, 0.0662214809563011, 0.07793965880409814, 0.10176112977205776, 0.16766597342211753, 0.24668990256031975, 0.33651270379778, 0.18480467173503712, 0.14567478705430403, 0.15081865713000298, 0.42149633110966533, 0.7008194911759347, 11.674336809664965, 84.12145167589188, 52.8549662232399, 41.5049334615469, 54.70530353486538, 66.08791574835777, 61.4509941637516, 97.4335053563118, 27.292090617120266, 0.9534339141100645, 1.687447652220726, 11.453794743865728, 78.08038383722305, 71.02228537201881, 81.76360219717026, 77.415761500597, 81.54922530055046, 74.0672367811203, 66.90465912222862, 61.89540691673756, 63.95235434174538, 62.00126923620701, 64.89035680890083, 63.928651213645935, 64.42042082548141, 65.72209417819977, 66.49331599473953, 63.52337256073952, 61.6390460729599, 62.34574735164642, 62.927241548895836, 57.779083997011185, 60.61340890824795, 57.85775497555733, 58.174426183104515, 52.302076891064644, 48.95045913755894, 53.62602844834328, 53.23790967464447, 50.85803657770157, 50.77502243220806, 52.314118444919586, 53.14576841890812, 51.87599815428257, 60.23481622338295, 59.94584932923317, 56.60818062722683, 64.16734680533409, 65.18333628773689, 64.09859329462051, 61.33978933095932, 61.27337269484997, 54.84001010656357, 58.2827165722847, 60.889528691768646, 58.64914231002331, 56.23859725892544, 54.319947212934494, 50.61439365148544, 49.957895278930664, 50.042927116155624, 45.708564296364784, 48.84667910635471, 44.09499607980251, 45.47950118780136, 46.27172067761421, 47.60047137737274, 50.105920135974884, 47.73816458880901, 51.58483877778053, 58.00330236554146, 56.684469133615494, 56.6955341398716, 52.1640644967556, 48.190910294651985, 46.40983186662197, 43.49067270755768, 45.18367946147919, 43.667234033346176, 49.89639937877655, 52.36269123852253, 45.51065571606159, 46.8997585773468, 45.551948100328445, 45.16704775393009, 47.77177758514881, 52.85913459956646, 54.967915043234825, 57.36878961324692, 55.582095086574554, 54.047532230615616, 47.14182838797569, 46.22115299105644, 45.179511085152626, 45.67511849105358, 45.39907090365887, 44.956504851579666, 47.14359529316425, 41.200546994805336, 51.906290128827095, 62.3031098395586, 48.03509205579758, 45.819347351789474, 51.562476977705956, 46.80516265332699, 59.23350155353546, 60.28515972197056, 58.09278376400471, 53.32881599664688, 59.23706196248531, 60.83874061703682, 59.02861274778843, 59.259195774793625, 62.16543562710285, 63.11774432659149, 58.300875797867775, 50.60945391654968, 52.0398985594511, 48.86731579899788, 47.43875965476036, 47.314415127038956, 50.43363355100155, 50.50362579524517, 51.926444247365, 51.92457474768162, 52.63706311583519, 53.25050599873066, 55.93403600156307, 53.57762284576893, 54.032815620303154, 55.10533466935158, 53.518828600645065, 55.896813198924065, 56.259328946471214, 56.490413546562195, 54.83966052532196, 56.48751050233841, 57.809113785624504, 57.42196016013622, 59.490253776311874, 59.87621806561947, 65.44701933860779, 76.53884455561638, 75.1317572593689, 82.2366464138031, 77.37587884068489, 84.04855638742447, 75.25126084685326, 82.68313005566597, 13.200979940593243, 0.40848959935829043, 69.61813151836395, 80.45546159148216, 75.02006605267525, 66.4446710050106, 50.02704776823521, 50.09083114564419, 81.99634730815887, 16.811872981488705, 1.1471246019937098, 0.37467945890966803, 0.15247897506924346, 0.16869797429535538, 0.19396788004087284, 0.1430108628119342, 0.10844287084182724, 0.23673126037465408], [0.005532438190130051, 0.0322632523602806, 0.043383359370636754, 0.0580742765305331, 0.07226323839859106, 0.10245952042168938, 0.10559277143329382, 0.01195394517708337, 0.17568710551131517, 1.6886691679246724, 50.39947338402271, 49.318195804953575, 28.521197363734245, 34.511693716049194, 59.084123969078064, 47.782542407512665, 83.30771014094353, 31.157872080802917, 0.04099424128071405, 0.2979750232771039, 15.209137983620167, 72.24632129073143, 64.2854368686676, 77.76858776807785, 71.0275898873806, 73.8833874464035, 59.14248883724213, 57.98951670527458, 51.348191276192665, 57.52060666680336, 58.244502022862434, 61.363142877817154, 61.046486869454384, 59.987768679857254, 59.55148369073868, 59.48988139629364, 57.52726770937443, 58.44876766204834, 55.56761026382446, 56.33195444941521, 52.65143394470215, 54.508584290742874, 49.786725863814354, 49.920250698924065, 47.40842968225479, 47.900647670030594, 46.271226704120636, 47.333862483501434, 47.67653189599514, 44.3058505654335, 45.73716916143894, 46.78327962756157, 46.67909301817417, 49.45388272404671, 49.21258047223091, 47.53459431231022, 53.93333315849304, 59.58655960857868, 58.30116458237171, 58.52319046854973, 55.78649751842022, 56.162430346012115, 47.67094239592552, 48.055515959858894, 47.92330965399742, 45.28826504945755, 35.54451249539852, 44.66443732380867, 51.52793303132057, 47.539701238274574, 43.068659752607346, 39.80622321367264, 40.772002190351486, 41.29088714718819, 42.4631280452013, 42.00989976525307, 41.85904785990715, 43.39682534337044, 50.632279291749, 52.73260518908501, 52.715392112731934, 51.864632964134216, 48.05407963693142, 46.246383637189865, 43.60033482313156, 41.155329421162605, 38.31790387630463, 40.48754945397377, 47.70466558635235, 49.49346140027046, 43.90485428273678, 40.035890489816666, 41.683698669075966, 40.477605387568474, 42.72868439555168, 45.4247385263443, 49.121867939829826, 49.63984094560146, 48.951709270477295, 50.4699482023716, 45.36594048142433, 42.45685078203678, 39.6484062820673, 42.25318931043148, 41.48275405168533, 39.9026620388031, 40.37696398794651, 42.19362750649452, 33.907659128308296, 35.76126806437969, 60.237582474946976, 49.21153552830219, 43.9232262969017, 45.526538863778114, 46.724048405885696, 52.69268073141575, 51.98831632733345, 49.73667494952679, 54.28672559559345, 46.57074563205242, 52.087320014834404, 62.519952803850174, 53.53111334145069, 57.171659991145134, 52.93633885681629, 47.15780273079872, 46.47291608154774, 44.10966709256172, 42.99623943865299, 41.86878673732281, 42.5434785336256, 45.17829515039921, 46.39081388711929, 49.01510886847973, 49.13981057703495, 49.69635531306267, 49.227042496204376, 48.663935512304306, 49.56654667854309, 51.140475422143936, 50.156985595822334, 51.97656735777855, 51.72594040632248, 51.72948941588402, 50.57110257446766, 50.51618032157421, 49.62154112756252, 52.911609783768654, 50.36685213446617, 54.343623742461205, 58.070657551288605, 68.20963829755783, 70.0067138671875, 75.63207641243935, 74.69490990042686, 76.7223747074604, 68.74140456318855, 73.68617042899132, 11.228819265961647, 0.1718458827235736, 59.52615424990654, 66.31753742694855, 57.722478434443474, 53.087574541568756, 33.494222313165665, 28.934244699776173, 58.58298406004906, 7.996196877211332, 0.14574405911844224, 0.10832219020812772, 0.050372943296679296, 0.018662514885363635, 0.0482550950255245, 0.038636612516711466, 0.01951694950548699, 0.06093600168242119, 0.008242562053055735, 0.06699698817101307, 0.07161984831327572, 0.044890472054248676, 0.04846064395678695, 0.018706854498304892, 0.026650040672393516, 0.011078899260610342, 0.07352025844738819, 1.7878551268950105, 61.241564601659775, 54.14427123963833, 29.42947592586279, 46.773088574409485, 66.1890435218811, 55.26522248983383, 90.16330987215042, 35.007802695035934, 0.15668002073653042, 0.33538024581503123, 19.144514612853527, 79.5999526977539, 70.04671812057495, 80.69846615195274, 74.67775002121925, 76.61196783185005, 62.71078236401081, 59.71164129674435, 56.312598288059235, 59.80962283909321, 61.79525949060917, 62.575418427586555, 63.94698143005371, 63.72369021177292, 61.83966390788555, 61.42816498875618, 61.36269070208073, 62.93340101838112, 59.92759510874748, 57.81196363270283, 55.390079990029335, 56.727475225925446, 53.297589272260666, 52.39977344870567, 50.46329855918884, 50.32677188515663, 49.56530414521694, 49.76376749575138, 48.127016723155975, 46.42458647489548, 46.80212661623955, 48.043390810489655, 50.54161235690117, 50.73396943509579, 54.14474621415138, 48.72424967586994, 54.27005589008331, 62.080449387431145, 58.87862719595432, 62.3919452726841, 58.033620938658714, 58.76977823674679, 52.469370514154434, 52.34950594604015, 52.49222248792648, 48.016602247953415, 41.97471745312214, 49.86228100955486, 55.03622777760029, 49.554356932640076, 45.558996722102165, 43.93739953637123, 42.96533949673176, 44.27504941821098, 42.81568832695484, 44.88408833742142, 45.55634066462517, 46.23643197119236, 54.11924958229065, 55.39030037820339, 54.81030710041523, 54.360361844301224, 50.540734604001045, 50.060626566410065, 46.37433797121048, 42.720712423324585, 41.87605954706669, 42.528226152062416, 49.885839745402336, 52.02354423701763, 44.31918404996395, 41.66153445839882, 43.81064213812351, 42.118452340364456, 44.493898674845695, 48.10316160321236, 53.0792073905468, 52.323617935180664, 51.489296704530716, 54.36764985322952, 47.96592816710472, 44.268456771969795, 41.37341111898422, 42.67983041703701, 44.0840108692646, 42.25435584783554, 41.3548719137907, 44.16747339069843, 39.303859770298004, 39.23537224531174, 57.160503789782524, 47.91716918349266, 45.641190111637115, 49.41379867494106, 49.58861969411373, 52.69455783069134, 53.74279238283634, 51.83957330882549, 54.070821180939674, 50.479489490389824, 58.07038776576519, 64.0653070807457, 57.59336516261101, 58.50726172327995, 54.61465559899807, 47.68978178501129, 49.84391279518604, 45.670190155506134, 45.033697709441185, 45.77197529375553, 47.50638462603092, 47.91886389255524, 50.577307641506195, 52.399294674396515, 51.425881907343864, 52.00737230479717, 51.666013821959496, 53.09797078371048, 53.83318953216076, 55.23694820702076, 52.98315994441509, 55.37485420703888, 54.90710690617561, 55.427519381046295, 53.453365713357925, 54.21367071568966, 52.31664910912514, 55.038393661379814, 54.12681497633457, 57.2582383453846, 61.25821150839329, 74.34708416461945, 73.69323804974556, 81.3219366967678, 76.1480887234211, 80.83146661520004, 70.46898186206818, 82.51768693327904, 14.410577584058046, 0.11182298985659145, 68.43414545059204, 72.57184982299805, 64.69379335641861, 63.40303681790829, 39.719671458005905, 31.04518722742796, 71.93966254591942, 11.210407353937626, 0.3530020377365872, 0.0316690555337118, 0.044890390418004245, 0.0331142916547833, 0.02102642407407984, 0.028495676597231068, 0.052035101762157865, 0.06316233339020982, 0.13724873919272795, 0.1485814232728444, 0.14370172808412462, 0.23392460629111156, 0.0984772747324314, 0.17384549573762342, 0.3422228473937139, 0.16016722423955798, 0.3989491128595546, 4.383326042443514, 79.60860103368759, 63.4878558665514, 38.5382654517889, 47.25044555962086, 79.68277305364609, 58.8899239897728, 96.79557278752327, 39.03438962996006, 0.23753282439429313, 0.8480292919557542, 21.859290339052677, 84.20617192983627, 70.79332485795021, 83.04346472024918, 78.06749492883682, 81.07486635446548, 65.27073919773102, 62.83212885260582, 58.206960037350655, 63.090803772211075, 65.29193446040154, 66.09301507472992, 66.85127198696136, 65.75559318065643, 64.01236072182655, 64.23521876335144, 63.37321221828461, 64.34346735477448, 63.55058290064335, 62.02420100569725, 59.469769075512886, 61.16496451199055, 54.39346566796303, 56.46367438137531, 53.158079758286476, 51.70809656381607, 51.778066009283066, 53.856322690844536, 53.07831063866615, 49.62790198624134, 52.120420038700104, 51.08318209648132, 52.27547071874142, 54.5197556912899, 56.01930342614651, 49.92932081222534, 57.69285522401333, 64.83966752886772, 63.95613133907318, 65.84590673446655, 61.15821227431297, 62.0388226211071, 53.99137884378433, 56.540407463908195, 56.37963809072971, 51.45876534283161, 44.47427652776241, 50.87850607931614, 54.739592894911766, 51.25643000006676, 47.395107597112656, 47.33173079788685, 46.19547016918659, 48.88839706778526, 44.734304174780846, 47.57115975022316, 48.50815527141094, 50.66004440188408, 56.38515159487724, 61.097681522369385, 59.32755410671234, 59.12877157330513, 55.354468300938606, 53.12710762023926, 50.16614690423012, 45.168054699897766, 43.41015122830868, 45.34959375858307, 53.204403072595596, 53.86502042412758, 49.590492993593216, 45.18049143254757, 45.6401489675045, 44.42901335656643, 46.84276923537254, 51.37047328054905, 55.815520361065865, 57.99878440797329, 56.35485582053661, 56.84050016105175, 50.28852693736553, 45.91629154980183, 41.78315073251724, 46.16590395569801, 47.541038766503334, 44.39785122871399, 44.1179658472538, 47.358766347169876, 39.78934071958065, 47.35574550926685, 59.563365653157234, 44.61145676672459, 48.43232274055481, 50.89976213872433, 53.49950663745403, 56.554873287677765, 55.51260821521282, 53.0058903247118, 59.70263957977295, 54.32581029832363, 59.040004536509514, 66.02335721254349, 59.32641416788101, 61.48549631237984, 57.33304113149643, 50.74430488049984, 52.32069209218025, 50.260283052921295, 48.135095089673996, 48.063567727804184, 50.08428029716015, 50.31513690948486, 51.705999076366425, 55.8508812636137, 53.32269832491875, 56.51886261999607, 54.96588595211506, 55.23731678724289, 55.428051352500916, 57.426189333200455, 56.13505661487579, 58.621278405189514, 58.837570399045944, 58.290825337171555, 56.44482359290123, 56.23636677861214, 53.45382548868656, 59.00310091674328, 56.624504551291466, 60.51604673266411, 64.40548002719879, 75.17543211579323, 75.94498962163925, 83.99220541119576, 80.95427602529526, 83.45483064651489, 71.32682383060455, 81.51696503162384, 16.598617024719715, 0.2466144855134189, 71.87444284558296, 79.90340441465378, 73.89524281024933, 71.36701047420502, 49.99367795884609, 44.42441560328007, 84.08311933279037, 15.997033305466175, 0.47428817488253117, 0.24043000565143302, 0.23707742773694918, 0.13685924524907023, 0.20310434134444222, 0.09538997750496492, 0.07139491077396087, 0.35312567953951657], [0.060020848250132985, 0.058092199396924116, 0.0499662908987375, 0.07617679089889862, 0.028498897518147714, 0.017255336097150575, 0.04925352113787085, 0.045299799894564785, 0.03523775056237355, 0.22006942162988707, 36.74109488725662, 54.971954226493835, 33.01152661442757, 32.80861370265484, 47.9027945548296, 41.668339893221855, 75.85329294204712, 40.81959843635559, 0.19942325918236747, 0.3969986300216988, 29.78000521659851, 76.65527790784836, 71.14577874541283, 76.78941071033478, 70.79647868871689, 70.3869366645813, 56.80563323199749, 52.058593556284904, 55.05087599158287, 59.46921810507774, 58.91330413520336, 62.765503227710724, 58.18048685789108, 61.55065141618252, 61.73042356967926, 61.072857454419136, 58.12558740377426, 56.96957163512707, 55.81094540655613, 54.73596788942814, 51.59328192472458, 51.15125924348831, 48.266294449567795, 49.306705221533775, 47.61651411652565, 47.87985898554325, 47.951937317848206, 47.46358372271061, 45.571156069636345, 43.3137010037899, 44.36171516776085, 45.759116783738136, 47.216460183262825, 50.39036147296429, 52.259389981627464, 52.32142545282841, 53.617596700787544, 59.677348136901855, 58.10453653335571, 57.97234922647476, 54.87214118242264, 55.1031231880188, 52.08554930984974, 49.909653067588806, 46.41455881297588, 45.566174536943436, 48.59074003994465, 51.30463421344757, 52.67979182302952, 52.20660701394081, 43.278803676366806, 44.672177508473396, 44.2128087580204, 42.50309810042381, 42.11483113467693, 42.881455197930336, 42.8420665115118, 45.23939207196236, 48.98812651634216, 52.948441207408905, 48.181167617440224, 51.2189070135355, 46.32060885429382, 45.681011974811554, 45.310976430773735, 43.11049550771713, 40.92052482068539, 43.213819563388824, 50.50211347639561, 55.09135901927948, 43.78329120576382, 43.20206679403782, 43.57307888567448, 44.05317932367325, 45.61847113072872, 50.92240892350674, 47.03105293214321, 49.62788678705692, 49.488472267985344, 52.4895816296339, 45.669547989964485, 41.85304418206215, 39.955505803227425, 37.71981216967106, 39.080785140395164, 41.74742504954338, 40.36063626408577, 41.4664301276207, 42.99446113407612, 38.79089489579201, 39.72578153014183, 56.89640276134014, 45.08489616215229, 43.899568766355515, 50.096454843878746, 52.883852273225784, 49.11850892007351, 48.25044929981232, 44.39155116677284, 52.01100490987301, 56.53144374489784, 57.498735040426254, 57.82452195882797, 50.75353838503361, 49.600421860814095, 46.05354778468609, 45.27691885828972, 41.62201277911663, 40.96738390624523, 41.72078847885132, 45.95578283071518, 47.875230833888054, 48.5721780359745, 48.02166737616062, 49.1755286604166, 48.91600638628006, 49.026895835995674, 49.275721684098244, 50.89267551898956, 50.08731633424759, 50.20920619368553, 49.665242582559586, 51.075130328536034, 52.30622626841068, 52.23420113325119, 53.58523003757, 52.62968011200428, 49.99933585524559, 53.24346497654915, 52.03847363591194, 56.08785554766655, 69.00897100567818, 72.29813531041145, 73.96998479962349, 73.63003984093666, 80.534558147192, 67.68179342150688, 79.29793730378151, 14.676455967128277, 0.10542543939664029, 67.16343283653259, 56.33723236620426, 59.247670993208885, 42.02921412885189, 30.773591101169586, 32.793809697031975, 60.57406201958656, 8.887054324150085, 0.3788095701020211, 0.039537286647828296, 0.09142999624600634, 0.00937135104322806, 0.043819634593091905, 0.10515816233237274, 0.04550580524664838, 0.03652569961559493, 0.01441637818061281, 0.04703242528194096, 0.05823345978569705, 0.10735949108493514, 0.0585383377620019, 0.02637342367961537, 0.05762003762356471, 0.043357117028790526, 0.0633765765815042, 0.1298679321189411, 48.87137018144131, 59.993111193180084, 35.87030701339245, 42.9451397806406, 55.98797410726547, 48.44890885055065, 85.35231962800026, 44.8593744635582, 0.2451730566099286, 0.33729878661688417, 37.79983967542648, 82.26094231009483, 75.53764387965202, 80.75739338994026, 75.88545441627502, 73.0922394990921, 59.182181507349014, 56.11166886985302, 58.51436734199524, 62.432770282030106, 61.803771033883095, 67.32098758220673, 61.81784547865391, 64.0533909201622, 65.23945167660713, 63.26990336179733, 60.926246121525764, 58.73695179820061, 57.581692188978195, 57.870871871709824, 55.79905964434147, 53.26689451932907, 49.86062429845333, 51.15626357495785, 50.72277523577213, 50.29706887900829, 49.10184681415558, 51.35447233915329, 48.865271508693695, 47.05389730632305, 46.90937206149101, 48.2604655623436, 49.93937127292156, 51.75604619085789, 55.485675260424614, 55.59286370873451, 55.15619494020939, 63.48784066736698, 61.087023094296455, 61.38525389134884, 59.61932525038719, 58.18297952413559, 54.07356843352318, 55.7394028455019, 50.43458350002766, 48.463017493486404, 51.41268901526928, 54.42848838865757, 55.102579817175865, 54.67588171362877, 46.40861973166466, 45.690598860383034, 46.668521985411644, 44.85716678202152, 43.7986271828413, 44.127841517329216, 44.96984973549843, 47.35231049358845, 50.212280228734016, 54.13860194385052, 53.22793520987034, 54.36832621693611, 50.51724046468735, 48.73897388577461, 47.46256537735462, 45.15248313546181, 44.036327227950096, 46.016940549016, 51.898048371076584, 56.10517121851444, 44.74795304238796, 46.00058242678642, 46.144777089357376, 47.029890194535255, 48.35272081196308, 51.7696912586689, 51.75551421940327, 52.82830685377121, 52.030570060014725, 54.28422532975674, 46.55789092183113, 43.30905765295029, 41.273392885923386, 42.33656443655491, 41.4641198515892, 41.927808970212936, 42.038994804024696, 42.97108478844166, 44.353583604097366, 44.79501731693745, 41.448669880628586, 54.72939424216747, 46.09229430556297, 46.04437507688999, 52.14590147137642, 53.9328695833683, 51.99324086308479, 50.21977722644806, 49.5440860837698, 57.10501156747341, 56.55659839510918, 58.3442048728466, 59.74851071834564, 54.40306015312672, 51.81709371507168, 48.828493282198906, 48.177952989935875, 45.41974559426308, 44.635672867298126, 43.82951572537422, 48.48357819020748, 48.176444470882416, 49.17656600475311, 51.77227132022381, 54.46417227387428, 52.239273861050606, 53.00345465540886, 52.77260184288025, 54.331130012869835, 54.371837228536606, 53.18501651287079, 53.861441016197205, 54.699622839689255, 56.140376329422, 56.41731306910515, 58.227034360170364, 56.054880917072296, 55.24226792156696, 55.996440052986145, 56.733554899692535, 59.87496793270111, 72.24718764424324, 76.26889944076538, 79.08687382936478, 77.95696645975113, 84.12930965423584, 71.16116791963577, 84.96774986386299, 19.62074875831604, 0.10899038286879659, 73.77326935529709, 60.095774084329605, 67.62914344668388, 52.7646716684103, 35.29017694294453, 39.55461971461773, 72.44754329323769, 12.540375888347626, 0.4212299594655633, 0.12262983262189664, 0.03915141809557099, 0.008993759292934556, 0.10089203031384386, 0.03959691821364686, 0.02478526846971363, 0.04393888659251388, 0.14515362126985565, 0.20957316766725853, 0.15649850625777617, 0.19360191217856482, 0.1156572661420796, 0.10603808230371214, 0.1702285499777645, 0.1722532178973779, 0.1237495627719909, 0.5592907418031245, 64.53417912125587, 69.33737978339195, 46.31186932325363, 43.317930176854134, 65.92500329017639, 51.31145104765892, 89.74400237202644, 47.35352262854576, 0.33061583584640175, 0.4445839812979102, 42.7493666857481, 85.82771971821785, 77.35805779695511, 81.9939686357975, 77.99172699451447, 76.52704998850822, 62.963677793741226, 56.976335272192955, 61.16513930261135, 65.73427632451057, 66.10379129648209, 68.09851706027985, 63.95575895905495, 66.21331661939621, 66.55450031161308, 64.307901263237, 64.80489939451218, 61.92111253738403, 60.325992330908775, 60.34895829856396, 56.51437506079674, 57.05842226743698, 52.284259647130966, 52.655898705124855, 52.80429594218731, 50.58829665184021, 52.484463304281235, 53.62832352519035, 52.62482777237892, 47.51954711973667, 49.79518800973892, 51.26274146139622, 52.469055131077766, 54.807335659861565, 58.982122242450714, 57.37247161567211, 56.74378015100956, 64.83614131808281, 64.04111757874489, 64.05480444431305, 61.25437751412392, 60.61984956264496, 55.55566370487213, 56.090929582715034, 54.13106694817543, 51.589831709861755, 53.55542443692684, 55.48081912100315, 58.7745925784111, 58.59126381576061, 49.60220396518707, 48.88391710817814, 49.2022792249918, 46.96677178144455, 46.64048328995705, 47.33510501682758, 46.716175228357315, 50.58401048183441, 53.99816907942295, 59.210558384656906, 57.33328051865101, 59.67778131365776, 53.488377034664154, 51.71696148812771, 49.238901659846306, 47.65416629612446, 46.8425602465868, 47.22953908145428, 55.36658965051174, 59.778810292482376, 47.72203825414181, 47.94947884976864, 48.93775261938572, 50.21868668496609, 52.54871025681496, 54.461250230669975, 55.008835047483444, 57.58327670395374, 56.90130069851875, 59.331106916069984, 49.8823781311512, 44.63818073272705, 44.479569643735886, 43.65915186703205, 43.936365991830826, 45.3743152320385, 46.00841000676155, 46.41267031431198, 47.9851209372282, 45.95085069537163, 47.73118436336517, 56.88510976731777, 44.617905020713806, 47.38297864794731, 50.986842066049576, 56.11382335424423, 53.423370122909546, 53.924365639686584, 53.71661178767681, 58.209464102983475, 59.94502857327461, 60.2811623364687, 63.37464854121208, 56.70261695981026, 54.32857654988766, 51.33688308298588, 49.483156353235245, 48.91464605927467, 46.873881965875626, 46.67116664350033, 50.38097597658634, 51.7273311316967, 50.6174448877573, 51.93224273622036, 56.08940206468105, 54.55822102725506, 55.47062806785107, 55.926098227500916, 56.294359266757965, 56.70836605131626, 56.10490903258324, 57.23914436995983, 56.77985541522503, 59.269219636917114, 58.70115391910076, 60.584997832775116, 58.87170396745205, 56.712211444973946, 58.710991591215134, 60.68463608622551, 63.31071697175503, 76.44995212554932, 78.94320353865623, 80.44453337788582, 79.79583218693733, 86.60590276122093, 71.39377623796463, 84.07993510365486, 26.97383489459753, 0.3596251120325178, 79.47142079472542, 67.22222328186035, 75.71689546108246, 59.99456271529198, 45.85680954158306, 50.74908122420311, 85.47800168395042, 17.076882161200047, 0.7696539256721735, 0.2527127129724249, 0.29128260270226747, 0.1194532921363134, 0.21753967768745497, 0.32747292949352413, 0.10708937901654281, 0.21055798279121518], [0.03172601907863282, 0.06043774228601251, 0.053353723778855056, 0.04958308294590097, 0.03976390515163075, 0.01697899555438198, 0.11764847062295303, 0.034516679879743606, 0.06243431620532647, 0.13610845897346735, 31.46352767944336, 61.63916386663914, 41.08225554227829, 28.217738047242165, 51.317063346505165, 47.2580299526453, 69.8351302742958, 49.29112985730171, 0.04673858675232623, 0.5675951368175447, 45.65230831503868, 68.54722738265991, 76.01501986384392, 74.3758562207222, 71.40347331762314, 66.37628987431526, 52.960239574313164, 53.81098352372646, 56.87655262649059, 60.86775965988636, 62.86721616983414, 62.79345452785492, 63.621984869241714, 63.65250863134861, 61.39444939792156, 62.595663741230965, 58.02970714867115, 59.47641871869564, 53.60374644398689, 53.14171023666859, 53.01956579089165, 52.70658798515797, 54.24361690878868, 53.31164851784706, 50.9410735219717, 49.38869722187519, 46.92237876355648, 48.505533412098885, 46.82056702673435, 44.596044793725014, 43.66591930389404, 44.63032655417919, 45.39874792098999, 49.49052035808563, 51.68683670461178, 53.616661950945854, 53.50137233734131, 54.76369500160217, 58.55843737721443, 57.63465754687786, 57.047440856695175, 56.78921811282635, 50.74856445193291, 49.319191351532936, 50.31126111745834, 52.07387633621693, 48.21280092000961, 50.36784388124943, 54.42794881761074, 52.10818089544773, 49.91452820599079, 43.72215248644352, 40.01805044710636, 39.82178337872028, 38.87611672282219, 43.10801424086094, 42.23990902304649, 41.8269319832325, 45.890943109989166, 52.56794862449169, 52.597476840019226, 51.08430303633213, 45.40374465286732, 46.394708678126335, 45.33566750586033, 48.26735079288483, 45.372673720121384, 43.585280030965805, 50.960688069462776, 51.76853232085705, 45.48017755150795, 45.50570838153362, 43.99903982877731, 46.6870079934597, 45.096512138843536, 46.98578216135502, 49.842655062675476, 48.638423681259155, 49.34240810573101, 50.38523554801941, 43.9517817646265, 40.304080098867416, 40.15668600797653, 42.707154750823975, 39.63380366563797, 40.851159542798996, 40.153190195560455, 41.70784257352352, 40.29652610421181, 44.16023477911949, 37.648695185780525, 45.0126126408577, 45.26319399476051, 41.67033478617668, 47.52862483263016, 45.69086864590645, 44.99313868582249, 43.73653091490269, 50.79495616257191, 56.42737112939358, 53.67889121174812, 52.7464896440506, 56.53107516467571, 54.082577750086784, 49.114131554961205, 44.959187507629395, 44.308578819036484, 43.06607969105244, 41.065110862255096, 42.80469551682472, 46.76093302667141, 45.6502678245306, 48.088908568024635, 51.479744017124176, 50.82200691103935, 51.474006325006485, 52.55264684557915, 49.7539222240448, 49.77153807878494, 51.614321395754814, 51.48561470210552, 50.90860426425934, 52.680114805698395, 53.945579901337624, 55.02821780741215, 58.253480941057205, 56.92736729979515, 55.09871542453766, 53.690366595983505, 55.800283178687096, 54.50976222753525, 63.457658886909485, 69.94871377944946, 74.24609318375587, 72.48207584023476, 79.03406426310539, 70.57891756296158, 83.23812067508698, 11.685270722955465, 0.4595106194028631, 68.93675208091736, 58.22805270552635, 55.835492089390755, 44.523818269371986, 34.00658681988716, 38.68478178977966, 68.35346817970276, 6.61611283197999, 0.25864211667794734, 0.08634708618046716, 0.017725282559695188, 0.06413533352315426, 0.11877530312631279, 0.04912678457912989, 0.04885099879174959, 0.04697903888882138, 0.09110576676903293, 0.034008843067567796, 0.08294138533528894, 0.04172321583610028, 0.04632348500308581, 0.022781083825975657, 0.01891034025902627, 0.09817532452871092, 0.04251319864124525, 0.12997689424082637, 40.024304911494255, 69.57713171839714, 36.166953295469284, 33.33653837442398, 60.13303488492966, 50.21191164851189, 79.21332344412804, 52.83836491405964, 0.12508599262218922, 0.586799425072968, 53.44318225979805, 73.5125121474266, 80.25873854756355, 77.08479166030884, 76.76362529397011, 69.7417464852333, 58.04812856018543, 57.1336430311203, 61.36354945600033, 62.49288685619831, 65.09945958852768, 65.24407982826233, 66.73803806304932, 65.35798251628876, 63.41789782047272, 65.71309626102448, 61.68777845799923, 60.69136552512646, 57.15784013271332, 54.30393107235432, 54.86846297979355, 54.58461441099644, 56.62757098674774, 59.11449953913689, 54.55816403031349, 52.72099681198597, 50.59882588684559, 50.83151400089264, 49.30188708007336, 47.51967251300812, 46.30024954676628, 45.76260879635811, 49.37788300216198, 51.39265649020672, 53.10370847582817, 55.60578681528568, 54.223158806562424, 56.00786603987217, 61.666191816329956, 59.38495382666588, 61.97354972362518, 59.25216235220432, 54.88350257277489, 50.33751770853996, 54.84122224152088, 52.427052184939384, 50.0125515460968, 53.133441880345345, 55.83453454077244, 54.021754413843155, 52.73091807961464, 46.714142337441444, 43.292600736021996, 42.79510863125324, 40.48633351922035, 45.03514923155308, 43.13871659338474, 45.286399349570274, 49.12993110716343, 53.93776372075081, 55.97731567919254, 56.47408962249756, 48.39037299156189, 49.294648468494415, 47.2891540825367, 49.46323402225971, 49.93781715631485, 45.344574227929115, 52.890000343322754, 55.29997922480106, 46.767575070261955, 46.15031719207764, 46.770979687571526, 49.09439541399479, 47.14724309742451, 50.008215978741646, 54.013771042227745, 51.95523530244827, 52.42614023387432, 52.88666792213917, 46.08174607157707, 43.52518245577812, 43.05460050702095, 42.778294533491135, 43.065821304917336, 44.04632829129696, 42.817493230104446, 42.4795051664114, 44.55710828304291, 46.704882234334946, 42.68334902822971, 46.94974109530449, 45.84794841706753, 45.06719671189785, 49.795697182416916, 48.803718611598015, 49.39668819308281, 50.33370651304722, 55.693033933639526, 59.07022051513195, 56.542250365018845, 55.58371759951115, 59.382499158382416, 56.96750074625015, 49.39641460776329, 46.61663196980953, 45.34846521914005, 46.065988317131996, 43.790689408779144, 47.27358631789684, 48.64615626633167, 50.41387841105461, 49.083440601825714, 54.519964680075645, 54.87475544214249, 54.76670444011688, 54.298200979828835, 55.54585263133049, 52.907452806830406, 55.2106574177742, 52.99567647278309, 55.715087950229645, 55.17159551382065, 57.02545903623104, 57.11167261004448, 63.15746359527111, 59.97575752437115, 58.7106192111969, 56.49029195308685, 59.574419260025024, 57.733995616436005, 66.9049783051014, 73.75042498111725, 79.60477843880653, 76.19960635900497, 86.11831292510033, 72.81828179955482, 87.50029116868973, 12.67988445237279, 1.1494091106578708, 76.9889760017395, 63.32631893455982, 63.176933750510216, 57.82898671925068, 46.38143979012966, 45.53574196994305, 76.1046190559864, 7.838158132508397, 0.31169715570285916, 0.12151690796599723, 0.0522122153051896, 0.014322909319162136, 0.025169379987346474, 0.0900221717893146, 0.014215588271326851, 0.12461168604204431, 0.14415810437640175, 0.2305885188980028, 0.14046565251192078, 0.18560409836936742, 0.19257504696724936, 0.06811031358665787, 0.19339063757797703, 0.23127741005737334, 0.21495624678209424, 0.21007392439059913, 51.87834642827511, 80.04003748297691, 55.55639326572418, 38.630433306097984, 72.19862625002861, 60.005897507071495, 84.41788896918297, 55.92391714453697, 0.28777770639862865, 0.9157072228845209, 56.194253638386726, 75.52425339818001, 81.9168783724308, 79.37401682138443, 80.05452990531921, 71.66529446840286, 59.72302928566933, 59.162536561489105, 63.659348264336586, 64.28613603115082, 68.17078158259392, 68.04452955722809, 67.95520395040512, 67.52433747053146, 66.38942196965218, 68.50235939025879, 64.30887401103973, 64.54816997051239, 58.930148631334305, 57.99032226204872, 57.92193353176117, 57.0030402392149, 58.88757571578026, 60.75087033212185, 56.14554405212402, 55.82676015794277, 52.79148682951927, 52.85460144281387, 51.9706966727972, 51.20403081178665, 47.8318827599287, 50.75174868106842, 52.420508936047554, 54.72545005381107, 56.66091799736023, 59.33041915297508, 59.017513543367386, 60.24237401783466, 65.78706309199333, 62.25239776074886, 64.13732841610909, 60.29024004936218, 58.00417251884937, 51.60327918827534, 58.444717079401016, 55.14234848320484, 54.56936202943325, 56.45998477935791, 58.77131335437298, 56.56065657734871, 55.03737531602383, 48.68045322597027, 45.47437906265259, 46.00234553217888, 42.625459134578705, 47.193589210510254, 47.315049692988396, 49.353089332580566, 52.017202377319336, 59.98552680015564, 60.02962723374367, 60.47065056860447, 53.20523522794247, 54.336335733532906, 49.024786949157715, 53.35960954427719, 53.016134575009346, 47.19649985432625, 56.53895974159241, 55.05023382604122, 49.870214983820915, 52.66780346632004, 49.773468375205994, 51.739433482289314, 50.92370845377445, 55.586107671260834, 58.759340196847916, 55.136872977018356, 57.401897236704826, 55.40435962378979, 49.554535523056984, 45.086742863059044, 45.39341300725937, 46.09001822769642, 44.13206689059734, 46.39791190624237, 45.62414802610874, 45.73484368622303, 46.61749452352524, 51.0049556940794, 49.423001781105995, 51.30612373352051, 48.176649659872055, 49.61065091192722, 54.619101360440254, 51.733380407094955, 53.01796227693558, 53.22624430060387, 56.326858922839165, 61.45323604345322, 58.12838785350323, 57.628786861896515, 60.25844715535641, 61.2492173910141, 51.93325348198414, 50.345527678728104, 48.820456713438034, 48.926729410886765, 46.26714572310448, 49.19827423989773, 51.14883877336979, 52.58576586842537, 51.91368833184242, 57.224648147821426, 56.264732256531715, 57.689104825258255, 56.55074290931225, 56.833918914198875, 55.4589056968689, 58.329233676195145, 55.05747623741627, 56.61571182310581, 58.3074114471674, 60.15773355960846, 61.60124570131302, 65.97212836146355, 63.39159943163395, 61.30830802023411, 61.30465641617775, 62.395167499780655, 60.35563834011555, 72.82369270920753, 75.78012406826019, 83.27155128121376, 79.92247179150581, 91.3013108074665, 75.37389546632767, 91.7900937795639, 23.291722275316715, 1.5606041648425162, 84.19638365507126, 71.30735367536545, 73.54898259043694, 62.268641889095306, 49.40264627337456, 54.303209111094475, 92.67683699727058, 11.74439650028944, 0.4779094993136823, 0.15422872180351987, 0.1358472229912877, 0.3129492182051763, 0.17760288552381098, 0.23151771747507155, 0.10050466633401811, 0.21214519918430597], [0.028461420915846247, 0.03278448493801989, 0.0719792555901222, 0.039594940390088595, 0.05699447021470405, 0.02974303573864745, 0.12215443508466706, 0.054303342549246736, 0.01779208698280854, 0.27714905329048634, 26.618895940482616, 62.68061198294163, 54.604095965623856, 36.78307123482227, 39.74043354392052, 50.36013789474964, 63.409534469246864, 53.81383717060089, 0.14458124729571864, 1.1994525440968573, 48.797065168619156, 68.8199083507061, 75.28270795941353, 71.91123247146606, 69.73354652523994, 60.72907090187073, 54.592544585466385, 56.60716228187084, 58.10694560408592, 62.89269000291824, 64.3421146273613, 64.2191532254219, 60.19872575998306, 63.52551944553852, 64.52674672007561, 63.120518177747726, 57.51978971064091, 54.84439507126808, 53.561344519257545, 56.875576078891754, 60.14325253665447, 62.03754588961601, 58.41281399130821, 61.19674600660801, 57.38993167877197, 53.605300560593605, 49.50207933783531, 48.14664267003536, 48.110081031918526, 44.9527582526207, 41.18232697248459, 44.639795646071434, 43.19492317736149, 44.62045468389988, 48.81597675383091, 50.82686685025692, 48.9922720938921, 52.86838710308075, 55.30065938830376, 54.85208585858345, 58.35900127887726, 55.652334317564964, 55.81645131111145, 48.728566244244576, 47.502425238490105, 47.764500975608826, 47.52914160490036, 54.157361537218094, 54.51518073678017, 54.43395249545574, 46.778233498334885, 43.54003585875034, 41.680138260126114, 43.66902753710747, 39.58758294582367, 41.45578309893608, 41.63082830607891, 42.31869399547577, 43.711456060409546, 50.95165595412254, 48.07399056851864, 51.708005368709564, 49.63326349854469, 44.423522651195526, 47.55026087164879, 48.43234933912754, 45.89821971952915, 45.771154537796974, 49.70473766326904, 51.606072038412094, 45.32207943499088, 43.82652908563614, 47.368421629071236, 45.48978343605995, 46.07763089239597, 47.09042474627495, 48.61980848014355, 49.52785335481167, 50.51149137318134, 46.54750607907772, 45.95466189086437, 41.253892332315445, 41.332973688840866, 40.40778413414955, 39.24076795578003, 41.67783558368683, 39.84055057168007, 41.76601365208626, 48.5419886559248, 51.29296883940697, 40.522910356521606, 44.52033765614033, 39.71255823969841, 43.331556245684624, 46.88322566449642, 43.29403705894947, 48.521697744727135, 54.261954724788666, 52.891022488474846, 52.36982345581055, 49.67844307422638, 53.63121896982193, 54.672233909368515, 50.16227871179581, 45.347549468278885, 42.27231368422508, 43.49538445472717, 41.80780000984669, 41.50147184729576, 44.69050772488117, 46.748196110129356, 47.30692572891712, 50.005221739411354, 51.665489450097084, 55.75715929269791, 56.49053514003754, 56.62700101733208, 58.13056133687496, 54.842639565467834, 51.61537393927574, 50.94736598432064, 50.9164584428072, 54.64446119964123, 52.38810807466507, 53.84594924747944, 56.27453573048115, 59.39364396035671, 60.55722892284393, 56.31304666399956, 55.85141323506832, 54.050902649760246, 55.489946231245995, 61.61704145371914, 72.52098575234413, 69.56679627299309, 75.13481229543686, 69.57139402627945, 78.67496833205223, 4.245702652260661, 1.893454547971487, 69.1090652346611, 50.323952436447144, 49.946670681238174, 34.992326125502586, 28.65696407854557, 41.117700040340424, 63.80603179335594, 3.885145462118089, 0.34408032428473234, 0.056957418491947465, 0.1055564804119058, 0.08938201746786945, 0.04839341279875953, 0.0327231761184521, 0.07348764847847633, 0.019164410805387888, 0.06435110553866252, 0.04044715969939716, 0.08719997713342309, 0.013347443400562042, 0.06963868509046733, 0.05692377693776507, 0.049982952114078216, 0.023187370716186706, 0.219036188791506, 0.49029843765310943, 30.28708230704069, 67.60241568088531, 54.225628674030304, 36.49364836513996, 47.97202304005623, 53.54494459927082, 70.63122555613518, 59.96526248753071, 0.06437149975681677, 1.2740053748711944, 57.52310313284397, 73.56656044721603, 78.05662751197815, 76.50074020028114, 72.25472643971443, 62.75724247097969, 60.09862773120403, 61.15194261074066, 61.4428436011076, 67.23021805286407, 65.3929178416729, 65.75621634721756, 65.56160598993301, 65.48303380608559, 66.61028891801834, 64.75155785679817, 61.877407282590866, 57.92594991624355, 56.72287367284298, 60.011247619986534, 65.32022014260292, 66.54506921768188, 63.29615235328674, 64.88041654229164, 60.16148395836353, 56.7502436041832, 51.12429969012737, 50.864678621292114, 49.42504607141018, 46.4459565281868, 44.5266605168581, 46.022484451532364, 46.10460564494133, 48.620165660977364, 50.17656974494457, 52.57604978978634, 52.441502809524536, 55.30151054263115, 56.82211294770241, 56.67402729392052, 61.916115805506706, 58.54894928634167, 58.91023389995098, 51.03692337870598, 49.25872899591923, 50.19313305616379, 50.449364706873894, 57.42424763739109, 56.27181127667427, 56.2976498901844, 51.09215721487999, 44.83379043638706, 43.186027854681015, 44.44037474691868, 43.44412140548229, 41.93500578403473, 44.144252836704254, 44.553582072257996, 47.86508157849312, 53.17151203751564, 51.55631370842457, 55.205147713422775, 54.475210681557655, 49.032599329948425, 50.99227577447891, 51.15101605653763, 47.87979058921337, 48.57906326651573, 51.62357769906521, 52.06032246351242, 48.16815331578255, 46.53787359595299, 48.79326157271862, 49.73794788122177, 47.45339646935463, 52.53560855984688, 54.581722766160965, 50.98833158612251, 52.785616144537926, 49.84839655458927, 47.61568196117878, 43.76146137714386, 43.12985546886921, 41.119193360209465, 42.62701325118542, 44.52203996479511, 42.3295234143734, 44.088042452931404, 47.80963495373726, 53.921280205249786, 46.11484609544277, 47.74188078939915, 45.136892572045326, 47.963788881897926, 51.56398929655552, 50.44429957866669, 50.45417904853821, 58.52629870176315, 55.520842373371124, 54.733460023999214, 51.71514518558979, 55.13592302799225, 56.89899042248726, 52.873767614364624, 46.54467523097992, 45.884681046009064, 46.010024920105934, 45.02927474677563, 44.54510472714901, 48.31168681383133, 49.210475385189056, 49.44275692105293, 51.65416605770588, 54.507368355989456, 59.61736835539341, 61.03915326297283, 61.33757404983044, 60.22898353636265, 58.4591943025589, 56.06044381856918, 52.11890012025833, 53.82652088999748, 56.78568810224533, 56.5164877474308, 58.721634820103645, 59.994775503873825, 61.882730796933174, 64.33315470814705, 62.77287483215332, 60.56575186550617, 57.75414973497391, 57.86191575229168, 63.62609624862671, 75.14267787337303, 71.23723223805428, 80.13036623597145, 72.25094184279442, 85.63614159822464, 5.789028787985444, 2.564970189705491, 77.64757946133614, 55.98796270787716, 58.704440742731094, 50.24637959897518, 33.84500049054623, 47.247211933135986, 74.2662625014782, 4.192382488399744, 0.18952918384457007, 0.04358449252322316, 0.07570434710942209, 0.008742693516978761, 0.04251241567544639, 0.041814718933892436, 0.06027476665622089, 0.04231205064570531, 0.22541169746546075, 0.11602470345678739, 0.19568476447602734, 0.12217914118082263, 0.24875547765986994, 0.16643209353787825, 0.18432911834679544, 0.15601088554831222, 0.43519501166883856, 0.5437499319668859, 42.26046212017536, 78.82512867450714, 71.65498942136765, 48.70340779423714, 57.21018612384796, 65.09778007864952, 75.70747196674347, 66.47737964987755, 0.41435262537561357, 1.65618542348966, 59.64665338397026, 72.41266116499901, 83.0687789618969, 76.4988175034523, 77.18976482748985, 64.01287749409676, 61.47596262395382, 62.22448445856571, 63.45429986715317, 70.01593977212906, 67.94725477695465, 68.49178835749626, 65.06128683686256, 67.14780807495117, 68.75605657696724, 67.54159614443779, 65.07754236459732, 58.96508775651455, 60.72573088109493, 61.50109067559242, 64.6734644472599, 69.68482553958893, 64.46925580501556, 66.2871390581131, 62.453376576304436, 59.73131664097309, 53.43531288206577, 52.562222331762314, 54.758895859122276, 50.54045721888542, 48.16168986260891, 47.61253573000431, 47.38721542060375, 50.85970088839531, 52.95433849096298, 55.58524891734123, 54.64248530566692, 58.86536970734596, 59.85477961599827, 59.66899238526821, 66.1985582113266, 62.78952933847904, 59.53865557909012, 50.91576687991619, 51.34482845664024, 53.30720655620098, 54.50992561876774, 59.096515104174614, 58.80583070218563, 58.94410528242588, 54.324149787425995, 48.365621119737625, 45.90116836130619, 48.08953553438187, 47.103036269545555, 44.861756935715675, 47.10023581981659, 46.304824501276016, 50.767609030008316, 57.474089562892914, 56.330339536070824, 60.43324537575245, 59.076364785432816, 52.58280582726002, 55.356079414486885, 55.526040494441986, 51.784221678972244, 50.15247143805027, 55.15408605337143, 53.82939733564854, 51.45117335021496, 48.783214911818504, 53.25149394571781, 52.0029379427433, 52.2751971334219, 56.68684780597687, 59.000688046216965, 58.16957384347916, 58.19928824901581, 53.18447694182396, 52.04472430050373, 45.512209832668304, 47.049903720617294, 43.61908681690693, 44.687441289424896, 47.893583849072456, 45.09685792028904, 47.107314839959145, 52.08432577550411, 57.37006634473801, 48.67624685168266, 50.87404511868954, 46.70508362352848, 48.89462873339653, 53.22193153202534, 50.4235602915287, 52.90047638118267, 59.29144844412804, 57.85335101187229, 56.143822744488716, 55.62806881964207, 59.06876519322395, 60.05130507051945, 55.81015504896641, 49.91803161799908, 47.75248222053051, 47.20689609646797, 47.41357080638409, 46.090151220560074, 51.061359867453575, 51.41995422542095, 51.29962608218193, 54.610673412680626, 57.471304312348366, 61.387993544340134, 63.0073032528162, 61.38311080634594, 63.26742209494114, 59.98770788311958, 56.62317082285881, 54.42588932812214, 57.39594295620918, 58.555617928504944, 61.84671252965927, 59.006501734256744, 62.929392233490944, 64.47810173034668, 68.52608531713486, 63.06472197175026, 65.26654422283173, 61.9235710054636, 62.682975456118584, 66.29527062177658, 79.8554053902626, 75.37760406732559, 84.6521919965744, 75.3568647801876, 95.5803219974041, 12.38376159220934, 2.815329018048942, 86.5956661105156, 62.16474786400795, 68.54073733091354, 49.25644911825657, 39.62647385895252, 53.88336583971977, 89.07351315021515, 5.4863987769931555, 0.4526721441652626, 0.13969226041808724, 0.10516262263990939, 0.13310710986843333, 0.11236512873438187, 0.11165539064677432, 0.1722817905829288, 0.09634029018343426], [0.03264179962570779, 0.03365775526617654, 0.07105836164555512, 0.03178623694111593, 0.06466001708758995, 0.020143080946581904, 0.033310496946796775, 0.062317042029462755, 0.15609152731485665, 0.4985852586105466, 16.386499106884003, 59.04874786734581, 40.563598573207855, 41.97198539972305, 39.22020725905895, 48.808392360806465, 55.79800710082054, 63.55230040848255, 0.37149356736335903, 1.7302115075290203, 58.660674691200256, 70.693838596344, 74.53776553273201, 70.57529255747795, 67.11080566048622, 58.17333564162254, 56.027104407548904, 59.030246660113335, 61.271750181913376, 65.47475785017014, 60.757785961031914, 63.402691036462784, 65.19262298941612, 66.05241045355797, 64.88082692027092, 59.18466277420521, 54.44577746093273, 55.41348293423653, 60.539841055870056, 60.69423817098141, 62.2110939770937, 60.22735342383385, 60.78845791518688, 62.21772462129593, 59.87041957676411, 55.691069439053535, 48.7914414703846, 45.48748075962067, 44.386562034487724, 43.796495497226715, 42.6914843916893, 42.58726738393307, 42.42110230028629, 46.03435881435871, 44.585986733436584, 49.32522922754288, 49.632423743605614, 49.24206309020519, 50.885284915566444, 54.419669061899185, 54.16125252842903, 55.35993620753288, 57.87511624395847, 51.065501645207405, 47.42289550602436, 52.302874848246574, 50.05967281758785, 52.52378359436989, 56.45259417593479, 51.320536360144615, 47.69369937479496, 43.68040032684803, 40.57454198598862, 39.91683527827263, 41.556622087955475, 39.83410231769085, 42.260439321398735, 43.94384779036045, 45.42598485946655, 49.83362674713135, 50.12865051627159, 49.77744676172733, 49.87391598522663, 48.43741066753864, 48.63251119852066, 49.00272913277149, 48.37778426706791, 48.93222011625767, 42.959522008895874, 48.16985182464123, 48.37858982384205, 45.30555412173271, 47.7206589281559, 46.12328924238682, 45.40755204856396, 51.270808428525925, 50.30817188322544, 48.99346522986889, 49.79108422994614, 47.411872297525406, 43.15835393965244, 45.51868088543415, 40.91543309390545, 40.30650056898594, 38.36910232901573, 40.31025856733322, 42.97656029462814, 47.88782715797424, 48.325875252485275, 52.13134445250034, 50.172773748636246, 47.51634009182453, 47.0784629881382, 45.43755903840065, 49.93358798325062, 54.713207110762596, 53.813901767134666, 55.24561174213886, 52.948999777436256, 51.323108822107315, 51.15624077618122, 50.22466756403446, 51.284974068403244, 49.84994687139988, 45.07746376097202, 42.60234497487545, 44.3861136585474, 43.17112885415554, 42.44064085185528, 46.945929899811745, 46.562579870224, 46.19107000529766, 50.98260149359703, 57.631606310606, 58.64729940891266, 60.29273271560669, 62.893548756837845, 58.151513412594795, 60.71211241185665, 62.142344266176224, 58.43719728291035, 55.22387310862541, 52.293656542897224, 52.85585157573223, 54.61535856127739, 55.104259327054024, 55.90698905289173, 57.89949953556061, 58.474644273519516, 59.34296227991581, 54.53226462006569, 53.28221909701824, 53.63650068640709, 65.17268165946007, 68.0131508409977, 75.29896348714828, 66.96460470557213, 77.56732776761055, 3.863292122259736, 4.371706265956163, 73.39224860072136, 47.221612706780434, 48.64057436585426, 30.570125319063663, 52.9814538359642, 49.075388833880424, 61.60629943013191, 2.5992320012301207, 0.22677307832054794, 0.0650546615361236, 0.021789481761516072, 0.01765108449035324, 0.02668901641300181, 0.04769124090671539, 0.03745748457731679, 0.007241702624014579, 0.07453826983692124, 0.05946317622147035, 0.060140768182463944, 0.04189609542663675, 0.04075640892551746, 0.027404010761529207, 0.024545456435589585, 0.01885580539237708, 0.15166719909757376, 0.49514700716827065, 20.486150421202183, 66.33106470108032, 42.59707845747471, 53.29804144799709, 49.25840221345425, 56.21401257812977, 61.506820768117905, 70.50554350018501, 0.6774306180886924, 2.1420866064727306, 65.8902807533741, 75.46536415815353, 78.71508657932281, 74.94575724005699, 71.28075510263443, 61.84076584875584, 60.14063447713852, 63.207324519753456, 63.92963156104088, 68.57395514845848, 64.36227634549141, 68.19382354617119, 67.6634556055069, 67.45196655392647, 67.25911930203438, 62.08321563899517, 57.72895708680153, 57.28131450712681, 61.77990831434727, 64.87187460064888, 66.79346188902855, 64.5073601603508, 64.00033056735992, 63.379394486546516, 61.16853252053261, 59.43832576274872, 50.0895544141531, 48.06211240589619, 46.97803057730198, 47.748807817697525, 47.03658163547516, 46.66903115808964, 44.9557600915432, 48.439861536026, 47.32549533247948, 51.409409791231155, 52.76899203658104, 52.00964838266373, 55.53414925932884, 55.9724785387516, 58.30359645187855, 56.31371162831783, 60.05962282419205, 51.974720656871796, 47.54105016589165, 53.51687170565128, 51.51739999651909, 55.40868379175663, 56.712074652314186, 54.978265687823296, 49.40996468067169, 46.63237452507019, 43.13373506069183, 43.3794716745615, 42.629395723342896, 44.21098105609417, 43.90535205602646, 45.38701415061951, 47.27838546037674, 54.08232696354389, 54.2458625882864, 54.28455211222172, 54.27203178405762, 53.25346224009991, 52.35534243285656, 51.42105996608734, 48.7802928686142, 49.256000742316246, 43.45684692263603, 47.53305919468403, 49.9304835498333, 47.49352231621742, 50.27380272746086, 49.81733702123165, 47.89940133690834, 52.16871164739132, 52.078257501125336, 52.91436083614826, 51.380193158984184, 51.38081632554531, 46.31825678050518, 45.01456193625927, 42.94641271233559, 43.10579515993595, 42.230975702404976, 43.35963673889637, 44.78984199464321, 51.454874351620674, 49.18557912111282, 54.39688168466091, 52.98166282474995, 50.582159981131554, 47.74952597916126, 46.51923179626465, 48.79126287996769, 55.34710429608822, 55.41855946183205, 57.11652494966984, 56.02523110806942, 53.91756020486355, 53.01739610731602, 53.07874761521816, 53.508914932608604, 51.506737768650055, 46.94621868431568, 46.60259172320366, 46.92753128707409, 44.55069802701473, 44.342982172966, 48.52585092186928, 50.06152331829071, 49.73569080233574, 53.666716665029526, 61.05412445962429, 62.403109073638916, 64.22307461500168, 67.60442197322845, 62.384011298418045, 62.4444280564785, 66.29243597388268, 61.333645060658455, 60.198110193014145, 57.38291345536709, 56.24938488006592, 57.32510335743427, 60.85566110908985, 58.667335733771324, 61.865263134241104, 62.05942131578922, 64.19516891241074, 57.965707182884216, 59.31042842566967, 57.059634402394295, 68.84830802679062, 70.84869548678398, 80.43880328536034, 70.38795500993729, 85.88569700717926, 4.9920187052339315, 6.384048359468579, 83.06618750095367, 53.774300292134285, 54.9609462171793, 30.646626614034176, 49.488122686743736, 53.98730546236038, 72.72278532385826, 2.992287422530353, 0.18741361767752096, 0.08992661285446957, 0.07907970153610222, 0.05430274883110542, 0.016378748368879315, 0.008177404270099942, 0.059093582967761904, 0.030576144745282363, 0.18822738260496408, 0.2404584744363092, 0.17880215164041147, 0.19828210322884843, 0.18628917488968, 0.12634097918635234, 0.19136099726893008, 0.25058616301976144, 0.3580477216746658, 0.7981947285588831, 27.235760539770126, 78.08438882231712, 51.242287158966064, 53.411491960287094, 55.04717119038105, 67.16540113091469, 67.48016104102135, 76.708824634552, 0.5915922741405666, 2.9231520323082805, 69.36098411679268, 77.81569764018059, 81.34230360388756, 77.76038020849228, 72.96965047717094, 64.43597719073296, 61.50003433227539, 64.3141633272171, 66.91545814275742, 71.06693297624588, 67.53406494855881, 69.45075809955597, 69.0007634460926, 68.57012495398521, 70.11028870940208, 63.52599821984768, 59.06018145382404, 61.80665507912636, 64.76085975766182, 65.3248330950737, 68.72615978121758, 66.48507043719292, 66.61592781543732, 67.80127421021461, 62.50022426247597, 62.36298702657223, 52.36013017594814, 50.15633203089237, 48.595641776919365, 50.18943965435028, 48.909827917814255, 49.711212515830994, 47.5639895349741, 52.56022743880749, 49.21486794948578, 53.19140776991844, 55.221475437283516, 54.73549671471119, 56.38596475124359, 59.8619232326746, 60.30239179730415, 59.629128724336624, 63.890569657087326, 55.815425366163254, 50.25121293962002, 56.84585027396679, 54.11562457680702, 58.76994162797928, 61.11251212656498, 56.094341799616814, 49.30902689695358, 48.819480165839195, 44.916793182492256, 45.733004584908485, 44.822809025645256, 45.51741175353527, 48.172971457242966, 49.26708474755287, 51.74552455544472, 60.66968768835068, 60.87346315383911, 58.79863388836384, 58.612128496170044, 57.483532056212425, 56.06758363544941, 54.775246381759644, 52.959270626306534, 51.678651943802834, 42.86406733095646, 50.395890176296234, 53.28778199851513, 50.08994959294796, 53.63687306642532, 53.97233806550503, 52.95363172888756, 59.36382316052914, 56.96215823292732, 57.770656049251556, 57.65101946890354, 56.11256942152977, 50.17623536288738, 47.76154473423958, 45.950805097818375, 47.852439656853676, 44.18081447482109, 48.01874153316021, 49.00515720248222, 52.369204089045525, 51.06501907110214, 56.72725863754749, 55.79740293323994, 55.203054025769234, 51.83361142873764, 49.52265523374081, 52.75791183114052, 58.67618925869465, 59.074134305119514, 61.04656666517258, 58.06341513991356, 56.49020455777645, 55.40692828595638, 56.225389167666435, 57.78648979961872, 54.73498374223709, 50.41882574558258, 49.42302078008652, 51.005955040454865, 46.90032094717026, 46.00134238600731, 51.877837255597115, 53.08570124208927, 51.505065858364105, 58.15524861216545, 63.194040432572365, 64.3387784063816, 67.68628478050232, 70.5421431362629, 63.93597722053528, 64.06923606991768, 68.04798737168312, 63.679696172475815, 60.728888511657715, 58.66363853216171, 59.3755379319191, 60.3743751347065, 63.3393370360136, 62.29705676436424, 64.45328146219254, 65.1852285861969, 68.0204464495182, 60.150038972496986, 60.8956653624773, 59.997055381536484, 73.1414544582367, 73.41332226991653, 82.92654499411583, 73.08351516723633, 95.85103467106819, 7.636451181024313, 5.783262122422457, 92.53323510289192, 59.87142652273178, 65.65036922693253, 39.78017181158066, 68.82263660430908, 62.227676287293434, 86.34714424610138, 4.644864583387971, 0.36048036301508546, 0.1839517362532206, 0.18738090380793437, 0.12952926044818014, 0.05267108150292188, 0.15648203057935461, 0.11588333174586296, 0.15111993940081447], [0.05843111597641837, 0.03722806075529661, 0.02903081702243071, 0.03659841895569116, 0.06444211510824971, 0.024178898565878626, 0.009863063769444125, 0.05814680662297178, 0.1524919774965383, 0.14123983128229156, 11.108496822416782, 64.90560159087181, 41.42162673175335, 27.615590058267117, 35.92778652906418, 42.7516845613718, 45.14059357345104, 75.30777141451836, 3.7093372084200382, 0.4122329328674823, 64.86884996294975, 73.97938549518585, 73.55570822954178, 69.76187020540237, 64.6671111881733, 57.18904785811901, 59.97106097638607, 59.898492470383644, 62.5495570152998, 67.13003262877464, 65.12470543384552, 69.21834737062454, 66.53193712234497, 66.5521976351738, 60.88764779269695, 57.44246765971184, 55.46600751578808, 61.08831502497196, 58.84992353618145, 63.75886872410774, 60.85164852440357, 62.49335043132305, 61.40686333179474, 60.565128698945045, 60.822006314992905, 55.158018842339516, 48.408832401037216, 46.34800158441067, 44.89045299589634, 45.1785459369421, 44.465221613645554, 40.94110831618309, 43.42366710305214, 41.970055103302, 43.58094446361065, 46.04813687503338, 49.20746974647045, 46.75968289375305, 52.51998759806156, 50.9087448567152, 53.0795531719923, 55.98673157393932, 58.54007676243782, 53.13611313700676, 45.84933154284954, 45.5830380320549, 50.598149523139, 57.39903599023819, 53.89371648430824, 53.63666407763958, 48.378776013851166, 41.37254476547241, 40.904504880309105, 44.17497418820858, 41.81077904999256, 41.35943166911602, 42.562268525362015, 44.48177732527256, 45.9429395198822, 45.91865882277489, 47.39001207053661, 46.04200780391693, 48.85499686002731, 47.936483547091484, 49.37752962112427, 51.25011093914509, 48.20316843688488, 45.47880582511425, 40.36105804145336, 46.05834312736988, 46.89654015004635, 48.904409408569336, 49.86581102013588, 48.66009011864662, 44.94373753666878, 46.688288524746895, 46.781938299536705, 47.78329856693745, 47.220225781202316, 45.95256820321083, 45.76882146298885, 42.488050907850266, 38.52918013930321, 40.157605558633804, 38.87293629348278, 38.76983642578125, 43.68923485279083, 48.50881263613701, 50.22190511226654, 57.27480545639992, 50.017476081848145, 45.01548528671265, 39.88889537751675, 47.42879278957844, 54.57901731133461, 57.12220944464207, 54.58382785320282, 53.86575758457184, 53.767285868525505, 51.137720569968224, 51.88593462109566, 47.98218749463558, 48.075084909796715, 44.97499845921993, 43.76345247030258, 41.5562155097723, 42.042426019907, 41.94164402782917, 42.48024992644787, 44.925426319241524, 46.67888022959232, 48.06370832026005, 52.3311073333025, 59.25140239298344, 57.5524565577507, 60.77435687184334, 60.65620221197605, 62.41097465157509, 60.758336931467056, 60.46447969973087, 60.68804070353508, 63.293864876031876, 62.06258274614811, 59.92863245308399, 54.7650933265686, 56.45544782280922, 54.94077309966087, 60.65365254878998, 58.5408291220665, 58.43726187944412, 56.16113841533661, 58.61263006925583, 56.232540383934975, 65.7469068467617, 65.35236641764641, 77.88298442959785, 67.46403470635414, 82.16222360730171, 2.1892962232232094, 14.275966957211494, 75.15475362539291, 45.83091013133526, 47.05380231142044, 54.102918058633804, 64.74053844809532, 47.768718749284744, 64.16903391480446, 1.7963505210354924, 0.07249739341204986, 0.10175477698794566, 0.020883981815131847, 0.006607487339351792, 0.03505349755869247, 0.0920711450453382, 0.04406022773764562, 0.029618061780638527, 0.05953770269115921, 0.00595469563450024, 0.016451079936814494, 0.014059475652175024, 0.026356981397839263, 0.06107189263275359, 0.027103541142423637, 0.06012043704686221, 0.14192202826961875, 0.266418993123807, 13.401801064610481, 76.16631254553795, 39.08667102456093, 34.59984518587589, 46.9148475676775, 46.7607544362545, 54.233878031373024, 82.90488615632057, 4.606270529329777, 0.402732344227843, 67.80146420001984, 76.31335705518723, 77.39762127399445, 73.671495616436, 67.9503858089447, 61.10832095146179, 64.35932770371437, 62.759476751089096, 67.08886563777924, 68.80388081073761, 68.71514037251472, 70.45898079872131, 68.70708480477333, 67.66310602426529, 65.91884762048721, 59.81942631304264, 59.956074580550194, 63.79650950431824, 62.77754858136177, 63.654169142246246, 63.78834754228592, 63.408797308802605, 63.794723600149155, 63.70064824819565, 61.85243122279644, 58.69008511304855, 49.18208710849285, 48.08296948671341, 48.5106061398983, 45.92101849615574, 46.46632343530655, 44.36315909028053, 45.07404014468193, 45.82916222512722, 45.74467375874519, 48.143591433763504, 51.9398233294487, 50.40821671485901, 55.08354663848877, 53.59683841466904, 55.83361878991127, 59.01128567755222, 59.95023809373379, 56.36227682232857, 48.1134894490242, 47.00313203036785, 52.81378783285618, 59.834720492362976, 55.26317819952965, 54.71102982759476, 49.40160892903805, 42.75000885128975, 43.48292872309685, 45.55025339126587, 43.74988719820976, 43.168423399329185, 43.51195156574249, 46.77921384572983, 49.05767038464546, 49.894499480724335, 50.01822844147682, 50.17657354474068, 52.96614445745945, 50.866772308945656, 53.49382974207401, 52.04179085791111, 50.35596191883087, 47.2582845389843, 41.07649885118008, 45.66616617143154, 48.396878242492676, 50.4073541611433, 52.892531007528305, 52.43404760956764, 48.31234037876129, 50.81469230353832, 51.31424389779568, 50.82176372408867, 49.74272042512894, 49.12032522261143, 47.44139291346073, 44.19091813266277, 40.45720428228378, 41.787235513329506, 41.002855002880096, 39.950189888477325, 47.45655409991741, 49.988544434309006, 52.165732607245445, 58.48765857517719, 53.75839054584503, 48.919870778918266, 43.01952078938484, 50.83854362368584, 55.98594881594181, 58.65997552871704, 57.025926411151886, 57.221327126026154, 57.62095548212528, 54.35831755399704, 53.82862597703934, 51.93882018327713, 50.23961216211319, 49.49560068547726, 45.77804356813431, 44.33026805520058, 44.424970373511314, 46.10268294811249, 46.419601142406464, 47.999974340200424, 49.002877324819565, 51.838665157556534, 54.83753643929958, 65.15915438532829, 62.122091352939606, 63.60140137374401, 64.3070501089096, 65.90497076511383, 64.65479224920273, 65.60328975319862, 61.65729269385338, 67.05922722816467, 66.11841291189194, 64.28428173065186, 57.06002578139305, 59.771605879068375, 57.907809689641, 64.82037976384163, 60.20247995853424, 62.895642444491386, 58.647432401776314, 61.482262685894966, 58.311602622270584, 69.09476280212402, 68.93872037529945, 81.98063135147095, 70.38062140345573, 89.6214209496975, 2.030955394729972, 17.720320634543896, 83.45103085041046, 50.45110121369362, 54.74038325250149, 56.433158218860626, 63.014211282134056, 47.395818158984184, 74.96372267603874, 1.5158544410951436, 0.044199024196132086, 0.07392532264930196, 0.06441201359848492, 0.08108433888992295, 0.06370599367073737, 0.0654057864448987, 0.04862780901021324, 0.0143935181768029, 0.1423825605888851, 0.20552981353830546, 0.18258501193486154, 0.14139942271867767, 0.142862492648419, 0.19597139675170183, 0.08642599132144824, 0.14482391474302858, 0.27161856880411506, 0.4897895915200934, 18.77328023314476, 86.90829053521156, 55.918954610824585, 38.21426443755627, 47.20024645328522, 58.761791065335274, 58.317632898688316, 90.50852134823799, 4.547664849087596, 0.9291565418243408, 74.59106147289276, 76.84627085924149, 81.20766162872314, 75.06876423954964, 69.90378499031067, 63.37527930736542, 66.61178603768349, 65.2086353302002, 69.94886577129364, 71.88160926103592, 70.02999901771545, 74.14983674883842, 71.48479655385017, 71.687713265419, 67.8998789191246, 61.94487266242504, 61.396071910858154, 67.13409841060638, 61.58084839582443, 67.11470425128937, 66.1081762611866, 65.9485924243927, 65.78186497092247, 64.17007505893707, 65.2329920232296, 61.532735377550125, 52.44240716099739, 50.66170111298561, 47.671485766768456, 50.14171801507473, 51.44456930458546, 46.96791931986809, 47.82650604844093, 47.40708075463772, 48.20268206298351, 50.433861538767815, 54.906859919428825, 51.2245687097311, 58.833797201514244, 56.66412502527237, 56.99390932917595, 64.6200393140316, 62.583443596959114, 57.50152789056301, 48.812705129384995, 48.199159651994705, 57.2490618377924, 62.354479283094406, 57.4872862547636, 58.01236867904663, 54.418939501047134, 45.3378713876009, 45.9079509973526, 49.09952513873577, 47.3097337782383, 45.56471161544323, 47.51582331955433, 50.56938886642456, 52.19902262091637, 53.65035094320774, 57.26018384099007, 55.15198476612568, 57.86795362830162, 55.592814311385155, 57.252352461218834, 56.30757495760918, 55.02166695892811, 49.063522070646286, 42.64947384595871, 47.93938659131527, 50.00443898141384, 53.38074021041393, 56.358355432748795, 57.775413393974304, 55.468241795897484, 56.80180303752422, 56.33646100759506, 56.09637849032879, 54.91610862314701, 53.490915298461914, 51.49382226169109, 47.24416829645634, 43.22755202651024, 44.223034009337425, 45.01569427549839, 42.73758351802826, 49.929366409778595, 51.650252267718315, 56.39203302562237, 60.773908495903015, 55.2148599922657, 52.18938633799553, 47.112691551446915, 52.94602833688259, 56.07540741562843, 62.55880571901798, 62.370377629995346, 58.766567409038544, 61.41011215746403, 56.65281303226948, 58.139129877090454, 53.38044762611389, 53.82759243249893, 50.7269474118948, 49.43660505115986, 47.59929344058037, 46.66799381375313, 49.52726438641548, 47.2311881929636, 51.49126499891281, 51.78750850260258, 55.6592271476984, 56.70358210802078, 66.6178885102272, 63.29352289438248, 66.0234560072422, 65.76631620526314, 67.55066245794296, 67.48473599553108, 66.24909549951553, 65.8443184196949, 70.99908381700516, 67.53497689962387, 67.194993942976, 60.54157756268978, 63.48479703068733, 61.11395604908466, 67.96891361474991, 65.58546870946884, 66.43872052431107, 63.150384575128555, 64.79307442903519, 62.368945106863976, 73.1881995499134, 72.42018476128578, 85.89266583323479, 74.21879544854164, 97.22166672348976, 3.0188342230394483, 18.42763178050518, 91.3915103673935, 60.29508098959923, 63.521225675940514, 78.08391004800797, 84.72978383302689, 61.027005314826965, 88.22715416550636, 3.3522786805406213, 0.14145021530566737, 0.18805634725140408, 0.13058652402833104, 0.27065514237619936, 0.1701500455965288, 0.2752087824046612, 0.16750647104345262, 0.09530881623504683], [0.07745704016997479, 0.052888816499034874, 0.06825185599154793, 0.076087955822004, 0.022709987933922093, 0.05361321942473296, 0.0315319474611897, 0.04195514069579076, 0.20737344195367768, 0.45546303503215313, 6.142798829823732, 59.754069820046425, 50.115294232964516, 41.62762127816677, 19.88404043018818, 42.875177934765816, 41.133514791727066, 77.99248695373535, 13.632920812815428, 0.07759176965919323, 49.712268859148026, 78.13231945037842, 70.34250184893608, 70.14303535223007, 63.74840788543224, 61.83598570525646, 60.2701011300087, 61.8638876080513, 64.31019634008408, 63.994972854852676, 65.61719700694084, 64.09667059779167, 62.780193239450455, 61.1823295801878, 56.000015661120415, 54.102978855371475, 60.45880280435085, 63.32887999713421, 64.13155272603035, 63.52555364370346, 62.04983443021774, 61.842855736613274, 60.18461711704731, 63.51875200867653, 60.448334366083145, 52.549728602170944, 46.63929395377636, 44.93644952774048, 45.22366851568222, 43.56181249022484, 42.129152566194534, 44.24488663673401, 42.73113526403904, 41.42465516924858, 45.41029930114746, 44.99955654144287, 47.72605083882809, 47.798782736063, 50.044789016246796, 52.716243267059326, 54.56647798418999, 54.69306439161301, 54.76252846419811, 57.13709704577923, 52.84615449607372, 50.071550980210304, 50.11000111699104, 55.9721365571022, 52.04779073596001, 52.49968148767948, 46.06624290347099, 43.86764667928219, 41.84669852256775, 40.18371395766735, 40.43147586286068, 42.72779904305935, 42.390559539198875, 42.169339209795, 44.41957086324692, 46.11656740307808, 47.359442710876465, 46.20009832084179, 47.60945409536362, 49.93465952575207, 52.08640806376934, 50.04210256040096, 50.22440157830715, 44.084732830524445, 44.15323555469513, 41.96193113923073, 43.3871054649353, 49.8285236209631, 49.35335531830788, 49.76559899747372, 47.94238083064556, 43.41770142316818, 45.06370089948177, 49.62819077074528, 48.97604696452618, 45.70944584906101, 42.09471121430397, 38.83875332772732, 41.14943973720074, 41.14141836762428, 37.19466894865036, 40.038975924253464, 45.96139132976532, 50.44558010995388, 54.12509746849537, 55.89754655957222, 54.21235218644142, 43.90455789864063, 39.10522922873497, 51.072611063718796, 56.24949127435684, 55.940195471048355, 53.987495452165604, 52.49833256006241, 51.471741646528244, 47.901909202337265, 47.40953542292118, 46.05411775410175, 42.577634900808334, 45.537455677986145, 40.73412202298641, 40.26369966566563, 42.67149366438389, 40.97394235432148, 44.28009934723377, 44.4010316580534, 45.22183321416378, 46.9523211568594, 51.63830950856209, 59.12532135844231, 60.68541504442692, 59.748917296528816, 60.60087338089943, 60.823438838124275, 62.44119442999363, 64.55714508891106, 62.50098802149296, 63.44431400299072, 62.88043566048145, 65.76967522501945, 61.76148310303688, 59.66342568397522, 54.57402437925339, 55.734056532382965, 55.24203613400459, 57.83403664827347, 54.156677573919296, 60.642279759049416, 57.70186834037304, 65.1941429078579, 67.57175892591476, 75.08906275033951, 71.6147343814373, 75.42868852615356, 0.7374830706976354, 20.723299495875835, 72.12390705943108, 40.55285654962063, 45.31650893390179, 89.11047756671906, 32.719858065247536, 49.504465609788895, 60.15286982059479, 0.8782785187941045, 0.0889063008071389, 0.12844265234889463, 0.0850699761940632, 0.02446578502713237, 0.0608812460268382, 0.003971021169490996, 0.05599500880634878, 0.04134928843996022, 0.027409126014390495, 0.06248663761653006, 0.035102022884530015, 0.026004253450082615, 0.01151748349002446, 0.13676560105523095, 0.06413330745999701, 0.11090988846262917, 0.302998858387582, 0.3907282539876178, 6.990160485729575, 69.50083181262016, 50.143952295184135, 39.43853974342346, 34.99119758605957, 52.43548773229122, 46.30849130451679, 85.40355607867241, 16.318919733166695, 0.13847935362719, 51.42177052795887, 81.53554603457451, 75.23249745368958, 74.36583995819092, 66.5888200700283, 64.6274109184742, 63.45558039844036, 64.27378669381142, 66.36615961790085, 65.8315435051918, 69.553003013134, 66.24327421188354, 64.47052493691444, 64.75032672286034, 58.561013638973236, 57.7106686681509, 63.82500797510147, 65.57254180312157, 66.85898557305336, 65.69525241851807, 64.69328418374062, 61.3687589764595, 61.75997458398342, 62.84136235713959, 61.6226689517498, 54.40694734454155, 48.684944584965706, 48.19644279778004, 47.00515352189541, 47.99601875245571, 45.30510954558849, 45.994392558932304, 44.22227784991264, 45.659292340278625, 46.28281608223915, 47.46981918811798, 50.47712601721287, 50.522940158843994, 53.8344244658947, 54.371879026293755, 56.8551217764616, 57.881659492850304, 55.59496119618416, 58.49545195698738, 56.27249523997307, 52.1382524818182, 53.56918729841709, 57.40628980100155, 56.38584315776825, 54.618295803666115, 48.753021731972694, 47.88948006927967, 43.222068920731544, 43.50538931787014, 43.4158281236887, 44.70860615372658, 44.039541855454445, 45.130695104599, 47.87996917963028, 49.15370263159275, 50.941016525030136, 49.99721936881542, 51.75043389201164, 52.61065453290939, 54.149739146232605, 52.58175328373909, 52.79806427657604, 46.61162383854389, 44.680605456233025, 41.74283489584923, 41.60923406481743, 51.11264191567898, 53.4662926197052, 55.24040602147579, 49.69699747860432, 51.22775673866272, 49.132233783602715, 49.545180425047874, 53.29668492078781, 47.46426768600941, 45.31675212085247, 41.88695356249809, 43.15035916864872, 42.12592653930187, 39.43191669881344, 40.444763749837875, 47.49349571764469, 51.26832716166973, 56.960205137729645, 56.460820734500885, 56.427025347948074, 46.750483587384224, 43.4551902115345, 53.938687071204185, 59.33707259595394, 57.811986431479454, 56.22554495930672, 56.577143892645836, 53.58163543045521, 51.89749360084534, 49.36226584017277, 48.09706673026085, 44.85460191965103, 46.87014676630497, 42.85365588963032, 43.28861095011234, 44.991318583488464, 44.42028522491455, 44.51632507145405, 47.64323428273201, 47.79220148921013, 50.056389793753624, 53.63904654979706, 60.84048852324486, 60.926477909088135, 62.89421372115612, 61.015256345272064, 61.49525798857212, 64.21172842383385, 68.15677553415298, 66.76719009876251, 64.13531452417374, 66.35559618473053, 68.86125773191452, 66.62488013505936, 63.75108674168587, 59.90137651562691, 58.84047344326973, 56.60175897181034, 62.229013815522194, 58.160526528954506, 61.81198999285698, 61.84669733047485, 70.86335510015488, 70.9216819703579, 79.51255738735199, 76.5791603922844, 77.43270859122276, 0.774683371419087, 25.075620152056217, 80.71520045399666, 47.78760753571987, 54.988316148519516, 104.41047057509422, 43.101603984832764, 50.832152366638184, 67.98500195145607, 0.8698378060944378, 0.031942024870659225, 0.13428417092654854, 0.04949953196046408, 0.07564727595308796, 0.013297373479872476, 0.018748218099062797, 0.02707247855141759, 0.008206282163882861, 0.16822461766423658, 0.2761345967883244, 0.24933038977906108, 0.22530280955834314, 0.14559785602614284, 0.3162928903475404, 0.3920124069554731, 0.15048032684717327, 0.5060043605044484, 0.8451882319059223, 11.952928360551596, 81.27474322915077, 66.17671698331833, 56.27652682363987, 30.721408501267433, 61.41975224018097, 52.76306815445423, 95.49380823969841, 16.48353450000286, 0.1871820676024072, 56.56761400401592, 82.74230808019638, 76.8957670032978, 75.74415519833565, 70.38879856467247, 65.78336969017982, 65.95512807369232, 66.44084081053734, 69.07428190112114, 66.32960557937622, 70.86324870586395, 67.83817023038864, 65.77782958745956, 65.74984028935432, 61.717325672507286, 60.42735569179058, 65.67018896341324, 69.0769037604332, 71.56904563307762, 68.71010184288025, 66.55290439724922, 65.36292225122452, 64.05937179923058, 66.43252685666084, 64.80416223406792, 58.36402840912342, 51.91916763782501, 49.97150234878063, 49.836978167295456, 48.47719453275204, 46.31533473730087, 49.2963507771492, 47.34690338373184, 49.041312262415886, 50.415314733982086, 50.06234787404537, 53.54950815439224, 52.7753034979105, 58.027662858366966, 57.84217581152916, 62.29595482349396, 61.25473089516163, 60.106527507305145, 59.707685708999634, 57.27975279092789, 52.958921045064926, 55.70401534438133, 62.44902960956097, 57.534939497709274, 58.763987347483635, 50.38238950073719, 51.648758947849274, 44.409596398472786, 45.5228416621685, 46.437163800001144, 47.80207335948944, 46.96337476372719, 48.2104754447937, 51.518779322505, 52.5266220420599, 56.5272905677557, 57.10430480539799, 57.32380002737045, 59.67074789106846, 58.38056892156601, 56.54743328690529, 55.99481754004955, 47.115290611982346, 44.43682573735714, 44.05746929347515, 43.80671314895153, 53.39169882237911, 56.37624107301235, 58.06811548769474, 55.97715228796005, 56.13475263118744, 54.292892664670944, 56.30953945219517, 56.30942165851593, 52.35642917454243, 47.87195160984993, 43.37689161300659, 46.81147791445255, 45.71618668735027, 41.053232699632645, 43.44285987317562, 50.95282629132271, 55.11583350598812, 58.93607251346111, 58.275219574570656, 60.29900997877121, 49.96210165321827, 45.99879652261734, 53.56090374290943, 61.88070170581341, 61.412597224116325, 59.05573949217796, 58.482566848397255, 56.259560734033585, 55.39818495512009, 52.54435949027538, 50.91102473437786, 47.45729885995388, 50.760894790291786, 46.155272126197815, 45.52450217306614, 47.716068774461746, 46.42732232809067, 47.43203781545162, 50.21349996328354, 50.62474049627781, 52.4432697147131, 56.84345260262489, 64.59901124238968, 65.38105487823486, 64.75546404719353, 64.72955703735352, 65.76478108763695, 67.74359330534935, 71.85525387525558, 68.8858500123024, 67.72561267018318, 70.06636306643486, 73.84527549147606, 68.26082155108452, 68.29729959368706, 63.4855417907238, 62.708821669220924, 59.792512357234955, 66.53219550848007, 61.01533994078636, 65.50433546304703, 62.28913798928261, 74.88006636500359, 73.09359222650528, 82.99725160002708, 79.41827684640884, 85.60660198330879, 1.5507670864462852, 26.21815614402294, 86.542848944664, 53.30706976354122, 62.416545152664185, 110.10024726390839, 45.79828888177872, 61.77646189928055, 83.02499771118164, 1.4372879569418728, 0.15754995140014216, 0.2260830590967089, 0.18296436814125627, 0.20673273102147505, 0.22045131598133594, 0.13633533351821825, 0.17222807393409312, 0.31904367555398494], [0.1313376220059581, 0.09417903740541078, 0.031242636032402515, 0.029830260355083738, 0.08136177595588379, 0.023854719183873385, 0.04020964275696315, 0.01748943359416444, 0.11380125870346092, 0.105366720672464, 2.2698471508920193, 58.050248846411705, 51.16020016372204, 36.921167224645615, 15.649933330714703, 34.97362732887268, 45.497649013996124, 70.02106949687004, 33.87889847159386, 1.0845431475900114, 26.621134020388126, 84.43663716316223, 70.68637579679489, 75.46899676322937, 65.00225320458412, 65.11564671993256, 62.0592275261879, 62.26169966161251, 61.545453295111656, 61.15236058831215, 59.481293857097626, 58.58719803392887, 57.03846573829651, 56.96480669081211, 56.24044395983219, 59.58518788218498, 61.33859999477863, 62.4751266092062, 62.11712881922722, 62.14668743312359, 61.935802549123764, 60.008644759655, 59.63951736688614, 57.95641668140888, 50.8076398819685, 46.5706430375576, 45.55635206401348, 46.8795208632946, 44.56588961184025, 44.0591412037611, 43.586651757359505, 43.89225795865059, 42.18702346086502, 42.592085525393486, 43.67620535194874, 44.99617092311382, 43.85268688201904, 46.387599259614944, 45.80748438835144, 50.264820009469986, 53.79584513604641, 53.08690957725048, 57.76473216712475, 53.65384675562382, 55.52670545876026, 57.6611003279686, 55.39311222732067, 58.173628225922585, 55.77998846769333, 53.0680625885725, 47.27135203778744, 43.4957530349493, 42.12795563042164, 43.550371304154396, 38.25912103056908, 40.03150172531605, 40.6040246039629, 43.43366056680679, 45.64788915216923, 44.47270341217518, 44.47578884661198, 44.86201532185078, 45.374999195337296, 49.64455649256706, 49.45499986410141, 51.230693981051445, 44.03012216091156, 44.36042323708534, 45.62470279633999, 42.20395915210247, 43.52548263967037, 45.04931107163429, 50.29237613081932, 49.48170863091946, 42.88150079548359, 42.71040737628937, 43.89568157494068, 47.99306631088257, 47.760400995612144, 45.50677232444286, 43.84327858686447, 41.119869723916054, 39.204027727246284, 41.93664729595184, 41.15800067782402, 38.43136578798294, 43.03853116929531, 48.642907440662384, 56.89618997275829, 55.08205711841583, 53.10046724975109, 43.862429559230804, 44.867699816823006, 54.83173035085201, 54.181638434529305, 54.83528696000576, 53.77658776938915, 48.88352192938328, 47.07290768623352, 47.34859049320221, 45.06720431149006, 42.512893974781036, 43.84932026267052, 41.190059557557106, 40.51632530987263, 39.87552769482136, 41.39771841466427, 43.686749786138535, 43.98824080824852, 45.2349729090929, 46.3309670984745, 47.01622232794762, 48.230253383517265, 58.58501695096493, 61.66965343058109, 58.40085983276367, 61.33133478462696, 55.817260667681694, 55.93785099685192, 59.30084154009819, 60.53151190280914, 62.45896987617016, 65.6728944182396, 62.635272815823555, 64.95340302586555, 65.58170691132545, 61.82817332446575, 56.29715971648693, 54.67705585062504, 55.68428300321102, 56.920083090662956, 57.709821313619614, 61.51587188243866, 63.416617289185524, 70.89189156889915, 72.31524959206581, 81.22489750385284, 59.79025147855282, 0.07479575055185705, 34.912405014038086, 67.44910910725594, 48.086746484041214, 31.444530598819256, 37.27072946727276, 43.73766325414181, 58.207921385765076, 51.482616662979126, 0.5741981731262058, 0.05131586789502762, 0.019451159969321452, 0.06615194914047606, 0.0559354032156989, 0.044953506367164664, 0.11587075976422057, 0.029431994225888047, 0.027811373765871394, 0.06499294453533366, 0.05595141505182255, 0.04277685031411238, 0.05559139550314285, 0.015416662445204565, 0.029328896926017478, 0.007060582875055843, 0.07684964424697682, 0.09872094407910481, 0.21534816012717783, 2.8610417526215315, 66.12937152385712, 56.65261924266815, 37.75821290910244, 22.103835716843605, 45.71812458336353, 52.72511199116707, 80.03851756453514, 40.374668911099434, 0.9582129295449704, 27.95276116579771, 89.490996748209, 71.48092836141586, 76.47395923733711, 67.57192611694336, 69.73758190870285, 64.36137199401855, 65.69653674960136, 64.09808412194252, 63.72619807720184, 60.684168711304665, 61.09122946858406, 58.49917195737362, 59.37637008726597, 58.29028196632862, 63.54138359427452, 64.1994246840477, 66.10373049974442, 64.03557747602463, 64.6970383822918, 62.31165178120136, 62.841282561421394, 61.797090992331505, 59.10109385848045, 53.56043256819248, 50.195865109562874, 49.73615437746048, 47.76595249772072, 47.394704818725586, 47.02541023492813, 45.72697050869465, 47.13280767202377, 43.15680742263794, 45.273202657699585, 45.27465797960758, 48.59472222626209, 45.998363345861435, 47.288869097828865, 48.54363776743412, 52.93338641524315, 56.60491660237312, 57.987255826592445, 58.594550639390945, 55.09036347270012, 58.11359904706478, 60.366836339235306, 59.596328884363174, 59.36650961637497, 56.09714984893799, 56.99571043252945, 49.118478521704674, 46.155348122119904, 44.78999398648739, 45.85026629269123, 41.17842838168144, 43.9161928743124, 44.42672587931156, 46.59330502152443, 48.14042240381241, 47.48994670808315, 48.459981456398964, 49.156518280506134, 50.68751312792301, 53.60355265438557, 53.9825215190649, 53.72400999069214, 45.9528835862875, 45.17254985868931, 44.2063757032156, 42.64331437647343, 42.233460769057274, 46.18430256843567, 53.09090316295624, 54.59832027554512, 46.33303798735142, 46.45331673324108, 46.47505536675453, 51.64284646511078, 51.795909851789474, 46.603385880589485, 45.2883106470108, 43.352189138531685, 42.47010447084904, 44.66079331934452, 44.220434948801994, 41.50643818080425, 44.62897762656212, 48.118174597620964, 57.778810411691666, 55.88568739593029, 57.857204005122185, 48.36940571665764, 48.916412964463234, 56.80104307830334, 57.771693393588066, 56.47444300353527, 57.4025622010231, 55.27386702597141, 49.95320253074169, 48.27723406255245, 46.75294205546379, 45.129517167806625, 48.18845182657242, 43.86436365544796, 42.61883608996868, 42.608797028660774, 44.49697270989418, 46.275444477796555, 47.605825290083885, 46.77248440682888, 48.7856961786747, 49.34469558298588, 50.93634657561779, 61.81527681648731, 64.91981282830238, 61.84796646237373, 64.6312715113163, 58.68960253894329, 57.826212868094444, 60.41453517973423, 62.823343724012375, 64.97761532664299, 68.23277145624161, 65.19430249929428, 69.18348044157028, 67.464429885149, 65.4407724738121, 59.243624210357666, 58.46136778593063, 58.034050315618515, 60.3387064486742, 61.037690341472626, 65.09576618671417, 66.15321144461632, 75.62769144773483, 75.60527265071869, 84.43587720394135, 57.11905561387539, 0.04304156325815711, 41.69117286801338, 72.7066969871521, 54.17868219316006, 41.30924016237259, 45.17003059387207, 49.18061278760433, 65.78732147812843, 55.7954004406929, 0.47081136144697666, 0.035052755411015823, 0.03055698620300973, 0.06326293150777929, 0.03798184159677476, 0.08241910632932559, 0.01772083338437369, 0.0864917530270759, 0.033136800993815996, 0.23205592297017574, 0.12781179713783786, 0.14868884172756225, 0.11191978817805648, 0.13104572048177943, 0.11207593604922295, 0.11289386442513205, 0.17051874456228688, 0.3441862732870504, 0.3509738965658471, 4.241427406668663, 78.16033154726028, 63.968138694763184, 48.8193129748106, 23.088619373738766, 51.683644875884056, 57.34641641378403, 84.78758633136749, 40.20207077264786, 0.9961094241589308, 36.969797015190125, 89.81470137834549, 75.13954684138298, 79.78602111339569, 71.71636372804642, 71.84931859374046, 65.87752863764763, 68.83180931210518, 65.59866160154343, 66.61346554756165, 63.691118359565735, 63.519819751381874, 61.07721582055092, 61.9477529078722, 62.35765591263771, 63.87926146388054, 67.04196095466614, 66.95124462246895, 64.44180607795715, 66.08790814876556, 66.39172464609146, 64.88900408148766, 65.28329372406006, 61.75960220396519, 57.85195268690586, 52.20382936298847, 52.45094150304794, 52.285570576786995, 49.003443494439125, 51.18147902190685, 49.04109947383404, 50.9420994669199, 46.999404430389404, 48.03412310779095, 47.52680853009224, 49.46199908852577, 50.36614917218685, 50.0026036798954, 51.197251975536346, 55.464768782258034, 60.669881477952, 59.35858704149723, 64.47262242436409, 58.93928714096546, 60.9254215657711, 64.32157292962074, 61.525188982486725, 59.47958014905453, 58.56413707137108, 59.43649806082249, 53.60767923295498, 49.78890314698219, 48.137367367744446, 49.44025665521622, 43.61532121896744, 45.271196365356445, 46.80458888411522, 48.303160071372986, 53.530995547771454, 51.30930796265602, 51.170083433389664, 55.187482461333275, 55.950519517064095, 60.12978985905647, 57.522609159350395, 57.425623163580894, 49.10651296377182, 46.76041625440121, 44.75794270634651, 43.384612798690796, 42.633271515369415, 47.04702727496624, 55.362827852368355, 58.1966245919466, 49.95281495153904, 52.45324797928333, 53.248864486813545, 57.30687193572521, 55.49065679311752, 49.92106765508652, 49.28187735378742, 46.06113217771053, 44.775113984942436, 46.62794776260853, 47.16021940112114, 43.5758413374424, 47.60899432003498, 51.23481296002865, 60.47803357243538, 59.919725731015205, 60.53204387426376, 48.480219170451164, 52.44728609919548, 58.75414967536926, 61.96166776120663, 59.60888721048832, 59.12233851850033, 58.39232549071312, 51.96526296436787, 51.469161584973335, 47.894765585660934, 49.3190773576498, 49.52222965657711, 47.644043639302254, 45.5720604211092, 45.201325714588165, 48.081567361950874, 51.05620734393597, 50.38137495517731, 50.12192867696285, 50.595580860972404, 50.670467242598534, 54.4011564552784, 63.900661915540695, 67.40462869405746, 63.88767421245575, 67.13097497820854, 60.76303727924824, 60.160431414842606, 65.29463991522789, 65.89732557535172, 68.27758625149727, 70.57489737868309, 69.5885007083416, 70.49359694123268, 71.66401773691177, 66.97989508509636, 61.857313960790634, 60.26975154876709, 61.15882784128189, 62.945024594664574, 63.734329640865326, 69.34561774134636, 71.04848116636276, 78.29355999827385, 79.48791190981865, 86.76950678229332, 67.78681978583336, 0.3852617129450664, 40.74927940964699, 82.73818910121918, 62.1064779907465, 45.822968557477, 43.4345269203186, 54.71563898026943, 73.40839013457298, 67.67859399318695, 1.222524312324822, 0.15939533128403127, 0.13831217744154856, 0.21601217449642718, 0.1430566533235833, 0.172725802694913, 0.15073406713781878, 0.18428163573844358, 0.13987186015583575], [0.01478168089306564, 0.005466855991471675, 0.020831181718676817, 0.04049644943734165, 0.041998753004008904, 0.024611270091554616, 0.07486896342015825, 0.06975851967581548, 0.03989139499026351, 0.16854543326189741, 0.5595950817223638, 49.681631103158, 48.62557657063007, 50.60633048415184, 45.99260285496712, 35.93975968658924, 42.732537388801575, 59.233839735388756, 57.33393408358097, 0.41600253840442747, 3.813634724356234, 80.21586924791336, 69.13535222411156, 71.95167750120163, 66.43648624420166, 68.80599349737167, 62.429863438010216, 64.922054708004, 60.90951181948185, 58.98745335638523, 54.14321109652519, 54.62363451719284, 54.39891457557678, 54.557882845401764, 60.0835919380188, 61.57440774142742, 60.94939827919006, 62.081323340535164, 59.61036533117294, 62.32378453016281, 60.15320420265198, 55.57297557592392, 49.172777608036995, 49.02146972715855, 46.602888107299805, 49.4576521217823, 45.68302966654301, 45.891079902648926, 44.95949149131775, 45.24180494248867, 42.67138347029686, 42.81407721340656, 41.03712536394596, 43.3313662558794, 41.12809248268604, 46.04516543447971, 43.256137892603874, 43.14912423491478, 46.84398137032986, 46.58152565360069, 51.3374188542366, 57.60131813585758, 56.5555040538311, 55.41165143251419, 57.23042003810406, 56.74813471734524, 52.374075427651405, 54.11862261593342, 53.983551263809204, 56.33046492934227, 55.243719443678856, 47.13834397494793, 42.438330575823784, 46.336165219545364, 42.376135513186455, 41.77546754479408, 40.39077624678612, 43.198616579174995, 41.519946455955505, 44.51029859483242, 45.934135392308235, 46.44204653799534, 43.68735395371914, 49.8726886510849, 52.60231398046017, 50.547046065330505, 43.93796570599079, 44.29646886885166, 42.957945093512535, 41.53900243341923, 43.514113649725914, 45.29207244515419, 46.526500806212425, 51.4714490622282, 43.15361559391022, 39.71992984414101, 43.78591686487198, 49.22907158732414, 44.97979000210762, 45.77411837875843, 40.002471283078194, 41.318454667925835, 41.765823662281036, 39.06036123633385, 42.16804727911949, 42.21788540482521, 47.93233036994934, 48.89216646552086, 52.634494453668594, 54.79370579123497, 56.21165670454502, 42.841975316405296, 47.935206815600395, 55.75240194797516, 53.252911269664764, 51.00260742008686, 51.9682952016592, 49.57345470786095, 46.29984676837921, 44.62191380560398, 43.17115545272827, 42.263441160321236, 47.38721162080765, 43.205494210124016, 40.79015001654625, 41.65903799235821, 41.2566813826561, 43.095250725746155, 43.49564664065838, 43.625120893120766, 44.838107004761696, 45.6073909252882, 46.948399767279625, 52.74225667119026, 58.17946471273899, 59.70848746597767, 61.70248746871948, 59.29603859782219, 60.1428497582674, 56.98021486401558, 54.34323616325855, 57.512326911091805, 62.51538164913654, 68.37842524051666, 67.01733827590942, 64.1261114180088, 64.20710027217865, 61.9340356439352, 56.0418476164341, 55.45900069177151, 57.29400962591171, 59.57931339740753, 64.22311261296272, 64.44806814193726, 73.74529525637627, 71.98755517601967, 86.96390435099602, 33.57462219893932, 0.03974749255576171, 50.88671363890171, 64.86196473240852, 49.54308293759823, 33.344601541757584, 25.218944661319256, 38.74155834317207, 59.71377678215504, 37.99036905169487, 0.012050561672367621, 0.07269700887263753, 0.059134575494681485, 0.039955345855560154, 0.02072014714940451, 0.0693575743935071, 0.03466661597485654, 0.027235591478529386, 0.05363143172871787, 0.02403781072644051, 0.023008218122413382, 0.020901889838569332, 0.0874216492229607, 0.05155073908099439, 0.02369676232774509, 0.0409799326735083, 0.0744852730713319, 0.050561523021315224, 0.12052944337483495, 0.5681939609348774, 58.78661893308163, 53.92691530287266, 43.428029268980026, 44.05134782195091, 48.36701564490795, 48.97969476878643, 64.7746454179287, 67.41209909319878, 0.8010357886087149, 3.303195764310658, 81.47677838802338, 73.06018441915512, 76.85354366898537, 69.95709612965584, 72.48377814888954, 64.51874434947968, 67.3909342288971, 65.22890344262123, 63.36426369845867, 56.788290962576866, 57.265963330864906, 55.85728012025356, 57.19243347644806, 61.778285801410675, 65.72587117552757, 63.03968891501427, 63.765594363212585, 62.525758892297745, 63.87837991118431, 62.97483779489994, 58.74332405626774, 51.18815526366234, 50.70408023893833, 49.19148400425911, 49.90447774529457, 48.007478937506676, 48.947643488645554, 46.81872792541981, 48.506673350930214, 46.50362603366375, 46.96708716452122, 41.886345595121384, 45.023252069950104, 42.9350171238184, 48.09584319591522, 46.30053833127022, 45.741253942251205, 49.748936891555786, 51.469598561525345, 52.589098289608955, 58.39283846318722, 60.138726979494095, 58.942642360925674, 59.04652878642082, 60.03264047205448, 56.577375680208206, 54.13272365927696, 55.51763914525509, 56.89392149448395, 57.09309920668602, 49.48030650615692, 43.86196218430996, 46.79143778979778, 42.698141634464264, 44.55591894686222, 43.03864136338234, 45.2322256565094, 43.95259492099285, 46.40738099813461, 48.67480292916298, 50.44777639210224, 48.038880452513695, 51.75613358616829, 57.73562952876091, 51.40409767627716, 44.17759604752064, 43.943748995661736, 42.53069221973419, 40.161808133125305, 42.70987540483475, 45.54552644491196, 46.68939806520939, 53.07150900363922, 47.55103223025799, 44.73930850625038, 46.54438644647598, 51.1701138317585, 46.81642144918442, 51.25336356461048, 41.64592869579792, 42.89773732423782, 42.12968833744526, 42.5492238253355, 42.83875308930874, 43.51196676492691, 48.088300600647926, 51.763315200805664, 54.22223165631294, 57.24386751651764, 57.803721874952316, 47.49099165201187, 50.00873655080795, 56.575411185622215, 56.7649070173502, 53.79217453300953, 55.500357672572136, 54.48144994676113, 49.71666902303696, 46.36793151497841, 44.3256551027298, 44.92859534919262, 47.78127707540989, 45.67958705127239, 42.03362949192524, 44.2367322742939, 43.962048813700676, 47.1208269149065, 46.79420404136181, 47.29510456323624, 48.3153460174799, 47.87616178393364, 48.69031749665737, 55.57728834450245, 62.11772158741951, 61.72430969774723, 65.81086501479149, 62.483714148402214, 63.097757399082184, 60.628858879208565, 57.6466953009367, 60.47515332698822, 61.53601460158825, 68.60708937048912, 69.80898767709732, 68.4822128713131, 68.66585701704025, 65.02584233880043, 59.454786479473114, 59.136048182845116, 61.129014641046524, 62.60760270059109, 68.75703692436218, 68.38888987898827, 78.70734259486198, 74.72523987293243, 89.27666544914246, 32.81147874891758, 0.033410816758987494, 59.12494897842407, 67.59042352437973, 59.50014464557171, 38.43798503279686, 32.2555685788393, 39.492933824658394, 62.717173621058464, 43.670653849840164, 0.08775280293775722, 0.08012072692508809, 0.06891698358231224, 0.06218909205927048, 0.06405928565072827, 0.024373539781663567, 0.039520851787528954, 0.058544571802485734, 0.06094917480368167, 0.11668490318697877, 0.13458779838401824, 0.11599513629334979, 0.16120419750222936, 0.19337509700562805, 0.12056295134243555, 0.16273444663966075, 0.14043504634173587, 0.2063301159068942, 0.42264933174010366, 1.7284912685863674, 71.02014228701591, 62.40660108625889, 65.16007393598557, 61.38939566910267, 53.932349011301994, 55.71249268949032, 72.48229622840881, 68.13712298870087, 0.8535198785830289, 7.158921780064702, 88.78983557224274, 73.20316314697266, 78.08596953749657, 71.92459255456924, 74.77320849895477, 63.660514801740646, 70.44775620102882, 66.37019500136375, 64.72979262471199, 58.801692724227905, 60.94605065882206, 58.50368991494179, 61.56814947724342, 63.70358929038048, 68.49151477217674, 64.57496613264084, 67.39377647638321, 65.19278258085251, 67.70586133003235, 66.53188392519951, 60.71787290275097, 53.40691700577736, 54.778745993971825, 50.734448209404945, 54.205622747540474, 50.905146449804306, 50.77458545565605, 48.823819532990456, 50.45625373721123, 48.265017718076706, 49.45540264248848, 45.79769231379032, 49.49125751852989, 45.532147362828255, 49.86317776143551, 48.83352421224117, 48.35507668554783, 52.08729341626167, 53.178119882941246, 55.39527431130409, 61.79963305592537, 63.55686396360397, 61.557080671191216, 63.322420343756676, 62.04892247915268, 60.65759293735027, 59.50355686247349, 59.05912131071091, 58.87495279312134, 60.25531232357025, 51.18822745978832, 49.18433278799057, 49.29491065442562, 45.25552220642567, 47.72942125797272, 45.85166081786156, 48.455866277217865, 45.31161479651928, 51.21088944375515, 52.278282567858696, 55.936395674943924, 54.84232038259506, 56.18389159440994, 58.56146961450577, 56.17675557732582, 45.251532420516014, 44.7426675260067, 42.920213118195534, 40.64943976700306, 43.606289103627205, 46.85666508972645, 48.38824890553951, 59.84832376241684, 51.769558265805244, 48.718618378043175, 51.49795264005661, 55.27330845594406, 50.20968496799469, 54.2161899805069, 45.41821427643299, 46.296050772070885, 45.4266232252121, 45.0566940754652, 45.9023766964674, 46.575328186154366, 52.840367406606674, 54.06382955610752, 58.025542572140694, 59.77485850453377, 61.571470499038696, 48.30018103122711, 54.149568155407906, 58.26639644801617, 59.04589042067528, 55.919330790638924, 57.921853736042976, 57.29810580611229, 53.33255119621754, 50.529107227921486, 49.45245020091534, 46.04993037879467, 51.284639686346054, 50.47079175710678, 46.58095568418503, 48.15983176231384, 46.15621827542782, 48.88889864087105, 49.57712531089783, 50.43795011937618, 51.310178115963936, 51.00324958562851, 51.91034071147442, 57.46004931628704, 63.92161399126053, 63.74257519841194, 68.29084753990173, 65.02422362565994, 65.85317954421043, 62.77605526149273, 59.17465791106224, 63.5681227594614, 66.68044075369835, 73.95886659622192, 73.23729291558266, 72.6343260705471, 70.21339997649193, 66.9090136885643, 62.6069263368845, 63.65527108311653, 64.30562138557434, 66.24411776661873, 72.177354991436, 71.54437735676765, 82.25937679409981, 77.70823940634727, 92.71275267004967, 42.084998935461044, 0.12498893454903737, 61.09730154275894, 76.6827580332756, 64.80249792337418, 45.62407582998276, 33.072118163108826, 51.51727840304375, 75.6563039124012, 55.28508402407169, 0.19441126874880865, 0.19226289965445176, 0.210844540852122, 0.13311398215591908, 0.20165969152003527, 0.14953543926822022, 0.07327601022552699, 0.07672751642530784, 0.17774257255950943], [0.017495910688012373, 0.03460519583313726, 0.01555396996991476, 0.021051770272606518, 0.0659559850464575, 0.012792476500180783, 0.05546204287384171, 0.033103463720181026, 0.0480188137589721, 0.0956509388925042, 0.21349948510760441, 40.77099144458771, 58.474522680044174, 50.725974664092064, 38.75218257308006, 37.36198917031288, 43.85723903775215, 55.33238388597965, 66.92499563097954, 6.837302288040519, 0.15952197136357427, 58.91105465590954, 73.96388232707977, 70.60160994529724, 69.11757677793503, 69.0154230594635, 67.6595950126648, 68.88566002249718, 63.77904564142227, 63.122239485383034, 55.135584846138954, 52.93991066515446, 54.23695586621761, 59.821565598249435, 60.51327668130398, 62.4645783752203, 62.56334267556667, 61.9407194852829, 60.50880812108517, 61.43926799297333, 58.62240694463253, 55.0166018307209, 51.59648135304451, 49.68974746763706, 49.040248319506645, 46.015755012631416, 45.83466812968254, 45.15486180782318, 45.02723045647144, 46.7068999260664, 44.62991237640381, 43.75719040632248, 41.28251239657402, 41.983236595988274, 43.890753239393234, 45.46451859176159, 42.67472729086876, 43.971213921904564, 44.37181122601032, 46.909546852111816, 51.33771523833275, 53.1206289678812, 57.92808160185814, 55.59223294258118, 57.16078117489815, 55.30956611037254, 55.91202758252621, 55.63962779939175, 51.06176644563675, 52.74337761104107, 56.47010363638401, 52.11385019123554, 42.479527965188026, 45.334728956222534, 42.00481563806534, 37.54779540002346, 42.16261737048626, 40.0189395993948, 44.81055848300457, 41.67797237634659, 42.99049414694309, 44.111247807741165, 43.35545316338539, 48.09974178671837, 51.27227135002613, 46.91100597381592, 44.39701907336712, 43.905580043792725, 43.5392265021801, 41.20370462536812, 43.6421287804842, 43.03717844188213, 45.33103175461292, 50.009397715330124, 44.7384687513113, 41.282155215740204, 43.500240594148636, 44.80993151664734, 46.47814840078354, 42.71191209554672, 39.937893748283386, 39.610590711236, 39.40916731953621, 39.24170270562172, 41.07442796230316, 43.09699483215809, 47.49327152967453, 51.23769700527191, 53.585165441036224, 57.21806310117245, 55.1573196798563, 42.50407084822655, 51.51024118065834, 55.15476241707802, 55.632286593317986, 51.209882497787476, 51.806636676192284, 50.01491501927376, 44.66983303427696, 40.935203433036804, 43.2571030408144, 39.87799756228924, 45.23040175437927, 41.082551926374435, 40.88699162006378, 41.89502812922001, 43.096117079257965, 44.67093877494335, 45.194980055093765, 43.574116230010986, 46.46383076906204, 45.572717785835266, 47.13548272848129, 52.99510270357132, 57.75982663035393, 57.867528051137924, 60.07946915924549, 60.3601410984993, 62.72086702287197, 62.21082419157028, 60.00587470829487, 55.41332334280014, 57.57849656045437, 56.90268002450466, 65.56941837072372, 64.69127029180527, 65.11629268527031, 66.1472837626934, 61.10371179878712, 53.0377022176981, 59.60035286843777, 59.999962225556374, 67.44961827993393, 64.7322928905487, 73.69214370846748, 68.52730125188828, 88.22776213288307, 13.908082097768784, 0.24812214367557317, 62.18574933707714, 57.03181229531765, 36.95484481751919, 37.348108515143394, 39.93698179721832, 39.48295176029205, 61.110912412405014, 35.41982978582382, 0.05323816767486278, 0.025902466040861327, 0.04868002281000372, 0.11209760676138103, 0.055508961449959315, 0.04478559916606173, 0.019581965352699626, 0.0405783714086283, 0.041030647334991954, 0.05104217867483385, 0.01717294657282764, 0.011473473205114715, 0.02797318978991825, 0.10963809967506677, 0.045165775445639156, 0.032062668396974914, 0.05768815193732735, 0.05030587541114073, 0.1620533035020344, 0.1899981321184896, 53.16109299659729, 63.504856154322624, 52.9895094037056, 41.601813063025475, 44.69611242413521, 54.43257316946983, 61.05865001678467, 76.10206559300423, 7.915587052702904, 0.1723027933621779, 58.04703041911125, 74.06855151057243, 76.57648533582687, 71.5869502723217, 73.53784918785095, 71.7888942360878, 72.58644104003906, 67.66385078430176, 68.27273771166801, 58.31417888402939, 55.279304534196854, 56.16137020289898, 62.852533757686615, 64.19629365205765, 66.18554010987282, 65.22603079676628, 62.93795317411423, 64.4029189646244, 64.18403550982475, 61.771932542324066, 57.772362157702446, 53.672290965914726, 52.94004745781422, 50.54801121354103, 48.857348933815956, 49.08452734351158, 47.76158273220062, 49.140011966228485, 49.87952068448067, 49.6782910823822, 46.45598419010639, 43.68633180856705, 45.43521076440811, 44.872054383158684, 47.986914440989494, 45.61576567590237, 47.83434882760048, 46.41800902783871, 49.35431286692619, 52.41704732179642, 57.72837571799755, 60.621551871299744, 58.20505253970623, 58.349976763129234, 57.40390732884407, 60.007037445902824, 58.756912127137184, 54.78003792464733, 55.35810470581055, 58.0992928147316, 54.26478557288647, 45.691252425312996, 46.86204940080643, 46.71506188809872, 38.983852341771126, 44.37864325940609, 42.23270460963249, 46.47414721548557, 44.042619690299034, 46.50513455271721, 48.3853230625391, 47.654052302241325, 50.63410319387913, 55.33227749168873, 47.41070196032524, 44.325035735964775, 42.528328746557236, 42.39207185804844, 41.929078102111816, 43.21960665285587, 42.35109865665436, 46.361350268125534, 50.421265214681625, 48.57865668833256, 44.16935048997402, 47.24623158574104, 48.63039471209049, 48.00896465778351, 44.57590587437153, 41.001635268330574, 41.59961678087711, 42.35403969883919, 41.33349806070328, 43.488123044371605, 47.64941655099392, 50.07122039794922, 53.323553279042244, 56.16328150033951, 57.900027707219124, 55.74131794273853, 49.613508358597755, 54.85413394868374, 59.45530325174332, 55.77724501490593, 53.44402961432934, 56.05234645307064, 52.69230455160141, 48.14176753163338, 44.910196736454964, 46.43768057227135, 43.39903302490711, 46.19881398975849, 44.09024253487587, 43.755985870957375, 45.99935129284859, 46.10805585980415, 47.415010929107666, 49.026417061686516, 47.131394147872925, 47.66378737986088, 46.61518804728985, 51.18003509938717, 56.350740641355515, 61.54440455138683, 63.66609290242195, 63.62658642232418, 62.801038920879364, 64.50098410248756, 65.20737379789352, 63.308372497558594, 59.753264263272285, 60.4961472004652, 58.56066405773163, 66.3571161031723, 69.98557180166245, 67.97316938638687, 69.81684565544128, 63.941669315099716, 57.205481976270676, 61.97001971304417, 62.97715567052364, 70.79275488853455, 69.23250541090965, 78.51010277867317, 73.07698711752892, 88.52983832359314, 13.73844400048256, 0.4493432556046173, 70.9186801314354, 58.436106741428375, 51.75336353480816, 41.62991635501385, 39.42364454269409, 40.02294458448887, 65.28205499053001, 44.78435508906841, 0.011043241847801255, 0.06943891377886757, 0.009886100961011834, 0.00476995613098552, 0.05050545005360618, 0.031511352863162756, 0.021535756313824095, 0.02466944704792695, 0.037626434495905414, 0.1400940294843167, 0.13182571768993512, 0.2944643975934014, 0.09106124532991089, 0.2140508414595388, 0.15622349601471797, 0.12265387078514323, 0.18028240971034393, 0.09394987704581581, 0.28234257304575294, 0.46221488679293543, 62.84765861928463, 74.96433064341545, 65.79622820019722, 53.029270470142365, 53.94472874701023, 59.155985713005066, 69.53459680080414, 80.09182870388031, 7.652893848717213, 0.17080442688893527, 68.6809878051281, 77.37277820706367, 79.87704902887344, 72.40168735384941, 75.66571220755577, 72.45699718594551, 74.87908601760864, 69.01853889226913, 71.34772270917892, 59.3752833455801, 57.921070978045464, 58.62687170505524, 65.40528997778893, 67.39210456609726, 69.5726403594017, 66.4761409163475, 66.8642520904541, 66.23186722397804, 66.67132884263992, 63.73819403350353, 59.42193724215031, 54.19643484055996, 54.468306452035904, 52.45641700923443, 50.88343061506748, 52.12910257279873, 49.27358619868755, 50.62269240617752, 53.401118516922, 52.27887533605099, 49.98172380030155, 46.66516296565533, 47.73947171866894, 48.40353548526764, 51.05566017329693, 45.90483896434307, 50.54162755608559, 48.905822932720184, 53.9394736289978, 55.51704257726669, 61.383749172091484, 64.44875970482826, 63.53292524814606, 63.547543063759804, 61.940563693642616, 62.50740587711334, 60.04820443689823, 56.89977318048477, 60.62912866473198, 59.90701541304588, 55.78400865197182, 46.55266620218754, 50.31597286462784, 49.18447718024254, 40.86387746036053, 47.47681841254234, 44.22328479588032, 49.87471394240856, 48.225203454494476, 49.819920882582664, 53.55973340570927, 53.303779140114784, 55.89883469045162, 59.26257759332657, 50.09312242269516, 45.85579499602318, 42.997888550162315, 43.46655160188675, 42.01116889715195, 43.31453315913677, 43.131857961416245, 47.79947429895401, 57.09344118833542, 53.50620947778225, 47.64389544725418, 53.60413782298565, 51.84979096055031, 51.143294870853424, 47.97636620700359, 43.42462845146656, 44.79690961539745, 44.616248309612274, 43.348674327135086, 46.03821560740471, 47.57521793246269, 53.56457434594631, 55.315125212073326, 58.978504836559296, 61.5275676548481, 58.98649960756302, 53.905096873641014, 57.95151114463806, 63.34572069346905, 59.36724677681923, 56.02528050541878, 59.16062906384468, 56.26622557640076, 51.245015412569046, 46.97711102664471, 48.25809068977833, 46.05702839791775, 50.11165402829647, 46.736515536904335, 46.983498483896255, 49.07870225608349, 47.683455124497414, 50.84526926279068, 52.30292424559593, 48.8934887945652, 50.216224417090416, 48.82775992155075, 53.163847848773, 57.14287653565407, 63.374428153038025, 64.14709389209747, 66.9866207242012, 66.13317891955376, 67.71365091204643, 68.42225968837738, 65.45602485537529, 62.585404291749, 63.93387973308563, 63.61818507313728, 69.9828739464283, 70.89893639087677, 69.99507889151573, 72.29913845658302, 66.2020692229271, 59.793754890561104, 66.09510496258736, 67.09623724222183, 73.9994940161705, 70.25337383151054, 81.41850471496582, 76.8187527358532, 94.01527717709541, 18.927612751722336, 0.5515453324187547, 75.27773782610893, 69.51007291674614, 52.638404443860054, 50.84917925298214, 52.18372464179993, 53.662909269332886, 79.62531253695488, 51.00511148571968, 0.23864466551458463, 0.17595427867490798, 0.1531420394894667, 0.18628292600624263, 0.17149961146060377, 0.2319010515930131, 0.17318752245046198, 0.2001148962881416, 0.12421060717315413], [0.09553258118103258, 0.012189851659059059, 0.06068403512472287, 0.026814179618668277, 0.031650642849854194, 0.04137635085498914, 0.025988230481743813, 0.06349384333589114, 0.06298540538409725, 0.013118085444148164, 0.14711474650539458, 39.432710856199265, 55.68117097020149, 34.29324343800545, 35.5097671598196, 39.12666007876396, 32.715184316039085, 45.92617101967335, 65.4279063642025, 15.389279667288065, 0.476526195416227, 21.530566178262234, 65.59034764766693, 68.86702582240105, 68.79928305745125, 67.98933371901512, 67.1427771449089, 71.99474439024925, 64.88636702299118, 68.60031813383102, 58.27278010547161, 54.25543427467346, 57.734622582793236, 61.17982931435108, 60.99021948873997, 63.277271166443825, 63.10010567307472, 56.71314239501953, 62.758283615112305, 58.46663810312748, 59.874481558799744, 58.72797667980194, 59.824335649609566, 59.29056689143181, 52.09190256893635, 46.163320094347, 46.165151596069336, 45.337662398815155, 48.64144831895828, 48.11298027634621, 44.896194487810135, 45.15996113419533, 42.32553742825985, 42.49872073531151, 42.091002613306046, 42.314214035868645, 48.93279388546944, 44.52133320271969, 41.79903008043766, 45.456968396902084, 49.398295506834984, 53.57375085353851, 56.006524711847305, 55.429791659116745, 54.91996921598911, 53.31697963178158, 56.435677483677864, 52.66830123960972, 56.762976720929146, 57.11543060839176, 53.2838986068964, 52.437934800982475, 46.52152307331562, 41.354092955589294, 44.91867408156395, 38.81698049604893, 40.3058660030365, 40.53423374891281, 41.579056084156036, 39.35034267604351, 42.415281012654305, 44.28262621164322, 42.63065345585346, 46.75831116735935, 47.08030968904495, 45.4266232252121, 47.01879478991032, 47.81956762075424, 45.008315071463585, 44.471061900258064, 40.144716650247574, 42.48642839491367, 42.61998362839222, 46.80179223418236, 43.88117775321007, 41.34349912405014, 40.842412412166595, 43.382074534893036, 43.66119995713234, 40.368254855275154, 42.200550734996796, 42.06267133355141, 43.980751410126686, 43.19844178855419, 48.74653548002243, 52.49178171157837, 53.182501047849655, 54.82548728585243, 56.78626947104931, 55.322515815496445, 46.09179653227329, 50.127179995179176, 55.86769536137581, 54.43258836865425, 54.17590074241161, 54.01324287056923, 56.25961013138294, 49.30651903152466, 47.01108880341053, 41.53218939900398, 41.81060045957565, 43.01010109484196, 43.198726773262024, 42.532968297600746, 41.353621780872345, 42.03903280198574, 44.41182687878609, 45.38211241364479, 45.157601460814476, 48.34777347743511, 46.82273291051388, 45.0052410364151, 49.91114258766174, 53.79893437027931, 57.351378947496414, 62.099478766322136, 61.663300171494484, 59.916655495762825, 62.109202444553375, 61.36151276528835, 62.94188216328621, 59.217812195420265, 58.565087020397186, 56.95002928376198, 56.90538167953491, 63.85088458657265, 68.4574382007122, 65.052060931921, 63.739052787423134, 55.03542222082615, 59.54544201493263, 60.416309684515, 68.8062746822834, 68.27434122562408, 77.45853200554848, 70.6882680952549, 77.20848262310028, 1.9866815954446793, 3.808388630859554, 68.94260376691818, 59.23170804977417, 38.062371388077736, 35.37618152797222, 38.977711871266365, 37.695694863796234, 64.69465970993042, 34.115177392959595, 0.026300153294869233, 0.02819349818310002, 0.010260530234518228, 0.045133573657949455, 0.023096882505342364, 0.05891233195143286, 0.06553496466949582, 0.025171953384415247, 0.0216232648017467, 0.05995316809276119, 0.020025745543534867, 0.03512040217174217, 0.07324478807277046, 0.021433130277728196, 0.03412765719986055, 0.0161109555119765, 0.02247084197733784, 0.019720064192370046, 0.05440562905278057, 0.023028178184176795, 45.19021511077881, 65.13105869293213, 35.32025992870331, 34.989632070064545, 45.07229223847389, 41.368475183844566, 51.17080919444561, 73.22743624448776, 19.296439960598946, 0.46503101068083197, 20.340658128261566, 65.21902397274971, 74.91215944290161, 71.2115228176117, 73.40835973620415, 69.28004086017609, 74.55582216382027, 68.19893807172775, 70.15716299414635, 61.23831197619438, 58.106991201639175, 58.87961894273758, 61.464399844408035, 66.50748163461685, 66.61979600787163, 65.01201868057251, 57.65985019505024, 65.6350028514862, 63.15806396305561, 64.83054801821709, 61.881693452596664, 61.50543764233589, 59.92765590548515, 53.54097381234169, 47.4819253385067, 47.68187440931797, 47.116601541638374, 48.94623376429081, 50.45977994799614, 50.396688133478165, 47.89335586130619, 45.67949965596199, 44.67866376042366, 44.84061487019062, 46.17525525391102, 51.6097616404295, 49.017232954502106, 46.078713834285736, 47.654918655753136, 53.19071240723133, 54.460022896528244, 58.97801086306572, 57.15314358472824, 57.84723713994026, 55.250665470957756, 59.36000056564808, 55.64986824989319, 58.28682415187359, 59.49776217341423, 53.76873359084129, 55.47404408454895, 49.70637917518616, 44.66436892747879, 45.53391046822071, 42.663825675845146, 42.309430092573166, 42.6629289239645, 44.10768359899521, 42.63392128050327, 45.36653324961662, 46.749609634280205, 45.833231806755066, 47.47413195669651, 48.886185586452484, 44.5519557595253, 46.66275009512901, 49.08481612801552, 43.34136351943016, 43.23256395757198, 41.42524413764477, 41.711258590221405, 42.122198939323425, 48.359883427619934, 47.59856007993221, 45.84671728312969, 44.55518938601017, 45.967904180288315, 46.78649425506592, 43.70376147329807, 44.342127218842506, 41.78803727030754, 44.76369559764862, 45.46556733548641, 51.29191629588604, 52.68876314163208, 55.02801641821861, 57.84258618950844, 58.52246470749378, 57.181144282221794, 50.71753911674023, 53.39991018176079, 57.904135286808014, 55.505012422800064, 57.33639255166054, 57.608378157019615, 57.77863182127476, 52.488741874694824, 49.32932160794735, 42.916698306798935, 45.65860457718372, 46.69404521584511, 45.91722629964352, 44.97466027736664, 44.55740846693516, 45.27566112577915, 46.308441907167435, 47.274049893021584, 48.95328998565674, 48.10391776263714, 49.15630169212818, 46.611772030591965, 53.60913835465908, 57.93345831334591, 61.07707142829895, 63.64354111254215, 64.58859980106354, 62.12806463241577, 63.69728922843933, 64.23893496394157, 66.50720044970512, 61.51117153465748, 63.023437187075615, 62.08363361656666, 60.21314598619938, 63.829332143068314, 70.06002500653267, 68.33767622709274, 69.03464242815971, 57.88400396704674, 64.47613343596458, 65.2335923910141, 72.42872670292854, 70.59336438775063, 79.51995179057121, 73.61079767346382, 77.68987879157066, 1.351412208750844, 5.903377952054143, 77.10574373602867, 66.67294755578041, 46.967075765132904, 39.60460603237152, 41.621047630906105, 43.722133487463, 71.20762422680855, 38.49674127995968, 0.05062087999249343, 0.059736869152402505, 0.11499069136334583, 0.02235390362329781, 0.028137030021753162, 0.04096803975699004, 0.03867842511681374, 0.00507382293108094, 0.04098840057849884, 0.1612422993639484, 0.07076258611050434, 0.15562839747872204, 0.19684732396854088, 0.09242776926839724, 0.1239910650474485, 0.12565616983920336, 0.16571914195083082, 0.1459892647108063, 0.13744217256316915, 0.279055304126814, 56.18419177830219, 74.25063014030457, 43.061352744698524, 44.10061217844486, 59.21035699546337, 46.589588820934296, 58.48879091441631, 79.0859466791153, 20.064665637910366, 0.6643967831041664, 30.719841085374355, 70.11935502290726, 76.87431335449219, 73.28710064291954, 74.99774605035782, 71.14345327019691, 76.87438175082207, 69.48567822575569, 73.51278573274612, 63.65057073533535, 61.34683035314083, 61.92548610270023, 64.07853037118912, 68.05013805627823, 68.40250074863434, 66.69218972325325, 58.69249418377876, 67.80439004302025, 63.74716155230999, 67.59363055229187, 62.54351153969765, 63.51027846336365, 62.66431845724583, 55.50869062542915, 50.642504543066025, 51.89807876944542, 50.17749309539795, 51.99320666491985, 53.185939863324165, 52.739034444093704, 50.97394175827503, 49.44137379527092, 48.747215643525124, 47.40255519747734, 48.731883466243744, 53.45376469194889, 51.56538002192974, 48.2378301769495, 51.46095782518387, 56.038553193211555, 57.25003078579903, 62.65088617801666, 60.16553834080696, 60.72899870574474, 58.702495247125626, 63.10979515314102, 58.64590108394623, 61.67078197002411, 61.34044669568539, 56.142523214221, 56.20922103524208, 50.49981079995632, 47.01798923313618, 48.6731082201004, 44.93558317422867, 45.58838814496994, 46.866840943694115, 46.51602476835251, 44.99188095331192, 50.58233857154846, 51.28709815442562, 50.112763568758965, 52.403539046645164, 53.28251168131828, 46.97018399834633, 48.00717115402222, 50.8525762706995, 44.68483082950115, 44.18861165642738, 41.299391090869904, 43.4275808930397, 43.390065506100655, 50.72478912770748, 51.20567612349987, 51.368592381477356, 49.014865681529045, 50.738160610198975, 51.94277197122574, 46.05453573167324, 46.838517263531685, 44.86624449491501, 48.0282524228096, 46.53335943818092, 53.95096801221371, 55.074829906225204, 57.91891269385815, 60.5818136036396, 61.27405285835266, 59.257128685712814, 53.98581974208355, 56.67966619133949, 60.59631362557411, 59.13553901016712, 58.788066655397415, 60.47465555369854, 60.96984498202801, 56.95259414613247, 54.47195045650005, 47.90546201169491, 47.365659177303314, 47.931460216641426, 49.20947603881359, 48.56593497097492, 47.846074998378754, 48.04165430366993, 50.09863592684269, 49.80582743883133, 51.58521115779877, 51.970518082380295, 51.50176763534546, 50.79457998275757, 56.09792120754719, 59.0207813680172, 62.37424202263355, 67.06194788217545, 67.74806946516037, 65.76560944318771, 67.31214925646782, 68.14237430691719, 70.4273208975792, 63.71926724910736, 66.39418691396713, 62.10808530449867, 61.99708566069603, 66.80410891771317, 74.97133746743202, 70.53997725248337, 70.47602668404579, 60.71817688643932, 68.04139852523804, 67.0294976234436, 74.8700501024723, 72.59757444262505, 85.53869962692261, 75.46984791755676, 86.73840165138245, 3.2759160781279206, 4.6686826553195715, 83.77754732966423, 71.73457995057106, 49.322706162929535, 50.88443376123905, 53.81574846804142, 48.132188245654106, 84.01454821228981, 47.57648326456547, 0.1535399939166382, 0.17098619369789958, 0.2545920090051368, 0.13058486161753535, 0.1631008746335283, 0.19008374627446756, 0.17728684935718775, 0.09548363654175773, 0.18057410343317315], [0.03463999142695684, 0.05222156636591535, 0.01236639560374897, 0.06517938687466085, 0.037971110141370445, 0.07700789981754497, 0.012816734524676576, 0.06403384482837282, 0.05566798885411117, 0.19415892369579524, 0.12504846963565797, 29.989776760339737, 58.458282351493835, 50.38764461874962, 43.19300428032875, 30.899926722049713, 34.421038180589676, 34.89048019051552, 71.09451949596405, 33.14475506544113, 0.17775659915059805, 1.5052512288093567, 38.57788972556591, 64.90161180496216, 66.8745419383049, 70.41671186685562, 68.65622073411942, 68.517976552248, 67.48966053128242, 66.03394344449043, 58.485378697514534, 56.353871673345566, 61.113538071513176, 61.62042327225208, 60.931144058704376, 62.65399441123009, 58.96203272044659, 50.85975408554077, 64.94011893868446, 62.623216062784195, 61.344159096479416, 61.67324423789978, 62.1326319873333, 58.757983669638634, 54.83654089272022, 46.2249755859375, 46.3355078548193, 45.42335920035839, 49.84277665615082, 50.719397217035294, 51.380793526768684, 46.761898174881935, 44.88625042140484, 43.18045735359192, 42.86252461373806, 40.51889397203922, 47.25574627518654, 47.27387510240078, 44.969040378928185, 48.004914075136185, 48.1287532299757, 53.468739688396454, 54.47011135518551, 52.60180480778217, 56.79817423224449, 54.28340457379818, 55.991773903369904, 56.59782998263836, 57.57625088095665, 55.6304094940424, 55.81097200512886, 56.11456051468849, 51.40583038330078, 39.20201763510704, 44.68949697911739, 42.737252935767174, 40.31563147902489, 41.788573041558266, 39.04366873204708, 43.470852971076965, 42.16212339699268, 40.55975317955017, 44.08466063439846, 47.33587257564068, 45.30902333557606, 42.486181408166885, 46.073302924633026, 49.175684452056885, 49.280156046152115, 42.37272709608078, 40.92991791665554, 43.92784304916859, 44.10946950316429, 42.8381223231554, 44.6529695391655, 40.4838864505291, 41.97264276444912, 42.06558957695961, 41.43917039036751, 43.182513043284416, 39.61448550224304, 42.38292194902897, 46.01328894495964, 52.46838636696339, 53.25392201542854, 57.95450158417225, 53.78864452242851, 55.28605677187443, 55.77271185815334, 46.708013266325, 48.894769325852394, 54.61066581308842, 51.46567717194557, 52.50413864850998, 54.4011602550745, 54.182033613324165, 53.04095484316349, 52.90449656546116, 46.45560801029205, 48.07576507329941, 46.05599105358124, 48.82868327200413, 43.52265179157257, 43.47078837454319, 42.4407472461462, 44.01448979973793, 44.573056027293205, 46.97336062788963, 48.913593515753746, 49.4302935898304, 44.25147548317909, 45.800097584724426, 49.10097286105156, 55.66386289894581, 57.67989031970501, 61.85369275510311, 59.022160694003105, 62.31810003519058, 61.70985907316208, 63.50413419306278, 61.773372665047646, 62.15040743350983, 61.1150997877121, 58.81145820021629, 58.4459026157856, 61.01929172873497, 66.96936205029488, 67.05060169100761, 64.83995631337166, 55.63801288604736, 58.59403766691685, 61.1470864713192, 69.54899042844772, 72.2304305434227, 70.42822524905205, 76.65427476167679, 53.37738499045372, 0.31740513222757727, 15.57371512055397, 72.20841452479362, 55.97166158258915, 33.52230280637741, 38.07164289057255, 35.5751958489418, 31.25966101884842, 55.535368993878365, 38.32317799329758, 0.08913125318940729, 0.05796263154479675, 0.025928372560883872, 0.060080498369643465, 0.07939077273476869, 0.019429049534664955, 0.05643955897539854, 0.021672740076610353, 0.05722051726479549, 0.05590190638031345, 0.02664789957634639, 0.03307911756564863, 0.060781082065659575, 0.025589246324670967, 0.07758648556773551, 0.039528863271698356, 0.05111787402711343, 0.03800301506998949, 0.12280701295821927, 0.09865372034255415, 37.52650514245033, 70.34240305423737, 52.12886318564415, 45.87822899222374, 38.503178134560585, 40.587111711502075, 42.41308473050594, 76.71042054891586, 41.03256180882454, 0.12867239158367738, 1.1783478828147054, 39.458093494176865, 69.33808654546738, 72.38969519734383, 72.43881896138191, 71.143529266119, 72.06652253866196, 70.02359256148338, 67.5537858903408, 61.31683476269245, 61.76538549363613, 64.94310557842255, 64.05054867267609, 64.18221160769463, 65.58954209089279, 59.39410373568535, 52.55018837749958, 64.56420511007309, 63.305929228663445, 63.55530604720116, 61.947661712765694, 64.55674231052399, 60.4526661336422, 58.541589081287384, 49.4723117351532, 47.24133364856243, 48.13919886946678, 53.259085938334465, 53.99222619831562, 55.75039945542812, 50.61655193567276, 47.212747782468796, 46.201052069664, 45.072303637862206, 43.80031429231167, 49.709669798612595, 49.590990766882896, 46.36376693844795, 50.85254207253456, 53.49640220403671, 55.78229494392872, 57.116669341921806, 55.076657608151436, 58.845553770661354, 56.64842426776886, 59.08049896359444, 58.486469238996506, 60.91447815299034, 57.628855258226395, 58.47527123987675, 57.423609271645546, 52.40860417485237, 41.88100688159466, 44.52967755496502, 45.39633505046368, 44.50467869639397, 42.9844106733799, 39.65743079781532, 46.07205659151077, 46.324005872011185, 43.60176734626293, 46.57299131155014, 49.48781870305538, 46.428846046328545, 43.2869428396225, 45.55771619081497, 50.352063328027725, 47.9828866571188, 41.932497918605804, 41.0023458302021, 42.71775238215923, 43.26958157122135, 44.070225208997726, 45.18166936933994, 41.79785214364529, 45.15785224735737, 44.338954389095306, 43.17024350166321, 44.71058964729309, 42.502509132027626, 44.114762619137764, 46.822995096445084, 52.964742332696915, 56.37134313583374, 58.80227409303188, 55.87571673095226, 57.47670002281666, 56.76099702715874, 51.946936547756195, 52.660667449235916, 56.562788262963295, 52.279183119535446, 54.01534415781498, 57.06186108291149, 57.47847832739353, 56.36979661881924, 54.87290494143963, 50.51892377436161, 51.070543974637985, 49.40781779587269, 50.29442802071571, 46.295511201024055, 45.91735549271107, 45.251919999718666, 47.520519867539406, 48.67311201989651, 50.57752422988415, 51.513151824474335, 51.83599770069122, 48.514854311943054, 47.304835841059685, 52.432326301932335, 56.55726715922356, 60.155423283576965, 62.78300888836384, 61.61034621298313, 64.95813757181168, 64.62044969201088, 64.27740409970284, 65.770313590765, 65.03810048103333, 64.3107283115387, 61.00554786622524, 63.33295717835426, 60.136830881237984, 70.80637335777283, 68.55417340993881, 68.92847612500191, 59.16616916656494, 61.515138521790504, 64.73937571048737, 72.52640426158905, 75.48880130052567, 74.9665193259716, 76.9288632273674, 53.36958020925522, 0.45239392784424126, 21.178767755627632, 78.69474247097969, 64.61525917053223, 36.314145997166634, 47.12028734385967, 36.88173674046993, 41.00282460451126, 67.74911820888519, 50.53790755569935, 0.7789903215598315, 0.03313525732664857, 0.029129006870789453, 0.01367461363770417, 0.10874139232328162, 0.0160827372019412, 0.06588111718883738, 0.01817117601603968, 0.10815568937687203, 0.16166033630724996, 0.20224867475917563, 0.12243316348758526, 0.20890372077701613, 0.1196922488452401, 0.224802260636352, 0.08326458322699182, 0.19224891759222373, 0.16354451567167416, 0.2879378024954349, 0.29820948257111013, 46.98251433670521, 76.40078276395798, 64.05427247285843, 55.79061269760132, 44.40608158707619, 48.50638836622238, 49.74966645240784, 84.18658778071404, 43.119827806949615, 0.2158085143310018, 2.6843068236485124, 47.52408787608147, 69.87342461943626, 76.29339292645454, 74.63304921984673, 73.87350037693977, 75.41016831994057, 72.18639850616455, 70.97516790032387, 65.33036559820175, 63.9269033074379, 67.85084635019302, 68.38692158460617, 66.30673840641975, 67.04384565353394, 59.29888464510441, 51.87153339385986, 67.30654075741768, 65.43872818350792, 65.04118591547012, 65.52357003092766, 67.06123352050781, 64.72402453422546, 58.57649780809879, 52.5097319483757, 51.52651570737362, 50.03916911780834, 54.54754360020161, 57.041030600667, 56.98068603873253, 52.35780470073223, 50.1946035772562, 50.55308014154434, 48.778567761182785, 44.87718030810356, 51.889422833919525, 53.46440032124519, 49.38384868204594, 54.23131696879864, 55.31035266816616, 58.95480550825596, 60.027772933244705, 56.815645694732666, 62.24207751452923, 60.57072199881077, 61.97851985692978, 59.91326987743378, 64.13846835494041, 59.3707349896431, 59.07064609229565, 60.19649147987366, 54.27458144724369, 44.47414733469486, 49.59405340254307, 47.326669469475746, 46.03896036744118, 46.02403476834297, 41.380771324038506, 49.25918497145176, 49.587662145495415, 46.55842289328575, 53.80114205181599, 52.97264210879803, 47.929605916142464, 43.58658716082573, 46.26386649906635, 49.23710435628891, 48.18841002881527, 42.44809605181217, 42.87358961999416, 44.15857046842575, 44.7734534740448, 44.025771394371986, 49.27026517689228, 47.87881404161453, 49.9628122150898, 49.38598796725273, 48.08127857744694, 48.61679144203663, 44.098727479577065, 45.204677134752274, 50.117729902267456, 55.59727147221565, 56.11344337463379, 62.426227033138275, 56.83391131460667, 60.731400176882744, 60.75014837086201, 56.326497942209244, 55.16453169286251, 59.18333664536476, 56.16080403327942, 57.87822067737579, 60.3291841596365, 59.4801577180624, 57.97064691781998, 57.57776319980621, 52.991618290543556, 54.11790445446968, 52.66842283308506, 53.50789278745651, 49.27340380847454, 49.42509546875954, 48.51804994046688, 49.977627620100975, 50.25815136730671, 51.97318933904171, 54.66346018016338, 55.665196627378464, 49.965270683169365, 51.48623026907444, 54.81786489486694, 59.97033141553402, 62.64720417559147, 66.14251881837845, 66.00016325712204, 68.19741815328598, 66.61373913288116, 67.62944743037224, 69.23608481884003, 67.17888280749321, 67.27763950824738, 63.8095124065876, 66.06482818722725, 61.933154091238976, 73.85243430733681, 70.85844576358795, 71.36885717511177, 62.77623005211353, 65.41606619954109, 69.12380084395409, 76.53190612792969, 78.84271413087845, 77.20835343003273, 79.58166807889938, 64.03744697570801, 0.41633125045336783, 17.37939912825823, 87.33993977308273, 69.0543557703495, 46.44582353532314, 53.53484474122524, 48.00292298197746, 41.81735649704933, 73.58769491314888, 56.11284680664539, 0.6585215858649462, 0.1384473967482336, 0.1427932205842808, 0.08402726612985134, 0.1771251205354929, 0.0892226115684025, 0.1833665676531382, 0.11139393944176845, 0.16414501704275608], [0.06117529977927916, 0.029935016355011612, 0.038121224351925775, 0.04096381693670992, 0.035035567270824686, 0.03535449410264846, 0.0946855457732454, 0.06116472046414856, 0.147713451879099, 0.07573205148219131, 0.035450082723400556, 35.307899191975594, 59.27399978041649, 42.71241746842861, 35.152981504797935, 38.70552107691765, 32.74095073342323, 32.834851294755936, 53.108762204647064, 53.0032304674387, 2.5735339801758528, 0.21498891612282023, 22.54456266760826, 55.47109544277191, 69.10267397761345, 68.06613519787788, 70.03939971327782, 66.62177190184593, 67.2395883500576, 61.96440741419792, 58.26733119785786, 61.28992460668087, 64.88512068986893, 61.598806232213974, 64.06243443489075, 60.77722951769829, 54.233733639121056, 54.15398731827736, 58.74740123748779, 56.03213153779507, 57.406852170825005, 58.05193975567818, 61.18380770087242, 59.95667114853859, 54.924103394150734, 43.407232984900475, 46.76228955388069, 49.469591081142426, 51.28512226045132, 51.22727036476135, 49.92395170032978, 48.69522303342819, 45.77272765338421, 42.85039186477661, 42.829375192523, 43.506662249565125, 43.539720475673676, 45.66954419016838, 50.97802273929119, 46.755757704377174, 52.021017372608185, 53.85527394711971, 54.61052902042866, 56.755342930555344, 55.40201134979725, 56.62502892315388, 57.00117453932762, 54.58539716899395, 55.09268894791603, 57.82895252108574, 55.76482728123665, 56.61774091422558, 51.95015877485275, 39.76368069648743, 35.858941823244095, 43.52341555058956, 37.48859077692032, 44.36853960156441, 41.16867810487747, 42.400078028440475, 41.82974003255367, 43.29104661941528, 42.595790326595306, 43.548072427511215, 44.68209117650986, 47.67307788133621, 51.28638759255409, 54.99888338148594, 49.70277316868305, 43.81596565246582, 52.909725084900856, 53.44269588589668, 54.50465530157089, 47.93601617217064, 46.646167784929276, 43.41118857264519, 42.095984145998955, 41.819940358400345, 38.80024999380112, 41.171003580093384, 39.58549305796623, 45.006084591150284, 45.32442010939121, 50.03586329519749, 52.932200878858566, 53.27107809484005, 53.06354843080044, 59.63806204497814, 52.983771711587906, 51.43351189792156, 53.99403490126133, 54.12849448621273, 57.268201410770416, 53.47018741071224, 52.7019028365612, 56.74332797527313, 53.921280205249786, 52.25807525217533, 47.588486820459366, 48.5691723972559, 51.9011490046978, 49.25361447036266, 44.29314784705639, 45.034674257040024, 44.792391657829285, 45.656917467713356, 46.142048835754395, 50.85328683257103, 49.25448842346668, 49.7887397557497, 50.20856022834778, 45.602276399731636, 46.77238181233406, 54.33062084019184, 56.10306993126869, 61.780729070305824, 58.00079070031643, 60.43641060590744, 60.82295626401901, 64.7274899482727, 62.34301909804344, 62.25275494158268, 61.48694023489952, 61.12490326166153, 61.79706819355488, 64.91182565689087, 65.6370547413826, 67.87113726139069, 62.26690538227558, 60.40286220610142, 55.46423301100731, 62.08029739558697, 65.30575811862946, 75.7119557261467, 70.08571162819862, 84.32968810200691, 24.963761754333973, 0.7132844848092645, 36.650929525494576, 71.4519815146923, 49.73389729857445, 39.17398653924465, 49.88539136946201, 38.03645297884941, 42.14696981012821, 52.741838693618774, 47.75797672569752, 1.6050396929495037, 0.0807751007960178, 0.021983772312523797, 0.021254660459817387, 0.1801915856776759, 0.06365180204738863, 0.09002636492368765, 0.0437127170880558, 0.021597964987449814, 0.04225988137477543, 0.02385610328929033, 0.020306269943830557, 0.050021725619444624, 0.035936723797931336, 0.06099646074289922, 0.03972889062424656, 0.05383457610150799, 0.07052745146211237, 0.0696450452960562, 0.032083452242659405, 42.21534714102745, 68.23518052697182, 43.10168378055096, 34.09099169075489, 40.91517470777035, 37.991976365447044, 43.42623196542263, 59.38375689089298, 63.39660756289959, 2.997128125280142, 0.11949400635785423, 23.807954974472523, 60.2332317084074, 72.1565093100071, 71.57089233398438, 74.3206299841404, 69.63295832276344, 69.37404781579971, 64.29821938276291, 61.81019648909569, 65.43770983815193, 67.91049554944038, 62.55690962076187, 67.25669503211975, 63.14632639288902, 54.908170849084854, 55.192524790763855, 60.607473626732826, 59.066147133708, 57.75733396410942, 61.13747678697109, 63.27234283089638, 61.14752344787121, 56.67459726333618, 46.25885836780071, 48.81969295442104, 52.5150478631258, 53.246470615267754, 54.05724070966244, 53.756806030869484, 51.78611397743225, 46.64375111460686, 45.59246152639389, 46.69013522565365, 46.10091224312782, 45.89918486773968, 47.744742035865784, 54.444888308644295, 49.46844354271889, 51.907886043190956, 57.097571566700935, 58.545860052108765, 60.330263301730156, 58.06376092135906, 58.99598769843578, 59.220187067985535, 58.17043639719486, 56.753731817007065, 59.06061463057995, 56.67759910225868, 59.66523438692093, 53.820091634988785, 41.079474091529846, 38.91439966857433, 44.31590862572193, 42.82203398644924, 47.47203826904297, 43.88238228857517, 42.80099831521511, 44.622791558504105, 45.69929659366608, 45.7349044829607, 47.05430768430233, 47.32898734509945, 48.1814906001091, 52.227730080485344, 54.161556512117386, 49.243222028017044, 43.37582387030125, 52.43214011192322, 55.68677946925163, 55.29730036854744, 47.07822360098362, 48.3575389534235, 44.5820577442646, 44.95677463710308, 44.71075303852558, 41.26610867679119, 42.87480175495148, 40.92238672077656, 46.762969717383385, 47.551879584789276, 51.53022050857544, 54.137382209300995, 53.60671408474445, 54.560455307364464, 59.95288275182247, 54.54494833946228, 53.20268176496029, 56.145741641521454, 57.627491131424904, 58.50013330578804, 59.78659227490425, 55.318640023469925, 59.48337994515896, 55.805633291602135, 56.06646649539471, 50.18269881606102, 52.83266521990299, 56.91573232412338, 51.23902693390846, 46.0005634278059, 46.371974498033524, 46.10447645187378, 48.68207573890686, 50.8598642796278, 54.15331855416298, 52.9645561426878, 53.8515767455101, 53.35646331310272, 48.2961418479681, 49.29306015372276, 56.92454405128956, 56.6995657235384, 62.136496379971504, 60.89333228766918, 63.99616599082947, 65.66974818706512, 67.29054361581802, 64.65080246329308, 64.96389046311378, 64.71096843481064, 66.34444758296013, 63.71227942407131, 66.44567415118217, 66.66876018047333, 70.10917916893959, 65.57364374399185, 63.876274824142456, 59.85768266022205, 65.99853694438934, 70.19326865673065, 77.24446669220924, 73.7905964255333, 88.92106533050537, 23.53418156504631, 0.5617138836532831, 44.74228374660015, 74.47922587394714, 58.81203576922417, 42.389985769987106, 64.22622084617615, 37.58408345282078, 44.977255538105965, 62.099710553884506, 54.407380521297455, 2.6213354151695967, 0.09583406383171678, 0.1113552215974778, 0.04621628548193257, 0.020664174371631816, 0.052108889794908464, 0.06281713824137114, 0.023351669224211946, 0.03565202852769289, 0.2511514420621097, 0.10874038300244138, 0.0771677064767573, 0.1343764495686628, 0.11946250218898058, 0.17571158154169098, 0.2287798307952471, 0.17238745756912977, 0.22900069394381717, 0.165958083816804, 0.10393195625510998, 49.33293141424656, 78.84719029068947, 54.82572667300701, 47.22763158380985, 55.002686977386475, 46.15412838757038, 49.245418310165405, 66.19935616850853, 68.12130823731422, 2.7052629366517067, 0.18395932100247592, 29.46659803390503, 61.274999007582664, 75.02924636006355, 75.31171560287476, 75.91933339834213, 72.15586334466934, 73.6349567770958, 70.03708183765411, 64.47458311915398, 69.14614364504814, 70.35446360707283, 65.10427013039589, 69.7839318215847, 66.5100046992302, 57.34962344169617, 56.42210081219673, 62.29699596762657, 60.214779898524284, 59.53384883701801, 61.637001782655716, 64.65564340353012, 65.40899857878685, 58.90558674931526, 48.70524309575558, 52.79627837240696, 56.06107458472252, 55.15834182500839, 56.269808784127235, 54.00137610733509, 53.13191436231136, 50.65470188856125, 46.47094018757343, 49.240983948111534, 48.54270301759243, 47.95329004526138, 52.61582225561142, 56.826380118727684, 51.42441898584366, 55.62015384435654, 59.41004768013954, 61.56088046729565, 62.17346079647541, 61.387875750660896, 60.245866030454636, 62.76810608804226, 60.65399073064327, 59.95728671550751, 62.20948666334152, 59.187155440449715, 62.623953223228455, 55.64020536839962, 39.643652737140656, 42.98563800752163, 48.522203117609024, 46.606163531541824, 48.96286927163601, 45.58489233255386, 46.44309528172016, 47.01925456523895, 48.751281425356865, 50.240071937441826, 49.12428840994835, 48.008250296115875, 50.85605688393116, 55.935289934277534, 59.60402727127075, 51.568701043725014, 44.26807679235935, 54.647683426737785, 57.36976996064186, 59.133319929242134, 49.56408441066742, 51.84398867189884, 48.56529280543327, 48.70902769267559, 49.258793592453, 45.51707737147808, 46.79305650293827, 41.32148690521717, 48.236796632409096, 50.303365141153336, 53.398124277591705, 55.304037407040596, 55.36288104951382, 56.902125254273415, 63.40560548007488, 62.18307428061962, 56.97798818349838, 58.9689065515995, 58.607918322086334, 62.633000537753105, 60.41308745741844, 59.985583797097206, 61.900130063295364, 59.42584343254566, 61.42173573374748, 53.25506195425987, 57.364036068320274, 57.07594692707062, 53.986218720674515, 49.70934301614761, 49.73021909594536, 50.52251078188419, 53.11123587191105, 52.93206408619881, 56.53462037444115, 53.168950974941254, 55.849779322743416, 55.82959100604057, 52.458807080984116, 53.05203124880791, 61.723439544439316, 59.48086068034172, 66.98553398251534, 63.2958597689867, 66.99814930558205, 67.74365410208702, 70.75593486428261, 68.11256870627403, 67.20782205462456, 68.0548270046711, 68.17071318626404, 66.34026780724525, 70.58892622590065, 71.12730413675308, 72.76213601231575, 68.4914767742157, 66.02391958236694, 63.29761527478695, 69.55326899886131, 72.952551394701, 79.86593842506409, 77.36567258834839, 88.40806245803833, 33.4228203445673, 0.7483553560450673, 44.82906349003315, 82.51607581973076, 61.85976482927799, 56.78924851119518, 69.65046778321266, 51.13468453288078, 51.63203984498978, 71.78312614560127, 68.04918050765991, 3.781271385960281, 0.2905113034648821, 0.2620465261861682, 0.11383303746697493, 0.30850918614305556, 0.16562524542678148, 0.1958597035263665, 0.14682533859740943, 0.11224688234506175], [0.04674636817071587, 0.15923838189337403, 0.07111008191714063, 0.039556738338433206, 0.04330023512011394, 0.062405060743913054, 0.03503715917759109, 0.18306473619304597, 0.13290337548824027, 0.16421265638200566, 0.10551027429755777, 43.53047177195549, 56.985956355929375, 52.782006338238716, 70.38053020834923, 101.12239301204681, 35.05150035023689, 33.79603631794453, 51.49044804275036, 55.38753792643547, 10.300709567964077, 0.48851048515643924, 12.152581997215748, 55.374189242720604, 70.97630023956299, 63.549009785056114, 70.89951395988464, 62.519546225667, 65.32557025551796, 57.05347493290901, 62.54818148910999, 61.15824267268181, 63.696529269218445, 61.99069820344448, 64.99673590064049, 50.870241522789, 55.09097903966904, 59.36577245593071, 58.53789947926998, 58.802000507712364, 63.727117627859116, 59.34400722384453, 60.99195599555969, 58.558285385370255, 50.87099768221378, 45.44447086751461, 47.72155947983265, 51.641744524240494, 56.00006125867367, 55.06890222430229, 55.94465263187885, 49.81056198477745, 47.25214406847954, 45.6538662314415, 43.515914753079414, 43.32225814461708, 42.31888398528099, 47.11174540221691, 50.110989063978195, 48.255362436175346, 53.48723329603672, 52.41942599415779, 55.640414357185364, 56.10510662198067, 55.2267799526453, 57.37475909292698, 56.542824134230614, 57.65654057264328, 55.611250922083855, 54.47372116148472, 56.25467799603939, 55.112295895814896, 54.53751973807812, 46.62426955997944, 35.66070266067982, 43.83926220238209, 39.43807616829872, 37.96782486140728, 44.32438977062702, 43.51833522319794, 43.108542412519455, 40.67132659256458, 41.364067420363426, 43.81845071911812, 47.94328138232231, 54.43402089178562, 55.46981871128082, 55.92481009662151, 55.64832553267479, 51.122946962714195, 55.81515558063984, 53.469169065356255, 52.189819514751434, 52.1186987310648, 43.792258724570274, 41.98369637131691, 44.629961773753166, 43.754777535796165, 41.17758862674236, 42.70212382078171, 43.399583995342255, 41.13246984779835, 47.392835319042206, 49.49963986873627, 50.38334704935551, 51.17250770330429, 57.40106128156185, 53.76716427505016, 50.383628234267235, 57.18710616230965, 53.95248793065548, 53.994965851306915, 57.192585468292236, 56.822101548314095, 54.12520006299019, 56.21535770595074, 52.47815564274788, 52.07480728626251, 52.7193097025156, 49.022453874349594, 51.58632829785347, 45.107968524098396, 46.21894150972366, 46.42622038722038, 43.969807997345924, 48.2072152197361, 52.10492826998234, 53.45037527382374, 53.811466097831726, 54.94698956608772, 51.04190871119499, 46.34544812142849, 44.292406886816025, 52.7174212038517, 55.85977278649807, 60.71572221815586, 61.80732384324074, 59.204296320676804, 59.91396144032478, 61.51567429304123, 60.975913256406784, 61.95764757692814, 62.78932794928551, 64.86859917640686, 59.93984565138817, 63.444633185863495, 65.51401734352112, 66.16360768675804, 63.601937144994736, 58.49908456206322, 53.03501956164837, 61.68618254363537, 65.81188336014748, 74.81835767626762, 66.65925309062004, 83.57498779892921, 5.517884837463498, 0.13644650724017993, 56.18913151323795, 62.41356611251831, 44.92459036409855, 25.642764419317245, 43.22372943162918, 43.866141960024834, 53.707910254597664, 53.642568960785866, 48.971620202064514, 2.1322337351739407, 0.053069514615344815, 0.11646994011243805, 0.12091973141650669, 0.0192249830433866, 0.05985952760966029, 0.04086229484528303, 0.011196147461305372, 0.07982730399817228, 0.016444777247670572, 0.0666701166483108, 0.05935007291554939, 0.02783786658255849, 0.10940384076093324, 0.17278708925005049, 0.03396932741452474, 0.08064492809353396, 0.10669840077753179, 0.14553610933944583, 0.02078947116388008, 53.124797344207764, 66.98311731219292, 53.049732372164726, 62.46730662882328, 97.47008219361305, 34.13326822221279, 43.921273201704025, 53.06255668401718, 65.5086824297905, 12.721670810133219, 0.530994669534266, 13.717736061662436, 59.34145376086235, 75.9644065797329, 65.83681762218475, 75.85234299302101, 65.33284306526184, 67.07744345068932, 59.99530367553234, 65.12522220611572, 64.02961179614067, 67.40066930651665, 63.67723390460014, 64.71716210246086, 51.461151614785194, 56.620043590664864, 60.74727192521095, 61.71859860420227, 63.08219723403454, 65.62499418854713, 62.257569283246994, 63.76481160521507, 60.66624127328396, 51.06932044029236, 47.34946824610233, 49.543234929442406, 52.58343659341335, 60.30747972428799, 57.77096763253212, 59.34790201485157, 56.077740490436554, 51.23992748558521, 48.71068440377712, 46.27071753144264, 46.75330303609371, 45.251087844371796, 48.12667474150658, 53.77512484788895, 52.0103095471859, 57.0031276345253, 54.87593337893486, 58.58377821743488, 58.802893459796906, 57.44279824197292, 59.41004768013954, 57.808129638433456, 57.95457758009434, 57.12050713598728, 57.19382420182228, 58.537318110466, 56.37491874396801, 55.80369919538498, 47.19683803617954, 39.60189677774906, 46.669019758701324, 42.23183825612068, 40.717326924204826, 47.48496897518635, 44.98721860349178, 45.20639084279537, 43.347712978720665, 43.01719531416893, 46.38647451996803, 48.06526243686676, 55.49063019454479, 56.39503486454487, 57.08195820450783, 54.341009482741356, 50.91305382549763, 57.11078345775604, 55.21836720407009, 55.659451335668564, 52.045643851161, 45.853416323661804, 45.6185357272625, 45.41943781077862, 46.80336534976959, 41.85508847236633, 44.78628918528557, 45.62857858836651, 42.90860094130039, 49.95761029422283, 51.61577671766281, 52.45612442493439, 53.72685603797436, 57.43532404303551, 54.21853065490723, 54.43648315966129, 58.99431958794594, 56.8743297457695, 56.9002253562212, 58.88107046484947, 60.19123636186123, 56.024068370461464, 56.12812578678131, 57.287819758057594, 55.955459251999855, 54.739497900009155, 52.08708442747593, 52.00035788118839, 48.19751814007759, 49.19729009270668, 49.47221294045448, 47.58649192750454, 51.55436061322689, 54.80948634445667, 54.55515459179878, 58.17629188299179, 56.51898421347141, 54.85398195683956, 51.721623837947845, 46.15013100206852, 54.13070596754551, 57.072017937898636, 63.81908029317856, 62.76827707886696, 61.419216468930244, 63.50381501019001, 64.91590663790703, 65.1229727268219, 64.76279005408287, 65.7303549349308, 66.47916555404663, 62.00738310813904, 65.70924326777458, 69.28291350603104, 68.71200174093246, 65.68364784121513, 63.69748681783676, 58.3699256926775, 65.6262481212616, 69.24813017249107, 77.01887279748917, 70.22125795483589, 82.54925563931465, 4.26851567812264, 0.22162944573210552, 64.37028631567955, 67.80097782611847, 52.65470936894417, 30.66211838275194, 59.99333158135414, 43.139670342206955, 51.9935068488121, 62.482213228940964, 60.13019263744354, 5.028394628316164, 0.06491150124929845, 0.1584569300757721, 0.1905665430240333, 0.018531462737882975, 0.06900861655594781, 0.030128549915389158, 0.02799868812871864, 0.07364778168266639, 0.05319959454936907, 0.18029152328381315, 0.3067829506471753, 0.13364843238377944, 0.17715165973640978, 0.3082528483355418, 0.12793551315553486, 0.20496633049333468, 0.2996600844198838, 0.28925446153152734, 0.1335143411415629, 60.5212714523077, 74.1573603451252, 69.78698685765266, 83.8747689127922, 113.28695386648178, 45.05387082695961, 47.95833237469196, 65.16879066824913, 69.92575541138649, 13.032546378672123, 0.6904539442621171, 17.91869468986988, 58.699432611465454, 78.60032513737679, 69.29159224033356, 78.56738090515137, 68.20090636610985, 71.33153557777405, 61.71748906373978, 67.76861116290092, 66.65217787027359, 69.45059090852737, 66.92681953310966, 69.06200855970383, 53.12348261475563, 57.496223375201225, 61.196715608239174, 62.257500886917114, 63.19816701114178, 68.06839987635612, 64.99029904603958, 65.96867054700851, 64.96921017765999, 54.24585498869419, 50.99343091249466, 52.737457528710365, 54.453035071492195, 60.82893714308739, 61.16324320435524, 62.842012122273445, 57.69439794123173, 52.97865338623524, 50.353340059518814, 49.79956537485123, 48.73770855367184, 46.89965598285198, 51.10644444823265, 55.71804039180279, 53.85373502969742, 57.167039439082146, 56.49140529334545, 61.25213943421841, 62.10016272962093, 60.396334156394005, 61.311469450592995, 62.085423320531845, 60.49012832343578, 60.80788627266884, 60.92621952295303, 62.70455449819565, 60.090758353471756, 60.09718380868435, 50.22999107837677, 41.86811037361622, 52.24368542432785, 46.971346735954285, 45.86036995053291, 49.45265159010887, 47.33103163540363, 47.868543192744255, 47.907380908727646, 45.863827764987946, 47.33545079827309, 48.98962363600731, 58.65736126899719, 61.0155413299799, 59.291266053915024, 57.189188450574875, 53.72367940843105, 59.59081918001175, 57.57701463997364, 58.43737967312336, 55.761635452508926, 47.13862136006355, 49.13209319114685, 49.90847893059254, 51.223877146840096, 45.53018666803837, 48.78647133708, 48.15487302839756, 45.29820531606674, 52.56172455847263, 54.203187078237534, 56.518714427948, 57.04442761838436, 62.52667084336281, 59.093042090535164, 55.918852016329765, 61.66948243975639, 58.24305050075054, 58.56077805161476, 62.67470329999924, 62.513025775551796, 59.80816751718521, 59.44123260676861, 59.289928525686264, 57.016723304986954, 57.01336808502674, 54.752284213900566, 56.8419174849987, 52.66494981944561, 52.71318823099136, 52.755791544914246, 51.09992399811745, 55.06101004779339, 57.48061001300812, 59.26287777721882, 61.688812002539635, 60.41960030794144, 56.197829246520996, 51.89511492848396, 48.79584923386574, 58.43001566827297, 61.17528095841408, 64.45296987891197, 65.90205252170563, 63.81684601306915, 65.19988059997559, 68.50586280226707, 67.46474906802177, 66.8810623884201, 70.60841158032417, 69.69659730792046, 64.07383382320404, 67.48374804854393, 70.93096107244492, 72.9094997048378, 70.65778613090515, 67.40265280008316, 60.567332580685616, 69.73220899701118, 70.140231102705, 82.332082092762, 71.80419221520424, 88.95584106445312, 8.222628626972437, 0.18887312529841438, 68.3092613518238, 73.497244566679, 60.85123814642429, 36.45402029156685, 60.2516683191061, 57.97286979854107, 66.4960366487503, 69.6982616186142, 69.26879346370697, 6.559046544134617, 0.20261198573280126, 0.41912226006388664, 0.34593809803482145, 0.11998892980045639, 0.19955326861236244, 0.09704824711661786, 0.124756894656457, 0.26833702926523983], [0.046061191460466944, 0.04071896386449225, 0.028803502755181398, 0.024602598095953, 0.020721061846415978, 0.06984420804656111, 0.07511474788771011, 0.036273124496801756, 0.06282222937443294, 0.09888215339742601, 0.5713486822787672, 51.83902993798256, 60.995972380042076, 44.20426681637764, 53.29610355198383, 89.06679511070251, 45.2420025318861, 30.097666271030903, 51.12941041588783, 51.58720225095749, 18.873860836029053, 0.3571563132572919, 8.309088237583637, 52.43747502565384, 67.22396358847618, 65.74017360806465, 65.64279243350029, 62.6178203523159, 61.78613618016243, 60.785440877079964, 67.19451516866684, 59.79628935456276, 72.5828692317009, 68.75288754701614, 58.07498551905155, 57.718766033649445, 64.58678349852562, 62.99076274037361, 63.03381063044071, 60.449364110827446, 61.23860836029053, 59.86239820718765, 61.3802495598793, 51.6975749284029, 45.99140591919422, 45.00426068902016, 51.21243976056576, 55.598362013697624, 57.47154749929905, 55.229132026433945, 54.197289794683456, 53.31698343157768, 49.89296816289425, 46.219602674245834, 46.05170488357544, 44.34476047754288, 44.797262996435165, 43.91089975833893, 47.59298577904701, 57.09716118872166, 54.31333176791668, 52.025588527321815, 55.416070595383644, 56.82887278497219, 57.36140660941601, 56.611984223127365, 53.58088307082653, 53.4270179271698, 54.40993778407574, 56.751391142606735, 56.47509656846523, 54.42495457828045, 52.36985385417938, 44.07375141978264, 37.324055805802345, 35.94843842089176, 41.74798741936684, 37.78779812157154, 38.85275937616825, 42.04561784863472, 42.74226866662502, 40.96595898270607, 43.89707610011101, 42.52993606030941, 49.31045942008495, 52.29802630841732, 55.55380940437317, 56.56683124601841, 52.370929196476936, 48.40184837579727, 54.37607400119305, 55.67039094865322, 53.350870013237, 53.74221861362457, 47.3936028778553, 44.161317721009254, 45.23061454296112, 40.16750782728195, 40.302586778998375, 39.81006860733032, 45.29727056622505, 46.52375355362892, 48.54727417230606, 50.979766845703125, 49.166466146707535, 54.44594085216522, 56.022286266088486, 50.94307601451874, 55.1429108530283, 52.45818391442299, 58.79244402050972, 57.100375816226006, 58.02247233688831, 54.94994580745697, 56.16814523935318, 56.409755274653435, 51.06477588415146, 51.73941448330879, 55.842867493629456, 53.3898863196373, 45.42800635099411, 43.70843902230263, 45.72115682065487, 48.575001284480095, 45.545199662446976, 48.95936205983162, 53.180221170187, 55.7131614536047, 56.253405064344406, 56.157885789871216, 55.67406915128231, 48.19113068282604, 44.394503608345985, 46.527074575424194, 52.58890450000763, 57.58307531476021, 57.83381246030331, 58.91029469668865, 61.46602235734463, 59.28683549165726, 60.87396092712879, 63.22284288704395, 60.23721009492874, 62.96450234949589, 62.653914615511894, 64.0623964369297, 65.14319524168968, 65.36715522408485, 64.07029241323471, 60.45756407082081, 55.74341543018818, 63.97937089204788, 67.6761469244957, 67.92494237422943, 75.5637788772583, 61.57546788454056, 0.519682023441419, 4.392160093411803, 71.83242470026016, 54.05813746154308, 33.76346826553345, 18.82003292441368, 47.94313699007034, 43.594232350587845, 39.71635423600674, 43.1943342089653, 58.20286005735397, 12.196629233658314, 0.21552789345150813, 0.04904681445623282, 0.06893537400173955, 0.12531693413620815, 0.034684935890254565, 0.06436581490561366, 0.03477077269053552, 0.02853370795492083, 0.06086809517000802, 0.0901880269520916, 0.0529797073249938, 0.004049834933539387, 0.0574891524593113, 0.02251533187518362, 0.08089728056802414, 0.07915447291452438, 0.002585761480986548, 0.03169478950439952, 1.0346669051796198, 62.48412452638149, 64.61976572871208, 50.66028758883476, 55.30948631465435, 93.72125655412674, 45.45534588396549, 33.94878812134266, 52.64793053269386, 57.308692038059235, 24.534892067313194, 0.5880750878714025, 9.253508560359478, 53.64990636706352, 72.5209629535675, 68.19729655981064, 70.11297136545181, 66.0230228304863, 66.6385518014431, 64.87613037228584, 68.43123480677605, 63.70525740087032, 73.58793050050735, 70.44368281960487, 55.947707667946815, 62.4664630740881, 65.02762824296951, 65.8329950273037, 64.16477054357529, 62.84054920077324, 64.37375172972679, 62.161613032221794, 61.2483586370945, 54.85004536807537, 49.967208579182625, 49.28778983652592, 54.08836863934994, 58.233167231082916, 61.87925398349762, 58.57372395694256, 58.56491222977638, 55.99188409745693, 52.62617290019989, 48.91840785741806, 48.223941922187805, 46.39834128320217, 48.70897829532623, 46.09263628721237, 49.13568779826164, 60.02040132880211, 58.935817927122116, 55.6328983604908, 60.1377010345459, 59.48956981301308, 60.7413936406374, 59.68123532831669, 57.323724031448364, 56.21474213898182, 58.27177695930004, 59.00948837399483, 56.99047431349754, 56.37697823345661, 54.608784914016724, 47.600011602044106, 40.5161315202713, 40.03918491303921, 42.72034764289856, 42.69001767039299, 45.38772851228714, 44.2461671680212, 44.85809773206711, 42.19710052013397, 45.49774780869484, 42.734733670949936, 50.158786699175835, 54.70101356506348, 55.05710005760193, 55.85308514535427, 51.60785794258118, 50.63102915883064, 52.84028381109238, 56.482103392481804, 56.309984028339386, 53.68395633995533, 47.075415551662445, 45.605673417449, 48.293812572956085, 42.688547149300575, 41.676699444651604, 42.28909358382225, 47.230660021305084, 48.96057419478893, 49.462154880166054, 53.83589118719101, 51.80306486785412, 56.69439040124416, 59.437508806586266, 53.81780415773392, 57.037287801504135, 54.112603738904, 58.08584913611412, 58.88560362160206, 60.68258039653301, 58.640581369400024, 57.8231730312109, 57.25295662879944, 53.49655419588089, 52.55873791873455, 59.04177524149418, 57.36933298408985, 47.45291389524937, 46.76996514201164, 46.63361705839634, 51.90529078245163, 48.84344927966595, 51.610909178853035, 54.92573730647564, 56.69528715312481, 58.96138675510883, 58.20971488952637, 58.757683485746384, 49.856930896639824, 49.92087006568909, 48.792638406157494, 55.31482882797718, 59.27106633782387, 61.24265894293785, 62.90136493742466, 63.335392847657204, 64.18949961662292, 66.0311695933342, 65.37470161914825, 64.36162278056145, 66.68921828269958, 64.1188158094883, 65.51362216472626, 69.17030274868011, 67.72466272115707, 68.3876283466816, 64.29142534732819, 60.261361598968506, 68.75534981489182, 71.37014150619507, 71.7449913918972, 77.70059421658516, 62.29017533361912, 0.4030175367370248, 6.717598736286163, 82.31567457318306, 58.44194322824478, 41.072638258337975, 25.267447158694267, 58.77252168953419, 46.66229411959648, 37.62250319123268, 51.85339316725731, 69.5430475473404, 20.755411572754383, 0.3404033090919256, 0.13566958252340555, 0.013881805498385802, 0.07290912952157669, 0.01711426866677357, 0.1021474770095665, 0.08775198657531291, 0.03142645116895437, 0.14934611739590764, 0.19225243537221104, 0.12607729411683977, 0.08131083493935876, 0.15718113369075581, 0.12985061039216816, 0.2850511745782569, 0.13710068073123693, 0.18343120871577412, 0.13646403676830232, 1.7458135890774429, 73.60964253544807, 74.3045948445797, 62.09893919527531, 64.44387316703796, 95.5046072602272, 56.916024908423424, 42.55684621632099, 63.164044842123985, 68.51340919733047, 25.892859399318695, 0.9527736401651055, 13.107933383435011, 56.64993658661842, 76.00134819746017, 69.93457093834877, 70.93246579170227, 71.00403115153313, 70.7344888150692, 68.18231016397476, 70.68778172135353, 65.69696992635727, 69.48991879820824, 70.75538769364357, 58.6754634976387, 62.212800085544586, 67.34029814600945, 67.82712042331696, 67.63042017817497, 65.36235988140106, 68.25648218393326, 66.33450731635094, 68.62307131290436, 58.06578241288662, 51.68413124978542, 51.48471035063267, 58.60725335776806, 60.17048567533493, 64.11331370472908, 62.523323222994804, 62.15013384819031, 60.20711570978165, 56.61931782960892, 53.12049977481365, 53.59777696430683, 49.41887900233269, 50.67482940852642, 50.20393967628479, 50.12920908629894, 61.162699833512306, 60.172427371144295, 58.56552019715309, 62.13301196694374, 62.58921168744564, 64.74148839712143, 62.09185637533665, 57.49427028000355, 60.291862562298775, 60.51996812224388, 64.9887715280056, 61.09192103147507, 60.70302329957485, 58.60018573701382, 51.58216372132301, 41.32851652801037, 44.84708212316036, 49.2865777015686, 47.80702829360962, 50.834322050213814, 49.80095990002155, 50.18961064517498, 44.808745980262756, 45.73839269578457, 43.236466348171234, 52.35886484384537, 56.0698065161705, 59.33182507753372, 59.00578737258911, 56.18077576160431, 53.69718722999096, 59.14060413837433, 63.507447615265846, 60.913813188672066, 55.852693766355515, 50.05546644330025, 47.66155309975147, 51.77072860300541, 46.43195427954197, 43.24767954647541, 44.14928376674652, 50.6410226225853, 50.68449229001999, 52.21375063061714, 56.55095189809799, 54.883407577872276, 59.721741154789925, 63.44382382929325, 58.28284576535225, 60.30056029558182, 55.58236867189407, 61.3950801640749, 61.7884274572134, 60.06658025085926, 59.26806069910526, 61.248810812830925, 61.8577965348959, 56.97472795844078, 56.74965463578701, 60.898883789777756, 60.89134879410267, 49.76142682135105, 49.78964030742645, 49.58645761013031, 54.94084149599075, 51.017248034477234, 53.58778730034828, 57.62762792408466, 60.78826792538166, 61.53214640915394, 61.26185551285744, 61.5682140737772, 53.70050065219402, 52.472740933299065, 52.59269289672375, 59.34919394552708, 62.056799456477165, 62.413706704974174, 64.60942268371582, 65.85763290524483, 67.73853957653046, 68.11275109648705, 70.21245762705803, 63.52740414440632, 69.05182510614395, 65.51938265562057, 67.07213133573532, 73.55175644159317, 71.19820073246956, 70.85286766290665, 69.36293721199036, 61.3889928907156, 73.09528693556786, 73.52135047316551, 77.2180125117302, 75.95946684479713, 71.51999026536942, 0.6950940296519548, 5.755497012287378, 87.10090979933739, 65.00921443104744, 46.680734530091286, 26.560620367527008, 66.0888808965683, 57.98142693936825, 51.82613343000412, 57.35744722187519, 79.58958685398102, 22.947842627763748, 0.5393460870254785, 0.37371018435806036, 0.12007351979264058, 0.18945608229842037, 0.10395649165729992, 0.17301575979217887, 0.13857546175131574, 0.16911014827201143], [0.04742237564641982, 0.039508758491137996, 0.07513573582400568, 0.023621855507371947, 0.06631636453676037, 0.03510067217575852, 0.06662475658231415, 0.031028708253870718, 0.08572763035772368, 0.042213589913444594, 4.030480301007628, 60.64753107726574, 50.79429119825363, 25.815736837685108, 58.639468029141426, 88.42619508504868, 38.53865683078766, 25.231955163180828, 46.27086192369461, 56.62019558250904, 38.503710106015205, 0.8478013041894883, 3.2070032134652138, 50.380189418792725, 68.64808157086372, 66.9261583685875, 65.1169766485691, 63.2456910610199, 60.36882743239403, 64.97041091322899, 59.62576970458031, 70.8978420495987, 69.25604894757271, 56.41085721552372, 59.85286071896553, 61.95216827094555, 60.46094968914986, 59.225993156433105, 59.53301288187504, 58.073659390211105, 57.7387073636055, 58.56131002306938, 54.37477067112923, 49.03718188405037, 44.67723123729229, 46.19968794286251, 54.15028631687164, 59.157270044088364, 58.40642273426056, 56.12702764570713, 58.79095830023289, 55.70293240249157, 51.77838519215584, 45.802472457289696, 46.37444816529751, 47.78009533882141, 42.80421294271946, 42.256468534469604, 45.52888713777065, 49.56934712827206, 51.567226722836494, 54.6583304554224, 53.103883266448975, 53.538234159350395, 57.14017868041992, 55.846313908696175, 56.722398698329926, 54.72936764359474, 55.31429685652256, 55.08333384990692, 54.47913967072964, 54.03546787798405, 54.0034393966198, 46.49296760559082, 34.35149811208248, 41.47667437791824, 36.3926687836647, 34.852558225393295, 41.43329590559006, 38.441214859485626, 44.336628913879395, 49.70031090080738, 48.633176162838936, 43.07111442089081, 49.00109522044659, 51.386136040091515, 53.27647380530834, 48.39994467794895, 45.001403242349625, 46.73503741621971, 53.67740549147129, 53.9254941791296, 52.86108769476414, 54.28723096847534, 50.5879470705986, 48.65371786057949, 45.52603729069233, 43.4245752543211, 44.86441299319267, 43.694698959589005, 44.996060729026794, 43.811459094285965, 45.306868851184845, 44.74183917045593, 50.20461603999138, 52.58012697100639, 51.98717638850212, 53.44990789890289, 54.713773280382156, 54.27333511412144, 57.000551372766495, 54.499092400074005, 55.100178346037865, 55.93755841255188, 56.009028777480125, 53.39113265275955, 51.50412730872631, 51.5757192671299, 49.666519314050674, 46.531584933400154, 41.47716835141182, 45.01723699271679, 47.715973779559135, 46.66041322052479, 45.784643813967705, 49.38807785511017, 53.84661801159382, 55.82548722624779, 56.12414360046387, 56.45322494208813, 59.40673425793648, 54.70080457627773, 49.515143036842346, 44.36780244112015, 52.447050511837006, 56.329055204987526, 58.175102546811104, 58.93466278910637, 59.718629121780396, 60.06262086331844, 62.100489512085915, 58.899081498384476, 62.19676494598389, 60.13037122786045, 56.74242362380028, 60.03404639661312, 67.28424355387688, 65.08492156863213, 66.00514099001884, 61.95729039609432, 59.602537751197815, 65.34292012453079, 68.76002356410027, 66.17001414299011, 71.84001669287682, 28.782587237656116, 1.0606991895474494, 20.271933116018772, 65.17673224210739, 43.88993628323078, 22.880534939467907, 27.927933298051357, 49.47126679122448, 44.85847771167755, 38.274168223142624, 42.13393650949001, 61.99605971574783, 23.028293810784817, 0.3036129707470536, 0.10273151012370363, 0.03968450277170632, 0.11084904719609767, 0.020125076443946455, 0.15316232980694622, 0.05864013815880753, 0.051932544374722056, 0.04567074014630634, 0.023341856176557485, 0.0035462255800666753, 0.03044344688532874, 0.11126062003313564, 0.02783023359370418, 0.15460053778951988, 0.020435717196960468, 0.1841282783425413, 0.1815474301110953, 6.4275512751191854, 69.21596869826317, 60.85083916783333, 35.916113555431366, 64.03382197022438, 99.9087381362915, 42.4933136254549, 30.075526759028435, 52.51755952835083, 61.19608484208584, 47.50151328742504, 0.9642958687618375, 2.1887839632108808, 51.78730711340904, 73.78290563821793, 73.48543480038643, 69.13463786244392, 69.228006452322, 64.14183497428894, 69.36758816242218, 65.33253148198128, 71.87643393874168, 71.9328761100769, 59.911278784275055, 62.12238013744354, 63.845762461423874, 63.35018925368786, 60.25450296700001, 59.3595027923584, 61.91764712333679, 59.76666994392872, 61.910119727253914, 54.133840799331665, 52.769725397229195, 47.28816233575344, 49.84337702393532, 55.90191252529621, 61.62983536720276, 59.50593553483486, 59.11812834441662, 59.80853229761124, 56.81283764541149, 53.65668520331383, 47.79614947736263, 50.5536425113678, 49.46365959942341, 47.592807188630104, 44.847306311130524, 46.066071912646294, 51.98152609169483, 54.852956011891365, 57.86301389336586, 56.02230526506901, 55.75674511492252, 59.447274282574654, 58.358887284994125, 59.46430876851082, 57.36728869378567, 58.15570078790188, 57.34885208308697, 56.89796447753906, 56.697992607951164, 55.88424727320671, 49.5897102355957, 37.83394284546375, 44.23851437866688, 40.328843370079994, 37.62516684830189, 43.00521835684776, 42.54917822778225, 44.53089728951454, 48.18609595298767, 49.04996819794178, 44.05289053916931, 48.49185794591904, 50.17937779426575, 52.49895192682743, 48.70973065495491, 45.49184292554855, 46.58937223255634, 54.64475378394127, 54.00553688406944, 53.623076006770134, 54.06588904559612, 50.926729291677475, 49.85883839428425, 46.99059650301933, 44.33811083436012, 45.28721250593662, 43.268426433205605, 45.6067031621933, 47.91942246258259, 47.36149460077286, 46.86453066766262, 51.198958083987236, 55.829017236828804, 56.57563917338848, 54.06845770776272, 56.31799019873142, 58.37742269039154, 56.9091472774744, 57.17458203434944, 57.43112526834011, 56.645616218447685, 55.74656546115875, 57.309550791978836, 52.2371231764555, 52.66343370079994, 51.55893936753273, 49.928705245256424, 44.60904389619827, 48.66635978221893, 50.64400926232338, 50.22578850388527, 49.83203083276749, 51.76573567092419, 56.54086723923683, 60.895118191838264, 58.854095712304115, 58.624116852879524, 62.69496001303196, 57.44371399283409, 51.99381463229656, 46.15701623260975, 53.86821985244751, 58.05661350488663, 63.12805317342281, 61.66263900697231, 63.36657017469406, 61.080084666609764, 64.01999071240425, 62.48075790703297, 64.40038070082664, 62.079541236162186, 59.4222754240036, 60.43187364935875, 68.62829223275185, 67.72915408015251, 67.96867802739143, 63.73431444168091, 63.383536264300346, 68.70950147509575, 74.39222574234009, 70.07215395569801, 74.40254598855972, 25.295056477189064, 0.8757665567100048, 26.617246828973293, 72.97227993607521, 47.8546055406332, 26.81514970958233, 30.83969995379448, 44.01994630694389, 46.85830280184746, 39.49160769581795, 57.33500562608242, 70.02733916044235, 31.919096633791924, 0.3513266541995108, 0.04830640340514947, 0.05238558100245427, 0.18505088664824143, 0.019634533528005704, 0.06845355688710697, 0.05785503126389813, 0.0376412663172232, 0.11525219451868907, 0.11912247238797136, 0.13247791706817225, 0.13022515748161823, 0.22899964009411633, 0.17259258718695492, 0.21791328967083246, 0.11753881088225171, 0.3476849652361125, 0.2387081933557056, 6.488068727776408, 81.84466704726219, 64.86644089221954, 39.35377009212971, 68.47196102142334, 102.18860059976578, 49.44676950573921, 37.8736013174057, 58.592107370495796, 67.99808844923973, 53.59520070254803, 0.5760317528620362, 4.482151139527559, 58.30043502151966, 77.40746274590492, 76.14469170570374, 72.0513005554676, 72.83347338438034, 65.92833191156387, 72.31160938739777, 66.84732019901276, 71.86381861567497, 73.97669523954391, 62.93671824038029, 63.37907150387764, 66.75293326377869, 65.08542314171791, 63.81094112992287, 60.819992423057556, 64.08139541745186, 62.723374888300896, 64.83642250299454, 59.182869270443916, 55.09331211447716, 49.438402354717255, 52.309110313653946, 59.769728779792786, 64.55407485365868, 62.47293032705784, 61.38246864080429, 63.54979254305363, 59.14278902113438, 56.54837183654308, 48.44355873763561, 53.319369703531265, 52.71705262362957, 50.60418739914894, 46.93841390311718, 48.487355187535286, 54.818887040019035, 56.185179725289345, 61.23359642922878, 58.77271927893162, 58.92138630151749, 62.703042179346085, 60.11441208422184, 62.66942918300629, 60.951784551143646, 62.27233529090881, 60.62089450657368, 60.69043457508087, 59.815930500626564, 59.297277331352234, 54.26498696208, 37.783462554216385, 48.69353972375393, 44.42517176270485, 38.358557894825935, 43.813602179288864, 42.69485101103783, 47.04807601869106, 48.90737324953079, 49.7173073887825, 45.62978312373161, 50.922211334109306, 53.45556579530239, 55.28820365667343, 50.72514250874519, 46.691297963261604, 48.24800223112106, 56.919756308197975, 56.73737749457359, 55.918852016329765, 57.91135109961033, 53.586229383945465, 54.67581331729889, 49.16620776057243, 45.6927115470171, 47.495068833231926, 45.24633429944515, 47.7125159651041, 49.536399096250534, 48.72313633561134, 50.56844651699066, 52.94985853135586, 57.50096172094345, 60.34192867577076, 58.75930979847908, 58.749384731054306, 61.326235458254814, 60.318274945020676, 59.77596424520016, 60.25714002549648, 58.324191346764565, 57.19004340469837, 59.93595466017723, 54.93421845138073, 56.798983588814735, 54.41315621137619, 53.384068831801414, 46.59058056771755, 51.78511843085289, 53.31557750701904, 52.80499130487442, 51.01733922958374, 53.71644839644432, 59.24052357673645, 61.9360039383173, 61.195644065737724, 64.03064534068108, 63.96868586540222, 59.042945578694344, 54.69325818121433, 49.86896485090256, 58.10256063938141, 60.72254665195942, 64.38553109765053, 64.09980162978172, 64.86552134156227, 65.27536734938622, 66.17253720760345, 62.827819883823395, 66.39533445239067, 65.77798917889595, 61.34781450033188, 64.2796079814434, 71.29747420549393, 71.5463836491108, 70.54388344287872, 70.17458885908127, 66.04777470231056, 72.82017409801483, 75.95869168639183, 74.7894336283207, 75.0140243768692, 38.922873213887215, 0.8628158422652632, 24.295389018952847, 79.17803853750229, 58.77250649034977, 36.784066781401634, 34.766823425889015, 66.35455504059792, 61.48982048034668, 50.41992008686066, 58.21004167199135, 78.78695592284203, 41.30498819053173, 0.6017136841546744, 0.16756055876612663, 0.16401747154304758, 0.18789746827678755, 0.15880833700066432, 0.20242481608875096, 0.14407645328901708, 0.16438854538137093], [0.056877604220062494, 0.05531340553716291, 0.05666318662406411, 0.08274350650026463, 0.11699788912665099, 0.03563586826203391, 0.1620593000552617, 0.023498846385336947, 0.2374717011116445, 0.33674181962851435, 10.357478521764278, 69.64726075530052, 50.45257933437824, 31.716831587255, 21.929692961275578, 33.1491856276989, 36.41986772418022, 22.326625362038612, 47.90539741516113, 60.1305840164423, 63.58276717364788, 7.721753278747201, 0.33987492963206023, 29.766595736145973, 69.52328860759735, 68.83109495043755, 63.42104785144329, 63.83890762925148, 62.6222775131464, 65.74731722474098, 64.24018129706383, 68.83553311228752, 51.76632083952427, 61.58555634319782, 60.04879720509052, 61.469107791781425, 59.20920565724373, 60.33198840916157, 56.19764685630798, 57.54159674048424, 55.15917778015137, 52.38927461206913, 51.331589967012405, 46.2080854922533, 43.32114480435848, 50.00970929861069, 54.139688685536385, 62.76207961142063, 56.34888254106045, 55.955466851592064, 60.78356757760048, 57.42523178458214, 50.33875644207001, 48.91002930700779, 47.62331195175648, 48.41581642627716, 48.08028683066368, 46.501779332756996, 41.36756703257561, 43.97303782403469, 46.60543777048588, 51.75707973539829, 52.18856178224087, 54.912666007876396, 53.73979054391384, 54.2074428498745, 54.98275324702263, 55.60084708034992, 54.60414536297321, 53.4633781760931, 55.744502171874046, 53.24116609990597, 55.58185949921608, 44.69763234257698, 37.66947627067566, 43.8474203646183, 31.312525682151318, 39.75958451628685, 39.35369789600372, 41.28861106932163, 45.96819296479225, 47.55808465182781, 48.91224838793278, 46.67691573500633, 48.24569575488567, 46.08521528542042, 47.16334283351898, 46.23173162341118, 46.64117105305195, 45.253694504499435, 43.73347207903862, 46.41938455402851, 50.743373930454254, 49.983631297945976, 49.92189981043339, 48.82654398679733, 48.32756616175175, 41.69749192893505, 43.79553034901619, 43.76230113208294, 44.60749737918377, 42.95722313225269, 41.97259336709976, 42.364808320999146, 50.42607955634594, 57.1786630153656, 53.39437387883663, 54.95233967900276, 53.22005443274975, 55.30108116567135, 55.29590964317322, 54.91132088005543, 56.45075507462025, 55.49349144101143, 55.004830062389374, 52.19822846353054, 52.11294583976269, 47.403638139367104, 45.19307255744934, 41.39324985444546, 42.775345891714096, 43.9417465031147, 49.09344166517258, 49.70944561064243, 47.236200124025345, 49.58080351352692, 56.21270924806595, 59.73284795880318, 58.91803868114948, 55.49282647669315, 61.13084614276886, 57.93040707707405, 51.97179861366749, 44.146878495812416, 48.20521652698517, 54.0082461386919, 58.46277751028538, 59.44596715271473, 60.71471147239208, 60.12964926660061, 61.530702486634254, 57.76815578341484, 57.35704444348812, 54.44650322198868, 57.777746468782425, 55.234603732824326, 60.79649828374386, 64.67342644929886, 64.67001423239708, 59.57833684980869, 60.987935811281204, 64.97224241495132, 67.07095339894295, 66.94956511259079, 63.970866948366165, 4.4278287794440985, 0.0826068028982263, 44.36843320727348, 58.70551608502865, 45.66860944032669, 16.862408369779587, 34.680115878582, 54.56850707530975, 41.62640534341335, 35.928683280944824, 40.00575810670853, 57.29751303792, 27.92519174516201, 0.7994745473843068, 0.30242764216382056, 0.04892862001725007, 0.11829471797682345, 0.11212103636353277, 0.026634041823854204, 0.022076021268730983, 0.07322273144382052, 0.023507993355451617, 0.02050583530945005, 0.023870955519669224, 0.028717031418636907, 0.12441178114386275, 0.06576601750566624, 0.20323133765487, 0.18745700363069773, 0.3006379975704476, 0.5039733101148158, 13.430872354656458, 79.60715711116791, 60.47159291803837, 39.18815217912197, 26.359709948301315, 44.40979778766632, 43.452613949775696, 24.593604616820812, 54.01470199227333, 65.62425702810287, 72.8646469116211, 10.928608775138855, 0.351169912610203, 29.679688699543476, 72.9148118197918, 75.55608049035072, 66.237141340971, 69.22190397977829, 65.67211925983429, 69.2144487798214, 67.21701756119728, 70.52312895655632, 55.252671763300896, 64.2166605591774, 62.23993442952633, 66.16394206881523, 61.02117262780666, 63.20660635828972, 59.2243592441082, 60.479872673749924, 58.80721762776375, 55.74770160019398, 53.53172890841961, 48.49112078547478, 46.46186247467995, 51.97211019694805, 56.08578845858574, 64.09428432583809, 57.54063919186592, 60.1164373755455, 61.007633954286575, 59.75509196519852, 54.129322841763496, 52.38537222146988, 49.57790806889534, 52.37483538687229, 49.146125838160515, 48.498648181557655, 43.569108098745346, 46.7076750844717, 48.42111714184284, 53.72651785612106, 55.934279188513756, 54.03957165777683, 56.51355430483818, 56.27221405506134, 56.83276757597923, 57.321751937270164, 56.76472082734108, 56.51344031095505, 55.90871036052704, 57.66628324985504, 55.58022938668728, 48.88555482029915, 40.3911904245615, 43.79209153354168, 35.73010593652725, 43.747934103012085, 39.98085044324398, 39.55100990831852, 44.331483989953995, 47.27813467383385, 49.82688210904598, 46.93819351494312, 45.80042816698551, 47.0966412127018, 46.2807147949934, 45.299922823905945, 45.421501100063324, 43.87112349271774, 44.76204268634319, 47.310315147042274, 49.608861207962036, 50.81820331513882, 52.79760830104351, 48.67297902703285, 47.89903275668621, 43.52140925824642, 43.91572169959545, 44.86576572060585, 46.51230476796627, 45.012422651052475, 40.83464562892914, 44.35895271599293, 51.452233493328094, 58.94210658967495, 56.84035576879978, 56.824537217617035, 56.0406506806612, 57.603643611073494, 58.74364323914051, 57.41401858627796, 57.936216965317726, 59.603696689009666, 56.83319695293903, 55.607709512114525, 54.929875284433365, 51.05376407504082, 47.098328322172165, 43.678587824106216, 46.22101999819279, 46.77603341639042, 50.80170080065727, 52.48627960681915, 49.17163386940956, 53.821600154042244, 57.837300673127174, 62.15315468609333, 60.217371359467506, 57.92107857763767, 63.24982523918152, 62.4030102789402, 54.369580149650574, 47.22211807966232, 48.04346680641174, 55.380800887942314, 60.517562851309776, 61.52531437575817, 63.68872068822384, 63.16987372934818, 62.517501935362816, 60.392294973134995, 58.54448452591896, 58.11793081462383, 64.58992972970009, 57.487339451909065, 63.365707620978355, 65.46128377318382, 68.17157194018364, 62.94895738363266, 64.65172201395035, 68.57941925525665, 72.93177410960197, 72.52667024731636, 63.518638014793396, 3.1847504200413823, 0.1914904871955514, 50.53017117083073, 63.03098738193512, 50.027150362730026, 20.384367182850838, 35.36328881978989, 51.8669318407774, 52.10683956742287, 29.235097356140614, 51.39679826796055, 65.83836033940315, 42.72211454808712, 1.0543819097802043, 0.1328240695875138, 0.033763225583243184, 0.08326462033437565, 0.05753778910730034, 0.034731583582470194, 0.036500307032838464, 0.09284448518883437, 0.16500978235853836, 0.087667070038151, 0.13918249402195215, 0.15999765833839774, 0.2698263118509203, 0.2535191009519622, 0.26252734882291406, 0.23487378348363563, 0.557542301248759, 0.571116004139185, 15.75113520026207, 91.59283876419067, 68.93996670842171, 45.51924325525761, 29.004641622304916, 48.70319500565529, 50.93529023230076, 35.99405877292156, 62.471041828393936, 72.3678919672966, 78.60732436180115, 9.273090809583664, 0.4690355504862964, 38.23499992489815, 74.34234201908112, 80.29916077852249, 68.62607315182686, 72.22666874527931, 67.33826905488968, 73.54503840208054, 67.73246750235558, 73.2909308373928, 59.72975492477417, 65.73602423071861, 66.26811727881432, 67.69539669156075, 64.15735334157944, 66.22807502746582, 61.78884543478489, 63.742191419005394, 62.579997181892395, 58.23064036667347, 57.08101585507393, 52.26511247456074, 47.856159657239914, 54.56663757562637, 58.00345055758953, 66.56821757555008, 60.65724715590477, 61.74843080341816, 63.70353229343891, 63.37450794875622, 57.19305284321308, 55.434241220355034, 53.48838083446026, 53.109183982014656, 52.701724246144295, 51.758523657917976, 47.300283685326576, 48.71890716254711, 51.62311792373657, 56.18338622152805, 58.611725717782974, 58.32781635224819, 59.76752109825611, 59.57541860640049, 60.41217550635338, 60.36111764609814, 61.43866382539272, 58.66864286363125, 59.73760150372982, 62.394540533423424, 59.99846510589123, 50.82452617585659, 41.28228820860386, 50.66813416779041, 39.408623948693275, 44.88634541630745, 43.03402841091156, 40.19182652235031, 45.84759123623371, 49.77968104183674, 50.66529951989651, 48.05507518351078, 48.05890157818794, 47.10671067237854, 47.43674956262112, 47.91089951992035, 47.46480345726013, 46.31603769958019, 45.992393866181374, 49.24265965819359, 50.097423791885376, 54.914311319589615, 53.18541929125786, 49.40938711166382, 48.48011277616024, 45.47294653952122, 44.55072462558746, 44.77879598736763, 48.8260842114687, 48.399519100785255, 45.28180539608002, 46.58914044499397, 55.041384100914, 62.14462034404278, 59.49992045760155, 60.89376166462898, 56.62317842245102, 59.53524336218834, 61.75826467573643, 59.563434049487114, 62.3189701884985, 62.587809562683105, 60.60289107263088, 58.30341786146164, 56.92779287695885, 52.669551372528076, 49.99097630381584, 45.55691443383694, 47.541065365076065, 48.97648774087429, 52.86631241440773, 55.89291840791702, 51.49815782904625, 55.990626364946365, 59.14459012448788, 64.11917299032211, 62.555009722709656, 59.82774406671524, 64.72450330853462, 65.17037138342857, 57.105942517519, 49.598312973976135, 51.96081720292568, 57.56093010306358, 61.269280314445496, 63.57757285237312, 65.7114851474762, 65.66294655203819, 66.57764866948128, 64.28176626563072, 63.02517369389534, 60.03550171852112, 64.71228316426277, 60.73826640844345, 67.71441087126732, 69.8909492790699, 71.14041343331337, 67.21674397587776, 69.00493562221527, 69.67360854148865, 75.26805594563484, 71.24296993017197, 71.8657261133194, 8.807954918593168, 0.328724873252213, 54.27056506276131, 69.30700421333313, 63.819627463817596, 25.315054804086685, 45.22509723901749, 73.6605978012085, 57.982711270451546, 46.882473304867744, 53.221920132637024, 76.20443969964981, 53.70190277695656, 1.9012962584383786, 0.28251522628124803, 0.1795359278912656, 0.20591614593286067, 0.1641482231207192, 0.0929115382314194, 0.1589999150019139, 0.11311398542602547], [0.03421107088797726, 0.003353000010974938, 0.030236300481192302, 0.07297119533177465, 0.014339399840537226, 0.00881119003679487, 0.10874425701331347, 0.08634120837086812, 0.20928001933498308, 0.19448937237029895, 11.518908999860287, 63.40327240526676, 51.23249128460884, 45.617650374770164, 23.344165161252022, 41.30090340971947, 40.18860809504986, 19.121875427663326, 42.593928426504135, 69.59531754255295, 61.630690321326256, 35.81691987812519, 0.3064052271656692, 6.741180745884776, 61.81156821548939, 67.16224730014801, 63.96246179938316, 63.877156376838684, 65.19495606422424, 60.03967769443989, 58.03573362529278, 54.0897973626852, 58.564999625086784, 62.654780969023705, 58.59480142593384, 61.666267812252045, 56.802285611629486, 61.41314819455147, 55.65775662660599, 57.83991113305092, 52.55914829671383, 50.57251609861851, 44.60036136209965, 47.354841157794, 43.930635899305344, 51.129532009363174, 54.41463813185692, 61.32311962544918, 55.90557552874088, 54.12373334169388, 57.83368706703186, 57.84179963171482, 52.06768646836281, 47.621089071035385, 47.495650202035904, 50.64597375690937, 46.716182827949524, 49.72914755344391, 47.34022334218025, 41.45961329340935, 45.2392590790987, 50.19808039069176, 50.21973542869091, 52.639741972088814, 55.928370505571365, 55.23302681744099, 53.903261572122574, 52.87998408079147, 55.82683615386486, 53.00485298037529, 53.05893547832966, 53.362793773412704, 53.68155486881733, 45.51158286631107, 45.790955275297165, 40.1438844949007, 30.925330258905888, 43.9339455217123, 40.5740974098444, 45.583239421248436, 46.42867125570774, 45.76039731502533, 47.459631934762, 48.1889533996582, 47.14907839894295, 48.92193026840687, 49.335636869072914, 50.476806834340096, 48.14571551978588, 47.577140629291534, 50.21924905478954, 51.320441365242004, 45.72186358273029, 51.53266377747059, 49.088646322488785, 47.68826946616173, 48.617258816957474, 45.10641060769558, 42.84473776817322, 42.73155704140663, 42.14529030025005, 43.385589346289635, 43.046210557222366, 44.675494730472565, 45.82240238785744, 53.961531445384026, 50.71813188493252, 56.50890715420246, 53.24517488479614, 54.96014066040516, 55.99508732557297, 54.11035805940628, 55.31835503876209, 56.461755484342575, 53.01972538232803, 50.46858787536621, 48.99520553648472, 48.159250393509865, 45.06210118532181, 44.718952998518944, 48.32859970629215, 46.887945011258125, 50.14386489987373, 50.15137329697609, 47.80745767056942, 51.876989901065826, 55.5208195745945, 60.967014133930206, 55.618523731827736, 56.098871156573296, 59.169661179184914, 60.4355176538229, 54.463727697730064, 47.11838364601135, 47.52909600734711, 49.70158763229847, 58.35359416902065, 59.921124055981636, 59.96440753340721, 59.87105794250965, 57.252268865704536, 59.787067249417305, 59.299105033278465, 61.54176749289036, 61.28610581159592, 59.437653198838234, 62.32027351856232, 65.21007165312767, 62.42193326354027, 61.36342406272888, 60.29718227684498, 66.3149231672287, 65.2881346642971, 71.41512349247932, 37.36499480903149, 0.2711323433322832, 2.6855142088606954, 54.748115837574005, 62.002903148531914, 39.233510345220566, 13.60437959432602, 35.652141720056534, 39.88564655184746, 42.10992179811001, 46.29442445933819, 35.926479399204254, 58.39068777859211, 44.66645501554012, 3.382947784848511, 0.1491422494291328, 0.07888388587161899, 0.11278174817562103, 0.09237486898200586, 0.062034049988142215, 0.03227813613193575, 0.01721558852295857, 0.08763618927332573, 0.044524912373162806, 0.07892948342487216, 0.08998509409138933, 0.011181797108292812, 0.04755003988975659, 0.05848679560585879, 0.01635824653931195, 0.16012600535759702, 0.28466573276091367, 14.41294675692916, 73.7990927696228, 57.658953443169594, 49.59609769284725, 24.00982864201069, 44.23070579767227, 61.6381873190403, 30.089656300842762, 46.49476110935211, 75.65946534276009, 65.38594901561737, 46.59290224313736, 0.32582301646471024, 4.912408227100968, 62.204755917191505, 73.89338091015816, 69.32008311152458, 70.84153667092323, 69.27261605858803, 65.37261173129082, 62.53177396953106, 59.59296606481075, 62.557194605469704, 66.32997035980225, 62.776959612965584, 64.33386147022247, 60.14463186264038, 62.8230207413435, 58.36104556918144, 59.770473539829254, 55.08849777281284, 53.44279088079929, 48.145692721009254, 50.7846587151289, 46.71479970216751, 53.16699407994747, 55.949387177824974, 62.76815168559551, 58.405271396040916, 56.243225410580635, 63.02192486822605, 61.405685395002365, 54.99956354498863, 49.49378818273544, 51.1938701570034, 53.200740069150925, 46.86782889068127, 50.62943324446678, 52.22147561609745, 45.85244357585907, 47.386086881160736, 51.674434170126915, 52.320103123784065, 53.44607010483742, 57.426660507917404, 56.872087866067886, 56.09358184039593, 54.004450142383575, 57.67289489507675, 55.02675488591194, 58.62673491239548, 53.60540695488453, 52.16803528368473, 47.35134154558182, 47.24432788789272, 42.52560809254646, 35.486846789717674, 44.97910223901272, 42.835036888718605, 45.71085177361965, 45.142816454172134, 47.28595085442066, 45.739384442567825, 48.517118990421295, 48.09324413537979, 49.64812450110912, 46.80865466594696, 48.52140136063099, 47.178051844239235, 46.79422304034233, 48.661241456866264, 49.62000600993633, 46.7249071598053, 52.346264719963074, 49.2364089936018, 47.822314873337746, 48.32165747880936, 45.41036009788513, 42.999970838427544, 43.75724360346794, 43.50744500756264, 43.70763346552849, 44.992553517222404, 44.75813649594784, 47.57614508271217, 54.726513996720314, 51.77050441503525, 57.564627304673195, 53.96329075098038, 57.8744550794363, 57.9360231757164, 55.43899476528168, 56.53133735060692, 58.78956377506256, 55.23206166923046, 53.60208973288536, 50.125481486320496, 51.25212483108044, 49.1115552932024, 48.015735894441605, 50.97347438335419, 49.357934072613716, 51.81113563477993, 52.4911205470562, 47.21543423831463, 54.322694465518, 59.67332415282726, 61.888175904750824, 57.84042410552502, 58.251938223838806, 61.32890671491623, 64.04484897851944, 56.55606262385845, 51.953540593385696, 49.43314343690872, 52.56578654050827, 60.08637338876724, 63.15311662852764, 62.852799743413925, 63.45146901905537, 60.07921077311039, 63.003834038972855, 63.4249996393919, 64.94986161589622, 62.434974163770676, 62.66057565808296, 66.97528213262558, 68.07666823267937, 66.55052572488785, 64.08667713403702, 64.91162046790123, 71.14733666181564, 70.36302074790001, 72.77165830135345, 36.52599222958088, 0.2745009813224897, 2.995817195624113, 62.08671525120735, 63.47159653902054, 46.575635969638824, 14.407483600080013, 26.505413129925728, 52.42295600473881, 55.51575444638729, 37.022758573293686, 44.62385170161724, 66.86918422579765, 57.93496683239937, 7.658696612343192, 0.1838774175848812, 0.20692193415015936, 0.05226502653385978, 0.17853444413049147, 0.01666849395405734, 0.04843648333917372, 0.025643946319178212, 0.22895281057571992, 0.15688984072767198, 0.15543263376457617, 0.2320269198389724, 0.13298857404151931, 0.1127170848485548, 0.2967549324966967, 0.1868799392832443, 0.3498639405006543, 0.44169759086798877, 17.52281293272972, 84.41168770194054, 66.61571502685547, 65.81012785434723, 30.48553615808487, 56.831243857741356, 56.25088959932327, 33.85057479143143, 55.08654087781906, 80.3966635465622, 73.54772865772247, 47.61686749756336, 0.4697099549230188, 10.503572132438421, 70.14662235975266, 76.66426822543144, 71.24841123819351, 71.96428522467613, 73.4258083999157, 68.63903045654297, 61.777924820780754, 62.47524060308933, 65.45335739850998, 69.12002384662628, 64.90163460373878, 69.09850940108299, 63.929114788770676, 67.05970600247383, 60.90233400464058, 64.83691647648811, 59.045476242899895, 57.22607307136059, 51.162434443831444, 53.16248372197151, 48.736944794654846, 55.63304275274277, 58.37443225085735, 63.760913014411926, 62.25614815950394, 58.13787214457989, 65.35411432385445, 64.32202890515327, 58.912673369050026, 51.819046810269356, 53.51377107203007, 55.56162938475609, 51.319540813565254, 53.751011341810226, 55.89794933795929, 47.00068116188049, 49.996725395321846, 54.514314383268356, 56.34954750537872, 55.91074325144291, 62.96944588422775, 60.0260516256094, 60.19133895635605, 56.425551027059555, 62.45448611676693, 58.4681998193264, 60.19253209233284, 55.59352107346058, 54.70117315649986, 49.02408018708229, 51.56149283051491, 47.367916256189346, 37.66264043748379, 47.49158062040806, 44.858660101890564, 47.68269136548042, 45.6019876152277, 49.239741414785385, 47.06029996275902, 49.75523315370083, 52.280262261629105, 51.38007536530495, 48.3522192388773, 53.20549361407757, 49.29966799914837, 49.80855189263821, 50.36274455487728, 53.656932190060616, 46.59561909735203, 55.36050617694855, 51.367064863443375, 49.91576313972473, 51.79351978003979, 47.1711590141058, 45.00685214996338, 46.20857946574688, 47.30789087712765, 48.48781116306782, 45.780673027038574, 46.744164526462555, 49.99344237148762, 58.93690086901188, 56.340219005942345, 62.51378193497658, 58.384114131331444, 60.36960259079933, 62.031553611159325, 56.72996789216995, 59.816249683499336, 62.50648632645607, 58.44184823334217, 56.40816695988178, 52.96089693903923, 53.9177767932415, 50.487100481987, 51.77681587636471, 52.687824591994286, 51.33292369544506, 54.97444309294224, 55.004522278904915, 52.00055547058582, 59.24454756081104, 60.49240060150623, 67.43299037218094, 60.39602257311344, 60.20526520907879, 64.8060317337513, 65.30606970191002, 58.66059869527817, 52.41633675992489, 52.08670064806938, 54.96166817843914, 64.46571439504623, 64.920853972435, 65.52190572023392, 65.48563286662102, 61.89839355647564, 63.97144451737404, 64.65336352586746, 66.80058270692825, 63.38380604982376, 61.23222090303898, 67.3624737560749, 74.10585790872574, 70.71389392018318, 68.06000232696533, 66.83345094323158, 73.77763912081718, 74.12739515304565, 74.4891357421875, 46.375766694545746, 0.29840870469342917, 2.5654850620776415, 70.02895787358284, 72.09290832281113, 58.40360328555107, 21.640450581908226, 47.36225076019764, 53.5806018859148, 59.92290996015072, 60.25718182325363, 53.08722876012325, 74.4589501619339, 68.05880159139633, 9.468781258910894, 0.43282598722726107, 0.3711283713346347, 0.2165119961136952, 0.22601583536015823, 0.15204189461655915, 0.1682431119843386, 0.19862395129166543], [0.08057467639446259, 0.048923050198936835, 0.024561019272368867, 0.03292479166702833, 0.03934458800358698, 0.07116208420484327, 0.050649185504880734, 0.03552193746145349, 0.25423960760235786, 0.0658729906717781, 19.517840780317783, 68.72965559363365, 46.06975011527538, 45.247614830732346, 26.483047530055046, 44.19967286288738, 20.312872119247913, 8.00433699041605, 31.40368279069662, 70.91161251068115, 57.15592123568058, 65.81252932548523, 12.680072542279959, 0.1287162525113672, 33.442780673503876, 67.7273377776146, 65.63772350549698, 64.12963762879372, 65.44364511966705, 63.76812502741814, 57.28241264820099, 52.862079441547394, 60.21351456642151, 58.71006824076176, 60.06120353937149, 56.071292236447334, 59.583603367209435, 55.653090476989746, 57.79859974980354, 54.335195794701576, 53.03170993924141, 48.447221741080284, 46.495399475097656, 43.12656484544277, 46.254530400037766, 50.5704528093338, 55.59552736580372, 60.76184794306755, 54.735090136528015, 52.66874581575394, 57.28651262819767, 58.44594821333885, 51.165599673986435, 45.74998587369919, 48.82400952279568, 50.39842464029789, 50.71544162929058, 47.12525747716427, 52.492496073246, 49.444938004016876, 46.18608467280865, 49.046020209789276, 47.380090802907944, 53.142299205064774, 51.12091027200222, 53.04778687655926, 53.581384643912315, 54.548048973083496, 53.8770467787981, 52.39824213087559, 52.191442027688026, 52.95901983976364, 48.09584319591522, 47.63025797903538, 45.60633458197117, 32.40536794066429, 39.96116749942303, 39.51902702450752, 40.379506051540375, 44.534879475831985, 44.353830590844154, 49.73032169044018, 43.57831500470638, 48.09480965137482, 51.43796145915985, 51.42609469592571, 51.34226739406586, 59.30199667811394, 50.86043804883957, 50.95629170536995, 55.1791001111269, 57.57378861308098, 55.05515456199646, 54.334371238946915, 51.86375521123409, 49.17789973318577, 44.930761232972145, 44.56308156251907, 42.00539320707321, 40.03850854933262, 41.43134281039238, 38.59457083046436, 40.13750843703747, 47.541262954473495, 50.39072625339031, 54.191293716430664, 47.55955897271633, 52.043819949030876, 56.839971989393234, 54.78096507489681, 56.13108202815056, 54.57738719880581, 55.82796089351177, 53.11528645455837, 52.27649286389351, 53.48385527729988, 51.00436292588711, 50.74914962053299, 51.283799931406975, 51.29221647977829, 54.23184514045715, 46.52240842580795, 51.34704373776913, 51.42310805618763, 47.52275414764881, 50.759804248809814, 55.644453540444374, 60.0893410295248, 57.43378512561321, 54.48184132575989, 58.44754792749882, 60.35938873887062, 55.68087838590145, 52.0440137386322, 46.95079363882542, 46.34600289165974, 51.96339726448059, 61.18124283850193, 61.462735533714294, 59.95487004518509, 61.9802525639534, 61.66049972176552, 63.38342987000942, 60.16429580748081, 60.87643079459667, 61.4915531873703, 64.41458433866501, 66.69230371713638, 63.97524431347847, 60.832828134298325, 59.688409343361855, 62.97410823404789, 64.42197114229202, 63.0616669356823, 13.237917758524418, 0.7582480064593256, 11.85600696131587, 66.631780564785, 54.28198724985123, 32.28031285107136, 11.655950546264648, 45.896034836769104, 34.168249145150185, 41.14967532455921, 38.239088505506516, 31.678398549556732, 37.43554562330246, 66.65465533733368, 10.884920619428158, 0.10814284280058928, 0.24619790317956358, 0.0594935968547361, 0.061008405609754845, 0.04729709369712509, 0.057067148736678064, 0.07462557608960196, 0.0673293590079993, 0.06212281085026916, 0.022836885909782723, 0.07350995743763633, 0.02966279844258679, 0.014337526845338289, 0.05783480402897112, 0.056106149131665006, 0.3037616971414536, 0.21910638111876324, 24.183044247329235, 75.73089390993118, 53.23153741657734, 49.95013989508152, 29.290277995169163, 50.920151844620705, 34.41444173455238, 17.267909310758114, 34.093001782894135, 79.61939245462418, 62.9561085999012, 76.7595063149929, 18.06104265153408, 0.0951140395773109, 29.175670444965363, 69.5662871003151, 70.43029993772507, 71.27538979053497, 70.71667537093163, 69.33042615652084, 62.20076613128185, 57.685631811618805, 62.2387108951807, 64.1678635776043, 62.93277405202389, 61.454888954758644, 61.25392533838749, 59.36237543821335, 59.83051411807537, 57.38037899136543, 56.51026368141174, 50.147056728601456, 49.90882471203804, 48.11410881578922, 49.999297857284546, 54.17336627840996, 56.65901429951191, 62.2112687677145, 55.17720781266689, 53.780482560396194, 58.30976352095604, 61.82513728737831, 54.3284397572279, 49.51285935938358, 50.69407157599926, 52.33586847782135, 51.955991461873055, 49.90939848124981, 53.039697110652924, 51.35687381029129, 50.31827934086323, 52.20992423593998, 49.8886363953352, 54.78297896683216, 54.65646855533123, 57.44348980486393, 55.499791502952576, 57.46601119637489, 56.954528242349625, 56.91730163991451, 56.45147703588009, 55.48401854932308, 51.24541439116001, 47.05260917544365, 49.42335516214371, 36.4114435762167, 41.056998297572136, 43.301328867673874, 42.77175508439541, 46.5764719247818, 44.91693377494812, 48.45530390739441, 44.32055577635765, 48.457777574658394, 50.14921121299267, 53.65697778761387, 49.53248530626297, 57.396201342344284, 51.49410344660282, 48.88831727206707, 55.24235151708126, 58.29679861664772, 53.90006214380264, 56.19519978761673, 52.04213663935661, 48.48583906888962, 45.46945832669735, 45.24267129600048, 42.44508281350136, 42.657992988824844, 43.05272340774536, 41.43738068640232, 41.97703532874584, 47.840990871191025, 49.033078104257584, 55.363967791199684, 50.38901634514332, 55.47123983502388, 58.081847950816154, 56.47573493421078, 57.2226532548666, 57.12070852518082, 59.32214319705963, 55.981639847159386, 55.339949280023575, 55.580423176288605, 53.86302173137665, 53.691221550107, 54.652425572276115, 54.061656072735786, 54.78323355317116, 48.694007098674774, 54.915477856993675, 54.194363951683044, 49.68649484217167, 52.44015008211136, 58.32647502422333, 61.06130987405777, 60.828522965312004, 57.651399448513985, 61.14101439714432, 63.57229873538017, 59.78153094649315, 54.153983518481255, 49.33501370251179, 46.95870481431484, 52.911309599876404, 63.422381579875946, 63.57243552803993, 62.719430699944496, 63.313502222299576, 62.87800759077072, 65.1310282945633, 64.12288919091225, 61.87699310481548, 59.67871606349945, 65.48837631940842, 72.86261782050133, 65.111915320158, 65.24646610021591, 64.8991647362709, 67.54133775830269, 68.73625203967094, 67.2258710861206, 13.691446222364902, 0.6060415331739932, 15.359380021691322, 74.51780140399933, 57.51825079321861, 40.901297852396965, 10.905813798308372, 43.968299478292465, 51.50665417313576, 51.821816861629486, 38.79572443664074, 35.664251670241356, 43.912518471479416, 76.01410791277885, 19.13156110793352, 0.2629981079371646, 0.20924028474837542, 0.01420432339727995, 0.033570823798072524, 0.10159043580642901, 0.04411614856508095, 0.036342815874377266, 0.272143593756482, 0.2683429961325601, 0.13030857488047332, 0.25233668158762157, 0.21613807242829353, 0.14436842902796343, 0.11630511653493159, 0.12438921243301593, 0.37510465015657246, 0.29949764313641936, 27.31131188571453, 89.97088819742203, 61.945545226335526, 62.886500135064125, 32.90589228272438, 66.50772482156754, 28.40932946652174, 15.518099404871464, 44.27848443388939, 83.00573274493217, 71.13236546516418, 80.46105489134789, 15.89464969933033, 0.2100710300146602, 43.7683542072773, 74.75909605622292, 75.24395003914833, 72.21334666013718, 73.66303727030754, 68.76294180750847, 61.617862209677696, 60.5142418295145, 66.15742921829224, 63.77038210630417, 68.31444427371025, 64.47358757257462, 65.87797701358795, 59.774284735322, 62.568043023347855, 59.81894753873348, 61.09948642551899, 54.50375854969025, 54.570190384984016, 49.67950701713562, 52.54546523094177, 55.972026363015175, 57.88007877767086, 64.6624906361103, 58.56781147420406, 54.86914314329624, 61.15848205983639, 63.736301735043526, 57.992298156023026, 51.778932362794876, 52.957720309495926, 55.567370876669884, 54.39254991710186, 52.16731332242489, 57.635998874902725, 52.50419184565544, 52.17506870627403, 53.9763430505991, 50.725864470005035, 57.838201224803925, 55.86312420666218, 58.626655116677284, 59.745212495326996, 61.241169422864914, 57.72282041609287, 55.049249678850174, 60.21489389240742, 58.42940770089626, 50.69381318986416, 49.37278747558594, 52.896501794457436, 39.64080668985844, 45.51341816782951, 45.47315172851086, 46.85409262776375, 50.14782428741455, 46.77021972835064, 51.30767025053501, 45.687281638383865, 49.86352354288101, 52.048733085393906, 54.905024617910385, 51.981210708618164, 60.56406855583191, 52.17576026916504, 52.82297573983669, 56.29364870488644, 63.30198124051094, 56.83711834251881, 59.10690374672413, 55.466357097029686, 51.411811262369156, 46.2416110932827, 46.24776676297188, 44.749028384685516, 45.424958914518356, 46.62452794611454, 45.7892719656229, 43.20160701870918, 49.842233285307884, 52.090819627046585, 58.82967822253704, 54.52104762196541, 59.71497371792793, 62.04179406166077, 60.55116064846516, 59.660746827721596, 59.41037446260452, 61.374660059809685, 60.05806490778923, 59.215900897979736, 56.948611959815025, 58.2206355035305, 56.67556241154671, 57.121179699897766, 54.69023734331131, 59.55554947257042, 49.98841904103756, 58.32920327782631, 56.74746975302696, 53.08281719684601, 56.705599799752235, 60.58983877301216, 63.14843147993088, 61.77566014230251, 60.43652839958668, 66.15417659282684, 66.22043743729591, 61.352974623441696, 56.74487829208374, 52.44005508720875, 49.846872836351395, 55.4781174659729, 69.37303707003593, 66.56944870948792, 67.69536629319191, 66.8007043004036, 66.28510236740112, 69.20458450913429, 66.82359427213669, 65.50837844610214, 61.835567727684975, 64.80915516614914, 75.97975015640259, 71.63539007306099, 68.98494869470596, 68.48620265722275, 69.95383590459824, 69.15758863091469, 73.68266701698303, 20.712479576468468, 0.9826952533330768, 14.625651743263006, 82.1406027674675, 65.03123804926872, 49.7982582449913, 21.53717402368784, 58.86584088206291, 45.239031091332436, 56.243483796715736, 51.00960664451122, 43.659866228699684, 53.71951103210449, 85.82702055573463, 28.950830809772015, 0.39963666815310717, 0.2934998134151101, 0.16983178298687562, 0.1833535503828898, 0.2376084789284505, 0.17966540297493339, 0.20889592822641134], [0.049094452915596776, 0.10627770694554783, 0.06569202538230456, 0.03216539647837635, 0.023254162151715718, 0.1430284368689172, 0.12603775248862803, 0.025769996391318273, 0.20025611214805394, 0.11068008243455552, 16.782076880335808, 65.61190769076347, 43.72967608273029, 50.40488809347153, 33.93554203212261, 42.52326741814613, 40.40823630988598, 12.932321056723595, 24.511029347777367, 66.27529889345169, 62.565907537937164, 56.518292650580406, 55.055956318974495, 2.305710813961923, 3.2010558201000094, 49.65029418468475, 62.39654302597046, 64.93810504674911, 61.89326003193855, 62.46558912098408, 52.787759229540825, 57.161396741867065, 58.118420988321304, 59.21275086700916, 56.949478313326836, 57.181436866521835, 54.98297743499279, 58.71024303138256, 56.19529478251934, 54.295218139886856, 51.59474864602089, 48.1621116399765, 43.52572962641716, 46.49384915828705, 50.457579866051674, 54.204011633992195, 57.868987172842026, 58.3328852802515, 56.76308311522007, 55.820167511701584, 57.37078830599785, 59.043306559324265, 50.74384890496731, 46.0670180618763, 44.02219198644161, 49.04051050543785, 50.560816526412964, 47.1649881452322, 46.204038709402084, 51.678807735443115, 50.706424713134766, 51.85473449528217, 51.59537561237812, 49.92411129176617, 53.03368583321571, 54.37923543155193, 55.398200154304504, 54.130804762244225, 55.86328759789467, 52.45681218802929, 51.40643835067749, 50.75133830308914, 47.38927111029625, 42.70884566009045, 40.58835804462433, 43.17894123494625, 45.90937212109566, 37.97751434147358, 41.578087136149406, 40.463842526078224, 43.36699314415455, 44.97723653912544, 46.15747220814228, 47.07825019955635, 52.42079772055149, 56.062142327427864, 58.61367121338844, 58.95576685667038, 55.382035821676254, 46.19380585849285, 55.87765082716942, 58.75047527253628, 55.26207625865936, 54.7114934027195, 52.20211185514927, 49.28204834461212, 44.557028487324715, 44.3811359256506, 42.72850960493088, 41.01449757814407, 41.12181901931763, 40.31753897666931, 41.31365932524204, 41.01005561649799, 44.36393424868584, 51.0580350458622, 54.3061463534832, 46.63476079702377, 51.83042719960213, 58.55940252542496, 56.05561427772045, 54.069476053118706, 53.67070645093918, 54.370780885219574, 54.030965119600296, 53.368428871035576, 51.98452793061733, 51.698239892721176, 51.041619926691055, 53.15285883843899, 45.918297842144966, 47.85903610289097, 52.42184266448021, 50.814350321888924, 46.07085585594177, 48.124117478728294, 55.91750308871269, 59.21324484050274, 58.56958597898483, 53.229724913835526, 57.728284522891045, 61.652409955859184, 59.659124314785004, 57.58179098367691, 51.454224586486816, 45.605586022138596, 44.93795044720173, 53.42076726257801, 57.71012529730797, 58.69669295847416, 59.73613478243351, 59.912772104144096, 58.683971241116524, 62.25751228630543, 63.33173364400864, 59.754438400268555, 60.225939899683, 64.73148733377457, 62.90207929909229, 59.30791296064854, 64.31368455290794, 61.78118884563446, 68.90518337488174, 46.20815768837929, 2.067813891917467, 0.05143072638020385, 28.79901945590973, 64.7141070663929, 53.064300790429115, 29.52491920441389, 16.566898226737976, 26.04043398052454, 16.241329796612263, 47.97433331608772, 25.427146889269352, 31.292458958923817, 61.34425029158592, 57.29167655110359, 26.65717128664255, 0.5865780275780708, 0.15662355814129114, 0.0320569612813415, 0.12853001797338948, 0.07906052444013767, 0.058489259536145255, 0.10894550519878976, 0.082918089319719, 0.015176456145127304, 0.030401279909710865, 0.04177866911049932, 0.059945887624053285, 0.1023125603387598, 0.0110149029387685, 0.029534481109294575, 0.2218296771752648, 0.13090768101392314, 19.730952344834805, 76.69722765684128, 47.60894492268562, 54.164402559399605, 33.81159268319607, 51.758504658937454, 36.93822830915451, 24.79250494390726, 34.572973027825356, 70.67143499851227, 72.73539304733276, 59.82584036886692, 67.68359452486038, 3.267806600779295, 1.6960374475456774, 47.404531091451645, 65.79053610563278, 71.67997688055038, 65.70484310388565, 65.0547131896019, 56.019311025738716, 60.90144485235214, 62.76958040893078, 63.54609914124012, 62.17977225780487, 60.1772341132164, 57.41763599216938, 60.07562376558781, 58.71239751577377, 57.19809517264366, 54.02200900018215, 51.78766809403896, 47.41107054054737, 51.17172874510288, 52.84621149301529, 55.110597386956215, 58.19101229310036, 61.6221521794796, 57.014348432421684, 57.2673274576664, 59.305310100317, 60.519850328564644, 54.52619254589081, 48.388275504112244, 48.990691378712654, 51.90405584871769, 53.14006492495537, 49.03866000473499, 49.417727664113045, 54.949546828866005, 54.82051335275173, 54.73258227109909, 52.63137862086296, 52.950721085071564, 56.36452630162239, 57.194823548197746, 56.43170289695263, 56.67146623134613, 55.987882912158966, 54.74841982126236, 53.764113038778305, 52.218975350260735, 47.909926772117615, 44.95493933558464, 43.417652025818825, 44.15242239832878, 46.99476107954979, 39.96801473200321, 42.52291403710842, 41.98759116232395, 45.05329325795174, 43.99392530322075, 46.322026178240776, 45.983167961239815, 52.95224480330944, 54.904982820153236, 56.43340140581131, 59.43480335175991, 54.59433048963547, 45.24880416691303, 55.507516488432884, 58.225259855389595, 57.29175254702568, 54.770017862319946, 52.545123249292374, 47.17273972928524, 45.04513889551163, 44.17068421840668, 44.222707226872444, 42.62995429337025, 42.514444291591644, 41.37197479605675, 42.46211349964142, 39.880988001823425, 43.53910110890865, 51.52231693267822, 55.12741148471832, 51.23179592192173, 53.96883465349674, 60.015074014663696, 58.56793686747551, 56.08116790652275, 54.18241359293461, 56.31471857428551, 58.236716240644455, 55.11815898120403, 54.99222993850708, 55.14434717595577, 55.068571642041206, 57.825107127428055, 45.80735519528389, 51.11138418316841, 52.89505787193775, 53.74863266944885, 49.27903890609741, 51.21861822903156, 58.83879393339157, 62.340853214263916, 62.57200241088867, 55.948642417788506, 59.531390368938446, 63.56236606836319, 61.60688079893589, 60.06969228386879, 54.26814079284668, 48.87824401259422, 49.54214058816433, 54.75585602223873, 62.25583277642727, 61.85384474694729, 62.55222447216511, 61.89914591610432, 62.33058616518974, 64.59072768688202, 65.49870416522026, 62.54683256149292, 63.9604327082634, 67.8159262239933, 66.42809629440308, 64.6861481666565, 68.21653112769127, 66.86469286680222, 72.85434946417809, 41.67329862713814, 1.6010493133217096, 0.11314616494928487, 35.44034108519554, 71.95572048425674, 57.76454597711563, 38.05568374693394, 16.180552057921886, 28.78354098647833, 18.536079861223698, 57.85110153257847, 29.68522310256958, 38.56960617005825, 77.587611079216, 58.061731830239296, 45.54788611829281, 0.7232239202130586, 0.1481602544663474, 0.06029478237906005, 0.043778148537967354, 0.033537464260007255, 0.05939271301031113, 0.05937149871897418, 0.18387294985586777, 0.19371506001334637, 0.21412248839624226, 0.22395355539629236, 0.13606017484562472, 0.21008093026466668, 0.18749270093394443, 0.16103423084132373, 0.40805455239024013, 0.24778359074844047, 24.06189914792776, 86.84566229581833, 57.53731817007065, 68.95817533135414, 41.54805734753609, 60.356212109327316, 54.81606759130955, 20.16276117414236, 42.93291583657265, 75.74243009090424, 76.09088659286499, 67.42034465074539, 73.32321390509605, 2.3187312902882695, 4.54655815847218, 59.68138352036476, 68.56909140944481, 75.423574000597, 67.47304782271385, 68.53279575705528, 59.147709757089615, 64.11884620785713, 64.52964216470718, 67.84562543034554, 63.76417323946953, 64.00818094611168, 59.61351536214352, 65.4974502325058, 62.73542784154415, 59.28729146718979, 57.922761887311935, 54.513755813241005, 48.17436218261719, 54.322135895490646, 54.5059510320425, 57.88478672504425, 60.33445447683334, 65.32429352402687, 58.58582630753517, 56.46522469818592, 62.99225606024265, 62.768968641757965, 56.20385952293873, 50.599456652998924, 49.40538972616196, 55.1273050904274, 57.101686745882034, 51.983741372823715, 51.735318303108215, 57.40212522447109, 56.9249202311039, 57.54668086767197, 55.74748881161213, 55.972619131207466, 59.46200609207153, 62.80104652047157, 59.559782445430756, 57.956059500575066, 63.162878304719925, 61.43946938216686, 56.655640080571175, 55.842077136039734, 52.04136148095131, 47.576342672109604, 45.2350565046072, 44.61399123072624, 49.48694474995136, 43.68327297270298, 46.70745849609375, 47.10889175534248, 48.33087958395481, 48.292026668787, 48.151806592941284, 48.487130999565125, 55.07652461528778, 57.78539165854454, 59.73590299487114, 59.82000768184662, 57.11974337697029, 45.72434864938259, 57.247439324855804, 61.16315960884094, 60.02058371901512, 57.974066734313965, 55.35184644162655, 50.963131338357925, 47.16317184269428, 48.5084592550993, 49.03906278312206, 45.56955635547638, 46.15001320838928, 44.24591638147831, 46.181585714221, 42.041616663336754, 44.227183386683464, 57.00411178171635, 59.15471278131008, 57.19510093331337, 60.78676700592041, 64.16119873523712, 61.3804167509079, 60.495189651846886, 59.18618269264698, 59.499525278806686, 58.61362561583519, 59.54453006386757, 57.573306038975716, 56.67438067495823, 56.34107396006584, 58.65244433283806, 48.906525894999504, 53.540343046188354, 56.54006168246269, 56.48140802979469, 52.38810047507286, 53.334838673472404, 62.25213557481766, 64.50223043560982, 66.0927414894104, 57.48160555958748, 62.89378434419632, 67.05351233482361, 64.91106569766998, 61.20113857090473, 56.684222146868706, 50.842590406537056, 51.554398611187935, 59.257960841059685, 65.64764857292175, 64.87325012683868, 65.05245611071587, 64.07990589737892, 63.286652863025665, 69.45512026548386, 68.95598664879799, 65.35709336400032, 66.750797778368, 71.85798972845078, 68.13938766717911, 67.42846861481667, 73.07129502296448, 69.76452246308327, 76.67968779802322, 54.64447259902954, 4.099162090569735, 0.29048470489215106, 36.82652190327644, 78.05534318089485, 66.6086246073246, 43.585359826684, 29.427954107522964, 33.89657512307167, 24.248807318508625, 64.63098272681236, 43.77734452486038, 42.1527075022459, 75.94881221652031, 72.08354562520981, 52.12040103971958, 1.1766479490324855, 0.3023119561839849, 0.1308473592507653, 0.33863509772345424, 0.13550449919421226, 0.1763196973479353, 0.1878321444382891], [0.022280991324805655, 0.07682844850933179, 0.12673934921622276, 0.08200197480618954, 0.032630960558890365, 0.030435613516601734, 0.1456522406078875, 0.0803251366596669, 0.5035770626273006, 0.44082194566726685, 23.74519184231758, 74.78811129927635, 48.68176035583019, 44.235159158706665, 34.29744601249695, 41.07913210988045, 48.83698582649231, 24.81070786714554, 8.735031131654978, 53.73754866421223, 65.06885603070259, 56.08981244266033, 60.41432999074459, 25.89062511920929, 0.6339223589748144, 13.645918015390635, 50.32826140522957, 64.71741288900375, 60.31322881579399, 63.667871206998825, 52.57792688906193, 60.72464793920517, 55.69926179945469, 61.87298431992531, 55.77296644449234, 57.86209434270859, 55.10511428117752, 58.46876218914986, 52.36796535551548, 53.86251635849476, 48.08765463531017, 45.729995146393776, 45.895290076732635, 47.706850469112396, 49.41071704030037, 56.36200323700905, 56.82076022028923, 57.8348384052515, 53.94108094274998, 61.40972077846527, 57.977581545710564, 57.35278867185116, 53.05651120841503, 47.3778223246336, 45.02446040511131, 51.05225555598736, 49.79384288191795, 51.15599378943443, 45.75418844819069, 48.01079995930195, 52.91309550404549, 52.34434962272644, 50.65874487161636, 51.2604995816946, 52.37332306802273, 52.606375962495804, 53.45373809337616, 49.25019845366478, 46.072504967451096, 46.609104573726654, 49.58780653774738, 44.80459280312061, 49.7473219782114, 36.91062659025192, 35.6112103164196, 41.19921326637268, 45.81806682050228, 48.841218799352646, 41.44818350672722, 39.95566539466381, 44.76027198135853, 43.679993748664856, 44.711091220378876, 47.592894583940506, 53.579891324043274, 56.42604120075703, 59.87117953598499, 63.57978813350201, 53.62222105264664, 44.078877344727516, 56.95676252245903, 64.19905230402946, 59.742647632956505, 57.82186210155487, 54.07851576805115, 49.080689549446106, 44.15391191840172, 41.70407697558403, 41.47932283580303, 38.25864605605602, 39.671136662364006, 42.26142726838589, 44.15602460503578, 49.87146511673927, 47.30504482984543, 46.39543443918228, 49.33179907500744, 51.42523214221001, 48.190917894244194, 48.63343454897404, 53.96783530712128, 54.92770180106163, 53.739323168992996, 53.7296336889267, 52.755696550011635, 54.187873899936676, 53.718853667378426, 51.75678335130215, 54.01692867279053, 52.62147635221481, 46.98438003659248, 48.42327542603016, 50.36645695567131, 50.162894278764725, 46.953483894467354, 49.95393589138985, 56.101656407117844, 59.71697621047497, 60.94373658299446, 54.723728746175766, 54.470229148864746, 61.148549392819405, 59.70114625990391, 58.1922510266304, 56.453430131077766, 50.963541716337204, 44.87716130912304, 45.407844632864, 50.80914460122585, 53.29200357198715, 57.25522130727768, 56.84031397104263, 63.48755568265915, 58.884064704179764, 59.84983988106251, 61.511262729763985, 61.60815753042698, 62.793211340904236, 63.27391974627972, 57.13605970144272, 59.91551175713539, 63.28802078962326, 64.30128961801529, 13.116689063608646, 0.1491985487518832, 0.13350880471989512, 32.35124744474888, 63.273136988282204, 53.358944579958916, 28.27847968786955, 12.025456968694925, 49.170531928539276, 67.47901350259781, 34.89542752504349, 36.77771732211113, 26.519301384687424, 51.97931841015816, 53.03188472986221, 61.66345976293087, 2.677323273383081, 0.18216215103166178, 0.10176309646340087, 0.030610675021307543, 0.04784584882145282, 0.02960934154543793, 0.08013340280740522, 0.059160027449252084, 0.07685083910473622, 0.02365753796766512, 0.1254053387674503, 0.03759704173717182, 0.03496153061860241, 0.09222659529768862, 0.056968595235957764, 0.3780345304403454, 0.541475338395685, 26.528211906552315, 86.19507640600204, 51.70336961746216, 53.736621513962746, 40.95920294523239, 51.20986729860306, 44.736884236335754, 23.55697464197874, 23.411244861781597, 50.61973996460438, 75.68949893116951, 59.08335641026497, 69.98323112726212, 32.83929705619812, 0.5907877860590816, 10.176944509148598, 46.70666813850403, 67.37684458494186, 66.47075280547142, 65.46981051564217, 57.46560841798782, 61.70393519103527, 61.22538506984711, 65.04962146282196, 59.13185700774193, 60.52440628409386, 56.576250940561295, 60.073435083031654, 55.51504388451576, 55.639996379613876, 52.72217094898224, 48.83510112762451, 49.57722790539265, 49.60404686629772, 53.67452524602413, 57.52281814813614, 59.14232924580574, 58.834655955433846, 56.66453540325165, 60.83928018808365, 60.29498219490051, 61.72366753220558, 55.63235878944397, 50.41085757315159, 47.56697617471218, 52.943930849432945, 51.990482211112976, 53.065098747611046, 48.62939536571503, 51.2715569883585, 57.33408607542515, 53.415899723768234, 53.711717650294304, 54.66282181441784, 56.13924778997898, 54.21330213546753, 55.96682444214821, 53.706633523106575, 48.59451323747635, 47.521796599030495, 47.199456095695496, 47.466650158166885, 49.25037704408169, 41.150868460536, 38.01148071885109, 44.84397388994694, 45.303559228777885, 52.13040590286255, 41.05805464088917, 42.627628818154335, 45.91991275548935, 45.33730521798134, 44.829401671886444, 48.4271702170372, 53.14169883728027, 56.9130002707243, 60.31094893813133, 61.12936422228813, 52.74695701897144, 43.32779444754124, 54.411180317401886, 63.31642806529999, 59.014416709542274, 58.854696080088615, 52.35181242227554, 47.577045634388924, 45.85570380091667, 46.08581945300102, 42.68396079540253, 39.811451733112335, 42.3603929579258, 42.80233584344387, 43.144336491823196, 48.19747254252434, 46.73014707863331, 44.179780930280685, 49.842199087142944, 53.6233913898468, 52.80817933380604, 53.11845548450947, 57.05887444317341, 56.969313248991966, 57.485272362828255, 56.476392298936844, 55.86532048881054, 56.92124962806702, 57.218405082821846, 55.77244967222214, 56.2902706861496, 54.5475360006094, 50.282698050141335, 49.25426043570042, 52.491549924016, 51.645175740122795, 48.824283108115196, 52.16083467006683, 58.91729772090912, 59.32032689452171, 62.502481341362, 58.45208868384361, 57.98456557095051, 60.675482377409935, 60.41124455630779, 61.30096301436424, 58.43760386109352, 51.959000900387764, 47.39604614675045, 47.03424096107483, 51.61528654396534, 55.15245594084263, 58.4131483733654, 59.32737551629543, 65.98011553287506, 64.43727672100067, 65.00351473689079, 63.32541458308697, 65.70124089717865, 65.69727391004562, 65.72055906057358, 64.17657271027565, 64.54177871346474, 66.92809626460075, 65.10208904743195, 10.365021117031574, 0.10765033133793622, 0.4211600491544232, 40.639085322618484, 65.51543846726418, 62.76144504547119, 32.314062640070915, 17.756960168480873, 51.9870699942112, 46.82219333946705, 48.0894785374403, 46.57439723610878, 25.642046257853508, 64.37065869569778, 56.37908332049847, 78.85803490877151, 4.028615551069379, 0.22529198904521763, 0.18639926507603377, 0.03796184442762751, 0.027930952310271095, 0.030312758390209638, 0.050845079094870016, 0.19880859763361514, 0.13002691499423236, 0.2015761553775519, 0.24301584111526608, 0.19968082895502448, 0.11310907240840606, 0.3444343584123999, 0.1519892763462849, 0.6255983118899167, 0.7947876770049334, 30.913115814328194, 94.46294635534286, 63.976209461688995, 59.252850115299225, 46.454384475946426, 54.40483085811138, 65.66049188375473, 36.468972489237785, 20.60396309942007, 68.93342345952988, 75.50071746110916, 72.0887741446495, 75.04281923174858, 33.55729132890701, 0.6705101800616831, 19.012838378548622, 55.45842692255974, 76.11709758639336, 68.86520192027092, 69.6227976679802, 60.47768019139767, 65.25347292423248, 64.03816893696785, 69.21011701226234, 61.79697699844837, 64.84897702932358, 59.83673818409443, 64.94165405631065, 58.582467287778854, 59.20569084584713, 55.12454643845558, 52.28072963654995, 53.62814113497734, 54.527974650263786, 55.08984290063381, 60.537549778819084, 60.616323351860046, 61.91428430378437, 57.07474239170551, 63.10740888118744, 63.00580993294716, 65.63144624233246, 59.15250509977341, 53.603089079260826, 49.147900342941284, 56.381594985723495, 53.054413720965385, 56.941057965159416, 48.586184084415436, 53.342453464865685, 58.83450776338577, 58.00063110888004, 55.665352419018745, 57.473276406526566, 57.9610600322485, 56.872661635279655, 58.91687214374542, 57.248408272862434, 50.86679130792618, 55.3813024610281, 53.81666041910648, 50.47813296318054, 49.05655324459076, 41.42823837697506, 42.50974394381046, 50.45192576944828, 48.86571228504181, 51.5216101706028, 45.59064902365208, 47.707929611206055, 49.50396403670311, 50.82628548145294, 47.77428925037384, 49.05473694205284, 55.101610869169235, 58.73132050037384, 63.917571008205414, 65.90019822120667, 55.53641013801098, 43.01565259695053, 58.65795783698559, 67.40551024675369, 63.66972170770168, 63.386511504650116, 55.4536771774292, 51.04146793484688, 49.7738141566515, 48.072683438658714, 46.17287278175354, 41.723547130823135, 45.56261792778969, 46.62027597427368, 45.83770416676998, 50.73623791337013, 48.20879593491554, 47.54734642803669, 53.83403308689594, 54.31384094059467, 54.95760999619961, 57.101139575242996, 61.92778117954731, 60.48142299056053, 58.45320202410221, 58.14561992883682, 57.68677555024624, 59.35963198542595, 59.9228947609663, 56.613329350948334, 59.51808728277683, 56.90413914620876, 51.65432944893837, 54.390737414360046, 56.70297794044018, 56.08214445412159, 51.826840192079544, 54.821296110749245, 60.99675513803959, 63.14880006015301, 65.67113131284714, 60.302349999547005, 60.615430399775505, 64.83237192034721, 63.946814239025116, 61.729697808623314, 61.94581501185894, 54.56088848412037, 49.89308215677738, 49.32736471295357, 56.47139556705952, 58.8974741846323, 61.22809052467346, 63.35276551544666, 70.63374102115631, 65.9500515460968, 67.68585920333862, 66.99510186910629, 69.75548654794693, 67.66271844506264, 70.73786303400993, 66.10995456576347, 71.43475323915482, 70.62246322631836, 75.65144017338753, 17.32289806008339, 0.32972546643577516, 0.5508608347736299, 43.051062896847725, 75.5001474916935, 65.05130097270012, 42.13417589664459, 25.71975778788328, 64.11646753549576, 84.46249097585678, 53.325354382395744, 55.20673222839832, 34.584858790040016, 66.90416514873505, 66.41037404537201, 89.37349185347557, 5.932463491335511, 0.4915779299335554, 0.26912067783996463, 0.16529369837371632, 0.14747747860383242, 0.2591643511550501, 0.2158145108842291], [0.06513070940854959, 0.03113521757768467, 0.028043278216500767, 0.2812548814108595, 0.06355569392326288, 0.25908969109877944, 0.08062699780566618, 0.011772366688092006, 0.5193202709779143, 0.31319555186200887, 23.439281657338142, 72.37764984369278, 44.72808390855789, 43.448650762438774, 26.934573501348495, 41.11804202198982, 22.84430008381605, 72.40042582154274, 4.898376055061817, 12.691307589411736, 54.440643936395645, 60.55076166987419, 46.70637175440788, 50.14694653451443, 3.9420906314626336, 0.36146528203971684, 17.23072450608015, 41.7439254373312, 56.41585774719715, 59.94654469192028, 56.978265568614006, 56.21094614267349, 58.924342542886734, 58.49382944405079, 57.498434856534004, 60.27079649269581, 59.15166914463043, 56.904256939888, 51.94872245192528, 48.277921825647354, 45.047623962163925, 47.569981813430786, 47.625101655721664, 55.62665909528732, 56.144225522875786, 53.70310351252556, 57.16900773346424, 55.169653818011284, 56.53872795403004, 57.58451543748379, 56.91379822790623, 56.010024324059486, 49.205303862690926, 46.24084733426571, 45.142903849482536, 50.231503397226334, 52.517460733652115, 54.38173569738865, 58.77019241452217, 55.20598366856575, 54.302813932299614, 52.01846770942211, 53.17358672618866, 53.545290380716324, 54.326593056321144, 51.846177354454994, 49.96807113289833, 41.977251917123795, 44.17574554681778, 42.653923407197, 43.177702501416206, 44.810425490140915, 32.186917662620544, 22.155210860073566, 18.937490321695805, 27.900149188935757, 25.129892639815807, 36.004325821995735, 48.340831249952316, 40.85033878684044, 39.29793208837509, 38.96571971476078, 43.41715045273304, 45.8000747859478, 56.984216049313545, 62.149487882852554, 55.445948392152786, 62.19332613050938, 47.95492775738239, 45.08208431303501, 55.627320259809494, 62.663296312093735, 58.689537942409515, 61.00127309560776, 56.6791570186615, 48.20029579102993, 41.3279427587986, 38.017446398735046, 37.831818759441376, 39.519372805953026, 40.66965848207474, 45.096295550465584, 51.04524873197079, 43.22542794048786, 43.11822809278965, 34.46704611182213, 35.73102928698063, 38.687441647052765, 49.819852486252785, 52.07030452787876, 50.046194940805435, 52.98146143555641, 53.63346844911575, 56.84886731207371, 56.022955030202866, 54.244426265358925, 52.94355466961861, 52.23132848739624, 52.29066230356693, 50.62926985323429, 47.79292345046997, 44.0837524831295, 46.32285073399544, 44.960620030760765, 45.206463038921356, 48.93388822674751, 57.162373289465904, 57.58030526340008, 61.946240589022636, 55.66083446145058, 58.07961747050285, 56.97915852069855, 80.0947393476963, 78.67208808660507, 59.762087389826775, 58.32609884440899, 47.33788266777992, 48.24642911553383, 48.239266499876976, 50.23366168141365, 51.961774751544, 55.92718876898289, 58.278289809823036, 60.07893718779087, 57.40847088396549, 61.30650691688061, 56.92939639091492, 63.14399711787701, 63.36465887725353, 61.351105123758316, 55.80118753015995, 60.25071457028389, 29.1721024364233, 0.7342746178619564, 0.026391767714812886, 1.9995260937139392, 52.2874590754509, 62.24573291838169, 51.751687824726105, 17.07746922969818, 8.433621805161238, 65.28522402048111, 94.07172694802284, 20.78965913504362, 39.44816842675209, 39.263950511813164, 36.6703312844038, 49.409949481487274, 60.774869844317436, 4.239437263458967, 0.10612349607981741, 0.18111357057932764, 0.04100399681192357, 0.06549180878209881, 0.07161538058426231, 0.10646164082572795, 0.07725036688498221, 0.03981480906077195, 0.05990418263536412, 0.1748382963705808, 0.1946966245304793, 0.10593256374704652, 0.0782015775621403, 0.01834859012888046, 0.5416402139235288, 0.3636057546827942, 27.937620878219604, 78.87023225426674, 51.91012032330036, 53.57008405029774, 31.90215714275837, 47.866715490818024, 30.712216794490814, 59.35712791979313, 6.638170648366213, 15.708706676959991, 54.376355186104774, 68.12550321221352, 50.40960744023323, 62.038138657808304, 6.205230904743075, 0.27384305256418884, 12.921080309897661, 39.25841800868511, 61.13784916698933, 64.84928101301193, 57.586700320243835, 58.04442755877972, 62.25407727062702, 60.705401971936226, 61.07288405299187, 63.26555639505386, 62.118660137057304, 59.07915763556957, 55.07538467645645, 51.56297095119953, 49.351003244519234, 50.64766086637974, 48.00031632184982, 56.18666164577007, 57.1799473464489, 53.44891615211964, 58.16579684615135, 57.937854677438736, 58.97435545921326, 60.7997927069664, 58.8385621458292, 56.127863600850105, 51.36424541473389, 49.13444146513939, 48.9018939435482, 53.65013815462589, 54.27710071206093, 57.29637689888477, 59.07053589820862, 56.497401371598244, 56.73705451190472, 54.52586196362972, 56.314862966537476, 57.17898979783058, 57.129273265600204, 56.68380416929722, 51.668593883514404, 46.20622739195824, 45.60330994427204, 42.49397858977318, 44.2725795507431, 44.28150527179241, 33.71497146785259, 26.99649877846241, 30.66883072257042, 40.539895445108414, 37.82812535762787, 38.19699056446552, 49.81011740863323, 40.56502729654312, 41.700094789266586, 39.551906660199165, 45.075408071279526, 45.30757561326027, 54.915519654750824, 61.11212454736233, 58.080278635025024, 61.61735683679581, 47.791084349155426, 42.21489116549492, 55.79014152288437, 63.08384634554386, 58.05846780538559, 58.693276941776276, 56.56412959098816, 49.804486110806465, 42.413916885852814, 39.68614585697651, 39.99037653207779, 40.62677778303623, 41.509930193424225, 42.93581888079643, 48.8949441164732, 51.65705390274525, 52.02347204089165, 43.11605840921402, 40.68422310054302, 39.042213410139084, 50.908927246928215, 53.45286414027214, 54.53101448714733, 57.664862126111984, 53.54199215769768, 57.79526732861996, 58.344265669584274, 56.87899969518185, 55.51257401704788, 53.70650812983513, 53.58892723917961, 51.43247835338116, 48.24495479464531, 45.87186813354492, 49.74928267300129, 46.529415249824524, 45.5018325895071, 50.143496319651604, 58.79159666597843, 60.44518053531647, 63.03241230547428, 60.16289368271828, 58.041725903749466, 60.457484275102615, 72.38388910889626, 74.78411391377449, 63.82433161139488, 58.820171132683754, 50.480751022696495, 48.91666755080223, 51.88773192465305, 51.952013075351715, 55.91975636780262, 59.89136025309563, 63.0735868960619, 63.70244175195694, 62.789308950304985, 66.76713690161705, 59.94959972798824, 65.84311008453369, 65.60806229710579, 64.60465013980865, 61.07986427843571, 62.70164765417576, 22.19989076256752, 0.8643824269529432, 0.2782371308421716, 4.4560313411056995, 61.052224561572075, 69.6288925409317, 59.23663258552551, 16.234070286154747, 21.409839056432247, 69.54386830329895, 73.70679572224617, 31.05881329625845, 50.530691742897034, 31.300286538898945, 43.05752635002136, 55.30211851000786, 73.67599457502365, 6.6208407282829285, 0.11746240677894093, 0.3711394441779703, 0.07403234776575118, 0.14107982424320653, 0.07108387668267824, 0.03726479335455224, 0.152572515362408, 0.14409125171368942, 0.3949297301005572, 0.4423543025040999, 0.4175071982899681, 0.2679341024486348, 0.2984770416514948, 0.13700540381250903, 0.8863676909822971, 0.4946981859393418, 34.00019556283951, 88.87274712324142, 59.73816767334938, 55.927245765924454, 33.79896216094494, 59.762756153941154, 27.387815080583096, 91.17460280656815, 10.445626191794872, 24.28659439086914, 65.31818345189095, 71.0047759115696, 57.93435886502266, 65.82293316721916, 5.169028406962752, 0.32754744112025946, 23.784650824964046, 46.99319176375866, 70.37420734763145, 71.18158802390099, 63.20253297686577, 61.37010410428047, 65.73573544621468, 65.52087977528572, 62.83609963953495, 68.12817066907883, 67.703155875206, 64.3847407400608, 57.60935850441456, 55.976597517728806, 50.364146679639816, 53.065596520900726, 50.78573025763035, 58.39730702340603, 60.39271295070648, 53.757630586624146, 61.46498501300812, 60.99463865160942, 61.72228820621967, 61.10197149217129, 62.35126465559006, 57.81786471605301, 51.87475562095642, 49.228361025452614, 51.05622634291649, 56.36670358479023, 60.02357415854931, 60.1618867367506, 65.85522383451462, 59.49461214244366, 58.879383355379105, 57.32678286731243, 61.448672488331795, 58.69670815765858, 59.93417635560036, 58.78411866724491, 55.143689811229706, 50.19648067653179, 47.345687448978424, 43.886706456542015, 43.681741654872894, 46.595839485526085, 44.88576024770737, 37.978677079081535, 36.55725695192814, 44.69929285347462, 51.21474243700504, 47.2607696056366, 50.11848606169224, 43.83688732981682, 47.83730886876583, 42.24188111722469, 48.89550268650055, 47.46275916695595, 61.68855361640453, 66.425801217556, 61.26667745411396, 64.56013932824135, 51.52321748435497, 44.246357157826424, 57.72351197898388, 67.25851133465767, 62.02838458120823, 63.0258234590292, 61.689051389694214, 55.159234777092934, 47.0233279466629, 42.12874598801136, 45.425506085157394, 45.409934520721436, 40.07245592772961, 43.161914348602295, 49.086115658283234, 55.465464144945145, 57.94197365641594, 49.180753380060196, 49.30824413895607, 45.92928685247898, 56.45463086664677, 56.42948381602764, 57.29191593825817, 59.21289145946503, 58.881226256489754, 60.664557963609695, 59.98057186603546, 57.65902943909168, 59.92346853017807, 56.01761631667614, 54.77699048817158, 53.84091451764107, 50.65581522881985, 47.39228054881096, 50.99071405827999, 49.18488755822182, 47.81923323869705, 52.76003211736679, 61.60979524254799, 63.96420210599899, 65.7048051059246, 60.891850367188454, 61.94893464446068, 62.654267996549606, 69.83886167407036, 69.43169832229614, 64.5661810040474, 59.710828140378, 50.794868767261505, 49.439808279275894, 52.907665595412254, 54.473306983709335, 59.90794636309147, 62.3365518450737, 69.40437778830528, 68.27297329902649, 66.7170175909996, 69.3849304318428, 63.02404135465622, 68.3359207212925, 69.76610317826271, 67.8980702161789, 64.4153442978859, 67.82709762454033, 34.439140409231186, 1.1586774070747197, 0.3484714636579156, 3.8032719679176807, 67.24335014820099, 76.70838385820389, 64.21313434839249, 29.878908209502697, 22.402858771383762, 81.5454863011837, 106.24240547418594, 32.0998415350914, 58.46749685704708, 54.27971877157688, 53.10078643262386, 62.185848131775856, 85.05133777856827, 8.838148098438978, 0.8793400868307799, 0.3487880638567731, 0.26183548907283694, 0.20192864583805203, 0.11175132807693444, 0.18778884754283354], [0.0902006434625946, 0.1289435278158635, 0.10258251655614004, 0.0963514372415375, 0.06145664425275754, 0.13766110612777993, 0.10850459526409395, 0.03712139558047056, 0.6013404729310423, 0.2853221772238612, 17.97717545181513, 70.83364829421043, 40.76590731739998, 45.894921496510506, 24.950971640646458, 45.03478065133095, 14.362219478935003, 41.826662197709084, 39.44113500416279, 3.196886256337166, 25.895553454756737, 61.681558191776276, 51.82151287794113, 55.55032879114151, 26.519308984279633, 0.14021612762007862, 0.2583464450435713, 10.510425064712763, 23.734546713531017, 46.71559005975723, 46.546540930867195, 54.95521232485771, 60.56846112012863, 58.225020468235016, 59.38151881098747, 59.964513927698135, 62.01773375272751, 54.007752165198326, 53.556404784321785, 45.573599338531494, 46.03845879435539, 50.08101247251034, 49.723451659083366, 56.79185897111893, 57.90306754410267, 59.31127578020096, 57.459315955638885, 53.309919610619545, 54.15853567421436, 54.01628650724888, 55.27243070304394, 53.00383843481541, 51.31321795284748, 47.70097978413105, 48.53235997259617, 51.90366066992283, 54.38561908900738, 53.45912240445614, 60.787405371665955, 64.53714296221733, 57.53745496273041, 54.61077220737934, 57.868120819330215, 53.617904484272, 56.22305229306221, 47.52224497497082, 47.16666765511036, 52.338684126734734, 46.77354075014591, 35.36719121038914, 29.297782592475414, 21.721597127616405, 26.796399615705013, 27.430220805108547, 38.95479530096054, 41.790089160203934, 56.85991711914539, 49.657525196671486, 40.05181543529034, 42.84604869782925, 44.9998415261507, 37.64634691178799, 41.47351674735546, 42.625930309295654, 53.168179616332054, 59.8563489317894, 61.12319715321064, 57.6773938536644, 49.52549368143082, 42.44482822716236, 58.88708934187889, 66.04066148400307, 63.96316096186638, 64.21444907784462, 49.05434176325798, 39.816554859280586, 37.481067180633545, 36.333999931812286, 39.18777979910374, 36.74022853374481, 41.76507890224457, 45.88104464113712, 54.71363268792629, 75.45027136802673, 65.35862848162651, 52.0065401494503, 43.52678596973419, 33.97889010608196, 31.904437020421028, 37.96319290995598, 44.1698482632637, 46.73591896891594, 46.214514747262, 51.38651601970196, 60.002861469984055, 56.366528794169426, 53.73913697898388, 52.30863153934479, 49.601614996790886, 51.56578280031681, 53.854092210531235, 46.74665719270706, 44.048288986086845, 44.29079197347164, 41.762829422950745, 44.131614714860916, 54.90291953086853, 62.95133985579014, 63.588774651288986, 63.33068490028381, 61.80351264774799, 55.44440187513828, 90.13459101319313, 84.05480325222015, 56.44139617681503, 63.121521323919296, 50.8569460362196, 47.71155081689358, 48.149500116705894, 51.07646405696869, 52.23990462720394, 58.7568399310112, 56.3734520226717, 59.89213541150093, 55.09767808020115, 61.58925734460354, 54.26196612417698, 60.04372447729111, 59.23583462834358, 59.89051289856434, 51.51025637984276, 36.28171093761921, 3.301868448033929, 0.1804366279975511, 0.28502199333161116, 25.077373757958412, 67.77805745601654, 57.250038385391235, 35.561486184597015, 5.11244279332459, 12.603144720196724, 23.252035304903984, 28.14318984746933, 28.90055950731039, 44.48657266795635, 42.10282377898693, 42.848149985075, 44.92922231554985, 62.95103207230568, 7.425041925162077, 0.4822112247347832, 0.6253383820876479, 0.08710503418114968, 0.01773515497916378, 0.08527327270712703, 0.033632299600867555, 0.0701768312137574, 0.1430826136493124, 0.04269436431059148, 0.07299012751900591, 0.05276030249660835, 0.1800793135771528, 0.09231236530467868, 0.03941258357372135, 0.5116591101977974, 0.46511033142451197, 22.35781978815794, 76.36747375130653, 48.18568177521229, 49.48376812040806, 23.676523827016354, 53.23068626224995, 6.111858515068889, 41.892083287239075, 31.31121475249529, 5.641154022887349, 28.21987733244896, 70.20200058817863, 61.66666679084301, 64.52343329787254, 35.93407519161701, 0.31269763014279306, 0.9170706372242421, 6.8551285564899445, 24.26515594124794, 45.511541068553925, 48.930194824934006, 56.45512484014034, 61.89512573182583, 63.50984528660774, 62.596359103918076, 63.66771921515465, 64.06412914395332, 56.892211586236954, 55.72976276278496, 53.179636001586914, 50.32088220119476, 52.29718275368214, 49.09893237054348, 54.645787328481674, 57.484706193208694, 60.09472914040089, 59.795111417770386, 56.319684907794, 55.21114379167557, 56.50797240436077, 56.85227192938328, 54.90143001079559, 51.02309212088585, 50.50092414021492, 51.1474784463644, 52.767084538936615, 53.96874725818634, 56.01062849164009, 61.071193143725395, 62.46833637356758, 59.0357069671154, 55.916743129491806, 56.965950429439545, 57.51367583870888, 57.65554882586002, 50.09565308690071, 49.0924347192049, 52.14060455560684, 45.50991475582123, 40.0176552683115, 30.42721688747406, 24.86939761787653, 39.53366383910179, 47.97264240682125, 52.14979626238346, 47.98754520714283, 64.56450149416924, 57.79021739959717, 38.79502147436142, 46.747964322566986, 46.3450263440609, 43.47029060125351, 43.01238477230072, 46.04663595557213, 53.20175841450691, 60.84765113890171, 62.820034101605415, 60.05477048456669, 47.19118773937225, 44.45756122469902, 58.7495481222868, 64.04072239995003, 62.20534488558769, 59.38029907643795, 48.49922955036163, 40.01309171319008, 40.14356531202793, 39.04176123440266, 41.96949653327465, 38.52238990366459, 40.97279101610184, 45.189895927906036, 49.597173035144806, 79.3974919617176, 68.53463485836983, 60.229838490486145, 58.09194400906563, 50.759599059820175, 38.440990671515465, 38.96867595613003, 43.410440012812614, 49.948532581329346, 53.57351526618004, 53.6859892308712, 60.82332484424114, 58.172617480158806, 55.29034674167633, 55.66851384937763, 51.45850695669651, 52.7901417016983, 52.7536940574646, 46.35066144168377, 45.48387095332146, 46.403094828128815, 46.102842539548874, 48.6003041267395, 55.156654715538025, 62.65446178615093, 61.910450309515, 65.23483872413635, 62.2496847063303, 56.363671347498894, 78.99903014302254, 73.00275430083275, 59.48334574699402, 61.5729334205389, 55.23418575525284, 49.158448576927185, 50.412278696894646, 52.079997807741165, 54.72266860306263, 63.42942640185356, 62.49449037015438, 65.57423651218414, 63.09270367026329, 64.04551014304161, 56.70990116894245, 61.00153528153896, 58.809151723980904, 62.241834327578545, 54.04349684715271, 28.466512598097324, 1.8791521154344082, 0.5659558216575533, 0.11285915417829528, 33.04482042789459, 69.96259063482285, 64.85986724495888, 34.068458899855614, 10.016103889793158, 18.950139842927456, 27.1742969378829, 36.64924621582031, 37.60960288345814, 44.98760998249054, 35.16397811472416, 52.79147922992706, 52.35528163611889, 76.18120014667511, 11.171860322356224, 0.2839401795063168, 0.5472599936183542, 0.04656581848394126, 0.033513504022266716, 0.09741783665958792, 0.03418691769184079, 0.18472060124622658, 0.44987350527662784, 0.12594634958077222, 0.20109947392484173, 0.20081423688679934, 0.37021674681454897, 0.28249747410882264, 0.12121455700253136, 1.0735597182065248, 0.7018100505229086, 24.648314081132412, 85.2345259487629, 52.37095199525356, 56.83049909770489, 33.423143327236176, 66.1441907286644, 20.95047600567341, 47.600311785936356, 51.70094534754753, 9.261762667447329, 35.849826112389565, 72.52530992031097, 61.30772665143013, 67.97546446323395, 36.673378720879555, 0.4232048738049343, 1.651174679864198, 14.083594679832458, 36.42278216779232, 51.970122903585434, 52.92652018368244, 61.9340318441391, 67.07174375653267, 67.4923887848854, 66.87108412384987, 69.8720870912075, 71.99207693338394, 63.53572189807892, 61.400479674339294, 54.2828194051981, 52.10470408201218, 55.285916179418564, 49.07744072377682, 56.62733539938927, 58.78911919891834, 61.67512133717537, 63.23373310267925, 57.04655550420284, 55.159227177500725, 57.35909253358841, 56.54055945575237, 55.54369434714317, 51.79947026073933, 51.00943185389042, 50.97876749932766, 56.472850888967514, 60.74167102575302, 63.16275671124458, 66.77827030420303, 68.34697812795639, 64.63704720139503, 58.37610796093941, 59.45831649005413, 61.78895182907581, 62.03926719725132, 53.2996791601181, 51.145027577877045, 57.7321907132864, 45.216323509812355, 41.22943304479122, 37.67443500459194, 40.50306402146816, 55.78824542462826, 53.03425960242748, 54.71416845917702, 56.37064777314663, 61.508887857198715, 60.97377397119999, 47.43243679404259, 49.450690895318985, 49.94485057890415, 44.806986674666405, 46.11120209097862, 47.50023275613785, 55.678644105792046, 63.313810005784035, 64.22604605555534, 64.64356765151024, 51.222471222281456, 47.50260002911091, 63.860923647880554, 70.95102399587631, 67.76820838451385, 66.0870797932148, 52.33784817159176, 43.08691777288914, 41.59330151975155, 41.43866501748562, 43.62410634756088, 39.35060866177082, 43.20387549698353, 43.614907041192055, 56.93405494093895, 73.77086788415909, 69.78251069784164, 60.39508402347565, 62.44050286710262, 55.94661332666874, 48.298357129096985, 51.13147370517254, 51.966649889945984, 54.295320734381676, 54.71529699862003, 55.48945225775242, 65.88135123252869, 58.94462965428829, 56.29307873547077, 55.55541291832924, 52.57849685847759, 54.30668592453003, 54.33047264814377, 47.2158408164978, 47.765967696905136, 46.271207705140114, 46.02327860891819, 49.54953119158745, 59.00410786271095, 62.27329283952713, 64.25737917423248, 67.82142072916031, 68.27874138951302, 54.057966470718384, 80.80470845103264, 80.01897901296616, 56.180798560380936, 61.02665193378925, 53.73111940920353, 51.80847577750683, 49.89739492535591, 57.51150995492935, 59.83053311705589, 69.07033011317253, 68.58556732535362, 71.26209050416946, 66.60743907094002, 67.5096170604229, 59.66931536793709, 64.93746668100357, 61.37702353298664, 65.92343777418137, 58.55534814298153, 38.116195499897, 3.544869446195662, 0.6373583839740604, 0.8673719165381044, 32.24997527897358, 83.68663340806961, 67.77602836489677, 49.51440207660198, 17.381371222436428, 23.002607189118862, 31.136160045862198, 32.59449899196625, 39.49032336473465, 60.06958208978176, 54.093186780810356, 57.448630928993225, 57.07698047161102, 84.69200626015663, 14.965655598789454, 0.6908634316641837, 0.696333535015583, 0.14789049862883985, 0.1416423128102906, 0.22202839463716373, 0.09757176550920121], [0.07786308400682174, 0.1006302228779532, 0.2565110247815028, 0.08163385471561924, 0.08777649971307255, 0.02198434933234239, 0.3373650455614552, 0.3181021870113909, 0.4253087140386924, 0.5986283684615046, 12.78438264504075, 62.14392118155956, 48.788872808218, 55.9599582105875, 32.13470846414566, 45.562598928809166, 56.63817621767521, 40.42203336954117, 14.086302034556866, 11.277934480458498, 23.449841290712357, 57.78239741921425, 44.32187430560589, 49.78313505649567, 53.45315672457218, 3.72169129550457, 0.11101689873612486, 0.809065232751891, 2.162383454851806, 13.692920543253422, 32.91078642010689, 52.75039963424206, 60.63631407916546, 61.131811290979385, 54.75194223225117, 52.59099818766117, 50.379779040813446, 51.19346737861633, 48.30859757959843, 47.41179630160332, 46.09533794224262, 48.690955862402916, 55.07948465645313, 60.50430156290531, 63.86210158467293, 63.74378353357315, 60.96389450132847, 60.92445261776447, 56.820133253932, 55.49829438328743, 54.09344516694546, 60.414709970355034, 61.976783350110054, 56.36604242026806, 52.0924611389637, 49.734984040260315, 48.82968261837959, 48.267153203487396, 50.50269104540348, 57.18536585569382, 54.053653702139854, 57.95311085879803, 57.5123231112957, 54.023889899253845, 49.15008902549744, 47.7303484082222, 48.167723938822746, 36.512430757284164, 25.358644165098667, 22.339747957885265, 28.38931404054165, 42.95295596122742, 59.536835476756096, 60.72953827679157, 64.8133197426796, 53.69159013032913, 45.92341996729374, 55.23576267063618, 47.87510544061661, 38.95452931523323, 42.04542025923729, 44.115758165717125, 46.85218133032322, 49.8774041980505, 53.24307359755039, 52.84905754029751, 56.37104295194149, 47.66249164938927, 45.84275409579277, 42.17893369495869, 49.47144158184528, 56.95729449391365, 59.278472140431404, 51.39207512140274, 48.40338349342346, 41.74781642854214, 40.78012615442276, 37.50816352665424, 38.986303210258484, 37.66649343073368, 44.70877334475517, 37.50476270914078, 38.65777663886547, 44.48295906186104, 49.39133048057556, 58.349539786577225, 65.71271628141403, 67.72544547915459, 59.00127321481705, 43.17858785390854, 38.802727460861206, 34.98173989355564, 39.578429237008095, 38.43771904706955, 40.00074237585068, 50.08607380092144, 50.673795863986015, 53.31197150051594, 50.83062864840031, 55.307081043720245, 56.53074458241463, 52.48365394771099, 49.05708521604538, 49.20197144150734, 47.65069708228111, 49.40935671329498, 48.84965814650059, 59.31205093860626, 57.56427772343159, 61.509617418050766, 57.429852336645126, 75.08723124861717, 55.500889644026756, 45.16673997044563, 63.972204476594925, 62.09809564054012, 57.50784695148468, 49.19328510761261, 49.49893310666084, 48.404561430215836, 53.72467115521431, 55.70969603955746, 58.61125834286213, 56.587433740496635, 63.020993918180466, 56.55458450317383, 55.795917212963104, 51.62518501281738, 52.56742425262928, 45.60831807553768, 32.88144439458847, 3.806133926846087, 0.05192795048060361, 0.7892848004121333, 2.351549416780472, 54.729755222797394, 56.05316340923309, 51.31843887269497, 17.621909715235233, 6.0748508758842945, 24.529540054500103, 16.143944822251797, 10.172561444342136, 35.05360163748264, 80.11793330311775, 46.918233186006546, 23.91431126743555, 52.02714264392853, 59.895414635539055, 13.064742051064968, 0.26069923129398376, 0.5365058581810445, 0.0873223424423486, 0.13586104178102687, 0.1528969971695915, 0.23314527701586485, 0.09003384577226825, 0.08615143378847279, 0.20919922913890332, 0.02766294237517286, 0.07427605421980843, 0.10152024347917177, 0.2149131873738952, 0.07943933145725168, 0.46441235637757927, 0.3868338785832748, 14.949829448014498, 72.34201535582542, 51.91271938383579, 63.75142112374306, 40.90999938547611, 55.624903589487076, 47.13884934782982, 36.663921028375626, 16.304324716329575, 14.010467603802681, 32.503212690353394, 65.64393237233162, 54.6164795011282, 58.03983360528946, 60.887290611863136, 5.036061191931367, 0.01745475674397312, 1.1400931980460882, 0.4771715373499319, 11.026308182626963, 32.5225118547678, 56.142922192811966, 60.902964770793915, 64.20068621635437, 58.64911951124668, 57.27714993059635, 53.203038945794106, 54.81366991996765, 49.319499135017395, 47.78870567679405, 47.48727545142174, 50.30606299638748, 56.039290353655815, 64.2441938817501, 66.18702962994576, 62.21793361008167, 58.64748939871788, 60.68241700530052, 60.13920955359936, 60.736803486943245, 60.11896423995495, 62.86079831421375, 59.83799211680889, 56.76249034702778, 51.23088397085667, 51.10055476427078, 52.15045362710953, 53.89437384903431, 55.05127117037773, 56.21454834938049, 55.187980234622955, 58.58736902475357, 60.4577274620533, 56.56156852841377, 50.83028666675091, 51.70474134385586, 51.87258593738079, 40.345839858055115, 26.2420454621315, 26.586907356977463, 39.41838942468166, 66.12390741705894, 77.04344987869263, 75.67533329129219, 69.96491611003876, 57.05240719020367, 50.011920779943466, 60.792618691921234, 54.61934454739094, 42.9483088105917, 44.39396783709526, 44.96286191046238, 43.51060263812542, 47.7684261649847, 46.82372085750103, 49.27488952875137, 60.589276403188705, 52.828132063150406, 53.18558648228645, 50.56630723178387, 53.86221997439861, 59.08959187567234, 58.69946300983429, 51.2070706486702, 46.61975160241127, 43.43492969870567, 41.77660748362541, 41.649834886193275, 41.657852455973625, 39.04999919235706, 43.706679716706276, 38.59870880842209, 39.06046383082867, 43.32616813480854, 46.125010550022125, 57.165287733078, 67.97371655702591, 76.80705696344376, 73.88069719076157, 56.30372956395149, 45.26456952095032, 35.70506148040295, 39.72200833261013, 44.00727778673172, 46.625724881887436, 52.55034796893597, 51.89446896314621, 54.390083849430084, 51.34854845702648, 57.66057215631008, 58.539214208722115, 50.87698616087437, 49.819518104195595, 48.49299028515816, 49.54513102769852, 49.70158003270626, 52.63204738497734, 59.47190836071968, 60.028551891446114, 62.171063125133514, 57.924338802695274, 68.36098417639732, 52.350923269987106, 43.427504897117615, 67.22905531525612, 59.61918845772743, 59.14125770330429, 51.194523721933365, 50.51692508161068, 49.862075820565224, 58.8531381636858, 61.543952375650406, 66.91697046160698, 62.244862765073776, 65.06693333387375, 59.38435345888138, 60.678750202059746, 57.15267241001129, 57.71447226405144, 50.70997752249241, 29.72612790763378, 0.7909663883037865, 0.07509409391786903, 1.320071134250611, 4.795507974922657, 64.20502558350563, 61.94359593093395, 57.30367250740528, 17.65028089284897, 10.388954132795334, 16.40645183622837, 17.683891989290714, 16.31654866039753, 45.10405853390694, 89.366994202137, 45.702081844210625, 27.624679170548916, 54.70282606780529, 70.92427343130112, 16.615510918200016, 0.19202434370527044, 0.5250778526533395, 0.04809464640857186, 0.10215786707703955, 0.04283607740944717, 0.28322118683718145, 0.16985956899588928, 0.19024152687052265, 0.4838089499389753, 0.18407064315397292, 0.15072836744366214, 0.26599617674946785, 0.4133346659364179, 0.4356832557823509, 0.787485537584871, 1.030092544388026, 17.336771115660667, 75.17705842852592, 60.58717891573906, 66.42398491501808, 41.7830291390419, 57.9873014241457, 59.16011229157448, 49.7197924554348, 19.00726217776537, 20.506980903446674, 33.002076521515846, 69.50853779911995, 54.532150626182556, 61.046574264764786, 66.72506555914879, 4.938009828329086, 0.18927490920759737, 2.0348409237340093, 3.1549452943727374, 22.023975402116776, 41.54716819524765, 63.86571139097214, 66.05880171060562, 70.62277480959892, 65.8853106200695, 64.49161380529404, 58.67175489664078, 60.41448198258877, 55.795385241508484, 51.486621648073196, 48.79347436130047, 52.38857164978981, 54.17080521583557, 63.96943062543869, 67.48391523957253, 60.67211575806141, 58.35574485361576, 61.916860565543175, 58.59359309077263, 61.75676375627518, 62.35213100910187, 64.82041776180267, 61.48042358458042, 58.88805449008942, 54.83093619346619, 55.33025220036507, 57.005266919732094, 57.479785457253456, 62.67091490328312, 61.39333225786686, 56.99535325169563, 63.42150382697582, 64.33674931526184, 61.22035413980484, 57.164930552244186, 55.50543799996376, 51.779943108558655, 39.85402464866638, 36.12618528306484, 42.02104836702347, 55.46924874186516, 66.08615264296532, 65.22648677229881, 60.80458804965019, 59.45876486599445, 43.96882005035877, 40.4509612172842, 55.778046771883965, 54.24329772591591, 45.85706412792206, 45.554015189409256, 46.771922037005424, 45.965897887945175, 51.27401925623417, 49.91687647998333, 54.60378058254719, 62.48672738671303, 53.426945731043816, 54.59885224699974, 55.034578666090965, 56.72973230481148, 65.34442484378815, 63.84780675172806, 54.62053008377552, 50.27396611869335, 48.267890363931656, 46.660907194018364, 43.728228360414505, 41.077338606119156, 38.22521924972534, 44.38726879656315, 41.98338098824024, 42.020968571305275, 45.191317051649094, 44.885912239551544, 52.90254347026348, 56.864644065499306, 67.47315421700478, 66.20594501495361, 60.86537338793278, 55.832087472081184, 46.576262935996056, 48.861163929104805, 47.129251062870026, 50.462451204657555, 56.07965178787708, 55.826197788119316, 54.45951372385025, 50.988118797540665, 57.938892021775246, 61.12551882863045, 53.364560678601265, 50.96074506640434, 49.022651463747025, 50.12481652200222, 50.12395016849041, 52.7347444742918, 58.30221712589264, 61.47464029490948, 63.960774689912796, 63.37882451713085, 63.837266117334366, 65.13861268758774, 53.49980302155018, 61.94553002715111, 60.83882421255112, 58.424452766776085, 52.6293533295393, 52.550800144672394, 52.738023698329926, 63.07635314762592, 67.51436680555344, 72.17556908726692, 66.90470471978188, 71.35085374116898, 63.56712721288204, 63.0309721827507, 59.263972118496895, 60.222729071974754, 57.15014174580574, 37.36625254154205, 5.28251264244318, 0.17039758153259754, 2.030128939077258, 3.8966704811900854, 68.63518506288528, 66.5461939573288, 63.798265010118484, 29.683591090142727, 17.006717026233673, 33.399896174669266, 25.424338839948177, 12.658051773905754, 53.248993679881096, 111.92383781075478, 63.238992020487785, 33.17901782691479, 62.82479904592037, 83.5907569527626, 22.832425720989704, 0.6099613790865988, 1.0733797028660774, 0.22761330823414028, 0.2923562825890258, 0.22135817591333762, 0.575139275752008], [0.05417965250671841, 0.10747068707132712, 0.07739807653706521, 0.10188429660047404, 0.059879201944568194, 0.13820174586726353, 0.09053156711161137, 0.5278167338110507, 0.4736232402501628, 0.8135780843440443, 9.623719844967127, 68.99804279208183, 54.03515249490738, 46.059787049889565, 22.082604356110096, 43.07964876294136, 33.83176200091839, 80.53814515471458, 6.310794465243816, 5.792694641277194, 48.215358182787895, 65.61375439167023, 55.93291886150837, 40.61505541205406, 66.79992914199829, 13.553210590034723, 0.4988993355073035, 0.7697426865343004, 0.38640111743006855, 0.8680985087994486, 4.984909761697054, 51.10783137381077, 66.00567296147346, 63.83576139807701, 57.20467261970043, 58.13201665878296, 50.27479067444801, 51.21195338666439, 48.494643196463585, 47.275440618395805, 47.40804970264435, 50.72959206998348, 59.16354350745678, 57.60157272219658, 57.26856619119644, 65.92631042003632, 60.51301449537277, 55.842935889959335, 56.23703554272652, 69.27827015519142, 60.496356189250946, 60.660594776272774, 54.25791934132576, 51.033431366086006, 49.43117894232273, 47.991227209568024, 49.80290159583092, 51.284692883491516, 53.57239432632923, 56.05993464589119, 51.91732473671436, 52.975495755672455, 55.15153259038925, 56.01947821676731, 51.55876077711582, 43.24183166027069, 29.355311505496502, 24.461597800254822, 29.48781419545412, 39.44768965244293, 63.62108051776886, 74.05638456344604, 75.78205436468124, 70.14586240053177, 64.46613997220993, 55.73062911629677, 49.77878049015999, 49.90203447639942, 55.052441507577896, 47.147721871733665, 46.279415264725685, 46.50087118148804, 43.56243945658207, 43.312640860676765, 49.673860520124435, 53.66663306951523, 50.43823130428791, 41.23734422028065, 36.74814730882645, 39.498413130640984, 42.6868562400341, 45.951637253165245, 52.545146048069, 47.765477523207664, 46.363941729068756, 40.40994621813297, 42.13796429336071, 41.297437995672226, 36.16187296807766, 36.9598263502121, 37.806109338998795, 39.914346411824226, 32.51504525542259, 34.100882560014725, 48.87963853776455, 47.976351007819176, 53.55831228196621, 54.162430465221405, 65.73813691735268, 69.5053231716156, 61.2345539778471, 42.99819253385067, 30.682770274579525, 27.706391885876656, 32.239149659872055, 26.529773622751236, 46.907377168536186, 53.64993296563625, 49.15534034371376, 52.411993592977524, 53.07045266032219, 52.55597926676273, 51.450854167342186, 56.33440911769867, 51.05165898799896, 53.717044964432716, 54.27679292857647, 57.6278293132782, 54.90394547581673, 58.11810560524464, 55.33515013754368, 78.97620856761932, 39.209799617528915, 39.06900577247143, 72.41387709975243, 62.40991450846195, 56.57424084842205, 48.18241775035858, 47.39327609539032, 40.97075812518597, 45.642493441700935, 54.64020922780037, 60.245102271437645, 61.31031431257725, 59.893134757876396, 60.06908431649208, 59.199136197566986, 52.87471756339073, 51.947612911462784, 26.730722039937973, 5.851883590221405, 0.26730185199994594, 0.18957966472953558, 1.3550360267981887, 8.648362532258034, 59.89812768995762, 54.73170831799507, 48.34987856447697, 19.28676187992096, 10.049631390720606, 9.617027454078197, 24.0663905069232, 19.961187690496445, 31.458996422588825, 55.94853602349758, 38.77783499658108, 52.89915785193443, 52.581456899642944, 64.34814870357513, 11.904325168579817, 0.07625942162121646, 0.41036283946596086, 0.05645250574161764, 0.1346995955100283, 0.17628726549446583, 0.2608195482753217, 0.07099533104337752, 0.1385185241815634, 0.030042638900340535, 0.16072304832050577, 0.12425032691680826, 0.040239933514385484, 0.20086321863345802, 0.2605356025742367, 0.430484184762463, 0.5238958192057908, 11.823035180568695, 78.24994593858719, 60.97869090735912, 46.692164316773415, 26.063909120857716, 54.77541737258434, 52.87290506064892, 95.59598475694656, 11.7318856716156, 9.025538843125105, 52.619033083319664, 74.28735136985779, 52.77054235339165, 46.00833401083946, 75.22701814770699, 17.17409234493971, 0.5797062744386494, 0.06007827934809029, 0.3884339489741251, 0.4698535456554964, 5.046327766031027, 51.81382589042187, 65.71378022432327, 66.05426475405693, 59.786656871438026, 61.06422431766987, 55.08601650595665, 54.94420811533928, 49.46153171360493, 47.15936064720154, 48.4363467246294, 52.027268037199974, 59.37168873846531, 60.10788403451443, 60.58278255164623, 63.831726014614105, 64.5567499101162, 56.17249980568886, 53.081529065966606, 66.52711898088455, 64.7445510327816, 62.389027029275894, 55.14808997511864, 53.131940960884094, 50.36146022379398, 50.753861367702484, 51.7575167119503, 54.97364893555641, 56.44915536046028, 61.31264738738537, 56.79743327200413, 56.641200855374336, 56.089284271001816, 58.5374017059803, 54.16271165013313, 47.01091781258583, 34.17082540690899, 30.229543894529343, 39.77431632578373, 62.17648923397064, 80.55022090673447, 81.75055369734764, 76.43001839518547, 75.20798116922379, 64.21971559524536, 55.692946538329124, 56.04704953730106, 49.49304722249508, 55.931284949183464, 46.05877250432968, 41.79176487028599, 40.885057523846626, 40.15359677374363, 45.06589338183403, 48.812773525714874, 50.82981929183006, 52.30961188673973, 41.85352675616741, 41.7524141818285, 42.5993849337101, 44.20232132077217, 46.70268215239048, 52.598179802298546, 49.06232513487339, 49.148500710725784, 43.61252836883068, 43.66650827229023, 44.32152472436428, 39.63411144912243, 36.027968153357506, 38.219451159238815, 40.66031478345394, 33.45883101224899, 31.36191163212061, 48.375071212649345, 47.87953980267048, 50.55449366569519, 51.85804031789303, 60.56855991482735, 69.22376587986946, 67.49884843826294, 56.59958928823471, 38.106240034103394, 31.62279613316059, 32.743249610066414, 33.604078218340874, 47.647904232144356, 54.48876455426216, 51.51527211070061, 54.3127503991127, 52.873862609267235, 52.76061348617077, 52.299170047044754, 55.04980444908142, 50.56166008114815, 51.795104295015335, 56.755475923419, 60.29497839510441, 57.068476527929306, 58.62562917172909, 58.43361407518387, 67.99954757094383, 38.90510156750679, 40.70352226495743, 74.35437977313995, 63.2331745326519, 60.892545729875565, 50.80838084220886, 48.724029287695885, 44.588422402739525, 51.54712960124016, 58.92378397285938, 62.83714838325977, 65.2279306948185, 63.51238735020161, 61.53915323317051, 64.22812074422836, 57.13622309267521, 57.434541285037994, 30.25947868824005, 3.267156360670924, 0.10224880985333584, 1.4894871809519827, 0.9043911925982684, 11.825385354459286, 66.91624850034714, 61.91390052437782, 54.5870690792799, 24.97085027396679, 13.156715165823698, 9.306889995932579, 25.275523625314236, 25.35375762730837, 33.035860508680344, 61.305921748280525, 41.33299268782139, 50.629505440592766, 57.483007684350014, 77.16207951307297, 15.988365970551968, 0.2897318109171465, 0.3151622135192156, 0.09127742552664131, 0.1479201251640916, 0.031122107538976707, 0.0991500612872187, 0.156219904019963, 0.3026735602179542, 0.19355673022801057, 0.27893759950529784, 0.24782801570836455, 0.1497358042979613, 0.2678811427904293, 0.5756624601781368, 0.587044155690819, 1.2394368485547602, 13.457259088754654, 86.31079539656639, 68.28051209449768, 55.6296419352293, 27.90068306028843, 64.69636961817741, 39.38116282224655, 89.89490747451782, 12.738838288933039, 12.46871743351221, 58.412103429436684, 79.23863768577576, 62.199413403868675, 54.48882915079594, 82.60910242795944, 19.97198861092329, 0.8007448073476553, 1.1307920096442103, 0.43962100229691714, 1.232068450190127, 9.554792493581772, 60.260571241378784, 70.20225897431374, 71.99240371584892, 64.77064803242683, 64.98589888215065, 58.2515012472868, 58.578162118792534, 55.17544470727444, 50.756521224975586, 50.93424528837204, 55.03425948321819, 65.14503434300423, 63.68531607091427, 61.3004994392395, 65.19212141633034, 65.03642097115517, 57.51556433737278, 54.46628876030445, 69.49944108724594, 65.88613137602806, 66.99248000979424, 59.399374052882195, 55.84670148789883, 55.10883808135986, 52.49586649239063, 55.24194873869419, 59.22390326857567, 58.471821025013924, 65.34162819385529, 58.39674085378647, 62.145045921206474, 58.341659009456635, 61.154199689626694, 57.268550992012024, 47.199497893452644, 42.922470197081566, 47.27597638964653, 56.34374141693115, 66.71651601791382, 72.97796443104744, 74.3690849840641, 63.910617381334305, 69.51691254973412, 62.64273181557655, 57.13199391961098, 55.56470721960068, 47.86611892282963, 51.719780936837196, 43.25103856623173, 44.23307307064533, 43.53934049606323, 43.77572201192379, 46.855050176382065, 51.487639993429184, 55.23061014711857, 56.624717339873314, 48.04724380373955, 42.32665836811066, 41.91983699798584, 44.78438928723335, 47.3636718839407, 55.661795809865, 53.46973143517971, 54.31653119623661, 47.02342674136162, 47.35565431416035, 47.971008494496346, 38.47353212535381, 36.8049580603838, 38.093396723270416, 45.14341302216053, 36.98537237942219, 36.3806576281786, 50.41032940149307, 50.807354897260666, 50.95210053026676, 48.04247125983238, 52.36745238304138, 57.963039726018906, 60.464506298303604, 58.12080726027489, 47.57502034306526, 44.20283429324627, 42.31465481221676, 37.48475298285484, 53.52806970477104, 59.242552667856216, 53.84819872677326, 56.89385309815407, 57.68779009580612, 54.60414156317711, 57.96848863363266, 59.05490353703499, 53.39444987475872, 52.829579785466194, 58.72906342148781, 61.9722767919302, 62.21807800233364, 62.73224361240864, 58.6799206584692, 75.31914800405502, 44.94172364473343, 45.90445898473263, 75.31001329421997, 67.28361278772354, 60.82471936941147, 53.91119174659252, 52.143583595752716, 48.18674571812153, 53.44797380268574, 61.312772780656815, 67.44475454092026, 68.33642229437828, 69.09615352749825, 67.49790608882904, 69.57819566130638, 61.5057036280632, 61.96478359401226, 41.239821687340736, 7.022120570763946, 0.2575343573698774, 0.921864554984495, 3.569352957420051, 10.645912494510412, 74.35069397091866, 62.60534942150116, 60.64078263938427, 28.30541644245386, 18.52516684681177, 19.500981085002422, 36.72806918621063, 30.37430662661791, 43.78057815134525, 73.21140110492706, 52.884342446923256, 66.48087546229362, 67.41259306669235, 86.01210102438927, 22.889646850526333, 0.3782378195319325, 0.6912987458053976, 0.2021658213925548, 0.31962534121703357, 0.2910548821091652, 0.2791387215256691], [0.07235188051708974, 0.08587191128754057, 0.2044398064026609, 0.14392582699656487, 0.03433201498410199, 0.19596379715949297, 0.11414755223086104, 0.12076425147824921, 0.4225723264971748, 0.21267730422550812, 9.235456679016352, 75.81656411290169, 49.39998261630535, 66.83047190308571, 31.70116502791643, 38.43309849500656, 28.351715058088303, 47.91336938738823, 22.027184329926968, 4.063455406576395, 46.32228836417198, 66.53689205646515, 69.4298668205738, 47.729428857564926, 60.54475799202919, 24.18816827237606, 0.10439648132887669, 0.4922292387345806, 0.25173046567942947, 0.3418998944107443, 0.35615129687357694, 13.651719354093075, 60.77112324535847, 62.12875999510288, 65.1644740998745, 61.065911427140236, 59.417415484786034, 53.57360266149044, 49.96105670928955, 47.724257335066795, 48.74495476484299, 56.25809781253338, 60.70977173745632, 62.4785578250885, 67.24462687969208, 67.47764557600021, 48.95268961787224, 51.50161184370518, 43.870466127991676, 56.44461840391159, 62.001284435391426, 61.9432919472456, 54.67714324593544, 51.84792146086693, 46.52488589286804, 50.612011179327965, 52.132332399487495, 56.07319213449955, 57.85347640514374, 57.75571145117283, 55.72408966720104, 55.40409363806248, 52.78824560344219, 51.6285440325737, 44.495441392064095, 37.003729194402695, 37.102147713303566, 42.30000659823418, 60.12385457754135, 80.88428378105164, 78.80113676190376, 65.12248635292053, 57.97027073800564, 46.71079471707344, 42.28294551372528, 48.551222160458565, 48.050827011466026, 48.90081100165844, 49.98780347406864, 47.62544743716717, 46.1091236025095, 50.56396655738354, 47.61390745639801, 47.39696949720383, 44.421333968639374, 49.388940408825874, 51.73293583095074, 46.156944036483765, 45.25408588349819, 42.7584557980299, 43.879426047205925, 38.716031312942505, 48.04391138255596, 46.57288871705532, 42.440827041864395, 43.194550797343254, 43.2282055914402, 41.39909394085407, 35.37614732980728, 38.42876672744751, 42.8911142796278, 49.18859235942364, 55.13750374317169, 52.84316785633564, 43.93632419407368, 38.870667815208435, 40.268988981842995, 38.97419326007366, 46.36216722428799, 48.65664750337601, 58.62568236887455, 64.67280328273773, 59.06907297670841, 37.64405183494091, 29.301365800201893, 23.295639865100384, 21.860325783491135, 39.493834376335144, 51.33424982428551, 52.180061638355255, 50.235534980893135, 57.276834547519684, 52.33427256345749, 51.345987394452095, 47.06649363040924, 49.72164295613766, 54.1651701182127, 57.00326822698116, 58.03750053048134, 62.2894761711359, 59.316599294543266, 47.712303176522255, 41.93428002297878, 44.063149988651276, 67.1446618437767, 59.27547790110111, 54.46362130343914, 43.58710013329983, 44.99332867562771, 41.07759699225426, 47.603963389992714, 54.62239198386669, 64.3565234541893, 56.44249811768532, 60.72802975773811, 57.97868348658085, 62.29963682591915, 55.91983996331692, 59.90729659795761, 8.127631824463606, 0.6167960248421878, 0.5973118578549474, 0.8341559395194054, 0.24249817826785147, 17.87676014006138, 62.70901545882225, 55.90580731630325, 55.08315145969391, 42.27479115128517, 20.418295562267303, 8.030665777623653, 15.713469721376896, 29.55717757344246, 34.03450392186642, 47.17843562364578, 26.155098527669907, 38.744176402688026, 50.863299295306206, 64.12269160151482, 7.053671702742577, 0.11127540361485444, 0.4818441881798208, 0.020246469539415557, 0.2373381590587087, 0.23991921509150416, 0.33139366598334163, 0.09682710195193067, 0.05117265936860349, 0.04782381816767156, 0.020462421525735408, 0.0781000591814518, 0.12716782075585797, 0.13151400082278997, 0.17575524951098487, 0.43671846273355186, 0.16255367430858314, 10.973372273147106, 78.99787500500679, 57.51761622726917, 66.23451188206673, 35.64933367073536, 54.34909924864769, 31.50332484394312, 54.62863504886627, 23.55387020856142, 8.31421036273241, 46.0101693123579, 74.45270329713821, 71.07320263981819, 53.987582847476006, 68.9732301235199, 30.39632074534893, 0.10325941460905597, 0.3712396934861317, 0.3057170781539753, 0.10081529224407859, 0.2867128432262689, 13.323399871587753, 63.400247767567635, 65.5368161201477, 67.47992545366287, 63.022726625204086, 57.26557195186615, 56.58899925649166, 51.81868202984333, 50.7599638402462, 52.21030041575432, 61.686874106526375, 61.793712973594666, 60.27030631899834, 65.73154047131538, 60.63322864472866, 51.958487927913666, 49.054311364889145, 42.979090958833694, 53.31604868173599, 60.400331541895866, 63.78838554024696, 57.03823395073414, 54.105714708566666, 49.3061276525259, 53.19078080356121, 51.50987260043621, 58.22853147983551, 59.20233942568302, 60.30933402478695, 59.65983107686043, 57.369971349835396, 57.366308346390724, 56.62627525627613, 49.55341458320618, 44.68621015548706, 50.074108242988586, 61.09505206346512, 75.32218784093857, 87.15919107198715, 77.49343693256378, 59.312833696603775, 53.17015551030636, 47.13439218699932, 45.5567092448473, 45.983270555734634, 47.814570888876915, 47.82597787678242, 42.19423547387123, 45.56535378098488, 45.98735153675079, 49.83797371387482, 46.403102427721024, 45.01211106777191, 45.87925113737583, 54.80458080768585, 50.9921769797802, 41.30574814975262, 38.237990364432335, 37.97352455556393, 41.585177555680275, 41.94354772567749, 53.417761623859406, 50.404576510190964, 46.00058622658253, 46.133267506957054, 43.595835864543915, 41.200220212340355, 34.931844770908356, 38.72209198772907, 42.025684118270874, 45.16480587422848, 53.23400728404522, 51.114492416381836, 46.529381051659584, 40.827581807971, 38.00331115722656, 36.52540326118469, 43.874151930212975, 44.90268833935261, 53.350326642394066, 62.53997012972832, 67.54728823900223, 51.1474784463644, 37.287353575229645, 23.05928874760866, 23.02730206400156, 39.97369542717934, 54.60751958191395, 54.14058543741703, 52.62774981558323, 55.05542054772377, 53.15267264842987, 50.17928659915924, 46.462941616773605, 48.75125102698803, 54.3444786965847, 58.38851809501648, 59.089664071798325, 65.34998014569283, 62.69429124891758, 44.79692481458187, 44.2778916656971, 47.601478323340416, 65.3095731139183, 58.705675676465034, 57.56705157458782, 49.78200651705265, 49.70572181046009, 44.74930576980114, 51.79946266114712, 56.67987518012524, 64.82623144984245, 61.36256530880928, 65.59313669800758, 60.25162272155285, 67.20343708992004, 59.849418103694916, 64.71579417586327, 8.397969268262386, 0.6436194980051368, 0.13004765060031787, 4.176290826871991, 0.8837669086642563, 22.323832511901855, 66.80521085858345, 58.71274709701538, 60.93503125011921, 52.322307005524635, 26.24225065112114, 9.571972321718931, 18.38565543293953, 21.86798047274351, 24.89512223750353, 50.74726112186909, 27.63474863022566, 37.992303147912025, 58.146034106612206, 72.76993319392204, 8.930912520736456, 0.4227582790190354, 0.39683411072473973, 0.09356164475320838, 0.19951820955611765, 0.06887984651257284, 0.08574849955039099, 0.13340637349756435, 0.1312799274455756, 0.16276609181659296, 0.29496671282686293, 0.19056326273130253, 0.25063772744033486, 0.1659198186825961, 0.37616253714077175, 0.6220228818710893, 0.6093582208268344, 11.737366877496243, 92.07019194960594, 63.73977094888687, 84.78685677051544, 41.83531433343887, 61.85155346989632, 37.97849468886852, 52.28070303797722, 29.20634999871254, 11.701713390648365, 54.5125512778759, 83.26873183250427, 82.43385583162308, 61.87101222574711, 74.61624652147293, 35.41357532143593, 0.17623311839997768, 0.7558856019750237, 0.36409459251444787, 0.3260425734333694, 0.43366609839722514, 17.86417331546545, 67.39056184887886, 69.31901916861534, 71.9071514904499, 68.32230985164642, 62.6267346739769, 60.10707087814808, 54.87892001867294, 54.42983731627464, 54.562754184007645, 63.238296657800674, 62.45419733226299, 60.95306508243084, 67.6443350315094, 59.78638708591461, 51.03318437933922, 49.679921194911, 44.25859250128269, 59.7885187715292, 64.57209348678589, 69.3279866874218, 61.19131989777088, 61.43505401909351, 54.15815569460392, 58.888172283768654, 53.98393124341965, 58.65290030837059, 63.454676046967506, 64.17898938059807, 61.2531653791666, 57.9548055678606, 58.13406474888325, 57.501307502388954, 53.61715592443943, 57.803729474544525, 65.3660836815834, 67.97171026468277, 75.0824511051178, 81.00564166903496, 72.5325295329094, 53.46173666417599, 54.952282682061195, 55.5511799454689, 50.69413997232914, 50.272203013300896, 51.27406865358353, 47.64816641807556, 44.42524015903473, 44.13735240697861, 42.43492975831032, 50.229250118136406, 48.71986851096153, 50.061356127262115, 47.495942786335945, 57.84102827310562, 56.873809173703194, 45.89714057743549, 42.3440196365118, 42.173393592238426, 42.16311514377594, 43.707758858799934, 53.83670054376125, 52.681991904973984, 51.361809745430946, 49.538287594914436, 44.855506271123886, 44.67169113457203, 36.05777755379677, 41.00573904812336, 43.322638124227524, 47.16766320168972, 55.605266243219376, 54.646277502179146, 52.17109031975269, 43.15716080367565, 40.837943851947784, 37.16579809784889, 44.871036037802696, 44.87844184041023, 51.260142400860786, 57.87663996219635, 61.91946342587471, 54.583797454833984, 50.66767059266567, 38.5612466186285, 35.80995865166187, 46.67458266019821, 63.30387733876705, 56.807833313941956, 54.617668837308884, 60.05238801240921, 54.52563017606735, 52.51464128494263, 50.179066210985184, 52.783214673399925, 59.72486078739166, 61.16453893482685, 61.15332953631878, 64.94488388299942, 63.14587041735649, 56.3497868925333, 45.24334765970707, 48.51868450641632, 68.59488442540169, 63.402683436870575, 59.608986005187035, 50.06618566811085, 52.31380686163902, 46.757114231586456, 55.02873457968235, 60.069798678159714, 71.51597008109093, 64.46198299527168, 69.80935245752335, 65.85475265979767, 70.50137132406235, 62.7669433504343, 69.40046399831772, 16.080615520477295, 1.4492989936843514, 0.570376884425059, 6.074830451980233, 3.1541896099224687, 22.124417312443256, 77.33032688498497, 66.03832080960274, 66.14438071846962, 50.30011631548405, 29.962152242660522, 17.78928693383932, 25.263964645564556, 38.353644758462906, 49.7833326458931, 69.62687864899635, 35.00241078436375, 53.30186404287815, 65.40496319532394, 86.44485980272293, 15.673240330070257, 0.8279225521255285, 0.9171361837070435, 0.23400265054078773, 0.4630138829816133, 0.19692803994985297, 0.25981583807151765], [0.03649422884336673, 0.12776943534845486, 0.20773857861058787, 0.3410403389716521, 0.2111860623699613, 0.0428530020872131, 0.0898138435150031, 0.07933238055557013, 0.6025650759693235, 0.042530379359959625, 4.533142978325486, 62.37341746687889, 50.34130610525608, 47.13219590485096, 27.057876884937286, 41.021040827035904, 64.90544199943542, 81.91882386803627, 14.050668496638536, 12.136075682938099, 36.213979572057724, 62.55094774067402, 58.13637122511864, 55.97901038825512, 53.3796838670969, 51.48284085094929, 0.8014829771127552, 0.3207566711353138, 0.1542116969358176, 0.1565957276034169, 0.20556739589665085, 0.9265770146157593, 33.89877140522003, 63.65159668028355, 64.99242693185806, 66.29337072372437, 57.69709959626198, 52.58274503052235, 47.56159566342831, 51.49882659316063, 60.06364680826664, 61.31107047200203, 59.68525171279907, 31.131932772696018, 44.53172564506531, 87.38784000277519, 56.91512055695057, 48.9562576264143, 43.47107715904713, 48.162081241607666, 56.21401257812977, 58.67461234331131, 58.24817642569542, 57.16213770210743, 52.21257269382477, 49.1400233656168, 52.16922841966152, 54.6069610118866, 57.09765896201134, 57.425778955221176, 54.90257374942303, 56.44460700452328, 51.5872098505497, 46.68303720653057, 44.09338876605034, 55.17993986606598, 66.49344518780708, 92.56266072392464, 106.96326479315758, 79.95486125349998, 60.5063496530056, 55.05250610411167, 56.19918577373028, 51.888461485505104, 59.66176137328148, 60.891945362091064, 58.59564118087292, 61.64343103766441, 56.41648091375828, 52.3144756257534, 50.241641253232956, 46.46541528403759, 47.681217044591904, 46.65425755083561, 45.44168561697006, 45.20483672618866, 50.05488507449627, 47.86211393773556, 49.75008822977543, 49.83356975018978, 46.72491475939751, 46.78332902491093, 40.366050973534584, 41.13843932747841, 41.940910667181015, 44.03934046626091, 38.28672654926777, 38.3725069463253, 37.15298518538475, 40.39140701293945, 44.38055455684662, 45.59446781873703, 44.68870662152767, 42.107269540429115, 44.418495520949364, 48.87922056019306, 49.11372497677803, 45.891592875123024, 45.821045860648155, 42.199315801262856, 39.449167773127556, 46.83485046029091, 60.51917776465416, 67.06200107932091, 57.25925289094448, 26.155997179448605, 18.68986900895834, 18.06838385760784, 45.0060997903347, 56.122950464487076, 51.89615227282047, 51.63650840520859, 53.10049764811993, 49.10512983798981, 46.29876762628555, 51.71319589018822, 53.36490646004677, 56.641508638858795, 63.036770671606064, 65.285983979702, 60.44122874736786, 29.65595707297325, 45.309483110904694, 54.533290565013885, 55.401809960603714, 59.38529960811138, 50.16340725123882, 47.98643946647644, 47.60830655694008, 43.452955931425095, 47.955246940255165, 49.06394004821777, 52.01463371515274, 55.49351043999195, 57.57500074803829, 57.90741451084614, 61.47538885474205, 58.6529953032732, 58.32878530025482, 1.8657321855425835, 0.17283411172684282, 0.029337845371628646, 3.7181562976911664, 0.23688999091973528, 31.171785034239292, 59.75652828812599, 51.99442259967327, 56.493954956531525, 44.55589234828949, 40.103359669446945, 8.507273253053427, 19.277490377426147, 39.166956916451454, 48.01524952054024, 34.533166363835335, 41.51993505656719, 43.73768225312233, 50.67297890782356, 59.62278686463833, 3.8643762515857816, 0.15485561394598335, 0.43596586561761796, 0.28961069241631776, 0.3709295648150146, 0.08181256387615576, 0.05357104688300751, 0.08332909812452272, 0.09100244496949017, 0.08843856223393232, 0.01899653514556121, 0.15606562636094168, 0.010861451846722048, 0.1636828519986011, 0.14703702880069613, 0.5775732232723385, 0.019815756713796873, 4.338362580165267, 69.99459251761436, 60.50924889743328, 51.49741306900978, 27.60701011866331, 56.42874665558338, 45.229744389653206, 64.78051230311394, 16.250711493194103, 14.171533361077309, 43.353055492043495, 69.98389229178429, 61.68795704841614, 60.284437760710716, 58.30243371427059, 57.96898640692234, 1.6028345050290227, 0.22347856604028493, 0.08222492338973098, 0.09034947375766933, 0.30723091098479927, 1.7385082435794175, 35.51134407520294, 66.83525964617729, 65.42621925473213, 65.66296935081482, 57.53982983529568, 57.38371141254902, 53.262653946876526, 55.27277268469334, 58.11663508415222, 61.60317599773407, 60.08395291864872, 32.51175843179226, 44.48669046163559, 67.23505899310112, 53.30097869038582, 44.90649193525314, 47.31262922286987, 51.878103241324425, 57.70188733935356, 57.40840628743172, 61.16696320474148, 57.666465640068054, 52.258687019348145, 55.50240956246853, 56.35133720934391, 55.23339919745922, 56.52633301913738, 56.98287092149258, 56.50892235338688, 59.37776081264019, 57.332326769828796, 52.256673127412796, 52.0506975799799, 67.90557861328125, 82.28228196501732, 103.7240906059742, 93.74164626002312, 65.48571646213531, 53.66178072988987, 52.51180283725262, 59.01837609708309, 58.438952788710594, 60.09836934506893, 60.98567113280296, 57.176470533013344, 54.4100783765316, 52.17134490609169, 50.07951155304909, 48.22028651833534, 47.43797309696674, 47.943748757243156, 44.55028384923935, 45.29686018824577, 42.6838544011116, 47.55062185227871, 45.513566359877586, 44.24101084470749, 45.073375180363655, 42.517951503396034, 45.0057540088892, 46.218960508704185, 45.23163288831711, 43.72297704219818, 45.40354706346989, 41.612832471728325, 39.39555644989014, 37.2801111638546, 42.02877335250378, 44.74153898656368, 46.20254918932915, 47.31395535171032, 42.381683215498924, 44.10083256661892, 46.03625871241093, 47.82800696790218, 46.90962664783001, 46.28708325326443, 44.5957788079977, 40.75131230056286, 46.87336519360542, 53.07511121034622, 63.87309819459915, 66.07558161020279, 43.47514294087887, 27.358539551496506, 20.680297203361988, 43.73134799301624, 54.174316227436066, 51.06181584298611, 51.12301915884018, 54.2173907160759, 50.21731115877628, 48.21199916303158, 51.61085978150368, 54.24540661275387, 55.050537809729576, 61.47288478910923, 64.46142822504044, 61.29859194159508, 30.261023305356503, 47.323272451758385, 60.42464643716812, 62.44721710681915, 62.74402678012848, 55.85955619812012, 50.605030953884125, 51.17558553814888, 46.51050366461277, 49.983072727918625, 51.827174574136734, 56.06840439140797, 58.95590364933014, 61.58869497478008, 62.405381351709366, 68.03738594055176, 61.039088666439056, 62.5490478426218, 1.6459895018488169, 0.22552904585609213, 0.2595885924529284, 4.306381121277809, 0.5789580114651471, 35.39071574807167, 66.57979935407639, 59.26144525408745, 63.10230195522308, 51.850672513246536, 42.826016172766685, 11.89413981512189, 24.663520865142345, 45.471985191106796, 50.640293061733246, 44.84131783246994, 42.72674649953842, 42.14931048452854, 58.021495789289474, 69.83939364552498, 6.355158509686589, 0.6411992653738707, 0.41692657163366675, 0.12244857047335245, 0.25331299169920385, 0.04808032295841258, 0.04129021348489914, 0.13758977089310065, 0.24297647760249674, 0.27216633316129446, 0.4069123574299738, 0.423428260255605, 0.17878560174722224, 0.34996600064914674, 0.23763258388498798, 0.753267661202699, 0.29184535844251513, 5.82476444542408, 84.74217116832733, 68.52164715528488, 66.53097957372665, 36.38658531010151, 62.60536842048168, 80.9080097079277, 87.52498984336853, 21.739391572773457, 20.623062774538994, 46.94222889840603, 78.49361926317215, 68.4362505376339, 69.04428631067276, 65.67647382616997, 64.76574629545212, 1.840535025112331, 0.3369425260461867, 0.4125575482612476, 0.32685130659956485, 0.6417622289154679, 3.2413583574816585, 39.00978974997997, 69.4127905368805, 70.70780664682388, 69.95882883667946, 62.07075610756874, 62.58657082915306, 57.102887481451035, 58.164710104465485, 63.97896811366081, 63.86810526251793, 69.28624212741852, 36.26786828041077, 48.00746753811836, 81.46304592490196, 48.315687999129295, 47.44073934853077, 45.73403052985668, 52.06877700984478, 62.163235545158386, 61.730222180485725, 66.05371758341789, 64.1387191414833, 57.62144185602665, 59.85184237360954, 59.92322914302349, 58.76079551875591, 60.47935590147972, 60.598528906702995, 58.49909596145153, 61.324863731861115, 57.006235867738724, 56.494426131248474, 59.920155107975006, 79.08710941672325, 88.22829410433769, 102.7243946492672, 91.18164762854576, 61.13397717475891, 54.825593680143356, 59.557122588157654, 65.2768112719059, 59.68615606427193, 65.24282589554787, 66.52410194277763, 61.90515339374542, 62.374416813254356, 55.87657928466797, 51.781117245554924, 54.778035432100296, 49.497880563139915, 51.410754919052124, 46.375610902905464, 47.36902579665184, 43.677136301994324, 51.026261150836945, 48.14455658197403, 48.70446793735027, 45.833000019192696, 47.93437086045742, 48.504564464092255, 47.983403429389, 47.060144171118736, 44.83277969062328, 47.114827036857605, 43.52775111794472, 43.12595307826996, 42.53630071878433, 44.80484738945961, 47.448574528098106, 50.25122053921223, 50.40008135139942, 46.15288965404034, 50.7171743363142, 49.37311425805092, 51.940856873989105, 51.96343906223774, 49.026648849248886, 48.78842443227768, 43.31785798072815, 47.96876661479473, 50.07773704826832, 58.76250542700291, 65.6914222240448, 52.58060194551945, 44.76391598582268, 37.26940333843231, 54.638936296105385, 60.60723423957825, 54.655169025063515, 54.86539654433727, 55.20221047103405, 52.21352644264698, 49.00580316781998, 58.578815683722496, 57.71988697350025, 62.958266884088516, 67.53613963723183, 69.09356966614723, 62.1188273280859, 39.13856863975525, 47.522928938269615, 55.20994685590267, 62.5330924987793, 63.3016050606966, 55.34067124128342, 53.5781966149807, 55.96663065254688, 49.3507182598114, 54.773240089416504, 55.86383476853371, 61.95936128497124, 64.21602219343185, 66.10977217555046, 65.85979878902435, 70.20956978201866, 65.50736770033836, 67.95075058937073, 3.8105730386450887, 0.33754485310055315, 0.37855982256587595, 10.313643123954535, 1.1509965942241251, 40.209727361798286, 70.72422936558723, 65.27728244662285, 68.3926060795784, 55.18660090863705, 50.82056678831577, 17.39209044724703, 28.178497552871704, 53.64232577383518, 69.50931295752525, 56.40278644859791, 56.308095529675484, 66.94816678762436, 65.33753201365471, 86.87530070543289, 11.202583573758602, 0.9256114508025348, 0.4844238341320306, 0.23939138482091948, 0.44312670012004673, 0.1280826365109533, 0.13861101062502712], [0.12302722301683389, 0.589683826547116, 0.42455617629457265, 0.26029532484244555, 0.0465183358755894, 0.25913778226822615, 0.21834597660927102, 0.19390491623198614, 0.0920662988210097, 0.04297668841900304, 0.7079108012840152, 56.4794397354126, 53.46717417240143, 68.40416505932808, 47.218166291713715, 38.951060101389885, 43.17422188818455, 58.79513807594776, 23.715021461248398, 3.8680979143828154, 29.806375801563263, 67.35167473554611, 63.57923336327076, 62.80933007597923, 48.8596136122942, 59.013497158885, 9.384576827287674, 0.33542468561790884, 0.23875282611697912, 0.22006725455867127, 0.2602457790635526, 0.5232274706941098, 19.850450232625008, 66.64132565259933, 66.73006609082222, 65.05433320999146, 57.68491365015507, 55.24164855480194, 48.986952379345894, 51.20379142463207, 49.43628206849098, 74.80636551976204, 35.42103052139282, 18.299246169626713, 54.86058980226517, 24.71424624323845, 71.20651468634605, 62.54403971135616, 42.438364773988724, 43.91188770532608, 48.3089205622673, 55.815425366163254, 60.99594958126545, 56.95051945745945, 57.34140448272228, 54.84453946352005, 54.58929196000099, 54.14091981947422, 56.188960522413254, 53.74206282198429, 61.76075354218483, 57.65270657837391, 49.259884133934975, 47.77423985302448, 58.73540148139, 89.58260983228683, 129.93161112070084, 109.48293998837471, 64.56178084015846, 53.924521431326866, 60.71413390338421, 61.51940569281578, 59.47467841207981, 62.19682194292545, 63.49113129079342, 50.355939120054245, 60.229108929634094, 61.79900608956814, 60.092540457844734, 61.058912202715874, 59.228060245513916, 60.60775861144066, 55.32786212861538, 57.017411068081856, 47.105977311730385, 47.27028429508209, 42.486481592059135, 46.05439893901348, 43.15429575741291, 43.08676578104496, 44.18961100280285, 37.96970576047897, 42.71756239235401, 42.84059979021549, 44.41975325345993, 49.980363473296165, 49.22687150537968, 47.01005905866623, 46.04234978556633, 47.995190396904945, 45.39085954427719, 43.456900119781494, 50.226548463106155, 53.475472927093506, 55.88591918349266, 55.543344765901566, 52.85474583506584, 50.585256814956665, 49.10462066531181, 52.4859756231308, 48.90833839774132, 47.498310059309006, 46.02199427783489, 51.07840575277805, 75.49551174044609, 78.7673869729042, 44.78819288313389, 28.265374191105366, 24.077596105635166, 48.89167629182339, 54.78083588182926, 50.46608380973339, 53.843673169612885, 46.942491084337234, 51.841803789138794, 51.06218822300434, 58.626723513007164, 58.809212520718575, 65.10943785309792, 61.70453555881977, 66.02558389306068, 38.98744314908981, 41.03874407708645, 57.27487005293369, 56.77341476082802, 58.64473834633827, 53.89252334833145, 48.56103703379631, 45.98085008561611, 47.21274398267269, 44.178519397974014, 46.55955523252487, 51.71964034438133, 51.40560619533062, 55.7786775380373, 57.61992573738098, 58.559512719511986, 62.36784316599369, 49.15548473596573, 0.2897477522492409, 0.2590646658791229, 0.16171794180991128, 4.420382604002953, 0.925300105009228, 49.472566321492195, 53.80553841590881, 60.47216668725014, 53.38061101734638, 57.96156920492649, 35.04925847053528, 3.9621951151639223, 21.312602274119854, 18.36368501186371, 31.895518898963928, 47.31237843632698, 29.356763027608395, 31.94861724972725, 54.805268570780754, 53.365461230278015, 2.635135087184608, 0.2838469063863158, 0.13901027123210952, 0.2041337892296724, 0.11390262865461409, 0.05588632498984225, 0.1641407422721386, 0.06194821689859964, 0.2694682404398918, 0.34208397672045976, 0.4006394580937922, 0.05427676624094602, 0.4583801206899807, 0.06681562212179415, 0.1444069464923814, 0.09744281735038385, 0.021035597019363195, 0.9630997048225254, 64.74442943930626, 63.224070221185684, 66.8473581969738, 37.783428356051445, 54.01357725262642, 43.782398253679276, 62.26154386997223, 27.292140014469624, 5.862670736387372, 29.067722037434578, 73.33194583654404, 65.10854110121727, 70.22356823086739, 53.91910292208195, 68.81072044372559, 13.051138781011105, 0.14837571477983147, 0.4723921953700483, 0.11671333486447111, 0.3623298247111961, 0.08562085015000775, 22.257425375282764, 67.11556300520897, 65.26887729763985, 67.65467807650566, 59.079298228025436, 56.487008929252625, 49.92604918777943, 51.74425162374973, 50.97848251461983, 75.89385956525803, 37.217619717121124, 24.167451784014702, 60.38416340947151, 24.72578812390566, 69.62474316358566, 54.58084501326084, 45.203639790415764, 45.62704727053642, 54.52325530350208, 58.50201040506363, 62.61492110788822, 54.214575067162514, 57.64531597495079, 55.30529133975506, 55.97373627126217, 58.82510706782341, 58.18777486681938, 57.78091549873352, 63.140866085886955, 60.35517476499081, 54.652794152498245, 55.492906272411346, 73.28384801745415, 98.08820262551308, 118.93691629171371, 86.32569059729576, 54.82124671339989, 51.52659170329571, 60.28060756623745, 63.98216754198074, 59.14460152387619, 60.930346101522446, 62.36559748649597, 48.791635259985924, 57.6724237203598, 62.968701124191284, 61.58647209405899, 60.339884385466576, 54.19318601489067, 58.85865166783333, 53.25701504945755, 52.59734004735947, 42.870967760682106, 42.18317046761513, 41.47067070007324, 46.59046657383442, 43.14615659415722, 46.79638512432575, 44.33065563440323, 40.003588423132896, 43.86087544262409, 43.00154775381088, 45.294948890805244, 51.0214202105999, 49.456162601709366, 47.097591161727905, 45.841659754514694, 48.316698744893074, 46.44528776407242, 46.57925717532635, 50.89789643883705, 51.74447201192379, 52.650487795472145, 52.28452943265438, 52.24245809018612, 49.84860174357891, 50.129494071006775, 53.852462098002434, 52.23485089838505, 49.953187331557274, 52.30187550187111, 44.9019967764616, 61.07011400163174, 76.04538023471832, 62.251626402139664, 41.094015911221504, 26.873664669692516, 49.27703641355038, 51.92223407328129, 51.315752416849136, 57.87963040173054, 51.14797241985798, 52.88220316171646, 50.48892438411713, 56.84115372598171, 58.81973035633564, 63.69243308901787, 60.094041377305984, 67.9863166809082, 42.521321922540665, 44.416181445121765, 62.64106750488281, 67.3131676018238, 67.11563140153885, 57.24243879318237, 51.04629747569561, 47.35354162752628, 50.811709463596344, 51.280463710427284, 51.532678976655006, 54.702092707157135, 54.900719448924065, 57.954892963171005, 63.09934951364994, 64.09349396824837, 66.02447435259819, 52.220271080732346, 0.20076475047972053, 0.08242267605965026, 0.2025462908204645, 1.5016895136795938, 1.9201165297999978, 58.92403855919838, 61.07628867030144, 68.03023472428322, 58.281812220811844, 63.148959651589394, 35.540606305003166, 8.73167971149087, 25.86346797645092, 22.305701784789562, 38.90214912593365, 59.75163035094738, 29.259100668132305, 34.59389090538025, 57.2592680901289, 62.281785383820534, 3.2269526179879904, 0.49699715164024383, 0.07529483002144843, 0.18225187668576837, 0.26469599339179695, 0.05952133462415077, 0.11874753196025267, 0.33651585050392896, 0.6186211144085974, 0.36629856331273913, 0.5931574932765216, 0.12902955757454038, 0.7248622854240239, 0.1982335073989816, 0.21141657343832776, 0.24729044846026227, 0.31446741486433893, 1.3975866185501218, 77.69122391939163, 68.77919733524323, 90.14203861355782, 56.244194358587265, 57.37761273980141, 60.689279437065125, 61.24365448951721, 32.91786544024944, 11.419367641210556, 40.473019033670425, 80.09214028716087, 76.33335918188095, 75.58276265859604, 61.593163534998894, 73.76600414514542, 12.068312019109726, 0.3342083946336061, 1.0751599073410034, 0.3005413996288553, 0.4767648404231295, 1.349376467987895, 28.068368062376976, 73.70789006352425, 68.06531444191933, 71.99463799595833, 63.34206148982048, 61.26934491097927, 53.31955209374428, 55.858241468667984, 56.26342132687569, 81.42013102769852, 37.024894058704376, 17.827244997024536, 66.82185396552086, 36.05598025023937, 69.20336857438087, 50.81617422401905, 46.063784435391426, 48.61760459840298, 54.25367496907711, 61.63860909640789, 66.31712704896927, 58.6691140383482, 63.86815845966339, 61.64356403052807, 60.360619872808456, 62.111113741993904, 61.19383156299591, 60.803166925907135, 67.98130095005035, 61.44860789179802, 56.944443583488464, 56.52115769684315, 78.34863424301147, 97.58252575993538, 107.21019834280014, 73.86552080512047, 52.776850014925, 57.55949757993221, 69.64508727192879, 66.93111330270767, 61.61719724535942, 63.09028699994087, 69.20126348733902, 51.45589269697666, 59.733668714761734, 66.07719272375107, 64.50446471571922, 66.34689465165138, 59.13840025663376, 65.8023002743721, 57.60762579739094, 55.27389742434025, 46.95766367018223, 46.210657954216, 43.932087421417236, 47.503599375486374, 43.48036766052246, 48.852185010910034, 46.352124363183975, 45.33259727060795, 49.53550614416599, 45.13707496225834, 45.60561262071133, 52.958757653832436, 53.63152675330639, 52.491967901587486, 49.45093788206577, 56.34557291865349, 49.4687095284462, 47.925148755311966, 57.042037546634674, 56.60960175096989, 56.14932864904404, 59.53986011445522, 56.47997550666332, 56.13469943404198, 55.42549408972263, 58.90053682029247, 56.13887540996075, 54.77104000747204, 52.58153669536114, 44.1194249689579, 57.936463952064514, 73.59230026602745, 66.36064991354942, 54.18418429791927, 43.101691380143166, 55.621696561574936, 56.83551482856274, 54.07250829041004, 59.724013432860374, 53.38839679956436, 54.90447744727135, 57.87135064601898, 67.57849976420403, 66.76664292812347, 71.34914383292198, 62.825923785567284, 72.73589462041855, 43.42634215950966, 45.559106916189194, 60.49472227692604, 64.55633953213692, 66.83977380394936, 56.794017255306244, 54.72382754087448, 47.78014473617077, 53.60845439136028, 51.87133580446243, 57.20723748207092, 58.578051924705505, 58.04498992860317, 60.147610902786255, 69.63460743427277, 69.35095265507698, 67.59257420897484, 56.117607951164246, 0.6571240327320993, 0.5240301182493567, 2.643917128443718, 11.203138343989849, 2.111437926068902, 64.36300590634346, 66.50994390249252, 71.39412581920624, 63.233957290649414, 66.7426510155201, 48.339345529675484, 11.789307240396738, 30.450245551764965, 24.750209413468838, 50.157551765441895, 71.30831122398376, 38.703879565000534, 50.96734531223774, 67.4746361374855, 79.87498953938484, 6.9927277229726315, 0.7063844113145024, 0.2494621358346194, 0.20021811418700963, 0.3107200440717861, 0.08911053242627531, 0.265538805979304], [0.14094392216065899, 0.6994862970896065, 0.19923896907130256, 0.301749556674622, 0.1172911562025547, 0.17903045110870153, 0.10507524959393777, 0.0372549970052205, 0.058292323228670284, 0.2905285212909803, 0.2862120122881606, 45.28614476323128, 60.641686990857124, 56.96397453546524, 44.17520597577095, 28.943909481167793, 33.744370490312576, 4.843023000285029, 25.16649417579174, 6.28593192435801, 12.262272611260414, 57.276458367705345, 63.50798338651657, 61.470874696969986, 54.899750500917435, 51.21385708451271, 7.236649934202433, 0.2605666243471205, 0.24301009689224884, 0.06076065074012149, 0.31595936918165535, 0.30335568299051374, 11.610389091074467, 61.35903149843216, 64.59530264139175, 67.96888321638107, 58.275253772735596, 59.244798347353935, 44.68932218849659, 52.46373921632767, 49.8112915456295, 80.12554809451103, 55.175015330314636, 57.41220988333225, 54.626940339803696, 27.82550409436226, 51.36080659925938, 67.32728764414787, 49.87327761948109, 41.93141117691994, 50.16250289976597, 52.694136053323746, 57.20405325293541, 54.78317275643349, 58.816553726792336, 58.56461584568024, 57.71711692214012, 54.33016486465931, 55.13232842087746, 50.93939021229744, 52.802886217832565, 47.571121752262115, 50.83981655538082, 61.362166330218315, 69.3390440940857, 95.94210058450699, 77.7913485467434, 47.508341521024704, 54.385995268821716, 57.89212413132191, 57.38936930894852, 57.59634420275688, 59.88709308207035, 58.78040246665478, 57.25128471851349, 58.150115087628365, 53.00416521728039, 50.262057557702065, 61.055724173784256, 53.07203717529774, 59.16525721549988, 58.5124484449625, 58.45255985856056, 62.98070088028908, 56.154994145035744, 47.912354841828346, 32.6409363001585, 35.987260937690735, 40.55141642689705, 53.16467620432377, 26.755084432661533, 29.903850071132183, 44.433124735951424, 51.68229214847088, 50.70424742996693, 56.14800252020359, 54.90556038916111, 53.856759667396545, 52.221376821398735, 61.739980056881905, 46.80892065167427, 48.46551015973091, 59.03477601706982, 60.34894309937954, 56.73962317407131, 57.15442031621933, 58.51600885391235, 54.63875010609627, 50.252485871315, 53.51726308465004, 54.89168733358383, 54.68870982527733, 53.46849650144577, 48.36563631892204, 49.202431216835976, 82.29824110865593, 104.71040368080139, 68.51474672555923, 32.827168107032776, 29.21096485108137, 56.11252762377262, 52.90982387959957, 56.93365976214409, 51.94437548518181, 54.00036536157131, 53.15822035074234, 58.41903045773506, 61.546019464731216, 57.96547919511795, 55.47600097954273, 62.31616593897343, 46.46984964609146, 48.53286534547806, 58.00421431660652, 62.526454254984856, 57.084409072995186, 51.297084018588066, 47.523343116045, 46.880159229040146, 47.897064462304115, 49.49303202331066, 50.84425091743469, 44.003679379820824, 51.213568300008774, 55.29351957142353, 61.669596433639526, 53.497948721051216, 68.59202697873116, 26.207047440111637, 0.17878434009617195, 0.16128967807162553, 0.9312925022095442, 2.6595516270026565, 8.072192799299955, 65.72183579206467, 47.36649513244629, 65.68247750401497, 43.9253655821085, 70.12920409440994, 7.17897710390389, 9.64733462780714, 28.254103995859623, 28.353827744722366, 48.92190366983414, 46.8464208394289, 27.88210205733776, 31.47573072463274, 51.755134239792824, 42.73229040205479, 0.5277771328110248, 0.28622252109926194, 0.1068837966886349, 0.14294887863798067, 0.09513871598755941, 0.10114184464327991, 0.2887974469922483, 0.16677425330271944, 0.38778836955316365, 0.16864458419149742, 0.2441565814660862, 0.03233777511923108, 0.10235782392555848, 0.12583118310431018, 0.13207175448769704, 0.05824746040161699, 0.3915875719394535, 0.2119651244720444, 51.647189632058144, 67.2922383248806, 66.48523762822151, 33.213007003068924, 40.55178880691528, 41.761860474944115, 6.6342630330473185, 27.744636833667755, 9.203832875937223, 13.798666968941689, 58.105448484420776, 69.2195101082325, 64.2291846871376, 60.82703724503517, 56.49192966520786, 11.220505312085152, 0.08043020250624977, 0.7694954029284418, 0.05541501297557261, 0.5527058138977736, 0.3067334939260036, 11.819879449903965, 64.70511674880981, 68.0760982632637, 69.25015926361084, 60.78891009092331, 59.70512844622135, 46.796472519636154, 53.97712580859661, 52.4649703502655, 80.42535960674286, 55.44206880033016, 59.579393193125725, 54.11302171647549, 35.446200370788574, 56.324791833758354, 59.481841027736664, 49.926698952913284, 42.31129579246044, 54.51363801956177, 54.63767096400261, 60.14826826751232, 57.39962875843048, 59.9727138876915, 56.729755103588104, 58.97735349833965, 58.485610485076904, 62.64029994606972, 54.51690964400768, 54.463495910167694, 52.06113941967487, 55.784951001405716, 68.67372259497643, 74.17757526040077, 86.38170719146729, 66.50995150208473, 48.273445665836334, 54.6426372975111, 58.319354206323624, 57.11582578718662, 59.304857924580574, 62.8473774343729, 62.51847468316555, 59.85133700072765, 61.01139575242996, 54.056594744324684, 49.742161855101585, 64.4318962097168, 54.58410523831844, 57.44596727192402, 58.135580867528915, 53.95013965666294, 59.774717912077904, 54.232874885201454, 47.35968969762325, 33.373954966664314, 38.04831974208355, 41.478536278009415, 50.134965777397156, 32.5949701666832, 30.628231801092625, 42.47254014015198, 46.38222634792328, 52.687034234404564, 59.005035012960434, 57.247697710990906, 55.02319447696209, 55.813343077898026, 65.68826079368591, 50.53951106965542, 45.6488087028265, 58.92446033656597, 55.26958465576172, 54.77551616728306, 56.322245970368385, 54.647022262215614, 56.397003158926964, 52.17450253665447, 59.507421255111694, 57.25717060267925, 55.0142003595829, 56.513265520334244, 53.76282870769501, 44.27064545452595, 60.058608278632164, 86.83945342898369, 97.52377331256866, 49.60327550768852, 30.676114931702614, 57.87096306681633, 53.371616899967194, 55.814490616321564, 52.70384453237057, 53.358154222369194, 56.15001641213894, 60.31317941844463, 62.77531810104847, 58.33292327821255, 56.3480693846941, 61.19541607797146, 47.49559320509434, 52.08304904401302, 66.50166034698486, 65.71232110261917, 65.26297241449356, 57.051890417933464, 52.76880584657192, 50.841131284832954, 53.346184864640236, 52.52873852849007, 51.13156870007515, 47.98540212213993, 57.90905982255936, 59.36362937092781, 67.50345379114151, 55.63421688973904, 73.41194674372673, 28.4657184407115, 0.37164618261158466, 0.14269182836869732, 0.38058867619838566, 2.298215953633189, 12.22919063642621, 75.9084203839302, 53.82383443415165, 72.55073055624962, 49.64247800409794, 66.85472220182419, 7.554586473852396, 14.973353035748005, 35.69148860871792, 27.175054997205734, 52.20381036400795, 60.32399743795395, 29.13660854101181, 38.17582190036774, 59.924072697758675, 46.59632205963135, 0.7850775355473161, 0.03157799401378725, 0.10789207852212712, 0.3114112210460007, 0.11889968707691878, 0.02770149880234385, 0.4701923212269321, 0.3333984443452209, 0.8975025184918195, 0.24413586070295423, 0.6053853558842093, 0.2011592613416724, 0.10384747016360052, 0.2095765815465711, 0.21649362053722143, 0.19295906386105344, 0.550773439463228, 0.4109442082699388, 63.09540532529354, 76.8668657541275, 79.49659064412117, 48.81618574261665, 48.27583193778992, 48.16390514373779, 5.554746184498072, 34.73059616982937, 13.560065422207117, 19.275575280189514, 67.78489708900452, 76.66549175977707, 73.9845684170723, 65.08014902472496, 65.39941549301147, 12.718853261321783, 0.2937893697526306, 1.302633157465607, 0.15952578600263223, 0.6915609911084175, 1.2275438429787755, 15.939361900091171, 65.44224679470062, 68.77114176750183, 70.03825977444649, 63.61263357102871, 61.626719534397125, 50.44824376702309, 56.12706944346428, 55.11320784687996, 84.44774016737938, 49.09125678241253, 52.97375164926052, 61.62122502923012, 33.189889043569565, 57.88697920739651, 65.81038624048233, 46.087734550237656, 43.77903163433075, 56.21599227190018, 56.13825984299183, 63.481464609503746, 59.4467119127512, 65.48202306032181, 57.27330453693867, 63.29728849232197, 61.12730473279953, 65.67342638969421, 56.48919761180878, 57.98690624535084, 56.400134190917015, 58.622684329748154, 67.43790730834007, 70.39785727858543, 79.90727260708809, 59.60275813937187, 51.103883385658264, 62.601948603987694, 61.147907227277756, 57.93454125523567, 64.54752400517464, 66.90589025616646, 64.26921173930168, 63.645087629556656, 69.1223569214344, 55.728011056780815, 55.968226566910744, 70.5848528444767, 59.976665675640106, 62.22915440797806, 65.0216169655323, 60.062149688601494, 64.60039436817169, 56.42793729901314, 49.651042744517326, 34.66998942196369, 42.069693356752396, 42.177501171827316, 56.52126409113407, 36.79790943861008, 38.740186616778374, 43.319697082042694, 53.62754836678505, 52.83221684396267, 66.18771359324455, 60.12073114514351, 61.17475278675556, 60.743551924824715, 73.77540484070778, 55.09401127696037, 50.018505826592445, 65.00299036502838, 58.21235194802284, 57.57128834724426, 58.91294315457344, 59.7254079580307, 59.35446806252003, 58.84334608912468, 64.82511430978775, 60.35366244614124, 57.70990490913391, 60.88170111179352, 56.93913906812668, 46.1244747787714, 57.18971662223339, 80.5311307311058, 91.57070115208626, 62.73992300033569, 39.19081583619118, 63.82441520690918, 56.26848265528679, 59.58469770848751, 58.373980075120926, 58.066686764359474, 56.6222170740366, 62.381275445222855, 65.72660833597183, 64.47679460048676, 60.74151523411274, 68.96567612886429, 48.09077046811581, 50.2445936948061, 65.01421496272087, 62.948748394846916, 65.84922775626183, 60.29965594410896, 53.517867252230644, 50.32088980078697, 56.72413520514965, 57.243666127324104, 55.05992330610752, 50.81811212003231, 57.254240959882736, 64.22698080539703, 68.34687933325768, 61.57348819077015, 75.53600996732712, 37.487017661333084, 0.5478952126577497, 0.24874980765162036, 2.8489574510604143, 5.837856167927384, 11.365323141217232, 79.69218134880066, 56.689374670386314, 79.69414204359055, 53.31117354333401, 81.47022753953934, 13.317624181509018, 17.494019977748394, 43.65017294883728, 36.90727137029171, 78.08681309223175, 66.18587449193001, 36.44316427409649, 48.766210824251175, 69.58191186189651, 67.08581820130348, 2.7302893437445164, 0.43366452504415065, 0.18785669468343258, 0.2750629949150607, 0.19793169078184292, 0.2415045167435892, 0.34035839431453496], [0.0588223799422849, 0.37402616115286946, 0.19093751296168193, 0.14824992074863985, 0.07577875483548269, 0.044700363505398855, 0.14304019248811528, 0.0879100343445316, 0.09212544056936167, 0.5086795950774103, 0.4627843218622729, 27.498820424079895, 66.6039128601551, 51.644951552152634, 52.55454674363136, 33.44387121498585, 31.120326295495033, 41.427558213472366, 24.322639256715775, 10.106834471225739, 32.30745479464531, 49.151973724365234, 66.77244141697884, 55.99565349519253, 52.551985681056976, 56.29771828651428, 19.55567914992571, 0.09004924533655867, 0.19892956770490855, 0.12552997504826635, 0.9194055525586009, 0.2814565080916509, 6.226414293050766, 60.62920846045017, 67.0240031182766, 66.58293798565865, 62.320315316319466, 60.01274473965168, 50.57713285088539, 49.813009053468704, 56.94093257188797, 62.98621818423271, 72.31645792722702, 62.782860696315765, 49.69838060438633, 52.511012479662895, 56.00323788821697, 45.352515801787376, 54.682892337441444, 45.320631712675095, 54.145399779081345, 52.42759555578232, 57.33817085623741, 52.765857204794884, 59.16946358978748, 64.29918453097343, 58.15989576280117, 56.72788180410862, 41.95982985198498, 40.04958875477314, 45.77716201543808, 52.109222039580345, 57.492381781339645, 61.78425908088684, 62.63898141682148, 57.65493705868721, 47.36975155770779, 54.112824127078056, 55.90261168777943, 54.87692132592201, 53.87685678899288, 54.744281843304634, 49.811473935842514, 52.531455382704735, 53.928670808672905, 54.644844979047775, 51.68007306754589, 60.055720433592796, 54.79348540306091, 60.53425155580044, 56.257649436593056, 60.080483704805374, 63.41648809611797, 61.86623968183994, 53.9499306678772, 57.25710980594158, 44.29990008473396, 22.817384228110313, 35.47475203871727, 47.64169156551361, 17.478815093636513, 51.25716716051102, 48.871275186538696, 51.523939445614815, 53.209582194685936, 56.02106653153896, 55.51922366023064, 54.71832923591137, 53.57227273285389, 52.65290826559067, 52.62748762965202, 57.164569571614265, 50.57809799909592, 51.7719217389822, 53.86491023004055, 54.85758796334267, 55.730241537094116, 55.04434034228325, 55.43886177241802, 54.53504987061024, 50.38974590599537, 51.73322081565857, 49.62844155728817, 53.09354782104492, 50.42238995432854, 52.97040782868862, 72.01580286026001, 107.62567564845085, 74.9631755053997, 20.44535581022501, 37.58476361632347, 59.70476746559143, 58.59542839229107, 55.72942838072777, 53.56283783912659, 60.379440262913704, 58.53253036737442, 64.27678853273392, 51.84504881501198, 49.936304837465286, 46.827619448304176, 50.46646758913994, 53.80084566771984, 55.13228662312031, 57.730454206466675, 57.32552133500576, 52.059984281659126, 48.697601705789566, 45.32182104885578, 53.17377291619778, 48.778833746910095, 51.08988493680954, 47.36832283437252, 58.78671392798424, 59.726243913173676, 66.61256119608879, 55.68181313574314, 71.23316645622253, 8.651369120925665, 2.0665174489840865, 0.031589549253112637, 0.20888197585009038, 1.0052868817001581, 21.605606451630592, 63.38723726570606, 53.70587736368179, 58.91307234764099, 42.19316393136978, 44.25261542201042, 3.145332522690296, 31.84226855635643, 17.071060873568058, 29.55580584704876, 48.65127459168434, 46.39758512377739, 24.3287493288517, 38.61362300813198, 55.14156952500343, 24.685688875615597, 0.3997119516134262, 0.12134662218159065, 0.07703691037022509, 0.27915267390199006, 0.1494360508513637, 0.21232398255961016, 0.18300031777471304, 0.05139915912877768, 0.14772983849979937, 0.2871270210016519, 0.2687227976275608, 0.10724140054662712, 0.052469057773123495, 0.07864007551688701, 0.05666076722263824, 0.06711090783937834, 0.7285343133844435, 0.604987267870456, 31.2021055072546, 74.19832214713097, 57.75448031723499, 47.51829318702221, 37.42813602089882, 40.34168668091297, 31.762497536838055, 36.45443446934223, 12.525368593633175, 39.50666628777981, 57.48878717422485, 69.31163236498833, 60.99377229809761, 57.378596886992455, 61.07066497206688, 20.291633158922195, 0.06948563939658925, 0.8631366875488311, 0.005882752302568406, 1.2940285191871226, 0.13462943286867812, 7.589267687872052, 65.340017080307, 70.03119215369225, 67.7223752439022, 64.37740713357925, 60.94250924885273, 55.22253938019276, 50.51149517297745, 58.61315444111824, 63.222930282354355, 71.49020746350288, 59.88825961947441, 51.4995713531971, 52.80991584062576, 62.69179478287697, 43.77316854894161, 56.385075598955154, 44.10204850137234, 53.49668338894844, 54.56281118094921, 63.01166921854019, 57.2939982265234, 60.13390123844147, 64.128847271204, 60.174160078167915, 59.03392106294632, 46.00648730993271, 47.85114772617817, 52.48198963701725, 60.28729520738125, 63.0629550665617, 65.62206074595451, 61.142709106206894, 55.15867240726948, 53.48746508359909, 61.58239111304283, 56.19691729545593, 54.899020940065384, 55.10659620165825, 59.68679443001747, 52.856926918029785, 54.68627415597439, 53.33334915339947, 58.47686715424061, 54.83803041279316, 61.97723172605038, 58.804994747042656, 59.05506692826748, 58.244194239377975, 60.40188565850258, 61.054154857993126, 59.40533973276615, 53.521693646907806, 61.58642269670963, 41.80265508592129, 24.161279015243053, 38.68653729557991, 53.03348444402218, 26.444920375943184, 47.38462395966053, 49.41396966576576, 50.547114461660385, 53.55561442673206, 55.83616845309734, 55.82675635814667, 56.750418394804, 54.88707438111305, 59.057593792676926, 57.28815034031868, 57.73480497300625, 51.78635336458683, 53.37425775825977, 50.646251142024994, 53.62198166549206, 52.498279362916946, 58.00687417387962, 53.266408145427704, 54.54303704202175, 51.77664868533611, 54.69214864075184, 51.59463845193386, 55.01641944050789, 56.151403337717056, 52.84593030810356, 53.82092759013176, 89.33019697666168, 86.87268644571304, 26.81312821805477, 36.98636792600155, 60.90705715119839, 55.55377520620823, 55.25625117123127, 53.66589970886707, 61.91570922732353, 58.36373582482338, 64.64337766170502, 51.48380979895592, 51.5509369969368, 48.41966561973095, 50.4844406247139, 52.94953554868698, 60.02535626292229, 63.72543431818485, 63.829795718193054, 56.916017308831215, 58.59994255006313, 51.343441531062126, 56.69105038046837, 51.50247819721699, 54.113998264074326, 50.99930539727211, 64.08226937055588, 62.673107385635376, 71.67901933193207, 57.166883647441864, 73.18782716989517, 11.610641777515411, 2.4271950451657176, 0.005075266408312018, 0.7599944877438247, 0.4447489161975682, 26.743310764431953, 69.57074046134949, 59.19582277536392, 67.39746987819672, 48.28805588185787, 47.08692893385887, 5.091647934168577, 33.91927510499954, 23.696377761662006, 29.106804840266705, 56.857629641890526, 59.99697558581829, 25.67904867231846, 43.027720749378204, 62.971873953938484, 27.20507338643074, 0.7324935821816325, 0.38107496104203165, 0.0749910541344434, 0.1979411012143828, 0.027052243895013817, 0.28305957675911486, 0.10056181170511991, 0.4392118414398283, 0.3641357668675482, 0.3381838125642389, 0.3189430106431246, 0.24266352877020836, 0.2748760033864528, 0.16022227675421163, 0.1671046277624555, 0.17785851086955518, 0.9181906271260232, 0.7592255040071905, 41.437323689460754, 85.6972499191761, 71.03610903024673, 63.55127826333046, 49.39512647688389, 51.05108521878719, 42.30968847870827, 37.40467227995396, 15.211291518062353, 43.84454011917114, 58.483721986413, 76.56187891960144, 66.5454263985157, 65.39734840393066, 72.46852576732635, 26.965906620025635, 0.2525668661110103, 1.1466094921343029, 0.22605044912779704, 2.054844475351274, 0.4193281615152955, 11.897005811333656, 68.47018271684647, 67.52690613269806, 73.04226458072662, 67.02672377228737, 66.15685924887657, 58.00481468439102, 53.208981826901436, 61.24478682875633, 67.98089057207108, 79.84804138541222, 63.105801567435265, 51.36166155338287, 55.58510072529316, 64.22001957893372, 50.55078886449337, 56.775443851947784, 45.450014770030975, 57.93438546359539, 57.152452021837234, 63.1710022687912, 57.338421642780304, 63.962454199790955, 67.86451041698456, 62.97264151275158, 61.730864346027374, 52.24775120615959, 48.18729668855667, 53.7437841296196, 59.869458228349686, 62.83686339855194, 62.79650196433067, 58.073685988783836, 56.766062155365944, 59.710748344659805, 63.47455658018589, 56.722508892416954, 61.094938069581985, 61.72258459031582, 61.58353105187416, 57.158953472971916, 59.04794231057167, 57.29623630642891, 60.02500668168068, 60.565265491604805, 69.062160551548, 62.095747366547585, 69.96265143156052, 61.89283065497875, 63.963259756565094, 66.16055265069008, 65.32779693603516, 57.92554333806038, 63.45023788511753, 50.466178804636, 28.05764313787222, 44.65236537158489, 57.28726878762245, 40.61193957924843, 56.88514016568661, 51.587422639131546, 53.90125907957554, 59.97834898531437, 62.38510563969612, 62.66487702727318, 64.23693627119064, 60.958506390452385, 62.56043963134289, 60.55038169026375, 63.791980147361755, 53.61520282924175, 57.36584857106209, 55.52175052464008, 58.58517274260521, 57.898811772465706, 59.90107633173466, 58.55181813240051, 61.42756462097168, 56.956029161810875, 58.81664112210274, 55.097579285502434, 61.49971514940262, 57.9440825432539, 57.06108592450619, 52.54777170717716, 83.0855056643486, 76.66316628456116, 27.296435683965683, 42.80404955148697, 64.48792040348053, 59.45553503930569, 58.57850030064583, 58.79684418439865, 64.65752810239792, 59.52583886682987, 67.69469752907753, 55.92613622546196, 54.67493176460266, 49.12877976894379, 47.64992192387581, 53.33359993994236, 60.01554898917675, 63.71935844421387, 63.398268073797226, 59.5744838565588, 57.431136667728424, 53.74285317957401, 60.74341133236885, 55.98500266671181, 59.88586574792862, 53.017247915267944, 66.16904899477959, 66.37720182538033, 74.23914715647697, 61.85676299035549, 80.30874386429787, 19.323030933737755, 3.472556001506746, 0.1533481338992715, 1.1726464075036347, 1.6215077717788517, 28.48877750337124, 76.72560453414917, 62.09002107381821, 73.47788080573082, 50.06798297166824, 56.06181174516678, 8.879600074142218, 42.35767990350723, 25.498286671936512, 38.07422675192356, 69.12358805537224, 58.902657106518745, 32.53868378698826, 53.51567097008228, 75.46980232000351, 45.00943601131439, 1.0407979949377477, 0.5608142225537449, 0.17877460311865434, 0.262121690902859, 0.1747523556696251, 0.4927906289231032, 0.282325919251889], [0.18542301433626562, 0.16140966850798577, 0.11996418659691699, 0.05766427704656962, 0.146234069543425, 0.12480270001105964, 0.052749571041204035, 0.05505930901563261, 0.15699547802796587, 0.27585302595980465, 0.37633795116562396, 11.586060896515846, 67.19720542430878, 51.37683793902397, 52.447153106331825, 29.47765164077282, 37.94579744338989, 46.453833505511284, 39.75927673280239, 2.3953855270519853, 27.32296396046877, 66.4634419977665, 59.84470255672932, 63.97709861397743, 51.721889823675156, 59.680855348706245, 28.832106180489063, 0.15744104865007102, 0.3237465466372669, 0.07349950799834915, 1.0170949855819345, 0.1797124551376328, 4.573104958981276, 49.32634636759758, 55.82719333469868, 70.83491742610931, 63.213616982102394, 61.39889895915985, 53.84353257715702, 49.41862441599369, 52.84525774419308, 62.28820703923702, 62.15438961982727, 60.17029568552971, 63.751763105392456, 47.17478781938553, 47.26997651159763, 48.59745427966118, 44.87331971526146, 50.07242873311043, 50.975925251841545, 55.15936017036438, 50.87853267788887, 58.34114983677864, 60.20295113325119, 47.08142302930355, 62.658390775322914, 32.40084998309612, 27.054977640509605, 55.13839669525623, 55.52197091281414, 60.170120894908905, 54.89650547504425, 56.57718189060688, 54.69649560749531, 52.07665018737316, 55.954353511333466, 48.56780827045441, 50.16250669956207, 53.550564497709274, 52.61346258223057, 48.98416332900524, 54.917210564017296, 53.9341539144516, 49.9678735435009, 52.43449978530407, 51.18839085102081, 52.91271932423115, 51.653998866677284, 56.15350842475891, 51.67718142271042, 56.22000105679035, 55.58728940784931, 59.16186399757862, 56.700120493769646, 50.88373459875584, 56.67482905089855, 20.819229148328304, 34.06554825603962, 33.31076815724373, 54.849312007427216, 51.9319349527359, 40.570681393146515, 54.890300408005714, 52.694778218865395, 54.08081844449043, 52.06615895032883, 51.643374636769295, 47.53829151391983, 48.04564788937569, 46.70263655483723, 47.94695198535919, 47.71756209433079, 48.13307359814644, 50.10148957371712, 56.71996682882309, 56.02839253842831, 52.159626334905624, 56.31682746112347, 54.91330437362194, 53.34586948156357, 49.24778938293457, 52.09304630756378, 48.18224675953388, 55.7754173129797, 51.699816808104515, 52.94670470058918, 61.41219824552536, 81.75565302371979, 37.75998741388321, 22.04811740666628, 55.726434141397476, 54.67650108039379, 61.19115650653839, 57.11071506142616, 60.67208915948868, 53.936961963772774, 61.119249165058136, 55.09611636400223, 55.564395636320114, 42.703674137592316, 63.68426352739334, 74.69164207577705, 52.93903671205044, 60.441722720861435, 56.40419237315655, 56.03161856532097, 49.048729464411736, 47.38467335700989, 48.961201161146164, 50.45748487114906, 49.4426429271698, 51.43244415521622, 61.36969372630119, 58.361322954297066, 63.680372536182404, 61.46470382809639, 55.87743803858757, 0.6994249660056084, 2.707925643771887, 0.05608608516922686, 0.7719956093933433, 0.3791413991712034, 30.112227089703083, 60.60112036764622, 53.378084152936935, 36.996209397912025, 51.186848133802414, 37.32268787920475, 2.9402753384783864, 26.430925726890564, 15.819261744618416, 32.52190388739109, 46.1574874073267, 24.20770112425089, 23.25630247592926, 43.9536664634943, 48.17299045622349, 15.223209578543901, 0.98186832270585, 0.45032487949356437, 0.06631836091401055, 0.2183570494526066, 0.04028996540000662, 0.10349996693548746, 0.016124698231578805, 0.3193931083660573, 0.09450132245547138, 0.08509227773174644, 0.08726451429538429, 0.1939473967649974, 0.04873627760389354, 0.041319160955026746, 0.06091876159189269, 0.17406904546078295, 0.5599378352053463, 0.3215432883007452, 13.954001683741808, 74.19686302542686, 58.56281094253063, 48.570688515901566, 34.4093994051218, 52.86475829780102, 42.53606133162975, 46.31263688206673, 5.0694067776203156, 28.166809380054474, 71.86957150697708, 66.95616915822029, 69.58982303738594, 58.57771374285221, 66.58678337931633, 32.51764811575413, 0.2081981164519675, 0.4673523595556617, 0.1738807774381712, 2.4391655903309584, 0.14972799690440297, 6.571753537282348, 53.78713600337505, 60.857207626104355, 72.76307076215744, 68.1499283015728, 64.84301134943962, 57.34615422785282, 49.66218374669552, 57.38199010491371, 62.50930577516556, 62.06620015203953, 62.92099468410015, 67.84966841340065, 49.084033370018005, 52.79748670756817, 49.795309603214264, 47.58944056928158, 53.552965968847275, 51.10332481563091, 55.55665545165539, 54.428552985191345, 60.23100882768631, 62.27949030697346, 49.86567422747612, 66.20325475931168, 33.20796847343445, 34.05517481267452, 63.60110118985176, 58.66626799106598, 59.749491065740585, 56.06269329786301, 62.23264642059803, 52.33514651656151, 60.311439111828804, 57.804269045591354, 52.0880875736475, 52.43065059185028, 55.25098465383053, 53.423267528414726, 52.17396296560764, 54.530452117323875, 56.79130420088768, 52.432162910699844, 51.72969080507755, 55.397497192025185, 55.23839972913265, 56.244467943906784, 56.958970203995705, 57.46455207467079, 60.693884789943695, 57.6508142799139, 58.9773079007864, 54.69914026558399, 54.88022334873676, 66.5798069536686, 26.144728884100914, 33.981815949082375, 48.372259363532066, 50.0642553716898, 53.187706768512726, 46.2117674946785, 55.89302860200405, 55.88550120592117, 56.73095963895321, 54.049538522958755, 55.40541596710682, 53.8712140917778, 52.57780909538269, 51.15301854908466, 52.31896698474884, 50.68415030837059, 51.13314561545849, 51.09996199607849, 52.51076929271221, 51.54983505606651, 54.497960060834885, 56.255342960357666, 54.508147314190865, 52.06367768347263, 54.65364530682564, 53.31740900874138, 52.540175914764404, 55.35616680979729, 54.97541964054108, 54.75053630769253, 47.30694092810154, 72.90970489382744, 49.6606258302927, 24.24579218029976, 55.59757925570011, 57.1687987446785, 61.22962184250355, 57.11045287549496, 61.64749301970005, 55.900844782590866, 61.99613571166992, 57.20672070980072, 54.7410786151886, 47.55540959537029, 55.955295860767365, 65.026153922081, 63.01206819713116, 62.10601061582565, 65.3779162466526, 56.384809613227844, 56.482061594724655, 52.2143130004406, 55.14417998492718, 52.16431148350239, 52.04772233963013, 53.21009896695614, 66.25210493803024, 60.953224673867226, 67.53101751208305, 65.67592665553093, 57.96497002243996, 1.2759858998470008, 1.4677131618373096, 0.1386232115328312, 0.9740239998791367, 0.41982412396464497, 38.24047163128853, 67.13605150580406, 59.3501590937376, 38.75906780362129, 60.91380178928375, 40.16709364950657, 4.353989716619253, 32.62417919933796, 20.447168312966824, 29.79780536144972, 52.99078233540058, 31.88309356570244, 26.63096409291029, 50.530520752072334, 62.472850531339645, 20.882282964885235, 1.0120955226011574, 0.3895069460850209, 0.09960606650565751, 0.2484469223418273, 0.03924886950699147, 0.09762560090166517, 0.12472257774788886, 0.551590514369309, 0.18950130877783522, 0.2441979487775825, 0.13858714315574616, 0.3636046266183257, 0.31666969356592745, 0.17442324286093935, 0.15940879384288564, 0.2540730102919042, 0.6433061335701495, 0.4903265502071008, 18.425460197031498, 86.76269754767418, 70.24932324886322, 64.80733126401901, 43.002467304468155, 69.04606461524963, 50.89003466069698, 52.001311630010605, 6.01697713136673, 38.070335760712624, 76.69526696205139, 73.72273206710815, 74.20205354690552, 65.22506564855576, 72.45579645037651, 37.21706874668598, 0.6670856731943786, 1.3250012509524822, 0.5129249766469002, 4.117513205856085, 0.1871046467567794, 8.248853869736195, 56.479264944791794, 65.8678163588047, 72.48997181653976, 71.23019501566887, 65.91955438256264, 63.13504859805107, 50.830275267362595, 60.40892668068409, 63.65459851920605, 64.47999402880669, 62.48054511845112, 69.14802074432373, 46.34971149265766, 60.51530957221985, 50.343608781695366, 47.754184529185295, 52.18293808400631, 55.379885137081146, 60.68861447274685, 59.56001803278923, 64.30323511362076, 62.69161619246006, 51.01266548037529, 69.70403730869293, 37.09033414721489, 36.19378745555878, 61.929380893707275, 54.82623964548111, 60.67129500210285, 61.56974919140339, 61.34855926036835, 55.202712044119835, 63.01185920834541, 57.50001177191734, 55.071280896663666, 54.89930972456932, 59.62350882589817, 55.58075375854969, 55.840002447366714, 59.75775942206383, 60.35631850361824, 56.67256437242031, 60.159128084778786, 59.34163995087147, 60.87749853730202, 59.369507655501366, 59.312001541256905, 57.5415663421154, 64.57024678587914, 62.55772277712822, 63.424566462635994, 60.47510392963886, 56.35048985481262, 66.44365265965462, 37.217688113451004, 36.871260702610016, 54.717949256300926, 70.74015811085701, 60.39891041815281, 54.04375143349171, 59.36680220067501, 63.77445548772812, 62.120829820632935, 59.001991376280785, 61.05270333588123, 56.27447113394737, 57.55371429026127, 54.69670079648495, 54.59552742540836, 55.047741159796715, 53.3968323469162, 54.4508957862854, 61.634695306420326, 57.80568636953831, 58.78694951534271, 60.041501596570015, 57.60722301900387, 56.81680463254452, 56.91826678812504, 56.47095859050751, 53.98022264242172, 59.40299905836582, 56.62175729870796, 59.4870163500309, 51.1442182213068, 63.76120179891586, 36.33309178054333, 22.81442228704691, 61.38970725238323, 58.00271339714527, 61.70375280082226, 57.97665059566498, 66.66786342859268, 58.20560351014137, 65.30464857816696, 57.489714324474335, 55.577045157551765, 47.6535165309906, 57.08921581506729, 62.93515272438526, 60.510597825050354, 65.89880749583244, 66.18281185626984, 59.39478009939194, 56.969560235738754, 53.511213809251785, 57.593216970562935, 57.78210483491421, 55.81750385463238, 55.2716251462698, 69.22669172286987, 64.35271605849266, 71.5469080209732, 67.54999369382858, 67.33547240495682, 2.7954629715532064, 4.7373283468186855, 0.2431638105190359, 1.3606948731467128, 0.33480463607702404, 40.0224582105875, 71.9525894522667, 64.13731321692467, 49.44417804479599, 63.08321937918663, 49.264694675803185, 10.153552014380693, 35.891897454857826, 23.121151328086853, 39.583232179284096, 64.38836574554443, 33.10214415192604, 32.71779477596283, 56.30353197455406, 71.94880485534668, 30.13373963534832, 1.2354958662763238, 0.8099168026819825, 0.25160287565086037, 0.34797826199792325, 0.2709557715570554, 0.38736950140446424, 0.2602803037734702], [0.018518480719649233, 0.13574637996498495, 0.18849031068384647, 0.09670956802438013, 0.04188291117316112, 0.032757066292106174, 0.043703109986381605, 0.06264061841648072, 0.13377259369008243, 0.11753710394259542, 0.07182517831097357, 3.4593502851203084, 61.75570361316204, 52.38113544881344, 52.939933463931084, 27.383939288556576, 39.06491719186306, 24.65070605278015, 46.208438873291016, 24.257828034460545, 3.2954194815829396, 49.362676218152046, 47.199756279587746, 62.79490984976292, 53.19228172302246, 60.19013062119484, 30.758568607270718, 0.8801354316528887, 0.07915171954664402, 0.014611948008678155, 0.3417766385246068, 0.19294843630632386, 2.3081488581374288, 42.562739700078964, 63.996523171663284, 71.70097455382347, 63.765054792165756, 64.01332587003708, 55.50535440444946, 50.958989560604095, 48.096633553504944, 61.551738157868385, 63.205101639032364, 66.52766615152359, 58.56563799083233, 64.19906750321388, 43.63117776811123, 46.186392456293106, 58.81372667849064, 47.49932840466499, 53.576376512646675, 49.78577971458435, 51.83476656675339, 54.89719323813915, 40.40120668709278, 57.169619500637054, 36.04987017810345, 20.28477642685175, 59.47316609323025, 61.755031049251556, 56.05713799595833, 52.91268512606621, 53.539510890841484, 52.70562283694744, 54.84008610248566, 53.40696640312672, 51.634114533662796, 54.66873049736023, 50.7924634963274, 51.10569588840008, 55.537272691726685, 54.45303127169609, 51.527173072099686, 50.247386544942856, 50.80065965652466, 50.3294887393713, 48.01911011338234, 50.97144529223442, 50.88088855147362, 53.136375322937965, 51.91361613571644, 48.4391737729311, 56.030140444636345, 52.79651015996933, 58.112402111291885, 47.813799530267715, 32.2833526879549, 33.9031183719635, 27.366298735141754, 38.01409877836704, 74.83202174305916, 54.32520993053913, 50.38063779473305, 48.34009788930416, 52.04104229807854, 49.61207963526249, 47.220962941646576, 50.586791932582855, 49.15529854595661, 46.14103049039841, 47.980302795767784, 46.53067298233509, 43.44448238611221, 42.03737609088421, 48.07444654405117, 52.40225851535797, 54.44713778793812, 53.00972431898117, 55.444781854748726, 50.85328683257103, 49.30283322930336, 48.78406226634979, 48.64387258887291, 52.1917612105608, 51.41624562442303, 49.07373212277889, 51.872160360217094, 55.7356296479702, 57.83136539161205, 54.84608598053455, 28.670559749007225, 41.969963908195496, 51.159459203481674, 52.064965814352036, 60.30018791556358, 60.52947141230106, 56.925733387470245, 58.887932896614075, 54.08899560570717, 53.736697509884834, 48.034533485770226, 63.83478105068207, 59.36252363026142, 60.88130593299866, 57.03096494078636, 57.524281069636345, 52.99778915941715, 50.80690652132034, 47.46890343725681, 49.463587403297424, 48.12107004225254, 46.77629180252552, 54.92388680577278, 59.24064137041569, 60.06402678787708, 62.461367547512054, 63.38030643761158, 26.5504939109087, 0.07730003882898018, 0.45177043473813683, 0.08074309938820079, 0.8803671004716307, 1.681571148801595, 47.69668981432915, 56.41137398779392, 51.10706761479378, 45.34961275756359, 73.25588911771774, 16.304623000323772, 2.9478533193469048, 30.829662792384624, 15.96109863370657, 36.42718233168125, 52.1861033141613, 29.35617595911026, 21.300441026687622, 45.71034640073776, 53.45290593802929, 8.971019368618727, 0.5195436871144921, 0.44229415885638446, 0.05968567209492903, 0.20038880815263838, 0.03898904731613584, 0.10853629239136353, 0.13343877566512674, 0.14043065282749012, 0.08111074450425804, 0.11793695084634237, 0.11809725474449806, 0.018806721600412857, 0.09143392962869257, 0.06558253633556888, 0.027353850855433848, 0.10301455782609992, 0.3331730986246839, 0.11569001711905003, 3.6906870966777205, 70.19710645079613, 62.312210351228714, 51.19246043264866, 28.544892892241478, 51.50968261063099, 22.204184532165527, 43.66890214383602, 25.946541018784046, 3.5661046067252755, 49.18184392154217, 57.292117327451706, 69.5664694905281, 59.652444273233414, 66.95895820856094, 34.197412580251694, 1.369098003488034, 0.16471984010422602, 0.14994011755334213, 0.6859231030102819, 0.11594335664995015, 1.6897747898474336, 47.04558715224266, 63.6073974519968, 72.03427746891975, 69.21490475535393, 67.95047700405121, 57.65047609806061, 54.25072632730007, 51.1582812666893, 61.05253994464874, 63.897454887628555, 66.56187191605568, 60.49941502511501, 69.03946816921234, 46.71143688261509, 51.77081599831581, 59.086559638381004, 48.15472863614559, 53.225993514060974, 55.15095502138138, 55.56122660636902, 59.40470136702061, 45.295952036976814, 62.84224770963192, 35.15386685729027, 29.934113547205925, 73.1798779964447, 61.284407302737236, 60.19276387989521, 53.79703067243099, 55.44916681945324, 58.04739899933338, 58.05354706943035, 54.001440703868866, 56.48126743733883, 56.63066402077675, 51.86228848993778, 52.4858084321022, 55.44978618621826, 58.00318457186222, 54.58056382834911, 53.88357102870941, 56.726118698716164, 55.37765085697174, 52.82756969332695, 54.9694387614727, 56.05564467608929, 55.922119840979576, 54.82699200510979, 55.04434034228325, 59.6750682592392, 54.079138934612274, 61.902736723423004, 54.69849430024624, 46.96848548948765, 46.46513409912586, 35.89914746582508, 36.98182716965675, 63.02798934280872, 53.88671725988388, 52.95339994132519, 57.722976207733154, 53.023730367422104, 55.17922170460224, 52.710471376776695, 53.52402672171593, 51.443786546587944, 51.313822120428085, 51.39183573424816, 48.939025551080704, 50.62608182430267, 47.28331759572029, 53.38918715715408, 51.37670874595642, 51.95393197238445, 51.992290914058685, 54.578910917043686, 50.19239589571953, 51.74832880496979, 50.84324777126312, 51.650981828570366, 51.47638499736786, 54.80988912284374, 53.15082214772701, 54.594911858439445, 56.77825190126896, 54.85708639025688, 65.43311968445778, 35.598420202732086, 40.84646679461002, 55.54099649190903, 54.332562536001205, 62.21028082072735, 59.14688520133495, 60.56786835193634, 57.974024936556816, 54.47706878185272, 52.665322199463844, 53.25247809290886, 59.68474633991718, 55.38989380002022, 64.95977908372879, 60.090773552656174, 62.60102145373821, 57.20840781927109, 53.89600396156311, 50.84291718900204, 54.9729535728693, 50.07476180791855, 50.684910267591476, 57.19626747071743, 61.65115222334862, 61.9159410148859, 65.95086470246315, 66.84545829892159, 32.581264302134514, 0.13656459777848795, 0.5129512189887464, 0.09207307462929748, 0.49991999636404216, 2.4268817994743586, 56.89673714339733, 59.147983342409134, 60.44778719544411, 45.48821412026882, 76.36299759149551, 16.059813536703587, 6.942929970100522, 37.182513400912285, 21.162339337170124, 29.07030399888754, 59.013618752360344, 36.617639511823654, 23.545176275074482, 53.27846109867096, 64.49747309088707, 11.542903762310743, 0.6482544774189591, 0.4317471123067662, 0.13684976060176268, 0.4112861305475235, 0.05296974028169643, 0.07230150353279896, 0.07527517052949406, 0.3178059810306877, 0.19077379518421367, 0.27461503457743675, 0.20314412045991048, 0.12748661771183833, 0.14071891782805324, 0.27380354062188417, 0.35380147921387106, 0.23657797719351947, 0.5040359473787248, 0.16214059491176158, 6.5206358302384615, 87.63243287801743, 72.8222107887268, 70.09739980101585, 32.33120732009411, 68.20184111595154, 32.79291674494743, 56.695366948843, 30.33678364008665, 8.738067168742418, 57.61758126318455, 64.4908158481121, 71.97792649269104, 65.23388877511024, 72.62487217783928, 39.28155116736889, 2.8545298520475626, 2.57800349034369, 0.3412434202618897, 1.53685211436823, 0.23113436851417646, 4.300473388284445, 49.34001423418522, 65.24401143193245, 73.04329812526703, 72.9005777835846, 68.89373078942299, 61.526116132736206, 52.6171749830246, 52.62990429997444, 62.92734034359455, 69.36672180891037, 69.40710604190826, 61.20384782552719, 67.69018337130547, 49.64833728969097, 57.6944587379694, 54.01211813092232, 52.37171195447445, 56.828971579670906, 57.46672175824642, 60.43795332312584, 65.65749764442444, 48.66496905684471, 64.50278520584106, 40.75158968567848, 26.17021031677723, 65.49260929226875, 62.980218306183815, 64.2289263010025, 57.46359072625637, 59.506984278559685, 60.99354811012745, 60.901935026049614, 57.41176150739193, 60.6682513654232, 58.40730808675289, 53.23471024632454, 56.125458329916, 58.45389358699322, 61.033255979418755, 59.263132363557816, 56.70142002403736, 60.22034280002117, 60.983691439032555, 56.88751883804798, 65.6005311012268, 60.720331370830536, 60.91063275933266, 57.2337182611227, 55.940522253513336, 62.50759966671467, 59.20803911983967, 66.58346235752106, 61.4176357537508, 42.92405091226101, 46.45971558988094, 42.545059248805046, 44.57217067480087, 73.14362034201622, 70.67589595913887, 64.52865421772003, 61.901790574193, 59.29083287715912, 61.91375233232975, 57.54019841551781, 59.13695253431797, 57.29858838021755, 54.989516884088516, 59.19628255069256, 56.3233707100153, 55.4005978256464, 52.182839289307594, 58.779893293976784, 56.68774835765362, 54.21117044985294, 57.33246736228466, 59.287922233343124, 55.07554806768894, 53.280136808753014, 52.86134988069534, 56.392614394426346, 55.573245361447334, 57.96596176922321, 55.160796493291855, 55.18617533147335, 60.62590643763542, 58.14792640507221, 55.01598246395588, 26.514730229973793, 41.65987394750118, 55.342453345656395, 58.21050524711609, 62.68053978681564, 64.30790886282921, 60.430273935198784, 62.85188399255276, 58.88118825852871, 57.631366923451424, 48.5780069231987, 64.40674155950546, 68.44426810741425, 65.5861222743988, 62.06964656710625, 63.07865962386131, 60.96635676920414, 56.237316727638245, 56.14524006843567, 58.99191811680794, 53.43207165598869, 53.86325351893902, 61.66007414460182, 65.64647823572159, 66.71441093087196, 71.62901401519775, 65.40219694375992, 40.70996671915054, 0.5786952911876142, 1.8615382793359458, 0.2781005162978545, 2.26266173645854, 2.3766185715794563, 61.14165656268597, 65.6409153342247, 67.27504044771194, 54.129098653793335, 85.97784966230392, 25.233378186821938, 8.938520662486553, 43.44111576676369, 25.338433049619198, 43.04294653236866, 81.8809475004673, 41.890882551670074, 33.65485109388828, 58.99491995573044, 75.49725964665413, 19.07474845647812, 1.2819809094071388, 0.7098859234247357, 0.2945528912823647, 0.5110988183878362, 0.19279068539617583, 0.2575514861382544, 0.14402536384295672], [0.14039329311344773, 0.12256128786248155, 0.06884857983095571, 0.029610957572003826, 0.11954918503761292, 0.04175212619884405, 0.04929130387608893, 0.02568107967817923, 0.06076583835238125, 0.17614993848837912, 0.010061765460704919, 1.0106257139705122, 47.33170799911022, 54.96896758675575, 51.652653738856316, 36.57061703503132, 36.1758866161108, 40.13874337077141, 25.50873041152954, 48.87487359344959, 6.918000932782888, 24.771655462682247, 58.122596964240074, 44.95101034641266, 63.29866021871567, 58.19531746208668, 44.49493981897831, 0.5539784487336874, 0.4347036505350843, 0.1809790637344122, 0.1674417409230955, 0.47836033918429166, 1.6844162461347878, 38.82956922054291, 72.74129793047905, 64.74067524075508, 64.15507346391678, 61.18903622031212, 59.47688229382038, 49.934416338801384, 52.774733528494835, 50.361779406666756, 57.97027453780174, 58.95215705037117, 65.22874385118484, 63.79594713449478, 56.71663820743561, 33.965609818696976, 59.83104228973389, 50.35185433924198, 47.42720067501068, 53.805101439356804, 54.050214886665344, 48.34846504032612, 55.18284671008587, 35.31473122537136, 25.180699713528156, 58.68123158812523, 68.23481574654579, 55.33074997365475, 54.36552196741104, 53.76385845243931, 54.81022350490093, 48.51139269769192, 51.168909296393394, 54.24190320074558, 54.457245245575905, 52.701047882437706, 53.38582433760166, 54.103982001543045, 54.44033995270729, 56.955953165888786, 56.26238018274307, 54.0021588653326, 49.19136621057987, 48.06970439851284, 48.360612988471985, 48.21435123682022, 49.69868078827858, 46.714476719498634, 54.031675681471825, 46.61204941570759, 51.524232029914856, 51.13562688231468, 52.89271719753742, 43.14750172197819, 22.293156757950783, 36.893272921442986, 35.02521336078644, 36.425214037299156, 52.97250151634216, 57.34702058136463, 48.70805874466896, 46.37258246541023, 47.433645129203796, 48.229257836937904, 43.675620183348656, 45.77490493655205, 47.733278051018715, 45.50777927041054, 42.174841314554214, 43.15781056880951, 40.32227352261543, 45.48904627561569, 47.59292118251324, 50.91379098594189, 56.89024709165096, 54.268444776535034, 53.53359080851078, 53.83551500737667, 50.830480456352234, 48.22510085999966, 49.01975981891155, 48.79344776272774, 48.53484503924847, 48.041787296533585, 52.38861344754696, 53.848244324326515, 56.07990637421608, 54.17217314243317, 38.89397956430912, 33.64725150167942, 47.91325159370899, 46.71795733273029, 60.37868030369282, 55.503496304154396, 54.174719005823135, 54.10030759871006, 57.159588038921356, 51.05887100100517, 61.57913848757744, 36.80781930685043, 22.99849011003971, 61.10740900039673, 57.725670263171196, 60.796958059072495, 55.308452770113945, 48.610639572143555, 51.1905263364315, 53.02670180797577, 49.05586548149586, 46.73830524086952, 54.33348208665848, 58.40408205986023, 60.55032469332218, 59.38589997589588, 56.85029983520508, 12.145241741091013, 0.14692313881823793, 0.3158696286845952, 0.11779653650592081, 0.28718419605866075, 7.500768061727285, 63.9826463162899, 51.47188983857632, 62.081110551953316, 58.56705151498318, 58.79626281559467, 7.147472044453025, 16.625996455550194, 37.0432660728693, 16.655429676175117, 42.30435736477375, 46.967873722314835, 26.689676642417908, 49.17616322636604, 54.74231734871864, 46.05469532310963, 2.100683315657079, 0.07090098180924542, 0.2790520980488509, 0.07941584248328581, 0.39484836102928966, 0.07272424569237046, 0.06794527478632517, 0.043838878482347354, 0.047674178931629285, 0.12669171817833558, 0.17903463682159781, 0.03079693367908476, 0.09150125726591796, 0.13098039664328098, 0.06827292556408793, 0.024014108385017607, 0.07533901007263921, 0.20616518100723624, 0.05797741512651555, 0.8334112982265651, 54.62070867419243, 63.280614987015724, 49.62738521397114, 31.05729717761278, 49.3328782171011, 35.088563561439514, 29.531133770942688, 55.418711453676224, 9.878331832587719, 26.974944435060024, 62.57350713014603, 48.440978676080704, 73.77858147025108, 62.81387843191624, 51.87923178076744, 0.9409446967765689, 0.44821958465036005, 0.1173310392186977, 0.7259526487905532, 0.28378174582030624, 1.1668995721265674, 42.252250760793686, 71.70525312423706, 68.46336588263512, 68.62835302948952, 63.970274180173874, 60.68268299102783, 52.5012432038784, 54.489231929183006, 52.73789070546627, 57.50956825911999, 62.55374439060688, 68.05564776062965, 66.24105513095856, 60.5681761354208, 38.626044541597366, 61.65358029305935, 51.969822719693184, 51.3785744458437, 55.64829893410206, 53.400791734457016, 51.86860375106335, 58.216786310076714, 36.28546893596649, 32.939786463975906, 80.46693697571754, 68.21734428405762, 59.10643257200718, 55.60557782649994, 55.352830588817596, 55.26659041643143, 52.020272612571716, 53.30564484000206, 56.44942134618759, 54.77000266313553, 49.59541752934456, 54.49108622968197, 54.66316759586334, 56.064965575933456, 56.70833185315132, 57.18521386384964, 58.35601843893528, 55.356577187776566, 52.74542950093746, 52.227920070290565, 52.96315401792526, 53.5443290323019, 51.46078683435917, 53.369971588253975, 50.97860410809517, 52.58790895342827, 53.131804168224335, 59.66344468295574, 53.80100525915623, 32.51982159912586, 50.41040539741516, 38.36154833436012, 42.55310721695423, 50.27446009218693, 54.30068604648113, 52.67084330320358, 56.03474199771881, 53.77732872962952, 51.391611546278, 50.12312941253185, 52.96383038163185, 49.48264338076115, 50.05577802658081, 46.9823357462883, 47.58984334766865, 45.83843752741814, 48.85914243757725, 50.00152833759785, 54.88583944737911, 54.92814637720585, 52.933846190571785, 54.33842942118645, 54.88414093852043, 52.749419286847115, 50.708172619342804, 51.92674823105335, 49.112889021635056, 51.89365200698376, 52.546582370996475, 56.46121971309185, 54.634923711419106, 55.721733793616295, 62.15143337845802, 50.612904131412506, 33.73914197087288, 48.157878667116165, 49.61634300649166, 61.144270822405815, 55.52336163818836, 57.86651350557804, 55.3567785769701, 60.82890674471855, 55.54545745253563, 63.372463658452034, 39.68307942152023, 25.62361154705286, 64.01191234588623, 61.6065464168787, 65.19272938370705, 58.66293556988239, 51.867786794900894, 53.541577979922295, 56.18306323885918, 53.032013922929764, 50.25981567800045, 56.66076220571995, 61.895456314086914, 65.34266173839569, 61.27235434949398, 63.36089327931404, 14.537087045609951, 0.21786366967717186, 0.3191664267797023, 0.11519005449372344, 0.22032926237443462, 8.817118126899004, 73.81603226065636, 55.76946683228016, 68.19993361830711, 60.854540169239044, 62.22183220088482, 8.947635423392057, 20.005018338561058, 39.83318276703358, 21.141759641468525, 34.67620588839054, 61.06626860797405, 34.560042321681976, 45.79807609319687, 64.50073331594467, 51.93202994763851, 2.640578057616949, 0.05670338876370806, 0.08923922825488262, 0.04904694804281462, 0.06827204240835272, 0.058101572722080164, 0.10751376874395646, 0.1520706751034595, 0.6684778828639537, 0.24070255196420476, 0.2868526638485491, 0.16906680684769526, 0.16604374250164255, 0.23630839947145432, 0.14127147645922378, 0.0744902306178119, 0.1688939012819901, 0.42119113029912114, 0.4226113634649664, 1.6274776076897979, 70.01840204000473, 73.13452363014221, 68.90417262911797, 40.24053990840912, 68.77675026655197, 52.39162668585777, 31.89690202474594, 62.29893386363983, 11.336069460958242, 33.073258101940155, 70.1956245303154, 57.20221035182476, 76.99782952666283, 70.26709109544754, 56.59650005400181, 0.6904680153820664, 0.8951244398485869, 0.5196206329856068, 1.0599343618378043, 0.785912600113079, 2.2002529352903366, 47.04372525215149, 71.30427584052086, 72.7440033853054, 69.42786812782288, 72.077876329422, 62.19781368970871, 56.39518305659294, 56.37152172625065, 57.03025057911873, 59.80862729251385, 65.82324475049973, 67.38284066319466, 68.78455504775047, 55.848578587174416, 52.15702347457409, 60.42335830628872, 49.7901114821434, 55.95328576862812, 56.83107666671276, 62.62414701282978, 52.98635937273502, 58.75881962478161, 44.34651218354702, 31.101129725575447, 65.45145750045776, 77.08474606275558, 62.257329896092415, 59.56838898360729, 57.221482917666435, 60.479766279459, 55.38661077618599, 54.82329860329628, 59.36505809426308, 58.73964585363865, 52.890756502747536, 59.13637116551399, 57.259667068719864, 56.38187617063522, 61.13711200654507, 60.084154307842255, 63.75106394290924, 61.44240662455559, 58.3048389852047, 56.7811169475317, 60.03206290304661, 60.70129819214344, 53.54016825556755, 59.686634838581085, 55.4700580984354, 55.786957293748856, 58.64920690655708, 64.0052779018879, 58.7782783806324, 35.2501080930233, 56.464164555072784, 46.49845831096172, 45.78222714364529, 56.14250421524048, 73.12011480331421, 61.56897023320198, 60.3189817070961, 58.42689223587513, 60.05277939140797, 53.349965661764145, 56.29812106490135, 56.355516985058784, 55.22384651005268, 54.622008204460144, 55.77825956046581, 52.12000586092472, 56.73063665628433, 56.69348604977131, 60.03124214708805, 60.24862468242645, 57.226069271564484, 58.12086045742035, 61.19665861129761, 55.44097065925598, 54.713849276304245, 54.38209667801857, 53.395149037241936, 54.191913083195686, 54.99441862106323, 57.815315052866936, 58.38006354868412, 57.87037029862404, 65.09273394942284, 38.01857113838196, 30.87196972221136, 50.34434214234352, 50.6213890761137, 63.15545350313187, 60.6760523468256, 59.76643815636635, 58.23783338069916, 61.33613772690296, 54.51654106378555, 63.32286112010479, 49.31722305715084, 32.18316726386547, 67.24145025014877, 64.36041444540024, 68.52512016892433, 61.42547853291035, 55.48265442252159, 55.53126901388168, 62.31621913611889, 56.11937865614891, 53.69201570749283, 60.646360740065575, 63.76581475138664, 70.79447999596596, 61.497902646660805, 64.59160923957825, 23.12035147100687, 0.41241814324166626, 0.9366888063959777, 0.27303583337925375, 0.859224263112992, 9.309363663196564, 77.03366920351982, 60.48753306269646, 76.60983234643936, 68.53389769792557, 71.81524202227592, 12.837307155132294, 25.323794335126877, 47.11416967213154, 22.2406492754817, 53.08097429573536, 76.8223625421524, 38.33483576774597, 67.66844853758812, 72.31711149215698, 69.52483892440796, 5.682388935238123, 0.4126432811608538, 0.6860473682172596, 0.1914715179009363, 0.4899894370464608, 0.18390309589449316, 0.2775612421100959, 0.27290720434393734], [0.14793391426792368, 0.10149219029699452, 0.10252511143335141, 0.12934465863509104, 0.1409084178158082, 0.12226044345879927, 0.059790266677737236, 0.02692311019927729, 0.09162282847682945, 0.11338404554408044, 0.4680836421903223, 0.7520085037685931, 32.77378857135773, 60.91763958334923, 52.44046926498413, 50.14507323503494, 38.849134370684624, 29.840703159570694, 27.21389651298523, 32.53365285694599, 52.6395557820797, 32.167683094739914, 67.05357313156128, 61.48399919271469, 52.197563499212265, 59.00535799562931, 52.19709612429142, 2.1756855910643935, 0.12533774395706132, 0.2607995696598664, 0.19595161109464243, 0.4519939993042499, 1.4473526668734848, 40.84992840886116, 72.24325105547905, 62.670105546712875, 64.81506764888763, 61.55154436826706, 57.34949804842472, 49.97801899909973, 52.881177216768265, 50.712675377726555, 54.495019018650055, 58.91068987548351, 59.408995136618614, 59.68474254012108, 66.13491922616959, 46.22857019305229, 38.4447068721056, 63.09401459991932, 50.45341908931732, 55.669725984334946, 50.188010931015015, 50.51478959619999, 31.824694499373436, 32.55360558629036, 71.33066922426224, 63.74494627118111, 56.936547607183456, 57.649032175540924, 52.66761727631092, 53.57424482703209, 51.6467260569334, 50.36877483129501, 52.23203904926777, 51.24351069331169, 54.39814701676369, 53.08770373463631, 54.52509440481663, 53.5472396761179, 53.996611163020134, 59.50588993728161, 53.168833181262016, 54.34871166944504, 54.5049174875021, 50.85700303316116, 51.998902559280396, 46.09302766621113, 48.26537109911442, 48.44293177127838, 49.18269507586956, 45.90861216187477, 47.62399211525917, 50.51172316074371, 53.20712752640247, 29.53538954257965, 19.68677021563053, 47.079181149601936, 40.699635073542595, 36.29494562745094, 38.08152616024017, 44.44571726024151, 44.05377969145775, 43.79857778549194, 44.70306225121021, 43.21900628507137, 40.989168137311935, 48.11093218624592, 47.81219221651554, 47.17634193599224, 44.51656065881252, 41.790989711880684, 44.15162444114685, 44.602819830179214, 48.4143041074276, 50.427439883351326, 60.197304636240005, 57.50959865748882, 57.10287608206272, 55.01101613044739, 52.73512065410614, 50.086617171764374, 49.177314564585686, 48.48135530948639, 47.61832281947136, 48.04982766509056, 52.86221243441105, 52.052247896790504, 50.82280106842518, 54.634064957499504, 46.27398915588856, 32.677254751324654, 47.55491942167282, 44.26397301256657, 42.57326513528824, 52.188386991620064, 57.246599569916725, 52.72497899830341, 58.79562444984913, 51.27744287252426, 52.93801836669445, 39.570548459887505, 35.59814661741257, 53.73816043138504, 63.33877466619015, 60.336855947971344, 60.16051881015301, 49.27185349166393, 51.081134006381035, 49.08258184790611, 51.26711122691631, 43.368592858314514, 58.56846883893013, 54.95377980172634, 65.42005598545074, 48.13542187213898, 47.21842087805271, 5.2821112889796495, 0.14435086981393397, 0.280745827476494, 0.08352362987352535, 0.14095069054747, 19.930035062134266, 64.29645627737045, 49.17887628078461, 62.73854747414589, 47.92098417878151, 55.30368022620678, 11.801193002611399, 13.68905995041132, 29.667975828051567, 22.44605865329504, 48.701124116778374, 39.89623658359051, 32.60916620492935, 36.98583975434303, 52.519261837005615, 33.152115270495415, 0.30364598147571087, 0.32414979999884963, 0.05171171833353583, 0.22962546354392543, 0.0847130105830729, 0.10310619822121225, 0.03149514064716641, 0.1458958283183165, 0.11956658097915351, 0.010137098088307539, 0.10839466092875227, 0.05181387867196463, 0.19755384855670854, 0.008339415107911918, 0.10106958914548159, 0.08018911583349109, 0.0727200302935671, 0.029385478264885023, 0.606472750660032, 0.7467406801879406, 37.758038118481636, 70.01163840293884, 58.12757849693298, 37.95247748494148, 49.290179908275604, 28.653468266129494, 27.709042243659496, 44.738977923989296, 54.485964104533195, 40.89169576764107, 68.02273392677307, 66.64789929986, 57.482468113303185, 65.99086135625839, 57.51568213105202, 2.5143362442031503, 0.2136428383528255, 0.46476532181259245, 0.2858678041957319, 0.7452812616247684, 1.0468610445968807, 46.64051368832588, 74.69269081950188, 65.9377934038639, 67.36493602395058, 64.95904952287674, 58.38569484651089, 54.202183932065964, 55.41934981942177, 53.12847174704075, 54.48368802666664, 60.63251428306103, 62.42913767695427, 62.224469259381294, 71.76801055669785, 52.31349527835846, 41.3346341997385, 65.4380214214325, 54.2939680069685, 58.196875378489494, 51.89508832991123, 51.853681951761246, 36.038497388362885, 43.73387485742569, 89.177825152874, 69.49427336454391, 57.546715065836906, 59.210839569568634, 54.6536149084568, 59.872862845659256, 51.92222647368908, 52.94030584394932, 56.75592429935932, 50.403189584612846, 52.09226734936237, 53.55279877781868, 55.85496984422207, 55.063571110367775, 55.65424561500549, 61.128064692020416, 59.66404505074024, 59.16155241429806, 56.65424935519695, 56.10423266887665, 54.714054465293884, 54.84368450939655, 52.99486331641674, 53.33236500620842, 53.02499569952488, 50.911062732338905, 54.81908842921257, 53.500562980771065, 60.972596034407616, 40.97963064908981, 31.157492101192474, 49.96994823217392, 48.03147464990616, 44.53544944524765, 46.55934624373913, 49.047863110899925, 52.647717744112015, 51.53881184756756, 50.990847051143646, 52.8205780684948, 48.289515003561974, 50.35936273634434, 50.365655198693275, 51.819517984986305, 49.587019979953766, 50.13402342796326, 46.04827366769314, 49.47267271578312, 53.19356985390186, 54.365430772304535, 57.9072131216526, 57.819662019610405, 57.38167092204094, 55.363925993442535, 54.651498422026634, 54.21532362699509, 53.029494658112526, 49.12246450781822, 52.404971569776535, 51.88025392591953, 55.51977463066578, 54.848590046167374, 55.365039333701134, 55.80499492585659, 55.069377198815346, 36.57705008983612, 47.62216441333294, 46.54590256512165, 47.30872303247452, 52.91063703596592, 57.29688987135887, 55.13051591813564, 59.0789258480072, 54.44436013698578, 50.940020978450775, 42.09506839513779, 40.542315915226936, 54.27360109984875, 68.62922698259354, 61.113177090883255, 61.70890152454376, 53.30362714827061, 52.349334955215454, 50.66751480102539, 52.221369221806526, 47.79538951814175, 61.17284528911114, 61.218917816877365, 65.88357031345367, 52.394449934363365, 56.158398762345314, 6.704383520409465, 0.4401820065686479, 0.4673426819499582, 0.12510433851275593, 0.20679529407061636, 24.14363656193018, 70.52125945687294, 53.040821850299835, 67.26257711648941, 52.62336865067482, 61.1454563587904, 14.043075554072857, 17.378481477499008, 35.7641065120697, 21.834962144494057, 39.47372205555439, 51.97546161711216, 29.947895407676697, 38.65462280809879, 60.621947050094604, 39.63480681180954, 0.7641167321708053, 0.3265666781226173, 0.0053490864320338005, 0.11504138747113757, 0.02787665493087843, 0.11205571252503432, 0.07791254814947024, 0.040839967332431115, 0.17263447400182486, 0.1460563251748681, 0.1824514105101116, 0.25619724474381655, 0.25420255959033966, 0.16425956011516973, 0.21317252452718094, 0.2131999097764492, 0.28413494874257594, 0.23653181560803205, 1.0133758164010942, 0.7453183690086007, 48.94121043384075, 80.20557180047035, 73.47242429852486, 52.91779205203056, 63.245303481817245, 44.25779454410076, 28.927294872701168, 48.09300094842911, 58.701902478933334, 46.11070051789284, 75.66817447543144, 73.83676394820213, 63.796600699424744, 71.56762450933456, 60.9712129086256, 2.901165224611759, 0.40946638444438577, 1.0187039617449045, 0.7227407523896545, 1.1784781445749104, 1.1930295825004578, 54.74610574543476, 75.31133562326431, 70.01783207058907, 70.55918142199516, 68.51863011717796, 59.50675629079342, 56.2369367480278, 55.48858590424061, 56.203745529055595, 55.78383006155491, 65.10932385921478, 62.72814363241196, 65.43256491422653, 70.83161160349846, 56.448121815919876, 49.444003254175186, 61.77549675107002, 52.91505619883537, 63.38208854198456, 55.37366107106209, 54.19704280793667, 43.141703233122826, 46.374041587114334, 74.27716791629791, 74.11804765462875, 60.99315293133259, 62.88700170814991, 57.684157490730286, 64.82290282845497, 55.71975030004978, 56.70579358935356, 58.10420215129852, 54.60918769240379, 58.30483138561249, 56.521077901124954, 58.4055981785059, 59.34403382241726, 56.415800750255585, 63.93108308315277, 64.97399032115936, 61.967188864946365, 61.240021884441376, 59.48509745299816, 62.1761092543602, 59.199846759438515, 56.80531784892082, 58.00770252943039, 56.191259399056435, 54.02159862220287, 58.76324638724327, 61.44851669669151, 66.10377609729767, 43.06924872100353, 36.61534823477268, 62.02293947339058, 46.673549115657806, 53.00081379711628, 53.45104403793812, 59.77232024073601, 64.27350550889969, 61.223899349570274, 57.74952918291092, 56.77978701889515, 52.507341876626015, 58.35694558918476, 60.38135156035423, 59.17270481586456, 57.47547648847103, 57.00683243572712, 53.75084035098553, 54.885087087750435, 57.317575961351395, 57.42960534989834, 61.53335094451904, 61.06092229485512, 61.53746232390404, 58.56358230113983, 57.07795701920986, 56.03502698242664, 54.06282640993595, 53.22022922337055, 54.33674991130829, 52.598882764577866, 57.14305892586708, 56.42489366233349, 55.52833937108517, 59.72301408648491, 48.618288561701775, 31.85576543211937, 51.06793351471424, 46.538530960679054, 49.344889372587204, 55.321581065654755, 63.58652517199516, 54.992157742381096, 63.485142812132835, 55.561720579862595, 54.46459025144577, 42.31090061366558, 43.07405546307564, 53.485591784119606, 68.85070949792862, 67.38936111330986, 66.07058107852936, 54.16037857532501, 57.74804726243019, 55.387302339076996, 54.99053902924061, 51.84402287006378, 66.81952089071274, 63.00118938088417, 71.7239861190319, 52.90404438972473, 60.887495800852776, 11.50621198117733, 0.43870151101145893, 0.8730962499976158, 0.43150205514393747, 0.9198785084299743, 25.8082265406847, 78.01089316606522, 58.61899472773075, 72.50975355505943, 57.714795246720314, 66.58064290881157, 18.695146925747395, 22.712084278464317, 42.19437226653099, 29.083755277097225, 66.30209505558014, 64.14406165480614, 41.943148747086525, 52.08940990269184, 65.5019947886467, 56.07414588332176, 1.5516545763239264, 0.5653464887291193, 0.19279264466604218, 0.4824661376187578, 0.2555634209420532, 0.24629181454656646, 0.179194035299588, 0.28636020433623344], [0.026113890926353633, 0.12261362411663868, 0.2502009883755818, 0.14340797119075432, 0.2514979656552896, 0.09924525656970218, 0.09209780298988335, 0.09695345259387977, 0.07467920368071645, 0.06917587437783368, 0.5754614272154868, 1.1258547683246434, 17.368848994374275, 62.165241837501526, 51.99611730873585, 42.84250348806381, 39.730500876903534, 34.12382572889328, 24.66156017035246, 21.238230764865875, 24.827081188559532, 57.01997593045235, 52.90246747434139, 60.85430458188057, 58.270709216594696, 48.83916310966015, 60.257493406534195, 7.57979242131114, 0.2952781179919839, 0.1888879682519473, 0.15030629321699962, 0.14709666778799146, 0.3507268207613379, 41.2728913128376, 67.94561326503754, 59.483729526400566, 62.97328747808933, 59.02645446360111, 54.333865866065025, 51.70510992407799, 58.471239656209946, 61.56911462545395, 55.34984014928341, 53.088258504867554, 55.987958908081055, 60.08828088641167, 61.536147594451904, 63.32513339817524, 35.80915309488773, 47.52629555761814, 53.95809642970562, 47.40978620946407, 51.68823502957821, 41.919198632240295, 53.72944749891758, 83.44765663146973, 68.49354386329651, 53.60468879342079, 58.421914502978325, 56.74559265375137, 54.80601333081722, 54.41622644662857, 55.809311494231224, 51.101166531443596, 51.42810858786106, 55.892192646861076, 52.94411703944206, 49.37048099935055, 54.011574760079384, 56.98867700994015, 59.39186565577984, 57.729477658867836, 57.35349543392658, 54.132366478443146, 52.53424443304539, 54.327288419008255, 54.160218983888626, 48.949102610349655, 48.41361254453659, 49.64976601302624, 48.18379707634449, 41.2515364587307, 42.989817783236504, 45.59163697063923, 45.972140952944756, 16.946940533816814, 25.77292263507843, 51.05198957026005, 34.93337608873844, 35.34882679581642, 37.11237296462059, 37.98280365765095, 37.25615344941616, 39.40962329506874, 39.25384685397148, 40.396228954195976, 41.617745608091354, 45.02194494009018, 46.61653317511082, 46.94308005273342, 40.71032389998436, 45.728323236107826, 45.437433645129204, 45.83594486117363, 49.004815220832825, 49.48710814118385, 56.45565301179886, 56.432189270853996, 55.84167815744877, 56.628182753920555, 54.89460177719593, 49.313411861658096, 48.63055430352688, 49.61382754147053, 48.623623475432396, 54.00029316544533, 50.74371211230755, 51.33821681141853, 55.52486635744572, 48.26613865792751, 42.50270292162895, 37.818637266755104, 33.77507284283638, 50.34997344017029, 52.67420992255211, 43.53324942290783, 47.77807004749775, 49.474462419748306, 50.58538220822811, 45.597139075398445, 48.161454275250435, 37.50225864350796, 53.936422392725945, 83.32246094942093, 60.598958283662796, 57.906365767121315, 58.663649931550026, 52.55595266819, 49.32597778737545, 51.15085646510124, 49.81218449771404, 47.25438594818115, 54.9589779227972, 57.264933586120605, 65.8986023068428, 48.199589028954506, 44.1568985581398, 5.05996523424983, 0.7776482810731977, 0.6454527808818966, 0.2469197308528237, 0.9228140884079039, 26.961360163986683, 55.09228236973286, 45.36703482270241, 56.69101618230343, 55.75114041566849, 57.401844039559364, 8.96391374990344, 19.946307688951492, 20.117125622928143, 27.761677019298077, 55.464168414473534, 33.856506273150444, 32.82789386808872, 46.32803365588188, 61.08182117342949, 25.605262331664562, 0.2820894116302952, 0.3506851417478174, 0.06951879855478182, 0.0934742865501903, 0.013884108939237194, 0.10393143675173633, 0.04481821655645035, 0.057764645098359324, 0.11894852039404213, 0.02726146274653729, 0.14867131219943985, 0.06201951502589509, 0.2562331943772733, 0.09115471140830778, 0.19188287551514804, 0.08444073886494152, 0.1017506951757241, 0.03841315185127314, 0.5261937458999455, 1.1787012638524175, 20.95200352370739, 73.2223217189312, 56.75761520862579, 40.061349123716354, 54.97090168297291, 36.99191562831402, 24.009034484624863, 36.76412545144558, 23.674508035182953, 56.80565223097801, 59.26685616374016, 65.81562995910645, 64.55174937844276, 55.966144278645515, 65.78485161066055, 9.51076140627265, 0.34248286625370383, 0.40874843078199774, 0.37489106005523354, 1.2636265880428255, 0.5734446854330599, 47.64275550842285, 70.95486178994179, 65.14121934771538, 65.3750815987587, 61.42310746014118, 55.904127806425095, 54.36456821858883, 62.16330014169216, 63.801806420087814, 58.08332987129688, 54.92110155522823, 58.94454225897789, 64.02978658676147, 64.62053328752518, 64.06412154436111, 39.732130989432335, 50.93880124390125, 54.91372235119343, 49.33745697140694, 53.65214064717293, 47.57709123194218, 64.86311987042427, 89.89768892526627, 66.75246968865395, 55.90432919561863, 59.50025103986263, 58.85220721364021, 58.685859739780426, 57.564669102430344, 56.86797268688679, 52.809307873249054, 52.2276920825243, 54.61627051234245, 53.24798673391342, 52.0277202129364, 56.27656862139702, 60.73441341519356, 62.42420554161072, 59.44238394498825, 59.70675855875015, 58.402672335505486, 58.71470019221306, 57.13044360280037, 58.31698693335056, 54.79718640446663, 55.51398754119873, 52.649321258068085, 53.19100499153137, 48.34427006542683, 51.61594770848751, 53.14698815345764, 58.22784371674061, 30.489871725440025, 33.31172950565815, 55.566284134984016, 43.41427020728588, 45.371370390057564, 50.6267923861742, 43.86735029518604, 47.18081809580326, 47.52889081835747, 53.07151660323143, 46.654485538601875, 47.65390411019325, 49.34904254972935, 50.839417576789856, 51.931630969047546, 47.34873868525028, 48.30033302307129, 51.42144754528999, 53.383339270949364, 52.40144915878773, 53.74287597835064, 54.345759227871895, 57.07711346447468, 58.60656179487705, 59.36860330402851, 53.34201268851757, 51.65329970419407, 49.71534289419651, 49.78664226830006, 51.72006592154503, 54.210167303681374, 57.10419841110706, 53.2354512065649, 59.361558482050896, 49.453726932406425, 46.4459603279829, 43.12270425260067, 32.44814604520798, 50.627977922558784, 56.81400418281555, 48.64880472421646, 49.740497544407845, 50.29242552816868, 51.14997111260891, 48.66267777979374, 49.23278398811817, 40.238632410764694, 49.82418045401573, 74.4397459924221, 66.20796650648117, 60.517509654164314, 61.29611447453499, 53.17278116941452, 52.95844227075577, 53.38329367339611, 55.147026032209396, 47.984444573521614, 56.96544125676155, 59.42565344274044, 69.49679642915726, 53.07811304926872, 51.53097286820412, 5.856466144323349, 0.6324663246050477, 1.0534872952848673, 0.2816960436757654, 1.0754799214191735, 34.479091465473175, 59.437774792313576, 49.92912322282791, 61.42607510089874, 62.9803740978241, 61.94325394928455, 11.46306149661541, 26.23919941484928, 31.094497181475163, 19.107115119695663, 49.16332371532917, 51.197422966361046, 27.438734248280525, 51.01553052663803, 73.36281538009644, 30.454706512391567, 0.5436946568079293, 0.2843226824188605, 0.07660262039280497, 0.08019347966182977, 0.053392374829854816, 0.039429126045433804, 0.03482348001853097, 0.023734867900202516, 0.15755689790239558, 0.22292881272733212, 0.34260365820955485, 0.36686292209196836, 0.4357578564668074, 0.11682345473673195, 0.378074457985349, 0.18313489883439615, 0.3518604958662763, 0.1419774815440178, 0.9722739562857896, 1.6054203850217164, 29.45308405905962, 86.92836105823517, 71.19142189621925, 52.768490463495255, 63.266715332865715, 51.95139370858669, 26.129518300294876, 36.740008145570755, 35.39477773010731, 65.36807477474213, 63.53566490113735, 73.28023061156273, 68.2290780544281, 60.77006310224533, 73.97379219532013, 11.925805415958166, 0.2903355925809592, 1.3240625825710595, 0.6116704561281949, 2.8825281746685505, 0.4669569729594514, 55.74318744242191, 73.91951590776443, 69.38110783696175, 68.91583800315857, 64.04337465763092, 59.268782660365105, 58.12873363494873, 65.02860099077225, 67.4935895204544, 56.9263831526041, 58.74501496553421, 60.746561363339424, 64.81411769986153, 65.94240635633469, 66.67838126420975, 42.4431449174881, 57.09388196468353, 54.229394271969795, 51.804580986499786, 55.75018286705017, 56.341024562716484, 65.96773579716682, 79.08430516719818, 66.600561439991, 60.40042653679848, 61.990872994065285, 63.046923726797104, 59.608412235975266, 61.52099020779133, 60.24068310856819, 53.59324760735035, 53.76566335558891, 57.46907003223896, 55.671964064240456, 52.47674971818924, 58.5969103127718, 61.1282242834568, 63.03290247917175, 62.41950139403343, 63.86094644665718, 64.13563370704651, 60.4903145134449, 61.67656525969505, 67.22451075911522, 58.525192961096764, 59.38234716653824, 57.953650429844856, 56.0619143396616, 49.7817899286747, 56.116741597652435, 58.4165795892477, 67.20705449581146, 29.10679344087839, 45.409136563539505, 60.96530802547932, 45.92370495200157, 54.10403519868851, 58.498860374093056, 57.46537663042545, 55.58678403496742, 57.73398421704769, 57.71800987422466, 53.7506465613842, 52.736427783966064, 56.064938977360725, 58.54150548577309, 58.92776995897293, 52.233057394623756, 56.82714007794857, 56.41095981001854, 56.18242867290974, 55.84626451134682, 56.8132708221674, 58.81037525832653, 58.78355249762535, 62.9645973443985, 60.939142629504204, 59.31764043867588, 52.54958041012287, 52.48811490833759, 54.1073714196682, 54.37570162117481, 55.76469428837299, 58.71634930372238, 55.56574076414108, 59.95795167982578, 52.840633392333984, 46.96629300713539, 38.31229157745838, 34.585842937231064, 51.92227587103844, 57.2326885163784, 50.0418783724308, 55.151536390185356, 52.459586039185524, 54.88780774176121, 50.02271220088005, 51.16739697754383, 41.810729652643204, 43.375094309449196, 67.62660518288612, 70.15280082821846, 60.630428194999695, 65.82668736577034, 57.732152715325356, 56.05950526893139, 57.062336057424545, 58.50714772939682, 51.3026887178421, 61.35627284646034, 63.59270364046097, 77.7480536699295, 51.71469300985336, 58.16004775464535, 10.3614635579288, 0.6823752215132117, 1.728477613069117, 0.48655145277734846, 2.2748016100376844, 38.51764775812626, 69.9933309853077, 53.93753953278065, 66.64639458060265, 67.83409684896469, 70.85846856236458, 17.135077938437462, 29.617104157805443, 32.026038095355034, 31.72088596969843, 78.72352212667465, 56.89736790955067, 40.49446128308773, 59.34434540569782, 79.95450407266617, 41.68481580913067, 1.2468588002957404, 0.40433383954223245, 0.19155027461238205, 0.17462880292441696, 0.20671168371336535, 0.20084715855773538, 0.14658719825092703, 0.11651188629912212], [0.04124249710002914, 0.13469201076077297, 0.05580244745942764, 0.13339570141397417, 0.0790122254693415, 0.08879766523023136, 0.0625705077254679, 0.034300533079658635, 0.059871157063753344, 0.07352577260462567, 0.19194215827155858, 0.3532751480815932, 6.332399630919099, 57.90551081299782, 52.279266715049744, 41.43091723322868, 35.56617133319378, 41.05421304702759, 23.76981072127819, 29.794132858514786, 6.787019111216068, 25.800172872841358, 67.797140032053, 59.00795705616474, 65.62474340200424, 48.21373946964741, 63.44926133751869, 20.052709579467773, 0.5760391743388027, 0.24731450888793916, 0.4151412908686325, 0.4418381239520386, 0.056756775156827644, 32.067714259028435, 66.53377622365952, 58.31767849624157, 62.98255518078804, 56.39030411839485, 53.828177601099014, 58.140596598386765, 63.471524342894554, 64.75683197379112, 64.37763512134552, 57.547794207930565, 53.329161778092384, 59.485580027103424, 60.46539165079594, 61.33955754339695, 61.27351328730583, 40.081586837768555, 40.78569285571575, 59.43229168653488, 64.11592796444893, 74.63352039456367, 82.49944791197777, 63.13579335808754, 56.703559309244156, 55.97198076546192, 56.644183695316315, 60.09399197995663, 59.821307212114334, 58.18720489740372, 54.040749594569206, 50.364788845181465, 54.14899058640003, 52.3343675583601, 50.208917409181595, 50.207408890128136, 53.326289132237434, 57.00579509139061, 56.00383445620537, 58.191225081682205, 58.93536955118179, 58.624907210469246, 50.05469508469105, 51.71864099800587, 55.14411918818951, 54.755928218364716, 48.62375266849995, 50.69205768406391, 45.80115392804146, 44.47128228843212, 40.32391123473644, 46.9662132114172, 41.68477401137352, 12.81372182071209, 31.651326902210712, 43.681038692593575, 28.77153553068638, 36.55032992362976, 32.37260989844799, 35.80229826271534, 35.68136975169182, 37.92996369302273, 37.225937470793724, 37.96360708773136, 39.504287615418434, 46.823329478502274, 47.59321376681328, 46.483821496367455, 48.29948566854, 48.11296887695789, 45.25773748755455, 45.96884272992611, 48.08258190751076, 51.55803121626377, 53.44420440495014, 56.66888236999512, 56.38377606868744, 56.031667962670326, 53.59666742384434, 49.96468171477318, 48.72826986014843, 49.47304129600525, 51.07437036931515, 51.21904760599136, 52.19259716570377, 52.15956173837185, 55.69328472018242, 51.52737446129322, 54.32756960391998, 55.85110165178776, 35.38505785167217, 24.98613115400076, 41.54289722442627, 50.85148572921753, 50.785342678427696, 45.32457210123539, 45.65356984734535, 47.22927689552307, 50.970738530159, 64.39720407128334, 87.51363605260849, 58.12749110162258, 58.26135791838169, 59.650456979870796, 55.29322698712349, 53.000673204660416, 50.07527858018875, 52.526242062449455, 50.399834364652634, 49.09379504621029, 56.0108944773674, 57.915815860033035, 59.07147824764252, 58.36114816367626, 40.77279634773731, 1.2536539044231176, 1.1592199467122555, 0.17670338769676164, 0.21024402463808656, 1.47566708503291, 34.80555094778538, 52.28090062737465, 54.6528435498476, 56.95223696529865, 54.31864768266678, 42.774692326784134, 6.719728522002697, 20.864444822072983, 14.684634078294039, 29.095899425446987, 50.03759600222111, 24.967099875211716, 33.43648441135883, 53.458947613835335, 61.47016033530235, 15.71332722902298, 0.10436692900839262, 0.20109586708713323, 0.15551651129499078, 0.19298128376249224, 0.11195683619007468, 0.022185538146004546, 0.14341086556669325, 0.13489485456375405, 0.09259123471565545, 0.06872552432469092, 0.062249621623777784, 0.1713122785440646, 0.1177521634963341, 0.01952084021468181, 0.03717561688972637, 0.02477593039657222, 0.08166956686181948, 0.12104497625841759, 0.1889288902748376, 0.43737383850384504, 6.640817206352949, 69.40905913710594, 63.160735219717026, 40.37724517285824, 44.87040527164936, 50.35609491169453, 16.45599737763405, 42.94620372354984, 9.953471850603819, 23.987805023789406, 70.46391293406487, 65.91430306434631, 69.97425600886345, 52.04725116491318, 70.49081549048424, 22.506494410336018, 0.44249222322832793, 0.4815945593873039, 0.7299103739205748, 0.36656529118772596, 0.04944456850353163, 38.48568007349968, 68.67032557725906, 60.10384105145931, 64.58435922861099, 59.13947939872742, 54.656772539019585, 60.135778337717056, 68.29622805118561, 64.28555086255074, 68.23111474514008, 59.252010360360146, 54.87371809780598, 61.87703490257263, 62.63097524642944, 65.4728351533413, 61.08326889574528, 42.32747532427311, 45.75674571096897, 62.55910590291023, 67.00515612959862, 75.919728577137, 76.68632984161377, 58.02938796579838, 60.03593109548092, 60.79873636364937, 58.899579271674156, 59.59928132593632, 61.24076284468174, 61.59382089972496, 55.28810866177082, 53.71804051101208, 57.69647262990475, 53.467421159148216, 51.230693981051445, 53.948847725987434, 55.11843256652355, 58.07362139225006, 61.03893667459488, 61.61491736769676, 60.536102056503296, 61.55924655497074, 56.28064960241318, 58.87205734848976, 57.67940394580364, 57.520105093717575, 53.046962320804596, 55.21489419043064, 53.01568999886513, 48.61520692706108, 46.20721533894539, 52.94709987938404, 52.086411863565445, 25.897542648017406, 41.20715104043484, 51.55339166522026, 39.86591421067715, 43.052708208560944, 46.56363621354103, 46.558631882071495, 43.68779473006725, 48.17038379609585, 46.01972579956055, 44.95059996843338, 48.31954479217529, 53.085986226797104, 51.51372179389, 50.897075682878494, 52.57040709257126, 53.99863265454769, 51.240144073963165, 48.763904348015785, 50.53467012941837, 53.14448408782482, 53.49151946604252, 56.631553173065186, 57.718431651592255, 57.2639000415802, 52.47673071920872, 50.017263293266296, 48.64047937095165, 52.87240348756313, 52.72640012204647, 55.93948870897293, 52.86531686782837, 53.967037349939346, 59.7989834100008, 51.95596866309643, 51.90470561385155, 59.987092316150665, 40.57879775762558, 29.683237709105015, 40.75902208685875, 49.78646367788315, 51.96241691708565, 46.455627009272575, 49.537121057510376, 48.76696318387985, 50.882758051157, 56.793948858976364, 81.1638043820858, 59.56765942275524, 62.13911063969135, 60.927009880542755, 59.02494974434376, 54.66974504292011, 54.040688797831535, 51.5217849612236, 54.71844702959061, 53.59360098838806, 57.9415138810873, 58.16152207553387, 63.69131214916706, 59.69120219349861, 47.1588970720768, 1.563780081924051, 1.3472409825772047, 1.460166173055768, 0.23906172282295302, 1.5371064632199705, 43.90923924744129, 59.11973565816879, 61.910841688513756, 62.837680354714394, 63.26499402523041, 45.84355965256691, 7.274448880925775, 30.42081233114004, 22.557994946837425, 22.63944547623396, 54.33556817471981, 35.69307692348957, 31.243306696414948, 57.17438444495201, 65.01572728157043, 15.514744184911251, 0.2667070651659742, 0.17470135528128594, 0.16734180331695825, 0.1403669171850197, 0.04811968276044354, 0.056403152921120636, 0.0491679255355848, 0.09305313258664683, 0.3054081666050479, 0.2150360425002873, 0.32312836730852723, 0.31835205329116434, 0.2847324963659048, 0.1522805099375546, 0.25646459602285177, 0.11107813334092498, 0.2875108894659206, 0.2693241450469941, 0.7185909594409168, 0.6854006310459226, 12.029488552361727, 87.27266058325768, 72.53034085035324, 54.63514029979706, 48.22489187121391, 64.35638666152954, 28.435240276157856, 44.650685861706734, 14.916994459927082, 32.858964800834656, 75.63817128539085, 71.13576248288155, 74.19031977653503, 61.48167371749878, 76.42173483967781, 30.265869945287704, 0.45315124501939863, 0.29099099803715944, 1.1687797587364912, 2.275022235698998, 0.20195172663079575, 48.23995426297188, 72.49603629112244, 65.22822707891464, 67.8515151143074, 64.86830279231071, 57.0544096827507, 64.85093772411346, 67.86273211240768, 66.97098836302757, 71.46153420209885, 63.71249981224537, 55.942296758294106, 63.889574110507965, 62.665295004844666, 66.60495400428772, 58.04220087826252, 45.86170367896557, 48.77696044743061, 66.1288471519947, 67.5187061727047, 72.82985597848892, 74.03984785079956, 60.17754949629307, 66.68056234717369, 64.56699416041374, 61.482673063874245, 62.39207066595554, 64.68611016869545, 65.72191178798676, 56.32162660360336, 55.17653524875641, 57.76065118610859, 58.446388989686966, 55.19361153244972, 53.40053714811802, 57.642473727464676, 58.622737526893616, 59.567199647426605, 62.50234454870224, 62.22428686916828, 64.92612808942795, 58.46235193312168, 60.714483484625816, 65.00563502311707, 63.166712298989296, 56.765161603689194, 61.06601782143116, 58.36698845028877, 55.231472700834274, 52.79307134449482, 59.77866590023041, 56.51805326342583, 25.223033241927624, 48.620625436306, 49.837415143847466, 44.2664010822773, 52.15132758021355, 53.9905808866024, 58.1290528178215, 56.17522045969963, 59.07234460115433, 51.358180940151215, 50.94748757779598, 53.45298193395138, 58.48505191504955, 57.1408436447382, 55.245151966810226, 56.975624710321426, 60.194827169179916, 55.174680948257446, 53.553437143564224, 54.7575469315052, 54.916541799902916, 55.48612363636494, 60.789301469922066, 62.825684398412704, 57.86113679409027, 56.52692198753357, 51.13365858793259, 51.0107883810997, 54.57340121269226, 56.76363408565521, 60.2073322981596, 57.601029351353645, 55.53322210907936, 62.565804943442345, 53.53822275996208, 54.627787694334984, 55.21115519106388, 41.02289892733097, 36.86510883271694, 47.63734079897404, 53.38274650275707, 53.954156041145325, 48.75250115990639, 51.19628302752972, 50.24436190724373, 50.23760586977005, 49.58610042929649, 78.13192427158356, 77.18850329518318, 63.523687943816185, 63.168547600507736, 60.68821929395199, 59.227440878748894, 57.84510925412178, 57.26438261568546, 58.46682049334049, 55.920482128858566, 62.206059247255325, 63.542382940649986, 68.55242550373077, 62.270260602235794, 56.269671991467476, 3.9483455708250403, 2.239981940947473, 2.3810011614114046, 0.32850285235326737, 1.736182530876249, 47.505932450294495, 66.63516238331795, 65.69329932332039, 66.38200476765633, 66.91342905163765, 54.77888658642769, 11.25849662348628, 29.283696748316288, 24.395830929279327, 34.317938312888145, 78.74494537711143, 40.04950515925884, 43.67421045899391, 65.05101978778839, 80.0422565639019, 26.52247231453657, 0.5042553856037557, 0.4384296474745497, 0.3767140122363344, 0.35144317138474435, 0.30092924600467086, 0.178724879224319, 0.26282037841156125, 0.25710762245580554], [0.21737441624281928, 0.06381800601957366, 0.03153248551825527, 0.16814847331261262, 0.21147404535440728, 0.09835874632699415, 0.02523819563066354, 0.08243279895395972, 0.12919183558551595, 0.03331492014694959, 0.20194914395688102, 0.06301667206571437, 0.6945326691493392, 53.47742602229118, 56.01496405899525, 50.39877042174339, 43.01107004284859, 48.29782135784626, 28.322521224617958, 34.22893188893795, 11.51723898947239, 12.959386054426432, 56.75574570894241, 63.52892406284809, 63.85545954108238, 59.01570104062557, 61.09656438231468, 34.76928949356079, 0.2349781888187863, 1.1308487690985203, 1.138855533208698, 0.38659072131849825, 0.5974817799869925, 21.085946336388588, 65.66354691982269, 56.78877353668213, 63.441562950611115, 56.7754590511322, 56.643841713666916, 64.75224182009697, 67.0260626077652, 65.23087933659554, 65.83662763237953, 59.7273800522089, 52.47993774712086, 55.03153122961521, 61.21538780629635, 61.8050629645586, 63.10476042330265, 46.41176976263523, 55.00537343323231, 58.90079900622368, 61.73271484673023, 62.24930852651596, 54.01831939816475, 56.844372153282166, 57.253853380680084, 60.239125192165375, 61.130618155002594, 59.02979448437691, 56.433329209685326, 58.288511261343956, 54.64448779821396, 50.62244921922684, 49.14531268179417, 51.27623453736305, 49.959901571273804, 50.06195269525051, 54.312332421541214, 54.09711956977844, 59.8812185972929, 58.55237290263176, 55.054953172802925, 54.936847910284996, 55.36553330719471, 53.0584567040205, 54.818662852048874, 54.63026896119118, 49.652927443385124, 47.38439977169037, 47.418894320726395, 43.294101655483246, 40.18183685839176, 45.10061591863632, 34.3557158857584, 8.704358227550983, 36.91495455801487, 38.67487192153931, 28.232914432883263, 35.40842279791832, 35.07600523531437, 33.87916445732117, 32.81568132340908, 36.186978220939636, 35.66429726779461, 34.016682878136635, 33.70028905570507, 46.45445667207241, 46.45674794912338, 46.95055045187473, 48.87366145849228, 48.352029249072075, 46.80973380804062, 48.21891099214554, 49.357975870370865, 53.09801258146763, 54.83811020851135, 53.69991548359394, 56.9463586807251, 55.07905527949333, 54.622300788760185, 48.46200294792652, 47.156510800123215, 46.42715133726597, 50.03704883158207, 50.68627819418907, 50.571535751223564, 54.632556438446045, 53.02407994866371, 57.124208137393, 55.28304733335972, 58.75121243298054, 63.577892035245895, 51.502630189061165, 42.89079509675503, 41.70348800718784, 47.53853850066662, 49.65551130473614, 52.03223057091236, 57.439712807536125, 63.00574153661728, 55.63915282487869, 29.618753269314766, 38.78375507891178, 61.369849517941475, 57.21578322350979, 55.024870187044144, 50.660367384552956, 49.49371598660946, 51.12803488969803, 52.58795455098152, 54.41083453595638, 55.15871040523052, 60.71931682527065, 60.04127740859985, 60.96684314310551, 35.62025383114815, 0.2737834432628006, 1.391725551802665, 2.0423989556729794, 0.18010303261689842, 2.490556645207107, 64.23489958047867, 48.70322920382023, 61.425649523735046, 54.373740926384926, 64.00790736079216, 33.01366209983826, 4.539043586701155, 28.678244836628437, 16.31405219435692, 26.77734173834324, 40.11484645307064, 29.74716167896986, 32.57281355559826, 53.185141906142235, 56.505806520581245, 4.865289805456996, 0.06201260934176389, 0.1953379885526374, 0.08044452595640905, 0.0337749515165342, 0.07365396377281286, 0.050928344353451394, 0.056503402229282074, 0.10035367638920434, 0.17690814624074847, 0.024329777188540902, 0.030911283793102484, 0.09249796901713125, 0.1587674446636811, 0.08060441425186582, 0.05403249575465452, 0.13156660425011069, 0.05490430034114979, 0.057047860318562016, 0.1125537529878784, 0.08693453317391686, 0.9495508193504065, 57.53284960985184, 65.57001113891602, 49.7065881639719, 41.261431127786636, 64.4239242374897, 19.638032130897045, 43.027207776904106, 16.185309402644634, 13.992942944169044, 61.89627327024937, 69.54386830329895, 70.89971914887428, 61.32032297551632, 67.93055087327957, 42.47641213238239, 0.17666210944298655, 2.258874289691448, 2.7838082844391465, 0.9990663779899478, 0.547414954053238, 24.86123565584421, 71.39010563492775, 58.89034956693649, 68.31289395689964, 57.08423048257828, 61.798496916890144, 66.59515053033829, 68.93624290823936, 66.7688924074173, 67.51634269952774, 62.272620275616646, 56.34214550256729, 60.360334888100624, 64.15227681398392, 64.69636961817741, 63.04275915026665, 47.59616240859032, 55.783947855234146, 56.741933450102806, 62.63227477669716, 59.49745059013367, 54.48890894651413, 59.39034953713417, 59.48939882218838, 60.820892974734306, 64.08664673566818, 59.97415781021118, 58.89249265193939, 61.712617725133896, 57.05657176673412, 54.69953164458275, 51.79165028035641, 54.56844247877598, 49.78653967380524, 50.71308575570583, 53.96919943392277, 57.776169553399086, 59.46925610303879, 62.70296238362789, 61.656612530350685, 60.904997661709785, 57.210170924663544, 55.80344840884209, 59.02999207377434, 59.16783727705479, 56.830822080373764, 55.549397841095924, 50.96740610897541, 49.212196692824364, 46.506905257701874, 57.22110293805599, 46.08436793088913, 22.217008844017982, 47.98097535967827, 47.1397764980793, 35.43993070721626, 41.991976127028465, 44.06836710870266, 45.62586173415184, 43.41899335384369, 45.752220153808594, 45.508087053895, 44.21142563223839, 44.41268563270569, 51.29804156720638, 52.51139625906944, 52.913840264081955, 53.895604982972145, 51.98406435549259, 51.55892416834831, 52.943759858608246, 51.257011368870735, 54.30059105157852, 54.729789420962334, 54.14323389530182, 57.15818211436272, 54.456850066781044, 53.80208820104599, 49.56719644367695, 46.804509088397026, 49.27435375750065, 50.8377418667078, 50.58762028813362, 53.75820815563202, 55.881154239177704, 56.55811831355095, 57.97949284315109, 60.95376804471016, 60.22521033883095, 61.76752097904682, 52.640900909900665, 50.19733563065529, 47.076281905174255, 49.63097222149372, 49.43657085299492, 52.382735162973404, 54.58852060139179, 56.04733072221279, 54.974534288048744, 37.13802918791771, 44.97969500720501, 63.33608441054821, 59.14916127920151, 59.33452293276787, 50.58907561004162, 51.62898860871792, 53.60939674079418, 56.56169392168522, 57.49941520392895, 56.54848203063011, 63.25676366686821, 62.31682330369949, 62.96252265572548, 39.8573836684227, 0.03342109550430905, 2.188618672080338, 3.5259084636345506, 0.5512007384095341, 4.909541755914688, 65.3451544046402, 52.41800867021084, 66.63026064634323, 57.65906743705273, 75.62855780124664, 27.591755837202072, 9.120801631361246, 37.46347412467003, 21.314371079206467, 21.105828769505024, 51.026732325553894, 35.42879730463028, 29.158014692366123, 59.55651842057705, 65.82569941878319, 6.5400774870067835, 0.2023787287180312, 0.30315782641991973, 0.14807288884185255, 0.1641160435974598, 0.21223272808128968, 0.08945586858317256, 0.017271841461479198, 0.11420611510402523, 0.24327771534444764, 0.1666875259252265, 0.11654272995656356, 0.2591105009196326, 0.2195539406966418, 0.25104406813625246, 0.09045749335200526, 0.20966863754438236, 0.3093095775693655, 0.09711996084661223, 0.5601331091020256, 0.30417786387261003, 2.135591092519462, 78.39040160179138, 74.67957392334938, 69.35962378978729, 50.558570846915245, 80.46876847743988, 36.629551872611046, 45.06334371864796, 19.211955294013023, 18.96148793399334, 68.60053852200508, 75.91992616653442, 75.79218462109566, 66.37195810675621, 75.91504722833633, 48.667655512690544, 0.196845572500024, 3.6316850502043962, 3.1613386888056993, 1.9363861880265176, 0.8584372897166759, 33.417835012078285, 75.5346192419529, 62.8124763071537, 72.43330925703049, 59.318681582808495, 63.765670359134674, 70.69306343793869, 71.33530497550964, 68.14813479781151, 71.90204456448555, 64.79327961802483, 57.8968320786953, 59.974803775548935, 64.68124642968178, 66.82613253593445, 66.98735028505325, 47.99251914024353, 57.854973524808884, 58.78371208906174, 62.78140537440777, 61.20447859168053, 59.45814169943333, 63.3128372579813, 62.725073397159576, 64.1921366751194, 67.13681146502495, 62.194466069340706, 63.60372304916382, 64.28099870681763, 60.06780378520489, 54.99511398375034, 54.51988108456135, 55.39847753942013, 52.17605285346508, 54.35069136321545, 58.391044959425926, 56.9520203769207, 60.82563132047653, 65.92447131872177, 63.72459076344967, 63.01333352923393, 61.78273156285286, 61.40500143170357, 65.36527812480927, 65.8127649128437, 59.925041645765305, 59.90714080631733, 57.14709810912609, 54.891774728894234, 54.5146107673645, 65.34286692738533, 51.31917983293533, 22.195648290216923, 48.83664384484291, 51.10426336526871, 44.668480306863785, 51.18482664227486, 54.54992227256298, 55.10279260575771, 51.922264471650124, 53.76581534743309, 53.12273025512695, 49.21791918575764, 47.65380151569843, 59.672700986266136, 58.44152145087719, 57.665789276361465, 60.02933084964752, 60.01467123627663, 55.57834088802338, 54.52472202479839, 55.551491528749466, 55.78087382018566, 57.434301897883415, 56.693079471588135, 60.63539832830429, 56.28051660954952, 55.884817242622375, 52.359548807144165, 51.91775791347027, 53.71410392224789, 55.47825425863266, 53.343293219804764, 55.12318231165409, 61.435217410326004, 58.09096746146679, 59.88660670816898, 61.76444314420223, 63.79033863544464, 59.56078179180622, 51.794606521725655, 54.35046337544918, 51.845037415623665, 55.101918652653694, 54.719852954149246, 54.19228546321392, 53.35319168865681, 55.90287767350674, 61.56567960977554, 55.87935693562031, 51.09896644949913, 65.61397477984428, 62.146383449435234, 61.39407321810722, 56.3581882417202, 55.65211392939091, 57.72014155983925, 58.57935905456543, 61.76923468708992, 61.824008747935295, 69.34895396232605, 68.55184033513069, 70.06593748927116, 49.4597952067852, 1.6797511652112007, 4.4414543733000755, 7.590669337660074, 0.638957207556814, 6.410761401057243, 72.77665883302689, 59.15403261780739, 75.27887776494026, 61.5934257209301, 76.1432021856308, 37.82467894256115, 9.228097423911095, 38.97042766213417, 25.030075795948505, 31.46944586187601, 67.77672752737999, 41.30460061132908, 45.23689180612564, 65.22014871239662, 77.01136440038681, 11.209458354860544, 0.5119079374708235, 0.5021633603610098, 0.1988689342397265, 0.27531413768883795, 0.30723432486411184, 0.246055900643114, 0.1124581198382657, 0.30565162072889507], [0.12452242051949725, 0.12533913919469342, 0.022499858096125536, 0.05280058627249673, 0.021178952119953465, 0.06084514425310772, 0.0935089003178291, 0.1002473192056641, 0.08065778209129348, 0.02596472666482441, 0.2531644731061533, 0.1994070506771095, 0.5688110715709627, 28.56195777654648, 52.389768585562706, 54.43275175988674, 46.095159351825714, 37.36205376684666, 34.14718687534332, 28.82599800825119, 15.815242510288954, 5.716752391308546, 38.874270021915436, 66.10675513744354, 69.84050318598747, 64.45673927664757, 55.63170522451401, 54.27499182522297, 1.1021800199523568, 2.131387093104422, 2.02967818826437, 0.5019170860759914, 0.18482352228602394, 7.142757447436452, 61.44101969897747, 59.476851895451546, 61.96383364498615, 58.24839301407337, 59.75853458046913, 61.79432474076748, 64.66790154576302, 67.0061668753624, 64.87107664346695, 60.90513065457344, 51.87643513083458, 57.382860258221626, 64.38812255859375, 64.41281363368034, 58.42182330787182, 45.30400760471821, 48.748484775424004, 52.71730341017246, 56.8615548312664, 58.19127827882767, 60.4917698353529, 62.26860389113426, 59.921865016222, 61.98358878493309, 61.4262080937624, 58.160233944654465, 56.63050822913647, 60.67909978330135, 56.4447969943285, 50.844072327017784, 52.173491790890694, 51.29135012626648, 47.07036182284355, 50.025923028588295, 49.859400764107704, 56.82587094604969, 54.874926432967186, 52.38961659371853, 55.857796892523766, 55.3403140604496, 55.70994682610035, 57.16118015348911, 52.35319934785366, 51.213826686143875, 48.45087334513664, 49.88887578248978, 48.47152143716812, 42.40605130791664, 36.57945156097412, 47.37335376441479, 31.568612940609455, 7.926820199936628, 34.10565510392189, 32.37225651741028, 28.924739509820938, 29.690537117421627, 32.91816182434559, 33.563150614500046, 35.214739590883255, 37.47066333889961, 39.62590388953686, 32.31158137321472, 35.7042483240366, 44.84589658677578, 48.64028558135033, 44.52471882104874, 47.50223144888878, 45.49259528517723, 45.02031482756138, 45.574199706315994, 50.387838408350945, 52.26214483380318, 51.69507846236229, 54.744540229439735, 53.338843658566475, 53.08162786066532, 50.63505694270134, 47.036277651786804, 44.28168386220932, 49.614709094166756, 48.43500919640064, 53.135748356580734, 51.52775064110756, 53.55895824730396, 54.541718512773514, 57.77125641703606, 53.59298922121525, 55.07409654557705, 54.4708751142025, 71.07324063777924, 74.99533697962761, 71.0092368721962, 58.56118842959404, 54.372771978378296, 56.165071204304695, 48.58927331864834, 39.92124304175377, 28.450376763939857, 44.59295555949211, 58.704733327031136, 59.00839403271675, 58.531755208969116, 54.0143334120512, 50.842590406537056, 51.49552837014198, 55.42968526482582, 53.68286959826946, 57.94083371758461, 58.41336876153946, 60.47506593167782, 54.869591519236565, 62.37167716026306, 17.98296444118023, 0.6400158070027828, 1.1073059448972344, 1.5780364419333637, 1.1657281662337482, 23.600282818078995, 49.43717882037163, 44.51583489775658, 62.85751149058342, 50.9121722728014, 51.73919029533863, 16.589372120797634, 12.367585860192776, 39.79587636888027, 12.52908194437623, 44.03908587992191, 42.86467909812927, 25.557215809822083, 37.81412310898304, 49.29517284035683, 49.3559505790472, 3.188431947492063, 0.03437569037487265, 0.07334589085076004, 0.06218304355570581, 0.22506699955556542, 0.03858713353110943, 0.09359398754895665, 0.06840327638201416, 0.025578249551472254, 0.010108712795044994, 0.06886262126499787, 0.0223809066665126, 0.04690640860644635, 0.04658720346924383, 0.13997025409480557, 0.0603792721813079, 0.023178648625616916, 0.03477947066130582, 0.1390466809971258, 0.27551033184863627, 0.5043192103039473, 0.7541527168359607, 31.169489957392216, 65.80632045865059, 57.517737820744514, 45.36803416907787, 56.43123932182789, 29.771972447633743, 26.895849779248238, 27.276845835149288, 5.90890190564096, 41.624212861061096, 71.04193791747093, 75.5173833668232, 69.43392500281334, 61.96577534079552, 58.80485035479069, 1.6874006297439337, 1.4653213089331985, 5.0436275359243155, 1.1568108759820461, 0.49592890427447855, 8.36448261514306, 70.54464340209961, 63.02855171263218, 66.26609578728676, 61.78485184907913, 61.724545285105705, 63.80283996462822, 68.31987798213959, 65.13078510761261, 68.18986415863037, 61.944549679756165, 56.866091787815094, 60.349497869610786, 66.7030343413353, 66.72752782702446, 62.14038737118244, 49.16627995669842, 48.65376725792885, 50.652589201927185, 56.18886172771454, 60.868637412786484, 62.623824030160904, 62.77249865233898, 61.14877738058567, 64.36240553855896, 63.98605093359947, 60.769500732421875, 60.70779964327812, 62.923665940761566, 58.15109923481941, 53.694405779242516, 54.64617110788822, 53.76432582736015, 48.223470747470856, 51.79545387625694, 53.17281536757946, 57.669201493263245, 55.64664602279663, 57.06492751836777, 58.69255878031254, 57.942543625831604, 56.726840659976006, 57.258432134985924, 55.50779387354851, 55.33836856484413, 53.810728937387466, 54.71459023654461, 54.45142015814781, 46.95588916540146, 44.5420078933239, 54.37205381691456, 42.304429560899734, 21.6977534070611, 45.52468076348305, 39.76541340351105, 37.595133259892464, 40.74104905128479, 43.41564953327179, 45.22609278559685, 46.484885439276695, 46.465042904019356, 48.20349521934986, 42.173906564712524, 43.85412320494652, 50.92624671757221, 53.100968822836876, 51.45729102194309, 52.43019461631775, 51.00543066859245, 50.684351697564125, 50.28933249413967, 53.970783948898315, 56.66991971433163, 52.47168838977814, 56.17256820201874, 54.17925976216793, 53.32243233919144, 52.076425999403, 47.61579975485802, 44.575123116374016, 50.719750598073006, 51.70506812632084, 53.51700849831104, 54.30479742586613, 56.08302220702171, 56.71430893242359, 57.244961857795715, 55.99317602813244, 59.43571150302887, 56.79170697927475, 62.68812417984009, 67.78998881578445, 71.80483058094978, 61.44080311059952, 59.58939045667648, 58.1817863881588, 51.61916233599186, 43.81228744983673, 34.566190391778946, 46.216764226555824, 61.8304418027401, 61.52409844100475, 60.47872133553028, 53.62374097108841, 52.46614448726177, 54.14549097418785, 57.18718595802784, 57.573005855083466, 60.52181862294674, 61.56014710664749, 63.92135560512543, 57.45962753891945, 65.6130400300026, 17.25595135241747, 0.9858500340487808, 5.882727960124612, 3.138448717072606, 2.3701427690684795, 32.39835351705551, 58.19776453077793, 48.77598389983177, 69.58074152469635, 57.9459672421217, 54.553725868463516, 17.677802816033363, 18.76291248947382, 43.61339472234249, 15.22272415459156, 29.42765962332487, 56.61000452935696, 24.331325590610504, 36.86272636055946, 59.29975479841232, 51.850406527519226, 4.182588988915086, 0.06970383823500015, 0.11343877151375636, 0.0886238319799304, 0.18831391702406108, 0.11675908826873638, 0.07152975900680758, 0.02259741897432832, 0.04175705777015537, 0.17797621549107134, 0.2629307802999392, 0.13035469193710014, 0.2745924732880667, 0.09715897554997355, 0.18393117876257747, 0.1309656724333763, 0.13457733410177752, 0.1382047589868307, 0.29410487157292664, 0.5565950239542872, 0.8503062603995204, 0.7376129168551415, 48.48126791417599, 76.53358563780785, 72.54219621419907, 52.62246809899807, 59.767893478274345, 49.648287892341614, 33.59607204794884, 25.52534881979227, 9.812178332358599, 50.754932910203934, 79.97300907969475, 83.60763564705849, 75.70136949419975, 70.82858696579933, 64.95053797960281, 1.3648753613233566, 6.197510669007897, 5.77108140103519, 1.9363238476216793, 0.7160755537915975, 13.819398656487465, 79.07522365450859, 64.52958896756172, 70.35884857177734, 63.48849803209305, 65.29904767870903, 66.71322539448738, 71.24901920557022, 68.98438632488251, 70.25829836726189, 65.21131798624992, 58.2744026184082, 60.994874238967896, 70.59927687048912, 70.13646930456161, 63.39990198612213, 45.95533825457096, 51.267840787768364, 53.47610369324684, 59.31322127580643, 65.14894813299179, 67.10895135998726, 67.38730922341347, 65.0759768486023, 68.3703088760376, 66.50105997920036, 61.92100614309311, 64.07840877771378, 68.1161481142044, 61.511931493878365, 53.65928806364536, 56.04797288775444, 56.16861641407013, 50.809839963912964, 53.79628211259842, 56.361349672079086, 60.05727834999561, 56.99747733771801, 57.690297961235046, 63.50230269134045, 65.06745010614395, 59.64515246450901, 62.157258465886116, 64.13569450378418, 62.42825612425804, 58.25958341360092, 62.14272424578667, 60.352480709552765, 53.15699301660061, 50.382127314805984, 63.90432491898537, 48.451397716999054, 18.90617810189724, 41.74576073884964, 47.66681581735611, 47.39455282688141, 45.62503717839718, 47.77926318347454, 52.702829986810684, 56.81292124092579, 57.87669695913792, 57.78324857354164, 47.57191590964794, 48.642101883888245, 57.004624754190445, 58.13389755785465, 54.994395822286606, 55.66887483000755, 53.49602222442627, 54.05210718512535, 53.88580150902271, 56.16609334945679, 58.73598664999008, 55.283457711339, 60.05859687924385, 54.83098179101944, 55.48350937664509, 55.245003774762154, 49.85324129462242, 46.85730345547199, 56.30583465099335, 53.09437237679958, 56.638172417879105, 57.943265587091446, 58.389559239149094, 59.64853808283806, 62.689955681562424, 57.9138969630003, 59.0850967168808, 56.645718812942505, 63.34394618868828, 68.34662094712257, 68.35210785269737, 62.622615694999695, 60.98249450325966, 60.13276129961014, 55.45132890343666, 50.46273238956928, 39.763798490166664, 44.77821081876755, 60.023030787706375, 66.83601200580597, 62.13129065930843, 60.55929981172085, 55.541338473558426, 59.341715946793556, 58.735397681593895, 61.20213411748409, 65.62250912189484, 65.33584490418434, 68.14365103840828, 63.83845925331116, 72.73081809282303, 26.418739780783653, 1.1346417968161404, 8.510509729385376, 5.742346392944455, 3.7164739379659295, 31.53898023068905, 63.736875504255295, 53.03808979690075, 75.1496011018753, 58.92562687397003, 66.07324093580246, 24.458185583353043, 18.041589595377445, 51.05345629155636, 18.10461301356554, 57.0000384002924, 69.22961756587029, 32.41935878992081, 52.307772785425186, 62.23211444914341, 73.6620569229126, 6.478675156831741, 0.21219520509475842, 0.2565776399569586, 0.2607383276335895, 0.4387835331726819, 0.4269562818808481, 0.13373790570767596, 0.24532020965125412, 0.2385883661918342], [0.11325897881761193, 0.020989544900658075, 0.04608574170561042, 0.085352689930005, 0.03360503680596594, 0.032490739176864736, 0.13434593245619908, 0.05525853113795165, 0.13158520247088745, 0.15201873960904777, 0.18865846650442109, 0.2176766039337963, 0.7981692580506206, 12.712165620177984, 55.9379193931818, 58.223287761211395, 39.00929197669029, 33.68044652044773, 46.69994629919529, 30.385698415338993, 31.198797784745693, 6.355840573087335, 25.371185392141342, 88.02128881216049, 62.14048236608505, 63.426196575164795, 47.863493263721466, 63.70923198759556, 9.92733495309949, 1.7038839077576995, 3.1544251972809434, 0.3439737518783659, 0.19102202873909846, 0.5411232635378838, 39.45998579263687, 65.71643248200417, 63.28257568180561, 63.417776226997375, 63.02999183535576, 66.10385969281197, 68.36368203163147, 67.54092738032341, 63.207408115267754, 60.488388016819954, 57.81730234622955, 57.97962963581085, 64.99479800462723, 60.10749265551567, 51.837654411792755, 58.08206453919411, 54.57185469567776, 54.53172504901886, 55.79819709062576, 53.12536731362343, 57.654503881931305, 48.0131596326828, 48.6153095215559, 58.10755357146263, 58.033047169446945, 56.542577147483826, 55.7245684415102, 55.90380862355232, 53.91218729317188, 48.817739859223366, 50.62552325427532, 48.90288949012756, 49.62765499949455, 49.802977591753006, 47.50825792551041, 50.90718314051628, 48.65546576678753, 49.092453718185425, 52.519391030073166, 52.386869341135025, 54.162430465221405, 55.27416341006756, 52.95362792909145, 52.20540627837181, 48.442908972501755, 48.96306686103344, 45.32415792346001, 40.05330875515938, 35.889040008187294, 45.205543488264084, 31.766783706843853, 6.691549709066749, 28.445904403924942, 32.48522065579891, 29.022082686424255, 31.754143685102463, 30.51222402602434, 37.16242007911205, 36.31690464913845, 37.892205119132996, 39.98036406934261, 35.815920531749725, 34.70994807779789, 41.48240067064762, 45.91427765786648, 47.39082522690296, 43.04549619555473, 44.47732776403427, 43.67270573973656, 50.27288697659969, 50.90034730732441, 52.23049633204937, 52.2517903894186, 49.48631778359413, 46.4266649633646, 47.23881438374519, 47.35832177102566, 44.581107795238495, 43.978357538580894, 45.48166327178478, 53.779806196689606, 52.92559303343296, 53.17270517349243, 50.59142008423805, 52.05474056303501, 54.675809517502785, 53.09292085468769, 53.616559356451035, 55.356618985533714, 53.004909977316856, 55.467006862163544, 61.872304156422615, 59.91377905011177, 51.88800930976868, 54.79445435106754, 45.05625709891319, 49.8636831343174, 44.51786778867245, 54.929145723581314, 57.668859511613846, 58.84511299431324, 56.84948667883873, 54.300473257899284, 53.06087717413902, 57.29214392602444, 57.76116035878658, 59.69053342938423, 57.592890188097954, 56.01934142410755, 59.73537102341652, 61.20457738637924, 45.88470384478569, 2.4421702791005373, 0.1395477939513512, 1.4331065188162029, 0.7415020081680268, 2.4581579212099314, 48.11742603778839, 63.033863827586174, 52.82431706786156, 62.168190479278564, 43.14533203840256, 56.4568005502224, 13.542979639023542, 15.15532337129116, 38.907970413565636, 13.027484100311995, 48.48404176533222, 32.567725628614426, 26.98522098362446, 40.12825593352318, 60.04057064652443, 20.916728116571903, 0.7408623956143856, 0.2626537811011076, 0.03616158712247852, 0.14623478200519457, 0.056697744730627164, 0.058808204921660945, 0.11848683774587698, 0.10057922248961404, 0.0338958807697054, 0.05704466166207567, 0.024165461982192937, 0.06805395489209332, 0.06200621945026796, 0.038243348462856375, 0.1194789852888789, 0.13603707920992747, 0.0756531760271173, 0.06900975946336985, 0.17946515668882057, 0.16278244875138626, 0.3186307742726058, 0.7449234277009964, 13.4498380869627, 62.59693667292595, 72.14080095291138, 36.93474009633064, 42.494301572442055, 52.91221395134926, 20.14116883277893, 45.52144333720207, 8.367957528680563, 28.35726086050272, 91.35862693190575, 72.30894953012466, 73.74053791165352, 55.46881176531315, 67.91224345564842, 13.636469822376966, 1.1185127310454845, 5.985293006524444, 1.2984069529920816, 0.46976125217042863, 0.3079056419664994, 45.368531942367554, 68.35908427834511, 64.54145953059196, 65.94219356775284, 64.79476153850555, 70.23838743567467, 67.718256264925, 67.34399914741516, 64.55105781555176, 62.94795423746109, 61.601610481739044, 62.70300418138504, 68.21892499923706, 62.726692110300064, 54.777837842702866, 60.566603019833565, 54.87412467598915, 53.9386110752821, 57.20722608268261, 53.6940485984087, 55.83898410201073, 52.22833804786205, 50.0776382535696, 61.16018816828728, 57.6467826962471, 59.499103501439095, 57.71199859678745, 60.36221958696842, 55.376256331801414, 51.88452489674091, 51.00801832973957, 49.33898068964481, 50.73926255106926, 49.88970413804054, 48.67822274565697, 52.58235365152359, 50.780581533908844, 50.928572192788124, 55.28031527996063, 56.52526907622814, 57.49922901391983, 57.58044585585594, 56.27253323793411, 56.8889931589365, 55.25814346969128, 56.19836121797562, 53.63538354635239, 46.022169068455696, 42.33463793992996, 52.35585540533066, 44.094285517930984, 20.7365170866251, 42.62670546770096, 38.872913494706154, 41.12627997994423, 38.89597445726395, 41.43158599734306, 42.923617735505104, 45.71190431714058, 45.73937684297562, 50.141721814870834, 45.2149897813797, 42.59094178676605, 48.76789413392544, 52.119504287838936, 52.687721997499466, 48.98304998874664, 47.409983798861504, 48.74029241502285, 52.844243198633194, 52.375823333859444, 53.21517929434776, 52.72328048944473, 51.029528975486755, 50.724758729338646, 48.965377137064934, 49.835150465369225, 46.09818018972874, 46.98477141559124, 47.58778005838394, 54.092483818531036, 54.55756366252899, 56.50418400764465, 53.81094552576542, 55.139445438981056, 57.95406460762024, 57.592677399516106, 57.27577820420265, 59.06673990190029, 56.33166566491127, 56.94569751620293, 59.96107891201973, 60.013554096221924, 55.00070348381996, 59.09585013985634, 49.55598704516888, 51.234303787350655, 44.169472083449364, 54.15746793150902, 60.169984102249146, 61.48499093949795, 60.010271072387695, 53.53347681462765, 54.69566725194454, 58.5108183324337, 59.727307856082916, 62.88520060479641, 58.54793094098568, 57.15922325849533, 62.09211476147175, 64.0802250802517, 48.62051144242287, 1.519662905484438, 1.7245026701129973, 4.40954796038568, 0.40414328570477664, 2.5104046426713467, 56.417601853609085, 61.917787715792656, 58.20664845407009, 65.52181452512741, 47.59344555437565, 59.27333861589432, 17.01611202210188, 20.326260700821877, 45.02798281610012, 12.692419979721308, 37.77142859995365, 45.24115897715092, 25.03424797207117, 40.97102031111717, 70.18642902374268, 23.61715391278267, 0.8809186646249145, 0.27208929823245853, 0.0908080542285461, 0.10274521016981453, 0.09515052355709486, 0.07547852641437203, 0.10777792136650532, 0.0622187223052606, 0.10149989378987812, 0.21770827879663557, 0.16106219496577978, 0.16440675768535584, 0.3159527195384726, 0.11099948053015396, 0.20734779332997277, 0.2286471941624768, 0.18326424033148214, 0.21200321149080992, 0.46621535962913185, 0.23917485581478104, 0.5298385221976787, 1.119484172668308, 21.873239390552044, 81.30935177206993, 78.8210628926754, 51.26671984791756, 47.4092960357666, 72.89624601602554, 34.09223422408104, 44.84193719923496, 10.330792553722858, 32.6197562366724, 92.52645626664162, 77.83953756093979, 74.59690555930138, 61.42542913556099, 78.07247266173363, 13.898456264287233, 2.71027154289186, 10.547073148190975, 1.2134924344718456, 1.6661657067015767, 0.9322871582116932, 55.82731492817402, 75.02813681960106, 70.28825595974922, 66.592847853899, 68.01163852214813, 72.99830853939056, 74.09188985824585, 69.6869458258152, 70.49449369311333, 64.99553516507149, 65.2726922929287, 60.04782445728779, 71.43254175782204, 61.808642372488976, 60.44868774712086, 59.92187641561031, 54.54038478434086, 57.667229399085045, 56.977311819791794, 53.9582484215498, 59.2906428873539, 56.51514641940594, 56.30680359899998, 65.828458070755, 61.375799998641014, 61.59423887729645, 61.21888741850853, 63.791524171829224, 58.658710196614265, 52.1070409566164, 54.63829033076763, 51.61450758576393, 52.395179495215416, 54.716714322566986, 53.117611929774284, 53.66466097533703, 53.07753928005695, 54.29235689342022, 56.52837730944157, 58.19389633834362, 57.370579317212105, 61.73642724752426, 60.18285781145096, 66.40181690454483, 59.46665324270725, 60.9847591817379, 57.386040687561035, 50.56355997920036, 51.113702058792114, 60.3048350661993, 50.78987963497639, 12.459663469344378, 37.16963589191437, 51.665626242756844, 46.16651572287083, 48.02260972559452, 43.03478457033634, 50.054220110177994, 52.87775360047817, 57.93521761894226, 58.68653230369091, 52.581893876194954, 48.058115020394325, 53.48056085407734, 56.441791355609894, 59.211097955703735, 51.050196066498756, 52.69631713628769, 52.975769340991974, 55.798713862895966, 55.25629676878452, 55.64169488847256, 55.77834315598011, 52.9849686473608, 50.217930525541306, 51.017704010009766, 53.195492550730705, 46.67588599026203, 48.771028965711594, 49.643469750881195, 56.97489894926548, 57.13440299034119, 59.699497148394585, 56.374443769454956, 56.590709164738655, 62.009336203336716, 58.40389966964722, 57.79017560184002, 58.39382641017437, 58.376233354210854, 57.38162912428379, 60.86827643215656, 63.88504475355148, 56.72951951622963, 63.73624473810196, 51.832053512334824, 50.99334731698036, 43.28253887593746, 59.24714282155037, 63.72671104967594, 62.64590084552765, 63.67814585566521, 58.460657224059105, 61.9123388081789, 62.41285555064678, 63.609498739242554, 65.34672752022743, 63.18736419081688, 60.90749032795429, 66.50602251291275, 68.03292497992516, 59.462967440485954, 5.461090235039592, 1.5812473883852363, 5.480629736557603, 3.412778084166348, 3.6244557006284595, 61.63485109806061, 71.70475155115128, 65.91956958174706, 68.84082242846489, 55.0388078391552, 67.25396677851677, 20.414034090936184, 20.63419807702303, 53.13428923487663, 16.192935593426228, 68.20164352655411, 51.38193726539612, 35.51590383052826, 51.455945894122124, 79.74086433649063, 41.4293897151947, 1.728702513501048, 0.21557478234171867, 0.15106558450497687, 0.1898280912428163, 0.2797952253604308, 0.2233599263126962, 0.26092564570717514, 0.13092702138237655, 0.20624773751478642], [0.004460014388314448, 0.07357640934060328, 0.07972888779477216, 0.017158012706204318, 0.09227388494764455, 0.01405156899636495, 0.06392091963789426, 0.0515713856293587, 0.14237301656976342, 0.2022376612876542, 0.09595363124390133, 0.13781020359601825, 0.10382663065684028, 1.8525321688503027, 44.7707974165678, 50.52093006670475, 67.51629710197449, 39.45945002138615, 44.35141772031784, 29.917212054133415, 30.812917090952396, 7.732262089848518, 18.893543779850006, 83.7674018740654, 93.68568286299706, 64.09980162978172, 41.137964352965355, 48.36398720741272, 37.74496681988239, 0.6598963402211666, 1.675498599652201, 0.9200643422082067, 0.5310634814668447, 0.528901219367981, 6.717409696429968, 55.1686392724514, 61.70546270906925, 67.0450159907341, 61.67724922299385, 65.69409728050232, 66.31731703877449, 67.68327534198761, 65.8041849732399, 64.91417393088341, 58.83317783474922, 63.51696230471134, 63.88993129134178, 56.74282260239124, 63.10185357928276, 60.856504663825035, 69.12310168147087, 64.92590770125389, 57.622501999139786, 57.35936991870403, 57.988061383366585, 55.01710720360279, 39.28315468132496, 51.43172599375248, 57.45327427983284, 57.41880252957344, 54.660906717181206, 53.4634617716074, 52.03853823244572, 50.41501075029373, 48.332581892609596, 50.860837027430534, 47.498564645648, 45.30438378453255, 44.911826848983765, 46.303673163056374, 47.44867332279682, 46.50954611599445, 48.38501147925854, 49.11814793944359, 53.36092807352543, 53.48439484834671, 56.70035608112812, 51.129934787750244, 46.676824539899826, 48.77677425742149, 47.04589493572712, 39.147140979766846, 37.0515002310276, 42.03004628419876, 36.27156548202038, 7.8645838145166636, 24.759254828095436, 35.66894821822643, 29.05713200569153, 33.25755961239338, 26.05264462530613, 31.737825460731983, 40.304197892546654, 39.99739095568657, 41.253994926810265, 38.89457993209362, 33.166881278157234, 40.60983829200268, 45.048558712005615, 48.758991211652756, 46.65000557899475, 47.907593697309494, 47.80346408486366, 50.657460540533066, 51.71799123287201, 53.788902908563614, 48.92574526369572, 44.97360773384571, 45.25758929550648, 44.965130388736725, 43.70844282209873, 43.37885990738869, 41.386577412486076, 46.934165731072426, 52.22301833331585, 51.16185687482357, 53.49911905825138, 51.778278797864914, 54.77091461420059, 52.66050025820732, 56.72115996479988, 53.22871416807175, 57.88982905447483, 56.19640812277794, 54.75506566464901, 50.72831153869629, 51.16513229906559, 53.82180534303188, 50.29606193304062, 52.33730100095272, 49.29563261568546, 35.129468366503716, 57.03978046774864, 58.11562433838844, 60.468967258930206, 53.70400406420231, 53.50103035569191, 54.89230290055275, 59.34426560997963, 55.683762431144714, 59.23366494476795, 57.402110025286674, 61.46648973226547, 58.391447737812996, 59.83995661139488, 9.191512037068605, 0.44721373706124723, 0.2539092331426218, 1.6441406635567546, 1.3294519996270537, 6.654256135225296, 58.50894883275032, 47.2136939316988, 58.71617451310158, 47.46423348784447, 53.39122384786606, 53.00114817917347, 4.659332782030106, 31.38798013329506, 20.087635405361652, 21.057806946337223, 47.81451769173145, 27.899702712893486, 34.11255553364754, 45.21887317299843, 54.691381081938744, 10.057825651019812, 0.2499404054833576, 0.15251079836161807, 0.07294064853340387, 0.10912365032709204, 0.0090324140546727, 0.148443101788871, 0.055467935526394285, 0.04875427839579061, 0.04878071369603276, 0.015723619362688623, 0.05835175441461615, 0.04079944235854782, 0.020057435249327682, 0.030360962737177033, 0.01716502600174863, 0.08672639043652453, 0.044334607155178674, 0.021906574111199006, 0.10081354819703847, 0.04153380490606651, 0.09647350569139235, 0.07743055291939527, 1.501874872483313, 51.92514471709728, 60.394369661808014, 66.21542170643806, 37.105955109000206, 62.1583604067564, 16.949361003935337, 43.03085558116436, 12.312413770705462, 21.20108775794506, 83.98248553276062, 91.63317739963531, 70.62761574983597, 46.7828768491745, 52.49453276395798, 44.21519882977009, 0.8707195962779224, 0.33675304090138525, 2.1783138625323772, 0.409271793323569, 0.3992033132817596, 8.43462685123086, 62.013949155807495, 65.15450343489647, 71.06825530529022, 62.4042946100235, 68.45139652490616, 66.0304020345211, 67.253647595644, 66.00969314575195, 66.64941921830177, 61.96196794509888, 68.08672249317169, 65.11039540171623, 61.83156654238701, 64.72343176603317, 61.64278507232666, 68.92703220248222, 66.63974493741989, 59.12356585264206, 59.66840721666813, 57.11826145648956, 55.990994945168495, 45.14994867146015, 53.98661769926548, 61.28211222589016, 59.62049558758736, 57.35039860010147, 55.358378291130066, 55.67299760878086, 51.06364734470844, 51.63316458463669, 53.757227808237076, 50.82203730940819, 47.647938430309296, 49.24349561333656, 46.810330376029015, 49.675737619400024, 50.22365681827068, 50.275007262825966, 52.44168899953365, 55.782112553715706, 56.453916504979134, 59.622570276260376, 54.427610635757446, 55.79345874488354, 55.16423150897026, 56.070889458060265, 44.915455654263496, 43.32309029996395, 51.04863055050373, 48.97446244955063, 29.216522052884102, 43.44352863729, 40.108101814985275, 39.80528846383095, 38.40257093310356, 37.9402307420969, 40.502839833498, 48.399416506290436, 48.30610491335392, 49.83800031244755, 45.909011140465736, 39.718436524271965, 47.64411963522434, 50.70020064711571, 55.28880022466183, 50.516115725040436, 50.66398099064827, 52.77987465262413, 55.3911629319191, 54.08038906753063, 55.6211493909359, 51.908657401800156, 46.525163277983665, 45.03709092736244, 44.860290214419365, 45.00021770596504, 44.684017673134804, 44.43991117179394, 47.96215116977692, 55.48668220639229, 53.068674355745316, 55.784126445651054, 54.463549107313156, 55.07864870131016, 55.92238962650299, 58.089591935276985, 58.8702068477869, 58.95571365952492, 57.653911113739014, 56.77231281995773, 55.143226236104965, 54.135546907782555, 54.11372847855091, 52.28521719574928, 52.83442072570324, 49.53183554112911, 38.682596907019615, 58.559915497899055, 62.733896523714066, 62.569536343216896, 55.14333263039589, 54.074852764606476, 56.230636686086655, 62.022928074002266, 56.85214273631573, 61.25443451106548, 59.36896048486233, 64.47066932916641, 58.858640268445015, 59.673582538962364, 9.227635748684406, 0.6024552381131798, 1.9272033870220184, 1.1383682093583047, 1.2499797390773892, 9.48071451857686, 68.58277827501297, 53.33532504737377, 64.83532816171646, 48.2626124471426, 66.05709940195084, 44.31282319128513, 10.407224502414465, 36.014307886362076, 25.192612074315548, 18.83613646030426, 46.390642896294594, 39.37865115702152, 25.639686584472656, 50.95636390149593, 59.21419098973274, 9.729317128658295, 0.22130952071165666, 0.13194042403483763, 0.06485447462182492, 0.06916725804330781, 0.0852472084807232, 0.03285429876996204, 0.05568975233472884, 0.09725020034238696, 0.045617977157235146, 0.13504411530448124, 0.1444467849796638, 0.11237084327149205, 0.17889071954414248, 0.25233887834474444, 0.1441195869119838, 0.12159161255112849, 0.22378661669790745, 0.21904607419855893, 0.38206177996471524, 0.15473771636607125, 0.4644242604263127, 0.26901279925368726, 4.557621739804745, 74.46337312459946, 68.22896406054497, 85.19025832414627, 49.00425285100937, 73.09025600552559, 34.39219392836094, 44.23356704413891, 11.590232122689486, 28.693934194743633, 86.37789979577065, 94.42443162202835, 74.10133615136147, 54.82976585626602, 61.44573524594307, 50.08975200355053, 0.8703713805880398, 9.38857801258564, 1.495864070020616, 1.1871632910333574, 0.6901095877401531, 11.421246640384197, 70.34118711948395, 70.27561023831367, 73.81693661212921, 67.23682209849358, 72.64165967702866, 71.19348898530006, 71.02806106209755, 71.7836657166481, 68.5677082836628, 64.57329422235489, 69.242232888937, 70.70307970046997, 65.16291618347168, 64.29274767637253, 65.25721952319145, 68.48438635468483, 71.65412306785583, 61.581372767686844, 60.33713713288307, 61.8041206151247, 57.80713029205799, 45.049656853079796, 59.72674548625946, 64.92839276790619, 62.21868596971035, 61.37403689324856, 59.89443048834801, 57.655868008732796, 53.84141989052296, 53.54356907308102, 55.12340269982815, 53.040863648056984, 50.73148436844349, 52.67962083220482, 48.57143707573414, 50.60333624482155, 52.977657839655876, 52.35091187059879, 56.40486493706703, 56.12668566405773, 60.31455874443054, 63.9838470518589, 64.04971271753311, 58.51925007998943, 58.73464912176132, 59.79593597352505, 49.56494316458702, 51.76843732595444, 57.69147589802742, 59.78287227451801, 17.125333361327648, 35.06703771650791, 55.351713448762894, 43.93539324402809, 47.35977329313755, 40.28396777808666, 44.8741290718317, 57.17251494526863, 56.962580010294914, 58.141694739460945, 53.54725867509842, 45.229588598012924, 53.67805905640125, 56.535843908786774, 57.74369269609451, 53.75730000436306, 56.753123849630356, 55.780858621001244, 57.04491399228573, 57.37462230026722, 57.066470235586166, 51.33086800575256, 45.842089131474495, 48.03892605006695, 47.10769861936569, 49.02799017727375, 46.18802636861801, 45.034974440932274, 49.87042777240276, 55.73440991342068, 56.65680281817913, 58.399970680475235, 56.86062008142471, 59.36058573424816, 58.08061681687832, 60.007444024086, 57.39063464105129, 58.92582066357136, 58.994703367352486, 59.72756624221802, 56.87914028763771, 53.43418814241886, 55.34496121108532, 53.18450354039669, 52.71061956882477, 52.52552770078182, 38.129445388913155, 58.57376955449581, 64.0748293697834, 65.63011631369591, 56.34343363344669, 58.747017458081245, 60.846822783350945, 66.68405055999756, 61.562670171260834, 65.70554986596107, 65.15635773539543, 67.76829198002815, 65.40982693433762, 68.80251288414001, 16.270958706736565, 0.9708273026626557, 2.3210261296480894, 7.487986497581005, 5.217297216877341, 8.239221386611462, 77.05589041113853, 58.31728331744671, 69.30464833974838, 54.92205150425434, 67.25500792264938, 60.20026087760925, 10.483932886272669, 37.275767996907234, 32.99964465200901, 24.044857062399387, 74.66862291097641, 42.19241537153721, 46.062899082899094, 57.43853107094765, 79.60901901125908, 18.85651096701622, 0.45819105114787817, 0.23485827259719372, 0.1158321309776511, 0.1918768641189672, 0.15666467312257737, 0.22159584128530696, 0.1983565406408161, 0.25799597322475165, 0.1422055286820978], [0.03344800577906426, 0.036326507179182954, 0.017482271869084798, 0.07955745168146677, 0.08936229860410094, 0.09525483983452432, 0.06108436071372125, 0.05012037931010127, 0.08287974254926667, 0.18789423251291737, 0.17449773964472115, 0.10606089592329226, 0.15054052986670285, 0.294034278485924, 25.164943858981133, 55.00494785606861, 58.97628575563431, 43.96805249154568, 34.20229531824589, 26.81582037359476, 36.18820935487747, 12.373201008886099, 5.68032612092793, 42.2689014673233, 88.83454397320747, 63.302414417266846, 57.08677634596825, 56.604764610528946, 60.18230304121971, 5.759901450946927, 2.042587995529175, 3.0008182022720575, 0.06782365162507631, 0.1616366024245508, 0.3148979495745152, 21.374423056840897, 60.11897563934326, 65.39979547262192, 77.67924696207047, 70.2173213660717, 68.3481028676033, 59.76597838103771, 63.695389330387115, 61.905274987220764, 63.52259360253811, 64.24249917268753, 60.56241564452648, 65.35216882824898, 66.46219566464424, 59.01930324733257, 60.0360032916069, 61.21822625398636, 63.897728472948074, 58.60016293823719, 57.73324705660343, 58.515864461660385, 65.26089772582054, 56.04720152914524, 61.18306674063206, 57.071896344423294, 57.5757797062397, 49.99244682490826, 50.47734260559082, 47.28960245847702, 49.76563319563866, 47.092617228627205, 47.722456231713295, 42.433288246393204, 44.741618782281876, 45.10164946317673, 44.642919078469276, 45.37198215723038, 46.86075747013092, 45.47791667282581, 49.37542073428631, 49.028791934251785, 55.37751406431198, 53.238950818777084, 46.46533168852329, 47.42844320833683, 45.51833510398865, 37.77149699628353, 36.10538139939308, 37.68895022571087, 40.05663737654686, 11.770285461097956, 25.04482850432396, 42.410736456513405, 31.031462363898754, 41.85410052537918, 15.234814155846834, 26.41758844256401, 45.715612918138504, 37.14421145617962, 42.59330525994301, 41.470777094364166, 36.45848885178566, 37.00641185045242, 45.91745808720589, 48.06319534778595, 47.250753343105316, 48.311956599354744, 51.17716625332832, 52.772727236151695, 52.48731315135956, 49.52700600028038, 43.26789826154709, 42.63744369149208, 42.39378556609154, 42.59137496352196, 42.28139899671078, 43.018228858709335, 44.55206215381622, 47.74918019771576, 50.994893833994865, 54.22043435275555, 52.912810519337654, 49.0210897475481, 50.55999577045441, 54.123558551073074, 56.57656632363796, 54.23232391476631, 55.519170463085175, 61.4804919809103, 44.19792115688324, 45.79078048467636, 50.19840717315674, 47.181935235857964, 46.81487113237381, 45.59736706316471, 46.906845197081566, 45.83126351237297, 59.372258707880974, 57.277066335082054, 56.65668122470379, 56.62012338638306, 55.11773720383644, 60.178928822278976, 57.679054364562035, 59.22216296195984, 60.56402675807476, 57.690715938806534, 49.500582218170166, 53.95292870700359, 18.18919077515602, 0.4649097437504679, 0.039188744412967935, 4.315114002674818, 2.6770748617127538, 1.1075047217309475, 43.63654688000679, 59.33864951133728, 54.5600563287735, 53.402592837810516, 58.45995806157589, 62.88100562989712, 10.7099799066782, 7.190201226621866, 61.296232268214226, 13.80737230181694, 27.487312741577625, 43.93635459244251, 24.588691480457783, 31.96036621928215, 50.50789296627045, 44.42489057779312, 0.8350114873610437, 0.05428829179436434, 0.04428555861522909, 0.037057778681628406, 0.0705731232301332, 0.048920204062596895, 0.04198670794721693, 0.15555989724816754, 0.010629569660522975, 0.13478651584591717, 0.07780111467582174, 0.030368920415639877, 0.02922814295743592, 0.052472742536338046, 0.12787293526344, 0.0315988520742394, 0.003341792653372977, 0.08818370872177184, 0.11328615626553074, 0.02396821026195539, 0.08949746596044861, 0.035521002355380915, 0.24055942136328667, 0.3295481821987778, 27.608404643833637, 66.43419876694679, 60.01105383038521, 39.51776169240475, 45.91273494064808, 21.48831434547901, 30.421853475272655, 24.124210104346275, 6.882975362241268, 42.84256808459759, 90.10616093873978, 57.92904295027256, 53.70444484055042, 63.94964888691902, 67.54069939255714, 10.435773320496082, 0.7515981257893145, 1.2497207592241466, 0.7653263735119253, 0.4279077745741233, 0.4912128526484594, 26.73053205013275, 65.91187879443169, 66.08780175447464, 75.37102282047272, 70.35697147250175, 66.01569682359695, 62.38402269780636, 67.55407467484474, 63.40068094432354, 66.11398994922638, 64.30793166160583, 63.627285584807396, 70.09309843182564, 66.73377469182014, 64.16779518127441, 61.981046721339226, 62.43943132460117, 64.65882763266563, 60.74033349752426, 57.00136832892895, 58.188291639089584, 65.08615270256996, 59.19995695352554, 61.255464255809784, 58.20533372461796, 59.1195684671402, 51.63179285824299, 53.351474180817604, 50.03341242671013, 49.607994854450226, 48.81389066576958, 49.53364424407482, 44.76505972445011, 48.92503850162029, 45.94150699675083, 47.22294643521309, 47.39324189722538, 49.73348692059517, 49.52206626534462, 50.829530507326126, 52.38687314093113, 59.02016960084438, 56.34070537984371, 55.45468792319298, 54.897786006331444, 52.83407874405384, 44.8802999407053, 40.6442454457283, 45.96732661128044, 49.930593743920326, 44.22391936182976, 46.817979365587234, 49.28316168487072, 40.793148055672646, 43.65744195878506, 29.00559537112713, 30.981187261641026, 52.60985657572746, 45.21941274404526, 51.40592157840729, 48.902805894613266, 44.11467902362347, 43.284719958901405, 50.83412066102028, 53.63624230027199, 53.399666994810104, 51.57552167773247, 55.400936007499695, 56.975966691970825, 55.03052808344364, 52.27905012667179, 45.47534421086311, 43.60569253563881, 42.81704865396023, 45.714431181550026, 45.13041391968727, 47.546871453523636, 47.098533511161804, 50.37285201251507, 54.95182290673256, 56.47740304470062, 55.208130553364754, 53.19078840315342, 51.72190122306347, 57.460687682032585, 57.89478778839111, 55.52336923778057, 56.12947851419449, 61.28727614879608, 46.98377586901188, 47.91635222733021, 49.37239229679108, 49.48490045964718, 49.073253348469734, 46.005772948265076, 48.649750873446465, 49.40518833696842, 60.706268325448036, 59.27233166992664, 59.373588636517525, 58.091127052903175, 57.4468108266592, 61.425349339842796, 57.92572192847729, 61.856132224202156, 61.98835372924805, 59.67266298830509, 52.102576196193695, 53.80862005054951, 20.140351876616478, 0.4704562289407477, 0.5330346256960183, 2.3813904030248523, 1.4886984857730567, 3.507618857547641, 51.02737449109554, 61.26790098845959, 58.30526456236839, 56.98753707110882, 65.62514618039131, 59.70214940607548, 11.86366830021143, 19.61954802274704, 56.2556279450655, 18.448827043175697, 17.497624084353447, 55.28689652681351, 30.137617327272892, 28.178849034011364, 56.3022780418396, 46.11215204000473, 2.3059511510655284, 0.042970302238245495, 0.04283258931536693, 0.056068140038405545, 0.02562116609624354, 0.07724074865109287, 0.09664093420724384, 0.02327355818124488, 0.016825027742015664, 0.014023634557815967, 0.1976873163948767, 0.12354641468846239, 0.1695735304383561, 0.24253317795228213, 0.33821438904851675, 0.2565678732935339, 0.26056347764097154, 0.21546323754591867, 0.21540762099903077, 0.2893165941350162, 0.2561562485061586, 0.19368111417861655, 0.552597816567868, 0.6822478689718992, 48.53705272078514, 76.60546258091927, 77.04671770334244, 56.89236357808113, 57.82006099820137, 38.057739436626434, 43.17218899726868, 20.263070091605186, 9.512259475886822, 54.573541805148125, 93.76412585377693, 70.29522478580475, 66.68517529964447, 71.00441113114357, 70.55687874555588, 9.655280951410532, 5.955797089263797, 12.31049107387662, 0.7717209553811699, 0.7125958905089647, 0.9698659542482346, 33.317034021019936, 71.56866565346718, 71.67698264122009, 80.59294581413269, 73.77083748579025, 69.81969550251961, 63.94738420844078, 69.89509105682373, 65.3718289732933, 67.92273849248886, 67.49654576182365, 66.23049929738045, 70.26332929730415, 66.54303252696991, 66.03027284145355, 64.65788528323174, 66.24871551990509, 69.78491216897964, 62.25836344063282, 60.37387736141682, 62.42579385638237, 63.4562111645937, 57.556180357933044, 66.71378776431084, 61.97640337049961, 63.357526659965515, 55.00283516943455, 56.61560542881489, 50.82305185496807, 54.239820912480354, 49.84734021127224, 52.51957342028618, 47.32233390212059, 51.10617086291313, 47.68986918032169, 47.152076438069344, 50.29934495687485, 51.191111505031586, 54.83359985053539, 55.051685348153114, 54.17459361255169, 64.03744697570801, 63.63631770014763, 57.71108664572239, 57.258732318878174, 57.71628476679325, 48.80974128842354, 48.64760018885136, 49.63193736970425, 56.25513017177582, 36.5146916359663, 40.5062710493803, 61.04749381542206, 43.13414543867111, 59.82448764145374, 28.10949895530939, 40.349552258849144, 62.86071091890335, 51.6880564391613, 60.19020661711693, 55.68584091961384, 48.8921132683754, 46.22129738330841, 56.35560818016529, 58.988167718052864, 57.066675424575806, 51.783484518527985, 59.06883358955383, 59.91706967353821, 55.511985048651695, 52.542945966124535, 46.82501278817654, 43.068462163209915, 42.8887128084898, 47.82798416912556, 48.195720836520195, 48.83301503956318, 49.33102011680603, 54.09132108092308, 57.24948361515999, 60.377528965473175, 57.97231502830982, 53.421071246266365, 54.777647852897644, 58.87875258922577, 57.96173259615898, 59.27617326378822, 55.19304156303406, 61.170364022254944, 46.40785217285156, 47.59547084569931, 50.520892068743706, 48.60401272773743, 48.53870943188667, 49.04454208910465, 48.99212010204792, 48.00299137830734, 65.38852527737617, 64.09363836050034, 61.5658164024353, 63.47169533371925, 58.53321433067322, 67.88033276796341, 63.40218186378479, 64.12102729082108, 67.85898551344872, 63.3194413036108, 60.78325219452381, 62.85599537193775, 29.913938529789448, 0.6907514564227313, 0.30878140591084957, 14.139392785727978, 11.661467850208282, 1.808841519523412, 53.972113877534866, 71.26448437571526, 67.03574448823929, 66.71797513961792, 69.8806594312191, 72.55127772688866, 16.27157237380743, 12.18348003923893, 72.54807069897652, 19.322462864220142, 33.382162526249886, 69.86744374036789, 35.17494052648544, 45.27562692761421, 61.930726021528244, 69.67184543609619, 4.236696185544133, 0.09728391611133702, 0.15113822591956705, 0.19499435933539644, 0.175861673487816, 0.15249108691932634, 0.21478709648363292, 0.30129975581075996, 0.1087682209617924, 0.2579488913761452], [0.02088810444547562, 0.043489694289746694, 0.07179127700510435, 0.006520843917314778, 0.12804682046407834, 0.049835049503599294, 0.008007083233678713, 0.13771740545053035, 0.04780791394296102, 0.05456369908642955, 0.06052789838577155, 0.1132268512446899, 0.24426747317193076, 0.41983587958384305, 8.132994286715984, 50.450516045093536, 56.13115042448044, 41.94607459008694, 42.95550562441349, 31.78357120603323, 30.827844589948654, 35.25391548871994, 4.108579885214567, 5.625015813857317, 55.071383491158485, 73.56846794486046, 66.7371717095375, 60.03305085003376, 39.96773734688759, 30.138761065900326, 3.281001867726445, 3.014276367612183, 2.3770491359755397, 0.4111641808412969, 0.04055055571370758, 0.2823928609723225, 30.76700035482645, 66.0258574783802, 54.23709645867348, 63.06274987757206, 54.38767857849598, 57.80313290655613, 64.87005829811096, 63.79815861582756, 65.27734324336052, 63.053957149386406, 65.14940410852432, 62.57873944938183, 61.296068876981735, 60.54058961570263, 59.12041202187538, 58.08593273162842, 60.068461149930954, 56.6278787702322, 63.19494478404522, 58.40980835258961, 57.84062549471855, 63.36406610906124, 58.27901177108288, 59.12507817149162, 53.04264955222607, 51.37055687606335, 50.052248015999794, 47.35114395618439, 48.3412454277277, 46.58906064927578, 47.713914290070534, 42.680871561169624, 45.41669815778732, 45.572098419070244, 47.100456207990646, 45.05330465734005, 46.05688780546188, 46.16975694894791, 49.61101569235325, 53.91066737473011, 59.05220948159695, 53.13038684427738, 47.47134670615196, 46.690021231770515, 45.26168927550316, 36.31729602813721, 36.48925580084324, 37.35141433775425, 38.816182538867, 25.656759068369865, 27.839703932404518, 45.28060846030712, 38.66932421922684, 43.1302772462368, 11.329470165073872, 22.683646604418755, 50.13782702386379, 37.54578150808811, 47.2473107278347, 41.471445858478546, 40.879946798086166, 36.77092328667641, 46.434093564748764, 47.320673391222954, 49.761274829506874, 53.261529207229614, 52.19250977039337, 51.5728048235178, 51.31241239607334, 44.92920711636543, 43.360362499952316, 42.00679533183575, 40.85374340415001, 41.34768649935722, 40.86701229214668, 41.30578614771366, 43.09352561831474, 45.82107625901699, 50.318826511502266, 54.492978528141975, 52.81523175537586, 49.4854324311018, 49.948665574193, 52.07200683653355, 54.90146800875664, 54.815284833312035, 52.08453096449375, 52.71808236837387, 54.161461517214775, 49.96332898736, 46.21687442064285, 47.004917934536934, 51.430985033512115, 52.6750572770834, 44.16453614830971, 43.75552989542484, 58.384535908699036, 61.14384524524212, 57.62426510453224, 59.1691330075264, 57.75355316698551, 57.30430707335472, 56.69283248484135, 56.347997188568115, 49.82055924832821, 50.92648610472679, 37.97833509743214, 17.664699219167233, 0.8861402375623584, 0.17960558587219566, 1.0607073828577995, 1.0260628606192768, 8.272645343095064, 59.536979869008064, 53.38177375495434, 54.38680462539196, 49.401031360030174, 54.06719997525215, 56.57542258501053, 13.864064309746027, 0.8614337851759046, 33.41065339744091, 58.479933589696884, 14.26614923402667, 40.889499485492706, 35.77331721782684, 21.179681606590748, 41.18167720735073, 56.36669218540192, 25.219980105757713, 0.32526976021472365, 0.08898748434148729, 0.039440406690118834, 0.12147439774707891, 0.09215567566570826, 0.06751492561306804, 0.09357560455100611, 0.0758217326074373, 0.021388213644968346, 0.02347951158299111, 0.06703978782752529, 0.02282404118886916, 0.023297286497836467, 0.023184066303656437, 0.05183075139939319, 0.03767671500099823, 0.07561648424598388, 0.05094862724945415, 0.05494682540302165, 0.015882754378253594, 0.042025537113659084, 0.2186652782256715, 0.1184947564615868, 0.3563982539344579, 9.084466081112623, 55.30831977725029, 62.09268093109131, 41.30305029451847, 51.59502983093262, 34.82252083718777, 21.111824847757816, 45.0051574409008, 9.638761337846518, 7.74507025256753, 58.640881553292274, 75.57859808206558, 70.15972405672073, 67.51892656087875, 42.329151034355164, 35.94781145453453, 5.372936865314841, 0.7319186255335808, 1.509470189921558, 0.41790196148213, 0.08845065181958489, 0.8935858786571771, 39.5422437787056, 68.25414150953293, 57.18960642814636, 63.31715002655983, 54.35830235481262, 58.47115986049175, 67.38803878426552, 64.92504894733429, 68.50413769483566, 65.57378813624382, 68.18906620144844, 64.84423488378525, 63.872999399900436, 62.57570341229439, 60.538047552108765, 58.67048196494579, 61.16008177399635, 61.20732843875885, 63.46528887748718, 60.366182774305344, 57.00759619474411, 65.6199100613594, 59.94005084037781, 59.17294800281525, 54.76683363318443, 53.18375498056412, 52.72255852818489, 50.09392037987709, 51.53878904879093, 47.70454399287701, 48.202374279499054, 46.69963091611862, 49.3775600194931, 47.28193446993828, 47.93695092201233, 45.64574986696243, 49.47403684258461, 48.98574024438858, 55.832817032933235, 56.62235386669636, 60.50864852964878, 56.581996232271194, 54.59555022418499, 54.2630110681057, 50.481351390480995, 46.15292385220528, 42.40466058254242, 44.131922498345375, 46.1044954508543, 48.23957048356533, 46.98263593018055, 50.846713185310364, 43.74440789222717, 51.05587676167488, 20.11388249695301, 29.179610833525658, 58.364229798316956, 43.736907094717026, 49.84858274459839, 49.17671039700508, 47.927531227469444, 41.48522391915321, 52.14429035782814, 50.63118115067482, 55.996174067258835, 52.7221405506134, 57.52391628921032, 57.37588383257389, 54.78840507566929, 48.801617324352264, 45.0797588378191, 42.09376126527786, 40.114379078149796, 44.0857207775116, 42.05766320228577, 44.4379922747612, 42.31302849948406, 46.59640185534954, 52.790639474987984, 57.638244554400444, 53.410910591483116, 54.903960675001144, 53.451564610004425, 52.88208916783333, 53.77311855554581, 55.075620263814926, 53.53090055286884, 54.72747914493084, 53.53011019527912, 50.204714834690094, 47.49134883284569, 50.08253999054432, 51.660131737589836, 53.61417308449745, 48.189891949296, 47.4343328922987, 58.5608996450901, 61.96633391082287, 60.406453013420105, 59.36709478497505, 58.42187650501728, 58.72970178723335, 61.36826120316982, 58.97418066859245, 50.560501143336296, 55.144521966576576, 42.93843314051628, 18.29579785466194, 0.2152035155449994, 0.9087993123102933, 1.6719706077128649, 3.222524905577302, 16.538025476038456, 66.07954859733582, 58.33673067390919, 57.414732947945595, 58.207389414310455, 56.60451002418995, 58.26629765331745, 15.076236315071583, 4.51583300717175, 36.96893826127052, 54.04365263879299, 15.204113703221083, 29.701263941824436, 49.80179205536842, 22.806197628378868, 40.30780769884586, 63.733942061662674, 23.026798591017723, 0.4453700641170144, 0.17412072862498462, 0.09928041210514493, 0.10149500303668901, 0.05756010548793711, 0.061602758287335746, 0.04921946027025115, 0.08749870641622692, 0.03514073701808229, 0.059068331393064, 0.16477403172757477, 0.15417319431435317, 0.13038771750871092, 0.13310148438904434, 0.2615761826746166, 0.1360334426863119, 0.17170331615488976, 0.1991239213384688, 0.20178204198600724, 0.22694069979479536, 0.2981526043731719, 0.4724965710192919, 0.5436612898483872, 0.5847838113550097, 19.706823639571667, 78.09816688299179, 70.19441619515419, 51.30280651152134, 58.465665355324745, 48.925015702843666, 34.10434037446976, 48.905214965343475, 8.853875454515219, 10.55054236203432, 69.53271210193634, 81.20834559202194, 81.31739214062691, 72.1310430765152, 57.049302756786346, 48.006726577878, 6.6132178623229265, 8.902783580124378, 5.043201958760619, 0.5660477885976434, 0.20464177447138354, 1.6170787531882524, 42.233745753765106, 75.70352777838707, 63.58333334326744, 65.66638916730881, 55.23098632693291, 60.63402660191059, 67.68452927470207, 66.38827443122864, 70.03537192940712, 67.75523588061333, 69.77189406752586, 65.25727272033691, 66.83670356869698, 65.7571890950203, 61.37906402349472, 62.218955755233765, 68.26687082648277, 58.97754728794098, 67.71886423230171, 61.907779052853584, 61.24530740082264, 68.30014184117317, 59.95152622461319, 64.77572456002235, 59.37284767627716, 58.17864775657654, 57.64809362590313, 53.39162662625313, 53.09624947607517, 48.422739654779434, 51.64197251200676, 47.492443174123764, 52.60652035474777, 50.24080529808998, 50.05690276622772, 48.28478425741196, 54.69813331961632, 52.726301327347755, 59.62944030761719, 62.548208087682724, 64.3427985906601, 61.833971813321114, 56.75361782312393, 59.08984266221523, 53.53694602847099, 51.940256506204605, 49.411685988307, 51.02254495024681, 50.35826079547405, 52.10020512342453, 45.649412870407104, 62.15984232723713, 49.46780137717724, 63.71344216167927, 19.998689778149128, 26.77915994077921, 68.98984283208847, 49.830735102295876, 58.87945555150509, 55.530163273215294, 54.32496294379234, 44.82883170247078, 56.97389580309391, 55.00077947974205, 58.975605592131615, 55.19838787615299, 61.85813091695309, 59.47104200720787, 55.327094569802284, 47.289598658680916, 48.26506331562996, 42.03029707074165, 39.47246052324772, 43.96012991666794, 41.26072056591511, 43.82680647075176, 45.48243083059788, 50.49617059528828, 55.440484285354614, 61.690210327506065, 57.02563002705574, 54.20644350349903, 54.91447851061821, 54.764717146754265, 56.284198611974716, 56.73567518591881, 50.984372198581696, 52.87535212934017, 55.44595219194889, 50.92553995549679, 48.096694350242615, 46.43171489238739, 49.4677709788084, 55.139521434903145, 49.4151172041893, 46.52678959071636, 60.60947231948376, 66.10701352357864, 63.8180011510849, 62.54992179572582, 61.447566747665405, 61.769941449165344, 64.83686327934265, 65.48333019018173, 55.68047560751438, 62.687539011240005, 56.821371987462044, 29.888787679374218, 2.246238780207932, 0.4759968660073355, 2.7136982465162873, 6.1346040945500135, 11.913883555680513, 72.65653967857361, 64.60990145802498, 66.70035928487778, 65.96040219068527, 60.696046873927116, 68.83711382746696, 22.320995964109898, 4.240253744646907, 39.37399260699749, 73.11702936887741, 16.924711726605892, 57.404982671141624, 55.59218354523182, 33.2845039665699, 54.0950258821249, 73.84152889251709, 45.1966367661953, 1.0455396655015647, 0.26608950924128294, 0.28458311688154936, 0.2763523132307455, 0.17832658340921625, 0.13101189339067787, 0.1379475899739191, 0.1818881946383044, 0.13014527270570397, 0.19080818630754948], [0.0072929163798107766, 0.06889230717206374, 0.050575030109030195, 0.07082715295837261, 0.004692421180152451, 0.030060129465709906, 0.020327326528786216, 0.13044109276961535, 0.029630787757923827, 0.11517739345435984, 0.05840896657900885, 0.018180616134486627, 0.016795033843663987, 0.08330362019478343, 1.4295649901032448, 36.14304877817631, 57.93785087764263, 54.993400275707245, 38.57763893902302, 38.78803364932537, 22.953738011419773, 37.174872010946274, 14.32040462270379, 2.6493432372808456, 19.76187888532877, 58.443660736083984, 60.17105184495449, 64.09560665488243, 43.857843205332756, 79.93916049599648, 49.37765881419182, 32.70918823778629, 1.9854149571619928, 0.23038666957290843, 0.5808850424364209, 0.29237997194286436, 0.7388717774301767, 32.14668162167072, 67.1389165520668, 57.24517084658146, 64.5039251446724, 59.74361278116703, 59.64935123920441, 61.097673922777176, 63.419106155633926, 66.53411820530891, 62.429605051875114, 61.72172963619232, 63.481772392988205, 60.21485969424248, 52.54963360726833, 53.6979053914547, 54.98746499419212, 57.0899111777544, 57.66587287187576, 61.709315702319145, 62.6129300147295, 57.123622968792915, 60.126560032367706, 56.617170944809914, 52.85988695919514, 54.45118837058544, 46.0327211022377, 47.99571096897125, 47.34675519168377, 46.26065567135811, 43.573926240205765, 41.95214666426182, 42.703012973070145, 44.324298575520515, 45.25093585252762, 44.67025861144066, 45.52398540079594, 43.668837547302246, 51.60645201802254, 54.92584370076656, 55.6093168258667, 50.784518122673035, 49.374064207077026, 48.31400848925114, 40.88432036340237, 39.38172519207001, 36.9188379496336, 36.551165878772736, 38.847591653466225, 38.929553255438805, 39.94500316679478, 48.24962094426155, 43.621955662965775, 29.18828386813402, 10.117431152611971, 26.505641117691994, 47.2730353474617, 41.06269799172878, 45.93084096908569, 42.98084646463394, 40.545401349663734, 35.05130276083946, 45.25684833526611, 48.64929489791393, 47.750916704535484, 51.516617238521576, 51.68400585651398, 53.13289470970631, 46.76659092307091, 42.72736966609955, 42.94446721673012, 44.001399502158165, 43.983065485954285, 42.08507873117924, 41.913631930947304, 41.21554858982563, 42.29064390063286, 44.2064592987299, 49.40830036997795, 52.97621391713619, 49.99988682568073, 53.31805497407913, 50.6283313035965, 55.45066013932228, 52.716790437698364, 49.99000355601311, 51.30665950477123, 52.23589964210987, 50.82968629896641, 54.340705499053, 56.14687018096447, 53.919855281710625, 54.17735606431961, 54.4856221228838, 48.370002284646034, 45.24111717939377, 57.61731147766113, 59.23897325992584, 59.83142986893654, 57.47942067682743, 58.407680466771126, 58.26482333242893, 57.27289795875549, 51.66450150310993, 38.26015457510948, 14.785326775163412, 5.223255297169089, 1.0584746464155614, 0.02963748007459799, 0.2974812872707844, 3.6932578962296247, 32.31587514281273, 59.32704873383045, 55.97963735461235, 51.36634670197964, 57.899522334337234, 48.021773770451546, 58.0689362436533, 39.26331974565983, 6.963348174467683, 12.18063684180379, 70.94220086932182, 44.49745528399944, 14.803614243865013, 41.82747535407543, 29.973815716803074, 24.60633583366871, 38.458089753985405, 54.27360109984875, 8.961595874279737, 0.2563961106352508, 0.12989539158297703, 0.05064627999672666, 0.09324041355284862, 0.030326983505801763, 0.003813262605945056, 0.032603601284790784, 0.10914845290244557, 0.032569840986980125, 0.09094951499719173, 0.0745498547621537, 0.046175318930181675, 0.056833160706446506, 0.01348564892396098, 0.02895856523537077, 0.028396868910931516, 0.09266960551030934, 0.03863004079903476, 0.07435487030306831, 0.04144630198425148, 0.11261580395512283, 0.05556693431572057, 0.10709711219533347, 0.13021363934967667, 1.888638543896377, 44.25567805767059, 66.51554480195045, 51.03084750473499, 40.56942746043205, 45.75086362659931, 21.4385674148798, 40.631436333060265, 22.71494932472706, 4.0838617365807295, 20.299253650009632, 60.00966690480709, 67.45357006788254, 66.50571092963219, 52.34207734465599, 83.95865321159363, 56.46971605718136, 38.33635188639164, 3.7357745273038745, 0.13422226096736267, 0.759160373127088, 0.438212109147571, 1.1294517503120005, 37.447161599993706, 72.47538059949875, 58.192460015416145, 62.349942326545715, 57.52965398132801, 60.29623992741108, 63.221026584506035, 66.54712870717049, 68.5069191455841, 65.87820500135422, 63.38949054479599, 65.56295871734619, 62.401239573955536, 54.99060362577438, 55.3018981218338, 57.84762091934681, 58.35784614086151, 59.48380932211876, 61.37347832322121, 63.79122778773308, 57.78337396681309, 61.102894842624664, 57.0600675791502, 56.31611689925194, 55.25280475616455, 47.80808083713055, 48.988274708390236, 48.31967778503895, 47.02834367752075, 46.95877321064472, 44.49812404811382, 47.244039103388786, 46.91419780254364, 46.64628177881241, 44.783173352479935, 47.734847366809845, 46.97700083255768, 53.14139865338802, 58.99312645196915, 58.34594517946243, 54.153443947434425, 54.9112942814827, 53.94128993153572, 46.99037231504917, 43.35841700434685, 45.00134624540806, 41.72684155404568, 46.76935337483883, 48.50368671119213, 46.93599343299866, 56.34355142712593, 46.168427020311356, 43.66128735244274, 32.99305960536003, 52.66930438578129, 55.22485725581646, 48.440902680158615, 50.89592434465885, 50.03405839204788, 47.475731670856476, 41.53047949075699, 52.25879721343517, 54.68341290950775, 54.10792239010334, 55.27724504470825, 56.542079374194145, 54.86717864871025, 50.16726404428482, 45.23957446217537, 42.689044922590256, 44.969652146101, 45.984144508838654, 44.934302642941475, 43.75413537025452, 42.825852781534195, 43.8382438570261, 46.13257214426994, 52.3155053704977, 54.60287243127823, 51.7146398127079, 55.52407220005989, 52.751828357577324, 56.222843304276466, 55.73016554117203, 53.47626328468323, 56.45341873168945, 53.3420392870903, 50.26888579130173, 54.31708976626396, 57.26950094103813, 58.449098244309425, 56.5569593757391, 53.449121341109276, 53.8417998701334, 47.61421523988247, 59.4064074754715, 60.0393471121788, 61.94062829017639, 58.95573265850544, 59.720677211880684, 60.27514725923538, 57.294799983501434, 55.10576404631138, 42.36606605350971, 19.90072723478079, 6.715794308111072, 0.8337364776525646, 0.15371809451607987, 1.4915737439878285, 5.993709079921246, 44.43119063973427, 65.70161327719688, 58.09503324329853, 57.172218561172485, 60.28569549322128, 51.517757177352905, 59.98848684132099, 45.7916734367609, 7.209903644397855, 18.28020729124546, 65.60437649488449, 50.704623609781265, 11.39915557578206, 39.75118696689606, 43.06821517646313, 19.638159424066544, 40.170657858252525, 59.02765139937401, 7.27469396777451, 0.2715480054030195, 0.04154046197072603, 0.14436833997024223, 0.1955337671097368, 0.12784127524355426, 0.037825022081960924, 0.09800561019801535, 0.10279156471369788, 0.08935449863201939, 0.040470607855240814, 0.09969692764570937, 0.15681443852372468, 0.17786628857720643, 0.17058028344763443, 0.23422026308253407, 0.18545366503531113, 0.191904041566886, 0.1632930908817798, 0.24246770568424836, 0.24275980016682297, 0.2816469134995714, 0.14518056123051792, 0.28275021992158145, 0.3745719662401825, 3.708943692035973, 68.66661697626114, 75.16576543450356, 68.74425441026688, 50.864610224962234, 59.75999750196934, 28.074842914938927, 47.20452502369881, 23.895416781306267, 5.800738809630275, 25.493810512125492, 68.71228292584419, 73.41133877635002, 75.99017679691315, 60.83953857421875, 89.30936649441719, 63.42882223427296, 41.82797692716122, 4.454595493152738, 0.8238551078829914, 1.0311012715101242, 0.46486978651955724, 1.3752607977949083, 38.33796679973602, 77.73531675338745, 63.656680807471275, 64.92141634225845, 60.97774475812912, 62.384284883737564, 64.55242574214935, 69.54218119382858, 72.04935505986214, 67.96165600419044, 67.70474418997765, 66.55133128166199, 64.66049194335938, 58.93367484211922, 58.92143189907074, 62.15370185673237, 59.84582729637623, 62.006744742393494, 66.73853203654289, 68.49751085042953, 63.32042545080185, 62.68425598740578, 60.11251978576183, 58.2734564691782, 60.12910969555378, 52.16187961399555, 53.13408024609089, 50.3273456543684, 49.43112574517727, 49.2428382486105, 45.99722720682621, 47.72804193198681, 50.13762943446636, 49.69024524092674, 49.08923149108887, 50.91882571578026, 48.977297097444534, 57.71260656416416, 61.612690687179565, 60.45462682843208, 58.19600522518158, 59.40783239901066, 56.982388347387314, 50.331183448433876, 51.494080647826195, 49.449216574430466, 48.4393447637558, 52.27140113711357, 55.40101960301399, 55.84386684000492, 61.212271973490715, 47.998104840517044, 46.55329316854477, 33.885833099484444, 54.87331531941891, 60.55203080177307, 56.36115588247776, 56.96469269692898, 55.21549455821514, 52.75281250476837, 46.02683141827583, 56.34389340877533, 59.71085473895073, 56.85440741479397, 56.64995178580284, 57.77371108531952, 54.597123339772224, 49.85462822020054, 45.77085815370083, 45.992241874337196, 46.366848573088646, 47.130964770913124, 44.995821341872215, 44.53108347952366, 46.64628557860851, 46.81143991649151, 50.23894339799881, 55.924160331487656, 57.18402072787285, 53.863610699772835, 57.83306770026684, 53.949687480926514, 57.63441435992718, 55.62696307897568, 55.436513498425484, 58.54566626250744, 54.72211003303528, 53.8692419975996, 56.425851210951805, 57.47560188174248, 57.55702771246433, 57.38810397684574, 53.43060113489628, 53.583774715662, 48.15715670585632, 61.75598479807377, 64.25326019525528, 64.62738811969757, 65.45512810349464, 63.26016068458557, 66.3556569814682, 61.79452992975712, 60.32579854130745, 50.671531185507774, 26.568427048623562, 12.984306067228317, 2.0074714673683047, 0.18625760392751545, 1.233007712289691, 9.791877921670675, 39.46305222809315, 73.02394956350327, 64.74605575203896, 62.739383429288864, 67.4797810614109, 59.640319123864174, 66.03318348526955, 51.7401098459959, 11.109540816396475, 17.239236049354076, 78.40925619006157, 57.77248375117779, 16.649811677634716, 63.45025308430195, 42.056914642453194, 33.317881375551224, 48.698243871331215, 75.57875767350197, 18.24822060763836, 0.44132328126579523, 0.34488047822378576, 0.27837564528454095, 0.3702972549945116, 0.19554852100554854, 0.23646263260161504, 0.20156218815827742, 0.22415608749724925, 0.10606898533296771, 0.13785896269837394], [0.018043595264316536, 0.025379470862390008, 0.022936237219255418, 0.049041422753361985, 0.04567051008052658, 0.11798659310443327, 0.01712004257569788, 0.07256070603034459, 0.038804215437266976, 0.03912681218935177, 0.14002172945765778, 0.018654501545825042, 0.04677951990743168, 0.1698573277099058, 0.3066984348697588, 21.69129565358162, 46.650822535157204, 48.45985226333141, 34.11794364452362, 41.807849407196045, 19.84024778008461, 29.125638529658318, 66.05779856443405, 11.435789410024881, 12.700052820146084, 59.20390494167805, 70.42488902807236, 65.23232325911522, 62.51103848218918, 45.137063562870026, 52.16425448656082, 66.51735350489616, 37.158331498503685, 1.4438002137467265, 0.9514409804251045, 0.6878062582109123, 1.605952475219965, 2.1547914622351527, 23.07125050574541, 51.86952330172062, 61.760449558496475, 66.32421746850014, 63.42750370502472, 64.2029432952404, 61.80260069668293, 66.5858182311058, 64.45020362734795, 59.802194237709045, 58.83424937725067, 54.90523740649223, 51.47877886891365, 49.317021667957306, 48.427618592977524, 57.19184450805187, 59.472041353583336, 58.77447098493576, 62.61161908507347, 59.535007774829865, 58.31043988466263, 58.192235827445984, 55.5426874011755, 52.14728459715843, 48.901122584939, 46.96454890072346, 45.12599855661392, 44.95546370744705, 42.753804847598076, 45.02332046627998, 43.16047802567482, 44.91999641060829, 44.949273839592934, 44.96540777385235, 46.34109355509281, 43.679761961102486, 50.64212456345558, 55.276055708527565, 53.385562151670456, 51.68994873762131, 49.053403213620186, 47.75543466210365, 39.207793325185776, 37.36892379820347, 35.540484711527824, 40.727685168385506, 41.21924579143524, 44.54525671899319, 45.31641013920307, 45.87797440588474, 36.801089867949486, 35.529602095484734, 39.55125689506531, 42.58195906877518, 45.10425232350826, 43.765496760606766, 44.295142740011215, 41.24738708138466, 38.064487874507904, 35.75577735900879, 45.6211955845356, 51.890528574585915, 52.3471424728632, 52.491333335638046, 53.531861901283264, 53.06412599980831, 44.338627606630325, 42.395970448851585, 42.859648168087006, 43.680670112371445, 46.19028724730015, 45.49767181277275, 44.3157072365284, 42.083688005805016, 42.32817068696022, 41.45256087183952, 45.937118232250214, 47.651457041502, 52.19592958688736, 50.80694071948528, 50.16585431993008, 50.04200376570225, 51.63193345069885, 51.384498327970505, 55.68494416773319, 56.46401636302471, 57.63731360435486, 57.204581424593925, 57.34731696546078, 57.28935107588768, 56.35884180665016, 55.23058734834194, 57.46332474052906, 59.28945355117321, 51.940530091524124, 58.15068505704403, 59.59384761750698, 60.78855291008949, 62.72918097674847, 56.70950599014759, 51.60026974976063, 23.27174674719572, 6.255622375756502, 11.521954536437988, 1.7164107668213546, 0.8308394299820065, 0.1841696901828982, 1.7268890608102083, 21.26838594675064, 61.90809063613415, 52.89932884275913, 59.707085341215134, 55.524144396185875, 53.14270958304405, 50.62643140554428, 61.16061374545097, 31.340332590043545, 4.723471915349364, 20.299460738897324, 69.55212146043777, 36.44892856478691, 24.707769490778446, 40.04953935742378, 16.333138570189476, 29.362768605351448, 44.6913892775774, 40.0526437908411, 1.966252822894603, 0.008894017428247025, 0.05533816358365584, 0.09112371932133101, 0.028357401497487444, 0.035249198190285824, 0.06026284405379556, 0.015133789147512289, 0.01842653418862028, 0.0863131477672141, 0.059011015327996574, 0.032129517348948866, 0.05739558248023968, 0.015816667983017396, 0.033967746639973484, 0.08667477406561375, 0.06299673055764288, 0.028430918646336067, 0.04385925785754807, 0.00697469180522603, 0.06715181501931511, 0.03099912624747958, 0.033345095871482044, 0.02442457727738656, 0.03941055379982572, 0.17221214744495228, 21.543977558612823, 58.96523594856262, 50.843935534358025, 29.554994590580463, 50.64019426703453, 23.178321160376072, 28.342591747641563, 66.52983963489532, 11.961362957954407, 15.062679592519999, 64.21970039606094, 78.19675639271736, 70.57392463088036, 64.5667053759098, 49.50527876615524, 55.34042425453663, 71.09947443008423, 45.58790937066078, 2.435742449015379, 0.7417874084785581, 1.4481404121033847, 2.691201791167259, 3.525259173475206, 30.417899787425995, 59.32169862091541, 62.15978153049946, 66.90247803926468, 64.8267026245594, 66.40208289027214, 65.19364133477211, 68.79659280180931, 68.45404878258705, 61.52931936085224, 63.227706626057625, 57.4462104588747, 53.556704968214035, 51.171808540821075, 51.34609758853912, 59.37103137373924, 62.52867333590984, 60.20222157239914, 60.90300276875496, 63.28242748975754, 58.82873587310314, 63.5020063072443, 58.40854302048683, 54.21815447509289, 50.1801073551178, 49.938257932662964, 48.264493346214294, 48.13724957406521, 44.312815591692924, 48.381485268473625, 46.776390597224236, 45.63990578055382, 44.1376905888319, 46.27344958484173, 45.96587508916855, 43.6359579116106, 55.503728091716766, 60.37393815815449, 59.58410494029522, 55.99141292273998, 54.169137105345726, 54.060386940836906, 46.49094611406326, 43.30415591597557, 43.883035853505135, 44.74468521773815, 46.95363208651543, 52.86068491637707, 51.66156426072121, 53.364819064736366, 44.113493487238884, 33.31197269260883, 34.280635714530945, 47.937505692243576, 53.90083730220795, 52.411720007658005, 51.51580788195133, 48.89324560761452, 48.12363490462303, 42.434652373194695, 50.62865428626537, 53.65939825773239, 55.4318093508482, 58.78070265054703, 56.69136956334114, 53.93867947161198, 48.79478149116039, 44.90252114832401, 43.44462677836418, 45.58528371155262, 47.518589571118355, 45.50666593015194, 46.42600379884243, 44.27058465778828, 44.05042827129364, 43.97043876349926, 47.85733759403229, 49.91193674504757, 53.67560438811779, 55.43788902461529, 53.6149862408638, 52.96410396695137, 54.738502353429794, 54.81750011444092, 57.04618692398071, 56.53190732002258, 60.93199521303177, 59.541224241256714, 58.27049262821674, 59.48976740241051, 58.27286750078201, 58.768300116062164, 60.3551709651947, 61.14335507154465, 51.170376017689705, 58.51443953812122, 61.17902375757694, 60.51439382135868, 64.11514520645142, 57.00608007609844, 57.058692052960396, 30.685608722269535, 10.90635621920228, 26.338486187160015, 3.091407953761518, 1.5758265042677522, 1.3684741244651377, 2.0593821443617344, 28.53197168558836, 66.2017272412777, 57.078834772109985, 64.92577090859413, 59.645148664712906, 55.72719030082226, 54.08386968076229, 66.03904277086258, 31.386726200580597, 5.945793651044369, 29.72753383219242, 60.76494857668877, 47.822288274765015, 17.85026416182518, 43.76288630068302, 21.73375267535448, 24.062229730188847, 55.8934161812067, 42.934139370918274, 1.123925659339875, 0.08067139307968318, 0.03841949350317009, 0.08576758758863434, 0.045819021252100356, 0.032253489407594316, 0.07835627824533731, 0.03828717970463913, 0.028747073556587566, 0.1469110418111086, 0.044584907591342926, 0.12730360409477726, 0.18007071950705722, 0.06612929137190804, 0.15182834904408082, 0.18037363450275734, 0.23009861237369478, 0.11567680689040571, 0.20307131577283144, 0.22509046626510099, 0.2132967600482516, 0.32393059926107526, 0.14489333523670211, 0.20061798335518688, 0.5735267966520041, 0.5639117688406259, 41.7212900519371, 71.63478210568428, 61.25058151781559, 42.427406162023544, 64.6123257279396, 28.253610022366047, 36.743378564715385, 79.51083227992058, 18.41787200421095, 18.428545631468296, 70.73041543364525, 79.9307781457901, 78.16749796271324, 70.90195342898369, 57.63080835342407, 62.78482139110565, 84.10261988639832, 48.95264782011509, 2.343209101818502, 1.591339053120464, 2.213092208839953, 2.4467281345278025, 4.02577567845583, 35.10024033486843, 64.09536346793175, 66.37248247861862, 70.4375271499157, 68.32970425486565, 70.03246888518333, 68.27295050024986, 71.70812577009201, 69.49934229254723, 64.72343936562538, 65.3942933678627, 59.40440118312836, 55.86020976305008, 53.30345615744591, 53.443657234311104, 63.43985304236412, 64.88807693123817, 64.35444876551628, 69.70877945423126, 66.73043087124825, 63.60078580677509, 65.054462403059, 62.7270682901144, 57.83493719995022, 53.30482788383961, 54.16391618549824, 48.375268802046776, 52.3245070874691, 47.270801067352295, 51.60493589937687, 48.15686032176018, 49.65288184583187, 48.77829797565937, 49.156708270311356, 50.59842690825462, 45.36495253443718, 57.075456753373146, 62.95118406414986, 61.58989951014519, 59.735523015260696, 58.110186830163, 58.38722616434097, 51.064490899443626, 48.21710228919983, 46.68226204812527, 51.7424239218235, 54.90740709006786, 59.29517984390259, 56.85961313545704, 58.3332272619009, 46.906913593411446, 42.63949558138847, 58.25275518000126, 58.22836808860302, 57.822637259960175, 57.67762564122677, 55.90718284249306, 52.30502553284168, 49.164117872714996, 45.802172273397446, 55.02534136176109, 61.051160618662834, 60.76439380645752, 61.753245145082474, 57.639711275696754, 57.10982970893383, 49.79766167700291, 46.583756133913994, 46.5626634657383, 47.285859659314156, 48.568363040685654, 47.89011463522911, 49.545051231980324, 46.51569418609142, 47.1556406468153, 47.92331725358963, 50.26621073484421, 51.78140603005886, 58.80937971174717, 56.84293583035469, 54.872996136546135, 55.6563924998045, 58.070615753531456, 57.903751507401466, 58.10622364282608, 57.25085914134979, 61.04022100567818, 61.874302849173546, 60.63231289386749, 60.74280336499214, 61.61047540605068, 60.61428666114807, 61.965285167098045, 60.62611922621727, 51.94279856979847, 61.299446895718575, 64.4554853439331, 62.672351226210594, 69.31274190545082, 60.22323064506054, 65.31218737363815, 43.17271336913109, 19.520346745848656, 43.58911022543907, 6.832616664469242, 0.9041687264107168, 0.7842943619471043, 6.149492170661688, 26.157851479947567, 72.57056549191475, 61.96854159235954, 69.63982075452805, 66.09765842556953, 62.00674094259739, 60.961550027132034, 71.84826985001564, 41.012688875198364, 7.9554117657244205, 23.998134769499302, 76.39827489852905, 52.907228618860245, 30.58673232793808, 62.39394396543503, 25.199694894254208, 42.14983865618706, 60.87562143802643, 63.55403311550617, 3.84723964612931, 0.22089618898462504, 0.13905987638281658, 0.16406667593400925, 0.14064348593819886, 0.08928167910198681, 0.16813833557534963, 0.09423630152014084, 0.21660029684426263, 0.18898671842180192, 0.2072312167729251], [0.04693241346103605, 0.05668081634212285, 0.04213717096718028, 0.01367678905808134, 0.05014222442696337, 0.05055403846199624, 0.08651270385598764, 0.02242830021714326, 0.04935485769237857, 0.06381737519404851, 0.07173292935476638, 0.03309346328023821, 0.1303380826720968, 0.11172964252182283, 0.12593791878316551, 3.0363776441663504, 49.0838547796011, 57.66377158463001, 43.23029167950153, 43.0089345574379, 34.50327716767788, 17.25187037140131, 59.67797130346298, 25.06554689258337, 3.635407187975943, 25.663021132349968, 61.685794964432716, 58.01008500158787, 60.43307438492775, 58.691836819052696, 54.90562878549099, 46.70335091650486, 55.321444272994995, 11.403512042015791, 0.3881782345706597, 0.9726299496833235, 4.477177681401372, 10.044044740498066, 29.916689582169056, 45.094125866889954, 39.621621519327164, 47.53067672252655, 56.6945043951273, 64.91960003972054, 67.63828575611115, 62.45670139789581, 63.29991415143013, 60.94196207821369, 58.75863343477249, 57.83173397183418, 54.04620610177517, 45.263478979468346, 45.5787518620491, 50.324374213814735, 52.59757563471794, 58.180479258298874, 57.97507368028164, 57.249077036976814, 59.35092285275459, 58.58428739011288, 54.445728063583374, 52.0771137624979, 48.063586726784706, 45.607721507549286, 44.9455576390028, 45.690488666296005, 45.20253024995327, 47.482917085289955, 47.19545491039753, 46.183261424303055, 44.15356233716011, 45.44683814048767, 44.762103483080864, 43.893017917871475, 45.50231896340847, 56.79767265915871, 53.892124369740486, 51.81391328573227, 49.639635756611824, 43.94647724926472, 37.72977523505688, 35.773507207632065, 37.47333459556103, 43.06182011961937, 43.57500918209553, 46.4871197193861, 46.11822031438351, 47.10992909967899, 46.58296577632427, 43.34004499018192, 49.60517540574074, 46.39823108911514, 46.38676330447197, 45.012259259819984, 43.324671015143394, 40.94490811228752, 39.600399658083916, 35.79045809805393, 44.19542469084263, 50.4439651966095, 49.37250629067421, 50.0321850925684, 55.316660329699516, 53.34651164710522, 44.34682376682758, 41.26478634774685, 42.94627971947193, 45.64622484147549, 48.81376527249813, 47.55204677581787, 46.10031947493553, 45.84769003093243, 43.22279468178749, 41.73618905246258, 41.00861169397831, 46.43222786486149, 47.06552468240261, 50.52754931151867, 51.8346031755209, 52.83898428082466, 53.52652698755264, 54.98666323721409, 52.98754870891571, 54.70002181828022, 50.63297085464001, 53.915842697024345, 53.49542945623398, 56.18199169635773, 55.06077826023102, 54.91033673286438, 55.780911818146706, 59.049823209643364, 49.035977348685265, 45.893188789486885, 47.62729413807392, 50.76083779335022, 42.06894859671593, 43.47180671989918, 25.544560588896275, 0.9493663511238992, 1.8686910392716527, 7.988458592444658, 0.42865105031523854, 0.3981523134279996, 0.26205264148302376, 2.8378413850441575, 43.59647423028946, 54.888689294457436, 56.71668380498886, 54.63504530489445, 54.85038734972477, 58.51640023291111, 61.18059307336807, 51.59865103662014, 7.424461031332612, 4.3563189916312695, 46.74671798944473, 69.69424143433571, 18.637222833931446, 23.99536281824112, 39.476454108953476, 21.488599330186844, 32.80955225229263, 50.298049226403236, 24.56343423575163, 0.28822842752560973, 0.11093872832134366, 0.03211082635971252, 0.023924148954392876, 0.03376198990736157, 0.04511874183663167, 0.053137450813665055, 0.09367029517306946, 0.011766674415412126, 0.04796005792741198, 0.048068541364045814, 0.06453961104853079, 0.008814671637082938, 0.025820501396083273, 0.047881842983770184, 0.1136805335409008, 0.018148956114600878, 0.03061247287405422, 0.047098335417103954, 0.11494208811200224, 0.010043936290458078, 0.007222234235086944, 0.07524095752160065, 0.13155686727259308, 0.20688672666437924, 0.25595773884560913, 4.27830015309155, 55.71226850152016, 68.61755400896072, 37.738974541425705, 48.56444165110588, 38.265611082315445, 17.836041525006294, 63.799534142017365, 28.84325098246336, 6.547995312139392, 24.401540122926235, 67.57399320602417, 63.735100999474525, 68.43037605285645, 62.265320867300034, 62.58529409766197, 55.22384271025658, 63.84713038802147, 14.734064675867558, 0.3711332695093006, 1.403668667189777, 7.592166932299733, 13.995729144662619, 35.21402522921562, 52.49573729932308, 44.8520028591156, 50.92550575733185, 58.96045960485935, 69.92722973227501, 70.6095439195633, 67.6262404024601, 65.77270746231079, 64.3304568529129, 61.22307479381561, 62.83919267356396, 56.682189255952835, 48.70734058320522, 47.717755883932114, 51.93791203200817, 54.128053709864616, 60.19551493227482, 58.586567267775536, 59.38564918935299, 60.045548379421234, 61.70699402689934, 57.59517766535282, 54.4536392390728, 49.67160724103451, 47.60855354368687, 47.66562648117542, 47.27515563368797, 46.87563367187977, 47.89960652589798, 48.907380849123, 49.917739033699036, 47.18320816755295, 47.058445662260056, 45.97162798047066, 45.737112164497375, 50.32713286578655, 59.114746525883675, 57.60969668626785, 56.5457309782505, 55.414269492030144, 49.848966524004936, 43.65143068134785, 42.15334206819534, 43.059749230742455, 47.72491089999676, 47.21992939710617, 53.13281491398811, 51.57394476234913, 51.982001066207886, 48.43313209712505, 46.14525206387043, 49.937376379966736, 53.37829314172268, 52.88065284490585, 51.646771654486656, 50.783617570996284, 48.07947747409344, 45.278529971838, 41.0959006100893, 48.08185234665871, 55.524110198020935, 53.64899441599846, 54.48372222483158, 56.99676677584648, 55.84112338721752, 47.971608862280846, 44.33321289718151, 44.49772506952286, 47.27159522473812, 50.750407353043556, 47.862873896956444, 47.109047546982765, 45.719351917505264, 46.34405739605427, 43.15491512417793, 42.492029294371605, 47.55691431462765, 49.22235354781151, 51.64254628121853, 54.695370867848396, 56.368174105882645, 56.57523259520531, 57.52539820969105, 53.39534282684326, 57.13656887412071, 53.509754687547684, 55.86182847619057, 56.539282724261284, 58.98256681859493, 55.45576326549053, 58.27765144407749, 58.424923941493034, 60.383000671863556, 53.003416657447815, 49.78552132844925, 53.54620233178139, 54.85982224345207, 46.00903317332268, 50.59106670320034, 32.90965028107166, 1.046374433208257, 6.8751967046409845, 19.20473948121071, 0.6867066922131926, 1.5148021350614727, 2.1027876902371645, 6.642386997118592, 49.412179961800575, 60.04250094294548, 63.231582418084145, 59.504601806402206, 60.99681593477726, 66.01077988743782, 66.14446431398392, 52.06057704985142, 7.468219483271241, 10.769944489002228, 45.21675668656826, 64.36674490571022, 28.99525422602892, 20.517128258943558, 52.939884066581726, 20.3922251611948, 29.03440162539482, 58.65806423127651, 23.858233876526356, 0.7520726253278553, 0.06250634163734503, 0.062457174353767186, 0.04289827309548855, 0.08358595543541014, 0.04243823801516555, 0.1215985367889516, 0.05359106260584667, 0.04294423430110328, 0.018479261925676838, 0.0620568042359082, 0.1741356309503317, 0.12588086246978492, 0.13890215515857562, 0.22386935132090002, 0.1394991239067167, 0.19369994988664985, 0.13611356494948268, 0.14831239474005997, 0.16697788378223777, 0.2811182668665424, 0.19492905033985153, 0.1939690377912484, 0.3693768731318414, 0.3110497654415667, 0.3624650737037882, 10.510731898248196, 76.6747784614563, 76.20659798383713, 52.39977344870567, 60.027233362197876, 50.07598914206028, 21.661032177507877, 75.7112717628479, 28.53557389229536, 6.40584921464324, 29.770969301462173, 73.5956820845604, 64.68197599053383, 74.07089218497276, 70.67380607128143, 70.5635891854763, 58.62844482064247, 70.67749947309494, 15.705677289515734, 0.9087655297480524, 3.4940371988341212, 10.779127646237612, 17.361612282693386, 45.466084107756615, 60.63304245471954, 49.38223376870155, 54.265135154128075, 59.119093492627144, 72.680204808712, 74.99276831746101, 67.50603005290031, 68.25319156050682, 65.8456027507782, 65.98437890410423, 63.72871734201908, 59.45949822664261, 51.69286698102951, 51.14484138786793, 54.30493421852589, 56.391345262527466, 64.26362603902817, 62.7091408520937, 61.862983256578445, 64.57602247595787, 64.53382194042206, 59.24517832696438, 58.324217945337296, 54.73187170922756, 51.148861572146416, 49.43532072007656, 50.88419057428837, 50.759659856557846, 50.100699216127396, 50.99225677549839, 53.058031126856804, 47.876868546009064, 50.733821243047714, 48.284457474946976, 47.72345557808876, 50.914638340473175, 62.91637033224106, 61.49125300347805, 60.624682903289795, 57.32868656516075, 52.439469918608665, 48.20922531187534, 46.726921051740646, 48.80254067480564, 55.250380486249924, 51.746569499373436, 59.49775457382202, 56.3670189678669, 57.99960896372795, 55.60848847031593, 51.17460899055004, 59.897557720541954, 58.43256153166294, 56.77507147192955, 55.10567285120487, 54.75757732987404, 51.93446561694145, 49.92283836007118, 45.70610962808132, 52.11045317351818, 59.998221918940544, 57.82266765832901, 57.6054485142231, 60.06039418280125, 57.47497871518135, 47.86859638988972, 46.640156507492065, 46.575723364949226, 50.42902819812298, 53.46799872815609, 51.39997109770775, 49.58423472940922, 50.17437346279621, 48.720719665288925, 46.30813032388687, 44.99099180102348, 51.70068696141243, 52.00245536863804, 56.00423723459244, 55.30449718236923, 58.13669800758362, 56.632700711488724, 58.276959881186485, 54.46706771850586, 59.20700557529926, 55.69620296359062, 59.573203325271606, 58.70762877166271, 60.92479079961777, 57.32456378638744, 61.73758998513222, 58.39800238609314, 64.49077785015106, 54.57170270383358, 53.02169747650623, 57.79033899307251, 62.243669629096985, 50.17662674188614, 60.02882547676563, 41.931863352656364, 4.767478303983808, 12.833436112850904, 33.28269526362419, 3.0722401197999716, 1.167445199098438, 1.9533286476507783, 6.726664574816823, 51.09390132129192, 65.7258103787899, 66.71645522117615, 64.01549935340881, 67.05632418394089, 68.91462206840515, 72.46905013918877, 61.02685712277889, 11.771371252834797, 6.0278948955237865, 52.574134692549706, 80.95687508583069, 27.420381233096123, 32.915148586034775, 60.552950352430344, 27.465739399194717, 48.006680980324745, 62.2637515515089, 43.63503076136112, 0.9668927919119596, 0.26482845190912485, 0.14647354575572535, 0.1497344981180504, 0.14967557159252465, 0.06783641656511463, 0.16900014714337885, 0.14899521513143554, 0.11072698616771959, 0.10370764211984351, 0.11189496333827265], [0.04471111351449508, 0.002422591037429811, 0.004858306492678821, 0.024567594700783957, 0.03346201381646097, 0.0047793354860914405, 0.03160248859785497, 0.039331169973593205, 0.06901542947161943, 0.0693918541946914, 0.02766574027191382, 0.08927180111641064, 0.029267294958117418, 0.06287347467150539, 0.1698163166292943, 0.10416191071271896, 27.8838062658906, 56.8527203053236, 46.84261344373226, 36.22003264725208, 44.40744951367378, 15.319065134972334, 37.8134049475193, 57.37905666232109, 7.588276891037822, 0.49322668521199375, 23.171838708221912, 57.37451210618019, 61.5050994604826, 59.24363560974598, 57.487818226218224, 53.778415471315384, 58.65014165639877, 32.04844169318676, 1.7679609381593764, 0.7225963601376861, 2.9288400895893574, 11.801161654293537, 56.84944488108158, 54.546255469322205, 47.24470026791096, 53.25172193348408, 61.627749279141426, 59.96796414256096, 62.09985874593258, 60.067929178476334, 64.49265494942665, 61.46936617791653, 58.96997809410095, 56.9580240547657, 55.601637437939644, 49.038036838173866, 46.075856387615204, 46.89959138631821, 49.210627377033234, 48.98289039731026, 56.90223164856434, 58.170326203107834, 58.337851613759995, 56.08761616051197, 52.305515706539154, 48.23349080979824, 46.45998917520046, 43.16676288843155, 43.39475825428963, 45.49990229308605, 49.53463599085808, 51.002379432320595, 49.537333846092224, 50.05025692284107, 47.540689185261726, 46.67194940149784, 44.13661144673824, 41.99973151087761, 47.521051838994026, 53.12189809978008, 53.64239037036896, 47.992823123931885, 47.22599007189274, 42.29652598500252, 38.72690252959728, 40.04746086895466, 43.48361648619175, 47.87243418395519, 45.63439227640629, 46.73749588429928, 47.735086753964424, 51.098164692521095, 48.64942029118538, 45.00449247658253, 50.97765035927296, 47.616612911224365, 45.9798089414835, 42.883966863155365, 43.921375796198845, 41.27299390733242, 39.771705865859985, 39.0638342499733, 42.0411416888237, 49.658057168126106, 53.079127594828606, 53.39516043663025, 53.977566584944725, 54.33181397616863, 46.313552632927895, 41.757616102695465, 43.218227326869965, 46.12702064216137, 46.90245643258095, 49.990748316049576, 49.77439172565937, 48.831202536821365, 46.4236631244421, 43.13337028026581, 40.76684206724167, 41.59183479845524, 43.674632236361504, 46.11333757638931, 48.06557022035122, 50.35917654633522, 50.66965028643608, 49.76504422724247, 52.50362567603588, 50.12880250811577, 52.56162956357002, 52.83530227839947, 51.321136727929115, 53.08462209999561, 54.05599057674408, 56.018076092004776, 56.26616097986698, 52.02013202011585, 52.5848463177681, 45.075218081474304, 31.874403432011604, 24.235698021948338, 21.57167237251997, 10.261283833533525, 0.783511841436848, 0.2081721561262384, 1.2947532115504146, 1.0127691552042961, 0.5944750132039189, 0.6351040361914784, 4.546970911324024, 16.725273728370667, 54.62298095226288, 55.31623475253582, 53.2129792124033, 55.24308107793331, 58.8080345839262, 55.02733625471592, 54.42788042128086, 24.749914929270744, 1.6167393838986754, 18.75124141573906, 72.04283460974693, 36.43207646906376, 11.330014485865831, 31.265146024525166, 29.86489076167345, 23.51525478065014, 36.34041018784046, 52.725503370165825, 10.458206366747618, 0.36156487825792283, 0.16656364663504064, 0.08585374351241626, 0.046985287772258744, 0.05086608187411912, 0.015937864409352187, 0.07205186731880531, 0.024324055229953956, 0.07578243588795885, 0.031196055133477785, 0.040679329467820935, 0.0031384627436636947, 0.06349513467284851, 0.01979675958864391, 0.03879587369738147, 0.02147432132915128, 0.04238185334543232, 0.035928519355366006, 0.05163991554582026, 0.042920381674775854, 0.0191032801012625, 0.018540238634159323, 0.129299343097955, 0.053387703010230325, 0.04902936656435486, 0.28000519378110766, 0.19223977433284745, 29.079921282827854, 67.58933678269386, 49.90610405802727, 37.545519322156906, 49.254944398999214, 15.386109687387943, 47.65980139374733, 61.90728507936001, 17.4696708843112, 2.059146794490516, 23.34508091211319, 61.823784559965134, 68.7299519777298, 67.22660064697266, 63.87642681598663, 59.22170698642731, 66.4869399368763, 36.2860769033432, 3.4421440958976746, 1.1377145256847143, 2.5876195868477225, 12.301874086260796, 66.93203285336494, 60.92512898147106, 51.52366206049919, 57.29549154639244, 65.8004155755043, 66.56168192625046, 67.01283931732178, 63.75044837594032, 67.16624468564987, 65.97452983260155, 62.612694427371025, 61.302224546670914, 58.55882115662098, 51.29663184285164, 48.118166998028755, 48.71004603803158, 52.5353729724884, 51.276777908205986, 57.141535207629204, 60.82199111580849, 59.628896936774254, 59.03313830494881, 55.52766300737858, 50.13251110911369, 47.363174110651016, 45.4629872739315, 45.75541578233242, 47.69778035581112, 51.37462645769119, 53.57516437768936, 53.77283737063408, 52.69492261111736, 50.49270898103714, 49.90464113652706, 47.07522556185722, 44.137428402900696, 49.9435168504715, 57.88221426308155, 55.39033457636833, 54.19242985546589, 53.604939579963684, 47.99193017184734, 42.30758339166641, 44.36084881424904, 48.627009093761444, 52.82099224627018, 49.91400383412838, 52.97283209860325, 51.23773880302906, 55.21372005343437, 52.13011711835861, 50.24714335799217, 56.921755000948906, 52.91115000844002, 51.764713525772095, 49.19786386191845, 49.93106871843338, 47.13235169649124, 43.85188892483711, 43.74611780047417, 48.158916011452675, 54.44580785930157, 56.63129858672619, 55.78590475022793, 58.029916137456894, 56.137074306607246, 48.15830424427986, 43.613440319895744, 44.83746103942394, 46.57670371234417, 49.151407554745674, 49.3472034484148, 50.370902717113495, 49.56504575908184, 48.48109692335129, 44.13095735013485, 41.66200943291187, 43.33938002586365, 46.33577764034271, 47.74213917553425, 51.27173937857151, 52.696811109781265, 53.35763365030289, 53.77151884138584, 53.280953764915466, 53.42014029622078, 54.907726272940636, 54.07940872013569, 53.79916995763779, 54.69830051064491, 57.39478021860123, 59.08270284533501, 59.82079043984413, 55.86484931409359, 55.443045347929, 51.14692747592926, 36.69222950935364, 31.05153288692236, 27.901821099221706, 16.69655106961727, 1.8755445652641356, 0.15582710009766743, 1.8461792659945786, 1.2503682682290673, 0.4884732293430716, 0.34431098378263414, 3.6458552023395896, 19.17254000902176, 60.43743655085564, 59.63312231004238, 57.58447363972664, 62.48045012354851, 65.1386658847332, 61.249506175518036, 59.62704263627529, 23.916824832558632, 5.038421815261245, 25.514181219041348, 58.883825317025185, 46.79705388844013, 16.00962582975626, 29.24157600849867, 45.823728516697884, 21.11435741186142, 39.97061759233475, 62.414436265826225, 11.033698786050081, 0.4733071743976325, 0.11015956974006258, 0.27447280939668417, 0.10587687298539095, 0.0446211429516552, 0.01842356003180612, 0.053901840656180866, 0.037963777722325176, 0.06628471935982816, 0.015110883687157184, 0.032872663214220665, 0.1469243410974741, 0.12755278759868816, 0.09573730261763558, 0.08587852382333949, 0.11285913191386499, 0.12891396065242589, 0.10971057781716809, 0.12816658825613558, 0.11772278929129243, 0.19148716237396002, 0.12493741465732455, 0.2643698937026784, 0.1284873444819823, 0.190037525317166, 0.41391891427338123, 0.593001761008054, 55.128631219267845, 74.94872868061066, 59.55516189336777, 51.14520236849785, 63.855983912944794, 18.3466125279665, 51.47114887833595, 65.65408542752266, 14.0335295163095, 1.5101337293162942, 30.934734754264355, 68.98765414953232, 72.99082294106483, 70.9767334163189, 68.26077595353127, 66.46767497062683, 71.4881631731987, 39.93618384003639, 3.696177564561367, 2.1475431136786938, 4.801104124635458, 16.397522315382957, 73.40112492442131, 70.26438564062119, 59.61173325777054, 62.453220784664154, 70.02041593194008, 66.05099692940712, 67.0750267803669, 67.36362129449844, 67.59537845849991, 64.26087498664856, 66.35871201753616, 61.96052402257919, 60.77400729060173, 54.5037167519331, 50.84114268422127, 53.22676107287407, 55.878042206168175, 55.76971761882305, 62.60047048330307, 63.522658199071884, 66.25024303793907, 62.04632341861725, 59.047775119543076, 52.61276341974735, 50.910067185759544, 49.989042207598686, 47.04897657036781, 51.304869800806046, 55.51333397626877, 53.60623151063919, 54.33879040181637, 53.990052714943886, 52.44771547615528, 52.77094513177872, 48.01442116498947, 47.602386474609375, 52.167111933231354, 60.123900175094604, 59.06370006501675, 57.82392539083958, 57.33291953802109, 51.41711197793484, 47.67591632902622, 50.25175251066685, 54.819384813308716, 57.67695687711239, 56.0775239020586, 58.63630659878254, 56.7455318570137, 60.568464919924736, 58.1075269728899, 54.625515416264534, 63.611189648509026, 56.79609194397926, 55.25559760630131, 53.42296354472637, 54.356824234128, 50.88420197367668, 48.44673156738281, 48.24886858463287, 51.346397772431374, 56.51973657310009, 60.53045175969601, 58.13246123492718, 61.132943630218506, 58.83861154317856, 51.2662448734045, 45.15744186937809, 47.67205573618412, 49.21077936887741, 51.10720440745354, 52.192581966519356, 54.09059911966324, 52.06882260739803, 51.587190851569176, 47.75399453938007, 45.466057509183884, 48.12342971563339, 49.630839228630066, 51.10209368169308, 53.40468272566795, 55.62153697013855, 57.08727791905403, 54.18589420616627, 56.25004604458809, 54.79829974472523, 58.13552387058735, 55.58155931532383, 55.69205358624458, 56.283229663968086, 59.90227706730366, 59.389410987496376, 61.94471687078476, 59.05353181064129, 57.507584765553474, 56.15483835339546, 41.223330572247505, 37.73224130272865, 35.280160680413246, 27.18329295516014, 4.209106341004372, 1.5582620655186474, 3.6674451688304543, 2.2488057799637318, 1.1257534800097346, 1.0205368883907795, 9.310688842087984, 19.742874205112457, 66.81123733520508, 65.26629343628883, 63.871274292469025, 66.50952592492104, 65.24599492549896, 64.60030317306519, 65.14961689710617, 32.57065147161484, 3.1023007817566395, 23.591799773275852, 82.01461672782898, 48.25209841132164, 13.720117583870888, 47.696541622281075, 46.42744392156601, 33.42810586094856, 51.44611582159996, 73.18446055054665, 24.17471319437027, 0.8238334371708333, 0.26715475833043456, 0.34934203256852925, 0.13221139699453488, 0.15501136105740443, 0.164534377399832, 0.15410056774271652, 0.14087083545746282, 0.1916106409044005, 0.13424375356407836, 0.1250121637713164], [0.09784502428374253, 0.015666117760702036, 0.007001632229730603, 0.06658358222921379, 0.05208330796449445, 0.030746502889087424, 0.06628727234783582, 0.029546425976150203, 0.0237732480673003, 0.08949621915235184, 0.024901733704609796, 0.02114644790708553, 0.08312816906254739, 0.14638710039434955, 0.09016423369757831, 0.3531077492516488, 10.080963559448719, 62.810017839074135, 56.30554586648941, 42.76392750442028, 42.16680854558945, 27.85770356655121, 21.53385490179062, 61.653644889593124, 46.050507947802544, 4.553849492222071, 3.8441751105710864, 39.36188265681267, 62.57180482149124, 56.7558217048645, 51.58454239368439, 50.00865675508976, 55.43752044439316, 45.91160260140896, 4.6099245082587, 0.06944781955098733, 0.09226461552316323, 0.9298146783839911, 0.6985697150230408, 5.466610388830304, 35.316277742385864, 57.09681920707226, 65.647511780262, 63.96795630455017, 63.72552551329136, 60.233045518398285, 59.8909080773592, 61.251090690493584, 64.42760244011879, 58.1684985011816, 58.93300607800484, 54.04266469180584, 48.184625431895256, 45.241310968995094, 46.67404308915138, 44.99716266989708, 45.97360387444496, 49.47407864034176, 52.13686555624008, 48.16183425486088, 46.65677681565285, 46.33753314614296, 43.436449617147446, 42.4451208114624, 45.59973053634167, 50.775900185108185, 55.21608352661133, 55.38145825266838, 53.49351055920124, 49.762262776494026, 48.02045524120331, 46.710224747657776, 44.646802470088005, 42.652316093444824, 43.02957125008106, 50.48447102308273, 48.77405360341072, 47.466494366526604, 45.49061939120293, 40.79900734126568, 37.87954039871693, 41.44151486456394, 46.82389944791794, 48.52521635591984, 49.046920761466026, 49.91580493748188, 47.81808190047741, 52.136481776833534, 46.67734891176224, 48.4997995197773, 53.701120018959045, 49.04886245727539, 47.68656335771084, 42.000996842980385, 44.183014556765556, 42.28076823055744, 39.61705416440964, 36.54641233384609, 39.88834820687771, 49.496018663048744, 52.53937415778637, 52.08377480506897, 52.95616239309311, 54.38258305191994, 46.504264399409294, 41.397399231791496, 41.95302061736584, 46.90543167293072, 49.110267162323, 49.897774904966354, 49.775888845324516, 51.85582123696804, 47.95412220060825, 44.493598490953445, 42.92291857302189, 40.053589940071106, 42.36299581825733, 42.68943250179291, 43.23747329413891, 44.715840965509415, 46.87915988266468, 46.782367676496506, 43.6447886377573, 44.6535737067461, 42.268190905451775, 46.67275495827198, 49.13232117891312, 51.91141225397587, 51.568161472678185, 55.30615769326687, 56.79896838963032, 55.25433607399464, 48.90159375965595, 42.38820746541023, 33.194802179932594, 32.14719459414482, 17.555854059755802, 12.378876004368067, 5.0397412944585085, 0.6268325331620872, 0.4044469428481534, 0.5504540784750134, 0.6195411994121969, 2.765080751851201, 3.1590452743694186, 28.545088581740856, 55.83070434629917, 53.27358976006508, 56.00790783762932, 51.06471508741379, 42.10895285010338, 38.96085977554321, 39.753698632121086, 2.646095836535096, 6.020846273750067, 53.46782773733139, 70.90473487973213, 21.7738576233387, 17.604231163859367, 38.54750655591488, 23.9300899207592, 20.49558911472559, 43.677523881196976, 47.40564823150635, 3.6492009228095412, 0.1190268986101728, 0.1579659103299491, 0.14520735276164487, 0.08008403514395468, 0.06289709723205306, 0.02454912264511222, 0.04318012222938705, 0.0664270187553484, 0.05469310737680644, 0.02521263792004902, 0.012095127640350256, 0.06272233629715629, 0.025939768238458782, 0.042074058728758246, 0.0877798319561407, 0.03114451297733467, 0.02626006618811516, 0.06493000299087726, 0.017772972969396506, 0.05765457346569747, 0.04295464292226825, 0.038172829590621404, 0.025647517904872075, 0.06405264342902228, 0.11890048117493279, 0.3990233573131263, 0.3728002222487703, 12.640794049948454, 72.26563945412636, 61.63900427520275, 44.243484511971474, 45.94176158308983, 25.77475033700466, 23.930118419229984, 61.62260055541992, 50.02530366182327, 11.578966677188873, 4.671043278649449, 41.84710510075092, 67.4947826564312, 63.666035905480385, 58.505206033587456, 55.10873168706894, 61.79750896990299, 49.207351952791214, 6.193781644105911, 0.3129408467793837, 0.15949644148349762, 1.1544243665412068, 1.5579383703880012, 9.403553009033203, 40.43103128671646, 61.03807792067528, 68.97693872451782, 67.37417712807655, 67.55783647298813, 64.52543199062347, 64.42627251148224, 65.40695428848267, 65.81909537315369, 61.007994934916496, 58.65533597767353, 55.754594430327415, 49.212462678551674, 48.657639250159264, 48.6862251162529, 49.98493082821369, 50.12114591896534, 51.58988490700722, 54.97658237814903, 50.936418771743774, 50.62014654278755, 47.31998182833195, 47.31988303363323, 43.289994075894356, 47.92062699794769, 56.20399251580238, 57.559824362397194, 55.07878549396992, 53.59590746462345, 52.36881650984287, 49.79353129863739, 47.624888867139816, 46.87734737992287, 44.85606864094734, 47.0406474173069, 51.39273248612881, 55.698452442884445, 55.12293912470341, 52.24502295255661, 46.98944516479969, 42.38984897732735, 46.374444365501404, 52.97214813530445, 55.18961414694786, 54.04261149466038, 53.982882499694824, 52.827075719833374, 55.27871176600456, 51.994897574186325, 51.43537379801273, 57.820296585559845, 53.641634210944176, 52.91969195008278, 48.93509656190872, 50.35586692392826, 49.372570887207985, 44.44932706654072, 41.52349926531315, 42.565680742263794, 56.18146352469921, 54.43541541695595, 56.09763242304325, 56.3473816215992, 56.7591655254364, 48.31212379038334, 43.261446207761765, 45.64662382006645, 47.609959468245506, 51.25385753810406, 50.49615919589996, 51.10712841153145, 50.957933217287064, 50.10489799082279, 46.69338025152683, 45.19076228141785, 43.26700910925865, 44.38580587506294, 45.61839513480663, 46.32643014192581, 47.64929495751858, 49.50731545686722, 48.86848233640194, 46.168263629078865, 47.52050846815109, 46.03019803762436, 47.400955483317375, 50.589759573340416, 54.2468087375164, 53.356809094548225, 58.24210815131664, 58.60589683055878, 60.21492809057236, 52.80908368527889, 47.62391231954098, 36.813727989792824, 38.87957073748112, 21.013013049960136, 17.044310308992863, 6.103831920772791, 0.22762518259696662, 0.36157989932689816, 0.3521024063229561, 0.5927424842957407, 1.2475028657354414, 4.657237194478512, 35.30988648533821, 59.54706072807312, 60.12128211557865, 60.45071303844452, 57.35707864165306, 44.75508525967598, 45.834379345178604, 38.26202027499676, 4.779001660645008, 10.567381158471107, 45.57180963456631, 65.13810351490974, 30.421648286283016, 16.370080187916756, 44.475572258234024, 31.21110912412405, 17.013469263911247, 49.60649013519287, 50.2374766767025, 3.730032560415566, 0.10087819668115117, 0.11612188027356751, 0.09318409938714467, 0.04946414635924157, 0.03581579825549852, 0.039108803975977935, 0.046258428337750956, 0.05996479754685424, 0.028139486530562863, 0.05008455955248792, 0.011488168656796915, 0.10326825358788483, 0.09891140143736266, 0.2468296786537394, 0.18167288275435567, 0.24302128847921267, 0.11705864875693806, 0.20150131720583886, 0.09630878601456061, 0.1453961106017232, 0.3067296644439921, 0.2179789697402157, 0.1729940000222996, 0.39073333027772605, 0.3296273248270154, 0.8002960158046335, 0.7628606620710343, 23.966683857142925, 89.10755172371864, 75.0936833024025, 51.91226340830326, 63.40171828866005, 36.97865813970566, 26.231259740889072, 71.6453455388546, 53.1431769579649, 11.799953319132328, 6.011273637413979, 48.6881136149168, 74.54558551311493, 73.59831154346466, 66.0535503923893, 59.48782570660114, 65.91113403439522, 55.627278462052345, 7.666372200474143, 0.6715886096935719, 0.2520245936466381, 2.3212655168026686, 2.361672786064446, 11.818415578454733, 46.97782538831234, 64.56451669335365, 71.16229265928268, 71.37343972921371, 71.26437038183212, 66.12117156386375, 65.87005823850632, 67.68096506595612, 70.62295719981194, 63.97358000278473, 62.312012761831284, 59.94240291416645, 52.85621255636215, 51.66770473122597, 53.4090980887413, 52.33538210391998, 52.22470924258232, 55.53147420287132, 58.510385155677795, 53.26987735927105, 51.4902276545763, 50.72277903556824, 48.66085007786751, 46.18661664426327, 50.60563512146473, 58.79826530814171, 58.6748631298542, 59.27244186401367, 56.93878188729286, 52.51076169312, 53.072755336761475, 50.1663026958704, 49.76754829287529, 46.39655917882919, 48.73602144420147, 54.6049053221941, 56.55708096921444, 57.14918039739132, 53.45104023814201, 48.84838901460171, 45.10535426437855, 51.68390326201916, 56.24275043606758, 59.03569936752319, 59.66199316084385, 59.00294132530689, 56.595785692334175, 60.283339619636536, 56.13363929092884, 53.05062152445316, 61.60580925643444, 58.33549194037914, 56.25720866024494, 51.31308875977993, 55.546346604824066, 52.62559533119202, 49.26431469619274, 44.47358876466751, 45.83021476864815, 59.44597475230694, 56.92118503153324, 57.17039845883846, 59.922024607658386, 58.03927883505821, 49.35316912829876, 45.14333702623844, 49.42224562168121, 51.2979693710804, 54.773335084319115, 54.66266222298145, 54.54949289560318, 55.709335058927536, 53.24980303645134, 50.45465022325516, 46.83246038854122, 44.710129871964455, 45.08043520152569, 49.22409765422344, 47.7776862680912, 51.464514434337616, 51.566523760557175, 50.23040525615215, 48.72363790869713, 51.21216617524624, 47.428549602627754, 51.30139298737049, 54.74411465227604, 56.806830167770386, 55.22130444645882, 58.97245556116104, 61.47898726165295, 60.63925512135029, 57.81152665615082, 48.883176147937775, 39.43345941603184, 41.27007186412811, 25.601850114762783, 17.05330442637205, 7.737683923915029, 1.1928792530670762, 0.8786454959772527, 1.2096472783014178, 1.7552357772365212, 4.318382777273655, 7.995390370488167, 37.61585354804993, 64.9659575521946, 66.35118082165718, 68.01235288381577, 63.21638323366642, 52.8368753939867, 51.76417015492916, 45.54439790546894, 5.095628220587969, 7.920122584328055, 64.21004891395569, 79.29772451519966, 31.83677215129137, 21.727232225239277, 60.178130865097046, 33.79413641989231, 32.02310465276241, 52.65438638627529, 67.89465799927711, 8.478809930384159, 0.2975940046599135, 0.299276186269708, 0.2857841196237132, 0.2595656749326736, 0.13228512194473296, 0.13586543529527262, 0.10367752576712519, 0.1656040793750435, 0.24861751240678132, 0.21327878523152322, 0.09644561578170396], [0.04035016099805944, 0.05214262411755044, 0.06709930807119235, 0.020187641348456964, 0.03627810801845044, 0.01217794668264105, 0.07046186045045033, 0.038086235799710266, 0.03908642822352704, 0.040556904787081294, 0.05669847574608866, 0.07120573733118363, 0.034189262878498994, 0.059316765327821486, 0.1268573506968096, 0.08482163873850368, 1.452537369914353, 44.38125751912594, 52.227053716778755, 50.658908262848854, 43.54795083403587, 45.06798326969147, 21.338260397315025, 48.1944365054369, 68.33826139569283, 30.05256649106741, 7.736059036105871, 25.990050584077835, 69.19401347637177, 67.21525445580482, 57.09469512104988, 53.77144664525986, 59.173992946743965, 42.359192222356796, 7.407683981582522, 0.08047911003814079, 0.28251763083972037, 0.22134869126603007, 0.8758390496950597, 4.355475911870599, 22.021393440663815, 46.27591945230961, 65.35547465085983, 67.70313307642937, 60.51079921424389, 60.71865566074848, 60.32270550727844, 59.287082478404045, 57.97988422214985, 59.126408100128174, 55.54070770740509, 59.251049011945724, 49.779301062226295, 44.09912645816803, 46.619052439928055, 46.414672806859016, 47.77055785059929, 47.98680804669857, 45.15651851892471, 46.15667425096035, 44.43336792290211, 45.93588709831238, 44.46897201240063, 45.618626922369, 49.375819712877274, 54.50696177780628, 56.17267079651356, 56.32280834019184, 51.05997294187546, 50.33069707453251, 48.09237398207188, 46.042174994945526, 43.0309771746397, 42.61532887816429, 43.78285802900791, 45.959689021110535, 47.21752032637596, 47.20805883407593, 42.573401927948, 39.82098162174225, 40.052552595734596, 44.78745572268963, 48.40002827346325, 49.23029512166977, 51.016374081373215, 48.81602615118027, 49.96360257267952, 53.20524662733078, 42.51463808119297, 53.74056950211525, 49.115640074014664, 49.35717411339283, 47.454525008797646, 44.99885357916355, 43.32999832928181, 40.449403300881386, 38.31603817641735, 39.7272102534771, 41.35295681655407, 47.59425491094589, 52.15696267783642, 53.80694054067135, 54.421941339969635, 54.12483528256416, 45.60212440788746, 43.806553557515144, 42.44508281350136, 45.239141285419464, 48.38311918079853, 53.044002279639244, 50.87384752929211, 48.93976651132107, 48.755886778235435, 47.2828084230423, 43.36161643266678, 42.872442081570625, 42.02838957309723, 41.172857880592346, 41.63354516029358, 42.79999516904354, 41.49415723979473, 41.601649671792984, 44.60304021835327, 45.186730697751045, 45.054896771907806, 45.93785539269447, 47.72451192140579, 48.525497540831566, 51.59433826804161, 52.094592824578285, 52.755928337574005, 51.06702536344528, 48.81769806146622, 51.17302447557449, 45.047323778271675, 35.80979526042938, 27.371626049280167, 26.267399601638317, 4.562323512509465, 0.1090940460562706, 0.6064229970797896, 0.5285386356990784, 0.1534543203888461, 0.5802402051631361, 8.464916925877333, 40.22784098982811, 55.438075214624405, 52.09470681846142, 48.152072578668594, 53.987324461340904, 49.07821208238602, 46.78578369319439, 16.16963904350996, 1.9638711819425225, 25.5003347620368, 73.79228353500366, 64.27854403853416, 24.37950510531664, 30.340484641492367, 32.19529241323471, 26.176850460469723, 36.0660345107317, 52.677242159843445, 36.75414718687534, 0.8095618186052889, 0.04992283815226983, 0.11255695906584151, 0.020107840064156335, 0.034181908195023425, 0.039086483884602785, 0.07169637116021477, 0.050593082851264626, 0.1335753605235368, 0.04324665576859843, 0.014050045738258632, 0.011643076213658787, 0.019788735116890166, 0.043045077327406034, 0.018910896869783755, 0.06640673585934564, 0.09484808353590779, 0.060149299170007, 0.05036905444285367, 0.05024999540182762, 0.09934315326972865, 0.013583045601990307, 0.05161873094039038, 0.0037962138503644383, 0.0715945559204556, 0.049409921339247376, 0.04357028039521538, 0.06815770713728853, 1.3096658675931394, 49.06416043639183, 59.41904939711094, 51.30282171070576, 49.127613231539726, 43.92650932073593, 20.612917318940163, 57.755829244852066, 61.49173177778721, 35.16990199685097, 9.90696994587779, 28.93462087959051, 74.9873574078083, 72.1268405020237, 61.82390235364437, 57.95185312628746, 65.00992119312286, 47.551184222102165, 9.214516002684832, 0.2284552450873889, 0.6359702709596604, 0.4118059604661539, 0.6538053858093917, 4.775027073919773, 24.496388733386993, 50.68543843924999, 69.62319284677505, 70.01561298966408, 65.87232291698456, 63.057076781988144, 62.03958638012409, 64.77628692984581, 61.46211996674538, 61.13654583692551, 59.61772173643112, 60.23163199424744, 52.07495167851448, 46.214913725852966, 50.79032801091671, 47.45780423283577, 48.24837081134319, 51.79985783994198, 45.730637311935425, 48.22314016520977, 48.33319365978241, 49.43471275269985, 45.69672793149948, 46.832129806280136, 51.524376422166824, 56.968678683042526, 60.04802964627743, 57.879808992147446, 55.486629009246826, 52.69149899482727, 50.03995567560196, 48.10634583234787, 45.972285345196724, 43.842788413167, 47.37906485795975, 49.773426577448845, 52.78671808540821, 51.79828092455864, 47.4039801210165, 44.636254236102104, 43.22839558124542, 49.92601118981838, 56.663315668702126, 53.689074665308, 54.66154508292675, 55.72770707309246, 54.765051528811455, 58.12401048839092, 47.37308777868748, 55.30966490507126, 56.334842294454575, 52.11077615618706, 52.27806217968464, 50.099129900336266, 49.353028535842896, 47.88999304175377, 43.502288684248924, 43.02297480404377, 44.84197519719601, 51.217436492443085, 56.34928911924362, 57.82795697450638, 56.754537373781204, 55.84368444979191, 48.5319571942091, 44.6150703728199, 44.12061810493469, 46.26694053411484, 49.550154358148575, 53.895054012537, 51.771298572421074, 50.06436176598072, 51.21955677866936, 48.861737698316574, 44.59712393581867, 44.81362111866474, 43.171030059456825, 43.78191187977791, 42.80692599713802, 45.79992279410362, 43.72520372271538, 44.97780650854111, 45.55038258433342, 46.8827772885561, 47.59633719921112, 47.743533700704575, 47.33628675341606, 51.6112207621336, 53.44035141170025, 55.89522488415241, 54.52114641666412, 58.1004935503006, 54.05236937105656, 56.83405950665474, 51.360992789268494, 43.05454730987549, 33.298631608486176, 30.040258951485157, 4.631310235708952, 0.5596570065245032, 0.7156369148287922, 0.4174552479526028, 0.09810752191697247, 0.5870603048242629, 10.73342939838767, 45.22892743349075, 60.493791326880455, 57.389376908540726, 53.45829404890537, 59.74866271018982, 53.019649386405945, 49.91937294602394, 16.629161685705185, 4.2213288601487875, 21.577364467084408, 66.37625187635422, 67.463738322258, 26.92044585943222, 21.05905517935753, 39.310763999819756, 17.35683023929596, 31.500455997884274, 64.03379157185555, 37.84271277487278, 1.708102987613529, 0.027107244459330104, 0.06170215041493066, 0.0890628865454346, 0.06531983090098947, 0.013126798257871997, 0.05941733375948388, 0.010398191207059426, 0.024926178193709347, 0.06203348595590796, 0.04440533011802472, 0.05121529946336523, 0.10836945017217658, 0.10915974839008413, 0.2540532691637054, 0.13222658133599907, 0.1682889915537089, 0.10297883825842291, 0.2457362724817358, 0.18931743426946923, 0.2738329890416935, 0.14752522838534787, 0.24569221859565005, 0.18920548871392384, 0.20382796501507983, 0.13620376557810232, 0.33737561374437064, 0.22366732388036326, 3.7510456703603268, 70.36948800086975, 70.07563456892967, 62.34944835305214, 61.2904641777277, 64.66553807258606, 24.243310913443565, 63.97683262825012, 75.84253951907158, 41.726746559143066, 11.834981739521027, 31.568554043769836, 81.11135959625244, 76.17138907313347, 66.83560162782669, 64.86523255705833, 71.61999329924583, 52.08458796143532, 10.916086547076702, 0.7349068683106452, 1.4987859944812953, 1.4650307432748377, 1.7144145676866174, 7.508254135027528, 26.264772042632103, 51.679381504654884, 71.48874074220657, 73.70189398527145, 66.98631674051285, 66.87150970101357, 64.06950205564499, 67.64293670654297, 63.12234967947006, 65.79035371541977, 63.2342004776001, 64.76763859391212, 55.49386382102966, 49.29179102182388, 55.55417038500309, 51.61385782063007, 52.882685735821724, 55.10325998067856, 52.137450724840164, 51.26449316740036, 52.57785089313984, 53.100110068917274, 50.40223203599453, 49.217402413487434, 54.40852425992489, 59.83306758105755, 62.40208312869072, 61.334028840065, 55.31829424202442, 54.42395523190498, 52.99288362264633, 51.61615289747715, 47.88245424628258, 46.36994160711765, 50.325438156723976, 51.602032855153084, 55.335062742233276, 55.987092554569244, 48.907247856259346, 46.79684489965439, 45.942453145980835, 54.848118871450424, 59.91677328944206, 56.87579646706581, 59.645661637187004, 59.12287048995495, 56.745509058237076, 59.452540799975395, 48.93608070909977, 58.85729134082794, 56.99766352772713, 57.66808435320854, 54.889931827783585, 54.511209949851036, 52.44214877486229, 50.877027958631516, 46.16658411920071, 48.034199103713036, 50.32218173146248, 53.2889599353075, 60.663193836808205, 59.59601350128651, 60.9980508685112, 58.59230495989323, 51.46222695708275, 46.579530760645866, 46.3392848521471, 47.995665371418, 51.39256149530411, 56.362523809075356, 55.020717009902, 55.15718288719654, 52.67456330358982, 53.253633230924606, 47.72060193121433, 47.86943234503269, 45.63408449292183, 46.002144142985344, 46.26375250518322, 49.20025773346424, 45.810524225234985, 47.600456178188324, 48.13317619264126, 49.02865134179592, 49.332490637898445, 49.57001969218254, 49.22540098428726, 53.80092926323414, 54.02636356651783, 57.888339534401894, 57.136055901646614, 60.46174004673958, 55.543207973241806, 61.04781299829483, 55.53690031170845, 45.255176424980164, 35.554813742637634, 34.332928508520126, 6.338517777621746, 1.1037794966250658, 1.9215401471592486, 1.1202405695803463, 0.5744491377845407, 1.8169378163293004, 12.25785344839096, 47.178747206926346, 66.07454806566238, 64.83061641454697, 60.65404772758484, 65.48798874020576, 56.777552738785744, 55.88523142039776, 22.811950519680977, 4.771453365683556, 33.458891808986664, 84.3359349668026, 73.75490874052048, 28.327166475355625, 39.61027532815933, 53.47815178334713, 33.32278311252594, 52.16897763311863, 67.7087339758873, 60.53117372095585, 2.5760658318176866, 0.14297814894234762, 0.18969034863403067, 0.10197996685747057, 0.11291841467027552, 0.1084493646339979, 0.20935861277393997, 0.13178219815017655, 0.1889393397141248, 0.14746751898201182, 0.12422216983395629, 0.11158240784425288], [0.01726189482724294, 0.03817562377662398, 0.09533301024930552, 0.0392712823668262, 0.09904251666739583, 0.041744556292542256, 0.04224310512654483, 0.11252023017732427, 0.021303580979292747, 0.046557220703107305, 0.08458473777864128, 0.04716179275419563, 0.06706126558128744, 0.01686096438788809, 0.08013084239792079, 0.11124998505692929, 0.2483047268469818, 27.313392274081707, 55.869629457592964, 58.3688959479332, 36.211988478899, 48.131192699074745, 22.969237379729748, 27.41634774953127, 87.15099111199379, 44.471886456012726, 6.276293266564608, 16.31757080554962, 57.71530821919441, 66.51307493448257, 61.93033084273338, 54.38360519707203, 49.96143288910389, 49.1864150762558, 16.626140847802162, 0.5112932610791177, 0.7077530503738672, 0.21795280161313713, 0.46474368078634143, 2.5341728422790766, 19.483268335461617, 57.59823650121689, 62.857842072844505, 66.80015712976456, 58.810842633247375, 56.7748548835516, 54.49322171509266, 58.21734867990017, 56.30512788891792, 60.5339589715004, 56.00093901157379, 56.97152853012085, 48.97557958960533, 47.675205767154694, 44.65693272650242, 46.7652989923954, 44.93036225438118, 45.61609625816345, 45.3536519408226, 43.81993643939495, 42.56863318383694, 44.10763420164585, 43.35144057869911, 47.41646625101566, 55.37781424820423, 60.01597836613655, 58.80087196826935, 57.3708339035511, 54.076859056949615, 49.540191292762756, 47.14429825544357, 43.585272431373596, 43.57209473848343, 42.49434716999531, 43.089866414666176, 43.41438040137291, 46.30716897547245, 43.01483564078808, 42.67029292881489, 39.75192792713642, 40.63276246190071, 46.29058666527271, 48.48430015146732, 49.08496052026749, 50.94838432967663, 49.82356868684292, 54.44318599998951, 46.01678855717182, 48.79521086812019, 57.689207419753075, 50.997302904725075, 53.72435577213764, 49.454232305288315, 49.23933483660221, 45.39004638791084, 45.24004563689232, 40.56977704167366, 39.19031426310539, 40.48670209944248, 47.169133722782135, 49.80387434363365, 52.92664177715778, 51.82438552379608, 51.45082376897335, 43.207610696554184, 43.16016644239426, 42.41199418902397, 42.9849274456501, 50.25432117283344, 50.34447133541107, 53.9346706867218, 50.905290842056274, 51.94942161440849, 49.755985513329506, 48.09537202119827, 44.250354543328285, 47.73877635598183, 46.908627301454544, 47.409307435154915, 46.14616021513939, 42.833231985569, 44.97919723391533, 41.77557393908501, 44.93806444108486, 43.90262760221958, 45.21204113960266, 46.11139588057995, 50.372179448604584, 49.23588842153549, 50.95794081687927, 48.99019740521908, 55.53401626646519, 53.63056920468807, 59.52379457652569, 55.11960670351982, 47.8173865377903, 30.73058120906353, 20.912546440958977, 12.89224935695529, 1.4081163285300136, 0.45169829798396677, 0.18951778445625678, 0.12938469008076936, 0.7062432251404971, 14.611044377088547, 46.486686542630196, 54.3787794560194, 45.592260137200356, 50.97062073647976, 51.654899418354034, 59.977205246686935, 43.08172345161438, 9.998022560030222, 12.683864738792181, 57.93272875249386, 67.14247316122055, 31.98003776371479, 14.154657516628504, 32.49711401760578, 32.74185508489609, 25.30419498682022, 26.32854212075472, 56.2178997695446, 15.170562453567982, 0.3244205651571974, 0.11763878559577279, 0.1899078572751023, 0.03246327971282881, 0.09480597407673486, 0.04480098017666023, 0.01988396565138828, 0.09087481783353724, 0.09437888293177821, 0.018907794692495372, 0.03210688926628791, 0.029715784075960983, 0.08682244661031291, 0.02920865601481637, 0.18157377635361627, 0.05354948007152416, 0.06851714410004206, 0.0473885411338415, 0.048115719691850245, 0.02120251901942538, 0.06161589059047401, 0.06515986096928827, 0.09302211081376299, 0.0991512338805478, 0.09760496177477762, 0.07005477760685608, 0.13483664049999788, 0.15730958461062983, 0.5645082180853933, 29.444399625062943, 67.59601682424545, 58.90702687203884, 41.074397563934326, 55.55609308183193, 20.329463928937912, 33.46527926623821, 82.57464587688446, 48.507007732987404, 11.55298177152872, 18.012217171490192, 63.12662445008755, 70.47304764389992, 68.11208993196487, 61.503074169158936, 57.572500482201576, 56.09278008341789, 19.71704699099064, 0.6687532493378967, 0.5309029994532466, 0.5579141469206661, 0.4542558576213196, 3.704398898407817, 21.940643973648548, 61.75485245883465, 68.86153131723404, 70.43927505612373, 63.239136412739754, 59.42151926457882, 59.29176762700081, 61.38030655682087, 60.83334110677242, 62.842080518603325, 57.67135217785835, 58.35767135024071, 52.51437909901142, 50.39261855185032, 46.59684643149376, 49.61780972778797, 46.85369364917278, 48.34352530539036, 47.6381691545248, 47.72264622151852, 45.93389980494976, 46.572463139891624, 45.924692898988724, 50.6709536164999, 56.19122140109539, 61.04846276342869, 60.99238537251949, 61.19404815137386, 56.38219155371189, 53.30580063164234, 49.780775383114815, 45.816645696759224, 45.43669268488884, 45.03213219344616, 45.36684863269329, 46.83168143033981, 49.84853334724903, 48.75090144574642, 46.5457733720541, 45.21042242646217, 45.04024475812912, 51.286604180932045, 54.67365883290768, 54.5891285687685, 59.11686301231384, 55.44316694140434, 58.61053258180618, 51.2592988461256, 50.97512349486351, 61.1177596449852, 53.88744302093983, 56.5262646228075, 52.67876587808132, 53.07911619544029, 51.232692673802376, 49.03669930994511, 44.50593642890453, 44.63523589074612, 45.351117476820946, 51.121985614299774, 55.338087379932404, 56.31202831864357, 55.282899141311646, 54.65226598083973, 46.21925309300423, 44.38029617071152, 44.67657007277012, 45.20531930029392, 50.64199537038803, 52.26067811250687, 55.93271367251873, 53.02635982632637, 52.03468903899193, 52.360483556985855, 48.018730133771896, 48.079697862267494, 47.82875932753086, 50.673358887434006, 48.28424088656902, 47.042513117194176, 44.42047901451588, 46.44157536327839, 43.55934642255306, 45.71332544088364, 44.43336792290211, 46.72907553613186, 46.2824285030365, 53.282135501503944, 50.989878103137016, 52.8764920681715, 52.26712256669998, 58.12099725008011, 57.284012362360954, 62.52116493880749, 58.425946086645126, 48.85153144598007, 37.16433897614479, 22.554702423512936, 16.29410896450281, 2.976146126165986, 0.36237518477719277, 0.2712834149133414, 0.32588675210718066, 1.0429603164084256, 16.95052184164524, 49.04646098613739, 57.924802377820015, 50.64725808799267, 57.212359607219696, 57.61603094637394, 65.92232063412666, 44.62737791240215, 12.973000723868608, 15.641966108232737, 56.67465426027775, 62.66448564827442, 42.06227995455265, 15.56710347533226, 26.933382265269756, 42.98244997859001, 21.32022086530924, 30.334598757326603, 65.1744219660759, 13.817992731928825, 0.18913505889941007, 0.19513579783961177, 0.19205192191293463, 0.13770890043815598, 0.06785914854845032, 0.04776082838361617, 0.045018919263384305, 0.04427645617397502, 0.02939075307949679, 0.015611764720233623, 0.07567458698758855, 0.030961751690483652, 0.20092009683139622, 0.10740779005573131, 0.24944669916294515, 0.17476206296123564, 0.140980881114956, 0.16354637104086578, 0.12619409331819043, 0.24486931040883064, 0.13768418692052364, 0.12208950458443724, 0.11845839864690788, 0.17226068390300497, 0.3501467878231779, 0.12526853126473725, 0.227673570625484, 0.3913119382923469, 0.6295161985326558, 43.57247091829777, 80.02977803349495, 71.3846643269062, 52.7716176956892, 70.67648112773895, 30.185810141265392, 41.15022249519825, 99.57162782549858, 51.25859588384628, 11.151851546019316, 21.210706941783428, 68.95173847675323, 76.4279817044735, 76.90623164176941, 65.28051227331161, 63.09901513159275, 59.03620094060898, 23.76858338713646, 1.2930262042209506, 1.759637009818107, 1.016940618865192, 1.183205209672451, 6.602790746837854, 24.64876625686884, 65.08106857538223, 70.91952368617058, 73.18997025489807, 65.99928930401802, 63.81862431764603, 61.931250393390656, 63.310466185212135, 63.15410077571869, 65.58218568563461, 61.31612800061703, 62.426956593990326, 55.80478973686695, 53.53554770350456, 51.447962522506714, 52.496151477098465, 49.51452746987343, 50.92190355062485, 51.16690680384636, 50.478239357471466, 48.137633353471756, 48.87758284807205, 48.51625643670559, 53.98169696331024, 59.06095281243324, 62.17039056122303, 63.58445808291435, 64.00448754429817, 57.87264257669449, 53.75785857439041, 51.48013919591904, 47.03069195151329, 47.4990776181221, 47.07075700163841, 47.230747416615486, 49.48670536279678, 52.343479469418526, 49.344957768917084, 50.354970172047615, 48.36444318294525, 49.5130455493927, 53.59680041670799, 56.53289906680584, 57.076235711574554, 62.29379653930664, 58.76530967652798, 61.66783332824707, 54.435267224907875, 54.756084010005, 63.120028004050255, 58.31886023283005, 60.80291993916035, 56.921618208289146, 56.552832797169685, 54.01706926524639, 51.752915158867836, 49.161853194236755, 47.995600774884224, 48.3464739471674, 53.12841475009918, 57.37916685640812, 59.94720585644245, 58.361132964491844, 55.49342684447765, 46.61803409457207, 47.15375974774361, 48.49120818078518, 47.254207357764244, 54.80777643620968, 55.920755714178085, 58.2733728736639, 57.63090714812279, 55.444044694304466, 57.22362980246544, 53.515116199851036, 49.21170651912689, 51.742625311017036, 53.38666409254074, 50.90407870709896, 51.55236952006817, 47.01516978442669, 48.05731326341629, 46.14491768181324, 49.03251193463802, 48.42061936855316, 48.230929747223854, 49.66483600437641, 56.18069216609001, 55.25896042585373, 56.32416486740112, 54.51522633433342, 60.891645178198814, 59.924175292253494, 65.85894003510475, 58.69124785065651, 51.132138669490814, 39.80480968952179, 25.184351317584515, 17.556625418365, 4.196012243628502, 0.9184078092221171, 0.8767232147511095, 0.7725911086890846, 2.072287439368665, 17.199264094233513, 53.95583935081959, 64.3979412317276, 54.210262298583984, 61.51559069752693, 62.5462131947279, 72.6183669269085, 52.05257087945938, 16.8514421582222, 18.209398090839386, 70.56139290332794, 69.88746866583824, 44.17690068483353, 16.251916028559208, 46.001038402318954, 51.63483269512653, 35.01554287970066, 37.911986857652664, 75.59116020798683, 31.94925181567669, 0.6272278900723904, 0.3407830809010193, 0.16914084349991754, 0.2017708503990434, 0.1817209442378953, 0.15080466022482142, 0.1723822922213003, 0.16047212819103152, 0.15198172128293663, 0.12725070380838588, 0.1898486487334594, 0.14785462321015075], [0.06723468322888948, 0.027179427597729955, 0.06880121596623212, 0.04063924236106686, 0.0582087054499425, 0.01610092724149581, 0.019789158141065855, 0.017894084048748482, 0.03218603931600228, 0.01945080002769828, 0.07084894241415896, 0.04409727574966382, 0.09337120965938084, 0.05787413043435663, 0.02706105133256642, 0.2090019514434971, 0.2326226417790167, 7.010297505185008, 49.28501598536968, 53.433101400732994, 35.127769857645035, 39.502471312880516, 37.908567041158676, 21.00922465324402, 50.17002649605274, 57.934081479907036, 8.616273254156113, 15.611231457442045, 52.6283273845911, 73.73530179262161, 51.74412243068218, 57.595059871673584, 54.95240807533264, 61.81335411965847, 23.99818606674671, 0.7427180022932589, 0.44101695239078254, 0.2053149914718233, 0.26552963303402066, 2.8241264959797263, 28.927585557103157, 55.56368127465248, 65.79542264342308, 67.79510334134102, 58.38170886039734, 54.439006224274635, 54.94956202805042, 60.30858926475048, 59.363169595599174, 59.52728658914566, 55.70452831685543, 56.66639730334282, 53.65491829812527, 48.324571922421455, 46.11154027283192, 43.532850444316864, 44.46692392230034, 46.550089940428734, 43.96024391055107, 44.84611317515373, 43.50730441510677, 44.19376417994499, 42.892524003982544, 50.45955955982208, 55.569996535778046, 58.685567155480385, 58.34349051117897, 57.75329478085041, 53.7202899903059, 47.59808890521526, 46.10511861741543, 45.43098919093609, 41.909653544425964, 44.25141088664532, 42.3913498967886, 41.79312139749527, 42.062222957611084, 42.52998925745487, 42.15230092406273, 40.13083599507809, 41.624357253313065, 49.434157982468605, 49.00897219777107, 51.5924421697855, 51.13743178546429, 51.22166186571121, 50.90557582676411, 44.37841147184372, 55.35683557391167, 52.71196469664574, 53.08649159967899, 52.25906699895859, 50.694565549492836, 49.43348541855812, 46.82604633271694, 44.939842745661736, 41.59289874136448, 40.84831349551678, 39.83007833361626, 43.74267898499966, 47.99629233777523, 50.493769124150276, 52.57489085197449, 49.31671768426895, 43.13981473445892, 41.87139339745045, 42.87727162241936, 41.320821940898895, 47.33353950083256, 54.58557955920696, 54.67710144817829, 52.218872755765915, 50.66954769194126, 50.30434928834438, 55.231328308582306, 54.55505579710007, 52.519835606217384, 52.490945756435394, 54.24943059682846, 51.49649351835251, 47.78204083442688, 43.55998858809471, 43.65623742341995, 41.17809019982815, 46.5650687366724, 46.46008796989918, 45.341830775141716, 48.465916737914085, 47.90213719010353, 48.94299253821373, 49.50785882771015, 54.876537546515465, 55.96474215388298, 60.329465344548225, 60.97654402256012, 53.999347016215324, 49.34386342763901, 33.0847030878067, 20.080581083893776, 13.449364062398672, 2.149522569961846, 0.30509943317156285, 0.1869977478054352, 1.5522751305252314, 21.309769526124, 51.561473831534386, 50.74929401278496, 56.550963297486305, 52.97600872814655, 56.63891717791557, 56.73651114106178, 39.124133214354515, 9.415000844746828, 21.70294962823391, 63.58200341463089, 50.95329746603966, 20.317238084971905, 22.67799060791731, 36.914794966578484, 29.692670702934265, 34.53230760991573, 39.63520959019661, 52.118440344929695, 1.9283825112506747, 0.2946028526639566, 0.0623563832778018, 0.11990106693701819, 0.044927516355528496, 0.032206711839535274, 0.03810478578088805, 0.07128935510991141, 0.02764946868410334, 0.09966992089175619, 0.014734457108716015, 0.03996021063358057, 0.04931726049107965, 0.02623643620609073, 0.013044452334725065, 0.1083999672846403, 0.017264930211240426, 0.021239444577076938, 0.06868368946015835, 0.05762886918091681, 0.03226367538445629, 0.06454791568103246, 0.014823214260104578, 0.1447372615803033, 0.1262095003039576, 0.007808468744769925, 0.0982604488672223, 0.15290826297132298, 0.2516361535526812, 0.34270019677933306, 6.827142583206296, 55.92278100550175, 62.79303275048733, 37.88495130836964, 48.71671088039875, 39.10250097513199, 20.615704469382763, 59.454144313931465, 53.85514855384827, 13.134796041995287, 17.831204384565353, 55.838638320565224, 81.43712371587753, 57.906776145100594, 62.58318521082401, 61.11606113612652, 67.3870812356472, 28.7274768948555, 1.721578964497894, 0.5205169098917395, 0.478459638543427, 0.3808551369002089, 3.2484409399330616, 32.59245850145817, 59.36698459088802, 71.33807122707367, 70.60201272368431, 62.14298643171787, 55.88438406586647, 58.37366469204426, 64.38570588827133, 59.9830037355423, 62.201780676841736, 58.64605687558651, 59.68507692217827, 54.70713123679161, 48.95266681909561, 49.224853813648224, 45.48463471233845, 48.80256347358227, 47.874322682619095, 45.75994893908501, 47.8376242518425, 46.92750468850136, 46.3619240373373, 44.046556279063225, 52.46060438454151, 57.80689090490341, 61.99181914329529, 58.27116139233112, 59.36150908470154, 56.973265036940575, 50.499145835638046, 48.4924279153347, 48.042980432510376, 42.81241290271282, 44.934732019901276, 46.12653426826, 45.64024396240711, 47.31125369668007, 45.88765248656273, 45.64797654747963, 44.28433611989021, 45.75512319803238, 54.49999675154686, 54.319331645965576, 55.82988739013672, 56.855125576257706, 55.098772421479225, 56.38790264725685, 48.87004405260086, 60.090465769171715, 56.71793393790722, 56.08915887773037, 57.40970961749554, 54.73380200564861, 52.41303473711014, 52.769657000899315, 48.69732812047005, 45.822151601314545, 44.04858157038689, 44.12466108798981, 46.431977078318596, 52.328721061348915, 55.37834621965885, 56.90587565302849, 51.403561905026436, 45.73675498366356, 43.85012201964855, 43.91322523355484, 43.23427386581898, 49.620986357331276, 54.53257240355015, 55.51701597869396, 54.94725935161114, 50.93373231589794, 51.234638169407845, 54.898678958415985, 54.915743842720985, 56.57147839665413, 56.1454376578331, 55.47519542276859, 55.506916120648384, 50.00799559056759, 45.721582397818565, 45.0206758081913, 45.211341977119446, 48.275942131876945, 47.801503390073776, 47.46618278324604, 49.73397709429264, 51.912867575883865, 51.14250831305981, 50.56864410638809, 56.797953844070435, 60.92857539653778, 61.320379972457886, 64.09843370318413, 57.443356812000275, 52.92095348238945, 35.59040643274784, 24.191301204264164, 15.823512766510248, 3.884791131131351, 0.20249638881068677, 0.7194232335314155, 2.502045566216111, 25.58907900005579, 54.81010191142559, 57.22837954759598, 60.4105643928051, 58.210459649562836, 61.33252412080765, 65.59806883335114, 42.63216197490692, 12.756871171295643, 27.243785709142685, 66.0269670188427, 52.93652504682541, 28.543585762381554, 17.49959047883749, 38.89726638793945, 42.299550622701645, 35.310737639665604, 44.26299266517162, 63.67808125913143, 5.24849496781826, 0.19369080662727356, 0.1335572818061337, 0.08088210364803672, 0.024278342643810902, 0.008503971512254793, 0.010195316790486686, 0.017219644360011443, 0.046653811223222874, 0.039999381187953986, 0.0038119341616038582, 0.05477566388435662, 0.017129581028711982, 0.0873050132940989, 0.13418803311651573, 0.1929937963723205, 0.1613771030679345, 0.19018824066733941, 0.20132194011239335, 0.15408047038363293, 0.12117471851524897, 0.22169380477862433, 0.1558838743949309, 0.21173111046664417, 0.20893147710012272, 0.14296234119683504, 0.23069102433510125, 0.2629656909266487, 0.5167149170301855, 0.4557828709948808, 13.42622995376587, 82.54555463790894, 73.42965379357338, 47.98488914966583, 58.12239557504654, 53.82300987839699, 24.2567165941, 64.12332996726036, 61.31862826645374, 14.719889536499977, 18.96332323551178, 64.24072086811066, 83.40160310268402, 63.61778609454632, 68.61661165952682, 68.96800920367241, 72.4633276462555, 33.22282947599888, 2.8148547559976578, 1.3071181043051183, 1.226667515002191, 0.8960484433919191, 5.237112678587437, 35.44890582561493, 62.2515694051981, 73.28837737441063, 72.39506050944328, 66.6644512116909, 60.845143273472786, 61.437311097979546, 67.94562086462975, 63.21050114929676, 65.79270198941231, 59.57484483718872, 63.558152094483376, 57.06120751798153, 55.1814179867506, 52.782485112547874, 48.480177372694016, 50.996007174253464, 52.41653434932232, 49.77200165390968, 50.14914661645889, 49.73536781966686, 49.899507611989975, 45.76598301529884, 56.4201857149601, 59.99007895588875, 64.54113274812698, 59.613728150725365, 63.0504347383976, 58.719696924090385, 52.532785311341286, 50.041391998529434, 50.60322605073452, 45.09196758270264, 49.08770017325878, 48.33168514072895, 48.25543463230133, 50.23415565490723, 49.67544123530388, 48.24720807373524, 45.816132724285126, 50.14387629926205, 58.68602693080902, 58.596898913383484, 60.12124791741371, 59.81311485171318, 58.24110120534897, 58.50786589086056, 53.28157313168049, 60.12259304523468, 58.01478534936905, 59.589664041996, 59.93463613092899, 59.238882064819336, 55.99015139043331, 55.659477934241295, 51.62678852677345, 49.2893173545599, 45.85228778421879, 45.62494218349457, 48.949110209941864, 55.237689167261124, 58.24728347361088, 59.935931861400604, 54.409523606300354, 48.21650192141533, 46.99618220329285, 47.767442017793655, 45.917575880885124, 51.54782496392727, 59.0757492184639, 58.67693021893501, 57.132077515125275, 53.57644110918045, 54.28217723965645, 60.73502138257027, 60.57128056883812, 61.314608082175255, 57.96418346464634, 58.042375668883324, 58.40826563537121, 51.72293856739998, 48.846663907170296, 47.17352628707886, 46.02235145866871, 49.16595697402954, 49.834014326334, 48.8062758743763, 53.80182981491089, 52.95908063650131, 55.40391884744167, 54.53783132135868, 61.675178334116936, 63.20426568388939, 65.12238755822182, 67.45098620653152, 59.21696104109287, 54.36674930155277, 39.37811158597469, 25.970548130571842, 16.67940068989992, 4.880171706900001, 0.6584260566160083, 1.0641752905212343, 3.072077678516507, 26.937753930687904, 59.25990633666515, 63.18144790828228, 64.16400298476219, 64.35999646782875, 67.58255794644356, 67.6172348856926, 46.70156501233578, 14.10818126052618, 26.819863356649876, 71.24295473098755, 57.36296832561493, 25.4201552644372, 25.690778642892838, 55.53404666483402, 41.611152961850166, 46.50175653398037, 51.45208530128002, 82.14329302310944, 11.200419589877129, 0.6015820568427444, 0.26779342093504965, 0.22495704295579344, 0.12861585477367043, 0.07061960393912159, 0.14542226388584822, 0.15483885625144467, 0.1687567523913458, 0.17674503702437505, 0.07474997488316149, 0.1159279867715668, 0.10168329332373105], [0.05572014328208752, 0.09407638353877701, 0.056879084804677404, 0.042098594130948186, 0.024269781970360782, 0.030380334646906704, 0.013391222692007432, 0.030902400285413023, 0.07613152731209993, 0.08252989413449541, 0.023741007316857576, 0.03962026246881578, 0.017355000964016654, 0.0599737923766952, 0.01426415255991742, 0.11895352246938273, 0.08561224865843542, 0.9260727697983384, 26.58214621245861, 53.271408677101135, 37.973300367593765, 33.48965495824814, 47.022275403141975, 15.804161354899406, 39.60279732942581, 89.15779262781143, 17.880128659307957, 12.3165412992239, 47.13409200310707, 74.93856802582741, 65.80716401338577, 59.000619649887085, 53.40035855770111, 57.70787201821804, 28.389205746352673, 2.389968680217862, 0.41683044866658747, 0.1465169168659486, 0.5550200678408146, 4.574374565854669, 28.65914136171341, 55.048067942261696, 70.83072245121002, 61.077143624424934, 57.555306404829025, 51.594615653157234, 57.30770789086819, 62.52114214003086, 66.31332725286484, 63.352320939302444, 58.719172552227974, 57.08831146359444, 51.88456289470196, 46.72776460647583, 44.79453854262829, 46.12779960036278, 46.91551253199577, 45.45515589416027, 42.40382842719555, 42.75869518518448, 43.737670853734016, 42.65660606324673, 45.68644568324089, 50.491504445672035, 57.29628570377827, 58.27914096415043, 58.38729836046696, 59.05370660126209, 57.75042973458767, 46.91498056054115, 45.08464157581329, 43.54896157979965, 43.5002937912941, 41.49384185671806, 43.2801678031683, 43.19790221750736, 39.36048053205013, 41.3675632327795, 41.031022891402245, 39.13223817944527, 44.46683272719383, 49.127560034394264, 50.363151133060455, 53.66698645055294, 50.76944053173065, 54.92092676460743, 44.6609491109848, 54.02497284114361, 56.51083745062351, 55.23556888103485, 56.097465232014656, 53.89733389019966, 53.055561259388924, 49.69724826514721, 48.563518300652504, 45.31261034309864, 41.14195793867111, 40.244997069239616, 40.11662095785141, 43.62887889146805, 45.56994393467903, 47.596246004104614, 48.322238847613335, 45.51970303058624, 41.99489817023277, 42.729330360889435, 41.57277122139931, 40.411466136574745, 44.64490257203579, 53.553361147642136, 53.6532311886549, 53.93969401717186, 51.97508163750172, 53.412856087088585, 53.7761165946722, 54.613948836922646, 55.4079732298851, 56.05278342962265, 52.391037717461586, 54.825593680143356, 52.4172031134367, 45.66979497671127, 43.95112819969654, 47.57712163031101, 46.05052314698696, 46.19417063891888, 45.70391334593296, 45.756415128707886, 47.68673434853554, 48.7357022613287, 47.7900356054306, 55.528278574347496, 56.65393017232418, 58.29010717570782, 57.633160427212715, 58.813817873597145, 55.86233764886856, 48.35231423377991, 33.30091908574104, 19.775028079748154, 9.96472779661417, 0.6964022875763476, 0.6432762101758271, 3.431107825599611, 26.036649383604527, 55.766358599066734, 53.864374458789825, 56.0805257409811, 54.595219641923904, 60.80688312649727, 52.8921852260828, 24.93829172104597, 8.019131496548653, 33.21000136435032, 54.387579783797264, 32.51558102667332, 14.108587838709354, 34.25511248409748, 26.703950576484203, 23.330713883042336, 39.003736674785614, 40.8686538040638, 38.68939094245434, 0.3209936834173277, 0.030547896749339998, 0.06893722937093116, 0.050099005457013845, 0.028559824131662026, 0.05101858951093163, 0.025332086588605307, 0.052263620164012536, 0.09896969713736326, 0.08665304398164153, 0.026145844094571657, 0.029256266643642448, 0.03205620057997294, 0.08110878523439169, 0.05285729748720769, 0.032782807684270665, 0.04766072379425168, 0.05416368519945536, 0.04422319594596047, 0.03253239221521653, 0.015892866140347905, 0.07732311962172389, 0.06342041524476372, 0.02466406276653288, 0.09118804126046598, 0.02894897112128092, 0.21444147831061855, 0.003321293606859399, 0.19680178578710184, 0.18271499167894945, 0.9467962046619505, 32.13081367313862, 67.97368615865707, 38.89680281281471, 41.77523575723171, 53.503625616431236, 15.219305288046598, 48.91144283115864, 85.6742687523365, 18.585564605891705, 16.189365684986115, 53.277993723750114, 79.10067468881607, 70.19437819719315, 65.68200632929802, 60.431999042630196, 65.44539302587509, 31.67195789515972, 2.619406543672085, 0.5826803867239505, 0.1712025742745027, 0.5537151941098273, 5.6583371758461, 32.46306784451008, 59.44187477231026, 74.68672513961792, 64.32638347148895, 61.90455682575703, 54.46090064942837, 61.033495366573334, 65.70893168449402, 69.39630702137947, 65.98342895507812, 61.15079887211323, 59.82149340212345, 55.326494202017784, 47.559140995144844, 47.27203980088234, 48.45347240567207, 49.37797039747238, 46.08852870762348, 45.97212955355644, 44.55530717968941, 45.366347059607506, 45.36040797829628, 47.65754051506519, 52.16872684657574, 59.56938453018665, 60.7341930270195, 60.43435871601105, 59.56107057631016, 57.93163821101189, 48.76176506280899, 49.32597778737545, 46.49399355053902, 45.62110438942909, 46.5133611112833, 45.518023520708084, 45.643865168094635, 45.211452171206474, 45.23833952844143, 45.206941813230515, 43.40736597776413, 47.13527753949165, 55.131804049015045, 55.01661702990532, 56.653565391898155, 55.767559334635735, 59.10729892551899, 49.57856923341751, 54.42673288285732, 60.44141873717308, 56.66780322790146, 60.46161845326424, 57.18550264835358, 56.42431989312172, 53.65238003432751, 52.13332034647465, 48.66116166114807, 44.700045213103294, 45.79937182366848, 45.54716415703297, 46.82342067360878, 51.349828988313675, 52.51560263335705, 51.65114142000675, 48.721517622470856, 44.20292168855667, 44.52526979148388, 44.58273030817509, 44.64281648397446, 47.467945888638496, 54.01379004120827, 55.81002205610275, 55.161035880446434, 53.806860744953156, 55.54756633937359, 55.49697585403919, 57.295290157198906, 56.122847869992256, 58.978478237986565, 55.90347804129124, 55.49126856029034, 52.52840414643288, 48.862740844488144, 46.395472437143326, 49.15063239634037, 47.826825231313705, 47.18958802521229, 49.0032497048378, 47.916899397969246, 49.240015000104904, 49.76452745497227, 49.80661779642105, 59.12627510726452, 59.76226978003979, 60.96355251967907, 61.91857427358627, 62.28860981762409, 59.12901096045971, 52.13292896747589, 37.47729018330574, 22.73320734500885, 13.104050941765308, 1.2926507368683815, 0.9803934080991894, 4.943762244656682, 30.305273830890656, 60.03601849079132, 59.79774467647076, 60.52426189184189, 59.79439325630665, 63.87790873646736, 56.28660388290882, 25.499873086810112, 12.980946097522974, 35.14319323003292, 58.73018056154251, 36.5425631403923, 16.46537147462368, 25.38206610828638, 36.92946217954159, 27.36879140138626, 41.10118992626667, 49.07704174518585, 46.946769654750824, 1.6786838974803686, 0.020065943972440436, 0.15620676800608635, 0.049392799992347136, 0.0015455400466635183, 0.03709882315888535, 0.02203278745582793, 0.051370586443226784, 0.0465097269625403, 0.05083459625893738, 0.058067307763849385, 0.1091857384017203, 0.02291305809194455, 0.2052063262090087, 0.18909783277194947, 0.2254210930550471, 0.16704138193745166, 0.14966258400818333, 0.11169608260388486, 0.16467400506371632, 0.20009990490507334, 0.25760319898836315, 0.18143751804018393, 0.15007505484391004, 0.1516976865241304, 0.12789598637027666, 0.3484803991159424, 0.1324006001232192, 0.36819190077949315, 0.26812251890078187, 1.4104381226934493, 54.845470413565636, 83.68384435772896, 53.5324926674366, 50.08433349430561, 66.76184758543968, 19.069770723581314, 54.28501568734646, 97.20044866204262, 22.805825248360634, 17.238333597779274, 55.32072611153126, 86.51048988103867, 75.79071030020714, 68.44453409314156, 65.82532703876495, 69.68009859323502, 37.059973776340485, 3.5918805235996842, 1.1430208222009242, 0.8699856419116259, 1.0773463337682188, 7.510186331346631, 35.59407703578472, 62.446799129247665, 81.29460096359253, 67.69233405590057, 64.31957423686981, 59.0130677819252, 63.487259298563, 69.09238412976265, 73.37228447198868, 67.37613022327423, 65.95418572425842, 63.07713210582733, 59.36320759356022, 50.36197319626808, 49.87528011202812, 50.35087399184704, 54.53971602022648, 49.620564579963684, 48.595231398940086, 46.982024163007736, 48.22357714176178, 46.60441942512989, 51.68732687830925, 55.73260121047497, 63.43873590230942, 62.153185084462166, 63.09944070875645, 62.13321715593338, 60.81477530300617, 51.44558385014534, 51.14306688308716, 47.60621666908264, 48.117498233914375, 47.31951825320721, 49.03472721576691, 47.54598990082741, 46.822542920708656, 48.184925615787506, 46.14052891731262, 45.082422494888306, 50.83059825003147, 58.20566050708294, 58.522620499134064, 61.26427598297596, 59.89424429833889, 61.78244657814503, 52.266731187701225, 57.31335058808327, 59.31981772184372, 60.830084681510925, 63.474621176719666, 60.72977766394615, 58.17533053457737, 57.60238967835903, 53.53096514940262, 52.1499178558588, 48.03578741848469, 49.15509335696697, 46.57696209847927, 49.58934165537357, 51.75190061330795, 53.96101087331772, 54.39416103065014, 49.33727838099003, 45.92225342988968, 45.958419889211655, 46.236188784241676, 45.7422760874033, 50.02641320228577, 57.56507568061352, 60.0600104033947, 58.89370858669281, 57.42097221314907, 57.94722877442837, 59.74239304661751, 60.42558118700981, 58.78242775797844, 60.86673751473427, 57.163764014840126, 57.687235325574875, 55.1394834369421, 50.03341622650623, 48.60044091939926, 50.96972398459911, 50.751220509409904, 50.40424592792988, 50.84021173417568, 48.729003220796585, 51.16371877491474, 52.00466305017471, 53.02281081676483, 61.30982793867588, 63.01021009683609, 62.295970022678375, 64.11929458379745, 65.22222340106964, 63.766992688179016, 53.32149378955364, 36.733054518699646, 24.50367484241724, 13.94495626911521, 2.380524999462068, 1.969257986638695, 5.508525464683771, 33.684428706765175, 67.33959138393402, 63.70942957699299, 67.86074861884117, 65.49225971102715, 71.33644491434097, 63.78108233213425, 31.292251870036125, 11.921988520771265, 38.91131043434143, 64.43496644496918, 41.735774874687195, 16.16477720439434, 43.522458001971245, 41.46218575537205, 31.510916836559772, 51.7945609241724, 51.8897420167923, 68.58596250414848, 2.9518922651186585, 0.11711830258718692, 0.24298490840010345, 0.11212969722691923, 0.1025192262022756, 0.08115442731650546, 0.1321290631312877, 0.10841921859537251, 0.18731136457063258, 0.08807801947114058, 0.13535482285078615, 0.1557785042678006, 0.1880025415448472], [0.04333231074269861, 0.1234579729498364, 0.05564198028878309, 0.07839423167752102, 0.14313352497993037, 0.03711021883646026, 0.09053930029040202, 0.03474602948699612, 0.04505858705670107, 0.05486545262101572, 0.0436537794303149, 0.10063465349958278, 0.012175261035736185, 0.02415128139546141, 0.02276833929499844, 0.027986216337012593, 0.13843457243638113, 0.23604276997502893, 9.40116198733449, 41.27446062862873, 42.648261711001396, 26.369046047329903, 44.723379760980606, 25.327404141426086, 20.900814570486546, 59.23368774354458, 35.71319304406643, 11.2358327396214, 40.549296140670776, 68.42015460133553, 58.76444712281227, 60.46207442879677, 55.516563802957535, 61.49751506745815, 30.432889983057976, 2.276497269049287, 0.40563933667726815, 0.2513929072301835, 0.2426078380085528, 8.956781532615423, 37.157860323786736, 63.40343579649925, 71.43891781568527, 63.11089709401131, 54.90647993981838, 49.40040439367294, 59.68317322432995, 61.503606140613556, 68.22562783956528, 58.99084657430649, 60.578230395913124, 58.17488215863705, 51.314061507582664, 47.44369179010391, 47.956044897437096, 45.412138402462006, 44.71435144543648, 51.08511999249458, 50.00796139240265, 51.84081584215164, 47.06340819597244, 47.35231429338455, 47.208640202879906, 52.59043961763382, 59.377327635884285, 61.11746326088905, 60.41654147207737, 58.23469094932079, 56.963172778487206, 49.55855950713158, 44.283446967601776, 45.537155494093895, 42.465438321232796, 42.10043750703335, 44.47421573102474, 42.595566138625145, 41.22431471943855, 40.238719806075096, 41.807610020041466, 41.106494441628456, 48.819172382354736, 52.25323811173439, 53.17340433597565, 52.38827906548977, 55.67269742488861, 48.562549352645874, 51.48081935942173, 62.752865105867386, 52.08185590803623, 57.193938195705414, 53.721194341778755, 53.85514095425606, 53.36380071938038, 52.497553601861, 50.24847708642483, 47.056283578276634, 38.79859708249569, 42.37633690237999, 40.69651924073696, 42.861593663692474, 44.08051885664463, 47.12569445371628, 47.45074421167374, 44.19339179992676, 41.70342341065407, 43.426570147275925, 42.278480753302574, 43.244537115097046, 42.466570660471916, 49.63957116007805, 53.44100497663021, 51.972585171461105, 50.93913562595844, 53.1053613871336, 53.53126913309097, 54.55915957689285, 52.09866240620613, 50.520029515028, 51.06217682361603, 53.71910825371742, 52.14095413684845, 48.48103232681751, 46.73978716135025, 45.748397558927536, 50.80479383468628, 46.646262779831886, 46.42125405371189, 49.345474541187286, 47.52539500594139, 47.32897214591503, 47.768239974975586, 52.024680376052856, 56.35490141808987, 58.942000195384026, 57.39872820675373, 59.562396705150604, 59.36891108751297, 59.263234958052635, 46.29559479653835, 29.778225012123585, 13.820714335888624, 2.757284282706678, 0.3720286855241284, 5.735091157257557, 28.593408688902855, 53.801620826125145, 55.388081297278404, 57.63558089733124, 56.369880214333534, 58.931759744882584, 39.476822689175606, 10.061769839376211, 25.670335739850998, 59.42365474998951, 53.975301906466484, 28.901083879172802, 16.054339930415154, 34.562029615044594, 24.244074672460556, 47.0386753231287, 36.992436200380325, 51.58731244504452, 18.870786800980568, 1.0084611363708973, 0.07343960925936699, 0.33208555541932583, 0.03610544736147858, 0.10638839827151969, 0.06364818778820336, 0.2267703620600514, 0.013442480048979633, 0.13265747227706015, 0.001683697098542325, 0.04369801885331981, 0.020298119306971785, 0.08268649471574463, 0.06360011146171018, 0.008924102239689091, 0.04859266831772402, 0.04946041706716642, 0.07793638593284413, 0.10860172755201347, 0.08295406863908283, 0.04988906301150564, 0.035365014045964926, 0.09416961212991737, 0.02425629714707611, 0.07125656702555716, 0.0522239672136493, 0.0323335226130439, 0.053977476636646315, 0.10108385322382674, 0.18095218314556405, 0.3837066167034209, 11.734445784240961, 59.38070945441723, 49.40625227987766, 27.100502997636795, 59.31665629148483, 24.34022281318903, 26.094142198562622, 63.86617496609688, 33.82221311330795, 15.386202782392502, 46.39415770769119, 73.5752771794796, 64.84107345342636, 64.53947603702545, 61.48142673075199, 65.28548240661621, 34.54009339213371, 2.910437914542854, 0.5434135312680155, 0.47413867665454745, 0.4882442916277796, 10.245313290506601, 39.529138281941414, 65.5306376516819, 74.43337753415108, 66.30230784416199, 59.342795088887215, 52.09424704313278, 63.67064505815506, 65.07258743047714, 72.70187884569168, 60.53008317947388, 62.30050317943096, 60.327132269740105, 53.99325214326382, 51.24650493264198, 50.081669837236404, 47.86777563393116, 47.06951066851616, 53.17417189478874, 52.383833304047585, 52.66350969672203, 48.8666470348835, 49.190503656864166, 47.18224681913853, 54.442315846681595, 61.0466692596674, 62.314972802996635, 63.31610508263111, 60.336342975497246, 59.96904708445072, 51.12125605344772, 46.51175759732723, 46.79849401116371, 45.23880310356617, 45.463716834783554, 46.6387277841568, 47.15331897139549, 44.00698900222778, 44.29734282195568, 45.321395471692085, 43.30262079834938, 51.88428170979023, 56.954254657030106, 58.77678506076336, 59.535197764635086, 60.01955397427082, 55.68207912147045, 55.30886694788933, 65.30576571822166, 56.21104873716831, 57.88881070911884, 56.871958673000336, 58.76912847161293, 57.49343432486057, 56.151703521609306, 54.19168509542942, 49.98472563922405, 44.344673082232475, 44.08333830535412, 44.012760892510414, 46.26788288354874, 48.00866827368736, 51.95921748876572, 51.36963352560997, 47.42657370865345, 44.196674823760986, 44.41189527511597, 44.294979348778725, 44.75840628147125, 44.92701843380928, 52.310223653912544, 56.07535421848297, 55.416594967246056, 52.2291512042284, 53.56080874800682, 55.83927668631077, 57.13890194892883, 54.889228865504265, 51.22686758637428, 52.706861570477486, 55.404272228479385, 53.17423649132252, 50.93623258173466, 48.53981137275696, 46.03677548468113, 52.041521072387695, 51.7673771828413, 48.99466596543789, 52.2105398029089, 49.42837469279766, 48.836913630366325, 50.28059296309948, 55.2521587908268, 59.00508061051369, 59.767034724354744, 61.13301582634449, 61.35218806564808, 61.0863733291626, 60.63559591770172, 48.021275997161865, 32.02216610312462, 14.35209397226572, 3.1259302888065577, 0.23289204138563946, 6.39935583807528, 32.800250351428986, 61.3993701338768, 61.03273160755634, 63.3773197978735, 57.76299566030502, 65.79239040613174, 42.93169990181923, 13.969432655721903, 31.49867009371519, 57.120982110500336, 56.7151752859354, 29.489816688001156, 16.23908791691065, 31.12276006489992, 30.772021785378456, 41.01012401282787, 44.70889113843441, 62.564972788095474, 24.922541566193104, 1.2831525527872145, 0.17131391126895323, 0.3989800752606243, 0.008635032008896815, 0.12389201801852323, 0.08754612965276465, 0.10204246311332099, 0.05474081634019967, 0.10754164381069131, 0.10602900583762676, 0.05097006418509409, 0.051271298216306604, 0.09634895104682073, 0.1701051159761846, 0.17791613121517003, 0.16170333634363487, 0.20437317638425156, 0.28765358962118626, 0.20066325436346233, 0.19311761629069224, 0.20013123837998137, 0.1393342632218264, 0.16618534427834675, 0.2037545369239524, 0.14647476287791505, 0.142990943568293, 0.1394395442912355, 0.21494621294550598, 0.12487854750361294, 0.5151024379301816, 0.49353954498656094, 22.93757937848568, 78.56203839182854, 61.99842318892479, 39.551101103425026, 67.6650819182396, 32.243489027023315, 27.653637416660786, 70.1098707318306, 41.17745563387871, 18.64156600087881, 48.76361936330795, 78.21300432085991, 70.6858666241169, 72.52509713172913, 65.24496138095856, 71.25502288341522, 37.973395362496376, 4.419146245345473, 0.7693070161622018, 1.1765005881898105, 0.6440615805331618, 12.02799143269658, 43.51206935942173, 71.88770413398743, 77.65447229146957, 68.88480886816978, 61.3263076543808, 55.132172629237175, 65.43805941939354, 67.54038020968437, 76.07839286327362, 63.453053534030914, 65.16204982995987, 64.65955719351768, 55.95176964998245, 54.75999020040035, 53.94575849175453, 50.07250852882862, 49.84174311161041, 57.46020130813122, 55.587300807237625, 57.00928330421448, 53.062902465462685, 49.87463414669037, 51.465749368071556, 57.33021788299084, 66.28698706626892, 64.94772613048553, 66.79712489247322, 61.68471202254295, 61.77141197025776, 54.54062417149544, 49.63340029120445, 50.406514406204224, 45.53939737379551, 48.262521252036095, 49.68547269701958, 49.012498408555984, 45.930198803544044, 46.93289279937744, 47.33480103313923, 47.317109182477, 55.5227916687727, 61.44518427550793, 62.09575496613979, 62.266977578401566, 61.3823052495718, 57.354475781321526, 59.35894422233105, 65.03923282027245, 57.00585588812828, 60.74347972869873, 57.72662401199341, 62.28649713099003, 61.23834617435932, 59.49149630963802, 55.43818920850754, 53.54894198477268, 45.2075307816267, 47.604514360427856, 45.52845016121864, 47.927953004837036, 51.19580805301666, 53.04732710123062, 52.77931988239288, 49.95313033461571, 45.476427152752876, 47.71201819181442, 46.999826207756996, 46.50304086506367, 45.79835347831249, 53.731852769851685, 59.40466336905956, 57.631986290216446, 55.85458226501942, 57.411457523703575, 58.11769902706146, 60.82755781710148, 58.208160772919655, 53.702997118234634, 52.38262876868248, 56.51971757411957, 55.218010023236275, 52.99606405198574, 51.72727793455124, 49.201906844973564, 55.87406001985073, 53.25262248516083, 52.22288154065609, 55.13938844203949, 53.28892573714256, 51.40778347849846, 52.64267161488533, 57.15989202260971, 60.2201072126627, 61.778817772865295, 64.56376433372498, 65.44949680566788, 63.50932851433754, 63.43071833252907, 51.31319135427475, 31.711133792996407, 16.342784352600574, 4.021432986482978, 1.055657691322267, 9.078700840473175, 39.25366446375847, 65.61568468809128, 65.67482471466064, 67.14479103684425, 64.05087545514107, 69.73950460553169, 46.47578872740269, 14.807262998074293, 32.42991842329502, 71.4749626815319, 67.0261462032795, 34.95178610086441, 18.06852824985981, 46.44125238060951, 37.13791899383068, 55.51075391471386, 50.83715669810772, 73.76912757754326, 38.61148752272129, 1.5571481315419078, 0.18363290961133316, 0.36849962489213794, 0.18747748690657318, 0.20228276902344078, 0.1861951596220024, 0.367656426387839, 0.12744821899104863, 0.30614033981692046, 0.16535097733139992, 0.1791804243111983, 0.15393857174785808, 0.16591248626355082], [0.022616132227994967, 0.017609652240935247, 0.10051608056528494, 0.03920243703760207, 0.15034838783321902, 0.015302862448152155, 0.04690395209763665, 0.024092037601803895, 0.05467620496347081, 0.0392774347710656, 0.031737377648823895, 0.05608766223303974, 0.08868251359672286, 0.004714555270766141, 0.03738422346941661, 0.03165249821904581, 0.06240452639758587, 0.06124514329712838, 2.1258890256285667, 37.37648919224739, 50.477946773171425, 33.97561088204384, 36.666337698698044, 40.505286902189255, 14.859678335487843, 44.8508021235466, 83.36986720561981, 27.179918736219406, 15.158879980444908, 51.80659867823124, 68.85553523898125, 63.29921878874302, 57.89335906505585, 61.88046991825104, 32.42325738072395, 2.6994129130616784, 0.23101025173673406, 0.26295684452634305, 0.8501610963139683, 11.289550457149744, 45.334782153367996, 67.22624346613884, 70.70101261138916, 63.41328486800194, 56.70684993267059, 49.996991381049156, 62.388487458229065, 63.593585193157196, 60.09119912981987, 60.17728731036186, 61.26308664679527, 57.87571661174297, 50.342955216765404, 46.611901223659515, 47.92369343340397, 49.26569402217865, 54.29357662796974, 56.85295209288597, 59.21802498400211, 60.214779898524284, 57.23799303174019, 55.76393812894821, 54.65757429599762, 56.98790945112705, 57.16495715081692, 61.44488409161568, 60.00488296151161, 58.33427220582962, 58.490345031023026, 52.278829738497734, 42.4918507039547, 46.93670779466629, 44.38901670277119, 43.61426867544651, 44.5650764554739, 41.515211910009384, 41.0664027929306, 41.69336535036564, 40.269760340452194, 41.29512012004852, 48.36707264184952, 52.18712545931339, 53.2061205804348, 54.82240565121174, 54.422351717948914, 46.99224941432476, 64.36602294445038, 56.92949898540974, 55.5652391910553, 58.29507350921631, 55.37750646471977, 55.235348492860794, 51.2967724353075, 50.23518539965153, 49.68206807971001, 47.136341482400894, 42.61497549712658, 41.41137108206749, 41.935602352023125, 41.4099195599556, 43.65126349031925, 42.137523517012596, 44.628742039203644, 42.959446012973785, 42.435047551989555, 42.27769799530506, 42.75299169123173, 44.18006211519241, 42.87546291947365, 46.301856860518456, 53.53620506823063, 53.405568078160286, 53.30589182674885, 53.416728079319, 55.20914509892464, 54.25444632768631, 55.09073965251446, 52.52598747611046, 52.00275555253029, 56.073952093720436, 54.33165818452835, 51.25927984714508, 45.20509511232376, 49.47909437119961, 52.37162075936794, 52.09728688001633, 51.23430758714676, 50.33057928085327, 45.966300666332245, 44.96036924421787, 46.924354657530785, 52.153615057468414, 54.41598705947399, 57.234569415450096, 56.27858631312847, 59.05109614133835, 62.01628603041172, 60.9459974616766, 54.20987091958523, 42.903972789645195, 22.056142576038837, 4.188697161152959, 0.45533262484241277, 2.8702344093471766, 29.590866565704346, 56.308380514383316, 57.94472090899944, 55.941893979907036, 60.353491455316544, 59.74913388490677, 46.118664890527725, 21.713338270783424, 61.764530539512634, 78.53580459952354, 58.329302072525024, 19.791407100856304, 25.140822753310204, 36.97755619883537, 26.615447625517845, 39.220347851514816, 43.243172988295555, 46.20424769818783, 4.6529158763587475, 0.22811860690126196, 0.28385020152200013, 0.2200980982161127, 0.14003048680024222, 0.14208307431545109, 0.07987287928699516, 0.050737734854919836, 0.08778732764767483, 0.06664657572400756, 0.1129406419931911, 0.03003656256623799, 0.04211344821669627, 0.07994483050424606, 0.029726010870945174, 0.04942460102029145, 0.08313701546285301, 0.006217158479557838, 0.1747213487396948, 0.042322934241383336, 0.027306692936690524, 0.026507852599024773, 0.07617734008817933, 0.04167647166468669, 0.040993580769281834, 0.0836557692673523, 0.03512027600663714, 0.03444041307375301, 0.10607705247821286, 0.1743513732799329, 0.16711408272385597, 0.09131163853453472, 2.5973033672198653, 49.161758199334145, 62.156289517879486, 30.886792726814747, 46.47173434495926, 40.21931804716587, 15.700014643371105, 50.62285579741001, 73.29771727323532, 30.40810391306877, 20.853729397058487, 56.95168599486351, 73.74806150794029, 67.5379179418087, 62.728424817323685, 68.65407004952431, 36.06278948485851, 4.222350530326366, 0.5175446381326765, 0.8705065108370036, 1.9273026566952467, 12.472836412489414, 47.61234574019909, 71.66564404964447, 72.74032518267632, 69.36765655875206, 59.484079107642174, 54.407783299684525, 64.77125599980354, 67.69738018512726, 62.936665043234825, 62.639000415802, 62.8491785377264, 59.424749091267586, 54.31290239095688, 49.6117452532053, 50.501418113708496, 51.186266764998436, 56.188223361968994, 58.584705367684364, 60.78116610646248, 60.7023811340332, 60.03109395503998, 58.87064762413502, 56.841077730059624, 58.411419466137886, 58.66318255662918, 61.16674281656742, 62.82459005713463, 61.73649184405804, 60.24561904370785, 54.33798484504223, 45.96766099333763, 48.23495373129845, 46.3367959856987, 44.76782977581024, 47.15364955365658, 44.30908039212227, 44.930202662944794, 44.227384775877, 46.80456228554249, 44.5866023004055, 53.793534860014915, 55.96436597406864, 57.087684497237206, 58.01331862807274, 62.15648330748081, 51.858800277113914, 62.94150598347187, 59.85425144433975, 57.401380464434624, 60.68309336900711, 58.51497530937195, 57.55304932594299, 52.59128697216511, 54.97161224484444, 54.13099095225334, 50.57431720197201, 46.29198499023914, 45.62939174473286, 45.97735807299614, 45.556963831186295, 49.010518714785576, 47.59648539125919, 47.54871055483818, 46.12094096839428, 44.1357184946537, 44.720016941428185, 44.269323125481606, 46.37977547943592, 45.58909870684147, 50.35876236855984, 56.87948986887932, 54.61402863264084, 55.573211163282394, 54.9031513184309, 55.38437269628048, 55.18669590353966, 55.46596571803093, 52.19881363213062, 54.90108422935009, 57.9637198895216, 56.633293479681015, 51.62302292883396, 46.28487937152386, 50.218477696180344, 55.032048001885414, 55.57702615857124, 53.84938046336174, 52.508816197514534, 49.574328660964966, 48.039857000112534, 50.175190418958664, 53.73050004243851, 55.872338712215424, 59.61929865181446, 58.15013788640499, 62.98692114651203, 63.43730337917805, 64.51465576887131, 57.18213602900505, 46.134673431515694, 24.377331621944904, 5.169079704210162, 0.40846783958841115, 3.8330431329086423, 33.044565841555595, 63.68306279182434, 61.04755841195583, 62.15482659637928, 65.15318110585213, 64.91105809807777, 50.428682416677475, 25.513645447790623, 53.61381970345974, 80.52663937211037, 56.3810820132494, 26.838934533298016, 18.9664713665843, 39.393926337361336, 33.384332209825516, 34.163096621632576, 53.174251690506935, 55.2378411591053, 6.200159601867199, 0.21524595154915005, 0.18302994430996478, 0.2324752215645276, 0.12297500550630502, 0.05714737118978519, 0.11506812705192715, 0.025816822198976297, 0.06592166813788936, 0.06772273438400589, 0.03012460540048778, 0.025510788327665068, 0.11287583023658954, 0.056491205032216385, 0.09595128605724312, 0.10783502963022329, 0.15126293641515076, 0.16310986946336925, 0.3827441402245313, 0.10307772201485932, 0.12699564249487594, 0.11842830455861986, 0.1871206919895485, 0.10546888472163118, 0.19397337193368003, 0.13171941245673224, 0.21023022069130093, 0.12298369605559856, 0.2374883252196014, 0.3796299104578793, 0.3085198433836922, 0.23902143904706463, 5.173911144956946, 70.35969972610474, 75.31850963830948, 47.330894842743874, 53.274889290332794, 54.20966573059559, 18.38218431919813, 55.35911925137043, 91.17672309279442, 34.8806919157505, 21.677340902388096, 60.225996896624565, 80.09392619132996, 74.97246980667114, 69.2250806093216, 72.3915646970272, 40.65997280180454, 5.399508364498615, 0.7486754294950515, 0.8942751854192466, 2.8065652633085847, 14.727524276822805, 51.31170183420181, 75.19432470202446, 75.27151376008987, 73.01701113581657, 63.41039702296257, 57.9954481869936, 68.61158832907677, 71.48717522621155, 65.93435078859329, 65.50154641270638, 65.91173440217972, 64.00627344846725, 57.517642825841904, 51.10664963722229, 55.0523579120636, 55.19665516912937, 59.85705949366093, 61.94804549217224, 64.06045094132423, 66.61967441439629, 63.06934632360935, 61.11383445560932, 61.67225629091263, 60.64244695007801, 61.96219213306904, 62.57798708975315, 64.73823577165604, 62.76466727256775, 61.89300164580345, 55.59806562960148, 46.37203149497509, 51.36267609894276, 48.347423896193504, 47.734383791685104, 49.8784339427948, 47.13083557784557, 46.21269844472408, 47.99224555492401, 47.67053961753845, 47.070897594094276, 54.49232876300812, 59.91585373878479, 60.25782398879528, 61.97155103087425, 63.15958008170128, 58.88502985239029, 65.00954881310463, 59.26754392683506, 58.765419870615005, 60.7933634519577, 61.14524357020855, 60.69430656731129, 56.176595985889435, 55.87359644472599, 57.507577165961266, 52.254967018961906, 49.578417241573334, 48.14194232225418, 46.6804039478302, 47.44199328124523, 50.61440885066986, 47.39445403218269, 49.10185061395168, 46.8820895254612, 47.398485615849495, 46.68179467320442, 47.2873529791832, 48.66803929209709, 48.11287768185139, 53.56673263013363, 61.26364901661873, 59.312704503536224, 58.31063747406006, 57.43296056985855, 60.27815289795399, 59.03705209493637, 58.82260300219059, 54.85253043472767, 56.34394660592079, 58.17240089178085, 59.22081023454666, 55.62937214970589, 48.83369520306587, 51.62850223481655, 56.74512527883053, 56.692015528678894, 56.029342487454414, 55.66953219473362, 52.80777655541897, 48.90945553779602, 53.37752178311348, 56.40713721513748, 59.30155970156193, 62.16682255268097, 60.96634157001972, 64.16867673397064, 67.137031853199, 66.83408930897713, 58.2081987708807, 48.18101182579994, 26.31712183356285, 6.463978495448828, 1.2958470778539777, 6.340623814612627, 39.71790835261345, 68.00185784697533, 69.41968336701393, 66.72973930835724, 70.68968921899796, 69.7483429312706, 55.42756877839565, 28.170897960662842, 71.01531654596329, 91.57255545258522, 67.24500685930252, 24.27263204008341, 28.4935025498271, 57.92659588158131, 37.75572024285793, 51.50087088346481, 57.922058925032616, 72.26826891303062, 11.478010844439268, 0.40422121121082455, 0.22026871796697378, 0.28916427574586123, 0.19959095487138256, 0.17785052536055446, 0.15628748398739845, 0.11065863436670043, 0.23813534440705553, 0.14138152211671695, 0.1865774398902431, 0.13544244080549106, 0.33763643412385136, 0.1607828654232435], [0.040666601635166444, 0.05490969204402063, 0.030389926905627362, 0.07015814393525943, 0.044444626837503165, 0.027862693277711514, 0.038857531326357275, 0.06355217614327557, 0.02853320329450071, 0.04509379083174281, 0.03137757332297042, 0.04856386185565498, 0.0516277777205687, 0.03616405476350337, 0.03172100958181545, 0.04309150237531867, 0.01904547978483606, 0.15711711603216827, 0.29716349963564426, 24.267272427678108, 48.6544094234705, 42.37487778067589, 47.563385367393494, 54.79992225766182, 21.626780815422535, 36.66883796453476, 90.63816279172897, 67.71361291408539, 20.030562467873096, 23.565581180155277, 60.82482196390629, 67.50856831669807, 59.093771651387215, 61.53529264032841, 41.969405338168144, 9.295448809862137, 0.9904848947189748, 1.3456174009479582, 0.33447654743213207, 16.60896196961403, 60.26505120098591, 74.83358725905418, 71.24398827552795, 67.4686248600483, 58.60161446034908, 51.03088170289993, 62.13012412190437, 65.16701996326447, 63.974499553442, 63.110733702778816, 62.91196636855602, 60.91296203434467, 52.56348766386509, 48.33276808261871, 50.34936927258968, 53.123794198036194, 55.62125578522682, 61.5378575026989, 59.40436698496342, 63.80470186471939, 59.87572409212589, 59.276526644825935, 60.81420533359051, 59.27604407072067, 63.839477598667145, 57.228060364723206, 60.77988937497139, 61.491230204701424, 56.24226026237011, 51.57359518110752, 44.861129969358444, 46.35468542575836, 42.42917686700821, 42.96785496175289, 41.392657086253166, 42.40558013319969, 41.32677622139454, 41.433105915784836, 41.371887400746346, 46.341910511255264, 53.49875047802925, 55.22012270987034, 53.196564093232155, 55.59124879539013, 47.065623477101326, 59.30005498230457, 61.549602672457695, 53.99374231696129, 58.01580369472504, 55.48839971423149, 56.34692944586277, 52.77515910565853, 52.48120307922363, 49.9478904157877, 51.32488712668419, 46.594828739762306, 42.87640526890755, 42.050021812319756, 42.55289822816849, 40.67160777747631, 40.163943618535995, 42.92381152510643, 43.2258877158165, 42.752167135477066, 40.30960500240326, 41.63705617189407, 43.566816821694374, 43.49688157439232, 42.693118304014206, 42.56125397980213, 49.14684019982815, 55.213670656085014, 53.77407230436802, 54.993426874279976, 53.16528037190437, 53.76261591911316, 57.60124213993549, 55.8348423242569, 55.01953147351742, 55.52461177110672, 54.05357390642166, 49.93920788168907, 55.28606817126274, 52.55317881703377, 58.774706572294235, 57.49247297644615, 58.39550592005253, 52.93436676263809, 47.94183366000652, 47.602352276444435, 47.78612181544304, 48.73814933001995, 49.737849086523056, 53.14208261668682, 55.68549893796444, 56.46180868148804, 62.27925091981888, 62.718142569065094, 61.58460259437561, 48.94061766564846, 26.763542778789997, 6.551554771140218, 1.01590137463063, 4.519302695989609, 37.69923247396946, 59.90084454417229, 57.17321030795574, 54.56971921026707, 50.42248874902725, 54.858393520116806, 41.876040548086166, 39.135563001036644, 53.221741542220116, 50.34150369465351, 35.991668701171875, 8.879762515425682, 41.81549459695816, 33.88926811516285, 24.15897063910961, 36.81634984910488, 50.64280852675438, 34.38785456120968, 1.8385059339925647, 0.16308666992699727, 0.3044391592266038, 0.10187845589825884, 0.15440274059074, 0.08702722741873004, 0.05432600031781476, 0.08491896398481913, 0.07275903015397489, 0.07432498401612975, 0.018421511704218574, 0.0687585944251623, 0.03796528799284715, 0.055545085488120094, 0.03535204130457714, 0.05329841893399134, 0.02316116548172431, 0.03079804875596892, 0.024060110408754554, 0.048380050429841504, 0.007838021065253997, 0.05146190771483816, 0.12697257654508576, 0.015660022872907575, 0.03648242498456966, 0.037680106615880504, 0.06317132822005078, 0.04121980593481567, 0.11889285189681686, 0.05872206013009418, 0.043155245439265855, 0.16260761360172182, 0.21615150530124083, 28.19055810570717, 67.14580938220024, 40.799706503748894, 46.934568509459496, 60.07958695292473, 17.527729868888855, 41.015664115548134, 85.28373330831528, 67.45176136493683, 23.166745081543922, 26.527716033160686, 63.609422743320465, 73.62820833921432, 64.73549991846085, 67.42383286356926, 45.373156294226646, 11.369312927126884, 1.3515761937014759, 1.903746414463967, 0.6528417812660336, 18.046434335410595, 61.9486116617918, 77.73383483290672, 73.18832874298096, 69.28955554962158, 61.29520632326603, 53.87763574719429, 62.72875539958477, 70.10974913835526, 66.46126091480255, 64.73950490355492, 66.99103608727455, 63.53881113231182, 54.65903341770172, 51.49642512202263, 52.352861166000366, 56.090731993317604, 59.588584899902344, 62.863389775156975, 62.98501364886761, 63.943888396024704, 62.130238115787506, 62.16515064239502, 62.70038992166519, 61.085153594613075, 64.68278914690018, 59.559695050120354, 61.677150428295135, 62.578986436128616, 58.55338364839554, 52.632324770092964, 48.53126563131809, 48.0637501180172, 44.243469312787056, 46.495570465922356, 45.259774178266525, 46.16667151451111, 44.83051501214504, 46.79760105907917, 45.65671607851982, 50.43812111020088, 55.654959976673126, 59.24642466008663, 58.08532856404781, 62.030679658055305, 53.33876386284828, 57.99761027097702, 64.56608980894089, 57.68223859369755, 60.81066392362118, 58.552711084485054, 60.14674834907055, 57.30581559240818, 54.64425981044769, 54.14000026881695, 55.94804584980011, 51.23758301138878, 45.82640737295151, 44.66062992811203, 45.45796014368534, 43.585853800177574, 46.402616053819656, 45.879821106791496, 47.399883940815926, 46.91034100949764, 45.70361316204071, 45.616168454289436, 45.14803737401962, 44.47090230882168, 43.972099274396896, 45.160071328282356, 49.625538513064384, 58.12174580991268, 56.52271941304207, 55.99128372967243, 56.056663021445274, 57.11380049586296, 59.950458481907845, 57.122551426291466, 56.93016774952412, 57.90681034326553, 55.45128330588341, 52.46280066668987, 58.41639719903469, 55.056283101439476, 61.77227832376957, 60.45159839093685, 59.85846921801567, 56.017072945833206, 49.926797747612, 49.32997517287731, 50.67862540483475, 49.35686632990837, 53.18212486803532, 56.56649686396122, 59.04478847980499, 58.63556183874607, 64.08586397767067, 64.29642587900162, 63.13892439007759, 51.28816969692707, 28.244579806923866, 7.948593506589532, 1.414757422171533, 3.990880725905299, 46.49171747267246, 65.37888139486313, 63.07855322957039, 56.8997123837471, 56.32382668554783, 59.77081552147865, 43.92440423369408, 38.88708673417568, 53.925566375255585, 58.05884398519993, 45.757889449596405, 15.204625725746155, 27.314915992319584, 45.938182175159454, 21.99882075190544, 38.847557455301285, 61.44497528672218, 39.01860527694225, 1.84501260984689, 0.08705010783160105, 0.19541524612577632, 0.08402427527471446, 0.16202759550651535, 0.061628495968761854, 0.07398044937872328, 0.05611776745354291, 0.09806779475184157, 0.07198696650448255, 0.003724072689692548, 0.02953867609903682, 0.07417638378683478, 0.05464685302285943, 0.10200961565715261, 0.1981058283126913, 0.12980170286027715, 0.16197016811929643, 0.17502522852737457, 0.15166918805334717, 0.07404886055155657, 0.15349527209764346, 0.17848558112746105, 0.15531328157521784, 0.11888340435689315, 0.18011340784141794, 0.21920593280810863, 0.16093729151180014, 0.2814645826583728, 0.15423220989760011, 0.280029239365831, 0.34313969663344324, 0.5699225713033229, 47.61626332998276, 76.97378441691399, 60.49144685268402, 63.56421656906605, 74.12908986210823, 27.201687768101692, 45.4857936501503, 99.1896191239357, 73.70494902133942, 27.51859836280346, 30.709376446902752, 69.73417729139328, 79.04854148626328, 70.23818984627724, 72.73391872644424, 49.96869809925556, 12.264884021133184, 2.0761743932962418, 3.0979628395289183, 1.0439886362291873, 19.56297855824232, 62.79792308807373, 81.48320764303207, 78.15178960561752, 72.82903522253036, 65.16245260834694, 56.17611721158028, 69.14889469742775, 71.99732065200806, 69.4617547094822, 69.93985265493393, 71.73955768346786, 67.24892064929008, 58.12923140823841, 54.49043646454811, 55.828751251101494, 59.61809031665325, 64.0015085041523, 70.15210926532745, 65.28104424476624, 69.15698066353798, 66.76561698317528, 65.00134125351906, 64.65752810239792, 64.5930227637291, 68.27215254306793, 62.98378251492977, 64.1379363834858, 67.88844153285027, 60.32315768301487, 57.102389708161354, 48.46646390855312, 51.07473514974117, 46.759352311491966, 47.551279217004776, 46.438820511102676, 49.14212465286255, 47.43190102279186, 49.725328758358955, 49.47991132736206, 55.02727545797825, 60.812248438596725, 63.224636390805244, 59.78884555399418, 63.7097829580307, 58.15617576241493, 64.07789960503578, 64.10608649253845, 61.064976677298546, 63.519287779927254, 61.50382652878761, 62.15965993702412, 61.71504199504852, 57.72359177470207, 56.755190938711166, 58.688644990324974, 53.51129740476608, 48.32268342375755, 46.69789060950279, 49.57600437104702, 45.700280740857124, 47.513239458203316, 47.20712028443813, 48.72407488524914, 49.94787521660328, 48.08857798576355, 48.11445839703083, 47.296081110835075, 47.506095841526985, 48.099901378154755, 46.17723494768143, 52.475339993834496, 59.177766144275665, 60.691057741642, 59.724587202072144, 58.316181376576424, 59.84390079975128, 64.00457873940468, 60.09961947798729, 60.32990612089634, 59.4448272138834, 59.088668525218964, 54.20713506639004, 60.75045995414257, 56.091788336634636, 63.910678178071976, 63.09176132082939, 64.06060293316841, 56.74223743379116, 52.79615297913551, 51.794640719890594, 52.05188311636448, 52.925889417529106, 53.494825288653374, 59.19787846505642, 62.87654846906662, 61.135189309716225, 64.27662894129753, 66.6755998134613, 67.60673984885216, 52.84117676317692, 29.39591232687235, 8.797951955348253, 1.823925047647208, 5.760235358029604, 50.756555423140526, 70.84183305501938, 69.20235022902489, 63.101549595594406, 60.31572908163071, 63.01962599158287, 51.15747570991516, 44.890407398343086, 61.24572157859802, 63.105193600058556, 48.402365148067474, 10.322935525327921, 53.263820484280586, 52.77349479496479, 31.82443231344223, 52.938185557723045, 69.66330349445343, 55.45506410300732, 2.7457668632268906, 0.16448518785182387, 0.2797957300208509, 0.13026505534071475, 0.22165835980558768, 0.18316140834940597, 0.16472141345730051, 0.11673328379401937, 0.192365538678132, 0.172869126254227, 0.12396261852700263, 0.15739151771413162, 0.1886205279151909, 0.17494702100520954], [0.0317465171974618, 0.02445077509037219, 0.05995812934997957, 0.048684078647056594, 0.032448035999550484, 0.031414209443028085, 0.06475157584645785, 0.06158636053442024, 0.03548152380972169, 0.012327933800406754, 0.03264996696088929, 0.08545803037122823, 0.07215740813990124, 0.020146947535977233, 0.03133658079605084, 0.08135986121487804, 0.08317620828165673, 0.1463135684025474, 0.16098569438327104, 12.459861058741808, 62.45695598423481, 53.259583711624146, 67.38563731312752, 63.89392867684364, 33.19263629615307, 22.898196391761303, 65.41095167398453, 76.17061391472816, 34.836488887667656, 24.272202663123608, 52.98627957701683, 68.73327299952507, 61.186144575476646, 62.82599218189716, 45.39431735873222, 22.385660894215107, 3.010545917786658, 0.05517957033589482, 3.453477225266397, 25.626748278737068, 67.62094348669052, 76.39021173119545, 68.02537098526955, 67.14059606194496, 59.073704928159714, 51.54815934598446, 58.248712196946144, 67.95409440994263, 67.88233906030655, 63.14783111214638, 63.60572174191475, 59.633958265185356, 57.061006128787994, 56.380660235881805, 56.56657665967941, 58.195024877786636, 59.262805581092834, 59.565501138567924, 60.40883548557758, 58.31124544143677, 62.58655183017254, 59.38489682972431, 62.263417169451714, 61.742586717009544, 61.02352850139141, 60.357762426137924, 60.977714359760284, 61.02694071829319, 59.73308354616165, 47.41914130747318, 45.04618003964424, 45.93432158231735, 44.979930594563484, 42.926277592778206, 42.57010370492935, 42.25427605211735, 42.2227643430233, 40.16924813389778, 41.29421956837177, 49.28269051015377, 54.8981773853302, 53.07073384523392, 54.44090612232685, 49.91973392665386, 50.36364510655403, 61.560622081160545, 52.876974642276764, 54.88456651568413, 55.11869855225086, 56.126833856105804, 55.67819572985172, 56.016556173563, 51.90985433757305, 53.412514105439186, 50.226453468203545, 48.19026052951813, 44.29255127906799, 41.78109884262085, 42.154774591326714, 40.843715742230415, 40.48215754330158, 41.81847743690014, 41.48379519581795, 42.34488219022751, 42.23611302673817, 41.50252819061279, 45.63639476895332, 44.92028519511223, 43.488430827856064, 42.49482974410057, 42.70629219710827, 43.76787543296814, 48.46821941435337, 48.88862885534763, 49.706318378448486, 50.851979702711105, 52.4245785176754, 55.67822612822056, 54.078762754797935, 54.43982698023319, 55.06905801594257, 55.38321755826473, 52.811006382107735, 53.974564746022224, 63.859373331069946, 57.23814882338047, 58.30507077276707, 55.37209555506706, 48.86023297905922, 46.79554916918278, 49.46928329765797, 51.17056600749493, 51.32152810692787, 52.226289957761765, 53.72306004166603, 56.34295105934143, 57.00889192521572, 62.22942799329758, 63.25748562812805, 57.57761500775814, 24.92679163813591, 6.319311708211899, 1.7270821379497647, 5.642112521454692, 40.23526579141617, 59.800469130277634, 55.23748777806759, 57.28179708123207, 50.470255985856056, 61.87475122511387, 41.10511511564255, 44.87460404634476, 62.05444358289242, 52.47003547847271, 20.346177332103252, 15.037110764533281, 49.590356200933456, 24.061038494110107, 37.004249766469, 39.63177837431431, 51.566394567489624, 5.986430095508695, 0.4898982716258615, 0.19128902378724888, 0.3718038147781044, 0.09528922353638336, 0.2718062431085855, 0.12119298276957124, 0.017434310575481504, 0.027443437356851064, 0.02497440109436866, 0.02122769637935562, 0.1312364821205847, 0.07314688395126723, 0.051234001584816724, 0.027409137146605644, 0.02217896828369703, 0.0801822732319124, 0.05363514988857787, 0.14252517168642953, 0.016854967834660783, 0.04210271676129196, 0.02953702296508709, 0.13422609044937417, 0.04169475447270088, 0.0795650141662918, 0.015692766428401228, 0.018237325493828394, 0.0711447921639774, 0.06522889554616995, 0.050631707927095704, 0.08747807471081614, 0.05987605523841921, 0.30920089746359736, 0.2456329803681001, 16.812807731330395, 74.03398856520653, 61.57871291041374, 70.49465328454971, 70.63488855957985, 29.182549975812435, 22.451201677322388, 75.67983224987984, 73.89953657984734, 36.068580374121666, 26.666347794234753, 60.0919970870018, 71.71761006116867, 66.36145547032356, 67.91146829724312, 51.373266130685806, 26.460110060870647, 3.4065561555325985, 0.22783336986321956, 4.851335529237986, 26.983245089650154, 70.55491045117378, 79.32698294520378, 71.11880779266357, 70.62731176614761, 63.46729896962643, 54.55621853470802, 61.43765687942505, 69.92008611559868, 70.40959104895592, 66.24424695968628, 64.65539261698723, 64.0873458981514, 59.57288034260273, 58.422112092375755, 58.78921799361706, 62.0746660977602, 64.34547364711761, 63.54909338057041, 63.106591925024986, 60.85164092481136, 63.131150007247925, 61.740253642201424, 65.10297060012817, 63.43495510518551, 61.277161091566086, 60.396007373929024, 62.17709340155125, 61.93466641008854, 60.244543701410294, 51.11382745206356, 45.64822353422642, 46.29215598106384, 46.84304282069206, 44.9607340246439, 44.10888433456421, 45.98205842077732, 46.18511572480202, 46.17031551897526, 43.75203028321266, 50.32073400914669, 57.40446209907532, 57.80839942395687, 61.33412383496761, 55.771769508719444, 53.55722174048424, 65.31422406435013, 56.66326247155666, 58.617273420095444, 59.28985632956028, 59.53045181930065, 58.88022691011429, 56.75171032547951, 55.97983114421368, 56.14927925169468, 55.101876854896545, 52.503637075424194, 47.653090953826904, 45.33797398209572, 46.488556042313576, 45.4345989972353, 45.340835228562355, 46.69882535934448, 45.64449593424797, 44.01260890066624, 44.098351299762726, 44.48586970567703, 46.060877591371536, 46.00815922021866, 44.92593169212341, 45.72660192847252, 43.48612815141678, 48.03826108574867, 51.32942408323288, 53.212804421782494, 51.675661504268646, 53.41116897761822, 52.88867801427841, 58.20607468485832, 57.202328145504, 55.67048214375973, 57.83222794532776, 55.823496133089066, 55.105118080973625, 56.63957454264164, 64.48151394724846, 58.04682143032551, 59.561591148376465, 56.76832303404808, 51.76140770316124, 48.119512125849724, 51.42098017036915, 53.30630600452423, 54.229052290320396, 54.051271229982376, 57.180562913417816, 58.59643153846264, 61.98762036859989, 64.85554307699203, 66.53166353702545, 58.29304441809654, 27.163900695741177, 7.104024700820446, 2.5584977120161057, 6.30056113936007, 46.68994143605232, 65.77655285596848, 60.43739475309849, 58.70661802589893, 57.19498693943024, 63.843414187431335, 49.439827278256416, 45.58393478393555, 67.00369700789452, 54.9994495511055, 33.517857044935226, 14.826908893883228, 39.03820842504501, 31.296249255537987, 26.85902215540409, 48.1993268430233, 60.712089613080025, 8.127790465950966, 0.6201689969748259, 0.18111190816853195, 0.2645938441855833, 0.1172021207457874, 0.07389623788185418, 0.024086417688522488, 0.06182007768074982, 0.041772349723032676, 0.05219691593083553, 0.02016102422203403, 0.016685533664713148, 0.01683002610661788, 0.03925134828023147, 0.10220043666777201, 0.1617982125026174, 0.24961032788269222, 0.10240279807476327, 0.40750165237113833, 0.1035804528510198, 0.1552480467944406, 0.1397458731662482, 0.23290547425858676, 0.15743396856123582, 0.26275679119862616, 0.0954464401002042, 0.23992889269720763, 0.22066174453357235, 0.21301328932167962, 0.12452123308321461, 0.1425658116932027, 0.15772643411764875, 0.5975267244502902, 0.3621369553729892, 27.064264342188835, 93.55334356427193, 71.8910251557827, 82.32242301106453, 84.21928122639656, 45.50096243619919, 25.940493643283844, 79.65845435857773, 84.11261335015297, 42.732974365353584, 30.9869534522295, 64.26575392484665, 79.3460351228714, 70.86995914578438, 71.25460490584373, 56.36117868125439, 29.84544150531292, 5.2117029670625925, 0.5682560638524592, 5.420952038839459, 28.81002366542816, 70.15510350465775, 81.6708567738533, 76.24363839626312, 75.66885843873024, 66.34790539741516, 58.44009652733803, 66.17113888263702, 73.82461979985237, 73.167954236269, 66.19937136769295, 68.48575428128242, 68.77854377031326, 62.740508168935776, 61.202445700764656, 60.79055540263653, 66.39200583100319, 66.87787815928459, 65.00673696398735, 66.50045201182365, 62.6143853366375, 64.84611958265305, 62.884794026613235, 66.44065082073212, 66.66977852582932, 63.91045019030571, 63.34325082600117, 63.260327875614166, 64.70648467540741, 64.49725270271301, 51.248222440481186, 49.752846881747246, 49.189652502536774, 48.880732879042625, 48.035707622766495, 46.79060563445091, 47.73603290319443, 48.86805295944214, 47.13016301393509, 45.29268801212311, 55.109533444046974, 60.30128225684166, 59.267323538661, 60.8661637455225, 57.573207244277, 58.55392701923847, 64.58225414156914, 56.73360049724579, 60.13158716261387, 60.366433560848236, 60.972508639097214, 62.200389951467514, 59.711253717541695, 58.771738931536674, 59.58975523710251, 57.85139411687851, 55.6340990960598, 50.9598483145237, 47.15431071817875, 48.985500857234, 46.33775353431702, 46.94866955280304, 48.639160841703415, 47.88887210190296, 45.86285121738911, 46.69160194694996, 45.64147129654884, 49.03415724635124, 49.17542986571789, 48.375584185123444, 47.07341305911541, 46.10374689102173, 48.95202845335007, 53.49067971110344, 56.613329350948334, 55.81178516149521, 55.90708784759045, 57.68818147480488, 60.42119242250919, 59.60604876279831, 58.18167619407177, 61.54066935181618, 58.57186585664749, 59.701674431562424, 59.85765986144543, 67.2419822216034, 61.08793884515762, 62.02979050576687, 61.065421253442764, 52.93642245233059, 48.64680603146553, 53.92872400581837, 54.38178889453411, 55.82416109740734, 57.330301478505135, 60.62226243317127, 61.68452963232994, 61.83891534805298, 67.83011466264725, 67.99941837787628, 62.56305009126663, 27.757852524518967, 8.404972292482853, 3.646002681925893, 7.7305270079523325, 51.1384691298008, 70.18104091286659, 63.66273008286953, 64.9879963696003, 60.3125486522913, 69.34552654623985, 51.635015085339546, 51.596272364258766, 71.80239111185074, 62.835776656866074, 29.1477058455348, 16.158511340618134, 69.04653578996658, 33.88249687850475, 49.75116737186909, 54.71899800002575, 76.50331646203995, 17.776772305369377, 0.6753772438969463, 0.26174467988312244, 0.37071826052851975, 0.2196528244530782, 0.3084338136250153, 0.17603368847630918, 0.10136641110875644, 0.11098921662778594, 0.16565997793804854, 0.10496040224097669, 0.2913521567825228, 0.17656908865319565, 0.057088173780357465, 0.2294331879238598], [0.08283393719466403, 0.03049368657229934, 0.029261827185109723, 0.07048057741485536, 0.04208150246995501, 0.027835872060677502, 0.02911587456765119, 0.042148626016569324, 0.03306393693492282, 0.058110697427764535, 0.053094599206815474, 0.08576221443945542, 0.014253638182708528, 0.07771439471980557, 0.060796585530624725, 0.07343116361880675, 0.07408945602946915, 0.07241418381454423, 0.07220433413749561, 4.13400954566896, 43.21940526366234, 60.33307135105133, 55.695872381329536, 27.989824377000332, 36.89976677298546, 20.69846972823143, 46.74978442490101, 62.85198658704758, 61.705417111516, 28.526477180421352, 43.924221843481064, 71.28762513399124, 69.98839125037193, 60.33429868519306, 56.06639809906483, 45.298209115862846, 8.129964899271727, 0.07587064013932832, 7.92920789681375, 42.10503526031971, 67.04907417297363, 74.91276741027832, 68.5086290538311, 66.96803212165833, 57.8764271736145, 49.734246879816055, 56.601291596889496, 65.94239875674248, 68.38187545537949, 66.83936342597008, 64.84874904155731, 58.727250918745995, 57.39641413092613, 61.71766385436058, 60.71180462837219, 56.48795887827873, 60.156829208135605, 58.366904854774475, 63.881495743989944, 61.853799149394035, 60.12379378080368, 59.689344093203545, 60.89863680303097, 57.030239179730415, 59.438922330737114, 65.28828665614128, 57.87928082048893, 58.683853447437286, 53.05959664285183, 44.80592653155327, 44.180715680122375, 43.84194105863571, 44.17754665017128, 42.745186910033226, 44.04444359242916, 41.92573048174381, 42.07178324460983, 42.8275740891695, 41.17951512336731, 50.206018164753914, 56.208529472351074, 54.11415405571461, 53.96405830979347, 50.0400772690773, 58.55697825551033, 57.62075029313564, 57.29340545833111, 56.016153395175934, 56.30684159696102, 55.66183000802994, 59.82044845819473, 56.24406896531582, 55.07889948785305, 51.344725862145424, 50.99724590778351, 50.708567798137665, 46.04854345321655, 40.97973704338074, 41.11886277794838, 41.45501174032688, 41.306834891438484, 40.52734471857548, 41.83781459927559, 41.35181687772274, 41.55830919742584, 41.67417638003826, 44.99345786869526, 45.38571462035179, 43.8916651904583, 44.33038964867592, 44.99110959470272, 43.51669751107693, 44.05362010002136, 45.07228843867779, 44.97653737664223, 48.81809324026108, 51.8731103092432, 56.31355203688145, 60.195511132478714, 57.382309287786484, 58.18539619445801, 55.38742773234844, 56.7084838449955, 56.31134055554867, 49.271845892071724, 53.30986641347408, 56.258549988269806, 53.84937286376953, 50.3253735601902, 51.0594941675663, 55.082847476005554, 54.735063537955284, 52.27187991142273, 52.19714552164078, 53.19666288793087, 54.603674188256264, 58.00096169114113, 64.74372267723083, 62.45820231735706, 54.32266786694527, 22.12523616850376, 9.187370259314775, 3.0916259670630097, 11.095199435949326, 47.89768382906914, 57.39327929913998, 56.205280646681786, 51.18191599845886, 50.21674498915672, 59.921971410512924, 45.99115893244743, 65.88732451200485, 45.08210331201553, 33.64453464746475, 8.151490744203329, 38.517009392380714, 41.19415573775768, 25.952407903969288, 35.657640025019646, 48.36296126246452, 28.238825015723705, 1.5970727079547942, 0.08001054768101312, 0.20232716429745778, 0.030043650076549966, 0.24688364763278514, 0.04532869170361664, 0.10360189349739812, 0.08746047096792608, 0.07969953585416079, 0.019091459544142708, 0.10018854853115045, 0.055174364169943146, 0.010790938540594652, 0.03144195092318114, 0.053015990924905054, 0.09042235265951604, 0.07048501545796171, 0.04783070529811084, 0.08566002070438117, 0.049748708042898215, 0.031767167456564493, 0.02448062426992692, 0.03929605896701105, 0.04842846443352755, 0.10748409767984413, 0.004472369755603722, 0.05555883006309159, 0.0027634497246253886, 0.18373403465375304, 0.04173730550974142, 0.09936989285051823, 0.05418174165242817, 0.1364126949920319, 0.08153022863552906, 4.2827036418020725, 54.13343422114849, 69.42523866891861, 53.594505339860916, 31.488334648311138, 36.478217393159866, 19.66664459556341, 59.98080365359783, 64.04520615935326, 62.00560100376606, 32.33683481812477, 49.82898719608784, 74.30487602949142, 73.87491390109062, 66.93452551960945, 62.75806322693825, 50.0143488496542, 9.718229323625565, 0.09105540462769568, 8.434315267950296, 44.73569869995117, 68.52699726819992, 75.84623292088509, 71.11812382936478, 69.53946053981781, 61.39706365764141, 53.34854833781719, 60.018091052770615, 70.03256008028984, 69.72366705536842, 69.56295847892761, 65.41464507579803, 62.48158246278763, 61.442429423332214, 66.98428004980087, 62.78147757053375, 60.66930390894413, 63.04645635187626, 63.553273156285286, 65.93423679471016, 65.02866178750992, 63.10740888118744, 62.32832528650761, 62.2527701407671, 58.86661984026432, 60.706921890378, 66.21415257453918, 60.86891479790211, 63.52825529873371, 56.05239585042, 48.3195523917675, 46.79811783134937, 46.758835539221764, 46.6131741553545, 47.89380423724651, 46.520823910832405, 45.60204841196537, 45.994126573204994, 46.03710226714611, 45.69624915719032, 51.669718623161316, 57.980480790138245, 58.680353835225105, 58.5128778219223, 55.02914495766163, 62.0917309820652, 59.93557088077068, 60.95692187547684, 59.731852412223816, 59.1761664301157, 59.61199924349785, 60.82807458937168, 56.73759028315544, 55.46981491148472, 53.77485506236553, 54.230663403868675, 54.64361384510994, 49.02751140296459, 45.32825790345669, 44.62771229445934, 45.517252162098885, 43.91751140356064, 44.88919906318188, 45.38437709212303, 45.842894688248634, 45.750479847192764, 44.46216277778149, 47.156149819493294, 47.23072461783886, 46.595900282263756, 46.42558582127094, 44.69177685678005, 44.98972646892071, 45.59312269091606, 46.04434847831726, 48.435123190283775, 51.70375719666481, 52.532082349061966, 59.12527196109295, 61.304584220051765, 58.865916877985, 60.544366613030434, 57.37295038998127, 58.22239100933075, 59.542314782738686, 51.546578630805016, 57.52033308148384, 59.29416909813881, 56.376491859555244, 51.507414132356644, 53.33047650754452, 57.87615738809109, 57.573271840810776, 55.72953477501869, 53.47174912691116, 57.6637601852417, 57.48455040156841, 61.54940888285637, 64.46034148335457, 64.71447944641113, 57.79375500977039, 24.494253247976303, 11.492253430187702, 5.341716315597296, 13.510895110666752, 53.7879491597414, 63.5974457859993, 61.85952544212341, 56.57422564923763, 53.90089429914951, 64.64103698730469, 51.6629283875227, 70.36957159638405, 51.44096329808235, 42.44540959596634, 15.790289249271154, 21.354417130351067, 43.53581428527832, 27.7868639677763, 36.11778773367405, 61.89280405640602, 31.523885540664196, 1.8624436995014548, 0.03128770666080527, 0.19698710006196052, 0.04688574350439012, 0.05768969560449477, 0.03258709220972378, 0.11651751919998787, 0.072324955399381, 0.09803390086744912, 0.018851658642233815, 0.07477665509213693, 0.1269693556241691, 0.05262560269329697, 0.021890347052249126, 0.06365362030919641, 0.18181485560489818, 0.13694511173525825, 0.15970565291354433, 0.19991908804513514, 0.16071935242507607, 0.1442468207096681, 0.14425072440644726, 0.1739356221514754, 0.12181437559775077, 0.17802737915189937, 0.2299899619538337, 0.22049471677746624, 0.06432365349610336, 0.3357720701023936, 0.11444668969488703, 0.24727137526497245, 0.22721714980434626, 0.3584910213248804, 0.20201734732836485, 8.819572795182467, 79.15078639984131, 79.01183545589447, 70.08044511079788, 40.65724454820156, 54.823860973119736, 22.969089187681675, 62.90976628661156, 72.92159825563431, 73.87742936611176, 37.69453212618828, 52.66422025859356, 80.31473994255066, 79.33500811457634, 69.61049392819405, 67.14750409126282, 55.41905723512173, 9.976416919380426, 0.2559392148396, 9.860015865415335, 50.676710307598114, 72.32105568051338, 78.75415608286858, 76.9229507446289, 73.22032302618027, 65.45881390571594, 55.026697888970375, 64.47471991181374, 74.95704263448715, 73.40000778436661, 70.85472196340561, 71.168053150177, 64.89938512444496, 65.5217233300209, 71.67745381593704, 66.72403961420059, 61.64549432694912, 66.49401515722275, 65.30678406357765, 69.79890301823616, 66.6162545979023, 65.10341137647629, 63.60704407095909, 63.06119196116924, 60.12318581342697, 61.74795962870121, 69.91122499108315, 62.16990798711777, 65.43349206447601, 56.72559432685375, 49.278286546468735, 49.31648589670658, 49.22681450843811, 47.34852969646454, 49.77170526981354, 49.981366619467735, 47.292383909225464, 47.9029655456543, 49.53762263059616, 47.15796232223511, 56.82506538927555, 61.57914988696575, 61.9052179902792, 60.290148854255676, 59.782898873090744, 61.529330760240555, 59.63154159486294, 64.2490804195404, 59.35272395610809, 61.392059326171875, 60.682789385318756, 64.41064774990082, 61.40903681516647, 60.44597089290619, 57.72532068192959, 57.36163079738617, 56.08657121658325, 51.36007323861122, 47.02926702797413, 46.61058269441128, 48.337141647934914, 45.28157740831375, 45.45961685478687, 46.843396201729774, 48.41938443481922, 47.36314371228218, 46.45463526248932, 48.996265679597855, 49.92565780878067, 48.203628212213516, 49.62141573429108, 48.83333042263985, 47.2954997420311, 47.98862814903259, 49.83728975057602, 50.70830941200256, 55.46391002833843, 55.22527523338795, 62.03615516424179, 64.72605362534523, 60.65989561378956, 61.69591002166271, 60.13263590633869, 61.099353432655334, 60.52754111588001, 50.88056176900864, 57.162966057658195, 60.07618993520737, 60.90848967432976, 52.26424992084503, 55.70822171866894, 59.66638572514057, 61.22455671429634, 56.84632524847984, 56.3463518768549, 61.690354719758034, 60.63675105571747, 63.71007174253464, 70.26467442512512, 65.79932883381844, 57.55728989839554, 27.587754651904106, 12.296685464680195, 6.7467450723052025, 16.088032722473145, 56.94034740328789, 67.14352190494537, 65.31597197055817, 61.26874454319477, 59.07947301864624, 68.49905356764793, 55.02717286348343, 76.28723725676537, 57.76607349514961, 45.328478291630745, 9.39099183306098, 47.14189678430557, 60.10066442191601, 35.33651165664196, 53.01649935543537, 67.9969485104084, 56.07116684317589, 2.731691231019795, 0.21701322781154886, 0.23883388348622248, 0.12788932188414037, 0.38430380809586495, 0.1301152750966139, 0.19579506246373057, 0.1757991104386747, 0.12159472214989364, 0.11405337369069457, 0.14482018916169181, 0.337242828682065, 0.146687685046345, 0.07700123533140868, 0.21116148243891075], [0.08988763525849208, 0.1118629693519324, 0.046226089252741076, 0.029191399225965142, 0.02672357080882648, 0.0868201014236547, 0.010420453781989636, 0.02911300431151176, 0.05263042294245679, 0.08076417638221756, 0.007903622281446587, 0.11906542349606752, 0.0036170164958093665, 0.04660284052079078, 0.09635118491132744, 0.061851114296587184, 0.13351999630685896, 0.18030228442512453, 0.1963322883239016, 0.7932823046576232, 26.412405520677567, 55.48827812075615, 54.56867426633835, 32.31727346777916, 41.37799747288227, 20.90471126139164, 25.534861609339714, 54.87178020179272, 67.12915107607841, 49.86441269516945, 62.02942952513695, 64.94704976677895, 74.51692745089531, 61.68650172650814, 64.02280256152153, 52.82754689455032, 22.43820447474718, 0.2855279599316418, 10.531784668564796, 49.29826207458973, 72.29881167411804, 71.10179990530014, 68.60260561108589, 62.24149614572525, 62.05601289868355, 50.45661851763725, 56.83093227446079, 65.02081140875816, 68.49111199378967, 64.30299952626228, 64.98767718672752, 62.7459304779768, 61.462203562259674, 62.56081581115723, 64.26787421107292, 65.85084646940231, 66.15232989192009, 63.83988797664642, 62.8407733887434, 61.213548704981804, 61.630998104810715, 58.635102063417435, 62.1613584458828, 60.993802696466446, 61.13226346671581, 59.98086825013161, 54.421967938542366, 53.529889807105064, 48.176288679242134, 44.109815284609795, 45.32028213143349, 44.68766927719116, 43.29198896884918, 43.93695496022701, 41.36166214942932, 42.18969851732254, 39.631527587771416, 40.39495602250099, 44.86729323863983, 52.86663919687271, 54.04752463102341, 54.32772919535637, 48.15928839147091, 56.290346682071686, 58.54624763131142, 52.24737502634525, 56.10169440507889, 55.08947052061558, 59.00065764784813, 58.063650727272034, 54.88355956971645, 56.56937710940838, 52.501657381653786, 52.240242809057236, 51.68700009584427, 51.13959386944771, 48.887386322021484, 44.43928800523281, 43.72627146542072, 41.65038965642452, 42.189060151576996, 42.19449386000633, 40.33547021448612, 43.26933078467846, 43.699277713894844, 43.449140936136246, 43.315384313464165, 42.747390791773796, 45.84709346294403, 46.316022500395775, 44.13678243756294, 45.06969317793846, 45.38256078958511, 43.595474883913994, 43.55574041604996, 45.42196847498417, 48.32245923578739, 51.865902096033096, 55.330457389354706, 57.255149111151695, 57.94315919280052, 58.141557946801186, 59.00336690247059, 55.28601877391338, 52.89438150823116, 53.21117430925369, 54.71331350505352, 54.235584139823914, 53.695579916238785, 56.08233444392681, 55.98316356539726, 57.49557740986347, 57.14111343026161, 53.93035411834717, 53.63711625337601, 53.32238294184208, 59.45832408964634, 60.550643876194954, 67.80876740813255, 54.03729557991028, 25.645295083522797, 15.120062213391066, 7.484174827113748, 14.97718608006835, 47.05842286348343, 55.14911971986294, 58.77804659307003, 41.695592030882835, 53.91455836594105, 61.91414371132851, 62.98958860337734, 54.57799896597862, 42.780772000551224, 19.03060432523489, 13.234020117670298, 57.91040875017643, 31.410115845501423, 32.42436312139034, 37.46146783232689, 47.98077017068863, 2.7728214114904404, 1.2427520519122481, 0.09585475490894169, 0.30280076432973146, 0.10364890113123693, 0.06260841662879102, 0.04907100104901474, 0.15951943321852013, 0.08618279694928788, 0.06671752504189499, 0.040828456621966325, 0.09916687093209475, 0.038679449280607514, 0.19203504547476768, 0.05898141105717514, 0.09755367937032133, 0.08006703996215947, 0.13023256411543116, 0.05784305300039705, 0.07419159039272927, 0.025442586811550427, 0.07342758646700531, 0.03408757009310648, 0.035878450362361036, 0.061425032472470775, 0.09574649040587246, 0.019378279212105554, 0.11131321603897959, 0.014491323036054382, 0.12645486916881055, 0.0941833938122727, 0.042872171761700884, 0.1916030709980987, 0.13217826752224937, 0.2126412803772837, 0.5865787400398403, 29.001924768090248, 69.97221931815147, 56.676641553640366, 37.601136937737465, 46.666371300816536, 21.08258731663227, 33.943947181105614, 63.4593839943409, 73.22267889976501, 52.74392478168011, 63.06027241051197, 69.42871928215027, 77.70836859941483, 67.79641807079315, 68.13287481665611, 57.97280140221119, 23.57639729976654, 0.3403266303939745, 11.184273306280375, 53.64425607025623, 76.14426612854004, 74.67234671115875, 72.00573340058327, 66.08103811740875, 63.82522076368332, 54.00265283882618, 60.57924494147301, 67.59469449520111, 70.73874458670616, 64.99376446008682, 65.2323080599308, 66.82391345500946, 64.16241466999054, 66.52967244386673, 67.35656887292862, 69.33865651488304, 67.47125431895256, 65.39262145757675, 66.37729302048683, 63.16728226840496, 64.16129752993584, 61.56192161142826, 63.76625552773476, 60.93331754207611, 64.5165328681469, 59.721980541944504, 56.39163784682751, 58.450743556022644, 51.68482281267643, 47.04864218831062, 48.71164195239544, 46.97571650147438, 46.446374505758286, 47.12822511792183, 44.65388149023056, 44.61175315082073, 44.2212101072073, 46.82788923382759, 47.19977527856827, 56.53359442949295, 56.85531176626682, 60.33986918628216, 53.327980041503906, 57.97969043254852, 63.038005605340004, 57.648921981453896, 58.201241344213486, 58.65586414933205, 61.72789290547371, 60.70674329996109, 58.60519386827946, 58.40935617685318, 55.869519263505936, 54.151677042245865, 55.32734535634518, 55.032340586185455, 50.3549549728632, 46.95530779659748, 47.55695231258869, 44.770079255104065, 44.73301984369755, 45.34990154206753, 44.69628721475601, 47.40884765982628, 46.110210344195366, 46.93730816245079, 45.0184491276741, 45.430913195014, 47.79936030507088, 51.14800661802292, 46.689447462558746, 46.04552261531353, 46.134624034166336, 46.44730165600777, 47.227506190538406, 47.69402235746384, 51.99158035218716, 55.7880250364542, 58.50165702402592, 58.48732799291611, 58.30114558339119, 60.26353508234024, 60.59421233832836, 57.02661417424679, 56.172727793455124, 56.793907061219215, 57.15170346200466, 57.837198078632355, 55.59800863265991, 58.04232247173786, 59.174053743481636, 62.277225628495216, 61.6742017865181, 58.542687222361565, 56.07980377972126, 56.22224673628807, 62.59491518139839, 65.33862635493279, 69.15919974446297, 60.04501260817051, 31.019665896892548, 17.01524566859007, 9.351178519427776, 19.387224689126015, 50.23792125284672, 63.788035959005356, 63.11797611415386, 46.89294174313545, 56.50400921702385, 67.08542302250862, 65.37913218140602, 63.43004196882248, 49.36917386949062, 28.753927275538445, 16.789133101701736, 37.12182305753231, 40.073930248618126, 29.04478646814823, 45.053232461214066, 59.326459765434265, 5.534133715555072, 1.0742025962099433, 0.048633679398335516, 0.347982210223563, 0.10453704409883358, 0.035342831251909956, 0.054137194238137454, 0.09759000749909319, 0.025802198179007974, 0.07398681700578891, 0.07785276815411635, 0.11691649036947638, 0.02204216449172236, 0.08649759372929111, 0.06718711156281643, 0.1423562440322712, 0.28476767416577786, 0.21949507354293019, 0.1330567625700496, 0.16120860585942864, 0.08284561117761768, 0.34080145647749305, 0.1206291806010995, 0.11021700454875827, 0.21151514549273998, 0.21767978032585233, 0.12094137244275771, 0.24148430064087734, 0.20409031421877444, 0.19449844141490757, 0.20110664307139814, 0.19943784980569035, 0.3421578649431467, 0.3266245062695816, 0.5661500862333924, 1.2032068613916636, 50.28278544545174, 86.29077047109604, 72.52055257558823, 47.04414702951908, 60.72392597794533, 29.182534776628017, 32.98249237239361, 69.37736883759499, 82.44486004114151, 62.94371746480465, 72.89639040827751, 74.19215127825737, 84.29757222533226, 71.89190670847893, 73.79030004143715, 63.6309789866209, 25.25909710675478, 0.4165006085531786, 13.024900238960981, 57.367045506834984, 78.78634035587311, 74.85866591334343, 77.32470318675041, 69.25606414675713, 66.04399010539055, 59.04161565005779, 64.6806612610817, 72.32200562953949, 76.56849056482315, 66.5023747086525, 68.15226897597313, 68.78047406673431, 67.80782505869865, 67.69404396414757, 70.10433822870255, 73.98969054222107, 71.44505828619003, 67.57473796606064, 67.64655411243439, 65.68079799413681, 67.80707269906998, 63.35703268647194, 66.00693449378014, 62.30643466114998, 65.72562798857689, 62.642553225159645, 57.94986203312874, 59.08201888203621, 52.731522247195244, 46.612801775336266, 49.449011385440826, 47.82305583357811, 48.97954657673836, 50.348556116223335, 47.49502703547478, 46.16794064640999, 43.81167568266392, 48.51540148258209, 51.433283910155296, 59.825167804956436, 58.88423949480057, 61.013139858841896, 55.03677874803543, 63.29477682709694, 61.233554631471634, 58.84084962308407, 60.66737361252308, 61.66515067219734, 65.57739794254303, 63.401003926992416, 59.862648993730545, 60.1823790371418, 57.47689001262188, 55.67021995782852, 57.292200922966, 58.637013360857964, 55.813343077898026, 49.90182168781757, 51.12452767789364, 47.45137117803097, 45.49472317099571, 48.180232867598534, 44.33171957731247, 48.745365142822266, 48.55268508195877, 50.43758913874626, 47.9232906550169, 46.71931765973568, 50.654869079589844, 54.40248638391495, 49.56879235804081, 49.57580678164959, 51.139521673321724, 49.666424319148064, 51.274118050932884, 49.811595529317856, 53.619937375187874, 56.422317400574684, 61.70111194252968, 60.52933841943741, 62.72851221263409, 60.96367411315441, 63.556521981954575, 59.101523235440254, 56.5308053791523, 59.23890486359596, 60.3161508589983, 61.09216421842575, 56.97324983775616, 61.01568192243576, 59.52355898916721, 64.27699372172356, 63.99957060813904, 61.33826181292534, 58.70248004794121, 58.86122792959213, 66.37184411287308, 69.05112594366074, 68.68380725383759, 62.77797035872936, 33.9021722227335, 18.228049390017986, 11.043693199753761, 21.743894331157207, 54.34682697057724, 67.6680001616478, 67.77854382991791, 53.6904501914978, 62.69022926688194, 70.01068085432053, 71.15581020712852, 70.16048401594162, 54.194793328642845, 25.388020388782024, 15.82232628017664, 74.87948879599571, 44.60275523364544, 45.71496695280075, 52.513945922255516, 77.04923316836357, 16.025007404386997, 1.6504208953119814, 0.18879640207160264, 0.5247461423277855, 0.23344480781815946, 0.23285836272407323, 0.1356103888247162, 0.23167018429376185, 0.16661678440868855, 0.19111460424028337, 0.18755777244223282, 0.20724191854242235, 0.1095191779313609, 0.21858828782569617, 0.17056803801096976, 0.248562608321663], [0.025641042666393332, 0.048687314410926774, 0.030449285732174758, 0.03479619866993744, 0.07683210729737766, 0.03592738758015912, 0.06420810852432624, 0.03938524656405207, 0.05564757979300339, 0.004983988737876643, 0.07647860009456053, 0.02589731739135459, 0.07346370679442771, 0.038240891954046674, 0.061736437637591735, 0.061958792502991855, 0.019398704971536063, 0.026605597158777528, 0.08186605788068846, 0.0399752762314165, 2.781408238224685, 50.302293598651886, 54.29805278778076, 34.02628116309643, 36.930275335907936, 33.3326131850481, 19.794828817248344, 48.704726323485374, 59.071991220116615, 73.96787971258163, 68.84668171405792, 64.86913114786148, 71.79799094796181, 63.35637532174587, 64.81809228658676, 59.12364944815636, 30.045477971434593, 2.5886046839877963, 12.374172806739807, 52.09087662398815, 74.07760262489319, 72.08703383803368, 67.12421894073486, 65.1878048479557, 59.856766909360886, 52.886880710721016, 54.952256083488464, 64.51817438006401, 69.02394980192184, 67.97492489218712, 63.46729137003422, 64.32426318526268, 65.73799252510071, 66.35220676660538, 64.83551815152168, 64.74422425031662, 65.34732028841972, 63.56276884675026, 60.545628145337105, 59.18747462332249, 56.01249039173126, 57.707712426781654, 58.65639232099056, 63.07225316762924, 64.13001760840416, 60.85391700267792, 56.39150105416775, 46.56482174992561, 45.917112305760384, 45.21506577730179, 46.562378481030464, 45.44006310403347, 44.13213528692722, 44.86204192042351, 42.51910284161568, 40.44262446463108, 41.255701035261154, 40.06946548819542, 45.39082534611225, 51.452233493328094, 58.67663763463497, 56.00648671388626, 51.037443950772285, 62.60227158665657, 52.79183641076088, 58.427978977561, 55.183982849121094, 59.25681710243225, 55.87938353419304, 56.79616793990135, 56.97745621204376, 55.378931388258934, 53.940434977412224, 54.88074392080307, 54.08326171338558, 51.125595420598984, 52.58112631738186, 43.4491903334856, 41.868999525904655, 42.84579411149025, 40.6223776191473, 42.1489305049181, 42.59773962199688, 42.97955833375454, 41.03522926568985, 44.081518203020096, 42.79981277883053, 47.13618569076061, 48.76288220286369, 46.489703580737114, 47.17146299779415, 45.5435885488987, 47.270842865109444, 46.1249041557312, 43.03076818585396, 45.877032056450844, 46.95344589650631, 50.093453004956245, 51.821455880999565, 56.91452398896217, 58.7402918189764, 57.64083981513977, 62.4532625824213, 60.65762713551521, 54.733186438679695, 47.82997906208038, 45.43334126472473, 49.81807418167591, 55.945967361330986, 57.279904782772064, 59.76059786975384, 58.96386422216892, 57.5385645031929, 54.81076307594776, 53.3923713862896, 53.22510056197643, 57.370674312114716, 61.195309683680534, 65.85112005472183, 60.52335374057293, 44.92296785116196, 24.756800159811974, 11.68051527813077, 19.948815554380417, 48.58562171459198, 59.12258930504322, 54.97438229620457, 55.40940195322037, 63.500243201851845, 64.84022989869118, 58.017046228051186, 52.163205742836, 44.2667430639267, 13.12359994277358, 31.777107752859592, 38.98607902228832, 28.46849799156189, 32.04292058944702, 47.10441939532757, 35.431605353951454, 1.3357258192263544, 0.11475198698462918, 0.18438267172314227, 0.14385192393092439, 0.11321850208332762, 0.168012541544158, 0.043307597225066274, 0.036992068926338106, 0.0704667586251162, 0.07292021720786579, 0.04418627038830891, 0.036294249730417505, 0.08768092593527399, 0.07748021744191647, 0.09688398014986888, 0.012197786145407008, 0.0044938646715309005, 0.08000598347280174, 0.08732172645977698, 0.09196060214890167, 0.041532495015417226, 0.05333358560164925, 0.06599088083021343, 0.08719136822037399, 0.05421603629656602, 0.02387506145169027, 0.09508328497759067, 0.03611616026319098, 0.10213106070295908, 0.05129117664182559, 0.05244942796707619, 0.017982006284000818, 0.062430983962258324, 0.08163022561348043, 0.04134496171900537, 0.05258172321191523, 4.534026430919766, 62.59727105498314, 63.87637361884117, 36.90602503716946, 43.768335208296776, 33.639974892139435, 21.462585926055908, 60.226373076438904, 59.44871060550213, 76.15717023611069, 69.7463670372963, 71.1343565583229, 75.96946030855179, 68.49785283207893, 67.76375502347946, 64.25531208515167, 32.760082706809044, 3.3627874916419387, 12.697167824953794, 54.08492602407932, 75.65658509731293, 74.8582935333252, 71.31664037704468, 68.59705790877342, 64.24900442361832, 57.40089029073715, 58.03597301244736, 66.701240837574, 69.94653269648552, 69.28761005401611, 63.486643731594086, 64.50522467494011, 68.56574758887291, 69.39477190375328, 68.48363399505615, 67.6773552596569, 67.90563181042671, 67.66703501343727, 61.93558596074581, 60.821842923760414, 59.245474711060524, 59.356010779738426, 61.31113886833191, 63.578921779990196, 65.06951719522476, 61.55138857662678, 57.23100520670414, 50.04263073205948, 48.27284149825573, 46.67217738926411, 46.97843335568905, 47.83118359744549, 46.9594419747591, 46.89914681017399, 44.64741803705692, 43.516119942069054, 45.880239084362984, 44.412545040249825, 49.18158933520317, 55.96990987658501, 59.44564417004585, 59.89362873136997, 54.17413763701916, 64.54798758029938, 58.407087698578835, 61.092734187841415, 57.8214555233717, 62.070794105529785, 59.79782447218895, 58.043808192014694, 60.51085241138935, 60.19855096936226, 56.096040308475494, 57.09712319076061, 54.65846724808216, 55.0090554356575, 54.784852266311646, 45.40961153805256, 43.530543968081474, 46.00746005773544, 43.83152201771736, 43.23534160852432, 46.443441063165665, 47.00007699429989, 44.561633840203285, 46.557054966688156, 45.60881964862347, 49.4227509945631, 50.00674545764923, 49.94206912815571, 48.358933478593826, 47.53868669271469, 50.09589247405529, 47.87808068096638, 46.017442122101784, 46.578261628746986, 51.62795886397362, 53.76309849321842, 53.799150958657265, 58.63257519900799, 60.4541252553463, 59.11591686308384, 65.50279274582863, 65.33474296331406, 56.91769301891327, 53.37390057742596, 50.91668263077736, 53.90386573970318, 57.73548513650894, 62.0064939558506, 62.016616612672806, 61.93674869835377, 61.37983538210392, 57.51517675817013, 55.85000351071358, 57.15720176696777, 61.20931573212147, 65.29964804649353, 68.46417903900146, 63.80477786064148, 49.0949197858572, 27.779017388820648, 16.677073314785957, 23.9527690038085, 52.069920748472214, 66.331307888031, 59.639471769332886, 61.84700511395931, 66.27672001719475, 70.79663828015327, 64.0536493062973, 63.988961577415466, 46.502790078520775, 22.275210320949554, 22.103303745388985, 38.777386620640755, 37.52006448805332, 28.096399158239365, 57.58070424199104, 41.405526995658875, 1.8927918397821486, 0.14581346476916224, 0.18103548180079088, 0.1323024436715059, 0.03259396078647114, 0.07524907661718316, 0.0694021477829665, 0.05418915570771787, 0.02800943999318406, 0.06582507019629702, 0.05150993209099397, 0.042228670354234055, 0.04391156442579813, 0.08826766046695411, 0.02377808872552123, 0.04840072666411288, 0.11581427490455098, 0.21751595864770934, 0.1797670326777734, 0.16763732652179897, 0.15424071490997449, 0.08930657073506154, 0.1314697094494477, 0.1542322544264607, 0.17920690414030105, 0.08745153550989926, 0.23610300268046558, 0.18402351677650586, 0.27391052863094956, 0.13481896254234016, 0.2032225060975179, 0.08798231210676022, 0.11117230445961468, 0.16545662947464734, 0.20360622613225132, 0.13348158274311572, 8.540049344301224, 84.99489560723305, 74.57419037818909, 49.324951842427254, 54.28259901702404, 48.897041603922844, 23.90400242060423, 64.00830253958702, 64.45854038000107, 85.72388648986816, 76.74798533320427, 78.45587208867073, 79.30166110396385, 73.51372048258781, 72.01033115386963, 69.52869191765785, 35.49028180539608, 4.0198608208447695, 13.516846541315317, 58.354471921920776, 80.60785621404648, 79.0248915553093, 73.24808433651924, 71.7448166012764, 66.51338651776314, 59.957294315099716, 62.876749858260155, 70.67956656217575, 74.60609346628189, 71.53079688549042, 63.32022786140442, 66.71893268823624, 70.25158792734146, 72.77040436863899, 71.91619500517845, 69.43731442093849, 73.75515192747116, 71.37220859527588, 65.48842951655388, 65.25570720434189, 61.722280606627464, 61.06504887342453, 62.93154291808605, 66.26266077160835, 67.66939088702202, 64.23831939697266, 60.755506083369255, 51.410454735159874, 49.78692725300789, 47.72793173789978, 50.33057548105717, 49.4550758600235, 48.783309906721115, 49.70658056437969, 46.79922737181187, 44.88986022770405, 46.93202644586563, 46.33677698671818, 51.825324073433876, 58.02851781249046, 63.48818264901638, 65.46208173036575, 58.11175994575024, 64.72455650568008, 59.01225082576275, 65.11189252138138, 59.60358649492264, 64.54229548573494, 60.221820920705795, 60.45748047530651, 62.47519500553608, 61.50978080928326, 58.231871500611305, 58.93919974565506, 57.93719731271267, 58.49962033331394, 59.618968069553375, 48.76847930252552, 45.336530059576035, 47.8974786400795, 44.17405463755131, 46.595102325081825, 48.2468318939209, 50.19798159599304, 45.893420577049255, 48.08628290891647, 46.49977684020996, 51.6226277500391, 52.9045345634222, 50.79863056540489, 51.2679547816515, 51.85457110404968, 53.93167644739151, 53.08245241641998, 48.57455290853977, 51.463895067572594, 52.54522584378719, 55.42291022837162, 56.167943850159645, 61.835465133190155, 63.30044612288475, 59.63259033858776, 68.52467939257622, 67.37684458494186, 60.076007544994354, 56.10296733677387, 56.80819049477577, 57.49836266040802, 59.19632814824581, 64.05041947960854, 66.32932439446449, 64.53186124563217, 64.01148676872253, 61.37929581105709, 59.620666578412056, 60.22478096187115, 65.0941550731659, 68.71043622493744, 74.13671985268593, 65.84272250533104, 53.856562077999115, 29.349296428263187, 18.68959542363882, 26.596093364059925, 57.028730660676956, 70.8533388376236, 64.23138856887817, 66.86774030327797, 70.44837936758995, 74.54034179449081, 70.16483098268509, 68.83780539035797, 53.55549283325672, 16.441187672317028, 36.523313373327255, 56.07122004032135, 42.38897882401943, 45.85373170673847, 62.966223657131195, 64.01495978236198, 3.3988957665860653, 0.25586942327208817, 0.23161197023000568, 0.19489099300699309, 0.21041492640506476, 0.18536665564170107, 0.16142614418640733, 0.15952710702549666, 0.15772146172821522, 0.3002455795649439, 0.09855375305050984, 0.1579220048733987, 0.16645425406750292, 0.2478864969452843, 0.2652347629191354, 0.1256036406266503], [0.1105924867442809, 0.05537833603739273, 0.07280646823346615, 0.0035814265720546246, 0.05549506844545249, 0.03996656341769267, 0.008538244819646934, 0.05247530665656086, 0.022818504767201375, 0.06326914328383282, 0.12874075822765008, 0.04027718932775315, 0.039349322905763984, 0.02638255580677651, 0.03267296982812695, 0.038130727552925237, 0.04896938247838989, 0.0653561441868078, 0.05203999993682373, 0.20318801107350737, 0.4758855141699314, 32.59571112692356, 61.62744149565697, 47.38180451095104, 41.392235308885574, 47.36069664359093, 21.973331719636917, 35.996711030602455, 86.87335520982742, 80.76440021395683, 71.99878737330437, 67.22691223025322, 60.182177647948265, 60.44494494795799, 59.39203664660454, 61.49200156331062, 39.843651205301285, 4.045839551836252, 7.974785976111889, 52.272750064730644, 66.33946985006332, 74.81589540839195, 65.76485708355904, 63.50897513329983, 64.55491080880165, 58.35338898003101, 55.55982448160648, 68.81874561309814, 64.36634972691536, 69.16591018438339, 60.182572826743126, 67.82796397805214, 63.143396750092506, 64.60164070129395, 63.90566244721413, 65.29913127422333, 61.97203740477562, 58.24060343205929, 56.0995627194643, 52.82230697572231, 52.67842769622803, 56.16132080554962, 61.831821128726006, 60.38512475788593, 60.788735300302505, 58.60946483910084, 47.92371243238449, 48.155374601483345, 47.235994935035706, 44.45678226649761, 48.65170396864414, 48.8574705272913, 44.33878339827061, 42.336389645934105, 42.87746161222458, 40.991132631897926, 40.502851232886314, 42.329443618655205, 48.673400804400444, 54.41952086985111, 54.35481794178486, 47.566577196121216, 60.676048547029495, 59.138096272945404, 53.524212911725044, 56.430285573005676, 56.09616570174694, 57.33382388949394, 56.119948625564575, 55.90870276093483, 57.27597579360008, 57.07586333155632, 54.840694069862366, 54.010222032666206, 54.17190335690975, 50.67218095064163, 51.56333573162556, 49.041088074445724, 43.55805829167366, 41.9407244771719, 41.4774077385664, 40.97066693007946, 41.15475185215473, 42.40184873342514, 42.65674285590649, 42.847469821572304, 44.68835324048996, 48.39202590286732, 48.85991379618645, 48.12891662120819, 46.80453568696976, 45.447183921933174, 44.10482235252857, 44.61735785007477, 44.91450570523739, 45.697256103158, 46.164551228284836, 46.81789956986904, 49.12398062646389, 50.62199704349041, 54.55174997448921, 57.53224544227123, 58.77993509173393, 61.33467100560665, 60.788708701729774, 54.154420495033264, 43.230618461966515, 37.44087673723698, 46.06587052345276, 55.54000474512577, 56.23811088502407, 53.673206716775894, 55.06949879229069, 56.6009496152401, 52.11529791355133, 53.92982214689255, 56.6199903935194, 59.92431968450546, 62.945746555924416, 58.810584247112274, 49.23621140420437, 34.60698500275612, 20.60941580682993, 26.96556843817234, 46.40257425606251, 60.88606707751751, 57.237415462732315, 54.66006316244602, 60.77505223453045, 62.55378998816013, 55.97715608775616, 55.00904783606529, 18.55480905622244, 11.832663863897324, 46.60241313278675, 28.91963068395853, 27.564883679151535, 31.790901012718678, 50.49899384379387, 11.868627034127712, 0.9442775335628539, 0.08878693377482705, 0.29516228358261287, 0.09835740303969942, 0.12551297986647114, 0.09600966339348815, 0.18909841164713725, 0.006909243656991748, 0.10798757066368125, 0.11044600163586438, 0.04317422957683448, 0.0827931116509717, 0.13683772296644747, 0.06189935389556922, 0.07033256348222494, 0.06333630022709258, 0.0562354238354601, 0.01350997838017065, 0.06731980756740086, 0.014315017506305594, 0.07887395593570545, 0.024424992880085483, 0.07270246365806088, 0.02352149302168982, 0.030011127309990115, 0.03976421314291656, 0.08352619770448655, 0.003745046246876882, 0.16329551028320566, 0.02892858989071101, 0.03143141984764952, 0.09563644474837929, 0.037079835310578346, 0.01026912152156001, 0.022780679355491884, 0.2460245374822989, 0.39340295421425253, 34.17142577469349, 79.2140682041645, 47.312921807169914, 48.3443308621645, 42.10789270699024, 27.508658096194267, 38.364645168185234, 85.02636551856995, 84.36452463269234, 76.24831974506378, 71.5980912744999, 65.13365015387535, 66.32113203406334, 64.88423153758049, 67.67501458525658, 45.05673207342625, 4.07335720025003, 8.56608934700489, 54.39295269548893, 69.41401407122612, 78.38548466563225, 67.2479023039341, 66.54240936040878, 66.96953684091568, 61.09381712973118, 59.26102727651596, 71.53022691607475, 70.80117523670197, 69.20218303799629, 62.05664746463299, 69.76708352565765, 66.51068866252899, 66.32655814290047, 65.58619067072868, 68.31814527511597, 62.34188675880432, 60.92356726527214, 59.67405751347542, 56.46604925394058, 54.67147774994373, 59.161936193704605, 63.84125590324402, 62.449147403240204, 62.67460070550442, 62.559717670083046, 51.69214881956577, 49.563883021473885, 48.05229373276234, 47.00537770986557, 49.48467627167702, 48.1939235329628, 46.38266332447529, 44.61602412164211, 46.326517537236214, 44.47026774287224, 44.90564078092575, 46.896426156163216, 54.04624789953232, 59.60746228694916, 61.308836191892624, 50.425551384687424, 61.029714569449425, 61.4610256254673, 57.538473308086395, 58.886656165122986, 58.807882592082024, 61.681900173425674, 58.234204575419426, 59.22424145042896, 60.61445765197277, 59.28065702319145, 56.42082408070564, 57.92769782245159, 57.086859941482544, 54.27396968007088, 55.633821710944176, 50.816007032990456, 45.60725413262844, 44.5833420753479, 44.818511456251144, 43.929856941103935, 43.46543446183205, 45.31998574733734, 47.1004182100296, 46.26393109560013, 46.358872801065445, 49.90551508963108, 52.1916738152504, 50.949376076459885, 46.93038113415241, 48.22550743818283, 49.16531100869179, 48.60437370836735, 48.714115619659424, 49.124489799141884, 48.94697852432728, 49.9075897783041, 51.6076185554266, 53.955090790987015, 55.481484085321426, 60.56925527751446, 60.65630100667477, 62.018254324793816, 63.07886481285095, 56.8565770983696, 50.40538586676121, 44.769786670804024, 50.90366452932358, 60.652277022600174, 60.02773113548756, 58.55980910360813, 59.97943572700024, 59.41351689398289, 55.198870450258255, 55.19740752875805, 59.615221470594406, 63.21124590933323, 67.41874873638153, 63.6222318559885, 52.17863671481609, 38.11844877898693, 24.837036654353142, 30.147644989192486, 49.83199283480644, 66.29415348172188, 63.40166889131069, 59.463791996240616, 67.67600253224373, 68.14890995621681, 64.21939641237259, 61.00540727376938, 27.766151279211044, 17.25320030003786, 30.0470282882452, 38.18580776453018, 28.519232869148254, 37.36708849668503, 63.714639097452164, 13.461169078946114, 0.9672046126797795, 0.022683561910525896, 0.2848881098907441, 0.060788069386035204, 0.05367637990275398, 0.03544793420587666, 0.14612078812206164, 0.02373605533648515, 0.0681202212581411, 0.013076312734483508, 0.041153242709697224, 0.026498787265154533, 0.05792960226244759, 0.04679426638176665, 0.042212569460389204, 0.006323883026198018, 0.19397593976464123, 0.12785405502654612, 0.17653290153248236, 0.07292629539733753, 0.16870270919753239, 0.10523930133786052, 0.1481734201661311, 0.16547116072615609, 0.13621506106574088, 0.23765478894347325, 0.22281661484157667, 0.11227006703848019, 0.26459761429578066, 0.12687584501691163, 0.2701904688728973, 0.14355073071783409, 0.16182230261620134, 0.11137519279145636, 0.23823293682653457, 0.4260693263495341, 0.9076404932420701, 57.22165770828724, 90.61332732439041, 64.04478058218956, 64.22828793525696, 65.16499847173691, 28.04775606840849, 44.03213605284691, 92.66127303242683, 93.45451846718788, 80.33565402030945, 79.26220402121544, 72.75478720664978, 78.91760811209679, 71.40912741422653, 73.07562679052353, 47.87917122244835, 5.600853860378265, 9.21488268300891, 58.39717023074627, 72.26423352956772, 82.02730044722557, 70.73820501565933, 70.6417053937912, 68.7326118350029, 65.8848774433136, 63.341996893286705, 76.97428598999977, 74.67743843793869, 73.5243447124958, 61.830464601516724, 74.20763164758682, 69.37156274914742, 70.06848335266113, 70.1612363755703, 74.52502101659775, 64.31106269359589, 65.02080380916595, 62.06340350210667, 59.04989920556545, 57.66199707984924, 62.35822208225727, 65.68976551294327, 64.64020863175392, 63.571854159235954, 62.51788191497326, 50.66466875374317, 50.20815744996071, 50.586252361536026, 47.88970045745373, 50.73416322469711, 51.701325327157974, 48.857151344418526, 47.830967009067535, 49.8512502014637, 46.890851855278015, 45.71916572749615, 49.04309816658497, 57.63427376747131, 60.34258224070072, 63.06049279868603, 54.172249138355255, 61.60525068640709, 63.27258221805096, 60.42457424104214, 61.99379503726959, 60.03680504858494, 61.916491985321045, 61.18884243071079, 60.61861842870712, 65.03104045987129, 60.58263435959816, 59.66906078159809, 57.94626362621784, 60.32955653965473, 55.38312256336212, 57.36587516963482, 55.07117450237274, 49.538036808371544, 45.51355496048927, 46.62688381969929, 45.688945949077606, 46.1000344902277, 46.48588478565216, 47.813909724354744, 48.432850912213326, 47.27957099676132, 51.26650705933571, 54.41435694694519, 53.489269986748695, 50.52790269255638, 52.67962083220482, 50.49010992050171, 50.64046025276184, 52.24504955112934, 52.798375859856606, 52.57340133190155, 52.03566178679466, 54.89558592438698, 57.14266374707222, 58.16401854157448, 63.97015258669853, 64.46349531412125, 66.65871351957321, 66.39491647481918, 61.70819476246834, 56.5793401747942, 52.598453387618065, 55.52328184247017, 62.06367328763008, 60.43100729584694, 62.09669731557369, 63.8780303299427, 63.22658188641071, 57.58325770497322, 60.43906286358833, 62.36136071383953, 66.80893465876579, 67.6692920923233, 68.13563346862793, 59.06007505953312, 41.301990151405334, 28.355406560003757, 33.289660289883614, 55.56903898715973, 70.34544289112091, 68.06345254182816, 63.036899864673615, 71.42248749732971, 72.0686200261116, 70.84532126784325, 69.34924274682999, 27.376881167292595, 13.916208911687136, 59.14912328124046, 42.732442393898964, 39.38957937061787, 49.261814430356026, 72.71685764193535, 27.2158021107316, 1.1178329237736762, 0.1702193621895276, 0.3998277860227972, 0.1733551439247094, 0.35719968436751515, 0.13628976565087214, 0.2567573287524283, 0.15001587598817423, 0.19729736231965944, 0.17895268887514248, 0.12761679041432217, 0.18561059958301485, 0.20974855200620368, 0.1722179213538766, 0.10436954136821441, 0.195781510847155], [0.019713605652214028, 0.03537112192134373, 0.02570680808275938, 0.083619804790942, 0.002267610657327168, 0.00936382844884065, 0.06198878640134353, 0.018131116739823483, 0.04180219519184902, 0.0495998295082245, 0.08236946407123469, 0.04159894320764579, 0.07483088382286951, 0.01898345293739112, 0.033481899663456716, 0.038074550684541464, 0.017659556106082164, 0.07435344537952915, 0.19471646955935284, 0.3665473312139511, 0.0720324824214913, 7.65811619348824, 72.37723186612129, 51.66967682540417, 43.80247637629509, 59.054284170269966, 31.79121259599924, 19.620606265962124, 56.52141608297825, 74.39448282122612, 72.01531648635864, 75.92836931347847, 67.2482442855835, 63.54182057082653, 58.44621799886227, 58.91095206141472, 47.14494802057743, 9.333663359284401, 6.767733721062541, 45.109648033976555, 67.63213768601418, 73.11663419008255, 69.59898054599762, 62.86273621022701, 59.8816479742527, 56.30424253642559, 55.51180645823479, 66.7212201654911, 70.73616832494736, 66.58868327736855, 63.37493732571602, 65.60512885451317, 62.813414856791496, 62.22898341715336, 57.591408267617226, 53.03363263607025, 53.43239463865757, 52.52647764980793, 49.52019676566124, 49.68301422894001, 51.83695524930954, 57.304052487015724, 60.10213114321232, 59.890433102846146, 59.2046383023262, 50.85571490228176, 48.78452204167843, 46.9729046523571, 49.369002878665924, 50.14303274452686, 50.4937881231308, 49.98149961233139, 48.61662805080414, 46.00415803492069, 40.70028103888035, 43.233517706394196, 41.55110478401184, 44.23077039420605, 49.08407896757126, 59.24299344420433, 47.08014629781246, 55.79194262623787, 62.21029981970787, 56.944770365953445, 58.58828477561474, 55.21879658102989, 60.439621433615685, 57.76643067598343, 60.37507429718971, 55.52818737924099, 58.885231241583824, 55.51498308777809, 53.546190932393074, 53.072223365306854, 53.36657077074051, 51.89414218068123, 52.26444371044636, 51.80624149739742, 43.9596701413393, 43.285852298140526, 41.749932914972305, 42.81004182994366, 41.368087604641914, 43.04644234478474, 42.362201660871506, 44.890156611800194, 46.317059844732285, 50.717322528362274, 49.72803421318531, 47.4717228859663, 46.41353666782379, 45.90977489948273, 45.75336009263992, 48.478376269340515, 53.29587936401367, 51.81579038500786, 49.97894234955311, 50.771895200014114, 51.000475734472275, 51.87535598874092, 51.19451232254505, 52.14053235948086, 57.661681696772575, 59.41845662891865, 63.24428133666515, 65.71014001965523, 58.218674808740616, 43.638214990496635, 31.92437455058098, 35.499572306871414, 45.40224373340607, 51.525850743055344, 56.01814828813076, 54.201043993234634, 52.7623575925827, 53.62531028687954, 55.92139407992363, 61.24058425426483, 63.79850819706917, 57.809733152389526, 51.533682122826576, 41.445538848638535, 29.566838555037975, 35.749264508485794, 43.952435329556465, 62.109244242310524, 59.37151774764061, 57.6111102104187, 62.75995932519436, 62.03460864722729, 57.47665822505951, 43.259937688708305, 7.625286905094981, 28.83828464895487, 43.46312418580055, 21.826144717633724, 29.192438945174217, 35.21678388118744, 45.628377199172974, 1.7447047610767186, 0.06594070422579534, 0.14980572945205495, 0.14699300460051745, 0.14868265221593902, 0.1233785186195746, 0.10223270524875261, 0.02448603823722806, 0.05070456085377373, 0.0940702756633982, 0.04610131938534323, 0.011119066148239654, 0.03300705131550785, 0.05898789000639226, 0.16969347634585574, 0.06624418325372972, 0.06563995630131103, 0.030036050484341104, 0.026328223175369203, 0.006460166387114441, 0.07355499095865525, 0.019882895103364717, 0.007821194722055225, 0.08222576201660559, 0.01259166525414912, 0.038911017909413204, 0.019220290814701002, 0.06333146142424084, 0.05419535264081787, 0.0555324689776171, 0.013083548674330814, 0.019572393503040075, 0.05486660294991452, 0.014347661799547495, 0.08611988509073853, 0.19386250991374254, 0.4925912286853418, 0.25438806682359427, 6.529829436913133, 83.27266842126846, 58.59507121145725, 47.78441570699215, 59.784924164414406, 35.13993680477142, 32.69443742930889, 58.711850345134735, 81.23395621776581, 73.58188882470131, 80.23300632834435, 71.20136216282845, 69.74342599511147, 64.74594935774803, 63.74463468790054, 52.88099482655525, 9.429955892264843, 7.013004859909415, 46.37287884950638, 70.36454066634178, 78.96946772933006, 74.3494476377964, 66.6295538842678, 64.04814720153809, 59.18270967900753, 57.50543028116226, 71.59127444028854, 73.23738411068916, 68.62400606274605, 65.65170675516129, 68.97499322891235, 66.66407883167267, 64.57955628633499, 61.67366221547127, 55.15973635017872, 57.970593720674515, 56.40207588672638, 52.02546313405037, 50.612885132431984, 55.00397890806198, 57.28921428322792, 61.959615871310234, 62.704516500234604, 62.45239622890949, 54.30122181773186, 51.29669263958931, 49.3582646548748, 48.70941907167435, 51.0649848729372, 52.13086947798729, 52.34901577234268, 49.506977275013924, 48.68779443204403, 44.60622824728489, 45.74327163398266, 45.81809721887112, 47.81234420835972, 52.97785922884941, 62.26686738431454, 52.43300646543503, 57.30330392718315, 66.32140561938286, 58.55516575276852, 62.58027836680412, 57.425528168678284, 63.4116243571043, 61.27432644367218, 62.85175859928131, 61.066716983914375, 61.90704949200153, 59.20115388929844, 56.18909731507301, 55.33015340566635, 57.03338161110878, 55.47926880419254, 55.12899599969387, 52.646672800183296, 44.84418287873268, 46.89541541039944, 44.39224652945995, 44.134418964385986, 44.4776925444603, 45.123281702399254, 45.607250332832336, 46.513106524944305, 48.26542429625988, 51.35046735405922, 51.855429857969284, 51.18663914501667, 50.84127567708492, 48.84214214980602, 49.09541755914688, 51.91395051777363, 55.65814420580864, 54.715023413300514, 53.798250406980515, 53.57213594019413, 53.270979300141335, 54.45183053612709, 54.0918530523777, 54.434108287096024, 58.640170991420746, 62.41769649088383, 63.95908758044243, 64.5996268093586, 63.38682308793068, 48.039051443338394, 37.23790682852268, 40.701367780566216, 49.58535186946392, 57.52051167190075, 60.381070375442505, 57.936216965317726, 55.45553907752037, 55.48025295138359, 60.339850187301636, 62.914782017469406, 65.6997361779213, 63.74313376843929, 55.867786556482315, 43.915501311421394, 33.68105448782444, 38.753926679492, 52.727741450071335, 67.28463873267174, 66.42163664102554, 64.0135994553566, 70.84462970495224, 66.80828869342804, 64.4640576839447, 50.86060903966427, 17.474086247384548, 22.76195280253887, 32.522131875157356, 29.7578714042902, 27.00904570519924, 44.73471835255623, 53.08160126209259, 2.7426256192848086, 0.17619854916119948, 0.07158519001677632, 0.2080203572404571, 0.018119978958566207, 0.009885262334137224, 0.06443087157094851, 0.027867866047017742, 0.02877985421946505, 0.06662735409918241, 0.07530515329563059, 0.04795948276296258, 0.055266835770453326, 0.01606809648365015, 0.03548016567947343, 0.04714015172794461, 0.05647653277264908, 0.10794716072268784, 0.19398952106712386, 0.10179119417443871, 0.20031226304126903, 0.1273528827005066, 0.13111082167597488, 0.2536845108261332, 0.21891564916586503, 0.1750073576113209, 0.11760569323087111, 0.17315770295681432, 0.10950358540867455, 0.3037877316819504, 0.27368423296138644, 0.11182998088770546, 0.18672319769393653, 0.11698578469804488, 0.18587766884593293, 0.3803410957334563, 0.8499255089554936, 0.5064508959185332, 15.446142666041851, 96.77057772874832, 70.6146964430809, 59.07606840133667, 78.1402838230133, 42.60310873389244, 26.32837872952223, 64.73440557718277, 83.16504299640656, 79.94174435734749, 84.83951434493065, 79.00060325860977, 74.62757751345634, 70.41370242834091, 69.72843199968338, 58.495550751686096, 11.691853869706392, 7.967984341084957, 47.70972691476345, 73.20990398526192, 82.05741763114929, 76.47029623389244, 67.71197900176048, 68.22433590888977, 61.86349242925644, 62.8252512216568, 74.33462843298912, 78.85393112897873, 70.99803507328033, 68.38366135954857, 72.18533456325531, 68.57213884592056, 69.44407045841217, 64.49284493923187, 56.21903210878372, 60.72039216756821, 59.90345500409603, 55.55098995566368, 54.26094777882099, 56.464730724692345, 60.65128147602081, 64.48576971888542, 65.71409180760384, 63.83287355303764, 56.15102715790272, 53.07598516345024, 50.77893242239952, 53.201614022254944, 54.74362827837467, 53.411115780472755, 54.069312661886215, 53.08267280459404, 52.759264558553696, 47.21310876309872, 49.01630960404873, 46.28915794193745, 50.1152828335762, 55.285847783088684, 66.20779931545258, 56.391223669052124, 59.273988381028175, 65.22951140999794, 62.30119854211807, 65.7180967926979, 59.19509321451187, 65.61457514762878, 61.27671271562576, 66.85580894351006, 60.540775805711746, 63.19411642849445, 60.893180295825005, 58.60066831111908, 58.26405957341194, 58.322690427303314, 58.08055222034454, 58.81831683218479, 57.30776108801365, 47.04280950129032, 49.031132608652115, 46.407134011387825, 46.755921095609665, 46.87353618443012, 48.241812363266945, 46.332923993468285, 49.21080596745014, 49.633958861231804, 54.124732688069344, 54.00309361517429, 53.67853783071041, 52.236298620700836, 50.749985575675964, 51.134464144706726, 55.80605886876583, 61.34368032217026, 58.36036540567875, 57.13592670857906, 56.91794380545616, 57.11562819778919, 56.04568541049957, 56.6245311498642, 58.00798751413822, 62.034597247838974, 65.47478824853897, 67.97575324773788, 70.59712618589401, 67.10585832595825, 51.911796033382416, 43.68298418819904, 46.56776659190655, 53.86620596051216, 60.42463883757591, 66.20540544390678, 62.5239197909832, 59.698683992028236, 59.191665798425674, 64.59477826952934, 67.83440083265305, 70.04627734422684, 67.86428242921829, 62.62839138507843, 48.62012766301632, 38.193631544709206, 41.99410021305084, 56.29060506820679, 72.93935850262642, 69.99104350805283, 67.29620531201363, 73.02021816372871, 73.64441066980362, 71.17590352892876, 56.060770601034164, 12.30194153264165, 32.82473623752594, 62.62116797268391, 34.940641298890114, 42.94643171131611, 51.79287001490593, 72.45885908603668, 5.655938079580665, 0.3803770453669131, 0.18252724315971136, 0.38958552468102425, 0.15078122320119292, 0.19947127613704652, 0.1352955400943756, 0.17767537850886583, 0.17368149594403803, 0.18867951381253079, 0.105989115400007, 0.18290621344931424, 0.16139299987116829, 0.22199560655280948, 0.29938186809886247, 0.3521652810741216, 0.12831127736717463], [0.03542561040376313, 0.04845152667257935, 0.05316128117556218, 0.11106078934972174, 0.04000171895313542, 0.08538262074580416, 0.07314975606277585, 0.0802270470012445, 0.01193114454508759, 0.019200716669729445, 0.06056432299374137, 0.012492517107602907, 0.049128168684546836, 0.054469694950967096, 0.16407586372224614, 0.045244383727549575, 0.08033419828279875, 0.04666675427870359, 0.00767350501519104, 0.09196581202559173, 0.26108948222827166, 0.514804272679612, 47.381344735622406, 63.06843437254429, 37.03776776790619, 38.603500351309776, 56.527947932481766, 11.803763564676046, 35.704331919550896, 75.30062019824982, 77.10309907793999, 66.19665831327438, 71.42998829483986, 71.48506253957748, 64.30701211094856, 61.907342076301575, 55.445766001939774, 13.961169049143791, 8.074768111109734, 35.569435358047485, 58.7427768856287, 78.75145062804222, 70.59204965829849, 64.05363410711288, 60.15457592904568, 53.967105746269226, 55.71630388498306, 66.84724420309067, 68.47341254353523, 66.85411423444748, 65.03125324845314, 64.49050426483154, 63.949420899152756, 57.79687084257603, 54.060367941856384, 58.34672413766384, 63.401516899466515, 62.614727318286896, 62.471486404538155, 54.68801826238632, 54.96639132499695, 56.5833755582571, 58.993244245648384, 58.17520514130592, 51.423533633351326, 48.2245384901762, 50.63326343894005, 54.678450375795364, 59.8452915251255, 56.30960024893284, 57.97935985028744, 54.224378541111946, 51.714738607406616, 43.53077195584774, 41.94202400743961, 40.3474585711956, 42.44722209870815, 44.302267357707024, 53.845181688666344, 53.73451642692089, 49.488457068800926, 63.29701870679855, 55.96134893596172, 56.88327446579933, 59.089200496673584, 57.122798413038254, 57.2069600969553, 57.994331046938896, 59.679259434342384, 58.537181317806244, 55.9560140222311, 55.072120651602745, 51.67820356786251, 52.08939850330353, 53.96228760480881, 53.504807353019714, 54.00833733379841, 53.90624441206455, 46.691168770194054, 42.014185935258865, 43.892786130309105, 42.011784464120865, 42.32314355671406, 42.79796227812767, 41.68920077383518, 45.6180227547884, 49.337369576096535, 48.501957803964615, 47.81840868294239, 47.53810152411461, 44.69133608043194, 47.426816895604134, 52.80474431812763, 55.22426448762417, 55.76763153076172, 56.238585859537125, 55.748127177357674, 56.24856412410736, 57.62293517589569, 56.33037373423576, 54.37381312251091, 54.90043066442013, 51.9616873562336, 57.62779891490936, 59.571349024772644, 63.07685852050781, 68.24585035443306, 60.825110748410225, 44.8375940322876, 28.330854177474976, 35.7933459430933, 54.69621442258358, 61.92773178219795, 55.29343977570534, 53.98563735187054, 53.28227989375591, 58.685422763228416, 60.044074058532715, 61.912574395537376, 63.19445081055164, 58.27930435538292, 41.90105840563774, 37.45409242808819, 30.486670397222042, 45.751536190509796, 56.69528715312481, 52.99972325563431, 56.01385451853275, 66.29212439060211, 58.335073962807655, 63.57725366950035, 26.41721986234188, 9.764676131308079, 45.87046600878239, 31.880897283554077, 42.092503532767296, 37.51077778637409, 40.28978906571865, 22.830221839249134, 1.45555654540658, 0.12391630109050311, 0.3013595729134977, 0.08255243315943517, 0.22558317810762674, 0.08417942124651745, 0.1546403020620346, 0.09880973462713882, 0.14507866435451433, 0.10227769424091093, 0.0954797254235018, 0.07506367328460328, 0.07971001497935504, 0.019915057928301394, 0.0808244981453754, 0.05448615578643512, 0.06929580544237979, 0.05698111155652441, 0.049190126883331686, 0.06593242927920073, 0.18872582382755354, 0.07019575597951189, 0.05829999703564681, 0.03167411698086653, 0.13490791636286303, 0.024239134982053656, 0.04215495653625112, 0.047726656193844974, 0.14006345300003886, 0.024808777852740604, 0.024787732400000095, 0.069908945588395, 0.0036012961845699465, 0.05624245939543471, 0.12419947495800443, 0.007081034609655035, 0.05571268098719884, 0.11261872801696882, 0.9598507010377944, 50.08378252387047, 75.5202104151249, 37.55242355167866, 52.66883321106434, 40.21726995706558, 19.56326924264431, 52.42275081574917, 74.30286973714828, 84.43357452750206, 72.64617383480072, 75.60913324356079, 73.26497822999954, 68.78953278064728, 67.00061157345772, 60.19712224602699, 14.96054582297802, 8.746865596622229, 35.61375617980957, 65.61190009117126, 83.8134554028511, 72.33164191246033, 67.15599283576012, 63.114351108670235, 57.547091245651245, 59.00236375629902, 69.05908271670341, 69.07710894942284, 70.0985549390316, 66.4717635512352, 67.17634454369545, 66.92963898181915, 59.96653161942959, 56.70989356935024, 61.23887814581394, 62.416484355926514, 64.0843440592289, 63.22371684014797, 57.85403497517109, 55.23212246596813, 55.98407931625843, 62.281682789325714, 58.69834206998348, 55.05095198750496, 48.2777888327837, 50.47108054161072, 54.474576115608215, 59.67852607369423, 58.58555652201176, 60.61935178935528, 55.064882040023804, 54.4197678565979, 46.411902755498886, 46.27275042235851, 42.14890770614147, 46.68926887214184, 48.44274938106537, 57.447859570384026, 60.66351301968098, 51.7868435382843, 68.3104544878006, 58.87557975947857, 59.37151774764061, 60.16091778874397, 60.610129684209824, 59.93144050240517, 59.77998822927475, 60.259438902139664, 63.51234555244446, 58.67232486605644, 59.572317972779274, 56.16989314556122, 54.8276037722826, 57.23707728087902, 56.124219596385956, 57.24478326737881, 55.86345478892326, 47.21251979470253, 46.47803820669651, 45.47466404736042, 46.27647042274475, 44.21952299773693, 44.46031607687473, 43.30860547721386, 46.453217938542366, 49.26699735224247, 51.960038244724274, 50.3575274348259, 52.7175921946764, 49.16693352162838, 50.08013091981411, 56.08006216585636, 59.14275482296944, 58.95922467112541, 59.34943713247776, 59.80294279754162, 60.72359919548035, 59.9981839209795, 56.65559448301792, 55.76386213302612, 58.31381790339947, 55.59353247284889, 59.371323958039284, 63.6448710411787, 63.7802691757679, 67.94702678918839, 64.00775536894798, 50.38091517984867, 35.88277414441109, 43.9265701174736, 59.257816448807716, 64.9259153008461, 57.57858395576477, 56.0025767236948, 57.53152348101139, 59.910617619752884, 62.651068568229675, 65.7018868625164, 66.46592706441879, 63.26539680361748, 45.829337015748024, 41.283982917666435, 35.15907637774944, 49.9863937497139, 62.74060316383839, 58.048706129193306, 62.790380492806435, 70.79033821821213, 68.04407358169556, 69.93892550468445, 35.53611874580383, 17.827320992946625, 28.073248900473118, 33.012837544083595, 48.66765171289444, 38.51642802357674, 52.620609998703, 27.92304866015911, 1.4770283619873226, 0.11653190944343805, 0.3496256220387295, 0.05769379225966986, 0.2117139074834995, 0.07161781482864171, 0.1375678033218719, 0.012607258704520063, 0.055414712405763566, 0.08985311054857448, 0.05481083797349129, 0.04093646879482549, 0.0748484133509919, 0.019174162625859026, 0.04801925904757809, 0.06870606521260925, 0.028118535701651126, 0.08390138304093853, 0.20795105549041182, 0.09388192600454204, 0.2880125812953338, 0.12337106003542431, 0.1665329810930416, 0.15495991538045928, 0.20248159038601443, 0.1592328306287527, 0.08910949341952801, 0.16719619394280016, 0.2739757188828662, 0.1468335319077596, 0.17072225629817694, 0.15208783355774358, 0.1674229052150622, 0.17501111287856475, 0.3194359748158604, 0.13042360777035356, 0.20518569450359792, 0.3152698546182364, 1.4905143133364618, 73.73723968863487, 81.44536167383194, 50.51512397825718, 58.55232730507851, 74.06930387020111, 15.314441733062267, 50.96315413713455, 81.75117686390877, 90.30960202217102, 78.4482192993164, 81.15561202168465, 83.54309231042862, 74.07947212457657, 72.8365284204483, 67.45769664645195, 17.72270690649748, 9.681267756968737, 38.86852853000164, 66.24592646956444, 86.38576537370682, 74.89917173981667, 71.37261897325516, 67.25709021091461, 61.64349943399429, 63.36537703871727, 74.24186781048775, 73.92749547958374, 72.88825124502182, 68.44149425625801, 74.58767965435982, 71.07768639922142, 63.65012615919113, 59.38272714614868, 65.32074451446533, 67.08036169409752, 66.70118004083633, 66.94244429469109, 60.34862391650677, 60.868990793824196, 59.5340920239687, 65.25523602962494, 61.61661967635155, 55.38074389100075, 49.50663909316063, 53.750220984220505, 58.34361590445042, 62.17230185866356, 59.1239458322525, 62.195416018366814, 57.347324565052986, 56.44106939435005, 49.92299795150757, 48.789484575390816, 43.919377103447914, 47.471931874752045, 50.072519928216934, 61.72291897237301, 64.19167309999466, 53.040153086185455, 65.28371930122375, 61.704839542508125, 61.22830331325531, 63.83396789431572, 63.903800547122955, 63.2366057485342, 63.096685856580734, 62.51713715493679, 62.10530385375023, 58.88575941324234, 60.40296860039234, 57.097047194838524, 57.61084422469139, 59.793549701571465, 59.71427455544472, 60.63071317970753, 58.63054230809212, 51.297433599829674, 47.47521869838238, 49.06219594180584, 47.940591126680374, 45.95696076750755, 47.42516778409481, 43.61581139266491, 47.67105259001255, 54.766689240932465, 54.23504836857319, 51.78663834929466, 54.292995259165764, 50.35863697528839, 52.417670488357544, 58.95719178020954, 62.42953285574913, 61.71949155628681, 63.656270429492, 61.85331657528877, 62.9380139708519, 63.599972650408745, 59.94035102427006, 58.94744150340557, 60.61412326991558, 59.176067635416985, 64.19297263026237, 68.70038196444511, 67.3438623547554, 73.42780709266663, 69.1205482184887, 55.10194145143032, 41.32978945970535, 51.53998218476772, 64.1428305208683, 71.36463940143585, 61.51340961456299, 60.85144333541393, 62.13663697242737, 64.07761842012405, 67.4172592163086, 68.63697856664658, 73.69620949029922, 67.58766487240791, 52.81265549361706, 44.91919845342636, 38.136615604162216, 53.43315839767456, 67.95448198914528, 63.04467424750328, 66.69168055057526, 77.56564825773239, 69.84367981553078, 75.7811576128006, 35.35039231181145, 13.705727756023407, 55.67789554595947, 48.97183679044247, 54.16849114000797, 49.73089545965195, 63.05513508617878, 47.33157500624657, 1.8716253130696714, 0.21422527584945783, 0.31496931449510157, 0.1275277920649387, 0.26592745387461036, 0.1347506997990422, 0.18809752160450444, 0.11085608275607228, 0.18801343627274036, 0.21887820039410144, 0.24231626302935183, 0.1492030461668037, 0.24840880563715473, 0.1429819784243591, 0.1590393972583115, 0.1398251493810676, 0.16160835628397763], [0.05882599791220855, 0.07503878165152855, 0.059686547829187475, 0.06610335331060924, 0.06440228404244408, 0.019671208610816393, 0.0337180510541657, 0.05079146634670906, 0.005004275344617781, 0.060098985268268734, 0.045191134631750174, 0.07679033180465922, 0.009987929188355338, 0.032068201107904315, 0.034996515460079536, 0.04296325925679412, 0.0788213154010009, 0.04367247784102801, 0.16821293625980616, 0.05207331865676679, 0.37177213991526514, 0.32087363360915333, 15.530512388795614, 74.9678872525692, 50.589972361922264, 32.638135850429535, 60.0121595710516, 37.13552512228489, 11.837029829621315, 55.616996213793755, 65.77719882130623, 74.12299498915672, 70.20425006747246, 69.41303372383118, 67.74413287639618, 65.24673208594322, 56.38909958302975, 20.89600022882223, 8.098476938903332, 27.358530052006245, 63.9189313352108, 83.82860139012337, 72.89653480052948, 66.0002164542675, 62.28833623230457, 55.963408425450325, 58.451370522379875, 68.97659674286842, 70.57592332363129, 66.3691234588623, 66.63676589727402, 65.40336728096008, 64.29239049553871, 61.48819416761398, 60.064285174012184, 63.30744154751301, 68.42074736952782, 67.53960505127907, 66.27586886286736, 63.229583725333214, 57.58437104523182, 55.0673671066761, 54.885782450437546, 52.06906959414482, 51.0766464471817, 52.72464841604233, 61.13283723592758, 60.532895028591156, 62.0880451798439, 61.98314040899277, 61.22370935976505, 57.215008065104485, 52.618254125118256, 42.58460372686386, 42.044645100831985, 41.89882032573223, 42.95185402035713, 42.13544502854347, 55.73450110852718, 52.43498235940933, 55.19995719194412, 62.524713948369026, 56.17954082787037, 57.788876071572304, 57.10657708346844, 59.10883404314518, 58.39457117021084, 58.685696348547935, 58.610148802399635, 58.94779868423939, 56.85962833464146, 58.815755769610405, 56.45782649517059, 54.937448278069496, 52.85847343504429, 55.91653794050217, 54.16632145643234, 56.030999198555946, 49.831943437457085, 42.457891926169395, 43.7826756387949, 42.4195671826601, 40.83987034857273, 43.730424642562866, 43.80403809249401, 44.34053510427475, 48.59274633228779, 48.161051496863365, 48.64216648042202, 49.746440425515175, 50.758740305900574, 53.521093279123306, 54.56360913813114, 55.220977663993835, 56.75151653587818, 57.06302002072334, 57.16362722218037, 57.04285830259323, 59.23303797841072, 58.2043381780386, 56.97874054312706, 53.6853888630867, 52.56413742899895, 53.91673184931278, 54.17842000722885, 60.62850549817085, 62.59087219834328, 66.9294185936451, 60.20204298198223, 35.6581149995327, 36.056858003139496, 58.4772053360939, 63.59167389571667, 56.78534612059593, 51.3674296438694, 56.46332859992981, 57.9024063795805, 61.93640671670437, 63.48174199461937, 62.62473978102207, 60.33393010497093, 49.23384413123131, 42.39283561706543, 24.057548381388187, 50.12835033237934, 57.7235309779644, 52.81920254230499, 61.90944716334343, 59.676352590322495, 59.978972151875496, 52.35305115580559, 11.08301728963852, 21.624176055192947, 46.83517724275589, 31.918994039297104, 35.73500767350197, 44.090348929166794, 42.543436735868454, 6.377685600891709, 0.6063828617334366, 0.046076168000581674, 0.45035438728518784, 0.0721847265958786, 0.15020971011836082, 0.06868970085633919, 0.15692620596382767, 0.04900464562524576, 0.09171190846245736, 0.03763384484045673, 0.07026052320725285, 0.019087763648713008, 0.019634245945781004, 0.05828588138683699, 0.05231053874013014, 0.10571592341875657, 0.088788492284948, 0.03293172332632821, 0.1477748720208183, 0.024678974368725903, 0.09251237410353497, 0.05935098946793005, 0.054951077909208834, 0.04661755730921868, 0.02022836484684376, 0.018866625905502588, 0.018990675889654085, 0.07309436216019094, 0.13478776265401393, 0.0071041005594452145, 0.07687282894039527, 0.011796592243626947, 0.04167551429418381, 0.05192163480387535, 0.2255958243040368, 0.09479590313276276, 0.09881752717774361, 0.3138030442642048, 0.47567136003635824, 16.22547134757042, 88.11941474676132, 53.8348538428545, 43.6092871427536, 64.64698746800423, 29.94685236364603, 30.50636474043131, 62.66461104154587, 72.39497691392899, 78.096282184124, 73.80515724420547, 76.63539737462997, 73.62145230174065, 68.47926422953606, 63.53927090764046, 23.6100634932518, 8.935013450682163, 29.979177229106426, 67.12831512093544, 83.74968722462654, 76.3164196908474, 69.19209837913513, 65.35882607102394, 59.24867793917656, 61.068586483597755, 71.11356407403946, 73.60830500721931, 69.48984280228615, 66.53560772538185, 70.81062912940979, 68.28932762145996, 64.69858109951019, 61.36753164231777, 65.84392324090004, 67.80232295393944, 69.12735745310783, 69.97482597827911, 65.56515499949455, 59.934860318899155, 54.69538226723671, 55.6290377676487, 55.374877005815506, 53.40592905879021, 52.25107982754707, 61.16862751543522, 62.135991007089615, 62.0489376783371, 61.54667682945728, 62.96097993850708, 57.38233968615532, 54.58757825195789, 45.71395620703697, 45.8778528124094, 45.77985607087612, 45.9503149241209, 46.201895624399185, 59.62054118514061, 56.499837040901184, 62.37210653722286, 65.34187138080597, 59.362090453505516, 61.390197426080704, 61.22586764395237, 61.20939552783966, 59.79218177497387, 62.13327795267105, 60.380659997463226, 62.89089269936085, 58.601728454232216, 61.5568070858717, 58.863089829683304, 58.731316700577736, 55.80951288342476, 59.20441411435604, 56.631363183259964, 57.475693076848984, 51.13574467599392, 44.82343599200249, 47.52285674214363, 44.7667620331049, 43.952264338731766, 46.3497456908226, 47.85502731800079, 47.582046166062355, 49.873782992362976, 50.74575640261173, 51.94138504564762, 51.46914258599281, 53.039157539606094, 57.88267783820629, 58.50462086498737, 59.491044133901596, 60.822633281350136, 60.59882149100304, 60.50392918288708, 61.54654003679752, 62.54536584019661, 60.634338185191154, 57.723010405898094, 56.94009281694889, 55.22145263850689, 57.17812344431877, 59.74289461970329, 63.225761130452156, 65.02574354410172, 67.43336275219917, 61.67656905949116, 42.148523926734924, 44.22596365213394, 62.52963088452816, 63.63204672932625, 60.12417756021023, 54.781352654099464, 58.20153012871742, 60.83457224071026, 65.37083342671394, 67.44992986321449, 66.9675761461258, 62.56831280887127, 53.50432477891445, 43.981119990348816, 29.804730489850044, 56.51912480592728, 63.868599236011505, 57.63622686266899, 66.80257380008698, 67.33389928936958, 67.26016044616699, 59.11273643374443, 22.243626415729523, 22.056636549532413, 30.646301731467247, 40.631694719195366, 34.33460421860218, 50.036779046058655, 53.34610506892204, 8.961016405373812, 0.8237558382097632, 0.05204353255976457, 0.3364606940886006, 0.026147243042942137, 0.11999111171462573, 0.06220272531209048, 0.10257859059493057, 0.053276317776180804, 0.097515109955566, 0.025032696794369258, 0.0654739081801381, 0.05331242697138805, 0.04490167477342766, 0.05364082731830422, 0.09813823940930888, 0.10627274197759107, 0.02351646682654973, 0.13841898733517155, 0.31710788724012673, 0.2422755042789504, 0.1455516499117948, 0.13419830444036052, 0.2189092370099388, 0.11114134205854498, 0.18703151552472264, 0.1502243897994049, 0.11595924603170715, 0.16036344808526337, 0.2551088109612465, 0.1784823602065444, 0.22130987694254145, 0.178380329743959, 0.14838160743238404, 0.29360389220528305, 0.28935518581420183, 0.3618167631793767, 0.2609552425565198, 0.708155888132751, 0.8571227977517992, 28.42404417693615, 98.22015434503555, 66.90823093056679, 48.34096424281597, 84.1478830575943, 50.516062527894974, 21.764555722475052, 66.55541986227036, 75.54468110203743, 87.69965127110481, 80.01362890005112, 84.56140726804733, 81.1684401333332, 74.59402531385422, 70.39621576666832, 26.303583160042763, 11.305644493550062, 30.69174349308014, 69.02449697256088, 89.34854999184608, 79.31180655956268, 72.93610587716103, 71.12588301301003, 63.056271225214005, 65.5715462565422, 75.03956660628319, 77.18013614416122, 71.75883024930954, 70.1316587626934, 73.926340341568, 71.73343241214752, 67.37449631094933, 63.86204078793526, 66.52413234114647, 73.45632836222649, 73.22364404797554, 71.24086484313011, 69.62869495153427, 64.75485607981682, 57.94713757932186, 58.29465553164482, 56.40555649995804, 53.74673277139664, 57.07150876522064, 65.33327624201775, 63.84392336010933, 63.88240769505501, 63.80161643028259, 65.12298032641411, 61.243646889925, 57.492921352386475, 47.65059068799019, 46.71903267502785, 48.06670255959034, 48.034362494945526, 47.63398937880993, 63.48963037133217, 60.129706263542175, 58.718891367316246, 68.02351668477058, 63.51271033287048, 63.186064660549164, 62.615137696266174, 63.53620447218418, 63.232175186276436, 63.59057195484638, 63.67656894028187, 63.99128705263138, 59.306898415088654, 64.33995634317398, 62.715623304247856, 60.43452590703964, 58.09068247675896, 61.218051463365555, 61.451013162732124, 58.68896797299385, 56.26786708831787, 47.298421785235405, 49.94942173361778, 46.71920366585255, 46.37244567275047, 50.41036739945412, 49.951010048389435, 48.80566790699959, 53.0330740660429, 51.90042324364185, 53.58731992542744, 55.127806663513184, 56.54736489057541, 59.88170497119427, 61.46020106971264, 61.01944752037525, 63.75716641545296, 63.55907164514065, 62.296980768442154, 64.95401099324226, 61.67029559612274, 61.01258888840675, 61.20661407709122, 59.76415067911148, 57.199402302503586, 61.22176006436348, 64.71913799643517, 68.37343230843544, 71.86364382505417, 71.03215724229813, 66.71532288193703, 47.083706706762314, 51.655138805508614, 66.48906782269478, 67.42533758282661, 64.13729801774025, 58.07319201529026, 63.340400978922844, 64.32902052998543, 69.64083909988403, 73.67978677153587, 71.50414511561394, 68.79175946116447, 60.40678359568119, 48.43047983944416, 34.05079744756222, 60.22707223892212, 68.61815437674522, 60.616133362054825, 71.29562750458717, 71.57763317227364, 70.82683145999908, 62.5817146897316, 15.388894937932491, 25.88905580341816, 62.76466727256775, 50.6419687718153, 49.26352433860302, 61.31341114640236, 71.78788349032402, 18.96583680063486, 1.455441601574421, 0.1312664500437677, 0.6381181650795043, 0.11161338508827612, 0.3307189350016415, 0.18257353833178058, 0.36539260880090296, 0.10435240517836064, 0.20892608910799026, 0.12380932792439125, 0.15160165261477232, 0.09489112067967653, 0.07282738195499405, 0.12346350195002742, 0.18073057784931734, 0.17187668185215443, 0.16365033108741045], [0.07073400600347668, 0.02551648060034495, 0.06378840917022899, 0.1229994221648667, 0.03845084924250841, 0.03856624949548859, 0.06430278430343606, 0.02050016901193885, 0.04555503932351712, 0.04077338184288237, 0.08064652371103875, 0.07054482513922267, 0.0712775846477598, 0.057353161319042556, 0.04615761499735527, 0.04277543652278837, 0.02704207832721295, 0.08596608240623027, 0.03764530360058416, 0.01930103277118178, 0.10578898043604568, 0.3089011291740462, 1.0943866381421685, 58.76407854259014, 63.09689104557037, 48.28110605478287, 36.215267702937126, 62.1184017509222, 13.12004143372178, 23.531791493296623, 69.59198892116547, 66.11959844827652, 74.97384533286095, 69.53174695372581, 66.7074117064476, 65.22080987691879, 61.01884715259075, 26.226162314414978, 10.695373490452766, 25.3189704939723, 62.14311942458153, 79.68599528074265, 72.39952147006989, 66.7183019220829, 62.17816114425659, 57.34088011085987, 57.42325209081173, 67.798523157835, 70.2112340927124, 68.09252098202705, 68.59444364905357, 67.72787734866142, 65.39515972137451, 62.72821582853794, 61.972067803144455, 63.73128220438957, 68.04063856601715, 68.92262443900108, 69.2688238620758, 67.97652840614319, 62.11903631687164, 57.39851541817188, 55.13778492808342, 54.125591441988945, 52.91352488100529, 59.392181038856506, 64.57533851265907, 66.45765870809555, 63.892119973897934, 62.22286954522133, 62.03934699296951, 59.50158856809139, 51.865506917238235, 45.262817814946175, 43.37053835391998, 41.41076311469078, 42.22886301577091, 43.316379860043526, 54.57427516579628, 53.64572659134865, 54.55402225255966, 59.64757293462753, 55.82876265048981, 58.40324230492115, 57.54357263445854, 58.024334236979485, 58.57198365032673, 57.394024059176445, 58.09789068996906, 62.1615332365036, 56.8075293302536, 56.52011655271053, 56.99552424252033, 55.92832110822201, 54.82968606054783, 56.887169256806374, 54.52161379158497, 58.22587922215462, 52.30820596218109, 44.567276537418365, 43.42419147491455, 44.22585725784302, 43.1776987016201, 42.94194795191288, 44.161112532019615, 44.422929883003235, 44.40762810409069, 44.7604201734066, 46.90304920077324, 51.875720769166946, 54.956451058387756, 55.21590493619442, 54.511810317635536, 54.33708429336548, 53.48767027258873, 55.89768335223198, 56.381697580218315, 59.413395300507545, 54.66549687087536, 55.66927760839462, 54.43175621330738, 56.22640751302242, 53.69011580944061, 54.90146040916443, 55.39319962263107, 56.361364871263504, 55.25834105908871, 65.53051605820656, 65.10834351181984, 49.35539960861206, 40.31305901706219, 62.349212765693665, 65.6279656291008, 58.65647591650486, 52.82185859978199, 58.44414331018925, 58.871031403541565, 65.26059374213219, 59.78460118174553, 61.47360675036907, 49.999666437506676, 40.576829463243484, 16.35205775499344, 26.07784867286682, 50.71823447942734, 61.616197898983955, 60.45466102659702, 67.87212520837784, 59.98475544154644, 70.1247127354145, 28.491760343313217, 8.60418040305376, 40.949825048446655, 39.80822570621967, 37.815901413559914, 33.5959542542696, 37.769038528203964, 24.97912622988224, 2.080189590342343, 0.30940736294724047, 0.15084478072822094, 0.2941224753158167, 0.029116577752574813, 0.14291916304500774, 0.06861105546704493, 0.08192680266802199, 0.052364581933943555, 0.1072421798016876, 0.07501587155275047, 0.019232987106079236, 0.06287242082180455, 0.0421023531089304, 0.04037654434796423, 0.04473929657251574, 0.07215055069536902, 0.09980755217839032, 0.009154989948001457, 0.06118996832810808, 0.028257289486646187, 0.07705759402597323, 0.04603767280059401, 0.04928148897306528, 0.06338922277791426, 0.04914645520329941, 0.05862102043465711, 0.04430352601048071, 0.054072783241281286, 0.03412563484744169, 0.12875910411821678, 0.026426357362652197, 0.0774023067788221, 0.04718285119452048, 0.022338402013701852, 0.05757194274337962, 0.0912677330779843, 0.04320090236433316, 0.020514711395662744, 0.17198715795530006, 1.3839482003822923, 62.129215970635414, 73.44895675778389, 40.07439382374287, 42.91724547743797, 36.59612126648426, 21.697253733873367, 45.2997100353241, 68.67949828505516, 74.15121987462044, 75.61063036322594, 77.56697818636894, 71.9829498231411, 70.89899718761444, 67.72277802228928, 30.9857964143157, 11.64793772622943, 27.496694438159466, 62.36015237867832, 85.06417348980904, 75.21563395857811, 73.42866584658623, 64.29122775793076, 58.971953988075256, 61.388715505599976, 67.2966156899929, 70.79294487833977, 70.8775207400322, 69.69316229224205, 70.62497869133949, 69.62759301066399, 63.00758823752403, 62.81150355935097, 67.0602759718895, 68.61818477511406, 70.69138392806053, 71.91320076584816, 71.07889473438263, 63.76228854060173, 59.25632692873478, 56.33029393851757, 55.73670119047165, 54.39611412584782, 59.825836569070816, 66.45140424370766, 65.83529770374298, 65.79771772027016, 64.75288018584251, 63.486985713243484, 61.081912368535995, 54.62876804172993, 48.67196448147297, 46.51151441037655, 46.092906072735786, 46.290563866496086, 47.96199917793274, 58.28365512192249, 59.305245503783226, 61.97905942797661, 63.21055434644222, 59.05599407851696, 60.6890894472599, 62.070262134075165, 59.3878036737442, 61.13224446773529, 60.90823508799076, 60.55149503052235, 65.24958193302155, 61.92865513265133, 60.90328775346279, 62.17227146029472, 58.40863421559334, 57.044336423277855, 58.826877772808075, 59.48845647275448, 59.52246844768524, 54.274817034602165, 47.53301739692688, 44.80722986161709, 47.51999169588089, 45.54458789527416, 43.47518473863602, 45.84119237959385, 47.13914953172207, 46.52828671038151, 48.22358854115009, 49.18070778250694, 55.44557221233845, 58.90055201947689, 58.06142784655094, 60.52300415933132, 59.91915576159954, 57.58274853229523, 58.45155671238899, 60.412756875157356, 62.892484813928604, 60.37501350045204, 60.663691610097885, 58.381002098321915, 58.35528127849102, 56.72684445977211, 59.004297852516174, 58.51225085556507, 61.225863844156265, 60.4198282957077, 67.99465343356133, 66.36812791228294, 54.532253220677376, 46.02238565683365, 64.74696770310402, 66.83060109615326, 61.17199793457985, 55.318864211440086, 61.62314772605896, 61.67596869170666, 68.52679207921028, 65.32599583268166, 66.69519156217575, 53.82223092019558, 42.46656306087971, 20.627212151885033, 31.60913586616516, 56.60899378359318, 67.2234696149826, 64.66084912419319, 71.66039273142815, 63.08817431330681, 72.99672022461891, 41.231040358543396, 16.935263760387897, 24.562537483870983, 35.223254933953285, 43.862197771668434, 30.97035974264145, 50.70167876780033, 31.813648492097855, 2.7558360854163766, 0.3715419553918764, 0.19029470917303115, 0.2166229471913539, 0.054333202861016616, 0.08147949542035349, 0.07516888756072149, 0.03541880862030666, 0.06673383002635092, 0.017816889558162075, 0.029952970762678888, 0.16259481897577643, 0.05398574787250254, 0.0476209038606612, 0.014377958123077406, 0.04341480787843466, 0.04180187977908645, 0.0491171106841648, 0.13694754597963765, 0.1856857049278915, 0.1459422125481069, 0.3396885615075007, 0.26222591812256724, 0.09295972588006407, 0.1340282932505943, 0.1780650208820589, 0.15776238375110552, 0.15808940370334312, 0.15183440496912226, 0.1490865438245237, 0.27430947753600776, 0.20334165048552677, 0.23981944075785577, 0.20107118325540796, 0.10430937545606866, 0.14663854002719745, 0.23864413116825745, 0.25358262879308313, 0.22554679802851751, 0.3978438471676782, 2.82048842869699, 84.65009450912476, 83.49200025200844, 62.241157963871956, 55.63666395843029, 85.96296966075897, 15.575289186090231, 39.44407604634762, 75.97570717334747, 79.86435011029243, 84.04426261782646, 84.11085784435272, 77.72868230938911, 76.09794661402702, 75.61452895402908, 34.60124351084232, 13.208246100693941, 30.682549886405468, 68.4124182164669, 89.01971563696861, 77.97106370329857, 76.69607251882553, 68.71243491768837, 63.60955573618412, 64.90292653441429, 73.55916604399681, 75.94093903899193, 74.68987137079239, 72.07105189561844, 74.00430455803871, 73.48397567868233, 68.76418054103851, 66.67965799570084, 66.9793251156807, 71.05418086051941, 72.99735859036446, 74.86808180809021, 75.76514527201653, 67.39234015345573, 60.64410366117954, 59.19532500207424, 58.521001785993576, 58.234846740961075, 61.3605248183012, 68.97771388292313, 68.17747682332993, 67.28628024458885, 65.44692054390907, 65.51764994859695, 63.139406964182854, 56.20727553963661, 50.74602618813515, 48.24473440647125, 48.233236223459244, 49.00595895946026, 48.90934534370899, 62.265719845891, 60.119321420788765, 57.72100791335106, 65.80749079585075, 60.094212368130684, 62.83302940428257, 63.94841015338898, 63.412365317344666, 64.09828931093216, 62.941217198967934, 62.45787553489208, 68.51662382483482, 61.08319669961929, 62.32193022966385, 63.16526837646961, 62.31606334447861, 59.36623603105545, 61.835636124014854, 61.54033496975899, 63.738342225551605, 56.50545693933964, 51.05789065361023, 48.198601081967354, 50.209593772888184, 48.62444043159485, 45.81305108964443, 48.47549222409725, 48.38531546294689, 46.608128026127815, 49.624159187078476, 52.96373538672924, 57.86680229008198, 62.543416544795036, 61.41521528363228, 62.302976846694946, 62.270260602235794, 57.08247497677803, 59.582714214921, 61.18827626109123, 62.8527769446373, 59.5456700026989, 60.54608412086964, 58.27678509056568, 60.60074418783188, 59.40964490175247, 64.9142499268055, 64.38663303852081, 66.02181449532509, 66.6691629588604, 77.3971500992775, 70.98667368292809, 57.47804135084152, 53.7867484241724, 68.27463760972023, 71.3477835059166, 63.84658321738243, 57.75855369865894, 64.49677392840385, 64.95145753026009, 72.12689369916916, 68.42391639947891, 72.88927718997002, 60.537352189421654, 49.2660778015852, 26.51375748217106, 33.012563958764076, 63.19222033023834, 71.78974539041519, 68.88442888855934, 76.69035002589226, 71.18010610342026, 81.43843084573746, 39.34116616845131, 11.075204908847809, 48.17670665681362, 58.06804709136486, 56.57448023557663, 47.58640073239803, 61.11192315816879, 55.973698273301125, 3.9121052529662848, 0.5618421861436218, 0.23549047851702198, 0.36427941697183996, 0.1321267179446295, 0.15619072277331725, 0.14108973933616653, 0.16255092836217955, 0.14167290413752198, 0.2742507588118315, 0.20417306368472055, 0.23847380827646703, 0.09065986218047328, 0.12854104628786445, 0.10593138373224065, 0.13925320585258305, 0.2099403674947098, 0.19692180590936914], [0.04364672531664837, 0.0076188184721104335, 0.1640207666787319, 0.017135538619186264, 0.05914199697144795, 0.07207607617601752, 0.062014921131776646, 0.03373985906364396, 0.01837956366216531, 0.05648935337376315, 0.006616555920118117, 0.05345208803191781, 0.10282398172421381, 0.012724920652544824, 0.075363137293607, 0.05587056548392866, 0.06189883439219557, 0.09805878507904708, 0.0013988894625072135, 0.18298495531780645, 0.02042843116214499, 0.4311929357936606, 0.24136824358720332, 24.97724913060665, 75.49228191375732, 51.139753460884094, 75.7267977297306, 69.76708352565765, 42.10763432085514, 10.45059822499752, 61.900464445352554, 66.03643611073494, 68.22894126176834, 72.15217754244804, 66.41564056277275, 63.552251011133194, 60.515906140208244, 35.9276307374239, 10.453577265143394, 11.971517913043499, 62.14518651366234, 79.477918446064, 71.97570741176605, 68.41532126069069, 62.93069176375866, 59.86337475478649, 57.579659298062325, 66.63561835885048, 74.38852474093437, 71.79425194859505, 67.51175254583359, 71.70364961028099, 70.6218096613884, 64.46286454796791, 60.3080040961504, 64.5429490506649, 66.12140715122223, 70.48879399895668, 65.42817994952202, 71.66701957583427, 64.70530673861504, 63.32365147769451, 57.98762820661068, 53.303015381097794, 58.03954862058163, 64.86933633685112, 65.90261489152908, 62.45534107089043, 58.944036886096, 62.87607729434967, 58.988391906023026, 57.228839322924614, 49.57453764975071, 44.13394778966904, 44.28508847951889, 45.08261628448963, 42.34431982040405, 43.803939297795296, 52.11391858756542, 53.865981772542, 53.423848897218704, 58.7389162927866, 58.62108461558819, 61.237791404128075, 56.663589254021645, 58.25909323990345, 58.5062737762928, 61.0314966738224, 61.33869118988514, 60.40440112352371, 58.34246836602688, 58.456378653645515, 53.153671994805336, 58.44027131795883, 58.91064427793026, 59.18571911752224, 57.93634235858917, 58.00756573677063, 55.45349478721619, 45.90289726853371, 44.25810992717743, 43.750943541526794, 40.74752390384674, 43.51027585566044, 45.23760996758938, 45.88954098522663, 45.8305149525404, 45.55221028625965, 51.73819474875927, 57.07053981721401, 56.66127137839794, 59.445465579628944, 53.643537908792496, 53.659934028983116, 55.684123411774635, 56.154215186834335, 52.87290886044502, 50.56927487254143, 44.49538439512253, 48.432318940758705, 52.166374772787094, 55.36107994616032, 59.213507026433945, 57.41390839219093, 56.290278285741806, 54.97202642261982, 51.7420819401741, 56.261285841464996, 59.35894802212715, 49.35110203921795, 42.0154132694006, 63.91085296869278, 64.80572775006294, 62.00358711183071, 56.78790718317032, 57.674604803323746, 62.71194130182266, 66.28809660673141, 61.21908500790596, 56.701689809560776, 46.120785176754, 13.317246101796627, 6.3869761023670435, 34.98901650309563, 47.565049678087234, 56.97023659944534, 57.45919056236744, 70.54618611931801, 63.79515677690506, 60.442083701491356, 9.140519723296165, 22.140737436711788, 41.42454497516155, 48.56657713651657, 41.72045409679413, 38.32004316151142, 41.420148611068726, 5.971665512770414, 0.6438739062286913, 0.14602760405978188, 0.2852663677185774, 0.08238055917900056, 0.03505700791720301, 0.11803184184827842, 0.11512136130477302, 0.04078739359101746, 0.08259248686954379, 0.030149664016789757, 0.07776049693347886, 0.0835588299378287, 0.06704896077280864, 0.0643060497532133, 0.04702829523012042, 0.09731029946124181, 0.025485317819402553, 0.011346177252562484, 0.025959702325053513, 0.026540310427662916, 0.07767650065943599, 0.06879385386127979, 0.09830194234382361, 0.08057467639446259, 0.0644238582754042, 0.07206626498373225, 0.02892908527428517, 0.01828838896472007, 0.03162555454764515, 0.03936647764930967, 0.051451788531267084, 0.03492485368042253, 0.04158940661000088, 0.0077438536573026795, 0.0201890718381037, 0.06350506460876204, 0.09538625192362815, 0.0631680256628897, 0.038301681270240806, 0.47707348479889333, 0.2663715847302228, 26.949286311864853, 84.70757022500038, 45.3153195977211, 67.30747550725937, 63.53525832295418, 29.91256110370159, 30.68092167377472, 73.63992691040039, 69.57166001200676, 73.85651528835297, 79.15014803409576, 73.40493991971016, 69.6776895225048, 67.24946022033691, 42.11657144129276, 11.091589629650116, 12.870214339345694, 63.2985158264637, 81.83011382818222, 78.16575765609741, 71.17366924881935, 65.5737653374672, 64.51717123389244, 60.56030675768852, 69.23842549324036, 74.29899394512177, 75.80309763550758, 69.25592735409737, 72.37988412380219, 71.45860835909843, 67.24463447928429, 63.30242581665516, 67.58174479007721, 70.11517524719238, 72.47690811753273, 67.05670416355133, 70.06086856126785, 68.47257658839226, 64.91265401244164, 60.73491878807545, 58.474351689219475, 59.38147321343422, 67.01327249407768, 67.47775197029114, 64.61930975317955, 62.25441165268421, 63.47033120691776, 62.3922910541296, 61.694523096084595, 53.29220116138458, 48.122753351926804, 45.03578379750252, 47.38838955760002, 46.974914744496346, 48.42084735631943, 55.20541749894619, 59.68110993504524, 60.63819117844105, 60.67530758678913, 61.545118913054466, 63.6207689344883, 60.488304421305656, 59.04708735644817, 60.899362564086914, 64.55197736620903, 63.863720297813416, 63.05306039750576, 61.197547763586044, 60.60140535235405, 57.732616290450096, 62.28306591510773, 59.54431727528572, 61.826205030083656, 61.44716016948223, 61.0431582480669, 58.38511347770691, 48.31710532307625, 46.444573402404785, 47.36777946352959, 45.57152844965458, 45.064593851566315, 47.46653616428375, 46.60726547241211, 47.172013968229294, 48.27314928174019, 51.873421892523766, 60.78417934477329, 58.58837977051735, 60.772715359926224, 57.90511183440685, 57.80556097626686, 60.847122967243195, 60.18028534948826, 57.362193167209625, 55.760818496346474, 49.36650641262531, 51.979136019945145, 56.507273241877556, 57.8416096419096, 62.71042138338089, 60.556655153632164, 60.932857766747475, 60.263101905584335, 58.0154313147068, 63.83810207247734, 63.386655896902084, 54.10666465759277, 46.7124742269516, 64.99102860689163, 66.31880655884743, 63.592658042907715, 59.92984838783741, 61.0950368642807, 66.27849072217941, 70.28646245598793, 66.84570148587227, 61.696016415953636, 50.99042907357216, 15.049974974244833, 7.646428495645523, 40.138097405433655, 54.426322504878044, 63.02098631858826, 63.3683180809021, 76.61413371562958, 70.38272649049759, 67.7562390267849, 18.455556482076645, 23.183916360139847, 21.540979519486427, 50.7543059438467, 45.8779364079237, 39.97415140271187, 57.550203278660774, 7.671475801616907, 0.9021854703314602, 0.08564898496842943, 0.18167264526709914, 0.010476436764292885, 0.062013050919631496, 0.04333686752943322, 0.12299023437662981, 0.03322441152704414, 0.10563148927758448, 0.023019387444946915, 0.035951974932686426, 0.015442466919921571, 0.10255069326376542, 0.15539282496320084, 0.05553318886086345, 0.06881928726215847, 0.03047111415071413, 0.03768064467294607, 0.1265417895046994, 0.08220971678383648, 0.30485128867439926, 0.12739292898913845, 0.20930051745381206, 0.14863413060083985, 0.12964947352884337, 0.12584124662680551, 0.17245839204406366, 0.20175513171125203, 0.15261367487255484, 0.2949635067488998, 0.19246669340645894, 0.10733463655924425, 0.18561543838586658, 0.19090876216068864, 0.14061224152101204, 0.3000926971435547, 0.13878412399208173, 0.3117935755290091, 0.22822523867944255, 0.8306522306520492, 0.912898579845205, 43.48543658852577, 91.7549304664135, 68.13159808516502, 92.70563945174217, 104.10815879702568, 53.7504755705595, 18.793523646891117, 71.94664657115936, 78.35561066865921, 80.49538224935532, 84.33579817414284, 82.10960403084755, 78.15395548939705, 74.23235312104225, 47.06636443734169, 12.58508998900652, 15.07872138172388, 67.52641975879669, 85.36457017064095, 79.77422654628754, 77.01046004891396, 70.14381811022758, 67.82014399766922, 64.62156683206558, 73.1022709608078, 81.75956681370735, 81.13341361284256, 71.8835623562336, 77.59653300046921, 75.7095542550087, 70.54020524024963, 66.18191510438919, 70.1072184741497, 71.83080598711967, 75.67914068698883, 69.55602005124092, 76.01824969053268, 70.52377492189407, 67.01419204473495, 64.05309453606606, 60.512493923306465, 61.74453981220722, 67.3755906522274, 70.48617973923683, 66.67889043688774, 62.81234711408615, 65.32728776335716, 63.15448835492134, 63.667612820863724, 54.96536158025265, 49.23490047454834, 48.180662244558334, 48.77237789332867, 49.138271659612656, 49.841986298561096, 59.023893401026726, 58.86517591774464, 59.739698991179466, 64.19681802392006, 64.67752262949944, 67.81543225049973, 60.85714302957058, 62.47364468872547, 62.600139901041985, 67.39305451512337, 66.44185915589333, 65.4519134759903, 63.01046468317509, 62.35653877258301, 58.96884575486183, 65.79838648438454, 62.921975031495094, 62.92272359132767, 63.44706505537033, 65.27237311005592, 60.334241688251495, 52.72997573018074, 49.834344908595085, 51.30106620490551, 46.060885190963745, 48.18571217358112, 50.23565277457237, 49.55899268388748, 50.27808889746666, 51.10726520419121, 56.496930196881294, 65.10888308286667, 60.42967736721039, 65.12338310480118, 59.333705976605415, 57.766924649477005, 61.64351463317871, 63.86862203478813, 59.693425074219704, 59.71050135791302, 52.61747516691685, 56.94675385951996, 60.21053172647953, 59.887868240475655, 67.14723810553551, 64.76243287324905, 64.81841906905174, 66.45629838109016, 65.77663645148277, 71.4422844350338, 70.44771060347557, 57.46286876499653, 51.3037184625864, 71.23350843787193, 69.65192690491676, 68.00799071788788, 62.85831704735756, 63.57486739754677, 71.2183852493763, 72.40712106227875, 74.6509462594986, 66.91342905163765, 57.44408257305622, 20.394913516938686, 9.788188319653273, 42.9626302421093, 58.8594838231802, 67.24186062812805, 68.8389453291893, 82.62145936489105, 73.76046404242516, 72.23601624369621, 12.851703632622957, 25.936893336474895, 56.14064231514931, 65.10989382863045, 61.20346024632454, 52.327151745557785, 73.71896266937256, 22.376311495900154, 1.470901903230697, 0.1506508723832667, 0.5043769790790975, 0.20646517194109038, 0.1624437325517647, 0.21120501682162285, 0.2534818451385945, 0.12928607349749655, 0.18896546331234276, 0.1704760710708797, 0.22695903084240854, 0.17953760514501482, 0.18915916385594755, 0.2891544793965295, 0.11013970986823551, 0.16140787251060829, 0.2124789875233546, 0.11915015449631028], [0.02211998053098796, 0.007306935085580335, 0.057783740558079444, 0.03279849297541659, 0.08888794007361867, 0.09347688406705856, 0.03195581026375294, 0.009719345944176894, 0.04518182067840826, 0.037266967847244814, 0.08115981530863792, 0.023416171134158503, 0.0458514345518779, 0.029334208848013077, 0.04042432010464836, 0.01017449862047215, 0.011391178304620553, 0.04185901030723471, 0.06583252135897055, 0.09037179755978286, 0.009576401807862567, 0.15812063327757642, 0.03773024982365314, 6.373265013098717, 84.25778836011887, 50.73263570666313, 78.23669984936714, 59.225358590483665, 68.97418767213821, 14.916741773486137, 24.9600550532341, 77.21900805830956, 61.50559343397617, 73.89520481228828, 66.55438631772995, 73.84233444929123, 63.88346403837204, 45.05425080657005, 6.337793441489339, 9.446093626320362, 56.570695638656616, 76.81493014097214, 78.16188186407089, 67.60734021663666, 65.10724917054176, 59.613617956638336, 61.99067160487175, 65.53734809160233, 70.57029202580452, 71.88195124268532, 72.41538181900978, 72.6392962038517, 72.09590256214142, 69.00274693965912, 63.197213262319565, 61.60437673330307, 66.2040527164936, 68.75597298145294, 65.44628217816353, 66.69028222560883, 68.7877468764782, 63.953038305044174, 63.489079400897026, 57.14212417602539, 61.07658125460148, 67.86999732255936, 65.25896742939949, 62.542394399642944, 65.52208051085472, 62.92575962841511, 58.78506861627102, 56.009028777480125, 47.06136390566826, 46.50970570743084, 46.392246410250664, 44.98619265854359, 42.982658967375755, 44.15771171450615, 47.72296540439129, 54.23886336386204, 52.03265994787216, 57.72836811840534, 57.597050964832306, 57.94903367757797, 56.795483976602554, 57.17318370938301, 56.436737626791, 58.80017660558224, 58.69961120188236, 60.43129988014698, 58.761483281850815, 58.55933032929897, 54.179563745856285, 58.23073536157608, 58.847510665655136, 59.94365684688091, 61.02854423224926, 59.20887127518654, 55.32189644873142, 48.10069553554058, 43.226571679115295, 44.48759861290455, 42.94098660349846, 42.890715301036835, 45.598742589354515, 45.7453653216362, 44.7347791492939, 49.24182370305061, 55.6226921081543, 60.57174414396286, 58.79939764738083, 57.73581571877003, 56.875412687659264, 55.89808993041515, 47.959293723106384, 50.00510394573212, 48.80676984786987, 50.700538828969, 50.1889418810606, 51.25287339091301, 54.458016604185104, 60.13566434383392, 60.78678980469704, 58.98743435740471, 59.265199452638626, 57.33199618756771, 50.47255866229534, 51.73179969191551, 57.59139686822891, 53.32293391227722, 37.692275047302246, 56.81895911693573, 68.50495845079422, 64.50331717729568, 59.41637434065342, 60.414831563830376, 64.59713414311409, 69.31385904550552, 59.345443546772, 54.473641365766525, 24.45130605250597, 0.8007826271932572, 13.025756143033504, 39.94470678269863, 50.79351983964443, 53.69422718882561, 63.576657101511955, 56.77265100181103, 71.47213563323021, 29.122300408780575, 9.838930796831846, 41.39670766890049, 39.01103988289833, 63.898800015449524, 33.006621077656746, 41.386087238788605, 38.850069120526314, 0.4134706570766866, 0.29184663493651897, 0.03611532905779313, 0.18648018885869533, 0.14432777417823672, 0.172539449413307, 0.09720520392875187, 0.03903087475919165, 0.09612885973183438, 0.07113184168701991, 0.06772910943254828, 0.02988230717164697, 0.020048258593305945, 0.03704536997247487, 0.10238261165795848, 0.017180590693897102, 0.034393130845273845, 0.05355383276764769, 0.13412419357337058, 0.037620411967509426, 0.07572302696644329, 0.06385607819538563, 0.042260296977474354, 0.09751954057719558, 0.046476074276142754, 0.11743818307877518, 0.03938245979952626, 0.03321048141515348, 0.05505267792614177, 0.050908573539345525, 0.04005936898465734, 0.018606775884109084, 0.04398857337946538, 0.014827999257249758, 0.025641782958700787, 0.03381933565833606, 0.07406716933473945, 0.14827451552264392, 0.029915202867414337, 0.03666615106340032, 0.161639615544118, 0.02109158092935104, 6.953304363414645, 89.55492451786995, 55.37407144904137, 78.64209249615669, 84.88408595323563, 42.63988696038723, 19.86478116363287, 50.99407307803631, 83.21117252111435, 68.19296479225159, 79.17061373591423, 74.11599576473236, 77.002784460783, 71.18477985262871, 52.49843895435333, 7.512821964919567, 9.914754778146744, 57.644753605127335, 78.48855793476105, 81.83399721980095, 72.65113636851311, 68.16577345132828, 62.724986001849174, 63.86047527194023, 68.54630023241043, 74.08851563930511, 75.65856859087944, 73.66727784276009, 73.99801209568977, 72.81659469008446, 68.98534387350082, 64.59853246808052, 65.2440494298935, 67.13905334472656, 68.45241487026215, 67.31995403766632, 70.15868291258812, 69.37404781579971, 65.58959528803825, 65.07198706269264, 57.613986656069756, 62.54892244935036, 67.60957449674606, 66.9282178580761, 64.1664120554924, 68.86674463748932, 64.64786902070045, 59.04816649854183, 59.021989703178406, 50.73787182569504, 48.950466737151146, 48.803084045648575, 47.15749494731426, 46.308502703905106, 48.983000591397285, 52.66627974808216, 60.89856080710888, 60.47275185585022, 61.667194962501526, 61.039438247680664, 61.80013082921505, 62.14825674891472, 62.182219326496124, 60.28128392994404, 62.48613461852074, 61.90158158540726, 62.119560688734055, 62.28713169693947, 62.564528211951256, 58.58066998422146, 60.48366107046604, 64.31834310293198, 62.55396857857704, 63.27101290225983, 63.63524615764618, 59.92128744721413, 52.220571264624596, 46.65024496614933, 47.25370578467846, 46.33755974471569, 45.750111266970634, 47.1213398873806, 47.690754532814026, 46.24516010284424, 49.06298629939556, 59.0261884778738, 62.1281748265028, 62.38096006214619, 61.46901659667492, 60.12408256530762, 60.35323686897755, 54.98459234833717, 56.6191316395998, 53.469142466783524, 54.56159524619579, 52.63496182858944, 53.62626023590565, 56.88686527311802, 61.96279630064964, 63.63187953829765, 62.85158760845661, 63.527229353785515, 63.0545537173748, 57.58231155574322, 58.78406547009945, 62.02147275209427, 55.643948167562485, 41.65640853345394, 60.56885249912739, 71.29474595189095, 67.15207144618034, 62.2581772506237, 63.217055797576904, 68.96204352378845, 71.02230817079544, 65.83682522177696, 60.26790104806423, 25.362972132861614, 1.0107528883963823, 15.756339970976114, 46.84826374053955, 56.742283031344414, 60.01558318734169, 68.6615252494812, 65.34024506807327, 77.9602798819542, 41.88144385814667, 17.994985096156597, 28.893470987677574, 28.767323456704617, 69.82956737279892, 37.31171786785126, 49.08799655735493, 47.717809081077576, 1.1695842468179762, 0.10029965545982122, 0.04623348104360048, 0.12810168002033606, 0.08506513739121147, 0.08949060851591639, 0.04219436086714268, 0.031911188634694554, 0.022973815866862424, 0.08012444508494809, 0.03253434035286773, 0.06931795855052769, 0.02777565419819439, 0.02665845848241588, 0.013745168689638376, 0.06039827116183005, 0.10766690349555574, 0.017227917451236863, 0.04852472469792701, 0.1360265407129191, 0.15571929572615772, 0.10645319518516771, 0.18092285346938297, 0.19479218346532434, 0.2263161083101295, 0.23445807688403875, 0.15641609817976132, 0.12733180570648983, 0.12909747892990708, 0.1120146420726087, 0.08420550031587481, 0.10238186208880506, 0.0985303457127884, 0.18308337894268334, 0.17184824275318533, 0.12076009545125999, 0.1276189723284915, 0.19353338226210326, 0.14116184640442953, 0.08033567515667528, 0.4392128804465756, 0.10836642963113263, 13.007739409804344, 108.18078026175499, 64.83730405569077, 89.65423598885536, 80.37285402417183, 92.66210898756981, 17.789796106517315, 39.4578655064106, 87.82435297966003, 75.65422162413597, 85.20997926592827, 79.78955492377281, 84.25578966736794, 77.55426406860352, 57.77074344456196, 9.17900025844574, 11.208251919597387, 61.719278767704964, 83.07663694024086, 87.91152030229568, 75.8934035897255, 72.06634774804115, 66.72046020627022, 67.15997502207756, 72.2223673760891, 77.5479108095169, 79.62693125009537, 76.69224232435226, 78.98214384913445, 77.42612734436989, 74.23207953572273, 69.21284526586533, 67.91561767458916, 72.31122940778732, 70.99621877074242, 72.90914252400398, 72.95043870806694, 70.93128025531769, 68.2643249630928, 66.25766783952713, 62.63532221317291, 65.1097722351551, 70.56956246495247, 67.83142179250717, 64.93906259536743, 71.9609186053276, 67.07801342010498, 62.97199934720993, 60.391592010855675, 51.55000604689121, 50.1178514957428, 51.41364276409149, 50.838327035307884, 46.41929715871811, 49.95241977274418, 53.06523934006691, 61.1958796530962, 59.45783771574497, 64.61126178503036, 62.74106293916702, 65.50634175539017, 62.333082631230354, 62.268649488687515, 63.599809259176254, 64.68763008713722, 63.4138510376215, 66.3473430275917, 64.73982408642769, 64.42046642303467, 58.15674193203449, 65.66383570432663, 63.9835050702095, 65.74198991060257, 65.32109409570694, 66.56266987323761, 62.02605530619621, 56.86133064329624, 50.71958340704441, 50.69765858352184, 48.127693086862564, 48.107721358537674, 51.33448541164398, 48.181023225188255, 49.583717957139015, 51.84589996933937, 62.552942633628845, 65.39642885327339, 64.69041913747787, 65.41099727153778, 64.91241082549095, 65.47088205814362, 58.34834285080433, 59.083379209041595, 57.21184283494949, 59.40873295068741, 58.742970675230026, 58.546555414795876, 62.10840828716755, 64.574935734272, 68.12431007623672, 66.52884408831596, 67.55331471562386, 64.95585769414902, 63.26573118567467, 65.06665974855423, 68.38129788637161, 60.371244102716446, 45.87362363934517, 63.9505760371685, 77.13744163513184, 71.75050869584084, 64.4192884862423, 66.33784353733063, 70.59927687048912, 74.03433814644814, 70.25921031832695, 68.61914232373238, 30.8580681681633, 2.2997817071154714, 17.006228752434254, 50.87434910237789, 61.03811211884022, 62.97752045094967, 73.0594776570797, 67.23249793052673, 83.2359927892685, 39.52736757695675, 13.030635081231594, 49.08450074493885, 56.49368517100811, 81.03385135531425, 49.930198565125465, 56.23298496007919, 68.88429209589958, 3.0078582745045424, 0.5002927919849753, 0.16573502391111106, 0.3101279289694503, 0.16363468661438674, 0.21405051491456106, 0.20068217912921682, 0.11063933110563084, 0.13435850443784148, 0.22428940690588206, 0.17500124231446534, 0.12302625080337748, 0.08584591385442764, 0.09155690349871293, 0.1707149832509458, 0.1354685940896161, 0.134582276805304, 0.10065864713396877, 0.16780092555563897], [0.05248275410849601, 0.0645293619891163, 0.022662631490675267, 0.030406361765926704, 0.04518209527304862, 0.05465848989842925, 0.04950118323904462, 0.07604509679367766, 0.03235402444261126, 0.017532314886921085, 0.0187926801663707, 0.07240474369609728, 0.01761301788064884, 0.0358228412369499, 0.06101403479988221, 0.03164503592415713, 0.020152895849605557, 0.03483677930489648, 0.057452449545962736, 0.04458634364709724, 0.05783466302091256, 0.01563548190461006, 0.41936292371246964, 0.4584262822754681, 37.96109542250633, 66.26808688044548, 30.7206504419446, 30.463286451995373, 45.63503064215183, 63.78572568297386, 9.30954510346055, 48.62925477325916, 64.64238211512566, 70.24289399385452, 68.92861291766167, 66.42273858189583, 67.31681540608406, 51.578485518693924, 11.506594810634851, 5.644231857731938, 35.880524665117264, 74.41437095403671, 79.29846167564392, 71.06304198503494, 67.74345651268959, 67.03534170985222, 58.860407173633575, 63.67610156536102, 70.29834061861038, 72.43789181113243, 71.14418283104897, 77.04901278018951, 72.80841752886772, 71.07321783900261, 68.63781452178955, 66.30701959133148, 63.4900863468647, 67.80657112598419, 68.19942444562912, 65.80097794532776, 65.70096731185913, 69.64969262480736, 65.19773751497269, 66.5917307138443, 65.94631254673004, 64.46152701973915, 64.83309388160706, 62.44513861835003, 60.622068643569946, 60.65777152776718, 50.46518325805664, 50.38345344364643, 47.02012091875076, 46.88853777945042, 44.810854867100716, 45.252820551395416, 42.994860112667084, 42.54139244556427, 45.424263551831245, 54.7741824388504, 51.37697473168373, 54.334131851792336, 52.10432030260563, 54.98579688370228, 53.30218702554703, 56.15275226533413, 56.337950527668, 58.95812273025513, 60.6214264780283, 60.65336376428604, 59.13949839770794, 60.669444501399994, 58.370875641703606, 54.454767778515816, 59.48028691112995, 61.49184577167034, 62.21222631633282, 56.237548515200615, 57.417597994208336, 48.98559585213661, 44.69534106552601, 42.5405602902174, 44.77463141083717, 43.37178848683834, 46.012399792671204, 46.06731064617634, 45.04329979419708, 56.506045907735825, 63.18793796002865, 60.75013317167759, 58.21899779140949, 59.4371098279953, 61.20011642575264, 54.92384500801563, 50.711972415447235, 53.01994577050209, 53.08824710547924, 56.08623303472996, 55.67823752760887, 54.31384474039078, 56.49553567171097, 58.34383249282837, 58.70228245854378, 56.00833721458912, 50.35346545279026, 55.151072815060616, 51.14346966147423, 53.50184731185436, 55.38572542369366, 51.87474802136421, 35.18238812685013, 48.17359462380409, 61.568331867456436, 62.88633294403553, 64.91238802671432, 63.90389174222946, 66.25235572457314, 71.23068898916245, 61.02621875703335, 45.22863104939461, 4.137398488819599, 0.5460770695935935, 16.182735040783882, 38.17025899887085, 45.465244352817535, 58.32935146987438, 63.46978023648262, 59.173700362443924, 62.57197581231594, 10.413070488721132, 26.441373266279697, 40.96763849258423, 41.913187354803085, 48.527579829096794, 33.01251456141472, 52.96847753226757, 20.863314382731915, 0.6733872194308788, 0.13467271492118016, 0.010795481412060326, 0.15492311969865113, 0.05366728859371506, 0.07856855474528857, 0.07980760739883408, 0.018486640728951897, 0.1567878547939472, 0.056533366441726685, 0.026917072827927768, 0.07023883023066446, 0.06784946352127008, 0.07220131359645166, 0.051927252861787565, 0.025970890201278962, 0.01604268534720177, 0.05022481062042061, 0.020420460496097803, 0.05806367866171058, 0.08259177440777421, 0.037802865263074636, 0.027655890116875526, 0.0832071781042032, 0.03549112348991912, 0.05613878136500716, 0.025568000492057763, 0.13590761896921322, 0.013361316923692357, 0.02604714216431603, 0.12384031258989125, 0.02175666955736233, 0.07102912102709524, 0.1087692599685397, 0.056313894820050336, 0.06626424350542948, 0.09312330264947377, 0.07367530051851645, 0.04638497564883437, 0.05130488410941325, 0.07645171950571239, 0.31195616524200886, 0.21589058102108538, 41.42505034804344, 76.31159394979477, 32.62192592024803, 41.18747569620609, 44.75245960056782, 43.08947503566742, 24.01963211596012, 63.80130484700203, 70.45252114534378, 78.77332985401154, 75.56193217635155, 72.91563257575035, 72.8724592924118, 59.47005786001682, 14.116006940603256, 5.8838968724012375, 35.20646743476391, 76.75395101308823, 83.53323563933372, 74.52591016888618, 70.87508127093315, 69.2042425274849, 62.39864431321621, 66.19772985577583, 70.69029718637466, 76.42840728163719, 71.58428281545639, 76.44767224788666, 74.97196823358536, 71.78833946585655, 69.54285755753517, 67.3490908741951, 65.90893775224686, 70.67430764436722, 67.5073067843914, 68.08737605810165, 67.41313263773918, 72.01615244150162, 67.51993730664253, 65.36768719553947, 68.25804769992828, 66.05755537748337, 64.18675616383553, 65.70048853754997, 64.1937629878521, 63.342707455158234, 53.34476374089718, 52.89425611495972, 49.40793178975582, 49.45384472608566, 46.4267485588789, 51.07760779559612, 47.6104686409235, 48.03735673427582, 49.63142439723015, 59.48853626847267, 57.54594750702381, 59.20165166258812, 57.8268626332283, 60.34926988184452, 58.98683778941631, 58.98791693150997, 59.37951251864433, 61.755878403782845, 63.650566935539246, 63.66453118622303, 63.21733318269253, 64.22880470752716, 63.30559864640236, 58.53213518857956, 62.87095136940479, 65.42573288083076, 64.37945902347565, 59.908972308039665, 60.493517741560936, 52.27145813405514, 48.4197112172842, 46.19759805500507, 46.630482226610184, 46.427398324012756, 46.99364393949509, 48.57802592217922, 46.65724039077759, 58.03953342139721, 62.82906621694565, 65.70384755730629, 61.33592113852501, 62.34681509435177, 62.081976905465126, 59.14805553853512, 56.927447095513344, 55.72498641908169, 57.804234847426414, 57.05303035676479, 57.77880281209946, 57.03134872019291, 60.09040877223015, 60.269147381186485, 62.7262057363987, 59.92947980761528, 56.735337004065514, 61.084526628255844, 57.9120996594429, 59.61567744612694, 60.68465128540993, 53.53411518037319, 39.273203015327454, 54.74481001496315, 68.80192771553993, 66.11302480101585, 67.82898992300034, 65.28588518500328, 68.56644675135612, 73.19706827402115, 65.31315252184868, 50.9557331353426, 4.534112876281142, 0.6935944163706154, 21.60313468426466, 41.940713077783585, 53.21825712919235, 64.68363270163536, 70.31883671879768, 66.84468314051628, 70.33612579107285, 21.95845741778612, 29.928934425115585, 25.271824523806572, 44.098822474479675, 60.09360060095787, 35.627416446805, 63.13708148896694, 20.093606784939766, 0.8324054209515452, 0.07217917533125728, 0.11536667821928859, 0.06281293768552132, 0.029972073643875774, 0.11001387872966006, 0.07846654654713348, 0.007570731477244408, 0.028997579938732088, 0.028760729073837865, 0.004339701117714867, 0.09824072258197702, 0.12546732294140384, 0.061749484593747184, 0.04179600939096417, 0.023146931089286227, 0.007314256836252753, 0.0414436191204004, 0.025679773498268332, 0.25358340062666684, 0.15918132557999343, 0.15460120572242886, 0.28398874565027654, 0.11687758698826656, 0.11842049716506153, 0.20378891320433468, 0.17924968153238297, 0.1444435492157936, 0.11125054166768678, 0.11091153603047132, 0.2698179107392207, 0.12409325878252275, 0.23468588653486222, 0.2605491690337658, 0.1418237976031378, 0.14050891972146928, 0.32805599039420485, 0.2410241393954493, 0.23403095605317503, 0.13913894479628652, 0.19066541193751618, 0.4953703342471272, 0.979160611750558, 65.64127251505852, 83.41592073440552, 48.934936970472336, 44.6192729473114, 72.76230320334435, 80.5527363717556, 16.291863285005093, 58.89930948615074, 76.075459420681, 87.46807649731636, 82.64925867319107, 80.1569876074791, 81.25445991754532, 63.90278980135918, 14.857851583510637, 8.120647799223661, 39.94380623102188, 81.3247561454773, 89.68005940318108, 77.05084428191185, 74.88303020596504, 72.92102828621864, 65.00545263290405, 71.16866111755371, 73.31283286213875, 80.29615134000778, 75.0124740600586, 79.57718431949615, 78.99827778339386, 76.49014636874199, 74.99342188239098, 71.49684950709343, 68.21548238396645, 73.18153470754623, 70.66739201545715, 71.7476512491703, 70.72336301207542, 74.00463134050369, 70.1397143304348, 69.73906382918358, 68.77193972468376, 67.01005786657333, 65.71864396333694, 66.65260344743729, 65.06015449762344, 65.42515531182289, 53.984622806310654, 54.47052173316479, 52.99852252006531, 52.12769664824009, 47.17224195599556, 50.95988631248474, 50.513189882040024, 48.32879349589348, 52.59691447019577, 61.15477345883846, 58.98720636963844, 63.98548096418381, 60.1180636882782, 63.48741129040718, 61.74423582851887, 62.413911893963814, 62.320349514484406, 65.95224782824516, 64.27870362997055, 66.00554376840591, 65.32407313585281, 66.29041448235512, 64.97158125042915, 60.91603606939316, 64.78406131267548, 66.656813621521, 67.75130689144135, 63.70727129280567, 64.1570645570755, 56.367444545030594, 51.50796890258789, 49.07212480902672, 49.99764874577522, 49.162761345505714, 49.89380031824112, 50.14284275472164, 49.127062261104584, 61.78176261484623, 66.61726534366608, 67.25652024149895, 65.52914813160896, 64.8868153989315, 66.58548384904861, 62.648161724209785, 60.54299108684063, 60.48965334892273, 61.199417263269424, 62.24735163152218, 62.379493340849876, 60.149488002061844, 63.88504475355148, 65.26327639818192, 66.22206375002861, 63.42463105916977, 58.90876717865467, 63.81373777985573, 62.68074497580528, 63.51194657385349, 66.93515628576279, 56.56935431063175, 42.41753049194813, 59.42429691553116, 75.07889449596405, 72.91883200407028, 71.2622956931591, 67.27878704667091, 71.20241850614548, 75.41469767689705, 71.84894621372223, 53.71609501540661, 5.378051865845919, 0.7527546293567866, 23.188278526067734, 47.88946107029915, 57.35772080719471, 66.10247656702995, 75.49252510070801, 69.35324773192406, 75.48568546772003, 16.820656210184097, 32.01688438653946, 55.01191288232803, 58.704269751906395, 73.13852861523628, 46.26015029847622, 77.01473101973534, 40.59346877038479, 0.8130924822762609, 0.09542296596919186, 0.3549452475272119, 0.4129261284833774, 0.14647470350610092, 0.2026254779775627, 0.14685595961054787, 0.11427536490373313, 0.19733914523385465, 0.18586776859592646, 0.20156990649411455, 0.1814698163070716, 0.17565468850079924, 0.1539862621575594, 0.11095083274994977, 0.07658410380827263, 0.16701319516869262, 0.13989753846544772, 0.12918655149405822], [0.04293735830287915, 0.07112165199941956, 0.015861057690926827, 0.05409935212810524, 0.028759951674146578, 0.02852758152585011, 0.02196991456003161, 0.08198736191843636, 0.03406048912438564, 0.018280600124853663, 0.020131605488131754, 0.0773586610739585, 0.06072113508707844, 0.05659437469148543, 0.016520680401299614, 0.04356881836429238, 0.016767652305134106, 0.04143984158872627, 0.06595925049623474, 0.01963390826858813, 0.05700871945009567, 0.08185874030459672, 0.38653942407108843, 0.10355680060456507, 8.404596112668514, 85.4684565961361, 55.45907288789749, 45.73822170495987, 42.221164628863335, 57.292064130306244, 27.22646813839674, 14.494218695908785, 64.39020484685898, 59.89001892507076, 64.57169830799103, 63.13388966023922, 72.36625045537949, 57.673704251646996, 23.71715124696493, 1.01748232729733, 15.822212286293507, 66.04620918631554, 77.94954925775528, 75.22318035364151, 73.04801747202873, 69.58565086126328, 67.16410920023918, 65.0044646859169, 71.41155168414116, 72.4242277443409, 74.20275270938873, 76.76664233207703, 75.22295236587524, 72.59309068322182, 68.9095151424408, 65.32386034727097, 68.4976552426815, 65.42930468916893, 67.5948540866375, 68.4082992374897, 68.3494783937931, 69.07874286174774, 65.85150003433228, 67.60702103376389, 67.74031788110733, 64.45632129907608, 60.14443427324295, 62.54097327589989, 64.89803239703178, 59.846252873539925, 52.632849141955376, 49.91131357848644, 48.506141379475594, 46.66092239320278, 46.11376315355301, 45.34783445298672, 44.84410308301449, 42.31052823364735, 43.48098702728748, 51.280661299824715, 51.23051919043064, 50.19244149327278, 49.76131282746792, 49.549227207899094, 52.83849410712719, 54.18307475745678, 54.42178174853325, 57.13566452264786, 60.49943022429943, 60.58519922196865, 60.02067871391773, 58.71721185743809, 62.45115749537945, 53.3613346517086, 62.11767598986626, 59.9702288210392, 60.29064282774925, 57.643716260790825, 56.78110554814339, 49.316402301192284, 45.10747455060482, 44.208568185567856, 43.21343578398228, 44.41560007631779, 46.30525007843971, 44.70126874744892, 49.596014097332954, 60.20274594426155, 60.28692662715912, 58.864275366067886, 55.005825608968735, 61.862990856170654, 62.02255189418793, 57.91132070124149, 54.728539288043976, 55.50923779606819, 55.66186420619488, 56.227403059601784, 56.13174319267273, 52.355673015117645, 56.46958686411381, 57.404237911105156, 51.38304680585861, 50.24473048746586, 51.06022372841835, 50.64028166234493, 50.06477974355221, 51.497553661465645, 52.44543939828873, 50.5460999161005, 29.487810395658016, 37.504211738705635, 53.7899212539196, 59.14762616157532, 67.38651886582375, 67.4501882493496, 69.71905410289764, 71.41516149044037, 66.34992688894272, 36.97945609688759, 1.700715352781117, 1.1154952179640532, 19.48804847896099, 38.77525873482227, 39.825343787670135, 63.99781510233879, 53.5101954638958, 64.92530733346939, 31.965609937906265, 11.101751234382391, 41.02552458643913, 36.18546210229397, 49.22462582588196, 40.046222135424614, 42.80609004199505, 46.061090379953384, 2.6087355287745595, 0.5658158229198307, 0.15431835839990526, 0.27900430373847485, 0.07163483227486722, 0.14009618171257898, 0.04538029323157389, 0.11938283263589256, 0.0626598548842594, 0.04622954023943748, 0.028440531314117834, 0.0855819319258444, 0.07392118146526627, 0.056914362794486806, 0.03816528194874991, 0.05420337154646404, 0.040862517489586025, 0.03202429194061551, 0.05947941441263538, 0.06316739483736455, 0.0460800568544073, 0.015318290770665044, 0.008226296959037427, 0.04394970339490101, 0.05182914836041164, 0.060887279687449336, 0.008978848618426127, 0.02839070908521535, 0.025509955266898032, 0.09989652084186673, 0.06843328141258098, 0.07238299876917154, 0.07262810046086088, 0.05539749457966536, 0.07161920264479704, 0.0856984565325547, 0.020470828203542624, 0.03778169550059829, 0.1230836559261661, 0.015784325187269133, 0.0710929160413798, 0.04427992200362496, 0.28128530946560204, 0.07781561624142341, 8.450463451445103, 92.67356157302856, 59.331939071416855, 39.685173109173775, 49.443368688225746, 37.486432492733, 31.96737304329872, 35.89964523911476, 70.20041227340698, 70.72204828262329, 71.5127782523632, 68.23803797364235, 80.29752686619759, 62.15708747506142, 24.850508831441402, 1.409503254108131, 16.414875984191895, 71.4549757540226, 83.16857680678368, 79.27473574876785, 77.70150616765022, 73.75606387853622, 67.93990597128868, 68.37017208337784, 73.3768518269062, 75.67933827638626, 75.40246233344078, 77.26202934980392, 75.27671948075294, 71.84487283229828, 69.12779062986374, 66.36631160974503, 66.85834720730782, 67.57270887494087, 70.0314049422741, 68.19108009338379, 69.94528636336327, 70.28453975915909, 69.62950810790062, 68.69272157549858, 67.33749389648438, 65.84956973791122, 63.49211543798447, 64.17583554983139, 65.41893124580383, 60.36293014883995, 53.08762773871422, 52.48015433549881, 50.69595627486706, 49.58606243133545, 48.62967275083065, 48.9091819524765, 48.206208273768425, 47.75911666452885, 49.939321875572205, 54.09873068332672, 56.71603783965111, 55.191951021552086, 55.806526243686676, 53.863713294267654, 57.20490820705891, 58.77811498939991, 58.84309910237789, 60.440016612410545, 64.8043142259121, 64.26676467061043, 63.97262245416641, 63.03542174398899, 63.966383188962936, 57.82217748463154, 64.5020404458046, 63.02482031285763, 64.23493757843971, 60.645897164940834, 60.285877883434296, 52.956166192889214, 47.835887745022774, 47.325502932071686, 46.535992696881294, 46.4197151362896, 48.47752891480923, 46.927751675248146, 50.244152918457985, 61.58869117498398, 64.67271968722343, 61.32190749049187, 59.947741627693176, 64.9560096859932, 64.89370822906494, 61.645927503705025, 57.676652893424034, 58.99746961891651, 58.559949696063995, 59.30578127503395, 59.531690552830696, 56.87786355614662, 59.23179164528847, 61.91369153559208, 54.950044602155685, 53.277127370238304, 53.83867643773556, 54.6348325163126, 55.685563534498215, 56.61430589854717, 55.654899179935455, 52.17749297618866, 32.07643859088421, 43.11485767364502, 63.876814395189285, 65.47371670603752, 69.9162483215332, 69.60647374391556, 73.34369480609894, 74.68734830617905, 68.74278768897057, 39.520470947027206, 1.5676670358516276, 1.6770603158511221, 23.144149594008923, 43.887014240026474, 48.07936728000641, 70.17597958445549, 63.73217895627022, 68.86712461709976, 42.67641060054302, 20.770897641777992, 32.14039295911789, 26.524748392403126, 56.90564386546612, 44.83678087592125, 48.521036580204964, 57.00281225144863, 3.443137505091727, 0.5932125309482217, 0.0069029725091240834, 0.2583479293389246, 0.02938467117928667, 0.06648072056123056, 0.07175365753937513, 0.13221179775428027, 0.04807982571946923, 0.049700141898938455, 0.027029218763345852, 0.0924106924503576, 0.0905093843175564, 0.08128429573844187, 0.023657773599552456, 0.040368072732235305, 0.028708940153592266, 0.03197061982064042, 0.039659985923208296, 0.06340911975712515, 0.10635149126756005, 0.22280616540228948, 0.07196466496679932, 0.22655657900031656, 0.12661839398788288, 0.11001865816069767, 0.06562203343492001, 0.158446510322392, 0.14672642515506595, 0.14712066884385422, 0.10998686455423012, 0.2744849806185812, 0.1476805895799771, 0.14380111650098115, 0.19618458609329537, 0.1783873949898407, 0.10788779633003287, 0.16588039579801261, 0.28493590420112014, 0.13183205563109368, 0.19806897325906903, 0.1990179723361507, 0.5499622423667461, 0.23854925500927493, 14.738985411822796, 114.02434229850769, 70.82325965166092, 60.78061893582344, 64.11808624863625, 82.62316927313805, 33.00594851374626, 25.181814953684807, 72.61174768209457, 75.20485013723373, 74.64329347014427, 75.88981658220291, 85.26259124279022, 72.54189983010292, 27.44191087782383, 2.3141171503812075, 19.674109295010567, 76.54208958148956, 87.3163278400898, 85.27173355221748, 79.42477449774742, 78.43412965536118, 74.18614000082016, 71.04819238185883, 76.83142885565758, 80.40117010474205, 81.97914943099022, 81.34873285889626, 81.58665329217911, 78.1573449075222, 72.88278713822365, 68.98548066616058, 71.81311413645744, 70.15997484326363, 74.63643863797188, 72.00758770108223, 74.76893752813339, 74.5723208785057, 71.99104338884354, 71.64352163672447, 69.60447505116463, 68.89267444610596, 63.076174557209015, 65.23131251335144, 67.03433856368065, 63.92602175474167, 57.811549454927444, 54.65077646076679, 53.62034775316715, 50.72855092585087, 49.80689898133278, 51.442038640379906, 48.986112624406815, 49.120716601610184, 51.656461134552956, 55.556131079792976, 57.29782462120056, 56.42406530678272, 57.05827407538891, 55.42644403874874, 60.09089894592762, 61.46318010985851, 59.32886503636837, 62.73431830108166, 66.56099036335945, 67.02964201569557, 64.012740701437, 65.22137984633446, 65.22106066346169, 55.839633867144585, 67.56159827113152, 62.797626703977585, 65.08047580718994, 63.85729104280472, 62.61527068912983, 54.67776641249657, 50.810387134552, 50.35040661692619, 48.49289149045944, 50.27398131787777, 50.635866299271584, 47.125519663095474, 54.07915413379669, 63.7527434527874, 65.97316190600395, 64.72245901823044, 63.12844455242157, 68.44870626926422, 69.35178101062775, 65.01565128564835, 61.496204137802124, 62.190871462225914, 62.98631697893143, 63.52023392915726, 63.81247624754906, 58.763884752988815, 62.07107529044151, 65.51309779286385, 58.6700563877821, 56.314631178975105, 57.170691043138504, 58.54389935731888, 62.07622781395912, 62.877015843987465, 58.6237520724535, 54.79822754859924, 34.97197061777115, 46.537554413080215, 70.39043247699738, 74.40891444683075, 74.88935306668282, 72.24736243486404, 74.71365809440613, 78.37498962879181, 73.13362687826157, 43.788238540291786, 1.8978363065980375, 2.2362460289150476, 26.344831846654415, 47.915869653224945, 48.64646404981613, 76.03488519787788, 65.1038445532322, 74.42865058779716, 44.860658794641495, 15.708528086543083, 47.42751605808735, 51.81447185575962, 64.60282623767853, 58.982388228178024, 56.65573127567768, 72.09461823105812, 9.91131691262126, 1.025035846978426, 0.17074622766813263, 0.4452586529077962, 0.21224742260528728, 0.2641802898142487, 0.13076806819299236, 0.16627999779302627, 0.15768469573231414, 0.15654134302167222, 0.21743999241152778, 0.31412270211149007, 0.21425028622616082, 0.2073880919488147, 0.11034041628590785, 0.08102291874820367, 0.18710166332311928, 0.07158000982599333, 0.11608002314460464, 0.3154213121160865], [0.06713214810588397, 0.05836431897478178, 0.05024295242037624, 0.130498401413206, 0.03834117094811518, 0.05077117973996792, 0.031849738807068206, 0.044693327945424244, 0.12563985743327066, 0.02147090002836194, 0.04818626824999228, 0.04243044175382238, 0.04829767203773372, 0.042600371307344176, 0.09494604702922516, 0.0356677397940075, 0.04120015386433806, 0.08583536793594249, 0.040993350703502074, 0.04290717886760831, 0.031872103427303955, 0.07791059630108066, 0.07538543140981346, 0.2592679252848029, 0.37120985914953053, 38.11864636838436, 73.39779630303383, 43.83013889193535, 45.625257566571236, 52.22988836467266, 55.01426875591278, 8.34045935422182, 37.950429394841194, 60.222387090325356, 68.61151233315468, 68.18058505654335, 55.68625129759312, 72.2968053817749, 37.18997240066528, 3.3301375061273575, 2.718822034075856, 54.420242831110954, 76.02930709719658, 79.17797014117241, 73.29154640436172, 74.18775111436844, 65.60599520802498, 70.79463198781013, 71.05480402708054, 73.79562735557556, 69.00445684790611, 74.19627785682678, 76.21115773916245, 69.96500730514526, 71.85468390583992, 69.72470059990883, 67.01396405696869, 64.74585056304932, 66.85446381568909, 68.558109998703, 68.01047578454018, 67.478838711977, 68.88239219784737, 70.56153729557991, 69.58440452814102, 62.51357674598694, 66.45378291606903, 65.2287894487381, 63.0377434194088, 58.86904790997505, 53.12493413686752, 52.21098057925701, 50.24590462446213, 48.27100619673729, 45.33771179616451, 48.16993162035942, 45.63216559588909, 44.99676749110222, 44.29154813289642, 47.69998423755169, 50.47610767185688, 51.407806277275085, 52.8192975372076, 52.79380850493908, 52.541437447071075, 51.73089534044266, 54.66444432735443, 58.17969270050526, 60.362641364336014, 62.74407237768173, 60.567332580685616, 57.839641347527504, 63.490751311182976, 57.26165436208248, 59.807213768363, 61.69645719230175, 58.983725756406784, 57.86663889884949, 55.31742788851261, 49.80805031955242, 45.29552645981312, 43.67453724145889, 44.913954734802246, 43.97006258368492, 46.06620490550995, 48.03695395588875, 57.53784254193306, 62.818308994174004, 61.99771262705326, 58.65780584514141, 60.20993135869503, 62.747495993971825, 59.96196426451206, 55.11358022689819, 54.37280237674713, 63.71556244790554, 58.41849848628044, 52.525736689567566, 45.18042303621769, 47.0162109285593, 42.31593154370785, 40.33714972436428, 43.53547990322113, 49.82388027012348, 44.05749969184399, 45.25007329881191, 44.485710114240646, 48.331483751535416, 43.99786949157715, 45.89568145573139, 24.930344447493553, 27.883589677512646, 38.161876648664474, 50.7705956697464, 69.35201659798622, 67.87074968218803, 73.93176645040512, 63.129348903894424, 65.84353566169739, 22.840367294847965, 0.16693249403033406, 0.8284082135651261, 24.01579052209854, 39.71626304090023, 49.36450012028217, 55.214229226112366, 46.01344093680382, 59.61417272686958, 11.58987209200859, 25.802203863859177, 46.223212480545044, 36.545583978295326, 47.52438426017761, 32.945934534072876, 48.16865488886833, 31.879996731877327, 0.34000094630755484, 0.062354052934097126, 0.1147674088133499, 0.04005985880212393, 0.15101238735951483, 0.028480915279942565, 0.013781622055830667, 0.032630867790430784, 0.1273590573691763, 0.02657792061654618, 0.05181959691981319, 0.017749355974956416, 0.018326713470742106, 0.0727898144396022, 0.08025324481423013, 0.021527403441723436, 0.08912772798794322, 0.08854496394633316, 0.04586731651215814, 0.009692837356851669, 0.05510381932253949, 0.02500040594895836, 0.0760769349290058, 0.075158638501307, 0.07094700238667428, 0.05313138375640847, 0.019932077229896095, 0.03803121668170206, 0.028000996207993012, 0.01793324718164513, 0.04287994946935214, 0.0390321030135965, 0.0801020915969275, 0.06586256349692121, 0.09089789862628095, 0.017386573781550396, 0.06572702506673522, 0.04665500237024389, 0.03763364817132242, 0.05881971192138735, 0.07584749997477047, 0.051196166896261275, 0.09534535958664492, 0.23627944086911157, 0.4476325458381325, 38.35476949810982, 84.58043664693832, 40.50968326628208, 50.09291723370552, 43.267347291111946, 34.18568640947342, 20.851208232343197, 53.16923975944519, 68.8320904970169, 73.00534576177597, 77.6247350871563, 61.853240579366684, 78.42628687620163, 43.14673416316509, 3.3092820877209306, 2.3473511170595884, 56.69067420065403, 81.86820298433304, 82.05511495471, 76.71032175421715, 77.17264294624329, 68.8419471681118, 72.340107858181, 73.67249116301537, 77.05160424113274, 73.585734218359, 75.46920955181122, 77.74253636598587, 73.80024790763855, 74.47064593434334, 70.89773565530777, 68.6327075958252, 65.92884868383408, 67.40087449550629, 69.5584899187088, 69.93074834346771, 69.26561683416367, 72.36036077141762, 73.3974315226078, 71.4801836013794, 63.85169014334679, 66.92229017615318, 66.94815918803215, 65.87154775857925, 61.631803661584854, 56.71610623598099, 54.89889174699783, 52.62866176664829, 49.1539154201746, 48.683116883039474, 50.867646262049675, 49.60824564099312, 46.67538821697235, 48.62153738737106, 52.19069346785545, 55.47480024397373, 55.465927720069885, 57.780026346445084, 57.625279650092125, 57.80612334609032, 55.576418191194534, 58.79238702356815, 62.98677295446396, 64.64650109410286, 65.83232626318932, 63.53729501366615, 62.50451423227787, 65.78327089548111, 60.915922075510025, 63.78605246543884, 65.70324718952179, 61.782720163464546, 61.73117972910404, 57.82983407378197, 52.06344969570637, 47.567287757992744, 46.10451824963093, 46.60644091665745, 47.28985704481602, 47.71609537303448, 49.037854447960854, 56.820133253932, 65.13230502605438, 62.82205939292908, 62.31193296611309, 63.305819034576416, 65.56358188390732, 62.99990504980087, 56.574518233537674, 58.421538323163986, 65.95655679702759, 60.4864539206028, 57.88720339536667, 51.05441004037857, 51.97278656065464, 47.432349398732185, 46.83650717139244, 47.798699140548706, 51.179054751992226, 46.81113213300705, 48.20646286010742, 49.08070094883442, 53.930677101016045, 46.120336800813675, 47.06701420247555, 28.26744318008423, 28.71014792472124, 51.50732293725014, 61.77140437066555, 73.13249453902245, 71.57806634902954, 75.76852709054947, 66.14301279187202, 67.8481636941433, 23.906821869313717, 0.1963734329910949, 1.0303248069249094, 24.71335519105196, 43.71072269976139, 54.441605284810066, 61.069829016923904, 55.17080515623093, 62.54802569746971, 24.132144078612328, 28.400645032525063, 29.877317994832993, 38.26395437121391, 55.44217139482498, 35.84562733769417, 58.678457736968994, 34.3754406273365, 0.6903378129936755, 0.1256665153778158, 0.11400280374800786, 0.05317496266798116, 0.1098401345370803, 0.053519638313446194, 0.0235068022084306, 0.07875965035054833, 0.0370350504090311, 0.06087997695431113, 0.019115115501335822, 0.04040792235173285, 0.05694721396139357, 0.05143920541740954, 0.04769933031639084, 0.05579612065048423, 0.02819526634993963, 0.08049564508837648, 0.09181474044453353, 0.058538066878099926, 0.166071439452935, 0.09027949665323831, 0.16802977421320975, 0.26148843113332987, 0.25095830555073917, 0.14288563281297684, 0.11215638485737145, 0.1561702394974418, 0.32687775674276054, 0.11893908769707195, 0.1562491149525158, 0.1719733836944215, 0.2140873996540904, 0.14150415459880605, 0.28249999741092324, 0.2113463811110705, 0.29956042882986367, 0.1662148372270167, 0.11330055393045768, 0.17203349765622988, 0.2158088854048401, 0.1451591428485699, 0.15780232613906264, 0.3007668344071135, 0.8141051279380918, 58.143701031804085, 97.85665825009346, 59.7643406689167, 63.6398059129715, 81.93672090768814, 72.91193917393684, 11.17696724832058, 45.937266424298286, 75.72623535990715, 77.30353072285652, 84.12699937820435, 67.24770471453667, 87.16166093945503, 48.56280013918877, 3.6628925381228328, 3.3109273994341493, 64.96484041213989, 85.77405899763107, 85.53765088319778, 83.34123954176903, 81.30394846200943, 72.59035483002663, 77.24690616130829, 75.08612170815468, 81.9098487496376, 76.53498396277428, 78.8997794687748, 82.55114793777466, 79.89538684487343, 79.73479226231575, 75.89925527572632, 71.80739924311638, 69.42167446017265, 69.84923511743546, 73.9737693965435, 70.48601254820824, 73.34127813577652, 74.68858703970909, 75.3532549738884, 72.7175036072731, 68.3751118183136, 70.66917791962624, 69.45024132728577, 67.26332187652588, 64.89066079258919, 56.75791919231415, 57.50324159860611, 54.66369576752186, 51.98999963700771, 51.26986987888813, 53.576824888587, 51.30803123116493, 50.65908685326576, 49.68970946967602, 55.977300480008125, 58.16231623291969, 58.37600536644459, 61.20365023612976, 61.82324878871441, 61.25030793249607, 58.18703010678291, 61.45351342856884, 65.12212917208672, 66.1231778562069, 68.31471785902977, 65.47442346811295, 65.33732682466507, 68.67988586425781, 60.04035785794258, 66.08446553349495, 67.64113560318947, 62.821500822901726, 65.51699638366699, 60.832049176096916, 54.69021834433079, 50.63554711639881, 48.99493955075741, 50.90593680739403, 51.19898848235607, 50.95347985625267, 52.78262950479984, 61.61261089146137, 67.19124734401703, 68.16738456487656, 66.69500917196274, 66.30162388086319, 67.8093221783638, 65.31627595424652, 58.868819922208786, 60.82937031984329, 70.30328795313835, 64.87430647015572, 60.27705475687981, 51.69710375368595, 56.11411973834038, 51.81238196790218, 50.3276040405035, 49.44050744175911, 52.22805306315422, 48.56031887233257, 52.27630287408829, 51.299398094415665, 58.38971883058548, 51.91245719790459, 50.08562922477722, 30.245941914618015, 32.53264211118221, 61.95721060037613, 71.58296048641205, 78.07315662503242, 74.1958598792553, 76.9248354434967, 69.27411317825317, 71.6257993876934, 27.317714542150497, 0.39534177049063146, 1.9392344914376736, 30.534279942512512, 46.95382207632065, 59.072223007678986, 69.74211886525154, 54.3914669752121, 71.11163377761841, 17.554803416132927, 31.613822914659977, 60.89263692498207, 54.95289444923401, 66.3397966325283, 47.376165613532066, 68.51037696003914, 54.518566355109215, 1.2171286018565297, 0.3748676972463727, 0.20418455213075504, 0.20590729953255504, 0.20481129584368318, 0.12460607540560886, 0.12915547034936026, 0.1472548343008384, 0.2026008683606051, 0.17977678449824452, 0.12545127770863473, 0.21004961163271219, 0.21346926485421136, 0.13044149352936074, 0.23409123328747228, 0.21296267485013232, 0.14405913156224415, 0.14763861370738596, 0.15407015453092754, 0.1148618916340638], [0.03812014823779464, 0.017124981568485964, 0.08093476644717157, 0.07970315753482282, 0.0635856766893994, 0.030438105277426075, 0.026464891525392886, 0.0833893456729129, 0.08091652445727959, 0.05505854460352566, 0.03393251317902468, 0.06994189694523811, 0.08558852961868979, 0.0031013980333227664, 0.03349365899339318, 0.04155959453782998, 0.06146335697849281, 0.028735312371281907, 0.02264931365061784, 0.07610859494889155, 0.008883520677045453, 0.05680298127117567, 0.07427724165609106, 0.28718618501443416, 0.1997717420454137, 7.649601325392723, 77.42912158370018, 56.08366817235947, 46.549474373459816, 49.28231053054333, 67.0607091486454, 35.14358460903168, 9.742824453860521, 64.76637706160545, 74.39287930727005, 71.05693191289902, 69.41424205899239, 65.45137390494347, 40.81692337989807, 11.248863190412521, 0.4485468124039471, 15.343473125249147, 68.69395270943642, 77.00327083468437, 82.03448966145515, 73.51115942001343, 72.92542085051537, 72.44834885001183, 71.80199593305588, 77.42336109280586, 67.53341898322105, 69.57881882786751, 75.71998089551926, 70.93672916293144, 70.03044739365578, 72.39429295063019, 67.35457018017769, 67.21928983926773, 65.94262674450874, 67.12845951318741, 68.19079890847206, 68.76912787556648, 66.55814811587334, 67.00830236077309, 56.724936962127686, 68.58625888824463, 70.30377432703972, 67.41660565137863, 62.90291905403137, 58.046346455812454, 52.388765439391136, 53.37763957679272, 52.42669120430946, 49.692931696772575, 46.88219211995602, 45.197510719299316, 46.80759072303772, 44.738958925008774, 45.85788868367672, 43.228140994906425, 44.40390810370445, 48.041023537516594, 52.27310724556446, 51.086047142744064, 52.53637991845608, 52.06003747880459, 55.70368096232414, 58.41622620820999, 58.72883543372154, 61.6840660572052, 58.45266245305538, 58.299298882484436, 63.34017299115658, 55.34539818763733, 60.62394954264164, 61.977144330739975, 61.195773258805275, 55.35234421491623, 53.4205012768507, 48.41374933719635, 44.12936523556709, 42.667975053191185, 44.44604404270649, 44.37885604798794, 46.90895788371563, 49.39876668155193, 63.49464230239391, 59.82009507715702, 60.94115272164345, 55.56777365505695, 62.56881058216095, 60.83144500851631, 57.67743185162544, 55.36200329661369, 61.299070715904236, 60.474058985710144, 56.79700389504433, 48.061622232198715, 35.25289714336395, 26.963556446135044, 24.613234363496304, 26.06880135834217, 32.95448787510395, 38.718493580818176, 41.238765344023705, 44.411104917526245, 45.12081563472748, 47.54749841988087, 40.42116321623325, 37.09533087909222, 22.75919795036316, 19.17215622961521, 28.981622457504272, 47.107143849134445, 64.5836828649044, 69.18678626418114, 72.24846437573433, 62.15699627995491, 40.9842512011528, 14.93512423709035, 0.2809298801003024, 0.5596682277973741, 20.34361246973276, 40.07014945149422, 63.20363111793995, 43.60870577394962, 60.603141859173775, 39.80462349951267, 5.625274199992418, 46.40557609498501, 34.70663845539093, 48.734174743294716, 34.701539129018784, 33.88814717531204, 51.81434266269207, 9.332635514438152, 1.3285835087299347, 0.11816123529570177, 0.3586879576323554, 0.0889584663673304, 0.15860268787946552, 0.06035538244759664, 0.12994593183975667, 0.04404282437462825, 0.04627843663911335, 0.006671084756817436, 0.050135166602558456, 0.018027817204711027, 0.07396409244392999, 0.045640159951290116, 0.04420916193339508, 0.043021198725909926, 0.05591703134996351, 0.0675264882738702, 0.07975510045071132, 0.0342715707665775, 0.0439802687469637, 0.03861529432469979, 0.09782098612049595, 0.06809320708271116, 0.03377048378752079, 0.029887340788263828, 0.022920466581126675, 0.031306865203077905, 0.0629511775332503, 0.021901744585193228, 0.03716081104357727, 0.011968393864663085, 0.05107089236844331, 0.0145396108746354, 0.03687465374241583, 0.03948074241634458, 0.004905023297396838, 0.03686847907374613, 0.016378900509153027, 0.07253119081724435, 0.0642281019827351, 0.05796682096843142, 0.08198670882848091, 0.14607327582780272, 0.1772045303368941, 8.926480058580637, 88.96901115775108, 59.50626231729984, 44.363117292523384, 53.36311295628548, 36.908905282616615, 32.03710690140724, 26.993571035563946, 71.78878784179688, 72.86887988448143, 77.18350276350975, 72.45851710438728, 73.63751024007797, 46.28000423312187, 11.42849000170827, 0.42288583936169744, 18.30925863236189, 73.2980364561081, 83.02585646510124, 82.2362968325615, 77.14721471071243, 76.01935923099518, 75.40778204798698, 75.39674744009972, 78.26355680823326, 70.76267570257187, 74.00577887892723, 77.55265295505524, 74.59685996174812, 73.00806641578674, 73.1885415315628, 67.738486379385, 66.53399661183357, 69.17994663119316, 69.59511995315552, 68.64628806710243, 70.43033793568611, 67.73007363080978, 69.43539932370186, 60.58742210268974, 66.84863492846489, 69.28011685609818, 65.19199222326279, 64.7045087814331, 60.84279499948025, 55.36187030375004, 55.398268550634384, 55.9351759403944, 53.131108805537224, 48.37676212191582, 49.64412711560726, 49.480925872921944, 47.6493139564991, 49.31673288345337, 49.29524503648281, 49.77157987654209, 53.54323089122772, 55.62699727714062, 55.99121533334255, 55.44246017932892, 56.40172630548477, 60.00493995845318, 61.381598487496376, 64.80651050806046, 64.73755940794945, 61.90158158540726, 61.33044183254242, 66.02168530225754, 60.2798818051815, 63.10235135257244, 64.01347026228905, 64.04750123620033, 59.530565813183784, 59.20593783259392, 53.018517047166824, 47.52389408648014, 46.16533398628235, 47.59607121348381, 46.33635140955448, 48.24353747069836, 50.64741387963295, 62.95350953936577, 64.30698931217194, 63.34539391100407, 61.87240295112133, 66.33605003356934, 65.04118591547012, 60.9568876773119, 60.398538038134575, 62.304793149232864, 65.17791017889977, 60.79169534146786, 51.48967668414116, 38.159167394042015, 33.927980437874794, 30.093777179718018, 34.297974184155464, 39.14551466703415, 42.807013392448425, 43.58169302344322, 46.88050881028175, 47.59981021285057, 51.74278490245342, 44.33367267251015, 38.64587187767029, 27.662452943623066, 22.026572562754154, 37.585797160863876, 58.08185175061226, 70.28116554021835, 72.51335576176643, 75.78262433409691, 64.83727365732193, 42.85117842257023, 15.567399859428406, 0.22766574838897213, 0.7330881909001619, 19.75716333836317, 44.94493827223778, 65.25465846061707, 54.78835187852383, 64.35167491436005, 49.88720007240772, 12.530688308179379, 35.595615953207016, 30.20593386143446, 54.32456016540527, 44.70130294561386, 37.26635590195656, 64.47806373238564, 13.403503373265266, 1.5842189476825297, 0.14479978010058403, 0.1300715477555059, 0.03320297830214258, 0.1648505768389441, 0.06551759841386229, 0.050026994867948815, 0.05840294776135124, 0.03942661758628674, 0.04164799545833375, 0.03964189236285165, 0.04128318163566291, 0.07592922527692281, 0.035402206776780076, 0.020071448852831963, 0.035229883797001094, 0.02932582257926697, 0.04875889455433935, 0.020890329033136368, 0.03851030640362296, 0.10367993774707429, 0.16894999280339107, 0.20550961227854714, 0.17947317188372836, 0.08483705314574763, 0.11357454000972211, 0.10899858360062353, 0.14615967666031793, 0.1708673164830543, 0.08649026873172261, 0.13898788805818185, 0.1506672441610135, 0.27060826832894236, 0.10019478999311104, 0.14578367496142164, 0.17372828093357384, 0.11118740716483444, 0.18229419394629076, 0.08164538026903756, 0.24816791934426874, 0.24072633037576452, 0.25814938999246806, 0.19016688165720552, 0.3633145953062922, 0.6207919854205102, 15.685302782803774, 106.54118344187737, 71.91050291061401, 65.06377190351486, 74.61555495858192, 98.53886604309082, 45.401795357465744, 16.798237413167953, 76.18928611278534, 84.81736913323402, 84.82214167714119, 81.70905992388725, 79.50173556804657, 52.575533017516136, 12.813025508075953, 0.44772504712454975, 22.798856422305107, 79.7368973493576, 86.39019593596458, 84.98187750577927, 81.225376278162, 80.23803725838661, 79.26210522651672, 79.72817301750183, 80.79049721360207, 76.05584487318993, 75.58252707123756, 83.28266948461533, 80.71266978979111, 78.80729243159294, 77.09056735038757, 71.14418283104897, 69.84504774212837, 71.06725975871086, 71.12253919243813, 72.50525459647179, 72.87755101919174, 69.36161488294601, 67.77573198080063, 61.32868252694607, 70.59113770723343, 71.70798897743225, 66.8266037106514, 65.42552009224892, 64.64040622115135, 56.980769634246826, 59.80934165418148, 56.37115314602852, 56.219351291656494, 50.45664891600609, 51.789229810237885, 53.05957764387131, 50.378783494234085, 52.671086490154266, 50.795461535453796, 50.70051982998848, 55.28406947851181, 58.715349957346916, 57.81755693256855, 58.67346480488777, 59.64978441596031, 61.95721819996834, 65.33347383141518, 68.19710657000542, 66.91134676337242, 62.40327246487141, 63.34494933485985, 68.97420287132263, 58.381731659173965, 65.4336516559124, 66.03411823511124, 66.59887433052063, 61.25568464398384, 58.49018543958664, 56.24111272394657, 50.684617683291435, 49.601485803723335, 50.51687188446522, 49.06795643270016, 50.220898166298866, 53.658904284238815, 66.8816627562046, 66.83152824640274, 67.46842727065086, 63.30974042415619, 66.83591321110725, 67.22058936953545, 63.27461890876293, 62.45671659708023, 67.97123149037361, 68.04987967014313, 64.14429724216461, 53.64330232143402, 38.86489972472191, 34.46014188230038, 31.771229468286037, 35.026410296559334, 41.15079626441002, 44.510971158742905, 47.68623657524586, 51.65827363729477, 50.903789922595024, 53.588801845908165, 46.52172066271305, 42.19468764960766, 31.735895164310932, 24.85216934233904, 46.113295778632164, 68.59896540641785, 75.52770361304283, 77.07204714417458, 75.39665624499321, 69.75198313593864, 45.61329960823059, 18.526035100221634, 0.39859056647401303, 1.0385628836229444, 24.69518456608057, 48.61739560961723, 75.09476244449615, 55.39928309619427, 69.43340823054314, 51.13072894513607, 9.331458527594805, 55.14571510255337, 52.20775455236435, 67.76724323630333, 54.1752053797245, 46.062112525105476, 78.4410148859024, 25.424918308854103, 1.7962178844027221, 0.21631795418215916, 0.4907569068018347, 0.13791585573926568, 0.18473559262929484, 0.1793371807434596, 0.1273877191124484, 0.17770355043467134, 0.20934184023644775, 0.16180748934857547, 0.2159006445435807, 0.08808183411019854, 0.19178166141500697, 0.19287230679765344, 0.18319498311029747, 0.1369181866175495, 0.16361139802029356, 0.1139245368540287, 0.12560132512589917, 0.12281390008865856], [0.07209178002085537, 0.06052186472516041, 0.05315503971360158, 0.024047683145909104, 0.05623206190648489, 0.030391516957024578, 0.06442758385674097, 0.014027905617695069, 0.035202457729610614, 0.05976764972729143, 0.04339867358794436, 0.049384821904823184, 0.07759017404168844, 0.038167679085745476, 0.0705855616251938, 0.022226632718229666, 0.02342178919207072, 0.024704370662220754, 0.03918646601960063, 0.0757473248813767, 0.040193950044340454, 0.09843443796853535, 0.022039184768800624, 0.03340733608638402, 0.01056289604093763, 0.7310932385735214, 41.13395556807518, 72.44230717420578, 39.64220501482487, 54.634099155664444, 50.848746076226234, 76.78653046488762, 15.406839475035667, 25.711856111884117, 79.0279845893383, 73.44196513295174, 61.72489106655121, 55.27055360376835, 44.83304187655449, 10.57350642979145, 0.06732852038112469, 1.8848164239898324, 56.544359251856804, 72.11616307497025, 86.19753107428551, 75.50045147538185, 74.86777022480965, 74.8723603785038, 75.63995718955994, 75.22055089473724, 63.044001683592796, 62.67831690609455, 71.99534475803375, 70.87511166930199, 72.61987924575806, 73.03601011633873, 68.98478910326958, 68.54918047785759, 67.85685002803802, 62.36582167446613, 58.2668524235487, 51.022788137197495, 49.313126876950264, 51.28865607082844, 67.77049586176872, 75.50086185336113, 69.03971895575523, 64.79748979210854, 59.207890927791595, 55.814654007554054, 53.87355096638203, 54.92161452770233, 55.596492514014244, 54.399533942341805, 52.31503039598465, 45.46426400542259, 46.15129753947258, 46.3680113106966, 45.00548042356968, 42.37645089626312, 45.5158918350935, 47.489201948046684, 52.16548182070255, 50.93331813812256, 52.81933553516865, 53.795746341347694, 56.11693158745766, 59.533172473311424, 56.73016548156738, 60.85170932114124, 57.086654752492905, 59.65130053460598, 62.39288002252579, 57.92381823062897, 60.69567449390888, 62.07868628203869, 56.69601671397686, 54.93046045303345, 51.83919332921505, 47.78215102851391, 41.13006837666035, 44.62423548102379, 44.7139448672533, 47.37408332526684, 45.546734780073166, 57.40589082241058, 65.94734609127045, 61.8996474891901, 60.84974482655525, 63.301392272114754, 64.8473659157753, 60.26155158877373, 54.988297149538994, 54.30826663970947, 57.06955946981907, 60.74251838028431, 56.46710939705372, 52.948338612914085, 27.537101469933987, 14.743591714650393, 11.128140818327665, 11.099159773439169, 23.400149457156658, 32.37439580261707, 39.28065061569214, 40.068200156092644, 44.56634558737278, 43.51816803216934, 40.259797275066376, 29.13750149309635, 21.9851091876626, 15.623859129846096, 22.05301344394684, 42.28927597403526, 59.523080214858055, 61.82803653180599, 62.49446377158165, 45.69182239472866, 25.478618927299976, 2.5694406498223543, 0.26199264626484364, 0.4087256023194641, 14.641432296484709, 45.305968299508095, 63.5056085139513, 47.398075237870216, 81.75939202308655, 15.997059904038906, 36.71478509902954, 43.505153730511665, 37.754872888326645, 40.88398978114128, 25.213714241981506, 38.89560587704182, 43.3130968362093, 2.8363599395379424, 0.44671186711639166, 0.019654768184409477, 0.2702819905243814, 0.0767562969122082, 0.10445819832966663, 0.00550753125025949, 0.07801484578521922, 0.09497242295765318, 0.02411666020634584, 0.060842958628199995, 0.03943104078643955, 0.05994013226882089, 0.03174085832142737, 0.0461551955959294, 0.023604789821547456, 0.05454440695757512, 0.0749971397453919, 0.05674493047990836, 0.0477026588487206, 0.12157796445535496, 0.03351896993990522, 0.01748447790305363, 0.09360014737467282, 0.024048646082519554, 0.07508036418585107, 0.042171224413323216, 0.06254350097151473, 0.06666089175269008, 0.03413031779928133, 0.04459140880499035, 0.051066639862256125, 0.09692866486147977, 0.04003250694950111, 0.0714296952355653, 0.03159724161378108, 0.0271715608323575, 0.05583998157817405, 0.03450897638686001, 0.06470460532000288, 0.0603548814979149, 0.01901101815747097, 0.06386068693245761, 0.05037436822021846, 0.0027597123153100256, 0.06059763429220766, 1.0396077088080347, 48.48459653556347, 82.51903966069221, 39.81771379709244, 63.56197468936443, 40.88749699294567, 41.605894044041634, 27.144029662013054, 45.01007437705994, 83.19874718785286, 80.77807947993279, 69.27489593625069, 65.39040237665176, 50.13087339699268, 13.464195616543293, 0.018208442961622495, 2.8819914534687996, 62.41882123053074, 78.8124905526638, 89.72417503595352, 77.0001170039177, 77.5227789580822, 75.9057605266571, 77.02995300292969, 79.73215520381927, 64.30750608444214, 64.3031895160675, 74.0056648850441, 75.28265476226807, 75.90106397867203, 73.11344996094704, 73.3245362341404, 67.84078449010849, 68.04623186588287, 62.67373435199261, 63.03135596215725, 58.196035623550415, 55.35378433763981, 53.63853357732296, 67.37292319536209, 73.29599976539612, 68.24132099747658, 66.02616906166077, 62.32871286571026, 58.84236954152584, 56.77642039954662, 57.58652172982693, 58.82573023438454, 56.08252063393593, 54.1139792650938, 50.389932096004486, 49.618353098630905, 48.937387838959694, 48.78765307366848, 46.439960449934006, 48.44823248684406, 52.19032108783722, 57.223078832030296, 56.42154224216938, 57.961573004722595, 57.62479707598686, 59.89469267427921, 63.33332195878029, 64.348034709692, 65.45737758278847, 61.25927545130253, 62.655073553323746, 64.02755230665207, 62.917757257819176, 64.72115188837051, 65.4141055047512, 60.635804906487465, 58.9883729070425, 55.87483137845993, 50.68771071732044, 46.27832472324371, 48.53156961500645, 47.71108344197273, 49.70955200493336, 48.142922669649124, 59.758606776595116, 66.72244369983673, 63.27000975608826, 64.97995600104332, 63.59771557152271, 66.41513139009476, 64.0129990875721, 58.72064307332039, 57.288644313812256, 61.80101238191128, 64.3080760538578, 63.17572921514511, 54.05520781874657, 31.207864098250866, 16.291188821196556, 13.358795922249556, 14.773066733032465, 27.44204767048359, 36.148474887013435, 40.608413368463516, 43.670619651675224, 48.98466870188713, 46.251330971717834, 41.58472537994385, 31.42844796180725, 24.831861332058907, 18.82960081100464, 25.719347409904003, 49.938919097185135, 65.15251234173775, 65.70339918136597, 64.23742264509201, 46.50927633047104, 26.150027699768543, 2.5575002655386925, 0.4823913291329518, 1.7593311262317002, 17.302063778042793, 49.597378224134445, 68.54791894555092, 52.62906834483147, 82.76500806212425, 25.993624292314053, 32.119011506438255, 36.33758693933487, 33.52045610547066, 47.85727299749851, 30.72107031941414, 49.7361695766449, 52.77235485613346, 4.367402996867895, 0.478028331999667, 0.08837907909764908, 0.20270798995625228, 0.005503430884346017, 0.09519593557342887, 0.0194521451703622, 0.019561563713068608, 0.026489571646379773, 0.038880975771462545, 0.01227231725351885, 0.04158818948781118, 0.037705042777815834, 0.028929066720593255, 0.01705701753962785, 0.060617494164034724, 0.05812762952700723, 0.10559697198914364, 0.08672645722981542, 0.017318359277851414, 0.10179975855862722, 0.10013864652137272, 0.19326468027429655, 0.1671306771459058, 0.11750510995625518, 0.23304437461774796, 0.14466557011473924, 0.1664351363433525, 0.19629423099104315, 0.16094192251330242, 0.38803051749709994, 0.2140322729246691, 0.35938136104959995, 0.21931427152594551, 0.18702084344113246, 0.08681693987455219, 0.11624666498391889, 0.13051563408225775, 0.1586328784469515, 0.12449102025129832, 0.16312680527335033, 0.0835691235261038, 0.12705491040833294, 0.10300159992766567, 0.1555297660524957, 0.14471297850832343, 1.9317218195647001, 73.4650830924511, 97.60956510901451, 55.062799751758575, 76.54541820287704, 79.66485321521759, 98.73782336711884, 22.688004970550537, 38.64135392010212, 94.57065537571907, 86.4986801147461, 73.53284865617752, 72.05597430467606, 52.656069695949554, 14.526823796331882, 0.16543737816391513, 3.8534530252218246, 70.5233645439148, 83.28772321343422, 93.91607969999313, 79.97907355427742, 81.5567184984684, 82.76231780648232, 82.47946858406067, 84.31067392230034, 69.998909085989, 69.48368713259697, 77.42222875356674, 79.2595973610878, 81.43918320536613, 76.83695375919342, 76.00044384598732, 70.32246932387352, 72.80062794685364, 65.63887104392052, 62.27711163461208, 55.630861669778824, 52.436338886618614, 52.500920221209526, 69.23474729061127, 76.35532960295677, 73.66130456328392, 67.96383708715439, 64.36179757118225, 61.1747869849205, 59.11954186856747, 60.50749719142914, 60.25245487689972, 59.74115431308746, 58.0107993632555, 52.64120489358902, 53.26526440680027, 53.28354522585869, 52.379664927721024, 49.27429296076298, 52.14568488299847, 55.03609098494053, 61.33058622479439, 60.90511925518513, 60.55190160870552, 61.193310990929604, 60.310891941189766, 65.64710140228271, 65.09387388825417, 65.19551083445549, 62.50967055559158, 65.07093071937561, 66.70949399471283, 60.94396457076073, 66.94015681743622, 67.68679395318031, 62.78723806142807, 61.04235649108887, 58.16222123801708, 52.07631200551987, 46.92124642431736, 52.30289004743099, 50.52032209932804, 53.968545868992805, 52.803486585617065, 66.16465643048286, 69.6853955090046, 66.75164893269539, 67.88944467902184, 66.93136408925056, 68.96010562777519, 64.73705023527145, 62.0328189432621, 58.7985160946846, 65.62095120549202, 67.84209161996841, 68.84694769978523, 59.50178995728493, 33.96858885884285, 16.796618700027466, 14.577486477792263, 16.11395113170147, 29.385267198085785, 38.773252442479134, 45.49688905477524, 47.8477469086647, 53.97741079330444, 51.984007358551025, 46.62334620952606, 32.64240302145481, 30.425807163119316, 19.764903523027897, 32.277284413576126, 56.93681739270687, 66.4241673052311, 68.8740174472332, 67.43391752243042, 48.28071087598801, 29.570243172347546, 4.421473145484924, 1.1232510767877102, 1.2393194111064076, 19.1561970859766, 54.642614498734474, 76.09116777777672, 54.000445157289505, 94.21996459364891, 23.65078780800104, 47.32513815164566, 55.80851353704929, 54.01852458715439, 66.1658039689064, 38.71372103691101, 60.84659479558468, 70.87853148579597, 9.450320899486542, 1.1522918497212231, 0.20869645377388224, 0.40571369987446815, 0.10393001182819717, 0.29573234205599874, 0.11477564665256068, 0.2309096758835949, 0.14134770986856893, 0.1267438317881897, 0.11913736729184166, 0.16416829079389572, 0.1527875749161467, 0.1293930021347478, 0.11956457718042657, 0.19213706109439954, 0.12937674910062924, 0.22430913319112733, 0.22260063502471894, 0.07927831509732641, 0.2953748940490186], [0.06597164436243474, 0.06961000108276494, 0.06971650669584051, 0.10358589279348962, 0.03302917844848707, 0.07583190003060736, 0.04727399063995108, 0.11333985064993612, 0.06940833729458973, 0.004122581176488893, 0.01334648788542836, 0.01728703693515854, 0.12242846569279209, 0.027955730765825137, 0.07468538577086292, 0.10322615155018866, 0.047864469306659885, 0.034661825411603786, 0.056986889176187105, 0.0209161279417458, 0.10561292074271478, 0.0182466635669698, 0.05687137760105543, 0.11145041687996127, 0.11525045789312571, 0.12006120756268501, 15.846592728048563, 80.57393923401833, 46.495741456747055, 41.706592440605164, 57.91653022170067, 51.812613755464554, 46.19953595101833, 8.933414686471224, 50.79130455851555, 81.66371315717697, 70.26074543595314, 68.6912852525711, 46.58160164952278, 8.231529649347067, 0.3642741031944752, 0.22990914207184687, 33.67475062608719, 72.78411403298378, 85.37974655628204, 82.90813878178596, 84.16205629706383, 78.09760451316833, 76.40635326504707, 71.07127234339714, 59.2080657184124, 53.744749277830124, 57.54718244075775, 63.48642714321613, 71.65243595838547, 73.75350281596184, 73.22458639740944, 68.59804585576057, 69.04081329703331, 64.24252197146416, 55.27470298111439, 24.6423427015543, 29.859390556812286, 57.551506608724594, 72.84746423363686, 67.68784269690514, 66.48959219455719, 64.89652007818222, 61.22301399707794, 56.72778680920601, 56.29991456866264, 56.12949751317501, 59.284886196255684, 57.218754664063454, 55.37476301193237, 48.74111317098141, 44.86827738583088, 44.5065101981163, 45.57179443538189, 43.644936829805374, 44.56867106258869, 49.81851875782013, 52.69556477665901, 51.59409888088703, 54.92503434419632, 53.9351836591959, 59.66357007622719, 61.317917704582214, 54.50565464794636, 52.48000614345074, 62.26763874292374, 61.993711441755295, 63.115551844239235, 59.844957143068314, 57.46776670217514, 60.387286841869354, 53.942502066493034, 55.53246594965458, 49.940530210733414, 47.319525852799416, 44.5047926902771, 44.73362021148205, 42.34436921775341, 46.72620669007301, 53.153953179717064, 63.81500691175461, 63.348840326070786, 61.215984374284744, 63.26566658914089, 67.49861285090446, 66.92612797021866, 58.587072640657425, 55.735033079981804, 56.01198881864548, 56.422051414847374, 54.93456803262234, 53.96128445863724, 49.512885957956314, 35.97018085420132, 13.797346539795399, 3.519584177993238, 4.04009853489697, 13.864840418100357, 28.443162851035595, 35.86227044463158, 37.83154517412186, 39.206326603889465, 42.06149719655514, 36.58263199031353, 24.264414981007576, 16.94823056459427, 11.596824768930674, 13.65638930350542, 34.54220227897167, 41.130573749542236, 46.37895092368126, 40.48383705317974, 26.446470692753792, 9.336117077618837, 0.5661594669800252, 0.18854009394999593, 0.727225283626467, 5.748466439545155, 56.11480750143528, 55.096028968691826, 72.1215283870697, 52.21213951706886, 20.599063262343407, 81.22498869895935, 39.58334997296333, 41.68934516608715, 61.427990198135376, 72.86271661520004, 35.13593941926956, 25.34839801490307, 1.6705777449533343, 0.34715210320428014, 0.37848973413929343, 0.03103762886894401, 0.20386533957207575, 0.11165702337166294, 0.2590004255762324, 0.07573776601930149, 0.08377987862331793, 0.03422546484216582, 0.09773925339686684, 0.024815605611365754, 0.04014485326479189, 0.02566463554103393, 0.028320704150246456, 0.014510307173623005, 0.11612475238507614, 0.01071215399861103, 0.09052133289515041, 0.018586964251881, 0.04036245467432309, 0.06780126102967188, 0.06487766673672013, 0.012748625777021516, 0.008009624161786633, 0.03749478120880667, 0.09197457678965293, 0.018474601238267496, 0.05242480350716505, 0.11837039477541111, 0.048199170487350784, 0.018450772731739562, 0.10082995708216913, 0.0764811530825682, 0.017586896137800068, 0.06023190762789454, 0.11377468981663696, 0.04438853531610221, 0.06430126290069893, 0.03733561279659625, 0.09809615221456625, 0.0503925508382963, 0.044376954101608135, 0.05474914323713165, 0.0513539623352699, 0.10198799689533189, 0.18918300163932145, 17.95061867684126, 94.79335382580757, 49.34988230466843, 50.46974681317806, 67.91684120893478, 32.03700430691242, 41.44577443599701, 24.479918517172337, 65.10641321539879, 82.34274432063103, 71.42425820231438, 71.77320867776871, 52.590196430683136, 10.863285530358553, 0.48416574485599995, 0.0774070862098597, 34.770501628518105, 76.73287734389305, 86.67872965335846, 84.56797331571579, 85.88080286979675, 81.32348701357841, 77.04176276922226, 74.2378780245781, 60.80439805984497, 55.21736025810242, 61.87438264489174, 70.05333736538887, 76.10930800437927, 75.47085106372833, 72.97516018152237, 69.33281242847443, 70.79033061861992, 64.47585985064507, 56.30455791950226, 30.818728879094124, 33.85982729494572, 56.70782268047333, 72.12431743741035, 68.4112098813057, 66.50501936674118, 65.83793476223946, 61.57019756734371, 57.22727380692959, 58.520067036151886, 57.053759917616844, 62.33058996498585, 60.02547785639763, 58.565797582268715, 51.81773968040943, 50.78125409781933, 49.275672286748886, 52.152938693761826, 47.28945426642895, 49.388469234108925, 53.098343163728714, 57.811044082045555, 55.39629265666008, 58.48293162882328, 57.22503952682018, 65.2901941537857, 66.98241055011749, 60.90137645602226, 60.62660939991474, 65.62266111373901, 66.48931100964546, 66.55977442860603, 66.73325031995773, 63.84070873260498, 64.68295633792877, 59.602742940187454, 59.22836422920227, 53.91472175717354, 51.984847113490105, 48.52540634572506, 47.23514758050442, 45.23841552436352, 46.58864267170429, 55.216338112950325, 67.26335227489471, 68.28280717134476, 62.79174081981182, 68.10519710183144, 67.34297320246696, 68.99032920598984, 62.73985840380192, 60.11008031666279, 60.80033227801323, 61.86781659722328, 59.73779909312725, 60.45108541846275, 53.32587115466595, 38.844023644924164, 18.717921003699303, 5.201880969107151, 5.107802767306566, 19.14889957755804, 32.26513646543026, 38.532368168234825, 41.17308586835861, 42.74875491857529, 45.56705988943577, 38.293300196528435, 25.591208785772324, 19.28732044994831, 13.635633867233992, 17.90227197110653, 40.018267035484314, 44.08370688557625, 48.097233921289444, 42.275934889912605, 27.276253066956997, 10.565327368676662, 0.981130568543449, 0.3478197689400986, 2.0410298416391015, 7.399595640599728, 58.466702699661255, 61.58654808998108, 71.37720912694931, 60.0438878685236, 23.16127337515354, 77.86769405007362, 31.871859468519688, 42.18195453286171, 70.72885751724243, 73.7376044690609, 50.358819365501404, 35.202306658029556, 1.9952073879539967, 0.380796596291475, 0.3133491170592606, 0.032741770628490485, 0.1197255119041074, 0.036115573966526426, 0.14728135865880176, 0.09613875998184085, 0.03065101074753329, 0.03108170501946006, 0.010049542288470548, 0.01750319486745866, 0.06828198718721978, 0.044082544118282385, 0.03008813440828817, 0.08143140425090678, 0.08563293231418356, 0.02578399329649983, 0.059038341205450706, 0.030777962529100478, 0.08560338741517626, 0.17357778822770342, 0.1418465221649967, 0.1962566189467907, 0.19228975055739284, 0.19164831232046708, 0.18809153989423066, 0.1268334238557145, 0.2522651385515928, 0.1708374821464531, 0.05695382278645411, 0.11058116157073528, 0.18893521337304264, 0.22103048802819103, 0.12680802756221965, 0.1978433009935543, 0.24838915356667712, 0.1967062268522568, 0.16267121565761045, 0.17885306297102943, 0.16846237209392712, 0.37465333531145006, 0.10633647762006149, 0.22308245213935152, 0.15996935282601044, 0.21387881162809208, 0.38931354240048677, 26.819148994982243, 110.78047916293144, 63.816694021224976, 59.68659304082394, 81.6709403693676, 78.28081548213959, 59.54343192279339, 15.823644809424877, 63.22297967970371, 96.319929510355, 80.64364269375801, 83.15648585557938, 54.9672044813633, 13.515816796571016, 0.4209154669661075, 0.32101826334837824, 40.17233356833458, 81.35052636265755, 87.6094289124012, 87.85936430096626, 88.4383012354374, 87.49936401844025, 83.75097915530205, 79.00265514850616, 65.30245989561081, 57.76358462870121, 62.97842480242252, 73.35141599178314, 83.76762226223946, 80.0554570555687, 78.13959985971451, 73.73438984155655, 74.80806022882462, 68.31968039274216, 58.246458917856216, 31.036645285785198, 34.56733413040638, 60.14291055500507, 79.17841091752052, 72.11614027619362, 70.22283107042313, 67.25787296891212, 62.68984168767929, 59.84750300645828, 62.73746833205223, 60.65152086317539, 63.595386296510696, 64.09049972891808, 60.65862648189068, 56.17825269699097, 51.850113943219185, 50.49697235226631, 55.342077165842056, 50.585515201091766, 52.54383511841297, 55.06407268345356, 58.07602286338806, 57.51400642096996, 61.220316141843796, 58.378764018416405, 67.63042017817497, 68.68496999144554, 62.894491106271744, 59.338619112968445, 69.74747657775879, 69.43530052900314, 70.31734719872475, 63.75645965337753, 62.69149839878082, 67.73155555129051, 60.0720139592886, 61.31842687726021, 55.841339975595474, 54.58250172436237, 51.30399964749813, 51.56276576220989, 47.64917716383934, 50.93423768877983, 60.4349210858345, 71.00457072257996, 71.12982720136642, 67.6263315975666, 70.95091000199318, 70.57676687836647, 71.51359140872955, 64.35134813189507, 63.53308103978634, 62.27348282933235, 63.3365897834301, 63.85400801897049, 62.489451840519905, 57.8462377935648, 43.24965924024582, 21.649222411215305, 6.542209647595882, 8.712170608341694, 22.843952402472496, 37.4743415415287, 42.728369012475014, 49.721399769186974, 48.82560543715954, 51.610172018408775, 43.761833757162094, 28.94695121794939, 22.597244940698147, 15.837972890585661, 20.0262364000082, 42.446545735001564, 46.8837234377861, 51.373007744550705, 43.866768926382065, 31.13875910639763, 12.097978927195072, 1.6725716879591346, 0.7908956171013415, 3.2249525003135204, 7.83099171705544, 65.41347473859787, 66.11367076635361, 78.12718212604523, 63.4504658728838, 30.021056681871414, 95.94352930784225, 49.156510680913925, 67.7628506720066, 76.40722721815109, 75.45203447341919, 67.24831268191338, 54.91951324045658, 2.6745197363197803, 0.45800171443261206, 0.36086437990888953, 0.2222068514674902, 0.24885553400963545, 0.15228356758598238, 0.26547667337581515, 0.14417935948586091, 0.22765661997254938, 0.2064923197031021, 0.12828432256355882, 0.14848639868432656, 0.1638007495785132, 0.15612433024216443, 0.12782943056663498, 0.19193032843759283, 0.27910909499041736, 0.12036927306326106, 0.2564156142761931, 0.10320253641111776, 0.17609040340175852], [0.07985471893334761, 0.007819920083420584, 0.028600454861589242, 0.026148584474867675, 0.012841148400184466, 0.06090614137065131, 0.10631059150910005, 0.09226045207469724, 0.07006410640315153, 0.020619109309336636, 0.10945343849016353, 0.07748393560177647, 0.0355946382478578, 0.026044247788377106, 0.0059986678843415575, 0.024809134083625395, 0.01518100272733136, 0.03889231207722332, 0.08015380444703624, 0.03402069887670223, 0.07534232747275382, 0.053469157428480685, 0.13273765391204506, 0.05502694766619243, 0.18680704553844407, 0.03993443213403225, 2.9569495562464, 59.5067372918129, 68.65141779184341, 34.1884146630764, 42.56936654448509, 44.040647596120834, 61.98523789644241, 20.483178980648518, 28.485954254865646, 90.80404669046402, 80.28423517942429, 74.85618844628334, 46.677964478731155, 8.60236695036292, 0.2374392989440821, 0.06776269161491655, 12.254275940358639, 54.071014970541, 67.67178475856781, 84.30011048913002, 84.83594253659248, 76.27565547823906, 68.1633871793747, 55.79716354608536, 46.73770107328892, 37.30474904179573, 39.64428350329399, 49.88484039902687, 69.0282891690731, 74.44482252001762, 72.17265084385872, 69.97221171855927, 65.77658325433731, 62.88163639605045, 51.553532257676125, 10.554376356303692, 21.67663224041462, 54.540966153144836, 64.39163357019424, 63.14877346158028, 65.46302407979965, 63.12394939363003, 64.27159041166306, 62.736134603619576, 56.77438750863075, 56.28397062420845, 59.03543718159199, 58.40041905641556, 55.786888897418976, 51.07503533363342, 46.83165483176708, 46.645643413066864, 47.50100411474705, 45.6889421492815, 48.554387390613556, 53.9164886623621, 56.04751691222191, 57.31390915811062, 57.3746033012867, 59.3478412181139, 58.65549176931381, 63.11486408114433, 46.97847135365009, 41.289762407541275, 64.4781169295311, 59.58877868950367, 62.68245868384838, 60.60586251318455, 60.118979439139366, 57.34567925333977, 55.03699913620949, 52.96509571373463, 49.190374463796616, 44.62065987288952, 44.125535041093826, 45.26697859168053, 42.8171968460083, 46.545879766345024, 55.934689566493034, 59.80516567826271, 59.82845842838287, 64.40971300005913, 63.273729756474495, 67.52727091312408, 65.01765757799149, 55.810367837548256, 56.692281514406204, 58.93275149166584, 61.56022310256958, 57.24506825208664, 55.678549110889435, 48.88566121459007, 41.220028549432755, 29.438650533556938, 9.542976077646017, 0.9829554799944162, 9.655819572508335, 20.17600916326046, 32.601460218429565, 34.75550763309002, 41.37962378561497, 37.2277195751667, 35.468075796961784, 20.902573876082897, 12.19112142920494, 6.248135827481747, 3.6327071953564882, 21.236556954681873, 24.950838647782803, 25.62776282429695, 16.824642196297646, 9.35244670137763, 1.8739897361956537, 0.10317947788280435, 0.5645178956910968, 3.217751174233854, 5.546201867982745, 58.1377087533474, 55.84846459329128, 73.12766119837761, 30.894757099449635, 33.72196689248085, 24.881264381110668, 48.052875101566315, 43.88520933687687, 80.67920878529549, 50.60962490737438, 40.21628960967064, 13.00704499706626, 1.0965489596128464, 0.09431623082491569, 0.4378662386443466, 0.06030108321283478, 0.34898473299108446, 0.018919810063380282, 0.17971104505704716, 0.07601075019920245, 0.06379735947120935, 0.03301736716821324, 0.048198988661170006, 0.043500299580045976, 0.06175257563882042, 0.010485472412256058, 0.029922759786131792, 0.05022779034334235, 0.024805568064039107, 0.037941765622235835, 0.14566194789949805, 0.05185652989894152, 0.051575025863712654, 0.034285337605979294, 0.0334867495985236, 0.0417646870482713, 0.04505374454311095, 0.04789942075149156, 0.06663984444458038, 0.06862695969175547, 0.06769966843421571, 0.020259800367057323, 0.09041285316925496, 0.12599858193425462, 0.08949690192821436, 0.05412542748672422, 0.013987484544486506, 0.10272325744153932, 0.058033614259329624, 0.06081417071982287, 0.05788578957435675, 0.0861745813745074, 0.02044031109107891, 0.10126219131052494, 0.02625178938615136, 0.08722207086975686, 0.007164391245169099, 0.1785037192166783, 0.019565786533348728, 3.3077032724395394, 71.44984602928162, 75.36185011267662, 34.19842332601547, 55.936498269438744, 40.24071469902992, 41.76214545965195, 26.341425329446793, 51.82620942592621, 95.34998595714569, 82.45641142129898, 79.45203423500061, 55.82555562257767, 11.23256966471672, 0.589130837470293, 0.19089682842604816, 14.812514316290617, 55.13266660273075, 71.70853614807129, 83.00144657492638, 84.92944031953812, 78.29783096909523, 72.19582960009575, 62.030352875590324, 47.67122358083725, 40.18977463245392, 46.271561086177826, 57.136846259236336, 77.1296064555645, 76.00601434707642, 75.51298320293427, 71.23993769288063, 68.48018378019333, 65.71505695581436, 59.166043773293495, 13.773619662970304, 23.494574390351772, 61.62264235317707, 67.60648146271706, 66.91867277026176, 66.53166353702545, 66.23163923621178, 64.55209136009216, 63.88692945241928, 60.14582499861717, 60.01443184912205, 61.842308565974236, 59.37327705323696, 57.44985066354275, 54.632324650883675, 51.1994406580925, 50.48299290239811, 51.35611765086651, 48.257813304662704, 51.522430926561356, 58.494965583086014, 57.75726556777954, 61.01393401622772, 61.997579634189606, 63.097107633948326, 64.15836408734322, 66.82693809270859, 54.09653440117836, 47.2314427793026, 69.95768889784813, 65.68781241774559, 66.27158269286156, 67.33483403921127, 66.42916783690453, 60.49033351242542, 61.77429981529713, 56.641440242528915, 51.937520653009415, 50.119701996445656, 48.6241402477026, 48.41716915369034, 46.366958767175674, 49.65018779039383, 61.07824556529522, 63.960379511117935, 63.058877885341644, 65.85601419210434, 66.40303283929825, 68.19403633475304, 68.46724927425385, 59.50686268508434, 58.926778212189674, 61.696958765387535, 65.86508810520172, 62.36969366669655, 60.502014085650444, 55.22830367088318, 43.584884852170944, 31.89744919538498, 14.641311652958393, 3.8970207748934627, 11.84872655197978, 29.680023081600666, 36.738902404904366, 38.731336891651154, 45.54096668958664, 41.090911477804184, 38.17961789667606, 23.880715370178223, 14.05632734298706, 7.3288605362176895, 7.673768978565931, 27.455599643290043, 26.9859866425395, 26.956258937716484, 17.845575213432312, 9.60655901581049, 2.1813731733709574, 0.14051138365175575, 2.2024076571688056, 2.423864286392927, 6.072516851127148, 63.93274739384651, 63.07016707956791, 76.15854576230049, 38.111411556601524, 37.68661715090275, 26.69184822589159, 40.50960727035999, 54.549549892544746, 75.48260003328323, 58.918684646487236, 55.74075177311897, 16.49393454194069, 0.9886500088032335, 0.02200303104473278, 0.4337718989700079, 0.17982710211072117, 0.2734151598997414, 0.013292130206536967, 0.14800602133618668, 0.08139886849676259, 0.03167110757203773, 0.07990862854057923, 0.016857322298164945, 0.026509381423238665, 0.11740503876353614, 0.013765991498075891, 0.11896285868715495, 0.13693261396838352, 0.06830826663644984, 0.034602242085384205, 0.05183977591514122, 0.056578017756692134, 0.084316340071382, 0.11708781516063027, 0.1602587607339956, 0.09072135653696023, 0.19416475697653368, 0.207058786181733, 0.14220394048606977, 0.1561490586027503, 0.22653619962511584, 0.24277636490296572, 0.15042001992696896, 0.23878770705778152, 0.21628420130582526, 0.13828350085532293, 0.19961072568548843, 0.15338436554884538, 0.1980622939299792, 0.17359726218273863, 0.11130977989523672, 0.2195752106490545, 0.17981424811296165, 0.1905546835041605, 0.12074582395143807, 0.1542203503777273, 0.11261394116445445, 0.4916032520122826, 0.1518826000392437, 5.592705672606826, 90.80706372857094, 85.46636670827866, 50.703115090727806, 63.094576969742775, 70.11978060007095, 84.24638137221336, 27.29485496878624, 40.39274834096432, 106.1898846924305, 90.60204192996025, 89.09394845366478, 56.49272382259369, 13.269918691366911, 1.3635980361141264, 0.16426278103608638, 14.693943578749895, 61.25056251883507, 75.26205986738205, 87.37408474087715, 92.16115906834602, 83.8475851714611, 77.21669778227806, 67.06757918000221, 50.772753953933716, 38.57254721224308, 48.87051522731781, 61.66215643286705, 83.63793522119522, 79.06601294875145, 76.70424208045006, 73.44992950558662, 71.93435043096542, 68.98074612021446, 65.17461195588112, 19.212931841611862, 28.863091617822647, 71.76915809512138, 72.29866728186607, 72.83014476299286, 68.57794493436813, 69.20668199658394, 66.74832791090012, 64.99070942401886, 62.34274551272392, 62.92126066982746, 64.1558638215065, 65.065086632967, 61.38425834476948, 58.08772623538971, 55.69246396422386, 53.88145834207535, 54.24453265964985, 53.013037741184235, 56.87993824481964, 63.22375863790512, 62.662027180194855, 64.06950205564499, 63.632840886712074, 66.06605932116508, 66.63036704063416, 68.4753580391407, 55.56588135659695, 50.56552827358246, 71.73274084925652, 66.50262549519539, 68.86817336082458, 67.30552241206169, 65.83483412861824, 61.51211008429527, 61.7016477137804, 60.257098227739334, 54.773437678813934, 52.83391535282135, 50.062222480773926, 55.61595506966114, 51.491268798708916, 55.011692494153976, 65.34264653921127, 66.47762283682823, 65.98747953772545, 72.80528649687767, 70.92596054077148, 70.33311635255814, 69.31759804487228, 61.054892018437386, 62.31466121971607, 64.97611060738564, 69.56813380122185, 68.31716492772102, 66.99026092886925, 61.65272913873196, 49.568986147642136, 40.00698164105415, 17.59811159223318, 6.446273345500231, 14.392045978456736, 35.50929978489876, 41.16456672549248, 45.562367141246796, 49.98084604740143, 47.93636575341225, 44.360012859106064, 29.609517864882946, 15.953863821923733, 9.681305754929781, 13.119824845343828, 31.354093551635742, 30.425240993499756, 29.16132241487503, 19.143228381872177, 10.482686553150415, 3.7303740670904517, 0.33104530186392367, 2.4696382926777005, 7.967166909947991, 8.756231144070625, 70.04925638437271, 65.484758913517, 84.66194987297058, 44.51883673667908, 42.27578289806843, 30.520304292440414, 68.9392751455307, 63.48907180130482, 86.47361665964127, 71.09939083456993, 68.80434438586235, 26.09600029885769, 1.2010444211773574, 0.14983474742621183, 0.5233928211964667, 0.16878957016160712, 0.40091764472890645, 0.14927748357877135, 0.307840570458211, 0.1970842175069265, 0.16227799613261595, 0.14264695812016726, 0.13275594043079764, 0.17464282951550558, 0.3942694264696911, 0.08943174136220478, 0.362474899739027, 0.1892409782158211, 0.20606671285349876, 0.09603071070159785, 0.2955064916750416, 0.21835648542037234, 0.13045979489106685], [0.02868782976293005, 0.035584348370321095, 0.044007204996887594, 0.07790209871018305, 0.07833116396795958, 0.05118237779242918, 0.05061957752332091, 0.037427182687679306, 0.07355538429692388, 0.04066578527272213, 0.04181900483672507, 0.04608921495673712, 0.04042560402012896, 0.07560119600384496, 0.10652786266291514, 0.021299573381838854, 0.010625520317262271, 0.03744553971046116, 0.04710810579126701, 0.0382962821458932, 0.045237381564220414, 0.1177819087752141, 0.00669248319354665, 0.05227056666626595, 0.031118042425077874, 0.1880032243207097, 0.14753214520169422, 40.832456946372986, 90.47125294804573, 51.00510388612747, 45.51953203976154, 40.220666974782944, 53.89585576951504, 42.81125396490097, 11.367584969848394, 65.7714231312275, 78.21450144052505, 62.75734506547451, 46.55464969575405, 7.573151802644134, 0.29612571001052856, 0.6989209586754441, 3.0580312572419643, 31.53390560299158, 50.46641819179058, 62.18736045062542, 66.93746656179428, 63.49500708281994, 53.294028863310814, 37.04873397946358, 26.52229942381382, 21.076672933995724, 22.187573723495007, 38.78666952252388, 59.56728704273701, 73.94635766744614, 68.23149472475052, 69.15901735424995, 64.47310879826546, 65.1479297876358, 39.46855053305626, 12.63631884008646, 25.177232399582863, 51.19887828826904, 58.0740849673748, 65.72257295250893, 61.69270299375057, 70.3613032400608, 69.40738722681999, 70.05364134907722, 62.48271860182285, 61.92329742014408, 60.58989197015762, 60.02795532345772, 55.63137464225292, 55.80226667225361, 49.30814914405346, 47.331548407673836, 45.95701776444912, 47.42274351418018, 49.22028265893459, 57.59645439684391, 59.036892503499985, 58.614985942840576, 58.6272668838501, 64.13501054048538, 62.00865224003792, 65.96138253808022, 49.778544902801514, 44.26763981580734, 67.15524047613144, 61.201408356428146, 58.99034880101681, 61.21737129986286, 58.36745202541351, 57.61983834207058, 54.59107406437397, 51.34984038770199, 46.21006138622761, 46.170562505722046, 45.62433801591396, 45.77823355793953, 43.95990192890167, 50.937748700380325, 57.173951268196106, 60.84983982145786, 58.83608087897301, 61.18405468761921, 61.102115884423256, 64.90125462412834, 57.5988482683897, 56.78383760154247, 57.1422153711319, 60.621768459677696, 59.657703191041946, 56.9935255497694, 54.621297642588615, 52.90313243865967, 39.86504405736923, 35.495457127690315, 24.28954493254423, 13.390304781496525, 7.2875358536839485, 17.03785065561533, 31.31579540669918, 32.49915450811386, 38.42065416276455, 36.43103912472725, 30.225077234208584, 19.749434553086758, 9.152171798050404, 2.5840214174240828, 2.888369648717344, 7.540868259966373, 12.09045723080635, 8.842897843569517, 5.315171889960766, 1.299036294221878, 0.3102059435332194, 0.18889378668973222, 0.45094424625858665, 2.255605277605355, 2.304863934405148, 48.17217729985714, 76.89429268240929, 58.107686564326286, 36.05235144495964, 40.840440317988396, 43.02492029964924, 50.33391930162907, 55.11415399610996, 38.192575201392174, 39.8452965170145, 46.89454145729542, 3.563067619688809, 0.638021626509726, 0.3165639820508659, 0.06413407187210396, 0.0596298403252149, 0.04688460430770647, 0.06654654906014912, 0.021131955618329812, 0.0675189851608593, 0.014022278282936895, 0.07665274504688568, 0.054590004510828294, 0.034767985926009715, 0.019053174000873696, 0.003281773315393366, 0.11873878946062177, 0.03428633950534277, 0.12037987093208358, 0.037276218718034215, 0.08493069733958691, 0.0307923212312744, 0.05482291271619033, 0.08460922123049386, 0.01448335608074558, 0.033321788723696955, 0.05008818123314995, 0.014445695796894142, 0.059696737516787834, 0.09524217137368396, 0.009460181481699692, 0.03510550355713349, 0.04156102688284591, 0.10149793452001177, 0.06620097541599534, 0.017178377238451503, 0.06595926533918828, 0.012648788360820618, 0.007683662697672844, 0.039557747659273446, 0.029791961824230384, 0.02477665213518776, 0.040279616150655784, 0.024827457709761802, 0.02614347107737558, 0.029271940802573226, 0.04067684327310417, 0.02682983522390714, 0.12734495656332, 0.16654282197123393, 48.3006826043129, 106.06332868337631, 57.22230367362499, 48.87778803706169, 49.29603159427643, 35.440154895186424, 37.586405128240585, 26.465619765222073, 86.60803064703941, 85.22740513086319, 71.35313361883163, 48.261210322380066, 10.201344899833202, 0.8990919019561261, 1.8797198287211359, 3.493419731967151, 33.550596088171005, 52.333607599139214, 64.80298429727554, 72.20383197069168, 69.26019072532654, 59.0372458845377, 40.90462267398834, 28.723029233515263, 23.794013522565365, 24.8522225394845, 48.8384335488081, 69.01961043477058, 75.0921481847763, 71.02153301239014, 70.47636866569519, 69.29970860481262, 68.59685271978378, 49.23691816627979, 15.034690294414759, 29.883800446987152, 61.55924655497074, 66.76342070102692, 68.4782762825489, 65.57131826877594, 71.75120025873184, 69.97527435421944, 71.16635844111443, 62.66872622072697, 61.709745079278946, 62.36104153096676, 63.221163377165794, 57.546198293566704, 58.69630537927151, 51.05372607707977, 52.423035800457, 50.41702464222908, 50.663247630000114, 52.42853790521622, 60.4863703250885, 59.52022276818752, 61.93065382540226, 62.902869656682014, 66.60895898938179, 65.26674181222916, 70.89609414339066, 57.454573810100555, 48.3748584240675, 72.90377721190453, 64.8770423233509, 63.53724181652069, 63.94958809018135, 63.86780887842178, 61.29244767129421, 59.33298401534557, 56.54616415500641, 50.70504158735275, 48.631572648882866, 48.766408413648605, 49.71574567258358, 46.61838747560978, 53.86666193604469, 60.52023410797119, 63.8414990901947, 63.328868597745895, 67.2011724114418, 65.39713561534882, 68.85523125529289, 62.20796674489975, 58.04885812103748, 61.27901919186115, 64.06704738736153, 65.43062701821327, 61.717572659254074, 61.4298103004694, 56.69480077922344, 47.70895555615425, 35.36649204790592, 27.578219063580036, 19.52648911625147, 11.853848677128553, 22.56502076983452, 37.42071121931076, 36.9752611219883, 42.432604283094406, 39.981625601649284, 34.34084728360176, 20.817720629274845, 11.051402986049652, 4.994031172245741, 6.424728501588106, 10.710003655403852, 13.777573350816965, 10.297263152897358, 4.83990621753037, 0.2889720891835168, 0.6725759035907686, 1.5252237883396447, 4.159537525847554, 2.2004417376592755, 2.487504933960736, 52.66441024839878, 80.74611559510231, 64.01476979255676, 40.806937515735626, 41.92296043038368, 37.14989215135574, 52.178560718894005, 62.23895028233528, 45.1553937792778, 53.0250146985054, 55.79013392329216, 4.116854891180992, 0.5498161283321679, 0.149449261080008, 0.127549106546212, 0.031011317878437694, 0.01669998327997746, 0.017261373468500096, 0.05445539005449973, 0.03720563305250835, 0.010282039529556641, 0.03172758129949216, 0.04720328623079695, 0.038796593580627814, 0.02898829938203562, 0.04349878188804723, 0.0657913247414399, 0.038144334830576554, 0.08757992705795914, 0.03579471755074337, 0.027847353085235227, 0.03168958704918623, 0.043469496740726754, 0.21573069272562861, 0.16262079414445907, 0.11103184559033252, 0.09743239017552696, 0.11169139223056845, 0.22949036298086867, 0.20872878172667697, 0.21057618025224656, 0.18196834658738226, 0.16134617035277188, 0.19052388437557966, 0.20014916866784915, 0.13907314598327503, 0.14353930164361373, 0.14655705221230164, 0.14773703733226284, 0.1597896046587266, 0.15440302260685712, 0.12531677086371928, 0.12636512867175043, 0.22135026461910456, 0.20378339162562042, 0.11661649201414548, 0.1960123929893598, 0.11367987302946858, 0.2883877814747393, 0.3844378102803603, 63.85518595576286, 116.01298078894615, 75.35373374819756, 62.57221519947052, 66.35511741042137, 81.32840394973755, 57.260233238339424, 19.328170157968998, 76.63180276751518, 92.90144294500351, 73.70976716279984, 55.51290079951286, 12.569525074213743, 3.330586119554937, 1.5809454233385623, 4.402854619547725, 36.87895528972149, 55.61978906393051, 64.63842272758484, 71.82986363768578, 73.26191559433937, 61.094732880592346, 44.2788378149271, 30.070482529699802, 22.67757073044777, 26.00013144314289, 52.23247982561588, 75.33745542168617, 78.53140443563461, 77.86684289574623, 72.42112711071968, 74.27437886595726, 71.8022695183754, 56.699725314974785, 19.415808655321598, 37.33509801328182, 71.61279648542404, 71.06434151530266, 71.57976105809212, 66.39583602547646, 76.173554956913, 69.9014063179493, 71.7874427139759, 67.2326423227787, 66.66896536946297, 65.38918644189835, 68.70529890060425, 63.18751998245716, 62.287849858403206, 55.148507952690125, 55.73941804468632, 53.210231959819794, 52.96872451901436, 56.17106728255749, 64.80113759636879, 63.09483915567398, 63.29935558140278, 63.77678096294403, 68.37385788559914, 67.03480213880539, 71.10207349061966, 58.51599745452404, 52.91903458535671, 74.4842492043972, 67.17996194958687, 64.24553140997887, 65.90333685278893, 61.80388502776623, 62.82682053744793, 59.208267107605934, 57.356181889772415, 50.866677314043045, 50.86121700704098, 51.510845348238945, 53.68424132466316, 49.25078742206097, 57.54638448357582, 64.11544919013977, 67.33947739005089, 68.07677462697029, 69.6949177980423, 69.21157613396645, 69.48796570301056, 63.23366850614548, 59.44466382265091, 61.73069715499878, 63.46940405666828, 68.12387689948082, 63.71395893394947, 64.50552105903625, 60.29240593314171, 52.0367219299078, 39.674875661730766, 34.93180677294731, 26.257071755826473, 14.746516607701778, 27.596868462860584, 42.36575827002525, 40.07681429386139, 46.942525282502174, 46.79798103868961, 40.52540302276611, 25.335148125886917, 13.42401847243309, 7.218641275539994, 11.676387749612331, 11.38423852622509, 12.850427851080894, 10.757723394781351, 6.976657910272479, 2.376263765618205, 0.7213084667455405, 0.7845943083520979, 3.101066085509956, 5.868460200726986, 3.7310796417295933, 55.561241805553436, 83.00406843423843, 68.54333639144897, 50.6391379237175, 48.625876754522324, 54.84700933098793, 74.5333805680275, 65.21276950836182, 53.02620783448219, 62.20228984951973, 73.96817609667778, 4.699783511459827, 0.667598289437592, 0.3037213539937511, 0.18954548140754923, 0.18209056346677244, 0.09886290950817056, 0.12433208932634443, 0.14806224644416943, 0.12221105353091843, 0.09297031632740982, 0.14090117445448413, 0.14065022463910282, 0.11845582339446992, 0.24634422501549125, 0.13148234080290422, 0.3205049049574882, 0.10597285494441167, 0.30777051171753556, 0.1518691671662964, 0.23266872914973646, 0.13739425950916484, 0.12249164472450502], [0.056521339938626625, 0.08264855612651445, 0.017976095077756327, 0.06835863619926386, 0.0347790327941766, 0.03649767240858637, 0.0986904047022108, 0.0341091443260666, 0.02829516313795466, 0.07277521639480256, 0.09239425387931988, 0.05614010980934836, 0.03863573307171464, 0.04531561877229251, 0.036830533063039184, 0.0692942320893053, 0.08813324267975986, 0.024506619847670663, 0.012316667070990661, 0.028217502949701156, 0.07092108658980578, 0.04002163819677662, 0.01229042565682903, 0.06939768747542985, 0.03176431760948617, 0.0405187695287168, 0.09595153838745318, 4.579592635855079, 47.152532413601875, 58.65275591611862, 48.4565806388855, 66.98356568813324, 53.87778013944626, 57.87953540682793, 41.66208542883396, 19.863618426024914, 70.18017455935478, 71.79796814918518, 67.25117012858391, 9.795679617673159, 0.814296305179596, 1.7841576877981424, 0.3012338827829808, 6.933439979329705, 27.112823836505413, 33.9774613827467, 38.96970570087433, 34.21309053897858, 25.84210742264986, 17.510826475918293, 9.39577767625451, 4.0393737237900496, 16.730950623750687, 33.55363592505455, 54.559444561600685, 70.38867697119713, 71.14968493580818, 71.47085130214691, 63.76417323946953, 64.77048844099045, 34.526828303933144, 20.07582563906908, 32.73906983435154, 49.84911851584911, 56.268076077103615, 60.216717794537544, 64.14846941828728, 66.61465868353844, 66.54023587703705, 72.33122393488884, 64.44280162453651, 61.91760912537575, 62.76130825281143, 56.22593253850937, 51.23868875205517, 53.04605796933174, 49.75758522748947, 49.133297726511955, 49.02089215815067, 47.76694044470787, 51.781102046370506, 58.41749534010887, 57.27940320968628, 60.08758932352066, 57.64473460614681, 62.403143271803856, 61.57894089818001, 62.747598588466644, 52.60229878127575, 45.88862903416157, 66.71593844890594, 59.12455379962921, 58.24928216636181, 56.58591382205486, 54.71240155398846, 55.260886922478676, 53.361646234989166, 48.5635145008564, 47.7517032623291, 46.01717233657837, 45.69221757352352, 46.745365262031555, 48.30485858023167, 55.514891892671585, 58.45058016479015, 56.872266456484795, 57.034156769514084, 59.14688520133495, 57.129660844802856, 61.51738040149212, 57.305048033595085, 55.927101373672485, 58.44301097095013, 62.40563593804836, 61.74370765686035, 57.33147941529751, 54.844630658626556, 50.92675969004631, 42.01723337173462, 37.100293412804604, 32.697348073124886, 40.88549070060253, 27.165384516119957, 19.038361608982086, 27.05669514834881, 30.937539003789425, 34.83667127788067, 30.071726962924004, 27.542974054813385, 17.214995250105858, 8.263256046921015, 4.200390558689833, 1.8862672336399555, 1.7057802435010672, 2.9842974012717605, 1.7616012669168413, 0.9820769552607089, 0.03588548592233565, 0.38213142310269177, 0.7652751356363297, 3.084688726812601, 0.6762360571883619, 1.3001991505734622, 41.0020000487566, 99.64571624994278, 39.36850190162659, 43.65573965013027, 51.534795463085175, 42.43313245475292, 55.48718377947807, 53.51382426917553, 36.620436161756516, 61.236187890172005, 11.130583137273788, 1.452584273647517, 0.11333403963362798, 0.22691797523293644, 0.039586572675034404, 0.05808068126498256, 0.00897607947990764, 0.08319105123518966, 0.045234101271489635, 0.12709503091173247, 0.06556096952408552, 0.0273349168128334, 0.07545793923782185, 0.03873232359183021, 0.04311991549911909, 0.02332713938812958, 0.01212011575262295, 0.06947678557480685, 0.041575862414902076, 0.015413255059684161, 0.03063456289964961, 0.03167964969179593, 0.06455916663981043, 0.012556664642033866, 0.12175927855423652, 0.02124239461409161, 0.008385531236854149, 0.04693200156907551, 0.0847267551580444, 0.047226808601408266, 0.03235902651795186, 0.039144965121522546, 0.04143885453231633, 0.08879057771991938, 0.022441697838075925, 0.05947348465269897, 0.034068608219968155, 0.07168825206463225, 0.052267405117163435, 0.009617655941838166, 0.11909743974683806, 0.07508958165999502, 0.06043872934242245, 0.037557307150564156, 0.09114080356084742, 0.0274534990239772, 0.08330463693710044, 0.04086410568561405, 0.1035719329956919, 0.09812673612032086, 7.9801940359175205, 60.263675674796104, 69.90774437785149, 50.90074248611927, 74.91418853402138, 45.08521534502506, 28.605541437864304, 40.3787574917078, 43.024084344506264, 84.74758207798004, 75.72489783167839, 67.91715279221535, 11.129556242376566, 0.7011216937098652, 3.4637580486014485, 0.8238928683567792, 8.79724994301796, 28.266753517091274, 36.04869984090328, 39.63405065238476, 38.1536690890789, 30.64030185341835, 21.779247634112835, 10.917252134531736, 5.032592928037047, 16.842461340129375, 38.912856951355934, 63.3978196978569, 74.38661724328995, 73.50807398557663, 71.12991079688072, 67.4140977859497, 70.70032864809036, 40.47200448811054, 21.667974404990673, 37.457896023988724, 61.05459563434124, 62.73671977221966, 64.85390916466713, 67.58359149098396, 70.14434248209, 71.85220643877983, 72.9915601015091, 69.51806008815765, 63.59189048409462, 63.75794157385826, 61.28074049949646, 56.80465288460255, 57.77499161660671, 55.32006494700909, 52.66883701086044, 53.453133925795555, 51.02280333638191, 55.2424693107605, 65.07758036255836, 62.51204922795296, 65.72784706950188, 63.71010594069958, 66.95817545056343, 65.65159276127815, 67.77440205216408, 57.48613491654396, 49.26621079444885, 71.03151887655258, 63.982433527708054, 64.30043086409569, 60.09252905845642, 60.43308578431606, 61.56147323548794, 57.694747522473335, 52.24498875439167, 51.84359349310398, 49.91614691913128, 50.831175819039345, 50.56517869234085, 52.090690433979034, 59.18565832078457, 62.78020843863487, 61.49699069559574, 63.09303805232048, 64.87825065851212, 63.586802557110786, 64.44017216563225, 61.264674961566925, 59.54313553869724, 60.466668382287025, 63.97463634610176, 65.88312193751335, 62.161578834056854, 60.410252809524536, 56.13058805465698, 47.260857000947, 44.25952725112438, 34.97842267155647, 44.00063194334507, 32.23014034330845, 21.500766277313232, 31.8039533123374, 33.028735890984535, 37.389879673719406, 33.050045147538185, 31.4023794606328, 17.148365825414658, 10.725513473153114, 5.761371972039342, 3.34599738009274, 2.5027547031641006, 3.8085862202569842, 1.9294523913413286, 0.946959595894441, 0.39964067575056106, 1.4426608686335385, 2.758784252218902, 7.64781542122364, 0.9517218684777617, 1.444272338412702, 42.851862385869026, 100.51361247897148, 42.31795683503151, 51.59043587744236, 47.463021352887154, 35.6485965102911, 57.53432773053646, 55.175064727663994, 43.57223153114319, 71.35480552911758, 13.625129330903292, 1.202187209855765, 0.06395778953447007, 0.2660323935560882, 0.0402423863124568, 0.08221156473155133, 0.023303585476242006, 0.04803310010174755, 0.07200717518571764, 0.07315386756090447, 0.04595016987877898, 0.026629603780747857, 0.05412228449131362, 0.03585335463867523, 0.04740748816402629, 0.046697913348907605, 0.020307108570705168, 0.021757613940280862, 0.041961790338973515, 0.05661868373863399, 0.04127413485548459, 0.06128804314357694, 0.05001915407774504, 0.1355842949124053, 0.1764427899615839, 0.09942857446731068, 0.2203066268702969, 0.12582392490003258, 0.2980080933775753, 0.1760727254441008, 0.13212285877671093, 0.15601579856593162, 0.15474023966817185, 0.1992794606485404, 0.11007660505129024, 0.137814374465961, 0.15337213495513424, 0.13953450950793922, 0.1886432376340963, 0.1776172238169238, 0.2743948542047292, 0.09297189710196108, 0.14277879323344678, 0.12667331291595474, 0.16830125183332711, 0.07531978844781406, 0.3414743469329551, 0.2786314190598205, 0.17152478510979563, 0.19496646942570806, 13.56818938627839, 90.88423758745193, 81.89277246594429, 69.65506553649902, 86.76235556602478, 84.3308736383915, 76.42820209264755, 53.15232306718826, 33.978232741355896, 83.46524968743324, 84.75613161921501, 79.12961393594742, 14.034570660442114, 0.9152827737852931, 4.214528650045395, 0.9491894231177866, 9.648558162152767, 30.825163833796978, 38.136064633727074, 40.153634771704674, 39.860476702451706, 30.530474446713924, 23.44426888972521, 10.510595105588436, 5.477731442078948, 19.72784411162138, 43.947393000125885, 72.77443215250969, 78.22634160518646, 77.54531174898148, 72.88451224565506, 72.3584608733654, 75.70541247725487, 48.23127172887325, 24.664326421916485, 47.253230810165405, 68.36634948849678, 67.19301044940948, 69.8196043074131, 70.85802018642426, 74.74020346999168, 71.28563404083252, 73.40550228953362, 72.3565685749054, 67.20654532313347, 68.79411533474922, 65.29263362288475, 62.293405160307884, 62.36458674073219, 60.19205331802368, 55.87642729282379, 57.368573024868965, 54.642941281199455, 60.57030402123928, 66.34532153606415, 66.27984344959259, 67.16853216290474, 65.65907835960388, 68.70890870690346, 67.4234376847744, 69.89813089370728, 60.009499713778496, 53.46322238445282, 74.69377756118774, 66.40940889716148, 65.20067855715752, 62.467842400074005, 60.19837237894535, 63.05347837507725, 60.15817053616047, 55.19911363720894, 52.50872880220413, 53.71800631284714, 51.93593613803387, 53.45978356897831, 56.400863751769066, 62.755274176597595, 65.67690700292587, 64.79346200823784, 66.29532381892204, 67.82420217990875, 64.55231934785843, 65.84830060601234, 61.70143112540245, 61.487054228782654, 62.01909027993679, 67.09625244140625, 66.96553945541382, 63.03256429731846, 61.508295089006424, 60.70602513849735, 50.07589794695377, 48.775068148970604, 38.99832956492901, 49.29237999022007, 39.37825217843056, 26.67081255465746, 35.59518277645111, 36.086063235998154, 44.363683462142944, 39.57061305642128, 40.470685958862305, 22.178420014679432, 12.072304654866457, 7.639139061793685, 3.438782226294279, 2.5009355507791042, 3.96129812579602, 3.049481241032481, 1.9876517308875918, 0.34987587423529476, 1.1648062407039106, 1.950915064662695, 9.539333023130894, 3.646493093110621, 2.688286635093391, 51.22263841331005, 99.9486967921257, 51.6521255671978, 58.18306691944599, 54.58135798573494, 64.25832912325859, 69.85934257507324, 65.88823646306992, 51.54546529054642, 83.02417695522308, 23.837222903966904, 1.4208047976717353, 0.15234188555041328, 0.5107238853815943, 0.13975151348859072, 0.1713468923117034, 0.0818667554995045, 0.11637179850367829, 0.16249079955741763, 0.22536722797667608, 0.15657637239200994, 0.09827192247030325, 0.3570629213936627, 0.16750219627283514, 0.17276173748541623, 0.10872618571738712, 0.12625993666006252, 0.20226924709277228, 0.15310279472032562, 0.11596553944400512, 0.16463234089314938, 0.1893962503527291, 0.18107756157405674], [0.02745559930190211, 0.03945302320062183, 0.025186133971146774, 0.07572628499474376, 0.016376213934563566, 0.05152645971975289, 0.047783760746824555, 0.07900875963969156, 0.02737901893851813, 0.07681068891542964, 0.05599880118097644, 0.05212823016336188, 0.016176383251149673, 0.03468537746812217, 0.11333731992635876, 0.029136352277419064, 0.04066650886670686, 0.008212080192606663, 0.07747615047264844, 0.015329059333453188, 0.04346696601714939, 0.05887270126549993, 0.12973059026990086, 0.08580450201407075, 0.13491970166796818, 0.020327324673417024, 0.15651269612135366, 0.4398279724409804, 13.297051135450602, 66.05130851268768, 42.7497124671936, 51.57819673418999, 66.66516557335854, 57.39293351769447, 79.26943883299828, 10.83049139007926, 38.358196914196014, 71.91849008202553, 68.80711063742638, 7.836233535781503, 1.214286235626787, 1.741063843946904, 0.5802357522770762, 0.7173371454700828, 3.5788631346076727, 10.298227351158857, 14.642108660191298, 15.63589783385396, 13.583282176405191, 7.483923565596342, 2.2238168958574533, 1.4973743702284992, 15.962116979062557, 34.81473885476589, 50.55310294032097, 65.82042530179024, 67.83115580677986, 66.38685330748558, 65.1391750574112, 65.55072337388992, 35.73984481394291, 29.41914238035679, 38.79239201545715, 52.53698788583279, 54.07249689102173, 59.702362194657326, 54.84617717564106, 66.24346420168877, 69.63393867015839, 66.72909334301949, 58.812609538435936, 69.65837135910988, 60.01386947929859, 46.71405874192715, 49.39456790685654, 50.74164882302284, 51.97136923670769, 46.40528731048107, 48.25718253850937, 48.978737220168114, 52.51400671899319, 62.1171972155571, 59.85965475440025, 60.48755586147308, 58.29714819788933, 63.355923146009445, 61.79038815200329, 69.40566211938858, 53.496010825037956, 40.696093663573265, 69.23945903778076, 59.56321366131306, 61.86269447207451, 55.245965123176575, 57.12253622710705, 52.41477124392986, 52.45781533420086, 48.05048502981663, 48.48824813961983, 45.140073001384735, 47.63621985912323, 48.94154101610184, 54.330993220210075, 57.13580131530762, 59.33929927647114, 58.46752345561981, 57.696077451109886, 55.00617899000645, 55.07778234779835, 56.240386962890625, 57.3708339035511, 57.64204055070877, 59.21902813017368, 65.80109193921089, 63.66746462881565, 49.76623356342316, 45.09494662284851, 45.73134787380695, 44.49986435472965, 41.24689310789108, 35.4712638258934, 43.25526013970375, 47.26596772670746, 29.160792343318462, 28.25571320950985, 29.010780192911625, 29.130715057253838, 26.889287531375885, 20.6172376871109, 11.471557840704918, 7.91297041811049, 3.9241957291960716, 0.7855792867485434, 1.4299613563343883, 1.5112233208492398, 0.9205551096238196, 0.18260594049934298, 0.6333405745681375, 1.86458773445338, 4.71012513153255, 8.343650233000517, 1.3350195321254432, 1.0048572672531009, 35.88197618722916, 80.64358949661255, 45.5729191750288, 45.006909146904945, 40.643793269991875, 52.64342397451401, 64.35392439365387, 47.393203899264336, 47.85784296691418, 34.776820689439774, 2.279390813782811, 0.509790382348001, 0.22895666974363849, 0.17745151708368212, 0.06363286986015737, 0.12328134922427125, 0.10975762255839072, 0.04163857389357872, 0.05103496499941684, 0.09693099520518444, 0.05329556166543625, 0.06950908384169452, 0.07447354713804089, 0.012603819777723402, 0.027432217939349357, 0.09126214470597915, 0.0443608494970249, 0.06652449243119918, 0.024137930158758536, 0.028282121747906785, 0.04141825993428938, 0.08404815016547218, 0.00726855723769404, 0.03344425051182043, 0.007355912657658337, 0.030194363571354188, 0.028442613038350828, 0.01768735881341854, 0.07912935863714665, 0.09815084107685834, 0.07767669361783192, 0.0420019627927104, 0.03930593695258722, 0.06729501241352409, 0.18173560907598585, 0.02531301710405387, 0.03470900373940822, 0.050135292767663486, 0.04365529712231364, 0.03436281411268283, 0.08078546859906055, 0.08868025746778585, 0.036868920651613735, 0.029089661911712028, 0.04068338901561219, 0.05548940956941806, 0.05661511400830932, 0.09068711384315975, 0.10397506019216962, 0.22322308912407607, 0.8712089387699962, 20.121955163776875, 85.54101750254631, 48.30988571047783, 57.91991963982582, 71.81424647569656, 41.56750850379467, 67.78638660907745, 22.189948596060276, 50.16139715909958, 79.38336431980133, 71.2890462577343, 8.765199612826109, 1.0633953823707998, 5.510395914316177, 2.0233287289738655, 0.9594411542639136, 4.401432070881128, 11.917505711317062, 18.252255991101265, 17.437131330370903, 15.13371393084526, 10.373760648071766, 2.7261651400476694, 2.3885325947776437, 16.191200986504555, 39.60272513329983, 57.78786152601242, 68.2180966436863, 68.95448952913284, 70.27510106563568, 70.05384653806686, 68.2402266561985, 39.04378652572632, 31.697891503572464, 43.35316188633442, 58.90443541109562, 62.4399670958519, 63.586270585656166, 62.0085496455431, 70.10441422462463, 73.44036921858788, 70.82074418663979, 62.50377707183361, 66.6360667347908, 66.41968354582787, 57.08780989050865, 55.48087611794472, 55.622433722019196, 55.3461467474699, 52.081627920269966, 51.73105873167515, 53.14955681562424, 55.33488795161247, 65.58889612555504, 62.86047153174877, 65.26046454906464, 62.266574800014496, 69.18425559997559, 62.73769252002239, 75.87074920535088, 57.77870021760464, 46.463481187820435, 73.96309196949005, 64.07925233244896, 65.5442713201046, 59.05468314886093, 62.614468932151794, 56.48003250360489, 55.466630682349205, 51.275079399347305, 51.4719582349062, 49.38670612871647, 50.38561552762985, 51.32199168205261, 57.90207579731941, 62.13183023035526, 61.75541862845421, 61.92421317100525, 62.472413554787636, 59.917316660284996, 62.19020649790764, 60.29815502464771, 60.90453028678894, 62.26885087788105, 64.31059911847115, 70.2643096446991, 68.33482638001442, 55.92017434537411, 49.931509494781494, 50.92317268252373, 49.170368537306786, 44.84013229608536, 38.918621242046356, 46.122411489486694, 49.08538229763508, 34.536931961774826, 31.60644371062517, 31.546112447977066, 31.598925814032555, 30.694378651678562, 26.160929314792156, 14.21304328367114, 8.799744509160519, 7.0883676409721375, 2.3357410775497556, 2.2732206573709846, 1.264829698484391, 1.3962682080455124, 1.6107619483955204, 0.9985687234438956, 4.217100162059069, 5.308096194639802, 6.124266749247909, 1.1904655513353646, 0.8319315745029598, 40.817774534225464, 81.27175658941269, 55.68358764052391, 58.71791481971741, 33.59265983104706, 48.75874422490597, 67.25569188594818, 54.622711166739464, 56.96164146065712, 43.22454258799553, 2.5106703909114003, 0.2954705123556778, 0.15333289018599316, 0.07000673838774674, 0.026152074424317107, 0.06031619705026969, 0.02388068136497168, 0.029744380881311372, 0.02233529055956751, 0.03719729131262284, 0.02615552170027513, 0.03926107783627231, 0.04373788702650927, 0.07107379831722938, 0.06870606521260925, 0.020880399097222835, 0.01823725313442992, 0.12181613448774442, 0.014217231200746028, 0.05702481292246375, 0.06221893381734844, 0.07708113495027646, 0.007155590301408665, 0.1320479909190908, 0.16439250844996423, 0.20491105533437803, 0.1301025101565756, 0.18235196272144094, 0.27522273478098214, 0.22038047056412324, 0.19925353000871837, 0.15062759863212705, 0.17030439747031778, 0.18347711797105148, 0.21739368239650503, 0.11886377455084585, 0.09527610978693701, 0.22261172271100804, 0.24403375602560118, 0.1534334511961788, 0.17824378941440955, 0.17554498423123732, 0.17745819641277194, 0.20271299203159288, 0.14406440081074834, 0.24220063642133027, 0.21092942770337686, 0.28892726346384734, 0.211127788934391, 0.496259902138263, 1.0010127048008144, 35.76312996447086, 101.51141613721848, 62.408595979213715, 73.99490386247635, 90.03966450691223, 83.07549700140953, 96.81809037923813, 17.61842530220747, 50.749438405036926, 87.41778239607811, 78.52940574288368, 11.147745866328478, 2.077252110466361, 8.084448091685772, 1.408151714131236, 1.4914422947913408, 4.50692581012845, 12.16410107910633, 17.265920117497444, 16.492196135222912, 18.11591360718012, 12.12651539593935, 6.825706260278821, 4.64510397054255, 18.965821601450443, 51.8207111209631, 64.89156514406204, 72.52512753009796, 75.3920128941536, 75.36367401480675, 75.11749282479286, 73.60816061496735, 45.4187386482954, 34.56356853246689, 50.97805693745613, 67.07364365458488, 68.76449212431908, 68.74567553400993, 68.5148075222969, 72.19945460557938, 72.45350897312164, 69.67561483383179, 61.449633836746216, 72.33937829732895, 70.95173835754395, 64.54108715057373, 60.428594425320625, 60.522954761981964, 59.30626004934311, 53.622015863657, 55.31453624367714, 57.212804183363914, 59.21883434057236, 68.70986625552177, 65.28216898441315, 66.98300331830978, 66.13845303654671, 68.80774140357971, 67.7103678882122, 75.96943750977516, 61.90198436379433, 50.594399124383926, 72.84886255860329, 66.97246268391609, 68.41513887047768, 60.64459003508091, 64.71790686249733, 58.822162225842476, 56.32102623581886, 53.194952979683876, 52.38400809466839, 51.104601547122, 51.666443198919296, 54.300602450966835, 62.2668369859457, 66.07527002692223, 65.3021939098835, 64.18937802314758, 66.99748054146767, 63.168194219470024, 65.3376080095768, 61.86391040682793, 63.65003876388073, 63.36006112396717, 65.69568559527397, 72.34640792012215, 70.12370198965073, 55.81554315984249, 49.65206488966942, 50.1420333981514, 51.79141849279404, 46.52511768043041, 44.605719074606895, 49.64168004691601, 53.81269343197346, 38.298847898840904, 34.75478187203407, 34.413457587361336, 35.22394649684429, 37.15355135500431, 31.431565694510937, 18.76084540039301, 8.629830926656723, 9.380991719663143, 4.040710777044296, 2.532454147003591, 2.446361929178238, 1.8874177406542003, 1.1256893584504724, 0.6840352574363351, 4.713991899043322, 10.150606222450733, 16.236281767487526, 3.651464176364243, 1.3291706959716976, 47.82611466944218, 88.53276416659355, 61.03580184280872, 51.128262877464294, 48.10661181807518, 74.24615398049355, 75.97417965531349, 63.731498792767525, 63.14424030482769, 63.602244928479195, 2.0186773035675287, 0.4861956968670711, 0.21858806518139318, 0.24995322979521006, 0.152662196487654, 0.2746468281839043, 0.16901411436265334, 0.12304237767239101, 0.1039338116243016, 0.2901734778424725, 0.08263062583864667, 0.14998952974565327, 0.1699181689764373, 0.11793232726631686, 0.1261670346138999, 0.1502331768278964, 0.21125261817360297, 0.1431382747250609, 0.11221364155062474, 0.15683547098888084, 0.15001756808487698, 0.13959695381345227, 0.1373230281751603], [0.03257446827774402, 0.045488494652090594, 0.09042452715220861, 0.037362092625699006, 0.0797173696628306, 0.027398108832130674, 0.05567669795709662, 0.034179095455328934, 0.04571959201712161, 0.027441118145361543, 0.03621427218604367, 0.025133884919341654, 0.10470720371813513, 0.03925793484086171, 0.022808498761150986, 0.02256225787277799, 0.072193357773358, 0.03083798372244928, 0.05772385295131244, 0.09431416765437461, 0.034191044032922946, 0.059125970292370766, 0.04791161794855725, 0.12128938775276765, 0.038410906854551286, 0.03900432442605961, 0.12915640545543283, 0.12701565079623833, 4.809979973360896, 70.24932324886322, 58.218321427702904, 66.78551271557808, 67.05027490854263, 33.96182902157307, 41.01494215428829, 28.06235298514366, 28.560204170644283, 70.6503689289093, 63.252059519290924, 13.714029360562563, 0.41070544451940805, 5.9904654789716005, 0.8536327444016933, 0.7399452792014927, 0.34243649686686695, 1.5356936515308917, 2.604902721941471, 1.7758971685543656, 2.82040910795331, 2.1859616646543145, 3.5862767742946744, 9.92495533078909, 19.223438277840614, 33.29781465232372, 44.43813666701317, 59.39945764839649, 68.0694030225277, 66.06631770730019, 62.96723820269108, 56.794283241033554, 38.20258766412735, 28.6539451405406, 37.405356243252754, 48.880698680877686, 49.12871137261391, 51.45447917282581, 53.8427460193634, 53.7560498714447, 42.80669800937176, 38.366617262363434, 57.5730324536562, 65.07827952504158, 40.133176669478416, 36.82916276156902, 48.552449494600296, 51.11785143613815, 50.69592967629433, 50.96014469861984, 50.09911090135574, 49.17845830321312, 53.836632147431374, 60.856941640377045, 60.957811027765274, 64.25648242235184, 57.47027076780796, 65.00397071242332, 57.895046174526215, 75.56903779506683, 48.36742602288723, 35.033082738518715, 69.90525931119919, 60.77994257211685, 59.43114414811134, 50.94345219433308, 52.98161722719669, 50.302035212516785, 51.241379007697105, 47.07825779914856, 49.30804654955864, 45.637682899832726, 48.09570640325546, 50.283161625266075, 55.38255639374256, 56.09371103346348, 58.312373980879784, 55.603997111320496, 55.056925266981125, 54.82188507914543, 54.14367847144604, 53.92859861254692, 56.44390784204006, 56.0258124768734, 59.367277175188065, 62.020336613059044, 64.21582460403442, 47.420858815312386, 40.35272888839245, 41.48909971117973, 44.70483675599098, 43.601254373788834, 39.26923982799053, 45.624554604291916, 54.32489834725857, 40.000518187880516, 26.458660438656807, 26.667662523686886, 25.451674573123455, 22.116071060299873, 17.617608346045017, 10.563664007931948, 4.393086768686771, 4.453584747388959, 0.7527564105112106, 0.9689077525399625, 0.459606118965894, 0.20843253121711314, 0.08224783348850906, 1.7309005768038332, 2.14613885153085, 5.619348417967558, 8.653051480650902, 0.18089696735842153, 1.4243071409873664, 43.55533003807068, 58.9735347032547, 32.53204174339771, 24.270032979547977, 49.609066396951675, 50.81308878958225, 58.31304654479027, 47.49451406300068, 47.36636593937874, 6.038688691332936, 1.9667875254526734, 0.10726780616096221, 0.22504629363538697, 0.011561926075955853, 0.10137169520021416, 0.06483341247076169, 0.0341983578982763, 0.06356525278533809, 0.0517828791635111, 0.012040616893500555, 0.07410433609038591, 0.01620363305846695, 0.050423516950104386, 0.09299859957536682, 0.03823057981207967, 0.07895813032519072, 0.03584106838388834, 0.059179917006986216, 0.051845765046891756, 0.11094013098045252, 0.0755690313235391, 0.03595737405703403, 0.03438274077780079, 0.054366848125937395, 0.05128406315634493, 0.03605691461416427, 0.016707265604054555, 0.12228693813085556, 0.012791654571628897, 0.08563495095586404, 0.02377777887886623, 0.05952185041678604, 0.015162719919317169, 0.0654552951164078, 0.018604744254844263, 0.013798427989968332, 0.034176215922343545, 0.044838406683993526, 0.07266894826898351, 0.05218514546868391, 0.010074931160488632, 0.029298068111529574, 0.017466258177591953, 0.06659558275714517, 0.0505488694034284, 0.13239963533123955, 0.04767309539602138, 0.04742557059216779, 0.020101862064620946, 0.04274165024980903, 0.016331018996424973, 7.282657865434885, 90.18140450119972, 62.56892837584019, 67.69332960247993, 76.13627895712852, 41.790381744503975, 36.12247668206692, 29.710111767053604, 47.20682010054588, 77.86366626620293, 72.92634040117264, 14.838254135102034, 0.5641342943999916, 4.90597422234714, 2.542470647022128, 2.1076136687770486, 0.5812304676510394, 2.5795811181887984, 2.360629979521036, 2.0677595073357224, 5.571185052394867, 3.6708668852224946, 2.836928484030068, 12.349102701991796, 18.567023500800133, 38.07545028626919, 50.72859272360802, 66.72128096222878, 68.97557839751244, 68.41592162847519, 67.0313823223114, 64.70773100852966, 39.65760938823223, 31.011604629456997, 43.39204519987106, 59.10433128476143, 57.68182061612606, 60.305530428886414, 59.8164738714695, 65.76227322220802, 52.5952235609293, 48.96609529852867, 61.98190167546272, 69.95153322815895, 54.3828110396862, 49.42617081105709, 57.10213512182236, 57.26348966360092, 56.13886781036854, 53.26396867632866, 53.718184903264046, 53.015378415584564, 56.516130566596985, 63.20816047489643, 64.09777253866196, 68.2551446557045, 62.46702164411545, 66.99020013213158, 64.57875072956085, 78.45667004585266, 51.093730330467224, 40.38780480623245, 74.55839842557907, 64.59518104791641, 64.42134037613869, 55.23481272161007, 57.015541568398476, 54.45797100663185, 53.563160821795464, 50.73151856660843, 53.222942277789116, 49.20630320906639, 51.80574752390385, 53.98921675980091, 59.5893182605505, 61.266312673687935, 63.92389386892319, 59.69103500247002, 60.89139059185982, 57.73017682135105, 57.852556854486465, 56.794412434101105, 60.761224776506424, 61.196244433522224, 62.732722386717796, 67.85138592123985, 69.44882020354271, 52.84221030771732, 46.73644334077835, 46.35001167654991, 49.16659913957119, 48.58407139778137, 43.709259778261185, 50.801951587200165, 57.0303113758564, 42.51710034906864, 30.077158771455288, 28.640733249485493, 29.071782119572163, 26.39406580477953, 22.314965687692165, 11.991217955946922, 5.002753604203463, 6.86664336360991, 1.091369956266135, 3.456883504986763, 1.8754013604484499, 2.0683921733871102, 4.516544044017792, 4.7837119828909636, 6.147865382954478, 5.0188538152724504, 7.176662553101778, 0.7377329072915018, 1.0488931043073535, 46.833243146538734, 70.139030367136, 48.942361772060394, 24.035558961331844, 42.97680728137493, 58.35246182978153, 64.18269038200378, 57.309265807271004, 58.901251181960106, 8.226941395550966, 1.572404787875712, 0.03221363978809677, 0.21110979927470908, 0.04404589315527119, 0.03703849397425074, 0.0860012008342892, 0.02896387901273556, 0.011309239635011181, 0.0548587287630653, 0.04120170866372064, 0.05702849026420154, 0.048544684759690426, 0.05937793685006909, 0.042545355900074355, 0.04568959440803155, 0.0721177106606774, 0.044274704705458134, 0.028463324524636846, 0.0754585923277773, 0.06270402009249665, 0.024779078958090395, 0.04364420201454777, 0.011778391071857186, 0.10789336985908449, 0.161369206616655, 0.178967799001839, 0.15133038279600441, 0.2607105119386688, 0.10011401463998482, 0.23971806338522583, 0.1261628489010036, 0.1075989895616658, 0.13009939313633367, 0.1946423586923629, 0.1455795843503438, 0.13875442324206233, 0.15863609936786816, 0.10278489280608483, 0.09755451057571918, 0.13357834395719692, 0.0840361719019711, 0.11384854835341685, 0.07890821347245947, 0.22438162617618218, 0.16438072314485908, 0.24554154777433723, 0.18514797440730035, 0.28009671543259174, 0.13711225823499262, 0.23242684837896377, 0.2647675067419186, 13.30595975741744, 112.6615758240223, 77.76822298765182, 82.46420100331306, 90.46474009752274, 57.10834018886089, 62.318590208888054, 38.27122338116169, 42.216844260692596, 83.95212516188622, 76.87666922807693, 18.56000527739525, 1.7768459301441908, 13.951364625245333, 4.117346964776516, 1.775081637315452, 0.637812934583053, 2.172394492663443, 3.2656732527539134, 1.9026867463253438, 4.074313323944807, 3.7775561353191733, 6.900742733851075, 18.716817162930965, 24.75711364299059, 44.57395277917385, 57.352245301008224, 70.13306468725204, 73.29472303390503, 73.32833603024483, 72.91950076818466, 69.71897810697556, 44.47638921439648, 32.112092077732086, 49.2275782674551, 67.11777448654175, 63.2640440762043, 67.58106842637062, 63.89408066868782, 62.654609978199005, 50.541163980960846, 50.436973571777344, 62.45146527886391, 74.7234995663166, 62.73603580892086, 59.74961265921593, 65.81320568919182, 62.99509450793266, 59.94612291455269, 57.93012209236622, 58.50004971027374, 56.56599149107933, 60.4760804772377, 68.42792138457298, 68.03059190511703, 71.81656435132027, 66.68353378772736, 71.07557371258736, 66.0446284711361, 81.29672884941101, 54.31398153305054, 43.83286714553833, 76.68551668524742, 68.96119236946106, 66.90348118543625, 56.02602906525135, 58.761038705706596, 57.422784715890884, 57.67565354704857, 52.653687223792076, 56.036554500460625, 51.659265384078026, 55.996671840548515, 56.700325682759285, 63.48683752119541, 62.071386873722076, 65.3532175719738, 63.25274348258972, 62.352609783411026, 59.2135564237833, 60.064843744039536, 57.852617651224136, 61.52263551950455, 63.01002010703087, 64.42264750599861, 67.858195155859, 70.18810853362083, 55.217983424663544, 49.01959642767906, 46.43613785505295, 49.94383603334427, 51.13777756690979, 45.810885205864906, 55.52192911505699, 58.53048987686634, 45.07441632449627, 32.30295583605766, 31.91772110760212, 32.264764085412025, 30.799154229462147, 26.21462043374777, 14.259471092373133, 4.906325228512287, 9.146004728972912, 1.7294422863051295, 2.064234483987093, 1.748078742530197, 1.0796889080666006, 3.4161093179136515, 4.072614815086126, 7.841091575101018, 17.521600797772408, 18.56228705495596, 1.305700067896396, 1.3511892082169652, 52.67794892191887, 76.27040416002274, 40.34821093082428, 25.98402790725231, 67.81819090247154, 67.10587352514267, 73.5010215640068, 62.145817279815674, 76.84008479118347, 15.64308799803257, 1.8058330309577286, 0.37926144897937775, 0.23298681364394724, 0.08005569994566031, 0.17552497592987493, 0.1449848123593256, 0.14939165557734668, 0.1759063804638572, 0.10706304019549862, 0.12573354615597054, 0.2598401211434975, 0.1385535832378082, 0.15948596235830337, 0.095898727158783, 0.1687457092339173, 0.22124343988252804, 0.15756368113216013, 0.25106983550358564, 0.15720031078672037, 0.17300161445746198, 0.1585621666163206, 0.10967692884150892, 0.1918815544922836], [0.04345593770267442, 0.004655401926356717, 0.03249810870329384, 0.023214691027533263, 0.03981346577347722, 0.0554941370501183, 0.07465422298992053, 0.05276738629618194, 0.06102800944063347, 0.08620769600383937, 0.054905428405618295, 0.032533783742110245, 0.028187137977511156, 0.07925337893539108, 0.09096581998164766, 0.022626650315942243, 0.11621513112913817, 0.09167407377390191, 0.013204879614931997, 0.025421012578590307, 0.052670124132419005, 0.03208666945283767, 0.12864947406342253, 0.019655005671666004, 0.08934062047046609, 0.12742343125864863, 0.04744253608805593, 0.012747342789225513, 0.13989323400892317, 47.74464324116707, 67.97650560736656, 89.79251816868782, 68.95867690443993, 48.77674765884876, 48.385558649897575, 46.61846727132797, 14.766437988728285, 53.37100513279438, 68.99244949221611, 10.24975810199976, 0.28199842432513833, 2.0066127134487033, 3.3771732822060585, 0.8859557099640369, 0.6799932243302464, 1.9785611936822534, 1.2263119965791702, 0.11287807894404978, 0.5031304084695876, 0.7769343943800777, 5.144755784422159, 12.316982075572014, 19.971941113471985, 29.51530572026968, 38.51882949471474, 50.05713455379009, 58.704509139060974, 59.393860548734665, 61.797828152775764, 51.95441074669361, 38.93854357302189, 25.260569527745247, 39.82392266392708, 48.4606958180666, 47.52621956169605, 52.795066237449646, 49.83673498034477, 33.67421105504036, 15.508134439587593, 17.733815610408783, 46.03252351284027, 54.28992122411728, 29.820801727473736, 34.3401101231575, 43.99856485426426, 51.292110085487366, 50.98786041140556, 53.618162870407104, 48.79182144999504, 51.76926948130131, 49.76442486047745, 61.31843827664852, 60.850869566202164, 63.33173744380474, 58.798588290810585, 64.57832515239716, 62.57186561822891, 70.96831306815147, 51.70721501111984, 31.350468546152115, 66.87976285815239, 60.175121426582336, 58.11365984380245, 54.63690720498562, 53.69493015110493, 50.087715312838554, 50.3680794686079, 48.36679145693779, 47.802221551537514, 47.3795398324728, 49.15967971086502, 51.81796006858349, 53.89679431915283, 55.64791515469551, 54.48657967150211, 56.5801153331995, 54.17034924030304, 52.13110126554966, 50.677078887820244, 52.32966721057892, 55.305580124258995, 57.26034343242645, 58.61263766884804, 63.36615599691868, 64.18322995305061, 57.38438777625561, 49.42142106592655, 38.15241515636444, 37.89095118641853, 42.57861144840717, 38.411800637841225, 46.33912906050682, 52.66031786799431, 50.730279833078384, 29.19783655554056, 25.06259825080633, 22.832315526902676, 20.18009964376688, 13.916860576719046, 8.330234102904797, 4.23326306976378, 1.9504075543954968, 0.6449686631094664, 3.7715044850483537, 0.014645294559159083, 2.6964217610657215, 2.7753981482237577, 4.508978174999356, 4.968150286003947, 4.0214472357183695, 1.016263305209577, 0.8468780131079257, 0.6046648195479065, 53.05456951260567, 40.30565321445465, 14.0593196824193, 45.12455463409424, 54.73906472325325, 53.035821318626404, 46.99992500245571, 59.36107590794563, 24.611801840364933, 1.225296501070261, 0.5995254765730351, 0.2324281248729676, 0.1321784604806453, 0.019418744814174715, 0.04119527424336411, 0.004301019916965743, 0.07137991939089261, 0.02607103560876567, 0.05059854876890313, 0.0212972170629655, 0.024186529699363746, 0.0804204581072554, 0.04045047709951177, 0.04409107510582544, 0.07392795727355406, 0.03322195501823444, 0.01047938587362296, 0.02003731748118298, 0.012412363303155871, 0.05855498413438909, 0.10380994717706926, 0.02164397814340191, 0.05489669332746416, 0.07915627633337863, 0.08881045985617675, 0.04919866900308989, 0.08246039942605421, 0.06309926568064839, 0.05576777803071309, 0.05117060733027756, 0.09722720118588768, 0.0673540576826781, 0.04324939058278687, 0.09141090820776299, 0.03360754897585139, 0.07734183658612892, 0.04293513185984921, 0.04731164350232575, 0.009712687951832777, 0.10154841540497728, 0.11845094748423435, 0.010958761322399369, 0.04863021727942396, 0.05983007918985095, 0.004813306832147646, 0.044992053517489694, 0.052508065055008046, 0.05760727639426477, 0.11745264753699303, 0.006916798256497714, 0.013486137813742971, 0.3617174341343343, 57.530026361346245, 80.3428204357624, 89.70734193921089, 77.9824934899807, 56.47576533257961, 43.35079461336136, 30.465896911919117, 28.224351592361927, 65.54459050297737, 72.88972556591034, 11.417410746216774, 0.17671259032795206, 6.485951766371727, 6.129061141982675, 3.512170775793493, 3.0933933472260833, 3.5495928302407265, 1.121768206357956, 0.41055098874494433, 2.2304416028782725, 1.1528820055536926, 7.764596454799175, 12.874445412307978, 19.20028991997242, 32.82251715660095, 45.8661912381649, 55.52469916641712, 63.13779965043068, 66.50479137897491, 66.90486431121826, 55.51126688718796, 42.19096004962921, 30.126003250479698, 42.37245351076126, 55.12393847107887, 57.18738354742527, 59.09746505320072, 57.21499286592007, 41.182851344347, 21.279692240059376, 25.826085582375526, 57.94534407556057, 64.09388154745102, 38.754173666238785, 47.734976559877396, 51.63569524884224, 57.66554228961468, 55.12426905333996, 57.09675081074238, 51.63001835346222, 54.664790108799934, 53.33632819354534, 64.37674596905708, 62.15060122311115, 68.35146188735962, 61.17386743426323, 68.99434939026833, 64.64577913284302, 77.85093694925308, 54.912415221333504, 35.09576037526131, 71.38555347919464, 65.50736770033836, 62.20850631594658, 57.79412738978863, 57.18613341450691, 53.67995895445347, 53.393355533480644, 52.368862107396126, 51.61112956702709, 51.321410313248634, 53.11556003987789, 54.35718521475792, 58.65212894976139, 59.53224532306194, 58.267836570739746, 59.812655076384544, 58.05893138051033, 55.42871251702309, 55.19035890698433, 58.44908304512501, 59.57480303943157, 62.78844639658928, 65.80492973327637, 69.6590781211853, 68.15217018127441, 62.157266065478325, 53.79392243921757, 43.62683080136776, 44.91868168115616, 46.56500793993473, 43.04374448955059, 49.887865036726, 57.230906412005424, 52.24730663001537, 32.49171070754528, 27.034574635326862, 24.58698347210884, 23.448784947395325, 15.563466120511293, 10.30068201944232, 4.65458826161921, 3.329865583218634, 2.0316293835639954, 7.565653380006552, 3.6091230483725667, 6.168073648586869, 6.598033402115107, 8.063684105873108, 7.772304341197014, 5.408363789319992, 2.476059948094189, 1.058693490922451, 0.6282279489096254, 54.341910034418106, 49.197191298007965, 17.015823237597942, 41.587476432323456, 56.30110390484333, 56.63390524685383, 49.61853928864002, 73.40040296316147, 28.024195432662964, 1.0827358695678413, 0.33415849262382835, 0.13455085427267477, 0.04355478064098861, 0.01608137350558536, 0.06762857810826972, 0.06102307786932215, 0.07842815524782054, 0.03552594505890738, 0.11188769029104151, 0.0324597619328415, 0.06876288403873332, 0.05194098259380553, 0.07116305641829967, 0.13819649146171287, 0.020181043655611575, 0.0038916967150726123, 0.02775559580186382, 0.04419425218657125, 0.03553490278136451, 0.053749177168356255, 0.03610863859648816, 0.02321163337910548, 0.06664494299911894, 0.12161701626610011, 0.15362477686721832, 0.1484841573983431, 0.19020290550542995, 0.15448344172909856, 0.10800655480124988, 0.09648713152273558, 0.1241561483766418, 0.10612660567858256, 0.08958089820225723, 0.1326666006934829, 0.177289669518359, 0.12663074332522228, 0.16151634481502697, 0.0981526444957126, 0.07420180234475993, 0.26617414376232773, 0.2627583348657936, 0.08840383714414202, 0.12510942964581773, 0.24282659345772117, 0.12633124220883474, 0.13795630278764293, 0.11485380964586511, 0.22602782846661285, 0.33026307821273804, 0.17006489157211035, 0.10557958346907981, 0.3516162995947525, 80.52785530686378, 89.62295606732368, 102.266656011343, 88.9003412425518, 71.46589636802673, 77.80451104044914, 63.56993526220322, 26.668156497180462, 65.40859580039978, 82.51444190740585, 13.883782401680946, 0.3620585845783353, 8.376717958599329, 8.160655852407217, 4.872184535488486, 2.198937493376434, 3.34370254073292, 1.5449791657738388, 0.46057349361944944, 1.108958381228149, 1.169147863984108, 11.694046352058649, 14.59754940122366, 21.422572173178196, 37.20143638551235, 53.55689495801926, 60.84270380437374, 67.97838270664215, 73.27875629067421, 72.49168172478676, 58.711584359407425, 46.07817806303501, 31.818286143243313, 47.104442194104195, 61.706348061561584, 64.26148295402527, 64.46409568190575, 54.69179905951023, 42.88104481995106, 29.404585361480713, 32.945873737335205, 63.55662077665329, 69.39094170928001, 50.26164337992668, 60.9234456717968, 60.84276080131531, 64.23454999923706, 58.80945570766926, 62.77613125741482, 56.320976838469505, 58.747378438711166, 57.69812934100628, 67.02485427260399, 65.73499828577042, 70.40238663554192, 64.09807652235031, 72.52090975642204, 70.54279670119286, 79.03874561190605, 59.084861129522324, 38.121325224637985, 72.12093561887741, 69.20332297682762, 64.04727324843407, 60.308197885751724, 60.617486089468, 56.5837175399065, 56.73127502202988, 53.89655493199825, 54.2945721745491, 53.63362044095993, 55.80508232116699, 56.85902036726475, 59.98057186603546, 61.034027338027954, 60.3307268768549, 63.13710808753967, 60.77185660600662, 57.123862355947495, 56.34779579937458, 59.01342876255512, 61.11618272960186, 63.969734609127045, 66.13798186182976, 71.9808979332447, 69.47579115629196, 63.12296524643898, 55.018585324287415, 48.57304058969021, 45.09827144443989, 49.58314038813114, 45.062880143523216, 53.10300551354885, 58.167119175195694, 55.22742971777916, 34.52865220606327, 30.127234384417534, 26.85884166508913, 25.120550841093063, 17.72734645754099, 9.65665552765131, 6.722325682640076, 4.581179050728679, 1.6177178313955665, 8.345474135130644, 2.866617478430271, 8.682004977017641, 9.543603993952274, 12.079594563692808, 13.058469537645578, 13.159836698323488, 4.624619744718075, 2.129467483609915, 0.7129842415452003, 61.2691131234169, 52.33613446354866, 20.516757778823376, 61.617277041077614, 70.05184024572372, 69.23112988471985, 57.26883977651596, 79.5238883793354, 45.79255498945713, 1.000616338569671, 0.6902864563744515, 0.16675163264153525, 0.13808926596539095, 0.19539675180567428, 0.2427416917635128, 0.09207818060531281, 0.14011194492923096, 0.07849315996281803, 0.1798954835976474, 0.13886052067391574, 0.10143616556888446, 0.14647231379058212, 0.10933858371572569, 0.21088408248033375, 0.15796720166690648, 0.11064043690566905, 0.0828984372492414, 0.078393882868113, 0.4257165687158704, 0.15028107503894717, 0.2003977436106652, 0.09578413955750875, 0.13210676901508123], [0.07535941171227023, 0.10338575040805154, 0.05996070831315592, 0.08222891614423133, 0.07967575002112426, 0.07630999898537993, 0.06994941490120254, 0.010664110141078709, 0.0925224376260303, 0.11414419030188583, 0.07317931580473669, 0.026965809665853158, 0.0679481914266944, 0.025686744120321237, 0.08251727020251565, 0.04312156677769963, 0.012656551225518342, 0.0042631406995496945, 0.05460966029204428, 0.08558129367884248, 0.05370423641579691, 0.08752949070185423, 0.034365656538284384, 0.1322185661410913, 0.03843988772132434, 0.05831617956573609, 0.09067667182534933, 0.19322243722854182, 0.20329480612417683, 9.225865993648767, 86.23916164040565, 58.414333909749985, 44.25127409398556, 61.325901076197624, 57.82004579901695, 62.33959548175335, 28.88141043484211, 42.61832691729069, 85.43449401855469, 7.480374556034803, 0.17612083145650104, 0.7965134968981147, 3.89619835652411, 2.1208151103928685, 5.3820516262203455, 0.5603449477348477, 0.28470200893934816, 3.997991569340229, 6.360328132286668, 1.7475747945718467, 2.638723044656217, 12.134358175098896, 14.552906546741724, 22.981499321758747, 28.325564861297607, 38.100376948714256, 49.56669867038727, 57.640269845724106, 51.562237590551376, 46.62029877305031, 29.782562479376793, 20.841944329440594, 36.32056005299091, 47.40607000887394, 47.426801696419716, 51.58939853310585, 36.01052328944206, 17.204464115202427, 18.512701615691185, 35.50675772130489, 53.625914454460144, 49.01220582425594, 30.532311648130417, 33.30018192529678, 38.55863995850086, 50.04148319363594, 47.83174976706505, 50.88772438466549, 49.59913372993469, 53.2169234007597, 51.01712644100189, 58.80208410322666, 61.490219458937645, 64.49117302894592, 58.28690014779568, 65.03933161497116, 60.28380699455738, 68.07413756847382, 53.3039653301239, 28.237185403704643, 66.76592856645584, 61.46365128457546, 59.26868386566639, 59.74231705069542, 54.921891912817955, 48.61954249441624, 47.13141694664955, 48.128312453627586, 47.0421027392149, 48.80680404603481, 47.65386611223221, 50.09605586528778, 51.506813764572144, 54.925965294241905, 54.750490710139275, 51.43507361412048, 50.91455094516277, 54.300317466259, 53.908022716641426, 51.60778574645519, 56.00367106497288, 52.76997998356819, 57.59734354913235, 58.721444830298424, 61.26408599317074, 61.64823018014431, 60.76710306107998, 40.15341818332672, 34.3570002168417, 36.34700283408165, 41.06357954442501, 46.444239020347595, 54.494855627417564, 53.85227970778942, 36.841367706656456, 22.828403636813164, 23.074626624584198, 14.602389391511679, 11.314307078719139, 4.866751302033663, 3.3493989100679755, 0.06427833795896731, 1.5872680465690792, 7.53048911690712, 3.152250526472926, 6.039337031543255, 7.076547900214791, 6.818865677341819, 5.569978142157197, 1.1318920506164432, 4.059376800432801, 0.36966271873097867, 0.7764366804622114, 52.985994592309, 36.96894586086273, 42.00664333999157, 52.349403351545334, 61.068825870752335, 50.19223250448704, 56.92452125251293, 55.51406733691692, 2.6008877623826265, 0.9125497110653669, 0.12626661598915234, 0.28200370841659606, 0.05619304720312357, 0.06516928624478169, 0.057857061037793756, 0.09013580944156274, 0.06162665915326215, 0.16022241034079343, 0.07155194922233932, 0.04520375114225317, 0.02348640984564554, 0.04917895385005977, 0.04390579051687382, 0.04897223974694498, 0.05667728000844363, 0.06276568514294922, 0.01659202120208647, 0.033771986636566, 0.05620818330498878, 0.027398374149925075, 0.03645446086011361, 0.0722465846047271, 0.017448364997108, 0.01695118913630722, 0.09080106319743209, 0.09057456714799628, 0.05190569718251936, 0.11070115942857228, 0.03374992258613929, 0.047233487930498086, 0.058445365211809985, 0.08019779153983109, 0.08459275297354907, 0.12568668695166707, 0.0035959165415988537, 0.022453039709944278, 0.05033959860156756, 0.08260761183919385, 0.05200205763685517, 0.01441784763301257, 0.027587640361161903, 0.04861890323809348, 0.07525505832745694, 0.06182502780575305, 0.03490083407086786, 0.06881922789034434, 0.1448185119079426, 0.06655439356109127, 0.08859507375746034, 0.12008563164272346, 0.4281649139011279, 0.13533810968510807, 10.59746889397502, 96.63424104452133, 70.75509890913963, 49.81040999293327, 66.93030774593353, 61.76912069320679, 45.02088479697704, 28.359647132456303, 63.07224936783314, 89.05052438378334, 8.166126608848572, 0.04195822431938723, 4.65985762886703, 9.87235950306058, 8.698136061429977, 5.47616402618587, 4.114422546699643, 1.9540240103378892, 4.246494909748435, 4.868751894682646, 3.297302993014455, 4.248207192867994, 16.114015728235245, 15.678510647267103, 25.69492232054472, 31.583688631653786, 44.23726424574852, 51.940024718642235, 60.56296281516552, 54.79242146015167, 50.37616923451424, 34.7530073672533, 23.277357146143913, 42.306994423270226, 53.06870475411415, 53.30469869077206, 55.68956471979618, 44.94720675051212, 24.68505620956421, 26.895257011055946, 39.78599689900875, 61.498107835650444, 54.4571578502655, 38.21664310991764, 44.64863397181034, 51.55941814184189, 57.97283560037613, 52.60147802531719, 55.08944012224674, 52.45675899088383, 57.15539686381817, 56.345964297652245, 62.341331988573074, 65.85716173052788, 68.9493978023529, 62.74965047836304, 70.45062124729156, 66.06494978070259, 73.01625117659569, 59.375697523355484, 34.282075837254524, 73.36868226528168, 66.38150319457054, 66.50178954005241, 63.28132554888725, 60.04712909460068, 54.08920459449291, 52.52153791487217, 53.57294909656048, 52.266594395041466, 51.24012127518654, 51.413346379995346, 54.019858315587044, 57.1608267724514, 59.22721669077873, 57.801217809319496, 55.05770042538643, 54.26442839205265, 55.218918174505234, 55.70618122816086, 55.27844198048115, 60.66527612507343, 58.90414662659168, 63.80758211016655, 65.93627348542213, 67.4958086013794, 66.28183454275131, 65.354243516922, 43.229942098259926, 40.272857174277306, 41.777055859565735, 46.23386710882187, 50.7626236975193, 59.005669578909874, 56.17389053106308, 38.24500858783722, 25.2581699565053, 26.562360674142838, 17.12584063410759, 13.835164960473776, 5.829886570572853, 4.947955794632435, 1.0993698332458735, 3.4611162403598428, 8.13416177406907, 7.628015633672476, 10.250425916165113, 11.50794468820095, 8.220364898443222, 8.031638525426388, 3.3879098435863853, 2.653427543118596, 0.2993905363837257, 0.5676762980874628, 62.43665747344494, 40.2428387850523, 40.194436982274055, 51.77305407822132, 63.666130900382996, 49.235899820923805, 63.168281614780426, 59.528422728180885, 2.572077470831573, 0.4274939827155322, 0.08696190358023159, 0.18940717476652935, 0.05954879037744831, 0.06161915975098964, 0.07062257252982818, 0.09617453892133199, 0.04270136276318226, 0.12921617802930996, 0.05046585647505708, 0.04580710607115179, 0.03769934308365919, 0.0204100815608399, 0.03251910035032779, 0.13290788774611428, 0.024475108257320244, 0.01135403937951196, 0.027068287272413727, 0.014760746762476629, 0.03327622085635085, 0.05329552084731404, 0.048795085385791026, 0.10058890751679428, 0.02493445499567315, 0.15922941674944013, 0.3918062086449936, 0.1509507148875855, 0.16524816019227728, 0.13866618188330904, 0.11332563110045157, 0.13025677297264338, 0.140601406164933, 0.19287759088911116, 0.15486867574509233, 0.24846581742167473, 0.14098128187470138, 0.21262278605718166, 0.18112268415279686, 0.23749865591526031, 0.20320197829278186, 0.08005917319678701, 0.18602465861476958, 0.17566696362337098, 0.16057493048720062, 0.21242628019535914, 0.24576634430559352, 0.24242020823294297, 0.21906577079789713, 0.14200624718796462, 0.22870689252158627, 0.32469337864313275, 0.7512461103033274, 0.386622158694081, 17.55604214966297, 119.96400117874146, 82.93036758899689, 64.89481776952744, 77.6856230199337, 88.074721544981, 85.15609815716743, 40.7122465968132, 61.39601491391659, 101.66571825742722, 11.25435484573245, 0.9184400481171906, 8.154555279761553, 19.30272102355957, 7.00760867446661, 11.802004259079695, 2.2726765740662813, 1.1755441082641482, 5.981233399361372, 12.507678642868996, 4.843384455889463, 5.53404632024467, 20.629511028528214, 19.330489933490753, 28.184550628066063, 35.427790358662605, 48.92169468104839, 53.943573608994484, 68.75937759876251, 57.81215362250805, 54.18453007936478, 38.5084218531847, 26.373474709689617, 47.64223113656044, 59.03899759054184, 58.679848462343216, 56.23984359204769, 47.50297240912914, 30.041286796331406, 35.793676525354385, 49.59479436278343, 69.84689444303513, 64.36106041073799, 52.7962289750576, 56.343923807144165, 62.29963302612305, 66.66902616620064, 58.4611663967371, 60.590948313474655, 54.34607461094856, 60.5942427366972, 57.82157711684704, 65.6043840944767, 68.73614564538002, 71.19774475693703, 65.25649756193161, 74.71505641937256, 69.48505505919456, 76.43034517765045, 61.04543052613735, 37.878244668245316, 75.46614691615105, 68.65716308355331, 67.76741042733192, 67.19924971461296, 61.097442135214806, 56.20830528438091, 55.04133090376854, 54.66285601258278, 57.27072827517986, 52.80170828104019, 53.22863057255745, 57.92767882347107, 58.27701307833195, 62.024463191628456, 59.397831335663795, 55.247466042637825, 55.52976429462433, 55.82034610211849, 56.03576794266701, 56.05436034500599, 64.7337444126606, 59.11966346204281, 62.76658996939659, 65.69190099835396, 67.31587305665016, 65.43406203389168, 64.34693276882172, 46.43462173640728, 40.32871417701244, 42.86250561475754, 47.54339464008808, 51.11837200820446, 60.3521653264761, 59.67681996524334, 41.60708338022232, 27.68965758383274, 30.27558982372284, 18.626663200557232, 13.057249803096056, 5.2959829196333885, 6.032941974699497, 2.187495119869709, 3.1611617607995868, 16.174717471003532, 10.92164184898138, 12.570399977266788, 16.10123511403799, 14.509635418653488, 15.887433886528015, 6.656830497086048, 9.428440723568201, 1.1480164853855968, 0.6905093975365162, 67.18310818076134, 51.29287764430046, 56.02602146565914, 66.17592662572861, 78.71777683496475, 62.330749556422234, 70.14058068394661, 79.96484711766243, 8.113168850541115, 0.9051525767426938, 0.22401849331799895, 0.37502906983718276, 0.17525340925203636, 0.26691299630329013, 0.23031879274640232, 0.24886277737095952, 0.10160193167394027, 0.25323940033558756, 0.19488520425511524, 0.13948488951427862, 0.15462179289897904, 0.1425237170769833, 0.12781644298229367, 0.1819245598744601, 0.16832537163281813, 0.20703138608951122, 0.1458782097324729, 0.14466922148130834, 0.10811400294187479, 0.21958984580123797, 0.10075370140839368, 0.20822133083129302, 0.10199846117757261], [0.025008996308315545, 0.0322366500768112, 0.05368962723878212, 0.009571531463734573, 0.03976172323746141, 0.04964081461366732, 0.04777013120474294, 0.04088386907824315, 0.07470799158909358, 0.07314791553653777, 0.015539722589892335, 0.0510148119792575, 0.07700372152612545, 0.02882624958147062, 0.05376129272917751, 0.16777794866357, 0.06887971292599104, 0.0827993976417929, 0.0846062229538802, 0.051411430540611036, 0.0729286034766119, 0.1281049899989739, 0.06389861810021102, 0.0911948319117073, 0.050522322781034745, 0.050762956743710674, 0.10438022829475813, 0.030901038444426376, 0.01477692929256591, 0.3146520908921957, 22.118360437452793, 90.59438914060593, 70.64966976642609, 42.54840686917305, 68.00797551870346, 65.36948069930077, 49.18012261390686, 28.553070053458214, 70.65690457820892, 6.920283185318112, 0.053452781939995475, 6.105179898440838, 7.5689117051661015, 6.3909863121807575, 5.417494224384427, 4.990408066660166, 3.86418079957366, 0.8537570689804852, 2.7283317362889647, 2.2417317470535636, 1.5089643420651555, 8.832557648420334, 9.216599240899086, 14.058676566928625, 19.075542613863945, 23.037766702473164, 30.981614738702774, 36.793372482061386, 40.761351361870766, 36.87440313398838, 18.912402167916298, 17.408532164990902, 31.608368307352066, 37.350544184446335, 48.06333214044571, 43.004541993141174, 26.87667790800333, 26.12171731889248, 52.803657576441765, 64.35545191168785, 68.96047040820122, 54.80422742664814, 37.52958297729492, 37.79727101325989, 43.09953689575195, 47.46711753308773, 50.06471514701843, 55.68609170615673, 53.57741005718708, 54.32041838765144, 51.920721754431725, 56.361684054136276, 61.627430096268654, 62.00412668287754, 61.3793870061636, 63.87894228100777, 62.08737261593342, 69.52628284692764, 54.41482812166214, 24.98768337070942, 64.82135251164436, 61.77520416676998, 64.94069650769234, 60.24846509099007, 62.304861545562744, 54.05933819711208, 49.33881729841232, 47.637416794896126, 48.49727265536785, 50.647949650883675, 50.380147621035576, 49.63248074054718, 52.26004354655743, 50.61657093465328, 51.65921978652477, 55.770990550518036, 56.33498288691044, 54.82741378247738, 56.47531695663929, 52.4064876884222, 54.00736078619957, 53.638864159584045, 57.259188294410706, 56.062495708465576, 61.517881974577904, 60.078279823064804, 62.85652734339237, 44.36032824218273, 25.216774977743626, 25.11242877691984, 37.758140712976456, 48.444839268922806, 49.6368733048439, 45.89983843266964, 40.61386227607727, 24.416385926306248, 20.250944942235947, 17.8418780118227, 7.007458582520485, 1.6515912325121462, 3.323681652545929, 0.40033336670603603, 7.001683367416263, 7.515017772093415, 7.436138279736042, 5.602865852415562, 9.737911317497492, 6.637561256065965, 6.751007018610835, 1.5935859200544655, 2.609397880733013, 0.14853573666187003, 3.5535056702792645, 51.79820112884045, 32.18510515987873, 40.267351269721985, 63.068723157048225, 53.77044729888439, 47.71514542400837, 67.21830949187279, 15.603746809065342, 0.9724257106427103, 0.14939771150238812, 0.18265891500050202, 0.10454548973939382, 0.1561663654865697, 0.05169395502889529, 0.014467667078861268, 0.06528426718432456, 0.05537472177820746, 0.06244450589292683, 0.016844698366185185, 0.10562060197116807, 0.08903671841835603, 0.037655022024409845, 0.013369335829338524, 0.05575025592406746, 0.018442959772073664, 0.03773089549213182, 0.02388114335190039, 0.020687151263700798, 0.0917651056079194, 0.020279873606341425, 0.0769374922674615, 0.05745939975895453, 0.08569883502786979, 0.005579532562478562, 0.031523527795798145, 0.03694984072353691, 0.03445813927100971, 0.02420987580990186, 0.025648953960626386, 0.046889547011232935, 0.05208363079873379, 0.036004177600261755, 0.029825334349879995, 0.038803180141258053, 0.04850116521993186, 0.06322134897345677, 0.023762249438732397, 0.05970036661892664, 0.11521188105689362, 0.10044204391306266, 0.05184154593735002, 0.06338276609312743, 0.03453932651609648, 0.048836660498636775, 0.09921916265739128, 0.09218958439305425, 0.0698396735242568, 0.14051567326532677, 0.03417907690163702, 0.13680342090083286, 0.08754251539357938, 0.048819309085956775, 0.33868220925796777, 25.79065628349781, 105.32698139548302, 73.17185282707214, 43.552172407507896, 79.62349623441696, 63.828458189964294, 35.18586494028568, 41.79159387946129, 92.9140430688858, 8.176760338246822, 0.0658990400552284, 5.33579433336854, 8.663878049701452, 12.96470481902361, 10.593260619789362, 5.750458957627416, 5.650623114779592, 6.184976091608405, 3.582927966490388, 2.2922932589426637, 2.2699499828740954, 11.79999416694045, 10.752948950976133, 16.82973202317953, 24.456122294068336, 30.523416325449944, 35.77402397990227, 46.46315060555935, 43.8968975096941, 41.21940158307552, 23.581870906054974, 21.446630582213402, 36.12261727452278, 42.39478871226311, 53.3140803873539, 49.18184012174606, 32.49614506959915, 33.536411449313164, 56.04727752506733, 64.09265041351318, 73.20867285132408, 58.172761872410774, 43.6805447191, 46.49926766753197, 53.065714314579964, 57.34151467680931, 54.997678846120834, 60.04626654088497, 57.339512184262276, 57.42133319377899, 56.66609711945057, 59.902326464653015, 65.23031696677208, 65.9210667014122, 64.13447096943855, 67.94936746358871, 65.07413774728775, 74.78605940937996, 59.45634439587593, 28.031217455863953, 69.48433309793472, 67.41427257657051, 69.45370674133301, 65.1859125494957, 66.55204564332962, 57.52385549247265, 52.85098783671856, 51.29124753177166, 53.839462995529175, 54.38964307308197, 55.28206318616867, 52.401000782847404, 55.08353903889656, 52.269311249256134, 56.73934958875179, 57.40396812558174, 59.79055546224117, 58.56765568256378, 61.89344622194767, 59.0363035351038, 61.02002128958702, 58.96345004439354, 63.14432010054588, 62.26270280778408, 67.22782418131828, 68.12684074044228, 67.41070836782455, 52.76606619358063, 31.884617283940315, 29.125463739037514, 46.736139357089996, 54.25704538822174, 53.9556759595871, 51.977403312921524, 45.475526601076126, 26.335602141916752, 22.2487523406744, 19.923552609980106, 8.617562334984541, 1.7502315645106137, 6.694167293608189, 0.3278277354547754, 6.92598145455122, 11.832513771951199, 11.099711693823338, 7.92658556252718, 12.542962599545717, 8.03723942488432, 7.096875859424472, 2.2393962973728776, 2.0415387768298388, 0.37011361797340214, 4.085599668323994, 57.845474034547806, 43.409326672554016, 41.02775886654854, 68.12606558203697, 61.19674600660801, 50.330324694514275, 76.88771143555641, 14.098535478115082, 0.799545852933079, 0.10535898749367334, 0.1672138719004579, 0.04857678635744378, 0.07595698902150616, 0.00641953241029114, 0.05032256631238852, 0.069277875154512, 0.07508007474825718, 0.023237756977323443, 0.018805643630912527, 0.04271919657185208, 0.04467454047698993, 0.0613367206096882, 0.09397367772180587, 0.06296287378063425, 0.08885752686182968, 0.026668356877053156, 0.010989205147780012, 0.07016278977971524, 0.0506957367178984, 0.045492832505260594, 0.00762234923968208, 0.019872905795637053, 0.09690102728200145, 0.17102450336096808, 0.09750972938491032, 0.17961348232347518, 0.1793176622595638, 0.10297654502210207, 0.16494993556989357, 0.18429073446895927, 0.2045736601576209, 0.21247468306683004, 0.22600011667236686, 0.10871449689147994, 0.11991228078841232, 0.1803849299903959, 0.11979472459643148, 0.1764644161448814, 0.283359345048666, 0.18830027634976432, 0.152785689861048, 0.16799854463897645, 0.25582569593098015, 0.2077994792489335, 0.25299092929344624, 0.20458826562389731, 0.14730581984622404, 0.3256667498499155, 0.22766450158087537, 0.1917026672163047, 0.2029831486288458, 0.21222299110377207, 0.40402056416496634, 41.39468237757683, 123.89440387487411, 93.53353142738342, 61.184617057442665, 92.37818822264671, 98.58383283019066, 65.7946626842022, 39.56864096224308, 95.87486699223518, 10.578790996223688, 0.11713462241459638, 16.634340807795525, 17.40159373730421, 21.081217490136623, 16.053716763854027, 15.087693650275469, 10.153194833546877, 7.570043094456196, 11.41666978597641, 4.8102298099547625, 3.1009091064333916, 13.293742462992668, 11.552929524332285, 16.239445097744465, 25.59463430196047, 32.285533770918846, 40.64694330096245, 51.517688781023026, 48.03696535527706, 44.34037931263447, 27.64652229845524, 22.804255932569504, 41.148117408156395, 45.48507548868656, 53.11347775161266, 48.50003510713577, 37.0618736743927, 38.72926600277424, 64.08333331346512, 67.36210897564888, 73.6876979470253, 66.08587145805359, 60.81575185060501, 60.24498827755451, 64.89673286676407, 62.85754568874836, 62.52461135387421, 65.42966187000275, 62.04665020108223, 60.629098266363144, 58.818259835243225, 61.76829233765602, 65.22084787487984, 67.33987256884575, 65.60492366552353, 68.53631436824799, 68.883615732193, 77.64769345521927, 62.48767353594303, 31.681949459016323, 69.5081578195095, 70.90202942490578, 72.13761672377586, 68.06862026453018, 69.46629926562309, 60.20320571959019, 54.700154811143875, 52.38558121025562, 56.89042188227177, 56.1588129401207, 57.5527985394001, 55.159766748547554, 58.07788096368313, 54.47736516594887, 59.13636736571789, 59.34181474149227, 59.34695206582546, 59.397428557276726, 62.674247324466705, 60.0315385311842, 62.028148993849754, 61.26402899622917, 67.21788391470909, 66.10392048954964, 66.92326292395592, 67.07402363419533, 66.98616474866867, 52.87611588835716, 35.613794177770615, 33.194904774427414, 46.736644729971886, 54.752155020833015, 61.49364307522774, 56.96202524006367, 48.61541971564293, 30.525962188839912, 24.25566405057907, 20.349920131266117, 8.782800268381834, 2.0603746036067605, 11.248466111719608, 1.6533842612989247, 13.706925641745329, 15.21771602332592, 18.048469126224518, 14.588577132672071, 20.660063289105892, 16.82419192045927, 13.82243374362588, 9.182655662298203, 5.504155699163675, 0.5727864301297814, 4.353353250771761, 66.51817426085472, 48.62880639731884, 49.08246025443077, 80.41000843048096, 71.19513049721718, 57.61655531823635, 89.61034834384918, 32.98230238258839, 1.075055175460875, 0.22430896991863847, 0.2647465484915301, 0.2025325907743536, 0.3416885604383424, 0.21399244928034022, 0.1533455215394497, 0.1466024122782983, 0.18396858300548047, 0.17431186133762822, 0.09135063839494251, 0.10366018177592196, 0.1345530807157047, 0.2592600288335234, 0.1317988074151799, 0.16189099580515176, 0.13190726487664506, 0.17586945119546726, 0.0864272158651147, 0.19452052772976458, 0.17663015256403014, 0.12387415452394634, 0.2068386651808396, 0.20012528635561466, 0.2201751628308557], [0.08766161525272764, 0.007864979579608189, 0.04921916712191887, 0.029535093381127808, 0.007121355956769548, 0.05086062337795738, 0.07468004230759107, 0.0706328809610568, 0.027356934479030315, 0.047764873088453896, 0.05391244965721853, 0.03089026617089985, 0.0714681384852156, 0.008725343959667953, 0.05608146901067812, 0.0190537046364625, 0.0981199974194169, 0.04825685762625653, 0.014197511409292929, 0.045173887119744904, 0.10803626297274604, 0.02723054487432819, 0.06896813240018673, 0.04448249121196568, 0.08845172051223926, 0.019132494744553696, 0.1375866835587658, 0.11355050184647553, 0.14516724710119888, 0.11381915188394487, 0.5924373725429177, 35.479763969779015, 91.60647243261337, 59.392952397465706, 57.19314783811569, 70.62428712844849, 65.3930090367794, 26.67352180927992, 52.38949500024319, 8.788900841027498, 0.13228532974608243, 4.422656306996942, 4.107386749237776, 15.36685137078166, 3.744045258499682, 10.115977730602026, 3.8106739707291126, 5.298122204840183, 4.504587985575199, 1.1315492377616465, 1.0460241395048797, 3.0843175342306495, 8.454647976905107, 4.865212384611368, 7.889997325837612, 5.72910220362246, 14.82728412374854, 17.836778685450554, 25.431959331035614, 23.24166376143694, 12.22100492566824, 13.599970880895853, 30.9691609069705, 39.84545610845089, 47.842784374952316, 41.97653755545616, 31.91318415105343, 41.64027839899063, 60.68641439080238, 59.69585694372654, 65.7342079281807, 67.55696251988411, 50.36907501518726, 44.19276103377342, 45.79478166997433, 49.66109700500965, 54.801890552043915, 55.52603669464588, 57.801157012581825, 54.26263488829136, 53.430563136935234, 53.269607573747635, 59.75399002432823, 63.87328818440437, 62.104399502277374, 64.75060790777206, 61.7187125980854, 68.06839227676392, 52.850554659962654, 19.236368983983994, 61.763690784573555, 61.59009329974651, 65.71576371788979, 63.99273097515106, 65.13271540403366, 53.815908059477806, 48.6657328158617, 48.14693905413151, 50.01110382378101, 48.796977773308754, 49.509344547986984, 52.249039337038994, 56.38252593576908, 59.45241920650005, 58.00712876021862, 57.90937140583992, 60.458685010671616, 59.95310693979263, 56.71741336584091, 50.87877206504345, 49.28378105163574, 46.07159301638603, 50.93619458377361, 51.405173018574715, 57.24407650530338, 61.293230429291725, 66.53261348605156, 59.14056994020939, 19.333603866398335, 11.119811665266752, 30.087370723485947, 51.70611687004566, 53.40539328753948, 42.83051133155823, 36.559517830610275, 31.464044451713562, 22.072698287665844, 12.50992052257061, 10.4207175783813, 2.7558472473174334, 2.4846284883096814, 2.1197582921013236, 4.224815173074603, 7.273526005446911, 7.090904479846358, 9.084349237382412, 9.463648684322834, 6.2250083684921265, 5.5791480001062155, 1.6029393556527793, 0.733634055359289, 0.09752295445650816, 4.2018872033804655, 40.87252959609032, 25.752945207059383, 68.46458941698074, 59.130937457084656, 37.75291979312897, 60.85550531744957, 46.65481612086296, 0.8087541838176548, 0.20844936312641948, 0.0730452171410434, 0.061606131348526105, 0.04151962617470417, 0.0705177961208392, 0.028721881353703793, 0.042845562056754716, 0.0036839628546658787, 0.015554437522951048, 0.025119413039647043, 0.008027574858715525, 0.02575784186774399, 0.040641379746375605, 0.0877460568153765, 0.022230644026421942, 0.008983372936199885, 0.028238698687346186, 0.0224450671885279, 0.026601094177749474, 0.06733841320965439, 0.04825103918847162, 0.10533720545936376, 0.015345783631346421, 0.02934754524176242, 0.020117641979595646, 0.12901048437925056, 0.0548445426102262, 0.06763212557416409, 0.0302654483311926, 0.03443493973463774, 0.026316838630009443, 0.07490888354368508, 0.04849315002502408, 0.06129661123850383, 0.04450505992281251, 0.042495977104408666, 0.06149496875877958, 0.060750338598154485, 0.05146834213519469, 0.03604614976211451, 0.02210785198258236, 0.047206106391968206, 0.026869143075600732, 0.0863552423834335, 0.09894795963191427, 0.13885989726986736, 0.05042582502937876, 0.1111340986972209, 0.062039523327257484, 0.1878895124536939, 0.055896555495564826, 0.07848738605389372, 0.1000674077658914, 0.14133956108707935, 0.15647471300326288, 1.0305188340134919, 40.20634934306145, 110.86366429924965, 57.96299032866955, 61.4571688324213, 76.93535327911377, 56.32042966783047, 24.361674562096596, 72.8668811917305, 9.32446975260973, 0.14715804340085015, 2.1785078896209598, 5.4559405613690615, 10.618485566228628, 9.35427725315094, 14.284734036773443, 9.669324047863483, 8.825570773333311, 4.840424889698625, 0.9674918535165489, 1.0055552423000336, 5.179722933098674, 9.523240886628628, 6.153445383533835, 9.262351635843515, 11.090050712227821, 21.144064217805862, 24.051755592226982, 32.7827674895525, 27.94274490326643, 16.208298169076443, 16.106119751930237, 32.542890161275864, 42.62140095233917, 52.1133828163147, 45.978684201836586, 37.31668800115585, 48.59315291047096, 62.25939318537712, 64.52539399266243, 71.81662514805794, 68.62837582826614, 55.3541225194931, 51.04006581008434, 58.64859513938427, 59.9884108453989, 63.090864568948746, 62.16652996838093, 61.03407293558121, 57.19716042280197, 58.197004571557045, 57.653276547789574, 65.07601484656334, 67.31094092130661, 65.85994318127632, 69.61509928107262, 65.93740582466125, 74.60287883877754, 56.57234475016594, 22.536522299051285, 66.30635842680931, 66.01609200239182, 70.32009065151215, 69.46491613984108, 70.2517095208168, 57.41436056792736, 54.20776963233948, 52.7866230905056, 54.87247556447983, 52.4092311412096, 55.093464106321335, 57.749130204319954, 61.639745235443115, 61.84632495045662, 59.590549394488335, 59.50224973261356, 63.563794791698456, 62.47002728283405, 62.39941567182541, 56.73778027296066, 57.1303828060627, 54.92762580513954, 58.84612374007702, 61.69944003224373, 64.21249598264694, 69.39163327217102, 74.35944870114326, 65.8881376683712, 26.57391395419836, 13.695931881666183, 36.56707942485809, 59.43021319806576, 61.26490294933319, 48.72323893010616, 41.89220868051052, 37.15580843389034, 23.93384601920843, 14.75320614874363, 11.884290743619204, 3.8583861105144024, 3.981289565563202, 3.2290961779654026, 7.284884545952082, 13.261666484177113, 12.118597570806742, 12.289150469005108, 10.281294509768486, 7.023855177685618, 3.913498353213072, 3.122129780240357, 0.9158158139325678, 0.16525296930922195, 5.076434025540948, 48.51452372968197, 31.71291969716549, 62.551407516002655, 70.72197988629341, 39.916402101516724, 71.92827075719833, 50.0283282995224, 1.4831302408128977, 0.3169706789776683, 0.0704110084916465, 0.057739549374673516, 0.06731646048137918, 0.06384085674653761, 0.020337685054983012, 0.011429989845055388, 0.04551521938992664, 0.04526193923084065, 0.0525358955928823, 0.0433573656482622, 0.020387848671816755, 0.05172672084881924, 0.07677514746319503, 0.05383930358220823, 0.03264220409619156, 0.03456419588474091, 0.05329445586539805, 0.034441993848304264, 0.07216810990939848, 0.0031248774985215277, 0.044982702456763946, 0.06297721949522384, 0.01323481692452333, 0.007657251517230179, 0.26367942919023335, 0.13603801431600004, 0.16832333814818412, 0.20246150786988437, 0.08472423927742057, 0.14228378073312342, 0.15186244330834597, 0.27608421980403364, 0.09753184538567439, 0.11414287670049816, 0.10607492993585765, 0.1596240166691132, 0.16429775103460997, 0.3653145645512268, 0.14987512025982141, 0.08276762629975565, 0.17188192141475156, 0.21633214404573664, 0.11318941731587984, 0.20297179376939312, 0.2411654739989899, 0.09800017025554553, 0.28376990114338696, 0.1294998565572314, 0.2162109364871867, 0.17975723632844165, 0.14846070553176105, 0.17967096908250824, 0.372364284703508, 0.36305603105574846, 1.5510102733969688, 65.62977433204651, 120.76362267136574, 78.75031068921089, 78.34595918655396, 95.21628633141518, 93.85630890727043, 35.040328949689865, 72.12964475154877, 9.738786220550537, 0.17166842037113383, 9.987508524209261, 18.19491896778345, 29.82500810176134, 15.607283469289541, 26.344814747571945, 18.057634234428406, 11.264714989811182, 10.50262788310647, 4.667046843096614, 1.1250664293766022, 5.891771474853158, 9.741955250501633, 5.486437724903226, 8.777001779526472, 11.879607494920492, 23.05641420185566, 26.322251558303833, 32.098731994628906, 29.586422704160213, 18.903218060731888, 18.533976674079895, 32.91776284575462, 43.99039909243584, 49.18653666973114, 47.7203169465065, 41.70627325773239, 54.67192232608795, 65.5657933652401, 66.97712883353233, 66.70088365674019, 69.5132115483284, 64.05932620167732, 60.12128211557865, 67.47405096888542, 68.80980089306831, 70.65802931785583, 67.5777018070221, 65.09328112006187, 60.89579835534096, 60.82151994109154, 58.6487927287817, 67.12026715278625, 70.50454795360565, 68.89880731701851, 73.3305475115776, 69.94970932602882, 77.03613147139549, 57.176789715886116, 26.768558509647846, 68.55120196938515, 69.9706082046032, 71.77218273282051, 73.20666655898094, 73.2393904030323, 60.04196897149086, 56.120978370308876, 55.5361707508564, 59.016791582107544, 58.76460671424866, 57.20124140381813, 59.93360258638859, 63.543066903948784, 63.996044397354126, 60.76700806617737, 58.432394340634346, 64.43313494324684, 65.06821006536484, 61.78477585315704, 59.15992230176926, 58.70180368423462, 58.01452316343784, 62.453444972634315, 62.02987790107727, 63.3346176892519, 67.248844653368, 70.78777715563774, 62.98104286193848, 31.406758725643158, 20.525077432394028, 40.91314181685448, 54.107713401317596, 59.19059045612812, 52.10659258067608, 45.6902264803648, 37.69785314798355, 27.054498866200447, 14.095815774053335, 13.361698966473341, 5.940458737313747, 8.277912810444832, 5.769632728770375, 10.671885050833225, 19.75405130535364, 19.93342448025942, 23.13174705952406, 23.994131684303284, 15.61512054875493, 14.846644084900618, 3.5837814956903458, 1.7114576138556004, 0.4021687572821975, 7.24450696259737, 62.73956961929798, 37.20908157527447, 82.7592171728611, 79.80207145214081, 48.716756477952, 74.08449545502663, 72.78114259243011, 1.9882898591458797, 0.42334617872256786, 0.15009074384579435, 0.22620900155743584, 0.15953332622302696, 0.1428806158946827, 0.10753302005468868, 0.14720163715537637, 0.16269217390799895, 0.08452303562080488, 0.1093766484700609, 0.08559865993447602, 0.11685313322232105, 0.17997096001636237, 0.15704788849689066, 0.1628673356026411, 0.05453700403450057, 0.11682626005494967, 0.12021110655041412, 0.09800586252822541, 0.15769180550705642, 0.17953803559066728, 0.23586360068293288, 0.260728175053373, 0.11135738124721684, 0.07106028380803764], [0.04046903450216632, 0.07414155479636975, 0.02982174977660179, 0.033557201677467674, 0.04905779453110881, 0.03531559072143864, 0.05262589213089086, 0.04650790498999413, 0.007278880975718494, 0.11691228981362656, 0.00962964812060818, 0.027323025751684327, 0.07105846554622985, 0.030526329937856644, 0.07263892097398639, 0.07063009790726937, 0.020478758051467594, 0.04925366214592941, 0.051704842335311696, 0.0236949236568762, 0.013419079205050366, 0.14550925843650475, 0.1467584859346971, 0.03242348204366863, 0.09632126151700504, 0.041111311365966685, 0.06664148459094577, 0.08849547011777759, 0.041801853803917766, 0.1744600830716081, 0.10670607458450831, 2.4513337248936296, 79.47630733251572, 86.93947926163673, 53.79368685185909, 73.141720443964, 69.51422229409218, 49.583022594451904, 44.1835693269968, 6.733365515246987, 0.06817564484663308, 1.674014066811651, 5.094666872173548, 9.240844789892435, 10.51922919228673, 4.60272959433496, 2.3308899253606796, 9.488901179283857, 1.0181914642453194, 1.8186693359166384, 0.5179426074028015, 0.5023205769248307, 3.35251331795007, 2.098091854713857, 0.6852523796260357, 2.2122541163116693, 4.461714886128902, 10.306304767727852, 14.279862698167562, 11.645248420536518, 6.343779070302844, 10.986768454313278, 21.53910432010889, 31.74669798463583, 35.683296248316765, 31.449753418564796, 31.014224588871002, 43.22010062634945, 58.06843087077141, 55.14542631804943, 58.85800950229168, 67.52680733799934, 62.96193368732929, 54.3177205324173, 51.73023797571659, 53.89167219400406, 60.49414850771427, 61.42798639833927, 64.49348330497742, 64.41695541143417, 55.46595811843872, 54.738509953022, 56.62062115967274, 59.923867508769035, 57.747321501374245, 63.46494309604168, 58.85788410902023, 68.24740067124367, 57.92551673948765, 27.800881415605545, 60.48460341989994, 61.12938702106476, 64.64580953121185, 65.47454506158829, 64.70247209072113, 56.84873811900616, 48.89111012220383, 50.188618898391724, 48.93658988177776, 48.7337339669466, 54.30862382054329, 62.95007072389126, 65.68143635988235, 65.88935360312462, 65.45742318034172, 63.0492378026247, 63.804078698158264, 60.892108753323555, 56.55817151069641, 51.78994417190552, 47.18252420425415, 43.25585290789604, 43.42829145491123, 45.84652729332447, 43.76004405319691, 47.662199065089226, 44.183983504772186, 47.3009068518877, 18.73174276202917, 6.964116683229804, 23.13724536448717, 37.44161009788513, 42.96391077339649, 50.935081243515015, 40.25491073727608, 32.96955406665802, 20.339535288512707, 15.841987375169992, 2.7225669706240296, 5.6660450622439384, 3.6499995924532413, 1.7209635162726045, 4.746644971892238, 12.426812332123518, 11.002357117831707, 5.056316005066037, 7.651144517585635, 3.475627899169922, 4.330199668183923, 2.146183499135077, 0.46623631787952036, 0.027485990249260794, 3.398746862076223, 27.25466262549162, 57.973637357354164, 81.06565564870834, 44.59681235253811, 52.732749581336975, 66.00649371743202, 10.687402468174696, 0.6105551565997303, 0.2008970605675131, 0.07729668432148173, 0.01055777243891498, 0.051560245992732234, 0.15937072166707367, 0.10567374716629274, 0.13462687988067046, 0.1312045252416283, 0.11289189773378894, 0.026167188261752017, 0.07168247073423117, 0.02478888643963728, 0.05028803789173253, 0.014057638836675324, 0.05489847077114973, 0.15178297413513064, 0.08721780352061614, 0.06473084766184911, 0.040630856092320755, 0.005016680806875229, 0.06519738395581953, 0.04388096938782837, 0.030579271042370237, 0.020357520807010587, 0.06868705881061032, 0.07038780895527452, 0.013178779208828928, 0.02032715769018978, 0.06795699329813942, 0.002941380789707182, 0.06243090232601389, 0.030251566458900925, 0.052272937828092836, 0.022314397247100715, 0.04577569467073772, 0.07305159218958579, 0.025557569606462494, 0.04136186784307938, 0.015146871355682379, 0.09468405405641533, 0.019343611638760194, 0.00692752414579445, 0.03527206376020331, 0.062064003068371676, 0.1564126249286346, 0.12390974792651832, 0.1419454356073402, 0.0108291276046657, 0.04524508134636562, 0.07770669122692198, 0.044856860185973346, 0.05580377961450722, 0.074480694020167, 0.06751605367753655, 0.09988938880269416, 0.24438384192762896, 4.18208884075284, 89.39678460359573, 96.08666002750397, 58.13840411603451, 86.45279377698898, 72.19598919153214, 41.17000803351402, 42.627758011221886, 10.451312586665154, 0.13629548018798232, 2.0837571239098907, 2.4663315201178193, 6.305023524910212, 5.993142435327172, 10.598871018737555, 8.899748492985964, 12.502938397228718, 4.298036294057965, 2.050757557153702, 1.021299697458744, 0.3655947104562074, 4.301083255559206, 2.245946195907891, 1.114680280443281, 2.3676242167130113, 6.246015066280961, 12.4878522567451, 15.410279240459204, 12.680922746658325, 8.039193470031023, 14.108140412718058, 25.728206634521484, 34.25322778522968, 39.30321380496025, 38.85559022426605, 38.84597294032574, 52.15941734611988, 67.17813044786453, 62.03999675810337, 64.41950887441635, 70.03623068332672, 67.38166272640228, 60.77863924205303, 59.828006252646446, 64.46315333247185, 67.48973652720451, 69.59924653172493, 69.9877604842186, 67.23802283406258, 60.2586105465889, 58.14712464809418, 60.02444811165333, 64.43346172571182, 64.12507027387619, 68.1155401468277, 66.26436308026314, 73.78739699721336, 62.555788680911064, 31.561708711087704, 63.49800892174244, 66.4962950348854, 70.22291466593742, 70.2825790643692, 71.11474201083183, 61.05510860681534, 56.33497528731823, 54.8526406288147, 53.69344063103199, 52.663752883672714, 60.21134488284588, 66.37670785188675, 67.2988423705101, 69.22182038426399, 69.62510034441948, 66.35558858513832, 68.7946093082428, 66.87211006879807, 64.66579645872116, 60.25384180247784, 56.57269813120365, 53.617152124643326, 50.849851816892624, 53.98216433823109, 53.633016273379326, 54.88560006022453, 50.30648477375507, 54.0168222784996, 22.979069352149963, 11.258719861507416, 28.55998568236828, 42.90171571075916, 50.995691791176796, 57.48375244438648, 48.00340935587883, 37.58485101163387, 22.09574405103922, 18.763835839927197, 4.348131380975246, 8.117921445518732, 4.889565277844667, 3.5781252617016435, 12.195896822959185, 12.213093750178814, 11.44746808335185, 9.146323911845684, 6.58493977971375, 4.065522970631719, 5.815607411786914, 1.0387841030023992, 0.524465610506013, 0.09650486885220744, 3.600047710351646, 43.259242326021194, 52.78995931148529, 85.80123513936996, 47.8895066678524, 54.783358946442604, 75.18927097320557, 11.198471244424582, 0.4109806922497228, 0.22416315274313092, 0.05474270510603674, 0.05941735602391418, 0.0691218682914041, 0.018401384659227915, 0.03458010753092822, 0.07497359882108867, 0.015160349685174879, 0.046197204865165986, 0.060413377577788197, 0.0553873494209256, 0.028127324585511815, 0.015196512686088681, 0.021453633962664753, 0.06172485271235928, 0.06899992600665428, 0.06896899329149164, 0.0762704128283076, 0.08287327844300307, 0.021105657615407836, 0.14049470017198473, 0.031946329327183776, 0.047945352271199226, 0.022822857463324908, 0.06549886660650373, 0.1717066706623882, 0.14581713097868487, 0.14458409714279696, 0.12164060171926394, 0.216754604189191, 0.18335596978431568, 0.1503433263860643, 0.1773467258317396, 0.09979497277527116, 0.20342137198895216, 0.1810553268296644, 0.1644346327520907, 0.17448709724703804, 0.1571754043106921, 0.23550165526103228, 0.13675096590304747, 0.10880918009206653, 0.19366496504517272, 0.18108891643350944, 0.25582091649994254, 0.31592908955644816, 0.21754162211436778, 0.3742258879356086, 0.19732643966563046, 0.26690533733926713, 0.24938706017564982, 0.14515632268739864, 0.20428443036507815, 0.20302628225181252, 0.33970661053899676, 0.40632338903378695, 8.798542823642492, 116.10991358757019, 107.36302614212036, 77.21230521798134, 90.89110761880875, 92.85097405314445, 66.12388461828232, 66.37043818831444, 11.693559028208256, 0.21678581892047077, 3.919947319664061, 12.015684843063354, 22.46092915534973, 24.935732558369637, 17.383882887661457, 12.975617833435535, 21.849205680191517, 5.421662600710988, 4.774110373109579, 1.7166539537720382, 0.7546795229427516, 3.8037711661309004, 2.239075689576566, 0.6591908249538392, 2.4234429839998484, 6.1686664167791605, 15.73551518842578, 16.363650932908058, 13.547700885683298, 9.744479265064001, 13.95448425784707, 25.719288513064384, 33.37957486510277, 40.419947281479836, 41.155827194452286, 43.862790539860725, 56.35817304253578, 71.53835088014603, 68.29723119735718, 68.28608259558678, 67.69271403551102, 68.62958416342735, 70.14609798789024, 68.23066636919975, 73.0260394513607, 73.04845824837685, 72.95432969927788, 74.26252350211143, 73.12056317925453, 63.829058557748795, 59.39100310206413, 61.53026171028614, 65.91606616973877, 64.69842910766602, 70.42729809880257, 68.14571052789688, 76.63003966212273, 66.59184470772743, 37.392125353217125, 66.00088521838188, 68.37179839611053, 74.6795891225338, 74.32342663407326, 73.16765785217285, 64.88138169050217, 56.46682821214199, 57.94849790632725, 55.851287841796875, 55.89956045150757, 63.50004941225052, 71.11398965120316, 72.0636422932148, 71.11230254173279, 72.18044802546501, 67.3497748374939, 67.56606683135033, 65.52116855978966, 63.92026886343956, 61.81687273085117, 59.76320832967758, 60.058638677001, 56.96058131754398, 60.24115048348904, 58.40863801538944, 63.51404406130314, 57.210197523236275, 60.19758582115173, 32.83980242908001, 23.057645335793495, 37.80261732637882, 45.198263078927994, 49.50163096189499, 54.63032975792885, 47.920079827308655, 38.4590283036232, 23.232717141509056, 22.528014555573463, 5.4376008454710245, 9.992487207055092, 7.428443692624569, 3.320228587836027, 15.796621609479189, 25.50576277077198, 22.676409892737865, 15.043391827493906, 17.413492798805237, 13.964622113853693, 13.21082616224885, 5.0585574097931385, 1.552244732156396, 0.328109246911481, 6.266588112339377, 44.08520020544529, 68.20569410920143, 101.00377097725868, 59.12842199206352, 60.47065816819668, 91.4144079387188, 22.89520025253296, 0.7188611605670303, 0.37331889441702515, 0.2915979264071211, 0.18181498919147998, 0.2025195289752446, 0.1915311865741387, 0.2273746780701913, 0.15624184190528467, 0.260138227022253, 0.2600261924089864, 0.0995555410918314, 0.1305926393251866, 0.13924315717304125, 0.15883449028478935, 0.16558611940126866, 0.15215072315186262, 0.3047436475753784, 0.15710746811237186, 0.13011404313147068, 0.15307082299841568, 0.09063502249773592, 0.22524106287164614, 0.25000099441967905, 0.21506951336050406, 0.13246740825707093, 0.1610576530219987], [0.019758963862841483, 0.015183513969532214, 0.0025686399021651596, 0.031377844206872396, 0.06586052259081043, 0.025184493824781384, 0.019943313345720526, 0.09171609417535365, 0.07663852549740113, 0.023310782453336287, 0.058008781998069026, 0.0728045089635998, 0.03777546888159122, 0.0669875109451823, 0.022216988509171642, 0.05568435321038123, 0.0359542384831002, 0.10369124807766639, 0.012950640229973942, 0.05736812672694214, 0.04358828118711244, 0.0531648175092414, 0.03975706255005207, 0.12838173686759546, 0.059204934805165976, 0.08970390175818466, 0.09853111012489535, 0.12267795347725041, 0.17563977133249864, 0.13884649408282712, 0.4323764832224697, 0.847811991116032, 25.37705607712269, 96.463143825531, 59.02938790619373, 43.820840790867805, 85.71912914514542, 45.412146002054214, 52.24732182919979, 6.305972998961806, 0.04865678616624791, 0.45246977533679456, 2.0144649920985103, 2.2054218454286456, 5.546984151005745, 8.631912264972925, 8.679923638701439, 6.617972832173109, 5.234919246286154, 0.6483105244114995, 0.3890020481776446, 0.0932534530875273, 0.7889995782170445, 0.35345151205547154, 0.5638698523398489, 0.036853521087323315, 0.8361539791803807, 2.2845870349556208, 3.7944635655730963, 2.6318470761179924, 3.218141603283584, 5.3115910571068525, 14.852830152958632, 25.643169097602367, 27.23645970225334, 25.048476308584213, 30.48346906900406, 37.52420246601105, 45.22695533931255, 45.078117325901985, 50.24707496166229, 66.3292407989502, 70.01517221331596, 60.23866541683674, 57.08866864442825, 58.50831426680088, 62.23783314228058, 70.19593611359596, 70.19153594970703, 71.45784839987755, 67.30928421020508, 56.66181854903698, 56.59423537552357, 58.56320612132549, 58.78035306930542, 62.05364562571049, 62.99826733767986, 61.34030230343342, 64.87502083182335, 42.883092910051346, 55.96447616815567, 62.90923051536083, 65.221326649189, 65.41463747620583, 64.05852064490318, 57.95681186020374, 49.68570448458195, 49.918913170695305, 49.558833092451096, 58.141196966171265, 64.03862491250038, 67.52041608095169, 68.61478015780449, 71.35350599884987, 75.77519953250885, 72.34801143407822, 66.15352302789688, 60.98456159234047, 53.826479092240334, 48.35257641971111, 41.872103959321976, 34.889397248625755, 32.031817585229874, 30.901178754866123, 25.561418384313583, 18.63143004477024, 17.959257513284683, 15.277283526957035, 6.2041831109672785, 2.609879979863763, 8.103264681994915, 13.714188002049923, 25.487945526838303, 37.25494511425495, 36.63297928869724, 38.97583097219467, 21.215023510158062, 12.818355672061443, 0.9300401725340635, 4.964494407176971, 11.324239745736122, 1.1148217041045427, 9.340078365057707, 6.073472974821925, 9.738345444202423, 6.7118016723543406, 6.03652423247695, 2.850060104392469, 1.6284874035045505, 2.1274614287540317, 0.89190524071455, 0.2908905706135556, 12.810965068638325, 32.92424529790878, 64.87504363059998, 54.29363742470741, 48.384255319833755, 70.5908565223217, 33.05829830467701, 0.289167333394289, 0.1093992023379542, 0.01813706876419019, 0.13877409015549347, 0.029530145111493766, 0.011662439774227096, 0.08869734912877902, 0.05699162407836411, 0.05178201085072942, 0.023034547666611616, 0.053722322554676794, 0.029233952118374873, 0.06288506701821461, 0.044397804740583524, 0.04108743647520896, 0.04945480643073097, 0.08349712035851553, 0.07482710629119538, 0.031231585453497246, 0.08756367402384058, 0.06419947734684683, 0.09900085249682888, 0.06689664980513044, 0.04735321119369473, 0.029593743456644006, 0.030130793056741823, 0.04071759460202884, 0.037835694165551104, 0.051309285045135766, 0.010090935575135518, 0.07762584908050485, 0.04439386022568215, 0.029865718315704726, 0.08333494624821469, 0.096386251389049, 0.08478922172798775, 0.016640785870549735, 0.09549020454869606, 0.04574494007101748, 0.11061604993301444, 0.0682739274634514, 0.03664403506263625, 0.059620125612127595, 0.036236892847227864, 0.02363920877542114, 0.009166940380964661, 0.031404097680933774, 0.08955231809522957, 0.04820725618628785, 0.024326719540113118, 0.09017809701617807, 0.09004663297673687, 0.09908942782203667, 0.11677502217935398, 0.14273266133386642, 0.12707027286523953, 0.22108598583145067, 0.37342840572819114, 0.7595974684227258, 31.49481140077114, 113.60953375697136, 62.525690495967865, 55.918981209397316, 89.81923073530197, 51.273217499256134, 58.39155413210392, 5.81747786141932, 0.10472902285982855, 0.5490173993166536, 2.963943318463862, 2.610765569843352, 5.656613018363714, 9.07023299485445, 11.495807189494371, 10.992004573345184, 7.295836033299565, 3.8064880203455687, 1.456455197185278, 0.35160487052053213, 2.5856878655031323, 2.243382283486426, 2.3327314015477896, 0.4848159255925566, 1.1077101482078433, 3.495369739830494, 5.147870192304254, 3.11667968519032, 3.4360561100766063, 5.654743518680334, 15.383355785161257, 28.21031704545021, 33.143873512744904, 32.83314138650894, 38.229767605662346, 46.92022807896137, 54.34226721525192, 56.06299728155136, 58.974819034338, 70.57257190346718, 72.62889996170998, 65.88114604353905, 65.89822992682457, 65.13507127761841, 69.9657216668129, 75.15956416726112, 75.7567249238491, 75.48936367034912, 67.51414641737938, 60.84736995398998, 60.398872420191765, 62.88807325065136, 63.2300017029047, 67.50229105353355, 68.70276063680649, 67.2105123102665, 72.83656641840935, 47.490695267915726, 62.97473520040512, 68.69532823562622, 72.86292940378189, 70.46155706048012, 70.77598258852959, 63.623827770352364, 54.813483729958534, 55.816413313150406, 55.6744035333395, 61.67272366583347, 69.8700200021267, 71.32888332009315, 72.24512055516243, 73.94088596105576, 78.6199700832367, 73.23732331395149, 72.00291395187378, 67.691330909729, 62.91013486683369, 58.40383127331734, 51.53434328734875, 46.71137988567352, 43.67158479988575, 41.39881655573845, 31.421469636261463, 24.543278217315674, 20.346996188163757, 18.997010327875614, 12.156290598213673, 5.275037018582225, 12.484943512827158, 16.517721265554428, 29.50317107141018, 43.26777666807175, 42.31878139078617, 46.840892136096954, 26.904353722929955, 16.299221590161324, 1.031751036643982, 6.819808026775718, 16.657734252512455, 1.8335882853716612, 12.76471870020032, 11.433049757033587, 8.169991951435804, 6.97451957501471, 4.093484245240688, 2.1334857679903507, 2.422306607477367, 1.2690897448919713, 1.449567354284227, 0.5446070234756917, 24.924059584736824, 37.49600797891617, 64.63896989822388, 67.675029784441, 47.76345983147621, 76.98643013834953, 37.82338701188564, 0.6208639440592378, 0.23283828020794317, 0.02167825794458622, 0.0967593735549599, 0.08110811730148271, 0.05421574314823374, 0.07714188715908676, 0.03889417857863009, 0.011994883898296393, 0.06503591488581151, 0.03500954757328145, 0.046687504727742635, 0.03845011080557015, 0.019484443437249865, 0.09609327375073917, 0.050060825669788755, 0.0543841104808962, 0.028206290953676216, 0.03958978988521267, 0.03722309207660146, 0.03631620988016948, 0.04836035011976492, 0.01706260776700219, 0.044968724105274305, 0.03712071651534643, 0.08689139212947339, 0.09307452128268778, 0.1228683143563103, 0.2421178572694771, 0.1826581431669183, 0.11957148657529615, 0.13268598559079692, 0.10926166753051803, 0.16522078978596255, 0.18519277044106275, 0.1466427108971402, 0.2360862449859269, 0.09810234914766625, 0.11216224040254019, 0.2160128127434291, 0.20761085499543697, 0.15514828730374575, 0.204959265247453, 0.18705848517129198, 0.1660108208307065, 0.14139712206088006, 0.1959073790931143, 0.1650942536070943, 0.16510094777913764, 0.22673347732052207, 0.1933667849516496, 0.3120615502120927, 0.1829201212967746, 0.30648356827441603, 0.27618058025836945, 0.3785434359451756, 0.2879058010876179, 0.8304729871451855, 1.1285703163594007, 48.777264431118965, 125.92398136854172, 79.06817123293877, 64.19140711426735, 102.88079425692558, 66.69914335012436, 74.42083820700645, 12.124129123985767, 0.15901812730589882, 2.0132956048473716, 4.264855999499559, 8.956822380423546, 17.448853701353073, 20.59079870581627, 21.96220401674509, 18.536687828600407, 16.215544380247593, 2.6018225122243166, 2.073218389414251, 0.7400989334564656, 1.4080007909797132, 2.46269297786057, 1.6474645351991057, 0.7736151537392288, 1.214676545932889, 3.2409380050376058, 4.567761020734906, 3.935673013329506, 4.100586539134383, 6.333147715777159, 16.777393631637096, 29.883169680833817, 33.55349153280258, 38.38018253445625, 45.24743244051933, 54.846515357494354, 61.799321472644806, 62.663030326366425, 63.4561313688755, 70.89807003736496, 72.76514545083046, 69.25794884562492, 75.08843198418617, 72.88485422730446, 75.93213111162186, 79.14558827877045, 80.42903780937195, 78.35713818669319, 72.91504740715027, 63.6154530197382, 65.40886178612709, 66.5556326508522, 65.75459003448486, 73.49903047084808, 73.61490905284882, 71.99187934398651, 75.85347533226013, 53.68726596236229, 63.73606234788895, 70.17259016633034, 75.51348477602005, 72.46946811676025, 74.844751060009, 67.11196839809418, 59.57669913768768, 59.042071625590324, 60.35129137337208, 67.45772704482079, 73.7581917643547, 75.12114822864532, 73.95167738199234, 75.96062198281288, 78.58139455318451, 72.73605421185493, 72.21244990825653, 67.87782490253448, 64.19775277376175, 64.6856389939785, 59.1276316344738, 55.476912930607796, 53.822493106126785, 59.37778741121292, 49.954448863863945, 48.686916679143906, 44.18421149253845, 43.094676956534386, 20.751476883888245, 12.996561359614134, 25.87025061249733, 36.69858276844025, 48.64247426390648, 54.453061670064926, 42.63599216938019, 42.776356637477875, 28.93386662006378, 18.739634938538074, 1.0818950459361076, 8.587391003966331, 15.084082894027233, 2.8619092935696244, 21.169044077396393, 18.27417891472578, 26.84086862951517, 18.51903397589922, 13.917457144707441, 7.480708938091993, 5.249723726883531, 5.853587798774242, 2.0746055524796247, 0.6179954542312771, 19.875154606997967, 47.71152801811695, 75.76905906200409, 76.98786646127701, 55.685571134090424, 85.06094366312027, 61.06491208076477, 0.754999240161851, 0.35922141338232905, 0.1545822067419067, 0.17952856578631327, 0.10589446188532747, 0.15785899653565139, 0.17681908851955086, 0.10793585781357251, 0.1382947963429615, 0.09841648541623726, 0.17765249067451805, 0.14722868101671338, 0.17227751581231132, 0.15824342903215438, 0.17221921269083396, 0.14424489112570882, 0.11644560509012081, 0.1333216202328913, 0.1404961696243845, 0.16756124154198915, 0.21795685373945162, 0.1588774606352672, 0.14401365275261924, 0.13150742539437488, 0.09586947911884636, 0.16264274687273428, 0.2666740247514099], [0.05757429535151459, 0.028996002874919213, 0.037262986224959604, 0.01337199921181309, 0.04170929685642477, 0.04341846295574214, 0.02427505864034174, 0.06826478420407511, 0.006675351178273559, 0.006997512382440618, 0.025174432157655247, 0.03238372890336905, 0.07239779719384387, 0.12757634336594492, 0.02688214364752639, 0.10490392480278388, 0.06216990754182916, 0.035319787566550076, 0.05849164925166406, 0.1033102220389992, 0.06189479710883461, 0.12477985670557246, 0.07528455127612688, 0.14526339975418523, 0.10690062859794125, 0.06633977929595858, 0.0869233267439995, 0.09745926334289834, 0.014285134930105414, 0.10110372793860734, 0.1029533900145907, 0.1978595243417658, 3.375749308615923, 73.15473094582558, 84.5155817270279, 44.51514333486557, 64.61891457438469, 79.31034743785858, 42.185286954045296, 8.837063256651163, 0.25043630856089294, 0.8703184209298342, 1.050649678800255, 2.8102684020996094, 2.4982526572421193, 8.914106972515583, 5.711086895316839, 10.328402481973171, 3.565743863582611, 0.7501847797539085, 0.8222622214816511, 1.172823216766119, 0.2841706608887762, 0.0983259805070702, 1.181830633431673, 1.4039326342754066, 1.6591244470328093, 1.7900415533222258, 1.535860130097717, 2.7557220915332437, 3.0848259944468737, 3.370506064966321, 8.233329802751541, 13.084578886628151, 13.934624623507261, 12.142971362918615, 11.500557884573936, 19.006735906004906, 35.407689437270164, 44.290598183870316, 46.853822842240334, 67.0914874970913, 72.90467396378517, 64.72836390137672, 59.183538034558296, 63.52574363350868, 65.20841494202614, 71.22024714946747, 78.43159139156342, 73.55774492025375, 73.47747802734375, 67.2895860671997, 58.665758818387985, 52.920159325003624, 57.749415189027786, 57.733619436621666, 64.81714993715286, 59.74909208714962, 64.65804487466812, 38.231355920434, 49.56302046775818, 70.2308714389801, 64.64504957199097, 66.14219963550568, 62.86827251315117, 58.434469029307365, 51.155610010027885, 51.121343448758125, 57.62367233633995, 67.59502127766609, 71.8760159611702, 69.40899834036827, 75.48424154520035, 73.89102503657341, 73.50060358643532, 72.85683453083038, 67.31232404708862, 63.014416471123695, 50.26762805879116, 41.25060170888901, 31.676386557519436, 25.74215568602085, 18.177113123238087, 10.392719730734825, 6.069258050993085, 5.805603498592973, 7.850178312510252, 11.55405331403017, 8.413049709051847, 6.0915248561650515, 4.019708829000592, 3.3051253482699394, 3.8341892464086413, 7.041137125343084, 18.455953560769558, 33.50672364234924, 20.5904833227396, 11.149867102503777, 0.402572366874665, 1.4954571356065571, 3.850669674575329, 6.432791668921709, 10.976168923079967, 9.884563498198986, 5.701574580743909, 6.457825675606728, 1.4994806447066367, 2.0325510716065764, 1.4788300590589643, 0.7191844400949776, 0.8160490798763931, 10.228540990501642, 34.44430433213711, 52.75614872574806, 67.39378407597542, 38.66079367697239, 62.70558424293995, 57.28003777563572, 5.577857494354248, 0.5731069191824645, 0.18737769772997126, 0.14531285647535697, 0.017411741864634678, 0.05895459355087951, 0.0915059847466182, 0.10148529574507847, 0.09103557444177568, 0.04172827357251663, 0.058616801325115375, 0.04627954614988994, 0.06344305074890144, 0.024014013761188835, 0.010028392007370712, 0.026002119775512256, 0.04022746543341782, 0.050645125957089476, 0.05816732700623106, 0.0256930597970495, 0.034630978043423966, 0.08469062740914524, 0.14106195332715288, 0.05493288786965422, 0.005300043922034092, 0.04948133821017109, 0.027648899085761514, 0.039141039160313085, 0.02685596809897106, 0.03944235482777003, 0.05038590119511355, 0.048935867089312524, 0.04302861649193801, 0.10251516665448435, 0.06274690880673006, 0.06917082777363248, 0.06981834420002997, 0.07064782781526446, 0.03895434449077584, 0.09300576130044647, 0.0369267154019326, 0.10920401007751934, 0.05065556426416151, 0.07224143409985118, 0.16944095317739993, 0.07870261630159803, 0.09514491292065941, 0.08134735602652654, 0.08209028295823373, 0.13242031156551093, 0.1922187567106448, 0.06643358676228672, 0.10413266267278232, 0.04586411414493341, 0.09379015944432467, 0.10274929940351285, 0.1285317397559993, 0.14170316891977564, 0.2642936009215191, 0.3475163789698854, 4.745470834895968, 83.44488278031349, 98.4759110212326, 42.68073096871376, 81.82465732097626, 76.25537976622581, 59.77802753448486, 13.343538790941238, 0.5074812937527895, 1.4072012901306152, 0.9290548972785473, 2.0495333103463054, 1.7983057536184788, 4.881643652915955, 8.566041849553585, 12.193402256816626, 7.819446986541152, 3.562671965919435, 1.4669095049612224, 3.106910646893084, 0.6763479136861861, 2.666947217658162, 2.6431115716695786, 4.982585711404681, 1.1190494522452354, 3.6782472766935825, 2.870327504351735, 3.990659387782216, 4.399118945002556, 3.5760994954034686, 8.806203212589025, 15.817180406302214, 17.911887355148792, 20.266645699739456, 21.681988053023815, 33.372575640678406, 49.010765701532364, 56.26313254237175, 56.42856426537037, 68.72599259018898, 71.71225234866142, 69.00542959570885, 65.09412467479706, 69.42149966955185, 71.73557549715042, 76.21953248977661, 81.80347725749016, 78.34584519267082, 77.54585891962051, 69.18094217777252, 61.496223136782646, 56.400768756866455, 63.08779813349247, 63.38483199477196, 69.94211733341217, 69.23407092690468, 70.5875962972641, 45.04628263413906, 54.19567868113518, 75.41218221187592, 70.41681066155434, 72.47342750430107, 68.37564378976822, 62.741416320204735, 56.590667366981506, 55.13918325304985, 59.503271877765656, 71.2640891969204, 74.65739831328392, 72.55541190505028, 77.11572200059891, 76.76054745912552, 77.88500592112541, 78.65574896335602, 73.0974680185318, 71.50933563709259, 62.42550507187843, 57.06175848841667, 45.84164835512638, 38.041738495230675, 28.923675566911697, 21.005335561931133, 15.122400037944317, 12.573403716087341, 11.26419061794877, 21.97168830782175, 19.790153168141842, 9.664115477353334, 12.485024258494377, 6.9197991862893105, 5.217723743990064, 8.44871174544096, 20.034385062754154, 36.70136421918869, 23.64122562110424, 10.848121494054794, 0.5678493669256568, 1.2950703757815063, 10.56292399764061, 7.534578647464514, 8.497203793376684, 6.088332077488303, 5.1256428100168705, 2.8259622724726796, 1.853255198802799, 2.1152391470968723, 1.214685570448637, 1.7455483158119023, 1.6509738843888044, 17.689631581306458, 51.52968093752861, 48.022982105612755, 77.65127286314964, 39.44892078638077, 66.35493502020836, 66.6090577840805, 6.819414747878909, 0.5049835215322673, 0.20310083840740845, 0.08295702238683589, 0.029161427592043765, 0.036156874484731816, 0.04606753311236389, 0.13511510915122926, 0.03680494752188679, 0.029957798433315475, 0.0914398964960128, 0.009147807813860709, 0.09219554383889772, 0.028123535921622533, 0.022613733235630207, 0.01396040728650405, 0.035914344334742054, 0.05547017681237776, 0.010664015517249936, 0.07563651481177658, 0.05698214685253333, 0.07182134882896207, 0.10970964271109551, 0.061524112898041494, 0.02974333630845649, 0.10751767244073562, 0.1202899894269649, 0.08901936700567603, 0.15100551507202908, 0.12356553241261281, 0.12380483050947078, 0.12352279212791473, 0.1225336131756194, 0.22529142501298338, 0.15053025854285806, 0.1642901959712617, 0.12259236900717951, 0.14207958622137085, 0.11190153134521097, 0.3415754868183285, 0.16598416288616136, 0.2016926577198319, 0.13915012154029682, 0.2110296324826777, 0.285129189142026, 0.11174400307936594, 0.17920314887305722, 0.2345714028342627, 0.1054819168348331, 0.18418340507196262, 0.2479276861413382, 0.23348354792688042, 0.20949873025529087, 0.22190984396729618, 0.2573271794244647, 0.30636657611466944, 0.20693723723525181, 0.21293989091645926, 0.2824761002557352, 0.5775580834597349, 8.293846305459738, 106.9022324681282, 111.94783732295036, 64.4935517013073, 86.37759581208229, 97.65830889344215, 64.89227190613747, 14.62938979268074, 0.3764345491072163, 2.0457123778760433, 4.014694048091769, 8.060810510069132, 7.429105807095766, 22.546033188700676, 15.321690794080496, 22.61582974344492, 10.889497473835945, 2.9972860543057323, 1.1533648171462119, 1.9778292579576373, 0.6470301118679345, 2.0695511111989617, 0.8734192326664925, 4.8899538069963455, 4.83997936360538, 3.415797734633088, 3.3242266857996583, 5.466160112991929, 4.752492858096957, 6.043365765362978, 9.959727264940739, 17.73655716329813, 22.842956855893135, 27.333533093333244, 32.1452035009861, 48.73441033065319, 60.94963386654854, 67.08907082676888, 63.70722949504852, 71.8052789568901, 73.87731537222862, 71.41502469778061, 68.75754609704018, 73.80094707012177, 75.13608902692795, 79.07358974218369, 84.7469513118267, 80.14911442995071, 76.3101652264595, 71.63199305534363, 62.21132576465607, 58.78974236547947, 63.66828538477421, 65.21526977419853, 74.17078122496605, 72.53477141261101, 75.38770392537117, 51.26988127827644, 57.590336725115776, 76.67119145393372, 72.88699731230736, 74.86808940768242, 73.36352214217186, 68.07139411568642, 60.27847968041897, 59.863576143980026, 64.7765301167965, 75.70079952478409, 77.40937024354935, 75.37121281027794, 77.68143564462662, 76.5187132358551, 78.83773639798164, 77.77418866753578, 73.56341421604156, 74.4802214205265, 68.8588334619999, 66.51169940829277, 57.2736731171608, 56.46687000989914, 48.16546306014061, 48.19657199084759, 39.25620272755623, 34.51992407441139, 21.743136271834373, 31.51430055499077, 24.95327051728964, 13.488436415791512, 20.468735955655575, 19.251841753721237, 19.027429595589638, 31.97058007121086, 37.669996842741966, 45.61538569629192, 23.404828906059265, 13.373670224100351, 0.8903198351617903, 3.026715237647295, 10.185843631625175, 13.901523649692535, 25.599251054227352, 24.539453722536564, 13.028036020696163, 15.421026013791561, 7.535333381965756, 7.6683936920017, 3.607450188137591, 2.6787211233749986, 1.5909480303525925, 13.877806272357702, 57.765047550201416, 62.74993546307087, 89.32273417711258, 50.30415929853916, 69.60371509194374, 83.33542585372925, 17.988698333501816, 1.1431858758442104, 0.6435867841355503, 0.30273302108980715, 0.3270966012496501, 0.2746378630399704, 0.25345839327201247, 0.19001540931640193, 0.14205169631168246, 0.14271658641519025, 0.16104487323900685, 0.09919726187945344, 0.19162855634931475, 0.17941403755685315, 0.21723803918575868, 0.22143031266750768, 0.10609615535940975, 0.32719771144911647, 0.13401238160440698, 0.16904921794775873, 0.24131277546985075, 0.22225532855372876, 0.3256634250283241, 0.1743845027522184, 0.23694070929195732, 0.18033430067589507, 0.16432676900876686, 0.1743895493564196], [0.08889376593288034, 0.06907295333803631, 0.08115936259855516, 0.13802863250020891, 0.08140522870235145, 0.052447769267018884, 0.06341591782984324, 0.04940938328218181, 0.04610074793163221, 0.006604459840673371, 0.11060529621317983, 0.034106238817912526, 0.03696408253745176, 0.018169847571698483, 0.0515385196194984, 0.04836666579649318, 0.013500241402653046, 0.0426341612910619, 0.07864161176257767, 0.14040699315955862, 0.06262098861043341, 0.08805159159237519, 0.03521875900332816, 0.16577030561165884, 0.09749717966769822, 0.11294558469671756, 0.08498776107444428, 0.07672030274989083, 0.09424626114196144, 0.1418131255195476, 0.05178074919967912, 0.17147161765024066, 0.6610721396282315, 21.932622604072094, 73.106389939785, 75.14180392026901, 45.36845974624157, 79.7833688557148, 65.95449730753899, 29.115945249795914, 1.4325967524200678, 0.29285571828950197, 1.3058089558035135, 1.1528728622943163, 1.2998913670890033, 1.8514863937161863, 10.032931286841631, 8.786519318819046, 7.764910412952304, 11.503391582518816, 2.912783813662827, 2.8936219168826938, 1.9989727484062314, 1.3486802740953863, 2.217291221022606, 0.2678616688353941, 0.39487184258177876, 0.9309976024087518, 0.5233015667181462, 0.1493700293940492, 0.6967158301267773, 0.31162377214059234, 3.4650195809081197, 4.815776562318206, 3.612826424650848, 5.497723119333386, 10.15839770436287, 20.057387128472328, 38.93067039549351, 50.77444106340408, 54.96786944568157, 70.5141082406044, 71.91328436136246, 67.65423730015755, 64.0693348646164, 69.5968146622181, 68.91206860542297, 74.76703003048897, 79.19594317674637, 78.02947416901588, 76.78483575582504, 74.52714130282402, 69.16349351406097, 57.69796594977379, 56.681630685925484, 59.815691113471985, 65.71030721068382, 60.08801490068436, 63.67634475231171, 35.09960196912289, 47.80103601515293, 70.83762288093567, 64.70044299960136, 67.79878154397011, 63.14033791422844, 61.39094978570938, 52.70534165203571, 55.516092628240585, 64.28639441728592, 72.45942905545235, 73.33143666386604, 72.70061731338501, 74.68189179897308, 78.77340584993362, 81.1858431994915, 78.07094514369965, 68.67817595601082, 59.21642906963825, 43.005845323204994, 30.40388233959675, 20.51670078188181, 13.832191620022058, 7.173463124781847, 4.488382805138826, 5.817448887974024, 4.834657274186611, 9.926962573081255, 19.315311647951603, 14.869433362036943, 5.976924430578947, 6.339645367115736, 5.159223033115268, 4.0480187349021435, 4.919397477060556, 2.3874824261292815, 10.548740308731794, 16.005392856895924, 7.109335865825415, 0.4554843791993335, 1.433526633772999, 8.660142850130796, 1.427676253952086, 7.149461712688208, 6.158247850835323, 2.707783388905227, 3.418091149069369, 1.7840438126586378, 0.8096356771420687, 2.610588166862726, 1.3933572079986334, 7.206611121073365, 30.59812031686306, 45.75744487345219, 79.20824691653252, 38.865127712488174, 49.99753475189209, 65.78562676906586, 31.16678260266781, 0.22082314681028947, 0.1717946893768385, 0.03733943485713098, 0.04896931197436061, 0.030983398282842245, 0.07721792761003599, 0.05539676727494225, 0.012465782165236305, 0.03507720917696133, 0.02705317900108639, 0.0036516430191113614, 0.13258212944492698, 0.04380092133942526, 0.027053744888689835, 0.06132601512945257, 0.006853589075035416, 0.10962343483697623, 0.02630087317811558, 0.015991180298442487, 0.11653800989734009, 0.030253471923060715, 0.035708379800780676, 0.13391759450314566, 0.04040777021145914, 0.05059068571426906, 0.03147908428218216, 0.03616966539993882, 0.02036307763773948, 0.09153448321740143, 0.06331589858746156, 0.08704376989044249, 0.06468858235166408, 0.1051620660291519, 0.03528111054038163, 0.07577570460853167, 0.016216470357903745, 0.03955745451094117, 0.02945992866443703, 0.09978651229175739, 0.011909511867997935, 0.08361003812751733, 0.03503619438561145, 0.06386814551660791, 0.03974809740611818, 0.023066333851602394, 0.21160775067983195, 0.09458405707846396, 0.06323005436570384, 0.07420578767778352, 0.0820861491956748, 0.11539686878677458, 0.09841523118666373, 0.040891138414735906, 0.0831264398584608, 0.10618784028338268, 0.14044706913409755, 0.06658481419435702, 0.22377450484782457, 0.081756784056779, 0.13254327059257776, 0.7502098940312862, 26.178917549550533, 90.61302334070206, 80.37585586309433, 47.23681569099426, 103.23869705200195, 65.70869609713554, 48.995965495705605, 1.8839050666429102, 0.31154967611655593, 1.664071544073522, 0.9536395187024027, 0.8434244140516967, 3.1212824257090688, 2.3182045435532928, 7.50241432338953, 7.999942526221275, 8.08744803071022, 6.301283575594425, 5.579424435272813, 2.9598594876006246, 6.7106023617088795, 3.534410032443702, 1.4912610920146108, 1.3014781381934881, 3.549601617269218, 3.2092192070558667, 0.5598060297779739, 1.5913148294202983, 0.5088964209426194, 3.373502204194665, 8.320396430790424, 12.833353467285633, 12.30552664026618, 19.965021684765816, 31.738735511898994, 50.400864109396935, 61.100759357213974, 62.167289927601814, 74.47174027562141, 73.92906099557877, 74.269347935915, 71.52697429060936, 77.6624746620655, 75.09129703044891, 79.852145165205, 82.79424369335175, 81.95076495409012, 79.97499257326126, 80.55846646428108, 72.49183371663094, 60.981153175234795, 59.67831328511238, 64.91716057062149, 70.07507979869843, 67.22558990120888, 70.40476530790329, 44.449976831674576, 54.81792189180851, 75.82032591104507, 72.79411509633064, 74.7341237962246, 69.06523078680038, 64.52482402324677, 57.44313642382622, 59.54986497759819, 67.25550949573517, 74.5398098230362, 75.57685017585754, 77.25524291396141, 77.22528532147408, 80.19063860177994, 81.72757253050804, 80.26934757828712, 76.80470868945122, 71.72799870371819, 59.278403744101524, 48.712375313043594, 36.988036036491394, 26.429307013750076, 18.943030424416065, 12.04246485605836, 8.33506079390645, 10.159560441970825, 18.09289824217558, 26.24781735241413, 21.79996222257614, 8.26014781370759, 12.578471694141626, 10.807387679815292, 7.446241462603211, 7.162765748798847, 6.62396558560431, 18.573068976402283, 17.798516638576984, 4.840640053153038, 0.45412785199005157, 1.307342885993421, 7.334450511261821, 4.507577000185847, 8.703833855688572, 4.305343301966786, 5.337398797273636, 3.300650850869715, 1.5717520541511476, 0.6386748945806175, 2.917032935656607, 2.038673018105328, 10.414742399007082, 48.90473239123821, 42.13530823588371, 88.24487641453743, 40.34576006233692, 50.5050241202116, 72.7771832048893, 35.54828189313412, 0.42638812330551445, 0.01607733065611683, 0.032095501010189764, 0.0058578156767907785, 0.04695738673035521, 0.05619999370537698, 0.048980807841871865, 0.022828200926596764, 0.06191041931742802, 0.014513114347209921, 0.03788740330492146, 0.053039116246509366, 0.0397788557165768, 0.07253053030581214, 0.01555286788061494, 0.016155569719558116, 0.17007458402076736, 0.040650077717145905, 0.02824637806043029, 0.012733962794300169, 0.021796496912429575, 0.01805631567549426, 0.1396505962475203, 0.04961073907907121, 0.06056002966943197, 0.04097110853763297, 0.03349582235387061, 0.029442844424920622, 0.18970490957144648, 0.2583800791762769, 0.13499756780220196, 0.24515034689102322, 0.15439776820130646, 0.20756187324877828, 0.22006725455867127, 0.2546674705808982, 0.11863723397254944, 0.08485769227263518, 0.246583879343234, 0.097966469329549, 0.1256261722301133, 0.07790658870362677, 0.14475856121862307, 0.09017135831527412, 0.13853409443981946, 0.3025343926856294, 0.21625463414238766, 0.15730829327367246, 0.12006515578832477, 0.16897531488211825, 0.18809443427016959, 0.26121404429432005, 0.30712098407093436, 0.25213247223291546, 0.18446199246682227, 0.3086167381843552, 0.16389483906095847, 0.28366911748889834, 0.23519133363151923, 0.3691183385672048, 0.9641209000255913, 39.68068175017834, 106.52692660689354, 97.25474014878273, 65.91093644499779, 102.77442276477814, 84.05902102589607, 50.65353915095329, 1.8454573047347367, 0.49446562654338777, 4.532898366451263, 2.020099852234125, 5.983492378145456, 8.699754774570465, 25.54533764719963, 22.289847135543823, 17.6276683062315, 22.85309661179781, 9.171638153493404, 6.502944454550743, 2.7357612876221538, 4.221594370901585, 4.47877929545939, 0.920084350509569, 0.5072173860389739, 2.2481417655944824, 1.6861186735332012, 0.48015915672294796, 2.2069130279123783, 0.7748507405631244, 4.155721105635166, 10.3481500223279, 19.65894240885973, 20.571358948946, 29.35807205736637, 43.47323924303055, 61.1613243073225, 72.79671415686607, 72.45847910642624, 78.33327546715736, 76.95855483412743, 75.1559467613697, 73.78544390201569, 80.94674482941628, 74.51085537672043, 80.89632153511047, 84.62704494595528, 81.88049152493477, 82.50199377536774, 80.6130163371563, 75.40340468287468, 64.61050942540169, 62.58348539471626, 68.30154776573181, 74.35843795537949, 72.87660866975784, 74.3000502884388, 49.33131270110607, 59.23383213579655, 77.53271162509918, 75.50882622599602, 77.7015745639801, 73.54420244693756, 69.85319450497627, 60.328162014484406, 65.43400883674622, 70.73605433106422, 79.31424602866173, 79.4241513311863, 80.42554959654808, 78.27459141612053, 81.29746600985527, 83.0125267803669, 81.67046159505844, 79.32689175009727, 77.60040119290352, 69.06556516885757, 61.589777916669846, 56.005753353238106, 48.58038939535618, 44.4747819006443, 35.2295245975256, 25.57001542299986, 18.483787067234516, 25.930657871067524, 37.98611328005791, 31.50801759213209, 13.45988379791379, 18.53611595928669, 16.39958180487156, 11.358349565416574, 12.335393987596035, 18.977264687418938, 28.649771064519882, 20.79665645956993, 8.276706375181675, 1.1793354735709727, 3.034185874275863, 13.6984539963305, 10.240931175649166, 19.26518663764, 13.576952666044235, 9.993183519691229, 9.106637891381979, 4.9918068666011095, 1.9395003584213555, 5.815553739666939, 2.4234997434541583, 9.60160693153739, 49.691506773233414, 55.255673602223396, 98.13063874840736, 56.746816188097, 57.42813862860203, 83.32348689436913, 62.615901455283165, 0.6626876466907561, 0.30165637261234224, 0.15038800367619842, 0.15203990566078573, 0.18092389247613028, 0.11017365570296533, 0.07091258899890818, 0.09281214981456287, 0.08452562571619637, 0.18034475011518225, 0.12873498431872576, 0.18145749665563926, 0.17270284064579755, 0.2539675362640992, 0.19000162021256983, 0.07953836364322342, 0.27812663989607245, 0.11465719988336787, 0.106079590623267, 0.20039568044012412, 0.28583488252479583, 0.088197527511511, 0.21513084444450215, 0.16231229819823056, 0.13314668118255213, 0.11218938074307516, 0.1447286526672542, 0.13368191808694974], [0.0451933202566579, 0.09501599444774911, 0.0155751415877603, 0.10220484502497129, 0.057582021108828485, 0.06514314038213342, 0.043515435681911185, 0.0072975353214133065, 0.05023538622481283, 0.007099344784364803, 0.14674477104563266, 0.11312768547213636, 0.11446780379628763, 0.017915303906193003, 0.043105235818075016, 0.07484663219656795, 0.04703884114860557, 0.16005133045837283, 0.11382505195797421, 0.07001618592767045, 0.1352367174695246, 0.06260526992264204, 0.010456953532411717, 0.052475677730399184, 0.02922912815847667, 0.06298899737885222, 0.08266999677289277, 0.0420032244437607, 0.11649901745840907, 0.08655410085339099, 0.15885951550444588, 0.1333883689949289, 0.0681957125198096, 0.8194012125022709, 52.64343537390232, 84.69562366604805, 63.71955223381519, 32.73026950657368, 87.59362936019897, 57.5455941259861, 32.84254588186741, 1.224617762491107, 0.16242465935647488, 0.6827542511746287, 0.6375466519966722, 0.8301467983983457, 3.838160983286798, 5.126860644668341, 5.172887099906802, 2.9045517928898335, 2.7926620468497276, 6.897664424031973, 3.9977830555289984, 6.13711385987699, 7.5634756218642, 1.2897200253792107, 1.0687904991209507, 2.421603170223534, 2.0228528045117855, 1.3834026921540499, 2.1638105157762766, 0.17042033578036353, 0.1676136371679604, 1.0309598478488624, 0.8903847285546362, 5.006932904943824, 9.871860779821873, 23.09770278632641, 47.25560188293457, 54.22332599759102, 58.63007493317127, 65.35857528448105, 69.38316732645035, 68.73790875077248, 68.31409469246864, 70.1996599137783, 70.67556917667389, 74.36437323689461, 77.5110299885273, 74.28423553705215, 75.89818373322487, 76.36053532361984, 72.68018960952759, 62.347111478447914, 58.844577223062515, 56.17148905992508, 66.03723406791687, 58.60344976186752, 69.91185575723648, 34.28117148578167, 23.161163181066513, 71.62700772285461, 59.48143444955349, 74.26629289984703, 62.77869991958141, 61.89502313733101, 53.14900204539299, 62.321394458413124, 69.41285133361816, 75.95174565911293, 78.13807994127274, 76.84126272797585, 79.56662848591805, 81.2293128669262, 75.3638944029808, 78.13090592622757, 70.09362280368805, 57.80639313161373, 41.15896962583065, 24.636732302606106, 12.174992244690657, 7.443611053749919, 6.011799909174442, 4.60739859379828, 3.916813200339675, 6.476258961483836, 13.905416540801525, 14.035650752484798, 7.767898952588439, 2.7863045129925013, 4.591593341901898, 5.267716236412525, 1.8077700957655907, 2.9298662720248103, 3.8338617514818907, 4.772317819297314, 5.295279957354069, 1.3406101008877158, 0.6511137052439153, 0.6716792704537511, 5.024280874058604, 5.729964757338166, 2.6195293245837092, 1.1825663689523935, 2.009819741360843, 0.5642237677238882, 0.9508948191069067, 0.9489639289677143, 2.2135629085823894, 5.495349671691656, 29.014503993093967, 37.17936336994171, 73.39885264635086, 40.421087220311165, 32.877838388085365, 63.35675910115242, 47.050462290644646, 0.8922019216697663, 0.22440785367507488, 0.048136099067050964, 0.035552031549741514, 0.039727669791318476, 0.062211820331867784, 0.07269924273714423, 0.049979323011939414, 0.013081107936159242, 0.054271589760901406, 0.03701351328345481, 0.1018328954523895, 0.050908183911815286, 0.09658018199843355, 0.03794041491346434, 0.03774911892833188, 0.005551117583308951, 0.0676478368404787, 0.02689070246560732, 0.051856466816389, 0.05242256593191996, 0.046704845008207485, 0.06315983235253952, 0.07121244634618051, 0.04583798683597706, 0.0357848618295975, 0.08445829807897098, 0.02453093260555761, 0.09416403860086575, 0.0411164433171507, 0.009401345869264333, 0.1266720364219509, 0.04493163898587227, 0.07952723142807372, 0.04769255821884144, 0.05146996001712978, 0.04209445665765088, 0.012522991546575213, 0.027283996205369476, 0.08746948806219734, 0.08325911359861493, 0.13203967886511236, 0.039932684376253746, 0.07417222033836879, 0.09378579561598599, 0.1169613903039135, 0.07654082917724736, 0.040605782633065246, 0.09377599926665425, 0.06389701506122947, 0.09225726083968766, 0.027940084437432233, 0.02602107237180462, 0.05809720889374148, 0.037737819729954936, 0.056618308954057284, 0.13345952611416578, 0.1564352455898188, 0.097119968268089, 0.04370460541395005, 0.1776448910823092, 0.13289065507706255, 1.0814431076869369, 60.5201581120491, 100.354043841362, 61.70234687626362, 44.089474976062775, 102.18940615653992, 59.07451428472996, 54.75885406136513, 1.5255465335212648, 0.24246426211902872, 0.7526024000253528, 1.1073283874429762, 0.586587170837447, 3.6040068604052067, 5.089862504974008, 8.484565671533346, 6.978589631617069, 6.452462738379836, 7.177481409162283, 8.119526859372854, 9.631836209446192, 13.784624822437763, 10.476602129638195, 3.836310957558453, 4.373924396932125, 5.250236699357629, 2.9647398507222533, 2.7691443962976336, 0.10672491771401837, 0.31097943952772766, 2.024112674407661, 5.935598323121667, 10.19060667604208, 16.932845190167427, 32.1193040907383, 53.53783518075943, 58.884349688887596, 64.35298204421997, 67.12470531463623, 73.15812036395073, 74.20560255646706, 73.25940012931824, 74.88791674375534, 79.51575681567192, 81.04724943637848, 84.42352786660194, 80.16220852732658, 82.54079729318619, 81.242186576128, 77.8741081058979, 65.92597603797913, 62.726426124572754, 59.495425298810005, 73.09717923402786, 64.54875513911247, 80.47220349311829, 38.3201951533556, 28.62189196050167, 77.55456805229187, 66.51130422949791, 78.73712539672852, 66.52513548731804, 67.34459191560745, 55.90827718377113, 64.00858372449875, 72.29204803705215, 76.91890776157379, 80.09693562984467, 76.14405333995819, 80.38875997066498, 80.56956946849823, 78.11487078666687, 82.6816177368164, 80.00588491559029, 71.55294969677925, 55.306507274508476, 40.41680485010147, 27.182162515819073, 15.926112961024046, 14.457492716610432, 9.960247837007046, 13.054737187922, 15.929957404732704, 18.138788379728794, 15.696972906589508, 7.090372033417225, 2.8623721562325954, 5.3096061386168, 8.92403393983841, 4.743061289191246, 4.915114156901836, 6.332441903650761, 6.61550153978169, 5.910332528874278, 1.9894826388917863, 1.3089095894247293, 3.997918898239732, 8.028306104242802, 4.807674922049046, 3.8057591719552875, 2.037713094614446, 3.4853026550263166, 0.6028536229860038, 0.8235552802216262, 1.246958188712597, 2.614631149917841, 7.270511342212558, 51.17149315774441, 35.05509875714779, 81.1916720867157, 48.47979739308357, 39.44078542292118, 65.18680930137634, 55.89028134942055, 1.1686357227154076, 0.07092214043950662, 0.032566594090894796, 0.026488315561437048, 0.023718661250313744, 0.07628333361935802, 0.02779523390927352, 0.06611985125346109, 0.06758687683031894, 0.02670037869393127, 0.026731244615803007, 0.11518881510710344, 0.05466046401124913, 0.06487253107479773, 0.03329431441670749, 0.0377687672880711, 0.06624918532907031, 0.030921156212571077, 0.08201353746699169, 0.07335458140005358, 0.0945474840409588, 0.06217943300725892, 0.013945076370873721, 0.0773341182502918, 0.02659909223439172, 0.025803838325373363, 0.08027660762309097, 0.030411482584895566, 0.14635633095167577, 0.19841773813823238, 0.12960444000782445, 0.2191439041052945, 0.11850403330754489, 0.15845853311475366, 0.15035465155960992, 0.11343799968017265, 0.12881673930678517, 0.10867160817724653, 0.12297946581384167, 0.4157400853000581, 0.18513048940803856, 0.17948402208276093, 0.12559518014313653, 0.1281775868847035, 0.1376424336922355, 0.18653049162821844, 0.18305427191080526, 0.10692051815567538, 0.16004781267838553, 0.3333776938961819, 0.14989855728344992, 0.21996348747052252, 0.12955248967045918, 0.20696420688182116, 0.11418413268984295, 0.25170692475512624, 0.29946599795948714, 0.28672620188444853, 0.20733382611069828, 0.32040334946941584, 0.21419605007395148, 0.2981095894938335, 1.2554592825472355, 84.66979265213013, 109.46679845452309, 87.15054273605347, 51.03083610534668, 112.45484411716461, 76.69091999530792, 56.145072877407074, 1.5982113406062126, 0.409690928645432, 1.6469347011297941, 1.657360391691327, 4.22851474955678, 12.382236924022436, 18.132801800966263, 19.59480945020914, 8.522863816469908, 9.48260111734271, 15.641340091824532, 12.234066724777222, 15.270250104367733, 22.703996412456036, 12.333102710545063, 2.2537077544257045, 4.343740241602063, 5.171666415408254, 3.7559381453320384, 6.493408866226673, 0.8094005053862929, 0.29314554180018604, 2.975021149031818, 8.700677175074816, 15.888623222708702, 24.448456205427647, 40.700999200344086, 65.97143679857254, 70.3715930879116, 74.60449755191803, 72.29615941643715, 73.1640100479126, 73.87907087802887, 72.13759392499924, 74.77807983756065, 79.24790918827057, 77.5433586537838, 82.91088983416557, 78.75851824879646, 80.09384259581566, 80.78681141138077, 78.51375058293343, 67.3446375131607, 66.3636365532875, 62.62231171131134, 77.9988706111908, 69.13808047771454, 86.11840412020683, 41.456216275691986, 33.68398793041706, 86.17187485098839, 70.41134655475616, 83.73225376009941, 69.54083606600761, 69.57577139139175, 61.4208921790123, 69.01058211922646, 78.46659511327744, 81.33004546165466, 84.14915978908539, 79.57566440105438, 82.19931721687317, 82.22358271479607, 79.53731685876846, 83.71210724115372, 82.84198433160782, 78.76529708504677, 70.43488249182701, 61.3229638338089, 51.555975526571274, 43.60867917537689, 33.207124918699265, 24.914668388664722, 22.35256277024746, 25.04355937242508, 24.83697585761547, 19.16671872138977, 8.122409954667091, 4.12775888107717, 6.725731724873185, 11.595357097685337, 8.651406168937683, 7.935666125267744, 11.970415972173214, 9.95980516076088, 7.604154339060187, 2.326523484662175, 2.4511791206896305, 3.320728735998273, 14.133213367313147, 13.645324297249317, 11.416848376393318, 8.5484753921628, 6.431008139625192, 4.604025324806571, 1.7197456816211343, 2.7268115803599358, 3.4382127318531275, 7.377504575997591, 52.92257599532604, 46.22556075453758, 93.23471546173096, 64.62043449282646, 47.171732783317566, 72.69870221614838, 82.72464662790298, 6.010388284921646, 0.471877382369712, 0.15680654207244515, 0.14366445742780343, 0.30739712237846106, 0.2119228962692432, 0.14097427600063384, 0.10573136009043083, 0.12281979274121113, 0.21283802372636274, 0.10791287350002676, 0.21153222973225638, 0.16577081027207896, 0.22054261498851702, 0.14067643729504198, 0.12921329849632457, 0.18768270558211952, 0.18375494837528095, 0.1599918250576593, 0.15431533043738455, 0.18343252973863855, 0.13714786648051813, 0.15810703713214025, 0.17907935864059255, 0.09963254633476026, 0.09345347672933713, 0.17774727777577937, 0.16693565557943657, 0.21781626128358766], [0.09214326695655473, 0.06434658585931174, 0.04687730528530665, 0.03813769631960895, 0.06945671790163033, 0.027877163302036934, 0.005481607568071922, 0.039180710664368235, 0.05686598218744621, 0.06862758309580386, 0.04597644932800904, 0.05751978460466489, 0.14189971931045875, 0.1544510989333503, 0.06733526650350541, 0.03293246918474324, 0.07698503424762748, 0.1266252959612757, 0.12506409926572815, 0.04476976173464209, 0.010132780644198647, 0.08391674549784511, 0.08288531607831828, 0.08680550337885506, 0.026070927997352555, 0.034196769702248275, 0.06502970310975797, 0.04284794064005837, 0.10031510697444901, 0.03876770548231434, 0.1930805979645811, 0.062197890219977126, 0.12189317683805712, 0.16738876642193645, 6.704859444871545, 87.12653562426567, 81.4850315451622, 52.68649086356163, 41.704475954174995, 78.71300429105759, 44.4117546826601, 28.034236393868923, 2.832587454468012, 0.7600543939042836, 0.3641407540999353, 0.6057432491797954, 0.3752849920419976, 2.674693576991558, 3.127962229773402, 6.674307659268379, 6.235624048858881, 6.682134764268994, 8.1805363856256, 14.612544346600771, 7.488116165623069, 8.218998871743679, 8.606697767972946, 6.325627444311976, 7.375661674886942, 2.504906337708235, 1.4325867779552937, 0.3566300414968282, 0.19424790720222518, 0.511326331179589, 0.8776798134204, 4.221930652856827, 8.264542277902365, 14.05880481004715, 23.779015727341175, 36.39400631189346, 51.492667123675346, 62.19302214682102, 72.46790260076523, 74.81898084282875, 77.31764316558838, 74.12039592862129, 74.76030439138412, 71.26500874757767, 74.36767905950546, 71.6000671684742, 73.69934052228928, 74.50156107544899, 74.71018508076668, 69.50425162911415, 64.77118760347366, 59.065672159194946, 69.2885448038578, 58.10954086482525, 70.39961278438568, 41.55639410018921, 3.6118140164762735, 58.64669904112816, 68.61057758331299, 75.59565156698227, 70.47822296619415, 62.654875963926315, 58.708103746175766, 66.7714686691761, 74.15159225463867, 77.57127955555916, 78.57028394937515, 79.57890942692757, 81.4133369922638, 80.93596860766411, 85.55517554283142, 80.65428972244263, 72.54509925842285, 51.26858554780483, 32.42011874914169, 14.971708673983812, 8.903778176754713, 7.157440334558487, 7.064566668123007, 6.975573543459177, 7.469044988974929, 4.492758270353079, 2.7367423474788666, 1.4034797460772097, 0.36352307943161577, 0.40143462480045855, 0.20162567147053778, 0.4966904962202534, 0.38995187846012414, 1.168456538580358, 2.5571950944140553, 3.2291023526340723, 0.032023753883549944, 0.6511529500130564, 0.9683078003581613, 1.65656219702214, 2.8203048510476947, 3.702085060067475, 4.640647284686565, 1.807932537049055, 3.4771879529580474, 1.8610118888318539, 1.118141538463533, 2.1715905983000994, 8.21250407025218, 31.367311142385006, 34.49069224298, 77.18156486749649, 47.35611408948898, 26.41228012740612, 63.58345493674278, 60.692513063549995, 12.857826054096222, 0.9391443058848381, 0.11534485907759517, 0.12497116753365844, 0.15865238208789378, 0.07315091381315142, 0.1000489060243126, 0.08550870421458967, 0.07910830390756018, 0.03688548538775649, 0.10533746521105058, 0.031337300679297186, 0.12979015504242852, 0.011078555089625297, 0.13290610659169033, 0.11785437207436189, 0.03335029090521857, 0.015332689363276586, 0.008822434501780663, 0.0622955642757006, 0.06555302112246864, 0.01991286302654771, 0.06761998403817415, 0.06326069764327258, 0.04462360688194167, 0.021482288284460083, 0.019022348897124175, 0.05332561122486368, 0.04264957569830585, 0.03967434277001303, 0.1222791604232043, 0.09251485287677497, 0.042474540168768726, 0.011036104242521105, 0.04771253312355839, 0.07399116599117406, 0.01692117853963282, 0.02938230558356736, 0.046849771606503054, 0.10307638614904135, 0.07487415845389478, 0.013657459821843076, 0.14064535615034401, 0.08947152047767304, 0.0521355291857617, 0.0819849202525802, 0.04039046703837812, 0.13920452096499503, 0.06536631160997786, 0.02505595013644779, 0.16234680806519464, 0.06440272933105007, 0.14135807025013492, 0.04526734948740341, 0.03805077969445847, 0.06837711567641236, 0.027767913597926963, 0.044335297352517955, 0.17616086290217936, 0.0708347228646744, 0.29557892528828233, 0.06521515097119845, 0.08010776160517707, 0.3904875903390348, 8.067736588418484, 98.60660120844841, 93.02501231431961, 46.74100689589977, 54.29367922246456, 89.95163843035698, 52.01334938406944, 50.96641816198826, 3.039968926459551, 0.8304110029712319, 0.9772897465154529, 0.9899126691743731, 0.36541018285788596, 1.3455102941952646, 0.05554019473493099, 3.4851943608373404, 6.895375996828079, 9.8096277192235, 8.383155763149261, 9.350310266017914, 10.244712922722101, 10.946271177381277, 12.076679170131683, 9.270218163728714, 12.373031917959452, 3.9498424530029297, 2.29784048628062, 0.4935051390202716, 0.24846930551575497, 0.5895944719668478, 2.681398317217827, 6.97984023950994, 11.712311021983624, 16.654458828270435, 26.5348444506526, 39.70510683953762, 58.11968632042408, 69.77272242307663, 80.13836860656738, 79.6646100282669, 82.63690173625946, 80.5292384326458, 80.25880694389343, 77.50260204076767, 77.88305282592773, 74.70484256744385, 79.79247316718102, 79.9609637260437, 79.16293814778328, 73.28306525945663, 68.94272536039352, 62.76405170559883, 77.28963106870651, 64.22667682170868, 79.19107183814049, 45.33692143857479, 5.638551162555814, 66.64175882935524, 74.78173524141312, 81.91735714673996, 75.43945714831352, 66.37137293815613, 63.71828310191631, 69.80910167098045, 77.84013792872429, 78.31746071577072, 79.31963413953781, 81.01058900356293, 82.67431452870369, 82.07801252603531, 83.84501650929451, 79.83527407050133, 79.4417367875576, 65.76950803399086, 48.66501845419407, 35.23871250450611, 21.79237972944975, 21.408834010362625, 20.58931678533554, 21.107996553182602, 12.610873505473137, 5.057432195171714, 2.7146952180191875, 1.7026189318858087, 0.27247675869148225, 0.4152078169863671, 0.15817878796951845, 0.7395930262282491, 0.6342529412358999, 2.1152716828510165, 3.18266908172518, 2.37074859905988, 0.20269589294912294, 0.5450534401461482, 1.2202683021314442, 5.844955611974001, 3.5145957581698895, 4.5326433051377535, 2.628704644739628, 3.05550629273057, 0.7672332774382085, 1.2214176217094064, 1.193629594054073, 2.9493454517796636, 11.456016674637794, 56.89038008451462, 34.7871333360672, 83.32496121525764, 55.49524314701557, 31.976515352725983, 63.04373189806938, 74.79925990104675, 13.80769718438387, 0.6287756538949907, 0.15140922856517136, 0.023498983682657126, 0.16092069708975032, 0.08148791879648343, 0.034853032339015044, 0.10609094548271969, 0.14076441148063168, 0.045156457781558856, 0.08263579860795289, 0.03544488768966403, 0.04137472926231567, 0.0124771592891193, 0.1196738806902431, 0.010058145635412075, 0.017657398311712313, 0.05474447883898392, 0.039308597552007996, 0.038062331223045476, 0.06553523926413618, 0.010882429578487063, 0.02694665854505729, 0.09479012922383845, 0.05959122638159897, 0.037649845544365235, 0.038994884307612665, 0.09159714274574071, 0.06989434012211859, 0.05259171623038128, 0.20555206312565133, 0.11700980801833794, 0.11028172724763863, 0.08748669104534201, 0.1911200219183229, 0.18396556988591328, 0.21672862902050838, 0.17503131413832307, 0.15213356469757855, 0.2675616630585864, 0.1413954744930379, 0.13108867598930374, 0.35617338318843395, 0.37614321161527187, 0.16119854233693331, 0.18438636761857197, 0.1630649546859786, 0.2467912799329497, 0.25113582727499306, 0.11003436200553551, 0.16461029910715297, 0.20118632004596293, 0.32619501056615263, 0.21316048689186573, 0.20937572669936344, 0.12795601127436385, 0.21409243141533807, 0.13527103437809274, 0.2869294019183144, 0.17732677690219134, 0.5046109633985907, 0.2279298787470907, 0.2555692393798381, 0.6630405527539551, 13.1122338026762, 118.81763309240341, 101.97839587926865, 78.64606708288193, 63.50682444870472, 103.87035995721817, 60.17693392932415, 48.91255237162113, 4.909736020490527, 0.9880022623110563, 1.5109911770559847, 2.0446082996204495, 1.671045001130551, 7.970236670225859, 9.405913632363081, 23.741414844989777, 17.156161107122898, 22.2089209780097, 19.73994266241789, 33.112259209156036, 19.982624240219593, 20.104838982224464, 23.785885758697987, 14.471557661890984, 15.582251362502575, 10.206490773707628, 7.058933945372701, 2.728877244517207, 0.31310815655160695, 0.7272069971077144, 3.3374817995354533, 9.195228237658739, 13.877879418432713, 19.547239802777767, 28.919693380594254, 44.43416208028793, 63.28871615231037, 73.80712553858757, 80.18813833594322, 81.13109573721886, 83.35850581526756, 79.05416518449783, 78.02461043000221, 74.76390659809113, 75.69422587752342, 70.20826265215874, 78.0927711725235, 81.05160400271416, 79.62655127048492, 75.50355970859528, 73.13505560159683, 65.91160520911217, 80.72660744190216, 68.95949766039848, 81.88113749027252, 46.601174399256706, 6.124499486759305, 68.43312710523605, 80.55428668856621, 86.96464911103249, 78.52222412824631, 70.52256658673286, 67.40858808159828, 74.05570060014725, 80.50442576408386, 83.01291435956955, 84.9781309068203, 86.82504460215569, 86.53771921992302, 83.54655772447586, 84.31575044989586, 81.04471877217293, 82.74141892790794, 76.16623654961586, 60.77185660600662, 52.23457731306553, 41.647638604044914, 38.921930864453316, 35.85932940244675, 32.43575111031532, 22.42576204240322, 11.39521423727274, 4.759099278599024, 1.9630368892103434, 0.2308523078681901, 0.42434083472471684, 0.2826946182176471, 0.8143345999997109, 1.107823548372835, 3.4945884067565203, 3.6095543252304196, 4.201440727338195, 0.19273833429906517, 1.664792555384338, 1.115350944455713, 5.168424239382148, 9.111409485340118, 11.223876681178808, 12.72798702120781, 6.641365326941013, 5.8048786874860525, 3.8294801115989685, 2.1286678640171885, 3.073831284418702, 11.660961527377367, 54.58745285868645, 47.04728186130524, 95.7742027938366, 73.162642121315, 41.15090265870094, 72.1308682858944, 93.31435158848763, 27.67685417085886, 1.1574338050559163, 0.38205073680728674, 0.24778011749731377, 0.1847512964741327, 0.21597929735435173, 0.07801987012499012, 0.168880557466764, 0.20494976575719193, 0.13001786079257727, 0.10153600669582374, 0.10755985611467622, 0.26276566728483886, 0.14125595072982833, 0.1833442586939782, 0.17267912160605192, 0.12662965978961438, 0.14527804974932224, 0.19710686785401776, 0.17264259309740737, 0.17071977752493694, 0.08569495359552093, 0.11704031770932488, 0.2061745765968226, 0.28328382410109043, 0.11591107322601601, 0.11540928491740488, 0.21790327067719772, 0.12056526684318669, 0.14644860959379002], [0.04748608902445994, 0.0665858383581508, 0.039342851378023624, 0.11836027188110165, 0.035738136211875826, 0.056566187922726385, 0.08994055038783699, 0.01661064354266273, 0.030529463656421285, 0.04041808606416453, 0.06976935503189452, 0.041743658293853514, 0.07380891678621992, 0.029188187581894454, 0.05928647085966077, 0.058491612144280225, 0.045789457799401134, 0.08799276896752417, 0.14400260959519073, 0.04849357675993815, 0.061011823199805804, 0.17616356431972235, 0.032908330831560306, 0.056331005034735426, 0.08547447636374272, 0.045064694932079874, 0.13446892116917297, 0.10157187469303608, 0.04939121921779588, 0.20930249156663194, 0.08103409549221396, 0.3532118577277288, 0.15793995000422, 0.2291409153258428, 0.2978225564584136, 31.687139980494976, 87.03936070203781, 68.17379862070084, 48.69160182774067, 45.18544256687164, 74.2695227265358, 44.74945016205311, 31.587955802679062, 10.525959581136703, 1.6031418135389686, 0.12243210221640766, 0.8104698511306196, 1.2372390227392316, 1.3184419716708362, 3.1680396292358637, 4.136758698150516, 3.122386741451919, 4.262535749003291, 4.614800596609712, 10.415869038552046, 11.103073563426733, 6.781296143308282, 8.124397248029709, 10.424030050635338, 2.1957663260400295, 2.5051310006529093, 0.12283853939152323, 0.12995596567634493, 0.049794517108239233, 0.1942311495076865, 0.11225912778172642, 0.7779827225022018, 1.7903916095383465, 3.849860318005085, 10.628515128046274, 15.43405931442976, 17.724154628813267, 22.65822596848011, 32.49502792954445, 47.8793840110302, 58.990424796938896, 69.91619512438774, 69.92615818977356, 74.32325944304466, 75.03681555390358, 70.41934132575989, 70.49559563398361, 68.18159580230713, 65.79414591193199, 65.41295796632767, 59.427021369338036, 66.62630885839462, 64.15435150265694, 72.74346381425858, 49.58468310534954, 3.474041009321809, 54.903516098856926, 80.63989609479904, 77.8077332675457, 69.28344547748566, 60.14865204691887, 65.52553832530975, 73.88266548514366, 79.05943170189857, 81.27063184976578, 84.05134543776512, 87.41111755371094, 82.6158356666565, 64.05037388205528, 43.542061150074005, 53.65549586713314, 54.059904366731644, 48.06861765682697, 30.20235825330019, 12.734733559191227, 7.635126477107406, 8.764928877353668, 7.586675751954317, 5.294354232028127, 1.4889250486157835, 2.098983619362116, 1.1029104120098054, 0.6461248104460537, 0.3607706318143755, 0.13222512672655284, 0.019311385731271002, 0.11059033451601863, 0.33776648808270693, 0.24222281179390848, 0.08359933635802008, 0.26959057606291026, 0.29186515894252807, 0.3662524017272517, 1.4383262512274086, 5.557338120415807, 4.050500001758337, 2.099237493239343, 1.388983998913318, 0.9135865210555494, 2.4586765933781862, 0.3602068964391947, 2.2395404521375895, 10.50916163250804, 27.049602828919888, 28.277438543736935, 68.79422172904015, 48.984980285167694, 25.31051404774189, 47.23584294319153, 64.19578447937965, 26.355817057192326, 0.3586052526952699, 0.03992078032752033, 0.08177494441042654, 0.142552423349116, 0.08361080996110104, 0.028609262299141847, 0.03014635218278272, 0.13491866266122088, 0.04114701980142854, 0.08467869367450476, 0.060606235783779994, 0.07700726899201982, 0.03451777825830504, 0.03487735251837876, 0.05605685197224375, 0.1072620767808985, 0.0682193721877411, 0.12822970049455762, 0.10144834421225823, 0.04566925956169143, 0.11068750391132198, 0.016667284253344405, 0.03253404349379707, 0.04983742437616456, 0.0693856795260217, 0.04789762104337569, 0.09969185877707787, 0.09745128525537439, 0.18329147715121508, 0.043271551112411544, 0.11411408137064427, 0.08137062235618941, 0.08474765403661877, 0.05984296658425592, 0.023828315424907487, 0.0398283866525162, 0.02128072468622122, 0.026898303913185373, 0.012117140668124193, 0.060371832150849514, 0.06413724084268324, 0.06392514987965114, 0.03751765420020092, 0.0657177556422539, 0.050971837918041274, 0.13900909863878042, 0.031057876512932125, 0.05823188643262256, 0.06777460308512673, 0.05726926523493603, 0.04805441087228246, 0.17679771466646343, 0.07811274248524569, 0.0382442724367138, 0.06353148506605066, 0.07926313817733899, 0.10319340799469501, 0.15767596807563677, 0.06914540921570733, 0.10606217983877286, 0.06701067337417044, 0.31363861402496696, 0.02530259735067375, 0.22049539955332875, 0.25694298441521823, 39.426570385694504, 102.4324943125248, 74.34392273426056, 45.416021794080734, 66.90181687474251, 80.02303719520569, 46.30554646253586, 63.83690133690834, 10.233356282114983, 1.8849939457140863, 0.5477906588930637, 1.2843821430578828, 0.9933584311511368, 1.206388478167355, 2.852026023901999, 2.060879501514137, 4.864231087267399, 7.1091145277023315, 6.278483374044299, 10.943282637745142, 10.72569776326418, 13.897716253995895, 10.89414557442069, 9.973917603492737, 5.807043621316552, 3.6890253983438015, 0.19365601474419236, 0.1598514404031448, 0.09271852046367712, 0.5770986049901694, 1.2348179589025676, 1.4855638914741576, 2.405600566416979, 3.0584432976320386, 14.671175200492144, 18.0541555210948, 22.703394144773483, 28.674255050718784, 40.09004518389702, 57.10351824760437, 69.27795857191086, 76.50803580880165, 78.93160656094551, 83.53075817227364, 84.8998475074768, 79.28696349263191, 79.0152856707573, 74.90270555019379, 71.96807742118835, 71.40734910964966, 65.32683178782463, 73.59411656856537, 69.69250112771988, 82.21687227487564, 55.13926304876804, 4.749061642214656, 59.981210231781006, 86.94660007953644, 80.41516855359077, 73.69429439306259, 64.5419991016388, 69.36496630311012, 75.49504056572914, 79.82123002409935, 84.02733832597733, 83.39354753494263, 84.73497435450554, 83.61432328820229, 68.04003819823265, 53.32653611898422, 60.30227020382881, 60.462792590260506, 57.42817282676697, 41.18150241672993, 25.107143260538578, 16.478180587291718, 14.29557865485549, 9.233261346817017, 3.926749904640019, 0.15325046726502478, 2.0726056722924113, 1.2901290971785784, 0.9993562311865389, 0.3096003510290757, 0.23881301429355517, 0.024225856104749255, 0.10733925271779299, 0.23308894800720736, 0.45520191779360175, 0.0561603741516592, 0.20565669110510498, 0.07629544546944089, 0.6897702184505761, 2.815443961881101, 6.362071763724089, 3.816268458031118, 2.2883172472938895, 2.0932138664647937, 0.4430501104798168, 1.1978585296310484, 0.8620677574072033, 2.9791691014543176, 14.610932283103466, 57.1547394990921, 28.104526922106743, 72.87903293967247, 58.522905483841896, 32.856468334794044, 48.61744500696659, 75.39299324154854, 27.762302085757256, 0.5535632616374642, 0.236275804345496, 0.11212558572879061, 0.18282346398336813, 0.07197328130132519, 0.015242043446050957, 0.14646984986029565, 0.010493795598449651, 0.04365691500424873, 0.07194067133241333, 0.0952456149389036, 0.0569251424894901, 0.05129755169036798, 0.03253764662076719, 0.06322333050775342, 0.08047150302445516, 0.10994409458362497, 0.08672508425661363, 0.08282140974188223, 0.08537218614947051, 0.07619289550348185, 0.05041354990680702, 0.04754970963404048, 0.0478912459948333, 0.03433682781178504, 0.042536802648101, 0.02602909127745079, 0.006916317252034787, 0.14969534240663052, 0.08050276228459552, 0.21051542804343626, 0.11380134776118211, 0.10607685209834017, 0.15242551075061783, 0.142795120482333, 0.1004974971874617, 0.2289098995970562, 0.11338356314809062, 0.08567203607526608, 0.11554207740118727, 0.10067234718007967, 0.1596937488648109, 0.1437343974248506, 0.12855563691118732, 0.11320767414872535, 0.17522296635434031, 0.14974457648349926, 0.2072678491822444, 0.18960857880301774, 0.17552941397298127, 0.2663093333831057, 0.3197103913407773, 0.19190285413060337, 0.20941796974511817, 0.23574378836201504, 0.17593850061530247, 0.23478929739212617, 0.18283401732333004, 0.22715887636877596, 0.2795727294869721, 0.17810993565944955, 0.3804864379344508, 0.26362828037235886, 0.30187815602403134, 0.49350222980137914, 55.905252546072006, 120.07497802376747, 90.51739767193794, 73.7978920340538, 72.36869752407074, 99.64035093784332, 60.75435094535351, 54.22780595719814, 14.85825341194868, 2.437840411439538, 0.6023303791880608, 4.305939394980669, 3.7750399578362703, 5.68092648871243, 8.033224940299988, 15.34832451492548, 14.85149072483182, 20.037354603409767, 21.28431659191847, 32.17618703842163, 34.96135778725147, 20.069844760000706, 20.681231953203678, 20.648272521793842, 16.96232970803976, 7.574662221595645, 0.20346085424534976, 0.5456947151105851, 0.33333031518850476, 0.7438189932145178, 0.9235454304143786, 1.7498994385823607, 3.0747125996276736, 3.842763011343777, 15.547353085130453, 18.466224409639835, 21.466127336025238, 27.5289224088192, 39.59643267095089, 54.944572895765305, 65.96448317170143, 73.21473732590675, 74.5721384882927, 81.57514750957489, 80.04348769783974, 75.5290487408638, 79.76811647415161, 76.57763287425041, 73.73808324337006, 74.50867429375648, 67.39870861172676, 76.60243794322014, 73.87139528989792, 85.6911550462246, 55.543952733278275, 5.587231116369367, 59.26689796149731, 87.64422744512558, 84.717016518116, 77.04859480261803, 66.57315731048584, 72.32841968536377, 80.60901135206223, 84.78871867060661, 86.20928004384041, 89.33623105287552, 90.46027153730392, 86.1314906179905, 69.37502056360245, 55.75882360339165, 64.5341183245182, 65.2205590903759, 68.81518140435219, 56.77131347358227, 43.79363425076008, 31.17816299200058, 27.347200959920883, 19.141581170260906, 12.688512839376926, 2.4545920500531793, 3.2350879814475775, 1.9500047760084271, 1.2744215712882578, 0.6196554901544005, 0.35799315897747874, 0.11446709133451805, 0.2182313593220897, 0.33298539463430643, 0.4498532001161948, 0.24069976148894057, 0.3916760953143239, 0.48333703307434916, 0.9197638614568859, 2.3662771889939904, 14.810045398771763, 10.89221527799964, 9.587489739060402, 5.950499698519707, 3.794988887384534, 5.500361602753401, 0.8060532412491739, 2.612620582804084, 16.756407357752323, 47.09609404206276, 38.02115499973297, 85.20051017403603, 73.08762654662132, 42.7056348323822, 55.40337547659874, 92.98003792762756, 48.0646088719368, 0.7073570403736085, 0.6060064444318414, 0.10665332272765227, 0.14823316305410117, 0.21583483088761568, 0.09557104669511318, 0.18528233282268047, 0.1400809973711148, 0.24600728997029364, 0.1680877507897094, 0.12268556791241281, 0.1064674963708967, 0.08913269295589998, 0.07684895404963754, 0.16353243350749835, 0.14633618906373158, 0.2984701842069626, 0.23898214974906296, 0.3121633728733286, 0.221187986608129, 0.2631131705129519, 0.12995384313398972, 0.18880867719417438, 0.10065071357530542, 0.1746764636482112, 0.22597960371058434, 0.18295540299732238, 0.14861980715068057, 0.30117834045086056, 0.1417649898212403], [0.039176784703158773, 0.03118200256722048, 0.03196045981894713, 0.11597506862017326, 0.03235057716665324, 0.07253754360135645, 0.029782555102428887, 0.035365229268791154, 0.06846274467534386, 0.05622896715067327, 0.01912027899379609, 0.03838211894617416, 0.10332732112146914, 0.043602088844636455, 0.024483362794853747, 0.12530783540569246, 0.008323091569764074, 0.051808479547617026, 0.0775484653422609, 0.018741826352197677, 0.04714645256171934, 0.014517615472868783, 0.08191983390133828, 0.07075865272781812, 0.08976960409199819, 0.08309831988299266, 0.03462069187662564, 0.0976418168283999, 0.14318416913738474, 0.05024308971769642, 0.16955028637312353, 0.1268931815866381, 0.09730281119118445, 0.0647719923290424, 0.12145513901486993, 0.23126267100451514, 54.77252572774887, 66.99487388134003, 68.64135593175888, 38.011005744338036, 48.4089045971632, 96.76284894347191, 45.60891464352608, 41.78335212171078, 25.35705015063286, 0.14637785323429853, 0.17779666028218344, 0.24263693019747734, 0.8459107868839055, 0.6165097933262587, 3.0320670129731297, 5.81558033823967, 4.829079648479819, 1.3778837257996202, 4.260763144120574, 4.710829043760896, 13.280462175607681, 6.8526434898376465, 13.35355220362544, 0.8872415847145021, 2.140131611377001, 0.32293754629790783, 0.2759359386982396, 0.0566505070310086, 0.2272007186547853, 0.1569960717461072, 0.1741188287269324, 0.1919207992614247, 0.22398963861633092, 0.22194074699655175, 0.07684122087084688, 0.21296788472682238, 0.12914650520542637, 0.09939717419911176, 1.6561600123532116, 6.945560853928328, 17.481292560696602, 35.362722650170326, 41.43068924546242, 48.52428160607815, 60.20514741539955, 68.42383280396461, 66.70144602656364, 69.22998234629631, 70.23218616843224, 65.88189080357552, 77.27430269122124, 60.60355603694916, 78.06426510214806, 52.39102631807327, 3.7909974390640855, 59.42687697708607, 86.87003418803215, 82.75942996144295, 75.45969486236572, 67.93627336621284, 71.77101239562035, 76.85834661126137, 81.29871234297752, 83.80742892622948, 81.40029609203339, 77.40852668881416, 79.32127565145493, 57.18489088118076, 37.415269911289215, 24.09120697528124, 20.807381384074688, 13.461936637759209, 5.014778058975935, 1.6985492315143347, 0.37480354600120336, 0.4454719164641574, 0.1405519642867148, 0.7279876177199185, 1.1447977018542588, 0.9855802485253662, 0.10302324095391668, 0.06103334548242856, 0.07976815482834354, 0.056317646376555786, 0.06723831233102828, 0.0814131845254451, 0.06798417074605823, 0.12636045314138755, 0.11858384386869147, 0.20216675649862736, 0.21704291371861473, 0.6447116425260901, 1.8373398715630174, 7.011351948603988, 2.220678976736963, 0.9208957257214934, 1.4744608872570097, 1.3710994273424149, 0.16407944087404758, 1.683723139576614, 13.94729409366846, 25.535944551229477, 24.881142787635326, 68.27858939766884, 49.33016136288643, 32.766796946525574, 34.54247586429119, 56.85609072446823, 27.92301256209612, 0.784689481370151, 0.17080729157896712, 0.08075317775364965, 0.055591128329979256, 0.05656697088852525, 0.017784197953005787, 0.033395795690012164, 0.03840700686851051, 0.04196104819129687, 0.07555985837825574, 0.07635984162334353, 0.05646120371238794, 0.07140164947486483, 0.0721403535862919, 0.018892512016464025, 0.05788848728116136, 0.04828551194805186, 0.14597318979213014, 0.0660687914933078, 0.06562777023646049, 0.08518157294020057, 0.062487298127962276, 0.03796885401243344, 0.0995194430288393, 0.07095118809957057, 0.042771989246830344, 0.11273730837274343, 0.012800702279491816, 0.02320549396245042, 0.029141812628949992, 0.022257250020629726, 0.02527032876969315, 0.036044940061401576, 0.02654651292687049, 0.017377083568135276, 0.11082114244345576, 0.04907582129817456, 0.05487568683747668, 0.031280849216273054, 0.04461215183255263, 0.07375331508228555, 0.04337298043537885, 0.06333113487926312, 0.02371950729866512, 0.07099430687958375, 0.12139616053900681, 0.03164693582220934, 0.09566069071297534, 0.05107153803692199, 0.027120489939989056, 0.04912291427899618, 0.016955183746176772, 0.04261489513737615, 0.06873376958537847, 0.013128611881256802, 0.1199985999846831, 0.0373547898925608, 0.05074202075775247, 0.18364123650826514, 0.07082784315571189, 0.03926379780750722, 0.12647722265683115, 0.10411096969619393, 0.060438747896114364, 0.056455904777976684, 0.05990894351270981, 0.5407778383232653, 71.73116773366928, 79.00389388203621, 75.98952323198318, 39.138865023851395, 75.90321466326714, 95.3341256082058, 39.74107950925827, 76.79477602243423, 28.328488804399967, 0.2562643645796925, 0.10985429471475072, 0.41117249289527535, 0.4120635747676715, 0.6332075223326683, 0.5372278788127005, 3.89728628564626, 6.129653435200453, 7.817259253934026, 4.407772030681372, 6.229533450677991, 8.58497528359294, 5.241585038602352, 10.238950531929731, 5.273525174707174, 2.7392117399722338, 0.6503035174682736, 0.1063694067124743, 0.047143424599198624, 0.2936331328237429, 0.16371362144127488, 0.17654839757597074, 0.6774590571876615, 0.19371017668163404, 0.09924020254402421, 0.25846901815384626, 0.12399416722473688, 0.1538672365131788, 0.19638676196336746, 2.535519157536328, 9.117444511502981, 22.182609289884567, 40.873513743281364, 50.49810469150543, 56.534532979130745, 70.48276752233505, 77.99153700470924, 75.20200788974762, 73.4954434633255, 76.55443891882896, 71.23512715101242, 82.37340867519379, 66.26683294773102, 86.6883659362793, 56.54757767915726, 4.934268454089761, 64.78449448943138, 89.99964505434036, 88.11551615595818, 80.04794105887413, 70.32857939600945, 75.39058417081833, 79.82669413089752, 84.5972241461277, 85.18310710787773, 87.64534458518028, 84.39670890569687, 82.88701191544533, 58.23151431977749, 38.1802524626255, 27.109196931123734, 24.703173637390137, 13.97239364683628, 5.045512234792113, 1.505721928551793, 0.9649448620621115, 0.32291943789459765, 0.3943925636122003, 0.5794615438207984, 1.1911590141244233, 0.5256219953298569, 0.18813771632267162, 0.04114719791687094, 0.047162568298517726, 0.10683946078643203, 0.06233117252122611, 0.02793009512970457, 0.08824069082038477, 0.10311474034097046, 0.11736888132872991, 0.26492098288144916, 0.4490631096996367, 4.3457346595823765, 5.62579857185483, 4.749898072332144, 2.1339453058317304, 1.5427014254964888, 0.5666237545665354, 0.5586697719991207, 0.7426822010893375, 2.2196342702955008, 16.02703269571066, 60.74631817638874, 21.430872827768326, 61.14569574594498, 61.61502756178379, 37.356821447610855, 38.935564532876015, 67.12237223982811, 33.36067467927933, 0.846243625273928, 0.2868756407406181, 0.03198502861778252, 0.07317328214412555, 0.05908104809350334, 0.027774539121310227, 0.08648463583085686, 0.021981119134579785, 0.1429492051829584, 0.1112968145753257, 0.06545070864376612, 0.08617708983365446, 0.09397877627634443, 0.050064725655829534, 0.013923373189754784, 0.02764651864708867, 0.05822472470754292, 0.10203674857621081, 0.008665071363793686, 0.08260163012892008, 0.09503022884018719, 0.10980411811033264, 0.09230781593942083, 0.07765436981571838, 0.017189383288496174, 0.02694520022487268, 0.05508671652933117, 0.09179173386655748, 0.03276968651334755, 0.013150481117918389, 0.039754212702973746, 0.16748656664276496, 0.14375862112501636, 0.17971006542211398, 0.3002556727733463, 0.16557706519961357, 0.27544434007722884, 0.17259214189834893, 0.11281840284937061, 0.1217735129466746, 0.24251904746051878, 0.12025144227663986, 0.12286078155739233, 0.2829396160086617, 0.17404715210432187, 0.2207676786929369, 0.20810677291592583, 0.237854782899376, 0.11870088055729866, 0.14674039237434044, 0.14472658949671313, 0.1853270546416752, 0.22277376323472708, 0.17158573027700186, 0.1137386733898893, 0.27399525220971555, 0.22358650399837643, 0.1544622311485, 0.2983977209078148, 0.2769398270174861, 0.09328728017862886, 0.24971464416012168, 0.18568325584055856, 0.14263867575209588, 0.1306267039035447, 0.23687786422669888, 1.2886311463080347, 92.91449144482613, 94.00535970926285, 95.78292712569237, 56.76333390176296, 72.85891681909561, 118.28788071870804, 61.2465613335371, 71.37809827923775, 39.32532861828804, 0.21401305129984394, 0.417740618577227, 0.6751502654515207, 1.6376303066499531, 2.108652200549841, 9.264081493020058, 14.121089167892933, 14.970116559416056, 16.419517435133457, 14.826607760041952, 18.280606269836426, 32.7132274210453, 24.88558854907751, 33.66634547710419, 14.608288574963808, 9.705825839191675, 1.222174612339586, 0.47551547933835536, 0.14545503712724894, 0.41175730526447296, 0.29978874314110726, 0.27162275451701134, 1.279905627015978, 0.46650996257085353, 0.4486512771109119, 0.3363155300030485, 0.2811832493171096, 0.38277629006188363, 0.3765728260623291, 2.8162108082324266, 9.874167256057262, 24.07259937375784, 41.01393140852451, 49.38957117497921, 57.65491805970669, 73.75044777989388, 78.99355843663216, 77.40127667784691, 79.41426426172256, 81.4485003054142, 75.42337641119957, 87.74001270532608, 72.3325614631176, 88.24489161372185, 55.616350248456, 6.554476339370012, 66.60617753863335, 93.83946821093559, 90.5960002541542, 82.78800442814827, 74.81414750218391, 77.74369150400162, 84.61151137948036, 87.17907160520554, 91.60708799958229, 90.98585173487663, 90.43320938944817, 88.90332788228989, 68.5923233628273, 47.606786638498306, 33.43984343111515, 30.109327845275402, 20.674303025007248, 11.359326113015413, 4.168002996593714, 1.7924083513207734, 1.3733751489780843, 0.8937234431505203, 1.2332028080709279, 2.0913740526884794, 1.5885991626419127, 0.3536857635481283, 0.11139498586999252, 0.23811134335119277, 0.2024194280966185, 0.18097112275427207, 0.23778984497766942, 0.22438245738158002, 0.3836851241067052, 0.3451412689173594, 0.5950776371173561, 0.39440001477487385, 5.245850784704089, 6.4434420224279165, 18.235857971012592, 6.425601029768586, 6.463944772258401, 3.647528300061822, 2.5763550912961364, 1.1133125913329422, 1.5756342583335936, 19.073486924171448, 47.455904334783554, 32.08345301449299, 85.18875360488892, 74.559196382761, 49.076882153749466, 45.05273088812828, 87.78887808322906, 58.75084385275841, 1.8740054103545845, 0.41468481067568064, 0.155377343762666, 0.19373076385818422, 0.12885075935628265, 0.07193104567704722, 0.1333730955957435, 0.1584523287601769, 0.14853999658953398, 0.29958174331113696, 0.18072044011205435, 0.20790709066204727, 0.13538067927584052, 0.18418401363305748, 0.15913327893940732, 0.22142274276120588, 0.11086448386777192, 0.24350199237233028, 0.22413909231545404, 0.20290342712542042, 0.14135048550087959, 0.18589932471513748, 0.16472000337671489, 0.2912917756475508, 0.12856345914769918, 0.13690724736079574, 0.17693685251288116, 0.11617489188211039, 0.1697994550340809, 0.1929046050645411, 0.11625973420450464], [0.03128798496618401, 0.035215679090470076, 0.11136587883811444, 0.054124217786011286, 0.025723742037371267, 0.05693660496035591, 0.026866324769798666, 0.038156992159201764, 0.05656259221723303, 0.0772572317509912, 0.038686726038577035, 0.03687762233312242, 0.04195277695544064, 0.08029298682231456, 0.07138973058317788, 0.1592936718952842, 0.03350023071106989, 0.07796851350576617, 0.12741504498990253, 0.02613314223708585, 0.036058194818906486, 0.04944556669215672, 0.03449808536970522, 0.06661167251877487, 0.05545156745938584, 0.10190673914621584, 0.06813072264776565, 0.035036817789659835, 0.0872357412299607, 0.02768362046481343, 0.025559387868270278, 0.21922929561696947, 0.23643867607461289, 0.026731908837973606, 0.11395381457987241, 0.3142077522352338, 2.526919269002974, 57.26411283016205, 62.98516184091568, 63.20181101560593, 35.04077732563019, 50.948414728045464, 104.08942580223083, 43.99934761226177, 34.81899842619896, 36.53127394616604, 1.3113565393723547, 0.1370795740513131, 0.04188134153082501, 0.5547058722004294, 0.11875612603034824, 2.021760600619018, 2.5591327529400587, 3.3777793496847153, 4.737702151760459, 2.591501553542912, 5.184509251266718, 6.695250710472465, 3.436238500289619, 2.8226452879607677, 4.049048479646444, 0.561709312023595, 0.24093243962852284, 0.2240871122921817, 0.061049257128615864, 0.04772051492182072, 0.39452962344512343, 0.5793633428402245, 0.7016239198856056, 0.196158507023938, 0.10404829532490112, 0.26853105635382235, 0.3326037822989747, 0.6749136687722057, 1.551578699145466, 0.08013217826373875, 0.5832444783300161, 2.2299269679933786, 9.816921427845955, 21.625281795859337, 33.87715436518192, 43.9226221293211, 61.61176733672619, 63.625853061676025, 66.86657756567001, 64.74516659975052, 68.83063897490501, 68.06757912039757, 94.87764090299606, 24.618911258876324, 1.6150791104882956, 56.28551334142685, 87.21229702234268, 81.9415694475174, 80.3103169798851, 75.35791352391243, 77.93346852064133, 78.45700442790985, 86.23066529631615, 89.55379217863083, 76.81598648428917, 71.38158649206161, 64.23755943775177, 52.35850386321545, 34.69596482813358, 22.834580205380917, 9.14164636284113, 1.537021561525762, 0.4416315397247672, 0.4650728084379807, 0.6934836879372597, 0.7323199789971113, 0.9140531241428107, 0.800140758510679, 0.3411609528120607, 0.040354773445869796, 0.03576765513571445, 0.05268511922622565, 0.08013827871764079, 0.08397370533202775, 0.05199989798711613, 0.06888373536639847, 0.18855993897886947, 0.07923383076558821, 0.32020653190556914, 0.12660288310144097, 0.8570035197772086, 0.30137135821860284, 4.979215767234564, 2.8335540276020765, 1.4177523739635944, 1.3467009365558624, 0.10785664097056724, 0.02868304291041568, 0.8639488939661533, 20.727363377809525, 34.2122545838356, 22.432573176920414, 78.4284907579422, 61.97164602577686, 53.55282537639141, 31.0304307192564, 56.42266698181629, 39.31008383631706, 2.3046112479642034, 0.2928206592332572, 0.06071845222322736, 0.033657053936622106, 0.043380606002756394, 0.018918307214335073, 0.0688219812582247, 0.0661160885647405, 0.05303603633365128, 0.05082326737465337, 0.038898612910998054, 0.1424023907748051, 0.021375509932113346, 0.048554221357335337, 0.08300952933495864, 0.07720680281636305, 0.09719636494992301, 0.024226188215834554, 0.06813232568674721, 0.10444117346196435, 0.07868784014135599, 0.04756148380693048, 0.06870624332805164, 0.009970461815100862, 0.027780370546679478, 0.09632842324208468, 0.03633748725405894, 0.0239016359046218, 0.06698057928588241, 0.03306375510874204, 0.06133154412964359, 0.05850478155480232, 0.08626970986369997, 0.1019230812380556, 0.13833128032274544, 0.043571334244916216, 0.0501541247649584, 0.12196334690088406, 0.06931598443770781, 0.019722004908544477, 0.028045098333677743, 0.06108494329964742, 0.014997240468801465, 0.04641684347006958, 0.10646423092111945, 0.08179691198165528, 0.00901876503121457, 0.0510879135254072, 0.01534164523036452, 0.04808490200957749, 0.040191437874455005, 0.03162850458465982, 0.04932106770866085, 0.0840832908579614, 0.0252650725087733, 0.07258579804329202, 0.00965363062277902, 0.03150200551317539, 0.022934491316846106, 0.04069145245011896, 0.022441584660555236, 0.04808913967281114, 0.13695548695977777, 0.15529312484432012, 0.2473739697597921, 0.0859032670268789, 0.06282887901761569, 0.366586041636765, 5.158094968646765, 82.06604316830635, 77.87750512361526, 61.04823857545853, 34.692347422242165, 83.29327091574669, 96.998231112957, 35.79684175550938, 71.5998999774456, 48.50023649632931, 0.874107233248651, 0.39358576002996415, 0.18760187085717916, 0.7535104325506836, 0.27080989500973374, 0.7749935891479254, 2.5148964766412973, 1.6225334792397916, 2.3938240483403206, 6.2547308485955, 12.119611166417599, 10.794177688658237, 12.071254011243582, 7.911045346409082, 1.0269154398702085, 0.3920401039067656, 0.3610958706121892, 0.1316402104566805, 0.1226338476408273, 0.1641204667976126, 0.486346174729988, 1.3827953184954822, 2.1280078869313, 0.16141803993377835, 0.24508695263648406, 0.4919012391474098, 1.206465542782098, 1.5562353492714465, 2.1873101172968745, 0.14478401688393205, 0.07722167545580305, 1.4697546022944152, 9.747039377689362, 23.696763440966606, 41.005803644657135, 54.6400648355484, 71.85007855296135, 71.00064173340797, 74.44619044661522, 70.27955442667007, 76.28937274217606, 75.93492016196251, 99.32980120182037, 23.947095908224583, 2.0584352826699615, 60.96518263220787, 93.00784483551979, 88.17964911460876, 83.67726311087608, 78.64623427391052, 80.05821570754051, 79.17933806777, 88.28634738922119, 91.50596782565117, 79.66667711734772, 73.80807548761368, 68.29182028770447, 54.32433217763901, 38.25243338942528, 29.751404151320457, 14.520173203200102, 2.0399951096624136, 0.15285191911971197, 0.31992297212127596, 0.5964326206594706, 0.568302373867482, 0.6175723706837744, 0.6838560733012855, 0.16665591043420136, 0.04677728604292497, 0.05373091291403398, 0.15006836067186669, 0.04939160142384935, 0.05268662207527086, 0.07012007175944746, 0.19795468251686543, 0.16044980438891798, 0.04799572183401324, 0.2967240591533482, 0.8831901708617806, 3.8709736475721, 2.035477627068758, 2.6019175071269274, 3.2120201317593455, 0.5331407231278718, 0.761416977038607, 0.19718158728210256, 0.4172889475012198, 1.1987531441263855, 24.47113148868084, 77.87028551101685, 18.49825669080019, 60.03270126879215, 77.2543765604496, 61.48734301328659, 35.922596007585526, 60.63623808324337, 55.34548558294773, 4.556704089045525, 0.1782404349069111, 0.16207375709200278, 0.0784445196040906, 0.0464056184864603, 0.047306003179983236, 0.05428917123936117, 0.1327680522808805, 0.04455715126823634, 0.020820839890802745, 0.015563842389383353, 0.11763494127080776, 0.10281713912263513, 0.08021309462492354, 0.015002868731244234, 0.06439571603550576, 0.0060621683587669395, 0.05953293068159837, 0.07291730798897333, 0.09082219956326298, 0.07951515668537468, 0.0632002051861491, 0.0038779788110332447, 0.026595116178214084, 0.015862384279898833, 0.08501273434376344, 0.1121023268206045, 0.08824379299767315, 0.03344678123539779, 0.018705654074437916, 0.10691985764424317, 0.0369489353033714, 0.1964666912681423, 0.1933983262279071, 0.27130467002280056, 0.20712378347525373, 0.22772368043661118, 0.2562910522101447, 0.13619784323964268, 0.1927513218834065, 0.1059268121025525, 0.15831632277695462, 0.1859800555394031, 0.20255040231859311, 0.18231331167044118, 0.2434811380226165, 0.17854542791610584, 0.22404978226404637, 0.12243605044204742, 0.1428358198609203, 0.29241589189041406, 0.19647072855150327, 0.13538299477659166, 0.19897365127690136, 0.16257534502074122, 0.17209181562066078, 0.13904295541578904, 0.24830205511534587, 0.14037108805496246, 0.12079487249138765, 0.29505957034416497, 0.1580704640946351, 0.16529267420992255, 0.28699162357952446, 0.352432721410878, 0.14024287462234497, 0.1346278446726501, 0.6217734015081078, 7.5064886547625065, 107.55227118730545, 96.12721145153046, 89.2442911863327, 56.09271548688412, 80.67958876490593, 128.51095855236053, 58.29042635858059, 59.616129621863365, 54.44824352860451, 1.8445091368630528, 0.8418914338108152, 0.3719806537264958, 3.6241315305233, 0.9837375255301595, 5.234082341194153, 14.741020202636719, 8.38572347536683, 16.454433761537075, 15.36154305562377, 21.34468775242567, 22.991160303354263, 22.231290377676487, 21.94877363741398, 12.89639113470912, 1.5546071366406977, 0.5063765030354261, 0.5385233124252409, 0.20365375326946378, 0.3125476272543892, 1.6555155906826258, 4.254164798185229, 5.800529345870018, 0.2594005619175732, 0.5455638596322387, 1.2459280877374113, 1.6097924066707492, 1.954540426377207, 1.9832078693434596, 0.34020343387965113, 0.880684977164492, 3.7831563223153353, 13.23262844234705, 30.00816397368908, 49.04502846300602, 64.09819811582565, 75.00229820609093, 75.00052750110626, 75.13434112071991, 73.14571022987366, 77.14267775416374, 75.54977282881737, 101.04421600699425, 25.58258704841137, 2.126458282582462, 63.475263342261314, 95.02034604549408, 90.07358148694038, 85.64524590969086, 82.81524896621704, 83.268503844738, 85.07782995700836, 91.35833814740181, 93.23384150862694, 82.94365167617798, 75.39719581604004, 70.79891055822372, 61.699538826942444, 49.518460258841515, 41.01101316511631, 21.502649076282978, 4.089407538995147, 0.40267721749842167, 0.6326190289109945, 0.856767991790548, 1.3772847829386592, 1.008702542167157, 1.7886347975581884, 0.6725814251694828, 0.13551387994084507, 0.28946511272806674, 0.27517122973222286, 0.2743704820750281, 0.2853466087253764, 0.15522351139225066, 0.23936667130328715, 0.2511402207892388, 0.36372853559441864, 1.3023155182600021, 1.0124650527723134, 2.669448908418417, 6.985152829438448, 14.806191455572844, 7.86673117429018, 3.729820246808231, 5.238465880975127, 0.537343950709328, 1.185792158357799, 0.7138051756191999, 29.228537008166313, 62.606690749526024, 29.76408787071705, 92.65341505408287, 89.24044579267502, 65.98234981298447, 43.96565102040768, 70.95486178994179, 79.72764104604721, 8.639634400606155, 0.7599740638397634, 0.4029394331155345, 0.12397209575283341, 0.2350126244709827, 0.18754539341898635, 0.13594744261354208, 0.19664238730911165, 0.26048938161693513, 0.27541032002773136, 0.12433033785782754, 0.18220332538476214, 0.2038292563520372, 0.14365942566655576, 0.16735761106247082, 0.19607842928962782, 0.20920157432556152, 0.1893904319149442, 0.26856697630137205, 0.21158968680538237, 0.21780178940389305, 0.11387831589672714, 0.17704081255942583, 0.15200407477095723, 0.19320686697028577, 0.3527257213136181, 0.11682540658512153, 0.2532678988063708, 0.12355602550087497, 0.1981785736279562, 0.18055428809020668, 0.1594156216015108], [0.06877622043248266, 0.04558476975944359, 0.030976366433606017, 0.02646986577019561, 0.07521003222791478, 0.011994836586382007, 0.03137581443297677, 0.06502310541691259, 0.06077982412534766, 0.10871119433431886, 0.04001715191407129, 0.06691354108625092, 0.09642554810852744, 0.03185654059052467, 0.04892669414402917, 0.03174796067469288, 0.05573341288254596, 0.06466378719778731, 0.04950325012032408, 0.026694909065554384, 0.02646539061970543, 0.01889010931336088, 0.06278486223891377, 0.023657380261283834, 0.018500893675081898, 0.1385787717299536, 0.05023574245569762, 0.03712847566930577, 0.042955763565259986, 0.03425106522627175, 0.05434871374745853, 0.11540761508513242, 0.05152317571628373, 0.2478225831873715, 0.026892646892520133, 0.1199251644720789, 0.22348874830640852, 5.39543735794723, 55.224655866622925, 64.33900639414787, 66.18522092700005, 38.54968763887882, 49.17793773114681, 102.93693244457245, 52.985717207193375, 37.59259879589081, 54.3719208240509, 4.072605790570378, 0.6484568165615201, 0.10784261437947862, 0.3000690374756232, 0.18470972136128694, 2.031555287539959, 2.346625356003642, 0.9909427107777447, 4.077852359041572, 5.844947537407279, 4.034113381057978, 6.106770113110542, 3.6185287311673164, 4.049456007778645, 0.8978980535175651, 0.11312223810818978, 0.04747080820379779, 0.05179129511816427, 0.17349684960208833, 0.19642075232695788, 0.45213536359369755, 0.15565161185804754, 0.05733829239034094, 0.0374225591076538, 0.10923350302618928, 0.23873752303188667, 1.1560940206982195, 0.6390989280771464, 0.40789962164126337, 0.4360386554617435, 0.31521398574113846, 0.3543932974571362, 1.9816542277112603, 10.966719780117273, 29.715497978031635, 55.81783063709736, 62.34062522649765, 70.39556980133057, 84.60630565881729, 81.60121411085129, 67.14626535773277, 37.877420112490654, 2.2279745852574706, 0.4003406100673601, 32.048985064029694, 82.62187734246254, 84.69759196043015, 81.47135987877846, 83.1867778301239, 82.64344498515129, 87.0851482450962, 87.27630078792572, 78.15419107675552, 66.754399985075, 48.14647167921066, 35.91019347310066, 26.168278120458126, 17.819404117763042, 6.063437238335609, 2.039991784840822, 0.5352652841247618, 0.06781186631997116, 0.07707835189648904, 0.19689915556227788, 0.13702542695682496, 0.20858939155004919, 0.04735773087304551, 0.02633321226312546, 0.02813020968460478, 0.14144552493235096, 0.14463699742918834, 0.1814361970173195, 0.08900379674741998, 0.10777401766972616, 0.054194102121982723, 0.06791030478780158, 0.14692211465444416, 0.27221973810810596, 0.2199297642800957, 0.8572806080337614, 1.8074357137084007, 5.382931753993034, 0.19273855694336817, 0.6770455918740481, 0.40841686888597906, 0.4042979492805898, 0.2809138793963939, 27.04321537166834, 27.890784591436386, 18.99194709956646, 82.35201582312584, 57.537504360079765, 32.58775815367699, 43.28355722129345, 50.90576961636543, 57.721828669309616, 4.993066024035215, 0.1993377786129713, 0.14186862332280725, 0.11635558999842033, 0.1690090974443592, 0.034841948363464326, 0.08694268937688321, 0.032939957454800606, 0.02873573910619598, 0.04750256841361988, 0.03436690705711953, 0.069290491665015, 0.0960002678039018, 0.13031002948991954, 0.04521822673268616, 0.046637988634756766, 0.06707038657623343, 0.029343684218474664, 0.018077617169183213, 0.03493203766993247, 0.04180793941486627, 0.021586983057204634, 0.05223075415415224, 0.06681610451778397, 0.06259203742956743, 0.006037110206307261, 0.050380045649944805, 0.040282510526594706, 0.09744627575855702, 0.038865275637363084, 0.04610094089002814, 0.009297218839492416, 0.01507539140220615, 0.10502853139769286, 0.032834735757205635, 0.0517710381973302, 0.08891507299267687, 0.09064647383638658, 0.028010350979457144, 0.00945730473176809, 0.05869619257282466, 0.0960153630876448, 0.08278272158349864, 0.057915998695534654, 0.018082335373037495, 0.03910127859853674, 0.028774213897122536, 0.10281607785145752, 0.12203981037600897, 0.04016681712528225, 0.03446872971835546, 0.025347506561956834, 0.015621805978298653, 0.10665600188076496, 0.03808310393651482, 0.08459564734948799, 0.03224373016564641, 0.024012013673200272, 0.03319893730804324, 0.0392551035474753, 0.004793896887349547, 0.04998507094569504, 0.04808186291484162, 0.07222630913020112, 0.06387357803760096, 0.05928014776145574, 0.16800400684587657, 0.21367843175539747, 0.11113467015093192, 0.4215363773982972, 10.804233849048615, 78.99962291121483, 73.39265897870064, 62.25513741374016, 40.609055534005165, 87.99382388591766, 103.27011376619339, 34.058488234877586, 69.00998175144196, 70.48488020896912, 2.4136950820684433, 0.1089004123059567, 0.11195540384505875, 0.2519715449307114, 0.4650850093457848, 0.6534029636532068, 0.8697663818020374, 0.7890659559052438, 4.6143674198538065, 2.3979815002530813, 7.002335982397199, 9.529267363250256, 5.162028232589364, 1.8151850416325033, 1.3132077525369823, 0.8012079074978828, 0.3054838062962517, 0.07640684183570556, 0.18184142449172214, 0.2193143605836667, 0.5559723917394876, 0.8039739215746522, 0.07860510551836342, 0.0926970798172988, 0.23999647266464308, 0.12758330471115187, 0.20201779261697084, 0.48820780764799565, 0.2954957156907767, 0.5617317545693368, 1.06143765617162, 0.46844043710734695, 1.570755795110017, 11.702229212969542, 34.17931795120239, 58.99686545133591, 64.76405918598175, 75.05867958068848, 90.02218544483185, 83.46249863505363, 67.68236339092255, 34.61771182715893, 1.5715063735842705, 0.23777053429512307, 33.38732644915581, 91.91226482391357, 93.16976174712181, 87.24487647414207, 89.6558926999569, 85.38533225655556, 92.25862383842468, 91.19015157222748, 82.04085811972618, 70.78481331467628, 56.69297307729721, 45.54889686405659, 32.60084845125675, 24.186509661376476, 13.085559234023094, 4.589388985186815, 0.3469098958885297, 0.5166452145203948, 0.22362963762134314, 0.20796347904251888, 0.20091979997232556, 0.18054864776786417, 0.07739044725894928, 0.08240349154220894, 0.11011810594936833, 0.08102309686364606, 0.11372243519872427, 0.10114344768226147, 0.09079620955162682, 0.07046358965453692, 0.0524906134523917, 0.042371648814878426, 0.19257224164903164, 0.6170113664120436, 1.041598089504987, 1.9721353822387755, 3.331959508359432, 2.002758770249784, 0.5939916672650725, 0.9107599477283657, 0.21942085877526551, 0.23165419843280688, 0.5452503764536232, 31.223580054938793, 66.76131561398506, 17.420005649328232, 58.245060592889786, 81.70823156833649, 48.94091784954071, 49.945625737309456, 55.0111149251461, 70.87622880935669, 8.966472912579775, 0.199435667891521, 0.13295108074089512, 0.06964946849620901, 0.06587515032151714, 0.06766686550690793, 0.0551747723511653, 0.09901355806505308, 0.058608262916095555, 0.06248617006349377, 0.015690035324951168, 0.09002166712889448, 0.049263844412053004, 0.1039721658162307, 0.022900545482116286, 0.07957184192491695, 0.08815716952085495, 0.06847853015642613, 0.09696605426142924, 0.054623456817353144, 0.06487880964414217, 0.03627346217399463, 0.03025467234692769, 0.048036766311270185, 0.037643036339432, 0.019690836561494507, 0.010210958480456611, 0.0652631901903078, 0.03863010759232566, 0.09818175152759068, 0.08964199179899879, 0.10345979448175058, 0.053366013744380325, 0.20989934157114476, 0.18614859727676958, 0.11411835614126176, 0.1634636809467338, 0.16216121177421883, 0.17836903425632045, 0.12262707925401628, 0.1284971705172211, 0.23792251129634678, 0.22876593779074028, 0.15380249154986814, 0.10634876758558676, 0.15457763511221856, 0.12107959744753316, 0.18115394341293722, 0.21831600868608803, 0.147024575562682, 0.12529282917967066, 0.1304277786402963, 0.0961048660974484, 0.18167004775023088, 0.10337798012187704, 0.23569620185298845, 0.19810725323623046, 0.15432417683769017, 0.16910122765693814, 0.19480246963212267, 0.17912131967023015, 0.08092021293123253, 0.2395888406317681, 0.1839336278499104, 0.248324200802017, 0.22720719018252566, 0.31801024975720793, 0.30372898327186704, 0.260113439289853, 0.6108610995579511, 14.840899743139744, 104.6732796728611, 92.0713622868061, 94.99653652310371, 58.25157344341278, 81.80981531739235, 130.09088337421417, 69.46611687541008, 58.29260364174843, 85.72131022810936, 7.8151774406433105, 1.2146951886825264, 0.25924981688149273, 0.347030806588009, 1.7916272557340562, 3.876607082784176, 13.493216559290886, 7.007372137159109, 15.04963394254446, 13.258618097752333, 11.357031036168337, 21.741958335042, 15.358268581330776, 13.252098597586155, 5.193872898817062, 2.0488586090505123, 1.0227345954626799, 0.17065047577489167, 0.2911565563408658, 0.5781447363551706, 0.992838452802971, 2.6628624368458986, 0.1984800785430707, 0.33656204177532345, 0.37091534526553005, 0.46161891252268106, 1.2004561652429402, 1.4849427435547113, 1.2085865414701402, 1.6787925479002297, 2.1342324279248714, 1.9268023897893727, 6.481947731226683, 18.03962890058756, 41.82105369865894, 68.08027043938637, 71.67128294706345, 80.23460984230042, 93.81748259067535, 91.51183471083641, 68.68158057332039, 40.65785251557827, 1.6873667878098786, 1.2071105581708252, 38.23966607451439, 93.601775765419, 95.2035342156887, 90.74174523353577, 90.03861576318741, 90.56044176220894, 93.4398740530014, 97.74927601218224, 84.80944275856018, 76.18864014744759, 62.28644013404846, 48.6812549829483, 37.41658464074135, 24.896845445036888, 14.13215797394514, 5.964784556999803, 0.9185166377574205, 0.509041347540915, 0.4879150749184191, 0.6083976442459971, 0.3090613440144807, 0.44024345639627427, 0.15767292527016252, 0.21470063627930358, 0.3871854190947488, 0.27668963419273496, 0.28888558445032686, 0.3025236463872716, 0.10836533867404796, 0.1603402485488914, 0.2871328394394368, 0.20648868317948654, 0.29449191642925143, 1.0216049873270094, 0.8291222783736885, 2.5011488143354654, 12.723059635609388, 12.320736274123192, 4.703272199258208, 4.454617816954851, 0.6479705614037812, 1.5937306685373187, 0.3449393156915903, 38.03749032318592, 49.35941219329834, 26.689999625086784, 99.144766330719, 85.78987374901772, 48.08024503290653, 58.98895427584648, 63.221395164728165, 100.34738659858704, 19.79405175894499, 0.2709210984176025, 0.4327363951597363, 0.20749650488141924, 0.355475734686479, 0.19553387101041153, 0.16627216071356088, 0.26911307824775577, 0.16278650087770075, 0.19433031528024003, 0.08777656650636345, 0.23179381125373766, 0.1648878029664047, 0.2057331768446602, 0.1812552910996601, 0.18855610949685797, 0.1636171422433108, 0.13063832593616098, 0.20193008560454473, 0.15700056916102767, 0.21665431035216898, 0.15822952118469402, 0.11210286116693169, 0.13130893057677895, 0.11954611996770836, 0.18522674596169963, 0.08311773446621373, 0.15887418034253642, 0.332548032165505, 0.18438794097164646, 0.15124726225621998, 0.23036992672132328, 0.12175192387076095], [0.025908486713888124, 0.056763168759061955, 0.019021857224288397, 0.07879621596657671, 0.026628119485394564, 0.059814638807438314, 0.03319713759992737, 0.05186105328903068, 0.05689230245479848, 0.028097878021071665, 0.012009611818939447, 0.033075429091695696, 0.09597512384061702, 0.07099391354131512, 0.05643544747726992, 0.05045792662713211, 0.02727656359638786, 0.1295600744197145, 0.13406201644102111, 0.09647189523093402, 0.09647561339079402, 0.07796799400239252, 0.024550675589125603, 0.04634190510842018, 0.058162028071819805, 0.09347116210847162, 0.01397173246004968, 0.029838312657375354, 0.05392159291659482, 0.07120166294043884, 0.010699639533413574, 0.02479169732396258, 0.22987874370301142, 0.10208921099547297, 0.31459245190490037, 0.18081377260386944, 0.2043931995285675, 0.3732257103547454, 11.663537789136171, 68.28352153301239, 61.729724407196045, 57.24488586187363, 24.027526192367077, 40.40355496108532, 94.41137552261353, 47.62061029672623, 33.73211234807968, 69.83609542250633, 11.97751684114337, 0.7845444954000413, 0.10672790856915526, 0.20759607141371816, 0.6885850382968783, 0.6885529181454331, 0.5862074287142605, 1.5901870024390519, 5.115896333009005, 7.199092274531722, 7.592669930309057, 4.391225343570113, 1.310115905944258, 1.9251415226608515, 0.14169709815178066, 0.48096952261403203, 0.7955153379589319, 0.06805232958868146, 0.6111626490019262, 0.31565660261549056, 0.5835316004231572, 0.21298747742548585, 0.13565876201028004, 0.010601599042274756, 0.1035319163929671, 0.07152572914492339, 0.12402341526467353, 0.21124224294908345, 0.2645407657837495, 0.07884257051046006, 0.2048157635726966, 0.8115338534116745, 0.8866522600874305, 6.453949408605695, 20.170003585517406, 24.210778959095478, 28.128756321966648, 40.398767217993736, 27.450336925685406, 6.379727516323328, 0.5917463439982384, 0.6046954554039985, 0.7226066908333451, 7.600711723789573, 48.50579559803009, 89.05174791812897, 83.35496440529823, 85.19283458590508, 81.78032889962196, 77.34349697828293, 68.49571734666824, 52.881511598825455, 32.3051293194294, 18.032202199101448, 6.0135288164019585, 1.2215975183062255, 0.31554311339277774, 0.11027456552255899, 0.6246188550721854, 0.26951882522553205, 0.030624139435531106, 0.07360216186498292, 0.06010959798004478, 0.017638605277170427, 0.04729928674350958, 0.030545148947567213, 0.07284903040272184, 0.022634858469245955, 0.06328799383481964, 0.03014791069290368, 0.10984947817632928, 0.06219252449227497, 0.05439735410618596, 0.025121802755165845, 0.33910665835719556, 0.2741634228732437, 0.07480462663806975, 2.14653545524925, 8.982167020440102, 0.662532567512244, 0.38337832025717944, 1.1638697097077966, 0.13283937267260626, 1.2012749025598168, 0.6003768683876842, 39.13058526813984, 28.412166014313698, 26.08331087976694, 92.08625748753548, 70.67395806312561, 21.973664201796055, 25.927682630717754, 55.71302466094494, 64.20419722795486, 16.79937355220318, 0.5762535659596324, 0.17542365792905912, 0.037282931443769485, 0.07080643219524063, 0.0573781160346698, 0.015502475125686033, 0.1202057111368049, 0.014565799410775071, 0.07164448019466363, 0.0636059521639254, 0.003676533956422645, 0.0389744270069059, 0.07135806314181536, 0.11780685978010297, 0.07526696237619035, 0.11836085075628944, 0.01980358920263825, 0.11908243352081627, 0.04386302054626867, 0.0243967485948815, 0.043944007411482744, 0.02332694271899527, 0.09574142895871773, 0.04485176163143478, 0.177262180368416, 0.045665222278330475, 0.04141698344028555, 0.03821361802692991, 0.0472547096433118, 0.06096555771364365, 0.02563833011663519, 0.08010792487766594, 0.034752526989905164, 0.07811434552422725, 0.07868896078434773, 0.09395638568094, 0.023470234737033024, 0.03319133771583438, 0.026211375734419562, 0.04951512077241205, 0.018633072031661868, 0.017451923595217522, 0.08102559790131636, 0.01668210494244704, 0.04196977955871262, 0.14410190895432606, 0.04909964423859492, 0.0590719382307725, 0.05499394806975033, 0.04480493582377676, 0.08923055997001939, 0.08240798895712942, 0.030800256645306945, 0.034402886376483366, 0.041070148145081475, 0.045164328257669695, 0.02247365286166314, 0.06744932717992924, 0.09338598581962287, 0.045041836783639155, 0.014582253752450924, 0.026325000399083365, 0.06100948914536275, 0.01324797427514568, 0.10092950877151452, 0.1481523283291608, 0.20369559555547312, 0.39553478825837374, 0.07932183463708498, 0.174879856640473, 0.32452081446535885, 19.169870652258396, 90.73884978890419, 67.49994277954102, 58.67349520325661, 34.782045409083366, 79.71023038029671, 95.1065482199192, 31.782727651298046, 63.632293716073036, 90.39823606610298, 3.978817560710013, 0.8410845114849508, 0.15790175908477977, 0.6449653976596892, 0.4540440783603117, 0.374011971289292, 0.32564956170972437, 1.8226696900092065, 3.1080403737723827, 5.083698760718107, 5.890396423637867, 5.969858709722757, 5.287326509132981, 2.0136957708746195, 1.1245149839669466, 0.48000766953919083, 0.6697168538812548, 0.32987131329718977, 2.4878549901768565, 2.7797429775819182, 1.5089105512015522, 0.34630017704330385, 0.15548431692877784, 0.13857791083864868, 0.015386696377390763, 0.040245017225970514, 0.07935375440865755, 0.37842890771571547, 0.3457072307355702, 0.18357249879045412, 0.10547898535151035, 0.24518678634194657, 1.181208654306829, 7.174720382317901, 19.79776605963707, 26.573294587433338, 27.001039534807205, 40.314316749572754, 28.658974170684814, 4.487853683531284, 1.0480618989095092, 1.4292985294014215, 0.305659695295617, 6.588984662666917, 53.356174528598785, 95.00477448105812, 88.74954253435135, 91.87859863042831, 85.89660242199898, 83.18825215101242, 72.45125189423561, 60.279840007424355, 40.50957687199116, 25.501871779561043, 13.753826525062323, 7.347471937537193, 0.7926994515582919, 0.8200201042927802, 0.6632260896731168, 0.2624215779360384, 0.03292217559646815, 0.026592648537189234, 0.09493381643551402, 0.014728191526955925, 0.06000976798532065, 0.08659334562253207, 0.025124507883447222, 0.03843767612124793, 0.07001574063906446, 0.058951205646735616, 0.142110533779487, 0.12777587719028816, 0.10525574733037502, 0.3626061708200723, 0.6857094832230359, 0.18891774321673438, 0.20513105759164318, 0.6114233506377786, 3.08018050622195, 0.12600953603396192, 0.5957700312137604, 1.5126793552190065, 0.3686813620151952, 0.4521774285240099, 1.323121301829815, 43.638359382748604, 66.21213108301163, 17.140150666236877, 61.55418902635574, 93.77904385328293, 38.145514726638794, 26.079421788454056, 53.673377707600594, 81.77206814289093, 25.882662646472454, 0.665444458136335, 0.15575684839859605, 0.07962836389197037, 0.02377381952101132, 0.045194040139904246, 0.044726895284838974, 0.054411499440902844, 0.06458679679781199, 0.0340328997845063, 0.09516932957922108, 0.007063915581966285, 0.03560010787623469, 0.15421190473716706, 0.0824778621608857, 0.03615983936470002, 0.07053176334011368, 0.04533422070380766, 0.06303881033090875, 0.05781190877314657, 0.06834634623373859, 0.03829578490694985, 0.054274836656986736, 0.039061020797817037, 0.019480738264974207, 0.10581711525446735, 0.04009181939181872, 0.01182937105113524, 0.07380616341833957, 0.08869969431543723, 0.08412321098148823, 0.02201448609412182, 0.06628463772358373, 0.03638679925643373, 0.19594374432926998, 0.2527269918937236, 0.1305905167828314, 0.15680391486966982, 0.12362780602416024, 0.17165405239211395, 0.11453908708062954, 0.07800020321155898, 0.1042051705007907, 0.163999407668598, 0.12660269014304504, 0.15958584059262648, 0.27511818101629615, 0.12625245581148192, 0.1721708246623166, 0.22176972648594528, 0.11806408074335195, 0.22381279966793954, 0.20922262163367122, 0.1723763847257942, 0.2169526685611345, 0.2328583924099803, 0.16818299802253023, 0.13822978420648724, 0.19983308797236532, 0.2636237087426707, 0.1324472069973126, 0.062370988744078204, 0.1594537976779975, 0.28652787033934146, 0.06466851467848755, 0.10091608332004398, 0.28823302884120494, 0.20993025944335386, 0.5972552171442658, 0.3318992763524875, 0.21868864103453234, 0.5688418261706829, 21.759304404258728, 112.97733888030052, 86.20683297514915, 86.66886538267136, 45.64344339072704, 70.2112264931202, 121.74491241574287, 62.82148562371731, 46.25098519027233, 94.66454073786736, 19.08325619995594, 1.5632558288052678, 0.34844246052671224, 0.5777341208886355, 1.6476615308783948, 1.7423263262026012, 0.9514286310877651, 8.515364918857813, 13.976293187588453, 21.29940178245306, 15.874646622687578, 17.89689715951681, 11.236473005264997, 6.876401714980602, 3.0710925813764334, 2.6169848861172795, 2.1696125669404864, 0.21729748521465808, 2.4045223742723465, 3.498432612977922, 3.795527033507824, 1.0201877821236849, 0.2103117827209644, 0.1651768694864586, 0.22132020763820037, 0.1519456974347122, 0.23126642627175897, 0.5701169546227902, 0.5111782578751445, 0.4841511097038165, 0.14638849563198164, 0.8906174066942185, 2.6011523231863976, 10.50271337851882, 22.166564650833607, 29.85324438661337, 30.77556699514389, 43.92281971871853, 31.719046868383884, 6.954660890623927, 1.5216059074737132, 2.0953707257285714, 1.3352913362905383, 8.512157890945673, 61.262395083904266, 95.60531705617905, 91.38613745570183, 94.13750901818275, 91.75173863768578, 87.32822880148888, 73.56391578912735, 61.392120122909546, 37.78849348425865, 22.279581986367702, 10.72495300322771, 4.571792604401708, 0.2902619418455288, 1.5563928033225238, 1.5851341048255563, 0.502408150350675, 0.13137098896550015, 0.25114488147664815, 0.23899000167148188, 0.20944697287632152, 0.15506929310504347, 0.18283763900399208, 0.13080297881970182, 0.1562611377448775, 0.1868096727412194, 0.2031253738095984, 0.33257614471949637, 0.2814296423457563, 0.3443549486109987, 0.41441484703682363, 0.7307988731190562, 0.6799011980183423, 0.16778893244918436, 5.171977523714304, 25.633175633847713, 3.528101658448577, 3.342459057457745, 4.233505306765437, 0.48272725485730916, 2.129538729786873, 0.9348145569674671, 54.2104484885931, 49.97247889637947, 35.60391090810299, 108.40775728225708, 98.80875036120415, 36.76911078393459, 41.94993518292904, 66.42135545611382, 97.6656424999237, 39.708788841962814, 0.5823648849036545, 0.49232981458771974, 0.2677067380864173, 0.28680801624432206, 0.16017216694308445, 0.12503671401645988, 0.22910529223736376, 0.2272642613388598, 0.1445856408099644, 0.3615346580045298, 0.16925544594414532, 0.12904076400445774, 0.15420455747516826, 0.2640540653374046, 0.11842190724564716, 0.2292031518300064, 0.18849652988137677, 0.34531083481851965, 0.19729758496396244, 0.226803298573941, 0.11895347794052213, 0.23223831318318844, 0.1695043919607997, 0.13940932403784245, 0.3302825818536803, 0.11829028735519387, 0.20138854044489563, 0.2810962696094066, 0.1415894422098063, 0.15880333492532372, 0.16951919038547203, 0.1775249748607166, 0.12714046519249678], [0.05486897411174141, 0.13576827332144603, 0.04287873976863921, 0.06654034470557235, 0.062379159789998084, 0.08630456854007207, 0.062302421720232815, 0.0385195275885053, 0.07271285372553393, 0.056263673686771654, 0.1257355054258369, 0.04622707259841263, 0.05114920379128307, 0.1140909263631329, 0.05226104491157457, 0.015189493824436795, 0.07657225913135335, 0.07361634430708364, 0.03746027505258098, 0.04505437165789772, 0.02969213925098302, 0.06505095821921714, 0.06988212437136099, 0.044492870147223584, 0.016416161888628267, 0.09961880175978877, 0.09028272499563172, 0.05109543519211002, 0.024890145068638958, 0.03663247982331086, 0.021238923218334094, 0.03274317699833773, 0.09474914040765725, 0.1337642371072434, 0.17790948157198727, 0.34132686734665185, 0.09796927464776672, 0.2024200069718063, 0.04037819191580638, 22.135419622063637, 76.75570651888847, 66.92160621285439, 52.92376533150673, 36.80297076702118, 60.01511961221695, 110.10175958275795, 58.434168845415115, 23.378589414060116, 60.732825100421906, 22.399651743471622, 0.38546675350517035, 0.1494144246680662, 0.13214129372499883, 0.32921807491220534, 0.30400250921957195, 0.9611150831915438, 0.5963711708318442, 1.9471188308671117, 3.96967810112983, 3.718281453475356, 2.4120131973177195, 2.2089929413050413, 0.6859885307494551, 0.2721525589004159, 0.13853376789484173, 0.9361817711032927, 2.32082711532712, 1.3602657336741686, 1.2689429777674377, 0.19894227327313274, 0.07935690111480653, 0.056450041811331175, 0.052079649176448584, 0.09783221481484361, 0.030274734453996643, 0.006854405437479727, 0.0688355031888932, 0.0645265715138521, 0.20889413222903386, 0.22884752950631082, 0.3633808542508632, 0.16805212770123035, 1.2770959152840078, 2.5446313060820103, 1.395061535295099, 1.2510348949581385, 1.0440787626430392, 0.4059050849173218, 0.6548134004697204, 0.8640342706348747, 0.7911417726427317, 0.49736513814423233, 11.31745520979166, 54.967907443642616, 76.80771052837372, 73.88645768165588, 63.19772623479366, 40.3656329959631, 27.658330164849758, 13.01497707143426, 4.0239152032881975, 1.2012556660920382, 0.6485937279649079, 0.3635002806549892, 0.19348140223883092, 0.7128314184956253, 0.35455713397823274, 0.19541846704669297, 0.06691652451991104, 0.033852702617878094, 0.09021825462696142, 0.06817263914854266, 0.14221593359252438, 0.10077331637148745, 0.030983938195277005, 0.1691919329459779, 0.162539410230238, 0.029993939169798978, 0.20877099508652464, 0.11264354543527588, 0.1987837950582616, 0.12316529217059724, 0.25707318680360913, 1.0945090628229082, 0.4915978491771966, 3.265093071386218, 4.455780079588294, 0.9057072876021266, 0.18012278858805075, 0.37395467748865485, 1.724561566952616, 2.6749001909047365, 42.6457804441452, 21.20462156832218, 28.28709952533245, 98.02752748131752, 71.09689816832542, 20.61339609324932, 25.785676650702953, 60.40648341178894, 65.93869015574455, 21.436257138848305, 0.4973237559897825, 0.2181631707935594, 0.07332577122724615, 0.11978612310485914, 0.0783208481152542, 0.07576587857329287, 0.02443231231154641, 0.03503435757011175, 0.05114362655149307, 0.049244715555687435, 0.05619661693344824, 0.06372274394379929, 0.03714260987180751, 0.06452948073274456, 0.04123490864003543, 0.11082756202085875, 0.17163950629765168, 0.0480964090093039, 0.09294650080846623, 0.09638533112592995, 0.10363465931732208, 0.029314907442312688, 0.011369220937922364, 0.049722725452738814, 0.045761938963551074, 0.04117972253879998, 0.028470068791648373, 0.043773480429081246, 0.02157909588277107, 0.017030476483341772, 0.07792894961312413, 0.06033362267771736, 0.08901559689547867, 0.0513539178064093, 0.12958036473719403, 0.12384442408801988, 0.08489543048199266, 0.07902538374764845, 0.10209752304945141, 0.03127934265648946, 0.04327157337684184, 0.0206403198899352, 0.055618005208089016, 0.1336948314565234, 0.061474734102375805, 0.02678040818864247, 0.015279264007403981, 0.060986935277469456, 0.05128979995788541, 0.02414450929791201, 0.0673358231142629, 0.09449435368878767, 0.03043465800146805, 0.0838739681057632, 0.07638252165634185, 0.11010804984834976, 0.033237785028177314, 0.06793544875108637, 0.024675358254171442, 0.0005974128191610362, 0.025971615650632884, 0.060067807644372806, 0.029913056205259636, 0.06657601974438876, 0.11717442379449494, 0.045904089929535985, 0.11883281957125291, 0.12270247403648682, 0.156076135172043, 0.24121528695104644, 0.10661725435056724, 0.23598045925609767, 0.01125857321312651, 35.5588149279356, 96.42162725329399, 72.80493691563606, 42.65466816723347, 41.197640150785446, 84.8784926533699, 92.92384654283524, 27.782275713980198, 52.277663201093674, 96.3147009909153, 11.620068121701479, 0.39294267422519624, 0.17545202281326056, 0.2273528737714514, 0.5259241384919733, 0.33299815957434475, 0.5017337459139526, 0.6101468566339463, 1.5184425772167742, 1.471622558310628, 5.089712888002396, 2.0774924475699663, 1.4936523512005806, 0.5795783875510097, 0.22876817907672375, 0.37962637783493847, 1.2806863663718104, 1.2045245594345033, 0.7499063259456307, 0.8133013523183763, 0.06283562513999641, 0.11710933744325303, 0.05076091212686151, 0.07360385396168567, 0.10123175583430566, 0.047105326448217966, 0.016175895289052278, 0.03529702218656894, 0.02342200812563533, 0.04274969513062388, 0.0900310033466667, 0.44304990267846733, 0.22697004431392998, 1.3547917711548507, 2.8364271484315395, 1.3101106812246144, 1.3261021231301129, 1.3494632695801556, 1.0758929117582738, 1.3474396406672895, 1.0446597752161324, 0.252762318123132, 0.23138089512940496, 9.75674880668521, 59.5403540879488, 81.57229766249657, 77.37608402967453, 70.948865711689, 46.1379374563694, 35.84503076970577, 18.446963243186474, 6.974011827260256, 1.78454692941159, 0.9912592812906951, 0.08807801947114058, 0.25948210910428315, 0.7142121694050729, 0.5664896930102259, 0.2509941364405677, 0.07451176774338819, 0.02670129710168112, 0.1253535071737133, 0.14021209033671767, 0.07334338239161298, 0.040107274617184885, 0.07004186423728243, 0.11606612271862105, 0.30506820359732956, 0.07868942833738402, 0.18494115269277245, 0.03719519103469793, 0.24269710353109986, 0.03307535487692803, 0.6696210277732462, 0.9065348713193089, 1.035139742307365, 1.946350559592247, 0.686892585363239, 0.27705310843884945, 1.102747970726341, 0.5510407313704491, 1.3449983904138207, 3.13113862182945, 62.51200743019581, 54.01461839675903, 16.781875491142273, 64.26669627428055, 93.48802506923676, 37.218117490410805, 23.372226655483246, 54.51449677348137, 87.15079352259636, 33.89413945376873, 0.6048369978088886, 0.2633568918099627, 0.10667510476196185, 0.19419899967033416, 0.02932630497525679, 0.013632697136927163, 0.037616359841194935, 0.06868210126413032, 0.02640777027409058, 0.02583298432000447, 0.12392079108394682, 0.039041142372298054, 0.041144155111396685, 0.126948798133526, 0.04501136048929766, 0.11748535398510285, 0.08468139509204775, 0.08869266617693938, 0.15155295288423076, 0.043673902764567174, 0.05836288291902747, 0.11338492127833888, 0.09782083769096062, 0.07765610644128174, 0.012921556390210753, 0.04186683625448495, 0.05449141390272416, 0.114155085029779, 0.07430230398313142, 0.05586470251728315, 0.07652958563994616, 0.08898002575733699, 0.11821662919828668, 0.1204994235013146, 0.1803602313157171, 0.3550591820385307, 0.2635899558663368, 0.12298116533202119, 0.17242680623894557, 0.13507124822353944, 0.1414916865178384, 0.2996347623411566, 0.18231001653475687, 0.29092096898239106, 0.20741286483826116, 0.148915879544802, 0.21966866188449785, 0.1905953383538872, 0.254561907495372, 0.14901108224876225, 0.13655855669640005, 0.31186295149382204, 0.09806492264033295, 0.2790833869948983, 0.2016065685893409, 0.17741981253493577, 0.1577520975843072, 0.15615863230777904, 0.1174349027860444, 0.22882722434587777, 0.1748321662307717, 0.18149418843677267, 0.17451967753004283, 0.13772781036095694, 0.1424547121860087, 0.1700397624517791, 0.18560009077191353, 0.3871105512371287, 0.2206896196003072, 0.44525078614242375, 0.2722581219859421, 0.40499274793546647, 0.10092749755131081, 41.14722065627575, 115.07962927222252, 92.27880075573921, 75.16457229852676, 62.637784481048584, 84.06811013817787, 137.29376167058945, 76.17871508002281, 36.323417499661446, 88.49842920899391, 34.80988271534443, 0.425887648598291, 0.5436633678618819, 0.21697726333513856, 1.2140783155336976, 0.9070761047769338, 1.735985060222447, 2.5559093384072185, 12.359223458915949, 13.220043517649174, 13.230591751635075, 15.413383673876524, 9.150015413761139, 2.446070294827223, 0.7344753539655358, 0.379149800282903, 2.147663994692266, 6.32793297059834, 6.533257327973843, 3.1079843267798424, 0.5843236204236746, 0.15665731101762503, 0.1323031264473684, 0.17440020659705624, 0.21666665968950838, 0.12977952748769894, 0.084621229179902, 0.24166146613424644, 0.15496583771891892, 0.3452808520523831, 0.3388972539687529, 0.49940553959459066, 0.3469561168458313, 2.279010834172368, 3.8144452683627605, 1.974651797208935, 1.3662607432343066, 1.3203384261578321, 1.1930738738738, 2.1425029216334224, 3.770896280184388, 2.063326332718134, 0.6413203838746995, 13.578531481325626, 63.79549115896225, 83.38602393865585, 82.4698930978775, 73.58907043933868, 46.316391080617905, 34.89460676908493, 16.44963651895523, 8.04252304136753, 1.8996733892709017, 1.7562557850033045, 1.3962759263813496, 0.2792146580759436, 0.9236137080006301, 0.9352196508552879, 0.6207788048777729, 0.17994773079408333, 0.08847719844197854, 0.22278740390902385, 0.28465688636060804, 0.345209576189518, 0.3725947067141533, 0.14818001043749973, 0.35001329029910266, 0.5521523498464376, 0.17948140972293913, 0.45140529808122665, 0.20038628485053778, 0.5179246771149337, 0.2538141788681969, 2.4183859303593636, 2.7037052577361465, 2.4166463362053037, 6.339912302792072, 8.812169842422009, 3.9597285725176334, 2.617219998501241, 0.6705441407393664, 2.354967570863664, 5.879183225333691, 62.46421359479427, 38.49524036049843, 38.35723556578159, 116.53615191578865, 97.36477464437485, 35.1967703551054, 43.527424335479736, 76.8065857887268, 100.78495591878891, 52.34222173690796, 0.9851540776435286, 0.6486832012888044, 0.15981272998033091, 0.30936286377254874, 0.2090743405278772, 0.1516506788902916, 0.20222114108037204, 0.18792135058902204, 0.19846153969410807, 0.23288371448870748, 0.15714215609477833, 0.21911022544372827, 0.12653485784539953, 0.271975482464768, 0.12784856313373893, 0.2740844286745414, 0.25406446075066924, 0.1769748207880184, 0.20314698514994234, 0.14848291059024632, 0.18199185782577842, 0.15005626366473734, 0.1809444054379128, 0.13604381791083142, 0.20473573036724702, 0.17851888871518895, 0.17544425994856283, 0.20562598103424534, 0.21659051533788443, 0.3318872832460329, 0.3064633521717042, 0.19518767396220937, 0.13960465730633587, 0.20476978010265157], [0.10412677002022974, 0.095779746043263, 0.04103607243450824, 0.06735157148796134, 0.07073173503158614, 0.04726828723505605, 0.14794244896620512, 0.11411577346734703, 0.07203028566436842, 0.11606617466895841, 0.07491734402719885, 0.10208632404101081, 0.06892283170600422, 0.02253527894936269, 0.08727906038984656, 0.10909709628322162, 0.07676666471525095, 0.09916926064761356, 0.19819120498141274, 0.054530513953068294, 0.07625376645592041, 0.05009230757423211, 0.045117001500329934, 0.06416587290004827, 0.02555305549321929, 0.04990394678316079, 0.06138632947113365, 0.04771658524987288, 0.08191500994144008, 0.09043879123055376, 0.12434055723133497, 0.055119382159318775, 0.10483581048902124, 0.11802289154729806, 0.33724235370755196, 0.12591526843607426, 0.46961050713434815, 0.1573386916425079, 0.35651364305522293, 0.06990447785938159, 19.84048906713724, 78.74202713370323, 81.03125229477882, 65.20896971225739, 27.66995944082737, 32.318101823329926, 112.25665435194969, 82.97257572412491, 26.477526426315308, 59.575483202934265, 46.3015528768301, 0.4534600081387907, 0.8640370611101389, 0.17678555828751996, 0.175968038092833, 0.8060950390063226, 0.5301166791468859, 0.5552390310913324, 2.9331749444827437, 2.565543008968234, 2.1491041174158454, 1.8158643739297986, 0.8807109226472676, 0.41497493104543537, 1.3926979433745146, 1.9169841916300356, 0.5206763232126832, 0.2478036138927564, 0.15335205243900418, 0.1400864595780149, 0.10023367853136733, 0.09430688718566671, 0.08562007831642404, 0.10936663689790294, 0.05137536587426439, 0.04532250219199341, 0.022790121329308022, 0.07484696616302244, 0.11509184609167278, 0.07437112333718687, 0.07531361377914436, 0.04204557881166693, 0.06434491602703929, 0.36129443964455277, 0.8276544883847237, 0.9045206231530756, 0.8960295037832111, 0.3849484078818932, 0.11063461104640737, 0.06478117269580252, 0.17755307257175446, 0.05457845298224129, 0.8607927476987243, 5.029428172856569, 8.575912769883871, 7.6850068755447865, 5.492259012535214, 2.6491544349119067, 1.357402706053108, 1.147147638257593, 0.841630850918591, 1.081360699608922, 0.8429722383152694, 0.4567551735090092, 0.03979976201662794, 0.08569860496209003, 0.4410376731539145, 0.40820333815645427, 0.21192565705860034, 0.07799451836035587, 0.07463762114639394, 0.11967904603807256, 0.07327754647121765, 0.16575810470385477, 0.18288648716406897, 0.17795732041122392, 0.09394454842549749, 0.11393978056730703, 0.1778031318099238, 0.10308736993465573, 0.16400970867834985, 0.13669916399521753, 0.3969514888012782, 0.20660468086134642, 0.3025141468970105, 0.1589720993069932, 0.48667827097233385, 0.24429368582786992, 0.10049418720882386, 1.0249751689843833, 9.486272670328617, 41.534568071365356, 16.96916364133358, 34.00323539972305, 103.41088101267815, 66.52841091156006, 24.171167984604836, 36.80110886693001, 59.43749740719795, 50.710429698228836, 16.147184148430824, 1.6151695931330323, 0.4935875174123794, 0.27460921613965183, 0.25652174139395356, 0.11774277532822452, 0.05725431466998998, 0.01222757317009382, 0.06864376191515476, 0.04120292578591034, 0.04996779745852109, 0.009503776163910516, 0.10148732180823572, 0.07996980377356522, 0.12063886562827975, 0.05380615184549242, 0.033807097643148154, 0.17053340940037742, 0.11126659432193264, 0.1755726514966227, 0.04074236006999854, 0.09417465873411857, 0.034876821882789955, 0.03756606449314859, 0.06495421926956624, 0.07410182020976208, 0.05624122000881471, 0.15701125608757138, 0.07992892627953552, 0.20229063578881323, 0.05997338048473466, 0.022807498717156705, 0.01980483044462744, 0.16841643315274268, 0.05876056275155861, 0.22875983733683825, 0.09442003502044827, 0.1084901308058761, 0.07654776083654724, 0.06621463835472241, 0.10738437529653311, 0.03674534193123691, 0.07660193019546568, 0.020833315393247176, 0.14407450886210427, 0.06990085617871955, 0.09371943277074024, 0.1331244019092992, 0.03166602757119108, 0.042894770158454776, 0.05790695191535633, 0.04294490223401226, 0.052191149443387985, 0.051942826830781996, 0.17544963309774175, 0.028393208267516457, 0.08429639114183374, 0.037587404949590564, 0.08927511851652525, 0.04221722643706016, 0.04952444585796911, 0.029698879807256162, 0.03877839611959644, 0.04862881833105348, 0.06017776424414478, 0.0807080180675257, 0.14395978767424822, 0.16752456460380927, 0.11493333819089457, 0.16753798263380304, 0.2955003170063719, 0.10705334774684161, 0.25955115852411836, 0.13903890328947455, 0.09158189161098562, 0.19762280891882256, 35.79091787338257, 98.32064375281334, 76.92375630140305, 65.6718760728836, 46.84851072728634, 80.44821158051491, 109.33967247605324, 31.82997051626444, 43.89036945998669, 94.83647391200066, 29.062953293323517, 1.14114134805277, 0.2269295378937386, 0.0718414165021386, 0.28997719462495297, 0.6785149849019945, 0.21437584277009591, 0.5592498939950019, 0.9993704804219306, 4.463924942538142, 3.7792088091373444, 0.5896597215905786, 0.8131957892328501, 0.40848663076758385, 1.1655830615200102, 1.1850599851459265, 0.38902742962818593, 0.1458420226117596, 0.14988401118898764, 0.1536487927660346, 0.09812384174438193, 0.08899490581825376, 0.07838780467864126, 0.11946829836233519, 0.08225293946452439, 0.09222440596204251, 0.12001173599855974, 0.07867840744438581, 0.2367675068671815, 0.07406885400996543, 0.05713859529350884, 0.02230585327197332, 0.04065706132678315, 0.32527174917049706, 1.0613959771580994, 1.0311208642087877, 1.0838987259194255, 0.805254690349102, 0.21402706304797903, 0.09497388498857617, 0.327845131396316, 0.3984992526238784, 1.3787808339111507, 4.566780673339963, 7.154370099306107, 7.918442124500871, 7.054762244224548, 3.7166344793513417, 3.134738691151142, 2.0743369543924928, 1.291427796240896, 0.9865451592486352, 0.6757027795538306, 0.8440864097792655, 0.024275913965539075, 0.18388902477454394, 0.12938598141772673, 0.5905809940304607, 0.2054863830562681, 0.14159952057525516, 0.05100499707623385, 0.0540498286136426, 0.12642614805372432, 0.16050582169555128, 0.15924893523333594, 0.12384771922370419, 0.09496814076555893, 0.13574523705756292, 0.3503462771186605, 0.12927327887155116, 0.16724750603316352, 0.3072387777501717, 0.34546914976090193, 1.7132906592451036, 0.31602580624166876, 0.12670019350480288, 0.3553122840821743, 0.30706107791047543, 0.14474291674559936, 2.021515751257539, 7.889150446280837, 65.45883670449257, 34.55838941037655, 18.166228607296944, 76.71292841434479, 87.90384471416473, 39.254150837659836, 25.959961898624897, 52.58725918829441, 75.0484125316143, 28.665635213255882, 2.196397567167878, 0.5045770027209073, 0.3603791637578979, 0.31892136961687356, 0.09974097411031835, 0.06517609173897654, 0.027417087403591722, 0.1275545242242515, 0.06605083151953295, 0.029358727551880293, 0.015511922665609745, 0.025527286270516925, 0.10069948009913787, 0.10276557470206171, 0.07312116853427142, 0.19017492653802037, 0.11275904587819241, 0.12138528807554394, 0.16253844543825835, 0.01015766300042742, 0.060020607052138075, 0.02097788204991957, 0.028367040140437894, 0.009758073992998106, 0.1170667159021832, 0.0585625280655222, 0.09080746051040478, 0.08217627560952678, 0.09604529390344396, 0.04404898048960604, 0.0772163765213918, 0.06828504483564757, 0.22189111215993762, 0.09982226896681823, 0.1530539317172952, 0.19814664643490687, 0.15212644007988274, 0.19117822113912553, 0.11987063888227567, 0.168419505644124, 0.1070326121407561, 0.2566642634337768, 0.18776489101583138, 0.19136009184876457, 0.21144545782590285, 0.18691628967644647, 0.28696867637336254, 0.27950762829277664, 0.15954479982610792, 0.15302773390430957, 0.17068826593458652, 0.1288305432535708, 0.1680439937626943, 0.2768966637086123, 0.22663293115328997, 0.20832527603488415, 0.12049678145558573, 0.21839935187017545, 0.1588391955010593, 0.1287892649997957, 0.11195038692676462, 0.22172329772729427, 0.0898064962530043, 0.16450317751150578, 0.1784414827125147, 0.2755331009393558, 0.2417356363730505, 0.20906822523102164, 0.3737068298505619, 0.45511205855291337, 0.29614901344757527, 0.4333750280784443, 0.24641774216433987, 0.3524589043809101, 0.24687717610504478, 39.59169052541256, 114.89220812916756, 97.01568737626076, 88.67375180125237, 40.16182713210583, 53.878103122115135, 134.9408519268036, 105.46524837613106, 37.340322732925415, 89.24468636512756, 69.91127818822861, 1.4038005913607776, 1.1858558049425483, 0.38933800358790904, 0.4667446296662092, 2.6195060508325696, 1.260313878301531, 2.2203412698581815, 8.291059155017138, 9.332983195781708, 13.918757624924183, 11.364865265786648, 1.2352256057783961, 0.47488916607107967, 4.576238840818405, 3.8817973667755723, 0.37631672574207187, 0.5231035617180169, 0.7546789292246103, 0.3170499997213483, 0.23725453385850415, 0.17933125840499997, 0.3293366701109335, 0.29083253466524184, 0.2475733996834606, 0.3232945193303749, 0.13248867820948362, 0.2742450591176748, 0.2773564984090626, 0.4553061746992171, 0.16013044340070337, 0.06534173910040408, 0.1659888681024313, 0.41698092652950436, 0.9672411263454705, 1.4574173768050969, 1.978466436266899, 1.1072517978027463, 0.35407455987297, 0.1274911151267588, 0.444353588973172, 0.8470148057676852, 3.0681859748438, 7.81926934607327, 9.843914229422808, 9.502677340060472, 8.01867077127099, 4.394758678972721, 3.735320451669395, 2.569628027267754, 2.6412546588107944, 2.1519632264971733, 1.2755493982695043, 1.4731772686354816, 0.12497352756327018, 0.4325576563132927, 1.210409018676728, 1.5489924629218876, 0.5505560198798776, 0.42028155410662293, 0.2312185725895688, 0.29206939798314124, 0.25924494839273393, 0.3742441744543612, 0.40186907805036753, 0.2867736993357539, 0.24615799047751352, 0.3842408146010712, 0.47532825032249093, 0.26985671021975577, 0.3313294850522652, 0.5741420667618513, 0.6624001089949161, 1.994536961428821, 0.4564350703731179, 1.2922654137946665, 0.6984762637875974, 0.29119642451405525, 0.1860093852155842, 1.822939831763506, 15.604229383170605, 62.05704644322395, 26.44146256148815, 49.47942495346069, 120.3554105758667, 88.83026540279388, 41.38141728937626, 55.91682292521, 77.2950191795826, 96.34610250592232, 44.99353386461735, 2.2440175618976355, 0.6667029624804854, 0.26092537853401154, 0.3341489040758461, 0.12647974595893174, 0.20369782199850306, 0.2862584113609046, 0.13690890977159142, 0.15291396266547963, 0.20741669432027265, 0.10228899715002626, 0.3270385356154293, 0.17702654848108068, 0.2146144284051843, 0.112351777497679, 0.2620774885872379, 0.26712729886639863, 0.3297676797956228, 0.4634411522420123, 0.19434141780948266, 0.10200580843957141, 0.15024730731965974, 0.12253032546141185, 0.086801755533088, 0.32028445741161704, 0.2424921520287171, 0.21566809999058023, 0.1641206003841944, 0.18705801019677892, 0.23596891143824905, 0.2369510251446627, 0.2543210657313466, 0.44451882073190063, 0.3107481269398704, 0.28456441476009786], [0.10117844736669213, 0.09778260966413654, 0.1663341003586538, 0.35001210286282003, 0.15012954332632944, 0.07303653401322663, 0.21927593217696995, 0.10909226490184665, 0.1046586969459895, 0.1782829302828759, 0.15405571233714, 0.09865872241789475, 0.06053320845239796, 0.12075172402546741, 0.09302775113610551, 0.19392431597225368, 0.2398327994160354, 0.1368515269132331, 0.24979488516692072, 0.18786647618981078, 0.07186211500084028, 0.13460244837915525, 0.0500034279684769, 0.058251560767530464, 0.13686203572433442, 0.11638727228273638, 0.07116434775525704, 0.13884631596738473, 0.05468547067721374, 0.1430456101661548, 0.039617754009668715, 0.13471791171468794, 0.14849540835712105, 0.05516337667359039, 0.15580376697471365, 0.2761660935357213, 0.21489816630491987, 0.3826099302386865, 0.19147050858009607, 0.032120715477503836, 0.08346416158019565, 23.940949738025665, 79.42406013607979, 57.112071588635445, 46.415075585246086, 31.111043393611908, 24.070821069180965, 97.94598385691643, 82.00552001595497, 22.109316922724247, 44.83541674911976, 67.55117923021317, 12.361584082245827, 0.3054778988007456, 0.4505014215828851, 0.18345952907111496, 0.38176423811819404, 1.0302401427179575, 0.27208701241761446, 0.9199882869143039, 1.6432598233222961, 1.79041120223701, 0.058398372420924716, 0.0535405742994044, 0.08473407273413613, 0.19309189345221967, 0.18237419746583328, 0.028818833670811728, 0.028776184299204033, 0.24694897147128358, 0.1112793073116336, 0.2274756843689829, 0.045013089693384245, 0.04383841464004945, 0.045231737531139515, 0.05515766955795698, 0.06741316974512301, 0.11131543506053276, 0.042198902810923755, 0.1251610682811588, 0.07666055244044401, 0.17246248869923875, 0.17416251153917983, 0.20920663577271625, 0.21551978919887915, 0.45529801107477397, 0.36245503986719996, 0.48846663907170296, 0.19932360359234735, 0.1916431321296841, 0.05251752372714691, 0.47977801936212927, 0.6667717744130641, 0.19237070402596146, 0.5641402909532189, 0.8317519153933972, 0.5672723916359246, 0.8080223668366671, 1.325979104731232, 0.6893900607246906, 0.11263368971413001, 0.14300082897534594, 0.2072096202755347, 0.182607306051068, 0.18045164906652644, 0.2167831323458813, 0.7210788165684789, 0.4513084329664707, 0.13136583846062422, 0.1892504925490357, 0.06207659731444437, 0.205420317070093, 0.15635688963811845, 0.04528933932306245, 0.10431179485749453, 0.30022658058442175, 0.15373966132756323, 0.2850988204590976, 0.1799296966055408, 0.2744072035420686, 0.16135062323883176, 0.6107412278652191, 0.26546616456471384, 1.14405638538301, 0.11643864374491386, 0.13870504073565826, 0.270985338720493, 0.8667445345781744, 0.40713485330343246, 23.21543376892805, 44.38286103308201, 21.254847273230553, 55.394350960850716, 108.34518224000931, 53.494612500071526, 16.058253720402718, 31.03099688887596, 53.87547746300697, 33.534902930259705, 14.278310481458902, 2.5770357297733426, 0.8161952532827854, 0.4794765589758754, 0.24606627586763352, 0.2442639257060364, 0.05987629643641412, 0.16103488393127918, 0.08022380381589755, 0.05237919482169673, 0.04129974637180567, 0.06303681395365857, 0.16233103000558913, 0.07565471969428472, 0.08171546127414331, 0.09774552454473451, 0.1818056232878007, 0.14902779541444033, 0.06281192836468108, 0.2182906272355467, 0.08438551565632224, 0.11728179772035219, 0.15068049891851842, 0.12706960493233055, 0.05939237162237987, 0.1115236000623554, 0.1207449111097958, 0.12467579275835305, 0.13609600573545322, 0.1250733167398721, 0.10107699577929452, 0.13925517996540293, 0.1078447666077409, 0.17434414476156235, 0.07341547461692244, 0.22230754606425762, 0.19357771816430613, 0.043863792379852384, 0.16155009769136086, 0.09557011158904061, 0.23328561714151874, 0.0459971292730188, 0.05795666096673813, 0.1003624931036029, 0.1964389201020822, 0.09814272198127583, 0.19212281185900792, 0.14599147631088272, 0.143303714285139, 0.0753627810627222, 0.06439428369048983, 0.15393967012641951, 0.18141161708626896, 0.23525918077211827, 0.035882821612176485, 0.14739383856067434, 0.09493677760474384, 0.07486508198780939, 0.09445290474104695, 0.019025849978788756, 0.11768652795581147, 0.0297932865578332, 0.12110676005249843, 0.0601281850686064, 0.23040556465275586, 0.06789117964217439, 0.04717239433375653, 0.060246746870689094, 0.11901853460585698, 0.09509353403700516, 0.12311331956880167, 0.09059288335265592, 0.15566914138616994, 0.2967715566046536, 0.1669164636405185, 0.22323138633510098, 0.028155960353615228, 0.14045238291146234, 43.7864526361227, 101.6254860162735, 61.311230063438416, 30.94198476523161, 32.800455540418625, 68.39930132031441, 116.34584292769432, 41.81949958205223, 35.88240556418896, 85.6175909936428, 53.4225607663393, 5.446162736043334, 0.39510965638328344, 0.44268052093684673, 0.15518146130489185, 0.801699209259823, 1.2984825926832855, 0.9134623745921999, 0.47096985450480133, 0.09248053596820682, 0.9513403452001512, 0.30909767956472933, 0.18286526174051687, 0.10046335839433596, 0.14924232062185183, 0.055893902317620814, 0.03915564462658949, 0.013262870106700575, 0.03965664996940177, 0.1419495025766082, 0.2683746116235852, 0.29903748189099133, 0.12838060880312696, 0.051413679248071276, 0.025288246069976594, 0.04781599964189809, 0.053915392272756435, 0.021186872691032477, 0.005712428019251092, 0.09665884223068133, 0.24674664717167616, 0.19544398208381608, 0.18054081068839878, 0.14553567889379337, 0.25465500249993056, 0.3413162101060152, 0.1164667414559517, 0.16049442230723798, 0.0841591160860844, 0.06146832565718796, 0.31172788061667234, 1.3868442387320101, 0.1313913386547938, 0.672370120882988, 0.29432873299811035, 0.8781706402078271, 1.5983215346932411, 1.5429112454876304, 0.9755570394918323, 0.2419861705857329, 0.3035546082537621, 0.36397293966729194, 0.2346906065940857, 0.2931313816225156, 0.7897109119221568, 0.5960334045812488, 2.4419180676341057, 0.9582955751102418, 0.2564754313789308, 0.22304691810859367, 0.19041640654904768, 0.14278297894634306, 0.12716676690615714, 0.1600474861334078, 0.35890516941435635, 0.19517346925567836, 0.2450602056342177, 0.032407010075985454, 0.30402207223232836, 0.2225324316532351, 0.23605301161296666, 0.6754845881368965, 1.529108367394656, 0.16100592532893643, 0.5392551887780428, 0.28437335626222193, 0.7751693890895694, 0.5940912931691855, 22.981368228793144, 73.24588805437088, 28.910250887274742, 26.10630914568901, 87.67920836806297, 77.93436527252197, 35.89203044772148, 30.69917969405651, 56.00183196365833, 64.69536647200584, 24.518292658030987, 3.2013681158423424, 0.7755034149158746, 0.5255826318170875, 0.2728320693131536, 0.16677674691891298, 0.11456639811513014, 0.27011782745830715, 0.08271559432614595, 0.06504347737063654, 0.03101136982877506, 0.09426354576135054, 0.15421140007674694, 0.06360751067404635, 0.05547163884330075, 0.2051717569702305, 0.08899250125978142, 0.1585908283595927, 0.13739440793870017, 0.07102854957338423, 0.0765369700093288, 0.05121792295540217, 0.12989439710509032, 0.10871283448068425, 0.09483295856625773, 0.09613172442186624, 0.053051625145599246, 0.09361124248243868, 0.12148781577707268, 0.09322443511337042, 0.17456245492212474, 0.03328542719827965, 0.1514415565179661, 0.15272005432052538, 0.056861792763811536, 0.2226491566398181, 0.1382325598387979, 0.16304018179653212, 0.25778956711292267, 0.36672203277703375, 0.48671914846636355, 0.2976450347341597, 0.1013106683967635, 0.29081929475069046, 0.3781232319306582, 0.291509076487273, 0.2517619030550122, 0.15173028165008873, 0.2475393796339631, 0.1729751197854057, 0.346728841541335, 0.29094679572153836, 0.35451224888674915, 0.3034672426292673, 0.3187225927831605, 0.244392643799074, 0.332800867035985, 0.1795587711967528, 0.28057652874849737, 0.17891237541334704, 0.2360652867355384, 0.23148491454776376, 0.26962041039951146, 0.3105723566841334, 0.2220320311607793, 0.22014586284058169, 0.26569560694042593, 0.20305148558691144, 0.15707001934060827, 0.1882363180629909, 0.17846251517767087, 0.15379618329461664, 0.31832726555876434, 0.42532833642326295, 0.43686380493454635, 0.2898058178834617, 0.3164061123970896, 0.11095311856479384, 47.07793861627579, 121.80554196238518, 83.94149333238602, 66.61152005195618, 45.523932203650475, 43.303198367357254, 132.07825273275375, 102.17011839151382, 34.05286453664303, 66.05191648006439, 92.59476140141487, 19.108391851186752, 0.5833434511441737, 1.0174528788775206, 0.2006384072592482, 1.5042510512284935, 2.3615720914676785, 1.8919481663033366, 3.812574581243098, 2.5517143635079265, 4.4314955826848745, 0.5756283807568252, 0.20660270674852654, 0.32680713396985084, 0.5591239663772285, 0.2757281076628715, 0.12195330564281903, 0.11872206887346692, 0.4896800505230203, 0.3471202205400914, 0.3735693544149399, 0.41342568292748183, 0.37415784783661366, 0.25261424481868744, 0.26266485394444317, 0.16835174756124616, 0.208113378030248, 0.09217876387992874, 0.15253997960826382, 0.1301849033916369, 0.2999911713413894, 0.266077812993899, 0.34583615662995726, 0.3174119896721095, 0.4994918068405241, 0.5229911708738655, 0.5568917642813176, 0.1702012389432639, 0.5496567743830383, 0.13876555545721203, 0.5315364967100322, 1.4619575394317508, 0.41537791723385453, 0.8083616173826158, 1.2975547299720347, 2.803041902370751, 2.8922782139852643, 2.3423876333981752, 1.662649114150554, 0.8527550508733839, 0.5912212596740574, 0.5361729604192078, 0.27216461137868464, 0.630615942645818, 0.9800546325277537, 1.2994282669387758, 3.1736695021390915, 0.7736658572684973, 0.5890261649619788, 0.3376946481876075, 0.3034153813496232, 0.27952671633102, 0.15912161237793043, 0.23436852934537455, 0.6401797325816005, 0.3869779146043584, 0.29045801726169884, 0.30989738821517676, 0.5672911531291902, 0.3119916399009526, 0.5196165363304317, 0.4793551139300689, 2.059934064745903, 0.3169883124064654, 0.4578322672750801, 0.2491452090907842, 1.6237260214984417, 0.2707437251228839, 37.63638384640217, 71.62817806005478, 32.03858122229576, 76.97909653186798, 126.65225028991699, 74.079160541296, 34.309586361050606, 50.96091605722904, 77.8480415046215, 87.90420189499855, 37.2586765140295, 2.8997122775763273, 1.2606552662327886, 0.6136361381504685, 0.39332369284238666, 0.2745500818127766, 0.28428462508600205, 0.30285583168733865, 0.15748482052003965, 0.2095565287163481, 0.18489148817025125, 0.19688685075379908, 0.3375657816650346, 0.2154047117801383, 0.12698004255071282, 0.33236872928682715, 0.2923862653551623, 0.29609492572490126, 0.2720438491087407, 0.28164623072370887, 0.14601388917071745, 0.2936370513634756, 0.30807265487965196, 0.2650364313740283, 0.177376426581759, 0.17423000244889408, 0.1978497873642482, 0.21358205645810813, 0.23779340728651732, 0.25278001092374325, 0.2251345053082332, 0.2861311478773132, 0.2065289521124214, 0.26866125874221325, 0.1363708230201155, 0.34458946727681905, 0.24912451801355928], [0.07021091063506901, 0.19893277378287166, 0.16078684333479032, 0.24273530929349363, 0.09058094961801544, 0.2597764745587483, 0.18643658026121557, 0.14942984649678692, 0.09874064067844301, 0.2218436443945393, 0.10424789594253525, 0.17696236755000427, 0.2572267223149538, 0.1463017682544887, 0.24450907192658633, 0.05696766384062357, 0.12530195759609342, 0.017318888058071025, 0.20581062737619504, 0.09438696491997689, 0.1690924257854931, 0.1318025478394702, 0.10085193207487464, 0.1305473831598647, 0.16403323475969955, 0.07642226366442628, 0.3130318340845406, 0.15219216467812657, 0.2776218013605103, 0.18332491832552478, 0.21280017419485375, 0.15044226951431483, 0.13287836511153728, 0.09054101465153508, 0.18574290967080742, 0.28352787194307894, 0.3373689344152808, 0.25523277930915356, 0.4176244279369712, 0.04406735606607981, 0.4921800788724795, 0.21057626930996776, 21.575073190033436, 79.78665947914124, 74.92650747299194, 73.10835063457489, 41.346204578876495, 33.371640890836716, 109.45724576711655, 90.61500683426857, 35.85548780858517, 32.142490446567535, 61.51282824575901, 39.07247118651867, 2.7133892755955458, 0.9791404253337532, 0.2764217782532796, 0.389666537521407, 0.2520868449937552, 2.671226500533521, 0.3425305418204516, 0.27815196197479963, 0.8939929911866784, 0.2643590286606923, 0.12408475377014838, 0.13058382261078805, 0.3070939105236903, 0.16393806174164638, 0.311500575626269, 0.1736596619593911, 0.14119764760835096, 0.09623730977182277, 0.20192070485791191, 0.150678509962745, 0.21236597327515483, 0.0630504397850018, 0.21427969011710957, 0.11125831195386127, 0.165560812165495, 0.16802193713374436, 0.2803837484680116, 0.18063939758576453, 0.18132977304048836, 0.16483536281157285, 0.3026736492756754, 0.13125402649166062, 0.19119255943223834, 0.15247121220454574, 0.2615458733635023, 0.08702865976374596, 0.10048389362054877, 0.8156732562929392, 0.31578229274600744, 0.19850664742989466, 0.1211584654811304, 0.47041989339049906, 0.3011689003324136, 0.09766354691237211, 0.14986590278567746, 0.05327211722033098, 0.22075757064158097, 0.16457866877317429, 0.07941249539726414, 0.16358714463422075, 0.11512252647662535, 0.1811606078990735, 0.41367911151610315, 0.7518765795975924, 4.576724739745259, 0.04283546513761394, 0.33793112612329423, 0.23332855780608952, 0.13225411501480266, 0.21275920764310285, 0.20464391185669228, 0.07876228497480042, 0.029247563106764574, 0.09946823483915068, 0.23326186841586605, 0.46975246514193714, 0.24048554798355326, 0.3214056644355878, 0.36427585466299206, 0.3291435039136559, 0.7159046817105263, 0.13586117536760867, 1.1267814435996115, 8.278141748160124, 57.790677174925804, 50.419122129678726, 28.36344502866268, 83.98140639066696, 95.13800293207169, 45.094357654452324, 19.08349558711052, 29.95226327329874, 43.463865146040916, 22.307909466326237, 4.118676418438554, 1.0033323615789413, 1.113607669249177, 0.41556125739589334, 0.36770422069821507, 0.43706029595341533, 0.2535042283125222, 0.22756704274797812, 0.22847535728942603, 0.22380411654012278, 0.1329100548173301, 0.05391568171035033, 0.1684290645061992, 0.14881227572914213, 0.14008142781676725, 0.1231929891218897, 0.16008215927286074, 0.0763335992814973, 0.15357716067228466, 0.17421290336642414, 0.14781868841964751, 0.19309906259877607, 0.2047068311367184, 0.15893545205472037, 0.2175917022395879, 0.09622145749744959, 0.09681145005743019, 0.11423254298279062, 0.22397451364668086, 0.12971478252438828, 0.22461822285549715, 0.16358750086510554, 0.10821977382875048, 0.3645203774794936, 0.0671768476604484, 0.11921409794013016, 0.1515219162683934, 0.16355704312445596, 0.09582639744621702, 0.130573209899012, 0.2664306596852839, 0.2016613242449239, 0.27421252336353064, 0.14314296509837732, 0.2690038044238463, 0.15821475244592875, 0.07821132196113467, 0.14335038053104654, 0.2603617322165519, 0.39109671546611935, 0.17483430361608043, 0.18337930290726945, 0.1843035884667188, 0.14066451840335503, 0.14446297864196822, 0.14979257859522477, 0.16097669955343008, 0.1928044596570544, 0.25682189560029656, 0.10961764608509839, 0.12270937600987963, 0.2520799281774089, 0.13076928531518206, 0.10050361248431727, 0.22993670543655753, 0.11691909530782141, 0.3719073592219502, 0.11066051200032234, 0.19073803850915283, 0.1771520753391087, 0.13633462105644867, 0.3401782305445522, 0.1492460462031886, 0.2851194521645084, 0.40457197988871485, 0.31649062817450613, 0.3091615636367351, 0.04043443186674267, 0.42135802446864545, 0.3793187427800149, 38.62774305045605, 101.36371806263924, 74.20228913426399, 43.11673477292061, 27.56727945059538, 68.15497443079948, 115.37929639220238, 45.96832595765591, 30.88659703731537, 63.889042139053345, 80.8325457572937, 21.341260336339474, 2.934583956375718, 0.47334888309706, 0.24663490941748023, 0.20042177435243502, 0.41277378040831536, 1.8627163348719478, 1.2220216705463827, 0.23193661530967802, 1.1062648007646203, 0.2590165153378621, 0.1281096803722903, 0.3333156503504142, 0.5310340330470353, 0.21698554570320994, 0.05080994582385756, 0.24777146405540407, 0.2000110104563646, 0.1318739721318707, 0.1313627659692429, 0.15479981928365305, 0.2558820991544053, 0.2284916993812658, 0.1628204170265235, 0.0907569722039625, 0.12740986479911953, 0.18498220830224454, 0.30530120828188956, 0.11369784784619696, 0.1697653904557228, 0.24741490662563592, 0.4104450100567192, 0.24080603703623638, 0.14899432455422357, 0.2681091899285093, 0.14432020427193493, 0.1135392657306511, 0.11922963851247914, 2.0925702759996057, 0.3210097731789574, 0.057876052596839145, 0.061844115843996406, 0.1396546038449742, 0.5155105597805232, 0.36265847738832235, 0.4053103574551642, 0.03399417822947726, 0.12244363519130275, 0.14393942314200103, 0.056451615164405666, 0.17427080572815612, 0.2212717750808224, 0.11086538186646067, 0.0833047111518681, 1.151665833313018, 6.554778898134828, 0.49537802289705724, 0.3004211717052385, 0.1594785854103975, 0.19864197063725442, 0.3513526887400076, 0.27592599391937256, 0.06299589935224503, 0.0924071301415097, 0.2763774571940303, 0.38164175406564027, 0.2735219104215503, 0.3722441755235195, 0.7827454700600356, 0.9621546836569905, 0.5957069783471525, 1.2417386937886477, 0.15750058373669162, 0.9828414861112833, 10.894578751176596, 61.727391332387924, 71.28789111971855, 32.79949799180031, 54.580883011221886, 95.72263956069946, 71.20297327637672, 33.32947455346584, 27.146894708275795, 50.811428278684616, 52.57055528461933, 15.415158178657293, 0.785605232231319, 1.3543112156912684, 0.45212901080958545, 0.32024637039285153, 0.2739330008625984, 0.20374704123241827, 0.1899045769823715, 0.21916809811955318, 0.11664452293189242, 0.09752433485118672, 0.11508507770486176, 0.12195999239338562, 0.14520897064357996, 0.1797704614000395, 0.11291907518170774, 0.16358089575078338, 0.10936132312053815, 0.10814305060193874, 0.1760584910516627, 0.1698374084662646, 0.2248336237971671, 0.22791988943936303, 0.12437970552127808, 0.22973770595854148, 0.16836442344356328, 0.10411212002509274, 0.2255636447807774, 0.1641577819827944, 0.10819324204931036, 0.1787348833750002, 0.21485341480001807, 0.1889057649532333, 0.18627974961418658, 0.0998467746831011, 0.1859990693628788, 0.2067479895777069, 0.19969544926425442, 0.28584833024069667, 0.3316572471521795, 0.3643346921307966, 0.2772717154584825, 0.2871863334439695, 0.3690890979487449, 0.3987967944703996, 0.19998695002868772, 0.40435957722365856, 0.34240814682561904, 0.35717655904591084, 0.3905260929604992, 0.3553713293513283, 0.18883968412410468, 0.33704684232361615, 0.24887653678888455, 0.3400029055774212, 0.23478067363612354, 0.250362865626812, 0.2332570296130143, 0.30443381576333195, 0.2707177499542013, 0.3212200978305191, 0.360967805609107, 0.3171247785212472, 0.2728888881392777, 0.4742302279919386, 0.31373004661872983, 0.41704789793584496, 0.2681138803018257, 0.26380259601864964, 0.26070792926475406, 0.1918254332849756, 0.508622182533145, 0.18271804932737723, 0.3471712803002447, 0.6151199585292488, 0.23759191419230774, 0.24890988890547305, 0.276306121959351, 0.6121516646817327, 0.23503261792939156, 35.45639522373676, 117.62974843382835, 101.98740139603615, 93.22156816720963, 59.66736227273941, 58.63921344280243, 135.6580102443695, 114.73434180021286, 51.18034668266773, 47.93503202497959, 96.59705623984337, 59.1225741058588, 6.484068967401981, 1.6407242906279862, 0.6041249516420066, 0.5755434196908027, 0.660100698005408, 9.136674329638481, 3.650518264621496, 0.6318775343243033, 2.0273997355252504, 0.5560274887830019, 0.2988265932071954, 0.2557925070868805, 0.8035134337842464, 0.6549653923138976, 0.4211721906904131, 0.4901090415660292, 0.34073873015586287, 0.1634562891558744, 0.1988889425410889, 0.25708797038532794, 0.3410686890129, 0.4435366624966264, 0.4615004063816741, 0.3134279034566134, 0.29289148980751634, 0.38390477013308555, 0.4343874956248328, 0.2800001174909994, 0.6311575917061418, 0.3518699953565374, 0.49389265885110945, 0.4444011754821986, 0.2267294845660217, 0.44424241525121033, 0.43430482037365437, 0.22759564511943609, 0.21489310485776514, 3.1239453703165054, 0.5521486687939614, 0.24908503575716168, 0.14851078565698117, 0.5834909901022911, 0.8093677915167063, 0.4630771733354777, 0.4394826659699902, 0.23695544834481552, 0.24385004478972405, 0.28946903126779944, 0.3921613114653155, 0.31181117927189916, 0.43791284551844, 0.3026169788790867, 1.3696471927687526, 1.5982467262074351, 13.539901804178953, 0.5374917865265161, 0.6413950736168772, 0.3143345407443121, 0.27493926405441016, 0.7435666036326438, 0.35333532141521573, 0.1355869518010877, 0.3498849581228569, 0.5041075497865677, 0.4551801283378154, 0.5931909789796919, 0.4357590735889971, 1.7893004743382335, 1.5124036325141788, 0.7949329598341137, 1.0561712575145066, 0.16993136436212808, 1.512650738004595, 12.866831570863724, 81.65339291095734, 71.16840273141861, 43.94676983356476, 109.84259828925133, 113.23687255382538, 68.0959939956665, 37.88873590528965, 49.05916750431061, 69.14217665791512, 74.15855348110199, 19.190370552241802, 0.8048145670909435, 1.906034010462463, 0.31522277276962996, 0.46390897245146334, 0.3658178594196215, 0.2548946568276733, 0.3587419562973082, 0.3459634497994557, 0.23824212461477146, 0.18592976761283353, 0.19737791502848268, 0.20211295079207048, 0.2597851131577045, 0.2514946408336982, 0.19949992303736508, 0.323991781915538, 0.15418233757372946, 0.18454426695825532, 0.21951763483230025, 0.35140793421305716, 0.3384150064084679, 0.3889329987578094, 0.329033131711185, 0.3492886573076248, 0.24922883429098874, 0.1997673188452609, 0.4273594164988026, 0.36051865783520043, 0.2637204551137984, 0.36507491022348404, 0.3259944525780156, 0.21604772337013856, 0.38115802221000195, 0.2489078405778855, 0.29535773559473455, 0.32850181334652007, 0.2279912692029029], [0.1904338618624024, 0.23619419778697193, 0.18754233577055857, 0.26469798234757036, 0.2552033605752513, 0.19432234461419284, 0.23166938277427107, 0.22616515547269955, 0.21271558420266956, 0.27566716249566525, 0.16999119630781934, 0.1939631302957423, 0.23371540970401838, 0.2375538123305887, 0.28757331892848015, 0.21746129204984754, 0.20294917310820892, 0.12083207635441795, 0.3227765893097967, 0.2885450574103743, 0.3232464875327423, 0.29597944754641503, 0.2785229170694947, 0.24007519969018176, 0.19988812564406544, 0.22498880687635392, 0.20077012362889946, 0.2952204382745549, 0.2609554206719622, 0.3915964480256662, 0.21718733565649018, 0.37876952381338924, 0.18123721238225698, 0.3118167899083346, 0.38808748475275934, 0.2554309624247253, 0.45977930654771626, 0.38672448601573706, 0.46738483593799174, 0.530943312915042, 0.36151025618892163, 0.34011983836535364, 0.5874013958964497, 7.805776270106435, 57.10598051548004, 68.89044016599655, 71.3359509408474, 42.206596210598946, 28.82586881518364, 81.30689710378647, 116.96067273616791, 66.25034183263779, 30.620472617447376, 35.57609260082245, 62.50938177108765, 28.265495784580708, 1.3601662265136838, 0.38149608531966805, 0.1855568977771327, 0.13113091903505847, 0.8751188695896417, 0.2652736514573917, 0.1730386179406196, 0.09892384725390002, 0.2599393908167258, 0.04991031441022642, 0.105906870594481, 0.13829041767166927, 0.14833249209914356, 0.1085957903706003, 0.16812632762594149, 0.2634750120341778, 0.1921522751217708, 0.19820509798591956, 0.11620840727118775, 0.1741100416984409, 0.07666245233849622, 0.20841630786890164, 0.024874053451640066, 0.24124589312123135, 0.1949908712413162, 0.24401404458330944, 0.2862203837139532, 0.14756865886738524, 0.177715795871336, 0.25769902509637177, 0.22378229739842936, 0.1849084536661394, 0.2464240207336843, 0.16378094907850027, 0.3048730187583715, 1.0269604437053204, 0.3395616542547941, 0.10480478871613741, 0.2031661622459069, 0.21507825586013496, 0.16124480782309547, 0.19875572703313082, 0.214848650211934, 0.2003643914940767, 0.2529023465467617, 0.15223847469314933, 0.12611894344445318, 0.20391504862345755, 0.5333570146467537, 0.23678824247326702, 0.42443327663931996, 0.13543562788981944, 1.4665381936356425, 1.3306542788632214, 0.26568325760308653, 0.28013156668748707, 0.2840190549613908, 0.10673719283659011, 0.2198864525416866, 0.4222645133268088, 0.28844774700701237, 0.30203712405636907, 0.27121240622363985, 0.21714721515309066, 0.3546197712421417, 0.5322121479548514, 0.5759038066025823, 0.349944478366524, 0.22372371226083487, 1.5930266375653446, 31.351464092731476, 48.3795777708292, 37.688304260373116, 41.55045121908188, 88.89654144644737, 76.15531593561172, 28.600508607923985, 21.636443696916103, 26.837046034634113, 38.10240224003792, 26.394586376845837, 4.2892782390117645, 0.7063068123534322, 1.2532422202639282, 0.49376299080904573, 0.419536140980199, 0.22555286879651248, 0.41806490742601454, 0.08404663618421182, 0.2952631562948227, 0.09962814539903775, 0.1611182716442272, 0.2605840499745682, 0.1981905518914573, 0.2161989879095927, 0.16874970198841766, 0.2638392284279689, 0.2575673977844417, 0.1177464341162704, 0.20698093489045277, 0.11331607223837636, 0.16086812334833667, 0.2016929694218561, 0.25151355075649917, 0.23979416320798919, 0.1870072918245569, 0.2665493142558262, 0.1541940338211134, 0.03844429607852362, 0.18423789355438203, 0.17043949803337455, 0.2146556176012382, 0.20437187020434067, 0.2512514538830146, 0.21306938084308058, 0.23368204274447635, 0.19112134294118732, 0.2500864601461217, 0.17464578326325864, 0.13813667435897514, 0.24225652014138177, 0.24426115007372573, 0.2132037392584607, 0.24202214990509674, 0.3780859167454764, 0.3024499659659341, 0.18038265901850536, 0.16003089171135798, 0.16674036683980376, 0.18655383959412575, 0.2938790211919695, 0.2786126278806478, 0.32215639133937657, 0.3167342900997028, 0.37987689720466733, 0.2435062374570407, 0.31591745268087834, 0.29081041866447777, 0.3152216743910685, 0.30074180918745697, 0.20902488380670547, 0.3691028425237164, 0.20600797928636894, 0.321677052997984, 0.24349004379473627, 0.1682618586346507, 0.282730181934312, 0.32119133218657225, 0.29526692640502006, 0.405103862285614, 0.39096164458896965, 0.32420091913081706, 0.2032835700083524, 0.2078670443734154, 0.40300693886820227, 0.4011360736330971, 0.394920616527088, 0.33822890545707196, 0.4714024969143793, 0.5976829316932708, 0.32210509409196675, 0.4949098761426285, 0.5086942599155009, 20.427076891064644, 85.08715465664864, 79.49656024575233, 53.7195148319006, 40.86673490703106, 69.23748314380646, 100.69535672664642, 81.99304908514023, 42.85445764660835, 49.42876987159252, 74.29340824484825, 61.40192739665508, 12.811212055385113, 1.635420131497085, 1.3995631062425673, 0.5073509726207703, 0.33649507036898285, 0.7042149652261287, 0.48496382078155875, 0.07976382068591192, 0.09280710321036167, 0.26147661614231765, 0.05477153383253608, 0.08823068666970357, 0.08909729251172394, 0.494052903377451, 0.232321047806181, 0.19562157802283764, 0.3556714835576713, 0.2517347998218611, 0.37652417086064816, 0.0741492211818695, 0.1897279458353296, 0.13404490251559764, 0.29186604951974005, 0.10183958962443285, 0.32342041726224124, 0.1316610796493478, 0.24892004148568958, 0.17941745143616572, 0.19331398856593296, 0.04784953358466737, 0.16177287558093667, 0.3735268145101145, 0.24722022644709796, 0.2637723460793495, 0.1874906526063569, 0.7364445389248431, 2.028683591634035, 0.3154946956783533, 0.06938686696230434, 0.2938059938605875, 0.5324902455322444, 0.5544004635885358, 0.27421522478107363, 0.25950045499484986, 0.3586744802305475, 0.3045913588721305, 0.14316374523332343, 0.26420926325954497, 0.3119689004961401, 0.3143176791490987, 0.39141886692959815, 0.5376536934636533, 0.20617233531083912, 1.3643177412450314, 5.551866414025426, 0.3285268088802695, 0.4555856081424281, 0.2880942769115791, 0.24041952652623877, 0.3363844903651625, 0.4373750853119418, 0.45627161976881325, 0.2500332333147526, 0.11807933929958381, 0.3359677892876789, 0.9693574346601963, 0.30185238865669817, 0.6837475416250527, 0.9185766626615077, 0.15529216005234048, 2.609018376097083, 35.715830102562904, 75.08789241313934, 64.04329866170883, 43.142713978886604, 74.10431519150734, 96.2379603087902, 54.599122032523155, 33.608219996094704, 29.458696357905865, 48.87672409415245, 53.72694343328476, 12.844120189547539, 0.8446902805007994, 1.4351694518700242, 0.9227810776792467, 0.5087922827806324, 0.3846122743561864, 0.36610275506973267, 0.3977911843685433, 0.274997329688631, 0.18656903877854347, 0.13170566788176075, 0.22907293459866196, 0.14451433526119217, 0.203759093710687, 0.18485746812075377, 0.22199195518624038, 0.3562338830670342, 0.24372849584324285, 0.2328457758994773, 0.16280817158985883, 0.238569114881102, 0.2585163968615234, 0.2431089658057317, 0.2784813567996025, 0.29634986829478294, 0.24337940441910177, 0.1963602821342647, 0.16280918091069907, 0.28631600202061236, 0.2536380523815751, 0.20223268889822066, 0.2435207093367353, 0.17546809773193672, 0.3108329395763576, 0.22120328969322145, 0.27759419346693903, 0.35496522614266723, 0.33132310258224607, 0.2570511895464733, 0.2710197150008753, 0.3097827115561813, 0.31383908295538276, 0.39502701081801206, 0.5654051480814815, 0.5239045468624681, 0.489870099700056, 0.25374961202032864, 0.308459818479605, 0.2697796456050128, 0.37421576504129916, 0.39956414548214525, 0.6147661025170237, 0.4691164445830509, 0.4600034945178777, 0.4098289384273812, 0.3485341602936387, 0.4414379282388836, 0.43919020041357726, 0.5977508530486375, 0.5434733186848462, 0.358850933262147, 0.3202018712181598, 0.5148257059045136, 0.5125069397035986, 0.41794114687945694, 0.5127261998131871, 0.5271472572349012, 0.3645405045244843, 0.6051522621419281, 0.49455607950221747, 0.39841963502112776, 0.24210230185417458, 0.42664285807404667, 0.5188381124753505, 0.4240042855963111, 0.5145682697184384, 0.6246743083465844, 0.48622749047353864, 0.7021669938694686, 0.31486104999203235, 0.6687476090155542, 0.40135990537237376, 14.93980273604393, 92.86303460597992, 105.66355213522911, 92.34969735145569, 63.350519835948944, 53.94147612154484, 104.47233125567436, 146.6940012574196, 90.01773968338966, 47.669589668512344, 57.91874170303345, 90.91284245252609, 43.357470855116844, 2.116496404632926, 1.9937435165047646, 1.2006292934529483, 0.4933566797990352, 1.95683847181499, 2.031630096025765, 0.33700744912493974, 0.341358037549071, 0.6751728861127049, 0.2581172698410228, 0.33081214874982834, 0.2692633186234161, 0.384456156170927, 0.3801993455272168, 0.2530700422357768, 0.6874810194130987, 0.3862615046091378, 0.5114406812936068, 0.2633505983976647, 0.2805606467882171, 0.19940124708227813, 0.3125172882573679, 0.17992154782405123, 0.34641238977201283, 0.16544373094802722, 0.4157452209619805, 0.33303574193269014, 0.2708764508133754, 0.2792755438713357, 0.34948597953189164, 0.379981747828424, 0.31719014688860625, 0.3064167156117037, 0.3221194026991725, 0.6610844889655709, 3.58180845156312, 1.1612359760329127, 0.2361440286040306, 0.6299920636229217, 0.6905687099788338, 0.8679160592146218, 0.25421743222977966, 0.470080049126409, 0.45106557256076485, 0.42461453878786415, 0.24452311336062849, 0.45390903716906905, 0.2807591564487666, 0.5813906528055668, 0.2887356706196442, 1.180688082240522, 0.527016461128369, 3.0807110527530313, 10.615730714052916, 0.3257170377764851, 0.7068195473402739, 0.5013941985089332, 0.2989211428212002, 0.3496882296167314, 0.8138308895286173, 0.5082371563185006, 0.40760896692518145, 0.31294883228838444, 0.36958514945581555, 1.0260410117916763, 0.4356736672343686, 0.37995488208252937, 0.6884421303402632, 0.5427714250981808, 1.7986092623323202, 48.15526820719242, 73.57625752687454, 54.61581073701382, 60.89015945792198, 111.45476818084717, 96.0325813293457, 47.750445529818535, 42.28058964014053, 49.0983472019434, 69.42753374576569, 73.77767711877823, 15.999125093221664, 0.7312304468359798, 2.216815771535039, 0.8636345202103257, 0.8323262783233076, 0.37056309229228646, 0.5066773400176316, 0.4377452685730532, 0.4811733163660392, 0.17265742120798677, 0.26565149368252605, 0.3887327673146501, 0.33710458141285926, 0.3477146214572713, 0.3631606441922486, 0.34751513216178864, 0.6666562962345779, 0.34483369323424995, 0.4347450623754412, 0.3246026881970465, 0.30954038549680263, 0.30682415468618274, 0.5012802639976144, 0.503806178458035, 0.4290395794669166, 0.3248095099115744, 0.26358297967817634, 0.3583397122565657, 0.40371085109654814, 0.521809256169945, 0.5153367191087455, 0.45193516183644533, 0.2825700561515987, 0.49595324671827257, 0.286281596054323, 0.42085392808075994, 0.5621085874736309, 0.3512714384123683, 0.22720704175299034], [0.18885494268033653, 0.1647298294119537, 0.37588256935123354, 0.35941832000389695, 0.2877098444150761, 0.3352795512182638, 0.28116920788306743, 0.25703420920763165, 0.3279440151527524, 0.24507261434337124, 0.2997296385001391, 0.23221854236908257, 0.3292561322450638, 0.3973653103457764, 0.10499432581127621, 0.2921623445581645, 0.10996244789566845, 0.23138093965826556, 0.33713910612277687, 0.18698878266150132, 0.3920867701526731, 0.19478348549455404, 0.34239615371916443, 0.19231128768296912, 0.1762626855634153, 0.2985359088052064, 0.22896238428074867, 0.30643372563645244, 0.22128020587842911, 0.34389725129585713, 0.4671067977324128, 0.26601956924423575, 0.2807473414577544, 0.25235523527953774, 0.06714414863381535, 0.4380721994675696, 0.5130433046724647, 0.5627154861576855, 0.6022833567112684, 0.4585477866930887, 0.7420386106241494, 0.6404941063374281, 0.8542198722716421, 0.7145170436706394, 4.118092674762011, 30.827259421348572, 58.20997327566147, 67.45674669742584, 48.382583409547806, 19.265665411949158, 50.07082521915436, 108.8157793879509, 102.07363396883011, 54.17978793382645, 37.32320085167885, 53.551362454891205, 59.88789863884449, 22.602758444845676, 1.2316586659289896, 0.8934840559959412, 0.1777238555951044, 0.11063824757002294, 0.2517265471396968, 0.45808103517629206, 0.09498469808022492, 0.09120944479946047, 0.3180034219985828, 0.05863574464456178, 0.5298016523011029, 0.2529760269680992, 0.2984480088343844, 0.22043460281565785, 0.2164425904629752, 0.1776800540392287, 0.14672936405986547, 0.1554700973792933, 0.21575163613306358, 0.4206257621990517, 0.29892048973124474, 0.3944765153573826, 0.2426089660730213, 0.28942604607436806, 0.2092046319739893, 0.32565739878918976, 0.23406539170537144, 0.37604269513394684, 0.3060560318408534, 0.3065721213351935, 0.08279755711555481, 0.1839406485669315, 0.606883306754753, 1.0812243819236755, 0.46313307189848274, 0.11488560325233266, 0.13934702816186473, 0.2109627056051977, 0.37393407546915114, 0.303116028662771, 0.09534535958664492, 0.24733419064432383, 0.15575699682813138, 0.2798420994076878, 0.1304339087801054, 0.20423353387741372, 0.13534039549995214, 0.2265460998751223, 0.3158317197812721, 0.5848029884509742, 0.17976602335693315, 0.9021806612145156, 0.7009564619511366, 0.527698346413672, 0.2581706747878343, 0.21812245657201856, 0.29463244951330125, 0.42669210699386895, 0.1811235153581947, 0.3433607378974557, 0.011432863811933203, 0.42722309881355613, 0.17997893068240955, 0.31823862344026566, 0.521370735950768, 0.17756533285137266, 12.324843853712082, 51.500126123428345, 57.85715080797672, 37.46424548327923, 62.64119669795036, 90.10356947779655, 60.241123884916306, 22.327391020953655, 19.470318630337715, 38.49861457943916, 43.18806454539299, 34.12423990666866, 5.905448840931058, 0.6163316185120493, 1.331195868551731, 0.4441551386844367, 0.4648971272399649, 0.43484789435751736, 0.4005845688516274, 0.44300406763795763, 0.3005352249601856, 0.2694647968746722, 0.2425681776367128, 0.39539006946142763, 0.2962009934708476, 0.3879704629071057, 0.37426789349410683, 0.34416258393321186, 0.28695804881863296, 0.34759323578327894, 0.2585897804237902, 0.28743590286467224, 0.2648960764054209, 0.210026323038619, 0.42120511236134917, 0.21060804807348177, 0.3782773611601442, 0.21192386106122285, 0.3175561147509143, 0.1954792340984568, 0.2117139520123601, 0.2328004306764342, 0.35318561538588256, 0.26468382216989994, 0.24571250891312957, 0.22370575228706002, 0.27451683359686285, 0.22546182211954147, 0.28224368928931653, 0.32474547741003335, 0.36010456911753863, 0.21540535002714023, 0.4432670847745612, 0.2053940450423397, 0.26773838326334953, 0.333874843781814, 0.3963311720872298, 0.387880009948276, 0.40827823569998145, 0.26733061764389277, 0.33980795822571963, 0.314736042637378, 0.27020237292163074, 0.34656518313568085, 0.46354846679605544, 0.5240202031563967, 0.28164617135189474, 0.36779452522750944, 0.34550881013274193, 0.40067012363579124, 0.35434274235740304, 0.29125546978320926, 0.3485971537884325, 0.38120890385471284, 0.6148524291347712, 0.44741759018506855, 0.28378895949572325, 0.3078094299416989, 0.21965473919408396, 0.33861194271594286, 0.3126834402792156, 0.3175054112216458, 0.5687219544779509, 0.351439401274547, 0.32774992869235575, 0.2545225736685097, 0.2630312670953572, 0.44916463550180197, 0.5225663061719388, 0.480979882995598, 0.5857984162867069, 0.49383681965991855, 0.7125980278942734, 0.6999066495336592, 1.1407733615487814, 0.41187325841747224, 9.041646178811789, 60.493228957057, 87.94608324766159, 56.812704652547836, 43.940488770604134, 51.23188331723213, 86.5869265794754, 108.40011969208717, 64.98804196715355, 35.30206650495529, 57.61004626750946, 83.66182073950768, 58.465140983462334, 17.856495827436447, 1.0800908552482724, 1.2853380292654037, 0.054539226766792126, 0.23566152871353552, 0.3214187262346968, 0.046023115573916584, 0.03844838902296033, 0.3849072038428858, 0.5269465211313218, 0.28182698821183294, 1.3670349516905844, 0.5175608466379344, 0.25070045376196504, 0.18293910543434322, 0.22562611877219751, 0.2695075742667541, 0.3072572423843667, 0.27131381328217685, 0.3212447668192908, 0.3602287155808881, 0.15224466420477256, 0.2094031564774923, 0.3554876090493053, 0.473132086917758, 0.348349513951689, 0.5328039661981165, 0.38458499300759286, 0.42886927141807973, 0.2363836977747269, 0.3831755061401054, 0.11669026891468093, 0.38050561503041536, 1.6056785336695611, 3.397518815472722, 0.7539803010877222, 0.23596485931193456, 0.28196630417369306, 0.15148897975450382, 0.2157993710716255, 0.3856891900068149, 0.3323251800611615, 0.280729589285329, 0.24857187032466754, 0.2737287915078923, 0.16868241888005286, 0.3295523679116741, 0.3205769823398441, 0.14038869179785252, 0.2027194487163797, 0.388182865572162, 0.15638604119885713, 1.624623485840857, 2.8425324708223343, 0.983625550288707, 0.4094645142322406, 0.5570906598586589, 0.16617983754258603, 0.508065631147474, 0.1473192378762178, 0.26121273811440915, 0.7283908710815012, 0.46993360854685307, 0.6549820164218545, 0.3889550850726664, 0.8604610373731703, 0.32488280441612005, 24.26260057836771, 82.62651309370995, 93.16147059202194, 39.43046137690544, 50.57815119624138, 91.73591628670692, 86.90512910485268, 46.70346111059189, 30.077825635671616, 39.29944820702076, 53.49753454327583, 46.59099854528904, 15.752876456826925, 0.29459575773216784, 1.837985955644399, 0.5349874240346253, 0.43205486610531807, 0.5401027807965875, 0.24372344923904166, 0.4179963329806924, 0.24256699020043015, 0.28232793789356947, 0.22956293018069118, 0.32873449148610234, 0.3177399595733732, 0.2674211299745366, 0.25387666770257056, 0.3543551510665566, 0.31192172958981246, 0.41564179526176304, 0.2967012010049075, 0.40215432993136346, 0.3145104000577703, 0.3791205893503502, 0.3598642023280263, 0.2468876403872855, 0.2426632319111377, 0.28476639767177403, 0.2799374802270904, 0.27475835813675076, 0.33908813435118645, 0.4505873325979337, 0.2547235175734386, 0.36377600335981697, 0.3595088917063549, 0.2864363190019503, 0.32604637322947383, 0.17993098794249818, 0.3241455846000463, 0.23960881924722344, 0.32713213528040797, 0.18583775614388287, 0.4927813372341916, 0.3280825889669359, 0.49221089284401387, 0.4715066944481805, 0.5027120152954012, 0.5201989144552499, 0.5496346286963671, 0.37113870203029364, 0.501432433957234, 0.4479751508915797, 0.4546943778404966, 0.46208857325837016, 0.6778382055927068, 0.8598188124597073, 0.6254886521492153, 0.5248945718631148, 0.4078752198256552, 0.5042332399170846, 0.44321382825728506, 0.46690576476976275, 0.5150443722959608, 0.4665727779502049, 0.60885593527928, 0.686870499048382, 0.5203321448061615, 0.5810319283045828, 0.34775814099702984, 0.5722298787441105, 0.42970579059328884, 0.47704513475764543, 0.7507236977107823, 0.686724444385618, 0.455850554862991, 0.42760393931530416, 0.3581497521372512, 0.6358632235787809, 0.6386636733077466, 0.5796065891627222, 0.7786999933887273, 0.7164158730302006, 0.7932757143862545, 0.80354840378277, 1.2493033753708005, 1.1732060462236404, 4.842793112620711, 62.38977558910847, 106.4987625181675, 94.97157946228981, 72.39662602543831, 45.706113427877426, 76.86250358819962, 134.78287160396576, 124.30645376443863, 72.62871757149696, 56.82978853583336, 81.633041203022, 90.96398010849953, 35.23828312754631, 1.5435511549003422, 3.0174646340310574, 0.2935090457322076, 0.34892723138909787, 0.9703636087942868, 0.9079214406665415, 0.5359953199513257, 0.341472951695323, 0.8551612123847008, 0.3879708785098046, 3.9663851028308272, 1.137508386746049, 0.4324151639593765, 0.2734270639484748, 0.5188936844933778, 0.31921805057208985, 0.44662595610134304, 0.5213965033181012, 0.6201851461082697, 0.9102311823517084, 0.5959983158390969, 0.5959141859784722, 0.5928218050394207, 0.6883797305636108, 0.6166185031179339, 0.7251825963612646, 0.576161895878613, 0.5701373191550374, 0.3627983573824167, 0.666512141469866, 0.2653714962070808, 0.6903563369996846, 1.587361260317266, 3.6088133649900556, 1.3097219145856798, 0.37983937421813607, 0.5249871325213462, 0.261512387660332, 0.4967076249886304, 0.764523547841236, 0.43572131311520934, 0.5073117872234434, 0.5995504127349705, 0.4311781225260347, 0.3741811215877533, 0.5665504897478968, 0.3288114373572171, 0.321514819515869, 0.33014406741131097, 1.0972236609086394, 0.28373947308864444, 4.189926870167255, 4.463314125314355, 0.7187479385174811, 1.0220564506016672, 1.3039259193465114, 0.5841171252541244, 0.6854294263757765, 0.3103413409553468, 0.829737251624465, 0.9510946646332741, 0.8332628686912358, 0.8121153409592807, 0.411438241135329, 1.1544110672548413, 0.4880528472131118, 23.0632234364748, 88.07330802083015, 87.51682788133621, 50.50749018788338, 88.08942675590515, 114.99264433979988, 75.69363310933113, 43.78789275884628, 40.699661672115326, 59.60786886513233, 78.84375527501106, 59.456674978137016, 14.186286069452763, 0.6342207617126405, 2.275768658146262, 0.49466942029539496, 0.6301507644820958, 0.4886544618057087, 0.49764344352297485, 0.5113395710941404, 0.5332890339195728, 0.42980197293218225, 0.39436783525161445, 0.6893687462434173, 0.478315869695507, 0.5241237476002425, 0.4736882820725441, 0.5125569307710975, 0.40604787413030863, 0.7908497820608318, 0.5774877872318029, 0.5499364749994129, 0.5836182832717896, 0.42906136892270297, 0.47985232318751514, 0.43163341528270394, 0.4424993775319308, 0.3755305241793394, 0.47929140797350556, 0.2569287351798266, 0.3210416855290532, 0.5132999690249562, 0.3762044239556417, 0.5203374882694334, 0.5215873243287206, 0.41924147866666317, 0.4609940538648516, 0.4780202574329451, 0.43088351958431304, 0.4500954074319452, 0.5644527648109943, 0.4238680569687858], [0.40404820174444467, 0.3450989071279764, 0.3448464581742883, 0.4791229998227209, 0.4054010775871575, 0.5014377180486917, 0.4535680351546034, 0.5233570199925452, 0.32402298180386424, 0.40379417943768203, 0.29502896417398006, 0.30573877855204046, 0.3453099145554006, 0.37527008971665055, 0.26300066092517227, 0.2778727957047522, 0.20842119120061398, 0.3447503945790231, 0.2555382769787684, 0.3955519763985649, 0.3952657151967287, 0.34379599266685545, 0.5082573427353054, 0.38154741225298494, 0.41857431759126484, 0.2624163532163948, 0.2677126455819234, 0.16710563708329573, 0.40502745076082647, 0.3575181250926107, 0.42485422280151397, 0.16055907821282744, 0.49622956314124167, 0.2945369796361774, 0.29787079605739564, 0.2061126963235438, 0.5649811145849526, 0.4284187580924481, 0.9909056033939123, 0.831279493868351, 0.8146050979848951, 0.6115259451325983, 0.6123518070671707, 0.6766941701062024, 1.4200650248676538, 0.5741597595624626, 2.521994258277118, 31.014576070010662, 65.22414609789848, 54.5532850921154, 30.08898563683033, 31.806711964309216, 77.38250568509102, 113.62436816096306, 97.59216204285622, 51.94217920303345, 34.091595858335495, 45.659269541502, 54.87157121300697, 18.728176653385162, 0.07644851342774928, 0.2428586097084917, 0.35735998826567084, 0.1894759273272939, 0.2828566142125055, 0.20853278052527457, 0.11810371885076165, 0.6031561817508191, 1.0228116600774229, 0.2976798266172409, 0.16826432256493717, 0.13606385589810088, 0.2771799563197419, 0.5442842189222574, 0.2180382821825333, 0.16134229634189978, 0.12405261877574958, 0.15357079304521903, 0.23148694803239778, 0.20457889972021803, 0.30889560759533197, 0.14970641524996608, 0.1880701066693291, 0.236964680661913, 0.2398583886679262, 0.15420179668581113, 0.21363952837418765, 0.2216212821076624, 0.36053718184120953, 0.22674054256640375, 1.015936047770083, 1.760561428964138, 0.33018497459124774, 0.3896855068160221, 0.4123413754859939, 0.18329904705751687, 0.3365966258570552, 0.17925014166394249, 0.24062841141130775, 0.2897412807215005, 0.3672894195187837, 0.3454827459063381, 0.22103658848209307, 0.27743875805754215, 0.35377790860366076, 0.3156424721237272, 0.38279635773506016, 0.3674226498696953, 0.18826468294719234, 0.18186869099736214, 0.5655196763109416, 1.9171423581428826, 0.8967390563338995, 0.2523495355853811, 0.37825782783329487, 0.3279998543439433, 0.18983928282978013, 0.4157165443757549, 0.44549334968905896, 0.3726951341377571, 0.11148877107189037, 0.5981038184836507, 1.7478942149318755, 34.459925293922424, 59.42523546516895, 42.538352608680725, 51.523707658052444, 100.3684450685978, 88.28272238373756, 40.292570516467094, 18.945403397083282, 31.75958689302206, 46.75960689783096, 40.295074582099915, 23.585406616330147, 2.896862905472517, 0.870059144217521, 1.250320770777762, 0.4998274357058108, 0.769915992859751, 0.4952601104741916, 0.6019329442642629, 0.4286146257072687, 0.523836447391659, 0.31235662812832743, 0.4621968971332535, 0.32528941228520125, 0.41244008112698793, 0.3257603495148942, 0.6983141193632036, 0.5497411417309195, 0.3017845860449597, 0.4545297991717234, 0.4102253640303388, 0.36090855253860354, 0.2910255821188912, 0.435993384453468, 0.38468274869956076, 0.268842313089408, 0.34535040613263845, 0.3041332756401971, 0.5602168827317655, 0.3345710376743227, 0.29471726214978844, 0.35235274757724255, 0.480598151916638, 0.2799339179182425, 0.19493924744892865, 0.3666774742305279, 0.3899214504053816, 0.38699053111486137, 0.3272009768988937, 0.4573465167777613, 0.4029381269356236, 0.25986811495386064, 0.20543526392430067, 0.45897959789726883, 0.35726733854971826, 0.41608779632952064, 0.5036816163919866, 0.4041620471980423, 0.5315484304446727, 0.4131560755195096, 0.5895285098813474, 0.4761313134804368, 0.4589710780419409, 0.4406136693432927, 0.3897891996894032, 0.35881142131984234, 0.5900627968367189, 0.4380434931954369, 0.48341872869059443, 0.3866052080411464, 0.43596414383500814, 0.3277632873505354, 0.3673290502047166, 0.38956177595537156, 0.41378485271707177, 0.542113526025787, 0.4490852850722149, 0.31095830316189677, 0.45835476892534643, 0.3698340954724699, 0.34801035246346146, 0.5494752153754234, 0.46733683382626623, 0.4069122683722526, 0.40280106710270047, 0.6554030813276768, 0.46209439169615507, 0.46431332419160753, 0.33047702454496175, 0.582223639357835, 0.39236394746694714, 0.8033297373913229, 0.8990904770325869, 0.937589833047241, 0.7569969829637557, 0.7313735329080373, 0.9333897521719337, 1.1760054272599518, 1.0645443457178771, 26.513565592467785, 74.75101009011269, 71.66583403944969, 47.29389622807503, 50.24780832231045, 69.54937800765038, 109.38015550374985, 101.46891921758652, 65.20368039608002, 47.3673614859581, 58.152292370796204, 74.44859951734543, 64.0630804002285, 8.633034154772758, 0.2217937572277151, 0.4957108019152656, 0.6331884046085179, 0.624692594865337, 0.4515774466563016, 0.07858796190703288, 0.2761554066091776, 0.3874819219345227, 0.7220399868674576, 0.3333239920902997, 0.2621275093406439, 0.5382611264940351, 0.41348072059918195, 0.25141119374893606, 0.2128515308140777, 0.40758913673926145, 0.2246178369387053, 0.2563586173346266, 0.30492303951177746, 0.42018385778646916, 0.3498375497292727, 0.20272127439966425, 0.22591101442230865, 0.23322979279328138, 0.33572926302440464, 0.3525899082887918, 0.28580780897755176, 0.31936496612615883, 0.23582465277286246, 0.5335404141806066, 1.1931945174001157, 4.169747577980161, 0.6902884156443179, 0.3908466116990894, 0.3896756807807833, 0.24227713700383902, 0.4344681522343308, 0.25117299403063953, 0.24719943146919832, 0.3646403085440397, 0.46885366493370384, 0.26554103242233396, 0.3804026049328968, 0.352812641649507, 0.4780344769824296, 0.6103713414631784, 0.6225375167559832, 0.22457005747128278, 0.422749996650964, 0.16504778031958267, 0.4845744901103899, 1.2790719280019403, 1.5027789864689112, 0.6389548920560628, 1.1465182970277965, 1.4043873036280274, 1.0803955513983965, 0.47246605390682817, 0.10999922873452306, 0.8832951402291656, 0.8356519904918969, 0.9758952807169408, 4.196117212995887, 58.310086503624916, 85.52653267979622, 53.708400428295135, 47.32665427029133, 83.41309368610382, 100.287676602602, 69.65275526046753, 40.946728214621544, 32.38348491489887, 43.58122564852238, 54.8092545568943, 42.77727618813515, 8.223826512694359, 0.4422273061936721, 1.931269287597388, 0.5737427913118154, 1.0701712500303984, 0.5850301450118423, 0.5213006178382784, 0.33931627054698765, 0.4182568861870095, 0.3005543723702431, 0.3751064313109964, 0.3073791624046862, 0.39595416106749326, 0.3600628604181111, 0.4661861783824861, 0.409946910222061, 0.3285335178952664, 0.6019112141802907, 0.3243761550402269, 0.3628281026612967, 0.4771541414083913, 0.4724311432801187, 0.4549402365228161, 0.3633537807036191, 0.3988061158452183, 0.3401358687551692, 0.47606926993466914, 0.2677292993757874, 0.3164102684240788, 0.41886369581334293, 0.5489295290317386, 0.42687170673161745, 0.31227822764776647, 0.37614778324496, 0.6092704692855477, 0.39648924954235554, 0.47571734350640327, 0.47012757626362145, 0.3447569254785776, 0.36103335209190845, 0.33949177362956107, 0.6349440291523933, 0.46278930909466, 0.6261917331721634, 0.6150164734572172, 0.5979150161147118, 0.6812824832741171, 0.6036053888965398, 0.7905174780171365, 0.5182423756923527, 0.5734128621406853, 0.5222991923801601, 0.4398745793150738, 0.45666005986277014, 0.7118042861111462, 0.7024884328711778, 0.614012258592993, 0.6135976652149111, 0.5523732129950076, 0.5259094142820686, 0.5577456497121602, 0.4978892725193873, 0.662090010009706, 0.6741100712679327, 0.6552404025569558, 0.5080943077336997, 0.5636152066290379, 0.4810083517804742, 0.4915356868878007, 0.7228988595306873, 0.6796419806778431, 0.6229478353634477, 0.5375118541996926, 0.5999078904278576, 0.5820721224881709, 0.5118285573553294, 0.38689375505782664, 0.7576700218487531, 0.6426984630525112, 0.8294788654893637, 1.2012576847337186, 1.0329933324828744, 0.9895858867093921, 0.7443836785387248, 0.8013432752341032, 1.3316499441862106, 0.3640989266568795, 21.22233621776104, 87.3448795080185, 103.28359544277191, 82.33372360467911, 62.119621485471725, 58.363097459077835, 110.53863734006882, 140.0726893544197, 121.84236198663712, 66.28717705607414, 49.95265915989876, 61.64122715592384, 82.06836104393005, 26.96191493421793, 0.331861634622328, 2.0430164225399494, 0.9308519633486867, 0.8304539287928492, 0.5134264309890568, 0.44929510506335646, 0.6726046989206225, 2.3171021277084947, 3.556868014857173, 0.940297544002533, 0.2560154185630381, 0.627599082654342, 0.6671954516787082, 0.709680556319654, 0.4098257323494181, 0.4490487714065239, 0.2392923823208548, 0.43713786522857845, 0.5265985429286957, 0.49247364280745387, 0.5155137658584863, 0.4690313944593072, 0.23904305038740858, 0.2917218650691211, 0.39982211601454765, 0.5200920451898128, 0.35252608358860016, 0.390719793504104, 0.5062818643637002, 0.7759950135368854, 1.6002633492462337, 5.059016710147262, 0.8847662550397217, 0.5446738167665899, 0.49855634453706443, 0.39155847975052893, 0.6502232467755675, 0.4062002815771848, 0.2782681823009625, 0.5724021757487208, 0.6151857424993068, 0.4977852531010285, 0.544693231349811, 0.41667940677143633, 0.625231156591326, 0.6057973962742835, 0.6471221381798387, 0.315566654317081, 0.4778010566951707, 0.37716805818490684, 1.6864769230596721, 2.897007060237229, 1.2216070177964866, 0.5127168784383684, 0.7255102100316435, 2.2020367020741105, 1.5613267198204994, 0.6619751255493611, 0.6975721498019993, 1.1819546017795801, 1.6818908066488802, 1.0681553394533694, 5.57652804069221, 60.386439487338066, 92.81001225113869, 52.25156620144844, 70.03043219447136, 120.00272870063782, 104.12898927927017, 59.90528650581837, 42.89500527083874, 51.97222039103508, 68.48346680402756, 72.9547780752182, 45.300181210041046, 4.675349872559309, 1.4579355739988387, 2.1869726479053497, 0.3961337311193347, 1.5883709373883903, 0.6794169021304697, 0.6127798184752464, 0.42335956706665456, 0.6731693842448294, 0.39841441030148417, 0.6143315008375794, 0.5939245771151036, 0.6568003376014531, 0.4559653502656147, 0.7096675538923591, 0.5795122473500669, 0.4038893821416423, 0.7864797196816653, 0.6177438958548009, 0.584537893300876, 0.6356861174572259, 0.5557398917153478, 0.5133268644567579, 0.46524471952579916, 0.5390040460042655, 0.4486516333417967, 0.7730382971931249, 0.5277667427435517, 0.4010279575595632, 0.48006428056396544, 0.7985010277479887, 0.5232108465861529, 0.40282353933434933, 0.5360295181162655, 0.6206072797067463, 0.504223502939567, 0.5570346722379327, 0.7014444388914853, 0.6591538363136351, 0.6039256998337805, 0.5174748762510717], [0.4832355072721839, 0.44212586944922805, 0.4559733357746154, 0.27567915560211986, 0.42756715847644955, 0.2494748414028436, 0.46885645540896803, 0.3418732067802921, 0.40586572140455246, 0.4046770086279139, 0.2572436729678884, 0.2706617029616609, 0.5557398323435336, 0.5028317682445049, 0.45081336109433323, 0.35870965803042054, 0.40068645088467747, 0.5685619474388659, 0.3699831187259406, 0.40281881927512586, 0.3197722864570096, 0.4189345857594162, 0.44489669264294207, 0.4063093475997448, 0.36483145609963685, 0.3080336772836745, 0.17461113980971277, 0.27334999933373183, 0.33791215682867914, 0.38943854975514114, 0.40480830939486623, 0.48326249176170677, 0.488051125430502, 0.4197130986722186, 0.5255410121753812, 0.4667102236999199, 0.5539808236062527, 0.3863243496743962, 0.4961284826276824, 0.9088742395397276, 1.1619236203841865, 0.9134680149145424, 0.7094747736118734, 0.7661372737493366, 1.271761239040643, 2.5515668839216232, 1.5228376351296902, 4.978491431102157, 19.257946126163006, 63.38936135172844, 55.14215089380741, 30.844282507896423, 21.749575026333332, 41.295139119029045, 73.01169142127037, 98.25391173362732, 100.87452471256256, 73.36220741271973, 52.57998637855053, 61.802365109324455, 48.547578155994415, 4.186197845265269, 0.44019302004016936, 0.09854033502051607, 0.4131135356146842, 0.3156149829737842, 0.3513687488157302, 0.46832501830067486, 0.19377247255761176, 0.43448756681755185, 0.7097651611547917, 0.04138019517995417, 0.1846037872019224, 0.20271495130145922, 0.3841410996392369, 0.5274163896683604, 0.5365868413355201, 0.3160717006539926, 0.32328436675015837, 0.4816010902868584, 0.36736259527970105, 0.5447134177666157, 0.3546368406387046, 0.36001381929963827, 0.5981342762243003, 0.3699654556112364, 0.37836822972167283, 0.3902635211125016, 0.293481289409101, 0.6598524644505233, 0.5228171520866454, 2.311483179219067, 0.6322664790786803, 0.3812018979806453, 0.36762015020940453, 0.30726920580491424, 0.34930774534586817, 0.3733042592648417, 0.36182326439302415, 0.3970449400367215, 0.37159645871724933, 0.20179431710857898, 0.3841912391362712, 0.30369825835805386, 0.46140167105477303, 0.44974722142796963, 0.38679181365296245, 0.6162952235899866, 0.5333131982479244, 0.5305740202311426, 0.5209800694137812, 0.899284741608426, 1.340687284246087, 3.002874366939068, 7.785167600959539, 3.532851403579116, 2.0877509471029043, 0.47184837923850864, 0.4013866820605472, 0.5404496903065592, 0.29110787145327777, 9.61958946660161, 47.029289826750755, 65.92043593525887, 71.06143087148666, 92.16280058026314, 105.06256878376007, 62.43461698293686, 34.784762263298035, 30.713634118437767, 39.22718748450279, 54.7362794727087, 37.38370880484581, 10.907877087593079, 0.416201968328096, 1.458789815660566, 0.5858279240783304, 0.5583484517410398, 0.5424190533813089, 0.5897082283627242, 0.5383454938419163, 0.4780166654381901, 0.46341574110556394, 0.1646769291255623, 0.2843295695492998, 0.40942351799458265, 0.5830194591544569, 0.587431734893471, 0.6427298707421869, 0.4419746791245416, 0.5076538282446563, 0.46762460900936276, 0.38816784450318664, 0.4691160883521661, 0.4568854649551213, 0.5037044745404273, 0.23952845949679613, 0.23215088818687946, 0.44878159824293107, 0.35682813555467874, 0.38675529998727143, 0.4379408393288031, 0.38164116034749895, 0.3382578195305541, 0.6116561475209892, 0.548096364364028, 0.328892539255321, 0.36750888742972165, 0.22387139964848757, 0.362176526687108, 0.40849550685379654, 0.42536295019090176, 0.33922391769010574, 0.5634508654475212, 0.44307397794909775, 0.3514079638989642, 0.39596511516720057, 0.3996844921493903, 0.5409884895198047, 0.47033769311383367, 0.7451070647221059, 0.288785602315329, 0.396665227599442, 0.46554591273888946, 0.35168704111129045, 0.5099562671966851, 0.4259392723906785, 0.35454799071885645, 0.5206412344705313, 0.4921354609541595, 0.46957518090493977, 0.47558915975969285, 0.3680074622388929, 0.6138704787008464, 0.3816006687702611, 0.3891853883396834, 0.36085591942537576, 0.3930601413594559, 0.38057172554545105, 0.41583573329262435, 0.3060479572741315, 0.36212071718182415, 0.3515321994200349, 0.40176885842811316, 0.5116507387720048, 0.427109906449914, 0.475961035117507, 0.28031119611114264, 0.45281134138349444, 0.5088196531869471, 0.48463775077834725, 0.42789851257111877, 0.4598046879982576, 0.5588816106319427, 0.5234562896657735, 0.8957949257455766, 1.1297765141353011, 0.7436997152399272, 0.5535090551711619, 0.4690887179458514, 1.8793951836414635, 2.6990189217031, 1.0198956727981567, 16.38193555176258, 62.25813165307045, 78.12443107366562, 58.98653380572796, 42.703278958797455, 50.5898317694664, 78.91824647784233, 106.54649555683136, 101.05488583445549, 63.67487043142319, 50.45483261346817, 64.36556696891785, 88.97472605109215, 38.58672805130482, 1.4014149131253362, 0.8002180012408644, 0.09315520757809281, 0.730275094974786, 0.6037024024408311, 0.3425938915461302, 0.12587065051775426, 0.18551815766841173, 0.6690342561341822, 0.33633592422120273, 0.0843176239868626, 0.2945445495424792, 0.12440631893696263, 0.5040745390579104, 0.2747931203339249, 0.32611114787869155, 0.11967594386078417, 0.19385887339012697, 0.2703813789412379, 0.4703774128574878, 0.3268501488491893, 0.3949057142017409, 0.4990234225988388, 0.7328850205522031, 0.45834013377316296, 0.2841449232073501, 0.233318627870176, 0.25511189829558134, 0.7362782384734601, 0.4243023617891595, 4.274343615397811, 0.7136081205680966, 0.4110945970751345, 0.40848392935004085, 0.27823775424622, 0.33675235812552273, 0.2975959045579657, 0.4549394943751395, 0.29718107369262725, 0.39499067526776344, 0.2688412740826607, 0.5048572970554233, 0.379220541799441, 0.6105045124422759, 0.3261397947790101, 0.33191037888173014, 0.4125078540528193, 0.44729679822921753, 0.6270219292491674, 0.999034910928458, 0.4164453037083149, 0.7880496291909367, 3.2916372595354915, 6.97164217941463, 4.5087905600667, 2.3375564301386476, 0.42113736912142485, 0.21476426802109927, 1.9885317399166524, 0.15957681607687846, 20.8113806694746, 66.55924245715141, 75.95158606767654, 61.80262729525566, 72.35474467277527, 107.9212237894535, 96.24156251549721, 58.851025477051735, 38.24509598314762, 36.578319221735, 58.17114315927029, 58.66775371134281, 25.972109846770763, 1.304591002408415, 1.2052228907123208, 0.9810450731310993, 0.60875951545313, 0.7645571522880346, 0.46506592130754143, 0.5246947263367474, 0.5323912727180868, 0.2867846534354612, 0.3259651822736487, 0.3153712023049593, 0.29084939626045525, 0.5411949846893549, 0.40505128854420036, 0.4231801157584414, 0.47429862432181835, 0.606798583175987, 0.6078548671212047, 0.3528939513489604, 0.42125931882765144, 0.2584979322273284, 0.5046391650103033, 0.3893029742175713, 0.4524841730017215, 0.5916609079577029, 0.43317441071849316, 0.4081365745514631, 0.37544134771451354, 0.4121022258186713, 0.44835474458523095, 0.5556761263869703, 0.363444768008776, 0.383671527961269, 0.3835012495983392, 0.30831254669465125, 0.3999491420108825, 0.39622632146347314, 0.474083045264706, 0.3979715262539685, 0.5033751390874386, 0.4887257079826668, 0.49824149580672383, 0.48329808516427875, 0.6123196275439113, 0.7820284960325807, 0.551695543108508, 0.89225945295766, 0.36598291306290776, 0.7765994779765606, 0.49086716026067734, 0.6314377672970295, 0.6631264043971896, 0.6486770859919488, 0.6161504751071334, 0.6639349891338497, 0.5508006317541003, 0.6696730968542397, 0.7529690803494304, 0.5307065381202847, 0.724188118474558, 0.4058100009569898, 0.4618635243969038, 0.5373181833419949, 0.492187975323759, 0.5577297974377871, 0.527782179415226, 0.48121244239155203, 0.6252408341970295, 0.47422025352716446, 0.6270592147484422, 0.5687069927807897, 0.5104485189076513, 0.5590947554446757, 0.39912230044137686, 0.5243004381190985, 0.8462991379201412, 0.7120595849119127, 0.5601532361470163, 0.5570401938166469, 0.5787215335294604, 0.4543158528394997, 0.9305614570621401, 1.388789378106594, 1.046731376554817, 0.8602345339022577, 0.5396151007153094, 1.5465082274749875, 2.8031314350664616, 1.1913061374798417, 13.492835629731417, 66.6782596707344, 107.50427976250648, 85.60645759105682, 56.08013056218624, 47.38544471561909, 63.85208532214165, 101.56579121947289, 124.80403706431389, 124.17367368936539, 86.64608180522919, 63.297140300273895, 85.21134719252586, 65.9851236641407, 6.149592390283942, 1.3334003440104425, 0.4365249106194824, 0.7832592737395316, 0.941223744302988, 0.6294433493167162, 1.5914988820441067, 1.7754478426650167, 1.4791050693020225, 0.9445363353006542, 0.37500653823371977, 0.3458318818593398, 0.34047244756948203, 0.5327742802910507, 0.8126900601200759, 0.7450849190354347, 0.5469162901863456, 0.6271257111802697, 0.66739636589773, 0.9504895471036434, 0.6244329619221389, 0.733563284156844, 0.7253294228576124, 0.9084077551960945, 0.8550262008793652, 0.4628945159493014, 0.5521863698959351, 0.48446319764479995, 1.1521062534302473, 0.7448591280262917, 5.919859567657113, 1.1231909925118089, 0.4277427209308371, 0.6190868269186467, 0.4286248376592994, 0.4594235209515318, 0.5859541485551745, 0.8499782311264426, 0.6753783125896007, 0.656496116425842, 0.4779656353639439, 0.6406434858217835, 0.5496617022436112, 0.6286759092472494, 0.478188339038752, 0.41256781958509237, 0.8089900086633861, 0.718849761178717, 1.110210414044559, 2.2134403651580215, 1.1841378221288323, 0.9862043056637049, 4.1293638199567795, 10.292753744870424, 6.397801721468568, 3.85313811711967, 0.6164024490863085, 0.7047452148981392, 2.6219920674338937, 0.5653816962148994, 20.01705229282379, 73.69561672210693, 91.45037680864334, 84.64118778705597, 115.53664594888687, 126.59841477870941, 88.2801005244255, 57.99675531685352, 52.27069437503815, 54.990098252892494, 79.43020820617676, 72.21355184912682, 21.201959811151028, 0.43511100055184215, 2.0504640229046345, 0.938167164567858, 0.6928432441782206, 1.1465756502002478, 0.5174336722120643, 0.9620660415384918, 0.5505811341572553, 0.5428590578958392, 0.5519025132525712, 0.47264226945117116, 0.42420202342327684, 0.5816416768357158, 0.5958143225871027, 0.7303320919163525, 0.4697392845991999, 0.9453088813461363, 0.6384059402626008, 0.5085630482062697, 0.5139881477225572, 0.7392646407242864, 0.5382180819287896, 0.5289326864294708, 0.5388804338872433, 0.6254212057683617, 0.41391811275389045, 0.540109786670655, 0.4775994597002864, 0.521481583127752, 0.537042876239866, 0.7640662067569792, 0.6062881043180823, 0.46756173425819725, 0.5114196636714041, 0.42193511850200593, 0.5760908278170973, 0.6280693667940795, 0.6181562331039459, 0.482038541813381, 0.7590649032499641, 0.8510840311646461, 0.4518715449376032], [0.4773115657735616, 0.6181918561924249, 0.3079894749680534, 0.3770813753362745, 0.6412587559316307, 0.6309531151782721, 0.49482752743642777, 0.28522952750790864, 0.41167495655827224, 0.6645914039108902, 0.4178328230045736, 0.4583515034755692, 0.20454073848668486, 0.579024211037904, 0.37262388796079904, 0.3074613626813516, 0.4034713451983407, 0.3057272604200989, 0.3612303774571046, 0.5136702116578817, 0.4756495705805719, 0.5982813995797187, 0.45537029625847936, 0.4632905259495601, 0.5977224139496684, 0.4177706013433635, 0.3686918114544824, 0.3613460931228474, 0.37386769778095186, 0.3677319176495075, 0.5021073727402836, 0.5437797959893942, 0.4724917025305331, 0.43136220483575016, 0.549973463639617, 0.5942453630268574, 0.44267669145483524, 0.5314742750488222, 0.5894020479172468, 0.7336233684327453, 0.866126058390364, 1.035820262040943, 0.9334673511330038, 0.7207513216417283, 0.4792584269307554, 0.15049481356982142, 1.5199700952507555, 3.053541798144579, 1.214151936583221, 14.103811495006084, 50.07375866174698, 69.89698335528374, 48.776158690452576, 35.29531806707382, 30.07783893495798, 45.09142801165581, 81.39856338500977, 132.7660158276558, 122.342369556427, 75.10325118899345, 47.35676385462284, 50.87172344326973, 15.865209829062223, 0.4937296238495037, 0.658334445906803, 0.35851569031365216, 0.8585123950615525, 0.5026040773373097, 0.06222673750016838, 0.19084220635704696, 0.2652208402287215, 0.27382354892324656, 0.6326531083323061, 0.6386539957020432, 0.37461735599208623, 0.2299702208256349, 0.2740930375875905, 0.35154537996277213, 0.3601396281737834, 0.2533365029376, 0.15351404843386263, 0.24348795093828812, 0.18467037269147113, 0.3908462851541117, 0.354456736240536, 0.3047198097920045, 0.22735812817700207, 0.2934129227651283, 0.26690557482652366, 0.40729358384851366, 0.2697272796649486, 2.608091225847602, 0.055168946491903625, 0.7211885356809944, 0.28865753731224686, 0.33299216302111745, 0.2888102416181937, 0.16395608108723536, 0.33424582856241614, 0.3940044203773141, 0.4243394098011777, 0.24165370326954871, 0.5434517667163163, 0.5608773941639811, 0.3188980068080127, 0.3040080307982862, 0.219544337305706, 0.2241815728484653, 0.4033003840595484, 0.28653449029661715, 0.37708036601543427, 0.36859589628875256, 0.42432367627043277, 0.30410887382458895, 0.1941951850312762, 0.3641278110444546, 0.5725834972690791, 0.42379357502795756, 0.4205686168279499, 5.93493620865047, 31.735184602439404, 52.067716866731644, 86.36694878339767, 104.70648229122162, 103.98339629173279, 84.81378972530365, 44.52892139554024, 31.986406221985817, 43.120291382074356, 59.42026913166046, 59.15093198418617, 32.54353612661362, 2.8791228448972106, 1.0184320388361812, 1.1048119724728167, 0.49657573050353676, 0.6058323662728071, 0.7083500339649618, 0.4881359974388033, 0.5130699626170099, 0.4327114293118939, 0.26632868859451264, 0.3585917456075549, 0.36553596204612404, 0.3974738420220092, 0.6077494821511209, 0.5193323828279972, 0.7157558959443122, 0.4922250233357772, 0.49642831028904766, 0.4251073842169717, 0.5049497389700264, 0.6282893393654376, 0.40156307572033256, 0.4557482275413349, 0.4506036004750058, 0.3656891413265839, 0.2986022864934057, 0.3181545826373622, 0.4659329279093072, 0.3259737021289766, 0.3250153223052621, 0.3920744505012408, 0.35217377124354243, 0.5979133537039161, 0.44312530488241464, 0.4677804303355515, 0.3457906481344253, 0.3749658091692254, 0.3968647465808317, 0.3107836312847212, 0.17481420625699684, 0.33207795582711697, 0.3434520517475903, 0.527605963870883, 0.34630801412276924, 0.5089912377297878, 0.6624363258015364, 0.3314636059803888, 0.5195533053483814, 0.657665622420609, 0.4916054190834984, 0.4665969422785565, 0.450906099868007, 0.42721909121610224, 0.395234752795659, 0.4014314484084025, 0.4130727768642828, 0.3411123569821939, 0.5067514360416681, 0.34555227030068636, 0.40844495175406337, 0.34732003638055176, 0.33560342446435243, 0.32251232536509633, 0.2715073653962463, 0.5246397480368614, 0.5054907943122089, 0.4914478462887928, 0.45334832975640893, 0.5115158460102975, 0.31028645171318203, 0.4022220731712878, 0.25354991492349654, 0.35715444304514676, 0.4962319083278999, 0.5076672462746501, 0.5772304104175419, 0.42513567488640547, 0.29941309767309576, 0.43469044030644, 0.4460780433146283, 0.39498699421528727, 0.4422575264470652, 0.6386325624771416, 0.810368147213012, 0.9221492428332567, 0.7918405195232481, 0.6196887977421284, 0.6593102216720581, 0.36224263720214367, 0.5743064673151821, 2.2244685608893633, 2.2071678517386317, 4.491956038400531, 49.86484207212925, 75.04782736301422, 63.98698568344116, 46.31149314343929, 47.87006691098213, 52.8285576403141, 71.53647378087044, 112.38593101501465, 123.03339287638664, 79.33858752250671, 66.70635536313057, 77.82023459672928, 62.73920103907585, 13.77083346247673, 0.3122041909955442, 0.623692061053589, 0.5414101481437683, 1.3301126891747117, 0.37059405469335616, 0.151015623123385, 0.5592754238750786, 0.14099229534622282, 0.767616581870243, 0.3772603516699746, 0.14485143357887864, 0.21632981370203197, 0.505961790913716, 0.38696690113283694, 0.5443359911441803, 0.44050831405911595, 0.25369481183588505, 0.23286183597519994, 0.35674246202688664, 0.27632957382593304, 0.22112477046903223, 0.19062307983404025, 0.3838513948721811, 0.3426757059060037, 0.38331161602400243, 0.37460847990587354, 0.4098955832887441, 0.3957305965013802, 2.0166698237881064, 0.7653292827308178, 0.931357336230576, 0.2488844926119782, 0.3975809784606099, 0.31755041505675763, 0.1691687185666524, 0.19707955681951717, 0.5010165937710553, 0.35741722269449383, 0.18862830562284216, 0.31862608389928937, 0.351305102230981, 0.28656301845330745, 0.527698821388185, 0.4480652476195246, 0.330754320602864, 0.42979648103937507, 0.3419064253102988, 0.8770651370286942, 0.5719958350528032, 0.24402298004133627, 0.24853045848431066, 0.16758353565819561, 0.2305105933919549, 0.2651095774490386, 1.142686796374619, 0.8028237707912922, 11.399504207074642, 54.65890422463417, 63.22655528783798, 75.637776106596, 91.73234447836876, 116.53316527605057, 115.64685523509979, 73.34734261035919, 45.12507140636444, 45.909155532717705, 59.109859988093376, 68.68497759103775, 52.02275387942791, 8.277003709226847, 0.4724691709270701, 1.6974946693517268, 0.7380031677894294, 0.732044909382239, 1.000537492800504, 0.3588711196789518, 0.5182714678812772, 0.37925465090665966, 0.3823475958779454, 0.484632674488239, 0.46461205347441137, 0.36481346643995494, 0.3895834763534367, 0.44307537318672985, 0.513311605900526, 0.5285782960709184, 0.4137950052972883, 0.4752391926012933, 0.42877044703345746, 0.6413263804279268, 0.49910191213712096, 0.4025619471212849, 0.5318121600430459, 0.406558679533191, 0.29658590094186366, 0.20170999428955838, 0.34431968175340444, 0.46945735753979534, 0.49883758882060647, 0.2853110746946186, 0.4131496336776763, 0.5353222810663283, 0.4371519066626206, 0.5367954145185649, 0.24826773820677772, 0.3193801059387624, 0.3860134491696954, 0.362213485641405, 0.3792653972050175, 0.4904856369830668, 0.47422737814486027, 0.4848783550551161, 0.4360594949685037, 0.6056412484031171, 0.7477375329472125, 0.49703713855706155, 0.4828523809555918, 0.84840327501297, 0.7711931993253529, 0.5507695802953094, 0.5681985919363797, 0.5179652874357998, 0.6453449616674334, 0.46432558447122574, 0.6517306377645582, 0.3758070187177509, 0.7944176718592644, 0.4257558728568256, 0.590830355649814, 0.39309356769081205, 0.30934736772906035, 0.571243119193241, 0.5682619416620582, 0.6136459344998002, 0.6245565146673471, 0.5175707617308944, 0.4306021862430498, 0.6472319166641682, 0.7286223617848009, 0.6006881548091769, 0.6019300350453705, 0.4960331611800939, 0.6065957096870989, 0.6725197378546, 0.7653210894204676, 0.8357084530871361, 0.4763702256605029, 0.6093052017968148, 0.57100111967884, 0.571175494696945, 0.5448335863184184, 0.7127649220637977, 0.7300912798382342, 0.7615962205454707, 0.8996500563807786, 0.835027873981744, 0.9922294167336076, 0.5472827330231667, 0.39457533974200487, 1.7922588530927896, 2.432724223472178, 1.9776797597296536, 43.77305455505848, 94.14104282855988, 103.04955840110779, 70.47622427344322, 60.64589336514473, 58.155294209718704, 64.32874694466591, 104.71479624509811, 156.6160288453102, 134.72430914640427, 84.63434055447578, 68.10046255588531, 81.3757874071598, 30.784920193254948, 0.7153607171494514, 2.1386276045814157, 0.8617297536693513, 1.9443784654140472, 0.8297705592121929, 0.28939989279024303, 0.9266855462919921, 1.1457839864306152, 0.8728958701249212, 1.0364613588899374, 0.8408442931249738, 0.3645950969075784, 0.5606323073152453, 0.3737241367343813, 0.6195104448124766, 0.5045505822636187, 0.39171216369140893, 0.19550973636796698, 0.5015638831537217, 0.384965447592549, 0.566141833551228, 0.6810225534718484, 0.5530942243058234, 0.6924674799665809, 0.34594741940964013, 0.4452278686221689, 0.49066301027778536, 0.48758478951640427, 4.398865308612585, 1.0037597198970616, 1.1796115525066853, 0.3901072248117998, 0.6368217815179378, 0.41277597716543823, 0.2692176913842559, 0.40721776604186743, 0.5847094184719026, 0.5288763425778598, 0.37584801495540887, 0.6715916970279068, 0.5795714410487562, 0.5422210483811796, 0.5569295247551054, 0.5246745992917567, 0.3970786335412413, 0.5367297492921352, 0.4437387641519308, 0.9575115703046322, 0.5824501428287476, 0.41810100548900664, 0.4171005013631657, 0.30384481768123806, 0.38086490356363356, 1.126018159557134, 2.1758758183568716, 0.7799080910626799, 12.197309397161007, 53.009959906339645, 83.47514435648918, 105.69550082087517, 118.20691466331482, 131.74990475177765, 109.71409678459167, 67.40075290203094, 53.82637269794941, 62.28153079748154, 80.92101261019707, 89.10851687192917, 50.54162375628948, 3.638689974322915, 1.4947514422237873, 1.7943437537178397, 0.635552768362686, 0.9959542856086046, 1.255037267692387, 0.47090398147702217, 0.8490745327435434, 0.513403513468802, 0.5280985124409199, 0.6759045843500644, 0.5140731087885797, 0.44670518778730184, 0.7559263310395181, 0.5252159514930099, 0.6970489060040563, 0.5604986019898206, 0.6219060381408781, 0.47978021611925215, 0.6049672595690936, 0.793774378253147, 0.5158831179141998, 0.5884234223049134, 0.6163376744370908, 0.6204817083198577, 0.38778792426455766, 0.4621207230957225, 0.46542859403416514, 0.47239118604920805, 0.6708669452928007, 0.44654417142737657, 0.3959455224685371, 0.7392062188591808, 0.5212667165324092, 0.6714891619049013, 0.4014364059548825, 0.5301923188380897, 0.6313650961965322, 0.5296893802005798, 0.46633529069367796, 0.6037448532879353, 0.5741601157933474, 0.8075027447193861, 0.5345340014901012], [0.41351952007971704, 0.2655632671667263, 0.45899357995949686, 0.44098118087276816, 0.40079928701743484, 0.390561152016744, 0.4318947996944189, 0.5064006079919636, 0.4645138228079304, 0.2629726968007162, 0.40260433859657496, 0.2202628253144212, 0.3334306535543874, 0.5058875761460513, 0.36214835476130247, 0.4837811639299616, 0.42946171306539327, 0.40511261962819844, 0.40644308261107653, 0.3280003886902705, 0.4225689126178622, 0.3719750727759674, 0.3873498196480796, 0.35369624267332256, 0.40888792485930026, 0.47853857337031513, 0.38831057434435934, 0.6065368128474802, 0.3860996867297217, 0.4422593966592103, 0.22485487890662625, 0.40080433362163603, 0.3787298040697351, 0.4746672639157623, 0.5271043907850981, 0.4879047442227602, 0.5427170998882502, 0.5721125600393862, 0.5113060853909701, 0.6359328073449433, 0.8811206475365907, 0.6710813962854445, 0.8075326087418944, 0.9534373576752841, 0.5608651041984558, 0.9119736857246608, 0.4066547134425491, 0.4152841097675264, 1.7780584213323891, 1.6950922482647002, 3.609088850207627, 34.16630744934082, 77.26623192429543, 73.21693360805511, 50.999833568930626, 41.88674457371235, 39.14603143930435, 52.52525791525841, 92.77344301342964, 129.53048944473267, 111.50164246559143, 66.61585941910744, 32.12347626686096, 20.965813882648945, 8.836611080914736, 0.31066696566995233, 0.5289635004010051, 0.3195167798548937, 0.1824802058399655, 0.5235806142445654, 0.6454837729688734, 0.17897100507980213, 0.1692611159523949, 0.1367808596114628, 0.4103801760356873, 0.7580631226301193, 0.6864183826837689, 0.6718993023969233, 0.5945841979701072, 0.47816568869166076, 0.5905545735731721, 0.4534093046095222, 0.35171001800335944, 0.3882981062633917, 0.46505763893947005, 0.3296603949274868, 0.6788108346518129, 0.6655839818995446, 0.4964910662965849, 0.5767571576870978, 0.5571810237597674, 1.8901413632556796, 0.29008896206505597, 0.85939638200216, 0.5890579882543534, 0.48210940207354724, 0.4621026443783194, 0.3377936506876722, 0.3624355362262577, 0.20320540701504797, 0.3046359767904505, 0.33804452628828585, 0.41463158384431154, 0.3941475064493716, 0.38668954570312053, 0.3077413304708898, 0.24587069026893005, 0.2965618553571403, 0.6569209811277688, 0.5986673757433891, 0.8058750664349645, 0.9247673023492098, 0.30752147664316, 0.20354854641482234, 0.21983206795994192, 0.49233590019866824, 0.46666884154547006, 4.611325683072209, 32.73849606513977, 50.96123144030571, 58.318267464637756, 96.28747165203094, 99.07266899943352, 83.93142387270927, 55.65161615610123, 30.356610976159573, 32.45755434036255, 52.03953757882118, 62.175136506557465, 40.159931033849716, 10.587713867425919, 0.2468403655802831, 0.8414729812648147, 0.5065549747087061, 0.4595611448166892, 0.4723214538535103, 0.39827717235311866, 0.35940510977525264, 0.3820280567742884, 0.5041078466456383, 0.3012806974584237, 0.47280423576012254, 0.4027337394654751, 0.35089810844510794, 0.3668313066009432, 0.5688352952711284, 0.3047356620663777, 0.6610635307151824, 0.3529711643932387, 0.4711925581796095, 0.30094367335550487, 0.31761572405230254, 0.3887563676107675, 0.4098008555592969, 0.4204535542521626, 0.40103523060679436, 0.4597575170919299, 0.22467939066700637, 0.2723225700901821, 0.267017490696162, 0.5089494993444532, 0.388366294791922, 0.2897836425108835, 0.25852836028207093, 0.3009507682872936, 0.5022762261796743, 0.5911263241432607, 0.5265527672600001, 0.48179992649238557, 0.20957015454769135, 0.3492931992514059, 0.46188941050786525, 0.45417995075695217, 0.3021297440864146, 0.3731688321568072, 0.34556577738840133, 0.5130722187459469, 0.513996637891978, 0.29268048238009214, 0.32660532917361706, 0.5054348066914827, 0.4195931082358584, 0.49848699825815856, 0.5381804401986301, 0.22263535269303247, 0.3394280973589048, 0.3022793313721195, 0.23979027435416356, 0.34550115116871893, 0.5108021968044341, 0.4921727761393413, 0.36677674390375614, 0.39527533343061805, 0.2988994721090421, 0.4128265322651714, 0.3945504332659766, 0.5963392287958413, 0.5428649357054383, 0.5558911710977554, 0.2790174842812121, 0.3093443694524467, 0.5386874754913151, 0.5410200753249228, 0.4857411759439856, 0.45146900403779, 0.38931826245971024, 0.36163443233817816, 0.5235517595428973, 0.47138002468273044, 0.6503071985207498, 0.49348780245054513, 0.5689312401227653, 0.4159516270738095, 0.6201225682161748, 0.4564933438086882, 0.42563050927128643, 0.7870143034961075, 0.7321977324318141, 0.723716706270352, 0.7934955088421702, 0.9429982490837574, 0.45159689092542976, 0.6257685902528465, 1.781247875187546, 1.7077017528936267, 2.43120810482651, 23.83061695843935, 68.73563647270203, 81.35026037693024, 62.74711221456528, 53.61940160393715, 53.54386165738106, 58.397827595472336, 86.23872086405754, 121.59386292099953, 114.34860929846764, 73.32172438502312, 76.63495659828186, 60.84028713405132, 33.874395713210106, 6.3342909794300795, 0.24697438260773197, 0.6920713512226939, 1.096853418275714, 0.3767813992453739, 1.088576631154865, 0.23591065284563228, 0.03169394716678653, 0.7018705504015088, 0.11012752380338497, 0.5883624474518001, 0.4010955523699522, 0.36211872822605073, 0.2906228631036356, 0.3834436886245385, 0.1575099496403709, 0.3711733454838395, 0.3890530188800767, 0.4715347773162648, 0.5587527737952769, 0.6245438090991229, 0.3010898467618972, 0.4862006544135511, 0.3509196010418236, 0.5957362486515194, 0.37045654957182705, 0.4709341423586011, 1.0855766921304166, 0.5057294690050185, 0.7923252903856337, 0.40947404340840876, 0.6670491595286876, 0.2862794586690143, 0.4490116937085986, 0.3100059792632237, 0.25259414745960385, 0.33530466549564153, 0.4449525021482259, 0.499616606393829, 0.36843179259449244, 0.4872197122313082, 0.3441925666993484, 0.3453230654122308, 0.4233052715426311, 0.6683642452117056, 0.9912481787614524, 0.6886932731140405, 0.7563484646379948, 0.1572966415551491, 0.4247498471522704, 0.19129398133372888, 0.9893362282309681, 0.09940015763277188, 8.324627503752708, 51.1966098099947, 71.7406140267849, 59.90704581141472, 89.75085720419884, 107.94653043150902, 114.03153151273727, 85.06532862782478, 47.71761529147625, 40.916588231921196, 54.78347294032574, 70.87138026952744, 65.07533848285675, 25.064676739275455, 0.5717863712925464, 0.7394363440107554, 1.0646115546114743, 0.4095752426655963, 0.6786094454582781, 0.551054208772257, 0.5225069937296212, 0.48703346285037696, 0.45591372647322714, 0.351146906032227, 0.3565963776782155, 0.3936497925315052, 0.37282349599990994, 0.4426862800028175, 0.4346512845950201, 0.31348911579698324, 0.5392351211048663, 0.6211157399229705, 0.35531851812265813, 0.4328838747460395, 0.3369199647568166, 0.4103443451458588, 0.4843910312047228, 0.34093816007953137, 0.5259160045534372, 0.411478792084381, 0.26598575699608773, 0.36500505928415805, 0.41599758085794747, 0.6071576045360416, 0.4960691404994577, 0.2995408955030143, 0.32235576189123094, 0.38158229319378734, 0.4833750013494864, 0.5192601273301989, 0.5316273355856538, 0.3223562962375581, 0.28817484446335584, 0.31988515227567405, 0.43780514504760504, 0.44529801642056555, 0.3594344691373408, 0.5076972884126008, 0.4357175133191049, 0.5084562383126467, 0.5046847625635564, 0.5395069846417755, 0.5895852693356574, 0.550610760692507, 0.6179229612462223, 0.6112720118835568, 0.6433883041609079, 0.4989861370995641, 0.48395892314147204, 0.5872756463941187, 0.31619192857760936, 0.39443697372917086, 0.7264364103320986, 0.5060265655629337, 0.4809666727669537, 0.6011093384586275, 0.4791846574516967, 0.4852353280875832, 0.5248548521194607, 0.6463278620503843, 0.8012405619956553, 0.6105391855817288, 0.5091803963296115, 0.49491088546346873, 0.5372088798321784, 0.6258267746306956, 0.6511335354298353, 0.5313544627279043, 0.5150461534503847, 0.5582095810677856, 0.6784614315256476, 0.45592693670187145, 0.5970436159987003, 0.521843513706699, 0.601740104611963, 0.6687423842959106, 1.0305489948950708, 0.4579141706926748, 0.4795061855111271, 0.8573564852122217, 0.7797020708676428, 0.8292552712373435, 0.9683231776580215, 0.9842356550507247, 1.0934770619496703, 0.5527654231991619, 1.2733572721481323, 2.268101144582033, 1.5998833696357906, 14.633326381444931, 71.40219658613205, 110.7284827530384, 92.1426996588707, 74.16220128536224, 67.12964504957199, 64.17042464017868, 74.63644623756409, 117.4760390818119, 144.61002588272095, 126.10705554485321, 92.15686529874802, 60.2998611330986, 49.390749111771584, 20.497352220118046, 0.5704636860173196, 1.7365765222348273, 1.7108173482120037, 0.4250362567836419, 2.8851317474618554, 1.6524473740719259, 0.5018483335152268, 0.7674269482959062, 0.2079566809698008, 1.0515482118353248, 0.8111022796947509, 0.813646005699411, 0.7492551358882338, 0.7939511875156313, 0.4936576058389619, 0.9893806383479387, 0.5728229437954724, 0.9601632342673838, 0.6594271247740835, 0.7186354289297014, 0.4848403570940718, 0.8157826191745698, 0.7141866395249963, 0.6575019343290478, 0.5593536165542901, 0.6846947001758963, 3.392976396717131, 2.3110340908169746, 0.9759829728864133, 0.744014682713896, 0.9964521182700992, 0.5117865814827383, 0.6985998759046197, 0.5239865987095982, 0.4507617076160386, 0.4749713960336521, 0.5310399702284485, 0.5845742882229388, 0.655760143417865, 0.524101898772642, 0.45971337414812297, 0.4228551738196984, 0.6793517712503672, 1.233821699861437, 1.4463775441981852, 1.7486969218589365, 1.3905300409533083, 0.49951068707741797, 0.47416512679774314, 0.2703604503767565, 1.0568122356198728, 0.48183290753513575, 10.421024411916733, 57.96512581408024, 78.03685337305069, 83.3547592163086, 112.34916418790817, 125.89598447084427, 112.28266015648842, 81.22290641069412, 48.753348514437675, 53.611243441700935, 77.60196670889854, 91.9783964753151, 67.19270646572113, 15.324426647275686, 0.4053277237107977, 1.5464036143384874, 1.2925196439027786, 0.5086874915286899, 0.6292639276944101, 0.46685705019626766, 0.5136373196728528, 0.8308888273313642, 0.6248842470813543, 0.5474040890112519, 0.6888766132760793, 0.6613650207873434, 0.471228389069438, 0.6313117209356278, 0.6062647711951286, 0.4286628356203437, 0.6461838854011148, 0.8054601168259978, 0.8012774318922311, 0.4967246053274721, 0.5758405162487179, 0.5116296024061739, 0.44476981507614255, 0.6905153347179294, 0.6421184004284441, 0.4931263765320182, 0.34371738438494503, 0.36712400964461267, 0.3331516950856894, 0.6503434746991843, 0.6064290530048311, 0.3709271305706352, 0.36111457273364067, 0.5109335272572935, 0.6208404921926558, 0.6504075962584466, 0.6770540226716548, 0.5888019769918174, 0.3426208166638389, 0.5575753713492304, 0.4721843940205872, 0.5480849649757147, 0.48596245469525456, 0.5051061243284494, 0.49691554508171976], [0.3087821480585262, 0.35001887124963105, 0.42522134841419756, 0.3986107528908178, 0.47765577386599034, 0.3389417234575376, 0.3508437832351774, 0.3586565499426797, 0.29634874023031443, 0.26354863308370113, 0.22391119360690936, 0.4307922354200855, 0.35880417795851827, 0.29225576610770077, 0.30664315971080214, 0.3461832145694643, 0.3047725616488606, 0.37564380560070276, 0.2875590103212744, 0.44359398598317057, 0.3280471736798063, 0.3076061111642048, 0.1812295979470946, 0.30391665757633746, 0.38118663942441344, 0.3179693128913641, 0.5262532364577055, 0.40171563159674406, 0.28343148180283606, 0.37848459847737104, 0.3090736042940989, 0.3609000029973686, 0.38507614633999765, 0.22249097528401762, 0.36777261702809483, 0.28775594662874937, 0.3582430549431592, 0.44897859392222017, 0.46262398827821016, 0.5953435634728521, 0.42799828690476716, 0.5720880988519639, 0.501233241520822, 0.5770218372344971, 0.35658162378240377, 0.49817583058029413, 0.6304364616516978, 0.5878308322280645, 0.4076138947857544, 0.746213992824778, 2.923010727390647, 0.6054966186638921, 19.27068494260311, 51.5268424898386, 75.51555186510086, 84.34844389557838, 58.87942895293236, 46.88996650278568, 51.50747112929821, 72.05842897295952, 96.83116167783737, 114.21722754836082, 89.98933240771294, 39.526755809783936, 30.233987756073475, 29.119237773120403, 14.559732880443335, 1.383912458550185, 0.7298159727361053, 0.6455280049704015, 0.3577374742599204, 0.45506978582125157, 1.1301737115718424, 1.055490025319159, 0.27474063565023243, 0.0866106228204444, 0.13114025525283068, 0.32870275725144893, 0.07071705535054207, 0.3360271017299965, 0.27733384806197137, 0.19739128852961585, 0.4751737945480272, 0.3789463627617806, 0.145469939452596, 0.41572179878130555, 0.24980643298476934, 0.3008016262901947, 0.06154786533443257, 0.17474046646384522, 0.32759701658505946, 0.5377501726616174, 0.3861378924921155, 0.5179702746681869, 0.440709792310372, 0.7227729319129139, 0.174253172299359, 0.536386223975569, 0.30283288448117673, 0.554583091288805, 0.23580728651722893, 0.6035621662158519, 0.5854423635173589, 0.4337018699152395, 0.2980801113881171, 0.2976784610655159, 0.2642892667790875, 0.4695028957212344, 0.25735766685102135, 0.3866513696266338, 0.663392924470827, 0.0664554578543175, 0.6885379564482719, 0.4258680855855346, 0.3340813686372712, 9.433306362479925, 39.49581786990166, 71.42137035727501, 59.40122835338116, 72.53417864441872, 85.92509329319, 84.65564981102943, 64.74080443382263, 40.92412702739239, 40.32705746591091, 47.8008384257555, 64.23875257372856, 38.507148921489716, 9.573396295309067, 1.0740766092203557, 0.46095207799226046, 0.6762908573728055, 0.19438202813034877, 0.4498622246319428, 0.5721319746226072, 0.5164787953253835, 0.4528927995124832, 0.3504707501269877, 0.22880954638822004, 0.22813491930719465, 0.3907380800228566, 0.4824777151225135, 0.42449627013411373, 0.3265602659666911, 0.2871889161178842, 0.30419089598581195, 0.3044106607558206, 0.28980543196666986, 0.2815044211456552, 0.376902666175738, 0.43152206344529986, 0.24014841997995973, 0.36147190199699253, 0.46059115673415363, 0.4648790188366547, 0.407136456342414, 0.3902278980240226, 0.284260252956301, 0.36226962169166654, 0.33982784778345376, 0.27428035566117615, 0.45133129111491144, 0.28990660153795034, 0.3170441515976563, 0.3888976131565869, 0.2841210854239762, 0.4792804241878912, 0.34290301089640707, 0.312022483558394, 0.35552290559280664, 0.3257266856962815, 0.2650049049407244, 0.24371246545342728, 0.310505029046908, 0.39451602729968727, 0.30648425105027854, 0.2932064572814852, 0.4424247471615672, 0.48918575048446655, 0.5425966938491911, 0.41581382509320974, 0.3853148507187143, 0.37372018850874156, 0.34887382644228637, 0.3164993558311835, 0.3425764659186825, 0.2771647571353242, 0.32821201952174306, 0.34639594377949834, 0.3559463156852871, 0.5259303725324571, 0.35848787461873144, 0.3538686881074682, 0.4596823820611462, 0.37793680443428457, 0.6154275638982654, 0.4093557153828442, 0.47469463432207704, 0.2886177581967786, 0.44268179743085057, 0.4174818762112409, 0.38574488076847047, 0.429556232993491, 0.4016616032458842, 0.33087754680309445, 0.41208919370546937, 0.29177429038099945, 0.32411013962700963, 0.359807739732787, 0.3209682722808793, 0.41995094215963036, 0.31390320451464504, 0.48904685012530535, 0.33167066518217325, 0.5300648475531489, 0.6415772263426334, 0.40483811404556036, 0.7381194771733135, 0.5928117118310183, 0.517022522399202, 0.3607846732484177, 0.5050631985068321, 0.4351144441170618, 0.39774193544872105, 0.8019217348191887, 1.8120109057053924, 2.2066570166498423, 3.5830552596598864, 47.83337987959385, 79.13520723581314, 79.23633500933647, 70.89950636029243, 57.24839687347412, 54.431589022278786, 69.39300119876862, 94.62377652525902, 120.96052050590515, 110.25751322507858, 63.18391777575016, 53.24587784707546, 58.68533916771412, 41.94591499865055, 12.982406169176102, 0.7656435971148312, 0.6130988826043904, 0.6610533781349659, 0.9091981721576303, 0.36899163911584765, 0.8882953750435263, 0.2662683668313548, 0.4511214414378628, 0.5569036386441439, 0.47687283775303513, 0.5810294940602034, 0.2611442230409011, 0.36338150734081864, 0.4920681333169341, 0.1890556194121018, 0.2351239466224797, 0.4104306420776993, 0.25452646252233535, 0.32669943349901587, 0.27999798010569066, 0.3987647930625826, 0.15030566981295124, 0.1253253797767684, 0.3961757366778329, 0.6734358449466527, 0.30568608606699854, 0.9571949404198676, 0.3010694228578359, 0.30721963034011424, 0.19567139097489417, 0.27311064186505973, 0.15377958887256682, 0.4142161295749247, 0.04506034223595634, 0.2723288635024801, 0.35990600008517504, 0.38719459204003215, 0.32171804923564196, 0.8481525478418916, 0.22954308515181765, 0.37900226132478565, 0.3677562897792086, 0.18040860450128093, 0.325231613824144, 0.1678980133146979, 0.32859847065992653, 1.0363161354325712, 0.37691807316150516, 14.400948900729418, 49.05243046581745, 87.64059484004974, 68.8723075389862, 67.73106917738914, 87.59688958525658, 101.82718679308891, 95.92054814100266, 60.33533222973347, 46.820810213685036, 47.938577234745026, 70.2000018954277, 66.95391207933426, 31.3264462351799, 4.432844985276461, 0.7054088730365038, 0.9786559513304383, 0.49359214841388166, 0.49906812957488, 0.5002508754841983, 0.5932947609107941, 0.4928057093638927, 0.5277090333402157, 0.30535974889062345, 0.3165346523746848, 0.45908934669569135, 0.4510221123928204, 0.44383013737387955, 0.22034207184333354, 0.30638901866041124, 0.27221017924603075, 0.4330869560362771, 0.4686641797889024, 0.3064881102181971, 0.41030667372979224, 0.4687355743953958, 0.26525628520175815, 0.347043423098512, 0.40765043813735247, 0.48502975318115205, 0.3771212138235569, 0.3675473900511861, 0.32054747454822063, 0.44011743972077966, 0.24359905044548213, 0.3516785806277767, 0.35963149450253695, 0.4513853491516784, 0.3857115434948355, 0.5756595509592444, 0.28856432356406003, 0.5106860061641783, 0.40275769599247724, 0.4540708550484851, 0.3672177577391267, 0.4222677194047719, 0.28976951201912016, 0.3628806764027104, 0.43285766209010035, 0.3083721559960395, 0.3205343533772975, 0.5969526583794504, 0.6011668697465211, 0.7237614132463932, 0.6824472395237535, 0.5295010528061539, 0.5034256051294506, 0.4842844291124493, 0.6375306809786707, 0.55758599890396, 0.3781059547327459, 0.3313857695320621, 0.4868790664477274, 0.41932091815397143, 0.5123569665011019, 0.6114499492105097, 0.4899107397068292, 0.4562937654554844, 0.7206920091994107, 0.5033134517725557, 0.6543901981785893, 0.5336294719018042, 0.6640871590934694, 0.5565488326828927, 0.5829270172398537, 0.4624806944048032, 0.434924810542725, 0.7688979443628341, 0.5625547072850168, 0.4767837800318375, 0.42848917306400836, 0.383728762390092, 0.5574952787719667, 0.5179152963683009, 0.58299565105699, 0.5391963513102382, 0.6767496827524155, 0.5056117346975952, 0.6012131203897297, 0.8222188800573349, 0.9127640433143824, 0.6324214988853782, 0.7134336861781776, 0.5360691191162914, 0.7126855419483036, 0.4804385011084378, 0.5464001710060984, 0.9495198866352439, 0.5645709147211164, 0.6264814082533121, 1.0496574570424855, 3.445255416445434, 0.8989729802124202, 35.75022205710411, 86.3478434085846, 104.33611616492271, 104.9150151014328, 76.74720257520676, 70.57495817542076, 72.92998060584068, 92.52259567379951, 113.08935686945915, 135.26327222585678, 113.99873167276382, 70.30328035354614, 63.60705927014351, 54.63758356869221, 21.971059441566467, 2.1756518678739667, 0.7096990803256631, 0.8695211762096733, 0.9442534286063164, 0.7870569918304682, 2.09807594306767, 1.8392457067966461, 0.6886632309760898, 0.6012728484347463, 0.3831996110966429, 0.5644297879189253, 0.37282002274878323, 0.418352652923204, 0.5937403463758528, 0.4664625838631764, 0.7109015970490873, 0.7724508130922914, 0.5325480143073946, 1.118366438895464, 0.5680661334190518, 1.2660047854296863, 0.33847191429231316, 0.3846686182077974, 1.1554336873814464, 1.3395205093547702, 0.9679096529725939, 2.111913375556469, 1.937911449931562, 1.3265140447765589, 0.6782811786979437, 0.636656015412882, 0.5771328031551093, 0.6568848830647767, 0.3889321378665045, 0.5699331988580525, 0.8890657243318856, 0.7131291681434959, 0.8200525213032961, 1.120076822116971, 1.1739085335284472, 1.8004296021535993, 1.5584007580764592, 0.9265700087416917, 1.179306737612933, 0.5569617042783648, 0.5299211083911359, 1.0338586173020303, 0.6393931747879833, 16.61081627011299, 57.50395216047764, 99.87764060497284, 83.03532555699348, 92.59601533412933, 101.88777834177017, 107.22203090786934, 99.74802196025848, 65.02456560730934, 60.58160841464996, 69.24695983529091, 98.00851330161095, 73.61990198493004, 24.237014651298523, 1.4615450240671635, 1.4475108333863318, 1.0775472479872406, 0.5481784755829722, 0.8546093513723463, 0.7570287468843162, 0.869127600453794, 0.6490321294404566, 0.6951400428079069, 0.39693038212135434, 0.5935500597115606, 0.786909987218678, 0.8383323310408741, 0.6159068725537509, 0.6513733975589275, 0.5429385567549616, 0.4629451304208487, 0.4964821902103722, 0.47973221400752664, 0.3931371169164777, 0.5551331117749214, 0.678648155881092, 0.5586241150740534, 0.655527109047398, 0.45807851187419146, 0.8164620108436793, 0.6812821864150465, 0.5922149657271802, 0.5704842880368233, 0.5799539142753929, 0.5219122068956494, 0.481808238546364, 0.6430867547169328, 0.7102466665674001, 0.44078724284190685, 0.7369471807032824, 0.39849016873631626, 0.6550661462824792, 0.6013736024033278, 0.6120108347386122, 0.5652112397365272, 0.649357249494642, 0.42290834127925336, 0.47137687797658145, 0.4136324452701956, 0.594399314140901, 0.4443917947355658], [0.2694458869518712, 0.2276313424226828, 0.3261741413734853, 0.2620695030782372, 0.12595610140124336, 0.2583991672145203, 0.17228743090527132, 0.256499862880446, 0.22198598831892014, 0.2127116805058904, 0.20033317676279694, 0.27353672368917614, 0.21787051227875054, 0.18732282333076, 0.26857044955249876, 0.27465267630759627, 0.2693541278131306, 0.2934282406931743, 0.17785588366677985, 0.2117631712462753, 0.24824964464642107, 0.2032607267028652, 0.28104532859288156, 0.31855825160164386, 0.30002156971022487, 0.26106211182195693, 0.2543154254090041, 0.15287344140233472, 0.27198159776162356, 0.2638994314474985, 0.3575354616623372, 0.24532810610253364, 0.17426856444217265, 0.03974201550590806, 0.1934900408377871, 0.2836069551995024, 0.45311312831472605, 0.34626764128915966, 0.34938970813527703, 0.2044768544146791, 0.5085993837565184, 0.30754552222788334, 0.2873913146322593, 0.3718942974228412, 0.31493244459852576, 0.5060057854279876, 0.3168792760698125, 0.3144383820472285, 0.4751977510750294, 0.5086459312587976, 0.11549786024261266, 0.9509193396661431, 1.6060839244164526, 2.3737720493227243, 10.576094090938568, 49.3741250038147, 70.33203721046448, 90.55754631757736, 63.85345324873924, 62.802661433815956, 71.24180719256401, 80.73207154870033, 88.74508157372475, 100.45528560876846, 85.84775984287262, 71.46576717495918, 56.66404902935028, 52.8541074693203, 21.447445638477802, 1.5885782637633383, 0.13943604135420173, 1.3966683740727603, 2.726134741678834, 0.5175094306468964, 0.5258746817708015, 1.0197337064892054, 0.8003241580445319, 0.7572157680988312, 0.3915440523996949, 0.599097702652216, 0.49966796301305294, 0.6822462659329176, 1.3332147477194667, 0.6016258138697594, 5.1418323162943125, 4.069529380649328, 1.3977148616686463, 1.0104096005670726, 1.2463729013688862, 0.28597105178050697, 1.086038367357105, 0.77665421878919, 0.3840351803228259, 1.3261168473400176, 0.7632238394580781, 0.40828153083566576, 0.38248812896199524, 0.9920555760618299, 0.6153787602670491, 1.2981238681823015, 1.7071320209652185, 1.0354287642985582, 0.7595074607525021, 0.3058617078932002, 0.3878243488725275, 0.3563471348024905, 0.5063018132932484, 0.5620733206160367, 0.20646474149543792, 0.17823776317527518, 0.18832887872122228, 0.07619409036124125, 0.5021061259321868, 9.597386308014393, 34.791202917695045, 68.16666260361671, 91.06699258089066, 66.53936192393303, 83.89008209109306, 77.3491282761097, 59.56106297671795, 49.43975128233433, 41.04598268866539, 56.65983885526657, 68.65893378853798, 63.75485613942146, 23.935649022459984, 1.0543578048236668, 0.6233250838704407, 0.2842699008760974, 0.3151838545454666, 0.4131352360127494, 0.6663896574173123, 0.31227623869199306, 0.15748845704365522, 0.0683223303349223, 0.239577975589782, 0.1875531711266376, 0.19758292590267956, 0.20538159180432558, 0.10992542214808054, 0.24830852664308622, 0.45080323820002377, 0.2712593099568039, 0.13889400637708604, 0.15160689217736945, 0.16610229795332998, 0.15184601215878502, 0.336822773097083, 0.40949197369627655, 0.24102771654725075, 0.24244747473858297, 0.24541271093767136, 0.2935036725830287, 0.28364848578348756, 0.30048306682147086, 0.23910770629299805, 0.30264933651778847, 0.16596118599409238, 0.13678516406798735, 0.2225951579748653, 0.16443072905531153, 0.11201768487808295, 0.0858794069790747, 0.09746746407472529, 0.19082653219811618, 0.18104149319697171, 0.2776094520231709, 0.3702982049435377, 0.23264983406988904, 0.3013818373437971, 0.379427868174389, 0.22590092121390626, 0.18550901440903544, 0.16322727722581476, 0.1883752629510127, 0.3200731234392151, 0.24470750737236813, 0.5086292477790266, 0.4353218001779169, 0.36401815130375326, 0.2378266555024311, 0.3134576487354934, 0.43154981976840645, 0.2663159533403814, 0.357082900009118, 0.284512197249569, 0.255609760642983, 0.2752599905943498, 0.2556193491909653, 0.10202587611274794, 0.25191425113007426, 0.2597413561306894, 0.30763909220695496, 0.2659566351212561, 0.17258213774766773, 0.2654967410489917, 0.2673315675929189, 0.24137098953360692, 0.3690574230859056, 0.28343471756670624, 0.38989488151855767, 0.3222672385163605, 0.2497124474029988, 0.3236791893141344, 0.2677909273188561, 0.319986529648304, 0.2702766767470166, 0.2629620989318937, 0.13467185402987525, 0.34686934493947774, 0.21998527692630887, 0.42515657376497984, 0.4613113962113857, 0.5188410810660571, 0.35420497006271034, 0.5569134349934757, 0.30934196489397436, 0.31444381456822157, 0.4124095046427101, 0.6914487783797085, 0.47521942178718746, 0.45560392434708774, 0.4473004792816937, 0.3752151707885787, 0.5641372036188841, 0.8287551824469119, 1.5132404188625515, 3.264901419170201, 10.648674946278334, 42.60947339236736, 83.8916552066803, 83.75275745987892, 85.66137224435806, 67.54311606287956, 72.60364651679993, 76.53175413608551, 99.37464639544487, 113.90602424740791, 88.25348675251007, 70.68642139434814, 73.44775602221489, 81.31979361176491, 69.11083593964577, 28.8805003836751, 5.364970117807388, 0.17196602158946916, 3.0940545117482543, 2.507054884918034, 1.758793336339295, 1.2077250564470887, 0.11179455817909911, 0.4253690654877573, 0.23099941638065502, 0.3952192864380777, 1.2212969781830907, 1.9241973920725286, 2.3740178486332297, 9.14706202223897, 4.401590712368488, 3.1346987932920456, 2.2983617708086967, 1.7047008639201522, 2.1333648869767785, 1.7776616988703609, 1.9081939570605755, 0.9484215080738068, 0.10101269610458985, 0.08022230467759073, 0.6932639528531581, 0.21306737704435363, 0.5029798415489495, 0.37426744820550084, 0.4405021690763533, 0.45928319566883147, 0.5055189365521073, 0.7847279543057084, 0.8362721290905029, 0.08177349722245708, 0.38201134360861033, 0.8989478065632284, 1.3258360186591744, 0.9195926925167441, 0.48668165516573936, 0.30339299817569554, 0.3550833463668823, 0.38728121551685035, 0.3238591749686748, 0.2801348321372643, 16.628791205585003, 65.54659679532051, 100.06202951073647, 92.9445706307888, 70.21975323557854, 78.78844544291496, 92.2047883272171, 80.885970890522, 71.8310795724392, 48.69938001036644, 58.02317149937153, 72.38535583019257, 84.01441141963005, 49.843658208847046, 8.161565903574228, 0.4885303450282663, 0.5180156347341835, 0.48802847508341074, 0.3351936105173081, 0.626834670547396, 0.4603188479086384, 0.2975940046599135, 0.22949661186430603, 0.3982947760960087, 0.18422123976051807, 0.09057240749825723, 0.2868056413717568, 0.1964800202404149, 0.4456794209545478, 0.4592069919453934, 0.40582623914815485, 0.2381608891300857, 0.3417095186887309, 0.29734033858403563, 0.19745920988498256, 0.295256981626153, 0.34826781833544374, 0.35845011414494365, 0.37307318416424096, 0.2874128962866962, 0.26723217917606235, 0.27525622048415244, 0.3306712000630796, 0.3884270618436858, 0.33399741689208895, 0.28057151183020324, 0.289636044180952, 0.23579318571137264, 0.2771674288669601, 0.2676709368824959, 0.2119269038666971, 0.32233219128102064, 0.4205254832049832, 0.33884367090649903, 0.37497827725019306, 0.34078311058692634, 0.2804187481524423, 0.37226685555651784, 0.2889334678184241, 0.33166377805173397, 0.29189727909397334, 0.28844080050475895, 0.3174283169209957, 0.5300891306251287, 0.536050001392141, 0.5302432598546147, 0.5318889871705323, 0.4437175387283787, 0.47876712516881526, 0.42690433154348284, 0.5274277890566736, 0.4997339250985533, 0.49681075382977724, 0.31659696309361607, 0.38858974061440676, 0.6110599951352924, 0.46788658713921905, 0.3766963491216302, 0.44351591204758734, 0.4391945048701018, 0.5312764481641352, 0.39477574930060655, 0.42428995308000594, 0.42288575030397624, 0.42239153932314366, 0.5189602402970195, 0.47475931991357356, 0.5297289218287915, 0.44734575028996915, 0.5577386438380927, 0.4948088846867904, 0.4463197459699586, 0.46568142890464514, 0.653916351730004, 0.43556673859711736, 0.3275402868166566, 0.3860746615100652, 0.614740988239646, 0.4107907024445012, 0.5644612549804151, 0.5831091105937958, 0.6128406745847315, 0.5616575991734862, 0.9515224979259074, 0.5979839467909187, 0.3956245584413409, 0.5192582274321467, 0.8237611223012209, 0.6354605639353395, 0.5845938215497881, 0.6424653099384159, 0.7883017812855542, 0.997581013944, 0.5617747991345823, 1.5424368646927178, 1.7851628526113927, 3.6836035642772913, 28.08920994400978, 83.64750310778618, 105.53719371557236, 116.57013729214668, 86.63049504160881, 80.98176375031471, 90.63516095280647, 95.27389883995056, 109.35882344841957, 117.08067789673805, 107.56669521331787, 103.92806366086006, 83.33703696727753, 74.73183631896973, 32.821859791874886, 7.7093046717345715, 0.23652296920772642, 4.153625043109059, 6.621219282969832, 1.8205450102686882, 1.393983936868608, 1.7402131645940244, 1.1849898076616228, 1.1114641092717648, 0.7672551262658089, 1.5639203181490302, 2.540245153941214, 1.872410208452493, 5.256941439583898, 8.526691161096096, 9.994204714894295, 8.746182583272457, 4.444107580929995, 3.880374343134463, 2.1575237531214952, 1.9179057609289885, 1.6250284016132355, 1.2931988574564457, 0.6309745484031737, 4.244368448853493, 2.248412501066923, 1.5259596426039934, 0.7331676303874701, 0.8758180914446712, 2.346531548537314, 2.2748768934980035, 1.6473807021975517, 1.5040838601998985, 1.7935927002690732, 1.3120445399545133, 2.1521966764703393, 2.6773301605135202, 2.276345514692366, 1.029656280297786, 0.6559776817448437, 0.357656609849073, 0.6699394388124347, 0.5208769405726343, 1.7241386021487415, 19.952957332134247, 62.50158838927746, 101.74345448613167, 126.44676491618156, 93.61914083361626, 100.81850811839104, 100.78158169984818, 86.99663579463959, 77.63360381126404, 63.079005405306816, 80.21137028932571, 99.5544983446598, 96.65656104683876, 45.365359112620354, 4.166301637887955, 1.1432972573675215, 0.8089085505343974, 0.635491021675989, 0.6751483061816543, 0.85057741147466, 0.5901425331830978, 0.6771852937527001, 0.5821234791073948, 0.6310949544422328, 0.42330331227276474, 0.5379741231445223, 0.4539632733212784, 0.4576234269188717, 0.5123997142072767, 0.7922276831232011, 0.8987885119859129, 0.3492582292528823, 0.5065015994478017, 0.5073186149820685, 0.32246289832983166, 0.5241412029135972, 0.6283534015528858, 0.6795069691725075, 0.6843109801411629, 0.42422108177561313, 0.5604276526719332, 0.37941661721561104, 0.45373510743957013, 0.47952797496691346, 0.48949754156637937, 0.4038738564122468, 0.6883404857944697, 0.44439416960813105, 0.37307745893485844, 0.3838990704389289, 0.3041746577946469, 0.5832758266478777, 0.3720992192393169, 0.44174882874358445, 0.6237149785738438, 0.5468932539224625, 0.44260111113544554, 0.7006485597230494, 0.5421847722027451, 0.6396939523983747, 0.45345721766352654, 0.4106046608649194, 0.5518898670561612], [0.15640661353245378, 0.04577795451041311, 0.23836719134123996, 0.20094148552743718, 0.13506670627975836, 0.14131532254396006, 0.12782238016370684, 0.20240911224391311, 0.2516498090699315, 0.3267254977254197, 0.18785568536259234, 0.25227241159882396, 0.2030255104182288, 0.12825111887650564, 0.20741859421832487, 0.13531759672332555, 0.12454962765332311, 0.2614872733829543, 0.1556187347159721, 0.13541814289055765, 0.28915685426909477, 0.20928248326526955, 0.18945254967547953, 0.27462397003546357, 0.22587681625736877, 0.26325091312173754, 0.23833127139369026, 0.2993751590838656, 0.17405835853423923, 0.10062360292067751, 0.08947598820668645, 0.1242600564728491, 0.09335254464531317, 0.082864795695059, 0.16992544202366844, 0.1664747076574713, 0.10951708507491276, 0.13971928943647072, 0.13824536930769682, 0.28593115392141044, 0.2679152222117409, 0.3408641827991232, 0.2314384709461592, 0.33525333856232464, 0.18212118447991088, 0.12590201367856935, 0.35476169956382364, 0.2663753548404202, 0.34505200339481235, 0.29991392861120403, 0.46026752097532153, 0.02689878074306762, 0.08664396009407938, 0.8395236264914274, 1.1247876193374395, 0.19635143573395908, 1.9810666842386127, 18.51737156510353, 82.10576623678207, 88.61640527844429, 73.59433695673943, 55.218344405293465, 65.77818676829338, 61.484584361314774, 78.3379416167736, 88.0079211294651, 77.79158413410187, 84.36915278434753, 68.19656699895859, 41.23911492526531, 29.280590415000916, 14.384668674319983, 4.078452726826072, 0.5746567610185593, 0.9462515276391059, 0.8386243809945881, 0.14632513106334955, 0.2692485350416973, 0.36088070715777576, 0.9272879920899868, 3.1699093664065003, 3.3960817800834775, 10.38987273350358, 1.23621070291847, 0.1809743288322352, 0.3423416503937915, 0.555290209595114, 1.2870313134044409, 1.7864862503483891, 1.0521109378896654, 0.4544491128763184, 0.5311041511595249, 0.14417762286029756, 0.11953250897931866, 0.10593597020488232, 0.29177559656091034, 0.10821540257893503, 0.19112906127702445, 0.6849161570426077, 0.4250849416712299, 0.4709837771952152, 1.386874399613589, 1.1000245856121182, 1.10716060269624, 1.0745360283181071, 1.0731499339453876, 0.9738589462358505, 0.8366809040307999, 1.430569204967469, 2.547761625610292, 7.394601283594966, 12.493520602583885, 26.936462000012398, 32.046446800231934, 38.01413297653198, 61.70335382223129, 96.33336558938026, 77.66618326306343, 62.5100277364254, 56.457906290888786, 46.599054113030434, 57.165416926145554, 63.387461453676224, 80.61632215976715, 34.33793283998966, 7.519913809373975, 0.365603556856513, 0.5877352436073124, 0.29378034523688257, 0.15439474023878574, 0.3998272813623771, 0.40771853760816157, 0.3872092568781227, 0.3986526693915948, 0.12868388002971187, 0.06003576912917197, 0.14302842202596366, 0.1782118622213602, 0.15374751324998215, 0.21446507860673591, 0.28225378249771893, 0.2716981864068657, 0.21110938367201015, 0.32479965419042856, 0.18176467157900333, 0.12266167817870155, 0.12799184216419235, 0.10145127569558099, 0.07532121337135322, 0.10503463927307166, 0.1569419543375261, 0.13934027461800724, 0.1083143828145694, 0.08500266339979135, 0.24670194019563496, 0.19579905521823093, 0.18499524041544646, 0.316025004722178, 0.19644718762720004, 0.09815354249440134, 0.3314639028394595, 0.1795251964358613, 0.1240629272069782, 0.09734101695357822, 0.18648818921064958, 0.2121052419533953, 0.1075295171176549, 0.1320031503564678, 0.1203592392266728, 0.20786854351172224, 0.1113648027239833, 0.2891935460502282, 0.16365825722459704, 0.23621993546839803, 0.26164202601648867, 0.14230227505322546, 0.21177397691644728, 0.21901327127125114, 0.2471404752577655, 0.1668202961445786, 0.30560329207219183, 0.32490272365976125, 0.2445165379322134, 0.19079252699157223, 0.2097476614289917, 0.18697892694035545, 0.1917595454142429, 0.06029759511875454, 0.23749871528707445, 0.16276395443128422, 0.1299054254195653, 0.28637611598242074, 0.1224776849267073, 0.1366144701023586, 0.2645642473362386, 0.17369524051900953, 0.2773382712621242, 0.1701747442712076, 0.19417064962908626, 0.2393625004333444, 0.35615815431810915, 0.26528044953010976, 0.41963817144278437, 0.3401725011644885, 0.28586329193785787, 0.1465074173756875, 0.15374999202322215, 0.12104298730264418, 0.12718704238068312, 0.110122915066313, 0.266603312920779, 0.27710547437891364, 0.1430150485248305, 0.21385625033872202, 0.19764217897318304, 0.17367069027386606, 0.3114686632761732, 0.26830422633793205, 0.199066330678761, 0.17539089953061193, 0.14595669927075505, 0.30230857199057937, 0.23114012758014724, 0.42598439496941864, 0.2777936530765146, 0.2069664333248511, 0.39822691411245614, 0.3607978537911549, 0.6116886239033192, 1.3949271175079048, 2.2692094976082444, 5.0578083749860525, 28.83482113480568, 69.32976499199867, 94.96079564094543, 91.7876087129116, 85.91790407896042, 67.6561751961708, 77.62307837605476, 90.73918417096138, 106.87071695923805, 106.67707175016403, 75.391845703125, 83.52281659841537, 89.89226281642914, 70.92258632183075, 51.66887126863003, 25.261888056993484, 7.530385572463274, 1.2966655776835978, 1.2206304701976478, 0.5450828885659575, 0.3523801179835573, 0.3421266650548205, 0.2971762348897755, 0.5433275015093386, 1.0993536841124296, 2.065089913085103, 1.9389554439112544, 0.7834014692343771, 0.16340953385224566, 0.3288113186135888, 0.689925653859973, 1.1771383602172136, 1.6628072806634009, 1.9850092101842165, 0.981668655294925, 0.48386107839178294, 0.35647196404170245, 0.2042155442177318, 0.057742774006328546, 0.20041435287566856, 0.22024698788300157, 0.18022983596893027, 0.1961545439553447, 0.49852066207677126, 0.8488615066744387, 0.7277577894274145, 0.8686243055853993, 0.6210390315391123, 0.16202661587158218, 0.6276658759452403, 0.4291502188425511, 0.237839910259936, 0.6146575708407909, 2.462573521770537, 8.399429339915514, 18.31436175853014, 44.686909317970276, 63.193835243582726, 44.87769328057766, 55.56765966117382, 113.26312154531479, 97.21187844872475, 92.6599583029747, 80.51565036177635, 57.848749458789825, 59.467306807637215, 71.49195536971092, 96.46119832992554, 63.500482589006424, 23.673521988093853, 1.579851082060486, 0.2556581486715004, 0.6857360224239528, 0.1736190219526179, 0.35348671954125166, 0.26196839287877083, 0.16441003797808662, 0.08032848374568857, 0.17468171805376187, 0.07967924553668126, 0.2113027428276837, 0.12908863252960145, 0.0872539535339456, 0.13677009847015142, 0.24133836472174153, 0.3221918659983203, 0.3100014670053497, 0.20555872761178762, 0.2589640306541696, 0.1999750459799543, 0.23420773562975228, 0.1905842506675981, 0.12932509562233463, 0.25141128280665725, 0.15851818694500253, 0.2872290514642373, 0.36729197250679135, 0.1836397818988189, 0.129304078000132, 0.18852035282179713, 0.20413828664459288, 0.4054695926606655, 0.2894822118105367, 0.22483386128442362, 0.21673014300176874, 0.20865667465841398, 0.20442505250684917, 0.26966155506670475, 0.25164526712615043, 0.26963590644299984, 0.2572988293832168, 0.23773243243340403, 0.30723284056875855, 0.2820073894690722, 0.08313538273796439, 0.1620025554439053, 0.2544457168551162, 0.26681102521251887, 0.18261742894537747, 0.19463642151094973, 0.3825879032956436, 0.44029573327861726, 0.5476413981523365, 0.3650606016162783, 0.5694104300346226, 0.5552128481213003, 0.47090154723264277, 0.44594795966986567, 0.38446173712145537, 0.581140163121745, 0.4722065990790725, 0.36155618028715253, 0.6144122465047985, 0.40689683170057833, 0.43156870000530034, 0.5004810006357729, 0.2125156347756274, 0.4059864243026823, 0.5204543319996446, 0.39544344472233206, 0.5865868146065623, 0.4876394709572196, 0.48361049965023994, 0.8061057259328663, 0.6606408627703786, 0.495894854539074, 0.6896435189992189, 0.3908999572740868, 0.41363894648384303, 0.584475256036967, 0.35785286338068545, 0.50326939788647, 0.5426896701101214, 0.38393677154090255, 0.3725741937523708, 0.46188629348762333, 0.5984674114733934, 0.5155585322063416, 0.48236378061119467, 0.6119472475256771, 0.5295585840940475, 0.4668550018686801, 0.5196433130186051, 0.6586956046521664, 0.4481348016997799, 0.49123731383588165, 0.5980887974146754, 0.5666787922382355, 0.6668499670922756, 0.6149000453297049, 0.6987439119257033, 0.4909661033889279, 0.3581739164656028, 1.9111025822348893, 1.7020279448479414, 1.2307070544920862, 16.089569739997387, 59.646349400281906, 118.08174178004265, 109.8199363052845, 95.72963878512383, 75.46382144093513, 84.01811242103577, 80.45353889465332, 94.10647228360176, 108.85228782892227, 88.05956795811653, 109.66982156038284, 108.087487667799, 74.86628830432892, 55.079667046666145, 25.426018349826336, 8.269348070025444, 0.8392351388465613, 2.093265876173973, 0.957661543507129, 0.44178109732456505, 0.3862689557718113, 0.6865381356328726, 1.2289908528327942, 4.010785482823849, 8.525922652333975, 19.390578009188175, 1.749899082351476, 0.3477504523470998, 0.6847033090889454, 1.470946075860411, 2.5154536217451096, 3.9345325995236635, 4.466005805879831, 4.99610111117363, 1.256684004329145, 0.44921554683241993, 0.31891492777504027, 0.23008639662293717, 0.5349459231365472, 0.3633199684554711, 0.26206368464045227, 0.5219486611895263, 0.8321378321852535, 0.9266508731525391, 1.5249049616977572, 1.982250795699656, 1.3892375165596604, 0.6992388353683054, 1.396662793122232, 1.1621125414967537, 1.1616829270496964, 1.8350564315915108, 4.3233937583863735, 14.382991064339876, 28.220810182392597, 55.29176786541939, 66.4679029583931, 61.347639709711075, 81.58131837844849, 119.2844608426094, 99.04293939471245, 92.41533502936363, 91.38454154133797, 70.48599734902382, 77.98329144716263, 92.45830312371254, 114.88073274493217, 64.04218912124634, 15.133868772536516, 0.5735807062592357, 1.2152621895074844, 0.7614744489546865, 0.46076440368779004, 1.0414329171180725, 0.5391631624661386, 0.47460444853641093, 0.5393846787046641, 0.3217591642169282, 0.34968879364896566, 0.4555669950786978, 0.5119187431409955, 0.3600205580005422, 0.6990214751567692, 0.46822073170915246, 0.5799067136831582, 0.40757096896413714, 0.49555325880646706, 0.540632139891386, 0.4804266564315185, 0.5487531947437674, 0.5358046176843345, 0.3100526751950383, 0.33646271273028105, 0.3731759270885959, 0.45472017489373684, 0.506844234187156, 0.34646576503291726, 0.4530642949976027, 0.48116025456693023, 0.3739727265201509, 0.5570251727476716, 0.4350045172031969, 0.2932988991960883, 0.7184237684123218, 0.6250644999090582, 0.43671810650266707, 0.440598024870269, 0.6512312614358962, 0.720427151536569, 0.48899213899858296, 0.5229245556984097, 0.7477835461031646, 0.6243336922489107, 0.5230798129923642, 0.5213899724185467, 0.39836964395362884, 0.45943334698677063, 0.5935983883682638, 0.28365077159833163], [0.074026633228641, 0.12226649196236394, 0.0917081160878297, 0.038569741300307214, 0.15936218696879223, 0.053305821857065894, 0.009176248768199002, 0.11049638604163192, 0.07753537385724485, 0.11917696829186752, 0.12938256753841415, 0.15274867153493688, 0.09579024743288755, 0.24550139758503065, 0.09289484733017161, 0.1578882074682042, 0.13466409116517752, 0.011433710787969176, 0.23295266000786796, 0.17331846698652953, 0.03300452430266887, 0.017954370559891686, 0.15956474875565618, 0.0851566664641723, 0.15105797006981447, 0.14242207253118977, 0.07170211538323201, 0.2707961207488552, 0.20382477378007025, 0.08429617591900751, 0.0977843240252696, 0.03046202655241359, 0.033403302513761446, 0.027363257577235345, 0.03208720008842647, 0.18773296382278204, 0.21070393355330452, 0.10588309218292125, 0.0460317875695182, 0.08234050546889193, 0.054624410477117635, 0.1403684460092336, 0.17734576103975996, 0.1822335901670158, 0.24985606782138348, 0.28665661811828613, 0.19028443784918636, 0.0757979170884937, 0.29513749585021287, 0.21968147135339677, 0.13289087772136554, 0.21092438109917566, 0.23487725673476234, 0.16796504409285262, 0.06017785330186598, 0.8406128617934883, 1.2181714083999395, 2.256141761317849, 6.2750844564288855, 58.134345933794975, 83.3688260614872, 78.25502246618271, 71.4401413500309, 69.09420803189278, 69.36599984765053, 69.70421209931374, 71.16504371166229, 83.32891300320625, 86.13688632845879, 89.43282186985016, 58.86950768530369, 36.58587321639061, 38.321126103401184, 37.5944758951664, 26.73508420586586, 13.81752535700798, 5.211504902690649, 2.844979539513588, 3.491500597447157, 4.990655528381467, 6.398867564275861, 10.753090493381023, 19.16960846632719, 24.758722856640816, 23.55662126094103, 20.469720102846622, 10.170474406331778, 3.8625494996085763, 3.3781940024346113, 3.9033669093623757, 1.173768297303468, 1.3511032378301024, 1.7500538052991033, 3.5237554041668773, 4.808172695338726, 11.301006842404604, 6.430775402113795, 3.885901621542871, 5.8573785703629255, 3.3573886938393116, 4.254456432536244, 5.3115730080753565, 4.818256879225373, 6.191547363996506, 8.778203465044498, 14.474932830780745, 21.07354950159788, 27.80170027166605, 28.291226103901863, 28.979572467505932, 35.83382897078991, 38.071829080581665, 40.00090576708317, 57.25281223654747, 88.6122938990593, 88.41827630996704, 59.44254353642464, 52.12637051939964, 53.27517047524452, 53.16654570400715, 72.09960356354713, 75.99833115935326, 60.23054525256157, 16.758827827870846, 0.591959785670042, 0.7683321309741586, 0.22948412894038484, 0.18351934617385268, 0.11884490915690549, 0.20463177032070234, 0.1351816501119174, 0.17810352350352332, 0.13822096749208868, 0.2319877195986919, 0.1920391124440357, 0.1198251303867437, 0.13851720315869898, 0.10576509812381119, 0.02938463778264122, 0.0812979660986457, 0.040158445699489675, 0.12042548332829028, 0.051187802891945466, 0.0935547130939085, 0.053050626956974156, 0.1632410366437398, 0.12994259217521176, 0.15020156133687124, 0.02136158353096107, 0.05145957366039511, 0.06197005830472335, 0.09520037361653522, 0.004989502431271831, 0.055716592105454765, 0.006468580022556125, 0.057918180609703995, 0.07509156319429167, 0.12783496698830277, 0.11815373960416764, 0.1538848550990224, 0.1480126561364159, 0.08983779262052849, 0.05325366000761278, 0.15209258330287412, 0.14928469725418836, 0.13375510869082063, 0.13378365169046447, 0.02483349322574213, 0.041562811748008244, 0.0322230613528518, 0.08149021203280427, 0.1526237532380037, 0.09560937120113522, 0.1079720226698555, 0.13932789559476078, 0.16819757380289957, 0.044517843416542746, 0.20287982682930306, 0.15430510364240035, 0.10023600145359524, 0.14205942949047312, 0.14430515351705253, 0.16560504416702315, 0.13194156694225967, 0.13512897246982902, 0.16044104704633355, 0.11681823001708835, 0.2235849158023484, 0.11286764434771612, 0.17152646236354485, 0.12098640596377663, 0.10926476970780641, 0.09041544326464646, 0.13292748044477776, 0.21314138401066884, 0.15980544209014624, 0.2090680768014863, 0.28314343944657594, 0.31518346862867475, 0.4273349849972874, 0.37419845815747976, 0.32009494258090854, 0.28534999291878194, 0.1624688765150495, 0.30313660099636763, 0.0565990724862786, 0.2139236670336686, 0.17018399143125862, 0.12688347429502755, 0.17854922771221027, 0.1680633341311477, 0.2837629249552265, 0.15713531349319965, 0.11265093722613528, 0.14264971890952438, 0.17622372281039134, 0.0566721962968586, 0.12293500374653377, 0.25000541761983186, 0.1675948459887877, 0.3955209843115881, 0.0742724102747161, 0.11263333348324522, 0.17257804109249264, 0.16969130927463993, 0.045197665531304665, 0.07833522351575084, 0.09972440195269883, 0.12111519085010514, 0.2115236801910214, 0.530682789394632, 1.4359405729919672, 2.7554610930383205, 4.449528465047479, 33.71121346950531, 93.47766682505608, 94.90807726979256, 83.36064130067825, 71.7411307990551, 65.29809772968292, 65.98146066069603, 79.24548491835594, 92.83113911747932, 112.86829993128777, 105.68173795938492, 96.31055161356926, 80.01175940036774, 68.62668871879578, 65.16312897205353, 60.93501605093479, 46.1111830919981, 29.9125250056386, 15.78417157754302, 10.904512368142605, 13.683623392134905, 12.318123914301395, 14.718424715101719, 19.931448586285114, 31.226091720163822, 39.834030121564865, 39.790005683898926, 39.268650859594345, 27.48880036175251, 19.086176343262196, 6.838645990937948, 3.4593101497739553, 2.754059680737555, 7.517270101234317, 11.03766007348895, 14.940895177423954, 20.115206725895405, 29.935090094804764, 22.796365655958652, 19.75986499339342, 19.715690463781357, 13.674160949885845, 10.147181656211615, 10.899267699569464, 11.346535999327898, 12.80716622248292, 16.413496658205986, 26.404249258339405, 32.65250287950039, 41.75252817571163, 48.67069914937019, 48.93495596945286, 67.6815502345562, 62.046654000878334, 62.515613436698914, 58.58311325311661, 85.69788828492165, 103.93826231360435, 83.97187650203705, 64.64852258563042, 58.98607783019543, 59.74958226084709, 74.44242864847183, 87.64414384961128, 79.35201600193977, 36.80540643632412, 3.5104128951206803, 0.8245708944741637, 0.5681072187144309, 0.15441452589584514, 0.2009793053730391, 0.3919525898527354, 0.12278634414542466, 0.11684755227179267, 0.11666096892440692, 0.1352533118915744, 0.1613440181245096, 0.08315392158692703, 0.22941363975405693, 0.12137839352362789, 0.15963094832841307, 0.1757450375589542, 0.1157394218898844, 0.1254279594286345, 0.10896750245592557, 0.07645952689927071, 0.08266558841569349, 0.3441071306588128, 0.16354622261133045, 0.17083479557186365, 0.050004318545688875, 0.12311953876633197, 0.08399938364163972, 0.057785796307143755, 0.0626329223450739, 0.13982517906697467, 0.10783911144244485, 0.07705169395194389, 0.10607617674395442, 0.007543252531831968, 0.007761401739116991, 0.16616367356618866, 0.1856792630860582, 0.19372340175323188, 0.08392665316932835, 0.19961902289651334, 0.07477480714442208, 0.07896794151747599, 0.1436814377666451, 0.15697974449722096, 0.1320423505967483, 0.1645802569692023, 0.2141846061567776, 0.2439203707035631, 0.10353256948292255, 0.20745359390275553, 0.21978155738906935, 0.11687426216667518, 0.28482455236371607, 0.38227973389439285, 0.27690735063515604, 0.23853813763707876, 0.37856641283724457, 0.25915440637618303, 0.39875110785942525, 0.2764581731753424, 0.34310009563341737, 0.42844657378736883, 0.505036540562287, 0.5631567374803126, 0.48111795214936137, 0.458571802591905, 0.28831514006014913, 0.30331349931657314, 0.2725252654636279, 0.3416803077561781, 0.450803802232258, 0.38890426279976964, 0.4000256722792983, 0.4913692973786965, 0.7200845761690289, 0.48357760766521096, 0.4540243372321129, 0.4364893172169104, 0.3938057622872293, 0.4021852626465261, 0.40576674859039485, 0.25896554463543, 0.4898090654751286, 0.3415128495544195, 0.35517124633770436, 0.31284810800570995, 0.3647414187435061, 0.46782620600424707, 0.2623603359097615, 0.2219195364159532, 0.3594521025661379, 0.26819708989933133, 0.3211752721108496, 0.3354322852101177, 0.4815920360852033, 0.5133419448975474, 0.6293806526809931, 0.5233770282939076, 0.7145839557051659, 0.7564055803231895, 0.8919448417145759, 0.6497152021620423, 0.5467765289358795, 0.5872847302816808, 0.6214098678901792, 0.3102726477663964, 0.3436820878414437, 1.6554514691233635, 3.2459337869659066, 2.1147646475583315, 17.559629157185555, 90.15721499919891, 116.65569350123405, 101.64883956313133, 92.38016411662102, 86.43339961767197, 85.67128211259842, 90.93449369072914, 90.0319205224514, 99.88819643855095, 93.67024049162865, 104.67631191015244, 105.50041168928146, 89.41897541284561, 82.40401223301888, 75.89957445859909, 49.73610877990723, 24.35060005635023, 11.171744428575039, 7.463929513469338, 10.129603799432516, 8.043186105787754, 11.387844532728195, 17.471418790519238, 32.555205300450325, 38.062249794602394, 35.302951857447624, 39.475295171141624, 31.95426754653454, 27.210693284869194, 14.016683120280504, 10.305851642042398, 9.559001717716455, 12.702968213707209, 18.550211302936077, 24.122836478054523, 33.1373530626297, 38.360993564128876, 27.608155757188797, 24.06700987368822, 21.141569651663303, 13.20361889898777, 7.353605283424258, 6.267929440364242, 7.430432885885239, 9.265186283737421, 11.832569818943739, 23.84382124990225, 32.414221465587616, 44.90115702152252, 56.73741169273853, 72.73813650012016, 82.57663697004318, 83.89323592185974, 82.43171274662018, 81.29321783781052, 107.84271240234375, 116.92804768681526, 89.13150563836098, 81.37999758124352, 74.32709723711014, 70.99271535873413, 95.66771730780602, 109.98426988720894, 84.28644642233849, 26.25242840498686, 1.1841855570673943, 0.9967887564562261, 0.8993898890912533, 0.3627921233419329, 0.5817418964579701, 0.6244874652475119, 0.3733718837611377, 0.341539210639894, 0.4271395329851657, 0.4498192691244185, 0.4724861215800047, 0.33664430142380297, 0.3400926460744813, 0.3382268571294844, 0.3706329729175195, 0.2901480963919312, 0.2815054007805884, 0.3238343575503677, 0.19678479060530663, 0.31722971820272505, 0.2170864332583733, 0.4090150399133563, 0.43856771662831306, 0.35506078507751226, 0.18847393890609965, 0.21125147526618093, 0.23971374408574775, 0.22809932590462267, 0.1835036274860613, 0.34181870345491916, 0.3221001959173009, 0.2659709734143689, 0.420624099788256, 0.3047486051218584, 0.28625888633541763, 0.533818214898929, 0.4388011962873861, 0.4240401758579537, 0.4276215430581942, 0.5698196799494326, 0.3447217179927975, 0.3596608538646251, 0.3111288486979902, 0.29587088618427515, 0.3198849147884175, 0.33063723938539624, 0.49457620654720813, 0.418965132557787, 0.47227888426277786, 0.31371793476864696, 0.2518222841899842, 0.33555043512023985], [0.08097488695057109, 0.010840920331247617, 0.036748885686392896, 0.06281538677285425, 0.0733265801682137, 0.046656657359562814, 0.03848809021292254, 0.11646216982626356, 0.11516481405124068, 0.07309877051739022, 0.07414735839120112, 0.14418934879358858, 0.0722441503603477, 0.0982390007993672, 0.08033897029235959, 0.11942554323468357, 0.09996731430874206, 0.10831100604264066, 0.056617025038576685, 0.11814083365607075, 0.1570733738481067, 0.17947948013897985, 0.1445240425528027, 0.16400555265136063, 0.12603073177160695, 0.11976448950008489, 0.09997045359341428, 0.14850596169708297, 0.11630520559265278, 0.10533264867262915, 0.09196366721880622, 0.16434741555713117, 0.16402290406404063, 0.19530761986970901, 0.15182690927758813, 0.09043370751896873, 0.07454676000634208, 0.12551388528663665, 0.0702623043616768, 0.04405181920446921, 0.10144860396394506, 0.07419069981551729, 0.12844956916524097, 0.10760310105979443, 0.29653222882188857, 0.2763024705927819, 0.39994510472752154, 0.22845070314360783, 0.0789195386460051, 0.013234328962425934, 0.4079939634539187, 0.1642752342741005, 0.10802000251715071, 0.5108379980083555, 0.5103009799495339, 0.10704102809540927, 0.16292675194563344, 0.18274206522619352, 2.3651351127773523, 0.8630985708441585, 9.668641984462738, 39.949255138635635, 102.51192525029182, 95.23466974496841, 81.83254569768906, 64.3230852484703, 68.52951273322105, 69.65289205312729, 70.98177954554558, 60.284411162137985, 54.980340376496315, 63.383817449212074, 75.3044655919075, 48.676368445158005, 34.11593355238438, 23.7315296754241, 15.15909181907773, 16.217698864638805, 24.56426829099655, 27.666011452674866, 31.500241309404373, 41.36432960629463, 48.26734319329262, 56.56238928437233, 62.39620104432106, 61.69459529221058, 51.780003905296326, 27.807396166026592, 17.056188471615314, 14.406673293560743, 7.861104626208544, 7.431074101477861, 15.58134226128459, 17.754931077361107, 23.512017354369164, 14.610234070569277, 18.55317324399948, 24.879658967256546, 23.001761734485626, 23.5688604041934, 30.19531723111868, 30.7585097104311, 40.36667414009571, 47.49626576900482, 57.006194069981575, 56.2249331921339, 56.19401805102825, 60.53068734705448, 55.51065891981125, 51.131960079073906, 38.69671694934368, 60.677420273423195, 66.45137384533882, 67.19663545489311, 66.23691335320473, 70.24572104215622, 62.489459440112114, 64.59309116005898, 68.3890874683857, 85.06355792284012, 50.602629482746124, 19.007944241166115, 2.2315214574337006, 0.3431876690592617, 0.4903377121081576, 0.1527191192144528, 0.09630169850424863, 0.08529857252142392, 0.18481181119568646, 0.16156687022885308, 0.07167649644543417, 0.08192764871637337, 0.03804542138823308, 0.07822062849299982, 0.09267032539355569, 0.1192100383923389, 0.10265846794936806, 0.12884538620710373, 0.05935278917604592, 0.061021233632345684, 0.03267994230554905, 0.1536270626820624, 0.06228422425920144, 0.050386758375680074, 0.11241590647841804, 0.07179532170994207, 0.05664940494170878, 0.1954792340984568, 0.11669504834571853, 0.0767005690431688, 0.24424471892416477, 0.12779610813595355, 0.1972464213031344, 0.046645491747767664, 0.08965391069068573, 0.09973315929528326, 0.10586338074062951, 0.07042909463052638, 0.14436391677008942, 0.052645187970483676, 0.24037318682530895, 0.10196826318860985, 0.06577887892490253, 0.07510385315981694, 0.2608772279927507, 0.12420884828316048, 0.06456746385083534, 0.05947272395133041, 0.1761432591592893, 0.1139554547262378, 0.10842354531632736, 0.07059358424157836, 0.1312063360819593, 0.15729815553640947, 0.10872405575355515, 0.17304681125096977, 0.08943245382397436, 0.1205081660009455, 0.15380550466943532, 0.06656822719378397, 0.0902586942538619, 0.08922224049456418, 0.135326131421607, 0.12223643498145975, 0.1357791235204786, 0.21457393682794645, 0.2853601158130914, 0.18673636339372024, 0.33392967365216464, 0.13473167113261297, 0.12865986413089558, 0.15596795972669497, 0.14277257403591648, 0.15991017397027463, 0.15329296264098957, 0.16127946611959487, 0.12099931933335029, 0.20874417386949062, 0.095525671786163, 0.16298600501613691, 0.10641204309649765, 0.135953261051327, 0.1610376892494969, 0.24657322210259736, 0.19913174357498065, 0.18867421487811953, 0.17188868980156258, 0.23688537476118654, 0.1808193387114443, 0.1846134796505794, 0.08990897942567244, 0.06604582944419235, 0.08429825393250212, 0.12494627590058371, 0.08812872300040908, 0.08531541185220703, 0.1760008855490014, 0.10879594759899192, 0.17270675918553025, 0.12026846714434214, 0.1549561897991225, 0.2948979602660984, 0.14956470957258716, 0.35696581879165024, 0.2645497309276834, 0.34162675437983125, 0.3686999453930184, 0.3608193463878706, 0.1884248829446733, 0.37413576152175665, 0.07179762978921644, 0.036613848205888644, 0.38199765840545297, 1.4385899808257818, 2.9016124131157994, 6.80923224426806, 43.16935054957867, 83.73136460781097, 110.60717806220055, 97.46830388903618, 84.89034041762352, 71.15444228053093, 69.16700452566147, 69.54449906945229, 79.05789658427238, 85.41991040110588, 84.46131303906441, 86.61499187350273, 112.79560983181, 96.25809162855148, 76.69196873903275, 67.45524197816849, 54.13317583501339, 56.08385816216469, 53.85897494852543, 57.05088347196579, 58.20880673825741, 73.84598225355148, 75.3400544822216, 80.70838361978531, 95.45785456895828, 94.0498249232769, 94.9106839299202, 66.95625275373459, 58.41063670814037, 49.51790548861027, 38.227100148797035, 36.22504457831383, 49.08198907971382, 50.17591618001461, 57.42352947592735, 38.958108723163605, 37.786977365612984, 53.320912420749664, 54.49692651629448, 51.526614502072334, 54.60522070527077, 58.97912800312042, 57.85501152276993, 70.43466970324516, 83.38976293802261, 78.72555121779442, 85.46916335821152, 84.1169299185276, 79.86000314354897, 76.4180338382721, 65.76194643974304, 86.30169108510017, 78.94609898328781, 80.64682692289352, 81.20149835944176, 75.70836871862411, 63.217192590236664, 68.67695242166519, 73.2194946706295, 92.63908982276917, 76.17822870612144, 40.25217108428478, 9.577020350843668, 0.7490468595642596, 0.2546550618717447, 0.2667520986869931, 0.05265422361844685, 0.2114445375627838, 0.16513041104190052, 0.16641055641230196, 0.10702907951781526, 0.1130323343386408, 0.2320700534619391, 0.18826974439434707, 0.11834759599878453, 0.13163048832211643, 0.11868712113937363, 0.15464520023670048, 0.09121800918364897, 0.06724973398377188, 0.018728085487964563, 0.049725861026672646, 0.03220899023290258, 0.058674592364695854, 0.13945848389994353, 0.026841663202503696, 0.06341180633171462, 0.10698641344788484, 0.13318309094756842, 0.03275544098869432, 0.07442840971634723, 0.12464040715713054, 0.10389144241344184, 0.11371128814062104, 0.1254648293252103, 0.11630496810539626, 0.033280258139711805, 0.05956390050414484, 0.12793221801985055, 0.11183278620592318, 0.03806935565080494, 0.264366123592481, 0.13313488103449345, 0.0732087939104531, 0.09124107513343915, 0.14105117734288797, 0.07935126079246402, 0.13073490903479978, 0.13625258405227214, 0.13617305550724268, 0.17132032342487946, 0.05406048585427925, 0.20320070179877803, 0.2279692719457671, 0.10509293497307226, 0.04110235364350956, 0.3745107538998127, 0.27140120859257877, 0.24350182909984142, 0.3285201295511797, 0.3532717638881877, 0.266930510988459, 0.49958021147176623, 0.3961087652714923, 0.4717420443193987, 0.2853146370034665, 0.38510143873281777, 0.27490212698467076, 0.39292317058425397, 0.3351511596702039, 0.3316486382391304, 0.43295838637277484, 0.40662903513293713, 0.40798434522002935, 0.4081083135679364, 0.31963362358510494, 0.3433995967498049, 0.41038712253794074, 0.3042917390121147, 0.27086006419267505, 0.43636030226480216, 0.27254913293290883, 0.19019091239897534, 0.455963687854819, 0.32085012237075716, 0.34234055201523006, 0.3278416284592822, 0.3661269193980843, 0.3678644949104637, 0.5813478457275778, 0.320000066421926, 0.24892387096770108, 0.2302937675267458, 0.440930625773035, 0.3462334431242198, 0.33880920556839556, 0.49337986449245363, 0.6217478716280311, 0.5478520493488759, 0.5487852555233985, 0.4676952020963654, 0.6479816639330238, 1.0512420907616615, 0.6468259321991354, 0.6107261474244297, 0.5961754219606519, 0.8880710683297366, 0.6371023133397102, 0.5366419383790344, 1.048600876238197, 0.8499966957606375, 0.26835397991817445, 0.45557468372862786, 0.7945102325174958, 3.0380863649770617, 1.487859443295747, 26.94069117307663, 84.36679691076279, 135.80871015787125, 117.70886018872261, 101.67835637927055, 76.97552472352982, 81.24605476856232, 84.25297021865845, 91.40270456671715, 85.06247118115425, 70.10605573654175, 84.56323876976967, 127.1218366920948, 109.44249495863914, 105.26349440217018, 101.33249893784523, 91.42257750034332, 89.63275194168091, 86.4276771247387, 94.05091926455498, 86.97642847895622, 98.66358295083046, 91.12220361828804, 98.47217202186584, 110.02073273062706, 105.52883416414261, 90.88272526860237, 74.99659851193428, 66.54484122991562, 58.8891564309597, 50.16592651605606, 55.653136074543, 64.93372768163681, 72.05459117889404, 72.14571788907051, 61.36014483869076, 66.85100600123405, 77.36258715391159, 71.17707386612892, 67.33310133218765, 80.03684565424919, 82.2238638997078, 82.1261939406395, 93.52815851569176, 108.94495725631714, 101.10344722867012, 106.80702477693558, 110.39222359657288, 96.99086710810661, 84.51187312602997, 66.44902557134628, 89.62963610887527, 96.07495665550232, 101.77316129207611, 105.40328130126, 100.32996833324432, 82.67737716436386, 84.8450468480587, 94.73517894744873, 119.27169352769852, 82.96761319041252, 32.02003441751003, 4.092898601666093, 0.40265035175252706, 1.0501361126080155, 0.26392766274511814, 0.3668410732643679, 0.4330623464193195, 0.29479780001565814, 0.4600523575209081, 0.43277676799334586, 0.3061700554098934, 0.456313417525962, 0.42854720901232213, 0.5882498191203922, 0.5280046456027776, 0.306375392829068, 0.3960758139146492, 0.2785005932673812, 0.6653197179548442, 0.14945738017559052, 0.44705150357913226, 0.4064098047092557, 0.351656642742455, 0.49080713535659015, 0.23633296455955133, 0.27369589952286333, 0.4107229592045769, 0.30709212936926633, 0.3070819174172357, 0.5315395246725529, 0.44700133439619094, 0.40735856629908085, 0.2967473032185808, 0.5486113554798067, 0.28805550711695105, 0.5599611683283001, 0.4329421778675169, 0.7054346997756511, 0.7180204556789249, 0.4787685500923544, 0.4608939529862255, 0.33444030093960464, 0.31619020679499954, 0.5198031419422477, 0.43744306603912264, 0.3199224377749488, 0.45278880978003144, 0.30226517119444907, 0.1761118959984742, 0.3977075294824317, 0.21387560555012897, 0.3230310569051653, 0.41274863644503057, 0.42989800684154034, 0.36335532437078655], [0.05867520834726747, 0.1633424437022768, 0.05637514797854237, 0.07741401786915958, 0.06562829716131091, 0.09789218776859343, 0.11409114158595912, 0.04125484272663016, 0.14823702222201973, 0.0783639372093603, 0.1894885883666575, 0.19392584479646757, 0.08816430156002752, 0.11540065373992547, 0.1255574938841164, 0.0730795637355186, 0.05222126950684469, 0.02300065192684997, 0.08529188577085733, 0.07234597302158363, 0.10226423910353333, 0.08933757766499184, 0.08700186081114225, 0.19096568488748744, 0.10555419459706172, 0.13099623407470062, 0.12986183166503906, 0.05272497997793835, 0.11634584559942596, 0.13023548817727715, 0.2025641914224252, 0.18704205402173102, 0.18923515977803618, 0.09541929975966923, 0.09302415171987377, 0.15672410430852324, 0.1570317690493539, 0.13492198748281226, 0.08427483917330392, 0.0456989899976179, 0.07012119240243919, 0.0962424602766987, 0.13981511554447934, 0.04894657256954815, 0.07700781818130054, 0.08012217411305755, 0.08644657849799842, 0.09892689748085104, 0.1744315103860572, 0.17159224633360282, 0.17164216318633407, 0.13883488689316437, 0.14368103700689971, 0.155196170671843, 0.036072881921427324, 0.1983414008282125, 0.3191594505915418, 0.2157849882496521, 0.09413821928319521, 0.6903142423834652, 1.4666135958395898, 1.2355205649510026, 18.722513057291508, 66.34590670466423, 103.19730207324028, 118.13002958893776, 91.65631055831909, 75.27525275945663, 83.50883334875107, 81.85969904065132, 79.82074365019798, 62.790182903409004, 53.7430127710104, 47.936339154839516, 53.557210341095924, 49.22493740916252, 53.99525463581085, 50.880896151065826, 60.81583924591541, 54.037842750549316, 72.3472286760807, 64.81968820095062, 74.75597262382507, 87.76278868317604, 63.58652897179127, 55.89382655918598, 30.992829836905003, 44.01250250637531, 26.44889496266842, 26.838888935744762, 23.9441966637969, 23.342687040567398, 20.658349581062794, 42.09374986588955, 20.90248078107834, 59.63104002177715, 48.79989981651306, 30.407492145895958, 46.237568110227585, 44.90869581699371, 50.26132419705391, 50.3557301312685, 75.47452166676521, 58.634022921323776, 64.184590280056, 77.18381434679031, 62.41760529577732, 59.57963638007641, 53.72895732522011, 59.74496930837631, 63.597092404961586, 71.86780080199242, 82.09293812513351, 73.54800224304199, 71.19439333677292, 63.14920663833618, 81.48621708154678, 91.82522669434547, 75.69268316030502, 26.13187227398157, 1.7100635636597872, 0.2059569492121227, 0.2923749550245702, 0.009620887067285366, 0.10653058634488843, 0.049780772533267736, 0.039505886379629374, 0.16979477950371802, 0.04565810137137305, 0.07724606242845766, 0.07176221450208686, 0.14871587074594572, 0.06021375098498538, 0.15564528875984251, 0.18116672319592908, 0.09004189807455987, 0.07781577209243551, 0.032744512864155695, 0.06455172289861366, 0.14875891531119123, 0.0862882932415232, 0.06679047073703259, 0.04359444843430538, 0.06005892042594496, 0.06822850060416386, 0.13990671141073108, 0.15821807726752013, 0.07953963271575049, 0.15238668158417568, 0.14902185823302716, 0.20222271443344653, 0.015188982670224505, 0.08440006917226128, 0.12499540607677773, 0.11589004076085985, 0.07022786870948039, 0.0313397757417988, 0.15550684853224084, 0.17098111740779132, 0.39046891790349036, 0.0954367253871169, 0.3550717985490337, 0.15921639947919175, 0.18714684527367353, 0.029127329617040232, 0.061493039174820296, 0.07975334156071767, 0.09382582706166431, 0.1624127256218344, 0.2537422499153763, 0.16426764952484518, 0.2119141537696123, 0.11785722192144021, 0.10065404581837356, 0.19676470808917657, 0.18093977443641052, 0.23386548680718988, 0.04308388422941789, 0.14608995930757374, 0.06394924741471186, 0.12973109493032098, 0.14195131341693923, 0.1415434290538542, 0.17429311468731612, 0.2782118978211656, 0.05917767572100274, 0.15153928252402693, 0.1973047837964259, 0.1690519045223482, 0.15744593198178336, 0.15068958280608058, 0.2074412297224626, 0.220655050361529, 0.09608396721887402, 0.1034602991421707, 0.1393277768511325, 0.12382333225104958, 0.06965452252188697, 0.0987412640824914, 0.12146398541517556, 0.08884371549356729, 0.15506058029131964, 0.16832272958708927, 0.07656818474060856, 0.21426192310173064, 0.21141134871868417, 0.21349219721741974, 0.06912206867127679, 0.12103920234949328, 0.18344556185184047, 0.10568453799351119, 0.15984585945261642, 0.08795243324129842, 0.13948876352515072, 0.16680129716405645, 0.19400390388909727, 0.1804666849784553, 0.22090258629759774, 0.07573072303785011, 0.27386689034756273, 0.25837081717327237, 0.19292905140900984, 0.2388337202137336, 0.22413428319850937, 0.2623441274045035, 0.2737211325438693, 0.15466507495148107, 0.329120111418888, 0.3256924875313416, 0.1837862076354213, 0.2286147919949144, 0.5939322360791266, 0.2939326042542234, 0.07749690092168748, 0.5124672793317586, 1.821598147507757, 2.227231487631798, 4.965775413438678, 49.416982904076576, 96.27583667635918, 114.69129770994186, 104.56200644373894, 87.64292791485786, 76.10337272286415, 75.96404179930687, 73.61547142267227, 59.536379501223564, 62.11467795073986, 73.21096032857895, 64.38239246606827, 74.85093712806702, 92.44479864835739, 98.66880387067795, 96.69359385967255, 102.46009603142738, 105.11001303792, 110.63883796334267, 106.16689592599869, 106.46996766328812, 106.90663263201714, 84.26987171173096, 78.60821351408958, 50.088821053504944, 67.5082415342331, 54.545852690935135, 64.40321534872055, 56.88184194266796, 56.398488879203796, 45.862790420651436, 74.35108155012131, 48.184393644332886, 94.7783750295639, 74.73053678870201, 53.94497573375702, 70.1842251420021, 70.06410598754883, 80.08146286010742, 77.82510593533516, 103.93239542841911, 86.66057422757149, 101.4207074046135, 92.6325161755085, 86.87204048037529, 86.41761526465416, 78.6788821220398, 74.33802545070648, 58.180137276649475, 67.59992301464081, 74.43877324461937, 76.80438190698624, 77.0695772767067, 75.69731891155243, 89.78643089532852, 98.36512416601181, 94.14090603590012, 45.75928017497063, 7.437289617955685, 0.5605260911397636, 0.3484405012568459, 0.19060280435951427, 0.09159427805570886, 0.20530440844595432, 0.09176141713396646, 0.08065045709372498, 0.0658715509052854, 0.08899175169062801, 0.14863165182759985, 0.06157132833322976, 0.09794872457860038, 0.12685972556937486, 0.03498834070342127, 0.10462533740792423, 0.1485216210130602, 0.16050834499765188, 0.1173819208634086, 0.16360810288460925, 0.14224976068362594, 0.05317149683833122, 0.12446173510397784, 0.09721684080432169, 0.07753264275379479, 0.09688042526249774, 0.11395330249797553, 0.1582035014871508, 0.038254996470641345, 0.022107122822490055, 0.1545402011834085, 0.1263136087800376, 0.0734986767929513, 0.17634810676099733, 0.28542634507175535, 0.14500489487545565, 0.25956971221603453, 0.20046443300088868, 0.13200827117543668, 0.10826163095771335, 0.12282424562727101, 0.15419814531924203, 0.1876517728669569, 0.06151921843411401, 0.22038560622604564, 0.09587541630025953, 0.18100134300766513, 0.10432331298943609, 0.057630275550764054, 0.08431046226178296, 0.05285835875838529, 0.03615616573370062, 0.14737103978404775, 0.08170336426701397, 0.13088734616758302, 0.15384043013909832, 0.3329458530060947, 0.30212766607291996, 0.18169496906921268, 0.2256419265177101, 0.2298389349016361, 0.3362771758111194, 0.2706157194916159, 0.3332403372041881, 0.4244878690224141, 0.16749431466450915, 0.34290666226297617, 0.472655717167072, 0.18589444138342515, 0.21465199592057616, 0.2938298910157755, 0.2861798327649012, 0.3921787964645773, 0.22805170970968902, 0.2486341365147382, 0.27813210210297257, 0.34505651565268636, 0.3958019317360595, 0.39469295530579984, 0.3033817175310105, 0.2849553187843412, 0.36551969416905195, 0.3650088293943554, 0.18560000171419233, 0.22933032625587657, 0.33301442745141685, 0.35209201625548303, 0.49687588470987976, 0.29217341740150005, 0.30073702975641936, 0.4711105063324794, 0.2984789712354541, 0.4276453808415681, 0.32712501066271216, 0.34318933147005737, 0.2519335469696671, 0.4541123559465632, 0.3420276922406629, 0.5494007037486881, 0.46379206934943795, 0.6867166666779667, 0.6496734044048935, 0.3790649282746017, 0.4689448600402102, 0.5033579212613404, 0.6489121390040964, 0.20040253788465634, 0.4156835039611906, 0.6227636046241969, 0.3480961744207889, 0.36688667081762105, 0.7196904066950083, 0.7231212069746107, 0.37129526550415903, 0.3361469437368214, 1.3599737430922687, 2.2332349279895425, 1.553116429131478, 33.07637393474579, 94.7979287803173, 132.43157297372818, 145.36209672689438, 109.73928943276405, 90.07907599210739, 92.69882261753082, 98.7414787709713, 96.03366047143936, 86.12376943230629, 88.40120002627373, 67.96792566776276, 81.27294212579727, 93.42104226350784, 99.51140865683556, 107.1714024245739, 118.26189011335373, 106.37509435415268, 121.16574749350548, 116.7789588868618, 115.77615469694138, 111.32842496037483, 91.06930285692215, 88.94791468977928, 74.87860724329948, 99.62554693222046, 81.64279147982597, 91.53552263975143, 82.56141498684883, 66.84570908546448, 53.40317040681839, 91.5595905482769, 61.362876892089844, 113.57231095433235, 92.4553544819355, 74.72463950514793, 86.77117109298706, 87.26466581225395, 84.91914287209511, 78.82009774446487, 109.31163758039474, 85.63446968793869, 89.68081936240196, 97.09326401352882, 86.76945358514786, 81.82577446103096, 81.05630815029144, 99.26642820239067, 92.14097455143929, 102.97636672854424, 103.21462914347649, 93.2183763384819, 88.99665087461472, 89.13556382060051, 114.75115209817886, 131.81070148944855, 101.51144653558731, 34.84737150371075, 3.141704429872334, 0.5830509855877608, 0.8669081039261073, 0.32160248199943453, 0.20332995423814282, 0.5825020931661129, 0.31131646363064647, 0.2291346070705913, 0.24092671024845913, 0.2520187752088532, 0.18857724586268887, 0.30526033078785986, 0.1959150974289514, 0.33520643482916057, 0.37177683028858155, 0.27127780427690595, 0.38986611587461084, 0.37006680329795927, 0.31956098217051476, 0.4059790028259158, 0.37279740208759904, 0.27300026966258883, 0.37337072601076216, 0.30425840173847973, 0.4048362735193223, 0.3884201747132465, 0.3649953816784546, 0.5644997279159725, 0.37277389084920287, 0.5647872656118125, 0.47915295290295035, 0.42889664182439446, 0.41517412348184735, 0.5392269277945161, 0.4254384711384773, 0.44242584554012865, 0.4120555298868567, 0.49600849219132215, 0.4505829984555021, 0.6839313567616045, 0.5986830499023199, 0.7484795025084168, 0.4120860173134133, 0.3451123251579702, 0.5360723251942545, 0.2726622956106439, 0.4355079308152199, 0.4811665479792282, 0.268566946615465, 0.30678873939905316, 0.29047288990113884, 0.3489453694783151, 0.48793199588544667, 0.27740432240534574, 0.417896558647044, 0.3176973306108266], [0.06685238069621846, 0.02909459904913092, 0.1852184339077212, 0.141491508402396, 0.14875449211103842, 0.11562093801330775, 0.14411704876692966, 0.07738660293398425, 0.23579211701871827, 0.14989646442700177, 0.13412539585260674, 0.17974361049709842, 0.15142656513489783, 0.15147812955547124, 0.045918227842776105, 0.1798934055841528, 0.12190539258881472, 0.2953604963840917, 0.23334721539868042, 0.17894082935526967, 0.14683146873721853, 0.12352492951322347, 0.14096584520302713, 0.09379474591696635, 0.07757789149763994, 0.08574156046961434, 0.056424782815156505, 0.22027559025445953, 0.15135389403440058, 0.21575861232122406, 0.17556129663717002, 0.1310821747756563, 0.2581265021581203, 0.2806992206024006, 0.1344980875728652, 0.04595760619849898, 0.07049631094560027, 0.11253145887167193, 0.08930922762374394, 0.1535674385377206, 0.18623618554556742, 0.1956551379407756, 0.17522168986033648, 0.04856401399592869, 0.12740168633172289, 0.05678607143636327, 0.20490222377702594, 0.31865609635133296, 0.22987596807070076, 0.19248570722993463, 0.30338551732711494, 0.1904015042237006, 0.13915910152718425, 0.13150643091648817, 0.20417843683389947, 0.08771699431235902, 0.037641629969584756, 0.18719628715189174, 0.3785609803162515, 0.3222730866400525, 0.22052008338505402, 0.4089789715362713, 1.4142614300362766, 1.6538916528224945, 8.985888920724392, 43.093407824635506, 89.67178344726562, 119.95944142341614, 121.10109776258469, 92.90672466158867, 76.28104358911514, 75.06120264530182, 86.72233611345291, 75.79781591892242, 67.21293658018112, 55.15232294797897, 46.768175438046455, 56.510392874479294, 51.12425409257412, 54.28303599357605, 48.42359080910683, 38.00374053418636, 47.024057507514954, 49.126693680882454, 61.804595589637756, 66.58745214343071, 73.13841462135315, 63.01583759486675, 57.31515169143677, 58.802600875496864, 52.43100017309189, 40.434549897909164, 35.702530816197395, 44.08058725297451, 40.69540590047836, 61.42590790987015, 42.847496420145035, 26.12849235534668, 38.57793152332306, 36.44150756299496, 36.29857063293457, 48.93308266997337, 55.0126576423645, 44.09192584455013, 41.61819398403168, 51.85908906161785, 48.77905413508415, 55.135284662246704, 72.60496884584427, 68.64257946610451, 68.44759672880173, 76.85658350586891, 78.82660299539566, 83.43884110450745, 97.94938087463379, 71.73382759094238, 53.86773347854614, 18.07618483901024, 1.8560536298900843, 0.12622352689504623, 0.18647402903297916, 0.14335849962662905, 0.09638432922656648, 0.18150658230297267, 0.07523245993070304, 0.07182065121014602, 0.18426570924930274, 0.046343864378286526, 0.09114346044952981, 0.12874331121565774, 0.09278013356379233, 0.13023672014242038, 0.14020026050275192, 0.25632946577388793, 0.04493612897931598, 0.21219783229753375, 0.23356945894192904, 0.16055079584475607, 0.14724429580383003, 0.12542741023935378, 0.09087709622690454, 0.10612345155095682, 0.20197412464767694, 0.11199763204785995, 0.12172521397587843, 0.08159084725775756, 0.05452876619528979, 0.14120680571068078, 0.0875813965103589, 0.019508303485054057, 0.1092637752299197, 0.12016675580525771, 0.10130035996553488, 0.0961293421278242, 0.09726286138175055, 0.06740188167896122, 0.10163154336623847, 0.06863504910143092, 0.07311283421586268, 0.09400453622220084, 0.09171892175800167, 0.08260857663117349, 0.1384707447141409, 0.18892130552558228, 0.14445631415583193, 0.06873410355183296, 0.19774486252572387, 0.17510698351543397, 0.2340627645025961, 0.16625187039608136, 0.052780874830204993, 0.14365423063281924, 0.058297373543609865, 0.10835982451681048, 0.18172317068092525, 0.0762926327297464, 0.07923752666101791, 0.030463612893072423, 0.11035250587156042, 0.2010745377629064, 0.19448530540103093, 0.1827678325935267, 0.10464702296303585, 0.08847657503793016, 0.1872969075338915, 0.18390052806353197, 0.11652643981506117, 0.1397976602311246, 0.18338429013965651, 0.19796495384071022, 0.11432744140620343, 0.06262736365897581, 0.17654735856922343, 0.2054138752282597, 0.14692598866531625, 0.12508320214692503, 0.1970530324615538, 0.20115365070523694, 0.23723933467408642, 0.247555335809011, 0.27301766560412943, 0.02522013361158315, 0.08307234471431002, 0.28988519799895585, 0.08624253983725794, 0.27766339131630957, 0.13663780322531238, 0.21386445849202573, 0.083314915682422, 0.21865245391381904, 0.09708451587357558, 0.09860638616373762, 0.18271966720931232, 0.22048710234230384, 0.19032602780498564, 0.22063928714487702, 0.12342088783043437, 0.2240812047966756, 0.15505229792324826, 0.18072765378747135, 0.21671519614756107, 0.2729100838769227, 0.3185612795641646, 0.31442912004422396, 0.24142883252352476, 0.29254748951643705, 0.23531608865596354, 0.2949849399738014, 0.12921098299557343, 0.2664818085031584, 0.17964405880775303, 0.08049134063185193, 0.3134526318171993, 0.5554620909970254, 0.2509163593640551, 0.15890659735305235, 0.6832231697626412, 1.9346572807990015, 3.190415916033089, 6.897798366844654, 29.77500658482313, 74.72096130251884, 111.29683345556259, 113.3627749979496, 107.8828002512455, 93.09155434370041, 90.57871118187904, 87.90134444832802, 79.10420849919319, 64.19684082269669, 49.83920484781265, 47.41639405488968, 44.611927941441536, 56.68624743819237, 58.98035913705826, 51.68613374233246, 50.65749853849411, 43.665261939167976, 51.959388479590416, 52.04194284975529, 59.10035289824009, 67.14606776833534, 69.37509655952454, 69.87385019659996, 64.35947969555855, 63.74024972319603, 58.03492806851864, 44.33804243803024, 42.59997770190239, 55.06040208041668, 48.63127626478672, 78.91137644648552, 57.223094031214714, 35.87715804576874, 45.946123749017715, 41.12525783479214, 39.406952038407326, 45.08244529366493, 60.28257206082344, 44.61843319237232, 38.13197985291481, 61.14137537777424, 51.51083014905453, 44.51947130262852, 62.377802431583405, 72.80123591423035, 80.09463295340538, 89.05968949198723, 97.44858294725418, 98.81013348698616, 105.85567742586136, 96.18885934352875, 79.80244383215904, 40.81097669899464, 6.5685085114091635, 0.20016355148982257, 0.1332823754637502, 0.3405582398409024, 0.06395279488060623, 0.10357630424550734, 0.18297036469448358, 0.15362375270342454, 0.23184377263532951, 0.15707834623754025, 0.21665291511453688, 0.1875284724519588, 0.1333894525305368, 0.16397620813222602, 0.10975535158650018, 0.202743464615196, 0.1236737598082982, 0.17191516963066533, 0.20530662004603073, 0.16647424752591178, 0.12755770061630756, 0.13863774278433993, 0.15610239235684276, 0.18873854423873127, 0.15367919113487005, 0.16904261283343658, 0.11151971863000654, 0.14825002464931458, 0.13276744371978566, 0.12025343123241328, 0.1087431215273682, 0.10325191891752183, 0.17470794555265456, 0.07063324461341836, 0.08946412868681364, 0.1489425078034401, 0.1096158723521512, 0.10058187937829643, 0.12381919848849066, 0.1309323203167878, 0.1931220543337986, 0.12725169828627259, 0.20052981621120125, 0.16604197619017214, 0.1691287910216488, 0.2124968435964547, 0.1288584925350733, 0.12774915987392887, 0.09544342698063701, 0.03279580640082713, 0.29501124168746173, 0.0650411396054551, 0.043197785344091244, 0.15930211753584445, 0.1150846472592093, 0.15433478954946622, 0.13435654516797513, 0.10308086129953153, 0.31386259419377893, 0.25246314355172217, 0.41607197374105453, 0.3781888377852738, 0.32250701158773154, 0.2607153804274276, 0.378002350917086, 0.22151947428938001, 0.4423944081645459, 0.2422079094685614, 0.31730592192616314, 0.26459342858288437, 0.174109180807136, 0.3037259849952534, 0.2434550441103056, 0.2963322348659858, 0.26001841470133513, 0.34101905417628586, 0.30314328032545745, 0.40484271536115557, 0.4081025841878727, 0.3687972854822874, 0.35144456662237644, 0.29077242070343345, 0.2760193560970947, 0.2040070600924082, 0.1256908429786563, 0.3960563102737069, 0.22395809734007344, 0.27708092413377017, 0.26125412026885897, 0.20607848331565037, 0.3420657792594284, 0.3154497215291485, 0.41902830416802317, 0.36260403343476355, 0.24823785934131593, 0.28705209377221763, 0.2542317705228925, 0.3530804382171482, 0.42906929505988955, 0.5533692939206958, 0.30895492003764957, 0.3711220185505226, 0.37036784808151424, 0.4291433613980189, 0.46695038268808275, 0.52462650812231, 0.3866457589901984, 0.36662009137216955, 0.38717666175216436, 0.34210146171972156, 0.23802768846508116, 0.32221911766100675, 0.2210130772436969, 0.18303769233170897, 0.3724056371720508, 0.5330834886990488, 0.5896978976670653, 0.3763139352668077, 0.5570787854958326, 1.4875523722730577, 1.7051332094706595, 2.00411434751004, 15.152905751019716, 58.024136647582054, 114.58304911851883, 150.95770686864853, 149.8643383383751, 121.25866770744324, 105.74748203158379, 104.37935784459114, 105.86422696709633, 93.6079390347004, 83.48905920982361, 70.5057030916214, 71.47284999489784, 75.5192756652832, 76.89585819840431, 75.42711541056633, 75.5060675740242, 54.299994483590126, 68.13202366232872, 81.17925435304642, 90.11450529098511, 94.71870303153992, 91.48384541273117, 88.1641611456871, 82.50864341855049, 85.68800881505013, 81.9930262863636, 69.69804883003235, 65.60862466692924, 81.403229534626, 67.43093848228455, 99.65675845742226, 70.95745325088501, 48.925418481230736, 65.37151739001274, 59.652026295661926, 57.98046179115772, 69.01296079158783, 85.08368164300919, 64.30526420474052, 63.66048060357571, 84.15000334382057, 77.73706465959549, 80.15766397118568, 97.41890653967857, 89.31883558630943, 95.36324724555016, 104.84537243843079, 117.806606143713, 125.21778926253319, 136.78185313940048, 112.05209612846375, 73.24132829904556, 25.346420221030712, 1.9012368866242468, 0.4229897994082421, 0.41631836676970124, 0.4773019178537652, 0.2840241906233132, 0.2817300340393558, 0.3871784429065883, 0.3164038562681526, 0.2823499054647982, 0.4438252985710278, 0.4198487038956955, 0.29018811299465597, 0.3043368912767619, 0.18210861249826849, 0.26513270277064294, 0.3357405436690897, 0.20278886921005324, 0.2224134950665757, 0.3726532473228872, 0.30800197273492813, 0.3102504723938182, 0.2946016355417669, 0.315334124607034, 0.31141876126639545, 0.30834523087833077, 0.34244083100929856, 0.4064322175690904, 0.2949894522316754, 0.36584080662578344, 0.2689419686794281, 0.32766573945991695, 0.24515656608855352, 0.4702084406744689, 0.23187043057987466, 0.3394941781880334, 0.4713447281392291, 0.4540385864675045, 0.35412852885201573, 0.2917525899829343, 0.31947637733537704, 0.4188448452623561, 0.345841440721415, 0.2855557162547484, 0.3103155439021066, 0.4302256798837334, 0.48572695639450103, 0.3826309775467962, 0.3313423093641177, 0.352932068053633, 0.2219341864110902, 0.5695191398262978, 0.3553655109135434, 0.23642868676688522, 0.2455493700108491, 0.3302314627217129, 0.2445472776889801, 0.283725312910974, 0.28209867363329977], [0.12132438743719831, 0.05906856888032053, 0.07141767244320363, 0.12923933303682134, 0.05531837792659644, 0.031189375804387964, 0.10860432506888174, 0.13274473400088027, 0.20051863946719095, 0.16012708889320493, 0.21453892230056226, 0.09746417636051774, 0.09543325955746695, 0.12005972326733172, 0.13421526993624866, 0.07474667974747717, 0.19230898702517152, 0.18113129306584597, 0.16344910516636446, 0.19331611110828817, 0.05079461676359642, 0.13282987318234518, 0.12019889822113328, 0.1173641464265529, 0.11834813776658848, 0.10401363702840172, 0.05696928914403543, 0.07089761245879345, 0.12182521837530658, 0.1532351048081182, 0.16262263467069715, 0.13562671607360244, 0.1956640140269883, 0.23501192685216665, 0.1814410655060783, 0.216968001332134, 0.13533122255466878, 0.08657452475745231, 0.0861732974590268, 0.09034645321662538, 0.06518664507893845, 0.0769446614140179, 0.05905647929466795, 0.0697849178686738, 0.18801094265654683, 0.10437943419674411, 0.0529623336478835, 0.10042095949756913, 0.30192182399332523, 0.2854993427172303, 0.16615856759017333, 0.31779784709215164, 0.37004967452958226, 0.18454125383868814, 0.1359226697240956, 0.29760124802123755, 0.14769184053875506, 0.17002689361106604, 0.030103862372925505, 0.27449154120404273, 0.5777432047761977, 0.056478306505596265, 0.30022379010915756, 0.6784465292003006, 1.1036657402291894, 0.42813205160200596, 0.785666563315317, 10.271603129804134, 40.26439122855663, 74.88896548748016, 106.38846203684807, 115.03481447696686, 110.99162623286247, 91.33939996361732, 82.92563304305077, 68.21811944246292, 67.5729900598526, 71.0709835588932, 79.58798334002495, 76.38779506087303, 72.32516705989838, 65.14951050281525, 70.99304974079132, 75.47085866332054, 77.78799712657928, 87.03689843416214, 98.20348843932152, 101.77671790122986, 109.96740639209747, 96.26649677753448, 84.76908892393112, 81.65446445345879, 74.06953945755959, 78.68904277682304, 73.9609868824482, 76.86256438493729, 67.68737152218819, 71.15131124854088, 79.77168828248978, 68.55955392122269, 63.803873509168625, 63.56106273829937, 68.02059084177017, 63.132555931806564, 64.94930684566498, 65.96138253808022, 68.1362034380436, 71.89770519733429, 80.59632003307343, 86.8202492594719, 97.71842926740646, 79.57292854785919, 47.42691949009895, 29.953509606420994, 12.731952108442783, 1.7256673076190054, 0.2531545580131933, 0.18422560358885676, 0.11034013426979072, 0.3945625451160595, 0.10295493368175812, 0.12643395544728264, 0.044613161153392866, 0.02782260431558825, 0.23433854657923803, 0.20935022650519386, 0.04905724163108971, 0.2466804179130122, 0.0423212161695119, 0.06942628242541105, 0.08402739971643314, 0.07128554789233021, 0.2584228268824518, 0.10957626393064857, 0.12703309126663953, 0.08464397600619122, 0.22351746942149475, 0.14223373029381037, 0.18880876625189558, 0.02320516185136512, 0.21678203396731988, 0.10888254138990305, 0.1542226955643855, 0.27132634073495865, 0.09475359329371713, 0.20466215384658426, 0.16175258526345715, 0.19062545470660552, 0.11122596173663624, 0.2034568614908494, 0.1810527144698426, 0.15987066202796996, 0.10404266984551214, 0.1605535566341132, 0.08786593592958525, 0.14025026641320437, 0.06433768008719198, 0.11594350507948548, 0.029199136115494184, 0.0703190935018938, 0.14336777647258714, 0.03488472575554624, 0.0948292032990139, 0.06679317957605235, 0.09807382841245271, 0.1371345523511991, 0.2777895564213395, 0.18005887483013794, 0.24920615425799042, 0.07432373720803298, 0.16979699110379443, 0.08367093876586296, 0.1332719111815095, 0.1647258663433604, 0.08407234417973086, 0.044428596447687596, 0.0637767203443218, 0.1907454599859193, 0.21506485267309472, 0.1256076036952436, 0.08816416055196896, 0.1859407513984479, 0.09526421315968037, 0.0839842735149432, 0.07546253313194029, 0.052469632937572896, 0.11757381056668237, 0.16294382134219632, 0.09622406243579462, 0.10970685965730809, 0.17570594121934846, 0.18780449201585725, 0.2346050666528754, 0.16104046488180757, 0.08205754682421684, 0.16207985754590482, 0.10836484143510461, 0.14335818792460486, 0.06380735620041378, 0.04772149826749228, 0.11304237559670582, 0.10962501561152749, 0.08886220239219256, 0.10153935378184542, 0.17984584876103327, 0.15822860092157498, 0.06881251887534745, 0.13392767286859453, 0.13021038874285296, 0.12234443231136538, 0.11633358531980775, 0.10771475717774592, 0.07191432508989237, 0.07912909146398306, 0.0772568532556761, 0.08898981468519196, 0.0866643172048498, 0.07688855504966341, 0.1260873576393351, 0.1648941557505168, 0.23427457344951108, 0.16746786452131346, 0.11651898865238763, 0.2160488217487, 0.19962182821473107, 0.14311216596979648, 0.10632910067215562, 0.18705397291341797, 0.2215487594367005, 0.16365442774258554, 0.12631636956939474, 0.24025457678362727, 0.14118083054199815, 0.09282924889703281, 0.18837216077372432, 0.38789865269791335, 0.1693345292005688, 0.09852371833403595, 0.7883788459002972, 1.3302987604402006, 1.3163860444910824, 1.3032201072201133, 5.516263749450445, 35.23451752960682, 76.02654844522476, 108.20946112275124, 118.31780031323433, 116.62643507122993, 115.81101402640343, 102.67160028219223, 98.5378248989582, 84.84434008598328, 78.82876127958298, 74.59413930773735, 75.57170525193214, 77.72684320807457, 76.637654453516, 69.9487441778183, 80.56059435009956, 91.75074309110641, 93.24872151017189, 100.42005389928818, 111.08344450592995, 118.39629650115967, 119.61153209209442, 107.48687669634819, 95.6187379360199, 90.13145998120308, 84.38004299998283, 85.83998546004295, 84.51691165566444, 81.1536057293415, 75.05370944738388, 85.92019155621529, 93.3594323694706, 81.25617742538452, 79.77738037705421, 77.29594632983208, 75.91798827052116, 71.14277690649033, 74.1173180937767, 75.87580293416977, 85.67354679107666, 95.51921367645264, 99.69798624515533, 100.56949988007545, 108.61147195100784, 100.21070033311844, 79.96369957923889, 62.16336853802204, 32.78515376150608, 7.76406685821712, 1.045266198925674, 0.3533655416686088, 0.10372659657150507, 0.16303975135087967, 0.017774008265405428, 0.06090463481086772, 0.1725199754582718, 0.3393188532209024, 0.16927880875300616, 0.15455787914106622, 0.16074097860837355, 0.11014137970050797, 0.0973146632895805, 0.13741094298893586, 0.034653068069019355, 0.10045578106655739, 0.08880907204002142, 0.1303473743610084, 0.054855886337463744, 0.1533219954581, 0.13604841922642663, 0.12837671994930133, 0.09090595835004933, 0.11657761831884272, 0.07139283276046626, 0.1278471085242927, 0.04427253392350394, 0.13004782871576026, 0.0538622619205853, 0.11568316709599458, 0.034437667127349414, 0.08861198730301112, 0.14646557508967817, 0.0992145539203193, 0.12394201650749892, 0.1755127008073032, 0.16264626465272158, 0.15543766552582383, 0.17963601392693818, 0.16295731358695775, 0.14830182655714452, 0.11438610075856559, 0.182550739555154, 0.11043469130527228, 0.2293743652990088, 0.19093589507974684, 0.1507115355343558, 0.13862319668987766, 0.1991788254235871, 0.14485232415609062, 0.1708952954504639, 0.07627175611560233, 0.09493292585830204, 0.13155036605894566, 0.1451577476109378, 0.03795935081143398, 0.02307063274201937, 0.0383961418265244, 0.11905907071195543, 0.12432054150849581, 0.3141122526722029, 0.23941606865264475, 0.37872932909522206, 0.27766261948272586, 0.1607872440945357, 0.2825989405391738, 0.17969933396670967, 0.2913520677248016, 0.2606670220848173, 0.17729244515066966, 0.18743344786344096, 0.34113266214262694, 0.1897115889005363, 0.19177655543899164, 0.16600719915004447, 0.1939122486510314, 0.3353832144057378, 0.22439145221142098, 0.20807533554034308, 0.21294174628565088, 0.2764403319451958, 0.22811710776295513, 0.16104352253023535, 0.21199742273893207, 0.2296545112039894, 0.22310244559776038, 0.2855006785830483, 0.2925637870794162, 0.17244847695110366, 0.3099891770398244, 0.21072502539027482, 0.21095849020639434, 0.19759043643716723, 0.31166500586550683, 0.1974773479741998, 0.22191128373378888, 0.2225337823620066, 0.31105668225791305, 0.21168045146623626, 0.20718389743706211, 0.2848033863119781, 0.23527408309746534, 0.25081958330702037, 0.20244341430952772, 0.38013667857740074, 0.2833327167900279, 0.2260740494239144, 0.28118755377363414, 0.35341200011316687, 0.44935694080777466, 0.3343857085565105, 0.2949250041274354, 0.4970285593299195, 0.3604407620150596, 0.18801067548338324, 0.30078479438088834, 0.27695553086232394, 0.20200094586471096, 0.22633780870819464, 0.5048361013177782, 0.48906911455560476, 0.19202069233870134, 0.6564302137121558, 0.9293611370958388, 1.4236297085881233, 0.429116822197102, 1.126417969353497, 17.758045010268688, 54.20170895755291, 103.75920832157135, 141.1020389199257, 150.52478849887848, 156.58294022083282, 131.13181471824646, 121.60774737596512, 99.42008435726166, 93.87215405702591, 93.71263101696968, 100.9220677614212, 98.03354635834694, 97.2522246837616, 88.47129106521606, 100.45380368828773, 104.27377671003342, 107.59488970041275, 120.87563306093216, 142.21855580806732, 153.27313542366028, 152.2597450017929, 137.94212847948074, 119.71231028437614, 112.81925976276398, 101.94403812289238, 105.93687146902084, 103.70494723320007, 106.07348173856735, 97.6096411049366, 108.21112543344498, 119.55965727567673, 104.59124207496643, 97.26115420460701, 95.73089271783829, 93.04023429751396, 90.70914298295975, 89.31157037615776, 97.7874031662941, 102.66047447919846, 114.14310112595558, 124.92458939552307, 131.12394154071808, 142.05905556678772, 119.94306430220604, 84.84215140342712, 52.1644102782011, 19.794519133865833, 2.458661156706512, 0.3432985459221527, 0.43322520330548286, 0.1500317282625474, 0.43147866264916956, 0.16668426047544926, 0.2049149590311572, 0.26175284350756556, 0.44944350491277874, 0.33211423200555146, 0.32788446522317827, 0.3559957427205518, 0.3363956819521263, 0.20417298946995288, 0.27388280199375004, 0.19768296740949154, 0.2751344785792753, 0.3815553680760786, 0.19761612958973274, 0.22052982036257163, 0.24419342167675495, 0.45542604639194906, 0.26296483003534377, 0.5531807884108275, 0.23256925167515874, 0.4080429452005774, 0.2393359167035669, 0.2586830238578841, 0.29480379656888545, 0.20373409817693755, 0.29507010884117335, 0.21183170116273686, 0.3141334484098479, 0.4162607167381793, 0.3596238949103281, 0.28994148247875273, 0.2946081367554143, 0.21866051363758743, 0.5438937898725271, 0.26947144651785493, 0.46445246203802526, 0.2671800507232547, 0.2696428232593462, 0.3390210442012176, 0.2069912210572511, 0.3590905579039827, 0.31805231468752027, 0.24868308857548982, 0.3300813114037737, 0.2845314337173477, 0.2797884272877127, 0.3287094662664458, 0.25367872207425535, 0.3351572452811524, 0.3822097642114386, 0.17598423175513744, 0.1507839246187359, 0.17823797097662464, 0.25670710019767284, 0.32610470603685826, 0.16790953144663945], [0.16589817765634507, 0.14169876056257635, 0.2389115418191068, 0.20280576049117371, 0.3162491333205253, 0.1424548903014511, 0.18080998765071854, 0.2565732167568058, 0.16729733382817358, 0.23553097009425983, 0.10611013742163777, 0.05907355611270759, 0.1710531799471937, 0.14945246715797111, 0.26709491154178977, 0.4645436571445316, 0.26356089336331934, 0.1751016400521621, 0.32519495172891766, 0.35400456050410867, 0.21186570636928082, 0.29007287230342627, 0.30170951038599014, 0.18687257717829198, 0.24877269548596814, 0.19675100804306567, 0.17545539216371253, 0.06885695867822506, 0.113399059191579, 0.4062495898688212, 0.2812700212234631, 0.32298326259478927, 0.3683382226154208, 0.2553284866735339, 0.17632189410505816, 0.21569542586803436, 0.13438480615150183, 0.25188070605508983, 0.22594973968807608, 0.28177248488646, 0.30812831595540047, 0.312895902316086, 0.3907946316758171, 0.2382414269959554, 0.2877827826887369, 0.2892946562496945, 0.18353617808315903, 0.20013845205539837, 0.353654088685289, 0.3217720182146877, 0.2349287914694287, 0.18745255074463785, 0.2661124267615378, 0.4197032132651657, 0.2967632148647681, 0.18180872546508908, 0.2797530416864902, 0.21640805091010407, 0.1613300509052351, 0.09789640316739678, 0.5696696473751217, 0.3197388007538393, 0.2845898555824533, 0.10817588321515359, 0.7393842155579478, 0.49963358673267066, 0.2928335726028308, 0.683719280641526, 0.36579669336788356, 0.40091972274240106, 0.9685903508216143, 15.328307189047337, 40.38073718547821, 70.75753077864647, 100.86404487490654, 104.6984115242958, 106.74138709902763, 104.90461125969887, 100.15074715018272, 110.24413794279099, 100.70105642080307, 108.9035926759243, 108.01251009106636, 116.75882756710052, 107.4469256401062, 99.14386957883835, 66.35235115885735, 24.53786350786686, 43.44381742179394, 62.40151695907116, 78.97714331746101, 99.05528873205185, 101.8534129858017, 98.09600740671158, 103.2636085152626, 113.83531764149666, 105.74488297104836, 84.76506873965263, 63.46707858145237, 55.45740857720375, 73.56992706656456, 107.42552518844604, 109.71782818436623, 99.03438985347748, 92.92515367269516, 88.51614385843277, 79.73187401890755, 71.81751430034637, 56.81666783988476, 30.180821008980274, 11.316870041191578, 2.5024184212088585, 0.33082224195823073, 0.18990381999174133, 0.31198211072478443, 0.21352468844270334, 0.4238466831156984, 0.46583033341448754, 0.15671672736061737, 0.13106951373629272, 0.19965457177022472, 0.15034650277812034, 0.3043951647123322, 0.2575386024545878, 0.20011369400890544, 0.24634337896713987, 0.20059772272361442, 0.09585033170878887, 0.1961234924965538, 0.08881227811798453, 0.11940768716158345, 0.1897947836550884, 0.15997512673493475, 0.11264205371844582, 0.1270692635443993, 0.16258677409496158, 0.12230673120939173, 0.042538505877018906, 0.30491155106574297, 0.23671533388551325, 0.11390311847208068, 0.29832208121661097, 0.1731573764118366, 0.1926656038267538, 0.14916108513716608, 0.27343184337951243, 0.3089656663360074, 0.4224737692857161, 0.4392958525568247, 0.1587208971614018, 0.26937550166621804, 0.3009616630151868, 0.3468754899222404, 0.09857694516540505, 0.22500847378978506, 0.3220346791204065, 0.20388033095514402, 0.22397724475013092, 0.39481306448578835, 0.24257721699541435, 0.29114278207998723, 0.28769761382136494, 0.38748281251173466, 0.3134588658576831, 0.21187879785429686, 0.30853388481773436, 0.28179890534374863, 0.39004485472105443, 0.267884616041556, 0.3063558298163116, 0.2649524202570319, 0.12529894447652623, 0.05131013480422553, 0.04658822021156084, 0.1109819658449851, 0.10565818432951346, 0.0675017450703308, 0.1044989496585913, 0.13075824215775356, 0.05863219717866741, 0.1286213318235241, 0.03368239827977959, 0.06676132659777068, 0.07442537433234975, 0.09382337055285461, 0.08017879255930893, 0.08790941094048321, 0.13393507950240746, 0.10994565309374593, 0.055132636916823685, 0.1686372814583592, 0.18778225727146491, 0.07199697065516375, 0.21940252772765234, 0.12972027441719547, 0.24706118419999257, 0.13730217382544652, 0.19175218330929056, 0.148497634800151, 0.07441156296408735, 0.13349983957596123, 0.1224588714831043, 0.07106944933184423, 0.03209096277714707, 0.09242841493687592, 0.20950941718183458, 0.13062703044852242, 0.2409205652656965, 0.2153913679649122, 0.1210087000799831, 0.09782207707758062, 0.11166563228471205, 0.057344552405993454, 0.08439618031843565, 0.08947449648985639, 0.12603821262018755, 0.19492289051413536, 0.15214469691272825, 0.17881806328659877, 0.11360134638380259, 0.13686607300769538, 0.13106181024340913, 0.27900979563128203, 0.1348297533695586, 0.10736036681919359, 0.21173930377699435, 0.23002374451607466, 0.176362385682296, 0.28567291621584445, 0.18257974268635735, 0.1354380918201059, 0.16689563897671178, 0.25187355175148696, 0.11925400322070345, 0.06832676837802865, 0.08974137279437855, 0.453504299512133, 0.2705310849705711, 0.17977017938392237, 0.06565112562384456, 0.7649924070574343, 0.4970104806125164, 0.22004884929629043, 0.1060829525522422, 0.7762490655295551, 2.9449495626613498, 14.27682001143694, 47.84596860408783, 81.40560060739517, 106.80852949619293, 126.84610068798065, 125.76058253645897, 129.59519237279892, 127.00242429971695, 125.40622115135193, 132.9588782787323, 119.51117187738419, 128.42537194490433, 126.34311407804489, 124.11016389727592, 121.97001993656158, 116.55957385897636, 87.48285010457039, 37.69580505788326, 60.263804867863655, 86.43029138445854, 103.09684306383133, 115.02369627356529, 116.5883307158947, 111.27279594540596, 114.76854756474495, 122.97638073563576, 116.89929082989693, 98.41126129031181, 76.59432157874107, 77.11629197001457, 96.3273923099041, 118.44509348273277, 115.08131638169289, 113.90322759747505, 107.36721351742744, 106.13319173455238, 100.69976449012756, 97.6748076081276, 86.30460932850838, 60.3526820987463, 30.882141776382923, 11.373717840760946, 1.494454345665872, 0.9687129536177963, 0.5750850692857057, 0.17249168478883803, 0.12872309511294588, 0.10980831124470569, 0.03754506913537625, 0.08783920377027243, 0.13822475244523957, 0.09882573533104733, 0.17350082751363516, 0.08572416452807374, 0.15315216238377616, 0.07167464849771932, 0.1608404709259048, 0.0533817992254626, 0.09789730116608553, 0.05026114988140762, 0.04279439468518831, 0.07830983464373276, 0.09711864724522457, 0.07973998290253803, 0.07379751739790663, 0.14314351428765804, 0.11324786886689253, 0.03622210555477068, 0.23138359654694796, 0.1326139972661622, 0.0304242011407041, 0.18883156502852216, 0.22356654022587463, 0.10103734282893129, 0.07662340794922784, 0.08746190331294201, 0.20337998983450234, 0.13152899220585823, 0.17156990768853575, 0.10151314854738303, 0.125416916271206, 0.1923727078246884, 0.0947175471810624, 0.010160185374843422, 0.15873940632445738, 0.09913348170812242, 0.04862145993683953, 0.11969478699029423, 0.3378125902963802, 0.14071231271373108, 0.2528452902333811, 0.22219975653570145, 0.19083387946011499, 0.1614840020192787, 0.1675307541154325, 0.12264955890714191, 0.19820374727714807, 0.26028644875623286, 0.10015605730586685, 0.18951879377709702, 0.08679926191689447, 0.07093943990184925, 0.055310592797468416, 0.01752411601046333, 0.07324673992116004, 0.023767641141603235, 0.2115374247659929, 0.15447082521859556, 0.2927244472084567, 0.19506452197674662, 0.30324676539748907, 0.12490891618654132, 0.23826636315789074, 0.2307448151987046, 0.20039416645886377, 0.2216208665049635, 0.21122582664247602, 0.23571862955577672, 0.30943511927034706, 0.182290023076348, 0.22489458380732685, 0.35803697537630796, 0.2386515971738845, 0.2433742390712723, 0.22524164174683392, 0.3466349153313786, 0.23564594361232594, 0.17405669612344354, 0.25466004910413176, 0.2168675887514837, 0.2319655442261137, 0.2181492926320061, 0.20569560932926834, 0.07189537063823082, 0.20008124731248245, 0.42023013811558485, 0.19282261258922517, 0.34719437593594193, 0.3174779220717028, 0.157293658121489, 0.2365681660012342, 0.2219684884767048, 0.2705428999615833, 0.2105440155719407, 0.17608449590625241, 0.34484690346289426, 0.3333952382672578, 0.34104140766430646, 0.33801487006712705, 0.25727564468979836, 0.222782060445752, 0.26730948127806187, 0.3118972387164831, 0.22801908489782363, 0.264130862778984, 0.2586481429170817, 0.22266904619755223, 0.1899704648531042, 0.21227899356745183, 0.24626606202218682, 0.18145342968637124, 0.2562900725752115, 0.23512909712735564, 0.339432253385894, 0.09285119420383126, 0.12396736827213317, 0.6515589344780892, 0.2880987001117319, 0.2596443425863981, 0.1839230745099485, 0.7429138699080795, 0.44068850751500577, 0.259751538396813, 0.6221008370630443, 0.23857022810261697, 0.6651232566218823, 5.190898133441806, 30.820376090705395, 66.2332883477211, 105.97090244293213, 146.70702695846558, 164.7139111161232, 168.41412216424942, 174.19665187597275, 163.66126120090485, 178.81566882133484, 158.2810539007187, 164.23689991235733, 159.9331596493721, 154.0285500884056, 145.01813918352127, 130.60802042484283, 89.10976320505142, 37.115446999669075, 57.90150582790375, 89.99168828129768, 111.81751951575279, 129.16269958019257, 132.76376634836197, 129.75770205259323, 127.30537444353104, 136.51481866836548, 130.723078250885, 113.30818712711334, 82.91506201028824, 85.72430446743965, 115.90313628315926, 139.23529028892517, 140.76900959014893, 134.74101305007935, 129.46163713932037, 128.11593174934387, 116.10577180981636, 112.22342893481255, 88.10392677783966, 51.16700939834118, 19.313995018601418, 4.756483593955636, 0.36176187393721193, 0.6435873184818774, 0.643453256925568, 0.28721201175358146, 0.3437180968467146, 0.45024226361420006, 0.17851890355814248, 0.13660057709785178, 0.20096765365451574, 0.19281799643067643, 0.3180430823704228, 0.27580989233683795, 0.26819777267519385, 0.18876738409744576, 0.25149131601210684, 0.18479594407835975, 0.20144529989920557, 0.11873721610754728, 0.16560875490540639, 0.15359874232672155, 0.1682595579768531, 0.11392908621928655, 0.21941671759122983, 0.1893355426727794, 0.19853211793815717, 0.16584955214057118, 0.22883397788973525, 0.21071554074296728, 0.13816529157338664, 0.2119095524540171, 0.3055315709207207, 0.20495743956416845, 0.21108233981067315, 0.21572674449998885, 0.3182994498638436, 0.4809437255607918, 0.4169856762746349, 0.2818093547830358, 0.23966636537807062, 0.2825305738952011, 0.44592064863536507, 0.14536954171489924, 0.24987325596157461, 0.3174147801473737, 0.31903269176837057, 0.2921383286593482, 0.4979363246820867, 0.3901659732218832, 0.42130681627895683, 0.3381480707321316, 0.42176003102213144, 0.25887797120958567, 0.2269356680335477, 0.275327229173854, 0.30230468313675374, 0.3964401193661615, 0.22418871230911463, 0.24215352488681674, 0.27166701620444655, 0.14931515499483794, 0.09089464059798047, 0.1480626323609613, 0.24766968592302874, 0.1311535990680568], [0.6547819334082305, 0.5594227253459394, 0.6362963409628719, 0.5309988255612552, 0.5736974906176329, 0.8390408742707223, 0.7428141252603382, 0.6289261614438146, 0.774169567739591, 0.7134099374525249, 0.719729473348707, 0.6452688470017165, 0.7945411058608443, 0.598111180588603, 0.7469868951011449, 0.7366842229384929, 0.730277766706422, 0.7047740695998073, 0.9306448744609952, 0.8316494396422058, 0.6684542528819293, 0.8136900595854968, 0.6623979122377932, 0.5271638813428581, 0.6283743598032743, 0.6458790111355484, 0.8951707498636097, 0.639020794769749, 0.7383509678766131, 0.8052982692606747, 0.7620678702369332, 0.7113505667075515, 0.6873234466183931, 0.652420538244769, 0.7501737959682941, 0.8829555928241462, 0.7544873363804072, 0.9278048237320036, 0.7427138462662697, 0.6581213010940701, 0.6303674716036767, 0.6127364176791161, 0.8181741158477962, 0.7199137040879577, 0.7292097271420062, 0.700937284855172, 0.6882419879548252, 0.651438053464517, 0.9514021512586623, 0.8865802420768887, 0.9657565341331065, 1.0213828179985285, 0.8578115107957274, 0.8894220739603043, 0.950513236457482, 0.8676333900075406, 0.6730252888519317, 0.8672104252036661, 0.8537323109339923, 0.7869893673341721, 0.9587367670610547, 0.8349391131196171, 0.8417697215918452, 0.9601685777306557, 0.8187683089636266, 0.7714251650031656, 0.6391187582630664, 0.9610193758271635, 1.3362393854185939, 1.205732300877571, 1.0894697019830346, 0.9167627349961549, 1.2372406851500273, 0.4092993418453261, 4.720665765926242, 9.33528397232294, 12.648306246846914, 23.835972771048546, 33.322247341275215, 26.88449028879404, 25.141284428536892, 23.461295776069164, 16.88556432723999, 16.58885534852743, 8.063875995576382, 3.050639941357076, 1.551255953963846, 1.4284111582674086, 1.6343724564649165, 1.8949694791808724, 1.4146822574548423, 3.524918141774833, 4.439017754048109, 4.431975306943059, 3.959770370274782, 6.71800721436739, 4.741154266521335, 1.862039496190846, 1.360784168355167, 0.7458807388320565, 1.3469068380072713, 5.191764011979103, 9.272746928036213, 5.528721380978823, 3.783314013853669, 4.897283613681793, 2.56467143073678, 1.148517346009612, 0.8606322656851262, 1.6111701889894903, 2.1031204098835588, 1.2876946153119206, 0.5144564132206142, 0.5466516700107604, 0.8650733367539942, 1.484775790013373, 1.2394925393164158, 1.3487050915136933, 0.7757973647676408, 0.7890938012860715, 0.7912339770700783, 0.7919209683313966, 1.0010022553615272, 0.9899133816361427, 0.7560365251265466, 0.5964220524765551, 0.9008668817114085, 0.5022029613610357, 0.808494194643572, 0.7099903584457934, 0.6507072458043694, 0.7651417271699756, 0.5760971806012094, 0.5712181236594915, 0.590303490171209, 0.7105795049574226, 0.8250420691911131, 0.7429547770880163, 0.764827769016847, 0.980407182360068, 0.9079192439094186, 0.7224716793280095, 0.6102656002622098, 0.6485832191538066, 0.9586169547401369, 0.7671924890019, 0.7139769976492971, 0.6305208883713931, 0.6270887819118798, 0.7053325802553445, 0.7862716214731336, 0.6264132494106889, 0.6901196215767413, 0.6079579959623516, 0.6018345651682466, 0.599866567645222, 0.7296619622502476, 0.6257568346336484, 0.2991932141594589, 0.6096477177925408, 0.5191890592686832, 0.7104356470517814, 0.5151505290996283, 0.7170502014923841, 0.8688580524176359, 0.8571210759691894, 0.8036554511636496, 0.6525262200739235, 0.8304755995050073, 0.7689440762624145, 0.676430796738714, 0.7762775640003383, 0.5744388664606959, 0.755796009907499, 0.6718949682544917, 0.7780257076956332, 0.7007924770005047, 0.48921837529633194, 0.6804133392870426, 0.6810008233878762, 0.5913109704852104, 0.6655496056191623, 0.8055704890284687, 0.7210602331906557, 0.7422739011235535, 0.6674296734854579, 0.7356367260217667, 0.6444387696683407, 0.6753450643736869, 0.5971663375385106, 0.6577579455915838, 0.7610736298374832, 0.5997873656451702, 0.600203265203163, 0.6746421020943671, 0.6260732270311564, 0.7436660514213145, 0.6889574183151126, 0.7394684641622007, 0.47336313233245164, 0.5209303158335388, 0.811920779524371, 0.6659543432760984, 0.5378132849000394, 0.7132659608032554, 0.7399686123244464, 0.9125758346635848, 0.9434542839881033, 0.7563193130772561, 0.7072111044544727, 0.6678695592563599, 0.6424092629458755, 0.6364760000724345, 0.639519696123898, 0.7123405323363841, 0.5229163623880595, 0.6135954090859741, 0.5708959721960127, 0.8193277101963758, 0.7203350064810365, 0.5283256690017879, 0.8466557844076306, 0.7793626422062516, 0.8537275018170476, 0.746181100839749, 0.9393273491878062, 1.0547186667099595, 1.0817321296781301, 0.8363200421445072, 0.9708162595052272, 0.741097389254719, 0.7422147667966783, 0.6137667561415583, 1.0499882767908275, 0.9325263078790158, 0.47068795713130385, 1.220260583795607, 1.329786500427872, 0.883667164016515, 0.45146511518396437, 0.954656379763037, 1.1218666448257864, 1.0168755473569036, 0.8398302819114178, 0.5022134108003229, 0.16160471976036206, 0.06632644290220924, 1.0793671128340065, 3.1760379625484347, 9.010089822113514, 21.70717690140009, 31.352552734315395, 39.97845657169819, 56.72686725854874, 71.89645126461983, 59.16541300714016, 52.11328782141209, 46.12528033554554, 35.64624443650246, 36.07752129435539, 20.6812946498394, 7.937575522810221, 1.992588615976274, 1.05466665700078, 0.9784103895071894, 1.2977669248357415, 3.3686769381165504, 7.162973312661052, 10.021836832165718, 11.191656310111284, 8.043789323419333, 11.274678055197, 8.209693171083927, 4.383554980158806, 2.3248539492487907, 1.5139065706171095, 4.15479633025825, 12.12506577372551, 20.23138739168644, 15.046890489757061, 12.594666425138712, 11.934404354542494, 7.70372562110424, 3.9797003008425236, 1.2896823836490512, 0.4439374222420156, 1.7471316433511674, 1.8634786689653993, 1.1657140357419848, 0.45145042065996677, 0.5877824441995472, 1.270861637312919, 1.1173745733685791, 0.9766368940472603, 0.8203493803739548, 0.957168044988066, 0.8608922548592091, 0.8371206116862595, 1.3061907165683806, 0.8942642610054463, 0.5461243889294565, 0.9600446093827486, 0.7487822987604886, 0.6807642860803753, 0.5475784046575427, 0.4392924386775121, 0.5199100112076849, 0.5773376952856779, 0.4577938833972439, 0.5082370969466865, 0.7886229234281927, 0.567826924379915, 0.7300716277677566, 0.8151434815954417, 0.7902672851923853, 0.8504059456754476, 0.8415805629920214, 0.6894816120620817, 0.6279327522497624, 0.527335109654814, 0.7210968062281609, 0.6833789614029229, 0.5919158505275846, 0.6351604394149035, 0.4785426997113973, 0.5591741355601698, 0.7534307555761188, 0.47033561510033906, 0.7153402932453901, 0.5331632844172418, 0.46198648342397064, 0.5869268963579088, 0.4491812892956659, 0.3653172362828627, 0.4735912091564387, 0.4347010678611696, 0.550055515486747, 0.7226904644630849, 0.581606647465378, 0.5344952910672873, 0.6510365812573582, 0.7062030304223299, 0.7541918428614736, 0.6477814621757716, 0.7944496732670814, 0.565279636066407, 0.623881338397041, 0.6215527164749801, 0.543493980076164, 0.6587209564168006, 0.5949210142716765, 0.6155368080362678, 1.048205103725195, 0.5851097032427788, 0.9587590314913541, 0.6936005316674709, 0.7668129249941558, 1.0544622992165387, 1.0703591024503112, 0.7962972647510469, 0.9892110130749643, 0.9172699484042823, 1.1952261021360755, 1.049018616322428, 1.1769417207688093, 0.9739529911894351, 0.9236622147727758, 1.1297227232716978, 1.03481937199831, 0.9451161010656506, 1.0073842504061759, 1.1192221054807305, 0.9046936919912696, 0.9834584186319262, 1.01246802136302, 0.6982149684336036, 0.8783618768211454, 1.098290691152215, 1.1529961181804538, 0.9545658377464861, 1.286121024750173, 0.9770828951150179, 1.2112244311720133, 1.123131145723164, 1.0657148016616702, 1.0764384199865162, 1.0240336507558823, 1.0834710113704205, 1.1126187723129988, 1.484722236637026, 0.8705285377800465, 0.6958317244425416, 1.0173961194232106, 0.7966469053644687, 1.3572533265687525, 0.9798293164931238, 0.9330509172286838, 1.1701869894750416, 1.1160016595385969, 1.199801650363952, 1.2679031398147345, 1.1630476475693285, 1.5590246370993555, 1.2418539938516915, 1.1406770604662597, 1.2562564085237682, 1.2362755369395018, 1.21293825795874, 1.0624023294076324, 1.3930029957555234, 1.2486580037511885, 0.9238444268703461, 1.861220640130341, 2.027574763633311, 1.0652259341441095, 1.3127326592803001, 1.890913078095764, 1.3002676656469703, 1.1032990599051118, 1.2607229501008987, 1.3668858096934855, 1.1592104472219944, 0.9077465906739235, 0.7902529765851796, 1.6059117461554706, 3.7916913768276572, 9.93573060259223, 15.667888317257166, 22.868947461247444, 39.893945306539536, 56.799120381474495, 43.34464654326439, 37.72892788052559, 33.30690756440163, 25.60633957386017, 24.67507604509592, 14.80678042396903, 4.956692475825548, 2.0072912145406008, 1.2362777930684388, 1.51847226312384, 2.267571547999978, 3.387038502842188, 5.988559881225228, 9.38177827745676, 10.230419039726257, 7.864708732813597, 10.57017020881176, 6.9769875425845385, 3.693602252751589, 1.9504750007763505, 1.3842311664484441, 3.158390996977687, 8.541565462946892, 14.300165958702564, 10.796550661325455, 8.544154074043036, 7.435527937486768, 4.342462560161948, 2.134705977514386, 0.6875633087474853, 1.9163148337975144, 2.3247366305440664, 1.9863697746768594, 0.9744593733921647, 0.5033806012943387, 0.9625962912105024, 1.7986908392049372, 2.041236930526793, 2.0992317935451865, 1.261651525273919, 1.3429155084304512, 1.2320949300192297, 1.3155148224905133, 1.8500899686478078, 1.2533877999521792, 1.0289209010079503, 1.2281165434978902, 1.1579220788553357, 0.9299748041667044, 0.8452344825491309, 0.7761743164155632, 0.9020664892159402, 1.2432943540625274, 0.9656348219141364, 0.8055666892323643, 1.1649356712587178, 1.0491003119386733, 1.0846940707415342, 1.030958304181695, 0.8870336646214128, 1.2322378973476589, 1.0710832010954618, 1.205358614679426, 0.9029901959002018, 0.6179504503961653, 1.0700407507829368, 0.934609902324155, 0.8629857643973082, 0.8887802646495402, 0.7353524537757039, 0.9168137947563082, 1.0401411051861942, 0.7546862319577485, 0.9479274158366024, 0.7604456541594118, 0.7338761142455041, 1.061112298630178, 0.6878629582934082, 0.741532287793234, 0.7054780411999673, 1.0398645512759686, 0.8357677061576396, 1.0883411625400186, 0.8827388857025653, 0.9031959192361683, 1.0687173530459404, 0.9593578556086868, 1.0307151172310114, 1.0894687520340085, 0.9314012713730335, 1.0795572213828564, 0.9715146501548588, 0.9009481617249548, 0.9047622070647776, 1.2833978771232069, 0.9160291962325573, 1.0664837853983045], [0.07821983439498581, 0.12474687566282228, 0.22657191177131608, 0.1728924148483202, 0.15228534874040633, 0.12301669194130227, 0.20798590674530715, 0.1591005056980066, 0.22131268226075917, 0.16012431326089427, 0.12895767315058038, 0.14861631905660033, 0.26569940673653036, 0.20362587820272893, 0.135650405427441, 0.14613610605010763, 0.17117389768827707, 0.1122117045451887, 0.16032806248404086, 0.07425934847560711, 0.1985994158894755, 0.14674463745905086, 0.20119596796575934, 0.15133649809285998, 0.1727977761765942, 0.1818821090273559, 0.17315731704002246, 0.056924804812297225, 0.16154919227119535, 0.12577648682054132, 0.12953245168318972, 0.08760919736232609, 0.1638372929301113, 0.23544914089143276, 0.2183973035425879, 0.14385311136720702, 0.22511765855597332, 0.16718709521228448, 0.1280751556623727, 0.22524750471347943, 0.06818085472332314, 0.1279352608253248, 0.13238787971204147, 0.23534417152404785, 0.09281787919462658, 0.15252806071657687, 0.16256562288617715, 0.10856716573471203, 0.2784883033018559, 0.15938103751977906, 0.08206366954254918, 0.06950146940653212, 0.23899083287687972, 0.07418321154545993, 0.1450205096625723, 0.18465037923306227, 0.1370018711895682, 0.19798695109784603, 0.16735891724238172, 0.15038883488159627, 0.17305438115727156, 0.19138795207254589, 0.17250894714379683, 0.1984571758657694, 0.07692661980399862, 0.17338629928417504, 0.24758125160587952, 0.11449659170466475, 0.13864470412954688, 0.23780404968420044, 0.12086821152479388, 0.633987074252218, 0.4983849381096661, 0.4820252425270155, 0.26825239474419504, 0.4360374977113679, 0.19486599747324362, 0.062105912147671916, 0.1465936697786674, 0.06774682449758984, 0.19209642108762637, 0.2402015429106541, 0.16500163357704878, 0.15850205265451223, 0.04533318911853712, 0.1515332711278461, 0.10822212643688545, 0.21147609368199483, 0.06618171668378636, 0.12373477919027209, 0.07736112500424497, 0.1057124872750137, 0.13064758793916553, 0.091602345200954, 0.06674409392871894, 0.14444375701714307, 0.19199822010705248, 0.14658750995295122, 0.1533686913899146, 0.2996824379079044, 0.28053455287590623, 0.041391880295122974, 0.1492239598883316, 0.06881085646455176, 0.1627299195388332, 0.13462398550473154, 0.12208045038278215, 0.1571243000216782, 0.243772950489074, 0.284985865582712, 0.14202861551893875, 0.10461895493790507, 0.24065981910098344, 0.41200328269042075, 0.19460924406303093, 0.10711679395171814, 0.05145391478436068, 0.1719238972873427, 0.15759912610519677, 0.14265794190578163, 0.21027571434387937, 0.19749311119085178, 0.14193675247952342, 0.15855262259719893, 0.19690533023094758, 0.2152108628069982, 0.23199220217065886, 0.23716801428236067, 0.22245354135520756, 0.1715678148320876, 0.1657651551067829, 0.18896440946264192, 0.272658733301796, 0.16920006688451394, 0.11590349589823745, 0.13291403272887692, 0.17288206930970773, 0.21450586704304442, 0.13995843910379335, 0.08382920917938463, 0.15391845954582095, 0.1321471863775514, 0.2211856414214708, 0.15276961494237185, 0.3536314086522907, 0.20998361986130476, 0.19347087858477607, 0.09026169253047556, 0.12268552338355221, 0.22726356372004375, 0.23316406819503754, 0.20143489498877898, 0.20675788982771337, 0.12499457487137988, 0.09849614754784852, 0.13294036412844434, 0.16038983885664493, 0.2008590626064688, 0.18040297902189195, 0.2055980169097893, 0.15182533592451364, 0.14072914462303743, 0.20864419173449278, 0.14100180967943743, 0.2697510283906013, 0.17054149881005287, 0.09979216745705344, 0.15999406634364277, 0.14847115497104824, 0.13975498673971742, 0.14913260150933638, 0.18651002319529653, 0.08047169598285109, 0.1472408077097498, 0.11664071571431123, 0.1844128771335818, 0.309641495696269, 0.2866444765822962, 0.2311922560329549, 0.23305765906115994, 0.3157619578996673, 0.3196487040258944, 0.2739131706766784, 0.3716861695284024, 0.2951458375900984, 0.3118226083461195, 0.22526080399984494, 0.2715078997425735, 0.25418195757083595, 0.36036461766343564, 0.3862360044149682, 0.25321297987829894, 0.3699496923945844, 0.19300509185995907, 0.4623815731611103, 0.3446342039387673, 0.33640791254583746, 0.3953233949141577, 0.23322125809499994, 0.3389025974320248, 0.3841913281939924, 0.3171356732491404, 0.3364082094049081, 0.24878053256543353, 0.2860149275511503, 0.36576347483787686, 0.31955071084666997, 0.2377628011163324, 0.27795852860435843, 0.3947419667383656, 0.2929903141921386, 0.36844518093857914, 0.507277351571247, 0.3223527339287102, 0.32183860370423645, 0.3786149196093902, 0.367490571225062, 0.3189265646506101, 0.2863423037342727, 0.3554842248558998, 0.36877166654448956, 0.3184890537522733, 0.3873651969479397, 0.22162474051583558, 0.22559981705853716, 0.22088244440965354, 0.32140477385837585, 0.2787068806355819, 0.21890018280828372, 0.22279218334006146, 0.4035316966474056, 0.3250927431508899, 0.2617406425997615, 0.2106010273564607, 0.29391568328719586, 0.350144591066055, 0.21003732166718692, 0.1927856239490211, 0.6023502093739808, 0.3630176471779123, 0.21179524686885998, 0.24163899390259758, 0.26743431051727384, 0.31791231594979763, 0.22368173638824373, 0.475801948341541, 0.24771004391368479, 0.464305873028934, 0.051149530336260796, 0.28951780521310866, 0.21784560580272228, 0.37397919804789126, 0.2898946974892169, 0.3363114333478734, 0.8036528981756419, 0.301070818095468, 0.41384315583854914, 0.39979409251827747, 0.23662437626626343, 0.4773870570352301, 0.26162774709519, 0.28538623941130936, 0.36995723261497915, 0.4366714402567595, 0.29600690701045096, 0.3911479830276221, 0.2982779679587111, 0.36104264378082007, 0.3726484678918496, 0.3663446655264124, 0.340183989610523, 0.2066616778029129, 0.27325752773322165, 0.26956807414535433, 0.27502051438204944, 0.31516815070062876, 0.23688924877205864, 0.029573542196885683, 0.02723867139138747, 0.0353220177203184, 0.16341800917871296, 0.29545750992838293, 0.2985876513412222, 0.25560415000654757, 0.4543241945793852, 0.30103780736681074, 0.23858738655690104, 0.17194047686643898, 0.30019101686775684, 0.7017700339201838, 0.5696559324860573, 0.2624165313318372, 0.2836398471845314, 0.5303175933659077, 0.3832668496761471, 0.27549931837711483, 0.3494773112470284, 0.30360415403265506, 0.2348779543535784, 0.3552573354681954, 0.6712295883335173, 0.32642314676195383, 0.36144969693850726, 0.42528938851319253, 0.3536379395518452, 0.3501591371605173, 0.4039748478680849, 0.2678660920355469, 0.4537145351059735, 0.3046162653481588, 0.3230610099853948, 0.24223894608439878, 0.3097477415576577, 0.24418810789939016, 0.21090176043799147, 0.4236392379971221, 0.2750130632193759, 0.3764835902256891, 0.2925251954002306, 0.4016564675839618, 0.33527515770401806, 0.3515523858368397, 0.4031420691171661, 0.23818649322493002, 0.26141555223148316, 0.40813203260768205, 0.215790361398831, 0.3186356427613646, 0.3145513666095212, 0.2645331365056336, 0.2836677816230804, 0.3560023329919204, 0.3007342986529693, 0.26011536887381226, 0.3092541836667806, 0.3130970837082714, 0.2477218143758364, 0.3863889165222645, 0.3486939298454672, 0.2439942440832965, 0.3583053359761834, 0.24525110085960478, 0.29424671083688736, 0.21928972128080204, 0.32386389502789825, 0.24415073334239423, 0.199264409893658, 0.30437233624979854, 0.23469918582122773, 0.38643365318421274, 0.2337531850207597, 0.4093299777014181, 0.29821660718880594, 0.31852859538048506, 0.3352838259888813, 0.399475236190483, 0.2990369178587571, 0.4090092214755714, 0.4277146380627528, 0.34929316956549883, 0.435233959578909, 0.3523203305667266, 0.24298841133713722, 0.40945822081994265, 0.4024874948663637, 0.5201536731328815, 0.3204425942385569, 0.4669076349819079, 0.6240061379503459, 0.2542808116413653, 0.5278698715846986, 0.39428955351468176, 0.45319236000068486, 0.4998717864509672, 0.4207747260807082, 0.39134860038757324, 0.4045058396877721, 0.384339431184344, 0.33969826879911125, 0.4566350346431136, 0.37559642689302564, 0.487848311313428, 0.3553776821354404, 0.22538817138411105, 0.33535516122356057, 0.4309652152005583, 0.3053082141559571, 0.40730343956965953, 0.49858407117426395, 0.2856076369062066, 0.2573104068869725, 0.3346726525342092, 0.4187837219797075, 0.48585861339233816, 0.270046106306836, 0.48595360829494894, 0.32058416632935405, 0.3671626903815195, 0.4281773226102814, 0.31156348006334156, 0.39872795285191387, 0.30169757665134966, 0.34693221969064325, 0.3272680373629555, 0.44650724215898663, 0.2824555872939527, 0.3715117648243904, 0.3670315380441025, 0.30322426347993314, 0.2587966318242252, 0.3257861762540415, 0.2634775353362784, 0.2958638209383935, 0.29870027967263013, 0.6721403519622982, 0.32753126230090857, 0.2502524934243411, 0.3136411670129746, 0.5672378372400999, 0.5161864485125989, 0.23105743748601526, 0.5174022051505744, 0.1974740528385155, 0.7582835108041763, 0.6245337752625346, 0.41538771358318627, 0.2588888065656647, 0.4478018148802221, 0.2933125843992457, 0.2192544098943472, 0.2489751236862503, 0.2368187002139166, 0.45644991332665086, 0.4525590705452487, 0.30023866274859756, 0.6880812090821564, 0.2813111065188423, 0.30994524189736694, 0.35761427774559706, 0.5214868672192097, 0.36572372540831566, 0.3663682361366227, 0.24899027834180743, 0.22778652550186962, 0.32751187740359455, 0.3414651146158576, 0.36189100763294846, 0.12154865704360418, 0.1718284422531724, 0.2735502307768911, 0.26576979202218354, 0.37055736291222274, 0.3713774064090103, 0.09543854364892468, 0.18834544345736504, 0.11438110610470176, 0.3430798201588914, 0.4274200351210311, 0.33677678962703794, 0.2145261425175704, 0.3671979869250208, 0.4491197504103184, 0.32952936133369803, 0.3827862348407507, 0.3439104021526873, 0.9155658585950732, 0.6972648412920535, 0.2322200415073894, 0.18471534684067592, 0.5857488408219069, 0.4321757174329832, 0.3076579427579418, 0.41629156039562076, 0.37426222348585725, 0.23148359352489933, 0.44234851375222206, 0.5887183814775199, 0.39034619636368006, 0.4163545835763216, 0.5773175682406873, 0.3663454670459032, 0.4610486462479457, 0.44287134194746614, 0.3045490267686546, 0.4376078228233382, 0.47149829333648086, 0.33619283814914525, 0.32357810880057514, 0.3246836119797081, 0.2999883808661252, 0.307415112038143, 0.41780536354053766, 0.34745083248708397, 0.4873362887883559, 0.3989545750664547, 0.3831176779931411, 0.5026286572683603, 0.3765419527189806, 0.4064659704454243, 0.2383441402344033, 0.26626213279087096, 0.46780263539403677, 0.35376149229705334, 0.317065644194372, 0.28480953129474074, 0.3436657605925575, 0.4080667532980442, 0.28552629752084613, 0.43237606761977077, 0.2980250143446028, 0.31885413103736937, 0.325014372356236, 0.2989439119119197, 0.40816272783558816, 0.3587870195042342, 0.33203238795977086, 0.43299445474985987, 0.30599873804021627, 0.23069161805324256, 0.2408397602266632, 0.29061743058264256, 0.37093256309162825, 0.31790584442205727, 0.4481436777859926, 0.30677716189529747, 0.40131154702976346, 0.34223071415908635, 0.5655583273619413], [0.02479355454852339, 0.041371983315912075, 0.04266644471499603, 0.01959669141797349, 0.009156041014648508, 0.040065365537884645, 0.04347978661826346, 0.029524395322368946, 0.05158274791028816, 0.05054793429735582, 0.02261137320601847, 0.05424054943432566, 0.040001789457164705, 0.03870514243317302, 0.02656199041666696, 0.026227723392366897, 0.0651475487393327, 0.010795724465424428, 0.027721700062102173, 0.009003495342767565, 0.06862943104351871, 0.05679263202182483, 0.06109125155489892, 0.04338874736276921, 0.006890288741487893, 0.06676464399788529, 0.08131145092193037, 0.0200586263963487, 0.013823288081766805, 0.010063911195175024, 0.08770296029979363, 0.0921194588590879, 0.05853520218806807, 0.04843731083383318, 0.05404222902143374, 0.0329556724318536, 0.02019795349042397, 0.03649069622042589, 0.03991169643995818, 0.011146556225867243, 0.07931272106361575, 0.011054600417992333, 0.08827889658277854, 0.0377776211098535, 0.0424716903216904, 0.017409788160875905, 0.07113440209650435, 0.01155183472292265, 0.012273081665625796, 0.021059848550066818, 0.02927682042354718, 0.023742174344079103, 0.07671582759940065, 0.03472627722658217, 0.020054125270689838, 0.07850032910937443, 0.03417368519876618, 0.10051320845377631, 0.041169184041791596, 0.03567166946595535, 0.01771084778738441, 0.050183925704914145, 0.02200585306127323, 0.037369836936704814, 0.1391091401455924, 0.03702258603880182, 0.06750207903678529, 0.10610288663883694, 0.046471061068587005, 0.04254507388395723, 0.019604901426646393, 0.16544895566767082, 0.17580485466169193, 0.19161792879458517, 0.06543453724589199, 0.0652717768389266, 0.012388012510200497, 0.06628372488194145, 0.11279466896667145, 0.08899499487597495, 0.12348715419648215, 0.11620491917710751, 0.15632836148142815, 0.11081925738835707, 0.03554481787432451, 0.015094913596840343, 0.1606038594036363, 0.107835801463807, 0.16033831896493211, 0.19258522923337296, 0.005715882252843585, 0.03742106739082374, 0.028835622906626668, 0.029370206721068826, 0.0463745447632391, 0.08355094832950272, 0.019665969048219267, 0.02076644046610454, 0.06557897402672097, 0.17760462214937434, 0.09875409581582062, 0.019863107590936124, 0.07478965751943178, 0.10831923646037467, 0.07234146076370962, 0.05180595624551643, 0.049374817754141986, 0.04243070892698597, 0.11939421718125232, 0.12727175111649558, 0.13935216382378712, 0.020463052351260558, 0.03938735797419213, 0.10016318934503943, 0.02503444455214776, 0.018528720502217766, 0.04918698388792109, 0.014080411638133228, 0.030100112671789248, 0.028370543077471666, 0.014588003541575745, 0.023123508908611257, 0.027582124348555226, 0.020247913016646635, 0.02747604918113211, 0.04266398820618633, 0.03713454272656236, 0.00984709460681188, 0.02314064509846503, 0.028333253867458552, 0.026252794996253215, 0.04536935026408173, 0.15448871097760275, 0.025979716192523483, 0.017033793883456383, 0.03960143047152087, 0.008831251216179226, 0.053880047489656135, 0.041330037129228, 0.009954154975275742, 0.060059443640057, 0.052777171513298526, 0.039743377346894704, 0.08160326338838786, 0.05471785429108422, 0.005301532391968067, 0.05721615714719519, 0.16359461063984782, 0.07418940105708316, 0.043540063852560706, 0.0439201584958937, 0.03159358282573521, 0.04915219571557827, 0.018512949864089023, 0.051132156659150496, 0.023353159085672814, 0.04511930215812754, 0.005211982070250087, 0.01869869087386178, 0.013900171798013616, 0.008623617777629988, 0.015877839505265, 0.08966073102783412, 0.017090347391786054, 0.006912594917594106, 0.004774343151439098, 0.008954852200986352, 0.04144372302107513, 0.06024802707543131, 0.03267407933890354, 0.03901767937350087, 0.04999623284675181, 0.09252925796317868, 0.06006326570059173, 0.02721572975133313, 0.01676617728662677, 0.04850430450460408, 0.042318136256653816, 0.06076066187233664, 0.01704227292066207, 0.014208489628799725, 0.048631096724420786, 0.03529981266183313, 0.02723968071222771, 0.029541344119934365, 0.04920839855913073, 0.021978571712679695, 0.021194019573158585, 0.01932691146066645, 0.022147050367493648, 0.0310280922712991, 0.017061845210264437, 0.039972274244064465, 0.010141525926883332, 0.02411594774457626, 0.029282752038852777, 0.0819723037420772, 0.04054948331031483, 0.019854400343319867, 0.05003877646231558, 0.015369134380307514, 0.13416029163636267, 0.04603881199727766, 0.020316804730100557, 0.035537196017685346, 0.06752429151674733, 0.0596625950129237, 0.06858007080154493, 0.04098022953257896, 0.06374070391757414, 0.026073646113218274, 0.04529204816208221, 0.034865277775679715, 0.019432597000559326, 0.04629915740224533, 0.021294914549798705, 0.02218850302597275, 0.013225627280917251, 0.04426671177498065, 0.005225404738666839, 0.017034246593539137, 0.0019039134190279583, 0.013669539202965098, 0.06740061260643415, 0.033806893552537076, 0.04050066112540662, 0.03295166854513809, 0.03530394271365367, 0.026636533584678546, 0.04186807193036657, 0.05850323417689651, 0.035235371979069896, 0.03355949120305013, 0.05763133682194166, 0.07313798560062423, 0.042382157625979744, 0.1059428573353216, 0.04367326822830364, 0.030888781875546556, 0.15353393799159676, 0.0723706568533089, 0.028524971021397505, 0.06260098773054779, 0.05662918512825854, 0.06859122528112493, 0.013195852316130185, 0.06747841194737703, 0.16361677116947249, 0.09845345179201104, 0.08950221570557915, 0.06462591540184803, 0.05619800474960357, 0.04569101191009395, 0.06003310852975119, 0.07849092609831132, 0.05117057393363211, 0.09607223386410624, 0.07577577882329933, 0.04491946405323688, 0.14230574830435216, 0.032878618949325755, 0.007984088715602411, 0.15464941563550383, 0.10784784652059898, 0.11972389402217232, 0.08102734936983325, 0.010740970665210625, 0.07565847496152855, 0.026256605924572796, 0.01296314077990246, 0.03722351881151553, 0.044838725807494484, 0.06274217390455306, 0.008896628860384226, 0.04901313950540498, 0.09449614968616515, 0.028955678280908614, 0.019830128403555136, 0.10581973503576592, 0.03634640044765547, 0.04139395088714082, 0.04777286601893138, 0.062139720685081556, 0.019197480905859265, 0.019743796219700016, 0.05137490574270487, 0.14139942271867767, 0.0504172940418357, 0.11277393336058594, 0.08988729387056082, 0.03567976629710756, 0.04081303850398399, 0.07955986366141587, 0.01808281220291974, 0.024136761276167817, 0.03154833408189006, 0.025849536068562884, 0.03213787393178791, 0.06496122514363378, 0.07701349561102688, 0.03794204763835296, 0.05009996282751672, 0.039701950663584284, 0.021108650325913914, 0.029189016931923106, 0.036482829455053434, 0.017298117199970875, 0.06348669645376503, 0.06002359419653658, 0.02470739676937228, 0.025660236460680608, 0.057323230503243394, 0.06320358195807785, 0.027928883573622443, 0.04063058891915716, 0.06030877186276484, 0.1109832942893263, 0.017759089241735637, 0.022724875416315626, 0.05451429802633356, 0.04734485461085569, 0.06630646428675391, 0.0368423257896211, 0.011986451245320495, 0.0343990940018557, 0.044727689382852986, 0.05928188067628071, 0.03862717239826452, 0.041327781000291, 0.043969518737867475, 0.007015089686319698, 0.025949993178073782, 0.08944717803387903, 0.038110986424726434, 0.05501122526766267, 0.00942037546337815, 0.023566858653794043, 0.004487617179620429, 0.0795017163909506, 0.08676651836140081, 0.005125943034727243, 0.013704630728170741, 0.01712344903353369, 0.017350225243717432, 0.0170979729591636, 0.021511901832127478, 0.005930765546509065, 0.10560378490481526, 0.031899874593364075, 0.033516739786136895, 0.018836817544070072, 0.04845046540140174, 0.09154249841230921, 0.1462342031300068, 0.1338665495859459, 0.13447237957734615, 0.11004780229995959, 0.12046342191752046, 0.1683616329682991, 0.11667070590192452, 0.11578786186873913, 0.10168003529543057, 0.12746273539960384, 0.16132984310388565, 0.12810807733330876, 0.12400346633512527, 0.09198403175105341, 0.1131389438523911, 0.19100981298834085, 0.14294219930889085, 0.1451193043612875, 0.11127633872092701, 0.19628070906037465, 0.11844982684124261, 0.18866657075705007, 0.15200042340438813, 0.12424200001987629, 0.2465131229837425, 0.1482595389825292, 0.10944306326564401, 0.10502784862183034, 0.19481386902043596, 0.16423527704318985, 0.2618861629161984, 0.1542811025865376, 0.11285789994872175, 0.11034696202841587, 0.14639458124293014, 0.09352930195746012, 0.14088309573708102, 0.14977905666455626, 0.09260817052563652, 0.1494407857535407, 0.12162103870650753, 0.1790307034389116, 0.07456086823367514, 0.09420994785614312, 0.11456261316197924, 0.18593637272715569, 0.16472800372866914, 0.13849930255673826, 0.1095824089134112, 0.16138192702783272, 0.06909833478857763, 0.1951233742875047, 0.08910930788260885, 0.1557342425803654, 0.28974421962630004, 0.15193694009212777, 0.24536687589716166, 0.22287763422355056, 0.1395888940896839, 0.2149377969908528, 0.09723494920763187, 0.23988690198166296, 0.21116856252774596, 0.2309633034747094, 0.13430849852738902, 0.14838570408755913, 0.2773917652666569, 0.13746316049946472, 0.0870063879119698, 0.17061314574675635, 0.35100099979899824, 0.3262250230181962, 0.20197534176986665, 0.12264081640751101, 0.12248452752828598, 0.11033289832994342, 0.1451873147743754, 0.1887734845513478, 0.23800971364835277, 0.19889162911567837, 0.13433487445581704, 0.2483036878402345, 0.3286250989185646, 0.13045488187344745, 0.07897983072325587, 0.2938083984190598, 0.17131020053057, 0.3161311912117526, 0.23964502121089026, 0.14024483389221132, 0.1597677409881726, 0.11345038612489589, 0.11861146660521626, 0.11141408875118941, 0.18287646817043424, 0.11787927112891339, 0.12283943739021197, 0.14900955342454836, 0.21190192317590117, 0.15346340427640826, 0.1303905970416963, 0.2274017664603889, 0.31771989190019667, 0.1565791925531812, 0.12564811011543497, 0.12928108626510948, 0.21231184102362022, 0.24996534164529294, 0.3768079087603837, 0.3426318598212674, 0.1324896578444168, 0.16521768760867417, 0.1768755808006972, 0.11806431823060848, 0.10782381577882916, 0.16872089181561023, 0.11879478450282477, 0.13939529744675383, 0.30764197173994035, 0.19726500468095765, 0.16687754541635513, 0.21094720956170931, 0.24170041404431686, 0.16985118272714317, 0.14932110701920465, 0.12232069100718945, 0.0805156237038318, 0.1259766292059794, 0.12982275016838685, 0.14804453880060464, 0.09377973969094455, 0.2998346969252452, 0.10209048006800003, 0.07000405181315728, 0.13617136341053993, 0.1334548505838029, 0.21082454739371315, 0.2359015986439772, 0.17034524527844042, 0.25354382931254804, 0.0960895259049721, 0.10916388215264305, 0.15631624963134527, 0.12403862929204479, 0.12624032911844552, 0.22829212102806196, 0.23009895376162603, 0.13303635350894183, 0.22349570965161547, 0.15970746375387534, 0.26088631188031286, 0.12834311550250277, 0.08820562434266321, 0.11499856555019505, 0.12695513607468456, 0.12417911784723401, 0.13890363945392892, 0.15970290696714073, 0.09248480331734754, 0.10332147299777716, 0.1136607033549808, 0.11450268473709002, 0.2638219215441495, 0.11273544558207504, 0.11510744603583589, 0.11613811104325578, 0.1561639757710509, 0.1395652344217524, 0.09482223453233019, 0.14904286101227626, 0.18156727513996884, 0.13698607828700915, 0.11464634968433529, 0.11060831675422378, 0.1019903198175598], [0.007709064557275269, 0.023127822641981766, 0.023070775605447125, 0.028096028217987623, 0.04368999623693526, 0.02492185332812369, 0.079856581724016, 0.02840086537617026, 0.010740004945546389, 0.034153116575907916, 0.01971980444068322, 0.021069553986308165, 0.04726510713226162, 0.10683963148039766, 0.023754926296533085, 0.032763723356765695, 0.00875635367265204, 0.04246407588652801, 0.025334353849757463, 0.06833086503320374, 0.05920106821577065, 0.012870522605226142, 0.08163759513990954, 0.02475333385518752, 0.0869268667884171, 0.04983906452252995, 0.05227457055298146, 0.03567542844393756, 0.035727645954466425, 0.005392225621108082, 0.03701246314449236, 0.027741725061787292, 0.02796356970065972, 0.004500755976550863, 0.013456192154990276, 0.008377342564926948, 0.0641339531284757, 0.013578128873632522, 0.05777535057859495, 0.003686827544697735, 0.015764543240948115, 0.052966805087635294, 0.017135599846369587, 0.03350026410771534, 0.0223679821647238, 0.030166931937856134, 0.02574952239228878, 0.09654331210185774, 0.07598674172186293, 0.05318795396306086, 0.03568489453755319, 0.050922470254590735, 0.02410483779385686, 0.04419596283696592, 0.020891848580504302, 0.03938982932595536, 0.03350553335621953, 0.046583444491261616, 0.08086864851065911, 0.036634220159612596, 0.040256676365970634, 0.0168552294417168, 0.007188769868662348, 0.024089007783913985, 0.08141630154568702, 0.042441236291779205, 0.066823444358306, 0.04255712265148759, 0.019229302342864685, 0.01618416095880093, 0.04008839066955261, 0.10766720777610317, 0.0793085056648124, 0.05651947343721986, 0.06261538539547473, 0.05274191949865781, 0.07801696832757443, 0.036726702892337926, 0.03680460242321715, 0.05831345959450118, 0.08870301171555184, 0.10943069908535108, 0.08456665906123817, 0.05629452847642824, 0.04269941091479268, 0.0411584934045095, 0.03215458709746599, 0.011737070144590689, 0.03905488694726955, 0.02458832474076189, 0.023875948318163864, 0.0502922941086581, 0.16234504175372422, 0.056384157651336864, 0.05094665313663427, 0.077917958406033, 0.034492144477553666, 0.008053416440816363, 0.014759822788619203, 0.03787026340432931, 0.09276229233364575, 0.033575551278772764, 0.009558928868500516, 0.1064204887370579, 0.022535306779900566, 0.023197488044388592, 0.04145991297264118, 0.050411431075190194, 0.029348272546485532, 0.03873314737575129, 0.011740998888853937, 0.06396671014954336, 0.07456542502040975, 0.11745889642043039, 0.028140106223872863, 0.06765507278032601, 0.03638720001617912, 0.0609159265877679, 0.09189805394271389, 0.046464415136142634, 0.02188369369832799, 0.03346231809700839, 0.06082767038606107, 0.07647931997780688, 0.008977381021395558, 0.0028630867609535926, 0.07208097435068339, 0.02556880015617935, 0.09034483533469029, 0.038881406217115, 0.009514547509752447, 0.03803543950198218, 0.09661086238338612, 0.03420795015699696, 0.04190293802821543, 0.08613810481620021, 0.0557060721621383, 0.04409542780194897, 0.006336976366583258, 0.029306491487659514, 0.023608194424014073, 0.03304901976662222, 0.07462998444680125, 0.03753028555365745, 0.02998628948262194, 0.029666969312529545, 0.027919911008211784, 0.03894579866027925, 0.01594360492163105, 0.02295808790222509, 0.10346091512474231, 0.03255751762480941, 0.03806339991569985, 0.024728368007345125, 0.04536549480690155, 0.027517824673850555, 0.07962165487697348, 0.014498949531116523, 0.02074604624795029, 0.019493531035550404, 0.020778227626578882, 0.017883463915495668, 0.026620432690833695, 0.02993985515786335, 0.01906711153424112, 0.04416026182298083, 0.017660533885646146, 0.029702902247663587, 0.02437697407003725, 0.041398169996682554, 0.04218287613184657, 0.03826779480732512, 0.03748850263946224, 0.07638075534487143, 0.09984468182665296, 0.060375850880518556, 0.039261478596017696, 0.03968619115767069, 0.0464519841625588, 0.04532624261628371, 0.013604244122689124, 0.025570828074705787, 0.12043104201438837, 0.07170780765591189, 0.01798492477973923, 0.07440377041348256, 0.0012163126689301862, 0.04573820508085191, 0.06450145723647438, 0.053803940245416015, 0.008543236690456979, 0.05708238502847962, 0.061258873029146343, 0.007441982770615141, 0.030022233549971133, 0.015174435648077633, 0.040508420279365964, 0.021415673109004274, 0.02068902518658433, 0.02473202308465261, 0.016345277508662548, 0.0230549567277194, 0.03306308717583306, 0.026962373522110283, 0.033812032925197855, 0.0057268934051535325, 0.024451743593090214, 0.13190600322559476, 0.03264937324274797, 0.027502723823999986, 0.010622929294186179, 0.05726410359784495, 0.05652255335007794, 0.007722350856056437, 0.04396256110339891, 0.06189015868585557, 0.058440407665329985, 0.04107709464733489, 0.047532016833429225, 0.04047629641718231, 0.01783132061973447, 0.011507175058795838, 0.04193660555756651, 0.05673465915606357, 0.04533587569312658, 0.0062811033149046125, 0.1139209300163202, 0.034415725531289354, 0.041651268329587765, 0.04899631872831378, 0.01433921523130266, 0.03944019146729261, 0.029287683610164095, 0.1154056483937893, 0.055727954386384226, 0.07973014944582246, 0.002801360251396545, 0.023855555955378804, 0.0893502015969716, 0.022806238921475597, 0.13888514513382688, 0.037260830285958946, 0.03618984068452846, 0.0732197702745907, 0.0613832866656594, 0.015889745409367606, 0.022488668364530895, 0.01998736352106789, 0.059260992929921485, 0.045784648682456464, 0.009694535947346594, 0.011638742998911766, 0.1287016915739514, 0.06412224203813821, 0.036227964810677804, 0.08908411939046346, 0.1020209705166053, 0.10235202775220387, 0.15237550484016538, 0.19413170171901584, 0.010430351248942316, 0.1200840731326025, 0.03756175261514727, 0.04216884211928118, 0.04771391722897533, 0.025596439591026865, 0.05351120751583949, 0.05817380595544819, 0.02572767170931911, 0.06835119987954386, 0.06792617932660505, 0.01038225544107263, 0.041246059408877045, 0.05532195507839788, 0.013734559688600712, 0.039257081371033564, 0.006890521126479143, 0.009562968934915261, 0.054913150452193804, 0.039434681020793505, 0.07313966285437346, 0.15810927841812372, 0.0361847866588505, 0.04464966739760712, 0.016836976319609676, 0.07629053987329826, 0.05521907856746111, 0.07211867545265704, 0.08912458128179424, 0.04182040749583393, 0.07100446688127704, 0.1030141644878313, 0.03330436680698767, 0.05838930337631609, 0.027591774123720825, 0.03885461839672644, 0.035727760987356305, 0.022782354753871914, 0.0784668508276809, 0.007495076479244744, 0.01781327900971519, 0.007314575959753711, 0.03411060635698959, 0.11374841778888367, 0.05016692681238055, 0.022587899075006135, 0.03298295006970875, 0.020051275423611514, 0.06706202257191762, 0.06799241600674577, 0.030559817496396136, 0.013888238991057733, 0.08828944250126369, 0.05390004465880338, 0.0681574473856017, 0.039983840615605004, 0.02095303680107463, 0.02907403413701104, 0.0602087451989064, 0.04924082299112342, 0.03210294475138653, 0.09663133081630804, 0.027038922344218008, 0.056374186897301115, 0.01996300994505873, 0.029389311457634903, 0.02156055146770086, 0.01608637372555677, 0.06350858238874935, 0.031122725376917515, 0.057840663284878246, 0.017480685528425965, 0.049364821024937555, 0.011989571048616199, 0.04627266273018904, 0.06363229098496959, 0.06518758018501103, 0.035619451955426484, 0.08467807769193314, 0.009573200368322432, 0.007553123559773667, 0.020707654948637355, 0.035636643806356005, 0.07390791186480783, 0.02288824809511425, 0.020869899562967476, 0.11413757034461014, 0.013653418827743735, 0.07202589957159944, 0.05719875007343944, 0.07487789145670831, 0.05482829328684602, 0.11939441013964824, 0.10242778618703596, 0.14605363860027865, 0.0719641380419489, 0.18039616610622033, 0.09920927725033835, 0.26021042314823717, 0.14474831958068535, 0.07630434382008389, 0.1850046360050328, 0.13782746595097706, 0.141233938629739, 0.1496213799691759, 0.20905755314743146, 0.12844959885114804, 0.13436939916573465, 0.09443021728657186, 0.0919037833227776, 0.12811454886104912, 0.1647920807590708, 0.12254959903657436, 0.0947433739202097, 0.18682948808418587, 0.11151367754791863, 0.18235337280202657, 0.138645654078573, 0.19592989585362375, 0.10205048572970554, 0.0951512879692018, 0.13751099933870137, 0.17444592289393768, 0.3060724481474608, 0.0459953369863797, 0.12139400088926777, 0.11379828269127756, 0.05945963246631436, 0.1293720438843593, 0.08513565626344644, 0.17573519668076187, 0.11786678820499219, 0.1578583286027424, 0.11415447646868415, 0.1250024713226594, 0.11256580546614714, 0.14568070939276367, 0.09215307814884, 0.17220157926203683, 0.20620092283934355, 0.13394273846643046, 0.11942223325604573, 0.19699127093190327, 0.15452832682058215, 0.10025449577369727, 0.12039526307489723, 0.08981155770015903, 0.13938376447185874, 0.1463896533823572, 0.16839902236824855, 0.2737999486271292, 0.1385736805968918, 0.187143906368874, 0.10183120335568674, 0.3067547787213698, 0.10778975862194784, 0.29964838817249984, 0.13842226762790233, 0.16807645530207083, 0.18091010337229818, 0.25187530322000384, 0.09793079429073259, 0.09407156700035557, 0.2255312871420756, 0.18427746486850083, 0.16439883154816926, 0.09613740185159259, 0.11749858647817746, 0.247642315516714, 0.1654083898756653, 0.33551208092831075, 0.20164606568869203, 0.27974995435215533, 0.2159802324604243, 0.31270989042241126, 0.43477249215357006, 0.23058158723870292, 0.20896908914437518, 0.16724247427191585, 0.11148338307975791, 0.16923557122936472, 0.0782485851959791, 0.1316403440432623, 0.2126407905598171, 0.3202545637032017, 0.19033233606023714, 0.2649173612007871, 0.26674164924770594, 0.21200805029366165, 0.1714466666453518, 0.10198538453551009, 0.1725175412138924, 0.07092133149853908, 0.07824568339856341, 0.15602667845087126, 0.12205152146634646, 0.1230740080063697, 0.17494486877694726, 0.10897744723479263, 0.07541136947111227, 0.09815904923016205, 0.25975242897402495, 0.20658887311583385, 0.15283378103049472, 0.21553924831096083, 0.16620728216366842, 0.2368598448811099, 0.15148777747526765, 0.15036029188195243, 0.14947097632102668, 0.2190368715673685, 0.15235904400469735, 0.0918205885682255, 0.12578013818711042, 0.23226427350891754, 0.16045951168052852, 0.07700777365243994, 0.11649984866380692, 0.15080647106515244, 0.22811721166362986, 0.20521076425211504, 0.1920804352266714, 0.09716751024825498, 0.12204080485389568, 0.19454547873465344, 0.1914567788480781, 0.15616553428117186, 0.1207510412496049, 0.12291564853512682, 0.12033664825139567, 0.12711784453131258, 0.10707338573411107, 0.14306492084870115, 0.1690556894754991, 0.21293978701578453, 0.09747582065756433, 0.11706014047376812, 0.2222570206504315, 0.08849895821185783, 0.1272578284260817, 0.08067770875641145, 0.1303316408302635, 0.20546226325677708, 0.19804204814136028, 0.12004161486402154, 0.11761819841922261, 0.18543770886026323, 0.13091200031340122, 0.12582532013766468, 0.06162872974528, 0.19699720811331645, 0.11694838045514189, 0.13505595998140052, 0.16397536208387464, 0.17407559120329097, 0.09968560247216374, 0.14980477950302884, 0.11905108520295471, 0.14494929317152128, 0.14359420572873205, 0.1639881418668665, 0.0998011845513247, 0.192729695700109, 0.05988762903143652, 0.1672942761797458, 0.18117757339496166, 0.1882907620165497, 0.23084821121301502], [0.07547893459559418, 0.008802344564173836, 0.0811986815824639, 0.07743501322693191, 0.014074845530558378, 0.04017272462078836, 0.044014596787746996, 0.04895731144642923, 0.03367103599885013, 0.019460893236100674, 0.03712137331604026, 0.029435144642775413, 0.036597049693227746, 0.01850358024967136, 0.06544718344230205, 0.05455770624394063, 0.010518097224121448, 0.030815912250545807, 0.007306882671400672, 0.05253570634522475, 0.06686567998258397, 0.023824515628803056, 0.02205468452302739, 0.025913410863722675, 0.05119197376188822, 0.06281047375523485, 0.11305859894491732, 0.021524924668483436, 0.07858639597543515, 0.04580649379931856, 0.08430590547504835, 0.025775979956961237, 0.0346915892441757, 0.010815318091772497, 0.0412265706108883, 0.018406167801003903, 0.03476508041785564, 0.04069446928042453, 0.02433830075460719, 0.026947591795760673, 0.04616039434040431, 0.03810585447354242, 0.0645850230648648, 0.027311190351611003, 0.06328049072180875, 0.05594940383161884, 0.0250025878631277, 0.01986809482332319, 0.06093329284340143, 0.04567386087728664, 0.03849665830784943, 0.015278440223482903, 0.07472907600458711, 0.05192358294152655, 0.022952085782890208, 0.03554158582119271, 0.06030515389284119, 0.06143416088889353, 0.043099198446725495, 0.0032643551094224676, 0.06404753003153019, 0.05465276051836554, 0.06330862554023042, 0.02335112374566961, 0.031853249165578745, 0.021991800495015923, 0.10935915604932234, 0.034296866870136, 0.020807972905458882, 0.06687108281766996, 0.016545145299460273, 0.13269101735204458, 0.03129622280539479, 0.007620802789460868, 0.07310511588002555, 0.059851441910723224, 0.02593331526441034, 0.07117764704162255, 0.05001629680918995, 0.05331843836756889, 0.08410375929088332, 0.03745516165508889, 0.04071606577781495, 0.014878328001941554, 0.04614418954588473, 0.017997415125137195, 0.07415239015244879, 0.04581552944728173, 0.05053303568274714, 0.005471496269819909, 0.037311333435354754, 0.04216873079712968, 0.03313494933536276, 0.008593479160481365, 0.02054813772701891, 0.006826955714132055, 0.038332068506861106, 0.08981137958471663, 0.029213127454568166, 0.028023759732604958, 0.07838335921405815, 0.03615220637584571, 0.023046585301926825, 0.04422027188411448, 0.09501750842900947, 0.036773317187908106, 0.08759491101955064, 0.10306454147212207, 0.023137368516472634, 0.05057186113845091, 0.022435098289861344, 0.03468703987891786, 0.06068045426218305, 0.03985245079093147, 0.02640512822836172, 0.018864074772864114, 0.10608773198327981, 0.09813847689656541, 0.01877307819086127, 0.044282990784267895, 0.047995695858844556, 0.0035138248040311737, 0.021225599812169094, 0.0398643288644962, 0.09190012453473173, 0.019972232985310256, 0.059010488403146155, 0.041080649534706026, 0.0802495118114166, 0.018462845619069412, 0.0323351590486709, 0.06453493551816791, 0.06226029741810635, 0.020457473256101366, 0.022432816185755655, 0.06124503197497688, 0.03572770532628056, 0.03834990602626931, 0.030636496194347274, 0.080660943640396, 0.02611336029076483, 0.07405978496535681, 0.02097073145705508, 0.022815964766778052, 0.027511913467606064, 0.059878237152588554, 0.013460160789691145, 0.024146754294633865, 0.03933349289582111, 0.02560561439167941, 0.06133076487458311, 0.06742695884895511, 0.0853862424264662, 0.0667853350751102, 0.0523560954752611, 0.03431424425798468, 0.049485097188153304, 0.041136395957437344, 0.0734897784423083, 0.013031866437813733, 0.04281124143744819, 0.04710210552730132, 0.07218874903628603, 0.0814664781501051, 0.06825094314990565, 0.0238023736528703, 0.030256568534241524, 0.004561329142234172, 0.03477399732219055, 0.05760349886259064, 0.032906482883845456, 0.05037292845372576, 0.0293125362804858, 0.04826714750379324, 0.09590968125849031, 0.03597918948798906, 0.03602115793910343, 0.00735431843168044, 0.10676661899196915, 0.0597607069357764, 0.05170864584215451, 0.0648601223656442, 0.03233291776268743, 0.06912733791978098, 0.022474981306004338, 0.12745758489472792, 0.07806663285009563, 0.05144848226336762, 0.051395659902482294, 0.015072465484990971, 0.034317654426558875, 0.03492690942948684, 0.004946015360474121, 0.003229329913665424, 0.024589588247181382, 0.04137375333812088, 0.08230229970649816, 0.0499071973899845, 0.012029685985908145, 0.07607014427776448, 0.07388608530163765, 0.026434315041115042, 0.022777206104365177, 0.06212278487510048, 0.04166186619841028, 0.04081510167452507, 0.038363787898560986, 0.08268160396255553, 0.018637233624758665, 0.012220057997183176, 0.04996763418603223, 0.034168033744208515, 0.04160656135354657, 0.031856347632128745, 0.07705695577897131, 0.08157161078997888, 0.04848418488109019, 0.014057136031624395, 0.04698646778706461, 0.019482858951960225, 0.03439703454205301, 0.030837460508337244, 0.059555874177021906, 0.009553308027534513, 0.025808467471506447, 0.06768340055714361, 0.04774315413669683, 0.03229331305192318, 0.08033970501855947, 0.05524984801013488, 0.016941333415161353, 0.007572748263555695, 0.07425404211971909, 0.05189645373320673, 0.06860289926407859, 0.029641250184795354, 0.020350693048385438, 0.011564643264136976, 0.03603023440518882, 0.013859723821951775, 0.060656902205664665, 0.09255187862436287, 0.09982813193346374, 0.017054943236871623, 0.0719242327613756, 0.06474295951193199, 0.04895519632555079, 0.053854821890126914, 0.10318518499843776, 0.030387769111257512, 0.06677000972558744, 0.05375107335567009, 0.057002437170012854, 0.03362044379173312, 0.018073646679113153, 0.031320531852543354, 0.03836042225884739, 0.04917434882372618, 0.034896811630460434, 0.10874592684558593, 0.07822119252523407, 0.014235915696190204, 0.08187516403268091, 0.029935229722468648, 0.026317771880712826, 0.01638725894736126, 0.03436712970142253, 0.009353186978842132, 0.05203917986364104, 0.055952416951186024, 0.019418069459788967, 0.05438425148895476, 0.07983220217283815, 0.036673524300567806, 0.05374413056415506, 0.04059123282786459, 0.026414130479679443, 0.08209915904444642, 0.0757733297359664, 0.03442390028794762, 0.004367241290310631, 0.10882667251280509, 0.04785586039361078, 0.03349381855514366, 0.0200328868595534, 0.010842938972928096, 0.008196502512873849, 0.04462438613700215, 0.053489640704356134, 0.02050163660896942, 0.046388686387217604, 0.024933623790275306, 0.04300167282053735, 0.0066295226315560285, 0.00991382667052676, 0.03379180569027085, 0.014370829794643214, 0.0741592921258416, 0.0368980091297999, 0.054207750217756256, 0.04408163127664011, 0.033929488927242346, 0.014133719178062165, 0.0709997616650071, 0.01893440254207235, 0.03919204697012901, 0.03407599258935079, 0.06521808245452121, 0.032223261732724495, 0.025359319697599858, 0.04409689354361035, 0.05929441555053927, 0.07415536616463214, 0.08503586708684452, 0.02634789008880034, 0.014687907751067542, 0.03536170406732708, 0.04668404260883108, 0.04040951425849926, 0.009097420625039376, 0.04811281047295779, 0.024384143216593657, 0.035255109396530315, 0.04673286479373928, 0.017435228983231355, 0.019966950749221724, 0.04970421257894486, 0.011459326015028637, 0.016092485311673954, 0.03720550688740332, 0.03946855264075566, 0.04423424652486574, 0.05532560644496698, 0.0299101210111985, 0.0261938610492507, 0.02006185288337292, 0.0712813028076198, 0.028541728715936188, 0.04158761803410016, 0.014472618131549098, 0.03477707723504864, 0.029277221183292568, 0.0769833050435409, 0.025810141014517285, 0.03621367104642559, 0.02704706184886163, 0.026024838771263603, 0.05972981503873598, 0.02624243832542561, 0.04884633810434025, 0.09097086658584885, 0.045284882726264186, 0.13704571727430448, 0.07621547905728221, 0.2226149436319247, 0.11179472145158798, 0.09261193321435712, 0.15297158301109448, 0.0881740904878825, 0.15504846844123676, 0.0875382406229619, 0.2468774581211619, 0.11688668571878225, 0.14446245913859457, 0.18680752051295713, 0.08478298026602715, 0.18869937368435785, 0.12027451564790681, 0.05755716658313759, 0.07522005864302628, 0.06102663646743167, 0.13823754707118496, 0.11888652879861183, 0.11561146820895374, 0.0843723796424456, 0.21958583820378408, 0.16234173177508637, 0.18990824319189414, 0.28791877382900566, 0.13129359780577943, 0.13246881833765656, 0.07194461955805309, 0.2442239981610328, 0.38165160978678614, 0.1336394969257526, 0.1745117810787633, 0.1394729409366846, 0.09636692586354911, 0.15668010979425162, 0.10046481300378218, 0.17166067234938964, 0.10048876953078434, 0.13782089052256197, 0.14487108564935625, 0.2622696157777682, 0.13813297846354544, 0.1888013447751291, 0.17144966492196545, 0.14165408327244222, 0.09283221006626263, 0.14948853553505614, 0.13445977790979668, 0.06944707740331069, 0.1013973586668726, 0.25823444011621177, 0.21921418549027294, 0.13470250472892076, 0.0704144594783429, 0.15272944991011173, 0.12599895300809294, 0.1798423458239995, 0.11969426748692058, 0.1374216002295725, 0.10494358517462388, 0.24264310486614704, 0.12953025492606685, 0.23670270253205672, 0.23232100327732041, 0.19885615445673466, 0.1049390654952731, 0.1462347968481481, 0.206047891988419, 0.12659599597100168, 0.2455193130299449, 0.2595503570046276, 0.11887538916198537, 0.17608010239200667, 0.17393523623468354, 0.15687919832998887, 0.12592436716658995, 0.163146487029735, 0.15712369146058336, 0.13526892667869106, 0.16530015505850315, 0.2144010312622413, 0.18338546273298562, 0.14128440467175096, 0.08692078859894536, 0.17851425771368667, 0.09272723327740096, 0.11064975828048773, 0.13675256894202903, 0.1287685293937102, 0.14513616595650092, 0.15462338109500706, 0.17128857434727252, 0.11271406430751085, 0.11791847879067063, 0.16941485926508904, 0.15018121164757758, 0.122897592082154, 0.2145808981731534, 0.07589755783556029, 0.1739240001188591, 0.14864680648315698, 0.2409517948399298, 0.1329800096573308, 0.1791509462054819, 0.1567835800233297, 0.13911966379964724, 0.10497937153559178, 0.17343795276246965, 0.10274267944623716, 0.0853734923293814, 0.1609242445556447, 0.09656375084887259, 0.1334944218979217, 0.16214498842600733, 0.1782534967060201, 0.24373143474804237, 0.1048879834706895, 0.13651012413902208, 0.1722498337039724, 0.1392542151734233, 0.14930857956642285, 0.15679175849072635, 0.1510788095765747, 0.10381905332906172, 0.14661934808827937, 0.10333065336453728, 0.1485360780498013, 0.13052995753241703, 0.12569853162858635, 0.1838263578247279, 0.09672160565969534, 0.08314901599078439, 0.14738619443960488, 0.21639798738760874, 0.18677495507290587, 0.19275999016826972, 0.09936375528923236, 0.17251204932108521, 0.13286852423334494, 0.12295122709474526, 0.12264666453120299, 0.09580056328559294, 0.21438684139866382, 0.20225796644808725, 0.0969287464977242, 0.20457765291212127, 0.13934956630691886, 0.12217166033224203, 0.15185104392003268, 0.14031020225957036, 0.09935662325005978, 0.16881070652743801, 0.1370788912754506, 0.09513585129752755, 0.21342780848499388, 0.0906096187827643, 0.15914680087007582, 0.07978423716849647, 0.1450449411640875, 0.07651774096302688, 0.15583800966851413, 0.12386952352244407, 0.13952067587524652, 0.12266531470231712, 0.19624216191004962, 0.07982575290952809, 0.1710290601477027, 0.18495470430934802, 0.10775809860206209, 0.1773510006023571, 0.09265834713005461, 0.13033922557951882, 0.26841590472031385, 0.13238125975476578], [0.03476080564723816, 0.07481931374059059, 0.02660920214111684, 0.02584216468676459, 0.030799191663390957, 0.004120054627492209, 0.02112592937919544, 0.04782543604960665, 0.013514166876120726, 0.03831070207525045, 0.026228613969578873, 0.01606223166163545, 0.06421653932193294, 0.06137446252978407, 0.05967275872535538, 0.007925272584543563, 0.033249343978241086, 0.011428320940467529, 0.005440519025796675, 0.048414949924335815, 0.03234402771340683, 0.0389664377871668, 0.009199213600368239, 0.007387722498606308, 0.015125415866350522, 0.030668273102492094, 0.05592484987573698, 0.001947010514413705, 0.027047549810959026, 0.07676040841033682, 0.02104875529767014, 0.03451729586231522, 0.014764381430723006, 0.006100528116803616, 0.05442066496470943, 0.0638436694862321, 0.2271934604505077, 0.04619054408976808, 0.03204756198101677, 0.05246756976703182, 0.013586985478468705, 0.011027446162188426, 0.07146341100451536, 0.004750718271679943, 0.05268424349196721, 0.0641015064320527, 0.028474328719312325, 0.05485584551934153, 0.07843900544685312, 0.10095650068251416, 0.03169645191519521, 0.023534616047982126, 0.036934552481397986, 0.08043852940318175, 0.021388829627539963, 0.04155150141741615, 0.038935438278713264, 0.01568108687934, 0.006939013983355835, 0.07248335939948447, 0.04442505640326999, 0.03374916559550911, 0.020531229747575708, 0.045552675583167, 0.0818969460669905, 0.028944212099304423, 0.024700032809050754, 0.019340190337970853, 0.04401448917633388, 0.026211219883407466, 0.04627309688657988, 0.0853218388510868, 0.04796848130354192, 0.011293896659481106, 0.013280774419399677, 0.025885007016768213, 0.012375149235595018, 0.03641319373855367, 0.07832589471945539, 0.02869434581953101, 0.07200480773462914, 0.054269545144052245, 0.08844104100717232, 0.026144534203922376, 0.056745082620182075, 0.08208552579162642, 0.08372935320949182, 0.03859436204947997, 0.08452094276435673, 0.04684935600380413, 0.010028263059211895, 0.07030387205304578, 0.019341500228620134, 0.021803899835504126, 0.06871369449072517, 0.027390579743951093, 0.047546165878884494, 0.01302069247685722, 0.01687712279817788, 0.04738177274703048, 0.012791697245120304, 0.020683336624642834, 0.091301174252294, 0.033454952281317674, 0.03149742646201048, 0.045883870116085745, 0.04475994312088005, 0.0241373846802162, 0.031708010865258984, 0.07550331414677203, 0.01988297859497834, 0.039439122774638236, 0.05125206174852792, 0.07086131401592866, 0.05849326713359915, 0.02131781351636164, 0.060058029848732986, 0.03852328285574913, 0.03557986950909253, 0.060676825160044245, 0.013310982612892985, 0.0381389023095835, 0.02222361959866248, 0.019444645768089686, 0.023842175032768864, 0.05767350194219034, 0.017601303079572972, 0.03331495354359504, 0.00661350754853629, 0.032330698741134256, 0.05363263400795404, 0.029892216698499396, 0.04478477538214065, 0.004236339427734492, 0.035276063936180435, 0.024616374212200753, 0.041306477651232854, 0.015235012524499325, 0.05655103697790764, 0.04328184098994825, 0.015839179177419282, 0.03234671057725791, 0.0012998393026464328, 0.03754335848498158, 0.0616075265861582, 0.07238158126710914, 0.028256276455067564, 0.033556043927092105, 0.05458406732941512, 0.02067144185275538, 0.06390849608578719, 0.0050148913032899145, 0.06149884648039006, 0.0704628400853835, 0.09827506917645223, 0.03249109169701114, 0.021164083191251848, 0.07380670518614352, 0.02606537858810043, 0.041296863128081895, 0.006210615056261304, 0.04337541096901987, 0.02508746172679821, 0.007734415858067223, 0.012749152701871935, 0.07760850508930162, 0.04218370362650603, 0.07375913352007046, 0.017954368704522494, 0.00913429144929978, 0.020157784747425467, 0.009379268831253285, 0.04305601287342142, 0.031167148481472395, 0.06630552175920457, 0.02457016809785273, 0.02714568399824202, 0.020121118941460736, 0.04140252269280609, 0.03820601101324428, 0.02777734258415876, 0.04127413114474621, 0.02270460179715883, 0.02332046005903976, 0.06052089993318077, 0.0853313531843014, 0.06097866404161323, 0.01997098803258268, 0.06203112592629623, 0.05477063954458572, 0.04413743707118556, 0.05487722308316734, 0.05706313742848579, 0.07854388575651683, 0.10349270130973309, 0.0385689249378629, 0.11731537990272045, 0.023504822529503144, 0.05102084563986864, 0.004196968957330682, 0.0323358900641324, 0.06031954413629137, 0.02626832814712543, 0.006213454698809073, 0.006933148233656539, 0.06074647571949754, 0.009764394308149349, 0.02432947661873186, 0.07073388725984842, 0.014243171117414022, 0.05323669080098625, 0.023847878437663894, 0.19047751498874277, 0.04489006016228814, 0.04376469340058975, 0.012377715211187024, 0.04865363203862216, 0.017226804229721893, 0.1053307339316234, 0.030428600221057422, 0.0485686153115239, 0.06514966386021115, 0.03675183201266918, 0.0435509103408549, 0.010332227266189875, 0.08041945620789193, 0.04479784089198802, 0.04693639879405964, 0.05743165827880148, 0.05992389778839424, 0.04657600446080323, 0.010946097499981988, 0.03884184603521135, 0.021543456095969304, 0.00571637253415247, 0.03531569462211337, 0.010593479019007646, 0.06834974527009763, 0.04843637201702222, 0.051683735655387864, 0.05450517332064919, 0.058787124216905795, 0.1022627399652265, 0.021791036560898647, 0.04543816961813718, 0.03881876895320602, 0.0680791211198084, 0.04975526862835977, 0.021850814700883348, 0.007841693768568803, 0.010373286586400354, 0.05085574375698343, 0.11094577130279504, 0.08203526755096391, 0.02349078109546099, 0.033233814538107254, 0.05721354107663501, 0.04446452010597568, 0.004229449978083721, 0.0795082695549354, 0.040404968603979796, 0.052717035287059844, 0.015669984350097366, 0.028556785036926158, 0.055215605316334404, 0.04705269333499018, 0.031374467434943654, 0.05020000804506708, 0.02015760663198307, 0.027722566519514658, 0.02826377585734008, 0.0282595660246443, 0.015643575025023893, 0.0067166976168664405, 0.00046384148618017207, 0.059572468599071726, 0.033801063982537016, 0.05644034936267417, 0.01735096739139408, 0.04767391175846569, 0.09166398798697628, 0.11017945929779671, 0.050929205244756304, 0.032468040590174496, 0.024813026648189407, 0.0912888249149546, 0.023301551991607994, 0.018046556433546357, 0.013507031126209768, 0.02605621120892465, 0.012615394498425303, 0.012933011439599795, 0.015128824179555522, 0.016142932799994014, 0.044112003670306876, 0.056476135723642074, 0.03370536032889504, 0.03800772399699781, 0.024498569400748238, 0.0036024138125867466, 0.04138267395319417, 0.03944994699850213, 0.040074809367069975, 0.028972135405638255, 0.018518321157898754, 0.0473855317250127, 0.05995775085466448, 0.10253083339193836, 0.04091631206392776, 0.026654686516849324, 0.008676093184476485, 0.012121026738896035, 0.025797691487241536, 0.020462614484131336, 0.008014497288968414, 0.058696214837254956, 0.04535576525086071, 0.08825820550555363, 0.04412938476889394, 0.07567830514744855, 0.05779089486168232, 0.011845664903376019, 0.045129603167879395, 0.0064443906467204215, 0.035006348916795105, 0.04249062993039843, 0.005055554038335686, 0.04917350648611318, 0.012827429800381651, 0.03469976029009558, 0.03406721298233606, 0.014368767551786732, 0.06072308693546802, 0.04124941762711387, 0.045819158549420536, 0.024104841504595242, 0.03855621565890033, 0.03140098066069186, 0.007790932722855359, 0.012455566502467263, 0.08912249584682286, 0.05122939655848313, 0.030157981636875775, 0.022256103402469307, 0.04475333058508113, 0.03126516763586551, 0.029940127897134516, 0.0445896944438573, 0.04457266586541664, 0.011933191017305944, 0.05313971807481721, 0.04293742138543166, 0.15277850587153807, 0.1555451433523558, 0.17019406979670748, 0.17378575284965336, 0.12767504900693893, 0.12893635866930708, 0.10749117776867934, 0.10118226942722686, 0.13423864758806303, 0.23386023240163922, 0.14594641310395673, 0.12889793026261032, 0.24306933511979878, 0.20270660956157371, 0.13609895948320627, 0.15157371817622334, 0.2758170466404408, 0.1648878920241259, 0.23484737786930054, 0.103168842906598, 0.2332333699450828, 0.11680460418574512, 0.11841569546959363, 0.07784856759826653, 0.11656013331958093, 0.2589243702823296, 0.1435511017916724, 0.15032650931971148, 0.175366141484119, 0.16679332649800926, 0.145909350248985, 0.20697370637208223, 0.2312073958455585, 0.11123235904960893, 0.21066652931040153, 0.15663583326386288, 0.430111923487857, 0.16367497039027512, 0.16360980982426554, 0.13873624062398449, 0.14728671696502715, 0.10247809637803584, 0.230342986760661, 0.10303956820280291, 0.2599021646892652, 0.1888367600622587, 0.13245759706478566, 0.18531624897150323, 0.210395660251379, 0.14606594340875745, 0.09709319157991558, 0.1521370973205194, 0.1633835438406095, 0.19907504349248484, 0.14532498316839337, 0.08610824079369195, 0.11584807973122224, 0.10042841808171943, 0.0806248233129736, 0.1232956800959073, 0.11327713174978271, 0.11399482566048391, 0.14329647092381492, 0.17857266473583877, 0.1850720526999794, 0.17870899726403877, 0.1813908517942764, 0.12643129855860025, 0.16684352536685765, 0.177188262459822, 0.20566176739521325, 0.18029554572422057, 0.12790257664164528, 0.09187800111249089, 0.20304357429267839, 0.15582404244923964, 0.22067537036491558, 0.1835621680947952, 0.20449788687983528, 0.10143571285880171, 0.18658026005141437, 0.15592837356962264, 0.2170287090120837, 0.17121818906161934, 0.12063428657711484, 0.1078396754746791, 0.18418742751237005, 0.12586036435095593, 0.2341271680779755, 0.14405545050976798, 0.08569968107622117, 0.22448693693149835, 0.13873380637960508, 0.1377292798133567, 0.19392024900298566, 0.18260546552482992, 0.1365743495989591, 0.09106989877182059, 0.13291424053022638, 0.14729275804711506, 0.11921761572011746, 0.12597487773746252, 0.21066513407276943, 0.23688895191298798, 0.19345370528753847, 0.16398207109887153, 0.1011085147911217, 0.08524698583642021, 0.1266335931723006, 0.21415388124296442, 0.1801197457825765, 0.11857334247906692, 0.14491282403469086, 0.1611622513155453, 0.18632101302500814, 0.11726670985808596, 0.211551436514128, 0.1296092788106762, 0.17316128010861576, 0.18080721201840788, 0.086782942089485, 0.18717850529355928, 0.14217936055501923, 0.07621190190548077, 0.08015070226974785, 0.10804469377035275, 0.11319861994707026, 0.2231573942117393, 0.05093754327390343, 0.13330735615454614, 0.2140470119775273, 0.22269951878115535, 0.18066558055579662, 0.08034322279854678, 0.06223684184078593, 0.15679971431382, 0.11834310600534081, 0.10024852148490027, 0.09499963751295581, 0.11658638308290392, 0.10197581083048135, 0.23418487748131156, 0.11950471554882824, 0.16547996259760112, 0.15237372368574142, 0.21315600431989878, 0.14710508374264464, 0.08308003336424008, 0.2030470030149445, 0.12455335323465988, 0.11381153002730571, 0.11733005216228776, 0.1290880239685066, 0.13083428260870278, 0.25058111641556025, 0.11187336684088223, 0.13372704066568986, 0.1792740388191305, 0.12753994844388217, 0.10208620529738255, 0.13002229883568361, 0.09613856702344492, 0.14421735744690523, 0.10053101999801584, 0.15396099945064634, 0.22650903702015057, 0.13941192155471072, 0.15417779562994838, 0.09267385059501976, 0.09801642328966409, 0.07878894291934557, 0.15172942075878382, 0.12870323524111882, 0.07155537794460543, 0.21432334324344993, 0.17888519796542823], [0.059514399254112504, 0.06867036048788577, 0.030668339895782992, 0.036803292532567866, 0.0274070220257272, 0.09746513373102061, 0.028439533125492744, 0.04584670336043928, 0.04154387213930022, 0.0654095046047587, 0.018331635765207466, 0.06413836890715174, 0.012872089464508463, 0.07828626403352246, 0.01357996847218601, 0.08246212120866403, 0.02492055642505875, 0.01759832706738962, 0.018737748250714503, 0.04152979359787423, 0.06016525163431652, 0.01607291302207159, 0.03308816063508857, 0.01439432804545504, 0.032853990778676234, 0.00597427349021018, 0.02069976406346541, 0.01892306623631157, 0.03520134079735726, 0.05612885513983201, 0.06585218827240169, 0.029145553053240292, 0.12132605726947077, 0.07703187860897742, 0.04251490187016316, 0.021255922110867687, 0.05900107425986789, 0.08761925346334465, 0.029040040062682237, 0.050581160248839296, 0.01887285994598642, 0.058402880968060344, 0.02175227604311658, 0.04345718822150957, 0.06855600295239128, 0.0347864023206057, 0.014766332351427991, 0.07380659386399202, 0.03476581143331714, 0.025668459456937853, 0.04125499115616549, 0.03006268245371757, 0.03222837141947821, 0.03573861118638888, 0.008466967101412592, 0.03989081240433734, 0.056086445110850036, 0.03737070524948649, 0.053947282358421944, 0.06755217400495894, 0.034984407320735045, 0.07453709724359214, 0.03706288094690535, 0.013834682831657119, 0.0070810935176268686, 0.046223562239902094, 0.0717238974175416, 0.05177951723453589, 0.10841259863809682, 0.014314418222056702, 0.015156997033045627, 0.10071779630379751, 0.027254664673819207, 0.061317792133195326, 0.028745064191753045, 0.0213651625381317, 0.06167230865685269, 0.051518155087251216, 0.04417318632476963, 0.05050631094491109, 0.025235310531570576, 0.09577342294505797, 0.02216494169260841, 0.060213687902432866, 0.010480644741619471, 0.02379096684308024, 0.07083083401084878, 0.02355829426960554, 0.010751375575637212, 0.049623025333858095, 0.035074481784249656, 0.007791182270011632, 0.05407492433732841, 0.0675882126961369, 0.04070008362759836, 0.009559878817526624, 0.04105776170035824, 0.013269881546875695, 0.03457531696767546, 0.04885027519776486, 0.08520666495314799, 0.07660076502361335, 0.014477639688266208, 0.01885419864265714, 0.02452500099025201, 0.008450115710729733, 0.07471386939869262, 0.01747653692291351, 0.14342557493364438, 0.029732309849350713, 0.08344590474735014, 0.02076831067824969, 0.04138655167480465, 0.04734563015517779, 0.03598711562517565, 0.025305154049419798, 0.03634009961388074, 0.057342741565662436, 0.016859157258295454, 0.005125987099745544, 0.01194248085084837, 0.052496702774078585, 0.030496356448566075, 0.049380554555682465, 0.056237268072436564, 0.09667288366472349, 0.05164190079085529, 0.012363824062049389, 0.03951935264922213, 0.07193583995103836, 0.03344380522321444, 0.016946365176409017, 0.020218844947521575, 0.051289454859215766, 0.14526011946145445, 0.06612160272197798, 0.036468131220317446, 0.03096562941209413, 0.02421686684101587, 0.011641365563264117, 0.034309565016883425, 0.0281411378091434, 0.04904066947347019, 0.04315410253184382, 0.046907644282327965, 0.01827161086112028, 0.11617432042839937, 0.03093154628004413, 0.023203172895591706, 0.04180231764621567, 0.01554392221805756, 0.04493078922678251, 0.040810556020005606, 0.0680458135320805, 0.022065545854275115, 0.03267524822149426, 0.058020749129354954, 0.01635525382880587, 0.03501122111629229, 0.08643782115541399, 0.048253955828840844, 0.00838837737319409, 0.020354340704216156, 0.025742935831658542, 0.07631809581653215, 0.011101467043772573, 0.030742395101697184, 0.05994680046569556, 0.01096093674277654, 0.05511124079930596, 0.07427629170706496, 0.015897155753918923, 0.03682646609377116, 0.041153806741931476, 0.03636734385509044, 0.0521774902153993, 0.025493366410955787, 0.08536911365808919, 0.027762052486650646, 0.051179056681576185, 0.017260288077523, 0.057480309769744053, 0.012846592981077265, 0.018123934605682734, 0.014307052406365983, 0.030094518733676523, 0.028614065849978942, 0.06665138484095223, 0.04143591933825519, 0.002395865371909167, 0.03701133136928547, 0.013350117915251758, 0.0028127714676884352, 0.057145701357512735, 0.030398315029742662, 0.028164663890493102, 0.07766045542666689, 0.009085005422093673, 0.011314233361190418, 0.05262718717858661, 0.028984703676542267, 0.041338393712067045, 0.028871895374322776, 0.02408300009847153, 0.05071897336165421, 0.01868137471319642, 0.03193634744093288, 0.007715861702308757, 0.043355072411941364, 0.03287604369688779, 0.04403643819387071, 0.06990871552261524, 0.05927458907535765, 0.04132219262828585, 0.03980716493970249, 0.0175119058258133, 0.037548401378444396, 0.040439177901134826, 0.06294789724051952, 0.02718692700000247, 0.0490879850985948, 0.06138010285212658, 0.02662630122358678, 0.017315767327090725, 0.046598317130701616, 0.028189939584990498, 0.04955354175763205, 0.023554062172479462, 0.010686302211979637, 0.013111739153828239, 0.018111164099536836, 0.017881614112411626, 0.04473495871934574, 0.042730989298434, 0.026549934227659833, 0.02939070855063619, 0.034453196567483246, 0.13382826960878447, 0.10060825530672446, 0.04648339927371126, 0.05922264244873077, 0.06892729201354086, 0.10951014599413611, 0.035146069349139, 0.10457086376845837, 0.007465326098099467, 0.027424926338426303, 0.06867588948807679, 0.013750013058597688, 0.019559999636840075, 0.0339992804947542, 0.03474401084531564, 0.03215292097593192, 0.039180068706627935, 0.0487792219792027, 0.01725694841297809, 0.013216053575888509, 0.02239993162220344, 0.06491336403996684, 0.06276437154156156, 0.07524233791627921, 0.052848525301669724, 0.062023092177696526, 0.05027259379858151, 0.022601921955356374, 0.05535798263736069, 0.08388297035708092, 0.010396392426628154, 0.034449270606273785, 0.022797963974880986, 0.04080304548551794, 0.025779558964131866, 0.04125613777432591, 0.02026798996666912, 0.0217518288991414, 0.06210176354215946, 0.10616835890687071, 0.0518032399850199, 0.06610343494685367, 0.03433169214986265, 0.07032147579593584, 0.08153144575771876, 0.026937734219245613, 0.08517317924997769, 0.05770533265604172, 0.022012697518221103, 0.03220604019588791, 0.04801874325494282, 0.065422714833403, 0.01746466998156393, 0.05862542137037963, 0.03659478614281397, 0.026854821480810642, 0.06490545274573378, 0.028977473302802537, 0.03160702312015928, 0.021522419920074753, 0.02483306834619725, 0.009220983574778074, 0.043810131392092444, 0.07385222110315226, 0.03679254623421002, 0.13017375633353367, 0.014887694833305432, 0.025375852892466355, 0.0642266844806727, 0.059847519660252146, 0.026248924696119502, 0.0727092097804416, 0.05722443951526657, 0.06969004170969129, 0.016498968871019315, 0.04671684553613886, 0.05183518573176116, 0.008904651476768777, 0.03682685943203978, 0.0204475730060949, 0.04590476157318335, 0.034931996851810254, 0.01770987371855881, 0.026302160804334562, 0.026315246723243035, 0.11550518524018116, 0.02099089375406038, 0.059951327566523105, 0.005137884190844488, 0.03315506153739989, 0.015467922585230554, 0.04530267571681179, 0.04555025989247952, 0.04754199871968012, 0.03106023468717467, 0.060428810538724065, 0.06175691349199042, 0.022629843406321015, 0.058291521709179506, 0.02173425855289679, 0.016671885568939615, 0.029546516889240593, 0.04158741394348908, 0.06497781214420684, 0.03670678735943511, 0.029034813487669453, 0.03414274506212678, 0.010702622967073694, 0.06998497119639069, 0.10223522112937644, 0.04542595015664119, 0.049279533413937315, 0.053743863390991464, 0.04046097106765956, 0.07040617711027153, 0.11775191858760081, 0.43345247860997915, 0.1304600026924163, 0.12098694031010382, 0.22260008583543822, 0.1595190621446818, 0.1422731828643009, 0.19596154103055596, 0.09630667831515893, 0.16655359795549884, 0.12535252753878012, 0.2110222852206789, 0.1563399241422303, 0.22125384479295462, 0.2217743278015405, 0.17347511951811612, 0.0963770858652424, 0.17495920707006007, 0.1329918988631107, 0.17961731180548668, 0.1969250713591464, 0.09503624023636803, 0.11722980285412632, 0.11853241303469986, 0.18427320494083688, 0.11145662123453803, 0.09420668240636587, 0.17617233650526032, 0.17033200536388904, 0.14334831736050546, 0.20976931729819626, 0.09501120759523474, 0.14674247038783506, 0.1381671617855318, 0.17970549379242584, 0.11707885743817315, 0.17293682496529073, 0.19606806890806183, 0.14222837198758498, 0.09776446415344253, 0.11434966130764224, 0.17354952724417672, 0.18410724587738514, 0.1014225694234483, 0.1382512619602494, 0.12882165232440457, 0.14370245538884774, 0.1872859534341842, 0.14414186618523672, 0.13104477053275332, 0.15676495211664587, 0.07061978205456398, 0.1718297484330833, 0.056025299563771114, 0.0658160234161187, 0.17308963317191228, 0.21398073819000274, 0.1290254163905047, 0.1411851795273833, 0.2709633414633572, 0.1720784866483882, 0.13111760490573943, 0.16455774020869285, 0.11920351491426118, 0.09333241760032251, 0.1835133199347183, 0.22811562346760184, 0.16569140047067776, 0.23289996752282605, 0.09208769493852742, 0.11446142132626846, 0.25536785018630326, 0.10850552294868976, 0.10378604260040447, 0.11464335140772164, 0.07965073964442126, 0.20016457565361634, 0.10418224555905908, 0.17277359700528905, 0.21076239994727075, 0.0984348238853272, 0.20127687690546736, 0.17411673587048426, 0.2896724984748289, 0.14393986843060702, 0.13871405040845275, 0.19802842231001705, 0.1156362188339699, 0.10591244412353262, 0.08601123467087746, 0.10866987155168317, 0.2064516203245148, 0.10385863206465729, 0.11944866113481112, 0.11817555132438429, 0.24208343646023422, 0.1146845702896826, 0.15547811257420108, 0.11464859839179553, 0.23418530792696401, 0.2230074952240102, 0.19041720806853846, 0.165496364061255, 0.11346675790264271, 0.13780622568447143, 0.15177850640611723, 0.11992005849606358, 0.1624512134003453, 0.2417099877493456, 0.12537088827230036, 0.18284501595189795, 0.11880530073540285, 0.12275487708393484, 0.1784946650150232, 0.10427888060803525, 0.1525243796641007, 0.10213570654741488, 0.11868912493810058, 0.17052824405254796, 0.07331493587116711, 0.09714848900330253, 0.1316766647505574, 0.0741854083025828, 0.1266484658117406, 0.13719241018407047, 0.1943148043937981, 0.15316289383918047, 0.13012418086873367, 0.13729225873248652, 0.12690266623394564, 0.09350659223855473, 0.11957017297390848, 0.18662253278307617, 0.12708931637462229, 0.2627309050876647, 0.12131583047448657, 0.1675656350562349, 0.09886203377391212, 0.09694957116153091, 0.15149815269978717, 0.11856456287205219, 0.1095402029750403, 0.12522953882580623, 0.14122265798505396, 0.1461645748349838, 0.12989932496566325, 0.3274152794620022, 0.09187719959300011, 0.1826642287778668, 0.13199384382460266, 0.09758022599271499, 0.14117930171778426, 0.09792461962206289, 0.1577480899868533, 0.17203312658239156, 0.17742781288689002, 0.13921835459768772, 0.14142091531539336, 0.16158178739715368, 0.17482686729636043, 0.23791516403434798, 0.10914611513726413, 0.14257465809350833, 0.09620610988349654, 0.18636865890584886, 0.17199967056512833, 0.09210955860908143, 0.14924202376278117, 0.14653547055786476, 0.12294829561142251, 0.21650809241691604, 0.12517122086137533, 0.11249840361415409, 0.1150611879711505, 0.1488674321444705, 0.146159483701922], [0.05261601414531469, 0.016587262180109974, 0.03149131116515491, 0.04473829838389065, 0.012115404970245436, 0.04608738556271419, 0.08668760579894297, 0.05117291169881355, 0.06236397544853389, 0.014834137746220222, 0.055312277472694404, 0.02467608926963294, 0.0049196018608199665, 0.02944325631688116, 0.0574898389459122, 0.006815169481342309, 0.1470576605061069, 0.03979924622399267, 0.01689661901764339, 0.012670421965594869, 0.006463904492193251, 0.021067477828182746, 0.08695224081748165, 0.07349430554313585, 0.028977944566577207, 0.031207302381517366, 0.051682566772797145, 0.026347192469984293, 0.006650057857768843, 0.06511300918646157, 0.01957154931005789, 0.04028620271128602, 0.011052440768253291, 0.0392203339288244, 0.011245589339523576, 0.030099465147941373, 0.07974933396326378, 0.04340651437814813, 0.03259539313148707, 0.02434038804494776, 0.04867643452598713, 0.044433691291487776, 0.04617337450326886, 0.0419015947409207, 0.024956827037385665, 0.041209694172721356, 0.010702442068577511, 0.050739100406644866, 0.04235414155118633, 0.019990790387964807, 0.05961454095086083, 0.12994677788810804, 0.04054244403960183, 0.051548839182942174, 0.039212007031892426, 0.05385078831750434, 0.06939293030882254, 0.03272031513915863, 0.01866622747911606, 0.03224006395612378, 0.020392600272316486, 0.04992291607777588, 0.06702392071019858, 0.02715710008487804, 0.025408433175471146, 0.04937972335028462, 0.013431238367047627, 0.08095431461697444, 0.08402322142501362, 0.05826109365443699, 0.0652607559459284, 0.0944498174067121, 0.008266003715107217, 0.03705124036059715, 0.03527557411871385, 0.016424293971795123, 0.03542874597769696, 0.041011255016201176, 0.06650393494055606, 0.03263837832491845, 0.04865756171057001, 0.04077922996657435, 0.011516632803250104, 0.05814663221826777, 0.07182220972026698, 0.031153882591752335, 0.050723964304779656, 0.03620473187766038, 0.07150256671593525, 0.019559715765353758, 0.06783562246710062, 0.09410209895577282, 0.05180480962735601, 0.04804113385034725, 0.07782357948599383, 0.05972699487756472, 0.04560838489851449, 0.0645653042010963, 0.07304144703084603, 0.020760581210197415, 0.037869699372095056, 0.007037093437247677, 0.029161045385990292, 0.03613998691434972, 0.031193932591122575, 0.05763596411270555, 0.07137453882023692, 0.04311932178097777, 0.03142074405332096, 0.026289919078408275, 0.021447058534249663, 0.01997333878534846, 0.06803769443649799, 0.03189913615642581, 0.0440577304107137, 0.053914943273412064, 0.05616522779746447, 0.0074630064227676485, 0.023162005963968113, 0.034990144122275524, 0.03135209910396952, 0.03291556306066923, 0.03524535015458241, 0.03463928267592564, 0.02634724627569085, 0.03244676692702342, 0.03483323183900211, 0.07954808577778749, 0.020687744981842116, 0.049131486084661447, 0.05921144715102855, 0.029289551966940053, 0.06191967760969419, 0.0633925104921218, 0.03555163821147289, 0.011899120872840285, 0.00911117262148764, 0.047953193061403, 0.0513718221191084, 0.002645045628923981, 0.007980229547683848, 0.040770216583041474, 0.027435689335106872, 0.027368122355255764, 0.04613709832483437, 0.019105766295979265, 0.05878988129552454, 0.073159285238944, 0.022712516802130267, 0.07437631094944663, 0.017111622910306323, 0.03962625902204309, 0.04272555306670256, 0.041346909856656566, 0.05679206798959058, 0.02928950187197188, 0.05194858960749116, 0.005230607193880132, 0.024491596923326142, 0.02199006386945257, 0.01453028022297076, 0.032348328459193, 0.027512646338436753, 0.012351395871519344, 0.05311510103638284, 0.012805213609681232, 0.06883266076329164, 0.05673991356161423, 0.006814679663875722, 0.052599664631998166, 0.035912578023271635, 0.017131892818724737, 0.07458861713530496, 0.03138789288641419, 0.09986774035496637, 0.05107818025862798, 0.05273178918287158, 0.005278675171211944, 0.036279503256082535, 0.0061105053646315355, 0.03675074847706128, 0.015368300391855882, 0.012894620140286861, 0.03175926729454659, 0.01792846218449995, 0.007628969660800067, 0.02835091141605517, 0.01861721604655031, 0.09383797601913102, 0.0890686827187892, 0.031929953838698566, 0.06881504959892482, 0.01948311870364705, 0.06293846454354934, 0.021735948794230353, 0.041505447443341836, 0.05493019758432638, 0.006601416571356822, 0.04953543706506025, 0.027291742371744476, 0.03611763342632912, 0.018699375505093485, 0.04739321295346599, 0.03726112343429122, 0.013809633492201101, 0.06975714670261368, 0.05546137865167111, 0.03402359696337953, 0.007563898152511683, 0.029904747862019576, 0.010170297136937734, 0.03405548333830666, 0.0455532507476164, 0.019498683395795524, 0.04654601427318994, 0.05391085403971374, 0.030938654199417215, 0.02940532700449694, 0.018339127746003214, 0.007879292825236917, 0.032576164085185155, 0.02475170298566809, 0.03830313216894865, 0.09292215094319545, 0.029057261599518824, 0.023895468657428864, 0.06268387820455246, 0.09688775768154301, 0.019892403870471753, 0.027988331457891036, 0.042235153014189564, 0.035459686114336364, 0.059127161439391784, 0.02622894236992579, 0.041088015350396745, 0.04329104362113867, 0.03226227272534743, 0.07477454739273526, 0.04414622038893867, 0.02730526615778217, 0.06166696890431922, 0.053434202272910625, 0.03880359203321859, 0.048680004256311804, 0.03886382473865524, 0.0340228733693948, 0.008337389044754673, 0.10510377775062807, 0.018631877173902467, 0.04490181578148622, 0.021526516575249843, 0.005679486866938532, 0.016340900692739524, 0.09353347282740287, 0.01887624599476112, 0.03674170911835972, 0.04990367218852043, 0.06029221825883724, 0.037968905962770805, 0.12239670177223161, 0.014605153646698454, 0.017823717316787224, 0.053988894578651525, 0.03301209049823228, 0.03692730169859715, 0.025564469724486116, 0.050421383275534026, 0.039324397876043804, 0.041118102017208, 0.05690040299668908, 0.020685553790826816, 0.011076367609348381, 0.06153779810119886, 0.040420538862235844, 0.07206354130175896, 0.008736055933695752, 0.00447445287136361, 0.04413065755215939, 0.050170259055448696, 0.02800076614221325, 0.028101000607421156, 0.03559496850357391, 0.11687919744872488, 0.06272265542065725, 0.026782206041389145, 0.012903918322990648, 0.0530626571708126, 0.042012423364212736, 0.06275235617067665, 0.10645519898389466, 0.0850193394580856, 0.034508931857999414, 0.06586934672668576, 0.05039034665969666, 0.054110847995616496, 0.05117178734508343, 0.06033543722878676, 0.01187400010167039, 0.04827833538001869, 0.031462441620533355, 0.031710638068034314, 0.0299218951840885, 0.06349555027554743, 0.047171333062578924, 0.04614809324266389, 0.03239679441321641, 0.02386654530710075, 0.05196769619942643, 0.1170096818532329, 0.0902352572302334, 0.033942402296816, 0.04541246533335652, 0.04834029728954192, 0.1079176677740179, 0.02308699709828943, 0.061178669129731134, 0.06868552998639643, 0.05634511326206848, 0.040006565177463926, 0.05473940625961404, 0.011654419013211736, 0.006888461666676449, 0.05294945738569368, 0.032076591087388806, 0.036049140617251396, 0.09719862107886001, 0.0138231786149845, 0.05199650637223385, 0.015417761751450598, 0.02355789350986015, 0.03519282836350612, 0.02191850227973191, 0.04651896299037617, 0.0335146580619039, 0.026478682484594174, 0.026683069954742678, 0.03686287956952583, 0.07184862275607884, 0.022710974990332033, 0.015635708259651437, 0.009306643187301233, 0.022516302233270835, 0.03596898495743517, 0.045595564297400415, 0.01816159303416498, 0.015466341810679296, 0.05504515254870057, 0.00184392005621703, 0.034405606347718276, 0.0430356780270813, 0.06511527273687534, 0.07189509604359046, 0.18617531459312886, 0.07172915182309225, 0.09888856555335224, 0.11661285549052991, 0.12017890476272441, 0.07006626605289057, 0.12572652543894947, 0.12052349135046825, 0.09195474660373293, 0.19571496988646686, 0.15703865617979318, 0.15846064081415534, 0.1969468014431186, 0.14886234101140872, 0.14901036978699267, 0.10978121543303132, 0.23411906382534653, 0.13000298815313727, 0.18936484266305342, 0.113816955126822, 0.07909527179435827, 0.1396367626148276, 0.2123944865888916, 0.15093930065631866, 0.15970733016729355, 0.1275296029052697, 0.13093631307128817, 0.10499722018721513, 0.11130004291771911, 0.15907433757092804, 0.0811433322087396, 0.18014667090028524, 0.17877184232929721, 0.173640915309079, 0.13828949740855023, 0.1847664066008292, 0.22089719830546528, 0.1592203477048315, 0.17334154777927324, 0.0958011718466878, 0.14148316666251048, 0.17504698829725385, 0.17720120551530272, 0.07558323603007011, 0.17457155365264043, 0.20347476209281012, 0.09397330664796755, 0.16502955317264423, 0.0835443357937038, 0.08380676663364284, 0.12829809682443738, 0.2274789201328531, 0.10289550249581225, 0.16280796378850937, 0.17422566830646247, 0.1689886290114373, 0.1464163706987165, 0.11458442488219589, 0.1332242801436223, 0.08652093427372165, 0.16961103858193383, 0.15650307788746431, 0.1866451237583533, 0.07633610774064437, 0.16071360820205882, 0.12731261376757175, 0.1508682474377565, 0.25912697659805417, 0.15323546103900298, 0.11686864410876296, 0.12867427663877606, 0.18608854268677533, 0.24924326164182276, 0.12560721777845174, 0.16180811275262386, 0.1160256534058135, 0.14590914244763553, 0.17406423634383827, 0.23215578636154532, 0.16580573574174196, 0.18943672708701342, 0.11416970533900894, 0.15413405344588682, 0.18832493049558252, 0.17485873511759564, 0.07939320697914809, 0.1334815233713016, 0.14076133898925036, 0.24131048965500668, 0.07174402446253225, 0.18620357557665557, 0.1616102858679369, 0.18447766662575305, 0.1555537967942655, 0.18283324548974633, 0.10941078726318665, 0.13768847653409466, 0.23526436096290126, 0.17289815907133743, 0.10992807903676294, 0.1510437356773764, 0.09121442461037077, 0.13671664899447933, 0.13808291318127885, 0.09818448263104074, 0.220622381020803, 0.21291048702551052, 0.19563412031857297, 0.2013930823886767, 0.1590621960349381, 0.1642622021608986, 0.1252600410953164, 0.1847975471173413, 0.19316037883982062, 0.2020372962579131, 0.09824591761571355, 0.14967353810789064, 0.18692154408199713, 0.15264848159858957, 0.24978502944577485, 0.1910023469827138, 0.07648968035937287, 0.1293311663903296, 0.09338972624391317, 0.10226853613858111, 0.0988391088321805, 0.18578295595943928, 0.20735387894092128, 0.0753306460683234, 0.10796923219459131, 0.1102802058449015, 0.18235165101941675, 0.24586902785813436, 0.1855985916336067, 0.12008482270175591, 0.13271610194351524, 0.19641806575236842, 0.19356700155185536, 0.10111222552950494, 0.07631530534126796, 0.11193833444849588, 0.11779677399317734, 0.1272179454099387, 0.18336670123972, 0.1992823401815258, 0.09396264198585413, 0.1624435989651829, 0.19448680453933775, 0.10414442571345717, 0.17446320009185, 0.11371335131116211, 0.11790935037424788, 0.13820081076119095, 0.19771771476371214, 0.23528356774477288, 0.08567188022425398, 0.13956241426058114, 0.12479431374231353, 0.13296608696691692, 0.07932347478345037, 0.0942327021039091, 0.1382334652589634, 0.11867862354847603, 0.11635064729489386, 0.0955528937629424, 0.11701170791639015, 0.1484560893732123, 0.15497210144530982, 0.10648273266269825, 0.10192346715484746, 0.24872647452866659, 0.0834597903303802, 0.24377550347708166, 0.10190025277552195, 0.20492923795245588, 0.12277875197469257], [0.0742225899011828, 0.04948409528878983, 0.046214600806706585, 0.005773512802988989, 0.04003664442279842, 0.012645267797779525, 0.031477703887503594, 0.06369299866491929, 0.042745758037199266, 0.015740338094474282, 0.04849528369959444, 0.029292834115040023, 0.026232725467707496, 0.05751862314355094, 0.05371944673242979, 0.05694027859135531, 0.014243280584196327, 0.006614761778109823, 0.06059087332687341, 0.02389198798482539, 0.03832996080745943, 0.0329941824747948, 0.058711581004899926, 0.044291195226833224, 0.05827833745570388, 0.0117638032315881, 0.054598520655417815, 0.023734680507914163, 0.0268275419875863, 0.0313255673245294, 0.018488041532691568, 0.039470415431424044, 0.03742749810044188, 0.08268976758699864, 0.049326548469252884, 0.1428684892016463, 0.01293727971642511, 0.02068816429527942, 0.05768317212641705, 0.024611938024463598, 0.05401973823609296, 0.027699634156306274, 0.08958360704127699, 0.03959904446674045, 0.0192600179798319, 0.05300841359712649, 0.018758535807137378, 0.03275615716120228, 0.08376808589673601, 0.024873914298950695, 0.04494016626267694, 0.02569908603618387, 0.032826839305926114, 0.04319872045016382, 0.04900942134554498, 0.07215487741632387, 0.015858990809647366, 0.02281950666656485, 0.02241225683974335, 0.052514213748509064, 0.06044547546480317, 0.029137446945242118, 0.046368971234187484, 0.02899336082919035, 0.03655183805676643, 0.020896843234368134, 0.047048188498592936, 0.040599815765745007, 0.024499480387021322, 0.06118215351307299, 0.11559269929421134, 0.042951974901370704, 0.07200080013717525, 0.01783430590876378, 0.07142927221138962, 0.02577284994913498, 0.05210746116063092, 0.08362635053345002, 0.020642941526602954, 0.033465958331362344, 0.08502963304636069, 0.05819524660182651, 0.05434022728877608, 0.039877631861600094, 0.015377522504422814, 0.06269062432693318, 0.07491256459616125, 0.047365723803523, 0.03578757437935565, 0.05349251652660314, 0.06499953480670229, 0.046151392089086585, 0.09358784256619401, 0.020693658043455798, 0.030931997134757694, 0.03619687995524146, 0.029335489052755293, 0.06830509766587056, 0.038902505475562066, 0.042891497287200764, 0.024575179450039286, 0.04788143480254803, 0.05285589853883721, 0.07506285692215897, 0.05745013775594998, 0.10851371625903994, 0.06280962028540671, 0.05305844919348601, 0.09591791167622432, 0.04714988128398545, 0.031394917314173654, 0.03592622982978355, 0.00966922221778077, 0.0185007823529304, 0.016503445876878686, 0.022954208325245418, 0.017555039448780008, 0.005292006462696008, 0.03222108724003192, 0.0699984263337683, 0.008649310002510902, 0.06292933612712659, 0.09037866984726861, 0.06916365120559931, 0.05894584734051023, 0.07924860692583025, 0.08334253099747002, 0.019529287710611243, 0.01565023765579099, 0.07752098361379467, 0.1214662786514964, 0.03270729044743348, 0.01843090729380492, 0.01695079765340779, 0.019804286821454298, 0.04849204793572426, 0.04578076353936922, 0.025527032084937673, 0.09607416344806552, 0.003043409860765678, 0.042523896700004116, 0.05165552662219852, 0.05359499227779452, 0.013306848850334063, 0.014009960486873752, 0.013992459716973826, 0.0211801172918058, 0.04207346872135531, 0.047932405504980125, 0.03389357640116941, 0.022256834417930804, 0.05114767867780756, 0.04669002431910485, 0.01885440829937579, 0.03484338441921864, 0.034080530822393484, 0.023673405084991828, 0.03466813366685528, 0.061608587857335806, 0.038549005694221705, 0.062211271142587066, 0.01654771127505228, 0.03232775612559635, 0.05628950413665734, 0.026500546155148186, 0.07157784275477752, 0.01914734883030178, 0.029499685515474994, 0.025735135859576985, 0.01446657333872281, 0.002714685520004423, 0.04152392692049034, 0.017108684005506802, 0.019372252972971182, 0.025560874018992763, 0.04099993355339393, 0.06465169761213474, 0.04866583665716462, 0.013955623217043467, 0.01880727635580115, 0.1231965959595982, 0.05798060636152513, 0.012460612178983865, 0.10876266969717108, 0.02783689251373289, 0.04566823168715928, 0.04416379815666005, 0.039423849375452846, 0.039715435486868955, 0.03191000119841192, 0.013221706885815365, 0.03562580473953858, 0.03315866837510839, 0.08101985367829911, 0.04244181516696699, 0.03163172921631485, 0.034719167451839894, 0.023702070539002307, 0.06089984795835335, 0.02961488538858248, 0.04095543808944058, 0.07921014883322641, 0.026196469698334113, 0.03580879980290774, 0.06601796179893427, 0.08356306760106236, 0.024565848798374645, 0.030887600005371496, 0.010927464027190581, 0.055203901647473685, 0.026601253739499953, 0.05363287520594895, 0.016851184736879077, 0.017829147982411087, 0.03629226077464409, 0.021876058854104485, 0.042618628140189685, 0.06645934670814313, 0.06863517526653595, 0.05890827982511837, 0.07094409316778183, 0.06844571238616481, 0.019907953719666693, 0.024291007393912878, 0.029109247188898735, 0.013745625110459514, 0.018693738893489353, 0.027866535747307353, 0.07597733871079981, 0.026269192749168724, 0.0614136516378494, 0.020120430599490646, 0.06304349328274839, 0.017038831210811622, 0.023118759163480718, 0.04487335441808682, 0.05567333231738303, 0.018353896484768484, 0.034873678887379356, 0.029119802384229843, 0.012548060367407743, 0.05679624999174848, 0.07892502311733551, 0.029533733395510353, 0.0211267791382852, 0.07383412754279561, 0.05169077863683924, 0.035242771191406064, 0.05589503780356608, 0.027755603223340586, 0.01492769195465371, 0.06288349366514012, 0.04732555506052449, 0.0895671165199019, 0.05097332221339457, 0.04894948549917899, 0.08368987095309421, 0.05070213403087109, 0.030652539571747184, 0.0614922413660679, 0.02349687598325545, 0.050314818290644325, 0.02908345755713526, 0.03309151143184863, 0.049169031335623004, 0.03006338007253362, 0.04505967801378574, 0.017251502904400695, 0.0354365496605169, 0.05910483392653987, 0.03352208324940875, 0.01984161870495882, 0.08420356331043877, 0.02388410266576102, 0.025277160239056684, 0.08133347044349648, 0.047331855894299224, 0.06286053903750144, 0.11733902472769842, 0.04414112183440011, 0.06413574170437641, 0.04057193698827177, 0.08850451689795591, 0.026917870636680163, 0.05247843109827954, 0.06569261910044588, 0.028318101067270618, 0.0590112305508228, 0.03159166808472946, 0.052366611707839184, 0.011652943067019805, 0.04479064948100131, 0.04621800726454239, 0.04778350470587611, 0.03366793753230013, 0.036533518141368404, 0.047677852562628686, 0.015508383548876736, 0.026001887854363304, 0.07398174071568064, 0.0057874354934028815, 0.018604163524287287, 0.016734637865738478, 0.028644184058066458, 0.020066183315066155, 0.024171989171009045, 0.04500437687966041, 0.036964030587114394, 0.03639187183580361, 0.024050464344327338, 0.01575562262587482, 0.054328059777617455, 0.07900423996034078, 0.037839093201910146, 0.08709491870831698, 0.06047689057595562, 0.04796529749000911, 0.07526311062974855, 0.038785372307756916, 0.08454063194221817, 0.03843039936327841, 0.02903443313698517, 0.027798914961749688, 0.04853084741625935, 0.04545351352135185, 0.07235432218294591, 0.02043848355242517, 0.042694390285760164, 0.058680870934040286, 0.043532030103961006, 0.04620238505594898, 0.02903172244259622, 0.02863828955014469, 0.0201472425396787, 0.032321492399205454, 0.016988016359391622, 0.03459735875367187, 0.03574841495719738, 0.0498757488821866, 0.03533653783961199, 0.042943688822560944, 0.010192260069743497, 0.04420399658556562, 0.04953111405484378, 0.03193837350409012, 0.02856897295714589, 0.0653387927741278, 0.02879220170143526, 0.02761924100923352, 0.028036255644110497, 0.015451465460500913, 0.009478044048591983, 0.16114408354042098, 0.19195364671759307, 0.23693977418588474, 0.06348180570057593, 0.1420424343086779, 0.11928184118005447, 0.1360686353291385, 0.16677670239005238, 0.09520723106106743, 0.10645354399457574, 0.16457170742796734, 0.15423911187099293, 0.10873581137275323, 0.1460829534335062, 0.14407603768631816, 0.17590266972547397, 0.1411161301075481, 0.17040767474099994, 0.1387578371213749, 0.09523398548481055, 0.1250857996637933, 0.08065402682404965, 0.21147527731955051, 0.12708953901892528, 0.13913193892221898, 0.13138477806933224, 0.09980820526834577, 0.11337986725266092, 0.16547776584047824, 0.23610524396644905, 0.1527333090780303, 0.20104900788282976, 0.09005982094095089, 0.17211317463079467, 0.16819990414660424, 0.29743720369879156, 0.09418249581358396, 0.1554996200138703, 0.1294724564650096, 0.10660450425348245, 0.11749117984436452, 0.21681752346921712, 0.1304935329244472, 0.13427001074887812, 0.16990512202028185, 0.19415662303799763, 0.1031701713509392, 0.10347142393584363, 0.12049471086356789, 0.10551045241300017, 0.09396091278176755, 0.12494017544668168, 0.12898398970719427, 0.19580594234867021, 0.16884141659829766, 0.20702215377241373, 0.1276610669447109, 0.21914581884630024, 0.1005993272701744, 0.14226629573386163, 0.17274466808885336, 0.17424610705347732, 0.15421186020830646, 0.10082404958666302, 0.12405561705236323, 0.15689470921643078, 0.37285626924131066, 0.1338888585451059, 0.13445452350424603, 0.16010434948839247, 0.1569325735908933, 0.13606721040559933, 0.17699359712423757, 0.11248216542298906, 0.20571687928168103, 0.1546182157471776, 0.11069610540289432, 0.25640486797783524, 0.13337888434762135, 0.12325578965828754, 0.3008170035900548, 0.11507720351801254, 0.16671390185365453, 0.13057791511528194, 0.13902849837904796, 0.119412214262411, 0.2832438371842727, 0.138414460234344, 0.16739133425289765, 0.0828849375830032, 0.14356043800944462, 0.13016136246733367, 0.1294428002438508, 0.23422017402481288, 0.13089168031001464, 0.13025591208133847, 0.2004511485574767, 0.12065767165040597, 0.14553872169926763, 0.18193515774328262, 0.08982571045635268, 0.19228906778153032, 0.18294876819709316, 0.1068961682904046, 0.146020449756179, 0.17410812695743516, 0.1470854613580741, 0.19140867283567786, 0.19572541932575405, 0.2047065194346942, 0.09155368999927305, 0.17293278768192977, 0.06794131913920864, 0.2334932700614445, 0.19090178597252816, 0.20358044392196462, 0.09181916364468634, 0.135620882792864, 0.11294839001493528, 0.17912486713612452, 0.13178853609133512, 0.14064353046705946, 0.22292156936600804, 0.28387733444105834, 0.23141648853197694, 0.15571300231385976, 0.23189086932688951, 0.1650282321497798, 0.13484401744790375, 0.20058975205756724, 0.204119183763396, 0.15823480527615175, 0.12450082402210683, 0.1443759395624511, 0.13234862009994686, 0.17415509006241336, 0.17712920234771445, 0.14036994514754042, 0.21227264078333974, 0.13283870473969728, 0.10038432708824985, 0.19172478321706876, 0.14357309904880822, 0.1312969226273708, 0.17714027519105002, 0.11032994458219036, 0.10514525638427585, 0.19247819669544697, 0.15141144016524777, 0.13803672190988436, 0.12767265929142013, 0.18207261833595112, 0.12176545322290622, 0.23488227365305647, 0.13693978311493993, 0.08692884832271375, 0.11443378374679014, 0.14186516491463408, 0.10485568520380184, 0.13071429217234254, 0.14985027315560728, 0.16697837359970436, 0.13234391488367692, 0.1667687317240052, 0.08214874935219996, 0.14055186038604006, 0.12057922664098442, 0.14579321898054332, 0.11182175789144821, 0.10242707372526638, 0.2551957016112283, 0.13645421073306352, 0.13018865865888074, 0.09319253760622814, 0.10459721743245609, 0.08737233350984752], [0.026964920944010373, 0.025477714516455308, 0.0549918960314244, 0.012859940507041756, 0.005310748938427423, 0.0265334529831307, 0.0743946865259204, 0.028507768038252834, 0.05112236402055714, 0.015823484609427396, 0.023116772063076496, 0.03166571957990527, 0.08533206564607099, 0.018040699033008423, 0.013032130827923538, 0.056601417672936805, 0.03389701625565067, 0.05176704544282984, 0.007756104196232627, 0.03142415051115677, 0.05940855415246915, 0.017368465378240217, 0.04376484554086346, 0.00999336449240218, 0.0377100300102029, 0.058089041558559984, 0.05316735936503392, 0.03526159576722421, 0.05850720095622819, 0.029155288175388705, 0.014983427245169878, 0.03495571589155588, 0.011027730033674743, 0.03813744770013727, 0.0476477065240033, 0.058153741993010044, 0.06313872567261569, 0.04145495913689956, 0.041232990188291296, 0.03437357154325582, 0.05325076934241224, 0.01948945293406723, 0.07241557163069956, 0.052201016296749, 0.0224224261182826, 0.009889515768009005, 0.09139443252934143, 0.03256093892559875, 0.03301511475001462, 0.05944199161604047, 0.06405357111361809, 0.03829719869827386, 0.0289605950092664, 0.01906534336740151, 0.028069303480151575, 0.05230746253801044, 0.015398550331156002, 0.03073668613069458, 0.03339584021887276, 0.012527857252280228, 0.047589258683728985, 0.024250391506939195, 0.0396424118662253, 0.008902804456738522, 0.056741765220067464, 0.03757440252229571, 0.006967265690036584, 0.01980712553631747, 0.047505655747954734, 0.021821765185450204, 0.03293726345873438, 0.08197661562007852, 0.07407455370412208, 0.04994465358322486, 0.010015550997195533, 0.0367846720473608, 0.0775877694832161, 0.01081603240891127, 0.026014222348749172, 0.026733042468549684, 0.003941203067370225, 0.045252955533214845, 0.04860794542764779, 0.025226907564501744, 0.02008026927796891, 0.04686297812440898, 0.004090540342076565, 0.06378642763593234, 0.023888759642431978, 0.06244825373869389, 0.09336230388726108, 0.03872693188895937, 0.040801464710966684, 0.07487805472919717, 0.07224089975352399, 0.04309448951971717, 0.045107398109394126, 0.04658493991883006, 0.08707884378964081, 0.05938126538239885, 0.03742672626685817, 0.024609984320704825, 0.02108597214828478, 0.05915259855100885, 0.05314718036970589, 0.05694693936675321, 0.017508686760265846, 0.015067290860315552, 0.0584528423496522, 0.06757552939234301, 0.05491464587976225, 0.053874310688115656, 0.027556486857065465, 0.0650708848843351, 0.026846837827179115, 0.04452550980204251, 0.027448923683550674, 0.00871692986038397, 0.06300009990809485, 0.03523206942190882, 0.04374577234557364, 0.04781953968631569, 0.017625625114305876, 0.07008461194345728, 0.07193659694166854, 0.008536639925296186, 0.02867938226700062, 0.03506692672090139, 0.06493421838968061, 0.03834354953141883, 0.03421619170694612, 0.030123774195089936, 0.032421953219454736, 0.019033431017305702, 0.09163940805592574, 0.018567367842479143, 0.02502114155504387, 0.04169915911916178, 0.03640733448264655, 0.040600261054350995, 0.027826072000607383, 0.08611595912952907, 0.11835845361929387, 0.05415278305008542, 0.04607889168255497, 0.058287792417104356, 0.019758897069550585, 0.024571071662649047, 0.01256626896065427, 0.01800622441805899, 0.06559444780577905, 0.07350330779445358, 0.008102666288323235, 0.028978002083022147, 0.03637020112364553, 0.14106973103480414, 0.030403834753087722, 0.012265930145076709, 0.01517591901574633, 0.02016713024204364, 0.06061513784516137, 0.03519106576277409, 0.04697069714893587, 0.0924650473461952, 0.0630667076620739, 0.042834396444959566, 0.06720660778228194, 0.14211614441592246, 0.03659688642073888, 0.05639489652821794, 0.03819647441559937, 0.027825073811982293, 0.008800453942967579, 0.011160529938933905, 0.032181248752749525, 0.06664921776973642, 0.025792264532356057, 0.012695592831732938, 0.0472019466542406, 0.04062466658069752, 0.011634403290372575, 0.03811375092482194, 0.02639372512931004, 0.02884640074626077, 0.05835867494170088, 0.02471607062034309, 0.047203661015373655, 0.09628261046600528, 0.050419234758010134, 0.009193124278681353, 0.0066418487767805345, 0.04266710893716663, 0.03833730806945823, 0.0864073634147644, 0.026379717091913335, 0.08696129501913674, 0.012741318405460333, 0.02694614460779121, 0.06573348175152205, 0.01651525901252171, 0.029288570476637688, 0.025426441388844978, 0.09654398003476672, 0.01958347191248322, 0.0755119750101585, 0.04881297114479821, 0.01779742116923444, 0.053046300236019306, 0.040112644055625424, 0.07326529361307621, 0.0702535618620459, 0.0417504563665716, 0.05579826916800812, 0.028612566711672116, 0.012275033514015377, 0.060801836225437, 0.029348910793487448, 0.040779879345791414, 0.018755880773824174, 0.013647326723003061, 0.03585208556614816, 0.04720324541267473, 0.04038843726448249, 0.02097583743307041, 0.007850046640669461, 0.06542506744153798, 0.06728497857693583, 0.024654095723235514, 0.04735257294669282, 0.01950674683030229, 0.056020720512606204, 0.03558864911610726, 0.026143998002226, 0.054697820014553145, 0.03316714741231408, 0.05030826883739792, 0.07863877675845288, 0.020727063965750858, 0.05730594588385429, 0.002586768250694149, 0.02675760941201588, 0.06373895987053402, 0.044732335227308795, 0.00783234363552765, 0.015583984277327545, 0.045070572741678916, 0.03604508478019852, 0.048711345152696595, 0.04258148364897352, 0.11487277151900344, 0.028892478840134572, 0.031088139439816587, 0.09213853947585449, 0.024964254080259707, 0.07005101491813548, 0.02482000840245746, 0.03182928150636144, 0.023633523924218025, 0.029518022129195742, 0.059183301200391725, 0.07563929044408724, 0.015246942548401421, 0.0583171072503319, 0.11377535774954595, 0.02165979145502206, 0.04767062404425815, 0.0520431948825717, 0.03823173756245524, 0.061106866342015564, 0.04419182536366861, 0.09187276154989377, 0.022850762215966824, 0.05265937412332278, 0.015016033503343351, 0.0867598167678807, 0.026163718721363693, 0.011852596562675899, 0.03714660262630787, 0.060763593355659395, 0.07839572339435108, 0.05375018277845811, 0.02740043546509696, 0.01487235556851374, 0.12599029956618324, 0.055104015991673805, 0.052818034164374694, 0.04782184405485168, 0.0500616346107563, 0.021243283335934393, 0.03526746615534648, 0.043508826856850646, 0.10668559130863287, 0.07204386696685106, 0.11467544187325984, 0.02746809335803846, 0.03445647314947564, 0.017747381862136535, 0.017451333587814588, 0.0277705834741937, 0.060241663159104064, 0.024404335199506022, 0.0036991907973060734, 0.0511275961616775, 0.05525952932657674, 0.10630223492626101, 0.1223724706505891, 0.08306146482937038, 0.048850776147446595, 0.06928975693881512, 0.006913626966706943, 0.08906854171073064, 0.009052188579516951, 0.05808291141875088, 0.044143481864011846, 0.01340831991910818, 0.04601327840646263, 0.06330912277917378, 0.053654501389246434, 0.012677160666498821, 0.1344816861092113, 0.0341523447423242, 0.07043607824016362, 0.035745375862461515, 0.06469175132224336, 0.013051002715656068, 0.059362685715314, 0.05060748051619157, 0.05905277968849987, 0.03206533641787246, 0.032071952664409764, 0.03878644471114967, 0.06834677667939104, 0.052621480062953196, 0.029746933869319037, 0.03692236641654745, 0.040887030627345666, 0.025398918842256535, 0.023987619279068895, 0.02794297324726358, 0.05800022874609567, 0.043605324608506635, 0.06224110547918826, 0.02764572640444385, 0.03760480089113116, 0.061608072064700536, 0.04486627803998999, 0.03419184184167534, 0.053672576395911165, 0.02329087434191024, 0.0105358354812779, 0.057497939487802796, 0.0034107428109564353, 0.0933439951040782, 0.11520048166858032, 0.155612604576163, 0.11722786584869027, 0.12534265697468072, 0.11953420107602142, 0.2293024363461882, 0.08259705107775517, 0.1139814818452578, 0.10137096789549105, 0.08266146207461134, 0.2388828355469741, 0.21026818896643817, 0.10824399752891622, 0.06587717638467439, 0.13119762326823547, 0.13811476615956053, 0.14960374654037878, 0.0892286749149207, 0.2158392095589079, 0.11965960919042118, 0.11782580681028776, 0.25394954660441726, 0.0958318893390242, 0.12048649528878741, 0.09840641447226517, 0.16293748340103775, 0.08871661528246477, 0.16791808098787442, 0.13232518307631835, 0.07699869718635455, 0.23763576027704403, 0.14914885454345495, 0.24893847643397748, 0.1577185228234157, 0.10744858591351658, 0.13351643399801105, 0.16517805692274123, 0.11626694787992164, 0.16764461441198364, 0.15537159953964874, 0.09593208669684827, 0.19135062204441056, 0.13713872322114184, 0.22253443545196205, 0.08033714460907504, 0.12646258750464767, 0.09278409663238563, 0.20622755109798163, 0.11642619050689973, 0.1881930063245818, 0.14231633133022115, 0.09595161260222085, 0.08845180956996046, 0.20829305198276415, 0.17731349245877936, 0.10123196363565512, 0.1447043992811814, 0.15122214797884226, 0.2225741106667556, 0.1538613290176727, 0.09393989515956491, 0.15354480303358287, 0.09372443484608084, 0.15178959409240633, 0.11365357131580822, 0.11181795067386702, 0.1647989678895101, 0.1283766160486266, 0.1444281719159335, 0.18752452422631904, 0.13661546458024532, 0.18844762234948575, 0.2709574339678511, 0.1341280824271962, 0.11615354029345326, 0.126475352444686, 0.1657084995531477, 0.13793176738545299, 0.1047592876420822, 0.15758456516778097, 0.16671900782966986, 0.15393453446449712, 0.14895439700921997, 0.17577325401362032, 0.16340926667908207, 0.23147752275690436, 0.26261527847964317, 0.13955205387901515, 0.18776780023472384, 0.16134204401168972, 0.18369995523244143, 0.14565865276381373, 0.160672003403306, 0.1567163859726861, 0.15084936720086262, 0.2678018814185634, 0.09550800124998204, 0.28902668156661093, 0.1151531252253335, 0.17602515377802774, 0.10304908253601752, 0.19330960989464074, 0.1764532839297317, 0.14721888466738164, 0.11924833321245387, 0.12416520999977365, 0.24235101038357243, 0.18043699907138944, 0.12041084075463004, 0.09311629677540623, 0.19340083468705416, 0.12820433388696983, 0.20374946063384414, 0.16104119218653068, 0.24857280543074012, 0.22426884941523895, 0.13326729502296075, 0.14659104257589206, 0.2466670295689255, 0.10966227884637192, 0.11316302654449828, 0.18805719329975545, 0.22006554761901498, 0.16550966334762052, 0.07294720169738866, 0.08314134218380786, 0.14779026416363195, 0.161745980149135, 0.13809734053211287, 0.15331366856116802, 0.10238858594675548, 0.13304802007041872, 0.06295914819929749, 0.2384445528150536, 0.16446982539491728, 0.139433458680287, 0.237190471671056, 0.1590407924959436, 0.1036040234612301, 0.14974738180171698, 0.15660274832043797, 0.1728679981897585, 0.23544964555185288, 0.2185175908380188, 0.21290834964020178, 0.07899032469140366, 0.21244916802970693, 0.21287364681484178, 0.13501591369276866, 0.16091305296868086, 0.10026163523434661, 0.07709880548645742, 0.1885269579361193, 0.1601700295577757, 0.29160763369873166, 0.1371661975281313, 0.20431674347491935, 0.13775657600490376, 0.16681918292306364, 0.13888254761695862, 0.14777412987314165, 0.15557368635199964, 0.3256702231010422, 0.1369156187865883, 0.1310505741275847, 0.15623026440152898, 0.2492833969881758, 0.1017927675275132, 0.1680028045666404, 0.13572099851444364, 0.11334908296703361, 0.14752372924704105, 0.08411052767769434, 0.10169308967306279, 0.1824622310232371], [0.055378792458213866, 0.03443991212407127, 0.03127860793028958, 0.058425282695679925, 0.060258784506004304, 0.023121007870940957, 0.02158258397685131, 0.04160953365499154, 0.016228866079472937, 0.03417593390622642, 0.03926833604054991, 0.044700489670503885, 0.029980443214299157, 0.054507392342202365, 0.035273711328045465, 0.017463506665080786, 0.056204379798145965, 0.09714923857245594, 0.02781139046419412, 0.030414232242037542, 0.028112678301113192, 0.04246543401677627, 0.04217050824081525, 0.03296724251413252, 0.021106171552673914, 0.03242340411816258, 0.03746831993339583, 0.015087762076291256, 0.05890233151149005, 0.013916848783992464, 0.06518751339172013, 0.049623841696302406, 0.08481739365379326, 0.04264639559551142, 0.02066030036075972, 0.016612255858490244, 0.044896279359818436, 0.02889527673687553, 0.023942511543282308, 0.015202924842014909, 0.04941409220919013, 0.013939520467829425, 0.03767160160350613, 0.027957575002801605, 0.02563647474744357, 0.06360025989124551, 0.08420899583143182, 0.04318102764955256, 0.006513547677968745, 0.013379587671806803, 0.10492397763300687, 0.06789146907976829, 0.0829676202556584, 0.03964860508858692, 0.014154042892187135, 0.0389732321491465, 0.04839713466935791, 0.08216656831791624, 0.019280132037238218, 0.06289037337410264, 0.03441994093009271, 0.1421648293035105, 0.04543681148788892, 0.05084567281301133, 0.021468115119205322, 0.05825319720315747, 0.03915076500561554, 0.047093897373997606, 0.04402783670229837, 0.005967725892332965, 0.013684144669241505, 0.03292855806648731, 0.041289757064078, 0.028545810528157745, 0.04380264312203508, 0.0264141397565254, 0.03028108909347793, 0.04918139551591594, 0.036227174423402175, 0.012844840584875783, 0.03510628281219397, 0.028820241896028165, 0.04187716323940549, 0.02407272877462674, 0.019701376913872082, 0.021200288865657058, 0.04875789636571426, 0.05358027177862823, 0.029938068437331822, 0.011517163438838907, 0.05093386964290403, 0.04515458385867532, 0.013214714927016757, 0.03810465590504464, 0.05705230578314513, 0.015753227344248444, 0.013453430437948555, 0.07457300234818831, 0.04670782473112922, 0.04200672738079447, 0.00713866052137746, 0.028478961576183792, 0.01988763742701849, 0.07164784212363884, 0.07626593025634065, 0.02690048211661633, 0.049658221687423065, 0.07313731766771525, 0.08571309168473817, 0.022029889369150624, 0.042131838636123575, 0.04404345148941502, 0.021217083667579573, 0.0923240021802485, 0.041708784774527885, 0.04004510119557381, 0.03050729756068904, 0.10610628567519598, 0.03739543361007236, 0.020771171657543164, 0.012632800644496456, 0.024640265801281203, 0.0461037610511994, 0.05965726639260538, 0.013676144317287253, 0.03490559494821355, 0.029711583520111162, 0.0061974577056389535, 0.018694417958613485, 0.030463935727311764, 0.057079865437117405, 0.010819003782671643, 0.02346806209970964, 0.011315614683553576, 0.018269473475811537, 0.030676490532641765, 0.0065198735592275625, 0.05009944703488145, 0.034847154529416, 0.025372787822561804, 0.05589134932961315, 0.03617787726398092, 0.020092017475690227, 0.023756609116389882, 0.017602533189347014, 0.015103904715942917, 0.049504526614327915, 0.0478539753385121, 0.02944045656477101, 0.044655300298472866, 0.006897900393596501, 0.06913716395501979, 0.0182191317435354, 0.053450878331204876, 0.059481510979821905, 0.04160374490311369, 0.021854297228856012, 0.03949077254219446, 0.029888303724874277, 0.04049216353450902, 0.07578975346405059, 0.06939774684724398, 0.06960244601941667, 0.07178113926784135, 0.03532253722369205, 0.011329991011734819, 0.016652675076329615, 0.04805367614608258, 0.03716953498951625, 0.055442056836909615, 0.12112643438740633, 0.02158155053621158, 0.039907618338475004, 0.06389366797520779, 0.06825063886935823, 0.03116971260169521, 0.0058307180097472155, 0.0621764050447382, 0.047521700980723836, 0.06317653067526408, 0.019745723948290106, 0.02850201453838963, 0.019538967171683908, 0.05287706087983679, 0.044482691591838375, 0.027490970060171094, 0.022941881252336316, 0.04773815206135623, 0.053851497068535537, 0.04978497308911756, 0.015573276941722725, 0.031370912547572516, 0.032719428272685036, 0.03021445907506859, 0.03010813714354299, 0.016305886165355332, 0.028949357038072776, 0.004884898107775371, 0.03132186771836132, 0.04766300589835737, 0.04526799144514371, 0.018051606748485938, 0.026201588661933783, 0.0029745953770543565, 0.035616802488220856, 0.06667693698545918, 0.03353339358000085, 0.039758376151439734, 0.007576548987344722, 0.017186856275657192, 0.03608659309975337, 0.03890508072800003, 0.041993016202468425, 0.006268663992159418, 0.049435291657573543, 0.021578928899543826, 0.023148042455432005, 0.03697008280141745, 0.007132281298254384, 0.016992382043099497, 0.053039171907585114, 0.04614818601112347, 0.05288177722832188, 0.05531893082661554, 0.028397256683092564, 0.025122101469605695, 0.02492388495738851, 0.021759395094704814, 0.047825109504628927, 0.07708461562287994, 0.03608324230299331, 0.06291594778303988, 0.04995819406758528, 0.012181960773887113, 0.051977344119222835, 0.03376633147126995, 0.056643074422026984, 0.04853939695749432, 0.07946912868646905, 0.008728620541660348, 0.057059333921642974, 0.035587847596616484, 0.022794631731812842, 0.055156734451884404, 0.025313080186606385, 0.024095258522720542, 0.0489100440609036, 0.02541426831157878, 0.056064997042994946, 0.014132219112070743, 0.05767976195784286, 0.022213147894944996, 0.05019318399718031, 0.009049957498064032, 0.020101479858567473, 0.02365318898227997, 0.04025444250146393, 0.04653133830288425, 0.05486708534590434, 0.04922682979668025, 0.011803665838669986, 0.019392957037780434, 0.01965663097507786, 0.04978526252671145, 0.01954672818101244, 0.010765956922114128, 0.029794921138091013, 0.06423133032512851, 0.03859416909108404, 0.05210992880165577, 0.07046073238598183, 0.020402801092131995, 0.054407083662226796, 0.04233266008668579, 0.054542403158848174, 0.0886385710327886, 0.011918687596335076, 0.04381769758765586, 0.014945301263651345, 0.004106811466044746, 0.07008530956227332, 0.04984795545169618, 0.026545598229859024, 0.06590561548364349, 0.0336727911781054, 0.06545672746142372, 0.020808345834666397, 0.044048494382877834, 0.03995523453340866, 0.07866921223467216, 0.021700986217183527, 0.02472136027790839, 0.05915119960263837, 0.038986312501947396, 0.07922007876913995, 0.02880201103835134, 0.007301235855265986, 0.029947035436634906, 0.05100177244457882, 0.06382228821166791, 0.05253425544651691, 0.024621806733193807, 0.04400653335324023, 0.010835773537110072, 0.03215699165593833, 0.03277544557931833, 0.039625064164283685, 0.04775404515385162, 0.060099501060904004, 0.039807001667213626, 0.015962752331688534, 0.03021320855623344, 0.021860718661628198, 0.14359849534230307, 0.02374238771153614, 0.051900836115237325, 0.027979275400866754, 0.07091474864864722, 0.02639263231685618, 0.016964898459264077, 0.011603412131080404, 0.018836991948774084, 0.06952198236831464, 0.08884930386557244, 0.01694376394880237, 0.05151639990799595, 0.042007350784842856, 0.08655418991111219, 0.07133024002541788, 0.023814928936189972, 0.013089948770357296, 0.03703336202306673, 0.011070138207287528, 0.015157323578023352, 0.013333593069546623, 0.08276663182186894, 0.0336039829562651, 0.07038795738480985, 0.028679480601567775, 0.08802749405731447, 0.022921073286852334, 0.014261889937188243, 0.00029232283793589886, 0.04006112416391261, 0.035583268545451574, 0.0705499979085289, 0.009392463289259467, 0.006830884922237601, 0.011116427813249175, 0.04435948394529987, 0.0484550778492121, 0.014898672125127632, 0.11240094478125684, 0.21045605622930452, 0.1500738674076274, 0.2090534268063493, 0.1587109375395812, 0.09423769675777294, 0.08459005155600607, 0.17992340319324285, 0.11110175590147264, 0.11492835837998427, 0.1759102099458687, 0.20408603944815695, 0.2000346255954355, 0.09034606729983352, 0.13955442875158042, 0.12197484276839532, 0.11149070065584965, 0.17926305503351614, 0.1107613104977645, 0.1347192921093665, 0.0712788017699495, 0.1497205308987759, 0.08826964200125076, 0.10762996680568904, 0.13340618053916842, 0.09694254302303307, 0.107587701495504, 0.08254283718997613, 0.13988949358463287, 0.12377429855405353, 0.1940747196204029, 0.1180174367618747, 0.11465269504697062, 0.14836646761978045, 0.13928560802014545, 0.10475323913851753, 0.1461239645141177, 0.07234553515445441, 0.10140803817193955, 0.10306911310181022, 0.17331640381598845, 0.13083380763418972, 0.14227483043214306, 0.13943662022938952, 0.12536962662125006, 0.10865368531085551, 0.15936662501189858, 0.20206309331115335, 0.14133356453385204, 0.1544492584071122, 0.2283222522237338, 0.17620629718294367, 0.19871749158482999, 0.11358294112142175, 0.13669557200046256, 0.10168592794798315, 0.12640078144613653, 0.1256533942068927, 0.10576605549431406, 0.15131594060221687, 0.1577048673061654, 0.19610701681813225, 0.19209419464459643, 0.1934149651788175, 0.14377272193087265, 0.10375197060056962, 0.12103860863135196, 0.1010218913143035, 0.12874124804511666, 0.10015563428169116, 0.10057842839160003, 0.16065125295426697, 0.13085507758660242, 0.12553276552353054, 0.2212941730977036, 0.13807516515953466, 0.18467059533577412, 0.11856730139697902, 0.11021643309504725, 0.15375805174699053, 0.14204385923221707, 0.11245372632401995, 0.09018263153848238, 0.1764416173682548, 0.15914105664705858, 0.11449951576651074, 0.12622930080397055, 0.14137904334347695, 0.1309286244213581, 0.10792485176352784, 0.19750764244236052, 0.18630340928211808, 0.1182570614037104, 0.19048337795538828, 0.2430497869499959, 0.12305798503803089, 0.11115342422272079, 0.14262981450883672, 0.1534261929919012, 0.23550383717520162, 0.09626763392589055, 0.08742093676119111, 0.06566293319338001, 0.20344224118161947, 0.18015999987255782, 0.17423678567865863, 0.11626044666627422, 0.18427112692734227, 0.2017784648342058, 0.1441485752002336, 0.14906312164384872, 0.10437529301270843, 0.12282113602850586, 0.15904310799669474, 0.15008197166025639, 0.12570020888233557, 0.12819130177376792, 0.20300047035561875, 0.25390130700543523, 0.1279634772799909, 0.08016711115487851, 0.10877945707761683, 0.15335459058405831, 0.2092446040478535, 0.12908728182082996, 0.12941118475282565, 0.10618783286190592, 0.08247631107224151, 0.10948886119876988, 0.11946131475269794, 0.09985913144191727, 0.17177370144054294, 0.1802305632736534, 0.1121520581364166, 0.10343273577746004, 0.11748546530725434, 0.08602241141488776, 0.2548261120682582, 0.10287884128047153, 0.15416934998938814, 0.17358918761601672, 0.22838062955997884, 0.09713163482956588, 0.1108738943003118, 0.09962925119907595, 0.09744951894390397, 0.20809339941479266, 0.1611483286251314, 0.09420332789886743, 0.14004104014020413, 0.09576571945217438, 0.255232066847384, 0.13411030056886375, 0.2547344716731459, 0.13348854408832267, 0.16508923668880016, 0.15702008764492348, 0.11482240195618942, 0.09098721609916538, 0.2039787100511603, 0.09823298940318637, 0.13770881138043478, 0.13567773130489513, 0.14538377610733733, 0.17563899949891493, 0.13051432790234685, 0.08683151565492153, 0.1318908337270841, 0.05891470682399813, 0.23127650463720784, 0.2551918721292168, 0.09249934941180982, 0.11703924159519374, 0.09405895048985258, 0.11078030947828665, 0.08808338519884273], [0.029329214194149245, 0.03055756136745913, 0.040047349903034046, 0.11916723131434992, 0.042376832716399804, 0.018977799627464265, 0.003374869711478823, 0.024817767116473988, 0.0423503640195122, 0.0751423928886652, 0.05055144094512798, 0.037224197876639664, 0.026968724450853188, 0.00852556615427602, 0.05480567262566183, 0.07384525233646855, 0.051537892504711635, 0.0836667011026293, 0.03670156263979152, 0.07172053548856638, 0.04883578105363995, 0.03693542079417966, 0.020715425234811846, 0.04838369808567222, 0.02771714141999837, 0.07012726317043416, 0.04239700429025106, 0.018896089168265462, 0.029895322586526163, 0.03147181123495102, 0.09678029469796456, 0.07907921171863563, 0.02488669408194255, 0.02949305999209173, 0.04332359050749801, 0.039968648852664046, 0.037439402149175294, 0.050327074859524146, 0.017524190225230996, 0.028887337612104602, 0.03443154811975546, 0.11582905106479302, 0.0337223443784751, 0.04245468771841843, 0.050581906107254326, 0.05752951044996735, 0.09480523935053498, 0.026634305286279414, 0.05773174940259196, 0.053530703735304996, 0.04768506252730731, 0.15686775441281497, 0.0328857584099751, 0.04333560216764454, 0.02133538386260625, 0.027986620807496365, 0.015649695887987036, 0.0589932594448328, 0.033653450809651986, 0.07052999702864327, 0.047001640996313654, 0.03981418936746195, 0.0304101912479382, 0.06569941717316397, 0.04300358014006633, 0.01500693106208928, 0.0445852007396752, 0.03201272927981336, 0.02041087380348472, 0.03877304152410943, 0.06336056845611893, 0.11166000680532306, 0.050142209584009834, 0.03294976122560911, 0.02570638505858369, 0.04822224014787935, 0.03752344666281715, 0.020576680726662744, 0.02804427083901828, 0.0685949063336011, 0.03101951675489545, 0.01629477621463593, 0.04758759998367168, 0.041618090617703274, 0.014632866368629038, 0.07590208493638784, 0.05355287539714482, 0.030461193491646554, 0.08682862127898261, 0.05606023616564926, 0.02328870541532524, 0.03860795819491614, 0.026723125520220492, 0.02010527408856433, 0.04153246161877178, 0.022230970571399666, 0.0316808074421715, 0.029480818266165443, 0.050956059858435765, 0.0446379414643161, 0.05642091251502279, 0.06619946885621175, 0.02703807444049744, 0.02431335346045671, 0.0694574748922605, 0.04184880577668082, 0.05215405690250918, 0.023263296134246048, 0.0848479924025014, 0.03444301801209804, 0.05736250495829154, 0.011055735903937602, 0.005165500897419406, 0.10598330438369885, 0.02286360879224958, 0.05229577742284164, 0.016224539358518086, 0.044614445068873465, 0.02447600996674737, 0.0938758700795006, 0.007828976140444865, 0.033967379276873544, 0.00493235566864314, 0.06394339186954312, 0.01280649752516183, 0.06334130972390994, 0.040187122285715304, 0.04515862114203628, 0.031798519485164434, 0.15435865701874718, 0.035707025381270796, 0.026472418758203276, 0.045625929269590415, 0.04167688726738561, 0.01831294663134031, 0.04179240255325567, 0.0755838371696882, 0.06211415369762108, 0.03864352933305781, 0.05996113133733161, 0.0525204032601323, 0.042715964518720284, 0.06956792130949907, 0.016518055053893477, 0.07951718274853192, 0.017978258438233752, 0.034801000365405343, 0.029491462519217748, 0.03295906033599749, 0.01950255555129843, 0.06723991537000984, 0.026653736567823216, 0.04263130031176843, 0.02566173188824905, 0.018681794026633725, 0.05504397995537147, 0.018677584193937946, 0.04307605457142927, 0.03640999879280571, 0.01965772007679334, 0.006836199627286987, 0.04834152554394677, 0.006621276443183888, 0.008806315054243896, 0.00787546334322542, 0.04099714678886812, 0.06788301601773128, 0.057878382940543815, 0.02380283007369144, 0.02159708925319137, 0.02038811955571873, 0.05481316089571919, 0.05333356333721895, 0.029506524406315293, 0.009889212415146176, 0.04822190247068647, 0.02730738870013738, 0.09432947073946707, 0.05820405589474831, 0.04092165552719962, 0.05142159054230433, 0.02221823531726841, 0.03847309140837751, 0.01913124608108774, 0.04785410521435551, 0.04760524083394557, 0.02308993600308895, 0.03655671767774038, 0.015237966272252379, 0.013293012434587581, 0.05538992096262518, 0.03779492428293452, 0.008680341979925288, 0.021199565271672327, 0.05773413911811076, 0.03867526727844961, 0.03254126087995246, 0.04487398895435035, 0.012950572508998448, 0.015165426902967738, 0.018962975227623247, 0.06355505567626096, 0.07248402733239345, 0.04069647678988986, 0.004688909893957316, 0.048118899794644676, 0.042740752251120284, 0.022237475495785475, 0.02430574459140189, 0.021900603533140384, 0.007750449030936579, 0.03726028480741661, 0.03462526721705217, 0.032548359522479586, 0.02611975018226076, 0.030753438259125687, 0.06496765214251354, 0.0901313491340261, 0.06940293445950374, 0.012600353948073462, 0.057015625134226866, 0.04573691374389455, 0.06182451943459455, 0.045512295328080654, 0.017423924218746834, 0.0273004570408375, 0.04100920297787525, 0.02874008994695032, 0.03481462619674858, 0.02416725612420123, 0.019342663545103278, 0.010104023349413183, 0.05375027183617931, 0.046734419593121856, 0.03085999211180024, 0.09247699592378922, 0.036927939945599064, 0.05913334352953825, 0.05132831742230337, 0.04431641340488568, 0.01636959583265707, 0.07887215993832797, 0.044982264589634724, 0.02811278962326469, 0.060878763542859815, 0.03621473973907996, 0.07962373289046809, 0.031240940224961378, 0.005188064506000956, 0.03442987086600624, 0.15102362347533926, 0.052564501675078645, 0.07316418341360986, 0.02119163913448574, 0.041865337116178125, 0.026419180794619024, 0.04429703221831005, 0.04938546386256348, 0.03759001730941236, 0.07287099055247381, 0.026215565158054233, 0.045410494931275025, 0.025343766137666535, 0.026300685785827227, 0.0022375434718924225, 0.02329314902453916, 0.03137073443213012, 0.02350210812437581, 0.0056097305514413165, 0.021198333306529094, 0.015980027674231678, 0.004539880146694486, 0.08319740401930176, 0.041041597723960876, 0.14465191459748894, 0.05658461544953752, 0.041370513863512315, 0.03730535172508098, 0.029974446661071852, 0.006175427979542292, 0.01698503107036231, 0.02719088635785738, 0.07017818934400566, 0.02591915694210911, 0.03138650135952048, 0.07082963915308937, 0.03132325924525503, 0.043332076966180466, 0.061839547925046645, 0.09126731005380861, 0.02090706260787556, 0.020487053407123312, 0.015944612387102097, 0.06782987824408337, 0.021510886945179664, 0.041731301535037346, 0.0479053208255209, 0.007433858108925051, 0.0338333140098257, 0.02633774493006058, 0.02028324110142421, 0.049223278620047495, 0.05225347871601116, 0.026053934670926537, 0.040480545212631114, 0.03127965435851365, 0.007813648007868323, 0.035194839583709836, 0.010124733908014605, 0.06338429491734132, 0.02405509163509123, 0.0726520198804792, 0.07825983615475707, 0.07815752367605455, 0.0264469835019554, 0.04680618527345359, 0.0905130356841255, 0.04428816355357412, 0.04366165361716412, 0.04390136731672101, 0.050105751579394564, 0.017433291977795307, 0.033252683642785996, 0.025031615114130545, 0.04198001006443519, 0.048128837152034976, 0.02735173202381702, 0.026094452223333064, 0.023397775148623623, 0.05550890578888357, 0.03405472634767648, 0.04401678241265472, 0.05408252021879889, 0.030548340182576794, 0.05175088517717086, 0.032989091341733, 0.0206158197397599, 0.06814158026827499, 0.08604020811617374, 0.036500848800642416, 0.01690505538135767, 0.023767925013089553, 0.09551011637086049, 0.06188910483615473, 0.03706004594278056, 0.03713912177772727, 0.015493466380576137, 0.04117290962312836, 0.04828061006264761, 0.03761757325264625, 0.006643455526500475, 0.047913929738570005, 0.18008406332228333, 0.17214749153936282, 0.13921310019213706, 0.24695860454812646, 0.18015303852735087, 0.20723354711662978, 0.10326270232326351, 0.12378840678138658, 0.14625198498833925, 0.20936544053256512, 0.12995155731914565, 0.13014450087212026, 0.13367627776460722, 0.1960902739665471, 0.20156701211817563, 0.19828838179819286, 0.12411990188411437, 0.12455183925339952, 0.11110091727459803, 0.20099912071600556, 0.12425043823895976, 0.05414214436314069, 0.10734322320786305, 0.09497278661001474, 0.07173134858021513, 0.12512688495917246, 0.12113211181713268, 0.16491843882249668, 0.12376907383440994, 0.11604456332861446, 0.21009798481827602, 0.12206692103063688, 0.20700373366707936, 0.09224170542438515, 0.11712147897924297, 0.2198089426383376, 0.10853925356059335, 0.19261497451225296, 0.07257388657308184, 0.07823228021152318, 0.10268020545481704, 0.22180000611115247, 0.16793279035482556, 0.1379899517633021, 0.15072232636157423, 0.12475803756387904, 0.20358608424430713, 0.1212503582064528, 0.09148405428277329, 0.119727018463891, 0.12277746805921197, 0.2112053582095541, 0.15935673960484564, 0.0865106555284001, 0.17853344965260476, 0.057519569381838664, 0.19145185098750517, 0.11615040100878105, 0.10642171328072436, 0.17211793921887875, 0.09057706818566658, 0.13630808185553178, 0.10753327238489874, 0.1927306901779957, 0.11672820008243434, 0.11273393902229145, 0.17263910500332713, 0.20481470972299576, 0.20986174436984584, 0.09194017824484035, 0.2205817706999369, 0.2127438600291498, 0.11486764327855781, 0.0750221055932343, 0.2073315848247148, 0.12218320072861388, 0.20098657842027023, 0.13964914163807407, 0.18677581596421078, 0.11857237026561052, 0.207909895980265, 0.10444330342579633, 0.10871544684050605, 0.2651913621230051, 0.06306466675596312, 0.15846050722757354, 0.16684028960298747, 0.11716112450812943, 0.16957589046796784, 0.13178957509808242, 0.11818888029665686, 0.09768788193468936, 0.07643802688107826, 0.14357685431605205, 0.08818450281978585, 0.17716267320793122, 0.19054582226090133, 0.10338074833271094, 0.35569214494898915, 0.11904951927135698, 0.19381833728402853, 0.21519852831261232, 0.07240435777930543, 0.18671576137421653, 0.15993325476301834, 0.2101547591155395, 0.18870424217311665, 0.12199199380120263, 0.14720760402269661, 0.19320320076076314, 0.16658447129884735, 0.1477904719649814, 0.11436385859269649, 0.2590025629615411, 0.1703621365595609, 0.09886377039947547, 0.11062278121244162, 0.1925063389353454, 0.14018417074112222, 0.26519878359977156, 0.1965881956857629, 0.08701866303454153, 0.11193251601071097, 0.22138680797070265, 0.08509781415341422, 0.12281184433959424, 0.14867257385049015, 0.10397926816949621, 0.13270863593788818, 0.18623124284204096, 0.0895163907262031, 0.19308828661451116, 0.12112615237128921, 0.21668516885256395, 0.11029026194592007, 0.17761397321010008, 0.13411975553026423, 0.19955349125666544, 0.15710120438598096, 0.08724483253899962, 0.15374635549960658, 0.12966382666490972, 0.1924154703738168, 0.1595115367672406, 0.15410377382067963, 0.16618014924461022, 0.12568190752062947, 0.15840420790482312, 0.16157785401446745, 0.16777410433860496, 0.1241151595604606, 0.1444406993687153, 0.11530016694450751, 0.14880660572089255, 0.12467824184568599, 0.15478764806175604, 0.13325718697160482, 0.12055424595018849, 0.13527965813409537, 0.13671590684680268, 0.12694927310803905, 0.1650197122944519, 0.11444768417277373, 0.19397690455662087, 0.0924551322532352, 0.10084321926115081, 0.25437476753722876, 0.2409612201154232, 0.18566219368949533, 0.20340995775768533, 0.15291378455003724, 0.22221117076696828, 0.3119687223806977, 0.21079073514556512, 0.11354791175108403, 0.11305669162538834], [0.03371027334651444, 0.019046463130507618, 0.03259753793827258, 0.032541758118895814, 0.018458993872627616, 0.020454198529478163, 0.03130691344267689, 0.0259722761620651, 0.012932227546116337, 0.04278198226529639, 0.015381777793663787, 0.003279691591160372, 0.031304731528507546, 0.03171251941239461, 0.03351494007802103, 0.02758350474323379, 0.024796567668090574, 0.05385934156947769, 0.11000773374689743, 0.019322532789374236, 0.05404295261541847, 0.04780177267093677, 0.019064834996243007, 0.020410055585671216, 0.027134234514960553, 0.1688020976143889, 0.06963188701774925, 0.02044487715465948, 0.013672960503754439, 0.06580055705853738, 0.04160012693319004, 0.10339288986870088, 0.028362919365463313, 0.03764411616430152, 0.027580755086091813, 0.0328826376789948, 0.020417779487615917, 0.03084748506807955, 0.06355080317007378, 0.015110150816326495, 0.0978919725457672, 0.013550514486269094, 0.03306096092273947, 0.017966211526072584, 0.040506687364540994, 0.008182980582205346, 0.015510841913055629, 0.04622135806130245, 0.08866631993441842, 0.04849683849897701, 0.051504481016309, 0.014053375198272988, 0.06328486939310096, 0.016900977279874496, 0.07611601642565802, 0.01289588179133716, 0.025368431415699888, 0.08406809909502044, 0.042890866461675614, 0.010913238911598455, 0.020420293512870558, 0.08051760523812845, 0.06625342299230397, 0.036252155114198104, 0.03504665866785217, 0.06750936692696996, 0.027741589619836304, 0.014530834050674457, 0.030065994287724607, 0.03733186866156757, 0.04429919928952586, 0.058411671707290225, 0.06809849117416888, 0.022182205902936403, 0.0539922194002429, 0.06289639219176024, 0.012346613657427952, 0.022956915308895987, 0.033677997344057076, 0.02932611201686086, 0.06030441545590293, 0.024283175880555063, 0.06064068256819155, 0.03158475868985988, 0.021902074840909336, 0.05545065461774357, 0.06360746614518575, 0.051206920616095886, 0.019969442510046065, 0.05776054102170747, 0.02059566671960056, 0.07096460612956434, 0.031048890959937125, 0.015925054940453265, 0.024614370413473807, 0.036093012677156366, 0.026008702625404112, 0.04043719636683818, 0.0741221550561022, 0.08729129840503447, 0.03669873876788188, 0.039263152139028534, 0.004129064764128998, 0.045630163222085685, 0.008410655718762428, 0.01721273125440348, 0.03395363841264043, 0.04557789747195784, 0.026572178248898126, 0.04131763584155124, 0.07563234394183382, 0.03369721525814384, 0.0315729585418012, 0.05359157839848194, 0.03783175707212649, 0.04829114113817923, 0.07008401080383919, 0.039999102882575244, 0.07619360796525143, 0.02323956596228527, 0.041094787447946146, 0.027715664546121843, 0.06660077036940493, 0.011377108112355927, 0.048948628318612464, 0.013331724712770665, 0.036363447579788044, 0.07629797619301826, 0.026732294754765462, 0.03513465140713379, 0.028042504527547862, 0.05949588266958017, 0.0169045618531527, 0.018434534540574532, 0.04353814911155496, 0.041866669271257706, 0.043927427832386456, 0.0423107259121025, 0.0182606289308751, 0.02733831399382325, 0.0776771389064379, 0.05628658749628812, 0.07600813783938065, 0.03758154569368344, 0.0050235043909196975, 0.07898717056377791, 0.02577317278337432, 0.06041613836714532, 0.02886841099098092, 0.013837492788297823, 0.04998850708943792, 0.02138903371815104, 0.0313373637618497, 0.09808289745706134, 0.04793723317561671, 0.05307797509885859, 0.031063340575201437, 0.007210313024188508, 0.010180762346863048, 0.05471935342939105, 0.04071987670613453, 0.02788061243336415, 0.037181060542934574, 0.006824660622442025, 0.04879912637989037, 0.01455590658224537, 0.009450797024328494, 0.07610198241309263, 0.012211779339850182, 0.06342961787595414, 0.024571357389504556, 0.0393141079985071, 0.050168741363449953, 0.048790023938636295, 0.01316674992267508, 0.0649667318793945, 0.07103068695869297, 0.060665752316708677, 0.03423158013902139, 0.040398437704425305, 0.025662346015451476, 0.021962756545690354, 0.0018577073046799342, 0.0579367046157131, 0.022530933674715925, 0.023250807644217275, 0.03013293600815814, 0.018160919535148423, 0.03629333688877523, 0.11444378047599457, 0.030620901816291735, 0.03602938464609906, 0.020784988591913134, 0.01829174903832609, 0.02754777218797244, 0.03435486200032756, 0.06322877045022324, 0.029799997428199276, 0.03603094315622002, 0.018337532128498424, 0.019807235003099777, 0.04516892586252652, 0.03937089342798572, 0.051435034547466785, 0.005286387477099197, 0.038044634711695835, 0.0071964798553381115, 0.013547721227951115, 0.04296602004615124, 0.03526522858010139, 0.03791016497416422, 0.043546505694394, 0.04371157046989538, 0.02607584472571034, 0.024953348220151383, 0.01782852086762432, 0.03362008385010995, 0.04648689107852988, 0.08734292961889878, 0.0527974284341326, 0.004823791523449472, 0.02906363664806122, 0.04900772553810384, 0.0451367500500055, 0.0503493281576084, 0.038339204256772064, 0.0652394637290854, 0.010636020779202227, 0.05467138842504937, 0.029592056926048826, 0.020130822522332892, 0.013892883907828946, 0.050648602918954566, 0.0651638611452654, 0.016371610763599165, 0.06484672660008073, 0.005605638998531504, 0.05533575531444512, 0.07751063065370545, 0.02569808599218959, 0.029258435570227448, 0.04255286643456202, 0.04195579749648459, 0.04429462023836095, 0.021142427322047297, 0.059805621713167056, 0.06139333905593958, 0.034779255438479595, 0.046973595235613175, 0.016770242400525603, 0.024313188332598656, 0.04250953243172262, 0.0466101840720512, 0.0076210889801586745, 0.02461448915710207, 0.025530188067932613, 0.03546020561771002, 0.040370874339714646, 0.05290483204589691, 0.04759971925523132, 0.015281267806130927, 0.02129620588675607, 0.02558077099820366, 0.01957295939064352, 0.01510663303633919, 0.0244162911985768, 0.03449290517892223, 0.02330404746317072, 0.01070994054316543, 0.018818723983713426, 0.01214810399687849, 0.074152033921564, 0.04128840264456812, 0.06032727731508203, 0.022906028098077513, 0.1232050490216352, 0.027003571995010134, 0.02673200717254076, 0.029311805265024304, 0.049106271617347375, 0.034261332839378156, 0.07923443190520629, 0.03699344932101667, 0.019782363779086154, 0.030468282857327722, 0.02730490992689738, 0.01143874718763982, 0.02479347476764815, 0.026096962537849322, 0.06796503075747751, 0.024159020140359644, 0.010617708285280969, 0.022178478466230445, 0.06755139474989846, 0.06722607431584038, 0.05960472975857556, 0.03738472812983673, 0.021273900638334453, 0.015482008548133308, 0.02049673472356517, 0.06037748360540718, 0.01564007023262093, 0.08114772572298534, 0.02055443670542445, 0.05016445546061732, 0.042934063167194836, 0.042142154488828965, 0.044829352482338436, 0.04280475135601591, 0.07976494132890366, 0.06537655324791558, 0.012836577698180918, 0.04096502663742285, 0.043672574320225976, 0.02811989568726858, 0.013245785867184168, 0.06323894529487006, 0.01435015077731805, 0.032841114516486414, 0.06741562625393271, 0.05144359151017852, 0.017597267651581205, 0.05175301885174122, 0.022983844137343112, 0.11902652753633447, 0.024682753755769227, 0.014643118211097317, 0.040010710072238, 0.08297475971630774, 0.08569663827074692, 0.04310362164687831, 0.017456066634622402, 0.046646686605527066, 0.014034964369784575, 0.021960828817100264, 0.03332951448101085, 0.045589345099870116, 0.0834980999934487, 0.06278873624978587, 0.03625217366789002, 0.041556548021617346, 0.033966188129852526, 0.007668552570976317, 0.0687152158934623, 0.04831735750485677, 0.03328821396280546, 0.03974159248173237, 0.04706453430117108, 0.0345676283177454, 0.05236457451246679, 0.020409673379617743, 0.05925161218328867, 0.09960369163309224, 0.14764508523512632, 0.11637556119239889, 0.1274287301930599, 0.11367331244400702, 0.1148367699352093, 0.13554252684116364, 0.14883094816468656, 0.1051247285795398, 0.14498672710033134, 0.07959758702781983, 0.16247521445620805, 0.11315680734696798, 0.1482485403539613, 0.11149346144520678, 0.11572777759283781, 0.1255574048263952, 0.12647223542444408, 0.16241892997641116, 0.06433186164940707, 0.2500467997742817, 0.11003616542438976, 0.18149628129322082, 0.2543358493130654, 0.1506600750144571, 0.2303949964698404, 0.1893745202687569, 0.10549556493060663, 0.10545174853177741, 0.08311571582453325, 0.14553876622812822, 0.22957265231525525, 0.13419592956779525, 0.07176381011959165, 0.1274949000799097, 0.14014367916388437, 0.18664083414478227, 0.09320243043475784, 0.18441998690832406, 0.07242064049933106, 0.1638750682468526, 0.20007688348414376, 0.2251523910672404, 0.22480616433313116, 0.11909609645954333, 0.06812359803006984, 0.1602717928471975, 0.10329459240892902, 0.18693647609325126, 0.11765516479499638, 0.17801406502258033, 0.0853475987969432, 0.21209287777310237, 0.13384743186179549, 0.13633493275847286, 0.13069777196506038, 0.104862067673821, 0.20533974951831624, 0.13501517154509202, 0.25108218484092504, 0.11410265229642391, 0.15595433389535174, 0.21182629832765087, 0.08004791481653228, 0.15666271385271102, 0.11419056711019948, 0.10496850649360567, 0.13381402037339285, 0.1285859610652551, 0.1289893183275126, 0.09166124946204945, 0.1164259752840735, 0.1103697088547051, 0.11560841056052595, 0.10649552728864364, 0.18228558503324166, 0.1475304234190844, 0.10454902978381142, 0.14339205954456702, 0.08372229538508691, 0.15664696547901258, 0.12362445151666179, 0.14601642731577158, 0.09056094131665304, 0.04872083351074252, 0.12793610687367618, 0.1207667525159195, 0.21157920768018812, 0.08085761277470738, 0.14724322711117566, 0.08982454528450035, 0.1785292342538014, 0.12924764509079978, 0.14453898940701038, 0.12327870717854239, 0.17968256142921746, 0.11166571392095648, 0.13556682475609705, 0.1285047849523835, 0.21861657849512994, 0.11203444257262163, 0.13280781655339524, 0.14201075944583863, 0.07803630869602785, 0.15537609695456922, 0.2194619143847376, 0.15153010957874358, 0.16531254892470315, 0.08781427502981387, 0.16704623558325693, 0.16172334464499727, 0.12405068177031353, 0.1203431717294734, 0.1387594995321706, 0.16142088978085667, 0.17180083435960114, 0.11449750454630703, 0.1529212505556643, 0.19597497390350327, 0.28867650660686195, 0.22216760669834912, 0.09326834056992084, 0.12132568619563244, 0.17363165330607444, 0.11772554265917279, 0.0744248548289761, 0.14019395224750042, 0.1181242021266371, 0.0963476522883866, 0.13379842042922974, 0.10738710639998317, 0.13240040716482326, 0.11601295525906608, 0.18139068852178752, 0.2134372782893479, 0.09589327979483642, 0.12249117717146873, 0.18081243673805147, 0.23153778514824808, 0.1627189209102653, 0.10304462964995764, 0.1706949749495834, 0.1544531324179843, 0.14078351436182857, 0.10269590187817812, 0.08879278189851902, 0.11602712285821326, 0.26089100225362927, 0.15706240490544587, 0.08879149798303843, 0.10144798798137344, 0.12505805818364024, 0.12068417374393903, 0.17770153179299086, 0.10431242568301968, 0.139642343565356, 0.14561179355951026, 0.07022166435490362, 0.2451190134161152, 0.1288104458944872, 0.1256124721840024, 0.21194296394241974, 0.14734855270944536, 0.09959508272004314, 0.07123074770788662, 0.23957092518685386, 0.0882455741520971, 0.18593568995129317, 0.13167313212761655, 0.12975478428415954, 0.15680884273024276, 0.1325030016596429, 0.16623506817268208, 0.23396346514346078, 0.07063881814246997, 0.20946637261658907], [0.026936084796034265, 0.021843434042239096, 0.024570550303906202, 0.012184783718112158, 0.015333925966842799, 0.0596473030600464, 0.027279346650175285, 0.023018352148937993, 0.0442276376998052, 0.03126349038211629, 0.010655606056388933, 0.008804575645626755, 0.05091156439448241, 0.023400177851726767, 0.016932284779613838, 0.025618601976020727, 0.03425126560614444, 0.02950432764919242, 0.058815811935346574, 0.03374924352101516, 0.03153592537273653, 0.03793634423345793, 0.027189088505110703, 0.023043661240080837, 0.007621245758855366, 0.03921978845028207, 0.05364870521589182, 0.014008919624757254, 0.0466905883513391, 0.023845882060413714, 0.04045602465339471, 0.04934571814374067, 0.07579603945487179, 0.05122413844219409, 0.058910201987600885, 0.027704246604116634, 0.02758490554697346, 0.07856030948460102, 0.0625730978208594, 0.09980211965739727, 0.027560820999497082, 0.058069797669304535, 0.10563185292994604, 0.03500667917251121, 0.003127166328340536, 0.042351818628958426, 0.009010313824546756, 0.022709576041961554, 0.02723368972510798, 0.07168218871811405, 0.06566748998011462, 0.04429359978530556, 0.04075292825291399, 0.024423408394795842, 0.010950586565741105, 0.047435942105948925, 0.031099822699616197, 0.057134179514832795, 0.050755590928019956, 0.021927825509919785, 0.03884813573677093, 0.03548607688571792, 0.06856300140498206, 0.07491848693462089, 0.05087210069177672, 0.1312033526482992, 0.03301881064544432, 0.018856859242077917, 0.03219984697352629, 0.004957741293765139, 0.05010536937334109, 0.054237770091276616, 0.05952514555247035, 0.0215559835487511, 0.03959351175581105, 0.019913174728571903, 0.042533696760074235, 0.071427416842198, 0.0021579502208624035, 0.018448837581672706, 0.05696163389075082, 0.037860355732846074, 0.059582877220236696, 0.02566066505096387, 0.04934089047310408, 0.03851362751447596, 0.04274137936590705, 0.04393488270579837, 0.046187631160137244, 0.04310971467930358, 0.021733737194153946, 0.07960427377838641, 0.011954584351769881, 0.02817898177454481, 0.006872800959172309, 0.022296875140455086, 0.011351986413501436, 0.06464160440373234, 0.04035263234982267, 0.03360452472406905, 0.07274305171449669, 0.029015916552452836, 0.033933893573703244, 0.039998909924179316, 0.05454713806102518, 0.10104080865858123, 0.032258298524538986, 0.021161283439141698, 0.04791409672179725, 0.014165082338877255, 0.016444330103695393, 0.027131013594043907, 0.028292298447922803, 0.09376687827170826, 0.02910513198003173, 0.03635822286014445, 0.012084578938811319, 0.009388629168824991, 0.011677615766529925, 0.004526009406617959, 0.05491271258506458, 0.056935005632112734, 0.04829714882362168, 0.08459054137347266, 0.025357353006256744, 0.00949980010773288, 0.05615333859168459, 0.07555231073638424, 0.03776264828047715, 0.0674188620178029, 0.025459648786636535, 0.04482324831769802, 0.04533709281531628, 0.05223726650001481, 0.0024894242187656346, 0.02483284755726345, 0.004177680075372336, 0.0317322419869015, 0.043831293733092025, 0.03296323120594025, 0.007083668770064833, 0.04296829843951855, 0.027160115059814416, 0.03923609714547638, 0.09870220485026948, 0.01959718680154765, 0.08746159903239459, 0.007635891579411691, 0.017101414669014048, 0.009064582445716951, 0.03324034172692336, 0.04935695797030348, 0.016499334378750063, 0.06919248364283703, 0.025647300826676656, 0.0796144783089403, 0.02779560127237346, 0.05748069197579753, 0.044104589615017176, 0.04008451294794213, 0.04663823354349006, 0.05151194331119768, 0.026308381857234053, 0.030007342356839217, 0.033401959226466715, 0.040738612224231474, 0.04948705274728127, 0.06832173661678098, 0.05377471446990967, 0.0563978057471104, 0.04111588670639321, 0.03577244940970559, 0.039179196683107875, 0.026916942952084355, 0.02500689046428306, 0.012550545634439914, 0.042669558024499565, 0.046058300795266405, 0.047834367796895094, 0.056049961131066084, 0.027803846533061005, 0.05557292344747111, 0.0167037366918521, 0.028480711189331487, 0.04395082774863113, 0.02848950378393056, 0.04660598351620138, 0.013411563104455126, 0.026966503573930822, 0.023647283342143055, 0.014860267838230357, 0.027870316989719868, 0.03751815886062104, 0.02806187272653915, 0.042199511372018605, 0.0545518469880335, 0.023566572926938534, 0.06787871156120673, 0.034544176451163366, 0.07500251289457083, 0.0500337706762366, 0.05536301810934674, 0.020401593246788252, 0.05209979477513116, 0.05859411758137867, 0.044749938970198855, 0.05090182370622642, 0.04693659546319395, 0.06377503566909581, 0.021245869720587507, 0.052414502497413196, 0.0055425638674933, 0.01860414497059537, 0.013786239142064005, 0.06296824692981318, 0.03819093057245482, 0.04914767232548911, 0.04204363067401573, 0.02199221980845323, 0.037495222786674276, 0.01602385520527605, 0.046808931219857186, 0.07089419857948087, 0.04577464824251365, 0.0742996990447864, 0.036312922165961936, 0.0459568269434385, 0.06460588483605534, 0.0458087870356394, 0.015400260981550673, 0.07300165307242423, 0.05791530849819537, 0.059035149970441125, 0.0301468438556185, 0.08138263772707433, 0.032965398277156055, 0.028094013287045527, 0.03041348267288413, 0.1136953393870499, 0.03205555862223264, 0.03563306665455457, 0.03160350905091036, 0.033610461905482225, 0.06763369892723858, 0.09346839389763772, 0.06067693648219574, 0.04401447804411873, 0.031190752488328144, 0.038009679556125775, 0.0713391754834447, 0.04969270928995684, 0.014531600318150595, 0.063954041688703, 0.03250490306527354, 0.020523231250990648, 0.04019187945232261, 0.07920734351500869, 0.06617673687287606, 0.03355256325448863, 0.03088573535933392, 0.06001324865792412, 0.02521055990655441, 0.035728748043766245, 0.03709647797222715, 0.03450867210631259, 0.06651802832493559, 0.05183040258998517, 0.034512353158788756, 0.057150362044922076, 0.03557608826668002, 0.06459158365032636, 0.0556644413882168, 0.03953895648010075, 0.03779397433390841, 0.0721426319796592, 0.04360667531727813, 0.029969507668283768, 0.01833667680330109, 0.031435728014912456, 0.02525229829188902, 0.05019768883357756, 0.14885595854138955, 0.03287627376266755, 0.05766102643974591, 0.04722145771665964, 0.029960047140775714, 0.05297782969137188, 0.09417626919457689, 0.02642650764755672, 0.02760352046607295, 0.024272963928524405, 0.018352209954173304, 0.018693571910262108, 0.0330156936252024, 0.05806643945106771, 0.09988312507630326, 0.0026928329816655605, 0.0794720156409312, 0.02490687864337815, 0.035600712726591155, 0.01853229579865001, 0.059570824741967954, 0.0340967504598666, 0.012943050842295634, 0.017865567024273332, 0.013238777210062835, 0.03525862717651762, 0.07881859171902761, 0.053358336226665415, 0.07368833263171837, 0.03313160596007947, 0.07268486733664759, 0.02080483733152505, 0.022372759740392212, 0.011837200709123863, 0.0813688337802887, 0.0654466416744981, 0.04459903808310628, 0.008461677443847293, 0.0409403390949592, 0.04553557278995868, 0.02867072882509092, 0.03972636361140758, 0.006790584448026493, 0.02806618831527885, 0.0831251114141196, 0.055056381243048236, 0.10860400594538078, 0.04098657860595267, 0.08353918528882787, 0.06970896647544578, 0.07439315028022975, 0.026270699308952317, 0.052154658042127267, 0.08937456630519591, 0.02064778032945469, 0.042193336703348905, 0.01015592544717947, 0.012381309988995781, 0.010115801233041566, 0.04024727335490752, 0.03881263139192015, 0.011514176294440404, 0.0891567682265304, 0.05734019970986992, 0.05181033120607026, 0.033131602249341086, 0.026790642405103426, 0.04598591913236305, 0.057959996920544654, 0.01927455665281741, 0.05190192336158361, 0.155250258394517, 0.24449215095955878, 0.218014934216626, 0.10998992220265791, 0.11924566148081794, 0.15067613509017974, 0.1402923313435167, 0.10708106696256436, 0.13557506259530783, 0.18301885662367567, 0.21666885644663125, 0.11403590353438631, 0.12960727501194924, 0.07868497545132414, 0.2155109724844806, 0.17249386670300737, 0.2156602480681613, 0.12460790108889341, 0.12321915724896826, 0.1685536265722476, 0.11646857456071302, 0.11258583603193983, 0.10950727388262749, 0.10574817715678364, 0.11332625450449996, 0.2109158315579407, 0.16309318598359823, 0.17421814292902127, 0.08604753311374225, 0.17448205064283684, 0.14034189196536317, 0.15870167553657666, 0.1342083976487629, 0.08370931522222236, 0.09764805086888373, 0.18894383712904528, 0.08065516230999492, 0.14051110163563862, 0.12876922701252624, 0.16821057623019442, 0.10269207239616662, 0.15527209237916395, 0.1275966633693315, 0.1183847182255704, 0.1386464259121567, 0.12135888988268562, 0.22164878610055894, 0.12928196199936792, 0.14450602320721373, 0.13105698628351092, 0.20046167221153155, 0.11374429886927828, 0.11230516320210882, 0.0901388077181764, 0.1592993419035338, 0.15085315215401351, 0.123857099970337, 0.15043281455291435, 0.1602707093115896, 0.0935149636643473, 0.13634009810630232, 0.1251686381874606, 0.18694428348680958, 0.12548277445603162, 0.13719962385948747, 0.20721996581414714, 0.10077214377815835, 0.16174743475858122, 0.10165337735088542, 0.10707571607781574, 0.14729884365806356, 0.1619445491814986, 0.14641157642472535, 0.15589306218316779, 0.26997073378879577, 0.10610306475427933, 0.11369211104465649, 0.1426790188997984, 0.17410974483937025, 0.13426917954348028, 0.17767880723113194, 0.17722029355354607, 0.1558099119574763, 0.09913247980875894, 0.20970458717783913, 0.08974875716376118, 0.07002149228355847, 0.14987400703830644, 0.06775288042263128, 0.19913653784897178, 0.14970832999097183, 0.1483118158648722, 0.16666585521306843, 0.10629261669237167, 0.10879395122174174, 0.1348052328103222, 0.12013542233034968, 0.10922340239631012, 0.1427309395512566, 0.11488387404824607, 0.11029363871784881, 0.09432672479306348, 0.11157731671119109, 0.09612914916942827, 0.10274912870954722, 0.2356626864639111, 0.14485545601928607, 0.21916925586992875, 0.14272108383011073, 0.1329738349886611, 0.1606954404269345, 0.239992376009468, 0.11267747642705217, 0.1730283020879142, 0.09830212788074277, 0.14494537463178858, 0.11812026132247411, 0.14321915397886187, 0.11668945255223662, 0.15031516930321231, 0.1628295157570392, 0.17091861373046413, 0.10271592502249405, 0.11040295707061887, 0.15794081089552492, 0.1738381336326711, 0.13032833085162565, 0.17099539632909, 0.1293296820949763, 0.15502050431678072, 0.08272074483102188, 0.11391143052605912, 0.15428175567649305, 0.1959287084173411, 0.1266918666078709, 0.10125189030077308, 0.1247572954162024, 0.12150921931606717, 0.07385776494629681, 0.185736631101463, 0.10764084669062868, 0.1379113583243452, 0.1356728925020434, 0.12896981468657032, 0.18753979762550443, 0.14854335109703243, 0.2566572278738022, 0.08494158464600332, 0.09796517799259163, 0.13527671922929585, 0.10358114304835908, 0.25159673066809773, 0.08612729172455147, 0.3335523064015433, 0.19893223943654448, 0.15869481809204444, 0.10092949392856099, 0.14467900298768654, 0.29493049602024257, 0.1266965569811873, 0.11190306759090163, 0.15861901512835175, 0.21803325042128563, 0.14150097820675, 0.11215645165066235, 0.17722764081554487, 0.09905819824780338, 0.13387723651248962, 0.2183209068607539, 0.17877645848784596, 0.10847476834896952, 0.1281910197576508, 0.08880156150553375, 0.15799295419128612, 0.14992346375947818, 0.21081286598928273], [0.09216330494382419, 0.010304750176146626, 0.018024798519036267, 0.12050818826537579, 0.039017994786263444, 0.0164669693185715, 0.06488113256637007, 0.07527625406510197, 0.013645611434185412, 0.061496056005125865, 0.06847152428235859, 0.09121006078203209, 0.016383221664000303, 0.004807295899809105, 0.03391484264284372, 0.03644151038315613, 0.05553779388719704, 0.09236934740329161, 0.04757888716994785, 0.070977519499138, 0.01389160370308673, 0.043593056907411665, 0.01406399811457959, 0.05236244454863481, 0.03058194648474455, 0.025680151993583422, 0.031445490967598744, 0.029982337546243798, 0.08823856827802956, 0.059780143783427775, 0.0563010445330292, 0.022750405296392273, 0.06194506277097389, 0.041793853451963514, 0.020977807835151907, 0.02679939232621109, 0.03004646467161365, 0.07292291120393202, 0.02531231762986863, 0.016631021062494256, 0.04318651212088298, 0.06407461100025102, 0.0188594085193472, 0.04131646695896052, 0.05659204434778076, 0.029130788025213405, 0.028338801421341486, 0.02516503842343809, 0.01683113005128689, 0.013941481593064964, 0.018838737851183396, 0.057679735982674174, 0.03586814935260918, 0.003995831166321295, 0.04828862154681701, 0.037443925539264455, 0.04605387759511359, 0.056209430113085546, 0.04429519540281035, 0.0179566248334595, 0.05851898626133334, 0.029405631285044365, 0.04869609030720312, 0.013464695311995456, 0.07527272144216113, 0.07845052357879467, 0.04619809544237796, 0.05797874357085675, 0.052780830301344395, 0.050635715524549596, 0.02830179793818388, 0.021437902287289035, 0.04716710282082204, 0.010064607886306476, 0.01747559625073336, 0.04003491150797345, 0.05420423985924572, 0.05396562453825027, 0.008833049996610498, 0.003565408705981099, 0.019626488647190854, 0.06900118765770458, 0.06750407541403547, 0.02706139457586687, 0.019548386881069746, 0.03590229927795008, 0.026098560010723304, 0.006559842850037967, 0.04231135673762765, 0.03808822475548368, 0.022235983778955415, 0.06098079029470682, 0.032937330252025276, 0.02420288848952623, 0.021182258387852926, 0.06395310658263043, 0.07585449842736125, 0.06142066864413209, 0.016779606448835693, 0.05659678667143453, 0.042033010540762916, 0.026216945552732795, 0.033748089481377974, 0.03003376466949703, 0.029174988485465292, 0.014976357360865222, 0.06384307576809078, 0.032548081217100844, 0.018634261323313694, 0.01118899037464871, 0.032212255682679825, 0.019058541583945043, 0.06436618597945198, 0.07029762316960841, 0.06681859071250074, 0.0331855563854333, 0.10543393698753789, 0.08078271523118019, 0.03604917030315846, 0.07632280845427886, 0.057029648014577106, 0.015813048157724552, 0.03938274923712015, 0.06616104787099175, 0.036707904291688465, 0.052425323010538705, 0.05015598013415001, 0.020552173155010678, 0.09289748195442371, 0.048430976603413, 0.02195820718043251, 0.01577549919602461, 0.021849128170288168, 0.021671688082278706, 0.056392169135506265, 0.059535995751502924, 0.0207085084184655, 0.01797632699890528, 0.013397316652117297, 0.021902421794948168, 0.016790143090474885, 0.029191469729994424, 0.06383791784173809, 0.022768022026866674, 0.015463993840967305, 0.05544328138057608, 0.07655583540326916, 0.04005838563898578, 0.03515696407703217, 0.028849415721197147, 0.026011600712081417, 0.06090202987252269, 0.013874589967599604, 0.04859057175053749, 0.05087795252620708, 0.013237168604973704, 0.05754020850872621, 0.04666365210141521, 0.08091530733508989, 0.018607508754939772, 0.04416973162733484, 0.031030123900563922, 0.04307486713514663, 0.030637297713838052, 0.06455328883021139, 0.04963112958648708, 0.02345230259379605, 0.025090465569519438, 0.02094098617817508, 0.025050894255400635, 0.01931533024617238, 0.01657452135987114, 0.060113813378848135, 0.0719937942631077, 0.03675026608107146, 0.05915278408792801, 0.0873656096518971, 0.06951095405383967, 0.08129921290674247, 0.04208468628348783, 0.010285829121130519, 0.02385963591223117, 0.09862016042461619, 0.04930282571876887, 0.036615239732782356, 0.019572751589294057, 0.06707923297653906, 0.02251262303616386, 0.02617301968712127, 0.04348041373305023, 0.008049790121731348, 0.04434296002727933, 0.04167522485658992, 0.06387873596395366, 0.07860984042054042, 0.0439816639845958, 0.020180056599201635, 0.030513694873661734, 0.038328899536281824, 0.039486872556153685, 0.054879148956388235, 0.047754876359249465, 0.07031978369923308, 0.017237858519365545, 0.030392136650334578, 0.038553469712496735, 0.07120161099010147, 0.07916485556052066, 0.07784749890561216, 0.06425734260119498, 0.023307025330723263, 0.05138215281476732, 0.02106366133375559, 0.05726593670260627, 0.035465723485685885, 0.04641070219804533, 0.045269446054589935, 0.022217921759875026, 0.07388843048829585, 0.06794946792069823, 0.054195230186451226, 0.02285565667989431, 0.06711554626235738, 0.030962768432800658, 0.02505185162590351, 0.038711847737431526, 0.0066161843824374955, 0.044824587894254364, 0.044999526944593526, 0.06437123258365318, 0.05466840499138925, 0.013614914350910112, 0.041993932754849084, 0.053692213623435237, 0.026933585613733158, 0.07395829627057537, 0.0694578979164362, 0.042826511125895195, 0.021511439845198765, 0.0044576409072760725, 0.05759596235293429, 0.04805287091585342, 0.023886574017524254, 0.022063423311919905, 0.05155869119334966, 0.07623134617460892, 0.019603988585004117, 0.04826565578696318, 0.012310832862567622, 0.011549153714440763, 0.056569067455711775, 0.03447162780503277, 0.013927044037700398, 0.021580010579782538, 0.08248688667663373, 0.040569862685515545, 0.050796409050235525, 0.06120559053670149, 0.05522261119040195, 0.04840859714022372, 0.014673408968519652, 0.029316657055460382, 0.027714645948435646, 0.030871775561536197, 0.03857515155686997, 0.02488592410372803, 0.07309677414014004, 0.017821698675106745, 0.06484211786300875, 0.05350471372366883, 0.04489169659791514, 0.022371123304765206, 0.03300140728242695, 0.056830336834536865, 0.05553053939365782, 0.061587885647895746, 0.015935107330733445, 0.013062126581644407, 0.023668916946917307, 0.03210449584003072, 0.010971894553222228, 0.01300900272326544, 0.04291266333893873, 0.02284321828483371, 0.004725816434074659, 0.01100243393011624, 0.02755647015874274, 0.04062808417074848, 0.053163522461545654, 0.034780817659338936, 0.010415955439384561, 0.05568594511714764, 0.05663400537741836, 0.015409122224809835, 0.08267392273410223, 0.07308417989406735, 0.008089604489214253, 0.007152983971536742, 0.05016616611101199, 0.12736358447000384, 0.047223858564393595, 0.05197125850827433, 0.049583858490223065, 0.03884644364006817, 0.0282143506774446, 0.018973636178998277, 0.059814456981257536, 0.0069231371253408724, 0.03641987677838188, 0.011520555053721182, 0.047639843469369225, 0.02153292873117607, 0.031403882458107546, 0.02351945026020985, 0.015208613403956406, 0.061156968731665984, 0.017311412775598, 0.048938624167931266, 0.01839805241615977, 0.03767449969018344, 0.0227348406042438, 0.015574985736748204, 0.03149578631564509, 0.023986084888747428, 0.0637632652069442, 0.05223810512688942, 0.035899794529541396, 0.033602394760237075, 0.014436309484153753, 0.05570053202973213, 0.041394232903257944, 0.016662632842781022, 0.03335896290082019, 0.025818642316153273, 0.08197945062420331, 0.03713858743140008, 0.03692592501465697, 0.029177296564739663, 0.060108681427664123, 0.03153465630020946, 0.05587918923993129, 0.01367433904306381, 0.055368383837048896, 0.05872872090549208, 0.027964549335592892, 0.03347976969962474, 0.032483128452440724, 0.03136047795123886, 0.010234209967165953, 0.052792122078244574, 0.040079332757159136, 0.027008371835108846, 0.34914913354441524, 0.10756793068139814, 0.1657348606386222, 0.20470015180762857, 0.11799009604146704, 0.11569017297006212, 0.1684503789874725, 0.11898990254849195, 0.1451149702188559, 0.13673683541128412, 0.1978791764122434, 0.26170433673541993, 0.09368217695737258, 0.13183649367420003, 0.13428192964056507, 0.24288927525049075, 0.16837764851516113, 0.19697035721037537, 0.18653482577065006, 0.16045658761868253, 0.07836374425096437, 0.1680563431000337, 0.11126694313134067, 0.08697214521816932, 0.23348207847448066, 0.10590536403469741, 0.17434945853892714, 0.1016951899509877, 0.09598304255632684, 0.144614540040493, 0.13694723427761346, 0.09407504767295904, 0.1873405755031854, 0.15253966790623963, 0.09717137683765031, 0.10775273287435994, 0.08729849723749794, 0.16544343408895656, 0.10920608066953719, 0.17402914760168642, 0.15576609555864707, 0.08497164162690751, 0.15554665733361617, 0.1500109926564619, 0.17075545998523012, 0.08274678679299541, 0.16557850496610627, 0.09242333864676766, 0.12068784737493843, 0.13530885422369465, 0.04063624037371483, 0.1783856435213238, 0.11091093489085324, 0.11158969573443756, 0.11636672221357003, 0.12670025287661701, 0.16142771753948182, 0.14873823907691985, 0.12881115835625678, 0.13043476967141032, 0.12664708541706204, 0.10167047643335536, 0.12202392841572873, 0.05615815141936764, 0.14242971665225923, 0.17783376766601577, 0.14414458244573325, 0.11223478533793241, 0.15224721719278023, 0.20506555563770235, 0.12900582369184121, 0.17277707025641575, 0.1266037143068388, 0.1363833950017579, 0.15399001742480323, 0.1063285292184446, 0.12038949658744968, 0.1483535987790674, 0.15665230894228444, 0.12288171012187377, 0.11501385379233398, 0.182084062253125, 0.21745628997450694, 0.15572030504699796, 0.09187099523842335, 0.18183634820161387, 0.17382161342538893, 0.08807769292616285, 0.11463451242889278, 0.11796322287409566, 0.12899020890472457, 0.11219009320484474, 0.18718616425758228, 0.1559374129283242, 0.09928122846758924, 0.17927630979102105, 0.1625108820735477, 0.21799164562253281, 0.23023642919724807, 0.17449021426727995, 0.12525140249636024, 0.12684281944530085, 0.11284427411737852, 0.20092153659788892, 0.09361130927572958, 0.14807195373577997, 0.13484397291904315, 0.13802143366774544, 0.13341471523744985, 0.10547137833782472, 0.13893081690184772, 0.1364427965017967, 0.1384026897721924, 0.11079746051109396, 0.15004017390310764, 0.16423794877482578, 0.20666838681790978, 0.2015867829322815, 0.21111879410455003, 0.2495189249748364, 0.10441683101817034, 0.08332569908816367, 0.09033023728989065, 0.22980064008152112, 0.1308313140179962, 0.1979759376263246, 0.1583007673616521, 0.14000117196701467, 0.1428381650475785, 0.0674646970583126, 0.18790901609463617, 0.12307319164392538, 0.1263075676979497, 0.08316879422636703, 0.13610382797196507, 0.08379926352063194, 0.11822957967524417, 0.17387764557497576, 0.12123518128646538, 0.18709992669755593, 0.13170295162126422, 0.12721703998977318, 0.13417313079116866, 0.10896815554588102, 0.1198445598129183, 0.20530607085675, 0.14960500819142908, 0.07566469415905885, 0.19505444361129776, 0.1111628494982142, 0.15873290511080995, 0.13794306287309155, 0.19500559545122087, 0.12482536520110443, 0.20356313703814521, 0.08542106399545446, 0.19757544505409896, 0.16314503242028877, 0.220198733441066, 0.185124374111183, 0.12144857842940837, 0.08994476578664035, 0.2552910230588168, 0.09262607112759724, 0.22932940599275753, 0.12454119685571641, 0.2529217314440757, 0.16602873627562076, 0.16019671718822792, 0.10936829188722186, 0.15355796873336658, 0.05093692729133181, 0.08038285348447971, 0.13209050113800913, 0.14460541162407026, 0.16703293629689142], [0.056799912490532734, 0.04364890723081771, 0.06515108878375031, 0.023288564407266676, 0.06573086939170025, 0.018535156777943484, 0.03517816723615397, 0.02481728843122255, 0.0321808999433415, 0.06372192015987821, 0.07346297206822783, 0.029801936289004516, 0.05754269841418136, 0.022968147713982034, 0.01782986229954986, 0.023845536961744074, 0.03725856302480679, 0.030741408045287244, 0.01268532985704951, 0.05051990709034726, 0.051574120443547145, 0.02013445904594846, 0.08955858182162046, 0.03617618145653978, 0.012510754459071904, 0.05987264506984502, 0.06430391978938133, 0.06580897301319055, 0.05563267746765632, 0.046294897474581376, 0.03320916039228905, 0.04299455933505669, 0.046244873010437004, 0.027899752421944868, 0.012061660490871873, 0.08510947329341434, 0.047393528366228566, 0.06371575291268528, 0.02630280276207486, 0.02422932935587596, 0.021069270114821848, 0.03544978957506828, 0.055818359105614945, 0.04239206900820136, 0.008910665656003403, 0.05355487548513338, 0.0166299709235318, 0.03784723827266134, 0.0889686041045934, 0.09169080920401029, 0.07303168778889813, 0.0359213947376702, 0.04783746255270671, 0.024269097339129075, 0.01722528653772315, 0.04142146230151411, 0.005292408150125993, 0.019522309667081572, 0.013225042839621892, 0.020423098831088282, 0.0625746489095036, 0.01672954487730749, 0.02393940565525554, 0.06321901120827533, 0.06979700745432638, 0.038710159351467155, 0.04717650583188515, 0.008240406114055077, 0.026525046305323485, 0.017285146313952282, 0.027199923861189745, 0.05716202489566058, 0.05950104430667125, 0.08764213387621567, 0.03015839909494389, 0.03525793697917834, 0.06666677698376589, 0.01706527022179216, 0.02115234612574568, 0.01205993685289286, 0.024483841480105184, 0.029600326306535862, 0.12679040897637606, 0.026762051165860612, 0.03169239978888072, 0.02647357094247127, 0.06589022334082983, 0.012681890002568252, 0.023225869626912754, 0.06054206969565712, 0.10134476266102865, 0.011467139902379131, 0.003988603575635352, 0.043569348999881186, 0.03018330186023377, 0.06543162802699953, 0.043975281514576636, 0.07296145093278028, 0.050253813751623966, 0.03172539196384605, 0.032044756662799045, 0.0564304045838071, 0.02473326061590342, 0.025177096467814408, 0.0674147876270581, 0.05406913929618895, 0.08319937071064487, 0.03896468631864991, 0.08010942401597276, 0.05741921246226411, 0.04439333701157011, 0.027263819065410644, 0.06367478636093438, 0.0715276735718362, 0.012759001001541037, 0.024316594790434465, 0.09808263028389774, 0.08543240401195362, 0.026198640480288304, 0.03023314264282817, 0.04972595379513223, 0.055976035800995305, 0.02191810151998652, 0.08192914043320343, 0.04602913810231257, 0.09292318252846599, 0.04100948128325399, 0.05363300508179236, 0.036456434972933494, 0.02286318576807389, 0.051730754421441816, 0.035092783145955764, 0.04781766947417054, 0.01700967965007294, 0.09300400983192958, 0.07729733741143718, 0.030247358481574338, 0.058898186616715975, 0.06324730929918587, 0.044197198512847535, 0.00880235476870439, 0.03579220167011954, 0.042897972525679506, 0.03382576265721582, 0.02474262466421351, 0.02006491424253909, 0.019148927749483846, 0.03459841631411109, 0.02451094285788713, 0.00937020442506764, 0.03689937097078655, 0.015481964946957305, 0.08184889942640439, 0.02114425486070104, 0.011091408159700222, 0.0750234563020058, 0.07170609329477884, 0.034819798966054805, 0.007321335069718771, 0.0596361485804664, 0.0245055047707865, 0.07569158216938376, 0.10499566167709418, 0.016658077911415603, 0.022911633168405388, 0.02713333651627181, 0.018098562431987375, 0.0236174397286959, 0.027969306502200197, 0.033019278198480606, 0.03537216463882942, 0.07457846455508843, 0.03963567687605973, 0.025917334969562944, 0.05058109716628678, 0.04222958690661471, 0.0503233233030187, 0.06254062143852934, 0.09439906192710623, 0.003233218535569904, 0.05283867329126224, 0.021553705155383795, 0.013616084161185427, 0.05721203451685142, 0.07498322447645478, 0.055099140081438236, 0.06398460333002731, 0.039606402860954404, 0.01365306816296652, 0.03041222102183383, 0.03507702364004217, 0.06767338156350888, 0.024951353698270395, 0.0337466237397166, 0.04064986620505806, 0.014781520403630566, 0.028008276676700916, 0.015669869317207485, 0.03356909830472432, 0.05317843962984625, 0.036753234671778046, 0.018606595913297497, 0.09757936510141008, 0.0764587328012567, 0.059490921412361786, 0.039378749061143026, 0.041808269670582376, 0.02573611549451016, 0.06423412822186947, 0.03552518435753882, 0.0220171466935426, 0.05217086654738523, 0.040136329698725604, 0.03938852314604446, 0.02019928379013436, 0.04004844828159548, 0.01897365102195181, 0.05375540378736332, 0.048113986777025275, 0.06009146360156592, 0.00211526072689594, 0.05631178340991028, 0.01741657695674803, 0.07084765849867836, 0.10910231358138844, 0.01286593520489987, 0.04001207562396303, 0.014075673952902434, 0.052597148751374334, 0.045205435817479156, 0.052306950456113555, 0.10277548237354495, 0.030401188996620476, 0.05467109898745548, 0.06750621279934421, 0.030347776628332213, 0.04615185593138449, 0.027765162085415795, 0.013011493556405185, 0.023331870579568204, 0.041057364651351236, 0.06861381625640206, 0.07417800166876987, 0.02462507032760186, 0.06442760612117127, 0.03622622447437607, 0.02832969341397984, 0.05983391609333921, 0.05837649019667879, 0.07247029017889872, 0.035556926013669, 0.01360355670840363, 0.02042715837887954, 0.036084644962102175, 0.0446421902597649, 0.0678163711563684, 0.03724026908457745, 0.06515261018648744, 0.05393070649006404, 0.053340135054895654, 0.0011812236948571808, 0.043216698977630585, 0.02401137913693674, 0.0345895179634681, 0.024299484575749375, 0.03216328506823629, 0.04139261131058447, 0.03184441018674988, 0.03352976818860043, 0.025082519023271743, 0.01935742486239178, 0.023580334200232755, 0.051928688917541876, 0.0275201383192325, 0.06311666904366575, 0.08501303862431087, 0.030411289626499638, 0.0404464657913195, 0.00884751074408996, 0.005534563979381346, 0.04526825490756892, 0.03487412046524696, 0.020940867434546817, 0.059727792686317116, 0.08016639127163216, 0.011407572346797679, 0.04602107095706742, 0.0752140324038919, 0.021348228583519813, 0.055747506266925484, 0.06068859191145748, 0.06348767608869821, 0.046853730964357965, 0.025851432255876716, 0.06150627166789491, 0.031427107969648205, 0.013321229816938285, 0.03314917630632408, 0.012173274863016559, 0.10484711339813657, 0.007832820465409895, 0.03831937778159045, 0.04890238880761899, 0.005944804197497433, 0.018250810317113064, 0.03539674085914157, 0.04703102633357048, 0.032909752044361085, 0.08821124240057543, 0.013222442539699841, 0.10583369483356364, 0.02088709698000457, 0.06567765740328468, 0.06989324174355716, 0.03947263445297722, 0.024657713693159167, 0.04157769180892501, 0.04894314013654366, 0.05999297689413652, 0.016183205443667248, 0.027257770561845973, 0.04149524662352633, 0.0444532505935058, 0.06399612146196887, 0.05319397649145685, 0.11079226547735743, 0.06420327714295126, 0.025801305746426806, 0.018899554997915402, 0.02026627931627445, 0.015180487862380687, 0.02316843852895545, 0.07010902118054219, 0.003523017694533337, 0.026052465218526777, 0.005406585714808898, 0.049723174452083185, 0.0056529453468101565, 0.05308189363859128, 0.09537295263726264, 0.02110592478857143, 0.09586923421011306, 0.045599282457260415, 0.023376757526420988, 0.039888018218334764, 0.008894400561985094, 0.06415526018827222, 0.055556332736159675, 0.023734775131742936, 0.052162688079988584, 0.02783599451504415, 0.09454591068788432, 0.10896641892031766, 0.13016027893172577, 0.16273616842227057, 0.11576638411497697, 0.1662531023612246, 0.08434860123088583, 0.18433998338878155, 0.19156351452693343, 0.1686897364561446, 0.16724959888961166, 0.3355979919433594, 0.16444487439002842, 0.10420231323223561, 0.08846101962262765, 0.09252306845155545, 0.1282147239544429, 0.07419185756589286, 0.13618580560432747, 0.11645146063528955, 0.1366618339670822, 0.1419960055500269, 0.08323773232405074, 0.10786487138830125, 0.14561712217982858, 0.11026862834114581, 0.12660279404371977, 0.1596883311867714, 0.15884347027167678, 0.19878964318195358, 0.12772723683156073, 0.07605392092955299, 0.07192641467554495, 0.14981037529651076, 0.13677119684871286, 0.07180702537880279, 0.1682842566515319, 0.12919173168484122, 0.16089708195067942, 0.12477963406126946, 0.1667863057809882, 0.18080489651765674, 0.1304657172295265, 0.13849217793904245, 0.149201606400311, 0.13461254158755764, 0.10539731199969538, 0.0987052105483599, 0.11994216707535088, 0.1557019739993848, 0.16802113561425358, 0.20016236405353993, 0.17667698208242655, 0.06881880486616865, 0.20091745478566736, 0.12496708572143689, 0.24686018092324957, 0.1390637652366422, 0.10469067608937621, 0.206553339085076, 0.09186963710817508, 0.22836698888568208, 0.09075539142941125, 0.08902672911062837, 0.1441136942594312, 0.24535989970900118, 0.10903684873483144, 0.21298626030329615, 0.11344647500663996, 0.2404167063650675, 0.1585459877969697, 0.18846112943720073, 0.13913777220295742, 0.31429268361534923, 0.16034468659199774, 0.09630178756196983, 0.12423300519003533, 0.11060464312322438, 0.14067841140786186, 0.17974079033592716, 0.15997750160750002, 0.09650308027630672, 0.11482252812129445, 0.24507519701728597, 0.21059090446215123, 0.14454694523010403, 0.13327409309567884, 0.17554094694787636, 0.13716978952288628, 0.12139202677644789, 0.13076238334178925, 0.16877846763236448, 0.0998479472764302, 0.1236454988247715, 0.1654243015218526, 0.13636733492603526, 0.11806478578364477, 0.17652301612542942, 0.18365894415182993, 0.12050985809764825, 0.13072812580503523, 0.09972191575798206, 0.17923598148627207, 0.16644868795992807, 0.1350650141830556, 0.09948647682904266, 0.12200544893858023, 0.1494720598566346, 0.14568105078069493, 0.20920384529745206, 0.08478554809698835, 0.069996719394112, 0.13823079352732748, 0.18512256327085197, 0.278141750022769, 0.128183672495652, 0.11411847488489002, 0.08899127671611495, 0.13967924314783886, 0.17472350096795708, 0.07442223504767753, 0.12355300495983101, 0.15735435095848516, 0.1336395414546132, 0.13748061581281945, 0.09785319532966241, 0.17511336598545313, 0.1878471506643109, 0.12604992371052504, 0.13862340449122712, 0.09148452925728634, 0.20827638334594667, 0.08240710580139421, 0.19160526775522158, 0.11313753377180547, 0.15469615609617904, 0.18272590124979615, 0.11633893620455638, 0.11460946494480595, 0.16747877409216017, 0.11204111448023468, 0.10561016737483442, 0.21277222491335124, 0.12356308332527988, 0.10140624959603883, 0.10142197570530698, 0.14125324931228533, 0.16757817735197023, 0.19592242984799668, 0.08676217679749243, 0.10879044828470796, 0.16390705481171608, 0.10238112736260518, 0.17921879334608093, 0.07240680686663836, 0.07243937230668962, 0.1303107271087356, 0.18522486090660095, 0.13638720964081585, 0.10278898946125992, 0.14836517628282309, 0.12313980681938119, 0.15144681092351675, 0.1952725014416501, 0.14077515777898952, 0.12552497297292575, 0.18104502581991255, 0.1107788177614566, 0.11232208416913636, 0.1017421085271053, 0.1236255127878394, 0.22835599025711417, 0.13085120357573032, 0.11468144584796391, 0.19075932330451906, 0.14007210644194856, 0.17197255248902366], [0.020382121147122234, 0.04825345487915911, 0.007230558348965133, 0.07851986985770054, 0.04996655807190109, 0.04540555593848694, 0.03050771316338796, 0.04277831976651214, 0.013833588163834065, 0.05119494606333319, 0.08485381826176308, 0.025452568697801325, 0.037533057475229725, 0.0360051201278111, 0.02849489919753978, 0.01238936414665659, 0.06102412058680784, 0.03010364900546847, 0.0503393017424969, 0.05414538754848763, 0.036552108940668404, 0.028090783089282922, 0.0179724938061554, 0.042952412768499926, 0.02463385921146255, 0.02742843484156765, 0.03919711583876051, 0.08585974006564356, 0.04399207631649915, 0.0744702668453101, 0.05688597935659345, 0.07157517102314159, 0.06851263926364481, 0.03551057889126241, 0.02606011305033462, 0.07293933493201621, 0.059671292983694, 0.060322831850498915, 0.09526833207928576, 0.09633784109610133, 0.0035159030494469334, 0.04628483766282443, 0.05700963600247633, 0.06201689153385814, 0.04320516229199711, 0.021788121775898617, 0.028658414739766158, 0.01538291699034744, 0.03159232859616168, 0.04599289160978515, 0.042161698947893456, 0.1238089642720297, 0.07600142882438377, 0.015098205949470866, 0.04283736503566615, 0.08958567021181807, 0.05106081400299445, 0.022752692966605537, 0.13029312336584553, 0.035409490956226364, 0.02560770168201998, 0.027202599303564057, 0.06935203797183931, 0.03770554001675919, 0.055973108028410934, 0.057150198772433214, 0.05339721363270655, 0.0362653022602899, 0.02279381536936853, 0.04415544528455939, 0.03569044951291289, 0.03574433685571421, 0.02011756590945879, 0.05495517827512231, 0.047312163005699404, 0.01948121323948726, 0.009627743584132986, 0.07392797211650759, 0.04020166095870081, 0.08290511657833122, 0.038164521247381344, 0.029305172320164274, 0.029407963484118227, 0.050441257990314625, 0.013000863218621816, 0.03414323116885498, 0.051548794654081576, 0.030899717421561945, 0.044965889101149514, 0.08838897192617878, 0.054878930022823624, 0.1048015158448834, 0.09317425850895233, 0.0005688173473572533, 0.015499553846893832, 0.05015502647438552, 0.046394942692131735, 0.00851919017804903, 0.07918227376649156, 0.03700285975355655, 0.04330559713707771, 0.03099244506302057, 0.04223653711960651, 0.030179066052369308, 0.002990118555317167, 0.1246739225462079, 0.08103450367343612, 0.04661900078644976, 0.10647646151483059, 0.02838887412508484, 0.015621863494743593, 0.015608887042617425, 0.02668210887350142, 0.018701785629673395, 0.035630435741040856, 0.028781705877918284, 0.05092337938549463, 0.10428729656268843, 0.04578212166961748, 0.05861601464857813, 0.0018638473011378665, 0.054241625548456796, 0.013468523866322357, 0.04420153265527915, 0.013887646200601012, 0.018750249728327617, 0.04440800184966065, 0.03677421889733523, 0.0541670842358144, 0.03989243399701081, 0.06606559283682145, 0.021246257492748555, 0.05450204887893051, 0.09670535262557678, 0.0766149623086676, 0.023710540299362037, 0.0499340445821872, 0.02820291974785505, 0.03673093313409481, 0.05837212265760172, 0.036168626393191516, 0.015338061584770912, 0.0388845937413862, 0.04341434032539837, 0.01381948921334697, 0.03639955677499529, 0.09737351560033858, 0.0684745077160187, 0.047043334852787666, 0.051022504339925945, 0.07358109229244292, 0.07732729049166664, 0.015589377835567575, 0.0352984916389687, 0.0356963792728493, 0.028483843052526936, 0.039288114276132546, 0.0134897390853439, 0.024933532877184916, 0.023289653508982155, 0.0632348634826485, 0.022982311602390837, 0.06778117109206505, 0.03166258771670982, 0.06905222515342757, 0.042812087485799566, 0.13368380314204842, 0.035407861942076124, 0.015113584177015582, 0.03819945784925949, 0.08876006060745567, 0.05754747413448058, 0.05886326114705298, 0.03804076441156212, 0.03133978316327557, 0.04550642865069676, 0.027584191229834687, 0.016415757418144494, 0.044474498281488195, 0.0734230964735616, 0.015094920090632513, 0.04253392311511561, 0.04704618469986599, 0.04390333400806412, 0.04481446128920652, 0.031422874017152935, 0.061937355567351915, 0.018667208969418425, 0.02510284088202752, 0.03549550587194972, 0.042566470001474954, 0.05989147706713993, 0.03082002374867443, 0.017530671029817313, 0.07256792712723836, 0.06235098044271581, 0.02061407754808897, 0.0700538425007835, 0.034522438945714384, 0.04307630690163933, 0.058090522143174894, 0.03596181210014038, 0.03696242012665607, 0.02936262753792107, 0.06553742117830552, 0.03501707295072265, 0.025606586605135817, 0.026667894890124444, 0.024134059858624823, 0.05557667129323818, 0.040388006818830036, 0.03321687130664941, 0.045809473522240296, 0.05651680170558393, 0.06051311851479113, 0.049248641516896896, 0.05099220616102684, 0.019335256911290344, 0.026658016904548276, 0.03382181443157606, 0.01953060502273729, 0.016789337860245723, 0.06366222922224551, 0.023447992571163923, 0.07046484388411045, 0.023488632577937096, 0.04704515311459545, 0.07026413004496135, 0.04963138191669714, 0.06981280035688542, 0.04072023293701932, 0.0759852425835561, 0.04648585949325934, 0.02534588311391417, 0.10648483294062316, 0.051056680240435526, 0.0395557438605465, 0.03425144743232522, 0.01286424218051252, 0.012990949053346412, 0.0698285858379677, 0.06425058905733749, 0.08073792661889456, 0.04362759274954442, 0.016739187230996322, 0.05389581812778488, 0.029326462681638077, 0.012138125821365975, 0.014376517428900115, 0.035042094459640794, 0.05690620659152046, 0.009472821184317581, 0.035094586564810015, 0.03656396846054122, 0.025495117879472673, 0.01861750177340582, 0.07113434272469021, 0.024081768133328296, 0.045853494011680596, 0.035194539013900794, 0.013506224040611414, 0.07139341905713081, 0.051817993880831636, 0.052764454812859185, 0.05095964443171397, 0.05400421250669751, 0.029876551816414576, 0.0438818933616858, 0.05251329348539002, 0.09181348621496, 0.04139688237046357, 0.028498070023488253, 0.0444186590902973, 0.010905369363172213, 0.037034734996268526, 0.08129706067848019, 0.02919233618740691, 0.01911400042445166, 0.0945699711155612, 0.010820869356393814, 0.019961132311436813, 0.08342762565007433, 0.0381691782240523, 0.055646566761424765, 0.06414220581064001, 0.06187997270899359, 0.05837506156240124, 0.058497935242485255, 0.009813884425966535, 0.07399858004646376, 0.017837589912232943, 0.024565180865465663, 0.03603496930736583, 0.06840366972028278, 0.04288847674615681, 0.03360062102728989, 0.017486667238699738, 0.06181681223097257, 0.01592702163179638, 0.07044732177746482, 0.044803956188843586, 0.05818543540954124, 0.0230682356050238, 0.019025746078114025, 0.038088265573605895, 0.04746462240291294, 0.05093457468319684, 0.023028612340567634, 0.05871058652701322, 0.055792424755054526, 0.03864674654323608, 0.021093182112963405, 0.01744366905768402, 0.006155006394692464, 0.02381491409323644, 0.0421725120395422, 0.02380257959885057, 0.04117174074053764, 0.08319344095070846, 0.1113799870654475, 0.03635591478087008, 0.03391846803424414, 0.04573211946990341, 0.06670780290733092, 0.0466125069942791, 0.13400129391811788, 0.06776609807275236, 0.0200415180370328, 0.030938767376937903, 0.01569694657518994, 0.05736286489991471, 0.08110264025162905, 0.07131573103833944, 0.052059132503927685, 0.0079964408359956, 0.053209439138299786, 0.08561385911889374, 0.02201483861426823, 0.013954454334452748, 0.07081426185322925, 0.03546483661921229, 0.0744555945857428, 0.03824321487627458, 0.06185253550938796, 0.028662452023127116, 0.01346031014691107, 0.06339622123050503, 0.02757316848146729, 0.020092269805900287, 0.06138747608929407, 0.02200523707870161, 0.022913225075171795, 0.08965284941950813, 0.15560310508590192, 0.11269007067312486, 0.1829098499729298, 0.22659934154944494, 0.12730617192573845, 0.08680428625666536, 0.18995602265931666, 0.18988648342201486, 0.16844919155118987, 0.1863621873781085, 0.0952553296519909, 0.12997389596421272, 0.20544255181448534, 0.08500836309394799, 0.15236881066812202, 0.18474930751835927, 0.09998056906624697, 0.15825931099243462, 0.15312936360714957, 0.07990050944499671, 0.10870750586036593, 0.16576401219936088, 0.12772079498972744, 0.12143350541009568, 0.18458285863744095, 0.1485395067720674, 0.1543372089508921, 0.2063727448694408, 0.07936812238767743, 0.14022500370629132, 0.19444907375145704, 0.08962496693129651, 0.10710191389080137, 0.10464932362083346, 0.24663645308464766, 0.15413262852234766, 0.08534220338333398, 0.21096349228173494, 0.15030081616714597, 0.1636957802111283, 0.09482624212978408, 0.12292847284697928, 0.1341027009766549, 0.13491125602740794, 0.09498077954049222, 0.1476260565686971, 0.07937273854622617, 0.16913432744331658, 0.20804300758754835, 0.08706659093149938, 0.18120964901754633, 0.13527348346542567, 0.16165401320904493, 0.11187500698724762, 0.1586555881658569, 0.17606004956178367, 0.12997517245821655, 0.2537850273074582, 0.23793882370227948, 0.10828108264831826, 0.11830788367660716, 0.1451595436083153, 0.07393554944428615, 0.24969620921183378, 0.21716348303016275, 0.1287731307093054, 0.09246587855159305, 0.09993318293709308, 0.08682945248438045, 0.12019788890029304, 0.096053873130586, 0.06805111246649176, 0.1513623248320073, 0.14388281211722642, 0.09279908059397712, 0.13073602225631475, 0.1848610007436946, 0.09619024276616983, 0.1978404659894295, 0.23892442550277337, 0.09254382632207125, 0.10173881339142099, 0.11584012390812859, 0.1087740839284379, 0.13024994521401823, 0.14799898577621207, 0.13101075048325583, 0.18607187404995784, 0.13622352154925466, 0.15485959185753018, 0.23964957799762487, 0.2001805169857107, 0.20806929445825517, 0.13254849531222135, 0.10732539682067, 0.22591577901039273, 0.11461118672741577, 0.16233851085416973, 0.16988429735647514, 0.10932389661320485, 0.1292898436076939, 0.215073995932471, 0.0889075624581892, 0.0853144470602274, 0.15621736587490886, 0.16233033238677308, 0.12883309624157846, 0.18484976462787017, 0.1608338806545362, 0.12525950674898922, 0.10012753657065332, 0.1001082184666302, 0.1676031728857197, 0.14180059806676582, 0.11449249504948966, 0.1520464662462473, 0.1812767391675152, 0.1559751437162049, 0.14208448439603671, 0.10115033481270075, 0.18762225023237988, 0.05244252228294499, 0.1818059795186855, 0.10846309436601587, 0.06495038978755474, 0.11345060876919888, 0.10124463951797225, 0.13847197667928413, 0.1129987595777493, 0.16933567210799083, 0.06838645189418457, 0.16945397044764832, 0.17036341305356473, 0.13320862082764506, 0.16743666463298723, 0.2025932984543033, 0.0837001868057996, 0.12854212982347235, 0.2202105929609388, 0.11928434221772477, 0.11181815847521648, 0.1579997522640042, 0.19694730610353872, 0.15080808894708753, 0.1484429236734286, 0.15868436865275726, 0.1419611691380851, 0.13162284420104697, 0.2823681029258296, 0.17626884538913146, 0.14943036600016057, 0.1041791433817707, 0.14252722001401708, 0.15942124708089978, 0.1921893676626496, 0.16615032975096256, 0.21560578927164897, 0.07211466043372639, 0.13956854440039024, 0.21510216785827652, 0.09549891736241989, 0.10999787802575156, 0.1119918655604124, 0.14530023996485397, 0.12711980380117893, 0.22495831944979727, 0.19396431773202494, 0.16115325648570433, 0.10926946750259958, 0.16951371333561838, 0.16785753658041358, 0.11758579625166021, 0.06662449683062732, 0.15482623974094167, 0.13709722232306376], [0.07906709244707599, 0.06141202262369916, 0.008972007872216636, 0.01570943135448033, 0.021466569596668705, 0.021591651166090742, 0.018657503533177078, 0.11774233003961854, 0.04282571702788118, 0.04207657832012046, 0.047121861498453654, 0.03885692647600081, 0.002932046891146456, 0.03237650038499851, 0.031822320161154494, 0.009350614509457955, 0.03880225987813901, 0.07509979361202568, 0.00012023135894878578, 0.04542180526186712, 0.03272387744800653, 0.04807402583537623, 0.03458986306213774, 0.043492725963005796, 0.038706578488927335, 0.03255635245295707, 0.04023865330964327, 0.049835646932478994, 0.026304734201403335, 0.016184819614863954, 0.05437074440123979, 0.02403812984994147, 0.04790892024175264, 0.041371753250132315, 0.05019003358029295, 0.061307416908675805, 0.044002202921546996, 0.04707158470409922, 0.06682846127660014, 0.04370398572064005, 0.044222858268767595, 0.09558900666888803, 0.02538656579417875, 0.025075613339140546, 0.03513377938361373, 0.04710367516963743, 0.04154779810050968, 0.03645069446065463, 0.029977630474604666, 0.10466717969393358, 0.06886334856972098, 0.029244605648273136, 0.07639037357876077, 0.027359656305634417, 0.0564299852703698, 0.03052411091630347, 0.04907997732516378, 0.06208010025147814, 0.04617595717718359, 0.028019805940857623, 0.05302004676195793, 0.02905026685766643, 0.03188802249496803, 0.026156364037888125, 0.07337427799939178, 0.029195525567047298, 0.038384742438211106, 0.04811237260582857, 0.0325360510032624, 0.029401467836578377, 0.042661628176574595, 0.04658658006519545, 0.037620972289005294, 0.09997673958423547, 0.013088295636407565, 0.013311221955518704, 0.01241363608642132, 0.03902655174897518, 0.02745365858572768, 0.12713978241663426, 0.033906307944562286, 0.018767573310469743, 0.04660382015572395, 0.05617604088911321, 0.06852154503576458, 0.025927919850801118, 0.014014913394930772, 0.03229398840630893, 0.05790890376374591, 0.030115623558231164, 0.03819507917796727, 0.011245602327107918, 0.08852238781400956, 0.041245577012887225, 0.05342913711501751, 0.023276079627976287, 0.027731676382245496, 0.05295289352943655, 0.01626361899980111, 0.016569109247939195, 0.02298504456121009, 0.04015585560409818, 0.046706566790817305, 0.028582301929418463, 0.050647957250475883, 0.022776013101974968, 0.035241717341705225, 0.05090915241453331, 0.09205401627696119, 0.031826854683458805, 0.029497687282855622, 0.024203831017075572, 0.010860726397368126, 0.07329742118599825, 0.05158016523637343, 0.016135919504449703, 0.022438630912802182, 0.056852931520552374, 0.13894818315748125, 0.03644478325441014, 0.04132796653721016, 0.008518391441612039, 0.030006017623236403, 0.009706053151603555, 0.014035391104698647, 0.017778897163225338, 0.02540963359933812, 0.018866117534344085, 0.008024336311791558, 0.0647224391286727, 0.011763428447011393, 0.03680124049424194, 0.04506649464019574, 0.024136130450642668, 0.038726776037947275, 0.07926195074105635, 0.00550418045349943, 0.04966097134456504, 0.03611562220612541, 0.08043317851843312, 0.07187650524429046, 0.029908697943028528, 0.037453347104019485, 0.08233116182964295, 0.06478857932961546, 0.07445504539646208, 0.03439713102125097, 0.07292813592357561, 0.025606380659155548, 0.04610673706338275, 0.025417348224436864, 0.029421435319818556, 0.050406774098519236, 0.02941579314210685, 0.05058047747297678, 0.06110168244049419, 0.013430935941869393, 0.017176555265905336, 0.1637621727422811, 0.04477407732338179, 0.04008365947811399, 0.03764085442526266, 0.04258117565768771, 0.015435387758770958, 0.02765434459433891, 0.021470629144459963, 0.022426782525144517, 0.07356736256042495, 0.04978359640517738, 0.04127984939259477, 0.10706725559430197, 0.059266340103931725, 0.03805280204687733, 0.016369267432310153, 0.03262251120759174, 0.048623727197991684, 0.01707016839645803, 0.03085113272391027, 0.03761487554584164, 0.031512454952462576, 0.02313408265763428, 0.016932795006141532, 0.09241173887858167, 0.10161859288928099, 0.052725621935678646, 0.05370884515286889, 0.07031435117824003, 0.01527878161141416, 0.005136718555149855, 0.03589924905099906, 0.024415983207290992, 0.055225910036824644, 0.009550281920382986, 0.05181530359550379, 0.0407295988406986, 0.00921532098800526, 0.015528547701251227, 0.042563853930914775, 0.012169020501460182, 0.024987538963614497, 0.06860654320917092, 0.019560662003641482, 0.009584323306626175, 0.02459505973092746, 0.08985108448541723, 0.05396395470597781, 0.03961881528084632, 0.05214003031142056, 0.0243568674341077, 0.04204958640912082, 0.05239177793555427, 0.09064511570613831, 0.03788920301303733, 0.02711001638090238, 0.031790374414413236, 0.01536961770398193, 0.14275053224992007, 0.0662582172662951, 0.020018210889247712, 0.024735308943490963, 0.05237942488747649, 0.06399304154911079, 0.00567910002246208, 0.010818855353136314, 0.03399310211534612, 0.0464203575393185, 0.03442834575253073, 0.06011303783452604, 0.022955987624300178, 0.029344591494009364, 0.017445893645344768, 0.026776677041198127, 0.009889606681099394, 0.06830781392636709, 0.007932776625239057, 0.015114762336452259, 0.0022090266793384217, 0.08325231552589685, 0.05424992647022009, 0.030017463395779487, 0.027007002572645433, 0.02986989846249344, 0.020140962114965077, 0.07132794678909704, 0.022819929690740537, 0.018216604730696417, 0.02509022808226291, 0.04037782455270644, 0.09525660614599474, 0.07003790116868913, 0.0517293851589784, 0.06906547248945571, 0.02871646182029508, 0.00934492316446267, 0.05894248541153502, 0.025965867716877256, 0.054727346359868534, 0.0079191340955731, 0.07377869653282687, 0.06546799326315522, 0.025295927298429888, 0.041405469019082375, 0.024450686032650992, 0.0595920835621655, 0.0562323031044798, 0.02797567784000421, 0.08981898659840226, 0.048382221211795695, 0.04511865277891047, 0.013957213268440682, 0.026782215318235103, 0.024675347121956293, 0.07919477153336629, 0.023853882412367966, 0.01798816054360941, 0.05962940616882406, 0.012717227364191785, 0.06523780873976648, 0.10680253893951885, 0.03361553819559049, 0.04230397236824501, 0.04265553143341094, 0.06791081686969846, 0.046597638065577485, 0.02774759916064795, 0.0353759310382884, 0.02038438840827439, 0.05570108492975123, 0.07875922732637264, 0.02195776189182652, 0.026020309815066867, 0.05728246433136519, 0.019821393325401004, 0.040658204234205186, 0.0699015315331053, 0.051242940753581934, 0.09272126641008072, 0.01743186148814857, 0.038621751009486616, 0.07310158325708471, 0.03775835495616775, 0.0544837029883638, 0.0436363834887743, 0.008059784067881992, 0.040337904429179616, 0.05408678014646284, 0.024505896253685933, 0.012839419196097879, 0.02264817630930338, 0.03981348061643075, 0.020909016311634332, 0.12121167746954598, 0.02963616276247194, 0.05277327152725775, 0.05883198704395909, 0.05761227475886699, 0.029210988213890232, 0.04427805179147981, 0.036715537280542776, 0.09670120402006432, 0.022742111796105746, 0.033410931791877374, 0.036076440519536845, 0.060445004201028496, 0.06855995859950781, 0.050172058763564564, 0.009213993471348658, 0.031799473144928925, 0.008092754906101618, 0.06439368255087174, 0.031974375087884255, 0.01826309471653076, 0.014412716609513154, 0.03557957265002187, 0.03220306789444294, 0.03442406727117486, 0.03823932973318733, 0.03660707610833924, 0.05667995545081794, 0.044165100625832565, 0.06062135704269167, 0.04085928914719261, 0.06314645142992958, 0.04269394870789256, 0.02860793571016984, 0.026444695831742138, 0.03650793260021601, 0.08637910985271446, 0.06687025903374888, 0.04798750996997114, 0.06757997485692613, 0.011280834860372124, 0.1283361393143423, 0.12942055065650493, 0.12757500750012696, 0.11218456420465373, 0.13400873023783788, 0.13162680726964027, 0.17284655012190342, 0.19021323620108888, 0.1124371615878772, 0.16117040009703487, 0.23611918149981648, 0.13051401620032266, 0.11259977356530726, 0.12501994147896767, 0.2248962759040296, 0.09539262697217055, 0.10899909568252042, 0.18153071694541723, 0.14997045655036345, 0.21500813774764538, 0.09904851322062314, 0.14755276206415147, 0.07360301533481106, 0.12688650225754827, 0.12671478412812576, 0.1423395605525002, 0.10426051245303825, 0.11738702683942392, 0.22892451990628615, 0.10460144767421298, 0.12734258169075474, 0.1520091955899261, 0.08342416724190116, 0.2370198370772414, 0.18434369412716478, 0.1850371272303164, 0.11777685474953614, 0.12634210725082085, 0.1316490420140326, 0.12055049810442142, 0.2779891941463575, 0.14442649466218427, 0.11136533707031049, 0.1013452821644023, 0.20064707554411143, 0.09902782214339823, 0.18668295844690874, 0.09211422671796754, 0.14020452043041587, 0.22431244316976517, 0.17496502550784498, 0.09550643531838432, 0.23262463073479012, 0.1092467355192639, 0.14196283154888079, 0.07358947113971226, 0.15337176388129592, 0.18052871368126944, 0.13700059469556436, 0.07693010789807886, 0.19054610427701846, 0.11868883550050668, 0.21678749617422, 0.12232452048920095, 0.14863371499814093, 0.1450205987202935, 0.10906800409429707, 0.2291570941451937, 0.19890635332558304, 0.15417656366480514, 0.15336501033743843, 0.11685927078360692, 0.13129943108651787, 0.22657961526419967, 0.09243683831300586, 0.11662971708574332, 0.15398949792142957, 0.1066721064853482, 0.1610736537259072, 0.268790481495671, 0.14027437136974186, 0.08133359660860151, 0.12106396039598621, 0.144084527855739, 0.12841250631026924, 0.1050466917513404, 0.10690020557376556, 0.20372697355924174, 0.139800317119807, 0.11649966312688775, 0.1548749246285297, 0.14053300983505324, 0.14395002101082355, 0.250969942426309, 0.1776411506580189, 0.10755991548649035, 0.1916092456667684, 0.14179377030814067, 0.09590585177647881, 0.14370074844919145, 0.14421208819840103, 0.22163097455631942, 0.10061420733109117, 0.14244049263652414, 0.10063871304737404, 0.1034118740062695, 0.19427230901783332, 0.1716037793084979, 0.16466061671962962, 0.1159748385543935, 0.11126738099846989, 0.1435839047189802, 0.11351938359439373, 0.17042133025825024, 0.1672006765147671, 0.2112015287275426, 0.13331019115867093, 0.21762624179245904, 0.17842473986092955, 0.1319492852780968, 0.18123503046808764, 0.061873434387962334, 0.12870071193901822, 0.21236940199742094, 0.18134522455511615, 0.25644494395237416, 0.2604963578050956, 0.09960054492694326, 0.0833568544476293, 0.13095039903419092, 0.0665421703888569, 0.1794913545018062, 0.12110952826333232, 0.19759079266805202, 0.09653010187321343, 0.2685044874669984, 0.10525056713959202, 0.16757722740294412, 0.14889621263137087, 0.14944794005714357, 0.22518365032738075, 0.14335700048832223, 0.09839366437518038, 0.16515666822670028, 0.1097384380409494, 0.1620864329743199, 0.17776228400180116, 0.18717347353231162, 0.1659368138643913, 0.11775979277445003, 0.13726416102144867, 0.09547882742481306, 0.14469846209976822, 0.16948554140981287, 0.11906850340892561, 0.12460503639886156, 0.05148709249624517, 0.14580694871256128, 0.22566010913578793, 0.09962767784600146, 0.13568531605415046, 0.1508523803204298, 0.22578723903279752, 0.07772695185849443, 0.13003645901335403, 0.0705310731427744, 0.1678421295946464, 0.2257783035747707, 0.18176412238972262, 0.15995853231288493, 0.23079737409716472, 0.16490813781274483, 0.30768555065151304, 0.10191189707256854, 0.1164682480157353, 0.1391482216422446], [0.05309811698680278, 0.054071714548626915, 0.019583880093705375, 0.016387542818847578, 0.03499893857224379, 0.034425870690029114, 0.03383590781595558, 0.10029402998043224, 0.019216136643080972, 0.019974069800809957, 0.0159296506899409, 0.04004468930361327, 0.0570498121669516, 0.022562111298611853, 0.05095924738270696, 0.018555573260528035, 0.03308751867734827, 0.020939238420396578, 0.055676449337624945, 0.036872419877909124, 0.02499542428267887, 0.024406361262663268, 0.030036015232326463, 0.020134373698965646, 0.06242321367608383, 0.027418538302299567, 0.03907550752046518, 0.020030849664181005, 0.06338828767184168, 0.024083617936412338, 0.021416866111394484, 0.012367650761007098, 0.1110759588482324, 0.037150985008338466, 0.03706891460751649, 0.018625800839799922, 0.015399917738250224, 0.035202468861825764, 0.032610247217235155, 0.02753469925664831, 0.082280027854722, 0.06039001847966574, 0.07860169906052761, 0.02163253608159721, 0.07189396055764519, 0.061936450147186406, 0.040049001181614585, 0.014791025459999219, 0.012087464037904283, 0.04814732033992186, 0.007733510437901714, 0.043611361979856156, 0.05066049954621121, 0.010986163269990357, 0.038278199717751704, 0.058385473894304596, 0.011858387169922935, 0.022077342291595414, 0.03346779885760043, 0.03309347070171498, 0.039078335103113204, 0.020429631586011965, 0.026375175148132257, 0.030263062326412182, 0.04669595407904126, 0.04370730683149304, 0.029822415854141582, 0.019938070072385017, 0.018445028508722316, 0.01864994290372124, 0.04108138797164429, 0.03042397107492434, 0.09831844028667547, 0.09287529916036874, 0.027305867297400255, 0.08412885872530751, 0.12131819792557508, 0.06611540578887798, 0.008558681711292593, 0.04009643926110584, 0.028039727039868012, 0.004528525751084089, 0.02362185736274114, 0.04607686561939772, 0.04716215640655719, 0.02616800833493471, 0.04555679450277239, 0.041714258113643155, 0.05771188582002651, 0.03678895423945505, 0.04036075886688195, 0.08400290142162703, 0.08593037026003003, 0.03165492875268683, 0.039730489952489734, 0.048920352492132224, 0.05425912910141051, 0.07475261692889035, 0.032350183828384615, 0.062052744688116945, 0.05896482405660208, 0.06963186475331895, 0.06258235982386395, 0.05210928684391547, 0.031106095702853054, 0.039229633039212786, 0.07617092051077634, 0.014647350308223395, 0.03745479800272733, 0.07221105057396926, 0.04416697825945448, 0.013731558628933271, 0.014269854109443258, 0.04763032542541623, 0.017928237684827764, 0.04800505063030869, 0.029626295909110922, 0.05245563974312972, 0.029516853246605024, 0.02779622096568346, 0.0740005393163301, 0.017006974521791562, 0.029529410385293886, 0.04092717339517549, 0.02769371738395421, 0.03229302732506767, 0.06890638571348973, 0.06550881138537079, 0.049294038690277375, 0.02495791242836276, 0.012571894440043252, 0.07123324132408015, 0.012953065197507385, 0.013595814252767013, 0.08169475535396487, 0.03257602307712659, 0.033862858908833005, 0.11165720148710534, 0.08308500575367361, 0.047399999893968925, 0.016228201857302338, 0.0874995524645783, 0.04475081841519568, 0.006867366582810064, 0.02683295781025663, 0.03522268125379924, 0.031659470696467906, 0.018499889920349233, 0.034911157345050015, 0.08495722911902703, 0.05259682591713499, 0.038686852203682065, 0.007144315686673508, 0.046385324458242394, 0.07282272126758471, 0.03957589316996746, 0.01686600171524333, 0.11673703163978644, 0.018197871067968663, 0.054322389769367874, 0.03665546413685661, 0.03424413356697187, 0.01703889614873333, 0.007256825274453149, 0.10649065879988484, 0.023968915302248206, 0.045288990513654426, 0.013296789038577117, 0.035232592636020854, 0.021302682980604004, 0.029489391927199904, 0.06503355485619977, 0.03381044101843145, 0.03470782743534073, 0.06382277060765773, 0.03383231953193899, 0.009275120464735664, 0.08205119404010475, 0.02846018338459544, 0.05577711795922369, 0.02137553590728203, 0.08774452056968585, 0.023571304118377157, 0.03816579031990841, 0.06342610009596683, 0.09840246624662541, 0.027217677888984326, 0.024273982526210602, 0.058674740794231184, 0.027372506592655554, 0.03362614348588977, 0.018339602720516268, 0.04246462878654711, 0.016724960260035004, 0.0066004786822304595, 0.03888722094416153, 0.030795022648817394, 0.03736215570825152, 0.038173530920175835, 0.03275240189395845, 0.04729113425128162, 0.04089122005098034, 0.018416012389934622, 0.02967163556604646, 0.03880540287354961, 0.027262145522399805, 0.05826286367664579, 0.01439790705262567, 0.022978131455602124, 0.012690180719800992, 0.025524364064040128, 0.03836870462691877, 0.03032576267287368, 0.07900908618466929, 0.04561458925309125, 0.03697646898217499, 0.04155003567575477, 0.05736588173022028, 0.05953955806035083, 0.052073478218517266, 0.01596839265403105, 0.05599017000349704, 0.027347110299160704, 0.02829389963153517, 0.040991769928950816, 0.05446191724331584, 0.0016861097742548736, 0.029904059520049486, 0.014461276259680744, 0.010662014501576778, 0.061228611957631074, 0.017008987597364467, 0.04096604709047824, 0.03305769547296222, 0.03426332179515157, 0.031124426750466228, 0.03072465962759452, 0.012807284201699076, 0.009875110681605292, 0.0718176232476253, 0.016020155599107966, 0.030060749159019906, 0.005438279595182394, 0.03789626083744224, 0.0028265385390113806, 0.05053938475612085, 0.026789111725520343, 0.021120597048138734, 0.10916328843450174, 0.038187186437426135, 0.012029434583382681, 0.07041466727969237, 0.05201507490710355, 0.02333276115678018, 0.032434298846055754, 0.051188845609431155, 0.0504299105523387, 0.04376261538709514, 0.06505676923552528, 0.017771008133422583, 0.06015305814798921, 0.029108768503647298, 0.004546623949863715, 0.052539324315148406, 0.059377550933277234, 0.03329655941342935, 0.0018673571958061075, 0.04622474967618473, 0.030990181512606796, 0.02785932392725954, 0.06012148718582466, 0.02213307572674239, 0.005731853270845022, 0.0882484982139431, 0.04009330368717201, 0.01690692559350282, 0.03313285647891462, 0.01677079901128309, 0.017924465719261207, 0.03992485100752674, 0.04191713531326968, 0.02369512960285647, 0.05279369914205745, 0.01978096111997729, 0.04867176270636264, 0.0505346164572984, 0.037781932987854816, 0.03702153218910098, 0.08895406543160789, 0.0274845727471984, 0.012766442887368612, 0.02016670536249876, 0.008846274140523747, 0.054404352558776736, 0.04638391808839515, 0.0283274669709499, 0.03530354566464666, 0.07401978320558555, 0.07784123517922126, 0.08781650889432058, 0.04458366449398454, 0.08744631821173243, 0.0767226553580258, 0.03649585785751697, 0.05075004337413702, 0.04007760726381093, 0.0518943349015899, 0.02198171099735191, 0.013485694380506175, 0.023809375816199463, 0.006015693215886131, 0.08870030287653208, 0.021636745914292987, 0.06502415926661342, 0.042633177945390344, 0.021934278483968228, 0.02660654154169606, 0.06824067182606086, 0.01085347932530567, 0.03741876673302613, 0.022043706303520594, 0.03212481955415569, 0.035476718403515406, 0.038522819013451226, 0.015932871610857546, 0.03986945710494183, 0.006193312810864882, 0.0168992721955874, 0.047195066945278086, 0.03715589802595787, 0.02503947074728785, 0.04969189663825091, 0.027743092468881514, 0.046559276452171616, 0.06641000873059966, 0.07749587675789371, 0.040376139877480455, 0.03308967832708731, 0.04340573512308765, 0.07954556247568689, 0.02785093765851343, 0.05145741029991768, 0.019221763977839146, 0.06841526948846877, 0.05252000621112529, 0.05221344355959445, 0.035387608731980436, 0.04151847955654375, 0.05380156166211236, 0.0313100972562097, 0.04049881317769177, 0.009334339210909093, 0.1193450424761977, 0.2831868699286133, 0.10865474658203311, 0.15724914410384372, 0.08494650508509949, 0.25599885382689536, 0.12913654558360577, 0.14738607569597661, 0.11213384583243169, 0.2835969510488212, 0.1052935300685931, 0.12456545024178922, 0.1575872814282775, 0.1402844348922372, 0.15334526920923963, 0.18597548390971497, 0.10604693612549454, 0.11915721974219196, 0.13700455776415765, 0.09769335898454301, 0.08797044516541064, 0.13849447859684005, 0.10205488666542806, 0.12451921444153413, 0.19432889035670087, 0.22494951757835224, 0.08932502794777974, 0.15380822092993185, 0.17182617128128186, 0.1395516679622233, 0.19696096162078902, 0.06660651459242217, 0.2759273297851905, 0.1789233146701008, 0.12203558013425209, 0.13882298284443095, 0.09616277588065714, 0.18431244970997795, 0.16925126023124903, 0.12212882356834598, 0.22538714722031727, 0.17147644161013886, 0.19914336560759693, 0.1374245242914185, 0.1506842690287158, 0.16849992476636544, 0.14770386333111674, 0.09572956201736815, 0.17236329324077815, 0.209555801411625, 0.0994611473288387, 0.14789018692681566, 0.13534076657379046, 0.09360644078697078, 0.09127770754275844, 0.10448002489283681, 0.07786973365000449, 0.10524580997298472, 0.08288510085549206, 0.08040853921556845, 0.19295352743938565, 0.13210926263127476, 0.11589642323087901, 0.18920072412583977, 0.19488263642415404, 0.15699375624535605, 0.06663742504315451, 0.14575799665180966, 0.0858361620339565, 0.16116879705805331, 0.25812442414462566, 0.11056807008571923, 0.3308944380842149, 0.1506519559188746, 0.13169455050956458, 0.24170666292775422, 0.20544598053675145, 0.11165810690727085, 0.09506095375400037, 0.13379499170696363, 0.21450683183502406, 0.19489638099912554, 0.10414598422357813, 0.12711495015537366, 0.13721388793783262, 0.07906820566859096, 0.13856878242222592, 0.12012198203592561, 0.22228755260584876, 0.07729125180048868, 0.12488967971876264, 0.19672777882078663, 0.16846396028995514, 0.08811880048597232, 0.15519110922468826, 0.1971418526954949, 0.07349846157012507, 0.2416986774187535, 0.16111764824017882, 0.2595916797872633, 0.14386137889232486, 0.10561666116700508, 0.10987640329403803, 0.12075619175448082, 0.0967676262371242, 0.09030841814819723, 0.17086897889385, 0.11743712922907434, 0.16260275995591655, 0.16280760755762458, 0.16510623187059537, 0.20284736528992653, 0.1538091411930509, 0.309129087254405, 0.07152578109526075, 0.1166109333280474, 0.23306758899707347, 0.12656699283979833, 0.17420665448298678, 0.15404474339447916, 0.19482639647321776, 0.1677816445589997, 0.1651432501967065, 0.146343135565985, 0.11461083049653098, 0.19343403837410733, 0.2005634206579998, 0.1905617190641351, 0.13175390748074278, 0.09138018329394981, 0.1320541655877605, 0.12352464007562958, 0.06643667409662157, 0.18553800269728526, 0.17027304915245622, 0.1287101223715581, 0.06884799353429116, 0.13263844361063093, 0.22137316729640588, 0.13517402083380148, 0.08533598418580368, 0.1760171088972129, 0.07986979195266031, 0.1267970586195588, 0.20063956500962377, 0.10227043603663333, 0.1547596839373, 0.11019317418686114, 0.09476005739998072, 0.12988047441467643, 0.09995673128287308, 0.14523145771818236, 0.12257608628715388, 0.10871540231164545, 0.17224308016011491, 0.14042891620192677, 0.11313710332615301, 0.16658175503835082, 0.13451244070893154, 0.15130436309846118, 0.09776354389032349, 0.10123204527189955, 0.12427675479557365, 0.12798250594642013, 0.2817223750753328, 0.1349572098115459, 0.12413685995852575, 0.11566394547116943, 0.12895480846054852, 0.17559746891492978, 0.18090358731569722, 0.20101408241316676, 0.21053715812740847, 0.11096070331404917, 0.16899103356990963, 0.1066460348374676], [0.052399525957298465, 0.035794261129922234, 0.01053830961609492, 0.021449782216222957, 0.058000692588393576, 0.0427686792681925, 0.026379531554994173, 0.007043462455840199, 0.02997389561642194, 0.03133704834908713, 0.026880700170295313, 0.012700193219643552, 0.04956830307492055, 0.07324432794121094, 0.06037873412424233, 0.033880599949043244, 0.04287993833713699, 0.01416005521605257, 0.06968192261410877, 0.024222002502938267, 0.02444198435114231, 0.01848090392741142, 0.046152264112606645, 0.031748153633088805, 0.048264939614455216, 0.07661712195840664, 0.025364963730680756, 0.022024070931365713, 0.05032547553128097, 0.036843398193013854, 0.01986908002436394, 0.059577563442871906, 0.061060218649799936, 0.05634425608150195, 0.005386773154896218, 0.06394714713678695, 0.015715177432866767, 0.013452703133225441, 0.05115928215673193, 0.07746009781840257, 0.07862230850150809, 0.04285123577574268, 0.011899647797690704, 0.020926224860886578, 0.021054614553577267, 0.03815259493421763, 0.0453612794080982, 0.03885401354636997, 0.03346105273521971, 0.0475315789663, 0.027735531839425676, 0.0332737086864654, 0.01852001325460151, 0.05930343264481053, 0.021355037788453046, 0.007776384773023892, 0.035046124321524985, 0.06122432976553682, 0.017656778618402313, 0.07114801308489405, 0.07221359614050016, 0.08180114964488894, 0.026744052229332738, 0.029463708051480353, 0.02179926883400185, 0.04799366979568731, 0.15084978280356154, 0.04692375259764958, 0.040479064628016204, 0.045227915470604785, 0.05278350203298032, 0.0678948755376041, 0.01954305640538223, 0.0419933093508007, 0.021934274773229845, 0.03157557461236138, 0.007079112911014818, 0.014120874457148602, 0.03420793160330504, 0.013498765456461115, 0.025210604435415007, 0.06026105176715646, 0.02657634911884088, 0.026006619045801926, 0.035982937333756126, 0.034643969338503666, 0.007649670478713233, 0.02682646216271678, 0.016248061729129404, 0.06596049730433151, 0.03210271468560677, 0.019973708003817592, 0.09378830407513306, 0.12182617574580945, 0.018185594090027735, 0.03995442559244111, 0.04298901178117376, 0.016347524360753596, 0.043421516893431544, 0.014330904105008813, 0.018479137615941, 0.028296385826251935, 0.04215781380480621, 0.02263843191030901, 0.011523515295266407, 0.05799638442113064, 0.009097679449041607, 0.03191599404090084, 0.102026128442958, 0.09274854033719748, 0.039143966932897456, 0.055913906908244826, 0.013090103693684796, 0.02582379096566001, 0.04678164244978689, 0.02604192301078001, 0.04228587509714998, 0.022604667901759967, 0.010860234724532347, 0.06038868632458616, 0.05107451775984373, 0.06371683644829318, 0.043985916490782984, 0.046924387133913115, 0.029421502113109455, 0.04036106314742938, 0.028341057550278492, 0.012168466673756484, 0.02063302272290457, 0.06159747048513964, 0.034882606923929416, 0.02401650923275156, 0.06059390871087089, 0.04271702950063627, 0.05927536461967975, 0.021885478563490324, 0.03026071713975398, 0.02747131798969349, 0.03325627192680258, 0.045784362955600955, 0.03751074480533134, 0.032674131289240904, 0.03592649329220876, 0.03897355498338584, 0.025104573796852492, 0.09515936253592372, 0.043311293120495975, 0.07054432047880255, 0.0500945451494772, 0.04269727352948394, 0.042073093936778605, 0.003981782310802373, 0.03645159988082014, 0.025052308046724647, 0.06313928970484994, 0.030208822463464458, 0.10104043016326614, 0.07050072672427632, 0.03418289896217175, 0.0511170613754075, 0.0689655274618417, 0.048754827585071325, 0.03940490976674482, 0.03178452257998288, 0.021226768694759812, 0.0374509759421926, 0.02850261196726933, 0.04619360915967263, 0.042858197120949626, 0.028798469138564542, 0.01549190787045518, 0.0676230936369393, 0.09030002445797436, 0.009893220012600068, 0.00926064951272565, 0.017335677293885965, 0.017853887475212105, 0.026522866246523336, 0.06624324814765714, 0.027876545464096125, 0.03858727082842961, 0.03156381157168653, 0.030310437323350925, 0.01625041990337195, 0.01651903468882665, 0.007474829762941226, 0.07455674189259298, 0.028135599532106426, 0.05343115575669799, 0.061850127240177244, 0.05980337300570682, 0.03719897227711044, 0.043377863767091185, 0.04108593362616375, 0.04078255849890411, 0.043409802092355676, 0.055618554397369735, 0.027115849661640823, 0.05333466913725715, 0.05561640216910746, 0.04752730419568252, 0.006251765289562172, 0.01971003963262774, 0.039739488493069075, 0.023621807267772965, 0.0296385394904064, 0.07025894243270159, 0.04887395341938827, 0.03824223153060302, 0.014609823610953754, 0.08696438235347159, 0.08665628716698848, 0.046537357120541856, 0.04377907622256316, 0.03465378424152732, 0.04508954574703239, 0.04782320960657671, 0.036117559211561456, 0.03916876950825099, 0.013492592643160606, 0.03996168379671872, 0.033928149350686, 0.05040746429585852, 0.07314548871363513, 0.019053530231758486, 0.01660621477640234, 0.014280110590334516, 0.06715860567055643, 0.0450792744231876, 0.041569676614017226, 0.01068919844328775, 0.02659561527252663, 0.03881080941937398, 0.10868084791582078, 0.021747207174485084, 0.046559803377022035, 0.060270343456068076, 0.060229959490243345, 0.04598487270413898, 0.036529295321088284, 0.012787077375833178, 0.011271793646301376, 0.08711720540304668, 0.02922898158431053, 0.06105517204559874, 0.0286330203016405, 0.025798437345656566, 0.06002275928040035, 0.01855879232607549, 0.03525409265421331, 0.03532025140884798, 0.038800623442512006, 0.04309992575144861, 0.04767177437315695, 0.022869078420626465, 0.028652555483859032, 0.05590021057287231, 0.04149150990997441, 0.032796325904200785, 0.05048009457823355, 0.04647229303373024, 0.021687067237508018, 0.020622536176233552, 0.036401067045517266, 0.05377180154027883, 0.060430335652199574, 0.018828763386409264, 0.02024102032009978, 0.04863329719228204, 0.07979746966157109, 0.0071460175240645185, 0.02991487446706742, 0.07584539969684556, 0.04621661573764868, 0.07099783950252458, 0.03369902609847486, 0.044038453124812804, 0.02172379427065607, 0.07501535947085358, 0.02331814270291943, 0.04781939496751875, 0.050520853328634985, 0.017463853619119618, 0.05941255061770789, 0.03788298381550703, 0.026613052032189444, 0.025345725407532882, 0.028407639329088852, 0.03002780522365356, 0.012481135345296934, 0.0043453971011331305, 0.01635970485949656, 0.03646463941549882, 0.028963222212041728, 0.025445566534472164, 0.042494470544625074, 0.014302335130196298, 0.04480214905925095, 0.01949109122506343, 0.028532535361591727, 0.040893743353080936, 0.03027508511877386, 0.05496504141774494, 0.027056887884100433, 0.030604927087551914, 0.014879841055517318, 0.05968839206616394, 0.018992052573594265, 0.034514876460889354, 0.01302315826251288, 0.09547154695610516, 0.009120668401010334, 0.028292394927120768, 0.016085761453723535, 0.034690420361584984, 0.006577548174391268, 0.051599665166577324, 0.011925969920412172, 0.021945471926301252, 0.051056416778010316, 0.02771357354504289, 0.04897356076980941, 0.07253116113133729, 0.028468441632867325, 0.018575768954178784, 0.06296386825852096, 0.03226029119105078, 0.04384509025840089, 0.06480734824435785, 0.06973497875151224, 0.06691428323392756, 0.0846275596995838, 0.01723528326692758, 0.0655852748604957, 0.04315707854402717, 0.08212937187636271, 0.08973649688414298, 0.04831622944038827, 0.01528365752164973, 0.009573307979735546, 0.013031441558268853, 0.008232280524680391, 0.01665202569711255, 0.086427238129545, 0.04963049133948516, 0.03270655943197198, 0.024967669814941473, 0.05231970797467511, 0.09237339210812934, 0.03673043960588984, 0.04124555845919531, 0.04999088567274157, 0.14854557754006237, 0.09286253422033042, 0.2301865568733774, 0.0752218917477876, 0.09772466277354397, 0.17467521684011444, 0.09611397224944085, 0.1010070854681544, 0.11920327000552788, 0.12419320381013677, 0.1415448242914863, 0.13631519163027406, 0.14123416127404198, 0.22923458920558915, 0.23770449799485505, 0.11602456244872883, 0.14399769657757133, 0.09022572063258849, 0.16704246547305956, 0.14684447116451338, 0.10005460571846925, 0.136934409965761, 0.14164277294185013, 0.1562009347253479, 0.17243030917597935, 0.1123245332564693, 0.13467413984471932, 0.08443723592790775, 0.1800508744781837, 0.14376104052644223, 0.11307013934128918, 0.10909011267358437, 0.20176439371425658, 0.1083798031322658, 0.17516510852146894, 0.1725655433256179, 0.22740265703760087, 0.1449220860376954, 0.12161274149548262, 0.1813945031608455, 0.14529884472722188, 0.2017270340002142, 0.08889493110473268, 0.09438106484594755, 0.13759846886387095, 0.05060162497102283, 0.13294616772327572, 0.14270681975176558, 0.15685246617067605, 0.11791612618253566, 0.18658625660464168, 0.1450887872488238, 0.166151428129524, 0.17219469213159755, 0.08670946204802021, 0.08078847429715097, 0.1342207469861023, 0.16371960315154865, 0.12829866085667163, 0.18978979642270133, 0.19407926156418398, 0.1981104741571471, 0.11365066951839253, 0.12578212714288384, 0.09474706239416264, 0.13897491531679407, 0.3494986257283017, 0.164634196262341, 0.10520426454604603, 0.12680887361057103, 0.14552732231095433, 0.18665221869014204, 0.175370653741993, 0.11906550513231196, 0.09092610023799352, 0.11387931037461385, 0.0770028903207276, 0.06234326952835545, 0.17251356330234557, 0.11583144078031182, 0.142170914914459, 0.14987262664362788, 0.10934391975752078, 0.1800562476273626, 0.14412755757803097, 0.1307084588916041, 0.1518639424466528, 0.12234763096785173, 0.12245510137290694, 0.17208310280693695, 0.08286358599434607, 0.11769384553190321, 0.15287957154214382, 0.3142246138304472, 0.07711154074058868, 0.1367470622062683, 0.1181340726907365, 0.16373872087569907, 0.27175723167601973, 0.15972539404174313, 0.11342323094140738, 0.11989409817033447, 0.12584688694914803, 0.11768256488721818, 0.12130873554269783, 0.19035295292269439, 0.15007915149908513, 0.10076348291477188, 0.399114700849168, 0.2026642329292372, 0.10695402612327598, 0.10506484468351118, 0.11139773923787288, 0.11798105668276548, 0.14903739880537614, 0.16788458044175059, 0.11650364845991135, 0.19200316281057894, 0.12426473200321198, 0.15001871099229902, 0.10166009378735907, 0.15026924520498142, 0.11375925314496271, 0.1407314304378815, 0.15493726503336802, 0.09036466552061029, 0.17040399368852377, 0.1032869186019525, 0.06753693771315739, 0.09905209037242457, 0.21092267415951937, 0.1152309839380905, 0.1388668586150743, 0.19213955471059307, 0.204473648336716, 0.1124445533787366, 0.10335723709431477, 0.07621415061294101, 0.14341001951834187, 0.20122508984059095, 0.10792322646011598, 0.10916616054601036, 0.12098337057977915, 0.11700816787197255, 0.12394606863381341, 0.2786845568334684, 0.1460904788109474, 0.12607946118805557, 0.12828384758904576, 0.1745400865911506, 0.14698948682053015, 0.07074225868564099, 0.12928025505971164, 0.17529900680528954, 0.200802362523973, 0.16367173462640494, 0.19276848033769056, 0.16363605216611177, 0.1349849661346525, 0.133441150537692, 0.23118173237890005, 0.19529809069354087, 0.1891461168997921, 0.07671654006117024, 0.11040018885978498, 0.15589450194966048, 0.08950963718234561, 0.17675872222753242, 0.10080113948788494, 0.19730907340999693, 0.23126642627175897, 0.1583579572616145, 0.22005723556503654, 0.273469960084185, 0.09808563598198816, 0.15104296384379268], [0.013813873938488541, 0.024387345583818387, 0.043164333037566394, 0.025172064706566744, 0.03477312529867049, 0.06612753248191439, 0.025140471479971893, 0.05043300159741193, 0.12192406502435915, 0.07784522051224485, 0.025483985664322972, 0.08824479489703663, 0.03512155621137936, 0.03602590768423397, 0.012161530376033625, 0.052402475994313136, 0.008815274632070214, 0.06022244895575568, 0.012034360588586424, 0.09798363520530984, 0.05197749625949655, 0.05620642812573351, 0.0689570743998047, 0.02842543417500565, 0.05141056222782936, 0.005686325757778832, 0.05087761855975259, 0.046554292930522934, 0.09713277773698792, 0.10243071024888195, 0.03807800909271464, 0.03715691105753649, 0.032903922474361025, 0.05714961989724543, 0.03006408325745724, 0.05564892308029812, 0.02587063718237914, 0.03690890756843146, 0.07899712276412174, 0.03389922414498869, 0.020866283448413014, 0.05016524584789295, 0.03412720820051618, 0.018959142034873366, 0.051422432879917324, 0.050667375544435345, 0.03435429054661654, 0.03599870797188487, 0.0584001684183022, 0.030577410107071046, 0.03099666973866988, 0.04528167293756269, 0.03711493147420697, 0.034768720652209595, 0.058104671188630164, 0.038347571971826255, 0.011646750772342784, 0.03542067883245181, 0.06307205112534575, 0.038612477874266915, 0.01887097860162612, 0.0386719053494744, 0.019862515728164, 0.02722506225836696, 0.05221191102464218, 0.012131607909395825, 0.09112649495364167, 0.023332505115831736, 0.08179271142580546, 0.038879506319062784, 0.03729132884473074, 0.04866070099524222, 0.04500650684349239, 0.035033912281505764, 0.10028988137491979, 0.03615642177464906, 0.032920231169555336, 0.0762542340089567, 0.0282648779466399, 0.0521750559710199, 0.04410182882566005, 0.028766870345862117, 0.03172443830408156, 0.06419561817892827, 0.005769788149336819, 0.05975498126645107, 0.03226992797863204, 0.02401850561000174, 0.04907500864646863, 0.008753963957133237, 0.0998753696330823, 0.10039919230621308, 0.04541807225905359, 0.06151117355329916, 0.02634117736306507, 0.029391617681540083, 0.03361739727552049, 0.017538545216666535, 0.02844488586561056, 0.055821019705035724, 0.0215606312485761, 0.014001496292621596, 0.044204887162777595, 0.0034552405941212783, 0.031839155781199224, 0.0499953719554469, 0.03247751039452851, 0.04064332417328842, 0.011082765850005671, 0.023034555088088382, 0.013650986438733526, 0.06414520408725366, 0.04632918840798084, 0.04457425406144466, 0.016537562405574135, 0.029201865363575052, 0.03028830462426413, 0.0136505717637192, 0.02693420901778154, 0.017918860648933332, 0.03193113014276605, 0.05017033327021636, 0.02970704899780685, 0.03335604997118935, 0.023034913174342364, 0.025323618683614768, 0.11792880206485279, 0.050038769040838815, 0.10620800443575718, 0.02057861402136041, 0.026512593067309354, 0.03595794922148343, 0.022935062770557124, 0.04915930920105893, 0.022670039979857393, 0.028031912224832922, 0.023093672716640867, 0.01581716707732994, 0.027656405909510795, 0.03927624362404458, 0.07777338061714545, 0.035471048395265825, 0.008346512822754448, 0.04672628565458581, 0.04398322991619352, 0.028868694862467237, 0.026192848017672077, 0.013993787233630428, 0.05073352687759325, 0.044442021899158135, 0.023562869610032067, 0.0474015324289212, 0.013328176319191698, 0.045411333558149636, 0.019822790418402292, 0.030180854628270026, 0.013132549902366009, 0.004379849451652262, 0.04816293883777689, 0.014539552430505864, 0.034588263733894564, 0.024534233307349496, 0.012929700533277355, 0.03915800836693961, 0.022595589580305386, 0.015243816251313547, 0.0954192403878551, 0.05315119167789817, 0.008516665948263835, 0.015343270533776376, 0.02968087344925152, 0.08166762985638343, 0.0026251447070535505, 0.026716496286098845, 0.07485892216209322, 0.025568965284037404, 0.0229232941637747, 0.0329333412082633, 0.07481175125576556, 0.05824626554385759, 0.0305162033328088, 0.028374936591717415, 0.037387429547379725, 0.05453002413560171, 0.21154460875550285, 0.0809969287365675, 0.01999656615225831, 0.008909088592190528, 0.00677970502692915, 0.02666540127393091, 0.020366018397908192, 0.03167662172927521, 0.03118719017948024, 0.07108824793249369, 0.04457688126421999, 0.07019120661425404, 0.02593006836832501, 0.04950464906869456, 0.042667287052609026, 0.012562350420921575, 0.03968311124481261, 0.06979656216572039, 0.021208984981058165, 0.09555199576425366, 0.05174664009246044, 0.06085308523324784, 0.014988099992478965, 0.0327016649680445, 0.021511161539820023, 0.1013590935326647, 0.02712883539061295, 0.031664231573813595, 0.02225771200755844, 0.0425367803836707, 0.0936117026139982, 0.010846524473890895, 0.04507118872425053, 0.043426797274150886, 0.021791518956888467, 0.018646900098246988, 0.054725431618862785, 0.05007589868910145, 0.029019222820352297, 0.020626911136787385, 0.11616937030339614, 0.023452710775018204, 0.04401525729917921, 0.027223299657634925, 0.006605438547921949, 0.013328199511306593, 0.019119653734378517, 0.02174637782445643, 0.01624482039915165, 0.0452274479175685, 0.06971378301386721, 0.012002569765172666, 0.03588373074308038, 0.02084320080030011, 0.05326443970261607, 0.02298686096764868, 0.02400515066256048, 0.021405023289844394, 0.22043770499294624, 0.007584951954413555, 0.03898716968251392, 0.04857070816797204, 0.06251775586861186, 0.02713553698413307, 0.05612417218799237, 0.027348696639819536, 0.13188716751756147, 0.024156522813427728, 0.02371141603362048, 0.016382063913624734, 0.020241912752680946, 0.018525147061154712, 0.021671843933290802, 0.04669486312195659, 0.023582093090226408, 0.07695274340221658, 0.028403498145053163, 0.08444478356977925, 0.04686445499828551, 0.04661329738155473, 0.05015607661334798, 0.04591366734530311, 0.03690355297294445, 0.07072416512528434, 0.01646614182391204, 0.0033935975761778536, 0.020148047769907862, 0.0020051589444847195, 0.02083396106172586, 0.018677201987884473, 0.0661470509658102, 0.08253794643678702, 0.010906473307841225, 0.03277754956798162, 0.08866885807947256, 0.01833394569985103, 0.031161166771198623, 0.026266049753758125, 0.04483391669054981, 0.037537302559940144, 0.06794811721192673, 0.02824919080012478, 0.020155901547695976, 0.05034720932599157, 0.06977610115427524, 0.06981636266573332, 0.03959865112847183, 0.06305616916506551, 0.01735671903588809, 0.036537685300572775, 0.04762719356222078, 0.03602108372433577, 0.03007316900038859, 0.04149435604631435, 0.030147457982820924, 0.03456401034782175, 0.03339677532494534, 0.03244722705858294, 0.040568931290181354, 0.0741162475605961, 0.04478576986002736, 0.020417666310095228, 0.012225748414493864, 0.0359925258817384, 0.04656431934563443, 0.06216920250153635, 0.07780167870805599, 0.04924200300592929, 0.05662105118972249, 0.07604583151987754, 0.032408089900854975, 0.010510484644328244, 0.031027691511553712, 0.02895378023822559, 0.03226601314963773, 0.020842228586843703, 0.052820709606749006, 0.04501144212554209, 0.01802411203243537, 0.074262339330744, 0.044571389371412806, 0.01064214628058835, 0.04277135471056681, 0.04085025349922944, 0.02823221788275987, 0.03528041663230397, 0.03881476506649051, 0.037564305603154935, 0.04744427642435767, 0.033113883473561145, 0.0033950324723264202, 0.08792377149802633, 0.10917655803496018, 0.05970581027213484, 0.036943558443454094, 0.02152462966478197, 0.0451077135221567, 0.03690228761115577, 0.06413712209905498, 0.018946078380395193, 0.04935712866426911, 0.06022687957738526, 0.003984424356531235, 0.07985154996276833, 0.03140708853607066, 0.015193057060969295, 0.04051913318107836, 0.08267890254501253, 0.12857546709710732, 0.1284216792555526, 0.07193606259534135, 0.10239310562610626, 0.16309057362377644, 0.26147973316255957, 0.10215037138550542, 0.09352469322038814, 0.24423239927273244, 0.18234574352391064, 0.15803389105712995, 0.1681367473793216, 0.14246352890040725, 0.10456875606905669, 0.09281179358367808, 0.11386074926122092, 0.08492958411807194, 0.19425982609391212, 0.11877456840011291, 0.22574086964596063, 0.11530232659424655, 0.14509718836052343, 0.15058612741995603, 0.17780798545572907, 0.1465922745410353, 0.13735721149714664, 0.14081496658036485, 0.13040967023698613, 0.16931116639170796, 0.17318808648269624, 0.12700046645477414, 0.14721177489263937, 0.12644550326513126, 0.15513604186708108, 0.18475628370651975, 0.12181221594801173, 0.07387572492007166, 0.15958870528265834, 0.23003843904007226, 0.05434500671981368, 0.15390232525533065, 0.07496001009712927, 0.07411884507746436, 0.05750941680162214, 0.0897739604988601, 0.1289703935617581, 0.17517325730295852, 0.10674464399926364, 0.21060113125713542, 0.11464196359156631, 0.0659745758457575, 0.23379786231089383, 0.124379327025963, 0.15748810081277043, 0.13217277562944219, 0.16921400441788137, 0.0828922403161414, 0.09314691778854467, 0.13258625578600913, 0.15587563655572012, 0.09213691417244263, 0.07733105318038724, 0.1577654413995333, 0.11759904358768836, 0.17785805073799565, 0.10823911419720389, 0.3245103353401646, 0.2024049562169239, 0.1938792972941883, 0.15656613075407222, 0.1590120416949503, 0.08124169646180235, 0.1257511498988606, 0.15398223971715197, 0.23694833857007325, 0.12963437824510038, 0.1030299648118671, 0.12440784776117653, 0.12549202161608264, 0.10378432081779465, 0.08077042526565492, 0.0740637925628107, 0.11449980520410463, 0.21193543856497854, 0.13007156259845942, 0.23112725873943418, 0.1230228591884952, 0.1224192556401249, 0.1758110590162687, 0.16230793436989188, 0.27302087168209255, 0.3088334749918431, 0.1655568936257623, 0.2472208350081928, 0.10805182580952533, 0.10711780327255838, 0.1444974439800717, 0.09471872719586827, 0.1616423763334751, 0.1468051818665117, 0.11444732052041218, 0.11715800006641075, 0.18369986617472023, 0.10568090889137238, 0.09437254499061964, 0.15536876453552395, 0.15602902363752946, 0.11223253663047217, 0.15049798996187747, 0.15948826301610097, 0.16691169905243441, 0.10716237666201778, 0.17316886485787109, 0.24654626729898155, 0.07964856515172869, 0.13547818263759837, 0.09436618478503078, 0.1280449057230726, 0.10759979850263335, 0.18893782573286444, 0.1097669216687791, 0.12300607922952622, 0.1115398679394275, 0.12599374313140288, 0.07711701036896557, 0.11231298543862067, 0.21636346267769113, 0.1569064796785824, 0.2324562077410519, 0.09611605768441223, 0.06931573210749775, 0.14605914533603936, 0.07921268697828054, 0.1383164373692125, 0.23756380163831636, 0.13685706333490089, 0.11008663888787851, 0.19579627958592027, 0.18719542626058683, 0.08301693596877158, 0.1559718485805206, 0.14924880699254572, 0.10781911056255922, 0.1564974375651218, 0.16636512213153765, 0.09756789891980588, 0.1501392209320329, 0.13047673070104793, 0.1329595857532695, 0.132286264852155, 0.11962487667915411, 0.1441188744502142, 0.10104693879839033, 0.20485892688157037, 0.1809644137392752, 0.14099564985372126, 0.12657502287765965, 0.07688170502660796, 0.09862353719654493, 0.18535838811658323, 0.17654516181210056, 0.19281621527625248, 0.09057357267010957, 0.14571986510418355, 0.11868561457959004, 0.14420560182770714, 0.1301576368859969, 0.13311698043253273, 0.25652758951764554, 0.14732655545230955, 0.11141618902911432, 0.15590216091368347, 0.09386917590745725, 0.08155557297868654, 0.16199966106796637, 0.13857660465873778], [0.008718216558918357, 0.05614217669062782, 0.07504828114178963, 0.07121841321350075, 0.014089861033426132, 0.09328973668743856, 0.07561298130895011, 0.05102579205413349, 0.07485774214728735, 0.022997408741503023, 0.020875408154097386, 0.05289138432999607, 0.013715590393985622, 0.015016522393125342, 0.05395316387875937, 0.055242400558199733, 0.03102593262156006, 0.08413570132688619, 0.04123019600228872, 0.02804765503242379, 0.010365313137299381, 0.0499525017949054, 0.0606277691986179, 0.026147554744966328, 0.07559810124803334, 0.055921962921274826, 0.024147028889274225, 0.05146633833646774, 0.04744305930216797, 0.030105320693110116, 0.029523014927690383, 0.06139746168628335, 0.03891456166456919, 0.05251709699223284, 0.01624033597181551, 0.005753280001954408, 0.009859909641818376, 0.03165878792060539, 0.010898478521994548, 0.030403621385630686, 0.011919189473701408, 0.030146508033794817, 0.04068673981237225, 0.037486569344764575, 0.006504062102976604, 0.10404162341728806, 0.023491352549172007, 0.033178238809341565, 0.02839666667568963, 0.028043541678925976, 0.028544996021082625, 0.06582647285540588, 0.030458599685516674, 0.04632208605471533, 0.03003790399816353, 0.02311473301233491, 0.03914354390872177, 0.0448182499530958, 0.010516406055103289, 0.046259010923677124, 0.04857650805206504, 0.03960074398491997, 0.02561268520366866, 0.03318612041766755, 0.10164195569814183, 0.036634472489822656, 0.04780657807714306, 0.011940314707317157, 0.033687956965877675, 0.03985696304880548, 0.08041247259825468, 0.023229578509926796, 0.027606587391346693, 0.02008009672863409, 0.02301538726896979, 0.03431969533266965, 0.01753163025568938, 0.011932323632208863, 0.013371958393690875, 0.06780180279747583, 0.008718106164451456, 0.08787703103735112, 0.0730017718160525, 0.008309636432386469, 0.11290544192888774, 0.055835699386079796, 0.09007195505546406, 0.026051266650028992, 0.039087285404093564, 0.07021473269560374, 0.07253499803482555, 0.06894312202348374, 0.022585589140362572, 0.034532354038674384, 0.13541008316678926, 0.00810956826171605, 0.03237450400774833, 0.0755363619828131, 0.06960062775760889, 0.030918753509467933, 0.024303410536958836, 0.05448160271043889, 0.03161187305522617, 0.05574026290560141, 0.05082796145870816, 0.06678021425614133, 0.04551003919914365, 0.05280875360767823, 0.02873140310839517, 0.06210218656633515, 0.08090108778560534, 0.012092915112589253, 0.07308204993023537, 0.03840197139652446, 0.02534870513045462, 0.035596823872765526, 0.08540700771845877, 0.025649929884821177, 0.010650360927684233, 0.03708114520122763, 0.09384290387970395, 0.052268024810473435, 0.010672909229469951, 0.020616893998521846, 0.04679815894633066, 0.011957241240452277, 0.05805893262731843, 0.01829833745432552, 0.0307164088007994, 0.04924035172734875, 0.10121556217200123, 0.04678081124438904, 0.0075050235773233, 0.019710709420905914, 0.022462721026386134, 0.06530479498906061, 0.010775589998957003, 0.04080034406797495, 0.026324716527597047, 0.0956347600731533, 0.02346539778955048, 0.04566115530906245, 0.007623898936799378, 0.020781142411578912, 0.025002411603054497, 0.04686767962994054, 0.009717761458887253, 0.02817392032739008, 0.07427323405863717, 0.07165741582866758, 0.0587354670278728, 0.014284163644333603, 0.07334655136219226, 0.06107395209255628, 0.06518992537166923, 0.03966237934946548, 0.058523561601759866, 0.01603124514076626, 0.06645684567047283, 0.05300134464050643, 0.019670969268190674, 0.06345491026877426, 0.02619705042889109, 0.07270970701938495, 0.014506735587929143, 0.04857797008298803, 0.05117793603858445, 0.030182674745447002, 0.06749894717358984, 0.07382059076917358, 0.04565688795992173, 0.023648968017369043, 0.11037669246434234, 0.03878382492985111, 0.0769125709484797, 0.022827891079941764, 0.021400614932645112, 0.0590452914184425, 0.039795732154743746, 0.031057947016961407, 0.011364886795490747, 0.04009927055449225, 0.08739135475479998, 0.061668594207731076, 0.027210662738070823, 0.03550598499714397, 0.02879325740650529, 0.06410624133422971, 0.033068601333070546, 0.06037945771822706, 0.06419070516130887, 0.035834919690387323, 0.010544123415456852, 0.026770951371872798, 0.022980311514402274, 0.036256140447221696, 0.023614875608473085, 0.03656684799352661, 0.03429051037528552, 0.012226445105625317, 0.04782913936651312, 0.021265545910864603, 0.04488826045417227, 0.013782894839096116, 0.02642235347593669, 0.03710434102686122, 0.04002392030088231, 0.033607148216106, 0.04137032090511639, 0.10563411648035981, 0.02049421327683376, 0.022547793414560147, 0.0483324231026927, 0.01670102970820153, 0.026791479176608846, 0.0148612984958163, 0.03420150460442528, 0.030839156315778382, 0.05569508095504716, 0.045790619260515086, 0.038555707287741825, 0.06886459537781775, 0.07979223752045073, 0.01203094207085087, 0.0114273533654341, 0.06788122744183056, 0.05530253307370003, 0.05402516333560925, 0.028746290590788703, 0.008440227520623012, 0.01754843062371947, 0.025433437986066565, 0.04178708135441411, 0.06039789266651496, 0.04623498389264569, 0.025441354846407194, 0.010501027827558573, 0.059272592698107474, 0.022786818772146944, 0.026706354838097468, 0.05292980531521607, 0.07939648727187887, 0.06107795597927179, 0.021480740906554274, 0.02038774106040364, 0.009734938466863241, 0.032587500390945934, 0.05094958461995702, 0.06148338012280874, 0.019419203090365045, 0.011819764877145644, 0.03288949141278863, 0.04089643363840878, 0.05336381327651907, 0.051823407848132774, 0.032568946699029766, 0.03518005229125265, 0.04187445440038573, 0.005021263568778522, 0.04044419853016734, 0.0389334381907247, 0.10236073314445093, 0.03401003050385043, 0.0401680008508265, 0.04263690723746549, 0.021586654656857718, 0.02543913768022321, 0.07830440954421647, 0.030501551482302602, 0.020662680799432565, 0.0368304625590099, 0.038363661733455956, 0.011337226951582124, 0.026787384376802947, 0.0684712125803344, 0.061812407584511675, 0.03528535191435367, 0.07866576124797575, 0.009693416232039453, 0.039554704853799194, 0.03391596328583546, 0.07320323522435501, 0.02240984857053263, 0.03548825508914888, 0.0855250091990456, 0.030231424570956733, 0.02108187178237131, 0.03263171012804378, 0.03202158310159575, 0.0602756052830955, 0.02262217331008287, 0.0718921422958374, 0.044722661332343705, 0.059981636877637357, 0.038776789369876496, 0.030138862057356164, 0.015558519335172605, 0.040793627631501295, 0.048882024275371805, 0.026570122499833815, 0.024858984143065754, 0.009960869556380203, 0.03515132746542804, 0.036139912699582055, 0.02044171003944939, 0.046530644394806586, 0.02149671192455571, 0.021321561362128705, 0.03644896896730643, 0.058381893031764776, 0.02677812793990597, 0.04515431297477335, 0.027316416926623788, 0.041443659938522615, 0.05010186643630732, 0.021881671345909126, 0.03478032784187235, 0.02446430629788665, 0.040599103303975426, 0.11417089277529158, 0.060598869968089275, 0.02610745093988953, 0.046137369208736345, 0.026762913912534714, 0.12426904388121329, 0.027390934119466692, 0.02678799664863618, 0.01957314492756268, 0.015631529968231916, 0.0423112120188307, 0.024769429182924796, 0.11173108970979229, 0.002980931230922579, 0.037421913439175114, 0.026874070936173666, 0.04446707680472173, 0.03461101798166055, 0.0848322811361868, 0.016628161938569974, 0.04964364961779211, 0.033187534208991565, 0.0212271917189355, 0.05949904792942107, 0.011435981759859715, 0.0041831696489680326, 0.061276996275410056, 0.016254457186732907, 0.011458722092356766, 0.05288709100568667, 0.022667817247565836, 0.04460093055968173, 0.028060050753992982, 0.08084602042799816, 0.12838746624765918, 0.2280145132681355, 0.14158233243506402, 0.10911659250268713, 0.13244922563899308, 0.19614140794146806, 0.1340203671134077, 0.11754001316148788, 0.10236748668830842, 0.1430658411118202, 0.18085484305629507, 0.1408576252288185, 0.10312617683666758, 0.11937619783566333, 0.10407818161183968, 0.12937887164298445, 0.2877233811886981, 0.1201596534519922, 0.1628220349084586, 0.08598074724432081, 0.13102758239256218, 0.11453470098786056, 0.10618213316774927, 0.24298183590872213, 0.1214835632708855, 0.21398556214990094, 0.12709745031315833, 0.13243614899693057, 0.14085155446082354, 0.13926766288932413, 0.11281334882369265, 0.08766169688897207, 0.17883085791254416, 0.08575232161092572, 0.09788875162485056, 0.10381627027527429, 0.07915310736279935, 0.08463257661787793, 0.10941832748358138, 0.1970984518993646, 0.10720264559495263, 0.08774475063546561, 0.16073409147793427, 0.1040254371764604, 0.16103423084132373, 0.1082773570669815, 0.15781847527250648, 0.1662217837292701, 0.11788662581238896, 0.1913324394263327, 0.17628967005293816, 0.1672790027805604, 0.08370204217499122, 0.10798703631735407, 0.1275644393172115, 0.13316808472154662, 0.22371924453182146, 0.1566523386281915, 0.13439007540000603, 0.1624871778767556, 0.19086901273112744, 0.05345706784282811, 0.16337785898940638, 0.19210258091334254, 0.19318436505272985, 0.24455413513351232, 0.12130288741900586, 0.11246378242503852, 0.17365528328809887, 0.1812734143459238, 0.14811943634413183, 0.14587861049221829, 0.23075789184076712, 0.10614319267915562, 0.1346561056561768, 0.159657962503843, 0.09926594764692709, 0.22383611794793978, 0.11841247454867698, 0.11119349277578294, 0.23504386888816953, 0.18154799414332956, 0.11542722262674943, 0.14517095783958212, 0.16318662237608805, 0.17296805453952402, 0.14696122583700344, 0.11629387299763039, 0.14769345842069015, 0.09568289577146061, 0.24770624411758035, 0.1081100176088512, 0.13010740833124146, 0.22452552861068398, 0.12512725603301078, 0.11907477455679327, 0.14950130047509447, 0.19184173084795475, 0.11467720818473026, 0.10530793515499681, 0.24592267029220238, 0.15607972716679797, 0.1683021869393997, 0.1421248572296463, 0.20569013227941468, 0.09496543192653917, 0.15590803872328252, 0.14076169522013515, 0.1312948000850156, 0.14897436078172177, 0.0802915396343451, 0.19281927292468026, 0.17928245477378368, 0.0732285795675125, 0.08745105311390944, 0.1875833616941236, 0.09310210691182874, 0.10490892687812448, 0.11469772856798954, 0.14665949827758595, 0.12665334914345294, 0.09310769528383389, 0.12348829710390419, 0.15090044180396944, 0.08334979662322439, 0.14869244856527075, 0.04917375881632324, 0.1927722356049344, 0.09906253239023499, 0.24343279452295974, 0.11048261920223013, 0.15054477495141327, 0.08308463467983529, 0.09021708203363232, 0.1826827973127365, 0.10430986527353525, 0.1158582694188226, 0.16832063673064113, 0.2709610259626061, 0.08727972832275555, 0.15720408089691773, 0.08246561672422104, 0.25956056895665824, 0.12263525772141293, 0.11763920119847171, 0.1249432924669236, 0.1559330045711249, 0.2285246062092483, 0.1893542002653703, 0.1834965473972261, 0.11252960350248031, 0.29897727887146175, 0.13559824728872627, 0.09977448949939571, 0.21921878680586815, 0.09731494530569762, 0.12490052991779521, 0.11059528464102186, 0.15543545392574742, 0.09797653285204433, 0.19324287597555667, 0.09490346259553917, 0.15507650678046048, 0.10357458246289752, 0.2130876822047867, 0.24552263785153627, 0.12306166609050706, 0.16544246929697692, 0.11531837924849242, 0.11457703309133649, 0.12212563975481316, 0.11106167250545695, 0.10041037647170015, 0.19321632193168625, 0.16652483231155202]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.061811891791876405, 0.02498641646525357, 0.014385006670636358, 0.024628551000205334, 0.008245381286542397, 0.02454680528899189, 0.020985589253541548, 0.1430347005953081, 0.017392301306244917, 0.001605420927717205, 0.07873866983572952, 0.05744164387579076, 0.06733456888468936, 0.07311578054213896, 0.03666640339361038, 0.05415738807641901, 0.08273753963294439, 0.040555023442720994, 0.09437404412892647, 0.0007109291186679911, 0.01130864220613148, 0.05015910828660708, 0.003141694564874342, 0.049160771231981926, 0.06330076619633473, 0.02495043900125893, 0.015785889263497666, 0.03733927158464212, 0.026574375006021, 0.026756008228403516, 0.033756846823962405, 0.026605491402733605, 0.023214409011416137, 0.03324960372992791, 0.00469839036668418, 0.04161517397733405, 0.03895080073561985, 0.03783293337619398, 0.0793408855679445, 0.026372419924882706, 0.018909677892224863, 0.03711812270921655, 0.018795956748363096, 0.03232438306440599, 0.06052161981642712, 0.023136531744967215, 0.06456039860495366, 0.02053746564342873, 0.018428536131978035, 0.06902764522237703, 0.020611407671822235, 0.06464218327892013, 0.07184406596934423, 0.04759091738378629, 0.018236626019643154, 0.04485001387365628, 0.05263308725261595, 0.048899282919592224, 0.029448083987517748, 0.0719406787538901, 0.061232367224874906, 0.04480735893594101, 0.036471585917752236, 0.022298880794551224, 0.04445913582458161, 0.03893980952852871, 0.07324581223656423, 0.04220215341774747, 0.05065737510449253, 0.038364637657650746, 0.012983296583115589, 0.05423159171186853, 0.05052488690125756, 0.027485604332468938, 0.05947704325080849, 0.04660105194489006, 0.025843366966000758, 0.0392589552939171, 0.02339256156119518, 0.049172923900187016, 0.01680016765021719, 0.027854683648911305, 0.05333876579243224, 0.049158017864101566, 0.03914526940206997, 0.040434999609715305, 0.04736498165584635, 0.06411814538296312, 0.03788887646805961, 0.010296696946170414, 0.025594890357751865, 0.04070511909958441, 0.0255883093632292, 0.10635638202074915, 0.014423208722291747, 0.05878703886992298, 0.013237786442914512, 0.05210910130699631, 0.07384629876469262, 0.040067888839985244, 0.029256502275529783, 0.03411019817576744, 0.025982070656027645, 0.05452560093544889, 0.06523893680423498, 0.00703684713698749, 0.04134455353778321, 0.04997091076802462, 0.023124492254282814, 0.05236783625150565, 0.026853170202230103, 0.0733201160619501, 0.052626400502049364, 0.01859033916844055, 0.02085753352730535, 0.042056165548274294, 0.03755013800400775, 0.036317512349341996, 0.018932905259134714, 0.030455699743470177, 0.0359783619933296, 0.02646253335115034, 0.03637111767602619, 0.04229918180499226, 0.03969062177930027, 0.020431136290426366, 0.06168164487462491, 0.030217012063076254, 0.07644336292287335, 0.03817772405454889, 0.037153634475544095, 0.09774438163731247, 0.04680474921769928, 0.014498892942356179, 0.023877133899077307, 0.0367548377107596, 0.01792911898519378, 0.04793982327100821, 0.025933331962733064, 0.015618379111401737, 0.06674687698250636, 0.010959005303448066, 0.029073959922243375, 0.012019480527669657, 0.10148775225388817, 0.048203371043200605, 0.020805867061426397, 0.019304205452499446, 0.010293456543877255, 0.03663446877908427, 0.07030730819678865, 0.04000578592240345, 0.03324089091620408, 0.006794856899432489, 0.013368176223593764, 0.07041302713332698, 0.10558553549344651, 0.029882310882385354, 0.05670039419783279, 0.020284944330342114, 0.013988153405080084, 0.03402449125132989, 0.03235447715269402, 0.021658017722074874, 0.03974682833359111, 0.011621203266258817, 0.03680357454868499, 0.056802632461767644, 0.025703384926600847, 0.06488306215032935, 0.07214214216219261, 0.017368899534631055, 0.03203340922482312, 0.026529408278292976, 0.013208152486186009, 0.028317778233031277, 0.12010247097350657, 0.045651095497305505, 0.02705030688957777, 0.028148670608061366, 0.023936841535032727, 0.053974790062056854, 0.020331386076577473, 0.04710628381872084, 0.034839376821764745, 0.07157697444199584, 0.0481701747776242, 0.04298926411138382, 0.03808524503256194, 0.03888864957843907, 0.10290706515661441, 0.03644345481006894, 0.08042374582146294, 0.02640244536451064, 0.0665127145475708, 0.05046652069722768, 0.008627192146377638, 0.07151427780627273, 0.03510983027808834, 0.03455820675299037, 0.06741419390891679, 0.07767578077618964, 0.027438438992248848, 0.01992006928048795, 0.020180629908281844, 0.03894046261848416, 0.03737162180186715, 0.01657365861319704, 0.02886722912080586, 0.05350281382561661, 0.02607062371680513, 0.06405731895938516, 0.07120958907762542, 0.038354388598236255, 0.07225439199828543, 0.04951339527906384, 0.037926354925730266, 0.026133817591471598, 0.034191604354418814, 0.03613114793552086, 0.021637189347529784, 0.029003498566453345, 0.08203612102079205, 0.039564037360833026, 0.023017127605271526, 0.07492309567169286, 0.03778989252168685, 0.09629136780858971, 0.039686859090579674, 0.09468665899476036, 0.044411597555154, 0.06453669440816157, 0.04194351495243609, 0.12854744360083714, 0.06224182165169623, 0.018117769213858992, 0.022970257268752903, 0.04773856395331677, 0.023169746564235538, 0.024862804348231293, 0.09746341936988756, 0.006827438110121875, 0.05450007476611063, 0.07454601043718867, 0.004234148700561491, 0.04271213503670879, 0.015789299432071857, 0.024131976279022638, 0.06482127093477175, 0.0410810985340504, 0.03993951584561728, 0.037972843056195416, 0.06806581441196613, 0.04006609284260776, 0.05184662964893505, 0.05522446284885518, 0.0754285576113034, 0.12467885040678084, 0.01435526974091772, 0.0313356827973621, 0.02337259222258581, 0.026994940817530733, 0.0163340005747159, 0.026080180723511148, 0.009487717015872477, 0.04823430375836324, 0.02385887892160099, 0.013793899033771595, 0.03182947446475737, 0.029767417145194486, 0.03703927322931122, 0.04357048819656484, 0.010574335319688544, 0.012724477219308028, 0.0030565839097107528, 0.01997477484110277, 0.06176918490382377, 0.02806768930895487, 0.011150222435389878, 0.020250460438546725, 0.010244371824228438, 0.05083024727355223, 0.05583299425779842, 0.007071422869557864, 0.05915025707508903, 0.02632810628711013, 0.019230400721426122, 0.06990174675593153, 0.05757807659392711, 0.022021389922883827, 0.03605773097660858, 0.039403674090863205, 0.0420069203391904, 0.0622892782848794, 0.034035975986626, 0.01597463411599165, 0.03190624964190647, 0.052455539553193375, 0.053651287889806554, 0.07259469639393501, 0.015522521462116856, 0.012007018012809567, 0.04412862406752538, 0.031187976856017485, 0.030766527888772544, 0.06120267018559389, 0.11636353097856045, 0.10241439784294926, 0.07038549345452338, 0.03477594174910337, 0.06386136228684336, 0.027743725149775855, 0.03197104284481611, 0.059013713034801185, 0.05075474859040696, 0.025770894390007015, 0.05414270097389817, 0.0069714398068754235, 0.07779352250508964, 0.021440958080347627, 0.08969824659288861, 0.057515565495123155, 0.04395974465296604, 0.057679817618918605, 0.028744628179993015, 0.01785956304956926, 0.02537713309720857, 0.0710081701981835, 0.04998367941880133, 0.004673480179917533, 0.05674192107107956, 0.007652489712199895, 0.05311986191372853, 0.05457155100884847, 0.007846137377782725, 0.15004752116510645, 0.05193101926124655, 0.03707857737026643, 0.026809461414813995, 0.036127782295807265, 0.10462389021995477, 0.07300761993974447, 0.03872957393468823, 0.014488122524198843, 0.05341534430044703, 0.019765446522796992, 0.02026616613875376, 0.004520503598541836, 0.049122131313197315, 0.030627584856119938, 0.03373441541043576, 0.02300275406014407, 0.17832359997555614, 0.18097440304700285, 0.10819004339282401, 0.1455050430377014, 0.1097435069095809, 0.15371212764875963, 0.12879450456239283, 0.29554603330325335, 0.1527181247365661, 0.15465723787201568, 0.1245239345007576, 0.347801927709952, 0.14105500682489946, 0.16424581554019824, 0.20023987395688891, 0.16804641316412017, 0.1955897844163701, 0.24245606880867854, 0.18558830546680838, 0.11813238059403375, 0.2080835436936468, 0.09708478304673918, 0.1074852109013591, 0.11799982559750788, 0.2132952757528983, 0.14791763154789805, 0.11546043373527937, 0.1529248128645122, 0.12749675544910133, 0.17923093488207087, 0.10168416163651273, 0.12276250636205077, 0.07782988774124533, 0.21459367795614526, 0.116158156452002, 0.1839178497903049, 0.11390246538212523, 0.14541852346155792, 0.14737258345121518, 0.1035070841317065, 0.17596585617866367, 0.12583044095663354, 0.10998339872458018, 0.09563478975906037, 0.13425979879684746, 0.1575823684106581, 0.2574369282228872, 0.08260842820163816, 0.14307888806797564, 0.1487987834843807, 0.08147222237312235, 0.1865853214985691, 0.09727956712595187, 0.32921682810410857, 0.19845097151119262, 0.21474975161254406, 0.08107128451229073, 0.24550558329792693, 0.17695067130262032, 0.22890666383318603, 0.1618763606529683, 0.1880204866756685, 0.12657773913815618, 0.11293277522781864, 0.14505948725854978, 0.11395765148336068, 0.20041384821524844, 0.1554026361554861, 0.10593071579933167, 0.13278369675390422, 0.05678419009200297, 0.09384164965013042, 0.12591225531650707, 0.20030061132274568, 0.0775965787761379, 0.201716361916624, 0.15378064272226766, 0.14076516847126186, 0.2988373691914603, 0.1306893114815466, 0.1333292346680537, 0.18943368428153917, 0.11588478635530919, 0.13872927927877754, 0.13760923000518233, 0.17089326196582988, 0.15982136857928708, 0.14659499080153182, 0.1564888731809333, 0.10658795436029322, 0.12439887519576587, 0.09765300099388696, 0.14053900638828054, 0.27706483437214047, 0.1123987183382269, 0.12377584222122096, 0.1071243267506361, 0.16882758296560496, 0.21808963880175725, 0.1315334005630575, 0.14612010534619913, 0.10107211244758219, 0.1284073558053933, 0.11675778208882548, 0.14272947009885684, 0.2527696802280843, 0.12300168571528047, 0.14903947681887075, 0.125493535597343, 0.11289946021861397, 0.12019650850561447, 0.20210028975270689, 0.10266954079270363, 0.13710160099435598, 0.10316713596694171, 0.10041660309070721, 0.17746147670550272, 0.21477105125086382, 0.14788531843805686, 0.11623640850302763, 0.13790718745440245, 0.15972229186445475, 0.13386656442889944, 0.24520900624338537, 0.08652448916109279, 0.15548850264167413, 0.15362550417194143, 0.07124200608814135, 0.17205458949320018, 0.1839099681819789, 0.2455030006240122, 0.15276434569386765, 0.188059464271646, 0.11454133578808978, 0.21212740248301998, 0.12158291458035819, 0.15755747677758336, 0.1470338524086401, 0.20494798460276797, 0.18108130199834704, 0.19353287760168314, 0.10695639357436448, 0.1405676532885991, 0.13548493618145585, 0.1681687933159992, 0.1908595280838199, 0.10467521715327166, 0.18154726683860645, 0.10359082065406255, 0.13845486275386065, 0.1393764914246276, 0.12991488038096577, 0.1260220041149296, 0.17204308620421216, 0.17750637663993984, 0.164772784919478, 0.2258164796512574, 0.08446442079730332, 0.06566742318682373, 0.23766614380292594, 0.1372219031327404, 0.18015140580246225, 0.123512550489977, 0.1620163445477374, 0.17733140790369362, 0.15560099738650024, 0.10891932222875766, 0.09313064991147257, 0.1111155969556421, 0.10381603278801776, 0.14057267020689324, 0.09183987698634155, 0.10575457446975634, 0.08867361524607986, 0.1305521180620417, 0.09825930595980026], [0.054155900070327334, 0.042273611106793396, 0.0881592846417334, 0.05532449693419039, 0.02595194131572498, 0.027057472325395793, 0.03630646919191349, 0.08869615427101962, 0.012148502901254687, 0.060496609439724125, 0.0108789025216538, 0.007422103881253861, 0.04095035808859393, 0.026616874092724174, 0.027258050722593907, 0.026077167603943963, 0.04422962665557861, 0.05193854092794936, 0.07007816268014722, 0.03974498038587626, 0.024607904451841023, 0.024508553142368328, 0.026367336213297676, 0.029230972395453136, 0.07028439809801057, 0.1095961089595221, 0.017409604479325935, 0.11312257949612103, 0.14734883472556248, 0.026972459309035912, 0.02415677699900698, 0.018652614635357168, 0.08819607290206477, 0.06981212500249967, 0.058001126744784415, 0.026439784669491928, 0.0015642516768821224, 0.027732594789995346, 0.10208524050540291, 0.05088617923320271, 0.021671305876225233, 0.08443147686193697, 0.03516663797199726, 0.028860761303803883, 0.04268120974302292, 0.023159521624620538, 0.04807447112398222, 0.013862043033441296, 0.01717699684377294, 0.0756566270138137, 0.05113298415380996, 0.04690539928560611, 0.010057340405182913, 0.021472480802913196, 0.04178563045570627, 0.04529119840299245, 0.06273181352298707, 0.05451560420624446, 0.024989923113025725, 0.030198343338270206, 0.05476699931023177, 0.043331331107765436, 0.07409480691421777, 0.02097777814924484, 0.06413613504264504, 0.079885087616276, 0.014432711923291208, 0.027783869772974867, 0.057710297623998486, 0.011287268353044055, 0.02041288316831924, 0.0166228889793274, 0.022991777696006466, 0.033616499276831746, 0.052152372227283195, 0.03305250786070246, 0.060627765487879515, 0.03415277889871504, 0.06559620669577271, 0.06002676687785424, 0.039749711577314883, 0.033182988554472104, 0.024342736942344345, 0.07048566854791716, 0.04175921370915603, 0.05083616590127349, 0.04297079947718885, 0.02357099983782973, 0.0090760579041671, 0.020926590368617326, 0.032976103757391684, 0.02092561815516092, 0.07947407881147228, 0.06654206648818217, 0.07680641414481215, 0.07281596030225046, 0.07531061550253071, 0.111851859401213, 0.034207738644909114, 0.03986652191088069, 0.032416420508525334, 0.06561589587363414, 0.01563113106385572, 0.02008315994316945, 0.0719829292211216, 0.01807594919227995, 0.03322517964988947, 0.03187132788298186, 0.025616243801778182, 0.06060966079530772, 0.09704034324386157, 0.04361440478533041, 0.05897449795156717, 0.026379511145933066, 0.027980891427432653, 0.031979414270608686, 0.03313207722385414, 0.10007157863583416, 0.06819715970777906, 0.008876913707354106, 0.07541818980826065, 0.018668312914087437, 0.03781359671847895, 0.006668316545983544, 0.02977766991534736, 0.021432139510579873, 0.014982487500674324, 0.026009185021393932, 0.028643495716096368, 0.026583939434203785, 0.06663068634225056, 0.03781481755140703, 0.03466646383458283, 0.032150746483239345, 0.010968372134811943, 0.01778031095454935, 0.010998940269928426, 0.02901939722505631, 0.035321646646480076, 0.027000287991540972, 0.06350380295771174, 0.04826135133043863, 0.05008877495129127, 0.0461167968751397, 0.03894270761520602, 0.06766763734049164, 0.05195273079152685, 0.025358514467370696, 0.020892486827506218, 0.027376213620300405, 0.02141710359865101, 0.06663509469944984, 0.031217952200677246, 0.013040625635767356, 0.014547632563335355, 0.027510987638379447, 0.018804873652698006, 0.02372878785536159, 0.018100768465956207, 0.02035530920693418, 0.013112329161231173, 0.028721517701342236, 0.023935819226608146, 0.0504087073932169, 0.012922972964588553, 0.04635992074327078, 0.056732276862021536, 0.06645657107583247, 0.03761751388083212, 0.05007987288990989, 0.03884845857101027, 0.026341205193602946, 0.026477688006707467, 0.008941161431721412, 0.06269457255257294, 0.026893415015365463, 0.10805001496919431, 0.002580886730356724, 0.02527543289033929, 0.040039635277935304, 0.06485346530098468, 0.05957272464002017, 0.008557931214454584, 0.05288379587000236, 0.014722906507813605, 0.019057912613789085, 0.10147512090043165, 0.018929005273093935, 0.013949208278063452, 0.028644833437283523, 0.03029223058547359, 0.024641039490234107, 0.11499050582642667, 0.07057906041154638, 0.029246900739963166, 0.003237396826989425, 0.03597313356294762, 0.05773487384431064, 0.011090177122241585, 0.03313498273200821, 0.06672906543826684, 0.050636665473575704, 0.023434236863977276, 0.03574034781195223, 0.043152837170055136, 0.05847733322298154, 0.019698720025189687, 0.037120961424079724, 0.02034246634138981, 0.01019140752759995, 0.02913306456321152, 0.04091528790013399, 0.024710176112421323, 0.015916818956611678, 0.058962842522305436, 0.08069499337580055, 0.02238232973468257, 0.12012331048026681, 0.053444566365214996, 0.040584093367215246, 0.02504238553228788, 0.12662608263781294, 0.05500205232237931, 0.015417751546920044, 0.011205587579752319, 0.03723637280927505, 0.0153363602112222, 0.057618950377218425, 0.03431173579883762, 0.03525163614540361, 0.019120086035400163, 0.030422902382269967, 0.011880454003403429, 0.029157811477489304, 0.022529625639435835, 0.012253496388439089, 0.022921833988220897, 0.01729107792925788, 0.047474671082454734, 0.034771622449625283, 0.04153263602347579, 0.06352405616780743, 0.050168110537924804, 0.06526239609229378, 0.001467192444124521, 0.048940939668682404, 0.03136530562187545, 0.016127167727972846, 0.025024026654136833, 0.03422580994083546, 0.010525108664296567, 0.03020078129338799, 0.03618505012127571, 0.024236756398750003, 0.02800582573399879, 0.0352567940717563, 0.011593621347856242, 0.01922232058859663, 0.009803037937672343, 0.01583138291607611, 0.04093788629688788, 0.016084752132883295, 0.04254517778463196, 0.0246608270026627, 0.018656755819392856, 0.042895352744380943, 0.010184609454881866, 0.025691363989608362, 0.031066643132362515, 0.04842440117499791, 0.011480327866593143, 0.04815700165636372, 0.06280139728914946, 0.07528957561589777, 0.04442103025212418, 0.02100256588164484, 0.018140039210265968, 0.022359877912094817, 0.029072822580928914, 0.05611895117908716, 0.01922999625094235, 0.017989448169828393, 0.060778306433348916, 0.015676628427172545, 0.019715347843884956, 0.016304053060594015, 0.04048340990266297, 0.06867669842904434, 0.03816474389168434, 0.05524310559849255, 0.006434722781705204, 0.03164004869177006, 0.034773459265124984, 0.08512111016898416, 0.02437193488731282, 0.04497313617321197, 0.04733966328785755, 0.019072315844823606, 0.03839033823169302, 0.027837610541610047, 0.01506755246737157, 0.022379646870831493, 0.08593921666033566, 0.06790643077692948, 0.022783584863645956, 0.049142878051497974, 0.03513868497975636, 0.03430020282394253, 0.009233552773366682, 0.015524255304626422, 0.05141066241776571, 0.04082901323272381, 0.0645463349064812, 0.04039293839014135, 0.03088348665187368, 0.029974932767800055, 0.007095178089002729, 0.030644359248981345, 0.05807396853924729, 0.059594729318632744, 0.05727539166400675, 0.02252046011562925, 0.04750501750095282, 0.025818898357101716, 0.020084866882825736, 0.05159244035894517, 0.007580284309369745, 0.0809137117175851, 0.05478111866977997, 0.01713288358587306, 0.013611598806164693, 0.025239783826691564, 0.03389242607227061, 0.07917610651929863, 0.008464820439257892, 0.026767077361000702, 0.06900262742419727, 0.04301397391827777, 0.11509896328789182, 0.03362376490258612, 0.07332230539759621, 0.09087607948458754, 0.05277322699839715, 0.028100434719817713, 0.03881421958794817, 0.009155190327874152, 0.06300171779002994, 0.041696220214362256, 0.007832161809346871, 0.03414018465264235, 0.01790378020814387, 0.019242753769503906, 0.23444464401109144, 0.10541912371991202, 0.13318369950866327, 0.1409610954578966, 0.16210231493460014, 0.14452748611802235, 0.10377761180279776, 0.19951319263782352, 0.11642288794973865, 0.26088972575962543, 0.13801279506878927, 0.11599927747738548, 0.14663981652120128, 0.15411500993650407, 0.10001239235862158, 0.16355011146515608, 0.21127023675944656, 0.259934967616573, 0.09127534009166993, 0.12972300552064553, 0.11086401631473564, 0.11389586768927984, 0.08484958059852943, 0.15260778222000226, 0.1421121961902827, 0.19069195113843307, 0.10981732091750018, 0.18161775602493435, 0.2191859987215139, 0.13142028241418302, 0.11506365932291374, 0.12889870209619403, 0.11533244294696487, 0.1356537896208465, 0.17084468097891659, 0.1488218197482638, 0.10215053465799429, 0.07325592028792016, 0.13072993664536625, 0.14639150875154883, 0.12772423855494708, 0.24851292895618826, 0.20370390760945156, 0.13793203455861658, 0.11395266425097361, 0.19105453480733559, 0.11009806796209887, 0.06580187065992504, 0.10552607462159358, 0.13277643854962662, 0.11046769461245276, 0.15638559591025114, 0.15393705776659772, 0.1785057081724517, 0.12455952790332958, 0.22628008446190506, 0.1670729083707556, 0.16181131883058697, 0.13196959043852985, 0.11488125426694751, 0.16469168302137405, 0.17910855473019183, 0.1217278560216073, 0.13758742570644245, 0.1089241832960397, 0.15901535167358816, 0.1523939991602674, 0.10722705483203754, 0.136671660002321, 0.14338162494823337, 0.08526249672286212, 0.08182495774235576, 0.12206928106024861, 0.16034351399866864, 0.18790248519508168, 0.16850654472364113, 0.13145373843144625, 0.126355703396257, 0.21582521265372634, 0.13487070507835597, 0.1268639409681782, 0.11847283341921866, 0.09865537533187307, 0.0842394758365117, 0.08480575677822344, 0.13117810478433967, 0.1391982423956506, 0.05224737455137074, 0.0809186915284954, 0.1123988296603784, 0.11436768065323122, 0.1391996376332827, 0.1282783260103315, 0.232866823207587, 0.13852652453351766, 0.16327388409990817, 0.17438364186091349, 0.2874681417597458, 0.14592867577448487, 0.08037332430831157, 0.127497052308172, 0.17162264470243827, 0.11903164835530333, 0.16228218184551224, 0.29657809354830533, 0.10176546391448937, 0.16075611842097715, 0.08450391789665446, 0.08747417843551375, 0.1090246849344112, 0.1280616337317042, 0.11575684751733206, 0.14318030996946618, 0.13082227465929464, 0.09110323604545556, 0.10880941757932305, 0.1104230470082257, 0.23155617556767538, 0.20496986311627552, 0.07683260453632101, 0.13884772604797035, 0.16701086482498795, 0.11535748300957493, 0.12045030816807412, 0.14579133392544463, 0.16929436416830868, 0.12709232949418947, 0.19120842654956505, 0.1393395769991912, 0.14748374233022332, 0.15301249019103125, 0.1013193886319641, 0.08345708149136044, 0.22220990911591798, 0.13446981174638495, 0.14220775512512773, 0.24179585423553362, 0.12922098714625463, 0.13129278144333512, 0.08074440556811169, 0.10782141864183359, 0.12236818845849484, 0.16740631079301238, 0.1329259664635174, 0.06894638747326098, 0.10158797187614255, 0.15059221303090453, 0.08018175372853875, 0.1294641592539847, 0.17628600384341553, 0.08950924384407699, 0.22054334229324013, 0.1901127939345315, 0.09045362676260993, 0.0978944067901466, 0.15365940547781065, 0.10295655898516998, 0.1263930185814388, 0.13478948443662375, 0.2187595161376521, 0.10553235319093801, 0.17374536517309025, 0.1630123215727508, 0.14989968534791842, 0.19078188459388912, 0.14806423539994285, 0.18329413403989747, 0.16579708229983225, 0.13767559285042807, 0.16592688392847776, 0.12278201000299305, 0.1901379824266769, 0.08391876413952559, 0.11314206829410978, 0.13839028106303886, 0.0749661328154616], [0.01371844116874854, 0.019721108765224926, 0.0909207270888146, 0.009926274342433317, 0.011054046590288635, 0.02226310742116766, 0.015446914239873877, 0.029971802759973798, 0.01200987899210304, 0.057064087377511896, 0.01842367692006519, 0.017100399782066233, 0.005651006486004917, 0.013302075913088629, 0.022282659301708918, 0.058940830422216095, 0.039451483244192787, 0.04485245553951245, 0.02169692666939227, 0.04625347821274772, 0.048645750430296175, 0.032066226995084435, 0.04216775116219651, 0.06028966527082957, 0.01992648329178337, 0.0174196383159142, 0.021218120818957686, 0.01518611334176967, 0.022598253890464548, 0.03170101983414497, 0.03306145816168282, 0.015692220949858893, 0.05459154075651895, 0.004715587319878978, 0.029076633509248495, 0.033327069104416296, 0.09089642175240442, 0.03264404462242965, 0.04739198469906114, 0.01929373189341277, 0.10050904500531033, 0.016058585861173924, 0.08994020157842897, 0.01772278337739408, 0.07875506387790665, 0.01879897728940705, 0.017624821739445906, 0.020226084598107263, 0.015812177989573684, 0.034357144104433246, 0.03582502686185762, 0.023091043658496346, 0.05598604737315327, 0.020172195399936754, 0.03830824927717913, 0.09418792833457701, 0.020978678003302775, 0.05121588947076816, 0.09619969772757031, 0.06622490225709043, 0.06823382180300541, 0.051885815046261996, 0.09571322734700516, 0.031977462422219105, 0.058357138696010225, 0.05408490622357931, 0.028872778530057985, 0.005984407980577089, 0.020729065909108613, 0.017809811324696057, 0.08810836588963866, 0.041003922597155906, 0.04837472923099995, 0.13398605020483956, 0.014408755396289052, 0.009222593107551802, 0.03397686763491947, 0.08428601591731422, 0.06028892683389131, 0.01006754400805221, 0.050375741193420254, 0.0936937470396515, 0.039448566603823565, 0.046950321484473534, 0.02327631154912524, 0.055302087785094045, 0.017071428192139138, 0.029681636005989276, 0.038709688087692484, 0.02134018184733577, 0.018473680975148454, 0.04277301341062412, 0.021438835537992418, 0.004321042597439373, 0.05440822656964883, 0.014606488584831823, 0.05359420189051889, 0.024262753831862938, 0.038915815894142725, 0.05799349004519172, 0.013108339189784601, 0.017597519981791265, 0.06712006594170816, 0.052196945616742596, 0.06857272353954613, 0.023316389379033353, 0.0900493715016637, 0.02406360777968075, 0.010822014119185042, 0.03261471865698695, 0.054825038969283924, 0.0800114382582251, 0.028943518191226758, 0.017010544252116233, 0.044218208713573404, 0.039165207199403085, 0.05023690391681157, 0.02209526144724805, 0.01939060999575304, 0.009735713083500741, 0.05921241194300819, 0.04033279103168752, 0.001156420423740201, 0.048490734334336594, 0.05535908472666051, 0.010841502917173784, 0.04201692820060998, 0.062292358197737485, 0.02007922470511403, 0.010157845754292794, 0.03728502801095601, 0.03121949586784467, 0.014095663700572914, 0.02801313403324457, 0.022530954083777033, 0.06282438160269521, 0.03077841338381404, 0.02885366451664595, 0.030932791232771706, 0.014331065522128483, 0.011757682368624955, 0.040183370729209855, 0.07262679428094998, 0.07780956773785874, 0.015719424372946378, 0.06381474799127318, 0.05207602007430978, 0.11337424177327193, 0.09052681736648083, 0.034202072347397916, 0.03690727484354284, 0.051057322198175825, 0.05656626213749405, 0.053443256474565715, 0.015391381184599595, 0.021749734187324066, 0.017969827640627045, 0.08015667655854486, 0.043881570527446456, 0.04364544140116777, 0.03654590458609164, 0.028266835361137055, 0.05812970382976346, 0.03726792892848607, 0.0340892028179951, 0.013007880224904511, 0.02408971467957599, 0.06101414612203371, 0.0508604415517766, 0.004205118666504859, 0.006442534813686507, 0.03757665122975595, 0.025711611633596476, 0.04751338892674539, 0.019239564389863517, 0.03423076377657708, 0.029496154747903347, 0.03952486680645961, 0.0515397590061184, 0.006477329015979194, 0.03517741395626217, 0.0037866591628699098, 0.05357478730729781, 0.0936431103036739, 0.03225932639907114, 0.02230786078143865, 0.0347946141846478, 0.032381097989855334, 0.04111367881705519, 0.009262179264624137, 0.07537579833297059, 0.03645719938504044, 0.03406323507078923, 0.054928538884269074, 0.01664598090428626, 0.048802588498801924, 0.053876433230470866, 0.0631197341135703, 0.07705325246206485, 0.028526449750643224, 0.029392467440629844, 0.04539195237157401, 0.03707014286192134, 0.03837541735265404, 0.036739152419613674, 0.022573770438611973, 0.04108820459805429, 0.06281689333263785, 0.0700875285838265, 0.04343787753896322, 0.06102074752561748, 0.026406718279758934, 0.014954880534787662, 0.02499053724022815, 0.04484360913920682, 0.025809363614825998, 0.11208624448045157, 0.04826063144719228, 0.04054518627526704, 0.025593929276510607, 0.06483347926405258, 0.055553531128680333, 0.024413265091425274, 0.01812710914236959, 0.04511479732173029, 0.01511931448476389, 0.02083298884826945, 0.06422588296118192, 0.028184466245875228, 0.009390931681991788, 0.02036902224062942, 0.05711257559596561, 0.056095198742696084, 0.08616690756753087, 0.07175493403337896, 0.03966620141000021, 0.04330615003709681, 0.023324547437368892, 0.025827375538938213, 0.06009386073856149, 0.00606411371336435, 0.05609024490695447, 0.10916819403064437, 0.017467315738031175, 0.06322675180854276, 0.04281229899788741, 0.06518911643070169, 0.0755476055201143, 0.00609156390055432, 0.09029504464706406, 0.019872633056365885, 0.04829328223422635, 0.043575534800766036, 0.017754944346961565, 0.05885809579922352, 0.04526953140157275, 0.02052636496955529, 0.021869370248168707, 0.0335481660295045, 0.047388247985509224, 0.041075966582866386, 0.07465223403414711, 0.02657856442965567, 0.03720550688740332, 0.06740867233020253, 0.01945208765391726, 0.02497878533176845, 0.018500268415664323, 0.02711885350436205, 0.02798438694298966, 0.030188472774170805, 0.03992233512690291, 0.07587235450046137, 0.007759468444419326, 0.031258243398042396, 0.03091892234806437, 0.01552288140374003, 0.03541124242474325, 0.03762001120776404, 0.06153174217615742, 0.02514317660825327, 0.08300492059788667, 0.021446887840284035, 0.01290736838200246, 0.021385274740168825, 0.06250925085623749, 0.04046167239721399, 0.031879769812803715, 0.03562292520655319, 0.046793082656222396, 0.04583543755870778, 0.045398227230180055, 0.022808431967860088, 0.03136038518277928, 0.041907442864612676, 0.004427240683071432, 0.019517045984684955, 0.016840820644574706, 0.09366253230837174, 0.023922484688227996, 0.02190226408856688, 0.019766680343309417, 0.029780616241623648, 0.04166582184552681, 0.0020561143401209847, 0.013583851759904064, 0.025554163148626685, 0.05515108299732674, 0.03705893272126559, 0.02431994187645614, 0.022767485825170297, 0.014450593043875415, 0.017498619527032133, 0.08443400016403757, 0.022091289101808798, 0.05135501989570912, 0.008990231308416696, 0.028107542639190797, 0.07253736548591405, 0.03620707706431858, 0.05543771156226285, 0.014326813015941298, 0.04447705126949586, 0.06311066506896168, 0.04805826261872426, 0.05665042539476417, 0.05623586170258932, 0.02425027090794174, 0.036818380394834094, 0.061413855728460476, 0.04906665206362959, 0.026345413170929532, 0.06628932809690014, 0.058858329575741664, 0.02561331417382462, 0.03182433509209659, 0.06226218247320503, 0.053818916785530746, 0.11836179328383878, 0.04672417424444575, 0.04436574767169077, 0.023113053903216496, 0.10589690355118364, 0.0387251989741344, 0.030216050981834996, 0.03834612107311841, 0.03061850839003455, 0.0347715742100263, 0.011808756971731782, 0.04833891689486336, 0.01964049482921837, 0.009189183474518359, 0.11678098904667422, 0.1473870553309098, 0.19837237807223573, 0.180294610618148, 0.15672487614210695, 0.14817077812040225, 0.15484565432416275, 0.15502893511438742, 0.07074858178384602, 0.09381408628541976, 0.07603924124850892, 0.12407208530930802, 0.09377841124660335, 0.07185857495642267, 0.14859473740216345, 0.17609556874958798, 0.1274506383924745, 0.14665788039565086, 0.15399623662233353, 0.15396561560919508, 0.16249733045697212, 0.17914628551807255, 0.12318151551880874, 0.14782985032070428, 0.09527641406748444, 0.15084979764651507, 0.10934904057648964, 0.1627587593975477, 0.059316475890227593, 0.18427834060275927, 0.13488547381712124, 0.20348820980871096, 0.15573511831462383, 0.09972344458219595, 0.1594620503601618, 0.16954035643721, 0.1506321702618152, 0.1907181044225581, 0.11254047596594319, 0.16050099773565307, 0.2013251165044494, 0.07659480557776988, 0.13155559077858925, 0.07773985780659132, 0.2006545415497385, 0.15338666620664299, 0.11535768338944763, 0.13298855919856578, 0.13091073866235092, 0.1504218901391141, 0.14307627570815384, 0.12403665517922491, 0.16526217194041237, 0.11645706385024823, 0.13765506504569203, 0.1761085563339293, 0.19226376054575667, 0.1514400722226128, 0.17698295472655445, 0.12301051727263257, 0.13138648500898853, 0.06743190897395834, 0.14126326830592006, 0.13652305235154927, 0.09651974149164744, 0.19095734314760193, 0.2425763857900165, 0.1726955675985664, 0.16226819978328422, 0.13721385825192556, 0.1250767454621382, 0.18701596010942012, 0.13535851874621585, 0.12853303109295666, 0.10329254408134148, 0.17186854791361839, 0.1363101598690264, 0.13239175372291356, 0.12358698790194467, 0.08725088104256429, 0.16194349533179775, 0.202240051003173, 0.15551847056485713, 0.2000926318578422, 0.12797683593817055, 0.16019015660276636, 0.13665306178154424, 0.11154625783092342, 0.10534717992413789, 0.0988860274082981, 0.1383151311893016, 0.10170351684791967, 0.13697730610147119, 0.10477826435817406, 0.14666945789940655, 0.20447390066692606, 0.11275831115199253, 0.22082188515923917, 0.11579373967833817, 0.1033003514748998, 0.10460012665134855, 0.12725721986498684, 0.12613164901267737, 0.0978489279805217, 0.1484998018713668, 0.14613805047702044, 0.22928321472136304, 0.09171286583296023, 0.177495630341582, 0.13605302054202184, 0.13011327129788697, 0.19991833105450496, 0.131453174399212, 0.14367983472766355, 0.13324701954843476, 0.16258350864518434, 0.10297373228240758, 0.1314578647725284, 0.09905984581564553, 0.08695684955455363, 0.1951131920213811, 0.11160494686919264, 0.14089339674683288, 0.1211798467556946, 0.09032772140926681, 0.1604377370676957, 0.13404324010480195, 0.08896780258510262, 0.09753053920576349, 0.10041447312687524, 0.20214593183482066, 0.1701379189034924, 0.12304507166845724, 0.11877205251948908, 0.1190809418039862, 0.1938248088117689, 0.10941239772364497, 0.19973862741608173, 0.1054123330686707, 0.10898149936110713, 0.10125713728484698, 0.10214230424026027, 0.1891588669968769, 0.14816231763688847, 0.0827186148671899, 0.23376231343718246, 0.27380241255741566, 0.24930468178354204, 0.18269940657773986, 0.13482421694789082, 0.13056241907179356, 0.16249838430667296, 0.1291696898988448, 0.13049292436335236, 0.15903256949968636, 0.07502254346036352, 0.11386490528821014, 0.21776947629405186, 0.10740646903286688, 0.13612910552183166, 0.16905039054108784, 0.11725119897164404, 0.14687748189317062, 0.12473149836296216, 0.16709851246559992, 0.0975821258907672, 0.2128862781682983, 0.10578456465736963, 0.1989591497112997, 0.12369554184260778, 0.09315384202636778, 0.144347500463482, 0.13395455345744267, 0.18252764391945675, 0.18475635792128742, 0.09094791937968694], [0.00937404689466348, 0.038545001807506196, 0.016542440171178896, 0.03928194702893961, 0.008093115775409387, 0.02256590552860871, 0.029241323500173166, 0.06982343533309177, 0.012165522202849388, 0.08986223154352047, 0.027815848916361574, 0.05646439123665914, 0.027635061742330436, 0.05996178442728706, 0.059101123188156635, 0.02529208668420324, 0.011145121097797528, 0.03098777695413446, 0.035957426007371396, 0.025697139753901865, 0.060285787549219094, 0.02331183073692955, 0.0018983122913596162, 0.05012383029679768, 0.03974272796767764, 0.024550265552534256, 0.03742227709153667, 0.05158852924068924, 0.023143281578086317, 0.0659484819334466, 0.014175875949149486, 0.06661475985310972, 0.043979192632832564, 0.05340564443031326, 0.06197630718816072, 0.053605961220455356, 0.02507792698452249, 0.04050775234645698, 0.10023228329373524, 0.0351720519392984, 0.072487092402298, 0.01665518168010749, 0.02691294463147642, 0.0498495881765848, 0.07978276771609671, 0.03789553724345751, 0.032013382369768806, 0.06079579143261071, 0.03510499889671337, 0.02761888663371792, 0.07418203895213082, 0.04640823826775886, 0.06914819226949476, 0.041224151209462434, 0.03257594886235893, 0.021698173477489036, 0.010814939596457407, 0.05220097918936517, 0.01662895047047641, 0.034338965197093785, 0.018141219225071836, 0.02093181508826092, 0.01612507301615551, 0.005672128936566878, 0.02295031947141979, 0.005269152488835971, 0.06390618800651282, 0.017520967448945157, 0.020427418130566366, 0.015991237814887427, 0.028457088628783822, 0.06614241254283115, 0.050853146240115166, 0.02551000907260459, 0.02391186269960599, 0.08675770906847902, 0.036371273527038284, 0.06319229389191605, 0.02954278574179625, 0.08626409180578776, 0.02266396550112404, 0.03083152332692407, 0.05602410099527333, 0.06719598764902912, 0.06140601122751832, 0.03016378337633796, 0.067501611483749, 0.06578955100849271, 0.08317683910718188, 0.03129142110992689, 0.05435599050542805, 0.03309956373414025, 0.03996068560809363, 0.030806611284788232, 0.05481019601575099, 0.012285511711525032, 0.04817171844479162, 0.01951529451616807, 0.02632422485476127, 0.059730649954872206, 0.005473554801938008, 0.047457045075134374, 0.0312507625494618, 0.028412476276571397, 0.05243937557679601, 0.029529286075558048, 0.133367232629098, 0.022208531736396253, 0.023159491938713472, 0.08653902041260153, 0.069856668706052, 0.054716696540708654, 0.051508833712432534, 0.051873443444492295, 0.02412478301266674, 0.024183852401620243, 0.05372643034206703, 0.07132125261705369, 0.04069240239914507, 0.04312053519242909, 0.05777041158580687, 0.04073549520398956, 0.028802877495763823, 0.0482959057262633, 0.039279104603338055, 0.05666383229254279, 0.04318539889936801, 0.010858343175641494, 0.034881193132605404, 0.00968202333751833, 0.020914491506118793, 0.04347309615695849, 0.04862256573687773, 0.04301989254599903, 0.023175019523478113, 0.05186216651054565, 0.03571711487893481, 0.033749492140486836, 0.07255951117258519, 0.04381099599413574, 0.04549012737697922, 0.039549691646243446, 0.03546196821844205, 0.03532120506861247, 0.0903106594341807, 0.04139940567256417, 0.012991799740120769, 0.01570951299072476, 0.04457520029973239, 0.015227104941004654, 0.023504054406657815, 0.017133106230176054, 0.10773334055556916, 0.04788533478858881, 0.04349611386714969, 0.04092951487109531, 0.019406868595979176, 0.09666235258919187, 0.025878344386001118, 0.021234728228591848, 0.02939630805485649, 0.04868092823016923, 0.020647912060667295, 0.036115284528932534, 0.03770816350879613, 0.031016898828966077, 0.04591100303514395, 0.030215681763365865, 0.04203550415695645, 0.018382573070994113, 0.07278481978573836, 0.05147491014213301, 0.10871955833863467, 0.03572651417925954, 0.07482365530449897, 0.02612475411297055, 0.10476099458173849, 0.04394625611894298, 0.03310339692689013, 0.011543538439582335, 0.04516491826507263, 0.03784466673096176, 0.02252574049634859, 0.04666982677008491, 0.04253205290297046, 0.04031288292026147, 0.05461018350615632, 0.04481139621930197, 0.004946558055962669, 0.04079070728039369, 0.06501600306364708, 0.019618319456640165, 0.07163475806009956, 0.053788366276421584, 0.0073329649876541225, 0.06341737986076623, 0.08487320315907709, 0.06361669846228324, 0.05507360277988482, 0.03400483175937552, 0.06678604753687978, 0.020280665848986246, 0.05760303130955435, 0.035357473825570196, 0.03159081461490132, 0.04338143720815424, 0.03065902965317946, 0.03042166670638835, 0.03674683735880535, 0.03282262019638438, 0.03422202127694618, 0.04136908151849639, 0.0023421195010087104, 0.04672972179832868, 0.03327250640722923, 0.05172001554456074, 0.050953558820765465, 0.005710193690902088, 0.04268613389285747, 0.04198256676318124, 0.05658117188431788, 0.02867045608581975, 0.031209662411129102, 0.026903792095254175, 0.03599136442062445, 0.058371918566990644, 0.03345368320879061, 0.04463098382984754, 0.04241478243784513, 0.020646427765314, 0.01299522753470228, 0.03498497506370768, 0.030893000985088293, 0.046932717741583474, 0.11309039997286163, 0.05543425686482806, 0.022725634262314998, 0.04812032842892222, 0.021167189079278614, 0.012297204248170601, 0.04807257864740677, 0.009428679168195231, 0.035216309915995225, 0.03848491753160488, 0.011612073922151467, 0.012247114846104523, 0.01718510851787869, 0.03442565546720289, 0.013745956293860218, 0.053413444402394816, 0.029945107708044816, 0.040776012756396085, 0.013798567142657703, 0.05349998995370697, 0.1210992866253946, 0.006344543025988969, 0.04169451327470597, 0.024498105558450334, 0.04117188545933459, 0.022167385213833768, 0.03466694994131103, 0.038352804112946615, 0.043691380342352204, 0.01154753212176729, 0.05068004029453732, 0.05284502978611272, 0.058164002184639685, 0.07102424511685967, 0.017903529733303003, 0.03602272387070116, 0.01435288837456028, 0.04726802377263084, 0.02548195217968896, 0.024154582097253297, 0.01849623669841094, 0.03799394973611925, 0.03848256492346991, 0.01802067217795411, 0.04428082742379047, 0.05470864423841704, 0.0729531908291392, 0.04484809542191215, 0.057253709819633514, 0.015611304588674102, 0.06440462922910228, 0.05787959264125675, 0.03751270778593607, 0.049075446513597853, 0.04519602167420089, 0.03997207015345339, 0.06783934062696062, 0.03362046605616342, 0.04048158421937842, 0.02348578087548958, 0.013986791564093437, 0.07765200236462988, 0.032474500985699706, 0.018970641613123007, 0.005402191272878554, 0.068897383462172, 0.013993280717841117, 0.0067404305718810065, 0.041156630613841116, 0.051604266482172534, 0.049745286742108874, 0.025324674388684798, 0.019816632448055316, 0.07015380979282781, 0.018564744350442197, 0.03600291223847307, 0.05036669070250355, 0.017151214633486234, 0.017835879261838272, 0.07104967109626159, 0.0413877576647792, 0.005544871019083075, 0.011609929115365958, 0.03224996791686863, 0.014949178985261824, 0.04582788249535952, 0.07980760739883408, 0.020478268234001007, 0.008978934893093538, 0.04906593218038324, 0.018295851259608753, 0.009260268234356772, 0.01187454465252813, 0.03577242714527529, 0.03535460171406157, 0.030535100268025417, 0.030812160694040358, 0.009278417455789167, 0.09619934149668552, 0.06048300216207281, 0.07655424720724113, 0.047579562524333596, 0.05205060151638463, 0.04110050569579471, 0.11542366773937829, 0.029517942348320503, 0.027594917119131424, 0.05743699432059657, 0.02209327620221302, 0.032829948904691264, 0.03626865676778834, 0.027913958983845077, 0.06059563049348071, 0.02017760565649951, 0.042177707073278725, 0.02570048312918516, 0.03180232299200725, 0.06872268932056613, 0.09839935664786026, 0.103855685738381, 0.12218903400935233, 0.1607083241106011, 0.08821273411740549, 0.1574497763067484, 0.14032483741175383, 0.2153551808441989, 0.10411519251647405, 0.17759019479854032, 0.10489697830053046, 0.19546798313967884, 0.07715751678915694, 0.13306645501870662, 0.18947983102407306, 0.07112942228559405, 0.17605670989723876, 0.11096368674770929, 0.09129958605626598, 0.16497414442710578, 0.2293701350572519, 0.12752129085129127, 0.07388581070699729, 0.1572609442519024, 0.1717316365102306, 0.18623266776558012, 0.1385028797085397, 0.0867671195010189, 0.056810057649272494, 0.22250593698117882, 0.1685497970902361, 0.11389993465854786, 0.15614663920132443, 0.15858670201851055, 0.21129241213202477, 0.22030123887816444, 0.09586962012690492, 0.13422929652733728, 0.24869307788321748, 0.1508213733904995, 0.09747839591000229, 0.10033843267592601, 0.09376526781124994, 0.12793279689503834, 0.13621314632473513, 0.15492160571739078, 0.12488634005421773, 0.10349992240662687, 0.10386630587163381, 0.18148880044464022, 0.2091953848139383, 0.18072029168251902, 0.25745004939381033, 0.19744162098504603, 0.09255539640435018, 0.18268849700689316, 0.12786027422407642, 0.22422000125516206, 0.2118343728943728, 0.10058369764010422, 0.08793284796411172, 0.1311344961868599, 0.06100829428760335, 0.1339337436365895, 0.18124965077731758, 0.059524934040382504, 0.16012501087971032, 0.10831090214196593, 0.06474238805822097, 0.13586653367383406, 0.07431506150169298, 0.16076212981715798, 0.12606298550963402, 0.13224488269770518, 0.10218381998129189, 0.1532216719351709, 0.08405062151723541, 0.1264327234821394, 0.2552592888241634, 0.10696308774640784, 0.17587146983714774, 0.12653199315536767, 0.19968127424363047, 0.14282998658018187, 0.12189195229439065, 0.15426081226905808, 0.21846276096766815, 0.11478446336695924, 0.2669281361158937, 0.13732313207583502, 0.12685182911809534, 0.17710108979372308, 0.10912321245996282, 0.10708002795581706, 0.11518322673509829, 0.17275286139920354, 0.21001084183808416, 0.14846026024315506, 0.08085134904831648, 0.16232071415288374, 0.07952726111398079, 0.11980112190940417, 0.12883889983640984, 0.13248407689388841, 0.15408719424158335, 0.12611135869519785, 0.18635157466633245, 0.08424189523793757, 0.11964596851612441, 0.16677278385031968, 0.15448507445398718, 0.11107230006018654, 0.12373991485219449, 0.1196499093202874, 0.15823704656213522, 0.0882604467915371, 0.11633553716819733, 0.1530393707798794, 0.12163001127191819, 0.16307927813613787, 0.10773429050459526, 0.0966576102655381, 0.07331184853683226, 0.14995463396189734, 0.08058767140028067, 0.21616578422253951, 0.12819893105188385, 0.09993600309826434, 0.12991943716770038, 0.19481464085401967, 0.11242650434724055, 0.14780855068238452, 0.0915627293579746, 0.11802568202256225, 0.12669928808463737, 0.10067144918139093, 0.20432633202290162, 0.1179199705075007, 0.20549564505927265, 0.15065203013364226, 0.17080600024200976, 0.16780966805526987, 0.08919466228689998, 0.12294566840864718, 0.2984502352774143, 0.14462531602475792, 0.12265243101865053, 0.1278696401277557, 0.11226217800867744, 0.07123764225980267, 0.09330193017376587, 0.12034145736834034, 0.12904348026495427, 0.09693981191958301, 0.1263322218437679, 0.13103690376738086, 0.14251427695853636, 0.1244163750379812, 0.17056821612641215, 0.10168318942305632, 0.11385553196305409, 0.15178211324382573, 0.2926121454220265, 0.11519162784679793, 0.13517409504856914, 0.19562131084967405, 0.11181910842424259, 0.11236345148063265, 0.1000574481440708, 0.13835602352628484, 0.24244138912763447, 0.1005747176532168, 0.2158539931406267, 0.13916073425207287, 0.15244326292304322, 0.21948392648482695], [0.035192679933970794, 0.016703901819710154, 0.006910008069098694, 0.05167788011021912, 0.06504556280560791, 0.012211850771564059, 0.06640710693318397, 0.045447435331880115, 0.0662211247254163, 0.01078084254913847, 0.025994726129283663, 0.028039383796567563, 0.036528493801597506, 0.050031195423798636, 0.005922475293118623, 0.014578858426830266, 0.04652635849197395, 0.02740610361797735, 0.03595574504288379, 0.011965012454311363, 0.05335929359716829, 0.035633923835121095, 0.03287865976744797, 0.021194865621509962, 0.006437672818719875, 0.03972226695623249, 0.01243492923094891, 0.07534602336818352, 0.052107078954577446, 0.012344251772447024, 0.052170206035953015, 0.01981611108931247, 0.05407723983807955, 0.015727623249404132, 0.02549727196310414, 0.015403610850626137, 0.03931558116164524, 0.024783548542473, 0.028264916909392923, 0.08960529259638861, 0.03545781219145283, 0.04949819609464612, 0.03181941465300042, 0.0018619428806232463, 0.018475091055734083, 0.020543272948998492, 0.05843475621077232, 0.01349650468910113, 0.03612552616687026, 0.058075144843314774, 0.008963960208347999, 0.003639038568508113, 0.012068348169123055, 0.027037979816668667, 0.04132483838475309, 0.005652595609717537, 0.04695943876868114, 0.02389766726992093, 0.0352369638858363, 0.02027201982855331, 0.05701552494429052, 0.06652536816545762, 0.11648292769677937, 0.022633539301750716, 0.03276216855738312, 0.017634575415286236, 0.013580952745542163, 0.019022443520952947, 0.03864763712044805, 0.04117316937481519, 0.020515538890322205, 0.06606109542190097, 0.07008352840784937, 0.038977165531832725, 0.021983263941365294, 0.053547502247965895, 0.03887623344780877, 0.023363591826637276, 0.03654494350485038, 0.01888635404611705, 0.17896573583129793, 0.0060558211407624185, 0.07233412092318758, 0.021106047242938075, 0.03792560164583847, 0.002719439439715643, 0.06231596591533162, 0.08575118612498045, 0.03176553473167587, 0.033532747911522165, 0.08601418841863051, 0.03775972050789278, 0.058351242332719266, 0.08697877259692177, 0.022452752127719577, 0.02240559977508383, 0.05163912886928301, 0.06267926204600371, 0.0299515514052473, 0.05005838771467097, 0.03503628715407103, 0.035743539046961814, 0.0306329709928832, 0.035204717569286004, 0.015824516194697935, 0.02923461448517628, 0.02035034052823903, 0.04725365579361096, 0.033966418195632286, 0.05479319341247901, 0.017645496118348092, 0.012168521407147637, 0.016632028527965304, 0.011153613122587558, 0.023921792635519523, 0.0401136236905586, 0.009373234242957551, 0.028544007109303493, 0.01205970029332093, 0.05379787318815943, 0.03961445145250764, 0.0709587505843956, 0.042396881835884415, 0.006903690073158941, 0.03684552815684583, 0.1079001159814652, 0.01765737048117444, 0.020741493171954062, 0.0745708798058331, 0.012832820575567894, 0.02685930776351597, 0.0567490382672986, 0.012982279840798583, 0.06072695723560173, 0.04979117373295594, 0.05688259887392633, 0.03428326701396145, 0.020786389395652805, 0.08275310989120044, 0.1034638837154489, 0.035617526082205586, 0.07121150381863117, 0.0441836172103649, 0.045079177943989635, 0.005862904490641085, 0.02513763462047791, 0.016944604431046173, 0.024230615126725752, 0.04590643882693257, 0.03850899651297368, 0.0473675606190227, 0.037973956277710386, 0.07838427205570042, 0.017532730489620008, 0.11006556931533851, 0.04374067379103508, 0.012401142030284973, 0.1038174206041731, 0.04003006899438333, 0.023180954849522095, 0.01897945647215238, 0.06974130184971727, 0.06338918567053042, 0.03060356895730365, 0.06915728357853368, 0.04227236800943501, 0.03951522630813997, 0.017939232602657285, 0.013736630280618556, 0.030837736958346795, 0.026979632166330703, 0.010051726985693676, 0.01213229068525834, 0.02271311608637916, 0.09200982138281688, 0.04933793672535103, 0.018587706399557646, 0.03202640335075557, 0.028248029339010827, 0.009184305708913598, 0.04432763467775658, 0.003832859015346912, 0.022669216195936315, 0.02090246314764954, 0.03669741774501745, 0.0963710447831545, 0.05608172134088818, 0.01751415267790435, 0.02810147558193421, 0.03269806184107438, 0.0417447010113392, 0.06852539678220637, 0.04766134348756168, 0.03554095499566756, 0.018712752716965042, 0.030978609574958682, 0.03272752139309887, 0.08307707961648703, 0.033172271942021325, 0.02283193578477949, 0.07164511102018878, 0.02236989876109874, 0.02460821058775764, 0.05047533370088786, 0.0541795448953053, 0.007325434971789946, 0.025488421852060128, 0.015330952737713233, 0.021167936793062836, 0.01219715068145888, 0.04697932832641527, 0.016144378132594284, 0.03306060469185468, 0.04485079312871676, 0.02866234255634481, 0.05283358215820044, 0.03799271034949925, 0.04414647271914873, 0.02183926131692715, 0.020381098838697653, 0.013134553701092955, 0.044983448315178975, 0.04333064462116454, 0.043584589002421126, 0.02670249010407133, 0.011397261132515268, 0.05011287619709037, 0.012033447746944148, 0.04037747574329842, 0.043194078316446394, 0.07941450661746785, 0.04118504744837992, 0.03325240162666887, 0.027826409677800257, 0.008774951893428806, 0.03652722843980882, 0.019852127516060136, 0.057552171929273754, 0.0784358438977506, 0.02276098090078449, 0.06022282745107077, 0.05489378781931009, 0.04281826215446927, 0.010140901595150353, 0.020262151119823102, 0.028016764990752563, 0.008957213158282684, 0.015029879195935791, 0.0656868155056145, 0.024442527974315453, 0.01816916850657435, 0.07008405533269979, 0.08636338374344632, 0.01962934220500756, 0.024366984762309585, 0.015256051483447663, 0.024806657165754586, 0.01837793279264588, 0.05813443873194046, 0.030491693905787542, 0.028607857784663793, 0.00756383460611687, 0.01679882621829165, 0.029675806435989216, 0.011963406632276019, 0.08159781602444127, 0.037994209487806074, 0.029449304820445832, 0.029323226917767897, 0.028519156294350978, 0.004924587701680139, 0.08315035927807912, 0.03962460774346255, 0.05050524967373349, 0.05168723117094487, 0.005618984669126803, 0.03901229880284518, 0.029760645047645085, 0.03421331217396073, 0.0025288958067903877, 0.023335603582381736, 0.04676593860494904, 0.023089576061465777, 0.010758554926724173, 0.023929002600198146, 0.06343027838738635, 0.04800184826308396, 0.1011981959163677, 0.010219823434454156, 0.05735648614063393, 0.021748554172518197, 0.03478459519101307, 0.040122711288859136, 0.04232237763062585, 0.04987094347598031, 0.012971148553333478, 0.06603739864658564, 0.07714724546531215, 0.027835040855279658, 0.05322748074831907, 0.065535944304429, 0.10519762232434005, 0.04656213000998832, 0.04024868343549315, 0.061414909578161314, 0.040333221477339976, 0.038437598195741884, 0.026933431618090253, 0.0017780013399715244, 0.05229728398262523, 0.08243929274613038, 0.07380418188404292, 0.024703808485355694, 0.04283782887796406, 0.005847286456628353, 0.03738579311175272, 0.028448678240238223, 0.005348300219338853, 0.015122358217922738, 0.008524744225724135, 0.03148548159515485, 0.02988970823935233, 0.06570740268216468, 0.04143867270613555, 0.07275773139554076, 0.0674200568755623, 0.04413121787365526, 0.03341535499203019, 0.02784780579531798, 0.0788214044587221, 0.035763380365096964, 0.0855436445272062, 0.02122408026480116, 0.009082373580895364, 0.029942142828076612, 0.06570763274794444, 0.05626126170682255, 0.041105915952357464, 0.033689255724311806, 0.04831127189390827, 0.039578817231813446, 0.0680459025898017, 0.03112199621682521, 0.011223862038605148, 0.043977103487122804, 0.03706864001287613, 0.014012576557433931, 0.09424560805200599, 0.04008375595731195, 0.03470548595942091, 0.07056299291434698, 0.03660453425254673, 0.2343988386564888, 0.10483572885277681, 0.09090630715945736, 0.0926386060018558, 0.12239709511050023, 0.10698495141696185, 0.18481572973541915, 0.15895350108621642, 0.12983894383069128, 0.21983677317621186, 0.14465543237747625, 0.1301595664699562, 0.11111273968708701, 0.16512423637323081, 0.12846605968661606, 0.13535627746023238, 0.11460208057542332, 0.13485298259183764, 0.12418281374266371, 0.08926447611884214, 0.13606235675979406, 0.15170727507211268, 0.18847582396119833, 0.1004257240856532, 0.10246574704069644, 0.061031608856865205, 0.13360792596358806, 0.21073679585242644, 0.10324451970518567, 0.15549485542578623, 0.10476621187990531, 0.1948175797588192, 0.2350779779953882, 0.08528887265129015, 0.1007677279994823, 0.14363128342665732, 0.16268497507553548, 0.13067878782749176, 0.09346387421828695, 0.20487096451688558, 0.12815769732696936, 0.1031889402656816, 0.10857276894967072, 0.11182301212102175, 0.1436882358393632, 0.10947027782094665, 0.10498397285118699, 0.13710642495425418, 0.14080779743380845, 0.11225321286474355, 0.18308784667169675, 0.07922965247416869, 0.13808827148750424, 0.10368483592174016, 0.11704499323968776, 0.17961486271815374, 0.20290054759243503, 0.08656590842292644, 0.10072761491755955, 0.10494063142687082, 0.12700380611931905, 0.1669188088271767, 0.22350756917148829, 0.09666777026723139, 0.16865691868588328, 0.13784674694761634, 0.11736583852325566, 0.16147784219356254, 0.15546868729870766, 0.16574387031141669, 0.18521862686611712, 0.20020012452732772, 0.19932738854549825, 0.1258414692711085, 0.09704818032332696, 0.13680797768756747, 0.17732993845129386, 0.12042246278724633, 0.14640697510913014, 0.10239008508506231, 0.2559071243740618, 0.2171763963997364, 0.18716820428380743, 0.11283205094514415, 0.11753190148738213, 0.11382181619410403, 0.1524858028278686, 0.17274309473577887, 0.11597554359468631, 0.21115689596626908, 0.1319516749936156, 0.12208519270643592, 0.2016117933089845, 0.11021791739040054, 0.15455195680260658, 0.21524019248317927, 0.24739893560763448, 0.14769826753763482, 0.12806497339624912, 0.1067799331212882, 0.10368096933234483, 0.06250068647204898, 0.11870259491843171, 0.07498238584958017, 0.13465098483720794, 0.18861508055124432, 0.07938217866467312, 0.12407136542606167, 0.13816155114909634, 0.12026573604089208, 0.17978364194277674, 0.35683318215887994, 0.17854066332802176, 0.24604641599580646, 0.15451578452484682, 0.18959023291245103, 0.11009255380486138, 0.10730287263868377, 0.05131128513312433, 0.08752395428018644, 0.13115627079969272, 0.1922697719419375, 0.13706446392461658, 0.12203572114231065, 0.13659020187333226, 0.21218006528215483, 0.17161871131975204, 0.08180074888514355, 0.2349531339132227, 0.10400194820249453, 0.12777704978361726, 0.13234529527835548, 0.10151949391001835, 0.2124129215371795, 0.13165131298592314, 0.179771366820205, 0.1555704209022224, 0.19457022193819284, 0.14410432835575193, 0.18044259486487135, 0.17240813380340114, 0.15569646726362407, 0.18993789941305295, 0.1288245021714829, 0.12270830731722526, 0.13419416325632483, 0.14203357306541875, 0.13825317670125514, 0.17702018085401505, 0.1282008457928896, 0.11083525809226558, 0.1490418368484825, 0.2401779723004438, 0.13214007660280913, 0.13210362230893224, 0.15447569370735437, 0.13003718631807715, 0.22598649084102362, 0.11817444552434608, 0.19170832238160074, 0.2314213421777822, 0.14796014176681638, 0.1009886950487271, 0.13867437519365922, 0.17726825113641098, 0.10555031316471286, 0.12749488523695618, 0.09060332537046634, 0.08397513025556691, 0.10587305092485622, 0.08456836600089446, 0.20019648800371215, 0.09123516021645628, 0.09058062307303771, 0.17337295546894893, 0.10873279083170928], [0.039740623979014345, 0.008378568036278011, 0.05229746951954439, 0.05282341473503038, 0.1000107076833956, 0.026785067020682618, 0.0320055490010418, 0.03608821098168846, 0.05021135919378139, 0.010355565027566627, 0.03506398781610187, 0.017043185762304347, 0.08900903631001711, 0.03711342862516176, 0.05270177673082799, 0.0216427851410117, 0.030093982531980146, 0.03405710122024175, 0.06693487783195451, 0.04509647740633227, 0.033364135670126416, 0.05326388680259697, 0.04240605478116777, 0.054718303290428594, 0.06370554838213138, 0.03445783499046229, 0.04766294652654324, 0.03769302369619254, 0.014908688335708575, 0.027433043578639627, 0.0642661890015006, 0.05132503712957259, 0.02467517086188309, 0.0056635237342561595, 0.06580735513125546, 0.09024448954733089, 0.03853916481602937, 0.007380233300864347, 0.04408861859701574, 0.025364857974636834, 0.0604051657137461, 0.06850346631836146, 0.0435030158405425, 0.04348431000835262, 0.040938865931821056, 0.05927116406382993, 0.08482051809551194, 0.01901487361465115, 0.09119991562329233, 0.006723852848153911, 0.06765939207980409, 0.022659247297269758, 0.048409740047645755, 0.017001170926960185, 0.014473982755589532, 0.026338462957937736, 0.03406170624657534, 0.01959590288606705, 0.047744215407874435, 0.009057866009243298, 0.009971547206077958, 0.04023355104436632, 0.11068711799453013, 0.018726931448327377, 0.013058232161711203, 0.01446933783881832, 0.014321407397801522, 0.025041185108420905, 0.05010259374103043, 0.038253196762525477, 0.06512051229947247, 0.0690014028805308, 0.02877015806006966, 0.03544537379639223, 0.07835460099158809, 0.03269302636908833, 0.11978704336797819, 0.053377947479020804, 0.02701107325265184, 0.052586740130209364, 0.03147973366139922, 0.026860639918595552, 0.04955055090249516, 0.036974301910959184, 0.00886731217178749, 0.04469310530112125, 0.016741742074373178, 0.013716350167669589, 0.04758295413921587, 0.038306716742226854, 0.048992296287906356, 0.016810500201245304, 0.051400372540229, 0.04003820664365776, 0.06091423078032676, 0.046322416310431436, 0.05384440955822356, 0.07642384443897754, 0.09188579366309568, 0.07023900834610686, 0.04951842704031151, 0.08066584181506187, 0.04288880700187292, 0.0996459495218005, 0.022558304081030656, 0.059934365781373344, 0.0715366832446307, 0.04256523803633172, 0.0504031078889966, 0.06517575777252205, 0.04472108426853083, 0.013688008475583047, 0.04223038471536711, 0.0693622202379629, 0.03168405433825683, 0.033815624919952825, 0.01852543278801022, 0.01955538162292214, 0.05698177577869501, 0.014284778699220624, 0.0042510951789154205, 0.03578343690605834, 0.06603017754969187, 0.026721190370153636, 0.012463341427064734, 0.014753250143257901, 0.02332044707145542, 0.08781238997471519, 0.0692483970487956, 0.051207803771831095, 0.003275488020335615, 0.038061125233070925, 0.071400372980861, 0.04752736727823503, 0.09720447662402876, 0.04015909136796836, 0.058345145589555614, 0.04688054475991521, 0.05178575127501972, 0.02681740981643088, 0.024763098663243, 0.04970944472006522, 0.015197012708085822, 0.02507373756088782, 0.03478606835415121, 0.032409110353910364, 0.05374944434151985, 0.08105306478682905, 0.021612772688968107, 0.06283536538830958, 0.033085537143051624, 0.09888911474263296, 0.019488428770273458, 0.056728740528342314, 0.023235810695041437, 0.012243092405697098, 0.02556501520302845, 0.029507090293918736, 0.04611832569935359, 0.044962367610423826, 0.045425022472045384, 0.01804256738978438, 0.014339372009999352, 0.021064780121378135, 0.026449269316799473, 0.025855944513750728, 0.04067179666890297, 0.04341778389061801, 0.020827430162171368, 0.015498767170356587, 0.08245083314250223, 0.06250403355807066, 0.010486516985110939, 0.025212300242856145, 0.025887532174238004, 0.0546970778668765, 0.08654070508782752, 0.0036443354156290297, 0.025376643279741984, 0.05683332768967375, 0.03833260285318829, 0.0009461445336000907, 0.016313174055540003, 0.052079374581808224, 0.05228041125519667, 0.028806484333472326, 0.05666877128533088, 0.009892153175314888, 0.11147714161779732, 0.05610080195765477, 0.026955200664815493, 0.04790312406839803, 0.01812668240745552, 0.043997486573061906, 0.0745956230093725, 0.047612038906663656, 0.03790119240875356, 0.011623789650911931, 0.02905520399508532, 0.02485883014742285, 0.029291646678757388, 0.05884698584850412, 0.02446268841595156, 0.04771911968418863, 0.04457600552996155, 0.016239131837210152, 0.03187684946169611, 0.0022717643651049, 0.0022335780840876396, 0.033934698803932406, 0.07873551570810378, 0.11935740665649064, 0.017959983051696327, 0.017644458966969978, 0.02554893471824471, 0.022757708029530477, 0.025649330600572284, 0.026032757486973424, 0.09786767463083379, 0.036589164374163374, 0.04682745522586629, 0.03105884687101934, 0.03316672067740001, 0.0339218633598648, 0.0633789217681624, 0.028433200750441756, 0.04715971474070102, 0.030145309465297032, 0.05369579448597506, 0.04924464134091977, 0.01872646389529109, 0.0154113208373019, 0.029804528239765204, 0.08169017630279996, 0.00409237622989167, 0.06349658928229474, 0.03497064419207163, 0.10992120674927719, 0.05198496226512361, 0.015508556098211557, 0.05348414881154895, 0.02020638985413825, 0.01883187855128199, 0.029430456124828197, 0.036164470366202295, 0.024726520059630275, 0.006075742703615106, 0.04398212411615532, 0.044808423917857, 0.03235132302506827, 0.08131577764288522, 0.05364198506867979, 0.04089104935701471, 0.06516105582704768, 0.04217076057102531, 0.06770120467990637, 0.03962660412071273, 0.014745465014129877, 0.08376563680940308, 0.02096257154335035, 0.05298491349094547, 0.041707500859047286, 0.04632388947356958, 0.01630261143873213, 0.07522857849835418, 0.0735869404161349, 0.0881713668059092, 0.055750905303284526, 0.04049991526699159, 0.04566001982311718, 0.05657068904838525, 0.037183587555773556, 0.01910921542730648, 0.030412673731916584, 0.025487165767117403, 0.051672455010702834, 0.01598634149559075, 0.05455264850752428, 0.03772438685700763, 0.013475277410179842, 0.03720087588590104, 0.035311672181705944, 0.012744019823003327, 0.04732061606773641, 0.09130705948336981, 0.04199785129458178, 0.051370627261349, 0.01212314371514367, 0.013247276656329632, 0.10844164629816078, 0.015032651117508067, 0.08505827252520248, 0.02145889578969218, 0.037171765143284574, 0.0720842249575071, 0.03135244420263916, 0.034963282087119296, 0.02769189355603885, 0.021118070035299752, 0.023008173593552783, 0.033926149262697436, 0.03378315224836115, 0.031055822619237006, 0.0527749413595302, 0.03742868182598613, 0.03313517940114252, 0.047743250615894794, 0.044190749249537475, 0.043136495078215376, 0.0465159238956403, 0.06235104723600671, 0.040893891782616265, 0.029672513155674096, 0.052675701372209005, 0.06154732356662862, 0.05168973220861517, 0.05676975160895381, 0.054412408571806736, 0.016081722314993385, 0.015714179244241677, 0.03522761653584894, 0.05736420818720944, 0.09575118820066564, 0.04878928179095965, 0.05938849390076939, 0.06355822464684024, 0.036284219604567625, 0.050748944995575584, 0.049607774199103005, 0.037820294601260684, 0.04702623948105611, 0.06074596363760065, 0.009581050435372163, 0.046115164150251076, 0.06483432531240396, 0.08070288982708007, 0.03873649075103458, 0.019123438687529415, 0.07392908533802256, 0.06766515114577487, 0.027646375783660915, 0.03757849546673242, 0.04051707743201405, 0.03483431166387163, 0.03107680684479419, 0.012689600916928612, 0.03368068762938492, 0.06038331317540724, 0.013059790671832161, 0.10330160570447333, 0.04532784936600365, 0.0508128364890581, 0.22226349217817187, 0.12343669557594694, 0.22025132202543318, 0.22105888259829953, 0.17228131560841575, 0.0894310066360049, 0.1548223805730231, 0.08410665366682224, 0.1140099654730875, 0.14638702617958188, 0.22074250504374504, 0.09015215895487927, 0.2180267492076382, 0.13623367412947118, 0.16814200178487226, 0.10910511889960617, 0.12167373119154945, 0.0783491536276415, 0.16599685361143202, 0.2051589178154245, 0.0860817387001589, 0.1423082419205457, 0.11475312247057445, 0.14899292931659147, 0.18242736492538825, 0.16280316951451823, 0.2012270936393179, 0.24454779719235376, 0.13800837186863646, 0.06891379234730266, 0.17138266382971779, 0.10574626983725466, 0.0393060297210468, 0.17543321679113433, 0.215832723188214, 0.13455919601256028, 0.22292388486675918, 0.14681812492199242, 0.11819052786449902, 0.08447848449577577, 0.1290265444549732, 0.14117303799139336, 0.19155947724357247, 0.1843565035960637, 0.11587664499529637, 0.09117518726270646, 0.15450273756869137, 0.16420003987150267, 0.23729155218461528, 0.071955618186621, 0.17801271431380883, 0.21296255610650405, 0.12743975850753486, 0.23752881679683924, 0.10689287315472029, 0.14873344480292872, 0.11689625200233422, 0.1731597215984948, 0.09821282525081187, 0.19896400335710496, 0.11369507963536307, 0.12631758669158444, 0.22291229252004996, 0.09297823504311964, 0.12853690510382876, 0.1446770882466808, 0.10336405000998639, 0.14009667153004557, 0.13115122419549152, 0.15579926955979317, 0.1311103318585083, 0.38359541329555213, 0.12938797037350014, 0.09690363964182325, 0.20873562432825565, 0.15959731419570744, 0.25960450409911573, 0.15012133517302573, 0.13832624856149778, 0.16159269696800038, 0.1005979988258332, 0.08428807166637853, 0.21473397355293855, 0.15563985623884946, 0.11606527667026967, 0.1719570712884888, 0.10214228939730674, 0.12248075741808861, 0.12350986391538754, 0.16169106122106314, 0.266619551111944, 0.07948259124532342, 0.19178932037902996, 0.19466913538053632, 0.17781073140213266, 0.11323592028929852, 0.17278510029427707, 0.1918959224713035, 0.13878143741749227, 0.18673268234124407, 0.16379081964259967, 0.3211507812375203, 0.14314928819658235, 0.16055996879003942, 0.12401909596519545, 0.13704556884476915, 0.1306331012165174, 0.10955448931781575, 0.1202638509857934, 0.18634085805388168, 0.119196560990531, 0.13924103463068604, 0.15993331413483247, 0.21613350079860538, 0.15118287352379411, 0.2997506858082488, 0.14226206549210474, 0.1403618260519579, 0.16881131508853287, 0.10819723480381072, 0.09764503774931654, 0.09393245883984491, 0.15605259424773976, 0.11736358239431866, 0.2098495583049953, 0.09947913698852062, 0.1598171828663908, 0.15233541402267292, 0.08892080979421735, 0.18756414006929845, 0.10455005394760519, 0.1460786786628887, 0.22236979741137475, 0.15102294069947675, 0.1699260505847633, 0.11336310955812223, 0.21480827737832442, 0.14204326551407576, 0.2538793988060206, 0.10563694406300783, 0.19351928145624697, 0.12796577793778852, 0.12929144664667547, 0.11854760479764082, 0.07553452145657502, 0.09305512154242024, 0.21422583988169208, 0.2153891118359752, 0.1207705597335007, 0.13011908973567188, 0.15457641799002886, 0.1812951741158031, 0.1246788800926879, 0.1659810310229659, 0.16586843237746507, 0.10878396933549084, 0.07216128215077333, 0.12526415259344503, 0.1380501696257852, 0.1097966669476591, 0.15107683546375483, 0.1549105774029158, 0.15822174347704276, 0.20601906697265804, 0.14505387662211433, 0.10234277317067608, 0.11675220855977386, 0.11062352336011827, 0.12481512356316671, 0.11538154343725182, 0.23959655896760523, 0.17486680968431756, 0.1294871509890072, 0.1785703343921341, 0.15673859103117138, 0.1958354946691543], [0.0347485787642654, 0.03909215018211398, 0.02108715401845984, 0.021470079955179244, 0.05362894924473949, 0.052849282292299904, 0.012704346463578986, 0.029447976376104634, 0.05434758939372841, 0.06114206640631892, 0.05912021122639999, 0.014131545613054186, 0.04580870911013335, 0.04134614173381124, 0.02255345414596377, 0.029903039066994097, 0.04291003984690178, 0.06374379867338575, 0.009111463914450724, 0.021025674504926428, 0.03144686394080054, 0.024858264259819407, 0.01385640271109878, 0.05562481070228387, 0.05925213539740071, 0.02583991597930435, 0.021317017562978435, 0.05920644507568795, 0.02481090596120339, 0.06070420298783574, 0.09071978318388574, 0.014621354730479652, 0.05971761784167029, 0.017486157012172043, 0.03602226002840325, 0.02111181373038562, 0.012270354272914119, 0.0690510006097611, 0.038857093459228054, 0.01978326548851328, 0.13024688756559044, 0.07725133167696185, 0.03774497774429619, 0.09136614185990766, 0.016332020895788446, 0.04996317387849558, 0.045112422449165024, 0.026061601056426298, 0.010444496583659202, 0.049238989886362106, 0.018406375602353364, 0.14055281033506617, 0.06520690571051091, 0.027205627266084775, 0.021688993110728916, 0.0328664811240742, 0.014194343366398243, 0.0811542640440166, 0.012300143152970122, 0.06743027624906972, 0.12198832759167999, 0.03343559706991073, 0.049288988375337794, 0.04442427343747113, 0.02441539691062644, 0.04754559071443509, 0.02961849037092179, 0.036205908181727864, 0.021058217680547386, 0.03739826861419715, 0.06543680821778253, 0.08761531265918165, 0.006422966698664823, 0.0582272739848122, 0.036380973397172056, 0.06731491681421176, 0.022379914043995086, 0.024920127834775485, 0.07120163325453177, 0.02073624804324936, 0.085083743033465, 0.05657739064190537, 0.033935763785848394, 0.034590260111144744, 0.03552898415364325, 0.022251112459343858, 0.01775150820321869, 0.010504628171474906, 0.047420241971849464, 0.06673244963167235, 0.02693101592740277, 0.09424372299690731, 0.05487684829859063, 0.04734222369734198, 0.015884077256487217, 0.04715461618616246, 0.05535325144592207, 0.014002128045831341, 0.06708531858748756, 0.07927801081677899, 0.07224890752695501, 0.03360527058248408, 0.06665043489192612, 0.0053223083523334935, 0.018634270600159653, 0.03188945855072234, 0.01401801464453456, 0.045722876020590775, 0.03409722172364127, 0.03827711247140542, 0.004231355442243512, 0.07362207368714735, 0.046318007953232154, 0.038159014511620626, 0.05003630511055235, 0.020911567444272805, 0.03274289869295899, 0.019136231458105613, 0.11273882977548055, 0.05372487554268446, 0.04228068377415184, 0.01174062224890804, 0.10511094689718448, 0.06872965808724985, 0.03652838619018439, 0.014653355210612062, 0.0248969746826333, 0.023177739494713023, 0.03445102207479067, 0.03257341813878156, 0.05386742726841476, 0.054581848307861947, 0.03934484033379704, 0.013795652357657673, 0.07067933940561488, 0.012188643813715316, 0.010362274970248109, 0.03095865136856446, 0.023184910496638622, 0.025042749184649438, 0.03986506359069608, 0.056165684218285605, 0.05860105295141693, 0.02981569014082197, 0.05632600295939483, 0.07524316170020029, 0.03322856755403336, 0.0813379604369402, 0.03489171307592187, 0.03994013924966566, 0.03363953554071486, 0.037419917061924934, 0.026385474302514922, 0.05451396034914069, 0.051671675755642354, 0.0377390665380517, 0.05638175680360291, 0.027808334671135526, 0.026173138430749532, 0.031787446641828865, 0.046041097812121734, 0.02677201078768121, 0.037926892982795835, 0.03160939428198617, 0.02326473219000036, 0.04910874296911061, 0.02915900076914113, 0.007732499725534581, 0.09283975770813413, 0.06730066757882014, 0.01828145916078938, 0.013041523634456098, 0.07899547519627959, 0.036863480709143914, 0.034411836677463725, 0.04111620582989417, 0.0481856671103742, 0.028549781018227804, 0.05305069003952667, 0.011204999427718576, 0.0062790939500700915, 0.07191907483502291, 0.03940277609217446, 0.06315943159279414, 0.0663725525373593, 0.07260455211508088, 0.07877711308537982, 0.09021813588333316, 0.07421289003104903, 0.05251728623989038, 0.032977621449390426, 0.00911671646463219, 0.02578567055024905, 0.08244914104579948, 0.064006095926743, 0.09400908558745869, 0.03830729561741464, 0.031119814302655868, 0.08388184971408918, 0.012862140047218418, 0.03784125285164919, 0.03792445873841643, 0.025610911470721476, 0.03530855887220241, 0.0667381047969684, 0.05794533950393088, 0.06853215032606386, 0.00608038066275185, 0.02880568466935074, 0.04802959716471378, 0.020348785728856456, 0.030904838240530808, 0.004210502484056633, 0.04221343777317088, 0.07919836352812126, 0.0024736524210311472, 0.03636203007772565, 0.0782598287332803, 0.04502442228840664, 0.05727463467337657, 0.07522826679632999, 0.021581212859018706, 0.03177799539116677, 0.02920996405009646, 0.040743202407611534, 0.0366701401071623, 0.020541259873425588, 0.08739384837099351, 0.035320359020261094, 0.006403246907211724, 0.06155278948426712, 0.05459605672513135, 0.0340409780619666, 0.040890014061005786, 0.05855723284184933, 0.08504850586177781, 0.02381506623351015, 0.06524272175738588, 0.013855525121471146, 0.04035862519231159, 0.02124392158293631, 0.09255090641090646, 0.05240627579041757, 0.07134919447707944, 0.07264804939040914, 0.09099848190089688, 0.02135593578714179, 0.02418084299279144, 0.02778442267299397, 0.023642991873202845, 0.04521178860159125, 0.07448716554790735, 0.0827248563291505, 0.03087352517468389, 0.057695068753673695, 0.02449692925438285, 0.07689308215049095, 0.08250429746112786, 0.03566674160538241, 0.056460428168065846, 0.03450986696407199, 0.05292393121635541, 0.018351592116232496, 0.06349238872644491, 0.021106974927533884, 0.009996793214668287, 0.029769894063065294, 0.04522747760347556, 0.026751163859444205, 0.03371356477146037, 0.05952964667812921, 0.052996925151092, 0.008503490971634164, 0.05509770031494554, 0.04770128216478042, 0.05043377343099564, 0.055604668814339675, 0.060343660225044005, 0.03905741024937015, 0.006877373052702751, 0.02359997513849521, 0.053939949939376675, 0.09725083116791211, 0.03788850910495967, 0.015120909174584085, 0.03586866885598283, 0.019927442517655436, 0.06828928249888122, 0.07763960107695311, 0.07064019853714854, 0.04714766597317066, 0.07474611571524292, 0.035592601052485406, 0.05449908028822392, 0.020281022079871036, 0.023099828831618652, 0.061904960821266286, 0.047190855257213116, 0.035094104168820195, 0.029403484622889664, 0.020320877265476156, 0.027022704562114086, 0.05668691679602489, 0.03252662943850737, 0.030621105906902812, 0.008782786189840408, 0.0371756762615405, 0.04394674222567119, 0.05440596301923506, 0.07799150524078868, 0.02926130582636688, 0.020735652469738852, 0.0494480491761351, 0.04061701874888968, 0.05449166252219584, 0.04753819892357569, 0.04594208046910353, 0.09388666090671904, 0.028397351306921337, 0.061215691166580655, 0.11041328776627779, 0.04850889839872252, 0.03655488086224068, 0.0704406647128053, 0.093809121317463, 0.017771976636140607, 0.029722945801040623, 0.04574898848659359, 0.08830708335153759, 0.03859580181597266, 0.04484816221520305, 0.07400404225336388, 0.07450344826793298, 0.07554989875643514, 0.023381620449072216, 0.023335490404861048, 0.016185027416213416, 0.037712044941144995, 0.025294493098044768, 0.07168466749135405, 0.007706504611633136, 0.053036489043734036, 0.030538781320501585, 0.04315617312386166, 0.12757134129060432, 0.0685750093543902, 0.042531859944574535, 0.02461269687046297, 0.012448991074052174, 0.02788594847515924, 0.05226019144174643, 0.029195304778113496, 0.1890450660721399, 0.17036126082530245, 0.14324272458907217, 0.12847331789089367, 0.12738684337818995, 0.2486200802377425, 0.153959262825083, 0.11863539344631135, 0.15856091980822384, 0.16706784692360088, 0.17981770652113482, 0.14817011018749326, 0.25685051281470805, 0.20483130414504558, 0.1799632713664323, 0.14492241258267313, 0.07783270048093982, 0.15799786720890552, 0.14907599048456177, 0.1297759503358975, 0.17133065412053838, 0.1453759241849184, 0.2419819700298831, 0.15111802465980873, 0.24197965452913195, 0.1031773627619259, 0.10680666528060101, 0.1833850471302867, 0.15933840855723247, 0.21384747815318406, 0.22645416262093931, 0.16106825089082122, 0.1783585106022656, 0.16614065214525908, 0.13812839199090376, 0.1700389015604742, 0.08656409016111866, 0.14314109488623217, 0.18744650966254994, 0.044619001855608076, 0.13966331665869802, 0.16935636318521574, 0.1379291104967706, 0.1361296695540659, 0.23488176899263635, 0.14734432246768847, 0.14953067468013614, 0.15440438815858215, 0.1530815099249594, 0.10512702181586064, 0.1209155011747498, 0.2184557996224612, 0.2637497254181653, 0.08970156399300322, 0.10534942121012136, 0.1186188509745989, 0.17599410231923684, 0.135411997907795, 0.0975225240108557, 0.26188444113358855, 0.15669404732761905, 0.24195139354560524, 0.1657971416716464, 0.1237223185307812, 0.10731341855716892, 0.1452565868385136, 0.1049796535517089, 0.15861382009461522, 0.14813004905590788, 0.1482106908224523, 0.1469197843107395, 0.13895459531340748, 0.06292469770414755, 0.1619345005019568, 0.09780523032532074, 0.15888930531218648, 0.18347229401115328, 0.10409017471829429, 0.20329710678197443, 0.11332244728691876, 0.13796525308862329, 0.17488558602053672, 0.1553885205066763, 0.1243555783003103, 0.1935890136519447, 0.14799932716414332, 0.07875947223510593, 0.06278961940552108, 0.15014799311757088, 0.13324173545697704, 0.10547020574449562, 0.20045503741130233, 0.20778097008587793, 0.14550474617863074, 0.15221419162116945, 0.10706750050303526, 0.15304668835597113, 0.13188302633352578, 0.16631257807603106, 0.27267164667136967, 0.15903153049293905, 0.21189865772612393, 0.18261674616951495, 0.06438267650082707, 0.16785951069323346, 0.11639554722933099, 0.19195628876332194, 0.0960598028905224, 0.09449879173189402, 0.1722383897867985, 0.11761824294808321, 0.14879032300086692, 0.1124604650249239, 0.18836729228496552, 0.10908565236604773, 0.15097338007763028, 0.09617461313609965, 0.11474921135231853, 0.1618246774887666, 0.13485871197190136, 0.09659757051849738, 0.10157554832403548, 0.18803135171765462, 0.14958427258534357, 0.11567049863515422, 0.11468690805486403, 0.0737787781690713, 0.15117025701329112, 0.10628736228682101, 0.21144630387425423, 0.14491858310066164, 0.1244123229116667, 0.14059350971365348, 0.12938198866322637, 0.22732480574632064, 0.07800871564541012, 0.11326410705805756, 0.13624970451928675, 0.14050917205167934, 0.08382320520468056, 0.13137450674548745, 0.17853949073469266, 0.15708551538409665, 0.18934636318590492, 0.20238583849277347, 0.1998329840716906, 0.11471206686110236, 0.2828719618264586, 0.12119917228119448, 0.10492970701307058, 0.08369941497221589, 0.115377342881402, 0.2578021539375186, 0.14638303342508152, 0.091528204648057, 0.1557808939833194, 0.12454968702513725, 0.19160954252583906, 0.12900481437100098, 0.07943689721287228, 0.15996179776266217, 0.10974066448397934, 0.11773947277106345, 0.130823120707646, 0.2264707422000356, 0.13905864441767335, 0.0569281296338886, 0.19261984300101176, 0.19711185508640483, 0.11701549286954105, 0.1831422164104879, 0.11925464888918214, 0.14190151530783623, 0.09820358551223762, 0.09541707331663929, 0.08993549636215903], [0.066627843916649, 0.056406778312521055, 0.034018561491393484, 0.021641519779223017, 0.03072960789722856, 0.05217104837356601, 0.01660932623053668, 0.05613135246676393, 0.01854109581472585, 0.03895591042237356, 0.04330023512011394, 0.02808913737680996, 0.026344452089688275, 0.029563413736468647, 0.03156344420858659, 0.09574883559253067, 0.03464946865278762, 0.06068793140002526, 0.054015712084947154, 0.04415563824295532, 0.04394166222482454, 0.07960828879731707, 0.03838423035631422, 0.055829947741585784, 0.06617585371714085, 0.038750346648157574, 0.011833087355626049, 0.01444735635232064, 0.03485567067400552, 0.059766258200397715, 0.04178959352429956, 0.019899522922059987, 0.018165491164836567, 0.03982763708336279, 0.011115082670585252, 0.016270988526230212, 0.044000251073157415, 0.028354314163152594, 0.08730303175980225, 0.028575329451996367, 0.0372346361837117, 0.055564585418323986, 0.05038682145823259, 0.017624465508561116, 0.03580098498787265, 0.021893180201004725, 0.03415863815462217, 0.042881214831140824, 0.048024465213529766, 0.02189793551224284, 0.09032764719449915, 0.026246022898703814, 0.014746634824405191, 0.017290966607106384, 0.02806342010444496, 0.01685437968262704, 0.042715849485830404, 0.03970083002059255, 0.02448477658617776, 0.03499428159557283, 0.034906533765024506, 0.010769041473395191, 0.015079402710398426, 0.04126539977733046, 0.020861244265688583, 0.05296130577335134, 0.06609448464587331, 0.039088112898753025, 0.04226695775287226, 0.020672883474617265, 0.02055987479252508, 0.04288504431315232, 0.007823720807209611, 0.06614227153477259, 0.04460516822291538, 0.05797761550638825, 0.03690355668368284, 0.0321597858419409, 0.012961375396116637, 0.05787426031020004, 0.01621064449864207, 0.05736453844292555, 0.04774085718963761, 0.04904695917502977, 0.06983159895753488, 0.04557501422823407, 0.05440557339170482, 0.043570621783146635, 0.029769586071779486, 0.01967664484254783, 0.029807177706970833, 0.03636851644841954, 0.05250385707768146, 0.03389073768630624, 0.013345247571123764, 0.07498828592360951, 0.03488468864816241, 0.007900552573119057, 0.07278764736838639, 0.06217784852196928, 0.016819201882753987, 0.028539353843370918, 0.026517643382248934, 0.04812312632566318, 0.05125573537952732, 0.027829096252389718, 0.02684904757188633, 0.07280617137439549, 0.040484155761078, 0.029104349014232866, 0.01352724815660622, 0.047503039677394554, 0.025190176820615306, 0.009284459465561667, 0.03283964135334827, 0.008984713440440828, 0.06642402790021151, 0.0742212837212719, 0.02672460424946621, 0.0910090352408588, 0.00898192667591502, 0.07129798628739081, 0.02035978621279355, 0.039565618135384284, 0.04326214439061005, 0.011057490155508276, 0.022010235443303827, 0.05502491047082003, 0.04312546305300202, 0.009285051328333793, 0.05892553846933879, 0.08213432942284271, 0.029502006582333706, 0.04423158221470658, 0.02356031291128602, 0.03420945300604217, 0.023084423701220658, 0.021827835953445174, 0.029486755447578616, 0.015618028446624521, 0.03468925518973265, 0.02329003757040482, 0.032605426968075335, 0.03189255701727234, 0.00882077951246174, 0.06778364986530505, 0.01734980964101851, 0.033539850264787674, 0.01842340232542483, 0.05983787174045574, 0.010838139132829383, 0.04785479170095641, 0.038158461611601524, 0.05109221798193175, 0.05872765963431448, 0.020498539997788612, 0.022613445653405506, 0.06722033009282313, 0.029694948279939126, 0.046116496305330656, 0.08934738885727711, 0.025037570849235635, 0.0444692735618446, 0.046838776688673533, 0.05053077584307175, 0.042595885024638847, 0.03724811729625799, 0.03714305887115188, 0.06353611606755294, 0.09969021120923571, 0.06520244540297426, 0.04875688704487402, 0.05201261839829385, 0.016426498150394764, 0.033308441197732463, 0.019459770737739746, 0.017200309557665605, 0.08585113115259446, 0.05426181567599997, 0.04502143514400814, 0.004481266250877525, 0.07967048077262007, 0.011286060507700313, 0.04379639423859771, 0.010641562766977586, 0.047775715866009705, 0.061383490756270476, 0.03916121815564111, 0.04246972363034729, 0.02698790154681774, 0.015118284754862543, 0.012222466266393894, 0.025912206729117315, 0.04046611415105872, 0.0479326986533124, 0.04714707967650611, 0.012498743726609973, 0.021275475846778136, 0.06276595231611282, 0.05608748040685896, 0.07817036283086054, 0.02825147475959966, 0.05236515338765457, 0.009085994333872804, 0.014063538910704665, 0.06608976458664984, 0.020108008902752772, 0.03326550795463845, 0.030202504931367002, 0.0177004039142048, 0.01684487833699677, 0.03295356473245192, 0.028740551933879033, 0.017180384747916833, 0.036788739016628824, 0.03179604442266282, 0.04920296232739929, 0.07371418905677274, 0.018712351957219653, 0.0454838450968964, 0.028435939275368582, 0.024847161730576772, 0.044967703652218916, 0.01254451753993635, 0.060936428417335264, 0.03368230180058163, 0.1262721375678666, 0.07474599697161466, 0.04231135673762765, 0.007526767576564453, 0.03145502385450527, 0.050684233428910375, 0.013270981780806324, 0.07925423240521923, 0.058059953080373816, 0.015848038565309253, 0.04085140011738986, 0.07841455910238437, 0.021792836269014515, 0.046556107481592335, 0.03139506574370898, 0.01180268434836762, 0.061927637143526226, 0.01351573930151062, 0.030183986491465475, 0.044972694595344365, 0.01249074151928653, 0.0751198390207719, 0.012028626570099732, 0.051231522811576724, 0.06490820611361414, 0.027887766736967023, 0.036035299563081935, 0.04122178004763555, 0.04260506168066058, 0.02255332798085874, 0.032731269238865934, 0.012674275567405857, 0.06125066487584263, 0.07712881793850102, 0.0059038483141193865, 0.02098722197843017, 0.07122540424461477, 0.024809011629258748, 0.03637758178228978, 0.03932408617401961, 0.050764656261890195, 0.01674709110375261, 0.041907543054549024, 0.047824716166360304, 0.07953232256113552, 0.09164708186290227, 0.05620463954983279, 0.009343711608380545, 0.07641833028174005, 0.02695951068744762, 0.020909270497213583, 0.009479263026150875, 0.034442305550328456, 0.03571220186131541, 0.012356637289485661, 0.04529781093879137, 0.06127965316409245, 0.030423045245697722, 0.05215369696088601, 0.0384988773294026, 0.01846150047640549, 0.029350326440180652, 0.022401703499781433, 0.02292209002916934, 0.016559893629164435, 0.05658631125697866, 0.07173047284595668, 0.038329073940985836, 0.0697401218349114, 0.05741144217608962, 0.04374670374090783, 0.012070534721715376, 0.003329020291857887, 0.05800761311547831, 0.02798289708152879, 0.04306061418901663, 0.03678742912597954, 0.016084429298643954, 0.02599525119876489, 0.023692875329288654, 0.05556931660976261, 0.039118129061535, 0.023932433177833445, 0.06518985857837833, 0.0550955851940671, 0.061422575963661075, 0.03505719345412217, 0.02437802049826132, 0.0205996854492696, 0.04393957307911478, 0.02538784970965935, 0.03279704578744713, 0.04629981420293916, 0.050987686481676064, 0.032599092737655155, 0.078359180042753, 0.036529410353978164, 0.02618147831526585, 0.010146523363800952, 0.08286232434329577, 0.027192582165298518, 0.050906083633890375, 0.046860629227012396, 0.03502805302559864, 0.016032696039474104, 0.0281551477019093, 0.09701853152364492, 0.018086799391312525, 0.021344595770642627, 0.043841253354912624, 0.00842898027258343, 0.037139474297873676, 0.021145130594959483, 0.06031963319401257, 0.046408390408032574, 0.07712418693699874, 0.040937110752565786, 0.028322702382865828, 0.03815950061834883, 0.06558497057994828, 0.09897535972413607, 0.03411409445106983, 0.047723283132654615, 0.06030469747202005, 0.011602664417296182, 0.05474269768455997, 0.16237232310231775, 0.1463325970689766, 0.24252195667941123, 0.12416178869898431, 0.09325170904048719, 0.12107558985007927, 0.0565507586725289, 0.20472001167945564, 0.1734332920750603, 0.12783645128365606, 0.14928128337487578, 0.1513946379418485, 0.24665448727319017, 0.08587897653342225, 0.133282731694635, 0.2096737880492583, 0.12374755155178718, 0.12793208443326876, 0.18083762523019686, 0.10922051544184797, 0.14571743085980415, 0.12240171126904897, 0.10544485397986136, 0.14594776381272823, 0.17837143881479278, 0.12190233494038694, 0.13524781999876723, 0.11738765024347231, 0.09620985030778684, 0.1995044352952391, 0.08264506803243421, 0.11917309428099543, 0.07331486907787621, 0.14985913439886644, 0.09380264236824587, 0.12352199060842395, 0.08856161774019711, 0.08988231405965053, 0.16988511371891946, 0.1431029781815596, 0.10588741148239933, 0.25064120069146156, 0.10653468300006352, 0.11147809156682342, 0.1406472412054427, 0.14005303324665874, 0.14891669590724632, 0.08596554063842632, 0.13513345504179597, 0.10010723883169703, 0.21815144486026838, 0.16963511385256425, 0.18893125030444935, 0.10111022915225476, 0.10330130884540267, 0.17396881099557504, 0.09134384774370119, 0.2718921541236341, 0.140524786838796, 0.10669852694263682, 0.10531612104387023, 0.13386417471338063, 0.10504138539545238, 0.14608559547923505, 0.09946216407115571, 0.14770427893381566, 0.19585030793678015, 0.10440518672112375, 0.10771169952931814, 0.18767834175378084, 0.10059870386612602, 0.22699217515764758, 0.11539881321368739, 0.09571393980877474, 0.09647839644458145, 0.13702658470720053, 0.1398681939463131, 0.1387703645741567, 0.15378997894003987, 0.10906182942562737, 0.10502257195184939, 0.16327784716850147, 0.1949143409729004, 0.17014940734952688, 0.14323993411380798, 0.11207684889086522, 0.1921833711094223, 0.21499761409359053, 0.12695387442363426, 0.14419001672649756, 0.1820017135469243, 0.1710162209928967, 0.19379139732336625, 0.08594909464591183, 0.11767002259148285, 0.22046820726245642, 0.16257207957096398, 0.08415681542828679, 0.19284665817394853, 0.09192440018523484, 0.15919495141133666, 0.064925943443086, 0.12910449964692816, 0.13921354548074305, 0.10415927608846687, 0.10326148520107381, 0.20123427762882784, 0.1473359955707565, 0.10230297921225429, 0.19854161742841825, 0.09663460368756205, 0.13409683801000938, 0.09163993498077616, 0.08918371560866944, 0.14614585787057877, 0.1337501363013871, 0.20156198035692796, 0.10538764923694544, 0.24482305976562202, 0.14969581738114357, 0.2058021372067742, 0.09634875066694804, 0.06482143420726061, 0.09394978798809461, 0.09137450586422347, 0.12773612776072696, 0.07736019731964916, 0.13178782362956554, 0.18753614625893533, 0.08105693879770115, 0.1658768780180253, 0.1383600162807852, 0.13398547132965177, 0.14690124546177685, 0.13337946322280914, 0.144315499055665, 0.1078605224029161, 0.12631240650080144, 0.09334472240880132, 0.11465683623100631, 0.15728871541796252, 0.07734451573924161, 0.17403894395101815, 0.16311870102072135, 0.0782254153455142, 0.18461868952726945, 0.1120976364472881, 0.09329365522717126, 0.09660609037382528, 0.16255576716503128, 0.10731458372902125, 0.16009001119527966, 0.170060230884701, 0.16302320145769045, 0.1044408320740331, 0.12868815480032936, 0.15787239972269163, 0.10086195848998614, 0.11052581219701096, 0.09428187680896372, 0.11448254284914583, 0.1478464002138935, 0.15644634811906144, 0.13684254692634568, 0.1715740340296179, 0.14350732992170379, 0.12471288529923186, 0.09702202703920193, 0.13377502793446183, 0.2510752680245787, 0.13411439722403884, 0.12818558723665774, 0.23198899609269574, 0.11708420832292177, 0.12747367465635762, 0.13889559457311407], [0.009508922030363465, 0.02074519648886053, 0.0703426195832435, 0.053560345113510266, 0.08359104656847194, 0.02217721124907257, 0.016749827773310244, 0.06785351564758457, 0.0037118750287845614, 0.030108042519714218, 0.017182891351694707, 0.024098856083583087, 0.04187018334050663, 0.03044982749997871, 0.024343894692719914, 0.08167324049281888, 0.038577615487156436, 0.029170891830290202, 0.050988870207220316, 0.013193512695579557, 0.0924862727697473, 0.019560099826776423, 0.018826616724254563, 0.01797056607756531, 0.03814323645201512, 0.0530930666718632, 0.02763720098300837, 0.06661372826783918, 0.028336736395431217, 0.02616144403873477, 0.03155350685119629, 0.056061174982460216, 0.02189492053730646, 0.039727417461108416, 0.03842668862489518, 0.03527686174493283, 0.029227367413113825, 0.016177316501853056, 0.03702369926031679, 0.03025483190867817, 0.02402037767751608, 0.06343413013382815, 0.1478639742708765, 0.014553240416717017, 0.025411275601072703, 0.03024667385034263, 0.02480809693224728, 0.04596627077262383, 0.01826268467993941, 0.04423260637850035, 0.08113679388770834, 0.004341314825069276, 0.061123828127165325, 0.012996105124329915, 0.0093744847617927, 0.028405334960552864, 0.06611528704524972, 0.030863454230711795, 0.053988657091395, 0.026742796144390013, 0.007012720379862003, 0.02012624161579879, 0.02697704763704678, 0.021648898582498077, 0.0062556569264415884, 0.07081688905600458, 0.06255232510739006, 0.0548451400391059, 0.03876664050039835, 0.04201729556370992, 0.010194676688115578, 0.06581380439456552, 0.02273797246743925, 0.035443540691630915, 0.052690596276079305, 0.023836234140617307, 0.06257965840632096, 0.09842174724326469, 0.005887801689823391, 0.04683178565755952, 0.029527861152018886, 0.03523973580740858, 0.02360594386118464, 0.05573413276579231, 0.021999505843268707, 0.030510609394696075, 0.030526194495905656, 0.02363209343457129, 0.023047629874781705, 0.05504243257746566, 0.020502295265032444, 0.03155509133648593, 0.056669528275961056, 0.02638628880959004, 0.048375107726315036, 0.004981494657840813, 0.03974007850047201, 0.014871157927700551, 0.02154744328436209, 0.024879029551811982, 0.022785100700275507, 0.010532447577134008, 0.03431417004321702, 0.042903802095679566, 0.03494440927170217, 0.015046452281239908, 0.025705353473313153, 0.024527522436983418, 0.1568893063813448, 0.04454488727787975, 0.08043582056416199, 0.03976487736508716, 0.07803863161825575, 0.04021590648335405, 0.02337873163924087, 0.11036913740099408, 0.048391676173196174, 0.0376418860105332, 0.03874793466820847, 0.06195263267727569, 0.01459674882426043, 0.06222697869816329, 0.026086008438142017, 0.03882359291310422, 0.053459954797290266, 0.03748181588889565, 0.04320493964769412, 0.05734573242079932, 0.034856694837799296, 0.02800001842842903, 0.0344802515610354, 0.0249406630609883, 0.017787005126592703, 0.04388714405649807, 0.023678305115026888, 0.047890782152535394, 0.04205734185234178, 0.07771282136673108, 0.027171839137736242, 0.0159551026445115, 0.0457974989694776, 0.05755719255830627, 0.0075961556012771325, 0.05380833747040015, 0.08463579011731781, 0.04661365361243952, 0.05911395863222424, 0.04107453794858884, 0.025518298862152733, 0.07803467597113922, 0.05893310095416382, 0.012350166689429898, 0.026368226790509652, 0.007807541060174117, 0.05055577137682121, 0.029808209292241372, 0.07321004071854986, 0.04861455425270833, 0.022859896198497154, 0.03460646861640271, 0.05444517810246907, 0.05185726833587978, 0.041956970089813694, 0.03660184767795727, 0.07903889083536342, 0.06198077491717413, 0.030532558412232902, 0.04755912748805713, 0.10838712070835754, 0.019803101240540855, 0.076097870914964, 0.007583199558212073, 0.04540000096312724, 0.03543017461197451, 0.032179801564780064, 0.01704677961242851, 0.014259227482398273, 0.04181739808700513, 0.027282254013698548, 0.06623174485866912, 0.041292284076916985, 0.03979425528086722, 0.03970249614212662, 0.0395304032281274, 0.02275824052048847, 0.05424649774795398, 0.04382603561680298, 0.013622758851852268, 0.0551228516997071, 0.012862563999078702, 0.019886691188730765, 0.03155941805744078, 0.03713304358825553, 0.044637292085099034, 0.08179388401913457, 0.02191028299421305, 0.14057943859370425, 0.04520635979133658, 0.04801109913387336, 0.010713609535741853, 0.01452291255191085, 0.03256991891248617, 0.007768447039779858, 0.01411105955412495, 0.05792854099126998, 0.05077340247225948, 0.009630276163079543, 0.033807776708272286, 0.00790504906035494, 0.07297690244740807, 0.019297925027785823, 0.054497625678777695, 0.032570553448749706, 0.05086718396341894, 0.017709339372231625, 0.054561524593736976, 0.056859555188566446, 0.05745279835537076, 0.037969054392306134, 0.043216825142735615, 0.008867848373483866, 0.00505857411553734, 0.01995464408537373, 0.04070567199960351, 0.019553468737285584, 0.02170895502786152, 0.05631228435959201, 0.02646270404511597, 0.03476378165942151, 0.07324851365410723, 0.02999978358275257, 0.0478316663793521, 0.047006784079712816, 0.06014220794895664, 0.045575893673230894, 0.03467718415777199, 0.030793440018896945, 0.04495310931815766, 0.01639768983295653, 0.07695269145187922, 0.02980413304612739, 0.06020714958140161, 0.07947905120090581, 0.005231038567217183, 0.049393393710488454, 0.036801511378143914, 0.02822303937136894, 0.016920493908401113, 0.08262359027867205, 0.04604958798154257, 0.05052168453403283, 0.05841977595991921, 0.037453517797985114, 0.050612360137165524, 0.050975923441001214, 0.08589885866967961, 0.03442548477323726, 0.057654985357658006, 0.04813306739379186, 0.04737955372547731, 0.0059476535807334585, 0.025469552747381385, 0.05407223405200057, 0.008847307581163477, 0.033956755432882346, 0.036936044198228046, 0.037771880597574636, 0.018078882530971896, 0.044784022102248855, 0.04174979585513938, 0.04912114796752576, 0.043316491864970885, 0.11765967705287039, 0.052583678771043196, 0.014168454472383019, 0.02098097680573119, 0.0566071730281692, 0.009559881600580411, 0.06721422221744433, 0.0558200066734571, 0.02906037676439155, 0.036379975208546966, 0.012462721733754734, 0.08097393700154498, 0.05420885601779446, 0.05171154021809343, 0.04685951971623581, 0.0880943244555965, 0.10108604998094961, 0.06756430069799535, 0.04559780558338389, 0.057387507913517766, 0.035446179026621394, 0.04232545383274555, 0.04951613380399067, 0.0385442485276144, 0.07149527882575057, 0.07469184987712651, 0.045379476869129576, 0.0310488519971841, 0.01064318621502025, 0.08747089814278297, 0.02951064147055149, 0.028604660983546637, 0.021611739248328377, 0.03372439641680103, 0.020191752846585587, 0.006517341907965601, 0.029306317082955502, 0.04315063670219388, 0.07572537957457826, 0.007900832733866991, 0.012995213619433343, 0.024507089256076142, 0.05105080985231325, 0.056613755878061056, 0.03951197941205464, 0.03735284546564799, 0.019808734141406603, 0.033737302364897914, 0.021899299208598677, 0.019921219609386753, 0.05714325969165657, 0.05956071297987364, 0.003617295033109258, 0.04517705980106257, 0.01947712771652732, 0.05258069904812146, 0.01976636307517765, 0.04319621199101675, 0.05702581111108884, 0.04893190402071923, 0.08918185281800106, 0.016758766942075454, 0.045341593940975145, 0.05001373639970552, 0.058975303181796335, 0.028168719727545977, 0.03593009641917888, 0.0458019926736597, 0.05359896647860296, 0.01879823143099202, 0.05141620997164864, 0.041832022106973454, 0.03591054453863762, 0.012507985320553416, 0.020569982843881007, 0.050541347736725584, 0.06827350443927571, 0.057049741662922315, 0.04509265905653592, 0.11609835419221781, 0.18663344235392287, 0.13475438085151836, 0.1439443213166669, 0.18222374928882346, 0.20881504897261038, 0.17339048499707133, 0.1379329845076427, 0.15110194974113256, 0.11913636539247818, 0.12428915608325042, 0.15056671283673495, 0.16197582328459248, 0.1471971397404559, 0.0709338292654138, 0.15486057149246335, 0.21035925048636273, 0.13259833795018494, 0.14960365748265758, 0.2086715176119469, 0.1767677319003269, 0.2896237245295197, 0.14779391553020105, 0.08842879557050765, 0.05160816275747493, 0.07527756766648963, 0.13608733745058998, 0.07352905289735645, 0.18610420200275257, 0.17351286514895037, 0.13531492499168962, 0.09657683491241187, 0.14791601366596296, 0.11709010097547434, 0.1466611013165675, 0.09278714685933664, 0.15465045464225113, 0.23966201639268547, 0.07818735801265575, 0.1222026078903582, 0.1810576720163226, 0.13151981926057488, 0.15865751774981618, 0.22540432051755488, 0.1721573472605087, 0.14588972786441445, 0.13577993988292292, 0.11672709428239614, 0.09541323641315103, 0.15217818261589855, 0.09629253298044205, 0.13708423473872244, 0.13781565095996484, 0.1538321329280734, 0.148747990897391, 0.15758875088067725, 0.1327506118104793, 0.15510032972088084, 0.214868703042157, 0.1526413718238473, 0.10878332366701216, 0.1955078067840077, 0.10747139211161993, 0.12060860084602609, 0.15409985528094694, 0.09966536410502158, 0.11907263717148453, 0.12262876392924227, 0.25770433887373656, 0.15805873816134408, 0.1628387183882296, 0.09381168172694743, 0.1946660183602944, 0.13492593570845202, 0.14986973226768896, 0.19974351074779406, 0.22538469813298434, 0.13532056531403214, 0.20884889090666547, 0.156477251148317, 0.3014722606167197, 0.20391323778312653, 0.16984205431072041, 0.1635614811675623, 0.19167341175489128, 0.13040958117926493, 0.13665607490111142, 0.15760248061269522, 0.10872350656427443, 0.13555759243899956, 0.1324390879017301, 0.0871612444461789, 0.08296429543406703, 0.16898027242859825, 0.16616394073935226, 0.16459973092423752, 0.17145790276117623, 0.1719721220433712, 0.09440872468985617, 0.09776976308785379, 0.14127800735877827, 0.14828837884124368, 0.07996902451850474, 0.18019385664956644, 0.10732737835496664, 0.1411677835858427, 0.13349943881621584, 0.1630535998265259, 0.17147792590549216, 0.2394568274030462, 0.19737343245651573, 0.15918889548629522, 0.23274160805158317, 0.2495108504081145, 0.1386580924736336, 0.1066783702117391, 0.2094479079823941, 0.14622198737924919, 0.13431658793706447, 0.11105354598839767, 0.08379889986827038, 0.16075087885838002, 0.1468095011659898, 0.1054299516545143, 0.10987113404553384, 0.1326155854621902, 0.14780751167563722, 0.09572866401867941, 0.14506221836199984, 0.16619845060631633, 0.12973680946743116, 0.08891208213753998, 0.12579187896335497, 0.2007783020962961, 0.17185846954816952, 0.2310588030377403, 0.1289133372483775, 0.1627074769930914, 0.15095246635610238, 0.19784117845119908, 0.09595603580237366, 0.3180677513591945, 0.19408258638577536, 0.19777388049988076, 0.11826417859992944, 0.15863134962273762, 0.09744776747538708, 0.14325842843391, 0.1131140893267002, 0.16652610880555585, 0.11337388554238714, 0.15913118608295918, 0.09875127565464936, 0.14461032464168966, 0.061213097360450774, 0.17575239966390654, 0.14213164045941085, 0.1589231175603345, 0.20174836332444102, 0.16422257147496566, 0.2228188858134672, 0.16861268668435514, 0.13148361729690805, 0.10100589803187177, 0.13879255478968844, 0.22647148434771225, 0.17971006542211398, 0.13840225932653993, 0.10538997215917334, 0.23724966536974534, 0.1537058045505546, 0.21087303932290524, 0.15201765607343987, 0.15068159729707986, 0.13268261624034494, 0.26562724029645324, 0.17564864741871133], [0.008064940138865495, 0.03306068632809911, 0.03771421572309919, 0.034722566488198936, 0.04392500843096059, 0.055931440147105604, 0.03348475322127342, 0.025345795911562163, 0.07007823689491488, 0.06570256387931295, 0.03806365595664829, 0.018020879979303572, 0.022927134778001346, 0.04011384262412321, 0.025262836788897403, 0.06224697586731054, 0.017897917241498362, 0.043042450124630705, 0.07909622174338438, 0.04930874063575175, 0.07038075855234638, 0.039730478820274584, 0.015848044131416827, 0.01156245578386006, 0.027451504502096213, 0.0045204298476164695, 0.025484436519036535, 0.027793929584731814, 0.0620562513358891, 0.04276771447621286, 0.023842392110964283, 0.06973548341193236, 0.050499969293014146, 0.06356831785524264, 0.031817388589843176, 0.10382171763922088, 0.04652756077121012, 0.07539709054981358, 0.0328262233233545, 0.05464395864692051, 0.06257525747059844, 0.03993311111116782, 0.057772003492573276, 0.03239076817408204, 0.1010494472575374, 0.044790471365558915, 0.03511347793391906, 0.07248924463056028, 0.06987497006775811, 0.01618639853404602, 0.018662943475646898, 0.01752114370901836, 0.01253242702659918, 0.024903635458031204, 0.01200356702611316, 0.03680552268633619, 0.055101203251979314, 0.053289906500140205, 0.025076012243516743, 0.002497922969268984, 0.01202705785544822, 0.05441127308586147, 0.013234767757239752, 0.06373240670654923, 0.02741993168456247, 0.024324981059180573, 0.049040665762731805, 0.030210566510504577, 0.062417513981927186, 0.04579903521516826, 0.023349626462731976, 0.017743455900927074, 0.06904007619596086, 0.045961398573126644, 0.07511900781537406, 0.044105977431172505, 0.03241865437303204, 0.0465399583481485, 0.015201466521830298, 0.04007345865829848, 0.022062506759539247, 0.07694086903939024, 0.04578985484840814, 0.02262713085656287, 0.014182510749378707, 0.05296943229041062, 0.07123237301129848, 0.05675386964867357, 0.06109050569648389, 0.027845534823427442, 0.015280822517524939, 0.04829069584957324, 0.02908590107836062, 0.03595340356696397, 0.011390054878575029, 0.01927422268636292, 0.009670516337791923, 0.06274327228311449, 0.03760511630389374, 0.012529733958217548, 0.09599202254321426, 0.05626713209494483, 0.034144325836678036, 0.05031572742154822, 0.002092088789140689, 0.03074997428484494, 0.020790029630006757, 0.04577759085805155, 0.03090146889007883, 0.05449294643767644, 0.009929537009156775, 0.034414705078233965, 0.04296087696275208, 0.054835158152855, 0.08723862818442285, 0.03657124521851074, 0.03196791840309743, 0.012721035509457579, 0.04636791367374826, 0.02880358624679502, 0.02931214479758637, 0.023017448584141675, 0.07023654441582039, 0.0554668705444783, 0.017293779346800875, 0.024002551290323026, 0.02596396967419423, 0.04891285308985971, 0.013282267991598928, 0.06610805852687918, 0.010562438692431897, 0.08564685500459746, 0.029568473328254186, 0.040230018421425484, 0.010187285824940773, 0.030892683716956526, 0.01619772370759165, 0.06133400434919167, 0.01750509847624926, 0.010311815422028303, 0.025395145021320786, 0.011745987048925599, 0.09371925465529785, 0.03779809696425218, 0.04243011891958304, 0.02878295268601505, 0.05548493812966626, 0.029292489016370382, 0.02240081663330784, 0.02602462911454495, 0.07656672270968556, 0.026864899846259505, 0.01785958531399956, 0.015051569389470387, 0.03678173314256128, 0.031772633374202996, 0.052819481352344155, 0.03605147096095607, 0.03740086242032703, 0.015624342267983593, 0.0588037668785546, 0.02010492156841792, 0.10237166497972794, 0.05731066965381615, 0.0747491733636707, 0.013513090761989588, 0.06005842318700161, 0.0493078871659236, 0.03346729790791869, 0.040446829443681054, 0.022339485549309757, 0.09352716457215138, 0.03426866896916181, 0.07253577728988603, 0.024680443821125664, 0.04232218838296831, 0.05148948221176397, 0.056899248957051896, 0.030104094294074457, 0.04703184269601479, 0.02189422848459799, 0.03676939493743703, 0.02283272802742431, 0.04788342375832144, 0.03380368376383558, 0.04143447215028573, 0.061353559940471314, 0.03870875298161991, 0.03729118041519541, 0.03472668911854271, 0.04031347663840279, 0.0026885621537076076, 0.0705214697518386, 0.06598349646083079, 0.06992090158746578, 0.026210887772322167, 0.03696906605910044, 0.05620754134724848, 0.028865928507002536, 0.08449070766801015, 0.03472382442851085, 0.03897526934451889, 0.025186367747664917, 0.01834021313698031, 0.03499199578072876, 0.05468689931149129, 0.05055291410826612, 0.03985766066762153, 0.016128930328704882, 0.05893780617043376, 0.03404770191991702, 0.08319279528222978, 0.07789246563334018, 0.10004296884289943, 0.03908716294972692, 0.02855007231119089, 0.06308956581051461, 0.02793450348690385, 0.045271097333170474, 0.023854882456362247, 0.05655896682583261, 0.04362732928711921, 0.009387424106535036, 0.010309107510693138, 0.01545575971249491, 0.012495994069467997, 0.08975166638265364, 0.07590162480482832, 0.056420790060656145, 0.047357526782434434, 0.0057193165412172675, 0.07214282493805513, 0.017147867547464557, 0.017315130935458, 0.010939061940007377, 0.014513097648887197, 0.03227557201171294, 0.0426533495192416, 0.0854990488733165, 0.011287110646662768, 0.04838092616409995, 0.03591910150134936, 0.008793737506493926, 0.02461212541675195, 0.009213810717483284, 0.10700557570089586, 0.0029130131224519573, 0.04493089683819562, 0.07771224249154329, 0.019776159424509387, 0.01835042694438016, 0.08969444679678418, 0.00812117174064042, 0.034694576388574205, 0.04036681479192339, 0.06176948547363281, 0.051706860976992175, 0.026871427035075612, 0.03520178608596325, 0.05486119269335177, 0.068618521472672, 0.05511580500751734, 0.0213034362604958, 0.036468186881393194, 0.06399831079761498, 0.04903293258394115, 0.05361295225156937, 0.05821686536364723, 0.005229699454503134, 0.05632362066535279, 0.044370033574523404, 0.029714984411839396, 0.034882744221249595, 0.009934470435837284, 0.041835432275547646, 0.0526665172947105, 0.06108707697421778, 0.06800878036301583, 0.03526142878399696, 0.0478564541117521, 0.026762997404148336, 0.009398861529916758, 0.009013264789246023, 0.01481597460951889, 0.041513893083902076, 0.09137297704000957, 0.07451046898495406, 0.0510924072295893, 0.05383627561968751, 0.05011522509448696, 0.038631870193057694, 0.037657523062080145, 0.04321037216868717, 0.006065897650842089, 0.05296103860018775, 0.06772496082703583, 0.03550915025698487, 0.013578341313404962, 0.037481841864064336, 0.06855762083432637, 0.02128866752173053, 0.03296236289315857, 0.06087796202336904, 0.10154903880902566, 0.018194312469859142, 0.04466706333914772, 0.10026171687059104, 0.05150970202521421, 0.05674568375980016, 0.050821987169911154, 0.049448457357357256, 0.012716453675238881, 0.04315018028137274, 0.03203256688721012, 0.03630573075497523, 0.024779190280241892, 0.044086881971452385, 0.034012101095868275, 0.004726658307845355, 0.07064231365802698, 0.04333293414674699, 0.028144299358245917, 0.04213848085782956, 0.03340301678690594, 0.01842145047703525, 0.017219688888872042, 0.015835852500458714, 0.05517339566722512, 0.09600667995982803, 0.04715712093457114, 0.02792277569824364, 0.031546675381832756, 0.02008226565521909, 0.026200440188404173, 0.055121630866779014, 0.05005919294490013, 0.06207402948348317, 0.04753894107125234, 0.022287922984105535, 0.01909584563691169, 0.02767473881249316, 0.023726602230453864, 0.025563731287547853, 0.06015997125359718, 0.021944225118204486, 0.04589728814607952, 0.05973617524432484, 0.04126724772504531, 0.06411375186871737, 0.024264690837298986, 0.01721028958854731, 0.04053481847222429, 0.12120217055780813, 0.0961093560908921, 0.18306978279724717, 0.160002511984203, 0.09550987888360396, 0.11625930375885218, 0.13385330967139453, 0.21738798270234838, 0.1312368383514695, 0.23722979065496475, 0.1701822696486488, 0.16014585038647056, 0.09518400926026516, 0.15549341565929353, 0.07889889209764078, 0.16412355413194746, 0.10452102113049477, 0.15502264170208946, 0.182397055614274, 0.18879089533584192, 0.09786505484953523, 0.14524830447044224, 0.07766606606310233, 0.17919301113579422, 0.1396132810623385, 0.15812832192750648, 0.1358163941767998, 0.10793689682031982, 0.14637047628639266, 0.15349856723332778, 0.145217549870722, 0.208432694489602, 0.08238735725171864, 0.17737411108100787, 0.11006018874468282, 0.23441317694960162, 0.21363235922763124, 0.18406868388410658, 0.18990417622262612, 0.15403781173517928, 0.11421047893236391, 0.15924691659165546, 0.12741771672153845, 0.17457183566875756, 0.14891872939188033, 0.08449183573247865, 0.08287695949547924, 0.18872205371735618, 0.12279691232834011, 0.14952678582631052, 0.2662425994640216, 0.18974887439981103, 0.2010796734248288, 0.10609310513245873, 0.07827057503163815, 0.25933180935680866, 0.15501766931265593, 0.1355471578426659, 0.11794396414188668, 0.1025726756779477, 0.10782489931443706, 0.16796283249277622, 0.1594298263080418, 0.13029060006374493, 0.17631744121899828, 0.13618075900012627, 0.13011727889534086, 0.1221416775661055, 0.21628878777846694, 0.15056631207698956, 0.20344657532405108, 0.10649094823747873, 0.18768849433399737, 0.17635071912081912, 0.14140978310024366, 0.15390363143524155, 0.08780915421084501, 0.18355879874434322, 0.08429041685303673, 0.12283737421967089, 0.09782406603335403, 0.2856068650726229, 0.12762517668306828, 0.13843999011442065, 0.24364061071537435, 0.15847588452743366, 0.13671863795025274, 0.22204283683095127, 0.18535608745878562, 0.11557994177564979, 0.09878748503979295, 0.18255013099405915, 0.09306811654823832, 0.09773511221283115, 0.12085432594176382, 0.08428956338320859, 0.13015275355428457, 0.11807190297986381, 0.1155807136092335, 0.06014984093781095, 0.19751911604544148, 0.183641177136451, 0.081044930848293, 0.16609603422693908, 0.1426402194192633, 0.14322982606245205, 0.14909832912962884, 0.14043987030163407, 0.13565355213358998, 0.17268088791752234, 0.17917473945999518, 0.146982213773299, 0.18206492968602106, 0.11759688393794931, 0.12100752006517723, 0.10205245984252542, 0.12306449367315508, 0.11307523789582774, 0.18526459549320862, 0.11602606900851242, 0.14570399798685685, 0.06937706319149584, 0.1509008722496219, 0.13993811910040677, 0.13576621015090495, 0.12220664517371915, 0.29677028011064976, 0.2341948519460857, 0.11060157063184306, 0.19356948032509536, 0.12463412858778611, 0.17162417352665216, 0.10592492704745382, 0.1340254582464695, 0.12730413844110444, 0.09777477258467115, 0.17838344676420093, 0.11577701909118332, 0.07783596593071707, 0.10458834876772016, 0.12316239779465832, 0.14393546007340774, 0.21993512258632109, 0.13999490824062377, 0.12163006322225556, 0.15707540733274072, 0.16948849515756592, 0.07572301954496652, 0.1581816526595503, 0.10771627115900628, 0.13855094119207934, 0.20967448566807434, 0.1568025938468054, 0.1996221992885694, 0.1070895348675549, 0.07853690214687958, 0.19024646957404912, 0.16166236979188398, 0.15803601359948516, 0.1691863519954495, 0.14322577393613756, 0.17820788430981338, 0.14626063843024895, 0.1625625800807029, 0.14704302535392344, 0.05845799656526651, 0.14646918192738667, 0.1530199561966583, 0.12565603625262156, 0.10516542053665034, 0.1505620521493256, 0.2622340223751962, 0.23637295147636905, 0.1275411804090254, 0.09159180670394562, 0.13017274701269343], [0.00474611556455784, 0.026994139298039954, 0.03928058889869135, 0.06462850549723953, 0.06952408264623955, 0.0159593959688209, 0.037729752584709786, 0.017284862442465965, 0.017265787391806953, 0.05365775570680853, 0.039509745547547936, 0.02855848455510568, 0.028665780555456877, 0.08207943275920115, 0.04656085351598449, 0.026160393899772316, 0.08092261748970486, 0.030170913560141344, 0.0630875100614503, 0.03402122951229103, 0.010165860021515982, 0.0604101677890867, 0.03179890540195629, 0.016749337955843657, 0.06381750135915354, 0.026948638223984744, 0.03396164989680983, 0.031002265532151796, 0.027981318162346724, 0.017185399810841773, 0.018056115295621566, 0.023516531764471438, 0.05891403146961238, 0.015393973135360284, 0.04207868601952214, 0.04320187457778957, 0.022253756360441912, 0.024302121055370662, 0.03468378556135576, 0.01521266274721711, 0.030705844328622334, 0.02649682242918061, 0.016658140993968118, 0.07623626661370508, 0.03672564904263709, 0.021960704507364426, 0.02976454317831667, 0.04842395217565354, 0.06184816425957251, 0.03099525780271506, 0.037318368995329365, 0.04809780424693599, 0.03900517418514937, 0.015165218173933681, 0.04061338222527411, 0.010304228817403782, 0.0610139271884691, 0.05264790052024182, 0.050215838055009954, 0.03720083135704044, 0.054557932598982006, 0.10351232369430363, 0.018256203875353094, 0.026359231960668694, 0.028714535947074182, 0.048070437551359646, 0.046925544884288684, 0.038182585121830925, 0.09557503944961354, 0.01737102949846303, 0.010087110731547, 0.04805789525562432, 0.09090252962778322, 0.02314703870069934, 0.03096167933108518, 0.01682698701188201, 0.01298711400522734, 0.05516467172128614, 0.03263341335696168, 0.007956423305586213, 0.0494128602440469, 0.023482639735448174, 0.05399749607022386, 0.07664525677682832, 0.032762472837930545, 0.031892059778328985, 0.02261527504742844, 0.024787901238596532, 0.04165314596320968, 0.05282264290144667, 0.04725947052065749, 0.04744601304992102, 0.0489732750429539, 0.07184311602031812, 0.09785292815649882, 0.03083487412368413, 0.05356227840820793, 0.01574243651703, 0.053563488108920865, 0.0108856746192032, 0.08214511282858439, 0.0253953194260248, 0.07808909023879096, 0.041400144109502435, 0.07528015776188113, 0.05030398293456528, 0.0844637380214408, 0.03193957207258791, 0.010487901090527885, 0.00952468339164625, 0.04657571502320934, 0.009137402903434122, 0.03286881517851725, 0.030987699028628413, 0.02303831592143979, 0.01248537671926897, 0.05259803932858631, 0.062031263223616406, 0.012765415012836456, 0.0687968150305096, 0.031087451097846497, 0.014610471134801628, 0.06098625992308371, 0.06532236162456684, 0.042180735035799444, 0.06355762350722216, 0.01719066349323839, 0.05823011641041376, 0.007168108013502206, 0.0499023289012257, 0.046313729471876286, 0.057179335490218364, 0.06657239806372672, 0.0499141476029763, 0.04969816036464181, 0.10308005235856399, 0.03341286879731342, 0.05307835730491206, 0.0545902902376838, 0.009229190800397191, 0.07757724582916126, 0.02090471185510978, 0.0590799719793722, 0.025595038787287194, 0.04740187752759084, 0.053393027919810265, 0.04845650648348965, 0.043086344448965974, 0.01620838651433587, 0.0633926440787036, 0.004218166086502606, 0.036379169978317805, 0.007121057242329698, 0.039126073752413504, 0.018178766331402585, 0.06410897243767977, 0.06985227519180626, 0.032546715665375814, 0.0393122489185771, 0.02063757950963918, 0.005165331131138373, 0.04075510645634495, 0.04999983968446031, 0.023247891003848054, 0.008621372780908132, 0.0648492350592278, 0.09365855439682491, 0.01554863856654265, 0.03192013522493653, 0.02358974834351102, 0.046764565631747246, 0.008836859997245483, 0.04725328471977264, 0.015910622023511678, 0.01609211423783563, 0.03638735586719122, 0.02755053668806795, 0.02213511663285317, 0.015597500641888473, 0.019690916342369746, 0.1309211435727775, 0.02596177477244055, 0.008922981596697355, 0.044747415668098256, 0.03767148285987787, 0.027129818736284506, 0.030187155462044757, 0.0881279882742092, 0.05559939214435872, 0.045354459070949815, 0.05284317070618272, 0.08408494584728032, 0.027987283174297772, 0.02751273539615795, 0.016827599283715244, 0.047961185991880484, 0.04866928022238426, 0.01403117663357989, 0.04573461308609694, 0.015749891390441917, 0.03324473153043073, 0.06282061149249785, 0.0077021542347210925, 0.052612310828408226, 0.014716047207912197, 0.017443036376789678, 0.016442519263364375, 0.02161757438443601, 0.02541929265134968, 0.05923688426264562, 0.01033871085382998, 0.04381052844109945, 0.02757503683824325, 0.02994110938743688, 0.031289409889723174, 0.017048942972905934, 0.02069753947580466, 0.0359225673309993, 0.05004099177313037, 0.05667132056260016, 0.00993678408121923, 0.015942853497108445, 0.05178032246476505, 0.056926285396912135, 0.056584515259601176, 0.04863825844950043, 0.02004859627049882, 0.05171783734112978, 0.057007235154742375, 0.0373629126988817, 0.048600305017316714, 0.031651529716327786, 0.018292982858838513, 0.011876873140863609, 0.03092083894443931, 0.03462824322923552, 0.10245310084428638, 0.03797618643147871, 0.029152087663533166, 0.07984740877873264, 0.01951822228875244, 0.09299686294980347, 0.029801761884300504, 0.03280838209320791, 0.029274156113388017, 0.03068308451474877, 0.013978242022858467, 0.0114229051177972, 0.07759962158161215, 0.02307911177922506, 0.04564303206279874, 0.09926147249643691, 0.03450886135397013, 0.033606354118091986, 0.00862705021063448, 0.02227990778919775, 0.040163369849324226, 0.007167876092353254, 0.035768616216955706, 0.06544408126501366, 0.0257624431833392, 0.052832643341389485, 0.053216266896924935, 0.02562866735388525, 0.057857521169353276, 0.012450351987354225, 0.019555465114535764, 0.0212597701465711, 0.02951430211396655, 0.0428257133171428, 0.038633042786386795, 0.06746986982761882, 0.10464351260452531, 0.0314472053287318, 0.06425432948162779, 0.0641263832221739, 0.025719801233208273, 0.09419809575774707, 0.027626421288005076, 0.023179303570941556, 0.06548388264491223, 0.027372977856430225, 0.041584731079638004, 0.02094093979394529, 0.023496929788962007, 0.06913366101798601, 0.014073177553655114, 0.05672069193678908, 0.020462328757275827, 0.015875329190748744, 0.03436467319261283, 0.021309857693267986, 0.022028718631190713, 0.07278024815605022, 0.022093888474046253, 0.033069413984776475, 0.03502111023408361, 0.03456125326920301, 0.03300052783743013, 0.04918073500448372, 0.03147087241814006, 0.03560611185093876, 0.017193021667480934, 0.029193824193498585, 0.07164862137869932, 0.023745180042169522, 0.02496103501471225, 0.10573478139122017, 0.04626318179361988, 0.06223321644938551, 0.012399912848195527, 0.05963110568700358, 0.07810502414940856, 0.029511361353797838, 0.03743629997188691, 0.044675290046143346, 0.02254175975394901, 0.01612586525880033, 0.03236347569327336, 0.007738157673884416, 0.048850479288375936, 0.060260302198003046, 0.042000003522844054, 0.05419711524154991, 0.03073241692618467, 0.014368268457474187, 0.05237521319941152, 0.10169633285840973, 0.013529110019590007, 0.03140016058750916, 0.09383867363794707, 0.04577757601509802, 0.0682169824722223, 0.023625067151442636, 0.013613054343295516, 0.028710407750622835, 0.06787080026697367, 0.03224505118851084, 0.07225698951515369, 0.028364043719193432, 0.027451586138340645, 0.07794489836669527, 0.041026517283171415, 0.014626295578636928, 0.0268886485719122, 0.00835374505186337, 0.05513803604117129, 0.03635138025856577, 0.0020897876675007865, 0.027237563735980075, 0.03521007216477301, 0.10143635110580362, 0.17197466018842533, 0.14582317206077278, 0.08789190367679112, 0.17995176807744429, 0.2505840256344527, 0.1586427490110509, 0.0841340611805208, 0.12255546942469664, 0.10302272145054303, 0.12712186697172, 0.12723495543468744, 0.10450515401316807, 0.16796268406324089, 0.17044203617842868, 0.12422372834407724, 0.13777955289697275, 0.13208349526394159, 0.11048430387745611, 0.1618786613107659, 0.18615986307850108, 0.1752753322944045, 0.20819173398194835, 0.14394064026419073, 0.07350553423748352, 0.12242001263075508, 0.16490518406499177, 0.14253983652452007, 0.07400911854347214, 0.14851590647595003, 0.0729680412041489, 0.1831482129637152, 0.11053853260818869, 0.08792402382823639, 0.17338680394459516, 0.0956596591277048, 0.15645942476112396, 0.09115100066992454, 0.1789553606067784, 0.1601585856406018, 0.10880778485443443, 0.13775901024928316, 0.15130241867154837, 0.2013845180044882, 0.25394930911716074, 0.16763918189099059, 0.08602011075709015, 0.11467258460470475, 0.16853164415806532, 0.12509618973126635, 0.19775376829784364, 0.11714527223375626, 0.12810346117476, 0.13953632034827024, 0.13957525341538712, 0.13999452232383192, 0.11664750636555254, 0.22029448533430696, 0.12670141062699258, 0.11670270730974153, 0.1325477531645447, 0.18884723918745294, 0.15136104833800346, 0.11173592109116726, 0.23961769533343613, 0.09285102350986563, 0.19949851295677945, 0.15114546928089112, 0.10859195346711203, 0.13994423439726233, 0.0693451359984465, 0.12587609788170084, 0.08849863908835687, 0.38048311311285943, 0.08832486520987004, 0.11903543330845423, 0.17342040839139372, 0.10936092978226952, 0.11399086259189062, 0.11814432917162776, 0.16598343558143824, 0.28874879179056734, 0.11392508604330942, 0.11976348017924465, 0.14330974052427337, 0.10690341165172867, 0.10109123759320937, 0.23770565574523062, 0.14134223281871527, 0.12231925124069676, 0.11492332661873661, 0.09836803801590577, 0.153463062888477, 0.10224176687188447, 0.13016701763262972, 0.22075892135035247, 0.1566974908928387, 0.23448149906471372, 0.09248387563275173, 0.24718295579077676, 0.23967020970303565, 0.318116644048132, 0.20604125718818977, 0.27279300265945494, 0.16741597355576232, 0.16029365651775151, 0.1531807944411412, 0.31213353853672743, 0.14459012338193133, 0.08403264670050703, 0.120608444995014, 0.16938935907091945, 0.1752525186748244, 0.1678705686936155, 0.12916698848130181, 0.06695823321933858, 0.1409000760759227, 0.1115783111890778, 0.1523013346013613, 0.11921982732019387, 0.1672273938311264, 0.11297668068436906, 0.12681074382271618, 0.0845072501397226, 0.1359840453369543, 0.12610585195943713, 0.1363169282558374, 0.10279047375661321, 0.10417424520710483, 0.19381551712285727, 0.08505096979206428, 0.0995976579724811, 0.22807410772657022, 0.10987542365910485, 0.20517885190201923, 0.11309840032481588, 0.136258150159847, 0.20594673726009205, 0.12265669094631448, 0.11939383868593723, 0.10525863428483717, 0.2559602027758956, 0.2537751419004053, 0.12099629879230633, 0.12472649628762156, 0.14116523059783503, 0.1897533718147315, 0.13707581878406927, 0.10621757814078592, 0.07893476009485312, 0.10831167397554964, 0.11450039150076918, 0.19169298961060122, 0.09118527304963209, 0.1310553090297617, 0.1156775193521753, 0.22690112848067656, 0.18481581879314035, 0.10006638360209763, 0.12198986383737065, 0.07573928742203861, 0.27084694302175194, 0.10711346170864999, 0.13714903907384723, 0.08958803766290657, 0.16457252379041165, 0.27470480476040393, 0.1035321167728398, 0.08328425014042296, 0.05049446626799181, 0.05559361081395764, 0.17673627968179062, 0.08351734388270415, 0.10377768601756543, 0.09074137225979939, 0.12661836430197582, 0.2171788751729764], [0.029718658042838797, 0.052575448353309184, 0.03816294418356847, 0.02368321813264629, 0.047489454664173536, 0.015334663476096466, 0.033456354940426536, 0.028255185497982893, 0.0805503265291918, 0.03874963418638799, 0.038147169834701344, 0.03533530587446876, 0.01477800726206624, 0.04923029562633019, 0.008446926331089344, 0.027493855159264058, 0.006441988407459576, 0.03718552827194799, 0.04940555380017031, 0.009716258609842043, 0.07896801573224366, 0.015108096922631375, 0.021062900632387027, 0.037552438661805354, 0.06213049950019922, 0.019077303077210672, 0.06298873020568863, 0.08906224829843268, 0.09089508588658646, 0.037555659582722, 0.02037465885223355, 0.03164000045217108, 0.06306200986728072, 0.08721214093384333, 0.02754693170572864, 0.031594436295563355, 0.008915005364542594, 0.0340043048345251, 0.07512662967201322, 0.060326138118398376, 0.003897130163750262, 0.02999151976837311, 0.05677808221662417, 0.022282197314780205, 0.04995672461518552, 0.027212360400881153, 0.07673673389945179, 0.10614932281896472, 0.03365863100043498, 0.03169960233208258, 0.06196806192747317, 0.011204876045667334, 0.06526543889776804, 0.017347059983876534, 0.04526506738329772, 0.03827959866612218, 0.055547289666719735, 0.06269669509492815, 0.112960093683796, 0.07749309370410629, 0.025487607344985008, 0.06350348383421078, 0.014684989255329128, 0.044841423514299095, 0.03591383596358355, 0.015179569454630837, 0.023819237103452906, 0.03481876367004588, 0.07225208391901106, 0.02507978235371411, 0.04212486986943986, 0.06375372118782252, 0.06011963923810981, 0.04997063988412265, 0.032442299198010005, 0.09901228899252601, 0.08310790100949816, 0.021406181040219963, 0.046420016151387244, 0.08704417065018788, 0.05724365371861495, 0.10466993306181394, 0.03929070437152404, 0.03571023145923391, 0.04757366987178102, 0.054310307605192065, 0.04595772494212724, 0.030391548498300835, 0.06867018237244338, 0.023880161861598026, 0.023777841961418744, 0.012479077740863431, 0.025528618425596505, 0.04010376054793596, 0.05659001457388513, 0.036754704124177806, 0.14603747462388128, 0.03696016028698068, 0.048012138140620664, 0.011696789151756093, 0.02560678512963932, 0.06409259323845617, 0.03455706384556834, 0.020221436898282263, 0.0728852694737725, 0.0530650468863314, 0.032949894812190905, 0.05002867212169804, 0.03929994782083668, 0.06511315019452013, 0.04505983386479784, 0.04230901897244621, 0.05349166676751338, 0.009523889293632237, 0.02174704204662703, 0.06623891400522552, 0.023322016713791527, 0.02304040506714955, 0.003700529678098974, 0.07867894921218976, 0.04613291261193808, 0.012125247703806963, 0.07430566591210663, 0.07298922952031717, 0.06715174080454744, 0.01698442065389827, 0.05828846406075172, 0.019618699807324447, 0.09638588773668744, 0.006235247865333804, 0.026650565741874743, 0.014328515317174606, 0.028035062641720288, 0.05703439404896926, 0.05725047034502495, 0.027299705616314895, 0.03432792203966528, 0.08344087298610248, 0.07694821630138904, 0.060324382939143106, 0.00961700192419812, 0.035271496017230675, 0.061923447719891556, 0.09122074028709903, 0.010869420657400042, 0.007518278798670508, 0.036305070243543014, 0.046930502430768684, 0.05974770450848155, 0.02879205141653074, 0.021462780932779424, 0.014817111023148755, 0.03215273914975114, 0.050007313111564144, 0.018343359843129292, 0.0267792504382669, 0.007714029061389738, 0.042039619365823455, 0.05527525914658327, 0.05231075767369475, 0.02020098516368307, 0.05672312618116848, 0.019583132379921153, 0.06849194076494314, 0.00664177456201287, 0.04043866952997632, 0.03746904352738056, 0.0584354241436813, 0.04809870595636312, 0.06430640598409809, 0.046367457252927125, 0.03644301323220134, 0.0316312319773715, 0.12024916388327256, 0.025833232939476147, 0.04715813396614976, 0.027608220116235316, 0.027873710459971335, 0.06481017582700588, 0.009977515001082793, 0.03114288396318443, 0.012290492450119928, 0.027137310717080254, 0.006939589611647534, 0.014002942552906461, 0.029369091644184664, 0.030682078904646914, 0.1017088899970986, 0.04367302331957035, 0.044896657855133526, 0.007311303088499699, 0.03521898906910792, 0.007496145171899116, 0.03677624867123086, 0.011159890764247393, 0.05943398013187107, 0.06909016374265775, 0.05997418942570221, 0.023804754091543145, 0.053651944690500386, 0.04214978005620651, 0.012354993432381889, 0.04783611926541198, 0.0440466872532852, 0.01070115629772772, 0.07373656480922364, 0.016009685750759672, 0.022702655514876824, 0.032862863154150546, 0.05377804671297781, 0.04613115372194443, 0.04712065179774072, 0.028414634070941247, 0.018087589778588153, 0.04913010940072127, 0.01698566189588746, 0.016819059019326232, 0.06490652885986492, 0.02925271175627131, 0.03208189373253845, 0.03616962829255499, 0.03527182627294678, 0.025614280821173452, 0.02312730128323892, 0.024888812913559377, 0.02529750250687357, 0.024955242552096024, 0.0034942093770951033, 0.04407959037052933, 0.032521378743695095, 0.04117145130294375, 0.034691511318669654, 0.04061199440911878, 0.012854717642767355, 0.03177989899995737, 0.03956223765271716, 0.021547563883359544, 0.03649900827440433, 0.0450258694763761, 0.050959239961230196, 0.02980481025588233, 0.03644123578851577, 0.02467400197929237, 0.06118318509834353, 0.012920376375404885, 0.05532570292416494, 0.019788378886005376, 0.025843704643193632, 0.06605983377085067, 0.008851727998262504, 0.07346576254349202, 0.024817776393319946, 0.07147789772716351, 0.0631137598247733, 0.0971249926078599, 0.07249423928442411, 0.1097881916211918, 0.05506454857822973, 0.0374751662457129, 0.0016575475251556782, 0.02590609514300013, 0.06749288382707164, 0.027449189001345076, 0.007315350112548913, 0.027006542441085912, 0.006408829713109299, 0.06552358012413606, 0.09622156881960109, 0.020583616096701007, 0.08601441848441027, 0.0608742512849858, 0.03269874090619851, 0.05120176268974319, 0.02216073185991263, 0.06306844428763725, 0.016675366241543088, 0.039841084799263626, 0.07035065704258159, 0.014702695043524727, 0.034396618939354084, 0.07037786417640746, 0.052737095538759604, 0.033220723053091206, 0.025606712770240847, 0.04565478768199682, 0.048877100125537254, 0.0626178047969006, 0.07824257379979827, 0.04301170294638723, 0.026935433561448008, 0.010501641027076403, 0.032815755330375396, 0.07359621726209298, 0.06969925918383524, 0.056499168276786804, 0.032476475098519586, 0.05668739919201471, 0.019241807531216182, 0.03333041619043797, 0.045075519155943766, 0.031275179208023474, 0.02799297173623927, 0.06155017712444533, 0.05113262792292517, 0.03514597658067942, 0.01941909547895193, 0.05076624445791822, 0.03176945698214695, 0.021506152043002658, 0.011508262305142125, 0.06123090519395191, 0.02912244071922032, 0.03536640557285864, 0.06054975834558718, 0.02817231543303933, 0.0785042550705839, 0.044088737340644, 0.06769232117221691, 0.053995173147995956, 0.01852980403782567, 0.03667454104288481, 0.017601700128579978, 0.03397849664906971, 0.00865622867422644, 0.04544711991911754, 0.028985605385969393, 0.06213198008481413, 0.032135773653863, 0.02951714825030649, 0.05147575619048439, 0.050578106311149895, 0.00997847608232405, 0.060629542931565084, 0.03304089324956294, 0.049940282333409414, 0.038804868527222425, 0.042465070364414714, 0.03003426932991715, 0.022918203030712903, 0.0470396092714509, 0.061806039957446046, 0.13326791842700914, 0.020404558126756456, 0.07402255141641945, 0.024806004075799137, 0.05229612623224966, 0.07136756263207644, 0.025764318961591925, 0.06363982378388755, 0.09521160231088288, 0.0286578302984708, 0.020902119904349092, 0.1186200903612189, 0.1885144304833375, 0.08773234192631207, 0.1359000787488185, 0.13093465066049248, 0.09974913773476146, 0.14152046700473875, 0.05883142672246322, 0.22425761329941452, 0.12534979643533006, 0.06964624757529236, 0.2029899467015639, 0.1662326042423956, 0.15370578970760107, 0.11190711229573935, 0.14486483676591888, 0.16970579599728808, 0.18113552330760285, 0.15904543834039941, 0.1450763043249026, 0.17003495333483443, 0.12319911184022203, 0.14955473510781303, 0.15526342409430072, 0.1712654490256682, 0.07627457627677359, 0.1626892201602459, 0.16729250986827537, 0.1969737117178738, 0.15130436309846118, 0.12027761040371843, 0.10358624902437441, 0.11050526212784462, 0.1871570126968436, 0.09184099020785652, 0.10859692585654557, 0.13503546186257154, 0.15505332208704203, 0.149662658222951, 0.11510076670674607, 0.10622675850754604, 0.1957330189179629, 0.1698313673841767, 0.1530882337829098, 0.14915823529008776, 0.09834955853875726, 0.08363818778889254, 0.15192128077615052, 0.13569963950430974, 0.12634807411814108, 0.1495753668132238, 0.11034459457732737, 0.20307542727096006, 0.08771492372034118, 0.1108118804404512, 0.070728402788518, 0.20833774411585182, 0.1344966923352331, 0.15517271880526096, 0.16876343172043562, 0.1150973305630032, 0.12982102838577703, 0.09387900194269605, 0.1753459105384536, 0.0921690788527485, 0.13725411234190688, 0.17666972387814894, 0.13184839772293344, 0.16323735559126362, 0.1405970868654549, 0.13003304513404146, 0.18808995169820264, 0.20278226409573108, 0.10334697319194674, 0.1297907784464769, 0.15854834782658145, 0.11919523996766657, 0.14342845446662977, 0.14562733413185924, 0.2158763911575079, 0.21401502541266382, 0.32782360911369324, 0.10793579102028161, 0.16784511302830651, 0.12789601605618373, 0.14619227178627625, 0.18022639240371063, 0.20546284213196486, 0.2041673639905639, 0.16252925765002146, 0.11310041896649636, 0.17798262764699757, 0.08739990429603495, 0.19322800333611667, 0.14653058722615242, 0.1288548411685042, 0.2156207212829031, 0.10635863814968616, 0.1229896183940582, 0.14258242095820606, 0.16428620321676135, 0.2148773119552061, 0.14994365017628297, 0.14637268788646907, 0.230600779177621, 0.21475907298736274, 0.13330631714779884, 0.1437890640227124, 0.0932698322867509, 0.20275327580748126, 0.14864382304949686, 0.186910901684314, 0.1942019979469478, 0.11630904991761781, 0.26158446504268795, 0.13403981138253585, 0.1112432983063627, 0.12427300694980659, 0.17660860059550032, 0.1689671364147216, 0.19105207087704912, 0.09583289123838767, 0.14385784626938403, 0.17316392215434462, 0.22911470266990364, 0.11617257638135925, 0.1363258043420501, 0.12952511926414445, 0.17234760423889384, 0.13418816670309752, 0.16199871111894026, 0.16844653466250747, 0.1515978528186679, 0.12382961824187078, 0.1676979154581204, 0.16791932779597118, 0.15114831912796944, 0.14127998147159815, 0.159435318200849, 0.18276315706316382, 0.20050134742632508, 0.21474317618412897, 0.12604836520040408, 0.10672230535419658, 0.18919397058198228, 0.10956326892483048, 0.14556180249201134, 0.21121641620993614, 0.1319230132503435, 0.0856387433304917, 0.21355219243559986, 0.09198805419146083, 0.23293772799661383, 0.16038173460401595, 0.1668569730827585, 0.054386711708502844, 0.18650445708772168, 0.10597049491479993, 0.13636127900099382, 0.26898916927166283, 0.0890008281567134, 0.13761959038674831, 0.10552226740401238, 0.15642062528058887, 0.17881693522213027, 0.2725387428654358, 0.14915022009517998, 0.19247395161073655, 0.22437220090068877, 0.11464025665191002, 0.11446816744864918, 0.13331627676961944, 0.1371305892826058, 0.20076087646884844, 0.11421968156355433, 0.1505817487486638], [0.06239738693693653, 0.02608691756904591, 0.10546266552410088, 0.1076174690388143, 0.028271002520341426, 0.06311309931334108, 0.012891809255961562, 0.1014828540792223, 0.051443205593386665, 0.056833490962162614, 0.05232429815805517, 0.03107527987594949, 0.015114191810425837, 0.0383043826877838, 0.0366501540702302, 0.02560647713835351, 0.04026151516882237, 0.031248755039996468, 0.021907882146479096, 0.03576923962100409, 0.07750701639452018, 0.12384174493490718, 0.04581463887006976, 0.04163698940828908, 0.061731320529361255, 0.012388366885716096, 0.0469471859105397, 0.056407420270261355, 0.037519973411690444, 0.07165047674789093, 0.034188242425443605, 0.047374718633363955, 0.06354110329994, 0.07996627857210115, 0.022845413186587393, 0.020730110481963493, 0.04567436182696838, 0.007132022010409855, 0.02900415907788556, 0.061397617537295446, 0.018039528295048513, 0.03352476611325983, 0.012199533903185511, 0.04354309923655819, 0.02873887282476062, 0.019476708403090015, 0.022758001177862752, 0.0277993546842481, 0.026593876791594084, 0.03641439230705146, 0.06831933947978541, 0.02684260944079142, 0.02357892783038551, 0.014881040551699698, 0.06544877905980684, 0.002061458731077437, 0.03999753695097752, 0.01331359775576857, 0.07808081529219635, 0.04798204405233264, 0.016472644892928656, 0.045623747355421074, 0.029184990780777298, 0.03348211117554456, 0.04943418956827372, 0.010913865098700626, 0.09062348952284083, 0.007825104912626557, 0.011423321648180718, 0.016847809820319526, 0.06753902314812876, 0.014036502470844425, 0.05023596138926223, 0.0679778921767138, 0.05054108056356199, 0.05430838544270955, 0.01689730921498267, 0.033613341438467614, 0.13799578504404053, 0.041856305178953335, 0.06108341447543353, 0.043510982795851305, 0.047815743600949645, 0.023540755464637186, 0.01491818411523127, 0.04228866928315256, 0.036614709097193554, 0.048269655962940305, 0.011275610140728531, 0.08347234746906906, 0.027767880201281514, 0.02470010887918761, 0.014010295381012838, 0.03763266111491248, 0.026494213780097198, 0.046896077910787426, 0.01945684853126295, 0.039371023303829134, 0.00878083155839704, 0.033612732877372764, 0.03929995895305183, 0.019836568390019238, 0.026549980611889623, 0.05988992597849574, 0.0212325481697917, 0.02730713451455813, 0.03898316579579841, 0.008102662577584852, 0.07199396495707333, 0.046975235381978564, 0.00964231008765637, 0.04137565694691148, 0.03933708489057608, 0.07281042388058268, 0.029093764132994693, 0.02095283827657113, 0.036900090854032896, 0.034494968349463306, 0.024854542389221024, 0.030932076915632933, 0.045899303077021614, 0.07489067866117693, 0.013885161861253437, 0.043119210458826274, 0.07209777657408267, 0.12378816929413006, 0.056036947571556084, 0.03215866148821078, 0.01811170772270998, 0.0189095814130269, 0.04483924902160652, 0.012252569631527876, 0.010506368507776642, 0.06326362912659533, 0.03128207004920114, 0.012962355958734406, 0.057069145113928244, 0.035163762149750255, 0.028533568802231457, 0.023878037463873625, 0.03712504323630128, 0.0456381487310864, 0.03713900674483739, 0.058190407798974775, 0.06494279019534588, 0.01743052933306899, 0.03370907106727827, 0.034354297968093306, 0.05356087574909907, 0.05141043606272433, 0.019683825121319387, 0.01611415973457042, 0.04266145377187058, 0.05722976813558489, 0.04187263242783956, 0.05884835140022915, 0.03751278200070374, 0.04397146687551867, 0.03150891490804497, 0.001720238246889494, 0.035560903925215825, 0.015249904645315837, 0.03615658133639954, 0.03029217306902865, 0.06272512677242048, 0.037157308106543496, 0.054451549440273084, 0.04765578851220198, 0.10808689228724688, 0.03320438838272821, 0.031742027204018086, 0.07636211259523407, 0.030162814873619936, 0.08442898324574344, 0.03886110847815871, 0.03775726399908308, 0.04539558147371281, 0.03716777981026098, 0.04405847626912873, 0.06080574734369293, 0.053384292841656134, 0.015465156229765853, 0.04613236342265736, 0.03602197801228613, 0.007852646012906916, 0.03654397871287074, 0.06779730538255535, 0.040288763120770454, 0.027151578506163787, 0.012705334447673522, 0.031293128049583174, 0.06785424295230769, 0.03264492406742647, 0.008368025828531245, 0.040776966416160576, 0.07944313125335611, 0.05384680669521913, 0.06490410945843905, 0.09987297249608673, 0.030229283474909607, 0.0354404682002496, 0.0455949928436894, 0.04845750467211474, 0.09263268366339616, 0.053002828935859725, 0.02628115616971627, 0.02788860165310325, 0.05726665287511423, 0.0513359021715587, 0.08445555213256739, 0.047015426389407367, 0.03746790433069691, 0.04179961251793429, 0.07772746394039132, 0.009416058019269258, 0.017830969954957254, 0.04164350175415166, 0.0423118762410013, 0.02705244427488651, 0.03668371769890655, 0.04032798562548123, 0.0393097256164765, 0.10813756613060832, 0.0332793081906857, 0.04047473048558459, 0.04586513830872718, 0.02096154923492577, 0.05271378468023613, 0.01961441019375343, 0.04663439292926341, 0.08358047838555649, 0.06141368503449485, 0.03927508587366901, 0.10520427938899957, 0.024346605387108866, 0.02500147464161273, 0.062296877877088264, 0.04525609110714868, 0.0195113258814672, 0.041457578918198124, 0.06352587442961521, 0.03816234675468877, 0.024185587171814404, 0.05419438784883823, 0.0524104948999593, 0.0274055618501734, 0.05606770588201471, 0.0598852875555167, 0.03095719490374904, 0.053757255445816554, 0.0267820613225922, 0.11003847350366414, 0.0638921168865636, 0.051484654541127384, 0.04469895713555161, 0.009932500961440383, 0.05300694043398835, 0.03579034630092792, 0.030456658969342243, 0.024795745739538688, 0.008466710132779554, 0.039755303660058416, 0.044281729133217596, 0.026512069853197318, 0.02569026004493935, 0.046048445074120536, 0.0683657533954829, 0.026103760610567406, 0.06475182075519115, 0.0655269791604951, 0.07296815994777717, 0.05163762973097619, 0.03400477238756139, 0.028918290736328345, 0.022332527914841194, 0.031034567509777844, 0.05734194375691004, 0.0304606962527032, 0.026596552233968396, 0.03801576516707428, 0.03320382806123234, 0.020436952872842085, 0.040808121775626205, 0.05555851093959063, 0.05997145832225215, 0.06149787055619527, 0.04324418070609681, 0.016262991885014344, 0.010424872343719471, 0.04576549385092221, 0.053438699687831104, 0.014330097947095055, 0.03364712028997019, 0.05246219290711451, 0.02236519540019799, 0.03650686390756164, 0.03044824487005826, 0.04477273774682544, 0.02535241401346866, 0.009131837723543867, 0.05627243474009447, 0.03458519866399001, 0.0501410666765878, 0.00787992736150045, 0.038284029287751764, 0.0865277842967771, 0.020201851621095557, 0.051063931023236364, 0.029902218993811402, 0.0478520939941518, 0.02797113218548475, 0.01594039327756036, 0.013263947148516309, 0.024142564870999195, 0.0870209933782462, 0.032054463954409584, 0.05132537851750385, 0.027238849506829865, 0.04435632610693574, 0.03775758312258404, 0.03834580937109422, 0.03080829596001422, 0.040458547955495305, 0.02688337004656205, 0.04671811831940431, 0.013624543717014603, 0.02503429241187405, 0.03170920943375677, 0.021658819241565652, 0.032885906839510426, 0.012391960735840257, 0.008634283367427997, 0.018086124036926776, 0.016586505189479794, 0.09118931775446981, 0.023796102505002636, 0.02477651298249839, 0.01231209265824873, 0.03907549638825003, 0.03788894697208889, 0.06947614732780494, 0.009837160032475367, 0.06433555012336001, 0.10375352168921381, 0.041147056908812374, 0.03161343156534713, 0.029972684060339816, 0.02992475430801278, 0.02846503703040071, 0.017239363223779947, 0.08010109711904079, 0.012789109005097998, 0.15313653275370598, 0.14023790223291144, 0.21155897673452273, 0.19979733129730448, 0.1487662032013759, 0.11841559899039567, 0.08041611654334702, 0.18878896575188264, 0.13975949899759144, 0.1113587393774651, 0.235430542670656, 0.08703013663762249, 0.13985197059810162, 0.12722829094855115, 0.20966169104212895, 0.10953165343380533, 0.19038510276004672, 0.1211229462933261, 0.140474988729693, 0.16655339015414938, 0.2062881994061172, 0.23373751086182892, 0.17545720300404355, 0.10952202035696246, 0.11103590513812378, 0.10544823817326687, 0.10823449061717838, 0.31683005683589727, 0.2418019695323892, 0.1833790505770594, 0.0722688267705962, 0.13962739671114832, 0.1110066422552336, 0.17943892918992788, 0.18415898841340095, 0.15357419208157808, 0.23141500423662364, 0.13397515547694638, 0.09937422699294984, 0.15963494108291343, 0.17073558527044952, 0.11370420063030906, 0.14061846071854234, 0.12183643964817747, 0.14675964368507266, 0.1780958051676862, 0.1424431792111136, 0.14434757467824966, 0.10599672241369262, 0.1203517583780922, 0.1821738324360922, 0.15640374884242192, 0.07016360614215955, 0.13180708978325129, 0.14482640835922211, 0.1382890372769907, 0.13697867165319622, 0.15902703307801858, 0.13345523650059476, 0.13053568691248074, 0.1527573843486607, 0.13127212005201727, 0.10973379961797036, 0.13343683123821393, 0.2557459002127871, 0.18288592313183472, 0.09983155323425308, 0.13331290741916746, 0.19774679210968316, 0.18266658880747855, 0.15339171281084418, 0.11596187323448248, 0.11179501088918187, 0.1501058688154444, 0.12691080017248169, 0.19101218786090612, 0.13621645630337298, 0.12424944376107305, 0.2193858739337884, 0.1077526067092549, 0.18195184122305363, 0.17953352333279327, 0.2260628281510435, 0.1497478864621371, 0.10486637955182232, 0.1877653066185303, 0.19873830140568316, 0.12289525431697257, 0.096744211477926, 0.17694121634121984, 0.15856795536819845, 0.22158647538162768, 0.10143572770175524, 0.09268156150938012, 0.14076659339480102, 0.19845879374770448, 0.1189743768190965, 0.14085845643421635, 0.1534604059997946, 0.10227562364889309, 0.16889235761482269, 0.14081888512009755, 0.10909471398917958, 0.15655142138712108, 0.17524649243569002, 0.11221517037483864, 0.1781639046384953, 0.11496707622427493, 0.18206849199486896, 0.15841403394006193, 0.11928993801120669, 0.2250552736222744, 0.11347553008818068, 0.21512890001758933, 0.13758689136011526, 0.12830479099648073, 0.1702879960066639, 0.11085109552368522, 0.07754433900117874, 0.10173466478590854, 0.14028296543983743, 0.1624081688350998, 0.12234584981342778, 0.1185988872020971, 0.13657175208209082, 0.14256823109462857, 0.33352131431456655, 0.06995362287852913, 0.11853608666569926, 0.20344543241662905, 0.11808202587417327, 0.11456871361588128, 0.11689093080349267, 0.12986981717403978, 0.12713432020973414, 0.17728698294376954, 0.12662897701375186, 0.1863279743702151, 0.20457603503018618, 0.111926667887019, 0.16102097608381882, 0.16221788217080757, 0.14469745277892798, 0.1257777781574987, 0.10316466461517848, 0.09850336122326553, 0.20699917688034475, 0.10096066413098015, 0.12255094974534586, 0.10765988277853467, 0.137988333881367, 0.08753977686865255, 0.13283634471008554, 0.09387434125528671, 0.13911304384237155, 0.10091573451063596, 0.1893599593313411, 0.15495669445954263, 0.1900358183775097, 0.11349396503646858, 0.09861636804998852, 0.09493807636317797, 0.19716448819963261, 0.124975471990183, 0.14620460628066212, 0.10547635814873502, 0.13251226366264746, 0.1502489103586413, 0.18682969588553533, 0.10043880072771572, 0.1743591361446306, 0.10906035255175084, 0.12240605283295736, 0.18446507980115712, 0.1481950908782892, 0.097613244142849], [0.029401178398984484, 0.036190864848322235, 0.023817446672182996, 0.04248757228197064, 0.018606974408612587, 0.020927057921653613, 0.032634129529469647, 0.04221780902298633, 0.022625433193752542, 0.06106143206125125, 0.06368827118421905, 0.0930426905688364, 0.06378427540767007, 0.009593297727406025, 0.08023892136407085, 0.03442607478064019, 0.05835952841152903, 0.027774936170317233, 0.031271071420633234, 0.03165783055010252, 0.04269925877451897, 0.03418627573410049, 0.02788785579468822, 0.032112225308083, 0.04540196394373197, 0.04315560909162741, 0.0325975564919645, 0.03459902487520594, 0.037060131289763376, 0.10306054871762171, 0.06782615266274661, 0.05108049575937912, 0.06284421178861521, 0.024763308319961652, 0.011833805383503204, 0.021342977888707537, 0.04493822554650251, 0.07673778774915263, 0.02413366466498701, 0.02598386850877432, 0.10996802142472006, 0.09677697729784995, 0.05436837695015129, 0.04122450372960884, 0.034630577283678576, 0.020641121409425978, 0.05077095338492654, 0.030694183333253022, 0.08205617385101505, 0.019053261203225702, 0.015297872432711301, 0.014708562648593215, 0.013633493090310367, 0.03507806635752786, 0.04243845694873016, 0.01254237737157382, 0.023525341057393234, 0.016909975820453838, 0.04907900882244576, 0.019399645643716212, 0.049310117319691926, 0.04270885474397801, 0.05356614499760326, 0.1415988674852997, 0.03235605050576851, 0.0745611873571761, 0.04153483278059866, 0.0580592703045113, 0.03679904744785745, 0.025540073474985547, 0.05855726252775639, 0.03043913315195823, 0.04506404926360119, 0.06850022313301452, 0.018006261525442824, 0.08070743919233792, 0.0633626984199509, 0.009933702312991954, 0.04487992984650191, 0.062207964874687605, 0.18709755182499066, 0.04208098667731974, 0.023668078320042696, 0.012930707998748403, 0.06570609650225379, 0.03274379669164773, 0.04548005272226874, 0.11688764308928512, 0.029247963866509963, 0.04258976972778328, 0.08186437320546247, 0.012984252098249272, 0.048918897882686, 0.020404372589837294, 0.02805655894917436, 0.03216539647837635, 0.045138761270209216, 0.04198656322841998, 0.044941364831174724, 0.06611703109228984, 0.09285572872613557, 0.06693308183457702, 0.026874195245909505, 0.024658426154928748, 0.03322803691844456, 0.03724755697476212, 0.03845087150693871, 0.07598325362778269, 0.08172643021680415, 0.029287394172570202, 0.026703401090344414, 0.0367697548790602, 0.04388417917652987, 0.10919877793639898, 0.027179798671568278, 0.03370709695445839, 0.020571183267747983, 0.05339470888429787, 0.061706543929176405, 0.02255385676107835, 0.07308535990887322, 0.05321964366885368, 0.03816182725131512, 0.05860260032932274, 0.07013241367531009, 0.07002973012276925, 0.05136332823894918, 0.05253613679087721, 0.1046586969459895, 0.010460237535880879, 0.009177217270917026, 0.02811432772432454, 0.023445777260349132, 0.02847565345291514, 0.03399773682758678, 0.03903857454133686, 0.07099497481249273, 0.03043704400624847, 0.02410063723800704, 0.06679092344711535, 0.03888845290930476, 0.011429255118855508, 0.052499274315778166, 0.03412139347346965, 0.01788452333130408, 0.018213378243672196, 0.05653289146721363, 0.01025892534016748, 0.05174655103473924, 0.015045466152514564, 0.09009162939037196, 0.012669517473113956, 0.07004772720392793, 0.008736060572118731, 0.021293146382959094, 0.028217079925525468, 0.1055812681443058, 0.018413272009638604, 0.016730012430343777, 0.027479882373881992, 0.03777906087634619, 0.06388541529304348, 0.030686563331983052, 0.03525894630001858, 0.055952888214960694, 0.026916540336969774, 0.03831974885542877, 0.04883780340605881, 0.007903465502749896, 0.004860810313402908, 0.019025196888833307, 0.09374529661727138, 0.057024059642571956, 0.008374479730264284, 0.040533092978876084, 0.0327845257561421, 0.06982178034377284, 0.014117542214080459, 0.03206157372915186, 0.04773447843035683, 0.03731439479452092, 0.012477109194151126, 0.06129227338533383, 0.02597009424789576, 0.028433106126612984, 0.027837168963742442, 0.033676939783617854, 0.08430846588453278, 0.021799595378979575, 0.0436828604870243, 0.048118599224835634, 0.046449394067167304, 0.05720382265280932, 0.006317578017842607, 0.04198939823254477, 0.005476118458318524, 0.0597525841294555, 0.046598866319982335, 0.024470725875289645, 0.015119300569494953, 0.02226227064966224, 0.06946490379050374, 0.015127402966754744, 0.038362158884410746, 0.018668008633540012, 0.0723334307258483, 0.025503277793177404, 0.006172089242681977, 0.04245228315994609, 0.029011029510002118, 0.07344599172938615, 0.05994880055368412, 0.09135691696428694, 0.06342776250676252, 0.011284552092547528, 0.022356825829774607, 0.0571396676969016, 0.07507329151849262, 0.07204997484222986, 0.040340427731280215, 0.01685862476733746, 0.02291218792379368, 0.06014965540089179, 0.032654026508680545, 0.010198352174484171, 0.042966194450855255, 0.06694598036119714, 0.020663712384703103, 0.011674898578348802, 0.08712603696039878, 0.047626807645428926, 0.04823801078600809, 0.04628614755347371, 0.007327762996283127, 0.011551532297744416, 0.05066276680736337, 0.023005882212601136, 0.017346442145935725, 0.03035203098988859, 0.06287062482442707, 0.008271901933767367, 0.018357709268457256, 0.0031325777445090353, 0.03604822406487074, 0.058760559040820226, 0.012277038240426918, 0.008785492245806381, 0.03617795147874858, 0.023010323966445867, 0.020225557673256844, 0.05520347120182123, 0.036509442870737985, 0.0614990134636173, 0.056329695144086145, 0.07897815346950665, 0.06120805075624958, 0.03112478483672021, 0.0382709637779044, 0.05395095227868296, 0.007763800731481751, 0.06768071398255415, 0.06981224374612793, 0.051735997694777325, 0.039573399553773925, 0.04260126930603292, 0.010949870393233141, 0.01685395294771297, 0.0388895290234359, 0.006415132402253221, 0.01135914071710431, 0.0581659020826919, 0.09270761089283042, 0.03488268113869708, 0.02884857152821496, 0.041216648096451536, 0.03847327323455829, 0.02619254002638627, 0.12446576496586204, 0.023922766704345122, 0.057801288639893755, 0.05234298914729152, 0.0695260196516756, 0.03194901961251162, 0.060399662688723765, 0.05335208734322805, 0.057648625152069144, 0.0006637978708567971, 0.020730271899083164, 0.068268791801529, 0.17886524903587997, 0.0718366815999616, 0.035300462041050196, 0.03663814983156044, 0.05141420246218331, 0.055444249883294106, 0.03573774658434559, 0.05061082760221325, 0.055401398276444525, 0.10797162191011012, 0.05013745612814091, 0.030158311892591882, 0.04282656307623256, 0.03687076117785182, 0.0870979021419771, 0.09289351146435365, 0.03133800571959, 0.002844004752660112, 0.0879147469822783, 0.017581955289642792, 0.07080183087964542, 0.10040669541922398, 0.03527994907926768, 0.027687392430379987, 0.03393222374143079, 0.0992219457111787, 0.011441321512393188, 0.04923706401314121, 0.06641023137490265, 0.06436874638893642, 0.02708201700443169, 0.0727375375572592, 0.027587241456785705, 0.010192209047090728, 0.007966161210788414, 0.0387207720632432, 0.027758928044931963, 0.06421161146136001, 0.04170658430666663, 0.04430626082466915, 0.022519230005855206, 0.034305661320104264, 0.0830693835450802, 0.08066648006206378, 0.051331271170056425, 0.028749800949299242, 0.04294667225622106, 0.05578185657213908, 0.04993450471374672, 0.06202332595421467, 0.03296581387985498, 0.028041276273143012, 0.02040183073404478, 0.019253709724580403, 0.02978043441544287, 0.028861477476311848, 0.03304096004285384, 0.04311132142902352, 0.0596379408671055, 0.05239545527729206, 0.03239146579289809, 0.010501007418497466, 0.03360873641213402, 0.198662735929247, 0.12247620805283077, 0.16556480491999537, 0.08199260148103349, 0.11555235614650883, 0.09524963737931103, 0.12638169340789318, 0.14066232164623216, 0.08910379372537136, 0.1479432059568353, 0.21964898012811318, 0.15941964404191822, 0.18014870438491926, 0.1347668340895325, 0.1823572171269916, 0.08959629776654765, 0.16664685623254627, 0.05545320389501285, 0.1317318360088393, 0.13880383543437347, 0.13332366856047884, 0.07883048092480749, 0.14168207708280534, 0.14175310061546043, 0.14748996152775362, 0.21983376005664468, 0.11275844473857433, 0.1241957642196212, 0.12514313799329102, 0.25454593647737056, 0.08104153181193396, 0.09761193054146133, 0.1270838690106757, 0.13758959277765825, 0.13615619391202927, 0.1631801508483477, 0.11472883939859457, 0.24473771278280765, 0.09537143123452552, 0.1260508588165976, 0.1772881406941451, 0.21112688351422548, 0.1256023344467394, 0.10668835951946676, 0.09839960155659355, 0.11765169896534644, 0.10930687174550258, 0.1388596449396573, 0.16591321356827393, 0.10378308885265142, 0.14016986213391647, 0.08640059502795339, 0.09541166306007653, 0.1549260734464042, 0.13753244740655646, 0.0674506853101775, 0.2022003461024724, 0.1386787390219979, 0.17299874976743013, 0.1508415598073043, 0.14643952570622787, 0.1619377065799199, 0.08977580844657496, 0.20689052646048367, 0.09559883270412683, 0.12955427082488313, 0.12231368513312191, 0.121497307845857, 0.18521549500292167, 0.12153436327935196, 0.15915131312794983, 0.13056624855380505, 0.11381078787962906, 0.1490856532473117, 0.08917793427826837, 0.17776970547856763, 0.13585115637397394, 0.19426687649684027, 0.12398553604725748, 0.14498363976599649, 0.3252469911240041, 0.15965134254656732, 0.13024172221776098, 0.126582162338309, 0.1393844620906748, 0.11269196314970031, 0.33836563874501735, 0.1807782831019722, 0.13684486242709681, 0.11989736362011172, 0.23939732200233266, 0.09493998368270695, 0.1564495245111175, 0.16628004232188687, 0.10172487585805357, 0.11311347334412858, 0.12201187593745999, 0.11694423184962943, 0.22889887128258124, 0.09115511216805317, 0.191361635515932, 0.340433232486248, 0.14662360801594332, 0.1194950973149389, 0.1611605889047496, 0.14045725140022114, 0.175383715541102, 0.1508221897529438, 0.1630424230825156, 0.1721086326870136, 0.08599143417086452, 0.15705652709584683, 0.13869512564269826, 0.28256931400392205, 0.17329546040855348, 0.09570502661517821, 0.12628125114133582, 0.1429601147538051, 0.19355695287231356, 0.10345138594857417, 0.08191833476303145, 0.12451477639842778, 0.1579398164176382, 0.13762852584477514, 0.09169719909550622, 0.1660720183281228, 0.20576912647811696, 0.1871642263722606, 0.27830989100039005, 0.1248862806824036, 0.07783632216160186, 0.11883664905326441, 0.1842474821023643, 0.14530938322423026, 0.16057859669672325, 0.09312032663729042, 0.2692693448625505, 0.08369356684852391, 0.12459936639061198, 0.135791250213515, 0.11212409401196055, 0.1462053187424317, 0.1182531205995474, 0.07117309025488794, 0.15953479567542672, 0.14017349865753204, 0.21618600032525137, 0.06103256622736808, 0.11915144583326764, 0.09746995769091882, 0.19773416075622663, 0.1349973600008525, 0.22756931371986866, 0.08897000676370226, 0.12596871791174635, 0.20871555665507913, 0.22577572090085596, 0.14517431234708056, 0.11403958458686247, 0.09437494212761521, 0.25171030894853175, 0.1262021975708194, 0.12549534643767402, 0.09037892959895544, 0.23512315994594246, 0.12681487016379833, 0.09508348535746336, 0.1677591129555367, 0.13825141038978472, 0.1379080631886609, 0.11920814591576345, 0.18952863465528935, 0.18163852131692693, 0.12318256194703281, 0.07765042901155539, 0.12603234965354204], [0.02212014380347682, 0.06442337587941438, 0.07021434677881189, 0.04127017920836806, 0.029627837720909156, 0.044204979931237176, 0.039769278300809674, 0.005955860342510277, 0.04151401182753034, 0.069760219193995, 0.02785802887956379, 0.05541155085666105, 0.05280077180941589, 0.041353188426001, 0.0679070244950708, 0.012085075250070076, 0.025928157338057645, 0.05925381265114993, 0.039824880004744045, 0.06455689566791989, 0.03158781262754928, 0.05939275011769496, 0.022536353208124638, 0.013596993339888286, 0.08982309809653088, 0.026228317110508215, 0.03514246622216888, 0.04334068587922957, 0.023664976142754313, 0.04750179658003617, 0.036123110476182774, 0.010448249995533843, 0.01315425864959252, 0.09351656670332886, 0.04715190363640431, 0.014340585421450669, 0.022593014327867422, 0.03256681302445941, 0.061235153989400715, 0.09511874479358084, 0.01869894320407184, 0.026122921008209232, 0.11697408845066093, 0.030069356216699816, 0.01857287272287067, 0.09751699501066469, 0.018970123965118546, 0.052465109547483735, 0.06213327884324826, 0.0865709179197438, 0.02901969593949616, 0.032707424034015276, 0.017256703504244797, 0.020319611903687473, 0.04497440895647742, 0.054453397387987934, 0.07282381964614615, 0.04386283129861113, 0.03218077377823647, 0.018101260138791986, 0.04263410191924777, 0.010471545083419187, 0.006299104570643976, 0.02150460652046604, 0.02821508725901367, 0.1275039542815648, 0.030419662907661404, 0.0326724057958927, 0.016242760939348955, 0.03942796458431985, 0.03475859404716175, 0.011770424116548384, 0.01785136973921908, 0.04581208217132371, 0.05455176535178907, 0.020128109972574748, 0.02388286327914102, 0.045901106495875865, 0.006267758108151611, 0.040130834095180035, 0.0296497607632773, 0.059389198941062205, 0.021836595151398797, 0.022033139975974336, 0.0245268841899815, 0.056447941533406265, 0.06092352246923838, 0.056870809858082794, 0.018839222102542408, 0.012412593368935632, 0.09039001728524454, 0.06320119966403581, 0.04876630118815228, 0.017702971745165996, 0.020037623617099598, 0.01655910695262719, 0.012221288106957218, 0.05487509311933536, 0.06346686626784503, 0.055207779369084165, 0.025572401427780278, 0.03788836438616272, 0.026127056626137346, 0.04669462563470006, 0.004286861594664515, 0.010847492976608919, 0.06540266942465678, 0.04769998340634629, 0.06325877548079006, 0.03525712432747241, 0.05151269659108948, 0.02108987027895637, 0.02163135606679134, 0.04502929819864221, 0.02650131984410109, 0.03271050765761174, 0.020435646692931186, 0.05495785371749662, 0.09686933757620864, 0.01588657272804994, 0.03648889280157164, 0.012894164647150319, 0.0351162127481075, 0.007467252899004961, 0.02119552984368056, 0.037573152003460564, 0.02046286124823382, 0.023957354496815242, 0.017699758245726116, 0.021096020827826578, 0.06802647316362709, 0.04327737326093484, 0.07183421024819836, 0.02960157311463263, 0.04165496793575585, 0.060316909512039274, 0.029617187901749276, 0.07246586697874591, 0.04725899554614443, 0.018212953364127316, 0.0875827694835607, 0.018125129463442136, 0.04534534178674221, 0.0258610412129201, 0.04506408266024664, 0.018846049861167558, 0.009658191120252013, 0.04059896229591686, 0.021377285520429723, 0.04164303791185375, 0.01889166782348184, 0.04037608050566632, 0.022679864159727003, 0.060976697350270115, 0.016062576760305092, 0.09013135655550286, 0.09029223190736957, 0.01680534227489261, 0.05840188649017364, 0.010219330833933782, 0.032426461766590364, 0.029157390308682807, 0.05381310205848422, 0.019925203087041155, 0.02955369902338134, 0.016777843848103657, 0.020823860431846697, 0.02181750154704787, 0.033802770922193304, 0.05903819648665376, 0.06316884202533402, 0.04489718106924556, 0.0748645921703428, 0.03900534116837662, 0.08346002781763673, 0.030445422853517812, 0.07123339717509225, 0.07052156623103656, 0.017841875815065578, 0.06296156017924659, 0.03432808160141576, 0.01826871834055055, 0.025827512836258393, 0.020541187514027115, 0.039316905895248055, 0.02542537826229818, 0.04923527914797887, 0.018658696535567287, 0.01661179201619234, 0.02106038104102481, 0.031600518195773475, 0.01542994503324735, 0.08607181618572213, 0.03916131092410069, 0.03060404949792428, 0.04897524915577378, 0.0281076966348337, 0.03659701258584391, 0.02716070692258654, 0.08555222375434823, 0.07235286015202291, 0.08605504364822991, 0.07184605492511764, 0.04243038609274663, 0.04145330414758064, 0.04143194884818513, 0.016159731312654912, 0.05853113892953843, 0.023673323448747396, 0.029143000065232627, 0.03343517775647342, 0.005488333281391533, 0.020402368791110348, 0.04973843300831504, 0.012428784248186275, 0.0770586627186276, 0.029430498798319604, 0.048029352255980484, 0.03633035521488637, 0.07901518663857132, 0.0445457184832776, 0.11174619241501205, 0.04352716532594059, 0.056135489940061234, 0.02716581289860187, 0.05716333107557148, 0.014951437897252617, 0.00224656497266551, 0.08782028642599471, 0.0477491135825403, 0.01948048964550253, 0.03337446636578534, 0.027975722368864808, 0.010419812751933932, 0.03309649495349731, 0.006758152594557032, 0.06091195980843622, 0.030839460596325807, 0.010132349270861596, 0.09323706646682695, 0.022791351439082064, 0.023571634374093264, 0.06760519303497858, 0.08162706406437792, 0.049287314832326956, 0.07207762726466171, 0.04130240326048806, 0.0169348822964821, 0.07236891280626878, 0.041654767555883154, 0.024975874257506803, 0.028001319042232353, 0.04742219753097743, 0.018379071989329532, 0.014894078231009189, 0.010496238191990415, 0.05638882204948459, 0.06461792989284731, 0.012955347301613074, 0.083265340217622, 0.0602336219890276, 0.032791895282571204, 0.04519240370427724, 0.015367985906777903, 0.03171079391904641, 0.052643499584519304, 0.03594950358092319, 0.031254053974407725, 0.061336713188211434, 0.052781724589294754, 0.008933641620387789, 0.03852939073112793, 0.054619393558823504, 0.049763076021918096, 0.02389488792687189, 0.05447594383440446, 0.0456779204250779, 0.02167970327718649, 0.06302985260845162, 0.052341115224407986, 0.10803857105202042, 0.06736648865626194, 0.058001412471639924, 0.043222632448305376, 0.04175435264187399, 0.01166162433946738, 0.035075283303740434, 0.04526219898252748, 0.039301172364503145, 0.10564654745394364, 0.02464176679495722, 0.029325277100724634, 0.051126163816661574, 0.019275491758889984, 0.03520851365465205, 0.028229473791725468, 0.0034696612192419707, 0.029984936918481253, 0.02637365374539513, 0.030622818412666675, 0.014001826548337704, 0.011367900842742529, 0.046458470533252694, 0.011042268706660252, 0.037428622454172, 0.04959215941198636, 0.052247025741962716, 0.061581722111441195, 0.07023452577413991, 0.013662511064467253, 0.050051541402353905, 0.03865408638375811, 0.03694674596772529, 0.12394235047395341, 0.043255624623270705, 0.05216426885453984, 0.029441684819175862, 0.010713731062423903, 0.09599127297406085, 0.03494983437121846, 0.01489078495069407, 0.016790120826044586, 0.04526797289145179, 0.02862512756109936, 0.01017601909552468, 0.005426314783107955, 0.026860645484703127, 0.028235804311407264, 0.0485108502471121, 0.023223671014420688, 0.15528975549386814, 0.029595886408060323, 0.028764792332367506, 0.002407393940302427, 0.08771867898758501, 0.02164697456464637, 0.027616496918199118, 0.027785450547526125, 0.015403228644572664, 0.04357111902208999, 0.02503632589650806, 0.018436282298353035, 0.014307854853541357, 0.0595045286900131, 0.014304272135632345, 0.039545717445435, 0.12300910719204694, 0.021175226538616698, 0.03950637619709596, 0.017424670077161863, 0.018818788921635132, 0.0497635843930766, 0.09484949361649342, 0.12900785717647523, 0.10028010729001835, 0.15656800096621737, 0.09539411126752384, 0.1326893104123883, 0.056889723491622135, 0.10262097464874387, 0.15290337963961065, 0.17558574298163876, 0.11847785033751279, 0.14716398058226332, 0.11148691570269875, 0.06585578026715666, 0.13315727905137464, 0.13136720401234925, 0.16945037845289335, 0.17906804831000045, 0.1636681574746035, 0.15392922068713233, 0.10268075464409776, 0.2059671314782463, 0.1012984303815756, 0.1662023097742349, 0.18930965656181797, 0.1791004801634699, 0.11163476636284031, 0.08318359265103936, 0.2063229022314772, 0.14824352343566716, 0.1306017825845629, 0.14037603075848892, 0.14007688587298617, 0.14427288493607193, 0.11319468656438403, 0.1162761653540656, 0.10742129714344628, 0.11754608392948285, 0.14495677402010188, 0.2272755716694519, 0.15772106096846983, 0.0775568738754373, 0.14346657117130235, 0.17876744881505147, 0.09823143089306541, 0.2052056582760997, 0.12354099701042287, 0.12747309578116983, 0.07804449458490126, 0.17929910856764764, 0.09229562245309353, 0.13352403359021991, 0.1979811178171076, 0.0797496159793809, 0.15937015763483942, 0.13240049622254446, 0.15622365928720683, 0.11703780182870105, 0.12217669209348969, 0.10002090479247272, 0.2891947631724179, 0.20328915095888078, 0.10939129104372114, 0.18107241106918082, 0.07946188532514498, 0.23351140815066174, 0.17235208681086078, 0.16858473740285262, 0.0771593647368718, 0.1536306695197709, 0.16760675003752112, 0.1138688312494196, 0.17572103650309145, 0.16087348165456206, 0.21336865931516513, 0.08998575460282154, 0.15916700212983415, 0.13654485665028915, 0.06732467605615966, 0.10214787034783512, 0.15699687326559797, 0.1525207728263922, 0.1841759539092891, 0.1649983978131786, 0.1283559695002623, 0.2345978084485978, 0.1282386656384915, 0.11429092031903565, 0.14359871798660606, 0.13135791232343763, 0.17818613938288763, 0.12088583011063747, 0.09644758247304708, 0.24643219920108095, 0.06278842454776168, 0.1265932054957375, 0.10634699385263957, 0.2189573727082461, 0.1815061370143667, 0.1537319429917261, 0.13524529669666663, 0.11128199388622306, 0.13439568603644148, 0.1237297325860709, 0.09118149551795796, 0.09961328018107451, 0.16785765532404184, 0.12407175134285353, 0.1482980267610401, 0.09061164484592155, 0.19930322421714664, 0.1318089006235823, 0.16938955202931538, 0.19621418294264004, 0.08988626970676705, 0.15345151507062837, 0.18550040549598634, 0.173437433259096, 0.1557476309244521, 0.17589058756129816, 0.13360274577280506, 0.15289837756427005, 0.08554314728826284, 0.10363289300585166, 0.1244882149330806, 0.11433473671786487, 0.11005940948962234, 0.12702498701401055, 0.14576849061995745, 0.16545628808671609, 0.19017581711523235, 0.21355088625568897, 0.23324655048782006, 0.12390834526740946, 0.15303364139981568, 0.08368727343622595, 0.13145071046892554, 0.2532492857426405, 0.178465275967028, 0.13143450196366757, 0.2322472189553082, 0.08292442726087756, 0.24143445800291374, 0.21250453224638477, 0.0909097952535376, 0.10888419637922198, 0.08578075328841805, 0.09183898640912957, 0.09731474492582493, 0.12024667026707903, 0.06226862431503832, 0.12312903825659305, 0.1204372315260116, 0.11485909373732284, 0.20658639434259385, 0.25838257279247046, 0.13857486803317443, 0.11466703334008344, 0.21685804473236203, 0.09913863963447511, 0.09468606527661905, 0.1521353903808631, 0.13084621634334326, 0.09023094535223208, 0.08481691125780344, 0.1344204440829344, 0.14202019956428558, 0.25023765047080815, 0.09817096070037223, 0.1325703738257289, 0.21510417165700346, 0.14050791040062904, 0.12026758398860693, 0.11096714515588246, 0.11081200660555623, 0.13383880810579285], [0.03742324930499308, 0.08462850222713314, 0.04817883935174905, 0.010071531196444994, 0.052190529750077985, 0.05678950015862938, 0.06557511485880241, 0.03515716816764325, 0.022580052718694787, 0.020317917951615527, 0.019254939834354445, 0.07703305120230652, 0.01555239661684027, 0.04326418158598244, 0.026112759151146747, 0.05984640272799879, 0.017026368695951533, 0.02483951575413812, 0.021697104784834664, 0.0371713384083705, 0.01713646259304369, 0.02679516765056178, 0.019007249902642798, 0.09870109162875451, 0.026173902842856478, 0.04459768737433478, 0.03611779669881798, 0.060835477779619396, 0.046883854738553055, 0.04884361071162857, 0.0339381089725066, 0.010033394082711311, 0.05643267184495926, 0.010582217855699128, 0.02616221030621091, 0.019159161965944804, 0.025863332593871746, 0.023705076237092726, 0.028297543576627504, 0.030685372184962034, 0.035372780621401034, 0.034944446379086, 0.02161064086976694, 0.04967103115632199, 0.04146694853261579, 0.0372927982971305, 0.06001534151437227, 0.04750261294248048, 0.020328404498286545, 0.03699480745126493, 0.02935710595920682, 0.040891275712056085, 0.059364400076447055, 0.008797920436336426, 0.04264813593181316, 0.05296382907545194, 0.03352485888171941, 0.012401968597259838, 0.01943408129591262, 0.03638696623966098, 0.04398326331283897, 0.04491563457122538, 0.018613585089042317, 0.00945808398682857, 0.07168132040533237, 0.07393770167254843, 0.10213937275693752, 0.02847116717020981, 0.06924422617885284, 0.03955426698666997, 0.021466293146659154, 0.05868015105079394, 0.0346000527497381, 0.07285809944733046, 0.03321962838526815, 0.08034520433284342, 0.0645344085933175, 0.029219847601780202, 0.0420944752113428, 0.02638122736243531, 0.039606150530744344, 0.08708587192813866, 0.04571694626065437, 0.024492802913300693, 0.02530363079131348, 0.007903056393843144, 0.027368740193196572, 0.03614171611843631, 0.04558966793410946, 0.041162334018736146, 0.02899306025938131, 0.06637302009039558, 0.04138819553190842, 0.02120294204360107, 0.08578715060139075, 0.14641429268522188, 0.04301871253119316, 0.0640645474777557, 0.02020094991166843, 0.017227898897544947, 0.02467456230078824, 0.05480608451762237, 0.0750645119114779, 0.04701247264165431, 0.08149052373482846, 0.022118024971859995, 0.05361910465580877, 0.05575454924837686, 0.04991817746486049, 0.05011732908315025, 0.0997974218626041, 0.05468259485496674, 0.01580823904077988, 0.0017335834536424954, 0.08310766352224164, 0.03137321320537012, 0.0595617853832664, 0.05776729456556495, 0.01568133920955006, 0.04206757235806435, 0.016713837321731262, 0.05442466885142494, 0.0448095519823255, 0.0394430264714174, 0.05811666058434639, 0.02386586809734581, 0.012277394471311709, 0.04487676458666101, 0.09835648277658038, 0.015899944373813923, 0.017464135635236744, 0.06065787070838269, 0.0357267887738999, 0.030796608989476226, 0.021067156849312596, 0.015830438533157576, 0.02403660288109677, 0.03285817649157252, 0.01305728777879267, 0.01933483945322223, 0.03258990494941827, 0.027149795496370643, 0.022299528318399098, 0.032486089621670544, 0.045476204686565325, 0.05090583872515708, 0.04947782785166055, 0.0693513329315465, 0.06302036053966731, 0.05196564787183888, 0.07826684202882461, 0.05129387805936858, 0.09258983205654658, 0.08185090322513133, 0.0336213121045148, 0.02207406756497221, 0.03184673310897779, 0.05660479444486555, 0.019490172817313578, 0.026306545041734353, 0.08352029020898044, 0.023600105014338624, 0.042139252691413276, 0.05158551241038367, 0.04815933200006839, 0.0414124786038883, 0.00911078763238038, 0.0355179298639996, 0.03250249479606282, 0.04506517361733131, 0.04500525632465724, 0.0035642147759062937, 0.009895623643387808, 0.04891719094302971, 0.0883152469759807, 0.05185510126466397, 0.018382654707238544, 0.08453574861050583, 0.0254590587792336, 0.043029332664445974, 0.03894720874086488, 0.05326308528310619, 0.02052845597063424, 0.008680583177920198, 0.08189135027350858, 0.02238791810668772, 0.018984157977683935, 0.04212887375615537, 0.011431835937401047, 0.07581069687148556, 0.024719106004340574, 0.04324034751334693, 0.019569601172406692, 0.05400430898589548, 0.025155728180834558, 0.11894193012267351, 0.013640884881169768, 0.06326227099634707, 0.031001887036836706, 0.015988207996997517, 0.011989570120931603, 0.07108429228537716, 0.05589761305600405, 0.019074757510679774, 0.006725734656356508, 0.049440149014117196, 0.0018633727904671105, 0.00513238394887594, 0.053025768720544875, 0.005326095624695881, 0.020405200084496755, 0.040276747749885544, 0.03196769946953282, 0.025386844099557493, 0.11623867947491817, 0.02534125953388866, 0.03191041309037246, 0.07428055163472891, 0.05001906873076223, 0.015609584661433473, 0.018635062842804473, 0.06835005697212182, 0.040466603968525305, 0.03874881782394368, 0.02507144246919779, 0.054401343149947934, 0.016686517010384705, 0.024878376461856533, 0.04897558312222827, 0.07434720391756855, 0.0257091940875398, 0.011375749054423068, 0.013034131843596697, 0.020684258743131068, 0.019483241158013698, 0.016108608469949104, 0.05050136453064624, 0.08231151718064211, 0.03783601328905206, 0.024385106153204106, 0.07567806766019203, 0.025364811590407044, 0.10327493291697465, 0.04206568359222729, 0.04395510251924861, 0.01993425357795786, 0.04695952411566395, 0.09280732585466467, 0.0053341024704423035, 0.05913142507779412, 0.036491423525149, 0.056881645214161836, 0.05526360742805991, 0.03773453201574739, 0.07028364852885716, 0.06789780702092685, 0.01563263576827012, 0.09890438072034158, 0.01762571973813465, 0.05707015443476848, 0.039206967849167995, 0.02029421189945424, 0.05744548449001741, 0.03151408025587443, 0.06341965825413354, 0.013883606134186266, 0.07011447596596554, 0.025300523047917522, 0.06847106415079907, 0.052778269891859964, 0.018541144054324832, 0.1327445261995308, 0.04610117837728467, 0.09417942332220264, 0.009592200276529184, 0.02302635992236901, 0.029298997651494574, 0.0039697200918453746, 0.03768108996155206, 0.023174184607341886, 0.0288077292861999, 0.04772649292135611, 0.06891841592732817, 0.07374481749138795, 0.029916438543295953, 0.075374069128884, 0.015258840103342663, 0.04903115885099396, 0.01924796735693235, 0.03738469473319128, 0.03197863872628659, 0.04640287996153347, 0.04520287911873311, 0.03247951048251707, 0.04279080640117172, 0.04832159145735204, 0.06152861031296197, 0.06229052509297617, 0.03116676256468054, 0.020367834804346785, 0.008180538916349178, 0.02701645382330753, 0.011480745324661257, 0.009775289963727118, 0.09124074858846143, 0.03660056747321505, 0.03417198939132504, 0.016084351373137906, 0.04100522506632842, 0.049456650667707436, 0.03266478393925354, 0.045768514391966164, 0.030422004383581225, 0.01704385555058252, 0.020647576238843612, 0.03333631255372893, 0.012302420618652832, 0.10135901931789704, 0.024983362527564168, 0.00547252739124815, 0.08226422753068618, 0.03755767080292571, 0.062342542223632336, 0.02705333670746768, 0.02129320018866565, 0.010704766846174607, 0.008739686891203746, 0.03650370235845912, 0.09894340284517966, 0.038971117028268054, 0.038803194984211586, 0.037202567982603796, 0.06167554070998449, 0.03254255963838659, 0.07901405115262605, 0.016209998830163386, 0.043801158826681785, 0.09354820445878431, 0.015751843238831498, 0.026212930533802137, 0.09727765238494612, 0.07151720186811872, 0.04478020746319089, 0.004148411162532284, 0.030868504545651376, 0.032375635782955214, 0.028197348074172623, 0.004479782419366529, 0.004043259041281999, 0.047613393326173536, 0.00630810032816953, 0.03513406882120762, 0.20233756920788437, 0.2234124852111563, 0.13775948522379622, 0.13431336701614782, 0.11014338349923491, 0.1819741353392601, 0.16983518202323467, 0.1079324958845973, 0.13795400212984532, 0.16458815342048183, 0.06846750926342793, 0.15503950329730287, 0.13982299715280533, 0.1440239982912317, 0.11324338629492559, 0.15806403709575534, 0.11660012023639865, 0.0765691717970185, 0.14717971411300823, 0.19359440164407715, 0.1295007619773969, 0.12350731834885664, 0.1521016375045292, 0.19825250637950376, 0.15088254120200872, 0.17107176332501695, 0.10755825307569467, 0.11804879250121303, 0.10321441077394411, 0.21344849956221879, 0.054494538344442844, 0.18329141777940094, 0.1448878285009414, 0.06510400693514384, 0.12527316226623952, 0.09359409144963138, 0.14254915789933875, 0.1534854609053582, 0.13719500770093873, 0.11104810604592785, 0.11037108182790689, 0.22741315100574866, 0.12345988026936539, 0.18739414372248575, 0.14478202792815864, 0.15039947727927938, 0.15015517710708082, 0.20663172472268343, 0.1301542081637308, 0.17359258665237576, 0.11320165533106774, 0.10665488123777322, 0.11287999368505552, 0.1223312369256746, 0.10116747842403129, 0.24201581196393818, 0.09662128213676624, 0.1373334033996798, 0.07805625762557611, 0.10588456905679777, 0.13515371567336842, 0.25324661401100457, 0.14408619026653469, 0.10389343136921525, 0.20373242092318833, 0.09702774899778888, 0.3171551175182685, 0.09099910530494526, 0.1715734848403372, 0.09541282823192887, 0.08306636300403625, 0.14675243000965565, 0.11421845701988786, 0.13390549749601632, 0.14875189459417015, 0.15360991907073185, 0.1403987850062549, 0.14693256409373134, 0.14980213745729998, 0.1634140164242126, 0.09925369478878565, 0.24004974402487278, 0.2087392905377783, 0.12121513587771915, 0.09478462248807773, 0.19896703131962568, 0.13208253047196195, 0.13338591990759596, 0.16552021668758243, 0.21048719674581662, 0.1735474492306821, 0.1316996564855799, 0.14780537429032847, 0.11983983233221807, 0.20053026149980724, 0.27214487025048584, 0.12852983985794708, 0.21648467023624107, 0.08266063086921349, 0.048529248088016175, 0.08090064991847612, 0.10734603594755754, 0.13425875979010016, 0.10795731330290437, 0.13041418249486014, 0.1289134263060987, 0.1668217804399319, 0.13592348608653992, 0.15625301864929497, 0.2794752409681678, 0.11992039246251807, 0.20448535942705348, 0.08778614763286896, 0.1443459716392681, 0.17320993531029671, 0.1319396373583004, 0.2052932168589905, 0.1570515547064133, 0.17227037635166198, 0.25083214044570923, 0.14743302395800129, 0.21871227101655677, 0.12915441649965942, 0.13126049801940098, 0.136035060568247, 0.13868740730686113, 0.09523515807813965, 0.1496212463825941, 0.22173554316395894, 0.09779708154383115, 0.11670407286146656, 0.1286704619997181, 0.0763011971139349, 0.18390799406915903, 0.1609340705908835, 0.1253665838157758, 0.10646652415744029, 0.10295703395968303, 0.15625667001586407, 0.05178266765142325, 0.07655136767425574, 0.15755657135741785, 0.12312362057855353, 0.12604293267941102, 0.19166460988344625, 0.1093780882365536, 0.18929521436803043, 0.1453391878749244, 0.1574158898438327, 0.14354281942360103, 0.11791445635026321, 0.10065754133393057, 0.2436274747014977, 0.21781755262054503, 0.11722599563654512, 0.15382428100565448, 0.13836947124218568, 0.1351558679016307, 0.1802337248227559, 0.1542621778207831, 0.17466819612309337, 0.18029428407317027, 0.17768435849575326, 0.15578466409351677, 0.22868200088851154, 0.1314210839336738, 0.13483859976986423, 0.10367589304223657, 0.0935078167822212, 0.16072868864284828, 0.1018574382760562, 0.09813091441174038, 0.08448829568806104, 0.09404262324096635, 0.20036658825119957, 0.12802612938685343], [0.050009884653263725, 0.04648404865292832, 0.05772037970018573, 0.07917779119452462, 0.029615211933560204, 0.09315022776718251, 0.01683614325884264, 0.05208887036133092, 0.03731690325366799, 0.02463660144712776, 0.02013325305597391, 0.054146478505572304, 0.028371830703690648, 0.04348194255726412, 0.03010127598827239, 0.03009347230545245, 0.05410461395513266, 0.049781666821218096, 0.05364543976611458, 0.023414551396854222, 0.055105541105149314, 0.04756076763442252, 0.01630946517252596, 0.010004307459894335, 0.04087656634510495, 0.05068145408586133, 0.06470575564890169, 0.018685176364670042, 0.07794201883370988, 0.029116731748217717, 0.02540965586376842, 0.03022874727321323, 0.030498584746965207, 0.049284880587947555, 0.04910453128104564, 0.06856873820652254, 0.012565535162138985, 0.021449954765557777, 0.04861419431108516, 0.038158624884090386, 0.04254047256836202, 0.016328716483258177, 0.09176856401609257, 0.025962490944948513, 0.03328082959342282, 0.04389568988699466, 0.0048136268833332, 0.07238182617584243, 0.01415291297234944, 0.01666982610913692, 0.02322576016013045, 0.056892706925282255, 0.017891759271151386, 0.03996123108663596, 0.02500740625691833, 0.052270332889747806, 0.03696237559779547, 0.016886932135093957, 0.08779284922638908, 0.041608405590523034, 0.03507461166009307, 0.01148589675722178, 0.03666306001832709, 0.019582481145334896, 0.042599258085829206, 0.05251128226518631, 0.07179322885349393, 0.01753455617290456, 0.04414885501319077, 0.009097679449041607, 0.023693127659498714, 0.05040940872277133, 0.056554205948486924, 0.028977939000469632, 0.09924404686898924, 0.006667948719041306, 0.0460746577300597, 0.05580540491791908, 0.05421533867774997, 0.037265398204908706, 0.031293198553612456, 0.038755608475185, 0.030298149213194847, 0.016677436833560932, 0.02224470958026359, 0.05146440504177008, 0.05593853878963273, 0.10754814502433874, 0.029611801764986012, 0.07742768822936341, 0.02835528452123981, 0.07750306074740365, 0.01723868972476339, 0.029527859296649694, 0.053194555366644636, 0.059909347983193584, 0.04477336857235059, 0.02559787935751956, 0.05038149654865265, 0.048145557739189826, 0.043956401277682744, 0.01685698462097207, 0.038933671967242844, 0.04643101849069353, 0.04876095030340366, 0.07487564274924807, 0.10515701200347394, 0.06324796238914132, 0.07558299112133682, 0.10251245039398782, 0.04617010534275323, 0.03556340867362451, 0.03227948312996887, 0.02355551678192569, 0.030937103110773023, 0.019037683523492888, 0.08315355793456547, 0.02842101654096041, 0.02691386303922627, 0.013703129734494723, 0.04416861469508149, 0.06668522677500732, 0.016062795693869703, 0.059378378427936696, 0.028979536473343614, 0.013647366613440681, 0.10971983982017264, 0.0276121627757675, 0.053895825549261644, 0.05744624519138597, 0.03441025961365085, 0.026498149018152617, 0.014580910465156194, 0.04109005254576914, 0.02710594199015759, 0.0461476479540579, 0.03500992606859654, 0.05881198245333508, 0.04404838306072634, 0.03410889570659492, 0.04515681772318203, 0.050704189779935405, 0.06247176497709006, 0.03139342930808198, 0.0516396854800405, 0.030229979238356464, 0.032341793848900124, 0.031089247095223982, 0.08553678708267398, 0.02927095745690167, 0.01918717061926145, 0.03210061069694348, 0.019956902069679927, 0.08914709062082693, 0.0312716762709897, 0.020264897066226695, 0.04075339580595028, 0.046733280396438204, 0.011174281935382169, 0.00663015299323888, 0.03224556698114611, 0.04145339691604022, 0.04986645719327498, 0.05596221701125614, 0.06476417751400732, 0.015607888853992335, 0.08811122315819375, 0.038720946467947215, 0.0249068229823024, 0.07787512906361371, 0.04202361495117657, 0.020510111935436726, 0.015731677231087815, 0.05638453243591357, 0.006260364461923018, 0.026767105191538576, 0.018685731120058335, 0.04200210751150735, 0.0257983853953192, 0.01795587711967528, 0.032890574948396534, 0.11344671249389648, 0.04285296497982927, 0.016074881568783894, 0.0417510983243119, 0.02725866299442714, 0.04844770461204462, 0.026694482330640312, 0.08082815693342127, 0.03403970898943953, 0.03870758038829081, 0.006985486807025154, 0.03647807599918451, 0.0410388258023886, 0.012060124245181214, 0.041324920020997524, 0.014741674494871404, 0.03297597017080989, 0.010472033973201178, 0.0054315993384079775, 0.012812174954888178, 0.023000852306722663, 0.04345161469245795, 0.028656429494731128, 0.08208847211790271, 0.10040680674137548, 0.04912832453555893, 0.03913233376806602, 0.021209868136793375, 0.05166661801922601, 0.02715915583394235, 0.015720146111561917, 0.018365468422416598, 0.007009737410044181, 0.038579615575145, 0.06132492046162952, 0.052498227887554094, 0.009214666970365215, 0.04453548797755502, 0.06866020790766925, 0.008285093608719762, 0.06349350936943665, 0.02416777006146731, 0.035045586264459416, 0.025428387671126984, 0.028998229317949153, 0.057815322652459145, 0.04517673696682323, 0.024380146751354914, 0.026804262670339085, 0.02239451579953311, 0.05703652401280124, 0.08914855265174992, 0.045060312550049275, 0.017896945028041955, 0.033917588589247316, 0.019777191009779926, 0.034207386124762706, 0.02216303808381781, 0.014006920464453287, 0.043133741710335016, 0.019478702924971003, 0.05553648399654776, 0.027388642738515045, 0.01484569113017642, 0.013302107454364887, 0.06386906577972695, 0.08772466069785878, 0.005869180740774027, 0.06640042760409415, 0.014269483963289531, 0.05218229191086721, 0.09394386564963497, 0.08724127765162848, 0.013899569730710937, 0.06408390268916264, 0.035064934054389596, 0.08105791843263432, 0.020702617621282116, 0.05061266441771295, 0.04032752549392171, 0.028278542740736157, 0.049977556700468995, 0.02964403509395197, 0.06098838246543892, 0.04765770696394611, 0.029836670655640773, 0.0976095705118496, 0.033051086647901684, 0.01665109801251674, 0.020511329057626426, 0.05928261540248059, 0.024841981539793778, 0.07285014362423681, 0.0758055537880864, 0.032263174434774555, 0.021775462591904216, 0.034169124701293185, 0.024770588788669556, 0.04362347011920065, 0.024914172099670395, 0.05536313314223662, 0.06163675236166455, 0.03515554286423139, 0.06523041694890708, 0.07265732623636723, 0.0066566184432304, 0.04714933209470473, 0.01450688680051826, 0.0718983392289374, 0.013677203733095666, 0.03581482233130373, 0.02590931977465516, 0.024322214703715872, 0.014243482819438213, 0.04387427521578502, 0.11570898641366512, 0.01668544275162276, 0.023633765122212935, 0.06317296836641617, 0.02700071101571666, 0.02130573135218583, 0.04955269570928067, 0.0364209343388211, 0.03527247936290223, 0.033051190548576415, 0.03525376981997397, 0.02284171358041931, 0.02286361992446473, 0.02171803149394691, 0.027085013425676152, 0.017305596193182282, 0.024998700864671264, 0.04996934854716528, 0.02828914988640463, 0.059438844909891486, 0.018403473804937676, 0.037399559951154515, 0.07316764182178304, 0.026857899538299534, 0.03310666979814414, 0.023086902474460658, 0.03407022981264163, 0.04202088755846489, 0.05285883744363673, 0.06286731484578922, 0.03178724255121779, 0.062363129400182515, 0.028944865189259872, 0.04740483869682066, 0.016472138377139345, 0.053261697466950864, 0.05427097748906817, 0.036477048124652356, 0.06642916356213391, 0.041573394773877226, 0.06189459301822353, 0.07739248074358329, 0.05966020900814328, 0.06779710500268266, 0.02284065973071847, 0.03810370595601853, 0.06914445184520446, 0.039647773883189075, 0.02305549664015416, 0.017194524516526144, 0.07762179695419036, 0.04289488148060627, 0.02631606494105654, 0.026209683637716807, 0.013700884737772867, 0.015275394634954864, 0.16872089181561023, 0.14025071170181036, 0.17330825503449887, 0.1970852119848132, 0.09978131725802086, 0.2460747808800079, 0.1629527864861302, 0.10711045601055957, 0.10978749400237575, 0.0901871215319261, 0.1641198730794713, 0.14725956920301542, 0.1909898640587926, 0.12222053817822598, 0.13529579242458567, 0.1667573768645525, 0.15996632486348972, 0.18372125487076119, 0.10471297020558268, 0.19097169628366828, 0.20855427312199026, 0.17687326529994607, 0.07895274975453503, 0.08563229406718165, 0.13013979565585032, 0.14307826466392726, 0.09386437421198934, 0.10267057979945093, 0.15694801026256755, 0.1543435172061436, 0.07768538416712545, 0.12797837960533798, 0.06267178119742312, 0.11064037753385492, 0.12307298384257592, 0.24946676683612168, 0.17429681058274582, 0.13966110505862162, 0.11436450426117517, 0.08408742462052032, 0.18992182449437678, 0.08428104352788068, 0.16477671830216423, 0.11608953747781925, 0.19324560707900673, 0.2164237992838025, 0.1583860846585594, 0.12288206635275856, 0.11374573121429421, 0.13053409871645272, 0.12557014008052647, 0.1904463447863236, 0.1144251377263572, 0.09436741675017402, 0.13424069591565058, 0.15276908059604466, 0.24159002699889243, 0.15331859642174095, 0.14932394202332944, 0.09012580529088154, 0.08001807305845432, 0.1352038700133562, 0.1818800310138613, 0.07417050597723573, 0.12097842045477591, 0.14441261650063097, 0.18676308071007952, 0.11314534116536379, 0.11715348038705997, 0.15428747021360323, 0.15906765824183822, 0.21905407455051318, 0.11672713138977997, 0.19415496062720194, 0.23876578401541337, 0.15327721426729113, 0.16731265175621957, 0.16340650588972494, 0.13167828263249248, 0.11638532785582356, 0.13296019431436434, 0.19068386172875762, 0.22864618484163657, 0.20777763042133301, 0.10231424501398578, 0.17843005363829434, 0.2221149587421678, 0.28182853187900037, 0.11915468901861459, 0.19862098270095885, 0.09661371223046444, 0.158044281124603, 0.10233456501737237, 0.07055526715703309, 0.13866790366591886, 0.1610344386426732, 0.1044062405708246, 0.12785809230990708, 0.1560189452720806, 0.1386342992191203, 0.1510318910004571, 0.10480855882633477, 0.14035243046237156, 0.1414457178907469, 0.0690683520224411, 0.2059744342113845, 0.2915621252031997, 0.16689998796209693, 0.2539924130542204, 0.1764727578847669, 0.16478946839924902, 0.1481128460727632, 0.11121189061668701, 0.16716913523850963, 0.0879829132463783, 0.26190097618382424, 0.21709048538468778, 0.076386647997424, 0.0997677211125847, 0.21533741382882, 0.2140415646135807, 0.12514802132500336, 0.1307153163361363, 0.1268759637605399, 0.13411656429525465, 0.19045749184442684, 0.14132103708107024, 0.17482087074313313, 0.20956190186552703, 0.10967828697175719, 0.10686995563446544, 0.1102755600004457, 0.07617567767738365, 0.13461821159580722, 0.12149560090620071, 0.11392170927138068, 0.1403393389773555, 0.2099520488991402, 0.09110802289796993, 0.15454762266017497, 0.14163517334964126, 0.16515166615135968, 0.2407109530759044, 0.2098654699511826, 0.11786724833655171, 0.09194190002745017, 0.12201234349049628, 0.20153447636403143, 0.22479875769931823, 0.09689963204436935, 0.1403597925673239, 0.101013549574418, 0.13524381240131333, 0.11883929109899327, 0.10974758130032569, 0.10534995555644855, 0.14807352708885446, 0.14335263665998355, 0.1635713962605223, 0.19247709831688553, 0.1656417507911101, 0.1131002556940075, 0.0869940163102001, 0.1785155787365511, 0.14816524169873446, 0.08408484194660559, 0.1826210951549001, 0.14705127803608775, 0.15045932406792417, 0.1692558021750301, 0.11025587824406102, 0.19758003152674064, 0.13595386961242184, 0.12000303060631268, 0.09309567249147221, 0.08862379487254657], [0.03700570588989649, 0.05227165762335062, 0.026494942940189503, 0.05105018644826487, 0.05010379230952822, 0.031179189827525988, 0.024470336247759406, 0.018061968985421117, 0.04626954199920874, 0.04163594298006501, 0.05668824895110447, 0.05338985152775422, 0.010991534563800087, 0.03711051198479254, 0.03554957133019343, 0.022717739666404668, 0.07228555477922782, 0.064159779867623, 0.022022078264853917, 0.06367195877828635, 0.07751146185910329, 0.028415192537067924, 0.06768649531295523, 0.03400542918825522, 0.008598177882959135, 0.02899902712670155, 0.042527544355834834, 0.011139852776977932, 0.03550821144017391, 0.02231282018328784, 0.037981014102115296, 0.018618377507664263, 0.02192886451666709, 0.05069126156740822, 0.04526032505964395, 0.015236075651046121, 0.020050384846399538, 0.04608568604453467, 0.024226039786299225, 0.016242293386312667, 0.05770930685685016, 0.025494019500911236, 0.045864474086556584, 0.012288655634620227, 0.03675514199130703, 0.05075782108178828, 0.02089035500830505, 0.04582679524901323, 0.041606008453527465, 0.024338079965673387, 0.03654950771306176, 0.027304158502374776, 0.048102568835020065, 0.00287284090063622, 0.04228746329317801, 0.03266556319431402, 0.015059452853165567, 0.037927008015685715, 0.02565348106145393, 0.06358179525705054, 0.08471324807032943, 0.027221817217650823, 0.030619734789070208, 0.049762396956793964, 0.005634541475956212, 0.03023477165697841, 0.07708605538937263, 0.0735818492830731, 0.028541561732708942, 0.02881234173401026, 0.04940151280607097, 0.02623169759317534, 0.017362060643790755, 0.019856888393405825, 0.023897327737358864, 0.08241826770245098, 0.03839320292172488, 0.006940206985746045, 0.018949466284539085, 0.060642983225989155, 0.06403524748748168, 0.10074736346723512, 0.04946010907588061, 0.03626152843935415, 0.012563816162582953, 0.05810574359202292, 0.03304442958324216, 0.06416907155653462, 0.019448788807494566, 0.02184905210015131, 0.00954211644057068, 0.05816515622427687, 0.007113472029232071, 0.020797558718186338, 0.051256677907076664, 0.09417623208719306, 0.020776633864443284, 0.02704957587411627, 0.03316820126201492, 0.10578025277936831, 0.03680832429381553, 0.06171674103825353, 0.08795848174486309, 0.042689469846664, 0.009479032032686519, 0.01710758933768375, 0.051794490063912235, 0.04557494743494317, 0.037325920347939245, 0.05034848210925702, 0.0019568135894587613, 0.12717922014417127, 0.04243230083375238, 0.017892033865791745, 0.0533328434539726, 0.030663848046970088, 0.04842630849452689, 0.09644168239901774, 0.03249403802328743, 0.08176020535756834, 0.03225015345378779, 0.032885365071706474, 0.06430945621104911, 0.08984701751614921, 0.010303311337338528, 0.06517793968669139, 0.024229106711572967, 0.032452548257424496, 0.05816219505504705, 0.018857534596463665, 0.025151102745439857, 0.058637711335904896, 0.028056772316631395, 0.0201571576326387, 0.013163617131795036, 0.019953929768234957, 0.07022699297522195, 0.07990711455931887, 0.050740948354359716, 0.04615660938725341, 0.01054089692843263, 0.08272488601505756, 0.032548853050684556, 0.03856714007270057, 0.02220165388280293, 0.02460441079165321, 0.03236582830140833, 0.0212421534160967, 0.03789719223277643, 0.04378255318442825, 0.08110411712550558, 0.006085771437938092, 0.028476681327447295, 0.061840935741201974, 0.021057531193946488, 0.028632565736188553, 0.03381007736606989, 0.05112047896545846, 0.0416022828721907, 0.011729805446520913, 0.13526855560485274, 0.036989553045714274, 0.024356728281418327, 0.031930503027979285, 0.019973195921920706, 0.059287112817401066, 0.053814096536370926, 0.05586565617704764, 0.02053411113593029, 0.020206486333336215, 0.03281749566667713, 0.05483231943799183, 0.03194077064108569, 0.015309231930586975, 0.047782944384380244, 0.047816066435188986, 0.020934759559168015, 0.025223395350622013, 0.10133780131582171, 0.04781007730343845, 0.04698749566159677, 0.026494443845876958, 0.06871754623716697, 0.017560347660037223, 0.023387724613712635, 0.02204133885243209, 0.04794775682967156, 0.01585899452038575, 0.08644696441479027, 0.04161377502896357, 0.048432850526296534, 0.018635962696862407, 0.04505116929067299, 0.07169678676291369, 0.048949043921311386, 0.04435831506270915, 0.04764357647218276, 0.0434497222158825, 0.028848541842307895, 0.044940459411009215, 0.03986829564382788, 0.006592701902263798, 0.021392967100837268, 0.04504393335082568, 0.03495151162496768, 0.05690215817594435, 0.05024051817599684, 0.0409601692808792, 0.034490411562728696, 0.0676353093876969, 0.039065644377842546, 0.04791569976077881, 0.04076069853908848, 0.04120555298868567, 0.044598607637453824, 0.07259823643835261, 0.0206056393290055, 0.018154475837945938, 0.006046250682629761, 0.017391928377037402, 0.030942077355575748, 0.024079428512777667, 0.004571578201648663, 0.020840414035774302, 0.03674068495456595, 0.08874483173713088, 0.0677424087189138, 0.060486211950774305, 0.049744611387723126, 0.012556164620036725, 0.031860488816164434, 0.00860549360368168, 0.02189515802456299, 0.10548885591560975, 0.11559160833712667, 0.039848049855208956, 0.029077023136778735, 0.034270479809492826, 0.01609278031537542, 0.009697805107862223, 0.02361787759582512, 0.03513846233545337, 0.05493433876836207, 0.045712790233665146, 0.0264700012121466, 0.047556607896694914, 0.08289511984912679, 0.06844070288934745, 0.007941354924696498, 0.06330541204079054, 0.022593817702727392, 0.024601089680800214, 0.029066983734082896, 0.0297564148058882, 0.08271660364698619, 0.08043866298976354, 0.07942328622448258, 0.1078941194282379, 0.04767164449731354, 0.011216768034501001, 0.06616288839722984, 0.04720198376162443, 0.044207573737367056, 0.05609093881503213, 0.05798942678666208, 0.06461238604970276, 0.06834140353021212, 0.062235587611212395, 0.03756904792680871, 0.01906304827571148, 0.039535987889394164, 0.04829255492950324, 0.005123870587340207, 0.013885139596823137, 0.04773207016114611, 0.04770767205627635, 0.02717789691814687, 0.04869906260864809, 0.011479021686682245, 0.046364703885046765, 0.11626033534412272, 0.041302232566522434, 0.04835830921365414, 0.06171032517158892, 0.010294008516211761, 0.019298856423120014, 0.03210156806744635, 0.054518799151992425, 0.05410787940490991, 0.013199361746956129, 0.07953338383231312, 0.06064133194740862, 0.03095764019235503, 0.04108188521058764, 0.07573156908620149, 0.02341712108318461, 0.015651079993403982, 0.04815473439521156, 0.060410483201849274, 0.0700416712788865, 0.06784482509829104, 0.034445333512849174, 0.06118893303209916, 0.007912326746009057, 0.014329206442198483, 0.06322063651168719, 0.027118903599330224, 0.06479254239820875, 0.020684256887761876, 0.025299920052930247, 0.018549927372077946, 0.031453788178623654, 0.04253066137607675, 0.05345210287487134, 0.06473270303104073, 0.08123693187371828, 0.031086417657206766, 0.009159248947980814, 0.05255089439742733, 0.0364238546899287, 0.02093883766065119, 0.03360671777045354, 0.03754959994694218, 0.03995519371528644, 0.03634366192272864, 0.03371161292307079, 0.01791654143744381, 0.011056644107156899, 0.02950857644464122, 0.04514149979513604, 0.04521029317402281, 0.04546316515188664, 0.059227173260296695, 0.027728379391191993, 0.015235995870170882, 0.029726732609560713, 0.048428160152980126, 0.027867648968822323, 0.018193032265116926, 0.024915322428569198, 0.033521686200401746, 0.08106189634418115, 0.0059996651452820515, 0.025144881692540366, 0.06853190541733056, 0.035852950168191455, 0.020666424934461247, 0.026495063539186958, 0.06417928350856528, 0.023990812369447667, 0.03199511440470815, 0.02438522489683237, 0.15859838342294097, 0.11377189934137277, 0.16410620271926746, 0.13235791178885847, 0.1926191008533351, 0.18012054730206728, 0.18099712760886177, 0.15156362496782094, 0.10663159264368005, 0.09354032285045832, 0.1973606675164774, 0.15314793214201927, 0.16622586554149166, 0.16270027816062793, 0.11516739672515541, 0.13178531517041847, 0.15724188589956611, 0.16782850376330316, 0.15914865623926744, 0.1055636050296016, 0.18538118689320982, 0.10502258679480292, 0.14670732227386907, 0.1563065720256418, 0.1253100173198618, 0.25086613080929965, 0.09517436876194552, 0.14770482812309638, 0.2061295133898966, 0.11707598532666452, 0.18075443047564477, 0.10139050864381716, 0.089835996623151, 0.2121647770400159, 0.12681283667916432, 0.20174836332444102, 0.12457836361136287, 0.1722472213441506, 0.055984871069085784, 0.19878931663697585, 0.16658470878610387, 0.2818003005813807, 0.1036437283619307, 0.12472186528611928, 0.07566674990812317, 0.11974903798545711, 0.15337137796450406, 0.12671551143284887, 0.27104097011033446, 0.10948140261461958, 0.09473159603658132, 0.22212840645806864, 0.11560343074961565, 0.0736858241725713, 0.08444475388387218, 0.11577146040508524, 0.22001585341058671, 0.16639418463455513, 0.21579266205662861, 0.1533300700248219, 0.12708315654890612, 0.22028419916750863, 0.15086173138115555, 0.1906751489150338, 0.10808024264406413, 0.12260278876055963, 0.2067591217928566, 0.23030464741168544, 0.10800025396747515, 0.1416366724879481, 0.17039784870576113, 0.14199846948031336, 0.10246517558698542, 0.17695919115794823, 0.13901037513278425, 0.11111460989923216, 0.17228204291313887, 0.13466222095303237, 0.1260578350047581, 0.18031585088465363, 0.1870828721439466, 0.2793869253946468, 0.16530278226127848, 0.1307481637923047, 0.1440849286154844, 0.21279548382153735, 0.11938699608435854, 0.21189497667364776, 0.13835161516908556, 0.0900804006960243, 0.14894322026520967, 0.19996573944808915, 0.1976893053506501, 0.08885257673682645, 0.16247267631115392, 0.24444039358058944, 0.138628302665893, 0.1104388028034009, 0.1282653829548508, 0.16979696141788736, 0.09667197824455798, 0.1392387191299349, 0.1506279845489189, 0.06273325328947976, 0.21519520349102095, 0.11866081942571327, 0.1438662176951766, 0.12143822546931915, 0.15270282165147364, 0.17686884209979326, 0.14351158984936774, 0.22825421212473884, 0.1701538305496797, 0.08256866392912343, 0.12883873656392097, 0.13781418150756508, 0.17832432728027925, 0.20443532383069396, 0.15993812325177714, 0.11146718199597672, 0.0967825879342854, 0.1743454360985197, 0.2568540454376489, 0.2298520115436986, 0.12439110490959138, 0.1546481391415, 0.09697187269921415, 0.1865070397616364, 0.10316639381926507, 0.1102540896681603, 0.14250391657697037, 0.11870229063788429, 0.08693998795934021, 0.07703204930294305, 0.10172806709306315, 0.09314301409176551, 0.1695838462910615, 0.11885231579071842, 0.1927591738058254, 0.10755883195088245, 0.15774102474097162, 0.14568845741450787, 0.12951907818205655, 0.09847647321294062, 0.10986884823068976, 0.09972471365472302, 0.09390462830197066, 0.17682029079878703, 0.17623757128603756, 0.13256207661470398, 0.1488481363048777, 0.14301619143225253, 0.08355603946256451, 0.17784507799660787, 0.21802712028147653, 0.141335345688276, 0.13505839422577992, 0.12169727953732945, 0.1515429190476425, 0.1299779035616666, 0.18760908453259617, 0.14370963937835768, 0.13414203480351716, 0.16870719176949933, 0.10928416202659719, 0.20892334316158667, 0.23844766983529553, 0.09653367902501486, 0.11251797404838726, 0.10610602592350915, 0.061616732928087004, 0.1260445950902067, 0.16929415636695921, 0.07715653715422377, 0.09357077316963114, 0.08011744663235731], [0.04958478988555726, 0.0026077153688675025, 0.10005539981648326, 0.019041999112232588, 0.07671176063013263, 0.01600724965101108, 0.018240297795273364, 0.015301614712370792, 0.03090740978223039, 0.03603364457376301, 0.07317826195503585, 0.061840868947911076, 0.08109759364742786, 0.00909609403606737, 0.007434067301801406, 0.014074597838771297, 0.008961113144323463, 0.05864829807251226, 0.04802822419151198, 0.03759172795980703, 0.029925724666099995, 0.026173477963311598, 0.06956095254281536, 0.02656343946000561, 0.085879651887808, 0.04445302423846442, 0.05634136170556303, 0.023766789527144283, 0.03720047141541727, 0.020670081867137924, 0.048218896772596054, 0.07862771133659407, 0.005591586896116496, 0.04751452070195228, 0.020504798158071935, 0.00797551041614497, 0.01251642353963689, 0.04555600040475838, 0.014117629416432464, 0.01764918830303941, 0.0553379075427074, 0.020292556910135318, 0.04452092332940083, 0.07233635478769429, 0.03729558135091793, 0.07685633099754341, 0.1003053032036405, 0.05221069761319086, 0.05827812594361603, 0.024274079005408566, 0.031111561620491557, 0.04350250004790723, 0.035495145930326544, 0.003321056351524021, 0.04212733751046471, 0.03835360563243739, 0.06025164133461658, 0.039839845412643626, 0.07505602916353382, 0.05964393370959442, 0.02162615546694724, 0.036590073505067267, 0.03729889132955577, 0.027022912363463547, 0.019000093743670732, 0.05306699873472098, 0.018998433188244235, 0.04442743127583526, 0.054503525752807036, 0.05715771301765926, 0.023879390028014313, 0.02972169157146709, 0.03897296868672129, 0.07133212508051656, 0.020849818902206607, 0.06653577307588421, 0.03708539028593805, 0.024201226078730542, 0.025094697666645516, 0.016953133563220035, 0.03393734456039965, 0.05260907877527643, 0.016183958723559044, 0.017658717479207553, 0.040871259989216924, 0.13077183830318972, 0.026795412559295073, 0.06297194282524288, 0.02949691544927191, 0.03314525034511462, 0.014202474521880504, 0.04312780081818346, 0.13297528959810734, 0.022536295691679697, 0.015176471915765433, 0.014676339524157811, 0.040175396352424286, 0.07340642783674411, 0.038765070858062245, 0.11226425602217205, 0.037305618898244575, 0.02515854092052905, 0.015356588373833802, 0.08043737907428294, 0.018841880846593995, 0.025534204942232464, 0.06954769778531045, 0.00998539475403959, 0.0282982523276587, 0.023928256741783116, 0.05766864829638507, 0.11215261474717408, 0.009910669759847224, 0.0452861184021458, 0.01008873974569724, 0.003601883408919093, 0.02918650661740685, 0.036518979468382895, 0.051483337229001336, 0.05020126969611738, 0.04533188293862622, 0.00478706402645912, 0.10845057433471084, 0.06285523268161342, 0.02547514483012492, 0.01250279028681689, 0.05142490794241894, 0.03509343252517283, 0.11633285059360787, 0.03106384894635994, 0.007716721665929072, 0.029222901539469603, 0.050986539863515645, 0.006334646022878587, 0.06381395389325917, 0.04385427062516101, 0.01795082866010489, 0.056355135966441594, 0.038986668732832186, 0.061326697905315086, 0.022236007898754906, 0.014152763615129516, 0.03562945610610768, 0.024738457505009137, 0.06999325356446207, 0.04465671780053526, 0.013099450115987565, 0.011263313681411091, 0.06575092222192325, 0.08985990862129256, 0.00667747557599796, 0.03249839071941096, 0.02301340202393476, 0.035338367233634926, 0.01958030479727313, 0.06779226619983092, 0.023229348444147035, 0.018447160327923484, 0.05191819123865571, 0.0145279693606426, 0.057942315252148546, 0.038814761355752125, 0.045508877738029696, 0.06206817393831443, 0.0653425109339878, 0.0718562891415786, 0.0438694772310555, 0.06864260416477919, 0.06572604543180205, 0.05744801521359477, 0.0679392930760514, 0.02834228209394496, 0.04381428370834328, 0.017911270333570428, 0.0455515475186985, 0.05268704509944655, 0.03965861666074488, 0.027795150417659897, 0.04965183550666552, 0.027396732148190495, 0.034536417297204025, 0.007597011390316766, 0.012168538105470361, 0.08218767499784008, 0.05046713296906091, 0.06562319860677235, 0.010925022361334413, 0.016097238767542876, 0.033719193961587735, 0.044702155792037956, 0.020966274860256817, 0.06860406443593092, 0.013080401040497236, 0.03432010351389181, 0.03057057678233832, 0.0625211771694012, 0.0017708582845443743, 0.053859905601711944, 0.01938465426064795, 0.05625359532132279, 0.06127674023446161, 0.010659391937224427, 0.08372230280656368, 0.00934647239773767, 0.0430790565587813, 0.031037196567922365, 0.023631191725144163, 0.0962684206024278, 0.03419642089284025, 0.03357265690283384, 0.06803721946198493, 0.02188449707318796, 0.02983906408189796, 0.028474915015976876, 0.035038402274949476, 0.043695065105566755, 0.05243857405730523, 0.06168475818412844, 0.027577131550060585, 0.04857821128098294, 0.02469378763635177, 0.0277604030634393, 0.06956729048397392, 0.03391211153939366, 0.021363284904509783, 0.04282070753106382, 0.011202283167222049, 0.026246701963827945, 0.057920726176234894, 0.013844660079485038, 0.06208716549735982, 0.018574184468889143, 0.08642988759675063, 0.04202010459266603, 0.027845837248605676, 0.1251206806045957, 0.03724951253389008, 0.08792687367531471, 0.011580091995710973, 0.02110309163981583, 0.052967643714509904, 0.06297511179582216, 0.05001601479307283, 0.017321103368885815, 0.042993909955839626, 0.031574019812978804, 0.06836510030552745, 0.03987648895417806, 0.043756195809692144, 0.09153443126706406, 0.06683679559500888, 0.03383009308890905, 0.07380513925454579, 0.05109140161948744, 0.06250054546399042, 0.05158128959010355, 0.04402769569423981, 0.05582792167842854, 0.03709643344336655, 0.013518845189537387, 0.019405798047955614, 0.0973467982839793, 0.06071157622500323, 0.04712115645816084, 0.014851187661406584, 0.05290041626722086, 0.023944398453750182, 0.03380381363967899, 0.022338483649946284, 0.027108333561045583, 0.037844785474590026, 0.021974899937049486, 0.05670897713571321, 0.0759542133891955, 0.01758647311362438, 0.053090458022779785, 0.034515841252868995, 0.07234767253976315, 0.03428915224503726, 0.0707603374030441, 0.07981767092132941, 0.05531103066459764, 0.04375092656118795, 0.02867632090783445, 0.02883806828322122, 0.09068704704986885, 0.012894795472675469, 0.008186325812857831, 0.07758827414363623, 0.06449122302001342, 0.01473276501201326, 0.085331620357465, 0.024970874037535395, 0.022960045316722244, 0.03234379393688869, 0.06465746409958228, 0.05514404743735213, 0.05636255373246968, 0.0554957734857453, 0.05058281523815822, 0.0170985926524736, 0.031243819757946767, 0.028255038923816755, 0.01659946679865243, 0.025460051401751116, 0.014209794881026028, 0.03872166635119356, 0.031256373185897246, 0.12141325219999999, 0.08636415557703003, 0.013126134963385994, 0.04543212482531089, 0.023920280509628356, 0.02832606616721023, 0.051546453178161755, 0.038894059835001826, 0.06092842435464263, 0.06006908784911502, 0.030967527454777155, 0.013883363080822164, 0.04166176600847393, 0.03844795486656949, 0.07635654648765922, 0.09773658908670768, 0.07750429271254689, 0.06172513843921479, 0.05007362400647253, 0.04026006055937614, 0.04911623494990636, 0.04886068381892983, 0.05743358044128399, 0.047268684284063056, 0.029674867619178258, 0.026716717075032648, 0.029094283636368345, 0.003264619035689975, 0.0830508372746408, 0.042643415872589685, 0.0166296610768768, 0.06334329867968336, 0.08220379444537684, 0.05677225264662411, 0.06938648104551248, 0.06488411600003019, 0.03818376142589841, 0.03706931536726188, 0.03574700858735014, 0.011676606445689686, 0.024747207426116802, 0.032696944908821024, 0.0688553556392435, 0.05261550206341781, 0.12660914682783186, 0.10886324555031024, 0.21022443193942308, 0.10970837363856845, 0.17203119699843228, 0.04390543057525065, 0.10664331857697107, 0.15266387374140322, 0.15845362009713426, 0.122290515282657, 0.16281122923828661, 0.09250631075701676, 0.1304136184626259, 0.15116203401703387, 0.1295492093777284, 0.12723180872853845, 0.11283041822025552, 0.12427553767338395, 0.07471922028344125, 0.14040564245078713, 0.19567565090255812, 0.14162948849843815, 0.11727751552825794, 0.11517017977894284, 0.13115385139826685, 0.12343417969532311, 0.1908274376182817, 0.10932170727755874, 0.16941751615377143, 0.12776176154147834, 0.07561456950497814, 0.1634253712836653, 0.1267290927353315, 0.22889878222486004, 0.07884762453613803, 0.14344061084557325, 0.1593920509913005, 0.08061654836637899, 0.09243336506187916, 0.13349722721613944, 0.15164146141614765, 0.14482560683973134, 0.12622230977285653, 0.20732904667966068, 0.11364196412614547, 0.12252463318873197, 0.16464200365589932, 0.10983703978126869, 0.16762427956564352, 0.0907164954696782, 0.16662160836858675, 0.12815993861295283, 0.23660107282921672, 0.1406892912928015, 0.09333628418971784, 0.18009201914537698, 0.14272054948378354, 0.13958160619949922, 0.22415249550249428, 0.27037187945097685, 0.09084867939236574, 0.11250281939283013, 0.06067302165320143, 0.087524317932548, 0.10028792210505344, 0.13465981639456004, 0.18978173669893295, 0.10800484044011682, 0.12274249063921161, 0.1731384961749427, 0.13654043345013633, 0.16194641939364374, 0.15044133440824226, 0.15055184019729495, 0.11623863494605757, 0.19505736767314374, 0.14703567809192464, 0.2785414410755038, 0.1210704912955407, 0.17373022536048666, 0.23012880294118077, 0.12360945271211676, 0.09893192182062194, 0.15139695344259962, 0.09616389652364887, 0.30972256790846586, 0.14722312975209206, 0.17011791060213, 0.11650645377812907, 0.12437884462997317, 0.084576611261582, 0.2176328469067812, 0.16501132602570578, 0.07358829854638316, 0.1648978516459465, 0.12856656132498756, 0.12012441628030501, 0.1852677867282182, 0.1109273660404142, 0.18361389578785747, 0.10278894493239932, 0.1519094657851383, 0.17078256321838126, 0.3414363489719108, 0.12309676225413568, 0.21934732678346336, 0.1623683303478174, 0.07229606359032914, 0.11880440273671411, 0.22732165904017165, 0.1347673832788132, 0.1260673048091121, 0.1633767457678914, 0.16851120541105047, 0.09984631455154158, 0.16907915618503466, 0.09990767532144673, 0.13406085869064555, 0.09590338042471558, 0.20017829054268077, 0.15809958596946672, 0.13465778290992603, 0.21130709181306884, 0.16369331628084183, 0.08801932301139459, 0.12442003382602707, 0.09636698523536325, 0.09442986847716384, 0.1497156178811565, 0.10570678015938029, 0.22018384595867246, 0.1268089923541993, 0.17173990403534845, 0.18323764175875112, 0.1258018979569897, 0.11693592721712776, 0.09475891449255869, 0.1330959628103301, 0.15446269128005952, 0.20834532886510715, 0.14520022814394906, 0.10733689268818125, 0.10774527429020964, 0.11909956228919327, 0.2549710386665538, 0.09087151527637616, 0.11887676955666393, 0.14538825867930427, 0.1433477978571318, 0.12419301085174084, 0.1440628571435809, 0.12772052781656384, 0.14678502513561398, 0.1739677571458742, 0.1445393604808487, 0.1137771611684002, 0.13739146903390065, 0.20939263282343745, 0.1541238563368097, 0.08993954106699675, 0.16470271133584902, 0.12770808942150325, 0.21201156807364896, 0.18394351325696334, 0.20653852581745014, 0.1340789967798628, 0.10781616423628293, 0.21677053067833185, 0.17154884553747252, 0.1383106189314276, 0.09035858733113855, 0.0985008898715023, 0.10039468004833907, 0.16455399978440255, 0.14595873275538906, 0.1259039284195751], [0.06004735405440442, 0.08578332111937925, 0.020298267736507114, 0.06983329105423763, 0.0412855305330595, 0.055911357630975544, 0.0013677691231350764, 0.02564196849561995, 0.06165682745631784, 0.04189476327155717, 0.014460114798566792, 0.029184931408963166, 0.015849439369048923, 0.07895842718426138, 0.016941622852755245, 0.025692987437651027, 0.05236745775619056, 0.0341989330627257, 0.04748658997414168, 0.011300303249299759, 0.07382773765129969, 0.012196538409625646, 0.0262579770424054, 0.04207161706290208, 0.04633213844499551, 0.05273794900858775, 0.03274298032920342, 0.02973859584017191, 0.060163444504723884, 0.05968216915789526, 0.0035212523107475135, 0.06464322228566743, 0.09563894578604959, 0.057021647662622854, 0.05269735353067517, 0.02105354957166128, 0.02143641613656655, 0.06210874344105832, 0.03944533826143015, 0.035754084965446964, 0.041152392950607464, 0.09390245380927809, 0.0526492549397517, 0.020214807664160617, 0.055997517265495844, 0.016955417522694916, 0.027731654117815197, 0.015682793818996288, 0.054865218844497576, 0.04367287489003502, 0.016274491463263985, 0.10153491573873907, 0.06942629726836458, 0.011316214895487064, 0.04859897286223713, 0.017458100119256414, 0.13646892010001466, 0.07295698320376687, 0.0648017153434921, 0.06360800049151294, 0.02756522379058879, 0.019316371108288877, 0.04216650435409974, 0.044522329699248075, 0.030930418215575628, 0.019033835487789474, 0.16692870907718316, 0.05354678236471955, 0.035255647453595884, 0.038487195924972184, 0.016752219344198238, 0.05870798529940657, 0.07671854385989718, 0.015074406201165402, 0.030607305670855567, 0.004664183388740639, 0.07594331123982556, 0.044874842424178496, 0.11462592578027397, 0.05383204166719224, 0.041845106170512736, 0.10445857682498172, 0.019424162492214236, 0.034800462308339775, 0.025025874601851683, 0.0475422250747215, 0.11093063149019144, 0.012246001624589553, 0.04851805650105234, 0.06077498532249592, 0.03802311985054985, 0.034940375699079596, 0.04457676623133011, 0.04505098004301544, 0.04975961761374492, 0.04093880284926854, 0.027711647671821993, 0.03252920098020695, 0.05259009834844619, 0.19045235618250445, 0.08575680418289267, 0.04484886354475748, 0.06214864501089323, 0.05862601137778256, 0.05448923941003159, 0.008213977307605091, 0.010970983566949144, 0.029529109815484844, 0.033819918244262226, 0.04686596897954587, 0.05220184008067008, 0.02313756889634533, 0.0891531836532522, 0.06444602622650564, 0.009094007673411397, 0.04417266682139598, 0.07473192585166544, 0.05651181076245848, 0.0896342437772546, 0.01691462723101722, 0.06385520246112719, 0.04501390234509017, 0.02435789159790147, 0.004591809147314052, 0.02709165379201295, 0.048319747220375575, 0.034299798353458755, 0.01280989934457466, 0.008686410892551066, 0.05912696477025747, 0.05974914427497424, 0.03711206678417511, 0.08119732345221564, 0.025032861922227312, 0.07764558278722689, 0.08847943230648525, 0.09859643396339379, 0.04938630991091486, 0.032939063166850246, 0.004539628744169022, 0.0312401387054706, 0.06008516276779119, 0.019901587947970256, 0.05928583261265885, 0.0053001250944362255, 0.013555785590142477, 0.08162857804563828, 0.03911982857971452, 0.04029869305668399, 0.025437269323447254, 0.05337674891052302, 0.008369807910639793, 0.05211768424487673, 0.0634358444949612, 0.035405843300395645, 0.029587095668830443, 0.036589038209058344, 0.01666931959334761, 0.0927131695789285, 0.028130512109783012, 0.06279438399360515, 0.028583530183823314, 0.05248176705208607, 0.04705091218056623, 0.03575641159841325, 0.07969957296154462, 0.017498664055892732, 0.04396642769279424, 0.06938983555301093, 0.05950661412498448, 0.041185845257132314, 0.04493264830671251, 0.011105305802630028, 0.03930117607524153, 0.015484123669011751, 0.06284668314037845, 0.05019856085709762, 0.064508270152146, 0.02878289331420092, 0.018467599074938335, 0.07138609405956231, 0.05361387251468841, 0.013813611403747927, 0.04002781286544632, 0.08019487489946187, 0.038935475386097096, 0.04290846278308891, 0.06400296406354755, 0.03415756575122941, 0.0838071302860044, 0.03186373200151138, 0.013651263816427672, 0.10500107193365693, 0.03947765137127135, 0.01077902335964609, 0.04297015009797178, 0.0305601570289582, 0.01707295887172222, 0.0183315838148701, 0.07264795291121118, 0.06180148688144982, 0.044782426484744065, 0.03233259492844809, 0.012360773835098371, 0.033867679157992825, 0.08797774789854884, 0.03602161807066295, 0.08352369666681625, 0.03287150917458348, 0.06167869483761024, 0.02943518731626682, 0.02206741235568188, 0.03331207401060965, 0.06834659856394865, 0.05101578419271391, 0.05093021085485816, 0.028324646809778642, 0.017220162008015905, 0.0329644371959148, 0.022882392549945507, 0.04661455161112826, 0.010591463160380954, 0.06471774133387953, 0.08560609625419602, 0.038437356997746974, 0.02447494312946219, 0.07094618602422997, 0.022744523776054848, 0.039218534220708534, 0.04120925259485375, 0.012691054598690243, 0.038948385044932365, 0.05332695822289679, 0.1063544227508828, 0.07953456384711899, 0.039841633988544345, 0.03435909966356121, 0.07071836153045297, 0.030214590806281194, 0.027487136867421214, 0.04709150394774042, 0.018368425880908035, 0.03244888946937863, 0.0666712447127793, 0.024764479057921562, 0.09500637621385977, 0.06076528545236215, 0.09071423191926442, 0.040713022972340696, 0.05092863750178367, 0.00945526197028812, 0.025472183660895098, 0.035639501074911095, 0.06935700293979608, 0.08862475966452621, 0.02542377151257824, 0.005827817140016123, 0.07985221047420055, 0.02462204978655791, 0.02393381728325039, 0.018912321793322917, 0.0797459868772421, 0.04329084695200436, 0.028627828978642356, 0.03653468331322074, 0.02885444748244481, 0.032499277585884556, 0.04013317186036147, 0.05440010747406632, 0.025550361497153062, 0.0053064189705764875, 0.0381493703025626, 0.04651909657695796, 0.05686172597052064, 0.026765071706904564, 0.08015869520022534, 0.047226211172528565, 0.03014495323441224, 0.061167514650151134, 0.014875639571982902, 0.012174987368780421, 0.04433752008480951, 0.0527030346711399, 0.10964004410197958, 0.041750853415578604, 0.07972960025654174, 0.09744480630615726, 0.07101928014890291, 0.026860892248805612, 0.0368310822523199, 0.009001027701742714, 0.015206038151518442, 0.01062247101799585, 0.05408873570559081, 0.03563659185601864, 0.004984222514394787, 0.06177786803164054, 0.06451135748648085, 0.05197417143790517, 0.044238224436412565, 0.021461821706907358, 0.03595048692659475, 0.03967258759075776, 0.07004326689639129, 0.05153011479706038, 0.06735950504662469, 0.031013418156362604, 0.07392975327093154, 0.05055344103311654, 0.043522285704966635, 0.030920158023945987, 0.017587406364327762, 0.035607024692581035, 0.05498737264133524, 0.0382379864458926, 0.02623074393341085, 0.027048902375099715, 0.02496104429155821, 0.07216688536573201, 0.01576690327055985, 0.03202737556421198, 0.025102924373641144, 0.05930424900725484, 0.029011736405664124, 0.027526877020136453, 0.04978723663953133, 0.033642719354247674, 0.003069607209909009, 0.07347089820541441, 0.0299060930046835, 0.0376338745263638, 0.004048225400765659, 0.007378598256764235, 0.027522105010575615, 0.04797428860911168, 0.012258919632586185, 0.04157399962423369, 0.057867503055604175, 0.03906136589648668, 0.05844635968969669, 0.05804680593428202, 0.07473562174709514, 0.03067482070036931, 0.03384387477126438, 0.04514650187047664, 0.10731081361882389, 0.01957966283953283, 0.03579217940568924, 0.011175893323525088, 0.03568666827050038, 0.023409439854731318, 0.08697322875377722, 0.15879128244705498, 0.14915560808731243, 0.14270569168729708, 0.14105328504228964, 0.23520408372860402, 0.15142040530918166, 0.1430448828614317, 0.12680375279160216, 0.196847383340355, 0.12030036465148441, 0.07374732595053501, 0.11301856007776223, 0.11019870318705216, 0.2622872492065653, 0.06964705651625991, 0.08861569061991759, 0.14399995270650834, 0.14410860312636942, 0.15544198482530192, 0.12183506667497568, 0.13441829185467213, 0.13533301855204627, 0.07500088759115897, 0.14641562855103984, 0.17913898278493434, 0.10466454506968148, 0.1391074777347967, 0.08275050495285541, 0.17627626686589792, 0.1469982590060681, 0.1686762145254761, 0.12182206424768083, 0.23980194091564044, 0.18039573566056788, 0.13915234798332676, 0.16293292661430314, 0.10429980175103992, 0.2359221116057597, 0.11877364813699387, 0.19114669470582157, 0.1360814002691768, 0.10447389475302771, 0.12607822922291234, 0.26706083212047815, 0.21445367921842262, 0.09245989684131928, 0.16111396718770266, 0.08191064611310139, 0.12020813053823076, 0.15580606763251126, 0.10555622066021897, 0.1906528399558738, 0.16836368129588664, 0.206082149525173, 0.1049313620023895, 0.1613404558156617, 0.20390787947690114, 0.20746773923747241, 0.1927635376341641, 0.21051925752544776, 0.20159033039817587, 0.1894490615813993, 0.0972672994248569, 0.16039280744735152, 0.1240032585337758, 0.11291530507151037, 0.21572445868514478, 0.26341068267356604, 0.21474822278833017, 0.2583715890068561, 0.2150061636348255, 0.18439663894241676, 0.2005398945766501, 0.12852203246438876, 0.1687197489081882, 0.1196564624842722, 0.14319026959128678, 0.16449473187094554, 0.2980860782554373, 0.19332427473273128, 0.1778665854362771, 0.23299582331674173, 0.1927804437582381, 0.14399671694263816, 0.08932341006584466, 0.22413235361455008, 0.18152489850763232, 0.20243915438186377, 0.18649684265255928, 0.31623188580852, 0.12351168959867209, 0.20819418306928128, 0.2179312051157467, 0.1688843869487755, 0.1563396124402061, 0.17620650498429313, 0.16957097745034844, 0.1946529417182319, 0.22063110867748037, 0.22474081080872566, 0.12124517801566981, 0.14163181884214282, 0.18899054790381342, 0.12016110063996166, 0.1836567177088, 0.1596348371822387, 0.09335071896202862, 0.2210277717676945, 0.1125611225143075, 0.19704589300090447, 0.24593334237579256, 0.13781291985651478, 0.20946606091456488, 0.18826523213647306, 0.11156714928802103, 0.15747094235848635, 0.15436374815180898, 0.14821112126810476, 0.14848577528027818, 0.16027151083108038, 0.1410785477492027, 0.24719468172406778, 0.13098673458443955, 0.15091121778823435, 0.10071709868498147, 0.15108553343452513, 0.10999579259078018, 0.14483535866020247, 0.14764492196263745, 0.162885993195232, 0.17961627279873937, 0.1936313309124671, 0.19372568756807595, 0.14664070709841326, 0.16307994606904685, 0.15834597899811342, 0.14781744161155075, 0.18414876161841676, 0.12124933404265903, 0.1346145899151452, 0.17764014133717865, 0.14778940327232704, 0.09605120882042684, 0.1318082623765804, 0.07778796381899156, 0.09421519484021701, 0.10124619060661644, 0.13529500574804842, 0.09553666299325414, 0.07444690403644927, 0.17083127779187635, 0.08860698522767052, 0.23370142764179036, 0.1872339437250048, 0.2040649179252796, 0.08854822197463363, 0.15330949769122526, 0.10494231610209681, 0.1998868936789222, 0.06934073506272398, 0.22292712063062936, 0.09119017864577472, 0.1428055253927596, 0.21992249123286456, 0.17256153572816402, 0.2169037313433364, 0.14426132227526978, 0.15415939036756754, 0.21393512579379603, 0.22203678090590984, 0.13430435734335333, 0.10501769604161382, 0.13952866138424724, 0.10852110804989934, 0.06735367918736301, 0.19635812990600243], [0.05863435682840645, 0.05197909187700134, 0.028008080007566605, 0.06052375349099748, 0.022653165397059638, 0.023220650473376736, 0.09583146631484851, 0.11132760628242977, 0.039560590084875, 0.04792857973370701, 0.06505083947558887, 0.03586176688259002, 0.027849735379277263, 0.03814102856267709, 0.001778542759893753, 0.04657482073525898, 0.0453115703567164, 0.03154840087518096, 0.028875587559014093, 0.04094079551578034, 0.017689132546365727, 0.0788659110548906, 0.04655714648833964, 0.017107092098740395, 0.06025670278177131, 0.04721026241895743, 0.0526802396052517, 0.034560585336294025, 0.0066546545349410735, 0.025183232173731085, 0.01724034285871312, 0.02834553084539948, 0.01180988596388488, 0.023266188654815778, 0.03353071071614977, 0.03239413010305725, 0.023277124200831167, 0.020106856718484778, 0.02677823926205747, 0.036392506372067146, 0.004510954013312585, 0.09147520788246766, 0.019792221355601214, 0.016437365047750063, 0.03773152631765697, 0.05707713062292896, 0.025238995294785127, 0.08603230424341746, 0.02975241091917269, 0.025364310640725307, 0.03552233822119888, 0.03359667651238851, 0.019025185756618157, 0.027573049737839028, 0.0548556302965153, 0.05354039247322362, 0.025145397485175636, 0.07948277678224258, 0.02155530448362697, 0.011239244904572843, 0.02875172496715095, 0.08310315126436763, 0.06791435691411607, 0.014484241091849981, 0.05107736389618367, 0.033055654566851445, 0.03268988337367773, 0.025691111659398302, 0.0798104572459124, 0.0355865377059672, 0.03853563219308853, 0.011645107842923608, 0.07110694263246842, 0.04854107421124354, 0.09831553848925978, 0.047601225815014914, 0.06433664108044468, 0.022149595934024546, 0.025884494934871327, 0.06182250821439084, 0.10750503366580233, 0.10546701450948603, 0.09191929420921952, 0.05885522739845328, 0.041357489171787165, 0.04876979670370929, 0.09220879859640263, 0.07219850085675716, 0.030763522190682124, 0.030812604127277154, 0.04285148068447597, 0.007853284259908833, 0.035227004264015704, 0.05466913971758913, 0.038477570269606076, 0.006839236866653664, 0.01184045038826298, 0.013530354972317582, 0.017171169129142072, 0.0734638849098701, 0.08325904680532403, 0.07238510646857321, 0.06702709710225463, 0.029504314661608078, 0.011856841647386318, 0.08013556245714426, 0.05512855510460213, 0.023650379953323863, 0.03191642077581491, 0.013418413127510576, 0.0414775686658686, 0.029839527924195863, 0.07506107576773502, 0.030892741233401466, 0.023552858037874103, 0.022373166066245176, 0.014182115555740893, 0.03933198633603752, 0.062400503957178444, 0.02488030233507743, 0.010378454717283603, 0.05600437471002806, 0.018815495641320013, 0.042357566562714055, 0.07090947197866626, 0.07021168989012949, 0.021363136474974453, 0.0257188215982751, 0.06289016557275318, 0.018426480382913724, 0.05544231287785806, 0.03117399479378946, 0.030869183610775508, 0.006478391214841395, 0.0069409143452503486, 0.059970367365167476, 0.030882746359566227, 0.023147459869505838, 0.15945075487252325, 0.07044493948342279, 0.03078750098211458, 0.06020041459123604, 0.02539525448810309, 0.0027189823231310584, 0.06909529198310338, 0.016806923049443867, 0.05826731285196729, 0.003170317809235712, 0.036232165366527624, 0.07334934183745645, 0.04508016871113796, 0.02919778911746107, 0.02470838197041303, 0.1335990201914683, 0.06988723776885308, 0.03300367825431749, 0.0640495412517339, 0.040093066199915484, 0.050702341832220554, 0.025747414692887105, 0.012240188752912218, 0.008925387082854286, 0.06262235416215844, 0.04705006242147647, 0.016918395485845394, 0.01455787420127308, 0.09617764109862037, 0.051450445243972354, 0.029031982194283046, 0.1411950500914827, 0.07055476991808973, 0.03988276010204572, 0.11736497763195075, 0.0716691862908192, 0.022144280301290564, 0.08157868345733732, 0.0799419435497839, 0.0673234515124932, 0.011466253963590134, 0.0353256468224572, 0.030867072200635448, 0.032118819290190004, 0.02547839358157944, 0.029501717144739814, 0.056213422867585905, 0.015554317851638189, 0.015638149925507605, 0.13068012369330972, 0.06809298443840817, 0.03954189167416189, 0.0049990599018201465, 0.07290298453881405, 0.031168250570772216, 0.058787320886040106, 0.023658526879444253, 0.00799302788436762, 0.015283264183381107, 0.06668299291050062, 0.0564987266989192, 0.017858429418993182, 0.05381239330745302, 0.008019228480407037, 0.12567852332722396, 0.05060921343101654, 0.027450125962786842, 0.02979048680572305, 0.04556625317491125, 0.0018505585671846347, 0.050389341049594805, 0.06419897268642671, 0.05547460743400734, 0.028086816309951246, 0.007909177256806288, 0.02789380039757816, 0.05176473736355547, 0.037166692563914694, 0.0027970154405920766, 0.023553136343252845, 0.06878807995235547, 0.02319966439245036, 0.012351223322184524, 0.0394163573946571, 0.019684452236106154, 0.028900295510538854, 0.02271223478601314, 0.06548576770001091, 0.01939434299856657, 0.050122691100114025, 0.023688466972089373, 0.060084754586569034, 0.02037461246800376, 0.03331470121338498, 0.012654488054977264, 0.09943798489985056, 0.03554111084667966, 0.04556108782708179, 0.059627354130498134, 0.022228135567274876, 0.020152055367361754, 0.031613854589522816, 0.054497844612342305, 0.0223251565330429, 0.0415129357133992, 0.028197077190270647, 0.04788532736711204, 0.008406236229347996, 0.04660962746129371, 0.00414792505580408, 0.05892983179364819, 0.03946412201912608, 0.07942096330225468, 0.028296933160163462, 0.09063737510587089, 0.05394505962613039, 0.03011662731296383, 0.04054396544233896, 0.05460960834170692, 0.06469362895586528, 0.11864874468301423, 0.06706121363095008, 0.08877120024408214, 0.019454156390565913, 0.06817768575274386, 0.007190058422565926, 0.0248674724571174, 0.030623710845247842, 0.030777916144870687, 0.02504650445189327, 0.04108057531993836, 0.06505106954136863, 0.011748482520488324, 0.1493392005795613, 0.021253831109788734, 0.027014266343030613, 0.060836991760879755, 0.06573306614882313, 0.04616491401975509, 0.028780516586266458, 0.046027327261981554, 0.055929855661815964, 0.020539016732072923, 0.01367776962069911, 0.041321695389342494, 0.07290559689863585, 0.06968287998461165, 0.07224724511615932, 0.04206925703329034, 0.02999817497766344, 0.010683232503652107, 0.05353598782676272, 0.023012223864498083, 0.0248548578019836, 0.019067308203375433, 0.07067295693559572, 0.014791706380492542, 0.031229344167513773, 0.05522625884623267, 0.04485478588321712, 0.0315828291059006, 0.043388480189605616, 0.04897232509392779, 0.01958938126335852, 0.03492951436783187, 0.02315399076906033, 0.018435109705023933, 0.04402433005452622, 0.02530662535718875, 0.003999099399152328, 0.03687323252961505, 0.08415874501224607, 0.014147850597510114, 0.016617064975434914, 0.04112569789867848, 0.04600395703164395, 0.07494247314753011, 0.1169689156813547, 0.03238206649257336, 0.005666061879310291, 0.0866220890020486, 0.04270002318662591, 0.05592384055489674, 0.012999735154153313, 0.04208898331853561, 0.09115284861763939, 0.06269872115808539, 0.04067018620844465, 0.033649914475972764, 0.021173879540583584, 0.018473771888238844, 0.033043605799321085, 0.031234101334121078, 0.04893331410130486, 0.04491414285439532, 0.03442302826442756, 0.07929441228043288, 0.030007125278643798, 0.016645630239509046, 0.018706973241933156, 0.03447098584729247, 0.044889381097164005, 0.024714823812246323, 0.026757713312690612, 0.02636319688463118, 0.01244354742084397, 0.019856994149449747, 0.043130691483384, 0.019562971938285045, 0.0464241202280391, 0.0454448712116573, 0.08425868261838332, 0.028562989391502924, 0.03319256968097761, 0.2360097147175111, 0.12934298138134181, 0.07941444724565372, 0.18082405877066776, 0.10209561572992243, 0.21126823296071962, 0.11074491645558737, 0.12667154660448432, 0.1363765078713186, 0.11094567482359707, 0.10856913242605515, 0.22655457520158961, 0.14406732487259433, 0.13851160736521706, 0.10132522191270255, 0.2154730338952504, 0.19307436392409727, 0.12099077721359208, 0.12966013076948002, 0.1021861651679501, 0.17727433674735948, 0.21897402650211006, 0.21895783283980563, 0.0532807669515023, 0.11134188520372845, 0.121414046298014, 0.23393352690618485, 0.10183250953559764, 0.10750645858934149, 0.11620791745372117, 0.17671692447038367, 0.10087846385431476, 0.08853754246956669, 0.13528500159736723, 0.20313129614805803, 0.08008993521798402, 0.10964706481900066, 0.10333736980101094, 0.20188493333989754, 0.08793422093731351, 0.10330054443329573, 0.20628383557777852, 0.1565521041629836, 0.13151355553418398, 0.14961342414608225, 0.0995221889752429, 0.13113240333041176, 0.11387166625354439, 0.20054434746271, 0.1421820471296087, 0.08457393210846931, 0.11713169093127362, 0.10538960850681178, 0.0757633701141458, 0.12157615361502394, 0.12286195415072143, 0.14773035800317302, 0.19180569215677679, 0.10218131894362159, 0.08294204584672116, 0.12766366446157917, 0.2521901816362515, 0.16171868395758793, 0.15555108053376898, 0.16236380324698985, 0.11430990445660427, 0.10614602026180364, 0.0659101945348084, 0.18338936642976478, 0.17810474062571302, 0.09165504510747269, 0.15016537421615794, 0.15001606894657016, 0.16462814033729956, 0.2087486267555505, 0.14533868321450427, 0.11514178520883434, 0.1486366242170334, 0.1821406139060855, 0.14609571837354451, 0.11339769363985397, 0.2102312003262341, 0.24197171354899183, 0.17112448549596593, 0.14317587192635983, 0.22501488594571128, 0.24016486597247422, 0.19286628055851907, 0.20341141236713156, 0.11425002798205242, 0.12595887703355402, 0.17083678452763706, 0.13322626909939572, 0.10526434140047058, 0.12780868011759594, 0.2686633664416149, 0.10868443248909898, 0.15061213227454573, 0.12222063465742394, 0.28786527982447296, 0.2700309071224183, 0.12762355880113319, 0.14031876664375886, 0.12677350285230204, 0.08324281603563577, 0.15138408460188657, 0.17944649909622967, 0.13396768947131932, 0.16824075195472687, 0.1599507249193266, 0.14750078204087913, 0.15737706067739055, 0.2634792571188882, 0.13525929360184819, 0.12402827633195557, 0.09093876869883388, 0.19157096568960696, 0.12279468588531017, 0.2129604632500559, 0.13258963997941464, 0.1147327059879899, 0.16144836408784613, 0.10657561986590736, 0.08317224521306343, 0.16098913794849068, 0.09047201718203723, 0.12848388607380912, 0.11289026500890031, 0.1595152771915309, 0.1236837416945491, 0.29281964991241693, 0.10879596244194545, 0.14019776688655838, 0.11415290311560966, 0.114006581279682, 0.22292292007477954, 0.134121224982664, 0.09681240742793307, 0.29793070221785456, 0.1523785773315467, 0.10293642451870255, 0.0907907250802964, 0.17390825174516067, 0.10233919601887465, 0.11385389923816547, 0.09718893605167978, 0.16855721856700256, 0.09189302218146622, 0.22286145540419966, 0.24586194776929915, 0.10886340140132234, 0.12672649521846324, 0.12208802771056071, 0.2528327627805993, 0.1516322884708643, 0.14687964896438643, 0.18950639991089702, 0.09650178893934935, 0.1847227683174424, 0.06751852502929978, 0.11064998834626749, 0.10499450392671861, 0.2219498308841139, 0.12089268755516969, 0.10817005735589191, 0.25447661988437176, 0.19449694227660075, 0.2293813118012622, 0.07974443578859791, 0.17851626151241362, 0.113655612221919, 0.14110051532043144, 0.1096616851282306, 0.1397989664110355, 0.1302389762713574, 0.1250831427751109], [0.0505766888090875, 0.020315014298830647, 0.00940421705308836, 0.08150662091793492, 0.014762162409169832, 0.03070659760851413, 0.03035631318198284, 0.04965205072949175, 0.006727185555064352, 0.01033060845657019, 0.06880370216094889, 0.05449449752632063, 0.037302086275303736, 0.011707450103131123, 0.024339590236195363, 0.03399471999728121, 0.027073942437709775, 0.0496507334173657, 0.016740671526349615, 0.05007697480323259, 0.04475697081943508, 0.01191058427139069, 0.037170228897593915, 0.05337198432243895, 0.013043272319919197, 0.04934679796861019, 0.04282348687411286, 0.05019258285756223, 0.026548294081294443, 0.06953962321858853, 0.010257841804559575, 0.09480429682298563, 0.011096233047283022, 0.03353358282765839, 0.06691454298561439, 0.019596685851865914, 0.031571118015563115, 0.052953023405279964, 0.017060973186744377, 0.09932726388797164, 0.11056642251787707, 0.03781467654334847, 0.013746382101089694, 0.03131544071948156, 0.05286638879624661, 0.05105200099933427, 0.007100523871486075, 0.046347467505256645, 0.06244319229153916, 0.043040156888309866, 0.056813534611137584, 0.03586904364055954, 0.02411110523098614, 0.04673200390243437, 0.09049343556398526, 0.029231278531369753, 0.05678737390553579, 0.08924491310608573, 0.025426951615372673, 0.02462610005750321, 0.07329799263970926, 0.020954994215571787, 0.018996780054294504, 0.011540400082594715, 0.05345993995433673, 0.05081128911115229, 0.026215617108391598, 0.008317517113027861, 0.06025228700309526, 0.007412971290250425, 0.035821575875161216, 0.02786945795378415, 0.017387360458087642, 0.047194469516398385, 0.009356540558655979, 0.047553602198604494, 0.05767367263615597, 0.05412108963355422, 0.09368087077746168, 0.052439598221099004, 0.10839167749509215, 0.09296612319303676, 0.03695092054840643, 0.08614033125923015, 0.12383485038299114, 0.11399592403904535, 0.0043742569050664315, 0.0410617321904283, 0.05208397218666505, 0.06627600654610433, 0.03175600926624611, 0.045520362473325804, 0.061274606559891254, 0.025442826154176146, 0.030410402760026045, 0.0854714929300826, 0.0679069131729193, 0.032756446598796174, 0.013840838946634904, 0.04735436523333192, 0.027534164910321124, 0.08064503941568546, 0.07354558052611537, 0.003601236580834666, 0.01908003046992235, 0.024226529603765812, 0.07676074237679131, 0.023216678127937485, 0.020732290540763643, 0.01894412282126723, 0.0022428354486692115, 0.03287695653853007, 0.029063863003102597, 0.05213438627833966, 0.05305818202032242, 0.026041960118163843, 0.038743173790862784, 0.06816009685280733, 0.015094345853867708, 0.0381947415007744, 0.05030799795349594, 0.01903801748994738, 0.02007522081839852, 0.044108949732617475, 0.08028003634535708, 0.01445070251065772, 0.029286306926223915, 0.04726648752694018, 0.05284450657200068, 0.049234685429837555, 0.12926682218676433, 0.0973069152678363, 0.04430015666002873, 0.026834646196221, 0.040807939949445426, 0.04075394128449261, 0.04945709966705181, 0.06549073266796768, 0.023618224549863953, 0.008383940257772338, 0.05836385513248388, 0.035788743261946365, 0.021151926812308375, 0.027451929381641094, 0.06165260463603772, 0.06255051426705904, 0.05023123390856199, 0.016455475306429435, 0.0757383597374428, 0.08053002136875875, 0.024761107852100395, 0.0528939892683411, 0.039118696804507636, 0.024960843911685515, 0.07391781953629106, 0.027840968759846874, 0.015860883286222816, 0.01064720772774308, 0.0822215763037093, 0.024073702843452338, 0.05439620006654877, 0.018968550612044055, 0.04435550232301466, 0.03258081364037935, 0.10974441975122318, 0.03337930887937546, 0.02897193502576556, 0.025689929789223243, 0.0012519799383881036, 0.05161190318176523, 0.023431813751813024, 0.059253775543766096, 0.01660780111706117, 0.05104932555695996, 0.025280193767684978, 0.035831201530527323, 0.0063404639968211995, 0.015006713056209264, 0.06116030097473413, 0.06961342980503105, 0.027244647535553668, 0.011978795064351289, 0.038855776147102006, 0.05731585726607591, 0.013059698831057176, 0.010021273883467074, 0.027966254419879988, 0.018024794808297884, 0.08640636151540093, 0.00966910718489089, 0.08427815657341853, 0.02214700583863305, 0.02909089016611688, 0.12008217323455028, 0.00551588829694083, 0.1203726053063292, 0.03312870787340216, 0.033505136307212524, 0.012162755847384688, 0.06498103306512348, 0.059459443218656816, 0.021022598302806728, 0.05771676544100046, 0.03756049838557374, 0.06798250833526254, 0.012696325702563627, 0.034520398039603606, 0.035756931101786904, 0.02334598066227045, 0.018608200807648245, 0.013591836341220187, 0.016659092798363417, 0.02919088157796068, 0.0343655860342551, 0.025469103748037014, 0.04442684126843233, 0.03791091083257925, 0.06031691693351604, 0.03651050785265397, 0.06589456490473822, 0.026475186969037168, 0.03519421617966145, 0.047974262633943, 0.028107895159337204, 0.05634178472973872, 0.004528774834398064, 0.05018597403250169, 0.028831967829319183, 0.05273389688227326, 0.10028832286479883, 0.0377365432359511, 0.06727844025590457, 0.0055041340692696394, 0.01654279083595611, 0.05147660223883577, 0.030818891973467544, 0.014275218909460818, 0.026393086882308125, 0.03008152558322763, 0.07727585223619826, 0.022668915626127273, 0.046347018505912274, 0.01111653078623931, 0.027876580716110766, 0.020212393828842323, 0.009534047439956339, 0.09136617896729149, 0.028383554781612474, 0.04247507080435753, 0.021254497187328525, 0.010192049485340249, 0.09086160760489292, 0.020087217635591514, 0.04845829877012875, 0.043384899327065796, 0.04868060539592989, 0.12970299721928313, 0.09582119499100372, 0.03347419617057312, 0.03930447492166422, 0.08572519611334428, 0.05216469558945391, 0.024934221219155006, 0.09184384005493484, 0.054417262217612006, 0.03446692258876283, 0.0579432985978201, 0.04112357164558489, 0.0986369329621084, 0.0435260780795943, 0.07224005370517261, 0.03795672731939703, 0.029863838826713618, 0.061809320250176825, 0.048881096590775996, 0.05604740814305842, 0.01957004831638187, 0.01772566476574866, 0.025252005143556744, 0.075373052386567, 0.06363583845086396, 0.011544378921826137, 0.002251654018436966, 0.032681626980775036, 0.039424376300303265, 0.03888985556841362, 0.027610242468654178, 0.024562392245570663, 0.07076548790792003, 0.034743257565423846, 0.04826782656891737, 0.046035557679715566, 0.10701168357627466, 0.036411657492863014, 0.030966325175540987, 0.0855871343810577, 0.035241305449744686, 0.01034696817441727, 0.051083063590340316, 0.04440636170329526, 0.02286332121002488, 0.0408995283942204, 0.0062648748644278385, 0.07018348085694015, 0.024021585522859823, 0.015617991339240689, 0.03937553927244153, 0.036874969155178405, 0.022042492892069276, 0.033292399675701745, 0.01080672123862314, 0.1141653118247632, 0.049744804346119054, 0.03622227995947469, 0.025608922514948063, 0.054644285191898234, 0.013838210816174978, 0.0247853630935424, 0.0681450312549714, 0.0075003772690251935, 0.05705729672627058, 0.0523981010337593, 0.014784619797865162, 0.05812869450892322, 0.060406249249354005, 0.08174589675036259, 0.022485389927169308, 0.009870337744359858, 0.010392903404863318, 0.020304234603827354, 0.06303142596152611, 0.030427097372012213, 0.018084732510033064, 0.02028002945735352, 0.044112645628047176, 0.018372606027696747, 0.005607493440038525, 0.004729978491013753, 0.04193883200059645, 0.012431111808837159, 0.051624029874801636, 0.021243238807073794, 0.06763645229511894, 0.0634147081291303, 0.01375814143102616, 0.015295696084649535, 0.04146179802773986, 0.07541546612628736, 0.0502307663555257, 0.07901250006398186, 0.020605531717592385, 0.03798978999839164, 0.11954284709645435, 0.1136110388324596, 0.0906222798221279, 0.12295516789890826, 0.12889303208794445, 0.1507347499136813, 0.13343594066100195, 0.1362247980432585, 0.1153128057194408, 0.07983905961737037, 0.20212285104207695, 0.19897629332263023, 0.1642920810263604, 0.09442963841138408, 0.26567001768853515, 0.08032540383283049, 0.08276960041257553, 0.2665041323052719, 0.09125999247771688, 0.2070656733121723, 0.10035602157586254, 0.18421035987557843, 0.12411225776304491, 0.15586126857670024, 0.11606615982600488, 0.16522055229870602, 0.1457974046934396, 0.12417191901477054, 0.07595424307510257, 0.08665698478580453, 0.06996182361035608, 0.16617496905382723, 0.10385919609689154, 0.15195883344858885, 0.1011087374354247, 0.11195302155101672, 0.18385206582024693, 0.14925612456863746, 0.08154670431395061, 0.2245507764746435, 0.2457519169547595, 0.11888730063219555, 0.08168968648533337, 0.11100364397861995, 0.17474572086939588, 0.1699032072792761, 0.13572279451182112, 0.13513436046196148, 0.1968019935884513, 0.10125560103915632, 0.15684526733821258, 0.1561966896406375, 0.12372531680739485, 0.19807007163763046, 0.16133209923282266, 0.14193117152899504, 0.10765036844532005, 0.16715228848624974, 0.06257404776988551, 0.10915841994574293, 0.16683371417457238, 0.11505437505547889, 0.08513642067555338, 0.18027966376394033, 0.22828872199170291, 0.20167572190985084, 0.14872682484565303, 0.0872343682567589, 0.14588459220249206, 0.06980288526392542, 0.18303895398275927, 0.09476096282014623, 0.20714230748126283, 0.1786145070218481, 0.09932051034411415, 0.21224429074209183, 0.23391740745864809, 0.14508549211313948, 0.21405262261396274, 0.09054137830389664, 0.20634415734093636, 0.16626177064608783, 0.1600974178290926, 0.14371958415722474, 0.1364979677600786, 0.1843911618925631, 0.1579122678958811, 0.15594478987623006, 0.24106121709337458, 0.11068447594880126, 0.11695569060975686, 0.1306005654623732, 0.2028930519009009, 0.10796762915560976, 0.22082575917011127, 0.17921637394465506, 0.1287572190631181, 0.11213897407287732, 0.17432968772482127, 0.14780982717638835, 0.11491999437566847, 0.14492242742562667, 0.15779367269715294, 0.17638116201851517, 0.17683164565823972, 0.13903979386668652, 0.2425414157914929, 0.16304524324368685, 0.12282794894417748, 0.17761250375770032, 0.12130706571042538, 0.16834790323628113, 0.19642363185994327, 0.16321596689522266, 0.14834092289675027, 0.14998092083260417, 0.17486336611909792, 0.11568575719138607, 0.11173986189533025, 0.27068046445492655, 0.19895846693543717, 0.11801629385445267, 0.16070091747678816, 0.1513293437892571, 0.23837064974941313, 0.11187713695107959, 0.17487617558799684, 0.14148944523185492, 0.07482584464014508, 0.13243752939160913, 0.1844561443431303, 0.16840694850543514, 0.15366899402579293, 0.15398033981909975, 0.12543462391477078, 0.21034884557593614, 0.13103951612720266, 0.21199703682214022, 0.11161857270053588, 0.11371169632184319, 0.1480184745742008, 0.140043236897327, 0.12715738615952432, 0.16371258243452758, 0.17758976435288787, 0.1277684557135217, 0.17312629526713863, 0.2141932150698267, 0.20017471339087933, 0.14631787285907194, 0.09016537660500035, 0.09477042520302348, 0.09916059978422709, 0.18315400171559304, 0.14076453022425994, 0.11298352328594774, 0.1266900557675399, 0.13026803877437487, 0.24113682709867135, 0.11776781539083458, 0.10302076218067668, 0.11252702082856558, 0.10693081174395047, 0.15453460538992658, 0.2318096486851573, 0.08952663236414082, 0.13058358512353152, 0.11778998334193602, 0.15581170795485377, 0.09576508120517246, 0.0978277248213999, 0.20350456674350426, 0.20632680592825636, 0.18699541746173054, 0.12839598610298708, 0.12503047997597605], [0.06225837525562383, 0.04703734572103713, 0.06278049098909833, 0.12072558558429591, 0.05827610359119717, 0.05803607447887771, 0.02156975224352209, 0.031191190355457366, 0.011933222558582202, 0.06418520584702492, 0.030742541675863322, 0.02940994130767649, 0.07239341110107489, 0.049472450991743244, 0.010809088689711643, 0.0411145397083601, 0.033555791596882045, 0.016148856993822847, 0.010547923211561283, 0.0371485878713429, 0.039259504483197816, 0.02977268824906787, 0.055779949252610095, 0.036518556444207206, 0.031109175615711138, 0.012100739204470301, 0.045659748939215206, 0.09903417492751032, 0.05440646025817841, 0.04361945510026999, 0.044892193836858496, 0.023350316660071258, 0.06310322874924168, 0.05139163746207487, 0.04463303957891185, 0.022380945629265625, 0.04824253417609725, 0.018132404366042465, 0.04453194793313742, 0.03503772692056373, 0.009428206976735964, 0.029812792054144666, 0.014510252440231852, 0.03559122807928361, 0.012604244657268282, 0.021522867064049933, 0.025980393402278423, 0.0448139788932167, 0.05077296089439187, 0.10361366395954974, 0.06338348597637378, 0.06539478039485402, 0.03511725917633157, 0.03579066913516726, 0.009845579697866924, 0.0612246674427297, 0.04641296203772072, 0.0586498825578019, 0.04192056403553579, 0.08989386187749915, 0.005534975871341885, 0.12680492538493127, 0.10968933755066246, 0.08970444352598861, 0.03469710711215157, 0.019119241842417978, 0.031152320370892994, 0.058872378431260586, 0.016793325048638508, 0.07917989889392629, 0.06234393746126443, 0.03229836707760114, 0.03729221200046595, 0.00757538752623077, 0.016559426076128148, 0.03541418875101954, 0.009507610284344992, 0.08818061396596022, 0.017279550520470366, 0.07080578652676195, 0.11605441162828356, 0.03346909019455779, 0.02356516655709129, 0.14206763764377683, 0.04497853900829796, 0.04180112278845627, 0.06560558744240552, 0.056588266816106625, 0.03747479888261296, 0.06373510070261545, 0.02919728445704095, 0.02722623114095768, 0.0927505292929709, 0.03332608575874474, 0.054736882957513444, 0.00725169054021535, 0.06876543702674098, 0.024514295510016382, 0.033771099770092405, 0.03330145758809522, 0.00885739244040451, 0.03205110944691114, 0.1081170754332561, 0.07224697052151896, 0.012862570492870873, 0.031029656347527634, 0.015632448375981767, 0.009542513489577686, 0.018945790798170492, 0.030411163461394608, 0.05200863306527026, 0.04429678730957676, 0.010409534934296971, 0.04469346895348281, 0.029988447276991792, 0.08164369559381157, 0.04096156080777291, 0.04350304923718795, 0.014720655017299578, 0.06008809796185233, 0.03949876547267195, 0.049700060262694024, 0.042499268529354595, 0.03239612648030743, 0.016852706139616203, 0.031863231051829644, 0.04571163248328958, 0.008594811315560946, 0.035330827013240196, 0.011752273039746797, 0.018991238066519145, 0.051450482351356186, 0.017317889869445935, 0.025377105266670696, 0.05346923535398673, 0.019538575688784476, 0.11843853135360405, 0.027551954190130346, 0.00392522045331134, 0.032418487389804795, 0.05223376356298104, 0.014005654174980009, 0.017921688231581356, 0.09669953418779187, 0.05064515193225816, 0.025904230496962555, 0.04560957975627389, 0.016445183573523536, 0.03438650717725977, 0.01223120505528641, 0.027628389834717382, 0.047461245630984195, 0.042960639475495555, 0.03524881227349397, 0.00900258899491746, 0.012236205275257817, 0.07280893958522938, 0.02833264159562532, 0.01417244444382959, 0.06617984647164121, 0.031668892261222936, 0.011799066378443968, 0.05728286509111058, 0.0320595068478724, 0.10152013957849704, 0.05973443119728472, 0.0318226504168706, 0.0030931472065276466, 0.02795564170810394, 0.062170601449906826, 0.008866091338859405, 0.07143598864786327, 0.04223975432978477, 0.029354426806094125, 0.05740736778534483, 0.008169465145329013, 0.08753782502026297, 0.024080653056444135, 0.05973751853161957, 0.06456305549363606, 0.012238564377184957, 0.08358755105291493, 0.06564878785866313, 0.009453911261516623, 0.0587496754451422, 0.03398909822863061, 0.03252324524510186, 0.037225852865958586, 0.07565358420833945, 0.004036397422169102, 0.013575294797192328, 0.03238228913687635, 0.057699269309523515, 0.020600377501978073, 0.0262031564489007, 0.0606517591222655, 0.03247198510507587, 0.04715511342510581, 0.03021563166839769, 0.09407500314409845, 0.02340140796150081, 0.03125300754618365, 0.058512774485279806, 0.04483340460865293, 0.017283888373640366, 0.024881857134460006, 0.016659196699038148, 0.0342720346088754, 0.04087147150130477, 0.024134466184477787, 0.03186351306794677, 0.005958689780527493, 0.06519288654089905, 0.022521050123032182, 0.006020064001859282, 0.06322231376543641, 0.030930922875995748, 0.03938494970498141, 0.08960263570770621, 0.060239206650294363, 0.052040471200598404, 0.10405869281385094, 0.030993426553322934, 0.10863254894502461, 0.0710160072776489, 0.046352321151061915, 0.0448698180844076, 0.04935423428833019, 0.031606555567122996, 0.051638431250466965, 0.047098877184907906, 0.052318943562568165, 0.06322969071334228, 0.06296302963164635, 0.045345586695475504, 0.05739260646805633, 0.03186221430951264, 0.0534375716233626, 0.07601612334838137, 0.030610864268965088, 0.0637643710069824, 0.019819912740786094, 0.018611956074892078, 0.057315920348628424, 0.07768786294036545, 0.04632583761122078, 0.09175691971904598, 0.1236553693888709, 0.07734106475254521, 0.053793795086676255, 0.04393963987240568, 0.09830776078160852, 0.007416577200274332, 0.0788202986586839, 0.05652896550600417, 0.08363207249203697, 0.1479328455752693, 0.08704515770659782, 0.037314695364329964, 0.027331150413374417, 0.01443820010536001, 0.06904006135300733, 0.05933594242378604, 0.015185518695943756, 0.05283019054331817, 0.08869855140801519, 0.06708386397804134, 0.05124580173287541, 0.11346231985953636, 0.03390702040633187, 0.09054019828909077, 0.07606609215145, 0.030723756062798202, 0.0237804190692259, 0.056966621123137884, 0.03417597843508702, 0.032534518468310125, 0.008562578914279584, 0.11618892589467578, 0.01210598247780581, 0.027003505201719236, 0.06449413966038264, 0.03491457493510097, 0.05374351087084506, 0.030320567639137153, 0.028339291238808073, 0.0024249763464467833, 0.07418391658575274, 0.03698934524436481, 0.048051030389615335, 0.021125795792613644, 0.05402417627919931, 0.09529536109766923, 0.03068840756895952, 0.026300372228433844, 0.05186354319448583, 0.029504372178053018, 0.04086258799361531, 0.018650937381607946, 0.03411344878259115, 0.023319469291891437, 0.026625583195709623, 0.037037351066828705, 0.05526074273802806, 0.07384278840618208, 0.04365359760413412, 0.10653773322701454, 0.07391678052954376, 0.017455576817155816, 0.07856201642425731, 0.04046628855576273, 0.06414148592739366, 0.05870112785487436, 0.01705593771475833, 0.01328153512076824, 0.0499954387487378, 0.02165237739973236, 0.059350651790737174, 0.06914321988006122, 0.06960554077522829, 0.04987374508345965, 0.06911556745762937, 0.049671465312712826, 0.028152262602816336, 0.022769433962821495, 0.06846410280559212, 0.03763303589948919, 0.0054529356202692725, 0.022853497030155268, 0.04666025677579455, 0.04068581954925321, 0.09766981063876301, 0.07928257502499036, 0.034417228380334564, 0.00981714338195161, 0.07901420700363815, 0.01562655386806, 0.03703165137267206, 0.061988960806047544, 0.042024297727039084, 0.06985395986703224, 0.05699149791325908, 0.012569362788781291, 0.015769088895467576, 0.05355501278245356, 0.03214389274944551, 0.02940829930594191, 0.02863527086446993, 0.03049018920137314, 0.03880983349517919, 0.004785076926054899, 0.012817060141969705, 0.22082032664911821, 0.1401762297609821, 0.15526710514677688, 0.14666317933006212, 0.241352999873925, 0.17470371531089768, 0.14034493477083743, 0.1059577077103313, 0.13585660373792052, 0.18491447990527377, 0.10492152854567394, 0.0730325561016798, 0.27169266482815146, 0.12612406426342204, 0.08246366487583145, 0.1269242775742896, 0.11502733119414188, 0.13840378815075383, 0.14512653287965804, 0.12406160618411377, 0.1394547286326997, 0.08604996735812165, 0.18529480090364814, 0.2263249843963422, 0.10618898319080472, 0.1247581563075073, 0.14428815833525732, 0.14242115226807073, 0.120190771704074, 0.11292758019408211, 0.11151962957228534, 0.1728940921020694, 0.1288236561231315, 0.17753540945705026, 0.13160145550500602, 0.08225227895309217, 0.21248032338917255, 0.09491378586972132, 0.15106004808330908, 0.18063482595607638, 0.08439624711172655, 0.19885777233866975, 0.17391084926202893, 0.15846834430703893, 0.2103920088848099, 0.15992816362995654, 0.12143436630140059, 0.24055143585428596, 0.151559142395854, 0.16816224757349119, 0.17421823198674247, 0.16935578431002796, 0.1570232937228866, 0.130910768348258, 0.15190254896879196, 0.10118054022314027, 0.15928507782518864, 0.19946035172324628, 0.14330294245155528, 0.17142014228738844, 0.14109339070273563, 0.1499683636939153, 0.36833661957643926, 0.17660938727203757, 0.1536332818795927, 0.17539085500175133, 0.18295917310751975, 0.13284873857628554, 0.2413827006239444, 0.1689237801474519, 0.12589747173478827, 0.21975210896926, 0.18130271433619782, 0.1386050586006604, 0.2824984834296629, 0.14452603150857612, 0.1260473410366103, 0.3138807916548103, 0.16125954687595367, 0.1674107785220258, 0.1877794074243866, 0.15179820300545543, 0.14614291896577924, 0.2696933486731723, 0.10885048803174868, 0.2626014151610434, 0.21188046026509255, 0.1859084828174673, 0.22142421221360564, 0.08551235558115877, 0.11711076236679219, 0.13726080651395023, 0.27308730874210596, 0.19957229727879167, 0.12383534020045772, 0.16697175364242867, 0.10147981869522482, 0.1779442437691614, 0.15123516524909064, 0.13276299083372578, 0.1327693139319308, 0.10701785824494436, 0.1711812597932294, 0.14752323942957446, 0.16048211749875918, 0.21493377455044538, 0.14102820045081899, 0.1436643980559893, 0.1799922893405892, 0.16951956145931035, 0.13932593632489443, 0.13335624884348363, 0.17622743354877457, 0.1978775585303083, 0.16648891236400232, 0.19444390840362757, 0.2758020255714655, 0.17244973860215396, 0.11340031342115253, 0.19431418098974973, 0.1625537485233508, 0.1849852956365794, 0.1613717744476162, 0.062050425476627424, 0.12550008133985102, 0.14895174012053758, 0.1981814976898022, 0.14607857476221398, 0.1371488906443119, 0.23817479697754607, 0.22545193671248853, 0.15392034460091963, 0.1002745189180132, 0.14786628977162763, 0.13371846143854782, 0.14913451625034213, 0.15917961864033714, 0.20293533947551623, 0.08777435490628704, 0.11345047518261708, 0.14004408294567838, 0.1787662910646759, 0.16485712258145213, 0.1755830118781887, 0.20283924619434401, 0.165786603174638, 0.15419468691106886, 0.12840760813560337, 0.10358757746871561, 0.16148903378052637, 0.09274508935050108, 0.09375714129419066, 0.11096623973571695, 0.09641952186939307, 0.15776563435792923, 0.17397020623320714, 0.23126072657760233, 0.09416824657819234, 0.10848855745280161, 0.21397690870799124, 0.10819724964676425, 0.07676202629227191, 0.17920194659382105, 0.10625106384395622, 0.2521021035499871, 0.1451924059074372, 0.17896898643812165, 0.06954914497327991, 0.17791838734410703, 0.16263115452602506, 0.09477783183683641, 0.13095627684378996, 0.18718128092586994, 0.10375902100349776, 0.12560402654344216, 0.09396284236572683], [0.036686949752038345, 0.014918045890226495, 0.09734076462336816, 0.04944319181959145, 0.08891839781426825, 0.0038932589359319536, 0.01096970521757612, 0.06052794291463215, 0.040690242749406025, 0.02728199055127334, 0.043768292816821486, 0.05825678177643567, 0.025937393365893513, 0.05422137975983787, 0.014858030262985267, 0.010722312144935131, 0.008980799539131112, 0.0626921012008097, 0.002472971268616675, 0.07475071703083813, 0.05139944114489481, 0.07760801527183503, 0.0511041814024793, 0.030027333959878888, 0.06006600051478017, 0.01744235174555797, 0.06074207107303664, 0.048427299261675216, 0.031045209907460958, 0.025240416507585905, 0.024429152617813088, 0.025874449966067914, 0.10051304518128745, 0.015393048233818263, 0.036466591263888404, 0.0546282473806059, 0.07716752836131491, 0.013736980017711176, 0.014367884396051522, 0.03303804340248462, 0.035146466398146003, 0.0729768282326404, 0.011959145776927471, 0.042424389539519325, 0.01207716673889081, 0.04496113564528059, 0.03385763418918941, 0.04489134778850712, 0.024650611339893658, 0.05200262166908942, 0.04224056327075232, 0.027392440679250285, 0.03274957802204881, 0.057685921783559024, 0.010748958957265131, 0.06884642018121667, 0.009161130292341113, 0.01372206656014896, 0.008925514175643912, 0.08275069048977457, 0.06505877303425223, 0.034343440347583964, 0.06616153026698157, 0.0054621053186565405, 0.08978114448837005, 0.01936065877089277, 0.0808109316858463, 0.0387091537413653, 0.06355873672873713, 0.054944469084148295, 0.08390429225983098, 0.04664970714657102, 0.011489012849779101, 0.03684845221869182, 0.05662666924763471, 0.10423334984807298, 0.024001939018489793, 0.10867642471566796, 0.20643045427277684, 0.033888759862747975, 0.13806737260892987, 0.2600977651309222, 0.10629607510054484, 0.11186938150785863, 0.021471002073667478, 0.13106471946230158, 0.09371790394652635, 0.04980103316484019, 0.21563151211012155, 0.13902465405408293, 0.1210000689025037, 0.10573055857094005, 0.08667399481055327, 0.032351527115679346, 0.12023250266793184, 0.09203662775689736, 0.06265792530030012, 0.04933719457767438, 0.051947461543022655, 0.04552274847810622, 0.04453703164472245, 0.03649469268566463, 0.03196109064447228, 0.027055513055529445, 0.10815524408826604, 0.047443827425013296, 0.03724440284713637, 0.045916506060166284, 0.019096469040960073, 0.004660660506488057, 0.021707500418415293, 0.02013032713875873, 0.12020007081446238, 0.010858347814064473, 0.041287282001576386, 0.004466016043807031, 0.06928050235728733, 0.02527575572457863, 0.018496631892048754, 0.025146156331175007, 0.014893371335347183, 0.0758651334035676, 0.023777387395966798, 0.015972656292433385, 0.052071192403673194, 0.04570236676954664, 0.01918754911457654, 0.049665724800433964, 0.022683656534354668, 0.014707392838317901, 0.08353763420018367, 0.03360279180924408, 0.034170972649008036, 0.03292128130851779, 0.05041970231104642, 0.10206510603893548, 0.0238708497636253, 0.019502004506648518, 0.009000467380246846, 0.05247200409939978, 0.07117209577700123, 0.018723443354247138, 0.051722067582886666, 0.09576494761859067, 0.011613701080932515, 0.05674810687196441, 0.059982082166243345, 0.024748829018790275, 0.02413177218841156, 0.04535054795269389, 0.05407389275205787, 0.052385618109838106, 0.031387469862238504, 0.08409402973484248, 0.058302561155869626, 0.018010532585321926, 0.0716640951577574, 0.043686159333446994, 0.05576639392529614, 0.014091794328123797, 0.04001539302407764, 0.05316409020451829, 0.03862323530483991, 0.08398278179811314, 0.0186250976548763, 0.03981745110650081, 0.027484936399559956, 0.025728443542902824, 0.01576732629473554, 0.04938195721479133, 0.01798890640202444, 0.07991167876753025, 0.006463007885031402, 0.044822053459938616, 0.04624764493200928, 0.06163673380797263, 0.040076920777210034, 0.043648692007991485, 0.08022879104828462, 0.019254763574281242, 0.12657223240239546, 0.024863735743565485, 0.01695753264357336, 0.042241272021783516, 0.06671736176940612, 0.03199898470484186, 0.08317309126141481, 0.05300539676682092, 0.02377449673076626, 0.03331323176098522, 0.05193761324335355, 0.044669197013718076, 0.012294269054109463, 0.037847331041120924, 0.03891529639076907, 0.004722473986475961, 0.02032157117355382, 0.09334268150269054, 0.046249084698501974, 0.026237879683321808, 0.03028564402484335, 0.031278118112822995, 0.027464998602226842, 0.0063331487399409525, 0.04674810108554084, 0.02982539743243251, 0.03839792298094835, 0.011559591093828203, 0.001486778533035249, 0.04681312064349186, 0.03644353273557499, 0.052502647376968525, 0.060344680678099394, 0.12420063270838, 0.040836397602106445, 0.05767059272329789, 0.016918887158681173, 0.05097379718790762, 0.0475384178571403, 0.03642362091341056, 0.029080728309054393, 0.016120636828418355, 0.07392016472294927, 0.10789171486976556, 0.015900154030532576, 0.0225820194100379, 0.046312798076542094, 0.135506413935218, 0.03574174304958433, 0.07884060381911695, 0.037351190476329066, 0.016790267400210723, 0.03798160410951823, 0.010421472379675834, 0.027274984677205794, 0.06442884550779127, 0.03326907397422474, 0.08725226143724285, 0.04259887216903735, 0.05700349101971369, 0.05534062009246554, 0.07138069864595309, 0.04471151427424047, 0.030476448337140027, 0.051019795500906184, 0.025569551580701955, 0.10073355952044949, 0.10837966954568401, 0.05556735733989626, 0.05610972999420483, 0.0350133436586475, 0.08104043343337253, 0.0626204171567224, 0.1378092833328992, 0.19825122988549992, 0.04289557538868394, 0.20993017038563266, 0.15797538013430312, 0.05087342913611792, 0.1796416097204201, 0.10872913946514018, 0.05737994913943112, 0.14424162567593157, 0.14467354078078642, 0.19159792049322277, 0.17257484985748306, 0.056405160430585966, 0.09381106574437581, 0.0984326568141114, 0.07713325598160736, 0.18750692048342898, 0.07533195966971107, 0.0638784836337436, 0.03671952632430475, 0.03597615781472996, 0.028270379116293043, 0.046045873532420956, 0.05834153504110873, 0.022475357945950236, 0.03483297579805367, 0.04915052588330582, 0.06115706892160233, 0.04408187247463502, 0.05614801739284303, 0.06782016353099607, 0.05809984722873196, 0.04114334245969076, 0.05110423706355505, 0.1594269319321029, 0.07250821392517537, 0.016309160891978536, 0.015835741178307217, 0.02011013144510798, 0.040821101938490756, 0.03722614230355248, 0.0568861018109601, 0.027212156310270075, 0.0770882744109258, 0.10420827267807908, 0.03910933832230512, 0.07086860190611333, 0.02748131657426711, 0.0201363533778931, 0.04029195064504165, 0.019071636779699475, 0.04162949371675495, 0.07107227691449225, 0.06095708238717634, 0.014914947423676495, 0.01415795493812766, 0.016461533086840063, 0.005789595606984221, 0.01943829483934678, 0.02341605239053024, 0.04526440316112712, 0.020780697122972924, 0.017595601530047134, 0.070563341723755, 0.03929637809051201, 0.1299513049889356, 0.04765161393152084, 0.014223827965906821, 0.045126296899979934, 0.057735682785278186, 0.013909020981373033, 0.028657960174314212, 0.020355414962978102, 0.027681824467435945, 0.023438444841303863, 0.031224857884808443, 0.024653221844346263, 0.06741669494658709, 0.020174178789602593, 0.031503742138738744, 0.05401197537139524, 0.03341329924296588, 0.012985751236556098, 0.07896815674030222, 0.044725852567353286, 0.06585719776921906, 0.07690999569604173, 0.03506093016767409, 0.011476990057417424, 0.022809185247751884, 0.07818396639777347, 0.05872473928320687, 0.06029489370121155, 0.028850803537352476, 0.055333001946564764, 0.038173876018845476, 0.030574630764022004, 0.02605821871838998, 0.14050394733203575, 0.12955479032825679, 0.1515107840532437, 0.06209768915141467, 0.21308368945028633, 0.07703054274315946, 0.0990512443240732, 0.1551783294416964, 0.18728665105300024, 0.1623765385011211, 0.18745602399576455, 0.16829019383294508, 0.14899867353960872, 0.13965565769467503, 0.23721159319393337, 0.16887806385057047, 0.08986070271930657, 0.13540692161768675, 0.10158909251913428, 0.20534516719635576, 0.08065010086284019, 0.17465241806348786, 0.19601322419475764, 0.13121528638293967, 0.11901416335604154, 0.11058265328756534, 0.20518982084468007, 0.10544563323492184, 0.15730118349893019, 0.14117996965069324, 0.14487144188024104, 0.09203993031405844, 0.14158463309286162, 0.19736969203222543, 0.1983477536123246, 0.14893959858454764, 0.18510271824197844, 0.24425691983196884, 0.08472756409901194, 0.1921545312507078, 0.09824998458498158, 0.23085808177711442, 0.0846946646925062, 0.1129676190612372, 0.10995042510330677, 0.19480340473819524, 0.1486360453418456, 0.27625052025541663, 0.2211580632138066, 0.13641128491144627, 0.17284594156080857, 0.27879825385753065, 0.1618217831128277, 0.1725101939518936, 0.10143814710318111, 0.26096287183463573, 0.12966556329047307, 0.1303745963377878, 0.20023362507345155, 0.20460983243538067, 0.1975872303592041, 0.26564166764728725, 0.17506184609374031, 0.14362776564667, 0.2573489985661581, 0.1810085863689892, 0.15420089126564562, 0.19401665398618206, 0.1610910941963084, 0.19693685666425154, 0.2277045775554143, 0.13718770496780053, 0.14853907632641494, 0.10319334862288088, 0.2852458250708878, 0.26227199065033346, 0.24487259070156142, 0.3072646341752261, 0.43257282581180334, 0.24084537086309865, 0.3726175945485011, 0.3465164388762787, 0.3780578635632992, 0.36404293903615326, 0.22758678387617692, 0.2715335780521855, 0.27796425798442215, 0.2663067210232839, 0.4788315435871482, 0.23459255404304713, 0.20015439338749275, 0.21115532261319458, 0.32956317358184606, 0.1301431650063023, 0.3479057096410543, 0.148541807429865, 0.12099285522708669, 0.13858083490049466, 0.10153426264878362, 0.13540742627810687, 0.12109688948839903, 0.11456700667622499, 0.16376209852751344, 0.1568700699135661, 0.18510372756281868, 0.25810738443396986, 0.14766447013244033, 0.23290480632567778, 0.13795407634461299, 0.19697982701472938, 0.16611972358077765, 0.16534499562112615, 0.2638882101746276, 0.21315477235475555, 0.27115021424833685, 0.0797285464068409, 0.20265534200007096, 0.16888397134607658, 0.12489986198488623, 0.1896833279170096, 0.11194442748092115, 0.19184287375537679, 0.1864120745449327, 0.10279520123731345, 0.1698550715809688, 0.1035742113890592, 0.12975344841834158, 0.0928807094169315, 0.09644037621910684, 0.11335408504237421, 0.2770854957634583, 0.14676206308649853, 0.2256760949967429, 0.12103522443794645, 0.29812363092787564, 0.2874688245356083, 0.15611637441907078, 0.10963491586153395, 0.11709040525602177, 0.12917046173242852, 0.13522159249987453, 0.10768884138087742, 0.19665797241032124, 0.26664772303774953, 0.062474295700667426, 0.12811641907319427, 0.09335209193523042, 0.24978749337606132, 0.09594185336027294, 0.11695214314386249, 0.061330230528255925, 0.14184386527631432, 0.20596101618139073, 0.14729378221090883, 0.19804765877779573, 0.15951083914842457, 0.1814663430559449, 0.12243332676007412, 0.08382325715501793, 0.07597099334816448, 0.12804497993784025, 0.3074760572053492, 0.11352012574207038, 0.1387498516123742, 0.11411955099902116, 0.17723906988976523, 0.14999537786934525, 0.15351550304330885, 0.09362608543597162, 0.1707110201823525, 0.1087442495918367, 0.2154202523524873, 0.18799025157932192, 0.17004970723064616, 0.1495296208304353, 0.15199591114651412], [0.04307664086809382, 0.032677070194040425, 0.024692576080269646, 0.039979376597329974, 0.04529896868916694, 0.030639826582046226, 0.056727226547081955, 0.04768467661051545, 0.0172339733762783, 0.025512357970001176, 0.053850116673856974, 0.020118842403462622, 0.029165477862989064, 0.005890933089176542, 0.006778702663723379, 0.09659885443397798, 0.03353141946718097, 0.03892402775818482, 0.07291220943443477, 0.030216692939575296, 0.06637272323132493, 0.01546433151816018, 0.021509107646124903, 0.017245936796825845, 0.009062556382559706, 0.022298548683465924, 0.04306911549065262, 0.004391694592413842, 0.056205893779406324, 0.029271087332745083, 0.057562261426937766, 0.033772695387597196, 0.053431827400345355, 0.08333785546710715, 0.141897359280847, 0.06232054496649653, 0.033050663623725995, 0.03753642311494332, 0.01600749270437518, 0.07178142128395848, 0.0517543510068208, 0.01068230667442549, 0.037238372897263616, 0.025120138489000965, 0.033876009765663184, 0.03176689657266252, 0.07921679847640917, 0.059707227774197236, 0.07503924920456484, 0.046034110491746105, 0.038419649354182184, 0.017788357690733392, 0.090580073883757, 0.037361803188105114, 0.03813441602687817, 0.0464537987136282, 0.014228097170416731, 0.06324907561065629, 0.025708307221066207, 0.06630736228544265, 0.06769578700186685, 0.052539209282258525, 0.019827260002784897, 0.019928700457967352, 0.0055850249191280454, 0.09298703691456467, 0.008363211145479, 0.03279163924162276, 0.06427451589843258, 0.06014211518049706, 0.03339570663229097, 0.042172474932158366, 0.03442581873969175, 0.027915276295971125, 0.05156346691364888, 0.10428943394799717, 0.19666990614496171, 0.023073746051522903, 0.19064675434492528, 0.05111912454594858, 0.11156669657793827, 0.11375163870980032, 0.031423334148712456, 0.025433091032027733, 0.0357458656799281, 0.08736386560485698, 0.06192563334479928, 0.05406657146522775, 0.08604957401985303, 0.05652993029798381, 0.019316656835144386, 0.06617189064854756, 0.10205622253124602, 0.07133008417440578, 0.05376259890908841, 0.029533158231060952, 0.05145021146745421, 0.022228653215279337, 0.08342418950633146, 0.07397697612759657, 0.09930928907124326, 0.068773444800172, 0.011251258420088561, 0.0677780169644393, 0.0773288267373573, 0.0697487752768211, 0.046506428116117604, 0.06165227066958323, 0.041461734945187345, 0.04831857462704647, 0.04394318733830005, 0.004719467360700946, 0.08362883672816679, 0.022380695154424757, 0.03852174289932009, 0.018710095828282647, 0.01733405199047411, 0.008144723797158804, 0.012957553335581906, 0.028844126063631848, 0.09722907139803283, 0.027450242851045914, 0.04860484696109779, 0.020639163994928822, 0.10714840944274329, 0.06777905597118661, 0.0990260335674975, 0.03609847859479487, 0.030004629807081074, 0.03843634025542997, 0.05856576382939238, 0.010695162527554203, 0.02062334882793948, 0.03161297143378761, 0.019882423839590047, 0.054153903693077154, 0.15439208335010335, 0.024849883557180874, 0.06810216480516829, 0.08512405649526045, 0.014485147439700086, 0.010676131078071194, 0.021316258716979064, 0.01326880264969077, 0.11306188665912487, 0.06833606748841703, 0.10494110640138388, 0.04873294907156378, 0.025962656072806567, 0.036064228479517624, 0.045844714404665865, 0.016449762624688447, 0.026615718197717797, 0.04858867185248528, 0.03990265337051824, 0.0511170391109772, 0.021517122841032688, 0.032050460067694075, 0.013266976966406219, 0.04945266533468384, 0.014346108855534112, 0.024434551742160693, 0.07125378397176974, 0.0449737929739058, 0.013245775662653614, 0.02082845618133433, 0.01266407196453656, 0.03975078398070764, 0.057986621468444355, 0.024927206068241503, 0.058067997961188667, 0.03585601152735762, 0.020982238456781488, 0.06896719729411416, 0.05728844233090058, 0.034760505077429116, 0.013641717941936804, 0.049023243846022524, 0.06227948935702443, 0.034434156768838875, 0.01974644197616726, 0.06331948316073976, 0.022296107017609756, 0.010935317804978695, 0.02029372022661846, 0.01678353797615273, 0.08669683811604045, 0.010519421957724262, 0.013894866369810188, 0.021216499226284213, 0.04045792455144692, 0.06466006161645055, 0.07041671560727991, 0.10117234691279009, 0.03972697217250243, 0.06114122035796754, 0.06259704692638479, 0.07471929449820891, 0.0587868125148816, 0.07033522037090734, 0.010530543968343409, 0.03866848404868506, 0.05568568536546081, 0.027395884244469926, 0.05431928388134111, 0.08516793968738057, 0.023314207464864012, 0.08512582280673087, 0.013894258736399934, 0.005003345804652781, 0.10973422264214605, 0.015486559768760344, 0.08093057331279851, 0.029408375376078766, 0.04041177038743626, 0.06732138092047535, 0.0478024294716306, 0.062003351049497724, 0.04977023403625935, 0.048610646845190786, 0.03181978943757713, 0.02005116595682921, 0.034199189103674144, 0.013358621999941533, 0.02856606188288424, 0.01527734741102904, 0.026273565854353365, 0.020070278114872053, 0.05809242204122711, 0.038059162252466194, 0.019156039379595313, 0.009820610139286146, 0.026820938728633337, 0.04155562404775992, 0.048142377636395395, 0.048561323710600846, 0.0775419121782761, 0.06977340715820901, 0.06695973235764541, 0.054239558667177334, 0.0568340921017807, 0.0741310534067452, 0.04352642688900232, 0.05496635501913261, 0.16175360942725092, 0.09065156496944837, 0.1393076646490954, 0.14011360734002665, 0.049095510476036, 0.05761880936915986, 0.02671346090210136, 0.06384539869031869, 0.12096788195776753, 0.11802979352069087, 0.12398581064189784, 0.023326972404902335, 0.17788193305023015, 0.07680643640924245, 0.018167930975323543, 0.018140551292162854, 0.03876020979078021, 0.04064802567881998, 0.10233754845103249, 0.04407276261190418, 0.07428029930451885, 0.09981670285924338, 0.012480318982852623, 0.034447630459908396, 0.06393140618456528, 0.036205358992447145, 0.1020248667919077, 0.028996754299441818, 0.061246078403200954, 0.01564494799822569, 0.07554272960987873, 0.15495792642468587, 0.08025830626138486, 0.0762879646208603, 0.10528256112593226, 0.04831867481698282, 0.016066896059783176, 0.04383683386549819, 0.032559558530920185, 0.07676624911255203, 0.07586016101413406, 0.03843364625936374, 0.07793764758389443, 0.011531883010320598, 0.11454122446593828, 0.058887444029096514, 0.007886076982686063, 0.03250050955102779, 0.0563548242644174, 0.033516932744532824, 0.03637861336756032, 0.01971854093426373, 0.059275119710946456, 0.049888654830283485, 0.030494734855892602, 0.042827316356124356, 0.027369294948584866, 0.053460470589925535, 0.03492513940727804, 0.10544999706326053, 0.018102534777426627, 0.04081764353031758, 0.04936106204695534, 0.03963365452364087, 0.04074880191183183, 0.01691878140263725, 0.04015307997178752, 0.044895533501403406, 0.08041301436605863, 0.0427934224717319, 0.08807377438643016, 0.06586459698155522, 0.02803048544592457, 0.022385888332792092, 0.018492195704311598, 0.021791843646497, 0.07010073881247081, 0.09851241542492062, 0.054869463929207996, 0.025069436815101653, 0.06463138503022492, 0.05276731950289104, 0.04321879183407873, 0.03952627317630686, 0.03794368778471835, 0.006856946365587646, 0.029715284981648438, 0.07531309427577071, 0.04522126582742203, 0.04669764246500563, 0.02261193723825272, 0.02454114826832665, 0.01340894425084116, 0.06009859193000011, 0.06035415419319179, 0.026423084491398185, 0.016353858591173775, 0.030947732520871796, 0.02680271714780247, 0.04134276867262088, 0.057238711015088484, 0.04406582724186592, 0.038312501783366315, 0.020810245732718613, 0.017169990969705395, 0.0643074227264151, 0.04456864342500921, 0.1279007806442678, 0.16256450966466218, 0.11891268208273686, 0.1300697072292678, 0.12723347113933414, 0.10786381753860041, 0.18569204286905006, 0.1522691105492413, 0.13619401375763118, 0.1759803874301724, 0.12680982355959713, 0.23025958420475945, 0.17248429299797863, 0.08967434201622382, 0.07882891499320976, 0.0817515593371354, 0.22859893972054124, 0.14263716177083552, 0.1526589458808303, 0.1784165168646723, 0.09094185603316873, 0.11944798578042537, 0.1574270220589824, 0.13609826186439022, 0.21497742767678574, 0.10723677696660161, 0.1768881973112002, 0.15446861361851916, 0.11809279443696141, 0.13075784139800817, 0.17928292974829674, 0.14973721437854692, 0.20901210402371362, 0.18152215256122872, 0.16941350855631754, 0.26036413677502424, 0.11433591673267074, 0.21333505486836657, 0.13168646109988913, 0.11586463704588823, 0.1624065509531647, 0.139814967114944, 0.1110438683826942, 0.2103573505883105, 0.1531489414628595, 0.1003230553760659, 0.1331700588343665, 0.3237361862557009, 0.1473496065591462, 0.14191744179697707, 0.14444461790844798, 0.08723342572920956, 0.08625546804978512, 0.2228153235046193, 0.1289712989819236, 0.1367061847122386, 0.13931993977166712, 0.11460827750852332, 0.1453213466447778, 0.1597219950053841, 0.18860648648114875, 0.1717122961417772, 0.1912973655271344, 0.20269431959604844, 0.09436883425223641, 0.2084311211365275, 0.2615751139819622, 0.17477304674685, 0.14218274474842474, 0.22127495147287846, 0.20559825439704582, 0.1673471913090907, 0.17250577075174078, 0.1936831179773435, 0.1043825363740325, 0.14908250654116273, 0.1651189522817731, 0.2413382162922062, 0.18962659814860672, 0.2543508406961337, 0.1896731901797466, 0.27645125635899603, 0.203477404138539, 0.12296322762267664, 0.18213310337159783, 0.09008593711769208, 0.20711193879833445, 0.27345879818312824, 0.18400990578811616, 0.18661211302969605, 0.15672213019570336, 0.10191340363235213, 0.15723948134109378, 0.1827251591021195, 0.18529751716414467, 0.35749532631598413, 0.2008375700097531, 0.1417081561521627, 0.1801381807308644, 0.12522679287940264, 0.25388008158188313, 0.2961091749602929, 0.2284927383880131, 0.17513073224108666, 0.2553732827072963, 0.158748920657672, 0.26066663616802543, 0.15129118255572394, 0.10324739181669429, 0.14952932397136465, 0.20287512161303312, 0.10053959922515787, 0.09917907183989882, 0.3157245833426714, 0.2889390487689525, 0.16699210333172232, 0.1444430445553735, 0.10509539148188196, 0.11165242205606773, 0.14384376030648127, 0.14485514431726187, 0.31702343083452433, 0.11676411260850728, 0.10639848405844532, 0.12692359479842708, 0.25316340441349894, 0.1893384667346254, 0.17808790871640667, 0.15070194698637351, 0.10215118774794973, 0.1519713460584171, 0.19026963942451403, 0.144845956529025, 0.17552549543324858, 0.11877682452904992, 0.11085210484452546, 0.10898175169131719, 0.26206787035334855, 0.11716977795003913, 0.24694886757060885, 0.23517295805504546, 0.12371315300697461, 0.08539488844689913, 0.12396108228131197, 0.09309159067925066, 0.17048438312485814, 0.19451148837106302, 0.12841626157751307, 0.16578537120949477, 0.08409385161940008, 0.14027769619133323, 0.1367301115533337, 0.12230836393428035, 0.13033361494308338, 0.1326369890011847, 0.15827087365323678, 0.15862274070968851, 0.1820158737245947, 0.18219533987576142, 0.08779506824794225, 0.09280057231080718, 0.08944499611970969, 0.16651132522383705, 0.16548183280974627, 0.10479134100023657, 0.07952655607368797, 0.1175059263186995, 0.08287093325634487, 0.14700876781716943, 0.1460986424353905, 0.08847581062582321, 0.16750175098422915, 0.13081506098387763, 0.09377398062497377, 0.08007602737052366, 0.09778409395948984, 0.14083225862123072], [0.053229981785989366, 0.015264429403032409, 0.02969195928017143, 0.04658019759517629, 0.02342284489714075, 0.060479796084109694, 0.005924011074966984, 0.016952456353465095, 0.04595458936819341, 0.04868508054642007, 0.04353026750322897, 0.028896564363094512, 0.07158429943956435, 0.07543950428953394, 0.023935392491694074, 0.04484271114051808, 0.01998133542656433, 0.02313270411832491, 0.04967166569258552, 0.0460063578793779, 0.0165772969921818, 0.01728764735162258, 0.012920445024064975, 0.015348844062827993, 0.07540442296885885, 0.039804808620829135, 0.037882827964494936, 0.02165063520806143, 0.03822757411398925, 0.00586505254432268, 0.02535698007704923, 0.049505639835842885, 0.09011220172396861, 0.03909631363057997, 0.013028825487708673, 0.0599640331347473, 0.020645064068958163, 0.008413415580434958, 0.056997616920853034, 0.042086612156708725, 0.05705354516976513, 0.03833911890978925, 0.037777743564220145, 0.017364782470394857, 0.02316018955752952, 0.04492154577746987, 0.08358464925549924, 0.026191712531726807, 0.028925958977197297, 0.011973125983786304, 0.08326539958943613, 0.043463852707645856, 0.03007231924129883, 0.03967118122091051, 0.03997185121988878, 0.09908573192660697, 0.022327431215671822, 0.019381771016924176, 0.09206983144395053, 0.04956443277478684, 0.03825727857474703, 0.09975723456591368, 0.03363251482369378, 0.03320401730888989, 0.06144674029201269, 0.13457228749757633, 0.04258927991031669, 0.049016026459867135, 0.02587227547337534, 0.05610536987660453, 0.033949649368878454, 0.08576288979384117, 0.13665620848769322, 0.06006026371323969, 0.24410927697317675, 0.44938834849745035, 0.45252421929035336, 0.5528247356414795, 0.29463645711075515, 0.1961139781633392, 0.29357153456658125, 0.21758815477369353, 0.035721185558941215, 0.09958452938008122, 0.15057973010698333, 0.15125688049010932, 0.17999573290580884, 0.11967672311584465, 0.040535790685680695, 0.20639588503399864, 0.10221574717434123, 0.2294692414579913, 0.4240614012815058, 0.3604660544078797, 0.5507517093792558, 0.4816725442651659, 0.2722011547302827, 0.12363672663923353, 0.06050080257409718, 0.10542661198996939, 0.06056076068489347, 0.022279820586845744, 0.012386177550069988, 0.03397673775907606, 0.10418227524496615, 0.21890187490498647, 0.11923297075554729, 0.015613679461239371, 0.023832170882087667, 0.060626181002589874, 0.04630489791452419, 0.025508893995720427, 0.0681981244997587, 0.010877696531679248, 0.02880793523218017, 0.06028172057995107, 0.02504854535800405, 0.05789921502582729, 0.01350300683043315, 0.013885574680898571, 0.025428192857361864, 0.026694747648434713, 0.030424472024606075, 0.041948524449253455, 0.07043159566819668, 0.036294572564656846, 0.06347782036755234, 0.03513934920192696, 0.013430569506454049, 0.06551750193466432, 0.0973380780487787, 0.0447463655291358, 0.01812046506529441, 0.020104055111005437, 0.031010226921353023, 0.016800961748231202, 0.007035026555968216, 0.024076200170384254, 0.0488908558327239, 0.03468863920716103, 0.02262548885482829, 0.07530113827669993, 0.06381936414982192, 0.07104716263711452, 0.0007291834003808617, 0.03447877839789726, 0.009308540302299662, 0.040264413255499676, 0.05008617743442301, 0.007349197612711578, 0.015787150914547965, 0.03466594062047079, 0.04058160717249848, 0.04654082666093018, 0.031055054496391676, 0.05878101634152699, 0.030184389106580056, 0.039401262110914104, 0.0037889588929829188, 0.012827517930418253, 0.013656274240929633, 0.06960506580071524, 0.0196761643019272, 0.06529584468808025, 0.03146715054754168, 0.021198440917942207, 0.02371784303250024, 0.10544003001996316, 0.0313640551030403, 0.03751150179596152, 0.023889950789452996, 0.042300395216443576, 0.08253026520833373, 0.018643530747795012, 0.042866390431299806, 0.05224492917477619, 0.02065708500595065, 0.015731278326711617, 0.06841957394499332, 0.08291472739074379, 0.011853512187371962, 0.044794590285164304, 0.01719868610962294, 0.05758544983109459, 0.04833316525036935, 0.02532998816604959, 0.03344379038026091, 0.035534038179321215, 0.06249411104363389, 0.0587424172408646, 0.09255383789422922, 0.020401446672622114, 0.023162694305938203, 0.04084085419890471, 0.03069801281526452, 0.09781488566659391, 0.009001421967695933, 0.015645356179447845, 0.014534615293086972, 0.036638420715462416, 0.03600355048547499, 0.054625063567073084, 0.010257459598506102, 0.0243899097040412, 0.011811418498837156, 0.019134246213070583, 0.07227411086205393, 0.057605190959293395, 0.04623223052476533, 0.0503720564302057, 0.0689670340216253, 0.026630236461642198, 0.06221888186701108, 0.08284672439913265, 0.0923162986873649, 0.02968433742353227, 0.067250015999889, 0.0185416821113904, 0.050895489475806244, 0.034285111250937916, 0.07768918396322988, 0.07436839965521358, 0.04090417794941459, 0.04819891073566396, 0.025113115916610695, 0.06120870755694341, 0.07661162264412269, 0.010339223863411462, 0.06591498138732277, 0.01899175942526199, 0.026159252847719472, 0.026879436663875822, 0.055574430007254705, 0.0461060839734273, 0.019038785612792708, 0.07110475329682231, 0.03999224914878141, 0.030087509148870595, 0.07998075045179576, 0.043355796005926095, 0.05508178124728147, 0.09342348654172383, 0.06331526034045964, 0.036042357387486845, 0.043588362823356874, 0.07043659032206051, 0.028740253219439182, 0.117110450664768, 0.06137432894320227, 0.06453858688473701, 0.38814845960587263, 0.4604462895076722, 0.5525029404088855, 0.45333951304201037, 0.1915936902514659, 0.07036932947812602, 0.2341700196848251, 0.05296528368489817, 0.13929340057075024, 0.06653440752415918, 0.05517250880075153, 0.04642371946829371, 0.10444527753861621, 0.10495850234292448, 0.02059790615021484, 0.08343190042069182, 0.07564987346995622, 0.10309450939530507, 0.450283259851858, 0.2850030834088102, 0.4319711518473923, 0.4013972799293697, 0.18555707589257509, 0.07884787686634809, 0.04885101363470312, 0.18274078873218969, 0.11618733027717099, 0.034578485938254744, 0.05157837294973433, 0.0713565714249853, 0.09659538118285127, 0.2770702075213194, 0.06491437336080708, 0.072431542648701, 0.01795459320419468, 0.07249045433127321, 0.03641410658019595, 0.01138413439548458, 0.06309901335043833, 0.07957847672514617, 0.0331105067016324, 0.04056690893776249, 0.03216306613467168, 0.03971632235334255, 0.013299519214342581, 0.028452500300772954, 0.02609054481581552, 0.021869863776373677, 0.03241309939767234, 0.018687117080844473, 0.055848861375125125, 0.07682424795348197, 0.03717343497555703, 0.04786277349921875, 0.015067918902786914, 0.04015870174043812, 0.0412353799038101, 0.03772473937715404, 0.012699820290436037, 0.06156633739010431, 0.042050532647408545, 0.14426357840420678, 0.0587448292208137, 0.048381634915131144, 0.03880303913319949, 0.08202658442314714, 0.034036877696053125, 0.02935487951617688, 0.014415662935789442, 0.056363756011705846, 0.02508373243472306, 0.12048175296513364, 0.04648832342354581, 0.055343596104648896, 0.030840282524877694, 0.00896320507308701, 0.04369504655187484, 0.028744765477313194, 0.039253237046068534, 0.017287962764385156, 0.003286211822342011, 0.013872215095034335, 0.05512662923138123, 0.033491332360426895, 0.02477472440659767, 0.054232708644121885, 0.013858156962669455, 0.02161222349968739, 0.005176170661798096, 0.03562985315511469, 0.030505837385135237, 0.018463144333509263, 0.07066391757689416, 0.04724569997051731, 0.04938613550621085, 0.03339420749398414, 0.033336019405396655, 0.07244832260766998, 0.0793929843348451, 0.017556238017277792, 0.045362778546405025, 0.05346158010070212, 0.16549544379813597, 0.06006939584040083, 0.13072493457002565, 0.21086460852529854, 0.08002138303709216, 0.20266173931304365, 0.07860527621232904, 0.17596158140804619, 0.20528592896880582, 0.08944602770498022, 0.12654682126594707, 0.1733931715716608, 0.1304657172295265, 0.14400957094039768, 0.16417038365034387, 0.220566037169192, 0.10498795818421058, 0.09628593528759666, 0.09302220729296096, 0.17324713175185025, 0.10786925748107024, 0.21141320408787578, 0.20477147219935432, 0.09382128511788324, 0.14205886545823887, 0.21613572724163532, 0.11919742188183591, 0.09684370379545726, 0.08178985415725037, 0.10211422879365273, 0.1954692744766362, 0.10087053771712817, 0.15427182574057952, 0.10210331922280602, 0.14441067207371816, 0.12246350248460658, 0.12032279977574944, 0.1427706889808178, 0.17869572766358033, 0.12759563920553774, 0.19763952208450064, 0.12565606593852863, 0.17345886648399755, 0.09538835962302983, 0.20086213509785011, 0.1839064949308522, 0.15772457874845713, 0.10622879199218005, 0.15699660609243438, 0.22315056645311415, 0.18848070729291067, 0.11678093709633686, 0.1358434825669974, 0.17502000380773097, 0.1521014593890868, 0.19895803648978472, 0.16060849040513858, 0.11661252152407542, 0.24965233344119042, 0.21317420178093016, 0.2044077159371227, 0.22407770185964182, 0.24676515633473173, 0.2661115361843258, 0.1553284956025891, 0.30125291144941, 0.13989927509101108, 0.2081657588132657, 0.17292584117967635, 0.18198523786850274, 0.11735653199139051, 0.1797115645604208, 0.24310878769028932, 0.2054293267428875, 0.741354291094467, 0.9079860965721309, 0.7313039491418749, 0.6558599474374205, 0.31812878558412194, 0.32210545032285154, 0.1983800221933052, 0.2596732566598803, 0.44887092313729227, 0.34981718519702554, 0.2383209703839384, 0.3204056352842599, 0.23798353067832068, 0.14139458391582593, 0.10888280856306665, 0.21231915859971195, 0.20627935300581157, 0.28457329084631056, 0.56166828610003, 0.4321573121706024, 0.8682030625641346, 0.7129284320399165, 0.4648671147879213, 0.2976329525699839, 0.10468245309311897, 0.1800011654268019, 0.19760477473028004, 0.13161301816580817, 0.14611209015129134, 0.20114435901632532, 0.25179197487886995, 0.5515366047620773, 0.28810125309973955, 0.2918804174987599, 0.1180104012019001, 0.2797951363027096, 0.1513788747251965, 0.14037981571163982, 0.21830388199305162, 0.12941603839863092, 0.11021048849215731, 0.2513229672331363, 0.15507377567701042, 0.1444468295085244, 0.09195548132993281, 0.12046043848386034, 0.1177425601053983, 0.09826473105931655, 0.17780485359253362, 0.16019597504055128, 0.1910874416353181, 0.21961530146654695, 0.1816677174065262, 0.13593392068287358, 0.08218940420192666, 0.1464332322939299, 0.18642592302057892, 0.10717435492551886, 0.1392877008765936, 0.09651090993429534, 0.14939674671040848, 0.20175792218651623, 0.09185520975734107, 0.15183657204033807, 0.11041754027246498, 0.14697114092996344, 0.09283538645831868, 0.1301881391555071, 0.15841560729313642, 0.14657557621831074, 0.14670496224425733, 0.15966468636179343, 0.12396311576594599, 0.14639792090747505, 0.10890022676903754, 0.09061502903932706, 0.12287580262636766, 0.058859799028141424, 0.1356663616024889, 0.1180434416164644, 0.08774408270255663, 0.1255978221888654, 0.12720617494778708, 0.12378250670735724, 0.10567126839305274, 0.1133322436362505, 0.05809913476696238, 0.1226448685338255, 0.2152083395048976, 0.19424893136601895, 0.08085776862571947, 0.17582939006388187, 0.0886710177292116, 0.11302860133582726, 0.08310934077599086, 0.12209397231345065, 0.06912350843776949, 0.14156032033497468, 0.24051881104242057, 0.14866834360873327, 0.1360845024464652, 0.1910156462690793], [0.006131559166533407, 0.01272363580937963, 0.021335205747163855, 0.061128692905185744, 0.05358343703846913, 0.015589318463753443, 0.05156654311576858, 0.06844302581157535, 0.02735821282840334, 0.006911150512678432, 0.028975233872188255, 0.0690189324086532, 0.019434821588220075, 0.035490566879161634, 0.02785370401397813, 0.028512052085716277, 0.0491598472581245, 0.019010851174243726, 0.07441521433065645, 0.03675081527035218, 0.018677029438549653, 0.0546244178985944, 0.08118884812574834, 0.03384740739420522, 0.0438490496162558, 0.056808818262652494, 0.047957055940059945, 0.0015896577110652288, 0.029068280637147836, 0.0045756321833323454, 0.04366483371995855, 0.015317955876525957, 0.03062289262743434, 0.09015929841552861, 0.046089515526546165, 0.05004491031286307, 0.06293554790318012, 0.08850676560541615, 0.07359454742982052, 0.09108287893468514, 0.04672820039559156, 0.03542362144798972, 0.05836412230564747, 0.022453497986134607, 0.021626866073347628, 0.10016672938945703, 0.051777424378087744, 0.04181806230917573, 0.04441585377207957, 0.05189996038097888, 0.03095268450124422, 0.031267249360098504, 0.019028325041290373, 0.07336655224207789, 0.013653564474225277, 0.02765584744338412, 0.024586478648416232, 0.04722280471469276, 0.04012443307146896, 0.036245156661607325, 0.08990903879748657, 0.14361201727297157, 0.06521923278342001, 0.01765298624377465, 0.13045838481048122, 0.10060029206215404, 0.04097598444786854, 0.07215302204713225, 0.1581894897390157, 0.24825670989230275, 0.14597169065382332, 0.14202175807440653, 0.06813871557824314, 2.5394616834819317, 7.67003757879138, 13.467480540275574, 17.0987081900239, 30.89747965335846, 43.43131609261036, 60.0147320330143, 58.148484975099564, 73.74082669615746, 87.47386738657951, 82.64334619045258, 78.52462559938431, 77.0952183008194, 55.80458454787731, 54.416462033987045, 64.97889965772629, 44.968827590346336, 48.81252273917198, 46.58040091395378, 33.58607478439808, 34.282410219311714, 32.5837379693985, 16.031522154808044, 8.213945142924786, 1.9817755836993456, 0.14570476982044056, 0.30134054424706846, 0.47315058123786, 0.3952902654418722, 0.1759589690482244, 0.03750855918042362, 0.07088581973221153, 0.09972784551791847, 0.05641920928610489, 0.031053173152031377, 0.03599116775149014, 0.10667038470273837, 0.017706079488561954, 0.030273485790530685, 0.17872047086711973, 0.030016854834684636, 0.05860613295226358, 0.012565331071527908, 0.04773197368194815, 0.05284046186716296, 0.03814151838014368, 0.03801490427576937, 0.04289406140742358, 0.06317132822005078, 0.014750502341485117, 0.023386750544887036, 0.020780882659892086, 0.033796447823988274, 0.03665337499114685, 0.015329507405112963, 0.05986092655803077, 0.0697801607020665, 0.09572064882377163, 0.03440160246100277, 0.037756777892354876, 0.05762534397945274, 0.015925275729387067, 0.0824320939136669, 0.03857652824081015, 0.010992938150593545, 0.016739491511543747, 0.030335171250044368, 0.007543850888396264, 0.008000055095180869, 0.05984136354527436, 0.03009871557878796, 0.05196080535824876, 0.059899469997617416, 0.02751019725110382, 0.06568387660081498, 0.018701297667576, 0.04017138504423201, 0.012235018766659778, 0.07753790458082221, 0.15260588232195005, 0.03057212416024413, 0.06327406372292899, 0.04158419673331082, 0.0610688795131864, 0.031553926164633594, 0.06880883040139452, 0.062083499287837185, 0.011522891891218023, 0.06809348909882829, 0.08433191775111482, 0.021529594632738736, 0.03561378936865367, 0.02154943966161227, 0.11491474739159457, 0.057186682752217166, 0.03810056296060793, 0.038044957545935176, 0.05305414102622308, 0.025409071422473062, 0.02227674067398766, 0.0240630660118768, 0.06728273729095235, 0.03131615689198952, 0.0570342085120501, 0.04611660391674377, 0.024740466869843658, 0.060218563812668435, 0.0641113102028612, 0.03128092343104072, 0.029190128298068885, 0.06651806543231942, 0.023362819993053563, 0.014186922817316372, 0.048903208880801685, 0.06251836442970671, 0.05601068667601794, 0.042745023310999386, 0.04124189596041106, 0.01511399421360693, 0.04504550299316179, 0.0317378192266915, 0.08576334250392392, 0.058260833902750164, 0.03174134071741719, 0.03771171839616727, 0.05187609662243631, 0.01397455633195932, 0.05637333342747297, 0.05784236651379615, 0.039526829787064344, 0.0085055634190212, 0.04581718814733904, 0.041143327616737224, 0.07931712199933827, 0.036415891445358284, 0.06485816309577785, 0.038408680411521345, 0.039499874983448535, 0.04093492141691968, 0.07036023074761033, 0.051958445328637026, 0.020368007353681605, 0.0651167199248448, 0.044684366512228735, 0.08345267313416116, 0.05149099990376271, 0.03527501379721798, 0.052079916349612176, 0.06536143569974229, 0.03180112813424785, 0.056098768473020755, 0.06541093694977462, 0.04405411244079005, 0.037753449360025115, 0.02413378155324608, 0.067419811966829, 0.047979813898564316, 0.06257498287595809, 0.02576886832684977, 0.07225353110698052, 0.0599496466020355, 0.04165897553320974, 0.07139953435398638, 0.10766945648356341, 0.21031489974120632, 0.061432260990841314, 0.024053041452134494, 0.10330743156373501, 0.08604781512985937, 0.025929090588761028, 0.1027572774910368, 0.16152286087162793, 0.37005837250035256, 0.2756573661463335, 0.18344394396990538, 0.3686992626171559, 3.4732354525476694, 9.143779948353767, 15.358684659004211, 20.65482147037983, 35.408194810152054, 53.6757829785347, 73.75987887382507, 70.92285230755806, 89.556345641613, 105.15586897730827, 97.65095248818398, 97.65481308102608, 93.53013440966606, 72.44277834892273, 70.98048761487007, 85.56345909833908, 62.932652458548546, 63.53188030421734, 61.29639185965061, 46.192411333322525, 44.804106429219246, 42.75550335645676, 21.347609795629978, 12.828144896775484, 3.733885078690946, 0.175559708441142, 0.3639127960195765, 0.4921706090681255, 0.4597096930956468, 0.09122776100412011, 0.02991954443132272, 0.03639744165411685, 0.13352314301300794, 0.06507731930469163, 0.027921061337110586, 0.041604242142057046, 0.2742976031731814, 0.0834661653789226, 0.007609206268170965, 0.12916436127852648, 0.08031895456952043, 0.019375982265046332, 0.057227912766393274, 0.0395774999196874, 0.012004949276160914, 0.014090465883782599, 0.0372680105647305, 0.023616267135366797, 0.05140537832630798, 0.02637212677655043, 0.02101072208461119, 0.06151808294816874, 0.009928947929438436, 0.033275497262366116, 0.030679728151881136, 0.03203571730409749, 0.02691293349926127, 0.043094756692880765, 0.040429377841064706, 0.04311921416956466, 0.07934523455332965, 0.05883056954189669, 0.046393072479986586, 0.0724673512740992, 0.04562700538372155, 0.14739979058504105, 0.03305724647361785, 0.05879972217371687, 0.015387735384138068, 0.044623614303418435, 0.03064943553908961, 0.050764069965225644, 0.06537423774716444, 0.01022327720420435, 0.03237503464333713, 0.02170686402678257, 0.04283716465579346, 0.014641444668086478, 0.09339432755950838, 0.03708859265316278, 0.0043519910832401365, 0.0112823673953244, 0.03728139890881721, 0.05059237410023343, 0.02881628810428083, 0.03394571227545384, 0.011817525446531363, 0.019273621546744835, 0.07062412361847237, 0.04957826640747953, 0.052768974492209964, 0.04078479978488758, 0.010556698180153035, 0.018627351928444114, 0.054110469500301406, 0.07453120459103957, 0.007298569225895335, 0.018235447860206477, 0.06118987927038688, 0.038332413605530746, 0.021208769758231938, 0.018224649611511268, 0.04451377273653634, 0.13555279816500843, 0.1115781108092051, 0.12695332523435354, 0.12535769288660958, 0.21971108304569498, 0.11267667490756139, 0.1537404183181934, 0.170214805402793, 0.06174893169372808, 0.0695620954502374, 0.1255388808203861, 0.17087455984437838, 0.10651460790541023, 0.16624128737021238, 0.13036870368523523, 0.11154257677844726, 0.1540988014312461, 0.12126373912906274, 0.20665007061325014, 0.1840836604242213, 0.1660516537958756, 0.171449457120616, 0.2172481472371146, 0.12408431590301916, 0.13267604081192985, 0.12104751440347172, 0.16003751166863367, 0.1753734887461178, 0.15142864314839244, 0.1759706949815154, 0.13009265443542972, 0.10377836879342794, 0.20120736735407263, 0.15929364220937714, 0.16397806350141764, 0.11080281881731935, 0.13241688284324482, 0.12461115169571713, 0.144798414548859, 0.2851349482079968, 0.12267651371075772, 0.1619588429457508, 0.23610294330865145, 0.21045705070719123, 0.13803974987240508, 0.14910046651493758, 0.1675564917968586, 0.1640136569039896, 0.19947290886193514, 0.13264052162412554, 0.16717568098101765, 0.14525989681715146, 0.21411361231002957, 0.20734755584271625, 0.139319435111247, 0.13655057118739933, 0.19766441371757537, 0.13859609345672652, 0.13346920371986926, 0.2104072377551347, 0.2342662020237185, 0.5635916953906417, 0.25515173678286374, 0.21443166711833328, 0.28591061127372086, 0.17301544809015468, 0.13558457692852244, 0.46747686224989593, 0.47887438035104424, 0.6304970209021121, 0.3115883271675557, 0.17841023829532787, 0.4685303260339424, 5.158393252640963, 14.179064556956291, 21.29315111786127, 29.145332872867584, 47.71031968295574, 69.73552241921425, 91.43888622522354, 89.79735150933266, 112.94317871332169, 122.63617739081383, 121.43106445670128, 118.1149671971798, 116.98924720287323, 89.55155789852142, 87.20405146479607, 100.19046261906624, 78.37894901633263, 76.7627665400505, 72.50802844762802, 54.88922506570816, 55.076125636696815, 50.91084994375706, 27.16952819377184, 16.279895827174187, 4.499342367053032, 0.23394992836983874, 0.518711709883064, 0.7793535583186895, 0.7393479987513274, 0.30111199244856834, 0.14677585219033062, 0.2041726777679287, 0.23704076564172283, 0.18038602836895734, 0.10124446140252985, 0.2237050249823369, 0.47465642855968326, 0.20359948743134737, 0.08909696596674621, 0.3914598928531632, 0.1715597847942263, 0.14984950132202357, 0.1976870937505737, 0.17812071164371446, 0.1547872176161036, 0.11700113231199794, 0.09730041405418888, 0.15488228673348203, 0.16652122547384351, 0.10345109651098028, 0.09263089508749545, 0.11671962827676907, 0.12758729746565223, 0.12668385141296312, 0.10191411609412171, 0.10883183043915778, 0.15663449739804491, 0.2106934247422032, 0.2215858519775793, 0.11392414351576008, 0.2180531102931127, 0.1050045748706907, 0.11939089235966094, 0.13005268236156553, 0.24396681430516765, 0.25560486246831715, 0.11946714803343639, 0.13781597750494257, 0.09638548697694205, 0.1411680062301457, 0.1044243638170883, 0.15241118730045855, 0.14495260315015912, 0.10525832258281298, 0.12206493949634023, 0.196406606992241, 0.12602371105458587, 0.0963189460162539, 0.19044232234591618, 0.300269951694645, 0.12368238356430084, 0.13180627342080697, 0.21189079096075147, 0.14032307110028341, 0.13040036370512098, 0.13513574085664004, 0.13086956430925056, 0.10058140440378338, 0.1508559871581383, 0.14223291393136606, 0.1202909616404213, 0.1729159409296699, 0.12520329648396, 0.1412636393797584, 0.10024147108197212, 0.18488351750420406, 0.13422309217276052, 0.15045187290525064, 0.08899260516045615, 0.122072160593234, 0.13810378237394616, 0.15076281793881208, 0.11076217138906941], [0.014525752194458619, 0.01408000160154188, 0.012644862399611156, 0.021390282381617, 0.028031533729517832, 0.01576491802552482, 0.05467313989356626, 0.02312983757292386, 0.014569700324500445, 0.009383836750203045, 0.0507024865510175, 0.030909541601431556, 0.037034055931144394, 0.021287682320689783, 0.07785697613144293, 0.039736493927193806, 0.03556596166163217, 0.0333090312051354, 0.048397631908301264, 0.050289366336073726, 0.04855068131291773, 0.013777628373645712, 0.0451331877411576, 0.01739370582072297, 0.044689646892948076, 0.012130175564379897, 0.025458928903390188, 0.04083348838321399, 0.024506979789293837, 0.06078162754420191, 0.013825306723447284, 0.05806827997730579, 0.016130399781104643, 0.037324577060644515, 0.0172194105834933, 0.06093788302678149, 0.042484384757699445, 0.04733321402454749, 0.032463702737004496, 0.04329082468757406, 0.06538662419188768, 0.05302765377564356, 0.021572166078840382, 0.021203404030529782, 0.04858477557718288, 0.0646409735782072, 0.028039996068400797, 0.016846935941430274, 0.06914748722920194, 0.023504167584178504, 0.10137706834939308, 0.05484342938871123, 0.011686273846862605, 0.1177179059595801, 0.09316233961726539, 0.024584048114775214, 0.0441302345279837, 0.02077050186926499, 0.07429848192259669, 0.045597367716254666, 0.03206941451935563, 0.10669100156519562, 0.034395702386973426, 0.2282115089474246, 0.5083522188942879, 0.22744601330487058, 0.1797626243205741, 1.4649950014427304, 3.5909509984776378, 15.570608787238598, 41.27637952566147, 45.11546552181244, 63.94532471895218, 96.55560806393623, 102.06055507063866, 110.03014862537384, 112.7360974252224, 110.77252238988876, 103.13331350684166, 97.01952517032623, 112.03628897666931, 106.73500344157219, 105.59367388486862, 98.3489066362381, 103.1299164891243, 102.84348025918007, 114.52697172760963, 109.90454256534576, 115.16822531819344, 113.28921854496002, 129.03154581785202, 118.12189042568207, 126.71940788626671, 133.35312992334366, 129.87510055303574, 132.8713309764862, 127.89868980646133, 112.21666529774666, 67.82670244574547, 33.24431352317333, 13.825295940041542, 5.11918505653739, 1.1314928345382214, 0.19935268093831837, 0.17008887778501958, 0.47984065662603825, 0.30670256121084094, 0.16655100043863058, 0.01833086022088537, 0.04951300936227199, 0.03335007939313073, 0.12059475979185663, 0.22247153101488948, 0.12270277089555748, 0.04423933394718915, 0.03717301195138134, 0.06364366068737581, 0.009337310584669467, 0.04905074783891905, 0.08669245202327147, 0.04830778751056641, 0.0094374281616183, 0.051573099990491755, 0.051598288482637145, 0.011270536633674055, 0.03732515964657068, 0.021559202614298556, 0.00858195639011683, 0.018176539888372645, 0.013198396027291892, 0.040670735397725366, 0.07205919973785058, 0.0547359849588247, 0.0023740585220366484, 0.0717003490717616, 0.05753120996814687, 0.010004133055190323, 0.04528769917669706, 0.04653092270018533, 0.04441106320882682, 0.0724798119335901, 0.027153847622685134, 0.004337663922342472, 0.047067157793208025, 0.024845525294949766, 0.021632680800394155, 0.05194272664084565, 0.0256887664727401, 0.018022789154201746, 0.11311592985293828, 0.026461800480319653, 0.006279213157540653, 0.05791841438622214, 0.08921878950786777, 0.03275417191616725, 0.07819849764928222, 0.006782583168387646, 0.0189108207996469, 0.026238323116558604, 0.04021227367047686, 0.04971367867256049, 0.02596156882646028, 0.023344958353845868, 0.023429481552739162, 0.014594468575523933, 0.03136289735266473, 0.04819088069780264, 0.04267372147296555, 0.055046866909833625, 0.03418842425162438, 0.03417958156205714, 0.075797939352924, 0.0424970977474004, 0.020006221493531484, 0.039427014635293745, 0.08388853646465577, 0.045234824865474366, 0.033402957415091805, 0.008324276222992921, 0.010904561349889264, 0.0487019606953254, 0.02752805517957313, 0.010133888299606042, 0.020751482479681727, 0.027238873626629356, 0.023244091207743622, 0.03783148618822452, 0.014828325802227482, 0.0617470466386294, 0.048098817278514616, 0.037356559914769605, 0.019664460633066483, 0.04447568942850921, 0.062224514767876826, 0.04265282259439118, 0.07112937775673345, 0.061957909347256646, 0.06994422728894278, 0.011039322380383965, 0.028260948274692055, 0.012763540162268328, 0.03928680809622165, 0.06388649140717462, 0.021662709950760473, 0.01787489582056878, 0.08927976436098106, 0.06335624915664084, 0.0208686768746702, 0.009651742784626549, 0.03583029239962343, 0.10186204701312818, 0.009337713199784048, 0.028164927352918312, 0.004932897436447092, 0.02406682127912063, 0.040434494949295186, 0.08487727754982188, 0.03299332158348989, 0.06973995114094578, 0.0673865934368223, 0.039264187435037456, 0.076112966198707, 0.07991360093001276, 0.043114427317050286, 0.0914884552184958, 0.03795751770667266, 0.09704086274723522, 0.03745796326256823, 0.01042099740516278, 0.04178324816166423, 0.11022401042282581, 0.0577346178033622, 0.04657971890992485, 0.02361109436606057, 0.1717523721163161, 0.14571458101272583, 0.07600424898555502, 0.1753025988000445, 0.03377095876203384, 0.23228538018884137, 0.3583365061786026, 0.14141793188173324, 0.5022519431076944, 2.2979782288894057, 5.572897335514426, 21.287111341953278, 49.61750574409962, 54.54760059714317, 76.24683782458305, 116.40801519155502, 124.09966886043549, 131.55465602874756, 134.61271673440933, 133.45227420330048, 123.69438260793686, 120.05087211728096, 130.46903908252716, 130.55933743715286, 130.00553995370865, 118.64967450499535, 123.10732930898666, 129.92153406143188, 134.2467963695526, 130.48489183187485, 134.71406489610672, 134.23278272151947, 157.51800924539566, 141.7138060927391, 147.34165370464325, 160.15909552574158, 158.01500737667084, 159.21186715364456, 158.92983108758926, 137.82801300287247, 92.794668674469, 52.053285241127014, 23.82991399616003, 8.819163367152214, 1.9729640940204263, 0.16697852202923968, 0.11805276299128309, 0.6721812591422349, 0.41441184876021, 0.25537916051689535, 0.019049498514505103, 0.1816916887764819, 0.06857793341623619, 0.10005485804867931, 0.21964423038298264, 0.1499492014409043, 0.026068289662362076, 0.03759752042242326, 0.11167891672812402, 0.040286180446855724, 0.022285260529315565, 0.045848399167880416, 0.011456672837084625, 0.051475967702572234, 0.041415465748286806, 0.03534097959345672, 0.019865196736645885, 0.016179991944227368, 0.028530798736028373, 0.042303241352783516, 0.0186708881665254, 0.046438677454716526, 0.021515122753044125, 0.027275916072539985, 0.06094238786317874, 0.02469722749083303, 0.053107601634110324, 0.021341931460483465, 0.05317879586073104, 0.040171103028114885, 0.06312348195933737, 0.052726813082699664, 0.05493943361216225, 0.04070595772645902, 0.020759154431289062, 0.03232321047107689, 0.09986762161133811, 0.05854330644069705, 0.02681284189748112, 0.07638453287654556, 0.04525309654127341, 0.10644922469509766, 0.04814728694327641, 0.034116873794118874, 0.019036724297620822, 0.08521301773726009, 0.051296189849381335, 0.05795073120680172, 0.027828519232571125, 0.057498718742863275, 0.022548457636730745, 0.02084297258988954, 0.006760736659998656, 0.044704964820994064, 0.02893491484428523, 0.02713615853281226, 0.016738925623940304, 0.02630081566167064, 0.06819120026193559, 0.040123546204995364, 0.03745161047845613, 0.07998317727469839, 0.03082148206885904, 0.012321685844653985, 0.04948545712977648, 0.00990495615042164, 0.044422559076338075, 0.06396858036168851, 0.14544273231877014, 0.15992181084584445, 0.07752273508231156, 0.07705470707151107, 0.10823262040503323, 0.08038061219849624, 0.08307797761517577, 0.11840098610264249, 0.0739399429585319, 0.07828371846699156, 0.19039863953366876, 0.08020662309718318, 0.20859172189375386, 0.17076172371162102, 0.20568596140947193, 0.22785590146668255, 0.13105694175465032, 0.15214334620395675, 0.1890015762182884, 0.20164772809948772, 0.08609526805230416, 0.13240333122666925, 0.10346363138523884, 0.09906446197419427, 0.11296547425445169, 0.09317339761764742, 0.17751777602825314, 0.11821881853393279, 0.18048783618723974, 0.2047162564122118, 0.15608738613082096, 0.06732429756084457, 0.07534268370363861, 0.2050448942463845, 0.24539751175325364, 0.08128199508064426, 0.16672865574946627, 0.2121542682289146, 0.15735979832243174, 0.06240884569706395, 0.16900736081879586, 0.14695139980176464, 0.22612717235460877, 0.13521293905796483, 0.12002078277873807, 0.13141167350113392, 0.19159475894412026, 0.13717802736209705, 0.21968185727018863, 0.11776459446991794, 0.19065468048211187, 0.19013949640793726, 0.09900810327962972, 0.22487218579044566, 0.2263483323622495, 0.16944389208219945, 0.19962746853707358, 0.10630357079207897, 0.25581022957339883, 0.3500934422481805, 0.21737359988037497, 0.2663833403494209, 0.10769480824819766, 0.517756239278242, 0.7456125563476235, 0.29544121236540377, 0.9333560289815068, 3.6283398047089577, 7.786301365122199, 26.677101217210293, 59.14110191166401, 67.1328292787075, 94.70054000616074, 133.66243332624435, 140.09287387132645, 146.0575506091118, 152.10956186056137, 147.95801103115082, 136.34089440107346, 130.66883236169815, 142.8945243358612, 137.55261898040771, 134.9548503756523, 128.73084515333176, 134.24115747213364, 132.50737130641937, 147.20382750034332, 145.90599954128265, 150.47590792179108, 150.99415451288223, 171.21838688850403, 156.14435255527496, 165.47733575105667, 176.65679186582565, 172.41697937250137, 178.24480265378952, 175.82630842924118, 153.86336535215378, 104.45543736219406, 58.00511106848717, 27.31236442923546, 9.02986491099, 1.9067421974614263, 0.4280163359362632, 0.33921311201993376, 1.0868723038583994, 0.6581410125363618, 0.39161028165835887, 0.11978449037997052, 0.26851235423237085, 0.160204183193855, 0.26783361565321684, 0.4587213305057958, 0.2511719550238922, 0.14169286791002378, 0.1722919728490524, 0.1707812273525633, 0.09076487607671879, 0.08943632783484645, 0.2111661876551807, 0.16600170725723729, 0.24567961692810059, 0.10884778661420569, 0.11033516930183396, 0.10946258917101659, 0.17810646240832284, 0.08959250539191999, 0.2559963602107018, 0.06187383514770772, 0.15490027639316395, 0.169590154546313, 0.11299518984742463, 0.19426542188739404, 0.1496745177428238, 0.08390070768655278, 0.18378628185018897, 0.13691229396499693, 0.1607653358951211, 0.13754322339082137, 0.20851005596341565, 0.13855517143383622, 0.08100838749669492, 0.14602010836824775, 0.19777821464231238, 0.152771485154517, 0.09586205022060312, 0.09351300439448096, 0.1364166135317646, 0.141464464541059, 0.18632006307598203, 0.19446418387815356, 0.10433161762193777, 0.116133368719602, 0.13487907650414854, 0.177133284159936, 0.13907431857660413, 0.1268183731008321, 0.16590077517321333, 0.1316824386594817, 0.11134415617561899, 0.13989456987474114, 0.15685910097090527, 0.22345299163134769, 0.12619447923498228, 0.1242243369051721, 0.11501212458824739, 0.2323186580906622, 0.09087889964575879, 0.17568683833815157, 0.1968225510790944, 0.15364808030426502, 0.12594425672432408, 0.13935226772446185, 0.1637487398693338, 0.1465745668974705, 0.1512624169117771], [0.0324803899275139, 0.03746926617168356, 0.05668781108397525, 0.032013185700634494, 0.01888306076580193, 0.009716778113215696, 0.017639291763771325, 0.051612174065667205, 0.06914209923706949, 0.031062257039593533, 0.04954896641720552, 0.025933732722478453, 0.06346588663291186, 0.0067369447970122565, 0.032203661612584256, 0.06856357285869308, 0.052482898827292956, 0.016124076682899613, 0.004031770595247508, 0.022172982862684876, 0.04137996140343603, 0.03792688927205745, 0.04337217520514969, 0.012279440943530062, 0.03942763061786536, 0.04142759986279998, 0.03824465093202889, 0.07998129964107648, 0.02370753645664081, 0.022569276734429877, 0.0614327730727382, 0.040685685962671414, 0.07844518011552282, 0.026431520855112467, 0.04212450250633992, 0.010144583575311117, 0.027599121385719627, 0.007351721378654474, 0.02197232097387314, 0.0064279734124284005, 0.026940975549223367, 0.024060774630925152, 0.042833695115405135, 0.02672833168617217, 0.05393266575993039, 0.054813335300423205, 0.011573202082217904, 0.015983120574674103, 0.030376983850146644, 0.02583976383903064, 0.02395574403635692, 0.06281158697674982, 0.06189089341205545, 0.03947722463635728, 0.02018156686972361, 0.026316582589061, 0.04970552246959414, 0.03605983867601026, 0.11579197336686775, 0.023338870887528174, 0.239543272764422, 0.47145002405159175, 0.043736113293562084, 3.3379876473918557, 13.023958839476109, 30.160541497170925, 59.52647723257542, 76.88306048512459, 91.44680500030518, 100.60670748353004, 112.74681285023689, 108.68532478809357, 104.14260014891624, 75.92746496200562, 95.82799270749092, 82.19678655266762, 67.51074180006981, 79.24865394830704, 83.33520546555519, 64.933370500803, 80.83182379603386, 107.19865456223488, 80.82236230373383, 70.6908367574215, 68.54014456272125, 84.13591369986534, 71.0407067835331, 75.90028882026672, 88.5850265622139, 75.48595905303955, 59.11765716969967, 69.92760971188545, 80.44993668794632, 85.51140189170837, 78.15111324191093, 91.0665214061737, 86.29675135016441, 98.568344861269, 111.83428421616554, 123.24505671858788, 120.36977380514145, 110.56245446205139, 84.42937195301056, 73.52964162826538, 59.85709369182587, 33.47008600831032, 11.007514391094446, 2.286674785427749, 0.14446559100179002, 0.5219027667772025, 0.23583243048051372, 0.017079562130675185, 0.16955088009126484, 0.08699015714228153, 0.10278772781020962, 0.08747391126235016, 0.07626141799846664, 0.039564920516568236, 0.05390470163547434, 0.033506238396512344, 0.028924014550284483, 0.08746377352508716, 0.008664589895488461, 0.0346297089708969, 0.06269775636610575, 0.05191715594264679, 0.06581374502275139, 0.04165470818406902, 0.04278351480024867, 0.04215500106511172, 0.025769996391318273, 0.1525268584373407, 0.06566739350091666, 0.023875773913459852, 0.06142789716250263, 0.045351416265475564, 0.02295492264238419, 0.023061528445396107, 0.10268679572618566, 0.019265671289758757, 0.06124717678176239, 0.07587035812321119, 0.0442976185149746, 0.04461264907149598, 0.0380148745898623, 0.11901557343662716, 0.037194704927969724, 0.041554184281267226, 0.028422868199413642, 0.020793621624761727, 0.10608053315081634, 0.03874144829751458, 0.0381190275948029, 0.008665553759783506, 0.04364555272331927, 0.00418078874645289, 0.04133465699851513, 0.04488430109631736, 0.05944026241195388, 0.002433440076856641, 0.053882503998465836, 0.01801704307581531, 0.01369043344311649, 0.020920462084177416, 0.07300986864720471, 0.018801116530084983, 0.060787460824940354, 0.05421066685812548, 0.04524118878180161, 0.03241581936890725, 0.044573166815098375, 0.08801568648777902, 0.11874307907419279, 0.00813517699498334, 0.05361341609386727, 0.04104290019313339, 0.05107174212753307, 0.028583945786522236, 0.04110255773412064, 0.026011658228526358, 0.02957007451186655, 0.041578341188142076, 0.03509125061100349, 0.0889760404243134, 0.018995288337464444, 0.07371369923930615, 0.030158933441271074, 0.0015296583183044277, 0.028492405581346247, 0.020343371761555318, 0.03579079158953391, 0.06900887630763464, 0.04406281412229873, 0.042980276703019626, 0.021338497172109783, 0.01911468691105256, 0.03962686016166117, 0.02888438757508993, 0.031237864022841677, 0.028185210248921067, 0.0737616494006943, 0.024462155924993567, 0.020441615415620618, 0.13348560518352315, 0.014875225824653171, 0.03038741102500353, 0.059120493242517114, 0.029060501074127387, 0.04921952335280366, 0.00577149648052, 0.03552961868990678, 0.04625699599273503, 0.07146843534428626, 0.01945142343174666, 0.056565876220702194, 0.007992182763700839, 0.08231803323724307, 0.036096155672566965, 0.0325769730261527, 0.055651695001870394, 0.036547693161992356, 0.05296204792102799, 0.024612717279524077, 0.02461793086695252, 0.042324147652834654, 0.05697362699720543, 0.01923856991197681, 0.06250982973142527, 0.056748158822301775, 0.030724744974577334, 0.028466111289162654, 0.03132544858090114, 0.12319900051807053, 0.1092402936774306, 0.11251793694100343, 0.025847973847703543, 0.27876399632077664, 0.2781342394882813, 0.07963149575516582, 4.95875813998282, 15.869184415787458, 36.22032903134823, 71.92033678293228, 91.88999801874161, 106.49728819727898, 123.46823394298553, 133.51246297359467, 133.98264974355698, 127.59195506572723, 99.32062849402428, 119.97606933116913, 109.35024350881577, 106.32565140724182, 105.69449007511139, 106.61431431770325, 99.29865807294846, 110.49099549651146, 132.37349689006805, 119.96435835957527, 92.26201325654984, 108.10967087745667, 113.95252615213394, 108.69258239865303, 114.18210983276367, 126.68755799531937, 100.39561361074448, 92.67353877425194, 101.7999042570591, 113.74967783689499, 110.46046793460846, 108.72523784637451, 115.66587701439857, 109.74236726760864, 118.11958014965057, 131.04545295238495, 139.31785225868225, 147.10194736719131, 134.14973437786102, 111.45713925361633, 97.42607295513153, 80.7219260931015, 45.345584973692894, 18.569700457155704, 3.4959192853420973, 0.012721439979941351, 0.6662745354697108, 0.29469202912878245, 0.03185874105838593, 0.3657831862801686, 0.12112729527871124, 0.03704362592543475, 0.11204912967514247, 0.036625900684157386, 0.049664682082948275, 0.06573428327101283, 0.019503722578519955, 0.02156345140974736, 0.11821392778074369, 0.052195223834132776, 0.053070961803314276, 0.03791800205362961, 0.06624169705901295, 0.09476540828472935, 0.04399991339596454, 0.03351193809066899, 0.04537199602054898, 0.0673093061777763, 0.08184724443708546, 0.08760444761719555, 0.06891322089359164, 0.11413630127208307, 0.03798805337282829, 0.011595304167713039, 0.02831678189977538, 0.03354803986439947, 0.022284219667199068, 0.038983455233392306, 0.012763193208229495, 0.012547590959002264, 0.0264777473785216, 0.05034978828916792, 0.129393313836772, 0.04440016477019526, 0.04160525517363567, 0.026179752821917646, 0.02331497558770934, 0.021021588981966488, 0.035384992661420256, 0.045783398163621314, 0.06857235988718458, 0.03552633097569924, 0.03189423427102156, 0.04868978947342839, 0.03640137874754146, 0.038586428490816616, 0.021760671588708647, 0.056859288015402853, 0.06983826344367117, 0.005428423874036525, 0.03694602979521733, 0.021605354922940023, 0.02462086977175204, 0.045923597281216644, 0.05235437740338966, 0.05551577065489255, 0.0880836375290528, 0.003999836908405996, 0.07518521480960771, 0.05546404296183027, 0.056098171044141054, 0.06414156756363809, 0.05598313444352243, 0.12615615472896025, 0.12666976545006037, 0.1420369275729172, 0.15791099140187725, 0.15664162201574072, 0.08826089950161986, 0.13397505157627165, 0.17868000897578895, 0.11976266381680034, 0.2142224260023795, 0.1229138376947958, 0.1558196934638545, 0.1451134859235026, 0.15319085796363652, 0.09936732501955703, 0.1974727466586046, 0.16888940386706963, 0.16178648656932637, 0.09375662921229377, 0.16383564536226913, 0.0909715642046649, 0.14713802025653422, 0.13811129290843382, 0.18194161442806944, 0.075826667889487, 0.14928199583664536, 0.1492640803917311, 0.18249160522827879, 0.1113524533866439, 0.15496021223952994, 0.19658988778246567, 0.15550635871477425, 0.17172923195175827, 0.07722351598204114, 0.24065698409685865, 0.1538992379209958, 0.17406146071152762, 0.13215169863542542, 0.11319050085148774, 0.10227799109998159, 0.17205999232828617, 0.08662322448799387, 0.13339875906240195, 0.13905806554248556, 0.11391728607122786, 0.16409783129347488, 0.08573756029363722, 0.13303406769409776, 0.16176009579794481, 0.22341420699376613, 0.20056677516549826, 0.20514815667411312, 0.27188482170458883, 0.22007385967299342, 0.15123881661565974, 0.1309577314532362, 0.31174162519164383, 0.22821342368843034, 0.18126830836990848, 0.11545847446541302, 0.4757505323505029, 0.5637923127505928, 0.25651764473877847, 6.900919424369931, 20.3358855843544, 45.245540142059326, 86.40951409935951, 105.73649302124977, 126.24033719301224, 139.90808218717575, 145.5868622660637, 142.9975900053978, 133.85740846395493, 103.22350546717644, 125.48967987298965, 108.11378985643387, 93.13787385821342, 104.67333287000656, 109.6543487906456, 94.38773319125175, 111.82022497057915, 136.66504740715027, 112.83203467726707, 102.2175170481205, 99.93064776062965, 114.93500903248787, 105.82948923110962, 105.56335151195526, 122.84240752458572, 103.75824317336082, 84.3008628487587, 100.1626481115818, 110.99794149398804, 109.66201677918434, 107.93003931641579, 116.74402356147766, 111.65084525942802, 126.42513647675514, 144.6108314394951, 160.05438834428787, 163.74651342630386, 151.47970765829086, 123.50667268037796, 108.32267984747887, 90.61216458678246, 51.577501371502876, 22.49913040548563, 4.641531687229872, 0.2728710469091311, 0.8905748371034861, 0.5371112725697458, 0.11972143009188585, 0.5524167325347662, 0.24970520404167473, 0.20554351358441636, 0.3125276486389339, 0.16329132457030937, 0.15589202317642048, 0.1937409906531684, 0.1421375182690099, 0.18590837891679257, 0.14489582885289565, 0.1734808340552263, 0.15176210494246334, 0.2842324966331944, 0.11896920404979028, 0.18169134738855064, 0.18309176521142945, 0.15205412521027029, 0.09342631412437186, 0.11611721958615817, 0.2692106261383742, 0.19885939022060484, 0.17053891613613814, 0.15706635313108563, 0.16367655858630314, 0.11809024887043051, 0.08535666784155183, 0.17811728292144835, 0.14831738197244704, 0.14023010968230665, 0.11500483669806272, 0.10174585637287237, 0.20939469599397853, 0.17848056420916691, 0.3230706579051912, 0.13674303976586089, 0.19682937883771956, 0.07780004598316737, 0.1468769772327505, 0.2345035260077566, 0.1247979947947897, 0.12110972122172825, 0.19937916076742113, 0.15287191257812083, 0.10608390250126831, 0.21105283201904967, 0.21899528161156923, 0.11389124410925433, 0.10801281852764077, 0.10889726559980772, 0.12544412340503186, 0.09497073086095043, 0.15775991982081905, 0.11210441967705265, 0.13220783468568698, 0.12227511571836658, 0.12450195208657533, 0.16458368569146842, 0.16551144450204447, 0.07609537729877047, 0.14526957442285493, 0.18048887519398704, 0.12524157646112144, 0.15928448410704732, 0.19137066003168002], [0.061058645296725444, 0.024502159540134016, 0.0257011158100795, 0.031434740958502516, 0.06993194474489428, 0.01819342745875474, 0.04424893362738658, 0.06375999233569019, 0.02268378455482889, 0.02616528650833061, 0.08316356208524667, 0.09204367073834874, 0.013505053302651504, 0.03535352931066882, 0.017836229926615488, 0.057545459203538485, 0.041917825510608964, 0.04781251154781785, 0.10573051404207945, 0.031156387340161018, 0.091227033699397, 0.027879918525286485, 0.07682619980187155, 0.035835598755511455, 0.05797383426397573, 0.04353980410087388, 0.027839701542689, 0.019231996338930912, 0.04717306226666551, 0.046236575799412094, 0.08463565653073601, 0.031475514551857486, 0.0622917570581194, 0.054224778796196915, 0.015297997670131736, 0.038294612313620746, 0.023771567102812696, 0.02456563543091761, 0.017974176626012195, 0.017704036727081984, 0.045036467345198616, 0.03507352441374678, 0.11032857903046533, 0.0517884118744405, 0.025193757683155127, 0.023157627292675897, 0.11568666261155158, 0.05066560181148816, 0.05586529994616285, 0.028587556334969122, 0.025289463192166295, 0.04588550655171275, 0.04335041172453202, 0.036820057648583315, 0.029156954296922777, 0.04914375378575642, 0.1768572794389911, 0.0539941675378941, 0.21818625158630311, 0.10436265423777513, 6.366395456716418, 23.98940473794937, 54.6087621152401, 79.70723614096642, 96.35141462087631, 99.46596309542656, 109.24319565296173, 87.4889449775219, 73.03415581583977, 56.294591054320335, 52.39004597067833, 48.29470172524452, 52.51370653510094, 84.00190249085426, 59.68012198805809, 48.19359675049782, 46.709221601486206, 60.54002344608307, 33.07762786746025, 26.9086816906929, 27.337716668844223, 43.42796467244625, 30.11944480240345, 39.06451441347599, 33.45187358558178, 32.8148377686739, 40.94718039035797, 41.860791966319084, 35.923298969864845, 48.40040065348148, 45.47469064593315, 59.91473279893398, 41.417344361543655, 50.60200251638889, 53.47201511263847, 48.26727859675884, 82.64605164527893, 79.76068407297134, 71.16142630577087, 68.52893516421318, 73.99650737643242, 96.10122844576836, 104.80819523334503, 106.25939816236496, 104.21766892075539, 116.59242689609528, 103.85137617588043, 80.06598249077797, 42.3533633351326, 29.047081544995308, 2.36746771261096, 0.17420830205082893, 0.9127338824328035, 0.16885709075722843, 0.05573664864641614, 0.20868860185146332, 0.0849943290813826, 0.04217362897179555, 0.07594200505991466, 0.04264037677785382, 0.020717401203000918, 0.0320656369876815, 0.09979986352846026, 0.07186754752183333, 0.006048261902833474, 0.05857270662090741, 0.06683109590085223, 0.020057704277860466, 0.024722367743379436, 0.020869370782747865, 0.019679791548696812, 0.06415102252503857, 0.061887494375696406, 0.05445192051411141, 0.03001588262122823, 0.021391870577645022, 0.10588661738438532, 0.053424873476615176, 0.01994656580791343, 0.07390616781776771, 0.09562783583533019, 0.09155317791737616, 0.006782120717616635, 0.013790303328278242, 0.04170496642473154, 0.05569205299252644, 0.03889801177137997, 0.07728272452368401, 0.08297537569887936, 0.041239643542212434, 0.012065425962646259, 0.04459660754946526, 0.03251462519983761, 0.044613250211114064, 0.05255749209027272, 0.0664404961571563, 0.06160417207865976, 0.05257878430711571, 0.017358092009089887, 0.03411327437788714, 0.039737180413794704, 0.0019247308932790475, 0.017164692035294138, 0.09029285531141795, 0.061736140778521076, 0.04152970082941465, 0.017193183084600605, 0.03012241420947248, 0.00428086272222572, 0.07835445998352952, 0.06701724138110876, 0.04230171623930801, 0.00484094209241448, 0.015739746231702156, 0.07461865927325562, 0.049482113754493184, 0.0645850453292951, 0.03164076857501641, 0.04764903125760611, 0.04588975163642317, 0.10391807809355669, 0.03423624082643073, 0.056458695253240876, 0.031249111270881258, 0.024843163409968838, 0.055801260023145005, 0.07653240580111742, 0.06848330958746374, 0.016937036380113568, 0.044665304449154064, 0.02487081212166231, 0.03725278911588248, 0.014246682403609157, 0.03132670281047467, 0.04169478786934633, 0.028505873706308194, 0.08294842831674032, 0.04017084327642806, 0.10021428621257655, 0.08204711964935996, 0.016969119424175005, 0.03463658496912103, 0.03662098024506122, 0.03591458182199858, 0.03230754744436126, 0.006154766588224447, 0.01506913695266121, 0.0560363019030774, 0.05728419353545178, 0.024666814279044047, 0.04972583876224235, 0.048805033875396475, 0.014026374938111985, 0.021910943505645264, 0.06765884289052337, 0.030690914172737394, 0.09829255417571403, 0.06570759564056061, 0.0985009566647932, 0.029392758733592927, 0.027318769534758758, 0.04443436293513514, 0.034574114688439295, 0.0716839030792471, 0.0701542328170035, 0.028470664365158882, 0.011888180688401917, 0.01832862079027109, 0.07555610311101191, 0.06424618812161498, 0.06901090979226865, 0.07762514404021204, 0.26557416189461946, 0.05990626435959712, 0.22878067684359848, 0.08244559357990511, 10.082720015197992, 32.84286126494408, 66.23865365982056, 98.28344374895096, 113.63902017474174, 117.28528931736946, 129.92185324430466, 115.11913195252419, 100.53812876343727, 84.90225657820702, 91.55490159988403, 82.91946217417717, 82.4957925081253, 97.10994511842728, 100.90504467487335, 87.16074898838997, 64.2911745607853, 88.62800225615501, 62.2050940990448, 47.11317792534828, 50.76505556702614, 73.3753927052021, 53.48157539963722, 65.10999262332916, 53.25451098382473, 70.08125826716423, 66.43571108579636, 75.40439262986183, 70.54410383105278, 82.46429219841957, 79.60119143128395, 95.18621474504471, 83.96980181336403, 92.92185544967651, 89.06160458922386, 97.18373715877533, 127.38004043698311, 124.1092823445797, 120.2074085175991, 116.39112129807472, 111.16263225674629, 120.72630867362022, 123.83000493049622, 129.4519704580307, 128.0127140879631, 131.7615169286728, 127.68482208251953, 103.261549025774, 59.9251214414835, 40.11602059006691, 3.722228016704321, 0.051298750258865766, 0.9030631638597697, 0.47915494185872376, 0.03835746851109434, 0.12495239119743928, 0.10071493903524242, 0.033767222048481926, 0.04031800002849195, 0.059008629323216155, 0.04257865606632549, 0.07850269656046294, 0.05588428037299309, 0.04241538357746322, 0.02820603120198939, 0.008824656306387624, 0.018587621052574832, 0.10412279210868292, 0.03287392115453258, 0.056891489803092554, 0.010547836009209277, 0.08578562177717686, 0.053502494702115655, 0.04001622422947548, 0.03440916865656618, 0.01803206600015983, 0.041920270887203515, 0.01070002545020543, 0.020375120839162264, 0.04937727426295169, 0.059566787458606996, 0.03687442367663607, 0.011402244654163951, 0.05605511905741878, 0.048754048330010846, 0.03272090514656156, 0.03100447527685901, 0.041143476046272554, 0.030490523167827632, 0.010446972573845414, 0.05605281468888279, 0.05935730514465831, 0.03951444705307949, 0.08855244479491375, 0.06144916340417694, 0.008388388505409239, 0.049845599132822827, 0.026935131136269774, 0.049083573030657135, 0.03491995550575666, 0.03161332024319563, 0.0686867100012023, 0.018268922431161627, 0.03392662052647211, 0.05917345290072262, 0.009988662986870622, 0.02271205110446317, 0.010893209273490356, 0.02329333085071994, 0.024830823349475395, 0.06230070735909976, 0.08102871492155828, 0.021267041338433046, 0.03158781262754928, 0.06116140677477233, 0.02029451246926328, 0.17554063524585217, 0.09501021311734803, 0.17729464190779254, 0.21254437073366717, 0.1976512628607452, 0.1280605947249569, 0.16049770259996876, 0.21912742842687294, 0.12643802241655067, 0.1984900381648913, 0.2085397715563886, 0.1534390024608001, 0.07647649981663562, 0.14451581955654547, 0.22776685858843848, 0.13806291972287, 0.09939425013726577, 0.17521941888844594, 0.14755893673282117, 0.09518824692349881, 0.3252718679141253, 0.08614980848506093, 0.22220113693038002, 0.20844075421337038, 0.15475874883122742, 0.17492017010226846, 0.17318954109214246, 0.16125629626912996, 0.08846418117173016, 0.12626694253413007, 0.1372161292238161, 0.14405332796741277, 0.12374100580927916, 0.10978758306009695, 0.05383751129556913, 0.17780820810003206, 0.11440128510002978, 0.09772688179509714, 0.20339600538136438, 0.10672447242541239, 0.2434393996372819, 0.1542349113151431, 0.196929182857275, 0.12524873076472431, 0.08717202785192057, 0.10012319500674494, 0.303482441813685, 0.2194639775552787, 0.1287117402534932, 0.12965499510755762, 0.11970804916927591, 0.17673866939730942, 0.16646097792545334, 0.21852032194146886, 0.15764766256324947, 0.16327332006767392, 0.39554244722239673, 0.3874498908407986, 0.39436842896975577, 0.22420698398491368, 12.851191610097885, 40.57497896254063, 80.34223526716232, 112.23489671945572, 126.82335510849953, 131.48174554109573, 137.0339012145996, 113.8045696914196, 97.47624546289444, 79.43209290504456, 71.61753863096237, 66.80068150162697, 72.25301653146744, 108.17790001630783, 80.92231214046478, 63.2296559214592, 64.47658941149712, 82.94725388288498, 46.48800127208233, 40.30127964913845, 44.34663377702236, 59.67188782989979, 43.03241349756718, 58.293656185269356, 50.05407951772213, 46.0975456237793, 55.221673026680946, 61.95134371519089, 54.12362314760685, 75.6501330435276, 67.62453809380531, 80.76431661844254, 59.23659838736057, 75.05094319581985, 77.6492589712143, 75.95473229885101, 109.31235194206238, 113.80725234746933, 100.34937009215355, 96.34789600968361, 96.98173999786377, 120.51675751805305, 128.69017213582993, 134.73800361156464, 133.49399596452713, 150.14100909233093, 140.6881347298622, 120.34612387418747, 70.09013459086418, 47.85239405930042, 5.066701797768474, 0.16786127700470388, 1.4860145235434175, 0.5949968320783228, 0.12249007137143053, 0.3028434229781851, 0.21564080379903316, 0.19625295273726806, 0.30031243222765625, 0.19875253579812124, 0.08417158416705206, 0.14546207268722355, 0.2231241756817326, 0.12814598623663187, 0.14625551761128008, 0.11258950224146247, 0.1315527260885574, 0.23668995243497193, 0.09657715403591283, 0.17036476376233622, 0.14285728277172893, 0.1707125490065664, 0.14641881978604943, 0.23861325782490894, 0.1391129250987433, 0.06535226275445893, 0.26152547914534807, 0.1598898391239345, 0.10251707397401333, 0.1649748717318289, 0.12700782855972648, 0.14526806044159457, 0.09976554661989212, 0.14696425379952416, 0.15268097282387316, 0.10829719467437826, 0.0832156089018099, 0.19353774609044194, 0.224760344135575, 0.15121926844585687, 0.14346949523314834, 0.13307583576533943, 0.11449583471403457, 0.1751604923629202, 0.1103783845610451, 0.23998375225346535, 0.12756522599374875, 0.08489516330882907, 0.18707626702962443, 0.12917835818370804, 0.17637957382248715, 0.15201557805994526, 0.14926179457688704, 0.17007434653351083, 0.15293033444322646, 0.10904142778599635, 0.09594905219273642, 0.07107439945684746, 0.07791449257638305, 0.20644308562623337, 0.253944915602915, 0.22335485002258793, 0.10815180794452317, 0.13725955970585346, 0.15760969428811222, 0.08202085504308343], [0.035006430553039536, 0.013441619157674722, 0.0216845699105761, 0.058435624523554, 0.06704850064124912, 0.07861027828766964, 0.07930213061627, 0.024274797033285722, 0.04612866381648928, 0.06853839178802446, 0.00956375932219089, 0.053862859349465, 0.016447510206489824, 0.025142044833046384, 0.017937245502253063, 0.03260982419305947, 0.012196254538139328, 0.03497426958347205, 0.02459434912452707, 0.023467078754038084, 0.034640191806829534, 0.06268827914027497, 0.014977640348661225, 0.052725217465194874, 0.02284686594066443, 0.013775082807114813, 0.058410810815985315, 0.027081525331595913, 0.025369320137542672, 0.05302300050971098, 0.04396421980345622, 0.029692215321119875, 0.048060945482575335, 0.0890876742778346, 0.05983032038784586, 0.02696709914744133, 0.03625414406997152, 0.02880662719690008, 0.02118949432770023, 0.010464813803992001, 0.03634129818237852, 0.04590417898725718, 0.05595405338681303, 0.019555992039386183, 0.01694557478913339, 0.04545898314972874, 0.03213820047676563, 0.09260967708542012, 0.05729257238272112, 0.04083056061062962, 0.05598158706561662, 0.056823438571882434, 0.055023136737872846, 0.0670742902730126, 0.10787857143441215, 0.1232612221792806, 0.40433749090880156, 0.7435346022248268, 14.989408124238253, 41.38125389814377, 70.16594812273979, 87.46626019477844, 88.25126767158508, 86.7936658859253, 81.71228215098381, 72.7968281507492, 58.89445714652538, 55.74569150805473, 43.883894607424736, 45.73045872151852, 42.3626272380352, 56.654826924204826, 53.8367385417223, 46.804550886154175, 42.351353242993355, 54.216170981526375, 89.37512576580048, 48.23189489543438, 60.34655682742596, 74.03072834014893, 68.93706366419792, 60.30377112329006, 100.23606777191162, 49.4964100420475, 87.073133289814, 71.54166430234909, 72.27196991443634, 80.30571922659874, 72.83910468220711, 56.20025351643562, 53.73491920530796, 43.471992909908295, 53.006418496370316, 29.48365341871977, 51.40337571501732, 37.86366105079651, 30.49168422818184, 40.04873380064964, 31.248825900256634, 35.134389102458954, 34.83979471027851, 62.021940127015114, 60.67138999700546, 55.44746831059456, 72.54189223051071, 69.99390095472336, 75.97345769405365, 93.18694442510605, 92.4782444536686, 91.19542568922043, 76.32200539112091, 45.20078234374523, 17.598117291927338, 2.7708569169044495, 0.41214975295588374, 0.6259247974958271, 0.01955830754013732, 0.06533995794598013, 0.04081650433363393, 0.03814139592577703, 0.031553629305562936, 0.17223071597982198, 0.05387397301092278, 0.022388528523151763, 0.08459027420030907, 0.027215726040594745, 0.02222884988441365, 0.08563814219087362, 0.08731370384339243, 0.07405156196909957, 0.06598066887818277, 0.01429182631909498, 0.05709470096917357, 0.02077431279758457, 0.030071113251324277, 0.0740639929426834, 0.025461665572947823, 0.024323172074218746, 0.025538110494380817, 0.01969450091564795, 0.020224138315825257, 0.019160390220349655, 0.06335491329082288, 0.021244181334623136, 0.03174806457536761, 0.020216594384692144, 0.038078673314885236, 0.03131789722829126, 0.06507892976514995, 0.06430797933717258, 0.026129661564482376, 0.04646242618036922, 0.040870814700610936, 0.056681313581066206, 0.0658518765703775, 0.031817570416023955, 0.025079040206037462, 0.044760188029613346, 0.029283572112035472, 0.05119767345604487, 0.04060708139149938, 0.071591238520341, 0.048408237198600546, 0.03777301237278152, 0.018380545152467676, 0.026756600091175642, 0.06450244429288432, 0.01472286105126841, 0.03268366046540905, 0.034028398658847436, 0.03682941242004745, 0.019114718452328816, 0.025261131704610307, 0.030215867300285026, 0.013497798809112282, 0.019404857375775464, 0.05233891475654673, 0.04943643827573396, 0.07532756615546532, 0.07784847111906856, 0.03663945601147134, 0.08378388622077182, 0.0873780257825274, 0.010047441082861042, 0.043687584256986156, 0.05066439953225199, 0.10950598996714689, 0.0912928770412691, 0.02195775818108814, 0.011708865749824326, 0.054428639341495, 0.07324446152779274, 0.015155317923927214, 0.033023797877831385, 0.07868921311455779, 0.011644893547781976, 0.04483406512008514, 0.011823945951618953, 0.05410747122368775, 0.02465556146489689, 0.02265077011543326, 0.009778853200259618, 0.02359516602155054, 0.08708186433068477, 0.028590576876013074, 0.01990239503356861, 0.021323422297427896, 0.045504870140575804, 0.047449137491639704, 0.08433733542915434, 0.012212113306304673, 0.026440103792992886, 0.12211073000798933, 0.05929478662437759, 0.0355365429277299, 0.03872190383845009, 0.04814399922906887, 0.04117098746064585, 0.004300409964343999, 0.07279375524376519, 0.04701724465121515, 0.09391273997607641, 0.09155589417787269, 0.019918466241506394, 0.054794596071587875, 0.09227256392478012, 0.04750122512632515, 0.11817827500635758, 0.08480413889628835, 0.034442509640939534, 0.0867346728045959, 0.056202624618890695, 0.23844810028094798, 1.4756645914167166, 19.558122418820858, 57.24173583090305, 88.70895311236382, 103.54468703269958, 101.35746359825134, 99.14446994662285, 100.71371734142303, 94.50164347887039, 91.44294440746307, 76.17603242397308, 54.83460299670696, 57.092426642775536, 48.25408950448036, 51.77368484437466, 44.59203600883484, 45.048292726278305, 26.76149658858776, 27.392327338457108, 47.327904403209686, 29.20458499342203, 26.130840629339218, 29.22643382102251, 28.182760924100876, 28.241494372487068, 41.48523911833763, 31.226019524037838, 38.843852654099464, 20.855731889605522, 31.241093315184116, 35.79896964132786, 32.73654296994209, 35.1594677567482, 25.488013923168182, 22.25141789764166, 25.71958489716053, 19.066162817180157, 31.453741304576397, 27.276300564408302, 33.96138444542885, 43.91317203640938, 35.50348609685898, 47.95059598982334, 59.73266936838627, 97.24111407995224, 103.97247567772865, 94.17198076844215, 111.29174932837486, 106.73612058162689, 102.67878949642181, 114.67874318361282, 104.1538779437542, 110.58542802929878, 98.26712742447853, 64.00077894330025, 28.489742651581764, 7.054009884595871, 0.2729440445546061, 0.41048122686333954, 0.008651009520690423, 0.055109259265009314, 0.017854726102086715, 0.06026225404639263, 0.05925916353589855, 0.15326669061323628, 0.018860736963688396, 0.059655310833477415, 0.13471191516146064, 0.0192780113502522, 0.03903647426341195, 0.04152573033934459, 0.047812359407544136, 0.08779263400356285, 0.08272157603641972, 0.0166488938339171, 0.025947840949811507, 0.027330415687174536, 0.033695920210448094, 0.025764686324691866, 0.03775377590500284, 0.05769443421741016, 0.015180634436546825, 0.04014540616481099, 0.02970941273815697, 0.009830640265136026, 0.04551832898869179, 0.024924040808400605, 0.02673758441233076, 0.09636268820031546, 0.011431604016252095, 0.06392689392669126, 0.03368884754308965, 0.030066992476349697, 0.04147794345044531, 0.028507161332527176, 0.026569744004518725, 0.032380489428760484, 0.021464858946274035, 0.007745202974547283, 0.040037249273154885, 0.060926594960619695, 0.032052638271125033, 0.014189959128998453, 0.04238668843754567, 0.03368512567249127, 0.04564758142805658, 0.01624081465706695, 0.04549555618723389, 0.03880485368426889, 0.01736891808832297, 0.08204406200093217, 0.05350252438802272, 0.0408870454702992, 0.0355414114164887, 0.07532782590715215, 0.05743045599956531, 0.01910278657305753, 0.01748039423546288, 0.04615110265149269, 0.1579711795784533, 0.1598149267374538, 0.17209712939802557, 0.16462328669149429, 0.20468910865020007, 0.18287661659996957, 0.14172109920764342, 0.12329431454418227, 0.15278714447049424, 0.20248681510565802, 0.1548325628391467, 0.2247829647967592, 0.1088661102403421, 0.11196913357707672, 0.1756001406465657, 0.21315437159501016, 0.07616877570399083, 0.14077570696827024, 0.1121125536155887, 0.16252750618150458, 0.13032571849180385, 0.17775354150217026, 0.16990795702440664, 0.09869208937743679, 0.113832621864276, 0.15744168689707294, 0.1399967636098154, 0.14164455409627408, 0.17267594521399587, 0.1340301040909253, 0.1604397111805156, 0.11046434010495432, 0.12062621201039292, 0.18185567372711375, 0.1184785776422359, 0.10607734933728352, 0.15826518880203366, 0.15831262688152492, 0.16246071289060637, 0.20375795080326498, 0.11490040909848176, 0.08566682619857602, 0.15319029393140227, 0.14092913857894018, 0.1328876122715883, 0.23690073721809313, 0.14806861407123506, 0.1231839571846649, 0.1650953816715628, 0.20506852422840893, 0.252477036556229, 0.3406597953289747, 0.21326181973563507, 0.1668065515696071, 0.32376605027820915, 0.13003498956095427, 0.68044462823309, 1.8907462432980537, 23.28797187656164, 68.2352489233017, 103.02822634577751, 117.78515249490738, 109.80659902095795, 108.44526126980782, 101.47910267114639, 94.96590256690979, 76.41472041606903, 75.9505221247673, 62.92920224368572, 63.31202410161495, 55.69882482290268, 73.7211437523365, 75.19486427307129, 65.35734415054321, 60.56950606405735, 76.39639779925346, 125.05309090018272, 72.39324420690536, 91.5960305929184, 105.29745697975159, 100.42654395103455, 87.72593066096306, 147.51323729753494, 73.10084983706474, 126.19562119245529, 99.28769186139107, 100.56787356734276, 113.83515805006027, 106.95233657956123, 78.42149153351784, 75.54367035627365, 66.04221180081367, 75.9230799973011, 43.390092104673386, 74.37475427985191, 52.85904720425606, 39.54319752752781, 57.48191334307194, 42.76976779103279, 49.73013550043106, 52.510712295770645, 86.51735991239548, 88.90581294894218, 80.3641676902771, 101.92798018455505, 98.66432771086693, 104.5181491971016, 122.29044914245605, 126.29088968038559, 124.30962279438972, 113.28472718596458, 73.49127128720284, 33.42524081468582, 8.0789839848876, 0.6435833405703306, 0.9875489585101604, 0.10039745568064973, 0.223111737286672, 0.10690888870158233, 0.19225280644604936, 0.17290483840042725, 0.29426378023345023, 0.18505756597733125, 0.1001568217179738, 0.2230426878668368, 0.04794341897650156, 0.11247163434745744, 0.1953135125222616, 0.21206880250247195, 0.20224794745445251, 0.1729603362036869, 0.10472462192410603, 0.12252248838194646, 0.14570520026609302, 0.09066623722901568, 0.1631691967486404, 0.1533571584150195, 0.15615596057614312, 0.08096353951259516, 0.08166052008164115, 0.08290663055959158, 0.1146487616642844, 0.13862223189789802, 0.14227459294488654, 0.1567742438055575, 0.12267171201528981, 0.11409508239012212, 0.2020625738077797, 0.15238389110891148, 0.1254215621156618, 0.15368260501418263, 0.11019824305549264, 0.11182756148627959, 0.12951809854712337, 0.11542881824425422, 0.1590966762159951, 0.17189314268762246, 0.1159053883748129, 0.07699523135670461, 0.11647735416772775, 0.11340242112055421, 0.15879855549428612, 0.14327404322102666, 0.1744797796709463, 0.12169834080850706, 0.1208079639764037, 0.08547112185624428, 0.14242415054468438, 0.16594950458966196, 0.1209677335282322, 0.14565357647370547, 0.11655808499199338, 0.128091957885772, 0.08000777947017923, 0.06448469212045893, 0.05551515467232093], [0.02321786741958931, 0.03395294821530115, 0.034255432765348814, 0.02280342061567353, 0.021353601732698735, 0.022383368741429877, 0.02118735879776068, 0.02971306039398769, 0.05637251706502866, 0.009881214846245712, 0.09956235400750302, 0.048449285386595875, 0.04005796632554848, 0.04348458460299298, 0.04279578621208202, 0.03159392421366647, 0.01468896160076838, 0.03640529357653577, 0.055344282591249794, 0.021862048961338587, 0.056296587936230935, 0.08869729717844166, 0.11703478870913386, 0.0331956495938357, 0.0340891360247042, 0.067512988607632, 0.08203318211599253, 0.008846918881317833, 0.037932162231300026, 0.03947271979996003, 0.018779477359203156, 0.01722944256471237, 0.06539721463923343, 0.05135861189046409, 0.041385534932487644, 0.07104801610694267, 0.01943577895872295, 0.08584165392676368, 0.07148642500396818, 0.060092168641858734, 0.02969273667986272, 0.05973230865492951, 0.04789767670445144, 0.011439966165198712, 0.023078983758750837, 0.04589879099512473, 0.0070762523955636425, 0.035375674997339956, 0.02045797235041391, 0.09897788302623667, 0.05062598596850876, 0.044421286293072626, 0.03961492271628231, 0.09727196011226624, 0.06453521011280827, 1.3647133950144053, 22.376533783972263, 59.36920367181301, 89.40432339906693, 88.86159852147102, 81.14457741379738, 89.60622936487198, 65.90690106153488, 60.29570035636425, 58.15398707985878, 60.82683585584164, 35.880243480205536, 63.67895521223545, 96.8755204975605, 64.21908482909203, 92.35567823052406, 93.70909720659256, 65.62460660934448, 52.34659530222416, 97.61587277054787, 130.66357344388962, 79.52939048409462, 80.61450585722923, 96.28059402108192, 80.73408544063568, 76.06114938855171, 82.96128273010254, 72.42554247379303, 67.73084878921509, 57.44864992797375, 107.89757385849953, 82.92315557599068, 86.77038833498955, 92.9384757578373, 94.22520831227303, 123.86803328990936, 106.38070285320282, 138.67477476596832, 124.40419971942902, 132.94883161783218, 174.57489877939224, 113.60231414437294, 90.23117423057556, 100.63673347234726, 106.3688550889492, 78.46737027168274, 52.094995602965355, 46.37368440628052, 39.44555416703224, 39.50264610350132, 35.913848876953125, 48.904006630182266, 57.7050943672657, 87.7841891348362, 69.53846499323845, 80.74785590171814, 96.61281019449234, 88.4312716126442, 72.21529975533485, 58.346735537052155, 25.977154076099396, 1.2950307154096663, 0.19041725259739906, 0.23413447081111372, 0.26551556191407144, 0.02077253164316062, 0.08107672445476055, 0.006619608466280624, 0.009126726181420963, 0.06924638582859188, 0.09090578023460694, 0.0362926578236511, 0.04258231114363298, 0.0023322862762142904, 0.12916520732687786, 0.06310938857495785, 0.04419334676640574, 0.11092930304585025, 0.030929943241062574, 0.022143768219393678, 0.03343842094182037, 0.07760790394968353, 0.06733360409270972, 0.059453795474837534, 0.07062329241307452, 0.035264519829070196, 0.047195078077493235, 0.03744361754797865, 0.021976135612931103, 0.0070230640631052665, 0.02475742865499342, 0.05624051125778351, 0.06021851186233107, 0.05618811563181225, 0.021110129055159632, 0.0918145474861376, 0.06560357622220181, 0.07767205519485287, 0.029260658302519005, 0.04752043190819677, 0.0791203415428754, 0.002892633051487792, 0.0707974522083532, 0.07923273238702677, 0.1056594162946567, 0.05887278290174436, 0.027453994407551363, 0.03920880837540608, 0.02076760934869526, 0.025863082119030878, 0.051127232509315945, 0.05522488587303087, 0.09753686972544529, 0.02750356430624379, 0.0008207324185605103, 0.09481268309173174, 0.03771895804675296, 0.010720328755269293, 0.049319238314637914, 0.06982701990636997, 0.034576341131469235, 0.01556777391670039, 0.05789900722447783, 0.0033189273153766408, 0.021539938315982, 0.09405010408954695, 0.026356716080044862, 0.04736173475976102, 0.046679047954967245, 0.13630315399495885, 0.058609446641639806, 0.03180922125466168, 0.01176801028123009, 0.009472222827753285, 0.030745825679332484, 0.04676304422901012, 0.04921704086882528, 0.016484430198033806, 0.028377153757901397, 0.027325157570885494, 0.03319418385217432, 0.05870725057320669, 0.046449520232272334, 0.03512549701554235, 0.005647468296956504, 0.059938647973467596, 0.04999174656404648, 0.039367375647998415, 0.03541881604178343, 0.013981728261569515, 0.03440912412770558, 0.057349201961187646, 0.09284860410843976, 0.02430211734463228, 0.008489934716635616, 0.01805958669137908, 0.0224447796063032, 0.027998702971672174, 0.08584505296312273, 0.025359520077472553, 0.05709139470127411, 0.060589415006688796, 0.05723732690967154, 0.10848636069567874, 0.01239089575392427, 0.0379821866954444, 0.029620906061609276, 0.011044794791814638, 0.017337866629532073, 0.060452073157648556, 0.12834367953473702, 0.042197641159873456, 0.012449205369193805, 0.13741631613811478, 0.1376141281798482, 0.15838844468817115, 3.0944525403901935, 32.54013530910015, 78.30233752727509, 105.42291104793549, 103.3158253133297, 95.18486201763153, 110.08196264505386, 97.58996576070786, 100.03603130578995, 90.42392268776894, 82.60825127363205, 39.13493983447552, 60.44882833957672, 82.64691799879074, 45.6647564470768, 54.64984551072121, 63.63635189831257, 59.38460424542427, 53.17189201712608, 76.91051781177521, 101.85866430401802, 86.05686262249947, 76.23466327786446, 89.95487585663795, 78.8605123758316, 82.36694142222404, 76.62905931472778, 74.8401989042759, 60.49618899822235, 64.37022551894188, 82.39087253808975, 77.01954156160355, 77.65295997262001, 88.07940289378166, 86.50870397686958, 85.53279474377632, 84.51039120554924, 97.775319814682, 77.72213906049728, 112.89855390787125, 107.30425089597702, 56.12771160900593, 58.62626373767853, 57.13329344987869, 56.1028191447258, 36.60992592573166, 35.547799319028854, 36.98541417717934, 36.020395159721375, 55.43213993310928, 60.5366226285696, 86.99431791901588, 86.42207622528076, 126.41778007149696, 99.62208911776543, 98.45783919095993, 114.883673787117, 109.36424195766449, 94.12046313285828, 79.43940371274948, 39.16179299354553, 2.750762407667935, 0.156767267617397, 0.08650125251733698, 0.5514663679059595, 0.028504762340162415, 0.06186767903272994, 0.029056103849143256, 0.05634813009237405, 0.07278854536707513, 0.030582976214645896, 0.025972192670451477, 0.012274584514671005, 0.01850724089308642, 0.054612198437098414, 0.0598833839467261, 0.015858619735809043, 0.05750369484303519, 0.0034568914088595193, 0.02629427548527019, 0.019740423158509657, 0.06822352821473032, 0.045808553259121254, 0.034180498114437796, 0.07009935841779225, 0.0241463924976415, 0.09966747922590002, 0.12422123472788371, 0.034883375046774745, 0.021341334031603765, 0.05699498229660094, 0.08347525668796152, 0.017194914144056384, 0.05418511100288015, 0.027441197926236782, 0.030715529355802573, 0.038059084326960146, 0.04079521582752932, 0.06107293906097766, 0.03771991912799422, 0.04763547593029216, 0.02248800970846787, 0.015879212478466798, 0.039964333263924345, 0.03932409359549638, 0.05167774281289894, 0.03997548403276596, 0.0291263407052611, 0.045079304109094664, 0.04205555327644106, 0.030632560956291854, 0.15570408169878647, 0.05714925624488387, 0.03398688291781582, 0.0450495068798773, 0.03235801719711162, 0.035431306387181394, 0.04423062113346532, 0.020265405437385198, 0.06904366076923907, 0.044910554570378736, 0.13687241094885394, 0.12522698583779857, 0.14711577066918835, 0.07605429942486808, 0.13741996750468388, 0.09531586663797498, 0.1628316382993944, 0.12635432300157845, 0.15868554124608636, 0.18399344495264813, 0.16042657516663894, 0.13319690973730758, 0.1421456373645924, 0.0859489462163765, 0.20466696296352893, 0.11458737120847218, 0.16620765323750675, 0.14424762222915888, 0.11185320268850774, 0.1251235749805346, 0.18269413732923567, 0.15764113166369498, 0.31289403210394084, 0.10544534379732795, 0.10479709264473058, 0.11851185554405674, 0.18095354869728908, 0.19525552110280842, 0.14084309397730976, 0.12034375802613795, 0.20219188561895862, 0.1689946255646646, 0.1580460325931199, 0.14104926260188222, 0.11876095741172321, 0.1871146954363212, 0.09599378143320791, 0.131242923962418, 0.21338541700970381, 0.122920123685617, 0.13188652927055955, 0.16221301368204877, 0.24205568013712764, 0.11767103191232309, 0.263916322728619, 0.1121907017659396, 0.14759490120923147, 0.08057774146436714, 0.1235040306346491, 0.24958203721325845, 0.17225781921297312, 0.11684933342621662, 0.18569027655757964, 0.25941950152628124, 0.40537162916734815, 3.159680077806115, 37.22556509077549, 90.46386614441872, 119.54543083906174, 112.17085495591164, 100.14894604682922, 111.00294202566147, 88.65673631429672, 81.55492499470711, 75.83545669913292, 81.14736646413803, 55.00088207423687, 90.80147802829742, 121.34012773633003, 93.61423149704933, 125.51234185695648, 127.47669965028763, 95.0780801475048, 82.97503039240837, 146.02016061544418, 188.23791682720184, 116.90934509038925, 122.06031069159508, 144.57496136426926, 117.12470233440399, 115.64769878983498, 121.14723488688469, 109.66425105929375, 101.89704224467278, 85.28714552521706, 151.9896098971367, 119.37536716461182, 126.5252611041069, 137.28199750185013, 138.54126513004303, 180.5483302474022, 149.57204282283783, 200.89608639478683, 168.36946696043015, 184.6477934718132, 228.34177047014236, 162.3596030473709, 133.37533593177795, 140.33554404973984, 151.64045423269272, 108.47602441906929, 69.58046793937683, 59.5119734108448, 52.93682903051376, 59.54465165734291, 54.574639946222305, 72.89507567882538, 83.84832993149757, 120.50368621945381, 96.75420820713043, 107.40644261240959, 126.32807448506355, 121.55690610408783, 106.37192532420158, 91.28148347139359, 44.67543013393879, 3.6022527795284986, 0.46162292012013495, 0.2817174472147599, 0.7835954963229597, 0.07449037904734723, 0.2613319567171857, 0.17910603142809123, 0.1117304663057439, 0.2266807996784337, 0.1464630221016705, 0.12343789785518311, 0.14996955113019794, 0.09282422455726191, 0.16706674854503945, 0.10805682788486592, 0.1535165568930097, 0.25820959301199764, 0.07353815162787214, 0.1367870342801325, 0.16597754292888567, 0.3413745725993067, 0.111562065576436, 0.1158633828163147, 0.18570424377685413, 0.09660488067311235, 0.18153067241655663, 0.17601124593056738, 0.09887560765491799, 0.13624176353914663, 0.19071038608672097, 0.18131585035007447, 0.16084367700386792, 0.16819332871818915, 0.09892665999359451, 0.23225176089908928, 0.26969584228936583, 0.19694641552632675, 0.2005132514750585, 0.134239983453881, 0.18072493752697483, 0.06840059722890146, 0.19979795470135286, 0.12080912172677927, 0.12495504808612168, 0.19835695624351501, 0.19543126167263836, 0.15277480997610837, 0.25591588171664625, 0.1357132801786065, 0.1274049369385466, 0.30391597480047494, 0.14383924804860726, 0.09879043878754601, 0.10822669806657359, 0.1813546646735631, 0.1756674682837911, 0.11413420099415816, 0.10347829622332938, 0.17413819878129289, 0.11408665901399218], [0.03313928718853276, 0.09234314959030598, 0.05817738681798801, 0.018734434561338276, 0.02994616897922242, 0.04566133713524323, 0.005196844576857984, 0.012291101938899374, 0.059255059459246695, 0.04108422297576908, 0.009827193916862598, 0.015491992289753398, 0.013807363447995158, 0.017034151969710365, 0.03171976648445707, 0.022128333403088618, 0.008007974738575285, 0.05096454631711822, 0.02393256305367686, 0.019249488759669475, 0.03938949164876249, 0.07767586241243407, 0.005752818942710292, 0.021263378839648794, 0.026602274192555342, 0.004872556191912736, 0.09713018764159642, 0.02293797384481877, 0.024425120900559705, 0.025229469829355367, 0.01817730430047959, 0.0371609817375429, 0.0952393957413733, 0.07901175791630521, 0.05415018182247877, 0.06995172298047692, 0.08582902999478392, 0.08585841162130237, 0.052492272152449004, 0.07692256767768413, 0.05721468027331866, 0.037630382721545175, 0.01841178585891612, 0.05009513515688013, 0.03271177673013881, 0.032163266514544375, 0.016473962205054704, 0.05142920126672834, 0.06502708332845941, 0.053126871498534456, 0.061747877844027244, 0.08562704708310775, 0.12635677208891138, 1.7687484459020197, 18.534174263477325, 57.030771151185036, 79.66364488005638, 83.14466089010239, 70.619066208601, 71.24081924557686, 52.5518374890089, 58.70694100856781, 43.71358014643192, 33.21163907647133, 50.91347560286522, 50.933116748929024, 75.37453383207321, 79.79393228888512, 81.01132616400719, 66.87704980373383, 60.697794780135155, 42.70621620118618, 25.43355904519558, 20.39393126964569, 10.954166203737259, 6.796244541183114, 4.91201969794929, 2.531512272544205, 1.615403399337083, 1.009210527408868, 0.17486292083049193, 0.3165141394129023, 0.36940798396244645, 0.530923007754609, 0.3693260211730376, 0.9722182061523199, 0.709664347814396, 0.3528754273429513, 0.7288989750668406, 2.049805708229542, 4.896764466539025, 7.2697328589856625, 11.771106217056513, 19.282392114400864, 15.895242467522621, 26.12541262060404, 46.78485654294491, 51.18228457868099, 57.41272285580635, 68.41794312000275, 96.3029520213604, 114.82663124799728, 107.63122335076332, 109.82913941144943, 80.9472008049488, 52.341644167900085, 37.233183681964874, 44.782006815075874, 41.16172447800636, 44.19787555932999, 58.836825639009476, 59.96761076152325, 81.31014212965965, 88.174017816782, 86.00659132003784, 94.99208316206932, 80.83419486880302, 44.01556134223938, 17.045530043542385, 4.30895215831697, 0.40678390651009977, 0.5688826739788055, 0.054941337220952846, 0.03628370010119397, 0.06991158763412386, 0.008741924466448836, 0.05692605162039399, 0.1082649854652118, 0.026124863579752855, 0.010128682133654365, 0.013129392064001877, 0.07336679715081118, 0.05962470837403089, 0.030877859317115508, 0.018801268670358695, 0.024130575475282967, 0.02140056483767694, 0.020726017537526786, 0.008025924507819582, 0.03637303612777032, 0.03028401315532392, 0.019323141350469086, 0.06701628401060589, 0.04273111917427741, 0.03707574236614164, 0.04365327476989478, 0.08533656306099147, 0.10632275530952029, 0.036598975566448644, 0.06669995840638876, 0.038185282828635536, 0.02288440562551841, 0.09909237414831296, 0.049455641346867196, 0.020759386352438014, 0.005870680342923151, 0.04355651355581358, 0.025748806219780818, 0.050348315126029775, 0.054652478502248414, 0.09728255798108876, 0.04475375360925682, 0.0458118187088985, 0.02598057337309001, 0.06846022879472002, 0.01931030590640148, 0.046054363701841794, 0.018984085618285462, 0.018704457361309323, 0.043599324344540946, 0.029527365768444724, 0.010838078833330655, 0.07755046171951108, 0.010171299036301207, 0.058005716928164475, 0.022954963460506406, 0.05887629697099328, 0.025527666621201206, 0.02564537866419414, 0.04222479634336196, 0.04489066130190622, 0.04364357118902262, 0.03377836910658516, 0.022990055913396645, 0.03500605947920121, 0.018292448512511328, 0.07552498485893011, 0.02956606876978185, 0.0509397622954566, 0.04213685926515609, 0.02566130700870417, 0.03287555759015959, 0.022853654736536555, 0.07962302042869851, 0.022026069163985085, 0.05744271256844513, 0.03840629069600254, 0.0032918442593654618, 0.06880755390739068, 0.032448095371364616, 0.027185685758013278, 0.009014871538965963, 0.017431347550882492, 0.020460705309233163, 0.06467757630161941, 0.048203853439190425, 0.01597599039087072, 0.03941878421755973, 0.0269664646111778, 0.042602171015460044, 0.06562129128724337, 0.05089884769404307, 0.04895786063570995, 0.05106472141051199, 0.03351717023178935, 0.008205721842386993, 0.01805753279768396, 0.03985141549492255, 0.019223161070840433, 0.035630539641715586, 0.0290644159031217, 0.0473804628563812, 0.007030006390777999, 0.01735955404001288, 0.053532503443420865, 0.06115538053563796, 0.07522463027271442, 0.04057774800457992, 0.06944911830942146, 3.443393516354263, 28.157482780516148, 74.24520403146744, 94.85104233026505, 94.18461129069328, 89.67445850372314, 104.01279151439667, 85.21975234150887, 98.30583974719048, 65.39316862821579, 33.56523670256138, 39.60873261094093, 34.65606316924095, 51.02321371436119, 67.71881103515625, 87.88986146450043, 68.95732417702675, 67.9277466237545, 49.78549472987652, 31.503167152404785, 24.416566416621208, 16.36269338428974, 10.298831518739462, 7.337374454364181, 3.8196920743212104, 2.1901818132027984, 1.2168121500872076, 0.3060469776391983, 0.24633655120851472, 0.06898380655911751, 0.10635615195496939, 0.14137034537270665, 0.1537434759666212, 0.1755957174464129, 0.3913894185097888, 0.6621052685659379, 2.9592109099030495, 6.531679937615991, 9.72660692408681, 14.474443607032299, 22.234734892845154, 19.593743607401848, 32.923724725842476, 47.211957424879074, 59.27754119038582, 61.865513920784, 77.62038812041283, 87.44070276618004, 95.98188444972038, 81.18938460946083, 75.24655669927597, 42.68560230731964, 22.553853169083595, 27.082214578986168, 45.559236109256744, 58.13801273703575, 61.563194543123245, 95.15563398599625, 92.89686039090157, 94.6796715259552, 104.5034895837307, 98.97029489278793, 113.41536417603493, 103.09477597475052, 61.92983686923981, 28.429346792399883, 9.473084527999163, 0.4337832983583212, 0.706933659967035, 0.09246133660781197, 0.04196861438686028, 0.046617249317932874, 0.028238245977263432, 0.018426849601382855, 0.06268272045417689, 0.04661464066884946, 0.05480399908265099, 0.08387450987356715, 0.012536668400571216, 0.029204793136159424, 0.035775258438661695, 0.032298003425239585, 0.043162407164345495, 0.03725034745002631, 0.022527562468894757, 0.03800150108872913, 0.03444460620812606, 0.05377965346269775, 0.052111554105067626, 0.03388646291568875, 0.03553692513378337, 0.07175862250733189, 0.028513092947832774, 0.08790578183834441, 0.0578796483023325, 0.043946167061221786, 0.04860544067923911, 0.031825225669308566, 0.01566456296131946, 0.03540583958965726, 0.04952802672050893, 0.09588493805495091, 0.0054993068624753505, 0.041364387434441596, 0.025496611451671924, 0.03125610601273365, 0.0803363801969681, 0.05170565869775601, 0.06300225213635713, 0.02248350858280901, 0.015121327560336795, 0.051976687318529, 0.013378119147091638, 0.021984054328640923, 0.033639884350122884, 0.03114829793048557, 0.039577611241838895, 0.02050802835583454, 0.053133550827624276, 0.03976574196713045, 0.02394172115600668, 0.01614953791431617, 0.00440659645391861, 0.18942804395919666, 0.1562478087726049, 0.12005203461740166, 0.08645907626487315, 0.1090803460101597, 0.15865383669734, 0.0982330042461399, 0.08281452261144295, 0.10935180878732353, 0.14842218806734309, 0.25476581999100745, 0.1336246242863126, 0.10625156850437634, 0.10741838792455383, 0.08722238999325782, 0.09328426705906168, 0.0941273542412091, 0.12672481796471402, 0.09178375577903353, 0.1642314178752713, 0.17986490711336955, 0.17032908130204305, 0.11139055524836294, 0.164859319338575, 0.1342188025591895, 0.11906670741154812, 0.20206485962262377, 0.11748586606699973, 0.10478119584149681, 0.19121464574709535, 0.21311227697879076, 0.0993002274481114, 0.18931669212179258, 0.2300942040164955, 0.10166953390580602, 0.1305261577363126, 0.20259142824215814, 0.1711739570600912, 0.1673160507925786, 0.16019998263800517, 0.10169712695642374, 0.1609055424341932, 0.1427272881846875, 0.2018153792596422, 0.08432942413492128, 0.10617793261189945, 0.2101719324127771, 0.18248670705361292, 0.2432297429186292, 0.17511354410089552, 0.2515417226823047, 0.15138019574806094, 0.1843503734562546, 3.6828599916771054, 33.76911476254463, 84.94017094373703, 107.53615245223045, 104.35064658522606, 89.26905825734138, 92.44173601269722, 71.9087778031826, 74.83003064990044, 57.66283303499222, 44.447609558701515, 68.7145172059536, 71.95120632648468, 105.22571682929993, 106.38331711292267, 107.46825769543648, 95.9330266714096, 90.23372009396553, 63.15330281853676, 39.83060270547867, 32.094563618302345, 18.904954567551613, 11.039776559919119, 8.672439940273762, 4.334600307047367, 2.5427758181467652, 1.5993515169247985, 0.4696979618165642, 0.3928090282715857, 0.3712080779951066, 0.7990131096448749, 0.46259554917924106, 0.9177911141887307, 0.9301973890978843, 0.7817484391853213, 0.7098437694367021, 3.584350277669728, 7.444043755531311, 13.060779813677073, 18.234598338603973, 29.689891152083874, 24.530127122998238, 41.717870235443115, 68.53450566530228, 77.32243090867996, 84.95334103703499, 105.03628939390182, 142.39738941192627, 160.60900658369064, 156.50670111179352, 155.14901876449585, 114.25498232245445, 74.84317794442177, 57.64077141880989, 68.04884612560272, 57.84265458583832, 67.13404521346092, 83.52290779352188, 86.51402369141579, 108.29211428761482, 115.41449010372162, 110.28020560741425, 123.94328445196152, 116.48934602737427, 68.08328747749329, 34.655846580863, 11.523712892085314, 0.6477307586465031, 0.9136367496103048, 0.2689900004770607, 0.10860261070774868, 0.16614871186902747, 0.08117071003653109, 0.1381321917870082, 0.22435691265854985, 0.15851302159717306, 0.29540826100856066, 0.2256052495795302, 0.1217772311065346, 0.15552004391793162, 0.11151945145684294, 0.159935807751026, 0.10063661276944913, 0.07375220186077058, 0.08431435111560859, 0.13357659248868003, 0.2526796131860465, 0.18057622597552836, 0.14536399045027792, 0.12170811489340849, 0.12676116835791618, 0.22444110189098865, 0.16822182718897238, 0.19374100549612194, 0.12429266644176096, 0.1901926935533993, 0.27882746479008347, 0.10491844863281585, 0.10358121726312675, 0.18080756824929267, 0.12550256011309102, 0.2172683336539194, 0.09003264349303208, 0.10995520453434438, 0.10273341744323261, 0.17247154290089384, 0.154523977835197, 0.19001419219421223, 0.12908407574286684, 0.1298699656035751, 0.09626853192457929, 0.16207785374717787, 0.14639939035987481, 0.13440034672385082, 0.06166538441902958, 0.20278593030525371, 0.12211751323775388, 0.12705968983937055, 0.14655242121079937, 0.19024516339413822, 0.07407430137391202, 0.1682943498599343, 0.10044763228506781], [0.0056852375837479485, 0.05070870203780942, 0.032434117019874975, 0.00871027279572445, 0.09837108082138002, 0.05870379216503352, 0.04955695563694462, 0.016042006282077637, 0.07423806368024088, 0.044925597903784364, 0.08486245686071925, 0.005617235519821406, 0.03483196647721343, 0.04030402909847908, 0.05483850894961506, 0.03699518223584164, 0.023758987699693535, 0.030807474031462334, 0.04109334397071507, 0.03512465096719097, 0.07076951776980422, 0.03584472717193421, 0.047157139488263056, 0.030080095093580894, 0.030604318526457064, 0.04760843949043192, 0.03438915293372702, 0.05291859888529871, 0.03417260908463504, 0.016329172904079314, 0.0597353217744967, 0.029495635244529694, 0.033545716942171566, 0.00696052513376344, 0.018679725289985072, 0.041406856835237704, 0.011783231730078114, 0.04693017959652934, 0.02083117244183086, 0.035270189837319776, 0.0302425642075832, 0.055201845898409374, 0.12165617939899676, 0.01731255753838923, 0.04530860918748658, 0.11875433003297076, 0.027422163693699986, 0.04824485338758677, 0.04727406114398036, 0.03499779195408337, 0.21460688818478957, 2.97944244928658, 33.53359580039978, 76.88885137438774, 92.83435374498367, 81.91228061914444, 87.49545022845268, 81.45697385072708, 54.449330270290375, 45.32385773956776, 54.838934764266014, 46.76228575408459, 58.73773455619812, 69.73546162247658, 81.0677607357502, 70.48922717571259, 71.9922137260437, 49.641934633255005, 21.109784357249737, 6.720458557829261, 1.1457404075190425, 0.3766883339267224, 0.5212904058862478, 1.1285985773429275, 0.4325412993784994, 0.2005733802798204, 0.13153905572835356, 0.07071669169818051, 0.21717503084801137, 0.14744721382157877, 0.32233827689196914, 0.4007419338449836, 0.47422826872207224, 0.38929501839447767, 0.24508816975867376, 0.8169746864587069, 0.39437460363842547, 0.2952192508382723, 0.35936996166128665, 0.09706285258289427, 0.09943358396412805, 0.1234196632867679, 0.2392028199392371, 0.5217364663258195, 0.3787894727429375, 0.30257906997576356, 0.6397423997987062, 0.03269659238867462, 0.440997330006212, 1.5230968524701893, 4.568300591781735, 9.524118639528751, 24.9636572599411, 42.937631383538246, 83.49326178431511, 89.74714860320091, 90.04344150424004, 55.142230689525604, 60.08502446115017, 48.5413882881403, 41.99888035655022, 58.21193017065525, 72.3525407910347, 58.115042969584465, 66.2518997490406, 84.32373762130737, 71.31903424859047, 95.839202105999, 94.08750370144844, 90.32582715153694, 43.68649899959564, 6.254604030400515, 0.2572487195720896, 0.23812903615180403, 0.07223861393867992, 0.031054085993673652, 0.048142904561245814, 0.06962668456253596, 0.02665870895725675, 0.018252908739668783, 0.06537427485454828, 0.11513461606227793, 0.04600664360623341, 0.05798132624477148, 0.0633679008751642, 0.04461244127014652, 0.08020538371056318, 0.034456558496458456, 0.03710344673891086, 0.07363129858276807, 0.08867059470503591, 0.019340103135618847, 0.04998872973374091, 0.05348924365534913, 0.06065102439606562, 0.06226176687050611, 0.022779569844715297, 0.03879066382069141, 0.015844721165194642, 0.03854564005450811, 0.0920465354283806, 0.07438253014697693, 0.04006620787549764, 0.012376652084640227, 0.032080995733849704, 0.0057825169096759055, 0.03887063394358847, 0.01873216544481693, 0.05678901776263956, 0.038242109076236375, 0.038873736120876856, 0.07743582958937623, 0.031536541355308145, 0.035757368968916126, 0.028388571699906606, 0.027363259432604536, 0.04065060093125794, 0.05315832742780913, 0.04067178182594944, 0.05860136094270274, 0.07070692503475584, 0.039510317001258954, 0.054040889444877394, 0.049542591368663125, 0.028311948663031217, 0.029660829895874485, 0.08387933383346535, 0.03588177147321403, 0.009251636129192775, 0.041623326469562016, 0.07398565183393657, 0.048616476415190846, 0.039571139714098535, 0.02135196529707173, 0.04325211055402178, 0.06221668882062659, 0.0397782360232668, 0.05602236065897159, 0.05969259262201376, 0.01832881931477459, 0.0429043921030825, 0.10500089381821454, 0.02803514427796472, 0.013896537129767239, 0.04121986901736818, 0.02552315065258881, 0.04193978194962256, 0.05265459469228517, 0.0505054240784375, 0.03423009955440648, 0.029282883770065382, 0.01055612579875742, 0.06890237811603583, 0.0518218085198896, 0.03224223844881635, 0.018909416285168845, 0.06354969737003557, 0.01417090634276974, 0.02794915904814843, 0.02363909374253126, 0.015345522951975, 0.008902228364604525, 0.049179855559486896, 0.022915689005458262, 0.05949230551777873, 0.04043445784191135, 0.03835620314930566, 0.09722216942464001, 0.03367180412169546, 0.0741110673698131, 0.10912096375250258, 0.12257925525773317, 0.05101338705571834, 0.042467571402085014, 0.030523838177032303, 0.04989222084986977, 0.02177833841415122, 5.75695613399148, 49.03678670525551, 95.83317562937737, 107.90493786334991, 93.83395850658417, 102.21987292170525, 116.23170465230942, 88.54157969355583, 67.94336378574371, 53.403337597846985, 30.901936814188957, 29.863378442823887, 38.14805679023266, 64.39680129289627, 69.87560570240021, 76.15381881594658, 57.782686203718185, 25.288148447871208, 8.92348961904645, 1.3915467238985002, 0.29583912226371467, 0.8671572874300182, 1.3691551191732287, 0.4802334605483338, 0.33709241019096226, 0.2713316248264164, 0.11285718748695217, 0.06653785851085559, 0.08079243736574426, 0.40346576424781233, 0.3489877609536052, 0.28518018953036517, 0.03843386148218997, 0.14639038068708032, 0.4568072722759098, 0.16507203370565549, 0.1409094122936949, 0.088694298901828, 0.20318787748692557, 0.20712554978672415, 0.20912112551741302, 0.3177825588500127, 0.5273454997222871, 0.34854134428314865, 0.6280139135196805, 0.8243774611037225, 0.1266310698702, 0.39214590447954834, 0.9303068113513291, 5.619984408840537, 12.942210026085377, 30.589259192347527, 48.85459028184414, 81.79341539740562, 89.04727175831795, 64.90264534950256, 46.71982683241367, 34.76497672498226, 29.714363738894463, 41.616898253560066, 67.45122939348221, 115.75426027178764, 103.96727755665779, 95.06381571292877, 104.46720913052559, 86.67399510741234, 108.63455951213837, 110.82104578614235, 110.21537348628044, 62.92620800435543, 15.137570723891258, 0.4689117899397388, 0.3116664011031389, 0.08355165336979553, 0.04510198785283137, 0.04585441798553802, 0.06792468018829823, 0.0274891313893022, 0.08317294283187948, 0.02722960420214804, 0.08002041824511252, 0.08998730569146574, 0.049744210627977736, 0.06560367270139977, 0.07310069267987274, 0.054945226074778475, 0.044156424919492565, 0.02982507459819317, 0.028200151537021156, 0.016474637559440453, 0.06926294314325787, 0.058387915560160764, 0.031138638878474012, 0.01661115005845204, 0.052575863956008106, 0.006324507821773295, 0.03654264655779116, 0.027226062302361242, 0.04338802376878448, 0.0822399444587063, 0.05324541845766362, 0.05194717952690553, 0.05860681943886448, 0.014718763468408724, 0.02251302565127844, 0.037387945340014994, 0.06547780445544049, 0.03929333157429937, 0.05742809968069196, 0.05285616200126242, 0.03519714024150744, 0.08110661816317588, 0.012563036907522473, 0.03709075230290182, 0.024093703723337967, 0.02055997869319981, 0.011578119738260284, 0.03635100547398906, 0.04082869410922285, 0.013087379084026907, 0.04827148535696324, 0.06470196327427402, 0.06657026067841798, 0.08881535060936585, 0.08240095339715481, 0.15854086697800085, 0.12470813555410132, 0.12234047666424885, 0.14206211606506258, 0.1575226997374557, 0.2105908005614765, 0.11792378514655866, 0.08479916650685482, 0.12460375990485772, 0.11864936066558585, 0.18485751264961436, 0.12472256290493533, 0.14134644821751863, 0.088556949631311, 0.144062441540882, 0.12278612150112167, 0.11172897458891384, 0.08507107457262464, 0.15157612273469567, 0.11495791812194511, 0.17672780435532331, 0.12130903982324526, 0.1186931251140777, 0.28450709127355367, 0.15571220079436898, 0.07991016478626989, 0.16817443363834172, 0.12064234630088322, 0.1434922791668214, 0.08182201883755624, 0.17216377425938845, 0.11430761122028343, 0.19353602430783212, 0.10500447839149274, 0.10161300451727584, 0.11817017817520536, 0.06572476893779822, 0.20103002374526113, 0.18343680450925604, 0.13407022459432483, 0.1039620280789677, 0.3190223907586187, 0.23668821580940858, 0.08314057035022415, 0.1521016375045292, 0.30201322690118104, 0.135560946946498, 0.14561177871655673, 0.2111885411432013, 0.160672448691912, 0.2542255067965016, 5.617567263543606, 56.828405410051346, 108.69369193911552, 119.36202988028526, 105.79994961619377, 105.17594709992409, 105.73901608586311, 73.10169339179993, 54.24304313957691, 64.9825930595398, 63.11936303973198, 86.34459838271141, 104.60972428321838, 119.93225008249283, 106.33655682206154, 104.39645692706108, 77.68157243728638, 36.07125163078308, 12.445232793688774, 3.254002179019153, 0.7671338890213519, 1.1805793130770326, 2.0212331414222717, 0.5239702120888978, 0.3790336987003684, 0.30533329874742776, 0.27008849778212607, 0.2796983008738607, 0.3698932594852522, 0.8349531248677522, 0.7779266161378473, 0.813523877877742, 0.6411505211144686, 0.4294648894574493, 1.2029994162730873, 0.7077452132944018, 0.4104819393251091, 0.8643944200593978, 0.4822055250406265, 0.23004817601758987, 0.18857645918615162, 0.4608306032605469, 0.5669207917526364, 0.37797411961946636, 0.6050287093967199, 0.8354478108230978, 0.3437779436353594, 1.0582867939956486, 2.8692535869777203, 7.265748297795653, 17.16301403939724, 39.899561405181885, 65.93548312783241, 124.75104510784149, 127.96672135591507, 128.77288609743118, 79.67604741454124, 85.22279977798462, 78.41327637434006, 59.94429901242256, 78.0302645266056, 94.91281181573868, 78.13965305685997, 92.32274919748306, 107.75403276085854, 89.40311506390572, 122.57129207253456, 123.11012595891953, 125.07547169923782, 70.84878668189049, 17.44709249585867, 0.6727476662490517, 0.42918765277136117, 0.27757287898566574, 0.13598555931821465, 0.13788793614367023, 0.3058451134711504, 0.1275805290788412, 0.2374419558327645, 0.14029938174644485, 0.1896281269728206, 0.1555291426484473, 0.13948692299891263, 0.169938993640244, 0.1885334591497667, 0.18765897169942036, 0.12244932004250586, 0.17080071615055203, 0.15832643082831055, 0.1136669448169414, 0.17653155082371086, 0.14102751767495647, 0.15620851947460324, 0.15163132367888466, 0.20649306185077876, 0.1618202542886138, 0.16831275512231514, 0.10184567523538135, 0.12851622886955738, 0.22149366239318624, 0.23938911384902894, 0.2245781320380047, 0.10390707946498878, 0.06700322963297367, 0.09148384648142383, 0.16951274854363874, 0.18064612144371495, 0.11502164634293877, 0.11062642515753396, 0.10909513701335527, 0.15855790668865666, 0.18430278694722801, 0.1255750234122388, 0.11363633122527972, 0.0908278844144661, 0.14994413999374956, 0.09431539219804108, 0.11540659092133865, 0.15388475119834766, 0.11409137907321565, 0.09264051332138479, 0.10641901928465813, 0.18067893921397626, 0.1678924323641695, 0.15899929159786552], [0.02452647044265177, 0.04366524190118071, 0.024871066307241563, 0.041360049581271596, 0.05197740720177535, 0.056869203108362854, 0.05088639816676732, 0.07410990219796076, 0.0423812373628607, 0.005986154810670996, 0.03750074436538853, 0.05698674445739016, 0.020130720477027353, 0.04053223579830956, 0.03258345568610821, 0.022757591141271405, 0.032476864726049826, 0.06483607678092085, 0.06132905422418844, 0.010230958432657644, 0.053359445737442, 0.03684221075673122, 0.051072172573185526, 0.05363536882214248, 0.04465790152607951, 0.04961759281286504, 0.043130802805535495, 0.0211460564241861, 0.02593680335849058, 0.06078738661017269, 0.07534669872256927, 0.022670331272820476, 0.04171219494310208, 0.09776731400052086, 0.019812359532807022, 0.07083614778821357, 0.05280090539599769, 0.026701785063778516, 0.040354049851885065, 0.047922171288519166, 0.044655860619968735, 0.04504111690039281, 0.07181650260463357, 0.048548124614171684, 0.03396917527425103, 0.1290100094047375, 0.0365485911606811, 0.016537161645828746, 0.19792968698311597, 0.5268148938193917, 28.03972139954567, 74.59318175911903, 86.96065932512283, 79.78203892707825, 63.10525059700012, 61.523456275463104, 48.93204152584076, 37.120086550712585, 41.70081675052643, 50.31865552067757, 64.04769882559776, 93.11227083206177, 73.56672763824463, 54.21448767185211, 34.63925667107105, 20.10811060667038, 7.051913347095251, 0.8323502645362169, 0.1270556970848702, 0.3916199295781553, 0.06578931352123618, 0.04874650068813935, 0.08735740892007016, 0.5028235749341547, 0.35713452380150557, 0.060413329338189214, 0.17508673772681504, 0.0606239619810367, 0.23793656757334247, 0.27089354989584535, 0.09546293062157929, 0.12790873646736145, 0.2752818987937644, 0.27624188165646046, 0.284898885875009, 0.49886317807249725, 0.3975474333856255, 0.21713752270443365, 0.26412029459606856, 0.12068554671714082, 0.20963712595403194, 0.32287517620716244, 0.3386695036897436, 0.42211587599013, 0.26753684564027935, 0.3304260835284367, 0.40516373876016587, 0.15328141482314095, 0.11060211239964701, 0.026291000758646987, 0.11449825411546044, 0.14523320918669924, 0.19859092572005466, 0.15782266098540276, 1.3396099233068526, 6.751766502857208, 33.98634150624275, 57.74774707853794, 66.73831164836884, 58.06222580373287, 63.35840441286564, 55.419570207595825, 28.026475310325623, 30.806286446750164, 44.72685657441616, 57.75322638452053, 65.78321009874344, 73.91298785805702, 62.13807329535484, 87.55662694573402, 87.16760382056236, 87.88184389472008, 35.12738227844238, 1.120630286168307, 0.29037652944680303, 0.0234956477288506, 0.07515213728765957, 0.06529296515509486, 0.027138531550008338, 0.012403695018292638, 0.055911116432980634, 0.027608359268924687, 0.025504808472760487, 0.03499010701489169, 0.049766734809963964, 0.09150594763923436, 0.07742207759292796, 0.06599494779948145, 0.038800141046522185, 0.04362997875432484, 0.059170873937546276, 0.02536472624342423, 0.03351546329213306, 0.04324731256929226, 0.02750090185145382, 0.01665558615059126, 0.08363743079826236, 0.020581987082550768, 0.015455512020707829, 0.019894335309800226, 0.11196900741197169, 0.020188396483717952, 0.03474614080914762, 0.07305597828235477, 0.08376672776648775, 0.028073077301087324, 0.1008669011935126, 0.09223037282936275, 0.07026813022093847, 0.016283202421618626, 0.045488516916520894, 0.07863577106036246, 0.04938261772622354, 0.02942362094472628, 0.0475478023145115, 0.053909080306766555, 0.081602877471596, 0.02939232457720209, 0.009680316397862043, 0.03104639363300521, 0.039943389856489375, 0.027576016473176423, 0.02206876491982257, 0.06631238662521355, 0.04172343476966489, 0.03687075375637505, 0.01283262205106439, 0.046317814994836226, 0.036070347487111576, 0.022680975525872782, 0.06325505732093006, 0.033093199817813, 0.012728259389405139, 0.1152286832802929, 0.01643699211854255, 0.04112763861485291, 0.048123831365955994, 0.04335795565566514, 0.009023931306728628, 0.04793307343788911, 0.04278507702110801, 0.04620501225872431, 0.0858424257603474, 0.05349145896616392, 0.054772999574197456, 0.021993308910168707, 0.03264703176682815, 0.06007115473039448, 0.02550112927565351, 0.041800785111263394, 0.02485349410562776, 0.04054981727676932, 0.06021328714268748, 0.03664046904304996, 0.013007898778596427, 0.061354398567345925, 0.05572560919972602, 0.03436725957726594, 0.0026819700269697933, 0.025578425811545458, 0.021090751579322387, 0.018243789600091986, 0.09226987735019065, 0.05695976367860567, 0.054173722746782005, 0.11330882887705229, 0.04344105393101927, 0.029931383542134427, 0.07949724124046043, 0.019620375205704477, 0.05527435372641776, 0.12713426083792, 0.015431092579092365, 0.02742327134910738, 0.169421152677387, 1.690162606537342, 40.62580123543739, 93.5922534763813, 101.89521074295044, 92.92166545987129, 88.62966656684875, 103.61238420009613, 78.5001853108406, 59.26626719534397, 40.6476766616106, 30.821939706802368, 46.27700239419937, 63.364636078476906, 69.73452687263489, 61.19760476052761, 44.08638194203377, 24.18321903795004, 8.453134708106518, 0.889411149546504, 0.16278758441330865, 0.40837112290319055, 0.025918965839082375, 0.07748671123408712, 0.10326448347768746, 0.4476154170697555, 0.46079135849140584, 0.07173473277362064, 0.29072658566292375, 0.16611791274044663, 0.19606067711720243, 0.25966509303543717, 0.14168047404382378, 0.2513526234542951, 0.35684211761690676, 0.3404260484967381, 0.34150352817960083, 0.5311795533634722, 0.5910420755390078, 0.25286794058047235, 0.04921592764731031, 0.1450007685343735, 0.3006297448882833, 0.4394681198755279, 0.3644422144861892, 0.5509201472159475, 0.23861077905166894, 0.5953341827262193, 0.38321400876156986, 0.30345308245159686, 0.15594952477840707, 0.04316116406698711, 0.15189006604487076, 0.23919799597933888, 0.37629437225405127, 0.028128346893936396, 0.9659078728873283, 9.115014541894197, 39.215449914336205, 58.916651755571365, 72.4662534892559, 61.81152641773224, 43.262741938233376, 43.58464926481247, 28.848093822598457, 35.608675852417946, 68.59182938933372, 95.08434221148491, 104.77365508675575, 102.35855787992477, 73.45815986394882, 101.63628503680229, 97.75992304086685, 102.49066919088364, 53.15081834793091, 2.6255847746506333, 0.3589761187322438, 0.04277953688870184, 0.03392847960640211, 0.05652202642522752, 0.05765323017840274, 0.1272984832758084, 0.009445077848795336, 0.030798853986198083, 0.06072644144296646, 0.012361788722046185, 0.08592159807449207, 0.06055302750610281, 0.03899770075804554, 0.06028359079209622, 0.05256888034637086, 0.029367316055868287, 0.013215994204074377, 0.06188114530232269, 0.01785546453902498, 0.02144660582416691, 0.027973816904705018, 0.03861371355014853, 0.048569253558525816, 0.05693465682270471, 0.04500720075157005, 0.1110289512143936, 0.06070680421544239, 0.019776810659095645, 0.038383432547561824, 0.044766934151994064, 0.02948178862425266, 0.04223021773213986, 0.12833517452236265, 0.024499304126948118, 0.0674298606463708, 0.03068746875214856, 0.02277019651955925, 0.0849213611218147, 0.04555414503556676, 0.04582241286698263, 0.02166743372072233, 0.0309268169439747, 0.013810407181154005, 0.044017142354277894, 0.029969754432386253, 0.054474225762533024, 0.012410649869707413, 0.029507032777473796, 0.0060580146509892074, 0.01806527710868977, 0.02154339301341679, 0.038312924807542004, 0.1452003765734844, 0.16052495426265523, 0.09895517330733128, 0.1272932585561648, 0.11784485031967051, 0.09051589295268059, 0.12519826472271234, 0.23677761491853744, 0.11479866807349026, 0.17878989136079326, 0.14533368113916367, 0.0952653338026721, 0.10032034653704613, 0.1982717725331895, 0.16111432341858745, 0.11971681393333711, 0.1592130449716933, 0.21744978876085952, 0.24037772876909003, 0.13806063390802592, 0.13015489093959332, 0.16951136814896017, 0.11159651607158594, 0.16446587716927752, 0.12630263983737677, 0.12585874646902084, 0.14666144270449877, 0.13973842200357467, 0.10784536774735898, 0.17434233392123133, 0.22749440133338794, 0.19661615981021896, 0.12266595294931903, 0.18297701433766633, 0.0983842762070708, 0.13273728283820674, 0.18510086287278682, 0.2409015514422208, 0.1424387560109608, 0.34165100776590407, 0.13492148282239214, 0.13931449240772054, 0.2645075472537428, 0.17947014392120764, 0.19590951647842303, 0.2672008011722937, 0.17770631122402847, 0.16629956080578268, 0.4208502470282838, 1.682520266622305, 43.24035353958607, 107.88658484816551, 112.25736111402512, 98.46542358398438, 82.57557302713394, 82.71116495132446, 66.3163822889328, 45.43161615729332, 53.75554449856281, 78.99674266576767, 92.81086340546608, 129.3999284505844, 106.671212464571, 79.0191538631916, 53.46009895205498, 30.3457872569561, 11.885512378066778, 1.6345359664410353, 0.6948802911210805, 0.6995371193625033, 0.13817318802466616, 0.20632888394175097, 0.21772088046418503, 0.9446239087264985, 0.7386408804450184, 0.20265937928343192, 0.48901039583142847, 0.47090879059396684, 0.4200592660345137, 0.6671316269785166, 0.25097703735809773, 0.47463885450270027, 0.46846445300616324, 0.6179718242492527, 0.4696671775309369, 0.583479234483093, 0.7727241609245539, 0.6197171774692833, 0.5334485066123307, 0.2796255110297352, 0.5536232271697372, 0.807439157506451, 0.794117784826085, 0.8912669937126338, 0.4619025019928813, 0.7980115071404725, 0.7295785448513925, 0.4778897581854835, 0.21704846498323604, 0.14879921393003315, 0.3111255238763988, 0.4159473819890991, 0.5353114160243422, 0.6727123400196433, 2.23968674428761, 14.423230905085802, 53.285008147358894, 88.16577225923538, 96.170893907547, 82.73205623030663, 92.92565524578094, 81.12945422530174, 39.18974809348583, 44.64042641222477, 61.175432950258255, 75.1896433532238, 90.48436224460602, 93.54067504405975, 79.4194395840168, 108.14690887928009, 108.3486932516098, 122.19268038868904, 60.599634647369385, 2.9301845049485564, 0.5505411769263446, 0.09658936236519367, 0.11096750880824402, 0.5034659779630601, 0.10048083597212099, 0.2454804244916886, 0.12762265338096768, 0.15788767312187701, 0.2062139252666384, 0.16163550404598936, 0.1404652517521754, 0.23335769452387467, 0.14544126286637038, 0.14703492110129446, 0.12236445545568131, 0.127484435797669, 0.13970202708151191, 0.12141093669924885, 0.11796644379501231, 0.19756475812755525, 0.14397963270312175, 0.11333144211675972, 0.1928895988385193, 0.10688130307244137, 0.1140833564568311, 0.1773260347545147, 0.1967820298159495, 0.10972380288876593, 0.14861683855997398, 0.18529376189690083, 0.17544828238897026, 0.13965896767331287, 0.25300351611804217, 0.1745693272096105, 0.14368289237609133, 0.07704419083893299, 0.17138088267529383, 0.1397435725084506, 0.2025395818054676, 0.11923080368433148, 0.1057361246785149, 0.20447292103199288, 0.11714742446201853, 0.1699041572283022, 0.20885604521026835, 0.1142109242209699, 0.08605464288848452, 0.09611127825337462, 0.07497853410313837, 0.2178702302626334, 0.13167614524718374, 0.13206063711550087], [0.015404522764583817, 0.015176590659393696, 0.029032670536253136, 0.032838294355315156, 0.04846491872740444, 0.0587124938465422, 0.020790461931028403, 0.048352980593335815, 0.0250215775668039, 0.027257403198746033, 0.0008615120998456405, 0.028288077483011875, 0.019820888664980885, 0.03203069296432659, 0.0360837098560296, 0.005673943023793981, 0.0714238545333501, 0.021375127726059873, 0.025921292472048663, 0.04989556793589145, 0.021965699161228258, 0.024382864867220633, 0.02858062282030005, 0.04667309964133892, 0.03130868346488569, 0.023581523491884582, 0.022949549493205268, 0.03792603580222931, 0.03155573329422623, 0.027837977904709987, 0.03331526153488085, 0.05551981164899189, 0.04121286685403902, 0.0796445575542748, 0.08771353590418585, 0.01668834825977683, 0.03327482190798037, 0.04869147414865438, 0.025338450504932553, 0.014058865235710982, 0.027499324787640944, 0.059189750463701785, 0.05287838932417799, 0.004072940309924888, 0.059990780137013644, 0.05276409487123601, 0.09660164490924217, 0.35437812795862556, 11.695319283753633, 58.68946574628353, 87.93146163225174, 74.80378925800323, 73.57127979397774, 71.48769959807396, 44.348480477929115, 26.18141021579504, 36.76300451159477, 50.01431465148926, 75.49292027950287, 72.75887578725815, 57.994749024510384, 36.91546373069286, 17.515080347657204, 6.0346281342208385, 1.078895463142544, 0.1951855662628077, 0.29830982093699276, 0.14887224126141518, 0.1330865523777902, 0.17354134877678007, 0.05990021956677083, 0.13312505499925464, 0.13285862398333848, 0.550771658308804, 0.12990207091206685, 0.12582015478983521, 0.11903364473255351, 0.05730934863095172, 0.22678039589663967, 0.09295567375374958, 0.15880199905950576, 0.06931846321094781, 0.13715034525375813, 0.1589793129824102, 0.26715051324572414, 0.4962870053714141, 0.08554975982406177, 0.08583269620430656, 0.10478868411155418, 0.016613649240753148, 0.07822062849299982, 0.01376975882521947, 0.16373474296415225, 0.1174534490564838, 0.10381072643212974, 0.14031989470822737, 0.18751573719782755, 0.08519254930433817, 0.10778431125800125, 0.14823442470515147, 0.1670953509164974, 0.05495803925441578, 0.11664609628496692, 0.04421493213158101, 0.11373002736945637, 0.2966664091218263, 0.1686214143410325, 1.0562444035895169, 10.538929235190153, 29.476694092154503, 59.270891547203064, 64.90864902734756, 89.34797242283821, 63.50887253880501, 35.32029792666435, 28.606668077409267, 23.380113132297993, 46.72881335020065, 78.35509389638901, 66.31395041942596, 70.71740493178368, 81.25488549470901, 91.54405698180199, 64.24731731414795, 9.118358362466097, 0.5210326728411019, 0.039721287321299314, 0.046220786607591435, 0.01385042934998637, 0.03510564085445367, 0.12594689877005294, 0.020777496611117385, 0.02360049278649967, 0.020862275850959122, 0.019016545302292798, 0.016693513607606292, 0.04834515835682396, 0.04263145245204214, 0.03749255476577673, 0.02389324963587569, 0.04658685465983581, 0.023932453586894553, 0.028518475373857655, 0.023957992743817158, 0.03808764216955751, 0.023601437169418205, 0.061499955991166644, 0.0007786769390349946, 0.09274659591028467, 0.02850552489690017, 0.02459753664879827, 0.017596968937141355, 0.022749010058760177, 0.034899130841949955, 0.023523439303971827, 0.04578329426294658, 0.02963778064440703, 0.033238716423511505, 0.0661764177493751, 0.028758239168382715, 0.028677205918938853, 0.03667708660941571, 0.05690913807484321, 0.0893627067853231, 0.016648815908411052, 0.026138426328543574, 0.08457115647615865, 0.034794484308804385, 0.062432728009298444, 0.04664031897846144, 0.031009024642116856, 0.03257557036704384, 0.09552126342896372, 0.04074010765179992, 0.08935336314607412, 0.03254256705986336, 0.03706246163346805, 0.057002311004907824, 0.03392585240362678, 0.0308754269281053, 0.07105946002411656, 0.011883987554028863, 0.019757763438974507, 0.07450566728948615, 0.0394931771006668, 0.014465274580288678, 0.054385472321882844, 0.028896857511426788, 0.06072676056646742, 0.047215446320478804, 0.008046186067076633, 0.04154178299359046, 0.010605111256154487, 0.03118444794381503, 0.023920475323393475, 0.03632870764704421, 0.04658959689550102, 0.007232392381411046, 0.047034473609528504, 0.030778168475080747, 0.03727833754965104, 0.033543557292432524, 0.07711358906817622, 0.03920971750630997, 0.04608183058735449, 0.04074762931850273, 0.020493927549978253, 0.035391234123380855, 0.015123284047149355, 0.03929911290470045, 0.008458906449959613, 0.022857053772895597, 0.01148395140262437, 0.07342757904552855, 0.03519189325743355, 0.04316273370932322, 0.05385395728808362, 0.05386326010921039, 0.042258497269358486, 0.020194645367155317, 0.03796390759816859, 0.09220139938406646, 0.0555312073265668, 0.9973221528343856, 18.919029012322426, 80.04879981279373, 101.70251548290253, 86.87536150217056, 104.45292949676514, 108.24432045221329, 69.41370248794556, 43.59246164560318, 33.90814930200577, 22.21072018146515, 47.61118300259113, 51.469264179468155, 58.15646834671497, 45.7686922699213, 23.8110214099288, 7.027734769508243, 1.2379806954413652, 0.413174718269147, 0.5780118028633296, 0.12736236734781414, 0.019148009341733996, 0.10585664203972556, 0.04658193051000126, 0.263755900086835, 0.3258590551558882, 0.9510867681819946, 0.26543119456619024, 0.5094681121408939, 0.4405142809264362, 0.5121784948278219, 0.4493102745618671, 0.49323244427796453, 0.9316554421093315, 1.2570771644823253, 1.7324555246159434, 1.3428491307422519, 1.3403859129175544, 1.8273949739523232, 0.7600739866029471, 0.8965997700579464, 1.3037082622759044, 0.8959846780635417, 0.45351819251663983, 0.37594502849970013, 0.7837098464369774, 0.6653618125710636, 0.5426235892809927, 0.719855697825551, 0.6331828236579895, 0.3987199970288202, 0.45994014479219913, 0.4406466503860429, 0.15479753346880898, 0.13188646989874542, 0.13686746824532747, 0.03938468995329458, 0.02484410779288737, 0.17282798158703372, 0.21969621040625498, 1.5201592538505793, 12.455109413713217, 35.52643686532974, 66.15077957510948, 66.99357435107231, 53.70548978447914, 36.61737732589245, 30.06388608366251, 35.70460930466652, 37.37983301281929, 77.88359239697456, 114.80687230825424, 94.92705345153809, 96.04423150420189, 94.90436106920242, 104.4747631251812, 86.97952151298523, 19.900465048849583, 0.23458363342797384, 0.10214289795840159, 0.11756659689126536, 0.053344818006735295, 0.11146863660542294, 0.10827043282915838, 0.016732060757931322, 0.00582087713155488, 0.04429638654983137, 0.016039178699429613, 0.1045235147466883, 0.09545805471134372, 0.05738645406381693, 0.0383142532518832, 0.020078016859770287, 0.08704740641405806, 0.02791668081044918, 0.043893548790947534, 0.0017403316633135546, 0.09610568988136947, 0.025380394836247433, 0.07188891395344399, 0.07059099414618686, 0.036040361010236666, 0.0375192089995835, 0.04458940871700179, 0.039624685668968596, 0.09342892648419365, 0.03470311850833241, 0.08340904969372787, 0.07084319819114171, 0.07068368096952327, 0.023130919253162574, 0.044948010763619095, 0.04410510169691406, 0.056040094277705066, 0.04564525850582868, 0.008309360910061514, 0.01940919151820708, 0.007638824454261339, 0.07847499960917048, 0.048817438873811625, 0.07520733823184855, 0.05826294902362861, 0.033578512448002584, 0.07027737738098949, 0.03720638262166176, 0.019070545822614804, 0.006269468294703984, 0.05731763842049986, 0.03291779321443755, 0.16695244295988232, 0.18147478869650513, 0.13353829766856506, 0.14141960913548246, 0.1458842508145608, 0.1346378933521919, 0.06061747932108119, 0.1621431775856763, 0.10999489459209144, 0.15166472032433376, 0.17619311664020643, 0.0729955971473828, 0.14632234058808535, 0.21097656892379746, 0.10953114877338521, 0.1396863826084882, 0.1925312157254666, 0.14998008962720633, 0.12212142435600981, 0.16727472800994292, 0.12729836453218013, 0.20046251825988293, 0.13462300586979836, 0.1297570700990036, 0.08922595123294741, 0.10601051893900149, 0.14740439190063626, 0.16708438197383657, 0.14217207266483456, 0.1028691562532913, 0.0819783893530257, 0.09242762083886191, 0.10694254509871826, 0.16474366304464638, 0.1484130893368274, 0.09009499874082394, 0.1595264984644018, 0.23064852895913646, 0.16246647195657715, 0.08998303092084825, 0.169021624897141, 0.15412347042001784, 0.14303720905445516, 0.14282363379606977, 0.16667755146045238, 0.4109619010705501, 0.28363969875499606, 1.0775008192285895, 20.405134968459606, 89.32433009147644, 118.06692257523537, 93.28506276011467, 96.2393206357956, 95.48653542995453, 59.81423959136009, 35.380463898181915, 50.51327347755432, 72.93322563171387, 110.68300679326057, 104.80793684720993, 85.91558620333672, 58.170660585165024, 30.930473282933235, 11.733361892402172, 3.2421019300818443, 0.6773166835773736, 0.7636858115438372, 0.27820305142086, 0.3719835332594812, 0.6800337159074843, 0.3511344379512593, 0.390443506767042, 0.6194074940867722, 0.95687510445714, 0.3436599421547726, 0.7379153568763286, 0.6276922370307148, 0.40570951416157186, 0.471572270616889, 0.27732351736631244, 0.46617023705039173, 0.9727264288812876, 0.7544903643429279, 0.4687406506855041, 0.4532627749722451, 0.5707859562244266, 0.2742543804924935, 0.421568289748393, 0.8143603673670441, 0.6241958308964968, 0.239283446862828, 0.21712554444093257, 0.40952563751488924, 0.30246314650867134, 0.5372859444469213, 0.5940224218647927, 0.5413188342936337, 0.5522203305736184, 0.6370539253111929, 0.48160355421714485, 0.5393559427466244, 0.3384261089377105, 0.35685978073161095, 0.16223924118094146, 0.14161501661874354, 0.39607958402484655, 0.2808993333019316, 3.434082828462124, 22.834485210478306, 51.047999784350395, 90.23407727479935, 92.7329295873642, 123.7393569946289, 93.82942914962769, 53.89372408390045, 40.889507085084915, 29.0207489579916, 61.53453268110752, 101.48981049656868, 86.59358382225037, 92.7823193371296, 97.20385327935219, 114.6609677374363, 96.3919660449028, 20.413511618971825, 0.42341941385529935, 0.18819446093402803, 0.21801005088491365, 0.09016590352985077, 0.2282180992187932, 0.17337007593596354, 0.11874972871737555, 0.18423114001052454, 0.1290680156671442, 0.17910990543896332, 0.18150253017665818, 0.19863616704242304, 0.09668426821008325, 0.12310266232816502, 0.1475351583212614, 0.12002105737337843, 0.11332089619827457, 0.12417487276252359, 0.20547952561173588, 0.15067046508193016, 0.10185781677137129, 0.13139592512743548, 0.17802859627408907, 0.15557208331301808, 0.09637018389184959, 0.2125505157164298, 0.17247307172510773, 0.2446096477797255, 0.1542931402218528, 0.1444353410624899, 0.1630386826582253, 0.12288925776374526, 0.11390918924007565, 0.1759755189414136, 0.1340787296066992, 0.12928700860356912, 0.1432440901407972, 0.2331040581339039, 0.14966163405915722, 0.08951872849138454, 0.1748147257603705, 0.21822812355821952, 0.15314278163714334, 0.18390970100881532, 0.13429800455924124, 0.1354064021143131, 0.168298268399667, 0.2124377983273007, 0.1529574376763776, 0.14100347209023312, 0.10093350894749165], [0.0276068953826325, 0.06371633920934983, 0.027638512729026843, 0.014267912465584232, 0.08240269002271816, 0.07365380792180076, 0.033021378476405516, 0.008926371356210439, 0.12863280542660505, 0.01156320813606726, 0.029413661322905682, 0.010522375705477316, 0.05257049822830595, 0.06007931464409921, 0.028209962729306426, 0.021461704818648286, 0.028024399834976066, 0.056025013836915605, 0.02063094656477915, 0.038252885060501285, 0.01283113033423433, 0.0099739721736114, 0.03442043445829768, 0.024809265814838, 0.04930452523694839, 0.008068716742855031, 0.038806798111181706, 0.0099780224445567, 0.025338237137475517, 0.019047665409743786, 0.007663469787075883, 0.008412829283770407, 0.05259909688902553, 0.06640299543505535, 0.0546665125148138, 0.035453340751701035, 0.024031916218518745, 0.05335631016350817, 0.03402310343517456, 0.017634182077017613, 0.03566819250409026, 0.07058482689899392, 0.038615127341472544, 0.04739999618323054, 0.048183574253926054, 0.10333319893106818, 3.9600007329136133, 47.28127710521221, 86.74331098794937, 73.70436385273933, 73.93676698207855, 67.31476351618767, 42.96665042638779, 30.643394887447357, 35.37630312144756, 55.77236607670784, 63.60521636903286, 90.89891999959946, 54.88026514649391, 33.75525310635567, 13.023371770977974, 2.7039990294724703, 0.17075341165764257, 0.15771404025144875, 0.13915607356466353, 0.015334722847910598, 0.1301558260456659, 0.12441481652786024, 0.08033655831241049, 0.12178810356999747, 0.04826523276278749, 0.05134415485372301, 0.06337773433187976, 0.14227080799173564, 0.24708907410968095, 0.05701582551409956, 0.05018391086196061, 0.0315226965904003, 0.5227819446008652, 0.42698136647231877, 0.30660985212307423, 0.19568678311770782, 0.15195429150480777, 0.9401450178120285, 0.8325001189950854, 1.802840216550976, 1.0666704503819346, 0.10103398832143284, 0.1541227728012018, 0.1910439963103272, 0.10651327203959227, 0.1360127961379476, 0.13062072219327092, 0.23569792363559827, 0.035314830020070076, 0.21076385455671698, 0.06126885491539724, 0.04073596646776423, 0.03992860627477057, 0.0834536379261408, 0.020652797247748822, 0.12970348703674972, 0.1733758201589808, 0.0992727605625987, 0.29589861282147467, 0.158052162732929, 0.1766550590400584, 0.13609596120659262, 0.16745898843510076, 0.20961333269951865, 3.929848400875926, 22.97267809510231, 51.32977746427059, 60.78805893659592, 62.69977055490017, 76.89074367284775, 66.14967003464699, 32.292521595954895, 22.747414782643318, 36.80001072585583, 51.396813467144966, 72.10183024406433, 73.13085302710533, 81.90845042467117, 75.96642807126045, 25.13223521411419, 0.740011241286993, 0.5584898160304874, 0.0753668999823276, 0.017700676653475966, 0.011698702965077246, 0.07249899645103142, 0.05812758128740825, 0.059069073540740646, 0.018266773913637735, 0.06745631821104325, 0.05261857084406074, 0.03747662827663589, 0.01705067217699252, 0.054361593720386736, 0.06938041769899428, 0.07593609014293179, 0.02119518660038011, 0.022737232175131794, 0.020171735268377233, 0.04580446402542293, 0.01534663802885916, 0.1172402968222741, 0.037560817509074695, 0.10222402954241261, 0.02851566820027074, 0.09480646389420144, 0.026945701174554415, 0.06331376120215282, 0.03547371270542499, 0.06454861329984851, 0.08185189770301804, 0.01063086099748034, 0.027929989373660646, 0.04751209016831126, 0.05756351936724968, 0.06931139054358937, 0.07097186433384195, 0.032029127032728866, 0.012876154578407295, 0.03143314163025934, 0.04740101292554755, 0.08502832686644979, 0.04106321277504321, 0.04344190369010903, 0.04562387723126449, 0.04702781654486898, 0.027977108329650946, 0.09556398887070827, 0.01701425870123785, 0.060164810056448914, 0.03850502231216524, 0.01772886713297339, 0.027215189838898368, 0.008566465912736021, 0.04690682049840689, 0.059467970495461486, 0.043631993685266934, 0.035607128593255766, 0.01693483405688312, 0.06977563360123895, 0.05172099146875553, 0.04258005130395759, 0.03985613555414602, 0.024813251147861592, 0.02234802581369877, 0.047872996583464555, 0.007263896086442401, 0.023544245414086618, 0.03484192980977241, 0.015932407768559642, 0.0153155782209069, 0.024728295647946652, 0.043271243121125735, 0.05705614268663339, 0.05628692888421938, 0.023912348806334194, 0.01427631636033766, 0.015358791624748847, 0.01717668514174875, 0.05004774902772624, 0.03903528682712931, 0.0050460341390135, 0.03108573302597506, 0.009112297902902355, 0.05205095774726942, 0.036143927718512714, 0.0360248835204402, 0.03283959311374929, 0.013348833072086563, 0.00252201447437983, 0.02946029602753697, 0.07274932286236435, 0.010607658678054577, 0.11863049527164549, 0.01994911508518271, 0.2863689319929108, 8.256117179989815, 63.26390728354454, 103.65688741207123, 87.39258974790573, 88.9041106402874, 98.65799725055695, 72.47377708554268, 50.79308666288853, 35.0836656242609, 28.02646581083536, 42.910523638129234, 76.51813566684723, 57.91276082396507, 38.7644749134779, 16.16235863417387, 3.0017657764256, 0.20904781616991386, 0.3158562403405085, 0.0536043359170435, 0.05430549106677063, 0.1851916720625013, 0.0887170754140243, 0.1428053918061778, 0.45820046158041805, 0.23945992958033457, 0.39074288913980126, 0.36680135352071375, 0.6366162956692278, 0.897741133812815, 0.5076494347304106, 1.0148812481202185, 0.6476254924200475, 2.2157898265868425, 1.6168466093949974, 1.4016184397041798, 1.5234024985693395, 3.463128232397139, 6.347494320943952, 6.857619797810912, 8.413895163685083, 5.687577556818724, 2.7731838170439005, 1.7854787106625736, 1.08703842619434, 1.8033506954088807, 1.4808393199928105, 1.6179869044572115, 1.535051129758358, 0.9339642932172865, 1.2653203471563756, 0.747737770434469, 0.5421236192341894, 0.3235315316123888, 0.7589262106921524, 0.458273459225893, 1.042485460639, 0.8942787477280945, 0.17611940653296188, 0.06934337710845284, 0.20500061771599576, 0.44743777660187334, 0.18644924130057916, 0.10197758456342854, 0.1821056884364225, 4.044561870396137, 25.971672870218754, 60.58658994734287, 48.859286829829216, 36.151655316352844, 41.1398870497942, 33.69624227285385, 34.37593840062618, 40.76868116855621, 68.04501593112946, 82.00625717639923, 100.58237358927727, 90.0496655702591, 90.62359437346458, 92.56814002990723, 41.05711229145527, 3.1711433501914144, 0.3170687612146139, 0.16194443043787032, 0.08151191243086942, 0.042701184647739865, 0.022040735857444815, 0.1429725086200051, 0.029996059856784996, 0.06046493457688484, 0.050771621317835525, 0.12453419098164886, 0.05269279303320218, 0.05092022896860726, 0.013886896631447598, 0.09193182166200131, 0.037323923970689066, 0.011545674897206482, 0.04813387633475941, 0.06312908517429605, 0.029739161727775354, 0.02402668964350596, 0.08673656528117135, 0.013090897791698808, 0.03204130567610264, 0.009501654549239902, 0.021294858888722956, 0.01693135709501803, 0.04773891647346318, 0.025637766084400937, 0.03611590793298092, 0.05066478915978223, 0.03604397898016032, 0.02446630267513683, 0.07731181671260856, 0.03403050264751073, 0.04211895866319537, 0.07853580376831815, 0.017569665324117523, 0.023892349781817757, 0.036718784176628105, 0.00800088258984033, 0.04814953565073665, 0.04628580987628084, 0.059620184983941726, 0.041285022161901, 0.0481088251399342, 0.06554395949933678, 0.02329220649698982, 0.030799657361058053, 0.02367137716646539, 0.11336998184560798, 0.1340625507873483, 0.10380366118624806, 0.13089304586173967, 0.1665602921275422, 0.19098227930953726, 0.19316799327498302, 0.07656376154045574, 0.2170124856638722, 0.12785283790435642, 0.13987730751978233, 0.13061511155683547, 0.1250231623998843, 0.10965454566758126, 0.13517868152121082, 0.08085097055300139, 0.11999382797512226, 0.13866456400137395, 0.1783047939534299, 0.12053708007442765, 0.0669486892002169, 0.13227088755229488, 0.08503893957822584, 0.10748979737400077, 0.09736482505104505, 0.10031308091129176, 0.13539583393139765, 0.0688367203110829, 0.09057415154529735, 0.17269022413529456, 0.12681378662819043, 0.15737642243038863, 0.29186857282184064, 0.15997089649317786, 0.23307613853830844, 0.1314206386450678, 0.0952738759224303, 0.21075410273624584, 0.0910907902289182, 0.17608927533729002, 0.09115303415455855, 0.17396100360201672, 0.07712150778388605, 0.21783285570563748, 0.08902790912543423, 0.41809376212768257, 7.952907225117087, 70.43825671076775, 120.54103061556816, 93.20235639810562, 91.33616253733635, 91.3705050945282, 53.28766420483589, 37.76586949825287, 52.300423979759216, 89.55810874700546, 90.12181609869003, 122.85285696387291, 80.50319463014603, 54.42325986921787, 23.496174104511738, 5.14045394025743, 0.7371467887423933, 0.8373223571106791, 0.21159197262022644, 0.1963321547373198, 0.4862710100132972, 0.3085115016438067, 0.3370447049383074, 0.3313092392636463, 0.22980114474194124, 0.24643838871270418, 0.4201171832391992, 0.5156882002484053, 0.6658663542475551, 0.20351351704448462, 0.3696459758793935, 0.21663324820110574, 0.9257743670605123, 1.2289726850576699, 0.5993663601111621, 0.5315439775586128, 1.6679130191914737, 2.6895393803715706, 2.982860365882516, 3.796495031565428, 3.3442948339506984, 1.8332932074554265, 0.5679113510996103, 0.5575536412652582, 0.6743803317658603, 0.6905415770597756, 0.44249542930629104, 0.5116326897405088, 0.2921175485244021, 0.5065225576981902, 0.33698334416840225, 0.1730154629331082, 0.11433181265601888, 0.43956768640782684, 0.3372159629361704, 0.5980757356155664, 0.45668579754419625, 0.4699035960948095, 0.5478128045797348, 0.5555315560195595, 0.6175890541635454, 0.29375680431257933, 0.3875955002149567, 0.3904536890331656, 8.071190603077412, 40.840079337358475, 83.26545640826225, 90.5772976577282, 85.77243268489838, 107.94957026839256, 91.88875168561935, 47.16066017746925, 31.463523879647255, 48.39767999947071, 63.68034593760967, 94.34896767139435, 94.0856646001339, 100.877306163311, 107.78262242674828, 44.59000691771507, 2.373372120782733, 1.0266711842268705, 0.18561281118309125, 0.1677067470154725, 0.15779560228111222, 0.15250682045007125, 0.24446337047265843, 0.25537343113683164, 0.16928447876125574, 0.23790003906469792, 0.23568744451040402, 0.09123536059632897, 0.18827148101991042, 0.18951336125610396, 0.23303107533138245, 0.1470375483040698, 0.10434212643303908, 0.16099976550322026, 0.1526718444074504, 0.10798053510370664, 0.14119059720542282, 0.27214190165977925, 0.11201414483366534, 0.19911305629648268, 0.07034604088403285, 0.21684850071324036, 0.08567205091821961, 0.11511769509525038, 0.11853754869662225, 0.11171648424351588, 0.12858907808549702, 0.09037156007252634, 0.09109103513765149, 0.23474542162148282, 0.17995525617152452, 0.19743442215258256, 0.21949456888251007, 0.15702614356996492, 0.13692448002984747, 0.1497879475937225, 0.07995034466148354, 0.17822672001784667, 0.10942479158984497, 0.15613804513122886, 0.12369342672172934, 0.14775419578654692, 0.13200168090406805, 0.1711023843381554, 0.11140364673337899, 0.27265451790299267], [0.06337690312648192, 0.05136988140293397, 0.04949217356625013, 0.010139047153643332, 0.013925081984780263, 0.029226873884908855, 0.03445889626163989, 0.01717904888209887, 0.0303305606576032, 0.028356781804177444, 0.04265755007509142, 0.08377342936000787, 0.0484452740784036, 0.019206347715226002, 0.03405274481337983, 0.0415595685626613, 0.08976551485829987, 0.07176174694905058, 0.03705615708895493, 0.018757669349724893, 0.061788009479641914, 0.03449791838647798, 0.023961248916748445, 0.03839516590232961, 0.021929452668700833, 0.04422196027007885, 0.08090867995633744, 0.037005368212703615, 0.019295195779704954, 0.17498503380920738, 0.009506858859822387, 0.014420364441320999, 0.04143608261074405, 0.026815211203938816, 0.05505932756932452, 0.051654094277182594, 0.0903454958461225, 0.044013134756824, 0.028785540926037356, 0.01590720443346072, 0.03260038036387414, 0.05500030456460081, 0.06819184593041427, 0.25368272967170924, 0.25151417416054755, 25.177412889897823, 87.57475957274437, 88.3243453502655, 70.23973256349564, 85.9355579316616, 77.08144024014473, 26.50562971830368, 43.44148054718971, 56.90530568361282, 51.49610213935375, 60.16000583767891, 49.16520841419697, 25.731345266103745, 7.616355009377003, 0.16925422882195562, 0.4077139956643805, 0.4158223746344447, 0.0674410819192417, 0.02932582257926697, 0.16827940300572664, 0.04724997474113479, 0.2540121541824192, 0.09842341707553715, 0.24659223592607304, 0.14896863140165806, 0.20968205557437614, 0.20878086565062404, 0.17039450904121622, 1.0319792618975043, 0.33705640118569136, 0.8929506002459675, 1.050326933618635, 1.2478783330880105, 1.1381260911002755, 2.503948314115405, 3.808381981216371, 1.898073556367308, 8.509707022458315, 7.621989632025361, 9.310155920684338, 12.711206171661615, 4.885068219155073, 5.226076170802116, 4.628654178231955, 2.0860681124031544, 2.73704229388386, 2.8976869862526655, 3.574680034071207, 1.265965481288731, 1.421919681597501, 1.5448500914499164, 0.4544259875547141, 0.26253485935740173, 0.47152759332675487, 0.23561585694551468, 0.1828219203162007, 0.05961617367574945, 0.07770988988340832, 0.10259809423587285, 0.03528721470502205, 0.0689308691653423, 0.11022081918781623, 0.023684615225647576, 0.3598979255184531, 0.10154664167203009, 0.2020599614479579, 0.05221323575824499, 3.536639562807977, 30.348604805767536, 59.190218076109886, 65.60889065265656, 93.1651183962822, 66.29183560609818, 54.47850130498409, 30.411656722426414, 36.80541783571243, 54.38101373612881, 61.137666776776314, 64.48956951498985, 73.33668038249016, 90.47847256064415, 61.16589546203613, 18.226301483809948, 0.42386099172290415, 0.4281707026530057, 0.0529411304887617, 0.07429572855471633, 0.03391586309589911, 0.07185332797234878, 0.036798149449168704, 0.08882662383257411, 0.023362595493381377, 0.01130549086155952, 0.053091730806045234, 0.0741099170409143, 0.07332776760449633, 0.03348419661051594, 0.038682399317622185, 0.052821548233623616, 0.02949248668301152, 0.07613476307597011, 0.01203759264171822, 0.06518044072436169, 0.035517651558620855, 0.033807145882747136, 0.05037973023718223, 0.045153058745199814, 0.08163691236404702, 0.05026305349019822, 0.07931816842756234, 0.041161573317367584, 0.028238103113835678, 0.007053064455249114, 0.013428807833406609, 0.03285815051640384, 0.0603580022288952, 0.045203539630165324, 0.007991172515176004, 0.08068317838478833, 0.04248246630595531, 0.016405478672822937, 0.0875713255663868, 0.04522875038674101, 0.05903639306779951, 0.01563218862429494, 0.012166004598839208, 0.0506298933760263, 0.009720485140860546, 0.037243720071273856, 0.027552482970349956, 0.03869032174407039, 0.0848268337722402, 0.033300066061201505, 0.06974875301239081, 0.023503349366365, 0.04559079970931634, 0.04269609351467807, 0.04212966043269262, 0.01768487818480935, 0.03471377945970744, 0.046306244912557304, 0.021853807411389425, 0.037175787583692, 0.03922642696124967, 0.06355568650178611, 0.012358468538877787, 0.05252707145700697, 0.0456338999356376, 0.04156912000325974, 0.04523176721704658, 0.07493022028938867, 0.042104676031158306, 0.05615518653939944, 0.06310126947937533, 0.024928169004851952, 0.04076787881786004, 0.043420600341050886, 0.06981483384151943, 0.010558370795479277, 0.016078315857157577, 0.14932894409867004, 0.049677959104883485, 0.02359255922783632, 0.039611030151718296, 0.03285410210082773, 0.00451995162620733, 0.05316794937243685, 0.05600747688731644, 0.08154723123880103, 0.016473758114443626, 0.049495999337523244, 0.03753247860004194, 0.02167794809793122, 0.028806922200601548, 0.27645383903291076, 1.1297505092807114, 40.88152751326561, 109.31104481220245, 102.15013906359673, 86.39854788780212, 127.20583498477936, 109.97905656695366, 41.89435936510563, 31.041883304715157, 27.442336454987526, 27.21446268260479, 48.29366818070412, 51.37749530375004, 33.64523001015186, 8.436647392809391, 0.4301126062637195, 0.8678331167902797, 0.36819261324126273, 0.10673600540030748, 0.15320607199100778, 0.5245255760382861, 0.37510319554712623, 0.86299556074664, 0.5582011502701789, 1.7036956991069019, 1.3883741316385567, 1.453880954068154, 2.1745765255764127, 4.034211225807667, 4.249511947855353, 3.0925070447847247, 3.8906535040587187, 5.9545426815748215, 6.898858034983277, 5.247100442647934, 6.087402077391744, 8.141108751296997, 6.96491084061563, 8.245657291263342, 13.459975942969322, 12.708618510514498, 14.206500984728336, 10.854308512061834, 9.835759866982698, 8.632754869759083, 9.445422012358904, 9.702444020658731, 10.336975771933794, 5.869939746335149, 5.14575750567019, 4.159570299088955, 6.2025354243814945, 4.6892082039266825, 2.298978050239384, 3.61978598870337, 1.8831517570652068, 1.0968207637779415, 0.12719078280497342, 0.698949754005298, 0.8972808241378516, 0.2476913417922333, 0.27060417167376727, 0.4114563495386392, 0.3018068504752591, 0.5528993660118431, 0.14367334835696965, 0.13411251216894016, 0.0736175020574592, 2.632710342295468, 30.360927544534206, 59.81736682355404, 56.633996441960335, 77.4047800898552, 42.02159933745861, 36.58534124493599, 25.140454173088074, 49.25659351050854, 89.36219125986099, 92.40634471178055, 88.89100894331932, 88.5440343618393, 103.5150334239006, 89.88697350025177, 34.11801964044571, 2.0164503855630755, 0.39038544113282114, 0.03232332550396677, 0.026393834596092347, 0.0030900580168236047, 0.02092127102514496, 0.08067770133493468, 0.05887282743060496, 0.0827483601460699, 0.025442161932005547, 0.025208596925949678, 0.05973230494419113, 0.04971735972503666, 0.03295847403933294, 0.07750205142656341, 0.021897000406170264, 0.012721563361992594, 0.032890689981286414, 0.029721661885560025, 0.019907918467652053, 0.03992751160694752, 0.031596009648637846, 0.032603968647890724, 0.013532546163332881, 0.020686229145212565, 0.014667999639641494, 0.11595091171329841, 0.03334211985929869, 0.013951082200946985, 0.021582222179858945, 0.03448025898251217, 0.03536455020366702, 0.016289056111418176, 0.0421062048553722, 0.01837375821196474, 0.06873347272630781, 0.03826692278380506, 0.03871240434818901, 0.05551395610382315, 0.04572896163153928, 0.05448260089906398, 0.01534878283564467, 0.03177939805027563, 0.0437591940863058, 0.0134856665499683, 0.038606830130447634, 0.07653513690456748, 0.04589325086271856, 0.1694100204622373, 0.13463991199387237, 0.17847103503299877, 0.12876933091320097, 0.1650851548765786, 0.16098514519399032, 0.1742530387127772, 0.09570975409587845, 0.12696781195700169, 0.1390138186980039, 0.17324757704045624, 0.12168419547379017, 0.17814288701629266, 0.19946188054746017, 0.15354140399722382, 0.19249528093496338, 0.3049100667703897, 0.1555823694798164, 0.1287438307190314, 0.13607242028228939, 0.13572457566624507, 0.12079597829142585, 0.10485223421710543, 0.14758534234715626, 0.18672451871680096, 0.12932427925989032, 0.1263596219359897, 0.08837651868816465, 0.08814634900772944, 0.3708645823644474, 0.09640497577493079, 0.11138395755551755, 0.31046673422679305, 0.12031770864268765, 0.1957063312875107, 0.21356348792323843, 0.2905908616958186, 0.2844744367757812, 0.12650589924305677, 0.1286369317676872, 0.14879602269502357, 0.2187871388741769, 0.09452333455556072, 0.4937122279079631, 1.0186132416129112, 45.727928057312965, 123.02580088376999, 115.12230858206749, 87.69610986113548, 109.45355236530304, 98.34092706441879, 37.5367645919323, 64.04496297240257, 86.41941636800766, 81.95566669106483, 95.53820505738258, 75.27259290218353, 41.47864647209644, 14.860363248735666, 0.6186865421477705, 1.1227866704575717, 0.6439489522017539, 0.19131853157887235, 0.3831683815224096, 0.5307262495625764, 0.3079224145039916, 0.5222022975794971, 0.37613157473970205, 0.6848393299151212, 0.3970125230262056, 0.6149991962593049, 0.9947023121640086, 2.208154136314988, 2.991507751867175, 2.1108328085392714, 3.054966959170997, 2.8641924960538745, 4.699439154937863, 5.410436103120446, 8.030236400663853, 9.771870095282793, 10.664562843739986, 19.91470668464899, 19.735107421875, 24.749998524785042, 30.661050640046597, 15.335439406335354, 15.455667804926634, 10.382526777684689, 12.582567874342203, 11.950780525803566, 7.162226652726531, 9.150413442403078, 4.264157311990857, 2.835154691711068, 4.499360416084528, 2.559330342337489, 1.0863253707066178, 1.3507213583216071, 0.8914542524144053, 0.4087984812213108, 0.30283190484624356, 0.2313542371848598, 0.48677427519578487, 0.22342343931086361, 0.15732631261926144, 0.226562857569661, 0.42446035018656403, 0.74078414356336, 0.24253605748526752, 0.48388880502898246, 0.12865646509453654, 5.844041761010885, 48.75065065920353, 89.82982456684113, 96.47201254963875, 123.24015498161316, 90.14856666326523, 73.67573618888855, 42.70551323890686, 49.39233362674713, 65.2612017095089, 78.92392337322235, 89.1255247592926, 93.49253162741661, 118.38279962539673, 99.07507047057152, 34.74731147289276, 1.230673212558031, 0.8173545473255217, 0.17991813394473866, 0.11792059391154908, 0.2350164984818548, 0.13688199949683622, 0.17871615156764165, 0.22257676755543798, 0.14406169939320534, 0.10027601805632003, 0.15739404101623222, 0.16543433535844088, 0.19352088449522853, 0.10804631165228784, 0.1578872575191781, 0.0880599333322607, 0.17833179328590631, 0.10703277541324496, 0.10459667566465214, 0.09766363597009331, 0.18162839842261747, 0.1691671006847173, 0.09739445900777355, 0.1441373984562233, 0.16152042662724853, 0.1127965614432469, 0.26359132141806185, 0.14750996982911602, 0.07979392961715348, 0.07577125172247179, 0.1671004865784198, 0.09082930933800526, 0.08673177100718021, 0.18719260609941557, 0.10508976600249298, 0.3264927305281162, 0.1056221679027658, 0.10049262127722614, 0.2488487062510103, 0.22313550085527822, 0.10836556873982772, 0.08494655703543685, 0.094116489199223, 0.1610875764163211, 0.14357893232954666, 0.11368475636118092, 0.18346629745792598, 0.1304657617583871], [0.03321680080262013, 0.05432814512460027, 0.010646587106748484, 0.012415640812832862, 0.01813221326301573, 0.017741092160576954, 0.0321876497764606, 0.024541027669329196, 0.06004690505506005, 0.03860298951622099, 0.06712840768159367, 0.05512432486284524, 0.061612591744051315, 0.07914679910754785, 0.023155521448643412, 0.0203607268849737, 0.05248265020782128, 0.02567594958236441, 0.023035543999867514, 0.05921084972214885, 0.02146854927559616, 0.0328125455416739, 0.06763215526007116, 0.04881750195636414, 0.00688833735694061, 0.04356011297204532, 0.00953006581767113, 0.03597919690946583, 0.022812161259935237, 0.05872706591617316, 0.053516621483140625, 0.022023679448466282, 0.03130609336949419, 0.03409591554373037, 0.052259935400797985, 0.033155748024000786, 0.08039667969569564, 0.04938766061968636, 0.05439003281935584, 0.03443573754339013, 0.04678528268414084, 0.23758591763908044, 0.12071519551682286, 13.907159697264433, 57.36231856048107, 92.56773725152016, 69.35963898897171, 71.18651255965233, 64.09758254885674, 37.290116026997566, 36.64842166006565, 49.3062986433506, 62.582037672400475, 67.57194131612778, 57.740804851055145, 40.92551775276661, 13.410073220729828, 0.7734388788230717, 0.5553502344992012, 0.07573457478429191, 0.1091260919929482, 0.2144469108316116, 0.15893120697000995, 0.04343396270996891, 0.055216892942553386, 0.0721351733955089, 0.07609586711623706, 0.20276412600651383, 0.5844646284822375, 1.255056622903794, 0.9855253295972943, 1.0502645932137966, 2.29678675532341, 1.5080774459056556, 2.845818819478154, 4.76576934568584, 5.536189405247569, 3.8196308026090264, 8.68973471224308, 3.8037825655192137, 4.992810012772679, 5.992083717137575, 8.486268930137157, 15.681657828390598, 18.499617017805576, 23.30659657716751, 9.592849351465702, 4.73731504753232, 7.530033141374588, 2.564674518071115, 8.913407810032368, 7.7693395502865314, 10.521045494824648, 5.693752700462937, 6.7335692793130875, 4.005584511905909, 4.17664990760386, 4.537691809237003, 2.321327975951135, 1.7618018249049783, 1.574219784233719, 2.3260432854294777, 1.7707123467698693, 0.541789474664256, 0.35186901572160423, 0.36451660736929625, 0.5421020078938454, 0.09549726979457773, 0.096428167889826, 0.13412414904450998, 0.129207183199469, 0.125372298352886, 0.11606083120568655, 0.438887226046063, 3.517060875892639, 29.45237159729004, 46.36693976819515, 67.41257786750793, 76.83275878429413, 92.2729642689228, 74.01071101427078, 24.454731568694115, 28.01521461457014, 50.49609459936619, 65.96070617437363, 54.2023853212595, 62.560865208506584, 70.62956884503365, 52.114598751068115, 7.344775982201099, 0.5158673843834549, 0.0025327213461423526, 0.03563638776540756, 0.022417485270125326, 0.037036330613773316, 0.0441674829198746, 0.051955851522507146, 0.05571319306909572, 0.04402150618261658, 0.008815680957923178, 0.13715053821215406, 0.11015559924999252, 0.04829678888199851, 0.06750607921276242, 0.0014784595214223373, 0.01934079518832732, 0.04471196327358484, 0.05010854576539714, 0.09073039589566179, 0.03286688559455797, 0.048743717634351924, 0.030643438985862304, 0.02904541506723035, 0.06024191177857574, 0.009229359638993628, 0.008407446857745526, 0.022971761973167304, 0.051006678040721454, 0.014405701458599651, 0.06336847232887521, 0.025414110605197493, 0.053100395380170085, 0.017262553483305965, 0.04574156329908874, 0.03384241274034139, 0.04921492203720845, 0.023680789454374462, 0.02491014780389378, 0.029696150559175294, 0.014388392719411058, 0.014797654694120865, 0.11299648118438199, 0.03775889301323332, 0.024505879555363208, 0.0062350224379770225, 0.034333926014369354, 0.048156860648305155, 0.048360702639911324, 0.038813703795312904, 0.05479440682393033, 0.04970229412720073, 0.023167013605416287, 0.07267703767865896, 0.021259169006953016, 0.06377790778060444, 0.04267214440915268, 0.04872924204391893, 0.054544985832762904, 0.020264898921595886, 0.07780463245580904, 0.04766786325490102, 0.021402154889074154, 0.0781356896914076, 0.0219396182365017, 0.028693330932583194, 0.06816531415097415, 0.023615760619577486, 0.0386793416691944, 0.052680499356938526, 0.07023405079962686, 0.041483101376798004, 0.023026729140838142, 0.019755338471441064, 0.023824730851629283, 0.022095302265370265, 0.04263636175892316, 0.0923089291609358, 0.013485948566085426, 0.07734532468020916, 0.03306408536445815, 0.10885415424127132, 0.03543474624166265, 0.11063997677410953, 0.0668710086029023, 0.001775486155111139, 0.11632883557467721, 0.046250016093836166, 0.2108089771354571, 0.7541762280743569, 22.599874399602413, 78.80897954106331, 106.04396492242813, 79.35526102781296, 106.36894628405571, 98.5113175213337, 53.10993254184723, 41.21202617883682, 28.068582750856876, 40.587085112929344, 55.73932684957981, 60.548439994454384, 47.288568913936615, 16.790383234620094, 0.6652902695350349, 0.9487700799945742, 0.12297493129153736, 0.12526667589554563, 0.2774671377846971, 0.44846214819699526, 0.5831430712714791, 0.57853112812154, 0.6104745890479535, 0.6461822229903191, 1.5963003993965685, 2.6426973938941956, 3.6818487709388137, 4.85923245549202, 3.07584042660892, 3.65099870134145, 8.031877912580967, 5.6826933939009905, 4.367483267560601, 8.25811967253685, 8.592900708317757, 10.63566254451871, 9.987120945006609, 8.74529818072915, 9.14919275790453, 14.37221484258771, 20.98953600972891, 20.641860365867615, 23.33156693726778, 14.203518144786358, 10.034728590399027, 6.403120961040258, 12.110961880534887, 7.13361038826406, 13.407908286899328, 19.032494723796844, 11.291339211165905, 14.217671435326338, 12.92071457952261, 11.902693156152964, 7.276932997629046, 6.794081032276154, 4.182063192129135, 4.034536108374596, 4.545219205319881, 2.6683156192302704, 1.456285275053233, 0.7589306635782123, 0.7067847554571927, 0.4486337921116501, 0.19830398174235597, 0.5027669342234731, 0.1647514259093441, 0.16573163971770555, 0.13987001962959766, 0.12909547513118014, 0.5299924733117223, 3.592002592049539, 29.865650720894337, 46.12512454390526, 45.37211894989014, 53.99192601442337, 44.25320819020271, 41.027139499783516, 20.51337406039238, 46.9404049962759, 78.92016157507896, 89.21912133693695, 78.32990124821663, 69.56456199288368, 86.08770176768303, 75.84782123565674, 17.84182481467724, 0.0899044523248449, 0.047563632324454375, 0.030733964304090478, 0.08471698849461973, 0.047326234125648625, 0.13167322118533775, 0.023709916895313654, 0.03500752151012421, 0.0893938250374049, 0.08568142424337566, 0.029350224394875113, 0.02025348469032906, 0.01735677655233303, 0.05816333054099232, 0.034003046894213185, 0.044036055987817235, 0.029663355053344276, 0.07449215278029442, 0.04054576886119321, 0.019681455814861692, 0.10116132601979189, 0.06785284771467559, 0.04670530142902862, 0.08670791095937602, 0.022964787640376016, 0.029385988491412718, 0.015728753169241827, 0.030969768740760628, 0.0397700686880853, 0.010445146890560864, 0.043390795690356754, 0.0611266668420285, 0.0321368349250406, 0.04804264412086923, 0.02280367294588359, 0.019273953657830134, 0.07004323721048422, 0.09680267045041546, 0.009355522888654377, 0.020114421058679, 0.017649346009420697, 0.038552196929231286, 0.04275503859389573, 0.0407959950825898, 0.0547192309750244, 0.009912953719322104, 0.14990473195211962, 0.17113567708292976, 0.1783663031528704, 0.12201215053210035, 0.09478523847064935, 0.06149210406874772, 0.1705054601188749, 0.09470554665313102, 0.20491537463385612, 0.10102532003656961, 0.1503955587395467, 0.12331580714089796, 0.16795147763332352, 0.21156136645004153, 0.1067055921885185, 0.1369032694492489, 0.14359423541463912, 0.10015333362389356, 0.18428274895995855, 0.17163025913760066, 0.1695400447351858, 0.178734794317279, 0.14843330543953925, 0.13365019869524986, 0.1685929307132028, 0.14338978857267648, 0.10961638443404809, 0.14351961988722906, 0.132254263444338, 0.16839298128616065, 0.20393424056237563, 0.09223007597029209, 0.11335136136040092, 0.13321856560651213, 0.20708529569674283, 0.09733861981658265, 0.30100049218162894, 0.14191579422913492, 0.259891715249978, 0.2219795316341333, 0.22609643259784207, 0.32969319785479456, 0.7640874618664384, 24.11095641553402, 91.5352338552475, 120.59254065155983, 85.71244150400162, 88.0952176451683, 85.30280068516731, 47.16985568404198, 48.98373395204544, 78.34155142307281, 99.35293436050415, 107.09218427538872, 87.83104062080383, 65.47655895352364, 25.335727594792843, 2.8131415229290724, 1.5771754318848252, 0.19099056167760864, 0.8515598368830979, 0.529163108440116, 0.37177501944825053, 0.3208593843737617, 0.23852271580835804, 0.27300433663185686, 0.3380039456533268, 0.8846178255043924, 1.3003994710743427, 2.6536683551967144, 4.710432440042496, 5.701872389763594, 7.3108993750065565, 6.706549404188991, 9.23275787383318, 15.280212219804525, 14.29973753169179, 15.806470680981874, 21.443320959806442, 15.312741324305534, 18.607789613306522, 20.905085541307926, 23.191194869577885, 38.30415241420269, 41.70760318636894, 45.59490479528904, 28.199970200657845, 17.993421480059624, 27.213651426136494, 20.0299222022295, 25.578827150166035, 21.588558666408062, 28.211246095597744, 20.984026305377483, 23.165772333741188, 21.428705044090748, 18.784596025943756, 13.684992268681526, 10.079535786062479, 9.385996051132679, 5.003190580755472, 8.279662616550922, 4.960487047210336, 1.95738825481385, 1.410423160996288, 1.4704652829095721, 0.9768689784687012, 0.2197495856671594, 0.15638077195035294, 0.21757476642960683, 0.34952973655890673, 0.27671572810504586, 0.223729174467735, 0.504556578816846, 7.196030588820577, 48.7039777636528, 73.33531245589256, 98.21687132120132, 104.82320442795753, 126.69945135712624, 92.14062497019768, 33.43567505478859, 37.5305937230587, 63.596001863479614, 86.89087986946106, 72.54190742969513, 80.96612378954887, 101.35103434324265, 87.07377925515175, 16.381604969501495, 0.5138186411932111, 0.10373476761742495, 0.11278576319455169, 0.14700909436214715, 0.3265561396256089, 0.28673017979599535, 0.2768907562131062, 0.19176340458216146, 0.21231574472039938, 0.1504990883404389, 0.29298707842826843, 0.21812840859638527, 0.22022358054528013, 0.3013390302658081, 0.20036445086589083, 0.14170524693327025, 0.11744926334358752, 0.17700842523481697, 0.14437786914641038, 0.0694290135288611, 0.14251377229811624, 0.1306911074789241, 0.19174908113200217, 0.11108556966064498, 0.08192594919819385, 0.15343140286859125, 0.0742932794673834, 0.159367946034763, 0.10060444808914326, 0.07684128766413778, 0.11700507311616093, 0.1647859506192617, 0.08187504528905265, 0.09296267220634036, 0.13930457731476054, 0.07656264089746401, 0.13308079331181943, 0.17639894387684762, 0.09864320410997607, 0.07843868632335216, 0.08009101133211516, 0.275279909837991, 0.15992771834135056, 0.11374941226677038, 0.1431080693146214, 0.09987582976464182], [0.032388545441790484, 0.028913286805618554, 0.04165589562035166, 0.04593153455061838, 0.029452854141709395, 0.018289320360054262, 0.060274610805208795, 0.022359219256031793, 0.06939995102584362, 0.07672169056604616, 0.04718921882158611, 0.02015368067077361, 0.061626970855286345, 0.03514156451274175, 0.041911045991582796, 0.04983637794794049, 0.05925037279666867, 0.016442819833173417, 0.02080003006994957, 0.04337519574619364, 0.02793496176309418, 0.051703016652027145, 0.08209147039451636, 0.08290958430734463, 0.007951114166644402, 0.05864339247636963, 0.057475630528642796, 0.010962037904391764, 0.03246386600949336, 0.028076359449187294, 0.053422416967805475, 0.04189902319922112, 0.05301691489876248, 0.009538199756207177, 0.02948600402305601, 0.06215947665623389, 0.11187471012817696, 0.04677327844547108, 0.04041303945996333, 0.16462543891975656, 0.1216928637586534, 8.452820274978876, 57.4446639418602, 95.99698483943939, 79.23323437571526, 77.86565735936165, 81.32336542010307, 50.289644077420235, 43.07125501334667, 60.651703253388405, 57.66186408698559, 58.221235871315, 50.31998924911022, 38.14660146832466, 14.165969509631395, 1.2282222253270447, 0.8885070949327201, 0.08490058840834536, 0.10608083743136376, 0.07435648076352663, 0.24349302722839639, 0.13783623813651502, 0.3359568945597857, 0.09730841440614313, 0.7026001112535596, 0.7200974598526955, 2.771594077348709, 2.3514159489423037, 5.779897877946496, 8.53248205035925, 5.42858867906034, 5.827009174972773, 6.863885661587119, 11.757449749857187, 7.74177772924304, 4.579651532694697, 15.363895129412413, 14.438666626811028, 4.920220132917166, 7.47874871827662, 15.549783054739237, 7.724584126845002, 5.12374053709209, 11.738585662096739, 6.861019665375352, 6.2661397363990545, 8.78079492598772, 9.216386452317238, 8.92456591129303, 11.795366015285254, 8.02284674718976, 19.68835473060608, 5.167899392545223, 8.452357649803162, 6.332194916903973, 12.314735446125269, 11.065020505338907, 4.493188122287393, 11.716674137860537, 6.374835753813386, 5.780494920909405, 6.798316380009055, 8.15837787464261, 3.5832310002297163, 4.406430227681994, 5.344081213697791, 3.1942679593339562, 1.3930342253297567, 2.6924984715878963, 0.79026217921637, 0.2021167060593143, 0.06156989969895221, 0.10448591754538938, 0.2112423616927117, 0.23838733322918415, 0.2404597806162201, 9.867876693606377, 45.71100376546383, 60.31378738582134, 62.19915121793747, 79.87445756793022, 100.63155815005302, 47.23748825490475, 30.052794478833675, 46.776193007826805, 51.058426424860954, 69.36327159404755, 75.61938509345055, 69.9568909406662, 65.12899920344353, 16.926231645047665, 0.46161953592672944, 0.1818207185715437, 0.02584491991001414, 0.027051104698330164, 0.006591079845748027, 0.09164662173134275, 0.0339769492711639, 0.03534288320224732, 0.06645343179116026, 0.06195735273649916, 0.0830770425091032, 0.00346200596595736, 0.04918553298921324, 0.03165896974678617, 0.044792066983063705, 0.058029966603498906, 0.05354699016606901, 0.06973768016905524, 0.03852541653031949, 0.027066370676038787, 0.05886041501071304, 0.06253053565160371, 0.019082067665294744, 0.03080633297940949, 0.03413988779357169, 0.0603531560045667, 0.08181150260497816, 0.02156400430976646, 0.031450140522792935, 0.045018826494924724, 0.06472384178778157, 0.047864573207334615, 0.01484449348936323, 0.03963779941841494, 0.036951169167878106, 0.022636544999841135, 0.02592696804640582, 0.028068405481462833, 0.042264683070243336, 0.038655685712001286, 0.07665845958399586, 0.034259622188983485, 0.049239587315241806, 0.02299710631632479, 0.06569687160663307, 0.06972737173782662, 0.08857379638357088, 0.030374573725566734, 0.0262009429934551, 0.05335422101779841, 0.04832104597880971, 0.03490612929454073, 0.048782713784021325, 0.043106920493301004, 0.021292949713824783, 0.02698109976336127, 0.025126062682829797, 0.08899169231881388, 0.034146207181038335, 0.043446735071484, 0.03795461590925697, 0.009388273865624797, 0.030867949790263083, 0.02917298839747673, 0.03664534866402391, 0.038204467346076854, 0.049816840910352767, 0.0317631821235409, 0.010118947011505952, 0.05200186467845924, 0.057808565397863276, 0.07613785783178173, 0.027601229085121304, 0.031336851679952815, 0.034616550692589954, 0.020162026121397503, 0.011125973687740043, 0.014163614741846686, 0.03979095272370614, 0.08302405316499062, 0.022204141932888888, 0.06634207253227942, 0.09371077932883054, 0.04738522744446527, 0.2486343146301806, 0.13264313398394734, 16.454196274280548, 78.1304195523262, 114.41424697637558, 92.79893964529037, 101.4874242246151, 117.51567095518112, 66.76427945494652, 40.397771671414375, 30.830977521836758, 38.157461285591125, 55.195294842123985, 52.68112175166607, 46.87584646046162, 16.95476621389389, 1.4632302336394787, 0.8870368113275617, 0.16907887416891754, 0.13009468792006373, 0.07379908332950436, 0.7858049590140581, 0.3458163561299443, 0.7767545571550727, 0.6208007724490017, 1.7094330349937081, 1.5775526803918183, 2.3914254270493984, 1.6728708031587303, 3.3394914167001843, 3.0821200646460056, 0.5319838633295149, 0.2442478804732673, 2.8720875224098563, 6.189779983833432, 2.645541066303849, 4.9539100751280785, 2.3441440891474485, 2.1180474339053035, 4.629655899479985, 9.715886749327183, 24.004343636333942, 14.559611286967993, 14.286170359700918, 19.605251289904118, 17.84819707274437, 10.572333242744207, 4.528001379221678, 2.311024353839457, 0.9383177314884961, 2.6562809525057673, 4.112269962206483, 7.093163458630443, 10.816629733890295, 16.32971115410328, 12.1640963293612, 10.270144958049059, 6.143349325284362, 3.810280691832304, 0.35180890175979584, 1.3695926894433796, 2.764752544462681, 3.7944980012252927, 3.5585299506783485, 2.4488301342353225, 1.2152871256694198, 0.7823539723176509, 1.341764407698065, 0.7021633128169924, 1.1077931500039995, 1.9135323143564165, 1.4005974819883704, 0.15954778325976804, 0.16845266480231658, 0.2531174209434539, 0.24890488683013245, 0.10972881980706006, 9.551826752722263, 49.489767998456955, 51.64375081658363, 62.927978709340096, 50.56743957102299, 52.117676585912704, 27.079735212028027, 35.21997570991516, 80.88944390416145, 90.19001483917236, 108.0125404894352, 98.42434018850327, 83.0950203537941, 85.02835661172867, 35.95053970813751, 1.6367080248892307, 0.09771161581738852, 0.05072923726402223, 0.04003531597845722, 0.18360812187893316, 0.11559118531295098, 0.04597638253471814, 0.034544796144473366, 0.034616424527484924, 0.062207300652517006, 0.028220510503160767, 0.016785320985945873, 0.027591605285124388, 0.021978044787829276, 0.08433516093646176, 0.06714917297358625, 0.02091246915369993, 0.052660427973023616, 0.02332451032998506, 0.04509927530307323, 0.015910122929199133, 0.059492023501661606, 0.07651511376025155, 0.0679167392081581, 0.05655534885590896, 0.040273797712870874, 0.06669510476058349, 0.0112456283022766, 0.070717025664635, 0.01644935444346629, 0.0336515657545533, 0.04905656256596558, 0.0349210316198878, 0.029341884510358796, 0.043919186282437295, 0.01344439293461619, 0.03528746703523211, 0.013265838697407162, 0.017639007892285008, 0.06297077023191378, 0.0385609134536935, 0.04049139541166369, 0.029475851442839485, 0.029664180692634545, 0.015924275685392786, 0.17060176120139658, 0.17525376548292115, 0.13312989380210638, 0.2375071163987741, 0.10060041822725907, 0.1087839099636767, 0.19897690188372508, 0.10308575205272064, 0.14146629022434354, 0.1598405753611587, 0.11912364498130046, 0.174002370913513, 0.20525075116893277, 0.1556146825896576, 0.08014947772608139, 0.1433699287008494, 0.10408787406049669, 0.12960381660377607, 0.16174258111277595, 0.11451274825958535, 0.07569712601252832, 0.10320034707547165, 0.25723016588017344, 0.13113586173858494, 0.13952374836662784, 0.11320601173792966, 0.17534651909954846, 0.15167450183071196, 0.12415523553499952, 0.1165511978615541, 0.12957218626979738, 0.1661495430744253, 0.10093144577695057, 0.1345216581830755, 0.16020629089325666, 0.20322541531641036, 0.42085072200279683, 0.22013516107108444, 0.13031336915446445, 0.3760693233925849, 0.19557492661988363, 18.94119132310152, 89.40522775053978, 130.91071218252182, 100.06858795881271, 96.9906011223793, 106.33741557598114, 64.95197430253029, 56.30008175969124, 89.94575634598732, 88.64326983690262, 90.84762275218964, 77.27464467287064, 59.611026495695114, 24.400476180016994, 2.537886193022132, 1.508096088655293, 0.360764991492033, 0.5173837405163795, 0.12441142491297796, 0.8115690608974546, 0.2972538932226598, 0.6698212889023125, 0.6539323227480054, 2.83387653529644, 3.732254966162145, 7.682103831321001, 9.017208740115166, 16.953303292393684, 24.5236636698246, 23.12272634357214, 21.029794849455357, 26.162445433437824, 30.50976935774088, 19.543303214013577, 20.381338745355606, 31.308718286454678, 27.463716007769108, 19.578707814216614, 21.913965605199337, 34.06037673354149, 19.053695686161518, 24.23672776669264, 29.133574403822422, 29.144628010690212, 30.20902119576931, 31.0242560505867, 27.1578324213624, 28.360230401158333, 28.291286900639534, 27.960628643631935, 39.33161348104477, 17.352321781218052, 24.429470524191856, 23.764074929058552, 27.495928779244423, 29.574487544596195, 21.888839453458786, 27.172113955020905, 20.78768514096737, 19.96131308376789, 24.861256554722786, 21.88826948404312, 14.81097349897027, 9.309445358812809, 8.730926401913166, 4.866362772881985, 4.362570606172085, 4.889817964285612, 1.7041503684595227, 0.5752397328615189, 0.140479278343264, 0.21815674379467964, 0.27670397248584777, 0.3967532463138923, 0.37416794104501605, 17.13797338306904, 75.35019233822823, 86.69478759169579, 87.66026258468628, 117.64794185757637, 134.26912397146225, 62.210535407066345, 42.32758171856403, 59.662494733929634, 66.36290699243546, 91.34000793099403, 97.02527806162834, 94.85690161585808, 101.43116444349289, 38.53246696293354, 1.17737109772861, 0.42362988693639636, 0.15020117542007938, 0.1441821054322645, 0.24034485162701458, 0.2261283152620308, 0.20331129664555192, 0.1722978358156979, 0.20034490269608796, 0.15342310565756634, 0.26262513420078903, 0.12485108803957701, 0.1245155482320115, 0.07279124678461812, 0.18805291852913797, 0.16832583176437765, 0.20994168851757422, 0.10071980010252446, 0.060124151495983824, 0.13185445364797488, 0.22780608851462603, 0.1663918246049434, 0.1833855517907068, 0.17728635953972116, 0.10417286481242627, 0.12365150279947557, 0.15031841991003603, 0.06673886178759858, 0.13731977756833658, 0.15584719745675102, 0.1740479833097197, 0.08629876494524069, 0.06358084530802444, 0.1575782272266224, 0.1097780984127894, 0.06288743446930312, 0.08721728401724249, 0.11755819577956572, 0.09979342168662697, 0.146042981359642, 0.16730551229557022, 0.08438321499852464, 0.12294701169594191, 0.10639445419656113, 0.12149148198659532], [0.08148091292241588, 0.037231303940643556, 0.023000082328508142, 0.022827640605100896, 0.04019893356598914, 0.03762976673897356, 0.03013097302755341, 0.014816951461398276, 0.032783438509795815, 0.023878740648797248, 0.06847706070402637, 0.05337530543329194, 0.02288745585246943, 0.07333651010412723, 0.013506283412425546, 0.02844724032911472, 0.03622665120929014, 0.08462361147394404, 0.007926367252366617, 0.04051937437907327, 0.03077522400417365, 0.04130185036046896, 0.07188341463916004, 0.07548527253675275, 0.06777346759918146, 0.023753605273668654, 0.07564270432339981, 0.05732255885959603, 0.012066575363860466, 0.007188800018411712, 0.038997121882857755, 0.02492636373062851, 0.032916936033871025, 0.08578294262406416, 0.0406572060455801, 0.043957974630757235, 0.08081326945102774, 0.178006257629022, 0.16304276447044685, 8.375769909471273, 41.39437839388847, 98.38778614997864, 85.66047549247742, 81.09720915555954, 61.78170181810856, 48.357364162802696, 39.33088392019272, 53.43467831611633, 69.67771992087364, 60.367934480309486, 52.908353358507156, 37.13822677731514, 21.396887451410294, 2.937059048563242, 0.22331184998620301, 0.010429110006953124, 0.10131745162652805, 0.14132229873212054, 0.2349910873454064, 0.29476440337020904, 0.09832866708165966, 0.22865752485813573, 1.0558399627916515, 2.2143159806728363, 4.378878381103277, 3.6027560150250793, 5.2619813941419125, 5.103045422583818, 7.082057129591703, 6.867803726345301, 9.352436251938343, 5.262318151071668, 6.0512840654700994, 22.328745648264885, 16.59749038517475, 8.487233128398657, 7.337979571893811, 4.014048082754016, 5.73134645819664, 9.962805099785328, 12.564628086984158, 5.009746178984642, 8.505745735019445, 15.037983767688274, 10.851249676197767, 14.911687094718218, 7.582773361355066, 6.746065858751535, 0.9976589097641408, 7.385606216266751, 0.8352207730058581, 8.163723237812519, 16.42936460673809, 8.22396045550704, 13.280842155218124, 10.373959187418222, 9.42070433869958, 7.144179046154022, 6.7520861607044935, 4.901778772473335, 12.095256373286247, 10.75038693845272, 9.584567695856094, 16.92731648683548, 25.579900592565536, 27.94994741678238, 15.240590795874596, 3.568680393509567, 3.1424556020647287, 1.5133612998761237, 12.722920943051577, 1.7272420856170356, 0.46554157859645784, 0.42617147555574775, 0.19808206474408507, 0.12473918701289222, 0.5823512887582183, 0.41169288684614, 21.38907317072153, 74.96597975492477, 69.67396572232246, 57.56056532263756, 68.7584200501442, 57.872262597084045, 23.974652029573917, 24.247437492012978, 22.567420341074467, 44.674191400408745, 63.48996475338936, 69.57964718341827, 68.47417250275612, 48.01189810037613, 5.980104384943843, 0.31560658186208457, 0.03848343694698997, 0.06665963752311654, 0.08279470726847649, 0.00964725650192122, 0.018106649986293633, 0.03454209101619199, 0.061394311269395985, 0.0321547837666003, 0.06458906034822576, 0.02504583837435348, 0.017925680986081716, 0.036012267009937204, 0.06632995326071978, 0.020086061740585137, 0.06301915083895437, 0.01984654471016256, 0.023872883248259313, 0.00582330070756143, 0.016600388917140663, 0.05916499241720885, 0.049117815724457614, 0.03099701483733952, 0.07363434880971909, 0.06529830119688995, 0.021159708230698016, 0.052434722310863435, 0.034340790880378336, 0.01076735958122299, 0.04347249872807879, 0.06341476750094444, 0.04238442859787028, 0.0271129775501322, 0.04298588362871669, 0.03334849861857947, 0.01031081352266483, 0.045456489533535205, 0.04545698677247856, 0.040569287521066144, 0.021397390300990082, 0.03337603971885983, 0.005566331146837911, 0.03735842270543799, 0.04149280495767016, 0.03016306163772242, 0.03435981212533079, 0.017785999516490847, 0.0614086940913694, 0.02816792006342439, 0.06527262288727798, 0.03784715663641691, 0.027813179040094838, 0.02630446331750136, 0.09311979229096323, 0.03437603918428067, 0.03184120410878677, 0.043697336077457294, 0.03329522725834977, 0.0038558586356884916, 0.05171535856788978, 0.057647396897664294, 0.016710041236365214, 0.01908276157337241, 0.009929001735144993, 0.04381050246593077, 0.016103958914754912, 0.0525260027643526, 0.06168733714730479, 0.01549091617562226, 0.12006869583274238, 0.08140282414387912, 0.041013548252522014, 0.014434872500714846, 0.07478137515136041, 0.0834028898680117, 0.05401239468483254, 0.058127933807554655, 0.021247127660899423, 0.055430353168048896, 0.05512542324140668, 0.3259440459078178, 0.40878853644244373, 15.717970579862595, 57.866783291101456, 120.56767478585243, 97.47034817934036, 100.59949547052383, 98.59369710087776, 90.24264961481094, 58.07840533554554, 39.760572463274, 52.68192730844021, 54.597928896546364, 53.85487496852875, 43.55222940444946, 29.139108806848526, 3.5045968322083354, 0.3579059714684263, 0.1528718977351673, 0.13359951000893489, 0.22595631511649117, 0.5035654851235449, 0.3836750902701169, 0.16422021144535393, 0.2731507475255057, 0.6047234789002687, 0.8895352366380394, 2.065766276791692, 1.290985238738358, 0.7341073080897331, 1.00315329618752, 3.514914228580892, 6.344344289973378, 8.805813733488321, 9.268059879541397, 13.13132967799902, 24.204509295523167, 21.08391534537077, 14.233948811888695, 5.862307380884886, 0.7662701478693634, 0.2641699294326827, 5.713384822010994, 11.184036768972874, 12.770699579268694, 18.68080459535122, 15.16794154420495, 5.950525347143412, 1.5327288606204093, 1.990539338439703, 3.034884799271822, 1.9277420081198215, 1.8717046338133514, 1.4149845787324011, 0.6842789787333459, 3.248828281648457, 5.243166703730822, 6.949995690956712, 1.733105645980686, 0.5804031214211136, 2.326425164937973, 6.43899911083281, 8.88810021802783, 16.124900244176388, 16.295473091304302, 19.29420568048954, 26.982507929205894, 41.09613239765167, 41.37257896363735, 28.30260269343853, 7.977646272629499, 2.403257042169571, 2.621257994323969, 12.136992383748293, 0.7274757733102888, 0.4143920779461041, 0.29866450815461576, 0.2555519621819258, 0.061884967362857424, 1.0256232717074454, 0.14552147418726236, 20.711415633559227, 71.46991655230522, 70.65809771418571, 53.68172965943813, 40.66488973796368, 31.19920626282692, 22.425627149641514, 21.865185722708702, 30.7435043156147, 78.1108658015728, 92.45185106992722, 88.7361292541027, 85.22010192275047, 72.64510229229927, 14.966636896133423, 0.18773386924294755, 0.06999041856033728, 0.11477724969154224, 0.07398682442726567, 0.023820649039407726, 0.01631784216442611, 0.014397791092051193, 0.05242137849563733, 0.04765371420944575, 0.03783324507821817, 0.023468412764486857, 0.05358696966140997, 0.03296311988378875, 0.07136043059290387, 0.037497159792110324, 0.04173066328803543, 0.051480294423527084, 0.08028932061279193, 0.041615244481363334, 0.013994259425089695, 0.03421244757191744, 0.08831450482830405, 0.026086201396537945, 0.04009383432276081, 0.01752176340232836, 0.07097243578755297, 0.031445906570297666, 0.013557242982642492, 0.015221939593175193, 0.05047764549090061, 0.06646232272032648, 0.05339125789760146, 0.020871404267381877, 0.04685452506237198, 0.017251766366825905, 0.05729043128667399, 0.03672196799016092, 0.02767984478850849, 0.06740829383488744, 0.014215278424671851, 0.02996573384734802, 0.06315506776445545, 0.07943790653371252, 0.17836122686276212, 0.1210473214450758, 0.15720292314654216, 0.08159487711964175, 0.09000200021546334, 0.16800647077616304, 0.20155374251771718, 0.12823066528653726, 0.1015932930749841, 0.13349672255571932, 0.20519228477496654, 0.15862839587498456, 0.13020894897636026, 0.2070476094377227, 0.09158258922980167, 0.09701171860797331, 0.1708822336513549, 0.21598530875053257, 0.03851698573271278, 0.07894183276221156, 0.1000490618753247, 0.19430426589678973, 0.14353456674143672, 0.12669392977841198, 0.25820950395427644, 0.1352793167461641, 0.30844536144286394, 0.20298948657000437, 0.14709602954098955, 0.12361026907456107, 0.10905279748840258, 0.14905023796018213, 0.1796167774591595, 0.14795585215324536, 0.13649442029418424, 0.10924114714725874, 0.18952210375573486, 0.5663267767522484, 0.346651776926592, 17.517449520528316, 71.08330249786377, 136.36715859174728, 105.32933726906776, 99.95064988732338, 83.63646849989891, 65.59336468577385, 45.80588087439537, 71.73243686556816, 100.85297986865044, 88.10306802392006, 81.8776872754097, 60.49173563718796, 38.7517835944891, 7.627893565222621, 0.9285514836665243, 0.2794344525318593, 0.4123993223765865, 0.5960369075182825, 0.6951569044031203, 0.4499049426522106, 0.453454278758727, 0.9358228091150522, 2.7061395021155477, 7.132676113396883, 15.399474520236254, 16.134346537292004, 14.94333939626813, 17.928013689815998, 20.36687672138214, 24.191181510686874, 22.97450579702854, 14.764780327677727, 15.817911867052317, 33.71310196816921, 23.110975474119186, 12.884061746299267, 20.42490340769291, 18.63627288490534, 22.019660733640194, 23.039636202156544, 21.55678667128086, 16.038202196359634, 28.882314786314964, 34.683455899357796, 34.483833611011505, 37.93595977127552, 28.4974904358387, 19.568476863205433, 11.76843211054802, 18.140015713870525, 13.324620556086302, 28.624012246727943, 41.93856619298458, 27.68345631659031, 30.672499425709248, 26.313147246837616, 28.017771877348423, 18.30264888703823, 16.32569096982479, 11.061397399753332, 17.87392359226942, 17.379243336617947, 17.27931059896946, 20.73635369539261, 31.00933615118265, 30.1435849070549, 18.933325745165348, 5.265102926641703, 13.050535563379526, 11.819301880896091, 20.245222449302673, 2.650880729779601, 0.49902930040843785, 0.48554723791312426, 0.565665909089148, 0.12062233057804406, 1.0417682491242886, 0.5582215148024261, 33.5140610486269, 93.62609446048737, 92.00551941990852, 83.98830682039261, 104.541305154562, 74.58324909210205, 32.361020520329475, 35.99731519818306, 31.119914017617702, 64.55650672316551, 82.50962376594543, 91.2275567650795, 99.43991169333458, 82.24559873342514, 13.66877568885684, 0.44114329561125487, 0.14239916985388845, 0.17662708007264882, 0.22729137941496447, 0.08474359448882751, 0.1334318588487804, 0.1439094403758645, 0.13898183213314041, 0.1687713133287616, 0.21074215415865183, 0.07643368531716987, 0.08894931568647735, 0.1322895599878393, 0.1878063176991418, 0.15503545117098838, 0.13406569749349728, 0.11049336550058797, 0.18357383465627208, 0.11471015954157338, 0.11373413886758499, 0.2127190277678892, 0.11603251085034572, 0.07208890048786998, 0.09762427987880073, 0.18661960872123018, 0.12338302345597185, 0.20854683680227026, 0.08032678422750905, 0.12539358314825222, 0.1638798922067508, 0.132112305436749, 0.12066856637829915, 0.10950055002467707, 0.17845963564468548, 0.13391852960921824, 0.16343257011612877, 0.15493015525862575, 0.10891997531871311, 0.15194842853816226, 0.064964141784003, 0.15600382030243054, 0.15663234516978264, 0.1734371215570718], [0.03541531681548804, 0.019071388160227798, 0.010460006542416522, 0.051470713297021575, 0.0723436129919719, 0.01891039592010202, 0.041589837055653334, 0.05291766377922613, 0.0654193306399975, 0.12454921205062419, 0.03724229885847308, 0.04088654452061746, 0.04347430214693304, 0.052053900362807326, 0.04799251946678851, 0.04029740171972662, 0.08723782666493207, 0.0072351582730334485, 0.04449405016202945, 0.011041599846066674, 0.055618751066504046, 0.03622730429924559, 0.0306057044872432, 0.026899970034719445, 0.03181269821652677, 0.06281882291659713, 0.05264452374831308, 0.043188801646465436, 0.05363408490666188, 0.015882104999036528, 0.045264017244335264, 0.02646552791702561, 0.06282907197601162, 0.03046792662644293, 0.0857007794547826, 0.06952020121389069, 0.09318340176832862, 4.009624170139432, 40.9460024535656, 98.0213414132595, 94.58076283335686, 74.86729145050049, 69.27632465958595, 67.51306727528572, 41.98450192809105, 31.14656388759613, 54.32730741798878, 52.856763526797295, 45.849061757326126, 46.4489583671093, 26.148108802735806, 10.372684355825186, 0.5745411640964448, 0.18628669611644, 0.06740443466696888, 0.10764753344119526, 0.23321247106650844, 0.043621069271466695, 0.13638437463669106, 0.5580356216523796, 1.9884083652868867, 4.71159185282886, 6.1396188754588366, 6.65905337780714, 8.02519217133522, 13.792588245123625, 28.519472256302834, 35.831894874572754, 47.18891926109791, 53.72644565999508, 72.5824436545372, 84.85735058784485, 95.53177580237389, 103.26656475663185, 116.5710112452507, 104.66563448309898, 80.9920459985733, 17.433662116527557, 1.7342044995166361, 3.9181015687063336, 11.257853507995605, 14.750437047332525, 15.361705496907234, 14.930248148739338, 12.973316106945276, 4.553747372701764, 3.216339787468314, 4.234846634790301, 7.978953402489424, 7.163516683503985, 1.4747541840188205, 0.28295419178903103, 6.749157467857003, 11.285021100193262, 9.189536143094301, 6.65927424095571, 4.609743067994714, 17.267025858163834, 44.24314633011818, 66.87101572751999, 83.81949707865715, 95.49926474690437, 103.67142543196678, 120.13259813189507, 138.0184891819954, 134.74368810653687, 129.68114376068115, 106.1950372159481, 46.95359028875828, 7.596653066575527, 2.1779611939564347, 0.7467968459241092, 0.5156335781794041, 0.4541752010118216, 0.03661598930193577, 0.43276195472572, 0.3513756953179836, 0.06492313812486827, 0.8479653485119343, 3.316039312630892, 39.170163944363594, 65.7120019197464, 61.371282041072845, 61.33060522377491, 98.35197687149048, 197.37361460924149, 105.85859566926956, 27.40817628800869, 33.455665782094, 46.571699380874634, 56.204053312540054, 69.47319209575653, 60.259894877672195, 10.224516056478024, 0.18242899765027687, 0.24119815818266943, 0.1175801336648874, 0.07318843679968268, 0.03454813951975666, 0.03833346003375482, 0.09393448490300216, 0.025438944721827284, 0.0687561824452132, 0.03303314893855713, 0.0043262445888103684, 0.020655198095482774, 0.054978403786662966, 0.02601407020847546, 0.008267118791991379, 0.09011660265969113, 0.03954204010369722, 0.058861394645646214, 0.018370080870226957, 0.05893717905564699, 0.03331724677991588, 0.014059517397981836, 0.004114687044420862, 0.057218309375457466, 0.025470962827967014, 0.025980361861002166, 0.00922379538678797, 0.023402025799441617, 0.02245187082735356, 0.04977662392775528, 0.017221217713085935, 0.0955047135357745, 0.025095141099882312, 0.05265953739581164, 0.06080541337723844, 0.06673496551229618, 0.0461558820825303, 0.028710383630823344, 0.048418460282846354, 0.04373405754449777, 0.0400651985546574, 0.01844447004259564, 0.02911244399001589, 0.05978554290777538, 0.053434992660186253, 0.04662159088184126, 0.05677030450897291, 0.05716330881114118, 0.03596052818465978, 0.07220036364742555, 0.09558000441757031, 0.09187049057800323, 0.05415795210865326, 0.052887992715113796, 0.040638841601321474, 0.027778166368079837, 0.022717255415045656, 0.04190339444903657, 0.01268936435735668, 0.09405481672729366, 0.031079116779437754, 0.04563692789815832, 0.058199001869070344, 0.0428677856689319, 0.04039628547616303, 0.0015622985529262223, 0.06269406789215282, 0.019965828250860795, 0.044781899559893645, 0.01094832579838112, 0.06912097771419212, 0.14784859697101638, 0.05422352456662338, 0.024681132163095754, 0.12207210864289664, 0.039927437392179854, 0.115251942188479, 0.08401923609199002, 0.05444405374873895, 11.150001995265484, 61.531268656253815, 117.98413261771202, 110.90087950229645, 90.5763629078865, 100.07383927702904, 114.75923046469688, 69.97788101434708, 21.459069214761257, 17.010155841708183, 34.535712227225304, 49.45671357214451, 49.1727814078331, 33.07825483381748, 12.142776623368263, 0.42401138052809983, 0.35070509067736566, 0.03231789298297372, 0.07283792045200244, 0.5308426776900887, 0.4065579076996073, 0.21668579225661233, 0.7121736975386739, 3.0471009062603116, 8.429380282759666, 11.552348155528307, 13.648454379290342, 15.442683901637793, 22.939386181533337, 37.06622824072838, 46.4173174649477, 57.44270324707031, 65.70430353283882, 83.71021494269371, 98.12525823712349, 109.38807427883148, 121.39910817146301, 129.3088549375534, 120.74159905314445, 94.34930965304375, 27.304259464144707, 2.4562953086569905, 1.3499642489477992, 1.8989464407786727, 6.087469523772597, 6.614822801202536, 3.708625459112227, 1.3512979773804545, 1.0466000461019576, 2.827161345630884, 7.533109551295638, 14.774282667785883, 13.392983637750149, 3.4460248751565814, 0.6200279295444489, 2.1184264635667205, 1.4671636163257062, 0.9601418604142964, 3.1967879366129637, 9.54636549577117, 26.54085762798786, 59.569000750780106, 82.77582988142967, 98.75753670930862, 109.32447329163551, 111.36351227760315, 127.1831502020359, 142.22141325473785, 142.01619386672974, 136.10024571418762, 124.57261428236961, 68.6861403286457, 16.1917557567358, 5.415423810482025, 2.319454438984394, 0.2519706840394065, 0.2511658990988508, 0.2566659258445725, 0.275485425372608, 0.4320318001555279, 0.04647825990105048, 1.2275488302111626, 3.040841929614544, 41.53505824506283, 67.90346592664719, 65.15484541654587, 45.60450308024883, 39.44047383964062, 136.19581818580627, 67.37860009074211, 30.917540676891804, 62.937436401844025, 74.79283824563026, 76.61927103996277, 80.20002409815788, 82.0871776342392, 24.48110595345497, 0.20818548509851098, 0.5428063357248902, 0.10266732177115045, 0.09888058004435152, 0.039134267062763683, 0.12625638919416815, 0.09172197198495269, 0.0572914702934213, 0.016779092511569615, 0.03099974408542039, 0.03224818305170629, 0.026638084673322737, 0.019783387942879926, 0.035189893169444986, 0.08232682768721133, 0.016307943769788835, 0.02576734321337426, 0.037655330015695654, 0.03142411711451132, 0.022023141391400713, 0.07697298176935874, 0.030440322443610057, 0.013382234355958644, 0.1044383087719325, 0.021691093388653826, 0.024832851268001832, 0.02419647447823081, 0.0052677989970106864, 0.008994147065095603, 0.04161376018601004, 0.01508603472757386, 0.09802999717066996, 0.020799876074306667, 0.0500945228850469, 0.04948222507664468, 0.05515224445844069, 0.05397586246544961, 0.09139616915490478, 0.01542443644211744, 0.04157106071943417, 0.059978330609737895, 0.006044306719559245, 0.13718486996367574, 0.10747427906608209, 0.17034751625033095, 0.13746080046985298, 0.16836624912684783, 0.16151128336787224, 0.15811628429219127, 0.1846070378087461, 0.15574359364109114, 0.23574776627356187, 0.13191879785154015, 0.14651035628048703, 0.18923428404377773, 0.13200435263570398, 0.16293963562930003, 0.09607768122805282, 0.12318204244365916, 0.21485305856913328, 0.09473711019381881, 0.1583169907098636, 0.23185745783848688, 0.1769958235672675, 0.13154932705219835, 0.07711981568718329, 0.22634303342783824, 0.15602881583618, 0.2557212015381083, 0.1387613103725016, 0.1646099131903611, 0.3423296276014298, 0.10676717560272664, 0.12925503688165918, 0.3441431396640837, 0.20489840913796797, 0.30667430022731423, 0.20932683401042596, 0.26493466808460653, 13.225590270012617, 75.3338760137558, 135.47710955142975, 121.02514743804932, 93.21122512221336, 92.26699858903885, 86.1225762963295, 48.91213819384575, 43.155192509293556, 84.34385374188423, 79.06377106904984, 67.8152346611023, 69.92192521691322, 44.71037305891514, 18.351882845163345, 1.0911792539991438, 0.7337675231974572, 0.0830856959510129, 0.32371543580666184, 0.4811999446246773, 0.30251993564888835, 0.3880176931852475, 1.092012596782297, 6.512187933549285, 10.2135412953794, 11.449158042669296, 13.834797330200672, 14.907560516148806, 20.892639309167862, 33.38682487607002, 41.90953195095062, 51.579522863030434, 60.3939288854599, 81.34553343057632, 94.02773290872574, 106.34403482079506, 116.39762654900551, 132.85277277231216, 117.42619335651398, 87.22837015986443, 21.81639824062586, 6.148816756904125, 13.163733389228582, 26.527571640908718, 35.265744253993034, 29.794828221201897, 43.00502456724644, 35.67598544061184, 15.015108995139599, 6.945678172633052, 6.827417593449354, 13.65331906825304, 13.506520595401525, 2.592854043468833, 4.023311510682106, 25.792939960956573, 36.49646021425724, 25.52797257900238, 16.143146865069866, 10.28200127184391, 21.493694856762886, 50.58862343430519, 77.8468407690525, 95.10647222399712, 106.14104971289635, 108.38679000735283, 128.4352058172226, 153.69585514068604, 152.95571565628052, 145.55682867765427, 122.5562296807766, 53.76832701265812, 9.486678298562765, 8.270122278481722, 5.9864989668130875, 0.7585814979393035, 0.28187297168187797, 0.2934440632816404, 0.6525409442838281, 0.6469982885755599, 0.2869389014085755, 1.2442149734124541, 6.60684322938323, 56.428499668836594, 83.90113949775696, 82.3903101682663, 88.52010324597359, 119.28808584809303, 214.1486656665802, 123.75311985611916, 37.2657061368227, 45.64463272690773, 65.87923094630241, 76.12096577882767, 90.61431527137756, 97.88805976510048, 25.722486041486263, 0.24809757858747616, 0.5566125980112702, 0.269783801632002, 0.18489133974071592, 0.19555048027541488, 0.25596937572117895, 0.2544450934510678, 0.16509808308910578, 0.08054574005655013, 0.1963470273767598, 0.15604028943926096, 0.158560311247129, 0.1585967803839594, 0.136760895838961, 0.21505481883650646, 0.2039642827003263, 0.14186538755893707, 0.16118853818625212, 0.11985184028162621, 0.22959554014960304, 0.1354211856960319, 0.09490141426795162, 0.1420215651160106, 0.2395251049892977, 0.1088286169397179, 0.10414418080472387, 0.07070660591125488, 0.11702787931426428, 0.09169759985525161, 0.1339183366508223, 0.13044484803685918, 0.26708484801929444, 0.10612632366246544, 0.1153908202832099, 0.12883308139862493, 0.19149554864270613, 0.10639100320986472, 0.12160948346718214, 0.14205196348484606, 0.11007076434907503, 0.1349786133505404, 0.03999292450316716], [0.052816761381109245, 0.07708278251811862, 0.06617097780690528, 0.12447331260773353, 0.06115208911069203, 0.06348211740260012, 0.05977595807053149, 0.056752830641926266, 0.03227602101105731, 0.028805395231756847, 0.08778707531746477, 0.038607223468716256, 0.05089043916086666, 0.0353758865094278, 0.030738929272047244, 0.08575264073442668, 0.08504976751282811, 0.07581607002066448, 0.08075469915638678, 0.04741538461530581, 0.01732171749608824, 0.04728723055450246, 0.03670552199764643, 0.04302762943552807, 0.038754213237552904, 0.011977047306572786, 0.12926386843901128, 0.054420119486167096, 0.05018148403905798, 0.054539902121177875, 0.1073538581840694, 0.047141439354163595, 0.02360114402108593, 0.04490299579629209, 0.18168603361118585, 1.1866154079325497, 42.88824163377285, 96.45350754261017, 105.13171747326851, 87.21516206860542, 76.1660161614418, 73.77983540296555, 43.06641787290573, 33.08996960520744, 52.52742759883404, 101.13740980625153, 85.04423215985298, 64.52453523874283, 37.79824376106262, 9.9024329893291, 0.4408441804116592, 1.01821877527982, 0.09195550359436311, 0.3115809056907892, 0.1746188581455499, 0.08018991735298187, 0.10822714335517958, 0.05769381081336178, 0.8201681775972247, 18.741322048008442, 66.48748710751534, 101.25466391444206, 110.62029495835304, 113.40838775038719, 109.72328469157219, 115.16901567578316, 117.3252023756504, 115.70245385169983, 113.09286788105965, 114.70329746603966, 92.43534475564957, 118.65576177835464, 109.36715260148048, 107.24068030714989, 95.68954333662987, 101.24205619096756, 110.28601929545403, 117.80285954475403, 39.74079072475433, 2.333929049782455, 3.486586748622358, 10.7746372371912, 12.360158208757639, 8.28971117734909, 3.1808024318888783, 2.686124788597226, 31.811205223202705, 56.031382977962494, 68.19363355636597, 69.08520251512527, 47.72543907165527, 22.05835595726967, 1.2620581034570932, 2.74390353821218, 4.87105124630034, 16.1260686814785, 61.23735822737217, 100.60343205928802, 117.91027218103409, 109.84433099627495, 111.7690721154213, 108.68421524763107, 100.75352400541306, 103.92716690897942, 102.46323466300964, 94.2532280087471, 96.83984041213989, 107.59631842374802, 132.251857817173, 123.86604979634285, 71.50055810809135, 63.490914702415466, 42.86166585981846, 18.268496319651604, 1.874584760516882, 0.364017141982913, 0.13205741619458422, 0.07075250032357872, 0.46951658092439175, 0.27866926859132946, 0.07276082615135238, 11.819569766521454, 63.55610780417919, 83.53642746806145, 73.05338278412819, 104.6007339656353, 85.86073994636536, 41.63038372993469, 27.15134046971798, 30.669009312987328, 52.43723563849926, 63.48402187228203, 65.46396642923355, 64.55710709095001, 26.852036230266094, 1.4020997076295316, 0.4513715748907998, 0.09241811392712407, 0.062198417144827545, 0.05072651729278732, 0.1714378796168603, 0.05083118980110157, 0.034509243560023606, 0.05147180796484463, 0.017774188236217014, 0.07250399852637202, 0.027272359329799656, 0.04280975343135651, 0.15352645714301616, 0.05065451412519906, 0.06670623697573319, 0.044509167710202746, 0.10766132254502736, 0.02445461941533722, 0.06914997342391871, 0.07712075821473263, 0.04389946741866879, 0.016137791571964044, 0.024470809366903268, 0.04670522721426096, 0.020006486811325885, 0.024554302835895214, 0.03488492613541894, 0.06547002674778923, 0.015823562534933444, 0.05210494528000709, 0.01806859265343519, 0.005910139407205861, 0.12314820793108083, 0.055877011036500335, 0.08800819821772166, 0.023613189077877905, 0.04962514416547492, 0.05046063175541349, 0.03405388772080187, 0.050997304715565406, 0.06988689638092183, 0.03403540453291498, 0.02843182777723996, 0.03784673361224122, 0.08069640345638618, 0.04341904554166831, 0.10759763143141754, 0.033125394184025936, 0.09109949562116526, 0.02335356541152578, 0.06282133879722096, 0.03623283701017499, 0.022972383521846496, 0.03883031306031626, 0.05887258623261005, 0.07839433557819575, 0.021598313796857838, 0.021704492864955682, 0.01550670722281211, 0.06814741354901344, 0.07252680472447537, 0.07130888101528399, 0.04003753128927201, 0.06665771536063403, 0.06568497497937642, 0.014602403061871883, 0.1290526383672841, 0.08532615072908811, 0.08297970984131098, 0.03004932379553793, 0.1134806805930566, 0.09277587363612838, 0.045423211631714366, 0.03272714289778378, 0.17860022810054943, 3.244988350197673, 60.30145324766636, 117.54324227571487, 119.78617072105408, 104.99824583530426, 99.29613500833511, 107.65060991048813, 75.27353525161743, 35.02837099134922, 19.356592632830143, 57.27849505841732, 76.03194415569305, 69.16217878460884, 44.5672195404768, 12.337502874433994, 0.29941606626380235, 1.504941782914102, 0.08563839452108368, 0.19103924656519666, 0.251706360722892, 0.47083214158192277, 0.09574976327712648, 0.029573200808954425, 1.081060040742159, 29.450885877013206, 82.81022563576698, 117.44146093726158, 122.07899048924446, 124.14050906896591, 119.21160355210304, 124.99713510274887, 122.17254146933556, 121.15424171090126, 116.6087432205677, 113.70446026325226, 98.62205117940903, 118.45682725310326, 112.55201250314713, 106.68302223086357, 96.30213126540184, 104.00609627366066, 114.25394877791405, 127.12465614080429, 52.197939679026604, 6.162602417171001, 2.061758916825056, 4.060284001752734, 5.19800802692771, 0.6216936057899147, 1.5920130419544876, 5.360841164365411, 44.46699231863022, 68.43904718756676, 81.21434926986694, 87.70095840096474, 68.74481678009033, 33.9351050555706, 3.2510093646124005, 1.279156592208892, 7.044331328943372, 24.52686119824648, 76.68022736907005, 113.8958939909935, 121.75343155860901, 113.02377238869667, 113.49246203899384, 109.28953036665916, 101.70082837343216, 107.8019405901432, 107.01050385832787, 98.34812387824059, 102.57608860731125, 106.65498733520508, 131.7196735739708, 135.5148795247078, 95.48601105809212, 82.42587625980377, 60.16429580748081, 29.263654723763466, 5.499541321769357, 0.2489179783151485, 0.14220202574506402, 0.08247074496466666, 0.5583549826405942, 0.38537543965503573, 0.35622625378891826, 12.241106797009706, 64.52224016189575, 90.07634773850441, 71.96739345788956, 99.57450807094574, 77.6062984764576, 25.078646689653397, 31.553708240389824, 50.52639037370682, 84.04847279191017, 84.74936038255692, 77.52067387104034, 86.48872464895248, 47.880075573921204, 5.7896495796740055, 0.42185594618786126, 0.023721405341348145, 0.05104167772515211, 0.08321923058247194, 0.15568018454359844, 0.08815816399874166, 0.02526648258935893, 0.05177819992240984, 0.03703476468217559, 0.03427298826863989, 0.039521712678833865, 0.08902602407033555, 0.06936263584066182, 0.021119509801792447, 0.009055803766386816, 0.045076402311678976, 0.0877835055871401, 0.031637929860153235, 0.03899389354046434, 0.025656312354840338, 0.08512352957041003, 0.0723151516285725, 0.026149797886318993, 0.06970750444452278, 0.053332435272750445, 0.08325532122398727, 0.0445114349713549, 0.07793570315698162, 0.0369273573596729, 0.03307385944935959, 0.09187477277009748, 0.09687810234026983, 0.019053801115660463, 0.02525299962144345, 0.025692343624541536, 0.003171886755808373, 0.05325286590959877, 0.09258165358914994, 0.04634089578757994, 0.029256639572849963, 0.1403745316201821, 0.1789606298552826, 0.1489885654882528, 0.24109801277518272, 0.20135965605732054, 0.13403120246948674, 0.2704269764944911, 0.14070685050683096, 0.16809515742352232, 0.10057023508124985, 0.2747856988571584, 0.2010634946054779, 0.09966531215468422, 0.15254878147970885, 0.11382697412045673, 0.24305176106281579, 0.19142905221087858, 0.15668385021854192, 0.26244134875014424, 0.1621141447685659, 0.1794804894598201, 0.15850122144911438, 0.14347175136208534, 0.10144004700123332, 0.15300091268727556, 0.10445315172546543, 0.27841494942549616, 0.10154012561542913, 0.20388836099300534, 0.13634952338179573, 0.1715320729999803, 0.24508830334525555, 0.10675927915144712, 0.1712539605796337, 0.5055060528684407, 4.518435867503285, 72.61797934770584, 139.25913780927658, 132.5555983185768, 105.51768556237221, 98.72069388628006, 96.10190480947495, 55.53789205849171, 40.033652409911156, 75.36321803927422, 153.4837657213211, 114.23349827528, 89.83605623245239, 60.674239844083786, 18.313541002571583, 1.1129470984451473, 1.8699144548736513, 0.18107702722772956, 0.6330463872291148, 0.3977534832665697, 0.35023370815906674, 0.2564182266360149, 0.5357124726288021, 4.955933941528201, 22.14437384158373, 72.00517863035202, 112.07304060459137, 121.99132919311523, 121.27680033445358, 116.44985854625702, 125.31603679060936, 130.43114751577377, 127.32460901141167, 124.83494460582733, 121.71664953231812, 108.50741073489189, 126.89200982451439, 121.51445478200912, 119.63873863220215, 105.07826954126358, 114.47245985269547, 125.08979693055153, 128.70333462953568, 46.43119812011719, 5.937538119032979, 13.92724921926856, 28.433655761182308, 35.879684910178185, 22.31580924242735, 9.067415446043015, 4.499419312924147, 48.98860149085522, 78.5598573088646, 92.00900763273239, 100.78595906496048, 82.80984565615654, 35.98734453320503, 1.7196592362597585, 7.066656081005931, 9.5838438346982, 20.85535190999508, 70.86939677596092, 109.8880286514759, 131.00908130407333, 119.7003561258316, 122.13958203792572, 118.03674459457397, 105.40426924824715, 111.48654207587242, 112.24065721035004, 103.56906652450562, 108.25456470251083, 120.10186538100243, 151.01452142000198, 142.78469502925873, 86.21258586645126, 66.62707641720772, 47.04877898097038, 20.579980686306953, 3.1775828171521425, 0.3353048436110839, 0.2698299632174894, 0.3775418037548661, 0.9714035061188042, 0.7586384355090559, 0.21829825651366264, 21.36110097169876, 83.1113974750042, 106.12084999680519, 95.75883641839027, 118.36424142122269, 99.02336284518242, 49.68337520956993, 36.37986347079277, 39.76195938885212, 71.35488912463188, 85.4249869287014, 85.12883841991425, 99.26384434103966, 52.543648928403854, 4.27618034183979, 0.6188986182678491, 0.1294761078315787, 0.23491506173741072, 0.13434363179840147, 0.27257608773652464, 0.13549912604503334, 0.1894536183681339, 0.16146201960509643, 0.12321792528382502, 0.15274086414137855, 0.13550175324780867, 0.16073376493295655, 0.25823203555773944, 0.21222576673608273, 0.18039992137346417, 0.13704429235076532, 0.1475697720889002, 0.1315922528738156, 0.2085774578154087, 0.19302548607811332, 0.16220539924688637, 0.2148138137999922, 0.1748342442442663, 0.134318636264652, 0.11522388900630176, 0.10407971785753034, 0.16165897075552493, 0.13359002536162734, 0.1341859996318817, 0.175066209922079, 0.23487641068641096, 0.18368279677815735, 0.23673440708080307, 0.14223810896510258, 0.11042973375879228, 0.1530193179496564, 0.10476243434823118, 0.2492214721860364, 0.20399514120072126, 0.13955891132354736], [0.05873670270375442, 0.03523428844346199, 0.0875492615159601, 0.036081616999581456, 0.052440711442613974, 0.18793027120409533, 0.036517647313303314, 0.043232328607700765, 0.036648621535277925, 0.0077048412731528515, 0.014408641291083768, 0.12449999281670898, 0.016775916119513568, 0.024801079925964586, 0.028100835479563102, 0.04951374779921025, 0.03685025563754607, 0.11484864429803565, 0.02686713371076621, 0.02791976814478403, 0.020437900966499, 0.05666738717991393, 0.09872783863102086, 0.06922379485331476, 0.020405888426466845, 0.056755628538667224, 0.1582939099171199, 0.17795963591197506, 0.16014877444831654, 0.15561300533590838, 0.10261342700687237, 0.024497484009771142, 0.14707245893077925, 0.10070942487800494, 2.615843522362411, 78.33709046244621, 106.2802666425705, 86.53249070048332, 81.5476293861866, 67.78099089860916, 64.45258989930153, 39.95605297386646, 37.52393268048763, 82.056133300066, 105.44823288917542, 72.5152176618576, 51.66904605925083, 18.182248547673225, 0.445105325197801, 0.3929695696569979, 0.03972296828578692, 0.2760515653062612, 0.10987052548443899, 0.13979619077872485, 0.029806294551235624, 0.1212752795254346, 0.32222686568275094, 1.0854144883342087, 50.53377337753773, 126.31367325782776, 116.39278560876846, 107.89113700389862, 101.08643174171448, 106.97525694966316, 103.16178917884827, 103.18578869104385, 96.16115123033524, 98.62028807401657, 94.41061556339264, 95.62515959143639, 92.19917222857475, 94.77586716413498, 110.00085979700089, 92.57988139986992, 92.79747292399406, 87.86309570074081, 92.9035784304142, 94.98976528644562, 109.8420587182045, 58.00264500081539, 5.394639875739813, 1.68183749075979, 1.9700441882014275, 0.5969848379027098, 3.714560028165579, 39.83531825244427, 64.87609997391701, 78.84915858507156, 82.89149567484856, 88.40385228395462, 91.09543785452843, 67.65049070119858, 56.479720920324326, 23.508692532777786, 45.41499584913254, 82.87308186292648, 114.21565443277359, 118.70235487818718, 107.73430421948433, 102.68570512533188, 97.99257695674896, 106.08066335320473, 110.426284968853, 111.30630254745483, 113.91727164387703, 104.76196691393852, 106.07192382216454, 103.36700096726418, 98.74320387840271, 98.4206847846508, 115.29524490237236, 123.0614885687828, 126.3949964940548, 122.96859115362167, 100.36842226982117, 33.12633365392685, 0.41968715318944305, 0.0339659951714566, 0.11054350499762222, 0.40445222693961114, 0.020253800103091635, 0.9030575829092413, 0.976479499367997, 26.68656460940838, 58.23580428957939, 42.852778136730194, 32.58916027843952, 54.34963122010231, 78.11990171670914, 31.517600677907467, 30.729344375431538, 49.82308231294155, 61.06983661651611, 62.564638406038284, 68.34389269351959, 55.07008396089077, 11.251746285706758, 0.1667424596962519, 0.09252774398191832, 0.02429811160254758, 0.17313677439233288, 0.08643031804240309, 0.059070138522656634, 0.009212643690261757, 0.12888608558569103, 0.06119298886915203, 0.06637883110670373, 0.02953525665361667, 0.11822014697827399, 0.07683261195779778, 0.03760167644941248, 0.0008370982243377512, 0.07287588130566292, 0.10299308007233776, 0.031373988749692217, 0.03660889808088541, 0.09495878970483318, 0.019277005740150344, 0.008951303807407385, 0.05077112036815379, 0.035305349083500914, 0.11229635390918702, 0.03442361827183049, 0.009721983351482777, 0.05095297994557768, 0.028072656132280827, 0.09891048117424361, 0.030316519223561045, 0.09518493694486097, 0.04156491944740992, 0.02415299204585608, 0.14103004097705707, 0.02595673744508531, 0.02078575485938927, 0.011420210194046376, 0.12188311331556179, 0.0077888018313387875, 0.12119272301788442, 0.07636172667844221, 0.04655150987673551, 0.027338542204233818, 0.0496977633156348, 0.026379062146588694, 0.07071876971167512, 0.08950644594733603, 0.05459384141431656, 0.03270895656896755, 0.11549109927727841, 0.03631063264037948, 0.02950100282760104, 0.04689066394348629, 0.01930212372826645, 0.11444298637798056, 0.07672436229768209, 0.04603218461852521, 0.054311546991812065, 0.054675971186952665, 0.03172253098455258, 0.04938639154715929, 0.04359241123893298, 0.02180284969654167, 0.1876233337679878, 0.17048384877853096, 0.11046849613194354, 0.23105516651412472, 0.26855287549551576, 0.27062183478847146, 0.07727512493147515, 0.1064820795727428, 0.14336562424432486, 7.072314927354455, 101.3200356066227, 120.69733902812004, 100.0558890402317, 107.99996316432953, 104.97794732451439, 107.13973492383957, 63.699394315481186, 22.935892269015312, 40.13074479997158, 77.70158216357231, 79.81276407837868, 64.45998430252075, 24.33410134166479, 0.3599554568063468, 0.7534411456435919, 0.03471741969406139, 0.6293240119703114, 0.0858792288636323, 0.6915181246586144, 0.3598987270379439, 0.27040486049372703, 0.5122620903421193, 2.5845631258562207, 67.23565176129341, 131.51071518659592, 115.27927055954933, 107.52191841602325, 103.33767414093018, 110.05062192678452, 106.38177439570427, 105.77513694763184, 101.28147527575493, 103.2672107219696, 99.95420649647713, 102.16726094484329, 104.03045296669006, 101.20951473712921, 113.80687236785889, 98.82426872849464, 101.21149823069572, 95.50051108002663, 98.3761739730835, 98.35538148880005, 115.36578431725502, 71.97782009840012, 9.775430504232645, 1.3627859484404325, 2.069833008572459, 0.3245860937749967, 7.766472604125738, 56.40436716377735, 78.86100634932518, 90.17081066966057, 93.57079982757568, 96.74150168895721, 106.56551733613014, 92.88860723376274, 71.85126408934593, 36.27979204058647, 60.124439746141434, 96.31388783454895, 114.17623534798622, 117.7499283850193, 112.81073302030563, 107.01877981424332, 99.91219595074654, 109.48938444256783, 115.88519364595413, 117.14913502335548, 119.72095862030983, 112.13577523827553, 107.1425087749958, 112.39855393767357, 105.40942177176476, 99.4037452340126, 111.21126964688301, 118.88422071933746, 125.89830234646797, 129.19864565134048, 115.58463737368584, 48.45135971903801, 0.902648689225316, 0.022554422648681793, 0.20492931216722354, 0.5773136497009546, 0.03796457553107757, 1.43598688300699, 0.5334557499736547, 25.833200700581074, 61.95520430803299, 48.88750031590462, 38.14044959843159, 28.916146270930767, 28.55847906321287, 26.934820488095284, 45.81206314265728, 83.68240043520927, 93.21583047509193, 78.94894883036613, 83.29917579889297, 76.05978906154633, 24.73590698093176, 0.14394240657566115, 0.09324808735982515, 0.08136809163261205, 0.123135776957497, 0.0391887073055841, 0.02329665752768051, 0.04080208811501507, 0.1755730967852287, 0.013138639224052895, 0.04642045772925485, 0.04482280302909203, 0.14925107796443626, 0.12154886484495364, 0.07162340320064686, 0.04940240709402133, 0.035753765841946006, 0.1088993065059185, 0.0805681454949081, 0.07085507255396806, 0.11467452903161757, 0.04311219716328196, 0.017282661974604707, 0.11887452827068046, 0.03438244391873013, 0.09851530237938277, 0.05856528143340256, 0.024189509422285482, 0.025285490846727043, 0.2617200108943507, 0.13521338434657082, 0.018049591817543842, 0.10521628733840771, 0.054247236184892245, 0.09831070710788481, 0.12043251146678813, 0.024192025302909315, 0.03721548135217745, 0.02102883419865975, 0.13872743875253946, 0.14721567858941853, 0.23500303592300043, 0.22110608319053426, 0.21498861926374957, 0.1851254576467909, 0.2964562922716141, 0.23616106831468642, 0.12451535527361557, 0.21788044221466407, 0.19149816100252792, 0.12445517451851629, 0.21967335225781426, 0.1690939100808464, 0.1457580560236238, 0.06610163152799942, 0.11564908767468296, 0.17331067443592474, 0.2823919407092035, 0.20226184045895934, 0.13306535664014518, 0.11783143228967674, 0.1775763463228941, 0.2637868921738118, 0.10541536103119142, 0.2608153031906113, 0.2561332716140896, 0.33945620991289616, 0.32479157962370664, 0.28916424605995417, 0.4315720545127988, 0.38245541509240866, 0.19137622613925487, 0.2207094943150878, 0.15913470386294648, 9.128953143954277, 120.01339092850685, 134.8334088921547, 109.28921118378639, 105.29594466090202, 89.83822211623192, 82.27170333266258, 51.9427377730608, 50.670630633831024, 121.86148256063461, 151.6461083292961, 92.67340958118439, 73.93428191542625, 33.47676604986191, 1.3584993034601212, 0.9806238301098347, 0.0852511047560256, 1.0495769488625228, 0.28977960522752255, 0.6336198595818132, 0.15917276119580492, 0.3168629191350192, 1.8307080399245024, 6.2535191886126995, 57.2408314794302, 138.5842028260231, 125.76223164796829, 116.2656444311142, 108.80697146058083, 118.9424715936184, 113.62632885575294, 111.00928768515587, 103.04721012711525, 106.69098660349846, 99.88539978861809, 104.67543035745621, 102.10882008075714, 106.74285382032394, 115.49790322780609, 101.61610811948776, 103.58743473887444, 98.70929449796677, 100.47987788915634, 105.20804017782211, 123.33739176392555, 70.14226019382477, 7.426755633205175, 6.680004978552461, 11.832262985408306, 2.3517557932063937, 6.886106394231319, 67.12174907326698, 90.21996483206749, 95.5948980152607, 95.47394290566444, 96.50120258331299, 107.70178556442261, 115.26268064975739, 88.5399229824543, 33.358425199985504, 57.763691022992134, 100.00377863645554, 111.47158607840538, 123.47452640533447, 118.50251600146294, 111.90912500023842, 106.459229439497, 114.56465810537338, 117.95335426926613, 118.54886591434479, 128.44160467386246, 118.5708287358284, 116.94708466529846, 114.7840279340744, 110.16358986496925, 105.81505760550499, 124.70533356070518, 135.58114796876907, 138.29158812761307, 136.9519928097725, 111.20701387524605, 38.66962820291519, 0.5293403926771134, 0.09760314351296984, 0.232269884145353, 1.2343009491451085, 0.33639669127296656, 1.8834874453023076, 2.354195024818182, 38.36782179772854, 76.71483591198921, 62.45769314467907, 51.05013906955719, 74.93181958794594, 99.57408249378204, 42.18575432896614, 38.16507987678051, 66.93908527493477, 83.40953707695007, 81.33443802595139, 96.63397505879402, 90.51906198263168, 22.69470401108265, 0.2265819307649508, 0.23753865767503157, 0.15197153901681304, 0.4291745909722522, 0.25069303228519857, 0.17920932354172692, 0.12018616296700202, 0.27751252753660083, 0.16202317230636254, 0.11758266438846476, 0.140195109997876, 0.289126307470724, 0.22921141935512424, 0.1383634895319119, 0.10047648698673584, 0.1145764542161487, 0.2317490745917894, 0.17649457702646032, 0.2279565663775429, 0.25823767588008195, 0.09484764566877857, 0.09512940945569426, 0.19147323968354613, 0.10341416724259034, 0.25898923398926854, 0.15473122999537736, 0.17548176809214056, 0.2565962530206889, 0.37705073948018253, 0.2058582435711287, 0.18572808156022802, 0.14406278292881325, 0.2204229065682739, 0.24149948498234153, 0.2507490199059248, 0.09748940938152373, 0.14490181056316942, 0.1360610208939761, 0.1951046721660532], [0.051869254020857625, 0.02472890049830312, 0.06463847996201366, 0.05980329879093915, 0.007260314760060282, 0.03964613744756207, 0.09605074126739055, 0.09240384984877892, 0.050848337123170495, 0.039610043095308356, 0.03416556239244528, 0.11665425990941003, 0.05117054795846343, 0.07050315354717895, 0.051497360109351575, 0.07705163458012976, 0.028882122169306967, 0.06923630746314302, 0.0199663366220193, 0.03842363839794416, 0.0589740489522228, 0.07568428685772233, 0.0414523838844616, 0.03683728660689667, 0.11492077363072895, 0.10212022534688003, 0.1465872279368341, 0.29172575392294675, 0.20944093179423362, 0.08444380393484607, 0.23418167140334845, 0.05945490127487574, 0.17659611767157912, 2.7807959960773587, 77.55864903330803, 93.52951884269714, 89.16343912482262, 82.80944287776947, 66.4313717186451, 45.51260121166706, 26.00814711302519, 44.962196946144104, 81.42600551247597, 77.50848412513733, 64.89849597215652, 47.81280018389225, 8.96554671227932, 0.35914164735004306, 0.08811287814751267, 0.2445482276380062, 0.09943711658706889, 0.37630431703291833, 0.011552304131328128, 0.20771677431184798, 0.5544789531268179, 1.0686957417055964, 1.2051503383554518, 55.41873425245285, 121.99142038822174, 90.83664134144783, 90.33252239227295, 94.6060162782669, 104.0990848839283, 110.30039772391319, 104.59120407700539, 108.09226021170616, 108.64475816488266, 105.41912645101547, 106.56069159507751, 107.94416695833206, 109.08439457416534, 92.27411180734634, 94.92044180631638, 93.82835760712624, 87.0761351287365, 93.59091594815254, 90.96448168158531, 101.25587984919548, 92.94270873069763, 108.32780197262764, 68.84273752570152, 12.784315198659897, 1.5329786972142756, 4.308908460661769, 49.28970493376255, 59.534373208880424, 86.86976820230484, 98.25583443045616, 104.4456034898758, 102.08825558423996, 110.2661007642746, 97.7623701095581, 76.09891936182976, 70.55048748850822, 90.85124775767326, 94.92796540260315, 98.69001433253288, 111.66995823383331, 101.10893413424492, 97.69354820251465, 87.6222038269043, 100.80240458250046, 112.01971426606178, 109.71998646855354, 107.00305625796318, 108.4308372437954, 94.16957169771194, 89.79600638151169, 107.18222424387932, 108.00632402300835, 94.65555042028427, 95.40696769952774, 86.9080625474453, 93.98449122905731, 100.5579636991024, 127.48157858848572, 52.65205331146717, 0.22223710140679032, 0.35016151203308254, 0.13826809386955574, 0.03990988559962716, 0.06040673906682059, 0.2710271958494559, 0.4903028014814481, 3.736498625949025, 30.459264367818832, 61.528035029768944, 76.23764231801033, 77.4664355814457, 78.01733002066612, 45.736853778362274, 17.247817888855934, 27.787865214049816, 55.56182697415352, 63.162414729595184, 72.39658042788506, 66.224624812603, 35.497592613101006, 0.16168294212548062, 0.2323694952065125, 0.03529699992213864, 0.11747831100365147, 0.0350313592934981, 0.06927717011421919, 0.03110302877757931, 0.0931765443237964, 0.031041590082168113, 0.12686711736023426, 0.09418865563930012, 0.10414071497507393, 0.09041322424309328, 0.019263556168880314, 0.05416957414126955, 0.09616846815333702, 0.04232953935570549, 0.0575189867959125, 0.051569496863521636, 0.022715626400895417, 0.01648055433179252, 0.012827162627218058, 0.08108313661068678, 0.024451385506836232, 0.013342172296688659, 0.07904637168394402, 0.06618472238187678, 0.0226180061508785, 0.1543943543219939, 0.036255427985452116, 0.04475818794162478, 0.04255228384863585, 0.07146839081542566, 0.12454146402888, 0.03981430068961345, 0.05916240232181735, 0.07939509945572354, 0.13366900471737608, 0.01950122710695723, 0.050260630378033966, 0.027124573607579805, 0.043341992059140466, 0.051477611559676006, 0.05879871285287663, 0.11742328817490488, 0.1595568671473302, 0.10670249743270688, 0.007132335103960941, 0.1495680640800856, 0.15744146425276995, 0.025777538467082195, 0.08794072215096094, 0.08288507116958499, 0.05932186759309843, 0.05048065118899103, 0.056310621948796324, 0.02356670465815114, 0.0361432226782199, 0.04126989719225094, 0.02986416351632215, 0.035375626757740974, 0.08695131313288584, 0.06485037054517306, 0.07920976291643456, 0.0966414091817569, 0.24420084315352142, 0.1583999628201127, 0.15608710411470383, 0.23918160935863853, 0.05046619786298834, 0.10905543953413144, 9.365746937692165, 100.14332994818687, 107.16048941016197, 108.00820112228394, 107.29970633983612, 97.00918972492218, 70.01710250973701, 31.455010436475277, 24.779173359274864, 54.017681032419205, 77.3734849691391, 75.17842635512352, 57.12366856634617, 10.973194632679224, 0.2126521899481304, 0.15473891864530742, 0.19498453330015764, 0.03276361574535258, 0.5948687077034265, 0.05060901305114385, 0.7174709101673216, 0.7646320201456547, 1.6417770716361701, 2.447095289826393, 71.16327300667763, 121.69863849878311, 93.81680622696877, 98.06003853678703, 99.82540100812912, 112.07128509879112, 115.23586168885231, 111.38400077819824, 112.69075825810432, 113.51415127515793, 108.52246552705765, 110.57684808969498, 111.93662032485008, 113.00957635045052, 99.34426322579384, 97.1001036465168, 94.35906752943993, 88.88373613357544, 96.01099848747253, 95.60448110103607, 106.58646941184998, 98.51668283343315, 115.38114309310913, 81.76913470029831, 19.051463305950165, 4.065549094229937, 8.605548329651356, 63.98784443736076, 71.22646361589432, 95.82929223775864, 106.42372414469719, 109.86824691295624, 108.70531171560287, 114.3882791697979, 104.65242639183998, 94.9220073223114, 82.26877748966217, 97.75266543030739, 97.64966055750847, 103.54918599128723, 116.02361261844635, 103.23278456926346, 100.6110468506813, 89.35515403747559, 102.59492039680481, 111.9339756667614, 110.97602427005768, 110.57130038738251, 111.02959379553795, 98.38695779442787, 89.53482359647751, 107.3283340036869, 113.40458035469055, 103.47834259271622, 101.63144409656525, 91.31924584507942, 95.53163900971413, 100.90512827038765, 132.140371799469, 68.25393632054329, 0.4796478169737384, 0.4407446732511744, 0.14819384407019243, 0.1867399999173358, 0.2606708515668288, 0.041895000758813694, 0.4457107395865023, 3.818959901109338, 34.83006723225117, 69.08444255590439, 81.77313968539238, 61.9877115637064, 36.25296168029308, 39.939900040626526, 33.7282707542181, 52.804900109767914, 84.87050548195839, 83.19416463375092, 84.96847942471504, 80.80596998333931, 54.59008611738682, 1.2426704750396311, 0.5790924886241555, 0.10881699490710162, 0.06293770755291916, 0.0181955166044645, 0.11376648166333325, 0.03926144891011063, 0.022431981269619428, 0.05229881280683912, 0.24185038724681363, 0.07846764492569491, 0.11269384078332223, 0.03991748519183602, 0.1256460914737545, 0.05441315071948338, 0.05916771980992053, 0.0979154763626866, 0.07658414091565646, 0.06066819769330323, 0.12524510908406228, 0.08835890010232106, 0.05484601206262596, 0.03389878627785947, 0.03556906754965894, 0.046633661913801916, 0.10303194634616375, 0.10362346030888148, 0.081363898498239, 0.2685792068950832, 0.10620303204632364, 0.036726988619193435, 0.03126461844658479, 0.052098985834163614, 0.09817118334467523, 0.02554118855186971, 0.057242213952122256, 0.05320190633938182, 0.08426460495684296, 0.2157661970704794, 0.1318810076918453, 0.1810843893326819, 0.17701157194096595, 0.09195125108817592, 0.1548403999186121, 0.2231133106397465, 0.2766203769715503, 0.13287441688589752, 0.16654308914439753, 0.3141267690807581, 0.23596499289851636, 0.09149041448836215, 0.22728953888872638, 0.1079486747039482, 0.14237608906114474, 0.15112755383597687, 0.17016202386002988, 0.12324571129283868, 0.20342548348708078, 0.18738323415163904, 0.2153136651031673, 0.12359245753032155, 0.10280117552611046, 0.31760102952830493, 0.15187096316367388, 0.22304362297290936, 0.4058202129090205, 0.2695092960493639, 0.26591608417220414, 0.3261497989296913, 0.12563227268401533, 0.32667363644577563, 12.076500579714775, 122.48987004160881, 117.82675266265869, 115.29677242040634, 111.20186895132065, 84.3732337653637, 56.02059155702591, 36.26007869839668, 64.82520550489426, 124.41806897521019, 103.14092829823494, 81.10705062747002, 72.93682783842087, 19.044397585093975, 0.9241630753967911, 0.21623783191898838, 0.5334238079376519, 0.5331428605131805, 0.7084388541989028, 0.1732277765404433, 0.5957514478359371, 2.1079499507322907, 6.0404266230762005, 3.7003718269988894, 65.06983637809753, 134.37571585178375, 102.12909579277039, 101.29404500126839, 105.39121314883232, 117.85914212465286, 120.47189712524414, 112.8426057100296, 116.80013135075569, 119.64481070637703, 112.80456975102425, 114.06470373272896, 118.32824975252151, 117.63302385807037, 104.91753056645393, 106.6791920363903, 100.29343709349632, 96.7998057603836, 101.80578634142876, 102.59544476866722, 110.73161378502846, 99.75706547498703, 120.15872552990913, 83.20927262306213, 18.957538045942783, 3.9907852560281754, 6.14468352869153, 70.31283304095268, 81.84046447277069, 100.53903311491013, 112.26996123790741, 117.35514476895332, 115.95023855566978, 117.9922565817833, 104.44890931248665, 104.71166521310806, 99.44324791431427, 104.20021265745163, 106.91838920116425, 107.02316477894783, 124.31556567549706, 113.07966738939285, 109.55922469496727, 98.19443732500076, 109.59820300340652, 117.88146212697029, 115.08296549320221, 115.44440969824791, 117.48768165707588, 103.14076870679855, 98.03371354937553, 118.43087464570999, 121.79845154285431, 104.83308389782906, 103.8030731678009, 95.33373042941093, 103.8812805712223, 112.93372482061386, 144.78281021118164, 60.262269750237465, 0.3392717120004818, 0.5874414718709886, 0.33019480062648654, 0.18072752020088956, 0.36355050920974463, 0.4646576807135716, 0.6357238779310137, 8.911206778138876, 47.99305111169815, 85.40842741727829, 102.20569208264351, 114.1049511730671, 101.53209462761879, 58.90848219394684, 23.926704302430153, 35.48545606434345, 75.38426131010056, 81.49585336446762, 92.97563776373863, 98.79618063569069, 57.55378648638725, 0.7181135506834835, 0.8308362832758576, 0.23358401987934485, 0.20338070229627192, 0.136036871408578, 0.18774068215861917, 0.18362845672527328, 0.2710363391088322, 0.12103852699510753, 0.3714770619990304, 0.22536477888934314, 0.2204259642167017, 0.16319410322466865, 0.20343027776107192, 0.13678601011633873, 0.1760554185602814, 0.16683632653439417, 0.2266889187740162, 0.16635301028145477, 0.22894688823726028, 0.13538830855395645, 0.08401441955356859, 0.21008449257351458, 0.14617082371842116, 0.1590777514502406, 0.18629901576787233, 0.17805004434194416, 0.2933666424360126, 0.47193654638249427, 0.17870683019282296, 0.15569041133858263, 0.1336618949426338, 0.20336513203801587, 0.22339164570439607, 0.14957155217416584, 0.22911465814104304, 0.11205689253984019, 0.3152949985815212], [0.035894135653506964, 0.11072130873799324, 0.00809062772532343, 0.035384795992285945, 0.16972062410786748, 0.1806214079260826, 0.03346022524056025, 0.022999019201961346, 0.1278162351809442, 0.00559934326702205, 0.09080547897610813, 0.14621462527429685, 0.05125342358951457, 0.021307228635123465, 0.058551629626890644, 0.02306789978320012, 0.03760015133593697, 0.012524794037744869, 0.04846677038585767, 0.02856608414731454, 0.020710328535642475, 0.08335973398061469, 0.040764134682831354, 0.03592225562897511, 0.022271951966104098, 0.06877958236145787, 0.06400536862201989, 0.1353679143358022, 0.10710995135013945, 0.07944458586280234, 0.15219137800158933, 0.028090580854041036, 5.082783009856939, 87.52464026212692, 95.7616938650608, 92.44379550218582, 89.1742305457592, 68.48239526152611, 32.652103900909424, 45.399481281638145, 83.64339172840118, 75.0732783973217, 79.54405009746552, 77.69444614648819, 44.39933694899082, 3.7003853637725115, 0.44184501108247787, 0.0554425911832368, 0.05068440041213762, 0.20655831147450954, 0.1135924480331596, 0.6309426063671708, 0.3185270813992247, 1.43751107621938, 5.3725602105259895, 1.614140085875988, 61.565493419766426, 115.96900194883347, 83.39542463421822, 104.85414236783981, 90.70991814136505, 92.01916828751564, 98.78496363759041, 105.27625411748886, 104.36019167304039, 100.02438873052597, 100.33813789486885, 101.45919173955917, 102.94618114829063, 108.36608871817589, 101.37739732861519, 99.30235907435417, 85.64808055758476, 89.52482253313065, 93.56150552630424, 102.0237198472023, 87.17645734548569, 85.92910587787628, 98.50903764367104, 102.67982304096222, 97.7327013015747, 63.39065708220005, 34.74544197320938, 48.91678914427757, 58.298645317554474, 80.7952393591404, 98.52938935160637, 91.8073220551014, 93.30248862504959, 89.54009011387825, 98.17236810922623, 122.1472880244255, 117.95035243034363, 76.20958462357521, 90.83553180098534, 94.65848386287689, 97.15484350919724, 105.93731224536896, 104.64484199881554, 95.61324343085289, 88.26091915369034, 90.6453900039196, 108.89963328838348, 109.26173865795135, 110.98499178886414, 113.74319538474083, 122.42427036166191, 91.72264739871025, 76.35285213589668, 83.4224183857441, 96.68179929256439, 93.93889367580414, 96.38580277562141, 92.75968015193939, 95.67955747246742, 80.14357432723045, 117.10449501872063, 30.6103328615427, 0.7172540249302983, 0.2916625526268035, 0.03422951696848031, 0.10420166014228016, 0.08375533579965122, 0.07086555167916231, 0.2977563865715638, 0.1408333273138851, 4.015048379078507, 27.077385038137436, 45.33336102962494, 57.63506792485714, 59.78257969021797, 54.89915393292904, 28.685711435973644, 22.349538132548332, 45.01871891319752, 51.76124431192875, 63.240732327103615, 76.0194656252861, 35.8833859115839, 1.7340856371447444, 0.41120390058495104, 0.12588939716806635, 0.03699177206726745, 0.013623837749037193, 0.020576278111548163, 0.06136599833553191, 0.053751392479171045, 0.030653151843580417, 0.03563926729839295, 0.1916689143399708, 0.060777260005124845, 0.09077283932128921, 0.053920234786346555, 0.040693237315281294, 0.07866612490033731, 0.05467790448165033, 0.017180616669065785, 0.06904095935169607, 0.07287367712706327, 0.08970200186013244, 0.07816435885615647, 0.09868541004834697, 0.04267477532266639, 0.05108275930979289, 0.05893467430723831, 0.02946257998701185, 0.0946458631369751, 0.06824452357250266, 0.04256584288668819, 0.02079690562823089, 0.04234878324496094, 0.01168582113677985, 0.09290693691582419, 0.009659838688094169, 0.05194346136704553, 0.02109273125824984, 0.05450808625028003, 0.05494017204910051, 0.11474481783807278, 0.05034307927417103, 0.08797619680990465, 0.07840030244551599, 0.10568597033852711, 0.03859498545352835, 0.20407530799275264, 0.0897496180550661, 0.1758388153393753, 0.1233178777329158, 0.13754065555986017, 0.08510823390679434, 0.07282180100446567, 0.0245157742392621, 0.035409435295150615, 0.06448663654737175, 0.013445952372421743, 0.03105112296907464, 0.05925625060626771, 0.042599417647579685, 0.049171903447131626, 0.014534540150634712, 0.022064902041165624, 0.16444619541289285, 0.10878529777983204, 0.16279672767268494, 0.0841636951372493, 0.1038318479550071, 0.21045049012172967, 0.08337476247106679, 10.004330221563578, 108.97163942456245, 106.43671184778214, 118.24030727148056, 115.80016940832138, 110.43738037347794, 58.5547249764204, 37.39755526185036, 38.20670284330845, 51.75327993929386, 85.39415538311005, 84.55346569418907, 51.32523290812969, 4.14854234084487, 0.6962822971399873, 0.0989879910775926, 0.1147082299576141, 0.2730690222233534, 0.192048033059109, 0.6370374199468642, 0.28716202068608254, 1.2456092610955238, 1.848174158949405, 4.5222860109061, 74.85890910029411, 118.31933543086052, 91.25168547034264, 110.42467385530472, 92.89372935891151, 94.33753028512001, 102.56197616457939, 110.01212999224663, 107.986990660429, 105.38226842880249, 104.23064142465591, 104.08607438206673, 107.17416107654572, 111.65454626083374, 106.79523020982742, 102.31452584266663, 89.47263613343239, 93.7462668120861, 99.40115377306938, 105.7532349228859, 92.46469438076019, 88.0375063419342, 106.01823270320892, 108.73921349644661, 103.05743917822838, 74.84431028366089, 47.7876303344965, 65.54225742816925, 69.13860484957695, 92.69316092133522, 107.2986575961113, 98.52571114897728, 97.89171516895294, 95.16484469175339, 104.15461510419846, 121.74221456050873, 122.97434404492378, 86.68573647737503, 97.66356781125069, 102.0350432395935, 100.55785730481148, 110.15134692192078, 108.58360424637794, 99.73742052912712, 92.42374777793884, 92.36451655626297, 112.40426883101463, 114.50638443231583, 115.29102712869644, 115.77654227614403, 124.69543129205704, 98.40425446629524, 80.73346987366676, 86.58962443470955, 97.20082864165306, 93.27785834670067, 96.82515040040016, 99.52673703432083, 104.29516196250916, 84.9024161696434, 121.06837391853333, 41.4317873865366, 0.38428590749390423, 0.17909449845319614, 0.06123726168880239, 0.10720412246882915, 0.025949167538783513, 0.12475297611672431, 0.4744384449440986, 0.3625992243178189, 4.036000929772854, 30.70685338228941, 52.28826843202114, 52.34230913221836, 33.51164057850838, 34.1002631932497, 28.25018260627985, 40.06686642765999, 73.28328564763069, 80.9954734146595, 83.70237976312637, 89.30169850587845, 58.18020947277546, 6.08752129599452, 0.2315299480687827, 0.15869631723035127, 0.03819206976913847, 0.07155050945584662, 0.05088808284199331, 0.09600286532077007, 0.11388026032363996, 0.044392528070602566, 0.02175704990804661, 0.18953739199787378, 0.06451511275372468, 0.024993856495711952, 0.016223873280978296, 0.0807936693308875, 0.10286089614965022, 0.055396830357494764, 0.06677993966150098, 0.12108541588531807, 0.036621585095417686, 0.01931559370859759, 0.022234655334614217, 0.037897730289842, 0.04928738533635624, 0.015697260132583324, 0.10705457229050808, 0.0633084771106951, 0.15422088472405449, 0.05509642382094171, 0.08442143560387194, 0.019676880474435166, 0.021816566440975294, 0.029407510774035472, 0.042489572369959205, 0.0446893092157552, 0.09337043782579713, 0.028333574846328702, 0.10758941585663706, 0.23712492518825457, 0.15059353405376896, 0.0844057317590341, 0.3159422997850925, 0.35000138625036925, 0.12164358515292406, 0.10990785551257432, 0.387593837804161, 0.17460613773437217, 0.2491785166785121, 0.27839835500344634, 0.31782551435753703, 0.1199428275867831, 0.1508773906971328, 0.1419994788011536, 0.2477674713009037, 0.18870195635827258, 0.16683901310898364, 0.10785195059725083, 0.21390546957263723, 0.1293250362505205, 0.11765163959353231, 0.13400493044173345, 0.09763629524968565, 0.20539777062367648, 0.2584149007452652, 0.2785867120837793, 0.19244993571192026, 0.2677726111141965, 0.46146463486365974, 0.16613753512501717, 13.015197459608316, 135.08402824401855, 118.23324725031853, 120.36548763513565, 115.10223805904388, 87.78792053461075, 43.31226848065853, 71.12721294164658, 117.54426062107086, 109.0315394103527, 100.96563622355461, 99.28286612033844, 71.94854646921158, 7.6151989214122295, 1.1806979379616678, 0.12672078068135306, 0.2276889924542047, 0.4458941094344482, 0.24122444505337626, 0.9035679430235177, 0.6025722005870193, 4.436051063239574, 12.999519500881433, 4.814507905393839, 69.8515073955059, 130.73529839515686, 98.78351971507072, 118.66115748882294, 102.3467481136322, 104.92647528648376, 108.78415748476982, 116.84730961918831, 114.06180068850517, 111.25117510557175, 107.81956404447556, 107.7321383357048, 110.97889691591263, 115.53729951381683, 110.76803103089333, 108.54061335325241, 93.19883778691292, 95.7467682659626, 103.37849155068398, 110.78071475028992, 95.90374544262886, 91.65251076221466, 113.76338750123978, 115.39210170507431, 108.32772597670555, 78.92590686678886, 49.819046929478645, 66.07083186507225, 90.96923902630806, 98.46391886472702, 116.74447953701019, 104.16626527905464, 105.79805731773376, 103.43649163842201, 113.9929635822773, 129.45783734321594, 128.77639710903168, 90.430146753788, 104.38107535243034, 106.3942377269268, 108.75329554080963, 116.36875569820404, 113.22770744562149, 107.38644808530807, 97.662633061409, 98.52732986211777, 117.49185383319855, 117.54603892564774, 120.02845332026482, 122.73282900452614, 129.6648046374321, 101.27265214920044, 83.93740475177765, 93.69778901338577, 105.27230992913246, 106.70294836163521, 107.6205687224865, 105.7145681977272, 107.84714296460152, 90.83555459976196, 134.96320992708206, 36.66191853582859, 0.7539591053500772, 0.7612724066711962, 0.07528690388426185, 0.43905052822083235, 0.32597408804576844, 0.1931312124361284, 0.9447468677535653, 0.4114761500386521, 9.530175514519215, 43.12252186238766, 61.503716334700584, 87.70494818687439, 81.83655068278313, 67.1832525730133, 39.600338861346245, 27.636426240205765, 58.823165372014046, 71.30315870046616, 82.60230079293251, 104.26326647400856, 65.37502840161324, 4.803868001326919, 0.4906807327643037, 0.26074384921230376, 0.13007144385483116, 0.17103621445130557, 0.11318151344312355, 0.19252854399383068, 0.24178252526326105, 0.21917255100561306, 0.13958359515527263, 0.24673311039805412, 0.2685986808501184, 0.13199293840443715, 0.17367806722177193, 0.10980753198964521, 0.15783693990670145, 0.08632766417576931, 0.12058992841048166, 0.23607043724041432, 0.16095143684651703, 0.11371651286026463, 0.14354578801430762, 0.1968586046132259, 0.09029012420796789, 0.1711663871537894, 0.18977483472554013, 0.19810458150459453, 0.31176656135357916, 0.30704575998242944, 0.17562326596817002, 0.09987361816456541, 0.133957180660218, 0.11928213061764836, 0.18867768812924623, 0.14004492899402976, 0.17973651556530967, 0.12037495791446418], [0.08609913464169949, 0.05739501473726705, 0.025649709095887374, 0.034680449607549235, 0.11859272737638094, 0.03518608595186379, 0.0031162653385763406, 0.02206155866588233, 0.08409886853769422, 0.039464415167458355, 0.07341400516452268, 0.05282712176267523, 0.07569981258711778, 0.0394472530024359, 0.01356489452518872, 0.01742744385410333, 0.03163429704727605, 0.036433001660043374, 0.06552911654580384, 0.021647356770699844, 0.07572747985250317, 0.037406547271530144, 0.04094613155757543, 0.018052656887448393, 0.08289388788398355, 0.060036971408408135, 0.09664808851084672, 0.27823769487440586, 0.17115584865678102, 0.09497140621533617, 0.27750546229071915, 1.2169761350378394, 75.33943891525269, 88.20320025086403, 72.21029922366142, 67.36113622784615, 58.60877327620983, 39.36256282031536, 53.72302584350109, 78.45999106764793, 79.28959295153618, 90.13868719339371, 85.74418500065804, 28.321668170392513, 0.7199769944418222, 0.09093870932701975, 0.15481774957152084, 0.06473069181083702, 0.1342411115183495, 0.23826257820473984, 0.022720882661815267, 1.7862241831608117, 1.5356770274229348, 6.637116204947233, 29.497258588671684, 92.92166545987129, 113.24694201350212, 93.58543664216995, 103.0633744597435, 84.49700072407722, 80.97852632403374, 94.39047664403915, 107.59506449103355, 105.71561694145203, 105.07825434207916, 101.5623714029789, 108.2711774110794, 105.15181839466095, 113.35959076881409, 105.64292684197426, 96.88536956906319, 86.65427416563034, 90.45762687921524, 86.58767893910408, 97.06490233540535, 100.74954941868782, 98.98927867412567, 81.50958582758904, 89.63709890842438, 96.16015568375587, 111.86279028654099, 80.8817607164383, 51.433652490377426, 61.609012484550476, 64.30742248892784, 99.33569848537445, 92.10598602890968, 88.45985367894173, 88.64518493413925, 94.60325762629509, 98.10197308659554, 108.0369883775711, 96.04643538594246, 90.81793114542961, 96.60536259412766, 104.87896263599396, 104.1828627884388, 95.33628389239311, 101.77355647087097, 104.95114356279373, 89.54925522208214, 89.34297949075699, 92.60789349675179, 114.29535895586014, 110.52298218011856, 106.43191650509834, 102.7912786602974, 110.52587002515793, 90.09864494204521, 85.6070351600647, 80.58039888739586, 78.17350924015045, 79.35805767774582, 83.80156204104424, 91.3681948184967, 101.81096166372299, 93.46232324838638, 97.16599211096764, 23.782211355865, 0.3768470050999895, 0.2634523616870865, 0.13448360085021704, 0.04761496667924803, 0.1483569384436123, 0.10154060801141895, 0.08978640631539747, 0.028649173145822715, 1.6057544108480215, 16.832986548542976, 47.131264954805374, 94.97762873768806, 87.41297945380211, 78.65489780902863, 36.62782296538353, 22.105406932532787, 33.81994843482971, 34.97792489826679, 53.254617378115654, 76.50034502148628, 59.74917948246002, 19.21015039086342, 0.7775635574944317, 0.05694241226592567, 0.0521793715597596, 0.04335746954893693, 0.0801441416842863, 0.06968757035792805, 0.08130949165206403, 0.06882861605845392, 0.08549196878448129, 0.060959449838264845, 0.08871983620338142, 0.10624309317790903, 0.046405132379732095, 0.02603417684440501, 0.030847010093566496, 0.04868822725256905, 0.1036658592056483, 0.102208318276098, 0.042705236774054356, 0.04384536856377963, 0.0962978319148533, 0.051272938362671994, 0.02533718514314387, 0.05063882141257636, 0.03915085777407512, 0.05600448974291794, 0.05398625253292266, 0.0626775402633939, 0.09469448865274899, 0.07059729497996159, 0.05487405040184967, 0.1111742043576669, 0.06280713409068994, 0.03480630672129337, 0.036149493826087564, 0.013623608610942028, 0.03396307110961061, 0.01894438813906163, 0.048273396387230605, 0.032560935214860365, 0.08585666015278548, 0.01986042843782343, 0.03897377391695045, 0.14973059442127123, 0.05680189402482938, 0.03774499629798811, 0.041947455756599084, 0.03082269919104874, 0.06397625416866504, 0.08250590792158619, 0.04535570587904658, 0.04175779249635525, 0.012474991290218895, 0.03847204126941506, 0.04638299040379934, 0.049482996910228394, 0.04004680442449171, 0.0902736559510231, 0.045882712365710177, 0.14288383681559935, 0.021371296388679184, 0.14117146463831887, 0.25431625661440194, 0.14107117080129683, 0.13114231842337176, 0.18430099094985053, 2.9380944930016994, 98.07348981499672, 99.62537214159966, 95.996825248003, 99.74991425871849, 96.90616205334663, 59.130473881959915, 29.51506443321705, 43.08574363589287, 70.55472806096077, 93.98993253707886, 98.30985993146896, 33.982879891991615, 0.5653286771848798, 0.3073056897846982, 0.11641554068773985, 0.2560401172377169, 0.25744369660969824, 0.3443228284595534, 0.07143012568121776, 1.553425162564963, 1.735513648018241, 11.898493431508541, 39.59624268114567, 107.67558977007866, 117.2709108889103, 100.69863975048065, 107.12942227721214, 88.23450297117233, 87.83426284790039, 100.9525953233242, 113.48226338624954, 112.03406229615211, 108.28897565603256, 108.92702221870422, 110.3070017695427, 109.04306039214134, 115.38558885455132, 110.03417640924454, 99.97949033975601, 90.83710491657257, 94.06416535377502, 91.3458900153637, 99.20095011591911, 102.91016668081284, 103.01834687590599, 85.92949345707893, 94.4640862941742, 102.26671680808067, 116.03247374296188, 85.3085307776928, 54.34873066842556, 69.79727670550346, 77.00520873069763, 103.82306769490242, 96.95226117968559, 96.52973145246506, 96.08163669705391, 102.34927117824554, 104.13022801280022, 112.21133798360825, 99.79218319058418, 94.5586708188057, 100.98239332437515, 105.80240428447723, 109.3736806511879, 99.78111058473587, 104.16416019201279, 108.33198174834251, 96.24635025858879, 94.7584716975689, 95.30884176492691, 115.17753481864929, 112.89845511317253, 108.00472050905228, 105.63885346055031, 111.43381610512733, 93.8128088414669, 91.36684209108353, 86.207554936409, 84.10752922296524, 83.67159381508827, 87.9123106598854, 94.71231937408447, 110.8652526140213, 97.77343511581421, 104.09029215574265, 37.06806354224682, 0.5959368066396564, 0.3859042644035071, 0.12175803916761652, 0.035086964708170854, 0.2417703837272711, 0.11765938019379973, 0.05117486354720313, 0.08950706192990765, 1.5697108511812985, 18.91837164759636, 51.67332082986832, 75.53060665726662, 52.56014384329319, 29.66573014855385, 24.758069291710854, 33.03578071296215, 58.21321830153465, 67.74613916873932, 69.19818565249443, 90.91323763132095, 82.80287683010101, 35.501141622662544, 1.6750401305034757, 0.06984918043599464, 0.09383456956129521, 0.11266632936894894, 0.03233935589378234, 0.015401097753056092, 0.12739937083097175, 0.09747274074470624, 0.0978957352344878, 0.08106100576696917, 0.05297864234307781, 0.08654364399262704, 0.00939857765843044, 0.015096423867362319, 0.05426898853329476, 0.03543989674653858, 0.053082205340615474, 0.011936114151467336, 0.040143561927834526, 0.06433763555833139, 0.05893663357710466, 0.065931308636209, 0.10307672011549585, 0.05569888075115159, 0.0698431022465229, 0.03278307485743426, 0.04547987089608796, 0.05862895770405885, 0.03792090014030691, 0.06436919909901917, 0.06428924010833725, 0.09139185727690347, 0.04391837363073137, 0.027560869239096064, 0.055862769222585484, 0.25851485319435596, 0.1035596059227828, 0.07124697847757488, 0.07356808986514807, 0.25405585183762014, 0.18470274517312646, 0.14659301668871194, 0.23862146597821265, 0.16776034492067993, 0.1479606018983759, 0.2069188468158245, 0.14342710375785828, 0.1304131731740199, 0.204044597921893, 0.15646248240955174, 0.12196261959616095, 0.10894373146584257, 0.0765056959062349, 0.17238396947504953, 0.10266514727845788, 0.2918731147656217, 0.13925688690505922, 0.1877073003561236, 0.14467788976617157, 0.19742044009035453, 0.16671768680680543, 0.21180271287448704, 0.46607132360804826, 0.32545980939175934, 0.19701681565493345, 0.2581958781229332, 5.136866457760334, 118.76151770353317, 109.83345597982407, 99.10242900252342, 87.64541298151016, 79.54196020960808, 53.287402018904686, 77.79011741280556, 108.77139776945114, 107.59756475687027, 108.41088831424713, 111.00731939077377, 48.10459792613983, 1.7552229529246688, 0.4716002644272521, 0.4820374434348196, 0.5393036361783743, 0.37051995866931975, 0.4920736845815554, 0.27716285723727196, 3.0562498653307557, 5.184260364621878, 11.762229893356562, 32.75400683283806, 103.51312592625618, 125.14237850904465, 104.6124829351902, 115.66320195794106, 94.06356498599052, 93.00269231200218, 105.23645505309105, 119.05432239174843, 115.48534870147705, 112.6029297709465, 111.66996583342552, 115.9347353875637, 112.64604985713959, 120.32656252384186, 116.15035861730576, 108.44678118824959, 94.6559152007103, 100.57160496711731, 97.08553522825241, 106.64207562804222, 108.83417800068855, 109.4646705687046, 91.16030037403107, 97.1235103905201, 109.18644949793816, 122.56184577941895, 93.00361186265945, 68.38738515973091, 84.29665267467499, 85.89648082852364, 111.46403968334198, 102.52594649791718, 103.10486823320389, 105.52903935313225, 111.47012695670128, 113.14678698778152, 115.21574556827545, 105.27878478169441, 104.00892332196236, 107.87762492895126, 115.18158540129662, 118.41040894389153, 108.15244898200035, 108.52097600698471, 113.68339419364929, 103.08540567755699, 98.11434522271156, 100.62486290931702, 121.46425947546959, 115.7959896326065, 108.51369559764862, 113.09400781989098, 117.08095908164978, 101.21751710772514, 96.08498051762581, 90.79368844628334, 86.40407279133797, 86.64407551288605, 92.7646578848362, 104.76339563727379, 116.37580811977386, 102.20008358359337, 108.37995037436485, 32.203116193413734, 0.7351016078609973, 0.43176257866434753, 0.6388825178146362, 0.12464741303119808, 0.4380139260319993, 0.3695395222166553, 0.15938765747705474, 0.12124932662118226, 4.663610402494669, 33.43874529004097, 65.72464004158974, 127.59247183799744, 127.13747665286064, 101.36250972747803, 52.18962952494621, 30.559066012501717, 45.37104740738869, 51.173814833164215, 69.80895727872849, 97.98439219594002, 92.65169754624367, 35.75992293655872, 1.3512748223729432, 0.27573719155043364, 0.24514914461178705, 0.1887633022852242, 0.1870287102065049, 0.126135760510806, 0.23566896503325552, 0.13328103959793225, 0.18885611527366564, 0.14641350600868464, 0.1744671631604433, 0.1734907046193257, 0.10414897507871501, 0.09184873822960071, 0.24153730482794344, 0.1293386472389102, 0.23058409569785, 0.27899029199033976, 0.1486562317586504, 0.1591501702205278, 0.24637690919917077, 0.17700419499306008, 0.12029693592921831, 0.3465791355120018, 0.14408670976990834, 0.1497713234857656, 0.12563516705995426, 0.13447712932247669, 0.17018932005157694, 0.11607032327447087, 0.09379933981108479, 0.16675874241627753, 0.11646679340628907, 0.15286925568943843, 0.1995857895235531], [0.0792750199616421, 0.06764983321772888, 0.008021116318559507, 0.10114184464327991, 0.07861489444621839, 0.013266155037854332, 0.027165208048245404, 0.03932607884053141, 0.0519625902234111, 0.03811147624219302, 0.08197697927244008, 0.07716278603766114, 0.1536153070628643, 0.02598922681499971, 0.018248209089506418, 0.026762674569908995, 0.02342800838960102, 0.06656127327005379, 0.0296191304732929, 0.04088686364411842, 0.047620644108974375, 0.02051980438409373, 0.03065667704504449, 0.10883927418035455, 0.011600918514886871, 0.23031530465232208, 0.09802630127524026, 0.052339118847157806, 0.042504489538259804, 0.3193473623832688, 1.1751773091964424, 48.06230999529362, 96.59834057092667, 92.52005741000175, 75.37977755069733, 61.45658366382122, 32.894078716635704, 67.94393375515938, 117.73842260241508, 79.1604682803154, 96.0615585744381, 74.45034742355347, 21.459274403750896, 0.39162482775282115, 0.0877758243586868, 0.04331869975430891, 0.11040261568268761, 0.027842083836731035, 0.29095644364133477, 0.41956270986702293, 0.3779366856906563, 21.594794131815434, 70.1377460360527, 108.89928370714188, 122.39936649799347, 107.72196248173714, 99.80407655239105, 101.98377639055252, 87.99353510141373, 93.05353358387947, 88.07399198412895, 92.69230216741562, 103.11217904090881, 101.60297602415085, 99.38829526305199, 103.83898884057999, 102.10018694400787, 104.08816426992416, 98.39906394481659, 92.20225006341934, 88.5330605506897, 89.95528623461723, 87.20662772655487, 93.01425129175186, 98.66054311394691, 98.04744601249695, 91.5835140645504, 75.32243862748146, 85.19221901893616, 95.51607504487038, 101.56805589795113, 86.69844299554825, 49.703916907310486, 65.04598125815392, 89.85545039176941, 100.45481443405151, 85.29125690460205, 80.15143230557442, 81.93186476826668, 90.81784754991531, 100.29531419277191, 108.3035896718502, 91.79422795772552, 85.30168354511261, 95.55063799023628, 92.98550963401794, 104.92748603224754, 106.64968281984329, 96.11423134803772, 108.78718212246895, 101.16185009479523, 91.66374295949936, 82.77994126081467, 99.13943141698837, 110.29155939817429, 113.04406329989433, 111.42164155840874, 107.07655191421509, 91.71681091189384, 81.22746616601944, 87.73393303155899, 99.31261092424393, 100.49786612391472, 101.3780964910984, 96.32080346345901, 94.4618672132492, 103.00542756915092, 89.05286505818367, 95.15792906284332, 58.00661198794842, 5.88179606013, 0.3641750116366893, 0.042638239392545074, 0.09559313300997019, 0.11731174337910488, 0.17776532680727541, 0.13711311912629753, 0.11852381896460429, 0.28713827196042985, 11.8026739731431, 77.32393562793732, 112.01559528708458, 83.99152144789696, 82.01585546135902, 49.18331064283848, 26.024885214865208, 29.981430508196354, 52.411925196647644, 55.67589305341244, 68.44145625829697, 74.81242999434471, 54.285931438207626, 3.53105410002172, 0.20519356126897037, 0.060429259538068436, 0.09653861430706456, 0.0835083935817238, 0.02914144155511167, 0.04955610587785486, 0.02725282229221193, 0.03985274765000213, 0.033546633494552225, 0.012469607008824823, 0.056639745889697224, 0.012002665316686034, 0.02339987357117934, 0.07723110073129646, 0.04923274842440151, 0.02986418392538326, 0.027303195565764327, 0.03573762784071732, 0.07924370875116438, 0.01866191374574555, 0.0191212066783919, 0.04795580171048641, 0.0452484729612479, 0.03501115432300139, 0.09300815843744203, 0.03956733620725572, 0.001747020501170482, 0.06776376030757092, 0.0530856748810038, 0.02387812466622563, 0.17076773510780185, 0.04649072798201814, 0.06858179258415475, 0.026220121944788843, 0.0304387194046285, 0.04831553182157222, 0.07989639794686809, 0.026353326320531778, 0.03654240907053463, 0.05669998601661064, 0.05470202428114135, 0.08433096780208871, 0.14026895369170234, 0.10308313969289884, 0.04589244934322778, 0.0794559926725924, 0.08405258820857853, 0.03302042852737941, 0.007295187815543613, 0.0416783492983086, 0.10304626979632303, 0.05027382205298636, 0.014662296234746464, 0.02550058750784956, 0.008549634003429674, 0.040223064497695304, 0.10596893640467897, 0.0975461614143569, 0.22170389798702672, 0.10960632091155276, 0.13481811649398878, 0.05272215239529032, 0.33623641706071794, 2.027049441821873, 64.4953528046608, 108.33352446556091, 110.46592444181442, 105.07779836654663, 80.9119462966919, 54.83954653143883, 43.363003358244896, 73.9627879858017, 77.77545019984245, 103.86440187692642, 85.13071551918983, 25.216828174889088, 0.2889432938536629, 0.11870537055074237, 0.0790432769281324, 0.20984777715057135, 0.13020933489315212, 0.21364430780522525, 0.6724044377915561, 2.019175789318979, 30.95941822975874, 82.86408394575119, 119.22336012125015, 127.63130575418472, 109.30090695619583, 102.07698538899422, 107.18450412154198, 92.85983517765999, 98.3462543785572, 90.52394092082977, 96.57369509339333, 104.91782695055008, 106.14814773201942, 104.62996199727058, 108.07363361120224, 105.20692303776741, 105.48493131995201, 100.70145919919014, 96.21374800801277, 94.61993873119354, 94.74418446421623, 93.05762976408005, 100.70028126239777, 105.74377343058586, 102.83058375120163, 95.02645611763, 77.94840171933174, 89.54127565026283, 98.77961352467537, 105.63596561551094, 93.40881451964378, 58.607602939009666, 75.0508064031601, 97.05513685941696, 106.43223568797112, 94.4000369310379, 87.21869587898254, 90.68559184670448, 98.44644740223885, 105.59264034032822, 112.88922920823097, 100.92550277709961, 94.14738848805428, 100.65130189061165, 96.4038822054863, 108.42416480183601, 110.70122301578522, 99.64155927300453, 110.03990650177002, 104.19352501630783, 94.58134800195694, 88.31852406263351, 101.38286143541336, 114.13804739713669, 114.349604845047, 117.0783144235611, 110.08197784423828, 96.05202108621597, 81.96868479251862, 88.08814242482185, 103.84706720709801, 107.52523183822632, 109.89303678274155, 104.23473000526428, 97.22868874669075, 106.2273582816124, 92.68649607896805, 102.66803607344627, 78.57360497117043, 12.667246330529451, 0.21329143142793328, 0.0753618088492658, 0.11110872466815636, 0.12922753288876265, 0.18596617737784982, 0.10660834857844748, 0.36447032704018056, 0.1326336048077792, 13.224668819457293, 79.85813364386559, 100.65269261598587, 75.79234421253204, 45.800146982073784, 24.633078798651695, 30.5355129763484, 39.2525739222765, 88.79048153758049, 82.37794563174248, 86.80115148425102, 87.48343527317047, 76.64308056235313, 8.24834754690528, 0.39932321466039866, 0.04482730044401251, 0.16454907192382962, 0.05381000359193422, 0.061562786213471554, 0.11561618084670044, 0.021126877472852357, 0.03163594090437982, 0.026274634547007736, 0.027322483983880375, 0.09860208170721307, 0.053258461703080684, 0.05044006684329361, 0.04202509553579148, 0.05494573815667536, 0.09199310079566203, 0.05653067615639884, 0.012567454541567713, 0.019230300531489775, 0.027571919818001334, 0.021422020327008795, 0.06314979851595126, 0.03312854089017492, 0.012817547176382504, 0.031285049772122875, 0.04785846533195581, 0.02942982901004143, 0.041186108719557524, 0.11606069761910476, 0.013714528195123421, 0.09779294035979547, 0.02151868506189203, 0.038759252420277335, 0.18175785866333172, 0.12792026944225654, 0.158790391869843, 0.3281369438627735, 0.21341499901609495, 0.11458237655460835, 0.1415938208810985, 0.24124896561261266, 0.2094940101960674, 0.26505145244300365, 0.2880916645517573, 0.20699220069218427, 0.22781024454161525, 0.21642978099407628, 0.1107389792741742, 0.17788923578336835, 0.15278747101547197, 0.2225512673612684, 0.1507767554721795, 0.16272702516289428, 0.15168365993304178, 0.0676465083961375, 0.169902034685947, 0.2668288961285725, 0.2557059726677835, 0.31198846350889653, 0.2574851381359622, 0.33434138749726117, 0.15948406246025115, 0.48912617086898535, 3.2326399628072977, 84.27893042564392, 124.89574134349823, 122.79021352529526, 102.72381708025932, 78.82759094238281, 42.374668791890144, 94.59156185388565, 162.06019431352615, 105.29667422175407, 115.53876623511314, 99.08470675349236, 37.28940166532993, 1.3321581669151783, 0.20608053164323792, 0.20537676784442738, 0.2769424393773079, 0.20170542265987024, 0.5028271372430027, 0.9947198862209916, 2.6022848999127746, 26.801261454820633, 76.77663579583168, 116.91436842083931, 135.33054381608963, 114.44614246487617, 107.30657637119293, 112.71218150854111, 98.19259822368622, 104.45249632000923, 98.52617472410202, 102.33669385313988, 111.02521643042564, 113.45190301537514, 110.21460592746735, 111.88720017671585, 109.53185096383095, 114.78764533996582, 107.44110435247421, 100.65033674240112, 97.6131521165371, 98.97008210420609, 96.23098388314247, 103.0434863269329, 109.09475281834602, 105.93764662742615, 101.1325840651989, 83.24109971523285, 95.33303126692772, 105.69776549935341, 114.20481741428375, 99.8077243566513, 65.09187519550323, 82.12261453270912, 106.18968710303307, 113.38751167058945, 100.47224789857864, 96.63503140211105, 99.68366101384163, 107.09433495998383, 115.30340686440468, 121.53959423303604, 106.52365878224373, 97.81521767377853, 106.31372764706612, 102.74371281266212, 113.96905526518822, 114.72812533378601, 104.48371544480324, 114.66129451990128, 109.31018605828285, 97.85499393939972, 91.70072257518768, 108.26135873794556, 120.11749014258385, 118.48980188369751, 119.42221865057945, 115.91280296444893, 100.98145857453346, 87.44223788380623, 93.50428059697151, 109.10151645541191, 113.32666173577309, 112.24331706762314, 105.8982427418232, 103.67554441094398, 117.0366382598877, 96.18192091584206, 106.48491606116295, 70.75094193220139, 8.53745598345995, 0.7286578067578375, 0.24410185549641028, 0.18680134584428743, 0.5829199519939721, 0.36367183551192284, 0.26470635377336293, 0.6653523724526167, 0.5149737792089581, 22.716233655810356, 98.97065967321396, 129.67789113521576, 116.09601393342018, 114.31955605745316, 69.79424446821213, 35.443327724933624, 36.56542271375656, 72.64766335487366, 74.16141092777252, 86.31419241428375, 101.25388875603676, 85.90824499726295, 8.924469016492367, 0.34793693921528757, 0.25196260947268456, 0.22166230803122744, 0.1693416983471252, 0.15164943208219483, 0.1957966506597586, 0.1015015562006738, 0.12668074923567474, 0.14281213050708175, 0.10519679854041897, 0.17230114579433575, 0.17863832996226847, 0.12393807570333593, 0.12245720165083185, 0.16286650439724326, 0.20816406671656296, 0.19554601254640147, 0.07839732643333264, 0.128029543266166, 0.21127431857166812, 0.053037921388749965, 0.2531235065544024, 0.21122741483850405, 0.09618944124667905, 0.20324284094385803, 0.2139643664122559, 0.10870942802284844, 0.1885416079312563, 0.2441811910830438, 0.14656911953352392, 0.3156853385735303, 0.06731677960488014, 0.12328838478424586], [0.008909337211662205, 0.039349645740003325, 0.02010523141507292, 0.05737293955462519, 0.06985248299315572, 0.044704367392114364, 0.08047594848903827, 0.009930037958838511, 0.05032747933000792, 0.07457326209987514, 0.0607515742740361, 0.03269395405368414, 0.029046520867268555, 0.11383254022803158, 0.09766979579580948, 0.0587337192700943, 0.05991124045976903, 0.07341531876591034, 0.04529713929514401, 0.029168578184908256, 0.053739722206955776, 0.04938934158417396, 0.12686732516158372, 0.07112162231351249, 0.08467461928375997, 0.06737845207680948, 0.05042385091655888, 0.022232521660043858, 0.0930652221722994, 0.04297692590625957, 26.139141283929348, 89.14572447538376, 94.81684416532516, 80.449488312006, 61.34929642081261, 52.677584141492844, 65.05696266889572, 76.76952257752419, 76.2174654006958, 91.43548160791397, 57.28652022778988, 20.396900810301304, 0.9097882092464715, 0.03213280506315641, 0.14493973430944607, 0.18207978748250753, 0.17571517353644595, 0.3661032597301528, 0.41231759707443416, 8.351124431937933, 81.11173957586288, 119.89505767822266, 112.031220048666, 100.236736536026, 92.17410877346992, 101.15472167730331, 105.33641248941422, 92.46789380908012, 98.34374651312828, 90.09309723973274, 86.57001748681068, 86.57735869288445, 93.50733563303947, 98.81888821721077, 101.2106242775917, 98.24305951595306, 100.66939651966095, 99.17876690626144, 91.69920265674591, 83.92488062381744, 85.30787721276283, 85.04997745156288, 93.19221094250679, 95.12097984552383, 96.05269744992256, 98.49688589572906, 84.20544996857643, 75.84203034639359, 79.18488577008247, 91.30391746759415, 96.84402018785477, 98.0101852118969, 63.357234075665474, 64.0097464621067, 96.98620095849037, 98.48716601729393, 96.42534345388412, 89.51399311423302, 95.54705858230591, 95.35501688718796, 99.93485033512115, 96.5799343585968, 91.92820116877556, 95.33256009221077, 94.03838753700256, 92.11949050426483, 99.32597860693932, 103.93051832914352, 106.58118009567261, 103.07389229536057, 104.00379359722137, 93.07892382144928, 84.17289331555367, 80.8016762137413, 92.044687718153, 97.16438859701157, 102.72046566009521, 104.50396835803986, 99.58260923624039, 81.48765340447426, 87.19553992152214, 99.73033010959625, 92.77403578162193, 98.47227841615677, 99.0962353348732, 99.55990925431252, 98.84941577911377, 102.92182445526123, 96.76218777894974, 106.76537901163101, 100.75614586472511, 24.06012464314699, 0.16273079527309164, 0.2457100004539825, 0.14624941715737805, 0.09877748088911176, 0.08893709251424298, 0.124283448967617, 0.12113282427890226, 0.27660117018967867, 4.919040771201253, 63.95414784550667, 84.30227637290955, 46.49220384657383, 72.99123331904411, 76.32081985473633, 51.42603009939194, 17.30300422757864, 25.235108993947506, 37.24689334630966, 63.38502578437328, 75.48117130994797, 54.08881701529026, 2.3978665564209223, 0.4324235947569832, 0.12553496228065342, 0.04359277489129454, 0.09385638128151186, 0.041792729098233394, 0.03171997799654491, 0.05786071240436286, 0.03836292329651769, 0.04503694231971167, 0.010428634104755474, 0.028629892149183434, 0.06897818107972853, 0.05231982300756499, 0.08442360267508775, 0.0396245743468171, 0.011549493247002829, 0.035512875838321634, 0.07617071270942688, 0.020655207372328732, 0.0428002836270025, 0.029606311727548018, 0.049025206826627254, 0.05414391809608787, 0.10017015811172314, 0.0718747686187271, 0.04517066990956664, 0.1272386364871636, 0.14975474390666932, 0.09098031412577257, 0.03142384251987096, 0.08509254490491003, 0.0304610283637885, 0.022433643680415116, 0.04566763796901796, 0.023801392162567936, 0.046063202680670656, 0.018816447445715312, 0.0641475863812957, 0.039618188166059554, 0.02163678302167682, 0.029414115888357628, 0.02981527639349224, 0.08990766582428478, 0.01987539199035382, 0.04455019734450616, 0.02626821311423555, 0.014627519194618799, 0.06444958111387677, 0.049276869103778154, 0.02379303001362132, 0.03836276373476721, 0.037191320734564215, 0.026348615538154263, 0.031181048907455988, 0.0730699380801525, 0.057720234981388785, 0.13737166853388771, 0.12241449105204083, 0.037736305748694576, 0.06876498431665823, 0.061989387540961616, 0.06461191107518971, 40.56892208755016, 106.43629387021065, 117.80662894248962, 108.10674503445625, 90.7076458632946, 70.22192671895027, 20.788977071642876, 50.579477325081825, 80.3481325507164, 101.59014031291008, 69.9195845425129, 25.36340720951557, 0.3010199364507571, 0.0728295416047331, 0.13151070568710566, 0.1929847421706654, 0.16106393159134313, 0.09612410256522708, 0.3884363832185045, 13.64474292844534, 97.41269007325172, 123.96354496479034, 118.5619144141674, 103.62632185220718, 98.02113622426987, 109.5162945985794, 110.01166641712189, 99.09695729613304, 103.94855216145515, 92.06746369600296, 92.08982929587364, 90.9538422524929, 100.37512511014938, 102.76751473546028, 104.67016384005547, 101.54683783650398, 102.88987576961517, 99.97599452733994, 95.52537694573402, 87.19349563121796, 87.74179100990295, 89.49310183525085, 99.63988736271858, 99.60385769605637, 99.18680727481842, 101.62062987685204, 88.3974078297615, 79.66784745454788, 82.30419158935547, 95.60610741376877, 104.64622512459755, 102.53954216837883, 69.82173219323158, 66.63813382387161, 98.25004354119301, 100.44952511787415, 102.90794759988785, 98.10290783643723, 103.92388388514519, 100.2194094657898, 104.81455609202385, 102.44572520256042, 98.68312150239944, 101.26733243465424, 96.44941136240959, 95.06465926766396, 100.40088012814522, 106.79476663470268, 107.25994527339935, 103.81270945072174, 109.24770221114159, 99.8492181301117, 89.21835377812386, 82.72938877344131, 93.92158940434456, 99.36364218592644, 103.95941197872162, 104.75711077451706, 101.47081911563873, 83.87455612421036, 93.64871084690094, 105.09583219885826, 96.35084465146065, 100.71821630001068, 100.8716368675232, 104.15058732032776, 100.39393410086632, 105.32768055796623, 100.6068442761898, 105.29242604970932, 112.0571194589138, 39.54194739460945, 0.4959117161342874, 0.29551949410233647, 0.16627026081550866, 0.09417045817826875, 0.06824811556725763, 0.19029346236493438, 0.09445815914659761, 0.7052098587155342, 4.275578549131751, 66.41578495502472, 90.61927020549774, 47.092993408441544, 51.603852957487106, 31.27759225666523, 23.76391913741827, 19.54390738159418, 47.82901011407375, 70.71690335869789, 78.36162954568863, 83.79135578870773, 74.52109202742577, 7.700424548238516, 0.5577046237885952, 0.304025515797548, 0.023005353432381526, 0.08988754620077088, 0.09396705034305342, 0.12903347611427307, 0.07477171238861047, 0.042802413590834476, 0.05729630167479627, 0.023562949390907306, 0.0747518525167834, 0.0690037925960496, 0.09635126654757187, 0.12973787816008553, 0.03887930964992847, 0.022277178541116882, 0.060814968528575264, 0.008748787477088626, 0.019434556270425674, 0.04471213396755047, 0.026806606001628097, 0.04631644202163443, 0.06180154625326395, 0.10130862006917596, 0.06526880082674325, 0.05603570076345932, 0.0741817346715834, 0.0720188714331016, 0.05833618786709849, 0.1503788455738686, 0.02420430970232701, 0.08200834243325517, 0.12039592358632945, 0.13291743176523596, 0.13606076856376603, 0.1671042715315707, 0.09840185026405379, 0.1002796991087962, 0.22526099695824087, 0.09458772328798659, 0.0879633057047613, 0.14044386305613443, 0.155064350401517, 0.15211333375191316, 0.16152389987837523, 0.2514378813793883, 0.18105744937201962, 0.1862243705545552, 0.10866040174732916, 0.1821774838026613, 0.14385127084096894, 0.0989864399889484, 0.30741496360860765, 0.1625423936638981, 0.3468715416966006, 0.19041193882003427, 0.1934741291915998, 0.248358680983074, 0.20351951359771192, 0.15330687048844993, 0.19716508191777393, 0.11414776745368727, 56.4833003282547, 122.95014694333076, 122.38982900977135, 105.4669126868248, 79.00799006223679, 71.44077211618423, 86.61604821681976, 112.56876200437546, 98.17505836486816, 110.36918923258781, 84.93643194437027, 36.19535677134991, 1.6276483610272408, 0.2973221708089113, 0.3982213925337419, 0.32377667783293873, 0.7235717203002423, 0.5819444137159735, 0.7578965253196657, 11.172082610428333, 94.26911115646362, 131.88830852508545, 126.90341681241989, 112.15808764100075, 99.60698112845421, 111.72615721821785, 117.43567764759064, 102.87267029285431, 109.53288450837135, 99.76897403597832, 93.98393645882607, 95.90938434004784, 106.03220835328102, 109.95068728923798, 111.34132146835327, 108.58743444085121, 110.03089338541031, 108.06057751178741, 101.20523616671562, 92.71731242537498, 96.26581281423569, 95.97464203834534, 101.96460261940956, 103.72713804244995, 104.3267610669136, 106.87914490699768, 97.31643363833427, 85.02806022763252, 84.76531192660332, 99.02502715587616, 111.38897091150284, 110.50010740756989, 74.9072577059269, 78.34893822669983, 109.12837341427803, 106.40877574682236, 109.38726872205734, 104.97352436184883, 111.49494722485542, 106.47597134113312, 111.19464173913002, 110.02538368105888, 106.16552039980888, 107.9474575817585, 102.83326640725136, 99.33311462402344, 107.65388533473015, 114.145517796278, 114.2780926823616, 110.34878432750702, 110.79444721341133, 102.89998322725296, 92.0431450009346, 87.59938985109329, 98.37089225649834, 105.43435603380203, 109.28335949778557, 111.25171467661858, 110.54793164134026, 88.16630423069, 96.09513357281685, 109.16766330599785, 101.10015660524368, 104.87020790576935, 108.01982089877129, 108.69594141840935, 103.44408363103867, 108.94744232296944, 106.13538801670074, 116.55327379703522, 114.78449150919914, 29.56325724720955, 0.28681891097221524, 0.4434710863279179, 0.22948202124098316, 0.2596595120849088, 0.18994526151800528, 0.4819390346528962, 0.255704399314709, 0.8321758301462978, 9.476359002292156, 83.86501103639603, 97.20013707876205, 71.95094794034958, 104.83287110924721, 106.45287618041039, 68.90307068824768, 20.788883976638317, 35.96527151763439, 54.52820643782616, 81.2586472928524, 94.4180403649807, 89.79785308241844, 7.546561304479837, 0.7659398030955344, 0.3974345972528681, 0.0731862400425598, 0.2448199872742407, 0.21339954750146717, 0.25086779322009534, 0.19035326462471858, 0.1176124913035892, 0.18218107579741627, 0.1286371544119902, 0.12208003478008322, 0.22232753952266648, 0.20888294064207003, 0.2287580116535537, 0.16415420483099297, 0.11665060854284093, 0.19246529816882685, 0.1932830410078168, 0.17057868040865287, 0.17781932547222823, 0.07954706161399372, 0.13112217653542757, 0.09543753432808444, 0.1807981578167528, 0.15636900148820132, 0.22023652360076085, 0.39315409725531936, 0.24514311837265268, 0.1764953785459511, 0.19996633316623047, 0.12847263511503115, 0.134017116506584], [0.07626998980413191, 0.042873941783909686, 0.07529536436777562, 0.04328748502302915, 0.05660064583935309, 0.041624012956162915, 0.05089682905236259, 0.14413088239962235, 0.06557483284268528, 0.034601622392074205, 0.08954957957030274, 0.0561367144837277, 0.01557992844027467, 0.10727127199061215, 0.04793799016624689, 0.05973544793960173, 0.06619173567742109, 0.04667673616495449, 0.017322810308542103, 0.05759827414294705, 0.08915605576476082, 0.07563486724393442, 0.019305084897496272, 0.18593055428937078, 0.04286689138098154, 0.09186364797642455, 0.032936261559370905, 0.12814138492103666, 0.37863941048271954, 30.369100905954838, 91.08833223581314, 94.72175046801567, 78.20016860961914, 69.41230416297913, 45.24935893714428, 40.75750216841698, 96.73159942030907, 85.19554004073143, 101.30925938487053, 55.96210889518261, 16.235818192362785, 0.0625137408496812, 0.14904912473866716, 0.09505587004241534, 0.061098123842384666, 0.0864709506276995, 0.18025113560725003, 0.3023943048901856, 8.235817719250917, 114.79621008038521, 111.35022819042206, 93.31358402967453, 91.11524239182472, 101.61451980471611, 109.78122398257256, 104.24815848469734, 96.70998618006706, 95.43494179844856, 87.80136421322823, 88.94409969449043, 89.11626845598221, 85.0435633957386, 82.05886155366898, 87.04971894621849, 86.18685364723206, 86.50564134120941, 81.28759413957596, 80.6436350941658, 81.12207502126694, 76.23637318611145, 76.8508306145668, 88.59837904572487, 96.48206681013107, 98.36230471730232, 94.87248077988625, 93.64900723099709, 75.79979941248894, 71.27891600131989, 75.79546004533768, 83.66660848259926, 89.35794308781624, 94.1655059158802, 74.75275039672852, 52.570456489920616, 62.84930773079395, 74.71711590886116, 78.5876490175724, 86.37765660881996, 82.8077557682991, 89.47192177176476, 88.2420189678669, 91.34048670530319, 92.3662568628788, 92.8897699713707, 90.6174387037754, 81.78265437483788, 91.82309120893478, 104.78301778435707, 100.82682207226753, 103.96635800600052, 100.76385945081711, 97.69423216581345, 90.1422818005085, 78.74753683805466, 78.46306890249252, 83.78178790211678, 90.26110902428627, 90.02771034836769, 80.4329364001751, 77.12059333920479, 87.17831924557686, 102.51955524086952, 95.37298992276192, 102.9483850300312, 96.06620952486992, 96.98085084557533, 99.7977764904499, 97.26762905716896, 96.82279452681541, 89.53441321849823, 89.38613757491112, 108.71772944927216, 39.52648222446442, 0.4563338711159304, 0.22527483059093356, 0.17611259361729026, 0.14589118247386068, 0.06322095563518815, 0.06580873552593403, 0.1340464610257186, 0.22706103161908686, 4.74113954231143, 67.3297955095768, 98.42731162905693, 49.63757626712322, 77.73216292262077, 79.72486719489098, 64.66150268912315, 26.633481457829475, 28.28007560223341, 55.08798860013485, 56.90911687910557, 76.00867420434952, 64.5606105029583, 9.549643769860268, 0.3766738175181672, 0.010706969169405056, 0.06095121942053083, 0.08293616803712212, 0.0286398591924808, 0.06703645558445714, 0.02194389671785757, 0.06486827114713378, 0.11490242031868547, 0.03892094784532674, 0.02837551732227439, 0.02328841968846973, 0.06406630636774935, 0.08075642836047336, 0.1312234648503363, 0.06064691660867538, 0.011976576042798115, 0.010325374460080639, 0.030031634705665056, 0.013203430571593344, 0.02610706873383606, 0.047777240979485214, 0.04599794192472473, 0.05169523894437589, 0.04241217378876172, 0.00412326348850911, 0.030017331664566882, 0.029426036635413766, 0.06773620436433703, 0.05721170797187369, 0.02247196633106796, 0.04954346710292157, 0.07170020064222626, 0.032021965307649225, 0.023936175457492936, 0.022785755645600148, 0.06873614445794374, 0.0716131244553253, 0.04284948801796418, 0.09679932336439379, 0.016821578610688448, 0.05178320199775044, 0.0413152090186486, 0.02043062420852948, 0.0473669409257127, 0.05681686685420573, 0.04598365558194928, 0.003394409532120335, 0.05352438805857673, 0.07006166473729536, 0.1084901085414458, 0.04029927935334854, 0.03710721313836984, 0.09151207777904347, 0.21476898808032274, 0.17678466771030799, 0.1349275535903871, 0.03904935052560177, 0.06267509859753773, 0.40205057768616825, 46.89896062016487, 115.10641783475876, 118.53441148996353, 106.40918612480164, 92.76981800794601, 70.64976096153259, 27.5757871940732, 62.33516491949558, 86.66194975376129, 107.56576046347618, 67.15047553181648, 19.627801179885864, 0.10633296726155095, 0.04619269631803036, 0.08402341438340954, 0.038192774809431285, 0.19428738945862278, 0.24466983595630154, 0.38112584268674254, 13.331241700798273, 125.56746169924736, 109.65136215090752, 98.71909037232399, 97.91797176003456, 109.31944996118546, 115.29303342103958, 108.11375185847282, 102.25733131170273, 98.80481377243996, 90.0897154211998, 92.79477506875992, 91.97212681174278, 87.96646535396576, 83.73149380087852, 90.46732395887375, 90.97490072250366, 89.5577971637249, 83.88850137591362, 82.94394046068192, 84.08355250954628, 80.75007498264313, 82.0750866830349, 91.16613686084747, 99.95686635375023, 104.20253813266754, 99.52831014990807, 98.2747346162796, 80.50799757242203, 74.81451228260994, 79.35557261109352, 87.82474055886269, 94.39973294734955, 98.0222761631012, 82.67975583672523, 57.6564721763134, 66.06660649180412, 78.51091593503952, 82.9081691801548, 90.01520901918411, 86.47052362561226, 93.05675581097603, 96.62728741765022, 96.239845007658, 99.41006049513817, 99.80422094464302, 93.7793630361557, 85.68122237920761, 95.56387647986412, 107.39096224308014, 103.15618067979813, 103.97638946771622, 104.14522960782051, 101.96699649095535, 93.87336239218712, 81.13787457346916, 80.49181804060936, 86.32407188415527, 90.89366868138313, 94.27715912461281, 84.92795839905739, 80.68883746862411, 90.09943529963493, 104.32153254747391, 100.47944471240044, 105.68606212735176, 100.02842411398888, 97.98465818166733, 101.85272142291069, 100.81608384847641, 100.92293411493301, 96.78404420614243, 90.50756379961967, 113.65778356790543, 56.13593816757202, 2.055173870176077, 0.16982620203634724, 0.09246895846445113, 0.19765780860325322, 0.11166943208081648, 0.15177197550656274, 0.16464201849885285, 0.21516660111956298, 4.047893341630697, 72.86669880151749, 103.36619541049004, 56.77709296345711, 73.26918840408325, 49.99669499695301, 23.690356984734535, 11.321610286831856, 35.79366132616997, 94.93504822254181, 79.33539569377899, 87.69563868641853, 85.53154841065407, 20.358101092278957, 0.2346876380033791, 0.03157596423989162, 0.03730117343366146, 0.058283888720325194, 0.09545116015942767, 0.07239377475343645, 0.030017665631021373, 0.06493165055871941, 0.03694985185575206, 0.0696895964210853, 0.016652168560540304, 0.06253879575524479, 0.04759261690196581, 0.004667098637582967, 0.07298707729205489, 0.00981552550001652, 0.029092021941323765, 0.0169743218793883, 0.005163255436855252, 0.03616174297349062, 0.02074743406410562, 0.025554723470122553, 0.020551987618091516, 0.039376177519443445, 0.05414924300566781, 0.040127861793735065, 0.04510075588768814, 0.054438524748547934, 0.04458108182006981, 0.07324016449274495, 0.015303386589948786, 0.15554817131487653, 0.18154680670704693, 0.11920426448341459, 0.10346542738261633, 0.17382517573423684, 0.14254181063733995, 0.1324916468001902, 0.24432852223981172, 0.19778625952312723, 0.15903354913461953, 0.1619352278066799, 0.16885979217477143, 0.07230925155454315, 0.249784198240377, 0.13090872002067044, 0.14236071176128462, 0.10232286876998842, 0.1965113537153229, 0.16341276961611584, 0.2163562341593206, 0.21245206240564585, 0.3254560095956549, 0.1398099650396034, 0.3644498437643051, 0.25167379528284073, 0.35938438901212066, 0.1451581928995438, 0.3330591937992722, 0.855831460794434, 64.37549963593483, 132.45172709226608, 127.72748619318008, 107.21288099884987, 91.84354171156883, 61.16767376661301, 58.62944036722183, 151.5766328573227, 113.59883353114128, 121.73798158764839, 81.94840148091316, 31.282467395067215, 0.6694751512259245, 0.3115155076375231, 0.24138194363331422, 0.1613885469851084, 0.20655792555771768, 0.3367998555768281, 0.6861117272637784, 11.192019190639257, 128.79668802022934, 121.59276098012924, 105.1603451371193, 100.19135177135468, 112.16269299387932, 121.02013170719147, 115.85910424590111, 107.40967243909836, 106.98036387562752, 100.65377175807953, 101.68284013867378, 98.46080303192139, 91.05635315179825, 89.83946084976196, 97.64602795243263, 96.89142644405365, 95.60494467616081, 90.05502328276634, 89.32706594467163, 89.56810221076012, 84.38641905784607, 86.36321738362312, 96.61017313599586, 103.33243042230606, 104.84719634056091, 103.68597105145454, 103.98753806948662, 84.13345903158188, 79.12696927785873, 83.15251886844635, 92.04403415322304, 100.46920046210289, 106.64430230855942, 89.62147414684296, 65.9226094186306, 75.47680914402008, 87.9532116651535, 94.84786570072174, 101.96056723594666, 95.35231903195381, 102.8160685300827, 107.98239290714264, 108.74802902340889, 105.79664379358292, 103.5778820514679, 100.54534837603569, 89.65210050344467, 100.35463660955429, 111.4752946794033, 106.61968722939491, 108.41604083776474, 107.68539324402809, 107.26793244481087, 97.04046204686165, 86.8693046271801, 84.9964839220047, 93.27940106391907, 98.09580981731415, 99.67738375067711, 88.22410672903061, 83.52036193013191, 96.83447510004044, 110.87650761008263, 105.59901639819145, 110.63381463289261, 104.34582844376564, 104.38749700784683, 108.00683319568634, 109.19765889644623, 106.89812868833542, 101.58557295799255, 98.05856421589851, 123.8540880382061, 47.68787048757076, 1.1678369343280792, 0.7812175364233553, 0.2607138961320743, 0.30039730423595756, 0.4016170743852854, 0.2946524281287566, 0.37996550963725895, 0.5192973534576595, 9.947670511901379, 93.22878777980804, 111.76981687545776, 71.86642527580261, 109.7677955031395, 111.90790146589279, 95.90968072414398, 39.090828001499176, 34.21655595302582, 75.09594798088074, 75.18076702952385, 96.92152842879295, 96.8281826376915, 21.30083430558443, 0.6018581951502711, 0.13737005065195262, 0.24406446609646082, 0.19864418223733082, 0.1498538354644552, 0.11335769188008271, 0.22320790478261188, 0.16409872187068686, 0.17328946385532618, 0.22444021131377667, 0.12403867382090539, 0.13359686796320602, 0.1753301324788481, 0.14911928738001734, 0.19019871979253367, 0.15659914148272946, 0.16382573026930913, 0.12753616349073127, 0.18511097092414275, 0.10767730840598233, 0.09398353344295174, 0.16193758783629164, 0.13529568852391094, 0.1746198526234366, 0.1076176471542567, 0.12193821035907604, 0.14660803775768727, 0.17985968239372596, 0.20800781494472176, 0.07626080943737179, 0.14511364919599146], [0.06248924997635186, 0.04057863858179189, 0.004403560606078827, 0.1011371987988241, 0.015250921387632843, 0.025041103472176474, 0.03284172678831965, 0.011247660859226016, 0.030021773418411613, 0.1431920804316178, 0.003126169299321191, 0.028696260560536757, 0.022435445243900176, 0.01265941777091939, 0.027083089407824446, 0.0317402089422103, 0.09592151851393282, 0.06481094766058959, 0.017554703626956325, 0.015265852471202379, 0.08501329837599769, 0.03739870277058799, 0.14273600099841133, 0.07921973738120869, 0.1520463326596655, 0.17323265987215564, 0.2126133014098741, 4.812100259587169, 49.72660169005394, 96.80791452527046, 87.21985101699829, 67.99151480197906, 67.2382128238678, 49.37223270535469, 59.544347673654556, 91.07535973191261, 74.79111313819885, 107.48249933123589, 64.39515218138695, 18.766250610351562, 0.17418689851183444, 0.11962362244958058, 0.18469898990588263, 0.07629842148162425, 0.06836895947344601, 0.14364450849825516, 0.16415812337072566, 1.8237616564147174, 92.20236405730247, 110.68217843770981, 89.21236529946327, 98.15436467528343, 86.23486027121544, 87.62301698327065, 81.29607528448105, 85.69375410676003, 80.84791973233223, 78.78537520766258, 76.60670131444931, 76.11204385757446, 78.45014199614525, 82.42321640253067, 76.61104068160057, 78.3153784275055, 78.66362974047661, 81.33519798517227, 77.24769651889801, 77.94340118765831, 75.81850960850716, 77.69611045718193, 83.65123450756073, 87.87272438406944, 100.35551056265831, 95.18725588917732, 90.99704593420029, 78.77069279551506, 69.14423614740372, 72.7531760931015, 75.58928310871124, 80.34150570631027, 93.01887944340706, 92.4557876586914, 88.59829545021057, 65.08414641022682, 51.98693320155144, 69.4310675561428, 76.31065919995308, 75.60537904500961, 83.1804321706295, 90.65090730786324, 85.92318579554558, 80.32784163951874, 87.53170788288116, 97.62721136212349, 89.49702322483063, 82.87230670452118, 90.42214438319206, 94.53791633248329, 98.05506080389023, 95.63611060380936, 92.50307232141495, 90.71516185998917, 87.43332356214523, 79.0579117834568, 76.98122441768646, 77.4994558095932, 78.35376396775246, 79.331284314394, 79.00889441370964, 77.8770187497139, 78.99714544415474, 92.37025424838066, 88.8794119656086, 86.38070404529572, 91.78493365645409, 92.31290772557259, 90.10122120380402, 88.6726650595665, 86.9914148747921, 89.8356306552887, 87.56456092000008, 85.00345274806023, 97.23702549934387, 42.4671596288681, 0.745471726404503, 0.0789938350499142, 0.13305140426382422, 0.017375128009007312, 0.041541389655321836, 0.17301492858678102, 0.09109571066801436, 0.2181844407459721, 3.9217925956472754, 59.50525917112827, 93.46305280923843, 60.08079908788204, 114.6948467195034, 108.15264657139778, 102.70835191011429, 52.68093556165695, 17.25209265947342, 36.52552105486393, 52.790821865200996, 72.46078178286552, 71.54451414942741, 22.39706788212061, 0.8438179898075759, 0.18973596103023738, 0.058360730690765195, 0.05211896444961894, 0.0321809667366324, 0.015584737557219341, 0.024091315863188356, 0.11409569095121697, 0.07418235065415502, 0.023097201628843322, 0.05543817169382237, 0.05495566067111213, 0.06841087597422302, 0.0388994218519656, 0.05398176253947895, 0.07974556385306641, 0.04158449730311986, 0.04710171961050946, 0.08033977181185037, 0.03163220048008952, 0.0643693697929848, 0.028223156259628013, 0.028908043532283045, 0.06822284543886781, 0.0072159765386459185, 0.11964705947320908, 0.003687833618641889, 0.023967356792127248, 0.10927130802883767, 0.044758065487258136, 0.09491287302807905, 0.025836630120465998, 0.04103105922695249, 0.10184704078710638, 0.07390036422293633, 0.06756931019481272, 0.0761130997852888, 0.024137794716807548, 0.05956775596132502, 0.07556023687357083, 0.04932819974783342, 0.029363321445998736, 0.039914253138704225, 0.0012743115098601265, 0.037297139861038886, 0.052783446371904574, 0.19848208234179765, 0.003769631744034996, 0.035018995113205165, 0.01761620726028923, 0.05963384421193041, 0.031159597128862515, 0.2312411487218924, 0.0473427283577621, 0.15284111344954, 0.2998566348105669, 0.19656487740576267, 9.392054826021194, 70.6390531361103, 117.35458999872208, 101.59171342849731, 92.56551817059517, 100.83581238985062, 79.89989340305328, 40.96037708222866, 53.28521713614464, 83.32987815141678, 120.73680371046066, 75.31708091497421, 22.5898315384984, 0.08663975953822955, 0.07592728827148676, 0.036312862794147804, 0.15255446633091196, 0.48387618851847947, 1.1142330919392407, 0.22661319002509117, 3.1743883760645986, 101.80120378732681, 113.72975170612335, 96.85803383588791, 104.50823172926903, 89.9453991651535, 91.7083677649498, 85.14184132218361, 88.66994440555573, 84.38214808702469, 82.01389476656914, 79.75216493010521, 79.00960877537727, 82.01476871967316, 85.05998611450195, 81.70595169067383, 81.53950542211533, 81.3748374581337, 86.01254940032959, 82.06215977668762, 83.41194614768028, 79.87420678138733, 81.5333041548729, 86.20079129934311, 90.60416221618652, 103.37691083550453, 99.06848162412643, 94.1906225681305, 80.9221525490284, 74.32401180267334, 78.05961415171623, 79.12112519145012, 86.4054787158966, 96.32219418883324, 96.48660376667976, 94.07795861363411, 71.03395074605942, 56.36217802762985, 72.72755786776543, 82.03493043780327, 82.3415207862854, 91.5900345146656, 100.3604730963707, 94.58916038274765, 86.21929630637169, 93.75617668032646, 102.31285393238068, 93.94277706742287, 86.49221286177635, 92.26828292012215, 97.15435713529587, 99.74498212337494, 99.34776663780212, 94.04515877366066, 94.88661602139473, 90.78188627958298, 82.80704140663147, 80.4342283308506, 79.00754168629646, 81.00058034062386, 80.22003382444382, 80.98388403654099, 82.3020713031292, 82.61705920100212, 95.92960685491562, 90.5373466014862, 88.06253179907799, 92.37461641430855, 95.81252753734589, 91.76851853728294, 91.46987736225128, 90.76745465397835, 91.11029505729675, 94.52682852745056, 90.29285252094269, 102.48470351099968, 57.981578931212425, 2.634176113642752, 0.05424150309409015, 0.11582413804717362, 0.14442536659771577, 0.0850764848291874, 0.1782467876910232, 0.051056702504865825, 0.310756498365663, 2.9199103312566876, 67.34639301896095, 95.7941061258316, 63.926508128643036, 113.82828041911125, 104.78370174765587, 67.962985932827, 26.207455918192863, 32.07999899983406, 58.62282112240791, 73.15897151827812, 78.0298313498497, 89.78362664580345, 39.33417074382305, 1.5865934640169144, 0.18306443933397532, 0.08270247315522283, 0.024590334105596412, 0.03107211090537021, 0.01683867027168162, 0.021671754875569604, 0.08129841880872846, 0.06293979298789054, 0.05309029475029092, 0.03422246656555217, 0.06994303985266015, 0.07497751736082137, 0.06786000201827846, 0.035764575222856365, 0.06676773133222014, 0.02820079720549984, 0.13323922699782997, 0.013802515368297463, 0.008890819699445274, 0.019742128242796753, 0.014252261498768348, 0.016996888734865934, 0.05370964667235967, 0.01835061990277609, 0.03029496168892365, 0.059027954848716035, 0.04245469142915681, 0.04685203515691683, 0.09434035062440671, 0.1110870910633821, 0.14161218161461875, 0.16303666401654482, 0.19339146878337488, 0.21505115262698382, 0.1387922727735713, 0.2506899746367708, 0.15772738406667486, 0.1763291671522893, 0.2546622755471617, 0.1492323461570777, 0.10815661706146784, 0.11119499191408977, 0.12402393476804718, 0.15179263689788058, 0.09883747610729188, 0.269285790855065, 0.1475739132729359, 0.14100811793468893, 0.11153746338095516, 0.3316260175779462, 0.18950648896861821, 0.3414023289224133, 0.1386081162490882, 0.3537630062783137, 0.4979772318620235, 0.13338894787011668, 14.574115108698606, 93.70667293667793, 134.66329962015152, 112.53254994750023, 92.63726592063904, 89.19811606407166, 62.70853288471699, 79.45955023169518, 146.1442467570305, 95.74635788798332, 129.60612058639526, 87.94568806886673, 34.905869364738464, 0.6548413645941764, 0.18523401900893077, 0.37601764022838324, 0.48444120038766414, 0.5013244959991425, 0.4255935503169894, 0.7830338389612734, 3.6388555029407144, 104.36197757720947, 122.28987917304039, 101.27439245581627, 108.05364668369293, 98.44652339816093, 97.56098091602325, 91.03584945201874, 94.79698643088341, 92.07051113247871, 87.13467478752136, 86.26821488142014, 83.22554334998131, 85.41956081986427, 90.59924528002739, 85.19816190004349, 85.73315799236298, 87.87357553839684, 91.50501787662506, 86.23406991362572, 87.61034086346626, 84.86663728952408, 84.77085202932358, 93.9684484899044, 97.2677506506443, 107.56677120923996, 104.30595338344574, 99.83982503414154, 86.56235709786415, 78.86632606387138, 80.86732909083366, 82.98063889145851, 90.9993714094162, 102.95966282486916, 102.80281484127045, 97.88470834493637, 79.16973978281021, 66.28069460391998, 76.25771284103394, 87.17976316809654, 88.53201940655708, 100.6954175233841, 110.49175545573235, 105.02633392810822, 95.7917046546936, 99.90268886089325, 108.54879051446915, 99.99858811497688, 91.47873848676682, 100.39865344762802, 104.33809205889702, 105.53684413433075, 102.75915518403053, 99.0730793774128, 98.39029401540756, 96.30300521850586, 87.88699641823769, 85.2613753080368, 83.39888244867325, 85.74633568525314, 86.43149971961975, 87.04641312360764, 86.7656309902668, 86.81616067886353, 100.08431151509285, 96.33467271924019, 94.02936682105064, 100.6171341240406, 102.29712277650833, 97.4894991517067, 96.24254286289215, 96.77316918969154, 98.27457502484322, 99.59726884961128, 93.86371850967407, 112.00839847326279, 52.03858382999897, 1.8005663948133588, 0.311314890277572, 0.17083356360672042, 0.26350956643000245, 0.20535008021397516, 0.49740800459403545, 0.215105997340288, 0.4826881882036105, 8.03931126371026, 81.98449954390526, 105.23222967982292, 77.97945365309715, 126.92927822470665, 131.5313708782196, 134.197216629982, 72.1584016084671, 23.055426254868507, 49.092727303504944, 71.00052773952484, 91.99365645647049, 104.65850606560707, 44.06901687383652, 1.8722755531780422, 0.36275207705330104, 0.2184334461344406, 0.0968360151455272, 0.13908979977713898, 0.09003370476420969, 0.08417174001806416, 0.1720549160381779, 0.15973726840456948, 0.0943161195027642, 0.13419066031929106, 0.14180028636474162, 0.1541962899500504, 0.19291349599370733, 0.13933838956290856, 0.1935583629528992, 0.13219771179137751, 0.34748327918350697, 0.17384591134032235, 0.0652518130664248, 0.1296397513942793, 0.11277200377662666, 0.10866386015550233, 0.19534149148967117, 0.10421520433737896, 0.2338412482640706, 0.08539251357433386, 0.14612014987505972, 0.3684773010900244, 0.19847823801683262], [0.11407199417590164, 0.016644125535094645, 0.07272823844687082, 0.09150622223387472, 0.03753606688405853, 0.012570293256430887, 0.01565156981087057, 0.00664708833937766, 0.02199497503170278, 0.06245813172427006, 0.024187869275920093, 0.054050118051236495, 0.05772965283540543, 0.05920085299294442, 0.09253895041183569, 0.04450585402082652, 0.05548978064325638, 0.01736195303237764, 0.07408687335555442, 0.04168564460997004, 0.02535608393372968, 0.09564147650962695, 0.10620753688272089, 0.1612180905067362, 0.0930378220800776, 8.228130731731653, 36.73682391643524, 91.33973434567451, 98.789933770895, 91.34893745183945, 74.94663119316101, 79.55137610435486, 44.166052266955376, 49.525269493460655, 98.2368278503418, 91.19324460625648, 115.5579400062561, 72.14657664299011, 22.022261694073677, 0.44141824648249894, 0.049415301909903064, 0.12192968308227137, 0.20805661857593805, 0.3253054723609239, 0.17189205915201455, 0.3651857277145609, 3.0914901243522763, 19.20133676379919, 125.22893786430359, 92.86085352301598, 104.99760746955872, 74.93344590067863, 79.50007125735283, 72.67464950680733, 78.96208852529526, 70.32052382826805, 75.90682446956635, 73.59557569026947, 75.89491590857506, 77.52755150198936, 76.04311555624008, 76.40091195702553, 77.4971455335617, 72.82556220889091, 75.64281463623047, 74.89952132105827, 78.09810608625412, 77.5319592654705, 80.2057845890522, 78.3563782274723, 84.03684541583061, 98.65404546260834, 96.69263631105423, 91.57529130578041, 87.79711604118347, 71.26329123973846, 72.52221688628197, 71.0688404738903, 77.31090232729912, 74.20013844966888, 81.74189776182175, 87.21379414200783, 94.64411303400993, 75.4700531065464, 47.279882580041885, 45.6468366086483, 56.326516941189766, 78.45839515328407, 90.89450463652611, 83.6533471941948, 76.10083445906639, 72.85370349884033, 88.11249151825905, 92.08743542432785, 86.48780509829521, 76.6664569079876, 78.95444333553314, 88.9978440105915, 94.93090644478798, 93.87267842888832, 91.23201012611389, 97.90521964430809, 92.04450532793999, 86.79868161678314, 82.7749103307724, 84.75673958659172, 84.70946252346039, 79.51484486460686, 74.67949792742729, 73.52929964661598, 75.22897124290466, 79.82311472296715, 87.77299493551254, 83.64941820502281, 81.51468515396118, 78.29948008060455, 83.29555839300156, 76.6017235815525, 75.97734868526459, 73.28716143965721, 83.0276271700859, 92.16993659734726, 88.048305362463, 94.0279532968998, 32.12983712553978, 0.2038529605488293, 0.29093046847265214, 0.14144740998744965, 0.1265754533233121, 0.0844006851548329, 0.020822190599574242, 0.03761183645110577, 0.10938820370938629, 4.645910477265716, 62.38730952143669, 98.94563421607018, 83.32078143954277, 81.74461841583252, 116.15392282605171, 93.69357123970985, 43.874144330620766, 19.645318239927292, 47.288637310266495, 79.64460030198097, 66.69387683272362, 84.75589603185654, 60.93567721545696, 9.286647532135248, 0.5618656380102038, 0.044564914132934064, 0.1152223972894717, 0.041486912305117585, 0.015196578551694984, 0.03631692976341583, 0.07496913851355202, 0.024478262384945992, 0.04229604252032004, 0.02844400270987535, 0.022539138117281254, 0.03388744997209869, 0.011464259441709146, 0.09722775779664516, 0.05315424932632595, 0.025759912459761836, 0.021727777748310473, 0.04962569335475564, 0.04147651110542938, 0.03741120053746272, 0.0973181142762769, 0.012072661902493564, 0.01615922294149641, 0.023136921372497454, 0.04099750301975291, 0.03392656486539636, 0.046301873662741855, 0.05327283710357733, 0.07924025776446797, 0.029998041391081642, 0.056778798389132135, 0.05344554600014817, 0.01794953361240914, 0.041812767085502855, 0.04788267789990641, 0.06264930896577425, 0.050459310732549056, 0.03331027430249378, 0.035407976974966004, 0.0998379876546096, 0.053404868885991164, 0.019333494310558308, 0.039390282036038116, 0.05176051454327535, 0.057611157826613635, 0.09465252020163462, 0.13754752784734592, 0.04710109620646108, 0.0040473236913385335, 0.15077826945343986, 0.04989562730770558, 0.2662983495974913, 0.08823726951959543, 12.580952011048794, 47.77413725852966, 111.63620844483376, 116.34688407182693, 117.92152717709541, 109.55543249845505, 113.1652083992958, 62.3886052519083, 24.224796406924725, 49.451599046587944, 98.59213158488274, 127.08975121378899, 82.50731348991394, 26.374156773090363, 0.18289954896317795, 0.05051757674664259, 0.08230733146774583, 0.05558671626204159, 0.35700372769497335, 0.7949062425177544, 1.908207256346941, 3.6420057713985443, 24.193497486412525, 128.53097587823868, 98.2108524441719, 108.19528788328171, 79.91591334342957, 82.9085947573185, 78.44184324145317, 83.94261807203293, 75.48266842961311, 81.12635359168053, 77.7758377790451, 80.91730400919914, 81.61810040473938, 78.7717567384243, 78.67664784193039, 80.10572835803032, 76.41487240791321, 80.21507889032364, 81.9035030901432, 83.32006707787514, 82.23962545394897, 86.56241029500961, 84.97243121266365, 89.26691517233849, 104.17037665843964, 100.51435723900795, 96.84652045369148, 93.36592242121696, 75.84994152188301, 76.12955331802368, 75.6346982717514, 84.25639763474464, 77.3663717508316, 84.20255452394485, 90.81806033849716, 98.35133090615273, 81.81489944458008, 54.99030724167824, 50.661636516451836, 60.25830656290054, 82.38206461071968, 95.42620226740837, 89.63779047131538, 82.25447505712509, 77.93006390333176, 92.724190056324, 97.52954140305519, 92.3664316534996, 81.34132325649261, 81.59555241465569, 92.65099838376045, 98.45004200935364, 95.90578213334084, 93.81260365247726, 100.97645804286003, 96.10799208283424, 92.04059913754463, 87.46317476034164, 88.59159260988235, 89.62568432092667, 84.7244793176651, 78.18400427699089, 75.33870175480843, 76.94345444440842, 82.96469494700432, 91.57865032553673, 88.15327852964401, 85.49833059310913, 80.71862027049065, 87.30671435594559, 77.0538081228733, 77.61064544320107, 76.57654613256454, 89.09283891320229, 94.85836073756218, 94.00539770722389, 98.63956063985825, 45.69043926894665, 0.9767840767744929, 0.11786053190007806, 0.2391586621524766, 0.0696463960048277, 0.09047014696989208, 0.11137752313516103, 0.10513339686440304, 0.038993392590782605, 3.9461792120710015, 68.04801017045975, 99.21194672584534, 89.52231466770172, 82.69937798380852, 125.39099156856537, 75.76671838760376, 31.3924315944314, 34.97680775821209, 68.43508780002594, 98.9845897257328, 72.61476472020149, 96.06369405984879, 83.83439227938652, 16.21157169342041, 0.532797850901261, 0.1425456252763979, 0.20170316653093323, 0.04660973136196844, 0.036746533078257926, 0.0574419221811695, 0.16166275570867583, 0.03091056576522533, 0.01912722178531112, 0.02780238264676882, 0.01774393458617851, 0.02833456004736945, 0.1202907835249789, 0.05247087603493128, 0.05545086612983141, 0.05039263247454073, 0.027139667035953607, 0.050006385426968336, 0.04081993676663842, 0.10351258344599046, 0.07072114458424039, 0.05074898952443618, 0.023226114535646047, 0.021860440356249455, 0.0493074901169166, 0.034111905115423724, 0.08304274786496535, 0.07295746559975669, 0.2984004223253578, 0.10069064854178578, 0.14087531802942976, 0.22469577728770673, 0.0920870789559558, 0.1958332533831708, 0.13258388091344386, 0.1145678898319602, 0.08744349805056117, 0.12086574759450741, 0.16133451863424852, 0.29040642315521836, 0.1551676425151527, 0.14512576104607433, 0.13637183234095573, 0.17288129747612402, 0.15811013930942863, 0.10456880059791729, 0.21833448816323653, 0.19325941102579236, 0.16375203500501812, 0.30537376063875854, 0.11194108781637624, 0.5153839790727943, 0.1091236577485688, 21.72543302178383, 67.70591452717781, 135.11985272169113, 132.31379449367523, 118.49949136376381, 103.26748430728912, 100.70379987359047, 54.2867673933506, 70.66915512084961, 154.12009477615356, 124.57966670393944, 136.92338794469833, 100.97410216927528, 37.816296592354774, 1.1608140799216926, 0.21485997538547963, 0.6088322459254414, 0.428255099686794, 0.5700350215192884, 0.2698127750772983, 1.2419440015219152, 6.542348340153694, 23.79490837454796, 136.76715552806854, 101.040750592947, 116.36810213327408, 85.54593443870544, 87.24188983440399, 79.91684049367905, 87.85732001066208, 78.67463394999504, 86.33034154772758, 82.41502404212952, 86.07820227742195, 86.80277019739151, 84.65360552072525, 85.69066867232323, 87.22571790218353, 81.96364626288414, 86.89612358808517, 86.60026386380196, 89.38401728868484, 85.63993379473686, 90.84005355834961, 86.4287942647934, 93.51638674736023, 105.96828818321228, 104.9014650285244, 102.19689935445786, 98.64206090569496, 81.11563816666603, 80.88077276945114, 80.82436859607697, 89.65357482433319, 83.89473304152489, 91.19738638401031, 97.23221495747566, 104.88867491483688, 86.51306614279747, 64.525196403265, 61.79743677377701, 69.9696734547615, 92.07769274711609, 106.79164320230484, 99.67671498656273, 94.07771542668343, 83.36070969700813, 96.42212122678757, 101.34747013449669, 96.17597803473473, 85.55903613567352, 85.17676904797554, 95.15956297516823, 103.94615828990936, 97.98604890704155, 97.02571123838425, 104.22885552048683, 101.44659161567688, 95.90228632092476, 91.37827187776566, 93.19360166788101, 92.88333311676979, 87.03918591141701, 82.13231921195984, 80.99573940038681, 82.49475136399269, 90.26570677757263, 98.89587208628654, 94.5411765575409, 88.92739579081535, 86.39445930719376, 96.84278145432472, 84.15247321128845, 83.41049462556839, 78.78726750612259, 93.60926136374474, 103.16030725836754, 97.896229326725, 105.22722914814949, 42.02378802001476, 0.7059785455930978, 1.2324397615157068, 0.32066957268398255, 0.4163987858919427, 0.2863751066615805, 0.20962663198588416, 0.16395237034885213, 0.5007289373315871, 10.597074665129185, 84.89413261413574, 119.32708695530891, 90.42067766189575, 85.17394199967384, 127.71809309720993, 113.49773615598679, 61.14215053617954, 24.079577699303627, 61.76978565752506, 99.74312022328377, 82.69251555204391, 112.6346580684185, 96.96576565504074, 20.593760646879673, 0.5699809337966144, 0.2258365324814804, 0.32677103590685874, 0.1601605597534217, 0.09713783918414265, 0.11553903459571302, 0.2519097685581073, 0.14800331991864368, 0.21535451291128993, 0.23815069202100858, 0.15110825799638405, 0.13721213646931574, 0.27244169963523746, 0.16024302720325068, 0.11487007010146044, 0.16987236362183467, 0.12789453176083043, 0.13637310883495957, 0.11343853402649984, 0.2170789524097927, 0.195065590669401, 0.10157591197639704, 0.09077793787582777, 0.0836780782265123, 0.1292390064918436, 0.18216813274193555, 0.17187461868161336, 0.13205805444158614], [0.08208573359297588, 0.025527655488986056, 0.03078317426115973, 0.05843226630531717, 0.043011591624235734, 0.013408574104687432, 0.038471406733151525, 0.011104542318207677, 0.07366062825894915, 0.015632240574632306, 0.06940085644600913, 0.055184138254844584, 0.04176167392870411, 0.06896850347402506, 0.05551412308705039, 0.07885892744525336, 0.01698117375781294, 0.07808232185197994, 0.035345436190254986, 0.04083454594365321, 0.03842094069113955, 0.019862582521454897, 0.28518203005660325, 7.092519868165255, 51.99758023023605, 86.69084340333939, 103.11622962355614, 86.49903729557991, 70.98933354020119, 44.56023931503296, 47.68948920071125, 39.92410808801651, 59.95115764439106, 109.42250043153763, 99.12784203886986, 114.34222564101219, 62.71872013807297, 24.690488018095493, 0.4545429500285536, 0.030049090019019786, 0.046598417320637964, 0.0641524771344848, 0.19754961831495166, 0.1690912086633034, 5.930665237829089, 15.440960694104433, 0.7524832407943904, 58.99315305054188, 124.84762832522392, 98.2163317501545, 94.96587216854095, 86.96830451488495, 91.39257431030273, 88.94360572099686, 88.9804257452488, 90.51704049110413, 89.7241522371769, 74.3172937631607, 73.40284243226051, 74.22791495919228, 70.05948543548584, 69.69704568386078, 72.2443225979805, 73.15151631832123, 73.95141139626503, 74.78713855147362, 82.43620410561562, 87.72244244813919, 91.12943083047867, 90.33853366971016, 99.62097957730293, 93.99501666426659, 90.82460358738899, 92.20827654004097, 74.43529263138771, 67.4437589943409, 71.04493975639343, 73.43914568424225, 75.75819924473763, 70.86609855294228, 79.32618498802185, 85.70100411772728, 87.522132396698, 88.6486579477787, 75.45755937695503, 62.33837954699993, 55.29043793678284, 48.29780995845795, 57.801491394639015, 66.99020773172379, 65.59759005904198, 79.30132672190666, 93.11697497963905, 93.7311740219593, 84.96205016970634, 75.83648264408112, 75.07001057267189, 84.53525707125664, 93.6188292503357, 96.54990836977959, 87.25428476929665, 96.14750236272812, 99.26042452454567, 91.90263614058495, 89.76114705204964, 86.8183645606041, 89.98688533902168, 89.66872081160545, 81.0699874162674, 72.58315041661263, 71.39859437942505, 72.13476687669754, 75.59133499860764, 75.57737454771996, 80.07633313536644, 77.1810632944107, 74.33494001626968, 71.16320461034775, 72.69522920250893, 80.19148215651512, 90.38752064108849, 81.30594715476036, 92.5387904047966, 91.61612391471863, 84.2350959777832, 22.53926955163479, 0.6001307722181082, 0.09314123293734156, 0.18391700374195352, 0.02533520175347803, 0.0738793911295943, 0.03832074704405386, 0.041873196460073814, 0.10609886419842951, 3.529578591696918, 45.54559864103794, 82.34073042869568, 85.80302104353905, 57.22761958837509, 64.39422503113747, 86.81771099567413, 47.13752321898937, 30.664563551545143, 46.4913184940815, 62.417540699243546, 63.383277878165245, 85.57173505425453, 80.88815197348595, 12.730013262480497, 0.2769920148421079, 0.11624049031524919, 0.13178773457184434, 0.04354330332716927, 0.01983595240744762, 0.06004478993418161, 0.03745777401491068, 0.047356736395158805, 0.02292433873662958, 0.010169924207730219, 0.08101722647552378, 0.04210152190353256, 0.04776623492944054, 0.010386441153968917, 0.044737923599313945, 0.033948881246033125, 0.029236466143629514, 0.07778745173709467, 0.0398160373151768, 0.0289859801705461, 0.07387563586235046, 0.08583666669437662, 0.059024500151281245, 0.0619997701869579, 0.058682050948846154, 0.07636246140464209, 0.06844465111498721, 0.07573807029984891, 0.022213804695638828, 0.022452379198512062, 0.09182501176837832, 0.023626866859558504, 0.027083252680313308, 0.007466909191862214, 0.0728502772108186, 0.028947095343028195, 0.04017099170596339, 0.051913137212977745, 0.06164773614727892, 0.09839219492278062, 0.08404184933169745, 0.05305784063239116, 0.10177360527450219, 0.049337142627337016, 0.0588192592113046, 0.007889930584497051, 0.024364609889744315, 0.021120300189068075, 0.05584001868555788, 0.29795376816764474, 9.310661293566227, 67.83157378435135, 104.87608999013901, 123.87053355574608, 99.60958778858185, 106.18325024843216, 73.26055526733398, 61.011749133467674, 63.87049913406372, 27.27004610002041, 73.68061512708664, 101.9805009663105, 124.05755192041397, 71.71789884567261, 29.727191850543022, 0.25325664784759283, 0.034285775473108515, 0.1718903670553118, 0.13401356904068962, 0.3300021687755361, 0.9804575890302658, 7.881198422983289, 6.689281705766916, 0.745613268809393, 63.05594064295292, 130.57684689760208, 102.14821636676788, 100.74409291148186, 91.09552145004272, 95.8295126259327, 93.13770666718483, 95.72526901960373, 97.64856621623039, 93.87133330106735, 81.36118859052658, 78.57208505272865, 78.01043719053268, 77.0911905169487, 74.28251042962074, 76.68531909584999, 75.28809607028961, 78.6969767510891, 79.3719345331192, 87.27519884705544, 93.19323688745499, 95.73774755001068, 95.64844474196434, 103.04766610264778, 97.95818120241165, 96.85114860534668, 95.01523911952972, 78.5026703774929, 70.44335603713989, 75.36773219704628, 75.6501254439354, 82.58748918771744, 76.28071680665016, 84.05007630586624, 90.06035059690475, 92.13647559285164, 92.39638164639473, 84.50919046998024, 72.07406133413315, 65.66133543848991, 54.111896976828575, 61.3978274166584, 73.48484203219414, 73.6095741391182, 84.00928169488907, 94.83230173587799, 96.25404104590416, 89.05734121799469, 80.62855750322342, 79.09986153244972, 87.88385018706322, 98.04511293768883, 99.29678857326508, 87.54543274641037, 98.01073238253593, 102.8182952105999, 94.51213091611862, 93.57463002204895, 90.54023444652557, 93.62471893429756, 92.46194332838058, 86.23167604207993, 79.1043908894062, 75.25416389107704, 75.59278652071953, 77.41684064269066, 78.71912196278572, 84.2142578959465, 81.42437919974327, 77.88839533925056, 77.80703410506248, 79.85898479819298, 83.01377311348915, 92.16378852725029, 85.86271584033966, 93.98832902312279, 95.43949395418167, 91.9378450512886, 35.347664058208466, 0.5207520816475153, 0.340331380139105, 0.21444840996991843, 0.5967399885412306, 0.021911795120104216, 0.11965514146140777, 0.07891619898146018, 0.19215708423871547, 3.2359816459938884, 49.785525128245354, 91.86982110142708, 97.60058999061584, 64.1992498934269, 69.06165137887001, 46.76046945154667, 34.4029625505209, 47.383951395750046, 73.11832889914513, 86.0490882396698, 79.9724543094635, 91.88391834497452, 101.97825908660889, 20.499383211135864, 0.3501800954109058, 0.06719664816046134, 0.1224562813877128, 0.06387230154359713, 0.005887121697014663, 0.0213199026620714, 0.04220431306748651, 0.02322481021110434, 0.04511130180617329, 0.004329098610469373, 0.06749947409844026, 0.027335018858138938, 0.08919618368963711, 0.02734057754423702, 0.024898586998460814, 0.06469480154919438, 0.030209115611796733, 0.004500264303715085, 0.05831605340063106, 0.023458952236978803, 0.04207415149721783, 0.13642804260598496, 0.05970363206870388, 0.07595649920403957, 0.07646164944162592, 0.05488503047672566, 0.05950275495706592, 0.18854527414077893, 0.2068258260260336, 0.13673843845026568, 0.15627641114406288, 0.19091688125627115, 0.11995367778581567, 0.09361464894027449, 0.1149705791613087, 0.19950778980273753, 0.1705797342583537, 0.18640861613675952, 0.1474489801330492, 0.17084119288483635, 0.18062366405501962, 0.17962216545129195, 0.1651829550974071, 0.1583505209418945, 0.2169989192043431, 0.09333635840448551, 0.16149105242220685, 0.22360066417604685, 0.16370256344089285, 0.29100073501467705, 13.901170268654823, 87.98146694898605, 129.2222347855568, 138.7942859530449, 110.39229959249496, 97.05721154808998, 67.57479876279831, 66.19100421667099, 51.42653167247772, 88.75377550721169, 161.66399717330933, 129.57971960306168, 131.90457165241241, 85.61614707112312, 42.36024856567383, 1.1399771855212748, 0.10035934639745392, 0.4046792647568509, 0.4179433436365798, 0.6431485014036298, 0.41122147464193404, 9.173106774687767, 26.00066151469946, 1.3333611586131155, 69.74167048931122, 136.25241994857788, 110.27072131633759, 105.90789422392845, 96.41150459647179, 100.9144301712513, 99.84224170446396, 99.63778227567673, 101.87925159931183, 98.22557285428047, 85.00323235988617, 84.70342084765434, 81.29960149526596, 80.82809239625931, 80.46067491173744, 81.8280391395092, 82.92605102062225, 84.1538867354393, 83.51534619927406, 91.92147552967072, 97.75575086474419, 100.79716086387634, 97.99074545502663, 105.63360214233398, 101.58928155899048, 105.06678655743599, 102.5797288119793, 83.46261262893677, 75.30581071972847, 81.3956755399704, 83.36284518241882, 86.06817081570625, 79.5733617246151, 90.28413578867912, 95.50049588084221, 96.91935494542122, 99.02191132307053, 87.66393318772316, 76.38651832938194, 67.65269458293915, 60.56424714624882, 73.28917533159256, 83.71244922280312, 80.71893945336342, 87.33470365405083, 99.77807834744453, 101.2151688337326, 93.51799786090851, 84.73752021789551, 83.49463731050491, 94.32744562625885, 104.08025309443474, 104.47705820202827, 91.60702720284462, 101.85669600963593, 107.04681470990181, 98.12674015760422, 95.98319917917252, 96.0405533015728, 97.23702549934387, 98.37107464671135, 89.72341507673264, 83.51599976420403, 79.09840241074562, 79.02853935956955, 83.11734035611153, 83.28085318207741, 90.4515092074871, 88.12126144766808, 82.04110130667686, 79.72103700041771, 81.99245631694794, 86.67967960238457, 98.11656430363655, 91.54092594981194, 102.2844922542572, 102.60797649621964, 101.49833723902702, 32.07478567957878, 1.1883440776728094, 2.368789091706276, 0.37817993201315403, 0.8608728996478021, 0.24837024364387617, 0.32411263324320316, 0.13809156662318856, 0.3678532736375928, 8.118561711162329, 64.49725270271301, 98.45594689249992, 109.0733827650547, 72.82210439443588, 87.98241689801216, 112.84914895892143, 60.05104288458824, 40.17905540764332, 63.07870902121067, 83.67701232433319, 83.23914662003517, 103.89787048101425, 118.90385046601295, 28.97902149707079, 0.4983038955833763, 0.2806318335933611, 0.2686432097107172, 0.12401582309394144, 0.09291723050409928, 0.17864058609120548, 0.18394793645711616, 0.2406340665766038, 0.10559179179836065, 0.0670602339960169, 0.265317972516641, 0.09218601466272958, 0.17265979608055204, 0.19122809346299618, 0.13200203713495284, 0.21151744615053758, 0.13133478700183332, 0.20081371738342568, 0.113654150190996, 0.09219549188856035, 0.23576789331855252, 0.20236198586644605, 0.15349562832852826, 0.23030430602375418, 0.14685864618513733, 0.15856181038543582, 0.2588163432665169], [0.03708312302478589, 0.04981697078619618, 0.09737242464325391, 0.024911500368034467, 0.09919139891280793, 0.048053097270894796, 0.04213868494844064, 0.023067883084877394, 0.012577273155329749, 0.03166211645293515, 0.047472938167629763, 0.04133830836508423, 0.053332101306295954, 0.0347580077504972, 0.05454043646750506, 0.0974075950216502, 0.027447697284515016, 0.030970922780397814, 0.03610689083870966, 0.11049772932892665, 0.046343864378286526, 0.21997787029249594, 18.998108468949795, 101.99880078434944, 112.10967063903809, 100.59434294700623, 81.19512990117073, 83.7840373814106, 55.81276550889015, 66.7133317887783, 189.11411941051483, 99.43530634045601, 72.56279870867729, 79.70991119742393, 109.6193678677082, 74.4229356944561, 24.928898625075817, 0.37222458282485604, 0.08839240806992166, 0.1101129554444924, 0.22031338041415438, 0.19375771866180003, 0.201913075579796, 5.108837261795998, 53.81069093942642, 10.700997188687325, 0.5806386494077742, 93.43606665730476, 107.94118031859398, 106.93108052015305, 101.55724167823792, 95.11587291955948, 95.682452917099, 99.3719333410263, 100.78946247696877, 97.32917815446854, 94.18224021792412, 96.50356605648994, 83.56106534600258, 77.31540128588676, 75.15986815094948, 74.39406484365463, 71.25182345509529, 72.05957651138306, 70.16266509890556, 72.74844914674759, 80.2312584221363, 90.01014769077301, 93.56959149241447, 99.11314442753792, 89.32987779378891, 90.90865507721901, 93.6960107088089, 78.46401125192642, 67.31648102402687, 66.0925742983818, 67.87215560674667, 74.10662546753883, 78.50672096014023, 73.99679616093636, 73.11927124857903, 78.2336600124836, 80.13413563370705, 83.65302041172981, 85.48565447330475, 92.95920744538307, 94.46600139141083, 83.04568380117416, 46.74688138067722, 55.943634286522865, 61.1708427965641, 82.78585374355316, 95.32809153199196, 84.62236359715462, 81.21698632836342, 72.47034206986427, 71.3782274723053, 80.89358568191528, 85.33583611249924, 89.96448174118996, 84.20500159263611, 81.57010897994041, 101.03992223739624, 91.78684115409851, 92.97360867261887, 92.837203592062, 92.92207583785057, 90.69586649537086, 83.8366873562336, 72.9017861187458, 75.4953445494175, 72.79027730226517, 73.1743074953556, 75.4171447455883, 72.81610831618309, 74.32550132274628, 77.67360046505928, 79.97844278812408, 81.47591963410378, 78.07933509349823, 80.08300557732582, 86.27354979515076, 80.99577739834785, 92.29596823453903, 93.77661198377609, 92.26906567811966, 24.385685473680496, 0.8078551758080721, 0.07937204092741013, 0.059066776593681425, 0.07936487178085372, 0.0050631021440494806, 0.16867642232682556, 0.03736635255336296, 0.15221788751659915, 5.711174765601754, 49.05099794268608, 83.22110518813133, 92.1292331814766, 44.825278893113136, 72.78039783239365, 78.50176602602005, 26.40186868607998, 26.441369466483593, 31.823432967066765, 46.725256741046906, 72.23921567201614, 74.26224991679192, 79.55120131373405, 13.445474971085787, 0.5573912593536079, 0.08038419677177444, 0.08967437170213088, 0.06051191252481658, 0.028583394741872326, 0.054372866943595, 0.03511478040309157, 0.05671615741448477, 0.05396294538513757, 0.042484176956349984, 0.017402936282451265, 0.021731911510869395, 0.045126137338229455, 0.0029803864481436904, 0.03895754685800057, 0.04595705329847988, 0.022387500648619607, 0.05350470259145368, 0.03165682494000066, 0.06000006069371011, 0.06496070564026013, 0.0741494215617422, 0.045455457948264666, 0.047055060786078684, 0.016186404100153595, 0.014407772050617496, 0.02308061833900865, 0.035298257862450555, 0.028127539808338042, 0.0660675521066878, 0.07726653086137958, 0.033235836890526116, 0.058274248222005554, 0.0316901918995427, 0.06018711159413215, 0.0043041234857810196, 0.05936315697908867, 0.05947869081865065, 0.017619107202335726, 0.01741071027936414, 0.09794203782803379, 0.009960718343791086, 0.04146684463194106, 0.07810115013853647, 0.046869635189068504, 0.15404202713398263, 0.033539898504386656, 0.28495772334281355, 23.695486709475517, 121.44382417201996, 128.23460698127747, 110.04166960716248, 98.16001877188683, 115.58356583118439, 88.06073069572449, 66.21406137943268, 146.89400732517242, 49.36491809785366, 57.00270965695381, 95.1725734770298, 120.26444345712662, 85.86891710758209, 31.43733948469162, 0.1739170981454663, 0.057769231571001, 0.1518486690474674, 0.36087064363528043, 0.21254828927339986, 0.8428146655205637, 8.235187903046608, 48.560999035835266, 6.374152265489101, 1.3605510746128857, 101.70484095811844, 111.06135249137878, 111.93489521741867, 106.13617837429047, 101.56784310936928, 101.19596466422081, 105.93346685171127, 107.11461827158928, 104.20797944068909, 100.16668349504471, 99.79805007576942, 88.44927504658699, 81.67910233139992, 77.1834571659565, 78.15077885985374, 74.82887551188469, 76.75783440470695, 75.48837572336197, 75.03775790333748, 85.33181592822075, 93.49019095301628, 97.63956069946289, 102.36357361078262, 94.92421120405197, 95.53228497505188, 96.63186997175217, 81.92402198910713, 72.03961238265038, 71.05196937918663, 71.7985837161541, 76.11329779028893, 82.89312958717346, 77.99935698509216, 76.5823370218277, 82.72695690393448, 87.21693277359009, 87.29946434497833, 88.47860187292099, 97.41980329155922, 97.91820734739304, 91.5908020734787, 55.869621858000755, 60.5704940110445, 65.68512976169586, 84.08917620778084, 99.40540954470634, 90.60573533177376, 84.96540918946266, 77.48563975095749, 75.47694593667984, 82.486612200737, 90.3381384909153, 95.34872442483902, 90.3544320166111, 81.83949172496796, 100.08548945188522, 98.46695870161057, 98.46979334950447, 97.00527593493462, 96.96535527706146, 95.43675810098648, 89.29518565535545, 76.68588906526566, 76.99678838253021, 76.41147539019585, 76.84245586395264, 77.91607305407524, 77.99728989601135, 78.58831018209457, 81.9718462228775, 84.6111997961998, 84.47721898555756, 84.66563567519188, 81.91373214125633, 89.31757405400276, 85.45895710587502, 94.43043529987335, 95.3828389942646, 100.57156696915627, 37.14929178357124, 0.42021449364256114, 0.23003278387477621, 0.18959921289933845, 0.4545798199251294, 0.12450478709070012, 0.11989484031801112, 0.032716292698751204, 0.291785808512941, 6.067313030362129, 53.20261336863041, 88.80539953708649, 97.8678448498249, 52.83882088959217, 66.66849419474602, 38.478532657027245, 28.347521983087063, 46.55131347477436, 58.77363882958889, 64.71585497260094, 82.44646355509758, 82.74445116519928, 100.84512189030647, 21.010326594114304, 0.36717952229082584, 0.09786971553694457, 0.09975763532565907, 0.05944664488197304, 0.010793036035465775, 0.07251753529999405, 0.03989012220699806, 0.029618412445415743, 0.11289895555819385, 0.027434776493464597, 0.06435186995076947, 0.03005458005645778, 0.12431218492565677, 0.006596585189981852, 0.05416560736193787, 0.0259328811080195, 0.07618344796355814, 0.009965031149477, 0.06556329244631343, 0.06311526638455689, 0.05255206699075643, 0.0454330525099067, 0.031116949612624012, 0.019484189251670614, 0.04527880453679245, 0.06397356759407558, 0.12942773464601487, 0.19230941747082397, 0.14212277921615168, 0.11297974575427361, 0.19342724030138925, 0.1913976890500635, 0.1753805243060924, 0.10404002779978327, 0.20089961355552077, 0.11705763943609782, 0.15659299649996683, 0.20978895452572033, 0.21243285562377423, 0.12753706891089678, 0.2503332094056532, 0.18302605545613915, 0.06706319516524673, 0.1649981751688756, 0.09273363059037365, 0.28013634611852467, 0.20367797696962953, 0.34396463830489665, 35.06246656179428, 149.18602913618088, 142.89987444877625, 125.38817211985588, 106.73889443278313, 111.90933018922806, 74.88782554864883, 81.51653945446014, 198.40886145830154, 123.69130477309227, 115.39907813072205, 100.69265127182007, 131.3046446442604, 97.44889453053474, 46.690553203225136, 1.055796027649194, 0.1851585425902158, 0.22143019392387941, 0.3977024235064164, 0.5430087342392653, 0.5752277397550642, 6.38852926902473, 67.40926444530487, 15.68755891174078, 1.2678111135028303, 105.53130403161049, 112.70123049616814, 119.2987708747387, 110.44428080320358, 106.58265441656113, 105.78005388379097, 109.61848631501198, 110.70550918579102, 106.42576083540916, 102.08315625786781, 103.22863519191742, 91.56803369522095, 86.03367626667023, 83.75010520219803, 83.7918421626091, 81.40251517295837, 81.81727051734924, 81.84890002012253, 82.42991924285889, 91.0648874938488, 98.78733471035957, 102.71428719162941, 107.45642513036728, 100.01032948493958, 102.16566503047943, 102.3644171655178, 85.28274536132812, 75.90938553214073, 74.66049894690514, 76.11211985349655, 82.99594447016716, 89.47998493909836, 86.5904451906681, 82.68968850374222, 87.00981348752975, 93.05194526910782, 92.97298550605774, 95.74752062559128, 103.23897823691368, 105.34681633114815, 93.57646152377129, 61.11916936933994, 73.51675271987915, 73.27384695410728, 89.61444452404976, 104.40002113580704, 93.80428209900856, 88.02899479866028, 80.82009762525558, 77.8622679412365, 87.7242511510849, 95.59315770864487, 97.84926384687424, 92.37087741494179, 82.10350155830383, 103.33965763449669, 100.51864340901375, 103.50982770323753, 100.2015732228756, 99.87128734588623, 98.92813235521317, 93.050896525383, 80.63233450055122, 84.49898421764374, 81.11829802393913, 82.36045137047768, 83.98390665650368, 83.24736177921295, 83.06982770562172, 89.41238656640053, 89.1885481774807, 90.5023580789566, 87.94679000973701, 87.12479531764984, 95.36546632647514, 89.19513702392578, 101.5706017613411, 101.65837705135345, 104.04861599206924, 34.22272302210331, 1.594570423476398, 1.7613565362989902, 0.41006087441928685, 0.7294515485409647, 0.2257150280638598, 0.44196660455781966, 0.11935127651668154, 0.42704332096036524, 12.61653520166874, 68.29903990030289, 92.84439280629158, 112.55819857120514, 62.56965413689613, 112.5802905857563, 101.10521033406258, 35.505841970443726, 35.489480048418045, 43.136429116129875, 66.86258777976036, 95.5255289375782, 89.93846073746681, 116.96652442216873, 26.83172632008791, 0.8548606722615659, 0.22438432759372517, 0.2936361311003566, 0.172383286699187, 0.13014021125854924, 0.12051488985889591, 0.14868421072605997, 0.15181172493612394, 0.2552035090047866, 0.17499249981483445, 0.15184394898824394, 0.12961468164576218, 0.13180995447328314, 0.09105779434321448, 0.13950853433925658, 0.17852176824817434, 0.18238234624732286, 0.10192939691478387, 0.08140023404848762, 0.13286939996760339, 0.1569647531141527, 0.14046271360712126, 0.15153432497754693, 0.12688014947343618, 0.1306498737540096, 0.18985237431479618], [0.07256164113641717, 0.03265142899181228, 0.05559145487495698, 0.025483631288807373, 0.012514282443589764, 0.0644907183595933, 0.056646599623491056, 0.07334485184401274, 0.10413672222057357, 0.008995736188808223, 0.08696337303263135, 0.07446714982506819, 0.03482483072730247, 0.04649510665331036, 0.04668596477131359, 0.018838060641428456, 0.1115530781680718, 0.01781075756298378, 0.03402259506401606, 0.03869699365168344, 0.3727104817517102, 28.890358954668045, 125.89264065027237, 93.15833956003189, 98.29190209507942, 69.73750591278076, 82.75042444467545, 47.679195553064346, 38.07084113359451, 43.43249022960663, 121.8299974501133, 131.46736711263657, 80.47578290104866, 119.01403695344925, 79.44194957613945, 34.72721055150032, 0.943298670463264, 0.016102329900604673, 0.07640029609319754, 0.09759473497979343, 0.35207087988965213, 0.1803994909278117, 0.4117173480335623, 16.99110746383667, 15.477729421108961, 1.7330946028232574, 38.34288373589516, 103.9160107076168, 108.63936245441437, 109.37589973211288, 101.80638670921326, 105.52944973111153, 107.72564828395844, 102.14284345507622, 96.45451828837395, 97.99356490373611, 102.30479836463928, 94.85790476202965, 94.43280637264252, 82.64860510826111, 74.41989585757256, 72.02898815274239, 72.17897370457649, 71.0151569545269, 73.24227064847946, 69.47360247373581, 75.21956294775009, 83.19613292813301, 94.51716184616089, 91.44609823822975, 90.98200634121895, 92.0067809522152, 78.29921409487724, 67.55970597267151, 66.26016050577164, 68.63944083452225, 74.0700714290142, 79.27909791469574, 75.2483806014061, 72.19606518745422, 73.06440979242325, 77.32111617922783, 79.65031519532204, 81.23282387852669, 80.00573292374611, 78.93478319048882, 76.4317587018013, 90.80168321728706, 79.95801508426666, 48.85265998542309, 53.78410376608372, 80.94292223453522, 93.62370818853378, 90.45958757400513, 83.6227360367775, 74.21985179185867, 70.44036939740181, 76.00276932120323, 85.33407300710678, 91.37520924210548, 89.47277292609215, 84.99191656708717, 90.22656887769699, 93.76199796795845, 93.05709779262543, 95.27592033147812, 87.70424902439117, 89.51735213398933, 92.27009922266006, 78.63681837916374, 68.35125669836998, 66.11697658896446, 69.66743767261505, 69.2371791601181, 71.53441429138184, 75.04767537117004, 76.3044199347496, 80.36302775144577, 82.29700237512589, 84.20385405421257, 87.54251450300217, 80.84372475743294, 84.13032799959183, 84.44780096411705, 89.73853826522827, 89.14105072617531, 100.60790821909904, 23.824696876108646, 1.169498038943857, 0.29849081591237336, 0.08569393685320392, 0.12937167281052098, 0.046678725120727904, 0.04912366013741121, 0.0800758418336045, 0.17623056541197002, 11.88741322606802, 53.291475400328636, 87.12223425507545, 108.35334420204163, 59.45933863520622, 70.51669210195541, 68.10921728610992, 32.39863470196724, 29.072245694696903, 35.92406652867794, 66.15460216999054, 71.29160732030869, 67.80147939920425, 69.72400143742561, 3.108159117400646, 0.05372385880036745, 0.055502649483969435, 0.031726913366583176, 0.04439067641214933, 0.058487571150180884, 0.048815245827427134, 0.040058426457108, 0.03859983909933362, 0.03704190043208655, 0.02453351713484153, 0.030236359853006434, 0.036696152383228764, 0.023876709019532427, 0.1451394907780923, 0.02835113034961978, 0.06527541336254217, 0.04340429535659496, 0.03435222366533708, 0.06856373613118194, 0.030217446219467092, 0.05034035930293612, 0.04354855031124316, 0.008289231082017068, 0.04774583700054791, 0.0723212817683816, 0.01556153709316277, 0.07223073233035393, 0.028771736979251727, 0.032695568224880844, 0.02586096328741405, 0.04635964614863042, 0.022677051420032512, 0.044601765475817956, 0.06129936460638419, 0.033358810760546476, 0.07162790803704411, 0.07748875956167467, 0.047615812727599405, 0.03200639876013156, 0.05201068881433457, 0.04730760250822641, 0.06089871247240808, 0.11523274282808416, 0.08210727814002894, 0.018880402021750342, 0.5374874523840845, 35.78212134540081, 144.86170917749405, 109.60416108369827, 109.33420836925507, 97.97555387020111, 111.39248192310333, 79.06496420502663, 63.99523884057999, 56.980116069316864, 127.98324286937714, 112.94042766094208, 85.84304049611092, 128.58572334051132, 88.21648433804512, 43.35805982351303, 0.2878610644256696, 0.07337309056310914, 0.06488930361228995, 0.18260003300383687, 0.4483720217831433, 0.4317925911163911, 0.4919316968880594, 7.669106153771281, 11.114187017083168, 1.5541357244364917, 50.9357576072216, 106.55234724283218, 109.93746399879456, 112.7894389629364, 107.00757801532745, 109.81012523174286, 108.96603852510452, 104.77869361639023, 97.32925415039062, 101.97591841220856, 105.34320652484894, 100.23349910974503, 99.15679648518562, 87.33864784240723, 79.46477115154266, 77.90673315525055, 76.40786558389664, 75.0170186161995, 77.04618573188782, 73.50104436278343, 78.11971932649612, 85.4799547791481, 97.92596653103828, 95.43266952037811, 96.23038351535797, 95.26560768485069, 83.52581083774567, 70.82523554563522, 68.90079081058502, 72.53618493676186, 77.12233364582062, 82.25819885730743, 79.40092697739601, 76.8355630338192, 77.32062220573425, 82.78302669525146, 81.46638214588165, 83.73033866286278, 82.21681147813797, 84.61958214640617, 82.81451180577278, 93.88919994235039, 86.55504629015923, 54.972186014056206, 59.54792708158493, 83.0368834733963, 95.70948466658592, 92.68648087978363, 88.66607621312141, 76.72413781285286, 75.4141353070736, 76.70435607433319, 88.98572266101837, 93.81832614541054, 91.9348432123661, 89.39626783132553, 92.13784351944923, 97.64048784971237, 96.01384833455086, 96.72396183013916, 93.03963392972946, 92.22627997398376, 95.96195071935654, 81.457589417696, 74.58970114588737, 72.38729372620583, 72.690319865942, 70.84989622235298, 76.6218701004982, 79.88900318741798, 79.67621460556984, 84.5067586004734, 84.70709145069122, 87.50349819660187, 90.97395837306976, 86.74421533942223, 87.59146347641945, 87.86257892847061, 93.54686871170998, 90.92695489525795, 107.80034467577934, 36.20462067425251, 0.2855035581160337, 0.15892788214841858, 0.2804511057911441, 0.40319639432709664, 0.03290384825959336, 0.08191262022592127, 0.05771723670477513, 0.5333130795042962, 13.340859934687614, 60.047942250967026, 88.70014518499374, 116.3428258895874, 68.8967402279377, 52.09698289632797, 21.850077733397484, 25.49996428191662, 43.457595482468605, 53.240288347005844, 81.67581930756569, 82.76243180036545, 74.05079886317253, 89.51802089810371, 6.096676904708147, 0.1907928683795035, 0.07817658202839084, 0.10061100125312805, 0.04464901430765167, 0.07905074293375947, 0.00460276046396757, 0.052535732320393436, 0.029045359406154603, 0.056209155518445186, 0.01817741933336947, 0.0496786864096066, 0.01874164823675528, 0.07398269808618352, 0.0907619297504425, 0.0616299246030394, 0.05502867315954063, 0.04674400443036575, 0.06488301019999199, 0.03203258915164042, 0.07019548138487153, 0.03520673621096648, 0.04281491135770921, 0.00661041140119778, 0.02667539429239696, 0.012022973260172876, 0.1617204799549654, 0.2229445759439841, 0.1276640355354175, 0.0885913852835074, 0.1321144576650113, 0.23383439081953838, 0.11072316410718486, 0.17825554503360763, 0.19575748010538518, 0.07676776309381239, 0.17410135857062414, 0.21311726421117783, 0.1649790129158646, 0.15361901780124754, 0.14460305159445852, 0.10144906409550458, 0.21018192172050476, 0.16524287610081956, 0.2007794746896252, 0.09300039557274431, 0.6106527044903487, 49.30194027721882, 167.028686106205, 118.2400792837143, 123.4810696542263, 99.85982716083527, 110.10262593626976, 63.662270307540894, 53.64916920661926, 56.39537684619427, 128.41696679592133, 187.43486791849136, 99.4999560713768, 145.84433645009995, 100.94672843813896, 63.66111516952515, 1.4806262939237058, 0.1385303243296221, 0.21188452723436058, 0.43352057808078825, 0.5612537520937622, 0.4842386534437537, 0.5273176543414593, 32.58585445582867, 22.844913750886917, 2.93977044057101, 48.89426775276661, 106.55868530273438, 112.1337765455246, 117.77163282036781, 111.31862908601761, 112.94702410697937, 115.33119857311249, 108.67189630866051, 103.73808905482292, 108.60250443220139, 111.46828785538673, 107.14997917413712, 105.39800718426704, 90.15561148524284, 84.47606384754181, 83.79783824086189, 80.2585257589817, 80.84388434886932, 82.38615319132805, 77.84183263778687, 82.14668244123459, 92.67841011285782, 104.60695803165436, 101.11496061086655, 101.29039719700813, 101.02808207273483, 88.66980761289597, 77.80899479985237, 72.06911399960518, 78.38492229580879, 82.25965037941933, 89.64017674326897, 84.55121621489525, 81.14358946681023, 82.60632857680321, 87.02870607376099, 89.74145650863647, 88.73756557703018, 87.2732837498188, 88.50651517510414, 88.03448930382729, 100.75996845960617, 89.87109795212746, 65.49698665738106, 66.92855224013329, 85.48573046922684, 102.10309758782387, 98.37269335985184, 92.44696453213692, 82.4761551618576, 78.50775450468063, 83.29372689127922, 93.6178109049797, 98.37563440203667, 93.96223202347755, 89.85668152570724, 98.41893687844276, 101.38896390795708, 100.52825689315796, 101.69350236654282, 95.7850930094719, 95.25363072752953, 101.9238992035389, 86.10505923628807, 78.10936108231544, 73.64906921982765, 76.43656924366951, 75.5943976342678, 81.76695361733437, 83.56598988175392, 83.2169558107853, 89.22796726226807, 89.87105995416641, 91.57180309295654, 93.21375578641891, 88.9420934021473, 93.52679058909416, 94.83835101127625, 99.98785749077797, 98.73377278447151, 114.11470904946327, 33.830242082476616, 2.117500500753522, 2.2694947198033333, 0.2761051483685151, 0.5616988032124937, 0.14051620761165395, 0.3516412654425949, 0.4167607758427039, 0.6225832924246788, 21.356814801692963, 75.87996751070023, 98.51808115839958, 128.2033422589302, 77.22085475921631, 102.59789943695068, 85.15360549092293, 41.77356384694576, 39.00676131248474, 47.65340253710747, 86.39721035957336, 94.71040427684784, 83.00167456269264, 107.6272563636303, 9.555007182061672, 0.3886215342208743, 0.15558170154690742, 0.19288484909338877, 0.16197076183743775, 0.16811437904834747, 0.12695148470811546, 0.11577205412322655, 0.19096708012511954, 0.07484046494937502, 0.10300799724063836, 0.17377134034177288, 0.138789422926493, 0.14004662109073251, 0.15176620159763843, 0.10722842038376257, 0.06721356170601211, 0.12109858900657855, 0.18909522041212767, 0.1921332612982951, 0.21311843680450693, 0.12090221673133783, 0.21141795383300632, 0.06373516749590635, 0.11774775513913482, 0.20406196417752653], [0.030063131453061942, 0.03875580143358093, 0.0449163173470879, 0.008338767584064044, 0.026867573433264624, 0.0557990706874989, 0.10049894437543117, 0.0173647731935489, 0.0397391953447368, 0.03780377439397853, 0.10378081788076088, 0.04325933907239232, 0.06203239128808491, 0.06548503297381103, 0.05599346142844297, 0.02809242323564831, 0.04219252034090459, 0.20946996461134404, 0.032920320227276534, 0.44143736420664936, 15.443927384912968, 122.92026534676552, 94.11136642098427, 99.66420605778694, 93.1063811480999, 70.33836007118225, 30.43108318001032, 34.55412603914738, 47.14190438389778, 35.34641392529011, 39.81764540076256, 68.75315353274345, 108.9635306596756, 72.65517935156822, 28.35594803094864, 1.388464376796037, 0.09527622853056528, 0.06479584495536983, 0.10337504863855429, 0.16755940101575106, 0.08517423309967853, 0.04270249082765076, 3.8215444749221206, 2.2715242858976126, 0.8234811841975898, 46.94617308676243, 108.6902417242527, 106.51209980249405, 103.03980812430382, 107.37827092409134, 102.81496658921242, 101.64048001170158, 96.87909990549088, 96.5842205286026, 89.68635946512222, 90.9400337934494, 91.86277627944946, 97.91362479329109, 93.81802976131439, 93.20383071899414, 81.45609229803085, 68.9483642578125, 72.98440128564835, 71.74167796969414, 69.46772038936615, 70.28030678629875, 67.53576725721359, 78.23147132992744, 92.78420403599739, 89.74483072757721, 92.34585955739021, 87.426947504282, 73.7015900015831, 68.0793584883213, 66.2833696603775, 68.49740445613861, 74.03034076094627, 73.36520925164223, 74.08080965280533, 70.52056029438972, 68.2890236377716, 69.11911189556122, 76.19133040308952, 73.99345993995667, 77.68495425581932, 80.41632369160652, 89.94381844997406, 80.49294278025627, 91.09402433037758, 61.70064456760883, 58.28596159815788, 85.44688895344734, 82.8024360537529, 88.45212489366531, 82.05445379018784, 77.72251144051552, 68.62598195672035, 73.2732617855072, 75.5052924156189, 91.36131718754768, 88.59478443861008, 93.0666808784008, 89.75706607103348, 90.81720158457756, 87.66358360648155, 91.0949818789959, 89.29681196808815, 87.16105297207832, 88.48194569349289, 85.03961160779, 73.73552218079567, 68.69875565171242, 70.24899646639824, 72.68059238791466, 66.76935598254204, 74.99137759208679, 80.19977331161499, 84.08742070198059, 83.66850838065147, 88.8701556622982, 87.13104978203773, 89.79142382740974, 81.71705469489098, 81.54467314481735, 85.21845281124115, 91.98985666036606, 87.21764713525772, 104.30158361792564, 18.12822874635458, 1.7499361303634942, 0.3284402744611725, 0.15662309800973162, 0.23293967242352664, 0.06898475650814362, 0.038171890773810446, 0.012122614934924059, 0.18258793599670753, 7.921400740742683, 32.319370955228806, 76.92018449306488, 103.59671384096146, 82.32023432850838, 80.3278948366642, 83.02231505513191, 53.5127679258585, 23.12190368771553, 27.473941259086132, 62.23547726869583, 64.92053478956223, 73.24570566415787, 46.48859404027462, 0.908152456395328, 0.04232609207974747, 0.054301620766636916, 0.05135811836225912, 0.06279423556406982, 0.005443395311885979, 0.029762448466499336, 0.0604318125260761, 0.07269023306434974, 0.026382630021544173, 0.045274069634615444, 0.04221079572744202, 0.005845330897500389, 0.030845492401567753, 0.05619337003736291, 0.08310555582283996, 0.049829449999378994, 0.023925154564494733, 0.07154967082897201, 0.04404910665471107, 0.048786213010316715, 0.08891246805433184, 0.068888930400135, 0.06179023221193347, 0.05875098904652987, 0.027706293076334987, 0.06167463900055736, 0.0385398661455838, 0.003769872710108757, 0.042161628443864174, 0.03452855053183157, 0.012690406147157773, 0.06839037785539404, 0.032951100802165456, 0.024491166477673687, 0.06817439803853631, 0.01965843439393211, 0.032500413071829826, 0.058299726151744835, 0.047102951575652696, 0.0401221212814562, 0.013129687067703344, 0.10477015268406831, 0.18953871302073821, 0.4260973498458043, 19.668728783726692, 143.63226234912872, 102.21085220575333, 114.2049466073513, 113.33451971411705, 90.2685034275055, 61.236351281404495, 56.25091999769211, 31.696734465658665, 18.19413810968399, 49.8770622164011, 83.13000127673149, 125.1468850672245, 86.39525726437569, 33.861085027456284, 0.7404245878569782, 0.0263772680045804, 0.050399245010339655, 0.18773628864437342, 0.07630718624568544, 1.383815088775009, 0.7613888347987086, 3.7834339449182153, 1.4257431076839566, 1.4532326138578355, 60.59742696583271, 113.22932615876198, 107.02188804745674, 101.33994653820992, 106.65202349424362, 104.70568433403969, 104.2575591802597, 99.15393143892288, 98.89783278107643, 96.24303683638573, 95.24260371923447, 94.4485755264759, 101.83697506785393, 99.833874553442, 98.46915498375893, 85.55070698261261, 72.67604783177376, 75.10404914617538, 74.05520662665367, 72.81756743788719, 72.95527964830399, 70.26378527283669, 81.66447311639786, 97.76996970176697, 94.38899472355843, 97.38264128565788, 89.34880837798119, 74.96542498469353, 70.92466861009598, 71.09831929206848, 72.21563413739204, 78.08602273464203, 76.62951529026031, 78.63777592778206, 73.81467193365097, 72.09920838475227, 73.4745217859745, 80.58591619133949, 76.52398735284805, 80.58555901050568, 84.92390781641006, 92.87393242120743, 85.9168629348278, 93.34158852696419, 67.84257039427757, 63.13286371529102, 88.38210225105286, 85.97925558686256, 93.60472440719604, 83.98592054843903, 82.83454433083534, 71.05547279119492, 76.46855592727661, 80.0624030828476, 95.08902356028557, 91.06855809688568, 96.57222837209702, 93.40087294578552, 95.09202539920807, 91.4948420226574, 94.66319561004639, 93.28773021697998, 90.6302136182785, 91.40636757016182, 88.10758218169212, 78.26738700270653, 71.96698307991028, 74.00038316845894, 76.89643576741219, 68.93359065055847, 77.83618614077568, 83.36817249655724, 86.60737708210945, 86.90006777644157, 93.7663297355175, 88.29511731863022, 94.83151897788048, 84.54095676541328, 85.8226127922535, 87.32057601213455, 95.85394531488419, 86.77135348320007, 110.68178325891495, 28.29076062887907, 0.42275127314496785, 0.09786683600395918, 0.5115975416265428, 0.8061976928729564, 0.2465119058615528, 0.05718177344533615, 0.061652723379665986, 0.04683041639509611, 7.148643806576729, 36.76967315375805, 80.51647871732712, 109.23632562160492, 87.86716908216476, 60.21646320819855, 33.22814159095287, 32.661743983626366, 33.836192563176155, 48.158984407782555, 76.34380862116814, 76.83405831456184, 82.2763466835022, 64.14767906069756, 1.8195215589366853, 0.034755603192024864, 0.07587613945361227, 0.055041486339177936, 0.01681575275142677, 0.021875483689655084, 0.02213722989836242, 0.12010569189442322, 0.06813452244387008, 0.021109064073243644, 0.03364418509590905, 0.05949299200437963, 0.0241485391597962, 0.011548895818123128, 0.03266934072598815, 0.06692661030683666, 0.02892354143114062, 0.012703926222457085, 0.030787519535806496, 0.04150597807893064, 0.04099091274838429, 0.05108004676003475, 0.018215075906482525, 0.10448676359374076, 0.04533237646683119, 0.1439307993859984, 0.12502236088039353, 0.17525573959574103, 0.08106464229058474, 0.157209157187026, 0.1635247448575683, 0.12002067145658657, 0.09469304146477953, 0.1344603270990774, 0.16760568134486675, 0.18414283927995712, 0.16960308275884017, 0.09350849955808371, 0.16188393055927008, 0.10836572459083982, 0.17962229903787374, 0.26790450559929013, 0.29202293953858316, 0.30198113643564284, 0.8572655275929719, 31.053411886096, 165.48811197280884, 116.84526532888412, 129.73028272390366, 122.18156218528748, 93.77519086003304, 46.002771109342575, 46.65519990026951, 67.1847040951252, 47.71672993898392, 67.11691573262215, 94.49314713478088, 135.26933670043945, 95.97390487790108, 49.18209470808506, 4.543796181678772, 0.2957132243318483, 0.2029400595347397, 0.35276395676191896, 1.3142602960579097, 3.6819713143631816, 0.4618304839823395, 10.763159953057766, 11.1293501034379, 1.7371574160642922, 56.48928880691528, 114.16285246610641, 108.88096109032631, 104.08092945814133, 110.72750240564346, 111.0575982928276, 110.9805004298687, 106.76608577370644, 106.41034886240959, 100.5279453098774, 101.98661863803864, 99.76634457707405, 108.80187973380089, 103.88481438159943, 104.50888529419899, 92.15987473726273, 75.75214996933937, 81.03151068091393, 79.04280379414558, 75.57005614042282, 78.91141444444656, 74.37127366662025, 86.5811812877655, 101.30416005849838, 96.03768825531006, 99.51769351959229, 96.92267596721649, 79.86855268478394, 73.71833950281143, 75.16676858067513, 74.73552972078323, 82.85427287220955, 82.64703199267387, 84.19328302145004, 80.21498769521713, 76.81937590241432, 76.82377606630325, 87.2329831123352, 83.03797021508217, 87.65561923384666, 89.59412321448326, 98.97039368748665, 91.32115334272385, 98.04604008793831, 73.13625633716583, 70.36350712180138, 90.3170420229435, 91.42580732703209, 96.14564046263695, 88.29773917794228, 86.14345997571945, 75.6928351521492, 79.5818504691124, 85.62946155667305, 100.45122742652893, 95.06430968642235, 98.90164777636528, 98.06737214326859, 98.9941880106926, 95.20394459366798, 100.13405844569206, 96.67756631970406, 93.42467486858368, 95.39890453219414, 93.99573862552643, 82.1763664484024, 75.72002649307251, 78.26019778847694, 82.17724800109863, 73.35042044520378, 83.68069052696228, 89.45305958390236, 93.31461757421494, 90.95858439803123, 97.81998261809349, 95.55196791887283, 99.14095133543015, 88.86360481381416, 90.67828103899956, 91.53277158737183, 99.63456004858017, 92.72369608283043, 113.93839851021767, 24.313911125063896, 2.7379027102142572, 1.7544483882375062, 0.3834531584288925, 0.6520061229821295, 0.32093475689180195, 0.24337309616385028, 0.31269970815628767, 0.3572278859792277, 16.444520093500614, 50.761905536055565, 92.14054897427559, 121.7433013021946, 106.15293547511101, 117.5926624238491, 107.08833128213882, 63.992768973112106, 33.429941162467, 41.80520474910736, 81.84644535183907, 88.08953315019608, 91.86318665742874, 79.83560845255852, 3.0956715624779463, 0.2791709010489285, 0.27215730864554644, 0.14359782740939409, 0.1696339264162816, 0.1136024744482711, 0.08463855090667494, 0.21484841272467747, 0.17009233619319275, 0.08469269057968631, 0.1097733189817518, 0.15707810875028372, 0.11274053671513684, 0.07634386318386532, 0.15157463843934238, 0.10507439612410963, 0.17804297909606248, 0.11046160158002749, 0.1494844537228346, 0.115052846231265, 0.10561373710515909, 0.1759453135309741, 0.15510812227148563, 0.20899684546748176, 0.10397427351563238], [0.033121227024821565, 0.02185591140005272, 0.04992842652427498, 0.039815194977563806, 0.04242178831191268, 0.03418434615014121, 0.04230526370520238, 0.011699617662088713, 0.06055768819351215, 0.009379827297379961, 0.05667454890499357, 0.09031929061166011, 0.02432967143249698, 0.03009115123859374, 0.03597131530113984, 0.025902063425746746, 0.0344171541655669, 0.02326298999832943, 0.1925511349691078, 2.2725219698622823, 93.69705185294151, 94.55665692687035, 99.36190947890282, 68.10758337378502, 50.94769276678562, 43.950873613357544, 42.52234406769276, 44.98882971704006, 94.30625796318054, 106.36591404676437, 81.72776252031326, 116.92332834005356, 79.50368106365204, 24.579596668481827, 1.3507820363156497, 0.09277821882278658, 0.16347387805581093, 0.04473607194086071, 0.2783407346578315, 0.12073294026777148, 0.3978960053063929, 0.23660027130972594, 1.5857405285350978, 0.6544083065818995, 55.860034972429276, 115.28126165270805, 103.7448450922966, 107.81061932444572, 109.30428117513657, 98.9989985525608, 94.36922818422318, 94.16685104370117, 95.83403438329697, 94.00822475552559, 96.0088250041008, 98.23861375451088, 96.8951578438282, 91.53897285461426, 101.59857586026192, 93.38266432285309, 85.7678273320198, 73.78945648670197, 70.21943405270576, 73.93710136413574, 74.88255903124809, 70.4897591471672, 70.8076348900795, 79.06435623764992, 93.01919102668762, 89.21674266457558, 91.80114358663559, 79.71291303634644, 65.97947716712952, 65.20527631044388, 66.11442312598228, 71.08533918857574, 77.22501933574677, 74.72704857587814, 75.61890631914139, 70.76108738780022, 71.52242213487625, 71.04871675372124, 72.8826579451561, 72.74844154715538, 73.90076011419296, 70.1634706556797, 77.52375930547714, 81.94649398326874, 95.56856542825699, 68.07671383023262, 60.89231014251709, 86.66168376803398, 81.5190701186657, 92.05966651439667, 84.44030776619911, 77.61490121483803, 66.89217299222946, 70.62000095844269, 73.96970361471176, 82.91354209184647, 87.63342082500458, 90.97859412431717, 84.5536556839943, 83.25088039040565, 81.1309665441513, 86.6570708155632, 87.54990890622139, 87.41193071007729, 89.68044698238373, 84.78885546326637, 81.98342800140381, 75.35713836550713, 69.05231148004532, 68.305993527174, 66.12377062439919, 65.33431738615036, 73.16622912883759, 80.55537343025208, 81.8272639811039, 89.27872493863106, 84.85463753342628, 83.33330556750298, 85.09100005030632, 80.70424944162369, 82.06106543540955, 84.55676391720772, 90.8975824713707, 87.87081688642502, 99.02603790163994, 9.870123323053122, 1.985019303392619, 1.8950848979875445, 0.326808113604784, 0.10349956617574207, 0.021445154925459065, 0.14778364420635626, 0.09351273722131737, 0.3120277379639447, 2.0899427169933915, 20.42367037385702, 59.73665535449982, 95.7067260146141, 70.74562981724739, 92.26355597376823, 91.09742134809494, 34.44731377065182, 23.125175312161446, 36.176764369010925, 63.53736720979214, 69.49084594845772, 78.91304835677147, 24.139918461441994, 0.6591307406779379, 0.024086267403617967, 0.029996612756804097, 0.06356013196636923, 0.07472413330106065, 0.023358116632152814, 0.013622192964248825, 0.02392878737737192, 0.06529584468808025, 0.0605161798739573, 0.08263636264018714, 0.14150865201372653, 0.0215070055128308, 0.04949124588165432, 0.029380932610365562, 0.006008552827552194, 0.0316800318978494, 0.0519934413023293, 0.03656676635728218, 0.05688688106602058, 0.05502892548975069, 0.08390519767999649, 0.039090235441108234, 0.020990305602026638, 0.06980221733101644, 0.019335180841153488, 0.027039668202633038, 0.029857779190933798, 0.016927598117035814, 0.02732276414462831, 0.02090657093503978, 0.048809290092322044, 0.03296255956229288, 0.037466130597749725, 0.01649009092943743, 0.03556514158844948, 0.06659952356130816, 0.04589608957758173, 0.049291032992186956, 0.01744241853884887, 0.061652664007851854, 0.07955374094308354, 0.24153923441190273, 3.2111060433089733, 111.19391217827797, 111.29624828696251, 114.44312542676926, 85.46885937452316, 76.36340796947479, 78.88928443193436, 57.77617335319519, 29.078695848584175, 35.02558194100857, 94.65906143188477, 93.52040693163872, 129.49635207653046, 91.37678995728493, 29.772109240293503, 0.7451433409005404, 0.20258792530512437, 0.04979068020475097, 0.12584623385919258, 0.4354415531270206, 1.0876116016879678, 1.3119852868840098, 0.6945877661928535, 0.6021601008251309, 1.6901203338056803, 67.22496673464775, 118.92137512564659, 106.44831642508507, 111.92609488964081, 113.33765834569931, 101.13620907068253, 100.078604221344, 101.6595321893692, 102.96556010842323, 99.12218034267426, 102.77262926101685, 101.69886007905006, 99.59475338459015, 95.78397586941719, 104.25023317337036, 96.96958065032959, 91.0610269010067, 77.06026777625084, 73.69245529174805, 77.2795920073986, 74.75227162241936, 73.76044124364853, 74.84219759702682, 82.91978135704994, 96.6607104241848, 91.48120075464249, 94.53034713864326, 82.68870815634727, 69.37749803066254, 68.96116197109222, 67.82966628670692, 73.46753776073456, 81.92664384841919, 80.34647583961487, 80.91129273176193, 77.01654732227325, 76.77782893180847, 76.35573238134384, 77.44691222906113, 76.19296431541443, 76.9185733795166, 72.8359280526638, 82.40547895431519, 85.48661202192307, 98.1597451865673, 72.2577814757824, 65.22517204284668, 87.23411545157433, 85.22735193371773, 94.97773513197899, 87.9988244175911, 81.39674708247185, 71.75883784890175, 73.19113299250603, 77.9317282140255, 86.03544697165489, 92.1430416405201, 94.11081925034523, 88.1193919479847, 85.1586364209652, 85.58733701705933, 89.46019560098648, 92.11496114730835, 91.32011219859123, 91.33736327290535, 88.40336591005325, 86.29529222846031, 80.41953831911087, 73.41820880770683, 70.79941973090172, 68.86182770133018, 68.95328879356384, 76.62003859877586, 84.82840374112129, 85.37551358342171, 91.97931602597237, 89.34234872460365, 86.91677168011665, 88.7142576277256, 83.74145686626434, 86.28098219633102, 88.39828178286552, 96.67791590094566, 91.34530484676361, 106.23726055026054, 16.695566922426224, 1.9317509117536247, 3.574239257723093, 0.4325024108402431, 0.6858086341526359, 0.0349309689772781, 0.17262108565773815, 0.08102940511889756, 0.4866816254798323, 2.0472976053133607, 23.990839160978794, 65.789525359869, 101.78959161043167, 84.90637555718422, 84.57243427634239, 47.14961037039757, 32.66353748738766, 39.20880027115345, 50.11543482542038, 73.96763652563095, 79.90537270903587, 91.52582556009293, 39.43358860909939, 0.4364545253338292, 0.03074448981351452, 0.10408798538264818, 0.054133487210492603, 0.03065475117182359, 0.07843435960239731, 0.06994583774940111, 0.036366627682582475, 0.017609778406040277, 0.04144533348153345, 0.06346999070956372, 0.03166989787132479, 0.025066306807275396, 0.049614327363087796, 0.024660693416080903, 0.017499747591500636, 0.007198078719738987, 0.02495503104000818, 0.0682304821384605, 0.09598067510523833, 0.022047888305678498, 0.031106887945497874, 0.020258629629097413, 0.08114796321024187, 0.1298854616470635, 0.13204975723056123, 0.24344199715415016, 0.1267982312128879, 0.1268386040464975, 0.11890115652931854, 0.12190483597805724, 0.13949815911473706, 0.2532272587995976, 0.10501531374757178, 0.1641135648242198, 0.14040078880498186, 0.16166299319593236, 0.08348550574737601, 0.10627997791743837, 0.08275491331005469, 0.18965266237501055, 0.1510756480274722, 0.4668176866834983, 6.066492274403572, 138.8254290819168, 120.76212555170059, 131.25523209571838, 94.42025944590569, 75.04802495241165, 63.54100741446018, 56.01405970752239, 64.37868386507034, 136.3695752620697, 156.68275326490402, 105.2275787293911, 145.65618574619293, 105.83595648407936, 44.973011165857315, 2.538827355019748, 0.43781262589618564, 0.3051768837030977, 0.21042653359472752, 0.6718409992754459, 2.3247884027659893, 1.9394547608681023, 3.247635383158922, 4.40953703597188, 1.757494993507862, 64.62794288992882, 126.45314857363701, 110.56150451302528, 116.15558713674545, 116.08051836490631, 107.6675646007061, 103.79601314663887, 106.36942505836487, 107.17779368162155, 103.98498460650444, 105.80256387591362, 107.34494671225548, 104.96480002999306, 101.46160081028938, 111.08515441417694, 102.48177766799927, 95.4694439470768, 81.2084823846817, 79.69128459692001, 81.59104585647583, 78.84646072983742, 78.35178807377815, 78.73976245522499, 88.72819527983665, 101.67809039354324, 97.75806114077568, 100.17944321036339, 88.30478399991989, 73.92314851284027, 73.209288418293, 71.9646044075489, 76.46987825632095, 85.58135613799095, 85.59030845761299, 83.71994242072105, 81.0750487446785, 79.16298374533653, 80.15479132533073, 81.88234582543373, 82.13101968169212, 82.26516768336296, 78.44587862491608, 86.66774064302444, 91.99780583381653, 103.95387187600136, 78.2415559887886, 70.5605037510395, 87.76151955127716, 88.42056378722191, 98.46128180623055, 94.55640614032745, 85.18873080611229, 76.8039259314537, 79.02747541666031, 82.46012762188911, 91.21165841817856, 98.10852393507957, 99.283686876297, 92.83184587955475, 89.4693075120449, 89.03133541345596, 94.3913733959198, 97.82336443662643, 93.76870080828667, 97.96506643295288, 93.0104210972786, 90.92471301555634, 82.89844930171967, 76.978260576725, 73.42549681663513, 74.74778786301613, 73.85684967041016, 80.673987865448, 87.79672086238861, 88.80723103880882, 97.18706578016281, 95.17752081155777, 90.71481987833977, 93.07124823331833, 88.25279518961906, 92.58668303489685, 91.69541046023369, 102.6564010977745, 97.4548602104187, 110.27442991733551, 13.216128777712584, 4.399691289290786, 4.602150600403547, 0.5495548923499882, 1.4942075964063406, 0.14365783747052774, 0.3980318480171263, 0.21401789010269567, 1.1263569351285696, 6.356163080781698, 38.12830924987793, 77.43836268782616, 109.24460917711258, 89.94789943099022, 126.4209794998169, 120.75564309954643, 43.722790852189064, 36.22763603925705, 52.072280421853065, 83.4582656621933, 90.79424321651459, 104.3226420879364, 54.7232423722744, 1.0148725798353553, 0.13467513432260603, 0.1888960279757157, 0.16781291866209358, 0.1661825241171755, 0.17566812137374654, 0.14964484667871147, 0.1468894156278111, 0.20183296815957874, 0.20181818457785994, 0.21647604648023844, 0.17679664597380906, 0.15424533106852323, 0.11267060413956642, 0.1673351536737755, 0.12084947971743532, 0.1249356335029006, 0.15395388967590407, 0.16132694872794673, 0.14097684383159503, 0.17263920890400186, 0.17138276773039252, 0.07238141057314351, 0.2503533661365509], [0.09843303530942649, 0.04194762273982633, 0.017032394935085904, 0.06957129065995105, 0.07489103489206173, 0.05669122125254944, 0.044509442304843105, 0.03772976742766332, 0.015257224076776765, 0.05773040982603561, 0.08053944664425217, 0.01078058558050543, 0.007692377366765868, 0.16732940945075825, 0.05870840832358226, 0.05028323990700301, 0.13182343187509105, 0.037387006523204036, 0.07815776116331108, 49.98796686530113, 102.35556364059448, 105.31843945384026, 78.4304666519165, 65.83460614085197, 45.12600235641003, 30.162823274731636, 48.80349442362785, 86.5603432059288, 78.12299475073814, 83.37267145514488, 106.32324233651161, 78.15229877829552, 22.856554426252842, 2.379690231755376, 0.14606788783567026, 0.28196110913995653, 0.04557583059067838, 0.11575604599784128, 0.25693191157188267, 0.4961386352078989, 0.6076911790296435, 1.8211382534354925, 1.6239570965990424, 50.668548345565796, 121.58203035593033, 101.18582680821419, 106.608447432518, 103.46267983317375, 104.83410984277725, 103.03176015615463, 100.77586680650711, 94.65288296341896, 102.76671677827835, 100.99599659442902, 99.74004238843918, 98.55620831251144, 98.91031891107559, 97.3422722518444, 92.37292170524597, 94.18550804257393, 93.43418955802917, 76.25447541475296, 68.87900277972221, 70.81030234694481, 68.07314962148666, 66.58568903803825, 68.57530787587166, 79.14450153708458, 85.84380805492401, 83.80014851689339, 87.34981164336205, 71.47042572498322, 66.72065019607544, 66.81303843855858, 69.00166019797325, 70.95780283212662, 80.52888125181198, 81.81391149759293, 86.5599100291729, 76.92885562777519, 74.78168204426765, 71.74721047282219, 76.69405102729797, 72.96018898487091, 76.60672411322594, 72.93578669428825, 72.57331654429436, 80.27345895767212, 85.4343344271183, 69.19188559055328, 66.56085357069969, 84.82623025774956, 83.38294610381126, 89.46189031004906, 82.12681710720062, 76.47522836923599, 65.40727347135544, 68.07177409529686, 70.40502369403839, 77.60283306241035, 84.77640733122826, 83.87188106775284, 77.14816465973854, 74.01226133108139, 71.30174517631531, 83.9536602795124, 85.79270839691162, 88.95258843898773, 82.0017658174038, 87.43284478783607, 85.07238104939461, 83.52751314640045, 78.72995138168335, 74.57724541425705, 64.58755865693092, 62.145004123449326, 62.88614295423031, 74.11008328199387, 80.52926883101463, 81.50476008653641, 81.36468440294266, 87.47518971562386, 82.58515611290932, 83.29409927129745, 79.84026700258255, 82.42995724081993, 85.07146149873734, 90.76701387763023, 85.5288353562355, 90.35675749182701, 1.0346056334674358, 2.5355564430356026, 7.313695549964905, 0.5744852952193469, 0.2164561123936437, 0.07539886428276077, 0.11688526821671985, 0.048290666163666174, 0.09351983957458287, 0.42678923928178847, 12.120681758970022, 53.090181201696396, 93.47274228930473, 78.42991188168526, 69.23149466514587, 67.25951448082924, 30.258599035441875, 25.572021715343, 48.88427048921585, 63.21389056742191, 66.85890957713127, 69.83225762844086, 9.64237779378891, 0.41553436196409166, 0.05871482047950849, 0.1944892090978101, 0.04242772549332585, 0.08480243195663206, 0.13253917393740267, 0.026566717897367198, 0.0789638448623009, 0.015799858338141348, 0.023004605718597304, 0.026132904749829322, 0.05698198358004447, 0.04120422454434447, 0.023602698820468504, 0.03907217156665865, 0.03927442907297518, 0.030750007681490388, 0.016258025061688386, 0.0391962772118859, 0.006004165343256318, 0.04747675651742611, 0.027063658126280643, 0.02881630109186517, 0.0728095110389404, 0.032633387381793, 0.047991105675464496, 0.07126292723114602, 0.0893951089528855, 0.043660269511747174, 0.02440783257043222, 0.05156046863703523, 0.06998672266490757, 0.02997932071593823, 0.011147615641675657, 0.010217937451670878, 0.03995584309450351, 0.04293485726520885, 0.04226172932249028, 0.043621265940601006, 0.04150267181103118, 0.026990975893568248, 0.19349287584191188, 60.672214552760124, 120.18260344862938, 114.37621101737022, 90.46838030219078, 76.63975194096565, 66.4391840994358, 38.14605809748173, 24.684873819351196, 35.72438724339008, 78.47091928124428, 95.24926096200943, 111.03646382689476, 92.30800598859787, 32.41344250738621, 1.2272294098511338, 0.03863769605231937, 0.14096358907409012, 0.06867252755910158, 0.12986641813768074, 0.6119843549095094, 0.8712576830293983, 1.6925437725149095, 0.44216935930307955, 2.465609796345234, 62.8245634585619, 124.96446445584297, 104.88601505756378, 108.73966947197914, 107.4029316008091, 109.76481646299362, 106.34203612804413, 103.78704562783241, 98.03556025028229, 106.52304321527481, 103.77993240952492, 102.4145744740963, 99.92874786257744, 102.7728496491909, 100.69589629769325, 98.28263059258461, 97.09634184837341, 98.27120080590248, 78.96500676870346, 70.93362092971802, 73.79577934741974, 73.0432753264904, 69.93735238909721, 71.06999561190605, 85.29398515820503, 89.54053089022636, 88.07153731584549, 90.93670517206192, 75.13205364346504, 69.5006950199604, 69.46743920445442, 71.14416763186455, 75.37554457783699, 84.9585771560669, 85.80936670303345, 91.80897876620293, 82.95640379190445, 78.93748864531517, 76.28377944231033, 81.62928700447083, 79.20761615037918, 81.41030475497246, 76.39750733971596, 76.21802017092705, 86.60428404808044, 90.11062189936638, 74.30299893021584, 71.97519823908806, 87.70695447921753, 86.64733573794365, 91.8921335041523, 86.8083406984806, 80.5866913497448, 69.55798834562302, 71.98462933301926, 73.0358961224556, 80.3860393166542, 87.89401084184647, 87.88068875670433, 80.3546530008316, 74.62933301925659, 73.66573512554169, 86.1970143020153, 90.03598630428314, 94.07172694802284, 85.6830082833767, 90.84034994244576, 89.08366620540619, 88.83610188961029, 83.07076245546341, 78.12648296356201, 68.69194641709328, 65.73910966515541, 67.13365763425827, 78.51002678275108, 82.57551982998848, 87.6969762146473, 85.8170498907566, 91.31556764245033, 85.46129018068314, 86.91917315125465, 84.40438449382782, 85.70363357663155, 86.58219203352928, 96.29010111093521, 87.24382013082504, 100.5780266225338, 2.747966470196843, 0.8634846657514572, 4.584908075630665, 0.9552946861367673, 0.07771993114147335, 0.08456589464913122, 0.08587726959376596, 0.05520280697965063, 0.18227385909995064, 0.5841556575614959, 14.168536271899939, 60.62625601887703, 97.1681047976017, 90.5775636434555, 61.579024493694305, 34.78011131286621, 29.409337006509304, 40.24358734488487, 66.14895567297935, 74.20360386371613, 74.8114800453186, 87.79069438576698, 15.7015972584486, 0.5235091899521649, 0.02788517107546795, 0.16414662008173764, 0.03023457869858248, 0.06979754922213033, 0.1606907055247575, 0.06387878791429102, 0.07397785186185502, 0.03640877053840086, 0.030466761454590596, 0.029609176417579874, 0.04019697800686117, 0.07935951347462833, 0.07966587945702486, 0.0395309783925768, 0.008373235705221305, 0.039566916893818416, 0.0705272436607629, 0.05309298503561877, 0.08822012590826489, 0.049644725731923245, 0.0068523162917699665, 0.010444061499583768, 0.22070472972700372, 0.11734856132534333, 0.15323811792768538, 0.15413774934131652, 0.1641150045907125, 0.1140731964551378, 0.19210424332413822, 0.18348581594182178, 0.13447652076138183, 0.1159685525635723, 0.08594599989010021, 0.08286656942800619, 0.1318396849092096, 0.21471460349857807, 0.10837444482604042, 0.19623272179160267, 0.2030326795647852, 0.1265945116756484, 0.23674458934692666, 82.38853186368942, 132.566739320755, 132.9848688840866, 105.07294222712517, 94.5466710627079, 65.77064037322998, 42.77001477777958, 70.1075528562069, 132.53514021635056, 118.59465345740318, 94.46809887886047, 119.52475994825363, 104.8266926407814, 46.43769957125187, 2.6302917720749974, 0.26596791576594114, 0.4041875770781189, 0.17705482430756092, 0.17093600967200473, 1.353828285355121, 1.5162029536440969, 2.379308114759624, 7.558278450742364, 3.9938440918922424, 61.708988919854164, 134.04306650161743, 107.20807045698166, 114.46744412183762, 111.80313348770142, 115.38610562682152, 109.79216739535332, 110.8746001124382, 100.75567469000816, 109.71165731549263, 109.33107733726501, 109.78921875357628, 105.92895269393921, 111.23333126306534, 104.48949113488197, 102.8351891040802, 102.48010575771332, 103.12719583511353, 83.68066012859344, 76.6205857694149, 78.95150989294052, 76.74983963370323, 72.95113787055016, 75.84480419754982, 88.56396049261093, 95.59389486908913, 95.35639241337776, 96.11410215497017, 79.15954872965813, 72.56781443953514, 72.86481410264969, 74.4956561923027, 78.76013696193695, 89.97561514377594, 90.24609982967377, 96.16547539830208, 85.81850901246071, 84.82496872544289, 81.42238050699234, 86.3323326408863, 84.21675816178322, 86.05545669794083, 82.58024677634239, 78.9828734099865, 91.05997815728188, 92.55528911948204, 78.99922013282776, 75.4269178211689, 91.16224586963654, 90.20408928394318, 97.2618305683136, 90.01909241080284, 84.24509704113007, 72.30262666940689, 74.70619529485703, 77.22569569945335, 84.23815101385117, 94.14068564772606, 93.65674361586571, 86.67290076613426, 80.75835853815079, 79.48956862092018, 94.04112339019775, 96.70339733362198, 99.20948445796967, 88.42444717884064, 95.56127741932869, 91.38913169503212, 93.50776121020317, 86.21934950351715, 79.73587900400162, 73.30616801977158, 69.66118320822716, 71.94348514080048, 82.68876895308495, 87.50965386629105, 91.61399602890015, 91.73561990261078, 96.27379238605499, 90.70424124598503, 92.11110055446625, 88.07881012558937, 91.99834540486336, 89.36977565288544, 99.11833494901657, 91.80772483348846, 109.16149243712425, 1.680901434738189, 4.653622163459659, 16.12760189920664, 1.1844244692474604, 0.3876987477997318, 0.36245616793166846, 0.26702292321715504, 0.2132610627450049, 0.576764460420236, 1.6587620414793491, 26.065763421356678, 74.82704401016235, 110.16073241829872, 94.6902197599411, 93.47113117575645, 89.03296932578087, 39.719097688794136, 38.8277605175972, 68.76484170556068, 86.69106379151344, 85.36165952682495, 103.17608401179314, 26.441952735185623, 0.7782247220166028, 0.2268413855927065, 0.31720380240585655, 0.13995128480019048, 0.2692097652470693, 0.22753753495635465, 0.13446103956084698, 0.28299679106567055, 0.09812607560888864, 0.11296418291749433, 0.16765911597758532, 0.13508085161447525, 0.13009957125177607, 0.18129489209968597, 0.1532810289063491, 0.12252200598595664, 0.13390845124376938, 0.16540393698960543, 0.18279524752870202, 0.11738984700059518, 0.1383010155404918, 0.13957077084342018, 0.08325140268425457], [0.03274834234616719, 0.02287746097863419, 0.03223165913368575, 0.07381288727628998, 0.08285482865176164, 0.04025413451017812, 0.03551544366928283, 0.03580516699003056, 0.04967553599271923, 0.062488685944117606, 0.028680825744231697, 0.036155931957182474, 0.023425490653607994, 0.028741678142978344, 0.046233421671786346, 0.16102171823149547, 0.03621426105382852, 0.15140930277993903, 2.2249884204939008, 84.81912463903427, 105.6541134417057, 88.99479657411575, 60.603468641638756, 43.0789989978075, 35.82822047173977, 58.084891587495804, 94.07270729541779, 92.48443812131882, 90.6476166844368, 126.64401233196259, 99.39204186201096, 36.7338714748621, 2.5897322734817863, 0.04745724916574545, 0.17780224123271182, 0.041658623013063334, 0.13918773358454928, 0.2722372527932748, 0.10605235380353406, 1.1437920620664954, 1.0569585277698934, 1.494453395716846, 23.48832182586193, 106.3186825811863, 103.67356091737747, 100.59820353984833, 96.04100927710533, 96.33726418018341, 101.61711126565933, 104.53562065958977, 97.34023556113243, 101.13596588373184, 95.52087038755417, 91.44696459174156, 89.72181916236877, 92.51513287425041, 90.29238134622574, 90.20006909966469, 93.56975108385086, 86.78683385252953, 87.5563533604145, 77.1040566265583, 70.07572576403618, 69.12723585963249, 67.88930788636208, 69.92536023259163, 68.34670454263687, 81.81496024131775, 81.34111046791077, 83.15109014511108, 74.42051902413368, 65.7364422082901, 63.20016570389271, 64.46736350655556, 65.85870444774628, 64.01675328612328, 78.78167420625687, 86.08680501580238, 89.42884728312492, 87.09326460957527, 86.32748410105705, 78.29370439052582, 80.30701875686646, 81.72783851623535, 86.12304747104645, 76.1315444111824, 70.99359691143036, 81.33576795458794, 90.13596653938293, 66.41152158379555, 66.133733689785, 89.99709159135818, 82.47047826647758, 88.10554549098015, 82.89208084344864, 78.86118113994598, 67.2870934009552, 66.19943976402283, 63.415203765034676, 66.80369853973389, 69.22536939382553, 69.0166237950325, 64.45100158452988, 67.81092569231987, 62.49981388449669, 70.33373191952705, 78.32588106393814, 86.7981344461441, 87.40819171071053, 86.0280753672123, 83.79257172346115, 85.10511249303818, 81.40307754278183, 79.12304788827896, 71.15394070744514, 65.77910631895065, 61.841810792684555, 66.65378898382187, 68.72040688991547, 81.72452509403229, 77.32265889644623, 81.10354721546173, 81.82442173361778, 84.97671738266945, 79.60705071687698, 80.25530353188515, 81.22355997562408, 90.47284126281738, 84.700388610363, 91.90186098217964, 48.20177011191845, 0.026942098047584295, 0.3653190768091008, 0.5669998156372458, 0.14597038447391242, 0.17566175374668092, 0.05583208141615614, 0.2712342847371474, 0.04807832287042402, 0.026548594651103485, 0.07659159207833, 7.848771912977099, 41.80666387081146, 82.80572667717934, 71.64358243346214, 88.32714959979057, 73.04030388593674, 24.684718027710915, 23.27441230416298, 65.94796925783157, 63.915754705667496, 73.30809831619263, 49.42435830831528, 3.3681072061881423, 0.2794923697365448, 0.10292052771546878, 0.0719133454549592, 0.0740612692607101, 0.03877976909279823, 0.03804372558079194, 0.053550797383650206, 0.06606203052797355, 0.02240771118522389, 0.049767758973757736, 0.050492807567934506, 0.044851442507933825, 0.0648814813757781, 0.0449502891569864, 0.04645352411898784, 0.07616695002070628, 0.010764533853944158, 0.048452109258505516, 0.020889015431748703, 0.02755489866103744, 0.049624446546658874, 0.04555955158139113, 0.09354925088700838, 0.01681764337263303, 0.11544768363819458, 0.025766246690182015, 0.028894779497932177, 0.09319853415945545, 0.03323138771520462, 0.06271403908613138, 0.040108514003804885, 0.044774062480428256, 0.01470737521231058, 0.02095926527545089, 0.10119859667611308, 0.009565112814016175, 0.0454883833299391, 0.17023858381435275, 0.061308058866416104, 0.1903849098016508, 2.826041355729103, 103.73478323221207, 116.47852420806885, 108.67956429719925, 85.75265854597092, 74.09585684537888, 60.89390225708485, 38.2401068508625, 45.83903029561043, 91.96854740381241, 100.57251691818237, 130.4456627368927, 112.12011247873306, 45.24682827293873, 2.203645440749824, 0.1868282858049497, 0.24262337858090177, 0.07939751143567264, 0.2491287630982697, 0.25619944150093943, 0.19635683856904507, 2.641856214031577, 0.8791317511349916, 2.344218185171485, 33.30976501107216, 114.58741128444672, 106.98648914694786, 105.26851013302803, 97.86445543169975, 99.38514903187752, 105.21504700183868, 106.7205262184143, 102.22113445401192, 103.16564977169037, 98.24951156973839, 97.3269970715046, 95.259178429842, 94.11266595125198, 94.1438090801239, 94.263776242733, 96.54986277222633, 91.76037177443504, 92.73613661527634, 81.24294653534889, 73.16270291805267, 71.49064064025879, 71.09352394938469, 72.59597092866898, 72.52581909298897, 82.888965010643, 84.14073944091797, 86.872648447752, 76.23403251171112, 70.23748308420181, 67.21963942050934, 69.42563384771347, 67.91700080037117, 67.606261074543, 81.76446855068207, 88.90116959810257, 91.09085530042648, 92.01375737786293, 91.98979586362839, 86.03788644075394, 84.39884439110756, 86.2791658937931, 93.0772215127945, 82.85600557923317, 73.65752756595612, 85.51661521196365, 94.13494795560837, 68.30109938979149, 69.94057461619377, 91.21733531355858, 85.81530198454857, 91.35195448994637, 86.00030645728111, 82.99942508339882, 71.52953535318375, 68.63355115056038, 66.71426653862, 70.05838349461555, 71.80910155177116, 73.5384039580822, 67.57081657648087, 70.77253237366676, 64.79134932160378, 72.83478051424026, 82.02907875180244, 90.69296345114708, 91.009152084589, 89.89201962947845, 87.34533548355103, 89.28694769740105, 84.78565603494644, 82.4028342962265, 76.3332299888134, 70.21981403231621, 65.73831170797348, 68.94195020198822, 72.8066012263298, 83.78814116120338, 81.87249675393105, 84.71458464860916, 84.58289131522179, 87.62541085481644, 82.70009994506836, 82.81429141759872, 84.78738114237785, 92.69196778535843, 88.7440176308155, 95.43153718113899, 60.36502383649349, 0.09350648833788, 0.6864381534978747, 0.6800503400154412, 0.3771454078378156, 0.16419254417996854, 0.024692355291335844, 0.24208352551795542, 0.024259746278403327, 0.07895363291027024, 0.04125802282942459, 8.73300014063716, 48.9824116230011, 87.00526133179665, 78.2975497841835, 68.64507973194122, 58.700325563549995, 32.68541671335697, 38.48419055342674, 74.30526360869408, 76.83558583259583, 83.2328237593174, 70.95398783683777, 4.837208362296224, 0.23486744554247707, 0.18568488856544718, 0.07765110436594114, 0.0696264767611865, 0.09712387196486816, 0.05999698078085203, 0.020956233602191787, 0.08968409383669496, 0.02550699224229902, 0.01992851492104819, 0.060305513834464364, 0.016714711200620513, 0.03223527339287102, 0.04021740562166087, 0.0348595929244766, 0.05851149428053759, 0.029529718376579694, 0.06112420291174203, 0.11037497810320929, 0.08001659618457779, 0.05905745521886274, 0.03474165823718067, 0.1644715917063877, 0.07113430561730638, 0.1505145398550667, 0.10795205889735371, 0.18686004972551018, 0.26755441969726235, 0.1313037207000889, 0.08135171243338846, 0.10653089804691263, 0.13246623566374183, 0.15702256641816348, 0.11585795771679841, 0.21703292441088706, 0.10130206690519117, 0.14326633972814307, 0.22737767634680495, 0.18075500935083255, 0.45315338240470737, 4.927159510552883, 121.61046802997589, 130.25027722120285, 118.27679291367531, 87.21054911613464, 70.41731223464012, 49.77701358497143, 86.9743537902832, 130.68812012672424, 123.83490666747093, 110.76502159237862, 149.2963296175003, 121.30165100097656, 64.84861224889755, 5.070097865536809, 0.24545520631363615, 0.6766201334539801, 0.4378407681360841, 0.36945963744074106, 0.8417891955468804, 1.7379529983736575, 3.7093792436644435, 4.356420636177063, 6.460437085479498, 34.15643937885761, 121.22368678450584, 110.71256160736084, 113.02599146962166, 105.37855222821236, 105.02345368266106, 109.88945737481117, 112.71563932299614, 106.42335936427116, 107.28404358029366, 103.45593139529228, 103.30267041921616, 99.11605507135391, 102.0814311504364, 99.10622119903564, 100.20308554172516, 98.27154278755188, 97.60277107357979, 97.32546955347061, 87.35087558627129, 76.17300018668175, 76.20112627744675, 74.66118291020393, 78.28114986419678, 75.90658888220787, 89.49836075305939, 87.83072143793106, 92.71760880947113, 82.19421029090881, 74.02892723679543, 69.93653163313866, 73.1404285132885, 72.40411162376404, 71.43104463815689, 87.1722623705864, 94.88703399896622, 97.51172035932541, 97.85889253020287, 96.1761300265789, 88.29113513231277, 90.70007666945457, 90.7314857840538, 95.7286736369133, 86.09431341290474, 78.60089510679245, 92.94959396123886, 100.51541358232498, 74.40794169902802, 77.2183620929718, 94.73144754767418, 90.76851099729538, 95.43190956115723, 91.05500042438507, 86.16692751646042, 73.98775264620781, 74.99457702040672, 69.67861667275429, 73.7076772749424, 79.00295153260231, 79.30525571107864, 70.61182379722595, 75.76763793826103, 67.22790017724037, 77.28152990341187, 89.41737189888954, 97.17720150947571, 95.44318735599518, 93.47610130906105, 89.61549326777458, 91.90667912364006, 87.8671082854271, 87.31136530637741, 80.07425844669342, 74.14419785141945, 68.5527902841568, 74.61867079138756, 78.07495012879372, 90.8239272236824, 84.69905108213425, 89.37827199697495, 89.59540754556656, 95.13931006193161, 88.09062749147415, 88.06187823414803, 89.41177859902382, 97.56278201937675, 93.29679653048515, 101.30921378731728, 65.67542508244514, 0.21697859920095652, 6.177862398326397, 1.252385841216892, 0.3127187368227169, 0.756026313174516, 0.22490381612442434, 0.6953848921693861, 0.09915368296788074, 0.2793444151757285, 0.1854051137343049, 15.335554350167513, 65.6693834066391, 97.48585894703865, 92.79872685670853, 116.96657001972198, 94.79067116975784, 32.14967206120491, 38.25705774128437, 85.81277132034302, 90.53309082984924, 93.9358614385128, 88.85000914335251, 7.950974078848958, 0.5762782052624971, 0.2610074303811416, 0.17644189938437194, 0.18419735744828358, 0.13363921490963548, 0.11323388680466451, 0.06940773615497164, 0.22648751473752782, 0.06851974161691032, 0.15427292411914095, 0.12219427357194945, 0.09162809030385688, 0.1282401944627054, 0.14832536748144776, 0.09738255495904014, 0.18850936903618276, 0.15327068336773664, 0.13705163961276412, 0.24341827811440453, 0.16364903975045308, 0.08277246510260738, 0.17864413355709985], [0.044418013421818614, 0.040063012929749675, 0.018044328135147225, 0.022043704448151402, 0.03311006883450318, 0.062264460866572335, 0.051533669684431516, 0.04250712787325028, 0.0063573752231604885, 0.012625158378796186, 0.03202327148756012, 0.03157703664328437, 0.0914361783361528, 0.11557317338883877, 0.09839580918196589, 0.10406803645309992, 0.062044217411312275, 0.6512123811990023, 16.467457562685013, 100.44711604714394, 93.49481910467148, 67.5936533510685, 48.75724710524082, 25.2624599263072, 31.124401576817036, 67.80851662158966, 89.3352735042572, 99.9755385518074, 117.31688842177391, 98.02560478448868, 37.18008913099766, 1.972514649387449, 0.1890032980008982, 0.104202936636284, 0.17383019265253097, 0.1842450923868455, 0.12916958599817008, 0.29098437807988375, 0.48213938483968377, 0.4481766588287428, 4.0037976577878, 16.471952721476555, 99.02954131364822, 98.09469267725945, 110.41098698973656, 94.71869543194771, 88.41750875115395, 82.35782191157341, 95.99600449204445, 94.35731202363968, 100.30940383672714, 91.21410548686981, 92.81320407986641, 85.78016147017479, 85.76560065150261, 80.40443032979965, 80.34592866897583, 76.90857991576195, 83.3546832203865, 82.42732778191566, 83.312748670578, 76.15185812115669, 69.01021733880043, 68.3126811683178, 67.8118072450161, 67.59660199284554, 72.34446242451668, 72.92900025844574, 76.83722734451294, 71.69431731104851, 68.34396868944168, 65.40953055024147, 67.1337716281414, 62.77819834649563, 63.90899106860161, 59.1811403632164, 64.308410435915, 72.75743946433067, 84.40698355436325, 86.56757801771164, 86.6310878098011, 86.4341975748539, 86.8350076675415, 78.2545892894268, 86.68624565005302, 77.52622917294502, 73.46213445067406, 79.27026718854904, 87.46945962309837, 55.23539789021015, 60.743654519319534, 89.25619214773178, 75.87662369012833, 85.06488025188446, 81.28721415996552, 79.82766687870026, 69.54886123538017, 64.96255293488503, 61.9341192394495, 63.027278780937195, 62.8325430303812, 65.6614038348198, 64.18631538748741, 65.67317560315132, 65.06812646985054, 64.57829475402832, 69.71099093556404, 79.60170820355415, 81.37067288160324, 82.33576029539108, 84.74293112754822, 87.04357087612152, 82.30333283543587, 79.05751660466194, 74.44220826029778, 67.35588490962982, 63.3245862275362, 63.243547976017, 64.40209060907364, 69.53908056020737, 75.55252388119698, 78.7891598045826, 79.8783865571022, 82.06507802009583, 80.27359575033188, 80.75641304254532, 80.64965397119522, 81.91024392843246, 88.4519425034523, 85.84733426570892, 81.68600276112556, 12.01428746804595, 0.8822536398656666, 1.5055070025846362, 0.536338429665193, 0.27713590243365616, 0.053431805135915056, 0.12862078263424337, 0.367966050398536, 0.15804990660399199, 0.045304104351089336, 0.09363479082821868, 6.804842529818416, 44.08311031758785, 66.853878647089, 71.00245043635368, 68.79505768418312, 41.202956065535545, 22.387277707457542, 37.534180730581284, 57.630055993795395, 59.562955275177956, 76.2272384762764, 39.90676201879978, 1.4031300460919738, 0.08259351845481433, 0.056955778345582075, 0.1126093917991966, 0.009885083291010233, 0.06668679270660505, 0.01652456554438686, 0.03856349612760823, 0.085799091757508, 0.052120849504717626, 0.03153683079290204, 0.025364065731992014, 0.05153432648512535, 0.007057971442918642, 0.06507383121061139, 0.11281770523055457, 0.0392680725781247, 0.038578383610001765, 0.023928705741127487, 0.040231064849649556, 0.03323048229503911, 0.04203330368909519, 0.067134530399926, 0.030156078028085176, 0.026822287582035642, 0.07825549459084868, 0.03440105698246043, 0.02544256640248932, 0.09191794350044802, 0.03193265525624156, 0.04656851619074587, 0.05708101576601621, 0.02688643326109741, 0.0403732751874486, 0.11248925293330103, 0.08928548631956801, 0.07146465781261213, 0.06355351200909354, 0.1501747698057443, 0.7222012407146394, 20.2933943644166, 117.71532744169235, 105.68878278136253, 80.96189841628075, 55.71524374186993, 35.226933136582375, 39.692658707499504, 45.773651003837585, 91.43020749092102, 110.46886548399925, 124.93573039770126, 111.83762803673744, 44.39197674393654, 1.883044175338, 0.2183140197303146, 0.09746779061970301, 0.0543120924703544, 0.12594373722095042, 0.14507956977467984, 0.06624813147936948, 0.7821896905079484, 0.8165455469861627, 2.3904294054955244, 24.908043444156647, 109.42105650901794, 105.33008962869644, 114.48794782161713, 100.36993458867073, 90.57716086506844, 87.98266768455505, 100.84655821323395, 98.69041711091995, 102.44181901216507, 94.70636129379272, 96.16400867700577, 86.78331524133682, 88.00777673721313, 83.42128604650497, 82.63181760907173, 81.73955708742142, 85.43093740940094, 84.8752324283123, 84.53091010451317, 79.47321429848671, 71.53399631381035, 70.07080882787704, 70.75889870524406, 69.63878720998764, 73.84027495980263, 76.18399679660797, 79.37837898731232, 75.19320756196976, 71.12487986683846, 67.24691435694695, 71.27053365111351, 65.72780147194862, 67.74977937340736, 62.289126589894295, 67.80253574252129, 73.59309822320938, 88.7854354083538, 87.8394989669323, 91.39277949929237, 89.21449318528175, 89.57320153713226, 84.23831820487976, 90.96402570605278, 81.65457844734192, 76.98581457138062, 84.51843917369843, 91.59812048077583, 58.11304807662964, 65.08388042449951, 91.7371854186058, 81.9212557375431, 88.79909947514534, 84.85201567411423, 84.4565024971962, 73.57221454381943, 69.55500930547714, 63.53563070297241, 67.04620912671089, 66.00680530071259, 68.19338276982307, 67.79625847935677, 68.39468076825142, 66.72732263803482, 69.69368666410446, 71.38789415359497, 81.17447420954704, 85.42251706123352, 86.1287471652031, 88.24518039822578, 88.53534802794456, 85.26135250926018, 83.17318975925446, 76.50321006774902, 71.44410073757172, 67.34416633844376, 67.22238287329674, 66.42756432294846, 72.15939715504646, 78.75782668590546, 82.48867928981781, 85.23908570408821, 85.92369496822357, 82.9681983590126, 82.64278382062912, 83.03702026605606, 85.13666599988937, 92.50364229083061, 91.6148167848587, 92.51403093338013, 19.524674713611603, 0.40768392384052277, 0.7502827432472259, 0.5173802969511598, 0.3186091926181689, 0.10611001867800951, 0.07843168787076138, 0.4363358113914728, 0.07686422002734616, 0.031869543017819524, 0.14508638269035146, 7.167723057791591, 50.78076772391796, 71.50270119309425, 78.57235863804817, 56.74686558544636, 33.95297929644585, 30.89756514877081, 55.646281242370605, 68.05421903729439, 70.29997453093529, 91.07335343956947, 56.505171954631805, 1.4674368454143405, 0.01276961278563249, 0.06284309114562348, 0.024661878996994346, 0.0504668695066357, 0.0610857002902776, 0.027021949426853098, 0.018941157941299025, 0.04016709171992261, 0.016232131529250182, 0.022474150100606494, 0.03304491940070875, 0.03794720927544404, 0.03840682504232973, 0.018014132001553662, 0.06262256938498467, 0.05526352579181548, 0.04598227147653233, 0.05815916338178795, 0.07236922450829297, 0.06510222578071989, 0.055360658079735, 0.15819645108422264, 0.1569917524466291, 0.15986717393388972, 0.16128270188346505, 0.1118966109061148, 0.22713564714649692, 0.16930674319155514, 0.1434290481847711, 0.17175298067741096, 0.1215938241512049, 0.13505066104698926, 0.13436429318971932, 0.2996586001245305, 0.2682445279788226, 0.15384586266009137, 0.23367482906905934, 0.35933926643338054, 0.8840591961052269, 29.484800957143307, 137.83805966377258, 118.33319708704948, 96.7316222190857, 70.70603594183922, 38.383803740143776, 49.25746746361256, 97.90408730506897, 115.19324317574501, 122.54262641072273, 136.03320211172104, 122.04349279403687, 59.25311230123043, 4.563552271574736, 0.4888497060164809, 0.19899659848306328, 0.3707762074191123, 0.3567943529924378, 0.37771600065752864, 0.8195871650241315, 2.2010682290419936, 3.4905083756893873, 9.933517221361399, 20.884040370583534, 112.34963536262512, 106.84672504663467, 120.51144540309906, 106.91827520728111, 94.31258082389832, 92.61220246553421, 106.8175882101059, 102.06905141472816, 106.44146919250488, 101.70047119259834, 98.75120624899864, 92.57083788514137, 95.53794667124748, 91.42807200551033, 89.61994662880898, 87.14352071285248, 91.02577239274979, 89.83918726444244, 90.7700765132904, 84.8860314488411, 74.5570532977581, 77.46680796146393, 75.182264149189, 75.40945395827293, 78.84739547967911, 80.49652218818665, 85.03237679600716, 81.61436900496483, 74.62998658418655, 72.47232556343079, 73.74136626720428, 68.6426630616188, 71.87819704413414, 67.32152715325356, 71.65239036083221, 83.23152422904968, 95.76256021857262, 93.89278694987297, 93.91737163066864, 96.58700197935104, 93.75839576125145, 87.4522465467453, 95.03964141011238, 86.95641875267029, 80.50656884908676, 91.3253179192543, 93.76962795853615, 64.67950612306595, 71.5929463505745, 96.53043061494827, 85.71321666240692, 92.50540539622307, 88.6128106713295, 87.82128274440765, 77.97157287597656, 71.7823737859726, 68.4371168911457, 70.17442926764488, 69.20231983065605, 70.96208900213242, 69.78998869657516, 72.09731608629227, 70.57188034057617, 73.1613577902317, 76.79986774921417, 87.05468907952309, 89.85442444682121, 90.73056623339653, 92.40240812301636, 96.33096411824226, 89.4898872077465, 88.8292470574379, 80.43831691145897, 74.60965007543564, 71.25677838921547, 70.06732821464539, 71.15043729543686, 78.34554880857468, 83.9525431394577, 87.23594695329666, 87.55752369761467, 90.63838317990303, 86.3264125585556, 87.68211901187897, 86.34804099798203, 88.97858664393425, 99.12333548069, 96.98098003864288, 99.63301733136177, 23.794401101768017, 2.1129466826096177, 3.224662528373301, 1.6731166024692357, 0.6335486727766693, 0.4701872152509168, 0.39207213500048965, 0.954255263786763, 0.20913491462124512, 0.0871910342539195, 0.2614962088409811, 12.545547410845757, 66.48720592260361, 81.46643534302711, 92.38973960280418, 92.38929122686386, 55.2547350525856, 32.79148422181606, 55.23045435547829, 78.12463626265526, 84.39797043800354, 105.8997854590416, 73.11053931713104, 1.8812363035976887, 0.18464659427991137, 0.1772596125374548, 0.20466647314606234, 0.1558587304316461, 0.12972751777851954, 0.15698767063440755, 0.14357612701132894, 0.15747955127153546, 0.14463457802776247, 0.10650764656020328, 0.12808075145585462, 0.1756254627252929, 0.2690688462462276, 0.15750690683489665, 0.21136852679774165, 0.1786645277752541, 0.15647987835109234, 0.07639743882464245, 0.19174361892510206, 0.10992648341925815, 0.10311142294085585], [0.024664838310854975, 0.043674570697476156, 0.08780902804573998, 0.048592801904305816, 0.10545001932769082, 0.09712399070849642, 0.05830231624713633, 0.031670992539147846, 0.03469332958047744, 0.030616309777542483, 0.06430130000808276, 0.06965271910303272, 0.06862520080176182, 0.042059679617523216, 0.026882963720709085, 0.032703705874155276, 0.06565998686710373, 0.16015609202440828, 51.31738252937794, 105.06430149078369, 86.59194990992546, 75.61192229390144, 63.538480550050735, 85.29319480061531, 95.15414446592331, 93.54281052947044, 91.77532777190208, 108.36340606212616, 103.89634296298027, 59.86940883100033, 3.422659453935921, 0.27614020742475986, 0.1883992343209684, 0.11603031409322284, 0.12669801159063354, 0.11900622979737818, 0.29275876411702484, 0.12169581750640646, 0.6762806454207748, 3.508626753464341, 16.603015288710594, 118.44953164458275, 109.31491300463676, 110.83425387740135, 97.89455741643906, 91.95964068174362, 76.40126913785934, 80.221386551857, 82.0153234899044, 84.84749391674995, 82.98831447958946, 85.1998034119606, 78.37822705507278, 72.30444297194481, 72.3898395895958, 70.39564579725266, 67.426188737154, 69.61746275424957, 72.4859744310379, 74.87872883677483, 71.05668112635612, 69.07761812210083, 69.32025030255318, 67.83487200737, 68.34811806678772, 70.14621958136559, 68.21520119905472, 68.84609654545784, 70.32276570796967, 69.60715770721436, 64.72801432013512, 62.03447565436363, 64.3470011651516, 65.26687860488892, 67.81401112675667, 68.35760235786438, 68.86095374822617, 70.83792686462402, 80.29195636510849, 80.74315175414085, 82.06681072711945, 75.42333081364632, 72.590841203928, 85.44509544968605, 80.25515913963318, 69.21650826931, 67.7634434401989, 83.56318563222885, 88.18498402833939, 52.832186445593834, 61.5343426913023, 84.22864392399788, 75.6777423620224, 86.90383717417717, 82.7688230574131, 83.29818785190582, 75.34371748566628, 69.96545568108559, 62.553406208753586, 63.3602587133646, 59.85518239438534, 65.17551630735397, 63.48146840929985, 63.096951842308044, 62.5035110861063, 64.48580011725426, 59.16980557143688, 65.45776516199112, 69.67903465032578, 76.94706425070763, 76.35057985782623, 77.24004372954369, 75.26196867227554, 77.57051959633827, 72.35598340630531, 70.03315284848213, 62.08877854049206, 64.66193586587906, 60.06778858602047, 63.49811911582947, 69.21089977025986, 74.87679094076157, 76.78254067897797, 81.23013362288475, 76.03084221482277, 79.76300194859505, 74.83252331614494, 83.58816549181938, 81.85208424925804, 88.51644784212112, 79.18586611747742, 49.09775823354721, 1.9984422018751502, 1.0254343505948782, 0.6334463751409203, 0.08002205097000115, 0.2722621592693031, 0.0999074823630508, 0.17657367512583733, 0.04171111882897094, 0.13570707582402974, 0.05729523669288028, 0.2625414793146774, 10.97376935184002, 39.23526205122471, 68.38242262601852, 89.02527093887329, 72.59760484099388, 31.205960400402546, 17.36169397830963, 49.38035286962986, 67.2081184387207, 69.03726428747177, 71.49750307202339, 21.878847889602184, 0.6957108434289694, 0.043423776733106934, 0.0970134700764902, 0.02639787559019169, 0.06706287604174577, 0.08069867442827672, 0.04762655902595725, 0.02409213408100186, 0.07173804275225848, 0.023871096527727786, 0.042460135082365014, 0.022761366817576345, 0.03230617076042108, 0.011040009794669459, 0.013719776106881909, 0.07726828232989646, 0.07279190729605034, 0.07927972517791204, 0.057646135246613994, 0.04191422980511561, 0.02307785012817476, 0.025090959097724408, 0.0650038466847036, 0.0756915524834767, 0.01884223151137121, 0.09724215546157211, 0.06912646960699931, 0.005818301415274618, 0.052775828226003796, 0.02907421781856101, 0.046558207759517245, 0.04908515009447001, 0.010717925124481553, 0.04232217725075316, 0.003915059523933451, 0.062433418206637725, 0.050089687792933546, 0.05241871047473978, 0.045278960387804545, 61.790847927331924, 120.89438125491142, 96.76137462258339, 85.63852027058601, 63.99754911661148, 80.65789952874184, 59.89884205162525, 75.96538692712784, 104.8408430814743, 115.75353071093559, 116.54946640133858, 69.4512140750885, 4.813250647857785, 0.4373488429700956, 0.17661240039160475, 0.13831510150339454, 0.1741282391594723, 0.3040590905584395, 0.15736380591988564, 0.1434995818999596, 0.5392842215951532, 1.8869625963270664, 24.358456134796143, 125.10341539978981, 111.2516538798809, 111.75193503499031, 102.06401288509369, 96.86919003725052, 81.73761919140816, 83.58137905597687, 84.15425151586533, 88.14496457576752, 87.14990437030792, 86.33583605289459, 81.29614368081093, 76.55643001198769, 76.13047286868095, 72.29158446192741, 71.22579485177994, 73.41861918568611, 75.70617243647575, 77.76827618479729, 75.60650378465652, 72.89702877402306, 73.30416932702065, 70.11072188615799, 71.51755079627037, 72.30845555663109, 72.60203540325165, 72.54219621419907, 74.48515355587006, 72.22172141075134, 67.48490318655968, 66.00022405385971, 65.01737639307976, 69.81002882122993, 71.5393616259098, 73.88639688491821, 74.77070063352585, 73.75770539045334, 84.48675647377968, 84.59163844585419, 84.39840361475945, 78.87254253029823, 75.48689380288124, 87.40249961614609, 85.56152880191803, 72.77694001793861, 72.01267942786217, 88.74600112438202, 90.28028279542923, 55.43448820710182, 63.61513003706932, 86.45806029438972, 78.87519478797913, 89.28086802363396, 85.29859811067581, 87.69062295556068, 79.56364944577217, 71.69550284743309, 66.88257470726967, 67.01305210590363, 63.066492676734924, 68.16426113247871, 64.75627720355988, 66.98984295129776, 64.28661480545998, 68.24012786149979, 63.82876977324486, 66.42358213663101, 74.0552370250225, 79.47052404284477, 77.79522433876991, 80.15475332736969, 75.45849412679672, 79.39008235931396, 75.98192363977432, 72.93801337480545, 65.93474596738815, 67.39311531186104, 64.12569344043732, 67.78902366757393, 71.95075035095215, 77.753966152668, 80.3607326745987, 84.17487680912018, 83.0865316092968, 84.69189986586571, 78.56120243668556, 88.52711766958237, 85.3410342335701, 92.64828532934189, 85.88325753808022, 64.81668636202812, 2.9269131179898977, 0.6375268811825663, 0.6690763507504016, 0.1432950163143687, 0.16237900243140757, 0.07162198569858447, 0.32763635041192174, 0.1128485934168566, 0.11164535681018606, 0.05709630029741675, 0.37219011748675257, 11.921573393046856, 43.799375742673874, 66.66534036397934, 67.90112525224686, 53.561257123947144, 35.579295828938484, 30.967998169362545, 60.67636393010616, 80.4734118282795, 78.49222093820572, 85.83614006638527, 31.947059333324432, 0.7065647235140204, 0.013200928606238449, 0.10730185589636676, 0.026563166720734444, 0.06348739407258108, 0.04683582294092048, 0.05816441778733861, 0.04946974957420025, 0.06604173278901726, 0.0697974898503162, 0.043905003840336576, 0.03293708534329198, 0.05557058939302806, 0.041982640977948904, 0.027895512903342023, 0.05838843135279603, 0.024481388682033867, 0.04752507033117581, 0.052851130240014754, 0.01858713494584663, 0.07507937712944113, 0.053324264226830564, 0.10393200078397058, 0.18655867839697748, 0.1347878368687816, 0.23293646634556353, 0.14972804143326357, 0.16195430100196972, 0.07560725935036317, 0.10828388796653599, 0.2118195002549328, 0.21537376422202215, 0.2563699573511258, 0.17997452232521027, 0.13356072537135333, 0.1785712398122996, 0.11359939453541301, 0.17529922944959253, 0.34585432440508157, 78.6161170899868, 135.67612767219543, 110.93602001667023, 103.76008987426758, 83.71245682239532, 100.24566605687141, 118.7852132320404, 120.79040363430977, 112.7954350411892, 129.6805813908577, 125.48258945345879, 85.4877595603466, 7.000029506161809, 0.5174249445553869, 0.6355080020148307, 0.3989228408318013, 0.33500362071208656, 0.6695730553474277, 0.507570292102173, 0.32907700748182833, 2.1435592649504542, 9.123331345617771, 19.712772220373154, 127.90128886699677, 117.47825056314468, 117.03937411308289, 107.31703341007233, 103.14085990190506, 86.57521560788155, 86.47325187921524, 87.95197293162346, 94.41488653421402, 92.5341546535492, 90.73116660118103, 87.70999431610107, 83.23310494422913, 80.70514619350433, 77.53124490380287, 77.40535005927086, 78.84681791067123, 79.87019419670105, 82.42020696401596, 80.27336776256561, 77.62127727270126, 76.75402700901031, 74.75654259324074, 75.5400225520134, 76.82249933481216, 76.08907788991928, 76.11988663673401, 79.88814443349838, 76.77910566329956, 71.79696500301361, 72.08144053816795, 69.59235370159149, 73.94137993454933, 75.11702165007591, 77.54549413919449, 77.17616155743599, 80.2839843928814, 88.81963357329369, 90.07027566432953, 86.08425915241241, 82.58560448884964, 78.71969193220139, 89.2051912844181, 89.84778240323067, 77.52419248223305, 76.15688145160675, 93.16047504544258, 95.33364683389664, 61.63906887173653, 70.8476847410202, 89.35993418097496, 83.00603672862053, 96.0715140402317, 90.63379302620888, 91.0933555662632, 84.47902008891106, 76.39868527650833, 68.88862386345863, 69.83333677053452, 65.90171054005623, 71.80834159255028, 69.95977878570557, 69.82965856790543, 68.56251776218414, 70.16675367951393, 65.78688830137253, 73.84344398975372, 78.28474447131157, 87.68160983920097, 84.36300471425056, 85.26861771941185, 83.37588608264923, 83.3047766983509, 81.4376100897789, 77.42920517921448, 68.19570064544678, 71.47886887192726, 68.50453287363052, 72.01787754893303, 76.62414997816086, 82.54563063383102, 86.7271238565445, 88.70307862758636, 85.81093981862068, 87.2584493458271, 83.38141858577728, 92.19786509871483, 90.9952600300312, 95.77756941318512, 92.69784986972809, 74.5694862306118, 2.547659268602729, 2.4424422020092607, 3.817889071069658, 0.3682469384511933, 0.5942951166070998, 0.39168998831883073, 0.6319718167651445, 0.23737339623039588, 0.5929092597216368, 0.1660249216365628, 0.41338305396493524, 18.59534528106451, 58.82095389068127, 85.76236322522163, 109.0358179807663, 97.35580712556839, 42.4274555593729, 25.666197761893272, 69.0194508433342, 91.2170921266079, 91.00030615925789, 102.73757234215736, 42.31139838695526, 1.0396187519654632, 0.14000135008245707, 0.15905707521596923, 0.1262094112462364, 0.27424903702922165, 0.21029515861300752, 0.13361948862439021, 0.16583764809183776, 0.25842929841019213, 0.10656122962245718, 0.15347515989560634, 0.13226946262875572, 0.1729592081392184, 0.1728846222977154, 0.1879130385350436, 0.22518819227116182, 0.14416098390938714, 0.19375289470190182, 0.09328062311396934, 0.15275447512976825, 0.1567089496529661], [0.0389719927625265, 0.05393049868871458, 0.06028592113580089, 0.011987420675723115, 0.027929044990742113, 0.051213748374721035, 0.035329609891050495, 0.0024251025115518132, 0.03207824607670773, 0.033736281911842525, 0.01789673166058492, 0.02371417125687003, 0.08429967885604128, 0.013583362870122073, 0.12714515556581318, 0.06730458611855283, 0.3417925798567012, 4.028890086337924, 83.69778960943222, 94.55861762166023, 76.05323821306229, 58.16953964531422, 39.073797315359116, 25.909075029194355, 84.47183847427368, 72.82496944069862, 109.23744276165962, 112.18397945165634, 72.17790216207504, 6.845915950834751, 0.5795840872451663, 0.3374497394543141, 0.11561879320652224, 0.20271852845326066, 0.019382502032385673, 0.08824685064610094, 0.10670459028915502, 0.3502098110038787, 0.849284827709198, 6.864249017089605, 121.29310145974159, 104.15684178471565, 101.88683599233627, 98.23878094553947, 96.8923307955265, 82.22274675965309, 74.73409339785576, 75.91734230518341, 72.52616107463837, 71.2785816192627, 71.48095116019249, 70.22159993648529, 69.9188169836998, 69.00039866566658, 67.43976920843124, 68.5654816031456, 69.28586974740028, 67.4927231669426, 66.28795221447945, 68.54394435882568, 68.72419148683548, 67.65504285693169, 66.59882113337517, 69.76194620132446, 67.8619721531868, 67.70047321915627, 66.56936511397362, 68.44158545136452, 67.03598767518997, 64.10191431641579, 62.52582348883152, 64.97973561286926, 68.49770843982697, 72.74025678634644, 78.86884152889252, 79.66356888413429, 80.97211226820946, 82.070542126894, 83.45866084098816, 84.52400207519531, 82.87291467189789, 75.90341985225677, 70.04268273711205, 85.29206246137619, 79.67569783329964, 68.60071331262589, 72.25424006581306, 83.5238653421402, 76.32991656661034, 53.35589334368706, 53.67455944418907, 78.62402826547623, 74.70251709222794, 77.99868062138557, 81.4112851023674, 80.01445725560188, 76.5515586733818, 73.82930874824524, 71.28922864794731, 71.39832079410553, 70.74167042970657, 68.81202757358551, 62.88980595767498, 62.81113877892494, 61.038454100489616, 61.400745660066605, 61.570106372237206, 62.616038247942924, 59.120981991291046, 61.56459666788578, 63.44980850815773, 65.74713483452797, 65.07948026061058, 65.47400549054146, 64.43119704723358, 65.90985730290413, 65.16296938061714, 63.53332802653313, 62.05975949764252, 62.989204823970795, 61.81420147418976, 71.61109417676926, 73.62085193395615, 76.53419360518456, 80.49204602837563, 80.80031588673592, 75.121900588274, 77.69212827086449, 80.65777033567429, 90.62629222869873, 80.07008627057076, 74.30932939052582, 16.282605081796646, 0.46700429229531437, 0.2414236226468347, 0.11227410432184115, 0.04137165677093435, 0.06206538717378862, 0.15396613511256874, 0.1157864072592929, 0.03606001308071427, 0.057239905872847885, 0.10711639319197275, 0.3994866949506104, 14.842422511428595, 31.00736975669861, 80.68469569087029, 76.22737526893616, 49.57816645503044, 24.7085864469409, 29.255359768867493, 49.20216143131256, 54.26829278469086, 64.21933561563492, 49.70614738762379, 5.673578158020973, 0.12890178943052888, 0.0318568003422115, 0.05938219306699466, 0.07832563496776856, 0.02383247516263509, 0.023250002413988113, 0.011896458418050315, 0.024445401941193268, 0.039317399423453026, 0.0420943861536216, 0.022524039122799877, 0.04333556134952232, 0.04692504393460695, 0.0148578901826113, 0.021256092804833315, 0.025466096194577403, 0.033864821889437735, 0.02788869256619364, 0.02451731234032195, 0.04759624229336623, 0.056060050628730096, 0.04461980708583724, 0.07203297223895788, 0.025353761011501774, 0.05113913655804936, 0.04722090481664054, 0.05795348457468208, 0.03717480423802044, 0.05647749756462872, 0.03171210009895731, 0.023357886566373054, 0.03629068371083122, 0.006968342731852317, 0.0480808944121236, 0.09493863297393546, 0.04057265687151812, 0.3361475671408698, 5.879583153873682, 100.20212799310684, 103.7023937702179, 91.94841608405113, 70.30745252966881, 56.99942283332348, 35.731291472911835, 55.29868349432945, 75.37353068590164, 121.26784041523933, 120.09400740265846, 85.51806673407555, 8.450991623103619, 0.9844470780808479, 0.29866661585401744, 0.21688154112780467, 0.08461382996756583, 0.22132920246804133, 0.04438606396433897, 0.13372202374739572, 0.4043279914185405, 0.9756686585023999, 10.748767275363207, 127.29708328843117, 105.77506855130196, 107.72285923361778, 102.45020896196365, 98.84354889392853, 84.41918089985847, 80.6295682489872, 78.72174382209778, 75.4443208873272, 75.37348508834839, 74.61770564317703, 72.02226251363754, 72.37512677907944, 72.2505010664463, 70.32363966107368, 71.7073430120945, 72.08030819892883, 72.05117136240005, 69.86441150307655, 71.39059960842133, 72.26896047592163, 69.08812835812569, 69.85453203320503, 72.4578407406807, 70.33617898821831, 69.68013659119606, 70.14474526047707, 72.06436425447464, 70.51912397146225, 68.36780861020088, 64.47842851281166, 67.86295250058174, 73.16331848502159, 78.8221724331379, 82.12101861834526, 84.78920504450798, 85.52614510059357, 86.43558830022812, 86.26334354281425, 88.85877147316933, 85.44748932123184, 80.49881726503372, 76.77975922822952, 85.91743290424347, 84.23739105463028, 71.3964056968689, 76.53768181800842, 85.8280237019062, 81.96768924593925, 57.897858023643494, 55.265929251909256, 81.59474685788155, 77.15872809290886, 81.64850637316704, 83.99640038609505, 84.23682868480682, 79.56104278564453, 78.6241802573204, 76.63547337055206, 77.28650003671646, 75.846156924963, 74.99475181102753, 67.74782627820969, 65.32224163413048, 64.31148067116737, 65.53189918398857, 63.847023993730545, 64.84627917408943, 62.78455160558224, 65.1899479329586, 64.18616339564323, 68.88166263699532, 66.83725073933601, 67.71609798073769, 67.97158107161522, 69.61564645171165, 68.25299397110939, 66.89902782440186, 63.11578743159771, 66.53764441609383, 64.11431685090065, 74.74379047751427, 76.00379526615143, 81.83697625994682, 83.97534191608429, 84.60792437195778, 77.85817176103592, 81.92885532975197, 82.06529080867767, 95.89068174362183, 85.85396111011505, 85.90268969535828, 23.046139553189278, 0.22373500774847344, 0.2790436375653371, 0.03683287824969739, 0.07361232186667621, 0.20147563889622688, 0.12775333074387163, 0.0926277409598697, 0.06190231135406066, 0.1029034583189059, 0.12263588112546131, 0.38520435977261513, 16.379273794591427, 39.990707114338875, 77.92956992983818, 55.77805817127228, 43.230420872569084, 33.55392470955849, 43.137690648436546, 61.66863888502121, 65.65571174025536, 76.03434562683105, 64.23705026507378, 7.9794977232813835, 0.11928156658541411, 0.061181767596281134, 0.04830107849556953, 0.08301280962768942, 0.04489741855650209, 0.015553621160506736, 0.01917272100399714, 0.06998343495070003, 0.06554037492605858, 0.02960668280138634, 0.019585611153161153, 0.07811208197381347, 0.025679463651613332, 0.05258447657979559, 0.06212131542270072, 0.09033454916789196, 0.03388414370419923, 0.03427937816013582, 0.031093518155103084, 0.043564666048041545, 0.147890112712048, 0.1817254861816764, 0.17551709432154894, 0.12443900312064216, 0.1508603064576164, 0.1734858361305669, 0.08824724398436956, 0.09950221035978757, 0.2956769778393209, 0.14931384881492704, 0.15827289229491726, 0.17037267505656928, 0.1749711111187935, 0.14559255709173158, 0.2988691924838349, 0.2554364246316254, 0.5833233240991831, 11.337076406925917, 124.21414151787758, 114.38902392983437, 108.79890829324722, 84.04005244374275, 64.44936767220497, 34.40398849546909, 118.94773051142693, 89.91991773247719, 131.3702443242073, 132.63065189123154, 102.5715820491314, 11.817999500781298, 1.1999861779622734, 0.9873010218143463, 0.42457573930732906, 0.3645715559832752, 0.33335694344714284, 0.32172683626413345, 0.3514299017842859, 0.6141831306740642, 1.7340541700832546, 8.598950933665037, 131.7811694741249, 112.4351991713047, 113.06995511054993, 107.10858419537544, 107.05307677388191, 89.00553479790688, 83.19636851549149, 82.67087951302528, 81.1923560500145, 78.56774568557739, 79.14502590894699, 78.07881072163582, 76.99628680944443, 76.34178712964058, 75.87991431355476, 75.61202868819237, 77.42335349321365, 76.31652608513832, 74.66752856969833, 75.31400308012962, 77.61040985584259, 74.30909380316734, 73.21767836809158, 77.53302320837975, 74.54594269394875, 72.99760177731514, 73.33055511116982, 75.7626374065876, 73.42491164803505, 72.29010254144669, 70.59385076165199, 71.27186357975006, 75.97304731607437, 82.34483420848846, 86.00131720304489, 90.13964474201202, 88.70630085468292, 90.00192493200302, 91.23841658234596, 92.6084254682064, 89.15948733687401, 83.18430796265602, 81.98164969682693, 90.83915680646896, 91.2021741271019, 75.62816262245178, 79.28835421800613, 90.48342749476433, 87.17351630330086, 63.87606203556061, 64.92623448371887, 87.35586851835251, 82.85386249423027, 86.93455472588539, 88.1374941766262, 86.58038333058357, 84.71260875463486, 81.53680756688118, 80.1157446205616, 80.37096932530403, 78.2165989279747, 77.43264779448509, 69.33980405330658, 70.23473963141441, 67.6445098221302, 67.59221702814102, 68.4976552426815, 69.3576554954052, 64.43226099014282, 69.02138873934746, 70.7748730480671, 73.03488537669182, 72.56748005747795, 73.86320292949677, 70.60385942459106, 74.21248778700829, 73.69457557797432, 69.55646082758904, 67.63547390699387, 70.60172393918037, 68.8524878025055, 79.36522409319878, 80.45565158128738, 86.10166221857071, 88.57498750090599, 87.5589220225811, 82.94816583395004, 87.1416588127613, 87.08048969507217, 101.23945713043213, 88.72207760810852, 93.6901818215847, 24.210328683257103, 0.6335920142009854, 2.1934980852529407, 0.5528089427389205, 0.21786139870528132, 0.4330335510894656, 0.5313673464115709, 0.25001263129524887, 0.2604828804032877, 0.33263991004787385, 0.31990804011002183, 0.544008199358359, 25.35997599363327, 52.712777853012085, 100.87976083159447, 94.7656837105751, 68.37121322751045, 34.2625866830349, 44.21737991273403, 70.0036208331585, 80.1074230670929, 89.6913143992424, 84.27594378590584, 13.067516852170229, 0.1775636852835305, 0.1926633922266774, 0.21350978611735627, 0.18817329488229007, 0.16987623763270676, 0.13138495618477464, 0.1283646674710326, 0.2296827721875161, 0.2101173994014971, 0.11846679233713076, 0.07899465883383527, 0.18379135814029723, 0.22676777938613668, 0.16094572230940685, 0.08829146856442094, 0.14731447328813374, 0.1306053448934108, 0.10358202620409429, 0.11140939095639624, 0.08625074056908488], [0.016928518380154856, 0.04669442896556575, 0.043560420963331126, 0.019169355364283547, 0.04266070791345555, 0.055338649690384045, 0.04893780409474857, 0.02705050355871208, 0.06613707650103606, 0.09646117861848325, 0.021874817612115294, 0.057336117897648364, 0.03721849076100625, 0.07992140090209432, 0.05430367651570123, 0.04870665849011857, 0.010723918894655071, 30.012404546141624, 89.56195414066315, 91.09894126653671, 85.03648057579994, 45.587122812867165, 21.75932340323925, 56.39636479318142, 67.01464802026749, 87.26082041859627, 115.14477297663689, 85.5405767261982, 16.691301651299, 0.31449698202777654, 0.2595538896275684, 0.07422713926644064, 0.06129767622041982, 0.12597561988513917, 0.03720123211678583, 0.1280461673741229, 0.14185722393449396, 0.1749505239422433, 0.25068068294785917, 78.63339856266975, 113.44744965434074, 97.21498668193817, 104.97905686497688, 90.9167030453682, 81.7831939458847, 74.33430925011635, 75.7346785068512, 75.88313654065132, 77.60603249073029, 71.24955117702484, 71.83750122785568, 68.43490540981293, 67.58811324834824, 68.43644052743912, 67.96769767999649, 67.22055897116661, 67.72236004471779, 64.8487414419651, 66.80947422981262, 65.97152039408684, 66.61683976650238, 65.7403028011322, 65.93979209661484, 67.58116722106934, 67.30099305510521, 69.23480048775673, 69.20657560229301, 66.54846623539925, 65.5957281589508, 61.00725397467613, 62.72299110889435, 66.19922697544098, 71.49213775992393, 77.1416138112545, 83.80681335926056, 84.40352573990822, 86.45578801631927, 82.54043251276016, 85.80035358667374, 82.0404477417469, 80.99991157650948, 81.99874877929688, 75.91414287686348, 82.49944031238556, 75.27917414903641, 63.676652535796165, 74.43437308073044, 81.52400985360146, 85.65045163035393, 62.77779936790466, 55.43083280324936, 78.19520607590675, 71.23842537403107, 74.8973174393177, 79.74986985325813, 77.65451028943062, 78.0557231605053, 77.51733765006065, 77.15058892965317, 78.747149258852, 78.05047944188118, 79.63438645005226, 76.86029970645905, 64.32569190859795, 61.46378047764301, 59.86373193562031, 63.41868057847023, 62.43398241698742, 63.974742740392685, 59.2503422498703, 58.93975831568241, 60.53792215883732, 60.036520063877106, 60.40863789618015, 60.48845261335373, 61.477452144026756, 62.43683986365795, 61.566830947995186, 59.755475744605064, 61.003355383872986, 61.62413947284222, 59.84199330210686, 68.95553067326546, 77.52154022455215, 79.16519522666931, 77.16136515140533, 77.70272970199585, 75.84398344159126, 79.90612506866455, 83.11306178569794, 84.37456369400024, 80.23938998579979, 48.63525465130806, 1.559890634380281, 0.5289609474129975, 0.1615102295181714, 0.09625741455238312, 0.259577578981407, 0.05936481938988436, 0.0873730237071868, 0.040909970412030816, 0.0453388591267867, 0.07448729171301238, 0.03093959116085898, 0.42043399123940617, 26.074996925890446, 38.99946950376034, 60.64770206809044, 62.11087055504322, 37.709818705916405, 21.181541606783867, 40.46899124979973, 53.241283893585205, 61.32606826722622, 64.15469348430634, 39.721179977059364, 1.5060303057543933, 0.08447778687695973, 0.13007677247514948, 0.02037074216787005, 0.10072929217130877, 0.01202204928631545, 0.024271023212349974, 0.0471673774154624, 0.016348567078239284, 0.06793274733354338, 0.04576033592456952, 0.05362936855817679, 0.02530458259570878, 0.07960906805237755, 0.02399456949206069, 0.05796595636638813, 0.023920876083138864, 0.03517228571581654, 0.03569327338482253, 0.07329421510803513, 0.04505852768488694, 0.027783847508544568, 0.007446737154168659, 0.055070508024073206, 0.015645714265701827, 0.018687233969103545, 0.02589281997643411, 0.03150780910800677, 0.030936837792978622, 0.06684439518721774, 0.09847590918070637, 0.08396810953854583, 0.01878423267044127, 0.11541750049218535, 0.03776924597332254, 0.13961295451736078, 0.05436833613202907, 35.84886096417904, 103.29957738518715, 102.35449969768524, 97.25928470492363, 58.157729879021645, 39.037839844822884, 46.17902085185051, 54.99194115400314, 104.80716168880463, 121.65547281503677, 101.1913289129734, 21.2656082957983, 0.24727529380470514, 0.23668441601330414, 0.13192474987590685, 0.1265145229990594, 0.13482234673574567, 0.08072060489212163, 0.13623987848404795, 0.08235198649344966, 0.12578978610690683, 0.4941752983722836, 87.21633240580559, 114.53568086028099, 103.21158170700073, 107.14662775397301, 93.3092750608921, 85.75392007827759, 77.20779106020927, 78.95404055714607, 79.30357620120049, 81.82686120271683, 74.34896886348724, 76.09980091452599, 71.80239871144295, 71.84491842985153, 70.04895240068436, 72.49632507562637, 70.35159856081009, 69.36670660972595, 67.253138422966, 69.38109263777733, 70.73480799794197, 70.07105201482773, 68.68574514985085, 69.54247757792473, 70.92997312545776, 69.76671874523163, 72.52348601818085, 71.75597280263901, 68.43588575720787, 67.85773918032646, 64.37021791934967, 65.72758108377457, 69.40585970878601, 75.37641853094101, 81.54313042759895, 86.24625205993652, 87.6231461763382, 89.38527122139931, 85.00089168548584, 87.72923648357391, 85.57986661791801, 85.43526917695999, 85.56597456336021, 81.4141957461834, 82.87216231226921, 80.5981895327568, 66.4118255674839, 78.16233024001122, 84.90028828382492, 88.76899749040604, 65.13182625174522, 62.469069734215736, 82.65241250395775, 77.1411882340908, 76.41751706600189, 82.32610121369362, 81.46035566926003, 84.37937423586845, 81.41508489847183, 81.76810875535011, 82.77544990181923, 82.58435055613518, 82.54590421915054, 79.53629851341248, 67.89792582392693, 62.3941795527935, 62.18562014400959, 65.43816581368446, 64.2615057528019, 67.29375064373016, 63.45658354461193, 61.59083425998688, 62.66337990760803, 62.13286377489567, 62.205192893743515, 64.17911857366562, 65.48863470554352, 64.9778813123703, 63.25487896800041, 63.37810255587101, 65.17797857522964, 66.11030414700508, 61.42950251698494, 73.39392811059952, 80.62710598111153, 82.28164359927177, 82.16237559914589, 81.53344094753265, 78.51505011320114, 84.39822882413864, 86.66755825281143, 89.70154345035553, 87.77036547660828, 59.921371042728424, 2.579863015562296, 0.6580558139830828, 0.10791928565595299, 0.1099840147071518, 0.9676590445451438, 0.12977514881640673, 0.19992340734461322, 0.04635769430024084, 0.0786849606083706, 0.23349371535005048, 0.015827473653189372, 0.2962515188846737, 30.25922030210495, 43.965461030602455, 45.767046958208084, 36.95438124239445, 33.892034366726875, 34.27560098469257, 51.72639258205891, 64.29316565394402, 74.86659228801727, 78.54293301701546, 49.574609845876694, 2.1798886405304074, 0.021663619081664365, 0.08186116712749936, 0.0633278397435788, 0.057470854808343574, 0.016034649743232876, 0.03834557930531446, 0.0814171030651778, 0.056972992460941896, 0.05948063524556346, 0.03224617554224096, 0.07173120757215656, 0.011923256442969432, 0.026814420816663187, 0.06496847592643462, 0.02946052794868592, 0.07892889712820761, 0.06833881343482062, 0.02680701232748106, 0.0832206777704414, 0.10070186981465667, 0.10178299344261177, 0.1961744186701253, 0.13548478775192052, 0.14967598719522357, 0.16428492672275752, 0.09406153316376731, 0.18470224051270634, 0.14492309535853565, 0.20649622339988127, 0.1715750730363652, 0.1749466054025106, 0.13301104627316818, 0.1523831341182813, 0.25099449267145246, 0.24828652938595042, 0.16806097410153598, 54.43297974765301, 117.72018358111382, 116.47343248128891, 112.93057858943939, 70.20500242710114, 35.38198381662369, 79.76559340953827, 98.07142272591591, 114.59723755717278, 135.88008552789688, 112.67299041152, 31.55832689255476, 0.4670441010966897, 0.7705799478571862, 0.25737438001669943, 0.3413112525595352, 0.29847953526768833, 0.12582439987454563, 0.48366901057306677, 0.34005574649199843, 0.45163260307163, 0.716270946431905, 87.18544006347656, 119.98379051685333, 105.01246467232704, 112.82745972275734, 99.82230797410011, 91.18535622954369, 82.49565571546555, 84.28181067109108, 83.00124898552895, 87.00849115848541, 79.50720727443695, 78.69060069322586, 74.62541922926903, 76.22802883386612, 75.675508081913, 76.06658309698105, 74.17427703738213, 75.18676310777664, 70.42659893631935, 74.29045960307121, 74.08393308520317, 74.2858238518238, 73.8736979663372, 72.32140526175499, 73.82182314991951, 74.06659841537476, 74.35806557536125, 74.29776281118393, 73.72918412089348, 73.36061149835587, 66.52290880680084, 67.76878595352173, 74.60236966609955, 78.24434503912926, 85.06549581885338, 91.87149301171303, 90.3268150985241, 94.29169714450836, 88.2722881436348, 91.82699739933014, 89.19829845428467, 88.25772732496262, 91.00550428032875, 90.38732305169106, 90.16312748193741, 85.33985629677773, 70.84741875529289, 83.05571526288986, 90.67596316337585, 92.0607228577137, 69.42802771925926, 66.7515729367733, 86.57823264598846, 79.53862398862839, 82.85082265734673, 87.69512951374054, 85.06776809692383, 89.06999453902245, 84.13060918450356, 85.7738234102726, 85.715511739254, 86.13554120063782, 87.13589072227478, 83.71059492230415, 71.62960678339005, 66.30692839622498, 66.05014577507973, 69.88402605056763, 68.24720308184624, 71.76075294613838, 66.20114207267761, 65.14337003231049, 65.94704210758209, 66.96762934327126, 65.7267527282238, 67.57715463638306, 68.97267535328865, 66.97972029447556, 66.40851214528084, 67.10920214653015, 69.28846880793571, 69.62409719824791, 64.71596136689186, 77.31878310441971, 84.97417151927948, 87.97367736697197, 84.64178815484047, 86.68214187026024, 83.58276218175888, 87.9362341761589, 90.24482309818268, 93.35657492280006, 93.25640469789505, 63.83362591266632, 2.2679904755204916, 0.7676165224984288, 0.30998775211628526, 0.40640793449711055, 1.5472021652385592, 0.6024621252436191, 0.41974970139563084, 0.24725614639464766, 0.373279619961977, 0.3670255118049681, 0.1990058456431143, 1.1438859882764518, 43.923340290784836, 57.766597867012024, 79.51029270887375, 80.85122555494308, 51.524513214826584, 30.855020731687546, 59.86653618514538, 76.57075524330139, 86.30166828632355, 92.71112635731697, 64.29630428552628, 4.0428628865629435, 0.15976420836523175, 0.21490149112651125, 0.1759718675748445, 0.18377203261479735, 0.196986639930401, 0.09665714271250181, 0.17070187692297623, 0.12149368616519496, 0.25547032593749464, 0.14180285419570282, 0.1593075055279769, 0.09602328180335462, 0.1553026243345812, 0.13902449078159407, 0.17640002741245553, 0.24130553210852668, 0.11910690212971531, 0.10480294076842256, 0.1453905296511948], [0.10087246730108745, 0.025033160636667162, 0.040010409502428956, 0.026146990712732077, 0.056531989757786505, 0.04960499856679235, 0.02873332898161607, 0.02472660726198228, 0.04434676724486053, 0.07206197537016124, 0.03771270545257721, 0.03074563643167494, 0.02262324942421401, 0.06856860461994074, 0.172540117346216, 0.1234854398353491, 4.969838820397854, 78.19639161229134, 94.134461581707, 72.37673029303551, 60.67286051809788, 49.46080595254898, 27.75210153311491, 56.227927431464195, 72.17436835169792, 100.70347309112549, 103.88447999954224, 36.477993205189705, 1.0906108282506466, 0.13850325078237802, 0.5638348229695112, 0.12098607199732214, 0.10784720827359706, 0.09687920071883127, 0.224821868177969, 0.1921659306390211, 0.5986526515334845, 0.4507511097472161, 18.79381623119116, 122.62119099497795, 97.82863095402718, 103.88812780380249, 81.29806637763977, 80.67936837673187, 76.16929918527603, 76.06925055384636, 74.30448085069656, 77.15751215815544, 72.74155631661415, 71.78185701370239, 70.1092703640461, 68.70664402842522, 68.34460705518723, 66.54761508107185, 67.46209681034088, 67.35849916934967, 65.34247934818268, 63.97452235221863, 66.2182791531086, 67.30663195252419, 67.77763947844505, 65.47718212008476, 67.93830245733261, 67.5858561694622, 63.60292889177799, 66.32224917411804, 68.94760429859161, 67.57331684231758, 63.742776587605476, 62.770572155714035, 62.735663428902626, 72.59806841611862, 81.03255182504654, 80.53848713636398, 80.70189356803894, 82.35459968447685, 81.64748802781105, 82.11345702409744, 78.50396230816841, 78.18071365356445, 74.13074657320976, 76.75788760185242, 73.37707981467247, 78.89298543334007, 74.8582935333252, 65.17139732837677, 73.54899778962135, 80.10100901126862, 86.76221877336502, 72.43768662214279, 75.9670740365982, 76.91808700561523, 71.060351729393, 69.26014512777328, 73.56629446148872, 72.73021012544632, 72.71403059363365, 76.11504569649696, 80.94511091709137, 78.1378747522831, 79.61458951234818, 73.41119438409805, 78.2412976026535, 69.00732949376106, 59.10727992653847, 62.32307016849518, 66.24914109706879, 67.76465177536011, 68.49356666207314, 68.10288682579994, 64.82667222619057, 63.347947373986244, 60.86760766804218, 60.66402219235897, 60.01665472984314, 60.304124504327774, 59.98898461461067, 62.07813151180744, 62.46986769139767, 59.58393394947052, 60.38951352238655, 59.315877333283424, 62.71621607244015, 68.57232883572578, 80.71310296654701, 77.37732276320457, 78.12940120697021, 73.90793412923813, 75.71510955691338, 81.89369201660156, 85.42538970708847, 81.04914173483849, 83.14572483301163, 27.50303439795971, 0.23426792380632833, 0.27845262084156275, 0.13641711819218472, 0.5882853828370571, 0.0831328371714335, 0.10627305367961526, 0.0798809909611009, 0.13041311380220577, 0.08104870837996714, 0.01335122835371294, 0.3516360407229513, 3.807610385119915, 38.6674053221941, 23.28517522662878, 83.16292271018028, 66.43525511026382, 26.384328827261925, 20.567374862730503, 43.16358245909214, 53.88953670859337, 59.44517679512501, 62.41241477429867, 19.13794856518507, 2.6694600703194737, 0.05590113083599135, 0.09702655414002948, 0.012980606297787745, 0.08660121980938129, 0.030932457266317215, 0.011331502209941391, 0.10669728755601682, 0.06171250337501988, 0.0386136764427647, 0.0611439291969873, 0.03856567062030081, 0.06792059837607667, 0.06856488646008074, 0.08863201044732705, 0.010798649454955012, 0.0041761011561902706, 0.051529561897041276, 0.03032176806300413, 0.03661632326839026, 0.034883961343439296, 0.04694352341175545, 0.013913946986576775, 0.028896842668473255, 0.01720006093819393, 0.02703208345337771, 0.020769707771250978, 0.0662102596834302, 0.12499901291448623, 0.059481729913386516, 0.06323397290543653, 0.07074369845213369, 0.026937838119920343, 0.07823594642104581, 0.1201498274167534, 5.991534646600485, 91.63955345749855, 104.46383491158485, 87.71903023123741, 76.1810253560543, 65.82633778452873, 36.797195076942444, 56.39261059463024, 81.61873117089272, 110.69692924618721, 116.67158424854279, 46.80329315364361, 1.1321877222508192, 0.08193723726435564, 0.2976855856832117, 0.21793740947032347, 0.03436026854615193, 0.24004471226362512, 0.2592396939871833, 0.30061160679906607, 0.5444918421562761, 0.8130145270843059, 22.076849564909935, 130.92858642339706, 99.73682776093483, 108.18783268332481, 84.20813262462616, 84.8585969209671, 77.0538005232811, 80.95185935497284, 77.86596134305, 81.1839585006237, 75.26234865188599, 75.59144139289856, 72.2801622748375, 72.46807739138603, 71.26360282301903, 71.8580125272274, 70.50859853625298, 70.8071181178093, 67.88429975509644, 68.15132662653923, 70.47999367117882, 70.90896025300026, 69.98934879899025, 67.94408574700356, 68.95271882414818, 69.6281173825264, 65.941471606493, 69.818145185709, 71.40398249030113, 71.16919308900833, 66.57924458384514, 64.98100474476814, 65.8828255534172, 77.04714328050613, 83.44717025756836, 85.1534914970398, 82.39356279373169, 84.74752888083458, 83.87555927038193, 84.16137233376503, 81.82515129446983, 82.84997910261154, 76.10338032245636, 77.80235275626183, 76.7050476372242, 84.20632392168045, 79.0134009718895, 68.91462966799736, 77.849842607975, 84.48293387889862, 88.10057535767555, 74.73271027207375, 80.66905573010445, 81.74032464623451, 74.50200945138931, 74.98940169811249, 78.75742390751839, 72.18878477811813, 74.25006777048111, 78.7855651974678, 82.88085624575615, 79.98730391263962, 83.5229229927063, 78.9225934445858, 81.27492561936378, 72.60240018367767, 62.26560205221176, 64.87922340631485, 69.43558931350708, 72.6481345295906, 73.53897392749786, 72.69576877355576, 68.95670101046562, 66.94962590932846, 64.79587107896805, 62.74597227573395, 64.34875667095184, 64.5131054520607, 64.07121956348419, 65.0616592168808, 65.18519058823586, 62.84177653491497, 64.04363304376602, 64.30981636047363, 65.96946850419044, 72.97157317399979, 82.3703384399414, 80.41843637824059, 80.33091187477112, 76.35481283068657, 78.8479882478714, 87.58178919553757, 88.90009045600891, 85.24163916707039, 90.05319938063622, 37.424746602773666, 0.10077699000248685, 0.34592245356179774, 0.1647131607751362, 0.6728585134260356, 0.004073752497788519, 0.050468123736209236, 0.05786837878986262, 0.09366603524540551, 0.4176099709002301, 0.13533119286876172, 0.47780450026039034, 3.928675688803196, 48.63433510065079, 26.334479302167892, 54.36952315270901, 49.04919683933258, 29.105452112853527, 34.41261783242226, 59.89987939596176, 62.640041559934616, 73.40585187077522, 75.87183594703674, 28.955369666218758, 2.3589309956878424, 0.024853097056620754, 0.10221884935162961, 0.047215550221153535, 0.03483653810690157, 0.07939671733765863, 0.03917560839909129, 0.03536067248205654, 0.058026957194670103, 0.14399630133993924, 0.032569473623880185, 0.03589797255699523, 0.06502133910544217, 0.03173423094267491, 0.007240657587317401, 0.03817494842223823, 0.01763373122230405, 0.06422341160941869, 0.043674088301486336, 0.23363574757240713, 0.16673932783305645, 0.17963360936846584, 0.24839194404194131, 0.2355898224050179, 0.11837622805614956, 0.11885284271556884, 0.19721186690730974, 0.17666538973571733, 0.16644922230625525, 0.1683617220260203, 0.18187566718552262, 0.1417128465254791, 0.1854904310312122, 0.36619914520997554, 0.27937855396885425, 11.405555382370949, 113.34294766187668, 117.71445348858833, 99.82951238751411, 85.74654087424278, 73.33821550011635, 43.91939230263233, 79.15457859635353, 97.81831070780754, 120.74148505926132, 125.35036414861679, 60.36485284566879, 1.7275740928016603, 0.1993195663089864, 0.8415559236891568, 0.4649830679409206, 0.27469310851302, 0.35230150970164686, 0.6828163540922105, 0.49370278778951615, 1.1322720302268863, 1.0672373324632645, 22.368506714701653, 132.25995898246765, 104.72160547971725, 113.732540756464, 87.33765229582787, 88.92103493213654, 83.38442042469978, 84.79627266526222, 80.4012081027031, 85.46207293868065, 79.82953637838364, 77.56447792053223, 75.12908980250359, 77.04952955245972, 74.94947344064713, 73.78737419843674, 74.51204851269722, 73.81331160664558, 70.90162664651871, 72.78168216347694, 74.26939353346825, 74.97710555791855, 73.71440291404724, 72.05187052488327, 72.86665320396423, 72.09720209240913, 68.78248795866966, 72.97307029366493, 74.93213877081871, 73.30286979675293, 71.67221009731293, 69.69671130180359, 69.22327190637589, 80.48082143068314, 86.62772119045258, 88.29760238528252, 89.19671013951302, 89.35071587562561, 87.58158400654793, 88.24569717049599, 84.73229929804802, 87.53678441047668, 81.39511317014694, 83.91706064343452, 84.1000284254551, 90.6355257332325, 82.23785474896431, 71.48905232548714, 82.45513468980789, 87.92306408286095, 87.43583902716637, 73.85103598237038, 81.73709481954575, 86.04305416345596, 78.51352259516716, 78.93669068813324, 82.00478285551071, 78.96695986390114, 80.1382926106453, 83.32224056124687, 87.50358939170837, 85.10305300354958, 87.66159251332283, 81.96537896990776, 84.85821694135666, 76.92086845636368, 65.34912899136543, 69.04494747519493, 71.96521237492561, 74.4155640900135, 76.47277370095253, 74.43399310112, 72.36938148736954, 70.47701463103294, 68.16534027457237, 65.88031768798828, 65.13846069574356, 67.07832500338554, 67.09512770175934, 68.68594273924828, 69.4949421286583, 65.82581341266632, 67.82598048448563, 67.67287150025368, 68.36986050009727, 76.53537914156914, 88.34480345249176, 84.71374869346619, 84.25495371222496, 81.18503004312515, 84.08264815807343, 91.88703417778015, 92.88302913308144, 92.1130308508873, 95.50242617726326, 35.89912846684456, 0.346752738696523, 0.4490155231906101, 0.4260488133877516, 2.6277751196175814, 0.3892783052287996, 0.2968539349967614, 0.20062602823600173, 0.3050953662022948, 0.3581539081642404, 0.22736761282430962, 0.6136717612389475, 6.233043037354946, 63.308323100209236, 35.07108449935913, 109.47777986526489, 87.47186109423637, 37.49259956181049, 32.521178126335144, 67.75664180517197, 76.88166975975037, 84.74234595894814, 92.81394124031067, 41.08338788151741, 2.857051254250109, 0.1602461887523532, 0.32434608321636915, 0.22996941930614412, 0.1785376205225475, 0.18633619736647233, 0.17523700778838247, 0.09289803114370443, 0.12099004990886897, 0.22662953211693093, 0.154526011319831, 0.1594094469328411, 0.14353343867696822, 0.14906714408425614, 0.1649387291399762, 0.14125131972832605, 0.11447586352005601, 0.13697729125851765, 0.16940197558142245], [0.015008479367679683, 0.009839935664786026, 0.11192449339432642, 0.0887998026155401, 0.10015386054874398, 0.09902227087877691, 0.05383287658332847, 0.01563997004268458, 0.013787406169285532, 0.028924454272782896, 0.050036152970278636, 0.03205990760761779, 0.04990982088202145, 0.013435495511657791, 0.018202151404693723, 0.1258222624892369, 29.440010860562325, 91.84696912765503, 72.338907122612, 71.7046907544136, 49.6021431684494, 39.82262313365936, 62.6313666254282, 64.85181927680969, 88.95277082920074, 112.81394764780998, 65.19324615597725, 5.830314522609115, 0.04799786664079875, 0.15236664359690621, 0.12281533243367448, 0.09094202672713436, 0.22638784430455416, 0.23162034165579826, 0.0527569925179705, 0.21864362235646695, 0.10640617270837538, 1.1100038001313806, 73.8195888698101, 116.3285082578659, 94.94647800922394, 90.7655243575573, 72.93461635708809, 76.78832396864891, 78.86461615562439, 84.46622237563133, 84.1748084127903, 84.83993232250214, 75.09745270013809, 70.18878489732742, 66.54157340526581, 70.6536291539669, 71.31352454423904, 70.62384635210037, 67.60674744844437, 70.23603156208992, 68.86509552598, 67.92870417237282, 67.48263850808144, 67.62261539697647, 65.53284153342247, 65.37050664424896, 64.6051213145256, 66.10891342163086, 62.50697650015354, 63.32358308136463, 69.47423323988914, 67.23931476473808, 63.68472330272198, 65.68528935313225, 67.56557285785675, 75.3287310898304, 86.32395789027214, 81.38476252555847, 76.84119433164597, 81.73770278692245, 79.91073802113533, 83.47829058766365, 81.48069217801094, 79.7646814584732, 73.67815285921097, 75.99578529596329, 73.19082900881767, 82.70754754543304, 69.17326658964157, 69.132639169693, 73.55500146746635, 82.80191168189049, 87.97977223992348, 90.35143777728081, 77.2187876701355, 71.51194229722023, 67.03224867582321, 71.35847613215446, 71.18028089404106, 71.51077196002007, 69.48873326182365, 71.99740424752235, 77.24087968468666, 78.22616681456566, 75.8061982691288, 76.83835968375206, 75.23890390992165, 67.25443795323372, 61.25360995531082, 63.08144487440586, 66.78446397185326, 72.73701176047325, 74.58156958222389, 76.98358029127121, 74.65931341052055, 74.76265266537666, 70.00955611467361, 67.64697968959808, 57.95469157397747, 60.36456786096096, 61.548436135053635, 61.83834917843342, 58.66927742958069, 60.843383967876434, 58.77458117902279, 61.8203267455101, 61.09219081699848, 62.297915518283844, 67.77355089783669, 77.14301973581314, 72.51230701804161, 77.47471153736115, 73.85677367448807, 77.80214756727219, 79.96098652482033, 81.50497287511826, 83.29714670777321, 91.8233571946621, 9.941400848329067, 0.9934864367824048, 0.0839917320990935, 0.0734233413822949, 0.03203933527402114, 0.1881286027492024, 0.13633092516101897, 0.04826095428143162, 0.2921699144644663, 0.0903755528270267, 0.24015501025132835, 0.3496238705702126, 17.031833678483963, 30.86939726024866, 35.96403658390045, 81.79928228259087, 52.591199576854706, 21.0640899091959, 24.84825175255537, 68.13885569572449, 54.98226687312126, 67.07279250025749, 51.53132624924183, 17.87946179509163, 0.9006546274758875, 0.07640173585969023, 0.03078885725699365, 0.01660761558014201, 0.024365207318624016, 0.07529305628850125, 0.050943940586876124, 0.11665129874018021, 0.10012117636506446, 0.061438572956831194, 0.017904151281982195, 0.03284484751929995, 0.017945256986422464, 0.039049966508173384, 0.014048170887690503, 0.07389496880932711, 0.03311648470116779, 0.05240922582743224, 0.027856739397975616, 0.05709895718609914, 0.04278996777429711, 0.0438953484990634, 0.01955583989911247, 0.04081388084159698, 0.10205593309365213, 0.07918276358395815, 0.012058275369781768, 0.026751957957458217, 0.09336800358141772, 0.00753799348785833, 0.011121142306365073, 0.05859566495928448, 0.05881099910766352, 0.06358604776323773, 38.89743357896805, 105.7695284485817, 84.25209626555443, 87.47952908277512, 61.272650733590126, 53.39884623885155, 55.524539574980736, 46.689686849713326, 99.61892008781433, 124.32710945606232, 77.32970371842384, 7.233216343447566, 0.02798919605993433, 0.1719550823327154, 0.05550057889195159, 0.11871987211634405, 0.12453475501388311, 0.27667728485539556, 0.16726261615986004, 0.23218579881358892, 0.261029249522835, 1.2935498636215925, 82.54588142037392, 117.6986463367939, 101.86243370175362, 96.49843633174896, 77.71157562732697, 81.00841552019119, 81.58045962452888, 88.98948445916176, 89.05420258641243, 87.89505958557129, 80.39664074778557, 74.71152260899544, 70.18540307879448, 75.23676842451096, 73.92113462090492, 76.19204476475716, 71.61949172616005, 75.307976603508, 71.86073318123817, 69.74429234862328, 69.69056323170662, 70.40032714605331, 69.68340441584587, 67.57640987634659, 68.10771256685257, 69.03049305081367, 64.90803346037865, 66.68936267495155, 72.24103197455406, 69.57408428192139, 65.73047652840614, 68.23530212044716, 70.96090346574783, 77.27114886045456, 88.61517414450645, 83.42338353395462, 79.5420590043068, 82.83521309494972, 82.22428187727928, 85.9057143330574, 87.11934641003609, 84.22546729445457, 77.35858216881752, 76.65213167667389, 78.56180280447006, 85.18298551440239, 73.7180583178997, 72.37476959824562, 78.79716977477074, 86.59415379166603, 92.32524186372757, 87.91094273328781, 82.5041900575161, 78.88339474797249, 70.91870293021202, 74.16766539216042, 75.78063324093819, 73.48730430006981, 75.19542664289474, 75.66098526120186, 79.1566076874733, 82.1893085539341, 79.6837306022644, 81.15650117397308, 80.23954197764397, 71.03791013360023, 63.33835668861866, 64.5652462542057, 68.06387811899185, 77.24267318844795, 79.37060460448265, 81.55529737472534, 80.88231548666954, 79.82106283307076, 74.76135313510895, 70.15787735581398, 61.4727707952261, 62.47065044939518, 65.03959000110626, 63.927724063396454, 63.326056748628616, 67.1528086066246, 63.63101318478584, 65.36163792014122, 66.32948398590088, 64.81474846601486, 70.11157304048538, 78.12079846858978, 75.70540487766266, 78.90993252396584, 77.05590561032295, 79.3866853415966, 83.74952763319016, 86.55626982450485, 86.21883273124695, 96.77567705512047, 15.614860262721777, 0.9574169316329062, 0.19851037301123142, 0.1822266585077159, 0.10226695536402985, 0.22529703564941883, 0.13559300772612914, 0.11068572275689803, 0.24722981499508023, 0.7182018365710974, 0.042712888316600583, 0.6334427534602582, 17.60395187884569, 38.02895978093147, 36.00731246173382, 54.763216227293015, 35.79513564705849, 28.150665946304798, 32.652267292141914, 79.40690785646439, 66.67220279574394, 78.85814890265465, 67.91231945157051, 22.83800572156906, 0.6514288508333266, 0.05686082055035513, 0.07072786102071404, 0.023199272909550928, 0.08876063948264346, 0.09986407414544374, 0.07363028926192783, 0.05176308608497493, 0.058646119869081303, 0.047903947852319106, 0.06428106906241737, 0.08332709432579577, 0.02301466553035425, 0.04447256498679053, 0.014611245751439128, 0.045080268901074305, 0.051994213135913014, 0.07501650979975238, 0.10004613781347871, 0.11414918495574966, 0.1755420453264378, 0.17652148730121553, 0.28566786961164325, 0.13164181349566206, 0.20274077804060653, 0.15313760144636035, 0.09495601407252252, 0.12495197559474036, 0.2116556785767898, 0.12620684341527522, 0.13084170408546925, 0.13356390176340938, 0.2597763855010271, 0.23464582540327683, 54.34662938117981, 121.8710808455944, 97.70304769277573, 97.64287412166595, 73.09131994843483, 55.07391035556793, 84.2450438439846, 86.53065919876099, 117.95466899871826, 131.2296062707901, 92.56345108151436, 11.233933791518211, 0.17623978288611397, 0.5406497733201832, 0.29219752235803753, 0.32437992515042424, 0.5732193100266159, 0.7662202161736786, 0.4043575585819781, 0.8971648116130382, 0.4996813810430467, 1.328735500574112, 81.7004419863224, 123.5311509668827, 103.23811188340187, 101.40575140714645, 80.30584841966629, 81.56884744763374, 86.50355145335197, 91.46812945604324, 91.3050802052021, 92.60841026902199, 83.62709820270538, 77.05347374081612, 72.53035604953766, 77.83741727471352, 80.5395358800888, 81.09478488564491, 73.77179503440857, 78.08131858706474, 74.76163432002068, 75.69537341594696, 73.1805619597435, 74.18799430131912, 73.42365011572838, 72.8678235411644, 72.26565465331078, 72.58734539151192, 66.5745860338211, 72.12258473038673, 76.62239447236061, 74.32911112904549, 69.1459308564663, 72.79152363538742, 76.06806501746178, 80.91991066932678, 94.04366165399551, 84.00175049901009, 82.8271347284317, 87.43653818964958, 88.32398816943169, 88.76398175954819, 91.32653385400772, 88.91745552420616, 81.69699937105179, 83.14705476164818, 84.02150183916092, 89.92915883660316, 78.8566441833973, 77.28852152824402, 84.9235962331295, 91.4974182844162, 85.72576358914375, 81.90871641039848, 79.15667608380318, 82.60382071137428, 77.46191382408142, 79.14068654179573, 79.04138267040253, 76.14745795726776, 76.69405102729797, 79.15896356105804, 85.38864567875862, 86.66742146015167, 83.14129427075386, 83.31065878272057, 83.6767615377903, 73.94782438874245, 67.69188567996025, 68.51246684789658, 72.55267605185509, 80.05316197872162, 80.98980411887169, 84.50434193015099, 81.74578115344048, 82.14014679193497, 77.15480670332909, 74.67012003064156, 63.91118735074997, 64.9398985505104, 67.89028063416481, 66.99074730277061, 66.27838432788849, 69.0310326218605, 67.04068422317505, 67.50232145190239, 69.3284122645855, 67.83104181289673, 75.62627792358398, 86.16188138723373, 81.61256030201912, 83.63676488399506, 81.79740518331528, 84.78006273508072, 88.3234030008316, 91.25464171171188, 90.42850524187088, 100.36105826497078, 13.315782230347395, 1.551373153924942, 0.8944645221345127, 0.3717090276768431, 0.2019965523504652, 0.6560723204165697, 0.3808504465268925, 0.2757639979245141, 0.7033006392885, 0.8292657800484449, 0.5205176223535091, 0.8256825723219663, 26.094510778784752, 47.46937461197376, 52.838627099990845, 104.61967214941978, 72.0519769191742, 31.3675619289279, 41.946880146861076, 95.47043949365616, 79.78104338049889, 92.45153948664665, 83.7794092297554, 31.85014173388481, 1.1180402501486242, 0.17978073272388428, 0.15648326254449785, 0.1186041564506013, 0.2099193647154607, 0.3260579507332295, 0.2011548084556125, 0.18316850328119472, 0.20783335086889565, 0.14703140332130715, 0.1389834500150755, 0.13906541280448437, 0.14359677355969325, 0.09015031842864119, 0.0731601683946792, 0.11902227503014728, 0.0867533526616171, 0.19869981362717226], [0.016698762447049376, 0.06626744216191582, 0.03422721631068271, 0.07689726044191048, 0.09875126081169583, 0.02694188468012726, 0.07958739734021947, 0.020433444369700737, 0.04518870780884754, 0.07030965338344686, 0.06812239575083368, 0.026065948186442256, 0.047642481804359704, 0.06824234907981008, 0.024628222599858418, 1.6048493469133973, 61.3243393599987, 88.38204145431519, 74.87774088978767, 48.61802637577057, 50.18013395369053, 64.88588824868202, 79.18127596378326, 88.55757683515549, 108.66795971989632, 90.93036711215973, 25.13327445834875, 0.3462576965102926, 0.14071345562115312, 0.1643849682295695, 0.18080756824929267, 0.21855244209291413, 0.043892747271456756, 0.17873719887575135, 0.3611519472906366, 0.47414737462531775, 0.7591257593594491, 18.839012905955315, 112.64712139964104, 99.23989042639732, 100.47517374157906, 78.68795603513718, 77.92453899979591, 80.98632350564003, 89.00552719831467, 89.25788685679436, 93.64375591278076, 92.20544189214706, 88.70731920003891, 79.55718219280243, 75.34360349178314, 74.1692765057087, 83.30035373568535, 79.209865629673, 79.79322552680969, 76.08524769544601, 71.74263551831245, 69.60043206810951, 68.20889353752136, 69.43880394101143, 66.67509824037552, 63.89630734920502, 63.663497641682625, 62.95750692486763, 61.74715407192707, 62.20239244401455, 67.51216292381287, 62.739786207675934, 63.85593071579933, 63.51457983255386, 69.13922041654587, 76.35942578315735, 81.46468743681908, 83.82395803928375, 78.24774965643883, 80.1648835837841, 76.9329822063446, 78.19873228669167, 77.63012319803238, 81.01761102676392, 77.3064337670803, 72.84230411052704, 70.42701691389084, 72.65826478600502, 62.030455470085144, 68.80570471286774, 75.70909827947617, 74.1865123808384, 80.5531619489193, 87.70946994423866, 73.87204125523567, 69.38697472214699, 65.94915479421616, 69.5524862408638, 70.35524636507034, 71.17813020944595, 80.21431133151054, 72.43738263845444, 71.16983145475388, 72.02882096171379, 71.26497074961662, 65.8227051794529, 63.01166921854019, 57.67035663127899, 57.848947048187256, 58.35403874516487, 64.74988594651222, 73.02705779671669, 71.85558825731277, 77.57184192538261, 78.48842114210129, 79.11183848977089, 79.34352725744247, 71.76607266068459, 62.2466866672039, 57.92846538126469, 58.551229164004326, 60.01858502626419, 60.81191025674343, 60.7741554826498, 61.65230356156826, 60.11165723204613, 56.752367690205574, 61.07946529984474, 60.022730603814125, 65.92419013381004, 70.14893263578415, 73.36276218295097, 72.62054800987244, 69.48102727532387, 75.66449627280235, 81.27748668193817, 81.78594499826431, 91.23688906431198, 71.16140350699425, 1.0343333543278277, 0.2515440678689629, 0.01936178312462289, 0.03521798716974445, 0.14311139413621277, 0.130265619372949, 0.02521579575841315, 0.5537793750409037, 0.28200059139635414, 0.18723857472650707, 0.17606395325856283, 0.42934935190714896, 25.487305261194706, 26.82472139596939, 85.80459415912628, 79.07032951712608, 34.68736968934536, 27.547581307590008, 31.055372580885887, 56.323925480246544, 54.27017368376255, 62.29467049241066, 52.53792643547058, 24.7639399766922, 1.5020928857848048, 0.12338514599832706, 0.06258651585085317, 0.06784614612115547, 0.04015480917587411, 0.048752634538686834, 0.05446430324809626, 0.06884678383357823, 0.05939425667747855, 0.05239570018602535, 0.032041346494224854, 0.06286606803769246, 0.030241204221965745, 0.02541148896852974, 0.06698123979731463, 0.004250055708325817, 0.05227342764555942, 0.058718293730635196, 0.03260684075939935, 0.042249476464348845, 0.1210570361581631, 0.030801533139310777, 0.0074264681734348414, 0.05134996215929277, 0.04645001747121569, 0.03822919570666272, 0.008962077936303103, 0.032298359656124376, 0.02112465659592999, 0.1775599893881008, 0.021983321457810234, 0.2166526034125127, 1.6331119928508997, 72.29797571897507, 104.19920951128006, 82.71598309278488, 65.62241032719612, 60.54757744073868, 61.0586766153574, 55.79902924597263, 74.09606963396072, 124.94385436177254, 99.66740548610687, 34.22264322638512, 0.4144476499641314, 0.06356926780426875, 0.1274694295716472, 0.10442251586937346, 0.2837828441988677, 0.15795281884493306, 0.2470702087157406, 0.687022372148931, 0.2608912397408858, 0.9482164378277957, 23.807191215455532, 117.30765491724014, 101.71447724103928, 102.71953091025352, 80.67786365747452, 84.5908784866333, 86.37104496359825, 95.80112814903259, 93.9961414039135, 98.54535609483719, 95.43489620089531, 93.5221092402935, 83.1174011528492, 79.54945340752602, 78.95492970943451, 85.75748428702354, 83.3953258395195, 83.9249262213707, 78.74461099505424, 77.44299083948135, 74.34288159012794, 72.29049772024155, 72.68453657627106, 69.13032129406929, 66.69795781373978, 66.3939893245697, 64.95269626379013, 64.31877627968788, 64.729975014925, 67.63649985194206, 64.7376050055027, 67.35941112041473, 68.87973234057426, 73.93884927034378, 80.72195649147034, 85.65075561404228, 86.57552719116211, 82.93309584259987, 85.24449661374092, 83.02171468734741, 82.09524840116501, 81.33268252015114, 84.90525841712952, 82.1827045083046, 74.25405755639076, 73.45388129353523, 74.55246314406395, 65.50846204161644, 71.82775095105171, 81.12801790237427, 77.32429280877113, 85.38958042860031, 88.85985061526299, 82.67107710242271, 74.29204031825066, 69.52652603387833, 74.01691228151321, 71.95655643939972, 74.96631413698196, 83.29111263155937, 73.75420197844505, 75.04236325621605, 75.24305328726768, 73.97726520895958, 70.40285781025887, 66.83371692895889, 62.47866041958332, 60.14200620353222, 61.45530313253403, 64.54079076647758, 74.53734755516052, 74.96563777327538, 81.10030978918076, 81.48284286260605, 81.49750247597694, 81.60383597016335, 76.45468667149544, 66.31772741675377, 62.98334553837776, 60.78284941613674, 63.72576870024204, 63.24794054031372, 65.50809726119041, 66.93425953388214, 64.72087070345879, 61.32804036140442, 63.978489339351654, 61.73212967813015, 67.92835459113121, 73.72223049402237, 74.66245204210281, 75.52368342876434, 74.46490064263344, 80.303545743227, 83.23009550571442, 86.40383720397949, 91.36479780077934, 81.8345519900322, 2.6985097490251064, 0.5140940076671541, 0.008965156921476591, 0.2200360398273915, 0.066778032341972, 0.11796720820711926, 0.029709787522733677, 0.6378600758034736, 0.5496975034475327, 0.42762605531606823, 0.13573912176070735, 0.19184259173925966, 28.995746299624443, 36.081784665584564, 72.74303823709488, 60.61497442424297, 30.147523395717144, 35.16307756304741, 46.218873113393784, 69.3438470363617, 66.94883555173874, 75.74502155184746, 68.06217581033707, 28.86256154626608, 1.1098032421432436, 0.0882258330238983, 0.04677269214880653, 0.016355096122424584, 0.13414323708275333, 0.0266801217730972, 0.12767775042448193, 0.03385419062396977, 0.0323823670623824, 0.016641902802803088, 0.04224832613545004, 0.017694143898552284, 0.07524407454184256, 0.06857906890218146, 0.05596798349870369, 0.04951951799739618, 0.046021430898690596, 0.17664833518210799, 0.08742191639612429, 0.10471023168065585, 0.15552025171928108, 0.2038774365792051, 0.07013918206212111, 0.18047486344585195, 0.19945943146012723, 0.13461904280120507, 0.1747326145414263, 0.21458245668327436, 0.04888747163931839, 0.43701834976673126, 0.20428496471140534, 0.3061460395110771, 3.3365479996427894, 90.38760423660278, 115.85485607385635, 98.25667798519135, 71.14304289221764, 70.50359040498734, 79.64313358068466, 99.78081420063972, 118.23218330740929, 128.67786079645157, 110.38209334015846, 43.43057133257389, 0.6837435043416917, 0.27858534653205425, 0.4773086862405762, 0.2751666581025347, 0.6500450125895441, 0.5593790276907384, 0.5873334151692688, 0.762866361765191, 1.0594368260353804, 1.4608101197518408, 21.97594977915287, 121.32424458861351, 106.79587617516518, 108.23064118623734, 85.69652795791626, 85.65272390842438, 87.78560265898705, 98.61077338457108, 96.69724926352501, 102.13945403695107, 98.363566249609, 95.90379863977432, 84.77874040603638, 82.2542242705822, 82.81137317419052, 91.76091134548187, 86.47314548492432, 86.27355739474297, 83.49537447094917, 79.27036598324776, 76.79716989398003, 76.41947016119957, 77.25175470113754, 73.06678846478462, 68.44810590147972, 69.82068344950676, 69.0416644513607, 69.58191186189651, 69.21632587909698, 73.1313394010067, 68.23996067047119, 69.67646598815918, 72.69650593400002, 76.83508425951004, 85.78448563814163, 88.56978178024292, 89.75199714303017, 86.33025035262108, 88.87514859437943, 85.73131129145622, 84.55295652151108, 85.6220443546772, 88.46431463956833, 87.3768661916256, 79.80267181992531, 78.05354967713356, 79.4778424501419, 69.71358999609947, 76.50191053748131, 86.73626616597176, 81.47398173809052, 75.69408148527145, 80.14789089560509, 73.10617715120316, 80.65216943621635, 73.44500496983528, 79.07428130507469, 73.53270426392555, 77.75514408946037, 87.23653972148895, 78.86246547102928, 79.75908055901527, 80.0448252260685, 79.9896065890789, 73.99564862251282, 70.19503176212311, 65.90294927358627, 61.0590185970068, 64.58370566368103, 70.20927339792252, 80.46289399266243, 77.9593451321125, 84.14371088147163, 84.06428754329681, 87.14609697461128, 87.12924107909203, 79.1760702431202, 68.1984668970108, 65.39058476686478, 64.76989567279816, 67.47696921229362, 65.53219556808472, 68.30752864480019, 69.54374670982361, 66.66629031300545, 63.46276581287384, 70.18519029021263, 65.73720216751099, 72.89575964212418, 77.44861453771591, 79.67372953891754, 80.17312914133072, 76.91076099872589, 85.23963287472725, 88.07980567216873, 90.670255869627, 97.54132837057114, 79.39437612891197, 2.1684935269877315, 0.7266217691358179, 0.1776369649451226, 0.4342996550258249, 0.22193329583387822, 0.25097397970966995, 0.18974127480760217, 1.8996984441764653, 1.5768395061604679, 0.32680947915650904, 0.25636606849730015, 0.9494492341764271, 42.61599384248257, 44.03638422489166, 109.7167718410492, 102.76451289653778, 48.90697807073593, 40.51247611641884, 52.97688648104668, 82.58083954453468, 77.90012910962105, 90.67344009876251, 83.37134912610054, 36.70791506767273, 2.526089013554156, 0.39606055535841733, 0.2192096583894454, 0.19658653327496722, 0.2503990527475253, 0.15707622369518504, 0.24413970502791926, 0.0936453441681806, 0.14348067197715864, 0.09722019531182013, 0.11801647196989506, 0.13811166398227215, 0.1335409248713404, 0.20086468808585778, 0.20600591611582786, 0.10734747571405023, 0.13537189224734902], [0.005876636078028241, 0.0636307176318951, 0.027574413434194867, 0.05960352747933939, 0.12868043646449223, 0.06016335915774107, 0.026858671371883247, 0.0393207242450444, 0.1023545436328277, 0.047285608961828984, 0.06916949190781452, 0.0534816366416635, 0.06273679333389737, 0.12355939485132694, 0.4205156571697444, 12.898974046111107, 84.94394034147263, 77.96651914715767, 58.11980031430721, 43.27575623989105, 52.80023396015167, 57.86723546683788, 92.30939671397209, 90.42232677340508, 98.5706627368927, 65.10370776057243, 5.969954179599881, 0.2318726570229046, 0.06043140805559233, 0.1652169751469046, 0.12279585847863927, 0.10446394255268387, 0.23459052055841312, 0.19169546838384122, 0.07366111065493897, 0.23916152684250847, 2.106612422503531, 62.789103761315346, 110.60907796025276, 98.24431344866753, 89.24176052212715, 83.11922505497932, 88.77250850200653, 89.82386648654938, 92.18827441334724, 93.9848256111145, 97.92902156710625, 92.2907093167305, 91.12787291407585, 88.05637612938881, 82.27501675486565, 86.1537954211235, 91.06500908732414, 84.8697379231453, 87.21297338604927, 82.21327006816864, 74.38892751932144, 71.59276396036148, 67.77679592370987, 63.68481069803238, 63.86048287153244, 61.81293234229088, 59.132582768797874, 61.33227713406086, 60.028468295931816, 60.32468520104885, 61.34450487792492, 63.032381907105446, 61.82766415178776, 64.07110556960106, 68.74283328652382, 78.83216589689255, 82.47575238347054, 78.84364128112793, 79.82595697045326, 79.35381710529327, 76.23350813984871, 81.39097899198532, 79.05468955636024, 79.35680374503136, 79.40720424056053, 76.0511103272438, 69.36445713043213, 65.13929665088654, 61.30747586488724, 74.57979887723923, 75.9331950545311, 64.89424780011177, 73.21362018585205, 79.4150622189045, 61.96992091834545, 68.25884565711021, 67.97239422798157, 70.52594840526581, 67.63349041342735, 74.7981883585453, 69.07298237085342, 72.85351350903511, 69.36675980687141, 63.86783927679062, 60.34906469285488, 56.007132679224014, 53.769489750266075, 57.208157032728195, 57.15833030641079, 57.95027621090412, 56.61344334483147, 62.89816550910473, 69.80672299861908, 75.04246205091476, 72.75740146636963, 74.94494408369064, 76.81648045778275, 74.21073988080025, 62.41401448845863, 58.02528418600559, 57.2174247354269, 58.61925691366196, 59.80255141854286, 61.069141253829, 61.434541046619415, 55.62102019786835, 58.44707295298576, 58.79493288695812, 59.17387135326862, 57.96091563999653, 62.685996294021606, 65.42427375912666, 67.1890814602375, 65.86449533700943, 71.97979599237442, 71.30091682076454, 83.83756890892982, 78.6740031838417, 96.51134803891182, 36.051352098584175, 0.3807223221519962, 0.3812764986651018, 0.22667379380436614, 0.08293595281429589, 0.0935721312998794, 0.1875976999872364, 0.3150550473947078, 0.2869590581394732, 0.05980127272778191, 0.2006419695680961, 0.30351711495313793, 5.610067415982485, 27.704176604747772, 50.08336454629898, 101.59005671739578, 70.86465463042259, 24.722689390182495, 20.61649862676859, 31.9889634847641, 54.61294949054718, 62.07213543355465, 65.54765313863754, 57.504677921533585, 28.83028607815504, 1.7547315917909145, 0.02954304734885227, 0.08274374398752116, 0.038480620496557094, 0.05635453482682351, 0.1341195625718683, 0.06991055604885332, 0.07722764232312329, 0.03041133972146781, 0.09045550439623185, 0.00913631658477243, 0.04253150000295136, 0.045950199564686045, 0.03015215763298329, 0.0035047135497734416, 0.028274509168113582, 0.06252842053072527, 0.050185680884169415, 0.024231114221038297, 0.05482874228619039, 0.10934747464489192, 0.02013196728512412, 0.03243184975872282, 0.10426579654449597, 0.03758876679057721, 0.0754424135084264, 0.03534856063197367, 0.04255737869243603, 0.1345182443037629, 0.12650812568608671, 0.4940336965955794, 17.185681723058224, 98.60989183187485, 86.87711700797081, 73.25866296887398, 50.96565060317516, 52.22636215388775, 61.22942805290222, 77.24238440394402, 97.45761886239052, 108.78858804702759, 77.25161790847778, 7.215178711339831, 0.46384502900764346, 0.7099352614022791, 0.4396453150548041, 0.042738332849694416, 0.37029096158221364, 0.34320361039135605, 0.45838424703106284, 0.21316566708264872, 0.32510806107893586, 3.861925145611167, 69.22786965966225, 114.37806531786919, 103.161561191082, 94.22555789351463, 89.31112959980965, 94.75651860237122, 92.38104566931725, 97.16404661536217, 98.09704095125198, 100.81495150923729, 93.4943175315857, 94.85498651862144, 90.21090611815453, 87.16773301362991, 88.364387601614, 96.04250639677048, 90.81014156341553, 90.73052823543549, 86.54312252998352, 80.01279294490814, 75.70865750312805, 71.78121864795685, 68.2600311934948, 66.16157099604607, 64.36714008450508, 63.52968022227287, 62.14863672852516, 62.943474277853966, 63.93134146928787, 63.681865856051445, 65.22289976477623, 63.626195043325424, 67.10206612944603, 72.53988593816757, 80.79360544681549, 85.17568990588188, 83.3148917555809, 82.08843156695366, 83.16781684756279, 81.32048517465591, 82.387315928936, 82.65572592616081, 82.70961463451385, 84.46038588881493, 79.88962635397911, 72.94154718518257, 67.92350605130196, 66.09580412507057, 80.5912435054779, 78.58997449278831, 68.34155201911926, 79.34503197669983, 84.70427960157394, 71.8896572291851, 71.86991348862648, 72.62028962373734, 73.918117582798, 69.5492260158062, 77.76333644986153, 71.72733753919601, 73.97895991802216, 71.44300639629364, 66.2705035507679, 64.9067947268486, 60.715391635894775, 57.703460454940796, 60.13045482337475, 59.45736654102802, 59.72877077758312, 58.32753896713257, 65.54405093193054, 73.81629824638367, 74.87559780478477, 76.49294301867485, 76.79642513394356, 79.18046280741692, 76.79147779941559, 67.17721849679947, 62.18272849917412, 61.989501267671585, 61.04765720665455, 63.184480145573616, 62.899423241615295, 63.95619213581085, 58.778985142707825, 61.76022917032242, 62.96388678252697, 61.99009783565998, 61.47538885474205, 64.7662478685379, 66.39050871133804, 69.84535172581673, 68.97230297327042, 75.95402553677559, 74.86394003033638, 86.9669821858406, 82.2102302312851, 100.11577382683754, 46.89565099775791, 0.06265681207878515, 0.3359163139248267, 0.39821619750000536, 0.2730707440059632, 0.45879450626671314, 0.3132983244722709, 0.3947135276393965, 0.8512286609038711, 1.7115668579936028, 0.8100647572427988, 0.5971379578113556, 5.389397582039237, 36.84492811560631, 56.75972789525986, 85.73032334446907, 53.50655905902386, 33.06775599718094, 32.474512830376625, 49.54764649271965, 66.60713508725166, 73.80635038018227, 74.40128445625305, 69.58003476262093, 33.05262140929699, 1.6096728318370879, 0.03959157103963662, 0.047137654401012696, 0.09879378587356769, 0.027970557021035347, 0.04196449175651651, 0.018518219112593215, 0.048814329275046475, 0.029413126976578496, 0.04417654454300646, 0.037164777822908945, 0.08458881216938607, 0.02310854906681925, 0.04618665152520407, 0.020632829764508642, 0.011958290451730136, 0.12693416298134252, 0.2458926133112982, 0.07741035908111371, 0.19068537571001798, 0.23887830844614655, 0.18168103153584525, 0.1583204639609903, 0.233167200058233, 0.22801608662120998, 0.18691688339458779, 0.2165419195080176, 0.2948908059624955, 0.2000288071576506, 0.3014239319600165, 0.6090871291235089, 23.598842695355415, 113.21282744407654, 98.72735112905502, 85.6351612508297, 59.74713519215584, 70.65344676375389, 74.23128917813301, 120.39636477828026, 113.61740693449974, 114.33543920516968, 98.33248391747475, 11.11600711941719, 0.35444937413558364, 0.4941202903864905, 0.6229626783169806, 0.38114018097985536, 0.7134522695560008, 0.7056498632300645, 0.9213007008656859, 1.2240169197320938, 1.707535630557686, 3.6972270207479596, 66.98994934558868, 120.7794526219368, 105.18729329109192, 100.20780488848686, 91.19409576058388, 96.61925464868546, 94.67809081077576, 100.62812313437462, 100.36504805088043, 105.4019133746624, 96.55561566352844, 98.17996770143509, 97.43201583623886, 90.47126814723015, 91.90406486392021, 102.32409372925758, 92.05550193786621, 94.49051007628441, 91.7537373304367, 82.27633148431778, 80.30548363924026, 76.8031507730484, 69.88274931907654, 71.86888754367828, 68.82112428545952, 66.87991484999657, 68.33228811621666, 68.6269699037075, 66.79099202156067, 68.2750403881073, 68.91793549060822, 69.08961027860641, 70.3028091788292, 76.1808429658413, 84.51574891805649, 90.1102115213871, 84.55986455082893, 83.65954846143723, 89.05858755111694, 82.94429004192352, 87.0663620531559, 85.73968604207039, 86.40914171934128, 87.91296422481537, 85.92788234353065, 77.63915911316872, 73.08407753705978, 68.23447376489639, 84.40481007099152, 85.54133668541908, 75.69115564227104, 74.043830037117, 81.59126624464989, 66.45309895277023, 77.73307487368584, 78.72623518109322, 77.9443359375, 70.93467727303505, 81.96437582373619, 76.31809920072556, 78.49817141890526, 75.75674772262573, 72.3955012857914, 68.82398173213005, 63.19657489657402, 58.20839636027813, 61.82449512183666, 62.10116967558861, 63.320653438568115, 61.31396971642971, 70.47074496746063, 77.16530174016953, 79.65893313288689, 80.28088375926018, 78.9878511428833, 84.2268580198288, 81.44851550459862, 70.5462697148323, 64.92948710918427, 62.37053722143173, 65.5184555053711, 65.6625209748745, 65.52084937691689, 69.4456435739994, 63.014458268880844, 64.8770347237587, 65.1992954313755, 66.27879470586777, 65.8214208483696, 68.48575428128242, 70.93025431036949, 74.44458693265915, 73.63358125090599, 81.15603759884834, 78.99146094918251, 93.25132817029953, 86.84215888381004, 105.78340530395508, 43.927763253450394, 0.36559545260388404, 1.2125804834067822, 0.34980376716703176, 0.3742011002032086, 0.27352645236533135, 0.6359981757123023, 1.2433578819036484, 3.035674919374287, 1.0820681741461158, 0.755776654696092, 0.7960968255065382, 9.377373363822699, 48.67812395095825, 66.54689311981201, 117.82891094684601, 92.23995164036751, 38.04494172334671, 31.458694338798523, 57.219689413905144, 77.63943269848824, 84.70225051045418, 84.94061172008514, 83.2225339114666, 42.83843010663986, 2.8991584572941065, 0.18358750501647592, 0.16027333651436493, 0.23816364991944283, 0.14850280014798045, 0.26532717514783144, 0.1680556157953106, 0.1987094318610616, 0.11988555605057627, 0.18159054889110848, 0.1531205914216116, 0.18000790412770584, 0.16638732719002292, 0.14084269321756437, 0.1316358317853883, 0.11714308289811015], [0.06955364980967715, 0.05956785615126137, 0.09019515899126418, 0.03923477612261195, 0.05823760096973274, 0.025483506979071535, 0.007375207569566555, 0.0716618167643901, 0.028935994669154752, 0.056065305034280755, 0.0500524282688275, 0.12057032086886466, 0.04292268233257346, 0.052593935251934454, 0.11448725548689254, 35.89944384992123, 86.50078520178795, 76.08682841062546, 52.706390395760536, 35.883750692009926, 72.50216916203499, 81.6545632481575, 65.79769492149353, 96.23292177915573, 87.07456201314926, 27.786780372262, 0.5998221575282514, 0.010272535400872584, 0.5281407258007675, 0.21224717027507722, 0.47451779537368566, 0.18382114794803783, 0.26799807557836175, 0.24513428681530058, 0.48682533495593816, 0.09247099194908515, 16.09048169106245, 88.069918602705, 107.30281457304955, 94.03272584080696, 87.18952104449272, 94.50248703360558, 95.02707168459892, 95.2096138894558, 94.91785034537315, 95.85170343518257, 93.95289972424507, 91.72688037157059, 89.40261349081993, 89.64204624295235, 87.89996892213821, 89.07747253775597, 93.68149548768997, 88.8854156434536, 89.63424906134605, 87.54688426852226, 79.65235948562622, 72.26648300886154, 62.25000388920307, 66.3071259856224, 63.15344721078873, 56.64166443049908, 58.55890475213528, 61.77543595433235, 63.965858817100525, 67.30881303548813, 66.20115727186203, 63.06222930550575, 58.66168163716793, 57.76165433228016, 64.38557669520378, 74.62859585881233, 81.65761068463326, 77.00245767831802, 75.9574681520462, 77.86497339606285, 71.76782816648483, 75.59092462062836, 75.61407297849655, 80.36340773105621, 79.99673500657082, 78.49885538220406, 70.26566997170448, 61.357184797525406, 62.55491852760315, 74.7773502767086, 77.29301288723946, 51.54749438166618, 39.985132813453674, 45.688189789652824, 47.61000506579876, 66.93579465150833, 63.69011141359806, 68.54070693254471, 69.10362392663956, 70.85753381252289, 68.75397428870201, 73.27235743403435, 69.39379915595055, 66.68467372655869, 56.56846135854721, 55.41368432343006, 51.774258613586426, 56.46425575017929, 52.55537889897823, 55.49324445426464, 55.245254561305046, 57.47911289334297, 60.813053995370865, 73.29992115497589, 72.42463812232018, 77.56216004490852, 72.22832545638084, 69.87908631563187, 63.3101812005043, 57.36283153295517, 57.228026166558266, 59.38035607337952, 61.9422622025013, 58.55453498661518, 57.53681279718876, 61.03865168988705, 60.683534145355225, 63.20474445819855, 60.01183658838272, 63.80843326449394, 60.6433816999197, 58.795947432518005, 58.62671211361885, 68.56721431016922, 68.48563268780708, 75.89291721582413, 73.58885765075684, 82.82916381955147, 77.25639045238495, 88.78055647015572, 4.565743803977966, 0.5748563690576702, 0.17612146970350295, 0.3544969012727961, 0.148727715422865, 0.3054355666972697, 0.050103146641049534, 0.2054789467365481, 0.6474502861965448, 0.27432200498878956, 0.04043130742502399, 0.1815204307786189, 16.16643201559782, 40.56315019726753, 86.82567536830902, 87.35807240009308, 45.243568047881126, 20.214643590152264, 21.79442971944809, 33.54101300239563, 50.58617256581783, 55.6915520131588, 55.661313235759735, 51.725473031401634, 28.56065634638071, 0.8273084100801498, 0.0811392800824251, 0.09827618981944397, 0.10234891073196195, 0.015560114952677395, 0.03699282962770667, 0.03906119891325943, 0.05455382852233015, 0.06763759520254098, 0.03583721292670816, 0.10270863713230938, 0.0862054324534256, 0.032075270064524375, 0.06713275666697882, 0.036181328250677325, 0.06157999661809299, 0.018594879256852437, 0.020418222920852713, 0.024951088380475994, 0.03573795438569505, 0.04727184583316557, 0.06268110999371856, 0.10891801604884677, 0.04812863677216228, 0.02724724319705274, 0.07382761148619466, 0.017462415707996115, 0.04560990259051323, 0.07152696111006662, 0.16215668467339128, 44.82107251882553, 102.50654473900795, 86.12050160765648, 64.52420085668564, 42.07881286740303, 83.6127881705761, 62.35702894628048, 71.89902752637863, 111.12150326371193, 100.04749909043312, 35.88838264346123, 0.4324589209863916, 0.2104940393473953, 2.8525444585829973, 0.7441895920783281, 0.4748363251565024, 0.318410029867664, 0.3263801318826154, 0.45219719933811575, 0.632033325964585, 0.1035334897460416, 18.788950592279434, 94.75436791777611, 110.40864631533623, 98.35052534937859, 90.85048779845238, 100.5954296886921, 101.21140703558922, 101.46938279271126, 97.05700635910034, 101.29576250910759, 95.85135385394096, 96.34902834892273, 93.23762610554695, 94.60871413350105, 92.69993215799332, 93.34097295999527, 94.80141699314117, 91.04715764522552, 93.85050281882286, 89.7541706264019, 83.10680732131004, 75.31051486730576, 66.51467844843864, 66.82139039039612, 64.90012228488922, 60.63432678580284, 60.87742254137993, 66.02565228939056, 66.18344262242317, 70.77293515205383, 69.6545259654522, 66.81412518024445, 62.46814638376236, 60.61618655920029, 68.25870126485825, 78.41632381081581, 84.76310804486275, 80.11920243501663, 80.24388134479523, 82.18884497880936, 75.52556052803993, 80.37800654768944, 80.62286540865898, 84.51418340206146, 82.56560996174812, 82.02696606516838, 74.11832123994827, 66.63162097334862, 66.99220642447472, 80.25075897574425, 79.32346433401108, 59.65154372155666, 50.87851367890835, 56.85447961091995, 56.888689175248146, 71.47227242588997, 68.1304581463337, 70.82192212343216, 73.32218796014786, 74.59337174892426, 74.73850876092911, 76.31220951676369, 73.71276900172234, 69.61254581809044, 61.96581333875656, 56.46026596426964, 54.853788167238235, 59.64725375175476, 56.341111958026886, 58.80818657577038, 59.169645980000496, 61.43850423395634, 63.6519880592823, 76.10867723822594, 77.11933180689812, 78.82594183087349, 75.16705736517906, 74.39886778593063, 67.6199023425579, 60.50089694559574, 59.77870389819145, 63.438724502921104, 63.03072139620781, 59.856037348508835, 60.37793554365635, 66.71408414840698, 64.86543774604797, 66.16543918848038, 63.81226345896721, 66.00110560655594, 62.51309797167778, 62.86698438227177, 61.78170181810856, 73.00929754972458, 71.00370436906815, 79.46727141737938, 76.46764397621155, 87.68766671419144, 80.9848415851593, 96.4454747736454, 9.445478059351444, 0.7686960801947862, 0.7278162706643343, 1.494390342850238, 0.8122448902577162, 1.1983042932115495, 0.31522250559646636, 0.7124970364384353, 0.3808750561438501, 0.5981281609274447, 0.16158140148036182, 0.21364699437981471, 17.802470326423645, 50.73560334742069, 86.69089660048485, 75.06659835577011, 39.29776109755039, 28.458992801606655, 30.97291700541973, 44.563195556402206, 59.99385975301266, 66.39642879366875, 65.985898822546, 63.104722425341606, 33.205882385373116, 0.8382084220647812, 0.013196682593843434, 0.062047705505392514, 0.08679502425366081, 0.05439156535430811, 0.021240259084152058, 0.028342378573142923, 0.06899231899296865, 0.07237496873131022, 0.009218053946824512, 0.04998409131076187, 0.07708261924562976, 0.01882975600892678, 0.01298222510740743, 0.0618139289872488, 0.19476184446830302, 0.11541907384525985, 0.11745198702556081, 0.17005150322802365, 0.13197496358770877, 0.1300628943135962, 0.1178339852776844, 0.14982554479502141, 0.11099749899585731, 0.22209938848391175, 0.15040505822980776, 0.198106600146275, 0.07969501617481001, 0.22653373569482937, 0.17798997490899637, 58.70320960879326, 114.9515001475811, 97.55207419395447, 81.80370524525642, 56.62514291703701, 85.08492037653923, 94.61974114179611, 88.13782095909119, 116.00339770317078, 112.74564251303673, 47.555633783340454, 1.1535156215541065, 0.1785252711852081, 1.9687010790221393, 0.8537986292503774, 0.7391153206117451, 0.6565279397182167, 0.9244741243310273, 2.222305526956916, 2.049107258208096, 0.35447677422780544, 18.31375189125538, 97.82099336385727, 115.82094669342041, 103.6157888174057, 94.31490629911423, 102.30814218521118, 102.99355700612068, 101.48023501038551, 99.0133085846901, 102.14481174945831, 98.96167695522308, 99.7697339951992, 95.60580343008041, 95.94069465994835, 96.83911845088005, 96.70768350362778, 100.62011316418648, 94.99985754489899, 98.29491913318634, 93.30040633678436, 86.86151504516602, 80.19166454672813, 69.88969534635544, 71.08261853456497, 68.8854244351387, 61.3578649610281, 63.985572159290314, 69.61737155914307, 70.66944390535355, 74.06557247042656, 72.61123090982437, 68.99539813399315, 64.95556890964508, 64.52076584100723, 70.31638965010643, 83.85826259851456, 87.88037717342377, 83.92940998077393, 82.0846925675869, 84.01499658823013, 79.89531844854355, 82.59657829999924, 84.4495640695095, 88.17637369036674, 88.09742912650108, 88.20971310138702, 77.78794392943382, 69.8291265964508, 69.28985953330994, 84.91060853004456, 87.2740513086319, 63.850489407777786, 51.88140146434307, 59.928678050637245, 55.66509783267975, 77.9979282617569, 72.723758071661, 74.50884908437729, 76.40201389789581, 80.65027713775635, 77.94079452753067, 81.48396000266075, 78.54484811425209, 74.0145792067051, 63.275496661663055, 60.16513556241989, 55.51931485533714, 62.221820801496506, 57.04175256192684, 60.56357458233833, 61.340993866324425, 65.279471129179, 67.1479144692421, 77.46385172009468, 79.98415008187294, 82.91072264313698, 79.0279845893383, 79.36387896537781, 70.7087641954422, 64.56019252538681, 62.87174552679062, 65.8492885529995, 67.40711376070976, 62.457791939377785, 64.65820446610451, 68.39475676417351, 67.08350032567978, 69.88259732723236, 66.59872233867645, 68.68936255574226, 65.62023684382439, 66.33589044213295, 66.0119578242302, 75.19794970750809, 75.56153699755669, 84.47569906711578, 81.7217056453228, 92.33423218131065, 84.80754286050797, 99.81799140572548, 7.584071941673756, 1.2430506921373308, 2.111538383178413, 0.9823039930779487, 0.4579253029078245, 1.1787125444971025, 0.7819580810610205, 2.387288874015212, 3.853592430241406, 0.29467540502082556, 0.1907853875309229, 0.37155148456804454, 27.778567112982273, 58.05486939847469, 103.29872623085976, 105.13652801513672, 62.41080366075039, 30.72866801172495, 32.58912608027458, 51.09380632638931, 75.11797919869423, 79.39865469932556, 74.42706227302551, 74.96796324849129, 41.93162776529789, 1.3460169732570648, 0.1582125705317594, 0.2202155059785582, 0.18150012561818585, 0.19103393278783187, 0.17791475082049146, 0.10745830062660389, 0.20679664477938786, 0.14303419593488798, 0.111173914920073, 0.18789503403240815, 0.15701146388892084, 0.09004205392557196, 0.15170411352301016, 0.14322731760330498], [0.004944084848830244, 0.06159124015539419, 0.04125254949030932, 0.055222136215888895, 0.03326058009406552, 0.09953623040928505, 0.06695887888781726, 0.02750020237726858, 0.0822375770076178, 0.09954835710232146, 0.09570958340191282, 0.04763144977914635, 0.03383002258487977, 0.43653651780914515, 4.8049423936754465, 76.95025607943535, 71.83937832713127, 67.08666175603867, 49.224580228328705, 34.82878290116787, 33.63495536148548, 75.64726039767265, 100.87441831827164, 92.93122574687004, 60.50633445382118, 6.508936733007431, 0.28868208755739033, 0.13304132589837536, 4.158466458320618, 0.39162203727755696, 0.16468446934595704, 0.17185717821121216, 0.4848547844449058, 0.9512285480741411, 0.14302931260317564, 0.9010127582587302, 37.06196866929531, 101.1467345058918, 99.09832522273064, 93.55926364660263, 95.59442684054375, 98.37929740548134, 100.05796372890472, 98.86203870177269, 96.59117415547371, 93.36521565914154, 96.33418634533882, 92.36989706754684, 92.11168572306633, 89.62054699659348, 90.16516417264938, 90.69390580058098, 91.60642683506012, 87.37404674291611, 87.6534229516983, 86.61734014749527, 73.58431309461594, 64.58385765552521, 63.006733283400536, 61.08253173530102, 60.72880491614342, 57.61749766767025, 63.58068868517876, 68.76851990818977, 71.96239292621613, 75.44667676091194, 73.368621468544, 68.16388875246048, 62.48832330107689, 56.486142575740814, 58.08271050453186, 68.3342108130455, 75.015399903059, 78.27146798372269, 74.42004784941673, 75.87713286280632, 75.15518680214882, 70.46474128961563, 72.74774998426437, 73.18391337990761, 78.99044260382652, 72.98476606607437, 74.18018952012062, 63.57443802058697, 67.54107937216759, 70.2089162170887, 78.17511275410652, 51.39029301702976, 20.401893742382526, 23.051379472017288, 34.17494438588619, 65.96104815602303, 58.2207190990448, 71.58157736063004, 70.20838424563408, 68.66519585251808, 66.51505082845688, 71.2967598438263, 71.36606812477112, 68.08172956109047, 66.55206084251404, 59.72149036824703, 57.886435836553574, 57.31507949531078, 59.68132272362709, 60.48509359359741, 61.014048010110855, 59.21937011182308, 57.72774115204811, 67.1983377635479, 74.36276212334633, 77.16165393590927, 75.06633996963501, 67.15360656380653, 60.7040074467659, 54.30472902953625, 56.45374171435833, 59.72725085914135, 58.06560382246971, 57.41434916853905, 59.22674171626568, 66.83207541704178, 69.19322311878204, 65.64132571220398, 62.20121830701828, 63.01749050617218, 59.953255131840706, 58.858074098825455, 61.978713646531105, 65.65067321062088, 71.14102900028229, 74.04269009828568, 73.14725294709206, 79.18637529015541, 75.80966368317604, 91.59473106265068, 49.92240518331528, 0.379743340308778, 0.7963332440704107, 1.897297566756606, 0.30552091368008405, 0.27223407640121877, 0.2978837984846905, 1.0569879761897027, 1.7987096006982028, 1.1161982989870012, 0.23570749734062701, 0.13932517933426425, 3.0168711533769965, 44.92441177368164, 60.00253468751907, 82.406345307827, 78.645960688591, 46.34187251329422, 22.347243055701256, 26.223743744194508, 44.54573929309845, 60.039958879351616, 62.24441818892956, 56.459456607699394, 61.99837379157543, 28.505215421319008, 0.4738413722952828, 0.11129204998724163, 0.06838393601356074, 0.05604899633908644, 0.030528452480211854, 0.08779011070146225, 0.09808287519263104, 0.014672137112938799, 0.054803123348392546, 0.0542717901407741, 0.09807561698835343, 0.025403052604815457, 0.05627615289995447, 0.042249361431458965, 0.04903331107925624, 0.049922645193873905, 0.10092515978612937, 0.034228808217449114, 0.0323452522570733, 0.048447749140905216, 0.06813223662902601, 0.0369998392125126, 0.03609716128266882, 0.18111827579559758, 0.10730991562013514, 0.0977062426682096, 0.08290209603728727, 0.40552670834586024, 5.886149676516652, 89.29353654384613, 84.04920995235443, 77.17714190483093, 61.621669605374336, 43.230439871549606, 41.10579527914524, 74.37595501542091, 99.51646238565445, 105.76758295297623, 68.70304942131042, 8.994793742895126, 0.5445253872312605, 0.3784554172307253, 4.562909156084061, 0.8967804978601635, 0.12226251405081712, 0.048669847965356894, 0.5917932477314025, 0.3358279983513057, 0.26343321427702904, 1.0437066201120615, 41.03822350502014, 103.92845883965492, 103.69348704814911, 96.38525560498238, 100.13862580060959, 101.72336116433144, 102.52868235111237, 101.90445944666862, 99.35089007019997, 96.12110897898674, 97.96600878238678, 94.68102425336838, 95.51827892661095, 93.5244271159172, 93.7791958451271, 94.46135804057121, 95.15887141227722, 90.86001008749008, 90.52074149250984, 91.00180327892303, 78.30370545387268, 65.84107339382172, 66.34029060602188, 64.56311836838722, 64.11605715751648, 61.16822473704815, 67.6684257388115, 73.7812489271164, 77.12313160300255, 77.45166957378387, 76.99026793241501, 73.60097900032997, 66.97044879198074, 59.02002140879631, 62.63181500136852, 72.0590977370739, 76.07704773545265, 79.91020604968071, 78.03870767354965, 78.58673706650734, 79.60026428103447, 75.40358707308769, 77.01668411493301, 76.20294257998466, 83.06681826710701, 77.61658072471619, 79.38612297177315, 70.32792583107948, 71.81874543428421, 74.2528872191906, 78.35193246603012, 59.7289227694273, 30.122655630111694, 33.89048784971237, 43.23694132268429, 68.37492182850838, 63.02442513406277, 73.2768639922142, 71.70069336891174, 69.84133914113045, 69.11091953516006, 74.87495183944702, 74.75130647420883, 72.01452612876892, 68.90661969780922, 65.75472682714462, 61.86808258295059, 58.1591510027647, 63.50416839122772, 63.73658671975136, 64.9783144891262, 61.824240535497665, 60.92143937945366, 70.50979927182198, 77.80918478965759, 79.00837004184723, 78.01206350326538, 70.1036086678505, 63.68840530514717, 56.0024057328701, 59.56785701215267, 61.343463733792305, 60.87128967046738, 59.88544017076492, 64.47055533528328, 70.13013884425163, 73.36995139718056, 71.378143876791, 65.65126597881317, 66.62607327103615, 61.463670283555984, 61.13265484571457, 63.97028177976608, 69.70802709460258, 74.64856758713722, 76.6042010486126, 76.63518458604813, 82.54079729318619, 80.26731848716736, 91.05709031224251, 58.621696382761, 0.36125270125921816, 0.5888582020998001, 3.3984970254823565, 0.6891806563362479, 1.0525106289424002, 0.5584337096661329, 0.8470869425218552, 1.0007938602939248, 3.1462762970477343, 1.3113565393723547, 0.203447436215356, 1.8000167305581272, 47.90844865143299, 70.98309427499771, 80.85276067256927, 61.64517514407635, 37.89818599820137, 28.140733279287815, 35.51424331963062, 54.984508752822876, 69.68305483460426, 72.0450384914875, 67.36407727003098, 73.54386046528816, 33.37607145309448, 0.3659919969504699, 0.02464413053530734, 0.031099132502276916, 0.0530732364859432, 0.04542140079138335, 0.10855326530872844, 0.01077025024642353, 0.04020137894258369, 0.041300685188616626, 0.05632580257952213, 0.028993101077503525, 0.0322187012352515, 0.06022147303156089, 0.03673594263091218, 0.13907618878874928, 0.15776738582644612, 0.23020797525532544, 0.17809964949265122, 0.09700377020635642, 0.16507458669366315, 0.1640964360558428, 0.1594485729583539, 0.1518341526389122, 0.27766662708017975, 0.22359420749126002, 0.18829439854016528, 0.3733989573083818, 0.5849576520267874, 8.49820313975215, 107.02422872185707, 96.15501075983047, 92.36246466636658, 75.00971540808678, 55.68141795694828, 41.838479563593864, 91.3031043112278, 126.58326879143715, 112.15786725282669, 85.39119154214859, 12.382893338799477, 0.5331475508864969, 0.9217410022392869, 10.49683889374137, 2.15539064258337, 0.5327910231426358, 0.4747250030050054, 2.2417443338781595, 3.0922873690724373, 1.722429406363517, 1.2455367087386549, 41.086066737771034, 110.86758568882942, 108.2591624557972, 99.45809751749039, 102.24992170929909, 106.67340874671936, 107.3164938390255, 105.78708350658417, 103.49300220608711, 98.98052394390106, 103.10480743646622, 99.23379555344582, 97.68102407455444, 95.79846829175949, 98.4070435166359, 98.35807174444199, 98.18437546491623, 95.94804346561432, 94.68451246619225, 95.21076902747154, 81.33225694298744, 71.3683708012104, 70.0267843902111, 67.45218694210052, 67.89526596665382, 64.35585469007492, 69.71997365355492, 76.24958887696266, 78.5601232945919, 80.21891668438911, 81.13034337759018, 76.34161993861198, 70.44840216636658, 61.34176902472973, 64.96199816465378, 74.82977226376534, 80.95227733254433, 84.77592095732689, 82.34535858035088, 81.11227914690971, 79.95193541049957, 76.7695377767086, 79.31228533387184, 79.5469531416893, 87.83768266439438, 84.46963459253311, 84.25388216972351, 72.90713623166084, 74.34367194771767, 81.36106699705124, 85.85018411278725, 63.47544193267822, 31.14835549145937, 35.78321188688278, 45.21042242646217, 78.9312569797039, 68.3841173350811, 78.43737468123436, 74.08067286014557, 74.78902325034142, 73.5586416721344, 78.57266262173653, 77.79170572757721, 73.51160019636154, 72.4018469452858, 65.8090715110302, 63.34967628121376, 61.3320529460907, 66.1254957318306, 67.09907189011574, 69.36527028679848, 65.92893987894058, 62.91497580707073, 74.8792228102684, 81.83315366506577, 83.76387566328049, 82.7312658727169, 72.08272486925125, 66.15006521344185, 59.1999189555645, 61.93010285496712, 65.9473916888237, 63.31298165023327, 62.567530050873756, 67.01815903186798, 72.40593552589417, 75.37270233035088, 72.31193616986275, 70.77725932002068, 71.0124059021473, 67.45068222284317, 65.15771806240082, 67.5931365787983, 71.10766679048538, 78.86426657438278, 80.01358330249786, 80.89884459972382, 86.2785655260086, 83.5143506526947, 95.68363845348358, 60.184974297881126, 0.5490798584651202, 4.121613660827279, 7.191632799804211, 3.403321341611445, 1.3992214808240533, 1.470799664966762, 3.54857234749943, 8.665396068245173, 4.870022451505065, 0.932657103985548, 0.2158733780379407, 4.43403004668653, 64.46970418095589, 75.83393678069115, 98.46578076481819, 96.80808931589127, 66.24913349747658, 33.64262714982033, 41.1536119133234, 65.421302318573, 79.40070658922195, 84.59455668926239, 77.62038812041283, 82.41924941539764, 39.92268696427345, 0.7438268302939832, 0.1669941219734028, 0.1426061399979517, 0.10480998374987394, 0.2831308823078871, 0.2247081563109532, 0.14028810110175982, 0.1329689664999023, 0.32670483633410186, 0.18826095736585557, 0.1717020248179324, 0.1702679877053015, 0.19736678281333297, 0.2393973813741468], [0.010341928064008243, 0.03801780236244667, 0.015635971722076647, 0.024772640826995485, 0.11589429326704703, 0.05065478500910103, 0.023059784398355987, 0.06365338282193989, 0.07790715273586102, 0.024263831801363267, 0.031401355445268564, 0.09948456950951368, 0.10501645665499382, 0.5344542057719082, 23.107456862926483, 78.59882801771164, 69.53827500343323, 66.22438162565231, 36.57675750553608, 31.057528965175152, 25.516852475702763, 47.33067065477371, 94.6784707903862, 87.3675186932087, 28.59663661569357, 0.3904518485069275, 0.07809012924553826, 0.8773066021967679, 1.7274298192933202, 0.3559766843682155, 0.32134320528712124, 0.32376379414927214, 0.26292917726095766, 0.12217322626383975, 0.13090312422718853, 3.7155330134555697, 52.097568064928055, 95.54382115602493, 102.42967486381531, 97.87279978394508, 101.56154304742813, 100.06012961268425, 102.0840074121952, 93.46609264612198, 94.13208290934563, 92.72583156824112, 89.62088897824287, 87.49602019786835, 87.30336293578148, 87.24212542176247, 90.73641031980515, 87.86992013454437, 86.79582417011261, 83.89645054936409, 83.96447449922562, 72.89816871285439, 63.31737421452999, 61.24654993414879, 61.20539054274559, 62.47226156294346, 60.936896950006485, 59.04970541596413, 68.02845641970634, 71.7364950478077, 74.41209867596626, 75.85852906107903, 77.82791778445244, 72.52871453762054, 68.86682063341141, 60.29940515756607, 58.39605689048767, 61.53175503015518, 68.87267991900444, 71.82027295231819, 76.022809445858, 74.09894987940788, 77.47214287519455, 72.18804761767387, 71.04574531316757, 71.10866993665695, 74.24845665693283, 69.50045183300972, 73.46036374568939, 68.02853241562843, 67.79492855072021, 69.91395324468613, 70.44008821249008, 49.96311999857426, 22.241641022264957, 18.138499595224857, 28.966617062687874, 61.412623822689056, 58.14908914268017, 68.83878573775291, 72.74754479527473, 66.55959203839302, 62.39268243312836, 69.45948243141174, 72.50697210431099, 75.29882669448853, 69.97743263840675, 68.28565701842308, 64.86453339457512, 62.00284615159035, 65.86945787072182, 68.89566108584404, 71.44299119710922, 65.49911454319954, 60.22967889904976, 65.58498993515968, 75.08851557970047, 73.597741574049, 76.35879501700401, 72.6041404902935, 61.679054126143456, 54.5285028219223, 56.072587966918945, 58.10414135456085, 57.971699461340904, 57.58877120912075, 68.32611724734306, 72.81066700816154, 76.54277354478836, 69.35306534171104, 65.86916148662567, 61.95098273456097, 59.6098979562521, 56.83980479836464, 61.5687308460474, 66.36292219161987, 71.05355009436607, 72.13817909359932, 76.68274283409119, 72.75059223175049, 80.52592501044273, 77.1280637383461, 89.198237657547, 10.992338955402374, 1.6015859157778323, 1.6162883955985308, 4.471174478530884, 0.8776499493978918, 0.2620858303271234, 0.2620218275114894, 0.5809117003809661, 2.07503872923553, 0.48537695955019444, 0.15225566283334047, 0.3087713720742613, 18.734440617263317, 44.510473385453224, 61.41711138188839, 98.65407586097717, 70.47661185264587, 30.515231564641, 16.582042314112186, 18.565488383173943, 38.06216239929199, 64.36146318912506, 63.26462164521217, 57.6945461332798, 66.61337435245514, 14.244086667895317, 0.098045790073229, 0.06519762886455283, 0.11968484963290393, 0.014597105982829817, 0.029078997249598615, 0.02910947168857092, 0.038607349633821286, 0.07614648900926113, 0.06448532294598408, 0.14196223783073947, 0.022205941641004756, 0.03836152063740883, 0.011564628421183443, 0.038274448161246255, 0.023676824530411977, 0.06861785353976302, 0.055941711470950395, 0.06108909561589826, 0.06665815322776325, 0.05303032921801787, 0.042684018771979026, 0.02789994909107918, 0.05126294163346756, 0.057961191778304055, 0.04280049884982873, 0.18242703838041052, 0.4722381255123764, 28.057774230837822, 93.88275548815727, 76.79403126239777, 82.5988657772541, 44.62948299944401, 30.673132091760635, 26.20496515184641, 55.011209920048714, 107.95501157641411, 100.16321808099747, 37.19149611890316, 0.07949970517074689, 0.10408454181742854, 2.1398138534277678, 3.9881320483982563, 0.6181702448520809, 0.35792470327578485, 0.7655905187129974, 0.26857297285459936, 0.6388059875462204, 0.22135039820568636, 5.418152064085007, 56.77363134920597, 101.99406623840332, 105.69337293505669, 102.56683230400085, 105.93944773077965, 102.57276758551598, 104.81378853321075, 97.08153784275055, 98.77831399440765, 95.68537876009941, 92.5304764509201, 90.5024416744709, 91.18124485015869, 90.43676599860191, 93.27889189124107, 89.89494547247887, 90.62035694718361, 86.48364812135696, 85.64080014824867, 76.41667351126671, 65.54654359817505, 63.73632073402405, 66.40778258442879, 63.52178804576397, 63.90183225274086, 62.94074222445488, 69.12814021110535, 72.64388635754585, 76.87081754207611, 78.43341529369354, 80.22187292575836, 74.65723872184753, 72.5966776907444, 66.40413478016853, 61.75623558461666, 64.31623801589012, 72.4334916472435, 75.88922381401062, 77.63567090034485, 77.12149769067764, 81.55275911092758, 76.08761116862297, 76.0691973567009, 74.32681605219841, 77.1000212430954, 75.19962921738625, 77.25794836878777, 71.83326825499535, 73.29910039901733, 74.26683247089386, 71.87707990407944, 57.44294263422489, 27.25107181817293, 25.699700564146042, 38.21041904389858, 67.00344622135162, 61.80689446628094, 72.84208372235298, 76.80508106946945, 70.64336210489273, 65.0222173333168, 72.21931993961334, 77.7269496023655, 77.78905346989632, 74.40534263849258, 73.91806438565254, 69.00612115859985, 66.90570786595345, 69.61494728922844, 71.53222560882568, 75.58457136154175, 69.47820782661438, 64.34791311621666, 67.70451620221138, 77.32699066400528, 75.5119040608406, 80.82544773817062, 75.4118250310421, 66.35414466261864, 57.08607718348503, 58.34348291158676, 60.91224767267704, 62.00616717338562, 60.62038153409958, 71.02037027478218, 75.94174459576607, 77.82012060284615, 73.47678646445274, 71.19414255023003, 64.29051339626312, 64.06656861305237, 58.35689999163151, 65.09820565581322, 69.89247679710388, 76.51835605502129, 75.27051821351051, 79.35395389795303, 76.62729620933533, 84.08868983387947, 80.97147390246391, 94.12441492080688, 18.517943434417248, 1.0385716706514359, 1.8706569587811828, 2.8728009341284633, 1.583487130701542, 1.0053005372174084, 0.5598046048544347, 0.39297895040363073, 2.310984693467617, 1.9103455916047096, 0.459114876575768, 0.34760454611387104, 16.256185099482536, 53.00714045763016, 67.72755816578865, 87.41236388683319, 54.10780839622021, 33.85480396449566, 26.40908259898424, 29.13674533367157, 47.52210058271885, 72.16004312038422, 71.53544783592224, 66.4105336368084, 77.23021745681763, 16.711818650364876, 0.18886025645770133, 0.059370986637077294, 0.09041266021085903, 0.03812150265730452, 0.037884375342400745, 0.013999068542034365, 0.04825541785976384, 0.04506870995101053, 0.04733608242531773, 0.060134426530567, 0.02232544225989841, 0.07217853708425537, 0.035157576348865405, 0.15667443978600204, 0.20894784887786955, 0.13166246004402637, 0.24678342801053077, 0.24869465123629197, 0.15766977856401354, 0.16979417094262317, 0.13798132800729945, 0.13684354140423238, 0.21089508110890165, 0.2321542426943779, 0.2576057519763708, 0.26688037149142474, 0.6571127520874143, 34.61200833320618, 105.85161924362183, 88.89648824930191, 92.2749325633049, 56.44126318395138, 43.74032311141491, 40.993085727095604, 70.75047075748444, 114.23267751932144, 110.99831387400627, 49.64865267276764, 0.7849291653838009, 0.19568742136470973, 2.85852889996022, 13.160114083439112, 2.0963522605597973, 0.7016831135842949, 1.1919212294742465, 1.7483142111450434, 2.0656655821949244, 0.6191308808047324, 5.922450553625822, 60.08464828133583, 108.02614375948906, 110.9076963365078, 105.88011011481285, 108.48911091685295, 105.46571955084801, 106.41585096716881, 101.23399302363396, 101.335219591856, 99.83363896608353, 96.69723406434059, 95.41667997837067, 95.71670427918434, 93.03844839334488, 97.72593766450882, 93.59299063682556, 96.76336571574211, 92.28224337100983, 89.55718919634819, 80.772774964571, 68.92818734049797, 67.9668541252613, 69.80817452073097, 68.18355649709702, 67.34097450971603, 63.3302441239357, 73.10541719198227, 78.32373037934303, 80.21808072924614, 81.49978995323181, 83.79745066165924, 80.57403802871704, 76.14717677235603, 67.8907822072506, 64.76883932948112, 67.25145891308784, 77.38836497068405, 80.59065833687782, 80.77404409646988, 81.37317314743996, 83.64146143198013, 78.35763975977898, 79.32308435440063, 79.54028829932213, 81.94756552577019, 77.15022414922714, 80.81804573535919, 74.24410969018936, 77.48296469449997, 78.01530852913857, 77.04810082912445, 60.695290714502335, 27.28364747017622, 24.188719242811203, 38.676661625504494, 76.11894428730011, 64.73171532154083, 76.48358792066574, 79.0862886607647, 74.68744710087776, 68.95542427897453, 78.9583495259285, 79.55517590045929, 80.20995676517487, 77.20710709691048, 75.76784312725067, 71.20279088616371, 70.61743229627609, 73.64948719739914, 76.23065069317818, 78.65188077092171, 72.93271645903587, 67.06930428743362, 71.81795507669449, 81.55461341142654, 79.39436852931976, 81.68239295482635, 80.29562696814537, 68.46382185816765, 59.879523888230324, 61.056761518120766, 66.10683113336563, 64.61263731122017, 63.20742331445217, 74.21431168913841, 80.13720586895943, 79.00279194116592, 76.36207044124603, 75.03350213170052, 67.28182688355446, 66.03724166750908, 62.333485409617424, 67.81933844089508, 73.42034429311752, 79.28328529000282, 77.75647401809692, 84.19440776109695, 77.72644802927971, 89.13282036781311, 82.78548896312714, 98.35076093673706, 16.434699520468712, 3.3408403443172574, 11.077318545430899, 12.368127331137657, 4.889370063319802, 1.3932103221304715, 1.7016922566108406, 3.074438776820898, 5.4572714399546385, 1.2779242708347738, 0.5181805102620274, 0.6335657124873251, 29.765562191605568, 64.99137818813324, 77.78099790215492, 111.76423877477646, 89.19733330607414, 43.19929674267769, 25.28158999979496, 32.094392627477646, 54.7581434994936, 82.34028965234756, 81.02356910705566, 74.97958302497864, 89.53898057341576, 19.725189954042435, 0.28828408860135823, 0.2535126591101289, 0.41908067010808736, 0.1384185123606585, 0.10156624179217033, 0.1265817615785636, 0.10181129153352231, 0.1216966709762346, 0.21838444954482839, 0.2282587392255664, 0.13373162713833153, 0.17290960298851132, 0.15615472861099988], [0.08204420300899073, 0.021041838481323794, 0.10497779818251729, 0.052144843139103614, 0.04383648876682855, 0.04408149769005831, 0.09839314487180673, 0.04552399528620299, 0.08222884935094044, 0.031986423855414614, 0.016880987532204017, 0.09563426283420995, 0.13229003496235237, 0.1807642713538371, 46.902813613414764, 77.43498846888542, 64.30591776967049, 44.35981906950474, 45.91072864830494, 30.71546372026205, 40.59232883155346, 89.56804901361465, 100.67524060606956, 65.23898810148239, 6.517684813588858, 0.06884284302941523, 0.20558207557769492, 0.47076439834199846, 1.0760009684599936, 0.21274838712997735, 0.22713963990099728, 0.19264639704488218, 0.13023811538005248, 0.0883997479104437, 0.1743046476622112, 12.776198834180832, 70.30166164040565, 97.57060959935188, 103.64032030105591, 99.61724817752838, 100.27255341410637, 99.19191420078278, 95.826176404953, 92.07928106188774, 91.95432856678963, 87.96816766262054, 86.68606325984001, 81.75769731402397, 85.90081259608269, 85.96458837389946, 90.84997862577438, 86.49356558918953, 84.58657711744308, 76.98979675769806, 71.4511227607727, 63.96410331130028, 62.44110703468323, 61.840583458542824, 62.62424200773239, 59.1876570135355, 61.74462340772152, 60.25990627706051, 67.60338842868805, 68.34165081381798, 71.4798492193222, 76.44857659935951, 74.97640639543533, 75.81564456224442, 68.8965654373169, 62.7204642444849, 59.510594084858894, 58.61450336873531, 64.6984139084816, 69.87788558006287, 77.92141556739807, 76.05454534292221, 73.91069278120995, 76.0580487549305, 70.78732118010521, 68.82022753357887, 73.62290382385254, 77.30277836322784, 71.54628485441208, 69.23210263252258, 68.4071896970272, 67.70149156451225, 63.521955236792564, 53.81859831511974, 34.87996615469456, 31.00845079869032, 32.26786091923714, 64.7552664577961, 60.660647973418236, 69.03873860836029, 70.54010644555092, 67.41677284240723, 60.36181300878525, 61.45077757537365, 69.86353754997253, 75.41421890258789, 71.52591034770012, 74.63010057806969, 70.52248299121857, 69.0616437792778, 67.85412937402725, 72.53723368048668, 72.92452409863472, 69.4891132414341, 70.27165085077286, 67.1448366343975, 70.0302042067051, 73.4757225215435, 71.25178545713425, 73.20111125707626, 65.20000219345093, 54.83697026968002, 54.24514062702656, 59.009666964411736, 55.78246593475342, 63.28458197414875, 71.47723495960236, 75.18802464008331, 73.8825210928917, 72.8450171649456, 66.37005060911179, 59.98097084462643, 56.90713718533516, 58.65574635565281, 62.225001230835915, 65.56036725640297, 73.54580596089363, 74.56106588244438, 76.82835102081299, 76.57936558127403, 77.67170056700706, 82.75847241282463, 79.7631311416626, 66.11849650740623, 0.45117009663954377, 0.22222960571525618, 1.576188316103071, 1.1571323149837554, 0.2401367831043899, 0.43690598860848695, 0.38573567813728005, 0.9167266963049769, 2.8414082061499357, 0.32220163266174495, 0.10165087631321512, 0.8126758108846843, 24.37569011002779, 49.47465620934963, 82.41617158055305, 92.70779013633728, 63.20355512201786, 35.96103094518185, 17.789845503866673, 28.54740835726261, 55.093961879611015, 57.027564123272896, 56.76164299249649, 63.681273087859154, 47.269189953804016, 0.9587469790130854, 0.11750762583687901, 0.1100523813511245, 0.004594771708070766, 0.029407505207927898, 0.10101774270879105, 0.01688724569248734, 0.04579583284794353, 0.011609846551436931, 0.058834484370891005, 0.03628903614298906, 0.03786775494518224, 0.014074374266783707, 0.02930987382569583, 0.04721340912510641, 0.06335745885735378, 0.06015298764395993, 0.14468090288573876, 0.009419975631317357, 0.07524085362092592, 0.0786860886728391, 0.05083606571133714, 0.0758962293912191, 0.04778895578056108, 0.0678748004429508, 0.1067660994885955, 0.22152219054987654, 55.16738533973694, 89.99689400196075, 71.52308329939842, 58.45728300511837, 48.36579971015453, 32.1713574975729, 42.10638798773289, 89.44988295435905, 113.28299447894096, 73.97494733333588, 8.978940043598413, 0.04352467542048544, 1.4136367198079824, 1.5318014728836715, 2.5316894380375743, 1.0308198491111398, 0.22213324526092038, 0.25009189266711473, 0.18417252518702298, 0.06998458527959883, 0.6003063940443099, 15.363879930227995, 72.00358271598816, 101.55695289373398, 107.74524003267288, 101.80200934410095, 103.23949500918388, 100.52009493112564, 99.03087124228477, 96.37831717729568, 94.87376511096954, 90.38464799523354, 88.51639464497566, 83.56394559144974, 89.79507163167, 88.69046330451965, 95.13806372880936, 89.75712686777115, 89.05896753072739, 79.23397153615952, 73.70581537485123, 67.09163948893547, 64.9463278055191, 64.70105096697807, 64.39353346824646, 62.32520945370197, 65.09619936347008, 64.77929636836052, 68.83913531899452, 72.53097161650658, 75.04251524806023, 79.4341067969799, 79.81125175952911, 80.79115837812424, 74.0530027449131, 67.54285767674446, 63.078602626919746, 61.42565332353115, 66.50521695613861, 72.71076276898384, 76.95701971650124, 77.31509730219841, 77.26540356874466, 78.43309611082077, 74.29228350520134, 71.63657560944557, 75.86330160498619, 77.78231263160706, 78.63571643829346, 72.0117598772049, 71.53431549668312, 70.47133773565292, 66.07245817780495, 58.6822385340929, 39.35932919383049, 37.48665668070316, 40.20931698381901, 69.27003979682922, 64.75673317909241, 70.26685550808907, 74.66975525021553, 71.0997024178505, 64.08412367105484, 62.5943224132061, 71.43409967422485, 78.43361288309097, 74.00668323040009, 77.7259312570095, 75.3306233882904, 71.49791345000267, 71.87712550163269, 75.16036212444305, 74.75418671965599, 74.49733570218086, 72.83174827694893, 70.98396822810173, 74.02475506067276, 77.81782552599907, 73.9333775639534, 75.81807643175125, 67.85941869020462, 59.06772404909134, 58.055222779512405, 61.26587949693203, 59.273619800806046, 67.62462928891182, 74.75995481014252, 77.51830279827118, 79.57128703594208, 75.021403580904, 69.46883752942085, 64.67842698097229, 58.77236969769001, 61.65622495114803, 66.87995284795761, 67.86369726061821, 75.6707963347435, 77.94137969613075, 77.66132712364197, 78.92398416996002, 80.57654589414597, 84.52168419957161, 79.45626720786095, 73.11936244368553, 2.2899112617596984, 1.2135355384089053, 1.7067706841044128, 1.3350546802394092, 1.1672916635870934, 0.7769936474505812, 0.6931948440615088, 3.155990238301456, 4.489166988059878, 1.484338219743222, 0.22983878647210076, 0.35571657645050436, 26.352154053747654, 56.191525384783745, 87.24571242928505, 81.23011082410812, 45.75101561844349, 26.236499659717083, 29.580774307250977, 40.52039109170437, 65.42002558708191, 67.70493417978287, 66.3558241724968, 74.68458205461502, 56.42389431595802, 1.0504442523233593, 0.09549061272991821, 0.0528680066781817, 0.03130397824861575, 0.04976624499249738, 0.08905318667530082, 0.013373675537877716, 0.05651310581015423, 0.024720959518163, 0.0438098530867137, 0.023684502048126888, 0.019305283421999775, 0.012125008361181244, 0.10605339281028137, 0.136230438365601, 0.22536074160598218, 0.2301092993002385, 0.27414587850216776, 0.12164852043497376, 0.1722734043141827, 0.25855706655420363, 0.15040729951579124, 0.14073623955482617, 0.17149352584965527, 0.2196275765891187, 0.3045177675085142, 0.28466418909374624, 66.03475660085678, 106.30931988358498, 84.59711015224457, 66.56653046607971, 63.94357681274414, 45.37839241325855, 59.04947742819786, 116.08036637306213, 116.71617865562439, 93.00117239356041, 12.158280741423368, 0.18722539418376982, 0.8022508327849209, 2.351849600672722, 6.281441990286112, 1.2496715993620455, 0.5006795399822295, 0.45600441691931337, 0.5283664574380964, 0.2655808412237093, 0.9099456039257348, 14.72451388835907, 79.11773577332497, 108.32372859120369, 111.95989027619362, 105.23986726999283, 107.0684203505516, 103.2747495174408, 102.5327405333519, 99.63633835315704, 98.71484979987144, 94.43613499403, 94.28978964686394, 88.11980992555618, 93.08303520083427, 91.83487057685852, 97.84521326422691, 93.28355804085732, 92.54160225391388, 84.32335764169693, 77.59310558438301, 70.49963861703873, 67.78902366757393, 66.64753451943398, 67.91175708174706, 66.90414994955063, 67.9057078063488, 68.85940343141556, 74.09960344433784, 78.58397841453552, 79.61025774478912, 81.22248843312263, 81.89975649118423, 84.75546285510063, 77.6803033053875, 72.09463343024254, 65.38111567497253, 65.64368158578873, 71.6897651553154, 76.88828140497208, 83.03784102201462, 80.44761881232262, 79.58548307418823, 81.66086331009865, 78.64701703190804, 76.45619139075279, 81.89255967736244, 81.07073977589607, 77.71532222628593, 76.71202406287193, 77.62384593486786, 73.13975974917412, 71.03284880518913, 62.797634303569794, 39.6363989263773, 35.936556458473206, 41.01836197078228, 77.70099699497223, 70.07585495710373, 73.93573343753815, 78.68566855788231, 76.72577172517776, 67.38413259387016, 68.86609107255936, 76.16040006279945, 83.76781225204468, 77.14431166648865, 82.80241325497627, 76.20731234550476, 76.16756647825241, 74.63523030281067, 79.0166687965393, 78.88204962015152, 77.70387724041939, 78.48064675927162, 74.05807927250862, 77.55617156624794, 78.19597363471985, 76.41380846500397, 80.04024267196655, 71.89324423670769, 62.66479343175888, 60.66197410225868, 65.7113179564476, 62.810754999518394, 70.60426220297813, 76.23483806848526, 81.24009668827057, 81.22733697295189, 79.20309439301491, 72.28459283709526, 68.13125610351562, 63.241093307733536, 65.26550307869911, 70.12207567691803, 70.96572920680046, 78.94289955496788, 81.27371728420258, 83.15337762236595, 85.07401496171951, 83.73829543590546, 87.5977711379528, 84.06149849295616, 74.09224703907967, 1.270476789213717, 4.284294806420803, 7.867164826020598, 3.896946203894913, 3.174767643213272, 1.6097135609015822, 3.7992543959990144, 11.208870336413383, 6.847227355465293, 1.0473706922493875, 0.23320170992519706, 1.2042366061359644, 39.649124443531036, 66.60336568951607, 96.01048171520233, 106.39686718583107, 80.8054532110691, 49.67934362590313, 30.803199112415314, 44.24909681081772, 75.08359864354134, 78.20288926362991, 76.63719847798347, 85.16180545091629, 64.9536994099617, 1.2290968908928335, 0.25132664828561246, 0.21223853167612106, 0.13595801079645753, 0.20889110426651314, 0.1554850590764545, 0.07781487409374677, 0.15812058874871582, 0.11201969609828666, 0.14870254177367315, 0.08529482467565686, 0.05955461994744837, 0.13874856027541682], [0.0416828875313513, 0.0428332609590143, 0.021053742530057207, 0.03404749040782917, 0.031895733409328386, 0.05321335767803248, 0.040062437765300274, 0.01931593695189804, 0.0061187408846308244, 0.045951301653985865, 0.06076803882024251, 0.1145578188879881, 0.08092158590443432, 1.4115050341933966, 69.09898057579994, 70.12603506445885, 65.91478943824768, 57.564087733626366, 29.23151984810829, 19.730173386633396, 56.455839201807976, 86.20806410908699, 89.06423404812813, 31.839743591845036, 0.9187418350484222, 0.14213688002200797, 1.0758881620131433, 2.4843302043154836, 1.453659615945071, 0.6277108797803521, 0.19949600449763238, 0.6394512404222041, 0.05906060934648849, 0.2094675600528717, 1.200150044169277, 26.955856159329414, 72.75777384638786, 98.86465296149254, 103.43015357851982, 105.79624861478806, 98.85344356298447, 94.8513463139534, 97.30450987815857, 89.9086931347847, 86.15517094731331, 82.96067476272583, 72.26852729916573, 74.6036995947361, 80.16825020313263, 86.18255987763405, 90.6766015291214, 86.7951326072216, 85.50544381141663, 74.84256237745285, 63.86134162545204, 64.10523533821106, 64.96266692876816, 63.38530316948891, 61.58943213522434, 59.492081478238106, 59.493023827672005, 62.795552015304565, 62.28699490427971, 64.77343708276749, 69.51547622680664, 77.01398625969887, 79.11143571138382, 75.59296131134033, 70.53282603621483, 68.0541430413723, 63.839485198259354, 62.7284400165081, 67.63399958610535, 70.65041452646255, 73.68549406528473, 71.26193091273308, 71.04891434311867, 78.54560047388077, 70.20696312189102, 67.13276088237762, 69.57577899098396, 70.28116554021835, 67.73156315088272, 63.07615175843239, 63.147777915000916, 63.27958904206753, 62.20904588699341, 61.30734287202358, 49.93792735040188, 42.4211061000824, 40.96340931952, 58.295198902487755, 59.52359318733215, 66.70377910137177, 69.3725810945034, 65.5632247030735, 60.24028792977333, 56.798546612262726, 61.11612193286419, 66.24174669384956, 67.11907401680946, 73.84081453084946, 72.56043523550034, 71.45062118768692, 71.03901967406273, 69.6828344464302, 70.24977162480354, 71.54541850090027, 69.66475501656532, 73.97730320692062, 73.76412704586983, 70.7659587264061, 72.36365899443626, 72.75243133306503, 63.07939678430557, 56.72595150768757, 55.99662244319916, 57.324350997805595, 58.67593467235565, 68.58414620161057, 75.99762439727783, 75.07974565029144, 73.99034410715103, 75.8561047911644, 67.26988032460213, 66.27026796340942, 59.341525956988335, 54.66440252959728, 59.90252785384655, 65.20497992634773, 70.58641076087952, 73.68574485182762, 72.75564596056938, 73.21127951145172, 72.99561068415642, 78.20906773209572, 73.31190571188927, 82.20947787165642, 50.18725857138634, 0.4404098755912855, 1.1818131781183183, 1.051364396698773, 0.6132655986584723, 0.3054114320548251, 0.3337050700793043, 1.6580666787922382, 3.5728661064058542, 1.643980003427714, 0.3271007869625464, 0.21579668449703604, 8.135127872228622, 37.35979288816452, 70.52154064178467, 89.23722356557846, 102.09702551364899, 77.83501580357552, 30.21010033786297, 14.88007279112935, 16.50051388889551, 35.78861139714718, 58.23416657745838, 60.46525105834007, 62.32014812529087, 6.748978877440095, 0.19192354520782828, 0.06986745953327045, 0.060107364115538076, 0.059059548075310886, 0.06024806418281514, 0.05506084897206165, 0.0417025841306895, 0.03987147574662231, 0.04053524520713836, 0.0461732334952103, 0.021451665415952448, 0.039211695329868235, 0.025808922036958393, 0.052892571766278706, 0.05581088196777273, 0.06332933146040887, 0.022291307177511044, 0.08962013554992154, 0.0514171710528899, 0.01891029573016567, 0.07685501739615574, 0.08142085091094486, 0.013380246327869827, 0.031550712665193714, 0.19095539872068912, 1.7915497161448002, 82.39046216011047, 77.8680968284607, 77.23545357584953, 59.59777280688286, 38.5543005913496, 26.235808096826077, 49.98781867325306, 97.5666806101799, 100.55253759026527, 39.01497647166252, 0.9332626964896917, 0.7148577785119414, 2.501256871037185, 6.234301719814539, 2.8861702792346478, 1.926681746263057, 0.9697134874295443, 0.4619252117117867, 0.06844565301435068, 0.23054958583088592, 1.9588688691146672, 29.366503804922104, 79.36175107955933, 104.86397624015808, 106.68598607182503, 108.32043036818504, 103.87515529990196, 98.84285733103752, 99.15740445256233, 93.40793296694756, 88.31093207001686, 85.82686096429825, 73.8923017680645, 76.27488031983376, 84.5952482521534, 90.56862652301788, 91.90595716238022, 91.10983148217201, 89.31913956999779, 78.58829498291016, 68.15440446138382, 66.146250218153, 68.60077410936356, 66.56073957681656, 65.15346229076385, 62.083527222275734, 62.928784266114235, 66.35875761508942, 68.13579306006432, 65.74920192360878, 73.57790663838387, 81.03621482849121, 79.62322264909744, 78.06345954537392, 75.71995809674263, 70.33107966184616, 68.10878410935402, 67.21989020705223, 70.42827844619751, 74.19693902134895, 77.44111374020576, 74.87841725349426, 73.33330616354942, 80.29124200344086, 73.66806820034981, 70.80432906746864, 71.68209716677666, 73.69042620062828, 70.28656125068665, 68.71109738945961, 67.65483766794205, 64.36745926737785, 64.86146315932274, 64.7216534614563, 53.51765066385269, 46.92261815071106, 47.811990827322006, 60.46208202838898, 63.091977909207344, 68.46446022391319, 72.80703440308571, 70.9506744146347, 66.35387107729912, 60.778513848781586, 63.107800260186195, 69.43087756633759, 71.37569680809975, 73.45587998628616, 74.34942483901978, 74.98112574219704, 72.3976443707943, 72.71505653858185, 70.95325827598572, 74.2953385412693, 72.2892589867115, 77.84896105527878, 77.19739481806755, 71.90211296081543, 75.13003215193748, 73.4064294397831, 66.76373228430748, 58.155689388513565, 58.05599793791771, 58.95822912454605, 59.92337353527546, 72.34674990177155, 77.57200911641121, 78.80260348320007, 76.7757998406887, 76.65543749928474, 72.1156919002533, 68.88771951198578, 62.20937266945839, 59.997450560331345, 63.957985639572144, 67.77931898832321, 70.88175371289253, 77.38616868853569, 78.19915026426315, 76.93141669034958, 77.53062173724174, 80.44337823987007, 76.91121697425842, 80.31303003430367, 62.822716757655144, 1.7143329908140004, 0.9549735439941287, 0.6328443449456245, 1.0667585581541061, 1.0495270765386522, 1.0584030440077186, 2.629684992134571, 3.390724305063486, 3.298270753584802, 0.4435444698901847, 0.5594236752949655, 6.454529352486134, 44.58256311714649, 76.35274574160576, 91.2296162545681, 80.57539075613022, 63.389049768447876, 28.421435616910458, 20.762615986168385, 20.645016096532345, 43.624364733695984, 69.57851484417915, 69.53323647379875, 77.3178331553936, 8.986781872808933, 0.2281315647996962, 0.0961677631130442, 0.05637398280669004, 0.04944558524584863, 0.04568302640109323, 0.026009283355961088, 0.01771743434801465, 0.031442292311112396, 0.033545575934113, 0.08437586031504907, 0.0686657294863835, 0.04235630862240214, 0.12957076134625822, 0.18025195196969435, 0.20644014672143385, 0.12794202921213582, 0.1366405194858089, 0.19708389096194878, 0.0839467356854584, 0.16084516129922122, 0.2148658235091716, 0.112533967330819, 0.12737341050524265, 0.30131813138723373, 0.2535847364924848, 2.6283821370452642, 95.50840705633163, 90.80361351370811, 87.87179723381996, 80.59583365917206, 44.61238011717796, 29.70951519906521, 82.09510400891304, 107.40272641181946, 108.08335348963737, 53.082566410303116, 1.6876831208355725, 0.3635431471047923, 3.642091741785407, 8.51428672671318, 8.058781418949366, 1.8572651711292565, 1.7265120497904718, 3.5991015611216426, 0.11150397767778486, 0.6578935508150607, 2.081071618013084, 30.969347096979618, 86.60401806235313, 109.5378090441227, 112.99899011850357, 113.5826388001442, 108.70202109217644, 101.97239980101585, 106.59676685929298, 97.01686531305313, 94.01995852589607, 91.12408071756363, 78.46762105822563, 80.0678899884224, 89.60343271493912, 92.1346364915371, 95.69143563508987, 94.57981288433075, 94.52595457434654, 80.8043284714222, 71.6366896033287, 70.16061320900917, 70.92238873243332, 67.89857178926468, 69.0671306848526, 65.49381002783775, 66.25013664364815, 69.12035062909126, 72.14795976877213, 72.61904329061508, 79.269028455019, 84.66603845357895, 83.35044264793396, 81.43543660640717, 78.216173350811, 75.72211638092995, 72.87289246916771, 71.00902408361435, 74.32057678699493, 78.77961471676826, 79.29886445403099, 74.86735984683037, 76.80328756570816, 85.9540705382824, 77.81660199165344, 74.65136423707008, 77.28504851460457, 77.25187629461288, 74.1493047773838, 73.16508919000626, 73.28810378909111, 67.93167561292648, 69.52887430787086, 67.81496107578278, 54.43238317966461, 47.61409744620323, 50.511802956461906, 67.89952173829079, 67.9826232790947, 74.29917633533478, 77.87832587957382, 76.16979315876961, 67.65869066119194, 65.76689377427101, 68.30017223954201, 73.27941745519638, 74.93593096733093, 79.77563247084618, 77.95641168951988, 77.69717440009117, 76.28576293587685, 75.33170253038406, 72.1579760313034, 74.79650884866714, 76.26211300492287, 79.46599468588829, 81.15786150097847, 76.65144011378288, 77.8770187497139, 79.91751685738564, 69.58654001355171, 62.32366293668747, 61.11139878630638, 61.58815920352936, 65.88623777031898, 76.3321204483509, 81.62009909749031, 82.11533412337303, 80.6606125831604, 78.55862617492676, 74.30746749043465, 72.53938436508179, 63.83143723011017, 61.36208273470402, 66.64959400892258, 71.19855791330338, 77.48079881072044, 81.34372472763062, 82.71440237760544, 81.6059410572052, 81.11746966838837, 85.27597412467003, 80.10352447628975, 85.90814620256424, 59.950089901685715, 0.8143299689982086, 2.765160072594881, 5.281533719971776, 1.9868687354028225, 1.333137326873839, 0.8501875167712569, 8.979282975196838, 8.08675266802311, 4.615267021581531, 0.6136839324608445, 0.49475081905256957, 12.932937573641539, 58.079302087426186, 85.10790154337883, 104.5563143491745, 122.09098264575005, 99.74075675010681, 44.274912625551224, 25.045835450291634, 31.77422370761633, 56.02314122021198, 80.28937250375748, 77.54707485437393, 89.18197453022003, 11.157875172793865, 0.42572642443701625, 0.16083459311630577, 0.2042078407248482, 0.18178888043621555, 0.0922247621929273, 0.16818725795019418, 0.15783573762746528, 0.2295360792777501, 0.12717604375211522, 0.2037320053204894, 0.17548599833389744, 0.16896416782401502], [0.047268316920963116, 0.02782936342555331, 0.028480787259468343, 0.05637308851873968, 0.0888929569919128, 0.003816689240920823, 0.025189154512190726, 0.06564010473084636, 0.051345568645047024, 0.06060477746359538, 0.11722385825123638, 0.1158570968254935, 0.39082458475604653, 5.859596701338887, 81.67923152446747, 70.00071778893471, 55.15032805502415, 49.797076508402824, 22.644366212189198, 40.505457893013954, 75.48519909381866, 93.37934330105782, 69.0325753390789, 12.500149346888065, 0.08644154673675075, 0.1872629320132546, 5.33279724419117, 1.6675385017879307, 1.0231488919816911, 1.0465165693312883, 0.34080641402397305, 0.26513145596254617, 0.17390759865520522, 0.06333805169560947, 5.279337912797928, 34.25059832632542, 87.92921975255013, 95.74397161602974, 97.68899604678154, 96.84706762433052, 97.08679676055908, 92.38685175776482, 88.45353081822395, 81.59000471234322, 73.58143284916878, 68.47191542387009, 68.45553070306778, 70.46181544661522, 81.3254477083683, 86.74520328640938, 88.53676915168762, 88.79504889249802, 85.42960748076439, 81.7211888730526, 63.589040637016296, 62.6860760897398, 63.34959648549557, 61.128543466329575, 62.07170985639095, 57.4091624468565, 59.63418245315552, 60.024231523275375, 57.843577936291695, 60.79176753759384, 64.60911110043526, 75.88239178061485, 78.93119618296623, 77.27930322289467, 72.96656504273415, 67.87580341100693, 69.03653472661972, 68.46971154212952, 71.2807247042656, 74.69883888959885, 74.80528637766838, 74.41405177116394, 68.54059293866158, 74.47545647621155, 71.82154208421707, 65.33189311623573, 65.95816791057587, 74.50035274028778, 63.240492939949036, 62.14771717786789, 58.59287492930889, 58.02407585084438, 60.97381956875324, 59.17613983154297, 62.043131589889526, 57.519607320427895, 52.77575947344303, 58.61131154000759, 55.80632485449314, 61.11279331147671, 64.5147317647934, 65.80454215407372, 63.91994208097458, 59.156817868351936, 55.029578134417534, 56.77651159465313, 59.92042489349842, 67.7456983923912, 68.71039062738419, 73.45406368374825, 71.13224387168884, 73.68060752749443, 70.66801518201828, 74.55179437994957, 75.16230762004852, 64.92196351289749, 64.49762508273125, 70.43104469776154, 73.86630356311798, 66.89772069454193, 60.97262643277645, 55.080240815877914, 53.681592866778374, 54.47342477738857, 57.036413848400116, 67.83434003591537, 74.58318829536438, 75.31682252883911, 70.4882164299488, 74.76107195019722, 70.29404684901237, 66.13789066672325, 63.251253962516785, 59.42353695631027, 60.29568515717983, 59.491085931658745, 65.27438700199127, 70.93919903039932, 74.61022764444351, 75.4736477136612, 74.45952013134956, 72.47518301010132, 81.01951852440834, 77.25366979837418, 87.61022686958313, 58.82067270576954, 1.7324502998962998, 0.882974888663739, 0.7408255850896239, 0.38008389703463763, 0.42733563808724284, 1.261091292835772, 3.7530638370662928, 2.437359499745071, 0.4238419036846608, 0.025607948446122464, 0.0756629130046349, 19.192944914102554, 47.47956946492195, 81.39745384454727, 90.01252636313438, 58.722276985645294, 79.94114398956299, 63.04813586175442, 50.03632307052612, 33.32620292901993, 51.689405366778374, 60.150817930698395, 68.62700790166855, 23.209238201379776, 0.43373725551646203, 0.035990945107187144, 0.1624486900982447, 0.01877348080597585, 0.12418474332662299, 0.04352498712250963, 0.10268852493027225, 0.04538207809673622, 0.05631385029118974, 0.10440448910230771, 0.03179038925736677, 0.055011061995173804, 0.03750462950847577, 0.0331354280206142, 0.02271691588248359, 0.06786817306419834, 0.028935358277522027, 0.007843072307878174, 0.0066479682482167846, 0.06847589553217404, 0.06923103821463883, 0.012042383204970974, 0.06279880719375797, 0.09226631504134275, 0.4848140850663185, 7.362708169966936, 97.95685887336731, 78.56403708457947, 68.75332832336426, 55.17483673989773, 39.12131376564503, 35.13496287167072, 65.73861569166183, 106.96157768368721, 78.6623378098011, 14.337462857365608, 0.2673547819722444, 0.6026411906350404, 5.679014241322875, 3.3290063543245196, 3.862221292220056, 2.185800173319876, 0.8957230264786631, 0.29630628938321024, 0.5912258313037455, 0.13850565534085035, 7.386163836345077, 37.908274456858635, 93.24995264410973, 102.14707642793655, 102.4706594645977, 99.26621541380882, 101.29290506243706, 95.50877943634987, 91.37977659702301, 85.80510333180428, 75.2783153951168, 71.42057999968529, 71.2861280143261, 73.16692069172859, 83.85198533535004, 90.41356444358826, 89.67620640993118, 92.60084107518196, 88.24376687407494, 85.42738080024719, 67.4875782430172, 65.69516882300377, 65.89171707630157, 65.24947553873062, 63.48812185227871, 60.44501334428787, 64.20833140611649, 61.691589653491974, 61.719613149762154, 63.421454429626465, 68.57427433133125, 78.26037257909775, 79.68615487217903, 82.40297108888626, 73.53252187371254, 72.2871994972229, 73.30763474106789, 74.2329078912735, 76.31987750530243, 78.9143630862236, 77.05692395567894, 76.12417280673981, 71.24683052301407, 76.22188836336136, 72.87196531891823, 68.20785999298096, 70.53152650594711, 77.43122667074203, 68.36330965161324, 66.78783819079399, 61.11191935837269, 61.259598433971405, 63.250243216753006, 62.276693657040596, 65.69567039608955, 61.396235302090645, 60.19889675080776, 61.69851668179035, 59.40193131566048, 64.02514323592186, 67.49502584338188, 71.77919715642929, 67.33083665370941, 64.89711284637451, 57.9006926715374, 57.914751917123795, 62.9362166672945, 68.59426125884056, 71.7706324160099, 75.12554839253426, 74.4436825811863, 74.81424629688263, 72.19011470675468, 74.72511067986488, 74.58974674344063, 66.09727844595909, 65.88526502251625, 75.44574201107025, 72.77842193841934, 70.54272830486298, 63.015795797109604, 57.279467806220055, 56.91306486725807, 57.878684252500534, 59.93359498679638, 71.57043635845184, 76.30258083343506, 77.27877125144005, 75.21473720669746, 76.7793944478035, 71.61416441202164, 69.43716242909431, 66.61853447556496, 63.76557916402817, 63.03029581904411, 62.982087805867195, 67.07180455327034, 73.66999849677086, 78.27131599187851, 78.64714622497559, 80.52136525511742, 76.41127020120621, 84.33093443512917, 82.2603115439415, 87.77070745825768, 71.65436625480652, 4.390112478286028, 1.0674141417257488, 0.6671186245512217, 0.8436480083037168, 0.9280132781714201, 3.325970792211592, 5.318005587905645, 3.308598124422133, 1.3483253493905067, 0.16505168401636183, 0.11294100564555265, 19.14401113986969, 56.860167905688286, 83.54240074753761, 94.24084067344666, 52.18003123998642, 58.52200873196125, 40.82848995923996, 57.57311224937439, 44.119170382618904, 56.73090644180775, 69.17151868343353, 79.4902753829956, 29.128535874187946, 0.3559977316763252, 0.1629620633320883, 0.06356385012622923, 0.04450308952073101, 0.058338432863820344, 0.07794584831572138, 0.06729867120156996, 0.057189009385183454, 0.0741224444936961, 0.07899783522589132, 0.03845848965283949, 0.014383847992576193, 0.09946296559064649, 0.13707163307117298, 0.12831647240091115, 0.1627172584994696, 0.127384839579463, 0.11657177019515075, 0.13426978810457513, 0.19759545335546136, 0.16642290574964136, 0.12717705307295546, 0.26913172099739313, 0.3547093929955736, 0.5517487996257842, 9.423621632158756, 111.18766531348228, 90.40841192007065, 76.12962171435356, 72.07564204931259, 36.113702952861786, 57.814277708530426, 102.89502829313278, 108.5130800306797, 97.97350957989693, 20.5419884249568, 0.376310016727075, 0.3859042940894142, 11.909801624715328, 7.3687659949064255, 8.170121144503355, 3.8590833730995655, 2.567558088339865, 2.4677806673571467, 0.9418484545312822, 0.3649368410697207, 7.1626983024179935, 41.33166655898094, 104.63091194629669, 108.84256795048714, 108.55387464165688, 105.64629346132278, 107.8740607202053, 99.25112262368202, 97.27459028363228, 90.13091281056404, 80.3266105055809, 74.4944554567337, 75.61975747346878, 78.40540319681168, 89.49772998690605, 94.74151700735092, 93.54737028479576, 96.05003759264946, 93.45354571938515, 91.7553636431694, 71.64340004324913, 68.26605007052422, 71.09084889292717, 69.66206476092339, 67.63276845216751, 63.18595066666603, 65.47766089439392, 68.86277005076408, 66.02556869387627, 67.08813607692719, 72.22446486353874, 83.38121339678764, 84.93029907345772, 83.88225451111794, 78.7629184126854, 75.48899129033089, 76.16392627358437, 77.94680580496788, 78.95371377468109, 83.79548996686935, 79.84353482723236, 80.30889585614204, 73.13567116856575, 80.33459007740021, 79.45343255996704, 70.85273087024689, 74.58153158426285, 82.4662908911705, 73.19280490279198, 71.47845089435577, 65.61842814087868, 61.940776482224464, 67.233926653862, 65.6161330640316, 65.94657093286514, 63.17788749933243, 61.60881109535694, 66.40514552593231, 63.657718151807785, 68.51033136248589, 72.0993147790432, 74.58419144153595, 70.83391427993774, 69.57038328051567, 62.51835688948631, 61.45824797451496, 67.75968164205551, 74.62439328432083, 76.23911663889885, 80.34866452217102, 77.77303352952003, 78.0499018728733, 75.41202262043953, 78.03035572171211, 78.7556304037571, 70.47155052423477, 68.00238981842995, 75.60297757387161, 78.90498518943787, 74.84631657600403, 69.14607524871826, 59.87791657447815, 60.47687083482742, 61.44206844270229, 64.67073619365692, 75.04211246967316, 81.04680106043816, 80.37491351366043, 79.36460092663765, 81.29883393645287, 75.97332090139389, 71.54345780611038, 69.32663396000862, 66.96384474635124, 64.95779559016228, 65.27532175183296, 70.70964574813843, 76.64327815175056, 81.75416350364685, 82.63010010123253, 83.6697319149971, 79.56731244921684, 88.68952855467796, 84.10192832350731, 91.6827343404293, 68.57739016413689, 2.4719440564513206, 3.3706141216680408, 2.9066583048552275, 1.533246107865125, 1.679773370269686, 5.935631096363068, 9.143110234290361, 6.966471606865525, 1.2862518802285194, 0.30739937850739807, 0.38795561995357275, 29.504130519926548, 69.20165866613388, 93.34176331758499, 105.94813406467438, 72.68556252121925, 103.96776393055916, 78.56491103768349, 68.30068901181221, 49.92377690970898, 71.05721309781075, 78.3742980659008, 94.19984847307205, 33.2391420006752, 0.5682835530024022, 0.3214249009033665, 0.22711488185450435, 0.11173485239851288, 0.23837471671868116, 0.1876484035165049, 0.20254209026461467, 0.12494673603214324, 0.2443870628485456, 0.19682302605360746, 0.15947365754982457, 0.12788871332304552], [0.056344842378166504, 0.060710277466569096, 0.060579236451303586, 0.02485833847458707, 0.030320237383421045, 0.044594982246053405, 0.053287472255760804, 0.08568045202991925, 0.04659970865759533, 0.10193073278060183, 0.13028490036958829, 0.11453454513684846, 0.43218281236477196, 10.248371176421642, 81.60578906536102, 60.273752734065056, 65.91485783457756, 42.91449822485447, 27.991895265877247, 34.171946346759796, 75.81884399056435, 87.14856684207916, 41.15437567234039, 1.6655445587821305, 0.04520867529208772, 3.3709933888167143, 2.014881307259202, 3.5483016120269895, 1.5986183937638998, 1.6130366013385355, 0.2685507677961141, 1.493530876468867, 2.3929379833862185, 0.174332270398736, 17.84188751131296, 54.42294828593731, 89.05699163675308, 96.97646588087082, 94.470956325531, 97.27497786283493, 92.40099459886551, 86.52557507157326, 74.21166703104973, 70.21951004862785, 68.02503660321236, 66.80880546569824, 65.081896930933, 68.09740751981735, 74.84816327691078, 88.03486168384552, 86.02750539779663, 84.36202436685562, 85.06893083453178, 81.8154314160347, 69.6896056830883, 63.365570828318596, 63.578089624643326, 61.2162047624588, 59.01128567755222, 58.961979523301125, 57.72817812860012, 59.64583642780781, 59.355847388505936, 58.390725776553154, 63.97863373160362, 72.51201823353767, 72.70861208438873, 79.92693275213242, 75.64763277769089, 76.28556534647942, 73.7083612382412, 71.71816483139992, 74.18126106262207, 76.50977611541748, 77.0441110432148, 74.29664567112923, 72.28268533945084, 73.48648354411125, 69.28902357816696, 64.80049923062325, 67.69352719187737, 72.08781659603119, 64.47682499885559, 58.03704835474491, 56.60341568291187, 67.14348390698433, 62.8174502402544, 55.73688358068466, 69.47775185108185, 69.60465744137764, 69.05904471874237, 62.6501490175724, 54.859807044267654, 52.96674482524395, 58.319612592458725, 64.02165502309799, 67.17360109090805, 62.423620373010635, 60.40784373879433, 54.123911932110786, 52.4479054659605, 54.276196360588074, 60.55907562375069, 67.0198005437851, 69.22384187579155, 68.0092902481556, 68.3002558350563, 67.9814301431179, 61.82306259870529, 60.93122385442257, 66.76399067044258, 71.11031904816628, 68.33366364240646, 63.06042820215225, 58.242556527256966, 53.3675055205822, 53.956549912691116, 53.76612313091755, 54.88240443170071, 64.26947012543678, 70.28400778770447, 72.67059892416, 74.1891722381115, 73.92836943268776, 74.94455650448799, 71.1228583753109, 67.17695251107216, 63.921310007572174, 56.21285744011402, 59.620176404714584, 59.33984264731407, 67.90103405714035, 71.84328451752663, 80.67470222711563, 77.46634438633919, 81.32271945476532, 76.75099477171898, 82.38920822739601, 75.50651594996452, 84.8424781858921, 57.63770118355751, 1.0631239344365895, 0.4984844452701509, 1.1530690267682076, 1.279863710515201, 0.6981374882161617, 2.656754027120769, 1.592772169969976, 1.2538972101174295, 0.2991691982606426, 0.1192376166000031, 2.959635774604976, 29.068841077387333, 46.37942589819431, 64.05465245246887, 85.86241945624352, 106.04850187897682, 106.17301359772682, 42.91153818368912, 19.382860623300076, 57.47666582465172, 49.20552045106888, 66.71994343400002, 31.26979697495699, 0.09135704312939197, 0.06059914827346802, 0.0557319434301462, 0.02960306668683188, 0.02394223694864195, 0.0299277822705335, 0.0508165769133484, 0.0379220096510835, 0.07400257280096412, 0.018694590507948305, 0.013278488604555605, 0.04097660043044016, 0.013967466966278153, 0.030946964398026466, 0.03913516135071404, 0.020034352601214778, 0.03099186062172521, 0.026219036553811748, 0.11195115133887157, 0.04624115113983862, 0.039558218923048116, 0.061121727849240415, 0.1555256693973206, 0.1645530349924229, 0.5270884791389108, 11.958407666534185, 93.91204431653023, 69.66606974601746, 71.54568448662758, 49.522472843527794, 34.40548561513424, 36.409562677145004, 85.15519380569458, 98.63772913813591, 46.53716683387756, 2.053897138684988, 0.12645892129512504, 4.167186040431261, 3.0771328322589397, 4.116465887054801, 3.2499979063868523, 3.085761219263077, 0.2308354017441161, 4.166889656335115, 2.32754610478878, 0.6612834439147264, 18.52530173957348, 66.43853053450584, 99.15639370679855, 103.30881088972092, 97.46061310172081, 99.07672718167305, 93.64424228668213, 86.9633799791336, 77.61784985661507, 73.0198685824871, 70.19016042351723, 71.02931499481201, 68.05523738265038, 71.14290609955788, 76.93424373865128, 91.20123937726021, 91.24918520450592, 87.8987529873848, 87.43540585041046, 87.21842229366302, 71.71442583203316, 64.83263030648232, 65.58428317308426, 63.20647336542606, 62.73792050778866, 62.50353008508682, 61.24478682875633, 62.332242876291275, 61.90992213785648, 62.912053763866425, 66.6594734787941, 75.73343217372894, 76.42204642295837, 82.3709388077259, 77.6358000934124, 79.89173144102097, 76.16290792822838, 78.44108328223228, 78.34899142384529, 80.15694960951805, 80.13702347874641, 74.4611768424511, 76.29191860556602, 75.953858345747, 70.28332382440567, 68.39019700884819, 71.76433995366096, 73.06899234652519, 68.52721765637398, 60.62200404703617, 61.07125014066696, 69.915039986372, 63.289122730493546, 59.30220566689968, 71.33875519037247, 73.89055386185646, 71.43057346343994, 64.69145268201828, 56.2619736045599, 55.28095744550228, 64.47749376296997, 68.1856843829155, 69.43982228636742, 67.58743688464165, 63.82508397102356, 59.16737750172615, 54.61673028767109, 55.58802656829357, 62.248301580548286, 69.42972242832184, 72.37676069140434, 70.04652053117752, 71.17473319172859, 72.94867560267448, 66.56518533825874, 65.99320963025093, 68.09565961360931, 74.51524034142494, 72.50549778342247, 67.53454372286797, 60.85024639964104, 55.8239559084177, 56.088315322995186, 56.26316674053669, 56.2224405258894, 67.33004629611969, 74.37711775302887, 74.66920807957649, 77.08331733942032, 77.72460892796516, 78.3149528503418, 72.62629330158234, 71.45478576421738, 65.3505577147007, 60.90663157403469, 61.17437280714512, 62.38667495548725, 69.23513486981392, 75.60550063848495, 81.43802806735039, 79.49184089899063, 84.38002020120621, 79.42782193422318, 84.12537306547165, 78.45967188477516, 87.09888070821762, 70.67538678646088, 2.9709216440096498, 0.8861043769866228, 0.8459693274926394, 2.130882195197046, 2.60397557169199, 4.084490602836013, 3.068294981494546, 3.0655933264642954, 1.5402000909671187, 0.4512298246845603, 2.5087887793779373, 32.19084285199642, 52.44264654815197, 71.52506679296494, 87.65893265604973, 106.57535880804062, 96.94253370165825, 50.16753003001213, 24.313029572367668, 63.54154698550701, 56.70615456998348, 77.51041442155838, 39.75776821374893, 0.09913643545587547, 0.05117126042023301, 0.049636094554443844, 0.047313012764789164, 0.045138520072214305, 0.07640117924893275, 0.015657471740269102, 0.060342168508213945, 0.038982308615231887, 0.09144197450950742, 0.024838280078256503, 0.03584891659556888, 0.0865251942013856, 0.12909091834444553, 0.10583262614090927, 0.1518083704286255, 0.11488620439195074, 0.10662041589966975, 0.23772523360094056, 0.22489318856969476, 0.16534363006940112, 0.28278789133764803, 0.24909263534937054, 0.38577943516429514, 0.7217431277967989, 14.178270399570465, 108.33426922559738, 78.85196283459663, 86.10870704054832, 59.806172624230385, 42.11998365819454, 50.67745886743069, 99.751897752285, 101.73330903053284, 62.07579083740711, 3.6808950221166015, 0.16964615700999275, 7.746881805360317, 6.665089828893542, 10.40713805705309, 10.38416638970375, 13.914774488657713, 2.955627227202058, 4.371069325134158, 3.680059779435396, 0.7123312109615654, 22.25286941975355, 73.70901480317116, 107.36617237329483, 105.85870206356049, 105.19393533468246, 103.75520333647728, 100.29703930020332, 92.5634054839611, 80.87922245264053, 77.55079865455627, 75.09979337453842, 73.80093947052956, 72.35520824790001, 74.21814188361168, 82.15574115514755, 95.9167255461216, 92.80979186296463, 90.4537358880043, 90.28151392936707, 90.24128168821335, 75.28539061546326, 68.43358308076859, 70.6871585547924, 66.4926928281784, 65.00082448124886, 65.88547021150589, 65.28558880090714, 65.51508128643036, 65.5997483432293, 65.66489964723587, 69.4979439675808, 78.49257811903954, 79.85621094703674, 83.68635222315788, 81.94387212395668, 82.31771886348724, 82.41437047719955, 80.23702651262283, 79.9497239291668, 83.6854250729084, 82.60653376579285, 78.82794812321663, 81.4293721318245, 82.27816298604012, 75.51688179373741, 71.55759304761887, 76.8868450820446, 81.78129404783249, 72.73932963609695, 64.49853703379631, 62.21464678645134, 71.40333652496338, 65.30668526887894, 60.94678021967411, 70.2727147936821, 77.05069988965988, 74.89298567175865, 68.34206119179726, 60.55953919887543, 60.05753293633461, 69.55100432038307, 72.7821609377861, 73.25824499130249, 71.1055389046669, 67.04538077116013, 63.32837462425232, 59.45675477385521, 59.89919923245907, 68.32145109772682, 75.6097412109375, 76.25580534338951, 75.37445023655891, 75.94402447342873, 76.48424908518791, 68.8123619556427, 65.52534073591232, 67.95203492045403, 77.37945064902306, 75.98927244544029, 70.01793846487999, 65.30597850680351, 59.58021014928818, 59.28736746311188, 59.70754511654377, 60.85735961794853, 71.764195561409, 76.73023268580437, 78.92943307757378, 78.9952227473259, 81.74444362521172, 81.26505374908447, 76.09825059771538, 73.19649830460548, 68.58388021588326, 63.46531167626381, 65.44206440448761, 65.9779192507267, 74.78685736656189, 78.28092947602272, 88.21102783083916, 84.2032840847969, 88.59809026122093, 83.9616246521473, 90.75392737984657, 81.90471142530441, 92.41392150521278, 68.49826321005821, 1.760665092151612, 4.399742111563683, 5.090560717508197, 4.301726846024394, 4.084440255537629, 7.4106368981301785, 7.701213955879211, 3.209662833251059, 1.1704758927226067, 0.267122964723967, 5.013326061889529, 46.25769183039665, 62.76377432048321, 80.25969609618187, 101.80627271533012, 118.73454675078392, 119.09706249833107, 54.099806025624275, 32.54038609564304, 79.78292807936668, 65.81350967288017, 88.27680990099907, 47.004249170422554, 0.27867734315805137, 0.20925831893691793, 0.1622110840980895, 0.29054158309008926, 0.18062434683088213, 0.14292493695393205, 0.11949565392569639, 0.1385114440927282, 0.14427934162085876, 0.16177562152734026, 0.06861196830868721, 0.08962404666817747], [0.04890275245998055, 0.049316106451442465, 0.023357393038168084, 0.08664930355735123, 0.039673652572673745, 0.015960030505084433, 0.010325662042305339, 0.09606315739802085, 0.0140173198087723, 0.08645309455459937, 0.03979285633249674, 0.12037345877615735, 0.3720320400316268, 8.224244490265846, 74.3653079867363, 70.67481681704521, 63.125834092497826, 30.689433217048645, 45.0610638409853, 48.26610065996647, 87.49253958463669, 73.79181995987892, 19.69765093177557, 0.23723709338810295, 0.04280477362044621, 1.504201297648251, 1.3084615697152913, 2.941471799276769, 1.165773645043373, 1.5961098158732057, 1.2105652852915227, 3.1847725063562393, 0.15463743737200275, 10.104001723229885, 65.52588790655136, 95.3614841401577, 97.50659823417664, 97.97624543309212, 94.52935919165611, 89.4587516784668, 78.58334004878998, 69.97260689735413, 70.29232934117317, 71.41083732247353, 67.90149763226509, 66.25067621469498, 65.17302364110947, 65.27982831001282, 70.74308395385742, 81.82324379682541, 84.98632326722145, 86.07101306319237, 84.7543229162693, 83.40157270431519, 74.45863097906113, 61.87295012176037, 62.35785350203514, 59.05230447649956, 58.74159514904022, 59.35451366007328, 58.83769579231739, 58.11444640159607, 56.896448358893394, 61.0947784781456, 66.60500720143318, 73.56443256139755, 75.27271449565887, 72.58266404271126, 69.58777874708176, 76.91921934485435, 71.61165654659271, 78.74110758304596, 73.24306860566139, 76.98098883032799, 74.68854144215584, 70.19950032234192, 69.34875637292862, 67.78628781437874, 62.12981253862381, 66.93805173039436, 68.917927891016, 67.35300466418266, 64.44422274827957, 56.46311201155186, 68.22224602103233, 74.04100298881531, 59.79987636208534, 57.051179856061935, 68.13688740134239, 65.00232920050621, 67.1013517677784, 61.483497619628906, 54.35813136398792, 53.64009149372578, 55.816952884197235, 63.37032437324524, 64.56662937998772, 66.23606219887733, 63.26513081789017, 61.00742496550083, 56.74269340932369, 51.94912903010845, 50.077022686600685, 54.126302003860474, 57.61345088481903, 62.16306075453758, 65.43706387281418, 67.01733067631721, 66.44128158688545, 71.22671440243721, 73.29558938741684, 70.60904994606972, 70.44711783528328, 64.92946431040764, 60.078633204102516, 53.13636772334576, 56.07334792613983, 53.21131110191345, 53.82978491485119, 54.235971719026566, 66.11227244138718, 69.15752023458481, 72.1214371919632, 72.96696782112122, 72.01438933610916, 69.67247620224953, 70.3648978471756, 64.17397364974022, 63.48710350692272, 55.33587209880352, 56.59262426197529, 57.464495077729225, 63.12264986336231, 66.48084506392479, 73.03510576486588, 72.5598880648613, 74.52265754342079, 74.29387181997299, 82.98701494932175, 76.79169818758965, 85.95983102917671, 37.18688316643238, 0.1704181983950548, 1.0436240932904184, 0.5263625993393362, 1.1831622244790196, 2.6100352965295315, 2.6944905146956444, 2.6428676722571254, 0.8947970636654645, 0.16274234309094027, 0.125686879910063, 11.676543541252613, 33.745955005288124, 61.78577899932861, 95.91787308454514, 116.16517782211304, 78.0841988325119, 30.023292861878872, 32.75219053030014, 33.39672714471817, 52.22821645438671, 62.44996435940266, 42.31566175818443, 0.045144305113353767, 0.041709152137627825, 0.026400291280879173, 0.024625142687000334, 0.018845586018869653, 0.04291612916858867, 0.040339830302400514, 0.09525840214337222, 0.10888495336985216, 0.04440100339706987, 0.09263266139896587, 0.020563483485602774, 0.09761771929333918, 0.052113216515863314, 0.03747400107386056, 0.025199262563546654, 0.09241900450433604, 0.058090418242500164, 0.106927108427044, 0.05886033337446861, 0.10486778221093118, 0.06909415649715811, 0.012348405944067053, 0.22062279662350193, 0.5200597469229251, 12.889682594686747, 87.91330620646477, 79.19278934597969, 65.77062517404556, 33.082476407289505, 32.527892366051674, 38.4817510843277, 97.98667967319489, 84.50039014220238, 24.38849162310362, 0.1864666966139339, 0.303625765372999, 4.390976931899786, 2.1421086927875876, 6.348376348614693, 3.2119116000831127, 3.351818430237472, 1.414548670873046, 3.782679922878742, 0.31493238522671163, 14.876935109496117, 77.83085882663727, 101.43136203289032, 102.33053058385849, 102.1333895623684, 97.72392377257347, 92.30968549847603, 81.71533718705177, 72.74224027991295, 73.44448059797287, 73.69934052228928, 70.02730876207352, 69.2977175116539, 67.4348446726799, 67.72851571440697, 75.39550110697746, 84.37425971031189, 87.67131999135017, 87.5638085603714, 86.77731156349182, 88.68855580687523, 77.22881153225899, 64.30546939373016, 63.57127659022808, 62.33597807586193, 62.46735982596874, 61.45780719816685, 61.32961347699165, 60.512657314538956, 61.2314647436142, 64.36524018645287, 70.6558558344841, 76.35819464921951, 78.72986778616905, 78.31844866275787, 73.19821581244469, 78.53462666273117, 73.1575807929039, 82.39157930016518, 76.27035096287727, 78.51162269711494, 74.65807467699051, 75.81281751394272, 71.6969695687294, 71.35570228099823, 67.03055396676064, 72.03155681490898, 71.73989966511726, 71.59553781151772, 66.53512135148048, 58.91700893640518, 71.76920369267464, 76.14100590348244, 60.00695385038853, 61.50206722319126, 70.04810884594917, 69.23721715807915, 70.33190801739693, 64.09853249788284, 56.95225216448307, 57.63296663761139, 58.85629579424858, 66.41093641519547, 67.20251753926277, 70.16579613089561, 66.8415217101574, 63.95079642534256, 60.81159867346287, 57.024391293525696, 52.275375723838806, 57.35603749752045, 59.96158808469772, 62.62179113924503, 68.72444987297058, 71.67925491929054, 72.21555054187775, 74.34750974178314, 76.05304822325706, 74.69516828656197, 74.68066066503525, 67.1632732450962, 62.67382174730301, 55.645483285188675, 56.09139695763588, 55.83839513361454, 55.19657917320728, 57.31542527675629, 66.81455075740814, 72.71528452634811, 74.65210899710655, 72.82392829656601, 74.76478055119514, 74.31389674544334, 74.02638897299767, 67.8062291443348, 66.56979069113731, 58.744574189186096, 60.280611366033554, 60.49430809915066, 65.15464782714844, 69.57320272922516, 75.28128683567047, 74.96078923344612, 77.45279431343079, 75.32385215163231, 87.17673853039742, 79.98485684394836, 86.49807214736938, 48.93105357885361, 0.23924714099848643, 0.439877369790338, 1.518309940584004, 2.9459828697144985, 2.837906456552446, 3.406171901151538, 2.8624398401007056, 4.9235672783106565, 0.333219111780636, 0.32531722798012197, 11.260233130306005, 41.677584797143936, 67.27495685219765, 101.20458260178566, 113.43467473983765, 81.64080798625946, 26.93780902773142, 36.20891824364662, 41.58810339868069, 60.256885439157486, 71.3827796280384, 50.61630114912987, 0.0858721042459365, 0.14690583193441853, 0.024522587154933717, 0.032364436774514616, 0.06624246889259666, 0.1079683713032864, 0.03435706988966558, 0.06652944997767918, 0.0644324003951624, 0.032556070436839946, 0.16334818792529404, 0.04011493358120788, 0.2326086745597422, 0.16185967717319727, 0.13183261966332793, 0.2344897369039245, 0.19087334687355906, 0.1660765751148574, 0.2274426884832792, 0.20518265169812366, 0.2605681383283809, 0.16469757567392662, 0.14916332642314956, 0.333915424416773, 0.7334018521942198, 14.424060210585594, 101.1608849465847, 88.17492216825485, 81.4111179113388, 45.3245835006237, 59.40021000802517, 73.55501666665077, 105.45706361532211, 98.18643495440483, 34.84419487416744, 0.5370565911289304, 0.21903077111346647, 6.842190725728869, 5.604900643229485, 11.221544556319714, 7.936636498197913, 14.407983273267746, 5.965091390535235, 8.906894009560347, 0.9841128741391003, 16.14190813153982, 82.47262135148048, 106.18227750062943, 103.2294787466526, 106.79227396845818, 101.1867007613182, 96.17133468389511, 85.23205608129501, 75.94086304306984, 75.67866951227188, 77.19226509332657, 74.27693992853165, 70.94027817249298, 70.99941819906235, 71.48895353078842, 79.45860028266907, 89.95488345623016, 92.15705528855324, 89.55935508012772, 90.89020326733589, 91.13384619355202, 80.54306969046593, 67.95271888375282, 69.31571334600449, 65.613564401865, 65.16812190413475, 64.3806217610836, 65.714570581913, 64.93279293179512, 63.145642429590225, 68.64165991544724, 72.52530992031097, 83.23774829506874, 83.05974304676056, 80.30420690774918, 76.93968504667282, 81.48478835821152, 77.69046396017075, 83.18955168128014, 78.72675195336342, 83.204355686903, 80.26568457484245, 79.94474619626999, 77.79817298054695, 76.05328381061554, 69.44103822112083, 75.85802748799324, 77.00688824057579, 78.22702556848526, 71.95873752236366, 61.24957077205181, 75.7937653362751, 79.95802268385887, 62.25313492119312, 64.3818224966526, 71.8069888651371, 70.43519407510757, 72.80094712972641, 67.79692724347115, 61.879523769021034, 61.33349686861038, 61.29609167575836, 70.28728321194649, 71.73174530267715, 74.15123507380486, 71.99283689260483, 67.92726024985313, 61.31298556923866, 56.9221805781126, 56.110259145498276, 60.809983760118484, 63.260111287236214, 66.69311687350273, 71.2767805159092, 74.00219187140465, 75.18106341362, 81.36431962251663, 76.66112959384918, 75.8499339222908, 78.98855030536652, 73.12325343489647, 66.32933959364891, 57.97918885946274, 61.52987413108349, 57.649632543325424, 58.6625973880291, 61.2860070168972, 70.32405003905296, 75.71936532855034, 78.5129526257515, 77.5829753279686, 78.40709030628204, 75.77264606952667, 79.07157585024834, 70.94163089990616, 69.36484470963478, 59.45449389517307, 63.245432674884796, 62.5140593200922, 69.56634789705276, 73.27478930354118, 80.61870083212852, 79.76174041628838, 82.47628435492516, 79.12695407867432, 93.52602303028107, 82.42594465613365, 94.65073987841606, 46.22493378818035, 0.469151652068831, 7.536697508767247, 4.3795238714665174, 9.423617832362652, 11.698138732463121, 9.160947427153587, 7.51065893098712, 4.158725794404745, 0.44974867603741586, 0.5033403472043574, 19.416878297924995, 53.34343001246452, 78.02806064486504, 103.99233341217041, 113.32400187849998, 86.82947516441345, 47.06197187304497, 49.09802421927452, 52.71072596311569, 70.90700715780258, 81.12582921981812, 57.749498784542084, 0.2333401353098452, 0.1753573989844881, 0.10024548610090278, 0.1803972347988747, 0.14963448629714549, 0.2159311913419515, 0.1439937186660245, 0.1794556571985595, 0.14248663937905803, 0.10671570766135119, 0.20370524347526953, 0.12450926966266707], [0.011488087020552484, 0.09358589071780443, 0.04708087639301084, 0.03262823687691707, 0.06535014763358049, 0.022073431173339486, 0.029743892919213977, 0.03884675163135398, 0.061523081312770955, 0.06327793031232432, 0.03508550267724786, 0.1815787042141892, 0.49863964319229126, 8.628847729414701, 76.97669506072998, 59.24955949187279, 62.50092342495918, 44.23374563455582, 46.41316048800945, 70.51919996738434, 90.86230516433716, 50.69624125957489, 6.128459824249148, 0.10240844581858255, 0.5479127867147326, 1.6401729639619589, 1.4200668060220778, 1.4488874282687902, 0.5797112616710365, 0.6325069942977279, 0.4676996549824253, 0.22188320086570457, 5.391488894820213, 77.86464661359787, 100.64678773283958, 97.45290711522102, 92.53366827964783, 89.0784452855587, 85.4809883236885, 77.85521551966667, 74.11917239427567, 74.53730955719948, 75.99997267127037, 70.72733759880066, 71.10207349061966, 69.68218088150024, 63.52941423654556, 64.80988472700119, 65.95714956521988, 74.36109781265259, 85.12678653001785, 85.20330682396889, 79.60399568080902, 81.8343847990036, 74.82865512371063, 63.09692904353142, 59.21615168452263, 57.65677236020565, 57.2278817743063, 58.069080635905266, 60.27258239686489, 63.532176688313484, 64.41659063100815, 68.60426992177963, 74.10695225000381, 70.27966842055321, 82.28586137294769, 73.254224807024, 62.0287873595953, 73.83082866668701, 76.96511328220367, 75.46897396445274, 70.80316632986069, 71.4854197204113, 65.32383754849434, 62.19116784632206, 59.57123123109341, 61.31448268890381, 62.372813299298286, 69.10952121019363, 66.774120926857, 61.44613042473793, 58.006832376122475, 59.4580315053463, 72.09701210260391, 69.96541008353233, 60.86049064993858, 60.209539979696274, 64.65822726488113, 69.1211561858654, 69.32993218302727, 61.035649850964546, 54.58455741405487, 58.25901724398136, 56.26812167465687, 60.45778825879097, 64.95030999183655, 64.34935703873634, 65.7256355881691, 63.9555461704731, 59.90131951868534, 57.99629934132099, 53.60146276652813, 51.574780717492104, 51.6245998442173, 54.17039483785629, 59.007428884506226, 63.46095710992813, 66.9231641292572, 62.20854811370373, 71.13304182887077, 71.3235180079937, 73.18303182721138, 67.70973712205887, 65.99244207143784, 58.97959537804127, 52.03444205224514, 53.3454705029726, 53.72029758989811, 53.775637820363045, 57.20024585723877, 66.96618542075157, 76.87026277184486, 72.12942436337471, 72.5612635910511, 76.09760463237762, 72.15841680765152, 64.92751881480217, 64.87938299775124, 60.52751451730728, 56.613063365221024, 56.24527350068092, 56.31678186357021, 59.78043280541897, 60.87234601378441, 61.58619090914726, 61.185183227062225, 67.8972190618515, 72.01385736465454, 76.88831180334091, 81.7235903441906, 73.53876873850822, 8.33145858719945, 1.1307966406457126, 1.7670658486895263, 3.8308682246133685, 3.7589105358347297, 2.51357177272439, 3.5516440076753497, 4.131856486201286, 0.4625713254790753, 0.04276267529348843, 0.932311856886372, 24.346017502248287, 54.63066413998604, 93.02945047616959, 95.2488961815834, 78.12954559922218, 37.18092128634453, 23.47718272358179, 42.11285904049873, 56.63856379687786, 53.83437126874924, 45.94230115413666, 0.14710689458297566, 0.0494994169275742, 0.011189494107384235, 0.0503404966002563, 0.04265560935891699, 0.04982624392141588, 0.05184501176699996, 0.0069029386486363364, 0.06077108162571676, 0.035994284771732055, 0.00589662582569872, 0.04031983684399165, 0.015968223815434612, 0.01017298463921179, 0.029124548418622, 0.03983025315392297, 0.035544149941415526, 0.07510147828725167, 0.06704096784233116, 0.026470286939002108, 0.06102717452449724, 0.06208152146427892, 0.03944712312659249, 0.10023376016761176, 0.5818606400862336, 10.014486126601696, 87.29570254683495, 67.89865538477898, 69.23476248979568, 49.00744087994099, 44.06573764979839, 67.89127618074417, 103.0003434419632, 59.54688213765621, 6.808910211548209, 0.4672665672842413, 1.349873528815806, 6.061673182994127, 2.5838176533579826, 4.358127694576979, 4.08277926966548, 3.5266947839409113, 0.4787502338876948, 0.07428461118252017, 9.654679633677006, 85.69992497563362, 107.18087911605835, 101.31130367517471, 95.6999471783638, 92.87627309560776, 89.92792770266533, 82.37958714365959, 78.92611965537071, 79.78995010256767, 79.92661356925964, 74.06343698501587, 74.85840752720833, 72.31699749827385, 66.38486981391907, 68.63814890384674, 67.85598367452621, 75.67786395549774, 86.87220767140388, 89.23397853970528, 83.56302604079247, 83.63879397511482, 79.0299528837204, 65.38089528679848, 63.39611738920212, 60.4102224111557, 61.19541987776756, 61.08387306332588, 63.68104510009289, 66.39623120427132, 69.05031278729439, 74.24133583903313, 75.81984713673592, 77.14328572154045, 87.10780262947083, 75.44130384922028, 65.53268954157829, 73.52363035082817, 79.06222835183144, 77.10008963942528, 72.60968819260597, 73.84165048599243, 67.33541160821915, 64.81139704585075, 64.05307933688164, 64.42128717899323, 66.37926891446114, 72.35848367214203, 69.85074743628502, 64.56621900200844, 61.277202889323235, 63.11134546995163, 74.36767145991325, 70.24041652679443, 61.679901480674744, 63.44644948840141, 65.29945805668831, 71.28468409180641, 71.77403703331947, 62.53726467490196, 55.96785418689251, 61.08411245048046, 60.2189102768898, 63.591552302241325, 68.43904718756676, 67.63376399874687, 68.69090527296066, 68.82669478654861, 65.12429505586624, 62.36224606633186, 57.71320693194866, 54.352576062083244, 53.09324383735657, 55.986252799630165, 60.531641095876694, 64.17615473270416, 70.87292298674583, 66.05190128087997, 73.31952810287476, 72.71232068538666, 75.23812875151634, 72.56941795349121, 70.06480515003204, 61.53636038303375, 54.505335465073586, 55.54351195693016, 56.37038178741932, 55.596279725432396, 57.253389805555344, 70.65954923629761, 75.92697858810425, 75.85741192102432, 76.08971625566483, 78.68404984474182, 74.60863932967186, 68.61169472336769, 67.65593200922012, 64.58303689956665, 59.912513718008995, 59.47687849402428, 59.848817735910416, 60.35171315073967, 62.88952857255936, 64.20633271336555, 63.2639566808939, 68.44977781176567, 72.22894102334976, 79.90964367985725, 81.9128429889679, 81.0150195658207, 11.825034823268652, 0.8717280859127641, 0.7622149342205375, 3.1649767560884356, 1.7016204167157412, 3.167025321163237, 3.991952743381262, 6.012681936845183, 1.0441197291947901, 0.10150194953894243, 0.8160443301312625, 27.284363731741905, 63.12249407172203, 98.96685987710953, 102.93296545743942, 84.37888026237488, 46.811804696917534, 30.14859303832054, 46.01271517574787, 64.32646706700325, 61.93339727818966, 55.62496438622475, 0.17499931273050606, 0.05533836767426692, 0.007989552777871722, 0.022793947100581136, 0.042316941398894414, 0.03721618268173188, 0.02404400765954051, 0.07186405942775309, 0.0856788935197983, 0.02396299852989614, 0.04402659360493999, 0.09757135732797906, 0.11999423615634441, 0.08791159285465255, 0.13177381188143045, 0.16719083563657477, 0.08747638261411339, 0.24386815319303423, 0.10063472029287368, 0.278681677300483, 0.24195850332034752, 0.1552889688173309, 0.13601656624814495, 0.28517140250187367, 0.8600840857252479, 11.600022297352552, 101.98503032326698, 79.20359596610069, 80.88946670293808, 66.20123326778412, 65.17297804355621, 99.51722234487534, 106.57115623354912, 72.36143231391907, 9.629372991621494, 0.6382977054454386, 2.1302668657153845, 8.380087427794933, 5.857922416180372, 7.822627890855074, 9.483869299292564, 9.525281377136707, 4.645634992048144, 0.4268528561806306, 8.941448405385017, 90.50516992807388, 111.6703762114048, 106.2187859416008, 100.21079912781715, 95.85622519254684, 94.30258736014366, 86.82391226291656, 80.43384075164795, 83.23156222701073, 83.5704280436039, 78.2520966231823, 78.86474534869194, 75.59328809380531, 69.98001649975777, 72.50110521912575, 73.25360924005508, 78.9268796145916, 94.56592842936516, 92.51017034053802, 87.56164267659187, 87.33123064041138, 80.50572529435158, 68.43672931194305, 66.0872469842434, 63.690107613801956, 66.16062104701996, 64.04870197176933, 66.44796922802925, 70.17671674489975, 70.45728608965874, 77.7219870686531, 82.83081293106079, 79.80980023741722, 83.84415775537491, 82.75718048214912, 68.1855171918869, 74.14368867874146, 83.45565900206566, 82.12798744440079, 78.1010851264, 78.0521285533905, 72.34384685754776, 68.16362276673317, 68.3651639521122, 68.84113401174545, 68.168965280056, 75.78877240419388, 77.48161196708679, 70.01816645264626, 65.04407376050949, 64.29163053631783, 78.3892160654068, 72.59254351258278, 63.0686167627573, 66.55465990304947, 69.78502616286278, 74.63789775967598, 74.94935184717178, 63.18122372031212, 57.95734763145447, 63.43888409435749, 63.18636104464531, 67.551209628582, 71.45299226045609, 72.38566741347313, 73.35085362195969, 71.40881583094597, 67.41814836859703, 65.10541006922722, 60.00489056110382, 58.161537274718285, 57.44338721036911, 59.66250993311405, 64.94654059410095, 70.57990550994873, 76.27220526337624, 69.75563853979111, 77.12380036711693, 76.4952152967453, 77.81672358512878, 74.50925946235657, 75.88014230132103, 65.51904067397118, 58.90259250998497, 60.37721738219261, 59.9316380918026, 59.6100689470768, 62.709954008460045, 75.14452457427979, 82.03163981437683, 80.17716452479362, 80.1364079117775, 82.46600210666656, 77.03671663999557, 70.98176434636116, 70.67079663276672, 66.45357772707939, 62.80811034142971, 61.844356656074524, 63.04960638284683, 63.89129921793938, 66.751998513937, 70.35532996058464, 66.73052966594696, 73.81786376237869, 78.44166085124016, 84.11829024553299, 88.31125125288963, 83.23849305510521, 11.639866959303617, 2.90965111926198, 7.734011895954609, 10.182516910135746, 10.196657851338387, 10.14033917337656, 14.316370189189911, 11.903156731277704, 0.9580745932180434, 0.13950054883025587, 1.9988516299054027, 39.86242599785328, 71.29930570721626, 106.73410668969154, 102.88004949688911, 96.62636026740074, 53.96873585879803, 36.33588083088398, 58.674179166555405, 72.86569565534592, 72.58093133568764, 64.0837436914444, 0.3016856132308021, 0.2047726744785905, 0.17898985563078895, 0.15717543399659917, 0.1724323575035669, 0.15891954040853307, 0.1634762529283762, 0.15186607983196154, 0.1643549557775259, 0.21681125974282622, 0.0797322423022706, 0.18008081271545961], [0.028762207803083584, 0.028679766328423284, 0.03553157424903475, 0.01810030276828911, 0.07487467795726843, 0.08627405884908512, 0.02353199255594518, 0.09909736138070002, 0.04085063570528291, 0.005930879187872051, 0.07756181657896377, 0.07466049413778819, 0.14838665403658524, 5.097532393410802, 71.6502396762371, 65.33805638551712, 59.02230128645897, 44.534545093774796, 30.50784856081009, 64.10091876983643, 83.775974214077, 32.37928234040737, 0.9341029264032841, 0.06871144578326494, 0.7833019620738924, 3.4452737029641867, 0.3014466416789219, 3.5626194812357426, 0.8084135677199811, 1.0099552874453366, 1.1373622133396566, 1.588153992779553, 59.746660217642784, 98.21588337421417, 87.06710681319237, 93.68328139185905, 91.98778957128525, 91.17090940475464, 82.54708215594292, 86.1411041021347, 84.79250326752663, 88.7915150821209, 82.19696134328842, 87.99623295664787, 78.84981215000153, 71.98486492037773, 62.38496124744415, 65.01709520816803, 64.20553475618362, 67.11186200380325, 73.00241991877556, 79.30435135960579, 78.86308863759041, 76.24540910124779, 73.91712203621864, 61.60574845969677, 55.84034062922001, 58.687934428453445, 60.396736934781075, 57.73927353322506, 63.07087764143944, 74.28080052137375, 74.34853568673134, 75.20690202713013, 72.56901517510414, 84.54691484570503, 74.18297097086906, 63.81519690155983, 74.8347955942154, 74.01462480425835, 74.82822194695473, 70.88864654302597, 68.49846079945564, 59.87442076206207, 55.16774632036686, 57.33750209212303, 57.7179566770792, 64.1418045759201, 67.53831312060356, 67.99423545598984, 60.77255956828594, 58.769295662641525, 63.099360913038254, 68.0867300927639, 74.03020396828651, 63.896922916173935, 56.45297795534134, 55.51409013569355, 59.48137365281582, 58.772844672203064, 55.57224601507187, 55.02197474241257, 51.98222145438194, 56.93240202963352, 50.15993803739548, 54.68215897679329, 58.42600308358669, 61.18410788476467, 65.29277801513672, 63.77291277050972, 63.87359976768494, 62.1171098202467, 55.59458501636982, 54.1655158996582, 50.6490857899189, 50.405708849430084, 52.26220183074474, 56.9680555164814, 64.00042936205864, 64.01518777012825, 68.08636531233788, 68.7989790737629, 66.60692229866982, 71.59591019153595, 66.99693337082863, 62.91698209941387, 55.9234269708395, 51.83758221566677, 50.46761132776737, 53.05218704044819, 53.40079553425312, 57.4935407191515, 65.78381046652794, 71.38958126306534, 73.26976597309113, 73.57563436031342, 72.29382634162903, 71.15236759185791, 66.19653671979904, 62.30092115700245, 59.60125342011452, 59.10784229636192, 61.52471020817757, 62.64520928263664, 59.48172703385353, 61.63756035268307, 62.65359163284302, 68.85517805814743, 66.54824584722519, 83.50308805704117, 74.17404904961586, 88.15504923462868, 21.29157230257988, 0.24708303302759305, 0.8139056980144233, 2.4562831968069077, 1.2159525649622083, 2.064728457480669, 2.617578129284084, 7.3195011634379625, 0.9494847385212779, 0.17653604823863134, 0.17073591181542724, 9.67824786901474, 34.8744298517704, 65.86690440773964, 75.77091336250305, 37.013806253671646, 29.15119405835867, 38.49754683673382, 43.02385255694389, 53.58776830136776, 56.56183451414108, 52.59533375501633, 0.44441304984502494, 0.07763789413729683, 0.018388556636637077, 0.02421228593448177, 0.07055164547637105, 0.011760534998757066, 0.03759206192626152, 0.06450709013734013, 0.024573385308030993, 0.05791838470031507, 0.05550820817006752, 0.03473412543826271, 0.015885689572314732, 0.021837890199094545, 0.04254548577591777, 0.02964432267617667, 0.017187813646160066, 0.07109343554475345, 0.1066310954047367, 0.07216448080725968, 0.0836778778466396, 0.03718579915584996, 0.04018023515527602, 0.12201626945170574, 0.47036022471729666, 7.071778681129217, 85.46866938471794, 75.27117937803268, 69.04990240931511, 49.09907676279545, 26.62289522588253, 66.1264380812645, 93.68054553866386, 37.48259849846363, 0.7100464648101479, 0.13261252781376243, 3.332618772983551, 6.480072056874633, 1.9464897271245718, 9.398940056562424, 3.992014490067959, 1.5080728149041533, 0.285077357548289, 2.8658648813143373, 69.18277367949486, 101.05177760124207, 95.5335085093975, 97.8579805791378, 95.8774508535862, 92.97378346323967, 87.96182200312614, 88.9036014676094, 89.95230719447136, 90.60355424880981, 87.44737520813942, 87.29586213827133, 83.11030313372612, 76.04812368750572, 68.18995535373688, 69.2184765636921, 67.06953227519989, 68.35289061069489, 75.3223018348217, 83.49547326564789, 82.06338331103325, 79.4654931128025, 74.99331548810005, 64.381472915411, 60.06863594055176, 60.25240547955036, 60.197080448269844, 60.74637897312641, 66.13256335258484, 77.81728595495224, 78.75173181295395, 79.63955417275429, 74.48937132954597, 91.68252915143967, 78.08172896504402, 68.34498703479767, 79.23446550965309, 77.3017068207264, 79.35655295848846, 73.49251002073288, 68.984295129776, 62.38275736570358, 59.312259927392006, 59.67676296830177, 62.86062732338905, 68.09217900037766, 71.55690908432007, 72.1909050643444, 65.49082338809967, 62.37811021506786, 67.94638842344284, 70.51872119307518, 75.9239387512207, 65.80097034573555, 58.52923974394798, 59.031378999352455, 60.730716213583946, 57.70434580743313, 57.46320694684982, 55.931235551834106, 54.00193467736244, 57.172879725694656, 53.24936605989933, 58.524379804730415, 61.41085311770439, 66.08214005827904, 67.20902279019356, 69.0610434114933, 66.54775947332382, 64.96459722518921, 59.351644814014435, 55.922932997345924, 54.005179703235626, 52.82661974430084, 53.77100586891174, 58.59963096678257, 66.2694776058197, 66.82245433330536, 70.81815272569656, 70.90174823999405, 70.23407846689224, 73.44728484749794, 69.56042021512985, 66.63434162735939, 57.91132070124149, 55.57747073471546, 53.11576522886753, 55.4347237944603, 55.77385559678078, 59.43820416927338, 70.45466423034668, 74.91303339600563, 75.09758189320564, 75.02579614520073, 74.79282304644585, 74.45264250040054, 68.58236789703369, 65.06936520338058, 62.95481286942959, 62.867611348629, 63.89677092432976, 66.44025564193726, 62.03183859586716, 64.73874494433403, 65.80939069390297, 72.97125399112701, 71.96478679776192, 86.86852186918259, 76.9804036617279, 91.51694923639297, 28.279513232409954, 0.15311466908315197, 0.132243680418469, 0.9632284822873771, 3.3193332608789206, 1.8580988701432943, 4.035730669274926, 3.736690040677786, 2.949851774610579, 0.8684654859825969, 0.25126071588601917, 9.494610372930765, 43.62006336450577, 69.46692243218422, 85.00301197171211, 43.37479792535305, 28.70678700506687, 31.187700480222702, 48.44531424343586, 61.051058024168015, 66.0617807507515, 62.64503449201584, 0.7985139708034694, 0.1275185152189806, 0.058632375294109806, 0.0722515644156374, 0.07537527882959694, 0.09953432308975607, 0.050095847618649714, 0.05456188453536015, 0.043362063443055376, 0.057672852562973276, 0.025150540568574797, 0.03839338845864404, 0.16495277057401836, 0.17748139594914392, 0.2151751655037515, 0.10559093090705574, 0.13131249288562685, 0.20172991353319958, 0.2736371214268729, 0.20894617162412032, 0.20697854517493397, 0.11905510764336213, 0.17915903561515734, 0.2528174448525533, 0.5536584940273315, 8.989495877176523, 97.62065291404724, 84.27386149764061, 80.62156587839127, 57.983961403369904, 46.861851811409, 80.28231248259544, 101.98276564478874, 51.4266000688076, 1.7101222230121493, 0.29482318146619946, 3.41266100294888, 12.11312111467123, 4.607772398740053, 14.784910697489977, 9.247954208403826, 11.452849544584751, 5.955129275098443, 3.1152642611414194, 75.07819533348083, 107.64016807079315, 100.2285897731781, 103.36321637034416, 98.2859668135643, 95.35507768392563, 89.21019181609154, 92.97502979636192, 92.56287351250648, 96.54724851250648, 89.76318374276161, 92.5145173072815, 87.69803255796432, 80.54299369454384, 69.39412593841553, 72.24238470196724, 70.56790575385094, 71.23599350452423, 79.6250769495964, 87.22983688116074, 84.61706668138504, 82.53766626119614, 80.93162164092064, 66.08764216303825, 63.00864078104496, 63.72077576816082, 65.46538755297661, 65.30738443136215, 69.68227967619896, 81.07566431164742, 80.81886649131775, 80.90848848223686, 80.66136494278908, 87.22501114010811, 80.95323488116264, 75.83213567733765, 79.47993233799934, 83.3876122534275, 85.48027396202087, 78.30739125609398, 74.86452519893646, 65.92580884695053, 62.48810671269894, 64.3234272301197, 64.67639788985252, 71.685129404068, 76.01403951644897, 76.16977035999298, 70.18253803253174, 66.6967798769474, 67.61232554912567, 74.7018863260746, 78.21826323866844, 67.67532616853714, 58.00104148685932, 63.99796709418297, 67.29979231953621, 63.49247641861439, 60.53418695926666, 58.71151976287365, 54.24315333366394, 59.14998583495617, 54.36533197760582, 62.92876146733761, 65.66465646028519, 69.02935311198235, 74.56587642431259, 71.8044202029705, 71.3384436070919, 69.5924524962902, 62.55819775164127, 60.60980670154095, 57.200405448675156, 56.65218986570835, 57.36584097146988, 62.17935808002949, 72.03930839896202, 71.1690790951252, 75.43650090694427, 74.62216660380363, 73.2694011926651, 74.97275099158287, 74.1480964422226, 70.74506744742393, 61.15712933242321, 57.76370622217655, 57.00063116848469, 59.53124597668648, 60.457750260829926, 62.85231716930866, 74.56542044878006, 77.09214046597481, 78.17069739103317, 79.4943867623806, 79.84738782048225, 76.66641131043434, 71.75752311944962, 68.74742344021797, 65.8411417901516, 65.82990199327469, 66.78269326686859, 68.34436386823654, 66.97578370571136, 66.91314786672592, 68.81257474422455, 76.64865106344223, 73.3247946202755, 92.21754804253578, 80.05745574831963, 96.78497895598412, 30.335286520421505, 0.27112272509839386, 6.079897005110979, 7.151482729241252, 8.5284305177629, 7.765646148473024, 9.873781576752663, 15.921532306820154, 4.617926403880119, 0.7002034492325038, 0.43422656832262874, 15.884024519473314, 55.401878356933594, 79.26006093621254, 90.39613857865334, 52.604464665055275, 41.63645200431347, 51.130056381225586, 61.61895275115967, 70.5074205994606, 77.16948911547661, 73.87548387050629, 1.1600203975103796, 0.22235333657590672, 0.2925010904436931, 0.10294297768268734, 0.17207047145348042, 0.15126382699236274, 0.17092084017349407, 0.15493380662519485, 0.10647710718330927, 0.08437770084128715, 0.1848070466076024, 0.13808420451823622], [0.12027723190840334, 0.07178260129876435, 0.0376114097161917, 0.07939443894429132, 0.009959423296095338, 0.03706880328536499, 0.04157374729402363, 0.049322967606713064, 0.046868329009157605, 0.0810143246781081, 0.029627034346049186, 0.039161444510682486, 0.19627386645879596, 4.22083773650229, 63.46730276942253, 58.48177649080753, 60.59805013239384, 56.99983321130276, 54.554873406887054, 80.78670501708984, 70.48148319125175, 14.023406859487295, 0.11743617928004824, 0.20883323159068823, 2.6881462801247835, 5.219034673646092, 1.7319729505106807, 2.6140343444421887, 2.7609976334497333, 1.251577315852046, 0.3051872440846637, 39.71234545111656, 84.63625565171242, 64.5328263938427, 87.71827027201653, 93.35843682289124, 96.14492610096931, 92.7227233350277, 93.83671715855598, 90.97860172390938, 90.96363052725792, 86.99403673410416, 88.18657234311104, 87.8524562716484, 86.55700698494911, 80.93925923109055, 67.42697909474373, 61.852359026670456, 64.51399460434914, 61.87314011156559, 70.49968421459198, 73.66756662726402, 74.59574282169342, 72.95338734984398, 70.56700900197029, 59.4143832474947, 57.68629677593708, 57.38570250570774, 58.2059682905674, 56.04161202907562, 73.15787717700005, 79.10888224840164, 78.95151749253273, 77.78140068054199, 80.1731139421463, 71.1954116821289, 56.05714179575443, 71.06895446777344, 72.00470745563507, 71.91347435116768, 68.22671458125114, 61.58388823270798, 54.87910620868206, 53.533560410141945, 56.45753011107445, 58.14516395330429, 62.2141870111227, 64.20110419392586, 66.893320530653, 63.984561413526535, 57.367809265851974, 62.815633937716484, 69.04269799590111, 73.00007164478302, 70.02616882324219, 59.10463146865368, 58.72945860028267, 55.78170217573643, 49.905682280659676, 53.50542671978474, 52.55952067673206, 55.96871294081211, 54.21168342232704, 55.77895112335682, 49.83887426555157, 54.05298873782158, 55.91629855334759, 58.51020656526089, 62.88684971630573, 64.51638087630272, 63.99830147624016, 60.67513279616833, 56.92828685045242, 53.93833369016647, 51.53315395116806, 51.679518297314644, 52.029859498143196, 49.561413154006004, 53.39523263275623, 60.15557907521725, 62.176037058234215, 70.09530991315842, 67.84732773900032, 68.04735660552979, 67.80238375067711, 67.13741183280945, 60.602378100156784, 53.50168012082577, 49.87353600561619, 53.109328374266624, 51.367099061608315, 54.08989995718002, 63.04269075393677, 69.23458769917488, 70.7167361676693, 73.13431844115257, 73.8355328142643, 70.01850843429565, 65.7222917675972, 65.87692826986313, 61.82221904397011, 65.88092565536499, 66.32214277982712, 67.76705324649811, 68.46068322658539, 71.35515511035919, 69.74584266543388, 73.82689967751503, 75.7711261510849, 76.75663366913795, 77.7928152680397, 82.85086065530777, 60.05979761481285, 0.5358342442195863, 1.423991045448929, 0.5951424711383879, 1.345447360072285, 0.8428500511217862, 1.9737119413912296, 3.8677609199658036, 2.358891572803259, 0.4672331112669781, 0.04241368777002208, 1.2649376364424825, 27.52829734236002, 31.642640568315983, 77.94528588652611, 45.49471937119961, 48.46957594156265, 43.87724496424198, 36.73854902386665, 53.72868373990059, 49.9809904396534, 50.51717586815357, 0.8259708224795759, 0.03343865471833851, 0.06773969987989403, 0.029546704281528946, 0.10085606583743356, 0.05882178622414358, 0.061299294102354906, 0.03079782796703512, 0.02137148563633673, 0.026386984573036898, 0.11930798704270273, 0.029002463270444423, 0.07376828420092352, 0.08556981265428476, 0.07826890519936569, 0.0848802832479123, 0.014405953788809711, 0.016969707576208748, 0.0752810706035234, 0.013017679357290035, 0.035438653649180196, 0.009233657601726009, 0.0602279334270861, 0.009288884521083673, 0.15057932934723794, 6.4337116945534945, 74.10309925675392, 66.34809538722038, 68.63346755504608, 61.719974130392075, 41.72776110470295, 89.08267065882683, 80.87193444371223, 15.37841035053134, 0.06366038869600743, 1.2337676715105772, 4.309534002095461, 4.938238291069865, 3.1329197762534022, 2.318059913814068, 2.7355627482756972, 0.4696790222078562, 0.8179489779286087, 49.86456848680973, 87.22064897418022, 76.69886916875839, 94.09515649080276, 97.2111564874649, 100.33846467733383, 95.26281103491783, 96.76631435751915, 95.92390716075897, 91.64994210004807, 91.72013953328133, 89.26657319068909, 88.77142176032066, 90.338564068079, 85.47965839505196, 71.70979008078575, 64.0842604637146, 65.55421158671379, 65.54421052336693, 72.10379093885422, 76.237011551857, 78.69865626096725, 76.82704389095306, 72.64995083212852, 60.64794525504112, 59.701598435640335, 59.1344902664423, 59.81245368719101, 57.128038331866264, 75.51397114992142, 80.593720972538, 80.28813377022743, 78.70749458670616, 83.25217232108116, 79.54689994454384, 62.806715816259384, 77.1435897052288, 75.80894932150841, 75.01207888126373, 71.91836848855019, 64.98684883117676, 56.69192813336849, 57.07058921456337, 61.192102655768394, 64.02324333786964, 64.088896214962, 69.89632979035378, 71.1864897608757, 66.41064003109932, 62.29546844959259, 65.3956612944603, 70.40587484836578, 74.99454662203789, 70.45505940914154, 59.028943330049515, 58.58448497951031, 56.58752493560314, 51.63401573896408, 55.02530336380005, 53.30748774111271, 59.23292018473148, 57.783457562327385, 57.816796973347664, 52.24197171628475, 58.4814915060997, 59.623512625694275, 62.3441856354475, 67.50925227999687, 68.54529708623886, 66.82563096284866, 61.92443735897541, 59.17122669517994, 56.63515157997608, 55.46209752559662, 56.45227499306202, 54.69293899834156, 53.48071664571762, 56.30229324102402, 63.0228216201067, 65.43601512908936, 72.42330819368362, 70.48530578613281, 71.04924872517586, 70.3324855864048, 70.07354468107224, 63.68530847132206, 56.82368606328964, 52.5711290538311, 55.746181681752205, 55.238984897732735, 56.204611882567406, 67.0967236161232, 72.02352404594421, 74.09290820360184, 76.2752602994442, 75.81664770841599, 72.97444581985474, 68.80505114793777, 69.24520432949066, 67.01170697808266, 69.71579387784004, 70.25404259562492, 69.67926263809204, 72.37573474645615, 74.31772693991661, 75.36224529147148, 76.40823796391487, 77.65799850225449, 78.88114526867867, 84.31217104196548, 82.2054272890091, 68.61481055617332, 2.6038592029362917, 1.1098068044520915, 0.4682817659340799, 1.6404870408587158, 3.1743513280525804, 4.040518412366509, 6.224344354122877, 2.195347398519516, 2.319725174456835, 0.10595590429147705, 0.8025754778645933, 31.052893213927746, 38.21880139410496, 86.63358047604561, 56.412156745791435, 40.064685344696045, 46.50808319449425, 46.30342997610569, 60.908649265766144, 58.75835984945297, 61.321075335145, 2.0306749222800136, 0.21715686307288706, 0.1259778463281691, 0.07830460992408916, 0.06235454275156371, 0.08680794504471123, 0.07938324735732749, 0.04465743026230484, 0.03171199990902096, 0.05262364342343062, 0.1057371636852622, 0.03547485561284702, 0.2009615532006137, 0.17227923759492114, 0.14659834530903026, 0.15449353493750095, 0.14350563782500103, 0.14606428099796176, 0.2829692425439134, 0.16765880427556112, 0.2081044574151747, 0.13342042977456003, 0.1341888791648671, 0.1532200540532358, 0.3393804811639711, 7.967523615807295, 90.74844047427177, 74.92007821798325, 79.86446410417557, 69.68864053487778, 83.30986842513084, 103.64947780966759, 92.34973534941673, 22.74518810212612, 0.343039536383003, 0.8733611670322716, 5.863522840663791, 11.844124998897314, 6.057366114109755, 11.989463400095701, 14.533646330237389, 6.593365352600813, 0.7167028763797134, 50.06110914051533, 91.24116003513336, 80.45828104019165, 96.7436371743679, 99.31411564350128, 102.09511041641235, 99.36571687459946, 100.32961115241051, 99.43962290883064, 95.01729860901833, 95.16724616289139, 95.36898493766785, 93.62920269370079, 93.18903431296349, 86.47693768143654, 74.7673112154007, 66.78400039672852, 70.33236399292946, 67.0165479183197, 76.31652608513832, 78.90774384140968, 83.47697585821152, 79.75791022181511, 77.97502309083939, 64.57997426390648, 61.40609957277775, 61.58070780336857, 63.33523325622082, 60.286957025527954, 81.61335825920105, 83.91134575009346, 84.16174471378326, 84.77900639176369, 87.26705968379974, 75.87029322981834, 67.72115930914879, 78.90982612967491, 80.76118558645248, 78.92399176955223, 75.5402809381485, 71.29911571741104, 59.94228132069111, 59.47521798312664, 64.37939062714577, 65.30984669923782, 68.17627608776093, 74.27363410592079, 74.71771627664566, 71.39408022165298, 66.18550971150398, 67.19598948955536, 73.78796696662903, 78.54851111769676, 74.46132883429527, 60.875268056988716, 60.47870613634586, 57.306978330016136, 51.01301126182079, 54.863177463412285, 54.35919530689716, 57.87920102477074, 57.918730303645134, 59.199820160865784, 53.11011113226414, 62.770632952451706, 63.41606631875038, 67.4563667178154, 71.06612741947174, 72.26209804415703, 70.29968574643135, 64.75843548774719, 64.51858475804329, 60.38783401250839, 59.386887922883034, 58.10976505279541, 58.36839437484741, 55.895278081297874, 58.98700498044491, 65.60345694422722, 68.92722979187965, 76.94486796855927, 73.24914827942848, 74.2871005833149, 72.17501431703568, 73.94031599164009, 67.7572725713253, 59.50823061168194, 54.16197068989277, 58.546323627233505, 57.85280384123325, 58.924068957567215, 71.69190064072609, 75.25190681219101, 76.12662747502327, 78.15569579601288, 80.39236977696419, 76.63841441273689, 72.69883900880814, 72.3625722527504, 68.87184396386147, 71.09890446066856, 71.51169151067734, 72.59643450379372, 74.7968964278698, 77.35570192337036, 76.62398278713226, 80.42888581752777, 83.9315302670002, 83.4783285856247, 87.07824021577835, 89.99374017119408, 68.12795028090477, 2.3976566176861525, 2.843317841179669, 5.831638751551509, 4.257111540064216, 9.2568713799119, 7.683728244155645, 11.321337651461363, 8.042624685913324, 2.5265003414824605, 0.18440524785546586, 1.633967540692538, 45.21261490881443, 50.17074465751648, 99.02770221233368, 64.3284809589386, 69.66600134968758, 57.88812294602394, 50.02213083207607, 71.10681563615799, 69.1961869597435, 76.87431335449219, 2.7257732860744, 0.37923482072073966, 0.2777159947436303, 0.14755037234863266, 0.3186709393048659, 0.16147338930750266, 0.17274070502026007, 0.10169611021410674, 0.10332338773878291, 0.17010950949043036, 0.2152703088358976, 0.15432199492352083], [0.0071236644998862175, 0.03846194435027428, 0.03177642203809228, 0.02783576444926439, 0.029647159535670653, 0.03399762550543528, 0.10656073238351382, 0.09009698027512059, 0.04726225357444491, 0.044044238165952265, 0.03918569418601692, 0.06583269947441295, 0.04962015322234947, 3.0244918819516897, 60.74412949383259, 58.62195856869221, 58.10149289667606, 22.4332894384861, 44.80127938091755, 82.92132407426834, 42.13007211685181, 2.8446427825838327, 0.026646380028978456, 0.22260390047449619, 5.596296954900026, 4.474334008991718, 0.9689618996344507, 8.85264242067933, 3.022512188181281, 1.3980979286134243, 57.03049756586552, 97.19998508691788, 71.32190689444542, 88.74382004141808, 94.82778757810593, 95.91352611780167, 92.49196171760559, 93.41167196631432, 92.14782938361168, 90.01310393214226, 92.66307413578033, 94.62270498275757, 88.72947201132774, 89.12148177623749, 85.14726743102074, 85.523432046175, 71.85845330357552, 60.278335288167, 63.27439472079277, 61.81047387421131, 64.38287883996964, 67.39807784557343, 70.24277240037918, 68.51777896285057, 64.83488738536835, 58.54209065437317, 58.88261318206787, 57.620161324739456, 56.464491337537766, 56.70556180179119, 73.13612714409828, 77.30478465557098, 78.45287784934044, 71.59771889448166, 76.65198728442192, 56.58685237169266, 67.29179754853249, 74.50751915574074, 69.88546997308731, 68.69209840893745, 57.688804641366005, 57.07924135029316, 55.92203624546528, 63.22902135550976, 63.91677305102348, 66.54851943254471, 67.1525426208973, 67.11827605962753, 65.0942462682724, 62.7886363863945, 59.59867335855961, 69.17617723345757, 71.77298828959465, 70.08271738886833, 67.62884706258774, 59.46767918765545, 52.03120842576027, 58.22774112224579, 55.304234996438026, 57.24945321679115, 56.32649414241314, 53.28746281564236, 61.376119181513786, 62.13319815695286, 54.88072872161865, 53.444344997406006, 55.92555485665798, 53.43471251428127, 58.1606063246727, 63.12276005744934, 65.4165069758892, 61.56607858836651, 56.7502474039793, 52.89374314248562, 53.090849965810776, 57.516195103526115, 60.84175005555153, 53.17961700260639, 53.40198487043381, 55.87861977517605, 60.16816399991512, 66.65301382541656, 68.38109269738197, 68.521578758955, 64.86992910504341, 65.55021420121193, 65.6202520430088, 56.505206152796745, 51.13056555390358, 52.91980214416981, 54.77682709693909, 52.32730373740196, 59.38502602279186, 67.57351443171501, 70.78873470425606, 72.09103882312775, 74.02327314019203, 73.13759386539459, 69.49208468198776, 66.00736767053604, 69.2774797976017, 68.77346724271774, 70.93041390180588, 73.3524951338768, 76.19785085320473, 74.85925868153572, 75.86540669202805, 74.61972713470459, 80.19928693771362, 76.78527653217316, 83.0238425731659, 67.94859230518341, 70.31202748417854, 47.61520318686962, 1.2920224643312395, 1.29044079920277, 2.528381240554154, 0.3658381348941475, 1.4733875636011362, 1.0050765867345035, 1.9194794702343643, 2.9370075138285756, 0.09553165349643677, 0.20458409475395456, 17.9471817612648, 25.207864455878735, 55.90157054364681, 69.8571614921093, 24.09653428941965, 24.080603644251823, 24.167113602161407, 43.1878175586462, 52.47223936021328, 48.242439329624176, 1.5450551616959274, 0.028931222659593914, 0.05525036380277015, 0.026359853509347886, 0.05874219088582322, 0.016542909579584375, 0.0263341993195354, 0.08853778737829998, 0.042352297314209864, 0.024060592804744374, 0.04006637856946327, 0.0042815042161237216, 0.017446897400077432, 0.08011617755983025, 0.0428393465699628, 0.03979033303039614, 0.027637514540401753, 0.05681621376425028, 0.06544129821122624, 0.07546295615611598, 0.046728968518436886, 0.06396084718289785, 0.046380207350011915, 0.14262181415688246, 0.11581481667235494, 4.323860183358192, 72.53824442625046, 68.0169278383255, 67.57020860910416, 36.27662681043148, 49.23222541809082, 90.3644634783268, 49.30330440402031, 2.629008390940726, 0.07878006683313288, 1.357919240836054, 5.5826732609421015, 6.2034431006759405, 1.5650927927345037, 3.5504765203222632, 1.283000917173922, 3.0387081066146493, 71.86886474490166, 98.16011756658554, 85.28911381959915, 94.68197420239449, 94.80398565530777, 97.44224488735199, 96.72212272882462, 97.24487587809563, 93.36138546466827, 91.16151630878448, 97.49510765075684, 96.03088662028313, 92.8666140139103, 91.29087656736374, 88.84520620107651, 88.92247125506401, 75.41940942406654, 62.61472351849079, 67.61528939008713, 64.11682471632957, 67.55196198821068, 70.46132907271385, 73.62556368112564, 71.79788455367088, 67.48077660799026, 61.56147323548794, 60.060238391160965, 59.98042367398739, 59.694884195923805, 60.16893535852432, 78.04024279117584, 78.2466173171997, 79.56320106983185, 73.31885933876038, 76.61879226565361, 64.61101099848747, 70.73688268661499, 76.43131792545319, 73.44807520508766, 70.53833574056625, 61.12464867532253, 60.663015246391296, 58.87432962656021, 68.22549104690552, 70.38689866662025, 71.01034641265869, 69.93158429861069, 69.98229637742043, 69.03748467564583, 65.52348643541336, 64.19485732913017, 69.58220824599266, 74.7888408601284, 72.35745012760162, 70.97490191459656, 61.0318386554718, 53.33418890833855, 59.913775250315666, 59.41939517855644, 59.76077266037464, 56.58684857189655, 54.778350815176964, 63.96102547645569, 64.38990846276283, 57.444059774279594, 56.1526420712471, 58.20738181471825, 57.4631879478693, 61.552836298942566, 65.26701539754868, 69.27638545632362, 63.59625265002251, 59.320148304104805, 54.87046927213669, 57.76138074696064, 62.12020665407181, 64.35417518019676, 56.6563468426466, 55.89241683483124, 58.99469196796417, 63.468754291534424, 68.09784069657326, 71.66299179196358, 69.90248546004295, 67.84005492925644, 68.56023028492928, 67.93697252869606, 60.820626989006996, 52.77602545917034, 55.48674300312996, 57.468446865677834, 54.38158370554447, 62.84433759748936, 71.27851322293282, 73.31849455833435, 73.47031161189079, 76.29036068916321, 75.66789329051971, 72.031230032444, 70.9821367263794, 72.850671261549, 72.05606549978256, 75.10205805301666, 77.07413703203201, 79.18810799717903, 76.55151307582855, 79.92352053523064, 76.88942894339561, 83.04097965359688, 80.50286784768105, 83.41217413544655, 69.46426257491112, 72.60652676224709, 60.198170989751816, 4.814957231283188, 1.0471417545340955, 1.366602131165564, 1.02493847720325, 1.5172248613089323, 4.989142259582877, 2.6698101265355945, 4.729399597272277, 0.5020840396173298, 0.2965057786786929, 19.311179369688034, 32.340619415044785, 59.59828197956085, 76.78396940231323, 29.61443480104208, 38.948924615979195, 34.337317273020744, 50.51936075091362, 59.56210792064667, 58.016145676374435, 2.0376109750941396, 0.05893880435905885, 0.0842220798949711, 0.14155945944366977, 0.10144135318114422, 0.045558301062555984, 0.061618744148290716, 0.0722257822053507, 0.04287399373424705, 0.026818734550033696, 0.042739078708109446, 0.049767974196583964, 0.14086385926930234, 0.15360046410933137, 0.12018896086374298, 0.13659297750564292, 0.08774200468906201, 0.3098156629130244, 0.19394512579310685, 0.23233234329381958, 0.10843391311937012, 0.17336655815597624, 0.10567687160801142, 0.3006623697001487, 0.24887217296054587, 5.909777283668518, 86.70488744974136, 73.97660404443741, 78.73519510030746, 30.78790683299303, 64.38758298754692, 94.9795514345169, 63.28814618289471, 5.440678680315614, 0.18611675914144143, 1.4309092867188156, 15.652704332023859, 11.673460006713867, 6.3090764824301, 26.986915692687035, 12.35334612429142, 2.112032356671989, 69.65911611914635, 102.28445425629616, 84.79089215397835, 93.21507051587105, 95.493975430727, 99.18972551822662, 99.1103857755661, 101.16206288337708, 96.85810983181, 94.88519489765167, 99.3899367749691, 101.40983998775482, 96.94537594914436, 94.34190765023232, 91.31351575255394, 93.5791289806366, 78.71253311634064, 66.5526232123375, 70.05496367812157, 68.56159061193466, 72.15539216995239, 75.64977586269379, 76.59926891326904, 76.36218443512917, 70.08758872747421, 64.7288578748703, 65.06702452898026, 63.9143031835556, 62.08777159452438, 62.931212335824966, 82.38076508045197, 84.42698568105698, 82.6090644299984, 78.83219629526138, 80.27497127652168, 62.78102919459343, 73.33209782838821, 80.17348632216454, 77.57172793149948, 75.2634809911251, 66.09971031546593, 65.40876299142838, 63.10952536761761, 72.30087876319885, 71.93642511963844, 75.42213767766953, 73.24721038341522, 72.4498763680458, 72.62646809220314, 70.87139546871185, 68.2800181210041, 74.38266545534134, 79.20801892876625, 76.06187134981155, 73.26749369502068, 62.263865545392036, 53.96449528634548, 62.48050332069397, 59.31305408477783, 60.06482474505901, 59.132670164108276, 55.86585246026516, 66.30075752735138, 65.13428092002869, 57.31729097664356, 60.081179067492485, 64.18954521417618, 62.013888359069824, 67.14456304907799, 68.38087990880013, 73.51995214819908, 66.88733205199242, 63.39201740920544, 58.240257650613785, 60.86271733045578, 64.09461870789528, 66.67368471622467, 59.46598067879677, 60.51490679383278, 62.220061495900154, 67.29343146085739, 72.0289197564125, 74.42402243614197, 73.5077092051506, 71.07015520334244, 70.5016753077507, 71.81609317660332, 63.63691806793213, 55.562423542141914, 58.93484137952328, 60.949512273073196, 58.33121336996555, 66.2500910460949, 74.43928241729736, 74.75006774067879, 77.73483797907829, 79.66796144843102, 79.09730806946754, 75.46813040971756, 71.23942852020264, 74.72371235489845, 75.35580843687057, 77.65257999300957, 79.42969143390656, 84.6061460673809, 79.05488714575768, 83.41317728161812, 80.1467813551426, 86.86348333954811, 82.85034388303757, 88.87062683701515, 73.0376972258091, 75.16096249222755, 60.82789599895477, 3.004068215377629, 4.467298211529851, 8.074969500303268, 3.2119750091806054, 7.870062170550227, 8.392278123646975, 8.26997123658657, 5.38571510463953, 0.5458834581077099, 0.23759957315633073, 29.016774371266365, 45.96644125878811, 69.6458700299263, 84.78668957948685, 34.949354231357574, 32.00252115726471, 35.84493577480316, 61.27791725099087, 67.19133853912354, 73.01529362797737, 3.055820963345468, 0.2946074539795518, 0.18285268975887448, 0.21011671662563458, 0.18568601662991568, 0.20226356224156916, 0.1944240930606611, 0.2058481503627263, 0.137021167029161, 0.14157437661197037, 0.17271392833208665, 0.06263252900680527], [0.013964424160803901, 0.07192043296527117, 0.027967859314230736, 0.0838492471666541, 0.08217407885240391, 0.05144547285453882, 0.05569109562202357, 0.0588446443725843, 0.02464463705109665, 0.04747140934341587, 0.07065119716571644, 0.0953163267695345, 0.10957400780171156, 2.646833471953869, 60.19643448293209, 59.253948256373405, 57.999046593904495, 33.58999617397785, 63.29223096370697, 74.47056993842125, 22.129155658185482, 0.2062251020106487, 0.2156284693046473, 1.6719005489721894, 5.42589794844389, 2.5158758740872145, 3.0020049260929227, 0.7383408746682107, 4.0556947980076075, 87.39311411976814, 107.31277763843536, 96.93498730659485, 101.39024823904037, 97.92765364050865, 92.6711069047451, 91.35564029216766, 93.32789406180382, 91.61264330148697, 90.82605510950089, 91.13732680678368, 90.80327153205872, 88.40866282582283, 86.92079946398735, 84.52415406703949, 87.59616762399673, 87.89882898330688, 74.36720788478851, 63.121099546551704, 61.36683627963066, 60.35936214029789, 63.21949526667595, 64.69717517495155, 66.90038815140724, 66.11797213554382, 59.93471212685108, 57.266297712922096, 57.53634922206402, 55.75591675937176, 56.30523048341274, 57.511015981435776, 68.2866145670414, 71.68439224362373, 70.81169307231903, 77.66232267022133, 70.08643358945847, 63.44404801726341, 73.20207640528679, 70.59870690107346, 73.71726796030998, 65.39507612586021, 60.695229917764664, 53.70898559689522, 63.521047085523605, 72.11143612861633, 70.708247423172, 70.49752593040466, 67.40846648812294, 67.91622564196587, 60.217473953962326, 58.514792919158936, 63.22709105908871, 67.72397115826607, 70.42121082544327, 69.06216815114021, 61.16780675947666, 54.71321851015091, 58.912715166807175, 58.75115543603897, 62.93285384774208, 59.303942173719406, 64.34001713991165, 56.99956342577934, 55.86853891611099, 57.051050662994385, 61.55511997640133, 58.03398571908474, 55.76390393078327, 55.92321798205376, 57.0533761382103, 60.6255454570055, 64.19753238558769, 58.98196645081043, 55.6845223903656, 50.45121140778065, 57.52856343984604, 62.702381014823914, 67.38923951983452, 59.84045818448067, 53.06918352842331, 55.56147739291191, 58.42740900814533, 60.374983102083206, 66.16360008716583, 68.79978463053703, 67.45207294821739, 66.87280923128128, 66.95276454091072, 59.237050563097, 52.65291206538677, 49.90799255669117, 51.7455967515707, 51.6361740231514, 55.847282856702805, 64.4722044467926, 68.53256016969681, 72.07880347967148, 71.01823478937149, 70.63940271735191, 69.7064995765686, 72.5104983150959, 72.03249916434288, 73.64395469427109, 74.06904548406601, 74.57723021507263, 76.498042345047, 75.24472519755363, 75.35156026482582, 77.98293426632881, 76.28706246614456, 72.8875444829464, 65.22985339164734, 69.7357352077961, 64.37352374196053, 65.94055205583572, 61.12698175013065, 1.9792725867591798, 2.526108012534678, 1.0716874874196947, 1.7687406088225543, 3.8893423369154334, 0.6714919523801655, 3.6073779920116067, 0.18049320933641866, 0.3345895023085177, 4.575358713045716, 37.453112080693245, 26.02480921894312, 74.75578263401985, 33.11787150800228, 32.48724214732647, 40.57218611240387, 59.54871363937855, 49.92337793111801, 51.843658089637756, 1.6504556871950626, 0.05481267478899099, 0.029490089546015952, 0.02344356009416515, 0.046961557600297965, 0.023807436955394223, 0.1077578314288985, 0.02651562845130684, 0.06556252803420648, 0.0703998540120665, 0.040144088852684945, 0.02910390558099607, 0.02622288273414597, 0.017873270517156925, 0.04794610555109102, 0.03866826511512045, 0.0674981382326223, 0.03544445353327319, 0.011483157304610359, 0.026861484111577738, 0.043130836202180944, 0.03923026015399955, 0.07091910505550914, 0.05333774533937685, 0.059539806679822505, 4.29336491972208, 73.82876917719841, 63.172225803136826, 65.24803921580315, 22.614705003798008, 58.84746506810188, 86.7776383459568, 25.488798581063747, 0.14019077585544437, 0.41809586982708424, 1.706643272191286, 6.040063267573714, 3.081202176399529, 1.940711543429643, 0.15358054486569017, 7.785182325169444, 97.93748751282692, 106.2017248570919, 99.30763319134712, 102.00294256210327, 99.09610614180565, 94.05448347330093, 91.3512933254242, 93.57311770319939, 90.91186970472336, 92.38001212477684, 93.4017089009285, 94.30771708488464, 92.12633013725281, 90.26317611336708, 87.02448070049286, 90.88280886411667, 90.7325953245163, 78.27342867851257, 66.0731041431427, 64.12460669875145, 64.20681908726692, 65.74133634567261, 67.76231870055199, 69.8201134800911, 70.05760833621025, 63.284543976187706, 59.8834490776062, 61.848817616701126, 59.91831220686436, 59.794123470783234, 58.78169819712639, 69.303288012743, 74.14642453193665, 77.23669230937958, 79.80508849024773, 76.64449408650398, 69.8063962161541, 72.04407334327698, 74.77129340171814, 75.77579990029335, 69.32677835226059, 64.25740197300911, 56.88400022685528, 65.73097050189972, 76.2742267549038, 73.70272994041443, 74.9774931371212, 71.71260952949524, 70.8560898900032, 64.85543668270111, 61.92926689982414, 64.7036500275135, 71.17811501026154, 72.59502857923508, 72.29167565703392, 62.361664697527885, 54.23482418060303, 62.186714485287666, 63.50032679736614, 64.9834518134594, 62.611322700977325, 68.85263979434967, 58.90191234648228, 56.751296147704124, 56.985545977950096, 63.92874240875244, 63.27189065515995, 60.249312445521355, 58.475491628050804, 60.401847660541534, 62.522981241345406, 68.11222672462463, 62.85172060132027, 57.91169688105583, 55.02248011529446, 62.08712562918663, 65.82469627261162, 70.02182945609093, 64.23146456480026, 56.018547266721725, 58.25989879667759, 61.368648782372475, 61.93275511264801, 67.13521555066109, 70.02681478857994, 69.23333376646042, 67.97188505530357, 69.62879374623299, 62.30435237288475, 56.04763850569725, 53.766077533364296, 55.34601375460625, 53.162495121359825, 57.73506335914135, 65.29128089547157, 72.23999083042145, 72.59026363492012, 74.96109321713448, 72.12319269776344, 73.69415000081062, 73.7872602045536, 74.57261726260185, 75.09859263896942, 77.29530796408653, 76.56609669327736, 79.43284526467323, 77.92380183935165, 77.86181956529617, 78.01667645573616, 77.34525248408318, 70.36995157599449, 68.21780785918236, 70.90240940451622, 69.6378144621849, 67.49326273798943, 75.20323902368546, 5.161504335701466, 1.3729680958203971, 0.25290688849054277, 1.2149655679240823, 3.892960217781365, 2.1111762151122093, 4.03599095530808, 0.6363032280933112, 0.264847005601041, 3.4789073606953025, 48.11771862208843, 32.5623033195734, 83.5279007256031, 35.22422768175602, 23.77473335713148, 41.58533714711666, 66.54442325234413, 56.53979949653149, 60.59471011161804, 2.361443373374641, 0.1477433307445608, 0.10197923955274746, 0.06285502488026395, 0.09799864143133163, 0.06877397172502242, 0.032994972862070426, 0.0182206141835195, 0.03078265846852446, 0.015405709273181856, 0.07213411954580806, 0.01563822599564446, 0.13542354572564363, 0.2117606034153141, 0.16231872519711033, 0.20045220240717754, 0.199418539123144, 0.12427350418874994, 0.13785882911179215, 0.18718263163464144, 0.13173639279557392, 0.19234563427744433, 0.17617221776163206, 0.20479355851421133, 0.46508242667187005, 7.0701951161026955, 87.71544322371483, 74.82533410191536, 73.61331313848495, 50.658102706074715, 85.99519953131676, 93.62699881196022, 39.90364998579025, 0.21670211950549856, 0.5713360954541713, 6.580119263380766, 14.244944471865892, 8.774316273629665, 13.17529521882534, 5.1454193238168955, 5.790008185431361, 96.00900739431381, 110.69547772407532, 103.16081643104553, 106.21420338749886, 103.02228346467018, 95.31156241893768, 93.99025931954384, 96.81183591485023, 95.13804093003273, 93.80161464214325, 96.31764963269234, 98.1338457763195, 95.65547436475754, 91.87634155154228, 89.51308876276016, 93.9357702434063, 95.5991081893444, 82.25716531276703, 70.83427146077156, 68.286272585392, 68.40295672416687, 69.6973192691803, 71.52877539396286, 73.92213776707649, 72.54789590835571, 67.1487808227539, 62.69598975777626, 64.84019190073013, 64.39000725746155, 64.29596990346909, 62.43445739150047, 74.64122638106346, 76.78339943289757, 81.31225481629372, 83.2144783437252, 76.5896326303482, 67.74993896484375, 79.61524307727814, 75.46819880604744, 80.46392753720284, 72.37856939435005, 66.87946647405624, 61.83748282492161, 70.83218917250633, 80.40643662214279, 76.04338154196739, 79.72811222076416, 76.20380893349648, 76.66688248515129, 70.38160935044289, 67.8370150923729, 69.05136913061142, 74.36935096979141, 75.28107404708862, 75.50244256854057, 65.5961537361145, 55.58013819158077, 63.10512140393257, 64.02641236782074, 69.11633804440498, 64.36586335301399, 71.22894868254662, 61.07417978346348, 56.62884011864662, 59.88854840397835, 66.20560303330421, 64.5879690349102, 63.48001308739185, 65.2348767220974, 64.57918390631676, 66.06738165020943, 72.23021015524864, 64.90611836314201, 61.07737921178341, 57.18373194336891, 65.7975885272026, 71.02972537279129, 72.96230167150497, 66.20865806937218, 60.14338552951813, 62.039160802960396, 63.54795344173908, 65.54140627384186, 72.54215061664581, 75.07626503705978, 72.0438301563263, 70.39626136422157, 74.31292399764061, 66.45616918802261, 59.30321641266346, 55.616517439484596, 58.675816878676414, 56.643609926104546, 61.41198165714741, 68.97516041994095, 74.42143857479095, 75.88224738836288, 77.07203954458237, 75.35431131720543, 77.09070414304733, 77.52439767122269, 77.6514932513237, 78.33488658070564, 79.06683370471, 79.07261699438095, 82.50334650278091, 80.25357082486153, 81.49577736854553, 81.89554631710052, 80.05762293934822, 74.24635156989098, 69.16040807962418, 70.69625526666641, 69.8665089905262, 67.93156921863556, 76.24740019440651, 4.021215448155999, 5.605507660657167, 6.569390539079905, 7.388230450451374, 11.948431301862001, 4.42569519393146, 9.201959576457739, 0.4353360494133085, 0.3288928361143917, 7.014149548485875, 60.09130172431469, 41.869744285941124, 92.24942073225975, 48.0255089700222, 43.78776736557484, 52.88368508219719, 74.59397211670876, 65.02429962158203, 74.48240250349045, 3.248896677978337, 0.3033833799418062, 0.18932175356894732, 0.1390785933472216, 0.2697877795435488, 0.16808185813715681, 0.2963950502453372, 0.14756132644833997, 0.09623569931136444, 0.15682530356571078, 0.16767462686402723, 0.13113460008753464], [0.028783936031686608, 0.1722537522437051, 0.004715749664683244, 0.06593189493287355, 0.07589708286104724, 0.029322616501303855, 0.03991230500105303, 0.1733937207609415, 0.017241350324184168, 0.07745695853373036, 0.03235533804399893, 0.25181848439387977, 0.34234987339004874, 6.525990692898631, 65.00971600413322, 57.795540913939476, 46.25166915357113, 58.78559298813343, 78.30167636275291, 51.99955612421036, 9.401526767760515, 0.0785895055742003, 0.09606896841432899, 3.1963602220639586, 1.4495508489198983, 4.419309161603451, 0.6131758284755051, 2.235925658605993, 96.60593256354332, 101.31023213267326, 93.860914260149, 94.90113884210587, 95.64298063516617, 95.4860870540142, 94.8150734603405, 94.45082500576973, 92.19982579350471, 89.66908559203148, 89.91240933537483, 90.05347296595573, 90.1969912648201, 88.36738184094429, 85.32821372151375, 81.34934842586517, 87.92275249958038, 82.82722592353821, 76.03579714894295, 62.82471925020218, 60.361999198794365, 62.086665853857994, 60.886097475886345, 63.21645922958851, 66.48819386959076, 61.14899396896362, 57.978113517165184, 57.39114001393318, 58.12749110162258, 57.33920060098171, 56.03979952633381, 57.8224890679121, 59.66497220098972, 68.47719714045525, 73.80665436387062, 75.7442919909954, 73.48974376916885, 63.96761432290077, 73.12047198414803, 73.15164551138878, 73.64342272281647, 71.07748880982399, 62.55214087665081, 53.8621211796999, 65.90578392148018, 71.64661467075348, 71.70292764902115, 68.48974406719208, 65.54617121815681, 65.55991888046265, 59.28045943379402, 55.46279288828373, 65.77367261052132, 67.45684549212456, 67.11240917444229, 64.45144236087799, 58.74051980674267, 58.05112659931183, 69.02686044573784, 66.63411363959312, 67.26121678948402, 64.62174162268639, 68.13368797302246, 64.99688029289246, 65.66822066903114, 56.26121744513512, 60.71620859205723, 57.77535639703274, 49.544941037893295, 53.672667145729065, 58.326129242777824, 57.77005188167095, 62.191601023077965, 59.953593313694, 58.40030886232853, 58.604943081736565, 59.24611307680607, 65.10337337851524, 66.55129328370094, 61.58324606716633, 54.167807176709175, 52.63457804918289, 57.28369317948818, 59.58612643182278, 63.10923658311367, 62.840005829930305, 67.63985887169838, 65.77681884169579, 68.1738594174385, 62.10303157567978, 57.00524792075157, 50.18171846866608, 50.91478273272514, 50.155203491449356, 53.397463113069534, 62.39568807184696, 68.30515757203102, 69.60092604160309, 71.47763773798943, 70.81032514572144, 72.19057828187943, 70.90991780161858, 73.03012803196907, 72.30939030647278, 74.74423885345459, 73.67546260356903, 73.95624473690987, 71.48082196712494, 72.56183356046677, 71.1325478553772, 69.60232436656952, 69.46863994002342, 73.87020975351334, 77.57204711437225, 79.34959173202515, 70.58010309934616, 67.56165906786919, 55.02695247530937, 0.43278867204207927, 0.7934231346007437, 1.6110949055291712, 2.887719408608973, 2.3200863925740123, 3.2388542918488383, 1.980856864247471, 0.12770492787240073, 0.55732102249749, 38.267017006874084, 39.82735387980938, 44.95208188891411, 59.630131870508194, 55.80112673342228, 31.991034373641014, 39.708549454808235, 57.23562955856323, 42.39630103111267, 0.8281226945109665, 0.052811150744673796, 0.036135504342382774, 0.06184648329508491, 0.07618623843882233, 0.04224755059112795, 0.022068416110414546, 0.041689058489282615, 0.03550813351466786, 0.04824696479772683, 0.06965430729906075, 0.01859900188719621, 0.043420232977950945, 0.08932746219215915, 0.09951985863153823, 0.08542961353668943, 0.06734389025950804, 0.06657787511358038, 0.044785042555304244, 0.053029212285764515, 0.06621420790906996, 0.10178355005336925, 0.06034135585650802, 0.3689783101435751, 0.39944863761775196, 10.1007129997015, 79.26379233598709, 66.23503625392914, 67.53363937139511, 47.01703168451786, 79.73933681845665, 63.66882115602493, 9.161111768335104, 0.0876064291514922, 0.6495434988755733, 4.613553788512945, 3.294868511147797, 1.0420716390945017, 0.33356426982209086, 4.675464341416955, 106.45210102200508, 99.98015910387039, 99.64608862996101, 97.73948773741722, 98.21494862437248, 99.72820982336998, 96.5620981156826, 96.03827342391014, 94.15882587432861, 92.61041656136513, 91.30598455667496, 92.33906552195549, 93.70643734931946, 89.40639808773994, 89.94295969605446, 86.6835705935955, 89.63647574186325, 85.36033719778061, 78.42760920524597, 65.3320375084877, 64.43356052041054, 65.00208601355553, 64.72096189856529, 66.86307415366173, 67.62359574437141, 64.65747490525246, 60.884083583950996, 59.68551389873028, 61.35200187563896, 60.62346316874027, 57.84922443330288, 59.67149265110493, 65.30651807785034, 70.26855021715164, 76.50765582919121, 76.12250089645386, 78.50248798727989, 70.2734063565731, 75.22299036383629, 75.60071289539337, 76.79591596126556, 73.70405226945877, 65.65869837999344, 57.58646473288536, 69.43044438958168, 75.31778767704964, 75.22083207964897, 69.09424602985382, 68.49143117666245, 68.70471373200417, 65.85352912545204, 60.93578360974789, 67.0933797955513, 69.43744361400604, 67.62319296598434, 65.0711815059185, 59.67485547065735, 60.65296858549118, 72.06554979085922, 70.48222795128822, 70.32348766922951, 69.11123111844063, 70.48171117901802, 69.16888922452927, 66.81012019515038, 59.25581015646458, 59.82036106288433, 58.05757865309715, 53.41174274682999, 58.00154685974121, 61.09049990773201, 61.75945021212101, 66.70628696680069, 62.938937321305275, 60.642321556806564, 63.24411414563656, 63.63567553460598, 67.21492767333984, 67.58770287036896, 64.060770124197, 56.966679990291595, 53.887116238474846, 60.57734504342079, 61.539989188313484, 68.0561113357544, 67.90241718292236, 71.36058881878853, 70.02440571784973, 72.3719273507595, 66.19485720992088, 59.79320392012596, 52.33629785478115, 52.52863593399525, 53.46863329410553, 56.5355209261179, 63.495569452643394, 71.01033121347427, 71.45139634609222, 74.29500415921211, 74.2464579641819, 74.70384702086449, 72.80160069465637, 75.22412270307541, 75.51166087388992, 77.71894723176956, 74.64598372578621, 74.17701289057732, 71.19088992476463, 72.81424641609192, 72.78403043746948, 70.39938479661942, 72.66936019062996, 76.47764503955841, 80.52710294723511, 78.20052579045296, 77.1220600605011, 70.2050556242466, 68.10582026839256, 3.761756345629692, 0.829235203564167, 0.5150288762524724, 2.9588891146704555, 4.060143884271383, 4.4234138913452625, 5.2041850704699755, 0.2744701970368624, 1.0495555750094354, 38.38221922516823, 48.013832196593285, 49.7838494181633, 58.10376897454262, 34.41947266459465, 44.587043076753616, 46.999533623456955, 63.557483330368996, 50.51630571484566, 1.571693157311529, 0.09930152620654553, 0.02695443996344693, 0.08117415360175073, 0.02034351091424469, 0.04098601086298004, 0.0102791052631801, 0.044606103328987956, 0.08298730943351984, 0.023572331992909312, 0.0746985366276931, 0.07641480508027598, 0.11728284414857626, 0.34135477209929377, 0.20874635578365996, 0.2440864485106431, 0.18372115097008646, 0.23465370701160282, 0.169899333268404, 0.3267430717824027, 0.10255959903588519, 0.4858822136884555, 0.3462828404735774, 0.6854707491584122, 0.7045849109999835, 13.691339828073978, 88.21396127343178, 74.75257560610771, 60.846978574991226, 86.53765082359314, 98.25504407286644, 71.05652153491974, 15.88821379467845, 0.2388528676237911, 0.5282763903960586, 10.133241154253483, 7.05717321485281, 12.867439538240433, 4.661282552406192, 3.0508821783587337, 107.68065869808197, 104.53517228364944, 104.71808686852455, 101.98094934225082, 101.9919915497303, 102.38759592175484, 100.86777627468109, 100.62607124447823, 97.52010270953178, 96.37202471494675, 95.49771443009377, 95.58355182409286, 98.4797716140747, 94.3182273209095, 93.60680669546127, 86.90555468201637, 94.25920888781548, 88.18622276186943, 85.26167929172516, 68.16620662808418, 68.67826715111732, 67.8128407895565, 67.74825185537338, 70.45129001140594, 72.40307807922363, 66.96981802582741, 63.157999366521835, 62.110498175024986, 65.70156767964363, 63.385789543390274, 63.32875080406666, 63.89139041304588, 68.57093051075935, 75.3423647582531, 80.35307988524437, 82.43444859981537, 78.98541167378426, 68.56190979480743, 79.34497117996216, 77.60262787342072, 80.45106902718544, 78.93745064735413, 68.98046493530273, 59.88531477749348, 74.68234777450562, 78.16368296742439, 79.54414129257202, 73.66993010044098, 72.56212994456291, 72.80067354440689, 70.59899568557739, 62.247613817453384, 72.92561084032059, 72.20595225691795, 70.0276431441307, 69.14097592234612, 63.189940452575684, 61.14909656345844, 76.50042101740837, 72.992684841156, 71.9765205681324, 70.67993894219398, 74.86548274755478, 70.88660225272179, 67.45772704482079, 58.84614273905754, 64.86226111650467, 62.86310859024525, 60.2395735681057, 61.83722823858261, 65.82021251320839, 65.06532981991768, 70.91341361403465, 67.04614073038101, 63.169885128736496, 65.05106538534164, 67.55997195839882, 71.4178441464901, 72.9649007320404, 67.4184599518776, 60.057958513498306, 58.04538130760193, 64.01765003800392, 65.68398982286453, 71.28539845347404, 69.16603937745094, 74.85050395131111, 72.05025181174278, 73.66590991616249, 67.94208705425262, 64.77256312966347, 55.40740706026554, 56.263292133808136, 56.23122565448284, 58.822394013404846, 66.94704964756966, 75.16981601715088, 72.998688519001, 77.45039284229279, 76.14488929510117, 77.31369137763977, 74.54448357224464, 76.41800343990326, 77.30906322598457, 80.33993259072304, 76.51410788297653, 80.00627249479294, 74.61284950375557, 74.83633071184158, 73.42358931899071, 73.65874350070953, 73.50373461842537, 78.95135790109634, 82.42033615708351, 83.29707831144333, 77.27963000535965, 71.72469288110733, 64.0889798104763, 2.761681596748531, 2.9705307399854064, 6.851913454011083, 8.330553285777569, 6.8785186763852835, 11.067366879433393, 6.19078597985208, 0.44843694486189634, 0.8532210008706897, 49.5817306637764, 56.23132064938545, 58.79600062966347, 77.8399783372879, 76.15182772278786, 44.91689197719097, 54.245987981557846, 71.51051357388496, 62.347480058670044, 2.3248275881633162, 0.252700126147829, 0.17164529504952952, 0.2185240772087127, 0.18145765992812812, 0.15735592431155965, 0.0760857664863579, 0.17483026633271948, 0.1590485405176878, 0.1614817013614811, 0.2222727393382229, 0.16892559098778293], [0.036855610233033076, 0.00959704557317309, 0.010248647522530518, 0.04993749927962199, 0.019229202152928337, 0.040652385796420276, 0.07418900771881454, 0.0932287766772788, 0.03720751810760703, 0.16071691818069667, 0.0505859619443072, 0.1594455895246938, 0.308611691580154, 18.453715480864048, 73.77941742539406, 46.281755939126015, 27.72660870105028, 37.37005613744259, 69.32525843381882, 39.66841980814934, 1.2544183759018779, 0.11177901760675013, 0.5960932513698936, 0.5495155288372189, 3.348277732729912, 2.1668954752385616, 0.466386676998809, 68.88837307691574, 102.67135709524155, 88.41794192790985, 100.33699035644531, 90.69044038653374, 98.61089497804642, 92.77110233902931, 97.05073669552803, 92.64906048774719, 93.03918555378914, 85.85320115089417, 87.41860315203667, 82.98753932118416, 88.20349663496017, 82.0287823677063, 88.77456799149513, 84.17656391859055, 86.55970484018326, 79.96029496192932, 73.51231455802917, 63.065345138311386, 62.37120218575001, 60.22107996046543, 61.810648664832115, 62.43535414338112, 61.964282020926476, 61.50754272937775, 55.96770599484444, 57.843517139554024, 56.94391921162605, 56.380230858922005, 56.70390889048576, 58.842768520116806, 60.00927172601223, 63.45285214483738, 68.88671636581421, 70.04933997988701, 70.70997253060341, 65.16823589801788, 70.44194251298904, 68.07859092950821, 73.61351072788239, 70.31326621770859, 64.87822785973549, 58.47036950290203, 65.21856039762497, 68.56482803821564, 68.51791575551033, 63.92213076353073, 58.857671320438385, 56.861881613731384, 53.73808443546295, 60.89897118508816, 63.09779539704323, 65.10356336832047, 63.75259146094322, 58.27715367078781, 62.745284512639046, 66.4717635512352, 66.44846320152283, 69.22127321362495, 66.01387292146683, 62.293234169483185, 65.28291374444962, 65.07039114832878, 65.58549150824547, 62.2885300219059, 61.37040428817272, 53.43167647719383, 48.772651478648186, 47.20295570790768, 58.19120228290558, 62.2122111171484, 59.95000630617142, 59.145068898797035, 62.65899494290352, 63.738779202103615, 61.77766263484955, 66.54917299747467, 64.85184967517853, 62.31181517243385, 58.64856854081154, 55.48458471894264, 58.41882146894932, 59.9378127604723, 60.584139078855515, 65.12878641486168, 66.31866216659546, 67.87626698613167, 70.45584216713905, 64.50554385781288, 67.11943879723549, 53.775827810168266, 51.262027099728584, 52.45112769305706, 51.98035195469856, 60.754259750247, 68.00083190202713, 70.45263513922691, 68.766308426857, 72.24110037088394, 66.71035274863243, 70.10864719748497, 69.77090612053871, 72.56390064954758, 72.18462020158768, 72.23947405815125, 71.60512089729309, 70.87166145443916, 71.27682611346245, 78.66850107908249, 73.42542082071304, 79.40129175782204, 74.52561378479004, 77.9425348341465, 74.61316108703613, 85.00743493437767, 71.96235492825508, 77.81139627099037, 44.29694004356861, 0.1934955030446872, 0.5252121516969055, 2.8422410739585757, 1.4394494472071528, 2.244687038473785, 1.8872618302702904, 0.11973518950981088, 0.16733059688704088, 7.303655538707972, 62.93216988444328, 32.25622974336147, 62.35699474811554, 37.210761085152626, 29.85049143433571, 39.498340934515, 47.58347108960152, 39.36597503721714, 0.721357389120385, 0.025070676201721653, 0.028912218112964183, 0.021482956217369065, 0.09789400603040121, 0.007689708882026025, 0.02179875118599739, 0.06601659624720924, 0.08484827441861853, 0.05474775542097632, 0.033001696720020846, 0.13001613900996745, 0.03204061547876336, 0.03279330165241845, 0.03852234403893817, 0.04241514237946831, 0.05085395518108271, 0.026343568933953065, 0.04316997707064729, 0.04976155832991935, 0.032344409919460304, 0.16253241919912398, 0.08354584977496415, 0.13709607941564173, 0.39430398086551577, 26.799013875424862, 81.12997859716415, 57.40088649094105, 35.13797231018543, 34.85215164721012, 81.99742645025253, 42.78546094894409, 1.4148944523185492, 0.27768993051722646, 3.008971377275884, 2.8349837008863688, 1.9944989634677768, 1.1812404775992036, 0.9471101628150791, 80.93769371509552, 104.23295930027962, 93.84589746594429, 99.79105845093727, 91.94106727838516, 100.60894176363945, 93.79387825727463, 97.20313891768456, 94.23668369650841, 93.36699396371841, 89.70320776104927, 90.88580310344696, 86.85895398259163, 89.75809201598167, 86.6917933523655, 91.1260338127613, 88.63507747650146, 88.01970809698105, 82.87459418177605, 76.2834070622921, 64.44831132888794, 64.73518833518028, 63.552080020308495, 64.8279869556427, 64.74608615040779, 65.42976066470146, 63.092844262719154, 60.003993809223175, 59.929244220256805, 60.15086732804775, 59.226137548685074, 58.36644887924194, 59.43174831569195, 62.36267164349556, 65.67354798316956, 71.93863660097122, 75.15042945742607, 75.88797748088837, 69.94093179702759, 71.64336204528809, 71.5167984366417, 75.53958937525749, 75.16088649630547, 66.95186778903008, 59.48740392923355, 69.26223501563072, 72.01641842722893, 72.69750908017159, 65.24157956242561, 58.405856564641, 57.4541862308979, 56.402338072657585, 64.1430053114891, 65.91164320707321, 65.77955469489098, 64.60256785154343, 61.499962136149406, 64.2435859143734, 71.35805055499077, 67.75942325592041, 70.07552057504654, 67.21335455775261, 64.82091173529625, 68.9466467499733, 67.82350301742554, 67.02908724546432, 64.58932176232338, 62.880884036421776, 56.83640398085117, 51.27357468008995, 51.82581804692745, 60.167411640286446, 66.73388868570328, 64.4859217107296, 62.29982301592827, 66.74766674637794, 65.51256582140923, 65.22631198167801, 65.18845841288567, 69.0668722987175, 65.27613490819931, 61.317549124360085, 58.531496822834015, 62.02468357980251, 62.39212766289711, 64.80838000774384, 68.60832810401917, 69.93290662765503, 69.61228743195534, 71.35020017623901, 67.24879905581474, 70.23616075515747, 55.22305615246296, 53.1111104786396, 54.945078268647194, 53.13378386199474, 63.42273876070976, 70.02799272537231, 74.744071662426, 71.04700684547424, 73.6307542026043, 68.59933778643608, 72.9899413883686, 73.00090000033379, 75.35856708884239, 74.42618072032928, 74.991894364357, 73.7678736448288, 73.44864517450333, 73.53550091385841, 79.54512923955917, 77.21466109156609, 80.2714754641056, 76.32209658622742, 81.15720793604851, 77.82018899917603, 83.85510116815567, 77.15314239263535, 77.71529942750931, 59.0413648635149, 1.5741005656309426, 0.7832773821428418, 1.3976519275456667, 3.7678790045902133, 3.3205024106428027, 4.117561653256416, 0.8890414412599057, 0.19281810033135116, 6.322369119152427, 69.65797618031502, 40.02935104072094, 64.3097859621048, 28.774104192852974, 36.448400393128395, 47.19978667795658, 54.17174756526947, 48.62321689724922, 1.5555515047162771, 0.09648331688367762, 0.015109212927200133, 0.034495814397814684, 0.0852250553725753, 0.019442077937128488, 0.05923980461375322, 0.04552571335807443, 0.030522418819600716, 0.043035715134465136, 0.08465323058771901, 0.04319368126743939, 0.14318605419248343, 0.10777136820252053, 0.16028617566917092, 0.15059541910886765, 0.11247124843066558, 0.1832922489847988, 0.15590281400363892, 0.22612369910348207, 0.11186742965946905, 0.21399709512479603, 0.22770848125219345, 0.22962532995734364, 0.6472630868665874, 29.76901240646839, 93.56101155281067, 61.78255297243595, 37.64050282537937, 53.02028015255928, 85.38389593362808, 58.74257169663906, 2.5177995208650827, 0.37449730618391186, 3.409235249273479, 3.4579766588285565, 7.780234040692449, 9.598591793328524, 0.7220732350833714, 79.19409647583961, 106.79476663470268, 95.94997376203537, 106.13117784261703, 95.0002147257328, 107.60812059044838, 97.24831089377403, 101.79546609520912, 100.13797983527184, 99.12604853510857, 94.14540499448776, 95.34872442483902, 91.44938886165619, 95.40207356214523, 89.860929697752, 96.83049291372299, 92.79169723391533, 90.72284504771233, 86.08460113406181, 79.33003038167953, 68.16808372735977, 67.7051393687725, 66.41352787613869, 68.20466056466103, 69.29133385419846, 69.1749157011509, 67.28197127580643, 62.297668531537056, 63.39256837964058, 63.23652595281601, 62.23527207970619, 62.22621716558933, 64.5892533659935, 68.17363142967224, 70.37380456924438, 75.64637884497643, 78.02919298410416, 76.10517382621765, 69.77254003286362, 74.61488619446754, 72.84413561224937, 81.65871262550354, 78.91158923506737, 70.58377370238304, 63.84744957089424, 73.59108433127403, 77.82895892858505, 76.37093156576157, 66.94043800234795, 62.578127682209015, 64.30427625775337, 60.84730915725231, 65.89699879288673, 68.4647186100483, 67.44811356067657, 67.32197552919388, 61.41030214726925, 66.40218928456306, 73.53492334485054, 72.98420369625092, 74.09671559929848, 73.44824999570847, 70.4263785481453, 72.7113251388073, 71.04578331112862, 71.48082956671715, 67.76578411459923, 64.88002896308899, 56.022928431630135, 52.66666352748871, 56.60994753241539, 64.55663591623306, 69.55770716071129, 68.3776804804802, 64.42384824156761, 69.44491401314735, 69.11895990371704, 66.90623983740807, 70.69827675819397, 74.23603132367134, 69.00558918714523, 65.48807993531227, 61.52691408991814, 66.5545991063118, 66.74498409032822, 67.7376276254654, 73.41566294431686, 73.67237716913223, 72.74265825748444, 76.49542048573494, 70.5321116745472, 73.54041025042534, 59.566272497177124, 56.92444145679474, 58.90237212181091, 57.49857924878597, 65.25544121861458, 72.99781456589699, 77.82812297344208, 73.4026600420475, 76.21251806616783, 71.76100373268127, 73.13240334391594, 76.80234521627426, 79.53471019864082, 77.58319571614265, 78.1534843146801, 75.05380064249039, 74.74315211176872, 76.81385099887848, 83.2232178747654, 81.74208015203476, 85.46397283673286, 79.64240401983261, 83.36790651082993, 83.29801306128502, 86.67266517877579, 80.19620150327682, 80.08326396346092, 59.4167847186327, 1.2824856885708869, 4.15598139166832, 11.065379586070776, 8.164393901824951, 5.562543366104364, 8.155201245099306, 0.8081175398547202, 0.3930715110618621, 10.561652015894651, 80.5701470375061, 48.37735868990421, 80.79142436385155, 51.1555340141058, 39.95191119611263, 53.71956802904606, 63.65454912185669, 57.65388451516628, 2.30563648045063, 0.23305066803004593, 0.10532091531786136, 0.15878415782935917, 0.23169439315097407, 0.16190861439099535, 0.19689093256602064, 0.20348697784356773, 0.1534287162940018, 0.2590706030605361, 0.24468412972055376, 0.20998847350711003], [0.09085534387850203, 0.010808561764861224, 0.05650143553793896, 0.03294369416835252, 0.05311221779265907, 0.03944951655284967, 0.013978495280753123, 0.03432986275583971, 0.03126180199615192, 0.02714994207053678, 0.012443794184946455, 0.09116801811615005, 0.06439357865019701, 35.91851882636547, 66.5447424352169, 35.768867656588554, 38.31793427467346, 49.39879707992077, 74.92901533842087, 18.124759532511234, 0.16631235543172807, 0.12204314261907712, 2.915579038672149, 2.5144535629078746, 2.56243335083127, 1.0009472770616412, 32.19594597816467, 103.494453728199, 92.10318937897682, 98.14005464315414, 86.25586554408073, 93.26268956065178, 91.22254863381386, 94.40360113978386, 90.42484983801842, 91.74847081303596, 87.34721258282661, 87.30391770601273, 86.01801350712776, 84.37768712639809, 84.73231449723244, 86.28393083810806, 84.85769256949425, 86.05239406228065, 82.3253944516182, 78.2184836268425, 69.98192399740219, 62.012687623500824, 57.96533480286598, 60.45299291610718, 60.22386521100998, 62.06640914082527, 59.86052490770817, 57.774581238627434, 58.60144726932049, 56.49795614182949, 56.42734833061695, 55.45184187591076, 54.780942276120186, 54.83297288417816, 58.31463485956192, 64.70329284667969, 72.72881180047989, 74.79478374123573, 73.4848040342331, 66.49572506546974, 69.04462829232216, 67.17456623911858, 71.44242122769356, 70.37274822592735, 62.6278480142355, 53.75471234321594, 60.525090247392654, 66.12143754959106, 68.55989590287209, 69.01906326413155, 53.29471282660961, 55.309148132801056, 54.84594538807869, 59.33148689568043, 59.99330498278141, 67.74812266230583, 66.6883747279644, 69.01800692081451, 65.50763368606567, 62.9621122777462, 62.34164737164974, 67.05963000655174, 62.97335587441921, 58.219617158174515, 62.284015864133835, 58.97711031138897, 60.70395804941654, 61.60960905253887, 61.99477918446064, 62.880325466394424, 55.13515166938305, 50.48395425081253, 54.26675006747246, 57.05988518893719, 58.639338836073875, 62.45962344110012, 65.57809710502625, 62.687751799821854, 65.27445539832115, 58.808045983314514, 62.71026559174061, 62.06069804728031, 60.29199555516243, 56.77004054188728, 60.0725307315588, 60.53150810301304, 62.849060744047165, 63.259237334132195, 63.86154681444168, 67.59949743747711, 66.92910701036453, 67.58527100086212, 67.08619818091393, 58.7336041778326, 51.119679138064384, 50.72359599173069, 50.916181057691574, 55.63989378511906, 66.50279268622398, 66.13903060555458, 72.15280830860138, 65.33587530255318, 66.22568875551224, 70.1332850754261, 70.39144322276115, 68.61174032092094, 73.36616680026054, 74.11601856350899, 72.89931625127792, 71.9262720644474, 74.51275527477264, 71.49775385856628, 75.11774361133575, 69.39249202609062, 75.86606025695801, 69.50378805398941, 81.49207636713982, 70.50908491015434, 80.7463663816452, 64.58498239517212, 77.16924592852592, 25.433625541627407, 0.12590959842782468, 1.3485908601433039, 1.9736636127345264, 2.8666991740465164, 2.653141845948994, 0.3150539787020534, 0.014539281546603888, 0.5307096254546195, 48.14383082091808, 54.790810346603394, 45.9794669598341, 61.0561915487051, 45.15221334993839, 44.12090688943863, 38.180845230817795, 47.45227552950382, 1.5626982087269425, 0.13255444733658805, 0.02892026855988661, 0.10828752449015155, 0.036822054025833495, 0.04699346623965539, 0.09749861943419091, 0.08605229028034955, 0.09275148666347377, 0.06151178211439401, 0.04627688926120754, 0.06673480223980732, 0.06989789500948973, 0.04370878370536957, 0.045416406137519516, 0.031763393635628745, 0.02232378912594868, 0.01709577063593315, 0.00863781506268424, 0.13438655762001872, 0.008367701138922712, 0.03320115261885803, 0.03226745662686881, 0.038513386316481046, 0.0410871841449989, 44.98005598783493, 71.23463317751884, 44.646141305565834, 39.23503026366234, 52.62931913137436, 87.18338057398796, 20.29882237315178, 0.08521601601387374, 0.37863445293623954, 4.2649120464921, 2.978457589633763, 1.6356281703338027, 0.8613879501353949, 39.42627780139446, 108.48346441984177, 95.62867060303688, 99.98412609100342, 88.80192652344704, 96.84333622455597, 94.3782564997673, 96.73553600907326, 94.01467680931091, 93.69594231247902, 91.78861945867538, 91.1426617205143, 87.18889027833939, 86.55012935400009, 86.96589544415474, 89.94289889931679, 86.81566670536995, 90.06533592939377, 84.4767478108406, 81.91400572657585, 72.03395828604698, 66.74512848258018, 60.03533832728863, 63.00050921738148, 62.914060056209564, 64.7334024310112, 61.66899226605892, 60.428689420223236, 61.715068593621254, 59.49815735220909, 58.762281239032745, 57.079845517873764, 57.71522082388401, 57.76339463889599, 60.24930864572525, 67.39406526088715, 75.04577547311783, 78.13003957271576, 74.11863282322884, 70.915936678648, 71.59558340907097, 69.45896565914154, 74.1570183634758, 72.19863384962082, 66.11391395330429, 58.93676407635212, 63.97953048348427, 70.81828191876411, 72.35643178224564, 72.11162611842155, 57.08952359855175, 59.98978637158871, 59.77179206907749, 59.808771684765816, 59.343566447496414, 68.53712752461433, 68.14344584941864, 71.44858449697495, 67.14278474450111, 68.06805029511452, 67.02071249485016, 66.88263550400734, 64.57340821623802, 62.19831146299839, 62.0331609249115, 60.406829193234444, 63.391185253858566, 67.10393562912941, 66.54461324214935, 64.6779254078865, 60.37098191678524, 54.44417014718056, 58.60188044607639, 59.00418385863304, 60.894647017121315, 66.69389963150024, 67.92393162846565, 66.2273682653904, 68.87878239154816, 61.784202083945274, 66.31236210465431, 65.89840471744537, 63.29187758266926, 61.391629949212074, 67.14458584785461, 63.04544560611248, 63.63078519701958, 64.76119413971901, 65.42794436216354, 69.36826452612877, 68.72387230396271, 69.85039785504341, 70.75136750936508, 61.30717188119888, 53.46789613366127, 56.15697003901005, 52.13793329894543, 58.665466234087944, 69.53040182590485, 68.63934203982353, 75.55920392274857, 68.00273180007935, 69.7183245420456, 71.80373623967171, 72.06969156861305, 70.19275188446045, 73.10841143131256, 75.65971612930298, 75.77709943056107, 74.09182906150818, 77.50900089740753, 75.39644345641136, 77.36186519265175, 73.17304596304893, 76.42291277647018, 72.3949921131134, 81.76607966423035, 74.59643438458443, 82.74920091032982, 71.3365589082241, 78.47632259130478, 38.15396927297115, 0.2374506983323954, 1.0211808350868523, 1.3965491554699838, 3.211731822229922, 2.7926228614524007, 1.5729703637771308, 0.046489455198752694, 0.26197394414339215, 51.22947804629803, 62.850588262081146, 51.090918481349945, 50.49389071762562, 37.51929312944412, 54.35476094484329, 42.655944898724556, 58.26919309794903, 2.2535631246864796, 0.08709662564797327, 0.027258128648099955, 0.06357893798849545, 0.0022710321900376584, 0.008342975561390631, 0.02808053402986843, 0.014225029317458393, 0.07051707623759285, 0.08626916809589602, 0.02149476935301209, 0.03175315941916779, 0.19589425792219117, 0.1521908733411692, 0.10444541854667477, 0.09162887698039412, 0.16625581862172112, 0.09435840707737952, 0.15133893233723938, 0.23462023615138605, 0.12809975043637678, 0.0787705228140112, 0.10521737829549238, 0.21027381444582716, 0.2040669959387742, 52.861976847052574, 86.07602879405022, 47.72416613996029, 55.23523449897766, 69.74018096923828, 96.22694090008736, 29.93505969643593, 0.24792780488496646, 0.46812297601718456, 11.534559410065413, 8.489235620945692, 10.390659291297197, 2.702992558479309, 38.72956998646259, 110.44333845376968, 97.95229151844978, 104.96870622038841, 94.96698930859566, 100.77205181121826, 95.94377249479294, 99.3562325835228, 98.11304569244385, 97.03522592782974, 95.21419644355774, 93.36969941854477, 90.47299325466156, 91.4337109029293, 90.48850402235985, 93.60020264983177, 91.53785571455956, 91.42094358801842, 88.4043538570404, 88.30235213041306, 75.53439125418663, 69.97840538620949, 62.211580350995064, 66.54841303825378, 66.68007597327232, 70.06456956267357, 65.92108190059662, 63.03784221410751, 66.37230768799782, 63.16755585372448, 63.5440244525671, 61.264735758304596, 61.91152185201645, 59.643115773797035, 64.45390462875366, 71.4499220252037, 79.15537655353546, 81.55964434146881, 77.61266693472862, 73.05943965911865, 73.89964297413826, 71.35270044207573, 78.81796985864639, 75.38727834820747, 68.7561097741127, 60.31398497521877, 67.01030105352402, 73.71798232197762, 76.57446384429932, 77.99756348133087, 60.43837510049343, 63.47545713186264, 62.849953696131706, 63.39277356863022, 61.77117258310318, 72.47449904680252, 71.51875913143158, 74.92038980126381, 71.60611644387245, 69.75398942828178, 68.14584732055664, 70.66768079996109, 66.90145969390869, 64.4279596209526, 66.10547840595245, 64.24714252352715, 65.30733123421669, 68.02563697099686, 68.13426554203033, 67.28594586253166, 61.17723785340786, 58.34787167608738, 63.18944647908211, 62.41918981075287, 67.41009280085564, 71.51378899812698, 74.454405605793, 68.27216774225235, 70.6768611073494, 63.055294677615166, 68.89679342508316, 69.46688443422318, 66.61288037896156, 63.35560776293278, 67.21530765295029, 66.42139345407486, 68.03000673651695, 68.88806149363518, 69.39321398735046, 73.02360758185387, 72.35510185360909, 72.79805928468704, 74.78726014494896, 63.63545134663582, 56.99541784822941, 58.91905702650547, 54.75898325443268, 60.81777714192867, 71.26557871699333, 72.2926028072834, 80.61900481581688, 71.11423283815384, 71.29938170313835, 73.71777713298798, 73.7740521132946, 72.8461343050003, 78.10509011149406, 78.56031328439713, 78.43874260783195, 76.60464942455292, 81.0679279267788, 79.7701607644558, 81.31543144583702, 75.70971384644508, 81.76765277981758, 75.95265001058578, 86.11701339483261, 77.87099987268448, 86.52017176151276, 74.89401921629906, 82.64915227890015, 40.89984253048897, 0.31942347704898566, 6.4405955001711845, 6.477933246642351, 8.065796792507172, 9.339293707162142, 1.8892227625474334, 0.2172574240830727, 0.9854124044068158, 59.57342751324177, 66.87078773975372, 61.93665750324726, 80.03443658351898, 55.82169122993946, 59.77650761604309, 51.14440441131592, 67.84114927053452, 3.258791109547019, 0.2625305252149701, 0.12823804223444313, 0.18715033336775377, 0.10679962229914963, 0.1611286765546538, 0.2398881784756668, 0.1904854114400223, 0.31274800712708384, 0.11111031286418438, 0.20339671784313396, 0.10895829982473515], [0.029080064086883795, 0.016887230849533807, 0.059704333398258314, 0.05459562256874051, 0.08116554468870163, 0.05436759769509081, 0.10312021739082411, 0.08471126653603278, 0.08326321025379002, 0.11058980759116821, 0.1126343131181784, 0.17514829145511612, 1.1718469066545367, 51.24686971306801, 53.78166429698467, 37.80957855284214, 38.249370753765106, 67.26410463452339, 56.12874895334244, 6.648633861914277, 0.18912676168838516, 1.3692954741418362, 1.0210647038184106, 2.2877294663339853, 0.9438001841772348, 5.605641603469849, 80.43678179383278, 99.39315140247345, 94.4467668235302, 86.31837978959084, 87.35630929470062, 88.19102570414543, 91.74702689051628, 87.00863555073738, 91.06764614582062, 88.90886798501015, 91.81276336312294, 87.65226781368256, 84.83366265892982, 84.46392729878426, 83.01465466618538, 86.15219950675964, 89.49225068092346, 82.8853552043438, 78.96942213177681, 76.76710590720177, 65.94454944133759, 63.869131207466125, 61.33583754301071, 60.6921748816967, 60.14752730727196, 60.146710351109505, 56.80296577513218, 55.65338686108589, 58.02721828222275, 55.790909081697464, 57.56895527243614, 55.950758904218674, 54.02344532310963, 57.01505899429321, 63.29737588763237, 66.35944917798042, 68.41535925865173, 72.91212156414986, 73.54659631848335, 69.97736424207687, 69.86336275935173, 69.93979185819626, 70.74991598725319, 67.49488905072212, 60.86531259119511, 53.543113097548485, 60.41596010327339, 67.93681293725967, 67.1301618218422, 63.51068504154682, 52.54752852022648, 52.131439447402954, 56.83329954743385, 57.34951704740524, 64.34233501553535, 68.49684968590736, 64.67528834939003, 62.177264392375946, 63.81600245833397, 66.3029158115387, 61.954565942287445, 63.53798657655716, 62.14620865881443, 63.33163104951382, 65.18246233463287, 61.58756643533707, 62.04600803554058, 64.04262989759445, 64.71272394061089, 57.31486290693283, 58.097978085279465, 57.99230195581913, 53.86075705289841, 52.78250031173229, 52.18468979001045, 58.31198640167713, 57.7804709225893, 64.34208422899246, 60.39871662855148, 60.8240620046854, 63.31996187567711, 67.18009874224663, 59.88468401134014, 67.44351580739021, 64.42513257265091, 65.1687678694725, 65.10794833302498, 64.21815007925034, 66.1151222884655, 66.40060096979141, 66.13441005349159, 66.67698293924332, 66.90786615014076, 59.78623889386654, 49.26570922136307, 50.28704881668091, 49.782652482390404, 54.841628819704056, 61.760286167263985, 68.75784248113632, 68.5942080616951, 65.41383191943169, 69.97103378176689, 68.82777392864227, 66.68373137712479, 69.06990453600883, 70.23115262389183, 71.06659859418869, 69.30812135338783, 72.49422758817673, 69.39515948295593, 73.09898793697357, 69.63578537106514, 69.99881789088249, 70.82952931523323, 72.14676663279533, 72.06922799348831, 75.98168045282364, 75.2031934261322, 75.4127749800682, 63.66881735622883, 69.00502681732178, 8.613092824816704, 0.8016529586166143, 3.0444175377488136, 2.7576920483261347, 2.932064929045737, 0.9901146520860493, 0.19853323115967214, 0.2592956816079095, 20.129226073622704, 74.52521860599518, 43.33628699183464, 47.52118483185768, 44.41720739006996, 41.601383686065674, 39.671178460121155, 48.98452050983906, 1.638143991585821, 0.17320288490736857, 0.02697980286029633, 0.0144650704896776, 0.06507736383355223, 0.08490012827678584, 0.027161100260855164, 0.01633083160413662, 0.051870756869902834, 0.07471112345228903, 0.05414023333287332, 0.034631423332029954, 0.05363098644011188, 0.04643402418878395, 0.023980067926459014, 0.05428007621958386, 0.017275093923672102, 0.040801969371386804, 0.06960309168789536, 0.08301375215523876, 0.024194032812374644, 0.03362034731253516, 0.06837159409769811, 0.06286854681093246, 1.5254400204867125, 66.89184620976448, 59.0908458083868, 51.87738507986069, 35.94258293509483, 70.9487821161747, 64.94398713111877, 7.512006433680654, 0.3359742014436051, 1.7493773228488863, 2.1727025136351585, 3.2115774555131793, 0.550756340380758, 9.714767709374428, 91.00884050130844, 99.66334730386734, 98.52026984095573, 88.97153422236443, 88.56331452727318, 89.44690391421318, 95.00696316361427, 87.7765591442585, 92.136961966753, 91.39029443264008, 94.21800389885902, 90.42266115546227, 87.63727381825447, 88.07687222957611, 86.16771787405014, 88.09767231345177, 88.71032103896141, 89.05574530363083, 81.92031338810921, 78.6595031619072, 70.10190635919571, 65.62607333064079, 63.80104646086693, 63.42557340860367, 63.04926440119743, 63.19718286395073, 59.87321622669697, 57.5105220079422, 60.39192259311676, 58.87438282370567, 59.092441722750664, 57.25513391196728, 58.83858114480972, 60.29606133699417, 67.83291131258011, 69.43833276629448, 73.3632181584835, 75.86353719234467, 77.40280419588089, 72.6231698691845, 70.89610934257507, 72.22037628293037, 74.12967503070831, 72.50957116484642, 63.11824589967728, 57.61079102754593, 63.753032237291336, 69.38576638698578, 70.50496593117714, 67.55726650357246, 57.11749769747257, 55.917111709713936, 60.55269196629524, 57.652273401618004, 66.27228945493698, 70.61696872115135, 67.79818877577782, 66.03198274970055, 64.83003124594688, 69.11313101649284, 64.35433477163315, 66.45534083247185, 64.27329272031784, 65.60625359416008, 66.4872895181179, 65.17379119992256, 64.56149965524673, 66.28475278615952, 67.23003566265106, 62.40706466138363, 59.982494562864304, 60.12734659016132, 58.004449903964996, 58.34133222699165, 55.377954840660095, 61.082451939582825, 62.393605783581734, 65.62075361609459, 63.51198457181454, 63.92121121287346, 65.51771074533463, 68.42396959662437, 64.7882866859436, 72.40735664963722, 67.7387523651123, 65.62835320830345, 67.58309751749039, 66.7773887515068, 67.27725952863693, 68.58730763196945, 67.37722456455231, 68.95983964204788, 68.57183486223221, 61.87428764998913, 53.832079991698265, 53.677717074751854, 51.06324456632137, 57.65581101179123, 65.30334144830704, 71.4956183731556, 70.58891102671623, 68.40221956372261, 72.40221932530403, 73.54666471481323, 68.60609382390976, 70.24758294224739, 71.73702701926231, 72.70567864179611, 71.93824142217636, 73.98719027638435, 71.40582919120789, 74.80910897254944, 71.47060811519623, 71.93543717265129, 72.49004781246185, 75.20004719495773, 74.89287167787552, 80.33215820789337, 77.89968073368073, 79.72159937024117, 68.15359130501747, 75.15263333916664, 14.696714580059052, 0.8628173859324306, 0.9235596796497703, 2.082320088520646, 3.452669531106949, 2.4522698996588588, 0.4788962291786447, 0.37891338171903044, 19.116016142070293, 82.99232706427574, 50.83293132483959, 48.08061741292477, 35.8870755136013, 48.519083485007286, 48.82710635662079, 60.37941366434097, 2.8981909342110157, 0.044154736533528194, 0.11072516048443504, 0.00946143014516565, 0.03140776389045641, 0.06079482292989269, 0.023278337612282485, 0.05713029808248393, 0.039169326119008474, 0.027380939245631453, 0.027173681519343518, 0.03385349300515372, 0.16788759356131777, 0.07393056963337585, 0.1727336397743784, 0.13074725837213919, 0.1647809485439211, 0.1884782878914848, 0.21275897015584633, 0.1942938461434096, 0.18100560293532908, 0.13185512158088386, 0.15598832425894216, 0.2577629388542846, 1.9480252009816468, 74.9910432100296, 69.6376396715641, 52.01100870966911, 53.38207773864269, 81.71972215175629, 77.0501147210598, 12.844010945409536, 0.4092414246406406, 3.9173484966158867, 7.7359730657190084, 6.6754646971821785, 4.783416548743844, 10.318155381828547, 90.65613582730293, 106.50111079216003, 102.20636084675789, 93.48052427172661, 92.68848717212677, 93.90186086297035, 97.71688655018806, 92.62673288583755, 96.96296900510788, 94.68401849269867, 97.45504260063171, 94.26413342356682, 90.50548911094666, 91.06234923005104, 91.1535595357418, 92.61854812502861, 91.35220527648926, 92.78071582317352, 85.57266220450401, 82.52004280686378, 70.98866477608681, 71.16413176059723, 66.3210940361023, 68.21251854300499, 67.4434170126915, 67.41060957312584, 62.666427344083786, 60.34147650003433, 63.65057073533535, 62.72460602223873, 62.830255553126335, 60.84579683840275, 61.64289906620979, 62.17669442296028, 68.49201634526253, 72.31088742613792, 76.29596918821335, 78.98306339979172, 79.29419070482254, 74.49433386325836, 75.33003062009811, 74.90757688879967, 79.54243898391724, 76.2695986032486, 69.01720896363258, 61.121392250061035, 68.86340081691742, 74.93352189660072, 75.97978055477142, 71.6355648636818, 62.28551298379898, 61.53903163969517, 64.33487981557846, 59.47579935193062, 68.0562861263752, 75.42013138532639, 72.26658180356026, 69.66686010360718, 67.65980020165443, 72.15563535690308, 66.76942437887192, 70.86701810359955, 66.78669065237045, 67.11912721395493, 69.32998538017273, 65.76411992311478, 67.00542971491814, 70.48930317163467, 69.86204043030739, 64.28850710391998, 61.63073971867561, 63.28750781714916, 62.28891380131245, 60.420945435762405, 59.125226363539696, 65.88232398033142, 66.67779609560966, 69.61315378546715, 66.00295230746269, 66.42689555883408, 69.52800035476685, 71.27056404948235, 68.20751041173935, 71.41355037689209, 70.87346255779266, 72.16861546039581, 69.75367024540901, 69.32070627808571, 71.58397883176804, 71.72604560852051, 69.84469816088676, 72.07692638039589, 73.52784812450409, 64.60064515471458, 56.81907311081886, 55.497534424066544, 55.00402070581913, 60.987293645739555, 68.0445371568203, 75.11344984173775, 74.13535952568054, 69.68452155590057, 72.8869441151619, 75.31176880002022, 71.7400136590004, 74.11006048321724, 76.53288647532463, 75.82779631018639, 75.08109837770462, 78.76276642084122, 73.39064508676529, 78.93197134137154, 75.99934950470924, 76.84426456689835, 77.80467063188553, 78.91236439347267, 79.38989236950874, 82.38275617361069, 81.00863590836525, 82.46253669261932, 71.82606384158134, 78.72396290302277, 15.800842233002186, 2.3552651423960924, 8.455795515328646, 7.837600512430072, 10.66650453954935, 4.073695857077837, 0.3333080210722983, 0.36252444551791996, 26.115041077136993, 93.01071748137474, 57.126609608531, 65.21899357438087, 58.53460505604744, 54.396197721362114, 53.96212801337242, 72.86618202924728, 4.303447678685188, 0.43528113048523664, 0.24676404311321676, 0.2443307189969346, 0.1225161727052182, 0.20921879215165973, 0.15803966496605426, 0.14087830146308988, 0.13748564757406712, 0.12992553762160242, 0.18994759186170995, 0.07363804470514879], [0.056871834021876566, 0.07296918411157094, 0.019141639859299175, 0.08529420869308524, 0.03555370138201397, 0.0743813649751246, 0.07118578840163536, 0.005699671428374131, 0.13707803038414568, 0.06367661204421893, 0.24613385583506897, 0.18720139312790707, 6.826322777196765, 68.85882586240768, 58.2084571570158, 40.934158489108086, 52.91786424815655, 82.50904619693756, 31.90286010503769, 1.4884836785495281, 0.19613674725405872, 0.44261865550652146, 0.7726383686531335, 1.5998361096717417, 0.471353693283163, 34.574945122003555, 97.13833719491959, 92.61392757296562, 90.63342824578285, 81.2515264749527, 80.02852410078049, 91.52725428342819, 90.10375946760178, 92.39437535405159, 86.1869828402996, 90.19892916083336, 85.02436682581902, 89.81461778283119, 87.27386131882668, 88.19332078099251, 82.92419672012329, 84.03738498687744, 81.49371787905693, 79.81954291462898, 82.32578203082085, 71.68474182486534, 64.60599526762962, 61.7106494307518, 58.24360907077789, 62.43265628814697, 61.037466153502464, 59.74269703030586, 55.19602060317993, 56.12284407019615, 54.89449918270111, 54.82343539595604, 55.31233236193657, 55.04491791129112, 56.71460151672363, 64.0816006064415, 66.05590626597404, 69.8086304962635, 74.11187678575516, 71.15663856267929, 70.8992251753807, 70.21585464477539, 68.56948658823967, 70.37305220961571, 66.94479256868362, 66.78640946745872, 59.36459071934223, 57.01467141509056, 62.71501153707504, 65.52949011325836, 68.95675420761108, 61.1728148907423, 51.355581879615784, 50.17433926463127, 56.69292747974396, 63.41844119131565, 67.5339737534523, 67.67927795648575, 66.93521708250046, 66.89123064279556, 66.15029320120811, 66.90840572118759, 63.508021384477615, 64.29106816649437, 63.22435900568962, 62.02476717531681, 61.53428189456463, 63.90336737036705, 63.772950768470764, 60.354110822081566, 62.96573728322983, 65.89485570788383, 59.34377543628216, 57.62221701443195, 56.59439116716385, 53.913319632411, 55.861380100250244, 57.768357172608376, 60.709517151117325, 62.48046152293682, 61.50326415896416, 62.055967301130295, 66.06080040335655, 64.44354638457298, 72.42421254515648, 66.4326636493206, 62.97813221812248, 62.607644498348236, 64.3022471666336, 62.240838780999184, 65.47760009765625, 64.88525748252869, 63.73418524861336, 63.19997191429138, 62.5164607912302, 56.93060852587223, 51.311044469475746, 51.40146441757679, 49.4086005538702, 51.81609816849232, 59.445655569434166, 66.17727175354958, 69.11333620548248, 69.90945428609848, 67.70494937896729, 68.77534434199333, 66.80942103266716, 63.07094983756542, 66.54210537672043, 68.91113385558128, 66.90388396382332, 68.01110655069351, 65.66810667514801, 65.48987343907356, 65.05438640713692, 66.80595561861992, 68.85346814990044, 75.22367432713509, 73.8773001730442, 75.26573047041893, 74.32531893253326, 76.50096818804741, 69.4907395541668, 66.8007954955101, 53.69789019227028, 0.17850213102065027, 0.5799064168240875, 2.445109896361828, 1.1214170814491808, 1.835327879525721, 0.2514537930255756, 0.06824114680057392, 4.239926962181926, 68.43214675784111, 52.87972189486027, 46.03653609752655, 50.39216257631779, 65.58464795351028, 41.97325073182583, 48.630816489458084, 4.076039381325245, 0.14218914206139743, 0.15864136861637235, 0.059534722968237475, 0.1265794163919054, 0.005359700535336742, 0.04714267131930683, 0.024760404667176772, 0.045562100858660415, 0.026861409896810073, 0.06562627109815367, 0.018873166081903037, 0.04607424954883754, 0.05375400112825446, 0.06617227656533942, 0.03202549793059006, 0.03375000051164534, 0.05967715595033951, 0.09914420574204996, 0.04422744103067089, 0.14357235690113157, 0.013802193461742718, 0.23502004594774917, 0.36644494452048093, 9.92826210334897, 79.32094886898994, 64.14195656776428, 50.492534190416336, 38.390062004327774, 89.57617297768593, 36.08092591166496, 1.1834157421253622, 0.5692049441859126, 3.1600146973505616, 2.193407127633691, 2.7232281351462007, 0.4980305180652067, 41.461201608181, 99.92358013987541, 93.78726661205292, 92.86249503493309, 84.09662380814552, 83.99243339896202, 94.80108261108398, 91.6464538872242, 92.83594205975533, 88.89487713575363, 92.72810384631157, 86.7291833460331, 91.99163496494293, 88.20889994502068, 89.68853294849396, 86.26807048916817, 86.46570548415184, 85.1754543185234, 83.93260180950165, 83.80045250058174, 74.9377852678299, 68.06033670902252, 64.95930030941963, 60.140999257564545, 64.7804819047451, 65.26142209768295, 61.92388258874416, 58.27703207731247, 58.40016067028046, 57.600558176636696, 59.409948885440826, 60.535277500748634, 58.53326752781868, 59.86483007669449, 68.53040188550949, 69.68646705150604, 73.99636298418045, 78.58693465590477, 74.01136457920074, 73.18383738398552, 70.9492076933384, 72.96202808618546, 71.31651118397713, 72.69462123513222, 69.70583841204643, 61.531534641981125, 60.349410474300385, 65.7483659684658, 67.88128271698952, 71.15591660141945, 65.65621331334114, 56.78545631468296, 57.04327628016472, 58.29814374446869, 66.41874119639397, 69.14606004953384, 71.37850865721703, 71.24423906207085, 67.82142832875252, 67.41390779614449, 68.83813977241516, 66.4227157831192, 66.85650810599327, 64.85973045229912, 64.25064593553543, 62.13960461318493, 65.00766411423683, 64.49390888214111, 63.37066635489464, 64.41924288868904, 66.21565729379654, 62.62171134352684, 61.8511126935482, 60.85571430623531, 55.66380590200424, 60.59952065348625, 60.20403407514095, 64.9049860239029, 63.21403495967388, 66.54861822724342, 63.824384808540344, 69.84759360551834, 64.1756683588028, 76.60336509346962, 68.46947595477104, 63.36902864277363, 65.29158487915993, 67.17431545257568, 65.79388752579689, 66.40377759933472, 67.12617203593254, 67.70696327090263, 66.20985880494118, 65.07262542843819, 58.71444180607796, 53.59014317393303, 52.381998002529144, 52.19787888228893, 54.19850192964077, 62.27733962237835, 70.44461756944656, 72.97352626919746, 70.02068191766739, 71.0391716659069, 69.78403061628342, 69.99224424362183, 64.10293266177177, 68.11715126037598, 70.37449613213539, 70.44195771217346, 70.76634630560875, 69.79494363069534, 68.55953872203827, 68.16626742482185, 69.90606486797333, 72.2064234316349, 76.63521498441696, 76.03024944663048, 76.45486146211624, 76.27211406826973, 77.36691892147064, 72.66012668609619, 71.41171127557755, 62.96375758945942, 1.33243567077443, 0.7384688209276646, 0.6282924266997725, 2.243825434707105, 3.810342913493514, 0.8668905892409384, 0.20917257119435817, 3.575525963678956, 71.02422326803207, 61.24531500041485, 49.48735132813454, 40.26072442531586, 67.42791384458542, 49.33283641934395, 58.10163348913193, 5.481352647766471, 0.22936345572816208, 0.1643936216714792, 0.06599866595934145, 0.11056745410314761, 0.04341488951467909, 0.09190851080347784, 0.013581340517703211, 0.03256159572629258, 0.07858196535380557, 0.0359090454003308, 0.038304917034110986, 0.13726934121223167, 0.2753137517720461, 0.18125478643923998, 0.1395761439925991, 0.1062977449328173, 0.14581294526578858, 0.17972737230593339, 0.1896708449930884, 0.2845664630876854, 0.29748009983450174, 0.45070904481690377, 0.5771459243260324, 12.308585476130247, 89.75675448775291, 73.3478669822216, 53.940564170479774, 72.21406102180481, 102.0677974820137, 48.896106854081154, 2.2492130706086755, 0.31170273665338755, 4.345324281603098, 4.867810970172286, 7.940118061378598, 2.1184475999325514, 45.037778690457344, 103.34315344691277, 100.58971479535103, 95.66665336489677, 89.67445090413094, 86.89677715301514, 100.12373819947243, 94.52449545264244, 97.29160577058792, 92.97319829463959, 97.11505964398384, 90.92863440513611, 97.52343133091927, 92.53723248839378, 91.28751754760742, 88.13763856887817, 89.45718616247177, 90.5702756345272, 88.97595718502998, 88.56338292360306, 78.39233949780464, 71.47750094532967, 68.53215739130974, 63.7443421036005, 69.68538790941238, 68.04329842329025, 66.69905975461006, 61.96583613753319, 63.365312442183495, 60.3249853849411, 62.28971175849438, 62.19768829643726, 62.430961579084396, 61.01997569203377, 72.03287914395332, 72.641781270504, 75.93273907899857, 79.41631615161896, 78.05323049426079, 74.76934790611267, 74.70770001411438, 75.88575080037117, 75.42971447110176, 73.53932350873947, 74.67987030744553, 64.29878935217857, 62.970639020204544, 70.24196684360504, 70.87063550949097, 76.00241973996162, 70.7673342525959, 61.15064688026905, 62.32536144554615, 63.179247826337814, 68.49355146288872, 72.02826619148254, 73.56244906783104, 74.37835648655891, 73.5999758541584, 72.03922480344772, 72.20045015215874, 69.83554065227509, 71.31692916154861, 69.10388991236687, 67.70360425114632, 66.21242746710777, 71.75509884953499, 71.77750244736671, 65.52762821316719, 68.9006008207798, 68.72443467378616, 66.31195932626724, 63.73077683150768, 65.28772428631783, 60.65689377486706, 63.98251712322235, 66.14887967705727, 66.20745733380318, 68.5281752049923, 70.53312242031097, 69.05106514692307, 72.45129749178886, 69.01884287595749, 73.68458971381187, 71.12062409520149, 69.9176162481308, 67.60487034916878, 71.2672658264637, 67.00245827436447, 71.20181053876877, 71.29980728030205, 72.91152119636536, 69.36004176735878, 68.13873410224915, 63.528737872838974, 56.4411985874176, 57.48964212834835, 55.0311778485775, 57.69933767616749, 65.39731800556183, 72.09796205163002, 76.80706456303596, 74.36112821102142, 73.37871372699738, 71.76498591899872, 74.02255117893219, 69.47560876607895, 73.37583348155022, 74.48073819279671, 72.08595469594002, 73.45611557364464, 72.86818072199821, 71.2911057472229, 70.92368826270103, 71.20264649391174, 76.38326570391655, 79.54860225319862, 79.97898235917091, 78.22554364800453, 81.42812579870224, 80.87908565998077, 75.4671348631382, 74.33984935283661, 65.28849184513092, 1.1527144582942128, 3.509670034982264, 6.939137298613787, 5.122264316305518, 7.237575659528375, 0.9071716340258718, 0.32643766317050904, 5.449601076543331, 81.00255623459816, 65.48626363277435, 63.73946696519852, 66.49155288934708, 76.28449380397797, 55.557141825556755, 71.14381045103073, 6.861636182293296, 0.26765906251966953, 0.21193710097577423, 0.3498535801190883, 0.4238252202048898, 0.12490709050325677, 0.17952708149095997, 0.22422742273192853, 0.15066770429257303, 0.13703816221095622, 0.12503046513302252, 0.13326771062565967], [0.09820389721426181, 0.0717720999091398, 0.047386678343173116, 0.04915751691441983, 0.012469575467548566, 0.03300579708593432, 0.08729943234357052, 0.03200962710252497, 0.06723405240336433, 0.09924412850523368, 0.2501746272901073, 0.3683366789482534, 17.627731002867222, 67.83122420310974, 43.15507471561432, 37.76854455471039, 61.89779318869114, 67.02744573354721, 17.015285566449165, 0.04862403518927749, 0.21409427194157615, 0.8276034879963845, 0.754814890678972, 2.3643870279192924, 0.7180279365275055, 57.73015782237053, 96.66950315237045, 92.44352951645851, 85.83721920847893, 75.19844368100166, 78.47277358174324, 79.84244048595428, 88.78683373332024, 93.13653632998466, 96.9793689250946, 84.66286182403564, 87.29357466101646, 86.54882982373238, 89.33584347367287, 85.8226127922535, 84.54471856355667, 78.37914660573006, 81.53518125414848, 83.64909902215004, 78.25680837035179, 68.96018922328949, 64.14562717080116, 59.06553916633129, 58.79760794341564, 61.56237758696079, 61.67119614779949, 59.17634882032871, 57.83850900828838, 53.720251992344856, 55.17663784325123, 55.91342590749264, 56.27456992864609, 56.501904129981995, 63.41078840196133, 67.75388315320015, 68.28723773360252, 72.78743505477905, 71.20215252041817, 70.8999091386795, 67.30193540453911, 70.9684194624424, 70.36156922578812, 68.47788870334625, 66.5884780883789, 61.74062602221966, 60.23882880806923, 60.929677337408066, 64.52938377857208, 67.79808238148689, 64.49932739138603, 59.133373126387596, 53.0222674459219, 51.98469132184982, 60.333333536982536, 66.50978431105614, 68.4645514190197, 64.88743856549263, 62.21661888062954, 57.7883592993021, 59.67749632894993, 60.62827371060848, 59.4909643381834, 61.15277856588364, 58.872634917497635, 56.450960263609886, 61.4936962723732, 53.4548894315958, 55.58149851858616, 55.46031542122364, 57.555667385458946, 63.10456283390522, 64.25702959299088, 55.51017254590988, 55.328097715973854, 54.59361992776394, 59.69052582979202, 59.560082629323006, 59.21042159199715, 58.83553750813007, 58.00836369395256, 60.01965656876564, 62.45264321565628, 64.11198377609253, 56.8702107667923, 50.3121654689312, 63.96708235144615, 63.379120901227, 63.01615297794342, 60.9919635951519, 62.09804244339466, 59.494729936122894, 61.563270539045334, 57.293318063020706, 55.88237777352333, 53.32687810063362, 49.4942669570446, 48.639692813158035, 49.213929399847984, 50.129794254899025, 59.872596859931946, 68.27149897813797, 67.74221777915955, 69.37167674303055, 67.11615577340126, 67.41114154458046, 60.45933477580547, 58.38421292603016, 58.04797276854515, 63.00520196557045, 65.00201001763344, 65.08251249790192, 63.848695904016495, 66.08616024255753, 67.35272347927094, 69.40649047493935, 72.77909070253372, 72.76625499129295, 74.01833340525627, 75.22349953651428, 76.79080903530121, 73.10016587376595, 76.07438027858734, 63.512976318597794, 73.17368432879448, 25.1313004642725, 0.7789908559061587, 0.2150138225988485, 2.827983764000237, 2.3532213270664215, 1.1764505971223116, 0.1373813016107306, 0.24999523535370827, 44.1391459107399, 67.92154535651207, 47.892717495560646, 46.24333620071411, 19.34773910790682, 35.05067579448223, 54.57867532968521, 5.350177986547351, 0.18922019808087498, 0.10737817836343311, 0.023260422167368233, 0.03783134889090434, 0.020498369303822983, 0.04136683652177453, 0.010475747494638199, 0.044405218795873225, 0.06456659553805366, 0.055541207766509615, 0.033173900956171565, 0.11517046179505996, 0.0393115401675459, 0.03897241949744057, 0.014175342530506896, 0.07235982149722986, 0.034654949413379654, 0.08620774795417674, 0.09299508921685629, 0.12962363194674253, 0.07663509677513503, 0.28213860117830336, 0.5077531572896987, 23.810707926750183, 74.53186064958572, 52.39916168153286, 49.482346996665, 48.34097184240818, 75.90645208954811, 17.498254850506783, 0.022086285171099007, 0.8048997656442225, 4.43776904605329, 1.7337405681610107, 0.644371738890186, 1.0892389831133187, 67.95821338891983, 98.89942109584808, 97.27832168340683, 86.24701201915741, 79.14249524474144, 80.40182366967201, 82.25873842835426, 90.13554096221924, 93.18643525242805, 96.30121171474457, 88.41881588101387, 89.06012266874313, 90.54233953356743, 94.17036205530167, 90.53727820515633, 88.29255625605583, 81.8003462255001, 83.124780356884, 86.9476792216301, 81.22824132442474, 72.09587216377258, 66.05026736855507, 60.65584883093834, 61.055868566036224, 64.40880104899406, 64.8994155228138, 61.64538413286209, 59.90436315536499, 58.531762808561325, 58.65652531385422, 58.446369990706444, 60.22080637514591, 59.15426440536976, 64.72880467772484, 70.52979379892349, 70.86080923676491, 75.63463747501373, 73.82829800248146, 73.35314109921455, 69.93031516671181, 74.85449373722076, 73.54022786021233, 72.90159612894058, 67.53585085272789, 65.55725142359734, 61.74857899546623, 65.41257038712502, 66.76500141620636, 71.02541640400887, 67.26486459374428, 60.51586054265499, 60.189431458711624, 56.251045390963554, 63.82288008928299, 67.64196395874023, 70.39789527654648, 66.91320866346359, 64.64982211589813, 62.34545856714249, 62.67600283026695, 63.46252642571926, 61.03976123034954, 62.98853226006031, 63.832463175058365, 61.364704594016075, 65.63257858157158, 58.12944419682026, 60.732429921627045, 58.48854772746563, 61.9293162971735, 65.33462896943092, 65.2082933485508, 59.26519565284252, 58.069946989417076, 58.12778748571873, 62.332242876291275, 61.96319907903671, 62.86630421876907, 63.15823495388031, 61.57697640359402, 62.34103940427303, 63.20445567369461, 66.33617162704468, 60.66435657441616, 54.71416845917702, 67.18888387084007, 64.55646112561226, 66.82950675487518, 61.75687775015831, 63.07121202349663, 61.9405484944582, 62.421458289027214, 61.84668593108654, 59.631435200572014, 56.2203848361969, 54.57713261246681, 52.653934210538864, 50.322975888848305, 53.42217318713665, 61.2432137131691, 71.18884563446045, 69.95374470949173, 72.54143625497818, 69.098000228405, 67.89602592587471, 62.558919712901115, 59.345933720469475, 59.73735071718693, 65.63133224844933, 65.46395123004913, 67.6498219370842, 66.9186119735241, 68.64275425672531, 69.83839049935341, 72.66967937350273, 73.79598453640938, 75.06955459713936, 75.35782992839813, 75.42884051799774, 77.78837710618973, 74.15494367480278, 77.33556300401688, 66.7365637421608, 77.45535537600517, 33.042130172252655, 0.1430123025784269, 0.3668820101302117, 2.094917125068605, 5.04407306201756, 2.796427169814706, 0.15055648604175076, 0.28516792925074697, 48.153197318315506, 76.61710515618324, 55.19742272794247, 36.28001242876053, 27.33559638261795, 42.6362581551075, 63.38485099375248, 7.104155793786049, 0.12948182236868888, 0.06942561449250206, 0.08968752998043783, 0.06019733838911634, 0.029658009734703228, 0.06389369023963809, 0.02527495234971866, 0.10847498357179575, 0.0558888371597277, 0.019012123957509175, 0.009610883844288765, 0.3022743738256395, 0.20481760409893468, 0.20918735477607697, 0.11895148156327195, 0.13418516842648387, 0.12484881706768647, 0.20533820585114881, 0.16680879285559058, 0.22686471871566027, 0.17428460967494175, 0.386856499244459, 0.6113254465162754, 25.435705929994583, 92.09020927548409, 53.906966373324394, 51.277351677417755, 80.23920759558678, 86.77751675248146, 27.562128826975822, 0.08795218091108836, 0.5670709430705756, 6.001489162445068, 4.172431658953428, 6.214852938428521, 1.7491422104649246, 71.58409282565117, 103.93374815583229, 101.43890082836151, 91.76610186696053, 81.14858999848366, 84.89820599555969, 84.7091357409954, 97.48509138822556, 94.11822125315666, 99.80185747146606, 91.33202835917473, 92.8570157289505, 93.57525318861008, 95.98315358161926, 92.7955350279808, 92.13179424405098, 87.81908646225929, 87.98097297549248, 90.67616075277328, 86.81266486644745, 73.61126124858856, 70.12624025344849, 61.92400798201561, 64.91274520754814, 68.57391715049744, 69.00913059711456, 65.62115639448166, 63.79161536693573, 60.03718502819538, 61.37824326753616, 62.44152121245861, 65.00199481844902, 61.38894349336624, 69.50714707374573, 74.77925017476082, 75.03790229558945, 79.75042462348938, 76.41756266355515, 76.35827824473381, 72.33078315854073, 77.03595668077469, 77.7361299097538, 74.72716256976128, 71.18538782000542, 67.41988867521286, 65.00784650444984, 69.59236890077591, 70.8374784886837, 74.03046235442162, 73.18757638335228, 66.54844343662262, 64.57058116793633, 61.36831060051918, 67.25816175341606, 72.27870315313339, 74.80790823698044, 72.73312836885452, 67.94615283608437, 65.17977207899094, 65.45313701033592, 67.23407864570618, 64.73703503608704, 67.5591816008091, 67.86195695400238, 62.794746458530426, 69.40196111798286, 59.78154234588146, 61.5039899200201, 59.926766753196716, 64.13834676146507, 69.52267304062843, 68.02673891186714, 62.74058796465397, 62.56835080683231, 62.73900344967842, 68.1856919825077, 67.01171457767487, 67.3974546790123, 69.09089460968971, 66.02686062455177, 65.43113619089127, 68.59816744923592, 69.11350339651108, 58.43870960175991, 57.53261022269726, 70.11120066046715, 68.22106048464775, 71.38841852545738, 67.4891209602356, 69.33602705597878, 65.7666277885437, 68.0333961546421, 65.98391532897949, 63.654845505952835, 59.95209999382496, 56.53244309127331, 55.514633506536484, 53.10713969171047, 55.83361119031906, 66.74250662326813, 76.37386500835419, 71.01666167378426, 72.69831463694572, 72.32522025704384, 72.8209188580513, 65.2071762084961, 62.72427923977375, 62.44987316429615, 69.27450835704803, 69.27485033869743, 72.58814334869385, 69.84280586242676, 72.46182292699814, 73.61560061573982, 75.0093886256218, 78.1188377737999, 79.3114721775055, 80.24942144751549, 80.69787338376045, 82.81636610627174, 79.39146548509598, 79.66547638177872, 68.47497045993805, 83.52736875414848, 31.31810948252678, 1.0210614977404475, 4.4273357558995485, 10.40593447163701, 9.051248263567686, 3.2062494289129972, 0.2564896806143224, 0.4214555723592639, 56.05684541165829, 81.2661100924015, 65.90046420693398, 61.275504380464554, 28.248953372240067, 47.8728711605072, 73.2623715698719, 8.416459076106548, 0.36420514283236116, 0.36596988094970584, 0.241556704568211, 0.16369993623811752, 0.11463437142083421, 0.14849649189272895, 0.09133917221333832, 0.16802284255390987, 0.12114449826185592, 0.1720516209024936, 0.069588961196132], [0.11514231213368475, 0.12937809980940074, 0.02480299095623195, 0.021704184873669874, 0.0536540004395647, 0.03510559632559307, 0.0830705116095487, 0.07487642942578532, 0.057384120009373873, 0.09499637948465534, 0.061357749364105985, 0.1065679757448379, 29.570929035544395, 69.73391890525818, 40.28267204761505, 30.684054605662823, 44.557765647768974, 55.231343507766724, 5.836540013551712, 0.02355324395466596, 1.2090243492275476, 2.827274389564991, 0.31474987627007067, 1.0327687882818282, 5.219163866713643, 76.81633606553078, 96.49183228611946, 90.95305189490318, 85.91472744941711, 80.15344619750977, 69.63023006916046, 74.7362668812275, 81.24804586172104, 89.6997119486332, 92.49187052249908, 92.25214898586273, 85.11670187115669, 88.99013042449951, 83.36320236325264, 83.92033606767654, 80.55679455399513, 83.58580201864243, 81.48550271987915, 80.00931993126869, 72.3365968465805, 68.18115502595901, 60.09353220462799, 62.98461467027664, 59.706503972411156, 58.21785405278206, 57.9227314889431, 57.0417145639658, 56.43679082393646, 54.57396738231182, 53.52665238082409, 53.367167338728905, 55.41052669286728, 60.82553252577782, 63.80964919924736, 66.016935557127, 66.7198446393013, 68.30834180116653, 72.9178136587143, 69.97270569205284, 65.32999321818352, 66.45618438720703, 68.74170854687691, 68.8971734046936, 64.17787224054337, 58.32478791475296, 60.79674147069454, 65.23193567991257, 66.24228626489639, 69.801334887743, 61.60392835736275, 56.66441760957241, 52.99408435821533, 54.69342537224293, 64.24241557717323, 65.3714793920517, 65.97867920994759, 59.8281392455101, 62.06281453371048, 68.41639280319214, 66.20612740516663, 57.81630299985409, 56.50929093360901, 59.399434849619865, 60.44196590781212, 61.438485234975815, 61.807886213064194, 63.596397042274475, 65.94385027885437, 64.54753920435905, 61.12301096320152, 58.432667925953865, 61.39725744724274, 57.03506492078304, 52.72538557648659, 55.37039324641228, 58.747256845235825, 60.50178609788418, 59.111429303884506, 55.06819926202297, 54.48784880340099, 57.120457738637924, 59.066519513726234, 60.452434346079826, 48.35319198668003, 59.13244217634201, 63.94365280866623, 60.36432087421417, 54.98030997812748, 54.05565619468689, 52.03208617866039, 51.68631613254547, 51.49572975933552, 53.20508323609829, 51.78416088223457, 53.2942720502615, 48.15769627690315, 49.54495243728161, 50.97086012363434, 52.879847288131714, 58.26880931854248, 65.63673555850983, 65.91190159320831, 69.9303987622261, 65.78193336725235, 67.42727547883987, 58.19197364151478, 54.54350061714649, 55.372129753232, 63.59323561191559, 62.698858603835106, 66.96588903665543, 64.34289738535881, 66.45166262984276, 67.87504345178604, 71.45481616258621, 73.97761479020119, 73.16018745303154, 70.01431345939636, 75.0450611114502, 70.96390530467033, 75.53289413452148, 69.13133203983307, 81.19873210787773, 60.677918046712875, 69.73537802696228, 5.521164061501622, 0.4009005456464365, 1.465561764780432, 3.0264333402737975, 0.9823801077436656, 0.03366805256519001, 0.10257536225253716, 20.53887639194727, 77.64988973736763, 47.155439257621765, 46.42744392156601, 27.79430016875267, 37.86810301244259, 52.972562313079834, 7.951909778639674, 0.30902684899047017, 0.14879633439704776, 0.07206770475022495, 0.11051483583287336, 0.05933982756687328, 0.06707588589051738, 0.0551252414152259, 0.06656726240180433, 0.08005587063962594, 0.04602203574904706, 0.03696260195283685, 0.06382615480106324, 0.09084422650630586, 0.04182953962299507, 0.07526926303398795, 0.09792729877517559, 0.049968053499469534, 0.08256582892499864, 0.006623105837206822, 0.07152277539717034, 0.036906009481754154, 0.12485050916438922, 0.12400814186548814, 39.15433779358864, 77.06317082047462, 53.21125030517578, 31.77353974431753, 43.00244830548763, 66.53280347585678, 6.70192695222795, 0.12720831233309582, 1.9220493198372424, 5.2134124003350735, 2.205807762220502, 1.2061697524040937, 6.151206828653812, 83.85249450802803, 94.82832714915276, 92.2912260890007, 86.20877087116241, 81.00941866636276, 72.64056533575058, 79.53341826796532, 83.3526237308979, 92.83226385712624, 93.19550156593323, 93.48458245396614, 87.15598404407501, 90.09510353207588, 87.1112984418869, 87.48548716306686, 83.75088796019554, 86.87225326895714, 83.82575914263725, 81.58111318945885, 76.89103245735168, 70.57376503944397, 61.362337321043015, 65.089610517025, 61.65549919009209, 59.652805253863335, 60.76694346964359, 61.169721856713295, 59.737339317798615, 58.91887843608856, 55.48942565917969, 57.75424852967262, 56.314338594675064, 62.232274040579796, 66.24357059597969, 71.00128009915352, 70.58890342712402, 71.04891434311867, 74.9762924015522, 71.03032574057579, 69.5247933268547, 68.83766859769821, 73.87872889637947, 70.98500177264214, 65.16144946217537, 62.09634393453598, 64.12681818008423, 68.88008952140808, 71.9769537448883, 71.9555912911892, 64.79510352015495, 62.537979036569595, 56.846910417079926, 58.391584530472755, 68.64202469587326, 68.27227413654327, 66.61186963319778, 64.45463418960571, 66.30496770143509, 68.59324291348457, 68.85770872235298, 60.20542860031128, 60.24256020784378, 64.26795780658722, 62.27555751800537, 65.43241292238235, 64.66767355799675, 66.60406485199928, 70.82473397254944, 68.7762638926506, 66.5566585958004, 60.50754278898239, 64.78206261992455, 59.267832711339, 55.9563560038805, 58.6608000844717, 62.95030631124973, 62.1673659235239, 61.71533077955246, 57.43528984487057, 58.23766618967056, 58.69308315217495, 60.54626651108265, 64.07549053430557, 56.479120552539825, 62.186953872442245, 63.76120939850807, 62.67684258520603, 57.629653215408325, 58.196746185421944, 54.05046567320824, 52.62254409492016, 54.61290009319782, 53.14372032880783, 53.99964340031147, 56.54082544147968, 51.77327446639538, 51.29611127078533, 53.92702929675579, 54.56694155931473, 60.84099389612675, 68.81111562252045, 69.13162842392921, 74.24204260110855, 68.36013302206993, 70.189278870821, 60.169759914278984, 57.49103285372257, 57.91700519621372, 65.37565916776657, 65.39607167243958, 69.37484577298164, 67.35554292798042, 68.29615965485573, 70.75553968548775, 74.00277704000473, 74.07776221632957, 75.176952034235, 71.6835942864418, 77.54406541585922, 72.35703974962234, 77.2539433836937, 70.56929647922516, 83.41844379901886, 66.10356330871582, 76.02334141731262, 10.774890873581171, 0.29225959558971226, 1.0259170434437692, 2.586060483008623, 4.559454191476107, 1.646639029495418, 0.2653939387528226, 21.804388985037804, 81.19989484548569, 57.03827954828739, 43.97376358509064, 27.82210897654295, 47.10207872092724, 59.54414628446102, 10.42477386072278, 0.375254979589954, 0.2574659016681835, 0.06427707630791701, 0.10859659189009108, 0.09450484765693545, 0.10674221717636101, 0.05171356999198906, 0.063604757306166, 0.06947988775209524, 0.0800858014554251, 0.057205856137443334, 0.18694201251491904, 0.19804835639661178, 0.15652412519557402, 0.16711213829694316, 0.14039209083421156, 0.136711097729858, 0.16445239976746961, 0.11200276770978235, 0.190360211126972, 0.16417459904914722, 0.19816994987195358, 0.2443542450782843, 42.9653736948967, 91.89186751842499, 53.703992664813995, 41.745464354753494, 61.41632102429867, 80.74736952781677, 10.800471100956202, 0.34379783319309354, 5.111234933137894, 7.114070411771536, 5.547959748655558, 3.751331130042672, 8.098474089056253, 90.00383242964745, 102.19331994652748, 99.08458516001701, 90.39721012115479, 84.80823442339897, 75.39164051413536, 83.92794325947762, 86.5865769982338, 98.0104511976242, 95.8112508058548, 95.31711772084236, 90.38735345005989, 95.2268497645855, 90.36101326346397, 91.83711245656013, 85.58254927396774, 90.15635624527931, 87.91849672794342, 85.31534761190414, 78.06105047464371, 75.14105916023254, 65.6558409333229, 68.95962685346603, 64.14155378937721, 63.53321023285389, 65.94139561057091, 62.717466205358505, 62.16569021344185, 61.388920694589615, 58.140562400221825, 59.19575057923794, 59.588603898882866, 65.09532541036606, 68.38892787694931, 73.27203065156937, 71.50373473763466, 73.81979405879974, 77.4559785425663, 73.40940847992897, 75.22356793284416, 70.80495983362198, 76.54873162508011, 75.73312819004059, 68.99991989135742, 63.64982217550278, 67.04435482621193, 70.71514785289764, 72.58259564638138, 75.5597434937954, 70.23776426911354, 67.24572882056236, 64.29514154791832, 61.873333901166916, 71.78669795393944, 72.45885908603668, 70.12707620859146, 67.52838805317879, 69.50846180319786, 73.19734185934067, 70.2085742354393, 63.17233979701996, 61.25114768743515, 63.989698737859726, 66.22262611985207, 68.29463973641396, 66.74867749214172, 69.56703186035156, 72.44325712323189, 71.92843034863472, 68.27484279870987, 64.62486505508423, 67.41277545690536, 61.2634552270174, 59.658121168613434, 59.852571934461594, 66.95432245731354, 65.6345696747303, 65.15652492642403, 61.142967492341995, 60.225423127412796, 62.812290117144585, 65.09335711598396, 66.38597935438156, 55.02828240394592, 63.567180410027504, 69.02800798416138, 66.6431875526905, 61.84269994497299, 59.29258458316326, 57.592111229896545, 55.4700542986393, 57.16491915285587, 58.094942048192024, 57.55017668008804, 59.66264292597771, 54.73024919629097, 54.045738726854324, 57.961975783109665, 57.12701618671417, 65.69883182644844, 73.44470858573914, 71.7640283703804, 76.77380874752998, 71.57307341694832, 73.53088796138763, 63.57898637652397, 59.26836088299751, 61.0487325489521, 68.89942288398743, 68.56584638357162, 72.4382109940052, 70.76704546809196, 72.31218695640564, 75.03822147846222, 76.29886463284492, 77.58411526679993, 77.18012854456902, 74.14474502205849, 81.9949109852314, 74.9489338696003, 79.59896475076675, 72.71153032779694, 87.03894272446632, 68.14077079296112, 79.57659915089607, 9.137982409447432, 0.6223713350482285, 6.074228659272194, 9.463467244058847, 4.137388039380312, 0.6223674758803099, 0.2561975416028872, 27.366230338811874, 88.36999610066414, 62.96306602656841, 63.329237177968025, 37.947454154491425, 51.289982199668884, 72.67912566661835, 13.308091443032026, 0.5003664130344987, 0.3420239518163726, 0.16250812128419057, 0.2496527787297964, 0.22781110543292016, 0.17003842658596113, 0.1865194336278364, 0.18720133375609294, 0.18343180243391544, 0.1311187181272544, 0.15999785129679367], [0.0161437101996853, 0.07139457680750638, 0.06443913909606636, 0.07859654113417491, 0.019821471250907052, 0.10867209057323635, 0.12491844536270946, 0.06379337413818575, 0.03228975816455204, 0.05037023816839792, 0.05420766487077344, 0.012732881114061456, 41.29325062036514, 64.88814532756805, 35.09441524744034, 48.73445212841034, 50.04078023135662, 34.07397240400314, 2.15620712377131, 0.09008710971102118, 1.1434594611637294, 4.000874664634466, 1.6451303916983306, 0.1700263295788318, 10.464455131441355, 87.70971313118935, 95.09338572621346, 92.88628175854683, 86.9341291487217, 83.74723255634308, 75.94881221652031, 67.16589510440826, 73.48155900835991, 85.49206092953682, 84.2059363424778, 88.77829179167747, 86.35474383831024, 84.26447600126266, 85.84975093603134, 86.85333028435707, 83.15782338380814, 78.2075934112072, 77.50306561589241, 75.95239922404289, 70.24061411619186, 63.258963748812675, 56.682299450039864, 57.51490697264671, 59.53240491449833, 57.54091277718544, 58.11795361340046, 56.10256835818291, 56.48935720324516, 53.40571627020836, 53.356782495975494, 53.946043476462364, 56.86659336090088, 63.89454424381256, 67.57405400276184, 70.0497579574585, 69.2807400226593, 74.00591567158699, 65.54211303591728, 69.22847762703896, 66.04254618287086, 63.71047452092171, 69.79898661375046, 66.36124268174171, 61.60662241280079, 58.747291043400764, 64.95223268866539, 68.94753590226173, 70.30546143651009, 66.97066158056259, 54.7303631901741, 56.899750381708145, 52.190188094973564, 55.51771514117718, 65.65975472331047, 63.39371971786022, 63.49415212869644, 63.51739168167114, 64.25830632448196, 58.17979909479618, 61.86117835342884, 60.544032230973244, 65.72740629315376, 61.55212193727493, 59.712762236595154, 65.65340146422386, 64.65771809220314, 58.607336953282356, 57.419741079211235, 53.62977884709835, 66.63890138268471, 62.64696478843689, 59.11928728222847, 56.85967393219471, 51.029639169573784, 54.029608592391014, 59.51522223651409, 57.2261718660593, 58.34661014378071, 53.2457372546196, 54.69546966254711, 50.22754020988941, 55.17684683203697, 60.933389738202095, 49.297665506601334, 61.448645889759064, 61.360855400562286, 59.327299520373344, 55.39340481162071, 51.10052056610584, 50.24710536003113, 48.32825392484665, 50.26906818151474, 49.44502539932728, 52.12125979363918, 51.33869178593159, 49.841218739748, 50.01381307840347, 47.67723485827446, 51.262319684028625, 58.452837243676186, 66.88780322670937, 68.3550488948822, 70.57273149490356, 65.67431554198265, 64.77177277207375, 53.360118716955185, 51.44948624074459, 53.53457495570183, 58.986317217350006, 62.25789986550808, 63.73111881315708, 64.71344590187073, 71.34972900152206, 71.94752052426338, 74.34719815850258, 73.96818369626999, 73.19930255413055, 68.71721506118774, 76.82092621922493, 72.02947452664375, 75.68826019763947, 71.3794358074665, 77.73988410830498, 70.71606740355492, 66.92474484443665, 44.879034608602524, 2.4460021359845996, 0.4211403080262244, 4.52894420363009, 2.3302574967965484, 0.6042780715506524, 0.31038159504532814, 5.319367814809084, 71.00241243839264, 58.61306704580784, 46.31980709731579, 46.85249291360378, 33.11567522585392, 55.74415259063244, 10.13622684404254, 0.19002415181603283, 0.1181676251871977, 0.05625697580398992, 0.038939353107707575, 0.020184834174870048, 0.04468554281629622, 0.06718514487147331, 0.05549409623199608, 0.02409124164842069, 0.03157622028084006, 0.0032653342805133434, 0.03907826459908392, 0.028758745684172027, 0.00796818263552268, 0.08970560127636418, 0.060914672358194366, 0.04278355561837088, 0.06226422337931581, 0.02531692080083303, 0.049570889459573664, 0.05564055165450554, 0.07405941389151849, 0.12935466278577223, 51.761308908462524, 70.04245474934578, 52.548778653144836, 39.499769657850266, 49.672659784555435, 41.127184331417084, 1.4703932055272162, 0.10949718067422509, 3.7242138851433992, 4.2014996241778135, 4.899743031710386, 0.4120720352511853, 13.895297683775425, 91.34364053606987, 95.43921276926994, 97.25048437714577, 88.01702544093132, 87.42773026227951, 77.59989202022552, 69.80617582798004, 74.37095448374748, 86.99362635612488, 86.38148680329323, 88.00218343734741, 87.84647539258003, 87.2966904938221, 87.91838273406029, 89.0361687541008, 84.57353621721268, 81.84620976448059, 81.09954223036766, 79.75974932312965, 71.82081252336502, 66.17541745305061, 60.05741514265537, 58.42518612742424, 60.74428528547287, 59.51093606650829, 59.28788423538208, 58.259587213397026, 60.36080986261368, 56.82301349937916, 56.89496263861656, 56.78057357668877, 58.89826454222202, 66.90571546554565, 72.5681260228157, 72.04711318016052, 72.99138531088829, 74.91272181272507, 69.9623854458332, 72.27575451135635, 68.68031144142151, 68.68462800979614, 70.71859806776047, 68.36099177598953, 64.91098210215569, 62.608594447374344, 68.4151616692543, 71.98218986392021, 72.70716056227684, 67.91447013616562, 61.05009287595749, 60.87331496179104, 55.451195910573006, 59.23921264708042, 69.03712749481201, 65.83734199404716, 64.64487478137016, 66.55583783984184, 69.04891446232796, 59.15868736803532, 63.830859661102295, 64.2681933939457, 67.75652021169662, 64.66065153479576, 60.203684493899345, 67.82291784882545, 64.59444388747215, 60.574347004294395, 58.318009078502655, 52.79932200908661, 68.32212746143341, 67.53342658281326, 62.87158973515034, 56.88284128904343, 54.31954063475132, 58.16282920539379, 60.6332628428936, 59.71440374851227, 61.883631348609924, 56.74232862889767, 59.07932102680206, 54.663555175065994, 58.911145851016045, 63.40970166027546, 53.840971514582634, 64.71078604459763, 64.34690997004509, 62.294195517897606, 59.00915399193764, 55.04267983138561, 53.32926817238331, 50.89940495789051, 52.46578350663185, 52.66926258802414, 55.85066467523575, 53.90120968222618, 51.20469957590103, 51.40890821814537, 50.16309566795826, 53.176618963479996, 61.73134692013264, 70.11254578828812, 69.93720039725304, 72.32580542564392, 70.22448778152466, 67.33145222067833, 57.1829529851675, 55.13625741004944, 56.02303862571716, 60.24955943226814, 65.45059874653816, 67.67176955938339, 66.69613391160965, 74.32955950498581, 75.47557801008224, 76.68311521410942, 76.11894428730011, 75.49719884991646, 70.71657657623291, 77.89011284708977, 74.6356862783432, 77.75607123970985, 72.68286466598511, 77.99076184630394, 74.61205154657364, 73.15862193703651, 55.48695579171181, 4.716841271147132, 0.5107022740412503, 2.29206170886755, 2.3264439264312387, 3.078375128097832, 0.509804334724322, 5.481618633493781, 73.83213579654694, 69.7738091647625, 49.57438565790653, 37.49678693711758, 39.60041485726833, 63.35049703717232, 14.090207275003195, 0.2551725466037169, 0.1611407587188296, 0.04466537124244496, 0.02851261797331972, 0.05185318281291984, 0.046351816490641795, 0.05340087984222919, 0.04467160899366718, 0.04356099612778053, 0.02570945754996501, 0.05605595026281662, 0.17096504248911515, 0.16436835896456614, 0.15953062480548397, 0.24450325348880142, 0.10755866125691682, 0.17896051111165434, 0.18927725439425558, 0.1103706588037312, 0.10964347282424569, 0.12554947868920863, 0.15899802994681522, 0.2569547697203234, 60.0263936072588, 82.99577727913857, 48.50750930607319, 65.83503171801567, 69.77785214781761, 51.86876334249973, 3.0269840732216835, 0.2718162472592667, 5.335383955389261, 10.4056466370821, 9.744663555175066, 1.1255058995448053, 14.587179757654667, 96.81381940841675, 99.49302524328232, 99.47959676384926, 93.52906286716461, 89.98848885297775, 79.94279310107231, 74.93308112025261, 79.11395117640495, 91.97331994771957, 90.98279669880867, 93.87355238199234, 91.92662045359612, 89.80367437005043, 90.80712452530861, 93.27774435281754, 89.20121669769287, 87.51029223203659, 85.04721879959106, 82.92507067322731, 77.08901703357697, 70.00505715608597, 61.37306794524193, 63.496709391474724, 65.32442271709442, 62.2009789198637, 64.21262517571449, 60.282610058784485, 62.519147247076035, 60.28317242860794, 60.00486396253109, 60.23457683622837, 62.17556208372116, 68.4364253282547, 75.40789604187012, 74.656091183424, 75.84634691476822, 79.94248911738396, 72.99039736390114, 75.33671826124191, 72.12888479232788, 72.23293840885162, 74.29295226931572, 72.41858124732971, 69.9000383913517, 66.4158533513546, 72.99452394247055, 75.74293926358223, 76.784288585186, 73.5535879433155, 64.7484040260315, 65.3045117855072, 62.00384549796581, 60.56896649301052, 72.25026547908783, 69.81022641062737, 69.46278065443039, 70.76440840959549, 72.02201932668686, 62.41020329296589, 66.53803959488869, 67.20840722322464, 68.06562602519989, 64.63635563850403, 60.861041620373726, 70.89328229427338, 67.92335405945778, 62.77988165616989, 63.04519101977348, 59.25354927778244, 75.54589703679085, 70.25481015443802, 66.05257764458656, 59.896820560097694, 56.42196781933308, 60.67410685122013, 65.46587392687798, 65.19687116146088, 63.393628522753716, 61.59551180899143, 62.20049634575844, 56.00782424211502, 59.69904497265816, 66.06361225247383, 54.580746218562126, 64.56613540649414, 70.73350846767426, 66.19947016239166, 61.56175062060356, 56.047969087958336, 55.69888561964035, 54.69212964177132, 55.80398418009281, 57.46990978717804, 58.582201302051544, 58.85392092168331, 56.27464212477207, 54.85314980149269, 52.129991725087166, 56.98154479265213, 65.10568365454674, 74.34011533856392, 73.57259452342987, 75.0972019135952, 72.91892319917679, 70.2735735476017, 59.189788699150085, 56.22016444802284, 58.76259282231331, 63.44488017261028, 67.07997411489487, 71.19104951620102, 70.16369864344597, 77.58730709552765, 78.9370858669281, 80.84504708647728, 79.68687683343887, 76.99573203921318, 73.54395166039467, 81.51249647140503, 78.7034972012043, 80.47945350408554, 75.28300434350967, 81.15140184760094, 78.05652871727943, 77.06184849143028, 55.33212170004845, 3.5647129314020276, 2.1236017858609557, 13.483449183404446, 7.075397511944175, 3.3900795271620154, 0.6454115174710751, 8.6182557977736, 87.54332765936852, 71.85995042324066, 64.06906127929688, 61.851796656847, 44.75914344191551, 73.12269106507301, 16.175331138074398, 0.35764906962867826, 0.3732112830039114, 0.1847863258444704, 0.10394329627160914, 0.09433635044842958, 0.29802056145854294, 0.21283394191414118, 0.13275120552862063, 0.13481865084031597, 0.1953040575608611, 0.17202531918883324], [0.04326491260144394, 0.039651410406804644, 0.07793882017722353, 0.006669756776318536, 0.022183157707331702, 0.02083688883431023, 0.09140036228927784, 0.025357744489156175, 0.055555657381773926, 0.09803668392123654, 0.07129130695830099, 2.1875029569491744, 56.25918075442314, 55.00621318817139, 20.525476410984993, 48.18280152976513, 58.52340705692768, 21.203920505940914, 0.26315766968764365, 0.16345906478818506, 1.2237550900317729, 4.7102277260273695, 0.8276353706605732, 0.18580100499093533, 27.076186202466488, 92.631915807724, 94.07295808196068, 92.6255701482296, 90.59720858931541, 87.30936661362648, 81.78213000297546, 70.75846552848816, 66.6303214430809, 71.38186767697334, 79.38087925314903, 83.64290535449982, 84.09315839409828, 82.55854234099388, 80.24791672825813, 78.86232107877731, 75.26050955057144, 73.54358687996864, 75.15509560704231, 69.34760883450508, 65.8515152335167, 58.70290942490101, 59.435065537691116, 57.54256188869476, 59.246838837862015, 58.82372014224529, 56.62583827972412, 55.134308114647865, 55.707910135388374, 52.14155450463295, 52.71136432886124, 53.21396715939045, 57.90408968925476, 66.44277110695839, 68.24020385742188, 69.23352375626564, 69.51753571629524, 67.70802721381187, 70.17196699976921, 68.62894579768181, 63.34704302251339, 66.10215738415718, 66.74878388643265, 62.004757449030876, 60.680300518870354, 65.69371730089188, 65.06366550922394, 70.25627687573433, 67.1873639523983, 65.05967572331429, 55.6614576280117, 54.639407470822334, 50.69385498762131, 59.03025805950165, 63.24699059128761, 63.292390555143356, 63.722683265805244, 66.04287296533585, 61.830191016197205, 51.88115067780018, 62.039510384202, 62.0304174721241, 62.68216609954834, 60.559512600302696, 61.03476069867611, 61.54861472547054, 60.52251398563385, 61.52010105550289, 55.723097920417786, 49.71349619328976, 47.83250592648983, 62.728063836693764, 62.61480711400509, 58.87833461165428, 50.41448637843132, 53.26180659234524, 59.45678897202015, 57.30475924909115, 56.81107074022293, 54.632263854146004, 55.66055327653885, 53.51473622024059, 49.71411935985088, 61.28594622015953, 54.85220745205879, 55.255912989377975, 65.70630222558975, 58.04769538342953, 61.07769079506397, 60.07528938353062, 55.5634380877018, 47.73870415985584, 49.00492921471596, 48.99152733385563, 50.78376196324825, 49.05556529760361, 51.80958531796932, 48.21916177868843, 49.50739145278931, 48.70137870311737, 55.36066576838493, 66.42189502716064, 68.64318743348122, 67.55539700388908, 66.29677534103394, 60.51686368882656, 56.12115316092968, 55.976897701621056, 55.67839331924915, 57.16386280953884, 64.11262214183807, 66.0059617459774, 71.42712324857712, 70.52518084645271, 73.07326331734657, 73.65843191742897, 74.76632326841354, 69.47221174836159, 74.78467628359795, 72.00891003012657, 74.89741623401642, 73.84842932224274, 78.01893353462219, 74.99133199453354, 82.6278506219387, 63.86870563030243, 67.92158335447311, 25.59418972581625, 0.7713729178067297, 3.451543366536498, 7.53107238560915, 6.752925915643573, 0.09811977477511391, 0.8939277415629476, 45.98665997385979, 73.68829071521759, 45.192175805568695, 53.07582177221775, 34.54814895987511, 61.715703159570694, 12.148207481950521, 0.177036834647879, 0.018547198123997077, 0.0625374673109036, 0.03166685135511216, 0.026140788213524502, 0.056021147247520275, 0.0919469392101746, 0.023329929863393772, 0.05190934483835008, 0.022038613315089606, 0.08114655312965624, 0.021388649656728376, 0.0508154043200193, 0.024017869218369015, 0.05669104684784543, 0.035827004685415886, 0.04142536599829327, 0.05754320678533986, 0.0810226886824239, 0.11546152469236404, 0.1599419378908351, 0.19195294909877703, 3.79095540381968, 68.69142964482307, 66.53636768460274, 33.97370718419552, 42.598678171634674, 67.36321091651917, 24.444576613605022, 0.17049374902853742, 0.2703897503670305, 2.1325681172311306, 6.864812336862087, 4.750587260350585, 0.06399426609277725, 31.630466021597385, 95.63168004155159, 95.03274857997894, 93.79536777734756, 93.99955362081528, 91.73961728811264, 85.10251343250275, 74.07931253314018, 68.37169960141182, 73.95505160093307, 80.67489981651306, 86.0996787250042, 86.21173471212387, 83.67448166012764, 83.385119587183, 82.54332795739174, 78.98773714900017, 76.17632120847702, 77.01252713799477, 71.55977413058281, 66.18404299020767, 60.44113755226135, 60.6070252507925, 59.26008112728596, 60.45685350894928, 59.98565599322319, 59.92615878582001, 57.716322764754295, 59.1675066947937, 53.16341087222099, 54.75196123123169, 55.35722315311432, 60.25815837085247, 69.2916302382946, 68.63239601254463, 72.39153429865837, 73.38286310434341, 72.62388423085213, 73.58768731355667, 69.13303434848785, 66.15352302789688, 67.1119076013565, 70.16514256596565, 65.72821944952011, 64.02222499251366, 67.19402119517326, 68.45733940601349, 71.8169367313385, 69.5242765545845, 69.02087956666946, 61.6314996778965, 60.08223921060562, 55.94551898539066, 64.08414646983147, 67.64971554279327, 65.75934737920761, 66.36012554168701, 70.17510563135147, 62.97150157392025, 53.0259570479393, 64.44093212485313, 62.202012464404106, 64.51890394091606, 63.843953758478165, 64.58961054682732, 64.61158856749535, 64.56342995166779, 64.36227634549141, 61.440157145261765, 53.95513258874416, 46.66134417057037, 62.76046849787235, 67.25616306066513, 61.49085782468319, 52.52058036625385, 57.52281814813614, 62.831019312143326, 61.807783618569374, 59.687577188014984, 58.36262248456478, 60.75930207967758, 53.93292658030987, 53.84821392595768, 62.663596495985985, 59.42488968372345, 57.50850051641464, 69.48718294501305, 63.42888303101063, 63.162046149373055, 64.6696874499321, 58.2738022506237, 52.59590372443199, 51.73199728131294, 51.69375613331795, 52.26383954286575, 54.301742389798164, 53.46870929002762, 50.072709918022156, 50.9180049598217, 52.56661109626293, 56.645943000912666, 68.71593832969666, 67.81702056527138, 67.89834380149841, 69.49311062693596, 62.9705136269331, 55.32495528459549, 58.449371829628944, 56.47579953074455, 60.248309299349785, 65.69074586033821, 69.46040958166122, 73.12030479311943, 73.06357383728027, 75.32499969005585, 77.15929806232452, 75.93338504433632, 69.43074837327003, 76.07334673404694, 74.04590472579002, 77.44846254587173, 75.15989854931831, 78.15471544861794, 78.31432208418846, 83.29769387841225, 70.84497168660164, 72.20304161310196, 35.44688053429127, 0.9403305547311902, 0.1231941839796491, 2.3284281324595213, 3.7551620369777083, 0.1608510094229132, 0.3958641237113625, 47.569852620363235, 81.5134160220623, 50.043820068240166, 45.971635580062866, 42.984099090099335, 69.5238509774208, 15.245407987385988, 0.33252659894060344, 0.11462536174803972, 0.08003678260138258, 0.040856502382666804, 0.09059844946023077, 0.02723341513046762, 0.015873139855102636, 0.03417880230699666, 0.028661370342888404, 0.04608359689882491, 0.08667202811921015, 0.15382650744868442, 0.119634287111694, 0.15426232625031844, 0.18048927595373243, 0.09652163396822289, 0.16372801910620183, 0.1297337221330963, 0.1769658556440845, 0.3045067243510857, 0.25511180923786014, 0.2776812622323632, 3.488467172719538, 78.64890933036804, 70.71000292897224, 30.1821718364954, 62.99362778663635, 81.62513762712479, 32.10797309875488, 0.7566075632348657, 0.33705372945405543, 3.97911180742085, 11.758825276046991, 7.060603005811572, 0.8389748528134078, 32.89396092295647, 101.53259620070457, 98.37265536189079, 99.6903258562088, 96.05996266007423, 96.73063427209854, 88.27165737748146, 77.79548272490501, 73.29156160354614, 78.29526990652084, 84.17685270309448, 88.6525109410286, 90.19709765911102, 86.90056174993515, 86.79424345493317, 85.9678865969181, 80.89826703071594, 80.69354921579361, 80.24338737130165, 75.7203608751297, 71.17059141397476, 64.99336928129196, 64.01093199849129, 61.35180048644543, 64.71072524785995, 63.831254839897156, 62.58843272924423, 60.551973804831505, 63.22514556348324, 56.880078837275505, 57.015275582671165, 58.144069612026215, 64.71764847636223, 73.28019261360168, 71.43177419900894, 75.08118957281113, 76.48159682750702, 73.82892116904259, 76.98019847273827, 72.64184966683388, 67.95000582933426, 73.1670118868351, 72.68452897667885, 70.32737106084824, 68.03977981209755, 70.17136663198471, 72.53230914473534, 76.00419044494629, 72.34731987118721, 72.19434767961502, 65.1844534277916, 64.4346472620964, 58.781196624040604, 66.90525189042091, 68.98136928677559, 69.57917600870132, 70.93460887670517, 75.54579824209213, 67.25542590022087, 55.23010477423668, 68.6852739751339, 63.62475112080574, 68.62795025110245, 66.82349547743797, 69.87520292401314, 68.40592816472054, 67.87885084748268, 66.97082877159119, 62.48612321913242, 53.879672437906265, 49.77053873240948, 67.74433046579361, 70.12757778167725, 62.171329110860825, 54.18085187673569, 59.57076005637646, 68.32097232341766, 66.72657027840614, 63.99205461144447, 65.03315314650536, 64.34578523039818, 59.00763027369976, 55.82310475409031, 67.32604131102562, 63.69825437664986, 59.23481248319149, 68.24077382683754, 66.36393293738365, 67.9422390460968, 68.45467194914818, 60.451548993587494, 55.610772147774696, 54.91887487471104, 55.32440811395645, 56.79110661149025, 57.32714004814625, 57.48464159667492, 52.84788720309734, 54.649955704808235, 55.205824077129364, 58.4040554612875, 71.5445901453495, 73.58917683362961, 71.68848842382431, 72.97899037599564, 65.16268819570541, 58.69193181395531, 62.69737668335438, 59.121255576610565, 63.001493364572525, 70.20785987377167, 71.95906430482864, 78.39999228715897, 75.69215878844261, 77.51769483089447, 80.26858001947403, 80.38767322897911, 71.7883774638176, 78.41540426015854, 79.05459076166153, 79.89236980676651, 79.05108734965324, 80.96745371818542, 81.45831137895584, 87.38794639706612, 71.86862155795097, 78.24520379304886, 35.828148275613785, 1.4798102877102792, 9.31787520647049, 16.89923409372568, 13.092495761811733, 0.2445102296769619, 1.319334211293608, 56.89927160739899, 86.95195779204369, 59.53917995095253, 70.83512261509895, 47.89046801626682, 83.04699093103409, 18.297625556588173, 0.4240121226757765, 0.2535059204092249, 0.09684246440883726, 0.20097838510992005, 0.19951627997215837, 0.1708126498851925, 0.12964153254870325, 0.09466770454309881, 0.21075339027447626, 0.14741326798684895, 0.1413017709273845], [0.03092426952207461, 0.05396675260271877, 0.02076636996207526, 0.14359252847498283, 0.04140428529353812, 0.04607259084878024, 0.03852900852507446, 0.15949371038004756, 0.06774729205062613, 0.053708084451500326, 0.26888313121162355, 11.494129579514265, 70.62355756759644, 40.16316466033459, 48.64145211875439, 59.968819096684456, 50.77592298388481, 17.184720374643803, 0.0983605720102787, 0.2088103734422475, 3.086988078430295, 2.060405476950109, 2.649516840465367, 0.7358148414641619, 48.819575160741806, 94.7835123538971, 89.17004317045212, 91.07656806707382, 87.80900940299034, 91.0285310447216, 85.89681521058083, 79.01638001203537, 67.23996073007584, 65.78795224428177, 66.49084612727165, 73.71109709143639, 79.14550468325615, 79.26043331623077, 79.43552032113075, 74.68853384256363, 73.01104545593262, 68.01663145422935, 64.5920804142952, 60.33476606011391, 60.16114957630634, 59.90194648504257, 59.442661330103874, 59.240785762667656, 57.83257372677326, 57.51654848456383, 56.36184744536877, 55.116832852363586, 52.93778657913208, 50.528119280934334, 52.411644011735916, 53.24794493615627, 61.358788311481476, 68.52339506149292, 68.69559422135353, 71.65582537651062, 68.4949117898941, 70.01714810729027, 64.94793891906738, 70.6400790810585, 61.4470461755991, 65.94373628497124, 66.3706585764885, 62.13534504175186, 64.7291998565197, 63.0296840518713, 70.16369104385376, 68.40314671397209, 66.38829723000526, 64.72245901823044, 61.23464897274971, 52.261020094156265, 54.4626409560442, 62.62015342712402, 65.64682021737099, 58.7361766397953, 64.16622966527939, 61.01251669228077, 49.94073159992695, 52.52997726202011, 61.165640875697136, 60.859977677464485, 62.81459279358387, 60.23667812347412, 61.19657501578331, 63.86762648820877, 59.60604876279831, 59.0200974047184, 64.22148630023003, 63.68503488600254, 54.900221675634384, 50.20355589687824, 60.87625980377197, 62.228611037135124, 51.78305134177208, 53.5665388405323, 54.6848264336586, 56.916917860507965, 56.418441608548164, 52.30382099747658, 58.094163089990616, 52.56536476314068, 50.26542417705059, 53.181060925126076, 63.6188006401062, 54.057058319449425, 56.58455729484558, 65.03281876444817, 63.36911603808403, 58.41217562556267, 58.96797940135002, 53.79701167345047, 50.52953280508518, 49.46221947669983, 51.06833629310131, 48.634460493922234, 49.25250492990017, 48.248826786875725, 48.26755978167057, 46.92303992807865, 53.592533245682716, 66.72331765294075, 66.22104540467262, 70.29058143496513, 66.63311049342155, 59.34799320995808, 54.581388384103775, 55.34762866795063, 53.40047635138035, 59.46123093366623, 65.4467761516571, 68.9265838265419, 68.6654694378376, 73.35200875997543, 72.64130249619484, 71.1478154361248, 67.34399914741516, 71.46954417228699, 72.54921823740005, 77.77433305978775, 76.27459913492203, 74.5718041062355, 76.09318926930428, 75.96449017524719, 77.25562289357185, 73.55596661567688, 66.50393262505531, 58.89080934226513, 4.990933388471603, 0.611709700897336, 1.7952031013555825, 3.5903316317126155, 0.5104817671235651, 0.24282334285089746, 24.68708150088787, 80.4788987338543, 47.381747514009476, 49.78761501610279, 31.919533610343933, 56.160690039396286, 17.343648746609688, 0.17938804754521698, 0.0654219429998193, 0.03884085155732464, 0.01880858439108124, 0.010591771151666762, 0.06720338686136529, 0.04457715214812197, 0.03689599790959619, 0.015185349857347319, 0.06870394267025404, 0.05779642757261172, 0.026847077169804834, 0.008947971564339241, 0.033945563845918514, 0.07886858278652653, 0.024772676079010125, 0.08531138199032284, 0.09517442071228288, 0.14248609018977731, 0.032195661260630004, 0.13605224870843813, 0.43847091088537127, 17.60975606739521, 77.09997564554214, 51.90017245709896, 42.134384885430336, 47.600551173090935, 62.72698849439621, 17.7267137914896, 0.31767660984769464, 0.9736351144965738, 5.055824406445026, 2.317695845849812, 0.15237611340126023, 1.4263536874204874, 57.23331168293953, 97.96858504414558, 90.60635089874268, 92.28669673204422, 92.23333239555359, 92.28784427046776, 89.20057833194733, 80.54165616631508, 70.36466985940933, 66.67265117168427, 70.70523038506508, 75.65944254398346, 79.55445393919945, 80.32700568437576, 81.9170455634594, 76.79535359144211, 75.39762899279594, 69.03289452195168, 68.55417340993881, 61.92699082195759, 64.22778636217117, 63.99161383509636, 61.37060947716236, 59.576847329735756, 59.94274489581585, 60.55910982191563, 59.76700432598591, 57.4305135011673, 56.25720486044884, 52.15710327029228, 54.93092782795429, 55.10468490421772, 64.74289432168007, 71.61557793617249, 70.52458047866821, 73.32043245434761, 71.61244690418243, 73.86409968137741, 66.51308253407478, 72.99004778265953, 66.30790874361992, 70.42354390025139, 67.80704230070114, 64.63174268603325, 69.00420606136322, 69.94597792625427, 72.23041534423828, 68.55462938547134, 70.38551554083824, 68.1919464468956, 67.47085154056549, 57.08700813353062, 58.26240286231041, 64.69188585877419, 67.4734278023243, 61.98002077639103, 70.19128516316414, 61.96842759847641, 50.64699210226536, 55.48353597521782, 63.21539148688316, 64.97870966792107, 65.84836900234222, 63.201982006430626, 60.86534298956394, 65.9353919327259, 62.803569585084915, 62.81971871852875, 65.17689943313599, 65.68229511380196, 59.302148669958115, 52.101443856954575, 63.63730184733868, 65.13852909207344, 52.38290995359421, 59.335780665278435, 58.631287068128586, 58.78678232431412, 59.53164495527744, 58.3428293466568, 61.11687809228897, 54.43919241428375, 53.198228403925896, 55.07428653538227, 66.8698225915432, 56.544849425554276, 59.26892325282097, 65.87855458259583, 66.79718568921089, 61.854338720440865, 62.775717079639435, 56.384775415062904, 53.883745819330215, 51.60391755402088, 53.93737234175205, 50.32396763563156, 50.783910155296326, 51.85452550649643, 50.2400491386652, 49.68666963279247, 55.27223691344261, 68.3124227821827, 69.7450903058052, 71.30755886435509, 67.60775059461594, 63.311176747083664, 55.805633291602135, 55.63096806406975, 56.0406506806612, 62.704714089632034, 68.38833510875702, 71.91231161355972, 72.27462977170944, 74.44064274430275, 73.47114756703377, 72.45157107710838, 68.50565761327744, 74.50152307748795, 74.45258930325508, 77.9845529794693, 77.25370779633522, 78.36072519421577, 77.04972714185715, 77.90294855833054, 78.6041097342968, 79.55264523625374, 70.65746694803238, 69.41764667630196, 7.043864903971553, 0.12841407966334373, 1.1346279038116336, 4.965912206098437, 0.3659208695171401, 0.24699798290384933, 24.691502563655376, 86.54905021190643, 55.42956367135048, 45.43333366513252, 36.79608553647995, 66.65087834000587, 22.14544728398323, 0.07468787196557969, 0.06387918125255965, 0.082703452790156, 0.12190485082101077, 0.0403547066525789, 0.1315770685323514, 0.06366201399941929, 0.023418471791956108, 0.06173943962494377, 0.06715554060065188, 0.05582332407357171, 0.11611755355261266, 0.15625944564817473, 0.09806762405787595, 0.28688534803222865, 0.12544208992039785, 0.149749415286351, 0.16365316609153524, 0.2392720920033753, 0.14801547629758716, 0.19534806691808626, 0.5305442155804485, 18.5855608060956, 93.29194039106369, 53.49730275571346, 61.63455851376057, 74.73045319318771, 71.47771373391151, 24.90702509880066, 0.3886717924615368, 1.4598135044798255, 10.171391107141972, 9.986060801893473, 6.580818425863981, 1.4630747982300818, 59.978174194693565, 102.18062102794647, 97.399892359972, 96.26218780875206, 95.97473323345184, 95.5317834019661, 89.66115921735764, 83.1687667965889, 73.8797776401043, 69.61635321378708, 74.94127348065376, 79.77998703718185, 84.0551908314228, 84.47909608483315, 86.61520466208458, 79.78754103183746, 79.29188042879105, 72.84186333417892, 71.40447646379471, 63.90864908695221, 68.20779159665108, 67.19681024551392, 65.11172533035278, 63.23049567639828, 61.05520360171795, 62.94019125401974, 62.717492803931236, 61.07097275555134, 57.855573892593384, 56.23180702328682, 57.13633328676224, 57.404887676239014, 66.82102560997009, 75.64779996871948, 74.54502314329147, 76.63822442293167, 75.97912698984146, 74.36920657753944, 72.6988086104393, 73.88944432139397, 68.23081836104393, 74.30637314915657, 73.30315098166466, 68.49487379193306, 70.93868225812912, 72.83368617296219, 76.18952170014381, 72.79894843697548, 71.19777515530586, 73.08851569890976, 70.68936243653297, 64.14278492331505, 62.7786885201931, 68.62495601177216, 71.2941911816597, 63.608153611421585, 72.33972787857056, 68.11651289463043, 51.860772371292114, 56.60975754261017, 66.96190685033798, 68.00536125898361, 69.08207908272743, 64.93717789649963, 65.1070211827755, 68.74202013015747, 64.63697120547295, 65.74602529406548, 68.77238810062408, 70.87809070944786, 58.74190293252468, 53.248495906591415, 68.24593394994736, 66.87549188733101, 53.41374523937702, 58.564699441194534, 63.97348880767822, 62.882692739367485, 65.06950199604034, 61.858172714710236, 63.84483531117439, 58.01468275487423, 57.6887172460556, 58.56889821588993, 70.07675170898438, 60.53117372095585, 62.64051653444767, 67.71807387471199, 68.9343886077404, 64.59968760609627, 65.27371823787689, 59.48429949581623, 57.95697525143623, 54.62361931800842, 58.90388064086437, 54.47191245853901, 55.93175612390041, 55.07802173495293, 53.832798153162, 51.57629683613777, 58.740713596343994, 70.15236005187035, 72.46945291757584, 75.05486458539963, 72.58889570832253, 65.75922578573227, 59.74422834813595, 59.783499240875244, 58.374090269207954, 65.29170647263527, 70.15648663043976, 74.25084292888641, 74.79238227009773, 79.09721687436104, 74.65364411473274, 75.60885965824127, 70.48037365078926, 77.11868584156036, 77.64073982834816, 81.6750593483448, 81.39303088188171, 80.66248208284378, 80.11254519224167, 81.87127321958542, 83.7379914522171, 82.22466945648193, 77.62223482131958, 74.84742611646652, 7.661125157028437, 1.9445971911773086, 6.116705155000091, 12.864008322358131, 2.073137881234288, 0.24319759308127686, 32.549118027091026, 94.05940800905228, 60.51871418952942, 68.99969950318336, 41.36665888130665, 74.81262758374214, 25.425754263997078, 0.42490382795222104, 0.19429224310442805, 0.16331020480720326, 0.13970567844808102, 0.15345642808824778, 0.23491201893193647, 0.12649616226553917, 0.14799720462178811, 0.16390223085181788, 0.28141488844994456, 0.17247979558305815], [0.017306598092545755, 0.09786717739189044, 0.015304807802749565, 0.035159023536834866, 0.021694145470974036, 0.049136959423776716, 0.042413958653924055, 0.09039070748258382, 0.11646084138192236, 0.15896257013082504, 0.02183875665650703, 29.688084349036217, 63.54460582137108, 25.47494452446699, 55.8592864125967, 50.96916921436787, 51.886025816202164, 7.534220516681671, 0.32040379475802183, 1.7235942813567817, 2.9600226413458586, 5.977355232462287, 0.9973084973171353, 7.2813521604985, 83.8269978761673, 93.24714839458466, 91.84244737029076, 86.12717404961586, 89.10109966993332, 87.70831480622292, 82.83351078629494, 86.07171982526779, 74.40601900219917, 64.74293991923332, 63.39331313967705, 64.74759846925735, 65.496074706316, 66.40552550554276, 62.89578303694725, 65.8345453441143, 63.67096804082394, 61.136614233255386, 59.10469986498356, 59.53184254467487, 59.81456257402897, 56.956105157732964, 57.63883352279663, 62.712062895298004, 59.12417382001877, 56.62619546055794, 55.89351877570152, 54.342160820961, 51.56788028776646, 50.03841295838356, 52.725469172000885, 56.30383975803852, 68.90029683709145, 70.17465725541115, 70.12699261307716, 70.44013381004333, 69.52745318412781, 67.52827405929565, 72.47595056891441, 67.83551037311554, 59.297664910554886, 69.21964690089226, 60.801802799105644, 65.29790014028549, 65.09644255042076, 69.80218604207039, 65.8412253856659, 66.44519537687302, 63.735879957675934, 61.85093030333519, 63.22432100772858, 52.8539402782917, 56.977562606334686, 63.64316873252392, 61.69880926609039, 65.8566677570343, 63.34812596440315, 50.3065075725317, 58.78952197730541, 67.4804650247097, 63.367782309651375, 67.29612931609154, 64.89631488919258, 63.25746662914753, 57.01186716556549, 59.50192295014858, 61.32646344602108, 64.05405968427658, 56.68875530362129, 57.142891734838486, 60.43390654027462, 61.143902242183685, 53.880838975310326, 60.066276267170906, 55.588904321193695, 51.25908225774765, 52.45829410851002, 56.97501294314861, 53.15186329185963, 56.227327063679695, 59.79486063122749, 60.20835444331169, 50.2058357745409, 49.03925657272339, 56.70219138264656, 65.78512519598007, 54.44139629602432, 48.43279771506786, 58.05805362761021, 67.22622826695442, 62.22749009728432, 55.70403054356575, 55.17110913991928, 51.49429723620415, 44.74186196923256, 48.08477059006691, 48.12618836760521, 46.50389201939106, 47.657054141163826, 48.389932215213776, 49.444413632154465, 60.955067574977875, 63.887309432029724, 68.16737696528435, 63.09225529432297, 57.59029872715473, 52.29197323322296, 55.422579646110535, 51.88632220029831, 64.95936870574951, 67.74224817752838, 74.70590651035309, 70.24952843785286, 70.44175252318382, 68.38852509856224, 71.21344551444054, 70.61406567692757, 73.48057866096497, 71.23484596610069, 76.20184823870659, 70.8886769413948, 77.3711746931076, 73.12377020716667, 79.12029683589935, 74.29500415921211, 81.07387080788612, 65.43754264712334, 76.11762195825577, 20.323479250073433, 0.3921120031736791, 0.9006924473214895, 1.7232552682980895, 0.16424513276433572, 0.40757435315754265, 8.703641016036272, 77.02313616871834, 56.488133668899536, 45.06410367786884, 29.87725719809532, 52.283830270171165, 29.12462018430233, 0.2754696918418631, 0.12460071709938347, 0.2123840371496044, 0.0508730580622796, 0.03092065526288934, 0.06687551343929954, 0.028301117017690558, 0.04609872557921335, 0.08319928907440044, 0.05157433566637337, 0.01703669568087207, 0.018628956822794862, 0.03124614268017467, 0.015308193851524265, 0.07277526834513992, 0.026457004350959323, 0.07841502665542066, 0.05237746561761014, 0.023677063873037696, 0.16353071172488853, 0.16567073907935992, 0.10966901754727587, 39.35058206319809, 68.60636740922928, 42.22478583455086, 43.833376318216324, 44.353633001446724, 63.2939712703228, 6.690456792712212, 0.304987725103274, 1.7071233526803553, 5.884178057312965, 4.160623317584395, 1.4255896909162402, 10.303654409945011, 91.03382036089897, 92.7370485663414, 96.75656408071518, 86.74935266375542, 92.65226751565933, 90.36194041371346, 89.71087574958801, 86.45248979330063, 80.70154398679733, 66.59797757863998, 66.04563921689987, 65.36783918738365, 68.92985165119171, 67.89338886737823, 68.71998891234398, 66.97895273566246, 66.42526164650917, 64.52207297086716, 62.77855172753334, 61.696502789855, 62.526667043566704, 62.09158658981323, 60.64234435558319, 64.82631504535675, 60.72056695818901, 57.5455105304718, 59.399974420666695, 55.86047574877739, 55.428754314780235, 53.394145891070366, 53.07847782969475, 58.59483182430267, 71.03754535317421, 70.89139759540558, 73.45710352063179, 72.11997047066689, 69.87322703003883, 69.02668565511703, 75.30998289585114, 68.42523112893105, 61.05357348918915, 71.14213094115257, 65.30037000775337, 66.58871367573738, 68.66774931550026, 73.2312436401844, 69.09920856356621, 69.46062237024307, 67.0258118212223, 65.32915726304054, 66.20732814073563, 59.43843595683575, 61.46625034511089, 68.17551612854004, 64.11045625805855, 72.19703033566475, 65.33819317817688, 52.25810185074806, 61.969537138938904, 70.01801446080208, 68.33822339773178, 70.94081774353981, 65.62163516879082, 63.580027520656586, 58.51892709732056, 60.25440417230129, 62.89737895131111, 65.03297835588455, 59.32696133852005, 60.35593092441559, 62.22852744162083, 63.6724803596735, 56.61146745085716, 59.36360277235508, 58.05790923535824, 53.198809772729874, 54.736469462513924, 60.731719359755516, 55.63916802406311, 60.36972798407078, 63.52871887385845, 63.64119663834572, 53.51347088813782, 52.252839133143425, 60.00061199069023, 65.94492942094803, 59.04859587550163, 51.42570711672306, 60.64898259937763, 68.40817004442215, 65.39423257112503, 58.197715133428574, 57.903466522693634, 54.11385387182236, 48.75904820859432, 51.83690585196018, 50.75340919196606, 51.29654824733734, 51.261460930109024, 51.503238156437874, 50.540468618273735, 64.0243148803711, 65.43587073683739, 69.34383183717728, 64.70668226480484, 59.8007807135582, 54.78778950870037, 56.640649884939194, 54.727570340037346, 65.8976599574089, 70.23377448320389, 74.95492234826088, 72.39822193980217, 71.80520296096802, 69.16507422924042, 71.16537809371948, 75.08115917444229, 74.73763480782509, 75.76384574174881, 78.5866990685463, 72.89390534162521, 77.35296607017517, 74.73439738154411, 82.46662527322769, 76.14611282944679, 83.22618931531906, 69.0174825489521, 81.14482820034027, 26.672740951180458, 0.598248626338318, 2.676705331541598, 3.1527794105932117, 1.3968082540668547, 0.4464868479408324, 8.913615848869085, 79.79043647646904, 67.32101798057556, 45.15224754810333, 30.978029631078243, 63.278874680399895, 37.417549788951874, 0.184137154428754, 0.049870865550474264, 0.04948235866322648, 0.08475228503812104, 0.06907360642799176, 0.043616523616947234, 0.019401809004193638, 0.019479901493468788, 0.08552731727831997, 0.02632196687045507, 0.056596987051307224, 0.08728291955776513, 0.3518296522088349, 0.11951212960411794, 0.17148558486951515, 0.06752328961738385, 0.08207699851482175, 0.2396543277427554, 0.14939650922315195, 0.25130978669039905, 0.2145669754827395, 0.18903040123404935, 41.47948242723942, 83.55889946222305, 37.689083218574524, 70.58532401919365, 67.72837892174721, 70.06290525197983, 13.09662614017725, 0.6435245624743402, 4.059886923059821, 6.1537189688533545, 16.68181736022234, 5.299733793362975, 9.37384145334363, 94.18292418122292, 99.30371180176735, 101.60732299089432, 91.54033318161964, 99.15567174553871, 96.00475162267685, 92.75236934423447, 92.43538275361061, 84.35396879911423, 72.07690358161926, 68.94548401236534, 69.95239198207855, 72.42636322975159, 72.67883688211441, 72.43463158607483, 71.00171327590942, 71.01976230740547, 66.39955222606659, 64.79735299944878, 66.9249652326107, 64.67064499855042, 65.07599964737892, 62.44703471660614, 67.46892124414444, 64.9892807006836, 59.89850766956806, 63.992312997579575, 59.080506563186646, 58.0600181221962, 56.476187109947205, 57.20931977033615, 62.47228816151619, 72.4511606991291, 76.51953399181366, 74.3572448194027, 77.02942863106728, 74.54746261239052, 74.3756054341793, 76.14782273769379, 69.91501718759537, 65.74632927775383, 75.55424138903618, 70.1595188677311, 70.57107478380203, 70.74384391307831, 76.33697658777237, 71.97468146681786, 76.28867357969284, 69.26323816180229, 69.90675643086433, 71.26820057630539, 63.89787286520004, 65.57875066995621, 70.83625495433807, 69.21463876962662, 75.52644968032837, 70.25548651814461, 54.04308646917343, 62.41396889090538, 75.45559108257294, 72.72413045167923, 72.64618143439293, 69.44112941622734, 70.41101977229118, 63.12455736100674, 64.03655022382736, 66.77262380719185, 67.34072372317314, 63.73866140842438, 63.691308349370956, 67.45176136493683, 67.62379333376884, 57.606577053666115, 62.166921347379684, 58.32630783319473, 55.451374500989914, 61.48852474987507, 63.40312801301479, 63.21606405079365, 62.9376719892025, 66.55092850327492, 65.76548784971237, 55.95784172415733, 54.822204262018204, 63.60808901488781, 68.98586824536324, 62.673080787062645, 52.79730051755905, 61.96046702563763, 68.52780282497406, 68.72520983219147, 63.14773611724377, 59.26326535642147, 57.07898676395416, 50.66577069461346, 54.824563935399055, 54.434032291173935, 53.10067243874073, 52.90192790329456, 54.51925411820412, 53.97537790238857, 66.85657650232315, 67.67171636223793, 73.03819879889488, 68.04611787199974, 62.541091069579124, 58.19050692021847, 59.77408714592457, 57.12811432778835, 68.4799861907959, 72.4629856646061, 77.33666494488716, 75.0634977221489, 73.43586266040802, 70.83581417798996, 75.53949058055878, 74.95198890566826, 78.13880950212479, 77.29447200894356, 82.6736381649971, 75.12413486838341, 83.59822735190392, 79.63245615363121, 85.57434931397438, 80.46179205179214, 88.80277007818222, 70.82416400313377, 90.24085611104965, 26.131148412823677, 1.1611709045246243, 5.068670092150569, 6.227351417765021, 1.4488221192732453, 0.5685775028541684, 12.212003208696842, 91.43090665340424, 69.82682392001152, 63.09159033000469, 40.21123208105564, 70.45864641666412, 44.23266649246216, 0.5218700529076159, 0.2763235179008916, 0.3022116475040093, 0.1629093856899999, 0.1176740598748438, 0.18749032606137916, 0.0654947105795145, 0.1735121972160414, 0.1952489308314398, 0.20665633433964103, 0.231056873453781], [0.0575621649477398, 0.027963864704361185, 0.023409961213474162, 0.016579157927480992, 0.03213656404113863, 0.02590276661067037, 0.060273349154158495, 0.06296356397797354, 0.021372407754824962, 0.12333240156294778, 0.150881992012728, 47.418791726231575, 52.1727242320776, 28.598639108240604, 39.152662083506584, 51.18436686694622, 43.32315869629383, 1.130116239655763, 0.2622935426188633, 0.667736625764519, 2.92848979588598, 5.285094603896141, 0.8739528665319085, 33.79879876971245, 95.63568502664566, 89.68682304024696, 89.3440130352974, 88.51381838321686, 87.77636155486107, 85.64303442835808, 82.71544352173805, 83.4845070540905, 83.58319535851479, 72.24008202552795, 62.941680774092674, 60.99129483103752, 60.80238036811352, 61.19385056197643, 59.948794171214104, 61.28462769091129, 59.774265736341476, 61.37356951832771, 60.562400445342064, 61.94049529731274, 58.180669248104095, 56.95687271654606, 56.60492040216923, 63.49442571401596, 57.46988318860531, 53.98436442017555, 54.4678770750761, 51.608739495277405, 50.50855793058872, 50.03883853554726, 54.23658728599548, 59.23143446445465, 68.39104056358337, 68.73090952634811, 67.67378345131874, 68.03008273243904, 74.26585212349892, 76.94406241178513, 61.83742202818394, 53.36967520415783, 65.08992969989777, 66.10873103141785, 64.23939853906631, 65.93796819448471, 67.75156527757645, 63.939199447631836, 66.49648502469063, 64.55806463956833, 60.61614476144314, 58.4299510717392, 59.93659682571888, 52.14788116514683, 53.52754533290863, 62.78493918478489, 64.69566285610199, 64.17814582586288, 52.13552802801132, 59.85808163881302, 65.28254896402359, 54.02007110416889, 59.50953774154186, 56.79468221962452, 53.99537242949009, 52.246219888329506, 53.61347772181034, 52.94992692768574, 55.53734488785267, 46.06052041053772, 56.11093170940876, 63.5516544431448, 58.05212214589119, 58.18061605095863, 60.01252435147762, 52.119375094771385, 55.8520781993866, 54.545544907450676, 53.66469517350197, 50.00279366970062, 47.14375488460064, 55.577687323093414, 63.89221876859665, 59.896573573350906, 55.25249697268009, 46.19790203869343, 52.781337574124336, 58.61606888473034, 64.30933758616447, 57.511262968182564, 46.6560510545969, 54.99652370810509, 67.57303565740585, 60.45350208878517, 55.53850382566452, 53.95245373249054, 47.27518983185291, 46.94320924580097, 47.65626758337021, 48.32776375114918, 48.66327054798603, 48.657156676054, 45.62756784260273, 52.68589049577713, 60.89308150112629, 59.50389884412289, 59.14772875607014, 56.60517118871212, 53.71244341135025, 53.57165716588497, 56.37520372867584, 64.95350182056427, 68.39479476213455, 67.87797689437866, 64.32275086641312, 70.78326299786568, 68.07919889688492, 70.59923887252808, 71.37789309024811, 73.10014307498932, 70.03478676080704, 73.03834319114685, 71.85511708259583, 74.62586000561714, 71.45798519253731, 75.53164020180702, 74.76698443293571, 81.79443374276161, 74.0948460996151, 69.59592550992966, 47.769877687096596, 1.3436745177023113, 2.532628937624395, 1.9231329741887748, 0.2297368599101901, 0.0179528844091692, 0.714431251399219, 58.92505690455437, 68.42093735933304, 51.31508745253086, 42.93862693011761, 38.14184032380581, 46.00436322391033, 0.5551989551167935, 0.008749981407163432, 0.04089925379958004, 0.060128121986053884, 0.013353201538848225, 0.03654630905657541, 0.04888522293185815, 0.06432006892282516, 0.020259128723409958, 0.04955666991008911, 0.10410804563434795, 0.03569457956473343, 0.0660786620574072, 0.027308377611916512, 0.019005583781108726, 0.042173072361038066, 0.04090918002475519, 0.0545916632108856, 0.16030596132623032, 0.03756013473321218, 0.038690536966896616, 0.3843388968380168, 58.080913200974464, 62.383384332060814, 40.023328363895416, 33.05213503539562, 60.76621770858765, 49.49621245265007, 0.9735359635669738, 0.27040607761591673, 1.7814736068248749, 3.3949910011142492, 9.54980431124568, 1.6846192977391183, 37.82261945307255, 99.59149315953255, 90.77788889408112, 92.26425513625145, 87.60837256908417, 92.39424616098404, 87.78627142310143, 87.3033857345581, 84.66178268194199, 85.1084715127945, 75.0822839140892, 64.63023036718369, 61.79800674319267, 63.493555560708046, 64.11527439951897, 63.016954734921455, 62.65359543263912, 61.15734592080116, 64.54263746738434, 63.526526391506195, 63.89152720570564, 61.217124313116074, 59.597795605659485, 60.19363783299923, 64.91692498326302, 60.29704928398132, 59.41924698650837, 57.428788393735886, 54.61710266768932, 53.80163602530956, 52.96599626541138, 56.47837959229946, 60.50138331949711, 69.93909269571304, 68.77789780497551, 73.63361924886703, 69.3770344555378, 75.14428898692131, 79.58049774169922, 66.03598013520241, 57.24333934485912, 67.0851494371891, 69.13611218333244, 65.24518176913261, 68.41551885008812, 70.51696568727493, 67.61034205555916, 68.43647852540016, 67.4661473929882, 65.11001542210579, 62.68245488405228, 65.77123314142227, 55.20107813179493, 57.780516520142555, 65.46955212950706, 68.07723820209503, 63.63078139722347, 53.72878633439541, 63.26160840690136, 66.87322720885277, 57.57335543632507, 61.8084067851305, 54.700447395443916, 56.73494942486286, 54.22814793884754, 58.2826291769743, 56.87975585460663, 58.424692153930664, 49.169939160346985, 59.39764894545078, 66.32303193211555, 60.46349175274372, 62.273254841566086, 61.78678594529629, 54.084971621632576, 60.372615829110146, 58.588649556040764, 57.05437168478966, 53.76724027097225, 51.32319621741772, 58.69719833135605, 64.57813516259193, 64.00941967964172, 59.45201262831688, 47.27436527609825, 54.39180515706539, 60.837004110217094, 67.01750546693802, 61.14441141486168, 48.01481634378433, 57.1294404566288, 69.4656229019165, 63.46411854028702, 58.049477487802505, 56.02146551012993, 51.79820492863655, 49.784255996346474, 51.675995886325836, 51.95593826472759, 50.752782225608826, 50.22960729897022, 50.504393354058266, 54.50880087912083, 61.17207773029804, 60.048747807741165, 60.92843100428581, 57.86866419017315, 56.36806771159172, 55.42471133172512, 58.415492847561836, 68.07550549507141, 72.69164219498634, 71.10188350081444, 68.27566355466843, 71.98222786188126, 71.26037299633026, 73.24428454041481, 71.46979495882988, 75.07428914308548, 72.78825581073761, 74.01151657104492, 74.11340430378914, 74.90800246596336, 74.70942512154579, 78.2588678598404, 77.66155511140823, 82.10249081254005, 78.2277475297451, 73.85874956846237, 56.06147736310959, 2.5421355525031686, 2.5149862468242645, 3.833731133490801, 0.4061352397548035, 0.008739338081795722, 0.4806495679076761, 59.58617962896824, 77.3122626543045, 55.06358250975609, 37.8399009257555, 44.11543518304825, 58.13930086791515, 1.0732958698645234, 0.03289427455456462, 0.06561432252055965, 0.033713583325152285, 0.04066633075126447, 0.051669059685082175, 0.06044607289368287, 0.03240479105443228, 0.05605826576356776, 0.033947114934562705, 0.023831454709579702, 0.16974628757452592, 0.21280940651195124, 0.14320149086415768, 0.11761099958675914, 0.09400893715792336, 0.14509395259665325, 0.14683865272672847, 0.2385851155850105, 0.14841680007521063, 0.23487920116167516, 0.5340492899995297, 65.39594247937202, 70.57303547859192, 38.89532469213009, 52.80149929225445, 72.40248531103134, 57.31941506266594, 2.504313332028687, 0.33439194259699434, 3.1481738202273846, 8.745002746582031, 18.958309404551983, 1.8172182887792587, 37.781688049435616, 105.69860905408859, 94.26535695791245, 97.48327508568764, 94.13313165307045, 96.76091104745865, 91.5420126914978, 91.50697857141495, 88.95857691764832, 89.15876537561417, 78.70469033718109, 68.66825848817825, 65.41828528046608, 67.51953452825546, 67.25079774856567, 66.06960833072662, 66.74751475453377, 63.30912105739117, 69.18813899159431, 65.38198962807655, 69.26531285047531, 64.32431638240814, 62.202913016080856, 63.77760171890259, 66.85976073145866, 62.08046078681946, 60.10437302291393, 60.07384926080704, 57.31696419417858, 56.959897354245186, 55.044473335146904, 59.36096951365471, 63.271921053528786, 74.75947603583336, 75.24419322609901, 74.18898984789848, 72.12518379092216, 78.55224251747131, 76.47740945219994, 67.38398060202599, 64.47888448834419, 70.01079484820366, 71.85640141367912, 68.71873497962952, 71.03971883654594, 74.54491674900055, 70.48203036189079, 72.25157260894775, 72.39281862974167, 69.72729966044426, 66.4241673052311, 70.27443990111351, 60.243232771754265, 61.081657782197, 68.42843815684319, 71.54139831662178, 70.47544151544571, 53.103241100907326, 63.9536614716053, 72.8495617210865, 59.73392330110073, 66.53201311826706, 62.76111826300621, 61.009777039289474, 58.085157573223114, 62.80188627541065, 59.2984476685524, 61.597761288285255, 54.68057066202164, 62.131085470318794, 68.82268220186234, 62.171458303928375, 67.32930913567543, 64.49694871902466, 54.53072190284729, 61.10801696777344, 60.488346219062805, 60.416632667183876, 57.47630104422569, 56.20782271027565, 62.51735754311085, 68.87912437319756, 68.74216452240944, 64.136743247509, 50.2982772141695, 57.857462391257286, 66.897431910038, 71.06545865535736, 62.6045248657465, 52.218435779213905, 61.132214069366455, 67.81182244420052, 64.90088984370232, 62.3476130515337, 59.14221525192261, 53.67041766643524, 53.424586057662964, 55.182569324970245, 54.36141438782215, 53.212025463581085, 53.562381863594055, 52.103871926665306, 57.463518530130386, 65.21509498357773, 63.44679147005081, 62.9165793210268, 62.62822799384594, 60.728322342038155, 59.166754335165024, 60.71514084935188, 72.28464603424072, 73.8787516951561, 76.02232307195663, 69.2770466208458, 75.28183400630951, 74.27768468856812, 76.86954841017723, 76.15758061408997, 80.0953397154808, 74.76736441254616, 77.44985327124596, 80.27700036764145, 79.63715270161629, 80.30977740883827, 82.74435237050056, 83.29724550247192, 86.81747540831566, 80.82252189517021, 80.96930041909218, 58.81513260304928, 2.4116021068766713, 6.217271508648992, 5.305558880791068, 0.4846038791583851, 0.2330594402155839, 1.3969239103607833, 71.25154986977577, 80.51185816526413, 68.22080969810486, 57.21317656338215, 52.2767436504364, 69.02569010853767, 0.9777150268200785, 0.15272743126843125, 0.1273367484100163, 0.14061803027288988, 0.11816306840046309, 0.12470648798625916, 0.11071275919675827, 0.1261928613530472, 0.09814750141231343, 0.0949839485110715, 0.2355009873281233], [0.020323150092735887, 0.05251367198070511, 0.046357623796211556, 0.05841849204443861, 0.07746178991510533, 0.08563339986721985, 0.09371069027110934, 0.11312036789604463, 0.11302486091153696, 0.18417016515741125, 1.218832810409367, 56.68431714177132, 39.377701207995415, 34.68154460191727, 38.677391186356544, 53.0470535159111, 33.08797471225262, 0.17020450439304113, 0.23314333258895203, 0.2739811217179522, 4.32814777828753, 9.535223543643951, 14.411323294043541, 68.75704452395439, 96.95380389690399, 83.9634257555008, 89.85125541687012, 80.9275558590889, 85.42829275131226, 83.88981610536575, 85.96458837389946, 80.72733700275421, 84.43404570221901, 78.55940893292427, 68.5585355758667, 62.02050760388374, 62.71445296704769, 61.08087122440338, 62.74131752550602, 60.25834836065769, 59.337555170059204, 58.80252867937088, 60.18012195825577, 57.94598624110222, 58.12051087617874, 58.27710047364235, 58.47379691898823, 56.022928431630135, 57.124892100691795, 54.42433141171932, 52.62959651648998, 52.11019478738308, 51.32293023169041, 52.8820625692606, 53.77890184521675, 59.52421635389328, 68.23065117001534, 68.83918851613998, 69.84085276722908, 71.47259160876274, 66.88779562711716, 47.33360029757023, 61.645756512880325, 66.8350924551487, 66.54212057590485, 66.76421105861664, 64.57977667450905, 65.48333778977394, 62.48603582382202, 64.96877700090408, 67.67439141869545, 60.820729583501816, 58.994213193655014, 61.55851699411869, 62.227866277098656, 50.870511308312416, 57.15601623058319, 64.57734480500221, 60.8179747313261, 58.351014107465744, 64.53399673104286, 65.52390441298485, 54.58958454430103, 57.32971630990505, 59.690674021840096, 47.73243449628353, 61.215444803237915, 62.973040491342545, 61.31822928786278, 57.69609645009041, 59.743677377700806, 54.438208267092705, 53.26287053525448, 64.85691860318184, 62.00482204556465, 58.52313347160816, 60.58274835348129, 58.754332065582275, 57.86351926624775, 57.70899675786495, 53.062568083405495, 52.28117421269417, 53.87641221284866, 52.99151189625263, 55.68089358508587, 58.25263738632202, 56.86509624123573, 49.014736488461494, 46.68241783976555, 56.39770232141018, 58.13151888549328, 62.600166499614716, 58.42193730175495, 49.12502937018871, 51.49375006556511, 65.65552175045013, 58.51243704557419, 56.81502252817154, 52.88745068013668, 47.563719749450684, 47.30376809835434, 45.207105204463005, 46.85527056455612, 48.63707855343819, 50.52016630768776, 48.60801391303539, 52.97788202762604, 55.00378891825676, 54.20662209391594, 52.25806005299091, 53.873360976576805, 53.68386894464493, 57.27670535445213, 66.6293714940548, 70.89189156889915, 63.65790814161301, 73.45390409231186, 69.38721030950546, 72.05313965678215, 69.7557981312275, 68.83725821971893, 67.93670654296875, 71.44745215773582, 71.19817793369293, 71.22585564851761, 70.51819682121277, 74.45232331752777, 71.77993431687355, 79.13864225149155, 74.98028218746185, 79.50792163610458, 68.58574211597443, 68.10169368982315, 11.06710184365511, 1.5564679680392146, 3.23277176823467, 0.5585947260260582, 0.18391259538475424, 0.16753076895838603, 29.552192240953445, 82.13712215423584, 43.2372073084116, 53.39025869965553, 30.45009545981884, 54.710083678364754, 5.0425426941365, 0.19697476556757465, 0.10847697252756916, 0.06368460497469641, 0.03198586724465713, 0.0647327327169478, 0.07249286631122231, 0.019431125692790374, 0.08132861679769121, 0.02437900755467126, 0.06130530920927413, 0.07235962111735716, 0.01877484450233169, 0.05836242649820633, 0.0401451167272171, 0.04672594426665455, 0.0350716616230784, 0.07678527777898125, 0.06891357712447643, 0.07730605764663778, 0.2001695628860034, 2.836714033037424, 67.8844365477562, 47.596777975559235, 36.84184268116951, 34.087514877319336, 66.37943610548973, 33.70684750378132, 0.36869374103844166, 0.13977974478621036, 1.5065442281775177, 3.381739924661815, 13.33847176283598, 18.78492470830679, 72.96667143702507, 97.18053013086319, 88.82555365562439, 90.90300098061562, 84.96650353074074, 87.21516966819763, 86.40194490551949, 86.75973370671272, 84.55156579613686, 84.49415847659111, 81.51273965835571, 69.88869979977608, 62.38741211593151, 66.21446415781975, 62.21823759377003, 63.72441977262497, 62.89536885917187, 63.90484169125557, 62.22033508121967, 62.22667694091797, 62.74885252118111, 62.40279749035835, 60.41860856115818, 59.31404583156109, 58.93984571099281, 59.69190135598183, 56.47033542394638, 54.566322192549706, 54.850185960531235, 52.35903203487396, 55.22322714328766, 56.42976500093937, 61.73336461186409, 72.0987220108509, 69.95948240160942, 72.99918249249458, 75.49469858407974, 73.01439687609673, 50.106186121702194, 63.492062240839005, 70.17330452799797, 67.21456289291382, 70.59770375490189, 66.46343439817429, 68.34151402115822, 65.72414606809616, 69.18509915471077, 70.006622672081, 64.29558232426643, 62.68812038004398, 64.29498955607414, 65.65963312983513, 55.589538887143135, 60.17008289694786, 68.56546640396118, 61.07701823115349, 59.27990846335888, 68.95569786429405, 66.3752107322216, 58.458624333143234, 63.19319687783718, 64.27296593785286, 52.946640104055405, 66.5693499147892, 66.43869772553444, 63.767403066158295, 58.485944867134094, 61.65430225431919, 59.450378715991974, 56.4663228392601, 64.38969567418098, 64.30778726935387, 60.64494341611862, 63.52710776031017, 61.97863385081291, 59.96004156768322, 59.37804959714413, 53.342024087905884, 54.82121631503105, 55.96804417669773, 54.621708020567894, 58.8994424790144, 60.91449715197086, 59.314634799957275, 49.75007303059101, 48.620621636509895, 58.95274981856346, 60.18460191786289, 63.29409286379814, 60.14815807342529, 54.954015389084816, 55.050005838274956, 67.57673665881157, 62.92328216135502, 58.6949260532856, 56.26216359436512, 50.807799473404884, 50.3567560762167, 47.32736103236675, 49.38736729323864, 49.56398941576481, 51.879699155688286, 51.662309020757675, 53.99091526865959, 57.79347762465477, 57.173658683896065, 54.446757808327675, 56.752819865942, 56.35830983519554, 61.219552382826805, 67.02467948198318, 72.68728002905846, 67.79472336173058, 73.87825012207031, 71.623055934906, 72.81710386276245, 70.28688043355942, 73.34522232413292, 71.8226820230484, 70.8125214278698, 72.28552758693695, 75.6189139187336, 72.8178334236145, 77.32564553618431, 73.62256184220314, 81.0527591407299, 76.51672214269638, 81.89480155706406, 70.63110396265984, 75.8861155807972, 13.530245572328568, 1.2920059589669108, 1.6604568692855537, 0.6707702879793942, 0.10160622128751129, 0.34606749890372157, 30.48545826226473, 88.79868909716606, 50.799303129315376, 47.36443944275379, 41.79783694446087, 68.47620159387589, 7.40384048782289, 0.16372126556234434, 0.10614141894620843, 0.040841997106326744, 0.053183274721959606, 0.025370381408720277, 0.04597224135068245, 0.02371348291489994, 0.10235858833766542, 0.09023744656587951, 0.014901537742844084, 0.1500475508510135, 0.1261500097461976, 0.14531667111441493, 0.13938075135229155, 0.1584336266387254, 0.18355029373196885, 0.20244942570570856, 0.24602712015621364, 0.16246237530140206, 0.3856301150517538, 3.3257869770750403, 83.20446208119392, 51.60683199763298, 45.922010242938995, 55.61168409883976, 74.57476034760475, 40.37574045360088, 0.6587046885397285, 0.23105559695977718, 2.1711020870134234, 13.551620375365019, 19.09173734486103, 19.997171759605408, 77.40449130535126, 103.17895665764809, 92.13407412171364, 98.50148364901543, 89.86385554075241, 92.4466985464096, 90.74543103575706, 92.16812029480934, 88.04908812046051, 89.44582477211952, 84.17625993490219, 74.75056931376457, 66.93325638771057, 69.7052076458931, 66.237141340971, 67.6707512140274, 66.35745048522949, 66.22872859239578, 66.51493683457375, 66.78352922201157, 66.0060453414917, 64.16448935866356, 63.56056496500969, 64.25372377038002, 62.13038630783558, 61.725917011499405, 60.30452348291874, 58.71965892612934, 58.81052725017071, 56.46670661866665, 58.37705411016941, 58.18773686885834, 64.4698865711689, 72.14358240365982, 74.57450196146965, 75.67339539527893, 80.82184553146362, 67.37132728099823, 50.61142981052399, 66.91005483269691, 72.87186652421951, 72.95607000589371, 73.34019139409065, 70.83180159330368, 71.24185279011726, 68.63765493035316, 69.40655127167702, 73.28961610794067, 67.64308109879494, 68.34113404154778, 68.44275578856468, 71.4426264166832, 59.538378193974495, 62.476923912763596, 71.20324686169624, 65.2859915792942, 62.673088386654854, 73.49545106291771, 72.67736256122589, 63.09916332364082, 63.29375088214874, 67.962985932827, 55.53872041404247, 67.40627020597458, 69.26617920398712, 67.05163523554802, 60.047520473599434, 65.86921468377113, 58.91228199005127, 59.646356999874115, 69.21683505177498, 67.26182475686073, 64.20770063996315, 68.19387674331665, 64.280466735363, 63.43577206134796, 63.0574681609869, 56.73384368419647, 59.204657301306725, 57.59364254772663, 54.97496746480465, 60.867702662944794, 62.83278241753578, 62.3380109667778, 53.295392990112305, 52.16866225004196, 64.60834354162216, 63.549963533878326, 66.85732126235962, 61.00378476083279, 56.41076982021332, 59.1879989951849, 67.73013442754745, 65.33730402588844, 62.89854548871517, 59.36272121965885, 54.414653331041336, 52.50431343913078, 50.47996066510677, 51.98217585682869, 53.24517868459225, 56.03846959769726, 53.86969797313213, 58.347438499331474, 61.833493039011955, 59.54276695847511, 57.10465058684349, 60.29301010072231, 59.55911748111248, 64.14487481117249, 71.22608363628387, 76.48436307907104, 70.0386093556881, 76.20893105864525, 75.17769679427147, 77.76853457093239, 75.15881940722466, 74.4757604598999, 73.17456588149071, 75.37156999111176, 75.52439779043198, 79.9926920235157, 73.98531317710876, 81.21616557240486, 78.6408081650734, 85.74524134397507, 81.19713619351387, 85.31981617212296, 76.9454075396061, 81.56892344355583, 13.943972121924162, 1.983272465877235, 10.947189778089523, 2.421263325959444, 0.2956553368130699, 0.4799821396591142, 37.68099345266819, 95.16651660203934, 56.008405610919, 71.12653657793999, 42.69235834479332, 79.13160502910614, 8.194554783403873, 0.4489240312250331, 0.3727588400943205, 0.18546813691500574, 0.15210635756375268, 0.2977428794838488, 0.18060871720081195, 0.08102253283141181, 0.24360080191399902, 0.2494576235767454, 0.1163070609618444], [0.04540934460237622, 0.08335422724485397, 0.057840496301651, 0.020840106044488493, 0.07949937862576917, 0.01683974824118195, 0.028255918368813582, 0.08275879474240355, 0.0719640489842277, 0.13845054345438257, 4.575493605807424, 54.55235794186592, 38.51499930024147, 43.032265305519104, 33.03142234683037, 67.4155493080616, 22.083305418491364, 0.2723988628713414, 0.34650011162739247, 1.4594286563806236, 3.154390761628747, 0.9124919422902167, 32.410421669483185, 93.7800469994545, 89.90756839513779, 87.21272259950638, 81.25467270612717, 81.37247398495674, 82.88773387670517, 82.29209303855896, 85.27633890509605, 82.72583216428757, 82.76512205600739, 84.98101115226746, 72.07447931170464, 61.80046521127224, 61.493631675839424, 59.465661495923996, 60.130067244172096, 57.94555306434631, 59.60032247006893, 58.752701953053474, 59.40378941595554, 58.272552117705345, 56.11078731715679, 59.85494300723076, 57.73350544273853, 57.876978144049644, 55.279399529099464, 53.38786102831364, 51.273038908839226, 51.260845363140106, 52.19726711511612, 54.16891671717167, 51.812913939356804, 63.80114525556564, 68.9194630086422, 72.6245529949665, 66.56093716621399, 68.93357545137405, 47.585716769099236, 59.93115931749344, 69.77145329117775, 70.73773384094238, 60.911472514271736, 60.991408824920654, 67.57354483008385, 68.61039519309998, 66.33326858282089, 64.86042201519012, 62.009146213531494, 56.72733083367348, 57.87223979830742, 65.86639523506165, 58.67084674537182, 52.668160647153854, 60.15851631760597, 61.99730224907398, 55.77170491218567, 64.36066523194313, 61.11048303544521, 57.22289264202118, 62.39096112549305, 67.21507966518402, 53.17795269191265, 61.22368276119232, 64.55505520105362, 58.942273780703545, 54.60997425019741, 58.760309144854546, 61.06216102838516, 63.27098250389099, 55.79380452632904, 52.80945606529713, 62.40543454885483, 57.67942674458027, 58.80108095705509, 59.04617540538311, 61.35850332677364, 49.04594801366329, 48.58396500349045, 46.46545708179474, 47.94348657131195, 51.10366679728031, 59.5539041608572, 57.43292257189751, 56.40836074948311, 49.78028140962124, 47.75815911591053, 51.383897960186005, 59.97593991458416, 63.58122445642948, 60.11945441365242, 56.17604501545429, 54.1815510392189, 53.48895080387592, 66.41709208488464, 58.523821234703064, 57.626822367310524, 48.193079978227615, 44.74023565649986, 49.21289585530758, 46.88977651298046, 49.35161881148815, 50.01067444682121, 50.59802792966366, 50.20618535578251, 48.32989543676376, 50.64296051859856, 51.24265193939209, 53.17249238491058, 53.516727313399315, 58.82787711918354, 64.15468588471413, 66.82778164744377, 68.76972824335098, 68.76852750778198, 67.27139264345169, 67.4664893746376, 64.22516450285912, 66.30481570959091, 64.01495218276978, 69.75196033716202, 69.52956587076187, 72.08830296993256, 71.14340767264366, 75.02523377537727, 72.45529487729073, 77.16892674565315, 72.75379925966263, 81.4581061899662, 68.9680016040802, 74.44679841399193, 31.68546997010708, 0.4080238868482411, 2.15257475618273, 1.2901578331366181, 0.1903215897618793, 0.4745704878587276, 12.957188822329044, 78.80337864160538, 53.26802685856819, 39.081993475556374, 13.653190825134516, 51.67403519153595, 12.5316278077662, 0.2568557672202587, 0.023682785831624642, 0.15272337914211676, 0.0689841850544326, 0.032470025835209526, 0.027486049621074926, 0.05743807414546609, 0.05793192147393711, 0.04198815884592477, 0.03425246788538061, 0.01423884903488215, 0.06449975771829486, 0.015619609221175779, 0.05115769396070391, 0.12341108405962586, 0.04647171786928084, 0.14398230443475768, 0.024638200775370933, 0.17341414466500282, 0.26718675973825157, 7.881091553717852, 64.16983187198639, 49.826171547174454, 43.19786421954632, 30.12637373059988, 83.25663328170776, 22.152250818908215, 0.43712744547519833, 0.23133957234676927, 2.3957830807194114, 1.3103903224691749, 0.9628862631507218, 33.18930767476559, 97.37110510468483, 91.18898123502731, 92.76211962103844, 82.7436152100563, 85.1998034119606, 83.39854806661606, 87.33943060040474, 86.88570454716682, 85.81382766366005, 85.29954805970192, 87.22771659493446, 74.86058101058006, 64.33912798762321, 62.0865822583437, 63.01834926009178, 63.86241316795349, 62.09322430193424, 60.87382793426514, 61.62811025977135, 64.01448100805283, 62.40084059536457, 58.61353062093258, 62.10194103419781, 59.27636705338955, 60.79204112291336, 58.26423816382885, 55.908938348293304, 54.53229121863842, 52.61620983481407, 53.54453422129154, 57.01508179306984, 53.146125599741936, 66.14300519227982, 71.4478625357151, 74.6025824546814, 69.93335500359535, 74.53797072172165, 50.2355045825243, 62.17202827334404, 70.73565915226936, 73.01402449607849, 66.88042402267456, 64.08484563231468, 69.1368417441845, 69.96549367904663, 67.75551706552505, 68.25525104999542, 65.81321328878403, 60.416701063513756, 59.45970341563225, 70.233523696661, 61.05635114014149, 55.78477241098881, 62.471759989857674, 66.08340919017792, 57.64914616942406, 67.66197368502617, 63.94149452447891, 61.59191720187664, 65.50141721963882, 67.58590936660767, 55.20310342311859, 62.138856053352356, 63.92563417553902, 59.974530190229416, 55.52573651075363, 61.50453329086304, 61.82442292571068, 65.18702208995819, 60.97569666802883, 53.81166748702526, 65.41760131716728, 58.148701563477516, 61.15478105843067, 61.37457266449928, 63.52950923144817, 50.743537321686745, 51.77081599831581, 50.40581524372101, 50.55394269526005, 53.833717703819275, 60.77171601355076, 60.71818068623543, 60.97829572856426, 52.979971915483475, 49.996467009186745, 53.05191345512867, 62.98330374062061, 64.31324377655983, 62.35573321580887, 57.23041623830795, 58.00183944404125, 55.863378793001175, 68.78244236111641, 62.034289464354515, 58.66530664265156, 51.92334361374378, 49.03433583676815, 50.880242586135864, 48.783644288778305, 51.57488711178303, 51.613789424300194, 53.526143208146095, 52.9212536662817, 50.915573090314865, 53.53567309677601, 54.046829268336296, 54.986309856176376, 54.428989961743355, 60.61964437365532, 65.18406584858894, 68.41857388615608, 69.6009336411953, 70.69057077169418, 70.76686307787895, 68.7523403763771, 65.0725570321083, 67.47816994786263, 66.7909388244152, 71.20703905820847, 71.78404569625854, 74.5751479268074, 74.49112683534622, 76.22395545244217, 74.15751233696938, 79.00211557745934, 77.23486840724945, 81.95378959178925, 74.19264525175095, 77.16169953346252, 37.66927108168602, 0.1346310062217526, 0.7207060209475458, 0.5020732339471579, 0.06682360763079487, 0.5610883422195911, 12.18715064227581, 86.7488206923008, 60.90628579258919, 41.759082823991776, 21.43424704670906, 63.391219452023506, 19.12252899259329, 0.18267844832735136, 0.03994740858615842, 0.04658629433833994, 0.027802918848465197, 0.033717427650117315, 0.01948504643223714, 0.04768905899254605, 0.08736003612284549, 0.060237384677748196, 0.12425565553712659, 0.1579019965720363, 0.10887614407693036, 0.20030383224366233, 0.16039850714150816, 0.12851121195126325, 0.11390305910026655, 0.1919392342097126, 0.09295809315517545, 0.3146523580653593, 0.3872672631405294, 7.913856245577335, 78.5361085832119, 52.23847210407257, 53.83501723408699, 46.8653704226017, 89.7896759212017, 27.504751905798912, 0.7247873581945896, 0.3771728673018515, 3.167906398884952, 10.437039602547884, 1.9335657893680036, 35.62528096139431, 100.23778527975082, 96.24517992138863, 97.63342022895813, 87.86947175860405, 89.2361444234848, 88.11552375555038, 91.69677838683128, 91.09299078583717, 90.07469102740288, 90.48945397138596, 93.36608201265335, 81.34601220488548, 67.58505821228027, 65.57480648159981, 66.74217224121094, 67.31845691800117, 64.20830100774765, 65.90326085686684, 63.83122444152832, 67.22369760274887, 65.31762108206749, 62.09815263748169, 65.04098072648048, 61.659443378448486, 63.40791955590248, 60.82965910434723, 59.84051898121834, 58.95508669316769, 57.52903841435909, 58.788632825016975, 59.56928953528404, 56.82571895420551, 67.66764298081398, 73.5578665137291, 77.17313691973686, 74.42787542939186, 76.7077910900116, 49.19209957122803, 67.82477214932442, 72.72368967533112, 74.11895960569382, 67.41456896066666, 65.66572040319443, 72.63831585645676, 72.31410205364227, 68.63243401050568, 70.70783704519272, 69.42371115088463, 63.62947806715965, 64.99436482787132, 75.99336862564087, 64.95262026786804, 59.46310043334961, 67.43208602070808, 68.86935889720917, 59.14596565067768, 71.25807031989098, 68.06887865066528, 64.66357737779617, 67.52819046378136, 72.42010116577148, 58.50375071167946, 66.06244951486588, 68.08225393295288, 63.891116827726364, 57.468260675668716, 63.460223749279976, 65.19888505339622, 67.34818652272224, 61.51194669306278, 58.74422840774059, 67.70472139120102, 60.75050175189972, 64.05928820371628, 64.25975784659386, 67.86953374743462, 51.46890699863434, 56.555405259132385, 54.638062343001366, 51.023593693971634, 54.77862820029259, 63.85226771235466, 63.85586231946945, 63.99140864610672, 56.766449734568596, 54.40215200185776, 56.52422413229942, 64.6630834043026, 68.50713953375816, 66.15352302789688, 56.08857370913029, 59.70024570822716, 61.39453299343586, 67.88208827376366, 63.338318690657616, 63.05744156241417, 54.661944061517715, 52.12876059114933, 53.582216799259186, 51.17303587496281, 54.26197752356529, 55.28538040816784, 56.800921484827995, 55.536037757992744, 54.68305952847004, 57.15185925364494, 57.977212965488434, 58.65842141211033, 58.37947078049183, 64.14843901991844, 69.70575481653214, 71.75355613231659, 72.7777835726738, 74.07583951950073, 75.11090397834778, 72.88122922182083, 67.38746121525764, 71.23799979686737, 69.70398411154747, 76.80498227477074, 75.12857303023338, 76.96861669421196, 78.5076405107975, 79.32413309812546, 78.63760873675346, 82.27057859301567, 80.67209556698799, 87.01538398861885, 77.8885169327259, 84.26523596048355, 38.66862125694752, 0.6012416782323271, 8.101099748164415, 2.130545200780034, 0.4088518861681223, 0.8212547411676496, 18.466300405561924, 94.56255421042442, 67.301494628191, 55.41812248528004, 20.341701172292233, 74.9503929913044, 22.58867260068655, 0.4596830945229158, 0.19186642952263355, 0.17432107881177217, 0.14331693935673684, 0.13479751447448507, 0.10973698343150318, 0.13562912063207477, 0.1852759503526613, 0.14806978666456416, 0.23966053209733218], [0.03419659158680588, 0.025992957962444052, 0.018746158639260102, 0.04053874814417213, 0.07225454784929752, 0.05145145085407421, 0.06019842563546263, 0.046464956903946586, 0.06621619686484337, 0.33443053427617997, 10.539192371070385, 62.88491941988468, 26.9190988317132, 40.47753319144249, 33.16936254501343, 73.33668038249016, 15.030025094747543, 0.36601337080355734, 0.42799463553819805, 2.6004856964573264, 0.596957883099094, 0.18799403653247282, 53.649959564208984, 99.32385832071304, 87.29431942105293, 86.52676060795784, 78.98837551474571, 81.93406105041504, 80.98974332213402, 85.96708863973618, 85.94999715685844, 83.92452344298363, 82.11126074194908, 81.63073852658272, 77.90950700640678, 63.823237270116806, 62.45692938566208, 60.78936226665974, 60.01470543444157, 55.350341722369194, 57.55703531205654, 58.69933381676674, 60.64121961593628, 56.86510004103184, 58.94306793808937, 56.334302723407745, 58.25873225927353, 54.16463814675808, 55.810675621032715, 50.88437296450138, 50.787717550992966, 50.00209450721741, 53.1145378947258, 49.27951008081436, 54.535270258784294, 62.29474648833275, 68.69577661156654, 64.96938496828079, 71.50343835353851, 60.09769678115845, 53.98426942527294, 66.41871839761734, 64.69569325447083, 67.50980705022812, 69.92868885397911, 64.7449842095375, 64.7893962264061, 63.73682990670204, 62.989770993590355, 62.06614315509796, 58.80305305123329, 55.0037395209074, 60.594231337308884, 62.83929526805878, 58.01238767802715, 52.57817007601261, 61.5614428371191, 60.64271293580532, 62.989573404192924, 63.12125153839588, 57.74577498435974, 64.83155876398087, 63.081216886639595, 54.358484745025635, 53.75554449856281, 59.935650676488876, 57.920934185385704, 58.54437433183193, 59.99752655625343, 61.180585473775864, 60.93016751110554, 59.179677441716194, 65.03518223762512, 52.511122673749924, 55.167503133416176, 63.553007170557976, 55.03500424325466, 63.29787366092205, 59.58529807627201, 57.48906075954437, 44.794929921627045, 51.64069578051567, 54.783719927072525, 61.818339452147484, 58.04161950945854, 57.627483531832695, 53.651794865727425, 48.63006792962551, 49.2940329015255, 52.014937698841095, 53.113033175468445, 59.31149236857891, 63.68008755147457, 56.849885657429695, 57.7209585160017, 50.6189876049757, 53.63315686583519, 66.40644505620003, 58.86579528450966, 53.40170368552208, 42.40835398435593, 45.309080332517624, 43.52063789963722, 48.97690951824188, 50.03072217106819, 50.69177649915218, 49.663080498576164, 49.52869690954685, 50.4068373888731, 50.454726219177246, 51.53952620923519, 51.17352604866028, 56.20338834822178, 62.44903340935707, 65.4476273059845, 64.12889286875725, 65.13807311654091, 61.52216054499149, 59.21634927392006, 59.97527875006199, 65.00899404287338, 65.481848269701, 68.82493168115616, 68.56904581189156, 72.31290891766548, 73.51715549826622, 73.69579151272774, 73.53107035160065, 78.42485815286636, 75.5699497461319, 78.80774840712547, 76.71137809753418, 69.67271938920021, 60.23033246397972, 1.5350983897224069, 0.4298405646113679, 0.29053401318378747, 0.021738579707744066, 0.14014753833180293, 2.2342777345329523, 73.61891403794289, 56.125994101166725, 47.685214430093765, 24.13584318011999, 45.94776526093483, 20.389029532670975, 0.5435845220927149, 0.09453440739889629, 0.02687950160179753, 0.052597389949369244, 0.05890020896913484, 0.08538946334738284, 0.06165008875541389, 0.03164596731949132, 0.046186933541321196, 0.02066464749077568, 0.03815352632955182, 0.01923883337440202, 0.05533388510229997, 0.04055075238284189, 0.06146933126728982, 0.09071792039321736, 0.06176714399771299, 0.12110040726838633, 0.06265784366405569, 0.4389194055693224, 16.453217826783657, 72.70237281918526, 39.33408334851265, 35.560019463300705, 32.44864001870155, 84.63587567210197, 13.880357835441828, 0.34983241406735033, 0.12068074502167292, 1.304453497286886, 1.4466445986181498, 0.31966630776878446, 60.0209105014801, 100.4242792725563, 89.5345576107502, 89.27004620432854, 79.9683429300785, 84.84193101525307, 84.9044680595398, 88.22818011045456, 89.24019500613213, 86.24648004770279, 84.86908435821533, 85.1029846072197, 82.3727323114872, 67.34443232417107, 64.82589706778526, 63.78906190395355, 62.36297942698002, 60.598202124238014, 61.555819138884544, 61.78324073553085, 63.91000181436539, 59.32771749794483, 62.21283808350563, 58.51076513528824, 59.97162714600563, 58.524679988622665, 58.23767378926277, 54.03859131038189, 54.4450668990612, 52.209149077534676, 54.523213505744934, 50.64544178545475, 57.72660121321678, 64.86903235316277, 72.34683349728584, 68.63513946533203, 73.8504584133625, 61.591518223285675, 60.06583549082279, 65.51929146051407, 64.89536494016647, 69.3126431107521, 72.1901223063469, 68.45105454325676, 67.1911333501339, 66.5009231865406, 65.0584065914154, 63.70493061840534, 62.117561995983124, 57.82552510499954, 63.46637561917305, 67.32470378279686, 63.14202882349491, 56.64197601377964, 64.54497814178467, 63.41092899441719, 67.49819487333298, 64.4782081246376, 59.170314744114876, 69.44661632180214, 65.30037000775337, 58.99329364299774, 60.331635028123856, 62.83663921058178, 63.631461560726166, 61.86533533036709, 61.71282671391964, 63.407889157533646, 65.12249395251274, 60.85146613419056, 66.61614060401917, 55.57228401303291, 58.49257171154022, 65.74341863393784, 54.999704137444496, 63.882764875888824, 61.86995968222618, 58.705736473202705, 47.76330403983593, 53.61057087779045, 57.81026132404804, 62.58530169725418, 60.26702329516411, 60.80735430121422, 57.442319467663765, 50.02328597009182, 51.12763971090317, 54.59862045943737, 57.9235902428627, 61.67807757854462, 65.20988926291466, 60.2976306527853, 57.70957812666893, 55.15075743198395, 56.933853551745415, 69.56779181957245, 61.61217391490936, 58.30986991524696, 45.18014185130596, 49.87641625106335, 44.63426314294338, 52.69479341804981, 50.6283313035965, 52.42800213396549, 52.4892358481884, 52.07550264894962, 53.164604008197784, 52.75931395590305, 54.12843368947506, 54.175532162189484, 59.11786235868931, 64.65074926614761, 65.81740826368332, 65.74749201536179, 66.4360910654068, 62.68849655985832, 61.66585363447666, 62.455382868647575, 66.17395833134651, 69.09617632627487, 71.40633836388588, 70.82562312483788, 73.64264756441116, 76.58635720610619, 76.66400983929634, 77.82190650701523, 78.24778005480766, 79.8404797911644, 80.0932802259922, 78.67702782154083, 71.5810377895832, 65.73220923542976, 2.1981599600985646, 0.2133115436299704, 0.244721652707085, 0.04690322108217515, 0.4332245799014345, 2.307570814155042, 76.80547624826431, 65.33927232027054, 52.002941742539406, 27.460609674453735, 59.74376477301121, 27.554337345063686, 0.19807019038125873, 0.12215921451570466, 0.05758740539022256, 0.10175298099056818, 0.018473614181857556, 0.026189916534349322, 0.014404786761588184, 0.07595894829137251, 0.048486129308003, 0.023988398534129374, 0.0830237488844432, 0.11618083648500033, 0.1981620682636276, 0.10769548360258341, 0.1732075010659173, 0.15602969157043844, 0.13716086890781298, 0.19569260155549273, 0.10431376154883765, 0.4650452302303165, 18.673463389277458, 85.87669149041176, 36.99583701789379, 55.2226609736681, 48.59444484114647, 90.15614345669746, 17.281854562461376, 0.6382907589431852, 0.5551947397179902, 5.840786285698414, 4.286985537037253, 0.6298077141400427, 62.932952642440796, 105.59941157698631, 91.85804933309555, 94.58389386534691, 83.74695897102356, 92.35335275530815, 88.64795118570328, 92.77015998959541, 93.06623250246048, 92.60800749063492, 88.35849031805992, 90.81279382109642, 88.19354116916656, 70.25476455688477, 69.142936617136, 67.85035997629166, 65.60914903879166, 64.49548959732056, 65.12358069419861, 65.91321632266045, 68.54513749480247, 62.33650244772434, 64.23703506588936, 61.21314972639084, 62.24932752549648, 60.070152059197426, 62.23953925073147, 56.38236254453659, 58.10253024101257, 54.46177460253239, 58.55445139110088, 54.30804245173931, 59.58926126360893, 67.70606651902199, 74.25325959920883, 71.88077330589294, 78.10824394226074, 62.1534738689661, 57.21628479659557, 71.14608272910118, 67.57995128631592, 72.59206473827362, 75.40563896298409, 70.43023154139519, 71.59033209085464, 69.69847440719604, 69.38525721430779, 69.69450742006302, 65.70594504475594, 60.41835397481918, 66.63731306791306, 69.74101692438126, 67.99355149269104, 59.01594802737236, 69.62896853685379, 66.35032966732979, 68.91348212957382, 68.59850943088531, 63.208825439214706, 75.07485911250114, 69.1286189854145, 61.70830115675926, 60.61769127845764, 65.80772638320923, 63.669809103012085, 63.86861443519592, 63.685768246650696, 66.86025470495224, 69.00223776698112, 63.53693023324013, 70.51755845546722, 57.71902821958065, 63.0341412127018, 67.1922504901886, 57.31870450079441, 69.68623906373978, 64.55294251441956, 59.986552745103836, 48.661746829748154, 57.35212750732899, 59.74664121866226, 66.33126989006996, 62.5437281280756, 63.51127400994301, 60.5433102697134, 53.23601737618446, 55.162324011325836, 57.509644255042076, 59.98443625867367, 66.65156230330467, 68.35648521780968, 63.330711498856544, 61.63058392703533, 59.615768641233444, 59.63195577263832, 67.55944758653641, 66.97582170367241, 61.1734988540411, 47.87086866796017, 52.88401186466217, 46.78252726793289, 54.770017862319946, 54.642048329114914, 55.415926203131676, 56.68808273971081, 56.3381253182888, 55.07709078490734, 55.28007969260216, 56.632734909653664, 55.9612425416708, 61.53501905500889, 66.99383273720741, 69.57329392433167, 69.20918226242065, 70.10377585887909, 66.73692092299461, 65.54828390479088, 67.10081979632378, 70.93020111322403, 70.97504630684853, 73.29992115497589, 75.65268650650978, 77.52092465758324, 78.26878532767296, 78.58055099844933, 82.15868979692459, 82.50621914863586, 83.42707693576813, 84.98991027474403, 82.13354274630547, 78.20251688361168, 70.79834058880806, 2.5219287117943168, 1.172405001707375, 1.1467554280534387, 0.2587760001188144, 1.0550591046921909, 4.769419999793172, 87.20275193452835, 69.22216236591339, 66.328906416893, 35.03455325961113, 66.31364643573761, 34.93889719247818, 0.5986573419068009, 0.2417060246807523, 0.1559821199043654, 0.20793772651813924, 0.15169724123552442, 0.15840471256524324, 0.13845900393789634, 0.15574098128126934, 0.15182953648036346, 0.13416060333838686], [0.1373114952002652, 0.03806992339377757, 0.056162893743021414, 0.08691462135175243, 0.020651398299378343, 0.028178143147670198, 0.045726983807981014, 0.023335547921305988, 0.09043293568538502, 0.2756363485241309, 16.465107388794422, 63.63959312438965, 34.39844459295273, 53.79470519721508, 41.160774528980255, 79.19381529092789, 5.05812993273139, 0.29350857075769454, 0.16355248633772135, 2.185476953163743, 0.3449337347410619, 5.679637882858515, 82.08919152617455, 92.99279004335403, 88.99822399020195, 79.99105051159859, 77.37531647086143, 80.01907020807266, 81.25241562724113, 87.48615592718124, 83.9642845094204, 84.21934202313423, 85.13611882925034, 80.04260614514351, 79.42436411976814, 67.11326792836189, 59.18476916849613, 58.04696962237358, 60.301571041345596, 57.6099056750536, 58.12160521745682, 56.411248594522476, 56.87160909175873, 55.93808278441429, 56.29834525287151, 57.56473369896412, 57.905594408512115, 54.516586661338806, 51.323648393154144, 51.070536375045776, 51.933234483003616, 51.66802391409874, 54.34129446744919, 53.68574224412441, 56.42647437751293, 65.1986038684845, 68.87613773345947, 65.25156542658806, 69.74211886525154, 62.96590447425842, 60.76049141585827, 64.23559114336967, 62.51945503056049, 65.60825988650322, 64.02930021286011, 64.72612962126732, 61.55627891421318, 61.757440119981766, 60.216254219412804, 60.8985798060894, 55.71896754205227, 55.830141976475716, 58.65709148347378, 63.12199629843235, 54.70993548631668, 53.33985820412636, 57.10141696035862, 57.30879843235016, 60.833284109830856, 61.23391941189766, 60.57981111109257, 62.17328600585461, 60.84964983165264, 55.419346019625664, 64.79305163025856, 60.18286921083927, 60.30770391225815, 58.74341145157814, 58.2454139739275, 55.503864884376526, 58.118120804429054, 54.34333115816116, 58.58435198664665, 64.22140270471573, 52.18755483627319, 57.88919448852539, 58.72104965150356, 56.67059987783432, 58.73663641512394, 51.3847491145134, 50.83555318415165, 52.622806280851364, 58.56263995170593, 56.915682926774025, 59.867322742938995, 52.678074315190315, 47.46890343725681, 44.39952313899994, 47.68072307109833, 51.46228015422821, 56.128114387393, 57.275284230709076, 59.04515706002712, 61.248400434851646, 56.37436777353287, 57.436847761273384, 49.34567213058472, 59.621103554964066, 62.89704076945782, 56.078025475144386, 50.19953951239586, 47.23397724330425, 46.93055212497711, 48.743168860673904, 50.17978057265282, 51.00209824740887, 47.79310584068298, 50.15790894627571, 51.00019834935665, 50.6138426810503, 48.522488102316856, 52.81462758779526, 53.9005409181118, 59.30961146950722, 55.50571918487549, 59.101481437683105, 54.27992396056652, 59.572181180119514, 59.65021759271622, 62.13390871882439, 65.79018652439117, 68.13418954610825, 66.82696089148521, 72.15772524476051, 68.82837429642677, 73.10559198260307, 74.70559492707253, 74.85900789499283, 73.97791117429733, 78.52286249399185, 77.42026045918465, 82.99472853541374, 67.12871789932251, 74.43763330578804, 9.182081893086433, 0.4727864539017901, 0.11957582813920453, 0.08508512342814356, 0.3409535373793915, 0.45040274562779814, 62.49275006353855, 67.15274021029472, 51.348122879862785, 32.67065070569515, 42.13006071746349, 28.97749587893486, 0.5114353378303349, 0.026478578583919443, 0.05440653818368446, 0.04710061381047126, 0.0649071745283436, 0.03456431833910756, 0.0245194478702615, 0.02995928458403796, 0.05969480793282855, 0.02679523629922187, 0.03211951319826767, 0.02457255595800234, 0.07545960164861754, 0.03233709605410695, 0.058474698598729447, 0.0310349979554303, 0.047477198095293716, 0.03026085814781254, 0.03822086138825398, 0.2724217210197821, 23.343728184700012, 73.30131947994232, 41.17227651178837, 43.09620827436447, 48.71295668184757, 86.77761554718018, 4.2745340801775455, 0.41569760476704687, 0.22066723642637953, 0.09595355702913366, 0.18940989102702588, 7.3529464937746525, 87.42968335747719, 93.33829030394554, 93.29133242368698, 82.7206340432167, 80.70834562182426, 83.1458692252636, 83.2872824370861, 89.44886460900307, 87.57944092154503, 88.30995932221413, 87.22308084368706, 83.8594101369381, 82.78798922896385, 69.0424320101738, 63.96354854106903, 60.18544167280197, 62.23273381590843, 59.89677116274834, 60.04255793988705, 59.23990420997143, 58.69686394929886, 59.1453842818737, 59.73263897001743, 59.67288337647915, 59.212728068232536, 57.8843117505312, 53.52325916290283, 53.69488075375557, 53.77811908721924, 53.998807445168495, 57.26434841752052, 55.71383021771908, 57.06879571080208, 68.2889324426651, 70.93581721186638, 67.67248392105103, 71.52496799826622, 65.84255531430244, 65.0741757452488, 65.50615176558495, 66.03887557983398, 68.88427689671516, 66.00337788462639, 67.3950608074665, 65.73948204517365, 64.15695816278458, 63.2245147973299, 64.36779364943504, 57.69610784947872, 57.80148759484291, 61.492955312132835, 66.03564575314522, 60.11959880590439, 56.17276959121227, 58.51027876138687, 58.964020013809204, 63.96822988986969, 62.872950062155724, 63.110912293195724, 65.97623214125633, 61.46196037530899, 59.83624421060085, 68.29763397574425, 62.185897529125214, 61.847582682967186, 60.2142783254385, 61.10576368868351, 58.60939264297485, 61.93087041378021, 58.883122354745865, 60.28857573866844, 68.20016920566559, 57.500562742352486, 60.07001906633377, 60.29103800654411, 58.74871216714382, 59.622182697057724, 52.559752464294434, 52.78348445892334, 54.72046472132206, 59.88515518605709, 58.32758076488972, 60.01678392291069, 55.43290749192238, 50.711467042565346, 48.68861898779869, 48.56329411268234, 53.61495204269886, 56.903633773326874, 60.029118061065674, 61.50823049247265, 63.12543511390686, 58.3233629912138, 58.68031583726406, 51.81486703455448, 61.29915811121464, 65.06665214896202, 60.40694318711758, 51.7864141613245, 49.693497866392136, 49.4896350055933, 50.87518125772476, 52.28404685854912, 51.55023403465748, 50.27390532195568, 51.62602856755257, 52.27109335362911, 52.43301406502724, 51.55374504625797, 53.770432099699974, 55.95464989542961, 61.29941649734974, 58.10684680938721, 59.76402148604393, 56.1343764513731, 61.39550194144249, 61.7444334179163, 66.0006420314312, 67.3450630903244, 71.65121242403984, 69.89076688885689, 74.74014267325401, 70.32275050878525, 76.7562384903431, 76.0356755554676, 76.73897221684456, 75.19000053405762, 80.99013850092888, 76.19649812579155, 83.04420188069344, 69.61764514446259, 80.21225944161415, 11.482074726372957, 0.5418582272250205, 0.20763751293998212, 0.02147132676327601, 0.6463510170578957, 0.39575734350364655, 65.46231731772423, 75.85541322827339, 55.99413737654686, 30.7331270724535, 55.4865226149559, 41.394895166158676, 0.33529011940117925, 0.0881020502129104, 0.04369813388620969, 0.02941459828434745, 0.05567528787651099, 0.03558579184755217, 0.0871673300571274, 0.0708958313043695, 0.03319320050650276, 0.07322982637560926, 0.22289127489784732, 0.1103582872019615, 0.19484526186715811, 0.19710680848220363, 0.17641512269619852, 0.1397566046216525, 0.1485463642165996, 0.12047744108713232, 0.2492860984057188, 0.5718807724770159, 29.103681407868862, 83.88245210051537, 46.6850358992815, 71.36211633682251, 57.53838591277599, 95.66664576530457, 5.773174138739705, 1.0101629700511694, 0.35259139258414507, 6.088523967191577, 1.0462295659817755, 7.879240103065968, 91.1445464193821, 98.59393268823624, 96.05834394693375, 86.81529432535172, 85.18601015210152, 86.39858588576317, 89.07584622502327, 93.04922461509705, 92.853322327137, 90.8235776424408, 90.45331791043282, 89.06375527381897, 87.29089960455894, 72.13364973664284, 67.68836706876755, 64.16202709078789, 65.2742426097393, 64.21862125396729, 63.749608621001244, 64.61134538054466, 62.66973316669464, 60.72030857205391, 62.21489377319813, 63.118321895599365, 63.08356516063213, 62.00768709182739, 56.956260949373245, 55.88055767118931, 57.53266341984272, 58.01907151937485, 60.20263195037842, 59.76237237453461, 60.66016919910908, 70.32242372632027, 74.98822376132011, 69.8012512922287, 75.23195028305054, 68.3208279311657, 63.148651868104935, 68.26600447297096, 66.26324594020844, 71.42655327916145, 69.80804532766342, 71.92810356616974, 68.33140656352043, 68.93818840384483, 65.91041207313538, 68.17310705780983, 63.071990981698036, 63.45800846815109, 65.9795531630516, 69.79432046413422, 62.10987500846386, 61.23102016746998, 64.19646844267845, 62.26943604648113, 66.63346007466316, 67.13127136230469, 64.81602519750595, 67.7672204375267, 64.24651935696602, 62.874538376927376, 73.23279395699501, 66.90851971507072, 65.42346820235252, 64.83109518885612, 64.78776231408119, 64.13795918226242, 65.67549347877502, 60.217283964157104, 63.53926710784435, 71.25069871544838, 59.136458560824394, 63.29084783792496, 63.05039294064045, 61.31739713251591, 63.342202082276344, 55.11983849108219, 54.4701037555933, 59.44864980876446, 61.556024327874184, 60.76796941459179, 65.28124943375587, 58.17223750054836, 53.99444527924061, 51.29232667386532, 53.20331633090973, 57.0342555642128, 60.594352930784225, 62.315417379140854, 63.85707825422287, 65.12367948889732, 60.724001973867416, 61.394194811582565, 54.91729415953159, 61.17708206176758, 67.54490956664085, 62.51087509095669, 55.92555105686188, 52.23619602620602, 53.125169724226, 54.94609281420708, 56.57676391303539, 56.45214579999447, 53.326957896351814, 55.26919327676296, 56.83373272418976, 56.758276373147964, 54.706869050860405, 56.22399464249611, 59.3445809930563, 62.60865144431591, 61.84288993477821, 62.51652158796787, 61.348772048950195, 66.26022890210152, 65.45932307839394, 67.8141251206398, 69.94502797722816, 73.75555470585823, 73.15055876970291, 79.29832488298416, 74.12050992250443, 79.00780767202377, 79.09925356507301, 80.56781396269798, 80.72832494974136, 84.16401699185371, 81.95272564888, 87.9821053147316, 76.09567433595657, 85.54240822792053, 11.819932647049427, 0.6385451077949256, 0.6967763893771917, 0.1963703753426671, 1.4020110061392188, 1.3642985047772527, 75.20064756274223, 79.33141350746155, 69.21472996473312, 45.74563890695572, 58.29658582806587, 50.68580701947212, 0.5593809275887907, 0.27311289799399674, 0.1365053150220774, 0.12244831072166562, 0.2720667963149026, 0.1124310314480681, 0.24890136905014515, 0.17553198180394247, 0.12793779897037894, 0.18373817583778873], [0.041363203708897345, 0.05859867436811328, 0.029231369444460142, 0.0762678227329161, 0.10402376734418795, 0.011900209046871169, 0.014898780664225342, 0.09552949384669773, 0.06279710025410168, 0.25132534210570157, 24.50084589421749, 53.56357119977474, 44.242002591490746, 49.14504289627075, 45.16410671174526, 76.48511543869972, 1.3685795688070357, 0.10184843602473848, 0.012117350324842846, 0.08390389892156236, 0.09732757665915415, 18.280298486351967, 92.82481625676155, 87.9727654159069, 86.98698431253433, 76.48094326257706, 82.96371459960938, 79.65972349047661, 86.01059630513191, 83.44110578298569, 85.85732012987137, 84.64020743966103, 81.05739489197731, 78.81813704967499, 81.27366408705711, 70.82719624042511, 63.41077700257301, 59.62170012295246, 58.743981420993805, 58.114966973662376, 58.40809844434261, 56.00786603987217, 58.21838602423668, 56.16986274719238, 55.75861841440201, 56.31027281284332, 56.667655035853386, 53.35396304726601, 53.440081626176834, 48.91534902155399, 50.79412780702114, 53.05015794932842, 53.132963106036186, 51.95159509778023, 54.38320241868496, 64.94679898023605, 66.6997741162777, 63.69981229305267, 68.53354051709175, 63.9593231678009, 61.251915246248245, 65.46301648020744, 62.16896943747997, 63.87576565146446, 63.895980566740036, 63.88882175087929, 62.556381449103355, 62.91419304907322, 55.64925268292427, 55.27892455458641, 52.425577864050865, 53.98590333759785, 57.28660002350807, 64.1154719889164, 56.42810828983784, 52.901441529393196, 54.537500739097595, 59.902060478925705, 63.607158064842224, 60.007090643048286, 61.88777692615986, 61.35099492967129, 54.947145357728004, 56.256080120801926, 62.32233300805092, 56.22084841132164, 53.70367728173733, 55.03235958516598, 59.20836590230465, 58.366965651512146, 55.31272754073143, 57.140729650855064, 56.48633636534214, 59.178727492690086, 61.95473313331604, 55.07552906870842, 60.51055982708931, 57.95871935784817, 60.483946055173874, 55.44650316238403, 50.97504369914532, 55.67150428891182, 56.36754713952541, 59.91796262562275, 53.93797270953655, 50.53316541016102, 47.365351393818855, 45.50373248755932, 44.029810577631, 52.05235429108143, 52.70821049809456, 55.44974818825722, 58.550533801317215, 60.74237018823624, 54.93209056556225, 53.065835908055305, 53.19675028324127, 51.00673779845238, 62.25364409387112, 59.058672934770584, 48.398257568478584, 45.472387969493866, 45.49374282360077, 45.852774158120155, 47.47662462294102, 49.018878266215324, 51.30438722670078, 48.42072956264019, 51.97503983974457, 49.62458856403828, 49.354339465498924, 51.68264552950859, 51.83050699532032, 54.84842665493488, 52.68909752368927, 54.59974519908428, 54.571964889764786, 57.7724077552557, 60.23774966597557, 64.64407682418823, 65.61091214418411, 67.67144277691841, 67.91901469230652, 71.16910949349403, 70.37768796086311, 72.35036730766296, 72.98019871115685, 77.38827377557755, 71.93437322974205, 79.8354184627533, 71.92784518003464, 82.60065168142319, 68.18828344345093, 77.99440205097198, 23.957009576261044, 0.5695982230827212, 0.1781659826519899, 0.1559814074425958, 0.8340841589961201, 0.032668728454154916, 49.42444950342178, 73.2651986181736, 54.1578783094883, 37.12919466197491, 32.641171887516975, 40.204434245824814, 1.131613003090024, 0.1271037882543169, 0.08672755560837686, 0.06933419674169272, 0.08659333077957854, 0.02866845970856957, 0.005123647015352617, 0.0768591437372379, 0.027578241060837172, 0.05367416830267757, 0.06678737598122098, 0.04537374377832748, 0.04816042295715306, 0.018576140028017107, 0.07517661331803538, 0.08040871733101085, 0.04699741446529515, 0.06732659079716541, 0.07894005160778761, 0.16120427171699703, 35.91713950037956, 63.96664157509804, 49.080894738435745, 42.448107451200485, 56.39493606984615, 79.91009965538979, 1.064612742047757, 0.13037492288276553, 0.08481566444970667, 0.08342064204043709, 0.028223570006957743, 22.694985195994377, 97.20442324876785, 90.46619921922684, 91.35630145668983, 80.51760345697403, 85.63687115907669, 82.48934045433998, 89.23193424940109, 86.10013470053673, 87.31249764561653, 87.53822073340416, 85.47778129577637, 81.16387277841568, 83.69902834296227, 74.65434327721596, 66.48424208164215, 64.53164085745811, 62.207594364881516, 61.19659401476383, 60.227307826280594, 58.39766800403595, 60.82813918590546, 60.33223159611225, 59.18276287615299, 58.762220442295074, 59.86139506101608, 53.99208560585976, 55.729416981339455, 52.14167229831219, 55.04445053637028, 54.16530691087246, 54.94161665439606, 53.947502598166466, 58.353039398789406, 68.65853860974312, 70.26494041085243, 66.33436292409897, 72.1550577878952, 64.70135495066643, 66.93097651004791, 66.12742602825165, 62.64117769896984, 67.53789514303207, 68.76907467842102, 67.48497158288956, 64.9459858238697, 62.053334042429924, 57.769462913274765, 57.76536673307419, 55.69013848900795, 59.232851788401604, 61.022673547267914, 66.40051737427711, 59.5369228720665, 58.85602220892906, 56.94744162261486, 61.26770339906216, 67.40638419985771, 65.44353112578392, 64.391770362854, 64.82357159256935, 58.400305062532425, 62.149058505892754, 64.68595817685127, 59.76524122059345, 58.028175830841064, 59.105665013194084, 61.707883179187775, 61.07524752616882, 59.0398183465004, 58.779612109065056, 59.44051444530487, 59.7188913077116, 65.5983804166317, 56.42984859645367, 60.4795078933239, 60.312142074108124, 62.895992025732994, 56.5250638872385, 53.64271715283394, 57.928282991051674, 61.40012249350548, 63.714760690927505, 56.63552775979042, 54.72923085093498, 51.14063501358032, 49.19114962220192, 47.610962614417076, 54.26651068031788, 54.25721637904644, 56.87743037939072, 62.29175224900246, 64.0301513671875, 59.131040051579475, 56.66517376899719, 56.81579388678074, 54.4723304361105, 64.47941645979881, 61.861379742622375, 53.07002708315849, 48.36646467447281, 48.667442724108696, 48.85363273322582, 49.58271861076355, 50.57690106332302, 52.329348027706146, 50.102302730083466, 52.69748367369175, 52.57392570376396, 51.42886094748974, 53.9701721817255, 55.63270837068558, 54.50237922370434, 54.77734386920929, 54.176417514681816, 57.925497740507126, 62.56151497364044, 63.238786831498146, 67.17828243970871, 68.25254559516907, 68.8865339756012, 71.1108510196209, 73.93357515335083, 73.93705576658249, 75.93541413545609, 75.88539361953735, 79.756268709898, 74.74182978272438, 80.69322243332863, 75.21445602178574, 83.8566742837429, 71.53040170669556, 81.3577763736248, 28.13465740531683, 0.4278469184646383, 0.2531998883932829, 0.07635834990651347, 1.3833024725317955, 0.28110817365814, 52.38364711403847, 78.75850304961205, 62.161031663417816, 37.89490297436714, 37.28142969310284, 52.94444762170315, 1.947377691976726, 0.08757552612223662, 0.005189605853956891, 0.044585044888663106, 0.050867937243310735, 0.03807517408858985, 0.10011961043346673, 0.035300484305480495, 0.11811679549282417, 0.028449507590266876, 0.19175638386514038, 0.10944992071017623, 0.1162399337044917, 0.19695643451996148, 0.38225928030442446, 0.12009906451567076, 0.12049118566210382, 0.17006416426738724, 0.27255771216005087, 0.3776119218673557, 48.91027249395847, 70.59768855571747, 56.601926162838936, 66.38312190771103, 62.27140054106712, 88.19796413183212, 1.6939035058021545, 0.7975701964460313, 0.20129828044446185, 1.2758792680688202, 0.2658014668850228, 23.256315775215626, 101.7355053126812, 94.92602750658989, 96.83522745966911, 83.31028640270233, 90.03546953201294, 88.99365663528442, 94.68122944235802, 89.7870996594429, 95.112035125494, 90.66813558340073, 90.02496689558029, 84.55161139369011, 89.03073504567146, 78.11889857053757, 69.30009618401527, 66.64467707276344, 66.58508867025375, 65.553710013628, 64.99786823987961, 62.53253772854805, 64.78264778852463, 63.72845895588398, 59.86710235476494, 62.41084545850754, 62.06564538180828, 58.47967140376568, 60.871707648038864, 55.44215239584446, 56.31850317120552, 58.43085542321205, 57.868994772434235, 56.39428250491619, 60.89701049029827, 70.63325464725494, 73.88971790671349, 69.45969521999359, 73.47989469766617, 69.90264505147934, 66.56003281474113, 67.89260610938072, 67.25544109940529, 68.45464915037155, 71.14349886775017, 69.7046148777008, 65.9254364669323, 66.2125414609909, 61.52716867625713, 62.015662863850594, 60.22999428212643, 61.568913236260414, 63.409971445798874, 71.61975011229515, 65.96313804388046, 61.94042690098286, 58.473846316337585, 65.33688604831696, 69.78844597935677, 68.71453240513802, 67.85558089613914, 69.20350536704063, 63.97395238280296, 63.80109205842018, 71.88171565532684, 64.33293431997299, 60.577827617526054, 61.052026972174644, 64.87349331378937, 65.7724566757679, 61.47426411509514, 64.10342663526535, 61.36710226535797, 64.19741079211235, 67.83957615494728, 60.86433224380016, 63.986172527074814, 62.101629450917244, 64.80182155966759, 58.51375937461853, 54.27756428718567, 62.20762476325035, 64.43913102149963, 66.64436548948288, 60.765400752425194, 56.803991720080376, 54.294195994734764, 52.46241308748722, 49.98719550669193, 56.481237038969994, 55.898416712880135, 61.44804932177067, 63.752766251564026, 68.03531885147095, 61.80230811238289, 56.85257591307163, 58.33238750696182, 55.36164611577988, 69.03727948665619, 63.66447798907757, 54.927773997187614, 51.47843308746815, 49.19083423912525, 52.109092846512794, 53.08288559317589, 54.533529952168465, 55.587969571352005, 52.64921486377716, 57.04612612724304, 54.891706332564354, 54.136352464556694, 56.77825190126896, 58.006361201405525, 58.61344702541828, 56.60684309899807, 57.85585127770901, 60.80456145107746, 63.76925736665726, 65.90127736330032, 70.39625376462936, 72.17201247811317, 71.71586215496063, 74.89161774516106, 77.188860476017, 75.53325891494751, 76.46407216787338, 78.41184765100479, 83.4867337346077, 80.03345623612404, 84.57583129405975, 79.97336626052856, 87.84298717975616, 75.60083448886871, 88.18041667342186, 29.87446054816246, 0.8080631552729756, 0.8688054489903152, 0.3537930187303573, 2.796313175931573, 0.6330203823745251, 62.48088710010052, 83.00039023160934, 71.27266153693199, 53.9678543061018, 44.31378073990345, 67.36033827066422, 1.9521554606035352, 0.1737296613282524, 0.13684366014786065, 0.17889922455651686, 0.33181844162754714, 0.1202997264044825, 0.18509920046199113, 0.13859987840987742, 0.1203655697463546, 0.14126641501206905], [0.0756123430619482, 0.027218375507800374, 0.007804477845638758, 0.010895159266510746, 0.0368541222269414, 0.02051942403340945, 0.024727783566049766, 0.03967226104578003, 0.08392333576921374, 0.05785012566775549, 28.036810755729675, 43.66678945720196, 35.7795374840498, 44.75884705781937, 56.369667425751686, 73.84073853492737, 0.5150199111085385, 0.3255700331646949, 0.04274869694199879, 0.3432831389363855, 0.025022631416504737, 38.87529596686363, 97.51815721392632, 90.67284733057022, 84.12500828504562, 73.44772562384605, 78.68072882294655, 79.79938879609108, 84.35469076037407, 82.73961022496223, 84.78406012058258, 82.6293857395649, 80.91296464204788, 79.14671301841736, 76.52704238891602, 68.29929828643799, 60.28587408363819, 60.92294789850712, 59.19165439903736, 57.50676400959492, 58.963438645005226, 56.86221979558468, 56.94411300122738, 53.94137732684612, 54.55890119075775, 57.20511719584465, 56.201739236712456, 52.85160340368748, 49.99417573213577, 47.69854411482811, 53.36295336484909, 52.34224073588848, 52.557772770524025, 50.689359828829765, 54.14584815502167, 65.09739249944687, 67.91054114699364, 66.06912195682526, 65.1098482310772, 66.02109253406525, 60.1445596665144, 68.81088763475418, 64.09650340676308, 64.89123076200485, 64.91499468684196, 61.38416714966297, 59.729982912540436, 56.48956999182701, 55.51249802112579, 54.07527454197407, 54.39096540212631, 55.15966035425663, 60.512398928403854, 60.43840929865837, 60.56609384715557, 54.891740530729294, 53.93216662108898, 60.28031498193741, 60.32550595700741, 60.284745544195175, 62.58379317820072, 51.45495414733887, 58.93204852938652, 60.626054629683495, 57.214080914855, 57.04017944633961, 60.03414139151573, 59.04979661107063, 59.43416118621826, 61.36585213243961, 61.84185639023781, 59.17074032127857, 58.39069537818432, 58.095166236162186, 60.57748183608055, 60.02010494470596, 58.17614369094372, 57.400377318263054, 59.18284647166729, 52.5189084559679, 47.72370256483555, 53.67939278483391, 54.912365823984146, 56.83006212115288, 51.38124570250511, 49.568590968847275, 46.90042734146118, 46.826418712735176, 47.11243696510792, 50.169232338666916, 54.79067735373974, 55.33454217016697, 59.68809396028519, 62.561191990971565, 58.009560629725456, 58.32199886441231, 54.59988199174404, 45.73328576982021, 61.22344337403774, 59.55847531557083, 54.07019421458244, 47.26607412099838, 47.519797906279564, 44.3493240326643, 47.283587381243706, 46.99937783181667, 49.99199464917183, 51.88263639807701, 50.20710490643978, 50.14791928231716, 50.1807951182127, 51.3405004888773, 52.15286649763584, 52.48745374381542, 52.022886872291565, 55.13821430504322, 55.11785499751568, 60.00072218477726, 62.608928829431534, 67.42976054549217, 67.87010371685028, 69.13013890385628, 68.86812776327133, 71.47034212946892, 70.67714989185333, 70.88894292712212, 68.299480676651, 75.78482061624527, 70.31729400157928, 76.8022084236145, 74.73254308104515, 77.7837185561657, 73.11857208609581, 73.39376851916313, 40.55063746869564, 0.0632350638625212, 0.05637378984829411, 0.07959819558891468, 0.09592076152330264, 0.3604968683794141, 35.30857555568218, 84.90544080734253, 51.57804474234581, 46.20558522641659, 26.318658851087093, 38.74017521739006, 4.875290393829346, 0.23618042352609336, 0.11804284789832309, 0.09193989622872323, 0.07908466650405899, 0.023190343017631676, 0.05305178841808811, 0.06137170174042694, 0.06220965697139036, 0.07665002136491239, 0.03548965403751936, 0.06770487831090577, 0.010683885593607556, 0.01984891958272783, 0.022569456705241464, 0.0339399012591457, 0.013103290730214212, 0.029161644670239184, 0.1580403625848703, 0.019860287429764867, 42.690819427371025, 54.21099565923214, 32.77998223900795, 46.171736642718315, 68.09141904115677, 79.76172521710396, 0.4442734073381871, 0.7428018352948129, 0.09588596221874468, 0.2671609626850113, 0.20567938598105684, 40.850722566246986, 100.74573442339897, 91.96663230657578, 86.29366591572762, 76.34942471981049, 83.4184817969799, 81.94410011172295, 91.40721872448921, 85.04091113805771, 86.1547377705574, 85.56684851646423, 85.30929073691368, 82.53907978534698, 80.25724902749062, 69.67417851090431, 63.74349094927311, 62.76885844767094, 62.415097430348396, 59.9650003015995, 60.39772488176823, 59.55964185297489, 58.73520769178867, 58.42321403324604, 59.047208949923515, 59.207735136151314, 57.45534896850586, 54.7212702780962, 53.075388595461845, 50.27071729302406, 55.342582538723946, 53.08730475604534, 55.20111992955208, 54.20934654772282, 57.47269883751869, 68.279759734869, 69.99678879976273, 69.05500933527946, 68.68985652923584, 68.180972635746, 62.12175317108631, 72.87231490015984, 63.618736043572426, 67.57091537117958, 66.33277460932732, 63.00604932010174, 64.37763512134552, 59.763212129473686, 58.85154604911804, 54.588266015052795, 56.9796334952116, 56.25903636217117, 63.39491285383701, 63.62511210143566, 63.16584214568138, 57.325456738471985, 58.13871189951897, 63.338463082909584, 63.43944266438484, 63.4335757791996, 63.48396107554436, 56.626252457499504, 62.486620992422104, 60.58165781199932, 60.078804194927216, 60.56078553199768, 62.14179329574108, 63.1338706612587, 61.18106044828892, 61.91086448729038, 64.50945764780045, 61.77301548421383, 60.83656333386898, 60.61812445521355, 62.00032688677311, 63.23174200952053, 60.24752654135227, 60.691612511873245, 62.5333546847105, 53.58774930238724, 50.94480872154236, 54.18747492134571, 60.06767839193344, 57.725643664598465, 53.915808498859406, 51.92554749548435, 49.659341499209404, 48.461603969335556, 49.399454444646835, 51.84312231838703, 56.47546894848347, 59.69506278634071, 61.461800783872604, 64.31382894515991, 60.399867966771126, 57.43995979428291, 56.80344074964523, 49.789195731282234, 64.719677567482, 60.927439257502556, 57.63873092830181, 49.40342143177986, 49.673336148262024, 48.65874119102955, 50.23723728954792, 48.713515251874924, 52.37839199602604, 53.36380451917648, 52.593677043914795, 52.581027522683144, 53.24951805174351, 53.465593457221985, 53.90990361571312, 53.47861535847187, 53.06602209806442, 57.6377771794796, 57.76252828538418, 62.19475485384464, 65.00587821006775, 68.63599061965942, 70.13634011149406, 71.90171018242836, 71.98703840374947, 74.41343620419502, 74.54081296920776, 73.418869972229, 71.1982387304306, 76.52830392122269, 74.0708389878273, 78.404650837183, 77.47566148638725, 79.62623968720436, 72.6314990222454, 76.82468041777611, 46.42489805817604, 0.010910749933827901, 0.14775611052755266, 0.07873043941799551, 0.8017989539075643, 0.5368484929203987, 36.52341976761818, 90.13228073716164, 59.022932052612305, 48.49436201155186, 34.041138365864754, 51.665139868855476, 7.114892117679119, 0.1637076842598617, 0.12082847693818621, 0.03634736895037349, 0.08225348123232834, 0.0832057606021408, 0.04234749932948034, 0.048760334320832044, 0.05222848689300008, 0.015442258190887515, 0.13947601342806593, 0.14791605819482356, 0.10196434464887716, 0.08401655693887733, 0.11530498348292895, 0.1583339858916588, 0.10969106675474904, 0.1505945879034698, 0.2420764454291202, 0.13530011172406375, 57.8897188603878, 59.80593703687191, 49.05347540974617, 65.44061288237572, 73.97053197026253, 86.96887448430061, 0.8345213730353862, 1.539599485695362, 0.17518939159344882, 0.47544521279633045, 0.4543365736026317, 42.60868303477764, 106.6088730096817, 98.2317741215229, 90.51199436187744, 80.04496961832047, 88.73425215482712, 86.08041375875473, 94.87008690834045, 90.22478297352791, 90.91754660010338, 88.39429199695587, 87.66123533248901, 85.15147000551224, 84.3017216026783, 74.12088230252266, 66.76974356174469, 67.72381156682968, 66.81361600756645, 63.673779889941216, 64.2654575407505, 63.73831182718277, 61.99152275919914, 62.33253926038742, 61.5947974473238, 62.442991733551025, 61.071637719869614, 58.67859832942486, 55.5546909570694, 52.33730860054493, 59.9579668790102, 56.153725013136864, 57.07095019519329, 55.75221575796604, 60.243422761559486, 71.04258388280869, 72.22329452633858, 70.36657735705376, 72.4218262732029, 69.05987307429314, 66.72021701931953, 71.72424450516701, 65.30080318450928, 70.32617792487144, 68.63401472568512, 68.3100289106369, 66.3802644610405, 64.30603936314583, 62.268159314990044, 59.171686470508575, 61.29478074610233, 61.26993387937546, 66.97782799601555, 67.4389636516571, 68.41291218996048, 60.76761603355408, 59.89379212260246, 66.3385958969593, 65.90882375836372, 67.76079878211021, 65.79185843467712, 58.65815542638302, 65.891914665699, 62.53384865820408, 61.92924030125141, 63.73798884451389, 63.565603494644165, 67.88129791617393, 65.50489023327827, 66.31410241127014, 67.99517780542374, 65.81281810998917, 64.51884314417839, 63.719749823212624, 65.19652158021927, 68.52639690041542, 64.00540709495544, 62.21055440604687, 63.00937034189701, 55.936885848641396, 53.97441655397415, 58.55980530381203, 60.46109788119793, 60.256516858935356, 56.451868414878845, 56.24414496123791, 54.92293305695057, 54.64870937168598, 53.92460882663727, 54.740440249443054, 57.994502037763596, 62.08953469991684, 64.83811721205711, 67.19680264592171, 61.62904120981693, 61.92270465195179, 56.328025460243225, 51.29491813480854, 66.7312516272068, 63.688811883330345, 60.199018344283104, 52.744411155581474, 52.247994393110275, 50.77395088970661, 54.51648026704788, 51.63426272571087, 54.64560113847256, 57.948923483490944, 54.85524348914623, 54.82825353741646, 55.44233858585358, 55.78958675265312, 56.089215874671936, 57.23260872066021, 56.53531573712826, 60.21128788590431, 62.13277257978916, 66.56783759593964, 68.26486453413963, 74.98098894953728, 73.45540881156921, 74.05837565660477, 75.45762777328491, 76.94607630372047, 77.22211629152298, 76.40851154923439, 76.05706080794334, 79.44185838103294, 79.1226527094841, 81.75173163414001, 81.6948638856411, 82.35939502716064, 79.19118583202362, 83.9131772518158, 51.35883070528507, 0.2748701552627608, 0.44459900236688554, 0.3129147528670728, 1.574797946959734, 1.2970330892130733, 43.94065596163273, 98.35810974240303, 66.19715988636017, 64.97532784938812, 41.28261499106884, 66.0704442858696, 7.897189389914274, 0.3227659617550671, 0.23038425017148256, 0.2705704187974334, 0.20019418734591454, 0.12593526189448312, 0.20610983163351193, 0.2172226767288521, 0.14363640424562618, 0.12794519076123834], [0.0163709391199518, 0.005446740078696166, 0.015983510202204343, 0.04413927388668526, 0.0948279861768242, 0.10931456039543264, 0.06533265521284193, 0.13123565091518685, 0.1298083970323205, 0.3639626980293542, 30.53448513150215, 38.83657604455948, 40.15124469995499, 45.21676428616047, 61.12292356789112, 65.76440870761871, 0.6449556606821716, 0.636947174789384, 0.0807565767900087, 0.09115169828874059, 0.18969382188515738, 48.9866977930069, 94.22348320484161, 87.40793332457542, 84.63243305683136, 72.35103607177734, 79.47750806808472, 82.51478388905525, 85.05123898386955, 85.24613052606583, 83.92900720238686, 82.25295513868332, 82.5940628349781, 80.83610236644745, 77.30935961008072, 73.0564834177494, 63.440362215042114, 58.79871368408203, 58.143727630376816, 58.31279195845127, 58.303155675530434, 57.439207434654236, 58.01636226475239, 54.988882318139076, 54.302635341882706, 55.94399146735668, 55.45772776007652, 50.220563784241676, 47.754716500639915, 49.17506128549576, 50.20982176065445, 54.04080659151077, 53.82088199257851, 52.57351152598858, 55.4595972597599, 63.62174928188324, 64.90788146853447, 66.95005908608437, 63.86077165603638, 66.57207816839218, 60.32510317862034, 57.824936136603355, 76.00808903574944, 60.95386303961277, 63.90616402029991, 61.98834612965584, 59.350881054997444, 58.57299439609051, 52.31136739253998, 53.738635405898094, 53.751094937324524, 56.60133719444275, 59.090735614299774, 62.77842253446579, 57.68508464097977, 54.396387711167336, 53.63966591656208, 60.61680592596531, 61.799253076314926, 58.722808957099915, 56.34684205055237, 56.81505672633648, 60.5120075494051, 56.14729955792427, 56.967048570513725, 61.90906718373299, 58.685532957315445, 54.28889527916908, 50.38003362715244, 55.163494348526, 57.29601211845875, 58.35007555782795, 59.26956921815872, 59.349467530846596, 56.77342236042023, 60.473511815071106, 54.00325320661068, 57.345762848854065, 59.341164976358414, 51.90700829029083, 45.52985988557339, 50.49462027847767, 57.24662996828556, 58.98997262120247, 52.448927611112595, 50.560003370046616, 46.68058633804321, 45.64153589308262, 48.610278591513634, 52.006578147411346, 53.09465356171131, 55.679723247885704, 55.610076785087585, 59.261270463466644, 54.31938864290714, 55.600463300943375, 54.216034188866615, 43.535457104444504, 63.550244718790054, 57.44107313454151, 59.054952934384346, 49.35134522616863, 47.26901136338711, 45.969112515449524, 48.64645645022392, 44.99005325138569, 48.14432479441166, 47.940978705883026, 51.101379320025444, 49.36387695372105, 50.38075178861618, 48.608694076538086, 52.20349498093128, 51.097940504550934, 53.279323652386665, 57.11704932153225, 58.87785203754902, 59.717204198241234, 62.75220774114132, 66.18308544158936, 65.00781610608101, 69.96920987963676, 69.54256877303123, 68.02723288536072, 71.39501497149467, 72.8670483827591, 71.2562008202076, 73.60118418931961, 75.63171923160553, 71.92211508750916, 74.1680833697319, 73.10221776366234, 76.42656058073044, 69.58913147449493, 61.73314042389393, 0.4600552667398006, 0.1251478135236539, 0.17080009274650365, 0.6080554844811559, 0.07837216762709431, 25.757957138121128, 84.32772740721703, 55.797022953629494, 46.271534487605095, 23.420926742255688, 34.38644103705883, 8.802047185599804, 0.09298004588345066, 0.03127890850009862, 0.026167381220147945, 0.0035685496141013573, 0.0799397319497075, 0.02724431727983756, 0.04762456264870707, 0.020571472705341876, 0.03605387180869002, 0.04862927475187462, 0.0224382505621179, 0.004548680626612622, 0.06756148795830086, 0.03952556442527566, 0.0014931462760614522, 0.05020257958676666, 0.10876590546104126, 0.10893068450968713, 0.9650449629407376, 47.6673249900341, 48.43972474336624, 39.94941093027592, 50.18374375998974, 69.76537361741066, 72.55257725715637, 0.7262667850591242, 0.7516174810007215, 0.06191084234160371, 0.0868079747306183, 0.2400190191110596, 53.0405330657959, 94.28386196494102, 88.21455404162407, 84.4677346944809, 76.32193699479103, 82.75487780570984, 85.29597625136375, 89.50742706656456, 89.73055109381676, 87.28272244334221, 84.18781131505966, 85.21596774458885, 83.04295554757118, 78.6692002415657, 76.29105985164642, 64.7988349199295, 61.5106775611639, 60.741469636559486, 61.50522865355015, 59.67911884188652, 60.71177423000336, 60.25669164955616, 57.9139007627964, 57.621232867240906, 58.021290600299835, 56.97864554822445, 52.638301849365234, 50.291540175676346, 50.84094129502773, 52.86681018769741, 56.25189274549484, 56.09796300530434, 54.54524092376232, 58.73906448483467, 67.59038552641869, 67.62795031070709, 69.59554553031921, 66.04159623384476, 70.0889490544796, 63.49942624568939, 63.166788294911385, 73.48779067397118, 62.21202872693539, 67.25009858608246, 64.44036215543747, 60.884467363357544, 59.24659565091133, 54.77910317480564, 56.71338178217411, 56.850660815835, 59.12709206342697, 63.49358215928078, 63.747355341911316, 59.70991998910904, 57.92592711746693, 56.715418472886086, 63.80629777908325, 66.05512350797653, 60.46303577721119, 60.21117389202118, 60.47488734126091, 63.42724531888962, 59.170424938201904, 60.178909823298454, 66.38809204101562, 60.08417710661888, 54.97446969151497, 53.1713942438364, 57.441016137599945, 58.11891496181488, 58.82532745599747, 62.66011968255043, 60.00573791563511, 57.353651225566864, 62.75628112256527, 56.8556347489357, 57.46273957192898, 61.77091419696808, 50.42885720729828, 47.6060950756073, 52.43547633290291, 59.228702411055565, 63.021164909005165, 55.699326395988464, 53.27442951500416, 49.11414295434952, 47.464385479688644, 50.84137827157974, 51.93558655679226, 54.42286089062691, 57.797752395272255, 60.72033517062664, 62.296748980879784, 57.658687457442284, 57.09224045276642, 56.292497366666794, 46.75901032984257, 66.12536653876305, 59.99022714793682, 60.066120475530624, 50.473899990320206, 50.724260956048965, 47.970047146081924, 48.77574071288109, 46.91718824207783, 50.56688480079174, 49.67557802796364, 53.060500994324684, 52.24190331995487, 52.544120103120804, 50.81509508192539, 53.20439927279949, 54.01374064385891, 56.429632008075714, 57.6987449079752, 62.05701224505901, 61.88016213476658, 66.25308528542519, 67.30841785669327, 68.33322286605835, 71.22555166482925, 71.96882218122482, 69.96245384216309, 73.9509630203247, 74.4865594804287, 75.09774908423424, 75.17295464873314, 78.33196073770523, 75.32819151878357, 77.45886638760567, 74.8624961078167, 81.90100282430649, 71.95554569363594, 70.09834215044975, 0.7562811963725835, 0.06683516287012026, 0.18249914544867352, 2.1128393383696675, 0.13684870675206184, 28.139165863394737, 86.47550135850906, 64.54707562923431, 45.852542370557785, 31.748654879629612, 49.456230998039246, 8.161932583898306, 0.07142545015085489, 0.025075511293835007, 0.05123362680024002, 0.038371740010916255, 0.07037635761662386, 0.026662282398319803, 0.026900578595814295, 0.09193395904731005, 0.11074789246777073, 0.14822192693827674, 0.11695528985001147, 0.1373053650604561, 0.2690357167739421, 0.1518251429661177, 0.16670982004143298, 0.20287170773372054, 0.39613123750314116, 0.20232130133081228, 1.6654836433008313, 65.78064903616905, 53.531785905361176, 56.41558796167374, 63.26156660914421, 78.14651548862457, 77.51270189881325, 2.010145098902285, 2.682634200900793, 0.28389478975441307, 0.3007432341109961, 0.5147492350079119, 56.38822942972183, 98.99386882781982, 94.13880094885826, 91.09017133712769, 81.48586750030518, 85.86710080504417, 90.50632506608963, 95.57553425431252, 97.13937073945999, 90.92951595783234, 88.06671157479286, 88.12612518668175, 89.77836772799492, 82.45593264698982, 81.3521982729435, 68.63016173243523, 65.39245426654816, 62.615000903606415, 65.23752897977829, 63.43545287847519, 64.07485976815224, 63.33296857774258, 61.0041381418705, 59.548075273633, 60.50080955028534, 60.96249997615814, 56.78238607943058, 51.95506811141968, 55.492887273430824, 55.46414561569691, 59.33141849935055, 59.136758744716644, 58.52469138801098, 59.98768508434296, 68.96281868219376, 69.47639912366867, 72.61373117566109, 67.8526322543621, 74.5248994231224, 69.59924653172493, 69.18523594737053, 71.10981747508049, 62.773342207074165, 72.51132667064667, 66.50689646601677, 66.53880715370178, 65.33107995986938, 59.987571090459824, 59.74810034036636, 59.11328740417957, 63.45238856971264, 67.43070289492607, 68.37917760014534, 64.12448510527611, 63.242636024951935, 61.11975833773613, 65.90104937553406, 70.84540486335754, 62.276708856225014, 62.216280698776245, 61.19186706840992, 66.54991015791893, 58.83810997009277, 63.942604064941406, 69.01055172085762, 63.060447201132774, 58.31718072295189, 54.881872460246086, 60.05175344645977, 60.13625331223011, 63.16730886697769, 66.34998008608818, 62.86091610789299, 59.23716835677624, 65.22938221693039, 58.438489213585854, 61.080719232559204, 64.12383154034615, 53.06343823671341, 50.633715614676476, 55.38968101143837, 62.94087141752243, 66.84326201677322, 58.559923097491264, 56.8928537517786, 53.71280059218407, 50.92200994491577, 55.03002651035786, 55.781075209379196, 56.93782053887844, 60.95041662454605, 60.09385138750076, 66.17306157946587, 60.513421073555946, 58.32409255206585, 56.38131000101566, 49.43503953516483, 68.38087990880013, 63.8486123085022, 63.014826849102974, 54.38982546329498, 53.594683930277824, 52.629984095692635, 52.140357568860054, 50.68033531308174, 52.89679057896137, 53.38097959756851, 55.61053276062012, 54.60628464818001, 54.61964093148708, 53.668798953294754, 55.568864196538925, 57.69455373287201, 58.75085145235062, 61.74934655427933, 65.89031875133514, 65.2269883453846, 70.62724336981773, 70.79078659415245, 72.94024765491486, 74.83758464455605, 75.0763638317585, 73.60239252448082, 77.87920743227005, 76.48100405931473, 79.04705956578255, 78.91478106379509, 84.61620032787323, 78.21338430047035, 83.41164976358414, 79.53433021903038, 87.6013733446598, 77.30569660663605, 74.43536102771759, 0.6982605659868568, 0.3000279818661511, 0.8151172392535955, 3.4338059183210135, 0.5837309116031975, 31.41740955412388, 95.57281360030174, 69.0396049618721, 65.65435901284218, 36.78005039691925, 65.25317654013634, 11.889397669583559, 0.23683904990321025, 0.15518555796006694, 0.15463240561075509, 0.14388092706212774, 0.12933717778651044, 0.1427396820508875, 0.18589331331895664, 0.13156384346075356, 0.20546687941532582], [0.04362532177765388, 0.036542928573908284, 0.04708487285824958, 0.11959502749959938, 0.04253849845554214, 0.09612800626200624, 0.03987829608377069, 0.09668421625974588, 0.17278698534937575, 1.9586201012134552, 39.1624541580677, 30.888054259121418, 43.94654184579849, 45.095911771059036, 70.6031146645546, 63.85840818285942, 0.47779508982785046, 0.2718425786588341, 0.09827599686104804, 0.06125515858002473, 0.46068018476944417, 58.04850473999977, 93.80895584821701, 87.35238030552864, 80.95567435026169, 72.08598509430885, 77.10449740290642, 78.08871299028397, 82.73702636361122, 80.88544651865959, 79.79428946971893, 82.82660275697708, 80.89181497693062, 80.72712421417236, 76.26879304647446, 72.63838425278664, 68.35706278681755, 57.8792542219162, 58.56466144323349, 57.1794343739748, 57.979967817664146, 55.13675518333912, 55.885125026106834, 54.42576013505459, 56.43071874976158, 58.94693233072758, 52.17741698026657, 47.71027788519859, 49.638153836131096, 49.81603369116783, 52.71182410418987, 53.736534118652344, 54.25389155745506, 48.790092542767525, 57.38698683679104, 65.64097613096237, 68.46419423818588, 64.84724432229996, 64.68204438686371, 65.20214527845383, 64.82108652591705, 54.48507495224476, 59.84669364988804, 77.5274147093296, 62.84112676978111, 62.83324219286442, 59.17598024010658, 52.32392191886902, 51.51574708521366, 53.696754053235054, 53.52309577167034, 59.23467569053173, 57.607337012887, 60.4182817786932, 57.92767122387886, 55.13852208852768, 51.31762191653252, 59.75218512117863, 59.692741110920906, 55.47510042786598, 58.7753601372242, 56.08089432120323, 62.49184191226959, 57.7934206277132, 59.127532839775085, 60.55178761482239, 55.80765098333359, 55.20824454724789, 49.3736158311367, 51.67743220925331, 53.32112520933151, 53.93991060554981, 54.61065821349621, 59.17384095489979, 55.45034095644951, 59.45103608071804, 58.68948854506016, 53.936612382531166, 59.477794244885445, 50.60908153653145, 41.48332022130489, 47.506730407476425, 55.432405918836594, 56.474481001496315, 52.22765028476715, 50.90005472302437, 46.59479834139347, 47.414547353982925, 48.41530725359917, 51.282257214188576, 50.06775878369808, 55.84284469485283, 56.159489303827286, 60.12825474143028, 55.738460496068, 63.009666725993156, 42.87004441022873, 50.33961519598961, 61.25049412250519, 56.932489424943924, 58.990534991025925, 50.6632324308157, 48.18856582045555, 45.70063032209873, 46.08792074024677, 45.514835491776466, 44.16784957051277, 48.47442448139191, 49.66493859887123, 50.401688665151596, 50.10747045278549, 50.19073158502579, 51.7095822840929, 51.03886507451534, 52.612938210368156, 54.24885682761669, 59.99920226633549, 62.887700870633125, 64.885014295578, 64.95866194367409, 68.45092535018921, 66.39473408460617, 73.17027971148491, 69.66274872422218, 73.15410777926445, 71.91468268632889, 72.26347357034683, 67.796630859375, 71.3170051574707, 62.74904251098633, 75.84407463669777, 70.09284764528275, 77.153529971838, 64.8531948029995, 76.84361100196838, 5.192519221454859, 0.28352427994832397, 0.13469766592606902, 0.6781069817952812, 0.14291708503151312, 22.283877655863762, 86.09517216682434, 55.20486652851105, 55.85950680077076, 23.68328746408224, 23.20527121424675, 6.931598028168082, 0.26565244363155216, 0.02471523384883767, 0.06450993998441845, 0.01860957192548085, 0.029068037583783735, 0.04398414646857418, 0.11479858643724583, 0.09034272763528861, 0.06261270624236204, 0.03599047013267409, 0.06601080007385463, 0.08552251558285207, 0.08092931908322498, 0.026948142840410583, 0.10795580674312077, 0.08540196111425757, 0.17090577457565814, 0.2823466993868351, 3.7189796660095453, 54.28180865943432, 42.00840264558792, 51.621438413858414, 53.353765457868576, 80.16386523842812, 68.96170154213905, 0.7426179607864469, 0.5271265958435833, 0.07535918164649047, 0.06273433682508767, 0.5953736649826169, 61.08572356402874, 97.1322575211525, 88.83903533220291, 84.87596958875656, 73.22251930832863, 81.89616188406944, 81.25662580132484, 87.67243713140488, 84.98946189880371, 81.6426394879818, 84.34363335371017, 82.2502800822258, 84.23877418041229, 80.64126402139664, 75.56820183992386, 70.83900600671768, 60.31439155340195, 63.372558653354645, 59.106953144073486, 61.94595940411091, 56.16211496293545, 59.672469198703766, 57.64202535152435, 59.26870286464691, 60.21639481186867, 54.84523102641106, 50.125952661037445, 52.98441767692566, 51.38150408864021, 54.60014417767525, 56.63364306092262, 54.84016589820385, 51.796039044857025, 58.70411396026611, 68.32154989242554, 70.33696174621582, 67.97704517841339, 64.89027321338654, 65.4873275756836, 69.45120647549629, 57.50341638922691, 61.87847122550011, 74.08737570047379, 61.518011167645454, 64.92912992835045, 62.62918934226036, 58.04444655776024, 54.97380472719669, 58.34922820329666, 56.314323395490646, 62.43876256048679, 60.719643607735634, 65.86776316165924, 61.04442737996578, 58.71911555528641, 50.23703210055828, 58.40793885290623, 59.201321080327034, 60.71399711072445, 62.097480073571205, 57.62806110084057, 64.5633539557457, 57.83947415649891, 61.521373987197876, 62.553816586732864, 57.33242556452751, 56.63566455245018, 51.69779151678085, 55.359123051166534, 55.96502333879471, 53.841264098882675, 55.79829588532448, 60.47041118144989, 55.56430444121361, 60.42708970606327, 62.43447259068489, 58.15570458769798, 62.35999658703804, 52.35197201371193, 43.61048027873039, 50.53819254040718, 56.559581235051155, 59.82650153338909, 54.59683075547218, 53.721923902630806, 50.87634019553661, 50.51489979028702, 50.634179189801216, 52.214499190449715, 52.563411667943, 58.61244387924671, 58.664729073643684, 61.657220497727394, 57.86136478185654, 60.813490971922874, 45.63963979482651, 53.74701015651226, 64.68371629714966, 58.56875002384186, 60.399731174111366, 54.054881036281586, 50.26615373790264, 47.958385571837425, 48.55812259018421, 48.42842794954777, 48.53465884923935, 49.85823042690754, 52.22809486091137, 52.23741576075554, 52.632643952965736, 52.05775000154972, 53.20719972252846, 53.05743835866451, 54.82714019715786, 55.76293118298054, 61.682595536112785, 65.38689896464348, 67.29889556765556, 69.10821408033371, 71.82523548603058, 68.06634038686752, 75.90133756399155, 71.24457344412804, 76.46031036973, 72.38223999738693, 74.98491033911705, 69.32482525706291, 72.94707208871841, 64.49071705341339, 79.26725775003433, 72.4314397573471, 81.988056153059, 66.54123902320862, 83.05599644780159, 6.396177783608437, 0.22597843111725524, 0.05245103100605775, 1.0946812410838902, 0.36976682720705867, 24.91211872547865, 94.09084752202034, 64.20696347951889, 60.30599020421505, 24.59729041904211, 44.26757521927357, 12.051178738474846, 0.44185302627738565, 0.10604304727166891, 0.08098189282463863, 0.030006949018570594, 0.031011937571747694, 0.030027732864255086, 0.16295251931296661, 0.06513891014037654, 0.06716916643199511, 0.14806193474214524, 0.14614236977649853, 0.14041836286196485, 0.2971200691536069, 0.1862682166392915, 0.17423841840354726, 0.23092345014447346, 0.22550454013980925, 0.41573747294023633, 5.036491518840194, 65.52572831511497, 46.26288615167141, 54.78120066225529, 61.59370690584183, 87.95100018382072, 77.09045335650444, 1.648421015124768, 1.8893909035250545, 0.3076145122759044, 0.17594853445189074, 0.9321779140736908, 65.98479688167572, 101.39871418476105, 94.69243124127388, 91.1653845012188, 78.67126733064651, 87.6465605199337, 83.21074694395065, 93.08647021651268, 88.16145569086075, 86.41231074929237, 90.63782081007957, 84.92586851119995, 87.2674548625946, 84.21111166477203, 78.99206131696701, 77.00887933373451, 63.241161704063416, 65.4008138179779, 62.45827451348305, 64.3362857401371, 60.13781502842903, 60.37483870983124, 59.86255019903183, 60.85285305976868, 65.37879019975662, 56.677146926522255, 54.165671691298485, 55.15661671757698, 56.05743058025837, 58.79141427576542, 59.99022714793682, 58.00454489886761, 53.116901367902756, 60.08881665766239, 70.2198976278305, 72.14671343564987, 71.21826365590096, 68.20909112691879, 68.4359085559845, 71.21176600456238, 61.59992717206478, 73.68275061249733, 75.97389087080956, 64.4651672244072, 68.06194022297859, 65.11087417602539, 60.737343057990074, 58.84007826447487, 59.99870449304581, 60.07217735052109, 67.13240370154381, 64.64431241154671, 67.31524229049683, 64.49324771761894, 63.865323811769485, 57.864313423633575, 64.52088743448257, 65.16744554042816, 61.24385967850685, 64.72374334931374, 61.83922313153744, 69.62291926145554, 61.01645328104496, 64.65955719351768, 66.48238018155098, 59.261965826153755, 58.08489538729191, 53.13312649726868, 55.86153209209442, 56.36998660862446, 55.67509509623051, 57.67744705080986, 64.10507574677467, 59.561530351638794, 63.70372608304024, 64.65574979782104, 59.35808166861534, 64.09456551074982, 55.109191462397575, 45.59451721608639, 54.58562135696411, 61.55066281557083, 62.16798149049282, 56.67089246213436, 55.93057818710804, 55.5874489992857, 54.78962101042271, 53.58946681022644, 57.21346914768219, 55.32460190355778, 61.01004682481289, 60.34551948308945, 64.82288762927055, 57.66865812242031, 60.422324761748314, 51.63637541234493, 55.623744651675224, 65.73754414916039, 61.77377924323082, 63.5344185680151, 56.38661451637745, 53.753059431910515, 52.01440192759037, 51.482255682349205, 51.172606498003006, 49.290172308683395, 55.30107356607914, 55.1885350048542, 56.618896052241325, 55.61608426272869, 55.60270518064499, 56.252341121435165, 55.01309461891651, 56.91299647092819, 59.86113667488098, 65.6818163394928, 69.77752536535263, 70.34143030643463, 71.96532636880875, 73.75995486974716, 74.81297716498375, 79.94145557284355, 75.60941442847252, 81.07663705945015, 78.07451695203781, 78.13162788748741, 73.45334932208061, 77.93477565050125, 69.90016758441925, 85.31665474176407, 78.74370664358139, 88.42318564653397, 71.7088933289051, 90.25737762451172, 7.570395525544882, 0.2805933606578037, 0.47028612869326025, 2.540244678966701, 0.8631753385998309, 27.59416300803423, 103.40363100171089, 65.7545368373394, 82.30951130390167, 35.44581279158592, 55.31488582491875, 18.27778872102499, 0.5843367415945977, 0.20607487647794187, 0.21406483836472034, 0.19126439932733774, 0.16149730130564421, 0.07566260130261071, 0.13830977288307622, 0.16558644594624639, 0.13375334237935022], [0.027453983275336213, 0.10922871617367491, 0.12077290492015891, 0.035079680528724566, 0.12291048318729736, 0.006419173396352562, 0.06701665508444421, 0.023833799896237906, 0.3600674617337063, 6.673209993168712, 50.67384906113148, 37.30070225894451, 37.729395255446434, 50.21932125091553, 68.46262872219086, 60.76834179461002, 0.18373939295997843, 0.3193047037348151, 0.0538751196290832, 0.070902933657635, 0.2842137648258358, 63.49519707262516, 90.88081017136574, 84.52078744769096, 78.17341044545174, 71.46594196557999, 72.95686796307564, 74.96466502547264, 79.81748342514038, 82.59412363171577, 83.89224797487259, 81.70621007680893, 82.76751592755318, 79.17138889431953, 77.551079839468, 74.76043358445168, 73.79897117614746, 64.01172995567322, 56.819658279418945, 57.370579317212105, 57.45991252362728, 56.54544219374657, 57.46416449546814, 56.29256196320057, 54.30089123547077, 56.077843084931374, 50.99510282278061, 46.34920611977577, 48.35710197687149, 49.83775332570076, 53.39218519628048, 55.596982687711716, 50.399921759963036, 50.507839769124985, 56.49026535451412, 67.220718562603, 65.04439294338226, 68.7276417016983, 61.379299610853195, 59.4915647059679, 60.37637382745743, 64.58561316132545, 46.39443129301071, 47.073777839541435, 69.06477481126785, 63.86407747864723, 60.27677357196808, 57.43618279695511, 50.656567588448524, 52.898618280887604, 54.71493981778622, 59.02083836495876, 60.76364904642105, 62.383342534303665, 58.70672062039375, 55.42750418186188, 45.40009684860706, 50.1572971791029, 52.65084117650986, 58.573883548378944, 56.60495840013027, 54.82372798025608, 59.02963489294052, 58.49186114966869, 57.25980766117573, 51.551157385110855, 54.21424448490143, 56.461747884750366, 55.7148751616478, 58.126636147499084, 55.1959940046072, 53.160093650221825, 50.60451418161392, 57.81400412321091, 57.418395951390266, 59.16380949318409, 57.45618112385273, 59.0298742800951, 59.321014657616615, 51.43995635211468, 42.85722389817238, 50.32680228352547, 55.904617980122566, 55.93146353960037, 52.23378695547581, 52.721334993839264, 47.73316405713558, 47.94912546873093, 49.633575081825256, 51.435168609023094, 50.45238554477692, 52.746520042419434, 55.84434561431408, 56.90926507115364, 55.82296796143055, 45.750248059630394, 42.801765874028206, 60.43335177004337, 54.48909893631935, 57.74281494319439, 57.2177667170763, 54.428723976016045, 49.08896170556545, 47.339968755841255, 44.82300661504269, 45.65820559859276, 45.22003211081028, 45.327585339546204, 48.60597342252731, 49.73866984248161, 50.475537702441216, 50.04231534898281, 52.606805339455605, 51.517096012830734, 52.55787916481495, 54.607029408216476, 58.26999485492706, 60.6719371676445, 64.78803589940071, 63.201526030898094, 70.13374105095863, 64.6596559882164, 67.74487003684044, 68.05562496185303, 69.63351309299469, 68.57969284057617, 70.17614677548409, 66.38642013072968, 69.96259063482285, 64.79014098644257, 76.6798397898674, 65.96211969852448, 79.07607480883598, 66.77120268344879, 77.67686069011688, 15.210442263633013, 0.42722318787127733, 0.09017190008307807, 1.5020899171940982, 0.26437312946654856, 20.882465355098248, 82.59454920887947, 60.04705309867859, 52.84955531358719, 34.34035710990429, 24.37055468559265, 10.753639563918114, 0.5430580128449947, 0.2336640827707015, 0.1756597202620469, 0.09865723812254146, 0.08998154662549496, 0.09481510249315761, 0.06907983304699883, 0.03819104931608308, 0.03425368129683193, 0.012923046251671622, 0.07554599505965598, 0.08992223418317735, 0.019030829789699055, 0.032997919188346714, 0.02930456004833104, 0.15848378097871318, 0.1589993212837726, 0.49153310421388596, 14.185221176594496, 63.19503977894783, 46.185020729899406, 37.6397542655468, 57.12091751396656, 75.46080440282822, 65.46540275216103, 0.7533996447455138, 1.6392744309268892, 0.1243393772165291, 0.05897815673961304, 0.5415126832667738, 65.58273285627365, 92.1442499756813, 87.03466415405273, 81.20115637779236, 74.05381590127945, 75.53917899727821, 78.9747266471386, 83.30961763858795, 84.87576439976692, 85.0126102566719, 86.47821441292763, 85.82387432456017, 83.3991028368473, 81.47670239210129, 78.07437255978584, 74.64208513498306, 67.97840550541878, 59.11607265472412, 62.81421661376953, 59.490876942873, 59.485564827919006, 59.54755090177059, 59.89292196929455, 57.96979196369648, 58.08131977915764, 52.71756559610367, 49.77384075522423, 50.37182226777077, 53.13599534332752, 53.7057975679636, 57.11389169096947, 53.75968247652054, 51.9609159976244, 59.35266695916653, 68.71466919779778, 67.83585995435715, 70.42094483971596, 65.52426159381866, 64.72989901900291, 63.64520542323589, 67.28290602564812, 49.56499636173248, 48.957747146487236, 65.806335657835, 65.81037104129791, 63.361360654234886, 60.26122100651264, 53.995463624596596, 57.440491765737534, 59.38601776957512, 61.09523065388203, 61.700294986367226, 63.657691553235054, 60.838470831513405, 59.08626325428486, 49.28107179701328, 52.25466303527355, 54.085784777998924, 61.114754006266594, 61.87415465712547, 59.2925313860178, 60.366038382053375, 59.692003950476646, 57.80328489840031, 54.62563320994377, 56.54609575867653, 57.8523288667202, 58.91860485076904, 60.96167542040348, 57.2518926858902, 54.14912737905979, 51.445443257689476, 58.800921365618706, 58.608989864587784, 58.945146426558495, 61.17952913045883, 60.39047107100487, 63.04376229643822, 50.99592737853527, 45.66891722381115, 55.67145109176636, 58.44761252403259, 58.03039871156216, 54.13608267903328, 55.8787527680397, 50.76011583209038, 50.174555853009224, 51.8302296102047, 54.41461153328419, 55.89822672307491, 56.35453663766384, 59.236754179000854, 53.65776054561138, 54.035011902451515, 46.95533439517021, 47.61119820177555, 62.556689232587814, 58.221460059285164, 60.41767381131649, 60.58829605579376, 57.24154204130173, 49.06455561518669, 48.81170958280563, 46.75244428217411, 47.00676843523979, 49.026451259851456, 46.319153532385826, 50.8092699944973, 51.94768890738487, 52.40122117102146, 51.04632027447224, 55.17677843570709, 52.31523938477039, 55.11441998183727, 54.49105583131313, 62.251653000712395, 64.1411130130291, 67.22506552934647, 65.98590642213821, 71.06930404901505, 67.81503707170486, 70.86665332317352, 71.10934630036354, 74.32996988296509, 71.02196618914604, 75.32719597220421, 70.83223477005959, 74.24106225371361, 67.80367568135262, 78.1762146949768, 70.83031967282295, 82.82999217510223, 70.55762350559235, 86.70802608132362, 17.72518627345562, 0.3690730972448364, 0.12006281060166657, 2.0194479497149587, 0.28295059979427606, 23.042166866362095, 90.12851893901825, 67.34537467360497, 62.9096332937479, 34.48876194655895, 44.01985511183739, 23.721697703003883, 0.6128234567586333, 0.111352386593353, 0.28413156454917043, 0.043802168147522025, 0.07573334281914867, 0.03059045335248811, 0.057459381205262616, 0.018442475520714652, 0.024489259158144705, 0.16365001938538626, 0.14808712323429063, 0.13678940915269777, 0.16804914426757023, 0.20130374265136197, 0.145715783291962, 0.17251923331059515, 0.29840045201126486, 0.5219998396933079, 14.065932277590036, 79.18006762862206, 49.01401832699776, 48.32225404679775, 66.48593679070473, 86.22499600052834, 71.67696744203568, 1.4536790899001062, 3.4810414211824536, 0.29449441004544497, 0.2372554986504838, 0.9767273173201829, 69.70508605241776, 99.20096531510353, 94.18448969721794, 88.03508207201958, 82.27220490574837, 78.9206251502037, 86.94114357233047, 88.5262057185173, 92.2421783208847, 90.53323522210121, 89.40185353159904, 89.41963657736778, 88.4682284295559, 85.45829594135284, 80.59266462922096, 79.69226494431496, 71.20155215263367, 62.977045476436615, 65.99161371588707, 62.1191693097353, 61.048728749156, 62.17164069414139, 61.223454773426056, 58.925775066018105, 61.94577321410179, 56.286083310842514, 52.80113451182842, 53.01886662840843, 56.07089705765247, 58.03657338023186, 60.556347370147705, 56.243867576122284, 55.15983134508133, 60.875112265348434, 71.81702792644501, 68.43444183468819, 74.85638603568077, 69.46642845869064, 67.65330255031586, 67.34057173132896, 69.84727442264557, 54.67989429831505, 61.685475781559944, 69.39974203705788, 69.59396481513977, 67.44840994477272, 63.77004012465477, 56.75073757767677, 60.03653526306152, 61.767395585775375, 63.58199581503868, 64.92509454488754, 68.08881998062134, 65.37377446889877, 63.12160111963749, 52.27218009531498, 55.92245042324066, 56.572614535689354, 62.3816592246294, 64.20177295804024, 63.53701762855053, 65.01122072339058, 62.32561603188515, 61.29254646599293, 56.96673318743706, 57.69851312041283, 60.25824196636677, 61.919364631175995, 63.8273486495018, 58.59439104795456, 54.29768040776253, 52.76781029999256, 61.12639658153057, 63.74727934598923, 62.71447956562042, 62.947410866618156, 64.63817194104195, 64.02271896600723, 53.50147493183613, 48.51336859166622, 58.85567642748356, 62.98872984945774, 60.7706368714571, 57.91491910815239, 60.57313486933708, 52.7868776768446, 55.472170785069466, 54.88299340009689, 57.34069012105465, 56.70735910534859, 58.24517458677292, 61.876119151711464, 59.468097165226936, 58.38599123060703, 54.76652204990387, 49.92437347769737, 65.90722784399986, 60.56400015950203, 63.82627710700035, 62.60693393647671, 58.547387570142746, 52.95310355722904, 51.88232861459255, 50.80374129116535, 49.80296239256859, 52.0450396835804, 50.19567511975765, 55.615582689642906, 56.059759855270386, 55.12254394590855, 54.354779943823814, 57.509317472577095, 55.76612301170826, 58.04094314575195, 58.56057286262512, 64.47320759296417, 67.47245505452156, 69.4654481112957, 68.32933187484741, 74.10920172929764, 71.61111697554588, 75.1682960987091, 74.77527558803558, 77.65965521335602, 74.98601987957954, 77.81609281897545, 72.93799817562103, 76.74987763166428, 68.56636315584183, 83.70678752660751, 75.13487309217453, 87.52718612551689, 74.59955021739006, 90.49193143844604, 19.373262338340282, 0.5487730249296874, 0.567531252745539, 3.1429236894473433, 0.4193985468009487, 26.089225262403488, 102.39122092723846, 69.10895124077797, 80.76703727245331, 50.717356726527214, 54.731351137161255, 30.69532100111246, 0.8180496725253761, 0.290939878905192, 0.355088600772433, 0.29381828382611275, 0.19436804606812075, 0.1687224948545918, 0.25356172991450876, 0.21464527206262574, 0.19466379191726446], [0.09263568936148658, 0.08447093685390428, 0.1441506383707747, 0.020754432516696397, 0.06059338920749724, 0.044925197144038975, 0.23273978236829862, 0.08011831494513899, 0.6727963511366397, 18.365193530917168, 54.13555830717087, 32.770003974437714, 51.81938499212265, 42.61643461883068, 75.15083223581314, 61.4200372248888, 0.3069301036885008, 1.4065745612606406, 0.07784757312037982, 0.19897985563147813, 0.95991903799586, 64.64590832591057, 90.22878795862198, 82.75686129927635, 80.59371337294579, 67.55024448037148, 70.5196863412857, 74.27860423922539, 77.07719966769218, 73.85789841413498, 80.06912872195244, 81.78279876708984, 78.73610705137253, 81.41876310110092, 79.51377332210541, 76.08732238411903, 74.06763195991516, 72.01138749718666, 61.093068569898605, 58.31269696354866, 56.937961131334305, 58.42484034597874, 54.89572271704674, 56.73079624772072, 56.08730457723141, 56.12103916704655, 49.55966144800186, 46.6923239082098, 47.81443029642105, 50.10943114757538, 53.616319969296455, 54.799352288246155, 50.05809970200062, 50.3553881496191, 56.17237441241741, 66.29187360405922, 65.30798479914665, 64.48528334498405, 59.74433854222298, 62.188317999243736, 61.375294625759125, 57.715995982289314, 61.93028524518013, 46.883495450019836, 42.24421799182892, 64.22982305288315, 60.63877634704113, 56.848643124103546, 53.811834678053856, 52.026120498776436, 53.52121487259865, 55.73260121047497, 59.64216962456703, 61.8884114921093, 57.620940282940865, 57.45537556707859, 49.71697300672531, 49.11139950156212, 54.16286364197731, 58.729454800486565, 56.1047076433897, 59.298333674669266, 56.23697094619274, 56.56256407499313, 57.354965955019, 60.37264242768288, 56.98124460875988, 60.978280529379845, 58.98660220205784, 58.056165128946304, 56.48702792823315, 56.295989379286766, 47.16436117887497, 57.991766184568405, 55.34971855580807, 57.72285461425781, 59.035513177514076, 58.30854758620262, 57.63873852789402, 46.64836026728153, 43.890624046325684, 49.99509908258915, 55.3000932186842, 53.20699453353882, 53.588741049170494, 51.24006807804108, 46.47705405950546, 49.53647129237652, 50.12099772691727, 51.99154615402222, 53.22032041847706, 58.170311003923416, 55.776606649160385, 51.3994163274765, 47.85632684826851, 50.89757725596428, 57.65134625136852, 59.9372123926878, 61.06844589114189, 55.87184473872185, 59.0381920337677, 59.45738174021244, 50.72670802474022, 46.083790361881256, 46.29386208951473, 45.31856842339039, 45.10144427418709, 42.44415186345577, 43.50186690688133, 50.12333460152149, 50.560200959444046, 48.98202404379845, 50.38673646748066, 50.36340951919556, 51.77355945110321, 51.8503001332283, 56.56060717999935, 60.32315008342266, 65.08679866790771, 65.12079924345016, 68.01334083080292, 67.11611017584801, 70.50980687141418, 70.65660059452057, 71.34670436382294, 70.48396825790405, 73.85183393955231, 71.8656425178051, 76.42637059092522, 74.30388808250427, 77.04172477126122, 72.93083935976028, 80.8333133161068, 68.93919914960861, 79.87543031573296, 30.70057611912489, 0.42089044174645096, 0.24916141759604216, 1.2448104727081954, 0.21923980442807078, 17.199598476290703, 81.17757484316826, 64.60403457283974, 50.07734566926956, 33.238423839211464, 23.081756941974163, 18.865307494997978, 0.6555559043772519, 0.05527894390979782, 0.0972423113125842, 0.05198797909542918, 0.12106837617466226, 0.06937196463695727, 0.024651837738929316, 0.04336949234129861, 0.058114081621170044, 0.03864334008540027, 0.04023842695460189, 0.0865960841474589, 0.05038787901867181, 0.05036131384258624, 0.08673105112393387, 0.16973671386949718, 0.08387004214455374, 0.48721796076279134, 24.916302300989628, 66.44220873713493, 41.390194818377495, 51.51400677859783, 47.12925486266613, 85.12676373124123, 66.26337513327599, 0.7928973971866071, 2.079083137214184, 0.0588222240912728, 0.2558599237818271, 0.8761675539426506, 67.40142926573753, 91.95774838328362, 87.78022974729538, 82.54306957125664, 74.00607526302338, 74.22593906521797, 76.59475475549698, 80.44603809714317, 76.35521560907364, 81.01966291666031, 84.13006201386452, 82.84077599644661, 81.43398508429527, 81.20029002428055, 79.96202006936073, 78.27591374516487, 76.28133997321129, 64.22657042741776, 60.53585506975651, 59.17931646108627, 61.112637519836426, 57.05970659852028, 59.73641596734524, 58.68951514363289, 57.32326805591583, 50.86339429020882, 50.05827449262142, 49.93711419403553, 54.979945197701454, 56.666051521897316, 56.814786940813065, 52.57820047438145, 51.98035195469856, 58.51096652448177, 69.20387014746666, 66.90476551651955, 66.57992094755173, 62.95936122536659, 65.79473868012428, 65.60776591300964, 64.53000694513321, 63.81768196821213, 52.41695612668991, 46.35271713137627, 64.77436423301697, 63.115422651171684, 60.18525928258896, 57.4950036406517, 55.660739466547966, 58.49384844303131, 59.60138261318207, 62.60305434465408, 65.77960789203644, 60.513402074575424, 59.973534643650055, 53.01852844655514, 52.88749247789383, 58.02505999803543, 62.07610622048378, 59.83155906200409, 59.70650017261505, 59.819669499993324, 59.44950096309185, 62.23246783018112, 60.22752441465855, 59.274828135967255, 61.667407751083374, 62.0515975356102, 62.145733684301376, 60.21854929625988, 57.41408698260784, 48.97501341998577, 58.670801147818565, 57.302775755524635, 59.48826268315315, 61.96478359401226, 60.02551965415478, 59.354707449674606, 48.826365396380424, 46.84778116643429, 53.307244554162025, 58.502401784062386, 56.8746717274189, 54.659269005060196, 55.07747836410999, 50.39724290370941, 52.57667675614357, 52.33043096959591, 53.17320674657822, 56.824571415781975, 60.52219480276108, 57.84301556646824, 54.51704643666744, 51.953848376870155, 54.683492705225945, 60.51025964319706, 59.52925868332386, 62.8209612518549, 59.705166444182396, 61.638905480504036, 61.591218039393425, 53.4289064258337, 48.50771449506283, 48.38032253086567, 47.60751619935036, 47.93325372040272, 46.24565787613392, 46.33168525993824, 51.457097232341766, 52.804162949323654, 51.411279290914536, 51.32510371506214, 52.11600847542286, 54.93855781853199, 54.23864297568798, 57.656510174274445, 61.73201188445091, 68.2555702328682, 66.87833413481712, 69.62332963943481, 68.37578058242798, 74.13906812667847, 71.61811619997025, 74.57944169640541, 74.13497194647789, 78.65004166960716, 73.58784690499306, 78.21103602647781, 76.810013204813, 79.29198682308197, 74.44565087556839, 83.96266579627991, 71.1487577855587, 84.53347116708755, 36.54208056628704, 0.2669514692388475, 0.12270144987269305, 2.0093687530606985, 0.22899713163496926, 18.39940119534731, 90.08063390851021, 68.46598774194717, 62.650878578424454, 34.3539983779192, 38.91086965799332, 33.62338498234749, 0.3859749168623239, 0.062410396785708144, 0.04663041501771659, 0.05857353411556687, 0.04335925441409927, 0.04176457201538142, 0.02419321273919195, 0.06280383153352886, 0.06353196746204048, 0.17353444680338725, 0.1974039792548865, 0.1899957424029708, 0.10416830060421489, 0.12710169539786875, 0.3305391571484506, 0.24570438981754705, 0.21207503654295579, 0.7643678749445826, 29.810261093080044, 80.9850923717022, 43.38937394320965, 73.65351498126984, 57.75298319756985, 92.47012808918953, 72.38147243857384, 1.5401612618006766, 3.4072059206664562, 0.22301338787656277, 0.7341890630777925, 1.2993475212715566, 71.37174502015114, 97.37349897623062, 95.31717851758003, 89.1692528128624, 81.18003711104393, 77.96229377388954, 83.9008355140686, 86.00440263748169, 83.23441967368126, 86.81898012757301, 89.00949418544769, 86.76139801740646, 87.43447110056877, 88.107650578022, 83.27811732888222, 81.37777850031853, 80.33892944455147, 66.49101331830025, 62.20800094306469, 62.72919997572899, 66.57843142747879, 59.00178238749504, 63.89429345726967, 61.43981136381626, 60.87767332792282, 54.791292920708656, 53.33065889775753, 52.452693209052086, 57.348042726516724, 59.652033895254135, 58.53718511760235, 54.385778680443764, 54.78504605591297, 59.75889936089516, 71.906209141016, 70.40753155946732, 71.7304077744484, 66.7272162437439, 70.22188872098923, 67.18407332897186, 65.73655620217323, 64.22510370612144, 53.17890264093876, 52.28730708360672, 69.59689825773239, 66.51245936751366, 62.917054295539856, 60.391189232468605, 57.35512174665928, 62.13659517467022, 62.96738639473915, 67.83097341656685, 66.76206797361374, 63.84966865181923, 66.00242793560028, 58.074856325984, 54.44263122975826, 59.67814229428768, 64.67120736837387, 61.21966637670994, 62.41877183318138, 61.565071642398834, 62.72048704326153, 64.6721801161766, 64.92849916219711, 61.02350950241089, 66.35412946343422, 67.0104530453682, 65.47287315130234, 62.08527892827988, 59.35697592794895, 50.069768875837326, 62.6764702051878, 60.35590812563896, 62.92425870895386, 63.884170800447464, 64.16288584470749, 62.86078691482544, 50.30465707182884, 52.21040301024914, 58.24809283018112, 62.11677543818951, 59.55600164830685, 59.47690889239311, 58.719123154878616, 54.13362041115761, 55.17440356314182, 56.099068745970726, 56.687676161527634, 59.53234411776066, 62.99895130097866, 60.15111431479454, 55.40003165602684, 57.15116769075394, 57.067644372582436, 62.496371269226074, 63.561100736260414, 65.32404273748398, 62.76829607784748, 63.788507133722305, 63.270218744874, 55.713948011398315, 53.10319550335407, 51.91094867885113, 49.442012161016464, 50.43951943516731, 48.8279765099287, 49.76305313408375, 55.47586418688297, 55.339041128754616, 54.515017345547676, 53.348894119262695, 54.21775929629803, 57.13583931326866, 57.490246295928955, 60.143210738897324, 64.6737988293171, 70.53002178668976, 71.21695652604103, 72.26469710469246, 72.26157367229462, 77.88366079330444, 77.15392515063286, 77.64940336346626, 75.71020781993866, 79.90152731537819, 77.60239988565445, 83.58627319335938, 80.94395577907562, 83.88301447033882, 78.25313776731491, 88.66980001330376, 74.2152464389801, 88.72045129537582, 39.28519897162914, 0.4354604333639145, 0.5079477780964226, 4.51218425296247, 0.35385541850700974, 21.163496375083923, 99.60333332419395, 72.62527495622635, 74.68648195266724, 47.828592136502266, 51.4791664481163, 43.739213570952415, 0.9312219684943557, 0.2338014097767882, 0.13950973661849275, 0.1512221628217958, 0.27344261936377734, 0.10346985058276914, 0.22521700244396925, 0.20458946790313348, 0.1567457156488672], [0.1233165938174352, 0.11488023010315374, 0.08728320899535902, 0.06427978514693677, 0.14338126871734858, 0.07461027300450951, 0.08136220640153624, 0.08788848979747854, 0.33854924608021975, 21.54813453555107, 59.88183416426182, 38.89205686748028, 48.607037365436554, 45.83249844610691, 80.51555916666985, 55.893879756331444, 0.3889674344100058, 0.3679946676129475, 0.17348294175462797, 0.02335671026230557, 1.0893492959439754, 64.58855420351028, 86.33013635873795, 79.05528992414474, 75.88281735777855, 68.18676352500916, 68.8989745080471, 68.9583957195282, 70.52020311355591, 71.1617074906826, 75.54557785391808, 78.83131474256516, 78.4109964966774, 77.12670341134071, 78.64662945270538, 77.57488936185837, 74.05242517590523, 72.56162077188492, 72.38404110074043, 59.95285615324974, 57.59373754262924, 58.09258617460728, 55.9893724322319, 54.89764541387558, 54.84574019908905, 53.02640922367573, 44.08845283091068, 47.85131111741066, 50.49825668334961, 50.80518141388893, 53.78747038543224, 53.20593819022179, 51.65040045976639, 51.238814145326614, 57.61147879064083, 66.4558120071888, 64.112219363451, 61.61688186228275, 65.07810473442078, 67.54695385694504, 65.37758946418762, 66.88445940613747, 60.71343474090099, 66.03307709097862, 53.43790054321289, 54.463264122605324, 61.56476005911827, 58.38238522410393, 55.55977128446102, 54.70536433160305, 56.18673764169216, 58.711173981428146, 55.88688813149929, 60.136758685112, 59.11029316484928, 55.31779266893864, 48.52939233183861, 48.25219340622425, 54.859506860375404, 53.705432787537575, 58.10621604323387, 58.77741202712059, 57.923404052853584, 57.831479385495186, 60.78635282814503, 54.140650033950806, 54.86843638122082, 61.37747570872307, 58.46403904259205, 58.498267605900764, 59.93621684610844, 51.764610931277275, 51.89001180231571, 58.054466620087624, 57.41475194692612, 55.43149396777153, 57.919828444719315, 58.64978067576885, 50.30485466122627, 44.57644924521446, 46.531569734215736, 50.7092859596014, 54.94875647127628, 58.77463057637215, 53.22133496403694, 52.609282806515694, 50.149123817682266, 51.497192680835724, 50.085264444351196, 52.9057352989912, 50.15896528959274, 55.85056208074093, 60.65000854432583, 60.27828589081764, 58.81658032536507, 58.749589920043945, 57.30192080140114, 57.05969899892807, 59.8104739934206, 56.18448056280613, 57.235184982419014, 59.349946305155754, 52.297323346138, 45.64476951956749, 47.64135718345642, 46.29192039370537, 44.90282513201237, 45.61526410281658, 42.65028700232506, 47.1492075920105, 49.48273077607155, 51.73555389046669, 50.490364506840706, 52.644742503762245, 52.14300222694874, 50.83198517560959, 52.744179368019104, 56.33836850523949, 64.17264372110367, 63.71778912842274, 67.01696589589119, 67.79403939843178, 70.997404307127, 72.3190113902092, 72.49513193964958, 69.73585680127144, 74.01466280221939, 68.47094267606735, 70.73169216513634, 71.47303998470306, 76.71531468629837, 73.55573862791061, 79.9691940844059, 76.30649462342262, 77.11548641324043, 41.63710176944733, 0.7169471320230514, 0.1271137033472769, 1.6070114308968186, 0.4786943946965039, 13.11211695894599, 76.5775340795517, 68.0255837738514, 52.78016723692417, 41.85311257839203, 21.61209650337696, 26.70613545924425, 0.19564151210943237, 0.11272395713604055, 0.03759070379601326, 0.028262477098905947, 0.07742014058749191, 0.018196900709881447, 0.05736054568842519, 0.04468148326850496, 0.07256414217408746, 0.07823698542779312, 0.03745706897461787, 0.0741644723166246, 0.0903841840045061, 0.1772918811184354, 0.05832957162056118, 0.20078490721061826, 0.07257301083882339, 0.24489629489835352, 33.81135709583759, 69.04716655611992, 43.15050736069679, 49.25240993499756, 55.13899706304073, 87.19355642795563, 62.48903766274452, 0.34961330238729715, 0.37512857699766755, 0.0615797294449294, 0.09473325844737701, 1.5443634800612926, 71.76473513245583, 89.95652496814728, 86.6485820710659, 77.43337735533714, 74.43960160017014, 73.95594835281372, 74.37435910105705, 72.2820545732975, 74.64599132537842, 78.97265955805779, 83.66906315088272, 81.74398005008698, 82.93833956122398, 79.43439558148384, 80.17325833439827, 77.49967619776726, 77.13763922452927, 74.62812468409538, 62.7780881524086, 59.73948620259762, 60.67613214254379, 57.03703321516514, 56.373208835721016, 57.24849186837673, 56.98044665157795, 48.6872548609972, 50.892496928572655, 52.79180981218815, 54.32914651930332, 56.16504080593586, 55.75942777097225, 53.08471329510212, 53.91404539346695, 58.765093088150024, 68.52570533752441, 64.929950684309, 68.01176771521568, 68.17692205309868, 67.78406113386154, 67.79050558805466, 66.90384596586227, 64.2538757622242, 68.84866520762444, 58.76968704164028, 58.99019680917263, 64.8309887945652, 62.1979770809412, 57.79772959649563, 56.460752338171005, 58.54551427066326, 61.89404658973217, 61.24642454087734, 61.23059079051018, 60.36445006728172, 59.278764724731445, 50.51746465265751, 49.05839994549751, 59.26757052540779, 56.816151067614555, 61.33040003478527, 61.75509184598923, 61.78681254386902, 60.98698206245899, 60.80309472978115, 55.071417689323425, 55.012144669890404, 63.72347742319107, 61.07447236776352, 61.81026108562946, 60.826604068279266, 51.451032757759094, 50.58184839785099, 58.38766694068909, 60.005528926849365, 59.59682285785675, 59.27496872842312, 58.519877046346664, 51.74612872302532, 47.926349490880966, 51.0471448302269, 55.82505024969578, 59.261707440018654, 59.11989524960518, 55.38753032684326, 54.91209223866463, 51.877324283123016, 53.75055156648159, 52.31688469648361, 54.56313416361809, 52.14038796722889, 59.36668060719967, 63.65388035774231, 63.125712499022484, 60.417514219880104, 59.75943513214588, 59.03607174754143, 59.054257571697235, 62.05284006893635, 60.6313743442297, 59.262995570898056, 62.188564985990524, 54.51781399548054, 49.83549244701862, 48.39392960071564, 47.60321483016014, 48.11330705881119, 46.815099120140076, 45.045461878180504, 49.00112941861153, 51.29452295601368, 55.040616542100906, 52.659063935279846, 54.17564235627651, 55.86826153099537, 52.77014717459679, 55.353738740086555, 58.979971557855606, 67.34786733984947, 65.10044753551483, 70.92506378889084, 68.52189034223557, 72.79624298214912, 72.60084226727486, 74.59043830633163, 71.9017481803894, 75.60240760445595, 71.35916009545326, 76.53756022453308, 72.13347494602203, 78.2010805606842, 75.80828815698624, 84.73775580525398, 79.15468499064445, 83.1537576019764, 46.94957010447979, 0.5305826291441917, 0.15521675784839317, 2.516125710681081, 0.5584374500904232, 15.088031832128763, 85.3502145409584, 71.80651009082794, 63.25369343161583, 42.39869490265846, 36.43732398748398, 41.09131805598736, 1.10046346206218, 0.07367903352132998, 0.0902863169903867, 0.07330594846280292, 0.005793950158476946, 0.04712598783953581, 0.05185200279811397, 0.03929779188183602, 0.15252718498231843, 0.2136066957609728, 0.305824659881182, 0.18224069994175807, 0.2891330164857209, 0.2605330792721361, 0.36689109401777387, 0.2300003223353997, 0.3804317564936355, 0.4814384412020445, 42.49829135835171, 83.60458821058273, 52.092525735497475, 66.63388565182686, 64.88127529621124, 96.53152495622635, 69.20127108693123, 1.1493717064149678, 1.4192595868371427, 0.3764522122219205, 0.23765723803080618, 1.6853688075207174, 75.77817857265472, 96.73435047268867, 95.23987546563148, 83.96605521440506, 82.72335469722748, 79.80289980769157, 79.27995666861534, 77.86435022950172, 81.99523776769638, 83.77609580755234, 88.33320647478104, 84.19542610645294, 88.21431085467339, 81.72358274459839, 84.97664138674736, 80.68725675344467, 79.27589848637581, 78.35283681750298, 65.8801580965519, 62.523684203624725, 65.45869991183281, 61.30737327039242, 60.765795931220055, 59.75300967693329, 57.99194097518921, 52.15589873492718, 55.02718806266785, 56.736967116594315, 56.627342998981476, 58.55374462902546, 57.70520456135273, 55.606603771448135, 58.27453941106796, 63.22643369436264, 70.80673053860664, 68.36136415600777, 70.04617094993591, 72.48267620801926, 69.8331543803215, 70.21623462438583, 70.31103193759918, 66.27565607428551, 73.18177789449692, 56.50543414056301, 65.45081153512001, 66.82474181056023, 65.10177746415138, 61.352940425276756, 59.5915487408638, 61.154792457818985, 65.98594442009926, 64.22450333833694, 65.77504813671112, 63.685278072953224, 62.02153354883194, 52.89187744259834, 51.85299038887024, 61.82806313037872, 58.96805539727211, 62.35058829188347, 67.6162089407444, 64.45109277963638, 63.05083751678467, 65.04791155457497, 59.2819831520319, 56.625602692365646, 66.10341131687164, 63.74703235924244, 63.935924023389816, 65.03526583313942, 53.65984283387661, 53.07573817670345, 62.87742622196674, 62.67147347331047, 61.91975601017475, 61.500011533498764, 62.527662590146065, 52.626674473285675, 50.31891390681267, 54.82079453766346, 59.058992117643356, 60.67014366388321, 64.47179406881332, 59.046718776226044, 58.123231530189514, 54.66406434774399, 58.50789248943329, 54.96156558394432, 57.41141192615032, 55.43723925948143, 61.08438603579998, 66.55972883105278, 66.23584181070328, 61.82629242539406, 62.424315735697746, 62.12557956576347, 60.331547632813454, 66.53040200471878, 64.31582003831863, 63.94383519887924, 65.71401581168175, 55.92815391719341, 52.264964282512665, 51.40076905488968, 52.07530505955219, 50.550819262862206, 52.22663573920727, 47.817169949412346, 52.50444643199444, 54.39171776175499, 57.58842542767525, 54.73426938056946, 57.639213502407074, 59.156517684459686, 55.43808661401272, 58.62998753786087, 61.29461355507374, 70.82121536135674, 68.25236320495605, 72.93029978871346, 72.36330181360245, 76.14034473896027, 77.62718215584755, 78.39792519807816, 75.96781879663467, 79.93039056658745, 75.80487594008446, 80.9088684618473, 78.40127661824226, 83.956228941679, 80.16017183661461, 88.53903383016586, 82.81477779150009, 85.02956494688988, 52.300389781594276, 0.8829856349620968, 0.35255550232250243, 4.7391964215785265, 0.5197476886678487, 17.055020034313202, 94.52405467629433, 74.51836377382278, 73.16582635045052, 59.383175522089005, 51.19931526482105, 52.05968029797077, 1.9757019658572972, 0.16882488154806197, 0.137809639563784, 0.20129513373831287, 0.20699003362096846, 0.11901562538696453, 0.14655858103651553, 0.1739083111169748, 0.2710534678772092], [0.05663796102453489, 0.025190258456859738, 0.06073261240089778, 0.04413686190673616, 0.05031095912272576, 0.03180415238603018, 0.03476467223663349, 0.04532501807261724, 0.0901647457794752, 38.42854633927345, 49.20143947005272, 45.85125043988228, 42.91733667254448, 51.3694017380476, 83.3489303290844, 63.33740293979645, 0.353144797263667, 0.175066209922079, 0.49005548818968236, 0.06349117902573198, 8.66818891838193, 66.86363652348518, 80.17854765057564, 76.63320869207382, 70.0031952559948, 68.60611662268639, 71.027422696352, 72.08549112081528, 69.06555756926537, 64.9597030878067, 68.07677462697029, 70.9420944750309, 73.80231499671936, 73.23790848255157, 75.61328262090683, 76.92513942718506, 76.80239841341972, 74.89930093288422, 74.3505647778511, 68.17560732364655, 56.26758970320225, 54.207245260477066, 54.94964562356472, 53.571565970778465, 55.85817687213421, 50.25527872145176, 44.806842282414436, 48.06835547089577, 48.576468005776405, 53.00507336854935, 53.99665676057339, 51.84999234974384, 52.95430429279804, 52.69297331571579, 58.78294073045254, 67.87021771073341, 64.68226477503777, 61.57703340053558, 64.8862986266613, 62.9682831466198, 62.897922322154045, 64.11515280604362, 63.00983391702175, 61.646501272916794, 60.7582039386034, 62.60448306798935, 60.673168301582336, 60.05051851272583, 58.90660509467125, 53.75042237341404, 58.33746403455734, 58.16349036991596, 56.21388338506222, 58.380994498729706, 58.43812823295593, 60.01453444361687, 54.1456201672554, 51.580913588404655, 56.60167157649994, 53.76956954598427, 59.290460497140884, 59.23900365829468, 57.44373299181461, 59.74102132022381, 61.27518519759178, 56.61190822720528, 50.93516483902931, 54.79285083711147, 58.471213057637215, 58.45288664102554, 53.2211297750473, 45.650408416986465, 41.14875577390194, 53.04051786661148, 58.404386043548584, 56.987833455204964, 56.39856867492199, 56.90359577536583, 51.04374021291733, 41.187194511294365, 47.08115704357624, 50.657836720347404, 54.66757155954838, 56.0120914131403, 53.55333834886551, 56.51875622570515, 52.71239407360554, 52.35866345465183, 51.44041232764721, 51.76863491535187, 51.594015285372734, 55.89101850986481, 57.485899329185486, 58.937858417630196, 57.17007167637348, 55.67948766052723, 57.91402615606785, 59.631932973861694, 58.94441306591034, 57.844778671860695, 54.89973530173302, 58.914577066898346, 55.27874976396561, 48.10549847781658, 45.091580003499985, 46.9344887137413, 45.26210345327854, 46.09820298850536, 43.075579181313515, 43.38276989758015, 47.71872863173485, 50.535631477832794, 50.608477368950844, 48.481275513768196, 49.54932980239391, 52.74036817252636, 51.93650610744953, 52.24881894886494, 62.183917835354805, 67.14235916733742, 65.9018625319004, 66.27941027283669, 67.44178310036659, 67.89795622229576, 67.13636308908463, 65.42168229818344, 68.18641394376755, 67.58693531155586, 70.64540639519691, 72.18253031373024, 74.25110131502151, 72.42675840854645, 77.62065410614014, 72.68745481967926, 79.3796557188034, 42.266860976815224, 0.6239435006864369, 0.15904460713500157, 1.0426595387980342, 0.3892688947962597, 17.43102315813303, 79.26197603344917, 67.14799046516418, 57.05590300261974, 43.796058520674706, 24.227422066032887, 29.009767547249794, 0.7946781360078603, 0.027057372135459445, 0.03419802393182181, 0.05606976163107902, 0.008760412292758701, 0.07557361779618077, 0.04945514410792384, 0.0867557869059965, 0.017203062925545964, 0.06588665361050516, 0.045811584932380356, 0.08474365386064164, 0.11299069985398091, 0.06868282856885344, 0.0679529485933017, 0.05363176569517236, 0.0620595056534512, 0.06738510171999224, 51.549322083592415, 54.65311333537102, 45.26531808078289, 41.117263063788414, 60.99981777369976, 88.94434288144112, 70.50761818885803, 0.15449605823960155, 0.46430332004092634, 0.5824799474794418, 0.10627424853737466, 10.794863551855087, 74.8762209713459, 89.51074808835983, 85.47824487090111, 76.48273676633835, 74.76813197135925, 77.13862717151642, 77.44358360767365, 73.28050419688225, 69.971474558115, 72.10046231746674, 75.34355029463768, 75.05360305309296, 78.73547628521919, 78.88265758752823, 79.61387515068054, 79.64395433664322, 77.58866742253304, 79.694012850523, 71.9263556599617, 60.13882577419281, 56.4423993229866, 58.81167858839035, 56.43503911793232, 57.9924463480711, 52.88088083267212, 48.08225132524967, 50.33801168203354, 51.15897282958031, 55.914805233478546, 56.74435392022133, 54.13134813308716, 56.92605637013912, 54.6433212608099, 60.29622472822666, 69.60175439715385, 67.71806627511978, 65.40656670928001, 69.12747144699097, 64.96631473302841, 65.82627698779106, 64.59320515394211, 64.99403804540634, 64.75181624293327, 63.7908174097538, 67.1264000236988, 63.885432332754135, 63.43818873167038, 61.10025778412819, 57.86809802055359, 60.44472835958004, 60.2395735681057, 60.06115414202213, 61.88833549618721, 60.899757742881775, 63.08133848011494, 54.08815585076809, 52.936426252126694, 57.447532787919044, 56.93233363330364, 59.80075791478157, 62.39897109568119, 60.32861039042473, 61.291592717170715, 61.502447202801704, 61.7819944024086, 51.9778136909008, 57.97110289335251, 59.885261580348015, 57.59265460073948, 54.29025940597057, 47.26837299764156, 41.07126273214817, 53.50627787411213, 61.57863691449165, 58.88420529663563, 58.399472907185555, 59.000258669257164, 55.580620765686035, 41.930552423000336, 46.88566133379936, 54.25533927977085, 58.56896661221981, 58.12345191836357, 57.364997416734695, 60.643985867500305, 54.99815762042999, 54.2251119017601, 55.14064997434616, 54.234744384884834, 54.26580011844635, 57.74587757885456, 59.36271741986275, 59.27808076143265, 61.18543021380901, 56.01528324186802, 60.19555673003197, 58.674274161458015, 60.32070681452751, 59.61066551506519, 58.30537095665932, 61.0988100618124, 58.034787476062775, 49.78034220635891, 46.89207158982754, 48.440739288926125, 46.5960218757391, 48.6412051320076, 46.42506144940853, 46.997793316841125, 51.24744348227978, 50.91769337654114, 52.16136284172535, 51.88847288489342, 52.22456485033035, 54.16009359061718, 56.17703676223755, 55.34852162003517, 63.423650711774826, 69.21627268195152, 70.1579837501049, 69.01236042380333, 71.06127887964249, 68.42608228325844, 70.5002997815609, 69.40994828939438, 71.96109339594841, 71.5723742544651, 75.73376655578613, 74.88246023654938, 78.21395426988602, 75.69658935070038, 80.47851115465164, 75.93435019254684, 83.64236578345299, 49.22465242445469, 0.4920033289818093, 0.1867103882250376, 1.0653495462611318, 0.3944794542621821, 19.8229606077075, 89.31478500366211, 71.10423937439919, 68.25126126408577, 44.39438961446285, 38.44931222498417, 44.08786006271839, 1.840945640578866, 0.16137941856868565, 0.06722491656546481, 0.05247869084996637, 0.041932883686968125, 0.03862091980408877, 0.08078462255070917, 0.11233492332394235, 0.05310154570906889, 0.14659126522019506, 0.14476807555183768, 0.19696529576322064, 0.17090826819185168, 0.18889400933403522, 0.13012746116146445, 0.15853458840865642, 0.16757782112108544, 0.17938645934918895, 60.79313926398754, 65.46974211931229, 60.07432423532009, 59.13443706929684, 69.6949177980423, 97.45673730969429, 77.88192808628082, 0.809391955845058, 1.1021110299043357, 1.2074707075953484, 0.3053292614640668, 10.50234954804182, 84.42543536424637, 95.76112389564514, 97.88682863116264, 82.83949926495552, 81.8058331310749, 83.15330162644386, 84.50453951954842, 77.14010149240494, 74.94886547327042, 76.44739866256714, 78.8258658349514, 77.92434141039848, 82.25746169686317, 82.19088926911354, 82.11555451154709, 84.37659278512001, 81.84719011187553, 83.3047766983509, 73.47038000822067, 63.151326924562454, 59.84997287392616, 62.333743795752525, 58.98634761571884, 59.359217807650566, 53.219537660479546, 53.43805633485317, 53.61680634319782, 53.2647780328989, 60.49309976398945, 61.01256608963013, 54.96488660573959, 60.312126874923706, 56.88991650938988, 62.73171924054623, 72.99864292144775, 70.81781834363937, 68.15363690257072, 70.7305446267128, 68.5891543328762, 67.19595149159431, 68.26576128602028, 68.31341072916985, 68.55307146906853, 65.88296234607697, 68.30768063664436, 67.38926991820335, 66.6154870390892, 65.36167591810226, 61.661723256111145, 64.86630409955978, 64.06699419021606, 63.560500368475914, 64.48470577597618, 65.53522780537605, 66.95647314190865, 55.200979337096214, 53.576881885528564, 60.63768960535526, 58.09870384633541, 63.5341639816761, 64.16765078902245, 62.49521233141422, 64.41052615642548, 66.26891523599625, 62.42107450962067, 53.92679750919342, 59.27319422364235, 62.373326271772385, 60.24993561208248, 56.4910177141428, 47.99448363482952, 41.86379000544548, 58.48941408097744, 63.22111777961254, 62.93849274516106, 62.12255112826824, 61.77483178675175, 57.187353149056435, 43.5986515134573, 47.987438812851906, 57.818187698721886, 60.37590265274048, 61.63616582751274, 59.62983928620815, 61.48792438209057, 57.88916029036045, 56.9033145904541, 56.72832638025284, 58.41073930263519, 58.41929644346237, 61.79225005209446, 61.81591898202896, 61.98043875396252, 62.4037816375494, 58.34730550646782, 63.97430196404457, 62.87266507744789, 62.58487232029438, 62.47176378965378, 60.69023698568344, 65.7910680770874, 61.296574249863625, 52.14707560837269, 49.53044481575489, 51.71045623719692, 49.459343031048775, 51.2610125541687, 47.872084602713585, 50.2975894510746, 53.16748805344105, 53.299990743398666, 55.340823233127594, 53.72444696724415, 55.011939480900764, 57.30855904519558, 56.2557989358902, 57.29898355901241, 66.31589591503143, 73.35170477628708, 73.22529315948486, 73.64332392811775, 74.78723734617233, 72.9413951933384, 74.7518840432167, 74.25407275557518, 76.89255237579346, 75.45683741569519, 79.94647890329361, 77.40588963031769, 80.52121326327324, 80.50137832760811, 84.98906672000885, 80.34142211079597, 86.77226543426514, 55.20882971584797, 0.7060896302573383, 0.27256554923951626, 3.080065087415278, 0.44026818475686014, 22.68957808613777, 98.56118604540825, 74.0644933283329, 78.93358245491982, 58.28148543834686, 47.34756454825401, 59.665899351239204, 3.4981944132596254, 0.3675585222663358, 0.189229445240926, 0.16189138172194362, 0.14081406116019934, 0.19049274385906756, 0.16568432038184255, 0.3012149134883657, 0.1477519396576099], [0.008451213161606574, 0.09300334932049736, 0.08441520898486488, 0.09596379866707139, 0.08987794280983508, 0.08152213922585361, 0.07564409213955514, 0.017148589286080096, 0.6219856557436287, 54.94521506130695, 39.786867052316666, 27.361951768398285, 40.718010887503624, 51.28989860415459, 78.97514462471008, 58.39531593024731, 0.3224121651146561, 0.1855296758003533, 0.25878493557684124, 0.08282645634608343, 25.74178710579872, 67.68727272748947, 67.94315099716187, 69.69690889120102, 68.05624812841415, 74.64235872030258, 76.9230343401432, 76.08298301696777, 76.63875639438629, 68.89704421162605, 62.24037140607834, 68.85226741433144, 67.71218419075012, 69.18537274003029, 72.55198448896408, 73.88467937707901, 73.42411369085312, 73.1316813826561, 72.87008821964264, 70.62113329768181, 57.41968408226967, 53.31178531050682, 54.693201184272766, 52.31574855744839, 56.09066739678383, 50.18213264644146, 43.99865224957466, 47.96000808477402, 52.16842286288738, 52.388765439391136, 55.15427224338055, 52.72755146026611, 52.89926424622536, 51.669049859046936, 58.62784065306187, 66.45114585757256, 61.50245100259781, 62.77616165578365, 66.80366054177284, 64.76147532463074, 60.85615888237953, 62.063152715563774, 57.16439478099346, 61.49879179894924, 59.75435860455036, 62.232642620801926, 61.757542714476585, 60.47888472676277, 56.66121058166027, 54.28015574812889, 53.28579090535641, 57.254924923181534, 56.99113167822361, 60.676314532756805, 60.13651169836521, 60.68798750638962, 55.30272647738457, 48.631614446640015, 52.83208005130291, 54.65302973985672, 59.3429546803236, 60.38551613688469, 59.91072401404381, 59.50000025331974, 61.14617072045803, 49.44819062948227, 44.87493462860584, 55.47445826232433, 58.2160909473896, 55.44420048594475, 52.565018981695175, 47.24545642733574, 38.166550397872925, 39.01366174221039, 55.250304490327835, 56.51233837008476, 54.08939078450203, 60.480138659477234, 53.953814059495926, 45.13283059000969, 42.93944388628006, 51.07619807124138, 53.131606578826904, 56.388153433799744, 56.953464299440384, 57.64467000961304, 58.29768396914005, 55.53919158875942, 52.56160296499729, 52.09392786026001, 48.746375888586044, 54.598932042717934, 59.99667540192604, 56.48692533373833, 59.9505914747715, 61.11343927681446, 55.204813331365585, 58.708384931087494, 59.33525629341602, 58.54810953140259, 56.056689620018005, 57.464502677321434, 56.440309435129166, 49.94825899600983, 46.60248912870884, 47.55225196480751, 45.157008692622185, 46.063586845993996, 44.74291071295738, 42.608892023563385, 47.17719689011574, 49.63260993361473, 49.503325670957565, 49.88431602716446, 50.90221680700779, 52.815440744161606, 51.50873266160488, 52.970909401774406, 53.542014956474304, 57.530550733208656, 58.74773561954498, 58.868664130568504, 59.50029283761978, 57.18231461942196, 59.115620478987694, 60.01861922442913, 61.83082938194275, 64.89325225353241, 68.53337332606316, 71.79783895611763, 72.86007195711136, 73.13840702176094, 76.37379661202431, 76.12298727035522, 75.04538029432297, 48.67940068244934, 0.9219180489890277, 0.4211035865591839, 0.991543197305873, 0.26473390229512006, 19.906977899372578, 78.62928718328476, 68.28101366758347, 59.890311509370804, 37.21916623413563, 26.773940920829773, 31.288889050483704, 1.8477111775428057, 0.021648436595569365, 0.07942099298816174, 0.04167679449892603, 0.02329500624909997, 0.07569902591058053, 0.03928318270482123, 0.06898247069329955, 0.11731963240890764, 0.026522728949203156, 0.048440127284266055, 0.07024324600934051, 0.05717236301279627, 0.021896004072914366, 0.07710488367592916, 0.04447155195521191, 0.033496393807581626, 0.8396453387103975, 67.22125813364983, 48.54402534663677, 29.006155841052532, 41.451740115880966, 62.15373605489731, 87.41008400917053, 65.11046379804611, 0.2670794748701155, 0.4802498471690342, 0.8459182677324861, 0.14945482718758285, 28.179846480488777, 77.90465846657753, 78.42006281018257, 78.5066069662571, 75.97648233175278, 82.1994236111641, 83.49063232541084, 83.71167406439781, 79.96677741408348, 72.81576633453369, 65.08597791194916, 73.79535377025604, 69.97544154524803, 71.78294375538826, 75.16418471932411, 76.73039227724075, 75.7619458436966, 74.81707334518433, 75.32447531819344, 73.51935178041458, 61.13968066871166, 56.102917939424515, 56.96039892733097, 55.520595386624336, 58.408915400505066, 51.92393258213997, 48.4130197763443, 51.01342163980007, 54.1295850276947, 54.78082448244095, 56.923829689621925, 54.77672450244427, 56.89984917640686, 53.82625870406628, 60.76381243765354, 68.26164990663528, 63.87034714221954, 64.05865743756294, 68.42533752322197, 66.57235935330391, 63.033863827586174, 62.648032531142235, 59.55606624484062, 65.89949145913124, 63.60183075070381, 64.14826422929764, 62.20741577446461, 65.42865112423897, 58.898781314492226, 58.48426155745983, 56.86938241124153, 59.649427235126495, 61.84987396001816, 62.74300083518028, 62.000691667199135, 61.92325182259083, 55.55976368486881, 48.62841881811619, 53.61201860010624, 57.02125646173954, 61.144912987947464, 60.61909340322018, 63.09713423252106, 62.50131480395794, 63.183192014694214, 50.737484246492386, 45.39044536650181, 57.01073482632637, 60.3369927406311, 55.93792699277401, 53.282272294163704, 47.55551598966122, 39.406325072050095, 38.937168046832085, 55.64820393919945, 61.931618973612785, 57.688094079494476, 62.56495758891106, 57.63270065188408, 46.7755888402462, 43.217189982533455, 52.509253174066544, 58.42623107135296, 57.373041585087776, 59.02094095945358, 57.1274683624506, 62.2726658731699, 57.48270370066166, 54.16556529700756, 54.38504911959171, 51.48432657122612, 56.225062385201454, 61.272589936852455, 59.94780622422695, 62.03265555202961, 61.097115352749825, 58.92075553536415, 60.06606727838516, 61.2909771502018, 60.83728909492493, 59.37566712498665, 61.0741151869297, 58.58906753361225, 52.15302988886833, 48.528738766908646, 49.908494129776955, 49.124106019735336, 47.82687082886696, 47.0796637237072, 45.277549624443054, 48.99376541376114, 52.045963034033775, 52.58852832019329, 52.41803526878357, 52.89034992456436, 52.12502159178257, 55.70550486445427, 55.449068024754524, 56.57383807003498, 61.081657782197, 63.15444655716419, 62.65698105096817, 61.1367130279541, 61.410229951143265, 63.21484051644802, 63.43353398144245, 65.25917261838913, 68.20610448718071, 74.09616082906723, 74.38720241189003, 76.13736569881439, 76.14814952015877, 78.70056375861168, 79.29463148117065, 77.32705146074295, 54.59501825273037, 0.9865495527628809, 0.28749563090968877, 0.9858806105330586, 0.02784301708743442, 18.76346156001091, 86.50358945131302, 73.84578466415405, 70.7832781970501, 42.75641530752182, 37.65593759715557, 48.288546055555344, 4.419753737747669, 0.3509419842157513, 0.03600054478738457, 0.06938872975297272, 0.03660410380689427, 0.118470057786908, 0.05891583859920502, 0.06754325338988565, 0.17813456011936069, 0.12199735952890478, 0.1981402194360271, 0.2826839906629175, 0.23878217063611373, 0.15251713630277663, 0.12086070099030621, 0.16982571221888065, 0.1222666997637134, 1.06457628775388, 83.88009622693062, 52.46873214840889, 38.381831645965576, 59.37612310051918, 69.24474835395813, 94.91484090685844, 73.06551933288574, 0.4428792087128386, 1.0911773541010916, 1.2909725331701338, 0.25742045254446566, 32.19859443604946, 89.20392975211143, 88.63833010196686, 89.03151020407677, 83.8268306851387, 89.49551850557327, 89.65396240353584, 87.30203300714493, 84.13942471146584, 77.35077738761902, 69.71390917897224, 77.58739829063416, 74.66087132692337, 75.6734561920166, 77.45507419109344, 78.77573892474174, 79.05668824911118, 77.85542830824852, 79.42880988121033, 76.71939566731453, 64.5023064315319, 58.82368214428425, 59.307491183280945, 56.88420161604881, 60.313574597239494, 53.995661213994026, 51.00302539765835, 55.744809955358505, 58.23377899825573, 57.95530714094639, 60.193531438708305, 57.334177270531654, 58.05932275950909, 58.365567326545715, 63.94694343209267, 70.82783460617065, 67.33210578560829, 67.63022258877754, 68.98426473140717, 68.90451461076736, 65.63930422067642, 64.56208482384682, 62.58957266807556, 69.74775016307831, 65.42562648653984, 68.08017924427986, 63.58799189329147, 66.09244510531425, 62.07626961171627, 61.77697107195854, 60.5806090682745, 62.901900708675385, 64.43576440215111, 66.73701211810112, 65.35005614161491, 67.03083515167236, 59.36557486653328, 52.40876756608486, 55.21726906299591, 60.44022940099239, 64.23717185854912, 66.53286427259445, 64.80368345975876, 63.25056999921799, 65.28634876012802, 53.60912695527077, 46.285494938492775, 59.36952285468578, 62.982885763049126, 59.86008033156395, 53.475651517510414, 48.65006245672703, 39.24294903874397, 40.593894347548485, 59.92172062397003, 61.88926264643669, 58.72165001928806, 64.88692179322243, 58.884220495820045, 48.87497238814831, 43.77320654690266, 55.31963936984539, 58.626776710152626, 61.25253461301327, 62.26598583161831, 61.45597569644451, 66.6864064335823, 60.50980366766453, 56.306982189416885, 57.92853757739067, 55.417237132787704, 60.178773030638695, 65.72119742631912, 62.67695277929306, 64.64777782559395, 66.20030611753464, 61.54142551124096, 63.5332178324461, 62.69327290356159, 63.506596460938454, 63.345735892653465, 62.45215304195881, 61.07240907847881, 54.949239045381546, 50.781979858875275, 52.43517994880676, 52.89449170231819, 53.1862286478281, 50.42309291660786, 49.71527449786663, 53.239551186561584, 53.36867965757847, 55.83815194666386, 53.284757360816, 55.12580797076225, 55.42777016758919, 57.636663839221, 58.54711778461933, 60.199174135923386, 62.96834774315357, 65.74306905269623, 64.19871032238007, 66.7614372074604, 64.80618372559547, 65.03873124718666, 65.41268438100815, 68.64178910851479, 71.70013099908829, 78.07368099689484, 78.0559815466404, 81.00092992186546, 79.08961728215218, 83.62785816192627, 82.6770731806755, 83.1367801129818, 60.41581951081753, 1.287715039215982, 0.37430016207508743, 1.8012972618453205, 0.3330590750556439, 24.653504602611065, 95.16600742936134, 79.73396390676498, 77.53314480185509, 55.014082565903664, 52.20447912812233, 61.48651085793972, 6.63754653185606, 0.5900509818457067, 0.2225842632469721, 0.22665485419565812, 0.1530057514901273, 0.17479482135968283, 0.09288989720516838, 0.13965458900202066, 0.2822017134167254], [0.059183553530601785, 0.03226228756830096, 0.05453738252981566, 0.04905284440610558, 0.0973120509297587, 0.06566308904439211, 0.17593006981769577, 0.10343381189159118, 1.4660572819411755, 55.0382074713707, 40.637474209070206, 31.053776666522026, 40.743720307946205, 55.78187316656113, 77.9405589401722, 59.91626791656017, 0.7603522622957826, 0.24141896195942536, 1.0907843126915395, 0.14721563406055793, 5.714070685207844, 50.94263143837452, 59.229773953557014, 63.12469035387039, 68.3464689552784, 74.68146622180939, 78.51138710975647, 79.03842642903328, 76.30560547113419, 73.4776908159256, 60.97907468676567, 62.71872393786907, 65.25169461965561, 67.76838317513466, 67.97005355358124, 71.00030735135078, 70.14938861131668, 73.78167450428009, 69.82240855693817, 67.82528892159462, 60.16256310045719, 54.127221554517746, 55.158756002783775, 54.10120815038681, 56.44467540085316, 48.674403950572014, 44.622191190719604, 47.720354944467545, 49.93703439831734, 52.561116591095924, 54.89996708929539, 51.71693108975887, 53.12264285981655, 52.14158110320568, 58.83283205330372, 64.56458508968353, 61.99758343398571, 62.0299880951643, 61.138920709490776, 62.632776349782944, 55.36361061036587, 57.562928795814514, 54.427755028009415, 50.03282345831394, 54.11033906042576, 56.92090004682541, 55.03265976905823, 56.94374822080135, 54.41555008292198, 56.17977261543274, 53.935746029019356, 53.53542611002922, 58.91824007034302, 58.53818066418171, 59.43304784595966, 63.38841140270233, 57.09191367030144, 46.77553944289684, 55.924038738012314, 57.26942494511604, 56.561826914548874, 55.302502289414406, 60.13403043150902, 63.09849075973034, 51.56618557870388, 47.35708683729172, 53.22717145085335, 44.90540899336338, 43.99219259619713, 44.00152109563351, 44.0395038574934, 45.410344898700714, 41.5206266194582, 40.190895572304726, 43.40209186077118, 63.38509798049927, 57.293394058942795, 54.36939395964146, 51.703829392790794, 42.59820319712162, 44.18924622237682, 43.95707108080387, 52.2830893099308, 56.37187510728836, 56.897649094462395, 58.7324034422636, 58.33157055079937, 56.83421529829502, 53.48004788160324, 53.141049072146416, 51.194557920098305, 52.64254242181778, 55.704231932759285, 57.62403331696987, 55.19237279891968, 54.47895348072052, 56.21475353837013, 59.18807499110699, 60.32976932823658, 58.65088261663914, 54.818681851029396, 58.13009396195412, 60.30591420829296, 52.29217082262039, 46.124478578567505, 51.15418888628483, 47.525740787386894, 46.084945499897, 42.65729762613773, 42.02402740716934, 42.433907613158226, 49.95500363409519, 50.990178287029266, 51.475275456905365, 50.91219127178192, 51.714685410261154, 52.612645626068115, 53.303247168660164, 52.53465101122856, 51.659873351454735, 51.94089487195015, 51.139445677399635, 52.66075864434242, 53.575939536094666, 57.96813905239105, 61.8312169611454, 65.04006877541542, 67.59442090988159, 70.14536082744598, 74.23665449023247, 74.58378106355667, 73.411665558815, 74.00324061512947, 71.48911312222481, 65.58050617575645, 53.95157217979431, 0.5325299652758986, 0.1444485067622736, 0.6883537850808352, 0.14868386933812872, 5.258917808532715, 73.56254026293755, 68.38863909244537, 64.41819414496422, 39.211334735155106, 30.239767245948315, 35.31291872262955, 3.8414157461375, 0.1698588120052591, 0.030749007637496106, 0.07195636775577441, 0.0527683028485626, 0.005737426799896639, 0.027445455998531543, 0.09497643797658384, 0.08531334126018919, 0.026892416826740373, 0.05955323955276981, 0.03805762229603715, 0.05677031564118806, 0.04877647974353749, 0.01437531700503314, 0.05439484564703889, 0.1445526152383536, 1.800936993677169, 63.700207471847534, 49.76483143866062, 34.29276846349239, 50.553365126252174, 62.983725517988205, 88.2131177186966, 68.652603328228, 0.696658476954326, 0.4210634808987379, 1.6866838932037354, 0.19981469755293801, 5.533886728808284, 64.14238214492798, 73.86473044753075, 77.3504202067852, 77.9326781630516, 85.07871150970459, 85.0866150856018, 86.15650847554207, 83.62853452563286, 80.00616610050201, 65.88096365332603, 65.58381199836731, 69.26150545477867, 72.18006044626236, 71.13496452569962, 72.9652427136898, 73.16596314311028, 76.74496829509735, 71.72628879547119, 71.79973125457764, 62.50411905348301, 57.012281343340874, 57.92608290910721, 55.13601802289486, 58.29500891268253, 51.393579840660095, 47.88321040570736, 52.4787750095129, 51.56910762190819, 53.69346342980862, 56.822128146886826, 54.53715115785599, 55.741336941719055, 54.59596440196037, 59.97646428644657, 66.59648045897484, 63.34221728146076, 63.787306398153305, 62.10955962538719, 64.49064865708351, 60.22504694759846, 59.22402486205101, 54.08551499247551, 52.03121982514858, 57.348540499806404, 59.37473237514496, 55.57718575000763, 58.872258737683296, 55.673670172691345, 56.39038011431694, 55.20453594624996, 56.120024621486664, 62.946320325136185, 61.4875216037035, 61.47250100970268, 63.741214871406555, 58.4120312333107, 47.68433287739754, 56.2986758351326, 59.06466521322727, 58.77032920718193, 60.78013256192207, 60.664265379309654, 61.31091848015785, 52.09053464233875, 46.47598631680012, 54.827934354543686, 46.21725060045719, 45.64442753791809, 44.627541303634644, 43.30111987888813, 45.61701960861683, 42.00125902891159, 40.703039690852165, 43.86827364563942, 63.13978314399719, 59.20821391046047, 57.18369774520397, 56.11574225127697, 44.09346096217632, 44.76512052118778, 45.22725932300091, 53.738000839948654, 59.548272863030434, 60.53682401776314, 61.25700697302818, 60.01330330967903, 60.26870660483837, 55.07241703569889, 55.30285187065601, 54.60333600640297, 57.06408016383648, 55.63395470380783, 57.280695140361786, 58.13422434031963, 58.3721599727869, 59.745983853936195, 60.66512793302536, 61.16092152893543, 60.34922808408737, 56.88884496688843, 60.16379803419113, 61.59150682389736, 53.741234466433525, 48.07108372449875, 51.644316986203194, 49.137910678982735, 49.795009419322014, 44.330507442355156, 44.42210912704468, 45.41349492967129, 52.27538712322712, 53.34069795906544, 53.60046721994877, 51.845500990748405, 54.93734188377857, 54.32603068649769, 54.828747510910034, 54.4057922065258, 54.44877170026302, 55.893340185284615, 54.809942319989204, 54.9872750043869, 57.491276040673256, 60.74149243533611, 66.88403382897377, 69.52939867973328, 70.36647096276283, 74.14854481816292, 76.39687657356262, 77.57919073104858, 77.87876665592194, 78.90630751848221, 73.29404667019844, 68.48463714122772, 60.49635998904705, 0.8635081769898534, 0.2037293929606676, 0.48045660951174796, 0.19619908765889704, 5.245284140110016, 82.62987971305847, 73.50792199373245, 74.44873631000519, 49.17403534054756, 40.3738671541214, 48.74896354973316, 7.361426213756204, 0.5611106066498905, 0.04734853937407024, 0.05983868810290005, 0.03900394593074452, 0.031506198647548445, 0.06670001035672612, 0.05281134741380811, 0.07632117572939023, 0.21255409286823124, 0.1830975984921679, 0.1482901006238535, 0.17466873046942055, 0.11416044333600439, 0.16964814596576616, 0.3536716033704579, 0.4831343673868105, 3.184616002254188, 79.75449040532112, 58.51995684206486, 42.643200382590294, 57.76286646723747, 73.19729626178741, 94.43805009126663, 76.64492726325989, 1.0158207477070391, 1.0610202723182738, 3.592299926094711, 0.3243606589967385, 6.256847335025668, 76.45347833633423, 85.08536115288734, 87.40531906485558, 84.96565997600555, 92.47634455561638, 90.29937297105789, 91.41484871506691, 87.7648101747036, 82.53107741475105, 68.69018331170082, 69.04968962073326, 74.13115695118904, 77.23657071590424, 75.59124380350113, 77.88837254047394, 76.82243093848228, 81.46069765090942, 75.32484009861946, 74.76606488227844, 65.87675347924232, 60.02227462828159, 60.21360956132412, 57.395334988832474, 60.72585627436638, 55.508888214826584, 51.63073651492596, 55.05731664597988, 54.06536467373371, 56.46564267575741, 58.97176779806614, 55.538002252578735, 60.26499420404434, 55.82967460155487, 62.03105203807354, 70.89075922966003, 67.3105837404728, 66.47886157035828, 64.61993291974068, 66.7594613134861, 60.859016329050064, 63.00484858453274, 57.9674930870533, 55.763280764222145, 61.947209537029266, 62.5332672894001, 60.933355540037155, 62.773744985461235, 58.18931758403778, 62.21021622419357, 59.865289852023125, 58.46314989030361, 67.40473508834839, 64.44606184959412, 66.01525604724884, 68.5708849132061, 63.653344586491585, 49.042152017354965, 58.878672793507576, 62.462902665138245, 60.827641412615776, 62.668380439281464, 64.1234439611435, 67.42089182138443, 56.86596259474754, 47.85637624561787, 57.3466520011425, 52.23218724131584, 47.81086228787899, 47.20807023346424, 47.59044371545315, 49.24717761576176, 42.85014867782593, 41.324097365140915, 45.5396443605423, 67.36454084515572, 61.87285132706165, 60.17124563455582, 58.106957003474236, 45.355171859264374, 46.60555176436901, 46.46400935947895, 55.96152372658253, 63.09670865535736, 62.94870659708977, 63.525325655937195, 63.58122445642948, 63.6922886967659, 57.167818397283554, 61.34341433644295, 58.59466463327408, 59.50117439031601, 59.11129631102085, 60.20705111324787, 60.203779488801956, 58.32120090723038, 61.133844181895256, 65.11455237865448, 62.85889081656933, 63.34532551467419, 60.65659739077091, 63.0796779692173, 64.87136542797089, 55.118915140628815, 53.316060081124306, 54.94287818670273, 51.907886043190956, 53.56784217059612, 49.03282731771469, 46.416823491454124, 49.10285755991936, 54.484360590577126, 56.111509278416634, 56.22933715581894, 54.84939940273762, 57.83392645418644, 58.50412309169769, 59.054462760686874, 58.4089419990778, 57.09036335349083, 59.25127699971199, 58.48467953503132, 59.47002366185188, 60.386488884687424, 64.55188617110252, 71.44021734595299, 74.34443190693855, 73.43993604183197, 77.87467047572136, 81.33515998721123, 81.61522015929222, 80.4142414033413, 82.68068298697472, 74.40496265888214, 71.73167690634727, 63.29554058611393, 1.6258622193709016, 0.4033696709666401, 1.848081776406616, 0.2709520311327651, 7.476463140919805, 91.1569033563137, 79.87879693508148, 84.7249960899353, 56.97932951152325, 50.80523081123829, 66.85045123100281, 11.106351837515831, 1.1692505772225559, 0.2128811425063759, 0.20038054062752053, 0.10140896585653536, 0.1926339734927751, 0.17657593125477433, 0.2551503712311387, 0.260615071747452], [0.0009311290307323361, 0.020180538995191455, 0.06930442919838242, 0.09155334118986502, 0.031020646674733143, 0.09312308000517078, 0.023651656447327696, 0.1081060545402579, 1.422916178125888, 49.450656697154045, 38.851057067513466, 24.362628310918808, 39.89721693098545, 56.9528791308403, 76.20930343866348, 64.14080142974854, 1.1545971385203302, 0.14878785907058045, 0.4269349080277607, 0.2338973100995645, 2.1133594354614615, 34.409384205937386, 57.977668941020966, 60.13677768409252, 70.57469978928566, 73.66750583052635, 78.77802640199661, 77.6873329281807, 77.76146695017815, 77.42573976516724, 67.97977343201637, 58.98361936211586, 64.39860999584198, 64.1820216178894, 64.95287865400314, 65.20335361361504, 68.33085179328918, 67.16302245855331, 66.2578122317791, 64.77746486663818, 58.470852077007294, 55.92987522482872, 54.527476876974106, 54.131294935941696, 56.21397078037262, 47.14402087032795, 43.53130392730236, 49.08592566847801, 49.19112682342529, 53.41369204223156, 55.00434368848801, 53.14057409763336, 53.565984070301056, 53.92094202339649, 57.567370757460594, 59.48075048625469, 61.07140973210335, 60.9517465531826, 60.79523675143719, 57.662111073732376, 53.93661618232727, 54.36448462307453, 50.38861356675625, 50.183173790574074, 48.50108005106449, 46.409132704138756, 51.051336005330086, 53.33030551671982, 51.69445529580116, 52.26552665233612, 50.76051861047745, 51.303745061159134, 56.055743470788, 60.73979012668133, 57.07939334213734, 61.85030333697796, 52.39948466420174, 46.97489194571972, 52.20091111958027, 54.90568198263645, 56.66905716061592, 57.15763874351978, 41.19304619729519, 44.9374944716692, 41.681065410375595, 46.908688098192215, 44.06262941658497, 39.33757536113262, 45.80662943422794, 43.10527078807354, 39.84710142016411, 40.50560228526592, 41.44274219870567, 39.47087220847607, 39.98935058712959, 49.32510383427143, 56.35779306292534, 57.72356517612934, 54.44989264011383, 44.05042827129364, 42.06314630806446, 46.797707453370094, 45.597747042775154, 53.79226952791214, 55.41135884821415, 57.62823969125748, 59.76052187383175, 57.276595160365105, 57.11058586835861, 56.03134498000145, 49.833212569355965, 49.70611698925495, 55.05520395934582, 55.33923491835594, 57.65725113451481, 58.92765216529369, 55.38579761981964, 58.36020961403847, 56.77856348454952, 60.6966358423233, 54.5548240095377, 57.43408910930157, 57.42710128426552, 52.269406244158745, 45.68946272134781, 48.80733981728554, 46.377172619104385, 45.58716081082821, 43.512502536177635, 42.91414484381676, 41.490387842059135, 48.63927863538265, 50.92266730964184, 49.435085132718086, 50.463746935129166, 51.2031302601099, 51.566823944449425, 53.16954754292965, 50.901749432086945, 52.77728319168091, 51.140722408890724, 50.610031485557556, 54.23748403787613, 57.24307715892792, 59.63585056364536, 63.37936028838158, 66.22786223888397, 68.7272161245346, 71.287761926651, 74.91261541843414, 72.00115844607353, 73.39575961232185, 71.01404741406441, 73.10461163520813, 68.5343536734581, 73.7822824716568, 7.8277737647295, 0.6618524633813649, 0.25685781554784626, 0.332912634476088, 2.3778917407616973, 65.46405002474785, 70.39727210998535, 63.66551153361797, 36.274126544594765, 37.069465667009354, 31.016646958887577, 7.003265507519245, 0.30088020488619804, 0.04618703373125754, 0.03890690641128458, 0.0340335862711072, 0.04269904726243112, 0.03718892730830703, 0.09588847809936851, 0.07502091815695167, 0.14266039099311456, 0.014969168732932303, 0.0597768412262667, 0.028266649824217893, 0.022067436475481372, 0.06343905057292432, 0.01957881308044307, 0.21481675270479172, 2.6425161911174655, 61.908071637153625, 45.91568358242512, 28.03356572985649, 48.91090326011181, 65.75443804264069, 85.45527130365372, 75.24860858917236, 1.5811238950118423, 0.1437464647460729, 0.6465633306652308, 0.1094744709553197, 1.9717695331200957, 40.4314910620451, 71.96059182286263, 74.37944322824478, 81.98826894164085, 83.29526200890541, 84.15478348731995, 83.59999805688858, 84.56678777933121, 79.4606065750122, 69.45097848773003, 62.82985657453537, 69.78087678551674, 70.20422726869583, 67.43485227227211, 70.8533464372158, 70.81177666783333, 68.72159242630005, 70.19403621554375, 66.66841059923172, 60.701062604784966, 57.65229620039463, 56.86570420861244, 55.692980736494064, 57.212409004569054, 50.38475677371025, 45.829432010650635, 51.4247115701437, 52.291589453816414, 54.01128217577934, 55.40985032916069, 55.437037870287895, 55.11459097266197, 56.02193668484688, 58.40733848512173, 62.453881949186325, 61.85469590127468, 63.126879036426544, 60.46104088425636, 58.747625425457954, 56.76157459616661, 56.61703035235405, 55.01024477183819, 52.19927720725536, 50.36686733365059, 48.46544936299324, 52.43514955043793, 56.129406318068504, 54.64719705283642, 53.58301095664501, 53.56563448905945, 52.73826688528061, 57.2982881963253, 63.11506927013397, 59.104088097810745, 62.50537298619747, 53.15885491669178, 49.84251827001572, 51.98401875793934, 57.5424212962389, 61.08469761908054, 58.3657269179821, 42.511803433299065, 45.261704474687576, 41.15322433412075, 46.4259772002697, 48.34554299712181, 43.15347120165825, 44.75435949862003, 44.743419885635376, 45.68746782839298, 44.149785339832306, 41.92900210618973, 40.33397689461708, 39.515075236558914, 48.66519704461098, 55.50541900098324, 61.52600213885307, 55.32516427338123, 46.20415270328522, 42.1096558123827, 47.66544409096241, 47.547308430075645, 53.49663399159908, 58.10787655413151, 59.526013657450676, 62.95058749616146, 58.894612938165665, 61.8744320422411, 58.29157389700413, 52.053011655807495, 52.31573335826397, 57.14611016213894, 57.756463810801506, 59.56190653145313, 58.23998026549816, 58.051552176475525, 61.404648050665855, 59.95841905474663, 63.471113964915276, 58.46424043178558, 58.22941683232784, 58.493894040584564, 54.5198392868042, 50.43581463396549, 49.56723064184189, 49.13921780884266, 47.0488777756691, 45.792961567640305, 46.16914518177509, 43.313636407256126, 51.20341144502163, 52.97986552119255, 51.95621185004711, 53.386306911706924, 53.67451764643192, 52.059254720807076, 54.334276244044304, 53.19940634071827, 57.29428321123123, 54.04343605041504, 52.64363296329975, 56.55809931457043, 61.39729164540768, 62.222953140735626, 66.95850983262062, 68.87464821338654, 73.5154227912426, 75.38153305649757, 78.70911329984665, 73.21050435304642, 74.67885196208954, 71.39734044671059, 77.11162582039833, 69.93444174528122, 81.11780405044556, 12.17613598331809, 0.8098226389847696, 0.616746568121016, 0.34241666668094695, 2.5401394721120596, 71.17976412177086, 77.3256303369999, 72.23185926675797, 42.41213858127594, 44.5280322432518, 44.61204573512077, 10.217771418392658, 0.25497083086520433, 0.05425670969998464, 0.15860522602451965, 0.018078466928272974, 0.015952158173604403, 0.035037771449424326, 0.10804731355165131, 0.12943209847435355, 0.18133719451725483, 0.08945219495217316, 0.22160670632729307, 0.16802120982902125, 0.12593423773068935, 0.28376966365613043, 0.30000402533914894, 0.40173338376916945, 4.074975438416004, 72.5997631251812, 58.64430896937847, 36.7526500672102, 57.706272304058075, 75.54307758808136, 92.74499014019966, 83.63280549645424, 1.7239614366553724, 0.747279895003885, 1.6606687079183757, 0.2241588186006993, 1.8451836006715894, 48.816976100206375, 86.68988585472107, 86.79509460926056, 91.40702113509178, 88.51834774017334, 89.23119708895683, 89.66907799243927, 90.03318965435028, 85.06583780050278, 74.25970405340195, 66.21672883629799, 72.62182474136353, 75.99326983094215, 73.50906953215599, 73.75627666711807, 74.82015877962112, 73.70614975690842, 71.30055204033852, 70.56469112634659, 64.16174590587616, 61.94505125284195, 59.09121058881283, 57.89489798247814, 60.7339346408844, 52.89582163095474, 49.47295770049095, 53.88713523745537, 54.071360751986504, 58.33155535161495, 59.23827789723873, 56.81193329393864, 58.8145512342453, 57.21277378499508, 62.32195682823658, 63.52981321513653, 64.76713702082634, 64.19317781925201, 65.11644467711449, 61.78803987801075, 59.69594433903694, 59.67025011777878, 57.058570459485054, 56.13022707402706, 51.54931828379631, 52.30322822928429, 56.72098137438297, 58.03534984588623, 58.42778518795967, 58.0081433057785, 57.77367688715458, 57.12865389883518, 60.181337893009186, 64.48906794190407, 61.44545026123524, 66.81665584445, 59.097620844841, 49.620454385876656, 55.05186773836613, 60.337258726358414, 62.84523814916611, 62.51693196594715, 47.40247160196304, 48.17649006843567, 41.48886792361736, 48.24180856347084, 52.61323839426041, 44.19882170855999, 43.9239938557148, 44.77583974599838, 47.78022453188896, 43.989513739943504, 42.53177896142006, 41.03196524083614, 39.028450548648834, 51.9991609454155, 59.97606910765171, 64.75855708122253, 60.070855021476746, 45.82920782268047, 43.45707111060619, 47.59116567671299, 48.21357227861881, 58.09902302920818, 60.00588230788708, 63.83037328720093, 67.13257849216461, 62.22665034234524, 63.940134197473526, 61.26633167266846, 55.186684504151344, 54.96425583958626, 60.26348568499088, 58.87325808405876, 63.02081532776356, 61.75938941538334, 59.522016271948814, 64.17685389518738, 63.08587163686752, 66.60707429051399, 59.89272437989712, 61.39469638466835, 62.98674255609512, 57.317705154418945, 52.61759676039219, 53.24223004281521, 51.552092134952545, 50.61616435647011, 50.10420262813568, 49.18416179716587, 47.26844899356365, 53.52737054228783, 57.35669486224651, 52.283324897289276, 55.385379642248154, 55.73336496949196, 56.07550621032715, 58.72537761926651, 56.61393731832504, 59.69258911907673, 57.23701648414135, 55.689131543040276, 60.799386128783226, 64.90292653441429, 63.82196053862572, 70.85978329181671, 72.25208938121796, 78.08140218257904, 79.7019012272358, 81.96743085980415, 75.99203109741211, 78.49086821079254, 74.67945992946625, 78.46867740154266, 72.075474858284, 82.08153113722801, 11.959091629832983, 0.7222338358405977, 1.8467953079380095, 0.597443247679621, 3.6959545640274882, 80.33205181360245, 85.04218026995659, 79.97847318649292, 51.92309282720089, 58.83083716034889, 63.903070986270905, 15.842391103506088, 0.9229845448862761, 0.26303224673029035, 0.32651357003487647, 0.10477115458343178, 0.292926489491947, 0.1289441215340048, 0.25707666005473584, 0.21184878540225327], [0.035070670855930075, 0.05239603044174146, 0.06133961498562712, 0.03759206934773829, 0.02354941261728527, 0.03675976186059415, 0.06721287150867283, 0.16952839301666245, 2.566872937604785, 51.89801037311554, 37.831621170043945, 31.115551851689816, 47.75239862501621, 54.96212415397167, 73.63013103604317, 68.85336935520172, 2.890578992664814, 0.15311205672333017, 0.45514809724409133, 0.08724216822884046, 0.945470966398716, 24.34431329369545, 54.4180503487587, 59.616471603512764, 71.88398033380508, 69.48478907346725, 76.06146097183228, 77.1071344614029, 78.25486287474632, 72.9499751329422, 65.09945198893547, 59.80309098958969, 62.00815066695213, 61.22737996280193, 64.44806814193726, 62.03755348920822, 63.03180433809757, 65.06813406944275, 63.80324274301529, 61.72828048467636, 55.399537682533264, 54.14420284330845, 54.62049588561058, 55.33067397773266, 55.93801058828831, 48.28004211187363, 45.408038422465324, 47.13057339191437, 50.81315338611603, 53.002189323306084, 52.736230194568634, 50.848936066031456, 54.397922828793526, 53.139118775725365, 55.190552696585655, 56.95749968290329, 58.164246529340744, 59.17097970843315, 56.490481942892075, 52.799755185842514, 51.44070491194725, 51.16070173680782, 56.0078052431345, 55.99774718284607, 56.66901156306267, 51.71104520559311, 48.19190204143524, 49.251334592700005, 50.12152209877968, 46.575240790843964, 49.20230582356453, 48.924183547496796, 53.23507122695446, 57.36669972538948, 59.95231278240681, 61.871301010251045, 43.77016671001911, 43.85495916008949, 46.35921098291874, 52.080263793468475, 54.97521065175533, 44.879300594329834, 42.15937614440918, 41.65406405925751, 44.872107580304146, 44.613846838474274, 44.927888587117195, 42.03193478286266, 41.94476746022701, 41.56550981104374, 42.59972311556339, 41.21864542365074, 40.18524527549744, 39.23601821064949, 41.393341049551964, 43.03961031138897, 39.05986726284027, 49.29004691541195, 49.353199526667595, 45.746262073516846, 44.98865872621536, 45.8888304233551, 47.10175573825836, 50.15159368515015, 53.91051158308983, 56.3165120780468, 58.77670146524906, 56.82214714586735, 58.59737008810043, 53.46661560237408, 51.17162615060806, 49.353473111987114, 51.05751447379589, 51.276777908205986, 53.23563739657402, 53.96282717585564, 54.246234968304634, 55.64172148704529, 58.8074342161417, 54.77778844535351, 55.605308040976524, 57.11436286568642, 54.86997149884701, 50.84202043712139, 46.23461566865444, 49.07912403345108, 49.264284297823906, 46.49340458214283, 44.71892639994621, 42.74634204804897, 40.72710759937763, 47.69074313342571, 52.44015388190746, 50.18170326948166, 50.475598499178886, 52.335055321455, 49.944056421518326, 51.46797984838486, 49.58131268620491, 51.97746030986309, 54.01828519999981, 52.24490135908127, 54.87660974264145, 57.80391946434975, 61.56841926276684, 65.95144227147102, 70.02611562609673, 71.52338728308678, 72.93305084109306, 74.71359729766846, 70.49514725804329, 74.76079076528549, 75.40541857481003, 76.85189455747604, 73.66765022277832, 73.70059445500374, 58.403538689017296, 0.4510367178590968, 0.2460790259647183, 0.13909195200540125, 1.142541691660881, 61.68268673121929, 70.99945619702339, 61.87640033662319, 43.49324516952038, 34.12648178637028, 32.397266775369644, 7.444089828059077, 0.08398875608691014, 0.06367931346176192, 0.018367303382547107, 0.10697750767576508, 0.04291429606382735, 0.12469682522350922, 0.08678903512191027, 0.05518047575606033, 0.07556171374744736, 0.046312683043652214, 0.023090765353117604, 0.1134087293758057, 0.03998093510745093, 0.07165503353462555, 0.005492413238243898, 0.20488703943556175, 3.5652301786467433, 64.81461927294731, 43.636379688978195, 39.20705996453762, 54.53868247568607, 64.01527136564255, 80.5822303891182, 80.71044310927391, 3.968855207785964, 0.31891154358163476, 1.031782147474587, 0.08984906584373675, 0.7129202981013805, 29.40135743469, 74.3990121781826, 72.85298153758049, 83.10408666729927, 78.07597607374191, 83.01968559622765, 81.99951633810997, 81.2137944996357, 78.47558543086052, 68.94516482949257, 64.32449117302895, 65.12192398309708, 64.75778192281723, 68.34858924150467, 65.4748110473156, 68.12536641955376, 67.2906956076622, 67.69314721226692, 63.99260178208351, 58.422507271170616, 56.78120814263821, 57.24452868103981, 56.970787569880486, 58.333907425403595, 51.19937226176262, 48.37959297001362, 49.8115461319685, 51.60041034221649, 52.88373827934265, 54.92689624428749, 54.16638225317001, 56.8932793289423, 55.827235132455826, 55.798216089606285, 57.10012502968311, 61.56809248030186, 59.5226014405489, 58.24971154332161, 55.2411849796772, 53.93296837806702, 54.208856374025345, 57.54353083670139, 59.53856438398361, 59.21596549451351, 53.60004164278507, 51.03114768862724, 51.362261921167374, 52.388009279966354, 49.80859749019146, 51.54523730278015, 51.95617765188217, 54.32644106447697, 57.75830291211605, 61.53842367231846, 64.48433339595795, 45.932832062244415, 44.218789637088776, 46.196655705571175, 51.78259916603565, 56.818028166890144, 44.3359487503767, 43.68044592440128, 43.36650677025318, 45.63999317586422, 46.505970507860184, 46.051400899887085, 42.6536650210619, 42.21139535307884, 40.88513731956482, 43.52122686803341, 39.84631486237049, 40.35317726433277, 40.85097335278988, 43.647098913788795, 41.75736531615257, 40.72847172617912, 47.47571647167206, 51.420205011963844, 46.46723538637161, 45.284856632351875, 47.56452910602093, 49.73311074078083, 52.539199367165565, 55.42052395641804, 58.16134728491306, 61.573055014014244, 59.257960841059685, 60.6107984483242, 56.24086953699589, 52.696450129151344, 52.245053350925446, 53.34879532456398, 53.4339639544487, 55.28976537287235, 55.592153146862984, 55.94128601253033, 59.28156137466431, 60.224127396941185, 58.279334753751755, 60.104494616389275, 57.932048588991165, 55.70016995072365, 54.03250403702259, 49.204464107751846, 52.480348125100136, 51.26379780471325, 49.82799544930458, 47.91290581226349, 45.78176736831665, 44.79564808309078, 50.68911664187908, 55.21311968564987, 52.185867726802826, 53.39709833264351, 56.57863341271877, 52.43528634309769, 52.19379410147667, 53.421671614050865, 54.6970047801733, 56.13835483789444, 54.7112388163805, 57.880914732813835, 61.80447779595852, 64.44961845874786, 68.04980367422104, 73.7465263903141, 73.87964084744453, 76.0175809264183, 75.07216885685921, 74.81435269117355, 78.00526186823845, 79.43222969770432, 80.47719642519951, 82.11583569645882, 80.58941200375557, 71.1343565583229, 0.9492685063742101, 0.19517784792697057, 0.22169332980411127, 0.7553580240346491, 70.26411205530167, 74.30787026882172, 73.03224831819534, 47.478535920381546, 44.32813256978989, 48.43723967671394, 8.988006357103586, 0.27922017965465784, 0.045704400254180655, 0.05045967438491061, 0.062421862967312336, 0.07077925474732183, 0.05291528890666086, 0.08730401881621219, 0.07303540594875813, 0.247932109341491, 0.11625659491983242, 0.12462920072721317, 0.15019713813671842, 0.16294180270051584, 0.19153022178215906, 0.22870395361678675, 0.303413481451571, 5.297750299796462, 82.81927675008774, 51.7464517056942, 48.27268950641155, 62.56990872323513, 76.4649461209774, 87.1792919933796, 90.71740373969078, 4.510650085285306, 0.7823612750507891, 1.4440324762836099, 0.4045325273182243, 0.9879015083424747, 35.37442222237587, 87.03602448105812, 83.36192563176155, 91.97426229715347, 85.50881803035736, 89.2940229177475, 89.4375792145729, 86.67965680360794, 80.08580222725868, 74.28893208503723, 67.79663845896721, 67.60733261704445, 67.26301789283752, 71.5656790137291, 66.76076084375381, 70.31030237674713, 70.80954998731613, 68.87831121683121, 66.5627458691597, 61.08557157218456, 59.14554387331009, 60.28280384838581, 58.37566338479519, 61.153462529182434, 52.67389073967934, 50.8252177387476, 53.02379496395588, 56.239494010806084, 57.892602905631065, 57.35335484147072, 56.404868736863136, 60.034221187233925, 56.84195928275585, 57.39905118942261, 59.56532634794712, 64.92210790514946, 63.56615446507931, 62.079944014549255, 58.653409481048584, 57.24773570895195, 55.82256518304348, 62.17914529144764, 61.23981669545174, 62.446042969822884, 57.17752307653427, 53.37493412196636, 54.61601212620735, 57.69774176180363, 53.38251851499081, 54.95987467467785, 54.582665115594864, 59.25978474318981, 60.74066407978535, 66.46199807524681, 65.44001251459122, 46.44829720258713, 44.34372313320637, 45.211486369371414, 54.27603296935558, 59.53666068613529, 47.29994550347328, 40.03593608736992, 42.8050184994936, 46.95716969668865, 46.72090217471123, 45.33520773053169, 41.83912932872772, 42.16023109853268, 41.7279776930809, 43.26759807765484, 40.29075801372528, 41.015390530228615, 39.767529889941216, 44.041738137602806, 43.39503563940525, 41.60635381937027, 52.995399087667465, 53.09270806610584, 47.835443168878555, 45.88052026927471, 47.76806898415089, 49.68525230884552, 54.917157366871834, 57.43384972214699, 62.69119441509247, 66.82329788804054, 61.541729494929314, 62.8711299598217, 58.8503111153841, 56.34964630007744, 55.330130606889725, 57.63738580048084, 55.46163775026798, 58.001539260149, 57.569806426763535, 59.54756610095501, 60.81035614013672, 63.21793355047703, 59.851629585027695, 63.952764719724655, 61.87877520918846, 58.662722781300545, 57.44198888540268, 53.11483807861805, 54.17561575770378, 54.90608476102352, 53.25094677507877, 51.36283569037914, 47.83062502741814, 47.91323259472847, 53.963742926716805, 56.95688031613827, 54.44795474410057, 54.405837804079056, 59.31328967213631, 56.23982459306717, 55.60076728463173, 56.90028615295887, 58.25012572109699, 60.7193548232317, 57.95006342232227, 62.641018107533455, 64.72335577011108, 68.98166567087173, 71.76864892244339, 77.41538912057877, 77.5809994339943, 78.89385178685188, 80.4531741142273, 76.10028728842735, 80.20589858293533, 80.31990006566048, 84.48183953762054, 84.33369308710098, 82.82411769032478, 70.82284927368164, 1.0700282827019691, 0.5925312987528741, 0.354236823040992, 1.852243384346366, 79.3659308552742, 80.00037521123886, 79.15801361203194, 61.42541393637657, 56.39003813266754, 64.73047658801079, 15.127389170229435, 0.5372022301889956, 0.1350130044738762, 0.28776571329217404, 0.1712817614316009, 0.21224225725745782, 0.26752755395136774, 0.240482950466685, 0.16649807046633214], [0.0333728596160654, 0.043396421169745736, 0.10315204810467549, 0.02824511640937999, 0.031650839518988505, 0.050434600925655104, 0.06931389900273643, 0.2038769022328779, 2.08670980297029, 44.532409608364105, 34.69146586954594, 19.750240109860897, 45.515941232442856, 58.68437021970749, 72.44419187307358, 74.76207509636879, 6.163304904475808, 0.12867117446148768, 0.7298427494242787, 0.05877301227883436, 1.0719633288681507, 16.610029712319374, 53.340583965182304, 58.53155001997948, 72.76019811630249, 69.05659005045891, 78.28120306134224, 73.63310247659683, 75.61250746250153, 67.7453564107418, 61.69867247343063, 59.51521463692188, 61.35155729949474, 61.461861580610275, 60.9003809094429, 61.437113508582115, 62.430498003959656, 62.374492809176445, 60.83388827741146, 57.90470525622368, 55.04339799284935, 52.50869080424309, 58.07961367070675, 52.070840299129486, 56.66890136897564, 47.659033834934235, 42.99770995974541, 47.140878438949585, 48.54100450873375, 50.03468155860901, 54.10283446311951, 51.86766520142555, 53.23362350463867, 50.618630424141884, 54.536034017801285, 54.74997013807297, 57.33612656593323, 56.09108157455921, 52.8383345156908, 52.396346032619476, 54.84480544924736, 58.37426885962486, 56.500874385237694, 58.09458866715431, 60.50813935697079, 58.65635432302952, 53.71567323803902, 48.62334609031677, 48.61283205449581, 48.9591758698225, 48.082570508122444, 46.64151683449745, 52.25268714129925, 51.08570136129856, 59.53793741762638, 59.74680081009865, 47.58698210120201, 42.33379438519478, 44.522256553173065, 51.048961132764816, 48.69329273700714, 51.57097712159157, 45.415353029966354, 42.736979350447655, 50.63289485871792, 52.585290893912315, 56.71609863638878, 52.47771106660366, 51.17021642625332, 44.82133090496063, 43.932060822844505, 47.15865768492222, 49.83079589903355, 50.74037209153175, 43.26383627951145, 41.18410147726536, 40.070825815200806, 40.21774113178253, 50.03273606300354, 45.03256916999817, 42.80314140021801, 46.59844234585762, 54.91448991000652, 56.98318250477314, 55.441042855381966, 56.855501756072044, 55.50014488399029, 57.51739203929901, 57.504677921533585, 51.375751197338104, 45.54408632218838, 46.18468634784222, 48.72329592704773, 48.858086094260216, 48.68889257311821, 49.71612565219402, 49.59501855075359, 49.83932264149189, 53.44264268875122, 52.76956960558891, 55.33170372247696, 55.98608560860157, 54.63259443640709, 52.49173991382122, 47.41118833422661, 48.18752087652683, 52.29642279446125, 45.47148361802101, 46.5131027251482, 44.043144062161446, 41.57985024154186, 42.309430092573166, 53.18255044519901, 48.92419494688511, 51.24929018318653, 50.81739395856857, 51.34814567863941, 49.14466671645641, 51.23859375715256, 51.10262185335159, 52.80771195888519, 51.42493195831776, 56.05278342962265, 60.741340443491936, 64.1317655146122, 67.87721693515778, 71.26347362995148, 67.56813392043114, 70.70211455225945, 69.47275891900063, 76.60182237625122, 74.01087820529938, 77.35105097293854, 71.92811876535416, 79.89597201347351, 69.20367255806923, 90.87261781096458, 23.52008242160082, 0.33102357177995145, 0.1656750138499774, 1.0905269952490926, 66.17474868893623, 69.2937733232975, 62.12338708341122, 48.761632069945335, 35.670844316482544, 29.186494164168835, 7.688733050599694, 0.1837613308453001, 0.04995910690922756, 0.0809882307657972, 0.05607274506473914, 0.030283666201285087, 0.01619700011360692, 0.069576567329932, 0.07694903266383335, 0.1111045760626439, 0.06748120242264122, 0.09622602170566097, 0.03553901056875475, 0.09806416564970277, 0.09428311619558372, 0.04911419404379558, 0.39614281500689685, 6.0679770447313786, 59.495493695139885, 41.96096979081631, 31.24359928071499, 55.322420820593834, 68.27051103115082, 77.84457609057426, 85.84232613444328, 7.108706049621105, 0.20336726942332461, 1.0224431985989213, 0.14920447109034285, 1.2472893646918237, 19.767751470208168, 72.96466514468193, 70.84557205438614, 82.56272211670876, 77.74634376168251, 84.34028953313828, 79.78419721126556, 81.23012602329254, 70.36083966493607, 65.95286339521408, 62.480104342103004, 65.52717223763466, 64.58350047469139, 64.54528972506523, 66.07780829071999, 67.35718443989754, 65.89702159166336, 64.57049757242203, 60.581935197114944, 59.455542638897896, 54.11195017397404, 59.82949197292328, 54.63561147451401, 57.328192591667175, 50.7756569981575, 48.04434835910797, 49.80317138135433, 52.51852087676525, 52.61813633143902, 57.586673721671104, 52.617262378335, 55.46916514635086, 53.935377448797226, 56.37510493397713, 55.325688645243645, 58.245394974946976, 58.50776709616184, 53.56098733842373, 51.99971951544285, 59.87255126237869, 59.97047200798988, 59.731567427515984, 60.03680884838104, 63.001519963145256, 60.31913749873638, 57.5207244604826, 50.88993966579437, 51.548626720905304, 52.169779390096664, 50.90116806328297, 48.63218441605568, 53.145035058259964, 54.850425347685814, 61.10273905098438, 59.94217872619629, 47.044451013207436, 43.77524323761463, 47.15999901294708, 51.82518728077412, 49.592738673090935, 52.44406007230282, 43.410903587937355, 44.33331549167633, 51.38368897140026, 55.70271961390972, 58.21228735148907, 55.63774310052395, 53.45950998365879, 45.381276458501816, 43.95225293934345, 47.913373187184334, 50.49054689705372, 54.313286170363426, 47.40086808800697, 40.875717625021935, 40.41463516652584, 40.17278574407101, 50.697453394532204, 45.5793522298336, 44.13344241678715, 48.52254509925842, 57.90419988334179, 59.01100069284439, 58.95575925707817, 58.29237565398216, 58.97920019924641, 59.671637043356895, 60.88961988687515, 51.731020733714104, 47.98124894499779, 47.37088769674301, 49.322869554162025, 51.268938928842545, 51.151570826768875, 51.81010589003563, 52.54944361746311, 54.58419643342495, 56.24124951660633, 56.21708281338215, 57.97585263848305, 56.27381756901741, 56.54664292931557, 53.649351596832275, 48.76066692173481, 51.55365765094757, 54.24966238439083, 48.73134009540081, 49.56714704632759, 45.35033851861954, 44.883905947208405, 45.456463024020195, 54.852880015969276, 51.68283171951771, 53.34188349545002, 52.65884354710579, 54.5543148368597, 51.950477957725525, 55.052456706762314, 53.890391662716866, 56.35909639298916, 55.77582769095898, 59.70314875245094, 64.35246527194977, 68.14485177397728, 70.06907612085342, 73.75755339860916, 70.85004061460495, 75.14175072312355, 71.1319550871849, 81.65657714009285, 76.55436292290688, 81.52104601264, 76.3624732196331, 85.13245582580566, 72.04711318016052, 95.56140661239624, 30.340482741594315, 0.3695603023516014, 0.0808268655964639, 1.3823472987860441, 74.58855360746384, 74.09884348511696, 71.20831578969955, 57.11596257984638, 41.969732120633125, 43.34289103746414, 11.818501073867083, 0.2937334415037185, 0.06105475273216143, 0.08749083965085447, 0.06300246735918336, 0.017864882393041626, 0.08932545097195543, 0.04657766316086054, 0.04217515408527106, 0.20568358653690666, 0.2968693122966215, 0.1933859323617071, 0.09780038410099223, 0.12877658911747858, 0.18123188376193866, 0.1645223397645168, 0.43203138455282897, 8.6962048150599, 79.83554765582085, 48.540434539318085, 31.5751675888896, 59.52168948948383, 79.81345564126968, 84.29767102003098, 96.70484885573387, 8.059723768383265, 0.4390583059284836, 1.979335283394903, 0.6686183565761894, 1.7532158293761313, 25.513649247586727, 93.56393739581108, 78.1413097679615, 90.69868594408035, 84.6469558775425, 89.20006915926933, 83.29653114080429, 84.86267790198326, 73.85383263230324, 68.86774018406868, 66.0980536043644, 69.48307156562805, 66.97940871119499, 66.86031550168991, 71.54633045196533, 71.57089993357658, 67.71789148449898, 67.53591164946556, 61.98629043996334, 61.11447662115097, 57.34010495245457, 61.49772025644779, 57.39945776760578, 60.98555713891983, 52.22770728170872, 50.4132704436779, 53.6247631162405, 56.34668625891209, 55.372053757309914, 61.32969707250595, 54.3975580483675, 58.769835233688354, 55.441145449876785, 59.5074288547039, 58.159189000725746, 61.994304209947586, 60.26801124215126, 57.0231943577528, 57.662076875567436, 60.45363508164883, 62.38437607884407, 63.4205386787653, 62.44280934333801, 62.89204403758049, 61.509951800107956, 58.93174834549427, 53.778749853372574, 54.11418065428734, 54.114674627780914, 54.41819094121456, 50.492131412029266, 57.47456073760986, 55.861072316765785, 65.35976082086563, 64.59770411252975, 48.9166409522295, 45.196788758039474, 49.88496199250221, 53.208491653203964, 52.448122054338455, 52.649176865816116, 45.549007058143616, 45.03494404256344, 53.94973687827587, 58.05457681417465, 60.54712526500225, 56.68763056397438, 53.9426426589489, 45.204832926392555, 44.52306590974331, 49.13819186389446, 52.00356110930443, 53.11631239950657, 47.37935744225979, 43.72390039265156, 42.325362637639046, 41.459791883826256, 50.84088049829006, 45.33271886408329, 44.3123672157526, 49.44257453083992, 63.48942518234253, 61.745493561029434, 61.884558498859406, 60.53599186241627, 60.96020109951496, 61.33698508143425, 63.95886719226837, 54.46866363286972, 50.878072902560234, 51.25378154218197, 52.77819134294987, 54.794249162077904, 54.815311431884766, 55.24267449975014, 55.275120958685875, 55.55238828063011, 58.31481344997883, 58.77686865627766, 61.48128613829613, 61.77606292068958, 61.7624406516552, 57.1372452378273, 53.85984890162945, 53.092229291796684, 57.97611102461815, 50.7020815461874, 53.35769064724445, 48.21785464882851, 47.880968526005745, 49.18363742530346, 59.41634014248848, 52.835078090429306, 56.19085282087326, 54.38093014061451, 59.26442049443722, 52.938580736517906, 56.589869409799576, 56.8563187122345, 59.97395262122154, 58.072800636291504, 61.91282518208027, 66.8464158475399, 71.92345261573792, 72.7542020380497, 76.83671057224274, 73.6058047413826, 77.12055534124374, 74.98262286186218, 85.74450418353081, 81.18745431303978, 84.9603022634983, 79.93393197655678, 90.54527297616005, 74.79214668273926, 101.2722797691822, 28.071092516183853, 0.4614293383201584, 0.40505093231331557, 1.9497202662751079, 80.03773480653763, 77.9805251955986, 79.64679658412933, 68.40380027890205, 56.8192782998085, 61.410769522190094, 20.281204618513584, 0.6359415943734348, 0.24131976650096476, 0.36888797592837363, 0.29814179870299995, 0.30358049436472356, 0.23275616898899898, 0.18375718966126442, 0.14661672088550404], [0.09727370415930636, 0.03245214749767911, 0.057230781167163514, 0.01273037729333737, 0.11797390237916261, 0.040281200635945424, 0.09755644758115523, 0.1823065135977231, 5.196367464959621, 41.049657091498375, 32.277052626013756, 29.650755152106285, 36.638245806097984, 61.27152219414711, 69.01695057749748, 82.1666769683361, 17.949721924960613, 0.2580701879924163, 1.3141560391522944, 0.21537688124226406, 1.0279885260388255, 14.247847516089678, 62.101424261927605, 62.92860947549343, 79.74796995520592, 72.72859141230583, 77.39756807684898, 71.83726564049721, 69.15310487151146, 61.80846758186817, 58.907836228609085, 56.688637509942055, 60.10222613811493, 56.48915581405163, 60.04001587629318, 57.76784040033817, 60.74229039251804, 59.12304528057575, 61.33038483560085, 55.28932839632034, 55.23749157786369, 53.7239757925272, 54.81740511953831, 54.00950387120247, 53.594889119267464, 47.90643475949764, 45.10553665459156, 46.31903953850269, 47.174552232027054, 49.95214618742466, 52.22631275653839, 51.64933271706104, 54.476616606116295, 52.86522187292576, 53.21305140852928, 53.55913303792477, 58.05466040968895, 55.6997025758028, 50.61513841152191, 57.47531309723854, 62.698771208524704, 62.361843287944794, 62.71932050585747, 59.235211461782455, 59.81833957135677, 60.661160945892334, 58.97258475422859, 52.611908465623856, 49.22768086194992, 46.354138255119324, 49.7432029992342, 48.14678706228733, 48.45930889248848, 52.062701135873795, 54.59326274693012, 53.78954887390137, 45.56748926639557, 47.69161328673363, 50.864180848002434, 44.171634167432785, 42.06598475575447, 46.07444666326046, 45.33733181655407, 51.33857399225235, 53.514018058776855, 56.76715649664402, 55.634824857115746, 59.207723736763, 61.92947968840599, 60.58476224541664, 55.72373628616333, 57.773665487766266, 56.521446481347084, 55.467523634433746, 53.406176045536995, 42.57282055914402, 34.63433213531971, 41.8376512080431, 43.96868325769901, 49.25037324428558, 42.008706629276276, 45.84882616996765, 57.52914480865002, 53.68343576788902, 54.50862228870392, 56.28208212554455, 57.89669148623943, 54.69021074473858, 52.643800154328346, 46.38852261006832, 48.301925137639046, 45.43207973241806, 48.936821669340134, 48.503432124853134, 50.39306312799454, 47.927660420536995, 47.95894034206867, 47.42401644587517, 50.47168470919132, 51.17207832634449, 54.07296046614647, 53.48081164062023, 51.34292855858803, 51.88873127102852, 48.14214751124382, 49.38322551548481, 51.97427608072758, 48.12191739678383, 46.92584037780762, 44.04029421508312, 41.71646051108837, 44.68071185052395, 51.927223205566406, 50.28107553720474, 51.71648271381855, 49.51412469148636, 50.195849910378456, 50.48035964369774, 52.125865146517754, 50.215323865413666, 51.090660095214844, 53.601493164896965, 57.82910071313381, 63.03108237683773, 67.11107164621353, 66.02221727371216, 71.1345237493515, 71.11013665795326, 71.58321887254715, 71.92580088973045, 74.64806601405144, 72.48118668794632, 74.66746777296066, 72.47386068105698, 74.48403641581535, 70.45674651861191, 82.16722413897514, 67.51432120800018, 0.8257119019981474, 0.10524563927901909, 1.7791952728293836, 66.88201993703842, 69.50055062770844, 64.69420373439789, 43.822144120931625, 42.232757806777954, 32.44121141731739, 6.363535160198808, 0.23632370255654678, 0.09789964635274373, 0.07551241287728772, 0.05071629049780313, 0.08887087809853256, 0.22576908610062674, 0.08077041784417816, 0.020355754495540168, 0.04573686179355718, 0.010563499963609502, 0.015406171260110568, 0.04446053848369047, 0.11035880670533516, 0.19990791130112484, 0.165677982440684, 0.3282221424160525, 8.698377348482609, 59.00177098810673, 35.85332952439785, 30.435899421572685, 43.123342618346214, 71.6703025996685, 75.60529544949532, 92.22463086247444, 21.28602460026741, 0.16453503048978746, 1.470525129698217, 0.168548179208301, 0.9329042688477784, 18.954023234546185, 78.35649222135544, 75.22620499134064, 90.654137134552, 78.8081131875515, 84.5700404047966, 77.44707942008972, 75.3143298625946, 65.29198005795479, 62.1882876008749, 61.17585472762585, 64.10624608397484, 61.42879195511341, 63.514169454574585, 60.33646836876869, 63.55445869266987, 61.495037600398064, 63.671849593520164, 58.33697386085987, 58.28311935067177, 55.55415518581867, 57.15837210416794, 55.13032212853432, 56.79116740822792, 49.91048142313957, 49.6236652135849, 48.9523134380579, 50.39127342402935, 53.04923079907894, 53.797239661216736, 52.561040595173836, 56.12884774804115, 52.89375454187393, 53.46164166927338, 53.84431153535843, 61.64250008761883, 58.012877851724625, 53.04844804108143, 59.08628225326538, 64.54556331038475, 65.41371792554855, 66.79068803787231, 61.03941544890404, 61.89225308597088, 62.290790900588036, 61.908440217375755, 56.497530564665794, 52.45320238173008, 50.931805819272995, 52.664543241262436, 50.287964567542076, 51.48303084075451, 53.63643229007721, 57.1429031342268, 55.99153071641922, 46.72734662890434, 46.30392014980316, 50.86897999048233, 44.2708620429039, 42.462478280067444, 46.484995633363724, 47.00719401240349, 53.82682107388973, 54.79169949889183, 57.38586209714413, 58.074989318847656, 60.587980672717094, 64.02442887425423, 63.45099024474621, 57.04164996743202, 59.87114913761616, 57.97197304666042, 58.18042606115341, 54.84920181334019, 44.67439278960228, 36.88881576061249, 42.361764684319496, 44.1356310993433, 51.03847749531269, 42.54890464246273, 48.5530536621809, 58.95499549806118, 55.274315401911736, 55.292125046253204, 58.6789783090353, 58.754058480262756, 54.6370629966259, 53.69630567729473, 49.647782519459724, 51.333425268530846, 48.72662074863911, 51.695150658488274, 52.79300294816494, 52.7163952589035, 50.733247473835945, 50.044154450297356, 49.69814881682396, 51.94677695631981, 52.83145688474178, 55.38775831460953, 53.20567600429058, 53.81850712001324, 54.79232266545296, 50.28998985886574, 53.5871147364378, 54.422739297151566, 50.71683615446091, 49.1137819737196, 45.763437151908875, 45.03939740359783, 47.95138634741306, 52.2795744985342, 53.62911008298397, 51.821866258978844, 51.32545329630375, 51.05951316654682, 53.0607707798481, 54.02981758117676, 54.052806347608566, 53.081810250878334, 56.387211084365845, 60.81142008304596, 66.97402819991112, 69.73236098885536, 72.08724662661552, 74.7293208539486, 75.7520891726017, 75.67410975694656, 76.08834832906723, 79.25853341817856, 75.8218002319336, 77.29916095733643, 76.82437643408775, 77.15873569250107, 76.87748998403549, 84.13519933819771, 77.43257939815521, 1.773390134330839, 0.14151334238704294, 2.4090500688180327, 75.92211484909058, 76.54403507709503, 75.82490846514702, 51.08525678515434, 50.305534824728966, 51.231336146593094, 14.26066042855382, 0.23897213075542822, 0.07994776940904558, 0.04949681198922917, 0.04487962927669287, 0.04329369679908268, 0.02147511171642691, 0.009727078195282957, 0.007984957956068683, 0.2558960812166333, 0.12316875800024718, 0.20765741734066978, 0.23134032933739945, 0.2731601579580456, 0.2777941577369347, 0.232986249611713, 0.3672543604625389, 13.081662543118, 78.28014671802521, 47.51469478011131, 42.74711720645428, 48.066459372639656, 83.65004897117615, 81.02177560329437, 103.9250922203064, 23.327573351562023, 0.26736410334706306, 2.3974226927384734, 0.2954952110303566, 1.1454031756147742, 26.505426429212093, 92.11177691817284, 81.96613132953644, 97.79402241110802, 84.48464378714561, 90.78350499272346, 78.66717875003815, 77.71158322691917, 67.84974440932274, 66.76598936319351, 64.36885759234428, 67.13904574513435, 62.59536735713482, 66.90173327922821, 63.738213032484055, 67.58853882551193, 66.559918820858, 66.34247168898582, 62.06181138753891, 62.060451060533524, 59.12269949913025, 58.91696333885193, 58.52183394134045, 59.569513723254204, 52.40719065070152, 51.142318323254585, 51.55022643506527, 53.04915860295296, 55.510210543870926, 56.891835406422615, 57.29508116841316, 58.21144759654999, 54.30452384054661, 55.59727527201176, 54.35620106756687, 62.99016237258911, 61.146645694971085, 52.86728136241436, 60.03135234117508, 68.92352879047394, 67.26304829120636, 69.12608072161674, 64.46892902255058, 66.53681606054306, 66.53330504894257, 65.69045707583427, 57.8096229583025, 54.363363683223724, 52.103210762143135, 54.647717624902725, 54.058122262358665, 55.01906789839268, 55.973261296749115, 59.10053908824921, 59.179848432540894, 50.23985154926777, 46.118596494197845, 51.84768207371235, 44.99583654105663, 44.44886349141598, 47.67488658428192, 48.19172345101833, 57.37736955285072, 59.66528378427029, 62.9734280705452, 61.18864484131336, 63.072940930724144, 65.77241107821465, 67.56412893533707, 58.32435853779316, 62.49713122844696, 61.60416014492512, 61.842813938856125, 56.46859511733055, 44.33409824967384, 36.95112481713295, 45.49982629716396, 44.835834726691246, 50.953688845038414, 44.16363179683685, 48.179727494716644, 61.43467403948307, 57.64034204185009, 57.76719443500042, 62.152257934212685, 62.87841036915779, 56.52570225298405, 58.85164864361286, 51.2427469342947, 54.37027171254158, 49.991854056715965, 54.243396520614624, 54.18237179517746, 56.62806876003742, 54.065832048654556, 53.40289682149887, 53.14809389412403, 54.400571286678314, 55.648716911673546, 59.14465852081776, 59.510594084858894, 56.22359946370125, 56.017585918307304, 52.62130916118622, 56.686072647571564, 56.25078700482845, 55.200036987662315, 51.91849127411842, 49.27082374691963, 48.08575093746185, 51.28619760274887, 56.10125742852688, 56.67759910225868, 54.82865251600742, 56.407441198825836, 53.99454787373543, 55.04679501056671, 56.84896610677242, 57.71739810705185, 56.62572428584099, 60.62563665211201, 65.45375257730484, 70.3764720261097, 72.27680325508118, 75.33630788326263, 78.12828406691551, 78.65529298782349, 77.54489377140999, 77.7021673321724, 81.80886536836624, 78.7687548995018, 82.0987594127655, 80.77025189995766, 80.16077980399132, 79.28861260414124, 89.91649031639099, 79.54846546053886, 1.8991598230786622, 0.2458729612408206, 2.841293499805033, 82.79916822910309, 79.3078775703907, 83.80450308322906, 60.73021084070206, 61.767095401883125, 70.94538509845734, 20.964235067367554, 0.436679307022132, 0.2197853720281273, 0.16141109343152493, 0.11021856305887923, 0.2072782689356245, 0.24045660422416404, 0.17960445780772716, 0.16307975311065093], [0.03501685401715804, 0.07413226310745813, 0.08110824346658774, 0.06785588309867308, 0.036827390067628585, 0.028889604873256758, 0.056583413170301355, 0.13005060434807092, 7.114853644743562, 45.626070722937584, 29.209184646606445, 38.715164959430695, 42.696488723158836, 64.28022354841232, 65.92953264713287, 77.11515203118324, 11.646614447236061, 0.14566914673196152, 0.7777461258228868, 0.08759749369346537, 0.8852532226592302, 33.55395130813122, 74.00247305631638, 64.9373146891594, 77.9526498913765, 73.71636360883713, 75.482736825943, 72.74541690945625, 68.45016539096832, 60.117117539048195, 57.764428183436394, 56.52785673737526, 55.4022279381752, 55.73754854500294, 56.72618709504604, 54.521363005042076, 57.21949942409992, 53.71792271733284, 56.3284320384264, 53.42953339219093, 54.6517264097929, 52.40000903606415, 52.79221259057522, 52.871787920594215, 52.53397084772587, 47.92169474065304, 45.39927989244461, 43.53940509259701, 48.549044877290726, 48.931729942560196, 51.60784654319286, 52.94170416891575, 54.639707654714584, 53.4882440418005, 55.84198594093323, 56.46748557686806, 58.067116141319275, 56.13362409174442, 56.736632734537125, 61.93759985268116, 63.08779813349247, 64.18326795101166, 58.951750472187996, 61.051692590117455, 58.28941561281681, 58.047402799129486, 62.150912806391716, 58.37133541703224, 51.90967574715614, 50.59656880795956, 48.35407353937626, 47.445580288767815, 48.74125376343727, 50.44917471706867, 52.142322063446045, 54.80881378054619, 48.936745673418045, 48.927603363990784, 47.90428787469864, 43.74324895441532, 42.27551311254501, 47.92914994060993, 49.9187345802784, 48.903448060154915, 48.770276606082916, 55.588345751166344, 57.00919210910797, 58.110771998763084, 61.36337846517563, 59.93899829685688, 58.305488750338554, 55.91662913560867, 54.22698140144348, 51.296293660998344, 52.171204313635826, 53.99682015180588, 45.67883089184761, 39.40574750304222, 40.87194062769413, 46.34955570101738, 46.44347906112671, 54.75333675742149, 54.014747589826584, 52.59232431650162, 50.47917030751705, 49.913475662469864, 48.62461522221565, 48.8602177798748, 47.31799453496933, 48.47207620739937, 46.13898999989033, 52.65838377177715, 52.75752805173397, 50.81504948437214, 49.442680925130844, 50.44537112116814, 47.73054979741573, 49.736055582761765, 45.62105879187584, 50.237548872828484, 53.0577727407217, 53.20848785340786, 51.83754421770573, 51.91922843456268, 49.299253821372986, 50.430244132876396, 51.74251511693001, 46.96394093334675, 48.903037682175636, 43.94563369452953, 41.421546936035156, 42.4389461427927, 49.45213861763477, 49.472634717822075, 50.019413977861404, 48.33470977842808, 50.21747075021267, 49.66940335929394, 50.78718937933445, 50.392975732684135, 49.39347356557846, 53.35748165845871, 54.94695916771889, 58.680163845419884, 65.77619567513466, 67.19586789608002, 68.88089507818222, 71.88929244875908, 70.27433350682259, 73.28030660748482, 72.0422874391079, 72.80062794685364, 69.36206325888634, 70.8395379781723, 68.4287877380848, 76.07751131057739, 76.51835605502129, 87.54667907953262, 8.513030894100666, 0.6980449869297445, 3.172269989736378, 64.48852837085724, 75.69049447774887, 62.7979800850153, 47.905853390693665, 33.02865989506245, 31.91360592842102, 9.739373289048672, 0.32860497187357396, 0.053539769069175236, 0.04805301934538875, 0.045633283953065984, 0.08911902259569615, 0.05580467390245758, 0.05234031370491721, 0.011171782753081061, 0.03272922091127839, 0.0853227665356826, 0.07976353124831803, 0.010085553149110638, 0.04304976770072244, 0.1747178309597075, 0.12479380908189341, 0.4268107912503183, 13.853216841816902, 59.65250886976719, 41.040507182478905, 42.253827676177025, 45.41236259043217, 76.35757148265839, 71.6469794511795, 88.53431448340416, 12.210649531334639, 0.08014482446014881, 0.7517936371732503, 0.06336882855976, 0.9676202747505158, 39.71911668777466, 88.23091596364975, 73.91362622380257, 87.7093255519867, 79.97772082686424, 82.95786291360855, 74.63033616542816, 74.79259505867958, 64.15233001112938, 62.045343071222305, 58.174384385347366, 59.595865309238434, 58.76356177031994, 63.57431262731552, 59.6770441532135, 60.41404880583286, 56.297908276319504, 59.03394006192684, 55.21150477230549, 56.76786705851555, 54.15344014763832, 54.778897985816, 55.744612365961075, 54.26683746278286, 49.728398993611336, 48.81612874567509, 47.27877303957939, 51.60308539867401, 49.794025272130966, 54.95324023067951, 55.27363523840904, 57.3570292443037, 54.82590526342392, 55.588174760341644, 57.487768828868866, 59.88140098750591, 57.10286848247051, 59.297835901379585, 64.382164478302, 62.3386113345623, 64.1671872138977, 60.800089091062546, 65.14232128858566, 61.41803853213787, 61.19408994913101, 63.113218769431114, 60.3435093909502, 55.7742165774107, 52.17509910464287, 51.83411680161953, 49.374235197901726, 52.0330361276865, 53.364233896136284, 55.12741528451443, 57.513383254408836, 50.19705444574356, 46.675958186388016, 48.210711032152176, 42.091010212898254, 43.87947544455528, 49.46204088628292, 53.58133904635906, 52.657863199710846, 52.78374284505844, 56.28949552774429, 59.919957518577576, 61.723276153206825, 61.51773378252983, 63.26545000076294, 61.62640035152435, 58.25360633432865, 56.64613299071789, 54.92348402738571, 54.110703840851784, 54.191381111741066, 47.58643113076687, 41.89022518694401, 42.640928104519844, 46.997432336211205, 47.61482700705528, 57.39601895213127, 57.59129047393799, 54.61119398474693, 54.194595739245415, 50.72714880108833, 50.22880934178829, 50.45985974371433, 48.92250783741474, 50.90910963714123, 48.403968662023544, 54.38005618751049, 54.35504972934723, 54.987225607037544, 50.88676683604717, 53.67097623646259, 49.89005371928215, 51.2065614759922, 48.65662470459938, 50.746702551841736, 55.72365269064903, 54.57696162164211, 52.818191796541214, 54.70965050160885, 51.218078657984734, 51.546483635902405, 54.162403866648674, 50.21143287420273, 50.49848087131977, 47.33339510858059, 42.775448486208916, 46.45992837846279, 50.99681653082371, 53.36066208779812, 53.375956267118454, 50.05222521722317, 52.01084911823273, 53.87080751359463, 52.101880833506584, 54.35516372323036, 54.6445219963789, 55.96712462604046, 57.55569778382778, 62.266985177993774, 68.22126567363739, 71.2849348783493, 71.59470185637474, 76.66287750005722, 75.33608749508858, 76.7743407189846, 74.47282701730728, 77.4108749628067, 71.58167615532875, 75.9843099117279, 72.463418841362, 80.42133182287216, 76.73850864171982, 95.23700281977654, 10.254101268947124, 0.6539268011692911, 3.7525392277166247, 74.15651679039001, 81.85054153203964, 71.2806487083435, 55.77742740511894, 37.04546235501766, 46.24133750796318, 20.33550750464201, 0.4345798009308055, 0.10398971018730663, 0.10655376361683011, 0.03358826426847372, 0.12095498343114741, 0.02528170960431453, 0.1064475771272555, 0.046107037633191794, 0.12191643574624322, 0.25047412840649486, 0.23909973562695086, 0.13233282719738781, 0.14304635231383145, 0.1670509556424804, 0.20371867634821683, 0.3261243284214288, 17.448477521538734, 81.80965572595596, 46.30001775920391, 57.252078875899315, 54.96813163161278, 89.51036050915718, 75.76025873422623, 100.38913115859032, 14.072999898344278, 0.20637271518353373, 1.3478438439778984, 0.230325857992284, 0.9448173420969397, 46.25521056354046, 96.59531593322754, 77.89618492126465, 94.84340474009514, 85.05845099687576, 86.238082498312, 81.18268176913261, 79.62594330310822, 65.38909524679184, 66.78911492228508, 62.57688894867897, 63.64134103059769, 62.529900670051575, 65.30876755714417, 61.80779121816158, 64.12245601415634, 59.93500471115112, 61.95251785218716, 57.18156225979328, 60.89055463671684, 56.63751885294914, 57.36527860164642, 59.088497534394264, 56.006653904914856, 52.69147239625454, 51.77975691854954, 50.57337865233421, 53.1040770560503, 54.30197797715664, 56.6175889223814, 57.52838484942913, 58.837038427591324, 56.7322363704443, 57.86169916391373, 59.56584692001343, 63.97471994161606, 59.06798243522644, 61.20786041021347, 64.57086235284805, 65.09933039546013, 68.32411095499992, 61.06229402124882, 69.49420496821404, 62.087532207369804, 64.75993260741234, 66.30792394280434, 62.58369818329811, 60.4804540425539, 58.16335737705231, 54.79837954044342, 51.58939853310585, 54.703061655163765, 57.06034116446972, 56.18366740643978, 61.8277857452631, 51.230101212859154, 48.458697125315666, 51.85498148202896, 43.82848598062992, 45.82578420639038, 49.13258716464043, 57.14340090751648, 55.874534994363785, 55.659170150756836, 60.671591386199, 63.43111351132393, 62.952529191970825, 64.69383135437965, 65.46538755297661, 64.4229818880558, 60.03354102373123, 59.740546345710754, 57.928514778614044, 60.13800121843815, 57.117543295025826, 49.026956632733345, 42.64076471328735, 44.442935809493065, 48.51715698838234, 48.902855291962624, 60.058764070272446, 59.81865495443344, 56.23613119125366, 58.571957051754, 56.2110411375761, 53.01481984555721, 52.31553576886654, 50.77056527137756, 53.50969389081001, 50.99811226129532, 56.64689674973488, 57.26192034780979, 58.22787791490555, 53.67791846394539, 58.09229739010334, 52.385376021265984, 54.82421055436134, 51.08499839901924, 54.88210044801235, 59.24525432288647, 56.560276597738266, 57.03904710710049, 56.50138355791569, 53.8917937874794, 54.23141956329346, 56.663125678896904, 53.23222137987614, 54.75276678800583, 49.43034678697586, 45.45958265662193, 48.98243822157383, 54.61615651845932, 56.919817104935646, 55.39343900978565, 50.92721566557884, 54.20485518872738, 56.775880828499794, 56.86456426978111, 56.73510141670704, 57.26405203342438, 61.70385919511318, 60.474754348397255, 65.29106810688972, 70.63328504562378, 73.36388692259789, 75.4234904050827, 78.25927823781967, 77.08824947476387, 82.27973610162735, 76.793894469738, 80.32219514250755, 73.50979909300804, 79.35673534870148, 74.68835905194283, 83.07091444730759, 80.9806390106678, 97.99298733472824, 10.539751891046762, 0.6603228079620749, 4.336870685219765, 79.43418279290199, 90.4442971944809, 76.05485692620277, 69.30913969874382, 49.68435935676098, 63.24748456478119, 28.376484028995037, 0.6835114792920649, 0.20440458407392725, 0.3352894663112238, 0.10996846671332605, 0.18722248496487737, 0.18038305977825075, 0.40809741884004325, 0.10330334975151345], [0.023730804641672876, 0.11289120011497289, 0.03258249460486695, 0.046519868410541676, 0.03470931544143241, 0.08586754003772512, 0.04073035954206716, 0.26003126869909465, 8.953864239156246, 49.783811420202255, 23.0206049233675, 31.63576103746891, 55.12811444699764, 57.7873295545578, 73.9266063272953, 67.88024917244911, 2.5755789829418063, 0.25587874464690685, 0.49030250462237746, 0.48087280592881143, 1.0342603269964457, 59.53142836689949, 70.68026572465897, 72.41965278983116, 75.21063342690468, 73.04269775748253, 70.62726616859436, 71.33846640586853, 64.49617356061935, 59.42963942885399, 56.59691043198109, 54.84913721680641, 55.13393193483353, 54.45513255894184, 54.13609027862549, 53.45968097448349, 53.82194593548775, 55.09585417807102, 52.53767564892769, 53.163505867123604, 51.192209646105766, 50.782082453370094, 52.15818241238594, 53.52274239063263, 53.10187317430973, 48.01680363714695, 45.87401121854782, 44.38047096133232, 47.91221044957638, 49.911666959524155, 52.23440632224083, 52.25636534392834, 55.91506741940975, 52.21656247973442, 52.9130233079195, 60.174289271235466, 58.86472374200821, 53.5144854336977, 61.031808257102966, 63.1828348338604, 60.60624249279499, 59.78446438908577, 62.35285297036171, 59.72399823367596, 59.52036716043949, 58.37906800210476, 58.87496039271355, 60.18634222447872, 56.615799218416214, 52.43517994880676, 52.552928030490875, 48.54771874845028, 48.42043697834015, 50.67992873489857, 54.733779206871986, 56.33321978151798, 52.62579292058945, 44.908749014139175, 43.23637895286083, 42.6125094294548, 46.46880470216274, 48.22455368936062, 44.22535188496113, 49.354734644293785, 52.250532656908035, 54.87285554409027, 56.487704291939735, 61.71691529452801, 56.07251577079296, 54.12173084914684, 60.38731724023819, 59.30647663772106, 55.37499099969864, 52.06224516034126, 51.21769107878208, 49.099323749542236, 46.58419691026211, 46.9587542116642, 39.43667024374008, 42.89048731327057, 53.407084196805954, 52.62682646512985, 56.368105709552765, 50.73336906731129, 48.16444851458073, 46.11681438982487, 48.21674130856991, 45.67392535507679, 45.964089184999466, 45.032667964696884, 49.904815927147865, 52.55504451692104, 54.0737584233284, 50.38149654865265, 53.14737193286419, 52.23381355404854, 51.039518639445305, 51.03648640215397, 47.70014762878418, 44.558890387415886, 51.24054305255413, 49.54626336693764, 52.615913450717926, 50.11349692940712, 52.38569900393486, 49.370967373251915, 50.52418649196625, 46.09913393855095, 44.751300662755966, 44.69176545739174, 41.19304999709129, 45.305033549666405, 49.46698822081089, 49.98746149241924, 48.4817960858345, 50.555595606565475, 47.74802125990391, 50.50692781805992, 50.04518419504166, 50.223212242126465, 52.45509847998619, 51.11492559313774, 52.14807115495205, 53.93935203552246, 60.47156251966953, 67.9856327176094, 65.35251840949059, 68.32380697131157, 70.75202107429504, 71.935353577137, 68.03642839193344, 67.52704292535782, 66.04387611150742, 65.65356105566025, 65.25754630565643, 78.02629753947258, 74.482531696558, 90.8279550075531, 18.584449365735054, 1.1432680464349687, 4.708126913756132, 68.32858711481094, 71.03536427021027, 62.4590078741312, 46.53219290077686, 34.303233101964, 31.09876625239849, 13.893432933837175, 0.24206798494560644, 0.1425661233952269, 0.029756075273326132, 0.036516797554213554, 0.037777869729325175, 0.12054109509335831, 0.06961712570046075, 0.04508576821535826, 0.01963839640666265, 0.05390555510530248, 0.01881255673652049, 0.03726959876075853, 0.045198882653494366, 0.06213720851519611, 0.14770004869205877, 0.24971577222459018, 13.99179920554161, 65.34436404705048, 28.71217131614685, 33.47534492611885, 59.68985326588154, 66.19982734322548, 80.70479661226273, 77.12699979543686, 2.7695324504747987, 0.2700477687176317, 0.5990230129100382, 0.3979335876647383, 1.264475011266768, 68.79055872559547, 83.95994514226913, 81.38028636574745, 82.50987455248833, 79.30425256490707, 77.54226431250572, 76.95003569126129, 69.40411180257797, 63.68397854268551, 58.89391377568245, 57.73000203073025, 59.20965403318405, 58.53895962238312, 57.456238120794296, 57.36942417919636, 58.64053577184677, 56.544412449002266, 55.74676305055618, 54.979705810546875, 56.82747446000576, 52.521260529756546, 53.585955798625946, 55.718758553266525, 56.997617930173874, 54.05602477490902, 49.70446787774563, 48.77392441034317, 51.051233410835266, 51.759876385331154, 54.15169224143028, 53.512653931975365, 57.29223132133484, 55.086981654167175, 52.554660737514496, 61.678864136338234, 62.47776746749878, 55.317644476890564, 63.077341094613075, 65.00610619783401, 62.15869478881359, 63.28153073787689, 64.26874056458473, 60.1404444873333, 61.769660264253616, 61.90489500761032, 60.24571783840656, 62.26940184831619, 59.09040503203869, 54.3684022128582, 53.509739488363266, 50.07846660912037, 50.63919872045517, 51.806955859065056, 57.0244824886322, 57.478660717606544, 50.2365343272686, 45.00002011656761, 43.629236072301865, 43.73680830001831, 49.348491579294205, 50.005780309438705, 49.23711195588112, 53.91703203320503, 53.04918520152569, 57.46959060430527, 59.08944748342037, 63.60922135412693, 55.41965760290623, 54.488407373428345, 62.95309156179428, 61.19138069450855, 55.211972147226334, 55.31523920595646, 53.05450491607189, 51.41167066991329, 49.50102299451828, 48.10241684317589, 39.43473994731903, 43.13668370246887, 52.10599981248379, 56.32304012775421, 57.01469041407108, 50.401054099202156, 52.227429896593094, 49.044785276055336, 49.54523362219334, 48.08998391032219, 49.2708807438612, 48.563886880874634, 53.27563405036926, 54.72899526357651, 55.930376797914505, 53.90910945832729, 55.40662810206413, 55.10568805038929, 53.64386849105358, 52.51778371632099, 52.05740801990032, 46.04079566895962, 53.04358810186386, 50.602492690086365, 54.17156137526035, 52.804926708340645, 54.39484119415283, 52.67037972807884, 50.97250923514366, 49.29519563913345, 47.79647246003151, 47.81835928559303, 43.27345736324787, 46.28404341638088, 51.94861985743046, 52.171812281012535, 51.79024055600166, 53.473310843110085, 50.07029324769974, 53.82018283009529, 53.44353184103966, 53.16837340593338, 52.78506897389889, 54.70232829451561, 54.13473755121231, 57.393115907907486, 62.941141203045845, 70.64686551690102, 69.81414780020714, 73.61226439476013, 72.6898030936718, 74.94882747530937, 71.71624973416328, 73.33493247628212, 69.39730256795883, 70.20466044545174, 67.9723334312439, 81.4019376039505, 75.67604005336761, 98.3730049431324, 20.653102062642574, 1.4467400684952736, 5.440704803913832, 77.30757370591164, 76.37861475348473, 69.35912981629372, 55.30919753015041, 41.6399060189724, 48.15209157764912, 22.41181679069996, 0.46545338176656514, 0.045259464168339036, 0.08846420343616046, 0.057309419134981, 0.05937487549090292, 0.059431557019706815, 0.020741611915582325, 0.07129459467250854, 0.10078174716909416, 0.21193175751250237, 0.14059486042242497, 0.1272893400164321, 0.14541260112309828, 0.16288560727844015, 0.2424207128933631, 0.3224540816154331, 19.51866153627634, 84.92404460906982, 33.6124187707901, 46.60401664674282, 70.26194617152214, 78.06377872824669, 86.36656120419502, 85.0227253139019, 3.6077083367854357, 0.6133514503017068, 1.17506533395499, 0.7953074178658426, 2.136236345395446, 74.39797103404999, 89.51523944735527, 85.5055122077465, 87.82787159085274, 80.9970997273922, 82.23899468779564, 81.73486053943634, 70.51167637109756, 66.11342757940292, 61.995451748371124, 61.121958419680595, 63.36649417877197, 60.7088977843523, 59.767080321908, 59.45167824625969, 61.50993660092354, 59.89161863923073, 56.993202567100525, 58.554770573973656, 58.75331752002239, 55.29346637427807, 57.43342034518719, 57.83093981444836, 60.05631700158119, 54.64062720537186, 53.39161142706871, 51.06428191065788, 53.88336963951588, 55.40241412818432, 56.19477801024914, 56.22069641947746, 59.11541908979416, 55.80949388444424, 53.40608865022659, 65.24718806147575, 63.17772410809994, 56.617265939712524, 65.2579414844513, 66.35571017861366, 64.30521100759506, 65.69970577955246, 67.32331305742264, 65.21758005023003, 64.94936764240265, 63.11177484691143, 61.645566523075104, 64.85340759158134, 63.74979481101036, 55.96314623951912, 58.67895931005478, 53.90740714967251, 54.09801632165909, 56.56112015247345, 61.20357804000378, 62.88250274956226, 54.471882060170174, 46.874550729990005, 45.45532688498497, 44.018540382385254, 49.98666733503342, 52.75768764317036, 51.10589347779751, 54.7308723628521, 60.102746710181236, 59.30663622915745, 61.62645734846592, 64.90031987428665, 58.354281932115555, 56.08286261558533, 66.22158497571945, 65.1382327079773, 58.113097473978996, 58.63142006099224, 55.91018848121166, 54.85675200819969, 53.363530933856964, 50.500627756118774, 40.10652869939804, 45.83066314458847, 55.26559107005596, 57.986818850040436, 60.83605796098709, 54.19560648500919, 55.147531405091286, 52.86376655101776, 52.76565961539745, 48.70266303420067, 51.22580364346504, 51.57611824572086, 53.86569678783417, 57.26366065442562, 59.51731592416763, 55.23652642965317, 58.608621284365654, 56.5643385797739, 57.07194194197655, 54.752223417162895, 54.29338663816452, 48.90185594558716, 55.83420395851135, 52.13143564760685, 58.07250425219536, 54.11685571074486, 57.002310678362846, 55.407540053129196, 54.48683425784111, 51.24360948801041, 51.41599863767624, 50.80786406993866, 47.20373086631298, 49.99520547688007, 54.900658652186394, 54.72389593720436, 54.430354088544846, 55.15280172228813, 52.304607555270195, 57.93891862034798, 55.38998119533062, 55.60199461877346, 57.31716938316822, 57.514857575297356, 56.10552839934826, 61.05686031281948, 66.7792658507824, 75.75101003050804, 72.71884113550186, 73.90797212719917, 73.63646149635315, 78.9205339550972, 73.2127158343792, 76.11592724919319, 72.50332430005074, 72.70701617002487, 68.18044066429138, 85.26894450187683, 78.73030096292496, 101.39581874012947, 23.481651283800602, 1.3983723451383412, 6.717451019212604, 83.07279914617538, 84.29050460457802, 76.00061103701591, 68.86357560753822, 51.60100311040878, 63.2964601367712, 31.89806856215, 0.5410960118751973, 0.2582125616027042, 0.1497145788744092, 0.19534940278390422, 0.1693807204719633, 0.21650142793077976, 0.1517484791111201, 0.23283167509362102], [0.04961249796906486, 0.03737548096978571, 0.029135897711967118, 0.039210604372783564, 0.01951218491740292, 0.11830109302536584, 0.17727460392052308, 0.27547571808099747, 6.952889235690236, 46.60327948629856, 34.960202649235725, 42.96688221395016, 34.97666336596012, 64.3528300523758, 71.2159913778305, 71.52140378952026, 4.81706659309566, 0.2748321573017165, 0.6718809565063566, 0.5611460516229272, 5.972702382132411, 78.81510481238365, 70.30005812644958, 76.41981974244118, 69.36785414814949, 73.12102675437927, 69.77849811315536, 68.97722750902176, 60.40136128664017, 58.993331640958786, 55.97834162414074, 56.13170139491558, 54.29985009133816, 55.376917496323586, 55.62463380396366, 54.00905169546604, 50.87968781590462, 52.90113374590874, 52.07316197454929, 52.62328885495663, 52.38357491791248, 54.45819519460201, 52.8597691655159, 52.889555767178535, 52.049299255013466, 51.79051414132118, 44.052369967103004, 44.23473358154297, 47.772149965167046, 50.8086734265089, 49.09287549555302, 51.98005557060242, 53.78882311284542, 53.59366178512573, 51.84852562844753, 61.15027830004692, 65.05284368991852, 52.71643325686455, 62.844576984643936, 60.082911774516106, 61.54822714626789, 59.09675449132919, 62.50167578458786, 56.47656708955765, 58.92528869211674, 56.48710012435913, 59.90486092865467, 58.167582750320435, 53.96064609289169, 54.66429993510246, 50.67615933716297, 49.55361597239971, 52.84565292298794, 52.733391746878624, 54.2633568495512, 52.43706464767456, 38.13576824963093, 45.36570869386196, 43.99987958371639, 42.32457987964153, 49.1289621591568, 46.85709826648235, 48.098187670111656, 49.37028340995312, 50.184393525123596, 58.394567370414734, 59.073834121227264, 59.07350733876228, 44.76989306509495, 45.21630451083183, 60.155955255031586, 56.65260024368763, 53.84015455842018, 50.414421781897545, 51.99072539806366, 47.740265876054764, 45.407240465283394, 47.63563469052315, 39.152688682079315, 41.89183630049229, 42.38839365541935, 58.09139683842659, 53.79690147936344, 52.33545050024986, 46.08241483569145, 45.536984503269196, 45.893188789486885, 45.29140368103981, 49.24259506165981, 47.164923548698425, 51.75663895905018, 54.54821616411209, 53.48260134458542, 50.621856451034546, 51.46774046123028, 53.37492652237415, 52.47307911515236, 54.33592155575752, 51.889533028006554, 48.28678295016289, 47.77043245732784, 48.49649369716644, 49.33494910597801, 50.25491014122963, 49.96047914028168, 49.26529884338379, 49.776702001690865, 46.11631281673908, 43.38774003088474, 43.81074473261833, 42.36929588019848, 45.90629428625107, 48.03103767335415, 49.23672057688236, 50.1754792034626, 49.64511886239052, 49.71023216843605, 49.22207236289978, 50.06448335945606, 50.11380471289158, 47.97921985387802, 52.7995689958334, 51.070114597678185, 54.450941383838654, 51.92510671913624, 59.75183553993702, 62.54219301044941, 65.13216823339462, 64.26343604922295, 65.35320237278938, 62.935335114598274, 66.16224735975266, 62.3880048841238, 65.78537598252296, 68.49574014544487, 79.89319816231728, 74.91590604186058, 93.12422499060631, 25.815478451550007, 1.7643704870715737, 6.846547666937113, 71.51094675064087, 69.09511998295784, 58.04388038814068, 47.77386747300625, 35.57252079248428, 32.328330874443054, 15.434156209230423, 0.4323663009563461, 0.03579104020900559, 0.07297839416423813, 0.08753627393161878, 0.025070566734939348, 0.0530273569165729, 0.05701423731807154, 0.008494764242641395, 0.05081927833089139, 0.0904893982806243, 0.02442744382278761, 0.06323917536064982, 0.08495077243424021, 0.06638599283178337, 0.1588351433747448, 0.3813359298510477, 12.877926975488663, 62.430095225572586, 39.60934437811375, 30.72817213833332, 41.650606244802475, 71.76047936081886, 80.95408603549004, 79.41237956285477, 5.678685558959842, 0.33428382652346045, 0.8326391677837819, 0.6974305480252951, 7.578745102509856, 88.23611408472061, 78.51388737559319, 82.8878478705883, 77.32173174619675, 78.99478197097778, 74.99960035085678, 74.40693095326424, 66.01112186908722, 61.92352540791035, 59.6453158557415, 60.66182591021061, 57.336312755942345, 56.33127048611641, 56.790639236569405, 57.7257576584816, 54.167575389146805, 55.00483386218548, 54.991830959916115, 54.99033764004707, 55.9578113257885, 55.96694603562355, 53.655568063259125, 55.314866825938225, 55.88942639529705, 53.29527139663696, 47.14278593659401, 47.48700946569443, 50.017202496528625, 51.73160210251808, 51.748670786619186, 55.742898657917976, 56.1113078892231, 54.80341047048569, 51.086271330714226, 61.92580908536911, 68.11473459005356, 53.396999537944794, 67.10955172777176, 64.00578707456589, 62.48160146176815, 63.51390726864338, 63.25472317636013, 57.24728733301163, 60.81155687570572, 59.99649681150913, 62.66864262521267, 62.14065335690975, 56.93823851644993, 57.18242861330509, 53.34331601858139, 52.55541309714317, 55.55885933339596, 56.20266638696194, 58.90044182538986, 51.515211313962936, 39.95112843811512, 44.55858260393143, 45.227779895067215, 41.6850969940424, 50.72244085371494, 51.02865882217884, 51.9269610196352, 52.72958815097809, 55.21394424140453, 59.756000116467476, 61.887636333703995, 59.97618690133095, 46.571494191884995, 45.41725292801857, 61.75470046699047, 60.289179906249046, 58.25940102338791, 52.653189450502396, 55.349175184965134, 49.178720489144325, 47.50248983502388, 50.010864436626434, 40.08048489689827, 40.72908729314804, 43.77748131752014, 58.561279624700546, 55.64115911722183, 52.66453564167023, 48.474063500761986, 47.57896453142166, 48.885448426008224, 47.299896106123924, 51.82194225490093, 50.199569910764694, 56.34975269436836, 56.19956575334072, 57.43465147912502, 53.99140544235706, 53.74091148376465, 56.26212939620018, 55.13541005551815, 56.51281714439392, 55.9481218457222, 53.282975256443024, 51.69033631682396, 50.72418496012688, 53.66052679717541, 51.85478389263153, 53.22977811098099, 51.924821734428406, 51.47340215742588, 48.783515095710754, 46.80572882294655, 45.20709000527859, 45.40471360087395, 48.7084349244833, 50.3634437173605, 52.37122558057308, 50.88389798998833, 52.11122453212738, 51.85325637459755, 52.217930406332016, 53.07249315083027, 53.278833478689194, 52.32393331825733, 56.390991881489754, 53.242089450359344, 58.08985032141209, 53.848210126161575, 63.1311272084713, 64.8667448759079, 68.9325039088726, 67.04000025987625, 69.79150101542473, 65.42762517929077, 71.57361298799515, 65.3627322614193, 68.84418904781342, 69.69685569405556, 85.24824321269989, 76.22238993644714, 98.08615073561668, 28.376921005547047, 1.6380780888721347, 7.991830911487341, 79.72470760345459, 73.82511377334595, 63.711698055267334, 60.7976458221674, 44.90003228187561, 44.05651934444904, 22.625959999859333, 0.4550096718594432, 0.051079790719086304, 0.07624771053087898, 0.03939236376027111, 0.07116993612726219, 0.052818516560364515, 0.034873782788054086, 0.05892236949875951, 0.12450156616978347, 0.1434062048792839, 0.1361600382369943, 0.23062099528033286, 0.13982507516629994, 0.2509260072838515, 0.2979532041354105, 0.41334253270179033, 22.413929477334023, 77.55385369062424, 49.78343524038792, 61.41674280166626, 51.22563265264034, 80.9869010746479, 87.09746718406677, 86.78654506802559, 6.250859331339598, 0.4457880713744089, 1.6354857967235148, 0.8278757671359926, 9.26411759108305, 94.5394666492939, 84.34915825724602, 85.43477520346642, 80.47164112329483, 82.58090794086456, 79.63074624538422, 79.35671254992485, 68.5057184100151, 67.39323690533638, 62.0040088891983, 64.33988034725189, 62.33336761593819, 61.13240785896778, 60.548527389764786, 61.942509189248085, 57.278799042105675, 57.91017696261406, 58.349710777401924, 58.563259318470955, 58.5500930249691, 59.619044065475464, 59.23717975616455, 58.608279302716255, 58.90934094786644, 55.53493581712246, 50.374641716480255, 51.50204122066498, 53.91988568007946, 54.38256785273552, 53.53140972554684, 57.477118000388145, 57.25179769098759, 55.716930851340294, 51.934750601649284, 64.47769895195961, 68.35389375686646, 54.279619976878166, 68.96246910095215, 65.41982039809227, 64.97761532664299, 62.93110974133015, 66.34656026959419, 60.84241881966591, 63.473652228713036, 63.4871681034565, 63.08127008378506, 63.567704781889915, 59.340462014079094, 60.481502786278725, 57.918616309762, 52.93362580239773, 60.24892866611481, 59.98968757688999, 60.51548056304455, 56.76682211458683, 40.09469613432884, 45.080416202545166, 45.40482759475708, 44.73373420536518, 52.900282591581345, 54.67362463474274, 54.34769332408905, 56.107549890875816, 56.85467720031738, 62.272688671946526, 63.33038471639156, 61.51352360844612, 47.16765560209751, 46.84512510895729, 65.08742183446884, 62.488114312291145, 60.21983362734318, 56.22323848307133, 59.28172096610069, 51.1091423034668, 51.51381678879261, 52.74639084935188, 39.469549879431725, 42.20853790640831, 45.507638677954674, 60.79269088804722, 57.85391718149185, 57.14299812912941, 50.33527962863445, 50.34249544143677, 51.095831617712975, 50.789997428655624, 53.92370447516441, 52.91900418698788, 59.31117318570614, 59.78865936398506, 60.12108452618122, 54.535665437579155, 56.44580014050007, 58.49373824894428, 56.56204730272293, 60.45589976012707, 58.2539065182209, 54.9629221111536, 52.85645194351673, 51.56970039010048, 54.45013202726841, 52.85037226974964, 55.21529696881771, 53.647843077778816, 56.06395483016968, 51.11745625734329, 50.20061485469341, 48.72196599841118, 48.2779598236084, 51.513710394501686, 53.321417793631554, 54.59464207291603, 53.879714235663414, 54.90994915366173, 55.29839850962162, 55.25077186524868, 55.086844861507416, 55.79946622252464, 54.60656963288784, 60.61209797859192, 56.51947818696499, 62.00903981924057, 56.69290468096733, 68.12766909599304, 69.66629013419151, 72.49896213412285, 71.55012264847755, 72.26895287632942, 68.84356588125229, 74.65581759810448, 68.51212486624718, 72.64883369207382, 72.75048583745956, 87.65773952007294, 80.4127062857151, 101.55561536550522, 31.05467151850462, 2.338056340813637, 8.888015672564507, 84.10705804824829, 83.04173201322556, 71.16421535611153, 69.64441850781441, 53.75791557133198, 66.81995406746864, 33.12675163149834, 0.5314350302796811, 0.18674246384762228, 0.2458027540706098, 0.16102333611343056, 0.14448754373006523, 0.21916555997449905, 0.22158214123919606, 0.13875011878553778], [0.030694886518176645, 0.01320992714681779, 0.06791849067667499, 0.08157529926393181, 0.03259146345953923, 0.1280594221316278, 0.033007960446411744, 0.4347380268154666, 6.751577937975526, 51.20794840157032, 35.81803701817989, 58.446738570928574, 71.0463684797287, 56.58379353582859, 74.74465683102608, 69.48828488588333, 3.723488124087453, 0.21087456814711913, 0.4582463559927419, 0.680260753724724, 24.603153504431248, 85.55354163050652, 68.30097019672394, 77.25528091192245, 69.31686088442802, 75.108692497015, 64.77151438593864, 67.95327365398407, 57.70212672650814, 57.83605054020882, 51.52005985379219, 52.894700691103935, 51.775337755680084, 53.695614114403725, 52.27773919701576, 52.621958926320076, 53.910644575953484, 52.60739430785179, 53.161157593131065, 52.73806929588318, 51.34096026420593, 52.743974179029465, 51.801784336566925, 52.79994137585163, 52.22405567765236, 52.06131421029568, 44.534244909882545, 43.36577720940113, 43.060133010149, 48.61247107386589, 50.560079365968704, 49.95903141796589, 51.53645597398281, 54.402843564748764, 58.70012417435646, 68.2783006131649, 63.70417445898056, 54.21717792749405, 63.02125610411167, 60.217310562729836, 61.13775037229061, 60.0008437782526, 62.44328051805496, 60.226570665836334, 60.69105014204979, 58.48075054585934, 58.57666499912739, 55.77540211379528, 54.940491914749146, 53.14196862280369, 56.13101743161678, 54.14701469242573, 50.481009408831596, 55.94901479780674, 52.983745113015175, 49.11548808217049, 46.44993111491203, 44.93436723947525, 43.6925482749939, 45.39028577506542, 51.21253855526447, 47.811071276664734, 48.00431750714779, 54.65500183403492, 53.538944721221924, 57.955432534217834, 57.60153852403164, 65.10725677013397, 44.54410158097744, 42.24018260836601, 61.519743874669075, 54.94361534714699, 58.52089539170265, 51.4693021774292, 51.524266228079796, 48.38089630007744, 47.26674668490887, 48.50007690489292, 47.78924144804478, 43.30232061445713, 44.564069509506226, 46.600057259202, 59.65519152581692, 46.963036581873894, 52.14721620082855, 45.972551330924034, 46.40483133494854, 47.124337926506996, 50.17528921365738, 51.362151727080345, 54.8011039942503, 53.7002232670784, 52.6084278523922, 52.10338555276394, 55.08503995835781, 56.05417035520077, 56.02029137313366, 54.90481562912464, 56.24518230557442, 53.37452374398708, 51.031276881694794, 50.37832371890545, 50.48858240246773, 52.96654723584652, 50.262528732419014, 49.067310467362404, 47.43991479277611, 45.09438805282116, 46.634179428219795, 44.60111752152443, 42.929150238633156, 46.63597673177719, 49.19105462729931, 51.70897051692009, 53.241017907857895, 50.80828204751015, 47.93856583535671, 48.65109600126743, 49.501121789216995, 49.4144332408905, 49.80150707066059, 50.70589654147625, 49.98295493423939, 52.655830308794975, 50.53296782076359, 53.03548313677311, 55.7502094656229, 59.306282848119736, 61.406148970127106, 65.30746042728424, 61.61952652037144, 61.14017844200134, 59.404518976807594, 65.2739842236042, 67.74383649230003, 78.30059722065926, 73.50749641656876, 92.30283066630363, 27.89713215082884, 1.4894047728739679, 8.992948941886425, 72.93640986084938, 65.43440401554108, 55.09135901927948, 47.3559544980526, 22.94569954276085, 31.56120713800192, 13.250411488115788, 0.12740778678562492, 0.06047072332876269, 0.013995016415719874, 0.07007919426541775, 0.08844151598168537, 0.11175135034136474, 0.08290061174193397, 0.10578537359833717, 0.10379678889876232, 0.07161797067965381, 0.05075865228718612, 0.08679194434080273, 0.05432967394881416, 0.1940008462406695, 0.07734473838354461, 0.4923401749692857, 10.912897568196058, 69.48078408837318, 39.5371900498867, 55.90130835771561, 76.63829281926155, 63.733805269002914, 84.47289481759071, 75.84167316555977, 5.249085836112499, 0.4912024922668934, 0.6134991080034524, 0.7245664356742054, 27.216843254864216, 94.58173558115959, 74.24195140600204, 84.913389980793, 75.12161180377007, 77.69209787249565, 72.23977044224739, 72.25757628679276, 62.56593033671379, 60.367744490504265, 57.579446509480476, 57.499757185578346, 55.216079726815224, 58.45262065529823, 55.05514316260815, 56.84905730187893, 56.13099083304405, 55.98229341208935, 55.26285141706467, 55.95079690217972, 55.87475158274174, 55.68782061338425, 54.41892810165882, 54.7706638276577, 54.7060938924551, 52.75675669312477, 46.86750590801239, 47.024547681212425, 46.5607787668705, 51.63444131612778, 51.411081701517105, 52.32606500387192, 51.94181442260742, 56.52639761567116, 60.30170403420925, 71.50242000818253, 62.91584596037865, 55.16542464494705, 64.9494968354702, 62.483398765325546, 63.00999730825424, 62.89525106549263, 64.50523227453232, 61.55669309198856, 64.22633484005928, 59.736526161432266, 62.80382417142391, 57.09592245519161, 57.19942510128021, 56.351299211382866, 58.656342923641205, 57.728440314531326, 52.56143197417259, 60.801666006445885, 53.9834638684988, 48.409474566578865, 47.51147635281086, 48.49102199077606, 45.00255838036537, 48.129623383283615, 53.05089890956879, 50.5191707611084, 50.85963249206543, 56.01881705224514, 55.2507908642292, 60.13163276016712, 58.3939404040575, 65.66676154732704, 44.55880679190159, 43.25794659554958, 64.2128075659275, 54.80322428047657, 60.473492816090584, 54.60631504654884, 53.9310684800148, 51.435734778642654, 49.631652384996414, 52.40238770842552, 49.096561297774315, 43.68662819266319, 45.56014806032181, 47.42963634431362, 62.35794849693775, 50.11688254773617, 54.705307334661484, 46.80750712752342, 49.51378270983696, 48.55357423424721, 52.609309405088425, 52.25654773414135, 57.011810168623924, 57.193638011813164, 55.87266929447651, 54.29207190871239, 59.50953774154186, 57.18573823571205, 59.23222482204437, 57.388271167874336, 57.530550733208656, 57.11419567465782, 54.2849662899971, 52.491838708519936, 52.931410521268845, 53.436559215188026, 53.72230768203735, 52.99607165157795, 50.153314992785454, 47.54588730633259, 47.65749491751194, 46.23624198138714, 45.13028472661972, 49.09724906086922, 51.8376924097538, 53.62162068486214, 54.85490530729294, 53.328280225396156, 51.113261282444, 52.15546555817127, 52.3667798191309, 52.447597682476044, 52.64416113495827, 54.00657422840595, 53.01080726087093, 55.90551093220711, 54.935122802853584, 57.495923191308975, 58.98004375398159, 62.57900543510914, 64.19241026043892, 67.71527722477913, 65.16767352819443, 65.92770874500275, 65.00074088573456, 67.08450347185135, 71.80353865027428, 82.0227862894535, 74.91524487733841, 95.98363235592842, 29.890845268964767, 1.2422160431742668, 11.064947359263897, 79.96245324611664, 72.49358922243118, 64.33200716972351, 55.593939051032066, 35.6310148537159, 46.77871987223625, 19.28232751786709, 0.25432937778532505, 0.02942599581729155, 0.05579731550824363, 0.06718207980156876, 0.08269290687167086, 0.04984249324479606, 0.03790712587942835, 0.014814505157119129, 0.1902919335407205, 0.1452583828358911, 0.1687914106878452, 0.17330164992017671, 0.1417155034141615, 0.44429935282096267, 0.11621278594247997, 0.43507466500159353, 16.6519832611084, 90.09052857756615, 47.66990125179291, 74.41215187311172, 86.11582785844803, 73.00213873386383, 89.8839944601059, 80.6507483124733, 6.320995967835188, 0.4318383370991796, 0.8150729478802532, 0.9376584668643773, 29.49508510529995, 97.53226205706596, 76.94751262664795, 86.56587570905685, 81.03512048721313, 81.88639640808105, 75.30486837029457, 74.50175866484642, 66.7988196015358, 64.66441333293915, 61.21050126850605, 59.81985189020634, 57.19602048397064, 62.07919925451279, 57.72904448211193, 60.17200939357281, 61.123835518956184, 58.47169183194637, 59.01622161269188, 56.83021031320095, 57.2875651717186, 57.48251371085644, 58.51498290896416, 56.41944095492363, 57.504875510931015, 57.33086384832859, 48.19165125489235, 48.66145424544811, 49.72531735897064, 53.583254143595695, 53.63650068640709, 53.70498061180115, 53.03536534309387, 57.73955851793289, 61.427268236875534, 74.56829309463501, 64.48707684874535, 56.96645200252533, 66.01465567946434, 66.36103749275208, 67.47492492198944, 65.75158059597015, 66.79467782378197, 64.98495653271675, 67.8669422864914, 64.11097303032875, 65.09314432740211, 62.22591318190098, 58.894434347748756, 58.845914751291275, 61.554447412490845, 60.38050800561905, 55.033704712986946, 62.78665669262409, 57.51456119120121, 49.153843224048615, 48.08953933417797, 52.12044283747673, 46.406172662973404, 48.44445928931236, 57.733163461089134, 53.377825766801834, 51.49526998400688, 57.97676458954811, 59.29140664637089, 63.79794582724571, 60.491990223526955, 69.9243114888668, 45.777766183018684, 42.90653385221958, 65.65833359956741, 57.03223027288914, 63.05415093898773, 56.201404854655266, 56.046399772167206, 52.89658918976784, 52.22698152065277, 56.38427384197712, 51.77832819521427, 46.40659064054489, 47.475765869021416, 51.205987706780434, 63.20021890103817, 52.65380881726742, 57.7827849984169, 50.419825091958046, 53.066599667072296, 53.028628304600716, 56.2835868448019, 55.39568088948727, 59.164482057094574, 60.61270594596863, 57.44206868112087, 56.41949415206909, 60.75620524585247, 60.55489584803581, 61.66671238839626, 59.87503632903099, 59.26999859511852, 58.27395424246788, 56.98075443506241, 52.28548318147659, 55.11150173842907, 53.49523566663265, 55.25602698326111, 55.058657974004745, 53.65320459008217, 51.28946162760258, 52.486359402537346, 51.14361025393009, 49.98516261577606, 50.87017312645912, 54.22881290316582, 57.45287150144577, 59.691342785954475, 56.77415952086449, 53.817750960588455, 54.394560009241104, 55.37464141845703, 56.08165808022022, 55.65021023154259, 58.69270317256451, 56.35592736303806, 59.67000313103199, 56.90024055540562, 60.85883393883705, 64.04523655772209, 64.97842088341713, 66.6677950322628, 71.87839463353157, 69.02163192629814, 68.76816272735596, 67.54842817783356, 70.04257634282112, 75.04633024334908, 85.57003274559975, 77.37507328391075, 99.68426898121834, 33.144473880529404, 1.672159053850919, 12.234384957700968, 86.32625296711922, 79.73206400871277, 69.75728005170822, 68.7001995742321, 34.75278697907925, 68.64878833293915, 31.923249810934067, 0.4285202838946134, 0.22891380329383537, 0.1971311360830441, 0.20534123381366953, 0.20686478877905756, 0.16938517335802317, 0.29513141023926437, 0.21708713087718934], [0.05256101729173679, 0.0508382661791984, 0.06088119407650083, 0.07883601734647527, 0.03668957324407529, 0.10850906299310736, 0.15119924530154094, 0.5736616894137114, 8.204112220555544, 53.45835864543915, 35.59486359357834, 26.467610858380795, 39.43893872201443, 57.13991269469261, 73.11031132936478, 68.42196330428123, 4.866302451118827, 0.22296502953395247, 0.5840649374295026, 0.39916691835969687, 41.44869647920132, 81.81667774915695, 69.3390440940857, 76.41745626926422, 66.648590862751, 69.11341980099678, 64.68635335564613, 62.416784539818764, 54.966953694820404, 56.50944672524929, 52.688158974051476, 53.336461186409, 53.22191633284092, 53.68931025266647, 52.508508414030075, 52.97972872853279, 52.75199554860592, 51.10251925885677, 52.96051315963268, 53.43862250447273, 54.539670422673225, 50.438337698578835, 52.620609998703, 49.18935991823673, 51.322903633117676, 51.227821335196495, 48.43260012567043, 43.072064369916916, 45.04269562661648, 46.77287198603153, 49.22070823609829, 48.801085352897644, 51.427546218037605, 53.90747554600239, 59.573552906513214, 71.38760536909103, 60.072097554802895, 54.42149676382542, 59.047938510775566, 56.367668733000755, 60.76553374528885, 59.31667909026146, 60.728888511657715, 62.042307034134865, 61.037268564105034, 57.23605513572693, 54.49139021337032, 54.07969370484352, 56.64201021194458, 53.36197681725025, 52.62613870203495, 50.76222851872444, 54.69938725233078, 53.690993562340736, 54.3757738173008, 53.65505129098892, 43.80464605987072, 41.80699065327644, 47.18662418425083, 45.71659326553345, 47.230850011110306, 48.04217107594013, 50.745741203427315, 50.86685210466385, 52.295184060931206, 55.22290036082268, 56.82371646165848, 59.42761793732643, 51.2170185148716, 45.91070204973221, 61.21256835758686, 55.76005093753338, 55.35931684076786, 50.56498110294342, 55.61016418039799, 50.415683314204216, 50.8144187182188, 43.7446890771389, 46.6196034103632, 39.932156056165695, 44.796826019883156, 51.37738510966301, 54.124964475631714, 55.94969496130943, 49.09498818218708, 51.24916858971119, 48.964563980698586, 46.63944214582443, 48.84317189455032, 52.22422666847706, 52.565094977617264, 53.109115585684776, 54.65324632823467, 54.843977093696594, 57.962215170264244, 57.096747010946274, 56.82691968977451, 57.537743747234344, 58.042694851756096, 56.479884311556816, 55.54449990391731, 51.14613711833954, 50.2740953117609, 53.638890758156776, 52.77917169034481, 48.9722053706646, 44.839022755622864, 43.789773657917976, 44.168924912810326, 42.46867194771767, 43.98265890777111, 45.4492662101984, 49.756388291716576, 51.11020624637604, 49.4380109757185, 49.85341988503933, 49.87143471837044, 48.359180465340614, 47.45113559067249, 49.520622342824936, 49.272077679634094, 48.11196953058243, 49.59360122680664, 51.86214029788971, 51.79021015763283, 53.73851761221886, 54.19906049966812, 53.70081223547459, 55.32286919653416, 58.98406773805618, 57.66169689595699, 60.05277939140797, 63.14586281776428, 68.18536520004272, 69.0648128092289, 77.64118060469627, 73.61142084002495, 88.16005736589432, 25.707778930664062, 1.1982496711425483, 11.42460661008954, 77.09163889288902, 60.793348252773285, 50.62203884124756, 44.158950448036194, 31.128811240196228, 31.01463496685028, 7.399385226890445, 0.1561233654501848, 0.04582968591421377, 0.026310830944566987, 0.03789615322602913, 0.03753805212909356, 0.07133415856515057, 0.07925001700641587, 0.029354263533605263, 0.03633749467553571, 0.029419858256005682, 0.058924603363266215, 0.058150680633843876, 0.08377541089430451, 0.1590622850926593, 0.13648014137288556, 0.47470897261518985, 11.052500177174807, 69.80061292648315, 37.266903072595596, 33.287414610385895, 51.54470153152943, 64.32313084602356, 81.60565227270126, 74.82814595103264, 6.025864854454994, 0.35677514621056616, 0.8257817232515663, 0.40176728507503867, 45.59817261993885, 89.442458152771, 75.45957326889038, 82.29585483670235, 73.00628051161766, 73.3488929271698, 70.13955473899841, 67.66478553414345, 60.641215816140175, 59.577694684267044, 55.86893029510975, 57.79776759445667, 55.925874039530754, 55.474218875169754, 55.93061998486519, 56.707674488425255, 55.94647653400898, 55.32186605036259, 57.62513905763626, 55.33739201724529, 57.06631824374199, 52.17236705124378, 54.423715844750404, 53.23915980756283, 52.650958970189095, 54.35773618519306, 49.689055904746056, 46.901373490691185, 47.97428771853447, 50.68883925676346, 51.9281617552042, 51.58041961491108, 52.20572926104069, 54.456576481461525, 63.10791425406933, 73.13084542751312, 60.50014838576317, 55.36397539079189, 61.55730105936527, 58.55699345469475, 62.97778643667698, 60.653641149401665, 62.80613824725151, 64.03132930397987, 62.24689565598965, 59.705303236842155, 57.673765048384666, 55.129900351166725, 61.01948171854019, 56.30345217883587, 57.43832588195801, 55.65269149839878, 58.150605261325836, 55.40054462850094, 55.57309716939926, 51.65236495435238, 45.03090865910053, 44.540769159793854, 48.86166550219059, 48.57078731060028, 50.069829672575, 53.24559286236763, 54.189580008387566, 54.74816143512726, 56.874025762081146, 57.55301132798195, 60.45629873871803, 61.324734538793564, 52.301734909415245, 49.1512555629015, 63.61067667603493, 57.1454793959856, 57.73598290979862, 54.32403579354286, 59.57549840211868, 53.16475600004196, 52.44169659912586, 50.57986110448837, 51.210927441716194, 43.326206132769585, 45.24479158222675, 51.4397169649601, 56.52030274271965, 57.58473202586174, 53.042064383625984, 51.81536480784416, 50.38474157452583, 49.513657316565514, 52.69411325454712, 54.28313098847866, 54.509690031409264, 55.133407562971115, 56.12900733947754, 58.25635738670826, 60.367299914360046, 60.72928749024868, 60.491226464509964, 59.23295818269253, 59.67011332511902, 58.81233975291252, 58.45103994011879, 52.814110815525055, 49.81352582573891, 53.57402823865414, 56.4304755628109, 52.03417606651783, 48.57095830142498, 47.339926958084106, 47.520888447761536, 44.56973500549793, 46.27980284392834, 47.88685441017151, 51.14513397216797, 52.635934576392174, 51.78552120923996, 53.07768367230892, 51.40689052641392, 50.91068275272846, 50.404276326298714, 52.697848454117775, 51.82635001838207, 53.58835346996784, 53.24070632457733, 54.710668846964836, 54.92832876741886, 56.88878417015076, 57.27786809206009, 57.02614299952984, 57.502276450395584, 62.554409354925156, 60.343296602368355, 65.72299093008041, 64.9595358967781, 71.95956587791443, 73.4465628862381, 81.68866261839867, 79.24550771713257, 93.80970820784569, 29.576898515224457, 1.2458851025439799, 13.00281772390008, 82.93884113430977, 66.39825269579887, 57.96101063489914, 52.90371760725975, 42.08594128489494, 46.09440699219704, 18.27877476811409, 0.3011591039830819, 0.07920317264506593, 0.14926216565072536, 0.04534626204986125, 0.0786763739597518, 0.04769185688928701, 0.12787305400706828, 0.01955683808773756, 0.12565354263642803, 0.13997081812703982, 0.16806374973384663, 0.23364143242361024, 0.23234188731294125, 0.2030455632484518, 0.46638219442684203, 0.554637179011479, 17.54299934953451, 83.44458639621735, 47.08168141543865, 35.72509400546551, 54.763182029128075, 73.67085725069046, 86.68137431144714, 82.29490488767624, 6.27810244448483, 0.5959850759245455, 1.2147494545206428, 0.667387816356495, 48.01927350461483, 90.24553745985031, 79.01793032884598, 84.6156607568264, 76.26500084996223, 74.50655400753021, 71.70823976397514, 70.49680396914482, 65.01233026385307, 63.80739212036133, 60.5090057104826, 58.8069174438715, 60.0674732029438, 60.75612924993038, 59.20023813843727, 61.620468869805336, 59.607853665947914, 56.24728739261627, 59.944052025675774, 59.008363634347916, 61.481704115867615, 54.8288881033659, 58.5390318185091, 54.258686900138855, 55.06398148834705, 56.578652411699295, 53.869116604328156, 50.7687109708786, 49.49299782514572, 53.898941203951836, 54.720358327031136, 53.06023120880127, 53.2776403427124, 56.40035457909107, 66.36464729905128, 77.217678129673, 59.4273367524147, 58.35009455680847, 62.90796898305416, 62.419942170381546, 66.5261310338974, 64.49083864688873, 65.40186256170273, 68.41070830821991, 66.48443207144737, 64.35452476143837, 57.933427914977074, 61.1934781819582, 60.125032514333725, 60.89065343141556, 61.11963674426079, 57.749168202281, 59.51217859983444, 60.016787722706795, 55.760142132639885, 51.371465027332306, 48.4678166359663, 44.369565546512604, 50.76010823249817, 52.27610908448696, 52.455470860004425, 54.108328968286514, 57.1658881008625, 57.752766609191895, 60.73067061603069, 59.40396040678024, 62.574362084269524, 65.09006649255753, 53.93527865409851, 49.23952102661133, 67.19535872340202, 58.79974342882633, 61.86237528920174, 56.08934126794338, 63.50305885076523, 56.21006838977337, 56.786524057388306, 52.63628035783768, 52.66398847103119, 44.43822406232357, 47.30083845555782, 51.223455369472504, 59.305492490530014, 62.52987027168274, 55.33539332449436, 55.49148514866829, 51.967113465070724, 51.590671464800835, 55.17881512641907, 58.110798597335815, 57.43102267384529, 56.9610220938921, 57.600926756858826, 59.7272964566946, 62.03938119113445, 61.224465519189835, 63.10038685798645, 60.558646246790886, 62.76793509721756, 59.87372539937496, 61.10587768256664, 54.612584710121155, 52.83546566963196, 54.85561966896057, 60.45297011733055, 53.250931575894356, 50.940955728292465, 49.21361781656742, 50.67307390272617, 48.105836659669876, 50.09464234113693, 50.13731025159359, 54.89799119532108, 54.74686570465565, 56.83057889342308, 55.24351045489311, 55.68441979587078, 52.7936565130949, 54.688466638326645, 54.758268892765045, 55.68163834512234, 55.491412952542305, 56.686201840639114, 57.75558225810528, 58.14695745706558, 59.97636169195175, 60.31643584370613, 61.68591655790806, 61.648233979940414, 65.37318930029869, 62.27066718041897, 67.82127633690834, 71.41775295138359, 75.50428166985512, 76.9538126885891, 83.29485923051834, 81.12827628850937, 96.1409743130207, 31.63314487785101, 1.60895811393857, 15.065458193421364, 88.8999916613102, 76.18946850299835, 66.3048005104065, 64.25450652837753, 49.67894844710827, 61.75572261214256, 29.008183032274246, 0.4851114784833044, 0.1886723149800673, 0.2590233430964872, 0.16297185968142003, 0.18671552388696, 0.1532160909846425, 0.265693380497396, 0.22031927306670696], [0.007359214287134819, 0.10479310731170699, 0.00923253510336508, 0.03949555197323207, 0.01352813131234143, 0.12225812053657137, 0.16879135131603107, 0.32679772353731096, 4.983304347842932, 57.9258169233799, 46.11508168280125, 32.85717889666557, 31.69228870421648, 59.50600393116474, 68.41127827763557, 74.63896930217743, 7.145694689825177, 0.5357019044458866, 0.31404741865117103, 0.25322942587081343, 52.25068844854832, 81.26119315624237, 70.21908447146416, 73.02435234189034, 68.03488567471504, 66.30376696586609, 63.403044417500496, 57.09984004497528, 56.30358137190342, 54.53927144408226, 54.06881868839264, 50.75305201113224, 52.97598972916603, 54.120590910315514, 52.04372115433216, 54.52014707028866, 55.68974331021309, 54.617326855659485, 54.08632814884186, 52.63735570013523, 53.02479051053524, 53.16595293581486, 52.802688628435135, 54.19474013149738, 52.01849430799484, 51.34750731289387, 48.90818640589714, 45.63872404396534, 44.34814229607582, 46.21474653482437, 47.467987686395645, 50.745330825448036, 51.26878693699837, 54.403633922338486, 62.28532299399376, 66.46784976124763, 60.482969507575035, 53.41197073459625, 57.44838014245033, 55.72521820664406, 56.1213431507349, 55.368067771196365, 59.38517801463604, 64.16480094194412, 61.443519964814186, 57.217607125639915, 44.73445616662502, 49.143690168857574, 52.85474583506584, 54.1301853954792, 58.56047786772251, 56.631252989172935, 46.53846636414528, 53.41851778328419, 60.962819159030914, 42.437012046575546, 37.71959938108921, 41.95378437638283, 48.225442841649055, 44.72179524600506, 48.51707339286804, 50.85049398243427, 51.15405589342117, 54.91206184029579, 53.13161037862301, 54.55197796225548, 56.42063029110432, 56.57888039946556, 56.098449379205704, 53.95631432533264, 56.94955050945282, 56.80211082100868, 52.404602989554405, 52.02013581991196, 54.894742369651794, 52.199364602565765, 48.56930159032345, 47.25316621363163, 46.49506129324436, 43.194835782051086, 45.547669529914856, 52.984774857759476, 57.43110626935959, 54.29718643426895, 56.56171292066574, 48.54976303875446, 50.26435263454914, 50.45952536165714, 50.89448422193527, 53.23495723307133, 55.53022027015686, 54.83328066766262, 55.2820859849453, 56.85391344130039, 57.40953102707863, 55.73888227343559, 55.19264258444309, 55.86744837462902, 58.34208458662033, 56.84430755674839, 57.82539211213589, 53.2284177839756, 46.734072268009186, 49.48922082781792, 52.59286388754845, 46.38677470386028, 45.64253903925419, 44.92470055818558, 42.943513467907906, 42.53510758280754, 43.52373093366623, 43.26051525771618, 49.14470471441746, 48.67056995630264, 48.829659819602966, 48.779065534472466, 49.68413896858692, 50.7644210010767, 51.06302037835121, 50.091317519545555, 51.76818273961544, 50.510051250457764, 50.1102215051651, 52.807164788246155, 51.991964131593704, 51.61321185529232, 52.185464948415756, 54.375960007309914, 55.36928750574589, 56.13769747316837, 56.855896934866905, 59.50796462595463, 59.44347828626633, 65.03682374954224, 68.21339249610901, 78.61442998051643, 74.0102170407772, 83.07522341609001, 27.660739235579967, 1.0114655876532197, 9.907705206423998, 75.20530611276627, 62.246815860271454, 47.87323594093323, 43.872206434607506, 23.9151244238019, 30.52787348628044, 13.234303202480078, 0.15656570030841976, 0.0543314365495462, 0.03062600408156868, 0.052296760768513195, 0.03215618271497078, 0.028832105126639362, 0.04541392365354113, 0.022775818288209848, 0.005587731438936316, 0.06351464573526755, 0.0412185813911492, 0.05706155665393453, 0.022236571930989157, 0.09284388404921629, 0.17064590414520353, 0.5592672899365425, 5.3401626739650965, 69.3555960059166, 50.48552356660366, 30.131224170327187, 39.69062961637974, 66.46197527647018, 75.5991929769516, 83.08462411165237, 8.024854939430952, 0.5887566762976348, 0.5978516663890332, 0.2546238322975114, 54.799515679478645, 88.0459950864315, 77.48383864760399, 80.94118192791939, 71.70218288898468, 68.59132781624794, 67.57172092795372, 62.410423681139946, 61.79166108369827, 57.710037901997566, 57.03427456319332, 56.1450956761837, 57.00250446796417, 56.1822272837162, 55.68012222647667, 57.44511991739273, 58.755308613181114, 57.58137680590153, 56.91625289618969, 56.5346659719944, 54.657863080501556, 55.387249141931534, 54.3857254832983, 55.92611722648144, 54.34601381421089, 52.954650074243546, 51.89368240535259, 46.46084412932396, 46.80309936404228, 49.26499865949154, 48.20591188967228, 51.432957127690315, 53.1495226174593, 54.72098909318447, 63.77265438437462, 68.78238156437874, 61.45006321370602, 54.21571120619774, 58.62628273665905, 56.786189675331116, 57.58458003401756, 57.34717257320881, 60.91078855097294, 66.25494718551636, 63.88264328241348, 56.75557851791382, 47.85470053553581, 51.057628467679024, 53.821216374635696, 55.93593589961529, 59.292451590299606, 56.79647572338581, 48.76373715698719, 53.485599383711815, 58.66720654070377, 46.082692220807076, 41.64890393614769, 43.242409229278564, 52.422705218195915, 46.951299011707306, 50.914243161678314, 53.13912257552147, 55.52130214869976, 54.70233969390392, 56.16582736372948, 57.60995887219906, 56.76998734474182, 58.891295716166496, 56.7984402179718, 55.72562478482723, 60.48551917076111, 59.086464643478394, 54.41532589495182, 54.098871275782585, 56.81098334491253, 52.743313014507294, 51.05181097984314, 49.886687099933624, 49.09683108329773, 46.24007597565651, 50.664919540286064, 51.79102711379528, 56.032241731882095, 55.52125655114651, 58.105490282177925, 51.89732261002064, 54.065239280462265, 53.63938093185425, 53.5552192479372, 55.59852920472622, 57.179799154400826, 55.169285237789154, 57.34774634242058, 59.571615010499954, 58.298413529992104, 58.416701182723045, 56.73828944563866, 58.32347318530083, 61.00071832537651, 58.203760609030724, 60.952031537890434, 54.33861941099167, 49.10990998148918, 50.86309030652046, 55.64702980220318, 51.477049961686134, 48.47885504364967, 46.448749378323555, 46.78174450993538, 44.753785729408264, 45.47017648816109, 46.11938685178757, 50.37393495440483, 50.55849865078926, 50.5355516821146, 50.0578261166811, 50.55268116295338, 53.15953128039837, 52.53815442323685, 53.12650725245476, 53.932983577251434, 54.33611914515495, 53.67583617568016, 56.411529779434204, 54.065547063946724, 53.753477409482, 56.200701892375946, 56.30801573395729, 58.74030701816082, 60.254962742328644, 60.07851541042328, 62.8913638740778, 62.10577882826328, 67.72732257843018, 72.1429592370987, 84.46433767676353, 79.06876400113106, 90.65878808498383, 31.76078762859106, 1.1776626133359969, 11.31428997963667, 82.13323876261711, 68.88170823454857, 54.46737930178642, 50.25344721972942, 28.268415927886963, 43.38289149105549, 24.29125864058733, 0.34521836321800947, 0.05912380693189334, 0.11551837320439517, 0.019120880133414175, 0.02175638383050682, 0.022588561441807542, 0.01972086014575325, 0.047468429620494135, 0.20917942863889039, 0.25812938169110566, 0.14680078835226595, 0.26548050285782665, 0.15969719243003055, 0.20778318168595433, 0.3121478174580261, 0.6150513247121125, 11.33956242352724, 83.10352429747581, 60.75962506234646, 46.14239081740379, 46.909444257617, 77.87385731935501, 80.70621013641357, 89.49339061975479, 9.396092109382153, 0.8672868961002678, 0.8759120770264417, 0.3539577458286658, 58.0540182441473, 92.56105720996857, 80.68049311637878, 82.14596047997475, 73.55627819895744, 71.09057530760765, 71.71896278858185, 62.64724597334862, 64.79192689061165, 60.45505240559578, 62.07835949957371, 58.56208898127079, 60.73592193424702, 59.93533909320831, 57.4021290242672, 59.71012517809868, 62.258025258779526, 60.107538253068924, 58.64142492413521, 57.655970603227615, 58.02106261253357, 58.831217139959335, 58.25012192130089, 59.07336674630642, 57.78687737882137, 55.92531926929951, 53.17810468375683, 48.32416154444218, 49.35561239719391, 52.220502868294716, 50.38049340248108, 55.663148537278175, 55.30141554772854, 58.24103660881519, 63.58799569308758, 71.85779973864555, 62.11346201598644, 56.034779995679855, 61.52383625507355, 58.85857567191124, 60.78199066221714, 57.51728184521198, 64.15900245308876, 68.16734656691551, 67.65834107995033, 60.22954970598221, 46.38500779867172, 52.73145765066147, 57.358727753162384, 57.467599511146545, 60.501672104001045, 60.8467011898756, 50.39849303662777, 53.787428587675095, 59.93006497621536, 51.37089505791664, 42.08037078380585, 43.686449602246284, 52.59096398949623, 51.09059929847717, 54.50717456638813, 56.5924608707428, 58.03214281797409, 60.25005340576172, 58.25589761137962, 61.51903711259365, 60.512854903936386, 62.26575404405594, 57.903690710663795, 56.54600456357002, 63.362303003668785, 60.53031496703625, 57.57233329117298, 56.249107494950294, 60.927583649754524, 56.849577873945236, 52.53357946872711, 53.165572956204414, 50.25750160217285, 50.45428924262524, 53.282340690493584, 52.79573880136013, 55.51385834813118, 60.32154656946659, 62.15090520679951, 52.27907292544842, 56.49006396532059, 56.24620825052261, 57.29311667382717, 59.37626749277115, 61.59757889807224, 58.43228034675121, 60.72071135044098, 62.74118833243847, 62.272422686219215, 59.44617994129658, 59.10604879260063, 61.073936596512794, 64.40494045615196, 62.524250373244286, 63.426557555794716, 55.74352942407131, 49.60517920553684, 51.564490869641304, 58.564220666885376, 53.382301926612854, 51.7086361348629, 49.51756730675697, 48.840025663375854, 47.4646932631731, 48.63601841032505, 45.53877420723438, 55.416389778256416, 54.160568565130234, 54.56670977175236, 53.85370083153248, 54.27627995610237, 55.82117445766926, 56.48457705974579, 54.99285690486431, 58.900692611932755, 56.24080494046211, 57.004050984978676, 58.510092571377754, 58.31638276576996, 56.756794452667236, 60.910245180130005, 59.04807910323143, 62.119982466101646, 65.04299461841583, 62.319190576672554, 66.41057163476944, 66.37364521622658, 71.31496086716652, 74.41299542784691, 86.81961849331856, 81.94155424833298, 93.90871569514275, 34.46312092244625, 1.5426787454634905, 13.27285498380661, 88.28740373253822, 77.59097769856453, 62.27089136838913, 65.82258358597755, 38.89288142323494, 60.252743661403656, 35.36740019917488, 0.46095540281385183, 0.1705282588955015, 0.15328574896557257, 0.1376079089823179, 0.15242831606883556, 0.11191102341399528, 0.17647206026595086, 0.15013626718427986], [0.06740384094882756, 0.10191405672230758, 0.049818904080893844, 0.061759689124301076, 0.12340159199084155, 0.09133796993410215, 0.06072485324693844, 0.1970547394012101, 2.1400819765403867, 54.86071899533272, 44.69065971672535, 42.0526322722435, 52.58488431572914, 56.13916799426079, 70.82947611808777, 72.58867532014847, 7.602248741313815, 0.24443148780846968, 0.37940922542475164, 0.08056744787609205, 56.242967024445534, 79.32737052440643, 72.24879115819931, 71.81746110320091, 62.470456659793854, 63.23407508432865, 57.8498438000679, 55.92970423400402, 56.65584146976471, 53.83386589586735, 53.41672047972679, 53.34433816373348, 53.25145594775677, 54.45776581764221, 56.361801847815514, 59.525610879063606, 60.456256940960884, 60.42577497661114, 60.43516427278519, 57.063639387488365, 57.054489478468895, 57.74398148059845, 56.83834567666054, 56.859936118125916, 53.01276035606861, 49.95820306241512, 49.73429627716541, 45.97456902265549, 43.97046156227589, 45.15166997909546, 48.388902470469475, 48.4391775727272, 49.67684715986252, 50.84944523870945, 59.25441563129425, 65.73204204440117, 56.32813185453415, 51.8239751458168, 55.515268072485924, 54.312925189733505, 51.28147825598717, 49.52248424291611, 54.27800506353378, 56.77865467965603, 55.02425082027912, 47.62591481208801, 42.718398347496986, 44.99049782752991, 43.839611783623695, 59.87931489944458, 52.437110245227814, 42.31553636491299, 47.55681172013283, 56.51163920760155, 36.608079224824905, 37.64676868915558, 42.70724214613438, 42.34973073005676, 45.40173076093197, 44.70981448888779, 48.27248811721802, 51.40658274292946, 50.61123602092266, 52.31825642287731, 52.182763293385506, 54.274843633174896, 54.79387678205967, 52.32104167342186, 56.42124205827713, 58.2977257668972, 55.34119561314583, 53.31701003015041, 53.63013982772827, 51.876507326960564, 51.42681285738945, 50.0900711864233, 49.28478419780731, 48.78254994750023, 43.547247871756554, 53.22972871363163, 41.986375227570534, 42.53522917628288, 52.95599900186062, 60.39772108197212, 48.92013676464558, 55.10451391339302, 51.804630383849144, 54.02701713144779, 52.64641061425209, 53.65868389606476, 52.23598703742027, 52.50912398099899, 55.31517080962658, 56.611676439642906, 59.47919636964798, 57.28672921657562, 56.52515888214111, 57.63648144900799, 56.344797760248184, 54.81160283088684, 58.02044704556465, 59.144297540187836, 53.170505091547966, 54.25438933074474, 50.2939036488533, 47.60274365544319, 45.814031437039375, 43.20649355649948, 42.895320653915405, 42.37155295908451, 46.353659480810165, 46.42150864005089, 46.405427902936935, 48.2378301769495, 48.13678599894047, 46.25317007303238, 48.18669632077217, 49.56573732197285, 49.327809289097786, 51.17195673286915, 50.34924767911434, 49.864572286605835, 51.23836576938629, 52.89184704422951, 53.357607051730156, 51.70187629759312, 54.57248546183109, 54.60026577115059, 56.58899165689945, 56.86331033706665, 56.53524734079838, 58.12820926308632, 57.62046530842781, 62.99415975809097, 68.63701656460762, 77.19141393899918, 74.69373196363449, 82.09683671593666, 33.53211767971516, 0.5811675928998739, 9.32169210165739, 76.0561640560627, 59.247234016656876, 51.11668109893799, 40.43458789587021, 38.58792878687382, 36.768468618392944, 16.437615863978863, 0.28383149940054864, 0.04088798428711016, 0.04155698959948495, 0.03551708010490984, 0.03658441833977122, 0.0761252487427555, 0.0366445545660099, 0.10143076273379847, 0.0251767216832377, 0.08047162176808342, 0.038376181764760986, 0.07858586905058473, 0.06659434337052517, 0.10987085945089348, 0.05845189982210286, 0.2598527376540005, 2.1850459137931466, 68.6592149734497, 46.33861228823662, 34.757502526044846, 57.01113000512123, 64.83180195093155, 76.32417127490044, 82.19877764582634, 8.606545776128769, 0.17828638869104907, 0.559690254740417, 0.037426941489684395, 62.047478556632996, 85.40022745728493, 80.11143565177917, 77.62522906064987, 67.51827299594879, 66.5002392232418, 62.39514850080013, 59.317043870687485, 58.67703281342983, 55.502029582858086, 57.63316422700882, 56.78537651896477, 57.639335095882416, 56.57114401459694, 59.62728962302208, 61.23123295605183, 65.03955960273743, 64.66938346624374, 63.21363978087902, 57.79345482587814, 60.859316512942314, 61.87993034720421, 60.573815032839775, 58.270716816186905, 56.44260451197624, 51.144058629870415, 51.81672513484955, 49.92691174149513, 46.17449529469013, 46.72929972410202, 52.10878126323223, 50.75817793607712, 51.133939772844315, 51.29183650016785, 61.38006716966629, 66.17812290787697, 59.34217572212219, 52.89594702422619, 57.570228204131126, 55.41868485510349, 54.340587705373764, 50.63268966972828, 55.883084535598755, 57.51354284584522, 56.171948835253716, 52.96097673475742, 43.82279388606548, 45.06294094026089, 44.62648116052151, 60.77840745449066, 52.34852559864521, 44.27444525063038, 49.426516592502594, 55.38950242102146, 41.85319997370243, 41.158836632966995, 43.59002597630024, 43.705186396837234, 46.86876744031906, 45.95609061419964, 48.72463345527649, 53.281671926379204, 55.387480929493904, 54.258926287293434, 54.63382177054882, 54.13517452776432, 55.65706506371498, 55.30664786696434, 58.30706566572189, 58.52960832417011, 56.308353915810585, 55.771940499544144, 57.382138296961784, 55.22173002362251, 55.19653357565403, 51.708461344242096, 51.98942966759205, 49.00066964328289, 45.74732981622219, 54.99792203307152, 43.29873740673065, 44.930092468857765, 51.65377467870712, 58.60328257083893, 52.61170707643032, 56.53413400053978, 54.29667726159096, 55.27347944676876, 55.88447146117687, 57.892773896455765, 57.01238393783569, 53.018585443496704, 56.76719829440117, 57.36336350440979, 61.29345461726189, 58.399773091077805, 56.72505475580692, 58.89719299972057, 57.9096107929945, 55.47026328742504, 60.41839957237244, 60.121586099267006, 57.25741758942604, 55.39113633334637, 52.51037411391735, 49.643538147211075, 48.856360986828804, 46.26035928726196, 44.747493267059326, 45.04191666841507, 47.78800271451473, 48.85457128286362, 50.81463150680065, 50.657304748892784, 49.392542615532875, 50.62252141535282, 50.559900775551796, 51.6018732637167, 51.64142154157162, 54.90570478141308, 53.294013664126396, 54.12453129887581, 52.906062081456184, 56.716626808047295, 56.240018382668495, 55.48606663942337, 56.96060411632061, 57.92202092707157, 58.337483033537865, 59.74136710166931, 60.08589081466198, 62.00355291366577, 61.249977350234985, 70.08042991161346, 70.96547082066536, 82.21261650323868, 77.98034280538559, 86.62708282470703, 38.64950068295002, 0.5513716104906052, 9.907247330993414, 83.42998757958412, 65.24066001176834, 60.24923264980316, 51.36915475130081, 34.449403658509254, 52.50082142651081, 26.90633911639452, 0.280908060958609, 0.009145805870502954, 0.12344851798843592, 0.015226323830574984, 0.12994060321943834, 0.05700550966139417, 0.02542653415730456, 0.0610955485899467, 0.1317667169496417, 0.20524261723039672, 0.26050683693028986, 0.13061203906545416, 0.18682643043575808, 0.16850937972776592, 0.15568870439892635, 0.5096099514048547, 3.9313502702862024, 88.34276676177979, 55.44039309024811, 60.259070321917534, 70.72902470827103, 71.53342634439468, 81.71659871935844, 87.43481308221817, 9.325391203165054, 0.4992164997383952, 0.9281008515972644, 0.2126087000942789, 64.22119751572609, 87.40540266036987, 84.11857903003693, 78.98946985602379, 71.90338969230652, 68.74306127429008, 64.19276744127274, 61.583679243922234, 63.26057866215706, 58.069612607359886, 61.28547504544258, 59.06067542731762, 60.764997974038124, 59.05519612133503, 59.87953148782253, 64.28981423377991, 68.09553042054176, 66.45848706364632, 66.43744379281998, 60.13523116707802, 62.69182898104191, 62.04262241721153, 64.96572956442833, 60.18160007894039, 58.358123525977135, 52.43019841611385, 54.33087542653084, 50.56631103157997, 50.930494889616966, 51.45458176732063, 55.265610069036484, 53.98248352110386, 51.9625499099493, 52.18432880938053, 64.8036302626133, 70.25970429182053, 62.835776656866074, 53.04244436323643, 58.307479843497276, 59.46461655199528, 57.172123566269875, 52.96561248600483, 58.70743118226528, 60.88562250137329, 60.91232746839523, 54.41508650779724, 44.65303033590317, 47.53759615123272, 47.98490434885025, 61.80051080882549, 57.094725519418716, 46.833809316158295, 50.24603381752968, 58.85092668235302, 46.959479972720146, 43.36378991603851, 41.82766914367676, 44.39289249479771, 49.60014067590237, 49.358010068535805, 52.503998056054115, 56.803467348217964, 59.96487870812416, 58.021385595202446, 57.169387713074684, 59.09236192703247, 59.84436057507992, 56.06170915067196, 61.690871492028236, 63.230305686593056, 59.973793029785156, 57.080217897892, 60.29144458472729, 58.04364860057831, 58.24898198246956, 55.66648855805397, 55.03576040267944, 53.36364112794399, 46.297851875424385, 57.88823314011097, 44.27221097052097, 48.7824397534132, 54.7657734900713, 56.41585394740105, 55.438580587506294, 58.59333850443363, 57.07703746855259, 57.229705676436424, 57.2074730694294, 60.911187529563904, 61.18158861994743, 55.83302602171898, 58.25039930641651, 59.2410783469677, 63.718644082546234, 61.02099783718586, 59.40400220453739, 62.58025176823139, 62.94923856854439, 57.573803812265396, 62.202027663588524, 64.56685736775398, 59.56821799278259, 56.888670176267624, 56.50595471262932, 51.848715618252754, 51.706865429878235, 48.31354111433029, 50.37072792649269, 45.96776358783245, 49.914744794368744, 51.65767326951027, 52.66370728611946, 54.01975192129612, 52.14456394314766, 51.18542321026325, 53.78198727965355, 53.66049259901047, 54.40264977514744, 55.74773199856281, 55.7676125317812, 55.558350160717964, 56.13914519548416, 61.523456275463104, 60.01649893820286, 58.987027779221535, 60.854806154966354, 59.6808173507452, 63.105440586805344, 62.47742548584938, 64.03767496347427, 63.146087005734444, 63.693956807255745, 70.24672418832779, 76.6023163497448, 84.75240781903267, 82.62711346149445, 89.19029608368874, 38.565673381090164, 0.7345378724858165, 12.558671906590462, 88.00132468342781, 73.21944907307625, 68.0380243062973, 62.21184253692627, 60.12353539466858, 71.47674858570099, 36.66888736188412, 0.28088790422771126, 0.17204460018547252, 0.15459841524716467, 0.12497048475779593, 0.3274364158278331, 0.167982796265278, 0.14930964825907722, 0.2539576211711392], [0.049657728159218095, 0.04620884916221257, 0.04305295522499364, 0.038038460043026134, 0.02237320688436739, 0.14091674471274018, 0.04955757533025462, 0.0707544967008289, 0.5139125080313534, 48.438938185572624, 51.27446003258228, 37.6417301595211, 40.31001158058643, 55.89798353612423, 63.96355614066124, 83.1488786637783, 15.58057565242052, 0.2910732279997319, 0.37109660741407424, 0.03169801413605455, 57.75631561875343, 79.70272198319435, 75.99608168005943, 75.46218752861023, 66.53714284300804, 62.92890205979347, 60.4162222892046, 57.52771608531475, 57.67618551850319, 51.35659262537956, 53.94114933907986, 51.30684569478035, 53.62860471010208, 58.646653443574905, 60.45426964759827, 62.18869797885418, 64.43436607718468, 65.8360044658184, 64.17614713311195, 61.36859938502312, 62.13725633919239, 62.2965931892395, 62.194344475865364, 58.102659434080124, 56.41820602118969, 48.54685619473457, 50.05601741373539, 46.77973061800003, 43.882374688982964, 42.65471376478672, 47.012422531843185, 47.48569093644619, 49.385296404361725, 51.01836517453194, 55.6617122143507, 60.180874317884445, 57.9672347009182, 50.41230149567127, 56.81492753326893, 53.085971027612686, 53.513109907507896, 48.53957578539848, 52.40064740180969, 47.76932291686535, 48.598214238882065, 48.945321813225746, 41.688748598098755, 39.10470865666866, 49.72675748169422, 47.27776609361172, 38.908468186855316, 40.20587436854839, 51.37345232069492, 36.46676480770111, 33.71760092675686, 42.58244164288044, 43.73685009777546, 47.85790756344795, 47.58245274424553, 45.02017803490162, 49.474511817097664, 49.119971841573715, 50.900875478982925, 51.759458407759666, 50.548280999064445, 46.85201033949852, 50.26080742478371, 48.278153613209724, 52.257349491119385, 53.05694818496704, 52.55531430244446, 53.17426308989525, 51.34787209331989, 49.61699657142162, 51.709593683481216, 49.48474086821079, 48.32899108529091, 46.31246589124203, 46.180620566010475, 51.456375271081924, 39.001464396715164, 38.256890550255775, 34.96828481554985, 51.36778682470322, 62.26636581122875, 47.17580236494541, 52.47180238366127, 51.72831907868385, 52.36294582486153, 51.72856606543064, 56.72240249812603, 53.15193168818951, 48.9516294747591, 49.11663182079792, 56.492317244410515, 55.09801246225834, 55.960596576333046, 54.52680051326752, 54.487738609313965, 49.00468982756138, 60.54173335433006, 53.88491615653038, 52.48268499970436, 54.615449756383896, 50.13478338718414, 45.463306456804276, 45.256532952189445, 43.573318272829056, 43.1220430880785, 43.75810995697975, 44.01672028005123, 46.33541285991669, 48.40164698660374, 48.554968759417534, 50.96914641559124, 50.647554472088814, 50.553254932165146, 51.16524629294872, 51.041422337293625, 51.23394660651684, 53.49663779139519, 52.14069955050945, 55.144031792879105, 56.769485771656036, 55.0038231164217, 55.050769597291946, 54.26194332540035, 54.470966309309006, 56.606333926320076, 57.540984973311424, 57.31231324374676, 59.23296198248863, 60.296870693564415, 61.92883752286434, 64.55548077821732, 71.87942817807198, 74.59988459944725, 80.79238191246986, 43.193304464221, 0.26535047858487815, 7.872263202443719, 81.35041236877441, 50.939025431871414, 47.53589764237404, 44.27591197192669, 31.23748730868101, 36.25804960727692, 15.334845688194036, 0.31320929643698037, 0.06806537654483691, 0.06417776210582815, 0.036647853412432596, 0.08091227937256917, 0.08223972181440331, 0.08421055434155278, 0.02273253438033862, 0.09044314021593891, 0.04104767220269423, 0.05532173985557165, 0.055292929682764225, 0.028602362181118224, 0.08470099521218799, 0.046922001129132695, 0.08286838768981397, 0.4913272027624771, 57.354905158281326, 52.82652094960213, 38.97022247314453, 55.346697717905045, 63.732657730579376, 72.65132635831833, 90.80733731389046, 17.26063460111618, 0.28761479014065117, 0.2844375668792054, 0.08495559639413841, 61.59602478146553, 85.45729279518127, 80.52964121103287, 79.10306096076965, 71.13768517971039, 66.8428972363472, 63.5954736918211, 61.89239747822285, 61.3335120677948, 55.09379468858242, 57.654606476426125, 55.55973708629608, 55.76128587126732, 62.26806052029133, 64.11799505352974, 63.42471085488796, 66.0832267999649, 69.61258381605148, 68.28615859150887, 64.52395007014275, 63.57183896005154, 63.925238996744156, 65.18521338701248, 60.1960127055645, 59.140524342656136, 50.8818195015192, 53.1547549366951, 49.468029364943504, 47.01247952878475, 46.00248232483864, 49.04774911701679, 50.64640313386917, 50.54196573793888, 52.90377840399742, 57.10262529551983, 62.88861282169819, 60.470536574721336, 55.16969561576843, 60.22941291332245, 54.36270631849766, 54.88776594400406, 51.177648827433586, 54.77268911898136, 49.939261078834534, 51.05172738432884, 49.810839369893074, 42.58785255253315, 41.77609071135521, 48.8007053732872, 48.329526856541634, 42.299858406186104, 42.76915602385998, 50.35989850759506, 38.613155633211136, 39.18360762298107, 43.785707876086235, 42.47724428772926, 48.10316540300846, 50.009363517165184, 45.17250806093216, 53.14015991985798, 50.75785495340824, 51.31746232509613, 52.95466147363186, 51.75036929547787, 48.88378791511059, 54.69204984605312, 48.845128789544106, 54.078462570905685, 55.577721521258354, 53.965099453926086, 54.280664920806885, 51.47658258676529, 52.35636077821255, 55.681448355317116, 51.64589770138264, 50.774235874414444, 48.59511360526085, 48.49925234913826, 52.15709947049618, 40.88953748345375, 39.536540284752846, 42.21861116588116, 46.886539086699486, 61.71415664255619, 49.40870314836502, 55.387910306453705, 54.46155421435833, 56.01142264902592, 52.93513052165508, 56.53317265212536, 54.13058817386627, 49.40979368984699, 50.74170961976051, 58.89982245862484, 55.6750874966383, 55.905336141586304, 55.69708451628685, 55.09412907063961, 51.55714966356754, 62.55186729133129, 56.7231472581625, 56.49957485496998, 57.20459662377834, 52.64242082834244, 49.49370078742504, 47.85728819668293, 47.92974270880222, 44.92824576795101, 46.3798438757658, 48.5040020942688, 47.54399120807648, 50.974431931972504, 52.196362763643265, 54.431220442056656, 54.7251270711422, 54.13780778646469, 53.48360829055309, 53.4264175593853, 54.989490285515785, 56.77338816225529, 56.348073184490204, 59.29358012974262, 58.55071999132633, 58.485473692417145, 59.205660447478294, 57.92073279619217, 57.606911435723305, 60.067055225372314, 61.209862902760506, 60.29305949807167, 64.16970267891884, 64.45322826504707, 64.9368967115879, 67.81853288412094, 76.01164564490318, 78.24133560061455, 86.77912026643753, 48.48761357367039, 0.3290292725432664, 9.451051410287619, 87.16201812028885, 58.6452779173851, 55.98603241145611, 51.9429087638855, 36.83185301721096, 49.58948604762554, 26.418226808309555, 0.382281158817932, 0.00554521519006812, 0.042329691495979205, 0.07463637433829717, 0.05976831766020041, 0.08945519322878681, 0.036815960993408225, 0.03862619647406973, 0.21249421639367938, 0.1625630253693089, 0.15988595027010888, 0.09983387615648098, 0.2033144433517009, 0.25979767029639333, 0.18958975793793797, 0.25984810665249825, 1.9360502623021603, 72.95165464282036, 66.29660055041313, 51.44441731274128, 54.508686885237694, 74.6421231329441, 78.8015167415142, 98.12232479453087, 18.268085941672325, 0.5534971808083355, 0.5239350639749318, 0.15059289580676705, 65.28339251875877, 87.962726354599, 85.51839351654053, 79.69116300344467, 73.91661286354065, 66.68146669864655, 65.12567058205605, 64.11335170269012, 64.39003005623817, 54.834758788347244, 59.999715238809586, 56.33086770772934, 58.33666227757931, 64.95530292391777, 66.96395114064217, 63.89943078160286, 71.20204612612724, 72.0747072994709, 69.6135413646698, 66.0458368062973, 66.86027750372887, 67.24333494901657, 67.27415129542351, 62.48064011335373, 65.08812859654427, 51.99609450995922, 56.58418111503124, 50.30120685696602, 49.436430260539055, 47.58213736116886, 50.360947251319885, 53.695982694625854, 52.82218158245087, 55.40516898036003, 59.42506067454815, 64.72866788506508, 62.627863213419914, 60.040737837553024, 58.955770656466484, 57.1260966360569, 56.818233355879784, 53.50130774080753, 57.397367879748344, 52.887112498283386, 54.89332124590874, 51.97417348623276, 44.827832356095314, 42.87092596292496, 50.54494097828865, 51.10248506069183, 44.929055124521255, 42.02044419944286, 54.338684007525444, 46.13545618951321, 43.33801589906216, 45.00141464173794, 43.72043877840042, 50.13252630829811, 54.349600821733475, 50.96651315689087, 55.42010597884655, 57.27045089006424, 56.18746720254421, 56.09919033944607, 56.81912250816822, 52.20218785107136, 56.48114964365959, 53.44757102429867, 56.598890125751495, 58.015545308589935, 58.1324802339077, 57.33014948666096, 56.690507009625435, 52.896801978349686, 56.77599862217903, 54.18488346040249, 53.744099512696266, 52.19657555222511, 52.409979701042175, 55.13900466263294, 41.30734406411648, 43.69936890900135, 44.68416206538677, 54.987620785832405, 58.05078461766243, 52.40788221359253, 58.25626619160175, 57.379326447844505, 57.25589007139206, 56.04706473648548, 60.30750252306461, 57.172545343637466, 53.3796800673008, 55.58334521949291, 61.763280406594276, 58.868021965026855, 59.03548277914524, 59.40873295068741, 57.27450907230377, 53.389008566737175, 63.945560306310654, 60.33165782690048, 58.37141901254654, 58.45346421003342, 54.872600957751274, 51.64416119456291, 49.69883657991886, 50.57299107313156, 48.2134734839201, 49.429047256708145, 50.7286611199379, 51.00848190486431, 53.4893611818552, 55.882073789834976, 58.04424896836281, 57.34040513634682, 55.538310036063194, 56.3914630562067, 55.93849316239357, 57.32817739248276, 60.12328460812569, 57.75185465812683, 62.10465028882027, 62.22865283489227, 61.83212511241436, 61.738942712545395, 60.60205511748791, 59.07637618482113, 62.52988547086716, 63.02475571632385, 62.36449554562569, 67.7025631070137, 68.08145597577095, 69.27807256579399, 70.65904006361961, 78.63288179039955, 80.89259013533592, 88.47264379262924, 51.21807485818863, 0.40923017368186265, 10.826045628637075, 95.31314313411713, 64.99872699379921, 66.14836290478706, 61.50271698832512, 50.07656291127205, 69.59907174110413, 37.301975190639496, 0.5195232632104307, 0.10547530429903418, 0.1829055158304982, 0.11315508556435816, 0.29074519872665405, 0.2195725537603721, 0.10757509982795455, 0.13222224719356745], [0.07290358567843214, 0.07270987029187381, 0.020851698391197715, 0.050874375374405645, 0.0014132734440863715, 0.14234054018743336, 0.003356399279255129, 0.009711470829643076, 0.2252882783068344, 36.061231568455696, 53.981803357601166, 27.9046443477273, 25.922767594456673, 57.28042155504227, 61.536611169576645, 78.84539678692818, 28.877110965549946, 0.15355736017227173, 0.2171880184323527, 0.7840016589034349, 55.74058838188648, 74.35522332787514, 75.83906650543213, 75.9195613861084, 65.68544134497643, 62.706644386053085, 62.34742686152458, 57.117148116230965, 56.41809582710266, 55.4619113355875, 53.85887235403061, 53.00404742360115, 57.00376980006695, 60.50740219652653, 65.90301766991615, 66.47829920053482, 70.68876966834068, 70.47242447733879, 67.5560961663723, 64.4662843644619, 65.80862313508987, 63.86803686618805, 65.2675473690033, 64.26912054419518, 55.76066270470619, 50.13010583817959, 49.320141300559044, 49.54933740198612, 45.636919140815735, 41.22727856040001, 46.336089223623276, 48.516286835074425, 48.950835317373276, 51.097142547369, 58.716695085167885, 57.131606340408325, 60.53508751094341, 49.028533548116684, 51.15900322794914, 55.453175604343414, 48.774323388934135, 46.69786021113396, 47.607136219739914, 44.894883558154106, 49.00657072663307, 45.18091320991516, 44.32087875902653, 46.30630262196064, 41.931787356734276, 45.29990382492542, 36.8721878528595, 45.14763079583645, 36.94415979087353, 32.619098871946335, 40.947955548763275, 42.831563875079155, 48.568089455366135, 48.458662927150726, 46.25321947038174, 41.647809594869614, 50.3379812836647, 46.88628830015659, 52.82391048967838, 49.137800484895706, 48.06114725768566, 48.434249237179756, 48.12680013477802, 45.988278687000275, 48.945998176932335, 48.0441127717495, 46.24960586428642, 48.00809070467949, 47.907920479774475, 45.193813517689705, 51.05202376842499, 49.88805502653122, 49.36785914003849, 47.200254052877426, 44.81180861592293, 47.18304857611656, 47.688926830887794, 35.142038092017174, 37.15087629854679, 33.25099356472492, 49.40233089029789, 61.83449238538742, 47.17911958694458, 46.828200817108154, 52.52909950911999, 52.7299415320158, 51.334967985749245, 48.16677778959274, 45.34443363547325, 40.81570364534855, 51.65871441364288, 53.31944949924946, 52.579948380589485, 51.168058142066, 50.78112490475178, 47.639525681734085, 57.94912487268448, 50.497386530041695, 56.75531633198261, 52.81468078494072, 47.37779572606087, 46.93583384156227, 45.23421294987202, 43.09582829475403, 42.20796413719654, 43.55371132493019, 44.96650971472263, 48.41453589498997, 48.895723074674606, 52.36897990107536, 49.32071506977081, 52.6655387878418, 52.00529381632805, 52.310911417007446, 53.557803109288216, 52.48844549059868, 53.29936757683754, 57.25092373788357, 56.43886171281338, 57.236214727163315, 61.48910611867905, 60.42921759188175, 60.57997450232506, 58.99899333715439, 59.0818402916193, 61.59105084836483, 62.510536909103394, 65.93489035964012, 63.81857872009277, 66.42044350504875, 67.11359471082687, 70.85826337337494, 69.39870849251747, 81.63377836346626, 53.10181997716427, 0.12058669264661148, 8.885389063507318, 80.11232480406761, 57.98345983028412, 48.15426126122475, 45.72457283735275, 23.908945955336094, 36.83543622493744, 19.241164326667786, 0.39299495110753924, 0.03025357025762787, 0.0617215946840588, 0.10136036260519177, 0.03774337099457625, 0.026579972654872108, 0.08193115165340714, 0.04706933970737737, 0.011708049387380015, 0.05769447874627076, 0.037142561632208526, 0.07077664238750003, 0.02188226135331206, 0.04622837877832353, 0.05371758023102302, 0.01965405943337828, 0.17977121839066967, 41.66523925960064, 59.10617038607597, 35.040568336844444, 40.025881826877594, 67.44088634848595, 67.58967876434326, 88.62917259335518, 31.786664240062237, 0.07292787617188878, 0.39530629583168775, 0.9884448791854084, 61.61981150507927, 80.1986637711525, 81.26476496458054, 77.78728276491165, 69.38817545771599, 66.01191222667694, 66.0155600309372, 62.319680750370026, 59.920299500226974, 57.64876998960972, 58.14250409603119, 57.00993686914444, 61.35168269276619, 63.64749290049076, 68.03062230348587, 69.92168202996254, 73.54734867811203, 70.56767776608467, 70.39707452058792, 68.0977115035057, 68.01163852214813, 65.5621987581253, 68.92793655395508, 67.19426438212395, 59.34180714190006, 52.221479415893555, 51.67789578437805, 51.82596243917942, 48.32168787717819, 45.12946777045727, 49.13399688899517, 51.418696492910385, 51.61774501204491, 52.88923278450966, 60.953095480799675, 60.64731068909168, 62.58009597659111, 52.395855858922005, 53.388100415468216, 55.47820866107941, 50.406996980309486, 48.974880427122116, 50.07013365626335, 48.67972746491432, 50.765078365802765, 49.46398638188839, 43.42608757317066, 47.27936200797558, 43.23647394776344, 44.666132032871246, 39.76917140185833, 47.74720050394535, 40.49574561417103, 36.9932721555233, 44.71570797264576, 42.837206572294235, 50.599483251571655, 50.23985154926777, 49.1231294721365, 44.75690536201, 52.13112026453018, 49.659428894519806, 54.46702592074871, 51.870556846261024, 50.543683245778084, 49.44853261113167, 50.28110593557358, 47.24299035966396, 51.778544783592224, 49.44077342748642, 48.35271701216698, 51.08787104487419, 48.40665131807327, 49.75927993655205, 53.564593344926834, 50.9102837741375, 52.10633799433708, 48.438869789242744, 45.2872809022665, 49.703624323010445, 48.669893592596054, 37.29342944920063, 39.95868623256683, 39.20183524489403, 48.58379401266575, 58.25072228908539, 49.33249443769455, 48.708963096141815, 57.044097036123276, 53.912472277879715, 53.98583874106407, 50.5262915790081, 48.0806440114975, 44.288299307227135, 53.531253933906555, 54.734626561403275, 54.64746303856373, 51.748978570103645, 50.040955021977425, 49.8718298971653, 60.08871026337147, 56.070194095373154, 60.649696961045265, 56.057221591472626, 50.93894183635712, 48.78017507493496, 46.040518283843994, 46.41826741397381, 45.12896619737148, 46.85449160635471, 47.910629734396935, 51.20252229273319, 51.34403809905052, 54.14975434541702, 52.961132526397705, 56.12763561308384, 54.685818180441856, 56.39856867492199, 55.38321375846863, 55.71869395673275, 55.398903116583824, 60.584473460912704, 60.41721023619175, 62.24377602338791, 63.96141305565834, 65.0363601744175, 62.96303562819958, 63.77212241292, 60.78265182673931, 66.75882294774055, 64.3915955722332, 70.74408710002899, 69.22227635979652, 70.83418786525726, 72.16991499066353, 74.4156476855278, 73.72051298618317, 86.83196023106575, 61.803839430212975, 0.08236754933022894, 10.43411660939455, 87.96559900045395, 61.429703906178474, 59.417563676834106, 54.76204589009285, 35.85737630724907, 52.28156939148903, 31.206532269716263, 0.3501863294513896, 0.01160819805591018, 0.04814995867491234, 0.09169267199467868, 0.057923572312574834, 0.017641108170209918, 0.042025963848573156, 0.04037286700622644, 0.10860395399504341, 0.11563749532797374, 0.17577822640305385, 0.1721641601761803, 0.09145536285359412, 0.2262093874742277, 0.12780093209585175, 0.2016733618802391, 0.5665947217494249, 61.24292492866516, 67.87309035658836, 39.19933117926121, 36.80365093052387, 78.82660299539566, 72.78651550412178, 93.86819466948509, 31.797250472009182, 0.23075210308888927, 0.5134361085947603, 1.3285217620432377, 65.6478613615036, 82.444768846035, 83.68015855550766, 80.37477672100067, 69.91497918963432, 68.02015766501427, 67.79758840799332, 63.55298437178135, 62.31535278260708, 61.55058301985264, 61.77208453416824, 59.011449068784714, 63.84634003043175, 66.87054455280304, 70.39545580744743, 72.43019342422485, 75.23984625935555, 72.72628873586655, 70.5880218744278, 67.67141997814178, 69.38800066709518, 68.4849563241005, 70.61781987547874, 70.04283472895622, 62.155928537249565, 56.20587341487408, 53.795575350522995, 54.962409138679504, 50.834356248378754, 46.125774309039116, 51.844368651509285, 52.04617202281952, 54.51183691620827, 54.71443444490433, 64.7577591240406, 61.73582687973976, 69.10455107688904, 57.35636427998543, 59.41123701632023, 56.194356232881546, 52.294762283563614, 50.627567544579506, 52.98260897397995, 53.02222564816475, 55.38167484104633, 52.26059451699257, 51.89822696149349, 47.96672612428665, 47.28297561407089, 49.784009009599686, 41.39952331781387, 52.08951249718666, 47.82775238156319, 43.244818300008774, 47.57999807596207, 45.23405335843563, 52.63810805976391, 56.197931841015816, 51.24232515692711, 48.60817730426788, 57.6180562376976, 52.82622456550598, 59.48736973106861, 55.92974603176117, 52.864617705345154, 55.13538345694542, 53.81561927497387, 50.80042786896229, 56.37304164469242, 52.82659314572811, 51.78523242473602, 53.88431578874588, 50.6785874068737, 50.735751539468765, 55.34393146634102, 53.274076133966446, 54.21137563884258, 52.72898778319359, 49.980336874723434, 51.37102425098419, 49.61994141340256, 37.733400240540504, 44.07310925424099, 44.40062887966633, 59.42239701747894, 57.171078622341156, 50.23100942373276, 51.927059814333916, 57.8517284989357, 57.33940199017525, 54.629622995853424, 53.43392975628376, 49.9009857326746, 46.018240079283714, 55.30990049242973, 56.95715010166168, 56.671831011772156, 55.39606086909771, 55.764952674508095, 50.73711186647415, 60.318677723407745, 58.66631738841534, 62.96430476009846, 56.74121908843517, 54.24525462090969, 49.72440920770168, 49.60922218859196, 48.29692080616951, 47.1492075920105, 48.592810928821564, 50.01456543803215, 53.07875141501427, 55.87401822209358, 59.222759529948235, 55.51293879747391, 58.16198565065861, 56.72656707465649, 59.99880328774452, 58.67224507033825, 58.82481448352337, 58.14315006136894, 63.13358187675476, 62.9195811599493, 62.3780570179224, 67.81191363930702, 67.21226021647453, 65.86955666542053, 65.74002161622047, 63.93434330821037, 68.84050324559212, 68.8688725233078, 72.4907773733139, 71.79324120283127, 73.10129821300507, 74.25027295947075, 76.92245677113533, 77.07800522446632, 88.2287272810936, 65.90375483036041, 0.20910874649416655, 12.402501236647367, 96.12458199262619, 69.91291970014572, 66.22532397508621, 62.60030709207058, 40.85271365940571, 67.29674488306046, 42.576263174414635, 0.47902833146508783, 0.15244430192979053, 0.11277605590294115, 0.20522277220152318, 0.21019909501774237, 0.07734700935543515, 0.12908507022075355, 0.11646986589767039], [0.04066390392836183, 0.0262489692249801, 0.07611212757183239, 0.07923591620055959, 0.04868915493716486, 0.009209946911141742, 0.037514121577260084, 0.0909593707183376, 0.23157838062616065, 21.290221475064754, 54.5189843326807, 41.247288286685944, 32.45936684310436, 53.7507339566946, 56.22497498989105, 79.3059852719307, 29.484901651740074, 0.03736458995263092, 0.18443528999341652, 1.6724119777791202, 59.056925028562546, 74.4941134750843, 74.01954174041748, 71.85798212885857, 68.13494190573692, 65.33462136983871, 62.54345454275608, 55.878042206168175, 54.34725634753704, 55.34113101661205, 55.12220956385136, 57.04136498272419, 62.33900271356106, 68.0155523121357, 70.49573242664337, 65.43333247303963, 84.59834888577461, 86.873340010643, 63.294936418533325, 69.32132944464684, 64.2663922905922, 69.19919639825821, 63.499247655272484, 65.14568030834198, 57.05531403422356, 50.13640969991684, 48.70692640542984, 49.4838897138834, 46.27726837992668, 45.79032450914383, 44.25467491149902, 49.216965436935425, 47.13260628283024, 50.479896068573, 55.840792804956436, 57.60074436664581, 52.645282074809074, 46.43564008176327, 45.16644358634949, 45.56298270821571, 50.616282150149345, 45.47493763267994, 45.06360590457916, 45.15362307429314, 45.38539543747902, 50.10294869542122, 32.85327650606632, 43.64544980227947, 43.30922484397888, 34.39750224351883, 48.65129739046097, 40.57857736945152, 30.818711780011654, 34.63673360645771, 42.50830762088299, 46.88482917845249, 45.13014793395996, 46.8343260884285, 46.23938821256161, 44.62325893342495, 47.99949176609516, 48.705892860889435, 51.0533194988966, 48.94293554127216, 46.33932664990425, 46.878392323851585, 43.75561349093914, 44.54977087676525, 48.03748972713947, 47.02416390180588, 47.53556326031685, 46.84578627347946, 48.05506758391857, 45.95651999115944, 49.52919088304043, 51.23015820980072, 49.22313630580902, 49.876397252082825, 44.21225018799305, 48.281824216246605, 48.81532698869705, 45.73818750679493, 38.85731153190136, 35.74161931872368, 30.928983762860298, 42.628536969423294, 59.90244045853615, 40.19209250807762, 43.35649810731411, 43.43372896313667, 52.37683027982712, 46.34712763130665, 45.608595460653305, 46.80265098810196, 47.77818024158478, 49.25719767808914, 51.3479632884264, 48.68902176618576, 49.23163644969463, 48.32231864333153, 57.64625072479248, 52.51172684133053, 53.46338577568531, 55.43788522481918, 47.794735953211784, 47.22837634384632, 45.06237857043743, 41.71714447438717, 42.80717298388481, 44.62104745209217, 45.576095804572105, 47.83258952200413, 51.490144059062004, 51.918844655156136, 53.94382819533348, 55.46176694333553, 53.04797686636448, 51.523434072732925, 54.07214730978012, 53.648527041077614, 54.443053007125854, 55.83487652242184, 59.744190350174904, 60.35246931016445, 61.17630310356617, 64.34560284018517, 67.11934000253677, 63.62346678972244, 64.33080643415451, 66.52196645736694, 65.55731981992722, 66.0919739305973, 66.87861531972885, 69.30453434586525, 68.30686748027802, 72.21832439303398, 72.88524940609932, 79.28924337029457, 59.6659791469574, 0.15128497820114717, 9.110066257417202, 85.40086582303047, 48.63805890083313, 49.460836350917816, 48.58029060065746, 21.656290031969547, 42.0019543915987, 22.267485335469246, 0.26884293649345636, 0.07099781723809429, 0.05668978519679513, 0.018584632052807137, 0.05826119755511172, 0.04554722079774365, 0.03208460257155821, 0.02314100132934982, 0.035323227421031334, 0.08458953205263242, 0.017327211244264618, 0.028199986409163103, 0.09512307893601246, 0.023591143581143115, 0.06476238151662983, 0.12173242022981867, 0.2770862972829491, 30.590619519352913, 65.13144627213478, 37.94169746339321, 36.93259701132774, 65.11236369609833, 60.86921498179436, 89.586181640625, 31.501660533249378, 0.02549488595832372, 0.39577542222104967, 1.8493596953339875, 61.95996545255184, 81.46521180868149, 78.81021827459335, 78.53907242417336, 71.50503426790237, 70.4354752600193, 65.77864274382591, 61.08611114323139, 59.124189019203186, 58.19485388696194, 56.05005517601967, 61.317739114165306, 64.9921153485775, 70.34098193049431, 70.93767151236534, 68.42333123087883, 84.02243658900261, 84.50282201170921, 66.60062983632088, 70.38884416222572, 65.71824878454208, 71.34887024760246, 65.64213126897812, 67.04277411103249, 61.29212088882923, 53.91307644546032, 51.59906521439552, 52.03602276742458, 47.87146523594856, 48.46984952688217, 47.35328324139118, 51.59276895225048, 47.89407022297382, 51.9793564081192, 57.658269479870796, 60.13156436383724, 57.072891891002655, 54.78537663817406, 48.91949839890003, 50.06550170481205, 50.51485039293766, 48.46411943435669, 47.01827421784401, 47.553380504250526, 48.363459035754204, 52.49396659433842, 34.249097406864166, 44.405162036418915, 45.948627814650536, 39.05768997967243, 49.73304994404316, 39.97475177049637, 34.622469171881676, 39.996984377503395, 45.28508462011814, 49.20124568045139, 48.58116455376148, 46.99753873050213, 48.32861490547657, 46.5157587826252, 51.66449390351772, 50.700291842222214, 52.63668313622475, 52.53110960125923, 48.01844894886017, 49.16717670857906, 46.04393430054188, 47.848932445049286, 49.18648727238178, 50.14521762728691, 47.89274409413338, 47.6067828387022, 48.50325733423233, 48.139715641736984, 52.71782398223877, 53.370777145028114, 50.559532195329666, 50.695146918296814, 46.56375780701637, 49.63350668549538, 52.1352506428957, 46.731344014406204, 41.04238048195839, 39.82953116297722, 38.912944346666336, 43.044287860393524, 55.06379149854183, 42.32705354690552, 44.89497855305672, 44.18638877570629, 53.33758592605591, 49.4104016572237, 47.790784165263176, 50.285760685801506, 48.84195975959301, 50.879429429769516, 51.322139874100685, 50.43217822909355, 51.1228633671999, 50.544234216213226, 57.15084470808506, 56.6533450037241, 57.82398998737335, 56.63260191679001, 49.07407030463219, 48.36063198745251, 47.164015397429466, 45.77077075839043, 46.3913344591856, 47.86738805472851, 47.16381400823593, 49.96381916105747, 52.76165463030338, 54.7495673596859, 56.33699677884579, 58.414641693234444, 56.11050233244896, 55.07128469645977, 56.91976010799408, 54.99714307487011, 59.48676936328411, 58.37604336440563, 60.99697172641754, 63.622345849871635, 65.3521840274334, 67.64661490917206, 69.32763710618019, 67.31494590640068, 69.17442932724953, 70.58503523468971, 70.28731361031532, 70.9107081592083, 71.86397820711136, 72.32896685600281, 73.39355573058128, 77.54612490534782, 78.90848100185394, 82.66135722398758, 62.5554770976305, 0.21656212076777592, 10.592057034373283, 92.50532180070877, 53.13001066446304, 58.71630370616913, 56.122984662652016, 31.692873872816563, 55.30766241252422, 32.35051788389683, 0.428177589783445, 0.04459886367840227, 0.07904731421149336, 0.04976974792953115, 0.013067199161014287, 0.12322142079938203, 0.038543944247066975, 0.016227671221713535, 0.14472489740001038, 0.16864621691638604, 0.20472237170906737, 0.15540613909251988, 0.17143704841146246, 0.13249146868474782, 0.345971257193014, 0.2859171124873683, 0.26312252157367766, 45.82320794463158, 73.22617471218109, 56.11853890120983, 43.36315535008907, 73.87852370738983, 66.42218381166458, 95.46436741948128, 33.27958703041077, 0.14493232767563313, 0.66711155930534, 1.8976167496293783, 64.27795127034187, 84.32778060436249, 81.89385160803795, 80.35583093762398, 73.31179931759834, 72.94789284467697, 67.48999491333961, 63.4893985837698, 61.334819197654724, 59.94352765381336, 59.69576574862003, 63.433108404278755, 67.45777264237404, 71.360824406147, 73.74475568532944, 70.44641867280006, 81.38793155550957, 85.04544049501419, 68.92294362187386, 73.67401868104935, 70.70174217224121, 73.99643138051033, 68.43559697270393, 69.10602539777756, 62.820436879992485, 54.99448321759701, 53.4684357047081, 52.74238586425781, 51.51567488908768, 52.26420812308788, 50.0574841350317, 53.524068519473076, 51.07734940946102, 54.97068129479885, 63.35025005042553, 63.82714346051216, 62.94166557490826, 57.15220503509045, 55.644350945949554, 51.165223494172096, 52.54295736551285, 50.760594606399536, 51.05740047991276, 50.363914892077446, 52.783480659127235, 57.37353935837746, 44.800299033522606, 48.928891494870186, 48.028127029538155, 41.668313294649124, 52.38155722618103, 49.91536796092987, 42.6799938082695, 46.000859811902046, 49.59491215646267, 52.16768570244312, 53.026834800839424, 51.91656097769737, 50.77707052230835, 49.21263746917248, 52.777476981282234, 55.00403590500355, 55.858644247055054, 54.864910170435905, 52.32243999838829, 50.921325981616974, 49.6190332621336, 51.18629336357117, 53.88422079384327, 52.52582408487797, 52.59594552218914, 54.075795114040375, 50.28484493494034, 49.23545144498348, 55.04418075084686, 54.103313237428665, 53.28924871981144, 54.18783210217953, 48.70310381054878, 54.451826736330986, 56.927766278386116, 47.88199447095394, 40.83698630332947, 43.032006919384, 45.64484551548958, 53.36878225207329, 57.79014140367508, 42.495905086398125, 46.672048196196556, 46.11053332686424, 57.643579468131065, 50.93801848590374, 50.098392739892006, 54.12113808095455, 52.25880101323128, 53.62428054213524, 56.06355965137482, 52.70026512444019, 53.51651072502136, 52.78093859553337, 61.229542046785355, 61.49563416838646, 58.67857553064823, 59.078842252492905, 51.37758269906044, 51.01254388689995, 47.96425245702267, 48.631048277020454, 49.844266176223755, 49.54243317246437, 50.231693387031555, 53.136417120695114, 57.79326103627682, 59.431839510798454, 58.16913686692715, 62.752872705459595, 58.93752783536911, 55.68549133837223, 60.60699485242367, 58.9888820797205, 62.64789953827858, 60.94168469309807, 64.95135873556137, 66.45942941308022, 68.13095211982727, 69.70955461263657, 71.25865548849106, 67.2248375415802, 70.59886649250984, 72.20121771097183, 74.11913439631462, 71.70630186796188, 76.17052271962166, 74.159936606884, 74.22541469335556, 79.11139011383057, 81.83307766914368, 84.26137536764145, 68.27899977564812, 0.25485226535238326, 11.607311256229877, 99.65735122561455, 59.87733140587807, 69.31302309036255, 66.97908192873001, 35.11151812970638, 72.48000875115395, 43.06023180484772, 0.46198856143746525, 0.18512830749386922, 0.15513733320403844, 0.1545966786216013, 0.1708983679418452, 0.306152748526074, 0.1274331533932127, 0.09978477566619404], [0.04092457958904561, 0.09045028709806502, 0.061541512550320476, 0.06770369087462313, 0.064200679626083, 0.050288731799810193, 0.12873093219241127, 0.08854929808876477, 0.40654481621459126, 19.26803458482027, 54.31451730430126, 39.16482523083687, 44.7043351829052, 56.22421123087406, 51.46274372935295, 76.77268400788307, 37.0851094275713, 0.04091968141437974, 0.4115529474802315, 3.8534074276685715, 61.86016380786896, 74.06573206186295, 74.98410478234291, 73.54214295744896, 65.35609781742096, 64.6416525542736, 57.006186470389366, 56.491853669285774, 55.147109627723694, 56.821672171354294, 59.264504089951515, 66.10147342085838, 66.71371936798096, 65.05559474229813, 70.55994138121605, 69.7851325571537, 63.37384678423405, 56.99968881905079, 66.07565760612488, 65.51790833473206, 68.12982738018036, 66.1824394762516, 63.74712735414505, 61.84797406196594, 60.165952518582344, 51.90627872943878, 49.71014857292175, 49.54426847398281, 48.740083426237106, 43.52885685861111, 45.18854700028896, 46.30700558423996, 44.484345987439156, 50.72665482759476, 52.35345013439655, 53.76627892255783, 51.85862548649311, 51.86644546687603, 42.01590344309807, 41.509166434407234, 46.02032616734505, 48.49561594426632, 42.704103514552116, 43.820343017578125, 47.89564333856106, 52.49964348971844, 38.60748253762722, 37.70457498729229, 44.29389260709286, 43.6350117623806, 41.641790717840195, 34.23493556678295, 38.155318200588226, 44.183956906199455, 44.36075381934643, 42.94536396861076, 42.923670932650566, 45.06125383079052, 45.596933886408806, 44.222802221775055, 45.97940236330032, 48.70850712060928, 50.22404819726944, 46.19396165013313, 45.34578636288643, 45.344711020588875, 43.58529523015022, 41.235353127121925, 48.7946180999279, 48.1299539655447, 45.50115242600441, 44.06383015215397, 44.87176559865475, 44.076107293367386, 47.58041985332966, 49.6453582495451, 52.05530293285847, 47.5258319824934, 43.78006137907505, 44.22932647168636, 51.50860346853733, 44.74706009030342, 45.20756497979164, 40.0047891587019, 36.223304271698, 28.019058108329773, 39.11449313163757, 56.958438232541084, 40.207360088825226, 47.44720660150051, 42.08972588181496, 40.957166254520416, 52.34577834606171, 44.94522325694561, 45.67228004336357, 46.62843033671379, 47.349187061190605, 44.76201988756657, 45.67594304680824, 46.63390964269638, 51.884980872273445, 50.08053369820118, 58.26528310775757, 53.31996247172356, 48.21397505700588, 46.866069585084915, 44.6618040651083, 43.300086334347725, 44.63028095662594, 46.97008520364761, 48.41377213597298, 49.079652205109596, 52.0517273247242, 55.153888463974, 52.540134117007256, 53.87383595108986, 54.165595695376396, 52.44108863174915, 53.286714255809784, 53.66269268095493, 53.59377957880497, 54.420535415410995, 56.26528322696686, 62.631723806262016, 62.55945548415184, 65.75664952397346, 64.7120475769043, 63.94238367676735, 67.57171332836151, 63.14808949828148, 64.70500275492668, 64.88623782992363, 64.45395782589912, 66.55933365225792, 72.46268928050995, 76.28127157688141, 75.42874172329903, 81.5713781118393, 58.37906040251255, 0.27241144969593734, 13.544485308229923, 81.25404953956604, 53.2100685685873, 46.058578714728355, 43.772089406847954, 26.074504852294922, 43.01297374069691, 26.915006451308727, 0.15225508395815268, 0.0797634941409342, 0.02940243448392721, 0.025136018593912013, 0.11383219141862355, 0.11936554059502669, 0.07817937250365503, 0.053459516930161044, 0.025045120346476324, 0.08022922891541384, 0.10454816889250651, 0.060315670125419274, 0.06751747117959894, 0.06997020245762542, 0.17289750598138198, 0.0612312614248367, 0.4672113514970988, 26.73444204032421, 63.59840713441372, 42.79250577092171, 47.852945029735565, 66.66168496012688, 54.16117273271084, 88.4793010354042, 40.82136154174805, 0.025101514293055516, 0.11015668278560042, 4.4635482877492905, 65.2028976380825, 82.56886258721352, 79.66884300112724, 76.91397562623024, 68.89304682612419, 66.66468679904938, 61.12800769507885, 61.269778087735176, 57.884163558483124, 58.87171156704426, 63.93054351210594, 69.22890320420265, 71.64822578430176, 69.08475413918495, 72.34071582555771, 70.79473838210106, 64.5966325700283, 62.43321105837822, 68.03368493914604, 67.86503478884697, 68.07430475950241, 67.50776275992393, 66.84535950422287, 64.79460954666138, 62.597525641322136, 54.5391346514225, 52.9127649217844, 53.072044774889946, 51.1463613063097, 48.3656021207571, 46.365047469735146, 49.15189012885094, 48.03920343518257, 53.655663058161736, 56.37354701757431, 55.04621364176273, 55.65505497157574, 54.59183782339096, 49.23458509147167, 43.31974267959595, 49.18185152113438, 49.69315968453884, 45.88388308882713, 44.7942079603672, 50.54627850651741, 54.48818318545818, 42.69147299230099, 42.57624797523022, 47.10550993680954, 44.32389959692955, 42.06118181347847, 39.940800592303276, 44.306960105895996, 48.14323805272579, 48.28126184642315, 47.471365705132484, 47.39438183605671, 49.073906913399696, 48.695063441991806, 45.71678705513477, 49.6677390486002, 51.165367886424065, 50.014542639255524, 49.051165133714676, 47.853055223822594, 46.116802990436554, 46.390034928917885, 45.45210465788841, 51.8135979026556, 52.012570425868034, 46.42899043858051, 47.43880145251751, 46.6804039478302, 45.53004987537861, 49.96285401284695, 51.58546194434166, 52.44408667087555, 48.87040503323078, 45.922686606645584, 47.381515726447105, 51.1814334243536, 47.55784146487713, 47.448289543390274, 43.22473257780075, 42.203191593289375, 35.57329595088959, 39.41010966897011, 52.100064530968666, 43.42634975910187, 44.960312247276306, 42.27178931236267, 45.372658520936966, 55.155583173036575, 47.07571193575859, 48.441062271595, 50.03883093595505, 50.09260565042496, 47.18806050717831, 46.88402742147446, 51.0818787664175, 54.371373653411865, 55.940830036997795, 60.35606771707535, 55.48829711973667, 49.54315893352032, 49.403835609555244, 46.696203500032425, 45.63518263399601, 47.153904139995575, 48.31971578299999, 50.228949934244156, 52.85748548805714, 54.444417133927345, 56.8630975484848, 58.13867390155792, 57.33059786260128, 57.611611783504486, 57.349646240472794, 54.442608430981636, 56.81700602173805, 56.90036974847317, 57.20833942294121, 61.69352374970913, 65.3609311580658, 65.68198353052139, 69.61341977119446, 68.09750631451607, 67.03080475330353, 70.652686804533, 67.72828012704849, 68.61421778798103, 69.52366098761559, 69.58288460969925, 70.70030584931374, 76.5229994058609, 80.69892972707748, 79.06754806637764, 84.876858741045, 61.04723162949085, 0.4875058546895161, 16.39934241771698, 88.71133178472519, 60.42380668222904, 55.72716750204563, 51.924050375819206, 33.08643579483032, 51.19991183280945, 38.67320381104946, 0.15194884414086118, 0.027695765711541753, 0.018991488541360013, 0.011074067879235372, 0.07069418235914782, 0.03209689253708348, 0.06823469011578709, 0.05841720070748124, 0.11247587201069109, 0.29184847546275705, 0.22991822595940903, 0.15656268718885258, 0.16432975244242698, 0.2689585631014779, 0.27736935240682214, 0.23092152056051418, 0.861335227964446, 38.29402595758438, 71.47112488746643, 57.4254559725523, 59.48919743299484, 75.9918563067913, 62.98144944012165, 93.29165160655975, 43.829732313752174, 0.19208714424166828, 1.248840750195086, 5.645707128569484, 67.01975494623184, 85.11407241225243, 82.93214589357376, 81.44443452358246, 72.92044311761856, 69.64480608701706, 63.40023256838322, 62.317887246608734, 62.05290086567402, 61.16637043654919, 66.83824628591537, 71.34886264801025, 73.12674164772034, 70.22593170404434, 74.57957848906517, 69.18715104460716, 67.45382845401764, 67.75661140680313, 69.32576760649681, 70.98481938242912, 71.9802975654602, 70.73034703731537, 67.83395245671272, 65.4499451816082, 63.38038243353367, 57.61395625770092, 55.125826969742775, 54.41587306559086, 53.12918610870838, 51.63501888513565, 49.8666013777256, 50.63131034374237, 50.92201754450798, 55.93449577689171, 57.94619143009186, 59.207864329218864, 60.86242854595184, 56.054983511567116, 52.39296041429043, 49.978357180953026, 51.77482858300209, 51.098670065402985, 50.07012225687504, 47.959027737379074, 53.4885860234499, 56.97060517966747, 43.47432218492031, 44.48152273893356, 48.05456601083279, 48.19136247038841, 51.57829932868481, 44.02425907552242, 48.62020745873451, 53.85574132204056, 50.996907725930214, 52.3187617957592, 50.043896064162254, 52.27980628609657, 53.36530543863773, 48.11500556766987, 54.66299280524254, 54.08537060022354, 53.800180703401566, 51.005407869815826, 52.36535109579563, 49.519687592983246, 48.95483270287514, 47.243522331118584, 55.34007467329502, 52.33765058219433, 49.17880028486252, 50.43260380625725, 49.42037232220173, 47.21919983625412, 53.38381804525852, 54.72592122852802, 55.95966562628746, 50.916515439748764, 47.36548438668251, 49.51641596853733, 56.24992825090885, 52.028856351971626, 48.73353637754917, 44.82236824929714, 44.84755329787731, 39.981428012251854, 51.892398074269295, 55.15076883137226, 45.155363380908966, 45.505161210894585, 42.91308470070362, 48.68960693478584, 57.260191440582275, 50.64432464540005, 51.647147834300995, 52.861068695783615, 51.67838975787163, 48.2489749789238, 51.29741460084915, 53.569396287202835, 58.74495416879654, 60.28471514582634, 62.92676657438278, 56.6792444139719, 53.00250470638275, 50.68450748920441, 48.26735459268093, 48.48617725074291, 50.19024521112442, 51.06031492352486, 52.92711675167084, 54.30993475019932, 57.18839429318905, 59.786064103245735, 60.077945441007614, 60.57995170354843, 57.848517671227455, 59.055123925209045, 59.33662801980972, 58.61982308328152, 60.83334490656853, 59.885937944054604, 64.14200216531754, 68.44630479812622, 67.72902488708496, 72.6591919362545, 71.223104596138, 70.20037427544594, 75.02212554216385, 70.9125928580761, 71.75831347703934, 71.85471430420876, 73.44854637980461, 74.52102363109589, 80.36346092820168, 83.68924006819725, 81.82411015033722, 86.43461555242538, 66.30024835467339, 0.44267606805078685, 17.12204083800316, 97.05458968877792, 64.83151316642761, 63.819627463817596, 59.746018052101135, 41.99716664850712, 64.30793926119804, 47.453324273228645, 0.2868600853253156, 0.15954200935084373, 0.21807592391269282, 0.20901026349747553, 0.2761906140949577, 0.1619629396009259, 0.1516515397815965, 0.13103402423439547], [0.1571663946378976, 0.057742566204979084, 0.01354719986920827, 0.04248335688316729, 0.06295928920735605, 0.0803075180738233, 0.1393299290793948, 0.068723869335372, 0.46133998373989016, 13.509749472141266, 56.53779320418835, 35.81424102187157, 28.8615944981575, 52.72598974406719, 53.77694875001907, 73.47005322575569, 48.560174480080605, 0.3207089065108448, 0.017118281830335036, 5.8436912298202515, 65.68459019064903, 77.56614223122597, 73.82333546876907, 70.21409913897514, 65.23001298308372, 62.96169430017471, 57.746850326657295, 57.568324506282806, 57.08686754107475, 59.86281618475914, 65.8836767077446, 67.28453233838081, 71.07184991240501, 76.92922040820122, 64.12555664777756, 55.40398724377155, 50.91006338596344, 62.35656917095184, 63.56956288218498, 63.55382412672043, 59.68471214175224, 59.671010076999664, 63.94229248166084, 65.45699000358582, 61.2153460085392, 54.324081391096115, 47.3016744107008, 49.297247529029846, 49.711744487285614, 44.42674867808819, 45.414137095212936, 44.89422619342804, 45.12236975133419, 48.74039500951767, 52.0780561119318, 48.228444680571556, 50.64949616789818, 49.244293570518494, 44.35331381857395, 37.87971518933773, 37.50334918498993, 46.46134190261364, 44.67721603810787, 42.55546689033508, 46.7875923961401, 48.79719436168671, 52.997671365737915, 46.62103973329067, 47.00579568743706, 43.45914199948311, 36.881550550460815, 50.68019852042198, 44.907985255122185, 40.580663457512856, 39.200718104839325, 39.0821872651577, 45.20706720650196, 51.14443100988865, 44.30985175073147, 44.39825400710106, 43.21595124900341, 42.66069084405899, 46.38115480542183, 41.102196872234344, 43.167994022369385, 40.80526180565357, 43.33819828927517, 42.42337457835674, 45.60433208942413, 48.29061694443226, 42.321467846632004, 43.834645450115204, 41.87376447021961, 41.149223148822784, 43.78552548587322, 48.56409966945648, 45.174168571829796, 46.67661935091019, 43.91651205718517, 48.762430027127266, 48.131956458091736, 44.380003586411476, 41.23871594667435, 44.621712416410446, 41.517203003168106, 37.65095226466656, 28.92192956060171, 41.06886886060238, 47.53138728439808, 38.69669795036316, 63.677997663617134, 50.361418426036835, 48.52755703032017, 45.9896732121706, 40.7576085627079, 43.009816110134125, 44.32318523526192, 45.86741857230663, 45.42035736143589, 47.70889475941658, 48.81028465926647, 49.635049402713776, 55.393526405096054, 49.12384383380413, 47.51260869204998, 44.95946869254112, 45.73359735310078, 42.52878472208977, 44.75211001932621, 47.33931139111519, 48.71394082903862, 49.4582524895668, 53.05189065635204, 55.00882364809513, 55.66443666815758, 57.50312760472298, 54.99335467815399, 55.788826793432236, 55.361653715372086, 54.86383102834225, 51.889696419239044, 50.21304778754711, 55.8640019595623, 59.21446077525616, 62.81087279319763, 64.16620686650276, 66.2416023015976, 66.80612280964851, 66.76877081394196, 66.07254937291145, 64.84180301427841, 66.89191460609436, 65.92580124735832, 68.48784416913986, 71.41558706760406, 74.96303111314774, 75.52160114049911, 83.85940253734589, 44.59330514073372, 0.7620103983208537, 19.85641971230507, 80.80286175012589, 51.205018758773804, 45.78872099518776, 41.58531054854393, 26.472064219415188, 57.27253317832947, 31.90884478390217, 0.08441949117695913, 0.06604304639040492, 0.02637751847942127, 0.025292758327850606, 0.032846591566340066, 0.04997088108211756, 0.06594575082999654, 0.07372372565441765, 0.08835684435325675, 0.013966158930998063, 0.06463651327067055, 0.08623567497124895, 0.0648973707575351, 0.07268602508702315, 0.1620417259982787, 0.17550415126606822, 0.5017469264566898, 17.591707035899162, 65.85377991199493, 36.81022837758064, 29.899227619171143, 61.29530891776085, 60.12401416897774, 82.82204300165176, 51.38692259788513, 0.5246401636395603, 0.17205119045684114, 7.20375937409699, 68.91927301883698, 82.44038388133049, 78.52224692702293, 73.5264801979065, 69.594337195158, 65.4646959900856, 62.56885997951031, 60.54435521364212, 60.40914706885815, 64.67415601015091, 71.71013206243515, 71.1468730866909, 69.89852607250214, 76.34022161364555, 66.10048547387123, 57.184275314211845, 54.00975085794926, 63.18411536514759, 67.42698669433594, 65.71562692523003, 64.82673302292824, 64.78208541870117, 67.97548726201057, 67.45573595166206, 63.07153880596161, 56.87117971479893, 50.10427102446556, 51.0592357814312, 50.15924647450447, 47.14737229049206, 46.32945857942104, 46.85558594763279, 49.46587108075619, 51.94595240056515, 52.0280621945858, 51.051301807165146, 56.914087012410164, 51.502664387226105, 50.36479264497757, 45.130588710308075, 40.57312846183777, 50.386303290724754, 46.471988931298256, 45.90569771826267, 49.91940334439278, 52.500566840171814, 54.334192648530006, 49.75182093679905, 47.98464976251125, 46.133567690849304, 43.99797588586807, 52.319742143154144, 47.20808543264866, 42.868566289544106, 41.7029370367527, 42.27142073214054, 46.98026105761528, 53.63611690700054, 48.559995889663696, 47.52939619123936, 44.67630788683891, 42.7852975577116, 47.36148700118065, 43.609127551317215, 44.51333463191986, 43.69214169681072, 45.71995988488197, 46.1214729398489, 45.92116668820381, 50.65918564796448, 44.439736381173134, 45.502261966466904, 43.87181505560875, 43.89814384281635, 46.218933910131454, 48.45130652189255, 47.638427540659904, 47.63105973601341, 46.69409081339836, 50.02577103674412, 48.768346309661865, 46.218694522976875, 43.7800157815218, 47.258109748363495, 43.93196202814579, 42.359260618686676, 36.29723310470581, 39.374099001288414, 45.92924505472183, 41.981351897120476, 54.0745297819376, 49.23225961625576, 51.30518138408661, 51.41325518488884, 45.36933369934559, 46.28661207854748, 45.286228358745575, 46.419867128133774, 46.4590772241354, 50.74138663709164, 51.67213149368763, 54.21109825372696, 56.70860543847084, 51.55201993882656, 48.91642436385155, 46.3154449313879, 47.98969209194183, 45.581951290369034, 46.00876338779926, 49.55788314342499, 49.37149174511433, 54.4177083671093, 56.02317921817303, 58.54384236037731, 58.481605499982834, 62.10824489593506, 57.66586907207966, 57.44751758873463, 59.378828555345535, 59.20146927237511, 55.13326697051525, 54.517734199762344, 58.95334638655186, 60.9355404227972, 64.93307411670685, 68.19732695817947, 67.9191666841507, 71.79073333740234, 71.36704847216606, 70.29337048530579, 69.018424898386, 70.18258363008499, 69.91237252950668, 72.3305855691433, 75.10677739977837, 79.43574070930481, 79.4293874502182, 87.12740957736969, 46.3169876486063, 0.7740037422627211, 24.114948101341724, 86.60976335406303, 59.0987303853035, 53.47759701311588, 50.839683562517166, 27.78668537735939, 65.64438834786415, 39.41534958779812, 0.13462468312354758, 0.07425091025652364, 0.07593535541673191, 0.06381283325026743, 0.0320948516309727, 0.03242805367335677, 0.06999936886131763, 0.013874204050807748, 0.3740008093882352, 0.25961780338548124, 0.1423214076203294, 0.18780878162942827, 0.15438506263308227, 0.17808252072427422, 0.4247164208209142, 0.2560241462197155, 0.7450525020249188, 28.77963289618492, 78.64893972873688, 48.420904353260994, 39.69412162899971, 70.25388300418854, 66.42787590622902, 88.57124090194702, 56.54533959925175, 0.5264568224083632, 0.42107021959964186, 7.848336361348629, 71.46545559167862, 84.06754776835442, 80.22355243563652, 75.38952022790909, 71.82185366749763, 67.37622901797295, 63.984105437994, 63.591586500406265, 62.60874643921852, 65.34064024686813, 70.43004915118217, 73.11486348509789, 70.99162861704826, 78.53461146354675, 62.99826353788376, 59.29036170244217, 57.899761721491814, 63.70941437780857, 68.426393866539, 68.67126792669296, 66.81098654866219, 64.76298004388809, 69.21082377433777, 68.70056435465813, 65.1460374891758, 61.423597633838654, 53.14171023666859, 52.948878183960915, 54.12487708032131, 50.3422636538744, 49.98635575175285, 50.60954511165619, 50.425638779997826, 53.29571597278118, 54.32529732584953, 54.88501489162445, 57.53357537090778, 54.9331621080637, 54.02977958321571, 49.04030531644821, 46.78348861634731, 53.18841353058815, 49.77332018315792, 49.88840460777283, 52.54649877548218, 54.584302827715874, 57.77311831712723, 53.028233125805855, 54.38618145883083, 51.528544798493385, 46.07138782739639, 53.21879290044308, 53.56574088335037, 47.60584428906441, 46.02955587208271, 44.41285282373428, 51.355266496539116, 56.49047814309597, 49.705691412091255, 50.615818575024605, 47.413107231259346, 46.7650406062603, 52.70696796476841, 45.61807595193386, 48.13823752105236, 48.91534522175789, 49.65855874121189, 48.11634689569473, 50.87691016495228, 54.99174356460571, 47.947795540094376, 49.64332155883312, 47.22430296242237, 46.610795482993126, 48.61410118639469, 54.185369834303856, 51.19842991232872, 52.51726694405079, 49.538990557193756, 53.42251896858215, 53.5317213088274, 49.27840054035187, 47.62074328958988, 49.98393528163433, 49.63503800332546, 47.341545671224594, 42.50923477113247, 52.00060486793518, 47.41664484143257, 47.20980294048786, 53.88436518609524, 48.826760575175285, 52.45894007384777, 52.18621350824833, 47.49222658574581, 50.311245918273926, 50.6096401065588, 49.46621686220169, 50.10856859385967, 52.35041409730911, 54.25720497965813, 58.21028485894203, 62.504442036151886, 52.5811643153429, 51.959019899368286, 49.438611343503, 51.434002071619034, 48.788059651851654, 48.97667773067951, 53.26491862535477, 53.27757954597473, 55.87842598557472, 57.78952583670616, 58.698258474469185, 61.09121426939964, 63.3321326225996, 61.3957679271698, 59.999859631061554, 60.01652553677559, 61.56991258263588, 57.27259397506714, 57.54521034657955, 63.532735258340836, 64.95883673429489, 66.74181506037712, 71.28790631890297, 71.94018691778183, 73.6817778646946, 73.83832186460495, 73.09483855962753, 71.52622193098068, 73.9104875922203, 72.25321412086487, 74.94775593280792, 77.9404753446579, 82.92406752705574, 82.82211139798164, 92.27401301264763, 50.93696974217892, 0.8240751398261636, 24.922617562115192, 96.2099938094616, 62.9248970746994, 63.57928656041622, 59.10604499280453, 41.65119141340256, 82.67082631587982, 49.963530376553535, 0.1833954668836668, 0.19868409493938088, 0.10474038514075801, 0.1473757004714571, 0.08720693105715327, 0.15622636070474982, 0.32975069945678115, 0.17928739747731015], [0.030704493619850837, 0.07454312348272651, 0.0613560424244497, 0.015963958321663085, 0.10769144631922245, 0.02195192861108808, 0.10922968838713132, 0.02104787028656574, 0.21875705220736563, 5.904589612036943, 53.14565822482109, 48.139039278030396, 36.69818378984928, 50.95414862036705, 46.76265433430672, 63.41429181396961, 55.53124241530895, 1.6766467317938805, 0.18703565670875832, 8.126883264631033, 70.33451467752457, 76.20838388800621, 74.00636404752731, 68.60510587692261, 63.39872404932976, 62.559330090880394, 58.36256928741932, 58.45800116658211, 61.21451385319233, 70.66470175981522, 65.0344754755497, 84.22076314687729, 120.24055793881416, 58.686775490641594, 55.958290100097656, 56.96733355522156, 63.64526242017746, 62.69908659160137, 61.7444372177124, 60.75568467378616, 62.25250795483589, 61.74449421465397, 62.64137528836727, 63.23513142764568, 61.14238232374191, 56.11107990145683, 47.45395503938198, 48.24658490717411, 47.487522438168526, 45.57111047208309, 44.96414624154568, 43.61249037086964, 45.80047756433487, 45.62911435961723, 49.261126667261124, 44.86116796731949, 50.275049060583115, 48.42373140156269, 45.95910005271435, 39.50761243700981, 33.10383886098862, 37.77141720056534, 42.27528132498264, 40.8268978446722, 49.03692729771137, 50.48629492521286, 46.19700528681278, 47.51476317644119, 50.51185995340347, 42.766211181879044, 49.11771476268768, 44.48240049183369, 39.71271403133869, 39.781395345926285, 38.290925323963165, 43.041939586400986, 46.75587169826031, 49.31437700986862, 46.41936555504799, 44.966836497187614, 42.22537100315094, 39.40300025045872, 43.462447822093964, 42.40917854011059, 42.902205884456635, 40.653330758214, 44.87947158515453, 39.7443625330925, 44.56892564892769, 46.52174346148968, 40.6673102080822, 40.70962093770504, 40.832027569413185, 41.21786266565323, 43.16015884280205, 42.54770390689373, 41.04953169822693, 38.71558293700218, 41.39216311275959, 47.241215854883194, 51.993704438209534, 44.602014273405075, 45.14966368675232, 39.98784966766834, 40.39039246737957, 37.52619355916977, 34.94449809193611, 30.044039748609066, 42.8075035661459, 43.02196025848389, 31.181453615427017, 38.26816454529762, 48.98606322705746, 47.12190605700016, 43.66861715912819, 44.347538128495216, 39.79428805410862, 42.090102061629295, 45.308240577578545, 51.11542336642742, 46.03419542312622, 44.119155183434486, 52.32525184750557, 50.54126277565956, 44.59374971687794, 44.00978945195675, 44.237765818834305, 43.67690451443195, 46.315148547291756, 48.318404853343964, 47.07382723689079, 51.23757541179657, 56.715342476964, 56.49587385356426, 56.122631281614304, 58.75736050307751, 64.21441867947578, 58.062297999858856, 60.04282012581825, 57.18051731586456, 57.29933314025402, 53.98960053920746, 52.0284041762352, 56.48360811173916, 57.08418868482113, 61.29624366760254, 64.03819933533669, 66.6641092300415, 67.63609707355499, 66.95945218205452, 63.81958186626434, 64.8172715306282, 64.01448100805283, 68.87729287147522, 73.36383372545242, 75.74466437101364, 73.67548540234566, 82.89463430643082, 35.099875554442406, 0.18169455346651375, 25.234440229833126, 82.0655719935894, 49.43839855492115, 51.69940643012524, 35.13105668127537, 31.918971240520477, 55.21199494600296, 31.891776099801064, 0.2196431320044212, 0.041510609080432914, 0.15924664941849187, 0.022996542284090538, 0.0276512479831581, 0.1242503862886224, 0.017054692762030754, 0.052977421510149725, 0.05981579655781388, 0.0346333158086054, 0.02037374972132966, 0.033494980016257614, 0.04315799138566945, 0.03844564678729512, 0.09436458174604923, 0.15303463587770239, 0.5485375563148409, 11.611547078937292, 66.89348012208939, 49.07927982509136, 39.8202520608902, 63.13354767858982, 54.23216052353382, 73.51640313863754, 59.80605863034725, 2.2522690566256642, 0.14173135568853468, 10.624859724193811, 74.41357299685478, 80.93444868922234, 80.61642095446587, 73.0522808432579, 66.70837685465813, 66.12608090043068, 60.63201270997524, 62.11117833852768, 66.07216939330101, 71.08764186501503, 69.10941481590271, 82.879359126091, 108.86087536811829, 66.63762465119362, 58.73306080698967, 60.46134486794472, 65.75923338532448, 65.9521110355854, 64.05710712075233, 63.92074003815651, 64.94508907198906, 66.01267218589783, 66.78446397185326, 67.5551538169384, 65.38141965866089, 60.52209980785847, 49.95279595255852, 53.03606830537319, 48.349893763661385, 48.909390941262245, 46.73846863210201, 47.710992246866226, 47.998199835419655, 48.2618372887373, 51.48523852229118, 49.17414553463459, 55.773734003305435, 52.49507613480091, 48.72574299573898, 47.8764695674181, 40.50333000719547, 41.67503513395786, 44.724888280034065, 44.60694260895252, 51.46625094115734, 53.395825400948524, 50.807465091347694, 49.32783588767052, 52.78418742120266, 46.19262412190437, 51.334633603692055, 46.67094625532627, 41.96316987276077, 44.454031214118004, 41.965160965919495, 45.09305812418461, 48.752276971936226, 54.947935715317726, 48.68375904858112, 46.879661455750465, 43.63923713564873, 42.85443864762783, 44.15054149925709, 44.909356981515884, 44.409269616007805, 46.27493530511856, 44.40980538725853, 42.655454725027084, 46.58399172127247, 51.84257514774799, 44.32962588965893, 42.95188061892986, 43.25154393911362, 43.078812807798386, 45.13013273477554, 44.76363480091095, 42.38470785319805, 42.44437985122204, 42.17329479753971, 49.13351811468601, 55.30679605901241, 48.04632805287838, 45.258641839027405, 43.87779973447323, 42.476533725857735, 40.89029744267464, 41.23480215668678, 38.49044881761074, 41.19037114083767, 46.69697105884552, 30.816437602043152, 32.38541901111603, 53.649359196424484, 50.007228031754494, 48.46162676811218, 45.026793479919434, 43.322193548083305, 44.374068304896355, 48.268122151494026, 51.58373683691025, 49.66519698500633, 48.40719848871231, 53.71209003031254, 52.86673419177532, 47.352960258722305, 45.320118740200996, 47.55332350730896, 45.700470730662346, 49.304501339793205, 49.71826493740082, 48.53587858378887, 54.65923860669136, 59.02574010193348, 60.91518871486187, 60.58342471718788, 62.13713854551315, 64.62643817067146, 60.91668203473091, 60.29117859899998, 61.17782302200794, 60.10639451444149, 57.95516274869442, 53.82268689572811, 59.18330244719982, 59.1928893327713, 65.7831797003746, 67.29894116520882, 69.6916651725769, 72.209592461586, 70.85337683558464, 68.32424014806747, 67.9021055996418, 68.10071334242821, 71.19687080383301, 75.71181133389473, 80.11164844036102, 78.3243915438652, 86.4172200858593, 40.803848281502724, 0.20573301357217133, 28.679570965468884, 88.83489355444908, 56.37741141021252, 60.033278837800026, 45.40778383612633, 32.62331284582615, 68.10811534523964, 39.251878559589386, 0.1748760271584615, 0.12111845629988238, 0.060870351298945025, 0.010442736765980953, 0.09135741420323029, 0.04327899114286993, 0.0675870401028078, 0.09937989700119942, 0.08958306527347304, 0.307322729495354, 0.13239268882898614, 0.1314507846836932, 0.30951533059123904, 0.22432265512179583, 0.2885974233504385, 0.3695477155270055, 0.7252067606896162, 18.145443722605705, 80.16129657626152, 63.704041466116905, 49.60327170789242, 68.54265242815018, 60.35452879965305, 77.42088362574577, 67.2999519109726, 2.388874338939786, 0.3682361327810213, 11.580613888800144, 77.58805945515633, 81.18848025798798, 82.27800339460373, 74.29330945014954, 69.72926795482635, 68.8382613658905, 62.28715069591999, 64.57406938076019, 70.34215226769447, 72.2007617354393, 74.11897480487823, 83.37516412138939, 94.40427750349045, 65.07848471403122, 59.27847974002361, 61.4030559360981, 66.64045929908752, 70.44011861085892, 66.81195929646492, 65.4775620996952, 66.0976280272007, 64.95134353637695, 70.70664390921593, 68.04242447018623, 66.90102651715279, 62.26235702633858, 49.479409754276276, 53.520534709095955, 51.01615749299526, 52.26715676486492, 49.92730692028999, 49.55862410366535, 49.13886442780495, 50.65123647451401, 55.80841474235058, 50.374204739928246, 56.998647674918175, 54.768953919410706, 53.8521771132946, 48.49987171590328, 44.13067616522312, 46.02876551449299, 47.631318122148514, 46.54545038938522, 56.28634549677372, 59.02026079595089, 54.73774619400501, 53.01636256277561, 56.96312718093395, 49.5712698251009, 54.761073142290115, 51.55014283955097, 44.85488310456276, 45.72524160146713, 43.391505628824234, 48.039754405617714, 55.173856392502785, 59.405487924814224, 51.95873871445656, 49.617410749197006, 47.16714262962341, 44.61315527558327, 48.91180761158466, 47.446754425764084, 48.586328476667404, 50.63002601265907, 48.37792865931988, 45.392964631319046, 49.32552561163902, 52.66927398741245, 46.712561622262, 46.67346552014351, 45.26377156376839, 45.91938078403473, 46.21282383799553, 47.14274413883686, 45.634947046637535, 45.32144486904144, 46.56170591711998, 54.081445410847664, 57.87558741867542, 50.205307602882385, 50.95390163362026, 47.62878365814686, 46.29130482673645, 45.96250467002392, 46.00238732993603, 45.000073313713074, 50.31485952436924, 49.791726395487785, 42.93814055621624, 39.17967863380909, 56.089257672429085, 50.94654142856598, 50.88165991008282, 48.186578527092934, 46.46764196455479, 47.573230639100075, 51.980671137571335, 54.49507221579552, 54.87197399139404, 51.14877797663212, 58.5347418487072, 55.194401890039444, 50.647470876574516, 48.95909987390041, 50.325206369161606, 49.09130617976189, 52.21713624894619, 51.582619696855545, 51.078888326883316, 56.899321004748344, 62.68780119717121, 62.159675136208534, 63.692414090037346, 62.785493955016136, 66.51615276932716, 62.092498540878296, 64.3296816945076, 62.1672747284174, 63.82927894592285, 58.67182709276676, 57.30850584805012, 62.08223149180412, 62.94683709740639, 67.37167686223984, 70.3654982149601, 72.37438961863518, 76.40055477619171, 74.7488822042942, 71.5592573583126, 71.12821608781815, 71.98721319437027, 74.95480835437775, 81.4196902513504, 82.2330442070961, 82.81781002879143, 89.07137766480446, 46.31633788347244, 0.1964081358164549, 29.542396366596222, 98.81571918725967, 62.14900150895119, 70.7734215259552, 50.1012197881937, 46.94809578359127, 81.31417751312256, 48.330085426568985, 0.48968254413921386, 0.20561177632771432, 0.21832319267559797, 0.09931108506862074, 0.23837010056013241, 0.15022639359813184, 0.1222666997637134, 0.1703610975528136], [0.06776556372642517, 0.07864662125939503, 0.04359330181614496, 0.06709782377583906, 0.060156972976983525, 0.12494011607486755, 0.07720757464994676, 0.019805307274509687, 0.20925763616105542, 3.6740667885169387, 53.68626281619072, 40.25480054318905, 33.41494716703892, 40.0343781709671, 49.029863476753235, 60.55865004658699, 70.22300586104393, 4.266949212178588, 0.3651962958974764, 8.856750000268221, 71.33696168661118, 80.01682832837105, 72.42420494556427, 70.19000843167305, 62.92556203901768, 62.4128707498312, 56.036622896790504, 60.37675380706787, 63.1326699256897, 74.69043374061584, 62.420960515737534, 93.73427465558052, 89.4790805876255, 55.11237569153309, 68.99076998233795, 62.78305448591709, 66.6791108250618, 63.68449531495571, 64.91130128502846, 64.73005101084709, 64.56462308764458, 63.958449214696884, 64.5326592028141, 61.69965662062168, 61.17197513580322, 55.31582437455654, 49.89061988890171, 47.04240292310715, 48.308639377355576, 45.62329687178135, 46.846808418631554, 43.78245145082474, 43.05722236633301, 44.77092660963535, 46.26078486442566, 45.47075405716896, 48.86515371501446, 50.466497987508774, 46.211284920573235, 43.33340294659138, 40.525087639689445, 36.55623100697994, 40.89984633028507, 39.82458382844925, 48.02411824464798, 46.347758397459984, 49.309577867388725, 48.94912540912628, 44.618547186255455, 45.46803720295429, 39.63061563670635, 39.40093316137791, 40.93833066523075, 41.49412304162979, 42.26535625755787, 41.36882096529007, 47.50420734286308, 49.395141676068306, 49.40754421055317, 43.78496311604977, 43.4705413877964, 45.47688312828541, 43.9075293391943, 41.7848264425993, 40.173667296767235, 42.45400473475456, 44.321338534355164, 40.65743833780289, 44.29087936878204, 46.99386812746525, 41.60542666912079, 44.76996146142483, 40.13123497366905, 41.84526979923248, 42.0895054936409, 42.21729263663292, 43.01006309688091, 42.91254512965679, 42.462744265794754, 45.79751372337341, 49.06060382723808, 46.96378894150257, 39.25350107252598, 43.94480153918266, 36.41460880637169, 39.16051246225834, 32.78647989034653, 31.071996688842773, 33.29293571412563, 48.496744483709335, 24.592595770955086, 26.70446164906025, 48.39957609772682, 46.56384140253067, 46.171710044145584, 40.37743516266346, 44.53042231500149, 40.45013286173344, 45.32383494079113, 46.60132259130478, 39.18160133063793, 45.18152877688408, 47.777028903365135, 50.150700733065605, 45.716977044939995, 44.31865967810154, 43.28355722129345, 43.96567761898041, 46.369789615273476, 47.10909314453602, 50.587088316679, 50.670015066862106, 55.251737013459206, 58.729678988456726, 61.43137201666832, 62.66791686415672, 65.95923945307732, 67.16321244835854, 63.73608134686947, 62.79861845076084, 59.711151123046875, 61.21896721422672, 56.56169392168522, 54.75245140492916, 52.62504056096077, 58.33898015320301, 61.53471127152443, 62.90059357881546, 64.18006092309952, 63.58929142355919, 62.4245323240757, 63.44322346150875, 62.52814516425133, 65.68220391869545, 69.2882788181305, 74.49032127857208, 75.28390109539032, 80.04506081342697, 33.56195367872715, 0.8396046096459031, 30.2230766415596, 76.87510371208191, 56.15402899682522, 41.95901669561863, 40.048916190862656, 35.85520662367344, 51.898504346609116, 35.176228657364845, 0.5229894490912557, 0.0433939720824128, 0.12272134685190395, 0.030935279282857664, 0.024126742282533087, 0.051542241490096785, 0.12905612646136433, 0.07867966167395934, 0.08809731531073339, 0.08268692516139708, 0.04048355091072153, 0.06325638576527126, 0.03191803494701162, 0.05223447602475062, 0.19336294062668458, 0.030342190111696254, 0.5079158360604197, 6.750434199348092, 66.33249342441559, 45.36564029753208, 41.615302339196205, 53.034415394067764, 54.437581300735474, 71.05557918548584, 74.57636386156082, 5.5163896176964045, 0.6974428379908204, 11.383013091981411, 75.17361581325531, 85.24922356009483, 77.06766217947006, 73.48481923341751, 67.2400215268135, 66.152763068676, 58.483159616589546, 63.30065131187439, 66.32520541548729, 78.10492292046547, 67.26579934358597, 90.33862486481667, 94.64988112449646, 56.36600062251091, 69.90962907671928, 66.34623348712921, 67.49197080731392, 66.99250280857086, 68.18861022591591, 63.31756040453911, 65.71572571992874, 66.19191616773605, 68.306685090065, 65.07485970854759, 62.28988274931908, 57.80269593000412, 51.30886718630791, 51.131306514143944, 50.36309413611889, 48.23044717311859, 48.50210979580879, 46.2663097679615, 46.7390576004982, 45.698464438319206, 51.089307367801666, 47.41680823266506, 52.14978866279125, 53.52811150252819, 51.52225613594055, 43.92269812524319, 46.8081720918417, 42.37691447138786, 44.5264857262373, 42.53544196486473, 51.76716059446335, 50.259108915925026, 51.90101981163025, 52.02216111123562, 47.458906173706055, 45.37687249481678, 42.09313049912453, 42.79439426958561, 43.75502452254295, 43.96561682224274, 44.40121404826641, 43.22908714413643, 51.86923071742058, 54.06406134366989, 52.009321600198746, 47.693061009049416, 46.11507028341293, 45.38337014615536, 46.578748002648354, 42.87546291947365, 43.79621051251888, 42.74415336549282, 46.544705629348755, 43.611407428979874, 46.60584434866905, 49.858868792653084, 43.0609043687582, 46.16456262767315, 43.67250055074692, 43.61173041164875, 45.51946744322777, 44.05469924211502, 44.87006328999996, 42.62289047241211, 45.21484538912773, 49.92807827889919, 52.67035312950611, 49.64129626750946, 40.50104632973671, 44.954969733953476, 40.19814558327198, 42.676300406455994, 36.59253425896168, 35.924875885248184, 36.06857657432556, 47.22166210412979, 31.54682870954275, 32.608577236533165, 50.486127734184265, 48.41259799897671, 46.68954245746136, 42.29847528040409, 44.953681603074074, 41.72987759113312, 49.568119794130325, 48.34585078060627, 45.96011459827423, 48.8909163326025, 48.76225143671036, 51.910295113921165, 47.89131157100201, 45.946997702121735, 45.59916816651821, 45.53690850734711, 47.0382459461689, 48.82275179028511, 51.36100798845291, 53.87960024178028, 57.83636972308159, 61.071937903761864, 63.355064392089844, 64.74388226866722, 68.74233171343803, 69.59429159760475, 67.08568140864372, 65.02631351351738, 63.68142507970333, 65.20466834306717, 61.52952454984188, 58.40810984373093, 57.02287137508392, 60.09089894592762, 64.94430631399155, 65.50085484981537, 67.59240701794624, 68.03435370326042, 64.78583201766014, 66.6100001335144, 64.61280450224876, 70.063057243824, 73.30313578248024, 78.93431961536407, 77.8961393237114, 85.44679015874863, 36.75471715629101, 0.9729576820973307, 33.29788684844971, 85.1329118013382, 59.128535985946655, 48.775687515735626, 47.64324568212032, 37.8803725540638, 61.98795475065708, 40.41128374636173, 0.4170063970377669, 0.01175589100967045, 0.10590577963739634, 0.013746490640187403, 0.07640363575774245, 0.03406730946153402, 0.0209418674785411, 0.05713304031814914, 0.28717211389448494, 0.21375503623858094, 0.18565883918199688, 0.25438355456572026, 0.14832444721832871, 0.2338978147599846, 0.45062835852149874, 0.4170051502296701, 1.041222265921533, 13.359742071479559, 80.41134595870972, 53.43329519033432, 46.421831622719765, 55.98725214600563, 64.17554676532745, 73.01915422081947, 82.423847168684, 5.534339854493737, 0.6134801090229303, 12.582701817154884, 80.84285840392113, 85.03322795033455, 79.15662288665771, 75.82222580909729, 71.180569678545, 66.45413249731064, 62.919702753424644, 64.3271054327488, 69.43866714835167, 77.81401813030243, 72.61583626270294, 81.19748577475548, 96.86198562383652, 59.944413006305695, 69.08178269863129, 69.0721920132637, 70.82655027508736, 67.50229105353355, 68.27819421887398, 66.34860455989838, 69.40380781888962, 69.19357270002365, 69.51079487800598, 67.74311453104019, 66.98785945773125, 59.23861987888813, 53.26054126024246, 52.012372836470604, 52.18786641955376, 50.867543667554855, 52.25712910294533, 50.17413027584553, 49.29970219731331, 50.83990775048733, 53.30757513642311, 50.35191893577576, 54.29871775209904, 57.466991543769836, 52.168631851673126, 49.49539929628372, 46.15404099225998, 46.30106270313263, 50.53869791328907, 44.303399696946144, 54.19147990643978, 51.71651691198349, 55.63737452030182, 54.00871731340885, 51.54369458556175, 51.630778312683105, 45.67534267902374, 45.83076573908329, 46.84013597667217, 46.33777633309364, 48.64072635769844, 46.7038980871439, 56.20688036084175, 56.52035593986511, 54.64396722614765, 51.67401239275932, 48.37284833192825, 49.23749193549156, 51.62403367459774, 46.787022426724434, 47.102831080555916, 45.69077745079994, 49.29251678287983, 44.991740360856056, 49.00253914296627, 52.74224527180195, 47.48444460332394, 48.7649454921484, 45.010211169719696, 45.78166477382183, 48.44901904463768, 47.05749191343784, 48.32810193300247, 47.05047369003296, 47.39169918000698, 51.876191943883896, 57.25247785449028, 54.957693591713905, 44.82235684990883, 49.318822771310806, 42.10220821201801, 46.08215644955635, 41.0325276106596, 39.27222266793251, 45.03638796508312, 58.1636917591095, 33.20556320250034, 33.09786178171635, 56.07470445334911, 53.583767116069794, 49.961102306842804, 46.53560131788254, 50.60925632715225, 43.976875618100166, 52.26100489497185, 52.656799256801605, 50.678142830729485, 50.51224373281002, 51.65843702852726, 55.36898732185364, 50.175475403666496, 48.95909987390041, 48.3897802233696, 47.172006368637085, 49.36480030417442, 52.07593962550163, 55.966117680072784, 54.83676128089428, 60.32883457839489, 63.68408493697643, 66.45399570465088, 67.94972464442253, 70.69481894373894, 69.87036198377609, 69.78471457958221, 69.30241405963898, 65.10493889451027, 67.10597231984138, 62.86711357533932, 60.22584870457649, 59.74668301641941, 62.44698531925678, 70.36862164735794, 69.05783638358116, 71.65945798158646, 70.49120306968689, 68.80827337503433, 68.97612556815147, 70.30103087425232, 71.22088551521301, 77.55385369062424, 81.14943355321884, 85.02646431326866, 85.32344877719879, 51.19817152619362, 0.5457984376698732, 35.556314662098885, 95.47623798251152, 67.4549987912178, 59.04096208512783, 55.787789449095726, 51.801810935139656, 71.18818446993828, 51.54709920287132, 0.7155625813174993, 0.15747820056276396, 0.3602425492135808, 0.10488486645044759, 0.4709312034538016, 0.25493004242889583, 0.30003757041413337, 0.2888276969315484], [0.17933746275957674, 0.02376385804382153, 0.03276316303526983, 0.05234125994320493, 0.06955960183404386, 0.06823004427133128, 0.2252010314259678, 0.18494097457733005, 0.46609210374299437, 4.377141874283552, 58.229941204190254, 45.58535970747471, 36.81024357676506, 36.93515047430992, 52.67919525504112, 55.479732379317284, 76.91346645355225, 9.634459968656301, 0.3562785603571683, 8.439861070364714, 77.10555374622345, 78.30032363533974, 70.82850337028503, 69.96772035956383, 65.44880524277687, 62.15361826121807, 56.373482421040535, 63.579727336764336, 66.77579283714294, 71.43865182995796, 70.13084560632706, 80.95519557595253, 51.45947590470314, 64.90779787302017, 64.14084702730179, 63.97753179073334, 66.23532503843307, 64.59622979164124, 64.50834050774574, 65.51330298185349, 64.63869631290436, 64.35983687639236, 62.481073290109634, 57.952818274497986, 53.85901294648647, 55.45177347958088, 50.472672656178474, 47.53962144255638, 49.41431164741516, 46.74815431237221, 43.66289086639881, 42.26065970957279, 42.79310613870621, 42.7878662198782, 43.74924123287201, 43.61855864524841, 45.53340509533882, 47.83221714198589, 45.34972295165062, 44.76014278829098, 42.88058124482632, 41.1548962444067, 40.85161551833153, 40.804509446024895, 46.59333162009716, 49.12806160748005, 43.14913183450699, 46.1209599673748, 42.902772054076195, 39.9539440870285, 40.954130217432976, 40.14538921415806, 39.70477245748043, 39.95641015470028, 42.0897600799799, 41.84951037168503, 45.14639966189861, 45.73589242994785, 51.62364989519119, 46.55139707028866, 47.1836793422699, 44.50818590819836, 43.48214216530323, 40.03340922296047, 41.976085379719734, 39.47043143212795, 44.67307426035404, 43.48751127719879, 44.358838722109795, 48.07469353079796, 43.07692810893059, 45.583281219005585, 42.33234666287899, 41.9314643740654, 39.75130096077919, 42.163951098918915, 45.401582568883896, 45.51917865872383, 43.66487056016922, 46.242739632725716, 50.26000186800957, 46.532743871212006, 41.560995653271675, 40.814765095710754, 41.58737003803253, 38.59846942126751, 38.988602086901665, 32.96664722263813, 32.405679523944855, 37.27277755737305, 50.95967352390289, 48.471833020448685, 42.90893152356148, 45.95138646662235, 44.097861126065254, 41.43411286175251, 41.3533253967762, 40.09916849434376, 44.077357426285744, 40.90547002851963, 45.65162055194378, 47.312279641628265, 45.49338944256306, 45.274673178792, 43.8179187476635, 43.288097977638245, 42.50949315726757, 42.680366188287735, 46.14562064409256, 46.53801038861275, 49.37063679099083, 53.23814146220684, 58.5043016821146, 59.76534001529217, 60.97657822072506, 61.264880150556564, 59.876567646861076, 61.30039304494858, 64.47329118847847, 61.89910031855106, 64.1217340528965, 64.4918341934681, 65.14591589570045, 61.72790810465813, 58.39341603219509, 56.50603450834751, 56.27667881548405, 57.32273228466511, 58.178062587976456, 58.72759290039539, 59.93718199431896, 59.856044948101044, 63.13694089651108, 66.44150957465172, 72.7165612578392, 74.5556777715683, 70.98279789090157, 89.90788757801056, 15.138836055994034, 1.5466491761617362, 34.39012683928013, 78.66144865751266, 55.236173048615456, 45.959244444966316, 38.00730474293232, 31.512385457754135, 57.0004677772522, 33.467973321676254, 0.2989135729148984, 0.05545903346501291, 0.07581541693070903, 0.09515358120552264, 0.10099384555360302, 0.039190191600937396, 0.1406319232773967, 0.04841256020881701, 0.025406987842870876, 0.055972421541810036, 0.009089304312510649, 0.07340898082475178, 0.060768595430999994, 0.03487816888082307, 0.1527663494925946, 0.12335213526966982, 0.6684972380753607, 7.667247578501701, 71.71079322695732, 46.133499294519424, 46.717383563518524, 47.3162542283535, 56.184913739562035, 61.82307779788971, 83.29321011900902, 10.857128910720348, 0.4423009866150096, 9.725395739078522, 79.65835556387901, 82.50266253948212, 75.59220135211945, 72.81007423996925, 68.73554527759552, 64.68341991305351, 60.03802478313446, 67.56205424666405, 71.11766785383224, 73.3156219124794, 71.92124873399734, 87.89535596966743, 62.279798090457916, 65.42883351445198, 69.21469956636429, 66.5066684782505, 67.58706450462341, 67.29388743638992, 66.28873497247696, 63.59534069895744, 67.77563318610191, 64.20358926057816, 65.9555384516716, 60.06108574569225, 58.339223340153694, 58.389380648732185, 52.560181841254234, 49.77317959070206, 49.70149263739586, 50.30588060617447, 47.34653480350971, 43.84420953691006, 44.93860401213169, 44.632807821035385, 46.37558050453663, 46.4679079502821, 49.21604968607426, 49.26140025258064, 48.37552338838577, 47.445245906710625, 45.38045950233936, 45.04996083676815, 46.48975297808647, 42.6388344168663, 49.35508422553539, 50.87622620165348, 48.1405857950449, 49.33729737997055, 45.712105706334114, 42.39104211330414, 42.76203140616417, 44.56419110298157, 41.214917823672295, 44.20098379254341, 45.096014365553856, 46.87064453959465, 50.22312484681606, 49.89605359733105, 54.13552410900593, 48.798212707042694, 49.83540125191212, 47.15974062681198, 46.076456755399704, 42.86124788224697, 46.55897006392479, 43.30214582383633, 47.7983533591032, 44.75936762988567, 47.800268456339836, 50.12883670628071, 43.606289103627205, 48.07453013956547, 45.91375708580017, 43.846762999892235, 41.696021407842636, 42.937175408005714, 45.71772180497646, 46.31536893546581, 48.78489062190056, 49.40343663096428, 51.84969216585159, 49.21215109527111, 46.17644838988781, 42.097124084830284, 44.17598493397236, 39.45119686424732, 40.18071971833706, 37.34985262155533, 37.89806440472603, 40.557123720645905, 50.336628556251526, 50.050139129161835, 44.65379789471626, 47.445219308137894, 45.307039842009544, 44.24656614661217, 43.13598833978176, 43.62421274185181, 46.607535257935524, 44.913156777620316, 50.13303928077221, 49.091047793626785, 47.50905208289623, 48.12127523124218, 45.43109558522701, 46.148694679141045, 46.1701787263155, 45.33745341002941, 47.97776073217392, 48.8711079955101, 50.28892211616039, 55.98654918372631, 61.322154477238655, 63.18785056471825, 62.58760057389736, 65.09687572717667, 63.26222777366638, 65.72787746787071, 67.63367280364037, 65.59739246964455, 66.83314695954323, 66.83807909488678, 67.75480270385742, 66.18883073329926, 61.37693993747234, 59.57494743168354, 58.67154970765114, 61.83257728815079, 60.476829037070274, 62.27735862135887, 61.63208484649658, 63.916689455509186, 65.45712679624557, 73.44533935189247, 76.96606323122978, 78.32785695791245, 75.86508750915527, 94.27182421088219, 17.206707894802094, 1.3646962959319353, 38.48992444574833, 85.58720782399178, 60.61143301427364, 49.642029628157616, 48.38069871068001, 35.97812242805958, 62.87055619060993, 44.94510546326637, 0.2169927000068128, 0.008448524731647922, 0.048891045080381446, 0.05449347707326524, 0.11710564154782332, 0.03932088380679488, 0.06077471814933233, 0.041002519938047044, 0.2879648463567719, 0.15475848165806383, 0.15186982025625184, 0.11682438242132775, 0.15279138955520466, 0.1753824093611911, 0.2734969148878008, 0.22143553738715127, 0.8990349643863738, 10.524856690317392, 86.89986258745193, 58.689632937312126, 51.51660583913326, 49.505932331085205, 69.37859997153282, 66.325304210186, 90.8505941927433, 11.726279072463512, 0.6165163835976273, 11.641854252666235, 85.19493967294693, 85.7655094563961, 78.13731238245964, 73.16704228520393, 70.49045830965042, 69.0144731104374, 62.673681154847145, 68.85813429951668, 71.1234587430954, 76.80519506335258, 75.15177458524704, 79.10433769226074, 65.83991825580597, 65.85713893175125, 70.79216971993446, 66.05188608169556, 70.96495404839516, 69.87508893013, 70.0682857632637, 66.22757345438004, 69.10825207829475, 67.57774740457535, 69.49931189417839, 61.49667911231518, 60.961344838142395, 60.06156072020531, 54.488407373428345, 49.81876574456692, 54.83236491680145, 51.980766132473946, 50.8208441734314, 46.984672620892525, 48.788926005363464, 46.58125966787338, 46.83497965335846, 49.0999773144722, 50.4560599476099, 52.543873116374016, 51.2523528188467, 50.06366640329361, 50.01270353794098, 47.57525213062763, 49.72224712371826, 44.73497673869133, 52.351763024926186, 54.28030773997307, 48.9030908793211, 52.02433839440346, 47.92253449559212, 45.28482623398304, 46.14046432077885, 46.72801159322262, 42.90728621184826, 44.84525442123413, 47.52727210521698, 50.18164627254009, 51.88198663294315, 52.83480070531368, 58.719282746315, 54.33598235249519, 54.62081886827946, 50.39044886827469, 49.7835948318243, 44.323869198560715, 49.465061724185944, 47.62580841779709, 53.439173474907875, 49.250358045101166, 51.57880090177059, 51.45510993897915, 46.65119491517544, 51.515211313962936, 49.27759498357773, 44.84066426753998, 45.32128907740116, 45.89226923882961, 50.35096138715744, 49.24819976091385, 52.94698588550091, 53.92417185008526, 54.839193150401115, 54.01337206363678, 47.69880250096321, 47.59422831237316, 48.63239340484142, 42.244841158390045, 42.41525821387768, 39.42551024258137, 42.07850128412247, 47.007619589567184, 56.43068075180054, 53.63448679447174, 47.471700087189674, 51.5532548725605, 49.79986175894737, 45.58784477412701, 46.90984703600407, 47.26583853363991, 50.963697507977486, 50.77553540468216, 54.77284871041775, 51.621833592653275, 50.32601572573185, 49.64118607342243, 47.236492708325386, 47.44391977787018, 48.56983356177807, 48.10599245131016, 49.96662341058254, 50.44037438929081, 51.296852231025696, 57.097039595246315, 61.76105372607708, 64.0167684853077, 65.31587317585945, 66.87189728021622, 66.2602972984314, 68.33843618631363, 70.17752230167389, 66.90589785575867, 69.42314118146896, 70.52178382873535, 71.64710104465485, 67.72446513175964, 63.57376545667648, 64.1049237549305, 61.665059477090836, 64.06346797943115, 64.06463071703911, 65.06178081035614, 65.0300145149231, 68.44107627868652, 68.88562962412834, 75.9049017727375, 80.11113926768303, 81.21672034263611, 77.78710797429085, 100.24033114314079, 28.948986008763313, 1.5357628790661693, 43.56099173426628, 94.73229110240936, 71.5572814643383, 63.49575564265251, 54.90319311618805, 47.836309522390366, 77.02870666980743, 51.40227757394314, 0.41396106826141477, 0.14702512475196272, 0.22299750591628253, 0.27074945450294763, 0.22090176993515342, 0.16219514276599512, 0.2156900824047625, 0.16187141794944182], [0.021845851588295773, 0.021323490946087986, 0.0327101625589421, 0.03840898469206877, 0.056121767629520036, 0.06713902781484649, 0.1554522561491467, 0.07856940079363994, 0.6797611399088055, 4.20790845528245, 58.06436128914356, 45.25298774242401, 34.08953256905079, 33.27686257660389, 55.56494660675526, 54.52422425150871, 79.79223757982254, 16.43660891801119, 0.9909375454299152, 6.635119412094355, 77.86648571491241, 77.53499150276184, 74.08025488257408, 71.45117595791817, 66.21783077716827, 60.383179262280464, 61.69819749891758, 65.60339614748955, 71.0504874587059, 66.8471910059452, 72.87118256092072, 69.24581989645958, 47.30952098965645, 67.77623355388641, 66.7249895632267, 67.83487200737, 63.1410750746727, 64.7979685664177, 63.74714255332947, 66.27373337745667, 59.96390216052532, 62.22604237496853, 59.84662525355816, 60.358191803097725, 59.75117437541485, 55.48067852854729, 54.242359176278114, 47.94169306755066, 48.285931795835495, 47.603184431791306, 45.070563331246376, 42.45834790170193, 41.53836026787758, 43.69538672268391, 42.867631539702415, 41.156640350818634, 45.65390422940254, 44.41032595932484, 45.30455097556114, 43.980185240507126, 44.271439611911774, 42.22818285226822, 43.71612221002579, 42.53107599914074, 42.39236444234848, 43.44359703361988, 45.485010892152786, 44.838346391916275, 39.73748490214348, 41.599609181284904, 40.56332118809223, 42.417211309075356, 42.309171706438065, 43.64926479756832, 45.717911794781685, 42.1360681951046, 43.44363123178482, 43.86090964078903, 48.71160015463829, 45.19143104553223, 45.19469507038593, 43.74015972018242, 42.86689817905426, 41.182383969426155, 42.3457333445549, 41.30808502435684, 40.664338767528534, 42.705551236867905, 43.80805067718029, 48.485690876841545, 42.030718848109245, 42.88538038730621, 41.89910151064396, 40.363831892609596, 40.49514524638653, 41.49184316396713, 42.301727905869484, 45.77733300626278, 45.06173260509968, 49.399093464016914, 48.34736689925194, 46.03387624025345, 41.65024906396866, 39.20714356005192, 40.472186878323555, 39.04181823134422, 36.58548563718796, 37.706372290849686, 36.674552857875824, 36.27986043691635, 40.33128663897514, 44.909520372748375, 44.490817040205, 44.327110424637794, 44.16099853813648, 40.08532963693142, 40.091466307640076, 38.679097294807434, 40.57116396725178, 41.9963762909174, 44.78987239301205, 46.34268566966057, 44.323835000395775, 44.35371659696102, 46.05418995022774, 43.52477207779884, 41.91067948937416, 43.21674920618534, 46.99318416416645, 46.88158415257931, 47.42074102163315, 55.417339727282524, 59.27774257957935, 62.23496049642563, 60.65001994371414, 62.54406251013279, 64.21406149864197, 62.276237681508064, 59.59228590130806, 61.77087239921093, 61.99977971613407, 63.63849878311157, 64.37912464141846, 66.8868912756443, 66.76142200827599, 65.52121415734291, 61.551464572548866, 59.26551103591919, 55.093137323856354, 56.15249767899513, 56.9241526722908, 62.391789481043816, 65.19150584936142, 70.16739204525948, 72.75235533714294, 77.6715561747551, 73.91018360853195, 76.08906269073486, 9.472651351243258, 0.7554171583615243, 38.422896042466164, 73.70585337281227, 50.429609566926956, 40.285495296120644, 33.58048528432846, 36.06885015964508, 61.25134527683258, 37.75439031422138, 0.1462647647713311, 0.04660211692680605, 0.12273772605112754, 0.08045439652050845, 0.058789053800865076, 0.08149372981279157, 0.03318224640679546, 0.010573027284408454, 0.018370017787674442, 0.027438275719759986, 0.06154924943984952, 0.026834251002583187, 0.041823094070423394, 0.019793677820416633, 0.12555844383314252, 0.036914870725013316, 0.33917929977178574, 4.87313543446362, 70.39540261030197, 48.22413571178913, 40.09085074067116, 46.2282358109951, 61.4515071362257, 59.11141410470009, 89.97262850403786, 18.13897266983986, 0.9567193721886724, 7.273129401728511, 83.13424944877625, 80.21492689847946, 78.37502762675285, 73.03775802254677, 68.28542903065681, 64.59680736064911, 65.58532431721687, 68.72691214084625, 74.18942302465439, 68.24020385742188, 74.91697758436203, 79.31622952222824, 54.88612063229084, 71.42035961151123, 68.76738756895065, 68.71732905507088, 65.08058980107307, 68.30945894122124, 65.33248588442802, 68.94933700561523, 65.63788309693336, 64.14270892739296, 60.56283742189407, 64.45477858185768, 62.22239077091217, 56.94189012050629, 55.883890092372894, 48.67470793426037, 50.99632255733013, 50.311082527041435, 46.81047476828098, 44.83619570732117, 43.958085626363754, 46.133396700024605, 44.87031027674675, 44.977247938513756, 47.198494747281075, 48.39382700622082, 46.80439889431, 47.37565264105797, 46.788857728242874, 45.175369307398796, 48.99848476052284, 46.721388548612595, 45.42047515511513, 45.41717313230038, 48.75607296824455, 45.37961594760418, 41.43372528254986, 45.42452193796635, 44.33784484863281, 44.69111569225788, 44.018456786870956, 45.55545911192894, 46.298220455646515, 46.82758145034313, 46.745475456118584, 47.821756303310394, 51.00193865597248, 48.36051419377327, 48.377875462174416, 47.906780540943146, 45.36287024617195, 43.68986561894417, 42.40560293197632, 43.82062040269375, 46.28712885081768, 45.141710713505745, 46.10839024186134, 49.60735268890858, 44.073481634259224, 45.435214564204216, 44.902205765247345, 45.983031168580055, 41.881554052233696, 44.184960052371025, 43.78565467894077, 47.74524360895157, 48.11082199215889, 51.96698047220707, 51.03409633040428, 47.9789424687624, 45.57898364961147, 41.241303607821465, 43.913753405213356, 43.274137526750565, 40.47991566359997, 40.14639616012573, 39.71214026212692, 39.10283915698528, 42.512662187218666, 47.57784739136696, 46.654519736766815, 46.56891033053398, 47.12410233914852, 42.90686443448067, 43.29146459698677, 41.946158185601234, 45.21406263113022, 45.648736506700516, 47.48725265264511, 47.58903779089451, 47.20941536128521, 45.33825136721134, 47.52615876495838, 47.37676978111267, 45.78666150569916, 46.09774701297283, 49.767510294914246, 48.91264736652374, 49.84042838215828, 57.42380306124687, 63.95538657903671, 63.67350250482559, 63.785110116004944, 65.25802507996559, 65.12917399406433, 64.60890591144562, 62.654438987374306, 65.45301541686058, 65.5987223982811, 67.44647204875946, 68.41299578547478, 68.80935251712799, 68.81341069936752, 69.27662864327431, 66.6322973370552, 63.81069794297218, 58.175687715411186, 59.072599187493324, 60.69496773183346, 65.53797125816345, 65.88253676891327, 74.15552884340286, 78.06041970849037, 81.09913945198059, 76.1211709678173, 82.23717838525772, 12.614410165697336, 0.7257327949628234, 45.01254424452782, 81.18082746863365, 55.766126811504364, 40.91403856873512, 41.84109382331371, 38.891703486442566, 67.83280491828918, 44.289602637290955, 0.060302485871943645, 0.022283709440671373, 0.04571964396745898, 0.0752128152817022, 0.032168109028134495, 0.013319231584318914, 0.10243362688925117, 0.04989445471437648, 0.12995267054066062, 0.16275406902423128, 0.2113807573914528, 0.17028099013259634, 0.15390152373583987, 0.11736582368030213, 0.18510668131057173, 0.19593164732214063, 0.8293182647321373, 8.609924744814634, 84.64184895157814, 56.939496248960495, 46.28755062818527, 44.339288771152496, 77.10547015070915, 63.58181722462177, 97.0072366297245, 18.85781429708004, 1.0891316388733685, 9.406143520027399, 87.86662951111794, 80.36743551492691, 81.11936196684837, 76.18753060698509, 70.62862649559975, 68.5148075222969, 67.97284260392189, 71.18496984243393, 77.20278292894363, 73.75394359230995, 70.9372079372406, 71.63721397519112, 61.66612721979618, 70.3188519179821, 71.4840441942215, 69.53114658594131, 67.66950488090515, 68.03738594055176, 69.36843931674957, 70.94627425074577, 69.37867596745491, 64.27522301673889, 66.25306248664856, 64.95428457856178, 62.9079195857048, 58.1808440387249, 58.60001474618912, 50.82902513444424, 52.92619340121746, 53.33168104290962, 50.256342664361, 47.61538177728653, 46.478642374277115, 48.45576748251915, 48.50627817213535, 45.9968738257885, 50.5567317456007, 50.64649432897568, 51.10332861542702, 49.03302490711212, 49.49719659984112, 49.51071247458458, 51.12060248851776, 48.476567566394806, 49.277188405394554, 47.1510124951601, 53.33844467997551, 49.23387072980404, 45.16613960266113, 48.72521102428436, 46.24060034751892, 45.249157547950745, 48.43212515115738, 47.661572098731995, 50.13468079268932, 48.867011815309525, 48.39787378907204, 51.21965557336807, 54.06464271247387, 54.290966168046, 49.49558548629284, 51.52731366455555, 50.002805069088936, 46.785753294825554, 46.52829810976982, 48.433759063482285, 49.11216326057911, 48.509580194950104, 50.024627298116684, 52.046058028936386, 46.62573628127575, 48.96708704531193, 48.33912894129753, 49.076828956604004, 45.864762514829636, 48.725769594311714, 47.510347813367844, 52.33394958078861, 51.215703785419464, 54.835222363471985, 57.272745966911316, 53.15212927758694, 48.83199289441109, 43.25592130422592, 48.682174533605576, 44.393595457077026, 41.26348301768303, 43.681243881583214, 43.998697847127914, 43.17762650549412, 46.24612145125866, 52.56550535559654, 48.279688730835915, 51.38437293469906, 50.7723131775856, 46.287467032670975, 46.1604892462492, 46.020006984472275, 49.86021392047405, 48.10966685414314, 51.281801238656044, 50.18391475081444, 47.857018411159515, 47.803312093019485, 51.70218028128147, 50.474466159939766, 48.00521045923233, 48.06329794228077, 50.76963812112808, 51.8996936827898, 52.19346731901169, 60.58162361383438, 65.74806958436966, 65.99957808852196, 67.37049132585526, 66.71175107359886, 66.84248685836792, 67.36286893486977, 65.7728062570095, 66.88635170459747, 69.19017568230629, 69.8280018568039, 68.63765493035316, 71.26913532614708, 72.423976957798, 72.00536102056503, 67.18448370695114, 66.92251056432724, 60.74399650096893, 62.24901594221592, 63.929844349622726, 69.06991973519325, 69.56064060330391, 77.92128637433052, 82.40882277488708, 84.60867673158646, 79.13595959544182, 88.2937341928482, 16.79579794406891, 0.9878017043229192, 48.86936768889427, 89.43857476115227, 65.5360409617424, 56.0933006554842, 51.145156770944595, 49.89153563976288, 81.0082483291626, 50.46676777303219, 0.34386453742627054, 0.15783707349328324, 0.23298681364394724, 0.19938019977416843, 0.14851842977805063, 0.13917600765125826, 0.23189714789623395, 0.0937344018893782], [0.05524974410946015, 0.044675508979707956, 0.0514704646775499, 0.03330258194182534, 0.03604376375733409, 0.11539304672623985, 0.06605446804314852, 0.06170946056954563, 0.21318730810889974, 2.1661229291930795, 52.55046956241131, 53.983045890927315, 47.36076883971691, 33.442309498786926, 53.17289896309376, 43.960882276296616, 80.63747942447662, 25.430409014225006, 0.4893791541690007, 2.777770645916462, 73.14058050513268, 78.66423010826111, 79.50041323900223, 73.61131444573402, 65.40499359369278, 59.409029334783554, 63.81644323468208, 67.93202519416809, 71.7364190518856, 63.022529035806656, 80.27574643492699, 54.02107045054436, 50.73322467505932, 71.86472296714783, 61.4985866099596, 67.03506052494049, 61.61916933953762, 65.85828647017479, 63.146174401044846, 63.248012736439705, 61.53136745095253, 61.17468439042568, 58.49604472517967, 64.82400476932526, 62.807376980781555, 58.73902268707752, 56.07898682355881, 45.446233972907066, 48.65999132394791, 46.89554080367088, 44.171934351325035, 43.32900658249855, 41.644655764102936, 42.1795454621315, 43.250761181116104, 42.06713229417801, 43.18998724222183, 42.69210375845432, 44.291464537382126, 44.85258422791958, 44.91484008729458, 44.47328098118305, 47.07556374371052, 41.37950599193573, 42.989912778139114, 42.14917749166489, 42.99783155322075, 42.71128512918949, 39.75414700806141, 41.05637513101101, 39.929085820913315, 42.28538118302822, 38.98568004369736, 42.91278451681137, 39.187263026833534, 41.66218042373657, 44.85394835472107, 45.334694758057594, 49.43916991353035, 44.2252416908741, 45.01138150691986, 42.036224752664566, 43.64198058843613, 40.594597309827805, 40.6253756582737, 39.97652247548103, 43.011609613895416, 41.74912355840206, 45.766670778393745, 48.392770662903786, 41.664737686514854, 43.5281652957201, 39.91724565625191, 41.749537736177444, 39.67069208621979, 43.176570162177086, 44.12255220115185, 45.23356318473816, 42.973748445510864, 49.9373459815979, 46.9701573997736, 43.28439697623253, 43.39869484305382, 40.599913224577904, 41.25552624464035, 39.11455772817135, 40.993249118328094, 39.012149423360825, 38.821342661976814, 36.84848092496395, 40.01939557492733, 44.82750177383423, 47.41103634238243, 46.29612296819687, 44.35250446200371, 43.13073702156544, 41.66813090443611, 37.559529170393944, 41.46212115883827, 41.04750260710716, 43.29776085913181, 45.89024014770985, 45.70022374391556, 44.41319100558758, 43.127586990594864, 43.735284581780434, 45.00581480562687, 43.290704637765884, 45.41121885180473, 48.24669510126114, 46.70496962964535, 52.582855224609375, 58.26269544661045, 60.41141554713249, 57.566633597016335, 61.71223774552345, 62.77344860136509, 63.58941301703453, 61.580267027020454, 62.17153809964657, 60.39483703672886, 64.38847973942757, 66.43824934959412, 68.27831581234932, 68.3839425444603, 66.94178313016891, 68.59078824520111, 65.83491012454033, 61.29916571080685, 57.78485968708992, 55.82614079117775, 58.566793128848076, 64.0251812338829, 70.13361185789108, 74.4863922894001, 79.0221557021141, 74.38192069530487, 82.02640369534492, 10.456953383982182, 0.4056363977724686, 45.40230453014374, 72.21363544464111, 52.443953678011894, 36.93919725716114, 36.43265783786774, 37.13340483605862, 65.77146872878075, 31.610482893884182, 0.3134929749649018, 0.030828246744931675, 0.0468517976696603, 0.005749014508182881, 0.025223406482837163, 0.07520808780100197, 0.04448933010280598, 0.03496983525110409, 0.07299823919311166, 0.008918089915823657, 0.018458043923601508, 0.007645173063792754, 0.02480324328644201, 0.05631248473946471, 0.05439454136649147, 0.03321332384075504, 0.19820017012534663, 2.1225663414224982, 63.13634052872658, 57.14874342083931, 43.781908079981804, 40.88822655379772, 59.33797314763069, 48.040981739759445, 88.87840121984482, 29.1056003049016, 0.45440307003445923, 2.9123323503881693, 77.2340476512909, 80.50576329231262, 80.8388078212738, 75.6020276248455, 68.06145384907722, 61.15907482802868, 66.44666209816933, 68.28742012381554, 74.25066813826561, 66.08350038528442, 84.71887081861496, 68.56516242027283, 53.67557018995285, 73.78403797745705, 65.77456936240196, 70.66847875714302, 64.37622159719467, 68.50851505994797, 64.46618556976318, 66.21029198169708, 64.13238868117332, 63.80749851465225, 62.43736803531647, 67.60012060403824, 64.97321516275406, 63.1684298068285, 57.63070575892925, 48.37798185646534, 50.40858529508114, 47.990721836686134, 47.72471331059933, 44.49144780635834, 44.71390686929226, 45.47476664185524, 46.25622510910034, 43.6113466322422, 46.67138323187828, 45.62756784260273, 44.98523510992527, 48.30578193068504, 46.69368803501129, 48.8446956127882, 49.16452445089817, 44.75369453430176, 45.14574609696865, 44.21475425362587, 45.69067105650902, 43.1811261177063, 42.24467396736145, 43.189569264650345, 43.07381987571716, 43.199490532279015, 41.07448875904083, 43.28852355480194, 42.952800169587135, 45.50322711467743, 46.75514213740826, 48.28889183700085, 53.23747269809246, 50.48579715192318, 47.06438474357128, 46.94474436342716, 46.49024695158005, 44.010481014847755, 43.12823675572872, 43.97837653756142, 46.441134586930275, 44.84026908874512, 48.350923508405685, 51.620693653821945, 44.694721698760986, 46.49322219192982, 42.96351559460163, 43.75076875090599, 42.742948830127716, 45.89872129261494, 45.87881796061993, 48.23209248483181, 47.098104134202, 53.809243217110634, 48.368596360087395, 47.87481665611267, 45.12295491993427, 43.05445231497288, 45.41545182466507, 41.105825677514076, 41.141068786382675, 40.63495494425297, 41.701010540127754, 38.65140438079834, 41.85101889073849, 46.04838386178017, 48.19163605570793, 49.305462688207626, 47.701542153954506, 45.30683845281601, 46.19978293776512, 42.646718993783, 45.076152831315994, 45.709670037031174, 47.317150980234146, 48.262992426753044, 47.391600385308266, 46.52199424803257, 44.31489408016205, 47.02884525060654, 46.91505275666714, 46.03859558701515, 50.00036180019379, 50.600915774703026, 48.22009652853012, 54.29633907973766, 60.553045347332954, 63.85441079735756, 60.999076813459396, 63.797132670879364, 64.89171713590622, 65.93634188175201, 65.68926393985748, 64.57507252693176, 63.697350025177, 69.0089862048626, 68.07957887649536, 70.17398089170456, 71.0361622273922, 70.95406383275986, 71.90810143947601, 71.04658886790276, 66.10580518841743, 61.60155728459358, 58.97188559174538, 62.54210941493511, 67.04822301864624, 76.29340812563896, 77.10625290870667, 83.48577618598938, 76.08165308833122, 87.84855768084526, 12.93641533702612, 0.3615109983365983, 48.7432486563921, 81.76143631339073, 57.76266887784004, 47.17957176268101, 44.573785588145256, 40.031577721238136, 76.83506146073341, 35.39731599390507, 0.31471552967559546, 0.04903638728137594, 0.027630248914647382, 0.02012355689657852, 0.01737474580295384, 0.11278237157966942, 0.10043353890068829, 0.06670215516351163, 0.20679348323028535, 0.2924431435531005, 0.09887562991934828, 0.16764920088462532, 0.1419783869641833, 0.27743988612201065, 0.228800967161078, 0.2819866390200332, 0.4989323462359607, 4.570402354001999, 77.70861178636551, 67.71529242396355, 57.858104556798935, 42.94946774840355, 69.78391662240028, 53.83624456822872, 94.86698627471924, 30.311972871422768, 0.7236530003137887, 4.273526659235358, 82.29189544916153, 80.16153216362, 84.35842975974083, 76.61965101957321, 71.30322709679604, 65.03800168633461, 69.09588754177094, 73.06049600243568, 76.09247490763664, 70.66028639674187, 71.90634593367577, 69.72823441028595, 57.37543165683746, 74.28891688585281, 68.07750418782234, 73.03426221013069, 67.73015722632408, 70.0566203892231, 67.90466666221619, 68.23440536856651, 67.02178403735161, 65.6350028514862, 64.63421255350113, 64.85010176897049, 69.89262118935585, 63.33671137690544, 59.54303674399853, 50.26553437113762, 53.668593764305115, 50.60938932001591, 51.75366751849651, 47.93266475200653, 46.85900956392288, 48.140745386481285, 48.787193298339844, 46.11497148871422, 49.977369233965874, 48.701055720448494, 47.29271449148655, 51.78483724594116, 52.957154139876366, 50.522032007575035, 50.65898805856705, 46.43639624118805, 49.73249897360802, 47.75549165904522, 48.90803441405296, 48.195823431015015, 46.091781333088875, 45.479417592287064, 44.99783903360367, 45.58009319007397, 45.49460157752037, 46.59793697297573, 44.48714643716812, 47.48558074235916, 51.211151629686356, 51.0700424015522, 59.29935961961746, 52.21840538084507, 50.8240170031786, 47.657901495695114, 50.18828071653843, 47.938189655542374, 47.357744202017784, 47.05970339477062, 51.31069868803024, 48.48267763853073, 51.84922859072685, 55.576418191194534, 45.982199013233185, 49.79407846927643, 46.56005300581455, 46.964727491140366, 45.96515692770481, 48.94181080162525, 49.90860052406788, 51.321170926094055, 50.5891440063715, 56.57567337155342, 52.07459829747677, 50.82714043557644, 49.347420036792755, 46.98487401008606, 47.664676532149315, 45.1934639364481, 45.03180541098118, 44.50603902339935, 44.8085255920887, 42.89829969406128, 47.953882813453674, 49.9628122150898, 51.51222467422485, 53.29437844455242, 54.053490310907364, 49.10290315747261, 49.79941338300705, 44.743986055254936, 48.22241060435772, 47.70377263426781, 49.49957527220249, 50.48147298395634, 50.72987325489521, 50.124212354421616, 48.59105922281742, 48.38986001908779, 50.44078856706619, 48.35199885070324, 52.635034024715424, 53.0312729626894, 49.154416993260384, 55.22442787885666, 62.1529570966959, 64.84326213598251, 62.16579660773277, 66.12093597650528, 66.7934998869896, 70.26009947061539, 67.05776050686836, 65.69580718874931, 65.48223584890366, 71.79572626948357, 69.75158035755157, 73.39577481150627, 73.74211862683296, 73.02774176001549, 74.50718477368355, 72.61699140071869, 66.14455550909042, 64.18113246560097, 64.03854131698608, 65.52125975489616, 71.23397961258888, 79.22103703022003, 81.3823002576828, 86.95319652557373, 81.75104767084122, 88.33689227700233, 15.214683786034584, 0.568058593198657, 54.12818670272827, 87.95137256383896, 67.94581085443497, 56.61437429487705, 51.41276501119137, 50.54375924170017, 84.91054013371468, 45.38003772497177, 0.4671544732991606, 0.38672519847750664, 0.12508559186244383, 0.15086300787515938, 0.14351880352478474, 0.19359655387233943, 0.18238898104755208, 0.18484088854165748], [0.0957082178501878, 0.01444297860871302, 0.12734955787891522, 0.06271088495850563, 0.018896497349487618, 0.05417034597485326, 0.05092275969218463, 0.05847240907314699, 0.021792426232423168, 0.23542214155895635, 41.21417686343193, 54.71265994012356, 54.547148421406746, 35.78613393008709, 50.376382023096085, 49.841625317931175, 76.89440667629242, 36.92556358873844, 0.2582644228823483, 0.8914572803769261, 59.62830796837807, 83.05959865450859, 73.92182618379593, 75.88841825723648, 63.39941941201687, 63.11154305934906, 65.4036408662796, 71.7032316327095, 65.8911395072937, 69.06534478068352, 72.4028804898262, 39.477491453289986, 62.406563088297844, 61.916484385728836, 65.08835658431053, 64.65312033891678, 66.35680451989174, 63.14045950770378, 64.5979169011116, 63.061811327934265, 61.59347891807556, 60.47326102852821, 63.916020691394806, 58.7738174200058, 55.91724470257759, 60.84070511162281, 56.157224625349045, 46.455463618040085, 46.39899864792824, 46.582103222608566, 43.770641684532166, 40.85598528385162, 43.99072967469692, 40.03098875284195, 42.8234589099884, 43.33775371313095, 42.00037367641926, 41.64594009518623, 43.11378613114357, 42.50649891793728, 45.91697171330452, 44.71117101609707, 49.96319979429245, 43.3331635594368, 40.79290106892586, 40.00158213078976, 42.67959862947464, 40.19948311150074, 41.24970495700836, 42.59215012192726, 39.62108954787254, 40.272291004657745, 40.47337621450424, 41.00939825177193, 39.718436524271965, 40.346064046025276, 40.71608439087868, 47.66536429524422, 49.8323842138052, 46.20698355138302, 47.0698906481266, 45.53687810897827, 41.78218938410282, 41.598571836948395, 42.00046107172966, 40.88264845311642, 42.904341369867325, 45.123771876096725, 46.89071886241436, 51.04645326733589, 42.22403347492218, 40.76156035065651, 40.35927213728428, 40.041179805994034, 38.49534675478935, 42.61023335158825, 43.83238457143307, 46.57597795128822, 46.155598908662796, 49.34191793203354, 47.47140370309353, 41.615678519010544, 41.00957304239273, 41.737173199653625, 39.150553196668625, 39.916250109672546, 38.252809569239616, 37.969656363129616, 37.89776802062988, 38.980816304683685, 36.25128977000713, 41.529240757226944, 44.78685915470123, 42.880452051758766, 42.57435567677021, 40.48763684928417, 44.85285021364689, 42.592488303780556, 39.80534926056862, 41.97353191673756, 41.86344042420387, 42.810881584882736, 45.10367855429649, 43.38280029594898, 43.54383185505867, 44.86744903028011, 44.80353266000748, 43.95916476845741, 44.44753736257553, 47.44242645800114, 45.32665058970451, 51.45124934613705, 59.983421713113785, 60.284840539097786, 59.30386617779732, 60.54668448865414, 62.41280995309353, 62.469377517700195, 63.49931985139847, 61.350546553730965, 62.98484645783901, 63.727991580963135, 65.57270899415016, 63.78946468234062, 67.19497874379158, 67.46568381786346, 69.2415489256382, 67.53443732857704, 70.60533374547958, 67.53745436668396, 61.643852815032005, 59.76226978003979, 60.499631613492966, 67.83437803387642, 69.14450213313103, 76.39569863677025, 70.08210182189941, 90.53894251585007, 16.037360541522503, 1.0105890221893787, 47.41563029587269, 71.02359250187874, 51.44567884504795, 26.682050451636314, 36.59836694598198, 34.656914323568344, 66.72305166721344, 27.008587829768658, 0.49715561501216143, 0.13692042790353298, 0.09569147499860264, 0.01576772890985012, 0.0770626703160815, 0.03128237804048695, 0.040380559366894886, 0.019180166600563098, 0.11248825845541432, 0.04240238115016837, 0.169262065901421, 0.04702752339653671, 0.06286363379331306, 0.008068105398706393, 0.02993963993503712, 0.014114559708104935, 0.03922307616448961, 0.44038585969246924, 53.89294132590294, 60.44870674610138, 47.80100181698799, 34.97580461204052, 60.30664376914501, 56.12790919840336, 83.57324749231339, 42.28701129555702, 0.39982452057302, 1.1923211580142379, 61.188466250896454, 83.57327029109001, 78.10440614819527, 78.79028454422951, 68.31278756260872, 64.75482568144798, 69.09409403800964, 72.22324132919312, 69.28907677531242, 73.47019001841545, 87.76227951049805, 46.69148035347462, 65.38015812635422, 64.46364730596542, 68.68507638573647, 66.41291990876198, 67.59776473045349, 65.47779768705368, 65.15232995152473, 65.31502962112427, 63.34352821111679, 64.35096055269241, 65.75463563203812, 62.3786535859108, 57.85949148237705, 61.63829371333122, 57.420649230480194, 48.31454426050186, 48.18722829222679, 51.08157478272915, 46.93236842751503, 44.667237773537636, 45.504853427410126, 43.757494390010834, 45.16287557780743, 43.6729147285223, 47.321007773280144, 44.97974820435047, 45.662199184298515, 44.81922581791878, 49.0986093878746, 45.81015944480896, 51.00951924920082, 49.15784440934658, 42.69198216497898, 42.8016746789217, 43.858777955174446, 41.36152155697346, 44.13681663572788, 45.35921864211559, 42.8647892922163, 43.289967477321625, 44.02254156768322, 43.13063442707062, 44.231024980545044, 44.58587273955345, 44.89520654082298, 48.84825982153416, 53.54888878762722, 51.005388870835304, 51.028601825237274, 47.764303386211395, 47.285730466246605, 43.68104249238968, 43.126842230558395, 43.75022158026695, 44.51007440686226, 46.77902765572071, 47.04552635550499, 53.69305305182934, 44.82142210006714, 44.426729679107666, 44.56747032701969, 42.96607285737991, 43.555257841944695, 42.67685517668724, 45.044914707541466, 48.50587539374828, 49.33174207806587, 51.58572793006897, 49.580689519643784, 46.182300075888634, 44.56214301288128, 44.38778176903725, 42.250913232564926, 40.2310062199831, 40.76334245502949, 38.98932404816151, 39.965582862496376, 40.86293511092663, 39.434109181165695, 44.914099127054214, 46.4854022115469, 45.80795556306839, 45.81402763724327, 44.404888451099396, 47.840914875268936, 45.22680714726448, 44.176505506038666, 45.718040987849236, 43.70582856237888, 46.21014878153801, 47.36408606171608, 45.59357866644859, 45.03939740359783, 45.676433220505714, 48.40755566954613, 48.48700560629368, 46.10054366290569, 49.92952220141888, 48.458731323480606, 54.66651141643524, 62.94138438999653, 63.886762261390686, 63.02640862762928, 63.093513026833534, 65.42754918336868, 65.98003953695297, 65.15970155596733, 65.77543571591377, 67.09350898861885, 67.11491703987122, 66.271962672472, 68.42285245656967, 70.7696521282196, 72.74680003523827, 73.02917808294296, 71.27671211957932, 70.88259726762772, 70.81735476851463, 68.18610236048698, 63.536242470145226, 64.47041854262352, 70.64634874463081, 71.43918380141258, 81.07688024640083, 74.88998383283615, 93.613091558218, 18.619996458292007, 0.7641704042907804, 51.385022699832916, 79.0967532992363, 55.98420470952988, 37.13117815554142, 47.171466797590256, 37.24750131368637, 76.75027281045914, 30.053486041724682, 0.33789030800107867, 0.1357108904630877, 0.010967058533424279, 0.03225614629627671, 0.0999187704292126, 0.024449418815493118, 0.014541480159095954, 0.03372912389750127, 0.18782426282996312, 0.13139801798388362, 0.3006813983665779, 0.17510448989924043, 0.12848421261878684, 0.0946036349341739, 0.12034820349072106, 0.14844273071503267, 0.19599913823185489, 0.9309135912917554, 68.1569655239582, 68.99155274033546, 65.62483459711075, 46.408539935946465, 71.98479652404785, 62.33631245791912, 90.8669713139534, 44.31901305913925, 0.9327387996017933, 2.5272363144904375, 68.83989527821541, 82.4196445941925, 82.60803088545799, 81.15383371710777, 71.37794628739357, 63.32227975130081, 73.05238723754883, 73.15206348896027, 75.93813478946686, 66.36283859610558, 73.74380573630333, 54.064562916755676, 67.40759253501892, 67.35294386744499, 69.32174742221832, 68.70074674487114, 67.84232720732689, 66.77286699414253, 69.01521027088165, 66.87863051891327, 65.3569945693016, 67.06872671842575, 65.42796716094017, 63.59034016728401, 60.49058809876442, 64.51470896601677, 59.53535735607147, 50.88075935840607, 51.54503971338272, 54.004894718527794, 48.581639528274536, 47.39999793469906, 49.69224393367767, 44.889180064201355, 48.75253535807133, 47.46188901364803, 49.669445157051086, 46.247428581118584, 48.3996444940567, 47.802042961120605, 50.710437297821045, 49.8280144482851, 56.86384990811348, 51.548421531915665, 45.653642043471336, 46.50036200881004, 48.77471096813679, 45.06944619119167, 46.10996335744858, 48.89658562839031, 44.53707955777645, 45.55332362651825, 47.15713396668434, 48.00342835485935, 45.55393919348717, 48.21746326982975, 46.6670286655426, 54.393412470817566, 58.78952197730541, 51.95215366780758, 53.324883207678795, 52.207081988453865, 50.71396350860596, 48.14074918627739, 48.36195811629295, 50.16271948814392, 50.54502457380295, 53.13771665096283, 50.533883571624756, 56.22864179313183, 48.42841275036335, 48.59615474939346, 48.909698724746704, 46.884471997618675, 45.088638961315155, 47.4216415733099, 48.26457694172859, 52.33352780342102, 52.95042470097542, 55.72695851325989, 55.72681412100792, 49.248522743582726, 49.53104518353939, 48.617885783314705, 44.024783447384834, 44.56963241100311, 42.57318913936615, 41.09562322497368, 42.32040770351887, 46.218420937657356, 41.313473135232925, 47.33776107430458, 49.8560531437397, 48.502516373991966, 48.65750625729561, 47.67782762646675, 49.408148378133774, 48.166394010186195, 46.7137585580349, 47.25549168884754, 47.84664496779442, 48.857227340340614, 51.579017490148544, 47.709206342697144, 47.0150937885046, 50.22282466292381, 50.209107398986816, 52.022757679224014, 46.910265013575554, 51.131728291511536, 50.05392372608185, 55.15987314283848, 65.98584562540054, 65.78966215252876, 64.22477692365646, 65.0593489408493, 67.07644790410995, 66.87041535973549, 67.9744005203247, 67.29416102170944, 69.57239717245102, 69.37374383211136, 70.54823040962219, 71.01645648479462, 73.24705839157104, 74.18718114495277, 76.36388674378395, 73.62240225076675, 77.22675204277039, 73.31122934818268, 69.65906292200089, 65.87463319301605, 69.28206235170364, 75.81189796328545, 74.91839110851288, 83.9057144522667, 78.35781455039978, 97.3330083489418, 20.097294487059116, 1.1121436790563166, 57.536261826753616, 88.09369772672653, 68.68203654885292, 40.8352117985487, 52.11608827114105, 48.95194485783577, 85.31706511974335, 38.2734614610672, 0.5972450051922351, 0.300267250277102, 0.23429484892403707, 0.0916557278833352, 0.20049380720593035, 0.12953139783348888, 0.21137127274414524, 0.12689668452367187], [0.020232040333212353, 0.03465835216047708, 0.03054590222745901, 0.018188327048846986, 0.052703713736264035, 0.056998893414856866, 0.023690446651016828, 0.04637114943761844, 0.026081026771862525, 0.20466107031097636, 38.45223806798458, 54.946510791778564, 47.338331043720245, 46.11230403184891, 44.524023458361626, 47.28959105908871, 73.08307439088821, 49.24218088388443, 0.1929106906754896, 0.5541969370096922, 46.064890176057816, 81.45549952983856, 68.52211073040962, 77.8840559720993, 62.77769677340984, 66.90968245267868, 64.38024938106537, 76.0336084663868, 63.31078916788101, 82.31033205986023, 42.635312005877495, 46.91381022334099, 66.62599727511406, 64.56561863422394, 69.08872872591019, 64.25041034817696, 64.25541087985039, 63.43599624931812, 61.365646943449974, 64.09409433603287, 62.64530047774315, 61.76797695457935, 58.17296706140041, 53.3084262907505, 59.11124691367149, 60.80799646675587, 57.01198875904083, 45.27916073799133, 46.18657864630222, 47.1416611969471, 45.063814893364906, 43.49794551730156, 42.05877274274826, 43.237838074564934, 41.7699920386076, 41.66577883064747, 42.441666796803474, 41.450220197439194, 42.68011920154095, 42.494867742061615, 42.539279758930206, 44.864166006445885, 51.38665661215782, 40.34510649740696, 40.12519709765911, 37.9903082549572, 38.70624303817749, 42.03827664256096, 43.58049228787422, 40.59441491961479, 40.26751846075058, 40.742257386446, 40.724580734968185, 41.65145739912987, 39.442985504865646, 43.76287870109081, 43.74454088509083, 47.29235351085663, 51.28326416015625, 47.46853865683079, 46.500476002693176, 45.056652277708054, 43.30785311758518, 41.634373515844345, 42.66457423567772, 41.42320364713669, 42.707352340221405, 41.01680405437946, 48.80317524075508, 51.028191447257996, 42.57276736199856, 43.59260603785515, 40.33931940793991, 42.714408561587334, 41.16883769631386, 43.97070474922657, 46.01633258163929, 44.26353223621845, 45.572744384408, 44.8685547709465, 47.57220469415188, 44.30673211812973, 44.176315516233444, 39.10420708358288, 39.875478297472, 37.71454945206642, 38.894256949424744, 38.92995983362198, 40.4459872841835, 38.438623398542404, 36.65751077234745, 43.68999481201172, 41.96596272289753, 39.192742332816124, 39.05947968363762, 46.19964234530926, 47.1489530056715, 42.20514468848705, 43.77899743616581, 39.55528847873211, 41.07234187424183, 42.2115283459425, 41.73615485429764, 43.7119310349226, 41.948559656739235, 43.19625310599804, 42.49789997935295, 45.76861247420311, 44.78663116693497, 46.48319832980633, 45.61212547123432, 51.31033390760422, 59.67316456139088, 61.29238307476044, 58.97241376340389, 56.603940054774284, 64.30358469486237, 63.08280900120735, 62.46947631239891, 63.84546607732773, 62.66365349292755, 60.20417466759682, 62.045282274484634, 63.53508733212948, 64.84826266765594, 66.1813223361969, 66.40955328941345, 69.70266178250313, 67.28516310453415, 68.70079234242439, 67.57946491241455, 64.02369171380997, 56.774543300271034, 61.30679190158844, 67.35843077301979, 75.83665743470192, 69.1063141822815, 87.27754712104797, 19.01085488498211, 0.35514883347786963, 53.74509505927563, 62.94797323644161, 49.81934331357479, 20.72212725877762, 29.987422786653042, 44.19197827577591, 71.52581915259361, 23.66672795265913, 0.3000332065857947, 0.0266500666475622, 0.1326926946057938, 0.03130781144136563, 0.01578082410560455, 0.05751560260250699, 0.07113218307495117, 0.09134625972365029, 0.03016436967300251, 0.04880700056673959, 0.017342184073640965, 0.0791536713950336, 0.08470837958157063, 0.10881332127610222, 0.009149075031018583, 0.08008373828488402, 0.04272376449080184, 0.21897960745263845, 45.46227291226387, 63.112850189208984, 37.69377216696739, 51.13616645336151, 54.94822070002556, 54.18710634112358, 79.60521921515465, 53.78871291875839, 0.2635505626676604, 0.5965251813177019, 46.7218217253685, 81.59359931945801, 72.39056915044785, 81.96141958236694, 66.65017157793045, 68.8545472919941, 67.1229650080204, 78.09596300125122, 66.91273748874664, 94.02422949671745, 54.291691929101944, 50.86999073624611, 68.5435339808464, 66.02925449609756, 70.05560964345932, 64.64788421988487, 66.31692185997963, 65.11174812912941, 65.06705492734909, 64.84786748886108, 65.12317031621933, 65.98060950636864, 62.234656512737274, 55.75528219342232, 63.51924978196621, 62.59402982890606, 58.76838371157646, 48.73842291533947, 49.11093972623348, 48.74188452959061, 46.545940563082695, 46.26671254634857, 44.87871542572975, 46.31512954831123, 43.665277138352394, 44.11649152636528, 43.506533056497574, 44.80709306895733, 43.64921160042286, 46.437334790825844, 46.829899325966835, 47.05208100378513, 53.750186786055565, 45.261951461434364, 43.615309819579124, 40.97383975982666, 40.11953540146351, 43.57460260391235, 45.68135015666485, 44.75708395242691, 42.47972175478935, 41.998382583260536, 41.74077920615673, 43.100566640496254, 44.70634147524834, 45.95121927559376, 46.35237514972687, 51.91439129412174, 53.84718418121338, 49.066660702228546, 49.20602962374687, 49.72563274204731, 46.798231825232506, 43.224436193704605, 44.79794695973396, 45.2913960814476, 47.56372734904289, 43.98403823375702, 50.47000139951706, 53.3172532171011, 46.79487280547619, 46.01371832191944, 43.53640325367451, 44.344980865716934, 45.16569122672081, 44.67581011354923, 48.49091939628124, 47.69769676029682, 49.22464482486248, 50.56442253291607, 51.93727366626263, 45.52282266318798, 45.78796483576298, 41.151351034641266, 42.60807506740093, 39.604001864790916, 41.47554203867912, 41.05194836854935, 41.5620443969965, 42.496942430734634, 39.341660141944885, 45.35941623151302, 45.06510682404041, 41.82819351553917, 42.70650498569012, 48.1450429558754, 46.800116524100304, 44.29878294467926, 46.5620668977499, 43.213348388671875, 43.612558767199516, 44.97201181948185, 44.86170753836632, 47.9971244931221, 44.84736330807209, 46.64402849972248, 46.036042124032974, 47.906856536865234, 47.1025612950325, 49.2081119120121, 46.661268174648285, 54.91734355688095, 61.824267134070396, 64.73063617944717, 61.38880290091038, 58.69078807532787, 63.62165428698063, 66.35638654232025, 66.0569854080677, 65.63179582357407, 64.0102556347847, 63.58783610165119, 63.72263386845589, 67.88471013307571, 67.87071168422699, 70.70454642176628, 70.15041455626488, 73.37397918105125, 72.36011758446693, 73.48537400364876, 71.01985350251198, 68.38088750839233, 62.229135408997536, 63.67598757147789, 70.08516445755959, 80.0095783174038, 73.21225985884666, 94.27450686693192, 20.64869999885559, 0.18044479162199423, 60.12223206460476, 69.43056598305702, 57.090728133916855, 33.137410059571266, 35.08818358182907, 42.52832494676113, 81.402537971735, 26.873132698237896, 0.3718414268223569, 0.09109435995924287, 0.035092623584205285, 0.06351639720378444, 0.05820520993438549, 0.06677366851363331, 0.017315181030426174, 0.006835897665951052, 0.1369874586816877, 0.20208111265674233, 0.08972448151325807, 0.19800832495093346, 0.18219814519397914, 0.27851273480337113, 0.1314913504756987, 0.227876830031164, 0.1712270948337391, 0.3978328040102497, 57.13603690266609, 71.44333317875862, 61.38569466769695, 63.55450049042702, 61.344630271196365, 60.46521686017513, 84.9154494702816, 59.12378244102001, 0.30074228416197, 0.8317331539001316, 52.19046927988529, 82.25153401494026, 77.16927632689476, 83.85802701115608, 69.42618861794472, 71.62693932652473, 70.85932731628418, 80.16514956951141, 72.11616307497025, 75.77238008379936, 60.28145872056484, 56.23697094619274, 70.63013881444931, 66.99781492352486, 71.91507786512375, 66.18259906768799, 68.03491607308388, 68.27810302376747, 68.45476314425468, 68.90069961547852, 66.63197055459023, 65.80119833350182, 66.35691851377487, 58.44130106270313, 65.44460266828537, 64.40956860780716, 63.25372003018856, 51.77659548819065, 49.50443521142006, 50.51027923822403, 51.279323771595955, 49.14010316133499, 46.81712061166763, 49.919840320944786, 46.08077332377434, 46.99685096740723, 46.659501269459724, 47.725568264722824, 47.28138729929924, 48.58278326690197, 48.4692757576704, 50.83763927221298, 57.01844461262226, 46.734174862504005, 47.94062912464142, 44.77247692644596, 43.453822284936905, 47.80377186834812, 48.36329184472561, 46.221677362918854, 45.36356940865517, 45.74077896773815, 43.35799902677536, 46.13044425845146, 46.03382304310799, 48.6705357581377, 49.97211791574955, 57.31830172240734, 60.67782685160637, 54.22118291258812, 52.95048549771309, 52.946503311395645, 51.78353771567345, 47.71946959197521, 50.52943401038647, 47.61035084724426, 52.729303166270256, 48.647752180695534, 53.60269770026207, 56.68512649834156, 47.20602214336395, 50.164866372942924, 48.31255316734314, 49.01984341442585, 48.8781414180994, 49.4354423135519, 53.951351791620255, 50.783514976501465, 54.28348436951637, 53.086339607834816, 54.861368760466576, 49.42243181169033, 49.15618009865284, 44.19429615139961, 46.32767267525196, 42.20759555697441, 43.39491784572601, 43.50168451666832, 44.448570907115936, 43.50767679512501, 41.53062768280506, 49.33565966784954, 51.09533004462719, 45.74775159358978, 46.4850640296936, 51.21721610426903, 50.434705093503, 48.667613714933395, 50.493449941277504, 43.4097408503294, 45.4599816352129, 47.87677735090256, 47.292273715138435, 50.98406061530113, 47.72687919437885, 49.817887991666794, 49.81803238391876, 50.546213909983635, 49.337772354483604, 50.275847017765045, 49.199668765068054, 56.26194700598717, 64.73776459693909, 66.9384241104126, 64.22547608613968, 61.22150167822838, 68.18813145160675, 67.56130188703537, 68.34730491042137, 68.80848616361618, 67.26120918989182, 65.33240228891373, 65.91510102152824, 70.47316163778305, 67.8691765666008, 71.44669219851494, 70.91660544276237, 78.2172828912735, 71.85565665364265, 74.99041244387627, 75.05695447325706, 70.52787870168686, 63.576964884996414, 67.7694471180439, 75.88546201586723, 82.48835250735283, 76.21667504310608, 95.0424912571907, 23.91511682420969, 0.47094634326640517, 64.45464178919792, 76.77668899297714, 68.98948565125465, 32.801329493522644, 39.94032561779022, 58.86635385453701, 91.91411152482033, 34.31036151945591, 0.6547766493167728, 0.30337907548528165, 0.16194025956792757, 0.11930996115552261, 0.18361288646701723, 0.13725708093261346, 0.09557732526445761, 0.1428489261888899], [0.016542382654733956, 0.013779718447040068, 0.024387173034483567, 0.023173928566393442, 0.12245286750840023, 0.0680085651401896, 0.13300242251716554, 0.0498832742596278, 0.11348301835823804, 0.22721579909557477, 31.17955181747675, 56.471144780516624, 44.37241919338703, 21.47975530475378, 43.31810496747494, 41.59344211220741, 62.710219994187355, 63.63856337964535, 2.4950974015519023, 1.1577787552960217, 29.744610115885735, 75.9877297282219, 71.89919471740723, 75.41125506162643, 67.03785717487335, 67.00429737567902, 70.79110577702522, 67.44294583797455, 69.57737490534782, 49.90917809307575, 33.9906694740057, 70.60358583927155, 64.15081769227982, 69.11269024014473, 62.542018219828606, 66.13237336277962, 61.55952014029026, 62.800894528627396, 64.4649164378643, 64.15970161557198, 59.35019329190254, 57.25670322775841, 55.58004319667816, 59.99256022274494, 57.444017976522446, 62.613002210855484, 48.80578950047493, 45.55747300386429, 45.74114374816418, 45.81014044582844, 44.324427768588066, 42.851862385869026, 43.79140757024288, 42.94621892273426, 41.080887615680695, 44.91258680820465, 44.32632766664028, 43.43858130276203, 41.90991573035717, 44.769334495067596, 42.190260887145996, 41.79540507495403, 46.41833961009979, 45.31075604259968, 41.06543384492397, 38.95545266568661, 41.01467236876488, 41.48530371487141, 39.9702338129282, 42.42970883846283, 36.01371131837368, 41.06923744082451, 42.02109016478062, 39.82419244945049, 40.25574669241905, 41.44759453833103, 44.84345331788063, 48.29282082617283, 47.49215818941593, 49.81869734823704, 47.09480971097946, 48.33994209766388, 44.993978440761566, 43.98040942847729, 43.90054151415825, 41.353211402893066, 39.33737397193909, 43.87263961136341, 50.07337488234043, 51.44377514719963, 42.96904809772968, 44.31379213929176, 41.49450682103634, 43.123335018754005, 43.39947760105133, 45.06742089986801, 44.4356743991375, 45.72376348078251, 45.583551004529, 46.980530843138695, 46.49111710488796, 43.418894559144974, 42.66213096678257, 38.984521105885506, 37.19029538333416, 39.62535671889782, 37.27497383952141, 38.49234491586685, 39.22694429755211, 39.807454347610474, 33.670107275247574, 41.44654579460621, 39.39448490738869, 35.82788988947868, 38.976716324687004, 48.094688057899475, 48.18067744374275, 42.15098239481449, 40.99683232605457, 40.40461890399456, 41.196439415216446, 43.08291658759117, 45.40123678743839, 42.08584628999233, 40.79700484871864, 44.43389229476452, 42.427132576704025, 45.83582326769829, 44.574891328811646, 46.100889444351196, 45.36005839705467, 52.360947132110596, 60.29423363506794, 61.21351830661297, 57.03960567712784, 54.05910640954971, 58.804006800055504, 61.964152827858925, 65.44800728559494, 64.82452914118767, 62.59348265826702, 63.11975821852684, 65.08041501045227, 65.33113315701485, 64.33430224657059, 66.68329820036888, 67.45721787214279, 67.89063781499863, 67.29696527123451, 70.14257937669754, 67.20902279019356, 68.40138360857964, 60.91907970607281, 62.01576925814152, 60.84874548017979, 75.80289244651794, 68.19489508867264, 91.98326781392097, 13.776081930845976, 0.10154337622225285, 65.63303455710411, 60.24131007492542, 48.99883434176445, 23.527136743068695, 52.76860065758228, 52.467235028743744, 74.96263593435287, 18.743161149322987, 0.32778350345324725, 0.034383364181849174, 0.01878974126157118, 0.0396363930485677, 0.025478490060777403, 0.0686582486378029, 0.031965124217094854, 0.05723061789467465, 0.04304548921936657, 0.013669597647094633, 0.0917411119735334, 0.07162712878198363, 0.09814424338401295, 0.05096853165014181, 0.05429062213806901, 0.03972483849793207, 0.15729227772681043, 0.4296656255610287, 37.73520514369011, 62.93384939432144, 43.863303512334824, 32.324508279562, 53.283894807100296, 50.966748744249344, 69.23015713691711, 69.95143443346024, 3.075372576713562, 0.6900743208825588, 36.41928255558014, 79.71909150481224, 76.78314864635468, 77.3978416621685, 70.36890283226967, 68.94028589129448, 74.96833562850952, 68.35269302129745, 81.573695987463, 62.98780269920826, 40.9559541195631, 71.19693920016289, 67.05451548099518, 70.01536220312119, 65.50695732235909, 66.0977192223072, 62.96190328896046, 65.84352046251297, 67.89553955197334, 68.3728775382042, 61.49759866297245, 59.93484891951084, 57.630527168512344, 62.22423367202282, 59.36863750219345, 63.881564140319824, 53.32969754934311, 46.76298871636391, 47.54184432327747, 48.782872930169106, 46.671387031674385, 45.653410255908966, 47.15153306722641, 44.52601455152035, 45.63951440155506, 47.82377399504185, 47.66287922859192, 44.26390081644058, 45.309080332517624, 45.516446605324745, 43.524927869439125, 46.25231511890888, 50.49993619322777, 46.156275272369385, 45.133134573698044, 41.927018612623215, 41.99600011110306, 45.7018918544054, 42.5109750777483, 43.91904652118683, 41.02321431040764, 43.252957463264465, 43.05835470557213, 41.709491685032845, 40.3154718875885, 44.04810659587383, 48.76928485929966, 51.65887400507927, 48.5936164855957, 53.11206042766571, 49.68236446380615, 49.48436088860035, 46.79468661546707, 48.88112045824528, 45.917131304740906, 45.05241170525551, 43.991622626781464, 43.478528559207916, 50.86549937725067, 52.436038702726364, 47.405492439866066, 48.03794950246811, 45.42526289820671, 46.18179850280285, 44.92487154901028, 47.082163989543915, 48.10837112367153, 49.64234121143818, 48.37468363344669, 51.3989033550024, 49.881808161735535, 46.10161140561104, 45.22529862821102, 40.77365890145302, 40.274031311273575, 41.46722808480263, 38.85996758937836, 41.594920232892036, 41.35055914521217, 42.75211773812771, 37.84703694283962, 45.16227900981903, 42.4104742705822, 37.722168043255806, 41.26914471387863, 49.576061367988586, 50.51156356930733, 46.20065689086914, 45.51758274435997, 43.141342252492905, 43.541331589221954, 44.57858853042126, 46.958321034908295, 44.98287543654442, 43.597370982170105, 47.719120010733604, 45.88793747127056, 46.871814876794815, 46.956417337059975, 48.01044657826424, 46.43913209438324, 53.51274132728577, 62.54262238740921, 62.89392873644829, 59.86951142549515, 55.66789448261261, 58.90035443007946, 62.94276751577854, 69.68777418136597, 68.47968980669975, 65.4789300262928, 66.68452933430672, 67.4510470032692, 67.58871361613274, 66.9913324713707, 69.12325367331505, 68.30575034022331, 71.79022416472435, 72.12038084864616, 74.38490733504295, 70.098387748003, 73.63692507147789, 63.903207778930664, 66.72885775566101, 64.64219212532043, 80.13743385672569, 71.67054578661919, 96.58735156059265, 14.322566706687212, 0.21529520046897233, 74.36138659715652, 65.36979988217354, 59.30622585117817, 24.564752764999866, 53.05969163775444, 48.964833766222, 83.2059819996357, 19.228051230311394, 0.2803251484874636, 0.08357391037861817, 0.0374547163664829, 0.14700832252856344, 0.04374630669190083, 0.04901175539998803, 0.03517230798024684, 0.0423496775329113, 0.08612942910986021, 0.14258022420108318, 0.12107876624213532, 0.0915528810583055, 0.37718509789556265, 0.22082755516748875, 0.12713106960291043, 0.09023968043038622, 0.20986039366107434, 0.4771273647202179, 50.26799663901329, 71.52565196156502, 58.769071474671364, 30.348671302199364, 57.876814752817154, 54.94098208844662, 73.92555758357048, 75.11927872896194, 2.7086606668308377, 1.2591846263967454, 42.07714095711708, 81.88321977853775, 78.30549895763397, 80.49922004342079, 73.3654448390007, 74.69120129942894, 76.58890306949615, 73.37892651557922, 70.24084970355034, 57.53114350140095, 45.532242357730865, 70.7946927845478, 69.46447536349297, 71.12244039773941, 68.17435339093208, 68.27140018343925, 67.86973893642426, 67.21642479300499, 70.3083872795105, 69.21935051679611, 64.77355107665062, 63.130010068416595, 58.00099588930607, 62.9242967069149, 64.66476291418076, 67.84861966967583, 56.14162266254425, 48.73419754207134, 49.57556739449501, 50.80868102610111, 49.73273076117039, 49.230325520038605, 49.59409520030022, 46.78521752357483, 47.62234300374985, 49.94581192731857, 49.84946809709072, 46.35785065591335, 48.390608578920364, 49.94863137602806, 47.55072444677353, 50.24239741265774, 54.31976482272148, 48.76934565603733, 48.48497651517391, 44.271758794784546, 46.494335532188416, 49.30381737649441, 44.67647507786751, 46.403300017118454, 42.84604869782925, 46.51008568704128, 46.16187237203121, 44.78544943034649, 45.44556140899658, 47.78858408331871, 52.84508675336838, 56.98463402688503, 52.620199620723724, 58.918821439146996, 55.72440505027771, 55.638974234461784, 49.617786929011345, 52.64525167644024, 50.13408802449703, 48.87372985482216, 45.87882176041603, 46.20862126350403, 54.38664883375168, 54.04926113784313, 48.922382444143295, 48.76083791255951, 47.88043275475502, 50.74067987501621, 49.85954515635967, 51.97124004364014, 52.04671159386635, 52.960558757185936, 52.00794607400894, 54.45557713508606, 54.03983764350414, 50.4780987650156, 51.0896797478199, 42.643185183405876, 40.900423899292946, 45.45354478061199, 41.54890090227127, 43.32453042268753, 46.23564161360264, 45.79972140491009, 40.60830697417259, 48.51141169667244, 45.85046008229256, 40.8147156983614, 44.743598476052284, 51.883787736296654, 54.94675397872925, 48.94466444849968, 48.52873496711254, 44.989844262599945, 46.588319689035416, 47.38053917884827, 49.740052968263626, 46.93651780486107, 45.89919626712799, 50.751110315322876, 49.240676164627075, 51.60895228385925, 47.84112386405468, 50.186080634593964, 50.01071624457836, 56.11856169998646, 65.78676670789719, 65.99409878253937, 60.44916272163391, 56.39813169836998, 60.49051210284233, 65.71244269609451, 71.78939580917358, 71.61949932575226, 67.2542479634285, 68.55506256222725, 70.06478235125542, 71.14347606897354, 69.74420115351677, 72.65125036239624, 72.12861120700836, 75.30556753277779, 74.54430118203163, 77.43203222751617, 73.24177667498589, 78.20841416716576, 67.31670901179314, 69.75924074649811, 66.97088956832886, 83.60917836427689, 73.90663459897041, 99.8820635676384, 17.734554670751095, 0.3698284551501274, 79.40831378102303, 73.1099845468998, 69.59615349769592, 35.46684846282005, 76.74008935689926, 66.42021551728249, 95.05242392420769, 25.983155854046345, 0.47882296436000615, 0.25852453080005944, 0.19942152255680412, 0.3269676159834489, 0.09805988345760852, 0.22329415718559176, 0.17671904701273888, 0.2221995042054914], [0.028344458442006726, 0.03098412744293455, 0.02034777084190864, 0.06402908024028875, 0.05229625981883146, 0.07136029700632207, 0.06476127571659163, 0.04804286676517222, 0.15432208398124203, 0.6565450981725007, 23.519024178385735, 63.35555836558342, 44.396483302116394, 30.300807170569897, 25.899186059832573, 44.220571741461754, 55.398671329021454, 79.96458873152733, 7.429917063564062, 0.41584208607673645, 21.678486540913582, 64.83482658863068, 70.99786788225174, 73.56321662664413, 66.3231535255909, 66.958669424057, 65.79061970114708, 69.93000358343124, 46.45729511976242, 35.60556381940842, 65.38079649209976, 69.25052404403687, 65.6173337996006, 66.88910275697708, 63.05655620992184, 63.0117604136467, 63.58909383416176, 64.1943633556366, 61.595359817147255, 58.503180742263794, 58.74601051211357, 62.863047793507576, 60.3781483322382, 58.6825767159462, 60.92402324080467, 53.69973309338093, 45.107846930623055, 45.864640921354294, 44.19033296406269, 48.7910158932209, 46.27819173038006, 45.3876943141222, 41.58532574772835, 41.203161254525185, 42.149724662303925, 42.877389416098595, 47.048455998301506, 48.73333118855953, 43.65633241832256, 41.35327219963074, 41.198540702462196, 44.68872182071209, 44.26785260438919, 47.05169342458248, 41.237530410289764, 41.24720849096775, 40.99031187593937, 39.11990784108639, 39.50435221195221, 38.70102971792221, 42.810015231370926, 41.92850053310394, 39.336754605174065, 39.02976907789707, 41.49668030440807, 40.765500739216805, 45.014318749308586, 47.27001070976257, 49.208605885505676, 48.25448848307133, 49.39192324876785, 48.66215340793133, 47.597917914390564, 48.446647971868515, 44.307009503245354, 44.38120052218437, 45.377776846289635, 49.54422667622566, 50.63672125339508, 50.48575535416603, 48.17556671798229, 44.40250977873802, 46.98564536869526, 45.424073562026024, 45.52680864930153, 46.9399756193161, 44.406491965055466, 47.743199318647385, 46.98124900460243, 48.74314226210117, 45.45524708926678, 44.231078177690506, 41.97959639132023, 40.90798169374466, 42.202093452215195, 40.8012530207634, 39.495867267251015, 39.06325288116932, 40.32651029527187, 40.05970761179924, 36.5261822193861, 45.78691229224205, 37.846284583210945, 36.902320235967636, 41.15761689841747, 47.488198801875114, 46.335462257266045, 42.61486530303955, 42.214142605662346, 40.862589329481125, 42.64532066881657, 42.935735285282135, 42.57054828107357, 42.89424151182175, 40.51496498286724, 42.30193309485912, 44.60319980978966, 45.95109008252621, 46.40431836247444, 44.28630821406841, 44.81080546975136, 46.62007838487625, 59.21492055058479, 61.26804918050766, 58.84559936821461, 61.636769995093346, 58.68948094546795, 56.12671606242657, 57.29041501879692, 62.76268757879734, 63.349714279174805, 64.50824931263924, 66.04087427258492, 64.96522799134254, 65.26238724589348, 66.09913274645805, 63.913558423519135, 67.77751788496971, 67.93456345796585, 69.5682629942894, 66.19126260280609, 68.27664390206337, 60.23939497768879, 65.01815915107727, 63.66532154381275, 77.86745086312294, 67.9285141825676, 95.61569809913635, 6.662418097257614, 1.888656949158758, 64.23147976398468, 59.2319056391716, 41.443703547120094, 45.30660666525364, 48.51650342345238, 42.19619616866112, 70.89967355132103, 8.77117669209838, 0.15293042350094765, 0.03668367317004595, 0.018326685640204232, 0.08303563066874631, 0.042491535350563936, 0.03264001104980707, 0.03502190062135924, 0.04978295444743708, 0.04633353739336599, 0.026729461606009863, 0.014436639739869861, 0.06677720855805092, 0.038167070524650626, 0.06612477911403403, 0.04883666420937516, 0.07312795918551274, 0.18932121922262013, 0.5882371729239821, 27.411181926727295, 72.1357624232769, 45.271272361278534, 34.083639085292816, 36.1322383582592, 53.33203062415123, 61.90094701945782, 84.00561109185219, 9.718937035650015, 0.5556175857782364, 24.66663859784603, 68.95575106143951, 73.60346406698227, 77.44372799992561, 68.22472348809242, 71.8946273624897, 69.21989008784294, 76.29408448934555, 55.59089921414852, 41.25674217939377, 65.87736904621124, 70.77127084136009, 68.55328425765038, 70.31528010964394, 67.01403245329857, 63.75601127743721, 66.81668624281883, 67.92051181197166, 64.87470924854279, 60.98286688327789, 61.20238110423088, 62.90074557065964, 63.88705864548683, 59.251485988497734, 63.78718480467796, 56.01228520274162, 47.46735692024231, 48.31115484237671, 45.705862641334534, 47.230496630072594, 48.449684008955956, 46.73054985702038, 44.873144924640656, 42.98064507544041, 45.470165088772774, 44.85218524932861, 51.2082751840353, 49.715646877884865, 47.39555977284908, 43.76618072390556, 42.53338247537613, 46.36353515088558, 47.00500153005123, 48.467786237597466, 44.20060381293297, 44.868376180529594, 42.23551265895367, 40.34283421933651, 41.19856730103493, 40.93404449522495, 44.03073392808437, 42.68883213400841, 40.894891396164894, 40.31416095793247, 43.19182254374027, 43.25459897518158, 48.70752677321434, 48.6153931170702, 51.1822883784771, 51.67021259665489, 51.93489119410515, 52.76418909430504, 49.66641291975975, 50.70357486605644, 47.97393053770065, 47.39026665687561, 46.32761187851429, 51.044028997421265, 50.527408719062805, 48.92300181090832, 50.236340537667274, 47.91236624121666, 48.70975725352764, 49.10574920475483, 46.86996057629585, 49.926056787371635, 48.706588223576546, 49.88048583269119, 50.881238132715225, 51.26247927546501, 48.4745916724205, 48.68112578988075, 44.30778466165066, 44.54937569797039, 42.93268404901028, 41.541958674788475, 41.912389397621155, 40.71242518723011, 40.43085649609566, 44.174712002277374, 39.76535260677338, 45.149754881858826, 39.67929482460022, 41.0254979878664, 43.43419633805752, 48.656997084617615, 51.29452295601368, 43.650347739458084, 45.01121051609516, 42.540590688586235, 43.492667600512505, 46.00985772907734, 46.51368789374828, 45.343878865242004, 42.79290094971657, 45.690591260790825, 47.581548392772675, 47.66548968851566, 47.66719579696655, 45.759861543774605, 47.88730278611183, 50.2926991134882, 59.20428492128849, 63.524364307522774, 61.58958412706852, 64.51786279678345, 61.81088425219059, 57.838106229901314, 59.43973548710346, 62.295438051223755, 65.64077094197273, 67.5381763279438, 68.1598761677742, 67.7667036652565, 67.40516066551208, 69.62328404188156, 67.76513814926147, 70.14984458684921, 70.73057502508163, 74.23228472471237, 69.41374808549881, 72.8920890390873, 66.88375264406204, 68.93046721816063, 69.42846849560738, 80.78355878591537, 72.26604223251343, 98.14956933259964, 6.316572530195117, 2.473413865081966, 74.48719024658203, 61.16270363330841, 55.25841325521469, 46.59486673772335, 53.15292723476887, 51.3270378112793, 78.5313892364502, 12.070484552532434, 0.16299204609822482, 0.05265866908302996, 0.04300307176890783, 0.10372136443038471, 0.04030494936159812, 0.053429189065354876, 0.014763564140594099, 0.04613573277310934, 0.1419462519697845, 0.11254606433794834, 0.1014843161101453, 0.15989729028660804, 0.1579490932635963, 0.13654075999511406, 0.20015728776343167, 0.17509470839286223, 0.326045987312682, 0.7718329306226224, 36.53397560119629, 81.4793698489666, 59.29898723959923, 37.71780967712402, 37.802826315164566, 58.149575516581535, 66.77887067198753, 92.6259197294712, 9.580874294042587, 0.48736327327787876, 32.77392536401749, 75.61492413282394, 76.84098154306412, 79.61944565176964, 72.09394186735153, 75.69204479455948, 72.20331519842148, 75.43161436915398, 47.80717648565769, 45.61822034418583, 68.88575121760368, 74.83731865882874, 71.34738832712173, 74.09565925598145, 68.47641438245773, 69.6697935461998, 68.62633913755417, 69.65648666024208, 67.01799184083939, 64.58806782960892, 62.787010073661804, 65.45478612184525, 64.04470458626747, 62.87254348397255, 66.00402384996414, 57.81566463410854, 51.185176223516464, 50.83515800535679, 49.769148007035255, 51.575905457139015, 51.31987899541855, 49.14889208972454, 47.5218839943409, 46.076414957642555, 47.144427448511124, 47.563301771879196, 53.28023940324783, 53.950675427913666, 50.33138103783131, 46.9554103910923, 45.88201358914375, 49.8550233989954, 50.84785312414169, 51.375811994075775, 46.34670965373516, 49.18224669992924, 46.41814202070236, 41.969241946935654, 43.103568479418755, 43.24907407164574, 47.11138442158699, 43.72149892151356, 44.8261034488678, 41.542034670710564, 44.80145797133446, 45.71913532912731, 51.50441989302635, 52.621521949768066, 57.94735796749592, 56.19407884776592, 56.968093514442444, 55.068005472421646, 53.75170290470123, 54.93179798126221, 51.86167672276497, 50.830902233719826, 50.38227930665016, 52.852845937013626, 52.92618200182915, 52.58305661380291, 51.517551988363266, 49.98135522007942, 51.25802971422672, 52.20486670732498, 51.415060088038445, 53.41326266527176, 51.50181323289871, 53.81202466785908, 56.13621175289154, 55.88748089969158, 53.20575200021267, 52.33837254345417, 49.20395113527775, 47.057776898145676, 45.20664922893047, 43.43385435640812, 42.697799652814865, 43.18384677171707, 43.24772894382477, 46.30154147744179, 43.64934839308262, 51.05686470866203, 44.02539141476154, 45.49187332391739, 46.88465818762779, 52.57305555045605, 53.31928990781307, 46.58857807517052, 46.91386342048645, 47.292041927576065, 46.555588245391846, 48.714184015989304, 48.57104189693928, 47.966273948550224, 44.14436303079128, 49.191738590598106, 50.969237610697746, 50.301795825362206, 49.727513641119, 47.08584599196911, 50.27482867240906, 51.56936600804329, 64.13504093885422, 67.00567290186882, 63.748822063207626, 67.77659073472023, 63.2310276478529, 58.899697065353394, 60.13631030917168, 64.45802360773087, 68.73391896486282, 69.69943955540657, 70.5031268298626, 70.24721816182137, 70.55625557899475, 71.49823263287544, 67.99902319908142, 72.95958861708641, 71.02309852838516, 79.00240436196327, 73.84883970022202, 76.8162676692009, 69.2311754822731, 73.10731709003448, 72.48988822102547, 87.1371978521347, 73.88293147087097, 103.93558725714684, 9.310855083167553, 2.562322444282472, 80.8159102499485, 71.45027160644531, 62.05075018107891, 70.10643571615219, 74.24718752503395, 57.411218136548996, 96.26040950417519, 15.878576561808586, 0.17861352738691494, 0.2667817549081519, 0.14605709700845182, 0.2999841654673219, 0.2797796402592212, 0.22409564699046314, 0.12253155742655508, 0.2100692637031898], [0.007272050897881854, 0.057536701860954054, 0.041036476904992014, 0.12853598484070972, 0.04107450455194339, 0.008044346468523145, 0.05038334820710588, 0.07896673181676306, 0.20037159032654017, 0.5216117261443287, 14.57134410738945, 59.344242811203, 60.978253930807114, 40.05102887749672, 17.625169940292835, 36.95877380669117, 52.62795880436897, 78.86004880070686, 20.922011733055115, 0.7268427510280162, 5.839057378470898, 57.93687433004379, 64.50571104884148, 70.29712468385696, 66.09930753707886, 67.31045454740524, 70.49397692084312, 55.79200342297554, 38.98351415991783, 59.08882051706314, 69.2552661895752, 66.3996510207653, 63.655711859464645, 63.581809625029564, 62.36078694462776, 62.030508667230606, 62.531975358724594, 58.02555397152901, 59.06409904360771, 61.417236775159836, 62.07816570997238, 59.37792420387268, 57.07520216703415, 59.63450163602829, 52.74375759065151, 45.79348213970661, 46.49856470525265, 45.59518598020077, 47.5641643255949, 49.15189392864704, 48.247128278017044, 46.310372203588486, 43.00805680453777, 42.97081120312214, 41.50440149009228, 44.10126954317093, 49.05748039484024, 49.187809601426125, 46.995194256305695, 42.85328730940819, 42.742827236652374, 46.409174501895905, 47.33900360763073, 47.743765488266945, 41.47541284561157, 43.24109070003033, 41.771344766020775, 38.39027099311352, 36.80735573172569, 42.63795666396618, 43.09273526072502, 40.84868587553501, 41.66428931057453, 42.727419063448906, 41.53479225933552, 41.902707517147064, 45.11998727917671, 47.17394046485424, 46.26003250479698, 47.5648482888937, 48.15098963677883, 49.981511011719704, 50.04917398095131, 52.15988092124462, 49.53863337635994, 47.58322410285473, 52.18288108706474, 49.39492888748646, 46.53360262513161, 45.26551567018032, 50.33959619700909, 48.20449836552143, 49.375143349170685, 49.33213725686073, 48.31250756978989, 47.16934271156788, 49.30551588535309, 48.21326069533825, 46.970848962664604, 46.05909548699856, 46.76588036119938, 46.03445760905743, 40.864561423659325, 38.06609518826008, 39.11341018974781, 40.46795390546322, 39.62341122329235, 39.12813439965248, 42.492724657058716, 38.78296472132206, 35.69278433918953, 43.89780946075916, 33.69346842169762, 34.58435341715813, 41.13722339272499, 48.80135513842106, 48.157878667116165, 41.324104964733124, 40.618015453219414, 43.94796296954155, 43.88071797788143, 46.558631882071495, 46.27963565289974, 42.19099044799805, 44.50713336467743, 44.3461512029171, 44.89480376243591, 48.32646042108536, 47.23807342350483, 45.7260699570179, 44.3879109621048, 45.32324977219105, 50.031273141503334, 60.199371725320816, 59.35570299625397, 59.26655977964401, 62.31423184275627, 63.33854667842388, 56.40392638742924, 57.94849790632725, 56.822728514671326, 60.582398772239685, 63.52813370525837, 61.427758410573006, 63.67507562041283, 68.20192471146584, 64.87350091338158, 67.64880359172821, 70.5710519850254, 67.72120490670204, 63.1221254914999, 68.79310458898544, 63.27414393424988, 65.85046648979187, 64.42643210291862, 74.69076812267303, 69.08397898077965, 88.78358870744705, 1.0064547252841294, 7.928688749670982, 72.18562334775925, 56.43250085413456, 33.055463656783104, 86.75927773118019, 61.427568420767784, 32.24443897604942, 70.77054128050804, 7.041194597259164, 0.06126155218225904, 0.04943059386278037, 0.07348990460741334, 0.01568241903441958, 0.04988056913134642, 0.0470333678094903, 0.08164543964085169, 0.09852347342530265, 0.010182759651797824, 0.026627685329003725, 0.08057475060923025, 0.05277832184219733, 0.055759543902240694, 0.046735736905247904, 0.13641000841744244, 0.015903879611869343, 0.18562150915386155, 0.40093949355650693, 16.228547282516956, 68.98378595709801, 59.14687380194664, 38.13307039439678, 23.66511683911085, 45.802943632006645, 59.41089503467083, 84.27148282527924, 26.010563783347607, 0.5756474391091615, 5.649640867486596, 63.586414977908134, 69.29616719484329, 72.44902521371841, 69.78862836956978, 70.9802596271038, 73.49760174751282, 57.78428211808205, 42.98100605607033, 64.65679854154587, 70.47168731689453, 70.47527432441711, 67.50523969531059, 65.69435566663742, 65.85425108671188, 66.05323120951653, 65.41146084666252, 62.64170967042446, 62.478835210204124, 62.71868593990803, 63.77330794930458, 63.014929443597794, 60.49799770116806, 61.1647555232048, 55.83109952509403, 48.260017186403275, 50.541103184223175, 47.13722303509712, 49.696294516325, 50.76592952013016, 51.277359277009964, 50.878065302968025, 45.44918641448021, 45.853484719991684, 44.12446349859238, 47.1753653883934, 49.52787235379219, 52.12268091738224, 50.50288483500481, 46.45697593688965, 44.64401341974735, 48.62514719367027, 51.427341029047966, 49.65992286801338, 44.451143369078636, 45.82261137664318, 44.63031515479088, 40.30969999730587, 42.34408803284168, 47.40374073386192, 43.56630764901638, 42.7166922390461, 44.02302414178848, 43.76575894653797, 43.677888661623, 45.32875567674637, 47.745532393455505, 49.27275404334068, 51.165565475821495, 52.540666088461876, 51.28778211772442, 52.59288668632507, 53.99048209190369, 51.07850454747677, 53.3601301163435, 51.45985588431358, 51.91409111022949, 53.17933201789856, 46.62966147065163, 47.32109136879444, 50.663684606552124, 51.08070082962513, 50.955714136362076, 51.352306455373764, 50.53026616573334, 50.412784069776535, 51.5763234347105, 51.74731805920601, 50.53053215146065, 49.48974519968033, 50.84341116249561, 48.88198301196098, 43.55438008904457, 42.33062535524368, 42.273628413677216, 40.45689269900322, 41.019292920827866, 41.89293064177036, 42.532417327165604, 41.08127139508724, 39.03857320547104, 45.50549179315567, 37.12777353823185, 38.18682610988617, 43.29791285097599, 52.49940410256386, 48.71244750916958, 46.04200020432472, 43.20444546639919, 45.681680738925934, 45.28912380337715, 48.77668306231499, 49.26325835287571, 44.322102293372154, 47.76108115911484, 46.00145258009434, 46.781364530324936, 50.78674100339413, 48.13720017671585, 48.094319477677345, 47.588699609041214, 48.59770126640797, 51.200774386525154, 62.57891424000263, 63.73823203146458, 62.81333886086941, 63.603445664048195, 66.49527668952942, 58.32066893577576, 59.34090659022331, 59.24047037959099, 63.67981016635895, 66.33711397647858, 64.76434037089348, 66.5150660276413, 68.86970087885857, 67.26621732115746, 69.07883405685425, 75.45410916209221, 73.42235058546066, 64.56891685724258, 71.80766522884369, 66.23553022742271, 71.47174045443535, 68.83007660508156, 80.36389410495758, 73.64708572626114, 88.71865779161453, 0.7532719953451306, 11.22163575142622, 79.8160471022129, 64.15574222803116, 43.95384505391121, 94.40919443964958, 73.13244134187698, 37.075427547097206, 77.92499497532845, 8.255597557872534, 0.10543320968281478, 0.096361241012346, 0.03285941587819252, 0.037479121892829426, 0.03250093628594186, 0.0322570776916109, 0.020073172490810975, 0.05086723962449469, 0.1118534550187178, 0.17894424323458225, 0.21829528792295605, 0.24883525853510946, 0.16114009078592062, 0.17706755956169218, 0.23106408712919801, 0.19208806450478733, 0.44069738360121846, 0.6878370721824467, 24.891516231000423, 80.35349026322365, 78.24898079037666, 51.918681263923645, 30.503264106810093, 50.821220353245735, 66.29046007990837, 94.08040568232536, 26.27409104257822, 0.7432727131526917, 9.791069515049458, 68.83488714694977, 69.72321107983589, 77.13308706879616, 74.90941599011421, 73.60716506838799, 75.86488232016563, 56.65194287896156, 46.27458572387695, 67.26620972156525, 71.34931862354279, 74.18644398450851, 70.76693147420883, 68.47342774271965, 69.04887646436691, 66.86174422502518, 68.62693950533867, 65.86308941245079, 62.76545003056526, 65.03366991877556, 68.63482028245926, 67.37116008996964, 61.50953382253647, 63.24176587164402, 58.8739762455225, 50.66690683364868, 53.81977625191212, 50.44604368507862, 52.25717470049858, 53.776462376117706, 52.66463443636894, 52.96759217977524, 47.21391052007675, 50.08039690554142, 46.86277896165848, 49.38437305390835, 51.52422823011875, 53.10496620833874, 55.09642794728279, 49.66040164232254, 46.63893297314644, 52.427884340286255, 55.36003120243549, 52.195283621549606, 46.910128220915794, 49.10594679415226, 46.78712882101536, 42.460566982626915, 42.20671780407429, 48.75866822898388, 47.47087173163891, 44.78098087012768, 47.273270934820175, 47.18671917915344, 45.38671396672726, 47.91234344244003, 52.707632929086685, 53.887321427464485, 56.090355813503265, 57.318981885910034, 55.859742388129234, 56.95544399321079, 58.57394814491272, 57.58525259792805, 56.19658671319485, 53.80806528031826, 57.41905331611633, 55.69216378033161, 48.6998625844717, 49.104571267962456, 53.06885674595833, 50.33858925104141, 55.809630677103996, 54.075726717710495, 55.41287876665592, 53.33375573158264, 57.246067598462105, 56.62145331501961, 54.45039041340351, 54.62855525314808, 56.58146806061268, 54.04761582612991, 47.3444639146328, 43.86447764933109, 43.086932972073555, 43.58593739569187, 46.10683232545853, 42.3209472745657, 47.747280299663544, 43.18756677210331, 42.1352968364954, 49.61426451802254, 40.740083903074265, 42.37371124327183, 44.694763496518135, 55.5265648663044, 52.838858887553215, 47.52467304468155, 46.419601142406464, 49.76228937506676, 48.165767043828964, 50.49020491540432, 52.663923874497414, 47.33424626290798, 50.76085299253464, 49.783845618367195, 48.153178319334984, 53.230496272444725, 51.18296094238758, 50.725062713027, 50.7185422629118, 51.7883026599884, 54.87257815897465, 67.34135448932648, 65.36480695009232, 65.18970474600792, 68.08674529194832, 68.38844150304794, 58.26459914445877, 61.54320761561394, 62.10461609065533, 66.76991075277328, 68.97750109434128, 66.97694644331932, 69.09280210733414, 72.97403544187546, 69.65725421905518, 72.69566997885704, 73.8933277130127, 75.41222780942917, 68.14602971076965, 76.37020200490952, 70.56380197405815, 76.19582936167717, 71.90145179629326, 84.642244130373, 75.03869265317917, 98.33556175231934, 2.3256780300289392, 9.419667944312096, 90.01960918307304, 69.9314247071743, 51.02213077247143, 105.87795183062553, 80.64280673861504, 43.269190192222595, 97.72235065698624, 13.081745188683271, 0.18849416985176504, 0.24120448128087446, 0.1493254560045898, 0.11922043588128872, 0.20993382175220177, 0.14217990974429995, 0.16142124601174146, 0.1496727514313534], [0.03810667083598673, 0.02165286165109137, 0.04178784947725944, 0.02380271689617075, 0.0262529972314951, 0.1001404202543199, 0.10790891785291024, 0.08606178977061063, 0.14841396507108584, 0.2544880786444992, 6.495455531403422, 56.238646656274796, 42.01461911201477, 30.708855874836445, 34.93416264653206, 37.91133709251881, 40.7028990983963, 69.01834890246391, 37.476059049367905, 0.14938794483896345, 0.7487979135476053, 55.16870766878128, 70.0053383409977, 69.99035194516182, 64.99972254037857, 64.25895228981972, 63.052292838692665, 55.58370620012283, 62.35367752611637, 65.76392233371735, 65.47493264079094, 64.54950749874115, 61.83701165020466, 61.538514867424965, 60.45222155749798, 62.05574311316013, 58.51302981376648, 60.68351894617081, 61.83469757437706, 61.02230116724968, 57.59329676628113, 58.559691309928894, 56.115597859025, 48.572934195399284, 46.4821457862854, 44.735409915447235, 44.95218068361282, 46.78323782980442, 47.8946477919817, 50.397459492087364, 51.7552824318409, 49.62616167962551, 47.11675353348255, 42.822972536087036, 43.91314163804054, 44.05046246945858, 51.53234079480171, 52.77297802269459, 49.23895865678787, 45.272963270545006, 43.15889351069927, 45.3083735704422, 46.19748406112194, 49.843331426382065, 47.45066441595554, 40.527770295739174, 42.99501210451126, 42.05441437661648, 39.09312307834625, 44.52329009771347, 43.99646356701851, 40.83623394370079, 39.32663194835186, 41.27492040395737, 42.180286422371864, 39.527253583073616, 44.32237967848778, 45.60005731880665, 46.21068075299263, 43.92807103693485, 44.09190684556961, 49.118668511509895, 48.668977841734886, 53.164193630218506, 53.00236791372299, 51.10060416162014, 51.26678064465523, 46.95989415049553, 44.21100005507469, 45.92477269470692, 50.64392566680908, 50.73659889400005, 52.64430172741413, 50.818818882107735, 50.91887131333351, 49.071486443281174, 49.49887990951538, 47.26451240479946, 45.6719608604908, 44.42549854516983, 44.560091122984886, 44.146680906414986, 41.97874143719673, 41.56325653195381, 42.15586893260479, 41.498036831617355, 42.69631773233414, 37.41014018654823, 39.98591177165508, 35.03565140068531, 42.921303659677505, 45.648975893855095, 30.770091488957405, 37.74073764681816, 44.96189296245575, 49.145517870783806, 44.496110156178474, 46.29716411232948, 43.57434421777725, 44.35073755681515, 46.381314396858215, 51.038420498371124, 44.22053374350071, 41.591549813747406, 43.71247440576553, 42.35472746193409, 46.46322660148144, 48.284962847828865, 49.729649126529694, 48.171436339616776, 45.78028924763203, 46.19254432618618, 44.492792934179306, 49.651255533099174, 54.17197175323963, 58.18217396736145, 58.13643582165241, 60.31161770224571, 64.68177080154419, 61.19651421904564, 62.56184555590153, 64.19567048549652, 61.51575028896332, 62.674642503261566, 63.905472457408905, 62.385082840919495, 66.68826073408127, 69.29431289434433, 75.54061532020569, 64.57786157727242, 64.53928604722023, 64.5546980202198, 64.48608130216599, 64.79633465409279, 66.78962409496307, 73.59302222728729, 74.91917386651039, 64.23443600535393, 0.182186359888874, 19.163165912032127, 75.92835411429405, 48.66693735122681, 38.140867576003075, 25.597942024469376, 24.174093827605247, 41.75803408026695, 47.96115942299366, 4.614325622096658, 0.2418874204158783, 0.09488492374657653, 0.034658990407478996, 0.02782237424980849, 0.010041510395240039, 0.031587894263793714, 0.05583287180343177, 0.028861245555162895, 0.04088138659426477, 0.04412659429362975, 0.024956817760539707, 0.0780095171649009, 0.012797479503205977, 0.04131472662265878, 0.1260379157611169, 0.06476045193267055, 0.16828585969051346, 0.32004456559661776, 9.014849066734314, 66.09660968184471, 46.11511208117008, 32.45813950896263, 34.73997786641121, 42.79466785490513, 45.7934707403183, 77.47188448905945, 43.19723345339298, 0.2083747772849165, 1.157564779277891, 57.47875951230526, 75.91073825955391, 73.5817976295948, 67.92741984128952, 67.76466697454453, 64.5210774242878, 59.08173389732838, 67.8789496421814, 68.50617438554764, 66.15068838000298, 67.52416267991066, 63.47383841872215, 64.18730333447456, 62.954432889819145, 63.780284374952316, 63.04945819079876, 63.57227973639965, 64.03908088803291, 64.04440820217133, 62.90104575455189, 61.66692517697811, 57.822405472397804, 49.45614740252495, 48.77144694328308, 47.26757504045963, 49.45789530873299, 49.05381739139557, 50.856421664357185, 51.93095460534096, 54.441286101937294, 53.12498353421688, 50.34472972154617, 46.36443950235844, 45.74444197118282, 45.900974571704865, 53.16767044365406, 55.31591176986694, 50.459270775318146, 46.25492177903652, 46.54341369867325, 48.13004896044731, 50.1602154225111, 54.01573173701763, 49.93547648191452, 43.45798306167126, 44.928549751639366, 44.7406954318285, 41.326909214258194, 46.5605203807354, 45.880258083343506, 43.40016916394234, 41.95361718535423, 42.48733654618263, 44.6804116666317, 41.38930566608906, 48.446682170033455, 48.595075607299805, 48.26079994440079, 48.03241699934006, 47.18724735081196, 50.33731251955032, 52.38009050488472, 54.02119964361191, 55.23800075054169, 52.814635187387466, 53.99432748556137, 49.0442419052124, 46.09271988272667, 45.983057767152786, 51.12947881221771, 51.899104714393616, 55.76577343046665, 52.19456925988197, 53.734356835484505, 51.46628133952618, 52.98939920961857, 48.945055827498436, 48.86549569666386, 49.297194331884384, 47.11081065237522, 45.35240180790424, 43.12301203608513, 41.618870347738266, 44.231241568923, 42.10701875388622, 44.256305024027824, 40.55233597755432, 42.947655245661736, 37.76021920144558, 44.44794774055481, 44.33156378567219, 36.056660413742065, 40.7889948785305, 48.44876445829868, 50.48739306628704, 48.130428940057755, 49.350155889987946, 43.868003860116005, 46.64279356598854, 48.427052423357964, 53.985188975930214, 45.72677671909332, 46.16989754140377, 44.89131934940815, 45.88955998420715, 48.600608110427856, 49.40843716263771, 52.52737820148468, 50.85429757833481, 48.8440116494894, 47.79169611632824, 48.29007737338543, 51.8135979026556, 57.717987075448036, 62.75929056107998, 62.5676516443491, 63.33049491047859, 66.35570257902145, 65.05931094288826, 67.75130689144135, 68.08815881609917, 65.03886044025421, 65.93510314822197, 65.98345175385475, 67.24575161933899, 68.62692430615425, 72.14722260832787, 81.34168043732643, 68.40733408927917, 68.62290412187576, 70.48516139388084, 67.0673131942749, 69.95064407587051, 72.40813180804253, 77.35568672418594, 79.80710998177528, 66.41033604741096, 0.24178175342967734, 23.76731425523758, 82.73016393184662, 57.06848032772541, 47.83396124839783, 37.593427151441574, 31.102446354925632, 47.648075222969055, 59.77074332535267, 6.6283054277300835, 0.22885170037625358, 0.02437423368974123, 0.03365836382727139, 0.0029342993093450787, 0.042995824696845375, 0.016161271269083954, 0.06319763735518791, 0.06457904135459103, 0.1601337979082018, 0.14850970212137327, 0.17512792692286894, 0.16716494952561334, 0.19253633654443547, 0.3135060070781037, 0.3237667924258858, 0.17321070714388043, 0.28901439160108566, 0.6273369560949504, 13.035564366728067, 80.09320423007011, 54.61771063506603, 41.714207231998444, 47.24358692765236, 57.215232253074646, 51.717618852853775, 84.04143556952477, 45.04592165350914, 0.3976678691105917, 2.2389130108058453, 64.17852580547333, 75.44386491179466, 77.33486384153366, 68.77125576138496, 71.46379888057709, 67.35330864787102, 62.10434630513191, 71.70997247099876, 72.39442974328995, 69.6651653945446, 71.7897529900074, 65.38881406188011, 67.12461411952972, 66.28550514578819, 68.70068594813347, 65.91019928455353, 64.60971146821976, 66.01696595549583, 66.01512685418129, 65.63409850001335, 64.59265038371086, 62.18292988836765, 52.46691204607487, 51.583983823657036, 48.6506362259388, 50.93985378742218, 51.194918900728226, 52.75178276002407, 54.67801719903946, 57.49373070895672, 56.14721596240997, 53.44428040087223, 49.432930648326874, 48.702093064785004, 50.45541398227215, 55.331829115748405, 57.89293348789215, 55.52735522389412, 51.269763484597206, 50.110628083348274, 48.284069895744324, 51.35298281908035, 57.43184722959995, 52.29717895388603, 47.26553834974766, 48.46668429672718, 47.23222553730011, 43.71117867529392, 48.92001897096634, 47.46393330395222, 44.790727347135544, 44.641193971037865, 44.62800107896328, 46.76575116813183, 44.84646275639534, 49.71174068748951, 53.76362286508083, 54.331099614501, 52.83320099115372, 53.73423904180527, 56.457374319434166, 57.0912829041481, 57.52216458320618, 56.57834082841873, 55.10065332055092, 57.15740695595741, 50.73813021183014, 46.773947328329086, 46.85853838920593, 52.018718495965004, 54.98789057135582, 56.758834943175316, 53.801826015114784, 57.94810272753239, 56.325494796037674, 57.174962013959885, 54.54047977924347, 54.240717664361, 54.19584587216377, 51.65883980691433, 50.626511201262474, 46.53099596500397, 45.4093037545681, 46.412081345915794, 47.18671917915344, 48.0762742459774, 44.124873876571655, 45.827467516064644, 41.20123475790024, 48.76397654414177, 51.774437204003334, 39.39979322254658, 44.987332597374916, 51.46488681435585, 53.53253446519375, 50.867004096508026, 52.73403011262417, 47.84263238310814, 50.91301962733269, 50.63029579818249, 56.05712279677391, 47.58193597197533, 47.31381855905056, 48.99191491305828, 46.304790303111076, 52.28319190442562, 51.76251724362373, 54.815585017204285, 52.446457743644714, 51.74788422882557, 50.54145656526089, 50.15783675014973, 54.26750622689724, 59.50732246041298, 64.40747112035751, 64.94543865323067, 64.96998533606529, 69.96447533369064, 65.90755462646484, 69.10493105649948, 69.72558975219727, 66.73882082104683, 68.91110345721245, 69.75721165537834, 68.80822777748108, 72.6772789657116, 73.0313591659069, 79.67483147978783, 71.8424941599369, 71.18818446993828, 74.57098335027695, 73.10132101178169, 74.0388523042202, 73.83601918816566, 82.5220339000225, 81.26581370830536, 75.23361459374428, 0.36758167727384716, 21.99147954583168, 95.05932435393333, 60.24416372179985, 58.647519797086716, 38.368513360619545, 32.30436936020851, 62.99236245453358, 72.76614859700203, 9.56154378131032, 0.7491195306647569, 0.24871262605302036, 0.1264316844753921, 0.25942540902178735, 0.17419108422473073, 0.06634304474573582, 0.20721085224067792, 0.22106870863353834], [0.015186446380539564, 0.04616545949829742, 0.06359622260788456, 0.03779715072596446, 0.09902282748953439, 0.08698165212990716, 0.04620825915480964, 0.05872666144568939, 0.16825540194986388, 0.6177618855144829, 6.991865169256926, 57.84740813076496, 48.09084266424179, 59.119743257761, 44.77110140025616, 31.15362200886011, 34.616765677928925, 62.24675126373768, 47.72182546555996, 2.356194667518139, 0.14437090780120343, 25.497253127396107, 67.97544926404953, 69.97084379196167, 66.52659460902214, 65.12830004096031, 62.792857959866524, 63.74127186834812, 58.677807971835136, 62.84001722931862, 58.811082020401955, 60.937425121665, 60.94261944293976, 60.97846291959286, 60.14758810400963, 59.60088483989239, 60.472489669919014, 62.625537738204, 59.22479622066021, 59.20724876224995, 56.41497619450092, 52.18428701162338, 46.916766464710236, 44.680195078253746, 46.79214835166931, 45.8388365060091, 47.46317334473133, 47.017267271876335, 54.32177871465683, 55.05945213139057, 53.57776343822479, 51.77283748984337, 48.5873544216156, 45.44678874313831, 44.75592881441116, 42.02868975698948, 48.76441352069378, 53.9908354729414, 52.08220548927784, 47.3852851241827, 45.12807324528694, 44.80522356927395, 49.02409918606281, 52.0296885073185, 51.85503467917442, 46.223341673612595, 40.61395347118378, 42.227973863482475, 39.13326792418957, 42.537178471684456, 46.789895072579384, 42.88315370678902, 39.88631531596184, 42.67204463481903, 38.47534462809563, 41.7476150393486, 44.682406559586525, 45.68757802248001, 41.71740286052227, 44.11372907459736, 42.79111124575138, 43.31390619277954, 48.08202713727951, 49.97763141989708, 50.8627787232399, 53.762080147862434, 49.99443031847477, 47.67929434776306, 44.33487720787525, 45.53408905863762, 46.05397716164589, 49.07981939613819, 54.55736227333546, 53.02387095987797, 52.79726631939411, 49.7563236951828, 47.89995990693569, 43.6878327280283, 43.46088990569115, 44.41198267042637, 44.50467869639397, 42.721905559301376, 39.16234016418457, 40.76841898262501, 39.47183355689049, 40.51714986562729, 39.57103483378887, 39.82275992631912, 36.52485989034176, 36.657780557870865, 46.66690707206726, 29.987006708979607, 33.05173605680466, 42.34034523367882, 48.60128827393055, 49.14574585855007, 46.522032245993614, 44.794192761182785, 43.56592006981373, 45.762323811650276, 51.743594259023666, 53.90007734298706, 46.49085491895676, 42.87950590252876, 44.79785576462746, 45.46356104314327, 48.5703731328249, 52.924388498067856, 50.7566162198782, 51.35120831429958, 47.26812221109867, 44.662503227591515, 45.772210881114006, 45.07799193263054, 47.63265945017338, 50.34267023205757, 58.5680128633976, 59.807468354701996, 59.56897035241127, 61.58635050058365, 63.16556856036186, 64.21639457345009, 65.1356640458107, 62.63480544090271, 63.53931650519371, 64.21098366379738, 64.38014298677444, 71.97691574692726, 73.41774523258209, 63.00385683774948, 67.13251009583473, 61.439427584409714, 65.04799515008926, 63.219081088900566, 69.85451683402061, 65.2533969283104, 83.96663278341293, 41.37508302927017, 0.7933126436546445, 29.354977123439312, 69.1467972099781, 45.04116050899029, 35.89215204119682, 28.90300277620554, 34.64783661067486, 48.21177877485752, 49.392413422465324, 3.0300122732296586, 0.17967180028790608, 0.05715730854717549, 0.10753263413789682, 0.047252008225768805, 0.024540109261579346, 0.0037686641690015676, 0.040249677913379855, 0.013816891696478706, 0.05163543297385331, 0.052027298079337925, 0.05950905579084065, 0.04896459562587552, 0.028569587084348314, 0.04637832229491323, 0.113629585102899, 0.028930927655892447, 0.16637349355733022, 0.6344323034863919, 9.705243520438671, 67.58448824286461, 53.894362449645996, 60.08654057979584, 47.46703393757343, 33.28045338392258, 40.176273956894875, 66.65360659360886, 56.111228093504906, 2.8365159686654806, 0.15833518817089498, 23.895532675087452, 70.8303652703762, 72.1275244653225, 71.4896222949028, 71.13459974527359, 65.49626469612122, 67.38590329885483, 62.88687251508236, 64.79785457253456, 62.668243646621704, 64.7337444126606, 62.79194600880146, 63.89830604195595, 61.75529703497887, 61.73379398882389, 60.85622727870941, 64.89006042480469, 62.307502403855324, 62.3516446352005, 58.85336995124817, 54.43009950220585, 48.97079184651375, 48.067272529006004, 49.85141359269619, 48.52394342422485, 50.11323854327202, 51.107158809900284, 55.50551779568195, 57.842643186450005, 55.89150108397007, 54.69893507659435, 50.583284720778465, 48.48938807845116, 46.43991865217686, 45.58386258780956, 51.325681284070015, 56.802920177578926, 52.77387097477913, 51.2160761654377, 48.12838464975357, 47.020174115896225, 51.42885334789753, 55.07882349193096, 54.55804243683815, 49.617676734924316, 43.18042315542698, 44.91431951522827, 43.08661378920078, 44.53545704483986, 47.57301785051823, 44.96367886662483, 43.09058837592602, 45.466574281454086, 40.413841009140015, 44.19311061501503, 48.72041568160057, 48.80237728357315, 46.34718842804432, 46.15987367928028, 45.815061181783676, 45.68813659250736, 51.22978202998638, 51.34878024458885, 54.70630668103695, 55.55629447102547, 52.200641334056854, 47.789712622761726, 43.542532324790955, 44.512464478611946, 48.4683296084404, 50.46507306396961, 57.45005205273628, 53.19602832198143, 55.81012845039368, 50.51383204758167, 50.553125739097595, 46.4317262917757, 46.12122595310211, 47.22543530166149, 47.95309625566006, 46.050070971250534, 41.102565452456474, 40.8447302877903, 40.61616875231266, 41.95227965712547, 40.51783002912998, 42.58596785366535, 40.296130925416946, 39.589543640613556, 45.198814049363136, 34.62803587317467, 38.047989159822464, 45.63101425766945, 49.77017395198345, 53.405617475509644, 50.27359373867512, 47.803114503622055, 45.865704864263535, 50.444941744208336, 55.95791392028332, 56.76904119551182, 48.19559544324875, 45.829124227166176, 46.73158340156078, 49.5380862057209, 52.06221476197243, 56.82684749364853, 53.699877485632896, 54.055394008755684, 50.47905631363392, 48.540407940745354, 47.762494683265686, 49.09673608839512, 49.99170586466789, 53.27466510236263, 60.041801780462265, 62.54968620836735, 63.52178044617176, 63.07739049196243, 64.94647979736328, 66.9823269546032, 67.76981949806213, 66.02254405617714, 66.36017873883247, 65.69910541176796, 67.76779800653458, 75.30764982104301, 83.14408332109451, 65.83091273903847, 72.58337080478668, 64.20480519533157, 71.70792818069458, 64.86184313893318, 75.33110216259956, 66.71625763177872, 88.38435932993889, 39.21885833144188, 0.6060919992160052, 34.438984617590904, 76.86530023813248, 49.3555174022913, 45.71291506290436, 33.92263412475586, 41.889305636286736, 60.47182470560074, 59.49939228594303, 6.194825638085604, 0.3620440681697801, 0.0779485645762179, 0.15066524036228657, 0.03517844554153271, 0.011801951477536932, 0.06063882348826155, 0.0792393449228257, 0.03841779769572895, 0.1344819087535143, 0.2001080388436094, 0.17142659897217527, 0.1291708179633133, 0.26627700543031096, 0.13898043689550832, 0.24672619358170778, 0.31468207365833223, 0.41632976615801454, 0.6966426246799529, 11.538136918097734, 81.1530889570713, 67.05756291747093, 72.38782569766045, 57.647428661584854, 48.6056162416935, 48.80797818303108, 75.61131432652473, 59.01867628097534, 3.4951248904690146, 0.2926983532961458, 33.30795630812645, 73.37293043732643, 74.95693624019623, 72.8141476213932, 73.45473244786263, 70.63801199197769, 71.23273327946663, 65.35130247473717, 70.5641895532608, 66.3346517086029, 67.92392402887344, 66.5021163225174, 66.18825316429138, 65.89411854743958, 64.78000313043594, 62.585579082369804, 67.88635164499283, 65.49519315361977, 65.33544212579727, 62.05915533006191, 58.75225357711315, 51.013018861413, 48.717778623104095, 52.456850185990334, 50.7828614115715, 51.696514785289764, 51.92326381802559, 56.502531096339226, 62.5986959785223, 58.982490822672844, 58.3288536965847, 54.34914104640484, 50.02453610301018, 50.73640510439873, 49.10625457763672, 54.550499841570854, 58.956937193870544, 57.77685731649399, 55.762984380126, 50.252565667033195, 49.57514561712742, 56.00465141236782, 59.50710207223892, 56.65762737393379, 52.98434928059578, 47.09945686161518, 47.908118069171906, 45.21453760564327, 49.299451410770416, 49.63542178273201, 46.14409312605858, 46.08607403934002, 47.19640865921974, 42.19517022371292, 47.665877267718315, 52.49895952641964, 54.37764331698418, 49.48030650615692, 51.60557046532631, 48.78522500395775, 50.870511308312416, 55.52777320146561, 54.72651779651642, 55.465703532099724, 58.676747828722, 52.60719671845436, 50.722117871046066, 47.41268165409565, 46.170972883701324, 49.10713993012905, 51.97842925786972, 60.51061302423477, 56.35071024298668, 59.950124099850655, 55.44563680887222, 57.149837762117386, 51.97731211781502, 50.35177454352379, 50.816520005464554, 54.27613936364651, 48.64227667450905, 43.80176581442356, 43.464883491396904, 42.97771543264389, 44.137496799230576, 43.975272104144096, 42.65549652278423, 43.40799294412136, 42.10130386054516, 49.48310315608978, 41.800329610705376, 40.20533859729767, 48.59338469803333, 53.125929683446884, 56.608872190117836, 51.949140429496765, 50.29756285250187, 46.18305243551731, 51.66803911328316, 57.73843377828598, 60.39184279739857, 51.902646124362946, 48.56083944439888, 50.539233684539795, 51.84444844722748, 54.27400007843971, 59.56087298691273, 55.33269926905632, 56.14000394940376, 53.95978353917599, 51.536725759506226, 50.78783914446831, 51.63029953837395, 52.518129497766495, 56.0877301543951, 65.87713345885277, 65.22125825285912, 67.25107133388519, 66.04046389460564, 68.41412052512169, 69.71669062972069, 72.76585981249809, 69.98978957533836, 69.07358273863792, 68.54317680001259, 71.31641998887062, 75.31687572598457, 82.47120782732964, 70.13111919164658, 74.64984431862831, 68.32247704267502, 73.5428649187088, 69.82109382748604, 78.29718500375748, 72.10602521896362, 89.70449969172478, 48.95372316241264, 0.5677739053498954, 36.408183351159096, 86.91296428442001, 57.79826536774635, 55.47595538198948, 40.543284863233566, 49.11008857190609, 67.84704655408859, 75.2103142440319, 8.81721692159772, 0.4977247235365212, 0.3270051389699802, 0.18911282415501773, 0.09887054620776325, 0.09632192202843726, 0.16196449811104685, 0.12345709721557796, 0.1685005333274603], [0.07408146309899166, 0.04089511632628273, 0.04416171272168867, 0.03520606456731912, 0.027479056734591722, 0.0557873187790392, 0.05684346913767513, 0.023167366125562694, 0.13685762736713514, 0.47753756458405405, 6.562855364754796, 47.50381976366043, 38.92582185566425, 20.809820853173733, 23.80195129662752, 32.06008806824684, 34.55926716327667, 53.1176271289587, 55.20389758050442, 6.9367909245193005, 0.44465249637141824, 1.2542015500366688, 43.61250936985016, 77.10563734173775, 63.273934945464134, 70.39589658379555, 62.361527904868126, 61.77328146994114, 61.03317618370056, 63.58660876750946, 57.687869891524315, 60.80515801906586, 59.268053099513054, 63.112671598792076, 56.89369350671768, 60.97068093717098, 61.068552285432816, 61.200549602508545, 61.524056643247604, 58.61358381807804, 53.0284459143877, 51.344623267650604, 49.900700747966766, 48.02192196249962, 47.17421405017376, 48.239342495799065, 45.471692606806755, 54.03717778623104, 56.69684126973152, 56.15510053932667, 55.21910436451435, 52.37298868596554, 50.795503333210945, 46.94318264722824, 43.03578391671181, 42.32288517057896, 46.559566631913185, 54.23410601913929, 50.175293013453484, 51.59341871738434, 50.30142344534397, 49.66401144862175, 50.10742485523224, 53.85710544884205, 54.5935895293951, 52.30729401111603, 45.93518793582916, 41.52604132890701, 38.78571957349777, 44.00041915476322, 40.33840745687485, 43.420482873916626, 41.18701592087746, 41.21052905917168, 43.390521481633186, 41.768867298960686, 44.67849276959896, 41.28959521651268, 43.082320019602776, 43.6663106828928, 43.53109873831272, 41.89701922237873, 44.24348071217537, 46.91454358398914, 48.93419221043587, 51.16216465830803, 47.30122223496437, 43.99495504796505, 47.013752460479736, 48.631287664175034, 43.7472615391016, 47.062484845519066, 51.11844040453434, 52.386766746640205, 51.028020456433296, 46.502729281783104, 43.86103503406048, 44.34655778110027, 43.80449786782265, 42.57795408368111, 46.776629984378815, 41.62328951060772, 40.21073430776596, 40.21344356238842, 40.49163043498993, 41.20628468692303, 41.74901716411114, 39.60929878056049, 37.20552496612072, 49.40247908234596, 35.583061426877975, 29.31887336075306, 38.01012799143791, 50.15092872083187, 52.64498949050903, 48.32115590572357, 46.538667753338814, 47.26884037256241, 49.06169056892395, 51.22206464409828, 52.84770481288433, 51.53254218399525, 43.848271518945694, 43.088126108050346, 43.976712226867676, 49.271074533462524, 54.633259400725365, 54.933279901742935, 55.36845535039902, 53.81137490272522, 51.45747721195221, 46.288960352540016, 43.907776325941086, 43.959176167845726, 46.42154283821583, 47.84067548811436, 49.156252294778824, 53.328629806637764, 58.275048583745956, 59.812176302075386, 60.13380624353886, 59.55508589744568, 62.22220458090305, 63.607887625694275, 63.271225690841675, 63.12492974102497, 62.98984698951244, 73.71597602963448, 62.59011223912239, 65.46025782823563, 67.2111202776432, 61.51318162679672, 66.49228245019913, 61.41382835805416, 72.52522632479668, 67.73062840104103, 83.87820392847061, 14.900204110890627, 0.397267346852459, 43.17378111183643, 67.92631030082703, 43.20300914347172, 33.32713767886162, 42.77768276631832, 44.76858213543892, 46.7194202542305, 47.167203426361084, 5.9840932209044695, 0.3012616984779015, 0.16218638542341068, 0.1255876399227418, 0.11639139862381853, 0.04842145855946001, 0.03695961851917673, 0.07866611005738378, 0.00424089018451923, 0.1347159969736822, 0.03186906433256809, 0.07726600393652916, 0.11387524340534583, 0.05736684652219992, 0.07050917978631333, 0.05162411893252283, 0.04416482232045382, 0.0646655609307345, 0.5105877458117902, 7.924442952498794, 59.92648936808109, 42.78334826231003, 24.37311004847288, 36.153559014201164, 35.981352254748344, 40.60598909854889, 57.83842921257019, 64.30708810687065, 8.667491655796766, 0.3085313318297267, 1.2888472597114742, 41.16347998380661, 81.16331800818443, 64.23422321677208, 75.59141859412193, 66.50353744626045, 65.64029216766357, 64.74251434206963, 67.19621747732162, 59.970962181687355, 63.33345875144005, 63.57118159532547, 66.69389963150024, 58.665568828582764, 64.46245416998863, 62.73725934326649, 63.68926025927067, 62.97630451619625, 60.88633306324482, 57.06652343273163, 53.845037296414375, 51.02801285684109, 51.3040566444397, 48.94127883017063, 51.875694170594215, 47.7640525996685, 56.28060020506382, 57.78603382408619, 58.043139427900314, 57.117072120308876, 56.55066691339016, 53.700485453009605, 51.076916232705116, 45.59448301792145, 46.2814025580883, 49.97521094977856, 56.48816026747227, 54.71827603876591, 55.371077209711075, 52.058148980140686, 51.43521420657635, 52.04184405505657, 57.16551952064037, 57.29852378368378, 55.90474337339401, 47.81544864177704, 44.781683832407, 41.57811373472214, 45.57885825634003, 43.701473996043205, 45.42967826128006, 44.16338860988617, 42.207169979810715, 44.76387418806553, 41.741580963134766, 45.9760395437479, 44.605692476034164, 46.700269281864166, 47.929837703704834, 48.48563767969608, 44.56615559756756, 48.02493900060654, 48.87772724032402, 51.32943548262119, 53.514762818813324, 48.34654614329338, 44.834633991122246, 44.758649468421936, 48.84028024971485, 44.08804625272751, 46.768278032541275, 53.88331264257431, 52.24360942840576, 53.234235271811485, 47.49902822077274, 47.87954360246658, 47.664307951927185, 47.15926185250282, 44.83718365430832, 50.38397781550884, 43.794265016913414, 43.54582294821739, 42.45379574596882, 43.43817472457886, 42.083790600299835, 43.34460474550724, 41.72524183988571, 40.38276247680187, 47.31185406446457, 38.44681955873966, 35.69206237792969, 42.73709334433079, 52.44468703866005, 54.5358744263649, 51.269934475421906, 49.68483053147793, 48.33022981882095, 51.970381289720535, 53.58124025166035, 56.47354245185852, 52.387975081801414, 46.07081785798073, 45.66057287156582, 47.149625569581985, 53.17489765584469, 55.15931837260723, 57.18965582549572, 57.731449753046036, 57.87910982966423, 56.23135484755039, 50.61852402985096, 48.52455519139767, 48.198935464024544, 49.30421255528927, 50.896406918764114, 51.72949701547623, 56.189260706305504, 60.98475158214569, 60.95213033258915, 64.11813944578171, 63.33379693329334, 64.10811558365822, 66.71851471066475, 66.35491982102394, 66.32034167647362, 63.96936982870102, 81.00156828761101, 72.0321723818779, 65.4036408662796, 72.04758435487747, 63.93164545297623, 70.4970395565033, 65.18914237618446, 78.88844087719917, 71.04749321937561, 87.54621550440788, 13.88908026739955, 0.1685684101539664, 50.66688023507595, 74.71793666481972, 49.3664114177227, 40.85232228040695, 41.42367482185364, 40.24364434182644, 57.833295688033104, 59.913817048072815, 10.337407998740673, 0.3979064547456801, 0.24374728702241555, 0.2083423305884935, 0.0683221522194799, 0.03172830489347689, 0.06789055623812601, 0.08133684721542522, 0.023265711824933533, 0.24212676304159686, 0.1112969036330469, 0.1519517830456607, 0.21773698506876826, 0.18058176239719614, 0.19782912597293034, 0.1144341028702911, 0.17878935701446608, 0.445159412920475, 0.770153955090791, 11.074647288769484, 74.97653558850288, 56.22417703270912, 31.96823939681053, 34.244431257247925, 49.539039954543114, 48.724185079336166, 68.15273255109787, 70.71740493178368, 9.601511936634779, 0.698640129994601, 2.7208760613575578, 50.41800118982792, 82.65169814229012, 67.80436724424362, 78.89073595404625, 69.65011060237885, 69.47277411818504, 67.66110733151436, 70.67275732755661, 64.24839645624161, 67.56349816918373, 64.73984688520432, 70.16923114657402, 61.03457070887089, 66.8493340909481, 65.70040494203568, 67.44973227381706, 67.27077707648277, 63.61911602318287, 59.668205827474594, 55.34762866795063, 55.0359807908535, 54.56098347902298, 51.08638532459736, 55.377225279808044, 50.89609153568745, 59.949926510453224, 61.690913289785385, 62.30652965605259, 60.1369334757328, 57.511213570833206, 55.055329352617264, 53.560212180018425, 48.79139207303524, 49.06551696360111, 52.41923600435257, 60.8444669097662, 55.5658433586359, 58.95163647830486, 54.89930972456932, 56.05796255171299, 55.51421172916889, 59.56722244620323, 59.95811507105827, 59.56519715487957, 50.62325857579708, 46.278180330991745, 45.259945169091225, 49.02557350695133, 45.4959125071764, 47.2166957706213, 45.99310822784901, 44.518886134028435, 46.70118123292923, 46.08835771679878, 49.3260195851326, 48.01874913275242, 50.51464140415192, 51.68967895209789, 49.83215242624283, 48.9079774171114, 52.29661278426647, 52.37970672547817, 53.25620949268341, 53.959506154060364, 50.92562735080719, 46.510575860738754, 46.24233305454254, 51.97322353720665, 45.18450401723385, 49.469427689909935, 54.75095048546791, 53.90055991709232, 57.11522161960602, 54.00456413626671, 52.054280787706375, 51.68693169951439, 51.93706087768078, 50.50316981971264, 54.30876441299915, 47.59069450199604, 44.25738796591759, 44.16377238929272, 46.030768007040024, 46.12423159182072, 45.17636105418205, 45.526702255010605, 42.11989626288414, 48.62542077898979, 48.846739903092384, 41.76840752363205, 45.69060645997524, 57.13496915996075, 56.7319817841053, 54.97976280748844, 52.35142484307289, 51.97406329214573, 55.17273925244808, 58.55778381228447, 59.685339108109474, 55.57509206235409, 51.393940821290016, 50.283591002225876, 51.01034000515938, 55.3417731821537, 59.58776794373989, 62.54389151930809, 62.34461881220341, 58.71704466640949, 58.67105573415756, 52.1151003241539, 51.61590591073036, 51.39363303780556, 52.226111367344856, 54.07884635031223, 55.104715302586555, 59.67916063964367, 63.09496074914932, 64.95174631476402, 66.81477874517441, 65.19085228443146, 68.36830258369446, 67.60064497590065, 70.91921210289001, 67.86508798599243, 68.67382138967514, 75.3008633852005, 73.32219555974007, 70.03452077507973, 76.51280075311661, 67.36294493079185, 74.95806097984314, 67.47140631079674, 81.41361817717552, 74.90791887044907, 90.93187943100929, 21.05880629271269, 0.411627518478781, 52.72734247148037, 85.34204497933388, 57.03139811754227, 49.78182412683964, 59.59721803665161, 58.75896021723747, 65.2855584025383, 76.52882069349289, 12.680700458586216, 0.4706454469123855, 0.3600873809773475, 0.28309950430411845, 0.22074575565056875, 0.08296014682855457, 0.13604537642095238, 0.19071329530561343, 0.1447199101676233], [0.043795718884211965, 0.04506222358031664, 0.07514864919357933, 0.13643150101415813, 0.12868960940977558, 0.01122460511396639, 0.13754420302575454, 0.1591211077175103, 0.1196165572036989, 0.3799853991949931, 3.089017882011831, 47.127313166856766, 52.62736603617668, 46.25502437353134, 24.89822667092085, 34.99212473630905, 37.428056225180626, 46.003481671214104, 55.01212187111378, 22.282832711935043, 0.01434897540093516, 0.30895076401066035, 3.4321608440950513, 60.367839485406876, 66.08713299036026, 67.95850217342377, 63.700344264507294, 66.36438891291618, 60.84308758378029, 62.81365044414997, 60.99317193031311, 61.53047449886799, 60.32497018575668, 63.324358239769936, 61.21445305645466, 60.559014827013016, 58.5100431740284, 60.012003779411316, 57.26442061364651, 59.91744965314865, 57.416070476174355, 54.06798653304577, 50.53782396018505, 46.19357027113438, 44.899891689419746, 45.18465980887413, 49.88189555704594, 56.32685512304306, 61.13921709358692, 59.441563189029694, 55.97037725150585, 56.49010956287384, 49.299322217702866, 48.62901158630848, 44.071201756596565, 43.62272322177887, 42.49081715941429, 49.0769999474287, 55.309756100177765, 55.04220485687256, 50.405838042497635, 47.81033791601658, 49.51071247458458, 54.62269976735115, 54.287249967455864, 58.22541564702988, 52.623064666986465, 45.34362427890301, 43.18441294133663, 39.76049646735191, 41.55873477458954, 39.380076080560684, 43.82964871823788, 41.79390035569668, 39.65200088918209, 44.03929486870766, 41.64598569273949, 41.441621258854866, 41.35828413069248, 44.12737034261227, 43.105377182364464, 41.58721424639225, 42.85572677850723, 46.94276466965675, 51.66166305541992, 51.45775839686394, 53.29681031405926, 50.231727585196495, 48.49853798747063, 41.360738798975945, 45.327045768499374, 48.91176201403141, 52.38418288528919, 49.86903324723244, 47.621362656354904, 41.153091341257095, 40.229782685637474, 40.46594001352787, 45.26907227933407, 43.971745893359184, 42.86740355193615, 39.9408195912838, 41.954228952527046, 41.51729799807072, 38.98743934929371, 43.62538307905197, 40.28148651123047, 38.763418570160866, 46.917374432086945, 33.940937742590904, 28.75192478299141, 34.108121171593666, 44.977985098958015, 53.349414691329, 53.84412154555321, 50.329150557518005, 48.291684687137604, 48.86842153966427, 51.88438430428505, 54.76151391863823, 53.76090981066227, 44.068097323179245, 43.410542607307434, 42.91202075779438, 47.58870340883732, 48.6549261957407, 54.119519367814064, 57.58751727640629, 55.20153410732746, 57.025557830929756, 56.16672411561012, 50.456105545163155, 48.00126627087593, 42.56409242749214, 46.55413292348385, 47.261145785450935, 49.59767460823059, 49.38260994851589, 51.793793365359306, 51.249001398682594, 56.66960433125496, 55.22176802158356, 60.01888521015644, 60.93162663280964, 66.13919779658318, 61.647762805223465, 63.70517000555992, 64.20719906687737, 56.37192830443382, 66.20767012238503, 68.33073779940605, 62.625788524746895, 64.14609834551811, 62.97766864299774, 71.85061812400818, 67.43856847286224, 73.13414365053177, 3.411934766918421, 1.3864718587137759, 58.53190340101719, 63.529638424515724, 43.510340452194214, 34.51059177517891, 46.239977180957794, 41.34403869509697, 42.44034826755524, 57.283001616597176, 9.825829099863768, 0.3767689014784992, 0.11278344027232379, 0.1406754131312482, 0.11637654082733206, 0.0563525236066198, 0.04477747635974083, 0.05837753662490286, 0.09816273028263822, 0.01751260529999854, 0.1082340007997118, 0.037636453489540145, 0.06223739845154341, 0.06250658654607832, 0.04818576358957216, 0.1973786868620664, 0.08193880319595337, 0.2453919456456788, 0.3372242453042418, 5.341392857953906, 59.53586272895336, 61.698801666498184, 49.43013019859791, 36.82248272001743, 46.41004465520382, 45.744297578930855, 52.69061744213104, 61.353882774710655, 26.723629720509052, 0.1741200013202615, 0.36049104994162917, 1.802817180287093, 60.36851204931736, 70.79204052686691, 72.26817011833191, 66.98988854885101, 72.22261816263199, 62.23505549132824, 66.70587658882141, 62.683104649186134, 63.75278905034065, 63.63433040678501, 65.26623263955116, 63.80403310060501, 62.5809433311224, 61.22600443661213, 63.18431295454502, 59.309353083372116, 62.41318613290787, 61.4825476706028, 59.37754422426224, 52.79598958790302, 49.66007485985756, 45.74698783457279, 47.48318687081337, 51.131804287433624, 58.03684316575527, 62.564098834991455, 62.022730484604836, 59.41505581140518, 57.955725118517876, 51.97734631597996, 50.08308716118336, 46.751403138041496, 47.13726483285427, 46.97679944336414, 51.880839094519615, 57.087452709674835, 59.148720502853394, 50.731016993522644, 50.52391290664673, 53.661545142531395, 56.12368002533913, 56.13787226378918, 61.1522351950407, 54.25549887120724, 48.77835117280483, 44.515971690416336, 42.39754356443882, 42.39361457526684, 43.149489015340805, 45.0547181814909, 43.55360493063927, 39.07548062503338, 45.52862495183945, 45.980698093771935, 44.26356263458729, 45.7562555372715, 48.363956809043884, 46.7568938434124, 44.97844107449055, 47.85813935101032, 48.85411910712719, 53.626617416739464, 51.79150588810444, 53.564046174287796, 49.72531735897064, 47.08211459219456, 39.967030584812164, 44.88674059510231, 50.649142786860466, 53.13365086913109, 51.92980706691742, 52.202203050255775, 44.69680018723011, 44.36910577118397, 44.40766230225563, 47.48546674847603, 48.09344932436943, 45.515914633870125, 41.78712151944637, 43.207534700632095, 42.23924785852432, 41.603047996759415, 45.15005126595497, 42.12593033909798, 41.049083322286606, 48.558407574892044, 37.37449809908867, 33.65943744778633, 40.03454156219959, 49.02015119791031, 56.85010984539986, 55.763520151376724, 54.07366722822189, 51.37194000184536, 48.84262092411518, 53.80738511681557, 56.73872262239456, 57.01646491885185, 47.934313863515854, 46.36880546808243, 47.13691145181656, 48.628236427903175, 52.0309766381979, 58.004989475011826, 59.64818090200424, 57.99902379512787, 58.30029062926769, 59.72581073641777, 54.71644453704357, 49.83173444867134, 46.093111261725426, 49.9688158929348, 49.81295205652714, 52.6404145359993, 53.284571170806885, 54.66952085494995, 53.29555258154869, 58.6286424100399, 57.721767872571945, 64.7919724881649, 60.79918093979359, 70.1921971142292, 60.09643144905567, 69.84668165445328, 76.50333926081657, 64.08239856362343, 66.90386116504669, 72.04107910394669, 64.47384595870972, 69.62783619761467, 66.67943760752678, 76.05338260531425, 69.5343080163002, 77.90975019335747, 3.0407998943701386, 2.247065710835159, 66.86138704419136, 71.53830528259277, 49.741500690579414, 48.110115230083466, 57.441882491111755, 31.51570837944746, 58.9972910284996, 71.16406336426735, 16.754746846854687, 0.4563089943258092, 0.15578752878354862, 0.20476684119785205, 0.1656273234402761, 0.0960600477992557, 0.05891391272598412, 0.07994983257958665, 0.025638300430728123, 0.1229798591521103, 0.2904152398696169, 0.2541100879898295, 0.32430692750494927, 0.252985853003338, 0.24239093792857602, 0.2795305458130315, 0.3026379074435681, 0.4894357651937753, 0.7636396202724427, 8.088654465973377, 73.43203246593475, 74.56659838557243, 60.76571233570576, 36.391726434230804, 52.449835762381554, 51.98606684803963, 58.9190836250782, 69.23762753605843, 29.95069395750761, 0.38775069813709706, 0.27115202508866787, 4.61257629096508, 71.20529875159264, 72.38988518714905, 76.20771512389183, 69.7100941836834, 73.50478336215019, 66.26469746232033, 70.51999792456627, 64.78104427456856, 67.95337244868279, 65.00426709651947, 66.77057951688766, 64.81702834367752, 64.90848943591118, 63.60777363181114, 64.9615877866745, 62.035034224390984, 65.18859520554543, 65.17225608229637, 61.60382956266403, 54.9210749566555, 53.742940574884415, 48.11557173728943, 50.809893161058426, 54.530056938529015, 63.05204585194588, 66.20383232831955, 63.620510548353195, 62.70733594894409, 60.26043824851513, 55.52235469222069, 53.22372503578663, 50.52744671702385, 49.61009994149208, 49.4609921425581, 53.89267913997173, 59.861653447151184, 62.042709812521935, 55.43105699121952, 53.33371013402939, 54.75723534822464, 58.037489131093025, 58.085252568125725, 65.37145659327507, 58.1835000962019, 52.993024215102196, 48.04408997297287, 46.76339529454708, 47.94274561107159, 45.90539753437042, 46.01485066115856, 45.61421535909176, 43.02142448723316, 47.99030005931854, 47.845664620399475, 46.28444619476795, 50.147869884967804, 54.530178532004356, 53.700690641999245, 50.83264634013176, 51.73208087682724, 50.55508643388748, 57.088619247078896, 56.099042147397995, 56.69682987034321, 52.525307312607765, 50.76075799763203, 40.188133120536804, 46.82100020349026, 51.836883053183556, 55.77072836458683, 55.790567100048065, 54.842331781983376, 49.54765409231186, 49.32304434478283, 48.012160286307335, 54.83290068805218, 54.303611889481544, 51.077018827199936, 45.563602074980736, 46.22608132660389, 46.55332736670971, 41.72464147210121, 48.09533782303333, 45.56158818304539, 45.12569837272167, 49.33117590844631, 48.828869462013245, 40.92254251241684, 42.95753851532936, 52.61355757713318, 58.08160096406937, 57.46519424021244, 55.61657063663006, 56.61764211952686, 54.06250722706318, 59.321520030498505, 59.248202964663506, 60.79052500426769, 48.33645388484001, 49.94887836277485, 50.738529190421104, 54.056792333722115, 53.25988009572029, 59.53104838728905, 61.364412009716034, 62.12032824754715, 59.875306114554405, 63.006474897265434, 57.08593659102917, 54.511422738432884, 47.77935057878494, 52.70303137600422, 54.17258732020855, 56.041030660271645, 55.57175204157829, 57.4227125197649, 55.02738945186138, 62.144711539149284, 61.21595777571201, 67.08906322717667, 64.31385934352875, 74.38508972525597, 66.65845513343811, 72.315583974123, 68.7495057284832, 68.43469262123108, 69.71113532781601, 79.15965512394905, 68.36267128586769, 74.20732006430626, 68.88890504837036, 79.89093348383904, 70.27010813355446, 87.71957740187645, 4.941917443647981, 1.5868228767067194, 73.7898288667202, 78.41030493378639, 60.29014125466347, 50.87476707994938, 65.75541079044342, 56.530957370996475, 64.26951572299004, 79.26585182547569, 20.18031433224678, 0.7980807940475643, 0.367089009960182, 0.29110024217516184, 0.27411233342718333, 0.13064435217529535, 0.2943733806023374, 0.27162578247953206, 0.2210036074393429], [0.04047769536555279, 0.02371424918237608, 0.03761337269679643, 0.03694237100717146, 0.029037555723334663, 0.05930391504080035, 0.030068654887145385, 0.036344225954962894, 0.09588996981619857, 0.19893660326488316, 4.3300742749124765, 52.0501010119915, 44.710430055856705, 42.94405683875084, 24.439916163682938, 29.545500800013542, 31.045449413359165, 52.676668390631676, 56.89959079027176, 42.01580084860325, 0.6208024942316115, 0.1308163968496956, 0.21360724495025352, 9.930367190390825, 58.05445522069931, 63.419311344623566, 68.3512794971466, 60.29073402285576, 62.79948100447655, 60.30493386089802, 62.02819839119911, 59.863617941737175, 64.33400586247444, 63.09181071817875, 60.3122902661562, 57.894901782274246, 58.31416368484497, 60.231776386499405, 62.73580402135849, 58.6679133027792, 57.488916367292404, 54.86712925136089, 54.6371465921402, 46.57611854374409, 46.83326214551926, 44.83611211180687, 55.29180586338043, 56.39718934893608, 63.40093173086643, 60.62883988022804, 54.9453404545784, 56.85609832406044, 53.134574219584465, 47.57934831082821, 46.79895758628845, 46.201637238264084, 43.388788774609566, 48.02331268787384, 56.31829418241978, 53.21140989661217, 50.43111428618431, 51.63251481950283, 50.57064279913902, 54.01953913271427, 56.19051083922386, 58.51511210203171, 55.84368444979191, 49.95832845568657, 43.49651299417019, 40.68998359143734, 39.66200955212116, 40.1371930539608, 38.470705077052116, 46.7369145154953, 44.352132081985474, 41.727533116936684, 42.57711052894592, 41.932703107595444, 39.67629678547382, 40.073869451880455, 39.84242387115955, 42.08788678050041, 43.41781921684742, 50.09753778576851, 51.739665269851685, 53.9862073212862, 51.35512590408325, 47.8833319991827, 53.82568493485451, 51.83542773127556, 52.888647615909576, 51.326676830649376, 55.598825588822365, 52.30922810733318, 47.92047120630741, 42.58726738393307, 40.08687995374203, 43.8096009939909, 40.57690545916557, 41.51245325803757, 42.92179383337498, 42.50407084822655, 41.25776432454586, 40.227381214499474, 42.07689397037029, 39.17614862322807, 36.9300739467144, 49.0725389868021, 36.6518110781908, 25.279836393892765, 36.73534959554672, 41.92523650825024, 51.74462780356407, 51.35483331978321, 54.594645872712135, 53.03402401506901, 50.850554779171944, 52.98820987343788, 52.991952672600746, 52.5400847196579, 54.76762019097805, 44.59067188203335, 45.14180190861225, 42.66534559428692, 50.04013806581497, 53.08636240661144, 57.787162363529205, 59.101618230342865, 56.661959141492844, 57.71049007773399, 60.12271463871002, 54.0596079826355, 49.26801569759846, 43.160113245248795, 44.92190770804882, 46.61455348134041, 48.60611021518707, 48.781516402959824, 52.66324371099472, 49.63047444820404, 53.86569298803806, 56.225700750947, 59.94052201509476, 58.56601797044277, 66.73727810382843, 58.212207555770874, 62.82183140516281, 54.5249842107296, 56.69479317963123, 66.71121910214424, 65.11595830321312, 65.3926594555378, 60.655605643987656, 65.22120505571365, 69.79757308959961, 75.04047855734825, 55.68396382033825, 1.2781606893986464, 10.31071063131094, 66.43331721425056, 56.710710525512695, 36.289793103933334, 19.79525249451399, 34.33952875435352, 36.126040890812874, 42.87502974271774, 54.752120822668076, 24.357540383934975, 0.2565385733032599, 0.05315954454999883, 0.1077578536933288, 0.03324537719890941, 0.06123177721747197, 0.04445728787686676, 0.022591563429159578, 0.041455686441622674, 0.04297626168408897, 0.025579121574992314, 0.12829857179895043, 0.041616520975367166, 0.09005770582007244, 0.029363323301367927, 0.10348251162213273, 0.031421909225173295, 0.11418530528317206, 0.1999565219739452, 8.897863794118166, 66.57983735203743, 52.55151830613613, 51.27372667193413, 23.519759438931942, 39.142193645238876, 37.53204144537449, 60.54419942200184, 57.30374850332737, 50.60905873775482, 0.8224531018640846, 0.36467872210778296, 0.2723508607596159, 7.371437726542354, 57.945066690444946, 66.20775371789932, 73.13633993268013, 64.84592199325562, 65.29315039515495, 64.57614406943321, 62.98529863357544, 64.45648849010468, 68.90072241425514, 65.50283074378967, 61.55765064060688, 56.49672120809555, 59.592890068888664, 62.69727408885956, 64.53100249171257, 61.41294680535793, 61.73651464283466, 58.57823431491852, 53.72846335172653, 49.512904956936836, 49.967371970415115, 47.18237221240997, 57.252439856529236, 59.57959458231926, 65.20085334777832, 60.96862904727459, 58.29198807477951, 58.565858379006386, 55.20863212645054, 49.38888341188431, 48.10979224741459, 47.79464855790138, 46.62084974348545, 49.71028156578541, 56.46113231778145, 56.47353485226631, 53.140026926994324, 51.783606112003326, 55.42993225157261, 55.93497455120087, 60.00380001962185, 60.2659897506237, 57.85750798881054, 52.850391268730164, 47.09421694278717, 45.11158972978592, 41.055831760168076, 41.44227862358093, 40.61330370604992, 44.620409086346626, 46.9855085760355, 42.807142585515976, 43.54306049644947, 44.87272694706917, 40.848001912236214, 43.13860259950161, 42.434644773602486, 46.313757821917534, 46.407700181007385, 53.06338883936405, 54.88895907998085, 57.882381454110146, 52.9161087423563, 48.86017218232155, 53.69219429790974, 49.67985279858112, 53.58875624835491, 52.96952247619629, 54.62675794959068, 54.35506872832775, 51.55165895819664, 44.94535245001316, 43.97839553654194, 47.588426023721695, 43.602379113435745, 44.14145238697529, 46.3115007430315, 42.84514434635639, 42.93942108750343, 42.54016511142254, 42.53097340464592, 41.82920426130295, 39.92315053939819, 50.31303562223911, 40.35291887819767, 33.1440407037735, 41.10715940594673, 45.49139454960823, 53.11133086681366, 53.598920702934265, 55.71870915591717, 54.51311744749546, 54.78945001959801, 54.245068430900574, 55.18850840628147, 56.06609411537647, 56.27549707889557, 48.1790017336607, 47.261609360575676, 45.16908824443817, 52.98488885164261, 56.24220326542854, 59.992742612957954, 60.057939514517784, 57.95942232012749, 58.77492696046829, 64.04463618993759, 57.325327545404434, 52.39624723792076, 46.59756079316139, 50.416952446103096, 48.087502643465996, 52.17273563146591, 52.38707073032856, 55.56869700551033, 52.0125438272953, 56.804120913147926, 59.75090079009533, 63.88844937086105, 63.17391291260719, 70.42307272553444, 60.387545228004456, 69.39012095332146, 68.93612891435623, 61.11459441483021, 71.04751601815224, 67.61231794953346, 69.54638376832008, 67.71136343479156, 69.29877385497093, 73.4582206606865, 79.7121150791645, 55.01499071717262, 0.9967140667140484, 14.245853573083878, 74.08002689480782, 64.67167854309082, 42.76538662612438, 25.031912997364998, 47.039287090301514, 34.15263198316097, 52.02290207147598, 61.687132492661476, 35.81161916255951, 0.431521232239902, 0.10057876977953129, 0.04962823892128654, 0.05611928514554165, 0.04003541616839357, 0.02508870111341821, 0.042501034840825014, 0.05143439630046487, 0.17314152413746342, 0.10222587749012746, 0.18619656970258802, 0.17523979826364666, 0.20517298893537372, 0.16974302212474868, 0.2721400314476341, 0.19087686465354636, 0.3076140076154843, 0.570632895687595, 12.118683066219091, 80.07843062281609, 61.028513833880424, 57.265530154109, 37.78106488287449, 44.092305824160576, 40.982066318392754, 68.74705865979195, 69.31361585855484, 56.38883359730244, 0.7059734396170825, 0.4283829568885267, 0.21779497648822144, 14.039261508733034, 63.15510392189026, 67.65186622738838, 75.77563270926476, 68.20341423153877, 67.8312774002552, 68.02502140402794, 67.15817391872406, 68.27054902911186, 69.20572444796562, 68.30036982893944, 65.19850507378578, 60.780922919511795, 62.174372747540474, 65.53129121661186, 68.20713803172112, 65.21321788430214, 63.73014606535435, 63.43840532004833, 58.97433266043663, 54.25562806427479, 53.145567029714584, 48.84494259953499, 60.96941560506821, 61.571348905563354, 64.85750377178192, 63.83035808801651, 61.372429579496384, 58.94173040986061, 56.88854478299618, 53.34357060492039, 52.966174855828285, 51.60378456115723, 49.67568062245846, 54.20138217508793, 60.14484465122223, 57.33286254107952, 56.19399145245552, 56.54236815869808, 57.49686174094677, 59.97948132455349, 62.34011225402355, 63.70670512318611, 61.14557795226574, 57.16634787619114, 49.67454828321934, 48.680502623319626, 43.63165654242039, 45.054030418395996, 43.05291719734669, 47.467516511678696, 48.28421428799629, 45.02837419509888, 45.11455737054348, 47.167906388640404, 46.62915989756584, 47.39159658551216, 47.11815185844898, 51.51477813720703, 51.01890094578266, 56.16948276758194, 59.31104019284248, 60.18774814903736, 57.31393575668335, 53.36417689919472, 57.01777204871178, 52.43093177676201, 57.478250339627266, 57.78968542814255, 59.4571727514267, 56.482224985957146, 56.64037249982357, 49.702484384179115, 46.8832902610302, 50.84656499326229, 48.19493427872658, 48.574906289577484, 49.09343786537647, 46.744122728705406, 45.181258991360664, 45.77301263809204, 46.27997383475304, 43.88074457645416, 42.93569728732109, 52.172188460826874, 50.18046073615551, 38.15336510539055, 47.629167437553406, 49.74448353052139, 54.38376098871231, 56.67074806988239, 58.86333681643009, 57.616266533732414, 56.762649938464165, 58.121981397271156, 58.94085645675659, 59.954102486371994, 60.14270156621933, 51.51853233575821, 51.32503151893616, 47.38597668707371, 56.3587050139904, 58.713788241147995, 61.55333787202835, 62.85791426897049, 61.244798228144646, 63.770138919353485, 66.92722231149673, 59.36115190386772, 55.56698329746723, 48.005814626812935, 53.81196387112141, 52.183397859334946, 54.59240399301052, 55.74449837207794, 58.61498974263668, 55.302749276161194, 58.34287114441395, 63.84859710931778, 66.86512604355812, 65.04899829626083, 74.19654384255409, 67.28316441178322, 68.80637347698212, 64.40307855606079, 64.8010616004467, 71.46150380373001, 74.15597721934319, 73.03121477365494, 71.08777865767479, 71.12244039773941, 77.16969430446625, 81.11525058746338, 71.91739574074745, 0.8854240947403014, 12.71701605990529, 82.28412866592407, 70.86736768484116, 51.601493284106255, 31.069984696805477, 52.67558164894581, 49.14437793195248, 59.07002292573452, 76.9257777929306, 42.77099132537842, 0.5333120108116418, 0.19850167504046112, 0.21432404086226597, 0.1350381039083004, 0.17622229788685217, 0.1456330783548765, 0.15053273731609806, 0.20052494772244245], [0.1175118560786359, 0.0446597197878873, 0.0332278513815254, 0.010627806132106343, 0.06034389400156215, 0.030719696515006945, 0.03310950480226893, 0.12290280938032083, 0.15478824177989736, 0.2565634797792882, 12.479034829884768, 61.9965460896492, 48.76244902610779, 41.159566193819046, 62.09578916430473, 67.8796412050724, 29.628767631947994, 46.93013794720173, 58.76847870647907, 63.6242039501667, 4.470242578536272, 0.7475024205632508, 0.12184730469016358, 0.7727096742019057, 20.814709290862083, 54.684400856494904, 63.22591692209244, 61.241454407572746, 60.629493445158005, 60.27321316301823, 61.08549937605858, 59.747081995010376, 67.48301088809967, 64.14759546518326, 53.51209536194801, 55.9279715269804, 58.055196180939674, 61.681626588106155, 60.21907366812229, 58.13358977437019, 58.03911164402962, 56.23980939388275, 47.78793811798096, 45.4577549546957, 43.95090401172638, 51.34740471839905, 56.636458709836006, 60.67465402185917, 56.95245735347271, 52.125196382403374, 56.61603860557079, 56.32356069982052, 53.298873603343964, 50.16393922269344, 46.120105013251305, 45.799444019794464, 45.80802395939827, 47.32781320810318, 51.757835894823074, 57.78661519289017, 54.215604811906815, 53.5679067671299, 52.11708381772041, 54.05472904443741, 56.79797664284706, 57.06991285085678, 54.07163813710213, 55.844102427363396, 48.04386578500271, 44.65100884437561, 42.471027821302414, 40.20003408193588, 38.75104643404484, 38.53849343955517, 44.34482887387276, 43.54611933231354, 41.38637222349644, 43.63789580762386, 44.54517312347889, 41.41674779355526, 41.943988502025604, 41.71337507665157, 45.88297873735428, 53.966246992349625, 53.85662667453289, 50.8353403955698, 51.9569756090641, 47.75592103600502, 52.519159242510796, 54.42803241312504, 52.002983540296555, 50.425870567560196, 53.00245150923729, 53.02237004041672, 53.41512456536293, 44.45151574909687, 43.867574483156204, 45.521032959222794, 40.34987524151802, 42.381736412644386, 45.00108025968075, 40.57207591831684, 42.749575674533844, 41.4045200496912, 40.88801756501198, 34.915380254387856, 44.36857379972935, 41.73218406736851, 25.838824398815632, 37.42898337543011, 42.598446384072304, 53.490409925580025, 54.286034032702446, 52.494943141937256, 51.9791854172945, 52.111460119485855, 52.65943631529808, 53.91272306442261, 52.82221578061581, 56.18289224803448, 46.345771104097366, 43.82494457066059, 44.48857136070728, 46.570156663656235, 50.21224603056908, 52.87890873849392, 57.38767459988594, 58.44875246286392, 52.41024948656559, 54.99608293175697, 59.72226172685623, 55.2965822070837, 50.901114866137505, 44.11097042262554, 43.67069564759731, 47.19141572713852, 49.53608751296997, 48.69740791618824, 49.08892370760441, 51.44866168498993, 53.56865152716637, 58.263033628463745, 59.79463644325733, 62.29784332215786, 59.99683499336243, 60.09227067232132, 55.0930917263031, 45.55258646607399, 62.826987728476524, 69.2348612844944, 64.77197796106339, 62.87429139018059, 62.210140228271484, 67.29128077626228, 66.64071008563042, 82.14276865124702, 20.55847954005003, 1.1596768721938133, 25.666545443236828, 68.00187304615974, 45.30016601085663, 34.795549884438515, 35.59082821011543, 43.43315899372101, 25.300796069204807, 35.420449152588844, 58.931888937950134, 29.62472654879093, 0.6602306629065424, 0.09952661217539571, 0.08168942673364654, 0.0590212569659343, 0.04445132100954652, 0.04211092491459567, 0.022391868187696673, 0.033631082478677854, 0.06448909305618145, 0.03971338344854303, 0.027655958765535615, 0.01680418266914785, 0.11767172210966237, 0.08585565083194524, 0.026532634765317198, 0.060506973532028496, 0.12288031488424167, 0.2058478831895627, 16.95129320025444, 69.57618176937103, 58.115377351641655, 36.57278671860695, 45.31508021056652, 70.79419121146202, 36.78782097995281, 57.2189636528492, 59.50029283761978, 72.75937736034393, 5.101319840177894, 0.795057046925649, 0.21736177004640922, 1.276818411424756, 20.183414965867996, 55.35790331661701, 66.13352850079536, 63.874268531799316, 63.02796274423599, 65.89438453316689, 65.04066154360771, 63.16868059337139, 70.67055344581604, 64.74597215652466, 56.46881930530071, 57.12288200855255, 59.60443764925003, 66.66013464331627, 64.02522683143616, 61.3781026750803, 61.27882160246372, 58.51964145898819, 49.76630575954914, 48.769410252571106, 44.77948755025864, 54.62605498731136, 60.8376956731081, 61.521423384547234, 57.836434319615364, 55.77985167503357, 58.11248950660229, 58.536109775304794, 56.11555606126785, 51.69806130230427, 48.04879792034626, 49.442509934306145, 48.426676243543625, 48.02216894924641, 55.043694376945496, 61.276089549064636, 59.3709933757782, 55.52858255803585, 56.57749347388744, 55.864913910627365, 58.76100450754166, 58.398975133895874, 57.92409561574459, 58.25958341360092, 50.70884898304939, 45.153159499168396, 44.71070744097233, 41.45420238375664, 42.39832252264023, 39.92529362440109, 42.521983087062836, 46.32561318576336, 44.31472688913345, 46.23516283929348, 46.67751610279083, 45.27806259691715, 44.495262801647186, 46.40079215168953, 50.5171150714159, 56.00409284234047, 55.82482986152172, 54.019687324762344, 53.32346968352795, 50.58105804026127, 50.416162088513374, 54.961671978235245, 52.972881495952606, 52.16441787779331, 52.64765314757824, 55.04676081240177, 51.473466753959656, 48.39756220579147, 47.33878321945667, 47.935951575636864, 42.121830359101295, 46.489764377474785, 47.185795828700066, 44.41219165921211, 44.890912771224976, 41.344498470425606, 42.48025372624397, 38.16440351307392, 45.94517379999161, 42.84988649189472, 32.15867377817631, 42.38069146871567, 44.64082159101963, 57.02067129313946, 57.24691115319729, 55.323743149638176, 53.927033096551895, 56.10937759280205, 56.083246394991875, 57.00550250709057, 54.47097010910511, 58.535209223628044, 49.71212826669216, 46.847290992736816, 48.585412725806236, 49.68658983707428, 54.55271892249584, 57.01380506157875, 60.02658739686012, 62.34963834285736, 56.266996935009956, 57.52519682049751, 61.53007172048092, 59.018053114414215, 53.33983160555363, 48.073052018880844, 47.879801988601685, 51.08057163655758, 52.584732323884964, 52.56863258779049, 51.93307489156723, 55.15804164111614, 57.96249255537987, 62.63900801539421, 64.30488422513008, 66.07457086443901, 64.96332809329033, 61.3857364654541, 65.08323445916176, 60.536983609199524, 63.80121365189552, 73.53410258889198, 67.48291969299316, 69.10239279270172, 65.27975231409073, 72.60561481118202, 69.77520748972893, 82.49151393771172, 17.843855805695057, 0.7692673557903618, 32.31592074036598, 77.97072932124138, 53.7756872177124, 47.689029425382614, 39.5777452737093, 46.56474955379963, 26.69522624462843, 44.202195927500725, 70.37178307771683, 41.11994951963425, 1.3265955029055476, 0.0583779039880028, 0.14336151274619624, 0.053196540611679666, 0.07602997924550436, 0.0368653657642426, 0.0973840244114399, 0.0239927530856221, 0.22372207953594625, 0.1355389496893622, 0.09704251031507738, 0.17102215817430988, 0.3433597879484296, 0.20210276852594689, 0.15246530470903963, 0.2171501243719831, 0.19937101198593155, 0.3667874011443928, 20.380259603261948, 85.042704641819, 62.22821205854416, 53.1832230091095, 77.83488661050797, 85.43814182281494, 43.066729456186295, 64.06766295433044, 67.99688771367073, 78.78884062170982, 5.306182522326708, 3.3137606224045157, 0.23603825771715492, 1.2363908370025456, 26.680969409644604, 58.25788110494614, 70.68683177232742, 67.3676946759224, 66.40318483114243, 67.72054374217987, 67.30773389339447, 66.58290758728981, 74.4893941283226, 65.00148564577103, 56.913418248295784, 60.128771513700485, 59.80699338018894, 69.47450682520866, 69.1102659702301, 62.337414398789406, 64.72684398293495, 61.511190533638, 54.31922905147076, 51.49041384458542, 49.25197295844555, 55.71099936962128, 63.08252401649952, 63.6714506149292, 59.10006791353226, 58.88944901525974, 60.44875994324684, 59.916191920638084, 56.527157574892044, 55.954687893390656, 51.41290180385113, 49.95980277657509, 50.691160932183266, 53.53443056344986, 58.55576612055302, 64.21759530901909, 61.85321778059006, 57.52903461456299, 59.99720357358456, 59.229663759469986, 62.466683462262154, 61.78193740546703, 61.45763240754604, 61.8756327778101, 53.05973343551159, 50.22883974015713, 47.85102993249893, 46.33142687380314, 44.49755787849426, 43.50599728524685, 45.107710137963295, 47.43089407682419, 46.7562934756279, 48.94600197672844, 51.09272338449955, 49.92383390665054, 49.22111101448536, 50.9414990991354, 53.10949556529522, 58.95868510007858, 58.90584893524647, 58.38027633726597, 55.94670832157135, 51.25579543411732, 54.96740587055683, 58.4505345672369, 57.302236184477806, 56.79402865469456, 57.93321132659912, 59.754799380898476, 57.35980689525604, 52.96619385480881, 50.804824233055115, 52.58461073040962, 45.42427875101566, 51.26792438328266, 52.80611224472523, 47.4705221503973, 46.54804565012455, 44.17665369808674, 46.19102440774441, 42.01056472957134, 48.138001933693886, 53.48872661590576, 40.93143783509731, 45.964936539530754, 46.731936782598495, 60.542094334959984, 61.471087485551834, 57.38432317972183, 55.58951608836651, 59.045347049832344, 57.9403093457222, 60.743886306881905, 56.45299695432186, 61.56471826136112, 52.33878292143345, 50.475606098771095, 51.39758102595806, 51.715278178453445, 57.117919474840164, 61.50781251490116, 62.34648831188679, 64.39700648188591, 56.961455270648, 62.47151680290699, 63.34722921252251, 61.13966926932335, 55.40127418935299, 51.38292521238327, 49.45805869996548, 55.47336012125015, 55.22205300629139, 56.22282810509205, 56.058027148246765, 60.53170949220657, 59.52102452516556, 64.99507158994675, 65.50327911973, 71.15787729620934, 67.271149456501, 69.23259660601616, 61.798599511384964, 56.83156684041023, 71.46591916680336, 75.4674768447876, 72.434601187706, 70.93913063406944, 69.46841955184937, 77.23644152283669, 73.30977782607079, 87.68674716353416, 28.773709014058113, 1.0118954395875335, 34.0336299687624, 84.40434649586678, 60.25528572499752, 54.009636864066124, 49.93387296795845, 64.50651660561562, 34.496000558137894, 54.23942573368549, 77.48773723840714, 53.45667913556099, 1.8128687096759677, 0.16798690776340663, 0.2508044434944168, 0.1685890567023307, 0.1197530010540504, 0.2037039224524051, 0.1916786067886278, 0.09234522018232383], [0.06232318701222539, 0.023876798077253625, 0.021620455772790592, 0.03328147897263989, 0.08393910640734248, 0.03080826070799958, 0.008743585021875333, 0.04244170013407711, 0.017894763113872614, 0.10211800632532686, 19.786556661128998, 61.61828398704529, 39.59470376372337, 63.027578964829445, 92.96252086758614, 84.59167644381523, 31.77273228764534, 41.21408186852932, 57.762782871723175, 72.5822764635086, 21.52664478868246, 0.5243034660816193, 0.556772070704028, 0.684705862076953, 9.566587060689926, 38.72046947479248, 60.55710732936859, 56.62380538880825, 64.19269144535065, 57.06526190042496, 61.1675825715065, 60.60023121535778, 56.42954461276531, 60.43376214802265, 57.86434382200241, 59.8160444945097, 61.83857336640358, 60.893575474619865, 60.95459260046482, 58.34559179842472, 56.230192109942436, 50.607174038887024, 47.65367992222309, 42.354499474167824, 46.289663314819336, 55.402110144495964, 57.34588444232941, 59.96265582740307, 52.34034463763237, 53.5225448012352, 59.91246812045574, 56.043561324477196, 54.343760535120964, 48.30493837594986, 45.32785892486572, 46.90126709640026, 46.769710555672646, 46.7171061784029, 49.01034392416477, 53.631994128227234, 56.59650765359402, 55.61248205602169, 54.21351112425327, 55.23779556155205, 56.7618253827095, 55.718397572636604, 56.35053925216198, 55.142249688506126, 57.192190289497375, 48.362106308341026, 42.24535413086414, 38.659752532839775, 41.03888086974621, 37.54583850502968, 37.99833722412586, 47.75972843170166, 45.07893048226833, 44.939124584198, 41.683440282940865, 41.67813956737518, 43.94613906741142, 44.18695494532585, 52.33048036694527, 55.90868756175041, 52.16906122863293, 52.437197640538216, 51.13857552409172, 55.76954282820225, 53.06682005524635, 47.647216469049454, 53.425744995474815, 51.874356642365456, 50.73591873049736, 55.75644113123417, 53.34684982895851, 48.068233877420425, 45.06657734513283, 44.35293763875961, 43.51073943078518, 41.79270721971989, 40.11943660676479, 44.33370307087898, 41.29225127398968, 41.19613543152809, 36.00016124546528, 34.22239623963833, 39.38044086098671, 32.95029670000076, 32.53458760678768, 43.883704617619514, 53.03738683462143, 53.79992991685867, 53.60815420746803, 53.4786419570446, 55.730541720986366, 53.225917518138885, 52.445276007056236, 54.744000658392906, 53.58670435845852, 50.274311900138855, 44.77112419903278, 45.233791172504425, 45.866502821445465, 47.741766795516014, 46.26404508948326, 52.73567542433739, 58.3238759636879, 55.712105110287666, 54.42758783698082, 54.70841556787491, 58.25971260666847, 58.827177956700325, 53.18794995546341, 47.77862101793289, 46.02933548390865, 43.751209527254105, 45.33117234706879, 47.136204689741135, 49.74170207977295, 50.16648888587952, 55.28773248195648, 58.482927829027176, 60.41471756994724, 64.63381737470627, 54.837597236037254, 57.97704577445984, 47.056002393364906, 42.990539744496346, 66.19678750634193, 62.87314385175705, 65.83340540528297, 61.9682490080595, 66.54528200626373, 63.24808873236179, 69.69674929976463, 62.87302985787392, 3.2189611718058586, 0.21948843874270096, 46.79760865867138, 60.9699247777462, 37.63997085392475, 16.630415618419647, 16.078514233231544, 42.45106369256973, 29.380304664373398, 39.09471519291401, 49.1147281229496, 38.352975994348526, 1.9613181939348578, 0.06808605277910829, 0.05578610907832626, 0.04165811464190483, 0.045760963039356284, 0.08141144047840498, 0.027052043515141122, 0.0480318050540518, 0.020704697490145918, 0.0828622278640978, 0.05607654486084357, 0.047367282313643955, 0.06435149887693115, 0.031220564560499042, 0.046247433419921435, 0.04761321521073114, 0.04487689817324281, 0.053089630528120324, 27.46820166707039, 70.7734215259552, 48.47765050828457, 49.954475462436676, 86.9321608543396, 84.94292959570885, 36.587936505675316, 49.001315608620644, 64.39835160970688, 78.35195526480675, 24.299304708838463, 0.4454974760301411, 0.6574791949242353, 0.7192606735043228, 10.140435118228197, 39.085690677165985, 63.10760647058487, 60.2532110363245, 67.48760104179382, 60.30078828334808, 64.83314707875252, 64.66170027852058, 58.12932640314102, 61.75571121275425, 58.939169347286224, 62.93548710644245, 66.12235710024834, 63.58087867498398, 63.28507974743843, 60.294727608561516, 59.58054073154926, 52.860939502716064, 51.869812086224556, 44.906013160943985, 49.56810459494591, 55.135850831866264, 61.316975355148315, 60.986427292227745, 51.10215447843075, 57.019649147987366, 61.344698667526245, 59.31925155222416, 56.794085651636124, 51.63053512573242, 47.64643371105194, 48.99353742599487, 49.045127257704735, 48.282356187701225, 51.36213652789593, 55.94225496053696, 57.44317442178726, 58.269945457577705, 56.30160927772522, 57.70969212055206, 59.402117505669594, 56.84718780219555, 56.66607812047005, 59.267540127038956, 59.315869733691216, 49.062252938747406, 43.924472630023956, 40.01062944531441, 41.79616503417492, 39.28723566234112, 40.06614066660404, 48.12974117696285, 46.55033312737942, 44.547312408685684, 42.03421086072922, 43.90305697917938, 48.13264042139053, 46.25053681433201, 53.90704236924648, 57.01598234474659, 53.877510353922844, 52.49881133437157, 54.05268855392933, 55.28982236981392, 53.3150265365839, 49.45848427712917, 54.478417709469795, 53.03139075636864, 53.99401970207691, 55.773175433278084, 55.86891129612923, 50.74434667825699, 44.348214492201805, 49.210859164595604, 45.04323899745941, 45.574963465332985, 41.904869601130486, 44.54922370612621, 44.43136543035507, 45.77897071838379, 37.62628398835659, 38.477468714118004, 41.90133959054947, 36.30516327917576, 38.95027734339237, 46.12985908985138, 54.87652234733105, 55.96112094819546, 55.47867603600025, 56.41386665403843, 57.56059192121029, 57.288283333182335, 56.1725340038538, 56.98290511965752, 56.546247750520706, 51.901589781045914, 47.49398589134216, 47.88546368479729, 49.34789881110191, 50.66482454538345, 49.787360429763794, 54.73940670490265, 59.9866097420454, 60.3020042181015, 58.41675817966461, 57.74602957069874, 60.53446814417839, 61.62035867571831, 55.62502138316631, 52.23524607717991, 47.372194826602936, 49.29178722202778, 48.90783682465553, 50.97059413790703, 52.9514354467392, 54.68197278678417, 60.10336987674236, 63.284114599227905, 64.28966984152794, 67.78783813118935, 59.14009116590023, 59.416636526584625, 54.5658890157938, 55.940434858202934, 68.87739926576614, 69.9883608520031, 69.1334979236126, 68.10697540640831, 68.86182770133018, 69.5321649312973, 74.47585165500641, 61.980248764157295, 2.231807867065072, 0.39961597707588226, 55.70020414888859, 69.27424997091293, 43.662541285157204, 25.498134680092335, 16.429651491343975, 46.38409584760666, 31.332467012107372, 46.264227479696274, 59.4365968555212, 53.5124259442091, 4.4995589554309845, 0.10768895270302892, 0.10772378169349395, 0.09090981009649113, 0.0406216386181768, 0.08656836493173614, 0.03677160282677505, 0.03842739366518799, 0.32503544935025275, 0.18180851766373962, 0.12630563811399043, 0.21409139240859076, 0.2595246193232015, 0.1574188584345393, 0.14458418620051816, 0.19417060510022566, 0.2122874985798262, 0.21508863108465448, 34.91486348211765, 81.2185974419117, 55.303342044353485, 83.47268208861351, 102.54605501890182, 92.86665961146355, 45.52234388887882, 57.155119478702545, 68.87963354587555, 85.3153096139431, 25.72412185370922, 1.4751390321180224, 1.0634218621999025, 0.8596177201252431, 11.855576634407043, 42.853534296154976, 65.38890525698662, 62.47969776391983, 70.72356820106506, 61.02769307792187, 68.27150657773018, 68.16455751657486, 62.20467992126942, 66.73460304737091, 61.030288338661194, 65.50411507487297, 68.00781592726707, 68.19472029805183, 66.4810274541378, 63.30928444862366, 63.93796071410179, 55.13783432543278, 56.01048029959202, 47.889122888445854, 51.22239902615547, 58.045172318816185, 64.91421192884445, 63.275264874100685, 55.455045104026794, 59.38289813697338, 63.740090131759644, 64.1884432733059, 58.07759217917919, 53.37269984185696, 51.85272820293903, 51.54504731297493, 51.700683161616325, 50.03582909703255, 54.08857382833958, 57.279433608055115, 62.05739602446556, 60.49950622022152, 60.669178515672684, 59.54758130013943, 62.37951993942261, 60.4418671131134, 60.36558240652084, 61.59257456660271, 61.59285955131054, 53.71426351368427, 48.300940990448, 43.17501984536648, 45.494373589754105, 42.60266795754433, 43.91930490732193, 53.0317023396492, 49.18651767075062, 48.567975461483, 46.27852611243725, 49.013125374913216, 50.08415870368481, 49.99541826546192, 55.5299998819828, 60.55230438709259, 55.22410109639168, 58.35421733558178, 57.50068813562393, 58.41561824083328, 55.043462589383125, 51.751148253679276, 57.24558122456074, 55.096978917717934, 57.934054881334305, 59.72252011299133, 59.12846378982067, 54.52716149389744, 50.85095375776291, 53.675402998924255, 50.57532414793968, 47.65170402824879, 43.16143937408924, 48.170680180191994, 47.752417623996735, 48.862733244895935, 41.321798488497734, 41.64120554924011, 48.33007402718067, 47.15534806251526, 43.92303630709648, 50.334869250655174, 58.296475633978844, 59.750357419252396, 57.14894860982895, 59.562259912490845, 58.743270859122276, 59.599338322877884, 58.18823844194412, 58.95924746990204, 58.866897225379944, 55.625177174806595, 50.84623821079731, 50.021747052669525, 52.15814061462879, 55.759480968117714, 51.39877796173096, 57.653842717409134, 62.50289931893349, 63.08595523238182, 60.12414336204529, 59.466208666563034, 62.707244753837585, 64.4390170276165, 57.71564640104771, 56.27426214516163, 49.903991371393204, 50.25104574859142, 52.6398141682148, 54.981301724910736, 58.05260471999645, 57.86538116633892, 62.129740342497826, 67.10011303424835, 65.36763399839401, 71.74488499760628, 60.2533820271492, 64.23576593399048, 54.044803977012634, 52.61740297079086, 71.67392760515213, 73.43948006629944, 75.78957036137581, 71.56425788998604, 73.78589987754822, 75.11621609330177, 75.7769550383091, 73.37364479899406, 5.199460973963141, 0.24326502461917698, 62.590853199362755, 73.34195449948311, 51.9782392680645, 29.26742412149906, 25.09858801960945, 71.08828023076057, 41.27999693155289, 57.173453494906425, 67.03522771596909, 66.05720579624176, 6.690065413713455, 0.3947351983515546, 0.1515441806986928, 0.18202534352894872, 0.24521970801288262, 0.15442179894307628, 0.18064350908389315, 0.17664499551756307], [0.03840636862150859, 0.021919997707300354, 0.020769646544067655, 0.12757039134157822, 0.056763409957056865, 0.07801852683769539, 0.048460588295711204, 0.1663926409673877, 0.03471182018984109, 0.31950508360750973, 32.874391973018646, 65.13464570045471, 43.3030691742897, 56.90622143447399, 89.12528917193413, 76.70010030269623, 28.383730240166187, 28.85601829737425, 62.90228448808193, 63.22412721812725, 57.89751224219799, 0.8575280103832483, 0.4684778116643429, 0.7027465815190226, 8.45488641411066, 26.333702243864536, 48.720822259783745, 60.89863300323486, 56.745250672101974, 55.60121566057205, 54.21682454645634, 60.02612762153149, 57.7532871812582, 56.418236419558525, 60.78223764896393, 58.90131577849388, 62.80299961566925, 59.33721698820591, 57.397702261805534, 55.60477986931801, 53.194618597626686, 46.42858766019344, 43.18143010139465, 44.31433171033859, 49.63330149650574, 55.632218196988106, 56.735834777355194, 56.9164314866066, 49.96489070355892, 54.64900575578213, 59.23477828502655, 58.041038140654564, 54.248936623334885, 48.887139335274696, 44.463618099689484, 48.03471587598324, 46.43204927444458, 47.503454983234406, 47.21423350274563, 46.571118012070656, 48.74991349875927, 56.47516876459122, 52.129630744457245, 52.89153926074505, 57.38045118749142, 56.456276178359985, 55.185510367155075, 55.60719653964043, 53.26962277293205, 55.24351045489311, 48.12035568058491, 40.909342020750046, 39.47213374078274, 40.67464001476765, 40.08506365120411, 45.316250547766685, 47.7432145178318, 49.16200518608093, 46.82009965181351, 42.347450852394104, 44.693631157279015, 51.312294602394104, 55.357116758823395, 56.40472434461117, 53.8079284876585, 52.62774981558323, 52.87631347775459, 55.62330387532711, 47.46135704219341, 45.95626540482044, 54.17319528758526, 57.31148488819599, 55.09984776377678, 52.842305302619934, 54.07532773911953, 53.22717525064945, 45.07373996078968, 41.79461091756821, 42.98453226685524, 45.66392429172993, 41.71317748725414, 43.45847703516483, 43.041510209441185, 38.88599619269371, 37.748664021492004, 34.94303897023201, 37.1529433876276, 33.65645840764046, 36.998850256204605, 53.26090984046459, 52.52957068383694, 54.56362433731556, 53.38819541037083, 53.81270483136177, 53.6634336411953, 52.55053795874119, 52.81434640288353, 52.32661597430706, 45.63242018222809, 47.0549688488245, 44.98842313885689, 47.796263471245766, 47.849969789385796, 46.1538890004158, 47.42187336087227, 52.57396750152111, 59.79322671890259, 56.643051356077194, 55.71754641830921, 52.263797745108604, 54.4045040756464, 59.43440057337284, 54.83030542731285, 50.41168972849846, 45.38004532456398, 46.15725941956043, 44.885999634861946, 45.50503581762314, 47.64121279120445, 49.33251343667507, 54.532063230872154, 60.07541477680206, 55.39964407682419, 66.55813291668892, 50.83157479763031, 59.21187311410904, 39.884168431162834, 39.17786993086338, 68.87889638543129, 65.09001329541206, 66.4892578125, 64.27165880799294, 63.87005835771561, 66.93166807293892, 77.18272000551224, 23.42684492468834, 1.0884781926870346, 5.3781297616660595, 53.03425580263138, 47.011179998517036, 28.993219435214996, 20.27686145156622, 40.23824863135815, 48.98255981504917, 39.734840244054794, 37.266139313578606, 53.238437846302986, 54.027758091688156, 6.397946113720536, 0.1920733996666968, 0.12657235114602372, 0.07253890173160471, 0.07377474088571034, 0.027542063216969837, 0.06334229678031988, 0.027465108069009148, 0.02247201271529775, 0.021701027035305742, 0.04703494858404156, 0.1211077174230013, 0.07901808843598701, 0.07623755795066245, 0.037033310072729364, 0.21041970583610237, 0.026607163090375252, 0.33116725157015026, 42.539226561784744, 73.76287311315536, 52.491948902606964, 65.9194403886795, 96.76320612430573, 84.13633927702904, 36.47128276526928, 35.494849160313606, 70.03757581114769, 68.63748773932457, 66.88407182693481, 1.3335887901484966, 0.17800091416575015, 0.260344662819989, 8.835754226893187, 28.333939611911774, 50.37066712975502, 66.21182709932327, 59.009727761149406, 61.08133479952812, 59.21478755772114, 62.83892668783665, 60.12942507863045, 61.043040454387665, 65.10525807738304, 61.72784350812435, 65.27691006660461, 62.3588490486145, 60.70990093052387, 57.767259031534195, 54.79369059205055, 49.50417302548885, 45.93280166387558, 47.504963502287865, 52.8077157586813, 59.24097955226898, 60.67903898656368, 57.44261585175991, 50.76876416802406, 55.03081686794758, 60.624287724494934, 60.28944969177246, 56.42925962805748, 51.94827787578106, 46.90514288842678, 51.179465129971504, 50.01958876848221, 49.723219871520996, 49.580871909856796, 49.186909049749374, 51.12391211092472, 55.606782361865044, 55.24917595088482, 56.822272539138794, 55.87400682270527, 57.92014762759209, 56.85991331934929, 58.87375965714455, 57.76360742747784, 57.50103011727333, 50.480150654911995, 43.081153482198715, 41.68922737240791, 42.87694863975048, 43.59134070575237, 48.2349157333374, 48.79849009215832, 48.35192285478115, 49.05403397977352, 42.99748197197914, 45.49189992249012, 54.39023584127426, 55.07359117269516, 58.70896250009537, 55.572447404265404, 53.550351709127426, 53.62512789666653, 59.638305231928825, 47.799512296915054, 44.70834396779537, 55.2736846357584, 58.06288696825504, 56.20577462017536, 53.70291352272034, 53.868489637970924, 57.532823011279106, 47.991614788770676, 44.45709004998207, 43.62671300768852, 46.16969995200634, 42.839820832014084, 44.567173942923546, 45.09104423224926, 40.49054369330406, 40.23985594511032, 39.548175260424614, 38.548198118805885, 37.691245302557945, 41.13617464900017, 56.001721769571304, 53.97671543061733, 54.45782281458378, 55.95099829137325, 57.49618157744408, 56.41331948339939, 56.151403337717056, 56.699691116809845, 54.44540128111839, 48.8065342605114, 49.677496924996376, 48.396619856357574, 49.38873901963234, 51.14432841539383, 50.67916117608547, 51.744844391942024, 55.858800038695335, 60.9257597476244, 59.696290120482445, 58.14201772212982, 55.487366169691086, 57.9658629745245, 63.97136852145195, 58.401403203606606, 54.13917951285839, 49.050880149006844, 47.550549656152725, 48.62699769437313, 48.023624271154404, 50.77872723340988, 53.058589696884155, 56.449337750673294, 62.12872199714184, 61.324590146541595, 67.98829257488251, 54.521868377923965, 63.63662548363209, 49.08859692513943, 51.50675296783447, 70.82104057073593, 68.58667686581612, 70.61414927244186, 69.0053839981556, 66.764005869627, 71.8310035765171, 75.89257523417473, 18.25388040393591, 0.9724555152934045, 7.013630401343107, 62.22810186445713, 49.762946739792824, 33.264030665159225, 21.078312546014786, 34.617229253053665, 72.81213372945786, 40.56947685778141, 48.52523535490036, 62.217576429247856, 65.20754098892212, 13.090569265186787, 0.26198296865914017, 0.2590473589953035, 0.08621888016932644, 0.054590535146417096, 0.0947919771715533, 0.09543334861518815, 0.016853798952070065, 0.1959103625267744, 0.15469507256057113, 0.18692310259211808, 0.2251964746392332, 0.15922946127830073, 0.1263746281620115, 0.23239308065967634, 0.26763941044919193, 0.25729980901814997, 0.4531911725644022, 52.845177948474884, 82.45637342333794, 59.98709611594677, 71.29724621772766, 98.60422253608704, 86.066415309906, 44.570715352892876, 43.58595259487629, 77.89925515651703, 73.37850093841553, 70.00637948513031, 1.5286503732204437, 1.4378753816708922, 1.0669069876894355, 11.443334855139256, 32.01339237391949, 55.94621054828167, 67.92119577527046, 63.52427691221237, 63.52485828101635, 60.69546550512314, 68.91023710370064, 63.96890625357628, 65.57185783982277, 69.17953625321388, 64.72565084695816, 68.11465859413147, 65.64843133091927, 64.24984037876129, 60.714730471372604, 59.66882139444351, 52.95921362936497, 49.69916716217995, 48.32688979804516, 55.36874033510685, 60.872110426425934, 63.22277449071407, 59.2506880313158, 53.98421622812748, 58.392150700092316, 64.3136465549469, 63.35417903959751, 61.099475026130676, 55.121461004018784, 49.63495820760727, 52.295362651348114, 51.67919151484966, 52.44722530245781, 50.21044112741947, 51.25573843717575, 55.08397601544857, 59.86575722694397, 56.62053756415844, 58.91123324632645, 62.5070258975029, 60.74899323284626, 59.945621341466904, 61.27465322613716, 60.592544227838516, 60.6441530585289, 52.04885467886925, 48.64093914628029, 44.31643299758434, 45.439990907907486, 45.9312741458416, 49.966866597533226, 51.26647666096687, 52.5445456802845, 51.15419648587704, 45.517947524785995, 47.76694044470787, 57.69928067922592, 60.206959918141365, 61.70118033885956, 60.15432894229889, 56.94376341998577, 54.60675582289696, 60.69416977465153, 49.96174447238445, 46.304900497198105, 57.84523084759712, 62.64156527817249, 60.310625955462456, 58.06373432278633, 55.698657631874084, 61.621472015976906, 50.443638414144516, 46.53563171625137, 46.62696361541748, 50.157046392560005, 46.87067113816738, 47.83752925693989, 47.60936290025711, 43.891585394740105, 43.08634780347347, 42.87776179611683, 45.107402354478836, 43.27058091759682, 43.08848328888416, 59.004932418465614, 56.14850789308548, 57.21034951508045, 57.390380054712296, 57.9268504679203, 58.57419513165951, 59.31829780340195, 58.18099223077297, 58.067408725619316, 49.75237190723419, 53.16012404859066, 51.30385145545006, 52.46357202529907, 54.36221994459629, 53.40613044798374, 53.43137629330158, 58.955360278487206, 64.47325319051743, 61.47079490125179, 61.41176126897335, 56.80623359978199, 58.1245082616806, 66.83296456933022, 60.7389921694994, 55.676379427313805, 51.40860043466091, 49.80324737727642, 51.83633208274841, 51.79881289601326, 53.36778670549393, 57.14158460497856, 60.0510086864233, 65.78884899616241, 62.45297759771347, 74.00219947099686, 55.47229617834091, 67.12043434381485, 48.16659539937973, 48.182934522628784, 75.49444019794464, 71.9028653204441, 74.24546241760254, 72.58229926228523, 70.3523813188076, 73.21184948086739, 81.7776994407177, 32.39415854215622, 0.8208581374492496, 6.7150087002664804, 67.82488614320755, 58.4628801047802, 43.081890642642975, 32.57045768201351, 51.732240468263626, 80.32333508133888, 51.446522399783134, 55.69032087922096, 70.53917929530144, 80.43906927108765, 17.61839110404253, 0.4058921418618411, 0.3464171988889575, 0.2467839326709509, 0.17670718749286607, 0.16672936821123585, 0.24649443570524454, 0.13018393859965727], [0.05902942801185418, 0.0026347594621256576, 0.0639703540946357, 0.052394212179933675, 0.03118545726465527, 0.021766593927168287, 0.010189564218308078, 0.09964374534320086, 0.10110500443261117, 1.0460876673460007, 42.25962616503239, 62.426458820700645, 43.298851400613785, 29.242457561194897, 86.47455900907516, 51.92386798560619, 21.87531217932701, 27.723793052136898, 70.0074814260006, 54.22745257616043, 71.43238976597786, 14.005316980183125, 0.6473098124843091, 0.2978207159321755, 6.180465258657932, 23.04806225001812, 43.04613076150417, 57.08903722465038, 55.48145368695259, 53.27753774821758, 53.03374283015728, 57.141056433320045, 57.65399470925331, 60.826816856861115, 58.778240382671356, 60.09549669921398, 59.14976544678211, 55.85283435881138, 51.69238060712814, 48.32207925617695, 46.11828111112118, 44.34231340885162, 44.7061400860548, 47.536999583244324, 54.41536009311676, 59.14342738687992, 58.60000714659691, 53.620222359895706, 52.1694678068161, 59.65073436498642, 56.22755125164986, 59.84869994223118, 53.19194734096527, 48.729413598775864, 43.34869332611561, 48.900773003697395, 47.2999607026577, 50.24309277534485, 48.209039121866226, 47.34262481331825, 44.995296970009804, 45.13912685215473, 48.98827850818634, 54.1980991512537, 52.873991802334785, 54.65615697205067, 53.98729786276817, 58.98113429546356, 56.52756795287132, 55.92350296676159, 54.27309572696686, 50.684925466775894, 42.07659378647804, 38.59393626451492, 39.45008732378483, 44.172310531139374, 42.49076396226883, 46.500817984342575, 44.47361536324024, 48.975514993071556, 53.00891496241093, 54.815980195999146, 56.07495903968811, 59.836365804076195, 52.93976627290249, 52.29176044464111, 60.74964299798012, 58.33755522966385, 44.112448543310165, 41.36583812534809, 50.74707493185997, 58.22978921234608, 59.639103189110756, 50.59383675456047, 54.16981726884842, 55.99488213658333, 54.42837439477444, 49.38992075622082, 41.635935232043266, 45.18992632627487, 46.00001625716686, 37.68636256456375, 40.47079995274544, 41.64185531437397, 41.547643169760704, 36.0502577573061, 35.40744245052338, 38.047723174095154, 45.34576736390591, 55.447852090001106, 51.27903878688812, 53.65358456969261, 55.61837173998356, 55.43340906500816, 51.80304206907749, 53.79742585122585, 46.82366006076336, 44.98493492603302, 40.95102958381176, 45.660705864429474, 47.10345044732094, 47.09283001720905, 48.27726066112518, 47.82871752977371, 46.320525258779526, 54.431186243891716, 58.667225539684296, 56.18948869407177, 56.30299240350723, 58.10693420469761, 55.01795835793018, 59.570364877581596, 56.10380709171295, 54.48685705661774, 47.48757943511009, 48.24932835996151, 43.946519047021866, 46.527196168899536, 46.00318528711796, 52.2026514261961, 47.236226722598076, 63.556487783789635, 56.535064950585365, 68.12717512249947, 56.853632256388664, 60.320642217993736, 37.52758428454399, 37.559160590171814, 64.73664745688438, 65.82592740654945, 61.076011285185814, 67.00626567006111, 59.89846207201481, 72.54132986068726, 40.21676078438759, 0.41628461389336735, 0.31011281884275377, 13.544107228517532, 61.55436381697655, 57.960208877921104, 35.07184065878391, 16.55814729630947, 34.67613369226456, 38.079918846488, 35.907940194010735, 26.51603166013956, 44.94528405368328, 54.329819083213806, 18.779954575002193, 0.17282179207541049, 0.24915604444686323, 0.11894422335899435, 0.15289857052266598, 0.04366904169728514, 0.07847335946280509, 0.020799263802473433, 0.03666751661512535, 0.008551588634873042, 0.03837217045656871, 0.060286455482128076, 0.03983413087553345, 0.03067299501708476, 0.04714071204944048, 0.1109173396253027, 0.06392113486072049, 1.3816891028545797, 55.28035707771778, 67.84583821892738, 53.86805646121502, 39.55266281962395, 92.95487567782402, 59.2494872957468, 27.455479949712753, 33.87199804186821, 78.4181173145771, 57.30138882994652, 81.64146915078163, 16.48751098662615, 0.40474593930412084, 0.5823307461105287, 4.834555629640818, 23.64402987062931, 46.10841304063797, 62.16866545379162, 58.577561751008034, 56.85370825231075, 55.29704958200455, 62.59160175919533, 59.36546087265015, 63.43268662691116, 63.40406656265259, 63.59898090362549, 64.0118819475174, 56.97351962327957, 54.98899631202221, 50.263927057385445, 48.22223201394081, 46.70590817928314, 49.72229652106762, 50.49647457897663, 58.0447543412447, 60.799617916345596, 60.576626881957054, 56.03990972042084, 52.74722680449486, 60.73250971734524, 59.946350902318954, 60.3700053691864, 56.85869738459587, 49.50855039060116, 46.05963505804539, 50.45063763856888, 49.479846730828285, 53.5884902626276, 49.74468871951103, 50.92905476689339, 47.40842588245869, 47.60971248149872, 50.04303731024265, 55.80541670322418, 55.81395864486694, 57.12942525744438, 57.401939034461975, 60.27588441967964, 57.20101721584797, 56.03328287601471, 57.28099152445793, 53.40054094791412, 44.56113986670971, 40.897988229990005, 41.64450377225876, 45.59899337589741, 44.60848532617092, 47.04120218753815, 45.67907027900219, 50.701758563518524, 55.33060938119888, 58.543253391981125, 54.63470712304115, 59.18543413281441, 52.995433285832405, 53.98285210132599, 60.237392485141754, 57.8856036812067, 45.30373401939869, 42.77227185666561, 50.44297344982624, 59.96112450957298, 58.93690466880798, 52.17191867530346, 54.86963331699371, 59.110467955470085, 55.82742892205715, 51.04476995766163, 44.39526356756687, 47.67406202852726, 49.38595376908779, 39.10712532699108, 42.19949819147587, 45.0983702391386, 41.6489115357399, 41.1728198826313, 38.54277580976486, 38.936765268445015, 50.1307176053524, 55.949497371912, 55.10273180902004, 55.156783908605576, 56.883080676198006, 57.38437257707119, 53.40011917054653, 55.39581008255482, 50.451792776584625, 46.96437790989876, 44.98478293418884, 49.637150689959526, 49.41089563071728, 51.26748360693455, 50.658463686704636, 50.65278299152851, 49.154743775725365, 55.966246873140335, 60.38814179599285, 58.96826818585396, 59.11063514649868, 60.71928262710571, 58.30368384718895, 62.05336444079876, 59.727786630392075, 57.36544579267502, 51.226415410637856, 51.84813804924488, 46.22979752719402, 50.88367000222206, 49.45886805653572, 55.44613838195801, 49.86819349229336, 68.14402341842651, 60.77744610607624, 69.47806343436241, 60.609213933348656, 64.05243337154388, 43.535947278141975, 46.36295758187771, 66.50451019406319, 69.39351037144661, 64.42111998796463, 71.6119073331356, 64.23806101083755, 75.96605569124222, 34.23006422817707, 0.09138394598267041, 0.2504944335669279, 17.94929064810276, 70.7936592400074, 62.213100269436836, 39.07677635550499, 14.452359192073345, 35.72713449597359, 54.63275782763958, 33.441055566072464, 29.45223670452833, 59.923704117536545, 64.35818016529083, 30.62145296484232, 0.27585050265770406, 0.1090678185573779, 0.058316539507359266, 0.26999371068086475, 0.11956147500313818, 0.0706502769025974, 0.030106613885436673, 0.35634514584671706, 0.1277243424556218, 0.20680638175690547, 0.16298282862408087, 0.1660827497835271, 0.11492858102428727, 0.14867333084112033, 0.20268504275009036, 0.2106754350825213, 1.5155751560814679, 63.7096993625164, 80.78387796878815, 59.31418262422085, 38.101285099983215, 94.00910630822182, 62.317674458026886, 35.23917607963085, 42.14655563235283, 86.42729714512825, 61.79118990898132, 87.12931707501411, 17.288903184235096, 1.0188400419428945, 1.2384646944701672, 6.606576768681407, 29.73905671387911, 47.74979956448078, 66.06989711523056, 61.511889696121216, 61.50113247334957, 60.25855354964733, 66.9525745511055, 64.43701833486557, 66.69519156217575, 66.95541679859161, 66.40459075570107, 67.32404261827469, 63.54682110249996, 57.30539761483669, 55.33944770693779, 51.78039148449898, 50.11945880949497, 52.00555220246315, 55.18145598471165, 58.9346893876791, 64.75334376096725, 59.54279735684395, 57.99095682799816, 55.80944448709488, 63.290726244449615, 61.88336916267872, 63.53512533009052, 60.65834529697895, 54.06450591981411, 48.87114219367504, 53.04910160601139, 51.562587171792984, 57.27757170796394, 51.99437700212002, 54.41113092005253, 50.07597014307976, 48.95156487822533, 52.80472531914711, 60.062468871474266, 58.39953750371933, 59.46116253733635, 59.5782570540905, 66.21951028704643, 60.904192104935646, 59.312157332897186, 58.19688677787781, 54.57877792418003, 47.06485591828823, 44.457504227757454, 45.92987202107906, 49.53520596027374, 48.440712690353394, 51.025523990392685, 49.27523151040077, 52.43417680263519, 58.58492195606232, 59.747716560959816, 56.32626235485077, 64.77688729763031, 57.29725085198879, 56.656445637345314, 62.29666158556938, 59.860103130340576, 44.0411301702261, 42.94874958693981, 50.96907801926136, 62.76768811047077, 63.471619337797165, 54.524243250489235, 58.081247583031654, 60.361691415309906, 57.626248598098755, 55.43889597058296, 47.08808407187462, 50.525915399193764, 50.697016417980194, 42.60877422988415, 46.322162970900536, 49.091716557741165, 46.808297485113144, 42.9297886043787, 48.11174154281616, 46.08007796108723, 54.493343308568, 58.13046634197235, 58.75914640724659, 56.45399250090122, 59.25489820539951, 59.69371385872364, 57.95281067490578, 59.84010860323906, 53.47472816705704, 49.25953075289726, 46.35931737720966, 51.331924349069595, 51.268596947193146, 52.291213274002075, 53.71970482170582, 54.79949668049812, 54.31842729449272, 57.42368146777153, 65.50375789403915, 61.600778326392174, 60.169246941804886, 62.00925260782242, 62.01276361942291, 64.2388665676117, 62.93245106935501, 57.98536352813244, 54.40030910074711, 53.33102747797966, 50.080092921853065, 53.73319409787655, 53.32717828452587, 58.971019238233566, 55.06571799516678, 71.50310397148132, 65.12621015310287, 75.54332837462425, 62.44350090622902, 68.51150929927826, 44.04890455305576, 46.468618512153625, 67.30374410748482, 73.76079842448235, 69.97002303600311, 75.42209208011627, 68.63943323493004, 76.23282417654991, 47.90748730301857, 2.141433279030025, 0.5779233982320875, 18.436230719089508, 76.7367835342884, 71.68704450130463, 51.154082491993904, 29.897320121526718, 41.24640293419361, 57.652197405695915, 48.521500155329704, 37.71626316010952, 62.810378819704056, 74.37549144029617, 39.89628218114376, 0.49722237861715257, 0.5110593361314386, 0.14729143702425063, 0.5316703801508993, 0.17957282747374848, 0.15252997545758262, 0.11268139496678486], [0.08072174779954366, 0.053502138471230865, 0.014946270694053965, 0.045109439015504904, 0.034038094818242826, 0.025758216652320698, 0.052891952072968706, 0.09307410567998886, 0.0605936638021376, 2.1388933528214693, 53.96916523575783, 53.29780586063862, 40.74651695787907, 34.3467103689909, 45.11436738073826, 37.58368447422981, 31.177874207496643, 23.548615090548992, 70.07314190268517, 66.10116183757782, 64.36745926737785, 48.00806790590286, 0.08956788835348561, 0.07503259956138209, 1.9139988580718637, 15.46867260709405, 35.85171461105347, 48.125515803694725, 48.42350721359253, 48.979158997535706, 52.56454020738602, 55.12023746967316, 55.614579543471336, 52.99463912844658, 55.65659388899803, 52.02838137745857, 53.557597920298576, 49.621157348155975, 48.730177357792854, 45.951378867030144, 48.04133132100105, 45.185290575027466, 45.81023544073105, 51.81463144719601, 56.512581557035446, 59.605512991547585, 58.31505663692951, 50.76070860028267, 60.539248287677765, 59.149837642908096, 57.15400233864784, 57.36552178859711, 52.46129594743252, 43.81006456911564, 43.7356835603714, 47.30780728161335, 49.002098366618156, 47.91286401450634, 48.80485475063324, 47.15261220932007, 43.94953988492489, 43.68929944932461, 43.36293116211891, 47.50351198017597, 54.026735946536064, 52.18209072947502, 53.652353435754776, 55.71598470211029, 57.12534807622433, 57.7496849745512, 53.37676182389259, 52.92453669011593, 53.62209565937519, 46.76499500870705, 41.5243998169899, 40.22040858864784, 41.31063088774681, 46.43195427954197, 47.450014650821686, 51.528354808688164, 58.334002420306206, 57.63469934463501, 59.08704601228237, 58.78835543990135, 50.34652702510357, 51.80164374411106, 65.02749145030975, 58.2609361410141, 44.269733503460884, 41.156161576509476, 46.89460605382919, 67.06381738185883, 59.50917296111584, 47.402266412973404, 53.01368370652199, 61.06332376599312, 55.16387812793255, 55.87732404470444, 49.95513662695885, 46.45259477198124, 46.722057312726974, 43.357839435338974, 41.27837061882019, 38.876489102840424, 41.82812511920929, 37.52292573451996, 34.17798042297363, 43.896722719073296, 44.71168398857117, 54.945070669054985, 54.33206856250763, 52.604198679327965, 54.11074943840504, 52.23689138889313, 53.67443785071373, 48.27070601284504, 43.805584609508514, 43.158372938632965, 42.61030174791813, 49.20378394424915, 48.223805129528046, 49.04570862650871, 48.79862688481808, 46.95797145366669, 46.09363563358784, 52.011130303144455, 53.97375538945198, 56.86590179800987, 55.466957464814186, 59.76453825831413, 56.33785553276539, 59.35491643846035, 58.14636088907719, 54.49035286903381, 48.90748344361782, 47.7345509827137, 44.98792916536331, 46.79169237613678, 44.68432545661926, 49.76556479930878, 48.39993327856064, 55.88444106280804, 57.6236267387867, 63.96776631474495, 58.759879767894745, 63.92089203000069, 42.96761177480221, 31.53265167027712, 57.883228808641434, 62.075775638222694, 63.08409333229065, 66.88862398266792, 58.45548950135708, 56.74854889512062, 5.717096272855997, 0.03443164088821504, 0.06902774912305176, 32.57406748831272, 63.22546474635601, 56.589603424072266, 39.206068217754364, 15.561437029391527, 30.637081526219845, 35.85334092378616, 48.346291556954384, 27.947021573781967, 36.931894049048424, 68.01885053515434, 31.9352837651968, 0.36902922147419304, 0.16259682277450338, 0.026435444960952736, 0.08136113770888187, 0.02135731247108197, 0.04550375320832245, 0.04036384249047842, 0.061111078030080535, 0.056116086489055306, 0.09777017869055271, 0.041641249335953034, 0.018154770841647405, 0.016031274826673325, 0.02751118430751376, 0.11124369906610809, 0.08203003540984355, 2.6693814620375633, 65.25015190243721, 61.39508776366711, 47.66887150704861, 40.065927878022194, 55.8552548289299, 42.43266128003597, 47.864933386445045, 31.78765408694744, 76.22408464550972, 71.65655493736267, 70.74062168598175, 55.974032655358315, 0.44034931634087116, 0.08696341756149195, 1.744995207991451, 15.184465907514095, 36.822680309414864, 53.09320583939552, 53.22105757892132, 52.04180225729942, 57.51243710517883, 58.481126725673676, 59.8273678869009, 56.57131880521774, 60.24081230163574, 53.501566126942635, 53.913004249334335, 51.59575939178467, 50.63861355185509, 49.176850989460945, 48.354267328977585, 47.43290416896343, 48.33694405853748, 53.150385171175, 58.086419105529785, 60.911145731806755, 60.048645213246346, 53.628220930695534, 62.77315601706505, 60.70552356541157, 59.970259219408035, 59.503743052482605, 56.475886926054955, 48.662537187337875, 44.57301042973995, 48.03674876689911, 54.270169883966446, 50.52485905587673, 52.707393541932106, 50.87317116558552, 47.2634332627058, 45.044561326503754, 46.34360522031784, 49.40495654940605, 56.5830297768116, 54.46491323411465, 55.77667124569416, 57.209357768297195, 59.078078493475914, 56.7762266099453, 55.28967797756195, 54.9636934697628, 55.21706007421017, 49.98920939862728, 45.17902471125126, 42.51816809177399, 42.45811991393566, 49.027161821722984, 47.47920088469982, 51.58107317984104, 57.050940468907356, 58.830221593379974, 58.40492561459541, 58.29248204827309, 50.83742268383503, 53.66268888115883, 66.16256654262543, 58.324081152677536, 42.523115426301956, 40.607623010873795, 47.008846923708916, 67.55047246813774, 59.73521903157234, 46.52728736400604, 54.319141656160355, 60.82852676510811, 55.874003022909164, 57.636074870824814, 50.64006507396698, 48.87046962976456, 47.99531199038029, 46.209202632308006, 42.98171281814575, 40.87053470313549, 43.34156110882759, 40.119953379034996, 39.80617381632328, 46.53080217540264, 49.784746170043945, 56.8757888674736, 55.590773820877075, 55.915352404117584, 56.66648469865322, 55.16584262251854, 55.502774342894554, 50.9537610411644, 46.13740548491478, 45.244400203228, 44.496349543333054, 51.944124698638916, 49.857060089707375, 51.72548063099384, 52.689238116145134, 49.468527138233185, 48.55564512312412, 53.81343439221382, 56.86981938779354, 60.40369816124439, 58.61815117299557, 61.60568006336689, 58.86777117848396, 61.884721890091896, 58.87632451951504, 57.960296273231506, 51.37447066605091, 51.85275860130787, 47.569613233208656, 50.65814450383186, 47.52638675272465, 54.91431511938572, 51.39955312013626, 58.302376717329025, 60.099847465753555, 64.14035305380821, 61.948528066277504, 68.53465005755424, 49.93223525583744, 38.381436467170715, 57.98420459032059, 64.41334560513496, 65.67113891243935, 70.51579535007477, 62.31180377304554, 52.31470361351967, 4.3949291948229074, 0.0410581476171501, 0.022372817256837152, 38.481705486774445, 68.02033245563507, 62.68669545650482, 43.83632116019726, 16.52046661823988, 35.26381015777588, 52.702788189053535, 54.6476112306118, 22.3578292876482, 45.180453434586525, 74.6594426035881, 44.807279258966446, 0.4874434252269566, 0.08961371597251855, 0.04918574450130109, 0.06146082254417706, 0.07241869607241824, 0.013958431318314979, 0.03550380679371301, 0.17048944457201287, 0.24380771268624812, 0.20269155880669132, 0.15105169150047004, 0.139421064814087, 0.2363659010734409, 0.20655670843552798, 0.3099390078568831, 0.1992124001844786, 3.571908320300281, 75.24218693375587, 73.07624235749245, 54.53426331281662, 46.413977444171906, 60.55511623620987, 55.33814437687397, 48.34949478507042, 39.45540703833103, 81.46597176790237, 74.72068771719933, 76.229807138443, 58.08659769594669, 0.4872360988520086, 0.2434326460934244, 3.8096674997359514, 21.823418363928795, 42.120603024959564, 57.92047061026096, 57.95050799846649, 59.05634745955467, 60.80969117581844, 63.67610156536102, 63.36449168622494, 61.403842493891716, 63.44836078584194, 56.683716773986816, 57.89843179285526, 54.478144124150276, 54.17592354118824, 51.0678955167532, 53.612185791134834, 50.95426261425018, 50.22223189473152, 56.150081008672714, 61.07178591191769, 63.361470848321915, 58.34150321781635, 55.90379722416401, 63.991917818784714, 62.74111993610859, 61.172662898898125, 63.06249529123306, 58.8446494191885, 49.10930581390858, 47.99485981464386, 50.144013091921806, 57.022768780589104, 53.99477206170559, 55.663156136870384, 53.807305321097374, 50.261688977479935, 49.093593657016754, 49.96988743543625, 51.840819641947746, 59.892602786421776, 56.49818032979965, 57.126590609550476, 61.064649894833565, 61.82029254734516, 61.305648162961006, 56.87247544527054, 57.996911108493805, 58.8423315435648, 52.472045570611954, 48.09360511600971, 44.713424295187, 46.676900535821915, 53.24811972677708, 52.15469799935818, 52.64237903058529, 60.05312517285347, 60.92789143323898, 63.17787989974022, 61.583097875118256, 54.30181458592415, 57.177800461649895, 67.24449008703232, 61.836168095469475, 43.20476084947586, 39.88856099545956, 46.758930534124374, 71.80151715874672, 62.61161908507347, 51.9401691108942, 54.00829553604126, 64.55896899104118, 59.004829823970795, 59.67168644070625, 53.47252048552036, 52.20620043575764, 52.97636590898037, 50.55050007998943, 45.85489824414253, 45.733665749430656, 47.7061665058136, 44.80054222047329, 45.61919309198856, 53.0356465280056, 53.15215967595577, 60.421390011906624, 57.48646929860115, 59.882149547338486, 60.19809119403362, 57.244027107954025, 58.546452820301056, 54.6101376414299, 49.27300862967968, 48.698373064398766, 47.46126964688301, 54.65908281505108, 52.35495865345001, 56.4237043261528, 56.038933172822, 52.53463201224804, 51.84597596526146, 57.223154827952385, 57.74235896766186, 63.843687772750854, 60.18261842429638, 65.41005492210388, 60.197912603616714, 64.9356959760189, 62.107625529170036, 61.87043085694313, 53.335610032081604, 54.70604829490185, 50.89320749044418, 54.26702745258808, 52.20242723822594, 58.510024175047874, 54.38002958893776, 62.98679195344448, 63.36788110435009, 70.23661673069, 64.87885102629662, 73.36717754602432, 49.59811918437481, 39.12287548184395, 62.748704329133034, 67.69057095050812, 68.88658717274666, 75.00767111778259, 65.54934024810791, 64.21412229537964, 7.85817070864141, 0.2278575490345247, 0.13198612548876554, 40.15754476189613, 79.05380040407181, 70.26152059435844, 56.356056556105614, 25.37542976438999, 41.795826852321625, 56.3418985158205, 69.05643045902252, 40.06677523255348, 56.3329765945673, 82.04274281859398, 57.27450147271156, 1.1910578445531428, 0.1706345789716579, 0.09947363767423667, 0.22425240342272446, 0.2835509675787762, 0.14525710634188727, 0.1194482232676819], [0.030140145972836763, 0.0616670394083485, 0.018859334304579534, 0.0387444094667444, 0.05136960680829361, 0.07864091414376162, 0.04475771296711173, 0.05525242697331123, 0.13331142312381417, 2.2860034089535475, 63.025614470243454, 48.14827278256416, 57.714985236525536, 36.88204452395439, 36.775004267692566, 51.66881047189236, 16.790862008929253, 15.477977357804775, 47.300865054130554, 69.1323883831501, 55.369808077812195, 71.47989481687546, 19.48532972484827, 0.10523427699808963, 0.1701540531939827, 3.387626758776605, 15.077898725867271, 30.11816617101431, 40.57847857475281, 39.37977969646454, 50.988513976335526, 55.090652257204056, 57.53585144877434, 54.51869174838066, 53.33986960351467, 50.124417543411255, 48.53518322110176, 45.192544385790825, 47.84787230193615, 48.0285070091486, 46.08547367155552, 45.51581583917141, 53.403637781739235, 53.47776420414448, 59.37800019979477, 59.21531952917576, 51.640691980719566, 55.95407232642174, 61.01132355630398, 58.206925839185715, 56.210391372442245, 54.42063421010971, 55.254180282354355, 46.343016251921654, 43.71822349727154, 45.573945119977, 50.0724021345377, 49.023122638463974, 49.371670335531235, 52.29117147624493, 43.30758333206177, 44.667116180062294, 42.82400608062744, 44.989236295223236, 48.395145535469055, 50.82905553281307, 51.77229031920433, 54.585959538817406, 54.8356669396162, 52.672895193099976, 54.57740619778633, 55.87090618908405, 53.50223109126091, 48.65577355027199, 55.88015489280224, 48.171375542879105, 43.973083421587944, 43.21429453790188, 45.70350296795368, 48.89054395258427, 52.14624725282192, 56.11621342599392, 59.16812226176262, 60.71173623204231, 51.85860648751259, 56.130196675658226, 63.087855130434036, 61.0805444419384, 42.957671508193016, 40.00958830118179, 48.4881379455328, 67.91446253657341, 59.56109717488289, 53.18421095609665, 53.10232155025005, 59.24074396491051, 55.6376177072525, 54.5432498306036, 52.51784831285477, 47.31371596455574, 44.07852776348591, 40.51243431866169, 38.64525631070137, 45.07275581359863, 44.97511625289917, 46.69149935245514, 32.65367701649666, 45.56880779564381, 51.34484365582466, 49.60872441530228, 53.61051008105278, 50.66613927483559, 54.25582565367222, 52.1677502989769, 49.8386424779892, 44.91306558251381, 42.37173914909363, 42.225101217627525, 47.43932582437992, 52.13789150118828, 47.77779646217823, 47.16030299663544, 51.40973657369614, 45.94735488295555, 44.620887860655785, 49.307503178715706, 54.3084642291069, 55.76806090772152, 56.04790449142456, 58.27864319086075, 56.729774102568626, 58.76199625432491, 57.92285308241844, 58.8798089325428, 53.69048058986664, 47.87457726895809, 46.89043007791042, 44.891277551651, 44.43887002766132, 46.13860622048378, 49.16187219321728, 50.535631477832794, 55.820897072553635, 58.316869139671326, 59.57983776926994, 63.940734565258026, 62.23146468400955, 43.97088333964348, 56.719970628619194, 61.754404082894325, 56.97511173784733, 58.37202697992325, 53.66640508174896, 21.4043103531003, 0.20002414647024125, 0.14026957709575072, 0.6738059688359499, 51.67944610118866, 58.269911259412766, 60.123265609145164, 30.837344080209732, 17.87263736128807, 23.916938826441765, 31.637102365493774, 42.860582917928696, 41.313267946243286, 47.31063053011894, 49.82519119977951, 54.137211218476295, 1.602345162536949, 0.1109931425889954, 0.07323021971387789, 0.04348794653196819, 0.038214913074625656, 0.06285523268161342, 0.09225016590789892, 0.07481150634703226, 0.05623509729048237, 0.019875859543390106, 0.03686843454488553, 0.042593061152729206, 0.07037853210931644, 0.061950024028192274, 0.07721794245298952, 0.04160753727774136, 3.0650998279452324, 70.65000414848328, 55.56270852684975, 53.13663370907307, 41.174446195364, 53.65536667406559, 52.07051731646061, 28.981571160256863, 33.238416239619255, 49.478543400764465, 80.84804132580757, 59.84615407884121, 79.81576591730118, 24.248911812901497, 0.07989173725945875, 0.2726191619876772, 2.7546875970438123, 14.477069266140461, 31.983256191015244, 46.86240278184414, 46.863033547997475, 57.87768870592117, 58.177025243639946, 60.55522263050079, 57.56037913262844, 57.11095444858074, 53.13933536410332, 52.99187287688255, 47.23922856152058, 50.66286765038967, 48.36529053747654, 50.09634464979172, 49.452267810702324, 54.7992192953825, 56.73254415392876, 63.3595709502697, 62.1102511882782, 54.80188675224781, 59.218146577477455, 61.694918274879456, 61.0170042514801, 60.14718912541866, 58.723204135894775, 56.36044152081013, 47.46133044362068, 45.886679738759995, 49.4380147755146, 53.51138100028038, 51.50417670607567, 52.46970109641552, 53.857170045375824, 47.07281269133091, 45.71814738214016, 45.95142066478729, 47.707287445664406, 51.18193879723549, 54.56978380680084, 53.561310321092606, 56.60557396709919, 56.948387771844864, 54.31545965373516, 57.796775847673416, 55.76456129550934, 54.53529305756092, 49.87529531121254, 54.025322422385216, 49.072018414735794, 47.17417985200882, 44.84886422753334, 47.41724520921707, 48.32569286227226, 53.10015946626663, 56.55858188867569, 58.12743790447712, 61.67347602546215, 53.179096430540085, 55.10222643613815, 62.55971387028694, 58.88948701322079, 42.50003546476364, 38.92199546098709, 48.76126728951931, 67.18846589326859, 59.98465284705162, 53.56230586767197, 54.55084562301636, 60.74861705303192, 56.98341429233551, 55.56093022227287, 53.63448679447174, 50.3139665722847, 45.33558011054993, 42.62149974703789, 41.064510494470596, 45.507520884275436, 48.354996889829636, 49.63146239519119, 39.992808401584625, 47.14193098247051, 53.723269030451775, 53.446564078330994, 57.66256704926491, 54.77359727025032, 55.00756971538067, 54.19747598469257, 52.27108955383301, 46.48615077137947, 45.29981642961502, 43.41312646865845, 49.375375136733055, 54.419361278414726, 49.63091142475605, 49.78530094027519, 54.70200531184673, 50.49493566155434, 47.47290462255478, 51.85684718191624, 57.05819047987461, 59.38122242689133, 58.557916805148125, 60.55269576609135, 58.46284210681915, 61.42376482486725, 60.169452130794525, 60.31912989914417, 57.78834410011768, 51.589204743504524, 50.858154371380806, 48.899598866701126, 48.39327223598957, 48.62033285200596, 53.45482863485813, 54.442616030573845, 59.32526282966137, 61.59204639494419, 62.69373647868633, 64.30642694234848, 66.10075145959854, 52.616392225027084, 58.221760243177414, 62.696156948804855, 61.747226268053055, 62.22125083208084, 56.84724859893322, 19.0134197473526, 0.638572775060311, 0.31880440714303404, 1.1122163501568139, 59.90439735352993, 64.21624258160591, 66.4824865758419, 38.97343710064888, 22.821294218301773, 31.46714698523283, 42.44609735906124, 53.68129648268223, 41.65475182235241, 58.280543088912964, 56.29654794931412, 69.55246344208717, 3.831886569969356, 0.041356398214702494, 0.02882473560021026, 0.035093792466796, 0.08529118073056452, 0.04001570101536345, 0.032109434832818806, 0.2392473933286965, 0.09687740472145379, 0.08211384614696726, 0.12134704520576634, 0.0991475157206878, 0.21739408315625042, 0.17878632905194536, 0.1431458001025021, 0.18228834582259879, 3.4679416241124272, 82.91253134608269, 64.17373046278954, 73.61275836825371, 49.23722214996815, 48.23923610150814, 74.8419240117073, 23.68177704513073, 27.319682836532593, 61.11636132001877, 80.21301940083504, 68.93108278512955, 85.09307473897934, 25.545985512435436, 0.2639401308260858, 0.4845497914357111, 3.9917451795190573, 18.901209868490696, 38.92324939370155, 54.33692470192909, 51.548394933342934, 62.18313507735729, 65.19978940486908, 68.09592559933662, 61.667939722537994, 60.48815242946148, 54.8359215259552, 56.599824875593185, 51.39516815543175, 54.77227874100208, 52.24791079759598, 53.936156406998634, 50.35712085664272, 58.206865042448044, 58.58338683843613, 66.088288128376, 60.27505986392498, 56.696278899908066, 62.43261069059372, 63.32377307116985, 64.30483102798462, 60.421355813741684, 59.55406375229359, 60.12770377099514, 48.776458874344826, 49.880694821476936, 51.347720101475716, 56.74548625946045, 52.452856600284576, 56.410826817154884, 57.77179978787899, 49.14100371301174, 48.06652396917343, 49.12873797118664, 50.99138282239437, 53.47930312156677, 58.13980624079704, 55.0636813044548, 58.06832827627659, 59.548557847738266, 57.711641415953636, 61.44417732954025, 61.39758422970772, 61.0132310539484, 52.80461512506008, 57.491485029459, 52.85849243402481, 50.85504233837128, 47.6015505194664, 51.12024150788784, 53.89449164271355, 55.16647718846798, 58.82097288966179, 61.674741357564926, 65.31487002968788, 56.46647483110428, 59.111600294709206, 66.42710834741592, 63.709323182702065, 43.05077791213989, 39.33272302150726, 49.15916293859482, 72.46450558304787, 62.359426617622375, 58.7390872836113, 57.009161710739136, 62.50075243413448, 61.01924233138561, 58.947240114212036, 56.87345199286938, 53.927933648228645, 49.44056823849678, 45.14032758772373, 44.71212096512318, 49.036003947257996, 52.78582513332367, 53.70051585137844, 44.415812864899635, 57.89319187402725, 57.73300766944885, 55.123022720217705, 61.18349991738796, 56.81603707373142, 58.51953126490116, 58.91628697514534, 58.59300412237644, 49.08901870250702, 46.02393977344036, 46.17006093263626, 52.725298181176186, 57.51327306032181, 52.53855720162392, 53.91649626195431, 58.41545104980469, 53.66046980023384, 50.408136919140816, 54.06460851430893, 60.290920212864876, 62.533176094293594, 61.98067054152489, 62.71544091403484, 60.67949116230011, 63.58806028962135, 62.45383635163307, 64.34773832559586, 61.66369155049324, 55.32707177102566, 53.71687777340412, 53.09473715722561, 52.77936168015003, 52.72705368697643, 56.64286516606808, 57.033172622323036, 61.860847771167755, 66.13488122820854, 68.15260335803032, 69.13525342941284, 68.372543156147, 50.44796258211136, 60.75348079204559, 69.21429678797722, 66.35526940226555, 66.12836077809334, 62.66012728214264, 28.64875841885805, 0.9234380861744285, 0.42907493538223207, 0.9927134751342237, 62.77982085943222, 73.47226470708847, 73.41250911355019, 44.92757320404053, 33.35733085870743, 32.5334020704031, 45.05939573049545, 66.00444182753563, 53.639464527368546, 67.88978666067123, 65.8230547606945, 79.34170335531235, 4.783557616174221, 0.1858090201858431, 0.17803989176172763, 0.1370341397705488, 0.14230539207346737, 0.1583954060333781, 0.12982567423023283], [0.014066407311474904, 0.1164919299480971, 0.026225227920804173, 0.03468115464784205, 0.08717015763977543, 0.017677035539236385, 0.03259541539591737, 0.08110405775369145, 0.028946416277904063, 1.5803186944685876, 62.153150886297226, 55.400909408926964, 49.308042749762535, 30.10532096028328, 30.676920488476753, 44.63349938392639, 41.86443977057934, 6.186275621876121, 25.773082226514816, 65.89862510561943, 62.58107632398605, 55.56332789361477, 62.36262604594231, 2.2004493372514844, 0.2898799139074981, 0.1952841828460805, 4.696920840069652, 12.276793532073498, 20.241795033216476, 37.03950047492981, 56.91271908581257, 52.06652753055096, 58.688971772789955, 57.432295605540276, 57.51640409231186, 50.825791507959366, 48.7654584646225, 46.97524532675743, 47.770622447133064, 45.44716112315655, 45.11681824922562, 51.18487983942032, 55.081715136766434, 55.56031845510006, 58.085389360785484, 54.525383189320564, 53.02419774234295, 61.578990295529366, 57.006425857543945, 57.63321362435818, 59.31295529007912, 57.360760644078255, 51.61779060959816, 46.04166202247143, 46.13299772143364, 46.695971712470055, 48.94719511270523, 51.35193407535553, 47.39908218383789, 49.632374346256256, 51.10850013792515, 48.225245252251625, 44.78795349597931, 43.16884517669678, 47.95580171048641, 49.11324620246887, 54.568225890398026, 52.908258363604546, 53.002679497003555, 53.33628259599209, 54.345151260495186, 52.2815465927124, 50.23626074194908, 55.65131597220898, 60.9616906195879, 52.18462899327278, 51.6777627915144, 48.417184352874756, 50.57660087943077, 47.17394806444645, 50.2790654450655, 51.672127693891525, 60.187664553523064, 60.66918611526489, 57.6570725440979, 54.53237481415272, 62.387579306960106, 59.82731468975544, 43.468341305851936, 40.82549571990967, 46.298125460743904, 60.88531091809273, 61.77580073475838, 53.18008057773113, 55.775747895240784, 59.73739631474018, 55.025060176849365, 50.29022164642811, 46.55780352652073, 44.44119930267334, 48.41286398470402, 45.27225650846958, 47.201162204146385, 50.273943319916725, 51.10977306962013, 45.87225191295147, 39.49468173086643, 37.229573875665665, 44.54710341989994, 55.46668387949467, 49.099965915083885, 50.76568253338337, 48.84177356958389, 50.08616499602795, 46.8065419793129, 46.74408473074436, 42.78497837483883, 45.27062639594078, 48.08225892484188, 50.42031526565552, 47.173704877495766, 49.042057022452354, 48.07839073240757, 46.207367330789566, 45.413749516010284, 51.05410225689411, 53.487176299095154, 55.74104055762291, 54.848213866353035, 57.67283409833908, 54.97980460524559, 58.88090327382088, 64.01255071163177, 53.73904578387737, 56.496922597289085, 53.45352150499821, 52.452674210071564, 46.47792421281338, 46.27459332346916, 42.873221039772034, 44.921045154333115, 48.55667106807232, 53.553273752331734, 57.744353860616684, 58.462260738015175, 58.77249129116535, 64.53382954001427, 60.46617440879345, 60.4301181435585, 55.122980922460556, 53.77008631825447, 57.03527010977268, 33.82956191897392, 2.775897108949721, 0.23177344672149047, 0.44868253637105227, 3.077678815461695, 56.96965143084526, 55.08653327822685, 60.096150264143944, 30.98878875374794, 14.20036906376481, 21.12163782119751, 32.49611087143421, 44.42544534802437, 35.430602207779884, 70.21164447069168, 46.705463603138924, 72.13667437434196, 7.836055895313621, 0.0167576054809615, 0.2643951860954985, 0.022792854288127273, 0.10613842066959478, 0.019589698531490285, 0.030405471188714728, 0.03132048361294437, 0.02942916107713245, 0.05973367049591616, 0.024060147516138386, 0.024548922265239526, 0.018607399288157467, 0.028528127004392445, 0.04082149898749776, 0.05193189870624337, 1.9789982889778912, 69.77096691727638, 66.02638185024261, 51.371130645275116, 32.34865218400955, 32.82220557332039, 64.4863548874855, 33.104507625103, 16.024695821106434, 35.58976426720619, 69.18979570269585, 70.88717222213745, 60.68348474800587, 71.76057055592537, 3.4706183429807425, 0.12794202921213582, 0.47012425144203007, 3.205580427311361, 12.665726412087679, 24.652725644409657, 45.11246368288994, 61.835404336452484, 56.76358088850975, 61.94035090506077, 58.70930828154087, 60.24524666368961, 55.297269970178604, 50.853480622172356, 49.00245554745197, 49.593004658818245, 47.169160321354866, 48.52222591638565, 53.88377241790295, 57.257782369852066, 59.04866427183151, 61.66714556515217, 56.709114611148834, 54.188979640603065, 60.78742437064648, 58.956997990608215, 59.579966962337494, 61.00950725376606, 57.58002407848835, 52.85160720348358, 47.703043073415756, 48.91511723399162, 49.62401859462261, 50.655195862054825, 53.53387199342251, 52.35869385302067, 52.79228858649731, 54.52700190246105, 48.754720240831375, 48.40251334011555, 46.5848732739687, 52.14618265628815, 51.19957745075226, 56.329286992549896, 56.156814247369766, 56.29595898091793, 54.890703186392784, 55.738756880164146, 53.574077636003494, 54.7277907282114, 56.60176657140255, 62.48834230005741, 53.41624930500984, 53.11097368597984, 50.48173896968365, 50.81401214003563, 46.47180654108524, 51.277161687612534, 54.06728737056255, 60.90191602706909, 59.97500516474247, 56.93977363407612, 54.647778421640396, 65.29415354132652, 57.55524180829525, 41.978684440255165, 39.11942146718502, 45.61645723879337, 63.10586616396904, 63.7818118929863, 53.557434529066086, 55.39378859102726, 60.34733198583126, 56.95483982563019, 52.69076183438301, 47.42205195128918, 45.427265390753746, 49.2486709356308, 45.09567618370056, 47.25096233189106, 52.784913182258606, 52.956356182694435, 47.96131141483784, 45.92359855771065, 43.36187481880188, 47.728577703237534, 55.41307255625725, 51.39955312013626, 53.3221435546875, 51.322098076343536, 53.520242124795914, 49.24905851483345, 48.01963448524475, 45.35186603665352, 48.12711551785469, 49.88299369812012, 52.08949729800224, 49.263262152671814, 49.79594796895981, 51.21357969939709, 49.175281673669815, 49.47310969233513, 53.3573866635561, 55.37055663764477, 58.19578483700752, 58.71767543256283, 60.11208660900593, 59.432542473077774, 56.68239824473858, 62.321592047810555, 60.21255321800709, 58.96516375243664, 57.964787632226944, 54.94580402970314, 51.13321781158447, 48.022013157606125, 47.501129508018494, 48.36560592055321, 49.93976265192032, 58.006026819348335, 59.997853338718414, 62.1268904954195, 61.511236131191254, 67.05951601266861, 62.119731679558754, 61.928180158138275, 61.81472584605217, 58.72041888535023, 57.02889785170555, 31.377378702163696, 1.7462283605709672, 0.6178960658144206, 0.8997884520795196, 4.057903429493308, 66.51339411735535, 57.10530035197735, 74.39771264791489, 31.108577325940132, 27.164440266788006, 28.36911052465439, 41.3337716460228, 56.051339507102966, 35.05904674530029, 82.12402805685997, 50.139115154743195, 82.40783482789993, 11.420610174536705, 0.12237032584380358, 0.1995241764234379, 0.038043187523726374, 0.09119278358411975, 0.07290865454706363, 0.038728141589672305, 0.10625998445902951, 0.1912760955747217, 0.16840570169733837, 0.09388266815221868, 0.2644666697597131, 0.1264643538161181, 0.19221791066229343, 0.2927779412129894, 0.18839194643078372, 2.454107813537121, 82.76392132043839, 72.00572580099106, 66.81353241205215, 40.92489078640938, 38.8210728764534, 63.66905674338341, 53.313495218753815, 12.63159854337573, 42.77691900730133, 77.03120693564415, 75.65575674176216, 67.20224395394325, 73.5598424077034, 3.4128310438245535, 0.533359864493832, 0.6606073176953942, 6.0778911877423525, 14.891924355179071, 33.20997856557369, 49.54322353005409, 67.44437456130981, 63.565888479352, 68.01237568259239, 64.3151892721653, 64.75386813282967, 60.55889703333378, 54.0735000371933, 52.10196442902088, 53.093969598412514, 51.20410680770874, 50.303235948085785, 56.30229324102402, 59.697456657886505, 62.05970250070095, 63.25547553598881, 58.484839126467705, 57.00850434601307, 63.95098641514778, 61.32954888045788, 63.281279951334, 63.380868807435036, 60.36210939288139, 54.60360959172249, 51.86305604875088, 50.23320950567722, 51.691293865442276, 53.46612922847271, 55.64587466418743, 54.60906609892845, 53.64133782684803, 55.59605173766613, 55.839523673057556, 50.47958068549633, 48.76142308115959, 55.835860669612885, 53.26227396726608, 59.99788373708725, 60.37667401134968, 58.60018953680992, 58.86448435485363, 59.47309009730816, 57.68815107643604, 56.40265345573425, 61.16015017032623, 64.7602441906929, 55.86236044764519, 56.11641101539135, 52.74476073682308, 54.07635748386383, 49.23719935119152, 54.23063300549984, 57.078166007995605, 63.7548865377903, 63.8843759894371, 62.40410082042217, 57.72102691233158, 65.41768491268158, 61.22174106538296, 43.60157735645771, 40.2853737026453, 46.8999295681715, 64.57288384437561, 66.11373156309128, 57.67887957394123, 59.305948466062546, 62.51625940203667, 59.46465075016022, 53.09799738228321, 52.143393605947495, 49.37067858874798, 55.86996003985405, 48.80206570029259, 51.7799811065197, 57.60524332523346, 55.887697488069534, 52.54793129861355, 50.70947214961052, 50.50899490714073, 57.08132363855839, 60.845641046762466, 53.60208213329315, 56.64101466536522, 54.526044353842735, 56.216744631528854, 51.00105710327625, 51.69266939163208, 47.96481102705002, 50.3557263314724, 51.99077479541302, 54.306940510869026, 53.01418147981167, 54.77084621787071, 54.595519825816154, 52.73326255381107, 53.24542187154293, 56.94513514637947, 56.954657435417175, 59.86754693090916, 61.44702337682247, 60.69095894694328, 63.093402832746506, 58.498928770422935, 65.01608446240425, 63.72352682054043, 62.12580755352974, 60.27167044579983, 58.12765829265118, 54.17019344866276, 52.780642211437225, 49.468656331300735, 51.53796449303627, 54.70579370856285, 61.55953533947468, 63.69856595993042, 67.07641750574112, 66.56130954623222, 73.57792183756828, 64.98382419347763, 63.72688964009285, 65.66531002521515, 66.60760626196861, 62.33403258025646, 40.672314539551735, 3.1028650514781475, 0.35148446448147297, 1.461796760559082, 5.302259707823396, 72.29930564761162, 67.88460373878479, 73.7156568467617, 44.733437821269035, 26.918175481259823, 27.95272696763277, 47.09146969020367, 65.30971750617027, 42.68575809895992, 83.0355079472065, 61.139057502150536, 93.0217444896698, 15.14414057135582, 0.3586968337185681, 0.5356545257382095, 0.13662391022080556, 0.2829052397282794, 0.12103052664315328, 0.11027502565411851], [0.016068551049102098, 0.026062048200401478, 0.039521504877484404, 0.11780216940678656, 0.08935471385484561, 0.03920101953553967, 0.030569469126930926, 0.08478226780425757, 0.17517399945063516, 0.6229877925943583, 59.71704080700874, 59.929483607411385, 50.3523863106966, 49.47271831333637, 55.86729258298874, 24.533708430826664, 70.83770647644997, 31.351541988551617, 4.199247770011425, 38.660645484924316, 68.49257111549377, 52.187684029340744, 64.83077600598335, 19.94780670851469, 1.2264211219735444, 0.2837585611268878, 0.264046584488824, 4.26776141859591, 12.311972994357347, 27.826351448893547, 39.55483630299568, 55.908527970314026, 53.37211087346077, 59.00916539132595, 58.63014332950115, 58.20664465427399, 47.577098831534386, 47.89646029472351, 46.463678777217865, 47.96107202768326, 48.749541118741035, 55.16427330672741, 57.36280493438244, 55.96223808825016, 54.346933364868164, 57.41231627762318, 53.40737298130989, 60.746682956814766, 62.497169226408005, 60.08223541080952, 56.818818524479866, 54.67215031385422, 50.936521366238594, 47.369534969329834, 44.11227375268936, 46.08073532581329, 46.289526522159576, 50.34711219370365, 50.22209510207176, 47.01524578034878, 55.27552753686905, 51.30819842219353, 49.25521418452263, 44.98581647872925, 46.93739175796509, 46.93351976573467, 50.68880885839462, 51.624159067869186, 52.32288837432861, 53.11682157218456, 52.420493736863136, 51.948103085160255, 46.26332312822342, 54.69560645520687, 52.47150219976902, 47.673834040760994, 52.36439734697342, 52.93672263622284, 53.02254103124142, 52.21318066120148, 52.864739298820496, 49.72010783851147, 54.29032400250435, 57.7628018707037, 63.472348898649216, 58.437786251306534, 66.25761464238167, 56.12875655293465, 41.72651097178459, 38.707747757434845, 47.541407346725464, 60.66591449081898, 59.7127166390419, 57.160606384277344, 57.1897242218256, 60.30402950942516, 55.52371881902218, 50.305139645934105, 49.3443688005209, 47.639628276228905, 47.71270215511322, 47.68864564597607, 49.50769163668156, 51.68930657207966, 47.96519100666046, 48.942388370633125, 48.85097287595272, 33.012700751423836, 36.55552804470062, 44.97971020638943, 51.91970720887184, 50.319563671946526, 50.22057518362999, 46.255343556404114, 47.56209343671799, 47.367718666791916, 45.99563889205456, 47.09056153893471, 48.09726431965828, 46.792201548814774, 45.09163320064545, 47.46609918773174, 45.57795390486717, 47.031767293810844, 45.438702777028084, 48.63118886947632, 51.75253517925739, 54.47603903710842, 53.318495750427246, 57.78903566300869, 54.58419643342495, 62.165876403450966, 64.0377889573574, 59.4209036976099, 60.017395690083504, 55.535532385110855, 57.53617063164711, 50.2862698584795, 51.08392305672169, 45.27078978717327, 46.92082844674587, 43.8714274764061, 49.504302218556404, 52.77859032154083, 61.94222420454025, 58.80101256072521, 63.599904254078865, 59.62719462811947, 57.979109063744545, 46.64657436311245, 49.443273693323135, 26.21122531592846, 6.663897167891264, 0.14184441446559504, 0.8943920291494578, 0.5510054051410407, 9.699700567871332, 59.45403411984444, 62.2521697729826, 51.26093275845051, 15.00693278387189, 10.119770877063274, 31.94417528808117, 27.036807015538216, 56.457150131464005, 24.855364970862865, 25.912428349256516, 53.12842234969139, 64.76079136133194, 14.570191819220781, 0.5786385317333043, 0.3423192969057709, 0.02969885383208748, 0.10461694371770136, 0.10176961252000183, 0.07772661789203994, 0.030523955065291375, 0.1316599070560187, 0.0785959919448942, 0.03201969804649707, 0.07170916578616016, 0.11716657929355279, 0.04697255622886587, 0.1073424587957561, 0.10770128719741479, 0.6872718525119126, 66.51948139071465, 67.4210362136364, 60.71479506790638, 51.26557230949402, 52.56107099354267, 33.25768120586872, 73.16147178411484, 18.67861021310091, 5.823594108223915, 37.809677347540855, 74.77448523044586, 56.5862862020731, 72.03264355659485, 23.445021249353886, 0.3413824690505862, 0.42211914143990725, 0.3957660711603239, 3.319917479529977, 13.24303513392806, 35.06335191428661, 46.94591470062733, 58.856744170188904, 58.901448771357536, 62.833264991641045, 60.414941757917404, 62.73390792310238, 51.104647144675255, 49.58144947886467, 48.207982778549194, 50.79592131078243, 49.81277346611023, 59.19355809688568, 59.141200706362724, 58.05003605782986, 56.10550180077553, 58.40427204966545, 54.321379736065865, 63.49735155701637, 63.122395277023315, 61.79069593548775, 57.505536675453186, 57.528016269207, 50.88143192231655, 48.895457088947296, 44.378605261445045, 50.01030966639519, 48.7254124134779, 53.65293860435486, 52.08334542810917, 47.43927642703056, 56.475750133395195, 55.77097915112972, 51.92230626940727, 47.38671764731407, 47.93382368981838, 49.20379154384136, 52.689538300037384, 55.49327105283737, 54.69019174575806, 55.442209392786026, 53.74142445623875, 55.12325070798397, 49.23725254833698, 55.5335146933794, 54.05259355902672, 50.584964230656624, 54.35255326330662, 54.591815024614334, 57.540369406342506, 51.97990357875824, 53.506403267383575, 52.22475863993168, 55.59085741639137, 57.88117311894894, 61.20233170688152, 57.547855004668236, 65.21167516708374, 57.91933827102184, 40.12749217450619, 37.332612946629524, 46.576441526412964, 61.72022871673107, 60.34168928861618, 58.83645325899124, 60.32476119697094, 61.9115674495697, 58.009541630744934, 51.38297840952873, 51.98305740952492, 48.84183056652546, 49.58196625113487, 48.21109481155872, 52.03006848692894, 50.82738362252712, 51.84244595468044, 49.9383757263422, 50.655693635344505, 39.78032760322094, 43.70211236178875, 47.15122148394585, 52.24197931587696, 50.441168546676636, 51.84193678200245, 49.71552908420563, 52.04257361590862, 49.93342459201813, 49.889320358633995, 50.48320569097996, 50.58437146246433, 46.97983168065548, 48.82410071790218, 49.344418197870255, 48.374368250370026, 48.32544967532158, 48.87056462466717, 51.979831382632256, 54.249837175011635, 56.617497727274895, 56.73890121281147, 59.102294594049454, 61.587615832686424, 57.24735572934151, 62.21875436604023, 64.38161730766296, 64.03604865074158, 60.31398497521877, 60.37577345967293, 54.22775276005268, 53.25188532471657, 48.9139810949564, 49.22313630580902, 48.357774540781975, 52.00334072113037, 56.06400802731514, 63.79127338528633, 63.221968933939934, 65.54985702037811, 62.785999327898026, 59.586080834269524, 49.078820049762726, 58.188591822981834, 26.626619026064873, 3.1143561098724604, 0.23267920827493072, 4.288983279839158, 0.8304703154135495, 13.386439438909292, 69.12085980176926, 69.95043128728867, 54.51584950089455, 19.9054978787899, 19.689226783812046, 21.030275523662567, 32.260261327028275, 62.82134123146534, 23.04738588631153, 30.22449966520071, 58.16602483391762, 74.88237664103508, 18.91303103417158, 0.86897436180152, 0.41723533475305885, 0.11016079428372905, 0.06007768191921059, 0.015747752149763983, 0.11310188841889612, 0.18044030905002728, 0.2790041849948466, 0.20655071188230067, 0.22378786350600421, 0.20817405602429062, 0.23950894101290032, 0.18470874172635376, 0.24661669711349532, 0.28245989175047725, 0.7717444666195661, 79.1768530011177, 76.73009589314461, 69.87461775541306, 61.021621003746986, 74.8501543700695, 35.25776468217373, 85.31568199396133, 44.42784681916237, 10.442148428410292, 55.457438975572586, 78.54529649019241, 64.25500810146332, 74.48796540498734, 25.590369030833244, 1.415095841512084, 0.8173968200571835, 0.43516963021829724, 5.9563580341637135, 16.60375624895096, 43.880831971764565, 54.30649593472481, 64.63192507624626, 64.98857393860817, 66.54121622443199, 63.62923868000507, 68.00719276070595, 54.178997576236725, 52.929704412817955, 50.6185582280159, 54.74995493888855, 53.30405652523041, 61.221988052129745, 62.101048082113266, 60.7329086959362, 58.91557261347771, 60.30193202197552, 56.15859255194664, 65.91133922338486, 65.58617547154427, 64.69531327486038, 61.26723602414131, 59.163342118263245, 52.88362808525562, 52.541703432798386, 48.39893773198128, 53.792942091822624, 50.951450765132904, 56.930372938513756, 55.350307524204254, 51.5180079638958, 60.86536578834057, 56.96466609835625, 55.644240751862526, 50.9129436314106, 50.15947066247463, 50.65844848752022, 54.31280359625816, 58.25034610927105, 58.34795147180557, 58.7247696518898, 57.99148499965668, 61.45891293883324, 54.24221098423004, 59.5352927595377, 56.35721929371357, 52.97290049493313, 56.25579133629799, 56.84543989598751, 57.580955028533936, 57.43878185749054, 57.16887094080448, 54.068978279829025, 56.84286743402481, 59.87611927092075, 63.53591948747635, 61.725677624344826, 70.59406355023384, 60.99456265568733, 40.58821365237236, 38.23530770838261, 48.96765321493149, 63.26489523053169, 61.607424169778824, 62.7095740288496, 61.61146715283394, 64.90215137600899, 60.42541019618511, 57.29541555047035, 55.85229478776455, 52.969108298420906, 53.90843689441681, 53.22209872305393, 54.56099487841129, 53.25802579522133, 51.991063579916954, 53.62426154315472, 54.48437198996544, 45.50171099603176, 49.14296820759773, 55.274178609251976, 58.77082318067551, 53.70075523853302, 53.86413127183914, 51.660044342279434, 53.00277829170227, 50.512806102633476, 52.105422243475914, 53.662137910723686, 54.16407197713852, 51.700253784656525, 50.718918442726135, 52.48391233384609, 51.3493350148201, 51.2990865111351, 50.5780827999115, 54.567861109972, 57.075224965810776, 60.36924920976162, 60.676356330513954, 62.7232950925827, 63.30385074019432, 59.562628492712975, 63.99140864610672, 61.50533504784107, 68.27599793672562, 63.153033033013344, 64.08910900354385, 57.936764135956764, 57.64606833457947, 51.466950103640556, 52.32732653617859, 51.11934095621109, 56.22204914689064, 59.09431882202625, 69.96017396450043, 67.0960320532322, 70.44669225811958, 65.7263195514679, 63.22361804544926, 53.62254023551941, 68.34443226456642, 36.86657175421715, 9.379677940160036, 0.1889840021613054, 3.9296614984050393, 1.539193857461214, 14.082405343651772, 75.40269792079926, 75.40691569447517, 63.39309275150299, 31.629383079707623, 20.506074652075768, 42.62918673455715, 41.50953881442547, 78.42630207538605, 36.744484305381775, 39.267484322190285, 69.12757784128189, 84.53826650977135, 25.169104635715485, 1.522976327687502, 0.6023560278117657, 0.18674645660212263, 0.29351308301556855, 0.2910964423790574, 0.2935828152112663], [0.019226970143790822, 0.029575360458693467, 0.11314180854242295, 0.03308760773506947, 0.07043917299597524, 0.08362357490113936, 0.046459862060146406, 0.0572970920620719, 0.18452422897098586, 0.2498277771519497, 46.74017854034901, 60.37118710577488, 46.767711862921715, 24.522842913866043, 33.737390264868736, 35.454552322626114, 36.225386559963226, 46.21848173439503, 5.133289424702525, 20.94136979430914, 62.75019384920597, 55.760449916124344, 56.17142826318741, 56.662525311112404, 1.2827650923281908, 0.31724652042612433, 0.019034215838473756, 0.3925520373741165, 2.7857737289741635, 14.891745764762163, 32.564860582351685, 46.049197018146515, 58.535631000995636, 56.101743802428246, 62.795122638344765, 56.62964187562466, 50.80124482512474, 49.16691452264786, 48.22980880737305, 49.21404339373112, 54.78608340024948, 55.531329810619354, 53.27510587871075, 57.186213210225105, 57.94291600584984, 58.25039550662041, 52.671504467725754, 56.427215337753296, 57.281645089387894, 59.448760002851486, 59.880777820944786, 53.5242585092783, 53.43703418970108, 45.422462448477745, 45.48715777695179, 46.4605363458395, 44.705790504813194, 48.89400936663151, 49.195485189557076, 49.647140353918076, 51.245589181780815, 53.41872297227383, 53.58187101781368, 50.552225187420845, 50.35356044769287, 48.81325609982014, 53.04605036973953, 53.57347346842289, 48.53074885904789, 49.451127871870995, 47.47933387756348, 50.674122646450996, 44.72427651286125, 46.46635763347149, 53.06579791009426, 48.641193732619286, 42.20678240060806, 48.1272067129612, 54.56146605312824, 50.7721421867609, 53.566899821162224, 55.82260698080063, 57.575441524386406, 55.94197757542133, 63.995991200208664, 61.91420070827007, 64.8914435505867, 60.914113372564316, 41.435944363474846, 40.25429517030716, 43.592218458652496, 60.667191222310066, 61.32097274065018, 61.01203791797161, 58.14190752804279, 56.287850216031075, 53.12163971364498, 52.315094992518425, 48.398455157876015, 52.68176011741161, 50.755062103271484, 51.19913287460804, 51.9624625146389, 40.578854754567146, 43.490429520606995, 50.26967614889145, 40.86229294538498, 38.44721853733063, 41.486914828419685, 35.892581418156624, 38.632139414548874, 47.40278318524361, 48.86646084487438, 47.51776121556759, 50.45591935515404, 45.85365571081638, 49.647071957588196, 49.41206596791744, 49.56596910953522, 39.310118034482, 46.084269136190414, 45.752273350954056, 46.97288565337658, 44.85630802810192, 48.842126950621605, 50.77697932720184, 53.48670892417431, 51.48217208683491, 58.15193518996239, 58.11049461364746, 54.96185436844826, 67.69869491457939, 74.02476266026497, 66.29183560609818, 62.27698624134064, 64.44208726286888, 62.03549399971962, 53.67386408150196, 53.06764081120491, 46.81727260351181, 48.406704515218735, 44.646897464990616, 50.51095940172672, 47.5890301913023, 58.378919810056686, 55.49349524080753, 64.02370691299438, 54.429966509342194, 65.24441421031952, 39.530331417918205, 19.138216450810432, 6.0499802604317665, 0.23032878205413, 0.5457579460926354, 2.174794301390648, 0.619401972508058, 29.052961729466915, 72.12236434221268, 47.257311791181564, 24.25838280469179, 7.281222492456436, 37.70356424152851, 66.2020768225193, 33.20717811584473, 45.753010511398315, 34.61665168404579, 39.105301424860954, 47.255134508013725, 73.06754842400551, 20.80328330397606, 0.22389848803868517, 0.3820718138013035, 0.11521533204359002, 0.11643941557849757, 0.06917686143424362, 0.058147567324340343, 0.05267121137876529, 0.02847036193998065, 0.11405975616071373, 0.016636841355648357, 0.09628089610487223, 0.044451328431023285, 0.04098251163668465, 0.0338307016500039, 0.19569773721741512, 0.4089532041689381, 56.49395875632763, 66.35974556207657, 55.39621666073799, 30.53157638758421, 41.89197689294815, 30.10989211499691, 29.696991071105003, 39.81266386806965, 4.228637292981148, 28.31808876246214, 65.33551052212715, 62.30779118835926, 61.84068225324154, 65.20943328738213, 2.0765752717852592, 0.6099255778826773, 0.22177674720296636, 0.09338407107861713, 1.9522904721088707, 15.40299978107214, 38.134187534451485, 50.25965988636017, 62.136283591389656, 61.07995927333832, 63.89066085219383, 60.39979577064514, 53.37174229323864, 53.1991745531559, 49.95274655520916, 51.999905705451965, 56.85023903846741, 58.85361313819885, 55.43916575610638, 59.63969595730305, 56.56464256346226, 58.78061905503273, 53.15685622394085, 57.05419309437275, 60.38073979318142, 62.22667694091797, 61.077546402812004, 55.9696476906538, 53.89987215399742, 48.55664826929569, 46.81546010077, 49.516427367925644, 46.78744040429592, 50.72768837213516, 49.574929028749466, 49.82409305870533, 51.40291973948479, 57.665850073099136, 55.755760967731476, 54.19002078473568, 51.84614695608616, 52.20481351017952, 54.09852169454098, 57.019185572862625, 51.33688688278198, 51.57837152481079, 50.02719596028328, 54.42589312791824, 48.32315839827061, 48.44910643994808, 55.73593743145466, 50.68650238215923, 45.0133042037487, 48.009261041879654, 57.62737713754177, 51.89657025039196, 54.56260219216347, 57.012247145175934, 58.3028668910265, 56.61686696112156, 63.08525986969471, 61.79207906126976, 64.11070704460144, 57.156183421611786, 40.58342970907688, 40.16333185136318, 44.917100965976715, 61.73983946442604, 60.3823509067297, 61.948923245072365, 60.30772291123867, 55.9729079157114, 55.39624705910683, 51.88713915646076, 51.80096738040447, 51.73450514674187, 51.82644881308079, 51.24982215464115, 51.88927464187145, 43.48931238055229, 45.98819509148598, 49.74340058863163, 44.72961902618408, 42.43168093264103, 44.211706817150116, 40.12040175497532, 43.98326687514782, 47.451420575380325, 48.87039743363857, 49.410918429493904, 52.75405503809452, 49.73761349916458, 53.83722871541977, 52.11366020143032, 51.905594766139984, 42.83808432519436, 46.882602497935295, 48.4040180593729, 49.11811374127865, 50.72277143597603, 52.00643375515938, 53.26701611280441, 55.94860062003136, 54.87534821033478, 60.508815720677376, 61.69245220720768, 58.405776768922806, 61.35901629924774, 65.32608702778816, 68.28720733523369, 67.55130842328072, 66.60537958145142, 61.0266937315464, 58.02671670913696, 56.28233291208744, 52.4021103233099, 50.41477136313915, 46.96926064789295, 54.75024752318859, 50.59073232114315, 60.64779706299305, 61.40146762132645, 64.98936429619789, 59.13138963282108, 66.31644308567047, 46.3078947365284, 28.007223643362522, 6.3001844845712185, 0.4773514636326581, 1.1534571996890008, 4.226170275360346, 0.26968468038830906, 38.17967489361763, 73.77475887537003, 56.53376542031765, 26.16695199161768, 14.194069001823664, 31.36699005961418, 51.08954295516014, 36.30143567919731, 63.83522942662239, 28.35199434310198, 38.26647363603115, 55.65678387880325, 81.79846912622452, 27.825920172035694, 0.315238565672189, 0.3969665989279747, 0.14185047039063647, 0.07595148970722221, 0.012405066136125242, 0.0049874981687025866, 0.16009047132683918, 0.14332185237435624, 0.21659484948031604, 0.05640794348437339, 0.19980355049483478, 0.1491048006573692, 0.12286661483813077, 0.11619340846664272, 0.3040514315944165, 0.3609033871907741, 64.27320152521133, 77.51656249165535, 64.99312609434128, 35.08991628885269, 46.87299281358719, 58.18292632699013, 42.52991326153278, 56.25670328736305, 10.356606468558311, 31.296838223934174, 73.09397980570793, 66.8687130510807, 69.05819356441498, 70.16302227973938, 1.7347135534510016, 1.8823585496284068, 0.1394236326450482, 0.552914208965376, 4.781863857060671, 22.422042042016983, 48.06979559361935, 54.671694338321686, 67.43322595953941, 62.97174476087093, 69.44664672017097, 64.3291649222374, 56.014242097735405, 55.32622441649437, 53.44531774520874, 53.39193060994148, 60.854642763733864, 62.2405081987381, 58.34884062409401, 62.7671979367733, 56.70302353799343, 60.40397934615612, 54.03055854141712, 58.88524644076824, 64.41193968057632, 63.94436717033386, 64.27536740899086, 59.02983248233795, 57.10685446858406, 50.107155069708824, 48.98759074509144, 52.968842312693596, 49.488369673490524, 52.63760268688202, 52.0642514526844, 53.54442022740841, 58.3288536965847, 57.69582286477089, 57.714324072003365, 55.18392205238342, 55.46951472759247, 56.88790261745453, 59.708783850073814, 59.58679139614105, 52.756999880075455, 53.805986791849136, 53.35652031004429, 60.042409747838974, 52.448954209685326, 56.1996303498745, 55.63309594988823, 52.48928904533386, 47.611802369356155, 53.25857296586037, 60.53079754114151, 54.59440268576145, 54.65804927051067, 60.20070165395737, 62.32842028141022, 58.77217970788479, 67.34331518411636, 62.61157728731632, 69.34953913092613, 60.32120458781719, 41.08507119119167, 40.10707966983318, 46.71691618859768, 63.63081179559231, 64.56140086054802, 63.96354094147682, 60.13531856238842, 61.52563355863094, 60.359126552939415, 54.8904599994421, 55.64025476574898, 56.11181326210499, 53.959403559565544, 52.64178246259689, 52.75247052311897, 46.358264833688736, 47.93429486453533, 53.57041083276272, 49.77358236908913, 47.63826794922352, 50.469302237033844, 45.23874990642071, 48.5127492249012, 52.19070486724377, 54.201936945319176, 53.242629021406174, 57.79316604137421, 52.2644779086113, 58.2803151011467, 54.71586316823959, 55.88248796761036, 46.3891913741827, 50.33064387738705, 52.26141147315502, 51.48477114737034, 52.492317482829094, 53.49569924175739, 57.18677558004856, 61.43058925867081, 57.65807569026947, 62.49514013528824, 65.44921562075615, 58.056001737713814, 64.17536437511444, 70.51446542143822, 70.74530303478241, 66.27519249916077, 71.28214582800865, 66.43071815371513, 59.64740574359894, 58.003214970231056, 53.90744514763355, 53.09337303042412, 51.090147122740746, 58.54222744703293, 54.91826310753822, 65.60033351182938, 65.25874704122543, 72.00941920280457, 64.4311286509037, 69.98686373233795, 54.376723766326904, 45.592260137200356, 8.739327751100063, 0.7200440252199769, 0.4337832686724141, 7.219621147960424, 2.587829288095236, 38.37263613939285, 85.7459557056427, 60.927344262599945, 37.084319069981575, 18.067572601139545, 51.01450078189373, 81.47527366876602, 43.97198528051376, 71.30749046802521, 44.95766378939152, 54.53425191342831, 65.89770555496216, 91.73250406980515, 35.390977934002876, 0.5788211000617594, 0.6144431792199612, 0.2611545834224671, 0.20061219460330904, 0.2894106094026938, 0.13382605800870806], [0.06995694027864374, 0.08187374653061852, 0.05247081666311715, 0.11321820522425696, 0.02770450821117265, 0.06568797325599007, 0.03731625016371254, 0.04659849153540563, 0.20548721426166594, 0.26422110793646425, 46.59677043557167, 61.181417629122734, 46.61211021244526, 41.54307201504707, 44.83893536031246, 44.819385409355164, 91.85727417469025, 21.866395957767963, 9.952348060905933, 41.31366312503815, 59.93642583489418, 65.40271371603012, 45.756544321775436, 67.77211457490921, 11.3186464458704, 1.360473653767258, 0.4021977010415867, 0.05155184117029421, 0.09731673388159834, 1.0503429640084505, 13.613660596311092, 56.21099554002285, 55.9859412163496, 58.85478727519512, 59.46755759418011, 54.53777052462101, 48.143344447016716, 46.92072205245495, 48.53318452835083, 53.38017024099827, 57.41594888269901, 56.24795235693455, 57.254453748464584, 53.64532761275768, 63.86175960302353, 57.423119097948074, 49.529540464282036, 53.04046466946602, 58.07383418083191, 56.70982137322426, 56.48635536432266, 53.56546349823475, 51.3405004888773, 46.82134598493576, 48.07292282581329, 47.540723383426666, 46.07834905385971, 45.29082991182804, 47.18903325498104, 48.903440460562706, 49.80053052306175, 52.847416028380394, 54.47568565607071, 52.7252259850502, 50.736154317855835, 52.13778890669346, 52.065197601914406, 48.56482923030853, 51.96960613131523, 49.96773675084114, 47.9479893296957, 45.317785665392876, 38.17989148199558, 37.9962283372879, 47.93813265860081, 39.64482307434082, 22.055325619876385, 22.45341695845127, 37.429940924048424, 46.4686831086874, 56.410648226737976, 51.51532530784607, 57.437869906425476, 55.52840396761894, 60.55169261991978, 61.06518566608429, 64.20361965894699, 57.31596104800701, 41.39601610600948, 40.09880371391773, 46.39546103775501, 62.975852340459824, 56.63827121257782, 61.103366017341614, 55.86686700582504, 57.03235186636448, 54.53140206634998, 51.718629598617554, 50.77973037958145, 49.251395389437675, 43.46188925206661, 42.37268529832363, 32.986185774207115, 22.350261993706226, 28.7271786108613, 41.31907403469086, 36.986098140478134, 33.258756548166275, 31.199282258749008, 38.49646009504795, 34.20878157019615, 35.271747931838036, 39.43733140826225, 43.89324210584164, 45.69662533700466, 49.571471214294434, 49.39276680350304, 46.84523530304432, 42.83669739961624, 45.212576910853386, 44.818211272358894, 45.40748365223408, 42.59220331907272, 45.40171556174755, 45.27268588542938, 51.57026655972004, 53.02354797720909, 52.39695020020008, 55.720654651522636, 62.419281005859375, 59.35938499867916, 67.21124947071075, 36.878651306033134, 28.34902100265026, 53.62183727324009, 55.640079975128174, 59.03795264661312, 55.70372276008129, 54.30822104215622, 52.23307639360428, 49.23961602151394, 44.795264303684235, 47.600182592868805, 51.56287595629692, 55.07864490151405, 60.07672570645809, 58.41816410422325, 59.24075536429882, 54.008770510554314, 43.18220525979996, 4.36989851295948, 0.7527007791213691, 0.6519105937331915, 2.653488339856267, 4.541327739134431, 2.539417273364961, 69.26986500620842, 49.74130690097809, 54.55157518386841, 19.327106215059757, 11.84888519346714, 32.53404803574085, 86.13969057798386, 34.706300273537636, 30.122401043772697, 30.399987548589706, 43.12506012618542, 45.76854407787323, 70.89204356074333, 19.600492045283318, 0.32192478189244866, 0.23332506971200928, 0.07116923850844614, 0.09602482547052205, 0.15482785762287676, 0.05831835405842867, 0.05563873710343614, 0.03622440621256828, 0.09270436770748347, 0.036503290466498584, 0.0700787192909047, 0.024460948079649825, 0.04294569262128789, 0.024764402987784706, 0.19336378667503595, 0.28294766088947654, 54.74740527570248, 68.42422798275948, 54.593152552843094, 35.27151994407177, 38.89444313943386, 63.11842069029808, 91.50988161563873, 23.939678706228733, 11.936443895101547, 46.91160634160042, 68.74818339943886, 71.92750319838524, 52.94077321887016, 73.05866450071335, 14.134928975254297, 1.572695947252214, 1.9952275743708014, 0.05256578187982086, 0.04538313936791383, 0.8625707554165274, 18.169439435005188, 60.15564367175102, 59.59938012063503, 63.570053055882454, 63.04355330765247, 58.123026341199875, 50.37734717130661, 50.293751657009125, 50.835378393530846, 56.16148419678211, 57.920455411076546, 59.37484256923199, 59.646227806806564, 58.751227632164955, 61.04571931064129, 55.400404036045074, 52.9417459666729, 56.18717461824417, 62.43491716682911, 57.55857042968273, 58.64787697792053, 53.926193341612816, 54.87949758768082, 47.629399225115776, 49.93352338671684, 48.77214230597019, 48.01043897867203, 48.89844752848148, 47.86280930042267, 52.18276709318161, 49.406495466828346, 55.297699347138405, 57.91643522679806, 56.405244916677475, 52.301632314920425, 54.83156315982342, 55.91736629605293, 50.10110579431057, 55.40583774447441, 49.52549368143082, 52.17801734805107, 50.238149240612984, 44.283693954348564, 42.05240808427334, 49.24207828938961, 41.980964317917824, 25.492096804082394, 28.207235410809517, 37.62349113821983, 49.57788906991482, 57.083405926823616, 51.1916396766901, 57.30030208826065, 56.73404507339001, 61.028684824705124, 63.44655208289623, 63.80638897418976, 55.044697523117065, 38.642026484012604, 39.18056398630142, 44.843088537454605, 62.32062689960003, 56.40184409916401, 62.79270976781845, 56.91592611372471, 57.531656473875046, 55.40169216692448, 51.29090175032616, 53.31467695534229, 48.77235509455204, 42.23878048360348, 46.33614622056484, 35.677379965782166, 26.39342363923788, 32.230102345347404, 46.49144388735294, 43.547901436686516, 39.74902868270874, 35.33443696796894, 38.81256513297558, 37.83564895391464, 41.62453584372997, 42.930487766861916, 44.439686983823776, 48.51356998085976, 51.45886413753033, 52.95490086078644, 49.11705739796162, 46.24239005148411, 47.638248950242996, 47.542034313082695, 46.87012776732445, 44.83680747449398, 47.08861604332924, 46.531953513622284, 52.39695779979229, 54.920417591929436, 55.83644203841686, 58.43045264482498, 64.86020922660828, 64.05173420906067, 64.83256950974464, 35.31078323721886, 30.65503366291523, 54.97734613716602, 55.17132192850113, 61.90124720335007, 58.569475784897804, 57.35235549509525, 56.815584897994995, 52.941202595829964, 47.04737685620785, 51.243761479854584, 53.256376683712006, 57.74890601634979, 64.27965357899666, 61.90943956375122, 63.014990240335464, 57.186057418584824, 49.682854637503624, 5.3969278279691935, 0.49223995534703135, 0.6923067604657263, 2.7282203547656536, 1.884444400202483, 4.588901186361909, 74.73048359155655, 55.002455189824104, 59.86187383532524, 24.79006167501211, 13.446709904819727, 26.900958605110645, 76.98652893304825, 31.212345957756042, 45.73994681239128, 38.98989401757717, 45.55783398449421, 51.655894964933395, 79.46663305163383, 24.57071464508772, 0.5293316056486219, 0.24578311684308574, 0.03960738249588758, 0.15920719684800133, 0.05307618652295787, 0.05518216785276309, 0.10937835540971719, 0.1947507419390604, 0.1529952575219795, 0.22239286336116493, 0.1861822314094752, 0.2601259370567277, 0.1426015089964494, 0.09464843838941306, 0.4109175206394866, 0.3529686707770452, 64.39667209982872, 81.46183758974075, 63.30689437687397, 49.825392588973045, 60.54927594959736, 59.92796368896961, 97.97544747591019, 30.14867663383484, 17.564154714345932, 50.98524235188961, 73.77067789435387, 77.61883780360222, 59.42309997975826, 78.04674804210663, 15.656206794083118, 3.1443239143118262, 1.2639614450745285, 0.15015203040093184, 0.23005020950222388, 1.6502094129100442, 22.61007685214281, 63.33380453288555, 61.57954506576061, 68.52522656321526, 67.7385775744915, 60.17235517501831, 52.95167103409767, 53.51282112300396, 54.068336114287376, 60.21819591522217, 61.954497545957565, 61.05527959764004, 61.35819174349308, 58.79754714667797, 59.73785609006882, 57.15813271701336, 54.40337173640728, 55.698125660419464, 62.213940024375916, 58.279026970267296, 60.339747592806816, 55.91189458966255, 56.34186811745167, 48.96873615682125, 52.420311346650124, 51.29253566265106, 50.75155109167099, 51.12232759594917, 50.11957660317421, 55.23666702210903, 52.82237537205219, 57.17365488409996, 59.066914692521095, 59.57398608326912, 55.25082886219025, 58.41671638190746, 58.00682097673416, 53.012669160962105, 58.068309277296066, 55.898621901869774, 58.56103643774986, 53.34509052336216, 48.07105332612991, 46.109609976410866, 57.28682801127434, 46.24951086938381, 23.10969304293394, 26.86070926487446, 42.91370026767254, 52.43166133761406, 59.12160135805607, 52.737328335642815, 59.970225021243095, 59.481928423047066, 64.73679944872856, 68.09615358710289, 66.0756728053093, 58.73684920370579, 39.92007650434971, 39.79602076113224, 47.369504570961, 67.34878689050674, 56.45599879324436, 65.09626775979996, 58.44332255423069, 62.113747000694275, 59.63782265782356, 53.85280787944794, 54.02064487338066, 51.47034712135792, 44.5914052426815, 50.08825108408928, 39.954331666231155, 27.91965924203396, 35.21077260375023, 51.53869405388832, 46.89878582954407, 43.06279666721821, 40.665908083319664, 43.63830238580704, 43.83151441812515, 46.98314890265465, 45.31667612493038, 48.501452431082726, 53.187687769532204, 57.70344525575638, 56.95423185825348, 50.90374052524567, 47.9081142693758, 50.083968713879585, 49.91837739944458, 51.307605654001236, 47.618448212742805, 50.360278487205505, 49.18207950890064, 56.33509308099747, 57.23369546234608, 59.34789061546326, 60.7284477353096, 67.96300873160362, 62.06784926354885, 72.60549321770668, 47.592928782105446, 34.03950825333595, 56.41688749194145, 59.38314512372017, 65.4630620777607, 60.059672221541405, 59.795951172709465, 59.004666432738304, 55.795035660266876, 50.498750656843185, 56.01666256785393, 56.52149207890034, 60.78722298145294, 71.43805146217346, 65.40409684181213, 64.8976980149746, 60.961303040385246, 58.661309257149696, 11.123976241797209, 1.3279056013561785, 0.7835944870021194, 7.58249550126493, 11.91094821318984, 4.0313176810741425, 85.5064545571804, 61.37443587183952, 67.01661631464958, 31.20345253497362, 24.177274256944656, 43.688277304172516, 96.96843311190605, 39.0881909430027, 46.824891194701195, 47.010097056627274, 61.9564164429903, 62.586745619773865, 87.69887611269951, 32.63908959925175, 0.7231741072610021, 0.3340554825263098, 0.25574435654561967, 0.2569537900853902, 0.2177253333502449, 0.11618671429459937], [0.00844976690132171, 0.07057984708808362, 0.07637907066964544, 0.02761761385045247, 0.03266452047682833, 0.10944694469799288, 0.05683326831785962, 0.114830773381982, 0.3609526954824105, 0.3177990939002484, 39.32714492082596, 64.27019208669662, 45.792953968048096, 37.99115180969238, 44.68071565032005, 28.461686857044697, 57.39653952419758, 29.481584429740906, 1.8544764770194888, 46.624353155493736, 60.51915876567364, 56.089086681604385, 42.63181619346142, 62.52828195691109, 27.164189480245113, 0.575180776650086, 1.1504033510573208, 0.05028759260312654, 0.0805779937945772, 0.12646123679587618, 1.2269502435810864, 61.23796999454498, 61.90913178026676, 57.12557226419449, 58.40672291815281, 52.95496925711632, 47.720484137535095, 50.1252268999815, 51.74363985657692, 56.2720088660717, 60.09214527904987, 57.193668410182, 56.452366188168526, 57.62876786291599, 68.19522187113762, 63.481206223368645, 50.12019596993923, 51.96506917476654, 53.655191883444786, 57.85270884633064, 53.936749175190926, 52.64917306602001, 51.854350715875626, 49.70146223902702, 48.849749341607094, 47.474599331617355, 44.73653465509415, 49.2604199051857, 48.61744120717049, 51.94896183907986, 52.13264398276806, 49.930977523326874, 55.48715338110924, 49.50517617166042, 51.30031384527683, 50.58079965412617, 47.36250154674053, 52.2609668970108, 52.37419322133064, 44.2176117002964, 45.23369237780571, 37.78908245265484, 38.056660294532776, 40.2996913343668, 50.889658480882645, 52.52860553562641, 44.695527255535126, 33.26298572123051, 28.01807016134262, 23.070140965282917, 35.564085245132446, 47.527234107255936, 54.59215700626373, 58.431091010570526, 63.11036892235279, 61.58483438193798, 64.90669593214989, 54.51800778508186, 38.49613331258297, 39.525950253009796, 42.802373841404915, 59.5724281668663, 61.45034059882164, 58.22314716875553, 59.49323281645775, 59.01485748589039, 52.87182591855526, 40.51225192844868, 34.63160388171673, 35.21060921251774, 41.43143780529499, 45.98669417202473, 53.329849541187286, 50.549215748906136, 46.62437595427036, 49.770021960139275, 43.65933045744896, 41.06767952442169, 33.08122627437115, 26.170858182013035, 23.60238790512085, 31.780941747128963, 37.175875157117844, 40.64429484307766, 46.8607422709465, 53.33609260618687, 50.44816397130489, 49.16241556406021, 45.358945056796074, 51.63147747516632, 48.45522031188011, 46.05753377079964, 38.91820326447487, 41.75606198608875, 43.137869238853455, 48.50557900965214, 50.65374054014683, 52.15005464851856, 57.66113452613354, 62.25572258234024, 64.87048387527466, 43.47407519817352, 30.54981730878353, 44.97298836708069, 51.72596700489521, 60.15561707317829, 57.291585355997086, 54.31511767208576, 53.9009702950716, 57.66070134937763, 49.245881885290146, 51.92800976336002, 49.95610557496548, 54.60879251360893, 52.03358329832554, 60.98740004003048, 61.84921279549599, 63.5094653069973, 64.11183178424835, 37.105970308184624, 0.18571214022813365, 0.09431686165044084, 0.10226966420304962, 1.8269260553643107, 0.880692636128515, 16.99959620833397, 71.84159740805626, 44.71217416226864, 58.108970895409584, 30.822975151240826, 25.4060922190547, 9.83303066343069, 42.738487869501114, 39.68616485595703, 32.9265745729208, 25.813943333923817, 24.314236007630825, 47.97176085412502, 66.68009117245674, 17.97064170241356, 0.26053806650452316, 0.26487820548936725, 0.09912572626490146, 0.16438094578916207, 0.040762023272691295, 0.13373248802963644, 0.08201429445762187, 0.05243763152975589, 0.04365686676464975, 0.1095710763183888, 0.06337550046737306, 0.04131051493459381, 0.03144448906823527, 0.11517061764607206, 0.33923050796147436, 0.19680188968777657, 43.989650532603264, 74.21838507056236, 48.47867265343666, 32.63920359313488, 52.842263504862785, 41.829261258244514, 74.03189867734909, 33.15168209373951, 3.955483725294471, 49.992655813694, 68.96183833479881, 59.07989859580994, 47.57163092494011, 71.44407793879509, 30.988142788410187, 0.682125206803903, 3.289503436535597, 0.1791656407294795, 0.11572275325306691, 0.11987796387984417, 1.7748117330484092, 66.22824221849442, 64.59632858633995, 61.459315717220306, 60.05544684827328, 56.20724894106388, 50.1736781001091, 54.27787587046623, 52.87841856479645, 57.672742903232574, 59.13868524134159, 62.46045559644699, 58.82479168474674, 62.13147684931755, 63.219730854034424, 57.92528115212917, 53.576771691441536, 53.95770505070686, 57.665728479623795, 59.8095278441906, 56.829655542969704, 54.19622205197811, 55.4564244300127, 49.27031457424164, 50.683948919177055, 49.876123666763306, 50.14624737203121, 49.0792266279459, 48.84298950433731, 53.308555483818054, 53.496953174471855, 55.11034280061722, 57.96850763261318, 54.376852959394455, 52.93807156383991, 52.53797963261604, 48.82075309753418, 57.47126631438732, 55.50995975732803, 49.98960077762604, 49.74786534905434, 44.959016516804695, 44.23162914812565, 48.820791095495224, 55.303771421313286, 54.425406754016876, 51.51128612458706, 44.39861498773098, 35.89666239917278, 27.11373768746853, 39.529491662979126, 51.7557118088007, 56.84897370636463, 56.70945659279823, 63.48385088145733, 60.906376987695694, 63.968533873558044, 55.01790516078472, 38.43997232615948, 39.10755470395088, 42.19318673014641, 60.0798187404871, 61.484603360295296, 57.69363418221474, 57.0260214060545, 58.6306980997324, 55.33336043357849, 42.464598566293716, 37.805098593235016, 40.17253875732422, 45.043523982167244, 48.08412842452526, 57.210224121809006, 54.85228344798088, 49.83676917850971, 48.4992029517889, 46.09773561358452, 50.521484836936, 46.52817651629448, 38.881987407803535, 31.12177401781082, 34.84289534389973, 40.233875066041946, 43.273271173238754, 49.237298145890236, 55.00769890844822, 52.37826280295849, 53.00644889473915, 49.21467415988445, 52.001475021243095, 50.59001415967941, 47.052878960967064, 43.63884575664997, 43.46573084592819, 45.15298470854759, 50.35595051944256, 53.641478419303894, 54.903523698449135, 60.351469963788986, 65.18447622656822, 68.96595731377602, 41.75535522401333, 34.77908916771412, 47.09310360252857, 52.58567847311497, 61.48317463696003, 56.784095987677574, 57.912977412343025, 56.968009918928146, 59.45814549922943, 53.62398415803909, 53.229090347886086, 51.71661950647831, 56.03637970983982, 54.87813726067543, 61.98447413742542, 63.6741978675127, 66.04884624481201, 66.95328891277313, 40.111479833722115, 0.08805785531876609, 0.05527108827664051, 0.11918677206267603, 2.7459625527262688, 1.4113674103282392, 21.54591355472803, 78.14202412962914, 52.099471762776375, 62.98083007335663, 39.41231735050678, 30.893305577337742, 13.509396091103554, 49.25096981227398, 39.48812708258629, 46.7992539703846, 28.882291987538338, 23.32834281027317, 52.51411311328411, 76.85285210609436, 23.82017321884632, 0.4652314796112478, 0.24776214268058538, 0.03614788336562924, 0.11323347862344235, 0.05560813093325123, 0.07797926722560078, 0.19054282398428768, 0.17138922441517934, 0.13268401147797704, 0.24213005817728117, 0.24433674523606896, 0.1417642179876566, 0.138588642294053, 0.34556654922198504, 0.7253338757436723, 0.3520666348049417, 56.51509702205658, 83.61634477972984, 63.66374082863331, 48.62815283238888, 62.35767111182213, 42.07752853631973, 59.588284716010094, 40.45907378196716, 7.748207934200764, 56.317477226257324, 73.97588968276978, 65.53120762109756, 55.57714395225048, 77.1825148165226, 35.01305781304836, 1.482017613016069, 2.732812645845115, 0.3314616170246154, 0.2104251680430025, 0.3097725292900577, 3.7612892081961036, 69.10005211830139, 66.79400905966759, 65.60223340988159, 65.31433045864105, 60.53355619311333, 53.25887314975262, 56.487001329660416, 54.513619020581245, 60.07959455251694, 63.69366802275181, 63.63692566752434, 60.33737272024155, 60.41155993938446, 64.82364758849144, 59.99769374728203, 52.301727309823036, 55.21164156496525, 60.32697267830372, 60.98744943737984, 55.46196073293686, 52.76817508041859, 55.05168154835701, 51.512585654854774, 53.978459537029266, 52.31020465493202, 51.91559962928295, 53.46658520400524, 51.629509180784225, 57.64476120471954, 56.085055097937584, 56.523840352892876, 62.48159386217594, 58.399598300457, 56.9870050996542, 56.33810251951218, 51.08974814414978, 61.43686652183533, 60.49946442246437, 54.826501831412315, 54.24907721579075, 49.60328310728073, 47.64326088130474, 51.50661237537861, 60.39126142859459, 56.42140544950962, 47.97276400029659, 42.08282545208931, 37.427790239453316, 31.91926382482052, 45.27237430214882, 56.36866807937622, 57.026105001568794, 57.93098084628582, 65.29356837272644, 62.29654759168625, 65.12741088867188, 54.9517697095871, 38.78996394574642, 39.84232507646084, 40.48282630741596, 61.043941006064415, 64.45915594696999, 58.03113967180252, 63.41171935200691, 61.70257106423378, 56.58003933727741, 43.43476630747318, 42.172542437911034, 48.172534480690956, 52.835754454135895, 53.01686033606529, 56.30317099392414, 46.80610880255699, 46.27055414021015, 52.68584869801998, 51.99104458093643, 50.73053441941738, 45.46509996056557, 40.06454095244408, 34.90054965019226, 41.447484344244, 46.92338950932026, 47.08800807595253, 50.14610677957535, 56.40242546796799, 53.82897935807705, 56.270150765776634, 49.3497759103775, 55.56895539164543, 53.456101566553116, 51.79372496902943, 45.89835651218891, 46.66659168899059, 47.45965473353863, 54.293717220425606, 56.99305057525635, 58.223561346530914, 64.10402700304985, 69.14322540163994, 68.57310399413109, 58.201172947883606, 40.22753320634365, 45.69054186344147, 54.236382097005844, 62.247408628463745, 60.59727117419243, 59.830913096666336, 57.71026968955994, 62.662996128201485, 55.68680226802826, 55.11859215795994, 56.82892978191376, 59.53329026699066, 57.97201484441757, 66.20329275727272, 67.11785048246384, 66.68320700526237, 67.3346820473671, 46.406738832592964, 1.357061080634594, 0.4077225155197084, 0.13342088990611956, 8.976061698049307, 6.034475667402148, 20.975801646709442, 84.50979843735695, 57.147565484046936, 75.3739182651043, 44.448776096105576, 36.381976157426834, 19.457346126437187, 60.84636300802231, 46.27214625477791, 51.4654453843832, 37.5031553953886, 31.991581544280052, 60.89826822280884, 83.30443471670151, 32.035324797034264, 1.1730675911530852, 0.3502405359176919, 0.24946611374616623, 0.2981674770126119, 0.17684518243186176, 0.30695269466377795], [0.1672584007610567, 0.05529357906198129, 0.06690233465633355, 0.08650995790958405, 0.06749122141627595, 0.0815383848384954, 0.05777776626928244, 0.4386288102250546, 0.2036420867079869, 0.8420678274706006, 27.117098607122898, 64.46181580424309, 49.73936900496483, 31.75534252077341, 19.633854255080223, 49.32226158678532, 22.218553461134434, 22.616046331822872, 9.277573619037867, 45.32367154955864, 62.87412419915199, 65.55652186274529, 54.03156168758869, 57.50953026115894, 47.32913553714752, 0.4203998821321875, 4.4965067692101, 0.3520034038228914, 0.11370547712431289, 0.2600903733400628, 1.3126165280118585, 58.28467346727848, 62.5848913192749, 63.781561106443405, 56.53482176363468, 48.826202005147934, 48.01277205348015, 51.429123133420944, 57.03396297991276, 60.17829045653343, 60.40316618978977, 62.359624207019806, 63.501641526818275, 59.40438598394394, 67.52555340528488, 76.24029457569122, 47.48110458254814, 49.15872976183891, 53.33503246307373, 61.91880606114864, 56.306013241410255, 58.77224050462246, 54.72116008400917, 48.69692154228687, 49.54578839242458, 48.11009623110294, 43.974208161234856, 44.73691463470459, 43.787619173526764, 46.64908602833748, 49.04459908604622, 49.68730799853802, 50.75734958052635, 57.595515847206116, 55.401870757341385, 57.885664477944374, 55.124618634581566, 56.777510941028595, 51.74255691468716, 46.10058166086674, 50.87631359696388, 52.29489907622337, 62.982988357543945, 54.30061765015125, 46.415143981575966, 52.451697662472725, 61.91584601998329, 68.32898989319801, 67.07783862948418, 49.977661818265915, 31.74385003745556, 24.312184117734432, 33.25923912227154, 44.918670281767845, 55.57144805788994, 59.08245585858822, 66.66572034358978, 54.168681129813194, 40.87670937180519, 41.78866423666477, 42.27384500205517, 59.28223013877869, 57.47988045215607, 60.60424380004406, 54.62849445641041, 37.79553070664406, 26.210140474140644, 27.35685244202614, 42.64935985207558, 56.1638742685318, 65.18674850463867, 70.28547450900078, 70.01629695296288, 62.13102467358112, 60.41984349489212, 45.55750720202923, 53.13438802957535, 53.92498880624771, 56.24484792351723, 54.50035773217678, 41.14532455801964, 28.867309391498566, 31.154482662677765, 34.85298000276089, 45.66269315779209, 50.8152736723423, 56.912236511707306, 52.76326194405556, 50.870241522789, 49.824199452996254, 46.987450271844864, 45.9857252240181, 46.84301242232323, 47.74838984012604, 46.420691683888435, 47.14032366871834, 52.04699657857418, 51.74618951976299, 56.146729588508606, 55.51408253610134, 61.541577503085136, 31.60401564091444, 43.29179137945175, 54.31147366762161, 57.970095947384834, 63.05809512734413, 58.86416517198086, 57.09588825702667, 53.63029181957245, 53.65999102592468, 51.260716170072556, 51.72070048749447, 49.28955674171448, 51.65944017469883, 53.831453025341034, 56.53178572654724, 63.04210938513279, 58.52029122412205, 71.00605264306068, 24.494445137679577, 0.14203415194060653, 0.05417902910267003, 0.22889228101121262, 1.1124842357821763, 0.40040143649093807, 31.308338306844234, 60.93914642930031, 49.45083148777485, 58.09690274298191, 47.45115838944912, 33.047104105353355, 7.664404856041074, 19.331819862127304, 28.397069424390793, 39.03083302080631, 41.72939121723175, 45.974086448550224, 46.37403018772602, 69.48835328221321, 14.216402303427458, 0.05753409321187064, 0.47413561900611967, 0.09798189115826972, 0.14676216698717326, 0.0512837366113672, 0.082304592942819, 0.10739162607933395, 0.07136047512176447, 0.07428213983075693, 0.08407920162426308, 0.01145584163168678, 0.06417966942535713, 0.09733778118970804, 0.27917763974983245, 0.3447886003414169, 0.7215824676677585, 30.510194934904575, 74.61209714412689, 56.256277710199356, 33.4198223054409, 34.53535504639149, 49.710794538259506, 26.514509841799736, 26.157036423683167, 13.769677374511957, 51.244928017258644, 68.94943580031395, 69.32835906744003, 56.10743589699268, 66.5525472164154, 50.26846021413803, 0.8097711042501032, 4.185726195573807, 0.2373352349968627, 0.14167613990139216, 0.3922104713274166, 1.8764581787399948, 62.44377449154854, 64.86329466104507, 65.94798445701599, 57.47106492519379, 52.017700150609016, 48.454426154494286, 54.83684107661247, 58.64914990961552, 62.252257168293, 62.98164322972298, 64.90326091647148, 61.986465230584145, 63.48512381315231, 64.7621288895607, 63.474047407507896, 46.1578293889761, 49.23193663358688, 56.468701511621475, 63.62340219318867, 60.16442880034447, 62.48226262629032, 54.95682343840599, 50.44092535972595, 50.33507443964481, 49.34012822806835, 46.8086888641119, 48.43604654073715, 48.34591917693615, 47.75288499891758, 51.081168204545975, 51.48653045296669, 53.42175900936127, 60.27976021170616, 57.45428882539272, 59.79882761836052, 60.47282785177231, 58.45920570194721, 54.05105464160442, 51.958229541778564, 61.96042522788048, 63.10140140354633, 70.12089774012566, 56.27779595553875, 48.715453147888184, 53.83946679532528, 69.84569370746613, 75.66337153315544, 76.95195838809013, 61.38243444263935, 38.00762392580509, 28.56152079999447, 37.246045991778374, 50.2104677259922, 55.24662248790264, 61.65409706532955, 65.91662853956223, 53.18655163049698, 41.2300980091095, 41.82546526193619, 44.289070665836334, 62.87557952105999, 59.55824352800846, 60.7259626686573, 55.29745236039162, 41.15585379302502, 30.412386283278465, 32.447937056422234, 47.5154547393322, 58.69880184531212, 63.754582554101944, 70.43222263455391, 69.38185259699821, 61.684928610920906, 60.42390927672386, 48.68367925286293, 50.94214506447315, 54.850915521383286, 62.482445016503334, 65.83709880709648, 59.76121723651886, 43.95744726061821, 38.79615381360054, 36.62035636603832, 45.50798065960407, 52.959931790828705, 56.91132836043835, 54.75873626768589, 53.193030282855034, 50.7043082267046, 48.06764870882034, 45.98652698099613, 46.375132128596306, 48.116863667964935, 48.90336446464062, 47.62001372873783, 53.6451680213213, 53.34914110600948, 56.79828442633152, 58.61831456422806, 63.61872084438801, 33.17180961370468, 43.38445320725441, 54.04282808303833, 60.84756374359131, 63.74915264546871, 59.867964908480644, 59.1487281024456, 56.343357637524605, 56.29082925617695, 54.195591285824776, 54.094258323311806, 52.1800996363163, 51.616886258125305, 56.69406361877918, 57.458122819662094, 66.32475703954697, 60.32255731523037, 74.26810160279274, 26.594774834811687, 0.1354125322541222, 0.04700716999650467, 0.10576540982583538, 1.0896391491405666, 0.5217809951864183, 37.90269635617733, 71.55741065740585, 54.23331946134567, 69.23582643270493, 56.64340853691101, 37.95184671878815, 11.209287364035845, 30.190749876201153, 26.01975169032812, 46.55445970594883, 43.06434318423271, 42.90271505713463, 54.101116955280304, 75.89594945311546, 17.151512056589127, 0.46129361435305327, 0.5769062996841967, 0.1267344065126963, 0.1530403652577661, 0.025502617281745188, 0.1037292905675713, 0.25491766340564936, 0.34846620925236493, 0.21461797587107867, 0.2878646267345175, 0.24428841657936573, 0.22635303757851943, 0.30789332231506705, 0.5410665040835738, 0.8106786024291068, 1.0587932355701923, 40.199220925569534, 86.02511912584305, 71.61449119448662, 44.30901579558849, 31.28961481153965, 70.01327991485596, 26.95617914199829, 30.67262291908264, 18.49313836544752, 52.41751469671726, 71.19571566581726, 73.98499399423599, 61.15082927048206, 71.42249509692192, 57.63437636196613, 1.208638313692063, 10.92447554692626, 0.8919218648225069, 0.4271504277130589, 0.5941536335740238, 2.981384857557714, 64.4128592312336, 67.74770468473434, 67.82157272100449, 61.58221252262592, 55.01767337322235, 52.31357887387276, 59.078697860240936, 61.15254297852516, 68.32532688975334, 65.3763735294342, 67.36419126391411, 65.22552162408829, 63.24484370648861, 71.75830587744713, 65.57098388671875, 44.053331315517426, 50.039951875805855, 58.04301783442497, 67.78671339154243, 58.785535991191864, 62.009917572140694, 56.41955114901066, 54.692547619342804, 53.25485676527023, 55.155446380376816, 48.22078429162502, 51.852051839232445, 51.20438799262047, 50.31082034111023, 53.19800801575184, 54.07792679965496, 55.478748232126236, 64.19794276356697, 59.23221342265606, 66.12920433282852, 61.405780389904976, 65.69380089640617, 59.23071250319481, 53.49634140729904, 64.64067220687866, 64.08182099461555, 69.92536023259163, 62.36764557659626, 54.07644107937813, 59.24548991024494, 68.00962463021278, 66.41670450568199, 67.69871011376381, 59.71475712954998, 45.09018927812576, 35.06855383515358, 43.279787823557854, 53.27139727771282, 54.59573641419411, 62.364981919527054, 66.07549801468849, 54.357181414961815, 42.065680772066116, 44.002995416522026, 47.566489800810814, 64.96305450797081, 61.30905658006668, 63.75768318772316, 54.16960448026657, 40.83694830536842, 35.252220779657364, 43.58893923461437, 56.49403095245361, 62.156057730317116, 62.88320951163769, 67.87863805890083, 65.3640165925026, 61.49154178798199, 61.73647664487362, 53.601329773664474, 55.2206052839756, 53.010225892066956, 56.57989874482155, 59.26583021879196, 55.77013939619064, 45.59637911617756, 43.8156046718359, 44.307944253087044, 50.73923595249653, 56.52073211967945, 58.25138345360756, 56.9759438931942, 54.34663698077202, 53.986089527606964, 53.66873435676098, 49.886044934391975, 50.30135124921799, 51.273586079478264, 50.64004987478256, 51.022780537605286, 55.06816886365414, 56.47970572113991, 59.86896425485611, 62.12908297777176, 68.70187908411026, 41.98902748525143, 48.43613013625145, 58.28495845198631, 66.20434910058975, 66.97887673974037, 65.64269363880157, 62.794222086668015, 58.81610535085201, 61.61050200462341, 55.3784754127264, 56.529832631349564, 54.14000786840916, 55.785156190395355, 59.17924806475639, 61.488874331116676, 68.40168759226799, 64.901133030653, 78.32515150308609, 30.861115604639053, 0.2515687665436417, 0.22436792613007128, 0.32314870215486735, 2.528922474011779, 0.6925086840055883, 38.575723841786385, 76.05434015393257, 58.97845923900604, 69.66469421982765, 57.76770740747452, 46.033933237195015, 19.79396626353264, 34.02666114270687, 33.96822787821293, 62.75254972279072, 59.001615196466446, 61.04405499994755, 61.84484302997589, 88.32088753581047, 24.799247682094574, 0.9760615811683238, 0.6498952768743038, 0.25380545121151954, 0.3089069772977382, 0.1541388625628315, 0.17508416989585385], [0.09819872444495559, 0.09964614248019643, 0.13437685032840818, 0.10913741716649383, 0.05243461098871194, 0.052313021224108525, 0.20907132740831003, 0.07326737904804759, 0.45984820753801614, 0.660159713588655, 15.045866444706917, 65.6097038090229, 47.42778584361076, 42.41857923567295, 27.660142667591572, 43.54731246829033, 29.542390666902065, 14.10504262894392, 15.845795720815659, 58.32865230739117, 68.92848372459412, 66.0467791557312, 57.444025576114655, 55.4641380161047, 49.48779210448265, 4.469767129048705, 3.177689448930323, 0.3715948556782678, 0.0736214428616222, 0.36678449192550033, 0.23248210869496688, 46.011130660772324, 69.7372779250145, 61.93486399948597, 60.56150749325752, 52.41821765899658, 50.369067415595055, 55.448855236172676, 55.11217050254345, 58.88356313109398, 59.60593856871128, 60.942866429686546, 50.76426520943642, 63.67236636579037, 37.903061136603355, 56.81487433612347, 69.76243257522583, 44.64550293982029, 55.80466814339161, 57.48808041214943, 64.48355823755264, 58.67349900305271, 56.51325412094593, 46.19109660387039, 44.46430966258049, 46.46737597882748, 45.766138806939125, 47.48217612504959, 47.95961670577526, 46.532348692417145, 47.13621988892555, 53.54062043130398, 52.12027184665203, 54.893302246928215, 58.47244419157505, 61.196244433522224, 60.85782319307327, 54.9834144115448, 53.788826912641525, 64.75730314850807, 58.576585203409195, 59.60632234811783, 61.33886978030205, 60.24909965693951, 56.029274091124535, 56.350911632180214, 54.83139596879482, 55.0915490090847, 67.70468339323997, 77.60361582040787, 75.57025372982025, 55.522240698337555, 29.097987413406372, 25.038978718221188, 35.68160533905029, 48.684325218200684, 52.79510423541069, 54.36852000653744, 54.22377057373524, 48.943862691521645, 52.59440280497074, 52.19230078160763, 56.098817959427834, 41.34720392525196, 24.287542439997196, 25.948201529681683, 45.54192043840885, 66.86963260173798, 68.94354611635208, 60.95803901553154, 61.2045393884182, 52.703996524214745, 48.807286620140076, 48.45424376428127, 47.59382173418999, 45.078383311629295, 52.59909935295582, 47.542231902480125, 52.56209313869476, 64.22915428876877, 66.6318641602993, 63.63495357334614, 54.45520095527172, 40.76143875718117, 35.840170830488205, 45.92249281704426, 51.25893026590347, 52.76516184210777, 54.73117254674435, 52.291205674409866, 47.9454130679369, 45.079831033945084, 46.39671117067337, 48.44546243548393, 51.64739862084389, 51.04031279683113, 56.51230797171593, 54.00907829403877, 54.635858461260796, 54.96429763734341, 54.56343434751034, 41.66055031120777, 48.31876203417778, 62.03738249838352, 60.660142600536346, 56.573746874928474, 57.01442062854767, 55.15508159995079, 53.063966408371925, 54.355338513851166, 52.048508897423744, 51.801818534731865, 53.295985758304596, 49.73837725818157, 51.45766720175743, 54.5972753316164, 66.0137589275837, 57.92202852666378, 72.70130887627602, 15.061461757868528, 0.6554701714776456, 0.11630841909209266, 1.2326753488741815, 1.2170970160514116, 0.9222942288033664, 51.49508759379387, 55.671758875250816, 57.93717451393604, 40.93285895884037, 48.15019927918911, 33.581792414188385, 10.01507319509983, 11.904794443398714, 30.455211885273457, 47.09323659539223, 23.601280264556408, 32.38923020660877, 51.81045547127724, 69.54137563705444, 7.936510629951954, 0.17153812892502174, 0.2326699165860191, 0.20077614986803383, 0.091789492580574, 0.07489547293516807, 0.12861094175605103, 0.0963586509169545, 0.07032757624983788, 0.07908966857939959, 0.08816447225399315, 0.06812068881117739, 0.07432111742673442, 0.18118155130650848, 0.03829883142316248, 0.4972923483001068, 0.5249748425558209, 20.48074521124363, 74.12996381521225, 55.58035857975483, 39.59932431578636, 37.03252784907818, 51.92520171403885, 27.988437451422215, 20.73133796453476, 14.787032883614302, 66.8320906162262, 74.19531270861626, 73.18488612771034, 61.57690040767193, 59.14155788719654, 54.34624180197716, 4.540312243625522, 3.923502741381526, 0.4112207918660715, 0.060195301193743944, 0.6064609356690198, 0.11497567771584727, 51.09711214900017, 72.90054738521576, 64.51408579945564, 60.46994760632515, 56.52609743177891, 53.60297128558159, 60.98508596420288, 59.007858261466026, 61.57477632164955, 60.37755936384201, 62.9356998950243, 53.42602238059044, 68.42839255928993, 35.664054080843925, 52.08983547985554, 58.63616220653057, 41.432608142495155, 55.89125409722328, 61.205584332346916, 67.69299522042274, 64.12819370627403, 58.53779308497906, 48.71209032833576, 47.08124823868275, 49.68563228845596, 46.87474451959133, 47.92391762137413, 51.622399762272835, 49.568583369255066, 51.85155786573887, 55.489167273044586, 52.256714925169945, 54.34016212821007, 59.362303242087364, 62.93066516518593, 61.95908010005951, 59.24595348536968, 61.944173499941826, 70.40499329566956, 67.45519638061523, 61.7716209590435, 60.118911042809486, 61.21864803135395, 58.135451674461365, 56.56634107232094, 55.99026158452034, 57.869655936956406, 70.87071910500526, 84.44701820611954, 89.71996486186981, 65.3414686024189, 34.631265699863434, 28.28967198729515, 43.60717065632343, 51.390148624777794, 57.370047345757484, 56.01939842104912, 49.93578426539898, 48.2287372648716, 51.92357920110226, 57.064144760370255, 62.95970320701599, 50.02290599048138, 29.253425672650337, 29.913775138556957, 44.6963632106781, 67.30326533317566, 68.07090774178505, 57.8803713619709, 58.36171053349972, 51.74952954053879, 52.660735845565796, 49.77425113320351, 47.11077265441418, 46.307765543460846, 54.41294342279434, 46.97316683828831, 51.736431643366814, 63.270864710211754, 73.53654205799103, 78.27763125300407, 73.78958567976952, 55.16014292836189, 43.588213473558426, 49.01663638651371, 52.25579917430878, 54.29317764937878, 55.81487439572811, 54.746143743395805, 49.63513299822807, 44.886607602238655, 45.79654477536678, 47.3209697753191, 52.004511058330536, 52.29326516389847, 58.03186543285847, 56.70987457036972, 58.55603210628033, 56.14326797425747, 57.0406848192215, 44.04333785176277, 50.635653510689735, 63.90370935201645, 62.88093343377113, 58.51995684206486, 58.57749715447426, 56.95575937628746, 57.067910358309746, 56.16643153131008, 54.48332704603672, 52.57886923849583, 54.8509269207716, 49.64886546134949, 54.88410674035549, 55.96883453428745, 66.66228532791138, 61.12598620355129, 76.80481508374214, 15.07685948163271, 0.5511421978008002, 0.022384040385077242, 1.4680425566621125, 2.959000733681023, 1.6592792887240648, 62.103593945503235, 60.59884048998356, 66.59233868122101, 48.048227950930595, 53.12619186937809, 38.399675488471985, 13.419280126690865, 23.084109015762806, 26.033235266804695, 55.91574378311634, 29.463995173573494, 31.967164054512978, 61.01070038974285, 76.5787424147129, 9.788217768073082, 0.13350170978810638, 0.3846548736328259, 0.014978513299865881, 0.06777156770112924, 0.046539468530681916, 0.06419296871172264, 0.3541789058363065, 0.14055821317015216, 0.3093187802005559, 0.20075535489013419, 0.1872561636264436, 0.19044328713789582, 0.2812150726094842, 0.23070462048053741, 0.5542943067848682, 0.8374744083266705, 25.199896283447742, 84.2218878865242, 65.59876799583435, 57.69005857408047, 38.36951270699501, 66.31880655884743, 35.61572827398777, 23.47564570605755, 22.176176235079765, 70.22799119353294, 74.87354591488838, 78.31870704889297, 65.80814436078072, 66.90462112426758, 57.57342003285885, 5.793241811916232, 9.88746939226985, 1.1893249000422657, 0.1810491076321341, 1.2187119293957949, 0.6147439568303525, 54.27533380687237, 73.09927672147751, 67.88507491350174, 65.26991084218025, 60.83224296569824, 56.970263198018074, 63.248381316661835, 61.971691623330116, 65.51792353391647, 64.54222708940506, 64.73174571990967, 55.62641590833664, 67.03462734818459, 48.79038892686367, 64.43777069449425, 56.02360099554062, 42.60459825396538, 54.807928428053856, 67.79592409729958, 69.2911134660244, 67.28167489171028, 61.35827533900738, 52.718960121273994, 48.17174792289734, 53.98224413394928, 50.681615844368935, 50.56878849864006, 53.53488273918629, 51.85696877539158, 54.8101969063282, 57.924365401268005, 54.93601955473423, 57.96606816351414, 64.562928378582, 67.9085348546505, 67.03505292534828, 64.88567546010017, 66.14137887954712, 71.37169182300568, 68.00352215766907, 61.86151273548603, 65.39248466491699, 67.90462866425514, 65.32897487282753, 59.95267756283283, 59.072496592998505, 58.04769158363342, 63.94892692565918, 71.8938522040844, 74.74597916007042, 69.50303569436073, 46.74971982836723, 33.6251936852932, 47.63412617146969, 49.63241994380951, 58.27117659151554, 57.05564461648464, 52.54277877509594, 48.963294848799706, 52.81464658677578, 58.0799176543951, 63.16605493426323, 47.01523818075657, 35.739411637187004, 48.45160290598869, 55.067481100559235, 62.0688334107399, 59.896812960505486, 53.6868479847908, 57.12342917919159, 52.27173551917076, 53.72184410691261, 58.04282404482365, 56.35652393102646, 51.403406113386154, 54.5164954662323, 50.462580397725105, 53.40446613729, 62.03930899500847, 65.61710581183434, 69.40846636891365, 65.09905681014061, 55.133380964398384, 47.269060760736465, 57.54912793636322, 57.05789029598236, 56.378935128450394, 59.370552599430084, 57.92982190847397, 54.05732050538063, 49.69254411756992, 48.10055874288082, 51.65625214576721, 52.93903671205044, 54.99140918254852, 59.96883049607277, 58.300883397459984, 61.823442578315735, 61.84556119143963, 61.18093125522137, 48.5228680819273, 53.22377063333988, 66.43439635634422, 66.82020485401154, 63.95446702837944, 61.73147991299629, 62.24060699343681, 60.92913016676903, 61.00498549640179, 57.98570170998573, 56.56600669026375, 57.94249042868614, 55.13968102633953, 57.73347124457359, 60.08108027279377, 70.61767548322678, 62.7496200799942, 79.11224126815796, 20.93620777130127, 0.4694764158921316, 0.3493592800805345, 2.393156234174967, 4.833530634641647, 2.094932561740279, 61.963020488619804, 67.89547875523567, 68.12668114900589, 52.49900512397289, 58.5528364777565, 47.77645893394947, 19.85428612679243, 20.02628769725561, 39.954339265823364, 79.13420408964157, 40.87873466312885, 47.0428740978241, 66.70546621084213, 92.0973452925682, 17.92793769389391, 0.582686027046293, 0.6488733098376542, 0.2762414957396686, 0.36375035473611206, 0.20483183849137276, 0.23457453469745815], [0.0951302851899527, 0.14057853317353874, 0.021383701387094334, 0.2009204085334204, 0.04723212980024982, 0.06000853230943903, 0.1562544732587412, 0.11199193977518007, 0.34439864626619965, 0.25755172362551093, 12.098908927291632, 73.05617183446884, 46.13041765987873, 43.99196460843086, 26.359077282249928, 43.679735362529755, 36.6499187797308, 27.15447150170803, 7.158752689138055, 37.806933894753456, 73.04374650120735, 65.40507718920708, 60.94607725739479, 54.83483858406544, 60.82478776574135, 12.524008266627789, 1.7488159029744565, 0.17165378521895036, 0.03813705436186865, 0.6751754984725267, 0.9031058521941304, 35.267305970191956, 66.55908286571503, 61.456682458519936, 60.62075011432171, 53.700614646077156, 51.864735558629036, 55.580096393823624, 60.221186354756355, 59.62077297270298, 55.47155521810055, 63.768011033535004, 65.46039462089539, 53.19922395050526, 43.05440291762352, 24.327048920094967, 60.33781349658966, 54.277526289224625, 47.625265046954155, 59.57142882049084, 63.99947941303253, 64.42878797650337, 56.70594938099384, 49.289579540491104, 47.78298698365688, 50.1654439419508, 43.467706739902496, 46.870709136128426, 49.037770852446556, 51.80508255958557, 51.376754343509674, 48.61121714115143, 49.534996971488, 48.553733825683594, 54.29684065282345, 56.37633226811886, 55.05229331552982, 59.238760471343994, 70.55942460894585, 62.3105688393116, 54.282534420490265, 56.61550663411617, 53.83196979761124, 56.85610972344875, 56.48749150335789, 58.419634625315666, 56.84918649494648, 55.509241595864296, 57.328466176986694, 55.38248799741268, 62.825076431035995, 81.57118052244186, 79.80440452694893, 40.09197548031807, 23.125978969037533, 30.290293134748936, 45.7714357227087, 48.74826818704605, 46.23463086783886, 46.38185016810894, 43.601170778274536, 46.979417502880096, 30.14922760426998, 23.040827438235283, 40.53325720131397, 67.12867990136147, 65.36593928933144, 56.600220054388046, 50.33644616603851, 51.797608360648155, 46.768851801753044, 55.10887987911701, 58.0915754288435, 51.67671784758568, 52.47057884931564, 54.11321170628071, 57.11358390748501, 55.69929599761963, 56.712982803583145, 54.1629434376955, 52.64866769313812, 61.468815207481384, 73.56406778097153, 65.9371930360794, 51.14587493240833, 52.47686371207237, 51.40391908586025, 51.914402693510056, 50.79681046307087, 49.93023656308651, 48.484087362885475, 45.813841447234154, 41.44123747944832, 47.45316468179226, 49.056720435619354, 53.75223867595196, 62.96558529138565, 61.45484335720539, 57.998883202672005, 56.45163282752037, 61.19839511811733, 52.14457154273987, 48.45367379486561, 57.55094803869724, 57.69363798201084, 57.5622334331274, 53.293052315711975, 54.898739755153656, 54.47575785219669, 51.843958273530006, 52.057016640901566, 52.25339010357857, 54.27691452205181, 48.02802063524723, 51.34877264499664, 53.55481646955013, 63.490682914853096, 60.97579546272755, 72.20953166484833, 6.367958597838879, 0.41674869367852807, 0.12282280586077832, 0.5580401932820678, 1.805184215772897, 6.356715951114893, 69.48588341474533, 53.941704109311104, 59.35583598911762, 28.214470222592354, 73.62662762403488, 24.09441590309143, 4.839482540264726, 26.11747484654188, 41.947727501392365, 43.451945185661316, 31.578902788460255, 37.904064282774925, 57.0938515663147, 55.192790776491165, 2.220377130433917, 0.25363054184708744, 0.3429918608162552, 0.17357887176331133, 0.10274456450133584, 0.029612161706609186, 0.02523480030504288, 0.029555506152973976, 0.05156073209946044, 0.13957332383142784, 0.14434512559091672, 0.12768604763550684, 0.027528407699719537, 0.0921539167757146, 0.07210970288724639, 0.4213434783741832, 0.6328639376442879, 13.309872597455978, 78.65192636847496, 54.13465395569801, 37.98793338239193, 30.336633548140526, 54.413957968354225, 26.164497323334217, 30.304276384413242, 9.257379602640867, 35.766382589936256, 75.04468113183975, 69.91104260087013, 65.20780697464943, 61.00337438285351, 65.84944814443588, 14.997141659259796, 2.3425536369904876, 0.2776355162495747, 0.1673911709804088, 0.7972137874457985, 0.9947723709046841, 38.216320127248764, 69.49372619390488, 63.99774670600891, 60.05914404988289, 57.067180797457695, 51.53360992670059, 59.31578993797302, 64.3759024143219, 65.61474993824959, 58.61090876162052, 68.567024320364, 65.52205011248589, 54.63647782802582, 45.456539019942284, 27.221353612840176, 50.104035437107086, 50.7247169315815, 48.720685467123985, 60.53766757249832, 65.25007590651512, 62.6734683662653, 58.49592313170433, 55.31996235251427, 53.52776572108269, 51.41770854592323, 47.32359163463116, 49.0208275616169, 48.49118158221245, 53.38149257004261, 54.80034023523331, 53.03688906133175, 52.37997271120548, 52.831912860274315, 55.07672980427742, 57.19697043299675, 56.914972364902496, 66.8823391199112, 73.6767165362835, 62.672153636813164, 53.94992306828499, 56.18763819336891, 56.2353940308094, 59.79917719960213, 59.99419793486595, 62.18505397439003, 60.38131356239319, 57.57799878716469, 59.49639044702053, 56.60819202661514, 71.21970757842064, 98.75376731157303, 91.95964068174362, 48.188174441456795, 27.90577668696642, 37.77776665985584, 47.21807509660721, 46.499514654278755, 46.631409376859665, 45.48777334392071, 44.0505650639534, 50.99467344582081, 39.800097942352295, 30.293055586516857, 43.69344502687454, 71.10687643289566, 69.73388850688934, 58.920322358608246, 47.612444534897804, 48.37516240775585, 49.610806703567505, 57.94477790594101, 63.10430444777012, 52.807833552360535, 55.60778930783272, 54.4827076792717, 58.33644188940525, 55.24424001574516, 57.76684105396271, 51.44964963197708, 48.99888753890991, 57.239189967513084, 76.89671695232391, 82.53939136862755, 69.92939561605453, 60.70674329996109, 54.62670475244522, 51.74861378967762, 51.038017719984055, 48.985975831747055, 50.87116867303848, 47.10344284772873, 43.60918074846268, 48.53044107556343, 48.57964463531971, 51.50512285530567, 59.75898675620556, 60.135478153824806, 59.14761856198311, 59.29581440985203, 64.82161089777946, 51.35292202234268, 49.31994751095772, 60.277594327926636, 60.49380652606487, 57.852085679769516, 56.75765320658684, 53.612675964832306, 57.11398288607597, 52.987860292196274, 54.546479657292366, 55.08821278810501, 56.594611555337906, 51.59939959645271, 54.43226158618927, 53.78101833164692, 66.05385437607765, 62.662893533706665, 76.22292950749397, 7.331701358780265, 0.5476495320908725, 0.18732739496044815, 1.085121666546911, 0.4158105596434325, 8.156184442341328, 75.654586404562, 58.802490681409836, 67.55696251988411, 31.81879911571741, 79.46301564574242, 26.093938909471035, 11.879433654248714, 29.76359959691763, 45.755221992731094, 57.339914962649345, 33.45667652785778, 37.78133846819401, 65.49698665738106, 61.27060264348984, 3.0673880176618695, 0.04602501918270718, 0.3152104828041047, 0.12405728688463569, 0.06314041034784168, 0.03277882235124707, 0.05060176597908139, 0.15661747253034264, 0.19979857810540125, 0.2578233793610707, 0.19853743171552196, 0.18695407983614132, 0.12223904734128155, 0.2763898659031838, 0.20123147231061012, 0.4071176057914272, 0.8518723701126873, 16.090363897383213, 91.75008192658424, 61.59554220736027, 61.07241667807102, 33.240688517689705, 70.83415746688843, 45.71550652384758, 38.09940040111542, 15.162207651883364, 47.11806446313858, 80.84196165204048, 73.60305368900299, 71.66414692997932, 66.0972860455513, 68.91748711466789, 15.268707387149334, 3.994829189032316, 0.5441891052760184, 0.47409100108779967, 1.4012077054940164, 2.1226546866819263, 43.41984450817108, 70.4076835513115, 68.04764539003372, 63.229541927576065, 61.82052433490753, 54.94936443865299, 65.3970368206501, 66.59239947795868, 69.86082449555397, 59.5731957256794, 70.62845930457115, 66.40790417790413, 53.88053119182587, 46.215597689151764, 32.4216652661562, 62.402687296271324, 49.971205964684486, 50.21334037184715, 63.37959587574005, 68.89783456921577, 68.4835048019886, 63.883152455091476, 56.93642981350422, 53.80274556577206, 54.509906619787216, 47.93097384274006, 49.31344226002693, 52.491470128297806, 56.708882823586464, 58.41973342001438, 55.084743574261665, 55.32323777675629, 57.230442836880684, 58.09237338602543, 60.18283121287823, 61.34524583816528, 70.21618902683258, 72.84434840083122, 62.137252539396286, 58.6963015794754, 64.27786007523537, 59.266210198402405, 66.23617619276047, 62.14500032365322, 65.00134885311127, 63.50178971886635, 65.54351896047592, 63.67128722369671, 56.86774089932442, 60.902220010757446, 78.18226397037506, 84.6777494251728, 60.60203231871128, 36.61903403699398, 42.90075436234474, 46.77561543881893, 49.01663638651371, 49.29069668054581, 45.16248419880867, 46.305561661720276, 48.78585956990719, 36.97376400232315, 43.02386395633221, 60.77911041676998, 68.03382933139801, 60.98952032625675, 58.999023735523224, 52.06883020699024, 53.06786499917507, 61.430631056427956, 69.62706863880157, 67.40266039967537, 57.92159914970398, 60.211325883865356, 59.920455291867256, 62.259036004543304, 59.12347465753555, 59.546874538064, 56.496622413396835, 52.92657718062401, 57.0170196890831, 72.33804076910019, 72.13030591607094, 65.98552644252777, 63.06387461721897, 60.31388618052006, 56.41987793147564, 55.088258385658264, 52.800879925489426, 55.09110823273659, 49.47722107172012, 45.63657335937023, 51.22937545180321, 52.08768479526043, 55.77165171504021, 67.05657497048378, 65.5216321349144, 64.31462690234184, 59.77826312184334, 70.02445131540298, 53.280721977353096, 51.426782459020615, 65.2947387099266, 63.900069147348404, 62.62563273310661, 61.03517487645149, 57.21558943390846, 60.44398359954357, 59.51675735414028, 59.28253032267094, 58.26537810266018, 61.96352206170559, 55.448194071650505, 57.16562211513519, 55.446461364626884, 67.2298912703991, 65.20646184682846, 81.32328942418098, 10.503331795334816, 0.5027061968576163, 0.25710162590257823, 1.2173728574998677, 5.2054542023688555, 8.49405376240611, 81.3772389292717, 64.76224288344383, 69.89169403910637, 38.141794726252556, 85.25990098714828, 38.070628345012665, 11.99097951874137, 37.03047215938568, 57.89917655289173, 70.60417860746384, 47.644697204232216, 52.37572833895683, 72.25483283400536, 78.72569561004639, 7.347000762820244, 0.409975764923729, 0.5376504873856902, 0.2864732185844332, 0.3206584701547399, 0.09371266438392922, 0.17391833011060953], [0.08216666479711421, 0.052517679578159004, 0.09078881033929065, 0.04846815449127462, 0.09838524099905044, 0.0499278699135175, 0.026141803100472316, 0.11943533958401531, 0.2166201121872291, 0.12123532229452394, 4.320563860237598, 64.97092008590698, 54.707290828228, 41.42404340207577, 32.01802432537079, 40.32675348222256, 59.068613201379776, 69.29441928863525, 10.64805842936039, 16.975385807454586, 53.72933730483055, 60.1579425483942, 63.23789767920971, 60.90299516916275, 65.26937127113342, 22.922311797738075, 1.2429972575046122, 0.8937714155763388, 0.05935058128670789, 0.3229011513758451, 0.7049229147378355, 21.305272467434406, 70.25794118642807, 62.71905452013016, 67.46146604418755, 52.87848696112633, 53.18466313183308, 55.630793273448944, 59.06217634677887, 56.824031844735146, 68.48362639546394, 51.43233396112919, 27.88611464202404, 51.81181199848652, 58.21921817958355, 63.69924232363701, 24.744086042046547, 43.34116593003273, 52.659029737114906, 55.20796716213226, 59.80234242975712, 62.64348417520523, 58.06535683572292, 56.2273308634758, 50.595204681158066, 51.332832500338554, 45.40726326406002, 46.025376096367836, 49.597986191511154, 49.34863217175007, 46.10786586999893, 46.55425451695919, 48.41939963400364, 50.02477928996086, 46.6626551002264, 51.79157428443432, 56.64753891527653, 65.40598154067993, 59.415530785918236, 53.2853577286005, 53.48727889358997, 57.16027960181236, 53.57035003602505, 54.05006669461727, 56.508120596408844, 54.36789683997631, 69.6173107624054, 63.91025260090828, 56.615518033504486, 60.20113483071327, 57.866475507617, 61.84012368321419, 74.52277913689613, 95.62716588377953, 57.09069013595581, 26.916370578110218, 33.05320657789707, 44.88607943058014, 44.68434825539589, 41.27321049571037, 45.142740458250046, 30.647321976721287, 30.48166036605835, 64.89659607410431, 77.89803922176361, 54.063111394643784, 49.28196094930172, 53.50174851715565, 56.612223610281944, 55.22012650966644, 70.43644040822983, 54.94937963783741, 48.162586614489555, 50.934807658195496, 51.91725254058838, 57.564851492643356, 58.63117307424545, 57.594349309802055, 55.581015944480896, 54.15253959596157, 57.46056228876114, 54.23043541610241, 54.618098214268684, 61.57834433019161, 71.60224065184593, 61.218412443995476, 55.6154078990221, 52.79899142682552, 47.88077473640442, 48.68831120431423, 49.71236005425453, 46.142607405781746, 43.963059559464455, 47.17215076088905, 49.470731019973755, 50.28534270823002, 58.57693858444691, 57.06499591469765, 55.153010711073875, 57.331836596131325, 56.972630470991135, 51.72353893518448, 52.28902839124203, 59.50655110180378, 57.20806963741779, 52.75370545685291, 56.17477208375931, 52.88578636944294, 56.36895686388016, 54.29335243999958, 54.66368816792965, 52.78927534818649, 50.62795132398605, 48.4666994959116, 50.489729940891266, 52.856721729040146, 65.4135051369667, 60.66006280481815, 68.36596190929413, 3.2729296758770943, 0.4791231779381633, 0.14518666168441996, 1.3937649736180902, 0.7338763517327607, 12.470133807510138, 63.62990744411945, 55.539107993245125, 55.00935561954975, 57.34209984540939, 60.8575876057148, 1.6884082881733775, 22.63854682445526, 23.739684037864208, 25.65384842455387, 41.17147095501423, 40.921174585819244, 45.095885172486305, 53.25766861438751, 39.718641713261604, 1.3113950123079121, 0.11968402584898286, 0.017578103543200996, 0.012599452238646336, 0.058770815521711484, 0.059819733651238494, 0.05199747116421349, 0.10818736423971131, 0.12444408683222719, 0.06960182261536829, 0.04095100004633423, 0.05533893912797794, 0.03690662546432577, 0.03693402926728595, 0.08846547250868753, 0.14790488145081326, 0.028012685033900198, 3.757817856967449, 69.89808529615402, 62.4833569675684, 43.42287294566631, 28.974817022681236, 54.41498391330242, 30.272113010287285, 56.65541209280491, 13.832278065383434, 22.631988376379013, 54.37105067074299, 63.15092034637928, 63.802072405815125, 63.528601080179214, 71.08593955636024, 27.055798396468163, 0.6577870377805084, 0.9501568274572492, 0.10193743437412195, 0.3599596722051501, 0.5809288588352501, 23.962300792336464, 71.9720596075058, 64.54079076647758, 68.55796560645103, 55.906856060028076, 51.98040135204792, 57.80301511287689, 61.795863658189774, 61.9185134768486, 69.55684080719948, 55.015268102288246, 29.403466321527958, 56.09521955251694, 58.932975679636, 61.040494590997696, 26.515228003263474, 45.663817897439, 54.77930836379528, 56.09898515045643, 63.83557140827179, 62.3852614313364, 57.97973982989788, 57.51584552228451, 52.344858795404434, 55.60632258653641, 47.231860756874084, 49.817014038562775, 50.47421157360077, 52.42111310362816, 48.750981241464615, 50.81905446946621, 54.40882444381714, 53.89984555542469, 52.043185383081436, 52.60721191763878, 57.12805733084679, 61.844641640782356, 57.023198157548904, 54.84159082174301, 57.09137789905071, 59.598601162433624, 57.44109593331814, 55.78891418874264, 59.13361631333828, 54.867182448506355, 65.39872393012047, 65.24965032935143, 61.14478759467602, 66.11187726259232, 57.720396146178246, 63.741214871406555, 87.31490671634674, 109.39830332994461, 58.57756935060024, 28.850768879055977, 38.882082402706146, 47.592328414320946, 44.9012216180563, 43.00796940922737, 45.46211712062359, 37.253060415387154, 34.196025654673576, 61.79984584450722, 77.1904943883419, 58.588573560118675, 48.35313878953457, 55.69390028715134, 58.78544479608536, 61.24018147587776, 67.48450800776482, 55.978801399469376, 51.519436687231064, 55.03342732787132, 54.57209028303623, 59.084177166223526, 56.44911736249924, 54.53197583556175, 57.348643094301224, 56.880086436867714, 57.054094299674034, 51.09935782849789, 53.0310145765543, 60.36439307034016, 71.93037584424019, 69.44785505533218, 62.41463005542755, 53.90014573931694, 48.83580029010773, 49.07987259328365, 49.7781915217638, 48.04466374218464, 45.46483397483826, 49.274281561374664, 52.467827796936035, 51.06846168637276, 58.2324642688036, 55.222581177949905, 56.871236711740494, 54.087080508470535, 59.2195563018322, 47.34008274972439, 50.78791134059429, 61.169885247945786, 61.47290378808975, 56.57259173691273, 58.44379372894764, 55.846443101763725, 58.585666716098785, 54.82498951256275, 56.361520662903786, 55.407452657818794, 54.07309725880623, 48.092320784926414, 53.49886067211628, 57.22450755536556, 67.51979291439056, 60.07354907691479, 71.82412594556808, 3.917539673857391, 0.42396578297484666, 0.12271903135115281, 1.4981883578002453, 1.0355852684006095, 17.803441174328327, 68.9680851995945, 61.811944395303726, 56.55589163303375, 60.07960595190525, 58.8300696015358, 4.998087929561734, 23.99439387023449, 22.040694504976273, 32.413267716765404, 52.575308829545975, 47.80386306345463, 45.25886982679367, 63.63452419638634, 49.04076129198074, 1.4127298747189343, 0.13445064949337393, 0.05083402109448798, 0.016042668648879044, 0.12520610180217773, 0.0075554826617008075, 0.07749761338345706, 0.33290892373770475, 0.21331531374016777, 0.3035648795776069, 0.21109802881255746, 0.32805697002913803, 0.15270261385012418, 0.3011422127019614, 0.2870382007677108, 0.5508376203943044, 0.3265289176488295, 5.662745889276266, 82.68734782934189, 69.09647271037102, 58.31769369542599, 37.56381914019585, 66.76198437809944, 70.73296889662743, 82.7281804382801, 20.749529488384724, 27.07830458879471, 64.59127485752106, 71.20113417506218, 72.09928438067436, 71.63409054279327, 77.91228085756302, 27.35312294214964, 3.640222242102027, 1.3943276996724308, 0.18385399540420622, 1.1976958508603275, 1.4487685658968985, 27.701891027390957, 75.23112952709198, 70.41022181510925, 73.05882409214973, 58.629219979047775, 57.485511749982834, 60.34984365105629, 65.79185083508492, 65.35985961556435, 76.27452313899994, 57.184807285666466, 32.672007232904434, 54.11704570055008, 65.55601269006729, 58.61546091735363, 29.444040544331074, 51.00562825798988, 53.45365449786186, 60.89309670031071, 65.40908217430115, 67.80298411846161, 58.66119526326656, 62.2100680321455, 54.03623543679714, 55.396684035658836, 49.54570099711418, 53.5420947521925, 54.07126195728779, 56.87893509864807, 50.26824742555618, 54.10092316567898, 55.006064996123314, 55.60775890946388, 54.31149646639824, 56.87779515981674, 61.28110907971859, 66.05702340602875, 60.50501212477684, 62.51786671578884, 62.661719396710396, 63.286360278725624, 60.878672674298286, 58.29246684908867, 67.574023604393, 54.48259748518467, 66.74284860491753, 65.7638843357563, 60.876039415597916, 72.843466848135, 61.70162111520767, 61.70165531337261, 68.83721262216568, 92.66329452395439, 71.03139728307724, 38.66338513791561, 47.395536974072456, 46.337324157357216, 41.92550249397755, 42.4978543817997, 45.93191631138325, 40.91711640357971, 59.09628711640835, 75.92064052820206, 68.0848453938961, 54.9533162266016, 58.79523687064648, 62.968324944376945, 67.13726744055748, 63.65699619054794, 67.21624240279198, 52.67267860472202, 52.512574195861816, 57.394297644495964, 58.4694841504097, 63.75233307480812, 58.5310522466898, 60.01836083829403, 62.24429279565811, 60.027856528759, 58.748430982232094, 55.64504250884056, 54.400795474648476, 58.53521682322025, 67.84325435757637, 67.45823621749878, 64.5878854393959, 58.19469429552555, 52.183131873607635, 51.768152341246605, 54.20314148068428, 51.425471529364586, 50.03919191658497, 50.2201572060585, 54.888818487524986, 55.64515270292759, 65.27515456080437, 60.00533513724804, 61.315850615501404, 62.421477288007736, 64.26969051361084, 48.04319702088833, 50.669498294591904, 65.33193871378899, 65.6001815199852, 62.34340287744999, 61.04089356958866, 60.50325661897659, 62.98436388373375, 59.99922126531601, 62.124595418572426, 59.61022473871708, 57.48894676566124, 51.81205898523331, 56.06348365545273, 57.893416061997414, 71.4598698914051, 62.788503393530846, 77.18840450048447, 5.5702028051018715, 0.6037057272624224, 0.2491743309656158, 6.090413890779018, 6.444895444437861, 16.662742383778095, 81.77036583423615, 64.63150709867477, 71.23627468943596, 63.71437691152096, 74.49636295437813, 8.334960099309683, 34.623935893177986, 33.47686484456062, 34.353037029504776, 63.04498963057995, 56.072390377521515, 60.52824027836323, 71.70178011059761, 67.69580706954002, 2.9254725202918053, 0.31717031670268625, 0.2722871251171455, 0.18332165287574753, 0.3195933101233095, 0.10732346723671071, 0.15643138642190024], [0.06149143984657712, 0.1600253552896902, 0.03702518355567008, 0.06209669838426635, 0.16911813378101215, 0.040051309260888956, 0.06137922711786814, 0.09430713951587677, 0.08261683673481457, 0.09914818365359679, 1.03704035282135, 48.52651588618755, 65.80177590250969, 40.88508792221546, 47.0444206148386, 29.734981432557106, 91.40911102294922, 91.4163838326931, 6.921250708401203, 34.275585785508156, 60.08792370557785, 62.16472126543522, 62.280740439891815, 56.111870259046555, 65.01115992665291, 24.298947528004646, 0.9656528115738183, 0.19131946668494493, 0.0723707236465998, 0.18244867940666154, 0.16179800470126793, 10.907915085554123, 63.461937457323074, 71.2736114859581, 67.34126329421997, 57.49667935073376, 51.02228656411171, 50.170167088508606, 62.848992347717285, 58.20263586938381, 78.96088778972626, 58.056602105498314, 28.521185964345932, 58.95314879715443, 31.156462356448174, 44.86903354525566, 53.57747085392475, 37.451816350221634, 56.158254370093346, 57.404648289084435, 59.99144308269024, 60.360532477498055, 55.96857614815235, 54.96173657476902, 56.171519458293915, 51.51315562427044, 47.88718119263649, 50.73216073215008, 47.882830426096916, 46.70093044638634, 48.29558327794075, 47.60003820061684, 52.56169036030769, 52.74466574192047, 51.70036017894745, 51.95668302476406, 58.15630495548248, 55.77908791601658, 54.82772536575794, 54.81794849038124, 56.60782724618912, 56.558688282966614, 55.804930329322815, 54.89905893802643, 61.153618320822716, 57.33250916004181, 52.028100192546844, 53.00544574856758, 62.619150280952454, 56.13939978182316, 58.201704919338226, 60.906661972403526, 59.22375127673149, 67.01227694749832, 94.32360783219337, 64.76380079984665, 35.63716672360897, 41.430928632617, 44.799535274505615, 43.802780359983444, 39.18510094285011, 47.62103967368603, 78.84857341647148, 74.37821969389915, 55.13280339539051, 57.47706860303879, 57.070292830467224, 55.46571493148804, 54.31381434202194, 62.86668419837952, 33.950722217559814, 37.349841222167015, 56.02419376373291, 54.909303188323975, 56.11578404903412, 55.487742349505424, 57.79701143503189, 57.6324612647295, 56.03963993489742, 56.98904559016228, 55.67021235823631, 56.993031576275826, 51.12450487911701, 54.13486294448376, 55.77528052031994, 58.594189658761024, 56.32377728819847, 51.19607023894787, 45.620352029800415, 44.0196119248867, 44.900370463728905, 49.79387328028679, 45.706326216459274, 48.60826849937439, 48.243054896593094, 50.86279012262821, 55.26030175387859, 54.602104872465134, 54.484428986907005, 58.66789050400257, 50.93693554401398, 66.99399992823601, 62.195666804909706, 51.176353096961975, 56.528453305363655, 54.54507753252983, 54.08843323588371, 55.968682542443275, 56.57955676317215, 56.97522193193436, 54.68320392072201, 54.0559221804142, 50.8735017478466, 46.73966936767101, 51.021142825484276, 59.581992253661156, 60.42504161596298, 64.22939747571945, 49.64050590991974, 0.6772522057872266, 0.11381711839931086, 0.04407934546179604, 0.05413524981122464, 0.7066060462966561, 29.042120911180973, 65.75837463140488, 53.22912074625492, 50.92353746294975, 56.73906460404396, 34.17660869657993, 6.545009622350335, 45.76181083917618, 21.202529780566692, 36.36024132370949, 43.15871872007847, 28.959482945501804, 38.918028473854065, 60.50629645586014, 27.44008507579565, 0.7544168026652187, 0.1031565603625495, 0.029332622507354245, 0.14207314437953755, 0.21261146088363603, 0.2501693135127425, 0.019373943214304745, 0.04509554601099808, 0.14080711465794593, 0.03097899734711973, 0.06816089095082134, 0.11124592550913803, 0.04723188489151653, 0.037499571772059426, 0.07471134609659202, 0.09308414693805389, 0.06775970075977966, 1.1311141611076891, 53.55270758271217, 74.15625840425491, 43.37840013206005, 37.35834516584873, 42.491653114557266, 75.08799880743027, 99.47650372982025, 11.160993855446577, 37.443088218569756, 65.1161102950573, 64.58351567387581, 68.53482484817505, 58.65818962454796, 67.47281983494759, 27.588286623358727, 1.611276464536786, 1.2087688129395247, 0.1958724536234513, 0.3381935792276636, 0.35404552705585957, 12.569823358207941, 65.41903004050255, 71.11185416579247, 68.86902451515198, 59.91786763072014, 53.074153661727905, 51.28006853163242, 66.54948458075523, 60.738448798656464, 80.22248089313507, 59.85454022884369, 30.254419259727, 58.66751052439213, 34.64565172791481, 46.937938928604126, 56.548998802900314, 40.325431153178215, 60.258428156375885, 59.664596021175385, 63.29104922711849, 62.00356051325798, 59.09247972071171, 55.17288364470005, 55.19768491387367, 50.995672792196274, 49.13228318095207, 51.18123583495617, 51.08136959373951, 50.412415489554405, 52.22922720015049, 51.49268992245197, 54.09967303276062, 56.805834621191025, 55.7610996812582, 55.979409366846085, 60.20095244050026, 58.689142763614655, 56.703806295990944, 56.56206250190735, 58.939074352383614, 59.396330416202545, 57.85495452582836, 57.004761546850204, 64.3323415517807, 59.184541180729866, 56.98084942996502, 57.47478112578392, 63.21743577718735, 54.551461189985275, 61.5928253531456, 65.5994139611721, 60.093433409929276, 71.4285671710968, 103.4026050567627, 67.3108497262001, 38.04165869951248, 47.42839761078358, 48.82593221962452, 42.97847159206867, 41.82362996041775, 44.281509071588516, 69.58213225007057, 71.42504096031189, 56.92807026207447, 58.08517277240753, 60.51572374999523, 57.47516490519047, 59.80955824255943, 64.1960808634758, 37.25370638072491, 37.433330342173576, 60.055367052555084, 56.40380859375, 60.76869137585163, 54.90487642586231, 54.63961645960808, 54.57476153969765, 55.09658753871918, 57.71896742284298, 54.726137816905975, 55.883513912558556, 52.230895310640335, 53.33415850996971, 50.377643555402756, 55.80176889896393, 58.37985835969448, 56.40686362981796, 47.04551875591278, 45.80694101750851, 47.03522890806198, 51.51211068034172, 48.32810193300247, 50.98786421120167, 51.66556164622307, 52.80948266386986, 57.59514346718788, 56.61297596991062, 55.026097521185875, 54.400837272405624, 52.05506354570389, 58.44510845839977, 57.74546340107918, 57.45002165436745, 58.98992322385311, 60.30192822217941, 55.659983307123184, 59.476217329502106, 60.40960684418678, 58.851318061351776, 57.37456150352955, 54.96633052825928, 53.38018923997879, 51.1510768532753, 53.72836075723171, 61.49701729416847, 61.673548221588135, 65.23279443383217, 51.25753954052925, 0.24218364123953506, 0.18801116530084983, 0.09419612164492719, 0.7539970439393073, 0.7827203557826579, 36.09187692403793, 69.6375560760498, 60.59886708855629, 58.23108874261379, 57.75405094027519, 39.87452074885368, 6.989125991240144, 43.83296214044094, 25.92808920890093, 38.42829555273056, 52.42802493274212, 35.78805662691593, 44.57538530230522, 70.29125019907951, 34.582989290356636, 0.4375901893945411, 0.173177384713199, 0.11144987511215732, 0.13950509077403694, 0.22296105162240565, 0.11455338084488176, 0.06759648764273152, 0.19185782060958445, 0.1299003342865035, 0.16623509785858914, 0.2099731852649711, 0.2773037465522066, 0.11606745858443901, 0.16351272206520662, 0.34285771020222455, 0.37464080785866827, 0.324306808761321, 1.9408123567700386, 69.38506722450256, 84.2360383272171, 57.578253373503685, 53.4722924977541, 50.68757012486458, 104.82620626688004, 102.76999220252037, 13.559402357786894, 43.893986865878105, 69.30936008691788, 71.6766482591629, 77.5449849665165, 66.03171676397324, 74.08991396427155, 30.84210902452469, 2.998481090180576, 1.4481321000494063, 0.2199555464903824, 0.4645863454788923, 0.9217420115601271, 16.52637530118227, 69.06086102128029, 74.25857171416283, 71.72257259488106, 64.4924421608448, 56.314270198345184, 54.062761813402176, 72.59645730257034, 64.45493057370186, 88.55523616075516, 59.118656516075134, 29.687843061983585, 59.84172731637955, 36.860978454351425, 61.059238985180855, 55.33853195607662, 41.72990418970585, 61.05751007795334, 62.221383824944496, 64.10558491945267, 65.31705871224403, 59.201123490929604, 57.578629553318024, 57.68706813454628, 52.48944103717804, 51.99983350932598, 52.607705891132355, 57.67625771462917, 52.70780771970749, 55.95239281654358, 52.46844716370106, 55.25184340775013, 57.60683164000511, 60.01417726278305, 56.821106001734734, 62.86947324872017, 62.45484709739685, 62.52583108842373, 63.482064977288246, 62.91862741112709, 65.70708498358727, 61.26496374607086, 59.1728226095438, 65.90450718998909, 69.29193422198296, 53.48672792315483, 61.13457374274731, 69.19319272041321, 59.14399355649948, 62.654275596141815, 68.74725624918938, 64.23129737377167, 61.45233169198036, 85.89442893862724, 82.09442764520645, 53.26610416173935, 58.533373922109604, 53.018270060420036, 48.194459304213524, 52.574210688471794, 69.80525627732277, 77.01402425765991, 64.29748982191086, 54.638009145855904, 64.23181414604187, 66.10128343105316, 64.00370478630066, 58.605672642588615, 73.9410911500454, 33.27346935868263, 38.71049880981445, 66.58140286803246, 56.950223073363304, 67.30406329035759, 59.196339547634125, 58.89342740178108, 58.72912421822548, 62.49033719301224, 60.46894446015358, 59.48575101792812, 57.7649487555027, 55.22811368107796, 57.56487049162388, 53.27088050544262, 54.18509244918823, 58.493886440992355, 61.009176671504974, 50.50809055566788, 49.809433445334435, 49.266666769981384, 55.91391608119011, 50.91977186501026, 54.166272059082985, 53.9280666410923, 58.35132949054241, 59.589135870337486, 60.25551751255989, 61.27754867076874, 62.9788351804018, 54.39038783311844, 58.44897285103798, 60.28478354215622, 59.93775196373463, 61.67796738445759, 61.968294605612755, 57.37199664115906, 63.47134195268154, 62.48008154332638, 62.095747366547585, 61.30604334175587, 59.32474985718727, 55.82685515284538, 52.13097587227821, 57.0215680450201, 63.57818841934204, 65.44837966561317, 67.21376493573189, 55.84566414356232, 1.0404164716601372, 0.42467281222343445, 0.1437063590856269, 4.358052173629403, 1.9309444050304592, 35.42546108365059, 76.10936880111694, 66.07607558369637, 64.25167188048363, 66.91222831606865, 46.84728719294071, 12.82156364992261, 59.832258224487305, 26.862035393714905, 53.56815755367279, 64.44005817174911, 39.78810578584671, 54.89623948931694, 74.83590513467789, 52.721532583236694, 1.7664395947940648, 0.34678583848290145, 0.13699229748453945, 0.17553227866301313, 0.30593256815336645, 0.45941704942379147, 0.23989022680325434], [0.010247798691125354, 0.11263116641202942, 0.018006421087193303, 0.13873518677428365, 0.0451288498879876, 0.14207589032594115, 0.07254142503370531, 0.20366905635455623, 0.281601672177203, 0.3920993866631761, 0.7826856232713908, 29.393558353185654, 60.29809042811394, 52.620226219296455, 39.50296528637409, 38.141965717077255, 24.221640676259995, 33.76119218766689, 6.553799025714397, 21.364097110927105, 80.29034525156021, 59.2060936242342, 58.364632576704025, 52.47153639793396, 61.22446931898594, 37.14331090450287, 0.617825057124719, 0.1004082168219611, 0.00799538049250259, 0.25533385982271284, 0.46593358099926263, 4.881416140124202, 50.81162966787815, 62.57623538374901, 65.62558695673943, 62.48022973537445, 57.35374242067337, 50.73433801531792, 53.606801480054855, 59.29118625819683, 61.67981408536434, 63.71224522590637, 68.57819572091103, 49.75538894534111, 53.7038254737854, 32.431252151727676, 48.342005386948586, 64.6334145963192, 59.05151031911373, 61.628718227148056, 57.00267545878887, 60.30886285007, 59.01459529995918, 56.78544111549854, 60.46277739107609, 55.74272386729717, 50.6411138176918, 52.56762944161892, 45.51025293767452, 48.21486420929432, 51.61947391927242, 50.487499460577965, 52.918753400444984, 54.71700310707092, 53.34025718271732, 55.86831472814083, 50.191989317536354, 53.88792559504509, 51.73884451389313, 53.326479122042656, 56.92664913833141, 58.119982704520226, 54.6713637560606, 55.26251703500748, 53.9070575684309, 60.22315464913845, 52.88548618555069, 62.63878382742405, 58.00992161035538, 63.45002129673958, 60.79313926398754, 56.76039285957813, 59.35155741870403, 60.82701824605465, 62.150183245539665, 95.30741304159164, 63.211378902196884, 52.39116311073303, 52.51132406294346, 49.13321413099766, 64.33432504534721, 72.5254999101162, 71.00074052810669, 59.47722427546978, 57.375450655817986, 56.12347103655338, 54.915538653731346, 57.22674563527107, 52.412422969937325, 58.63894745707512, 64.49988216161728, 60.76318547129631, 58.12121383845806, 51.16979464888573, 52.24603749811649, 55.8862117677927, 56.08856610953808, 57.81161405146122, 56.62119872868061, 52.895232662558556, 53.0303306132555, 54.774140641093254, 52.87798918783665, 52.107018157839775, 57.73754842579365, 52.90921971201897, 53.02422434091568, 50.63215769827366, 46.185757890343666, 37.87669435143471, 43.47245268523693, 50.51407143473625, 46.95850722491741, 49.73644696176052, 47.612269744277, 53.83011169731617, 53.038610368967056, 59.3335235863924, 54.8088213801384, 57.73801200091839, 53.83189000189304, 61.513432413339615, 62.42964304983616, 60.70380225777626, 61.040038615465164, 57.946411818265915, 54.921891912817955, 54.57112893462181, 61.234189197421074, 61.88781872391701, 56.33380874991417, 53.30783352255821, 46.06129936873913, 50.635284930467606, 53.88480216264725, 62.9290996491909, 59.67323675751686, 72.88058325648308, 29.771645665168762, 0.4552450217306614, 0.23874185717431828, 0.1933559644385241, 0.5924601713195443, 1.2837525643408298, 50.71996718645096, 57.626351192593575, 51.79894208908081, 52.25947357714176, 65.44284716248512, 33.20805586874485, 5.972343776375055, 29.20701116323471, 14.854765199124813, 62.57703334093094, 69.61027354001999, 34.315099865198135, 40.1666908711195, 66.18138313293457, 22.497481293976307, 0.5079410097096115, 0.07793408527504653, 0.07222261323477142, 0.10500815944396891, 0.05981372596579604, 0.042855247083934955, 0.03829695007880218, 0.03436846185650211, 0.09846166736679152, 0.09283506733481772, 0.13231482269475237, 0.07032908280962147, 0.10037846412160434, 0.06551588405272923, 0.2058695539017208, 0.13476711610564962, 0.5424056353513151, 0.5907625530380756, 32.9889178276062, 74.28061813116074, 57.22768038511276, 35.56277431547642, 50.72528690099716, 37.03137271106243, 48.26814875006676, 13.83595246821642, 20.427403673529625, 81.49384707212448, 62.68742121756077, 67.59173065423965, 58.32518309354782, 67.17935398221016, 36.38796083629131, 0.39032951288390905, 1.1739150644280016, 0.057960638878284954, 0.3064982034265995, 0.43423672090284526, 5.852745668962598, 53.95194076001644, 62.15069241821766, 67.09230065345764, 63.626282438635826, 60.01199617981911, 52.792706564068794, 56.02775037288666, 63.38806942105293, 66.39762192964554, 66.3153563439846, 73.96550863981247, 51.200793385505676, 55.16882166266441, 35.53054444491863, 48.987408354878426, 66.54877781867981, 59.43147473037243, 62.64482170343399, 58.15138041973114, 62.23576985299587, 63.049230203032494, 61.1034382134676, 60.79141415655613, 58.32272842526436, 50.738050416111946, 55.35747393965721, 50.787785947322845, 52.0037055015564, 55.89174427092075, 52.87929251790047, 54.23083819448948, 56.645213440060616, 54.74469222128391, 57.59852908551693, 55.14093495905399, 57.68107205629349, 55.52048899233341, 52.2725410759449, 57.85868212580681, 61.60229444503784, 57.24974200129509, 55.02417862415314, 56.17967762053013, 62.232737615704536, 52.898979261517525, 61.8148398399353, 64.81239259243011, 63.60235512256622, 58.08159336447716, 57.33894981443882, 67.68011391162872, 55.97741827368736, 64.19735759496689, 103.31827238202095, 62.540680691599846, 50.47925390303135, 54.77809622883797, 55.291061103343964, 57.02254839241505, 65.66052228212357, 67.06792876124382, 59.1745363175869, 58.15627455711365, 60.38956291973591, 53.76752905547619, 57.53997802734375, 55.90675726532936, 65.53309231996536, 61.09840348362923, 62.68385700881481, 61.245630383491516, 53.76068942248821, 55.91102443635464, 57.484071627259254, 59.83715236186981, 55.93092776834965, 54.682345166802406, 54.586894288659096, 54.979910999536514, 53.970981538295746, 53.28210890293121, 50.81145107746124, 58.20340342819691, 50.01441724598408, 51.6863427311182, 52.068283036351204, 49.0752824395895, 41.72431468963623, 45.88550180196762, 51.16225205361843, 49.88725706934929, 51.436156556010246, 50.61592496931553, 54.616399705410004, 54.32906672358513, 58.758739829063416, 57.88921348750591, 54.65098924934864, 55.37622973322868, 52.48120687901974, 54.84635956585407, 62.403751239180565, 60.6956896930933, 60.57674087584019, 56.14926025271416, 56.61791950464249, 61.95428095757961, 63.64382229745388, 58.6583986133337, 56.443721652030945, 48.61920431256294, 52.12474040687084, 57.192258685827255, 65.29692739248276, 60.14772869646549, 74.6285730600357, 30.313181206583977, 1.0717537463642657, 0.07331966335186735, 0.18375810992438346, 1.4735245937481523, 2.21650798805058, 53.67651253938675, 62.19109944999218, 58.75281974673271, 55.427321791648865, 72.15774804353714, 37.7031272649765, 7.431630771607161, 42.75122098624706, 16.17848876863718, 60.54804101586342, 72.12485700845718, 33.97547408938408, 47.32370562851429, 74.84239518642426, 30.917637571692467, 0.3986579831689596, 0.2406464159139432, 0.051764147356152534, 0.05055787165474612, 0.020604726487363223, 0.06333742087008432, 0.0711658617365174, 0.14426947105675936, 0.17238505301065743, 0.21085496060550213, 0.16056412481702864, 0.2823674201499671, 0.22109259094577283, 0.3107375290710479, 0.3437937068520114, 0.28127530531492084, 0.9152850299142301, 0.9890276729129255, 49.43133093416691, 83.09172973036766, 72.57735192775726, 47.38044798374176, 54.68144081532955, 35.8672633767128, 40.76484337449074, 12.807308714836836, 28.556932546198368, 91.60159349441528, 68.06740432977676, 70.6330494582653, 62.03928239643574, 75.47449886798859, 44.50514227151871, 1.799871982075274, 1.0124411853030324, 0.10619164007948712, 1.0351104126311839, 0.6026139389723539, 9.405596349388361, 60.93352273106575, 66.60825982689857, 72.11957529187202, 65.20906090736389, 62.53985233604908, 54.90871421992779, 58.058034628629684, 66.7606620490551, 71.04074478149414, 70.60464978218079, 78.89486253261566, 51.95629544556141, 52.79334492981434, 37.151712253689766, 56.59156411886215, 63.72579149901867, 63.47682125866413, 62.87902593612671, 58.58659766614437, 62.245333939790726, 63.377103209495544, 63.44530574977398, 65.1852285861969, 62.51212142407894, 52.72894598543644, 58.80527213215828, 51.18118643760681, 54.94961142539978, 59.369454458355904, 53.369842395186424, 58.19618001580238, 61.04051738977432, 58.58635447919369, 62.6097571849823, 58.63742753863335, 62.60499224066734, 59.05789777636528, 58.157319501042366, 62.088854536414146, 66.0147088766098, 60.88472954928875, 59.90381978452206, 59.19711850583553, 68.60265880823135, 62.38308034837246, 72.49916732311249, 64.74700570106506, 68.2715293765068, 63.539989069104195, 60.25892212986946, 66.98731228709221, 62.77535989880562, 59.49560388922691, 84.33656573295593, 78.45154792070389, 61.28078229725361, 56.47573113441467, 60.91988526284695, 71.4435763657093, 71.30784764885902, 65.84265410900116, 59.982418566942215, 69.78672847151756, 61.222159042954445, 58.4732573479414, 63.05612303316593, 64.38474833965302, 62.95789450407028, 78.72694954276085, 72.63718351721764, 65.28806626796722, 54.88142028450966, 59.8908206820488, 61.35189928114414, 63.12864974141121, 58.70065614581108, 56.414360627532005, 58.3764461427927, 56.45574800670147, 58.17509114742279, 56.554915085434914, 51.64549112319946, 61.749152764678, 56.88569873571396, 54.09883327782154, 56.1969742923975, 54.00771036744118, 46.29702731966972, 52.30309143662453, 55.170478373765945, 51.569669991731644, 57.69940987229347, 53.38609032332897, 57.989254519343376, 56.20319075882435, 64.82994765043259, 60.57129576802254, 61.83328025043011, 57.02089548110962, 65.01444295048714, 63.1301012635231, 61.40913560986519, 64.98592168092728, 62.05842196941376, 62.240796983242035, 59.803033992648125, 65.94771087169647, 64.6595647931099, 58.06237019598484, 56.97598189115524, 50.29752865433693, 54.88005615770817, 61.15493305027485, 67.90434747934341, 64.62516903877258, 76.6011992096901, 34.58311848342419, 1.546930242329836, 0.2439174911705777, 0.7256981811951846, 3.572413455694914, 2.8444746416062117, 58.81236255168915, 70.88588029146194, 64.56548184156418, 62.565770745277405, 76.471808552742, 48.80748800933361, 11.382083091884851, 43.108181431889534, 19.209776110947132, 86.53198912739754, 94.27640676498413, 45.883662700653076, 56.093965619802475, 84.60654884576797, 40.91140151023865, 0.8353021123912185, 0.436455772141926, 0.1290841499576345, 0.2757515595294535, 0.28063708799891174, 0.10966034926241264, 0.2047924601356499], [0.09315367133240215, 0.055932093237061054, 0.013799674798065098, 0.10067570168757811, 0.031446823122678325, 0.1284123578807339, 0.08357085273019038, 0.16058359877206385, 0.10571049831924029, 0.6932857423089445, 0.5385767470579594, 15.079664681106806, 60.88838115334511, 56.15494854748249, 31.931692957878113, 30.939853079617023, 27.451279275119305, 30.11603258550167, 18.05022083222866, 4.925130419433117, 57.75704137980938, 58.26055236160755, 58.945575803518295, 60.852355286478996, 54.15477767586708, 48.525273352861404, 2.622635420411825, 0.7864437997341156, 0.04440521508513484, 0.4100156034110114, 0.09062259152415209, 2.5415667705237865, 33.55014011263847, 66.56650766730309, 67.24911823868752, 65.45968025922775, 58.60140547156334, 53.60080540180206, 50.904082506895065, 56.438584327697754, 60.417548418045044, 60.31026877462864, 59.546490758657455, 63.10298211872578, 49.9346861243248, 49.3331404030323, 45.05224831402302, 59.37916673719883, 64.54921871423721, 57.10924454033375, 63.849691450595856, 60.33595159649849, 62.72840201854706, 59.21752721071243, 57.22344361245632, 54.264622181653976, 54.56587381660938, 54.30813364684582, 49.833744540810585, 49.45367753505707, 49.55612003803253, 50.88269725441933, 48.81653532385826, 51.41352877020836, 54.25104930996895, 53.20262476801872, 52.675612047314644, 50.22493354976177, 52.27278046309948, 53.74196782708168, 57.26369485259056, 53.65108050405979, 56.80312916636467, 56.15019500255585, 54.40663956105709, 56.11465930938721, 57.76677265763283, 55.99936969578266, 56.403668001294136, 59.18935552239418, 58.82813550531864, 57.11900241672993, 49.8379585146904, 54.88975703716278, 55.39063476026058, 67.75034934282303, 92.96091735363007, 60.7461965829134, 45.50959177315235, 35.113133043050766, 57.99683131277561, 63.40323060750961, 55.76750993728638, 54.435377418994904, 53.7640256434679, 52.82281614840031, 54.098400101065636, 53.20901982486248, 54.50921505689621, 51.84458903968334, 51.16159848868847, 52.62911394238472, 55.184834003448486, 52.299162447452545, 51.67830616235733, 52.60136403143406, 53.59066754579544, 53.45269314944744, 56.02166689932346, 55.43325327336788, 53.3415263146162, 52.75175616145134, 51.802160516381264, 53.9620216190815, 51.849376782774925, 47.51500256359577, 51.1352165043354, 47.305968180298805, 48.253458738327026, 36.20274357497692, 29.11895278841257, 47.12018474936485, 49.84755679965019, 47.55590356886387, 55.578348487615585, 51.26989647746086, 55.78786924481392, 55.151817575097084, 56.66668988764286, 54.019489735364914, 60.25480315089226, 25.297775231301785, 39.330614134669304, 61.68543018400669, 55.2352686971426, 58.93622450530529, 52.07476548850536, 55.069274604320526, 56.33655600249767, 60.23379027843475, 59.16409067809582, 54.78400491178036, 46.50439739227295, 52.83159747719765, 53.865540996193886, 62.453779354691505, 59.501280784606934, 69.59920093417168, 15.607666298747063, 1.5375962806865573, 0.22919078764971346, 0.08927759728976525, 1.1979279946535826, 4.514501178637147, 59.42469209432602, 53.26821304857731, 49.49479132890701, 45.99992886185646, 70.31967267394066, 11.402842327952385, 7.3735679872334, 34.769430086016655, 22.439561001956463, 65.94647213816643, 69.57713931798935, 42.94323988258839, 41.04042358696461, 67.20333829522133, 18.16358394920826, 0.39725193986669183, 0.35551907611079514, 0.1040239974099677, 0.0658915592066478, 0.05948742960754316, 0.05456245969980955, 0.08697121011209674, 0.07146529605961405, 0.08086991016170941, 0.019347379893588368, 0.11462126509286463, 0.06435074188630097, 0.05741677450714633, 0.03173548888298683, 0.057147089173668064, 0.05738903673773166, 0.7405528903473169, 0.5072898790240288, 18.908558674156666, 71.15803688764572, 61.86327964067459, 25.407857224345207, 33.48485581576824, 33.57240691781044, 19.047921895980835, 16.69181652367115, 6.142838727682829, 61.79064653813839, 61.1976807564497, 67.43856847286224, 68.45907211303711, 60.692357271909714, 54.78819228708744, 2.636199980042875, 1.0779753187671304, 0.035325810094946064, 0.7102324173320085, 0.8594773651566356, 3.173404228873551, 37.39088661968708, 66.87987685203552, 69.97160375118256, 66.75650507211685, 61.870810836553574, 55.289442390203476, 57.19353161752224, 58.74017022550106, 61.273197904229164, 61.50190383195877, 61.82716257870197, 62.8100710362196, 50.017810463905334, 48.140540197491646, 47.49519422650337, 59.80659060180187, 62.84063659608364, 59.694876596331596, 64.64109778404236, 63.426154777407646, 61.985188499093056, 61.93544536828995, 59.92381811141968, 57.509309872984886, 55.389908999204636, 54.37317095696926, 54.29035060107708, 53.73140059411526, 51.357306987047195, 52.82223857939243, 54.23004023730755, 54.85387176275253, 58.24238933622837, 54.59663316607475, 55.538610219955444, 55.10012894868851, 54.76216368377209, 54.39589373767376, 55.76138086616993, 56.82632312178612, 56.54896840453148, 59.648853465914726, 58.239288702607155, 57.9397089779377, 59.81459677219391, 62.193804904818535, 57.816891968250275, 61.57889150083065, 59.30450454354286, 57.38418258726597, 56.977004036307335, 62.30937570333481, 55.76353535056114, 68.96624609827995, 97.9912394285202, 55.4439003020525, 51.106824427843094, 45.317614674568176, 56.8115609139204, 56.12320885062218, 60.86754307150841, 62.23263882100582, 58.80413219332695, 54.546084478497505, 56.738905012607574, 55.46533115208149, 56.933416575193405, 54.72141087055206, 59.2327643930912, 58.40547278523445, 57.00047917664051, 55.62362685799599, 53.02846871316433, 56.4599733799696, 56.428381875157356, 55.00248558819294, 57.14903600513935, 55.3596056252718, 54.57665763795376, 52.044435515999794, 52.249392718076706, 51.56032629311085, 52.34831281006336, 49.490539357066154, 53.7613657861948, 49.404865354299545, 50.64230315387249, 40.15885569155216, 32.46017999947071, 50.6063798815012, 50.9861771017313, 50.37822872400284, 53.78797195851803, 55.08081458508968, 54.38096433877945, 55.70526547729969, 58.44705395400524, 55.667753890156746, 62.88088783621788, 27.272821851074696, 37.484376803040504, 64.27569419145584, 55.50999015569687, 61.697456538677216, 54.14456382393837, 58.41209962964058, 55.596785098314285, 62.918802201747894, 59.83896866440773, 57.879379615187645, 49.7768197953701, 54.56217281520367, 57.35095717012882, 63.46542946994305, 63.54116700589657, 69.60480943322182, 17.74912878870964, 1.9537034025415778, 0.16901599941775203, 0.3019927436253056, 0.34756835899315774, 6.545310281217098, 64.14972335100174, 61.03523187339306, 49.80817951261997, 53.88212330639362, 70.97729578614235, 13.838333990424871, 10.95995994284749, 44.90980915725231, 19.85033243894577, 70.20431086421013, 77.83969715237617, 38.072129264473915, 46.564779952168465, 77.24133566021919, 19.717584662139416, 0.14647531206719577, 0.21402125945314765, 0.19619957747636363, 0.12469692912418395, 0.08172139845555648, 0.07962204079376534, 0.037335501474444754, 0.17346673324937, 0.23962220759131014, 0.11558282130863518, 0.2052827228908427, 0.176496907370165, 0.1959264968172647, 0.2656634571030736, 0.38384189538192004, 0.21632452961057425, 1.1543389898724854, 0.6103771599009633, 26.008339002728462, 85.26003777980804, 72.91228115558624, 43.500609174370766, 46.169498562812805, 43.14944341778755, 32.9346339404583, 26.734770722687244, 9.132533501833677, 69.79923740029335, 67.05894604325294, 69.50055822730064, 71.02701231837273, 68.1470176577568, 58.53549040853977, 4.090911783277988, 2.5222913548350334, 0.2409065089887008, 1.1889548948965967, 1.5675864089280367, 4.7854128666222095, 41.30190655589104, 65.51242902874947, 74.774599224329, 71.1297208070755, 64.47447672486305, 59.24863614141941, 58.8058876991272, 59.97495196759701, 67.64889478683472, 63.470240011811256, 65.03032609820366, 64.22253504395485, 50.05596041679382, 48.615339919924736, 51.7532267421484, 64.31245341897011, 68.4359085559845, 61.117182075977325, 67.5831963121891, 60.57924494147301, 65.0235928595066, 62.993004620075226, 63.48729729652405, 59.472254142165184, 59.398348107934, 56.25250071287155, 56.590674966573715, 56.24659202992916, 53.83454225957394, 55.85034169256687, 57.839040979743004, 60.45018866658211, 61.9674738496542, 56.9255205988884, 60.77668994665146, 56.002382934093475, 60.640854835510254, 58.200143203139305, 63.20447847247124, 60.66330403089523, 61.50924123823643, 64.49950218200684, 61.52623772621155, 64.60951387882233, 63.67005608975887, 64.25324499607086, 64.43137183785439, 62.6779293268919, 62.36385717988014, 63.61714392900467, 60.7157564163208, 61.977117732167244, 61.49796724319458, 63.42862844467163, 86.41769126057625, 70.74347153306007, 56.56663365662098, 43.69354002177715, 61.704478561878204, 66.5625710785389, 62.3225723952055, 71.26629307866096, 62.89226822555065, 59.99167487025261, 60.408383309841156, 60.932454988360405, 59.087555184960365, 58.886131793260574, 55.20873852074146, 62.572690173983574, 62.93183170258999, 60.825608521699905, 58.77556152641773, 58.19971762597561, 58.96728403866291, 58.553201258182526, 57.60080896317959, 58.40202257037163, 56.813817992806435, 53.72901812195778, 52.383935898542404, 54.51253987848759, 55.46676367521286, 50.53736798465252, 57.312970608472824, 50.050602704286575, 56.321653202176094, 41.73244245350361, 34.28682558238506, 53.124626353383064, 52.649245262145996, 52.628673166036606, 61.467838659882545, 59.30690601468086, 57.896007522940636, 59.43193070590496, 59.28363226354122, 59.733668714761734, 64.5362614095211, 39.300405755639076, 47.971548065543175, 67.71459326148033, 59.98380549252033, 62.40937493741512, 56.13499961793423, 62.118713334202766, 58.580616787075996, 63.59094053506851, 62.48253621160984, 57.95134395360947, 52.91282191872597, 56.39916904270649, 57.39293731749058, 67.69631624221802, 65.26350438594818, 73.33745554089546, 25.405660942196846, 3.419713662005961, 0.2654957910999656, 0.3728088311618194, 2.0719176717102528, 7.031720755621791, 69.37803000211716, 65.70680379867554, 57.62936443090439, 58.778445571660995, 81.91299498081207, 22.766423262655735, 13.656529895961285, 50.66090315580368, 24.327246509492397, 91.07488095760345, 83.2685874402523, 56.72187052667141, 56.53390981256962, 89.75941434502602, 31.51466343551874, 0.5862876400351524, 0.38938407611567527, 0.3873168386053294, 0.23185968428151682, 0.29680614068638533, 0.22197834419785067, 0.09461188019486144], [0.058028552812174894, 0.08934183759265579, 0.012950313684996217, 0.04125885774556082, 0.10227034697891213, 0.04260198547854088, 0.058866203762590885, 0.07308159722015262, 0.10319412045646459, 0.3605978301493451, 0.3712520725093782, 7.227216465398669, 58.12356971204281, 53.4797552973032, 49.03264872729778, 43.168970569968224, 31.63238301873207, 56.08116030693054, 51.506171599030495, 10.816563237458467, 29.97119765728712, 72.11867853999138, 45.25732710957527, 55.83919309079647, 51.99584372341633, 57.74743929505348, 3.8721397100016475, 1.2194805569015443, 0.03793200266954955, 0.11897488147951663, 0.42237257002852857, 1.0822218284010887, 26.596513241529465, 61.224860697984695, 61.820828318595886, 66.21634885668755, 63.79355326294899, 58.27572874724865, 54.709065333008766, 51.67081296443939, 54.953430220484734, 66.86029270291328, 66.53636008501053, 61.14366665482521, 59.41529519855976, 49.19564478099346, 51.70806996524334, 53.631876334548, 59.47280131280422, 62.9002819955349, 59.404450580477715, 62.791642025113106, 60.15677981078625, 60.120864138007164, 58.68537336587906, 56.790399849414825, 51.52510978281498, 52.03667253255844, 55.00447668135166, 47.70126476883888, 52.11881272494793, 50.17472684383392, 47.51041240990162, 50.786577612161636, 51.00460611283779, 52.727578058838844, 54.459213539958, 51.53220020234585, 50.26630952954292, 53.115845024585724, 52.53047123551369, 52.96231046319008, 54.04335245490074, 55.79613380134106, 51.778803169727325, 56.59892052412033, 55.86227685213089, 55.85281156003475, 57.99488961696625, 55.58964528143406, 58.134011551737785, 54.52928178012371, 55.95270060002804, 52.41424307227135, 56.591738909482956, 56.814186573028564, 70.05240261554718, 78.77848237752914, 50.515849739313126, 42.10169903934002, 54.673742428421974, 55.939123928546906, 52.7283950150013, 53.74402351677418, 51.81215398013592, 49.87376019358635, 53.37833873927593, 55.97080282866955, 52.0514727383852, 55.61646044254303, 58.18198777735233, 56.33560225367546, 52.16139703989029, 49.60254594683647, 50.39521761238575, 52.2077127546072, 52.008687034249306, 54.47058252990246, 52.01059453189373, 52.53113619983196, 54.775675758719444, 53.001281172037125, 50.77018529176712, 53.176892548799515, 50.879908204078674, 50.141748413443565, 47.44615785777569, 45.7301889359951, 49.08554568886757, 47.583075910806656, 22.701125666499138, 36.899052411317825, 54.488802552223206, 51.73122972249985, 55.55972948670387, 52.89308577775955, 57.22443915903568, 57.28082813322544, 59.42400433123112, 55.45442193746567, 58.57986442744732, 35.02143256366253, 32.3693610727787, 67.66802296042442, 57.301138043403625, 59.10688854753971, 51.5378163009882, 57.231635972857475, 56.8297353386879, 60.37877909839153, 57.49070607125759, 55.76850928366184, 48.32300640642643, 53.94211068749428, 58.12686413526535, 63.82750064134598, 60.34257844090462, 56.25833339989185, 7.442334797233343, 0.5779913195874542, 0.01819066295865923, 0.14311730163171887, 0.9605669032316655, 7.466425504535437, 63.12002420425415, 50.4586286097765, 64.2068038880825, 58.52427341043949, 53.67662653326988, 8.900582548230886, 18.60235970467329, 30.543211363255978, 22.529025301337242, 45.38776271045208, 32.17083312571049, 32.31418423354626, 47.32418440282345, 54.156392589211464, 3.686412088572979, 0.05184254412597511, 0.09722023984068073, 0.022325561003526673, 0.1658946301904507, 0.0982168922200799, 0.07964414937305264, 0.037012919565313496, 0.10620500615914352, 0.01655085798120126, 0.04713638161774725, 0.13652418041601777, 0.1226252164633479, 0.08104440392344259, 0.06940617764485069, 0.043983563882648014, 0.17218311462784186, 0.4208065790589899, 0.16877845278941095, 7.310401126742363, 64.92571011185646, 67.21896305680275, 44.56652797758579, 50.62765493988991, 38.98814611136913, 43.47580410540104, 53.48873421549797, 11.568971313536167, 38.65967653691769, 73.61811608076096, 51.03235602378845, 63.95475581288338, 57.49275416135788, 63.14599961042404, 5.090752607211471, 0.8187249081674963, 0.28271115326788276, 0.35005155543331057, 1.105210951063782, 0.8346206427086145, 29.778508096933365, 63.54851581156254, 64.32936251163483, 65.68874716758728, 68.07235926389694, 58.821535259485245, 57.12194345891476, 53.597453981637955, 59.197977259755135, 68.69950041174889, 69.72809001803398, 63.0173347145319, 61.9919141381979, 49.682341665029526, 54.844269677996635, 56.62833094596863, 62.10778132081032, 64.35512512922287, 61.38917528092861, 65.42538329958916, 63.626331835985184, 62.02090658247471, 60.67032225430012, 60.02640500664711, 53.97127032279968, 54.7809536755085, 58.386386409401894, 51.83360382914543, 53.49132567644119, 52.82419927418232, 52.90513873100281, 52.94907957315445, 53.16383644938469, 55.48411354422569, 56.43155850470066, 57.01166197657585, 52.1827594935894, 56.43875911831856, 54.68126602470875, 53.680950701236725, 54.7623460739851, 59.08048756420612, 56.06118097901344, 58.26079934835434, 56.2960197776556, 58.67857173085213, 60.69497533142567, 59.6422304213047, 58.49044382572174, 57.294758185744286, 59.90255065262318, 55.62007784843445, 59.8912538588047, 55.302004516124725, 67.64222234487534, 78.55576112866402, 53.60810860991478, 43.81548307836056, 55.64676381647587, 60.6329170614481, 55.156289935112, 60.04227675497532, 56.22583754360676, 55.25445766746998, 55.32305918633938, 56.92178539931774, 56.62536330521107, 56.611444652080536, 58.46920296549797, 59.40096616744995, 55.46093478798866, 55.34847982227802, 54.43129263818264, 53.301240876317024, 54.831183180212975, 56.015442833304405, 54.427618235349655, 55.02176195383072, 53.96448768675327, 51.50338254868984, 51.80687986314297, 53.445826917886734, 52.63004869222641, 50.052198618650436, 49.998397305607796, 48.12199339270592, 50.786277428269386, 53.08569744229317, 27.596382088959217, 37.13009141385555, 55.789271369576454, 52.388909831643105, 57.830244451761246, 56.528711691498756, 55.67593105137348, 54.353142231702805, 59.543678909540176, 56.02660283446312, 62.16766610741615, 37.3399655520916, 35.04863530397415, 66.2433198094368, 56.367034167051315, 62.25246615707874, 53.26274514198303, 59.94188234210014, 58.503439128398895, 63.69071178138256, 59.677644520998, 58.45572508871555, 51.334299221634865, 57.86386124789715, 58.77471797168255, 66.1296983063221, 65.23018777370453, 60.96894823014736, 10.373982936143875, 0.9173688024748117, 0.5500118772033602, 0.2602885861415416, 0.4404217499541119, 10.128959733992815, 67.00209349393845, 56.77105128765106, 67.08457946777344, 63.329366371035576, 57.65715233981609, 12.925273384898901, 18.576013818383217, 38.75558719038963, 20.080210603773594, 48.59958216547966, 48.43329928815365, 31.174967363476753, 55.86643382906914, 63.271560072898865, 5.877935942262411, 0.08963002095697448, 0.11109084633062594, 0.08193929301341996, 0.09908317151712254, 0.055225405376404524, 0.11409036233089864, 0.025516076129861176, 0.2697669103508815, 0.23782285570632666, 0.13813380966894329, 0.15399123454699293, 0.2561999164754525, 0.2260031149489805, 0.1512583054136485, 0.13255844009108841, 0.2516289398772642, 0.4943582823034376, 0.5277932819444686, 11.543889809399843, 81.05700731277466, 73.49063292145729, 63.00941973924637, 56.27855211496353, 58.423784002661705, 58.92887569963932, 65.04493251442909, 14.730794951319695, 42.90825515985489, 82.3241177201271, 56.67191840708256, 67.2457668185234, 62.278209775686264, 69.02696684002876, 6.221753368154168, 4.4992939196527, 0.4433629405684769, 0.941153863677755, 2.2164172679185867, 1.196227348409593, 34.28144507110119, 67.12267622351646, 67.5059312582016, 70.29028505086899, 73.67259755730629, 61.42273128032684, 61.22845910489559, 55.31171679496765, 60.06982147693634, 70.00264048576355, 71.43938139081001, 65.83330661058426, 63.24579745531082, 48.06647077202797, 55.25652475655079, 56.6885045170784, 63.93113628029823, 69.79176700115204, 63.932534605264664, 66.10095664858818, 64.57663804292679, 65.51873669028282, 63.36696915328503, 61.504145711660385, 57.0050161331892, 58.21022406220436, 63.06958571076393, 54.55624893307686, 55.977729856967926, 55.61587907373905, 55.45687660574913, 57.2160492092371, 56.48033648729324, 58.295457288622856, 60.72325341403484, 60.37169247865677, 55.92917986214161, 59.93899829685688, 60.193892419338226, 58.40161979198456, 60.09566009044647, 63.66121016442776, 60.40757395327091, 62.507193088531494, 60.16227051615715, 63.53307344019413, 63.61484885215759, 63.871266692876816, 62.00491324067116, 59.79823864996433, 65.40799543261528, 61.83282807469368, 62.36000798642635, 63.891101628541946, 61.92338481545448, 80.88397979736328, 61.31547823548317, 49.485763013362885, 66.78143173456192, 64.53119248151779, 59.49075534939766, 64.00349959731102, 61.69123627245426, 59.88631032407284, 58.3626376837492, 60.800465270876884, 60.374656319618225, 62.24159874022007, 72.24324345588684, 66.56537532806396, 58.86098854243755, 60.07216975092888, 56.06228671967983, 56.30223624408245, 54.441312700510025, 60.37812553346157, 54.381758496165276, 56.538598760962486, 57.156346812844276, 54.763337820768356, 53.94771158695221, 58.062142208218575, 54.30179938673973, 52.12575115263462, 54.672670885920525, 50.085272043943405, 53.28081697225571, 54.276720732450485, 25.666140764951706, 39.54157881438732, 60.25120094418526, 55.87684907019138, 59.87812936306, 58.1772418320179, 59.67722274363041, 60.313095822930336, 61.365099772810936, 58.37053745985031, 62.772707641124725, 40.827912390232086, 36.94736301898956, 69.53117698431015, 60.26275992393494, 63.54847401380539, 54.09149207174778, 62.47700750827789, 59.61663879454136, 63.52668218314648, 61.72813229262829, 60.9447131305933, 53.31169031560421, 61.956496238708496, 60.238129645586014, 68.58824998140335, 63.25978450477123, 64.41059455275536, 13.595150839537382, 1.9472219003364444, 0.645574196241796, 0.4167289228644222, 3.762113763950765, 9.930052757263184, 75.2447859942913, 60.87481588125229, 72.9132767021656, 67.6132071018219, 64.62130084633827, 17.20116399228573, 26.849625259637833, 45.37395045161247, 27.55034565925598, 63.71015153825283, 48.925331085920334, 42.415178418159485, 61.20493836700916, 77.4458558857441, 10.332107283174992, 0.33213658549357206, 0.44035228493157774, 0.24558061442803591, 0.3493160870857537, 0.19025166460778564, 0.27830128208734095, 0.15666507388232276], [0.05671554885338992, 0.030760919107706286, 0.09098943512071855, 0.040281452966155484, 0.049703919430612586, 0.05382121373258997, 0.058338295566500165, 0.10066480695968494, 0.017650743102421984, 0.1956249919021502, 0.22862544923555106, 1.8067175522446632, 43.161975145339966, 57.00440816581249, 40.66304303705692, 31.426253579556942, 29.033856354653835, 38.50409768521786, 39.18640427291393, 18.356917575001717, 44.05861683189869, 64.34012353420258, 59.08144511282444, 51.056275740265846, 55.48358157277107, 60.76278269290924, 10.658316928893328, 0.3479489916935563, 0.8610442467033863, 0.04070328599482309, 0.19474287517368793, 0.1710196942440234, 21.41804851591587, 53.96903984248638, 64.48727443814278, 64.79369759559631, 63.335119262337685, 57.62052230536938, 55.07862210273743, 50.245995819568634, 56.13656133413315, 56.93515308201313, 60.915021523833275, 58.41006673872471, 67.43623539805412, 49.50758144259453, 43.52604500949383, 56.65261544287205, 57.55221717059612, 64.23298448324203, 61.157870292663574, 60.79278968274593, 61.0528439283371, 62.07545265555382, 59.02977168560028, 57.91760556399822, 52.80997283756733, 52.6518215239048, 51.002972200512886, 50.0321850925684, 50.817078575491905, 50.37448972463608, 48.527967408299446, 49.24610987305641, 50.75821973383427, 52.7365417778492, 51.27227135002613, 50.839759558439255, 51.08104661107063, 51.35915748775005, 52.56626531481743, 50.94618804752827, 52.797167524695396, 51.87281012535095, 54.738426357507706, 50.46522505581379, 52.711413726210594, 51.12056449055672, 53.65142248570919, 53.58582280576229, 51.42302066087723, 53.639342933893204, 52.685730904340744, 53.4290774166584, 52.18600831925869, 51.86758540570736, 57.942372635006905, 68.71227532625198, 45.696070566773415, 43.40716078877449, 51.10119313001633, 51.23387821018696, 51.61485716700554, 49.97523754835129, 49.14719358086586, 50.921713560819626, 51.667256355285645, 49.19239595532417, 51.94682255387306, 51.31446808576584, 48.54676879942417, 47.505753859877586, 48.8157943636179, 49.80236202478409, 49.20505307614803, 50.79721324145794, 51.85873568058014, 53.93787771463394, 54.0916782617569, 52.365962862968445, 51.759302616119385, 53.2824432849884, 51.293892189860344, 51.04711063206196, 49.03513379395008, 50.85337042808533, 46.34675905108452, 48.039085641503334, 49.771796464920044, 55.086339488625526, 29.243988879024982, 24.346167594194412, 52.034206464886665, 51.89901351928711, 55.571805238723755, 54.67446058988571, 59.443827867507935, 56.866247579455376, 59.11878950893879, 59.89510305225849, 62.093611881136894, 52.989292815327644, 47.16980628669262, 52.431193962693214, 56.127460822463036, 53.90085630118847, 57.65687495470047, 54.15689796209335, 57.78824910521507, 62.00373910367489, 58.77516254782677, 55.5529810488224, 51.67186550796032, 54.427679032087326, 58.22768032550812, 63.11888046562672, 62.635538801550865, 46.40117593109608, 5.67669921554625, 0.8294506638776511, 0.44188556203152984, 0.2577182912500575, 0.4187045793514699, 25.688597559928894, 62.87579610943794, 52.99297861754894, 63.32742087543011, 48.56760308146477, 58.583462834358215, 15.42756736278534, 15.067081656306982, 30.44800367206335, 30.59053212404251, 61.64237469434738, 21.53425768017769, 25.364334359765053, 51.59226357936859, 41.620679050683975, 1.152412137016654, 0.07961847848491743, 0.0556042420794256, 0.05880105061805807, 0.1166630098305177, 0.0899626589671243, 0.014510545588564128, 0.027960076040471904, 0.11839162762043998, 0.013303434971021488, 0.15729018487036228, 0.08059553816565312, 0.004457400636965758, 0.05827896828122903, 0.07644768222235143, 0.12774098140653223, 0.03278279284131713, 0.02870045183954062, 0.0947336814715527, 1.652781399898231, 48.09593439102173, 71.38389676809311, 39.72976751625538, 37.97010473906994, 39.29872244596481, 39.300884529948235, 48.18647973239422, 19.23426389694214, 49.22419644892216, 70.82240849733353, 61.073739007115364, 51.89296044409275, 61.74571394920349, 65.2242448925972, 11.481186524033546, 0.5739816441200674, 2.435037111863494, 0.22806086781201884, 0.7990240340586752, 0.12158470315625891, 24.1444269195199, 55.15206836163998, 66.6242341697216, 68.60851049423218, 65.44774129986763, 60.277738720178604, 58.059337958693504, 53.19035142660141, 58.94927300512791, 56.86483785510063, 62.65817418694496, 62.227771282196045, 68.86524751782417, 51.46503120660782, 47.921307161450386, 57.281740084290504, 58.980948105454445, 62.75320328772068, 61.70443296432495, 62.07388713955879, 61.652641743421555, 63.70090663433075, 59.50967073440552, 60.575916320085526, 56.16879120469093, 55.173658803105354, 54.28134508430958, 52.83573925495148, 52.702590599656105, 52.5264510512352, 52.7875692397356, 52.165227234363556, 52.69653372466564, 57.954566180706024, 56.92996256053448, 53.67791846394539, 53.29510800540447, 56.846583634614944, 53.684963285923004, 55.41925102472305, 55.742305889725685, 53.34509812295437, 56.1520417034626, 52.8353326767683, 57.21465088427067, 57.811104878783226, 58.29291142523289, 58.608640283346176, 54.68269854784012, 56.15378201007843, 54.21161122620106, 57.30901502072811, 57.415926083922386, 54.913950338959694, 58.808011785149574, 64.02908742427826, 48.20749640464783, 45.29983922839165, 57.14017108082771, 56.54382728040218, 56.17865927517414, 55.20964287221432, 56.24142050743103, 53.94702382385731, 56.67613998055458, 53.6580341309309, 56.62723280489445, 53.92017066478729, 54.66458112001419, 53.744783475995064, 54.577144011855125, 53.9374977350235, 52.063335701823235, 53.23835805058479, 54.08004328608513, 54.80039343237877, 56.28194913268089, 53.17245438694954, 53.93111787736416, 53.8279078155756, 51.841119825839996, 51.10224947333336, 51.890133395791054, 52.518756464123726, 47.01800063252449, 49.03468921780586, 49.35155801475048, 58.68847779929638, 38.249621540308, 27.081853598356247, 51.47296518087387, 53.43844771385193, 56.77911065518856, 56.079404801130295, 60.29704548418522, 56.2720962613821, 58.31464625895023, 60.30648037791252, 63.57387185096741, 55.81166736781597, 46.474090218544006, 55.88483244180679, 58.72256577014923, 56.35515600442886, 59.08096633851528, 55.87683767080307, 57.87234239280224, 63.38973753154278, 59.696282520890236, 57.134478986263275, 55.25750510394573, 57.45069041848183, 61.24434605240822, 64.76947009563446, 66.6381186246872, 50.26384346187115, 7.409423338249326, 0.4273598617874086, 0.922221913933754, 0.16158015467226505, 0.5818845669273287, 31.857598833739758, 69.2238798737526, 59.200352132320404, 68.26030477881432, 55.04178307950497, 63.71717356145382, 17.41074364632368, 18.387264646589756, 37.828284949064255, 21.367868408560753, 73.04467365145683, 28.618474043905735, 28.151270113885403, 60.22143334150314, 49.151795133948326, 2.249325164593756, 0.12114641300286166, 0.05446460752864368, 0.10166525913518853, 0.001478792676152807, 0.03796310236793943, 0.019307088696223218, 0.10599842935334891, 0.2802603441523388, 0.18255820556078106, 0.19178074115188792, 0.17032994219334796, 0.1676674428745173, 0.19114132155664265, 0.2048775547882542, 0.28474315360654145, 0.15050456539029256, 0.37760221457574517, 0.2595814678352326, 2.593717072159052, 64.52226296067238, 80.52317395806313, 54.600467160344124, 39.99032333493233, 47.30498023331165, 48.798915669322014, 50.028624683618546, 25.986036099493504, 58.20059917867184, 74.27934899926186, 67.96700611710548, 59.488220885396004, 66.47461339831352, 72.46398881077766, 13.197101298719645, 1.0350479534827173, 3.727644388563931, 0.6826422759331763, 1.5706910798326135, 0.2888798253843561, 30.79395990818739, 56.441673561930656, 67.59412452578545, 70.77233478426933, 69.18052420020103, 62.168293073773384, 61.03300899267197, 54.00054395198822, 63.128642141819, 59.231772646307945, 64.82655823230743, 63.8703927397728, 71.46267414093018, 51.993062272667885, 48.78704510629177, 61.04798398911953, 61.710360646247864, 66.54008388519287, 65.77756360173225, 64.66870710253716, 64.32541072368622, 64.07093837857246, 63.078173249959946, 62.15537756681442, 57.9274470359087, 59.450405314564705, 55.734117329120636, 56.2012604624033, 55.92462010681629, 55.30017301440239, 55.060322284698486, 54.5572254806757, 54.774003848433495, 60.45047365128994, 58.290053978562355, 58.213279098272324, 57.06878811120987, 57.77831643819809, 56.93551406264305, 58.307658433914185, 60.40407054126263, 57.475221902132034, 61.3482628762722, 56.91531054675579, 57.21081309020519, 60.31286023557186, 59.8043867200613, 59.41748008131981, 56.45636357367039, 59.44316290318966, 58.30189414322376, 62.587209194898605, 60.697099417448044, 59.49059955775738, 64.2138335108757, 69.21269327402115, 54.32706043124199, 51.780114099383354, 62.492495477199554, 62.54628539085388, 59.33261923491955, 59.977839812636375, 59.11208286881447, 59.340754598379135, 58.692554980516434, 57.086723148822784, 58.833816200494766, 58.128034472465515, 54.47158947587013, 57.36319251358509, 58.06008271872997, 59.80010434985161, 55.551438331604004, 56.83942101895809, 56.20578221976757, 60.00414580106735, 57.44505152106285, 55.95184564590454, 53.4501700848341, 58.52637469768524, 52.459183260798454, 55.81385225057602, 52.0698257535696, 54.518395364284515, 49.46530491113663, 52.74394378066063, 53.63164834678173, 63.075376600027084, 30.248094499111176, 25.341176502406597, 56.81459695100784, 55.16422390937805, 59.996037036180496, 57.13339224457741, 63.83884683251381, 58.90869498252869, 62.18403562903404, 60.80630175769329, 65.84658309817314, 57.92866677045822, 46.21449574828148, 59.75986070930958, 59.67802070081234, 58.84526498615742, 60.146068185567856, 58.85698735713959, 60.95472179353237, 66.45740032196045, 61.150008514523506, 61.8709172308445, 57.874629870057106, 61.40398308634758, 60.8900036662817, 66.83718994259834, 67.30368331074715, 57.126537412405014, 10.034154821187258, 2.509258291684091, 1.96298036724329, 0.7479541806969792, 2.139718383550644, 33.13401684165001, 77.21368074417114, 64.41793575882912, 75.99398419260979, 58.70766296982765, 67.59915545582771, 24.144464917480946, 23.641907684504986, 41.04279465973377, 33.70978854596615, 94.41344261169434, 33.94341140985489, 37.81370893120766, 66.19535878300667, 65.172970443964, 3.661793447099626, 0.1714815475861542, 0.15816274273674935, 0.15678494557505473, 0.2147994309780188, 0.18692102457862347, 0.2270592949935235, 0.13861777901183814], [0.07688553450861946, 0.04164357225818094, 0.008610802742623491, 0.048807167549966834, 0.049690742598613724, 0.04555403742415365, 0.0667530664941296, 0.16766784363426268, 0.07250800612382591, 0.02451514155836776, 0.28004728839732707, 0.41159988089930266, 22.122331224381924, 65.33796519041061, 45.446412563323975, 25.96362490206957, 33.301599249243736, 36.33879907429218, 40.42417645454407, 4.929908663034439, 27.474245242774487, 60.624717101454735, 67.22670704126358, 67.01276332139969, 51.99475698173046, 64.81173142790794, 23.391143940389156, 0.3153192816535011, 0.9933672775514424, 0.25444096710998565, 0.31296982022468, 0.18216828117147088, 16.21472742408514, 55.073484778404236, 64.31097909808159, 61.60776235163212, 62.25743629038334, 59.82330210506916, 56.92849583923817, 53.68942804634571, 56.01651057600975, 54.199945852160454, 65.89094191789627, 61.0602231323719, 63.47162313759327, 59.24386739730835, 50.77431946992874, 55.52557311952114, 59.60846923291683, 60.440814569592476, 58.69901463389397, 62.86250442266464, 61.04755841195583, 63.212271854281425, 61.237897798419, 57.0240493118763, 58.80581550300121, 56.51600897312164, 53.043025732040405, 48.98837350308895, 49.381188824772835, 48.82998660206795, 50.499529615044594, 48.98679278790951, 52.043432369828224, 51.0717599093914, 51.889852210879326, 47.10117056965828, 49.581985250115395, 52.21110977232456, 52.96355679631233, 50.49457848072052, 54.41019617021084, 54.18632738292217, 53.46280440688133, 51.48714601993561, 51.82228043675423, 50.65003573894501, 52.06677071750164, 48.97568978369236, 51.28000393509865, 49.684587344527245, 48.959726840257645, 51.75557121634483, 50.83303391933441, 52.19786748290062, 52.46716283261776, 62.58193887770176, 49.304166957736015, 44.25100050866604, 52.43274047970772, 49.86039251089096, 49.561405554413795, 49.93798054754734, 48.305876925587654, 47.38885313272476, 45.702750608325005, 47.65158623456955, 45.60406230390072, 49.21434357762337, 52.1055818349123, 49.213431626558304, 47.17483341693878, 45.50493322312832, 47.28873610496521, 51.21288053691387, 50.922629311680794, 50.00009201467037, 52.33520731329918, 50.10937415063381, 51.03862568736076, 49.8326425999403, 51.688858196139336, 52.48939163982868, 50.46316556632519, 49.75513055920601, 47.20126859843731, 50.29742605984211, 49.96786214411259, 53.868960812687874, 44.24487143754959, 18.928142823278904, 46.254496201872826, 56.119355857372284, 58.0986924469471, 57.21537284553051, 59.200884103775024, 57.54045680165291, 57.01365306973457, 55.11608809232712, 49.411974772810936, 48.30815680325031, 40.27739033102989, 86.19241654872894, 85.6343100965023, 54.054322466254234, 58.28739412128925, 53.21608364582062, 56.532131507992744, 59.404252991080284, 57.86183975636959, 52.82331772148609, 55.6986728310585, 54.34109687805176, 61.79720118641853, 60.1395895332098, 68.24727907776833, 34.26296666264534, 3.276154277846217, 0.5040525121148676, 0.4586643335642293, 0.06649859147728421, 1.169559310656041, 49.57131542265415, 53.672427758574486, 52.796574756503105, 61.94805309176445, 55.313692688941956, 62.233687564730644, 14.175654239952564, 20.736549384891987, 23.556961342692375, 32.89940983057022, 45.51860488951206, 24.967356361448765, 46.450550481677055, 51.61966770887375, 33.83816845715046, 0.45843780040740967, 0.5304347933270037, 0.10640741209499538, 0.09291821013903245, 0.03152147575747222, 0.13288697402458638, 0.07103375202859752, 0.061600680273841135, 0.011422289135225583, 0.04995167058950756, 0.041918938732123934, 0.06077855505282059, 0.017533487480250187, 0.02315457706572488, 0.014462499875662616, 0.09170209727017209, 0.06798562535550445, 0.02094878800562583, 0.4826325864996761, 0.4272246721666306, 26.80494725704193, 78.5764092206955, 49.30276483297348, 24.52066943049431, 46.14070750772953, 38.24744425714016, 48.26610445976257, 7.923141047358513, 26.66481837630272, 70.77755570411682, 71.1800529062748, 69.54374670982361, 57.229337096214294, 72.3942169547081, 25.856837332248688, 0.8105185953900218, 1.427311236038804, 0.5260964354965836, 0.5854042468126863, 0.15510506462305784, 19.22160677611828, 57.79239848256111, 65.68270549178123, 65.92838510870934, 65.26649102568626, 62.32178583741188, 57.68955700099468, 58.43658931553364, 58.77589590847492, 57.33606956899166, 65.64139410853386, 62.88551598787308, 65.49132496118546, 63.973739594221115, 56.1832570284605, 58.42327482998371, 61.67318344116211, 64.19354259967804, 60.65175645053387, 64.6794681251049, 64.45777282118797, 63.4382039308548, 62.89622001349926, 57.88392037153244, 61.02451644837856, 57.95803539454937, 55.91241896152496, 52.797714695334435, 52.94825501739979, 51.719495952129364, 52.18278989195824, 52.527518793940544, 52.56558135151863, 55.92324838042259, 54.257444366812706, 51.7377083748579, 50.991721004247665, 52.68704183399677, 56.559923216700554, 54.7179264575243, 54.94014613330364, 53.95616993308067, 53.696575462818146, 56.35037586092949, 51.11005425453186, 53.736123740673065, 57.644943594932556, 53.50927971303463, 52.912073358893394, 54.12419691681862, 55.797110348939896, 55.13491988182068, 57.36291132867336, 57.871859818696976, 53.31344202160835, 61.16101652383804, 49.68446955084801, 51.505210250616074, 56.17761433124542, 55.39514511823654, 54.4407769292593, 51.91708914935589, 52.231400683522224, 52.27029159665108, 51.5487939119339, 54.44266922771931, 51.01141534745693, 53.93778271973133, 53.11552204191685, 55.018087550997734, 50.29944375157356, 50.7533597946167, 51.87352068722248, 53.451598808169365, 53.45983296632767, 52.67223782837391, 53.77591520547867, 52.909774482250214, 51.32656283676624, 51.523836851119995, 52.99721539020538, 53.81938487291336, 50.584656447172165, 50.229531303048134, 50.644298046827316, 51.49686209857464, 51.853613555431366, 53.75754699110985, 59.43224608898163, 24.146421812474728, 45.00845946371555, 57.57986068725586, 57.21835948526859, 56.42243519425392, 61.23573191463947, 57.73711524903774, 57.63887532055378, 54.36492919921875, 51.91646218299866, 46.213720589876175, 44.98465374112129, 71.15842446684837, 80.33504605293274, 58.18894900381565, 60.45056864619255, 56.9802338629961, 58.135554268956184, 59.7090308368206, 59.71861392259598, 54.607200399041176, 57.31729857623577, 55.98609320819378, 63.09619188308716, 63.097613006830215, 70.61970457434654, 38.70615944266319, 3.938256874680519, 0.4488157667219639, 0.7007218839135021, 0.09382898861076683, 1.688888487406075, 56.4798729121685, 61.09334975481033, 57.76698924601078, 66.7833848297596, 61.407452300190926, 69.2291159927845, 14.74683104082942, 28.43003075569868, 31.185513697564602, 26.678757928311825, 58.527252450585365, 22.561692148447037, 45.70766754448414, 61.65042266249657, 35.05486696958542, 0.9533811919391155, 0.34352801798377186, 0.09808460439671762, 0.03193997654307168, 0.030765574229008052, 0.09447073112824, 0.06749644613591954, 0.08192611989215948, 0.16360025096219033, 0.07220518018584698, 0.1634777372237295, 0.12802655983250588, 0.09601248355465941, 0.11372044624295086, 0.13383800658630207, 0.28869494155514985, 0.15516087412834167, 0.2737965347478166, 0.5820797814521939, 0.6976283749099821, 39.883328676223755, 91.34996339678764, 60.3373347222805, 34.28655959665775, 51.39734543859959, 51.14881977438927, 50.002083107829094, 11.379246544092894, 35.85584498941898, 75.08170634508133, 77.91733458638191, 75.65070301294327, 60.704364627599716, 79.2639671266079, 27.646469101309776, 1.720057858619839, 3.697416060604155, 0.7406507944688201, 1.4527889876626432, 0.30505576520226896, 24.139705672860146, 59.72791202366352, 69.52467173337936, 66.46325200796127, 69.23796951770782, 65.08097738027573, 62.87934511899948, 59.63010527193546, 60.881381928920746, 58.778608962893486, 70.79439640045166, 68.00223022699356, 68.88317495584488, 63.88078898191452, 53.647748082876205, 61.21151961386204, 64.93802145123482, 66.41865000128746, 61.53144724667072, 65.86278542876244, 68.40232595801353, 65.47646775841713, 66.41225874423981, 62.25307032465935, 63.54352667927742, 62.26772993803024, 58.841875568032265, 55.52179612219334, 54.646893069148064, 54.08442065119743, 58.12248297035694, 53.64129222929478, 56.654500141739845, 58.137963339686394, 62.07244701683521, 54.89412300288677, 52.86576524376869, 55.58605447411537, 60.653933733701706, 61.33678749203682, 61.004632115364075, 59.969856441020966, 55.699326395988464, 58.700796738266945, 54.14660431444645, 59.23974081873894, 58.59179578721523, 59.0850131213665, 56.052479445934296, 54.77111220359802, 59.388552233576775, 60.194629579782486, 62.302657663822174, 62.78216153383255, 58.73136229813099, 65.81714987754822, 55.50158880650997, 54.81352932751179, 62.293329164385796, 61.69380113482475, 58.28395530581474, 55.24700626730919, 58.88459287583828, 57.662753239274025, 57.93172940611839, 57.200352251529694, 56.43552169203758, 57.678009420633316, 61.82754635810852, 61.2806037068367, 54.26838018000126, 55.10615922510624, 56.01800389587879, 54.33700829744339, 56.74056552350521, 54.83190134167671, 56.92911520600319, 54.71673332154751, 53.83068926632404, 53.45178119838238, 55.09320572018623, 55.64525529742241, 51.37808807194233, 52.08398759365082, 53.0946459621191, 54.39192295074463, 53.28489035367966, 59.298504665493965, 53.38120378553867, 19.23795349895954, 50.32946594059467, 59.05992306768894, 62.627718821167946, 58.723245933651924, 62.703642547130585, 58.64929810166359, 60.535106509923935, 58.46985653042793, 55.55331543087959, 46.64521023631096, 44.243518710136414, 66.23005852103233, 78.56784448027611, 60.05250200629234, 60.79827658832073, 54.60664562880993, 60.11996738612652, 62.388111278414726, 61.546087861061096, 57.0225065946579, 61.80554933845997, 57.7965022623539, 66.32768288254738, 62.21536874771118, 70.12278243899345, 42.08110794425011, 5.827586743980646, 0.47857143566943705, 1.3614963926374912, 0.4084566480014473, 1.6645688423886895, 59.022126495838165, 66.94386541843414, 63.92027646303177, 72.25438445806503, 64.29033100605011, 74.5045705139637, 20.832992009818554, 30.979769937694073, 32.303332015872, 43.0118528008461, 75.98931044340134, 31.445767432451248, 64.0036515891552, 66.27571687102318, 52.46611028909683, 1.7314587906002998, 0.6862074346281588, 0.22444944363087416, 0.2545875561190769, 0.1444211511989124, 0.23549349163658917, 0.1949760431307368, 0.24566480366047472], [0.10258448324748315, 0.09181210582028143, 0.18455888726748526, 0.012071884502802277, 0.040677596552995965, 0.016408447263529524, 0.07687604986131191, 0.1645878714043647, 0.02405373721558135, 0.11540680614416488, 0.5454509938135743, 0.9958027093671262, 12.085828129202127, 60.21923325955868, 54.49792966246605, 43.24956804513931, 51.333664655685425, 33.76756064593792, 34.040093421936035, 6.977479616180062, 12.051982395350933, 54.14419524371624, 61.159766390919685, 64.83133837580681, 60.88227108120918, 57.522514164447784, 32.86467209458351, 0.40981587662827224, 0.08714533279999159, 0.24257433746242896, 0.9869852231349796, 0.09811600466491655, 13.73925430700183, 57.867330461740494, 59.58130829036236, 67.82521292567253, 63.34397278726101, 62.292933985590935, 55.8735166490078, 54.686897322535515, 55.769926607608795, 54.129159450531006, 50.75088992714882, 58.9580125361681, 59.09155637025833, 63.770876079797745, 64.09091010689735, 57.54327245056629, 56.90267242491245, 58.17079737782478, 57.955269142985344, 57.936961725354195, 61.47410452365875, 61.28890246152878, 60.11603079736233, 59.967994540929794, 57.90871784090996, 58.16759034991264, 52.504758015275, 50.79182893037796, 49.24711301922798, 50.02736695110798, 50.57000823318958, 48.227380737662315, 48.54460671544075, 47.459514141082764, 46.75425298511982, 48.368630558252335, 48.31628076732159, 51.97096645832062, 50.47486133873463, 52.45818771421909, 51.939226761460304, 49.021013751626015, 51.98928527534008, 48.01262766122818, 46.42436608672142, 48.20693023502827, 47.34048172831535, 49.60582137107849, 48.62725228071213, 46.44782982766628, 49.5950223505497, 50.83820544183254, 48.948802426457405, 51.245452389121056, 51.541201919317245, 51.512414664030075, 43.66234749555588, 40.22872634232044, 46.26374490559101, 50.11060528457165, 50.51119118928909, 46.48619256913662, 46.238761246204376, 42.936867624521255, 46.848104149103165, 42.37973012030125, 45.78565075993538, 42.465909495949745, 41.71681009232998, 43.29616114497185, 46.46219305694103, 45.82693174481392, 50.17790347337723, 49.00461383163929, 50.15324279665947, 51.656324341893196, 51.075928285717964, 50.083136558532715, 48.75810205936432, 49.64529745280743, 49.818685948848724, 52.762866765260696, 48.70853751897812, 46.942996457219124, 48.51089492440224, 47.72628262639046, 47.62826308608055, 51.03378474712372, 55.40020264685154, 30.62617041170597, 34.865618124604225, 53.62102031707764, 56.57459802925587, 60.44951230287552, 64.79953408241272, 58.44627879559994, 59.43281225860119, 49.17234443128109, 47.20153458416462, 39.52764876186848, 59.894111305475235, 62.63988956809044, 46.54766947031021, 64.0052019059658, 56.60171337425709, 60.15827313065529, 55.84535256028175, 57.15424172580242, 55.81602193415165, 56.154720559716225, 53.3067087829113, 58.229325637221336, 61.202016323804855, 61.358469128608704, 71.22408494353294, 31.7699109390378, 1.024508150294423, 0.8608842396643013, 0.3326239390298724, 0.2376252959948033, 9.10605177283287, 60.032119899988174, 47.594669088721275, 60.448626950383186, 57.42490500211716, 48.97449664771557, 51.17916114628315, 9.863494578748941, 22.950962260365486, 19.82474461197853, 35.657818615436554, 44.97468687593937, 30.912956222891808, 43.046845123171806, 53.819381073117256, 17.435683608055115, 0.3385170071851462, 0.40954398340545595, 0.0836694025201723, 0.08708964945981279, 0.03630396444350481, 0.0731601906591095, 0.08132393384585157, 0.05940397139056586, 0.024809902206470724, 0.02973199443658814, 0.18424069887259975, 0.02216648164903745, 0.16325454373145476, 0.08927907416364178, 0.09342611374449916, 0.2360799367306754, 0.044773086556233466, 0.05112970757181756, 0.49256706435699016, 0.690120809013024, 14.890080504119396, 72.42281422019005, 58.97309772670269, 33.65688778460026, 65.88021129369736, 40.320217832922935, 38.37660312652588, 11.502865310758352, 14.244055319577456, 64.413892775774, 70.95068961381912, 72.42966145277023, 62.558851316571236, 63.259229734539986, 38.05334307253361, 0.350538493366912, 0.08451271976809949, 0.23911260446766391, 1.3940588640980422, 0.02799421297822846, 16.519358977675438, 62.480009347200394, 61.90508879721165, 70.6809800863266, 64.50030773878098, 64.24668654799461, 59.254058450460434, 55.601424649357796, 58.24270471930504, 56.41253672540188, 52.45718836784363, 61.027366295456886, 60.59096731245518, 67.16538593173027, 63.15129652619362, 57.99541778862476, 57.56289839744568, 58.22557523846626, 59.378091394901276, 60.9097246080637, 63.83676454424858, 61.921602711081505, 60.799667313694954, 64.38015058636665, 61.872106567025185, 57.391443997621536, 55.96095375716686, 53.36164243519306, 51.79697759449482, 51.77185334265232, 50.12986645102501, 50.73065221309662, 52.113458812236786, 49.50304068624973, 52.73339934647083, 52.397459372878075, 50.004150196909904, 52.90651425719261, 53.30312557518482, 52.56281889975071, 54.770755022764206, 54.078257381916046, 53.84119190275669, 52.621366158127785, 50.78705258667469, 51.32673762738705, 51.41086891293526, 53.093756809830666, 50.93701533973217, 50.01317471265793, 51.07907831668854, 55.6022834032774, 53.192061334848404, 56.17968901991844, 57.26314768195152, 55.10855309665203, 50.34755676984787, 50.47930710017681, 54.69231963157654, 54.60308521986008, 54.37470607459545, 52.06135980784893, 50.42611375451088, 52.24050119519234, 50.35211272537708, 50.94969145953655, 50.72735778987408, 49.83766973018646, 48.26290503144264, 48.61358821392059, 50.755784064531326, 51.36405922472477, 52.69960395991802, 53.4223859757185, 53.52454349398613, 53.327995240688324, 53.448494374752045, 50.96963658928871, 50.77043607831001, 51.102599054574966, 52.38446407020092, 53.36093947291374, 51.152437180280685, 46.05205066502094, 52.42290660738945, 47.319335862994194, 51.666560992598534, 48.925923854112625, 65.69298774003983, 41.87687650322914, 35.822163596749306, 52.44583077728748, 58.030866086483, 58.97090144455433, 64.43637996912003, 59.67115446925163, 60.44117175042629, 52.0922065526247, 48.28089326620102, 38.693357929587364, 60.043105110526085, 52.399670854210854, 44.513482823967934, 67.40849688649178, 57.987031638622284, 61.12301856279373, 57.93957598507404, 59.445663169026375, 57.797991782426834, 56.87238425016403, 55.65057121217251, 60.67517839372158, 64.20653030276299, 65.21386384963989, 75.73014914989471, 37.57940210402012, 1.296778740361333, 0.8728255145251751, 0.5643574730493128, 0.2714439562987536, 11.926089450716972, 65.95445930957794, 56.0773529112339, 65.36903992295265, 65.03016650676727, 55.545719638466835, 53.04064325988293, 12.062658872455359, 36.90440632402897, 20.567760542035103, 33.27624320983887, 60.05116447806358, 27.37095158547163, 47.07610331475735, 61.64112076163292, 18.423089124262333, 0.27831849991343915, 0.1860645564738661, 0.15340386918978766, 0.10029546232544817, 0.07458175226929598, 0.015628617038601078, 0.17134356749011204, 0.06349205475999042, 0.24437319952994585, 0.16996142134303227, 0.27647767681628466, 0.15442886418895796, 0.3359817119780928, 0.19992636109236628, 0.20827393425861374, 0.3379791876068339, 0.1996251381933689, 0.32630161265842617, 0.7320839760359377, 1.02878553327173, 24.103537313640118, 86.14476710557938, 74.29560452699661, 55.78861020505428, 68.48097413778305, 50.78087031841278, 39.55123029649258, 13.733143284916878, 18.892006762325764, 65.32233282923698, 71.29295244812965, 76.94733023643494, 68.27490359544754, 69.9881936609745, 39.74463231861591, 1.265745093114674, 0.3274659236194566, 0.4310945566976443, 1.8721543159335852, 0.19412926747463644, 19.14604213088751, 65.46093419194221, 64.49533000588417, 73.81920129060745, 68.5732863843441, 67.64875039458275, 60.34000977873802, 59.58809472620487, 62.18998610973358, 60.58663174510002, 55.19229680299759, 62.80332259833813, 62.419820576906204, 68.28536063432693, 62.53462001681328, 61.332634314894676, 58.44203442335129, 61.55131258070469, 62.81992010772228, 60.945104509592056, 66.14355236291885, 65.31195178627968, 64.53250721096992, 66.42590761184692, 64.09636661410332, 62.74803936481476, 59.0779796987772, 55.05183733999729, 54.26568612456322, 53.85570332407951, 52.6527638733387, 53.35094980895519, 54.89856496453285, 53.65718297660351, 55.226825550198555, 56.78067997097969, 51.86289265751839, 52.64977723360062, 56.11723557114601, 57.549929693341255, 58.7203124910593, 56.40285864472389, 55.459855645895004, 56.46921448409557, 52.30344861745834, 53.43614883720875, 54.332201555371284, 58.42743180692196, 55.88505282998085, 53.760966807603836, 57.33394168317318, 58.52708525955677, 58.511848077178, 62.74436116218567, 62.58545368909836, 58.935225158929825, 54.58965674042702, 53.303497955203056, 57.33675733208656, 59.287299066782, 60.077747851610184, 59.53101798892021, 55.36647945642471, 53.780087381601334, 59.31685388088226, 54.338471218943596, 54.17145878076553, 52.07550264894962, 48.15592937171459, 51.1436178535223, 54.547353610396385, 54.23807680606842, 58.40407446026802, 53.53010639548302, 57.71127663552761, 54.43034268915653, 57.193520218133926, 50.58591417968273, 52.25132301449776, 51.85851909220219, 53.81273902952671, 55.96868634223938, 53.348225355148315, 47.10992909967899, 55.834747329354286, 51.483859196305275, 52.82806746661663, 51.790232956409454, 62.204531729221344, 29.315217956900597, 39.83524605631828, 56.59132093191147, 59.69720207154751, 61.703802198171616, 66.57353729009628, 62.1316896378994, 62.538115829229355, 56.61891505122185, 49.718819707632065, 38.53557139635086, 56.55529886484146, 64.11023586988449, 59.20218363404274, 65.25650516152382, 62.38783769309521, 61.01817078888416, 60.049021393060684, 61.49929337203503, 60.6574447453022, 58.734687119722366, 58.8019435107708, 62.682230696082115, 69.67353254556656, 66.18017479777336, 75.17622247338295, 41.6421402990818, 4.507313864305615, 0.9493019920773804, 1.5577929094433784, 0.384437691536732, 11.003125626593828, 74.17088761925697, 60.45197457075119, 68.1853500008583, 70.11491686105728, 57.58150979876518, 65.31186059117317, 15.69552993401885, 33.729517087340355, 21.782490760087967, 49.39602702856064, 73.70569378137589, 38.85568521916866, 59.52400356531143, 70.00608310103416, 31.326235346496105, 1.153455418534577, 0.9516305546276271, 0.34401335287839174, 0.3783071361249313, 0.17202978691784665, 0.20304575620684773, 0.24650123377796263, 0.13135052053257823], [0.024477162151015364, 0.10538734495639801, 0.047188239186652936, 0.043341257332940586, 0.10218002018518746, 0.0938670162577182, 0.013043635972280754, 0.038157096059876494, 0.09604452949133702, 0.0697897640930023, 0.22907315724296495, 0.3345171577529982, 4.625280434265733, 55.19542023539543, 59.511794820427895, 39.09764103591442, 30.126900002360344, 28.874230720102787, 43.06749701499939, 11.688880529254675, 14.704334121197462, 42.51976020634174, 58.708016350865364, 67.36739829182625, 65.93611389398575, 56.290981248021126, 49.7766488045454, 1.3063577888533473, 0.04844091767154168, 0.25128298031631857, 0.888806328875944, 0.10975897326716222, 8.785770758986473, 58.11141796410084, 62.35324054956436, 65.69389969110489, 62.469487711787224, 62.79113285243511, 55.261065512895584, 59.58141468465328, 60.02704717218876, 58.2839211076498, 55.83645723760128, 56.55178785324097, 62.72473141551018, 62.5067713111639, 59.11265283823013, 56.04748651385307, 52.5851047039032, 49.5961394906044, 45.867471769452095, 54.72913585603237, 63.41201953589916, 63.53469595313072, 62.30661325156689, 57.0835617184639, 58.89850772917271, 56.67457066476345, 53.67950677871704, 55.61704941093922, 54.42978411912918, 50.43066971004009, 45.33484674990177, 46.84500731527805, 48.744525387883186, 48.63129526376724, 47.56375394761562, 44.97252479195595, 49.020405784249306, 49.7590671479702, 51.02559618651867, 48.821228072047234, 48.57736095786095, 49.187304228544235, 50.489068776369095, 49.92151603102684, 50.202845335006714, 49.22566697001457, 46.292372569441795, 48.0973669141531, 45.475370809435844, 46.82863399386406, 48.00749033689499, 49.128787368535995, 53.182037472724915, 50.01265414059162, 51.78683593869209, 48.511708080768585, 44.556633308529854, 45.04470191895962, 47.3275738209486, 46.35552138090134, 51.269512698054314, 47.54625588655472, 44.79195848107338, 42.424560114741325, 42.790659070014954, 45.411967411637306, 45.023905634880066, 42.89516866207123, 45.672059655189514, 43.45272794365883, 46.812500059604645, 44.61270309984684, 48.159079402685165, 48.34085024893284, 51.02873481810093, 49.36444692313671, 50.70574454963207, 50.921181589365005, 47.583581283688545, 47.930730655789375, 48.941495418548584, 48.63343074917793, 49.49918769299984, 47.28390656411648, 48.04383918642998, 48.49672168493271, 48.15056025981903, 47.48099818825722, 54.988160356879234, 62.01598584651947, 50.77634856104851, 48.80553871393204, 57.982623875141144, 57.71285355091095, 59.44694750010967, 55.46709805727005, 58.309470936656, 54.91566024720669, 60.43967463076115, 48.82036551833153, 50.63718102872372, 13.302409797906876, 35.52158832550049, 64.3710158765316, 55.81374205648899, 57.7432557195425, 54.618166610598564, 55.566257536411285, 53.31518232822418, 51.56050108373165, 57.39704109728336, 58.04114073514938, 64.1168475151062, 55.00788889825344, 61.17818020284176, 20.921760946512222, 0.7959140790626407, 0.3067819413263351, 0.1978830949519761, 0.0796222708595451, 11.400023829191923, 55.1927375793457, 55.633897706866264, 62.26291559636593, 55.163771733641624, 53.768528401851654, 36.33637860417366, 3.686720347031951, 32.832320630550385, 26.016799248754978, 48.46470460295677, 29.603907465934753, 34.81079086661339, 58.014583960175514, 46.35550618171692, 5.9648016560822725, 0.0966128587606363, 0.3274018317461014, 0.05541333943256177, 0.1315315006650053, 0.006054556706658332, 0.0931443425361067, 0.07421326852636412, 0.1418721114168875, 0.03318884781037923, 0.0066391121072229, 0.09853174837189727, 0.028820564730267506, 0.05371378414565697, 0.10382119071437046, 0.13906196923926473, 0.08018730499316007, 0.07756646242341958, 0.024934243483585306, 0.43982173840049654, 0.2573370054597035, 6.062912866473198, 60.054622292518616, 73.0793733894825, 32.22192898392677, 39.809874817728996, 41.54054135084152, 41.84745468199253, 17.522054873406887, 16.489076502621174, 44.864371195435524, 64.0571603178978, 73.74898105859756, 68.57798293232918, 60.09942188858986, 55.332908257842064, 1.8831206462346017, 0.00814595947304042, 0.41681768372654915, 1.0889093508012593, 0.11058817486627959, 10.581803284585476, 62.07716256380081, 65.19009992480278, 68.14237430691719, 64.49071705341339, 62.895042076706886, 55.72654813528061, 58.7685889005661, 64.07371982932091, 62.122399136424065, 59.20691817998886, 58.74447159469128, 65.09022608399391, 65.04638403654099, 62.86344677209854, 55.84764003753662, 55.09164020419121, 52.46667265892029, 48.886272981762886, 56.52142748236656, 63.60502637922764, 65.49884095788002, 63.138567209243774, 57.462754771113396, 61.46481782197952, 57.84663297235966, 56.70298554003239, 58.23780298233032, 57.44597487151623, 51.97957679629326, 49.095333963632584, 48.152809739112854, 53.88135574758053, 50.73643930256367, 48.53490203619003, 48.955345675349236, 50.674069449305534, 49.09498818218708, 51.70643985271454, 51.05676971375942, 52.34954014420509, 54.83276769518852, 52.0495880395174, 53.90511967241764, 51.98442533612251, 50.33852465450764, 50.901380851864815, 51.29289664328098, 45.85687793791294, 49.17353376746178, 50.0583428889513, 55.561386197805405, 56.4525181800127, 56.21838614344597, 57.31451712548733, 50.39049066603184, 48.33271108567715, 51.86986528337002, 52.32156224548817, 54.206720888614655, 55.74174351990223, 53.8939368724823, 48.71251970529556, 50.09884111583233, 48.796574994921684, 47.86402143537998, 48.69942560791969, 48.804353177547455, 49.529479667544365, 49.64272119104862, 52.29754373431206, 49.853579476475716, 52.562590911984444, 52.37150676548481, 53.86802986264229, 52.511415258049965, 52.34404183924198, 52.34689548611641, 51.540833339095116, 49.01467949151993, 50.941126719117165, 47.83483140170574, 49.832251220941544, 50.89209035038948, 49.90211047232151, 51.34971499443054, 50.42015187442303, 47.90887802839279, 54.892762675881386, 72.45721757411957, 61.88898906111717, 48.62566776573658, 59.347195252776146, 57.775637581944466, 59.6048404276371, 56.05186767876148, 58.58553372323513, 55.336312875151634, 59.052851647138596, 48.13466191291809, 49.20542545616627, 17.41790436208248, 40.28162330389023, 63.89606416225433, 59.435175731778145, 59.57637995481491, 56.97141453623772, 56.33068151772022, 56.36279359459877, 54.86760422587395, 60.210691317915916, 59.049378633499146, 68.18207457661629, 57.8824308514595, 65.7734826207161, 23.611716404557228, 1.0077454685233533, 0.2910423546563834, 0.34017591504380107, 0.3179130284115672, 16.028273329138756, 63.15581828355789, 59.86837148666382, 65.6701509654522, 62.96541050076485, 57.544826567173004, 35.77875852584839, 6.122657060623169, 45.941852778196335, 25.45041874051094, 56.05895049870014, 36.5463325381279, 32.92291156947613, 64.12582263350487, 55.589797273278236, 6.579133691266179, 0.13673766661668196, 0.08736055562621914, 0.13800022308714688, 0.07643689881660976, 0.08181969591532834, 0.11377340590115637, 0.06297070343862288, 0.06148156557173934, 0.1784683039295487, 0.24419057182967663, 0.1387112302472815, 0.17283167748246342, 0.2729280438506976, 0.21438700467115268, 0.2918787847738713, 0.24922770622652024, 0.27753321861382574, 0.12745749583700672, 0.6572310207411647, 0.5577316973358393, 9.734950326383114, 77.80961036682129, 78.98534327745438, 57.21161104738712, 40.4715371131897, 52.131363451480865, 49.07884664833546, 18.605426140129566, 22.19594467431307, 54.776070937514305, 70.68100288510323, 77.63507053256035, 73.15477654337883, 69.7937960922718, 60.99399648606777, 2.7047554263845086, 0.18858037772588432, 0.8541818149387836, 1.888086386024952, 0.1835425605531782, 12.48428424820304, 67.36274734139442, 70.34982785582542, 70.23522600531578, 67.91348218917847, 67.12139949202538, 58.89355279505253, 64.23896536231041, 67.8405337035656, 66.11044093966484, 61.056795716285706, 61.59774988889694, 67.52249076962471, 70.14129504561424, 63.27475190162659, 57.963286712765694, 53.7566464394331, 55.347066298127174, 51.64502374827862, 60.40085971355438, 67.59993821382523, 67.47999384999275, 66.766916513443, 61.480529978871346, 64.178586602211, 59.22790825366974, 58.33328425884247, 60.95824420452118, 61.00391015410423, 56.47159695625305, 50.64669571816921, 51.139719262719154, 55.39196088910103, 55.247568637132645, 50.62465310096741, 51.399119943380356, 53.84525008499622, 51.875667572021484, 53.29546898603439, 53.767396062612534, 57.431539446115494, 57.41260886192322, 60.340621545910835, 57.82418377697468, 57.30794347822666, 53.76152917742729, 55.40245592594147, 53.87146107852459, 52.30156771838665, 54.61233012378216, 57.30569779872894, 59.291456043720245, 61.77699767053127, 61.224438920617104, 62.49838896095753, 56.985792964696884, 53.083079382777214, 57.584059461951256, 58.713564053177834, 58.3552660793066, 64.42020803689957, 60.656171813607216, 57.11598917841911, 54.2695277184248, 54.38211567699909, 55.5372878909111, 53.40790495276451, 52.27834716439247, 56.84038236737251, 52.19955079257488, 55.95963142812252, 53.07727709412575, 56.482000797986984, 53.9852649718523, 57.248966842889786, 53.732487335801125, 55.2166572958231, 54.06256802380085, 53.564327359199524, 51.71959474682808, 52.6417026668787, 50.34361258149147, 53.5009391605854, 53.34953248500824, 52.51860827207565, 53.86833004653454, 53.04691672325134, 50.537158995866776, 59.01418872177601, 60.753678381443024, 55.02068281173706, 55.43495938181877, 61.373691111803055, 62.05666646361351, 60.83879001438618, 57.168984934687614, 60.43052092194557, 56.71575665473938, 60.34936107695103, 47.580571845173836, 53.200063705444336, 23.953779749572277, 40.43813310563564, 67.22348481416702, 57.92998909950256, 61.2180894613266, 59.85335849225521, 58.384543508291245, 59.34985511004925, 58.08963753283024, 63.439324870705605, 62.23456151783466, 70.99501803517342, 60.952521711587906, 65.02576634287834, 27.3022398725152, 1.7207776824943721, 0.5151102156378329, 0.6226107222028077, 0.5078215536195785, 17.158317491412163, 67.74105504155159, 65.35174325108528, 70.9493900835514, 66.01923063397408, 62.14305482804775, 50.51559895277023, 6.025563720613718, 45.63262537121773, 29.351418614387512, 72.80224665999413, 48.0986512452364, 47.66382917761803, 72.01422214508057, 69.02961909770966, 13.439556788653135, 0.5241364531684667, 0.4934266791678965, 0.33293528482317924, 0.3605484921718016, 0.38258012558799237, 0.24517654470400885, 0.21415754745248705, 0.24512949254130945], [0.02433357327390695, 0.023500683200836647, 0.036485241435002536, 0.06034928570443299, 0.022713355429004878, 0.012175940100860316, 0.07691977720241994, 0.023878057872934733, 0.07694261308643036, 0.09408775324118324, 0.04139055556152016, 0.0438320952525828, 0.7401271350681782, 37.46829606592655, 61.61339744925499, 44.08153340220451, 34.92488354444504, 30.98008342087269, 59.69758205115795, 19.46994625031948, 6.030312040820718, 51.39532774686813, 61.43706031143665, 53.646718338131905, 69.15244370698929, 48.5452526807785, 68.14614370465279, 8.361520674079657, 0.18569032108644024, 0.3147427219664678, 1.0766684263944626, 0.35366875352337956, 1.1369906645268202, 50.341275706887245, 56.36912785470486, 68.82071390748024, 62.2644317150116, 61.424361392855644, 55.02918675541878, 60.94973646104336, 60.83247855305672, 63.49054612219334, 55.89681699872017, 55.93691244721413, 56.0428811609745, 63.13169337809086, 61.93790763616562, 59.69249412417412, 47.8787874430418, 50.317298993468285, 49.22111101448536, 58.624770417809486, 61.920557767152786, 61.29520632326603, 62.3794287443161, 55.74580170214176, 56.0122662037611, 61.665025278925896, 56.77004434168339, 60.90421110391617, 57.083481922745705, 52.0880001783371, 50.37452772259712, 49.19266574084759, 48.933033272624016, 48.46261091530323, 49.47178356349468, 43.805242627859116, 47.92788840830326, 47.31400854885578, 46.93389594554901, 46.92641034722328, 49.83550384640694, 47.51253269612789, 49.0646506100893, 49.372399896383286, 50.420474857091904, 52.23102070391178, 50.48422023653984, 45.24198733270168, 46.57635033130646, 45.55828996002674, 47.604084983468056, 52.35378831624985, 54.048105999827385, 48.77974949777126, 51.482719257473946, 46.63519777357578, 40.02713195979595, 45.85526682436466, 47.05058768391609, 49.26613859832287, 48.425939083099365, 46.33397653698921, 43.60397882759571, 41.53082147240639, 39.03427183628082, 40.95227971673012, 46.115362867712975, 45.85022069513798, 42.74104133248329, 44.35825355350971, 46.94316364824772, 49.060862213373184, 47.71947719156742, 48.112866282463074, 49.12045821547508, 48.27382944524288, 50.96008390188217, 48.07974345982075, 44.336020946502686, 42.726955488324165, 47.80227854847908, 46.264056488871574, 47.9777455329895, 45.15099361538887, 47.46009550988674, 46.28951892256737, 47.36850902438164, 50.82658186554909, 54.09772373735905, 55.66301554441452, 70.22722363471985, 64.88603264093399, 55.296798795461655, 56.68056294322014, 58.01612287759781, 56.970399990677834, 58.12786728143692, 58.90398323535919, 54.45499576628208, 56.658736914396286, 43.33849847316742, 40.47787897288799, 60.44064737856388, 62.777559980750084, 58.582254499197006, 55.60814268887043, 54.09499928355217, 53.77609759569168, 53.17882664501667, 55.16634039580822, 58.451165333390236, 57.11878202855587, 63.89075964689255, 59.77285601198673, 43.51372607052326, 8.923752754926682, 1.4751625433564186, 0.7594081910792738, 0.3261210926575586, 0.35206571454182267, 26.571081206202507, 69.20295059680939, 48.65413963794708, 69.42705497145653, 46.722323298454285, 57.52086505293846, 21.131338700652122, 6.84522676281631, 42.705387845635414, 15.863995794206858, 51.23221389949322, 24.780913665890694, 33.39010789990425, 50.68282797932625, 43.38828720152378, 1.5548937837593257, 0.08284064620966092, 0.043244366243015975, 0.00931618071263074, 0.16114132275106385, 0.02643214425916085, 0.01721964992611902, 0.09943388824467547, 0.08103845932055265, 0.05359647286240943, 0.010028446740761865, 0.04635124874766916, 0.06393458999809809, 0.07111288723535836, 0.015428204696945613, 0.03891032400133554, 0.047462418224313296, 0.1559660301427357, 0.06717344862408936, 0.12471576483221725, 0.07888519947300665, 0.9896312467753887, 40.7882235199213, 76.29549041390419, 45.52143193781376, 35.23485951125622, 51.5800092369318, 52.297387942671776, 25.631965398788452, 9.007085133343935, 50.59564545750618, 70.75800195336342, 60.3935831040144, 75.78417465090752, 54.21379990875721, 75.50882622599602, 9.220230896025896, 0.12700799183221534, 0.6099287839606404, 1.4776155492290854, 0.5864250857848674, 1.7075760033912957, 54.38091494143009, 60.722808837890625, 71.81740030646324, 65.42805075645447, 66.40596628189087, 59.0704371035099, 63.60306568443775, 63.34478594362736, 64.96523559093475, 59.933659583330154, 58.59197057783604, 59.77976784110069, 64.32867094874382, 66.4089073240757, 62.4469131231308, 45.80129452049732, 49.05164010822773, 52.385341823101044, 60.33883944153786, 62.03526221215725, 61.2992113083601, 63.21652002632618, 57.78431251645088, 60.552213191986084, 63.095203936100006, 61.59812606871128, 60.124139562249184, 60.651642456650734, 55.23338779807091, 53.89707550406456, 51.58783681690693, 53.20593439042568, 50.46723894774914, 48.83432596921921, 47.20264412462711, 50.210897102952, 48.602226823568344, 50.86883179843426, 48.835386112332344, 50.394317060709, 52.0795152336359, 54.3854670971632, 52.58490711450577, 52.83465251326561, 55.34302331507206, 50.898379012942314, 50.29862679541111, 48.641562312841415, 48.19036692380905, 50.75454153120518, 54.109427109360695, 56.7457864433527, 54.53276239335537, 54.690909907221794, 45.75216315686703, 44.18318174779415, 50.17954498529434, 53.105418384075165, 54.30780306458473, 51.03297159075737, 54.07072238624096, 50.625207871198654, 46.50939032435417, 45.166097804903984, 49.14049074053764, 50.22942490875721, 47.77292512357235, 48.261913284659386, 49.782686680555344, 51.014109402894974, 54.223375394940376, 52.816322296857834, 53.333793729543686, 54.10581350326538, 50.55149182677269, 54.124056324362755, 48.01220968365669, 45.97855120897293, 46.76027946174145, 48.507600501179695, 47.31457471847534, 49.14917707443237, 46.24471552670002, 48.94671253859997, 50.067299008369446, 49.32174861431122, 51.836780458688736, 53.58902983367443, 54.43037688732147, 72.77310982346535, 64.73287805914879, 56.83516904711723, 57.356311082839966, 56.50001183152199, 57.88230925798416, 57.431539446115494, 58.121852204203606, 54.33234974741936, 57.34338417649269, 44.78324934840202, 41.364812180399895, 63.17642457783222, 62.58435934782028, 60.618998408317566, 56.09365403652191, 58.63042451441288, 54.50627401471138, 57.161001563072205, 57.21710555255413, 60.336076989769936, 61.243228912353516, 67.35235869884491, 61.57230645418167, 48.17339323461056, 11.484882775694132, 1.5160631923936307, 1.421393291093409, 0.1838459653663449, 0.424552732729353, 29.307728558778763, 74.27747189998627, 53.96623559296131, 72.9419195652008, 54.675338342785835, 57.5360756367445, 26.18182249367237, 9.263858254998922, 46.27151168882847, 15.265930686146021, 55.65916635096073, 32.72719547152519, 30.62983151525259, 56.16719529032707, 53.708742409944534, 2.5340735726058483, 0.0684300679131411, 0.055213323212228715, 0.0525401889171917, 0.098660525836749, 0.05620714800897986, 0.047359296804643236, 0.04190650404780172, 0.04902181892248336, 0.20581807853886858, 0.14045440155314282, 0.22438652435084805, 0.14521518984111026, 0.1074244586925488, 0.08723200822714716, 0.1490460374043323, 0.2067869671736844, 0.22523169696796685, 0.2102561216452159, 0.21210500446613878, 0.23831176775274798, 1.4613018371164799, 62.15263791382313, 81.61295548081398, 67.03081235289574, 40.75055234134197, 56.926428750157356, 70.24366915225983, 25.461725033819675, 12.159390281885862, 60.431398674845695, 71.64240449666977, 65.494873970747, 78.22558164596558, 59.22008827328682, 82.60044649243355, 10.815819427371025, 0.26407855621073395, 1.173759747762233, 1.7667568777687848, 1.1400264641270041, 3.0690095806494355, 61.471680253744125, 63.80375951528549, 75.38632839918137, 68.49510177969933, 70.68888366222382, 61.557817831635475, 67.17425465583801, 67.26869478821754, 69.34683367609978, 60.93046009540558, 62.541117668151855, 61.88477508723736, 66.61263719201088, 68.18835943937302, 63.78407657146454, 49.2635927349329, 48.231693506240845, 49.66228634119034, 62.14287243783474, 64.64890256524086, 64.7382889688015, 64.44925367832184, 60.40009215474129, 61.87428764998913, 68.2882484793663, 63.02588805556297, 65.45765116810799, 63.126073479652405, 58.27701307833195, 56.33761614561081, 56.969381645321846, 57.28393256664276, 53.47534753382206, 52.2617344558239, 50.601987317204475, 52.96647123992443, 52.37711526453495, 50.69426916539669, 51.58059820532799, 54.21517923474312, 57.29033142328262, 57.85304702818394, 54.72526006400585, 58.61182451248169, 57.43953801691532, 55.30629828572273, 53.102253153920174, 53.527891114354134, 53.333432748913765, 56.350071877241135, 60.86055904626846, 64.8194070160389, 59.12317827343941, 60.302752777934074, 53.89574557542801, 49.13417547941208, 56.33050672709942, 59.611250683665276, 61.445302069187164, 56.8892477452755, 60.54474659264088, 56.81780397891998, 51.03003054857254, 49.743696972727776, 53.523475751280785, 55.23441754281521, 51.6607891023159, 50.38101017475128, 52.55190588533878, 55.61957627534866, 59.837737530469894, 56.14691577851772, 55.86493670940399, 55.52032180130482, 53.048041462898254, 56.079378202557564, 50.234892815351486, 46.97895772755146, 48.924149349331856, 51.60918407142162, 50.77227137982845, 49.977585822343826, 48.58706943690777, 51.153037548065186, 51.96810141205788, 51.109130904078484, 54.683519303798676, 56.58829249441624, 58.579055070877075, 68.28226760029793, 66.43464714288712, 59.15296867489815, 58.96610990166664, 59.880424439907074, 58.084583804011345, 61.469601765275, 62.20744617283344, 57.28812374174595, 58.74240830540657, 45.77918730676174, 38.45126911997795, 63.592924028635025, 66.62996426224709, 64.04957592487335, 58.221091479063034, 60.168775767087936, 56.76235735416412, 59.58044953644276, 60.53286463022232, 62.47073784470558, 64.21391710639, 68.09756711125374, 63.18783916532993, 51.253143176436424, 18.648831211030483, 2.0753035275265574, 2.1963455574586987, 0.440783710218966, 0.4458364297170192, 33.34153510630131, 80.25940731167793, 57.98742301762104, 77.63337582349777, 57.349133267998695, 67.01897218823433, 31.386399418115616, 9.744603708386421, 56.49644002318382, 18.776069283485413, 75.91386169195175, 37.81634978950024, 47.28739857673645, 64.72236782312393, 70.44698104262352, 5.06748360581696, 0.23534975247457623, 0.2970194339286536, 0.3243372368160635, 0.35548947926145047, 0.1879864963120781, 0.13178779394365847, 0.2645109611330554, 0.16619724832708016], [0.06762042932678014, 0.05171810080355499, 0.035519373341230676, 0.04411996320413891, 0.03480080369627103, 0.08809019811451435, 0.04799806702067144, 0.09045200145919807, 0.06960341081139632, 0.016463373613078147, 0.1218502658593934, 0.22509120841277763, 0.5766061751637608, 15.656171645969152, 60.60403861105442, 47.02984839677811, 41.942738369107246, 27.450779601931572, 40.229182317852974, 28.477129228413105, 5.766953872516751, 30.422039665281773, 83.4508104622364, 51.29379719495773, 62.77466453611851, 56.02681182324886, 57.92601831257343, 30.06641674786806, 0.5437800928484648, 0.1811577135231346, 0.4385710117639974, 0.6218597874976695, 0.1719709049211815, 32.47539438307285, 64.46624636650085, 60.85803598165512, 68.46588894724846, 62.95235060155392, 61.20665207505226, 58.96731063723564, 63.95852521061897, 63.55426870286465, 62.716489657759666, 60.53052395582199, 60.166606083512306, 61.365331560373306, 64.93333250284195, 64.24629896879196, 49.278252348303795, 48.31458605825901, 53.39427128434181, 62.80494511127472, 62.04918086528778, 59.29350793361664, 61.32587447762489, 58.209756687283516, 55.29380835592747, 59.45235840976238, 59.40772220492363, 58.511422500014305, 60.76998330652714, 55.68230710923672, 51.81589297950268, 48.634221106767654, 47.606733441352844, 47.961224019527435, 47.72619143128395, 43.905777633190155, 44.18413929641247, 45.156632512807846, 46.09948731958866, 45.82363732159138, 45.3587094694376, 49.38409946858883, 47.49552860856056, 51.5022312104702, 50.2494802325964, 50.968044474720955, 48.180525451898575, 48.119075149297714, 46.91688805818558, 47.08923161029816, 48.47377851605415, 52.937577590346336, 51.74698367714882, 45.805044919252396, 44.469158202409744, 43.98314148187637, 41.77095338702202, 41.49022825062275, 47.49639116227627, 46.328706219792366, 49.92066487669945, 48.6941172927618, 44.84683893620968, 41.27824142575264, 40.857049226760864, 41.274867206811905, 46.313347443938255, 44.28538866341114, 48.09409908950329, 47.98152633011341, 46.45865924656391, 49.218466356396675, 47.98676244914532, 48.91388989984989, 44.51854035258293, 45.860293954610825, 47.0165529102087, 46.73548959195614, 45.5762629956007, 44.345239251852036, 45.53096562623978, 48.99310044944286, 47.831935957074165, 48.00118267536163, 49.44042004644871, 49.93821993470192, 52.18848578631878, 50.09561508893967, 50.36763109266758, 51.773700043559074, 55.08652187883854, 62.053771018981934, 56.87197007238865, 54.869146943092346, 56.17033012211323, 57.35473416745663, 58.306947872042656, 55.777970775961876, 56.91772721707821, 57.702928483486176, 50.72622925043106, 51.36817820370197, 58.37191678583622, 61.482194289565086, 59.212211295962334, 57.5421667098999, 55.83187088370323, 58.19117188453674, 54.49849583208561, 55.42884171009064, 59.71737138926983, 60.638050585985184, 58.445522636175156, 64.57082435488701, 37.944117933511734, 3.045567451044917, 0.5780924891587347, 1.7841997230425477, 0.19594332872657105, 2.3480704659596086, 41.63893707096577, 53.81293281912804, 54.111938774585724, 58.892682641744614, 39.2575516551733, 64.85668301582336, 13.176756240427494, 17.721829153597355, 38.560133278369904, 22.568096704781055, 55.76670058071613, 23.840163946151733, 38.075112104415894, 51.74922935664654, 39.07134264707565, 0.5745118937920779, 0.17845380236394703, 0.030547137903340627, 0.06019468521117233, 0.0735657372570131, 0.048271767373080365, 0.0347896121093072, 0.015977615694282576, 0.06873154314234853, 0.015148744350881316, 0.04269438657502178, 0.047199208129313774, 0.013682282806257717, 0.030212089768610895, 0.05721803107007872, 0.04736828792374581, 0.03966479875089135, 0.08123561827233061, 0.06266749900532886, 0.0743178668199107, 0.22413431288441643, 0.5797003966290504, 15.869128368794918, 73.62397536635399, 53.06983709335327, 31.469329968094826, 42.100699692964554, 45.35565063357353, 29.036436416208744, 8.257945831865072, 32.80210845172405, 87.99053326249123, 54.89190012216568, 70.94473913311958, 62.462241500616074, 65.4712924361229, 34.99368645250797, 0.35721995984204113, 0.4378763021668419, 1.1721132486127317, 1.022991556674242, 0.15164710173849016, 36.649470403790474, 68.70364218950272, 64.69889268279076, 68.32582846283913, 65.69700792431831, 63.78989025950432, 64.28684279322624, 66.13027587532997, 67.2779130935669, 64.061788469553, 64.42362785339355, 62.54280857741833, 63.86317312717438, 65.67000657320023, 66.39462009072304, 51.992788687348366, 48.8449501991272, 53.22587572038174, 65.65623611211777, 63.87766554951668, 62.298105508089066, 62.2866453230381, 59.49414096772671, 58.82840149104595, 62.84787140786648, 60.68288058042526, 61.63584664463997, 62.31971114873886, 57.89601892232895, 56.495319083333015, 52.34436862170696, 50.38742043077946, 50.33264257013798, 49.05586548149586, 46.12466096878052, 46.73079304397106, 47.27195620536804, 48.56843523681164, 47.46656276285648, 48.69436427950859, 51.07783958315849, 49.79888901114464, 53.131530582904816, 52.054512575268745, 53.796521499753, 52.883305102586746, 50.485253781080246, 48.8120249658823, 47.5777979940176, 51.20353303849697, 55.5221913009882, 55.35715855658054, 51.60732977092266, 50.42942717671394, 46.967641934752464, 45.35544924438, 49.70879964530468, 53.160017654299736, 53.07956837117672, 52.667431086301804, 53.09715762734413, 48.3427881449461, 47.96732269227505, 47.0460469275713, 45.328546687960625, 49.61475849151611, 50.14964058995247, 50.66725641489029, 50.924928188323975, 52.08395339548588, 51.85837469995022, 53.05749915540218, 51.041319742798805, 49.65795837342739, 50.06939649581909, 50.44454276561737, 49.66826342046261, 47.52139002084732, 47.42972753942013, 46.90055273473263, 50.20213857293129, 47.45197154581547, 51.08201555907726, 50.5754267424345, 53.709547966718674, 52.1834472566843, 53.139814138412476, 52.92800210416317, 53.42412248253822, 51.445811837911606, 58.263804987072945, 55.527712404727936, 55.91452784836292, 55.763178169727325, 60.05352795124054, 58.24143938720226, 56.80149145424366, 57.390558645129204, 58.04307863116264, 49.32352691888809, 50.97067393362522, 59.6491764485836, 62.90689364075661, 59.16653394699097, 59.3739990144968, 57.43805229663849, 60.17121143639088, 56.18142552673817, 59.34049241244793, 61.728584468364716, 63.64311173558235, 58.87645751237869, 66.9361062347889, 38.84591594338417, 3.527951566502452, 0.27904256887268275, 2.794818193651736, 0.05481729094753973, 3.3391822082921863, 48.4394321590662, 58.680353835225105, 61.92852973937988, 62.17126451432705, 45.93025200068951, 66.30613043904305, 17.387817576527596, 17.69928116351366, 41.84514820575714, 18.212439827620983, 67.74643555283546, 26.391772627830505, 39.29688334465027, 64.63729038834572, 39.95221897959709, 0.7880310458131135, 0.13033248687861487, 0.019656083641166333, 0.04435510898474604, 0.09891199515550397, 0.012960522853973089, 0.04331225049099885, 0.06960458340472542, 0.04271475481800735, 0.16115588368847966, 0.13040449004620314, 0.12693003664026037, 0.19935443240683526, 0.20880718220723793, 0.13989900791784748, 0.2563027781434357, 0.29895415354985744, 0.09869444940704852, 0.1285994829959236, 0.1630579339689575, 0.45352113142143935, 0.7121729850769043, 30.25579858571291, 89.19308513402939, 64.69589844346046, 53.37793596088886, 43.81565406918526, 59.60268594324589, 32.255606576800346, 10.152020696550608, 39.35430586338043, 89.68063697218895, 62.846830263733864, 76.0627681016922, 65.47410428524017, 71.6457787156105, 36.52743615210056, 0.5103468149900436, 1.7722757253795862, 1.9601138960570097, 1.703846741002053, 0.18521871592383832, 39.586971178650856, 72.11874693632126, 68.1812234222889, 72.13869586586952, 70.00938892364502, 68.55283588171005, 65.7378177344799, 69.6053034067154, 70.59793934226036, 68.03796350955963, 66.55320078134537, 64.79288443922997, 65.26871010661125, 68.99014681577682, 67.18506127595901, 52.78821140527725, 50.07416903972626, 51.688470616936684, 69.99979823827744, 66.33005395531654, 63.57316128909588, 64.87605437636375, 65.23439034819603, 60.51448121666908, 68.03337335586548, 63.89609456062317, 64.54501613974571, 64.69726637005806, 61.402314975857735, 59.26318556070328, 56.869598999619484, 51.72209121286869, 55.61416156589985, 51.46084763109684, 48.50000090897083, 50.61903320252895, 50.9927811473608, 51.75909362733364, 50.16855217516422, 51.43062025308609, 55.339956879615784, 53.398827239871025, 58.209334909915924, 56.357276290655136, 57.12331898510456, 55.381701439619064, 55.29680259525776, 54.39203314483166, 52.21738323569298, 56.96258760988712, 60.59932306408882, 58.65709148347378, 53.12457695603371, 52.101812437176704, 50.88192209601402, 49.425498247146606, 53.088482692837715, 60.9929059445858, 58.05136978626251, 60.223492830991745, 59.10591959953308, 55.903261452913284, 53.62988904118538, 51.72013811767101, 47.410637363791466, 56.7550465464592, 53.73851381242275, 56.95837743580341, 54.22080673277378, 53.01414728164673, 57.408394888043404, 54.874804839491844, 53.67434665560722, 51.209247931838036, 51.141459569334984, 51.88135206699371, 51.49531178176403, 48.42634566128254, 50.78121230006218, 48.40049184858799, 53.563958778977394, 51.718485206365585, 53.41645449399948, 54.23646189272404, 55.26906028389931, 54.90518040955067, 56.233946308493614, 54.615784138441086, 55.584420561790466, 55.23932687938213, 61.26415058970451, 58.04596267640591, 58.674540147185326, 58.00417251884937, 62.600945457816124, 60.19760861992836, 57.90596678853035, 58.04755859076977, 61.445826441049576, 50.355741530656815, 52.038819417357445, 60.81410273909569, 66.0472047328949, 61.59973718225956, 61.131039932370186, 59.80934925377369, 62.4117574095726, 57.74700991809368, 61.452316492795944, 65.88281035423279, 65.32521307468414, 62.831585481762886, 69.466732442379, 47.19179190695286, 7.208609813824296, 0.7019297441001981, 4.309577224776149, 0.24794248456601053, 3.6581202317029238, 53.29511560499668, 64.82654303312302, 66.03332787752151, 67.8766393661499, 50.89710608124733, 74.76864874362946, 20.46180322766304, 24.327922873198986, 50.99274314939976, 28.11484906822443, 85.87202534079552, 32.006298154592514, 55.161096677184105, 66.18185430765152, 61.060971692204475, 1.6632606438361108, 0.2330042838002555, 0.22112438455224037, 0.275344803230837, 0.20727197552332655, 0.12643441557884216, 0.14993198361480609, 0.17859387531643733, 0.1995499586337246], [0.05122206413943786, 0.08657254322315566, 0.07205252040876076, 0.07526135916123167, 0.11003206134773791, 0.10097292441059835, 0.07483936657081358, 0.11534886667504907, 0.035466194749460556, 0.08226283229305409, 0.10498236981220543, 0.04661410261178389, 0.5412601155694574, 3.0770948342978954, 42.70041771233082, 59.3243470788002, 41.15630216896534, 36.59750439226627, 33.27543005347252, 44.4457932561636, 5.488615008071065, 18.53107362985611, 71.9553405046463, 74.52962636947632, 44.41579386591911, 57.61948876082897, 51.994133815169334, 50.68425290286541, 0.5904737091623247, 0.3920219064457342, 0.25303726899437606, 0.7256171386688948, 0.7245105074252933, 6.850429633632302, 63.47099617123604, 55.96223048865795, 67.65321135520935, 61.575361490249634, 65.10711997747421, 62.4744388461113, 66.56200870871544, 62.40722805261612, 63.87543126940727, 61.02641634643078, 60.88594548404217, 62.43315026164055, 65.88059887290001, 57.6695092767477, 49.88419443368912, 58.059425354003906, 50.81275820732117, 58.36297206580639, 63.43452572822571, 62.49931611120701, 64.8897336423397, 57.62132406234741, 58.9556984603405, 61.014450788497925, 58.37570898234844, 60.38112357258797, 60.11243999004364, 58.57774794101715, 54.32902492582798, 48.76983962953091, 47.34878048300743, 50.54600492119789, 46.00950434803963, 46.14905945956707, 43.86113002896309, 48.43560956418514, 44.242112785577774, 45.148048773407936, 43.173568323254585, 44.78514164686203, 48.16947944462299, 50.08111886680126, 48.93434040248394, 50.01437544822693, 49.411606192588806, 47.27632977068424, 47.27493904531002, 44.34333935379982, 49.37152214348316, 54.81692634522915, 50.24045191705227, 32.67457589507103, 41.93141117691994, 46.07646815478802, 38.27067621052265, 41.2165517359972, 43.51952075958252, 47.267088666558266, 47.598639875650406, 49.70820687711239, 49.8812609910965, 45.195021852850914, 39.58540566265583, 40.21757014095783, 44.407571107149124, 46.01595260202885, 44.11281332373619, 48.41116927564144, 48.398078978061676, 48.422431871294975, 46.78991787135601, 45.55103234946728, 43.89797665178776, 45.696678534150124, 43.96648697555065, 45.106182619929314, 42.23505288362503, 46.49607963860035, 46.028427332639694, 46.46568886935711, 45.738046914339066, 48.5178979486227, 48.826255202293396, 52.18926854431629, 51.770314425230026, 52.58070454001427, 53.847780749201775, 54.06729876995087, 52.476282343268394, 55.98553083837032, 53.96998219192028, 57.17794485390186, 56.68076433241367, 56.29043407738209, 56.81672863662243, 57.4889999628067, 56.14471569657326, 57.4080491065979, 47.56997421383858, 55.23251384496689, 60.79949252307415, 59.78165253996849, 57.74927079677582, 58.24468821287155, 54.17135998606682, 60.30683375895023, 57.593216970562935, 62.92895145714283, 57.98459976911545, 63.09608928859234, 59.10660356283188, 59.29103426635265, 5.3276575449854136, 2.8839063132181764, 0.17901339655509219, 1.0864650132134557, 0.20844293612753972, 17.230559214949608, 62.203323394060135, 50.53407356142998, 59.64891046285629, 53.823823034763336, 51.593939289450645, 60.644027665257454, 7.435335572808981, 33.16492058336735, 36.911082565784454, 28.79141416400671, 43.85031580924988, 16.476233191788197, 47.790681570768356, 52.86128148436546, 17.128677181899548, 0.15824494301341474, 0.3303789719939232, 0.08942371874582022, 0.014966251164878486, 0.09360386553453282, 0.06129111934569664, 0.050759008518070914, 0.06529491700348444, 0.040647264977451414, 0.040944662105175667, 0.14372607052791864, 0.04184254947176669, 0.06790053070290014, 0.05337435177352745, 0.09173625090625137, 0.041528454021317884, 0.07549107613158412, 0.044138349912827834, 0.0714297397644259, 0.014932248741388321, 0.27095888857729733, 0.2107003118726425, 4.630749765783548, 50.47622926533222, 73.30377414822578, 36.57092101871967, 42.33076594769955, 43.984327018260956, 39.737173318862915, 8.966236375272274, 20.572316497564316, 76.20902985334396, 78.93320247530937, 48.29646863043308, 65.44315874576569, 58.264336958527565, 55.78940436244011, 0.825330438092351, 0.24607340048532933, 0.5887370242271572, 1.473620894830674, 1.1700927070342004, 8.833651039749384, 68.69038090109825, 60.48892758786678, 70.54474979639053, 64.0795487165451, 69.06234294176102, 65.93330204486847, 67.90132284164429, 64.71769407391548, 65.36377340555191, 63.1515397131443, 63.52296598255634, 63.838550448417664, 68.02845641970634, 58.93277809023857, 50.93676455318928, 59.77649241685867, 52.23940685391426, 60.98608911037445, 64.5379789173603, 63.46245042979717, 65.21621212363243, 61.43252715468407, 61.38851411640644, 63.98773804306984, 59.227957651019096, 62.610627338290215, 60.750163570046425, 61.625792384147644, 57.37147606909275, 51.38390555977821, 49.78338964283466, 52.01526068150997, 49.06241253018379, 50.50256945192814, 46.29649914801121, 50.1805367320776, 47.717816680669785, 47.78801031410694, 47.01611593365669, 48.34734410047531, 51.34726032614708, 52.31659211218357, 52.13863626122475, 52.086514458060265, 53.59876491129398, 48.028385415673256, 50.994061678647995, 49.34626869857311, 51.49496600031853, 57.1580795198679, 54.10095736384392, 37.499108612537384, 44.67863716185093, 48.06104086339474, 42.578098475933075, 45.213709250092506, 51.14094279706478, 53.19185234606266, 54.51171912252903, 54.06013235449791, 54.70998488366604, 49.13875423371792, 46.12170472741127, 44.99648630619049, 48.90333026647568, 50.59416353702545, 49.612444415688515, 52.11429476737976, 53.79207953810692, 52.248834148049355, 50.30692555010319, 47.90112644433975, 48.30338045954704, 49.15058679878712, 47.85372778773308, 47.62501426041126, 44.395411759614944, 48.32179807126522, 48.138207122683525, 48.60402412712574, 49.33257803320885, 50.09815335273743, 49.069533348083496, 54.14551757276058, 51.78977698087692, 53.836324363946915, 53.985454961657524, 55.692802146077156, 54.1444194316864, 56.970985159277916, 55.70169746875763, 58.359753638505936, 58.71798701584339, 57.92855657637119, 55.81789903342724, 58.53325612843037, 55.67507229745388, 58.81434604525566, 46.07018709182739, 56.004465222358704, 62.592962086200714, 61.99927054345608, 58.090553283691406, 60.2161668241024, 57.83719427883625, 64.68870922923088, 59.32007610797882, 66.46534949541092, 59.76950079202652, 66.6232006251812, 60.065976083278656, 61.83657847344875, 6.542979581281543, 2.8894250420853496, 0.4395701503381133, 1.4721135632134974, 0.09833878255449235, 22.586132436990738, 65.75303211808205, 55.22424168884754, 64.18909683823586, 58.902596309781075, 56.59603267908096, 62.981726825237274, 9.154963698238134, 36.25833839178085, 39.10457946360111, 26.8110079318285, 54.89859536290169, 15.78117448836565, 49.9854552000761, 58.55662487447262, 12.780171521008015, 0.5096911720465869, 0.27152229740750045, 0.08203846620745026, 0.040856639679986984, 0.08451254907413386, 0.12268343052710406, 0.029876329172111582, 0.06413203838746995, 0.08563968585804105, 0.1616526476573199, 0.3103403019485995, 0.18933530518552288, 0.2422389609273523, 0.1997654783190228, 0.24616772745503113, 0.14650364726549014, 0.1984354606247507, 0.12352663645287976, 0.4162471799645573, 0.2411482561728917, 0.6177598668728024, 0.8150500303599983, 9.338251613080502, 71.93143218755722, 83.46623003482819, 56.75177492201328, 45.654155015945435, 56.99355214834213, 50.771184638142586, 10.500864777714014, 26.462458334863186, 85.21296590566635, 78.45458015799522, 57.05264277756214, 67.67357066273689, 64.55802664160728, 61.18698053061962, 0.9683468076400459, 0.6313344009686261, 2.3086520936340094, 2.1328186662867665, 0.9851261135190725, 10.148436538875103, 69.28642451763153, 65.89641362428665, 72.49741181731224, 66.84136971831322, 71.87068864703178, 67.04478040337563, 70.68333595991135, 68.0038033425808, 68.17046239972115, 65.78705549240112, 66.96645900607109, 67.0502445101738, 71.84177979826927, 60.94601646065712, 49.93001997470856, 61.80331125855446, 50.51083020865917, 62.65609569847584, 68.41580003499985, 66.61113247275352, 68.4911347925663, 61.57899409532547, 63.25270548462868, 67.17438384890556, 60.46757273375988, 65.43979212641716, 64.42206233739853, 64.83833000063896, 61.70016199350357, 55.36310523748398, 52.853127121925354, 56.28181234002113, 51.94501005113125, 54.40616838634014, 48.954521119594574, 53.8625543564558, 49.52846132218838, 50.7047376036644, 48.16146947443485, 51.4939134567976, 54.479789435863495, 55.85221119225025, 54.93806004524231, 56.24228686094284, 55.96349582076073, 50.60220010578632, 56.63891337811947, 54.723394364118576, 55.617296397686005, 64.20966133475304, 58.39943490922451, 37.87749230861664, 49.56769801676273, 54.26605090498924, 43.61480824649334, 49.95887942612171, 55.58331102132797, 58.47815528512001, 57.87598259747028, 60.883866995573044, 61.593798100948334, 55.85265576839447, 50.14166481792927, 49.34337705373764, 53.30692917108536, 53.67579057812691, 50.3462952375412, 56.99078589677811, 57.50836752355099, 55.33605448901653, 53.708571419119835, 50.89032344520092, 48.640498369932175, 51.25576123595238, 48.34431566298008, 50.12092553079128, 44.96659331023693, 52.25437045097351, 49.92487125098705, 51.99037581682205, 51.23130954802036, 54.25873249769211, 51.36655569076538, 57.82061196863651, 54.02864344418049, 58.394654765725136, 57.04664669930935, 58.15815545618534, 55.1121287047863, 58.64050157368183, 57.14340090751648, 61.19436353445053, 60.73952414095402, 60.11521764099598, 58.780417665839195, 60.51757425069809, 58.30515056848526, 60.23313671350479, 46.00568175315857, 57.386185079813, 65.40747106075287, 65.60616999864578, 60.038834139704704, 64.50447991490364, 60.38874216377735, 65.40592834353447, 61.64797179400921, 69.95377510786057, 61.08647212386131, 69.62050259113312, 62.97612592577934, 67.13899254798889, 14.172140378504992, 4.377369387075305, 0.7254912704229355, 3.9834345504641533, 0.7504436408635229, 23.567724265158176, 72.35508665442467, 60.70337288081646, 70.47237128019333, 65.02721026539803, 60.89512579143047, 71.34361892938614, 11.695318333804607, 44.47540886700153, 44.663764759898186, 42.31436222791672, 65.95057591795921, 24.8329708725214, 65.77395379543304, 68.57802093029022, 31.733738780021667, 0.9507876529823989, 0.5799583077896386, 0.39227738336194307, 0.29018143366556615, 0.2737128204898909, 0.3293323062825948, 0.19246765819843858, 0.2271635370561853, 0.1664374815300107], [0.07904604513896629, 0.019772085033764597, 0.09670616156654432, 0.10316610438167118, 0.010172667371080024, 0.09282092200010084, 0.021176037334953435, 0.11116120935184881, 0.06865297938929871, 0.08380862200283445, 0.05387103039538488, 0.16883196163689718, 0.06905067406478338, 0.9060594812035561, 22.958694845438004, 54.95346441864967, 45.6934867054224, 39.04553823173046, 32.59138695895672, 59.86325316131115, 13.647611774504185, 7.141187181696296, 58.56851823627949, 77.63651445508003, 62.822416573762894, 46.416720896959305, 44.94397692382336, 57.891265377402306, 15.29699306935072, 0.5004057171754539, 0.14233748253900558, 0.8116398914717138, 2.898175735026598, 0.1534496300155297, 31.645915992558002, 60.40841370820999, 57.692577838897705, 68.58319625258446, 61.52726747095585, 64.57729160785675, 65.84605872631073, 66.41481220722198, 66.14371955394745, 63.40981565415859, 64.39051643013954, 63.58533963561058, 62.03108623623848, 56.196157336235046, 55.16081169247627, 60.93941241502762, 61.23506315052509, 59.1015612334013, 60.352875888347626, 63.95959675312042, 60.576189905405045, 62.76960700750351, 54.982312470674515, 59.97415781021118, 59.800666719675064, 56.540852040052414, 57.42510639131069, 61.09849087893963, 54.232403710484505, 48.46160776913166, 49.52043995261192, 48.296958804130554, 46.65353178977966, 44.36135418713093, 43.03514175117016, 46.1140975356102, 39.249750673770905, 44.494901821017265, 41.35219685733318, 44.364755004644394, 44.18069288134575, 48.91631796956062, 49.994289726018906, 53.18782836198807, 49.647938311100006, 49.275721684098244, 43.94010119140148, 45.98056510090828, 49.08447414636612, 52.03349210321903, 51.64195731282234, 20.518513284623623, 27.85710509866476, 46.0918041318655, 37.7459167689085, 41.7683657258749, 44.13555130362511, 45.88549040257931, 47.82820835709572, 51.70519731938839, 49.662799313664436, 48.13483290374279, 40.95546394586563, 38.3278289437294, 41.71300649642944, 47.34408013522625, 48.497447445988655, 49.30611625313759, 48.66986319422722, 49.29289296269417, 45.61715640127659, 44.09108988940716, 41.42718203365803, 43.59367378056049, 43.586480766534805, 42.33486972749233, 43.709328174591064, 44.448483511805534, 45.10552905499935, 48.54055233299732, 46.210813745856285, 48.430886417627335, 50.68530164659023, 52.27791778743267, 50.67153498530388, 52.508781999349594, 57.1551688760519, 54.67867836356163, 56.63837380707264, 59.088934510946274, 55.76326556503773, 57.70350985229015, 54.50863368809223, 59.016381204128265, 57.94722877442837, 57.019785940647125, 55.57729594409466, 52.4237197637558, 50.72654843330383, 54.617060869932175, 60.21034933626652, 58.34794007241726, 59.95113104581833, 57.72402875125408, 61.01670786738396, 60.151118114590645, 60.226802453398705, 60.2861400693655, 65.73729336261749, 61.178632378578186, 59.01155926287174, 18.981594555079937, 2.3262066766619682, 0.8692595839966089, 0.1663579381420277, 0.9567832562606782, 0.2895892591914162, 38.27825300395489, 58.135143890976906, 49.83038932085037, 55.238684713840485, 53.46908167004585, 65.74974909424782, 34.76540610194206, 4.843074297532439, 46.01620338857174, 20.17603386193514, 38.63986819982529, 33.49161185324192, 34.17478859424591, 50.78756935894489, 43.710665702819824, 2.3666315199807286, 0.15459700516657904, 0.1614689512643963, 0.1053665425570216, 0.052279743322287686, 0.10334821257856674, 0.10288143137586303, 0.019372735368961003, 0.06864059294457547, 0.03834372393612284, 0.08462093232083134, 0.09622445577406324, 0.04292544683266897, 0.12196709474665113, 0.022769996139686555, 0.043593665468506515, 0.06296369756455533, 0.032608766632620245, 0.12468472821637988, 0.13266395864775404, 0.07450962293660268, 0.23291654710192233, 0.0920413997664582, 1.2246958957985044, 27.412899434566498, 66.28248810768127, 45.844369009137154, 37.13396720588207, 48.78884620964527, 53.654967695474625, 21.177878603339195, 9.002630822360516, 64.17639032006264, 83.68020415306091, 64.17020425200462, 50.56869350373745, 49.074283093214035, 67.53010556101799, 17.403913512825966, 0.3013059007935226, 0.3701605217065662, 1.2486423295922577, 6.493810694664717, 0.25170152192004025, 37.50068172812462, 64.7153989970684, 61.94366052746773, 71.49738147854805, 63.36669936776161, 67.60919451713562, 69.00596156716347, 69.285459369421, 69.9429152905941, 65.27738124132156, 65.68652048707008, 64.19096633791924, 64.07650128006935, 56.59675844013691, 56.28722704946995, 61.13051936030388, 61.65288493037224, 61.29992187023163, 62.965649887919426, 64.61425602436066, 62.884227856993675, 64.69123229384422, 57.58685991168022, 63.085617050528526, 61.30036264657974, 59.33505870401859, 59.46929030120373, 62.1486709266901, 55.85598058998585, 49.94382843375206, 51.69768512248993, 50.70867419242859, 47.73064099252224, 46.949129328131676, 45.84510616958141, 46.375842690467834, 42.29132026433945, 45.66692993044853, 45.67571505904198, 45.34369267523289, 48.128791227936745, 51.600319147109985, 51.92895211279392, 54.383396208286285, 54.68061625957489, 51.58257029950619, 48.78188498318195, 49.242682456970215, 54.45593051612377, 54.81884524226189, 57.39340469241142, 24.673064053058624, 35.41208580136299, 50.51097460091114, 40.147239714860916, 43.39844025671482, 48.84387485682964, 52.94936075806618, 55.157692059874535, 55.70726037025452, 55.65948933362961, 52.184066623449326, 44.88148167729378, 44.713329300284386, 47.3593021184206, 52.01979003846645, 50.20005248486996, 51.31794109940529, 51.940925270318985, 54.400837272405624, 50.40852069854736, 46.71320378780365, 47.601820304989815, 48.45057316124439, 46.54513880610466, 46.156799644231796, 45.29125548899174, 46.966665387153625, 47.25565128028393, 49.721323773264885, 48.276162520051, 49.241705909371376, 51.337874829769135, 54.620233699679375, 53.966908156871796, 54.332672730088234, 58.74599531292915, 57.47383117675781, 56.22104600071907, 60.426895916461945, 57.58939057588577, 57.859176099300385, 55.24117358028889, 58.07540349662304, 59.266483783721924, 55.78472301363945, 55.47600857913494, 52.099730148911476, 49.78501595556736, 54.48153354227543, 59.2255599796772, 59.631290808320045, 59.18230690062046, 58.27609732747078, 63.35690349340439, 62.04508848488331, 61.55936814844608, 62.27511674165726, 64.2880131304264, 61.69674977660179, 60.31766317784786, 17.766480557620525, 2.358336327597499, 0.5646872241050005, 0.7544814585708082, 0.33143890730571, 0.45466406852938235, 47.34964303672314, 61.97976998984814, 58.87578874826431, 60.047186091542244, 59.85525079071522, 69.11519050598145, 35.924894884228706, 7.8043636959046125, 51.80941812694073, 19.27589826285839, 41.676023080945015, 40.78048713505268, 27.059436701238155, 59.40096616744995, 51.30967274308205, 2.5004945369437337, 0.13434237014735118, 0.09653559376602061, 0.0955827726284042, 0.0626862382341642, 0.19587770802900195, 0.02487587171344785, 0.03644204101874493, 0.07275835479958914, 0.0680285289126914, 0.1884524166234769, 0.26653497596271336, 0.2472782030235976, 0.23052957752952352, 0.1665945496642962, 0.16322475392371416, 0.11862322964589112, 0.21929976996034384, 0.3602438257075846, 0.20176258287392557, 0.16063795366790146, 0.40664372965693474, 0.2589404006721452, 1.9302301621064544, 49.1088992357254, 75.26084393262863, 62.81769722700119, 49.686757028102875, 58.69010031223297, 68.49309548735619, 21.293460801243782, 10.072319023311138, 74.22862932085991, 84.33376148343086, 70.4394194483757, 58.780527859926224, 56.52429632842541, 72.5106655061245, 18.62720087170601, 0.6650764716323465, 1.216396784875542, 1.353887775912881, 8.108604345470667, 0.16305330296745524, 39.46500912308693, 64.30073484778404, 67.90829166769981, 70.52338734269142, 68.58667686581612, 69.08184349536896, 72.59059801697731, 72.8235711157322, 74.63947847485542, 66.61657378077507, 68.54440033435822, 67.1014353632927, 66.89446046948433, 57.33105383813381, 52.63400427997112, 62.93704882264137, 64.8991571366787, 63.85659947991371, 65.11553272604942, 67.2513373196125, 66.15780159831047, 69.7173821926117, 60.88781498372555, 67.16645747423172, 64.21747371554375, 62.33127012848854, 63.805879801511765, 66.27732038497925, 59.727984219789505, 52.605228424072266, 55.65111078321934, 52.6955533772707, 50.162354707717896, 50.2618295699358, 47.6151005923748, 51.34061448276043, 42.699710950255394, 49.87257845699787, 45.5525066703558, 50.09226366877556, 48.49000744521618, 54.31189924478531, 54.51398380100727, 59.69497539103031, 58.55316326022148, 57.57603049278259, 49.92698013782501, 54.971361458301544, 59.400103613734245, 60.90733453631401, 63.0018163472414, 21.839649192988873, 35.05477197468281, 54.8311185836792, 42.77616664767265, 47.36901439726353, 53.240075558423996, 57.90579579770565, 60.04514180123806, 63.50436598062515, 59.91276830434799, 58.2641925662756, 48.760963305830956, 47.8570070117712, 51.22480429708958, 56.69575072824955, 54.01126317679882, 56.467105597257614, 54.92388300597668, 56.42329014837742, 51.48255966603756, 48.70178148150444, 47.47893489897251, 48.19559924304485, 47.54157833755016, 47.420627027750015, 45.851144045591354, 49.016028419137, 45.56637592613697, 53.862265571951866, 48.9549694955349, 51.77613191306591, 53.40723618865013, 55.28832904994488, 54.72816310822964, 56.72428339719772, 60.15881650149822, 57.36549139022827, 57.92131796479225, 62.9542201012373, 58.95317159593105, 61.658892408013344, 55.804356560111046, 61.294526159763336, 61.72459468245506, 57.63664864003658, 57.531337291002274, 54.57796476781368, 48.475211039185524, 55.41779950261116, 61.48823596537113, 63.16078081727028, 62.79897943139076, 61.82061932981014, 67.10098698735237, 65.27547374367714, 63.448440581560135, 66.36793792247772, 66.92759469151497, 65.72523280978203, 65.15074163675308, 31.753359027206898, 3.4132929565384984, 1.70497931772843, 0.9560231782961637, 3.3013298269361258, 0.5900778772775084, 49.8674601316452, 67.20574736595154, 63.5736932605505, 63.183013424277306, 64.93978455662727, 73.78676623106003, 48.706090450286865, 7.685964899137616, 60.9785009175539, 22.4766793102026, 59.62866894900799, 49.56782341003418, 46.21347360312939, 67.9772275686264, 68.47485646605492, 6.808730196207762, 0.602348071988672, 0.4661435791058466, 0.30941980134230107, 0.20756740967044607, 0.33593531290534884, 0.21916737081483006, 0.14223597157979384, 0.17734258464770392, 0.19981282734079286], [0.06672180723398924, 0.07641657881322317, 0.058240729122189805, 0.03904460449120961, 0.05939207105257083, 0.05777998158009723, 0.02769848011666909, 0.035377370804781094, 0.05687342221790459, 0.07027713989373296, 0.014738195677637123, 0.1489031146047637, 0.1455629602423869, 0.6302516371943057, 10.037086363881826, 51.120347902178764, 53.21477651596069, 43.63135255873203, 29.97361622750759, 43.878191113471985, 39.54037427902222, 3.095952747389674, 22.29440689086914, 67.13146135210991, 67.257249802351, 61.082007363438606, 53.145928010344505, 50.2409952878952, 39.88100700080395, 0.12652927689487115, 0.49245399073697627, 0.9000527753960341, 7.1008390467613935, 8.29481240361929, 2.78897553216666, 58.87640431523323, 62.88678891956806, 69.24760580062866, 67.9148805141449, 66.43659263849258, 60.676056146621704, 60.13689547777176, 64.90547239780426, 62.798021882772446, 62.638316452503204, 62.49697923660278, 62.86884628236294, 64.92704764008522, 64.43467766046524, 60.54084040224552, 63.42495784163475, 62.06469163298607, 61.461268812417984, 60.49918323755264, 58.383076786994934, 56.81024618446827, 53.30110788345337, 37.771166414022446, 47.882545441389084, 61.32182389497757, 58.692315593361855, 59.370252415537834, 56.07492484152317, 49.135072231292725, 48.36226209998131, 49.41381387412548, 44.59034129977226, 44.164087772369385, 44.73730981349945, 42.43677645921707, 42.87360481917858, 43.656480610370636, 42.27173611521721, 41.521386578679085, 43.26819084584713, 46.091678738594055, 52.03045226633549, 52.20679320394993, 52.15667389333248, 47.59281858801842, 43.367376923561096, 42.41045907139778, 52.01709218323231, 50.577737018465996, 58.552110716700554, 16.11720185726881, 14.222226440906525, 42.691909968853, 36.33007474243641, 46.21797256171703, 38.539279997348785, 44.22391556203365, 44.88332457840443, 50.80727510154247, 51.20943792164326, 50.73904596269131, 43.59898589551449, 39.75541993975639, 43.84521648287773, 48.197290152311325, 44.98969227075577, 49.18511554598808, 51.03858768939972, 50.852355882525444, 46.98608614504337, 42.81874716281891, 42.22762048244476, 41.55217632651329, 42.34765224158764, 42.586743012070656, 42.79570899903774, 45.61287023127079, 45.19002512097359, 46.985177993774414, 49.765785187482834, 53.054223731160164, 53.879106268286705, 53.0807539075613, 52.56539896130562, 55.08509695529938, 57.95363903045654, 54.32897932827473, 52.52518191933632, 49.46900971233845, 54.65075746178627, 55.6970427185297, 59.02716502547264, 58.67158390581608, 58.725620806217194, 52.55175769329071, 52.97099679708481, 50.481780767440796, 47.38004520535469, 59.19287413358688, 61.87849022448063, 57.6304891705513, 60.851032957434654, 60.53800955414772, 60.073427483439445, 62.582493647933006, 64.93013307452202, 68.22425231337547, 60.175060629844666, 56.576243340969086, 22.984755747020245, 1.5424740314483643, 0.9963076072745025, 0.4782078426796943, 0.7338259450625628, 1.5473025036044419, 6.340574417263269, 57.895844131708145, 51.109784469008446, 52.62044280767441, 52.71808236837387, 60.1640298217535, 45.058540776371956, 3.23057952336967, 16.787109710276127, 48.107823953032494, 18.09654224663973, 43.80690313875675, 23.36045678704977, 30.771068036556244, 55.35651259124279, 31.23399719595909, 0.6571217172313482, 0.06408383589587174, 0.11099784038378857, 0.03732343415322248, 0.13527916831662878, 0.0742227012233343, 0.0984228085144423, 0.11544737193617038, 0.07681994349695742, 0.04048453425639309, 0.02870476742828032, 0.0892657006625086, 0.06547163720824756, 0.021714248396165203, 0.06639144019572996, 0.03344292206747923, 0.03878579904267099, 0.06977350363740698, 0.06588435295270756, 0.08415334217716008, 0.07331711036385968, 0.08414802097831853, 0.23036860569845885, 0.6451622152235359, 13.402599021792412, 65.38818329572678, 58.4639972448349, 40.12959726154804, 48.56466203927994, 43.46031993627548, 42.28573456406593, 3.779330877587199, 22.819882594048977, 75.17929270863533, 75.56198537349701, 66.04364052414894, 62.31144659221172, 58.60339276492596, 46.78943149745464, 0.09408770129084587, 0.47044408740475774, 1.143099192995578, 8.738968670368195, 9.94599100202322, 4.81243179179728, 65.31249135732651, 65.97902119159698, 71.14398524165154, 70.24806171655655, 69.71311882138252, 63.45429226756096, 60.30819408595562, 67.80078023672104, 66.0962601006031, 66.03736326098442, 65.2666126191616, 63.241940662264824, 65.57629600167274, 63.81310701370239, 63.67493122816086, 62.9879204928875, 62.85122662782669, 63.13445582985878, 63.33172224462032, 62.90067717432976, 59.695594757795334, 56.66544735431671, 40.9091292321682, 51.7817822098732, 64.29012581706047, 60.885899886488914, 60.94408616423607, 56.35125741362572, 50.99811606109142, 51.17332845926285, 52.23502568900585, 46.43812894821167, 47.40239940583706, 46.57519519329071, 46.271260902285576, 45.02472639083862, 45.92743255198002, 45.12822903692722, 45.190142914652824, 46.72574691474438, 48.55158694088459, 53.374215960502625, 55.78876219689846, 55.1477137953043, 50.62005914747715, 48.0511461943388, 47.38270506262779, 56.01756311953068, 54.47185926139355, 62.37683728337288, 20.11234737932682, 20.159711837768555, 49.35334771871567, 42.252319157123566, 48.673822581768036, 45.855586007237434, 52.27281466126442, 51.86078377068043, 57.69474372267723, 55.24360544979572, 56.68330639600754, 47.58374087512493, 45.99333241581917, 48.30828599631786, 51.75812087953091, 49.96532768011093, 52.711242735385895, 55.0411257147789, 53.8528610765934, 49.81520153582096, 46.1130677908659, 46.0158272087574, 44.430012702941895, 45.796434581279755, 45.51695957779884, 44.99710187315941, 46.62624545395374, 48.23074735701084, 49.64578002691269, 51.62089504301548, 52.266165018081665, 53.76086801290512, 55.41428089141846, 54.61388424038887, 57.82361760735512, 58.42191830277443, 55.88812306523323, 53.892200365662575, 49.53372783958912, 55.591150000691414, 58.2810028642416, 60.37359617650509, 59.578329250216484, 59.32937040925026, 54.23659108579159, 54.76619526743889, 48.71697686612606, 48.35820011794567, 58.986822590231895, 62.909515500068665, 59.2075489461422, 59.41613495349884, 61.998180001974106, 60.962640568614006, 64.12646099925041, 66.32390588521957, 68.09109225869179, 60.50787337124348, 58.04575748741627, 24.903187304735184, 2.0367925940081477, 1.1558061861433089, 0.5660881020594388, 0.4188729578163475, 0.7256058580242097, 10.441043637692928, 67.35216870903969, 53.990463092923164, 61.3602664321661, 57.54916973412037, 68.77452358603477, 43.3040077239275, 5.359398191794753, 22.31831520795822, 53.43972064554691, 15.429742746055126, 53.173712119460106, 26.432248055934906, 28.70279911905527, 64.15152445435524, 28.530105985701084, 0.7508934417273849, 0.11248938651988283, 0.07372954409220256, 0.06117210854426958, 0.14076034451136366, 0.02262134581542341, 0.10069633339298889, 0.07858442928409204, 0.022199447848834097, 0.007900104501459282, 0.16891459235921502, 0.33680810825899243, 0.14027359953615814, 0.1792777347145602, 0.1391388854244724, 0.15769403195008636, 0.1770230010151863, 0.16176687902770936, 0.25584309187252074, 0.18975547951413319, 0.2115218248218298, 0.2540236129425466, 0.48448492772877216, 0.8592696825508028, 27.4205769225955, 78.72052788734436, 72.86544486880302, 53.76001685857773, 51.80728264153004, 57.21635699272156, 47.61172257363796, 5.986474743112922, 31.58644538372755, 85.41421070694923, 75.20545050501823, 69.0676474571228, 65.47066166996956, 62.25156180560589, 51.13961286842823, 0.37491359165869653, 2.202766975387931, 1.7861060332506895, 10.698963347822428, 8.338075932115316, 7.173480223864317, 64.81385931372643, 67.34485790133476, 78.0813717842102, 71.94638818502426, 72.89290979504585, 68.8503523170948, 65.54712116718292, 70.83596616983414, 66.18550211191177, 68.59376728534698, 67.84818649291992, 68.0616894364357, 66.82412624359131, 65.09721010923386, 64.72134187817574, 67.81449750065804, 66.95075824856758, 66.82864800095558, 67.0322334766388, 64.78977620601654, 62.818491384387016, 57.009461894631386, 39.67693895101547, 55.36037318408489, 64.79303643107414, 63.36404711008072, 63.36044490337372, 61.3727867603302, 53.68803732097149, 53.55760931968689, 56.276291236281395, 49.77637521922588, 48.97976316511631, 48.32319639623165, 48.15225876867771, 48.38715076446533, 47.56235562264919, 47.83379025757313, 46.622434258461, 47.58580036461353, 52.243947610259056, 57.33220137655735, 59.36158888041973, 60.561097115278244, 53.323211297392845, 50.3595033288002, 49.31550554931164, 62.53490500152111, 57.944671511650085, 73.6662594974041, 15.91791395097971, 19.301733076572418, 55.03592759370804, 41.67229548096657, 55.45627623796463, 46.20790310204029, 53.545693159103394, 54.81629557907581, 67.03654244542122, 59.49783816933632, 61.01460658013821, 52.21333645284176, 51.51163570582867, 51.00175626575947, 56.50603450834751, 50.175156220793724, 54.18311655521393, 58.85008692741394, 57.095907256007195, 51.36472798883915, 49.089588671922684, 47.79052957892418, 44.77519378066063, 47.69041635096073, 47.13832877576351, 46.153737008571625, 49.09126058220863, 48.23355160653591, 51.29905991256237, 55.22947020828724, 55.80409437417984, 55.28484083712101, 56.607378870248795, 56.5850018709898, 59.38892841339111, 59.54123184084892, 60.03378041088581, 58.436707109212875, 52.80403755605221, 58.36577631533146, 59.115278497338295, 61.51312842965126, 61.07966288924217, 60.977611765265465, 55.03425948321819, 55.17572209239006, 49.492135271430016, 47.11683712899685, 60.1128313690424, 66.35751128196716, 61.435380801558495, 63.426625952124596, 66.3825823366642, 63.42195600271225, 66.94409340620041, 68.62307891249657, 68.98802652955055, 65.03436148166656, 65.52428439259529, 34.664494916796684, 3.77843982540071, 2.291568685323, 2.5048441160470247, 2.566199186258018, 3.7430224008858204, 8.999199606478214, 71.26630827784538, 60.38710445165634, 65.22120505571365, 61.463138312101364, 70.64545959234238, 54.39133018255234, 8.889333251863718, 22.762232087552547, 63.08123588562012, 23.927544057369232, 70.65683618187904, 33.919826075434685, 45.98662577569485, 70.6009715795517, 52.3007545620203, 1.5495519828982651, 0.20994560705730692, 0.27452484879177064, 0.14595183078199625, 0.18960715387947857, 0.221740753040649, 0.2332823516917415, 0.23759178060572594, 0.16062443173723295, 0.1146906113717705], [0.049437885463703424, 0.10369048366555944, 0.028578092096722685, 0.040741402699495666, 0.021092105998832267, 0.10793730500154197, 0.08590227254899219, 0.13514368183678016, 0.05840960111527238, 0.060560025958693586, 0.10539569411776029, 0.09806116737308912, 0.051929902328993194, 0.38764442258980125, 3.228615028783679, 43.92824962735176, 58.07769477367401, 40.68785570561886, 27.173497080802917, 32.77369737625122, 65.19806429743767, 19.041353948414326, 4.229731634259224, 37.4858283251524, 69.59299206733704, 64.58218574523926, 65.53479462862015, 44.19653043150902, 46.75950050354004, 16.068363077938557, 1.2075369665399194, 0.3682938124984503, 3.835960663855076, 21.94226648658514, 12.958150170743465, 12.630695141851902, 56.98875680565834, 65.75560837984085, 66.92257136106491, 62.19116784632206, 59.37649168074131, 58.328496515750885, 60.01209497451782, 60.946210250258446, 61.14900156855583, 64.05121743679047, 63.49580504000187, 64.54190790653229, 62.22568899393082, 60.38585811853409, 61.69683717191219, 61.31405331194401, 59.926732555031776, 60.452244356274605, 61.295004934072495, 56.37466035783291, 57.195636704564095, 50.06484054028988, 39.541932195425034, 46.94472536444664, 57.51207992434502, 59.86123166978359, 54.54198829829693, 49.19546619057655, 49.910963997244835, 48.147596418857574, 47.03461714088917, 46.26947499811649, 43.66946451365948, 45.44641636312008, 43.142303600907326, 41.18051066994667, 41.694501489400864, 43.01012769341469, 44.22809153795242, 44.59052748978138, 50.09912610054016, 51.075149327516556, 48.52067939937115, 47.35529713332653, 42.20911547541618, 42.81199872493744, 51.364853382110596, 50.54222412407398, 56.52698278427124, 26.716885082423687, 7.922620000317693, 38.17532792687416, 42.33941048383713, 48.24807822704315, 9.06990336254239, 23.351236581802368, 51.691643446683884, 45.39822354912758, 52.84086138010025, 49.39388394355774, 47.57025919854641, 41.40144981443882, 42.77296721935272, 47.32115216553211, 48.74503456056118, 49.30521570146084, 51.496242731809616, 51.913167759776115, 46.88709385693073, 41.51767797768116, 40.78519128262997, 41.7648509144783, 41.31964400410652, 42.73853346705437, 43.04994575679302, 44.22801934182644, 44.741858169436455, 49.26908724009991, 51.40438266098499, 54.804299622774124, 53.54469381272793, 55.318632423877716, 56.76838383078575, 47.844368889927864, 47.846606969833374, 48.27138237655163, 47.94872649013996, 48.283993899822235, 52.67819210886955, 54.854190945625305, 53.39946560561657, 55.41687615215778, 56.325787380337715, 53.08035492897034, 47.78726935386658, 46.82808682322502, 50.48317529261112, 53.403964564204216, 59.06276911497116, 57.8038814663887, 58.74533414840698, 59.219423308968544, 61.29267945885658, 59.97699245810509, 63.28938111662865, 53.334941267967224, 42.359697595238686, 18.085080161690712, 0.32665220322087407, 0.9628602582961321, 0.43511794705409557, 0.6460182974115014, 1.0940196015872061, 13.478263411670923, 41.564529463648796, 52.38591559231281, 50.64326450228691, 53.79800342023373, 54.59515504539013, 49.1215905547142, 15.9593241289258, 5.0025944877415895, 49.16391268372536, 40.2813421189785, 24.631834365427494, 41.08315609395504, 23.176848739385605, 44.47211064398289, 52.371510565280914, 10.278131179511547, 0.4753457650076598, 0.2727273077471182, 0.18590302061056718, 0.05465351750899572, 0.05883859957975801, 0.04849222976190504, 0.10968492919346318, 0.08889053759048693, 0.018356017171754502, 0.039007645536912605, 0.13114504952682182, 0.09061469507287256, 0.06940312741789967, 0.039695857631159015, 0.047995773784350604, 0.0711138074984774, 0.07306999745196663, 0.10904533148277551, 0.009798572064028122, 0.08626332739368081, 0.06019649234076496, 0.0917573130573146, 0.28826954250689596, 0.17306261899648234, 4.97402049601078, 52.62946352362633, 68.66081088781357, 40.89998312294483, 34.05107103288174, 43.70487101376057, 67.26880878210068, 29.03586644679308, 6.259422171860933, 40.17846643924713, 78.84700030088425, 68.0941852927208, 74.39174696803093, 49.451918229460716, 55.49070619046688, 20.55633645504713, 0.4158262041164562, 0.5085848376620561, 2.7299221884459257, 26.80762231349945, 16.19640290737152, 15.266483556479216, 62.67051972448826, 68.79640281200409, 69.36870530247688, 63.495269268751144, 61.9646430015564, 58.028719201684, 62.47896060347557, 62.174137160182, 61.81529201567173, 65.58435156941414, 64.72609922289848, 67.31329679489136, 62.18193434178829, 60.252812057733536, 63.58931042253971, 62.69402526319027, 64.33434024453163, 61.20717264711857, 65.52428439259529, 60.06740860641003, 58.07533510029316, 53.989820927381516, 42.447165101766586, 54.280828312039375, 59.61946964263916, 63.02054174244404, 58.52235071361065, 53.60935494303703, 53.62469471991062, 52.48768173158169, 47.91246123611927, 48.61700043082237, 45.65476678311825, 46.380208656191826, 46.21111012995243, 43.28730762004852, 44.39086340367794, 44.703252241015434, 46.02960146963596, 48.13672140240669, 51.75137624144554, 54.69891607761383, 53.024733513593674, 51.02631814777851, 44.77417163550854, 46.064985170960426, 57.44173049926758, 52.35502704977989, 61.33055202662945, 35.5927737057209, 14.861149806529284, 42.97537475824356, 45.534111857414246, 52.980880066752434, 19.019146040081978, 31.30296729505062, 54.8669620603323, 50.15201926231384, 59.03232894837856, 54.249571189284325, 53.39126944541931, 44.55164037644863, 47.30070926249027, 51.76161289215088, 51.68487221002579, 50.464978069067, 55.484991297125816, 55.94703130424023, 51.23635187745094, 45.38621999323368, 45.41488565504551, 44.977016150951385, 44.65336851775646, 44.73636746406555, 43.6932360380888, 44.44867730140686, 45.93929931521416, 50.55573619902134, 53.55352073907852, 56.28948412835598, 54.81927461922169, 58.2563041895628, 57.089983373880386, 50.47128193080425, 48.299086689949036, 50.99251516163349, 48.14520254731178, 50.673427283763885, 54.961132407188416, 55.788560807704926, 54.89579111337662, 54.60624285042286, 55.98029851913452, 55.25256156921387, 50.19594870507717, 49.15458418428898, 51.30795903503895, 54.26193952560425, 61.015412136912346, 59.12952773272991, 61.01945511996746, 60.95330446958542, 65.36783158779144, 60.06610907614231, 62.98006251454353, 52.62864276766777, 47.21991799771786, 19.546749629080296, 0.8833955973386765, 1.2106162263080478, 1.0247810231521726, 0.11244036024436355, 2.8272033808752894, 21.19435641914606, 49.607041105628014, 57.698889300227165, 57.597050964832306, 61.01900674402714, 59.34227831661701, 55.4162871837616, 17.594684176146984, 7.542186789214611, 58.133350387215614, 43.163407668471336, 25.64057193696499, 50.78879289329052, 24.14657760411501, 43.24532367289066, 62.565899938344955, 9.022988229990005, 0.3018406330375001, 0.20833952527027577, 0.14088946336414665, 0.10896204024902545, 0.14269513834733516, 0.04046333480800968, 0.01602937492862111, 0.07122366761905141, 0.0438205437239958, 0.01645924727199599, 0.15396983100799844, 0.2338983045774512, 0.11564546599402092, 0.2873381768586114, 0.2098797043436207, 0.1952200019150041, 0.15491082973312587, 0.3625356371048838, 0.11582269828068092, 0.45019832847174257, 0.24879929405869916, 0.2646628045476973, 0.6099268840625882, 0.6510856817476451, 13.519578594714403, 68.16209524869919, 78.66454169154167, 55.24263270199299, 40.45699529349804, 51.03810511529446, 73.53292465209961, 26.88870996236801, 6.768927332013845, 50.004176795482635, 85.07043555378914, 72.37719386816025, 80.6650659441948, 51.97128564119339, 66.78222969174385, 23.275455348193645, 1.3549250015057623, 1.1054459447041154, 5.0380755588412285, 30.802693739533424, 15.910988822579384, 18.645684979856014, 65.33736482262611, 66.70927360653877, 74.21299695968628, 61.23614229261875, 60.45964635908604, 61.975582614541054, 68.5973770916462, 62.26711817085743, 63.735735565423965, 70.73712587356567, 70.05535125732422, 72.79679015278816, 61.845249608159065, 63.4517578035593, 66.73478543758392, 66.93566545844078, 66.9919328391552, 64.77923557162285, 69.47032704949379, 60.6158559769392, 61.95836953818798, 50.51758624613285, 43.41649688780308, 55.58003559708595, 62.03713171184063, 65.93340083956718, 61.32650524377823, 54.49000708758831, 56.05336859822273, 53.48440244793892, 51.490812823176384, 51.25441990792751, 47.43721693754196, 49.63056944310665, 48.31891022622585, 44.66478310525417, 45.95273919403553, 46.30974903702736, 49.645810425281525, 47.674631997942924, 55.98769672214985, 57.65839107334614, 57.533389180898666, 55.7730158418417, 48.812370747327805, 51.59214958548546, 63.813297003507614, 55.470780059695244, 67.42897778749466, 29.535083658993244, 8.784394282847643, 48.72889302670956, 49.54261176288128, 58.71470779180527, 14.208736214786768, 30.132639594376087, 61.000995710492134, 52.23192125558853, 65.78632593154907, 60.669136717915535, 56.86283156275749, 50.82522913813591, 52.364959716796875, 55.04683680832386, 55.66366530954838, 53.639000952243805, 58.19777972996235, 56.799925938248634, 53.0152378231287, 46.557199358940125, 46.07709512114525, 47.92995549738407, 48.14050979912281, 48.45056176185608, 45.27378782629967, 45.868440717458725, 45.86531728506088, 54.255719259381294, 58.90591353178024, 58.92933167517185, 57.204376235604286, 58.190522119402885, 59.325627610087395, 51.34757190942764, 50.69920130074024, 49.77203585207462, 48.93796160817146, 52.271499931812286, 57.53599964082241, 56.423088759183884, 56.00087061524391, 56.94728583097458, 59.19239155948162, 54.77741986513138, 50.96513383090496, 47.30052687227726, 52.76650317013264, 55.718994140625, 59.406141489744186, 63.24115790426731, 63.08058612048626, 64.30659413337708, 67.55147561430931, 60.621844455599785, 66.21451735496521, 59.262026622891426, 54.36436302959919, 25.583434402942657, 2.2839401196688414, 1.804697485640645, 3.009162792004645, 1.1608266667462885, 2.928906111046672, 18.030401095747948, 53.75190049409866, 65.12758567929268, 62.59966492652893, 63.72937470674515, 65.62694728374481, 59.999920427799225, 24.21894282102585, 9.158878438174725, 61.23809538781643, 49.83018793165684, 36.21405936777592, 60.05936063826084, 33.7163507938385, 56.70832425355911, 70.9934601187706, 23.97478312253952, 1.31210973020643, 0.6840685056522489, 0.5448972329031676, 0.23829245707020164, 0.3459310031030327, 0.17679673503153026, 0.33885417971760035, 0.17770270438631997, 0.17238263360923156, 0.2428730667452328], [0.03908799044438638, 0.029837088113708887, 0.03561261677532457, 0.030180659814504907, 0.025055484438780695, 0.026280104175384622, 0.022028384664736222, 0.1648409734480083, 0.02299017465702491, 0.2513637556694448, 0.1777809564373456, 0.08086609552265145, 0.10786402533994988, 0.044422662977012806, 0.5404555681161582, 31.998823955655098, 52.31028825044632, 43.99308554828167, 37.077433839440346, 19.658927209675312, 39.80372294783592, 35.66941179335117, 5.46918380074203, 25.33283405005932, 65.89646682143211, 68.36632668972015, 58.51684480905533, 56.56490094959736, 47.346751391887665, 71.7366774380207, 27.133566923439503, 1.7485642852261662, 0.14900738635333255, 14.840484615415335, 28.875499852001667, 6.246707579120994, 15.452176742255688, 47.59001053869724, 61.708080768585205, 60.64407706260681, 59.419277384877205, 60.13066381216049, 65.73861569166183, 66.0878549516201, 64.77049604058266, 64.00203287601471, 59.73813347518444, 60.93440428376198, 60.13925515115261, 60.08129306137562, 60.51839500665665, 60.169889107346535, 58.61494414508343, 60.77750690281391, 60.549367144703865, 61.0472696274519, 58.8848664611578, 60.70609353482723, 53.75067315995693, 44.19791355729103, 58.12798127532005, 57.321949526667595, 58.23899991810322, 48.825464844703674, 49.512380585074425, 47.23681569099426, 43.85075658559799, 44.3782214820385, 44.17879298329353, 42.94169716536999, 42.33369559049606, 42.898888662457466, 44.26526494324207, 43.13346907496452, 43.05832430720329, 43.270098343491554, 44.405127838253975, 47.71094284951687, 48.36519554257393, 44.349620416760445, 42.999594658613205, 40.89801862835884, 50.492515191435814, 51.35314241051674, 54.6973467618227, 36.25844858586788, 8.859487753361464, 32.39215984940529, 34.96089421212673, 41.032565608620644, 4.914567936211824, 26.38910137116909, 53.435829654335976, 46.7469497770071, 52.47974395751953, 52.937421798706055, 49.009412974119186, 42.15354725718498, 42.27658465504646, 47.237761840224266, 47.50263802707195, 46.61306396126747, 50.37205025553703, 51.0484329611063, 45.43977051973343, 41.33644290268421, 40.146012380719185, 40.47731660306454, 41.598640233278275, 42.79477804899216, 43.720005601644516, 44.6088083088398, 45.071771666407585, 49.2585352063179, 52.445181012153625, 56.62231966853142, 53.98877218365669, 52.43327625095844, 46.88596531748772, 47.70463518798351, 51.359921246767044, 52.63930879533291, 54.356109872460365, 55.44001691043377, 57.12023355066776, 57.1524254232645, 52.94113039970398, 52.14242085814476, 53.46323378384113, 50.390642657876015, 51.14383824169636, 41.57373636960983, 48.744335398077965, 54.20647390186787, 56.71463191509247, 57.10219971835613, 59.92766730487347, 62.170515954494476, 59.976414889097214, 57.35541433095932, 46.76331549882889, 25.782539919018745, 10.07860578596592, 3.144407272338867, 3.453965736553073, 0.808167471550405, 0.825290362117812, 1.6761738946661353, 29.580584317445755, 58.03611360490322, 52.579082027077675, 55.6297293305397, 53.92795264720917, 53.4210180491209, 57.33539320528507, 38.23712781071663, 18.39983057230711, 9.323025830090046, 44.47401814162731, 36.81643344461918, 29.2415589094162, 34.35791216790676, 25.165743716061115, 49.2837468534708, 42.71011479198933, 1.7701620887964964, 0.2452349368832074, 0.13921502977609634, 0.04630099792848341, 0.05708067437808495, 0.04566400144540239, 0.09798832557862625, 0.15894649521214887, 0.0840300640265923, 0.04535838132142089, 0.10798237562994473, 0.03560026743798517, 0.058722709509311244, 0.037411163430078886, 0.0869303623039741, 0.036547244162647985, 0.09608421212760732, 0.008325061971845571, 0.06640282474108972, 0.03332600412250031, 0.027276398468529806, 0.05160472290299367, 0.011181791542185238, 0.08274013714981265, 0.011956960152019747, 1.0265284543856978, 36.81984946131706, 63.70724469423294, 43.383993431925774, 30.44265355914831, 29.60549008101225, 43.34107093513012, 44.507695734500885, 7.7763905469328165, 27.131577730178833, 72.41164281964302, 73.73650252819061, 67.28003337979317, 62.40172974765301, 56.46310821175575, 76.00621193647385, 34.406614154577255, 2.3561972798779607, 0.20460328669287264, 15.989515408873558, 33.56240205466747, 13.419511914253235, 23.05806141346693, 53.242982402443886, 63.50015200674534, 60.35530015826225, 61.86880834400654, 61.39016702771187, 65.72142541408539, 67.17125281691551, 67.3842541873455, 67.4420414865017, 63.72080236673355, 63.95514339208603, 62.307924181222916, 62.85902760922909, 61.696992963552475, 62.180608212947845, 60.03500014543533, 61.503313556313515, 63.449246138334274, 66.83633118867874, 61.32884971797466, 62.49246507883072, 59.067325070500374, 49.66212294995785, 61.4523620903492, 58.85865166783333, 59.887963235378265, 51.69175744056702, 51.933386474847794, 50.76457679271698, 48.24922576546669, 46.07095085084438, 47.09556207060814, 45.33782958984375, 43.36095906794071, 44.12811130285263, 46.147630736231804, 45.45255683362484, 45.75098901987076, 46.979295909404755, 46.93151347339153, 47.8106115013361, 49.42565403878689, 49.522233456373215, 44.749165177345276, 46.06246970593929, 53.78476873040199, 56.73065945506096, 55.676645413041115, 58.46444562077522, 19.1707731038332, 37.08078905940056, 44.35839794576168, 45.115188136696815, 8.758554719388485, 28.00901334732771, 59.904032573103905, 50.13115078210831, 58.9098197221756, 55.86776755750179, 54.66236963868141, 44.253895953297615, 47.589353173971176, 49.607968255877495, 52.385231629014015, 51.82453751564026, 53.69538612663746, 53.62135469913483, 48.60880807042122, 45.95292918384075, 41.8869611620903, 43.90986241400242, 43.92897538840771, 44.35532011091709, 46.97895772755146, 46.0507283359766, 46.56312324106693, 48.97633574903011, 54.36675690114498, 59.51871804893017, 54.62445147335529, 54.69202324748039, 49.84380640089512, 47.264713793992996, 50.496554374694824, 53.2120368629694, 55.752990916371346, 56.50699205696583, 57.589170187711716, 55.88743910193443, 55.78017845749855, 55.23470252752304, 55.84662929177284, 52.8288996219635, 52.91476361453533, 44.86491836607456, 51.59468024969101, 55.346861109137535, 60.45081563293934, 58.72994117438793, 64.10952910780907, 63.465410470962524, 59.05247166752815, 57.536398619413376, 49.293945506215096, 28.667799197137356, 13.806220963597298, 5.762467738240957, 5.30227585695684, 1.1795337754301727, 0.7596305385231972, 3.2269856287166476, 39.82654072344303, 62.41288214921951, 57.369078397750854, 59.52827453613281, 58.559022545814514, 58.52021902799606, 65.53124561905861, 38.530225083231926, 18.056063018739223, 14.152042306959629, 44.804121628403664, 42.944585010409355, 30.690649151802063, 40.86023725569248, 24.281358271837234, 54.307487681508064, 44.4299291074276, 2.8729944862425327, 0.24643714190460742, 0.14024121221154928, 0.03673166786029469, 0.050273469532839954, 0.09115526801906526, 0.08469844222418033, 0.22088343888754025, 0.0597928196657449, 0.03641603245341685, 0.06644709385000169, 0.1340667810291052, 0.23168703104602173, 0.1747045762022026, 0.18079346744343638, 0.1547095295973122, 0.2084646513685584, 0.2810503158252686, 0.22736514889402315, 0.21627685404382646, 0.4544398805592209, 0.2204575648647733, 0.12580762733705342, 0.23332720709731802, 0.13204341928940266, 2.0656921807676554, 63.68270941078663, 72.42430374026299, 63.57945375144482, 46.84332400560379, 38.5293435305357, 49.39224623143673, 43.83123703300953, 9.782709963619709, 34.39271830022335, 80.5151715874672, 76.76022067666054, 72.45140388607979, 66.10214978456497, 62.561655566096306, 80.42609676718712, 35.763886123895645, 1.9996795104816556, 0.29464254272170365, 22.898789159953594, 37.02470786869526, 19.51842974871397, 27.217614613473415, 56.688261330127716, 65.36114394664764, 61.03842370212078, 63.19635450839996, 65.03452867269516, 74.69506189227104, 73.67695212364197, 72.0015536248684, 73.19048702716827, 72.34485760331154, 69.42281439900398, 63.615905195474625, 64.3313156068325, 66.87777936458588, 68.14862877130508, 63.10615114867687, 64.1305647790432, 66.94803759455681, 70.35440281033516, 65.83076074719429, 65.49360483884811, 56.41171596944332, 49.77336198091507, 65.54640680551529, 59.614020735025406, 63.05955044925213, 54.220339357852936, 52.68932931125164, 52.25263014435768, 49.119781851768494, 47.40947462618351, 49.040806889534, 48.96780900657177, 46.33737735450268, 45.89798413217068, 49.84602548182011, 45.56220754981041, 47.15247541666031, 46.813092827796936, 48.472562581300735, 50.583052933216095, 54.55575495958328, 50.837513878941536, 50.507368594408035, 49.978588968515396, 59.33522589504719, 61.648028790950775, 60.30791290104389, 54.68861483037472, 9.110104255378246, 35.91392107307911, 46.12499535083771, 48.0409437417984, 8.70336838066578, 30.0535886362195, 65.77728241682053, 54.65399868786335, 64.41817134618759, 60.95589593052864, 57.490519881248474, 48.680210039019585, 50.09968087077141, 51.422169506549835, 52.31303170323372, 51.59872703254223, 56.21313102543354, 54.85129550099373, 48.44863906502724, 46.761632189154625, 43.853606432676315, 44.7594778239727, 45.86980864405632, 45.97523018717766, 49.18485336005688, 49.3252482265234, 48.60799491405487, 51.86822757124901, 56.84776537120342, 61.06566444039345, 57.52251796424389, 53.97778697311878, 54.101382941007614, 49.36520308256149, 49.55385535955429, 54.78585161268711, 56.65290042757988, 59.80716057121754, 60.90196542441845, 58.460015058517456, 56.42954081296921, 54.76536311209202, 58.05608533322811, 51.80790200829506, 52.744479551911354, 43.014292269945145, 52.32307456433773, 56.07415348291397, 60.680722296237946, 58.97594757378101, 64.36039924621582, 65.58270245790482, 63.81718039512634, 58.53809326887131, 56.40316262841225, 37.20710568130016, 17.507716342806816, 4.4355224166065454, 4.64706989005208, 1.8138913298025727, 3.346634558402002, 2.927020937204361, 40.43767713010311, 72.51954182982445, 66.30933746695518, 65.79747453331947, 64.12639260292053, 62.39377297461033, 68.29641804099083, 45.28643734753132, 26.892372965812683, 13.396270461380482, 53.08201164007187, 44.745863154530525, 43.54568615555763, 51.10140211880207, 37.91095711290836, 64.91374835371971, 66.62756279110909, 7.475817175582051, 0.3373713686596602, 0.48119929153472185, 0.24971847364213318, 0.4483795916894451, 0.318830530741252, 0.33399533887859434, 0.5034482257906348, 0.2056254615308717, 0.1866624751710333, 0.3751010581618175], [0.05448977375635877, 0.061588423704961315, 0.1101450459100306, 0.07811985225998797, 0.0463590746949194, 0.08996029893751256, 0.025988393754232675, 0.05420786525064614, 0.14515268616378307, 0.24770026240730658, 0.041247276531066746, 0.08498039154801518, 0.05963162147963885, 0.298055739258416, 0.38858329877257347, 14.151590131223202, 53.685290068387985, 55.63740111887455, 44.67649407684803, 36.59126132726669, 28.943962678313255, 40.93364171683788, 10.004372019320726, 17.299229130148888, 67.04736426472664, 74.88037034869194, 59.64161105453968, 59.797353297472, 53.671603202819824, 43.172033205628395, 52.25767247378826, 48.338008001446724, 2.3108633374795318, 0.5901246622670442, 22.67573542892933, 15.01233134418726, 11.76852710545063, 26.23343512415886, 43.58926601707935, 55.51903747022152, 56.357979252934456, 62.857044115662575, 68.90418782830238, 64.99094501137733, 60.60499235987663, 61.88667118549347, 59.88427363336086, 58.38393934071064, 59.863644540309906, 56.6145870834589, 56.835632622241974, 57.85080894827843, 57.51877896487713, 61.7408350110054, 59.822344556450844, 61.3668666779995, 60.75698800384998, 60.2404323220253, 60.22266827523708, 57.81569503247738, 60.63424699008465, 56.934917494654655, 60.42978376150131, 51.9980476051569, 48.00405152142048, 49.81604129076004, 46.389031782746315, 43.914361372590065, 44.5529019087553, 43.63502316176891, 41.53779789805412, 42.41626515984535, 44.13578309118748, 43.61432187259197, 43.176133185625076, 45.474006682634354, 47.786976769566536, 47.824963331222534, 47.149298787117004, 44.847272112965584, 41.64673425257206, 43.17682474851608, 48.1934105604887, 52.584964111447334, 52.996299639344215, 45.940823033452034, 10.900743920356035, 21.00852359086275, 39.24495533108711, 34.61173094809055, 15.739652216434479, 42.29487307369709, 49.39596623182297, 50.6306491792202, 53.54070782661438, 51.12126745283604, 49.07909743487835, 41.093305349349976, 41.7276357114315, 44.63279262185097, 48.878760784864426, 51.21941618621349, 50.30735492706299, 48.06110545992851, 42.01951324939728, 41.19456231594086, 39.087620973587036, 39.38640654087067, 41.79233483970165, 41.08488120138645, 43.7847351282835, 42.98447147011757, 47.66996584832668, 43.90455409884453, 52.79435947537422, 54.06659960746765, 56.34708143770695, 50.15526808798313, 61.285923421382904, 58.37544299662113, 54.928606152534485, 54.98396918177605, 54.64533135294914, 55.15612654387951, 55.18537737429142, 54.34681937098503, 56.50330625474453, 57.66219846904278, 56.942232102155685, 54.77943755686283, 51.36978171765804, 52.58905649185181, 49.91732105612755, 47.63055056333542, 49.030171260237694, 55.88468424975872, 57.94416233897209, 55.90580351650715, 48.916466161608696, 41.3361769169569, 24.56221830099821, 27.34835609793663, 22.62772500514984, 12.213981002569199, 3.7856136029586196, 0.40477298316545784, 1.7630443582311273, 19.176182113587856, 54.486640468239784, 44.57758918404579, 52.463222444057465, 47.05395810306072, 52.77234725654125, 49.53444220125675, 55.41266217827797, 29.007077291607857, 3.2905236817896366, 16.789665073156357, 66.78029179573059, 35.8230147510767, 36.046043783426285, 33.060095608234406, 28.095739893615246, 52.814110815525055, 19.572396352887154, 0.8802193833980709, 0.07398571862722747, 0.10284528136253357, 0.09522783308057114, 0.288176714675501, 0.025499630137346685, 0.049639022327028215, 0.032148508907994255, 0.021211213279457297, 0.08931481599574909, 0.07168362106312998, 0.09911099463352002, 0.03787400382861961, 0.05413142032921314, 0.03952837345423177, 0.07001194084296003, 0.07503911561798304, 0.07560432786704041, 0.04991513837012462, 0.03328347534989007, 0.10795430018333718, 0.0201708354143193, 0.07512554613640532, 0.14676635270006955, 0.4270204034401104, 0.40694993978831917, 15.180990993976593, 67.50540688633919, 60.85821837186813, 46.92026227712631, 47.59866647422314, 30.788165219128132, 39.66170556843281, 12.159347534179688, 17.165719494223595, 73.14890965819359, 81.9255343079567, 65.74649646878242, 66.73394948244095, 62.07201763987541, 50.518764182925224, 59.33803014457226, 52.75156617164612, 2.542778430506587, 0.24977327382657677, 22.69741516560316, 13.344103060662746, 24.98135481029749, 33.040963634848595, 49.82712149620056, 57.886967808008194, 59.71350699663162, 62.6805055886507, 73.51481482386589, 69.13325473666191, 63.67319472134113, 65.602066218853, 63.46936605870724, 60.835237205028534, 61.975206434726715, 56.81057296693325, 56.90970964729786, 59.64269019663334, 59.70009371638298, 61.4352136105299, 64.82914969325066, 64.07004922628403, 65.91573178768158, 59.29851986467838, 63.61848145723343, 61.57687000930309, 62.54915803670883, 60.714301094412804, 60.97453773021698, 55.56033365428448, 49.055048525333405, 51.92350700497627, 47.47842952609062, 47.81053550541401, 45.467543229460716, 45.3906961530447, 42.879996076226234, 45.04924647510052, 45.3798021376133, 45.844190418720245, 44.71664272248745, 49.818651750683784, 51.54016077518463, 50.06306603550911, 49.02142032980919, 47.79181011021137, 46.32852002978325, 46.407004818320274, 52.301271334290504, 56.21199868619442, 54.01720605790615, 61.524588614702225, 39.773514568805695, 36.458526849746704, 40.94465732574463, 38.25997978448868, 26.497904732823372, 59.12067420780659, 52.48771972954273, 54.07712124288082, 57.86607652902603, 55.602864772081375, 53.72581489384174, 46.5656691044569, 46.95836663246155, 51.995171159505844, 53.47902953624725, 54.188782051205635, 52.00794607400894, 52.202366441488266, 45.26127889752388, 44.0399332344532, 43.768901377916336, 43.63090418279171, 43.17281976342201, 43.25940951704979, 46.73628754913807, 43.83081525564194, 48.53194199502468, 44.623084142804146, 55.06313033401966, 55.29013395309448, 59.55109231173992, 50.64138360321522, 61.88132867217064, 58.206960037350655, 55.177234411239624, 56.79002366960049, 56.100037693977356, 56.76414705812931, 56.692281514406204, 55.646642223000526, 58.465999737381935, 59.9244374781847, 57.98199310898781, 57.69203446805477, 54.55712288618088, 53.316204473376274, 51.425547525286674, 50.488897785544395, 53.10420244932175, 57.229337096214294, 61.79538108408451, 57.02424310147762, 54.299067333340645, 47.53684379160404, 30.70498388260603, 30.97306899726391, 32.41404287517071, 12.381110284477472, 4.055563705042005, 0.699757804395631, 1.7319369711913168, 22.744010165333748, 61.70320563018322, 49.41270433366299, 62.02616550028324, 50.71562021970749, 63.56242686510086, 52.23458871245384, 62.37485758960247, 23.827244639396667, 6.725378818809986, 21.025924757122993, 60.62639661133289, 44.7296342253685, 37.30096824467182, 45.580066591501236, 26.430353857576847, 63.206955939531326, 23.055238164961338, 1.3506999844685197, 0.04936775250826031, 0.11200561755686067, 0.13203026843257248, 0.07870283152442425, 0.011423154664953472, 0.09775219645234756, 0.1270018913783133, 0.017991607819567434, 0.01351682376480312, 0.032795843508210965, 0.19619758852059022, 0.1696500161779113, 0.23587247676914558, 0.15551875258097425, 0.17168216494610533, 0.20234458992490545, 0.12672085489612073, 0.13339840283151716, 0.2112249212223105, 0.5679616390261799, 0.22135088802315295, 0.222712209506426, 0.2522334340028465, 0.9958948544226587, 0.6717990827746689, 30.750161558389664, 79.35168921947479, 73.26018288731575, 57.371776252985, 54.229230880737305, 41.74918815493584, 51.003572568297386, 15.072864945977926, 22.739693596959114, 83.9522847533226, 85.99125534296036, 69.3285870552063, 71.61902815103531, 66.67316034436226, 52.780383825302124, 61.514530554413795, 54.22216705977917, 2.2198919439688325, 1.8512464128434658, 30.18719706684351, 19.268648251891136, 37.3495714366436, 39.507726430892944, 53.42429347336292, 60.456446930766106, 59.32527042925358, 67.41810277104378, 78.4640720486641, 73.61702173948288, 65.25355651974678, 72.67474070191383, 66.8243770301342, 67.69634664058685, 63.15046817064285, 62.80935287475586, 60.90653657913208, 62.31639392673969, 62.73351654410362, 67.32710525393486, 68.36409240961075, 70.23898780345917, 67.2787718474865, 63.44097398221493, 64.02271136641502, 60.78995883464813, 65.51921546459198, 61.838508769869804, 62.13569462299347, 57.71911181509495, 50.756460428237915, 55.293994545936584, 50.968903228640556, 50.63354082405567, 51.217444092035294, 50.51496438682079, 45.96062757074833, 48.016036078333855, 46.61356933414936, 47.93125502765179, 46.577205285429955, 51.58487297594547, 53.77512864768505, 53.40121731162071, 53.6601772159338, 53.916348069906235, 49.84335422515869, 50.15636242926121, 54.150065928697586, 62.597825825214386, 58.44587221741676, 67.86002665758133, 21.00454330444336, 21.296149156987667, 46.14783972501755, 37.44190268218517, 21.46787714213133, 54.792379662394524, 59.40664306282997, 58.322933614254, 64.53147366642952, 58.41887466609478, 59.7122872620821, 49.91491578519344, 50.45437663793564, 52.3412299901247, 57.28536508977413, 56.533571630716324, 53.02265502512455, 53.453966081142426, 47.33403727412224, 45.06816565990448, 46.93804532289505, 45.31680531799793, 45.900427401065826, 44.55769345164299, 47.974994480609894, 45.98694495856762, 51.109457686543465, 46.289868503808975, 56.89388729631901, 56.87385477125645, 59.46773238480091, 52.74653524160385, 63.82439240813255, 57.948676496744156, 57.17613235116005, 59.085111916065216, 57.18270979821682, 59.605573788285255, 59.263044968247414, 60.196240693330765, 60.396866127848625, 60.74892483651638, 61.13876111805439, 57.18107208609581, 55.04008077085018, 52.27718822658062, 53.76576215028763, 50.494152903556824, 51.45220309495926, 57.8410928696394, 62.113507613539696, 59.48263518512249, 57.2076478600502, 56.41433022916317, 36.937365755438805, 39.79780286550522, 38.38594302535057, 16.981309689581394, 5.291671101003885, 1.8844796670600772, 3.963336478918791, 24.126404486596584, 72.46821418404579, 54.84555020928383, 66.86358332633972, 58.36823098361492, 66.47915035486221, 58.33848237991333, 68.45511272549629, 33.46133127808571, 7.241732161492109, 24.280841499567032, 75.99950149655342, 46.096728667616844, 51.815144419670105, 46.38861380517483, 41.47999919950962, 69.56769302487373, 40.951721146702766, 1.5646190056577325, 0.09083465280127712, 0.32147052814252675, 0.21810635196743533, 0.5735308339353651, 0.13702311145607382, 0.14880133647238836, 0.255055406014435, 0.1915310975164175, 0.1780926584615372, 0.1844995896681212], [0.035586723242886364, 0.08865793366567232, 0.008813766216917429, 0.09047492640092969, 0.03484591143205762, 0.02252552341815317, 0.0439332165842643, 0.06633971992414445, 0.07704186791670509, 0.12055657629389316, 0.216408021224197, 0.021346816647564992, 0.16154931101482362, 0.2050163660896942, 0.21747644670540467, 3.8053112709894776, 42.47939497232437, 48.43110300600529, 50.265659764409065, 37.458230406045914, 22.55264673382044, 56.04738391935825, 37.64290429651737, 4.832545537501574, 15.845128856599331, 60.687736719846725, 58.97119402885437, 59.0132387727499, 56.48800067603588, 55.46367824077606, 53.893735483288765, 58.4041428565979, 19.201296865940094, 0.25088726717513055, 1.7593428818508983, 12.52197727560997, 6.86858743429184, 30.44490873813629, 43.22096697986126, 49.94187533855438, 57.55385868251324, 65.7450221478939, 65.49296647310257, 66.90480351448059, 61.79847791790962, 57.2022445499897, 52.176349237561226, 56.779851615428925, 54.79085214436054, 55.17531931400299, 53.79370205104351, 54.543553814291954, 54.58631671965122, 57.91780695319176, 59.00778606534004, 58.85206662118435, 60.699903666973114, 58.687265664339066, 60.4967475682497, 57.206519320607185, 57.51974031329155, 58.43602694571018, 58.31899702548981, 50.4959350079298, 45.67174807190895, 45.73937684297562, 44.465445801615715, 44.84768629074097, 44.08502921462059, 42.31990613043308, 41.74878917634487, 43.48067544400692, 43.64932179450989, 42.755655348300934, 42.192111387848854, 44.85696919262409, 43.58432248234749, 45.79144164919853, 44.94548164308071, 43.16213473677635, 39.3229765444994, 43.74267518520355, 41.67650185525417, 51.18183620274067, 49.49876971542835, 58.41852508485317, 7.707981867715716, 22.538840174674988, 46.89167261123657, 36.7159516364336, 30.64305290579796, 42.799090817570686, 53.29333730041981, 50.948209539055824, 54.48885954916477, 50.99314972758293, 49.49286863207817, 40.29256671667099, 40.230272859334946, 42.79297314584255, 46.94406419992447, 47.46529743075371, 50.219173058867455, 46.138739213347435, 44.2344143986702, 41.17555193603039, 43.41510996222496, 38.9157409965992, 40.328672379255295, 42.12761364877224, 42.65378661453724, 42.876044288277626, 47.62668617069721, 42.586074247956276, 47.72733137011528, 53.13965454697609, 55.805838480591774, 54.839595928788185, 53.40902969241142, 52.65956550836563, 54.074962958693504, 53.17704454064369, 53.07795725762844, 52.614024952054024, 53.19478198885918, 50.76249070465565, 51.33874498307705, 54.126936569809914, 54.131078347563744, 53.8967677205801, 52.354179695248604, 53.17604899406433, 51.17099158465862, 47.52958998084068, 51.59796327352524, 49.89680215716362, 48.40429164469242, 49.321471229195595, 47.14594356715679, 27.553463391959667, 11.740600503981113, 17.446687817573547, 16.966957859694958, 2.5889172172173858, 0.5631727678701282, 0.36658114346209913, 2.311922530643642, 29.579702764749527, 52.6278942078352, 52.65991508960724, 53.13720367848873, 58.12091365456581, 59.83082190155983, 50.320008248090744, 53.99756871163845, 5.907373437657952, 5.371387023478746, 44.611190780997276, 73.80445048213005, 25.221226438879967, 41.300158649683, 18.224677070975304, 29.563036859035492, 57.38122254610062, 13.091224730014801, 0.6652086926624179, 0.14775291929254308, 0.10086637426866218, 0.07605311198858544, 0.19292753742774948, 0.06489050589152612, 0.11607752210693434, 0.04587689021718688, 0.05510682502062991, 0.11427114950492978, 0.05281540325086098, 0.051329686684766784, 0.011722305116563803, 0.03405230323551223, 0.09326185419922695, 0.046063844638410956, 0.01862898836407112, 0.07017629686743021, 0.07395934269879945, 0.08323228496010415, 0.017068845518224407, 0.11255461387918331, 0.08218703675083816, 0.0543406651559053, 0.2277889003744349, 0.13554987410316244, 3.5302772792056203, 46.60299450159073, 57.93280854821205, 56.64620518684387, 49.72710706293583, 32.139712795615196, 47.261685356497765, 52.17190347611904, 7.759612072259188, 15.459099970757961, 62.693379297852516, 67.08657816052437, 66.33951544761658, 64.29493635892868, 57.26726286113262, 57.88759097456932, 62.81594932079315, 20.81966422498226, 0.15431938256369904, 3.661616281606257, 11.295275799930096, 7.243146160617471, 44.37494605779648, 43.26716110110283, 53.91171991825104, 58.77882935106754, 68.9490482211113, 67.11994796991348, 69.10719573497772, 64.50330957770348, 58.968686163425446, 54.0611506998539, 58.633293360471725, 57.05684915184975, 57.00643725693226, 56.94323904812336, 55.996835231781006, 56.68634623289108, 60.43679058551788, 57.41504453122616, 61.276226341724396, 62.25764147937298, 63.62479291856289, 62.62754403054714, 61.98019556701183, 61.94030910730362, 62.10557363927364, 60.37478171288967, 53.45122642815113, 47.90602058172226, 49.70126084983349, 46.34986348450184, 47.74642534554005, 46.08534827828407, 44.057009518146515, 43.34138631820679, 45.70447191596031, 44.57276724278927, 44.7803121060133, 45.883978083729744, 49.3132446706295, 48.43760825693607, 47.18541584908962, 45.93594789505005, 44.446948394179344, 44.09332036972046, 45.83572827279568, 47.43610739707947, 53.421732410788536, 52.3803336918354, 60.475628301501274, 42.19179220497608, 35.31117461621761, 42.59742423892021, 43.746167197823524, 53.38393583893776, 57.89309687912464, 55.988464280962944, 56.83838747441769, 56.62178009748459, 54.610080644488335, 54.793177619576454, 44.24242056906223, 42.85229176282883, 47.5019920617342, 51.6733056306839, 51.84243455529213, 53.653356581926346, 49.46183569729328, 46.70287974178791, 43.0156259983778, 43.9907106757164, 41.479832008481026, 44.08424265682697, 44.091918244957924, 43.61315153539181, 44.377738907933235, 48.63702915608883, 44.61629770696163, 51.29630886018276, 53.99432748556137, 57.907642498612404, 56.53397060930729, 57.21811629831791, 54.55897718667984, 56.703791096806526, 54.07173693180084, 56.408520340919495, 53.93466308712959, 54.14674110710621, 54.34964641928673, 53.736834302544594, 54.64138336479664, 56.18045657873154, 55.324890688061714, 56.83326154947281, 55.97675330936909, 56.41078121960163, 49.57612216472626, 54.44046534597874, 52.518137097358704, 51.46494001150131, 53.2773819565773, 53.0928448587656, 28.854251392185688, 13.285997528582811, 24.49764646589756, 18.860238566994667, 3.822040823288262, 0.9430447372142226, 0.44134631752967834, 2.8842998296022415, 32.26322516798973, 58.44110727310181, 59.87285144627094, 58.29765737056732, 64.06761735677719, 64.55847501754761, 56.38362407684326, 59.63810384273529, 7.832787595689297, 13.01869422197342, 41.862190291285515, 81.608517318964, 27.76127804070711, 53.40019516646862, 23.325344771146774, 27.789364233613014, 64.36144798994064, 13.308761157095432, 0.5800831667147577, 0.11662127886665985, 0.0981697955285199, 0.0874402400222607, 0.15327276138123125, 0.049225252732867375, 0.05027086088375654, 0.03214608208509162, 0.021696774529118557, 0.08484696081723087, 0.05731806144467555, 0.12868275196524337, 0.24617666291305795, 0.30672099615912884, 0.16637251392239705, 0.16059902060078457, 0.17646121006691828, 0.213086019793991, 0.23342785716522485, 0.20779732702067122, 0.2774712344398722, 0.2543337712995708, 0.19874263554811478, 0.426372152287513, 0.72696523508057, 0.7571888726670295, 11.1324792355299, 67.98773020505905, 67.75017455220222, 61.31719194352627, 54.36673030257225, 40.4210302233696, 66.28789901733398, 51.57033495604992, 6.487142527475953, 23.44288196414709, 72.70644620060921, 69.789509922266, 71.59627497196198, 65.84074661135674, 68.79625082015991, 65.09262755513191, 67.78090730309486, 22.018418200314045, 0.23466734768589959, 5.819961503148079, 15.771687347441912, 22.272947542369366, 57.612588331103325, 50.91833554208279, 56.819795072078705, 57.64763005077839, 73.04608717560768, 71.5908944606781, 72.63567879796028, 67.43644058704376, 65.34003987908363, 59.40734222531319, 62.128178626298904, 59.832831993699074, 57.55582697689533, 58.914052695035934, 60.31662583351135, 61.09625279903412, 63.893921077251434, 60.464274510741234, 67.51153215765953, 67.34113410115242, 67.31610104441643, 63.32416445016861, 64.88513588905334, 64.62557181715965, 62.38042809069157, 63.925770968198776, 57.52738170325756, 48.88663776218891, 52.92542204260826, 47.123513370752335, 50.599456652998924, 49.05987806618214, 49.44599814713001, 46.28766842186451, 47.67724625766277, 46.887789219617844, 46.762566938996315, 47.595911622047424, 51.4640736579895, 48.53923760354519, 51.65587216615677, 50.86078763008118, 48.932801485061646, 49.00990314781666, 50.603617429733276, 47.788219302892685, 58.95546667277813, 56.80531404912472, 67.57654666900635, 31.804010309278965, 31.79299660027027, 50.291445180773735, 41.474994868040085, 50.65603941679001, 59.08108793199062, 60.99375329911709, 60.506577640771866, 62.1002197265625, 56.82005725800991, 57.60799437761307, 48.40237274765968, 47.577467411756516, 48.90238791704178, 52.621521949768066, 52.67633020877838, 54.94972921907902, 52.68030859529972, 49.577531889081, 42.88137540221214, 47.40192823112011, 44.25501689314842, 46.72005482017994, 45.97600154578686, 47.39042244851589, 47.65608139336109, 50.566691011190414, 45.13549044728279, 54.06238563358784, 56.979242116212845, 61.09584242105484, 58.00096169114113, 59.738274067640305, 57.485340759158134, 59.27416317164898, 56.92993976175785, 58.76196205615997, 56.538306176662445, 59.395122081041336, 55.67451372742653, 55.77141612768173, 57.574480175971985, 58.505240231752396, 59.26811009645462, 56.75046779215336, 56.5197441726923, 57.521340027451515, 48.80922071635723, 50.27494266629219, 52.34692208468914, 52.64207884669304, 55.8176102489233, 59.582558423280716, 35.975762754678726, 15.706341303884983, 32.297974303364754, 28.271024487912655, 7.269207062199712, 1.2340765236876905, 1.3370589539408684, 3.465553689748049, 34.7549794614315, 67.37497508525848, 64.5205606520176, 66.13856703042984, 68.48469033837318, 67.30083346366882, 63.49487029016018, 65.4326257109642, 9.773102179169655, 9.731659702956676, 58.767760545015335, 81.04782700538635, 34.62275795638561, 60.489691346883774, 27.616410814225674, 40.042817518115044, 77.1845743060112, 26.29657443612814, 1.1883421777747571, 0.36517803906463087, 0.33416407357435673, 0.23859400651417673, 0.3377705253660679, 0.1875457793357782, 0.1692602995899506, 0.1931449124822393, 0.210718791349791, 0.13219714775914326, 0.1613575845840387], [0.005000543733331142, 0.015245969407260418, 0.02634770640725037, 0.026700271082518157, 0.029490996821550652, 0.0536929965892341, 0.024838788449415006, 0.0078338817365875, 0.026276306234649383, 0.020507503286353312, 0.0505544021143578, 0.00875092671776656, 0.055804588555474766, 0.044826079611084424, 0.13416849978966638, 0.5699448357336223, 21.39849666506052, 50.71503505110741, 53.98295849561691, 40.10173715651035, 27.80862919986248, 53.607306852936745, 68.96203592419624, 24.517150819301605, 3.733292310498655, 27.57014449685812, 68.77369523048401, 63.33837568759918, 58.156221359968185, 57.409629821777344, 48.70686560869217, 59.96573746204376, 30.87832298129797, 0.36459002061747015, 1.2043202016502619, 0.24080520583083853, 6.046007098630071, 16.252385303378105, 47.89637289941311, 47.94814132153988, 62.39481411874294, 68.78323271870613, 64.24578979611397, 58.96943472325802, 57.06484392285347, 49.653254225850105, 50.96031568944454, 50.32533936202526, 55.02657629549503, 55.781356394290924, 54.792972430586815, 53.59606325626373, 55.2242036908865, 54.94595982134342, 56.44149877130985, 58.261000737547874, 57.46690034866333, 58.123394921422005, 56.815695092082024, 57.63241566717625, 58.01366440951824, 57.91627563536167, 52.292558401823044, 46.45648196339607, 47.41937689483166, 46.652547642588615, 43.70349168777466, 44.91779252886772, 43.28889973461628, 41.330074444413185, 43.22138495743275, 43.38884197175503, 41.494031846523285, 42.86386974155903, 42.36057534813881, 43.258812949061394, 42.88216955959797, 43.32387685775757, 41.88897505402565, 42.4733304977417, 41.92186988890171, 42.250423058867455, 42.078508883714676, 44.59269717335701, 49.35475744307041, 53.26447784900665, 46.93537026643753, 48.43078762292862, 53.57268691062927, 42.835508063435555, 45.24749703705311, 51.40341371297836, 50.15929587185383, 51.74011744558811, 51.966410502791405, 50.42142100632191, 43.82230371236801, 41.209069937467575, 40.79128995537758, 41.55264750123024, 48.271260783076286, 48.29709939658642, 46.797065287828445, 45.31767167150974, 42.09572196006775, 43.00143375992775, 41.83421239256859, 39.579698368906975, 40.23922897875309, 42.1098268032074, 41.830693781375885, 42.98731751739979, 43.276014626026154, 45.195880606770515, 44.417895153164864, 47.000734359025955, 51.26515053212643, 55.066306963562965, 51.73707380890846, 54.86367143690586, 53.15907530486584, 52.06102542579174, 51.04326903820038, 50.693535804748535, 49.738232865929604, 52.631158232688904, 51.092385202646255, 50.93028210103512, 50.458833798766136, 54.84558440744877, 54.90046866238117, 53.64171400666237, 55.89285001158714, 55.70238143205643, 52.655005753040314, 53.05673159658909, 53.618789836764336, 46.00537396967411, 37.21281677484512, 16.971295326948166, 5.688904160633683, 12.860404215753078, 6.875812271609902, 0.9459952195174992, 0.43993792904075235, 0.5452122003771365, 4.391336012631655, 41.11296929419041, 49.89340893924236, 47.4604032933712, 52.655134946107864, 51.464563831686974, 39.159573912620544, 61.475031673908234, 26.767281778156757, 1.7956213164143264, 10.924178212881088, 65.59218674898148, 29.31493867188692, 27.165819592773914, 33.05189564824104, 22.996803000569344, 43.00939053297043, 48.749206736683846, 3.761360691860318, 0.1603031560080126, 0.13880512677133083, 0.04010645454400219, 0.017777722714527044, 0.04829484074434731, 0.015637264914403204, 0.08728715722099878, 0.02084969644783996, 0.05600949552899692, 0.058729333177325316, 0.03175052108417731, 0.039453364588553086, 0.05542667582631111, 0.039876589144114405, 0.075749825919047, 0.06150022316433024, 0.09195251273922622, 0.019836761348415166, 0.021492208943527658, 0.021682052174583077, 0.05595942653599195, 0.010747178730525775, 0.0777381805528421, 0.016967870760709047, 0.10166838357690722, 0.34685482853092253, 0.6771718163508922, 24.29266456514597, 64.97408151626587, 54.42838579416275, 45.90174213051796, 36.3864067196846, 52.01392315328121, 70.51503539085388, 36.037330850958824, 6.064663622528315, 27.96275842934847, 70.6876753270626, 69.80891168117523, 65.97390666604042, 63.349516689777374, 55.032743364572525, 65.06409868597984, 34.8071164637804, 0.22137551248306409, 1.6962646041065454, 1.9816062552854419, 5.40513158775866, 26.686074435710907, 52.363082617521286, 52.38781549036503, 62.94036224484444, 68.8517202436924, 69.12733465433121, 60.74153043329716, 60.173096135258675, 53.71447630226612, 52.9993736743927, 52.39862971007824, 57.612082958221436, 59.18502375483513, 57.95018881559372, 56.440985798835754, 55.6356418132782, 56.45626477897167, 58.70481692254543, 60.40950804948807, 59.244490563869476, 60.887803584337234, 62.222584560513496, 60.918384343385696, 61.74372285604477, 58.25625479221344, 54.57633085548878, 49.291604831814766, 49.08365339040756, 48.97156320512295, 46.67555160820484, 48.15354309976101, 46.538986936211586, 42.35642597079277, 45.07159687578678, 44.5851431787014, 43.449387922883034, 46.221943348646164, 45.453966557979584, 46.73784926533699, 49.27706681191921, 45.21033123135567, 44.8921363055706, 45.480774119496346, 43.582449182868004, 44.701983109116554, 46.84578247368336, 50.440868362784386, 52.806788608431816, 56.57393306493759, 45.17143651843071, 47.69191347062588, 52.724473625421524, 49.037143886089325, 54.52724128961563, 55.563153102993965, 56.5998400747776, 56.59725621342659, 56.30246043205261, 54.26347464323044, 50.422405153512955, 45.51225163042545, 45.017028003931046, 46.71397514641285, 51.93977013230324, 54.39546436071396, 51.34456627070904, 48.587692603468895, 45.589455887675285, 45.22078067064285, 44.43482704460621, 43.05032193660736, 42.943084090948105, 44.11733888089657, 44.59345333278179, 46.58685676753521, 46.434864923357964, 48.264493346214294, 45.81030383706093, 49.32712532579899, 53.57672989368439, 56.16674691438675, 54.34398092329502, 56.34013161063194, 56.18149392306805, 54.086274951696396, 53.174449279904366, 52.77775816619396, 51.37383230030537, 54.046795070171356, 52.76228919625282, 52.45115049183369, 52.455299869179726, 55.892979204654694, 58.309132754802704, 56.83435209095478, 59.07374292612076, 55.23319400846958, 53.558677062392235, 55.63841946423054, 56.46575286984444, 52.18931034207344, 42.94752225279808, 19.639310762286186, 7.394460216164589, 15.157073177397251, 8.263240847736597, 2.147580161690712, 0.7484009535983205, 1.0870761866681278, 5.986764477565885, 48.48516270518303, 53.23739670217037, 55.737339556217194, 60.46265199780464, 56.4342487603426, 43.57082560658455, 70.19374743103981, 27.119188494980335, 5.606983881443739, 16.35328508913517, 66.45597919821739, 35.47205038368702, 27.835748344659805, 43.08432251214981, 16.62969745695591, 47.537489756941795, 54.537911117076874, 3.17528679035604, 0.03749832496396266, 0.044712159942719154, 0.11864046973641962, 0.030747168966627214, 0.12111433738027699, 0.011817368667834671, 0.04583323338010814, 0.03081620354350889, 0.12199332966702059, 0.020559225413308013, 0.01036050402035471, 0.08218870658311062, 0.17265457136090845, 0.11323738232022151, 0.15067006432218477, 0.12638063955819234, 0.2069245613529347, 0.1669056134414859, 0.14072515186853707, 0.12483202968724072, 0.12779343640431762, 0.16665702365571633, 0.15259614534443244, 0.14323231967864558, 0.19997298280941322, 0.3937540791230276, 1.5103538800030947, 48.9222152531147, 76.08695760369301, 66.16344809532166, 53.740858286619186, 45.0336255133152, 64.23622190952301, 81.10755980014801, 29.88739125430584, 7.473917752504349, 35.71421518921852, 78.45158591866493, 75.07860571146011, 71.02465644478798, 68.0763490498066, 63.39655436575413, 70.24187564849854, 39.05805096030235, 0.5345785303507, 1.9446900486946106, 2.4502020981162786, 10.356174241751432, 35.84316127002239, 58.19640040397644, 56.40144892036915, 66.35920599102974, 74.56105828285217, 70.08422210812569, 63.459665179252625, 62.16117225587368, 56.087654158473015, 55.528578758239746, 56.80108867585659, 61.360030844807625, 62.56135158240795, 61.96397423744202, 57.86320008337498, 59.359567388892174, 58.47743332386017, 61.181505024433136, 65.02300769090652, 60.92074781656265, 64.21646296977997, 64.051673412323, 64.24594178795815, 64.33721289038658, 60.63470296561718, 56.179442033171654, 51.64973549544811, 52.157019674777985, 51.84874601662159, 47.49064587056637, 50.63726842403412, 48.19550044834614, 45.90298466384411, 47.50291921198368, 48.12021888792515, 45.39414256811142, 49.2039929330349, 47.46006891131401, 47.63192228972912, 49.59221050143242, 48.56155000627041, 48.139776438474655, 48.48302721977234, 47.85058155655861, 47.911891266703606, 50.922348126769066, 51.84135541319847, 58.48652243614197, 58.88304255902767, 59.5162557810545, 61.65155500173569, 57.17644013464451, 52.57416509091854, 60.42436145246029, 59.9915836751461, 58.81113901734352, 62.07356035709381, 59.426086619496346, 55.960011407732964, 51.02740868926048, 50.12380197644234, 48.168708086013794, 49.587217569351196, 54.34733234345913, 55.73955863714218, 52.85139061510563, 51.92474953830242, 47.83740386366844, 47.68673054873943, 47.83808022737503, 45.6139911711216, 46.347013637423515, 46.00511938333511, 44.96924936771393, 49.03132639825344, 47.526246160268784, 50.00661626458168, 49.39632721245289, 50.57237550616264, 56.556845381855965, 60.24338856339455, 56.48023009300232, 58.96292567253113, 59.11775216460228, 56.38632193207741, 56.95683091878891, 55.254187881946564, 54.70441818237305, 56.529319658875465, 56.33641920983791, 54.466824531555176, 54.66788314282894, 58.78020867705345, 59.74486291408539, 60.124827325344086, 60.81251822412014, 56.217884570360184, 53.27058032155037, 56.154522970318794, 58.9439494907856, 54.067579954862595, 44.36540476977825, 22.228683717548847, 10.996518731117249, 18.286794237792492, 9.762417152523994, 3.040518471971154, 1.0663180192932487, 1.8703139084391296, 5.821353178471327, 55.50038427114487, 61.65900640189648, 59.979553520679474, 64.01259630918503, 61.98999524116516, 51.85106389224529, 72.37986132502556, 33.18496450781822, 5.4437959380447865, 16.9841880351305, 77.31137350201607, 34.94733653962612, 43.25325384736061, 47.09339998662472, 33.1987539678812, 59.77210745215416, 70.04883840680122, 10.822060592472553, 0.7682303676847368, 0.3031608246965334, 0.35600812174379826, 0.12929472693940625, 0.28875217598397285, 0.0998703007644508, 0.16135155834490433, 0.1276585436426103, 0.1889748143730685, 0.2356595397577621, 0.14868516067508608], [0.06247753888601437, 0.06720608085743152, 0.03857558571326081, 0.00264738293026312, 0.012352053599897772, 0.06663774416665547, 0.024971690399979707, 0.15616281802067533, 0.026656235750124324, 0.0410208324319683, 0.0438533206761349, 0.05761949214502238, 0.007779684083288885, 0.07264271334861405, 0.06983003302593715, 0.31236200127750635, 5.452246209606528, 43.796605691313744, 46.539492309093475, 45.25021769106388, 34.88107189536095, 30.514532402157784, 71.75240099430084, 56.12500615417957, 11.028711553663015, 9.119393806904554, 53.507467210292816, 66.98261573910713, 63.04763808846474, 57.78056971728802, 50.08393831551075, 59.42781552672386, 33.60561713576317, 0.9427029336802661, 1.5757321030832827, 0.4272282641613856, 0.5252601834945381, 4.92279639467597, 25.715612210333347, 47.00097754597664, 66.7922155559063, 70.03676265478134, 65.58369040489197, 62.38923981785774, 55.1304779201746, 50.29975153505802, 50.942088067531586, 49.58385854959488, 52.666849717497826, 51.89632706344128, 54.57793816924095, 52.09549717605114, 53.14780130982399, 54.131063148379326, 57.88929708302021, 53.788587525486946, 55.235150903463364, 54.182136207818985, 56.21962107717991, 54.44620683789253, 53.99167522788048, 49.63703289628029, 48.121415823698044, 46.76451623439789, 44.65035907924175, 44.58105459809303, 45.149298906326294, 42.83509008586407, 43.149257227778435, 43.51305730640888, 41.8477738648653, 42.45383754372597, 42.68341362476349, 41.96785882115364, 42.43333764374256, 44.4597727060318, 41.75041548907757, 43.026041239500046, 41.91899724304676, 42.730557695031166, 43.136170729994774, 43.666382879018784, 44.63395155966282, 45.441541224718094, 46.02235905826092, 48.74709025025368, 50.465016067028046, 51.66292078793049, 55.20737439393997, 49.15604330599308, 51.07366360723972, 52.82848924398422, 51.61363363265991, 48.31901662051678, 48.58900733292103, 46.95586636662483, 41.40998415648937, 41.95992484688759, 38.745692521333694, 40.94710439443588, 43.98497678339481, 43.74209001660347, 45.22698573768139, 44.158015698194504, 41.94138944149017, 42.259341180324554, 40.1864156126976, 40.174225866794586, 40.83847962319851, 43.71152825653553, 43.01681153476238, 41.04222469031811, 42.49772898852825, 42.664262652397156, 41.97892762720585, 43.62383656203747, 45.04059053957462, 47.41406857967377, 46.67231798171997, 43.91073256731033, 48.364180997014046, 49.32720132172108, 47.459438145160675, 47.33216777443886, 47.836104333400726, 49.55225944519043, 50.108089819550514, 51.58211812376976, 48.64391438663006, 50.58523401618004, 53.58701974153519, 54.55934576690197, 57.782059237360954, 56.361418068408966, 55.560177862644196, 58.71604152023792, 54.13316823542118, 49.75191593170166, 38.08857478201389, 17.463349923491478, 3.433643952012062, 0.5731286492664367, 1.184428387787193, 0.40553225961048156, 0.2545348339481279, 0.43569486297201365, 6.992949061095715, 46.81267485022545, 47.80944116413593, 51.7036622017622, 48.78076784312725, 52.03276254236698, 57.242594584822655, 51.54603146016598, 9.330252092331648, 6.344185648486018, 45.22928461432457, 46.179712414741516, 19.731011241674423, 36.076597943902016, 22.328755147755146, 30.851118341088295, 49.2585314065218, 35.39433695375919, 0.754560719942674, 0.1181863718375098, 0.052465558546828106, 0.10264962154906243, 0.08226881400332786, 0.07606583982123993, 0.06668917500064708, 0.07798113001626916, 0.07745381924905814, 0.038305662892526016, 0.07884795850259252, 0.09491430537309498, 0.017961556404770818, 0.07352399145020172, 0.011547446774784476, 0.15150631632423028, 0.05092806233733427, 0.06944876950001344, 0.06060377185349353, 0.05158292973646894, 0.056317312410101295, 0.07093590727890842, 0.07275699666934088, 0.07209911243990064, 0.051373295282246545, 0.05487416172400117, 0.14130932599073276, 0.22972439182922244, 5.804377114400268, 56.493989154696465, 53.60989451408386, 47.008588537573814, 43.21905568242073, 39.24874372780323, 66.76902160048485, 56.63841560482979, 18.50880492478609, 12.969483062624931, 56.011411249637604, 73.20624098181725, 68.66290837526321, 64.22612965106964, 54.20194834470749, 65.44824287295341, 37.206550911068916, 2.225916045717895, 3.237836896441877, 2.2917496506124735, 0.559014662867412, 4.909912711009383, 32.45471589267254, 54.44399155676365, 66.89663395285606, 71.41406714916229, 67.55782127380371, 63.69534373283386, 60.22224649786949, 52.30799697339535, 52.88803964853287, 53.10971215367317, 53.221844136714935, 54.69916306436062, 57.666902616620064, 54.3849541246891, 54.4584421813488, 54.84409488737583, 57.805959954857826, 58.670174181461334, 57.71680913865566, 56.950686648488045, 57.984014600515366, 57.38130994141102, 56.317777410149574, 53.71183544397354, 49.93512310087681, 48.52327845990658, 47.7762271463871, 47.515811920166016, 47.477342784404755, 45.60304015874863, 45.927497148513794, 46.31701044738293, 43.37658762931824, 43.817211985588074, 45.9260418266058, 45.62712326645851, 45.45031115412712, 47.773316502571106, 43.874581307172775, 46.485896185040474, 44.78935182094574, 44.28196884691715, 46.94905333220959, 44.381675496697426, 47.418689131736755, 47.745232209563255, 50.252740457654, 55.37717588245869, 56.61895304918289, 56.031417176127434, 57.406757175922394, 53.19270730018616, 54.652801752090454, 59.2833586782217, 55.902953669428825, 54.3230364471674, 55.083903819322586, 51.54826954007149, 43.909816816449165, 47.294948771595955, 42.57313214242458, 45.99141351878643, 49.043489545583725, 48.00188183784485, 49.87110033631325, 48.00703056156635, 44.94403392076492, 43.326479718089104, 44.554190039634705, 44.16818015277386, 43.13189975917339, 46.01503685116768, 44.769212901592255, 43.93803410232067, 44.397444650530815, 45.28538480401039, 43.928929790854454, 43.45789186656475, 47.228209152817726, 49.441130608320236, 49.73086126148701, 46.21551029384136, 50.15817493200302, 51.60191886126995, 50.375652462244034, 48.46963293850422, 50.918909311294556, 50.311055928468704, 52.9508350789547, 52.81790301203728, 51.641607731580734, 51.81063786149025, 56.00712887942791, 57.50438913702965, 60.35385623574257, 59.41562578082085, 58.830077201128006, 59.7803720086813, 58.94727051258087, 55.12406766414642, 41.25209502875805, 20.437714420259, 4.886706406250596, 0.4250793013488874, 0.9522731357719749, 0.4834332747850567, 0.6219742563553154, 0.9156902425456792, 9.222131744027138, 54.365704357624054, 55.33415079116821, 59.88531477749348, 54.190119579434395, 60.66802337765694, 64.55645352602005, 54.14234094321728, 11.214129254221916, 10.860292240977287, 39.50852818787098, 49.84548971056938, 20.310482047498226, 36.68137729167938, 25.998214446008205, 25.96880402415991, 55.95355175435543, 42.96060875058174, 1.3653121003881097, 0.03573088542907499, 0.05036475740780588, 0.08899276101146825, 0.10061384367872961, 0.04305767528421711, 0.046259849550551735, 0.05610226398857776, 0.039468430186389014, 0.03327330050524324, 0.027499326643010136, 0.03499363221635576, 0.23055774945532903, 0.23551547405077145, 0.09442424299777485, 0.2793449198361486, 0.23643595981411636, 0.12746603053528816, 0.1960787855205126, 0.3237532259663567, 0.20189971692161635, 0.1718469662591815, 0.23667770699830726, 0.1921434880932793, 0.18751781521132216, 0.3764199139550328, 0.6521797261666507, 0.8829340408556163, 17.94538825750351, 73.82021203637123, 66.59123674035072, 58.69767710566521, 51.831384748220444, 42.958545461297035, 87.27467447519302, 63.467770144343376, 19.97491255402565, 13.009341023862362, 65.24941474199295, 75.00564962625504, 74.43223759531975, 68.35122630000114, 61.53762951493263, 68.11025083065033, 43.56013298034668, 2.2484630858525634, 3.9403629116714, 1.8410972761921585, 1.5520856156945229, 7.516528191044927, 36.96101948618889, 55.298831686377525, 70.79332485795021, 72.98165783286095, 70.73315128684044, 68.25810089707375, 62.109578624367714, 53.887982591986656, 57.42654651403427, 54.790563359856606, 58.91459986567497, 58.86310122907162, 61.74738585948944, 58.440875485539436, 57.61287711560726, 57.5809246301651, 62.51312457025051, 61.06584683060646, 60.66176891326904, 59.94374804198742, 60.854635164141655, 59.350478276610374, 60.29750145971775, 54.97975520789623, 54.269835501909256, 52.43459478020668, 51.691259667277336, 49.57535460591316, 48.96333284676075, 48.01213748753071, 49.5058411359787, 50.54384283721447, 45.84233611822128, 47.84331254661083, 47.93079525232315, 47.00921930372715, 46.391174867749214, 50.72742998600006, 46.16069823503494, 48.80810357630253, 47.86904476583004, 46.75856955349445, 49.741561487317085, 50.841621458530426, 51.68326489627361, 52.82528981566429, 53.36861126124859, 60.889931470155716, 56.54170699417591, 58.57810512185097, 63.159466087818146, 55.7211372256279, 60.99874623119831, 61.96914196014404, 60.925208777189255, 55.3977669775486, 55.75779385864735, 55.800317376852036, 46.820038855075836, 49.78860676288605, 45.72018027305603, 47.87161722779274, 49.253067299723625, 48.7374197691679, 51.51592567563057, 51.83536693453789, 47.9512495547533, 47.118900418281555, 45.534385442733765, 46.46759636700153, 46.862227991223335, 49.57432486116886, 46.27178147435188, 44.61266130208969, 46.65236905217171, 45.647577568888664, 44.75457988679409, 47.186909168958664, 49.20704796910286, 53.09207729995251, 52.54546903073788, 48.076224848628044, 54.89333264529705, 54.44532908499241, 54.54451136291027, 49.708161279559135, 53.628384321928024, 53.321117609739304, 54.06142808496952, 58.30910615622997, 53.532796651124954, 55.13157606124878, 58.95489290356636, 60.717124342918396, 62.35795609652996, 59.578013867139816, 60.145114436745644, 62.67051212489605, 60.4385194927454, 55.90386942028999, 42.836674600839615, 22.94299028813839, 7.158302888274193, 1.4323888323269784, 3.142118607647717, 1.3986398745328188, 2.0470812544226646, 1.2890532799065113, 9.68566982075572, 61.57555527985096, 60.30877165496349, 64.8839807510376, 58.671435713768005, 62.32686996459961, 67.57692664861679, 61.56045489013195, 14.605715163052082, 10.817647129297256, 56.91590331494808, 57.97798432409763, 24.939921833574772, 55.27984030544758, 31.944874450564384, 47.26314827799797, 60.23850202560425, 65.89171707630157, 3.439035387709737, 0.1496315177064389, 0.24991585523821414, 0.17822946596425027, 0.27352775854524225, 0.11732855302398093, 0.16586834331974387, 0.23069804505212232, 0.2933030849089846, 0.16481259372085333, 0.194812755798921, 0.14708396221976727], [0.0551805054419674, 0.06499911920400336, 0.017591118958080187, 0.05232804971456062, 0.051176555643905886, 0.018833963986253366, 0.03790255796047859, 0.01213397257743054, 0.007543946439909632, 0.08568308665417135, 0.08183206009562127, 0.010621730725688394, 0.04182951364782639, 0.00632079522802087, 0.13172907521948218, 0.05074501161288936, 0.5927123234141618, 27.126588597893715, 54.85470771789551, 40.733301267027855, 41.518814116716385, 22.735732309520245, 46.5727823227644, 79.1446079313755, 16.324915811419487, 9.469689410179853, 52.73909144103527, 69.00121942162514, 68.34838405251503, 57.6821967959404, 51.03536546230316, 57.76865355670452, 38.76230143010616, 2.0719977049157023, 1.8776565394364297, 2.2235041251406074, 0.4094982671085745, 0.3271873213816434, 21.20243478566408, 53.16752605140209, 65.99819496273994, 69.74931567907333, 64.1767019033432, 61.58341705799103, 54.878236055374146, 49.682322666049004, 50.56302800774574, 48.402923718094826, 47.34424352645874, 49.984984025359154, 51.93850480020046, 53.45323272049427, 53.2790956646204, 51.13177388906479, 54.07426379621029, 53.31347621977329, 50.540461018681526, 50.832118168473244, 50.79365663230419, 49.935780465602875, 48.11167694628239, 47.331951186060905, 46.84972666203976, 46.40631705522537, 44.61245231330395, 46.533876210451126, 44.11430664360523, 43.58277216553688, 43.5062974691391, 41.73459313809872, 42.53996752202511, 44.20013643801212, 43.377670571208, 43.37032176554203, 43.83496083319187, 40.36622576415539, 43.25731582939625, 42.339159697294235, 40.94644322991371, 41.7863729596138, 42.58371077477932, 44.838277995586395, 46.42789229750633, 47.31396295130253, 45.9657496958971, 47.20643252134323, 49.99782733619213, 52.68527492880821, 53.7151450663805, 53.79852779209614, 55.53034566342831, 55.708837285637856, 51.513888984918594, 48.82862247526646, 45.539496168494225, 43.178337067365646, 41.1136494576931, 42.14740298688412, 40.55071346461773, 43.64157781004906, 41.47956222295761, 43.601573556661606, 42.87021540105343, 42.96827293932438, 41.40200458467007, 41.442236825823784, 40.0500675290823, 39.58487369120121, 38.42357620596886, 41.20951071381569, 44.113915264606476, 43.81431274116039, 42.662332355976105, 43.35016764700413, 43.237522691488266, 40.70854179561138, 43.158965706825256, 43.28748241066933, 41.615028753876686, 41.434416845440865, 42.82212518155575, 46.06037221848965, 46.61068148910999, 44.52848061919212, 49.742401242256165, 49.03119720518589, 49.96929086744785, 47.44232766330242, 49.57919619977474, 50.184496119618416, 53.985420763492584, 55.5716722458601, 57.48597912490368, 56.5611657500267, 53.952054753899574, 57.58593276143074, 58.02247613668442, 56.77195943892002, 44.729337841272354, 23.267221190035343, 6.236763512715697, 0.20871953456662595, 0.2357652215869166, 0.8390322653576732, 0.7512676622718573, 1.5155556821264327, 15.980859473347664, 53.34847994148731, 49.880265444517136, 46.76825523376465, 42.79454246163368, 48.9665512740612, 60.608518570661545, 26.444861479103565, 7.045743428170681, 22.048592381179333, 70.36288395524025, 31.526224315166473, 25.55332861840725, 32.76368111371994, 40.35194233059883, 33.422584757208824, 51.51671223342419, 26.195359267294407, 0.22802521503763273, 0.06388766400050372, 0.021248220473353285, 0.040674004558240995, 0.027890592464245856, 0.03138840867904946, 0.0297281964958529, 0.04261512149241753, 0.057216543063987046, 0.020941325710737146, 0.02477116766385734, 0.02249987293907907, 0.029596574750030413, 0.012530961284937803, 0.044835170920123346, 0.07379330942058004, 0.04223336072755046, 0.0451064073422458, 0.020195873621560168, 0.08006158517673612, 0.053095218900125474, 0.04563563285046257, 0.0462300448998576, 0.05057817681517918, 0.07812781550455838, 0.032808296746225096, 0.22891613363754004, 0.13098254887154326, 0.9778524131979793, 34.18415129184723, 64.69699278473854, 40.35506196320057, 46.06747783720493, 30.930925458669662, 49.836643785238266, 77.55615636706352, 16.39297015964985, 13.202538806945086, 55.34601375460625, 76.5394601225853, 72.46343404054642, 64.37985420227051, 55.10268621146679, 65.1175694167614, 42.36956186592579, 2.306160139851272, 2.1945489663630724, 2.3153003118932247, 1.0791733232326806, 0.7563299406319857, 23.714189305901527, 56.08967565000057, 67.12200745940208, 71.15162283182144, 67.68826067447662, 65.40100380778313, 56.58211402595043, 54.04387682676315, 53.524273708462715, 50.016438737511635, 49.505537152290344, 52.44642734527588, 54.33386206626892, 56.88491217792034, 56.29523701965809, 54.20937314629555, 55.27502216398716, 56.130409464240074, 53.929039388895035, 53.903219774365425, 54.50909346342087, 52.353408336639404, 50.961467027664185, 48.933975622057915, 48.38642120361328, 48.532983139157295, 48.1642547249794, 48.17443437874317, 45.59558875858784, 45.63827186822891, 44.9123740196228, 43.47265027463436, 44.22348618507385, 45.34662611782551, 46.012563183903694, 46.19022645056248, 48.70395876467228, 43.63615170121193, 45.104974284768105, 44.82940547168255, 44.28326077759266, 45.57514205574989, 44.1022764891386, 47.77325950562954, 51.758189275860786, 49.887355864048004, 48.03008392453194, 51.90866880118847, 52.53668770194054, 56.40289284288883, 58.25761891901493, 57.347864136099815, 58.29771436750889, 59.88047383725643, 54.76304903626442, 53.55747252702713, 49.05157171189785, 47.408064901828766, 45.91405726969242, 44.25433672964573, 43.82111817598343, 44.740110263228416, 44.5345488935709, 46.908395513892174, 45.484676510095596, 45.80756038427353, 44.050956442952156, 42.5603686273098, 44.50510807335377, 43.14607299864292, 42.03798405826092, 43.667412623763084, 47.334428653120995, 46.19947515428066, 44.65198539197445, 44.82590585947037, 44.27573338150978, 42.893211767077446, 44.96718607842922, 43.73017765581608, 44.55394305288792, 44.2006304115057, 45.271230563521385, 48.65801922976971, 47.55534879863262, 49.70964699983597, 51.92040637135506, 51.9658937305212, 51.24954856932163, 48.85915383696556, 51.80247589945793, 51.6667015850544, 56.67987897992134, 57.437801510095596, 60.024736896157265, 59.35048587620258, 55.720669850707054, 60.803052932024, 59.78065699338913, 59.037990644574165, 49.71698060631752, 29.928077571094036, 9.069159552454948, 0.7185627578292042, 0.40558331937063485, 0.6330860476009548, 1.7550313007086515, 1.9337000884115696, 20.511202476918697, 58.6621718108654, 57.19202309846878, 52.127434462308884, 48.615355119109154, 55.29017195105553, 61.77456960082054, 30.896497406065464, 9.181637316942215, 28.321265392005444, 65.27102038264275, 39.58021134138107, 23.135345466434956, 37.732457891106606, 45.282147377729416, 36.93350896239281, 59.2892749607563, 29.310451112687588, 0.3736647352343425, 0.010607596523186658, 0.08754509064601734, 0.013226018763816683, 0.04231274455378298, 0.017173041196656413, 0.060745414448319934, 0.047940724980435334, 0.05014435439079534, 0.08087609967333265, 0.04399902652949095, 0.03296782510005869, 0.10322615897166543, 0.174228607211262, 0.16722985776141286, 0.24911861051805317, 0.09239207196515054, 0.1371799421031028, 0.1879661763086915, 0.15187851822702214, 0.27140106016304344, 0.16173857351532206, 0.17139057512395084, 0.1398443413199857, 0.14005609089508653, 0.15329582733102143, 0.42957671626936644, 0.2355783636448905, 1.7417972045950592, 61.92173570394516, 76.99440971016884, 54.12352055311203, 58.15751329064369, 33.746255189180374, 62.976445108652115, 93.05660381913185, 20.353562235832214, 14.738398343324661, 60.76910935342312, 82.22274675965309, 77.82722622156143, 68.24559956789017, 61.25346936285496, 71.60425454378128, 46.210384368896484, 3.334846878424287, 3.3662251196801662, 5.94932128675282, 1.5796156134456396, 2.0665506972000003, 27.534253522753716, 60.90227700769901, 71.15780889987946, 73.68671000003815, 71.49439483880997, 66.52420833706856, 58.910108506679535, 56.36151686310768, 54.60933208465576, 54.40011151134968, 53.431300297379494, 55.205824077129364, 57.89962112903595, 60.68630799651146, 57.42037184536457, 56.99699096381664, 58.9884565025568, 59.91247572004795, 56.64129965007305, 56.50155454874039, 57.99957476556301, 53.642834946513176, 54.102370887994766, 52.30202369391918, 53.2278174161911, 49.32771049439907, 49.8557947576046, 51.68315090239048, 47.87840746343136, 48.562009781599045, 48.98580864071846, 44.65209178626537, 47.39121660590172, 48.247291669249535, 48.06331314146519, 47.025311440229416, 51.11708387732506, 44.268722757697105, 47.87524223327637, 48.907821625471115, 45.336332470178604, 47.92424440383911, 46.89170300960541, 52.876590862870216, 55.03139063715935, 54.45685766637325, 52.73946762084961, 54.29303705692291, 58.593547493219376, 62.08689384162426, 62.15829961001873, 62.667943462729454, 61.46604135632515, 65.62048763036728, 58.31124164164066, 56.35726869106293, 50.59940725564957, 50.70086941123009, 48.89020957052708, 48.169532641768456, 47.017430663108826, 49.532344713807106, 47.80483201146126, 49.50257331132889, 46.78117074072361, 46.69728264212608, 46.156617254018784, 46.34170152246952, 46.09014742076397, 45.69879502058029, 45.235121101140976, 45.57625539600849, 49.44356627762318, 49.36564765870571, 48.49021643400192, 46.841097325086594, 46.41622692346573, 44.34447169303894, 48.15540499985218, 46.79186336696148, 46.24239385128021, 45.00285096466541, 47.619595751166344, 51.25469349324703, 51.17555893957615, 52.232156842947006, 54.068883284926414, 55.80934189260006, 56.13710470497608, 52.4940387904644, 53.72497133910656, 53.84431533515453, 59.53857198357582, 61.09942562878132, 61.097449734807014, 61.15452267229557, 57.07658529281616, 61.32217347621918, 62.80512750148773, 62.00715512037277, 54.84382130205631, 30.391650795936584, 10.586711671203375, 0.9919187834020704, 0.654325601644814, 2.5868867011740804, 3.2932182122021914, 2.4031986203044653, 21.69102966785431, 65.11550232768059, 61.92843854427338, 57.15343996882439, 52.9384895414114, 59.0364745259285, 70.14178901910782, 37.57209129631519, 11.218042094260454, 30.850318484008312, 81.18085026741028, 40.27932062745094, 34.552195742726326, 50.4835020750761, 50.791654139757156, 45.913494899868965, 63.63268509507179, 49.74527768790722, 0.6341837730724365, 0.20489520306000486, 0.23930370749440044, 0.13058463897323236, 0.15197038126643747, 0.14551679865689948, 0.15205795469228178, 0.17773421597667038, 0.34994260815437883, 0.1715679484186694, 0.14101737993769348, 0.07888160005677491], [0.034989272098755464, 0.04890410687949043, 0.0100147615376045, 0.08487790095387027, 0.05020984150178265, 0.029204620586824603, 0.05153663456439972, 0.0698158580053132, 0.017072162918339018, 0.04128889246203471, 0.06444949205615558, 0.015148787024372723, 0.1265300190425478, 0.03530509304255247, 0.0382250619441038, 0.15353978611528873, 0.23851619975175709, 8.18787569180131, 51.58990390598774, 42.99780495464802, 37.329405918717384, 30.702555812895298, 28.05871658027172, 76.09599351882935, 49.401434138417244, 11.803617272526026, 33.591303303837776, 65.26791214942932, 64.154571890831, 61.481035351753235, 56.77487388253212, 54.85263302922249, 48.30094859004021, 5.355226490646601, 2.787863854318857, 3.6432456923648715, 1.3846384570933878, 0.4065426788292825, 14.103359319269657, 56.667791828513145, 66.79482981562614, 71.01177513599396, 63.28236289322376, 63.666643872857094, 53.24567265808582, 50.989209339022636, 49.50019083917141, 49.71026636660099, 46.143576353788376, 47.08823226392269, 47.895529344677925, 49.259678944945335, 48.83943669497967, 51.11182875931263, 52.42576785385609, 50.59743136167526, 48.20579409599304, 50.553520917892456, 48.926094844937325, 47.96281613409519, 46.39177903532982, 45.517723336815834, 44.755955412983894, 46.05968825519085, 44.7448106110096, 43.844361528754234, 44.69905726611614, 44.49243575334549, 45.01417055726051, 41.3001624494791, 43.55518564581871, 43.09800557792187, 42.91084282100201, 44.47910986840725, 42.65179932117462, 42.13670656085014, 42.16498464345932, 42.14963346719742, 42.79210679233074, 42.277538403868675, 44.29037019610405, 47.77718469500542, 47.495076432824135, 49.51843746006489, 47.016898691654205, 48.91502603888512, 49.84390139579773, 55.020378828048706, 53.22955772280693, 52.30593368411064, 50.17023168504238, 54.86603491008282, 53.49099509418011, 51.360514014959335, 44.897558614611626, 43.32657091319561, 42.90760539472103, 41.65675051510334, 39.7965869307518, 40.48450581729412, 42.49579109251499, 42.4550686776638, 41.6475436091423, 41.71563595533371, 42.297107353806496, 42.523362413048744, 41.80930472910404, 41.3476675003767, 42.63931319117546, 41.26566410064697, 42.02701024711132, 44.26135875284672, 42.84513674676418, 41.01423539221287, 41.99276268482208, 41.066661179065704, 42.18243330717087, 42.16730631887913, 40.42401686310768, 40.61113782227039, 40.17592817544937, 44.0034893900156, 44.34645138680935, 45.00453807413578, 45.15798904001713, 46.38788804411888, 47.93826945126057, 46.09894774854183, 50.23493081331253, 50.80534480512142, 54.77935016155243, 57.38740101456642, 56.13739728927612, 54.23134736716747, 58.30860078334808, 56.27924747765064, 56.604635417461395, 58.39485615491867, 59.958210065960884, 46.55870407819748, 21.170598194003105, 1.9759915815666318, 0.23941201652633026, 0.34977161732967943, 0.04702862919657491, 1.5008782572112978, 22.18535654246807, 53.56274664402008, 50.6243035197258, 57.92113937437534, 58.869222700595856, 54.692874401807785, 57.93948478996754, 28.895479179918766, 15.699123591184616, 42.392334043979645, 52.75243632495403, 27.99265332520008, 32.36348278820515, 33.58453966677189, 55.06867043673992, 42.18258149921894, 56.74288719892502, 10.711876954883337, 0.5280332628171891, 0.2112286171177402, 0.13505763723514974, 0.025882346417347435, 0.0907532095152419, 0.06625285896006972, 0.01780107253580354, 0.014312321654870175, 0.006940950988791883, 0.05121851667354349, 0.04619794701284263, 0.0562924356199801, 0.043954657230642624, 0.05935265558946412, 0.02949403406091733, 0.07270634509040974, 0.010969398153974907, 0.03738337371032685, 0.05080984563392121, 0.019986424704256933, 0.009509532446827507, 0.09599175537005067, 0.014764198676857632, 0.03610925457905978, 0.08362036140169948, 0.011384735535102664, 0.07028879903373308, 0.39036605623550713, 0.21456623333506286, 8.890228103846312, 69.52635124325752, 44.5666191726923, 40.77786527574062, 40.86583435535431, 32.844574972987175, 74.13621068000793, 47.417932972311974, 13.009227029979229, 38.68436001241207, 71.59163162112236, 72.63429567217827, 65.60527324676514, 63.30273739993572, 60.59950925409794, 54.526720717549324, 5.21372445859015, 1.3147655501961708, 4.1101515758782625, 0.5620548559818417, 0.5060783971566707, 15.34861234948039, 57.72814393043518, 66.16215616464615, 72.09281712770462, 66.85007885098457, 65.58013379573822, 55.92664159834385, 52.66599856317043, 52.82130762934685, 51.30785644054413, 48.1732602417469, 50.288374945521355, 50.87749533355236, 51.3005418330431, 51.32930248975754, 52.20378376543522, 53.82952652871609, 53.20182301104069, 51.057662665843964, 53.072626143693924, 53.63351784646511, 52.49310024082661, 47.99960196018219, 47.26879857480526, 46.3085824996233, 50.414490178227425, 48.26922029256821, 47.53771774470806, 47.18036971986294, 47.93309032917023, 46.69732443988323, 44.46977376937866, 43.85328345000744, 44.15225140750408, 44.69828970730305, 46.34990908205509, 45.32762713730335, 43.91253747045994, 44.17630031704903, 43.775581419467926, 44.31164525449276, 46.108838617801666, 46.68657101690769, 50.70126838982105, 50.37385515868664, 52.47581496834755, 49.89932142198086, 52.54383131861687, 56.13640934228897, 57.27906122803688, 58.120529875159264, 56.57825343310833, 54.12724055349827, 58.58834557235241, 58.09364251792431, 54.90825064480305, 49.31858718395233, 46.371666714549065, 46.043390929698944, 44.819016829133034, 43.808947429060936, 42.055295929312706, 45.569183975458145, 46.71364836394787, 44.079561308026314, 45.36723241209984, 44.50400993227959, 45.10653980076313, 43.23619656264782, 41.60978123545647, 43.05290959775448, 43.88653166592121, 44.69689138233662, 46.36769972741604, 46.968842670321465, 43.224136009812355, 44.423024877905846, 42.98769369721413, 43.55377212166786, 44.791551902890205, 42.95077107846737, 42.69498400390148, 43.555497229099274, 45.200835540890694, 46.89878962934017, 46.3018074631691, 47.73062199354172, 47.60122753679752, 49.360609129071236, 48.07110272347927, 52.20628023147583, 52.951450645923615, 56.61285437643528, 58.5223963111639, 57.81290218234062, 57.39984914660454, 61.23398020863533, 59.08643804490566, 61.15808308124542, 60.60757242143154, 62.27604389190674, 50.65580762922764, 25.65575212240219, 3.0793010909110308, 0.14284794655395672, 0.31786374980583787, 0.4802041011862457, 1.9850493455305696, 26.850181929767132, 59.78933572769165, 57.60386019945145, 62.66383208334446, 63.946821838617325, 55.3024110943079, 66.21843114495277, 31.82713396847248, 21.154785342514515, 38.44790630042553, 56.29640355706215, 36.666930466890335, 27.56668098270893, 49.589292258024216, 51.12326234579086, 46.358143240213394, 66.42127946019173, 11.283192448318005, 0.7934498519171029, 0.18983551271958277, 0.14213327318429947, 0.04231754624925088, 0.06354463592288084, 0.04050705101690255, 0.05031056578445714, 0.02451366097375285, 0.03333653890877031, 0.03950457277824171, 0.05026447099226061, 0.0710617755248677, 0.15888776164501905, 0.1432642320287414, 0.10479434669832699, 0.1783320604590699, 0.12645212322240695, 0.1353887835284695, 0.17671388166490942, 0.23799932358087972, 0.21589911571936682, 0.14157302590319887, 0.2174601046135649, 0.11613912036409602, 0.18526710395235568, 0.10903519374551252, 0.22495505400002003, 0.7599158794619143, 0.4273224575445056, 24.807470440864563, 83.75632166862488, 58.04151691496372, 53.8738701492548, 47.79794678092003, 39.44726787507534, 90.84404334425926, 56.762744933366776, 18.58799457550049, 39.96316619217396, 77.82704383134842, 72.3456783592701, 74.44330260157585, 66.63962334394455, 69.3126355111599, 57.947680950164795, 7.884921748191118, 6.11781707033515, 9.350522104650736, 3.209987240843475, 1.6346313175745308, 18.938337676227093, 62.06976056098938, 66.94217070937157, 73.97360980510712, 69.79278534650803, 70.31033277511597, 57.73873396217823, 54.76915530860424, 55.07503129541874, 55.32065011560917, 51.71409644186497, 52.94067062437534, 51.913570538163185, 53.818985894322395, 51.68426424264908, 56.18108354508877, 56.97561711072922, 55.74193350970745, 53.881446942687035, 58.48675422370434, 56.41087241470814, 55.36607667803764, 51.171979531645775, 49.001649990677834, 49.454156309366226, 52.55950927734375, 50.814540311694145, 48.450858145952225, 50.090948939323425, 47.91854090988636, 49.24233667552471, 46.698114797472954, 46.82397924363613, 46.69675447046757, 47.72607743740082, 49.04126666486263, 47.6469998806715, 47.187228351831436, 46.68962225317955, 45.94384007155895, 46.3558329641819, 48.861258924007416, 52.44461104273796, 55.70703238248825, 54.10217709839344, 58.56302373111248, 56.59012019634247, 57.76193171739578, 55.63167102634907, 61.09676197171211, 60.353974029421806, 59.74306561052799, 55.56487821042538, 62.73190163075924, 62.285509184002876, 58.968583568930626, 52.654705569148064, 50.41427738964558, 49.16664853692055, 48.246478512883186, 46.38851121068001, 45.127381682395935, 48.73718798160553, 49.01720255613327, 45.79057149589062, 47.86221273243427, 45.80703601241112, 48.28724652528763, 47.50371716916561, 44.36260811984539, 48.283754512667656, 46.06370843946934, 47.32616789638996, 48.861505910754204, 49.0602770447731, 43.920631036162376, 46.43878631293774, 44.31968182325363, 46.657358184456825, 46.45233638584614, 45.446602553129196, 46.54382407665253, 46.091944724321365, 47.42098040878773, 50.666663646698, 48.3171471208334, 51.901718974113464, 50.256251469254494, 52.39556707441807, 49.303874373435974, 55.32124288380146, 56.51080325245857, 60.5174146592617, 60.617094710469246, 59.89841267466545, 57.911784276366234, 62.15086720883846, 61.08360707759857, 63.37224707007408, 64.78254899382591, 63.3376195281744, 53.18868711590767, 26.890606060624123, 3.5234340839087963, 0.5358803167473525, 1.5809354488737881, 0.6479428347665817, 2.9856261424720287, 30.02603441476822, 64.16779518127441, 62.716968432068825, 66.94541573524475, 69.11134511232376, 62.92425490915775, 70.45702010393143, 36.759387105703354, 21.740753799676895, 46.313442438840866, 66.69945493340492, 33.81971284747124, 44.45504195988178, 50.671584382653236, 61.591818407177925, 55.792204812169075, 77.46959701180458, 24.238937348127365, 1.1272438312880695, 0.5770278337877244, 0.31287969381082803, 0.12468235334381461, 0.23827437835279852, 0.23130982706788927, 0.15459532791282982, 0.16826493112603202, 0.19806541095022112, 0.12716020632069558, 0.18578752758912742, 0.303656401229091], [0.037187981070019305, 0.009313675964222057, 0.023135340597946197, 0.051921033664257266, 0.044886111936648376, 0.058781580373761244, 0.04151318804360926, 0.06684235428110696, 0.03532888258632738, 0.03861898279865272, 0.006710012721669045, 0.048600271620671265, 0.04795476270373911, 0.0174735071050236, 0.09699527261545882, 0.11771737161325291, 0.054532766371266916, 0.7806520198937505, 39.703104346990585, 43.15275304019451, 32.43848316371441, 41.18434466421604, 22.576116174459457, 54.344026520848274, 59.389152601361275, 14.392853435128927, 24.64095577597618, 63.246846199035645, 67.20953196287155, 62.0162708312273, 56.39782391488552, 53.1063037365675, 55.86419954895973, 14.426990803331137, 0.6758328631985933, 2.2106304159387946, 0.8838953298982233, 0.043127593016834, 10.385539066046476, 61.14750064909458, 69.5993909239769, 73.04717391729355, 64.23013463616371, 62.16686435043812, 55.02692587673664, 49.00488741695881, 48.55417840182781, 48.867809772491455, 47.75782473385334, 46.54287792742252, 46.04428768157959, 47.69839592278004, 47.67553634941578, 47.40222081542015, 48.943630903959274, 47.565676644444466, 46.69125996530056, 47.265131771564484, 47.029563412070274, 46.62730559706688, 46.87029875814915, 44.11138080060482, 46.45726092159748, 43.55059929192066, 46.79283991456032, 46.307096779346466, 46.94858215749264, 47.57932551205158, 43.4449877589941, 42.95972339808941, 42.5666306912899, 43.570616617798805, 42.26171985268593, 45.6850815564394, 45.60825727880001, 42.6336020976305, 42.14767277240753, 41.862517073750496, 41.37525022029877, 41.72844506800175, 44.37965780496597, 48.00956502556801, 49.88058462738991, 47.85396337509155, 48.19088749587536, 49.65136952698231, 51.45210810005665, 55.019485875964165, 57.75978483259678, 56.11762315034866, 53.858173191547394, 54.20135177671909, 55.88728331029415, 53.85829858481884, 48.68735745549202, 44.443194195628166, 42.87338063120842, 41.28947362303734, 39.32363770902157, 41.97157882153988, 41.25212162733078, 41.02124981582165, 41.09134845435619, 42.586682215332985, 40.220530182123184, 42.67291858792305, 41.72747232019901, 40.0369506329298, 42.1241520345211, 41.24903619289398, 42.581031918525696, 43.17334033548832, 44.5524687319994, 44.64789681136608, 45.985208451747894, 44.3688739836216, 45.99123872816563, 45.15702769160271, 44.067170172929764, 41.30700968205929, 41.480173990130424, 42.28692390024662, 43.883662819862366, 42.64931805431843, 42.940416634082794, 44.07973989844322, 45.54035872220993, 46.9905661046505, 49.05773118138313, 48.94825145602226, 54.128771871328354, 55.596956089138985, 57.74879962205887, 57.251136526465416, 59.17117729783058, 55.47126643359661, 54.59200121462345, 55.3569495677948, 61.339253559708595, 60.44415459036827, 46.98952876031399, 15.853795241564512, 0.5697671952657402, 0.1792644354281947, 0.23998109536478296, 2.730648899450898, 21.167298071086407, 51.17549054324627, 50.85929051041603, 53.003458455204964, 53.92630733549595, 59.52775776386261, 51.01357363164425, 18.609284833073616, 17.625437825918198, 71.24173879623413, 33.88971269130707, 21.88123796135187, 34.044542983174324, 29.643611535429955, 38.313564509153366, 45.58041997253895, 48.99376541376114, 0.9922842762898654, 0.18461512721842155, 0.09409473685082048, 0.09065250749699771, 0.023503709307988174, 0.06796230707550421, 0.031194700713967904, 0.009157319364021532, 0.12060526860295795, 0.055357114324579015, 0.06479480594862252, 0.06673636817140505, 0.028371183179842774, 0.05882380486582406, 0.05071158528153319, 0.03589789834222756, 0.024640399387863, 0.04130740162509028, 0.05171623430214822, 0.006778995348213357, 0.04321276559494436, 0.0336652435362339, 0.029956169419165235, 0.06579437496839091, 0.09913026078720577, 0.0366484508413123, 0.14252941677113995, 0.022463906607299577, 0.019192180116078816, 0.09330919579952024, 1.4239447354339063, 45.8526411652565, 53.92148919403553, 35.24895295500755, 49.85850401222706, 30.51301248371601, 55.72622895240784, 63.08180585503578, 17.198802419006824, 27.934904024004936, 68.58996748924255, 75.54319158196449, 68.086296916008, 62.07911565899849, 59.86420311033726, 63.68428632616997, 15.782259330153465, 0.315515297697857, 1.9631629949435592, 0.7368030259385705, 0.3893621976021677, 12.327167429029942, 62.11435876786709, 72.91062444448471, 75.09144142270088, 66.93045973777771, 65.46873897314072, 59.99324418604374, 50.76709985733032, 51.81061126291752, 51.536733359098434, 51.6734766215086, 50.291608572006226, 47.714868038892746, 51.284795477986336, 48.88167902827263, 50.5731126666069, 51.762844026088715, 49.21103395521641, 50.245798230171204, 50.61533600091934, 50.39416886866093, 50.007623210549355, 49.025919288396835, 46.617741510272026, 48.164497911930084, 47.69767016172409, 48.375542387366295, 49.72570113837719, 48.77193331718445, 49.924324080348015, 46.824195832014084, 45.31476862728596, 43.98030683398247, 45.16815349459648, 43.33417050540447, 48.74645568430424, 45.42391397058964, 44.494438245892525, 44.283986538648605, 44.286532402038574, 45.21797262132168, 45.495669320225716, 46.40784837305546, 50.92407703399658, 53.49321037530899, 52.01777994632721, 52.80398815870285, 51.52228653430939, 54.24513302743435, 59.71814654767513, 59.3881456553936, 56.4262729883194, 57.30788268148899, 57.75675639510155, 57.58311711251736, 56.998005509376526, 51.36217452585697, 46.03731885552406, 44.52810063958168, 45.290928706526756, 43.28500494360924, 44.80233192443848, 43.96396391093731, 45.15490360558033, 44.1460919380188, 45.2452627569437, 42.5471605360508, 46.15702763199806, 44.66076672077179, 43.765994533896446, 44.41122651100159, 43.94724480807781, 44.261142164468765, 46.33133187890053, 46.863428726792336, 47.35891453921795, 49.03622813522816, 46.388302221894264, 47.92366683483124, 47.69895449280739, 47.00279004871845, 44.166694432497025, 43.451815992593765, 44.37108166515827, 45.87571732699871, 45.81191495060921, 45.82073427736759, 46.19866959750652, 47.448726519942284, 48.11232291162014, 51.790601536631584, 51.48011639714241, 55.822774171829224, 58.42101015150547, 58.24923276901245, 59.531397968530655, 60.76885476708412, 58.86739879846573, 55.76459929347038, 56.434700936079025, 63.943409621715546, 63.385284170508385, 52.080108001828194, 19.67582680284977, 0.5907402886077762, 0.14855265762889758, 1.0001500323414803, 3.7641768157482147, 27.443375699222088, 57.99078203737736, 58.22807930409908, 58.75262215733528, 60.22244408726692, 63.66694785654545, 59.27559569478035, 21.248741000890732, 22.609267495572567, 64.31639760732651, 45.69609336555004, 22.597970701754093, 33.84246222674847, 42.27724961936474, 31.4168718829751, 56.30126729607582, 51.27154938876629, 2.5644372683018446, 0.11267252630204894, 0.1852969531319104, 0.09668636106653139, 0.06341142783639953, 0.09921062795910984, 0.13488753698766232, 0.029595142405014485, 0.05866652893018909, 0.013939587261120323, 0.06780341325793415, 0.09039983589900658, 0.05419362714746967, 0.1402422957471572, 0.2064064532169141, 0.24507801717845723, 0.11219623076613061, 0.12436546370736323, 0.1655362025485374, 0.16769965208368376, 0.12591712380526587, 0.13216861960245296, 0.13007187430048361, 0.13574514799984172, 0.26468634547200054, 0.13061077741440386, 0.22388305136701092, 0.19465617748210207, 0.4332441429141909, 0.3000100515782833, 4.096410563215613, 70.79256489872932, 61.410898715257645, 45.95235161483288, 57.298865765333176, 33.3666555583477, 68.95204246044159, 67.85239666700363, 19.419228471815586, 29.207514636218548, 77.70504757761955, 80.2603268623352, 73.30391854047775, 66.59499853849411, 66.17929324507713, 66.76519900560379, 19.68358788639307, 1.225781450048089, 7.180754458531737, 3.6208359198644757, 0.860346449771896, 15.822515320032835, 65.71692645549774, 75.17440617084503, 78.93094539642334, 68.6800454556942, 66.88137397170067, 62.14999705553055, 55.768383890390396, 52.41939939558506, 55.90149074792862, 52.892455011606216, 53.383555859327316, 51.23324364423752, 52.85693071782589, 50.199338123202324, 52.24237449467182, 53.83113004267216, 51.55045062303543, 52.13863626122475, 53.16173896193504, 53.122988641262054, 53.04551839828491, 51.494776010513306, 48.92812393605709, 51.711968556046486, 49.356630742549896, 51.63985222578049, 51.147128865122795, 52.38494664430618, 53.31091895699501, 48.92497390508652, 47.303532510995865, 47.495334818959236, 47.631549909710884, 47.36205697059631, 50.94933047890663, 49.24454055726528, 46.315148547291756, 46.876386031508446, 47.17127300798893, 47.598237097263336, 49.66913737356663, 51.22650660574436, 53.578785583376884, 56.92438066005707, 56.48408688604832, 56.89629636704922, 54.90125522017479, 58.90265330672264, 63.61835986375809, 62.56821021437645, 59.40038479864597, 60.19806079566479, 62.10893265902996, 63.74373413622379, 61.11752785742283, 56.044598668813705, 48.901468366384506, 47.51975990831852, 48.54497529566288, 45.56515999138355, 48.15014228224754, 46.08364976942539, 47.67153136432171, 45.77398918569088, 48.93717885017395, 45.060607865452766, 46.70212738215923, 47.64261871576309, 47.34085790812969, 46.645430624485016, 45.91615095734596, 47.61780984699726, 48.74558933079243, 49.26935702562332, 48.65728206932545, 51.54451534152031, 49.03074502944946, 50.93896463513374, 50.12603245675564, 50.7681106030941, 46.52839310467243, 47.439903393387794, 46.49155028164387, 49.420368522405624, 49.272902235388756, 47.37566404044628, 49.22087922692299, 51.21609516441822, 52.93606147170067, 54.212990552186966, 54.566664174199104, 59.333481788635254, 59.961546286940575, 59.798462837934494, 61.831452548503876, 62.236981987953186, 60.193900018930435, 58.44581142067909, 59.789537116885185, 68.94096225500107, 66.29362151026726, 52.90731601417065, 19.06185954809189, 0.9169995097909123, 0.3399955137865618, 1.5427277865819633, 4.151168949902058, 29.5555417612195, 62.399233281612396, 62.058307975530624, 61.51308663189411, 66.46063774824142, 69.44774866104126, 64.50851529836655, 26.501064263284206, 23.451735489070415, 81.63240283727646, 44.083832278847694, 26.960459612309933, 50.258208364248276, 43.1845573335886, 47.913939356803894, 58.930843994021416, 74.82066795229912, 4.535175869241357, 0.5414675606880337, 0.3671943652443588, 0.2215737698134035, 0.2618690935196355, 0.1542893107398413, 0.20759632374392822, 0.12247503545950167, 0.2074856695253402, 0.15509799937717617, 0.11875032243551686, 0.1761429919861257, 0.14336105261463672], [0.07535455806646496, 0.09113715219427831, 0.06314006153843366, 0.03988062642747536, 0.06542351635289378, 0.053623461062670685, 0.0985810715064872, 0.03501419341773726, 0.008483961355523206, 0.05301143784890883, 0.06799001144827344, 0.05162893176020589, 0.04863568319706246, 0.07898582727648318, 0.09075024092453532, 0.046099935279926285, 0.3093337418977171, 0.5783934448845685, 16.28832757472992, 55.49713544547558, 37.27022409439087, 45.71733422577381, 25.877546221017838, 33.891426399350166, 68.9988711476326, 19.96173106133938, 20.53251553326845, 56.300480738282204, 69.42194804549217, 59.909067302942276, 58.36681745946407, 53.037744015455246, 61.76665462553501, 18.22574481368065, 0.24193052435293794, 2.154482016339898, 0.031347167532658204, 1.312505027744919, 14.520262498408556, 59.40679885447025, 75.06233498454094, 69.60987076163292, 65.84352806210518, 66.57439604401588, 58.69279816746712, 51.23885974287987, 49.20178525149822, 50.241956636309624, 53.4584878385067, 49.41523119807243, 47.6206710934639, 45.78532017767429, 46.18777558207512, 45.7682628929615, 45.95325976610184, 47.06161089241505, 45.56759566068649, 46.026250049471855, 46.226943880319595, 43.49041432142258, 43.79941374063492, 45.043523982167244, 43.793588653206825, 43.42052087187767, 44.67522494494915, 44.844931438565254, 46.49079032242298, 48.53280834853649, 46.74247741699219, 43.904706090688705, 42.80331999063492, 42.45018593966961, 41.88028112053871, 44.605829268693924, 46.52744695544243, 42.89155125617981, 42.50054083764553, 42.39534728229046, 42.65455797314644, 42.28840962052345, 45.270364210009575, 47.21039950847626, 49.31413382291794, 50.991531014442444, 48.87679249048233, 49.68538150191307, 51.81958258152008, 54.923324435949326, 54.335830360651016, 54.83474738895893, 53.20562280714512, 56.676219776272774, 52.34013944864273, 53.51278692483902, 50.64153179526329, 47.09006756544113, 40.323466658592224, 43.81049394607544, 40.594057738780975, 41.02773226797581, 40.55683113634586, 41.842347756028175, 42.22201958298683, 41.52209714055061, 42.73916803300381, 41.6118673235178, 41.160671934485435, 41.55253350734711, 42.682038098573685, 41.33771203458309, 43.837210312485695, 45.54841808974743, 46.17390252649784, 47.74684712290764, 50.2807829529047, 51.33693628013134, 49.99147407710552, 46.95156119763851, 46.906826198101044, 44.7016791254282, 41.35481871664524, 43.88298645615578, 42.533960044384, 41.64973609149456, 43.92975054681301, 43.715100064873695, 45.834215953946114, 45.995961874723434, 47.97108829021454, 48.76226283609867, 53.03283467888832, 57.571907714009285, 57.14069165289402, 57.77038246393204, 57.1078310161829, 55.893435180187225, 53.214271143078804, 54.797380194067955, 56.126586869359016, 62.974609807133675, 55.28270535171032, 41.58659867942333, 7.143271369859576, 0.16823704121634364, 0.685590977082029, 4.7750498726964, 31.38542477041483, 51.77922114729881, 56.49580925703049, 52.965642884373665, 60.07858380675316, 56.78577929735184, 41.56103365123272, 10.97629051655531, 43.959708139300346, 58.05266931653023, 22.873353324830532, 31.715060882270336, 31.657229885458946, 23.514842502772808, 34.18898843228817, 58.15343990921974, 17.02212329953909, 0.47332041431218386, 0.08009411350940354, 0.15419734379975125, 0.06880541652208194, 0.062312017689691857, 0.02982928814162733, 0.01862804769189097, 0.048854412671062164, 0.011563658063096227, 0.03219378733774647, 0.03300406417110935, 0.02780565551802283, 0.024357665242860094, 0.047722860108478926, 0.08369845018023625, 0.04889844058197923, 0.08165670544258319, 0.0690660958935041, 0.019444966746959835, 0.055920849699759856, 0.01216603521243087, 0.03127268559182994, 0.06318121362710372, 0.0316412138636224, 0.018581791482574772, 0.09046066232258454, 0.07644403085578233, 0.043454086044221185, 0.028895141294924542, 0.3648951620562002, 0.8201305952388793, 19.654348455369473, 70.72827994823456, 41.17141015827656, 49.845542907714844, 34.24365609884262, 41.051253005862236, 72.41636216640472, 22.011608965694904, 25.467419028282166, 61.840952038764954, 77.44916930794716, 66.08252763748169, 64.99240413308144, 58.903094083070755, 67.89803221821785, 19.364526607096195, 0.17574082216015086, 2.6582839200273156, 0.39672442129813135, 1.5514449938200414, 17.62285966426134, 61.71428203582764, 76.9577644765377, 72.52034738659859, 68.20949390530586, 66.2108239531517, 61.13790236413479, 51.26919351518154, 52.73528404533863, 53.31011340022087, 56.870218366384506, 52.29676477611065, 49.20830950140953, 47.27411448955536, 48.739464059472084, 49.09726805984974, 48.363485634326935, 48.85503485798836, 49.038671404123306, 46.951777786016464, 49.436327666044235, 48.80832776427269, 46.09988249838352, 47.280653938651085, 45.55663324892521, 46.89667694270611, 48.151240423321724, 48.18497121334076, 49.78049799799919, 50.483262687921524, 49.2435260117054, 46.1201012134552, 44.65129382908344, 44.43344011902809, 43.502459675073624, 47.82808296382427, 49.14815112948418, 44.58173856139183, 43.37122991681099, 45.7377353310585, 43.28404359519482, 44.22228924930096, 47.046198919415474, 51.49832881987095, 51.27226375043392, 54.06428553164005, 51.04978188872337, 51.960357427597046, 55.635003447532654, 59.05927710235119, 58.51389616727829, 57.70210772752762, 56.079112216830254, 59.056693241000175, 57.153842747211456, 57.868591994047165, 53.758812323212624, 49.91641290485859, 43.714362904429436, 44.62311454117298, 44.92492854595184, 44.350950345396996, 43.05156446993351, 44.52905438840389, 45.635007843375206, 44.70007561147213, 46.42053969204426, 44.9482136964798, 44.370956271886826, 42.58619964122772, 45.82304835319519, 43.89586016535759, 45.241664350032806, 47.64644131064415, 46.42663836479187, 51.362649500370026, 51.250460520386696, 52.66372628509998, 52.42202885448933, 50.50901770591736, 48.92841272056103, 45.92968203127384, 43.98374184966087, 46.37728661298752, 44.30976055562496, 45.99630005657673, 44.91821430623531, 44.858926087617874, 47.08271875977516, 49.90876391530037, 49.53320726752281, 51.90828122198582, 55.513014793395996, 58.16469870507717, 59.35147762298584, 60.03487855195999, 59.924262687563896, 59.200686514377594, 55.01863472163677, 56.09478637576103, 58.192596808075905, 65.2228769659996, 59.40329164266586, 46.49205945432186, 9.971059206873178, 1.0927980858832598, 1.7040620232000947, 6.716755656525493, 36.817656978964806, 56.69774942100048, 61.63656860589981, 59.9079729616642, 64.70616549253464, 61.983079612255096, 46.79692469537258, 15.153462421149015, 50.3441521525383, 61.73844113945961, 32.72164396941662, 24.79024976491928, 39.994848892092705, 24.445395469665527, 35.37107080221176, 69.16011929512024, 13.810861464589834, 0.4895497887628153, 0.09382465446833521, 0.154875740990974, 0.03807355991739314, 0.01109370139602106, 0.0646492707892321, 0.0458625667670276, 0.06656278725131415, 0.04373679978016298, 0.040647012647241354, 0.06095030657888856, 0.031628174328943714, 0.012860243859904585, 0.20472038275329396, 0.25705403939355165, 0.14215249480912462, 0.19246908312197775, 0.23470524174626917, 0.15229288896080106, 0.14799618045799434, 0.18276722403243184, 0.14943991001928225, 0.14472132024820894, 0.1424630539258942, 0.0853353830461856, 0.1644825012772344, 0.17837633698945865, 0.16028515150537714, 0.12139011945691891, 0.5359003250487149, 0.8113806147594005, 42.49311223626137, 83.12226489186287, 52.56009824573994, 63.770199716091156, 37.965446189045906, 45.81020504236221, 79.76861044764519, 23.89173287898302, 30.16572631895542, 66.25839740037918, 82.25622296333313, 70.77828526496887, 70.38885936141014, 61.825619861483574, 76.02016478776932, 21.844237446784973, 0.5061250040307641, 5.555843375623226, 1.0848993784748018, 2.4947573198005557, 22.183249555528164, 63.95227074623108, 78.5770171880722, 74.56204622983932, 71.330806016922, 70.75832113623619, 64.40752431750298, 54.37212601304054, 56.57058544456959, 55.505646988749504, 59.765757992863655, 53.698710948228836, 52.494110986590385, 48.91988977789879, 50.77839285135269, 50.58832325041294, 49.68025177717209, 51.54807195067406, 51.425471529364586, 50.40646880865097, 52.199736982584, 50.91658003628254, 48.97768087685108, 49.16110083460808, 48.03368993103504, 47.60105274617672, 51.257809326052666, 50.19935332238674, 51.804656982421875, 51.95068694651127, 52.57359132170677, 49.7490356862545, 47.34205484390259, 47.62380972504616, 46.083265990018845, 50.88599547743797, 51.3393871486187, 48.44915583729744, 45.8067624270916, 49.49844293296337, 45.49999348819256, 48.460806012153625, 51.30784124135971, 54.86505076289177, 55.682424902915955, 58.62604334950447, 53.74879606068134, 56.43961027264595, 58.01903732120991, 62.100060135126114, 60.978048741817474, 59.43992167711258, 58.04303303360939, 62.8065600246191, 62.020123824477196, 60.25802917778492, 57.730693593621254, 53.19353565573692, 46.34442217648029, 48.480621948838234, 47.75396414101124, 46.527579948306084, 45.46373203396797, 46.57378926873207, 48.68850119411945, 47.63780057430267, 49.34612810611725, 47.798269763588905, 46.89484544098377, 46.27343438565731, 48.73957425355911, 47.86160096526146, 48.595049008727074, 50.57862997055054, 49.900503158569336, 54.04174514114857, 53.874132335186005, 56.59420497715473, 55.331570729613304, 52.20670200884342, 52.317899242043495, 49.94918994605541, 47.24710933864117, 49.61456850171089, 46.97507053613663, 48.252368196845055, 50.129117891192436, 48.06926742196083, 50.06351441144943, 52.59543634951115, 53.23970317840576, 51.36326126754284, 56.941107362508774, 63.25530454516411, 62.4558312445879, 61.20992749929428, 62.28994354605675, 61.61896035075188, 57.46041029691696, 58.87165077030659, 60.32534636557102, 68.98432552814484, 62.49237388372421, 48.01436796784401, 11.097292173653841, 1.6040944936685264, 2.2951540304347873, 9.559173658490181, 38.85101526975632, 60.64736008644104, 66.79859161376953, 66.90828412771225, 69.01119008660316, 67.87730813026428, 53.2582575827837, 15.695528034120798, 53.97478513419628, 73.63100498914719, 30.075971335172653, 43.407035395503044, 47.64037303626537, 33.1965234875679, 48.052567318081856, 75.88081106543541, 34.67905953526497, 1.00991538958624, 0.30689329316373914, 0.2953929133946076, 0.11715132073732093, 0.1680253361701034, 0.10166499196202494, 0.2380310875014402, 0.12353072568657808, 0.22926762962015346, 0.07252642622916028, 0.1689806583453901, 0.12409293223754503, 0.14171787828672677], [0.03691970952786505, 0.042993186361854896, 0.04738193230878096, 0.05917272930673789, 0.06994000446866266, 0.020928692501911428, 0.048536432077526115, 0.08197073781047948, 0.02750250860117376, 0.05725867478759028, 0.06716198986396194, 0.07315935945371166, 0.05367540397855919, 0.08867186377756298, 0.0816685426980257, 0.08429559704381973, 0.1536195373046212, 0.2803524595219642, 5.082469051703811, 46.586913764476776, 42.667040303349495, 30.797978192567825, 38.86370278894901, 19.179064258933067, 66.35453224182129, 41.47173084318638, 25.962078385055065, 46.94227069616318, 74.66219365596771, 53.444926366209984, 53.159698471426964, 52.30258226394653, 62.10775092244148, 16.376152262091637, 0.38004907546564937, 1.2006086320616305, 1.1102827289141715, 1.2348152277991176, 18.139200657606125, 60.85408799350262, 76.534573584795, 69.17450532317162, 68.63934963941574, 64.7315101325512, 61.381032317876816, 49.758223593235016, 51.142987087368965, 55.90531334280968, 56.39399752020836, 54.07189652323723, 47.321927323937416, 46.981499791145325, 46.29678413271904, 47.752220034599304, 47.00876332819462, 45.41848786175251, 44.47911746799946, 44.01097118854523, 46.01901903748512, 44.55996572971344, 45.66068306565285, 43.354727402329445, 44.81975398957729, 43.73128339648247, 45.73869667947292, 49.11547668278217, 51.2006451934576, 49.53840158879757, 47.26898476481438, 43.8958677649498, 41.79470591247082, 43.459696769714355, 42.072505205869675, 42.98891343176365, 44.059118404984474, 41.905648559331894, 42.230648919939995, 42.87555031478405, 41.78930260241032, 43.47393840551376, 45.60595840215683, 46.674252077937126, 49.840956553816795, 49.08903770148754, 50.32738745212555, 49.2334109544754, 53.99900123476982, 54.5290993899107, 57.3179217427969, 55.00248558819294, 54.28558185696602, 56.88055761158466, 51.890699565410614, 53.17451387643814, 54.2382325977087, 48.44807669520378, 41.451018154621124, 41.47105447947979, 42.5788888335228, 42.833106592297554, 39.99412693083286, 40.664597153663635, 42.001023441553116, 41.733931973576546, 43.785578683018684, 42.04794332385063, 40.877682119607925, 40.42700730264187, 39.570411667227745, 43.28052118420601, 44.48917172849178, 47.60256126523018, 47.43347033858299, 51.34236618876457, 52.07506187260151, 51.73185668885708, 51.07139132916927, 50.89066922664642, 50.867182686924934, 45.37338808178902, 43.28212849795818, 44.202469512820244, 43.75279404222965, 39.39771853387356, 42.440998032689095, 43.66148494184017, 42.21019461750984, 44.0250114351511, 46.56992107629776, 50.16996189951897, 52.69257053732872, 55.82261838018894, 56.145323663949966, 59.14324499666691, 55.423506796360016, 53.38381424546242, 50.036744847893715, 52.577075734734535, 55.461854338645935, 61.66967622935772, 55.971992164850235, 50.88363200426102, 15.278205927461386, 1.6245313407853246, 2.6899024983868003, 4.568743743002415, 34.270972833037376, 55.607375130057335, 53.91110435128212, 54.941837042570114, 55.38732513785362, 50.829435512423515, 19.03316918760538, 16.63713365793228, 35.94917178153992, 50.61654053628445, 21.401958279311657, 29.848523139953613, 29.105336219072342, 25.064897127449512, 43.85035760700703, 48.23890931904316, 2.3016792302951217, 0.17682450619759038, 0.04474992041650694, 0.15011281531769782, 0.06598567837500013, 0.02298752704518847, 0.021402384954853915, 0.02627726731589064, 0.0386396812973544, 0.052654253304353915, 0.055364973668474704, 0.07971843093400821, 0.02992303438077215, 0.04303177433030214, 0.05967134493403137, 0.06475254805991426, 0.06712315327604301, 0.05810601818666328, 0.061248568308656104, 0.02845537612301996, 0.0483158027054742, 0.05584946622548159, 0.07540675331256352, 0.019775903383560944, 0.04914404322335031, 0.013578628895629663, 0.06670596238109283, 0.07775320162181742, 0.12864619377069175, 0.039753040109644644, 0.3807363932719454, 0.10806733669596724, 7.244204878807068, 59.027605801820755, 48.30687627196312, 33.354070633649826, 44.333258494734764, 22.94461280107498, 68.91227379441261, 42.1145461499691, 32.01123408973217, 53.20565700531006, 79.07511726021767, 59.61063131690025, 59.769941568374634, 57.14107163250446, 67.82017439603806, 18.88250157237053, 0.20019135234178975, 2.022415352985263, 1.7350243055261672, 1.5729392529465258, 21.74426671117544, 62.75839000940323, 79.35140803456306, 70.90069949626923, 72.13890105485916, 67.24094867706299, 64.32021260261536, 51.86449237167835, 52.66310311853886, 58.836772441864014, 60.26383526623249, 55.646247044205666, 52.47883960604668, 49.75701525807381, 47.86881297826767, 49.35475744307041, 48.95343817770481, 46.85687407851219, 48.54124769568443, 46.940416395664215, 48.18932197988033, 46.979850679636, 45.3448174148798, 45.80478273332119, 47.9501324146986, 46.47270329296589, 47.905955985188484, 52.88667932152748, 53.568298146128654, 54.59537163376808, 50.73366545140743, 45.26160188019276, 43.70917618274689, 44.93361867964268, 44.41602945327759, 47.00827315449715, 46.11660160124302, 44.02846924960613, 43.196051716804504, 45.639803186059, 44.15828928351402, 43.48322510719299, 46.53726942837238, 49.92384150624275, 51.33952774107456, 53.389316350221634, 53.326315730810165, 51.68044924736023, 55.677640959620476, 59.47669990360737, 61.110707223415375, 58.65379326045513, 57.94472090899944, 59.446339532732964, 55.17089255154133, 56.29006549715996, 56.849258691072464, 49.92646336555481, 45.142371878027916, 45.417993888258934, 47.39688590168953, 45.84018923342228, 44.9164853990078, 43.65793593227863, 44.07022140920162, 45.13079769909382, 45.35551004111767, 45.52341163158417, 43.59259843826294, 43.15451614558697, 41.584637984633446, 46.45156502723694, 46.77036792039871, 51.35282702744007, 49.29453827440739, 54.65938679873943, 55.39506912231445, 53.989630937576294, 53.01796607673168, 53.185666278004646, 53.75560149550438, 49.24829475581646, 46.73088803887367, 47.059114426374435, 45.178781524300575, 44.13498133420944, 42.59517475962639, 45.5558542907238, 44.147049486637115, 48.22440929710865, 49.16702091693878, 52.500224858522415, 53.55531424283981, 57.4388312548399, 58.65174517035484, 63.065523728728294, 56.44116438925266, 55.31742788851261, 51.798182129859924, 56.787253618240356, 57.580833435058594, 65.20954728126526, 59.491481110453606, 58.70896250009537, 18.70833031833172, 2.3183553479611874, 4.006016738712788, 7.5122348964214325, 37.716396152973175, 60.87321236729622, 57.45625711977482, 61.959745064377785, 60.30983179807663, 56.190951615571976, 19.935206584632397, 21.5984970331192, 35.88782787322998, 58.713282868266106, 21.12264096736908, 26.186004169285297, 37.42161177098751, 21.562294475734234, 51.407848075032234, 54.066637605428696, 3.5797895723953843, 0.15548161551123485, 0.17363018385367468, 0.32578255457337946, 0.09063287769095041, 0.07263639025040902, 0.006519648595713079, 0.05498061167600099, 0.0631878558488097, 0.05036928450863343, 0.03441050081164576, 0.06811982049839571, 0.03604768600780517, 0.08277751170680858, 0.11898973185452633, 0.1291881693759933, 0.14696624275529757, 0.14942809502827004, 0.1725738256936893, 0.11185286130057648, 0.1044271542923525, 0.2236622921191156, 0.10883384908083826, 0.11895001953234896, 0.26814003358595073, 0.18341296672588214, 0.23983440245501697, 0.24319303629454225, 0.30695955210831016, 0.4644028568873182, 0.9567930526100099, 0.6029990839306265, 16.884943060576916, 78.53870004415512, 59.40384641289711, 44.8409416526556, 53.61289635300636, 27.950450889766216, 82.02571213245392, 45.834998711943626, 36.218182146549225, 56.58532105386257, 84.68926280736923, 65.05333006381989, 66.85780763626099, 60.99537581205368, 70.66483855247498, 22.56221652030945, 0.8693854522425681, 3.584079067222774, 2.9497038200497627, 1.8283537100069225, 25.020608603954315, 65.29077932238579, 80.64494222402573, 73.43117371201515, 75.53955897688866, 67.7936290204525, 67.95315206050873, 56.47494837641716, 55.841993540525436, 62.17040956020355, 61.48027919232845, 59.50218513607979, 52.896167412400246, 53.82240191102028, 50.73225952684879, 51.911366656422615, 50.619128197431564, 49.230264723300934, 49.57932159304619, 49.191187620162964, 51.57722778618336, 49.54830005764961, 50.268600806593895, 48.53970117866993, 52.182375714182854, 47.773582488298416, 50.287740379571915, 54.71517540514469, 57.803163304924965, 54.87380549311638, 53.55184882879257, 48.77495415508747, 46.929191797971725, 48.09326693415642, 48.51634003221989, 50.73825940489769, 49.48396570980549, 47.057024538517, 47.32119396328926, 47.96017907559872, 48.67496632039547, 49.04253199696541, 49.180160611867905, 53.07506941258907, 56.672636568546295, 58.12490724027157, 56.31098337471485, 55.33605828881264, 59.91816781461239, 61.65401726961136, 64.75079029798508, 60.363439321517944, 60.993776097893715, 63.587015345692635, 58.65992613136768, 60.49552023410797, 60.213081389665604, 52.5438579171896, 46.20982579886913, 48.53813946247101, 51.44249461591244, 50.281394720077515, 47.25755117833614, 46.53253488242626, 46.62289783358574, 48.48824813961983, 48.11305247247219, 48.55294346809387, 45.117836594581604, 46.583319157361984, 43.98685768246651, 49.40126694738865, 49.264291897416115, 53.50919991731644, 52.181706950068474, 57.05066308379173, 56.277130991220474, 56.42273537814617, 56.52038633823395, 56.13505281507969, 55.54811730980873, 51.14908955991268, 48.995118141174316, 50.91200888156891, 46.27706699073315, 45.44685713946819, 45.49573391675949, 50.89377745985985, 46.55607081949711, 50.27213841676712, 52.860692515969276, 56.01609639823437, 56.381473392248154, 61.312499195337296, 61.82445332407951, 65.1606211066246, 60.347704365849495, 58.08011904358864, 56.0274425894022, 59.4568307697773, 60.65784752368927, 66.94025561213493, 61.959239691495895, 61.12600900232792, 19.334536716341972, 4.050503326579928, 6.41594622284174, 9.033095687627792, 42.36851692199707, 66.67626097798347, 62.54691615700722, 66.24168589711189, 65.6833590567112, 61.82633802294731, 25.10071210563183, 22.907521091401577, 43.149318024516106, 63.71658459305763, 25.982709378004074, 45.5842349678278, 42.66360528767109, 37.29445539414883, 57.609449699521065, 73.63952413201332, 7.331844326108694, 0.5591980030294508, 0.24548633198719472, 0.5716371699236333, 0.23888280586106703, 0.12142103732912801, 0.22145941969938576, 0.16086077608633786, 0.2109762720647268, 0.20202727726427838, 0.18858963972888887, 0.180297089391388, 0.1534649627865292, 0.17625483364099637], [0.09690829290775582, 0.04813989515241701, 0.019677106829476543, 0.03004791185958311, 0.021095217452966608, 0.05631378720863722, 0.06238586880499497, 0.08993801966425963, 0.019392782633076422, 0.04794310356373899, 0.03670288366265595, 0.07678416455746628, 0.09891261855955236, 0.06636877500568517, 0.12238881274242885, 0.03415211096580606, 0.04121399120776914, 0.16395139071391895, 1.1911072419025004, 31.054884307086468, 50.726506635546684, 33.09656225144863, 42.220488265156746, 22.111701294779778, 38.77569951117039, 49.26952421665192, 28.059398643672466, 36.643675714731216, 65.20233526825905, 69.98517662286758, 57.79918111860752, 54.06737096607685, 58.73114950954914, 14.165053758770227, 0.029425956854538526, 0.4768386692740023, 1.0391606390476227, 3.6541256960481405, 25.19962839782238, 66.89770549535751, 76.19174838066101, 71.56539022922516, 66.29654735326767, 63.44061680138111, 64.31692957878113, 50.36034308373928, 50.65106548368931, 60.59277601540089, 61.05547338724136, 57.250277772545815, 57.03023158013821, 50.28267905116081, 44.75393392145634, 45.975545570254326, 46.61295376718044, 44.90853622555733, 45.00051029026508, 44.522324949502945, 47.793322429060936, 50.69773457944393, 51.66262060403824, 50.674791410565376, 49.094357416033745, 47.36901059746742, 46.589459627866745, 49.64350774884224, 51.4519789069891, 50.521336644887924, 47.23724126815796, 44.52752307057381, 43.377864360809326, 42.86454610526562, 43.997326120734215, 42.68277905881405, 43.86522240936756, 43.13601493835449, 40.596569404006004, 42.212485894560814, 41.998165994882584, 44.11483861505985, 47.243180349469185, 45.93277886509895, 46.83394230902195, 48.497474044561386, 49.75500896573067, 50.79164274036884, 54.75945442914963, 56.91367283463478, 58.311990201473236, 57.15820871293545, 56.642853766679764, 55.09140461683273, 54.6667356044054, 53.01505923271179, 52.020382806658745, 52.39795334637165, 44.29565571248531, 42.121066600084305, 42.69976794719696, 40.874870270490646, 39.73961278796196, 39.86831188201904, 40.97959265112877, 44.98133271932602, 44.19397696852684, 42.000069692730904, 41.848435029387474, 38.79326976835728, 42.61043094098568, 41.748500391840935, 44.058544635772705, 46.07903301715851, 47.08031348884106, 51.88261739909649, 52.622293308377266, 53.407942950725555, 52.82977357506752, 53.4750397503376, 53.52947182953358, 47.5249732285738, 43.958583399653435, 41.946389973163605, 41.92517191171646, 45.6097923964262, 45.22403709590435, 41.81614816188812, 41.98127970099449, 43.105259388685226, 45.770063996315, 47.722163647413254, 48.06514084339142, 49.323777705430984, 51.02574437856674, 51.38977624475956, 50.36679893732071, 45.78391805291176, 49.98585417866707, 51.52813442051411, 56.57973535358906, 57.686334773898125, 60.6711620092392, 49.80521947145462, 29.553315080702305, 1.1783541762270033, 0.31769207620527595, 8.681204169988632, 41.207664012908936, 57.778673619031906, 56.275098100304604, 54.80326987802982, 59.11522530019283, 50.295381769537926, 32.13655136525631, 45.319430977106094, 48.74087378382683, 46.252299919724464, 29.399003461003304, 37.416436448693275, 25.03307953476906, 33.25429938733578, 50.71789629757404, 19.728191792964935, 0.5930559674743563, 0.030437865934800357, 0.14544700708938763, 0.02839738841430517, 0.10099492166773416, 0.02405894709227141, 0.037195773620624095, 0.030535640180460177, 0.061086843197699636, 0.043079769020550884, 0.016299383096338715, 0.049878910431289114, 0.07385492252069525, 0.04385929125419352, 0.05466959984914865, 0.016988433817459736, 0.03989735814684536, 0.01932246785145253, 0.033867634629132226, 0.041844761071843095, 0.08008229109691456, 0.04296171558962669, 0.059839864406967536, 0.03194211021764204, 0.07905843158368953, 0.05371972132707015, 0.0502319612132851, 0.009639327581680845, 0.01515814736194443, 0.04067785630468279, 0.057559081324143335, 0.18588348728371784, 1.2301857699640095, 41.281855031847954, 59.72930274903774, 34.4163416326046, 52.583216205239296, 25.52083656191826, 44.33036684989929, 51.172621697187424, 29.435192719101906, 42.145788073539734, 70.39784967899323, 76.43020838499069, 62.6797304302454, 60.094881132245064, 64.30482342839241, 17.196210958063602, 0.3379320463864133, 0.6086176168173552, 1.4269217569380999, 4.10620073787868, 29.093190170824528, 69.20494168996811, 78.19365575909615, 72.67534866929054, 68.3159489929676, 69.6582193672657, 65.20927369594574, 51.54784396290779, 54.685867577791214, 62.06319451332092, 63.15939009189606, 60.502872839570045, 59.62410159409046, 52.11189329624176, 47.50467471778393, 49.09938834607601, 48.349585980176926, 45.248025208711624, 46.48442946374416, 48.42500053346157, 51.38610564172268, 52.05123335123062, 52.68305204808712, 51.54147930443287, 51.339136362075806, 47.79528312385082, 49.917951822280884, 53.146570175886154, 54.53628860414028, 53.67506101727486, 50.8831038326025, 47.38950289785862, 44.051195830106735, 44.947567731142044, 47.32615269720554, 46.6388113796711, 46.12857475876808, 44.805246368050575, 43.992188796401024, 44.93161238729954, 43.89191597700119, 45.665345415472984, 47.57324203848839, 50.14961399137974, 48.258903846144676, 52.32269838452339, 51.995649933815, 54.3503949791193, 57.43756592273712, 59.952354580163956, 60.430703312158585, 58.99749621748924, 60.38009002804756, 58.62916678190231, 56.67200580239296, 55.228463262319565, 55.54530166089535, 55.05130156874657, 47.974523305892944, 45.757391676306725, 46.1140139400959, 44.893021658062935, 43.13214294612408, 44.73213829100132, 43.16696047782898, 47.05880284309387, 46.34182691574097, 45.55977188050747, 43.27738635241985, 43.54912877082825, 43.58292035758495, 44.56042170524597, 46.384616419672966, 48.835617899894714, 50.332821160554886, 54.681281223893166, 56.645247638225555, 55.27210012078285, 56.060531213879585, 53.5561615973711, 56.01883225142956, 51.20771661400795, 47.47785955667496, 44.149264767766, 44.698966071009636, 45.70142447948456, 46.92269414663315, 45.50179839134216, 45.45069873332977, 44.757129549980164, 47.498918026685715, 50.06479114294052, 51.12416289746761, 51.19122929871082, 52.62375243008137, 54.00751277804375, 52.59776182472706, 48.719560727477074, 52.89365954697132, 52.977768033742905, 58.73610444366932, 61.54290363192558, 65.03092646598816, 53.48006688058376, 35.328790470957756, 1.7408109200187027, 0.42109509638976306, 11.76746791228652, 47.358937337994576, 63.79709467291832, 59.67083528637886, 61.63247622549534, 63.62366437911987, 56.74023874104023, 35.237515568733215, 44.46325711905956, 49.069438353180885, 55.67200966179371, 20.977722443640232, 42.10809409618378, 32.6810659468174, 30.262972600758076, 63.31132493913174, 18.626281321048737, 1.1822343617677689, 0.01762620213412447, 0.19670213019708171, 0.030118722024781164, 0.08612800418632105, 0.057510964179527946, 0.071498061879538, 0.024111441052809823, 0.08318567808601074, 0.007531892570113996, 0.04444450438313652, 0.02695037856028648, 0.05236727593000978, 0.00858492405313882, 0.17299031896982342, 0.2669229410821572, 0.21077050419989973, 0.14853682019747794, 0.15686255937907845, 0.1375172779080458, 0.2077172789722681, 0.15464389405678958, 0.12438947218470275, 0.10836945017217658, 0.22569386201212183, 0.18230335204862058, 0.15960020857164636, 0.11245923305978067, 0.14972207456594333, 0.13508618023479357, 0.3267362143378705, 0.16245372185949236, 2.3606964759528637, 62.11953029036522, 72.4448910355568, 46.14774093031883, 62.275363728404045, 29.362346827983856, 53.176748156547546, 57.85526230931282, 36.61650337278843, 45.78334428369999, 77.44515672326088, 80.6287930905819, 69.4151160120964, 64.35921370983124, 71.58729985356331, 20.097505375742912, 0.5998555244877934, 0.5734285956714302, 2.326600905507803, 5.290381545200944, 32.38997496664524, 73.58100727200508, 79.73087087273598, 76.01299837231636, 72.28715389966965, 70.89159518480301, 70.0302042067051, 54.96853820979595, 56.306750401854515, 66.8850901722908, 65.84314808249474, 62.637750282883644, 64.2393909394741, 54.25796873867512, 49.44670110940933, 51.221973448991776, 50.430320128798485, 47.848837450146675, 50.045887157320976, 51.966266110539436, 54.57037657499313, 55.118177980184555, 56.98766626417637, 55.20324781537056, 53.68285819888115, 51.133092418313026, 51.652516946196556, 55.26155188679695, 57.47343599796295, 57.36569657921791, 54.09164786338806, 49.78435859084129, 46.20030350983143, 49.035950750112534, 51.366859674453735, 50.289936661720276, 49.83488827943802, 47.586830109357834, 46.56796798110008, 48.052479922771454, 46.02768637239933, 49.68596287071705, 52.49186150729656, 53.33660937845707, 51.922587454319, 56.202913373708725, 57.35245428979397, 58.519542664289474, 60.58499023318291, 64.91295799612999, 63.19018363952637, 62.61240944266319, 63.604182824492455, 61.214012280106544, 58.68718206882477, 57.45886757969856, 58.93516056239605, 57.15389594435692, 51.52072861790657, 47.530319541692734, 49.42652799189091, 48.25855426490307, 45.14503553509712, 44.89041119813919, 44.79822054505348, 51.229820027947426, 48.89499731361866, 46.83539763092995, 45.44590339064598, 45.619880855083466, 46.6750006377697, 48.10789994895458, 48.34817245602608, 51.09363153576851, 51.53971619904041, 57.4532400816679, 58.50004971027374, 56.78218849003315, 57.82132253050804, 56.340579986572266, 58.781618401408195, 55.10086990892887, 50.24045571684837, 47.54536293447018, 46.61074988543987, 50.241933837533, 51.2876833230257, 46.80553123354912, 47.81788811087608, 47.9695949703455, 51.71092361211777, 52.86931425333023, 53.85677106678486, 53.84679280221462, 54.76836875081062, 55.899617448449135, 54.70228269696236, 51.078432351350784, 55.0473003834486, 56.32250435650349, 62.1484961360693, 64.36960235238075, 67.01505839824677, 56.21683582663536, 36.59069135785103, 1.9637341517955065, 0.9153375145979226, 11.817555874586105, 50.513619258999825, 68.78356710076332, 65.6223039329052, 69.02847915887833, 69.15229931473732, 60.7613729685545, 38.88612158596516, 53.54442402720451, 60.403641164302826, 62.28800565004349, 37.19432696700096, 53.47493715584278, 39.06707167625427, 49.04433310031891, 68.94429847598076, 45.160189121961594, 1.748783248476684, 0.22545999643625692, 0.28893750510178506, 0.14531195105519146, 0.21523823321331292, 0.16824918275233358, 0.17854922771221027, 0.1330671229516156, 0.2942787716165185, 0.15421132586197928, 0.12411336356308311, 0.1277349254814908, 0.21501367416931316, 0.08506312617100775], [0.03338430724397767, 0.022255147887335625, 0.03648412450274918, 0.05267064734653104, 0.022043400167603977, 0.03926104815036524, 0.13316398806637153, 0.016708204420865513, 0.054927084274822846, 0.03828608874755446, 0.01625415105081629, 0.013863960557500832, 0.07983700386830606, 0.10993351897923276, 0.05099069960124325, 0.07673985834117047, 0.07579859244287945, 0.17892016796395183, 0.10263794756610878, 10.338159408420324, 50.70987492799759, 33.608451783657074, 32.4243289232254, 29.325583800673485, 26.119885817170143, 73.32281112670898, 56.95654213428497, 33.59297141432762, 52.18522936105728, 63.579031974077225, 63.03387902677059, 60.45640893280506, 56.78912311792374, 13.864115606993437, 0.5428115604445338, 0.3291194583289325, 1.6297864587977529, 6.928252307698131, 40.935830399394035, 76.72491297125816, 72.49827817082405, 67.39226415753365, 67.10209652781487, 65.80008119344711, 62.669315189123154, 48.449744805693626, 52.98319414258003, 60.05342535674572, 64.52866181731224, 62.76255838572979, 60.25476135313511, 58.97882021963596, 55.67895948886871, 53.11486467719078, 47.437152341008186, 46.064684987068176, 46.53185851871967, 48.46029303967953, 50.5480682104826, 53.8583517819643, 57.67449080944061, 56.934127137064934, 54.967573061585426, 53.84876489639282, 52.64466650784016, 54.5417071133852, 52.85759948194027, 53.16587693989277, 47.96781286597252, 44.565072655677795, 42.32530564069748, 43.14449988305569, 44.83666688203812, 43.19015063345432, 42.7516807615757, 43.19809600710869, 43.11439409852028, 42.09883779287338, 43.697529807686806, 44.070240408182144, 46.44536755979061, 46.750715374946594, 47.71478444337845, 50.84521986544132, 54.03367817401886, 53.79556395113468, 53.42258356511593, 56.782218888401985, 58.82736794650555, 56.00555956363678, 56.11921526491642, 56.08266122639179, 56.00557096302509, 55.72845183312893, 52.82808266580105, 53.505107536911964, 47.94306479394436, 41.57736137509346, 42.775421887636185, 41.56345412135124, 40.0010197609663, 42.53357246518135, 41.36515036225319, 45.20502291619778, 43.031657338142395, 41.9695383310318, 41.56868264079094, 41.15702413022518, 43.40392716228962, 43.25878635048866, 46.35405845940113, 46.87873050570488, 45.77099874615669, 48.69412489235401, 52.74270884692669, 55.516221821308136, 52.20442213118076, 51.339109763503075, 51.44709996879101, 49.45019692182541, 45.481887459754944, 43.77063408493996, 48.997569009661674, 48.42210128903389, 51.18154361844063, 48.88648197054863, 42.503056302666664, 42.19980977475643, 42.98781909048557, 46.71965964138508, 46.93502068519592, 44.568253085017204, 47.78980001807213, 44.60480712354183, 47.929856702685356, 45.56176297366619, 48.62162858247757, 48.33126336336136, 55.06289854645729, 54.76552650332451, 60.625385865569115, 48.73958185315132, 37.212964966893196, 6.754235420376062, 0.9301225212402642, 13.169333338737488, 48.270136043429375, 54.21281956136227, 52.96037256717682, 52.71429777145386, 57.20200516283512, 52.244726568460464, 57.57082857191563, 55.73553845286369, 62.48373694717884, 41.612334698438644, 21.503656022250652, 27.44761437177658, 22.347111962735653, 40.59693418443203, 43.06713983416557, 0.7195295684505254, 0.16896560759050772, 0.05735673476010561, 0.19587082089856267, 0.05097932618809864, 0.1026817194360774, 0.044493619716377, 0.029585167940240353, 0.02274679845868377, 0.04006894268968608, 0.05751282697019633, 0.03615414709202014, 0.043366171230445616, 0.0461310943501303, 0.026183615700574592, 0.056537670898251235, 0.0212095527240308, 0.010276282318955055, 0.021477525551745202, 0.009276777309423778, 0.04573754828015808, 0.061331310353125446, 0.051899043828598224, 0.02564525249908911, 0.03492655319860205, 0.07789671813952737, 0.08760032869759016, 0.12365775168291293, 0.0954962159448769, 0.026886913801718038, 0.06645061905146576, 0.07584278733702376, 0.33811541623435915, 0.14888402656652033, 14.021676052361727, 62.34439082443714, 37.92991429567337, 40.07055602967739, 33.51148098707199, 32.032786533236504, 72.20346719026566, 58.53819586336613, 38.918165266513824, 57.92840078473091, 68.5849517583847, 68.59530240297318, 64.53422471880913, 64.12320837378502, 17.888446412980556, 0.737706427462399, 0.718756903661415, 2.2089307196438313, 9.521299190819263, 44.261879324913025, 78.86348381638527, 73.83271336555481, 69.96313780546188, 68.76822352409363, 69.34124797582626, 63.78934308886528, 51.77986331284046, 55.13204723596573, 62.72527098655701, 67.04052463173866, 65.63480526208878, 62.955204248428345, 62.31062963604927, 57.59504087269306, 53.56869712471962, 49.85941596329212, 47.18195043504238, 47.56530426442623, 51.75012610852718, 55.19819788634777, 56.57673731446266, 59.47025544941425, 61.473352164030075, 56.861418038606644, 54.114743024110794, 53.76638911664486, 55.6081198900938, 56.66096739470959, 54.98917490243912, 51.81201718747616, 46.15749880671501, 45.12381747364998, 45.17475374042988, 46.58142305910587, 43.575297966599464, 45.09484402835369, 45.73956683278084, 45.278408378362656, 44.45039100944996, 46.74058511853218, 45.202355459332466, 47.13778540492058, 49.83987741172314, 50.054014921188354, 52.65195831656456, 55.87621070444584, 54.902208968997, 56.19607754051685, 59.4905311614275, 59.72093939781189, 59.01376694440842, 58.7098478525877, 58.183918073773384, 58.73618043959141, 58.14646728336811, 55.641941875219345, 58.11299107968807, 50.44459976255894, 45.96811696887016, 46.172029227018356, 44.50709156692028, 43.80229398608208, 45.67422553896904, 43.7939078360796, 47.02780030667782, 46.94616548717022, 45.283424109220505, 44.681847989559174, 44.824515134096146, 45.39098113775253, 47.833949849009514, 48.98843429982662, 48.76175366342068, 49.339075684547424, 51.680738031864166, 55.33081457018852, 57.19640426337719, 56.48047707974911, 53.79241392016411, 54.938417226076126, 51.85721196234226, 47.95102916657925, 46.342966854572296, 50.50464794039726, 51.96987211704254, 54.70119595527649, 50.634760558605194, 46.895920783281326, 43.8151752948761, 46.70403108000755, 47.0018021017313, 49.58645761013031, 47.076418697834015, 49.79304872453213, 46.35561257600784, 49.081658497452736, 47.51252509653568, 51.57730758190155, 51.89391419291496, 59.44060564041138, 57.66624145209789, 65.50799086689949, 54.840203896164894, 42.66924798488617, 9.002105500549078, 0.9788405383005738, 15.571838021278381, 54.36834901571274, 60.49677416682243, 59.4066696614027, 59.72692407667637, 65.88386669754982, 57.449599876999855, 61.79149769246578, 56.78173251450062, 65.63966140151024, 46.54248654842377, 18.459990844130516, 38.8472268730402, 22.436870746314526, 45.64562067389488, 50.60953751206398, 3.091373755596578, 0.5401077086571604, 0.023167221406765748, 0.22676920430967584, 0.03051405852602329, 0.16334513027686626, 0.051697610106202774, 0.06531649865792133, 0.03016505615960341, 0.052530325774569064, 0.017885228371596895, 0.04383539780974388, 0.043246203058515675, 0.051605049447971396, 0.07301901932805777, 0.09480673106736504, 0.10484058249858208, 0.11487116105854511, 0.15061018784763291, 0.08037731706281193, 0.1836377929430455, 0.14914248691638932, 0.17106030456488952, 0.16710127325495705, 0.1689774967962876, 0.1416237442754209, 0.18459033948602155, 0.16628828016109765, 0.29377096449024975, 0.1279386004898697, 0.20663104194682091, 0.15263516746927053, 0.518978942418471, 0.48735056770965457, 29.639494456350803, 80.2455684542656, 44.18423809111118, 48.45123052597046, 40.1226132363081, 37.1578299254179, 83.08828711509705, 66.1010554432869, 45.208305940032005, 62.49157212674618, 75.59093222022057, 73.75614747405052, 70.06871894001961, 71.5693648159504, 20.175068713724613, 1.188717526383698, 1.497181411832571, 2.4383973190560937, 12.251219004392624, 48.59649293124676, 82.91209056973457, 76.26822307705879, 73.86445686221123, 72.53637492656708, 70.94958767294884, 66.59942150115967, 55.271518751978874, 60.91831214725971, 67.23657131195068, 70.70088341832161, 68.48937928676605, 66.31536394357681, 68.50033029913902, 62.89134867489338, 57.02680416405201, 53.06298986077309, 49.98466104269028, 50.492936968803406, 54.41644303500652, 57.7610881626606, 58.59566777944565, 62.377228662371635, 64.4434703886509, 59.846613854169846, 58.415397852659225, 56.43814355134964, 60.47075696289539, 60.283183827996254, 59.83524486422539, 53.06847296655178, 49.37415920197964, 45.862019062042236, 49.74909268319607, 50.26743046939373, 47.28137969970703, 50.04858121275902, 48.56340430676937, 48.564403653144836, 45.9368484467268, 51.92082814872265, 49.41680431365967, 51.318727657198906, 52.46261067688465, 54.46886122226715, 57.622870579361916, 61.050320863723755, 59.10260617733002, 57.33187459409237, 61.04413479566574, 63.97315442562103, 60.79000823199749, 62.44551099836826, 60.37578105926514, 63.54885019361973, 61.87344029545784, 59.38138961791992, 61.45837716758251, 54.172883704304695, 48.12255196273327, 51.845945566892624, 47.41423197090626, 47.4171008169651, 48.315349817276, 46.58672757446766, 52.19882883131504, 48.053114488720894, 48.83066676557064, 48.24677489697933, 47.60451056063175, 47.58266933262348, 50.95072880387306, 53.962276205420494, 50.637599006295204, 50.69819815456867, 54.01747964322567, 56.7257197201252, 61.7218854278326, 56.68368637561798, 56.15331083536148, 58.00695396959782, 54.390076249837875, 51.11706867814064, 48.80860134959221, 54.85246583819389, 54.5093784481287, 56.85845799744129, 54.398925974965096, 48.26452374458313, 46.50793880224228, 48.03981900215149, 50.14582559466362, 51.957982555031776, 48.50799188017845, 52.461482137441635, 50.19135855138302, 53.047262504696846, 50.808358043432236, 54.5832958817482, 55.21234072744846, 63.01416948437691, 60.63552372157574, 66.93220764398575, 57.23660610616207, 44.848826229572296, 9.070184547454119, 1.4184749289415777, 16.235271021723747, 57.878186479210854, 64.48091357946396, 64.14040625095367, 63.80613058805466, 69.12077620625496, 60.19571252167225, 68.23350101709366, 68.00238221883774, 76.23654037714005, 49.386538937687874, 34.002927616238594, 39.34155374765396, 36.901966854929924, 54.991796761751175, 68.41566324234009, 11.271542273461819, 1.290718896780163, 0.3013123129494488, 0.4564058891264722, 0.1568181937909685, 0.35978589090518653, 0.17427193379262462, 0.16290393832605332, 0.15310561488149688, 0.2331879356643185, 0.1661974858143367, 0.14434625365538523, 0.17835766455391422, 0.10650372802047059, 0.15943083562888205], [0.03467852744506672, 0.016661271001794375, 0.017796302381611895, 0.08559509020415135, 0.013939653126726625, 0.07019554817816243, 0.04473627974221017, 0.06238921589101665, 0.05693121696822345, 0.1029618430766277, 0.04697250798926689, 0.041213824224541895, 0.025365062065247912, 0.06813928703195415, 0.058408974000485614, 0.08306850781082176, 0.0899525212298613, 0.12743710161885247, 0.2642477658810094, 4.975633509457111, 40.5795881152153, 56.10776647925377, 70.17226338386536, 37.176726311445236, 20.43882206082344, 48.81403125822544, 77.17918619513512, 39.516868740320206, 40.186366215348244, 65.92187985777855, 67.40016773343086, 63.304420709609985, 59.841571524739265, 31.08680449426174, 1.2069997703656554, 0.7785125565715134, 3.4514543088153005, 21.727488711476326, 60.77900782227516, 73.83189260959625, 70.80907121300697, 65.05739584565163, 62.467542216181755, 63.92209276556969, 56.96732975542545, 49.70611318945885, 53.49614001810551, 63.66841457784176, 61.60944566130638, 61.98303021490574, 63.26109543442726, 62.70613521337509, 61.25314638018608, 62.80187867581844, 60.73983572423458, 55.6193520873785, 50.30336134135723, 48.97247515618801, 52.214791774749756, 54.57742139697075, 57.41400718688965, 59.578363448381424, 57.678112015128136, 56.83003552258015, 56.67050488293171, 58.16037453711033, 55.9088509529829, 55.090222880244255, 49.610669910907745, 43.342670649290085, 43.80012050271034, 44.262206107378006, 45.343913063406944, 44.33396525681019, 41.92483372986317, 41.956638023257256, 41.59090004861355, 43.450691252946854, 42.64012634754181, 45.29348976910114, 47.221673503518105, 48.31837445497513, 49.39549505710602, 53.73440243303776, 54.47801873087883, 55.01399517059326, 54.87318232655525, 50.257607996463776, 56.079431399703026, 57.36384607851505, 57.587847858667374, 59.12805341184139, 56.53224930167198, 55.85696093738079, 55.62825120985508, 52.93958008289337, 49.42886486649513, 44.86344404518604, 42.1198620647192, 42.47543178498745, 41.55288688838482, 39.28810961544514, 40.957303047180176, 43.05012434720993, 45.13804771006107, 42.691419795155525, 45.59798642992973, 39.58808071911335, 41.76512070000172, 43.6808905005455, 43.33911783993244, 41.674214377999306, 43.1130413711071, 45.482917204499245, 51.10372379422188, 54.27784167230129, 53.08171905577183, 53.428978621959686, 53.13328988850117, 50.61355009675026, 49.294614270329475, 50.65219022333622, 52.35182762145996, 53.959293365478516, 56.01356953382492, 51.56811587512493, 47.21563562750816, 43.3189295232296, 42.75513097643852, 43.5971923917532, 45.5044012516737, 45.761601850390434, 45.73210783302784, 45.59685409069061, 48.49230632185936, 45.999940261244774, 50.10519817471504, 49.70592699944973, 54.995740950107574, 58.40177558362484, 58.09525743126869, 51.25524066388607, 40.55686913430691, 13.435947932302952, 2.4674505600705743, 16.0448195412755, 54.26073499023914, 54.908170849084854, 54.68908600509167, 46.82423382997513, 52.01872989535332, 55.47110304236412, 56.19226634502411, 63.20456966757774, 57.529349997639656, 26.20027430355549, 21.431874074041843, 33.01489323377609, 30.700313933193684, 49.65125173330307, 25.771317221224308, 0.6466726341750473, 0.043343435536371544, 0.12353032492683269, 0.0751272753404919, 0.03707877032866236, 0.04777825772180222, 0.03080237547692377, 0.008615802962594898, 0.03485340341285337, 0.011836041103379102, 0.047013760267873295, 0.016574586297792848, 0.01621368730411632, 0.04686724176281132, 0.05104937750729732, 0.035097043073619716, 0.033704440065776, 0.05447387324238662, 0.013920105884608347, 0.019669922839966603, 0.02361721151828533, 0.025890664037433453, 0.008656196205265587, 0.05466743648867123, 0.06691687332931906, 0.021288257485139184, 0.05343720054952428, 0.05414880142780021, 0.11300742044113576, 0.02987046435009688, 0.07273951167007908, 0.07040257769403979, 0.23899544903542846, 0.23198166367365047, 6.28179014660418, 55.70065252482891, 60.80521121621132, 61.03505328297615, 43.37857872247696, 26.329463571310043, 54.66967664659023, 79.31125938892365, 43.744502887129784, 44.526508525013924, 70.88642746210098, 73.94114434719086, 66.74966543912888, 66.06683447957039, 33.931875228881836, 2.6551191648468375, 0.9642544866073877, 3.689193776808679, 24.92583978921175, 65.67955166101456, 76.3839040696621, 72.0005352795124, 67.13510155677795, 66.30067393183708, 68.27489599585533, 60.57041421532631, 51.97108045220375, 56.789997071027756, 64.67618510127068, 65.60574442148209, 67.26140677928925, 65.01764237880707, 63.946890234947205, 64.54499334096909, 65.29562786221504, 60.42533040046692, 55.69034747779369, 52.763474732637405, 52.25568898022175, 55.557886585593224, 57.81901225447655, 63.00851918756962, 63.32668371498585, 60.75769856572151, 58.87811802327633, 58.47671136260033, 60.2960841357708, 60.47229588031769, 57.91502170264721, 53.5625034570694, 46.52254901826382, 46.75719402730465, 46.264185681939125, 47.02785350382328, 45.879965499043465, 46.518589630723, 43.46627801656723, 44.64155875146389, 44.72599782049656, 43.64662013947964, 46.38441503047943, 49.33832332491875, 49.229185581207275, 52.01106570661068, 55.94827003777027, 55.13206243515015, 56.477646231651306, 56.18588648736477, 54.1815472394228, 59.1901420801878, 59.77987043559551, 58.3954831212759, 60.32756544649601, 60.06284885108471, 59.609483778476715, 58.478466868400574, 56.138126850128174, 52.23187945783138, 47.7615637332201, 46.56891793012619, 46.1994219571352, 45.710467994213104, 43.57804521918297, 42.44897000491619, 45.85874363780022, 47.10683986544609, 44.60647903382778, 48.182565942406654, 45.046628415584564, 44.04432959854603, 45.554547160863876, 45.33610828220844, 44.0124037116766, 48.452993631362915, 48.569453582167625, 54.509982615709305, 56.00646011531353, 56.08743377029896, 56.23465307056904, 55.32981522381306, 53.56322541832924, 53.564825132489204, 53.612976148724556, 54.977999702095985, 57.92387902736664, 57.783381566405296, 54.53217342495918, 48.85076388716698, 46.17439649999142, 45.4006440192461, 46.32645674049854, 47.93870262801647, 47.8216727077961, 48.71042221784592, 47.7495601773262, 50.965772196650505, 49.35693472623825, 53.73160198330879, 53.182269260287285, 59.04144085943699, 59.88778084516525, 61.49031825363636, 55.74235148727894, 49.45167504251003, 17.075183652341366, 3.06457141879946, 18.62489629536867, 60.52363112568855, 60.538571923971176, 62.759518548846245, 52.22073845565319, 58.314760252833366, 59.29345853626728, 63.44121336936951, 65.38416311144829, 65.72690472006798, 26.173472441732883, 25.18597573041916, 36.499910429120064, 27.36944306641817, 59.64832529425621, 29.76253565400839, 1.3276707264594734, 0.08219028735766187, 0.11053647685912438, 0.07359133393038064, 0.10153265960980207, 0.0803648415603675, 0.09647432947531343, 0.028234533383511007, 0.04690246409154497, 0.05851447400345933, 0.04812580918951426, 0.08517323120031506, 0.028188557334942743, 0.017083512211684138, 0.010154751926165773, 0.10997908684657887, 0.10053879028419033, 0.10427988992887549, 0.11382220211089589, 0.059482323631527834, 0.12703015236184, 0.17468523583374918, 0.15917525481199846, 0.26069967658258975, 0.3061993554001674, 0.11252190000959672, 0.21496025437954813, 0.10088727314723656, 0.27821029478218406, 0.18746133777312934, 0.1516777672804892, 0.2544295083498582, 0.6551316333934665, 0.5383963754866272, 12.273335717618465, 78.84855821728706, 71.07499614357948, 76.19286552071571, 57.67470359802246, 31.5686072409153, 63.81634443998337, 84.25163269042969, 50.50916589796543, 51.16931967437267, 76.70682594180107, 78.87947335839272, 72.14813455939293, 67.34177246689796, 38.969428315758705, 2.6838503731414676, 2.2343299817293882, 6.026184037327766, 28.61281044781208, 67.99590736627579, 78.97551700472832, 74.92152974009514, 68.72468546032906, 68.40325310826302, 72.09021806716919, 65.28995096683502, 53.81023496389389, 60.563388392329216, 68.49064081907272, 67.23226234316826, 68.7793493270874, 67.91392296552658, 66.39392852783203, 67.40758493542671, 66.72618269920349, 64.39083561301231, 59.20331597328186, 55.30808039009571, 51.995824724435806, 57.287785559892654, 60.22210970520973, 66.0946261882782, 65.7624252140522, 62.23481610417366, 60.16355864703655, 60.25795318186283, 63.209931179881096, 62.79519863426685, 61.11096940934658, 56.208050698041916, 46.80592641234398, 49.74960945546627, 49.824362844228745, 51.42428979277611, 49.759466126561165, 47.93733850121498, 47.04511597752571, 46.49836711585522, 47.73534134030342, 48.38587403297424, 49.41433064639568, 52.45721496641636, 54.002778232097626, 55.99398158490658, 61.83544613420963, 60.82582890987396, 61.46237455308437, 59.95468005537987, 56.03460140526295, 62.16733172535896, 63.337391540408134, 61.28442630171776, 63.16231973469257, 63.74376833438873, 65.15011087059975, 62.92433850467205, 59.03508000075817, 56.41687609255314, 51.86108015477657, 49.68753218650818, 50.44027179479599, 49.36317399144173, 44.834478199481964, 45.046225637197495, 49.023210033774376, 50.32533176243305, 46.34593449532986, 52.246219888329506, 44.869903698563576, 46.809087842702866, 48.35131108760834, 46.961330473423004, 46.656286641955376, 50.071311593055725, 49.1144735366106, 57.42389425635338, 58.76802273094654, 59.160598665475845, 59.36269462108612, 59.239060655236244, 57.17915318906307, 55.89839771389961, 56.07077166438103, 57.81490847468376, 60.60357503592968, 61.03658840060234, 56.654902920126915, 51.68631233274937, 48.020033463835716, 47.913707569241524, 49.54413928091526, 52.2055658698082, 51.27896659076214, 51.49033024907112, 50.76307587325573, 52.30880632996559, 51.15918941795826, 56.08011916279793, 55.54305978119373, 59.98697072267532, 64.68579858541489, 63.99100586771965, 62.17143550515175, 51.970354691147804, 18.392873145639896, 2.812997130677104, 20.24819578975439, 65.87817460298538, 64.41726699471474, 67.80451163649559, 55.86103431880474, 63.77035170793533, 63.49830150604248, 68.60258281230927, 74.46116164326668, 68.68717387318611, 32.544725462794304, 33.7491050362587, 48.42863693833351, 44.24817346036434, 66.95625275373459, 50.47127053141594, 1.4879938610829413, 0.1640629948815331, 0.25999665493145585, 0.11371486529242247, 0.28067787643522024, 0.18763427302474156, 0.14321340975584462, 0.12826309714000672, 0.13951744011137635, 0.11431515144067816, 0.11544432170921937, 0.1875583958462812, 0.1326469040941447, 0.15291379939299077, 0.1086886775738094], [0.0503498810576275, 0.05157278457772918, 0.03140923334285617, 0.04235806380165741, 0.008729217042855453, 0.06419426004868001, 0.05024378733651247, 0.021776551693619695, 0.024617233248136472, 0.0846906793594826, 0.03137859748676419, 0.042904110086965375, 0.06153591675683856, 0.02256948453577934, 0.09426237316802144, 0.038210515849641524, 0.037635169574059546, 0.043081308976979926, 0.2546653035096824, 0.25708794069942087, 22.073384150862694, 50.25455676019192, 42.96877071261406, 43.729368299245834, 25.83817843347788, 40.85766479372978, 77.99380168318748, 69.95059087872505, 57.99878440797329, 57.49117724597454, 68.71450960636139, 63.866600543260574, 62.481244280934334, 39.720298424363136, 13.444706462323666, 1.695013758726418, 2.629419481381774, 29.74094521254301, 68.77931892871857, 77.17830464243889, 67.70456939935684, 62.60284535586834, 61.78325593471527, 58.08500558137894, 54.29694704711437, 48.89060854911804, 50.46276278793812, 63.08352716267109, 65.75970456004143, 61.452153101563454, 61.318647265434265, 64.3240275979042, 62.240530997514725, 64.35111254453659, 62.688447162508965, 63.348737731575966, 58.86212848126888, 54.94519226253033, 52.77844972908497, 54.81356352567673, 54.934514835476875, 56.84049256145954, 60.14325253665447, 61.38422414660454, 58.387621343135834, 58.55626009404659, 55.37049204111099, 51.98836572468281, 46.92861042916775, 43.67091603577137, 42.63683572411537, 44.406655356287956, 45.43815180659294, 41.50327295064926, 44.19228985905647, 43.35996352136135, 42.64130808413029, 44.58269990980625, 42.63892941176891, 46.90785214304924, 48.31992097198963, 46.96864128112793, 53.69067817926407, 53.89054365456104, 56.933055594563484, 54.161461517214775, 58.43596234917641, 50.59593044221401, 50.130333825945854, 57.623907923698425, 55.726453140378, 60.66285565495491, 55.895004495978355, 55.3628696501255, 53.74055430293083, 56.5334652364254, 52.75046043097973, 43.56508031487465, 42.763064950704575, 43.044322058558464, 41.4058917760849, 40.70719666779041, 42.07977041602135, 42.882089763879776, 42.76465326547623, 42.96639584004879, 43.7054143846035, 43.19139316678047, 41.796119436621666, 43.402061462402344, 44.97556082904339, 43.9173898100853, 41.80254869163036, 44.93368327617645, 49.00801084935665, 55.41805788874626, 54.74635653197765, 55.38984440267086, 54.0976819396019, 57.161499336361885, 56.617805510759354, 52.661412209272385, 55.241823345422745, 56.45187981426716, 53.12710762023926, 54.3128377944231, 47.12071672081947, 45.76668977737427, 41.04973688721657, 43.05612042546272, 46.772746592760086, 45.04393436014652, 44.823888167738914, 45.29437132179737, 44.62251037359238, 49.186445474624634, 49.452963173389435, 52.827394902706146, 53.874937891960144, 56.733699291944504, 56.043595522642136, 53.435195088386536, 44.47104290127754, 26.11072450876236, 6.437735678628087, 19.563126750290394, 55.31120002269745, 56.615567430853844, 52.75856539607048, 47.13878095149994, 62.084955945611, 65.14019340276718, 63.516468331217766, 58.53012889623642, 46.47439420223236, 13.593933954834938, 34.6291796118021, 31.42091866582632, 34.608440324664116, 51.487161219120026, 10.283739678561687, 0.3706140036229044, 0.07067680868203752, 0.06571995239937678, 0.028872273869637866, 0.10937788043520413, 0.07228953269077465, 0.05642638585413806, 0.01927002398588229, 0.013769413726549828, 0.06029468589986209, 0.02497739937098231, 0.024099275397020392, 0.024670647471793927, 0.06614714744500816, 0.012251164189365227, 0.01677704232861288, 0.023978568788152188, 0.06466185761382803, 0.01768311187333893, 0.004849226315855049, 0.06347344169626012, 0.018177725469286088, 0.02037985574133927, 0.04721420322312042, 0.06733880654792301, 0.01190550705359783, 0.06434078226448037, 0.05095506909128744, 0.040911655087256804, 0.10467597414390184, 0.03338259288284462, 0.07122451366740279, 0.01834195903938962, 0.331193286110647, 0.45723189949057996, 31.10691111534834, 60.50342760980129, 40.86384326219559, 52.54982739686966, 32.42212504148483, 48.84835101664066, 84.85874131321907, 71.73734620213509, 63.48743788897991, 63.927184492349625, 75.7338197529316, 68.17862436175346, 67.37116768956184, 44.05447505414486, 15.347768794745207, 2.90226882789284, 3.2823030604049563, 31.07009869068861, 70.25728762149811, 76.75553172826767, 72.1098630130291, 66.22821941971779, 65.96494674682617, 60.0414028018713, 55.81813082098961, 52.31488600373268, 55.99679343402386, 63.993384540081024, 66.24571368098259, 63.78379538655281, 66.6002194583416, 66.99086129665375, 64.34105828404427, 65.87865337729454, 65.64020097255707, 66.44589453935623, 60.569775849580765, 56.837460324168205, 55.427124202251434, 58.57613302767277, 58.48302662372589, 59.400498792529106, 61.57673701643944, 64.21735972166061, 60.720494762063026, 62.06832803785801, 58.7384033203125, 54.79823134839535, 49.49061155319214, 45.41015110909939, 46.27627283334732, 47.571969106793404, 45.84802061319351, 44.828159138560295, 45.19109286367893, 44.75315496325493, 45.95332056283951, 45.77617026865482, 46.31418339908123, 48.455866277217865, 50.396216958761215, 49.61525246500969, 57.0968572050333, 56.89809747040272, 59.34050761163235, 57.157520949840546, 59.512585178017616, 52.120746821165085, 55.20020417869091, 60.164246410131454, 59.39417593181133, 61.13806955516338, 58.571242690086365, 57.486902475357056, 56.18884652853012, 58.219917342066765, 54.7372218221426, 46.279286071658134, 45.72700850665569, 46.582274213433266, 43.41226391494274, 45.21869458258152, 44.75263059139252, 44.61837239563465, 45.43427601456642, 45.56413024663925, 47.09349878132343, 44.84353311359882, 44.86885115504265, 45.28662733733654, 45.521291345357895, 45.09138621389866, 43.62723357975483, 46.42358332872391, 51.575932055711746, 57.523904889822006, 55.382035821676254, 58.89091193675995, 56.40010379254818, 58.95617723464966, 58.9820272475481, 56.32364809513092, 58.75433586537838, 59.86112907528877, 56.46954506635666, 54.955797493457794, 50.01201197504997, 49.14872109889984, 44.73326303064823, 46.17710955440998, 48.0586963891983, 47.5723072886467, 46.01607419550419, 47.576627656817436, 46.8021722137928, 51.654188856482506, 52.23722957074642, 55.59300050139427, 57.60726481676102, 60.2525270730257, 59.71116632223129, 59.125268161296844, 50.291813760995865, 31.707717776298523, 8.062075842171907, 22.046510092914104, 60.611793994903564, 63.65699999034405, 58.21856081485748, 52.658368572592735, 66.67022690176964, 69.3776424229145, 69.21903133392334, 64.83883157372475, 54.5724892616272, 15.076080523431301, 41.110001653432846, 30.341964662075043, 37.16919131577015, 61.336988881230354, 9.608669802546501, 0.4760404449189082, 0.047580479076714255, 0.0775780547701288, 0.08857142893248238, 0.27783901314251125, 0.051842688844772056, 0.10726006556069478, 0.012086752503819298, 0.048041734989965335, 0.03329680432216264, 0.01629027508897707, 0.013494336690200726, 0.01422480852852459, 0.01265550943571725, 0.02987825504533248, 0.11216655228054151, 0.09674381813965738, 0.21589858137303963, 0.15196793217910454, 0.11216896426049061, 0.17588622373295948, 0.13217253814218566, 0.1392825652146712, 0.21430780267110094, 0.2459928032476455, 0.17989288608077914, 0.1549380665528588, 0.11612059635808691, 0.16815254028188065, 0.19162725016940385, 0.17899980040965602, 0.21383741463068873, 0.23737997165881097, 0.2504364273045212, 0.8183345978613943, 56.25950753688812, 69.81449738144875, 54.084378853440285, 62.46585510671139, 39.71359558403492, 51.76894649863243, 90.0901485979557, 75.56255534291267, 69.984500259161, 67.19114854931831, 81.88427612185478, 74.85542088747025, 70.92508658766747, 48.26699361205101, 17.617435455322266, 4.507249742746353, 4.734343606978655, 34.298300966620445, 73.72237488627434, 81.60867691040039, 75.08012562990189, 69.22711730003357, 68.47239419817924, 65.67672461271286, 59.23910245299339, 55.5281949788332, 58.2812612503767, 69.26598161458969, 70.53259804844856, 67.77303412556648, 70.97655102610588, 71.60742357373238, 67.10727944970131, 67.92130216956139, 67.83840581774712, 70.2726311981678, 62.8253348171711, 59.33994524180889, 56.2371951341629, 60.349197685718536, 60.67697189748287, 60.00314265489578, 64.1502097249031, 66.19726628065109, 62.89450630545616, 63.091172352433205, 61.008036732673645, 59.22615274786949, 51.85220003128052, 47.54094377160072, 48.430510237812996, 51.41532987356186, 49.38708230853081, 48.04424196481705, 49.42495867609978, 47.74952977895737, 48.13194125890732, 51.04668125510216, 49.618292301893234, 53.839318603277206, 55.199771001935005, 52.7752161026001, 60.96908122301102, 59.943102076649666, 62.60522022843361, 61.28362074494362, 60.98126336932182, 57.89101839065552, 56.97427578270435, 62.255194410681725, 61.76675722002983, 66.0068129003048, 61.93820022046566, 60.244441106915474, 60.907741114497185, 61.69690176844597, 57.90253937244415, 50.55268496274948, 48.289268016815186, 49.99715097248554, 45.80252945423126, 48.207177221775055, 49.52792555093765, 47.03980006277561, 48.7167526781559, 48.80492314696312, 49.13447946310043, 47.70146615803242, 47.0454465597868, 47.268023416399956, 49.72952753305435, 48.675992265343666, 46.334478110075, 48.59502620995045, 53.04293833673, 60.98034381866455, 59.86820809543133, 60.83746388554573, 61.51021398603916, 61.85735195875168, 63.42441827058792, 59.116152450442314, 61.573450192809105, 63.856105506420135, 59.650293588638306, 59.71102572977543, 53.1204541772604, 51.27862460911274, 46.80357053875923, 48.34931619465351, 51.1479914188385, 49.59686525166035, 48.771021366119385, 48.774691969156265, 48.59439544379711, 55.812134742736816, 55.40789343416691, 58.9171951264143, 59.00009147822857, 63.20251017808914, 64.59986239671707, 63.25018621981144, 54.29589070379734, 34.76848393678665, 8.061797507107258, 25.073724053800106, 64.56897005438805, 68.77818658947945, 64.07613649964333, 60.10213874280453, 71.45924672484398, 74.94891867041588, 74.5794340968132, 71.888707280159, 57.97041513025761, 21.87344077974558, 51.875393986701965, 46.66637510061264, 49.3767848610878, 70.17252177000046, 21.97404608130455, 0.85616679280065, 0.18186288740253076, 0.22021742071956396, 0.18385395087534562, 0.3880957671208307, 0.2144646184751764, 0.270770798670128, 0.13861153012840077, 0.28301252459641546, 0.11925104205147363, 0.21678430493921041, 0.12123147796955891, 0.11956431000726297, 0.10394001597887836, 0.12263545810128562], [0.023937978876347188, 0.06043597597454209, 0.0713590501982253, 0.021152188419364393, 0.0036263761376176262, 0.019456536829238757, 0.051484368814271875, 0.062306073086801916, 0.02657339722645702, 0.026670811530493665, 0.04501727540628053, 0.047510386939393356, 0.0820564707100857, 0.05345998077245895, 0.07991866979864426, 0.01715860085823806, 0.05193262601096649, 0.1408726759837009, 0.3372837061760947, 0.11324718609103002, 8.548386096954346, 60.7770661264658, 34.1965614259243, 33.572976887226105, 35.017750561237335, 24.598629847168922, 63.65570425987244, 65.26156648993492, 68.71643230319023, 60.64794525504112, 64.58892658352852, 63.11443090438843, 64.35624986886978, 51.3419596105814, 15.938524045050144, 3.829723773524165, 0.9249132382683456, 26.563329622149467, 74.0566049516201, 75.86558908224106, 68.92659142613411, 64.35458555817604, 60.63802778720856, 54.96833682060242, 52.30372600257397, 49.442810118198395, 52.21581012010574, 60.71561202406883, 66.38407185673714, 63.79881978034973, 59.547433108091354, 61.945974603295326, 62.71959789097309, 66.134934425354, 64.85066413879395, 64.25335139036179, 65.19510805606842, 60.36022089421749, 57.88558468222618, 55.71481056511402, 54.88674379885197, 55.36367520689964, 59.4161881506443, 58.265226110816, 59.331946671009064, 56.44921235740185, 57.00300984084606, 48.10969725251198, 44.757851511240005, 42.859545573592186, 43.5105000436306, 45.706489607691765, 45.23448273539543, 43.28585609793663, 43.898121044039726, 41.967269852757454, 41.33541315793991, 43.913350626826286, 43.365910202264786, 48.826323598623276, 49.283328875899315, 51.14025503396988, 50.479223504662514, 54.294127598404884, 57.81246520578861, 58.82432051002979, 58.11562813818455, 60.487084686756134, 49.50880877673626, 56.9250950217247, 58.74000683426857, 58.22571203112602, 57.86994852125645, 58.009731620550156, 55.97763866186142, 55.968355759978294, 53.12006279826164, 44.466004371643066, 43.56165289878845, 44.10528592765331, 41.1383481323719, 41.088475808501244, 42.34595373272896, 41.51140831410885, 42.84575991332531, 45.173214823007584, 43.491603657603264, 43.07638853788376, 40.60489095747471, 42.01266601681709, 43.93384672701359, 43.34375359117985, 42.08467215299606, 42.3947811126709, 45.50815165042877, 55.72966396808624, 53.64750489592552, 56.31133675575256, 56.95994675159454, 55.083808824419975, 56.99001833796501, 56.615415439009666, 56.53692305088043, 53.54086361825466, 53.86721670627594, 51.24061904847622, 52.132640182971954, 47.767886593937874, 47.170034274458885, 47.53841310739517, 50.23256354033947, 49.96618263423443, 47.84142404794693, 45.766214802861214, 45.918966606259346, 47.62206941843033, 50.9517889469862, 51.27510219812393, 52.32471227645874, 56.24894790351391, 55.233908370137215, 55.83323501050472, 51.78664214909077, 37.01176196336746, 14.02140911668539, 15.167435221374035, 50.37780314683914, 61.642678678035736, 51.547057405114174, 55.19202321767807, 60.39785027503967, 59.26726654171944, 55.50608016550541, 43.694459572434425, 15.25608541443944, 21.139994636178017, 39.47252131998539, 27.804251834750175, 43.38404282927513, 45.07069632411003, 0.5713862052652985, 0.01826712272304576, 0.0661219070025254, 0.14332902152091265, 0.04611245160049293, 0.06208693543158006, 0.04700004908954725, 0.08483959129080176, 0.016588343860348687, 0.07781203166814521, 0.053601359904860146, 0.0426218342181528, 0.026454158214619383, 0.020102047601540107, 0.07311190653126687, 0.015449100792466197, 0.030574217016692273, 0.034845414193114266, 0.040988129694596864, 0.07296897631022148, 0.018535407252784353, 0.026022027886938304, 0.055298072766163386, 0.03908299950126093, 0.024718651438888628, 0.049789229306043126, 0.044259627975407057, 0.08475858587189578, 0.07600539931445383, 0.022798535428592004, 0.07956980101880617, 0.06398867029929534, 0.07743246023892425, 0.09305757062975317, 0.37899780843872577, 0.20864868914941326, 11.197229661047459, 76.26690834760666, 43.318591341376305, 39.77124609053135, 42.455448657274246, 31.703575998544693, 72.58740618824959, 70.40564686059952, 74.76583689451218, 67.66649544239044, 70.58994457125664, 68.59117582440376, 68.66279438138008, 55.24325966835022, 19.296964332461357, 4.083202471956611, 1.239892824087292, 28.841807059943676, 76.27385437488556, 78.65703329443932, 70.11723473668098, 67.45612353086472, 64.35169771313667, 58.84291671216488, 55.474838241934776, 52.045054882764816, 54.63005617260933, 62.088501155376434, 66.72021701931953, 68.87385785579681, 61.87119081616402, 61.92305043339729, 64.32091936469078, 67.92604431509972, 66.92004829645157, 66.30436733365059, 67.44588688015938, 61.659545972943306, 61.28129526972771, 58.026872500777245, 57.934320867061615, 57.47843652963638, 60.84024153649807, 60.66905312240124, 61.702901646494865, 60.51266111433506, 59.25588995218277, 52.156746089458466, 48.63854147493839, 47.46518723666668, 46.868649646639824, 47.043413668870926, 45.9496233612299, 46.48836225271225, 45.942760929465294, 45.12646593153477, 46.27189926803112, 46.083968952298164, 45.68104237318039, 50.692832842469215, 51.981495693325996, 52.87032499909401, 53.79732325673103, 56.65906369686127, 57.64793403446674, 60.01337930560112, 61.266837045550346, 59.76054847240448, 50.36250896751881, 58.29749397933483, 61.56501084566116, 61.356626227498055, 59.16915960609913, 60.77265836298466, 59.68859553337097, 57.48464159667492, 58.37136201560497, 47.846162393689156, 44.76274944841862, 46.30916006863117, 43.70482921600342, 44.73815716803074, 44.86209511756897, 45.39171829819679, 46.59549370408058, 46.91990129649639, 46.878555715084076, 44.284457713365555, 44.917701333761215, 45.11026740074158, 45.90045399963856, 47.38672524690628, 44.7368386387825, 45.775718092918396, 49.49732959270477, 57.82371260225773, 58.01929950714111, 60.833101719617844, 59.454600289464, 59.107036739587784, 61.516544446349144, 59.22310151159763, 57.24648557603359, 55.92601843178272, 55.781778171658516, 54.26467537879944, 55.29036954045296, 50.70417143404484, 50.45621573925018, 50.802088379859924, 53.82081359624863, 51.55014283955097, 49.824963212013245, 48.40364947915077, 49.083672389388084, 50.180000960826874, 54.68325711786747, 55.18919616937637, 55.06295554339886, 60.80274134874344, 58.46222274005413, 61.16967245936394, 58.83192390203476, 42.72831201553345, 15.15461090952158, 18.919876366853714, 55.45832432806492, 68.42301964759827, 56.6907349973917, 62.18560874462128, 64.73052978515625, 65.24443700909615, 63.26218977570534, 52.54757411777973, 19.133945479989052, 22.86816470324993, 44.57276724278927, 28.987384848296642, 50.74287995696068, 45.4423163831234, 0.7832631329074502, 0.04542418013443239, 0.10922729125013575, 0.14837454218650237, 0.004563889087876305, 0.07051025590044446, 0.06625763839110732, 0.07236593679408543, 0.01084454479496344, 0.07854090974433348, 0.050410948679200374, 0.048631530880811624, 0.03224880274501629, 0.01990685905184364, 0.04146655148360878, 0.051854162447853014, 0.07945876830490306, 0.09159672714304179, 0.15608517453074455, 0.1888611915637739, 0.09227922098943964, 0.14354295301018283, 0.18963706243084744, 0.09368682280182838, 0.10444944840855896, 0.13513363315723836, 0.16564512014156207, 0.1929699585889466, 0.3384189843200147, 0.09160527668427676, 0.2643604832701385, 0.17432097491109744, 0.20311220810981467, 0.19333092437591404, 0.8069394249469042, 0.5503955972380936, 24.53131265938282, 89.84633088111877, 49.271674901247025, 52.29433290660381, 50.55731311440468, 37.68936440348625, 77.75691479444504, 77.12498590350151, 82.27519154548645, 73.41152876615524, 78.01762640476227, 72.73746013641357, 75.09733870625496, 59.87578868865967, 21.99698355048895, 5.297594033181667, 1.8750748154707253, 32.44707070291042, 80.26774406433105, 81.18711993098259, 74.37301397323608, 71.5911528468132, 67.10151135921478, 63.24094891548157, 59.36126969754696, 53.57421822845936, 57.019158974289894, 65.51269501447678, 72.05844417214394, 70.73966413736343, 64.4346472620964, 64.13677364587784, 66.75082057714462, 69.70637798309326, 69.51223120093346, 69.08123552799225, 69.35213819146156, 63.57597313821316, 64.69845190644264, 58.402337953448296, 60.20510941743851, 60.11923022568226, 62.73415490984917, 63.02609324455261, 63.634463399648666, 61.26346282660961, 61.58454939723015, 54.794765934348106, 51.6787089407444, 49.73227098584175, 48.57488349080086, 51.79144889116287, 49.443368688225746, 49.76499482989311, 50.02393953502178, 48.84620413184166, 47.00413137674332, 49.82478082180023, 51.535464227199554, 55.716212689876556, 56.55529506504536, 58.20969969034195, 55.7530365139246, 61.62801146507263, 63.57372745871544, 63.92080843448639, 63.04302893579006, 62.84657567739487, 56.099942699074745, 62.15562455356121, 63.67471843957901, 63.657725751399994, 64.43512603640556, 64.41000178456306, 63.893579095602036, 61.08712948858738, 60.298466607928276, 49.9445503950119, 48.67621645331383, 51.58540114760399, 46.83415129780769, 47.253599390387535, 47.36393786966801, 48.705087304115295, 48.7621184438467, 49.43139933049679, 49.85516399145126, 47.493670508265495, 45.30889794230461, 47.49975398182869, 47.01030984520912, 49.09934654831886, 47.04814441502094, 47.101808935403824, 50.72444334626198, 61.136922016739845, 59.82896000146866, 64.05944779515266, 62.1304927021265, 62.67865128815174, 63.974674344062805, 60.932059809565544, 61.51505872607231, 58.37672732770443, 58.12238037586212, 56.36293038725853, 57.60834015905857, 52.79590219259262, 51.38273902237415, 53.19299228489399, 56.43040716648102, 55.81805482506752, 51.48973748087883, 50.07921516895294, 52.40418881177902, 53.12379039824009, 58.780983835458755, 58.564296662807465, 59.21892173588276, 63.970258980989456, 63.10318350791931, 65.49255609512329, 61.97299875319004, 46.36617600917816, 16.16477720439434, 21.56164851039648, 60.716026201844215, 73.64085406064987, 59.94539715349674, 65.09404867887497, 67.87045329809189, 71.48722842335701, 67.10205093026161, 56.72673046588898, 22.54613008350134, 33.692773059010506, 54.68948498368263, 43.17545682191849, 57.278267070651054, 69.05493333935738, 3.1457229517400265, 0.23665168730076402, 0.29140802565962076, 0.23046125541441143, 0.13710882951272652, 0.15015168901300058, 0.22134699916932732, 0.14742016996024176, 0.06796248519094661, 0.21759122726507485, 0.1304910096223466, 0.16448408947326243, 0.10706934102927335, 0.08630395997897722, 0.17291542142629623, 0.10372984717832878], [0.07992635102709755, 0.05208772745390888, 0.014815469021414174, 0.023801755814929493, 0.04252344398992136, 0.10889374039834365, 0.039665436997893266, 0.04203439093544148, 0.03498265585221816, 0.02377955817792099, 0.03701534638821613, 0.047493436286458746, 0.06647658679867163, 0.020691407480626367, 0.0357187550253002, 0.04800412294571288, 0.04013637051684782, 0.10429716712678783, 0.06092101029935293, 0.08833921834593639, 1.0695276595652103, 44.76825915277004, 59.9363574385643, 40.495031252503395, 44.77018564939499, 29.531310461461544, 50.24350695312023, 56.71395555138588, 52.81763702630997, 66.11459791660309, 63.97952288389206, 63.03713545203209, 63.378235548734665, 59.01449650526047, 33.851995915174484, 4.796577617526054, 0.49308909103274345, 21.968773864209652, 79.4226086139679, 74.11335870623589, 71.26055538654327, 65.61983406543732, 63.810743540525436, 56.32518321275711, 55.068723633885384, 48.89354579150677, 52.74305462837219, 60.559493601322174, 68.33370164036751, 64.72951143980026, 63.56298163533211, 63.22324946522713, 62.43501976132393, 61.24992415308952, 65.43821901082993, 65.76313197612762, 63.293975070118904, 62.466907650232315, 58.69642697274685, 57.41750679910183, 51.93790063261986, 50.362892746925354, 55.86940906941891, 55.11519894003868, 55.32382294535637, 55.60776650905609, 50.0194975733757, 46.29165820777416, 44.42634589970112, 46.03336326777935, 43.268160447478294, 43.44376802444458, 44.134563356637955, 42.26279899477959, 42.49866373836994, 42.27905832231045, 42.91876919567585, 44.944816678762436, 43.877058774232864, 48.58246028423309, 49.23360474407673, 54.00234505534172, 54.125618040561676, 56.85530796647072, 53.85590851306915, 57.766563668847084, 55.69291993975639, 61.58695466816425, 56.722877472639084, 51.19634002447128, 61.511536315083504, 58.12855884432793, 61.42484776675701, 57.55849063396454, 58.858837857842445, 56.08974404633045, 56.41868859529495, 48.38178165256977, 43.443403244018555, 41.208838149905205, 41.532698571681976, 40.461228266358376, 41.527595445513725, 42.68083356320858, 41.88185043632984, 43.232016786932945, 43.99269416928291, 44.10128094255924, 41.920843943953514, 42.15362325310707, 43.88272047042847, 43.431775867938995, 43.55230160057545, 42.65387400984764, 44.41289082169533, 50.67068763077259, 57.318168729543686, 55.960672572255135, 55.480024963617325, 59.48091387748718, 56.90256603062153, 54.98773477971554, 51.43458344042301, 57.75895267724991, 58.77057999372482, 55.18272131681442, 53.32800664007664, 52.351865619421005, 54.52863581478596, 52.65663206577301, 54.189443215727806, 53.22852037847042, 49.17888008058071, 47.37442150712013, 44.99489039182663, 47.28904388844967, 48.48707780241966, 51.92991726100445, 50.5756813287735, 54.6787353605032, 57.88012057542801, 56.9782617688179, 58.91546241939068, 45.707656145095825, 20.84515705704689, 15.827246066182852, 45.94365768134594, 58.977516889572144, 51.219013407826424, 56.229675337672234, 59.58850510418415, 60.032720267772675, 55.03392890095711, 24.5710851252079, 11.663363948464394, 28.655058480799198, 40.1105260848999, 30.66876992583275, 49.90448534488678, 12.07652147859335, 0.2960354054812342, 0.07362836709944531, 0.30292176408693194, 0.012189766312076245, 0.08871904210536741, 0.031250139145413414, 0.14388457842869684, 0.043064324927399866, 0.06028584321029484, 0.06379078404279426, 0.11060498451115564, 0.04386590007925406, 0.035377393069211394, 0.0396871188422665, 0.013153834697732236, 0.036115974726271816, 0.020611754625861067, 0.022682129565509968, 0.08140761841787025, 0.06925851994310506, 0.11112649168353528, 0.048211853791144677, 0.006810343666074914, 0.009880746365524828, 0.08323852642206475, 0.019655217183753848, 0.032884196189115755, 0.04781460069352761, 0.01897416866995627, 0.02907498594140634, 0.05981635316857137, 0.035293255787109956, 0.07241995772346854, 0.08112632218399085, 0.02692773563467199, 0.18207830318715423, 1.3395754876546562, 47.479178085923195, 67.53872349858284, 40.61324290931225, 48.35501208901405, 38.02165277302265, 57.529984563589096, 70.8032575249672, 65.1693606376648, 72.70518466830254, 67.4698331952095, 70.4332409799099, 68.94804507493973, 65.01693561673164, 39.86577741801739, 6.583969881758094, 0.5422190891113132, 23.78744177520275, 79.19985696673393, 77.69292622804642, 74.2891676723957, 68.556909263134, 68.2897911965847, 58.31209659576416, 55.15530578792095, 54.42001484334469, 52.947145476937294, 63.17398510873318, 69.91105020046234, 67.74366170167923, 67.32299387454987, 64.1209664940834, 64.47010695934296, 64.0416419506073, 68.58121275901794, 67.44739919900894, 66.14621222019196, 63.87310579419136, 63.241222500801086, 60.74488565325737, 54.4376040995121, 54.119306579232216, 57.736328691244125, 59.624188989400864, 56.959243789315224, 58.795879036188126, 54.51290085911751, 47.76205770671368, 47.23229393362999, 48.711869940161705, 47.51823619008064, 45.56580975651741, 47.16180391609669, 45.805257707834244, 44.91889446973801, 46.42098046839237, 45.26770435273647, 46.25264570116997, 45.30266247689724, 51.29997566342354, 51.714153438806534, 57.03750818967819, 55.20957067608833, 57.09328539669514, 57.210497707128525, 60.87903745472431, 60.074833407998085, 61.82305879890919, 55.39584048092365, 55.03662295639515, 61.887928918004036, 60.972501039505005, 61.05438284575939, 60.012851133942604, 61.297311410307884, 61.36251971125603, 59.74039435386658, 50.6769534945488, 45.24819619953632, 45.887914672493935, 44.48717303574085, 42.12633691728115, 44.03500869870186, 44.74493980407715, 45.33310264348984, 44.95479494333267, 45.55436857044697, 46.022872030735016, 44.50022533535957, 46.473592445254326, 46.05928547680378, 45.274376794695854, 45.18493339419365, 47.83742666244507, 47.08498723804951, 54.79809455573559, 60.721076130867004, 59.59788300096989, 58.18772926926613, 60.83730049431324, 59.76541221141815, 56.060565412044525, 53.82641449570656, 58.41224022209644, 60.28232507407665, 59.502884298563, 57.49274656176567, 55.525877103209496, 57.82905511558056, 57.63282224535942, 56.20600260794163, 55.037151128053665, 50.431931242346764, 48.7019182741642, 48.289746791124344, 51.031630262732506, 50.14857664704323, 52.64293000102043, 55.06265535950661, 59.042132422327995, 60.19502855837345, 62.94476240873337, 63.948220163583755, 51.12340293824673, 23.028573095798492, 18.471050150692463, 50.51914416253567, 64.92458537220955, 58.19760113954544, 63.04990276694298, 64.09150287508965, 68.70723679661751, 62.19889663159847, 33.84948045015335, 17.63619314879179, 32.2989584505558, 45.775417909026146, 32.952390387654305, 58.90409342944622, 11.345879584550858, 0.4938700085040182, 0.05205546258366667, 0.24725127790588886, 0.003388459595043969, 0.06909252377226949, 0.06827931545558386, 0.09191815130179748, 0.015687862687627785, 0.012741320260829525, 0.06255973916267976, 0.03336668865813408, 0.0586382419714937, 0.06242431205464527, 0.02441743967210641, 0.0774233095580712, 0.031797844130778685, 0.12370002441457473, 0.13647037470946088, 0.11620562421740033, 0.1138352564885281, 0.3460506076226011, 0.20016466471133754, 0.22106771415565163, 0.10226957514532842, 0.19951420195866376, 0.16552334855077788, 0.07169380332925357, 0.19499446323607117, 0.15575426572468132, 0.16267375380266458, 0.12049502256559208, 0.18284083023900166, 0.14752233400940895, 0.19980086392024532, 0.2590481308288872, 0.19817481836071238, 3.028198820538819, 72.66274854540825, 73.02079573273659, 58.959570452570915, 62.12503619492054, 43.07400606572628, 65.07314220070839, 75.54120808839798, 73.95081862807274, 75.95080330967903, 76.20309457182884, 78.21484342217445, 76.46344140172005, 67.83155858516693, 44.375405833125114, 7.552549783140421, 0.862365507055074, 26.48126732558012, 84.5146469771862, 77.20796585083008, 76.71719178557396, 71.68579056859016, 70.20641595125198, 60.81761375069618, 57.89044842123985, 58.08862678706646, 57.85080514848232, 67.46338874101639, 73.23606178164482, 72.13062509894371, 69.93504211306572, 66.20480507612228, 64.97713655233383, 66.3042077422142, 70.3901132941246, 68.66242200136185, 65.39692282676697, 66.99994280934334, 64.34377893805504, 62.29004614055157, 56.71666860580444, 56.27600245177746, 59.860809892416, 60.81328958272934, 57.91987024247646, 61.675942093133926, 56.65731959044933, 50.01307591795921, 52.04318918287754, 52.32689715921879, 48.84194456040859, 48.10540348291397, 51.46096542477608, 48.07392217218876, 49.25806783139706, 49.28782783448696, 48.88495825231075, 49.41243454813957, 48.92430894076824, 55.02416342496872, 55.14846995472908, 61.60149268805981, 59.2602027207613, 60.50533890724182, 59.309584870934486, 62.82649755477905, 61.78277336061001, 63.8214285671711, 58.2992684841156, 59.23222482204437, 63.889969289302826, 64.59926962852478, 65.73641940951347, 63.77798929810524, 65.20467594265938, 61.26059018075466, 60.173232927918434, 55.0244028121233, 48.067006543278694, 47.20662251114845, 46.129615902900696, 46.31932072341442, 46.08876809477806, 47.085105031728745, 47.0637121796608, 47.64111399650574, 48.634411096572876, 49.63384106755257, 46.00057102739811, 48.59745807945728, 47.42742486298084, 47.3087078332901, 46.610837280750275, 49.35975417494774, 49.160523265600204, 57.95753002166748, 64.19321581721306, 61.82870149612427, 60.14975778758526, 64.01469379663467, 63.11125807464123, 59.09065581858158, 57.576589062809944, 63.06764781475067, 63.534106984734535, 60.045609176158905, 61.19914747774601, 57.98197031021118, 61.23977489769459, 60.012440755963326, 60.71837067604065, 57.208833396434784, 53.84241163730621, 52.226692736148834, 50.32907076179981, 52.96020157635212, 52.925467640161514, 56.88168615102768, 58.968496173620224, 62.31507159769535, 63.649126812815666, 66.37828856706619, 69.66973274946213, 53.75060856342316, 26.373624801635742, 21.306066624820232, 55.52174672484398, 70.90563163161278, 61.501299664378166, 67.21156105399132, 69.75912675261497, 73.29960197210312, 68.30168455839157, 37.00581148266792, 18.513858653604984, 42.51946002244949, 56.44203454256058, 43.735843151807785, 67.8074298799038, 29.07324694097042, 0.634269209112972, 0.26507721981033683, 0.47717305133119226, 0.11624978942563757, 0.26336363051086664, 0.20415635051904246, 0.25174884125590324, 0.2083780724206008, 0.16633886494673789, 0.1957969623617828, 0.3040659776888788, 0.25585526309441775, 0.13523833535145968, 0.0976481028192211, 0.16719701030524448, 0.1181328778329771], [0.07922076154500246, 0.05884413229068741, 0.07081308925990015, 0.043434311519376934, 0.1349734331597574, 0.1312971452716738, 0.06837065157014877, 0.04395864256366622, 0.04246456199325621, 0.02556967217969941, 0.06058616439986508, 0.005924657207287964, 0.01735662626742851, 0.006045071595508489, 0.06980523045058362, 0.060371579820639454, 0.016505716848769225, 0.011572246567084221, 0.028243025408301037, 0.2516060817288235, 0.24261681799544021, 9.954264108091593, 61.15945480763912, 41.485953480005264, 46.62632904946804, 24.920288287103176, 33.59018996357918, 56.18289604783058, 60.212541818618774, 75.26000797748566, 69.0026481449604, 60.683138966560364, 61.74523897469044, 61.065052673220634, 46.08892008662224, 8.769503831863403, 0.648740257602185, 13.904699329286814, 67.5292544066906, 77.56323918700218, 73.25120776891708, 66.85485899448395, 66.2575614452362, 59.58473950624466, 56.89735271036625, 57.11098864674568, 52.683888003230095, 58.67094174027443, 66.85504898428917, 67.86470040678978, 63.36374692618847, 63.312301486730576, 65.72712510824203, 64.19926509261131, 66.55306398868561, 60.86709849536419, 63.41715306043625, 59.66511279344559, 59.76567819714546, 51.906597912311554, 47.28869050741196, 47.61299930512905, 50.38037560880184, 51.0687542706728, 52.02434599399567, 47.53891468048096, 44.77931655943394, 45.71718983352184, 44.61954653263092, 44.49085123836994, 47.18583382666111, 46.211706697940826, 43.480059877038, 42.99166448414326, 41.711600571870804, 42.161644622683525, 43.06400880217552, 43.32147918641567, 47.10662707686424, 48.75166140496731, 51.709464490413666, 53.670755848288536, 54.29059758782387, 55.4511883109808, 56.557438150048256, 55.68283528089523, 58.70537929236889, 57.913045808672905, 59.674372896552086, 52.66649633646011, 58.34835425019264, 58.813483491539955, 58.65652151405811, 58.066884353756905, 57.51585692167282, 56.19914397597313, 56.61746732890606, 49.53427881002426, 42.88493201136589, 44.093848541378975, 42.57954239845276, 41.80612049996853, 42.283283695578575, 41.359591260552406, 41.719910725951195, 42.7154953032732, 42.991987466812134, 44.194246754050255, 41.714473217725754, 42.67676778137684, 43.23764428496361, 44.220556542277336, 45.582646653056145, 45.30602529644966, 45.38356013596058, 45.381721034646034, 48.22198502719402, 53.49517486989498, 59.1886031627655, 55.608644261956215, 56.844402551651, 57.12308719754219, 56.86131164431572, 56.677986681461334, 52.85173259675503, 58.82942743599415, 60.836935713887215, 57.22923830151558, 57.51512736082077, 58.216736912727356, 60.02745755016804, 54.87988516688347, 51.980131566524506, 46.491497084498405, 47.1414066106081, 45.882093384861946, 47.89614111185074, 48.120177090168, 51.380827724933624, 52.67979182302952, 57.11253896355629, 58.44693996012211, 63.182147070765495, 55.35884186625481, 19.9210599437356, 10.798776391893625, 51.534350886940956, 55.61475433409214, 54.593581929802895, 62.042341232299805, 62.108070105314255, 60.461033284664154, 53.644704446196556, 13.295378275215626, 10.015862602740526, 33.938418477773666, 32.222282364964485, 34.919959008693695, 47.702758088707924, 1.5534428553655744, 0.09254501375835389, 0.08684988380991854, 0.19737178488867357, 0.02695152332307771, 0.07891389832366258, 0.0658518988348078, 0.06710942354402505, 0.05806172310258262, 0.04577821797283832, 0.05966890697891358, 0.09721585374791175, 0.07608968502609059, 0.08770836313487962, 0.029588611505459994, 0.10906294264714234, 0.04474465858947951, 0.045910238623037, 0.016310903083649464, 0.08395731871132739, 0.03998863117885776, 0.035724432455026545, 0.07988033787114546, 0.03333494329126552, 0.008513471002515871, 0.011040769568353426, 0.048038131862995215, 0.08719144243514165, 0.018730521587713156, 0.039933782754815184, 0.06244063188205473, 0.07485401656595059, 0.03770123927097302, 0.05112630482472014, 0.03699255503306631, 0.037963651557220146, 0.16166588757187128, 0.12824939709389582, 8.770600073039532, 77.52032428979874, 43.14268358051777, 52.8899547457695, 29.317537732422352, 38.65733206272125, 67.0049661397934, 64.1304811835289, 80.54432362318039, 72.29477629065514, 70.14886423945427, 67.40330636501312, 66.41788244247437, 50.96629656851292, 10.973086338490248, 0.717199818463996, 17.044198215007782, 67.62771472334862, 78.63295778632164, 75.0719864666462, 73.52009654045105, 67.07755744457245, 64.48957711458206, 58.95768955349922, 59.524425342679024, 57.10439220070839, 62.685479521751404, 66.47368624806404, 70.50213888287544, 63.83451506495476, 65.09803086519241, 67.9418970644474, 64.4869476556778, 66.42041310667992, 64.36490580439568, 66.50879636406898, 63.703714683651924, 62.24338464438915, 54.201515167951584, 49.93098132312298, 51.874603629112244, 54.53254960477352, 54.43771809339523, 53.69800038635731, 52.234429121017456, 47.86937914788723, 47.386155277490616, 48.6704483628273, 47.309912368655205, 48.228376284241676, 48.97388868033886, 45.893815755844116, 44.755389243364334, 45.051389560103416, 46.47266149520874, 45.58759778738022, 46.98186457157135, 48.93468618392944, 51.404633447527885, 53.42858724296093, 57.847411930561066, 56.28621630370617, 59.42286059260368, 57.60786898434162, 58.890695348381996, 62.04870969057083, 61.771708354353905, 60.52222140133381, 54.585735350847244, 61.224001944065094, 61.885295659303665, 62.84458078444004, 62.05950491130352, 61.55122518539429, 60.36119744181633, 59.93979625403881, 53.98892417550087, 46.372457072138786, 45.67311979830265, 46.888313591480255, 45.82123585045338, 44.812826961278915, 44.679765701293945, 44.0563939511776, 47.13759921491146, 45.28133042156696, 44.44549307227135, 45.557454004883766, 45.30911833047867, 45.70018194615841, 46.31853796541691, 47.25975126028061, 47.45891377329826, 47.449927255511284, 47.7352349460125, 53.35001885890961, 56.545385196805, 61.73779517412186, 59.068544805049896, 61.424729973077774, 58.063601329922676, 61.074795350432396, 58.90404023230076, 55.467291846871376, 60.079849138855934, 62.82941959798336, 59.3419249355793, 60.75234845280647, 60.34467972815037, 62.61179007589817, 58.43683250248432, 54.456610679626465, 50.57546094059944, 49.718287736177444, 50.03579869866371, 51.49967774748802, 52.44065545499325, 52.02552393078804, 55.801293924450874, 58.34015429019928, 62.70409472286701, 65.70055693387985, 59.98453505337238, 22.60944228619337, 12.69143583253026, 56.980047672986984, 59.8476891964674, 57.75869809091091, 68.96634489297867, 68.48032057285309, 69.977987408638, 56.158451959490776, 22.656379267573357, 13.590364046394825, 41.563499718904495, 36.255895122885704, 41.460365653038025, 54.54451136291027, 2.207906199619174, 0.2414264131220989, 0.09066805549082346, 0.09650164050981402, 0.07037714429316111, 0.057518329995218664, 0.019687315070768818, 0.018097831416525878, 0.019944357918575406, 0.07651139560039155, 0.014081241915846476, 0.0235176468413556, 0.03901135998603422, 0.03016483908140799, 0.024839100151439197, 0.017052069269993808, 0.05829412293678615, 0.22675326297758147, 0.1869235627236776, 0.202237126941327, 0.14462181308772415, 0.21449577383464202, 0.1662517516524531, 0.15393965528346598, 0.16020258015487343, 0.08632163793663494, 0.09536638463032432, 0.188016657193657, 0.24155753577360883, 0.12529860308859497, 0.25376620644237846, 0.1169564772862941, 0.1559677519253455, 0.1182235757005401, 0.10585313168121502, 0.06489965657237917, 0.4103598411893472, 0.4906569543527439, 22.82111182808876, 91.34952262043953, 57.46641777455807, 65.84861978888512, 38.83048877120018, 45.7985320687294, 67.57989808917046, 72.90009900927544, 85.63969060778618, 77.11361691355705, 74.01756584644318, 73.46027255058289, 73.26180920004845, 56.27426594495773, 12.154914122074842, 1.3697418314404786, 20.18112748861313, 70.39275795221329, 82.89881408214569, 77.20167338848114, 76.73897981643677, 71.04613289237022, 66.61476507782936, 63.12600888311863, 63.57953354716301, 58.86427916586399, 64.32563111186028, 69.54634577035904, 76.75775840878487, 64.66321259737015, 69.51027050614357, 70.56216046214104, 67.7684135735035, 69.53976452350616, 68.07887971401215, 70.43150067329407, 64.92878794670105, 64.3765939772129, 57.40025192499161, 51.622270569205284, 54.57207128405571, 54.67960171401501, 56.093502044677734, 56.68368637561798, 52.94923156499863, 51.597583293914795, 51.200603395700455, 49.89424489438534, 50.423047319054604, 51.330381631851196, 53.282899260520935, 47.678241804242134, 49.7579538077116, 48.05245712399483, 48.92085872590542, 50.648755207657814, 48.907221257686615, 52.695207595825195, 54.14388366043568, 57.95439898967743, 61.79128110408783, 59.52927008271217, 63.24211925268173, 62.52733200788498, 60.54900236427784, 64.59593340754509, 63.1805207580328, 59.8636407405138, 59.45775792002678, 63.715927228331566, 63.770207315683365, 64.38702061772346, 64.58954215049744, 64.43619757890701, 61.670599579811096, 62.8119595348835, 55.02144277095795, 47.86893457174301, 48.02425503730774, 48.621890768408775, 47.241877019405365, 47.75875948369503, 47.5927159935236, 46.53976209461689, 48.54935646057129, 47.34341137111187, 47.61761225759983, 48.94036307930946, 46.47123657166958, 46.270231157541275, 48.13109390437603, 49.60715129971504, 49.04455728828907, 50.28972767293453, 51.25510387122631, 54.208890572190285, 58.90106879174709, 65.0992240011692, 62.92981021106243, 63.11948463320732, 61.697961911559105, 61.26989588141441, 62.039126604795456, 58.062544986605644, 62.12969854474068, 65.4582591354847, 62.857781276106834, 64.51219350099564, 63.819163888692856, 66.37430638074875, 61.33710667490959, 57.39227615296841, 53.41802000999451, 52.11787037551403, 51.851390674710274, 52.99695320427418, 54.46176320314407, 54.867182448506355, 59.56369623541832, 62.74818375706673, 64.18350353837013, 71.04341983795166, 61.37752130627632, 25.046196430921555, 15.25248035788536, 60.634809359908104, 64.38357040286064, 63.815698474645615, 75.10000616312027, 74.37515705823898, 73.4970773756504, 65.46845778822899, 19.667805433273315, 14.684810768812895, 50.7889448851347, 43.88731822371483, 50.12509770691395, 68.64176630973816, 5.210885060951114, 0.38729843334294856, 0.1572026262874715, 0.38983749866019934, 0.0946717789338436, 0.23645185661735013, 0.12650429620407522, 0.15760849200887606, 0.10396648838650435, 0.19096289441222325, 0.1774309150641784, 0.247989566414617, 0.13660223950864747, 0.22628364677075297, 0.15065802668686956, 0.1185830200847704, 0.27528038481250405], [0.06530446844408289, 0.06098693156673107, 0.023552748571091797, 0.00606189608333807, 0.0239936158322962, 0.1076647215813864, 0.0412898906506598, 0.05545658066694159, 0.021752198117610533, 0.008527128375135362, 0.15230829594656825, 0.05785712040960789, 0.09038218762725592, 0.03721347384271212, 0.031031504295242485, 0.07254251599078998, 0.07170042328652926, 0.04432979432749562, 0.033198825985891744, 0.009001193757285364, 0.2180248047807254, 0.7316690857987851, 46.255267560482025, 64.47473511099815, 43.67726169526577, 76.19858041405678, 16.683741956949234, 54.663589373230934, 77.05396011471748, 65.71340784430504, 69.2993514239788, 64.30339470505714, 51.2446354329586, 59.46654684841633, 50.38759522140026, 11.244879104197025, 0.2632357139373198, 5.008459948003292, 58.82215842604637, 75.14135554432869, 72.8397886455059, 68.938849568367, 70.9005931019783, 65.4598018527031, 56.998955458402634, 52.57323794066906, 50.19010841846466, 59.267384335398674, 65.31105503439903, 68.10812294483185, 66.45184502005577, 68.21598395705223, 65.96379920840263, 62.008074671030045, 57.250114381313324, 54.58548076450825, 52.26874127984047, 50.501425713300705, 50.75183607637882, 46.83285936713219, 48.907616436481476, 49.42220762372017, 48.39182831346989, 49.040119126439095, 47.60508432984352, 46.05168588459492, 44.61879037320614, 44.929758086800575, 44.76845294237137, 45.52787259221077, 43.91751140356064, 42.13640637695789, 42.979322746396065, 42.1653114259243, 41.532500982284546, 42.76088006794453, 45.66533401608467, 45.08684545755386, 50.562473237514496, 52.65376701951027, 50.272108018398285, 56.71421393752098, 57.01105780899525, 56.882848888635635, 57.854673340916634, 57.59871527552605, 59.69141498208046, 58.4350124001503, 62.750102654099464, 55.388681665062904, 56.93803712725639, 59.97689366340637, 59.681497514247894, 59.381674602627754, 56.53813898563385, 55.89342758059502, 55.54405152797699, 51.007269769907, 44.47194345295429, 42.9881838709116, 43.77596139907837, 42.90746860206127, 42.82111443579197, 42.615230083465576, 40.20357169210911, 42.41009049117565, 44.03687819838524, 43.11738073825836, 43.87257121503353, 44.673864617943764, 43.814666122198105, 46.53723903000355, 45.61633184552193, 44.71054024994373, 47.92086258530617, 45.47352030873299, 44.95648965239525, 46.35289192199707, 49.7643830627203, 53.491352275013924, 53.17515604197979, 61.453707218170166, 56.35663032531738, 53.06382201611996, 55.28275094926357, 55.69319352507591, 56.89167581498623, 57.55945198237896, 59.14789214730263, 58.44434089958668, 60.32820761203766, 57.97740675508976, 54.74480241537094, 48.416830971837044, 46.63877338171005, 50.41426219046116, 51.68086722493172, 51.69183723628521, 51.94087967276573, 54.45552013814449, 58.240215852856636, 65.419592410326, 62.736613377928734, 63.43903228640556, 20.73680967092514, 9.64604839682579, 49.42422151565552, 59.90982726216316, 56.591951698064804, 55.80355480313301, 56.1495566368103, 52.186905071139336, 42.36619524657726, 7.630730113014579, 34.40461926162243, 31.953560784459114, 27.720092050731182, 44.83208812773228, 27.0600313693285, 0.3879736689850688, 0.0412179394334089, 0.08127291861455888, 0.04971128153556492, 0.067982493492309, 0.0760721109691076, 0.11915732364286669, 0.026369902188889682, 0.04142585210502148, 0.11950565807637759, 0.07170456447056495, 0.034796502950484864, 0.01968813143321313, 0.0502971625974169, 0.05281802674289793, 0.02188127244153293, 0.026914358422800433, 0.027330621633154806, 0.032329700552509166, 0.06143723338027485, 0.013319218596734572, 0.02707951596676139, 0.015425604397023562, 0.027048945048591122, 0.02438691142742755, 0.019110115281364415, 0.06605432703508995, 0.06923681212356314, 0.03767295231227763, 0.00205812718377274, 0.06281976544414647, 0.030872198585711885, 0.004859850623688544, 0.027986737695755437, 0.0484284310368821, 0.09994054504204541, 0.03341673167597037, 0.23074619559338316, 0.9864557452965528, 57.276287376880646, 71.91389992833138, 45.119124725461006, 73.32933157682419, 26.712843999266624, 62.68147833645344, 81.63817092776299, 71.74907237291336, 74.42262411117554, 69.1933599114418, 58.209429904818535, 66.87312081456184, 54.30084563791752, 13.899616152048111, 0.2113319982890971, 5.245470805093646, 61.07113994657993, 76.92708492279053, 74.46458905935287, 70.52639678120613, 75.05704566836357, 68.41855108737946, 59.65217448771, 56.87849052250385, 53.230864852666855, 62.11714021861553, 67.35139355063438, 70.2845473587513, 67.93842405080795, 70.52001312375069, 67.67445981502533, 65.34625634551048, 58.59230875968933, 56.116502210497856, 54.90347050130367, 55.312529951334, 53.09195950627327, 50.76333425939083, 50.48252172768116, 51.1169470846653, 49.5427181571722, 49.9485781788826, 49.12426941096783, 51.02784566581249, 47.912491634488106, 48.348864018917084, 47.08308354020119, 48.08993451297283, 47.43602380156517, 45.01974865794182, 47.11611516773701, 46.8970987200737, 44.5418407022953, 45.827117934823036, 46.925213411450386, 47.00328402221203, 51.2836479395628, 53.99629957973957, 53.8571472465992, 56.60024285316467, 58.963773027062416, 59.35112044215202, 59.746960401535034, 58.12039688229561, 63.5750687867403, 60.54269090294838, 61.954505145549774, 56.661411970853806, 60.28386019170284, 62.36196868121624, 61.210231482982635, 62.580802738666534, 61.072454676032066, 60.663733407855034, 57.76326164603233, 53.40643063187599, 49.058221355080605, 47.50960685312748, 45.760959684848785, 47.30341851711273, 47.22040057182312, 44.29492615163326, 44.045123755931854, 45.73930084705353, 46.96845889091492, 46.274167746305466, 48.114769980311394, 47.08525322377682, 45.885171219706535, 48.624858409166336, 48.041076734662056, 47.80397705733776, 50.31367778778076, 47.758394703269005, 47.11794286966324, 49.32125084102154, 53.802726566791534, 56.94271467626095, 56.36160045862198, 64.02367651462555, 56.948319375514984, 56.871327906847, 58.50262597203255, 58.38043212890625, 59.09717246890068, 58.17397400736809, 60.794507190585136, 60.003701224923134, 61.87986955046654, 62.046448811888695, 57.780816704034805, 49.52245004475117, 49.26174983382225, 53.54356147348881, 54.27753008902073, 52.8926146030426, 53.739623352885246, 57.43358373641968, 60.17486684024334, 68.32981064915657, 65.05553394556046, 67.58920758962631, 23.38349875062704, 10.416954830288887, 55.817663446068764, 65.80621406435966, 62.495463117957115, 61.09946362674236, 66.13165140151978, 59.85561177134514, 50.09083494544029, 14.941600039601326, 31.79226703941822, 42.12059162557125, 29.241993986070156, 54.14929836988449, 27.45141986757517, 0.9508118173107505, 0.07248635025462136, 0.14170952170388773, 0.06635129000642337, 0.03418730731937103, 0.038794437641627155, 0.12138831603806466, 0.0519371160044102, 0.12626363255549222, 0.04254015344486106, 0.02770853621768765, 0.03251407229981851, 0.029313059494597837, 0.08198256022296846, 0.03931943661882542, 0.03015772188518895, 0.021081613886053674, 0.2259976082132198, 0.14463794737821445, 0.19568673858884722, 0.13459734240313992, 0.08640586427645758, 0.18135586695279926, 0.11687283724313602, 0.11491571218357421, 0.1282191026257351, 0.11269080539932474, 0.3341269661905244, 0.17710914951749146, 0.19275454280432314, 0.09568847672198899, 0.20018657291075215, 0.243438093457371, 0.15148439328186214, 0.16678967513144016, 0.21819266374222934, 0.15358012926299125, 0.49981668940745294, 2.0174675434827805, 75.68797901272774, 80.91297224164009, 60.713358744978905, 92.02075660228729, 28.139612339437008, 64.77416664361954, 91.963911652565, 79.65171352028847, 79.70966041088104, 76.32726430892944, 62.905829697847366, 74.03183788061142, 60.172993540763855, 15.42548792436719, 0.44652211479842663, 5.8308156207203865, 62.04742155969143, 78.09973999857903, 77.19373181462288, 74.58926036953926, 77.66416177153587, 71.26627787947655, 63.83255437016487, 59.99863229691982, 55.31199797987938, 66.83306336402893, 70.39526581764221, 73.74202743172646, 69.1819529235363, 71.0938735306263, 70.81027954816818, 68.8990581035614, 62.59555734694004, 59.32391010224819, 56.875842064619064, 57.09542088210583, 56.33271060883999, 51.74804762005806, 53.1440395116806, 54.63934667408466, 51.36188194155693, 52.29293458163738, 51.50554083287716, 51.85677118599415, 48.98878388106823, 50.51037423312664, 49.15219031274319, 50.43192744255066, 49.991914853453636, 46.685887053608894, 50.63966989517212, 48.99080157279968, 47.478182539343834, 50.1132233440876, 50.86431764066219, 50.213359370827675, 56.46915748715401, 58.978634029626846, 56.46285742521286, 62.32106767594814, 63.097168430686, 63.282020911574364, 61.746162325143814, 60.56999243795872, 64.72483769059181, 64.25438493490219, 63.303390964865685, 58.02196316421032, 63.49538706243038, 65.61091214418411, 64.39113959670067, 64.10731002688408, 62.595268562436104, 62.540148720145226, 61.92395858466625, 56.184913739562035, 51.49933576583862, 48.13569165766239, 49.76646535098553, 48.69833126664162, 49.72120597958565, 48.90824720263481, 46.98223315179348, 48.82465548813343, 50.63273526728153, 49.647653326392174, 49.72951993346214, 50.23297391831875, 47.58539378643036, 52.96330600976944, 50.24911545217037, 49.97323505580425, 52.47652933001518, 52.475647777318954, 50.57085178792477, 50.58320872485638, 55.8482214063406, 58.895882070064545, 58.985982835292816, 66.52148008346558, 58.957339972257614, 59.09273810684681, 60.708608999848366, 60.99446386098862, 62.97131918370724, 61.917255744338036, 62.73810289800167, 64.06589984893799, 62.89457090198994, 65.55246368050575, 61.12317055463791, 55.048634111881256, 51.42080917954445, 57.534228935837746, 57.35987529158592, 55.87087579071522, 57.21841648221016, 60.61899080872536, 63.95999193191528, 72.30107635259628, 67.83050984144211, 71.73387318849564, 25.98933432251215, 11.980962306261063, 59.793317914009094, 70.76869457960129, 68.15168380737305, 68.31672415137291, 70.73051422834396, 64.19795796275139, 54.34220641851425, 11.508033983409405, 49.77094531059265, 52.23948284983635, 38.02864819765091, 61.10325202345848, 45.44870764017105, 1.0188422980718315, 0.16231816116487607, 0.12042896400089376, 0.13973601744510233, 0.12171443057013676, 0.1369967355276458, 0.21160117525141686, 0.14110685326159, 0.257038424606435, 0.2161449595587328, 0.1836454964359291, 0.1297015426098369, 0.17502147326013073, 0.27302339498419315, 0.10546184916165657, 0.1477655506459996, 0.08581947855418548], [0.030622740487160627, 0.04112297792744357, 0.05612907036265824, 0.09321717690909281, 0.010821643973031314, 0.0210050539317308, 0.04586775437928736, 0.07314138463698328, 0.047194744111038744, 0.013655814109370112, 0.05851820700627286, 0.04344068656791933, 0.023772726708557457, 0.03273418216849677, 0.031188307111733593, 0.01980532211746322, 0.007256634171426413, 0.04063888613018207, 0.07358466202276759, 0.009265017979487311, 0.2127623395062983, 0.04623236782208551, 24.779207557439804, 64.24595698714256, 42.46074177324772, 76.66416183114052, 24.44150447845459, 15.628003757447004, 65.49053460359573, 63.54471981525421, 70.19918113946915, 72.62801840901375, 64.76842135190964, 66.0571525990963, 57.75642201304436, 17.733561024069786, 1.4468370820395648, 1.2879559700377285, 46.57197296619415, 73.35202395915985, 73.26940879225731, 71.64866656064987, 67.94188186526299, 66.67350232601166, 59.78018581867218, 53.48328910768032, 52.07047551870346, 56.536702662706375, 64.06821012496948, 68.0225895345211, 66.40020579099655, 64.4171454012394, 66.89462006092072, 62.316671311855316, 56.86239838600159, 54.35263305902481, 50.76254390180111, 48.46492499113083, 51.96361385285854, 52.586962804198265, 50.63501134514809, 48.11353124678135, 46.904888302087784, 49.43024419248104, 47.56436571478844, 46.680707931518555, 47.79155932366848, 45.977396070957184, 47.14414246380329, 46.49872809648514, 45.50283573567867, 43.64217437803745, 42.73171663284302, 41.56266376376152, 40.713321939110756, 44.22465652227402, 46.64574980735779, 46.65524549782276, 54.70341123640537, 55.34107401967049, 52.70586222410202, 51.733790785074234, 52.828379049897194, 53.60404662787914, 55.638761445879936, 57.92802840471268, 57.85257585346699, 58.679153099656105, 62.86507308483124, 56.06326326727867, 56.136344745755196, 60.11907443404198, 60.28226047754288, 59.36449192464352, 56.8892515450716, 55.99291764199734, 54.53471548855305, 50.76185993850231, 45.76738893985748, 42.93337941169739, 44.537322744727135, 42.200687527656555, 42.03362949192524, 42.45720036327839, 44.83376003801823, 43.603484854102135, 43.09085056185722, 42.006373554468155, 43.63808199763298, 43.704312443733215, 45.8741670101881, 47.03394457697868, 51.14454500377178, 52.965445294976234, 51.31321795284748, 48.98460790514946, 47.691594287753105, 48.04877892136574, 47.09375336766243, 47.590766698122025, 50.468694269657135, 55.26062473654747, 56.86599679291248, 62.09546998143196, 59.55428794026375, 60.454482436180115, 58.424220979213715, 57.87592180073261, 53.548318818211555, 59.9899535626173, 61.87619134783745, 57.00243607163429, 51.80395022034645, 47.69178807735443, 47.95976109802723, 53.10807444155216, 57.193930596113205, 62.78277330100536, 61.49654231965542, 64.82577547430992, 60.3820963203907, 66.66308328509331, 65.91381669044495, 62.58820854127407, 12.905395701527596, 10.738131646066904, 47.795131132006645, 59.337555170059204, 60.520682483911514, 58.40301811695099, 47.92095758020878, 57.33846344053745, 17.72853199392557, 14.901914969086647, 41.76288641989231, 34.116651713848114, 37.877686098217964, 53.67308512330055, 6.163916671648622, 0.6602513836696744, 0.03634493099525571, 0.1397634472232312, 0.09114964253967628, 0.13117693219101056, 0.025269705365644768, 0.05841594276716933, 0.03464916066150181, 0.12950304779224098, 0.0033892650571942795, 0.04539397843473125, 0.03411196819797624, 0.06174709116749, 0.05211518691794481, 0.014608587935072137, 0.04036084792460315, 0.04003561283752788, 0.024961292911029886, 0.07135308333090506, 0.08673272095620632, 0.06616696278797463, 0.05353070002456661, 0.08155000687111169, 0.02684039227460744, 0.05296068608004134, 0.034499773755669594, 0.07427004282362759, 0.0714854231046047, 0.05470472569868434, 0.027336740640748758, 0.003926755307475105, 0.0429743729182519, 0.02783104995614849, 0.037688622760470025, 0.0413866296003107, 0.05850212095538154, 0.02647893110406585, 0.17358957353280857, 0.05788009730167687, 24.65206068009138, 74.45736944675446, 42.94716127216816, 86.01102188229561, 30.67432712763548, 28.506697341799736, 74.71985176205635, 70.21344557404518, 78.59229996800423, 79.33804795145988, 69.21681225299835, 69.30954247713089, 62.955907210707664, 19.804907776415348, 1.8367580277845263, 1.1660389183089137, 48.6057036370039, 75.14675885438919, 75.18331289291382, 75.02527937293053, 70.59109210968018, 69.62729662656784, 64.0406084060669, 56.5821748226881, 55.87586872279644, 61.45472176373005, 66.28069460391998, 71.19009956717491, 67.64863640069962, 68.04449915885925, 67.9563058912754, 64.30563658475876, 59.706272184848785, 56.559957414865494, 53.32036904990673, 51.2783358246088, 53.965734019875526, 55.40435582399368, 52.171014323830605, 49.67021271586418, 49.47329208254814, 50.88246926665306, 51.46629273891449, 48.867236003279686, 49.62721422314644, 47.73873835802078, 51.98001377284527, 49.84806977212429, 48.360776379704475, 46.11159346997738, 45.462234914302826, 45.643857568502426, 44.51516233384609, 45.40679968893528, 49.63228315114975, 48.058320209383965, 57.535498067736626, 56.8805006146431, 55.99864773452282, 54.2935424298048, 57.959000542759895, 57.85403497517109, 57.664261758327484, 59.332436844706535, 62.00865224003792, 61.83592110872269, 65.41551902890205, 58.23553450405598, 58.405605778098106, 63.61284255981445, 64.60920229554176, 61.827379167079926, 60.83481542766094, 59.98915560543537, 57.7555176615715, 54.16509412229061, 48.04073475301266, 46.50522954761982, 46.69379822909832, 46.175775825977325, 43.77028830349445, 44.57037337124348, 47.386523857712746, 47.301594614982605, 45.684203803539276, 45.97118720412254, 43.58670875430107, 46.97516173124313, 47.86171495914459, 49.672769978642464, 53.2199252396822, 55.006923750042915, 54.9222718924284, 52.05043539404869, 50.26241473853588, 50.02254880964756, 48.98346796631813, 50.912966430187225, 54.27614316344261, 59.84056457877159, 59.46977287530899, 63.43764916062355, 62.879356518387794, 62.562426924705505, 62.80449293553829, 61.68688550591469, 54.61141437292099, 60.48198916018009, 65.68214312195778, 61.005874648690224, 54.459080547094345, 49.06019724905491, 50.6956522911787, 55.39250425994396, 62.70063690841198, 64.99617353081703, 65.50575658679008, 67.68633037805557, 65.39628446102142, 68.57518628239632, 66.94284707307816, 62.691783383488655, 15.387600157409906, 11.974692642688751, 55.09057246148586, 65.36203309893608, 67.80609235167503, 63.213385194540024, 60.23269593715668, 57.45151877403259, 32.02604189515114, 16.646764241158962, 40.62195584177971, 42.53771424293518, 39.06945414841175, 60.69516532123089, 5.880182096734643, 0.48642585170455277, 0.05774301891506184, 0.058141047557001, 0.10210039516096003, 0.19268387550255284, 0.030084559111855924, 0.028991438666707836, 0.0445281889551552, 0.06596181090571918, 0.03006349696079269, 0.008203517663787352, 0.05598532377916854, 0.05722738213080447, 0.024807599693303928, 0.04955558637448121, 0.02211434763012221, 0.036048394758836366, 0.06996963842539117, 0.2103171855560504, 0.17749880673363805, 0.22352652362314984, 0.14635932922828943, 0.09008437118609436, 0.12446756096323952, 0.22812294104369357, 0.12410726310918108, 0.11761285495595075, 0.1100784752634354, 0.18296502123121172, 0.0639997654070612, 0.08353514058399014, 0.13059798278845847, 0.1729089647415094, 0.18179167091147974, 0.1304403506219387, 0.23518946341937408, 0.06657242774963379, 0.3025784168858081, 0.25893749145325273, 40.71675315499306, 83.9063148200512, 59.21388320624828, 90.05273580551147, 33.239582777023315, 24.50563933700323, 74.51174452900887, 77.75966584682465, 79.49405997991562, 85.8991102874279, 74.75071370601654, 78.33076760172844, 65.97513779997826, 24.38288312405348, 2.140931230969727, 1.1573371477425098, 53.15469413995743, 74.21997338533401, 77.41457596421242, 77.18720376491547, 74.0909095108509, 73.91766920685768, 67.05895364284515, 59.224199652671814, 59.29988019168377, 63.352415934205055, 69.82790306210518, 73.27736556529999, 69.68138292431831, 68.56369569897652, 70.49799710512161, 65.518379509449, 62.25396327674389, 60.889536291360855, 54.83239531517029, 52.99825273454189, 55.86769916117191, 58.49691867828369, 56.38586975634098, 52.37512797117233, 48.70047055184841, 53.36205281317234, 54.30710770189762, 50.631519332528114, 53.16692568361759, 49.75100018084049, 52.951253056526184, 51.95951007306576, 51.67909651994705, 48.8967490196228, 49.241052344441414, 49.56191472709179, 46.88487097620964, 49.71062354743481, 52.8758081048727, 52.34441801905632, 61.204322800040245, 61.629668176174164, 59.12733145058155, 57.503196001052856, 58.8646287471056, 58.74419800937176, 61.13039016723633, 63.17270837724209, 64.8020951449871, 63.19183275103569, 66.85400784015656, 58.743552044034004, 61.545202508568764, 65.89906588196754, 68.83341282606125, 65.53154960274696, 63.105588778853416, 62.80762016773224, 61.14853799343109, 55.71255348622799, 52.23357416689396, 48.59733648598194, 50.27955561876297, 47.40067429840565, 46.31118915975094, 45.522199496626854, 50.40673479437828, 49.72254730761051, 47.475765869021416, 47.35985308885574, 47.85403177142143, 49.05670903623104, 50.806762129068375, 52.21889555454254, 55.53065724670887, 56.73040486872196, 58.36374342441559, 55.26918947696686, 52.36662022769451, 53.17108266055584, 53.02043214440346, 52.99916088581085, 55.83640404045582, 63.45927760004997, 62.970563024282455, 68.52897316217422, 66.8229179084301, 64.38946008682251, 64.35122653841972, 65.50347670912743, 57.42036424577236, 63.78762558102608, 68.4784434735775, 61.70276865363121, 57.6649609208107, 51.36664308607578, 54.25689339637756, 59.57693852484226, 63.5489983856678, 68.10643583536148, 67.42760226130486, 72.32981041073799, 68.01183611154556, 73.17997679114342, 70.6227520108223, 69.00730669498444, 17.242422178387642, 14.366140868514776, 58.03570322692394, 71.06407552957535, 72.18091920018196, 70.49282938241959, 62.815428748726845, 69.43281546235085, 27.710235379636288, 21.242524534463882, 65.2481760084629, 47.8197880089283, 51.196119636297226, 68.88695955276489, 17.164218574762344, 1.3349926960654557, 0.2714060473954305, 0.25705448468215764, 0.23118916869862005, 0.4916788323316723, 0.13816848280839622, 0.25579393201041967, 0.1586701045744121, 0.24603817815659568, 0.11483041715109721, 0.15766949654789641, 0.10115129218320362, 0.13089070067508146, 0.10807435741298832, 0.10393834614660591, 0.14663321140687913, 0.12542098324047402], [0.07947257225168869, 0.0031758597970110714, 0.02888495902880095, 0.0295319522410864, 0.04832807040656917, 0.026271578753949143, 0.04801911061804276, 0.06631357406149618, 0.11582605278817937, 0.06031528420862742, 0.0896665568870958, 0.06883155496325344, 0.07049691950669512, 0.04176551825366914, 0.06611409960896708, 0.16244122409261763, 0.1608778306399472, 0.05736577411880717, 0.06899085696204565, 0.26149338867980987, 0.3925713925855234, 0.27884322800673544, 5.323943244293332, 64.19209107756615, 44.09278079867363, 17.598725259304047, 45.48420913517475, 8.614055123180151, 33.894770219922066, 75.46686127781868, 58.71523976325989, 61.860889568924904, 70.56382477283478, 62.8466060757637, 63.82207453250885, 14.842665698379278, 2.2502451902255416, 0.09610132605303079, 33.693054243922234, 72.30208709836006, 67.91828513145447, 72.29064211249352, 69.09667789936066, 68.19785133004189, 57.71754629909992, 53.914410173892975, 50.88810436427593, 57.328321784734726, 64.24757570028305, 68.49363505840302, 68.34860444068909, 67.71084666252136, 67.33523681759834, 68.46442222595215, 64.54161152243614, 54.592476189136505, 54.369709342718124, 54.42909635603428, 58.136591613292694, 56.96253441274166, 58.31129103899002, 53.485857769846916, 50.46296037733555, 49.57705691456795, 50.239239782094955, 46.025178506970406, 48.000137731432915, 48.51921267807484, 48.80817577242851, 46.44920535385609, 44.40748371183872, 43.863554298877716, 43.25440138578415, 41.67339742183685, 42.3021724820137, 43.0738540738821, 42.893914729356766, 47.221510112285614, 58.16523067653179, 53.94231207668781, 53.00436280667782, 54.288777485489845, 53.7969508767128, 53.69174212217331, 55.41078507900238, 55.92518627643585, 57.78547905385494, 59.795145615935326, 63.29690471291542, 54.90309812128544, 54.01328846812248, 62.854642644524574, 59.28018964827061, 60.39441145956516, 56.511388421058655, 54.27396968007088, 53.84378336369991, 52.758603394031525, 46.17793031036854, 43.20851884782314, 44.58819821476936, 42.96818174421787, 43.06126154959202, 42.29329235851765, 41.64121314883232, 42.54537843167782, 43.69716502726078, 43.70231755077839, 45.55081196129322, 44.81017090380192, 49.97735023498535, 53.146862760186195, 54.19762797653675, 56.21689662337303, 56.74539126455784, 55.98089508712292, 55.53300552070141, 48.31520542502403, 49.59723763167858, 47.589497566223145, 49.71191547811031, 52.93247066438198, 55.31174339354038, 57.1932390332222, 61.21750809252262, 61.71851500868797, 61.26428738236427, 61.98687180876732, 61.48398399353027, 58.146246895194054, 61.66363075375557, 59.69640791416168, 55.74561931192875, 47.97516547143459, 51.89586728811264, 58.964947164058685, 62.393298000097275, 67.05491065979004, 66.24705120921135, 66.81646585464478, 67.85878792405128, 67.36893340945244, 70.76344326138496, 58.21120820939541, 12.609843760728836, 16.58004742115736, 54.02088426053524, 58.66866946220398, 61.614689379930496, 46.78262986242771, 59.14017856121063, 50.04337169229984, 5.244719395413995, 41.19471050798893, 41.04676924645901, 34.898923337459564, 41.068200096488, 34.26515534520149, 0.3470905346330255, 0.040925358844106086, 0.03850490727927536, 0.043705944990506396, 0.07827212612028234, 0.07897221628809348, 0.08065211950452067, 0.037760529448860325, 0.04501923467614688, 0.07666544319363311, 0.07674280466744676, 0.08911756798624992, 0.044926826158189215, 0.042660722756409086, 0.0038177906344571966, 0.036505127281998284, 0.020182808111712802, 0.03659233705548104, 0.056066741090035066, 0.05345677840523422, 0.04784852055308875, 0.02282292796735419, 0.03789855778450146, 0.04002461049822159, 0.012995253509870963, 0.0177325389086036, 0.06287657684879377, 0.02995745890075341, 0.050973240577150136, 0.03218332305550575, 0.05051171377999708, 0.03556856288923882, 0.021994789494783618, 0.009137941888184287, 0.08178413219866343, 0.031772436705068685, 0.08096845995169133, 0.1353638622094877, 0.2472611633129418, 0.24718543456401676, 4.43995725363493, 76.15041419863701, 48.305766731500626, 27.063048407435417, 48.66849906742573, 15.429168026894331, 54.02684614062309, 78.89854833483696, 69.68381479382515, 66.607765853405, 76.36751934885979, 70.66639646887779, 69.92855966091156, 20.36560568958521, 3.0684362864121795, 0.07534997901530005, 36.0531722009182, 72.2311145067215, 73.35045844316483, 75.60310676693916, 74.77430284023285, 69.7909614443779, 60.12593686580658, 58.17808158695698, 50.527579709887505, 59.608978405594826, 66.92147701978683, 68.45802336931229, 70.27804210782051, 69.79489043354988, 68.14798280596733, 71.72308176755905, 65.83760797977448, 56.65354639291763, 54.55667831003666, 56.5747956186533, 62.32992880046368, 59.44729708135128, 59.10693034529686, 54.1270087659359, 53.877365961670876, 50.208985805511475, 51.47919304668903, 48.304307609796524, 49.8071763664484, 52.01904147863388, 52.667157500982285, 48.6713907122612, 47.98087276518345, 46.525600254535675, 45.87306506931782, 46.24822273850441, 45.83845652639866, 46.78568109869957, 47.73473717272282, 51.003382578492165, 61.38803914189339, 56.991067081689835, 56.23858965933323, 55.72742968797684, 56.17294818162918, 56.1367779225111, 58.42675544321537, 59.07357193529606, 60.18147088587284, 61.67754180729389, 63.48951257765293, 59.07742492854595, 58.06391291320324, 64.8191486299038, 62.96881511807442, 62.17243865132332, 60.18319599330425, 56.31547473371029, 57.09208086133003, 56.58043831586838, 48.24793763458729, 46.103545501828194, 47.61722467839718, 46.67933240532875, 46.22936055064201, 45.86868770420551, 44.143481478095055, 44.11361888051033, 46.037467047572136, 46.61458007991314, 48.58561411499977, 46.67952619493008, 50.633860006928444, 54.817994087934494, 54.71246995031834, 58.97186279296875, 59.750399217009544, 57.950861379504204, 57.15296119451523, 51.67640246450901, 52.36219726502895, 50.97347818315029, 53.206724748015404, 55.94388887286186, 58.230165392160416, 61.27569817006588, 64.21813488006592, 63.37882451713085, 63.21102172136307, 64.08619076013565, 63.573047295212746, 58.19180645048618, 61.571778282523155, 62.66190938651562, 57.18414232134819, 50.69342941045761, 53.96235600113869, 61.33966013789177, 64.37150225043297, 67.62677997350693, 68.90858799219131, 70.77840685844421, 68.54509189724922, 70.35905376076698, 72.04842031002045, 58.13062973320484, 16.05637662112713, 18.98092959076166, 61.12622559070587, 65.15045285224915, 67.17337310314178, 55.720403864979744, 67.25500792264938, 56.58548824489117, 16.904878690838814, 27.218961641192436, 48.15234616398811, 35.67125089466572, 48.374539241194725, 35.02822279930115, 0.9786213969346136, 0.08454349663225003, 0.06217506917892024, 0.03536220501700882, 0.0829962597345002, 0.05453490746731404, 0.06205701945873443, 0.01906971461721696, 0.10433398507302627, 0.07693928084336221, 0.04564106166071724, 0.016164887383638415, 0.03867017614538781, 0.04201604133413639, 0.04439111056854017, 0.0639875719207339, 0.004812905608559959, 0.046376511454582214, 0.3184970689471811, 0.16237606352660805, 0.14551246451446787, 0.1407126392587088, 0.10270460727042519, 0.14510305132716894, 0.09873673698166385, 0.13754691928625107, 0.23701140627963468, 0.0911400317272637, 0.18299463292350993, 0.13055875286227092, 0.15875579294515774, 0.21585708047496155, 0.15621457539964467, 0.34725992241874337, 0.191188121389132, 0.20402227411977947, 0.19811163190752268, 0.5101054685655981, 0.8481165091507137, 0.8136201195884496, 10.553831085562706, 86.75278007984161, 58.08325007557869, 35.37338487803936, 61.60024635493755, 14.156740754842758, 45.730869099497795, 88.01457077264786, 73.93460869789124, 72.04001516103745, 80.30322656035423, 75.54822251200676, 76.00721508264542, 23.463518656790257, 3.6008974397554994, 0.14564784709364176, 41.65069743990898, 72.7928839623928, 75.10050013661385, 78.4252381324768, 78.10573607683182, 74.89498436450958, 64.47163447737694, 60.93286536633968, 53.70324030518532, 63.44721704721451, 70.5489219725132, 74.54738661646843, 73.15625846385956, 72.49336883425713, 71.53295516967773, 74.2550379037857, 68.74079659581184, 58.532731756567955, 57.82359100878239, 58.676417246460915, 66.36726915836334, 60.567940548062325, 61.075369119644165, 58.5518903285265, 56.83005452156067, 52.992553040385246, 54.84099045395851, 50.28332121670246, 53.08716416358948, 54.44992683827877, 53.845542669296265, 50.1692209392786, 50.14644116163254, 50.77691093087196, 49.09940354526043, 48.60701836645603, 48.74198332428932, 48.03319215774536, 50.00616408884525, 53.77157583832741, 65.4721511900425, 60.711645036935806, 61.041961312294006, 59.50006864964962, 60.459517166018486, 59.47305969893932, 61.04882754385471, 62.81781122088432, 64.42183434963226, 63.651243299245834, 68.33382323384285, 55.91943338513374, 59.08807195723057, 69.38079625368118, 65.83036556839943, 64.60110872983932, 62.888574823737144, 59.11592446267605, 58.48564848303795, 59.67523545026779, 51.64064638316631, 49.30752977728844, 49.7131884098053, 48.1798604875803, 48.74814659357071, 47.08139643073082, 46.35087043046951, 46.191005408763885, 49.39351536333561, 49.40318964421749, 50.72174549102783, 47.9440413415432, 55.30119515955448, 56.06213852763176, 57.976228818297386, 60.81751495599747, 63.313312232494354, 59.994980692863464, 58.953897356987, 53.834154680371284, 55.72733849287033, 53.25749762356281, 56.99161805212498, 58.62432204186916, 62.18232952058315, 65.3707118332386, 67.36506521701813, 67.7808541059494, 65.66496804356575, 67.73919314146042, 63.94619107246399, 61.36479578912258, 65.98130866885185, 67.36707150936127, 60.76110318303108, 56.226684898138046, 56.72255828976631, 62.50950336456299, 67.35099837183952, 72.22862184047699, 73.58166083693504, 73.11382994055748, 73.35393145680428, 74.61962834000587, 75.52317425608635, 63.9129276573658, 21.77107997238636, 19.755814410746098, 66.12818598747253, 69.16502103209496, 73.2308940589428, 58.953524976968765, 74.42934975028038, 60.53674042224884, 9.933976046741009, 55.317978858947754, 62.957100346684456, 46.576863303780556, 55.59426583349705, 57.27620758116245, 1.9376737251877785, 0.27032325393520296, 0.13027502980548888, 0.11291854083538055, 0.22859852411784232, 0.1471012839465402, 0.1452938129659742, 0.16152964410139248, 0.15634672221494839, 0.17713303182972595, 0.20946131116943434, 0.22950860497076064, 0.19521258043823764, 0.08874704333720729, 0.1501102771726437, 0.09528880051220767, 0.1599324235576205, 0.16466665780171752], [0.04982841099263169, 0.07358717790339142, 0.017479924827057403, 0.029747651897196192, 0.013430724429781549, 0.04258858971297741, 0.06544137984747067, 0.05489465984283015, 0.032598495308775455, 0.0731478858506307, 0.04853735605138354, 0.05954602958809119, 0.05129352924996056, 0.008478824765916215, 0.03852815134450793, 0.03197847916453611, 0.033388129304512404, 0.031125235691433772, 0.028942388271389063, 0.02537788823246956, 0.015085841769177932, 0.3537145588779822, 0.05937102003372274, 37.172850519418716, 59.03830222785473, 35.3824207931757, 40.303597524762154, 37.05816127359867, 11.691162306815386, 60.75692720711231, 66.36207103729248, 68.79998221993446, 72.5953857600689, 61.13744638860226, 68.35595324635506, 26.698140688240528, 2.8690063627436757, 0.19986982428235933, 26.99499785900116, 76.13352030515671, 73.07688072323799, 71.38988524675369, 69.20345216989517, 63.26316252350807, 56.74322158098221, 53.454969227313995, 51.23929671943188, 54.50541906058788, 60.29588274657726, 67.5954620540142, 69.13105085492134, 70.37318900227547, 68.09726312756538, 68.42402279376984, 65.87609231472015, 58.50945420563221, 56.42701014876366, 55.89659661054611, 59.58873689174652, 62.51972481608391, 66.86305895447731, 62.41963818669319, 59.277195408940315, 50.409052670001984, 46.876659616827965, 47.011031806468964, 50.42548678815365, 53.55198182165623, 50.721696093678474, 49.365849047899246, 46.64264157414436, 45.56658871471882, 43.722551465034485, 42.79668174684048, 42.40772321820259, 43.967767506837845, 44.51668605208397, 51.0293959826231, 59.92382951080799, 53.80083806812763, 53.86903680860996, 55.829720199108124, 51.13998144865036, 54.45434980094433, 55.40254332125187, 54.03049014508724, 58.0530720949173, 59.09597173333168, 62.4984497576952, 61.57210126519203, 51.62686452269554, 61.35660722851753, 59.604699835181236, 58.63662578165531, 56.23422749340534, 58.139517456293106, 52.72969454526901, 51.160557344555855, 46.87632143497467, 43.7110760807991, 43.11480827629566, 43.75256225466728, 44.11028265953064, 43.45749668776989, 42.04750634729862, 42.089167311787605, 43.821707144379616, 44.937502071261406, 46.106212958693504, 50.14843985438347, 54.304170459508896, 56.289077550172806, 58.04340161383152, 53.603089079260826, 55.21824561059475, 55.80974467098713, 54.770701825618744, 51.83961130678654, 50.451690182089806, 46.212212070822716, 47.85482592880726, 47.01615773141384, 49.292246997356415, 52.12584614753723, 54.04049500823021, 55.26545807719231, 58.614290580153465, 62.961283922195435, 60.67606374621391, 63.139023184776306, 57.10544474422932, 59.14611004292965, 53.72598208487034, 48.428804129362106, 50.859499499201775, 58.75888042151928, 63.70181478559971, 64.33224275708199, 68.23606207966805, 69.89427790045738, 67.26655930280685, 68.7032850086689, 68.71704787015915, 29.596902541816235, 4.941533664241433, 23.133798949420452, 57.594227716326714, 56.428096890449524, 61.59708872437477, 48.32199186086655, 66.44445061683655, 14.701694212853909, 12.152287513017654, 47.929263934493065, 30.240570902824402, 27.277581095695496, 51.59413307905197, 9.804098065942526, 0.7251098065171391, 0.04182350967312232, 0.0666513032047078, 0.029622581459989306, 0.04653005438740365, 0.026019927609013394, 0.05660484268446453, 0.03790200877119787, 0.05344302269804757, 0.039982797898119316, 0.05154053826117888, 0.05162674613529816, 0.0547918018855853, 0.059403808118076995, 0.03124364164250437, 0.046199646531022154, 0.04245607924531214, 0.03710038166900631, 0.04840045206947252, 0.09180884779198095, 0.002557459215495328, 0.04535239590040874, 0.04688708308094647, 0.036770664009964094, 0.021721018638345413, 0.05914539229706861, 0.07904506550403312, 0.02433784247841686, 0.05463550929562189, 0.017485698735981714, 0.024575450333941262, 0.09073054432519712, 0.0538918513484532, 0.03606175341701601, 0.08179429220035672, 0.05660117276420351, 0.03259828379668761, 0.02591239597677486, 0.02520110680052312, 0.36884125031065196, 0.042212832922814414, 38.553780019283295, 68.17940711975098, 32.86827810108662, 51.110795214772224, 27.644863687455654, 27.73340653628111, 75.65466240048409, 67.34553426504135, 72.98677995800972, 77.8870578110218, 71.1945529282093, 75.56328490376472, 34.036244228482246, 2.657315921969712, 0.13454853877192363, 31.404492147266865, 79.69404324889183, 74.75720375776291, 76.72329425811768, 72.61053934693336, 68.00897866487503, 59.23586502671242, 55.88218778371811, 55.44240318238735, 57.34238862991333, 64.50112089514732, 70.21050453186035, 68.96756082773209, 71.60542488098145, 70.11246979236603, 71.91936403512955, 66.48252457380295, 62.049321457743645, 58.19204203784466, 58.89969326555729, 62.32256859540939, 63.270317539572716, 67.1766409277916, 62.671982645988464, 60.91399557888508, 53.02677020430565, 50.38615129888058, 48.47543142735958, 54.80651870369911, 54.46688152849674, 56.37984707951546, 52.13984079658985, 48.114154413342476, 48.23499172925949, 47.99203656613827, 45.754047855734825, 45.61647243797779, 45.5390439927578, 47.977388352155685, 53.95960494875908, 61.768098548054695, 55.67529648542404, 57.056263983249664, 57.3767501860857, 57.20248393714428, 58.72238717973232, 57.252842634916306, 55.96646346151829, 59.54632356762886, 63.232380375266075, 64.30752888321877, 62.37481579184532, 56.79868720471859, 65.25523602962494, 63.28903913497925, 61.354243755340576, 59.54676814377308, 59.85779285430908, 55.67536108195782, 54.587897434830666, 49.911488369107246, 47.27096065878868, 48.21501240134239, 48.14251609146595, 47.1404642611742, 45.54948963224888, 45.96193850040436, 45.77703282237053, 46.88386783003807, 47.21929483115673, 48.440363109111786, 53.14759612083435, 56.348734349012375, 57.814680486917496, 60.13032183051109, 56.5548162907362, 58.54682520031929, 58.149936497211456, 57.33131222426891, 54.027028530836105, 52.78209753334522, 49.038454815745354, 50.84036372601986, 49.58587624132633, 53.276792988181114, 55.604544281959534, 57.06240825355053, 58.16122189164162, 62.07695357501507, 64.80309829115868, 61.856132224202156, 65.52979409694672, 59.704471081495285, 62.41757109761238, 56.55756734311581, 51.22383914887905, 55.07170647382736, 61.998153403401375, 66.12897634506226, 69.19634655117989, 68.6345998942852, 72.6844833791256, 68.46439942717552, 70.7905738055706, 68.86547550559044, 29.98316891491413, 5.516155930235982, 27.14309111237526, 62.970992401242256, 62.997925356030464, 65.62778323888779, 56.6811291128397, 68.28745812177658, 28.910518772900105, 15.768652260303497, 35.021489560604095, 39.48739752173424, 25.344983898103237, 61.087691858410835, 10.10240200906992, 0.6965324305929244, 0.033095463368226774, 0.0984149714349769, 0.04678270372096449, 0.030955497240938712, 0.026336167866247706, 0.07918524235719815, 0.0248953586560674, 0.01261668769075186, 0.0609078260458773, 0.06185114027175587, 0.05482744723849464, 0.01787319444702007, 0.029439402715070173, 0.05475680962263141, 0.0351218790456187, 0.09030023968080059, 0.10297146131051704, 0.2598792768549174, 0.26325506914872676, 0.06066285051929299, 0.087889936985448, 0.10786050755996257, 0.11136072833323851, 0.203134888142813, 0.1854037630255334, 0.10667301932699047, 0.1828600073349662, 0.24985339608974755, 0.11384554265532643, 0.14492634596535936, 0.17520347755635157, 0.1516721269581467, 0.1452032709494233, 0.14835600333753973, 0.1855606827302836, 0.10490772459888831, 0.20112270314712077, 0.11594439565669745, 0.5529802304226905, 0.24617301154648885, 58.099513202905655, 76.6902968287468, 50.866608917713165, 61.209657713770866, 49.95507203042507, 17.1014953404665, 69.9953144788742, 74.06977504491806, 82.87751242518425, 84.10186752676964, 76.14628002047539, 81.5183937549591, 38.29948626458645, 3.9252192992717028, 0.46882486960384995, 33.535727486014366, 81.50167465209961, 78.66584122180939, 79.52562108635902, 76.56593710184097, 69.5640604197979, 62.734641283750534, 58.68567734956741, 58.12981657683849, 58.07676002383232, 68.52710366249084, 73.11861768364906, 73.30545365810394, 74.02774170041084, 72.76950001716614, 74.51118215918541, 67.57352203130722, 63.362303003668785, 60.52473686635494, 61.58171854913235, 64.3061001598835, 64.9935744702816, 70.43369695544243, 64.99080061912537, 64.58923816680908, 54.0324242413044, 50.68760812282562, 50.40997602045536, 57.813840731978416, 58.79674158990383, 57.508109137415886, 54.94463749229908, 50.70275790989399, 52.16610498726368, 50.75453773140907, 48.20835515856743, 48.13047453761101, 48.94988916814327, 51.667624935507774, 58.9901702105999, 65.5103163421154, 57.74323292076588, 58.69763910770416, 59.39967803657055, 59.05878692865372, 61.10740140080452, 60.854676961898804, 57.42978774011135, 62.95206181704998, 63.61458286643028, 67.9490938782692, 61.537306532263756, 56.93775974214077, 66.48849785327911, 64.0877714753151, 63.2084796577692, 62.023897022008896, 66.03021964430809, 58.009739220142365, 58.58641527593136, 51.20849557220936, 49.64812070131302, 50.334500670433044, 51.005525663495064, 49.67183142900467, 48.71264889836311, 46.507874205708504, 46.63505718111992, 49.469925463199615, 49.026914834976196, 50.692969635128975, 54.94727835059166, 57.06556588411331, 61.69560603797436, 62.74604447185993, 59.66704688966274, 59.178434908390045, 60.04176378250122, 59.10896323621273, 57.07795321941376, 56.85447581112385, 52.20401935279369, 53.55842247605324, 52.9745914041996, 53.27276900410652, 59.36007276177406, 60.567932948470116, 60.82793019711971, 64.02774229645729, 69.67061430215836, 66.28735184669495, 68.58980789780617, 63.42660695314407, 64.61616352200508, 59.48348633944988, 54.78782370686531, 57.26238772273064, 63.01831506192684, 67.603350430727, 70.45880600810051, 73.97003039717674, 75.83575308322906, 74.12818551063538, 72.59498298168182, 75.96803918480873, 33.810783326625824, 7.807452455163002, 29.229847937822342, 69.1552783548832, 66.7732621729374, 71.10662564635277, 60.399377793073654, 79.78407561779022, 22.4508273974061, 15.734025668352842, 66.90673381090164, 47.25962206721306, 39.640574902296066, 70.16877517104149, 25.27829747647047, 1.1349235754460096, 0.23254815983818844, 0.20671480073360726, 0.13860945211490616, 0.1267514462233521, 0.0912023127602879, 0.21851169818546623, 0.11900661571417004, 0.21084433305077255, 0.21807383105624467, 0.17569783696671948, 0.16428940929472446, 0.20074137282790616, 0.1587988671963103, 0.1288914290489629, 0.08187929779523984, 0.15294002689188346, 0.207773563452065], [0.04199788469122723, 0.05376649889512919, 0.02434145859297132, 0.023750280452077277, 0.03959385314374231, 0.020028903381899, 0.05721934838220477, 0.022097289365774486, 0.054077302920632064, 0.04434380978636909, 0.05974079140287358, 0.057767699036048725, 0.02285276415932458, 0.022411457175621763, 0.06496610847534612, 0.03349132864968851, 0.04526565367996227, 0.07482439003069885, 0.07593407892272808, 0.11897790202056058, 0.130059881194029, 0.39654829481150955, 0.5982434609904885, 9.062304720282555, 70.31023398041725, 42.54996098577976, 34.70287665724754, 65.61063095927238, 18.83506301790476, 20.45453041791916, 91.82977885007858, 71.22349217534065, 80.00874996185303, 62.441327422857285, 63.1638016551733, 36.741174682974815, 6.50224719196558, 0.34969036700204015, 22.41923589259386, 76.77299559116364, 74.68976497650146, 74.10414800047874, 65.8003243803978, 61.426797062158585, 55.658603981137276, 56.65442414581776, 53.65589864552021, 54.56438809633255, 58.142390102148056, 64.77279871702194, 66.1339844763279, 66.69956892728806, 71.17417842149734, 74.38798516988754, 67.58676052093506, 62.761414647102356, 57.32850417494774, 57.859871461987495, 60.81585444509983, 64.6508252620697, 66.01388812065125, 65.65916195511818, 64.48015362024307, 58.35325978696346, 49.445572569966316, 53.0289550870657, 53.06348763406277, 53.459574580192566, 54.732996448874474, 49.3106684088707, 44.77564975619316, 44.81357552111149, 42.80769355595112, 41.69211521744728, 43.770402297377586, 42.334314957261086, 46.14095449447632, 54.88363556563854, 61.87617614865303, 54.858625307679176, 55.76013073325157, 58.89783516526222, 56.034609004855156, 55.42024277150631, 55.052988678216934, 56.6771849244833, 58.9782540500164, 60.4127948731184, 59.02586929500103, 67.55963757634163, 52.922382205724716, 55.744277983903885, 60.25227628648281, 58.363268449902534, 56.9927503913641, 54.04317006468773, 55.03089286386967, 51.77503377199173, 49.20835129916668, 44.43950079381466, 44.693794548511505, 43.407859951257706, 43.58635537326336, 43.41261349618435, 41.87775045633316, 43.66025000810623, 44.18849766254425, 46.52378395199776, 51.04051798582077, 50.88021218776703, 55.072652623057365, 55.85718512535095, 57.21534624695778, 55.81587754189968, 53.68028573691845, 53.52118447422981, 53.14320735633373, 51.47315137088299, 49.60297532379627, 47.409539222717285, 45.24783901870251, 47.47554928064346, 46.469560861587524, 44.44016955792904, 49.01923164725304, 53.64052087068558, 56.63365066051483, 61.61698445677757, 63.02915968000889, 64.00386437773705, 58.822572603821754, 60.76222412288189, 55.90460278093815, 50.62055692076683, 52.41448625922203, 61.093763932585716, 62.582562044262886, 67.21889466047287, 70.10560736060143, 66.63565635681152, 69.92496505379677, 64.34986621141434, 30.87564032524824, 3.2056001387536526, 3.3844819525256753, 26.250574104487896, 51.721855625510216, 59.8965659737587, 60.485868752002716, 67.31342598795891, 44.625185430049896, 6.7113689705729485, 42.594194412231445, 42.15195894241333, 28.631518743932247, 37.2674198448658, 47.1075314283371, 1.9384182477369905, 0.50014614360407, 0.07347942548221909, 0.07681514180148952, 0.033827926017693244, 0.07309529726626351, 0.07355988171184435, 0.030173705890774727, 0.029256214693305083, 0.04755751331686042, 0.12965180387254804, 0.08405569780734368, 0.02669765686732717, 0.04455095804587472, 0.08930218464229256, 0.06250401129364036, 0.024630812695249915, 0.0460708950413391, 0.0838542047131341, 0.04660253252950497, 0.05618779279757291, 0.02313856708497042, 0.012602008009707788, 0.035459723221720196, 0.01121314078773139, 0.08082493601250462, 0.06897885643411428, 0.022917954411241226, 0.05203908709518146, 0.025161064222629648, 0.02355443695705617, 0.035854601446771994, 0.04331606513005681, 0.013458206158247776, 0.03655326298030559, 0.07690217345952988, 0.0473121852701297, 0.03376670996658504, 0.06643721586442553, 0.028547098154376727, 0.22388196783140302, 0.5940798937808722, 9.733553901314735, 83.01492065191269, 40.22321663796902, 39.28118258714676, 50.70975713431835, 17.687819078564644, 44.06492829322815, 86.69742465019226, 77.49896183609962, 80.75222566723824, 71.49875700473785, 70.50238206982613, 43.96861106157303, 7.502882648259401, 0.3350420342758298, 25.366103164851665, 79.15329426527023, 76.97810858488083, 77.2259920835495, 70.3750205039978, 63.67743529379368, 56.93484149873257, 59.50225733220577, 55.06214238703251, 58.14888775348663, 61.191297098994255, 67.85401538014412, 68.25859487056732, 68.00936624407768, 72.80195787549019, 74.5718877017498, 70.93648597598076, 66.87397196888924, 60.62343657016754, 60.802634954452515, 63.34978647530079, 68.01165372133255, 68.64620447158813, 68.00682038068771, 65.81809222698212, 59.037466272711754, 49.695982933044434, 53.59760597348213, 57.67324447631836, 59.576862528920174, 57.68501624464989, 51.632647812366486, 48.79528686404228, 48.782804533839226, 46.47661328315735, 46.50158554315567, 47.09967344999313, 46.92787706851959, 48.183071315288544, 59.791095033288, 64.88130569458008, 58.131670877337456, 59.23826649785042, 60.65324977040291, 58.92197526991367, 57.24858686327934, 58.890034183859825, 60.624272525310516, 61.8038584291935, 63.30432951450348, 60.83207957446575, 70.16505137085915, 56.61288857460022, 59.042440205812454, 65.00289157032967, 62.085560113191605, 60.07762245833874, 56.034582406282425, 56.852724105119705, 56.12531013786793, 52.78451420366764, 46.94184131920338, 48.07705320417881, 46.8099731951952, 47.784582898020744, 45.13580963015556, 44.661842063069344, 46.219690069556236, 48.66893984377384, 48.70597645640373, 52.34415203332901, 53.78370098769665, 57.60318383574486, 58.939066752791405, 58.92634503543377, 57.66610845923424, 56.70491203665733, 57.675642147660255, 55.9584990888834, 54.94598641991615, 51.36135756969452, 50.380945578217506, 50.421204417943954, 49.80263940989971, 49.81350302696228, 48.512924015522, 50.4878756403923, 56.43002338707447, 58.93495537340641, 62.82753109931946, 63.88955131173134, 66.12598210573196, 61.564737260341644, 64.18736413121223, 56.92181959748268, 53.953194692730904, 53.62545847892761, 63.78560408949852, 65.65881237387657, 68.75870883464813, 72.02980890870094, 68.21122661232948, 69.51668456196785, 67.163957208395, 31.556280702352524, 3.866735687479377, 4.395455466583371, 31.235121935606003, 57.91911408305168, 65.08303686976433, 65.05399122834206, 69.1376169025898, 53.68712916970253, 20.66287513822317, 27.591391056776047, 43.03241349756718, 33.53329561650753, 42.05946050584316, 56.42590440809727, 0.8844506344757974, 0.24917706206906587, 0.06259466463234276, 0.06418131699319929, 0.04955136726493947, 0.0611290120286867, 0.07297814925550483, 0.035654993407661095, 0.004838679005843005, 0.049232332821702585, 0.11758151405956596, 0.035124101777910255, 0.017229906407010276, 0.05562802420172375, 0.0418488985451404, 0.012975141307833837, 0.030879165497026406, 0.025062349304789677, 0.02788310419418849, 0.20796689292183146, 0.15160775306867436, 0.06988751236349344, 0.13377579976804554, 0.10452746297232807, 0.12936670042108744, 0.14030809456016868, 0.21760595147497952, 0.17853868921520188, 0.17532576865050942, 0.2069352037506178, 0.1069695815385785, 0.08297821812448092, 0.18404750298941508, 0.1649008647655137, 0.15021928382338956, 0.17105194798205048, 0.19156572612700984, 0.24639069830300286, 0.2253041899530217, 0.3013235639082268, 0.5787240865174681, 1.3107889448292553, 17.447592169046402, 94.53585684299469, 56.888635978102684, 52.77982905507088, 96.00364968180656, 22.495292611420155, 32.694954201579094, 98.74804481863976, 83.9962711930275, 90.63484936952591, 76.37436658143997, 74.45049941539764, 49.40798498690128, 8.670328203588724, 0.6527431646827608, 27.98517532646656, 79.64021533727646, 79.67092528939247, 81.37463226914406, 73.58660817146301, 67.28025376796722, 61.38972245156765, 64.79448795318604, 57.240253910422325, 60.95719166100025, 62.98128604888916, 71.84980496764183, 71.03055372834206, 69.12237972021103, 75.51517948508263, 77.09869131445885, 71.02290093898773, 69.51276317238808, 61.62473604083061, 65.1941505074501, 65.11730343103409, 71.1462651193142, 70.57115077972412, 71.153135150671, 66.14049732685089, 63.300005346536636, 49.748773500323296, 57.92043261229992, 59.93092752993107, 61.45278386771679, 60.83078384399414, 53.30622620880604, 52.41693712770939, 53.20327453315258, 48.460376635193825, 48.72966058552265, 49.31019343435764, 48.491933941841125, 52.87474416196346, 63.02802734076977, 67.9275718331337, 61.537306532263756, 61.8584842979908, 64.18757691979408, 63.42093005776405, 60.14020889997482, 60.26080682873726, 62.75281950831413, 63.99834707379341, 67.09574326872826, 62.600174099206924, 72.0039550960064, 52.94276811182499, 61.629763171076775, 66.89962059259415, 62.774037569761276, 61.340051516890526, 58.74409161508083, 59.25802543759346, 58.44114527106285, 55.20609766244888, 50.1041342318058, 51.303513273596764, 49.64374713599682, 48.31658095121384, 48.57468210160732, 47.54730083048344, 49.30941827595234, 52.17227205634117, 49.72655229270458, 55.18505059182644, 55.51408253610134, 60.173544511199, 61.262676268815994, 61.4266374707222, 60.32147437334061, 59.061803966760635, 60.350413620471954, 57.50986464321613, 57.8720536082983, 54.23030622303486, 53.05263541638851, 53.161020800471306, 52.89042592048645, 51.384198144078255, 49.55941446125507, 54.23409841954708, 58.748552575707436, 60.95435321331024, 67.15878188610077, 68.18899020552635, 69.78517055511475, 64.72766473889351, 66.6779100894928, 61.62615716457367, 57.80374847352505, 56.325023621320724, 68.13945606350899, 68.63154485821724, 69.90731120109558, 76.32612437009811, 71.69514566659927, 72.69378527998924, 73.55334475636482, 35.929378643631935, 4.981173612177372, 4.753263741731644, 33.97672042250633, 62.95474447309971, 68.66610780358315, 70.17458885908127, 77.64254093170166, 56.62128992378712, 12.548506502062082, 55.02901576459408, 62.46208190917969, 45.39482653141022, 53.713887333869934, 71.94242119789124, 5.526185967028141, 0.7817552669439465, 0.13046246662270278, 0.18934231105959043, 0.1485860245884396, 0.18872583867050707, 0.16827653831569478, 0.10760343502624892, 0.1348818076075986, 0.24802450672723353, 0.3013972146436572, 0.24212167190853506, 0.13618476659758016, 0.09713416555314325, 0.22322375705698505, 0.18759872415103018, 0.12307895813137293, 0.17326167784631252, 0.16270492400508374], [0.011760060024244012, 0.03277552350482438, 0.017267216026084498, 0.05947946265223436, 0.028504476613306906, 0.011762002595787635, 0.05777138751000166, 0.0200939489150187, 0.0539687155833235, 0.04786530422279611, 0.05905112098844256, 0.08437257260084152, 0.0717260422243271, 0.029821050302416552, 0.07738974221865647, 0.10924370755674317, 0.0033917644714165363, 0.07133291917853057, 0.012713487867586082, 0.06011002842569724, 0.1618395946570672, 0.10387132278992794, 0.2916697663022205, 1.1338589200749993, 57.42628052830696, 57.08132363855839, 54.96450662612915, 64.25400495529175, 65.1564109325409, 8.294574916362762, 46.55333876609802, 76.7532442510128, 71.0025492310524, 69.03091102838516, 65.62707647681236, 54.40395310521126, 12.236922271549702, 0.21989325061440468, 7.661773972213268, 76.68145090341568, 84.12609502673149, 74.59372892975807, 69.5612333714962, 63.790179044008255, 64.16345581412315, 64.24757570028305, 63.164842799305916, 56.500593200325966, 56.07217378914356, 61.269580498337746, 66.81388959288597, 68.39341923594475, 72.11459755897522, 71.96098700165749, 70.08666157722473, 64.95514333248138, 60.927515253424644, 55.522206500172615, 61.473420560359955, 64.83890756964684, 69.90704521536827, 66.58308237791061, 67.64566496014595, 59.20285239815712, 52.88951016962528, 51.62034787237644, 57.53419853746891, 54.381990283727646, 54.88807752728462, 48.59840802848339, 47.0948439091444, 46.27379156649113, 43.991314843297005, 44.30746927857399, 43.71885806322098, 42.875649109482765, 44.238339588046074, 55.29737636446953, 62.38129064440727, 55.173685401678085, 54.11732688546181, 60.92572554945946, 57.62914024293423, 63.308091312646866, 58.768395110964775, 60.06540611386299, 59.33996044099331, 61.86136454343796, 57.374010533094406, 62.40802600979805, 62.94670790433884, 53.874253928661346, 57.295597940683365, 56.1005886644125, 54.708430767059326, 54.06305439770222, 52.723326086997986, 50.575609132647514, 51.02697551250458, 45.284727439284325, 43.3787839114666, 45.60040310025215, 44.07061658799648, 42.58919768035412, 44.20935474336147, 44.50670398771763, 45.025250762701035, 46.76059104502201, 51.72702334821224, 55.612341463565826, 55.89076392352581, 57.55559518933296, 54.30943317711353, 55.00902883708477, 52.17743597924709, 51.17604151368141, 48.803376629948616, 46.526569202542305, 45.689295530319214, 46.521165892481804, 49.65361900627613, 52.17520169913769, 53.592635840177536, 51.72461047768593, 51.63512147963047, 54.021378234028816, 58.71306248009205, 64.0386401116848, 63.947748988866806, 61.41909867525101, 60.917062014341354, 61.353153213858604, 58.89503471553326, 50.721532702445984, 51.707473397254944, 57.43131145834923, 64.69921186566353, 70.03385201096535, 65.94197317957878, 68.52126717567444, 64.79090094566345, 21.533258333802223, 2.163287093862891, 1.358319406863302, 7.330909101292491, 36.2252801656723, 55.86663901805878, 62.483706548810005, 64.16646525263786, 68.36088538169861, 15.314164347946644, 14.566355925053358, 48.32357257604599, 37.64271430671215, 24.494735822081566, 45.22203080356121, 32.23486728966236, 0.2256726217456162, 0.12887139106169343, 0.05504200955328997, 0.034166953919338994, 0.03893929002515506, 0.037284938953234814, 0.080928873794619, 0.040350446724914946, 0.019317905498610344, 0.04411707624967676, 0.0426199751382228, 0.10009634410380386, 0.07661695868591778, 0.01426811191777233, 0.049003610329236835, 0.07955034932820126, 0.046693267504451796, 0.03364597367180977, 0.06273096005315892, 0.037198812715359963, 0.06779652612749487, 0.096724381292006, 0.041959174268413335, 0.015136498914216645, 0.05392506987845991, 0.06014712467731442, 0.033928409102372825, 0.06434787719626911, 0.01890366278530564, 0.06912619501235895, 0.01451789285056293, 0.046759066317463294, 0.025655026583990548, 0.09443320814170875, 0.04477215145016089, 0.033696977770887315, 0.08642569446237758, 0.048735913951531984, 0.018732107928371988, 0.08260045753559098, 0.1159388072846923, 0.42462653189431876, 1.5026753232814372, 64.72950384020805, 63.47254268825054, 53.89795705676079, 79.9271759390831, 32.720990404486656, 17.235991023480892, 64.23993811011314, 80.18709719181061, 78.20994168519974, 73.79835560917854, 71.20370283722878, 58.58462557196617, 14.744062889367342, 0.04904360095679294, 8.708399310708046, 77.73356884717941, 83.71328517794609, 76.17822110652924, 68.93115878105164, 69.09094780683517, 65.6259061396122, 64.64273929595947, 64.01186674833298, 61.11780904233456, 59.91827800869942, 65.3168535232544, 68.14672887325287, 70.30891165137291, 73.52690577507019, 71.55747145414352, 71.57690361142159, 64.82373878359795, 63.34211468696594, 57.835218384861946, 63.86254996061325, 68.89081254601479, 69.72337827086449, 67.1257084608078, 69.75945353507996, 65.09787887334824, 54.86517235636711, 53.50826516747475, 59.18998248875141, 57.305709198117256, 58.73715318739414, 51.40482343733311, 49.874098375439644, 49.25103820860386, 48.09694893658161, 48.18258494138718, 48.95019315183163, 47.803053706884384, 46.351147815585136, 59.04498606920242, 65.81642031669617, 59.98714931309223, 58.961310759186745, 61.50751233100891, 60.1515968888998, 65.60490846633911, 62.067347690463066, 63.033582642674446, 60.75893349945545, 65.6695505976677, 59.863712936639786, 65.85977599024773, 70.07929757237434, 57.92140536010265, 62.56949454545975, 58.8374450057745, 58.57083611190319, 56.75497055053711, 56.2812689691782, 55.8245562762022, 53.497260957956314, 47.043611258268356, 45.58112293481827, 49.25255432724953, 47.102143317461014, 47.200801223516464, 46.16396225988865, 47.341538071632385, 45.92573404312134, 48.653360679745674, 52.29964502155781, 57.26293109357357, 58.78204017877579, 59.52316381037235, 56.80428430438042, 55.716752260923386, 54.70325544476509, 55.383107364177704, 51.77601791918278, 48.70881490409374, 48.779331520199776, 48.04609626531601, 52.22518041729927, 53.88434998691082, 54.12653759121895, 54.08376328647137, 54.632514640688896, 57.12817892432213, 61.30758225917816, 65.75310051441193, 64.98094394803047, 65.05598232150078, 63.789510279893875, 63.89281913638115, 62.37795442342758, 53.96392911672592, 55.93861475586891, 58.867926970124245, 66.71647042036057, 70.77240318059921, 70.91668903827667, 67.97746315598488, 65.90497836470604, 22.2383750975132, 2.1014014771208167, 1.5331121650524437, 8.505474049597979, 41.76205426454544, 61.411202698946, 65.16492247581482, 71.50467708706856, 71.03083491325378, 27.105564326047897, 19.902686029672623, 31.816682629287243, 49.47312489151955, 25.71956779807806, 54.893241450190544, 34.23037201166153, 0.4121131502324715, 0.10334871723898686, 0.0674085239006672, 0.014704134810017422, 0.05372044492105488, 0.021120021883689333, 0.03124452479823958, 0.01216025666508358, 0.02454852521623252, 0.04872404329944402, 0.024435564773739316, 0.07073003551340662, 0.008452603760815691, 0.056269299166160636, 0.048525667225476354, 0.0544082117266953, 0.03682648835820146, 0.09035996772581711, 0.09250933871953748, 0.1263884617947042, 0.14303850039141253, 0.13765981479082257, 0.13372914836509153, 0.09942660777596757, 0.14870190352667123, 0.13589077221695334, 0.08314057777170092, 0.15640119585441425, 0.18992069642990828, 0.19039908482227474, 0.26428807934280485, 0.15031387796625495, 0.16340344824129716, 0.27019507018849254, 0.16007500496925786, 0.10741287376731634, 0.19750102248508483, 0.13592195726232603, 0.13325516832992435, 0.22876084665767848, 0.2884829544927925, 0.5481904093176126, 3.261077874340117, 83.2929365336895, 75.75400426983833, 70.47905892133713, 96.95797607302666, 89.68767419457436, 12.16851169243455, 57.82629646360874, 82.85312533378601, 84.32537913322449, 81.54400438070297, 80.93957841396332, 65.20257845520973, 16.77204731851816, 0.24950494291260839, 10.108084604144096, 80.10353967547417, 88.85428011417389, 80.47029599547386, 74.88025635480881, 71.3239435851574, 70.35896256566048, 67.1604385972023, 71.12619459629059, 62.47835263609886, 62.22578778862953, 67.97256141901016, 70.747180134058, 73.52869167923927, 76.00647792220116, 75.17413258552551, 74.19479593634605, 68.22954922914505, 65.18714368343353, 61.68525919318199, 66.35232076048851, 72.00950279831886, 73.78141611814499, 69.07901644706726, 72.27852076292038, 65.71232870221138, 56.00750505924225, 55.76836869120598, 62.238539904356, 59.3028250336647, 60.440556183457375, 53.84132109582424, 51.143716648221016, 54.09363515675068, 51.15959979593754, 51.33380904793739, 51.39228031039238, 50.784723311662674, 47.29226991534233, 62.78403863310814, 68.67648124694824, 59.90020997822285, 59.554918706417084, 65.36939710378647, 63.63508656620979, 70.74458867311478, 65.36055877804756, 64.90897580981255, 62.71902792155743, 70.09917810559273, 61.06683857738972, 66.79445743560791, 66.43800616264343, 56.02467633783817, 63.78693401813507, 61.272282153367996, 61.027332097291946, 61.61845117807388, 58.580719381570816, 55.583193227648735, 56.72944352030754, 49.33337219059467, 49.277025014162064, 50.76148375868797, 47.85913489758968, 47.0047165453434, 50.217630341649055, 47.46030829846859, 48.352356031537056, 51.082866713404655, 54.43424887955189, 59.29958000779152, 63.55580762028694, 61.15506984293461, 59.01015713810921, 57.59286738932133, 55.52403800189495, 57.50819653272629, 54.54089395701885, 51.84963136911392, 51.3640858232975, 52.10618980228901, 55.39577968418598, 58.93571153283119, 58.31938460469246, 57.69155189394951, 57.136185094714165, 59.86571542918682, 63.555773422122, 67.65049070119858, 69.56630989909172, 65.19724354147911, 68.12742590904236, 66.0064785182476, 65.88527262210846, 55.329667031764984, 58.40042665600777, 61.77749164402485, 69.71495032310486, 74.41771477460861, 71.64833217859268, 70.43828710913658, 72.7337895333767, 30.390904136002064, 2.9586962750181556, 2.3552535055205226, 8.981382362544537, 46.62726379930973, 67.08998277783394, 70.6656289100647, 74.95265766978264, 80.98937094211578, 22.216991744935513, 19.436660036444664, 68.51990684866905, 53.72261166572571, 37.886323034763336, 62.978873178362846, 55.01166969537735, 0.5150743550620973, 0.1951044940506108, 0.17683498532278463, 0.1477011915994808, 0.13489679899066687, 0.11333323069266044, 0.23751247470499948, 0.12090661024558358, 0.07723176866420545, 0.12943422101670876, 0.09291598369600251, 0.30300933751277626, 0.11776786734117195, 0.12338302345597185, 0.17469084647018462, 0.2254987513879314, 0.2955335355363786, 0.26996111555490643, 0.14967273658839986], [0.057180508083547466, 0.04891140590189025, 0.08460723227472045, 0.08164407408912666, 0.03991547768237069, 0.028498864121502265, 0.0010099898167936772, 0.028137466033513192, 0.06382973195286468, 0.12843169824918732, 0.10412107774754986, 0.006642750022365362, 0.060127435499452986, 0.06172751331178006, 0.06319614563835785, 0.09631418142816983, 0.10111342780874111, 0.004644194104912458, 0.14650995552074164, 0.12681772001087666, 0.2182994142640382, 0.11857746139867231, 0.7667826453689486, 0.8010791300330311, 24.01976700872183, 64.65903282165527, 49.65834215283394, 44.28224243223667, 61.146284714341164, 28.096081875264645, 10.631896946579218, 73.22977691888809, 71.61573752760887, 73.3765022456646, 67.73185953497887, 61.25569224357605, 20.14068055897951, 0.7219293178059161, 3.864535130560398, 64.66671600937843, 85.3637646138668, 75.7808992266655, 73.50701004266739, 71.60397335886955, 76.91393002867699, 71.96256771683693, 71.1136856675148, 61.60037934780121, 59.81463477015495, 58.04022878408432, 66.40611067414284, 67.91816353797913, 73.85849878191948, 69.57694172859192, 72.76422590017319, 68.32925587892532, 62.59342946112156, 54.390650019049644, 59.041969031095505, 66.26374751329422, 70.53844973444939, 67.86794543266296, 67.40846648812294, 64.84607398509979, 61.86122015118599, 56.78616687655449, 58.21879640221596, 57.83984653651714, 56.91374123096466, 53.46332497894764, 46.79792404174805, 45.21309368312359, 45.48208124935627, 45.32212123274803, 43.20180460810661, 45.17058156430721, 45.4022741317749, 57.239911928772926, 60.706351920962334, 63.89794126152992, 50.12768916785717, 58.332079723477364, 63.82462799549103, 60.29331788420677, 61.4074333012104, 59.062309339642525, 63.474921360611916, 59.16255556046963, 60.9472019970417, 60.901703238487244, 61.95896230638027, 60.69237247109413, 56.63419783115387, 53.82714785635471, 54.547592997550964, 52.833189591765404, 51.86014920473099, 51.70274265110493, 50.47282464802265, 48.792288824915886, 44.06914986670017, 44.42603811621666, 45.360711961984634, 44.19526889920235, 44.15749132633209, 45.18496759235859, 45.87732084095478, 48.61429117619991, 53.16592253744602, 55.27453199028969, 56.55882887542248, 53.79123978316784, 56.05332300066948, 52.30263166129589, 49.37945991754532, 47.86031283438206, 48.2269399613142, 46.97609268128872, 50.84403432905674, 54.659774377942085, 54.74726848304272, 57.490177899599075, 53.43272142112255, 52.456808388233185, 53.25539633631706, 58.23882132768631, 60.2022709697485, 65.5016528069973, 64.36794564127922, 60.499802604317665, 62.22924180328846, 62.019789442420006, 59.00514900684357, 54.11713309586048, 51.55161336064339, 59.32918801903725, 62.51648359000683, 69.12669628858566, 68.15308213233948, 69.20497208833694, 34.687073305249214, 0.4912659607362002, 0.3619027929380536, 1.149436659179628, 12.521293312311172, 42.87914112210274, 58.45649644732475, 57.54359923303127, 63.349440693855286, 32.181499153375626, 7.592163607478142, 44.01876837015152, 49.07446548342705, 29.420983381569386, 33.54416683316231, 55.158729404211044, 9.281217623502016, 0.7764878589659929, 0.03783417276281398, 0.02667930912139127, 0.05625754354696255, 0.031204946062644012, 0.025690497532195877, 0.08351983007742092, 0.0394522328133462, 0.044152131595183164, 0.1247038459405303, 0.1252327300608158, 0.04432038760569412, 0.09420163580216467, 0.03830279820249416, 0.022193490258359816, 0.07583829734358005, 0.009776640672498615, 0.020303844976297114, 0.025999683675763663, 0.04718857686384581, 0.01565013561048545, 0.02924902699305676, 0.06478992261691019, 0.022189096744114067, 0.04003747562819626, 0.020812405382457655, 0.05546635475184303, 0.026015691801148932, 0.11263323700404726, 0.18560991680715233, 0.03410983823414426, 0.08838414054480381, 0.020372721846797504, 0.03450775555393193, 0.06770435138605535, 0.0847165506274905, 0.08013823418878019, 0.013425431061477866, 0.036550194199662656, 0.035128083400195464, 0.035334244603291154, 0.5195139418356121, 0.6133675994351506, 25.84528025239706, 80.15213906764984, 45.90327724814415, 57.0563817769289, 48.64464394748211, 22.95750740915537, 31.174726076424122, 76.57520100474358, 79.54576000571251, 75.55328384041786, 75.33178612589836, 68.92895489931107, 24.135195314884186, 0.6480767182074487, 4.845765503123403, 64.64633390307426, 88.42384681105614, 77.60793998837471, 77.68680095672607, 76.07384830713272, 79.81113776564598, 77.2863632440567, 72.27857396006584, 64.49707791209221, 61.856679394841194, 60.431630462408066, 67.59506687521935, 69.80110689997673, 75.68484038114548, 72.37394124269485, 73.93945723772049, 68.46737086772919, 63.53932410478592, 57.63235107064247, 61.88690297305584, 69.15190413594246, 70.88246047496796, 69.27460715174675, 69.1969621181488, 65.84976732730865, 62.20651522278786, 58.03716994822025, 62.935403510928154, 60.75381137430668, 60.052365213632584, 54.93820823729038, 49.509944915771484, 46.73394687473774, 47.63561189174652, 48.12474824488163, 47.6008665561676, 50.3539252281189, 49.535422548651695, 60.78622363507748, 65.0451149046421, 67.94267982244492, 53.78840133547783, 60.5870421230793, 64.99641671776772, 60.76946273446083, 65.55855095386505, 61.25041052699089, 64.22517210245132, 62.18922235071659, 63.463601768016815, 62.40947753190994, 69.56622630357742, 65.58104574680328, 59.43398259580135, 58.273357674479485, 57.316006645560265, 57.19264626502991, 55.357048362493515, 56.10004909336567, 54.524345844984055, 50.642040967941284, 47.77379147708416, 47.512148916721344, 48.10781255364418, 46.203096359968185, 46.85667648911476, 45.59077061712742, 48.39282006025314, 49.86514985561371, 54.34451289474964, 58.81483241915703, 58.48987005650997, 57.26960353553295, 56.41173876821995, 54.19113032519817, 51.900852620601654, 50.68481907248497, 51.470799297094345, 51.13776236772537, 52.11649104952812, 55.89226484298706, 56.719362661242485, 61.87379747629166, 58.84580835700035, 55.19116446375847, 56.247074604034424, 61.87978595495224, 62.145251110196114, 68.00856068730354, 66.85390904545784, 62.92407251894474, 64.87672314047813, 66.6594734787941, 62.339036911726, 56.255745738744736, 54.962906911969185, 61.81674353778362, 64.83146756887436, 69.53831300139427, 72.19057068228722, 71.02290093898773, 38.43538597226143, 0.46359246131032705, 1.0386676155030727, 1.3155276468023658, 16.1580952629447, 47.7724539488554, 64.59854766726494, 62.77180328965187, 72.19718992710114, 40.95212012529373, 18.872344717383385, 28.50729390978813, 48.170930966734886, 38.66604499518871, 35.671136900782585, 69.76437047123909, 8.361964300274849, 0.7576701405923814, 0.05713157086574938, 0.13084876933135092, 0.00781030463258503, 0.04745527505292557, 0.014603075633203844, 0.08517012160154991, 0.06217954432941042, 0.05531520895601716, 0.0827224220847711, 0.09166466334136203, 0.0319286402373109, 0.01346573895716574, 0.0302184406973538, 0.02705214556044666, 0.0383247657737229, 0.0219725065107923, 0.06259551068069413, 0.037504596111830324, 0.2066543750697747, 0.17477990419138223, 0.26407211436890066, 0.2738741337088868, 0.0961428195296321, 0.1744402528856881, 0.18784422660246491, 0.23146674677263945, 0.1765662684920244, 0.3038725443184376, 0.23059110157191753, 0.17696676106425002, 0.16740638500778005, 0.1607246365165338, 0.16525239043403417, 0.29195329640060663, 0.212642096739728, 0.10091014613863081, 0.18508469889638945, 0.26974268665071577, 0.30531427008099854, 0.3513789607677609, 1.0146052879281342, 1.109016090631485, 38.133818954229355, 87.97794073820114, 61.78257577121258, 62.8935943543911, 93.76295551657677, 32.90506012737751, 20.519037656486034, 80.81164687871933, 83.96923184394836, 85.33701404929161, 81.77437081933022, 76.61459729075432, 27.605110220611095, 1.176500350702554, 6.014406094327569, 67.41987347602844, 88.8996496796608, 82.1948866546154, 81.85203865170479, 81.02664694190025, 84.77332949638367, 81.59684434533119, 74.4868178665638, 71.02195858955383, 65.99666744470596, 62.22725830972195, 71.57598406076431, 72.56605133414268, 79.79081645607948, 75.16767293214798, 76.63118720054626, 72.35469907522202, 67.02683016657829, 59.14125010371208, 65.12409746646881, 71.49020746350288, 75.0130820274353, 71.68777406215668, 69.86438870429993, 69.30965647101402, 66.64105206727982, 61.84477463364601, 65.1653404533863, 63.05962264537811, 62.07305118441582, 56.99493907392025, 52.203206196427345, 49.75455678999424, 53.02504129707813, 53.1274040043354, 49.03425604104996, 53.61673794686794, 53.98779943585396, 63.43676000833511, 68.35314139723778, 68.76119390130043, 55.15396445989609, 64.14476081728935, 67.12142989039421, 67.74116143584251, 66.94612249732018, 62.58669622242451, 68.32121551036835, 63.94660905003548, 65.67715018987656, 65.27676567435265, 67.94461011886597, 63.93403932452202, 59.156000912189484, 58.573302179574966, 60.99675513803959, 59.34453159570694, 57.66224406659603, 56.2955904006958, 58.257596120238304, 54.29176792502403, 50.70882998406887, 50.23405686020851, 50.850889161229134, 48.81032645702362, 49.660234451293945, 49.801013097167015, 51.246729120612144, 52.757034078240395, 55.61448834836483, 60.51920436322689, 59.27138552069664, 60.31290203332901, 59.87882472574711, 56.54454544186592, 54.20064501464367, 52.94387765228748, 54.018418192863464, 54.01265010237694, 55.2419563382864, 60.32391004264355, 60.46703316271305, 64.4834366440773, 59.80117589235306, 57.20288671553135, 59.47442762553692, 64.81894344091415, 67.3888747394085, 70.48626333475113, 69.861880838871, 65.07768675684929, 68.85697156190872, 69.94109138846397, 64.7296330332756, 59.46057356894016, 57.07070700824261, 64.86539974808693, 68.78469184041023, 74.10135135054588, 74.03968065977097, 73.1419788300991, 42.94643171131611, 0.8874766970984638, 0.6750011828262359, 1.805837305728346, 17.715620286762714, 52.292577400803566, 69.17414054274559, 68.12431007623672, 74.9166887998581, 41.639586836099625, 12.848818637430668, 55.20399257540703, 71.53022691607475, 45.728201642632484, 49.55107770860195, 77.67162457108498, 19.769660867750645, 1.0389677993953228, 0.2725464018294588, 0.2200485227513127, 0.1319257146678865, 0.1937380517483689, 0.12738635356072336, 0.2822954615112394, 0.1585672132205218, 0.12455608433810994, 0.26349415944423527, 0.17241264606127515, 0.10810187624883838, 0.20991733123082668, 0.2075909951236099, 0.10070397009258159, 0.12993356765946373, 0.14842117874650285, 0.10539451410295442, 0.10860243259230629], [0.04678929028159473, 0.03638783084170427, 0.03126752024400048, 0.05399521025537979, 0.04930910057737492, 0.06942809326574206, 0.05091297076432966, 0.03736525046406314, 0.07874108181567863, 0.028493587451521307, 0.0976143276784569, 0.023887609313533176, 0.014606994172936538, 0.03394927458430175, 0.05935299697739538, 0.051400858646957204, 0.02614536540932022, 0.03824887746304739, 0.07220666448120028, 0.05088161131425295, 0.019635392563941423, 0.022712724603479728, 0.0783801828220021, 0.09605609215213917, 1.7113896925002337, 53.61691273748875, 55.096690133214, 43.2417518645525, 46.38998933136463, 63.2970605045557, 10.094478484243155, 27.942596711218357, 73.72752740979195, 70.60267388820648, 61.656612530350685, 65.20279124379158, 37.24759630858898, 2.9009377118200064, 0.5700329435057938, 34.804065227508545, 84.13003161549568, 82.83379197120667, 74.57516312599182, 75.78346028923988, 80.81200405955315, 78.0380617082119, 74.24368411302567, 70.29336288571358, 58.45935769379139, 58.20147693157196, 65.41346713900566, 67.17319071292877, 72.70594462752342, 73.62809434533119, 70.83444625139236, 71.24332711100578, 64.48795840144157, 54.58247892558575, 57.54093557596207, 67.1855628490448, 68.88891264796257, 67.86018624901772, 68.1858591735363, 65.48095911741257, 62.88261294364929, 64.13282185792923, 61.87793545424938, 60.53408436477184, 56.64994418621063, 55.13305798172951, 48.66002932190895, 46.23312994837761, 46.40790157020092, 46.67669914662838, 47.09657281637192, 46.090170219540596, 43.47231589257717, 52.62919373810291, 58.13019655644894, 64.40946221351624, 62.10681237280369, 48.80351722240448, 53.660146817564964, 61.6197507083416, 60.6582161039114, 61.442516818642616, 60.39711691439152, 60.32690808176994, 60.23059464991093, 62.95585781335831, 59.19240675866604, 59.26902584731579, 58.01243707537651, 56.58657118678093, 56.41748405992985, 52.841560542583466, 53.61536622047424, 54.19028677046299, 53.00464779138565, 49.857960641384125, 45.34424364566803, 44.054266065359116, 45.342773124575615, 46.25956133008003, 44.658790826797485, 44.1958312690258, 48.28251197934151, 50.2705767005682, 53.13232094049454, 53.39440047740936, 54.06324438750744, 54.725176468491554, 51.001668870449066, 46.59933529794216, 47.31393255293369, 45.66011309623718, 51.80852897465229, 55.753188505768776, 58.3000398427248, 58.79640720784664, 61.76675342023373, 61.27021886408329, 56.833250150084496, 54.7514558583498, 55.036379769444466, 56.35238595306873, 62.4312237650156, 64.4890071451664, 63.37073475122452, 62.174494341015816, 60.83056725561619, 63.23710732161999, 62.21501536667347, 56.78120814263821, 52.51642718911171, 57.549724504351616, 62.188652381300926, 69.22172158956528, 63.47384601831436, 72.69860342144966, 12.141804825514555, 1.598439565859735, 0.48434795695357025, 2.299368241801858, 11.013119090348482, 41.97123683989048, 61.849562376737595, 58.345895782113075, 56.42403110861778, 10.5632583796978, 14.232709128409624, 50.70342667400837, 38.148611560463905, 26.897808574140072, 49.31886076927185, 48.53802166879177, 0.24293240887345746, 0.3156751563074067, 0.07325407976168208, 0.07869775523431599, 0.027135965574416332, 0.0270602590899216, 0.07810181807144545, 0.08372700060135685, 0.1041756256017834, 0.027925091198994778, 0.06364051398122683, 0.09410674480022863, 0.009486284670856548, 0.036832692712778226, 0.032551650947425514, 0.006824973252150812, 0.13587846740847453, 0.07506506852223538, 0.005299968315739534, 0.03440116830461193, 0.02457570080878213, 0.02604610130219953, 0.04562323527352419, 0.037780233469675295, 0.015254608933901181, 0.009440251105843345, 0.0978571361338254, 0.0167068574228324, 0.016555696784052998, 0.048352487065130845, 0.05606018421531189, 0.024048202649282757, 0.03353900050569791, 0.0389416277903365, 0.02866345577785978, 0.0022043411763661425, 0.03485269466182217, 0.006124776400611154, 0.02297655253642006, 0.030271652685769368, 0.01245245319296373, 0.031562843068968505, 0.1156526870909147, 0.09239554521627724, 1.0759816132485867, 59.60083544254303, 60.47783978283405, 42.70008713006973, 59.76120963692665, 34.99899476766586, 19.433350414037704, 46.4934653788805, 79.14312601089478, 80.42173460125923, 71.09219402074814, 71.04466617107391, 43.89148660004139, 3.18376247305423, 0.5649478663690388, 36.43481992185116, 84.07501056790352, 84.97763693332672, 78.02945896983147, 78.83097276091576, 84.14868101477623, 77.90847346186638, 75.5950739979744, 70.13231232762337, 61.78772069513798, 61.288727670907974, 66.03529617190361, 69.13103565573692, 74.59880545735359, 73.35801243782043, 74.10656467080116, 72.58888050913811, 64.45988550782204, 55.46547554433346, 59.53873157501221, 69.1903504729271, 70.61989456415176, 71.54257625341415, 72.16796189546585, 69.44730788469315, 66.35722249746323, 66.1627109348774, 62.63696752488613, 62.08762340247631, 60.988133400678635, 57.049207761883736, 50.55010110139847, 46.91281847655773, 49.186171889305115, 50.03552511334419, 50.520633682608604, 48.116434291005135, 48.626264333724976, 55.99169410765171, 62.606280371546745, 69.95899602770805, 66.16373687982559, 52.08901472389698, 58.652828112244606, 65.55731981992722, 65.56324750185013, 64.35046657919884, 65.14644026756287, 62.718837931752205, 62.23677299916744, 67.1763901412487, 62.7249214053154, 61.695013269782066, 62.34263151884079, 59.2356788367033, 58.78446824848652, 56.346386075019836, 57.35104836523533, 58.97217437624931, 55.03963619470596, 53.01641955971718, 47.00014919042587, 46.65317080914974, 47.61606954038143, 48.40420424938202, 45.56452162563801, 46.86148703098297, 48.936008512973785, 52.1091840416193, 55.32687418162823, 54.379794001579285, 56.765849366784096, 56.310626193881035, 54.587357863783836, 50.629102662205696, 49.3219918012619, 49.29933361709118, 55.68282388150692, 58.57565425336361, 60.679350569844246, 61.985952258110046, 64.42044362425804, 62.12423823773861, 60.309725403785706, 58.66544723510742, 56.915948912501335, 59.2886745929718, 63.758655935525894, 67.22456395626068, 65.0338751077652, 63.71403492987156, 62.07870528101921, 65.96655026078224, 63.80518063902855, 61.15745231509209, 54.59459647536278, 59.46568049490452, 63.7131267786026, 74.714744836092, 64.0007409453392, 77.12256163358688, 13.855960294604301, 1.3630072865635157, 0.8331702486611903, 3.18613663315773, 15.469295773655176, 45.672420635819435, 66.83456808328629, 61.76716759800911, 64.05214458703995, 20.260985903441906, 21.730444952845573, 28.848107121884823, 44.53139886260033, 27.035779170691967, 55.45061454176903, 49.42474588751793, 0.8804138854611665, 0.03988820746599231, 0.024520039733033627, 0.07843623723601922, 0.05806519264297094, 0.013487484811776085, 0.037608556158374995, 0.04513623796810862, 0.039330847139353864, 0.08163096033968031, 0.021265161849441938, 0.12022542257909663, 0.021033346456533764, 0.10731777496403083, 0.11233130906475708, 0.009590490553819109, 0.08512787855579518, 0.11676803114823997, 0.052730453317053616, 0.09028311833390035, 0.16697449958883226, 0.08072200012975372, 0.1981452660402283, 0.13428518024738878, 0.16208514163736254, 0.14494302944513038, 0.22149655676912516, 0.08916182967368513, 0.20422453904757276, 0.1422890945104882, 0.20323218370322138, 0.11832916105049662, 0.09305082450737245, 0.1241561038477812, 0.12898627552203834, 0.11557955585885793, 0.09828394526266493, 0.14075467450311407, 0.15928991662804037, 0.11947695922572166, 0.11847589848912321, 0.15899762918706983, 0.2372119642677717, 0.24827743065543473, 3.689925237558782, 78.84235695004463, 72.89034873247147, 55.30376002192497, 75.60303077101707, 88.77307087182999, 11.464937645941973, 41.302883103489876, 82.01337039470673, 86.41948476433754, 72.07687318325043, 81.6244612634182, 49.72601652145386, 3.9346587052568793, 0.9248459106311202, 41.87365807592869, 85.78343689441681, 88.0788405239582, 79.556475430727, 84.48507696390152, 87.22425118088722, 81.12082108855247, 80.58293715119362, 77.24733173847198, 66.01363733410835, 64.85809653997421, 68.05844441056252, 71.54097273945808, 79.57309573888779, 77.9130408167839, 75.95125928521156, 75.75107082724571, 69.53378364443779, 59.162680953741074, 62.31507159769535, 71.77643090486526, 72.79625058174133, 72.3130077123642, 73.97267505526543, 70.1585765182972, 68.41194704174995, 70.4866661131382, 65.21145477890968, 64.23090979456902, 63.116228207945824, 58.99966590106487, 53.34147311747074, 49.808688685297966, 50.73917135596275, 52.50155098736286, 52.36290022730827, 51.099072843790054, 51.853518560528755, 57.12330378592014, 63.03324066102505, 70.74170082807541, 63.12218628823757, 57.06780016422272, 60.41132055222988, 66.53837397694588, 68.4214237332344, 66.74509048461914, 67.40891486406326, 66.08243644237518, 61.5394002199173, 67.48460680246353, 66.84193208813667, 62.80533269047737, 64.939374178648, 60.92124938964844, 63.37387718260288, 57.97184765338898, 60.40555626153946, 62.49335803091526, 57.09846071898937, 54.280330538749695, 49.31137137115002, 48.389442041516304, 50.3774231672287, 49.70057688653469, 47.91490450501442, 47.986838445067406, 50.32407023012638, 55.373239293694496, 58.000418320298195, 56.89673714339733, 60.38572512567043, 59.49494272470474, 55.85807427763939, 51.889696419239044, 53.155944272875786, 50.29268391430378, 58.4655399620533, 63.2865958660841, 65.09752929210663, 64.70298886299133, 67.45852500200272, 65.50925239920616, 63.00054341554642, 61.67135573923588, 60.87805710732937, 62.40485318005085, 66.83924183249474, 68.07023897767067, 69.31137397885323, 65.34174218773842, 65.75389847159386, 69.92665216326714, 66.92447125911713, 61.9073610752821, 57.47645303606987, 64.59284797310829, 67.75438472628593, 77.28712320327759, 68.12532842159271, 81.52551457285881, 18.949015103280544, 1.2401977577246726, 1.7762256134301424, 3.2624780992046, 17.245889492332935, 53.567329198122025, 74.34076130390167, 67.67779603600502, 69.92487385869026, 15.199905429035425, 17.407567016780376, 67.95896574854851, 56.5916933119297, 40.14655955135822, 64.32642146945, 70.38966491818428, 3.2616924913600087, 0.7059049245435745, 0.14584929565899074, 0.2711686195107177, 0.13949847081676126, 0.12900281057227403, 0.1607255864655599, 0.2528737293323502, 0.20089639263460413, 0.16838581213960424, 0.19218473666114733, 0.23402288148645312, 0.15544058958766982, 0.2988585946150124, 0.14793299400480464, 0.10435408985358663, 0.3199969494016841, 0.23053679120494053, 0.1658151758601889, 0.15985237550921738], [0.0570342975697713, 0.01701874683931237, 0.04631333613360766, 0.10964644883642904, 0.04727503706817515, 0.06419492056011222, 0.015970223903423175, 0.029360460466705263, 0.057075330914813094, 0.08995997239253484, 0.034835532496799715, 0.05349691375158727, 0.01659269655647222, 0.029104918612574693, 0.10237287468044087, 0.03915138469892554, 0.057099246623693034, 0.054994664242258295, 0.03839914010313805, 0.11567158959223889, 0.04354563738161232, 0.021594768186332658, 0.07643918463145383, 0.6602139794267714, 0.6387428159359843, 17.93820284307003, 71.34254738688469, 46.61755532026291, 49.247929975390434, 55.45432694256306, 45.801184326410294, 4.640700006857514, 58.013983592391014, 60.056989565491676, 52.24238969385624, 64.49142381548882, 51.784753650426865, 9.933559969067574, 0.22036788373952731, 1.2745970743708313, 42.74050936102867, 89.98582899570465, 80.01478403806686, 81.42484277486801, 76.5889410674572, 82.54575222730637, 72.69804865121841, 69.24186810851097, 60.519576743245125, 58.24561536312103, 63.72467055916786, 71.29330962896347, 73.03192153573036, 75.53583517670631, 71.09141126275063, 73.27756315469742, 63.731293603777885, 55.08105397224426, 56.559984013438225, 64.69389975070953, 66.97835996747017, 65.08103057742119, 69.02754440903664, 70.42988196015358, 66.32179319858551, 68.40573817491531, 64.6876072883606, 63.56259785592556, 61.20661027729511, 54.647922813892365, 46.45835906267166, 47.15337976813316, 48.30063320696354, 45.141847506165504, 47.86553755402565, 44.177379459142685, 46.99681296944618, 49.647071957588196, 57.66639344394207, 60.7052955776453, 67.29820400476456, 67.13087618350983, 57.972531616687775, 52.7947698533535, 59.92827907204628, 60.197502225637436, 59.49503391981125, 60.849148258566856, 60.50654724240303, 60.83954617381096, 61.29706062376499, 58.03310416638851, 59.177165776491165, 56.929601579904556, 55.6849517673254, 53.586537167429924, 54.15272198617458, 53.48368428647518, 54.54438216984272, 51.13882251083851, 43.95329028367996, 45.902646481990814, 45.27781940996647, 45.38647837936878, 45.8173942565918, 47.16433458030224, 47.119466587901115, 51.66889026761055, 53.56039457023144, 56.61273658275604, 55.40840640664101, 52.89948843419552, 48.35795313119888, 46.47280968725681, 47.15815991163254, 50.58358870446682, 54.55237694084644, 59.49524290859699, 61.1304547637701, 62.07484468817711, 60.78156888484955, 62.43727304041386, 53.07814724743366, 54.50185105204582, 54.416838213801384, 62.189355343580246, 62.82209359109402, 65.63676595687866, 63.928392827510834, 66.63448601961136, 61.32455214858055, 63.10287952423096, 61.95404537022114, 61.514625549316406, 54.63444873690605, 58.24006386101246, 59.411286413669586, 72.61604905128479, 64.48330745100975, 71.32610946893692, 10.627926159650087, 0.8057221246417612, 1.0110568720847368, 3.386043906211853, 11.70529754832387, 45.64017936587334, 64.52515080571175, 60.807384699583054, 36.19855999946594, 7.643293188884854, 34.53866466879845, 47.19038598239422, 38.582232892513275, 31.700505763292313, 53.41599851846695, 11.118429489433765, 0.4987016273662448, 0.04595067824993748, 0.06780508309020661, 0.04696570249507204, 0.06261978633119725, 0.10472656635101885, 0.07433233127812855, 0.012654140173253836, 0.026298322045477107, 0.006643125734626665, 0.019277926003269386, 0.1390181083115749, 0.06856487903860398, 0.06389625064912252, 0.04430168919498101, 0.04657998608308844, 0.05292281057336368, 0.03120773282716982, 0.02276081020681886, 0.03138325446343515, 0.08802828073385172, 0.06024330330546945, 0.05759656349255238, 0.054346839824575, 0.012901317095384002, 0.04739897201943677, 0.0435619312338531, 0.01620188901142683, 0.016147979404195212, 0.02428608695481671, 0.05639624723698944, 0.022709336699335836, 0.03877744988130871, 0.015036375771160237, 0.12658759485930204, 0.05061336574726738, 0.023151630739448592, 0.018576822803879622, 0.035033077365369536, 0.09534686614642851, 0.04160589713137597, 0.0324412156624021, 0.0523894253274193, 0.5037670524325222, 0.5827487830538303, 19.890384189784527, 83.66361424326897, 44.420433416962624, 61.63612022995949, 42.84955210983753, 32.03316271305084, 19.850070253014565, 66.64137125015259, 70.6182150542736, 57.0883646607399, 72.64612063765526, 58.660021126270294, 13.428281843662262, 0.10882703616516665, 1.635599434375763, 44.128115102648735, 87.85460695624352, 80.71064829826355, 81.94728434085846, 78.12075287103653, 85.35756334662437, 76.65648624300957, 72.86026954650879, 63.23210299015045, 61.49317570030689, 65.66148743033409, 71.9108372926712, 72.87680625915527, 77.65914604067802, 72.818433791399, 74.25534188747406, 67.46763691306114, 57.62850567698479, 57.93641075491905, 68.04078295826912, 69.36445713043213, 66.97777479887009, 69.95856285095215, 70.82328245043755, 68.41315537691116, 69.31668609380722, 66.1998425424099, 64.49130982160568, 62.400810196995735, 57.6629052311182, 50.72465993463993, 49.60319571197033, 50.46442709863186, 49.19288232922554, 49.42913465201855, 49.633316695690155, 50.17364390194416, 53.57625871896744, 60.35009823739529, 62.576558366417885, 70.50908491015434, 69.1102583706379, 59.35928240418434, 58.3471193164587, 62.50674471259117, 64.47178646922112, 62.26232662796974, 64.02486965060234, 62.0612870156765, 63.945742696523666, 64.097118973732, 60.83343230187893, 60.27057230472565, 58.07167209684849, 59.21314984560013, 56.94281347095966, 57.60207049548626, 57.400780096650124, 58.05659830570221, 53.108830600976944, 48.20023499429226, 47.04720586538315, 47.48538315296173, 46.7724996060133, 47.03736439347267, 49.02359381318092, 49.5589204877615, 54.369401559233665, 55.84545895457268, 58.49123798310757, 58.685859739780426, 55.77012799680233, 50.607261434197426, 50.42464703321457, 47.52143181860447, 52.5147894769907, 57.24123425781727, 61.063817739486694, 63.818844705820084, 67.78382554650307, 63.91621068120003, 65.84187895059586, 58.35796773433685, 56.83558702468872, 56.15863814949989, 64.16523411870003, 64.2039692401886, 68.16293120384216, 67.64286071062088, 68.39798659086227, 64.62405189871788, 66.9964849948883, 64.81384411454201, 63.788643926382065, 56.35138280689716, 61.91527225077152, 62.76935622096062, 74.63915169239044, 67.14823365211487, 75.01995205879211, 13.123236112296581, 0.6674345419742167, 0.8832491270732135, 5.228307601064444, 15.281864181160927, 51.94801948964596, 68.3028244972229, 66.95873782038689, 45.6118480861187, 16.35645031929016, 24.796403534710407, 42.184918373823166, 48.659869730472565, 30.797746405005455, 64.49035987257957, 10.429441910237074, 0.5376011494081467, 0.04617937847797293, 0.09851789247477427, 0.0328750009794021, 0.11854330776259303, 0.04090749906026758, 0.06592010220629163, 0.051420484742266126, 0.046646720002172515, 0.0642381729267072, 0.0446546509192558, 0.05873155219887849, 0.047282454834203236, 0.04512475323281251, 0.018378671229584143, 0.051212245525675826, 0.0012071683659087284, 0.06094935662986245, 0.04515926309977658, 0.03860112301481422, 0.19627546949777752, 0.07762490655295551, 0.10989799979142845, 0.14508574444334954, 0.21717118652304634, 0.23847791977459565, 0.13648965570610017, 0.07502957902033813, 0.11005297506926581, 0.19899542588973418, 0.16066060401499271, 0.15324138337746263, 0.09076520262169652, 0.14107559400144964, 0.207820660143625, 0.16092394769657403, 0.1936008286429569, 0.2789897279581055, 0.12170973277534358, 0.2241189355845563, 0.14318602450657636, 0.2734114491613582, 0.35950319201219827, 0.916768197203055, 1.0847324249334633, 31.246194541454315, 93.09319585561752, 57.58618354797363, 69.32731792330742, 89.92269918322563, 57.83774524927139, 10.819888059049845, 64.4741727411747, 72.58541509509087, 60.91167390346527, 79.60595637559891, 61.750965267419815, 14.608235377818346, 0.2887856913730502, 2.2073975019156933, 48.1332977861166, 91.37140184640884, 83.48983436822891, 85.31617596745491, 79.39710438251495, 88.73514890670776, 79.60876822471619, 76.76215097308159, 66.98643833398819, 64.06640142202377, 70.319102704525, 76.28636330366135, 76.38104662299156, 78.007100969553, 75.70291981101036, 78.0734834074974, 70.23243695497513, 59.19564798474312, 60.37454232573509, 68.8892014324665, 70.35487398505211, 67.92898535728455, 71.67040139436722, 73.05998682975769, 67.26544976234436, 71.5471588075161, 68.59595596790314, 68.6417131125927, 65.8432012796402, 59.68504272401333, 51.24136380851269, 53.19690227508545, 54.52274613082409, 51.64091616868973, 52.02604070305824, 50.80390848219395, 52.279148921370506, 58.39686244726181, 62.772749438881874, 67.34486550092697, 70.70741146802902, 69.80867609381676, 66.02764338254929, 61.636845991015434, 63.7337900698185, 67.83180177211761, 63.51608835160732, 65.37315130233765, 64.69926506280899, 64.19057115912437, 68.28150764107704, 63.11918064951897, 63.98146077990532, 61.87239155173302, 61.770868599414825, 59.595052152872086, 60.017156302928925, 59.10188801586628, 61.58040001988411, 56.504845172166824, 50.358769968152046, 51.76170028746128, 49.09684248268604, 48.256639167666435, 48.29454593360424, 50.39467804133892, 50.612645745277405, 57.31665261089802, 58.051749765872955, 62.03557379543781, 60.037789195775986, 58.99302765727043, 52.238768488168716, 52.11568929255009, 50.46743653714657, 57.23127119243145, 59.63564917445183, 63.298109248280525, 67.4798646569252, 67.78726816177368, 64.65204119682312, 69.55054074525833, 58.56802046298981, 58.61841715872288, 57.750650122761726, 68.21325570344925, 67.55910560488701, 71.19934067130089, 66.68438494205475, 72.2416627407074, 67.36011788249016, 68.67599487304688, 67.63732820749283, 67.28243485093117, 59.6091265976429, 63.879823833703995, 66.58062011003494, 77.50449433922768, 71.0574334859848, 78.06871846318245, 16.22716035693884, 0.732553310226649, 2.6632360043004155, 4.47317554615438, 15.134017914533615, 56.8317986279726, 76.41370967030525, 70.99928140640259, 48.5709773004055, 10.360864140093327, 40.86648412048817, 70.22425219416618, 56.672294586896896, 46.11575424671173, 74.52118322253227, 28.494716584682465, 0.8794625708833337, 0.16650390374707058, 0.18986668292200193, 0.16046317789005116, 0.34214495157357305, 0.22913610620889813, 0.1721319361240603, 0.19387095555430278, 0.11275585464318283, 0.11959013674641028, 0.12668975890846923, 0.26809627655893564, 0.1526340245618485, 0.18498312856536359, 0.10456380594405346, 0.15972091146977618, 0.14890198654029518, 0.1119154466141481, 0.14926237345207483, 0.13324934989213943], [0.04455964488442987, 0.022276095005508978, 0.06278567117988132, 0.11751858735806309, 0.029748592569376342, 0.04390341193357017, 0.040165651953429915, 0.05110067104396876, 0.043224884866504, 0.023308763811655808, 0.0699500902555883, 0.013742417177127209, 0.0555499094480183, 0.03648249548859894, 0.020131397686782293, 0.06086775007133838, 0.04392165021272376, 0.05691745383956004, 0.06370188959408551, 0.03187371759850066, 0.09107242949539796, 0.022283342077571433, 0.035479586804285645, 0.1187886692059692, 0.15293362957891077, 2.271068310365081, 68.0545762181282, 50.8177625387907, 48.394218385219574, 46.68302960693836, 77.83755406737328, 14.016690719872713, 21.35040644556284, 67.71412208676338, 49.81619708240032, 71.16842553019524, 54.677815809845924, 19.006407223641872, 0.5604289588518441, 0.4006897163344547, 1.8427594495005906, 66.45860865712166, 83.82106259465218, 81.65562719106674, 80.256207883358, 75.77792018651962, 74.64517816901207, 65.76237201690674, 60.00605329871178, 56.56360141932964, 64.99311089515686, 69.53400403261185, 76.70829266309738, 75.81904917955399, 71.75978779792786, 72.95667037367821, 66.04913502931595, 57.27363131940365, 57.08069667220116, 62.69634313881397, 68.63790571689606, 69.10270437598228, 64.1527707874775, 64.78715434670448, 69.61658120155334, 67.69715219736099, 66.5642049908638, 66.2936519086361, 63.1099471449852, 54.45504516363144, 47.15087950229645, 47.12556146085262, 47.9264634847641, 45.7963015884161, 45.99765658378601, 45.54011553525925, 46.24971225857735, 48.103279396891594, 52.1427970379591, 56.15745261311531, 59.37352403998375, 63.92514780163765, 66.92758709192276, 64.75317656993866, 57.71481804549694, 58.543982952833176, 60.94755157828331, 61.95637844502926, 63.37187469005585, 59.48709234595299, 62.41545461118221, 58.876313120126724, 58.42716962099075, 56.47316627204418, 57.158755883574486, 57.176162749528885, 55.728603824973106, 55.60220740735531, 57.04581454396248, 53.56530390679836, 45.40728226304054, 46.57962195575237, 45.68275988101959, 46.78041458129883, 47.623935118317604, 47.13290646672249, 50.090458765625954, 51.96713246405125, 54.51744541525841, 54.116099551320076, 54.30868461728096, 52.656525671482086, 47.85028137266636, 46.11605443060398, 47.32966750860214, 51.99711665511131, 57.11768388748169, 61.010214015841484, 62.05307945609093, 58.098768442869186, 59.13930840790272, 59.73289355635643, 55.75139120221138, 56.56751900911331, 55.70991262793541, 57.98020340502262, 64.31173145771027, 70.04110962152481, 65.1384074985981, 65.8961932361126, 64.687440097332, 61.21532320976257, 61.53412230312824, 58.460786417126656, 58.443831726908684, 62.19396449625492, 66.79574936628342, 73.25175493955612, 61.42287567257881, 74.99736607074738, 8.200206980109215, 0.24676377594005316, 0.5906482029240578, 2.802283368073404, 23.746238686144352, 56.26074627041817, 54.82321880757809, 49.92972359061241, 12.870097495615482, 19.498222433030605, 56.370385587215424, 40.3636609017849, 31.56720131635666, 38.884525671601295, 50.023187175393105, 1.0495979664847255, 0.30804813432041556, 0.07920784075395204, 0.07118524663383141, 0.05897147369978484, 0.051038237870670855, 0.030301546394184697, 0.03518712124787271, 0.053186176519375294, 0.02767060690530343, 0.03131442397716455, 0.06076648773159832, 0.0772659074573312, 0.01837569707276998, 0.03567835250578355, 0.07640918702236377, 0.030113131797406822, 0.06519693124573678, 0.021365236752899364, 0.015862775762798265, 0.005516853552762768, 0.03037431768461829, 0.03851343455608003, 0.07582191814435646, 0.040362540021305904, 0.09697346831671894, 0.012895637810288463, 0.04002764217148069, 0.05210689712839667, 0.03014046324096853, 0.04458318951947149, 0.023926067406137008, 0.03825426916591823, 0.040281133842654526, 0.04400428835651837, 0.031400323859998025, 0.09372016007546335, 0.020178947088425048, 0.04164362791925669, 0.041458692139713094, 0.04280626533727627, 0.04968859037035145, 0.07655264416825958, 0.029588121687993407, 0.21916493657045066, 0.08660674138809554, 2.0432106871157885, 77.86648571491241, 55.150746032595634, 51.53006851673126, 60.126164853572845, 42.46114455163479, 18.90866506844759, 40.22966109216213, 72.18821480870247, 51.48484714329243, 77.416453063488, 62.30554170906544, 21.64661195129156, 0.3946275869384408, 0.6178587803151459, 2.235508393496275, 70.60936912894249, 79.99318599700928, 82.33424797654152, 83.64801228046417, 79.25740107893944, 77.25164830684662, 67.3581799864769, 63.48903760313988, 60.00613309442997, 65.90358763933182, 73.41538175940514, 75.82680076360703, 76.5847384929657, 73.91325384378433, 75.06179541349411, 69.87417697906494, 59.61429812014103, 60.85980288684368, 64.7614449262619, 71.05969056487083, 71.52267292141914, 66.14918366074562, 68.79474610090256, 72.45584964752197, 70.22044479846954, 67.50563487410545, 68.02880600094795, 65.41474387049675, 58.63056130707264, 49.87732820212841, 49.757235646247864, 51.41756795346737, 49.213690012693405, 48.02645891904831, 49.41574037075043, 50.458548814058304, 52.34062202274799, 56.15071937441826, 60.03183491528034, 62.012577429413795, 66.37467116117477, 72.33734920620918, 66.7633219063282, 62.2796954959631, 63.498776480555534, 66.865886002779, 65.72547599673271, 65.38832008838654, 63.11280459165573, 65.0775195658207, 62.974302023649216, 64.36680570244789, 60.06448656320572, 59.68112513422966, 59.863180965185165, 58.4507055580616, 59.80385474860668, 58.77640128135681, 56.07908561825752, 47.86178715527058, 48.56957897543907, 47.81425930559635, 48.679807260632515, 48.76078851521015, 48.377119302749634, 50.32397523522377, 54.59819108247757, 56.29183240234852, 58.11576493084431, 55.535292997956276, 53.21542628109455, 51.09446369111538, 48.39519493281841, 49.47966434061527, 56.00178636610508, 59.432679265737534, 64.23989251255989, 64.31410253047943, 62.92098708450794, 62.83141449093819, 65.05372524261475, 60.36726951599121, 59.30960386991501, 56.95384427905083, 62.2610916942358, 67.61293351650238, 71.14624232053757, 68.83222728967667, 67.4670821428299, 66.97629287838936, 65.60797870159149, 64.67211171984673, 62.77838833630085, 59.91235412657261, 65.55706903338432, 68.62307891249657, 76.32529601454735, 66.90782055258751, 78.14713105559349, 9.016555175185204, 0.3796678490471095, 2.226034076884389, 3.03945476654917, 24.82177097350359, 63.26698511838913, 61.21368929743767, 55.542041435837746, 21.515467688441277, 23.933268450200558, 33.72103214263916, 46.55038632452488, 36.09426699578762, 42.89484187960625, 61.031223088502884, 1.907504650298506, 0.2660137804923579, 0.020646179145842325, 0.12868386518675834, 0.017114721376856323, 0.06827028351835907, 0.02346064804441994, 0.04287625357392244, 0.0630069944600109, 0.04546100921288598, 0.0786229022196494, 0.060500535400933586, 0.04194085435301531, 0.06505012701381929, 0.007036357783363201, 0.05211648567637894, 0.04537017775874119, 0.05557006246817764, 0.0668159635097254, 0.013257422742753988, 0.050036850589094684, 0.12492809328250587, 0.190728880406823, 0.16624798154225573, 0.1610549070755951, 0.19921625935239717, 0.17243027949007228, 0.08613411948317662, 0.13611775066237897, 0.13033400085987523, 0.12389096416882239, 0.1103808188054245, 0.08990202550194226, 0.1087384311540518, 0.09437942469958216, 0.11065318700275384, 0.18375266256043687, 0.1585777517175302, 0.059979224897688255, 0.14640706416685134, 0.22149005555547774, 0.15299145772587508, 0.16612318198895082, 0.12022691429592669, 0.3544282674556598, 0.20535132702207193, 4.214249840006232, 95.2323366701603, 68.86088535189629, 59.7448705136776, 79.42721396684647, 107.44567930698395, 15.937110520899296, 31.876968294382095, 74.94777873158455, 58.224830478429794, 86.43200889229774, 65.05570113658905, 24.24429126083851, 1.1285308934748173, 0.8821629197336733, 2.7999892411753535, 70.8068597316742, 82.29355975985527, 83.97536471486092, 87.72104412317276, 81.10426917672157, 82.68379881978035, 69.92522343993187, 67.2406142950058, 64.27932679653168, 70.23843303322792, 75.58870553970337, 80.41840597987175, 81.80322647094727, 75.83026617765427, 79.6113520860672, 71.95215627551079, 61.94874465465546, 64.09955844283104, 68.76530528068542, 73.62627044320107, 74.82718840241432, 65.94404026865959, 68.38862389326096, 76.17874547839165, 72.68194511532784, 70.44924572110176, 70.34545049071312, 67.93001890182495, 60.66905312240124, 51.30729027092457, 50.53876630961895, 55.00454127788544, 52.21859157085419, 50.470202788710594, 51.40869922935963, 53.71381513774395, 56.19893118739128, 59.244627356529236, 61.49067923426628, 65.00175163149834, 66.42505645751953, 71.49251773953438, 71.29112854599953, 64.64911535382271, 66.20023012161255, 67.87944361567497, 67.44634285569191, 68.19720536470413, 64.34422731399536, 66.78300485014915, 65.91109603643417, 65.39790317416191, 62.10439570248127, 62.614400535821915, 64.57891032099724, 60.93919202685356, 61.804500594735146, 61.377901285886765, 58.32704499363899, 48.504100888967514, 52.14452974498272, 48.82109507918358, 53.637355640530586, 50.8139019459486, 49.93111811578274, 53.22396822273731, 56.6709266602993, 56.80257059633732, 60.155123099684715, 56.771663054823875, 58.090671077370644, 53.5490407794714, 50.335462018847466, 50.916165858507156, 59.35719631612301, 62.982122004032135, 66.38710409402847, 67.26069241762161, 63.27662140130997, 64.18640658259392, 64.58318889141083, 62.185882329940796, 61.527624651789665, 59.07297536730766, 64.63593006134033, 69.77780655026436, 74.76583689451218, 71.66097030043602, 70.01942798495293, 68.14980670809746, 68.76081392168999, 66.49451673030853, 64.68382269144058, 64.66524928808212, 68.64726841449738, 71.74494579434395, 79.72485199570656, 67.98440158367157, 80.09844034910202, 9.739049356430769, 0.24429726297967136, 3.1316007720306516, 5.9878393448889256, 28.61726190894842, 67.25696101784706, 65.00660017132759, 61.157296523451805, 20.082982555031776, 23.985796831548214, 78.82134407758713, 55.038249269127846, 47.91502229869366, 50.02578243613243, 76.41586795449257, 5.634084502235055, 0.6362518121022731, 0.12413821808877401, 0.29621209600009024, 0.17141859862022102, 0.19294609111966565, 0.18455639365129173, 0.09066256359801628, 0.16279365518130362, 0.08783895144006237, 0.09864059175015427, 0.2546724578132853, 0.18628392048412934, 0.1618011959362775, 0.08080945481196977, 0.22846170177217573, 0.21205735858529806, 0.1305522961774841, 0.09973384949262254, 0.06778524548280984, 0.18584945239126682], [0.008188202518795151, 0.06434341688873246, 0.06256546112126671, 0.030020699159649666, 0.08588680619141087, 0.01794736283045495, 0.09116126457229257, 0.0002179794844892058, 0.10064216403407045, 0.053147903963690624, 0.021477299196703825, 0.027655442972900346, 0.13271929317852482, 0.040819780915626325, 0.049389460327802226, 0.012551117088150932, 0.04027715222036932, 0.08161648103850894, 0.0397702468035277, 0.06225306147825904, 0.04897472223092336, 0.026406671895529144, 0.093226164317457, 0.024538515499443747, 0.6290622416418046, 0.6916815752629191, 24.536905959248543, 74.92909133434296, 43.496509194374084, 48.7524289637804, 52.85955257713795, 56.256988272070885, 8.850102256983519, 55.0003957003355, 71.15869805216789, 64.17579755187035, 58.77672806382179, 25.72242334485054, 0.3681045351549983, 0.25315565639175475, 0.5962276691570878, 15.754910297691822, 94.44846153259277, 79.12329867482185, 80.72213128209114, 79.04253020882607, 70.88453516364098, 62.70796291530132, 59.77610103785992, 60.032325088977814, 66.66726306080818, 71.50935843586922, 76.0248613357544, 80.15950307250023, 74.316176623106, 74.90693852305412, 68.21878060698509, 59.02077376842499, 55.92795252799988, 66.81053817272186, 68.65517199039459, 69.03541758656502, 61.76797315478325, 65.84467560052872, 69.68112453818321, 68.15580278635025, 68.8107280433178, 66.87638103961945, 62.839413061738014, 49.418267235159874, 46.511263623833656, 46.50441639125347, 48.22833068668842, 48.38587403297424, 47.586480528116226, 45.26531808078289, 46.17285758256912, 47.54017621278763, 51.18812866508961, 51.271382197737694, 55.07769875228405, 56.224454417824745, 58.214943408966064, 62.66070105135441, 62.22480744123459, 57.61080242693424, 59.64730314910412, 62.82038748264313, 63.282948061823845, 61.02043926715851, 61.06211543083191, 61.73432596027851, 61.089922338724136, 56.64840146899223, 55.06025388836861, 58.44926543533802, 57.85845033824444, 58.23934569954872, 57.31429673731327, 54.772803112864494, 46.54445864260197, 45.82888104021549, 45.229288414120674, 46.35346569120884, 45.494939759373665, 47.85576067864895, 50.34709319472313, 55.533757880330086, 55.619534477591515, 53.37857432663441, 53.45117323100567, 50.2827550470829, 46.30493849515915, 47.48221792280674, 47.620222717523575, 49.84429657459259, 55.63125304877758, 60.72266824543476, 61.599459797143936, 58.37333790957928, 49.855217188596725, 53.796270713210106, 55.99103294312954, 55.76918564736843, 54.68758508563042, 60.52304595708847, 65.57904705405235, 69.09587994217873, 69.03075903654099, 67.11980357766151, 63.95721808075905, 62.08844415843487, 61.57698780298233, 63.17564941942692, 61.46702170372009, 67.47161909937859, 65.1871208846569, 74.35892432928085, 67.18380734324455, 62.246371284127235, 7.509367475286126, 0.12683936103712767, 0.8469876134768128, 4.523707609623671, 22.816852256655693, 45.92447251081467, 56.62508971989155, 33.535932675004005, 10.944858603179455, 40.02156525850296, 45.972938910126686, 38.1303421407938, 32.335740476846695, 49.99792993068695, 36.50271087884903, 0.37331037456169724, 0.28944231395144016, 0.012235596714162966, 0.07219970313599333, 0.016373460566683207, 0.04734715897939168, 0.1620418595848605, 0.09670095168985426, 0.0658317792112939, 0.06862583162728697, 0.0381196027592523, 0.012597946606547339, 0.046753203350817785, 0.008793324686848791, 0.03274618269642815, 0.02084626587020466, 0.018616499874042347, 0.03887012928316835, 0.029912135942140594, 0.08782551856711507, 0.015733397158328444, 0.0407990490202792, 0.025956288445740938, 0.02873839228413999, 0.023158681142376736, 0.048525277597946115, 0.016498759214300662, 0.07179941836511716, 0.04957641845976468, 0.04738625902973581, 0.0571514418697916, 0.05431043005955871, 0.026261092207278125, 0.14545616519171745, 0.07450706994859502, 0.03846878695185296, 0.058860259159700945, 0.02798393052216852, 0.12777032592566684, 0.004446017483132891, 0.04314794270612765, 0.039451906268368475, 0.03521708174957894, 0.08416170618147589, 0.01864492969616549, 0.43569661444053054, 0.6683848472312093, 28.792749792337418, 86.80245101451874, 40.74092745780945, 60.395106822252274, 49.707002341747284, 39.57370989024639, 21.64550621062517, 64.94651779532433, 72.70865768194199, 72.0579046010971, 62.976984679698944, 29.514150582253933, 0.9139576542656869, 1.2401508539915085, 0.6860873848199844, 16.404823623597622, 95.95876649022102, 82.50437244772911, 81.63979724049568, 81.7621810734272, 72.56693288683891, 66.01072669029236, 61.50691956281662, 62.70035572350025, 70.12923449277878, 72.62093558907509, 76.8301597237587, 80.5979235470295, 78.28187942504883, 76.8218457698822, 70.14186501502991, 59.89496625959873, 57.36575357615948, 67.6220454275608, 73.2407659292221, 73.05920407176018, 63.29718589782715, 65.07762596011162, 72.61218085885048, 71.48354262113571, 70.95122918486595, 67.70406782627106, 65.09980916976929, 52.62569032609463, 51.988947093486786, 49.232958778738976, 49.81782339513302, 51.16092212498188, 48.53049427270889, 49.76964198052883, 49.920824468135834, 51.06535345315933, 55.16662158071995, 54.79815915226936, 60.097943767905235, 58.764260932803154, 62.66518481075764, 66.38255193829536, 66.32783487439156, 61.566599160432816, 61.664595901966095, 66.3116705417633, 64.28465411067009, 64.18807089328766, 62.12908677756786, 64.33897599577904, 62.366304248571396, 59.55926947295666, 57.69997984170914, 61.824916899204254, 60.362907350063324, 61.44227363169193, 58.93222711980343, 58.278700187802315, 49.53811280429363, 48.61532472074032, 47.23639391362667, 49.112262055277824, 46.76803484559059, 51.09444089233875, 53.98532576858997, 55.94658672809601, 57.74060346186161, 56.37177251279354, 55.0947218388319, 54.35647465288639, 48.736576214432716, 50.40077291429043, 49.87266965210438, 51.39160014688969, 56.57167598605156, 63.30784432590008, 64.96275052428246, 63.743760734796524, 57.99286812543869, 60.75172148644924, 60.99272735416889, 58.661848828196526, 57.89878137409687, 63.56132872402668, 67.68119305372238, 72.31058344244957, 70.90107187628746, 69.05138432979584, 66.28672868013382, 64.7791975736618, 64.75357174873352, 67.22409278154373, 64.17081981897354, 69.93599206209183, 70.46927064657211, 76.20633959770203, 69.5816458761692, 63.718096911907196, 9.939378406852484, 0.459098193095997, 2.6490304665639997, 4.607024788856506, 26.495670452713966, 54.90234576165676, 66.14257201552391, 38.36995728313923, 20.597911924123764, 30.809957049787045, 34.08151499927044, 45.89904807507992, 30.651556849479675, 57.2887659072876, 41.18078425526619, 0.5990081699565053, 0.18874557979870588, 0.0305338645921438, 0.02747123820881825, 0.061956473291502334, 0.0227459950838238, 0.045945609381305985, 0.021161786244192626, 0.10473564281710424, 0.015744349402666558, 0.045069158950354904, 0.04027656221296638, 0.06965078209759668, 0.07534398988354951, 0.0341971853049472, 0.037125907838344574, 0.03704888033098541, 0.02192881627706811, 0.01878418814158067, 0.05408374476246536, 0.0675784311897587, 0.23893757635960355, 0.1894189600716345, 0.15553795936284587, 0.15614286909112707, 0.16068951808847487, 0.08346958667971194, 0.23213870212202892, 0.19944896717788652, 0.17405871476512402, 0.12954128324054182, 0.13481317379046232, 0.14778367389226332, 0.2144086902262643, 0.241097908874508, 0.12203729449538514, 0.12280028910026886, 0.1729617759701796, 0.2407219517044723, 0.08312390171340667, 0.2015552861848846, 0.2366158860968426, 0.2492698305286467, 0.11607833846937865, 0.09267687113606371, 0.5691509158350527, 1.2216528528369963, 41.34519763290882, 101.05788767337799, 55.046171844005585, 68.30597832798958, 90.67547678947449, 69.974894374609, 14.191138409078121, 63.73711869120598, 79.73045289516449, 77.86979153752327, 71.30717888474464, 32.94344186782837, 1.0764565877616405, 0.4443000059109181, 0.8130774018354714, 17.688789926469326, 98.78944739699364, 84.93292853236198, 86.76353350281715, 87.09717079997063, 77.3902040719986, 70.36871284246445, 65.17949089407921, 64.7129899263382, 73.78986686468124, 75.74714943766594, 78.70171889662743, 83.54928597807884, 82.10939884185791, 78.98148268461227, 73.94774079322815, 63.51207576692104, 59.140136763453484, 70.94162330031395, 76.53581991791725, 75.01983046531677, 65.72562038898468, 69.0132799744606, 73.27462211251259, 71.78579360246658, 72.14421316981316, 72.49458476901054, 67.32462778687477, 54.84099805355072, 51.86620607972145, 50.14570400118828, 53.79178315401077, 55.336407870054245, 53.15165430307388, 51.7012645304203, 52.988350465893745, 54.050541669130325, 58.317803889513016, 56.769991144537926, 61.90973214805126, 61.746318116784096, 64.00910049676895, 66.86128064990044, 66.22895658016205, 63.99600639939308, 62.927678525447845, 68.98072332143784, 68.57485949993134, 65.18820762634277, 64.7010737657547, 66.5546827018261, 65.76896086335182, 61.43129602074623, 58.526959866285324, 62.375967130064964, 63.24504889547825, 64.48619529604912, 60.81429272890091, 58.71916115283966, 52.74242766201496, 51.89369760453701, 49.201135486364365, 52.23675839602947, 49.1951660066843, 53.55792090296745, 56.57319210469723, 59.90253925323486, 60.51454581320286, 57.693983763456345, 56.176398396492004, 56.37400679290295, 50.93195401132107, 52.31162577867508, 51.353970766067505, 55.36248967051506, 59.58307519555092, 65.79022452235222, 67.85096034407616, 65.90538874268532, 60.447528809309006, 64.46754589676857, 63.7196434289217, 61.70758679509163, 60.74898563325405, 67.45226293802261, 71.0766452550888, 73.71748834848404, 72.41348952054977, 72.63650715351105, 67.93449506163597, 68.294168561697, 66.42012432217598, 69.2534650862217, 68.06738153100014, 72.69904419779778, 72.1641393005848, 79.34420362114906, 71.48035079240799, 66.78017020225525, 10.52935279905796, 0.40158379648346454, 4.172639222815633, 12.413598541170359, 29.138457141816616, 58.33071559667587, 66.54348090291023, 42.728756591677666, 15.571829471737146, 50.69682262837887, 67.96031087636948, 56.68418034911156, 44.305622577667236, 64.94302958250046, 58.85792590677738, 1.1567031755112112, 0.4162318620365113, 0.09835260134423152, 0.1287230060552247, 0.12093982877559029, 0.1436392540927045, 0.2901725872652605, 0.19083751598373055, 0.16744050895795226, 0.15524568676482886, 0.1638780813664198, 0.1493662444408983, 0.15240691252984107, 0.12633694190299138, 0.08625329355709255, 0.11234977369895205, 0.1001631967665162, 0.12312930542975664, 0.08593235921580344, 0.1880233216797933, 0.15364864433649927], [0.10718392120907083, 0.051733140426222235, 0.01105587598431157, 0.0764278817223385, 0.10164202991290949, 0.04844137038162444, 0.04742366698337719, 0.07298978613107465, 0.010510407646506792, 0.09067268649232574, 0.01631403309147572, 0.03094170071562985, 0.02033862387179397, 0.038830814009997994, 0.020534819886961486, 0.004040897620143369, 0.05423254166089464, 0.05089610545837786, 0.024804592139844317, 0.027053561207139865, 0.015526168190262979, 0.0189594444600516, 0.026801407257153187, 0.01960597754077753, 0.21964133600704372, 0.12629653938347474, 1.7144548217765987, 58.18382307887077, 53.96242059767246, 56.31127215921879, 53.03692325949669, 67.15365216135979, 19.09161575138569, 20.81053901463747, 81.07249528169632, 58.308190405368805, 57.340652123093605, 25.283833779394627, 2.3492096923291683, 1.5384887577965856, 0.18714212521445006, 1.1858997400850058, 75.78102841973305, 83.78997266292572, 84.68929320573807, 71.61620110273361, 67.70366504788399, 62.11084395647049, 65.95217943191528, 65.3337550163269, 72.83180147409439, 76.07444867491722, 77.73267209529877, 80.1448206603527, 75.8254100382328, 74.70076158642769, 70.28910711407661, 58.52005183696747, 56.62485033273697, 68.06599080562592, 70.24142727255821, 67.31457352638245, 61.97799168527126, 66.23052209615707, 69.55575406551361, 67.36206337809563, 65.0924451649189, 61.910070329904556, 53.15413936972618, 47.68800728023052, 50.94311781227589, 47.935001626610756, 47.33490742743015, 45.42583666741848, 46.08901508152485, 46.17813929915428, 46.93843670189381, 48.30555394291878, 49.453692734241486, 50.964339673519135, 50.817618146538734, 54.11578796803951, 57.70221032202244, 53.865411803126335, 57.571368142962456, 56.21281184256077, 56.41165517270565, 59.503572061657906, 62.424099147319794, 61.88566043972969, 63.03368903696537, 61.39337405562401, 61.21549800038338, 58.13556186854839, 57.85855293273926, 59.504077434539795, 57.8944344073534, 58.64104874432087, 60.69898031651974, 58.725939989089966, 47.498085871338844, 47.21720114350319, 46.08949385583401, 47.6174146682024, 47.16919831931591, 49.693942442536354, 52.309513092041016, 53.672059178352356, 54.38518591225147, 52.994069159030914, 50.18991842865944, 48.5152380913496, 47.95048199594021, 46.574891209602356, 47.10405841469765, 49.5013003796339, 51.08875259757042, 57.095101699233055, 63.34348261356354, 57.73488476872444, 39.75522994995117, 29.996095821261406, 52.7464934438467, 57.48819820582867, 54.79847073554993, 58.72225418686867, 65.88566780090332, 69.28352147340775, 70.30623659491539, 68.5386398434639, 66.17247641086578, 56.683595180511475, 64.00032296776772, 62.300738766789436, 66.99645459651947, 67.1352307498455, 74.83962133526802, 67.79330983757973, 72.87132695317268, 30.706980675458908, 0.3035678481683135, 0.12197382602607831, 1.5868320199660957, 2.648499207571149, 28.125716485083103, 53.79865698516369, 55.78365907073021, 18.239435479044914, 18.40112440288067, 51.17973491549492, 36.320613250136375, 81.79472252726555, 60.20137041807175, 51.83382801711559, 14.058116097003222, 1.2816119729541242, 0.04461221120436676, 0.19620725128334016, 0.050365599745418876, 0.06663853084319271, 0.025899723805196118, 0.07674094929825515, 0.036769161160918884, 0.1510553725529462, 0.08400589969824068, 0.11200684210052714, 0.03162294960930012, 0.03842672573227901, 0.04575019076582976, 0.06426416293834336, 0.03231700982723851, 0.025908061834343243, 0.03250291782023851, 0.027549557053134777, 0.025647128277341835, 0.007591365038024378, 0.032171196362469345, 0.030379958006960806, 0.029557385641965084, 0.014534836082020774, 0.029721778773819096, 0.07968130128574558, 0.017291322837991174, 0.019659451136249118, 0.048539300478296354, 0.06178294061101042, 0.037597917471430264, 0.023553718929179013, 0.024421035377599765, 0.017330270748061594, 0.07799039201927371, 0.05944018077570945, 0.056319768918910995, 0.043188374911551364, 0.033648263197392225, 0.01527616368548479, 0.030180372232280206, 0.022396586391550954, 0.0613416558917379, 0.028537353755382355, 0.23180792690254748, 0.14104026777204126, 1.8752060271799564, 71.24175399541855, 56.12326204776764, 58.1398556381464, 67.2824652493, 39.221263602375984, 24.34059899300337, 40.19676245748997, 80.0567489862442, 65.15706449747086, 66.1604006588459, 31.2076798081398, 2.456727297976613, 3.635177300311625, 0.4920894477982074, 1.2318046018481255, 75.37693530321121, 89.18015822768211, 86.36365056037903, 73.82544055581093, 70.93824908137321, 65.8547754585743, 67.64676690101624, 66.89784988760948, 73.97500813007355, 78.08425202965736, 80.88119834661484, 79.52076494693756, 78.72327893972397, 76.4701746404171, 72.74898871779442, 60.56753396987915, 61.593988090753555, 69.91788223385811, 74.03921708464622, 68.59473243355751, 68.04497793316841, 69.95336472988129, 71.62807926535606, 68.56735110282898, 69.46700602769852, 66.69851258397102, 58.12789388000965, 52.423115596175194, 53.63515555858612, 50.282192677259445, 51.70771278440952, 49.29313234984875, 47.18271039426327, 48.988772481679916, 50.69005899131298, 51.63243502378464, 52.53240533173084, 54.01412442326546, 55.14652065932751, 57.87917822599411, 61.54204487800598, 58.142705485224724, 62.25367449223995, 61.32721200585365, 59.67175103724003, 63.10100242495537, 65.83004638552666, 64.22004237771034, 64.73756700754166, 64.75772112607956, 64.93065744638443, 61.344603672623634, 61.708475947380066, 62.49955169856548, 60.92589654028416, 63.13734367489815, 64.78619679808617, 61.509796008467674, 49.529050290584564, 48.240269646048546, 47.2870109975338, 50.15374056994915, 49.85412284731865, 51.03555545210838, 53.93496707081795, 55.64058914780617, 56.17246560752392, 55.908030197024345, 53.72230768203735, 50.84996581077576, 49.72257770597935, 50.481085404753685, 49.1310178488493, 52.36163109540939, 55.267506167292595, 59.88184176385403, 64.56200122833252, 63.13025325536728, 46.50256209075451, 37.41679362952709, 60.23060604929924, 59.485401436686516, 58.5049020498991, 62.51307897269726, 68.68282690644264, 70.65839409828186, 72.0596981048584, 69.42599102854729, 71.44372835755348, 60.69801136851311, 68.35426613688469, 65.70824012160301, 70.48877879977226, 70.18028855323792, 77.67028704285622, 71.72546803951263, 73.83915781974792, 31.70752588659525, 0.49850926268845797, 0.23556270432891324, 3.4143497748300433, 4.086675485596061, 29.088343530893326, 60.44197350740433, 58.87456901371479, 23.23089323937893, 24.17244091629982, 34.656701534986496, 41.020501255989075, 86.1018294095993, 57.215437442064285, 62.84756742417812, 15.36987790837884, 1.0822207597084343, 0.020986208946851548, 0.09293281560530886, 0.021932476920483168, 0.051420792733551934, 0.021509669822989963, 0.056470064955647103, 0.07512487078201957, 0.13054719020146877, 0.07451155994203873, 0.06800570045015775, 0.03485803441435564, 0.020286680955905467, 0.016929880221141502, 0.029142745879653376, 0.046712006733287126, 0.051434277556836605, 0.01753728913172381, 0.029747933913313318, 0.074265834846301, 0.08483070036163554, 0.15479296183912084, 0.18599417118821293, 0.09276766548282467, 0.15862207277677953, 0.16359219123842195, 0.2919750561704859, 0.11906796164112166, 0.09259026250219904, 0.1589125642203726, 0.20942565839504823, 0.1275052159326151, 0.09883504186291248, 0.13886356347939, 0.15753742394736037, 0.16721805761335418, 0.1916239847196266, 0.16483760409755632, 0.17117232433520257, 0.09699448593892157, 0.11308167231618427, 0.2680202212650329, 0.10823044591234066, 0.12768802174832672, 0.16336154658347368, 0.5102216592058539, 0.21767802885733545, 4.73077654838562, 86.97511374950409, 69.98576939105988, 69.88917097449303, 81.50962382555008, 95.32671600580215, 24.233233854174614, 32.53414683043957, 85.54704397916794, 71.9057759642601, 72.79305875301361, 34.21989597380161, 2.5827615475282073, 3.819124004803598, 0.2271634034696035, 1.7129588895477355, 77.51084759831429, 91.62409588694572, 90.17544642090797, 74.71672832965851, 75.85237339138985, 69.32743951678276, 73.56768518686295, 70.54538816213608, 78.66223901510239, 81.76455214619637, 84.70030501484871, 82.18617752194405, 81.02678373456001, 77.96401888132095, 75.26949986815453, 62.82857604324818, 64.10841956734657, 72.99046576023102, 77.07341507077217, 72.09807604551315, 67.74268135428429, 71.25901266932487, 74.52359229326248, 73.36324095726013, 71.09374433755875, 67.74467244744301, 59.18600030243397, 53.392139598727226, 56.90928786993027, 53.24631482362747, 53.59726019203663, 50.866977497935295, 51.4879135787487, 52.46266767382622, 53.99010591208935, 55.36916971206665, 56.49584725499153, 55.94468303024769, 57.685734406113625, 59.551111310720444, 63.68821531534195, 60.50546050071716, 65.77701643109322, 61.855178475379944, 61.47386133670807, 64.00276243686676, 67.33009189367294, 65.05247890949249, 66.24806195497513, 64.57576408982277, 67.39578276872635, 63.175106048583984, 63.072701543569565, 64.46625396609306, 63.14996659755707, 64.72959503531456, 67.91886270046234, 63.21188807487488, 51.90939836204052, 51.19898468255997, 50.92061161994934, 51.8284323066473, 51.667788326740265, 52.96329081058502, 56.78992487490177, 58.63127946853638, 58.35692659020424, 59.15888875722885, 55.27080439031124, 54.87007789313793, 52.38465406000614, 51.78155042231083, 50.55056847631931, 57.28421375155449, 55.7311724871397, 61.821402087807655, 67.63024538755417, 68.13643142580986, 51.313316747546196, 46.791798770427704, 62.191969603300095, 61.079613491892815, 62.219856306910515, 63.933469355106354, 72.3347881436348, 73.88692125678062, 74.29598450660706, 72.25674793124199, 72.21556574106216, 65.27700886130333, 71.5228021144867, 67.59503647685051, 72.74709641933441, 73.34541991353035, 79.2981804907322, 72.72465482354164, 75.16279399394989, 35.9051663428545, 0.6596584967337549, 0.7694543770048767, 6.674236888065934, 6.996489046141505, 33.80549021065235, 64.52378287911415, 65.53708210587502, 22.839157059788704, 24.07364621758461, 68.05855840444565, 58.98062892258167, 93.81651744246483, 65.14397040009499, 75.5829830467701, 28.593254797160625, 1.2093767803162336, 0.2053239566157572, 0.24807394860545173, 0.11056745410314761, 0.1257310970686376, 0.10393393778940663, 0.19308888033265248, 0.12251394626218826, 0.2811855945037678, 0.1938254470587708, 0.21618047874653712, 0.16445778775960207, 0.12379587278701365, 0.13367840030696243, 0.09100743220187724, 0.10688424197724089, 0.08720077865291387, 0.1289489900227636, 0.10402316620456986, 0.16460529703181237, 0.17768274061381817], [0.014470499299932271, 0.0098187389994564, 0.006869772068966995, 0.057653181938803755, 0.026563066530798096, 0.009766394396137912, 0.02362893745157635, 0.021669220441253856, 0.10956114638247527, 0.04870283642958384, 0.025789208739297464, 0.026695751403167378, 0.0698730701697059, 0.03561322533641942, 0.034596193581819534, 0.0295967769852723, 0.0012858057539233414, 0.02564652713772375, 0.022675149666611105, 0.006956952156542684, 0.04675306234275922, 0.041175013611791655, 0.07736181520158425, 0.11562565807253122, 0.05607840765151195, 0.4805644287262112, 0.6338221987243742, 25.912928022444248, 66.99070170521736, 46.20760291814804, 61.631134897470474, 71.89640566706657, 59.90287363529205, 9.668335150927305, 59.998890683054924, 78.70523750782013, 68.33297967910767, 44.15855146944523, 5.695303017273545, 6.2791388388723135, 1.52550924802199, 1.1159971472807229, 68.40082123875618, 91.8084467947483, 81.78369551897049, 78.06563302874565, 70.93608319759369, 70.35585433244705, 70.31987026333809, 77.07843840122223, 76.753069460392, 81.89649626612663, 80.00279948115349, 77.85805016756058, 77.21692577004433, 77.5457601249218, 68.73237624764442, 57.42297850549221, 61.54649443924427, 72.33735680580139, 70.04430904984474, 63.38056482374668, 61.985032707452774, 69.65672224760056, 70.18273562192917, 66.30829632282257, 59.62978608906269, 54.53106768429279, 50.42286112904549, 51.68090142309666, 49.48950581252575, 49.01555344462395, 42.84182332456112, 41.67529731988907, 47.42282330989838, 44.734748750925064, 48.12218718230724, 48.41139726340771, 48.32803353667259, 49.956857934594154, 50.551890805363655, 50.9822329133749, 53.310481980443, 56.24627664685249, 55.12350909411907, 54.18604999780655, 58.89246225357056, 59.49591547250748, 62.683997601270676, 57.15788573026657, 59.58325378596783, 64.00742098689079, 63.08875948190689, 58.47127765417099, 56.20012812316418, 64.08093944191933, 57.848278284072876, 60.985416546463966, 63.23704272508621, 58.03454048931599, 46.35563537478447, 44.14364106953144, 44.851869866251945, 46.03445000946522, 46.24784275889397, 48.59913758933544, 50.24058870971203, 51.31235919892788, 50.34325920045376, 52.123319283127785, 48.82988780736923, 47.56100669503212, 47.43375912308693, 46.69769302010536, 49.119835048913956, 48.85556682944298, 50.143849700689316, 53.01748350262642, 57.419782876968384, 61.742921099066734, 50.502121075987816, 33.370801135897636, 43.60522896051407, 58.88287536799908, 58.10053534805775, 58.87360766530037, 68.78241196274757, 68.83408159017563, 71.00985243916512, 69.98274475336075, 68.38569045066833, 52.80603624880314, 59.62179131805897, 66.1494192481041, 69.27287444472313, 74.1759717464447, 72.86584004759789, 68.16254362463951, 62.46720403432846, 5.372671829536557, 0.044895900864503346, 3.1643709260970354, 0.7163160690106452, 2.864127899520099, 30.233106203377247, 72.46837377548218, 50.49452528357506, 30.51905795931816, 49.32358771562576, 50.86271792650223, 29.39018413424492, 42.400788590312004, 52.363895773887634, 43.296183943748474, 2.255553505383432, 0.33834129630122334, 0.13242897985037416, 0.15465321543160826, 0.03521518185152672, 0.11745570518542081, 0.04474796114664059, 0.17698623501928523, 0.04459523828700185, 0.05160573222383391, 0.026268836518283933, 0.02187777321523754, 0.052956055078539066, 0.07780958258081228, 0.03207475056115072, 0.04866674578806851, 0.03631401683378499, 0.06467512721428648, 0.04502521267568227, 0.021937106066616252, 0.02517825607355917, 0.028316160351096187, 0.03795138014538679, 0.10314723898773082, 0.02676591775525594, 0.022629730228800327, 0.0063958987175283255, 0.025813560459937435, 0.016737869918870274, 0.03819199926510919, 0.062039950062171556, 0.021634393306158017, 0.040472823166055605, 0.027665714296745136, 0.03168058108713012, 0.03015255839272868, 0.038649039779556915, 0.09454656377783976, 0.056302027878700756, 0.028073685862182174, 0.035821022975142114, 0.00837737317851861, 0.010887922398978844, 0.028152848899480887, 0.08245627308497205, 0.015520049182669027, 0.06884497299324721, 0.3488893521716818, 0.583746051415801, 33.9606586843729, 80.30790030956268, 45.441191643476486, 68.35868149995804, 60.012851133942604, 30.88165160268545, 20.5484214797616, 76.62527471780777, 80.33702954649925, 70.24775013327599, 49.3660694360733, 5.616026446223259, 6.795186772942543, 2.4299396853893995, 1.3268152973614633, 72.67999202013016, 93.25834259390831, 83.39205041527748, 81.29048958420753, 71.81322053074837, 74.44243624806404, 72.91896119713783, 76.04133725166321, 79.8241026699543, 85.6340517103672, 80.78384757041931, 79.62035000324249, 79.83378455042839, 79.09037724137306, 71.29679784178734, 62.23737716674805, 61.51185169816017, 72.75448322296143, 73.00482138991356, 69.64233621954918, 66.38091042637825, 70.68024292588234, 71.91773772239685, 67.78024613857269, 62.59510897099972, 59.32035729289055, 52.25047565996647, 52.99870491027832, 53.30622240900993, 51.99186533689499, 44.46829564869404, 45.341306403279305, 50.42346149682999, 48.36322724819183, 50.936015993356705, 52.95599900186062, 54.46019768714905, 53.098806738853455, 55.561553388834, 55.76773412525654, 56.335039883852005, 60.543861240148544, 60.04625894129276, 57.77579717338085, 60.455117002129555, 61.4629977196455, 65.62277510762215, 62.286443933844566, 62.81278409063816, 66.48403689265251, 67.45668590068817, 62.19901442527771, 59.90772217512131, 67.66145691275597, 60.79202212393284, 65.78639432787895, 67.89202854037285, 59.660488441586494, 49.54699672758579, 45.78500859439373, 48.61904852092266, 47.94423893094063, 49.30437594652176, 52.59200893342495, 53.25112156569958, 55.88610537350178, 54.32662345468998, 55.41651517152786, 51.41707018017769, 50.0019995123148, 49.10291835665703, 49.86217841506004, 51.19276061654091, 51.25367134809494, 54.137127622962, 55.64063474535942, 59.85936976969242, 66.39661118388176, 58.103252202272415, 41.84714309871197, 49.931999668478966, 62.80391536653042, 60.504271164536476, 63.480442464351654, 70.3706431388855, 71.91910564899445, 73.5626770555973, 73.423672914505, 70.60712724924088, 59.76355791091919, 64.84728991985321, 70.1361957192421, 70.62539666891098, 79.03412505984306, 75.56374087929726, 70.97713619470596, 63.14331315457821, 5.186460921540856, 0.013857638386980398, 3.0917822336778045, 3.6274145543575287, 3.542987834662199, 33.471472933888435, 77.37339377403259, 52.27736681699753, 38.349305391311646, 37.562265023589134, 38.8654924929142, 45.014721527695656, 40.756643414497375, 59.2686952650547, 46.75383880734444, 2.4412063183262944, 0.16917103406740353, 0.06479045696323738, 0.07553944931714796, 0.09583001170540228, 0.0469434232218191, 0.030830504729237873, 0.0748299561382737, 0.039038964168867096, 0.025522594041831326, 0.02122898215020541, 0.019180632298230194, 0.07918138318927959, 0.026392784457129892, 0.03238314631744288, 0.023182248041848652, 0.050037162291118875, 0.0631543478812091, 0.03370259582879953, 0.04442386896698736, 0.04277563319192268, 0.014555093002854846, 0.18423415313009173, 0.1475733343977481, 0.13829748291755095, 0.11848452224512585, 0.14543188211973757, 0.10624660353641957, 0.1371861613006331, 0.13410409621428698, 0.22333353554131463, 0.1059492546482943, 0.13889455556636676, 0.179838738986291, 0.16416581202065572, 0.08051149736274965, 0.12595145555678755, 0.15164327225647867, 0.11073500136262737, 0.06919154853676446, 0.1556136881117709, 0.07876065967138857, 0.14268694503698498, 0.1272635132772848, 0.23613161989487708, 0.1992437188164331, 0.13664650119608268, 0.498426795238629, 0.686028606723994, 47.840519696474075, 91.81483805179596, 59.29153583943844, 77.6276533305645, 112.44894683361053, 73.56980547308922, 13.430768810212612, 71.86014041304588, 88.81508901715279, 77.80326470732689, 56.821200996637344, 7.309279711917043, 16.07631415128708, 3.6032312270253897, 2.2071253415197134, 76.55016794800758, 94.84247758984566, 85.07573246955872, 85.35317078232765, 75.84457620978355, 76.52473971247673, 74.86535355448723, 82.26868629455566, 81.66770294308662, 87.85101234912872, 84.45451140403748, 83.29288333654404, 84.52089384198189, 84.23454120755196, 75.65577194094658, 64.26152095198631, 65.04353418946266, 76.48068487644196, 77.49946340918541, 72.29828730225563, 69.63371828198433, 75.32222583889961, 73.70079204440117, 72.1186101436615, 62.70405292510986, 62.64417573809624, 54.62519243359566, 58.13398875296116, 55.052783489227295, 54.93372067809105, 47.24894843995571, 47.966205552220345, 53.709566965699196, 50.74652396142483, 54.3521922826767, 56.12066678702831, 57.742005586624146, 57.260320633649826, 57.90295735001564, 57.471140921115875, 58.94402928650379, 63.05812172591686, 62.46163733303547, 61.75465486943722, 62.31036365032196, 63.46304699778557, 66.98022946715355, 62.374261021614075, 63.795392364263535, 69.51214760541916, 67.8584535419941, 63.91103535890579, 60.700025260448456, 70.29230654239655, 60.95564894378185, 66.304891705513, 68.86470794677734, 62.9471904784441, 51.23371101915836, 47.92751982808113, 50.70636011660099, 52.509203776717186, 50.46687416732311, 54.17307369410992, 55.37626393139362, 57.45362006127834, 55.615529492497444, 59.3991194665432, 54.065642058849335, 53.743396550416946, 51.63884907960892, 51.59041307866573, 55.283799692988396, 56.58335655927658, 56.5635672211647, 59.533206671476364, 62.2497721016407, 71.01353824138641, 64.17324408888817, 47.66760237514973, 56.6334492713213, 63.85425120592117, 62.768805250525475, 65.80932229757309, 74.48851257562637, 77.2969950735569, 74.50385615229607, 74.93631854653358, 72.43098378181458, 65.06030648946762, 65.05482718348503, 73.32758367061615, 74.1570183634758, 82.2764378786087, 77.28824034333229, 73.03883716464043, 68.41021433472633, 7.941781897097826, 0.17491727572632954, 7.0610646810382605, 8.58681058511138, 6.150257829576731, 37.20754265785217, 85.16549125313759, 61.819676980376244, 39.920091703534126, 55.46260289847851, 74.12997901439667, 47.32916973531246, 56.621305122971535, 64.04454499483109, 71.71093761920929, 5.898610632866621, 0.4576027358416468, 0.25654958677478135, 0.18222054321086034, 0.24034838424995542, 0.26234175253193825, 0.11143893585540354, 0.4176598135381937, 0.13937331503257155, 0.14899169735144824, 0.14463983243331313, 0.149421771930065, 0.1891314223757945, 0.3617953893262893, 0.09678517060820013, 0.1155075897986535, 0.19350253860466182, 0.17746089783031493, 0.09502112268819474, 0.15269363386323676, 0.11677592759951949, 0.1969390088925138], [0.025891226214298513, 0.05501749270479195, 0.019454536741250195, 0.021977480755595025, 0.04815318330656737, 0.0628420001885388, 0.1273845724062994, 0.029127550405974034, 0.03518657205859199, 0.11431011225795373, 0.08303343391162343, 0.05022300720156636, 0.0351534166111378, 0.023412176524288952, 0.045152164457249455, 0.0469366511242697, 0.07724054084974341, 0.12136262288549915, 0.029890220321249217, 0.01595581696165027, 0.056400536850560457, 0.04650927054171916, 0.03479288498056121, 0.03715847327839583, 0.05096171502373181, 0.23253036313690245, 0.15824590780539438, 4.183089612051845, 76.31331145763397, 45.58957748115063, 72.33811676502228, 69.57224518060684, 74.65585559606552, 29.2872229591012, 16.67113233357668, 78.48446935415268, 79.21081557869911, 57.21888765692711, 6.698487661778927, 3.9574705436825752, 2.314776652492583, 0.835540727712214, 49.39192704856396, 97.68154844641685, 88.20087477564812, 81.31607741117477, 78.96719545125961, 76.11269742250443, 75.84883198142052, 82.54753813147545, 80.77765390276909, 77.65767931938171, 81.40590459108353, 80.63212931156158, 76.51780888438225, 77.08671435713768, 65.5940106511116, 59.94258910417557, 62.89879247546196, 72.02001303434372, 72.98502445220947, 65.81308409571648, 68.14371183514595, 71.80215552449226, 69.9398298561573, 61.2951835244894, 54.798341542482376, 52.91740067303181, 51.48134373128414, 53.80125604569912, 51.02183058857918, 48.78697291016579, 50.26665151119232, 50.052308812737465, 47.25530929863453, 49.05946768820286, 46.25278249382973, 45.77777378261089, 46.79665490984917, 49.92337793111801, 49.38590057194233, 52.45312258601189, 52.713944390416145, 53.74828688800335, 58.03125746548176, 54.17569175362587, 56.36454910039902, 65.06051167845726, 61.15022890269756, 39.84215408563614, 61.87020666897297, 60.057183355093, 63.46673659980297, 60.43482609093189, 56.759503707289696, 63.60990531742573, 61.52605153620243, 63.10439184308052, 61.74401544034481, 57.93737970292568, 47.94583484530449, 47.11687512695789, 46.16207376122475, 46.806978955864906, 48.231685906648636, 48.16306158900261, 50.41774660348892, 49.067295268177986, 51.85153886675835, 50.174145475029945, 48.33176873624325, 47.68334113061428, 47.01353967189789, 46.07544980943203, 46.46202586591244, 48.121579214930534, 49.5948551595211, 51.17516376078129, 53.0093215405941, 57.66008958220482, 62.07118168473244, 52.101778239011765, 47.150754109025, 57.72859610617161, 60.42624995112419, 56.89289554953575, 62.90194630622864, 70.77212199568748, 71.80840998888016, 73.13453122973442, 69.85283732414246, 51.691035479307175, 49.37900774180889, 66.40446916222572, 71.63217544555664, 73.91589850187302, 69.41956177353859, 57.40009993314743, 18.276325799524784, 0.19712129520485178, 0.1725979454931803, 0.3365026105893776, 2.680154121480882, 1.8531503481790423, 39.22761686146259, 76.50667548179626, 27.85815004259348, 19.23190802335739, 44.810786470770836, 39.5070044696331, 28.67217466235161, 32.341725155711174, 55.291053503751755, 9.021810293197632, 0.8505078870803118, 0.18442078842781484, 0.08271783561212942, 0.05133946819114499, 0.17419182637240738, 0.031036562031658832, 0.11802503635408357, 0.050248110346728936, 0.05561026460782159, 0.08166192274075001, 0.015348901579272933, 0.07719906963757239, 0.05994096718495712, 0.0014024164033799025, 0.04366501925687771, 0.04377426710561849, 0.11355183029081672, 0.05080394555989187, 0.011932149227504851, 0.02715549704589648, 0.09003429106087424, 0.054803260645712726, 0.0511678316979669, 0.046359586776816286, 0.045012113769189455, 0.037865613849135116, 0.03440129446971696, 0.024289933135150932, 0.014025637428858317, 0.05527590852580033, 0.03297746559837833, 0.08308120595756918, 0.016934301565925125, 0.028150748621555977, 0.0162144442947465, 0.049009966824087314, 0.047901858706609346, 0.08242195617640391, 0.07863584527513012, 0.010953916025755461, 0.08105592205538414, 0.021435918897623196, 0.028793903074983973, 0.12608345394255593, 0.03161008076858707, 0.015087830724951345, 0.0313386031484697, 0.157167018041946, 0.07106065488187596, 6.310772141441703, 87.71271497011185, 52.26267300546169, 68.38816791772842, 81.86055779457092, 44.37362752854824, 24.763370007276535, 41.05041325092316, 85.99323123693466, 83.53654906153679, 61.94640018045902, 7.1418198477476835, 4.905679738149047, 5.5932053457945585, 0.995503356680274, 54.066003039479256, 98.77203673124313, 88.20683285593987, 82.87436619400978, 81.84848204255104, 77.27137684822083, 78.32607105374336, 86.7228376865387, 80.41564732789993, 82.44827225804329, 83.7301866710186, 81.84117123484612, 78.1644581258297, 80.0503121316433, 67.68971219658852, 61.819308400154114, 65.18999353051186, 74.82786476612091, 74.64565694332123, 69.52309101819992, 71.33374705910683, 73.65688920021057, 72.47996315360069, 66.11788094043732, 57.199417501688, 55.79033151268959, 53.89749348163605, 56.446218118071556, 53.81378777325153, 52.17398576438427, 51.479983404278755, 52.66080044209957, 51.5323293954134, 51.67795278131962, 50.29214434325695, 49.87167790532112, 50.49783110618591, 53.52328196167946, 52.82210558652878, 55.98706595599651, 55.76563663780689, 58.05426523089409, 61.89145512878895, 59.31211933493614, 61.122832372784615, 67.8509147465229, 64.20795142650604, 43.88092316687107, 63.7578047811985, 64.57050517201424, 66.18266746401787, 64.67404961585999, 60.518531799316406, 65.03617778420448, 63.980077654123306, 64.07001882791519, 64.84759390354156, 60.42939618229866, 51.53053969144821, 47.95349523425102, 49.394575506448746, 49.39061991870403, 49.047828912734985, 51.622604951262474, 52.98089526593685, 51.93229593336582, 53.8237926363945, 53.14965941011906, 49.2027921974659, 50.94829313457012, 50.144697055220604, 49.29409369826317, 51.52187615633011, 51.561352238059044, 55.23511290550232, 54.360928013920784, 56.5610783547163, 60.30968740582466, 64.94825810194016, 58.12000550329685, 53.7379514425993, 61.029114201664925, 63.7544609606266, 61.361968740820885, 66.3596923649311, 72.48635441064835, 75.4132841527462, 74.89754542708397, 72.8440748155117, 58.085176572203636, 56.30232743918896, 72.42206186056137, 74.189772605896, 77.56499469280243, 69.99492689967155, 61.14671789109707, 18.460203632712364, 0.39806497748941183, 0.4562394105596468, 1.6130085778422654, 2.90567344520241, 2.1765958797186613, 43.4049417078495, 83.42733532190323, 33.12238946557045, 20.962411165237427, 27.82347310334444, 38.69126044213772, 31.71690758317709, 36.54440604150295, 67.17771247029305, 9.513015635311604, 0.7062884664628655, 0.2359977809828706, 0.07231259121908806, 0.07072275504469872, 0.11052655434468761, 0.029873137937102, 0.04629182869393844, 0.06225015968084335, 0.08816573390504345, 0.03133292200800497, 0.06595058963284828, 0.057414774419157766, 0.09206718939822167, 0.056375426283921115, 0.08591823614551686, 0.07888301755883731, 0.020122330497542862, 0.029739297169726342, 0.02627187190228142, 0.03277887801232282, 0.025113835799857043, 0.0381760839081835, 0.20162227243417874, 0.10427023458760232, 0.16138612758368254, 0.1484812333364971, 0.1452102026087232, 0.20993070473195985, 0.1650516246445477, 0.1698189735179767, 0.08009247336303815, 0.1432473407476209, 0.16682541696354747, 0.10691091476473957, 0.19234294770285487, 0.19295027683256194, 0.10601585498079658, 0.1887816927046515, 0.14690029551275074, 0.23326330818235874, 0.15743537864182144, 0.15163065574597567, 0.13103920442517847, 0.26948628947138786, 0.16305011173244566, 0.11966714198933914, 0.1838181645143777, 0.5092072917614132, 0.27837754518259317, 10.404879078269005, 100.82008883357048, 65.81452801823616, 82.16817408800125, 98.43051105737686, 113.43105733394623, 35.5688501894474, 29.493458792567253, 86.17492228746414, 94.54562991857529, 67.49982878565788, 8.98695096373558, 10.126518364995718, 6.229312112554908, 1.575835410039872, 55.21338187158108, 102.79331535100937, 90.92008486390114, 82.55755439400673, 84.81498286128044, 79.1896203160286, 83.324064463377, 88.97332772612572, 83.74945163726807, 83.29039067029953, 82.53140419721603, 85.29836252331734, 84.43393170833588, 87.27487966418266, 70.09841054677963, 64.90079864859581, 69.32158023118973, 76.98426425457001, 77.81911745667458, 72.82092645764351, 74.86555114388466, 75.54991722106934, 75.27621790766716, 68.86815816164017, 59.24076296389103, 59.98844124376774, 57.880853936076164, 60.56882590055466, 57.55915939807892, 55.24629570543766, 56.474678590893745, 55.64035356044769, 54.58588354289532, 58.10354098677635, 52.27681964635849, 51.79718278348446, 52.912434339523315, 55.444386675953865, 54.45935033261776, 57.69175708293915, 58.55974070727825, 62.147344797849655, 66.84123292565346, 61.3515231013298, 63.10415245592594, 70.97068414092064, 68.1442666053772, 44.8641812056303, 63.30485388636589, 64.36952635645866, 65.88906481862068, 64.62186321616173, 61.388476118445396, 67.94531688094139, 66.31670907139778, 66.07540681958199, 66.91630929708481, 62.39612504839897, 51.521256789565086, 50.64746327698231, 50.799181535840034, 51.31029970943928, 52.575540617108345, 55.6036551296711, 55.51892347633839, 53.605042174458504, 55.695982575416565, 55.42133331298828, 53.33760492503643, 52.855289205908775, 53.25528994202614, 51.788492649793625, 53.28411899507046, 55.68908594548702, 57.967694476246834, 57.142051979899406, 58.768455907702446, 61.50589361786842, 69.25387546420097, 64.64793741703033, 59.56347204744816, 64.00846973061562, 65.1875388622284, 63.174327090382576, 69.93618965148926, 78.24976354837418, 78.30161556601524, 77.11800947785378, 74.49175760149956, 62.03508362174034, 60.5948431044817, 72.09049165248871, 77.0699192583561, 78.01863715052605, 73.30461770296097, 61.368941366672516, 21.331973634660244, 0.6400126602966338, 0.4178120428696275, 1.7944640410132706, 8.73909691348672, 2.9529431462287903, 46.28415361046791, 90.19105598330498, 37.048817574977875, 25.63586588948965, 59.98966097831726, 59.67436149716377, 45.35752393305302, 43.326179534196854, 78.03873807191849, 26.272688917815685, 1.4704828569665551, 0.3078348113922402, 0.2764145645778626, 0.19217203109292313, 0.2704258484300226, 0.11289701113128103, 0.12215928873047233, 0.19729362189536914, 0.18255364877404645, 0.1166180802101735, 0.14054816449061036, 0.1818304555490613, 0.1433596425340511, 0.09396525434567593, 0.22424646624131128, 0.17902599822264165, 0.16030956816393882, 0.10598164197290316, 0.10379661078331992, 0.1446644717361778, 0.1452830369817093, 0.12579082511365414], [0.03146741772070527, 0.0544756247109035, 0.06599300337256864, 0.024600726028438658, 0.04898237377346959, 0.04773314998601563, 0.030859888211125508, 0.02689630382519681, 0.07252520168549381, 0.08688643458299339, 0.06443606660468504, 0.12483829341363162, 0.06643484099186026, 0.05176756494620349, 0.085946356120985, 0.06033600126102101, 0.03436950828472618, 0.03506062217638828, 0.011426023065723712, 0.02030604358878918, 0.025699251164041925, 0.07997248292667791, 0.06389962742105126, 0.02844985825504409, 0.0685315640293993, 0.06201927753863856, 0.4850267549045384, 0.5225096654612571, 43.99681314826012, 69.33144450187683, 49.40527193248272, 92.71443217992783, 59.27224047482014, 64.87829625606537, 12.73045213893056, 32.195938378572464, 77.07655370235443, 67.14341551065445, 7.59789464995265, 2.6599194947630167, 1.2264312151819468, 0.05390255682868883, 18.834504447877407, 85.37965536117554, 90.27101129293442, 89.64798152446747, 81.56890824437141, 81.21299654245377, 83.58051270246506, 86.54810786247253, 81.31161645054817, 66.06262430548668, 78.50663736462593, 80.79011723399162, 74.53602522611618, 67.56704717874527, 59.823237508535385, 63.52859728038311, 66.52706578373909, 74.48455318808556, 75.01073375344276, 73.99027571082115, 75.3658626973629, 73.1718984246254, 68.41997221112251, 59.00588996708393, 55.20986706018448, 54.68257315456867, 53.261460810899734, 52.728341817855835, 51.26679204404354, 49.91433061659336, 48.53715531527996, 45.835416689515114, 46.25195033848286, 45.83015017211437, 48.88174742460251, 48.61602008342743, 48.21775585412979, 50.50842493772507, 49.96073752641678, 52.298425287008286, 54.15880545973778, 55.81832841038704, 54.4571578502655, 52.7800228446722, 57.23331168293953, 64.70946371555328, 60.80364190042019, 45.49191512167454, 65.87504357099533, 61.827113181352615, 65.58647945523262, 60.67385606467724, 56.2342768907547, 62.96935088932514, 61.17557354271412, 64.85806614160538, 60.83946257829666, 56.764527037739754, 46.68462932109833, 47.056754752993584, 47.66987845301628, 46.7318531870842, 49.18561711907387, 48.046685233712196, 49.80589583516121, 47.26615771651268, 50.38287967443466, 49.58059832453728, 49.1919019818306, 46.962189227342606, 46.166435927152634, 48.46098080277443, 47.50549927353859, 47.42309309542179, 49.75741423666477, 51.84252195060253, 51.72226220369339, 54.50214743614197, 57.881549298763275, 60.12083373963833, 56.87217906117439, 56.32383048534393, 59.78695705533028, 62.238794490695, 62.761619836091995, 67.44895711541176, 72.88577377796173, 73.73658612370491, 71.18858724832535, 54.0073873847723, 37.152027636766434, 57.24002592265606, 67.83810183405876, 66.81330442428589, 52.05983608961105, 27.38370180130005, 2.2326511843129992, 0.1409890892682597, 0.3200152952922508, 2.0392541494220495, 1.981790664140135, 1.3299643783830106, 47.135167345404625, 72.41757810115814, 18.890574239194393, 28.6054103448987, 40.20009487867355, 45.28884641826153, 45.39739139378071, 49.32720512151718, 32.23680138587952, 0.7823020219802856, 0.009872181981336325, 0.08322573179611936, 0.04682250881160144, 0.023118345416150987, 0.023330608928517904, 0.05794547309051268, 0.02721171287703328, 0.04329979725298472, 0.02781306586257415, 0.04998892640287522, 0.06752441768185236, 0.036600493258447386, 0.009200119020533748, 0.08057136641582474, 0.06432856651372276, 0.03353774627612438, 0.07088530022883788, 0.02497176461474737, 0.043125570664415136, 0.07750818898784928, 0.05885724975087214, 0.04579568070766982, 0.09078990871785209, 0.01930636881297687, 0.035080251982435584, 0.08528380378265865, 0.04344159569882322, 0.06274769548326731, 0.04852833895711228, 0.04462381468329113, 0.01781950006261468, 0.02422411762381671, 0.07692662722547539, 0.038600302941631526, 0.06982912018429488, 0.0731986339087598, 0.028180525441712234, 0.07308023166842759, 0.024106335076794494, 0.02225151692982763, 0.0664911996864248, 0.026293164119124413, 0.06814921696786769, 0.005790298791907844, 0.11857622201205231, 0.10551989253144711, 0.02528747423639288, 0.10026370582636446, 0.4184293613070622, 0.679190339287743, 54.752352610230446, 80.37355318665504, 51.87298871576786, 102.51408353447914, 64.03835892677307, 32.460913360118866, 21.804938055574894, 50.205049216747284, 84.52758148312569, 71.04167953133583, 10.865684151649475, 3.8164251996204257, 5.1765653025358915, 0.16698071878636256, 21.39190211892128, 87.14967638254166, 94.43523064255714, 92.11126774549484, 85.00344514846802, 82.22023129463196, 84.28625643253326, 88.7191441655159, 87.40914925932884, 70.08773311972618, 81.97843506932259, 82.83148169517517, 77.95127436518669, 73.0891540646553, 63.47934812307358, 66.15356102585793, 67.76427179574966, 76.42169684171677, 76.1563190817833, 74.85972225666046, 74.16521832346916, 74.67982470989227, 71.08758866786957, 61.33258871734142, 58.80675785243511, 56.61899484694004, 55.20588867366314, 55.238840505480766, 56.026659831404686, 51.697517931461334, 53.61083686351776, 48.83348621428013, 50.188440307974815, 49.65413577854633, 50.446245074272156, 51.42251528799534, 52.120788618922234, 52.66993135213852, 53.87794353067875, 55.34799724817276, 55.54225042462349, 59.00300212204456, 57.006726041436195, 59.24779258668423, 58.72335612773895, 67.55245596170425, 63.38650390505791, 45.35696916282177, 66.06191754341125, 64.9236050248146, 68.51225405931473, 64.0965262055397, 58.80514293909073, 65.19301816821098, 63.65573465824127, 68.1303821504116, 67.13000982999802, 61.31575562059879, 49.5451196283102, 51.13034136593342, 49.70082387328148, 49.70902003347874, 51.524308025836945, 50.10234832763672, 53.23499143123627, 51.42320305109024, 52.41642415523529, 52.462880462408066, 51.53597719967365, 51.55431881546974, 51.10645204782486, 50.41162893176079, 51.667419746518135, 51.576042249798775, 53.30863907933235, 54.98975247144699, 54.97135765850544, 57.936232164502144, 60.24582423269749, 62.87878654897213, 60.0252840667963, 59.24028038978577, 63.5050917416811, 66.1963315308094, 67.41174191236496, 70.98716765642166, 75.15219256281853, 74.83343526721, 73.39992418885231, 60.02458110451698, 44.20933574438095, 61.19512729346752, 69.70706954598427, 68.92798975110054, 52.970753610134125, 27.143963165581226, 1.94452665746212, 0.16738858830649406, 1.1515450710430741, 3.6227823654189706, 1.908739109057933, 1.5131650166586041, 52.50909738242626, 77.4733056128025, 24.748640097677708, 26.155106127262115, 29.166053161025047, 53.33585701882839, 47.1565829962492, 55.81847280263901, 39.75157454609871, 1.5769375883974135, 0.10082243170472793, 0.009741682733874768, 0.03162401830195449, 0.029071206554363016, 0.038970256136963144, 0.008750512042752234, 0.036311233779997565, 0.04816333959752228, 0.06285644238232635, 0.047123813346843235, 0.047248750197468325, 0.07605515289469622, 0.016854372261150274, 0.03625413293775637, 0.007851512382330839, 0.02009103413001867, 0.05119013323565014, 0.061408623587340117, 0.013407063834165456, 0.017796152096707374, 0.06388735229847953, 0.07714584280620329, 0.1624395023100078, 0.1281175174517557, 0.18441111082211137, 0.20881040312815458, 0.08101669955067337, 0.19099174911389127, 0.10017589491326362, 0.15192426420981064, 0.14760871999897063, 0.1364176970673725, 0.18957387597765774, 0.23312338365940377, 0.24558693752624094, 0.14494874398224056, 0.1609236656804569, 0.23531212558737025, 0.12062531401170418, 0.08467823354294524, 0.14003689895616844, 0.09854365242063068, 0.1518103593843989, 0.11715186250512488, 0.17907628614921123, 0.13870088470866904, 0.1896069906069897, 0.21930634538875893, 0.5427686346229166, 0.5453492898959666, 73.51944297552109, 90.18055334687233, 63.30915145576, 96.16820365190506, 88.46139639616013, 87.72608265280724, 17.450666204094887, 42.99082852900028, 87.203648686409, 79.42677319049835, 11.16328988224268, 7.6750129368156195, 7.592453816905618, 0.2667122008278966, 24.158109985291958, 90.22255629301071, 93.82435262203217, 97.90364652872086, 85.85988119244576, 88.39116096496582, 88.4322215616703, 92.51228302717209, 86.19174018502235, 74.69107210636139, 84.12702977657318, 84.54108595848083, 83.61239299178123, 77.61867821216583, 66.43775537610054, 71.42285987734795, 71.82245403528214, 79.65878874063492, 80.5075415968895, 78.39312225580215, 79.74344059824944, 78.05746346712112, 75.18829062581062, 65.33308625221252, 61.02714590728283, 58.874831199645996, 58.67619305849075, 56.952426955103874, 58.04806016385555, 55.12403726577759, 57.65486866235733, 53.75706821680069, 53.36327254772186, 52.88134440779686, 55.36537751555443, 55.62342166900635, 55.86926847696304, 58.12970258295536, 56.605877950787544, 58.64386059343815, 60.045111402869225, 60.01421146094799, 60.05093649029732, 60.56190267205238, 62.4903067946434, 69.53116178512573, 67.23462581634521, 52.05143094062805, 68.40798765420914, 66.82056203484535, 70.58172181248665, 64.53661099076271, 57.989227920770645, 68.53648915886879, 64.2293518781662, 69.88752946257591, 68.01103815436363, 64.09156367182732, 51.68530538678169, 53.78873951733112, 51.84718430042267, 52.97581873834133, 54.572204276919365, 51.86013400554657, 56.37904912233353, 52.20058813691139, 52.30639345943928, 54.645582139492035, 53.87467950582504, 53.096842244267464, 51.81523181498051, 53.3163146674633, 53.638366386294365, 54.95714262127876, 55.25807127356529, 58.292257860302925, 56.11855410039425, 61.9877153635025, 63.42904642224312, 65.92536047101021, 64.18560102581978, 62.918023243546486, 66.46256044507027, 71.30907878279686, 69.72479939460754, 75.4479230940342, 78.44663858413696, 77.16069638729095, 75.09999096393585, 66.19519159197807, 47.52247676253319, 64.69192385673523, 70.07414504885674, 72.84979730844498, 56.29851244390011, 30.828739441931248, 3.343904879875481, 0.3588360903086141, 1.4920653426088393, 7.505758618935943, 7.945079170167446, 1.839288929477334, 57.19670444726944, 83.09592470526695, 27.97964282333851, 39.68822434544563, 59.712222665548325, 66.37099295854568, 56.99028052389622, 65.1349800825119, 71.54173269867897, 3.623670330271125, 0.11183868627995253, 0.16367695934604853, 0.36441335978452116, 0.12173855036962777, 0.14820019685430452, 0.1315429445821792, 0.10469020853633992, 0.17968058731639758, 0.233665433479473, 0.2270047619822435, 0.18660044646821916, 0.16148912283824757, 0.13828641007421538, 0.14988559938501567, 0.13296115910634398, 0.1159400466713123, 0.10256942507112399, 0.17040633887518197, 0.11738577260985039, 0.17096496827434748, 0.24978146713692695, 0.10645770002156496], [0.06443830789066851, 0.03132351157546509, 0.046200989818316884, 0.04996825759008061, 0.030532105702150147, 0.054765310924267396, 0.036615098724723794, 0.09417007226147689, 0.01578194660396548, 0.06826161523349583, 0.04183668650512118, 0.10467204818269238, 0.03383394483535085, 0.035368810131330974, 0.010208957464783452, 0.029902638307248708, 0.0493606946838554, 0.04816120221221354, 0.09515226760413498, 0.07598691983730532, 0.09086582300369628, 0.009983787076635053, 0.018817427080648486, 0.030104584111541044, 0.044524604381877, 0.06371148556354456, 0.24217521044192836, 0.18479098653187975, 9.408965818583965, 74.48380082845688, 42.76781469583511, 42.41653874516487, 58.96810099482536, 64.58220854401588, 44.59167122840881, 14.228249117732048, 60.29515698552132, 74.2912195622921, 11.701278313994408, 2.5361584732308984, 2.9060102021321654, 0.2595316548831761, 1.5397568210028112, 46.6846939176321, 81.58174395561218, 88.209348320961, 87.80615955591202, 82.55965948104858, 82.89996162056923, 82.2223287820816, 57.67491638660431, 63.208000883460045, 86.0120478272438, 83.40821474790573, 69.64974582195282, 64.68868643045425, 65.39479494094849, 67.69675701856613, 63.860178887844086, 73.81234645843506, 75.25066807866096, 74.70920473337173, 72.23770335316658, 69.81167033314705, 66.50257229804993, 60.22624008357525, 55.42148530483246, 55.157897248864174, 53.916648253798485, 55.04257343709469, 53.45723770558834, 51.25008054077625, 49.50088620185852, 48.28271336853504, 48.20685803890228, 49.614572301506996, 47.21915043890476, 46.87123730778694, 47.89094299077988, 49.68677222728729, 51.85960203409195, 54.091993644833565, 54.21688534319401, 54.35597687959671, 54.87155981361866, 56.55914045870304, 57.662916630506516, 65.31843423843384, 63.526268005371094, 52.43277087807655, 67.15361416339874, 62.96587787568569, 64.64800581336021, 59.23432990908623, 60.749787390232086, 63.64070266485214, 60.46718515455723, 65.62426462769508, 60.247606337070465, 54.81990918517113, 46.92290313541889, 47.77165599167347, 47.88576386868954, 47.09076292812824, 48.419034853577614, 48.07237185537815, 48.79828870296478, 47.778237238526344, 48.697274923324585, 49.401468336582184, 50.60193412005901, 49.41675491631031, 48.242070749402046, 48.04114133119583, 47.58901119232178, 47.76497595012188, 49.27907310426235, 49.91545155644417, 51.122878566384315, 50.58241456747055, 53.99037569761276, 56.3093076646328, 59.569069147109985, 59.735975190997124, 60.09482033550739, 60.30214861035347, 64.58422243595123, 65.86330220103264, 70.89389026165009, 68.39654266834259, 75.03463447093964, 56.16091802716255, 34.509885013103485, 40.71792729198933, 55.96663065254688, 44.96882379055023, 32.1109027415514, 3.7758531142026186, 0.06791748135583475, 0.9019310621079057, 0.9235112322494388, 0.9626769775059074, 1.542443276848644, 2.0345868123695254, 53.75824235379696, 50.33217139542103, 14.244366902858019, 25.566352419555187, 44.97219040989876, 73.3157967031002, 50.91933108866215, 41.298741325736046, 6.177269155159593, 0.5156347062438726, 0.06557803149917163, 0.16165460692718625, 0.06791183361201547, 0.057569330383557826, 0.04418407734192442, 0.023633251184946857, 0.05658707937982399, 0.03050835512112826, 0.04648465721402317, 0.02595597117760917, 0.021433974470710382, 0.011182803646079265, 0.039177003636723384, 0.02422555367957102, 0.049031106900656596, 0.09988888414227404, 0.04751663582283072, 0.026604675040289294, 0.02679909175640205, 0.0376493223302532, 0.018833466747310013, 0.016127613016578835, 0.06242846808163449, 0.04146505605604034, 0.03130389661237132, 0.04789922779309563, 0.08195310438168235, 0.04864760208874941, 0.07718852371908724, 0.10646013426594436, 0.02151764048903715, 0.04389526686281897, 0.014816331768088276, 0.09021484816912562, 0.07302806610823609, 0.06079173930629622, 0.06933285345439799, 0.032910783629631624, 0.018159327628382016, 0.045837233556085266, 0.13412949250778183, 0.009795508849492762, 0.020947832490492146, 0.06488819781225175, 0.07705562733463012, 0.0674990436527878, 0.05335298163117841, 0.0950324181758333, 0.29031136888079345, 0.2294753270689398, 13.203179072588682, 87.23479941487312, 48.90922375023365, 46.77423231303692, 70.55647596716881, 49.09133277833462, 30.76354444026947, 26.849703155457973, 70.88045418262482, 80.39192900061607, 13.970928825438023, 1.8878654041327536, 5.803991435095668, 0.694202680606395, 1.8321055336855352, 49.819613099098206, 85.40689989924431, 89.42198485136032, 89.73117426037788, 85.07510170340538, 87.9716482758522, 88.33150416612625, 64.17320609092712, 66.74062192440033, 89.32260498404503, 83.88648748397827, 74.84691694378853, 65.74216470122337, 66.76062405109406, 65.76085209846497, 67.75728017091751, 76.7411532998085, 79.4570043683052, 77.19690084457397, 75.9658733010292, 75.58746680617332, 71.8899992108345, 64.07993629574776, 58.7735590338707, 56.9037401676178, 59.28917996585369, 59.24267426133156, 57.41057217121124, 53.85023161768913, 53.13091121613979, 52.8211822360754, 52.46593549847603, 51.3255824893713, 51.60320699214935, 50.212398022413254, 50.96265636384487, 53.30645799636841, 56.715623661875725, 56.92781187593937, 58.47192741930485, 58.57199124991894, 59.65959168970585, 61.31006732583046, 61.88053831458092, 68.34862723946571, 65.23277923464775, 55.74033759534359, 69.36099171638489, 66.1028641462326, 67.330312281847, 64.24769729375839, 65.22294536232948, 65.64201727509499, 65.14691144227982, 67.90220439434052, 63.25356423854828, 58.79693537950516, 50.4632605612278, 50.00711403787136, 50.14741010963917, 49.51182961463928, 50.65918184816837, 50.736120119690895, 51.2686463445425, 50.41805058717728, 52.29283578693867, 51.156518161296844, 52.886158749461174, 50.86038865149021, 53.19915175437927, 52.712074890732765, 53.35542216897011, 50.70777364075184, 53.988415002822876, 54.24857184290886, 55.95414072275162, 55.12372188270092, 57.28966645896435, 60.25573030114174, 63.24007496237755, 62.10475668311119, 62.525348514318466, 64.03741657733917, 67.3087066411972, 71.904316842556, 76.14261701703072, 72.19001591205597, 76.91268369555473, 61.130412966012955, 40.616275146603584, 44.664311930537224, 56.85132198035717, 43.80893222987652, 32.118806317448616, 3.794025876559317, 0.05400573762017302, 1.4820186817087233, 2.4764301907271147, 6.187546653673053, 1.760388775728643, 2.3838035110384226, 57.09331959486008, 57.640038058161736, 19.993052780628204, 23.4232959151268, 48.113048672676086, 77.77120962738991, 54.487096443772316, 55.2517332136631, 11.64853049442172, 0.7344654388725758, 0.3060353407636285, 0.16100306063890457, 0.025381281702721026, 0.09192271551000886, 0.024913621055020485, 0.050083706082659774, 0.10754559945780784, 0.011052516838390147, 0.0569746288965689, 0.012522376491688192, 0.05959149726550095, 0.040717832089285366, 0.040753633293206804, 0.04619193190592341, 0.06589963377336971, 0.09387130587128922, 0.08953467724495567, 0.01758566046191845, 0.062452031270368025, 0.06413924464141019, 0.03977871470851824, 0.02433988523989683, 0.1499043163494207, 0.12225846192450263, 0.0944187214190606, 0.21753783716121688, 0.1810708228731528, 0.19133460649754852, 0.1272082084324211, 0.22815633768914267, 0.08776662914897315, 0.10636540653649718, 0.13298912323080003, 0.12459445337299258, 0.10614674014504999, 0.09831548653892241, 0.16290043538901955, 0.1740364354918711, 0.1758128104847856, 0.17530706652905792, 0.29565082455519587, 0.10945878937491216, 0.16080483299447224, 0.1675159705337137, 0.13593071460491046, 0.10279779875418171, 0.11255678837187588, 0.25263318442739546, 0.44222231896128505, 0.3455191111424938, 19.056917913258076, 108.89269486069679, 59.679552018642426, 61.58441640436649, 80.02374395728111, 98.82952764630318, 58.183515295386314, 23.040916733443737, 70.71521624922752, 89.39432993531227, 15.549582615494728, 4.255385482683778, 6.333726234734058, 0.3878367872675881, 1.877541714347899, 51.805017963051796, 82.91687831282616, 89.42964524030685, 90.56465953588486, 86.63028985261917, 91.41953006386757, 89.34925675392151, 65.3984047472477, 74.70974430441856, 92.65391662716866, 87.8822922706604, 79.40675586462021, 71.74195155501366, 70.92667490243912, 71.78096026182175, 69.69972833991051, 79.92295816540718, 80.69009140133858, 80.95739185810089, 77.10377544164658, 76.42964601516724, 74.96041685342789, 67.28869691491127, 61.4254367351532, 60.41801579296589, 60.12427635490894, 61.893313229084015, 59.9253798276186, 57.672742903232574, 55.59412904083729, 57.661845088005066, 56.41817942261696, 56.558312103152275, 53.54978933930397, 53.67533840239048, 55.26277542114258, 56.063833236694336, 60.645057410001755, 58.73980164527893, 60.13856738805771, 62.048789486289024, 63.11042591929436, 64.90306332707405, 64.41737338900566, 70.55551841855049, 67.39715069532394, 57.48344846069813, 69.95388150215149, 66.84554189443588, 69.90208268165588, 63.14959041774273, 65.39740160107613, 69.3444474041462, 64.27418947219849, 70.66386580467224, 64.42192554473877, 59.077797308564186, 51.91595681011677, 52.72793523967266, 53.4949316829443, 51.11285090446472, 52.54198461771011, 53.645604997873306, 52.16257877647877, 52.312195748090744, 53.8877622038126, 52.30404518544674, 55.63468046486378, 53.89232195913792, 54.56850327551365, 55.63368871808052, 54.91556525230408, 54.26975950598717, 57.36256554722786, 57.19883233308792, 59.04844768345356, 57.373486161231995, 60.57183913886547, 65.03571420907974, 65.21362826228142, 66.55234962701797, 65.84627151489258, 65.80863833427429, 70.77738091349602, 75.62754705548286, 78.36384102702141, 75.60023412108421, 79.6479669213295, 65.24214953184128, 45.70678599178791, 48.684591203927994, 59.90952707827091, 47.87331573665142, 33.7009160220623, 5.607265066355467, 0.19771112449234352, 2.277705129235983, 2.0957939280197024, 9.699668269604445, 6.4880535285919905, 3.5267914412543178, 63.67018148303032, 63.65208685398102, 21.424456872045994, 38.714993968605995, 58.869667276740074, 85.38096249103546, 63.17912623286247, 71.23040020465851, 19.098183698952198, 1.2049143947660923, 0.4742008092580363, 0.3764454438351095, 0.17816961917560548, 0.1888708840124309, 0.10470091030583717, 0.15374732029158622, 0.22009759355569258, 0.1666781451785937, 0.14330095349578187, 0.11777855426771566, 0.1302320891409181, 0.11455594867584296, 0.12181539976154454, 0.12950039090355858, 0.101467165077338, 0.2076138384290971, 0.11653821769868955, 0.13578851911006495, 0.16471209208248183, 0.1246441772673279, 0.14516318013193086, 0.08950513976742513], [0.05817405828565825, 0.025951817005989142, 0.02721931061387295, 0.07754061341984197, 0.053039954873383977, 0.018759637896437198, 0.09716762157040648, 0.07828814166714437, 0.02979894543386763, 0.06953231306397356, 0.08785846992395818, 0.01765740758855827, 0.012613318340299884, 0.03234907431760803, 0.009417114652023884, 0.07119929548935033, 0.027193418936803937, 0.013141191284375964, 0.01198014484543819, 0.02951236325316131, 0.015541194825345883, 0.03201669976988342, 0.009251609226339497, 0.04388515510072466, 0.018387443415122107, 0.04617779028194491, 0.006270889043662464, 0.08407115674344823, 0.07867020671255887, 50.52362032234669, 73.5729593038559, 64.13310304284096, 92.44689613580704, 50.26944436132908, 71.09981641173363, 18.355853632092476, 34.370075315237045, 78.69199901819229, 21.095795407891273, 1.3676110957749188, 3.6815276881679893, 2.378202136605978, 0.12345754250418395, 8.812002651393414, 41.09256058931351, 67.99278393387794, 71.16366058588028, 73.63532915711403, 67.50033035874367, 44.7059690952301, 45.459996834397316, 87.18112349510193, 86.67131245136261, 74.278444647789, 64.91779893636703, 67.92035222053528, 70.38323566317558, 69.66850161552429, 66.81747660040855, 73.54463562369347, 75.37543818354607, 76.52999863028526, 75.3415060043335, 72.91874840855598, 69.61918026208878, 57.625177055597305, 56.905203089118004, 55.56705169379711, 55.366232469677925, 56.31833977997303, 52.64164187014103, 53.51650692522526, 52.86057472229004, 49.62515473365784, 46.65801554918289, 49.030524641275406, 51.57079093158245, 47.20933176577091, 50.046597719192505, 47.43585281074047, 51.42366662621498, 53.17744731903076, 54.457606226205826, 56.12198531627655, 52.916978895664215, 54.53133746981621, 59.58875969052315, 66.46319881081581, 60.92424362897873, 45.555196925997734, 66.42560362815857, 62.37875238060951, 68.54436233639717, 59.60201717913151, 59.41654913127422, 61.9073648750782, 62.60072886943817, 65.36071076989174, 61.443656757473946, 54.73266966640949, 49.49351079761982, 49.25667330622673, 46.69702045619488, 47.65991538763046, 47.542076110839844, 48.06868605315685, 48.841534182429314, 52.801351100206375, 53.53101834654808, 54.2331712692976, 52.77509830892086, 50.74117384850979, 50.76266169548035, 48.2460643351078, 50.80724090337753, 47.582338750362396, 49.84474875032902, 50.314323753118515, 51.468922197818756, 50.506243854761124, 53.49901266396046, 56.519937962293625, 57.71095745265484, 58.3356287330389, 59.595447331666946, 63.36980000138283, 66.33469730615616, 66.08526349067688, 69.04513746500015, 67.06003278493881, 65.5994139611721, 54.5323596149683, 34.42938633263111, 30.1457279920578, 31.31363332271576, 22.94047102332115, 3.8850594917312264, 0.22403382608899847, 0.4999050940386951, 0.24994533334393054, 2.285746685229242, 4.078660290688276, 0.9066199511289597, 2.3630506871268153, 64.4628493487835, 43.23499582707882, 22.073566541075706, 39.79587256908417, 71.64728343486786, 59.934183955192566, 41.88300937414169, 48.30117277801037, 4.844711059704423, 0.19210744940210134, 0.11273208365309983, 0.03568867206922732, 0.05133276659762487, 0.043481352549861185, 0.026855077521759085, 0.009036266728799092, 0.022015157737769186, 0.019066990935243666, 0.006817068451709929, 0.06329224634100683, 0.0538812942977529, 0.008679786296852399, 0.009154335930361412, 0.018150470095861237, 0.017349024819850456, 0.09529830742394552, 0.03163317640428431, 0.043255350028630346, 0.10269507067278028, 0.021184573888604064, 0.011967430928052636, 0.03384224204637576, 0.0238262986385962, 0.0036036930896443664, 0.05858147509570699, 0.04040115025418345, 0.06549302590428852, 0.031670395110268146, 0.04445405211299658, 0.058317960720160045, 0.05420700807007961, 0.05723550864786375, 0.028359525895211846, 0.07603297752211802, 0.025111119539360516, 0.02236591713881353, 0.02607670376164606, 0.012255181991349673, 0.12409593793563545, 0.06341660060570575, 0.03179669380187988, 0.048729475820437074, 0.032138478782144375, 0.060587177431443706, 0.06966982560697943, 0.05059080445789732, 0.043375659588491544, 0.04194019013084471, 0.040638051214045845, 0.0868265210010577, 0.34427895268891007, 61.2533363699913, 82.16567382216454, 65.28386369347572, 90.00455439090729, 62.63541340827942, 46.160090267658234, 23.43501638621092, 47.81829088926315, 82.16076448559761, 22.523730285465717, 1.1649473081342876, 10.199260711669922, 3.135499837808311, 0.269109575310722, 10.234849601984024, 42.83118009567261, 72.8009395301342, 73.2238644361496, 77.34969824552536, 73.35691809654236, 50.42472302913666, 51.54977425932884, 87.2390627861023, 86.18230909109116, 81.24756708741188, 68.75786527991295, 69.44840222597122, 70.84320858120918, 72.80902549624443, 68.44280898571014, 76.16865321993828, 78.5487999022007, 77.79589310288429, 77.34621003270149, 76.44999772310257, 71.35480552911758, 62.06127181649208, 60.52740812301636, 58.36151294410229, 57.870298102498055, 58.53077106177807, 56.08127810060978, 56.50114797055721, 55.68265289068222, 52.385505214333534, 51.32164970040321, 53.45378749072552, 53.80502924323082, 50.95052741467953, 53.51287432014942, 53.27509067952633, 54.33042325079441, 55.07021315395832, 58.12932640314102, 59.117980152368546, 55.86633123457432, 58.21922957897186, 61.83594770729542, 68.2006099820137, 62.90623627603054, 49.41387467086315, 67.6335284113884, 67.34173446893692, 70.7756482064724, 63.51363368332386, 65.42884111404419, 63.7224742770195, 65.44870644807816, 68.2872149348259, 66.2655258178711, 57.667263597249985, 52.50692389905453, 50.278153494000435, 50.62445551156998, 50.42585536837578, 50.54488018155098, 51.22642681002617, 52.85364009439945, 56.34697884321213, 55.38581661880016, 57.27657616138458, 55.85458226501942, 55.21618612110615, 55.035084038972855, 52.864575907588005, 54.522681534290314, 54.81697574257851, 52.66229376196861, 55.70445992052555, 55.088558569550514, 56.069346740841866, 57.254085168242455, 59.906700029969215, 61.118595600128174, 61.782769560813904, 62.40157775580883, 68.24036344885826, 70.1961413025856, 71.57025396823883, 74.06846791505814, 73.47367063164711, 69.10968080163002, 58.30876037478447, 37.664893716573715, 32.65560731291771, 31.633697748184204, 23.438248112797737, 3.492857124656439, 0.013030858972342685, 0.8445601374842227, 1.9778382824733853, 6.0515206027776, 2.4678500136360526, 1.0216117557138205, 3.3723411289975047, 74.8980849981308, 56.097738817334175, 22.371588349342346, 39.91180054843426, 78.96866217255592, 58.906867280602455, 52.12691009044647, 59.51828867197037, 5.098250554874539, 0.13790745462756604, 0.07027022307738662, 0.059384323030826636, 0.024469566269544885, 0.02091712798574008, 0.035650069257826544, 0.03157578612444922, 0.04405584164487664, 0.04541846559732221, 0.010785241629491793, 0.041763729677768424, 0.07610820161062293, 0.034131931970478036, 0.042439700046088547, 0.04107663451577537, 0.029386075693764724, 0.05992495163809508, 0.05770162562839687, 0.11162318885908462, 0.040507915618945844, 0.03939830465242267, 0.059754428366431966, 0.023174715242930688, 0.12396319740219042, 0.1710063504287973, 0.14344304508995265, 0.18649918783921748, 0.10105605237185955, 0.05714124476071447, 0.13306084438227117, 0.154216387309134, 0.08119565361994319, 0.16555474139750004, 0.17517322761705145, 0.19281219283584505, 0.18699813372222707, 0.24241145089035854, 0.12070962198777124, 0.22906104539288208, 0.1409199953195639, 0.15059252473292872, 0.13105234043905511, 0.1450896926689893, 0.08738293137867004, 0.19594941433751956, 0.16326656652381644, 0.16934261861024424, 0.1200244044594001, 0.20391176833072677, 0.12056370091158897, 0.180467679456342, 0.6890012940857559, 79.60343331098557, 90.89313670992851, 81.80095419287682, 100.64059406518936, 77.47993245720863, 95.69433107972145, 24.057166501879692, 47.50646062195301, 91.11037865281105, 28.3999040722847, 4.550167489796877, 13.427977859973907, 4.24381272867322, 0.5780936765950173, 11.084392815828323, 43.22353184223175, 77.00504153966904, 74.53926265239716, 79.48817789554596, 70.99844545125961, 51.84869281947613, 59.423650950193405, 95.75445145368576, 93.16651672124863, 85.27600452303886, 73.10299292206764, 76.21291324496269, 76.58399373292923, 76.74253642559052, 71.11028105020523, 78.29020097851753, 81.10562950372696, 81.04139775037766, 78.95258903503418, 79.8088426887989, 73.82872357964516, 64.89313066005707, 62.93285384774208, 61.649905890226364, 63.838200867176056, 62.46678225696087, 57.540171816945076, 59.720430225133896, 62.20086492598057, 57.24476806819439, 54.848574846982956, 55.661020651459694, 58.43828782439232, 56.029179096221924, 57.920668199658394, 55.68420320749283, 56.94471716880798, 59.65855814516544, 61.67753420770168, 61.63395814597607, 59.04602721333504, 60.985629335045815, 64.27510142326355, 72.26166486740112, 66.74980223178864, 50.502489656209946, 68.25183123350143, 69.195077419281, 75.01863732933998, 62.414136081933975, 63.94764259457588, 63.810219168663025, 66.15910112857819, 69.43061158061028, 67.76064679026604, 58.61467435956001, 55.68130776286125, 54.03347298502922, 52.22774527966976, 53.190579414367676, 53.44273388385773, 54.30758647620678, 53.485162407159805, 57.03416056931019, 58.07194948196411, 57.888905704021454, 58.154728040099144, 56.663194075226784, 56.26889303326607, 55.509541779756546, 58.495033979415894, 58.039427027106285, 55.85149683058262, 59.043538346886635, 57.822808250784874, 58.25728453695774, 59.19808745384216, 61.218378245830536, 64.06279921531677, 63.384512811899185, 66.5625786781311, 69.21781539916992, 74.32230189442635, 75.44850826263428, 76.64242699742317, 78.02736908197403, 70.33973559737206, 62.29498587548733, 40.77512942254543, 36.196701899170876, 32.914084643125534, 26.209996081888676, 5.352496337145567, 0.42759984266012907, 1.0217037820257246, 1.476404364220798, 8.916059117764235, 14.238803051412106, 3.645341517403722, 4.359154114499688, 79.43621188402176, 59.80460710823536, 30.053744427859783, 58.7319702655077, 83.83827567100525, 71.51385739445686, 61.86383441090584, 75.71998849511147, 7.813110826537013, 0.24796271551167592, 0.14806294406298548, 0.09598165474017151, 0.12344169765128754, 0.09864778316114098, 0.09212737015332095, 0.1323231347487308, 0.1811126503162086, 0.1673916756408289, 0.08547840974642895, 0.14582820382202044, 0.15019295242382213, 0.1208634246722795, 0.16574682405916974, 0.06271331920288503, 0.1552381317014806, 0.2284800773486495, 0.1184376333549153, 0.31474996532779187, 0.1509793766308576, 0.10061868248158135, 0.11882201390108094, 0.11174141298397444], [0.010174085800827015, 0.03521153048495762, 0.0728144240565598, 0.08484702761052176, 0.09166346848360263, 0.0054237413860391825, 0.021543999719142448, 0.016980860200419556, 0.02092086841003038, 0.031632408281438984, 0.04904021305264905, 0.038370073889382184, 0.0558157801424386, 0.05663365656801034, 0.016122549714054912, 0.03667425160529092, 0.07358589398791082, 0.08638526225695387, 0.07267839580890723, 0.0069056785650900565, 0.02825961240887409, 0.029360397384152748, 0.043298888122080825, 0.08374371376703493, 0.09714442945551127, 0.15426342462887987, 0.026778200299304444, 0.15602635190589353, 0.19233951898058876, 17.933424599468708, 83.31936031579971, 67.81749173998833, 70.90799510478973, 48.41446749866009, 52.51383572816849, 29.79529369622469, 19.291789010167122, 70.62398314476013, 23.565106205642223, 0.2549949358217418, 8.194407541304827, 1.9477153988555074, 0.21635635290294886, 0.2721161342924461, 7.626126185059547, 28.28469045460224, 40.180408135056496, 42.127746641635895, 27.83792182803154, 28.621358089149, 64.8510517179966, 89.75246071815491, 74.82224866747856, 72.07935824990273, 70.38170054554939, 76.35070145130157, 78.32228645682335, 78.29481393098831, 65.57356014847755, 73.07424366474152, 79.79107484221458, 78.77137675881386, 73.28630268573761, 73.79862919449806, 66.85157597064972, 59.601644799113274, 55.373554676771164, 53.851109370589256, 52.83820912241936, 53.363686725497246, 54.79591727256775, 59.237476140260696, 59.94883216917515, 60.978246331214905, 54.41331200301647, 50.96330612897873, 49.10511463880539, 50.082236006855965, 48.645438104867935, 49.08820554614067, 48.56577157974243, 52.18658588826656, 52.8570257127285, 54.40988078713417, 54.86189313232899, 58.98190185427666, 61.652539148926735, 67.83265292644501, 58.6310438811779, 37.7521750330925, 67.25103333592415, 63.70899640023708, 64.28466930985451, 64.69750955700874, 66.47685527801514, 63.86743649840355, 66.17467269301414, 63.60547095537186, 59.146037846803665, 51.64369761943817, 51.11049123108387, 48.7512244284153, 48.034028112888336, 48.75773727893829, 47.735508531332016, 48.98816451430321, 54.38188388943672, 60.39069525897503, 61.6891235858202, 60.432778000831604, 59.01713356375694, 54.75397892296314, 51.88341535627842, 50.359978303313255, 50.58426886796951, 46.57462142407894, 49.825924560427666, 51.07551410794258, 51.77549734711647, 53.46099950373173, 54.32082496583462, 53.23822505772114, 56.34072057902813, 60.191061571240425, 60.61932519078255, 62.083280235528946, 67.05687135457993, 69.04979601502419, 69.70989659428596, 69.75750043988228, 61.5785077214241, 43.469583839178085, 25.939215011894703, 19.848345145583153, 14.071212094277143, 3.1913114804774523, 0.21264680195599794, 0.09576445037964731, 0.3675541584379971, 1.6458049742504954, 5.473705558106303, 2.79720232822001, 0.3453306946903467, 2.9889583261683583, 50.45566476881504, 20.583945773541927, 40.96568159759045, 48.09536062180996, 47.20944955945015, 34.66754995286465, 55.41407950222492, 22.034324146807194, 0.47047113126609474, 0.06965144260902889, 0.10955468227621168, 0.02765947654552292, 0.08028719064895995, 0.0661047559697181, 0.0452349065017188, 0.021451938155223615, 0.02204953030741308, 0.053322991443565115, 0.009257371075364063, 0.04162177909165621, 0.03312185413960833, 0.09473402285948396, 0.057727040475583635, 0.03216795688786078, 0.02874211972084595, 0.02451143453072291, 0.018284746874996927, 0.07637271788553335, 0.019948812660004478, 0.009959455765056191, 0.045464523282134905, 0.03723804635228589, 0.03489907147013582, 0.11658145522233099, 0.09331692155683413, 0.049558117098058574, 0.015415139187098248, 0.02694412411074154, 0.0545787164446665, 0.05018579220632091, 0.02594099463749444, 0.0485284243040951, 0.0631741780671291, 0.05642523923597764, 0.008665711466164794, 0.03448599578405265, 0.03209409464034252, 0.017456497080274858, 0.018520399171393365, 0.028457574735512026, 0.08021849003853276, 0.055028517308528535, 0.011621697722148383, 0.03738509178219829, 0.026295518582628574, 0.013750606776739005, 0.022459557621914428, 0.18281163414940238, 0.10000353853683919, 0.12419001999660395, 0.25070018658880144, 20.267829336225986, 95.12614756822586, 71.30229994654655, 76.33066892623901, 60.823499634861946, 49.93242904543877, 23.916277661919594, 31.41055092215538, 78.8641069829464, 22.855602577328682, 0.47020235506352037, 7.497962862253189, 4.409922240301967, 1.2089427723549306, 0.17146042606327683, 9.553623106330633, 28.06876514106989, 42.71306723356247, 44.016321301460266, 33.971689492464066, 32.72629112005234, 70.02436012029648, 94.72251802682877, 80.70746406912804, 73.86264055967331, 74.85599085688591, 83.92783686518669, 80.66024020314217, 81.16639584302902, 70.36306634545326, 77.93324813246727, 80.52488386631012, 80.47180071473122, 78.3695787191391, 79.4409616291523, 73.47435459494591, 63.63316006958485, 57.27630637586117, 58.12075026333332, 57.202917113900185, 58.67223747074604, 56.24167509377003, 59.43415738642216, 62.127346470952034, 62.34734706580639, 57.3160370439291, 53.77918682992458, 54.53684717416763, 53.32984574139118, 52.58405975997448, 52.464122995734215, 54.600793942809105, 56.1932884901762, 57.7042356133461, 58.31445626914501, 58.41017313301563, 63.827987015247345, 67.6284746825695, 74.30789306759834, 61.6488229483366, 41.37341491878033, 69.68870133161545, 68.16430673003197, 67.64914557337761, 68.11076000332832, 67.57302045822144, 65.3290356695652, 68.95518109202385, 65.69117903709412, 61.09191343188286, 54.664619117975235, 53.08146446943283, 51.75356112420559, 51.030068546533585, 51.66590742766857, 52.0889463275671, 51.412521824240685, 57.06271983683109, 61.515396907925606, 65.13208463788033, 64.58552196621895, 61.60544067621231, 58.489376083016396, 56.14517167210579, 54.72689777612686, 54.84932720661163, 53.29286992549896, 56.22991472482681, 55.929981619119644, 56.90093591809273, 58.01230028271675, 59.59196671843529, 56.06576733291149, 62.555480897426605, 63.1315565854311, 64.1755847632885, 65.63646957278252, 70.47227248549461, 74.87600058317184, 74.85873430967331, 73.69424119591713, 67.47157350182533, 46.501479148864746, 27.714760936796665, 20.721500292420387, 13.072555381804705, 3.7455340661108494, 0.568530895980075, 0.3870252933120355, 1.97045634733513, 3.9360681921243668, 4.632984520867467, 2.8596234787255526, 0.22172641474753618, 3.6764174373820424, 61.15908622741699, 29.292884655296803, 39.34568032622337, 58.38495768606663, 49.07664276659489, 43.867171704769135, 63.691023364663124, 24.736528247594833, 0.6937360775191337, 0.013046727017353987, 0.06489094375865534, 0.06417940225219354, 0.06206967307662126, 0.08631572301965207, 0.060529167458298616, 0.06129374654847197, 0.048433436822961085, 0.04084811240318231, 0.06228699247003533, 0.06107000386691652, 0.03222296487365384, 0.02928411016910104, 0.06623499546549283, 0.05519517028005794, 0.015240100874507334, 0.00865590769535629, 0.026401154027553275, 0.045874860443291254, 0.04900470499705989, 0.04912765660264995, 0.021459443123603705, 0.02286412829562323, 0.12047528885887004, 0.13007582252612337, 0.09831891526118852, 0.19791110360529274, 0.1583049085456878, 0.1098685736360494, 0.15144130418775603, 0.10529436127399094, 0.07948525555548258, 0.09200713480822742, 0.11185746261617169, 0.16512502304976806, 0.11143128431285731, 0.22830126428743824, 0.14093191421125084, 0.12144528329372406, 0.21349161834223196, 0.146268772368785, 0.32246491697151214, 0.19163731369189918, 0.09372462780447677, 0.1170087764330674, 0.13255808386020362, 0.14608770317863673, 0.13459378009429201, 0.31551327905617654, 0.2865347871556878, 0.37921386247035116, 0.5834589886944741, 29.90022886544466, 110.52586242556572, 81.49227395653725, 85.063117146492, 64.64308127760887, 79.22492042183876, 42.834573313593864, 29.261173456907272, 80.25116175413132, 29.134737141430378, 0.9004953328985721, 22.212553583085537, 6.222346136346459, 0.6068302283529192, 0.4200261365622282, 10.049506947398186, 28.91566749662161, 43.87927025556564, 42.244377583265305, 35.540142729878426, 38.664794862270355, 80.91994106769562, 102.28018328547478, 87.79732882976532, 80.5806040763855, 83.12943130731583, 88.12230259180069, 85.0469908118248, 85.86140871047974, 75.51599264144897, 81.24828904867172, 85.80784678459167, 81.77392244338989, 80.5694554746151, 80.15554368495941, 76.7998905479908, 66.08103811740875, 59.76117163896561, 59.70795929431915, 61.232646480202675, 61.954258158802986, 62.00277015566826, 62.91804604232311, 65.87609991431236, 72.26694658398628, 62.278365567326546, 58.0905456840992, 57.280771136283875, 56.51942498981953, 56.88028022646904, 56.65629744529724, 56.83448128402233, 58.318943828344345, 58.928347527980804, 60.81786073744297, 61.4394161850214, 68.54737937450409, 69.94495198130608, 77.13054120540619, 62.441661804914474, 43.05842310190201, 71.2078370153904, 67.72275522351265, 71.09559863805771, 69.44101542234421, 68.4679788351059, 66.91440179944038, 69.87340942025185, 69.61069151759148, 62.58585646748543, 56.21617466211319, 57.30112664401531, 53.91128674149513, 53.31027679145336, 54.23405282199383, 53.44746842980385, 52.81479857861996, 60.853829607367516, 63.90690118074417, 68.1290066242218, 64.55185577273369, 63.70782986283302, 60.155199095606804, 58.219943940639496, 58.29327620565891, 56.81666024029255, 56.309547051787376, 59.52240765094757, 57.964145466685295, 59.75943133234978, 60.002287700772285, 61.620115488767624, 59.04098488390446, 65.3634162247181, 66.71194106340408, 65.46920254826546, 68.89110893011093, 73.87941285967827, 79.15783882141113, 79.27565529942513, 78.6682578921318, 69.79875862598419, 50.42589716613293, 30.67366786301136, 21.751792207360268, 15.614895410835743, 4.5081160962581635, 0.6993952800985426, 0.5218936235178262, 1.1909387446939945, 3.920018090866506, 13.687697723507881, 11.456268411129713, 1.7357017379254103, 4.77478863671422, 62.922567799687386, 33.13676409423351, 56.48323193192482, 66.37852415442467, 57.16582730412483, 52.62288607656956, 75.9998206794262, 38.938326984643936, 0.608889777213335, 0.13145418372005224, 0.2811625285539776, 0.15391283406643197, 0.17837310122558847, 0.13084773032460362, 0.13428662001388147, 0.18135102814994752, 0.133912562741898, 0.17110388347646222, 0.24201116611948237, 0.16226493433350697, 0.12928886397276074, 0.2623679651878774, 0.14673862606287003, 0.1102791668381542, 0.10251447645714507, 0.11281095168669708, 0.09642764096497558, 0.1745955547085032, 0.1642758131492883, 0.11967837068368681, 0.11928507694392465, 0.19601218518801033], [0.03397760978259612, 0.0468698578333715, 0.028825587214669213, 0.09601889571058564, 0.019714099180418998, 0.012765236897394061, 0.01939785150170792, 0.05983915936667472, 0.053131187087274157, 0.038392201022361405, 0.018979821979883127, 0.0031562274398311274, 0.05727686111640651, 0.05716273735743016, 0.04642832820536569, 0.03719323176483158, 0.04549297351331916, 0.020064689742866904, 0.05728580028517172, 0.023663716347073205, 0.045465209768735804, 0.03182837608619593, 0.05530919384909794, 0.03204310167348012, 0.12255265668500215, 0.12278842958039604, 0.034019949307548814, 0.04379209720354993, 0.045067129176459275, 0.6402566784527153, 55.60084328055382, 81.81110724806786, 33.3898039162159, 37.81270958483219, 60.25798738002777, 58.15994136035442, 15.067513883113861, 48.141953721642494, 30.28607726097107, 0.7693410362116992, 9.850279837846756, 0.9216934454161674, 0.6518535374198109, 0.2584211644716561, 0.316153010353446, 1.5759128308854997, 11.72309199348092, 21.68892078101635, 23.29885259270668, 50.18478870391846, 73.64013969898224, 82.16163843870163, 76.3671013712883, 75.79692676663399, 77.2233322262764, 80.23688971996307, 78.1820359826088, 80.33040270209312, 74.16107654571533, 75.61758399009705, 76.54445305466652, 75.90178593993187, 76.07192561030388, 77.78296619653702, 67.78331637382507, 60.911438316106796, 57.61841341853142, 52.463393434882164, 49.84280705451965, 53.14404331147671, 54.893378242850304, 60.89753486216068, 64.40449208021164, 67.85797476768494, 66.97326064109802, 62.651307955384254, 52.71474614739418, 50.53633823990822, 50.37421993911266, 50.21264500916004, 48.29212546348572, 51.28993660211563, 54.56895165145397, 56.02694861590862, 55.63430428504944, 61.100527569651604, 61.51192769408226, 66.57760307192802, 59.75657768547535, 35.583764389157295, 65.81808462738991, 63.510799035429955, 63.30397993326187, 64.41314041614532, 64.69245582818985, 62.208023741841316, 62.629519924521446, 61.01176053285599, 57.58433684706688, 51.86056338250637, 47.19112694263458, 50.6610057502985, 48.26260484755039, 50.81049732863903, 50.01465663313866, 55.24268589913845, 64.25781235098839, 67.6945911347866, 69.4861949980259, 65.60677796602249, 59.74327079951763, 57.818966656923294, 52.7120178937912, 50.239118188619614, 47.52438805997372, 48.69170442223549, 48.508911430835724, 52.35461667180061, 52.48630240559578, 56.05734698474407, 56.65618725121021, 57.24448308348656, 58.74355584383011, 60.56691840291023, 62.58062034845352, 66.18171751499176, 65.38917884230614, 69.45699736475945, 75.7502880692482, 72.35523864626884, 53.676079362630844, 32.733997106552124, 8.72785521671176, 8.833151366561651, 1.1622359161265194, 0.36830782424658537, 0.1434495611465536, 0.39383164839819074, 1.0034478991292417, 5.521908346563578, 3.1440802523866296, 1.0585266561247408, 0.2458228069008328, 12.818111535161734, 44.786406978964806, 20.540941581130028, 64.96479481458664, 26.55545834451914, 33.88824597001076, 47.590971887111664, 46.80914103984833, 1.4768096362240613, 0.2176265386515297, 0.1194148043578025, 0.004116781292395899, 0.12534017820144072, 0.04534366824373137, 0.01387587017234182, 0.04967738765117247, 0.0785935131716542, 0.032319358724635094, 0.0209275032102596, 0.025485870719421655, 0.04574064674670808, 0.057315942613058724, 0.04848677868722007, 0.055523385090054944, 0.024353396038350184, 0.029480898047040682, 0.04646372122806497, 0.018206984641437884, 0.029367143506533466, 0.09195620863465592, 0.008998283610708313, 0.09689979531685822, 0.04976353244273923, 0.0534368851367617, 0.05421070025477093, 0.01700509132206207, 0.04654557640606072, 0.027748370994231664, 0.08799466144409962, 0.03499823353195097, 0.0348285859945463, 0.028688866914308164, 0.02626060610054992, 0.06647867223364301, 0.031487503947573714, 0.042930181734845974, 0.05516394812730141, 0.06352621581754647, 0.029284197371453047, 0.02028589056862984, 0.06831697202869691, 0.03686196301714517, 0.025556987020536326, 0.016959263703029137, 0.025846005300991237, 0.003061129564230214, 0.05732625846576411, 0.08802216543699615, 0.06646254536462948, 0.024226535169873387, 0.11014686417183839, 0.030012824972800445, 0.5113307840656489, 60.93294516205788, 91.98935508728027, 37.61026784777641, 42.15503677725792, 70.91150611639023, 44.844562858343124, 18.247225061058998, 60.86095802485943, 33.017887473106384, 0.4685647616861388, 5.692570013925433, 3.1361315539106727, 2.0242468547075987, 1.638448687735945, 0.5731855274643749, 2.3953171307221055, 11.777907852083445, 23.577504940330982, 26.233028545975685, 51.48704722523689, 79.04135227203369, 90.02087071537971, 80.0481690466404, 80.75761377811432, 82.00982138514519, 84.42558735609055, 83.52495968341827, 85.34133061766624, 74.25765976309776, 77.87053629755974, 78.9023557305336, 80.1540769636631, 78.12808647751808, 78.96848738193512, 68.51204887032509, 65.55446237325668, 60.76637350022793, 58.74219171702862, 54.441544488072395, 56.59479774534702, 57.54633128643036, 63.647967875003815, 66.18135273456573, 71.08166858553886, 70.93929782509804, 64.70669746398926, 56.34536013007164, 55.02779223024845, 54.56409931182861, 54.8205703496933, 51.78734891116619, 56.10356770455837, 57.6785983890295, 58.364005610346794, 58.63458149135113, 62.153527066111565, 64.05508562922478, 71.90245494246483, 63.946829438209534, 38.53619076311588, 69.38215658068657, 69.68799456954002, 66.74332737922668, 68.9534255862236, 67.74810746312141, 65.64139410853386, 65.63934221863747, 65.55795058608055, 60.15359938144684, 54.966721907258034, 49.51876804232597, 54.51587989926338, 50.83001688122749, 53.38574834167957, 51.03758454322815, 56.03690408170223, 66.31987050175667, 71.10241547226906, 71.93318009376526, 69.35790628194809, 64.78919103741646, 63.74645859003067, 58.373919278383255, 56.43107213079929, 53.46576064825058, 56.33488409221172, 53.57655130326748, 58.042702451348305, 57.75886528193951, 61.15273676812649, 60.520348101854324, 61.11717067658901, 62.10988260805607, 63.36079828441143, 66.05548828840256, 69.24099415540695, 70.5205374956131, 74.87293794751167, 79.33350339531898, 77.5520221889019, 56.70309193432331, 35.321054086089134, 9.619729109108448, 8.059323839843273, 1.2005713465623558, 0.781744698761031, 0.43445740593597293, 2.122686984948814, 3.676512432284653, 8.379816692322493, 3.7730106292292476, 0.8958368422463536, 0.16867214755620807, 16.57028954476118, 53.01162041723728, 18.463032580912113, 71.2115228176117, 37.22966127097607, 35.95474228262901, 53.95609773695469, 54.7996486723423, 2.391906576231122, 0.26309111388400197, 0.02759224909823388, 0.025543149677105248, 0.13623662787722424, 0.027696146062226035, 0.04630414092389401, 0.08446505162282847, 0.06447063584346324, 0.07389847174636088, 0.013745000778726535, 0.03743904220755212, 0.06396953031071462, 0.07293393951840699, 0.034652162648853846, 0.015057308974064654, 0.05168143870832864, 0.014700227402499877, 0.049475137566332705, 0.05279864926706068, 0.022527367655129638, 0.018722829227044713, 0.03687420474307146, 0.04241157635988202, 0.014923073940735776, 0.17287163471337408, 0.09354663110570982, 0.08133876937790774, 0.13771982485195622, 0.19435505848377943, 0.22934018197702244, 0.08585892370319925, 0.1296903658658266, 0.14368721167556942, 0.13379104348132387, 0.17578443075763062, 0.2363175427308306, 0.12570510705700144, 0.13131250772858039, 0.11814530880656093, 0.15993145876564085, 0.21171080530621111, 0.21826545358635485, 0.13510256685549393, 0.10041143032140099, 0.07495324171031825, 0.0875754444859922, 0.2816000988241285, 0.181075201544445, 0.15041601232951507, 0.17432999942684546, 0.12930069380672649, 0.151338308933191, 0.06257906468817964, 0.8769683015998453, 82.7153979241848, 100.96658617258072, 52.63558119535446, 54.30075824260712, 85.87463200092316, 84.86398503184319, 20.763755924999714, 62.187390848994255, 36.57894618809223, 0.7406780461315066, 21.28285937011242, 6.165877841413021, 1.1769476579502225, 0.6427413888741285, 1.032405907753855, 2.9937515314668417, 10.242161359637976, 24.918428286910057, 29.118886291980743, 58.49467299878597, 86.59509614109993, 98.41083571314812, 87.52598538994789, 87.50314101576805, 89.25949037075043, 90.87962463498116, 87.3532086610794, 88.88055950403214, 78.24477061629295, 82.98463627696037, 81.0185381770134, 82.33978807926178, 80.44979989528656, 82.95923084020615, 69.42809611558914, 68.0822691321373, 64.59996119141579, 62.132749781012535, 58.50032329559326, 62.18388743698597, 61.46522060036659, 65.59271112084389, 70.59661701321602, 76.1173939704895, 75.1913532614708, 70.71075528860092, 60.495353043079376, 59.5608501881361, 57.88613565266132, 59.960166960954666, 54.87248696386814, 58.572751209139824, 59.589975625276566, 61.558786779642105, 60.47100394964218, 67.16555312275887, 67.7411462366581, 75.22210121154785, 66.31797060370445, 41.221502870321274, 71.00307360291481, 71.25761434435844, 69.55523729324341, 68.76364096999168, 69.36548307538033, 67.63433396816254, 66.89224898815155, 65.72845503687859, 63.18526290357113, 57.44054116308689, 52.44305692613125, 56.40987306833267, 52.99403116106987, 55.10303199291229, 53.09063717722893, 59.466603845357895, 68.35889428853989, 72.30492934584618, 73.05658221244812, 70.99659115076065, 66.87095493078232, 64.33169558644295, 60.53912669420242, 58.99750001728535, 57.20472201704979, 59.13061447441578, 56.333994939923286, 61.75276257097721, 61.54591307044029, 66.06741204857826, 63.88047739863396, 62.876381278038025, 65.31939178705215, 66.43273204565048, 67.87437468767166, 70.81925466656685, 71.38902649283409, 78.44758093357086, 81.58482179045677, 79.82049286365509, 56.471102982759476, 36.83026850223541, 9.957418888807297, 9.912943225353956, 1.6580046946182847, 0.5433014966547489, 0.42061727202963084, 1.7983426828868687, 4.6062239818274975, 16.963507644832134, 9.6906903013587, 2.9013271909207106, 0.7046695752069354, 17.797874473035336, 60.88591888546944, 31.464109048247337, 84.1772098839283, 39.863622933626175, 46.2235164642334, 58.834834545850754, 73.66224691271782, 4.4560394156724215, 0.517739140195772, 0.20951297949068248, 0.11848847789224237, 0.16960104927420616, 0.1475502090761438, 0.18199663725681603, 0.18684949638554826, 0.22319739597151056, 0.11223221750697121, 0.12270407707546838, 0.16215649171499535, 0.15290513110812753, 0.1612528378609568, 0.08575572806876153, 0.10628354764776304, 0.10622337431414053, 0.13446013414068148, 0.20293688314268366, 0.1391435757977888, 0.09823518616030924, 0.10918452870100737, 0.2750294201541692, 0.2385109305032529, 0.08736747244256549], [0.10521080286707729, 0.15791749261552468, 0.03746789319848176, 0.036184081618557684, 0.0733796066197101, 0.02760447227046825, 0.026483088986424264, 0.04233884217683226, 0.00897724557944457, 0.03643352858489379, 0.025098853693634737, 0.023823643605282996, 0.007686271346756257, 0.02233221435744781, 0.03978278167778626, 0.05678801586327609, 0.09932214306900278, 0.029221491458883975, 0.04210796374536585, 0.0156172362039797, 0.08377285048482008, 0.04995390074327588, 0.15507537871599197, 0.041806284425547346, 0.06869776058010757, 0.025871941506920848, 0.017732219785102643, 0.08376604499062523, 0.07677404908463359, 0.14211900910595432, 4.64578365907073, 84.63405936956406, 81.2215992808342, 46.364523097872734, 55.0751718878746, 77.34614163637161, 25.04986323416233, 28.36868304759264, 32.47661031782627, 1.2340181018225849, 3.8470964413136244, 4.96787385083735, 3.5179578652605414, 0.7780150207690895, 1.0773792257532477, 0.11100523217464797, 2.8561274288222194, 11.311009805649519, 25.653819926083088, 56.95381388068199, 74.80562835931778, 80.3573888540268, 77.44759619235992, 81.49836882948875, 75.80823495984077, 79.32677775621414, 79.64534506201744, 81.49375587701797, 73.2324367761612, 78.63736554980278, 77.39992395043373, 78.16435933113098, 75.37277072668076, 75.8614169061184, 66.55966803431511, 58.69580760598183, 56.60324849188328, 51.860491186380386, 50.53981505334377, 54.50825370848179, 59.21366661787033, 66.97165712714195, 70.43402373790741, 70.46135187149048, 71.81295454502106, 66.81291684508324, 64.64171335101128, 54.492412358522415, 50.01569777727127, 51.55311048030853, 49.617049768567085, 52.83720977604389, 50.70853739976883, 54.376184195280075, 57.045400366187096, 66.35463103652, 64.43479165434837, 70.54940834641457, 60.22554092109203, 27.618540599942207, 67.8389073908329, 64.59249839186668, 63.79434362053871, 60.1778344810009, 59.74466912448406, 57.710277289152145, 58.562085181474686, 55.752751529216766, 52.068370431661606, 50.44917091727257, 48.52813459932804, 47.79798857867718, 50.0965878367424, 50.67525498569012, 57.00169891119003, 66.24175429344177, 67.69716739654541, 65.62503978610039, 69.05297264456749, 63.976209461688995, 66.65258064866066, 57.28812374174595, 56.515420004725456, 49.93547648191452, 48.60717415809631, 47.0827529579401, 49.437330812215805, 48.47031690180302, 48.469294756650925, 46.91378362476826, 51.7347901314497, 54.38672862946987, 55.441384837031364, 57.67876178026199, 60.24621561169624, 61.77458859980106, 69.79776307940483, 74.12326097488403, 73.28616589307785, 65.80572009086609, 43.24318438768387, 14.874477591365576, 2.3635938204824924, 0.9831001097336411, 0.4643089009914547, 0.1593259404762648, 1.2629770603962243, 2.094440250657499, 4.761351132765412, 4.764218078926206, 1.0248586814850569, 1.07962466776371, 0.1639830507338047, 14.706838186830282, 28.905235156416893, 47.6452861726284, 41.546108052134514, 35.85115984082222, 46.93128168582916, 64.0397572517395, 16.540827825665474, 0.37247922853566706, 0.08861669251928106, 0.1224058005027473, 0.05856788637174759, 0.055956628639250994, 0.03444751171628013, 0.07378913112916052, 0.02785144046356436, 0.08577024447731674, 0.07501656917156652, 0.0662780251877848, 0.04327976668719202, 0.07607335777720436, 0.031361798974103294, 0.011309632973279804, 0.061638147599296644, 0.08870261095580645, 0.0388150767685147, 0.057380702419322915, 0.04489806051424239, 0.05621347852866165, 0.027843464231409598, 0.04675609772675671, 0.0712313933763653, 0.05324028279574122, 0.06841443086159416, 0.07399270223686472, 0.060186580958543345, 0.04014785896288231, 0.07382390074781142, 0.07379076385404915, 0.03748399038158823, 0.061316459978115745, 0.01713274628855288, 0.014903580504324054, 0.024397900779149495, 0.0022921356230654055, 0.06295038343523629, 0.06234780405065976, 0.012697822057816666, 0.038846996540087275, 0.05198717386520002, 0.04732231187517755, 0.012278468730073655, 0.041251636648667045, 0.06552674167323858, 0.023794232292857487, 0.04642065439838916, 0.07443407230312005, 0.13425665209069848, 0.05742095650930423, 0.00186340386790107, 0.10511459826375358, 0.07460601307684556, 0.3530599846271798, 5.048484625294805, 91.28420412540436, 86.59182831645012, 42.14907489717007, 68.68300169706345, 75.37720888853073, 20.896243415772915, 42.52721540629864, 35.79170823097229, 0.5169205216225237, 2.3309492971748114, 1.5085327089764178, 5.434650778770447, 4.875741144642234, 4.015392260625958, 0.14628511446062475, 3.084196890704334, 12.68307913094759, 25.653339251875877, 54.74131800234318, 76.56535193324089, 86.77532806992531, 82.791887819767, 84.72743555903435, 84.90868583321571, 86.59693524241447, 82.68404960632324, 85.54470330476761, 78.97461265325546, 81.78727492690086, 79.49672743678093, 80.65899387001991, 82.05314666032791, 80.19829139113426, 73.13907578587532, 63.32068383693695, 60.673168301582336, 56.51617996394634, 56.93593204021454, 59.807236567139626, 60.62038913369179, 69.23426851630211, 72.81590312719345, 75.32583564519882, 73.62259984016418, 71.17100179195404, 67.08878964185715, 56.868717446923256, 53.35662290453911, 53.36958020925522, 54.72505487501621, 55.61587527394295, 55.43453760445118, 59.36090871691704, 60.311792492866516, 69.17376816272736, 67.87724733352661, 73.3133116364479, 62.56358586251736, 30.624808184802532, 72.56361946463585, 68.82780432701111, 66.882004737854, 63.52246440947056, 63.47373582422733, 62.190426886081696, 62.82854184508324, 59.119823053479195, 54.58017624914646, 54.078701958060265, 50.68159684538841, 51.14253111183643, 52.33764298260212, 53.73361587524414, 59.981191232800484, 68.35162907838821, 71.82005256414413, 70.74748411774635, 73.39480206370354, 69.83679458498955, 69.35184940695763, 63.34960788488388, 63.48255895078182, 58.485937267541885, 55.43371684849262, 52.390137165784836, 55.92678219079971, 57.296791076660156, 56.764090061187744, 56.042231395840645, 60.74243478477001, 60.717983096838, 63.60566094517708, 62.52417057752609, 64.17757585644722, 66.75815418362617, 73.36090788245201, 77.80625894665718, 77.35181093215942, 68.91760870814323, 45.366920828819275, 16.260402873158455, 2.5964745366945863, 1.9757792679592967, 1.201430931687355, 2.0195560064166784, 3.7224512547254562, 5.352326296269894, 6.090783895924687, 3.9963130094110966, 1.88755726441741, 0.6763376423623413, 0.1132649159990251, 17.18085028231144, 32.41215817630291, 52.84717284142971, 56.062640100717545, 39.09467339515686, 50.61352349817753, 75.19035011529922, 15.142615903168917, 0.3798515454400331, 0.0327852345071733, 0.05046287304139696, 0.023789855476934463, 0.059778974900837056, 0.030235137164709158, 0.04023981106001884, 0.057268263335572556, 0.06566895943251438, 0.03727210350916721, 0.053902757208561525, 0.0647770389332436, 0.08511230829753913, 0.022577659292437602, 0.07471231831004843, 0.05442820147436578, 0.035920589507441036, 0.044119759113527834, 0.006117372086009709, 0.03476991922070738, 0.03670334379421547, 0.0431981935253134, 0.03307391511043534, 0.07849356814404018, 0.05887552513740957, 0.22103298164438456, 0.3010850673308596, 0.10315055638784543, 0.09790464842808433, 0.17089514702092856, 0.16401787230279297, 0.10219504867563955, 0.0988971818878781, 0.07572064467240125, 0.10691506337025203, 0.1061399420723319, 0.10185114486375824, 0.16010244959034026, 0.12866535602370277, 0.13199893495766446, 0.14233029854949564, 0.24050230567809194, 0.13570125738624483, 0.18188800167990848, 0.1332218904281035, 0.13119602022925392, 0.1817339615081437, 0.16879620496183634, 0.12763927748892456, 0.18313675420358777, 0.1609966336400248, 0.17143200180726126, 0.15694553148932755, 0.12480710836825892, 0.6454527215100825, 10.276027042418718, 114.33582678437233, 96.07823207974434, 66.19246333837509, 74.15137186646461, 106.33401095867157, 35.005823001265526, 44.63044434785843, 38.50684113800526, 1.4109633257612586, 7.351882550865412, 18.490011133253574, 10.816094912588596, 2.4486605683341622, 2.9003171576187015, 0.17254712322028354, 4.796905349940062, 10.992938373237848, 29.825500175356865, 61.872106567025185, 81.4749164879322, 95.43313309550285, 89.16453346610069, 90.87399333715439, 91.42947793006897, 95.28729692101479, 88.32555368542671, 90.39891242980957, 81.33276611566544, 84.42543536424637, 79.65787678956985, 81.61226391792297, 81.77427962422371, 81.7036946117878, 74.84973639249802, 66.3779465854168, 63.16854000091553, 60.171690210700035, 60.17434246838093, 63.81612405180931, 65.40720507502556, 72.40040302276611, 76.19544938206673, 78.98823112249374, 77.6833963394165, 74.9443057179451, 73.31320524215698, 63.0262566357851, 58.14085878431797, 57.08426848053932, 57.94942885637283, 59.637036100029945, 56.269972175359726, 60.21962083876133, 63.37925009429455, 72.8990350663662, 72.05259248614311, 76.84530571103096, 63.96422490477562, 32.89659798145294, 73.61954480409622, 70.55238738656044, 67.55648374557495, 66.02446675300598, 65.08246690034866, 63.504685163497925, 63.63088019192219, 61.09739273786545, 55.04108011722565, 57.361068427562714, 52.33194328844547, 53.38567994534969, 54.39487159252167, 56.52316398918629, 62.185650542378426, 70.34977465867996, 75.00897824764252, 72.93415278196335, 74.5164866745472, 70.15999764204025, 72.5333958864212, 66.79150879383087, 67.09619164466858, 59.68698441982269, 58.59550818800926, 56.28903575241566, 59.35957498848438, 61.81092984974384, 60.963385328650475, 58.82382273674011, 64.44970965385437, 65.70918247103691, 65.43546035885811, 65.63342213630676, 66.56133994460106, 68.65006506443024, 74.14034485816956, 79.66758906841278, 76.81588008999825, 71.03673219680786, 46.71441212296486, 17.784343399107456, 3.5378782963380218, 1.4597636321559548, 1.0399303352460265, 1.3490878022275865, 2.7376595232635736, 6.344023682177067, 13.58237212523818, 16.12123914062977, 5.3545197285711765, 3.9950937498360872, 0.23905298032332212, 21.90854139626026, 46.52198664844036, 64.71041366457939, 59.533799439668655, 52.397098392248154, 60.88547430932522, 86.30398616194725, 28.954186029732227, 0.7868748984765261, 0.3078115970129147, 0.21506243327166885, 0.17157352936919779, 0.11177824577316642, 0.09804749701288529, 0.17564478825079277, 0.16931468417169526, 0.23745414189761505, 0.13489369681337848, 0.14168483787216246, 0.18417846236843616, 0.21157497743843123, 0.12428868853021413, 0.12472155358409509, 0.10734811396105215, 0.1191681664204225, 0.15041722945170477, 0.15113550965907052, 0.1615000917809084, 0.13179836212657392, 0.18384241790045053, 0.11865932028740644, 0.16686895134625956, 0.16113260993734002], [0.11864670377690345, 0.04822088572836947, 0.05358480630093254, 0.07312360277865082, 0.023136845302360598, 0.07874804316088557, 0.04053991702676285, 0.11763661110308021, 0.01281938955798978, 0.019387264765100554, 0.035957607833552174, 0.041120194873656146, 0.02333884491235949, 0.032664034370100126, 0.040226174096460454, 0.0229467534518335, 0.07295506846276112, 0.031275524306693114, 0.03738573373993859, 0.058432637379155494, 0.0407238880143268, 0.07331084663746879, 0.006315191085377592, 0.028626300154428463, 0.04472440166864544, 0.016556275659240782, 0.06642488137003966, 0.09347930346848443, 0.03882043878547847, 0.14408733317395672, 0.9451776696369052, 23.93588460981846, 88.69579821825027, 63.78151550889015, 36.41337387263775, 72.7711871266365, 59.3383227288723, 21.497785337269306, 34.611381366848946, 1.467225719243288, 0.7749418169260025, 1.673303742427379, 4.273711424320936, 11.976352203637362, 0.2759267360670492, 1.0222332598641515, 0.5502436053939164, 4.753144048154354, 17.65774369239807, 45.27618169784546, 63.91941010951996, 85.37268653512001, 81.66552945971489, 78.26440036296844, 80.50278425216675, 77.66372099518776, 75.89376837015152, 82.21000984311104, 80.67335709929466, 82.32943743467331, 72.05839097499847, 77.23660871386528, 74.74684551358223, 75.88608518242836, 64.76294204592705, 61.41174226999283, 55.49837797880173, 49.805531054735184, 52.56436161696911, 55.51273360848427, 60.92419043183327, 69.28703248500824, 72.8464762866497, 72.74981707334518, 73.80254298448563, 72.03451305627823, 70.36682054400444, 67.2893276810646, 59.17721897363663, 51.549527272582054, 50.486462116241455, 53.51754426956177, 51.38076692819595, 56.01693615317345, 61.83930292725563, 66.29539981484413, 63.34938369691372, 71.21146962046623, 54.845307022333145, 22.130546383559704, 65.83597406744957, 66.3732348382473, 65.33659726381302, 61.42493136227131, 57.119659781455994, 54.59742732346058, 52.068009451031685, 52.23642401397228, 51.12627938389778, 50.36028228700161, 49.47946295142174, 50.22850915789604, 49.482726976275444, 57.1597970277071, 66.97893753647804, 69.04315397143364, 67.87151724100113, 67.35203951597214, 67.45463401079178, 65.70466831326485, 62.6633495092392, 59.42794091999531, 54.17197175323963, 49.88244652748108, 47.004009783267975, 46.25213272869587, 44.44906868040562, 44.554729610681534, 41.37408748269081, 42.395712062716484, 47.72388115525246, 56.300499737262726, 55.58996446430683, 57.61199936270714, 60.998655036091805, 67.30163142085075, 68.22089329361916, 73.01049068570137, 75.51842451095581, 61.56806208193302, 24.88426622003317, 7.368663875386119, 0.30195798142813146, 0.6622873619198799, 1.5067396801896393, 2.5134470919147134, 1.5235378663055599, 4.877514224499464, 3.449387694709003, 4.058584067970514, 1.6270012082532048, 0.3208926919614896, 0.21345917164580896, 14.580439869314432, 35.1909376680851, 35.902050510048866, 33.576115518808365, 36.92343570291996, 66.67826727032661, 41.177600026130676, 0.7004823780152947, 0.17897814454045147, 0.003511746558615414, 0.045830220260540955, 0.09282652521505952, 0.045431070975610055, 0.06536536908242851, 0.03985293318692129, 0.062152340906322934, 0.04248582823493052, 0.035969886666862294, 0.09202884262776934, 0.007647111460755696, 0.024987167889776174, 0.0519488233840093, 0.02823047383571975, 0.00794832369138021, 0.04347064335888717, 0.04602284469001461, 0.07626433463883586, 0.0631757959490642, 0.03239475721784402, 0.06538544417708181, 0.08902720408514142, 0.004805998996744165, 0.05082933814264834, 0.07588203210616484, 0.024129089324560482, 0.03938191061024554, 0.05147502146428451, 0.02792719518765807, 0.06750622764229774, 0.023241836934175808, 0.04912128897558432, 0.04849967721384019, 0.010186585423070937, 0.03571876615751535, 0.025331724791612942, 0.024853232498571742, 0.07077215981553309, 0.05695375599316321, 0.015409885709232185, 0.030378308583749458, 0.021034853016317356, 0.00609174758210429, 0.04184614517726004, 0.005001678291591816, 0.031153767558862455, 0.022805068183515687, 0.030682127144245896, 0.06246451419428922, 0.009627316849218914, 0.12411834337399341, 0.04224283424264286, 0.047071725712157786, 0.15017763449577615, 0.6678021722473204, 24.999909214675426, 100.61812207102776, 65.31135141849518, 37.72486209869385, 84.94691178202629, 50.33121004700661, 26.152714155614376, 45.079325661063194, 1.756816254928708, 0.7913894124794751, 1.716788134071976, 5.626193275675178, 9.94724778458476, 4.159953603520989, 2.542867725715041, 0.6184890714939684, 4.821048304438591, 18.947514183819294, 47.27669455111027, 68.81794765591621, 89.36479032039642, 86.81427597999573, 87.52138003706932, 84.62947681546211, 83.07336151599884, 83.42283636331558, 88.6265355348587, 81.94803670048714, 85.65887957811356, 78.31692114472389, 81.52009606361389, 78.02995294332504, 78.41687858104706, 67.63658344745636, 65.54233342409134, 60.61490222811699, 56.21876612305641, 55.46510696411133, 57.51287408173084, 62.8522639721632, 73.09837237000465, 76.78726762533188, 77.7898134291172, 78.12022849917412, 77.14530721306801, 74.61007565259933, 69.69547256827354, 58.77712704241276, 55.180091857910156, 54.403831511735916, 55.68258449435234, 55.1249036192894, 57.517532631754875, 64.9876619875431, 69.58628922700882, 65.83149030804634, 75.69903641939163, 58.01622547209263, 24.08416025340557, 70.2442467212677, 72.20677301287651, 68.11678647994995, 64.87372890114784, 61.6558563709259, 58.343023136258125, 56.1396087706089, 54.66890908777714, 53.54265712201595, 52.167275324463844, 52.2345507144928, 54.410226568579674, 52.097070291638374, 60.51025964319706, 67.5837054848671, 71.26808658242226, 69.38205018639565, 72.11805537343025, 70.52081108093262, 68.01625907421112, 68.96018922328949, 65.72334051132202, 60.40916606783867, 57.42971554398537, 54.98056076467037, 54.65938299894333, 53.78302462399006, 54.3273264169693, 51.52354806661606, 52.41470284759998, 56.96736015379429, 61.94990739226341, 60.209232196211815, 64.66109231114388, 65.67481711506844, 72.8824907541275, 71.63941785693169, 78.00023853778839, 77.13767722249031, 62.31232814490795, 25.944513827562332, 8.727187402546406, 0.5149464088026434, 2.7758063888177276, 2.656522002071142, 4.88485780544579, 4.5320529118180275, 8.439843971282244, 5.264969933778048, 4.5582192577421665, 0.6369612459093332, 0.23479257768485695, 0.3777961229206994, 19.298486150801182, 45.310573652386665, 40.34313440322876, 39.46166530251503, 33.76790642738342, 77.6291124522686, 39.0346822142601, 1.0323601914569736, 0.24768028379185125, 0.008497546368744224, 0.03639374204794876, 0.056782883912092075, 0.03556787640263792, 0.03841317411570344, 0.04885679125436582, 0.0447582732886076, 0.07466600829502568, 0.056906110112322494, 0.08102129344479181, 0.03098208282608539, 0.020918703194183763, 0.051909545218222775, 0.04251742888300214, 0.0818841737054754, 0.06759550058632158, 0.07751943252515048, 0.03625323122832924, 0.09844614163739607, 0.03651668623206206, 0.0067726889483310515, 0.0766842121083755, 0.014861299423500896, 0.0212551447111764, 0.2667678619036451, 0.13895119627704844, 0.11255401273956522, 0.13607448345283046, 0.1272285432787612, 0.13898211414925754, 0.08246333090937696, 0.16451218718430027, 0.09512814780464396, 0.08860987960360944, 0.20537387346848845, 0.12742316408548504, 0.22798032994614914, 0.11434442916652188, 0.15033311443403363, 0.24391995510086417, 0.19609871960710734, 0.2139843747136183, 0.11250799958361313, 0.118486169812968, 0.1703188248211518, 0.17118976480560377, 0.14932164136553183, 0.1030375569825992, 0.16425283625721931, 0.10582965755020268, 0.24323832214577124, 0.16938012675382197, 0.17844516376499087, 0.32348293578252196, 1.173970161471516, 41.41267441213131, 111.50971323251724, 80.99086046218872, 53.5663678497076, 94.53198865056038, 82.82100945711136, 33.75624105334282, 47.559475377202034, 2.3617915296927094, 2.5281154923141003, 5.092811146751046, 20.431710742413998, 23.886299170553684, 3.719190079718828, 1.9237735960632563, 0.5783448193687946, 6.602787422016263, 21.307554244995117, 49.846276268363, 69.92950201034546, 92.54665598273277, 91.00926607847214, 91.85041174292564, 89.10359233617783, 88.03578123450279, 90.89488461613655, 91.21244117617607, 87.4793390929699, 86.99820131063461, 80.87535426020622, 83.02280142903328, 79.15696486830711, 80.78741177916527, 69.93264824151993, 71.53329715132713, 66.65095433592796, 61.161267310380936, 61.95928908884525, 62.67623081803322, 67.10618510842323, 75.54192245006561, 79.22238975763321, 81.97705194354057, 81.75053849816322, 79.35908362269402, 76.68287962675095, 74.10740822553635, 63.21389436721802, 58.736427426338196, 56.43701881170273, 58.80248688161373, 58.15118283033371, 61.1140738427639, 67.03972667455673, 71.37809067964554, 67.64739006757736, 77.47640624642372, 59.533765241503716, 27.72640161216259, 71.90965935587883, 73.64077806472778, 70.41594430804253, 69.78764802217484, 63.538275361061096, 60.418175384402275, 56.144233122467995, 56.41646571457386, 55.11726602911949, 55.47409348189831, 56.4308175444603, 57.87672355771065, 55.590139254927635, 62.90087476372719, 71.42622649669647, 71.67740821838379, 70.72043716907501, 72.43920654058456, 71.00213885307312, 68.41208383440971, 71.43668353557587, 69.70254018902779, 64.87286254763603, 60.02536006271839, 60.81169746816158, 61.061914041638374, 59.217253625392914, 60.92397764325142, 59.19570118188858, 59.93063114583492, 62.50199116766453, 67.11431667208672, 63.27616162598133, 66.09861597418785, 68.60230922698975, 74.31759774684906, 73.72571110725403, 80.12925669550896, 79.2482815682888, 66.9596041738987, 26.86893582344055, 8.278530277311802, 0.5403899028897285, 1.817995347082615, 2.1235255524516106, 6.08051304705441, 4.796338705345988, 13.84707922115922, 15.5855961330235, 9.969896469265223, 5.23740098811686, 0.8738443942274898, 0.7450418744701892, 27.925788313150406, 50.47215208411217, 50.399682372808456, 50.935510620474815, 47.74044826626778, 83.24432954192162, 62.570512890815735, 1.504506825003773, 0.4306341876508668, 0.12201314500998706, 0.11175400723004714, 0.1985089184017852, 0.2043881974532269, 0.1514411112293601, 0.20250685309292749, 0.1723331620451063, 0.12328267766861245, 0.10988223657477647, 0.18727182294242084, 0.09497886479948647, 0.11948743835091591, 0.13663130201166496, 0.1510082313325256, 0.2000886687892489, 0.1262682635569945, 0.12081715918611735, 0.27946710702963173, 0.2406796789728105, 0.09383095530210994, 0.15535013662884012, 0.16882183874258772, 0.0908513214380946, 0.16225749801378697], [0.011277645480731735, 0.024631337764731143, 0.07594773443997838, 0.022728877447661944, 0.028925637998327147, 0.05041251832153648, 0.017824277638283093, 0.05872035319043789, 0.05743048939621076, 0.08288760931463912, 0.027993021831207443, 0.022091571117925923, 0.01802654813218396, 0.02826567018928472, 0.04514574487984646, 0.07572684160550125, 0.07179557404015213, 0.03080829410464503, 0.04367812187410891, 0.05134087456099223, 0.05381985931308009, 0.0196344017967931, 0.03354044398292899, 0.009684678370831534, 0.04160126612987369, 0.03787843445024919, 0.04859945154748857, 0.027261039722361602, 0.08602350237197243, 0.025990892936533783, 0.16708271956304088, 0.6693930993787944, 59.4100970774889, 86.7370793223381, 54.475415870547295, 44.71154719591141, 87.80225336551666, 39.74896788597107, 32.08077795803547, 3.7955602817237377, 0.20316001726314425, 1.296067584771663, 3.017956707626581, 8.845368660986423, 9.347385372966528, 2.526459018699825, 0.891274712048471, 0.698902434669435, 4.162246780470014, 23.618409745395184, 50.98071679472923, 65.00290676951408, 67.44168430566788, 71.03870809078217, 64.76422637701035, 68.30585673451424, 78.7634351849556, 78.19239422678947, 84.58414524793625, 77.37995222210884, 72.04439252614975, 64.40569281578064, 72.2055646777153, 67.34199285507202, 58.000315725803375, 51.79825812578201, 52.57414609193802, 51.744905188679695, 51.60330958664417, 56.91816799342632, 61.44150227308273, 73.39249938726425, 75.00380292534828, 74.96923997998238, 71.27958476543427, 69.68670263886452, 71.01571932435036, 73.80023270845413, 62.54373952746391, 57.04498998820782, 50.69229707121849, 52.49744340777397, 50.52458547055721, 58.11455279588699, 65.75553998351097, 71.85893207788467, 67.07857578992844, 70.43584764003754, 54.11386527121067, 21.574421525001526, 67.13232770562172, 64.16258946061134, 66.22341647744179, 63.91826257109642, 59.301179721951485, 52.52247266471386, 51.25006154179573, 50.58904901146889, 48.53579118847847, 47.27245397865772, 51.21167980134487, 49.864066913723946, 52.283237501978874, 63.88084977865219, 68.98278281092644, 69.08970907330513, 68.18465083837509, 62.419588789343834, 66.15334823727608, 62.35632598400116, 62.16234639286995, 55.21521717309952, 50.7802889496088, 46.32378548383713, 44.34789150953293, 41.37053847312927, 41.25144146382809, 37.62272737920284, 34.659984558820724, 33.38765703141689, 37.90402628481388, 41.91300876438618, 48.4646438062191, 53.86614516377449, 57.85982586443424, 60.56548587977886, 70.46390533447266, 72.98283576965332, 64.69051033258438, 50.55637836456299, 12.31799092143774, 4.376949509605765, 0.29832338739652187, 4.271645760163665, 2.4928612215444446, 4.8682298976928, 8.537481632083654, 6.07490454800427, 3.945557945407927, 1.8487541028298438, 0.8852282864972949, 0.0825933032319881, 0.06177701085107401, 17.511162757873535, 43.76301929354668, 63.75856474041939, 33.77442307770252, 59.0748106688261, 59.995710253715515, 7.26324993185699, 0.39858445117715746, 0.04931159419356845, 0.07140647343476303, 0.04852358550124336, 0.08884813127224334, 0.07411070371745154, 0.017023364853230305, 0.14028536999830976, 0.075184442976024, 0.07421572503517382, 0.048671766417101026, 0.03819218109128997, 0.032728471342124976, 0.04864482645643875, 0.05661958173732273, 0.059125313491676934, 0.06472306253272109, 0.030922453115636017, 0.03980870118539315, 0.11476252548163757, 0.005329196874299669, 0.06916782949701883, 0.006582796086149756, 0.11887659144122154, 0.02439163890812779, 0.02916596582508646, 0.007385186208921368, 0.03434809732425492, 0.09347986007924192, 0.03852113433822524, 0.10126473687705584, 0.02745533398410771, 0.03264651968493126, 0.06760353804565966, 0.04974202500307001, 0.012630316305148881, 0.01794727006199537, 0.015004019987827633, 0.07200197273050435, 0.01605897177796578, 0.013707450889341999, 0.07762990862829611, 0.015596183329762425, 0.043678426154656336, 0.02684616803890094, 0.0419079029961722, 0.06441289675422013, 0.05333492888894398, 0.02918145815783646, 0.026385936289443634, 0.039313874221988954, 0.04629362098057754, 0.05227605113759637, 0.047822708656894974, 0.05347869773686398, 0.018097888932970818, 0.23478600225644186, 1.31258838577196, 61.3094175606966, 101.42273649573326, 46.944774761796, 57.71404288709164, 94.98076736927032, 33.976861014962196, 40.716338977217674, 4.683662876486778, 0.166567639389541, 0.8180061529856175, 2.761982730589807, 5.410890178754926, 9.792745225131512, 2.9056385345757008, 1.9544974411837757, 0.5913459998555481, 4.645096845924854, 26.329423673450947, 55.119542106986046, 69.68107894062996, 74.07045140862465, 77.43687316775322, 70.08726194500923, 76.10464185476303, 80.67537099123001, 83.80913883447647, 88.82154867053032, 83.29400807619095, 76.18325963616371, 72.46963530778885, 78.72182741761208, 76.35478243231773, 66.2087644636631, 59.66484300792217, 58.1253632158041, 56.96542225778103, 58.805534318089485, 64.1603171825409, 65.12450784444809, 75.05576133728027, 78.39227870106697, 79.89301577210426, 77.02930703759193, 75.97391366958618, 77.08843186497688, 76.887878626585, 65.66510483622551, 58.81167858839035, 54.65746030211449, 56.869823187589645, 55.94265393912792, 62.010407745838165, 67.9195162653923, 75.77602788805962, 70.19636169075966, 76.63675770163536, 57.69016116857529, 24.132164977490902, 70.86679011583328, 69.15095418691635, 69.55405175685883, 68.57280001044273, 62.35623858869076, 57.17471122741699, 55.29218964278698, 55.040384754538536, 52.430791184306145, 52.5201927870512, 53.34847614169121, 54.04087498784065, 55.30853636562824, 65.39297863841057, 70.83151280879974, 72.10897386074066, 70.9122584760189, 68.34001690149307, 71.94434389472008, 67.34178766608238, 69.2168578505516, 64.07413020730019, 59.43516433238983, 55.92578284442425, 54.235036969184875, 51.354932114481926, 51.28921464085579, 48.80764000117779, 47.296947464346886, 45.233825370669365, 50.099069103598595, 52.91282571852207, 59.03363987803459, 60.79323045909405, 63.0512934923172, 67.04031184315681, 76.85035943984985, 78.40395927429199, 68.67367699742317, 52.84884475171566, 14.436582438647747, 4.760826760903001, 2.149926535785198, 7.853351617231965, 5.2842173259705305, 7.8704796731472015, 4.80988877825439, 3.9090872649103403, 2.565908026881516, 0.7056575221940875, 0.6045707152225077, 0.10189126536715776, 0.14142627362161875, 32.22637094557285, 46.90102770924568, 76.38175338506699, 33.130874410271645, 57.340925708413124, 64.03173208236694, 6.28867395222187, 0.1752877706894651, 0.08881012588972226, 0.07031596163869835, 0.04552907157631125, 0.0899403945368249, 0.008534008084097877, 0.055536754880449735, 0.05318324874679092, 0.04301855296944268, 0.026346884478698485, 0.06605884671444073, 0.0778470016666688, 0.04199766575766262, 0.07881346347858198, 0.04912642092676833, 0.06409219247871079, 0.04692298076406587, 0.04446637918590568, 0.03548660752130672, 0.01444553252440528, 0.026381425886938814, 0.07430605925037526, 0.08311709621921182, 0.05365802287997212, 0.010768113788799383, 0.054698899839422666, 0.08022902111406438, 0.07164261740399525, 0.13824565132381395, 0.09680915682110935, 0.1358757066191174, 0.13032270537223667, 0.11842939551570453, 0.10584194009425119, 0.1757829761481844, 0.17552224482642487, 0.16559557436266914, 0.14849312254227698, 0.18329940328840166, 0.22424901922931895, 0.16328722791513428, 0.18016889080172405, 0.10890476129134186, 0.12434107673470862, 0.07942862226627767, 0.1449052689713426, 0.18531990033807233, 0.1646782353054732, 0.08760164229897782, 0.1682303025154397, 0.15686003607697785, 0.11020628793630749, 0.1443463278701529, 0.15127635444514453, 0.18640110560227185, 0.1155832591757644, 0.41138661734294146, 1.9896098133176565, 88.36090698838234, 107.55807727575302, 75.18885299563408, 66.23699694871902, 109.89166885614395, 54.5348484814167, 51.71668790280819, 5.1454459223896265, 0.3909278323408216, 3.536271695047617, 8.423423152416945, 20.44879462569952, 19.973048754036427, 3.7232905346900225, 2.6536583807319403, 0.6505847617518157, 6.203131042420864, 26.684744507074356, 56.11532427370548, 71.40512242913246, 73.62511530518532, 79.57694113254547, 69.58486050367355, 72.94618293642998, 86.5689155459404, 87.8528742492199, 90.47232449054718, 83.91434758901596, 80.92036664485931, 72.42604404687881, 81.7392835021019, 79.34374764561653, 71.40484884381294, 63.43673340976238, 63.692816868424416, 63.43810513615608, 63.347138017416, 67.12909027934074, 67.55923479795456, 79.18966591358185, 80.52142605185509, 82.29662239551544, 78.39927792549133, 76.28180354833603, 79.38132762908936, 80.17253637313843, 68.6707891523838, 62.03525461256504, 56.34159453213215, 58.449432626366615, 59.66981314122677, 64.27868083119392, 73.08321878314018, 78.65938156843185, 76.38508960604668, 78.20865735411644, 60.10209694504738, 28.537147007882595, 73.02480831742287, 72.04310819506645, 73.02986964583397, 69.6971444785595, 65.50573378801346, 59.562620893120766, 58.38404953479767, 57.67819941043854, 54.12432610988617, 52.84941852092743, 55.98359294235706, 56.46407715976238, 59.81165573000908, 68.16966444253922, 73.38078081607819, 73.77847507596016, 74.33170258998871, 70.30689775943756, 75.01620545983315, 68.39279606938362, 72.64997363090515, 67.10359364748001, 67.06530690193176, 61.29030078649521, 60.61622455716133, 57.09470272064209, 61.113785058259964, 59.028415158391, 57.739843502640724, 57.4521267414093, 59.959600791335106, 59.6700107306242, 66.10342651605606, 66.85246512293816, 66.0554350912571, 69.06206175684929, 76.33083611726761, 81.09304457902908, 71.36271670460701, 55.401372984051704, 16.489230394363403, 7.788346130400896, 2.1668629394844174, 5.244193598628044, 8.271919582039118, 10.326161552220583, 21.332463808357716, 16.0534355789423, 12.053697053343058, 4.380260081961751, 4.025844074785709, 0.41165269212797284, 0.6110474083106965, 31.25239010900259, 57.009659484028816, 84.63112592697144, 50.76173834502697, 71.22390255331993, 84.67719465494156, 15.06949357688427, 0.9302051074337214, 0.5060452676843852, 0.3710402635624632, 0.2438393430202268, 0.22133898397441953, 0.15956001385347918, 0.17006113630486652, 0.25479565432760864, 0.15820920118130744, 0.12351225363090634, 0.11609944514930248, 0.222333402489312, 0.21547585405642167, 0.11500349341076799, 0.16949162702076137, 0.09075280875549652, 0.28453033533878624, 0.10803107536048628, 0.15842752618482336, 0.1518634971580468, 0.09124395466642454, 0.15175300621194765, 0.1380839670309797, 0.2127973985625431, 0.08604977439972572, 0.17038742895238101], [0.007999840800039237, 0.06253916682908311, 0.029192339898145292, 0.05631961677863728, 0.05865043174708262, 0.029410841161734425, 0.07359196475590579, 0.05604276972007938, 0.014032855742698302, 0.05020589327614289, 0.06635582452872768, 0.16109863441670313, 0.008602960097050527, 0.04960903956089169, 0.0919260700175073, 0.021102727987454273, 0.006302108877207502, 0.0424705399927916, 0.012219546842970885, 0.013835501977155218, 0.01666322656092234, 0.00919331074328511, 0.017481455506640486, 0.1200813049217686, 0.05630117069813423, 0.10238456350634806, 0.09948928214726038, 0.05058103779447265, 0.16599038208369166, 0.08023633869015612, 0.09720255446154624, 0.9488739212974906, 7.469534687697887, 77.42052644491196, 75.87546855211258, 40.244609490036964, 74.0091834962368, 71.6258753836155, 43.22053760290146, 5.468324571847916, 0.08243377116741613, 0.9514557640068233, 1.3923077518120408, 4.2316662054508924, 4.237016793340445, 2.7530232863500714, 1.0216695838607848, 1.0326365078799427, 0.30405766563490033, 6.188294738531113, 18.93816288560629, 42.953700721263885, 33.701269403100014, 26.846182644367218, 28.7645211070776, 40.109370946884155, 67.056073397398, 76.27621784806252, 78.25632199645042, 63.25196072459221, 49.36858490109444, 54.61430601775646, 70.30318915843964, 63.78645524382591, 60.42131781578064, 51.01562552154064, 51.30606293678284, 51.46279692649841, 53.76586474478245, 56.41138158738613, 62.946088537573814, 68.54436233639717, 72.93595388531685, 73.28339204192162, 70.58098465204239, 67.83863380551338, 66.12588331103325, 73.72209370136261, 71.82875409722328, 64.57701042294502, 56.36794991791248, 52.767350524663925, 54.23286348581314, 60.661487728357315, 66.72307446599007, 67.74214938282967, 66.43742099404335, 67.19261527061462, 64.86020162701607, 28.165680840611458, 58.59209977090359, 69.16312113404274, 69.58419173955917, 66.78116574883461, 65.80269545316696, 58.89859512448311, 52.17547528445721, 51.16844952106476, 49.70765210688114, 50.00420339405537, 52.26280219852924, 50.7709376513958, 59.38906520605087, 69.81775000691414, 71.03866249322891, 70.58626636862755, 66.79690450429916, 65.95317497849464, 61.73854373395443, 63.33997540175915, 55.49893654882908, 54.220217764377594, 47.218067497015, 42.3975245654583, 39.70331333577633, 38.281802013516426, 37.28025555610657, 34.75708454847336, 33.15213806927204, 31.1660473421216, 35.59099920094013, 41.67537331581116, 43.68000514805317, 48.734748512506485, 51.64844736456871, 61.74024984240532, 69.31088000535965, 67.4058598279953, 60.20103983581066, 41.19282200932503, 3.164762305095792, 2.2406374057754874, 2.2161959297955036, 7.341829715296626, 6.12866691313684, 4.747843807563186, 6.250702114775777, 3.82180642336607, 2.7389911143109202, 1.84626191155985, 0.6598738976754248, 0.5853452312294394, 9.847045261412859, 27.545759305357933, 75.24921655654907, 33.41954492032528, 38.70547167956829, 61.4360685646534, 22.05845285207033, 0.18499314755899832, 0.1264946482842788, 0.12539371673483402, 0.09199464446282946, 0.027222728203923907, 0.08665594577905722, 0.02059868726064451, 0.01145421076216735, 0.03800954596954398, 0.05437721963971853, 0.019169091901858337, 0.01598326714884024, 0.007204171752164257, 0.056324463002965786, 0.05440220033051446, 0.03594202273234259, 0.03601878306653816, 0.014973770048527513, 0.0767823462956585, 0.04289957185392268, 0.05957029039564077, 0.03560352175554726, 0.0762754371680785, 0.03910950159479398, 0.08403179323067889, 0.039911945059429854, 0.04296129627618939, 0.021907420159550384, 0.02765205135801807, 0.06562938811839558, 0.1204410610080231, 0.08102569438051432, 0.06303942631348036, 0.0942788265820127, 0.06111842900281772, 0.0245724539126968, 0.02329750728677027, 0.037307088350644335, 0.2108983020298183, 0.007542496932728682, 0.0904287796583958, 0.023679418336541858, 0.05807744921185076, 0.01459534338209778, 0.012188443433842622, 0.043200022919336334, 0.06440314493374899, 0.061871130019426346, 0.0503399214358069, 0.05525374799617566, 0.04115932832064573, 0.07435740844812244, 0.0958085859019775, 0.10016913394792937, 0.054207152788876556, 0.191659088304732, 0.2623651153407991, 0.20024643454235047, 1.1295367707498372, 7.370803635567427, 82.439274340868, 84.5031563937664, 39.23220321536064, 92.49586030840874, 73.96857887506485, 54.8890844732523, 5.927658174186945, 0.08858319197315723, 0.9625141799915582, 1.4175559720024467, 3.9980466663837433, 4.998224722221494, 7.890624767169356, 1.802691430784762, 1.4490104466676712, 0.2875604649307206, 7.788815880194306, 24.455881007015705, 47.81739793717861, 40.82368701696396, 33.64145301282406, 34.418344125151634, 47.38106355071068, 73.90106409788132, 82.59024783968925, 84.77213636040688, 70.64174339175224, 59.239319041371346, 65.667415112257, 75.18299371004105, 69.08989906311035, 60.796410888433456, 58.739668652415276, 58.6263245344162, 57.922940477728844, 59.96570706367493, 61.06216862797737, 68.24603274464607, 71.74965754151344, 76.5688781440258, 76.22521698474884, 73.24716478586197, 70.78377977013588, 72.02340245246887, 78.26293364167213, 75.0271488726139, 67.3619569838047, 59.226737916469574, 55.73394253849983, 55.16331195831299, 64.43905502557755, 71.87502801418304, 71.75858706235886, 70.31210348010063, 71.35529950261116, 66.20471388101578, 29.42965641617775, 63.0074742436409, 72.95583441853523, 73.43315720558167, 71.22185066342354, 69.53616991639137, 60.73404103517532, 55.67892909049988, 54.82381157577038, 54.808407202363014, 54.18864905834198, 55.29156267642975, 54.48599070310593, 62.659093737602234, 71.04100316762924, 73.95582675933838, 73.46142008900642, 71.80916234850883, 70.32508358359337, 66.18601128458977, 68.91897663474083, 66.49479791522026, 63.07514861226082, 58.07409256696701, 54.907931461930275, 50.85980728268623, 51.2773022800684, 50.629402846097946, 48.951614275574684, 45.383351147174835, 45.00345893204212, 47.37041272222996, 53.287136033177376, 52.44504041969776, 57.41067096590996, 59.397538751363754, 69.12365645170212, 73.15393298864365, 73.66182893514633, 64.20057222247124, 45.71358002722263, 3.8702514488250017, 2.597829638980329, 4.904769686982036, 6.41164580360055, 8.05709620937705, 5.385212581604719, 3.7795351166278124, 4.321468686684966, 1.4739112230017781, 1.4047960191965103, 1.269595711492002, 0.8363739517517388, 20.728163234889507, 34.34300176799297, 80.37690460681915, 43.38422141969204, 37.54938371479511, 72.60092586278915, 24.264696165919304, 0.46826552774291486, 0.13227912539150566, 0.048050158366095275, 0.07263779290951788, 0.012966156682523433, 0.04245603471645154, 0.06381253639119677, 0.07060615622322075, 0.15956428862409666, 0.020102917769690976, 0.03823828330496326, 0.1025876151106786, 0.05194192512135487, 0.057094140647677705, 0.05482700937136542, 0.05922014141106047, 0.047145536009338684, 0.0520009444153402, 0.010777116967801703, 0.026577547687338665, 0.06923300490598194, 0.05879415606614202, 0.06015053113515023, 0.01666503925662255, 0.04421374098455999, 0.05420352368673775, 0.05182929307920858, 0.13026846922002733, 0.15453657950274646, 0.15078891185112298, 0.18084083130815998, 0.14266589772887528, 0.10191989742452279, 0.2480220576399006, 0.1828716738964431, 0.09249547540093772, 0.14979251922341064, 0.12001905357465148, 0.34356889547780156, 0.14142127154627815, 0.14850857405690476, 0.14434108830755576, 0.1409305041306652, 0.1006527767458465, 0.13464498828398064, 0.13677141949301586, 0.22416442923713475, 0.15017126686871052, 0.1677563670091331, 0.12454792071366683, 0.26445734838489443, 0.2861029759515077, 0.24816747405566275, 0.24189392162952572, 0.21312909404514357, 0.3170954785309732, 0.38586926471907645, 0.3883313841652125, 1.9479549047537148, 17.035357989370823, 101.66356757283211, 94.94777753949165, 57.05125965178013, 97.74743691086769, 90.78535169363022, 67.49806568026543, 10.28091263025999, 0.2735407609725371, 2.2937302943319082, 3.8858536491170526, 12.370151672512293, 11.112264320254326, 11.669550016522408, 0.906074324157089, 2.29982967954129, 0.7278885261621326, 7.718099299818277, 24.138558134436607, 50.609446316957474, 40.95084719359875, 30.657115951180458, 34.667386561632156, 46.11145667731762, 74.25612464547157, 83.1172263622284, 88.24668511748314, 74.53840389847755, 64.87664714455605, 71.57658442854881, 81.92344442009926, 72.75487840175629, 66.99404552578926, 64.56904605031013, 65.98470568656921, 66.71707838773727, 65.6717012822628, 66.06179594993591, 72.36349180340767, 75.09717911481857, 78.58510315418243, 77.22763359546661, 74.57511752843857, 73.19501638412476, 76.10525742173195, 80.52713334560394, 79.27901431918144, 71.89091116189957, 62.85580538213253, 58.09289015829563, 59.85294811427593, 66.46947607398033, 71.97150483727455, 72.81316727399826, 71.52201175689697, 71.28140866756439, 70.10668650269508, 35.04660241305828, 62.80873730778694, 75.40051683783531, 76.59491434693336, 72.88405627012253, 72.26616382598877, 65.36421418190002, 58.92215386033058, 56.105851382017136, 57.85496212542057, 59.22236815094948, 59.14625823497772, 56.0510279238224, 65.6217035651207, 72.68152713775635, 76.97639867663383, 76.25735566020012, 73.80785509943962, 71.57886430621147, 67.09687560796738, 71.44170686602592, 69.27829295396805, 69.87280905246735, 63.85151535272598, 63.93207103013992, 59.761589616537094, 60.90503565967083, 61.93872459232807, 62.118481546640396, 60.297976434230804, 57.6040805876255, 59.572112783789635, 62.700959891080856, 60.07034584879875, 65.9537373483181, 65.17801657319069, 73.80309775471687, 76.63346707820892, 77.03858613967896, 64.78124186396599, 50.4115529358387, 5.160667430609465, 4.540281845256686, 6.021331697702408, 16.339096650481224, 19.885110072791576, 18.112919367849827, 13.277269396930933, 13.898556958884, 7.55702736787498, 5.121559929102659, 2.377104707993567, 0.9030253440141678, 15.996693223714828, 40.72653762996197, 96.62224128842354, 51.52577094733715, 50.94672001898289, 79.1632117331028, 45.2339393645525, 0.6184427614789456, 0.20917831541737542, 0.2929678122745827, 0.10547266225330532, 0.18920991191407666, 0.15797475673025474, 0.267564186360687, 0.12508614105172455, 0.30477624270133674, 0.18151666066842154, 0.2113548415945843, 0.2544536429923028, 0.1637499124626629, 0.2520470065064728, 0.14543744822731242, 0.1713308916077949, 0.16285072633763775, 0.2386685775127262, 0.19675045885378495, 0.2138705292600207, 0.271083569386974, 0.0813242158619687, 0.19119585456792265, 0.06810865117586218, 0.1580651057884097, 0.1357014651875943, 0.18437266757246107], [0.06443960664910264, 0.09736736319609918, 0.10638800493325107, 0.09459666616749018, 0.08621197077445686, 0.11443699724623002, 0.028964044140593614, 0.010098527745867614, 0.03318141149065923, 0.04287380819732789, 0.02425237118586665, 0.02029153831244912, 0.03543060505762696, 0.05261968406557571, 0.04922517851809971, 0.025046042464964557, 0.04513706917350646, 0.021067446286906488, 0.015705722471466288, 0.012525013898994075, 0.025074845216295216, 0.035609503465821035, 0.0854305041139014, 0.03779725833737757, 0.04449944928637706, 0.0402337551349774, 0.01561336775921518, 0.08495178917655721, 0.04461176591576077, 0.09016430049086921, 0.1241151372960303, 0.03718206244229805, 0.46799844363704324, 17.62285966426134, 80.0415650010109, 62.32850007712841, 42.88930557668209, 76.04020491242409, 44.66100990772247, 10.64629627391696, 0.1762377197155729, 0.4883334384066984, 1.0698120505549014, 0.48851030704099685, 7.133556716144085, 3.2450246857479215, 1.872780688572675, 0.70725949248299, 0.24572058347985148, 0.15631844638846815, 0.36421419703401625, 1.372702110093087, 2.7584372833371162, 1.2954575987532735, 0.9797636512666941, 5.274608116596937, 27.07274168729782, 50.16645848751068, 49.36920426785946, 38.0213487893343, 42.99948826432228, 57.71497003734112, 61.817602291703224, 52.55341820418835, 44.33110401034355, 45.758197233080864, 47.04616092145443, 52.69713029265404, 52.687300220131874, 61.34616918861866, 66.35838523507118, 73.11799451708794, 73.14895525574684, 73.67711171507835, 69.19098883867264, 72.12197676301003, 70.5186527967453, 70.51125079393387, 70.50197169184685, 65.53889840841293, 59.790247678756714, 55.479219406843185, 51.6035071760416, 60.242427214980125, 68.24017345905304, 70.25708243250847, 72.37837940454483, 67.00840875506401, 68.25636819005013, 34.27615575492382, 49.068967178463936, 70.4643765091896, 66.7033839225769, 71.24435305595398, 67.2366701066494, 64.77700889110565, 53.92841622233391, 49.144985899329185, 50.56658461689949, 51.94144204258919, 53.28693084418774, 52.76840686798096, 64.64853778481483, 72.55710661411285, 71.39798641204834, 69.4166587293148, 66.77612721920013, 62.58010357618332, 57.00765319168568, 57.38744281232357, 52.8132900595665, 50.74854165315628, 41.36589132249355, 39.07537043094635, 33.964580073952675, 36.11623741686344, 36.58724494278431, 42.22626395523548, 37.24331013858318, 38.39311704039574, 34.651864394545555, 36.59231387078762, 33.85489895939827, 40.76713465154171, 41.61594070494175, 54.167677983641624, 62.51638099551201, 64.97322276234627, 49.23148065805435, 22.559501565992832, 2.2941558714956045, 0.08632780518382788, 3.672125330194831, 11.663561537861824, 3.602640121243894, 8.190257214009762, 1.2659249897114933, 1.1932409461587667, 0.7122640614397824, 0.22230543836485595, 0.6115093803964555, 8.801557961851358, 28.69650475680828, 70.88813737034798, 48.921474292874336, 36.797727048397064, 59.26164284348488, 57.53967024385929, 4.3018280155956745, 0.5633464304264635, 0.20280451368307695, 0.03566627034160774, 0.025288396354881115, 0.06221933086635545, 0.06158059404697269, 0.06944600128917955, 0.028752606267516967, 0.007481041538994759, 0.062300173012772575, 0.016120904001581948, 0.08209670253563672, 0.033250364431296475, 0.07304263446712866, 0.03984855080489069, 0.06338265477097593, 0.04969447931216564, 0.01596537582372548, 0.022164320143929217, 0.06772208129405044, 0.0597898325213464, 0.024302974525198806, 0.040082327323034406, 0.020741782609547954, 0.07228297952678986, 0.0414801810256904, 0.021191817249928135, 0.024520620463590603, 0.062259674014057964, 0.04065350272867363, 0.09186499868519604, 0.08766559316427447, 0.0719627873331774, 0.014829467781964922, 0.11103840617579408, 0.07247266505146399, 0.05499082733877003, 0.03688410128233954, 0.058967454970115796, 0.030785593662585597, 0.0443329855625052, 0.05024503785534762, 0.04405229046824388, 0.03995323815615848, 0.0161583843146218, 0.021830032710568048, 0.07781835476635024, 0.03195038887497503, 0.03818507873802446, 0.05795782242785208, 0.013426535933831474, 0.05093950996524654, 0.08392352872760966, 0.03616610309109092, 0.07389318765490316, 0.05001756588171702, 0.08967106172349304, 0.08845808071782812, 0.11974057750194333, 0.5481971183326095, 16.512167863547802, 97.11821347475052, 53.44229690730572, 53.80776509642601, 94.44424375891685, 53.497253358364105, 21.648038774728775, 0.478573216823861, 0.8542183286044747, 1.1881425697356462, 1.1685246974229813, 3.9583661081269383, 3.0038117291405797, 4.832140859216452, 1.3298015808686614, 0.5486118304543197, 0.589120922377333, 0.8750777842942625, 3.345639486797154, 4.71615350805223, 3.2411626679822803, 2.5856208940967917, 8.96894657984376, 30.676234625279903, 56.3717383146286, 59.00096543133259, 48.95927086472511, 53.46587844192982, 65.64602985978127, 72.60535642504692, 65.71786120533943, 58.867763578891754, 55.61196148395538, 55.54103448987007, 56.88589632511139, 61.69366434216499, 66.98688670992851, 72.27062478661537, 78.03431510925293, 78.19702997803688, 77.29149296879768, 73.92723709344864, 75.35820230841637, 74.03452053666115, 73.81584987044334, 74.32867795228958, 68.47309336066246, 64.45013523101807, 57.76372902095318, 56.702100187540054, 65.85219919681549, 74.15068030357361, 77.0572279393673, 77.62286558747292, 70.09480834007263, 71.77085280418396, 37.05212339758873, 53.11434790492058, 71.91346675157547, 71.06567144393921, 76.60790205001831, 70.84228903055191, 69.2599855363369, 55.904298797249794, 54.2264836281538, 53.00796501338482, 52.9987733066082, 54.65264216065407, 56.462450847029686, 68.10329720377922, 74.50538367033005, 73.82153436541557, 72.76997119188309, 72.02229291200638, 68.62057864665985, 64.44881290197372, 65.77224388718605, 62.90085196495056, 61.763698384165764, 56.190282851457596, 53.66226710379124, 48.16808491945267, 50.03614068031311, 49.104134291410446, 55.113359838724136, 52.67224162817001, 50.60761481523514, 46.37661784887314, 47.493412122130394, 46.45840086042881, 54.312659204006195, 54.220483750104904, 61.25918425619602, 70.42245715856552, 72.57487446069717, 51.94454647600651, 25.66950548440218, 3.6931531643494964, 0.4414228774840012, 5.724337259307504, 8.18299675360322, 5.849025193601847, 1.9334481144323945, 2.8259860211983323, 0.6113133940380067, 1.183075422886759, 1.03408292401582, 1.2604773882776499, 18.12676202505827, 39.13908541202545, 67.67948314547539, 68.53009790182114, 33.794740587472916, 61.3691009581089, 65.55748701095581, 4.665099922567606, 0.5565098847728223, 0.05479743478645105, 0.12229922809638083, 0.06037330531398766, 0.10088161056046374, 0.05101144633954391, 0.06142309917777311, 0.05520852151676081, 0.008876158572093118, 0.04693650269473437, 0.02322436306712916, 0.008486457754770527, 0.03742954271729104, 0.07436889689415693, 0.02903463722759625, 0.03383793016837444, 0.034048596207867377, 0.026715197527664714, 0.011939925079786917, 0.0435303714039037, 0.05481049287482165, 0.03125470335362479, 0.015053263341542333, 0.01028880327794468, 0.025874051061691716, 0.024260260215669405, 0.0415496534697013, 0.14679350046208128, 0.11422348135965876, 0.17649373097810894, 0.2836955973180011, 0.10664193076081574, 0.17800799425458536, 0.11242823355132714, 0.2261489469674416, 0.12942448403919116, 0.0962261256063357, 0.16464498708955944, 0.21336393925594166, 0.11590526220970787, 0.09999375703046098, 0.18348960089497268, 0.26433801103848964, 0.10763788552139886, 0.1588738092686981, 0.08801564938039519, 0.18320654577109963, 0.10043096364825033, 0.09444373921724036, 0.1458024512976408, 0.10016943822847679, 0.11530142117408104, 0.1800957298837602, 0.1517407310893759, 0.16543599776923656, 0.1372209977125749, 0.26422101887874305, 0.22878039482748136, 0.2066605497384444, 0.8629878424108028, 39.639415964484215, 110.91126054525375, 82.89789453148842, 65.38042411208153, 96.31832599639893, 65.07352218031883, 20.357166342437267, 0.3943525766953826, 1.5911015658639371, 3.3607187401503325, 3.3999839331954718, 15.415321569889784, 13.967037834227085, 6.704790573567152, 0.7798074558377266, 0.36993149493355304, 0.35713069431949407, 0.884830376598984, 3.4717578068375587, 5.092233577743173, 4.252011738717556, 2.016565566882491, 8.523440435528755, 30.329009257256985, 55.40803402662277, 57.262668907642365, 54.75183963775635, 58.52553494274616, 71.19608044624329, 77.21509426832199, 76.57966196537018, 67.11958318948746, 66.38653412461281, 64.64022383093834, 68.05657491087914, 66.17415592074394, 74.14950996637344, 77.13888555765152, 82.26981863379478, 77.45491459965706, 79.54260617494583, 74.94652479887009, 77.47352600097656, 75.41880905628204, 76.7023041844368, 76.41360327601433, 71.19598165154457, 65.26692420244217, 59.680596962571144, 57.424988597631454, 70.45686051249504, 74.41678002476692, 79.7207710146904, 78.29905450344086, 75.31462624669075, 71.43794506788254, 43.639613315463066, 53.455664590001106, 71.73318162560463, 72.33817756175995, 79.15829479694366, 73.16759705543518, 73.13999533653259, 61.11028924584389, 57.66469493508339, 56.14546425640583, 56.94331504404545, 58.59849102795124, 58.17867815494537, 70.42096763849258, 79.6363015472889, 75.34372508525848, 74.31217163801193, 73.71695637702942, 73.32123041152954, 68.84121000766754, 71.92098274827003, 66.66254371404648, 68.95622223615646, 63.42709332704544, 66.70198559761047, 59.86349254846573, 61.82873569428921, 62.073537558317184, 66.59526452422142, 64.86805200576782, 62.24769741296768, 59.78106737136841, 62.784532606601715, 60.14281935989857, 64.7962586581707, 62.381096854805946, 70.7941684126854, 74.61148157715797, 76.07935801148415, 56.641413643956184, 26.71364765614271, 5.408198973163962, 0.47687411424703896, 9.480534978210926, 33.09214308857918, 12.49032687395811, 17.194877229630947, 8.295647408813238, 6.345124673098326, 3.3874372439458966, 1.564585401210934, 1.3764174794778228, 14.934570416808128, 47.62718394398689, 87.12435454130173, 68.60691457986832, 51.02858282625675, 71.02723270654678, 82.8924760222435, 10.558659676462412, 1.036311979405582, 0.41575825307518244, 0.43314659502357244, 0.175454932032153, 0.20832773996517062, 0.13267406669910997, 0.18077742221066728, 0.2866860665380955, 0.11852599345729686, 0.22962411283515394, 0.13006945489905775, 0.17846535018179566, 0.10500597752979957, 0.23541047499747947, 0.13300314982188866, 0.09678314454504289, 0.12196000723633915, 0.19667471526190639, 0.14771337766433135, 0.34663556842133403, 0.23417533346218988, 0.10863588118809275, 0.206216448568739, 0.14335686690174043, 0.1995367929339409, 0.10616841085720807, 0.16569049505051225], [0.07235937620862387, 0.04820862544875126, 0.11235708385356702, 0.03565183185855858, 0.09767467170604505, 0.03089073743467452, 0.05092946499644313, 0.03696859108458739, 0.10894320454099216, 0.1095957972574979, 0.07683989984798245, 0.06280914531089365, 0.00762288265832467, 0.04907098991679959, 0.0301105027392623, 0.008411495273321634, 0.029591932616312988, 0.04471742548048496, 0.04797711990249809, 0.03137181054626126, 0.018443119333824143, 0.06698402285110205, 0.017059787605830934, 0.027428108296589926, 0.01616322682821192, 0.08499400995788164, 0.060723472852259874, 0.046465450432151556, 0.11864418789627962, 0.0482413281861227, 0.19587781192967668, 0.14382807130459696, 0.6474087259266526, 1.8185494048520923, 47.26681508123875, 91.56435549259186, 47.39807143807411, 52.89858788251877, 94.14409786462784, 32.519464418292046, 5.799956526607275, 0.6036533019505441, 1.0838697524741292, 0.2662069466896355, 1.4493261859752238, 5.29229711741209, 3.8478573504835367, 1.3872264744713902, 0.425894416985102, 0.3648515831446275, 0.12236738693900406, 0.07442661371896975, 4.847244573757052, 1.0718224989250302, 0.18579376162961125, 0.28006296255625784, 1.6728306678123772, 19.242270067334175, 27.782617695629597, 34.009007290005684, 27.236053124070168, 39.650135189294815, 67.56246462464333, 64.44795414805412, 57.936722338199615, 53.63954812288284, 52.60796807706356, 57.725609466433525, 60.61631575226784, 64.34324696660042, 63.81714999675751, 70.81184506416321, 69.69578415155411, 69.94539275765419, 68.38762074708939, 69.83048692345619, 70.5447193980217, 72.88238435983658, 68.48068535327911, 69.27632465958595, 62.99298942089081, 58.6322446167469, 53.09945650398731, 57.69028276205063, 64.89497736096382, 68.28243479132652, 69.20353576540947, 67.3345148563385, 66.20869606733322, 39.00804564356804, 45.237974748015404, 67.71169781684875, 66.84891611337662, 70.88399559259415, 67.77632474899292, 69.38376769423485, 56.27604804933071, 50.46184703707695, 51.99417941272259, 54.68231476843357, 52.051613330841064, 57.04952694475651, 68.07001858949661, 74.59202662110329, 73.84868770837784, 71.60284101963043, 67.5365500152111, 66.44858479499817, 56.5313221514225, 49.8539062589407, 45.821878015995026, 43.01743470132351, 37.57828876376152, 35.33065237104893, 33.03294226527214, 37.93975576758385, 43.09429317712784, 55.056967064738274, 62.80522249639034, 62.060211673378944, 61.53141304850578, 61.113416478037834, 56.58899165689945, 48.18605795502663, 43.68796572089195, 53.19826640188694, 55.11905953288078, 63.696536868810654, 44.001475498080254, 11.37324571609497, 1.0321425343863666, 1.7427929886616766, 3.552004275843501, 1.3252361258491874, 6.992715848609805, 0.38972095178905874, 2.541049998253584, 0.6789304094854742, 0.875377255724743, 1.6007651598192751, 11.201848313212395, 29.640695191919804, 70.21660700440407, 53.41757923364639, 29.92084465920925, 57.968587428331375, 69.15843218564987, 32.57860064506531, 0.4844643553951755, 0.2519580378429964, 0.09602759368135594, 0.03799478836299386, 0.04280757893866394, 0.03403616894502193, 0.08607195719378069, 0.06179170166433323, 0.02510663696739357, 0.049895137490238994, 0.011830032490252052, 0.01989240201510256, 0.10674908204236999, 0.028688302882073913, 0.0005755829511144839, 0.06622783374041319, 0.05929756967816502, 0.03676803309645038, 0.053671934438170865, 0.04928594185912516, 0.05806080283946358, 0.02370642323512584, 0.012638172865990782, 0.07104240547050722, 0.01687540101556806, 0.05906236081500538, 0.05615088579361327, 0.04369583693915047, 0.03995896753622219, 0.04493733496929053, 0.11589107976760715, 0.08290291239973158, 0.07716526481090114, 0.06270804995438084, 0.048808796564117074, 0.03375052001501899, 0.0699723992147483, 0.025037635787157342, 0.029803843608533498, 0.029779801734548528, 0.0830681664228905, 0.03207289148122072, 0.04601077365805395, 0.045484984293580055, 0.030232493263611104, 0.035809605033136904, 0.03246669359214138, 0.04204141536320094, 0.05523355786863249, 0.027652296266751364, 0.1281798875425011, 0.09000269041280262, 0.0625941451289691, 0.07588792475871742, 0.1796615289640613, 0.0698817681404762, 0.09196560422424227, 0.06766302860341966, 0.18344763986533508, 0.1428013396798633, 0.8257722831331193, 2.7691011736169457, 53.555667623877525, 107.15773835778236, 37.95368202030659, 73.05031254887581, 97.53156289458275, 39.82975535094738, 9.740806762129068, 1.0913530946709216, 1.2593913590535522, 0.5310430575627834, 0.5155140033457428, 4.685605997219682, 4.816332282498479, 1.5816181059926748, 1.1644665151834488, 0.8870419766753912, 0.7155939296353608, 0.1658013867563568, 4.23230504617095, 2.8268098644912243, 1.1127465404570103, 0.39336703426670283, 3.0678580049425364, 24.454138800501823, 32.14445114135742, 40.6648213416338, 34.49123181402683, 47.17760726809502, 69.91876378655434, 62.72213235497475, 57.190647572278976, 57.508040741086006, 60.0833335518837, 64.0371885895729, 63.0950291454792, 69.81065958738327, 69.10504505038261, 74.09851670265198, 75.3957062959671, 72.97043323516846, 73.14661458134651, 76.33373156189919, 75.7661560177803, 77.67865419387817, 72.94084802269936, 74.08424466848373, 68.80403280258179, 63.37179869413376, 58.35499629378319, 62.89310798048973, 68.63752573728561, 71.85173526406288, 74.6295078098774, 70.3235636651516, 70.24342596530914, 42.15046942234039, 49.00815524160862, 72.55793496966362, 70.19068479537964, 74.45893496274948, 72.78329327702522, 73.65164548158646, 59.77309159934521, 55.23653022944927, 56.96466609835625, 58.56537580490112, 55.733782947063446, 60.146771147847176, 70.94052895903587, 76.05760037899017, 74.85624924302101, 74.36854541301727, 72.3861613869667, 73.51891100406647, 65.91002449393272, 60.35659208893776, 57.24926322698593, 55.76849788427353, 51.167032197117805, 49.96128849685192, 48.69782969355583, 51.68662391602993, 55.90929552912712, 64.89031121134758, 68.28945681452751, 68.17139714956284, 68.52523416280746, 67.24671676754951, 61.708912923932076, 54.26622189581394, 54.38187628984451, 60.51357686519623, 64.78453248739243, 68.7279000878334, 45.58014638721943, 12.457121405750513, 1.1773379682563245, 0.9535997395869344, 5.278706671670079, 1.0868470114655793, 4.037932176142931, 1.8797692260704935, 0.8338068332523108, 0.6262657104525715, 1.2514715152792633, 2.3444853583350778, 19.165111407637596, 42.995057702064514, 63.10974955558777, 75.33877775073051, 32.763840705156326, 58.111862540245056, 78.69666516780853, 34.97858606278896, 0.7766485190950334, 0.1945455529494211, 0.14326258446089923, 0.06524614305817522, 0.16004481440177187, 0.02471119285473833, 0.03205477936717216, 0.038863394293002784, 0.1017396520182956, 0.08082530708634295, 0.04018743769847788, 0.02881499120121589, 0.017669474909780547, 0.014987109225330641, 0.06518445574329235, 0.1266058220062405, 0.058794122669496574, 0.01412913456078968, 0.13689820800209418, 0.045366266640485264, 0.06520965907839127, 0.05257242410152685, 0.0714198024070356, 0.11446207441622391, 0.021882109213038348, 0.012727597022603732, 0.05451478042232338, 0.0494355885166442, 0.11667413462419063, 0.08133995681419037, 0.15754962485516444, 0.21254906110698357, 0.1771310725598596, 0.14365767419803888, 0.11076138471253216, 0.13900126155931503, 0.13292325020302087, 0.23577372659929097, 0.15296116325771436, 0.10694131313357502, 0.1312477924511768, 0.26811497868038714, 0.1447087779524736, 0.1670836249832064, 0.1037624645687174, 0.11859332851599902, 0.15581084706354886, 0.12398083825246431, 0.17021612642565742, 0.13587904628366232, 0.23884356109192595, 0.3576461900956929, 0.18808490509400144, 0.1925441439379938, 0.1794053247431293, 0.19084504136117175, 0.2321530255721882, 0.1396408147411421, 0.32788630574941635, 0.21210883394815028, 0.8530454977881163, 3.343642456457019, 78.41230362653732, 115.18014147877693, 67.40631580352783, 77.16919273138046, 110.9756138920784, 53.767019882798195, 10.579690597951412, 0.9026705974247307, 3.2759512262418866, 2.252212534658611, 4.450992336496711, 15.113170333206654, 16.369977593421936, 8.330458290874958, 1.03765508858487, 0.48307021614164114, 0.5550319422036409, 0.18078408669680357, 10.49555741250515, 3.313459726050496, 0.4498394555412233, 0.3764040913665667, 3.2007444743067026, 25.978875383734703, 35.29319778084755, 42.96962186694145, 38.89714479446411, 52.08198130130768, 79.8424480855465, 77.57977589964867, 72.62864917516708, 71.04492455720901, 73.47490936517715, 75.15957176685333, 72.81899616122246, 74.22863692045212, 74.1425259411335, 79.44462463259697, 75.42132452130318, 73.15301343798637, 76.7269192636013, 77.86566495895386, 76.79599955677986, 79.65821117162704, 75.66141083836555, 75.97193777561188, 72.9247596859932, 66.69435560703278, 61.90446563065052, 64.22093152999878, 69.69152078032494, 75.26808634400368, 76.29384130239487, 73.54056984186172, 75.66617578268051, 48.63765612244606, 56.31413720548153, 71.52838781476021, 72.12215155363083, 77.94786214828491, 74.14824843406677, 78.74977111816406, 63.22317346930504, 58.67764078080654, 61.19152508676052, 62.922499403357506, 59.32628117501736, 62.58947767317295, 75.34915879368782, 79.68499213457108, 81.23897954821587, 77.11458966135979, 76.78541332483292, 78.47243160009384, 70.47448396682739, 69.0842753648758, 66.64341554045677, 64.50604543089867, 62.19640016555786, 63.44207592308521, 61.249137595295906, 65.11752381920815, 68.18681672215462, 75.48177167773247, 79.22808185219765, 78.421970307827, 79.4902753829956, 77.0104144513607, 75.07131770253181, 67.48751744627953, 65.4887942969799, 74.14380267262459, 73.351119607687, 75.6848555803299, 47.763410434126854, 14.026899822056293, 1.2170383566990495, 3.0448989244177938, 9.780143201351166, 8.19380147382617, 15.609010476619005, 7.597972545772791, 7.430948233231902, 1.1571918055415154, 2.5488096568733454, 2.4464267631992698, 16.515146903693676, 48.24851520359516, 88.70940148830414, 73.0688251554966, 44.72369894385338, 72.34120979905128, 84.78062510490417, 55.86690880358219, 0.90922144590877, 0.40204179065767676, 0.29778954572975636, 0.15881777711911127, 0.3153955744346604, 0.09506978531135246, 0.12702056381385773, 0.10651007338310592, 0.22156147984787822, 0.23474459041608498, 0.09673874184954911, 0.11103496261057444, 0.20509616180788726, 0.14714361605001613, 0.14640307141235098, 0.20488996349740773, 0.17776461434550583, 0.09145977863227017, 0.21151603606995195, 0.16713624325348064, 0.1747125171823427, 0.11703279975336045, 0.12130627903388813, 0.2516808605287224, 0.07760480177239515, 0.10205162863712758, 0.12338001775788143, 0.2065413014497608], [0.027764334590756334, 0.09100745446630754, 0.1703152625123039, 0.062035448936512694, 0.01412920320944977, 0.08920782056520693, 0.02801158479996957, 0.035120109023409896, 0.01962369446118828, 0.07484915549866855, 0.08837170957121998, 0.02060044429526897, 0.028398945069056936, 0.02307518952875398, 0.03194881181116216, 0.008131892063829582, 0.05368435427953955, 0.037667564320145175, 0.0409768564713886, 0.04780614392075222, 0.03865289152599871, 0.017146264508483, 0.04695008770795539, 0.1266352110542357, 0.052139176841592416, 0.09618074327590875, 0.05638428010570351, 0.09836533659836277, 0.09607332482119091, 0.12189213783130981, 0.11786295130150393, 0.23550880956463516, 0.38029739807825536, 1.263184268027544, 22.04426821321249, 86.15134835243225, 86.26108646392822, 31.885457038879395, 59.912855699658394, 83.57083842158318, 34.311892837285995, 6.835250873118639, 0.7914854167029262, 0.29775172588415444, 0.518784262239933, 2.573598576709628, 2.7563291089609265, 2.566208685748279, 0.7867742038797587, 1.5215104375965893, 0.2711391117190942, 0.836821140255779, 3.14099149312824, 0.455177694093436, 1.0533266351558268, 0.30263856053352356, 0.10827207297552377, 1.070636606309563, 17.900041490793228, 21.669099144637585, 12.400217559188604, 28.16516026854515, 65.66873744130135, 73.21544408798218, 75.09979337453842, 72.50625774264336, 71.76405876874924, 64.25548687577248, 68.52867677807808, 69.11218866705894, 71.60391256213188, 74.21898543834686, 72.92915984988213, 68.53078186511993, 71.55253931879997, 72.98689395189285, 72.4593834578991, 69.69649851322174, 68.84037405252457, 65.00375792384148, 65.98362654447556, 59.08575788140297, 57.35022380948067, 53.473474234342575, 62.501174211502075, 65.11316925287247, 71.40559360384941, 62.947882041335106, 71.96816101670265, 29.39451590180397, 49.47432182729244, 57.01552256941795, 69.14628803730011, 73.52409392595291, 67.98272967338562, 70.31338781118393, 53.7045968323946, 52.43704944849014, 51.51928089559078, 57.19972908496857, 55.250046104192734, 57.21128806471825, 68.70051875710487, 73.33788871765137, 73.6079478263855, 69.44951176643372, 66.13952457904816, 60.708848387002945, 54.3368449062109, 48.43235693871975, 40.80028407275677, 34.51738581061363, 33.36949020624161, 29.664903692901134, 34.94496546685696, 38.790385723114014, 57.43098087608814, 75.71811899542809, 76.40750080347061, 69.51571181416512, 71.26545712351799, 75.28344511985779, 75.96436098217964, 67.07230612635612, 55.712215304374695, 40.83034425973892, 52.268251106143, 50.01573197543621, 15.318863745778799, 1.8009555176831782, 2.128655989654362, 7.145726513117552, 9.736941419541836, 2.2194632794708014, 1.9043040345422924, 0.7160889124497771, 0.33157002995721996, 0.7335398916620761, 1.291033923625946, 10.157752688974142, 27.596663273870945, 68.28538343310356, 57.245604023337364, 28.127675279974937, 54.75872486829758, 61.67740121483803, 61.99639409780502, 1.3519960711710155, 0.2536463050637394, 0.0467518934601685, 0.060119308982393704, 0.007051336642689421, 0.06358225538861006, 0.05220846374868415, 0.061541935574496165, 0.0720311762415804, 0.058232201845385134, 0.04914398385153618, 0.09717917680973187, 0.04609767915098928, 0.04323706350987777, 0.022209323979041073, 0.02737498165515717, 0.032440302820759825, 0.010143866475118557, 0.06207810758496635, 0.07445625509717502, 0.03573429930838756, 0.0031572059151585563, 0.027210364023630973, 0.016006004698283505, 0.028541231476992834, 0.05338166192814242, 0.009708211873658001, 0.07622756864293478, 0.0067416894398775185, 0.11940163123654202, 0.07146324031054974, 0.04603321991453413, 0.04791135077539366, 0.018147265873267315, 0.0689667668484617, 0.013640421038871864, 0.09034143629833125, 0.10702087878598832, 0.021012724027968943, 0.056341354284086265, 0.09098769107367843, 0.054102803114801645, 0.04486192534386646, 0.059604967245832086, 0.01814964631194016, 0.05246471249847673, 0.053443646102095954, 0.006617009557885467, 0.015571265721519012, 0.06868150012451224, 0.04165319049207028, 0.09830160837736912, 0.06030507225659676, 0.009152269049081951, 0.07820686165359803, 0.043515643483260646, 0.0403862219536677, 0.12159671110566705, 0.2125841795350425, 0.08348913484951481, 0.407062093145214, 0.3368482139194384, 1.5516993426717818, 26.780588664114475, 96.19208917021751, 85.58029979467392, 27.11886741220951, 88.83867055177689, 90.1464007794857, 46.03558994829655, 10.82479739561677, 1.4161016000434756, 0.9771321143489331, 0.5604067537933588, 0.47134208609350026, 1.8058294686488807, 4.0489530097693205, 2.7679315488785505, 4.349409062415361, 0.7118692388758063, 3.5071054100990295, 7.420852649956942, 2.2668970841914415, 4.551830375567079, 1.7875463934615254, 0.6509839778300375, 1.8584337271749973, 20.537103787064552, 24.630542434751987, 16.330993585288525, 30.894371420145035, 71.22991383075714, 81.02173000574112, 83.9029709994793, 67.19692423939705, 69.2026162147522, 64.92491975426674, 72.20484271645546, 72.87806779146194, 76.3454121351242, 76.16552218794823, 76.83315396308899, 72.018713504076, 76.8512561917305, 78.73611465096474, 77.98567771911621, 74.55978915095329, 72.52420797944069, 68.22165325284004, 71.23028621077538, 64.07063439488411, 63.40141050517559, 58.41752573847771, 70.7535257935524, 72.43917614221573, 76.5067970752716, 71.14422082901001, 75.57529225945473, 36.993234157562256, 51.964028030633926, 64.60146591067314, 69.9466922879219, 76.3572447001934, 73.13203856348991, 75.96756041049957, 56.87728978693485, 57.55264274775982, 53.94313283264637, 60.87514266371727, 58.55384722352028, 59.22446183860302, 71.91685616970062, 74.56570163369179, 77.06350520253181, 74.28077012300491, 71.3525028526783, 69.56975251436234, 67.10608631372452, 58.50463606417179, 55.07475011050701, 48.26397657394409, 47.579044327139854, 45.07054053246975, 48.05653430521488, 51.82228423655033, 66.15549132227898, 75.71434959769249, 74.76230308413506, 69.88046944141388, 74.14957836270332, 76.65876612067223, 82.66395628452301, 74.5362076163292, 62.18132637441158, 52.15402163565159, 61.37785188853741, 52.769117429852486, 14.683871269226074, 2.146577015519142, 2.724292790517211, 8.803592752665281, 9.256895128637552, 4.450934864580631, 0.7402126304805279, 0.540876870509237, 0.34746092569548637, 1.0097073507495224, 2.2577369632199407, 17.888617403805256, 43.7470031529665, 64.79897931218147, 85.23596227169037, 34.57513891160488, 52.33594827353954, 68.68060022592545, 65.9750086069107, 2.415431351400912, 0.3351541282609105, 0.05118851906445343, 0.043999998742947355, 0.0652977371646557, 0.08957765501691028, 0.044131477625342086, 0.06369723632815294, 0.054536243333132006, 0.07670857681659982, 0.04274635917681735, 0.10620951099554077, 0.04346133311628364, 0.0817854458000511, 0.026221147963951807, 0.00932933806325309, 0.025565445648680907, 0.03559321332431864, 0.04972443981387187, 0.07584998616948724, 0.07048942381516099, 0.04421580415510107, 0.05963571813481394, 0.057790479258983396, 0.026766986447910313, 0.03352664745762013, 0.009222018870786997, 0.08092629854218103, 0.013256968177302042, 0.1552998783881776, 0.09849136811681092, 0.2813610975863412, 0.13118349277647212, 0.120785677281674, 0.19373331684619188, 0.09709005229524337, 0.1856474397936836, 0.23463623685529456, 0.19682085898239166, 0.15526050003245473, 0.4234069457743317, 0.11060096949222498, 0.10066588307381608, 0.1506284743663855, 0.10887417738558725, 0.11563793319510296, 0.0979266976355575, 0.16191655537113547, 0.1874125935137272, 0.17939808138180524, 0.23416040145093575, 0.17421683674911037, 0.21402050246251747, 0.18372269463725388, 0.1776927150785923, 0.20203235355438665, 0.27615196304395795, 0.31457838078495115, 0.37284715566784143, 0.3480278671486303, 0.9301240649074316, 0.48628211254253983, 2.1988439233973622, 42.293204963207245, 111.4022321999073, 104.14272174239159, 51.13845393061638, 82.6218393445015, 103.078892827034, 57.40529045462608, 12.073345798999071, 1.6343710315413773, 2.0824955916032195, 2.0567358238622546, 4.528929954394698, 9.540188927203417, 12.485964708030224, 5.673815170302987, 4.422263503074646, 0.23858330474467948, 4.067646581679583, 7.361463261768222, 1.094960526097566, 2.256760415621102, 1.376890316605568, 0.3611415869090706, 1.9517020974308252, 24.73842054605484, 28.093596808612347, 21.709392182528973, 35.95752753317356, 80.14855965971947, 93.79392385482788, 103.01512464880943, 81.13366439938545, 86.66293770074844, 75.85795149207115, 80.87663099169731, 82.17990025877953, 85.1746715605259, 82.9771126806736, 79.77906748652458, 72.30751320719719, 80.13530597090721, 79.76832926273346, 80.54929375648499, 75.94484522938728, 75.21555036306381, 70.21163687109947, 72.5677840411663, 66.39866307377815, 66.2467548251152, 61.7681859433651, 74.33527439832687, 75.42027577757835, 79.65365141630173, 71.19346618652344, 79.55104172229767, 41.48670583963394, 60.97131170332432, 69.8464384675026, 72.99781456589699, 78.50390151143074, 77.28334620594978, 78.65798324346542, 61.8654341250658, 59.50846239924431, 59.13193300366402, 66.0808177292347, 63.60995851457119, 63.446202501654625, 74.61154237389565, 78.02730828523636, 80.97735598683357, 75.70479691028595, 76.39470309019089, 75.23662403225899, 74.0069568157196, 68.3963830769062, 63.414645195007324, 57.89532735943794, 62.32610620558262, 55.76257400214672, 62.63180360198021, 61.32194548845291, 75.74636667966843, 79.74046155810356, 81.970045119524, 78.47226440906525, 84.75161746144295, 91.21197000145912, 99.96470153331757, 85.27370944619179, 74.13890093564987, 63.34923930466175, 68.84790524840355, 57.33839884400368, 18.952714204788208, 2.4649422196671367, 4.574007410556078, 11.777287535369396, 17.16714821755886, 9.0028958581388, 10.933562759310007, 2.4211733182892203, 1.0490137478336692, 1.9071990041993558, 1.56880471855402, 14.816794786602259, 44.257995933294296, 82.986551374197, 76.92459225654602, 42.73659557104111, 70.59439793229103, 73.65741357207298, 90.07178038358688, 4.841389087960124, 0.6484553322661668, 0.16822325211251155, 0.11662700824672356, 0.27355020109098405, 0.13798248575767502, 0.09181801331578754, 0.12960777967236936, 0.15972616587532684, 0.3072215005522594, 0.1209180022124201, 0.22418638196540996, 0.1610015911865048, 0.1004086175817065, 0.17944735998753458, 0.09711288817925379, 0.14065550873056054, 0.0680633207957726, 0.14764130028197542, 0.12939736596308649, 0.10915303937508725, 0.11101105803390965, 0.12720187049126253, 0.1804264754173346, 0.10610461584292352, 0.14703141816426069, 0.07185455251601525, 0.18409525277093053, 0.08169670720235445], [0.011728331355698174, 0.02167520586226601, 0.07802177002304234, 0.06659826933173463, 0.11078586074290797, 0.08869267359841615, 0.07174719343311153, 0.04189287079498172, 0.0820643077895511, 0.019991317312815227, 0.06391395087121055, 0.050195941075799055, 0.025270480909966864, 0.04244811229000334, 0.049101165641332045, 0.09243115346180275, 0.06554341773153283, 0.032627324035274796, 0.05317950090102386, 0.09006811073049903, 0.048399205261375755, 0.05243708976195194, 0.01989814994885819, 0.028710684200632386, 0.09001020094729029, 0.03854943613987416, 0.1483760413248092, 0.056242663486045785, 0.0312406693410594, 0.006489138904726133, 0.0727933099551592, 0.12561622745124623, 0.35465132736135274, 0.03410195291507989, 0.24742137815337628, 50.871085077524185, 74.3134331703186, 77.22244307398796, 37.37712375819683, 60.079514756798744, 82.41095826029778, 40.320586413145065, 14.098252393305302, 0.2478618427994661, 0.19105766667053103, 0.33843833953142166, 1.893914679531008, 0.3539237257791683, 1.5694810822606087, 5.295596290379763, 3.487402517348528, 1.1584014468826354, 3.640063600614667, 7.083869632333517, 5.887290565297008, 0.6622421205975115, 1.3015845324844122, 0.06771697531803511, 3.7451699981465936, 9.89379795268178, 8.12026496976614, 21.796097829937935, 40.24418391287327, 43.98535296320915, 55.70962004363537, 78.50150763988495, 86.42839908599854, 86.37513354420662, 79.09347027540207, 67.73656368255615, 61.93361006677151, 61.26204550266266, 62.970460429787636, 60.658991262316704, 64.34706196188927, 64.88600224256516, 67.35029920935631, 64.20396164059639, 66.96503788232803, 63.338482081890106, 64.50088530778885, 57.65581861138344, 60.65078750252724, 50.690533965826035, 58.58994908630848, 58.34294714033604, 72.27325424551964, 55.97305230796337, 76.16657093167305, 19.497878551483154, 8.816693499684334, 64.77605894207954, 72.21343025565147, 73.23163881897926, 69.72635731101036, 62.42994703352451, 52.09080822765827, 55.198612064123154, 56.44743785262108, 60.56117311120033, 57.170881032943726, 69.34027522802353, 59.96063433587551, 68.191779255867, 67.35954031348228, 66.78840816020966, 65.97720488905907, 62.33191229403019, 49.67441909015179, 42.50556796789169, 31.953819170594215, 30.55814266204834, 23.593260794878006, 27.107549719512463, 30.458329617977142, 44.30213816463947, 57.55798526108265, 56.14688538014889, 36.563332825899124, 27.00155820697546, 21.11742004752159, 26.473270654678345, 43.71187023818493, 65.79901725053787, 76.39118447899818, 58.734892308712006, 36.657240986824036, 6.2055519875139, 0.2759096072986722, 0.02592447814095067, 1.1583849415183067, 1.8493501958437264, 5.037006391212344, 0.6607055780477822, 0.6367494072765112, 0.24306373932631686, 0.3113042627228424, 0.8672796527389437, 15.443490408360958, 26.113637052476406, 68.07328641414642, 60.480526238679886, 24.5878479257226, 46.32285833358765, 58.99650067090988, 70.00833258032799, 7.0793967973440886, 0.5351533088833094, 0.14594098058296368, 0.14053161459742114, 0.097293482394889, 0.010812009968503844, 0.11689747654600069, 0.06981358703342266, 0.07898125564679503, 0.06942238615010865, 0.05685542884748429, 0.05665912707627285, 0.030355810376931913, 0.07597232179250568, 0.10165492101805285, 0.036001298067276366, 0.03216149649233557, 0.018706993650994264, 0.08301352951093577, 0.1619836306781508, 0.05600201096967794, 0.04732378132757731, 0.03556341980583966, 0.041734789629117586, 0.03809588743024506, 0.07531003662734292, 0.0025666465398899163, 0.047336802308564074, 0.026960046889143996, 0.06004513503285125, 0.023164816848293412, 0.0826517993118614, 0.05320632582879625, 0.08461667981464416, 0.07305787818040699, 0.03384246469067875, 0.06684506312012672, 0.09088466613320634, 0.0846174442267511, 0.007584365657749004, 0.05347847880329937, 0.017235459527000785, 0.03765167864912655, 0.006101909903009073, 0.015418012226291467, 0.06069431015930604, 0.051359213030082174, 0.039619086164748296, 0.053689790511270985, 0.049648109925328754, 0.032716029236325994, 0.08251853927504271, 0.05294686729030218, 0.03218748279323336, 0.1046189697808586, 0.05360449547879398, 0.08314365026308224, 0.038409953194786794, 0.09495443329797126, 0.004916833186143776, 0.015858551087148953, 0.1154679294268135, 0.14275790919782594, 0.026742135632957797, 0.7091845641843975, 57.043667659163475, 88.49641531705856, 72.3862373828888, 31.41813911497593, 90.09981527924538, 85.48597365617752, 50.44854775071144, 20.171633698046207, 0.920827507507056, 0.2127439936157316, 0.7454475027043372, 1.33958890568465, 0.4220750875538215, 4.420707011595368, 3.3145258063450456, 4.838501717895269, 3.4102379204705358, 5.808538366109133, 8.759766854345798, 14.646182041615248, 2.892581010237336, 3.521982324309647, 0.18891697138315067, 4.675059663131833, 11.888990141451359, 10.977193918079138, 24.5095132291317, 44.67119336128235, 60.32776303589344, 73.78114253282547, 83.42567101120949, 86.31353884935379, 81.51739060878754, 76.89707413315773, 70.34658282995224, 68.42774659395218, 65.71640208363533, 68.25195282697678, 67.46933162212372, 72.88914039731026, 72.7885065972805, 76.5120179951191, 72.41165801882744, 74.06433373689651, 69.78013202548027, 69.75078999996185, 62.447030916810036, 65.31061425805092, 56.513626500964165, 64.67667147517204, 64.03599545359612, 77.11533442139626, 62.18619391322136, 83.58014792203903, 22.90240466594696, 13.891797121614218, 72.05690905451775, 75.8794279396534, 79.68620046973228, 75.28412908315659, 68.04230287671089, 55.357846319675446, 58.621673583984375, 60.68710595369339, 65.52451997995377, 61.73970267176628, 72.27739602327347, 63.31985928118229, 71.22410014271736, 71.0900205373764, 68.14447939395905, 72.12438583374023, 69.0622441470623, 62.22080245614052, 55.360145196318626, 45.9030644595623, 44.860351011157036, 38.71167294681072, 42.530069053173065, 45.6251435726881, 53.399564400315285, 63.112405613064766, 56.1863424628973, 39.77636821568012, 30.069625675678253, 27.27427527308464, 31.802877970039845, 50.52375331521034, 72.05567792057991, 81.17096319794655, 67.7885676920414, 40.97048833966255, 6.322009088471532, 0.23520194634329528, 0.3303097444586456, 2.2162099415436387, 4.154414450749755, 7.723268922418356, 2.7369387494400144, 0.377166781690903, 1.0161901591345668, 0.3904929041163996, 1.5397096797823906, 26.330580711364746, 44.71250094473362, 57.073758244514465, 92.8101946413517, 35.03904081881046, 39.93822053074837, 60.68273238837719, 77.58052065968513, 6.402352452278137, 0.5485609488096088, 0.09177573316264898, 0.14094381825998425, 0.09588454471668229, 0.03789531459915452, 0.019238607019360643, 0.021380708676588256, 0.09938460963894613, 0.02640129874635022, 0.0644561491208151, 0.001430189424809214, 0.036354211551952176, 0.018487336492398754, 0.08652837059344165, 0.03926966448489111, 0.011359991403878666, 0.022249980684136972, 0.017934577481355518, 0.08168498126906343, 0.03293651760031935, 0.022040611547708977, 0.057490239705657586, 0.06760068819858134, 0.0034387291998427827, 0.10070776988868602, 0.06112156457675155, 0.0521725771977799, 0.07583682789118029, 0.05717649306461681, 0.10347520146751776, 0.1446580744232051, 0.15841764077777043, 0.17247859330382198, 0.19706570834387094, 0.21936353528872132, 0.18891808460466564, 0.2475283810053952, 0.24717958644032478, 0.1490278251003474, 0.08826014251098968, 0.0910878884315025, 0.10441648220876232, 0.10246683057630435, 0.11605818173848093, 0.23521629947936162, 0.154097628837917, 0.14376592385815457, 0.1564031996531412, 0.10468104301253334, 0.1419848288060166, 0.2771234046667814, 0.16037553024943918, 0.1998466841178015, 0.20288613508455455, 0.19063375191763043, 0.2602898923214525, 0.13465151918353513, 0.15501766931265593, 0.06738449315889739, 0.1466418500058353, 0.2358794678002596, 0.39837329532019794, 0.2083956019487232, 0.975371265085414, 81.45109176635742, 100.26517421007156, 98.38133409619331, 53.36945481598377, 79.24831956624985, 99.91052404046059, 63.31510193645954, 21.25096008181572, 0.6600606814026833, 0.40334814868401736, 3.9148605801165104, 3.99583138525486, 1.331774031277746, 11.279221661388874, 18.70472051203251, 14.965273719280958, 4.417067281901836, 6.603299444541335, 17.54028059542179, 17.5140468031168, 2.2122973389923573, 2.3981866892427206, 0.1808707250165753, 5.536195104941726, 11.42053797841072, 12.482352051883936, 28.209291100502014, 52.005890384316444, 69.18462038040161, 85.71657568216324, 95.36737382411957, 99.62501496076584, 91.46154820919037, 88.52383464574814, 79.17132809758186, 72.85909920930862, 68.30824300646782, 66.75264447927475, 68.8187988102436, 73.17600980401039, 74.32714283466339, 78.89333501458168, 75.48289641737938, 76.24011218547821, 71.50234401226044, 73.61645177006721, 64.89696845412254, 70.48129320144653, 59.867752119898796, 67.18702957034111, 66.72738343477249, 80.36055788397789, 65.64935848116875, 89.37527775764465, 26.150747761130333, 11.710841450840235, 76.49389296770096, 80.8164194226265, 83.74375194311142, 78.94436627626419, 68.93803641200066, 59.394491314888, 63.30999881029129, 65.1097646355629, 70.16024082899094, 67.59032472968102, 77.49852105975151, 67.24708154797554, 74.26304027438164, 73.92905339598656, 72.6798552274704, 78.0345430970192, 76.74281761050224, 71.3260106742382, 66.61892205476761, 57.331209629774094, 60.16302667558193, 52.66857482492924, 55.266598016023636, 59.66087222099304, 65.88671654462814, 70.79981490969658, 58.65289270877838, 41.54565967619419, 30.22674724459648, 26.24614354223013, 31.328954100608826, 52.95367732644081, 77.3204018175602, 89.52300623059273, 80.26626974344254, 51.457705199718475, 8.652340918779373, 0.3967642004135996, 0.19752638909267262, 2.6109771709889174, 3.609901531599462, 12.558178883045912, 5.103723686188459, 2.0311598712578416, 2.9351123655214906, 0.5137648503296077, 1.0319045721553266, 21.5102144703269, 46.30759075284004, 82.5062495470047, 80.21860510110855, 39.8246294260025, 64.69959184527397, 68.2125261425972, 98.27675610780716, 16.014918945729733, 0.7538791315164417, 0.12945440743351355, 0.17827498930273578, 0.21229131321888417, 0.17552895384142175, 0.2422305746586062, 0.19703560683410615, 0.268938762601465, 0.1588549290318042, 0.24749559292104095, 0.22775538498535752, 0.12659314612392336, 0.26375806715805084, 0.283383242203854, 0.13679277850314975, 0.1612813214887865, 0.11187295865966007, 0.18602413911139593, 0.2788791776401922, 0.18459274404449388, 0.15820669272216037, 0.20671962469350547, 0.21585549227893353, 0.15244664711644873, 0.21600313513772562, 0.1159004976216238, 0.192268421233166, 0.19944072933867574, 0.1457329565891996], [0.06406408734619617, 0.065205822174903, 0.06225317651114892, 0.11007262713974342, 0.04958261539286468, 0.03659115704067517, 0.04661907871195581, 0.0353658823587466, 0.05644466495141387, 0.1166541782731656, 0.04659625767089892, 0.015608374960720539, 0.04767590813571587, 0.041569171953597106, 0.05814070987980813, 0.04511591054324526, 0.13155999913578853, 0.04572470912535209, 0.005083553878648672, 0.013161732076696353, 0.0544423839164665, 0.021698279233532958, 0.0047751173042343, 0.04602190958394203, 0.0468071352224797, 0.07207649920019321, 0.024818177153065335, 0.04313804616685957, 0.0305152515284135, 0.04671720918850042, 0.021792756488139275, 0.047281972438213415, 0.05906328107812442, 0.03872037872497458, 0.40514132590033114, 2.4168085400015116, 75.1533704996109, 75.36204770207405, 82.10255920886993, 41.633077785372734, 52.04645700752735, 83.79650831222534, 43.94188329577446, 24.32648465037346, 0.617763310438022, 0.6364356866106391, 0.42940373648889363, 1.5371376927942038, 0.2644776238594204, 1.7903762916103005, 3.3953085215762258, 3.372083930298686, 5.771488454192877, 9.447821583598852, 15.73920289054513, 3.474070932716131, 3.0632669012993574, 0.9437466308008879, 0.42787155776750296, 0.6668168969918042, 1.999613014049828, 5.521930195391178, 10.040662921965122, 11.979651376605034, 19.505158960819244, 42.64043413102627, 58.83120194077492, 72.539391964674, 77.88910210132599, 73.03708165884018, 65.02757504582405, 65.36799117922783, 68.38932305574417, 62.99579747021198, 66.88864678144455, 61.771563962101936, 64.21336993575096, 59.65644545853138, 59.596218690276146, 52.76502884924412, 58.232247680425644, 57.12903007864952, 58.81659932434559, 54.44589525461197, 59.88047383725643, 59.56281088292599, 72.21948713064194, 53.82910095155239, 64.01073440909386, 14.483445324003696, 1.1821043374948204, 63.04096944630146, 68.36848497390747, 75.16586422920227, 67.96166360378265, 57.46343873441219, 53.84427733719349, 57.069882452487946, 56.69435240328312, 65.22849306464195, 62.93015979230404, 70.77232718467712, 74.2003284394741, 73.3967399597168, 75.42844533920288, 71.51347741484642, 63.40601585805416, 54.57285784184933, 47.75128908455372, 40.541415363550186, 36.73799425363541, 29.975512325763702, 27.844151593744755, 32.067372277379036, 33.960867673158646, 29.058260545134544, 19.380295760929585, 11.04183129966259, 3.7177390325814486, 1.2278314400464296, 0.6424463109578937, 0.06318377403658815, 0.700729958480224, 3.67290903814137, 11.472864970564842, 10.644877050071955, 1.2087843683548272, 0.08906557312002406, 0.18720725609455258, 0.3627454274101183, 0.889153357129544, 2.253236579708755, 1.5717883897013962, 2.1621780283749104, 0.5798815400339663, 0.5181081360206008, 0.35512864706106484, 25.532235950231552, 24.712735824286938, 60.40285460650921, 68.43020886182785, 26.752916648983955, 60.616125762462616, 60.29398284852505, 74.97216582298279, 15.349216517060995, 0.2621831407304853, 0.061748178413836285, 0.07071484375046566, 0.10859772737603635, 0.05083406933408696, 0.10135122676729225, 0.02375513780862093, 0.05125861491251271, 0.06748967774910852, 0.03872894310916308, 0.030450306185230147, 0.07484390851459466, 0.0645255547715351, 0.011973771652264986, 0.016748592097428627, 0.005462974095280515, 0.0037086559632371063, 0.03837741372990422, 0.04147634783294052, 0.07350010171649046, 0.02035535559116397, 0.019078881996392738, 0.038651485156151466, 0.07875726063502952, 0.035887916455976665, 0.03958293244068045, 0.02695200571906753, 0.05451348166388925, 0.05770426396338735, 0.14279197377618402, 0.07701927694142796, 0.023635139950783923, 0.05097009758173954, 0.06835989042883739, 0.15445372613612562, 0.12299071677261963, 0.14119539147941396, 0.019246369884058367, 0.06951254967134446, 0.018785870961437467, 0.01933018062118208, 0.01183218193546054, 0.02387571454164572, 0.015699095092713833, 0.08060234365984797, 0.06835735228378326, 0.09620535289286636, 0.01543322254292434, 0.03466802605544217, 0.015285533299902454, 0.10264087904943153, 0.042445837607374415, 0.04136738942179363, 0.021389363973867148, 0.017731152947817463, 0.024095147200569045, 0.0653014107956551, 0.02662010614585597, 0.04033315468404908, 0.040767407554085366, 0.017916743672685698, 0.07162232708651572, 0.11076314360252582, 0.0019597840355345397, 0.49708742648363113, 3.8174613565206528, 85.44172123074532, 85.09150922298431, 74.4858755171299, 35.030339285731316, 88.37818086147308, 94.01004865765572, 59.37396101653576, 41.58758282661438, 0.525951033923775, 0.3962256386876106, 0.9715071099344641, 0.8199781877920032, 0.7634067046456039, 1.2154835276305676, 2.5082601327449083, 4.2485173512250185, 3.821226479485631, 7.251529460772872, 10.069832056760788, 8.815264776349068, 7.112898649647832, 1.9532319903373718, 1.3271316303871572, 2.473234087228775, 2.0872864220291376, 7.8826418705284595, 17.129095159471035, 20.39100542664528, 33.498998656868935, 54.93344709277153, 65.97494781017303, 79.71066355705261, 81.46840363740921, 80.02993002533913, 75.4896068572998, 72.28844583034515, 74.41743358969688, 71.93267092108727, 74.9520269036293, 72.52159371972084, 75.60549303889275, 67.58137241005898, 69.60266634821892, 60.30016131699085, 65.16176104545593, 64.74009767174721, 67.07843899726868, 60.68098068237305, 66.58490628004074, 66.53013601899147, 80.97458973526955, 62.76752091944218, 75.85355132818222, 16.476379483938217, 1.0547665203921497, 70.08385732769966, 73.2074873149395, 81.38446614146233, 71.77899196743965, 63.999251425266266, 60.17718091607094, 60.950959995388985, 63.39762970805168, 68.20667445659637, 63.86869803071022, 72.685516923666, 72.61390596628189, 74.00618925690651, 76.36251881718636, 76.57574817538261, 69.17627602815628, 67.80478522181511, 60.36745570600033, 54.164360761642456, 48.95743176341057, 47.12389715015888, 44.39371705055237, 47.99881540238857, 43.95249232649803, 31.98965884745121, 21.29573877900839, 13.409061525017023, 5.50365555100143, 1.8970067636109889, 1.4540308085270226, 1.2337764585390687, 0.9493559610564262, 6.227936586365104, 12.987896874547005, 10.687738750129938, 1.5428782347589731, 0.1339497888693586, 0.03471314121270552, 0.9466956288088113, 2.1957195410504937, 1.799505539238453, 1.3355955574661493, 0.5728582106530666, 0.3848376200767234, 0.2847171784378588, 0.8714206586591899, 39.97697465121746, 42.437783405184746, 48.465719148516655, 94.27851185202599, 31.771166771650314, 47.48383283615112, 59.36433993279934, 83.26943099498749, 14.702912047505379, 0.4918101034127176, 0.11356295508448966, 0.14770527341170236, 0.037997582548996434, 0.03876505230437033, 0.07439753637299873, 0.01165065354143735, 0.04026901828183327, 0.07652995671378449, 0.023347511341853533, 0.03283174861280713, 0.060222820029594004, 0.07763100700685754, 0.021242767543299124, 0.06122297163528856, 0.023001924710115418, 0.035306291611050256, 0.032579077014815994, 0.06973083756747656, 0.024592861118435394, 0.01887568381789606, 0.07064445846481249, 0.03450879827141762, 0.05682852970494423, 0.004669562567869434, 0.021395638832473196, 0.04372161172796041, 0.0069782132959517185, 0.06545516895130277, 0.07431645673932508, 0.12397186568705365, 0.12525772559456527, 0.11040974030038342, 0.2058365728589706, 0.1866842943127267, 0.15754765074234456, 0.2053365285973996, 0.1299646933330223, 0.23196615278720856, 0.14573781023500487, 0.15147861937293783, 0.10310389014193788, 0.14773207978578284, 0.085871992923785, 0.14641396614024416, 0.1248813231359236, 0.13304913329193369, 0.16031565377488732, 0.10867126678931527, 0.13460051879519597, 0.1645102130714804, 0.16200590995140374, 0.2046358521329239, 0.12452011986169964, 0.11801377797382884, 0.13374690053751692, 0.1475823885994032, 0.13411322463070974, 0.13352517649764195, 0.14815057686064392, 0.18024800374405459, 0.14650251920102164, 0.1559632396674715, 0.11400386501918547, 0.8764078316744417, 7.1868018340319395, 113.93538907170296, 96.05722680687904, 109.07770693302155, 56.765959560871124, 76.2110285460949, 99.7095300257206, 68.29669162631035, 37.16539531946182, 0.7960427971556783, 0.8575742016546428, 2.175836870446801, 2.051483793184161, 3.6416241293773055, 10.252810288220644, 15.657737161964178, 14.19421149417758, 16.655754558742046, 27.444101460278034, 37.706414088606834, 12.761087995022535, 7.172517450526357, 2.0601938758045435, 1.9445277261547744, 1.4403749350458384, 3.29429735429585, 8.076674658805132, 13.544929884374142, 20.230918116867542, 31.847392581403255, 54.06001076102257, 64.01389583945274, 79.30537730455399, 86.26620098948479, 84.67382803559303, 83.37636485695839, 78.3038954436779, 78.2440410554409, 73.69131535291672, 79.68094915151596, 74.65471565723419, 78.6787985265255, 71.28384813666344, 73.68329018354416, 62.75425583124161, 68.91527563333511, 67.56651520729065, 70.72622805833817, 64.25169467926025, 72.20583066344261, 70.73803782463074, 86.82419344782829, 65.92909947037697, 84.35838416218758, 17.95417908579111, 2.6201586658135056, 75.95505148172379, 77.10081160068512, 86.4362570643425, 76.01916924118996, 67.19581469893456, 63.09542052447796, 65.57441130280495, 67.3431783914566, 75.98853528499603, 69.3821793794632, 75.03518924117088, 79.55145969986916, 77.57472977042198, 80.99989637732506, 79.72522437572479, 75.33654347062111, 75.24734705686569, 72.56590694189072, 66.06415182352066, 63.21660362184048, 61.001219898462296, 58.40472802519798, 62.67812691628933, 55.84809221327305, 36.57892718911171, 24.31854497641325, 13.338455613702536, 5.886097429320216, 2.492859084159136, 3.049611384049058, 1.7296113772317767, 1.1586053296923637, 5.747645208612084, 13.525948952883482, 13.133639954030514, 2.3161920765414834, 0.38698376272805035, 0.33659805078059435, 0.8301707252394408, 4.614986311644316, 7.228459948673844, 8.268591910600662, 4.567377716302872, 1.6947246179915965, 1.1729483725503087, 0.6169459980446845, 33.34454074501991, 45.468158796429634, 69.46017399430275, 89.50011625885963, 35.80602966248989, 77.55709111690521, 66.9385989010334, 100.60518756508827, 29.617147855460644, 0.4120969714131206, 0.2330186517792754, 0.4430128843523562, 0.19138030795147642, 0.09374351546284743, 0.2446457458427176, 0.1548810992971994, 0.17373463371768594, 0.2113964018644765, 0.08128221772494726, 0.08097484984318726, 0.12157520366599783, 0.16305174445733428, 0.09357004586490802, 0.2570511301746592, 0.20020396885229275, 0.14958642481360584, 0.10896759151364677, 0.16515671275556087, 0.22438144806073979, 0.10679853134206496, 0.2220616428530775, 0.1641742279753089, 0.11801886168541387, 0.15562939195660874, 0.11984286029473878, 0.115971231716685, 0.19260207598563284, 0.2502884133718908, 0.27908911637496203], [0.06742692916304804, 0.03544855760992505, 0.1285339958849363, 0.08654793360619806, 0.029519298623199575, 0.02981178644404281, 0.04295062419259921, 0.05986347583530005, 0.023431871268257964, 0.026793705619638786, 0.02673509079613723, 0.03455898600805085, 0.03271716843300965, 0.060680806782329455, 0.017576871578057762, 0.04262924085196573, 0.1165637030499056, 0.00848894023874891, 0.02035260222328361, 0.04490638370043598, 0.006087659276090562, 0.025762381956155878, 0.026696975946833845, 0.010854812408069847, 0.04093045739864465, 0.022170166412252, 0.02840024568286026, 0.04780158713401761, 0.017597006044525187, 0.0229111656153691, 0.07424586365232244, 0.09282787592383102, 0.12400798601447605, 0.038892441953066736, 0.07500640174839646, 0.6371201842557639, 8.191950023174286, 80.60448199510574, 73.59429135918617, 65.1780241727829, 28.001723438501358, 44.80704367160797, 81.48896053433418, 38.93427640199661, 34.851152300834656, 6.30307755433023, 0.7314182398840785, 0.5664840526878834, 0.5919595481827855, 1.0794460773468018, 1.6478852438740432, 4.6669637225568295, 5.937058394774795, 2.5812176428735256, 7.859555734321475, 9.857432954013348, 7.678034724667668, 0.7116272393614054, 0.31749237910844386, 1.3232573820278049, 0.11261481689871289, 0.05576647927227896, 0.24353721470106393, 0.8237735310103744, 1.4329053671099246, 1.4145381026901305, 3.9852703269571066, 8.204313609749079, 15.373855344951153, 20.260752215981483, 18.818465508520603, 17.543527521193027, 20.718240067362785, 28.670225366950035, 45.67077152431011, 47.340713515877724, 48.46190795302391, 45.7206666469574, 51.09080068767071, 51.440134942531586, 57.91172727942467, 57.00494773685932, 63.83278235793114, 57.59808070957661, 63.229336738586426, 56.636793091893196, 66.2909160554409, 51.35522089898586, 58.379656970500946, 10.504234246909618, 2.3542935820296407, 66.35329350829124, 63.51245954632759, 68.61760720610619, 61.91316336393356, 58.4350959956646, 61.82910047471523, 66.93313479423523, 67.81097888946533, 73.03026482462883, 73.64453986287117, 74.43500384688377, 80.52329555153847, 76.73105344176292, 82.10157886147499, 76.08140990138054, 67.7052153646946, 63.22730764746666, 48.03069569170475, 33.783325999975204, 28.985532447695732, 22.441990971565247, 20.276986844837666, 18.93626868724823, 11.48203482851386, 3.982176105491817, 2.2305971570312977, 1.1163995694369078, 0.7523430639412254, 0.5547777120955288, 1.0253454116173089, 0.942535683279857, 0.7890824612695724, 0.03837751391984057, 0.05733842968766112, 0.1271455711685121, 0.19379622128326446, 0.20100018940865993, 0.1268666869145818, 0.984837863361463, 1.4090649713762105, 1.2252001999877393, 1.556330700404942, 1.2685152632184327, 0.23479780240450054, 0.32434166001621634, 34.46929559111595, 21.580237112939358, 60.050309523940086, 84.07605931162834, 24.570659548044205, 72.97075241804123, 60.49551263451576, 68.41717556118965, 33.82976330816746, 0.2117037697462365, 0.094313551671803, 0.07616526534548029, 0.06469405940151773, 0.07706137155764736, 0.047393940258189104, 0.01972005862626247, 0.045408153455355205, 0.02255812596558826, 0.08014262770302594, 0.0534569379669847, 0.032117123482748866, 0.07058657836751081, 0.03207656882295851, 0.031257427035598084, 0.05592283865553327, 0.08075221296167001, 0.04783331765793264, 0.06115242307714652, 0.016485311498399824, 0.019459423783700913, 0.02107578060531523, 0.017611763651075307, 0.04899047431536019, 0.026969741193170194, 0.04015195190731902, 0.05186935050005559, 0.049781974812503904, 0.04934018543281127, 0.05048167906352319, 0.017633336028666236, 0.02570560209278483, 0.046290971513371915, 0.05269904562737793, 0.07376561989076436, 0.0375153349887114, 0.037773613512399606, 0.07652915519429371, 0.022517458128277212, 0.08329665884957649, 0.021071466871944722, 0.032251927186734974, 0.040393721355940215, 0.06968112851609476, 0.025690905713418033, 0.04463577439310029, 0.07081136747729033, 0.04963228362612426, 0.017773468352970667, 0.07623560610227287, 0.08846865632222034, 0.024094032123684883, 0.11934780326555483, 0.10619420791044831, 0.02582052180514438, 0.014356861647684127, 0.06490953455795534, 0.060626618869719096, 0.07675570319406688, 0.0359987228148384, 0.023450074295396917, 0.042841728864004835, 0.08844959796988405, 0.09449343342566863, 0.2079803851665929, 0.0611936159839388, 0.7474143721628934, 10.274066347628832, 90.2626821398735, 83.034907579422, 55.23660622537136, 27.26423431187868, 80.87051331996918, 82.92747974395752, 48.32913167774677, 64.03552427887917, 3.6190151050686836, 0.5240402708295733, 0.3659004159271717, 0.524153255391866, 0.603906522737816, 0.2621016529155895, 2.097311234101653, 2.3017374146729708, 5.894902031868696, 5.8793846145272255, 7.492845011875033, 8.770758714526892, 1.825192873366177, 2.3863588739186525, 2.7511442871764302, 0.7382770499680191, 0.6101292232051492, 1.3561055506579578, 2.033385126851499, 4.1235909797251225, 6.721004778519273, 9.844406303018332, 16.888366676867008, 25.54097168147564, 29.81857694685459, 29.635301381349564, 29.345021657645702, 30.4670824483037, 37.464465871453285, 56.301141902804375, 61.55917055904865, 63.29001948237419, 60.213012993335724, 63.613306134939194, 63.837532103061676, 68.70017677545547, 64.17753025889397, 70.26068463921547, 62.835442274808884, 66.60439163446426, 61.54903270304203, 75.68184614181519, 57.86179415881634, 76.95134282112122, 13.541807401925325, 3.028959254734218, 75.8314897119999, 69.29014831781387, 76.43276944756508, 66.2325967848301, 61.82734116911888, 64.66215625405312, 70.7599626481533, 71.27019166946411, 77.61451363563538, 77.63842955231667, 78.47437709569931, 81.78345993161201, 78.1335885822773, 81.31651818752289, 76.78697124123573, 73.91507774591446, 69.91940975189209, 56.868383064866066, 45.730207934975624, 36.5559384226799, 31.28398161381483, 28.222109712660313, 24.853444173932076, 13.38728204369545, 4.503281805664301, 3.6481289053335786, 1.8213600665330887, 1.2414800701662898, 0.7871956250164658, 1.1567226494662464, 0.8609394554514438, 1.0209642467088997, 0.4287247604224831, 0.09702518116682768, 0.3149270417634398, 0.0984462010092102, 0.7558004034217447, 0.5965321278199553, 0.5223555956035852, 0.8199175691697747, 0.4866918077459559, 0.5076154740527272, 1.0888124560005963, 0.05661573370161932, 0.7343776279594749, 56.19557976722717, 42.77781195938587, 42.14124731719494, 102.5977398455143, 39.585170075297356, 56.421785429120064, 60.49618899822235, 74.77124780416489, 36.52550965547562, 0.27744787163101137, 0.09852964067249559, 0.016716000682208687, 0.07908715269877575, 0.043396487963036634, 0.03180779633112252, 0.07404103089356795, 0.04183928402198944, 0.060593901289394125, 0.04967884597135708, 0.01785480217222357, 0.07363182550761849, 0.009957594829757, 0.038634901866316795, 0.04312984543503262, 0.029538143608078826, 0.05577198971877806, 0.04230671089317184, 0.04306997267121915, 0.05931848339969292, 0.006826357357567758, 0.05220211096457206, 0.041490285366307944, 0.06066541092877742, 0.020332699677965138, 0.04683980827394407, 0.02108772547217086, 0.056479902123101056, 0.013700546132895397, 0.062406151700997725, 0.09010048321215436, 0.20048776612384245, 0.17642287071794271, 0.1814172277227044, 0.20605814846931025, 0.13673465349711478, 0.08959480604971759, 0.2041176994680427, 0.0647324655437842, 0.1074812033039052, 0.10189465698204003, 0.15165332093602046, 0.11147041033837013, 0.12765131512423977, 0.12673854769673198, 0.08912883378798142, 0.15145184268476442, 0.15805274160811678, 0.09833907199208625, 0.17485192220192403, 0.131130488589406, 0.08101936386083253, 0.19422113051405177, 0.24394702864810824, 0.12628558528376743, 0.06816011169576086, 0.1778518909122795, 0.0773699714045506, 0.31016509572509676, 0.17885664012283087, 0.16068730648839846, 0.18964084738399833, 0.26592145732138306, 0.3045157785527408, 0.4012257547583431, 0.15485056734178215, 0.9771604940760881, 19.547501988708973, 117.40394175052643, 95.71883216500282, 88.61790999770164, 39.50470559298992, 64.86365184187889, 97.15023815631866, 57.57426358759403, 54.82152409851551, 8.797216694802046, 0.972614869242534, 0.7743992179166526, 1.3720535323955119, 3.0768024874851108, 3.685232726857066, 12.796243708580732, 14.397329594939947, 16.438278928399086, 20.646465718746185, 25.444040782749653, 22.63823714107275, 2.996207387186587, 3.781004687771201, 2.7342712925747037, 1.115376593079418, 0.9724077209830284, 0.9703821921721101, 1.0540887317620218, 2.2740157647058368, 3.0958748515695333, 4.806523583829403, 9.619221836328506, 18.828730657696724, 25.533799566328526, 27.39064782857895, 27.148551419377327, 29.34632308781147, 36.41371205449104, 59.74287562072277, 66.32644414901733, 71.22298300266266, 68.0733472108841, 71.20443999767303, 70.04829123616219, 76.30492150783539, 70.86255714297295, 75.35906106233597, 67.06247985363007, 72.33155831694603, 65.13255581259727, 79.96997684240341, 62.295669838786125, 86.55023574829102, 14.307892844080925, 5.492384880781174, 84.05005350708961, 72.79276236891747, 79.52622145414352, 69.05029758810997, 66.90555587410927, 68.47323015332222, 75.5810983479023, 77.42185637354851, 83.56222048401833, 81.19661942124367, 83.12093496322632, 85.28767749667168, 84.27940160036087, 89.51888725161552, 86.01712435483932, 84.97165605425835, 82.60335713624954, 70.90548723936081, 57.78418332338333, 46.15307964384556, 39.86432209610939, 39.12947952747345, 33.97173509001732, 17.83774383366108, 6.280852546915412, 4.142193831503391, 2.3993187909945846, 1.6524843033403158, 1.138320118188858, 1.7201549909077585, 1.2127361563034356, 1.2408449104987085, 0.7545467675663531, 0.13901196332881227, 0.32708232232835144, 0.23232452105730772, 0.7602250284980983, 0.5323112395126373, 2.1854064194485545, 7.230534637346864, 6.801750445738435, 3.437348515726626, 2.4317685747519135, 0.6401912507135421, 0.951431302819401, 49.55822892487049, 42.500149458646774, 65.55149093270302, 103.34732562303543, 42.62122616171837, 87.89520397782326, 75.22049769759178, 88.55921074748039, 57.22076095640659, 0.4114837199449539, 0.2518327336292714, 0.22313928580842912, 0.18345406686421484, 0.14138389698928222, 0.17626416985876858, 0.07697558670770377, 0.1375642855418846, 0.11404701348510571, 0.1588644878938794, 0.17392630077665672, 0.1720663154264912, 0.08843128176522441, 0.08724278421141207, 0.12762323225615546, 0.10217955263215117, 0.2202005888102576, 0.09201046705129556, 0.17611104995012283, 0.1683999871602282, 0.148375952267088, 0.16622595459921286, 0.19564798363717273, 0.11518959436216392, 0.11728888523066416, 0.15694024739786983, 0.09526534864562564, 0.16995358426356688, 0.12641891953535378, 0.13515539292711765, 0.14777061209315434], [0.029972776828799397, 0.05701427813619375, 0.020337250898592174, 0.05065848461526912, 0.013497438867489109, 0.019749074745050166, 0.07902996279881336, 0.0714486645301804, 0.08490343825542368, 0.024853761278791353, 0.010820918523677392, 0.048382336244685575, 0.058961324830306694, 0.04418596981849987, 0.03210930495697539, 0.024740971530263778, 0.04331203526817262, 0.05519066544366069, 0.04778471811732743, 0.024182681663660333, 0.07269747642567381, 0.07846584892831743, 0.061158712778706104, 0.030922861296858173, 0.04553075254079886, 0.03919540889910422, 0.14403150882571936, 0.028110711609770078, 0.034247469520778395, 0.06366362445987761, 0.051924039362347685, 0.039748279232298955, 0.02354670377826551, 0.0811470503685996, 0.04566084731777664, 0.1039337003021501, 0.6829836638644338, 16.363449543714523, 98.0169640481472, 71.72582522034645, 80.06554171442986, 41.414547711610794, 48.81368167698383, 105.39461776614189, 41.285240650177, 40.15722557902336, 18.70939616113901, 0.43518215767107904, 0.41379251168109477, 0.16063641000073403, 0.16224437684286386, 0.9161895595025271, 0.8775462268386036, 2.1875742031261325, 4.12748197093606, 5.532846534624696, 10.380873866379261, 3.3504813769832253, 1.6704308590851724, 2.5503989215940237, 0.46554045053198934, 0.2797726937569678, 0.43177228595595807, 0.4873973526991904, 0.07041131277219392, 0.15457956469617784, 0.1701507283723913, 0.20163767941994593, 0.20279114018194377, 0.0869156455155462, 0.4298429691698402, 0.5387468473054469, 0.44231930281966925, 1.4911342738196254, 6.228853287175298, 15.880052782595158, 27.54496894776821, 33.29888239502907, 34.419066086411476, 33.42081405222416, 45.734315514564514, 54.55130159854889, 62.174072563648224, 61.00755415856838, 68.39870095252991, 63.65476191043854, 66.83950781822205, 48.546582609415054, 50.99931299686432, 10.232177395373583, 2.4036439089104533, 68.21451723575592, 67.35821038484573, 71.37786269187927, 69.06539797782898, 70.56257084012032, 75.4612147808075, 72.39153429865837, 76.4974419772625, 74.20445501804352, 81.14934995770454, 82.07999601960182, 88.30656230449677, 89.16894122958183, 98.29530671238899, 88.93475219607353, 78.77417340874672, 53.136641308665276, 30.404100827872753, 14.985375590622425, 5.60987220145762, 3.1620867736637592, 3.232366140000522, 1.7939317133277655, 1.3693502149544656, 1.0851327097043395, 1.4454040839336812, 0.7776748796459287, 0.3688847995363176, 0.2532839885680005, 0.3260323021095246, 0.2974275260930881, 0.07857519696699455, 0.08438570861471817, 0.3313381830230355, 0.1816765489638783, 0.15155244822381064, 0.17362630984280258, 0.6553181202616543, 1.2865243968553841, 0.5116227746475488, 0.49069171654991806, 0.34493536746595055, 0.1773616875289008, 2.0202527940273285, 36.53935231268406, 19.681277610361576, 51.7156695574522, 84.70464438199997, 30.98807819187641, 35.996418446302414, 47.69814133644104, 62.65004262328148, 34.37216140329838, 1.3221614970825613, 0.23638328217202798, 0.05598155737970956, 0.03770323935896158, 0.11073272296926007, 0.09833732794504613, 0.03976138927100692, 0.011881603404617636, 0.04916622972814366, 0.02489736431016354, 0.13411521358648315, 0.039829744782764465, 0.04149425956711639, 0.039148382711573504, 0.05122536669659894, 0.02184962540923152, 0.014359473079821328, 0.011345796901878202, 0.14425176341319457, 0.032408765255240723, 0.05308862491801847, 0.06486320969997905, 0.04063692314957734, 0.06775235349778086, 0.06897873026900925, 0.055630246934015304, 0.02108093296556035, 0.05929968479904346, 0.12972187745617703, 0.05401851740316488, 0.05689511148375459, 0.02704096696106717, 0.014573605876648799, 0.10045357688795775, 0.10316574072930962, 0.03978404332883656, 0.00794698040408548, 0.03408945514820516, 0.09106260346015915, 0.02631869399920106, 0.03602764802053571, 0.07138616827432998, 0.05636609377688728, 0.08533870786777698, 0.03349095757585019, 0.05960698217677418, 0.02479660848621279, 0.006056862466721213, 0.04293876467272639, 0.027741381818486843, 0.027814691165986005, 0.03308970059151761, 0.09232981319655664, 0.010066716513392748, 0.007848990007914836, 0.06320227577816695, 0.08357580285519361, 0.021619405633828137, 0.0893625286698807, 0.033698777479003184, 0.02030829415161861, 0.05649448903568555, 0.06535477863508277, 0.05370802136894781, 0.018580850810394622, 0.06083204163587652, 0.10762124657048844, 0.015836941602174193, 0.7997031882405281, 22.6786270737648, 111.21120125055313, 72.76991799473763, 61.40145242214203, 31.876622512936592, 90.09386479854584, 95.18090263009071, 37.36611194908619, 80.83590477705002, 15.75931616127491, 0.5468772235326469, 0.4273367364658043, 0.23751363245537505, 0.5121324816718698, 0.25875884166453034, 1.567033063620329, 2.0141315599903464, 2.408699062652886, 3.2378311967477202, 7.050783857703209, 3.504693489521742, 2.4578636744990945, 7.110733715817332, 2.5905739283189178, 0.5853508715517819, 1.548418931197375, 0.29102003085426986, 0.051134268069290556, 0.3242628736188635, 0.17370864370604977, 0.434305562521331, 0.23101231490727514, 1.0365763027220964, 1.0128785180859268, 0.8487354009412229, 1.2843586318194866, 2.9873747611418366, 11.15326127037406, 23.166878074407578, 43.09093415737152, 49.97701585292816, 52.25465923547745, 48.382754400372505, 61.07780858874321, 63.97431716322899, 74.85454693436623, 70.91487273573875, 79.89724114537239, 73.75952169299126, 79.22076344490051, 55.90586431324482, 67.43471547961235, 11.773623581975698, 3.890862730331719, 79.58601504564285, 76.00738227367401, 76.78315624594688, 74.65235218405724, 75.6173712015152, 78.43960896134377, 76.06938734650612, 78.49703907966614, 76.58724635839462, 82.6112151145935, 83.4280800819397, 86.98183178901672, 87.17730090022087, 95.54265081882477, 88.42893853783607, 80.30369773507118, 61.90215155482292, 36.68283261358738, 16.377263702452183, 5.99683441221714, 2.455601370893419, 2.9350608307868242, 1.5515274018980563, 0.387403194908984, 1.9193853065371513, 2.15482993517071, 0.8596578554715961, 0.4113956418586895, 0.18641617120010778, 0.23832653649151325, 0.2589748363243416, 0.06580290966667235, 0.8641648292541504, 0.6745980482082814, 0.4139642743393779, 0.9054624976124614, 0.7546057831496, 1.3183239405043423, 1.288952229078859, 0.06286987525527366, 0.20663352072006091, 0.6533069000579417, 0.3383826487697661, 1.4393462589941919, 63.642496168613434, 39.189219921827316, 30.737874917685986, 104.99679431319237, 49.21662725508213, 28.71441699564457, 50.201010033488274, 69.8511578142643, 44.005704671144485, 1.8891502101905644, 0.44020441942848265, 0.051558813647716306, 0.008038330433919327, 0.10327280295314267, 0.03925758974219207, 0.009623275855119573, 0.09600636083632708, 0.043491108081070706, 0.02462666408973746, 0.05661324008542579, 0.02501085909898393, 0.022414490704250056, 0.10357535429648124, 0.0034373597054582206, 0.011964733221248025, 0.05256227894278709, 0.0496135072899051, 0.07597830350277945, 0.026167494397668634, 0.04183496843324974, 0.13248851493699476, 0.025312907637271564, 0.008474018432025332, 0.013133818974893074, 0.01686367508227704, 0.04362005623988807, 0.013920955643698107, 0.10570991202257574, 0.026335360780649353, 0.052881669616908766, 0.04798442263563629, 0.0801995355868712, 0.1288615501835011, 0.21803424489917234, 0.14475781907094643, 0.13319972989847884, 0.11723484203685075, 0.24897040362702683, 0.13765925075858831, 0.21194716449826956, 0.17401436401996762, 0.09900304925395176, 0.25961284583900124, 0.18848848500056192, 0.1410127044073306, 0.07244491614983417, 0.06871175748528913, 0.1948959060246125, 0.11110733685200103, 0.1098425019881688, 0.1080066809663549, 0.11411365834646858, 0.1356717199087143, 0.11277716912445612, 0.1651187741663307, 0.1345906185451895, 0.1170334751077462, 0.21480087074451149, 0.12956166261574253, 0.11285532469628379, 0.19637693592812866, 0.07137643129681237, 0.09527559770504013, 0.12355347993434407, 0.13541345251724124, 0.18152265722164884, 0.16200044774450362, 0.7184124283958226, 36.10130041837692, 131.29371643066406, 85.64761698246002, 104.40379053354263, 51.92023538053036, 75.93355983495712, 121.70117676258087, 56.559915617108345, 62.09796264767647, 25.541524551808834, 0.7511160266585648, 0.6091631844174117, 0.47580711368937045, 1.257154585327953, 1.620048531331122, 5.984405279159546, 8.291758317500353, 16.124381572008133, 16.428152471780777, 28.30276418477297, 9.058359581977129, 10.215312950313091, 9.515346810221672, 1.1145088146440685, 0.5227258976083249, 1.8287056661210954, 0.6040519836824387, 0.2702203032094985, 0.3990731405792758, 0.18705085589317605, 0.6164191325660795, 0.4532100528012961, 0.8100018824916333, 1.0038353595882654, 1.2017881125211716, 1.2247829348780215, 3.6132042668759823, 12.540495581924915, 28.40431373566389, 52.23782613873482, 61.52515858411789, 66.79273992776871, 61.08957275748253, 68.8884262740612, 70.52618399262428, 77.32578992843628, 74.7926938533783, 84.62395951151848, 78.8580273091793, 84.07054960727692, 59.98629815876484, 74.17363107204437, 13.651353623718023, 6.080611366778612, 87.53078833222389, 81.93324029445648, 82.60094046592712, 78.8798077404499, 80.23800686001778, 82.56725147366524, 80.36963179707527, 83.01099926233292, 81.26791879534721, 87.73698806762695, 89.97570633888245, 93.55047091841698, 94.38129633665085, 101.20430141687393, 95.13443872332573, 87.96173840761185, 69.2355528473854, 41.83304585516453, 17.64054961502552, 6.800164030864835, 3.0808787187561393, 3.7265265360474586, 3.412470775656402, 2.0911923749372363, 2.9323465889319777, 2.800880530849099, 0.9880011936184019, 0.8904037275351584, 0.3799780667759478, 0.36757247464265674, 0.5989452952053398, 0.43132221791893244, 2.7772531611844897, 0.9450029977597296, 0.6226600601803511, 0.8097095950506628, 0.8755782293155789, 3.662725347094238, 6.002818141132593, 2.1023891866207123, 1.0761529603041708, 1.1097139469347894, 0.5300244747195393, 4.152844185009599, 50.958165004849434, 33.574280217289925, 56.531257554888725, 105.43317809700966, 49.65614587068558, 46.01274557411671, 66.55071571469307, 82.73984581232071, 64.34385493397713, 2.2286343248561025, 0.5486202018801123, 0.17763080511940643, 0.13233616686193272, 0.1795120010501705, 0.20485687855398282, 0.1901407283730805, 0.17739542556228116, 0.1664817877463065, 0.13534075173083693, 0.20692576363217086, 0.08958542530308478, 0.19722506229300052, 0.22907510166987777, 0.1593127302476205, 0.1718275368330069, 0.08296326384879649, 0.08071781441685744, 0.19904057815438136, 0.15017024270491675, 0.15211855847155675, 0.21617669379338622, 0.15212256606901065, 0.14232887362595648, 0.166889657266438, 0.1268619965412654, 0.11062186094932258, 0.12214256072184071, 0.24424277449725196, 0.2848749590339139, 0.11971098065259866, 0.14699301944347098], [0.022459626270574518, 0.023911170646897517, 0.07270863090525381, 0.22443798487074673, 0.0031396351050716476, 0.04623752203769982, 0.058763735432876274, 0.1269459631294012, 0.04408530119690113, 0.03446315990004223, 0.018510417285142466, 0.06576470390427858, 0.052700797095894814, 0.03200425024260767, 0.04290906392270699, 0.020824272323807236, 0.07065504149068147, 0.03446208378591109, 0.06156021096103359, 0.03548488202795852, 0.0459549455990782, 0.026432849299453665, 0.07342994649661705, 0.04954566014930606, 0.014868545567878755, 0.01820936693547992, 0.04956284086802043, 0.03506804736389313, 0.05060520212282427, 0.10653141755028628, 0.04848971017054282, 0.03146233029838186, 0.018738944963843096, 0.06822806273703463, 0.051929468172602355, 0.03468447204795666, 0.03825548257736955, 0.3164616250433028, 27.106675766408443, 89.73440408706665, 72.34102740883827, 59.02902312576771, 23.130388632416725, 40.771006643772125, 104.97485429048538, 46.31056219339371, 49.12874937057495, 41.72444008290768, 0.7297475170344114, 0.07887862404459156, 0.19749692582990974, 0.19970453315181658, 1.1633896292187274, 2.1288234181702137, 2.1954319439828396, 3.1641384260728955, 2.327405749820173, 2.886524135246873, 2.433603876270354, 7.108804369345307, 3.8429366145282984, 0.45261764083988965, 0.9596692607738078, 0.8981777541339397, 0.3484654671046883, 0.2578571916092187, 1.1852348945103586, 0.28137879038695246, 0.05010729895730037, 0.08338762389030308, 1.1613449826836586, 1.9324612361378968, 0.5741641530767083, 0.3696548519656062, 0.2514040394453332, 0.6255463021807373, 3.7315023690462112, 10.661558154970407, 23.586692847311497, 34.819758385419846, 48.30895476043224, 53.83320093154907, 60.666959434747696, 57.25030817091465, 60.564991906285286, 61.71675570309162, 58.43905158340931, 37.681297436356544, 45.39283163845539, 1.5754339378327131, 3.437711871229112, 57.577542811632156, 62.75712847709656, 68.17349463701248, 71.49191737174988, 72.60391250252724, 78.83797958493233, 81.84972077608109, 83.92892360687256, 82.42861971259117, 84.95058238506317, 79.27972868084908, 76.5043880045414, 74.83879297971725, 78.07809635996819, 81.88549965620041, 66.77193984389305, 37.53676079213619, 9.014342743903399, 1.011783464346081, 0.6921155238524079, 0.28533179545775056, 0.874607025180012, 1.0559508693404496, 0.1312012894777581, 0.3417134966002777, 0.219853516027797, 0.09300842561060563, 0.04008022333437111, 0.011729660727723967, 0.04212190870021004, 0.06624972709687427, 0.046642426677863114, 0.2744262322084978, 0.37375340703874826, 0.3940644155954942, 0.32949376793112606, 1.3096849853172898, 1.3750825636088848, 0.26873205963056535, 0.0921056252263952, 0.4785418091341853, 0.8232727297581732, 5.386799471452832, 36.01853705942631, 18.103427477180958, 56.80340655148029, 86.60914018750191, 40.94570606946945, 39.1964927315712, 43.01507122814655, 65.09794726967812, 55.60188442468643, 2.036196500994265, 0.5827665352262557, 0.043260763995931484, 0.06594566919375211, 0.07235177661641501, 0.05463035136926919, 0.056907304970081896, 0.07399904759950005, 0.03405417715839576, 0.010980453371303156, 0.09216615479090251, 0.048764249149826355, 0.03496856246783864, 0.015760858477733564, 0.04476497488212772, 0.03246586238674354, 0.07138765999116004, 0.06688711320748553, 0.05163795256521553, 0.058946452190866694, 0.027312834208714776, 0.051190682424930856, 0.023997974094527308, 0.0276345162637881, 0.057135073802783154, 0.04844054659770336, 0.01519652196293464, 0.022974433704803232, 0.025939154111256357, 0.07959550159284845, 0.01856761646195082, 0.025878487249428872, 0.0779006292577833, 0.022428912488976493, 0.039875772781670094, 0.11402416275814176, 0.13418236310826614, 0.03697730018757284, 0.06826744851423427, 0.06148334301542491, 0.08626874507172033, 0.016413922458013985, 0.057488068923703395, 0.04932134601403959, 0.007792741707817186, 0.04226582226692699, 0.030831525182293262, 0.09351697488455102, 0.11232643315452151, 0.04239350506395567, 0.029777124436805025, 0.07288455701200292, 0.02873844794521574, 0.07117842629668303, 0.06952725161681883, 0.011189234355697408, 0.024595011491328478, 0.09128161866101436, 0.04650445771403611, 0.017353295879729558, 0.06349254457745701, 0.048833068503881805, 0.017483681949670427, 0.06681788567220792, 0.04263556023943238, 0.03727631890797056, 0.06297874089796096, 0.009409860158484662, 0.11506485418067314, 0.02525342450098833, 0.461113213095814, 35.13727314770222, 101.5939249098301, 75.43964713811874, 46.148918867111206, 21.19544506072998, 84.90845784544945, 108.75423029065132, 31.098409071564674, 84.982158690691, 44.05143901705742, 0.6993140594568104, 0.2659860241692513, 0.1568392856279388, 0.09419106761924922, 0.5696514202281833, 0.6777622690424323, 0.5638791143428534, 2.9850644851103425, 3.368394090794027, 7.121920790523291, 3.200312959961593, 5.656680939719081, 8.091010339558125, 2.412336179986596, 1.9289886974729598, 1.7195464298129082, 0.8683135535102338, 1.1607505520805717, 1.2616524752229452, 0.251914577675052, 0.3864548489218578, 0.11759216387872584, 2.1876309625804424, 0.3541710984427482, 0.294092403491959, 1.0054494417272508, 0.6796678074169904, 1.0013088514097035, 5.188141856342554, 17.01644640415907, 36.64105765521526, 52.4042572081089, 63.658850491046906, 64.82965886592865, 68.34184840321541, 64.77365747094154, 68.53282615542412, 71.51460975408554, 68.41822430491447, 50.20447164773941, 62.800301760435104, 2.041690768674016, 3.7843615701422095, 68.95318239927292, 74.68937739729881, 77.20639273524284, 77.43220701813698, 77.92149916291237, 81.67781040072441, 85.11467278003693, 87.79987469315529, 86.6442959010601, 88.97531121969223, 83.6169071495533, 85.68136677145958, 82.86406874656677, 89.91069942712784, 85.64029857516289, 69.48126286268234, 45.82718253135681, 14.715139791369438, 2.0302562322467566, 1.6494775959290564, 0.6352944415993989, 0.5683335440699011, 0.3444063646020368, 0.4899341915734112, 0.6325828714761883, 0.12073810561560094, 0.05981284281006083, 0.04736562361358665, 0.030011095768713858, 0.060068668535677716, 0.052942132388125174, 0.07116373919416219, 0.37362644041422755, 1.4453254756517708, 1.4052745560184121, 1.2413572892546654, 1.4779215515591204, 0.723459804430604, 0.2401495332014747, 0.1697684481041506, 0.41495815850794315, 0.7373073894996196, 6.495532002300024, 69.28443342447281, 28.93787920475006, 30.556028075516224, 102.93529093265533, 58.54131169617176, 38.10697339475155, 37.308868020772934, 67.5281372666359, 67.36293733119965, 3.5099041974171996, 0.6689371832180768, 0.028040244687872473, 0.08492320164805278, 0.08808585655060597, 0.09444254435948096, 0.031842313619563356, 0.08025915230973624, 0.07919240408227779, 0.020081514230696484, 0.03224660598789342, 0.0113539642370597, 0.085440909024328, 0.024308414467668626, 0.012871940107288538, 0.08225417885114439, 0.03761306099477224, 0.022889858555572573, 0.04450692271348089, 0.10065393449622206, 0.010367795621277764, 0.10332895384635776, 0.01784154555934947, 0.045639310192200355, 0.05712329591915477, 0.02297385854035383, 0.03687519551021978, 0.01776722689101007, 0.05840285128215328, 0.013411719883151818, 0.06563606002600864, 0.11857366160256788, 0.14350514800753444, 0.10347871924750507, 0.16274451016215608, 0.1720778929302469, 0.1796351233497262, 0.14129819377558306, 0.245319704990834, 0.18907656281953678, 0.1640669282642193, 0.08081165899056941, 0.21796377055579796, 0.12759739067405462, 0.19440941337961704, 0.14637832820881158, 0.24144391296431422, 0.16406774462666363, 0.18667345895664766, 0.14331690967082977, 0.13968081650091335, 0.24424213625025004, 0.11407668454921804, 0.1313000248046592, 0.12430578761268407, 0.08819671114906669, 0.13959045259980485, 0.16394141624914482, 0.13842903601471335, 0.10834287386387587, 0.14997563674114645, 0.19836178020341322, 0.20708673546323553, 0.18403360998490825, 0.10253936066874303, 0.11440410526120104, 0.16694521444151178, 0.11214660335099325, 0.3534312662668526, 0.15738458605483174, 0.63592413906008, 50.402726009488106, 118.76697421073914, 91.0795547068119, 77.64138579368591, 31.99649468064308, 63.99032950401306, 125.49358606338501, 59.16252136230469, 72.1163758635521, 59.87678423523903, 0.9328946506138891, 0.3959566249977797, 0.31546082405839115, 0.3764751594280824, 2.354394751600921, 6.104942886158824, 8.562983013689518, 15.386365223675966, 9.613872673362494, 15.547803360968828, 10.055169593542814, 18.151701986789703, 10.270654130727053, 3.5410378267988563, 4.079009871929884, 2.762517314404249, 1.4608769724145532, 3.900276250205934, 4.356814390048385, 0.3844950150232762, 0.962085040519014, 0.521729935426265, 4.411663971841335, 2.7321210829541087, 2.1635725535452366, 1.030980390496552, 0.7488045038189739, 0.8770306420046836, 6.210556318983436, 20.95377802848816, 45.18564395606518, 64.67850297689438, 79.90720421075821, 74.31226283311844, 77.24866166710854, 71.2833009660244, 75.18933936953545, 72.73470148444176, 75.29246583580971, 60.6644743680954, 75.08436620235443, 2.3254132317379117, 5.733832474797964, 79.9061706662178, 78.04210469126701, 81.50045871734619, 80.91176390647888, 82.63101205229759, 84.50132489204407, 88.91897544264793, 90.45593976974487, 89.42631661891937, 92.83170148730278, 88.74347046017647, 92.13952302932739, 93.07212218642235, 101.14757806062698, 93.25196653604507, 73.03434580564499, 49.39988762140274, 15.501610189676285, 2.187822852283716, 2.313615814782679, 1.4005813328549266, 1.731160981580615, 1.561435132753104, 1.345743031706661, 0.9270281216595322, 0.15378022711956874, 0.2388568306923844, 0.17041147453710437, 0.17229151271749288, 0.10932366654742509, 0.1700967742362991, 0.21778393333079293, 0.8962587383575737, 2.4962869752198458, 2.2640455747023225, 1.1105031170882285, 4.759467383846641, 7.709186878055334, 1.4160180045291781, 0.5278040282428265, 0.6999907793942839, 0.9512945101596415, 9.209625665098429, 53.59525769948959, 27.97984041273594, 62.4985371530056, 108.10319602489471, 54.356220066547394, 48.675768077373505, 55.195439234375954, 73.50995868444443, 84.83708247542381, 4.368927665054798, 0.6438694533426315, 0.14661252032965422, 0.14497937983833253, 0.19656774209579453, 0.16074498620582744, 0.1406273219618015, 0.18676362989936024, 0.2439385384786874, 0.17227637290488929, 0.11854097741888836, 0.13063961727311835, 0.13400291180005297, 0.14529039908666164, 0.12512963090557605, 0.2308147106668912, 0.1400375520461239, 0.13596546195913106, 0.16289154445985332, 0.18385301576927304, 0.1653554302174598, 0.30244863010011613, 0.1028525989386253, 0.13881906430469826, 0.15831345808692276, 0.1701511291321367, 0.09913418674841523, 0.10719852667534724, 0.10798958188388497, 0.18667118798475713, 0.16189841728191823, 0.1861747950897552, 0.2904086495982483], [0.05323618614056613, 0.017753029605955817, 0.047863367217360064, 0.020746847767441068, 0.08379881823202595, 0.01538097349111922, 0.0587045936845243, 0.05514678967301734, 0.05430595490906853, 0.023552171551273204, 0.07183409892604686, 0.03495893681247253, 0.028539589475258254, 0.07786832356941886, 0.033044318261090666, 0.029644302267115563, 0.07427396136336029, 0.01771003513567848, 0.018523879843996838, 0.04079265541804489, 0.04195693298242986, 0.02476502639183309, 0.039428977615898475, 0.059700351775973104, 0.07305217848625034, 0.06194574183609802, 0.036830247336183675, 0.05272422669804655, 0.009687703550298465, 0.022235928117879666, 0.01891617910587229, 0.05899191615753807, 0.008597885662311455, 0.0562395167798968, 0.007088932452461449, 0.12693475669948384, 0.08298892731545493, 0.04690778529038653, 0.504073885967955, 30.076917484402657, 93.10308292508125, 64.61822301149368, 66.77855908870697, 29.454153701663017, 22.910880111157894, 91.77785083651543, 39.84964728355408, 36.0504287481308, 54.33249793946743, 7.475049616768956, 0.06161674034956377, 0.028218580919201486, 0.39838077616877854, 0.3190345916664228, 0.32661785662639886, 1.7360142711549997, 2.8838122682645917, 3.8925075670704246, 1.0289492807351053, 4.634576635435224, 9.721082020550966, 3.233964191749692, 2.0059779100120068, 0.30759230721741915, 3.216084251180291, 1.600105301477015, 1.3685092725791037, 0.06899879052070901, 0.2673508634325117, 0.22403125825803727, 0.20499086589552462, 0.04552150538074784, 0.11667162616504356, 0.1906466207583435, 0.9701949334703386, 0.7730632333550602, 0.9271076798904687, 0.6398737896233797, 2.6777804363518953, 13.37281621992588, 38.48722659051418, 57.5064942240715, 73.67124482989311, 67.94324219226837, 57.825012132525444, 55.68471997976303, 42.35781669616699, 29.138582535088062, 7.043278310447931, 0.06106654916948173, 5.352928563952446, 32.62495815753937, 50.89387625455856, 72.85815685987473, 76.35624155402184, 82.7015894651413, 83.05259183049202, 80.10328888893127, 80.22222250699997, 80.57027623057365, 82.17878311872482, 82.96499893069267, 77.40819990634918, 59.737829491496086, 37.673751041293144, 20.32137606292963, 6.977396020665765, 3.186359158717096, 0.8762820821721107, 0.45178658387158066, 0.3796885401243344, 0.08530845050700009, 0.31222651479765773, 0.07621491502504796, 0.22247549408348277, 0.05887326529773418, 0.04467305989237502, 0.021195153203734662, 0.044686054898193106, 0.01430368027286022, 0.06894660269608721, 0.0900007905147504, 0.01007988035780727, 0.3687846095999703, 1.3530831690877676, 0.5142178572714329, 1.4096719888038933, 1.4061618084087968, 0.6870641105342656, 0.41383505158592016, 0.1290754074580036, 0.4409924615174532, 11.192270927131176, 39.58731696009636, 20.685525722801685, 74.21143144369125, 100.1016765832901, 42.655025348067284, 61.216550543904305, 53.99580180644989, 69.138642847538, 67.62583002448082, 5.498423231765628, 0.11190082630491816, 0.05698137501894962, 0.034784294621204026, 0.04565258350339718, 0.019811190650216304, 0.04364232809166424, 0.03417869840632193, 0.05484785629960243, 0.041870376298902556, 0.03082507220824482, 0.05944739816186484, 0.05396473025029991, 0.060938220703974366, 0.052202084989403374, 0.028587316992343403, 0.03266263171099126, 0.018982939000125043, 0.08162453334080055, 0.011285974233032903, 0.042892417550319806, 0.10095578079926781, 0.041022602454177104, 0.02798355017148424, 0.07737283609458245, 0.01837364132370567, 0.07202046705060638, 0.05727363648475148, 0.06443765480071306, 0.043991241400362924, 0.021274685459502507, 0.025193928377120756, 0.04407091095345095, 0.08417950288276188, 0.022420652385335416, 0.02482170606526779, 0.030064914462855086, 0.02737512822932331, 0.10362844754126854, 0.08554678381187841, 0.016028465797717217, 0.07312710571568459, 0.033896634049597196, 0.012492061614466365, 0.028023828381265048, 0.053137714276090264, 0.10236592817818746, 0.022260218611336313, 0.03843077414785512, 0.045226097208797, 0.029039591063337866, 0.0559247125784168, 0.02067643465125002, 0.013640258694067597, 0.04979515535524115, 0.027425930093158968, 0.04048138012876734, 0.013653591377078556, 0.03387962773558684, 0.025379769576829858, 0.07796806079568341, 0.04019636944576632, 0.04926692803564947, 0.04569471151626203, 0.012730500675388612, 0.03205653825716581, 0.01887462625745684, 0.07252546143718064, 0.036857558370684274, 0.06889482305268757, 0.09334720118204132, 0.03726346119947266, 0.3314340685028583, 41.025851368904114, 106.31909295916557, 60.334686264395714, 46.1660635471344, 19.9047664180398, 62.99638643860817, 113.52880328893661, 32.98107124865055, 76.0058319568634, 73.6359067261219, 5.8036869764328, 0.17788427823688835, 0.03830946639936883, 0.39905797108076513, 0.33761939441319555, 0.2232074149651453, 0.15364751627203077, 0.189249498071149, 2.6528912968933582, 3.087390619330108, 3.2595073711127043, 5.767711456865072, 3.106733006425202, 7.253568526357412, 3.020481434650719, 5.388801963999867, 2.216359796002507, 5.223478060215712, 0.20517082186415792, 1.2177584180608392, 0.9289600804913789, 0.2080567818484269, 0.045788196148350835, 0.13283693842822686, 0.39253188064321876, 2.038417006842792, 1.1724957218393683, 1.4811758394353092, 0.7140348257962614, 4.584375629201531, 18.040660545229912, 45.15394985675812, 70.29301330447197, 83.98818522691727, 82.69336670637131, 75.45483872294426, 72.70195484161377, 56.679282411932945, 38.904326409101486, 9.958559777587652, 0.12790493667125702, 7.040387140586972, 44.53324556350708, 64.17393565177917, 81.14154517650604, 82.47279614210129, 88.94525483250618, 87.34649062156677, 86.06506258249283, 84.36507940292358, 83.973039239645, 86.74648001790047, 88.74669268727303, 88.57523828744888, 77.85827815532684, 53.350737020373344, 30.55661704391241, 15.597260557115078, 8.540823552757502, 1.3962791324593127, 0.5999075341969728, 1.4179595815949142, 0.4919568111654371, 0.4067936434876174, 0.5229298991616815, 0.11768818294513039, 0.07303110891371034, 0.0353480225749081, 0.011138885201944504, 0.05924220917222556, 0.035499899386195466, 0.03836897922155913, 0.07876160219893791, 0.00647945016680751, 0.3179673833074048, 3.417095127515495, 0.5156362499110401, 0.4993261001072824, 0.23356184450676665, 0.4267118778079748, 0.48531337233725935, 0.1534191722748801, 0.5252063332591206, 15.884751230478287, 71.64203211665154, 27.46260266751051, 42.13134504854679, 113.44526097178459, 58.86162310838699, 52.026154696941376, 46.56906232237816, 68.67661044001579, 81.0992382466793, 7.215751530602574, 0.10728946945164353, 0.03572566442016978, 0.03199444276106078, 0.05673685962392483, 0.05574192160565872, 0.1124001581047196, 0.01618775109818671, 0.05133559046953451, 0.052398665065993555, 0.047408538302988745, 0.020096652187930886, 0.07048414714518003, 0.03604355966672301, 0.055410485874745063, 0.04505796736339107, 0.07839497382519767, 0.060199869112693705, 0.03463263674348127, 0.028521687017928343, 0.10185585750150494, 0.03155322112434078, 0.04170860294834711, 0.06657752630417235, 0.05777296086307615, 0.06606789349461906, 0.0770300232397858, 0.061813108914066106, 0.038308854127535596, 0.03437088125792798, 0.011759266853914596, 0.05046359292464331, 0.015921930498734582, 0.030574424818041734, 0.07624362129718065, 0.10214464200544171, 0.14055879204533994, 0.11950713495025411, 0.21340198174584657, 0.12136375837144442, 0.11295674659777433, 0.16269880870822817, 0.15548323339316994, 0.08770958767854609, 0.16634172963676974, 0.18422067572828382, 0.14265155943576247, 0.09591525478754193, 0.11259134276770055, 0.08822474206681363, 0.1187339135503862, 0.2093037829035893, 0.33794962044339627, 0.08649648050777614, 0.16236028546700254, 0.13600623555248603, 0.12012148479698226, 0.16043117648223415, 0.11293520947219804, 0.13680631527677178, 0.15951878012856469, 0.1952445224742405, 0.16813242807984352, 0.11603832928813063, 0.24046801845543087, 0.1379141042707488, 0.0984140882792417, 0.18852320266887546, 0.06627610302530229, 0.1390861187246628, 0.23132811358664185, 0.16480321297422051, 0.456508572679013, 57.50224985182285, 122.70941466093063, 79.842030107975, 88.16580265760422, 37.565137669444084, 45.353097170591354, 113.5013535618782, 50.33688314259052, 56.766081154346466, 80.06822437047958, 10.629440378397703, 0.49431986873969436, 0.13940642966190353, 0.9147524053696543, 1.3927266793325543, 0.8467624755576253, 4.137292569503188, 11.785821877419949, 13.196675721555948, 11.060446500778198, 16.215063706040382, 24.691532962024212, 11.486273501068354, 12.64378733932972, 3.9493841025978327, 8.644079212099314, 2.6279325736686587, 4.765705224126577, 0.383294754428789, 1.0828960547223687, 2.1380996704101562, 0.6542099453508854, 0.23024215857731178, 0.2945506351534277, 0.9639715799130499, 3.266374790109694, 1.3909158390015364, 2.2007081983610988, 1.252115461975336, 4.9039133079349995, 20.288116447627544, 48.07303301990032, 76.36788412928581, 88.8614921271801, 91.86967670917511, 84.0585346519947, 82.90711283683777, 67.94573485851288, 50.45938856899738, 14.244201611727476, 0.21597425075015053, 7.720285607501864, 53.350858613848686, 76.43311902880669, 83.61256018280983, 86.88046842813492, 91.0497111082077, 91.29420518875122, 86.02034658193588, 85.81827342510223, 85.98534286022186, 91.6828179359436, 95.34790366888046, 95.25731652975082, 82.69990235567093, 50.59441052377224, 22.84406639635563, 11.480770446360111, 6.792005393654108, 2.227911651134491, 0.9826333285309374, 2.071337252855301, 0.8283965173177421, 0.6209834001492709, 0.5829378229100257, 0.26836330129299313, 0.13824048597598448, 0.14626043062889948, 0.14759580662939698, 0.18836101371562108, 0.15332589915487915, 0.13566728186560795, 0.2332776613184251, 0.1780944989877753, 0.5331914266571403, 5.045341243967414, 5.876887198537588, 7.412502598017454, 4.706987924873829, 1.3187833596020937, 1.3089076895266771, 0.4703783628065139, 0.40259415633045137, 18.629425652325153, 59.466740638017654, 30.03727801144123, 84.13868755102158, 120.05550026893616, 53.78473833203316, 68.63372594118118, 70.38594871759415, 80.37932887673378, 100.34367799758911, 12.178897485136986, 0.2520402678055689, 0.25030714517924935, 0.1623311487492174, 0.2193120599258691, 0.1531455127405934, 0.18559036863734946, 0.14465696120169014, 0.27532544801943004, 0.1816754654282704, 0.18723916844464839, 0.07381660543614998, 0.10249415645375848, 0.11145440221298486, 0.14624833362177014, 0.17077232158044353, 0.21972361049847677, 0.11781773224356584, 0.17047786706825718, 0.15503905800869688, 0.14623378752730787, 0.16669534816173837, 0.15406953112687916, 0.08667970934766345, 0.1584063601330854, 0.12432010364136659, 0.09222197171766311, 0.13572266092523932, 0.2142853898112662, 0.11573076102649793, 0.16536598355742171, 0.13938440271886066, 0.14221713587176055, 0.24787092668702826], [0.07889171552960761, 0.013043598864896921, 0.009060584125109017, 0.0707789059379138, 0.05148134827322792, 0.04638860104023479, 0.032248850984615274, 0.06070763171010185, 0.032955412680166773, 0.05043195887992624, 0.07382427924312651, 0.06748996718670242, 0.009984598800656386, 0.05298234937072266, 0.06545583688421175, 0.023505397693952546, 0.07126344673451968, 0.03180052699462976, 0.023089525966497604, 0.042554113242658786, 0.005295681485222303, 0.03155870930640958, 0.009864563835435547, 0.031329244666267186, 0.05023398727644235, 0.050872861393145286, 0.034091503475792706, 0.007681699717068113, 0.023546655538666528, 0.09575977484928444, 0.03793313073401805, 0.02677470849448582, 0.02060121056274511, 0.060597560077439994, 0.1026197723695077, 0.05485910354764201, 0.10165058687562123, 0.08400558799621649, 0.06510766572318971, 0.04470305750146508, 36.881257966160774, 97.34562367200851, 63.35937716066837, 73.68851870298386, 39.640411511063576, 24.218693934381008, 77.64736667275429, 51.17730304598808, 26.897624284029007, 52.672963589429855, 18.49458798766136, 0.5873761628754437, 0.03772826828935649, 0.32370317552704364, 0.40861656598281115, 0.18178004887886345, 1.1590311443433166, 3.520195232704282, 0.7740079576615244, 0.7780960039235651, 3.9147712849080563, 1.4099606545642018, 2.600024021230638, 1.637666285969317, 3.37760123424232, 1.685480901505798, 1.058853438589722, 0.48590741702355444, 0.20850443048402667, 0.3848503256449476, 0.20828687731409445, 0.08491251472150907, 0.023351715608441737, 0.044637499886448495, 0.14335624349769205, 0.04110222005692776, 0.664271330460906, 0.2830683934735134, 1.2478423537686467, 0.166909487452358, 1.9905161834321916, 5.555607788264751, 16.21017336845398, 20.40340606123209, 12.66841096803546, 5.019747717306018, 2.879547472111881, 0.09550947812385857, 0.13000545208342373, 0.5956793110817671, 1.2134190509095788, 17.34604261815548, 26.76537238061428, 60.114469081163406, 75.33177092671394, 80.4560999572277, 83.94752740859985, 92.82670855522156, 92.21240311861038, 89.2947068810463, 75.32124549150467, 57.313407585024834, 37.18924283981323, 17.464991435408592, 4.20143835246563, 0.3476064756978303, 0.7690567045938224, 1.3391407672315836, 0.4207355703692883, 0.2909686148632318, 0.04501344221353065, 0.10571982711553574, 0.03100989109952934, 0.09005580592202023, 0.04523787880316377, 0.08755142116569914, 0.026153289691137616, 0.05566398125665728, 0.06137428070360329, 0.031203792023006827, 0.009641853666835232, 0.04476722358958796, 0.04827442426176276, 0.03042373173229862, 1.1887099267914891, 1.237477578688413, 2.327285106293857, 0.7035124185495079, 0.6142122228629887, 0.09120836126385257, 0.12909109645988792, 18.684756383299828, 29.570412263274193, 23.104954697191715, 74.22926768660545, 89.80653181672096, 43.526892364025116, 38.70455592870712, 44.46352690458298, 67.01005786657333, 58.78634534776211, 3.7899154471233487, 0.353640106623061, 0.05874910770216957, 0.08583475195337087, 0.07820092447218485, 0.13769542303634807, 0.029558211281255353, 0.09498092797002755, 0.0815511572000105, 0.035736848585656844, 0.02665073458047118, 0.0699698091193568, 0.04958607751177624, 0.07880227931309491, 0.03694241553603206, 0.04664274209062569, 0.027203860954614356, 0.01852181481808657, 0.043851090522366576, 0.03906728081346955, 0.03810831098235212, 0.04591066164721269, 0.07691325372434221, 0.04524089934420772, 0.05827266373671591, 0.0098160830384586, 0.08218737071729265, 0.04165525366261136, 0.0449043427943252, 0.07461618050001562, 0.0163553799939109, 0.01392842907080194, 0.012918293723487295, 0.014951782068237662, 0.014166844011924695, 0.04183427452517208, 0.07077598929754458, 0.05853328744706232, 0.038304056142806076, 0.02591113247035537, 0.056194119606516324, 0.009441736328881234, 0.06178836942126509, 0.06978675839491189, 0.010958739985653665, 0.04015480175439734, 0.012463516759453341, 0.07009555862168781, 0.033659105974948034, 0.03933983083697967, 0.025953839358408004, 0.07881504425313324, 0.04028007257147692, 0.02426445520541165, 0.021585537724604364, 0.01110672608774621, 0.06107991895987652, 0.034597228877828456, 0.059096566401422024, 0.07622627730597742, 0.04443043697392568, 0.035842827273881994, 0.03689548211696092, 0.045824379558325745, 0.08127987995976582, 0.047583852137904614, 0.011588227789616212, 0.06300009990809485, 0.08274726918898523, 0.04108308748982381, 0.08567156110075302, 0.05199949722737074, 0.08614928156021051, 0.10306242635124363, 0.1905182292102836, 50.449459701776505, 112.1554733812809, 60.58975897729397, 51.65474362671375, 16.54610574245453, 46.359583362936974, 97.07390025258064, 27.81851626932621, 52.98366531729698, 82.10770413279533, 17.066324427723885, 0.3081484726862982, 0.11441339695011266, 0.3755753202131018, 0.291728574084118, 0.16237717674812302, 0.687559568323195, 0.7769657426979393, 1.582175251096487, 2.0442138332873583, 3.7100206967443228, 2.917928025126457, 4.030439453199506, 2.0440449798479676, 2.798464810475707, 3.7491937447339296, 2.1581445448100567, 0.7707942207343876, 1.098468687850982, 0.47740988549776375, 0.1687827572459355, 0.034946743326145224, 0.06469105370342731, 0.005958392921456834, 0.15668036212446168, 0.010087049504363677, 0.49650546396151185, 0.7584812783170491, 1.1305697215721011, 0.6040813133586198, 2.97730696387589, 6.1048592906445265, 20.47542169690132, 26.996521577239037, 16.242781318724155, 6.84372584335506, 3.1429251143708825, 0.02668736513442127, 0.07190063246525824, 0.5470610980410129, 1.7893435782752931, 25.69584757089615, 43.23876902461052, 74.3822930753231, 79.64935004711151, 84.02455687522888, 85.48803314566612, 93.94043639302254, 98.46584156155586, 97.88145571947098, 90.13682529330254, 71.26381561160088, 50.27885265648365, 23.00689335912466, 6.750588566064835, 0.6833127024583519, 1.2075550155714154, 1.9397904491052032, 2.022385192103684, 0.5179326329380274, 0.033017912646755576, 0.032289223818224855, 0.13077479205094278, 0.019338941674504895, 0.05768546536273789, 0.10723740037065, 0.05254163981589954, 0.05781805746664759, 0.03944926422263961, 0.03457051527220756, 0.046549279722967185, 0.0787121380562894, 0.015304270673368592, 0.23685806372668594, 1.890841000713408, 0.861429451033473, 0.6025804532691836, 0.46526247169822454, 0.6183165963739157, 0.10556509674643166, 0.17013456439599395, 26.43534678965807, 62.45003655552864, 24.585245065391064, 42.73326314985752, 105.4343256354332, 53.95634852349758, 36.26024208962917, 40.14315113425255, 68.2359328866005, 75.01318082213402, 7.819374790415168, 0.37856590817682445, 0.04485023280722089, 0.05129666853463277, 0.01756634421326453, 0.08225586352637038, 0.07712454316788353, 0.07320596632780507, 0.026747432711999863, 0.03196140976797324, 0.05490147646924015, 0.033036009917850606, 0.051508295655366965, 0.036105974286329, 0.016322864648827817, 0.08151786445523612, 0.053258164844010025, 0.01217716742758057, 0.0394826645788271, 0.016041269700508565, 0.08739589669858105, 0.08819967231829651, 0.09530808150884695, 0.08089236012892798, 0.05433829399407841, 0.04171256230620202, 0.06563712129718624, 0.03087913581111934, 0.04487516525841784, 0.05501238672877662, 0.06507585727376863, 0.01057614430465037, 0.06758773772162385, 0.043011086963815615, 0.059228676109341905, 0.14853313914500177, 0.11876238975673914, 0.07629572748555802, 0.12486268038628623, 0.12274364096811041, 0.1463995239464566, 0.11622149133472703, 0.2523682080209255, 0.287172588868998, 0.06917390768649057, 0.15433516062330455, 0.1870277602574788, 0.1574485591845587, 0.19996306771645322, 0.10765919258119538, 0.16100500506581739, 0.2583320770645514, 0.14687325165141374, 0.07181681430665776, 0.09167160242213868, 0.09936437127180398, 0.21926998015260324, 0.10316564425011165, 0.18419039610307664, 0.14933413913240656, 0.14051693491637707, 0.1588241002173163, 0.22483233246020973, 0.23172909597633407, 0.2765389782143757, 0.14192253293003887, 0.12227695624460466, 0.12251726366230287, 0.12410232782713138, 0.19382010359549895, 0.15541188331553712, 0.24701687798369676, 0.21015720820287243, 0.22355389402946457, 0.288825262687169, 61.55625991523266, 126.40112936496735, 83.12030419707298, 92.90762141346931, 55.48303060233593, 44.49315771460533, 106.34806260466576, 59.39862549304962, 41.2822388112545, 81.92681863904, 28.27226512134075, 0.47655579226557165, 0.19115997914923355, 0.4986660636495799, 0.7951050787232816, 1.0015442012809217, 4.079230260103941, 7.3809015937149525, 9.930935259908438, 9.61904039606452, 10.253289062529802, 10.052055660635233, 10.245024506002665, 9.712022356688976, 6.49160728789866, 3.187833479605615, 1.7944274679757655, 1.534685636870563, 1.2539904238656163, 0.8758332312572747, 0.3286906750872731, 0.12430886752554215, 0.1757925350102596, 0.1626199926249683, 0.3205455746501684, 0.13887837674701586, 1.330871342215687, 1.3044989760965109, 1.6134381922893226, 0.852544637164101, 3.1855540769174695, 7.263593813404441, 24.848116859793663, 34.95128072798252, 23.53384528309107, 11.1801153793931, 4.7681123949587345, 0.17486211931100115, 0.2666245383443311, 1.1026390828192234, 2.0105870626866817, 32.70785830914974, 60.56120350956917, 79.53742325305939, 80.38404062390327, 83.47270488739014, 85.26151210069656, 94.61831241846085, 100.20908921957016, 99.8750339448452, 88.6856983602047, 65.83516851067543, 45.07314719259739, 19.98634234070778, 3.8022956578060985, 0.33081743284128606, 4.537678034976125, 13.905002363026142, 4.450906366109848, 0.5547498073428869, 0.20351406623376533, 0.1786135125439614, 0.13337339245481417, 0.11840993640362285, 0.09308437700383365, 0.19415739487158135, 0.08374984390684403, 0.17582808388397098, 0.12171978145488538, 0.13145887409336865, 0.1462230263859965, 0.11750983743695542, 0.19136552436975762, 0.7772813038900495, 2.4206532211974263, 3.0445733293890953, 6.426048455759883, 1.265073122922331, 1.2430378678254783, 0.21172772627323866, 0.21472762076882645, 28.73546976596117, 49.79827344417572, 33.11521925032139, 85.05163416266441, 110.64104944467545, 54.224085956811905, 48.13838951289654, 59.229542165994644, 79.73742932081223, 93.5988499224186, 12.908844966441393, 0.4250010789837688, 0.40194213506765664, 0.22238291858229786, 0.08592136058723554, 0.2652859117370099, 0.1329067745245993, 0.1767353742616251, 0.13606885797344148, 0.13315147545654327, 0.09223242857842706, 0.14819510572124273, 0.14442829065956175, 0.14288373291492462, 0.10499877127585933, 0.19100849196547642, 0.14885664131725207, 0.13763424038188532, 0.15551492309896275, 0.11514398938743398, 0.19097840529866517, 0.21385115920566022, 0.15293109143385664, 0.12145353597588837, 0.16484469902934507, 0.09921900680637918, 0.15846979891648516, 0.1883045065915212, 0.12456953205401078, 0.11126128054456785, 0.20906175370328128, 0.18546136852819473, 0.1270301968907006, 0.1169220193696674, 0.11148644814966246], [0.0458161565620685, 0.027979657606920227, 0.014891889823047677, 0.0150684309846838, 0.055327780937659554, 0.043036702190875076, 0.05641281939460896, 0.038116426367196254, 0.027494675232446752, 0.024551701608288568, 0.05996854910335969, 0.0601591029408155, 0.017474464475526474, 0.06779875257052481, 0.07987861608853564, 0.0720160809578374, 0.053856027880101465, 0.049788335018092766, 0.03617413683969062, 0.04216825582261663, 0.03259036879171617, 0.030287727604445536, 0.040078219535644166, 0.08718618060811423, 0.019077314209425822, 0.03287634055595845, 0.09075528010725975, 0.022965116040722933, 0.03698835818795487, 0.15236084000207484, 0.022653163541690446, 0.029878076929890085, 0.038426581013482064, 0.05883817655558232, 0.03933701809728518, 0.053423749122885056, 0.052534630231093615, 0.014467880446318304, 0.18221215694211423, 0.19885266636265442, 0.2926815510727465, 28.232067078351974, 85.35549625754356, 60.93904383480549, 74.29100677371025, 72.2341999411583, 26.13355938345194, 92.16511845588684, 74.51124295592308, 32.062972113490105, 50.74544481933117, 36.13143280148506, 4.313047863543034, 0.18927652708953246, 0.25487010658252984, 0.24561525788158178, 0.20688920543761924, 0.3059553966159001, 2.308252640068531, 2.0911078294739127, 1.6653732117265463, 2.4510271288454533, 4.085105219855905, 3.0199394887313247, 1.1607347591780126, 1.5046363743022084, 1.0110140056349337, 0.3049646888393909, 0.18138972372980788, 0.9851344849448651, 0.6689675222150981, 0.18050164013402537, 0.013346789382921997, 0.03910177212674171, 0.06416077434550971, 0.02471044885169249, 0.08815742185106501, 0.09077669106773101, 0.16361914604203776, 0.8286521723493934, 0.7856330776121467, 0.9533044241834432, 0.9516414790414274, 0.9728571656160057, 0.5002750991843641, 0.1452199395862408, 0.7275299797765911, 0.2558259334182367, 0.19112587004201487, 0.6331908388528973, 0.21465604804689065, 3.035731203854084, 14.886313006281853, 45.210817605257034, 78.71940314769745, 84.20495599508286, 87.2063921391964, 69.13720652461052, 46.63907736539841, 26.21246214956045, 10.488063264638186, 4.224556786939502, 2.1128281764686108, 0.883976788027212, 0.23576352949021384, 0.9607986314222217, 2.13920374866575, 3.0181136867031455, 1.1057042120955884, 0.06800204908358864, 0.05646120000164956, 0.0820764344825875, 0.11596714248298667, 0.04872440695180558, 0.06706801912514493, 0.08264220334240235, 0.06354563782224432, 0.04257506036083214, 0.03659902751678601, 0.05929555103648454, 0.05470711912494153, 0.0415600991982501, 0.06154738293844275, 0.13747056713327765, 1.1011361447162926, 0.2815515029942617, 0.20099014072911814, 0.21211022918578237, 0.26702924631536007, 1.7693158029578626, 33.69833216071129, 42.84454397857189, 28.518837690353394, 84.55740988254547, 86.57885581254959, 41.97887443006039, 41.53811328113079, 51.89756579697132, 74.53598722815514, 65.72660073637962, 4.5839443523436785, 0.7625334640033543, 0.14238137315260246, 0.03364757671079133, 0.05052442676969804, 0.10815909583470784, 0.08710596186574548, 0.021606883747153915, 0.043168637494090945, 0.04001533365226351, 0.05249714435194619, 0.021877507897443138, 0.023752078304823954, 0.02670415437023621, 0.014643091308244038, 0.026286004249413963, 0.02463640848873183, 0.036759420472662896, 0.023245690535986796, 0.04515944492595736, 0.028220992899150588, 0.07098659596522339, 0.023080876235326286, 0.007071218778946786, 0.044075842524762265, 0.035080860543530434, 0.05294612143188715, 0.03421027307922486, 0.051442251933622174, 0.08379475126275793, 0.012047418676957022, 0.061574987121275626, 0.1053346747357864, 0.04579476786602754, 0.02691966663405765, 0.017648841349000577, 0.035720873856917024, 0.05720890636439435, 0.02922854371718131, 0.04000138127594255, 0.023889763397164643, 0.052632734732469544, 0.03865059828967787, 0.09039888594998047, 0.04247961645887699, 0.009470527947996743, 0.03387884105904959, 0.027006972886738367, 0.04126105450268369, 0.03457329832599498, 0.06394097246811725, 0.030322899838211015, 0.02783814303256804, 0.08457979507511482, 0.04083962965523824, 0.030402150077861734, 0.011642398076219251, 0.08481526368996128, 0.019082655817328487, 0.11033866481739096, 0.05059284907474648, 0.026169863704126328, 0.09208415489410982, 0.04394550283905119, 0.01058865784216323, 0.059817956207552925, 0.012902780981676187, 0.020063255542481784, 0.05845293511811178, 0.01753562672092812, 0.04860473192820791, 0.09329750697361305, 0.06607137416722253, 0.07568147411802784, 0.06637539496296085, 0.21405628882348537, 0.6564382289070636, 43.47961910068989, 98.60312819480896, 59.82362128794193, 63.29321891069412, 54.997637048363686, 49.15853977203369, 116.48295477032661, 40.70326007902622, 43.67461323738098, 84.27398309111595, 40.44170871376991, 3.6550495214760303, 0.05546728614717722, 0.2643903176067397, 0.16195327683817595, 0.21786922094179317, 0.21728512103436515, 0.46385147084947675, 0.022153933787194546, 1.9436276494525373, 2.9413250321522355, 6.505849398672581, 2.2163118235766888, 3.0886148661375046, 2.407998237758875, 1.6955713788047433, 1.616215012036264, 0.9704905457329005, 2.3119253804907203, 0.2887037879554555, 0.10864344367291778, 0.061512798856711015, 0.02642925359396031, 0.06151657638838515, 0.04218688372930046, 0.12285166056244634, 0.1614094607066363, 0.22440872940933332, 0.9914678544737399, 1.0184344137087464, 1.1896395706571639, 0.9571597923059016, 1.5622678818181157, 0.7320816605351865, 0.29839386173989624, 1.0700995288789272, 0.6384735647588968, 0.17110916756791994, 0.0806684912822675, 0.1369895218522288, 3.693924047984183, 20.223269127309322, 55.38164064288139, 83.27050253748894, 89.1338463127613, 93.04865464568138, 75.36082416772842, 54.49238196015358, 33.45425225794315, 13.431969545781612, 5.812207069247961, 3.027461185120046, 0.7207979878876358, 0.3479199588764459, 1.870961298700422, 5.360350990667939, 5.634945156052709, 0.8953377034049481, 0.030319643665279727, 0.102903391525615, 0.05120350302604493, 0.0899388211837504, 0.03237386576074641, 0.09212273915181868, 0.056165361384046264, 0.010924937942036195, 0.039696648018434644, 0.02851991514035035, 0.03320698961033486, 0.02254505488963332, 0.024170849974325392, 0.29828043188899755, 0.34654746064916253, 0.6093050236813724, 0.34702668024692684, 0.21269352757371962, 0.2258917037397623, 0.22153229860123247, 2.5135660730302334, 42.51775771379471, 59.76505123078823, 18.85673325508833, 58.91928881406784, 101.46524861454964, 57.58462183177471, 41.739247888326645, 42.8015910834074, 73.74270379543304, 76.08125790953636, 8.138109762221575, 0.8563125506043434, 0.18497526179999113, 0.10682216132408939, 0.11836532590677962, 0.10722301754867658, 0.10717098557506688, 0.00728248271116172, 0.018668032753339503, 0.030925147111702245, 0.0882173799618613, 0.01501674410974374, 0.04376990327727981, 0.07222760046715848, 0.008793608558335109, 0.05605819525953848, 0.029873599924030714, 0.011501140470500104, 0.052525757855619304, 0.08240043389378116, 0.0162156391525059, 0.06906238515512086, 0.018629891928867437, 0.054114428858156316, 0.026392272375233006, 0.012329443143244134, 0.017400769211235456, 0.058200437924824655, 0.004062715370309888, 0.015241923774738098, 0.06197625523782335, 0.02117357526003616, 0.08026098541449755, 0.0470136712101521, 0.00781171656853985, 0.0574588097515516, 0.1479751628357917, 0.12874020903836936, 0.08407871922827326, 0.12907019758131355, 0.11465217554359697, 0.22075399348977953, 0.12479839555453509, 0.2031479202560149, 0.13461294234730303, 0.1619454546016641, 0.146230922837276, 0.18489162175683305, 0.10697151854401454, 0.18147952359868214, 0.18588069680845365, 0.14301205024821684, 0.1374232181115076, 0.18783180305035785, 0.17382609599735588, 0.1276041887467727, 0.14213385205948725, 0.14743854553671554, 0.13695188012206927, 0.17991215223446488, 0.18395712424535304, 0.20973448088625446, 0.2544982609106228, 0.15628564346116036, 0.14091092627495527, 0.3140970238018781, 0.0825947875273414, 0.1757463437388651, 0.07934427718282677, 0.11608713291934691, 0.15043275518110022, 0.2665378258097917, 0.14502340403851122, 0.30060718359891325, 0.3468061436433345, 0.27993819268886, 0.5967004469130188, 49.412487745285034, 119.16613519191742, 81.56165823340416, 94.82147231698036, 85.10397255420685, 39.385950565338135, 122.44519203901291, 91.28044992685318, 45.29218643903732, 79.36406895518303, 55.60325615108013, 4.586829822510481, 0.16277654125588015, 0.3308396675856784, 0.2861923899035901, 0.3001642698654905, 1.0547633143141866, 4.038048069924116, 7.950540902093053, 6.395259657874703, 11.854349300265312, 15.841984525322914, 8.939826842397451, 2.981367283500731, 4.570877328515053, 2.640324658714235, 1.9560221093706787, 0.9644648409448564, 5.201508114114404, 2.2528262017294765, 0.27128023852128536, 0.08099133294308558, 0.15764873125590384, 0.24395542975980788, 0.10422273713629693, 0.24624422803753987, 0.5613892979454249, 0.44624202826526016, 1.119678437244147, 1.376769554335624, 1.6277933469973505, 1.2877932912670076, 2.3788481019437313, 1.0837504151277244, 0.45011381269432604, 0.8963415026664734, 1.0347477695904672, 0.643231087597087, 0.9096768277231604, 0.40082475752569735, 2.904743207618594, 27.35028639435768, 70.0637412071228, 87.34778255224228, 87.95815140008926, 89.50073942542076, 74.00593087077141, 49.493970572948456, 29.580666013062, 11.024622973054647, 5.642695315182209, 2.4040699610486627, 0.9750285709742457, 0.24283860140712932, 2.161653656512499, 6.231943471357226, 14.259642083197832, 5.056576766073704, 0.6790905352681875, 0.12181318816146813, 0.22626944206422195, 0.21419602038804442, 0.1774302322883159, 0.16892470041057095, 0.16099421423859894, 0.10104939530720003, 0.15734857704956084, 0.1598813192686066, 0.1668032564339228, 0.275244761724025, 0.16298469883622602, 0.3541993594262749, 0.20945072814356536, 3.241707938723266, 0.7981894444674253, 0.3170017304364592, 0.4945210204459727, 0.44903226604219526, 1.9104065070860088, 49.036950096488, 63.49191024899483, 38.37637133896351, 100.3073899447918, 107.01702430844307, 55.50171419978142, 53.1472123414278, 65.01802995800972, 88.46275672316551, 89.37058880925179, 11.320626139640808, 0.9520501352380961, 0.40733689558692276, 0.2070056929369457, 0.13794049504213035, 0.1967088392120786, 0.20020186115289107, 0.14681407279567793, 0.13692213484318927, 0.2131451986497268, 0.1530997222289443, 0.1775229859049432, 0.3059971350012347, 0.1286981737939641, 0.09235341349267401, 0.18310543557163328, 0.13382090750383213, 0.16365482850233093, 0.1649314709356986, 0.13259050087071955, 0.11798277104389854, 0.12354213249636814, 0.10789834966999479, 0.16395557642681524, 0.08440574660198763, 0.1659889126312919, 0.13389294035732746, 0.17658305587247014, 0.15764801879413426, 0.15891511720838025, 0.09113075488130562, 0.11988183789071627, 0.1815019067726098, 0.1008299645036459, 0.08550647777155973, 0.1603205964784138], [0.006221598841875675, 0.05181173386517912, 0.058315953210694715, 0.029448733366734814, 0.030046963765926193, 0.04266145377187058, 0.016944572889769915, 0.07478916028048843, 0.0067132067397324136, 0.06317461593425833, 0.03272005167673342, 0.04908748414891306, 0.07326003178604878, 0.023693391121923923, 0.02537788823246956, 0.025807168713072315, 0.05838842022058088, 0.026924095400318038, 0.035010972496820614, 0.033869033577502705, 0.0403745368384989, 0.05720590066630393, 0.019979333483206574, 0.07965904427692294, 0.037918172747595236, 0.03944773168768734, 0.0645528658060357, 0.023373668336716946, 0.06382217688951641, 0.040885446142056026, 0.044899377826368436, 0.05344111908925697, 0.04532725564786233, 0.02536608066293411, 0.031502847850788385, 0.07010536239249632, 0.027800863099400885, 0.025111856120929588, 0.05006847721233498, 0.04755527574161533, 0.08804431854514405, 0.2149958032532595, 21.72830566763878, 92.67641142010689, 63.64022769033909, 49.36965264379978, 41.994050815701485, 16.48577068001032, 52.42620103061199, 80.93700215220451, 41.299573481082916, 43.95591974258423, 42.58865050971508, 13.228206429630518, 1.5106652257964015, 0.009093775752262445, 0.20445070113055408, 0.09335398441180587, 0.07205649089883082, 0.15365539788035676, 2.0768006471917033, 1.2160392478108406, 1.857851764652878, 2.3303798027336597, 1.0573767428286374, 0.3870386816561222, 1.7065919749438763, 0.20697407744592056, 1.180465081706643, 1.1776855308562517, 0.5927467590663582, 0.06806802601204254, 0.015316034641728038, 0.05440666063805111, 0.045103783850208856, 0.03374021158379037, 0.08815458684694022, 0.07702908813371323, 0.04212701096548699, 0.06785485151340254, 0.10299051966285333, 0.15667323750676587, 0.6324719649273902, 0.2823941077804193, 0.8142434048932046, 0.33322620671242476, 0.0807637904654257, 0.03570119210053235, 0.11597597404033877, 0.06350996278342791, 0.08621629749541171, 0.20688466349383816, 0.6067213998176157, 5.20355905406177, 13.506850227713585, 13.175956383347511, 6.847233530133963, 1.8294070847332478, 1.3852521241642535, 0.40176164475269616, 0.6187409861013293, 0.7302302098833025, 0.5006433231756091, 0.8780492248479277, 1.0071509191766381, 0.6703359237872064, 1.611085762269795, 4.014668399468064, 0.9029688814189285, 0.18100239685736597, 0.010258353886456462, 0.07612645102199167, 0.12591891980264336, 0.04143792684772052, 0.07896681345300749, 0.056163045883295126, 0.04064130553160794, 0.09347856132080778, 0.11586525302845985, 0.03159425818012096, 0.033711082287481986, 0.20339386799605563, 0.2169183368096128, 1.8753510131500661, 0.15509587683482096, 0.04483928612899035, 0.1652508319239132, 0.13703762786462903, 10.78440461307764, 54.45376843214035, 51.35246604681015, 54.75931763648987, 91.63494050502777, 68.36724624037743, 34.35658223927021, 34.65558439493179, 53.841632679104805, 82.76289537549019, 49.992462024092674, 4.307333445176482, 0.20266990293748677, 0.04045913054142147, 0.11388872080715373, 0.025359165701956954, 0.0359040655894205, 0.05258490331470966, 0.061704970576101914, 0.0559928343136562, 0.011962479875364807, 0.013667643015651265, 0.055293905606959015, 0.054228266890277155, 0.09811459458433092, 0.03667646320536733, 0.059520035865716636, 0.04213068830722477, 0.015080552111612633, 0.005206448895478388, 0.010908624608418904, 0.03931538449251093, 0.09622271914849989, 0.010658998598955804, 0.03274199327279348, 0.05645681761961896, 0.06032341443642508, 0.0222142314305529, 0.0028531623911476345, 0.04271236510248855, 0.054638778456137516, 0.03493811214866582, 0.036026278758072294, 0.05147262061655056, 0.050067894626408815, 0.04028358292998746, 0.08010762059711851, 0.04322472530475352, 0.10008552359067835, 0.02908263933932176, 0.08332207740750164, 0.026699308145907708, 0.024591207984485663, 0.013477972333930666, 0.04769441729877144, 0.02126775565557182, 0.036627277368097566, 0.05044611534685828, 0.007341169430219452, 0.07635443878825754, 0.021455025489558466, 0.030846596346236765, 0.02211866321886191, 0.06767217928427272, 0.04930666633299552, 0.056034709996310994, 0.04567630254314281, 0.032073915645014495, 0.03932963001716416, 0.012590442565851845, 0.025473296882410068, 0.09369422201416455, 0.06842764851171523, 0.021323604123608675, 0.0244203637339524, 0.04262219415977597, 0.06451275272411294, 0.011174911833222723, 0.028744683841068763, 0.08548318917746656, 0.04545656374830287, 0.015374836857517948, 0.03442788562097121, 0.0675253602094017, 0.07753794168820605, 0.057024415873456746, 0.013484373357641743, 0.00932665334403282, 0.05863889506144915, 0.1328653033124283, 38.81458282470703, 107.97826632857323, 66.66913256049156, 45.88254556059837, 23.601398058235645, 38.08627970516682, 99.71402898430824, 65.62066242098808, 40.25152511894703, 72.09842562675476, 64.43257257342339, 15.629181694239378, 1.2356846686452627, 0.07427895601722412, 0.35005217883735895, 0.17181155097205192, 0.08925023430492729, 0.3013052773894742, 0.338260016287677, 1.3167047523893416, 1.904628798365593, 2.967203068546951, 0.9126141888555139, 0.9134864201769233, 2.532067517749965, 0.9185987489763647, 1.626211206894368, 1.0342571209184825, 0.913874771213159, 0.09823694505030289, 0.004013254010715173, 0.038591029806411825, 0.03709994380187709, 0.02408732867479557, 0.079979058355093, 0.11404373319237493, 0.0845085340552032, 0.040554886145400815, 0.03333832006319426, 0.42616921942681074, 0.7949105172883719, 0.6360414577648044, 1.208668474573642, 0.48274064320139587, 0.4613666416844353, 0.1101934042526409, 0.06957923906156793, 0.1300421735504642, 0.13012636278290302, 0.14913099847035483, 0.8825806598179042, 5.448781745508313, 15.450671073049307, 15.398350730538368, 7.782158637419343, 2.480501434765756, 1.772494688630104, 0.8483318507205695, 0.8668691560160369, 1.2422547535970807, 0.4256299155531451, 1.147871024440974, 1.8065532110631466, 0.34035848337225616, 0.9664839575998485, 5.609913524240255, 0.32200368703342974, 0.21113895083544776, 0.05635879104374908, 0.05047848040703684, 0.12351875484455377, 0.0181239420271595, 0.05856294737895951, 0.06156939132779371, 0.061589388496940956, 0.09034115428221412, 0.030120998562779278, 0.022978222368692514, 0.1189709258324001, 0.11892330963746645, 0.8977118041366339, 0.9017142362426966, 0.12554533750517294, 0.12105556670576334, 0.336162528838031, 0.14560756331775337, 18.373028710484505, 71.97839766740799, 64.2736878991127, 44.94988560676575, 83.68621543049812, 90.84037274122238, 46.78378500044346, 32.90925890207291, 50.53695760667324, 86.50596812367439, 64.0342627465725, 6.672465233132243, 0.37416149920318276, 0.12346678966423497, 0.09247311449144036, 0.020539508404908702, 0.02772421223198762, 0.07101818919181824, 0.06296147854300216, 0.04017036088043824, 0.042299200358684175, 0.015359734152298188, 0.1278029804234393, 0.07012171932728961, 0.02683167203940684, 0.025884309397952165, 0.11637972464086488, 0.11238072125706822, 0.06408462257240899, 0.050028794576064683, 0.03119257446087431, 0.023022786481305957, 0.06277010092162527, 0.046966986410552636, 0.0282403110031737, 0.07989285048097372, 0.007825984357623383, 0.03233815361454617, 0.011890774494531797, 0.030941372315282933, 0.08115306176478043, 0.03615104862547014, 0.03919872629921883, 0.049708290680428036, 0.03428983131016139, 0.030902307516953442, 0.028500391090346966, 0.04057942525832914, 0.09197592749842443, 0.12225444690557197, 0.19533114595105872, 0.113381485134596, 0.14785569190280512, 0.1179718911589589, 0.1032568170921877, 0.1137063602800481, 0.08984539963421412, 0.10819281902513467, 0.09946128833689727, 0.16226128296693787, 0.17450403305701911, 0.1780008993227966, 0.12407947710016742, 0.1793789488147013, 0.14872731466311961, 0.13087729748804122, 0.1355645092553459, 0.13959346571937203, 0.11371883578249253, 0.09226077861967497, 0.12946292728884146, 0.2672570856520906, 0.10393231248599477, 0.12423271575244144, 0.11875134659931064, 0.1479878238751553, 0.23583881295053288, 0.06201175958267413, 0.14555877452949062, 0.22985463874647394, 0.19381260790396482, 0.07438215907313861, 0.14272947009885684, 0.23131582362111658, 0.13284991116961464, 0.10706027198466472, 0.1248797943117097, 0.20521892787655815, 0.2871529071126133, 0.3574523708084598, 40.468140095472336, 126.35065287351608, 84.1203573346138, 69.91364166140556, 49.07192721962929, 28.378739207983017, 82.24649548530579, 110.69218710064888, 56.95794805884361, 69.42555025219917, 74.22060415148735, 21.981484182178974, 1.7268047528341413, 0.11039683435228653, 0.29622521717101336, 0.18642800103407353, 0.1940244613797404, 1.9730605138465762, 7.32420863583684, 4.978716569021344, 7.529284581542015, 6.242264192551374, 6.877665147185326, 3.5128003545105457, 4.538276977837086, 1.6082164412364364, 2.157771452330053, 5.829602535814047, 3.313236963003874, 0.2719609660562128, 0.11899344259290956, 0.15336832031607628, 0.19536406762199476, 0.15366675273980945, 0.33345294767059386, 0.33064463117625564, 0.17262902663787827, 0.29313865466974676, 0.2139489445835352, 0.5124070169404149, 1.245494910981506, 1.5503454278223217, 1.6996187553741038, 0.7644461863674223, 0.9476747887674719, 0.323753374395892, 0.2665638900361955, 0.21932678413577378, 0.4867484187707305, 0.28562414227053523, 0.975468159886077, 6.748633095994592, 16.79172456264496, 15.862561371177435, 8.236848413944244, 2.4123855773359537, 2.020890209823847, 1.2626747391186655, 1.5861287014558911, 1.7888485360890627, 1.8899631290696561, 2.5044316006824374, 3.069089138880372, 1.7581585329025984, 4.16480309329927, 13.443206492811441, 6.260907417163253, 0.6286652816925198, 0.1632121077273041, 0.25242766889277846, 0.3259683586657047, 0.09348830571980216, 0.20713222911581397, 0.22719418775523081, 0.2517581626307219, 0.2579520974541083, 0.3119371662614867, 0.10320981687982567, 0.22540985693922266, 0.42591481120325625, 0.6957062124274671, 5.091491192579269, 0.3555723623139784, 0.14531411812640727, 0.41145474649965763, 0.14246817474486306, 14.53441008925438, 76.95034727454185, 69.07403871417046, 72.36623525619507, 109.89666938781738, 89.8723366856575, 47.9742307215929, 46.86353512108326, 69.04755413532257, 98.24384227395058, 76.5425531566143, 8.807106614112854, 0.606648491229862, 0.23275860323337838, 0.25253394444007427, 0.22546749212779105, 0.1110932879964821, 0.2252934139687568, 0.17238046653801575, 0.11171242469572462, 0.08734645482036285, 0.12810077460017055, 0.3139542939607054, 0.1833600367535837, 0.16133057040860876, 0.11154005347634666, 0.15257319813827053, 0.2601692487951368, 0.11055022143409587, 0.14592330262530595, 0.12903996248496696, 0.15407399885589257, 0.18138552317395806, 0.13119202747475356, 0.10167748972889967, 0.14340013411128893, 0.18967734620673582, 0.16985085618216544, 0.10092576834722422, 0.11740827452740632, 0.13357452931813896, 0.1157073091599159, 0.21010810771258548, 0.08616480728960596, 0.13180714915506542, 0.16637396853184327, 0.2048246396589093, 0.13004373206058517], [0.006439865865104366, 0.04114645947993267, 0.02937148692581104, 0.04324067776906304, 0.007405844817185425, 0.06553469007485546, 0.009358404277008958, 0.04375663738755975, 0.060903688572579995, 0.014259393537940923, 0.018258074087498244, 0.0482691253273515, 0.0034636106283869594, 0.06275470135733485, 0.03914506160072051, 0.04849696095334366, 0.040130845227395184, 0.02028076232818421, 0.02888755469030002, 0.062086482721497305, 0.027399405735195614, 0.04080514576344285, 0.08996379445306957, 0.056009625404840335, 0.08740827572182752, 0.031046321273606736, 0.043195926264161244, 0.09450693309190683, 0.012208007374283625, 0.012834333629143657, 0.05589919754129369, 0.013028620469413, 0.0364705320680514, 0.051301169660291635, 0.04181562064331956, 0.04069647678988986, 0.03811182134086266, 0.12549524253699929, 0.1394655936746858, 0.012329830915405182, 0.09969320948584937, 0.0686134748684708, 0.024376764413318597, 13.180824872106314, 75.66204160451889, 81.65494322776794, 75.89628383517265, 60.568643510341644, 18.317870870232582, 42.09471881389618, 86.63950815796852, 56.413691863417625, 36.6012167930603, 52.88638673722744, 48.603480756282806, 15.163423586636782, 2.5903637520968914, 0.03522013568726834, 0.07788117014570162, 0.11582718827412464, 0.5960080528166145, 0.5850302637554705, 2.1894914377480745, 1.7177209840156138, 0.38596060825511813, 0.27388277230784297, 1.1189048225060105, 0.7672887900844216, 1.6732836747542024, 1.0153367486782372, 0.33334833453409374, 0.010827207297552377, 0.08811278166831471, 0.07893550224252976, 0.029212930785433855, 0.030541779597115237, 0.04967465654772241, 0.053205101285129786, 0.043516949663171545, 0.01166947255114792, 0.06413220165995881, 0.03470435047347564, 0.22575238777790219, 0.06879771302919835, 0.2770876628346741, 0.21351983479689807, 0.1333540224004537, 0.028744008486683015, 0.049120238836621866, 0.02294228757818928, 0.10114199307281524, 0.3753886552294716, 0.4918822995387018, 0.8194402197841555, 0.4866327624768019, 0.2526896173367277, 0.31469727284274995, 0.7337639015167952, 0.37682153459172696, 0.11827573383925483, 0.4118296201340854, 0.1834161876467988, 0.12994832155527547, 0.039384957126458175, 0.0755775957077276, 0.09432541861315258, 0.21099766076076776, 0.02372674880462, 0.8214038831647485, 0.21154261979972944, 0.0747657752071973, 0.011880576457770076, 0.1405839656945318, 0.025339014537166804, 0.11888609093148261, 0.06465537124313414, 0.0312513154494809, 0.02346405450225575, 0.045235637517180294, 0.189688463578932, 0.11541208281414583, 0.6471796694677323, 0.9467333892825991, 0.08573409446398728, 0.1377390613197349, 0.4185873793903738, 2.114441664889455, 25.593011789023876, 46.4535903185606, 38.70468892157078, 53.24464671313763, 75.3354187309742, 44.446101039648056, 26.987945437431335, 38.42423357069492, 71.3623671233654, 78.65223035216331, 31.866205371916294, 0.15786867414135486, 0.07651482432265766, 0.05818039251607843, 0.019077664874203037, 0.048880016765906475, 0.0327938434202224, 0.030620441684732214, 0.046512740082107484, 0.026120058173546568, 0.059943568412563764, 0.03065522243559826, 0.0502426295861369, 0.03176995051035192, 0.012784679311153013, 0.018811950030794833, 0.03106959688011557, 0.03452400487731211, 0.07792192147462629, 0.047984229677240364, 0.024409754732914735, 0.07127978140488267, 0.012953292480233358, 0.07982598297530785, 0.05556562071433291, 0.014607034991058754, 0.02906221543526044, 0.060014706978108734, 0.012432644343789434, 0.05669096150086261, 0.018949902296299115, 0.05483290944539476, 0.024029860469454434, 0.06510891253128648, 0.02087007582304068, 0.05765402798715513, 0.029347172312554903, 0.04828963828913402, 0.021659672711393796, 0.03191231669916306, 0.02471175688697258, 0.033916497632162645, 0.013731381441175472, 0.039132916353992186, 0.046813851658953354, 0.055474395921919495, 0.02869564272259595, 0.03986199852079153, 0.06972054397920147, 0.026281703503627796, 0.049951726250583306, 0.025357915183121804, 0.030804444213572424, 0.03908890328602865, 0.02281576624227455, 0.016207852168008685, 0.051097027098876424, 0.033645955118117854, 0.07317583513213322, 0.025721046185935847, 0.016846407161210664, 0.10843038049642928, 0.035604375225375406, 0.04492379077419173, 0.019618792575784028, 0.12979515711776912, 0.07635323650902137, 0.011998099253105465, 0.007315317179745762, 0.05394440653617494, 0.07714737905189395, 0.0241423644911265, 0.047922067387844436, 0.02486672474333318, 0.044524463373818435, 0.09126807446591556, 0.07322463134187274, 0.06028456300555263, 0.2671349875163287, 0.13778942346107215, 0.15943791571771726, 0.026156813037232496, 29.113999754190445, 99.21275228261948, 76.19744807481766, 47.455904334783554, 26.2465463206172, 26.251157373189926, 82.13256999850273, 87.76637569069862, 48.55542853474617, 50.10188475251198, 67.48524516820908, 52.61060133576393, 14.173872135579586, 1.085196475032717, 0.0975091579311993, 0.272177851293236, 0.1909148329286836, 0.390086563420482, 0.014801026827626629, 1.2157186400145292, 1.1900660977698863, 0.5692778527736664, 0.667409902671352, 0.4904740594793111, 0.10324244911316782, 0.6750287907198071, 0.5110657482873648, 0.42497842863667756, 0.027518316346686333, 0.06356874087941833, 0.07529460737714544, 0.04229152655170765, 0.022520168822666164, 0.06886086237500422, 0.06622456086915918, 0.04864093760261312, 0.04225591088470537, 0.08345512964297086, 0.08725440624402836, 0.13925911334808916, 0.10503824611078016, 0.2225302200531587, 0.39172460208646953, 0.07305217848625034, 0.05815639888169244, 0.0731292059936095, 0.022090919883339666, 0.08357472674106248, 0.4826893756398931, 0.18101864989148453, 0.8480948978103697, 0.1841778983362019, 0.6226609507575631, 0.42143428756389767, 0.47921279969159514, 0.45797556114848703, 0.6829469127114862, 0.6793739169370383, 0.3581447945907712, 0.11851211529574357, 0.12646571936784312, 0.06320658765616827, 0.046565068914787844, 0.11152401566505432, 0.014294818101916462, 0.6346024037338793, 0.18378987384494394, 0.11303471663268283, 0.04583823916618712, 0.12512715213233605, 0.06324176545604132, 0.051466776203596964, 0.14549002196872607, 0.013922306352469604, 0.061872105943621136, 0.05479715648107231, 0.004450820570127689, 0.1804046265897341, 1.3693740824237466, 1.5371030196547508, 0.06360996718285605, 0.19016032107174397, 0.4281106183771044, 3.7379294866696, 43.02862890064716, 64.8907519876957, 48.41060310602188, 51.41547426581383, 93.89456525444984, 67.89699107408524, 40.34876570105553, 35.468033999204636, 60.05056791007519, 88.23915392160416, 42.04982042312622, 0.835699844174087, 0.2868137159384787, 0.028646924438362475, 0.08019028100534342, 0.038553766571567394, 0.01921851151564624, 0.06258984067244455, 0.06251105427509174, 0.016954886887106113, 0.1236006137332879, 0.036580559171852656, 0.050371199249639176, 0.040644418841111474, 0.04242144692398142, 0.004523144716586103, 0.029559153808804695, 0.015761672984808683, 0.018315063607587945, 0.027640050830086693, 0.03134992461127695, 0.03533458599122241, 0.08310194898513146, 0.02344723186979536, 0.09054210560861975, 0.022067839090595953, 0.0433431572309928, 0.0333443537238054, 0.0024345222209376516, 0.06340629217447713, 0.04750295804115012, 0.013954089754406596, 0.011417251807870343, 0.11604230719967745, 0.04762477045005653, 0.041973438346758485, 0.017552440076542553, 0.03561392666597385, 0.028030503999616485, 0.07007466716459021, 0.1553306626738049, 0.10437166391056962, 0.14533280540490523, 0.14318299654405564, 0.14796634612139314, 0.17252171208383515, 0.16279136936645955, 0.16343721596058458, 0.1607746721128933, 0.12076548344339244, 0.1266826639766805, 0.10639298474416137, 0.2509775123326108, 0.14163781539537013, 0.1529510403634049, 0.18526340805692598, 0.15811524528544396, 0.074059079925064, 0.11558004567632452, 0.11576461038202979, 0.09910824868711643, 0.17549865937326103, 0.16469431022414938, 0.36087669956032187, 0.1528975463588722, 0.18826729530701414, 0.20902906951960176, 0.12452009017579257, 0.056770683004288, 0.20211743336403742, 0.2513481111964211, 0.10402748550404795, 0.13798821513773873, 0.12109734961995855, 0.1568999487790279, 0.10031932237325236, 0.2178829358308576, 0.2166964198113419, 0.3081989981001243, 0.24130174715537578, 0.4158578789792955, 0.20984786620829254, 26.674849838018417, 111.19108512997627, 106.8750487267971, 92.85125523805618, 75.96787199378014, 28.454746529459953, 69.29891064763069, 115.55632889270782, 76.22255712747574, 50.40218263864517, 81.85583844780922, 75.49566373229027, 19.871037527918816, 2.538674888201058, 0.24645539873745292, 0.46284701849799603, 0.20990698569221422, 1.5699735120870173, 1.1728213168680668, 7.291747452691197, 5.4374331794679165, 2.681170329451561, 1.4376409817487001, 0.6080542970448732, 2.0786862960085273, 4.73156358115375, 1.6580748721025884, 1.217421186156571, 0.14497273019514978, 0.26212065189611167, 0.19526482763467357, 0.18083973292959854, 0.1434534351574257, 0.17012545082252473, 0.2653218019986525, 0.18994070473127067, 0.08213814406190068, 0.11499541884404607, 0.19920803635613993, 0.40890742850024253, 0.436170045286417, 0.4420338134514168, 0.7529217610135674, 0.27042510628234595, 0.12933262099977583, 0.13747660821536556, 0.1882721489528194, 0.24148286087438464, 1.7893716017715633, 1.6103843436576426, 1.132640610449016, 0.5034476320724934, 1.39829789288342, 1.0175187815912068, 1.18613603990525, 1.4675667509436607, 1.2197189941070974, 0.8165922726038843, 0.6542420061305165, 0.3006423910846934, 0.19885372021235526, 0.22952824219828472, 0.2228615593048744, 0.34429525025188923, 0.22364946780726314, 5.566232968121767, 0.9136027295608073, 0.1615266755106859, 0.14023773896042258, 0.24249731737654656, 0.21337204350857064, 0.12475104653276503, 0.2858588984236121, 0.12377364546409808, 0.10075243233586662, 0.24300628225319088, 0.3165652585448697, 0.47428677964489907, 1.3880873657763004, 3.9365918515250087, 0.15434841538080946, 0.1856175163993612, 0.40844515955541283, 1.9662607787176967, 38.644625544548035, 71.88915565609932, 56.83156304061413, 70.33598139882088, 98.62667173147202, 64.21762570738792, 43.5821034014225, 54.54318143427372, 80.60746863484383, 102.36725941300392, 50.74911542236805, 1.3305597589351237, 0.3998172178398818, 0.12497857416747138, 0.208574429852888, 0.14188181870849803, 0.07240453589474782, 0.19753294967813417, 0.21641587314661592, 0.20036459929542616, 0.15628585126250982, 0.1678782276576385, 0.10729828616604209, 0.10824091761605814, 0.08337025763466954, 0.11510268886922859, 0.11743206778191961, 0.23619951156433672, 0.1928206830052659, 0.07632534659933299, 0.06500429939478636, 0.18085185962263495, 0.13678146817255765, 0.1610424686805345, 0.18236621195683256, 0.09810211908188649, 0.17332217772491276, 0.11079408373916522, 0.08397835117648356, 0.1434534796862863, 0.10681380474125035, 0.1389063854003325, 0.07336917944485322, 0.2289599203504622, 0.15669391374103725, 0.23439438577042893, 0.10431487477035262, 0.08885607967386022, 0.0822896980389487], [0.04534075902483892, 0.03129563650873024, 0.05427777927252464, 0.011544509725354146, 0.016068831209850032, 0.046216103655751795, 0.03272498695878312, 0.029746518266620114, 0.050346630450803787, 0.010455027659190819, 0.013301698345458135, 0.028485023067332804, 0.051795269318972714, 0.03585419326554984, 0.0031661075126976357, 0.08251694365753792, 0.016877419657248538, 0.0035143964896633406, 0.034094958173227496, 0.04361928440630436, 0.06268117678700946, 0.08132987844874151, 0.037698192754760385, 0.09076227855985053, 0.03656309643702116, 0.03002066761837341, 0.12280188471777365, 0.09225284506101161, 0.055072066534194164, 0.08062277498538606, 0.03877010261930991, 0.035384406364755705, 0.053305020337575115, 0.05123067676322535, 0.04712792484497186, 0.042865804134635255, 0.036863907444057986, 0.04796196524694096, 0.014437014524446568, 0.05747194947616663, 0.03570511064026505, 0.11308501198072918, 0.0937244422675576, 0.445122899254784, 3.0782043747603893, 54.848977625370026, 74.46869283914566, 73.56911391019821, 64.81806188821793, 25.50552148371935, 30.1605186983943, 78.37605357170105, 65.91046527028084, 40.92034623026848, 47.60351121425629, 50.50582967698574, 34.13203328847885, 9.372905753552914, 0.4673916340107098, 0.08381388382986188, 0.2455921919317916, 0.1924618991324678, 0.6462190335150808, 0.27523837925400585, 0.24488872499205172, 0.20706862705992535, 0.3565161960432306, 0.09715056701679714, 0.5992553941905499, 0.39735201105941087, 0.16248579748207703, 0.049703975091688335, 0.1116501510841772, 0.0462548326322576, 0.05126235533680301, 0.12872183346189559, 0.04915397315926384, 0.0328384168096818, 0.07227379916002974, 0.017930076355696656, 0.04326492373365909, 0.07383637625025585, 0.06751125198206864, 0.12207967112772167, 0.0958889901812654, 0.08279454399598762, 0.04575690720230341, 0.05499591847183183, 0.03808138586464338, 0.08269286234281026, 0.034216336425743066, 0.05236142409557942, 0.571993519552052, 0.4267597908619791, 0.03361698538355995, 0.2802941860863939, 0.22181041102157906, 0.12348949196166359, 0.061971427567186765, 0.07422537295497023, 0.10318512562662363, 0.04583344860293437, 0.04009520729596261, 0.01951620179170277, 0.02698230204259744, 0.13871540111722425, 0.024524451800971292, 0.23346788861090317, 0.18185513938078657, 0.38079882273450494, 0.3722548921359703, 0.06969151116209105, 0.1342683780239895, 0.07772118537104689, 0.03083564410189865, 0.03411603145650588, 0.15772851213114336, 0.15075450588483363, 0.2446138483355753, 0.21278849279042333, 1.4727780525572598, 1.3866244442760944, 0.06936864723684266, 0.17642956488998607, 0.08873944374499843, 10.154112484306097, 43.198643177747726, 40.12123391032219, 33.28975148499012, 66.05633184313774, 69.02541652321815, 29.708810336887836, 26.611313447356224, 52.88761027157307, 72.30532452464104, 61.43568858504295, 19.970303401350975, 0.4723241552710533, 0.10916637576883659, 0.10715467316913418, 0.039394412087858655, 0.021364951026043855, 0.10334883598261513, 0.025956180834327824, 0.06786883357563056, 0.05700675646949094, 0.019311261421535164, 0.011474163402453996, 0.03257496180594899, 0.04041727712319698, 0.056698549960856326, 0.060229729424463585, 0.02342599160328973, 0.029608280274260323, 0.017666821731836535, 0.040554782244726084, 0.08578067907365039, 0.06940746898180805, 0.022286902531050146, 0.0370320855290629, 0.01936201319040265, 0.06677728277281858, 0.025482046803517733, 0.020853698479186278, 0.03253856688388623, 0.03406356161576696, 0.024351065694645513, 0.04738527197332587, 0.015174572017713217, 0.05534460913622752, 0.06323587280348875, 0.05225800210610032, 0.039718682382954285, 0.018853094697988126, 0.02773819986032322, 0.029126988229108974, 0.048463274870300665, 0.027423909596109297, 0.09808452276047319, 0.03592266009945888, 0.018552738256403245, 0.03869255189783871, 0.052203784507582895, 0.02414440539723728, 0.05674621068465058, 0.0389533129055053, 0.01956449334102217, 0.035305924247950315, 0.02852516026905505, 0.02176231544581242, 0.01216317794387578, 0.12484596722060814, 0.022389827281585895, 0.004804883456017706, 0.029210049397079274, 0.01240205023350427, 0.04360658254881855, 0.078753304987913, 0.07646323763765395, 0.023263695038622245, 0.009629302094253944, 0.01621093208086677, 0.07976659631822258, 0.06216396293893922, 0.03149721123918425, 0.07364754419540986, 0.10185891514993273, 0.0271600965061225, 0.005889063804715988, 0.017234175611520186, 0.027216015478188638, 0.06453840876929462, 0.09788011302589439, 0.07401124850730412, 0.1131013169651851, 0.08534724256605841, 0.05306631595885847, 0.10201178272836842, 0.10097359234350733, 0.4287560493685305, 11.634176764637232, 80.46642780303955, 91.52603074908257, 62.016726806759834, 33.889830484986305, 26.666186302900314, 63.24013575911522, 90.86781486868858, 62.46245048940182, 52.47209116816521, 70.89758366346359, 70.18477991223335, 50.430852100253105, 8.390337377786636, 0.2698508620960638, 0.18662572401808575, 0.3306062176125124, 0.1794752202113159, 0.37225572334136814, 0.43779600178822875, 0.0687957760237623, 0.1114618088467978, 0.6394325383007526, 0.9016271971631795, 1.203313018195331, 0.2687387092737481, 0.0808468961622566, 0.06068227252399083, 0.03472976532066241, 0.06366625166265294, 0.11275638898951001, 0.01495401129432139, 0.06277742591919377, 0.04170967535173986, 0.13075129565550014, 0.03282202276750468, 0.012660129305004375, 0.09420438174856827, 0.13618871482321993, 0.07270607049576938, 0.19169116392731667, 0.17915890202857554, 0.07859018092858605, 0.016522713885933626, 0.030777892025071196, 0.08060622509219684, 0.10961488529574126, 0.4539204662432894, 0.5610061122570187, 0.05044008168624714, 0.06912718949024566, 0.3644729097140953, 0.23055623547406867, 0.1734853908419609, 0.042565531184663996, 0.16347050870535895, 0.07218912753160112, 0.15766879892908037, 0.0481974190188339, 0.04876053470070474, 0.07121767848730087, 0.18791671958751976, 0.005224374544923194, 0.09729370503919199, 0.14155720331473276, 1.4198435680009425, 0.3875634988071397, 0.11813297431217507, 0.30284146370831877, 0.034815093749784864, 0.09382823162013665, 0.027004366093024146, 0.15178781293798238, 0.09562441453454085, 0.12779961107298732, 0.11735351145034656, 2.0858436869457364, 1.3054195954464376, 0.36685440223664045, 0.5737710522953421, 0.3570381930330768, 19.331075102090836, 59.688580334186554, 49.87280644476414, 35.38934402167797, 61.08442023396492, 91.6047777235508, 48.886143788695335, 31.452162489295006, 42.51189082860947, 72.22821146249771, 81.05418026447296, 28.21656011044979, 0.6253703834954649, 0.14764072140678763, 0.12235436224727891, 0.053680150012951344, 0.030616159492637962, 0.06108145520556718, 0.04356668840046041, 0.021976417629048228, 0.07201157612144016, 0.02949051257019164, 0.045510046620620415, 0.024983095354400575, 0.022570135770365596, 0.05214807519223541, 0.03409108045161702, 0.032924120023380965, 0.008480007563775871, 0.028632855173782445, 0.036077026816201396, 0.02038371119851945, 0.07124906391254626, 0.0562855967291398, 0.031019982452562544, 0.06571258287294768, 0.08931461561587639, 0.050664095251704566, 0.02906456618802622, 0.03846706516924314, 0.042154822949669324, 0.03431047414778732, 0.04771793224790599, 0.08587058284319937, 0.02405393202934647, 0.048888024539337493, 0.04542402057268191, 0.049575583543628454, 0.01198816096803057, 0.01689849294052692, 0.03564440296031535, 0.22339249175274745, 0.11772123078117147, 0.15458943526027724, 0.0895102383219637, 0.15010727889603004, 0.1828773587476462, 0.13414497370831668, 0.08276994180050679, 0.10895869316300377, 0.07500048683141358, 0.1511780940927565, 0.19222129485569894, 0.12557257432490587, 0.10654664642061107, 0.08780810778262094, 0.21314242301741615, 0.10882601200137287, 0.04172859640675597, 0.10019230379839428, 0.14448151749093086, 0.1261552344658412, 0.23059337254380807, 0.14357422711327672, 0.2303013819619082, 0.1159936297335662, 0.10561666858848184, 0.19799403118668124, 0.11389035353204235, 0.12285740478546359, 0.08300558853079565, 0.13613247487228364, 0.12517622293671593, 0.12865650962339714, 0.09899567230604589, 0.15190069359960034, 0.11541867308551446, 0.19406357256229967, 0.12852210667915642, 0.14143848937237635, 0.195912885828875, 0.08522825402906165, 0.14235432929126546, 0.2636433014413342, 0.6749142031185329, 8.292905855923891, 81.86801299452782, 106.66033744812012, 93.44777002930641, 78.9346008002758, 41.880482509732246, 54.15746793150902, 104.24351513385773, 94.71327692270279, 59.081878289580345, 69.02498334646225, 81.90405786037445, 60.04706829786301, 13.826890904456377, 0.6576118315570056, 0.22621859010541812, 0.8479848224669695, 1.0608005966059864, 1.6717816866002977, 1.8959127785637975, 0.27038241794798523, 1.0639760387130082, 1.116329391952604, 1.1191426659934223, 2.3712696461007, 0.4610026627779007, 0.6998598051723093, 0.09919408548739739, 0.23108541645342484, 0.34012384596280754, 0.2177420910447836, 0.22722114255884662, 0.17490679660113528, 0.15758303634356707, 0.16757278935983777, 0.08267106546554714, 0.08047577779507264, 0.17955869698198512, 0.3526488348143175, 0.2641862566815689, 0.4896951012779027, 0.2862761338474229, 0.17036973615176976, 0.1318174650077708, 0.10943245055386797, 0.19619579252321273, 0.3130443615373224, 1.2920627184212208, 1.2939648726023734, 0.7747543801087886, 0.2057709521614015, 0.6900150678120553, 0.5370587285142392, 0.37833308160770684, 0.12961925327545032, 0.24646072735777125, 0.20893677603453398, 0.21294898964697495, 0.18725559959420934, 0.1850729135912843, 0.22998846281552687, 0.619492573896423, 0.12999765953281894, 0.5290681729093194, 0.8339194615837187, 4.225043635815382, 1.4618967426940799, 0.188208190666046, 0.39523507934063673, 0.11347347433911636, 0.32491447927895933, 0.08837329034577124, 0.4307635291479528, 0.23143817408708856, 0.3651671146508306, 0.29182359867263585, 2.363872155547142, 2.8282601991668344, 0.48200930119492114, 0.6489940721075982, 0.23396537988446653, 14.521879311650991, 65.34760907292366, 61.45525373518467, 46.33292779326439, 82.52748280763626, 92.73717015981674, 48.900575414299965, 44.23517055809498, 67.4282406270504, 91.6521155834198, 95.64658284187317, 33.92722427845001, 0.6718427804298699, 0.23856153013184667, 0.25417429860681295, 0.1413959643105045, 0.11744699979317375, 0.2004283943097107, 0.1540075321099721, 0.15558882616460323, 0.1981553592486307, 0.0722502582357265, 0.1852134763612412, 0.17309411574387923, 0.09456720290472731, 0.19802762079052627, 0.23034896847093478, 0.084716884593945, 0.12424349915818311, 0.1121024826716166, 0.08761216595303267, 0.20434642938198522, 0.15294306969735771, 0.09836020835791714, 0.09828265392570756, 0.10954741665045731, 0.1805224796407856, 0.16274741938104853, 0.15592656272929162, 0.08330888944328763, 0.2318013514741324, 0.15684485173551366, 0.22733057965524495, 0.16221282072365284, 0.1052156490914058, 0.14826250757323578, 0.15401545824715868, 0.17620825645281002, 0.19126528990454972, 0.11756864521885291, 0.0685816070472356], [0.0890996451198589, 0.012414120337780332, 0.07350869578658603, 0.05838558150571771, 0.0739249812613707, 0.023361157582257874, 0.0029180956744312425, 0.016990599033306353, 0.06635747209656984, 0.035479286234476604, 0.014003973210492404, 0.018686491821426898, 0.04478354341699742, 0.06071225529012736, 0.0667655271536205, 0.06640012332354672, 0.034309861875954084, 0.04269725126505364, 0.03349372578668408, 0.04827937809750438, 0.03658674868347589, 0.02036262863839511, 0.026688023790484294, 0.04361862760561053, 0.026859871795750223, 0.03410519981116522, 0.05858336757228244, 0.07891169414506294, 0.06035829908796586, 0.060575414390768856, 0.07052845336147584, 0.04905462184979115, 0.014198334265529411, 0.0016583012688897725, 0.06922038839547895, 0.0996880441380199, 0.026753835591080133, 0.026908291365543846, 0.012988077869522385, 0.05607463754131459, 0.061722793252556585, 0.11311972964904271, 0.02025978552410379, 0.02057625028101029, 0.1692438981262967, 0.6498007569462061, 23.28101444989443, 69.45594862103462, 72.58805215358734, 63.65883909165859, 27.664768919348717, 16.695796810090542, 53.49804751574993, 74.24101665616035, 67.69017577171326, 44.34510625898838, 44.70720782876015, 53.469195663928986, 28.432470224797726, 4.308157525956631, 0.26390094542875886, 0.16079649125458673, 0.19071290938882157, 0.17444567056372762, 0.33209285815246403, 0.09778574894880876, 0.10862034803722054, 0.3291595046175644, 0.035118869636789896, 0.14074649603571743, 0.07597876363433897, 0.030786597417318262, 0.06650576804531738, 0.019633143856481183, 0.04138940894335974, 0.05322176992194727, 0.0491387108922936, 0.07931181564345025, 0.025085973720706534, 0.0199306151989731, 0.017367663858749438, 0.07125697520677932, 0.02913023141445592, 0.021889786730753258, 0.14406667178263888, 0.13328307308256626, 0.005701703057638952, 0.047884436789900064, 0.029943178124085534, 0.05869064130820334, 0.0635747671185527, 0.3177625505486503, 0.05030476961110253, 0.06247659635846503, 0.027432755996414926, 0.1300974190235138, 0.08684059954248369, 0.040433300091535784, 0.015489142442675075, 0.05035721718741115, 0.06807526937336661, 0.044610578479478136, 0.03094589941611048, 0.022448056188295595, 0.030361972058017273, 0.030186443000275176, 0.020698118350992445, 0.035961578323622234, 0.04213525622617453, 0.5487815150991082, 0.8301017351914197, 0.10843702271813527, 0.11014412564691156, 0.041564581770217046, 0.12964307621587068, 0.026065716265293304, 0.051927987587987445, 0.05563564976910129, 1.2136114155873656, 2.3145066294819117, 0.563328618882224, 0.1860673024202697, 0.16863458004081622, 4.1099663358181715, 19.731244929134846, 57.995041608810425, 59.55532528460026, 51.807031854987144, 86.07782229781151, 65.02515077590942, 28.259653598070145, 34.221913665533066, 51.86017580330372, 72.26218923926353, 43.57507757842541, 6.188608696684241, 0.07840319682145491, 0.08020150969969109, 0.06547562996274792, 0.024153326012310572, 0.014391730528586777, 0.0259865068437648, 0.04026576396427117, 0.07408324425341561, 0.08651444048155099, 0.033927514814422466, 0.011058540294470731, 0.018604152392072137, 0.05532628551009111, 0.08074548168224283, 0.057502448034938425, 0.0658655098231975, 0.05619395633402746, 0.0278632276240387, 0.023583217443956528, 0.08339916428667493, 0.009027455580508104, 0.06861005356768146, 0.014368924330483424, 0.03250149660743773, 0.06716385265463032, 0.0366060890519293, 0.020985472365282476, 0.05097996814583894, 0.03985874049249105, 0.09536186495097354, 0.0387419974867953, 0.046188595952116884, 0.03956089436542243, 0.0035932979199060355, 0.04680163961893413, 0.06769140833057463, 0.024370339269808028, 0.09427931639947928, 0.039055465822457336, 0.017641288141021505, 0.03383109127753414, 0.06611380274989642, 0.1885290804784745, 0.02296992330229841, 0.059505059325601906, 0.0232767846682691, 0.021343443586374633, 0.051084392034681514, 0.07462358713382855, 0.11786626870161854, 0.02489310809323797, 0.012910809164168313, 0.04049102062708698, 0.013959689258626895, 0.04469453764613718, 0.05776978076028172, 0.0425299637572607, 0.008537271678505931, 0.041776260841288604, 0.03845461193122901, 0.02669026693183696, 0.0164365820819512, 0.0504558708780678, 0.0663392226852011, 0.012244366116647143, 0.01079312138244859, 0.04263488488504663, 0.12826879683416337, 0.03724493348272517, 0.017562197463121265, 0.051994925597682595, 0.03230526534025557, 0.053929185087326914, 0.010792248431243934, 0.0832481223915238, 0.08508628117851913, 0.04158761803410016, 0.03846324310870841, 0.03451132157351822, 0.048843844488146715, 0.10797018214361742, 0.12851824751123786, 0.10206480175838806, 0.13484487833920866, 0.2524942543823272, 2.506871069781482, 44.13154251873493, 88.60081851482391, 68.36317285895348, 48.72200779616833, 29.927606396377087, 42.62311466038227, 70.94982326030731, 76.52967944741249, 64.70397680997849, 56.5246307104826, 63.07840883731842, 68.30064341425896, 27.23795872181654, 3.702566921710968, 0.2573165518697351, 0.35602997057139874, 0.2094664765172638, 0.41543001600075513, 0.42276825348380953, 0.3760943189263344, 0.13026753411395475, 0.25821713323239237, 0.11036299983970821, 0.013749424906563945, 0.01397679390720441, 0.07109006619430147, 0.11733965555322357, 0.05608571409538854, 0.011000037720805267, 0.048101307183969766, 0.0645302674092818, 0.032723179829190485, 0.04218319896608591, 0.05451892160635907, 0.02850039480108535, 0.050247809776919894, 0.16719889536034316, 0.04963980900356546, 0.14279688679380342, 0.08558527901186608, 0.07164712966186926, 0.07400063579552807, 0.052338784880703315, 0.0420571822905913, 0.02575729082309408, 0.15085401304531842, 0.033960714790737256, 0.06064799272280652, 0.06065847926947754, 0.12368964176857844, 0.09718941102619283, 0.11692737767589279, 0.10039143686299212, 0.04615003395883832, 0.028398831891536247, 0.055223501767613925, 0.030936832226871047, 0.07482383341994137, 0.030246219284890685, 0.07904528072685935, 0.054571977743762545, 0.06832938073785044, 0.14240642805816606, 1.9262165087275207, 2.9424098739400506, 0.1567296258872375, 0.2657531085424125, 0.06239506401470862, 0.1165452013083268, 0.15628693479811773, 0.05561611644225195, 0.0488320517615648, 1.0512120486237109, 3.0998090654611588, 0.5027234146837145, 0.17875585646834224, 0.3689894126728177, 8.727507535368204, 38.132644817233086, 74.96832802891731, 58.94755929708481, 51.757672503590584, 87.04842701554298, 86.71132430434227, 42.33420096337795, 31.848517321050167, 43.50036978721619, 81.03269621729851, 65.59404104948044, 10.626257099211216, 0.16889847291167825, 0.057098055476672016, 0.18449501803843305, 0.005906913384023937, 0.051797495762002654, 0.02482347237673821, 0.013438196929200785, 0.045420569585985504, 0.012335290339251515, 0.024856861600710545, 0.0613924930075882, 0.1344778120983392, 0.020104487412027083, 0.04341594707511831, 0.0877401493198704, 0.05452467696159147, 0.039918980619404465, 0.025839786103460938, 0.006841233243903844, 0.024702678565518, 0.0461031413578894, 0.09129653582931496, 0.05283993494231254, 0.06037957275111694, 0.03471521551546175, 0.04719770899100695, 0.03884811718307901, 0.055901743107824586, 0.03527488763211295, 0.015654200724384282, 0.021087283894303255, 0.050881971255876124, 0.028664307392318733, 0.044269609861657955, 0.04368581052403897, 0.03435763392189983, 0.045662387274205685, 0.03584768463042565, 0.006902404302309151, 0.016144266810442787, 0.13998278154758736, 0.12784316029865295, 0.3606011252850294, 0.1353581773582846, 0.20972848433302715, 0.17697349976515397, 0.0644856940198224, 0.12421608422300778, 0.20983061869628727, 0.1875843561720103, 0.15758729627123103, 0.10780872049508616, 0.18528568733017892, 0.18448385613737628, 0.14723638450959697, 0.12829457904445007, 0.11848937589093111, 0.18828820902854204, 0.1261771871941164, 0.09444840732612647, 0.3037309425417334, 0.182907682901714, 0.11642644283710979, 0.14594253909308463, 0.12189043089165352, 0.1569438839214854, 0.1777871756348759, 0.12335810955846682, 0.15094103728188202, 0.134383529657498, 0.15538434963673353, 0.1352154920459725, 0.14592965540941805, 0.04648824549803976, 0.2057221336872317, 0.1941877932404168, 0.20445033005671576, 0.07802122083376162, 0.09620838827686384, 0.1949476930894889, 0.16451313713332638, 0.2026794321136549, 0.1198062946787104, 0.1984481216641143, 0.6277948315255344, 1.0446049156598747, 40.48336587846279, 103.12675505876541, 98.58132496476173, 80.15670642256737, 50.86356908082962, 36.28326505422592, 73.04795667529106, 109.60396349430084, 98.46758186817169, 59.392333030700684, 66.79780125617981, 77.77209877967834, 42.15830460190773, 5.934102153405547, 0.5599865794647485, 0.5940249154809862, 0.514466684544459, 2.219536663033068, 1.310120893176645, 0.4256219894159585, 0.8541688125114888, 1.7748447437770665, 0.3721350501291454, 0.2623742586001754, 0.13913998380303383, 0.15686362807173282, 0.2920855471165851, 0.2267450251383707, 0.11473920720163733, 0.11228190429392271, 0.13960033800685778, 0.16587098536547273, 0.1150475769827608, 0.18279034935403615, 0.19825128925731406, 0.14226252562366426, 0.23116546450182796, 0.18692819372517988, 0.2830568456556648, 0.17670699453447014, 0.1153551675088238, 0.15612784802215174, 0.07963494674186222, 0.11376991038559936, 0.1935352079453878, 0.5380663275718689, 0.14883458468830213, 0.2190276689361781, 0.1707783032907173, 0.3311814117478207, 0.2590463199885562, 0.31068667711224407, 0.1870662925648503, 0.1162562461104244, 0.14696202735649422, 0.11568154921405949, 0.1390582585008815, 0.2702717488864437, 0.21761583688203245, 0.3835638868622482, 0.19724219106137753, 0.21240547037450597, 0.1584747267770581, 3.912139213643968, 3.243316914886236, 0.24501478619640693, 0.13992579944897443, 0.09679197610239498, 0.34074015507940203, 0.15824219706701115, 0.17147638223832473, 0.20397491025505587, 1.1787512549199164, 3.904677601531148, 1.766386991366744, 0.3234909806633368, 0.5842147918883711, 5.612537283450365, 30.74814196676016, 78.84753227233887, 71.24824404716492, 61.9414908438921, 104.91731777787209, 79.8767526447773, 46.24385677278042, 49.45781551301479, 66.58833369612694, 99.43290486931801, 76.88172295689583, 13.478190265595913, 0.28442907670978457, 0.1699740081676282, 0.177657195890788, 0.1720526599092409, 0.15060282574268058, 0.16453271498903632, 0.08543278250726871, 0.14908655866747722, 0.17861361644463614, 0.1312539671198465, 0.21795217820908874, 0.1971807115478441, 0.1738926221150905, 0.12158606870798394, 0.15043334889924154, 0.16769675770774484, 0.1765447758953087, 0.10042458859970793, 0.11586491906200536, 0.11431040911702439, 0.16608196310698986, 0.13993068278068677, 0.1327561037032865, 0.13719597249291837, 0.3268009889870882, 0.17280739441048354, 0.0722407216380816, 0.1597448976826854, 0.13323100400157273, 0.11260001847404055, 0.09539097198285162, 0.115718396846205, 0.13709459512028843, 0.10148200060939416, 0.11502625508001074, 0.10917182313278317, 0.18047575402306393, 0.2162842606776394, 0.13257904211059213, 0.18483014224329963], [0.09394457068992779, 0.04711710804258473, 0.09143453076831065, 0.0295114800974261, 0.09728872522828169, 0.021044098320999183, 0.042721085337689146, 0.013713594016735442, 0.012083605797670316, 0.017549673721077852, 0.11012833274435252, 0.0338388689851854, 0.009728477143653436, 0.0031266359246728825, 0.06284816001425497, 0.026732862497738097, 0.08035502294660546, 0.13241225184174255, 0.08754966969718225, 0.07033363217487931, 0.013516198505385546, 0.010193809303018497, 0.032250379808829166, 0.03481760220893193, 0.04750265747134108, 0.02376320495386608, 0.036659913312178105, 0.06409746172721498, 0.014678842417197302, 0.020732142111228313, 0.04184713223366998, 0.01614906850591069, 0.051719518305617385, 0.04227372242894489, 0.08822524672723375, 0.02143541980331065, 0.0740266777575016, 0.04312409750127699, 0.0864064802590292, 0.1151135984400753, 0.019446432488621213, 0.07936706111649983, 0.06114234471169766, 0.10067764611449093, 0.09250547213014215, 0.2668479544809088, 0.2680179651360959, 7.875149147585034, 48.68790462613106, 70.48205316066742, 72.38103166222572, 48.313081339001656, 22.381473518908024, 29.19987704604864, 57.71554380655289, 81.70709922909737, 72.10142746567726, 57.751163095235825, 58.938097804784775, 57.40321196615696, 15.43038111180067, 0.10506468883249909, 0.2036357784527354, 0.35114153288304806, 0.2964784379582852, 0.23488187289331108, 0.12177922006230801, 0.32322009676136076, 0.49916490563191473, 0.3225611289963126, 0.08357306433026679, 0.05805234977742657, 0.045087671824148856, 0.014206196392478887, 0.02486423483787803, 0.04111943788302597, 0.014799010041315341, 0.04541439120657742, 0.06751690714736469, 0.09103399366722442, 0.06324672300252132, 0.02346319361095084, 0.08076125232037157, 0.03990991157479584, 0.11380990472389385, 0.1752368445158936, 0.05067655962193385, 0.14727764792041853, 0.033577343565411866, 0.014634460130764637, 0.04239091867930256, 0.16595587221672758, 0.013171589653211413, 0.10776462950161658, 0.05790409093606286, 0.1039684253919404, 0.022141024128359277, 0.060280625912128016, 0.10396653291536495, 0.0688911197357811, 0.09272234252421185, 0.06970085480134003, 0.013629436325572897, 0.0672154690255411, 0.09256374556571245, 0.05377325614972506, 0.051279780964250676, 0.21290796372340992, 0.10994819866027683, 0.6304028572048992, 1.2332934094592929, 3.0501250689849257, 0.6203677738085389, 0.04252839782566298, 0.1964766508899629, 0.02906779081968125, 0.624613274121657, 1.7784163146279752, 1.6646868735551834, 0.2734916901681572, 0.0466628802678315, 0.6057069730013609, 16.620197966694832, 42.376238107681274, 46.488590240478516, 53.25017921626568, 66.93275481462479, 76.45557582378387, 53.26130501925945, 32.07421571016312, 43.58349032700062, 60.48887439072132, 62.46723063290119, 24.476760886609554, 2.323032421991229, 0.02617779540742049, 0.11447363707702607, 0.08323403642862104, 0.0835948834719602, 0.08759510397794656, 0.038682399317622185, 0.054834475376992486, 0.06878491098177619, 0.01310804511376773, 0.026703941002779175, 0.0597860920970561, 0.02927406705566682, 0.027919890599150676, 0.04634262870240491, 0.05713332233426627, 0.06508132690214552, 0.04798899797606282, 0.04971196802216582, 0.027746615814976394, 0.07860445242840797, 0.04833198894630186, 0.031717042802483775, 0.007952131836646004, 0.028084085206501186, 0.031092258359421976, 0.0321369907760527, 0.024620515396236442, 0.051536378523451276, 0.030077000337769277, 0.02347840021684533, 0.0334497015865054, 0.01770117574778851, 0.07675341737922281, 0.06917464983416721, 0.06818180467234924, 0.0285979408363346, 0.03696361127367709, 0.051461165567161515, 0.02874936122680083, 0.03327993159473408, 0.054681444526067935, 0.0042975976884918055, 0.061529140948550776, 0.006663381263933843, 0.06178790928970557, 0.03119261898973491, 0.04662622188334353, 0.040509878599550575, 0.019042659623664804, 0.035291611930006184, 0.033962332672672346, 0.07437919048243202, 0.06542269999044947, 0.06197745380632114, 0.033002383206621744, 0.016452438067062758, 0.054737228056183085, 0.013156355216779048, 0.10131696180906147, 0.027001451308024116, 0.13047586980974302, 0.055170646010083146, 0.023153000001912005, 0.028159741596027743, 0.06567657386767678, 0.06583038397366181, 0.015929875189613085, 0.0523826977587305, 0.07554118594271131, 0.035850070635206066, 0.09888883272651583, 0.033648641692707315, 0.05644957796903327, 0.030268975388025865, 0.061727119973511435, 0.016132893397298176, 0.08923308327211998, 0.050399174506310374, 0.04376621109258849, 0.029840329443686642, 0.149551336071454, 0.043820001956191845, 0.09733820421388373, 0.013507972726074513, 0.13330354151548818, 0.10338603242416866, 0.623618618119508, 0.5158054595813155, 22.62149713933468, 73.03331226110458, 80.81835731863976, 62.41606257855892, 41.18595577776432, 38.38002294301987, 58.99219170212746, 90.10524898767471, 85.66871345043182, 66.05695500969887, 61.181512624025345, 71.21497303247452, 58.24285291135311, 10.49875969067216, 0.07200836262200028, 0.2008559604291804, 0.19079586665611714, 0.5129584623500705, 0.20701960078440607, 0.19754911365453154, 0.5848794593475759, 0.08737478259718046, 0.0720334101060871, 0.09286507236538455, 0.07909336447482929, 0.05353719381673727, 0.07194202204118483, 0.0795429278514348, 0.01878011375083588, 0.08298651533550583, 0.04759339244628791, 0.04148225161770824, 0.06924395158421248, 0.04895542639133055, 0.05292676250974182, 0.03173897697706707, 0.06356093348586, 0.17181692412123084, 0.2810772112570703, 0.07690043683396652, 0.029962470252939966, 0.020527359447441995, 0.0806387460033875, 0.032458273926749825, 0.28155248262919486, 0.006216775345819769, 0.22236485470784828, 0.042817664725589566, 0.1558421360095963, 0.08829085258184932, 0.11742225658963434, 0.10373146506026387, 0.08162517158780247, 0.042624813941074535, 0.07552364157163538, 0.02508074714569375, 0.040853118189261295, 0.12422065585269593, 0.24431955709587783, 0.07707204364123754, 0.34925618092529476, 0.19965734740253538, 0.9639349475037307, 4.52123299241066, 5.06089998409152, 0.9442309860605747, 0.41198398685082793, 0.34878381877206266, 0.059807833313243464, 1.1067005898803473, 2.4248721823096275, 2.579823355190456, 0.34692108747549355, 0.3756417869590223, 1.2774527398869395, 25.524364672601223, 63.40580686926842, 41.84689611196518, 45.14002740383148, 73.7261138856411, 87.6769132912159, 73.20819407701492, 38.879046365618706, 37.52698011696339, 57.509925439953804, 78.09537783265114, 39.08276103436947, 3.997092917561531, 0.03802163555519655, 0.1591005502268672, 0.13785792369162664, 0.039194540586322546, 0.14008531667059287, 0.0830521211901214, 0.07929919171147048, 0.09156584637821652, 0.010403837095509516, 0.08794979119556956, 0.06862799127702601, 0.023509956336056348, 0.0010576428871900134, 0.011974453500442905, 0.06417775468435138, 0.031799599310033955, 0.04996909621695522, 0.010584777337498963, 0.04177894370513968, 0.01724984420434339, 0.013057689466222655, 0.03047684167540865, 0.05421307141659781, 0.04569303055177443, 0.004712179006673978, 0.058751883334480226, 0.027793348854174837, 0.0341252786165569, 0.02404959417617647, 0.060117141911177896, 0.01586918420798611, 0.03414125334529672, 0.01826394447562052, 0.045994531756150536, 0.015202884023892693, 0.04407417269248981, 0.017663652761257254, 0.036044446533196606, 0.005056968757344293, 0.024433855978713837, 0.05767874150478747, 0.13316137570654973, 0.19366619701031595, 0.19024468841962516, 0.11888265478773974, 0.166991286969278, 0.13526174268918112, 0.1433440129039809, 0.08643175038741902, 0.11312775226542726, 0.20165973604889587, 0.15797291620401666, 0.1375611239927821, 0.14529614330967888, 0.08881301284418441, 0.0959099706960842, 0.08134699979564175, 0.11345811188220978, 0.1539468244300224, 0.20545936888083816, 0.32454388041514903, 0.09636900387704372, 0.06582135203643702, 0.10205902042798698, 0.11793007855885662, 0.20255234674550593, 0.1475504762493074, 0.1571470542694442, 0.16135669400682673, 0.1716590247815475, 0.15746188815683126, 0.15695701993536204, 0.09932718225172721, 0.15558174607576802, 0.19559383654268458, 0.16120222338940948, 0.1553759039961733, 0.13016962999245152, 0.11465538904303685, 0.16691033350070938, 0.365530529525131, 0.0664556804986205, 0.2426430454943329, 0.16373802325688303, 0.2017725573386997, 0.18386447452940047, 0.8348119980655611, 0.32370362081564963, 14.483059644699097, 77.38202691078186, 106.09549015760422, 90.19027322530746, 69.36616703867912, 42.24552132189274, 48.200489580631256, 85.08362084627151, 106.7001137137413, 91.04549333453178, 70.9419272840023, 73.66366803646088, 79.81154054403305, 23.171078749001026, 0.17338025820208713, 0.4903867235407233, 0.5699340300634503, 2.1398395020514727, 0.7702012150548398, 0.608076264616102, 2.9202898358926177, 1.9191513815894723, 0.5711040110327303, 0.307247475720942, 0.32690741296391934, 0.2016893625841476, 0.24700818001292646, 0.13337278389371932, 0.14934647362679243, 0.10720073827542365, 0.1833799114683643, 0.17192226456245407, 0.4376867873361334, 0.23096318473108113, 0.09491691773291677, 0.33348566154018044, 0.21834904910065234, 0.4944623610936105, 0.4754068289184943, 0.16608852369245142, 0.21123332233401015, 0.1073634170461446, 0.1117749506374821, 0.20323374221334234, 0.5224623461253941, 0.15884038293734193, 0.34812170430086553, 0.1915898162405938, 0.3665002196794376, 0.1471817772835493, 0.33420103252865374, 0.26325524726416916, 0.13709040940739214, 0.18080425827065483, 0.17715367837809026, 0.11000596001395024, 0.19352579751284793, 0.37106095463968813, 0.46256431960500777, 0.15678757277783006, 0.5725266190711409, 0.4776086920173839, 1.8961722333915532, 8.032220844179392, 6.106674168258905, 0.4763291997369379, 0.31209551088977605, 0.6210089300293475, 0.8504467341117561, 1.7945027514360845, 3.7595009291544557, 3.21496426127851, 0.9195408609230071, 0.5658386810682714, 0.8163281867746264, 24.389086291193962, 60.891242399811745, 56.9744885712862, 63.729055523872375, 88.19381475448608, 91.61502957344055, 72.39641323685646, 48.88127624988556, 59.09311428666115, 78.37207898497581, 92.29944124817848, 43.05363915860653, 4.7712234780192375, 0.18011300708167255, 0.4193787759868428, 0.27350810647476465, 0.16305610828567296, 0.2568598638754338, 0.1745341790956445, 0.1948516146512702, 0.3412995266262442, 0.05758164632425178, 0.2727072994457558, 0.18503884901292622, 0.17100802768254653, 0.1349005542579107, 0.1623518398264423, 0.15883872052654624, 0.14848994615022093, 0.11395558089134283, 0.16186350665520877, 0.15919710363959894, 0.09028052081703208, 0.12560136965475976, 0.08206551006878726, 0.08405444357777014, 0.21127287880517542, 0.17696815630188212, 0.24987156386487186, 0.15155943925492465, 0.11068892883486114, 0.1466637582052499, 0.18615750304888934, 0.18128563009668142, 0.11898634766112082, 0.10019726876635104, 0.18267142761033028, 0.10433446004753932, 0.13610430294647813, 0.14314412284875289, 0.15584786538966, 0.11309070425340906, 0.20969382603652775, 0.1569398763240315], [0.021208639882388525, 0.019812099781120196, 0.02729794487095205, 0.023249720397870988, 0.033970351578318514, 0.0764375073777046, 0.05444142283522524, 0.013896075142838527, 0.05802084560855292, 0.036188029844197445, 0.032937775540631264, 0.02661796133907046, 0.007929487983346917, 0.07239841317641549, 0.00625593987024331, 0.05440614484541584, 0.035960487366537564, 0.0226487477630144, 0.03433206322370097, 0.05301007971866056, 0.07524259766796604, 0.00961602600000333, 0.06171889697725419, 0.013309572532307357, 0.04871756806096528, 0.028889337700093165, 0.0790273430175148, 0.05218714184593409, 0.02725461086811265, 0.03427251329412684, 0.02256474592286395, 0.10392155876616016, 0.03519260942994151, 0.016838080264278688, 0.034795712563209236, 0.06835982363554649, 0.04324405454099178, 0.04191271582385525, 0.0738468999043107, 0.08611796292825602, 0.03308179300802294, 0.03108710970991524, 0.04726119230326731, 0.08772790388320573, 0.11874819247168489, 0.16035066830227152, 0.05867756837687921, 0.7200842793099582, 1.0920736310072243, 31.320041678845882, 62.041638270020485, 74.35723721981049, 64.41422715783119, 40.65955102443695, 28.219753839075565, 43.49226102232933, 80.11078208684921, 82.14002519845963, 68.91530603170395, 61.61737583577633, 79.34627830982208, 43.28423738479614, 6.291994024068117, 0.06727178319124505, 0.032508079457329586, 0.4550305113662034, 0.7925241265911609, 0.3277708572568372, 0.12668297567870468, 0.08445866173133254, 0.10611467936541885, 0.0709589954931289, 0.17804994044126943, 0.014750198060937691, 0.060016636562068015, 0.04981381665857043, 0.05087472789455205, 0.04231830323988106, 0.014101565629971446, 0.026431131227582227, 0.07765928283333778, 0.005068019800091861, 0.1438220450654626, 0.023190652864286676, 0.09318112337496132, 0.03412400583329145, 0.12077507941285148, 0.015392040768347215, 0.08177014271495864, 0.09004124498460442, 0.0979704323981423, 0.28536424215417355, 0.05564980994677171, 0.18478395097190514, 0.056921992072602734, 0.044334380800137296, 0.03093402319791494, 0.07698882662225515, 0.09321182602434419, 0.07882404650445096, 0.028867238397651818, 0.025865290008368902, 0.07922972668893635, 0.0436197630915558, 0.07365829791524448, 0.0227592962255585, 0.1492224310641177, 0.11279020123765804, 0.05756490347266663, 0.8206584700383246, 3.376244707033038, 6.191012067720294, 9.856880083680153, 6.9669218827039, 1.6079708794131875, 0.6064977461937815, 0.6846367532853037, 0.10190510642132722, 0.38842373702209443, 0.5343269126024097, 10.788291804492474, 46.57297991216183, 64.44164648652077, 52.54667356610298, 67.34023734927177, 71.50501906871796, 54.17846940457821, 44.00047615170479, 42.47078463435173, 62.09900759160519, 69.91014584898949, 44.81611378490925, 7.786114225164056, 0.14805832790443674, 0.03439090811298229, 0.11465406802017242, 0.166232559713535, 0.086323129653465, 0.058753786943270825, 0.04571635996398982, 0.03146173286950216, 0.005025657083024271, 0.020127004172536545, 0.06734890717780218, 0.03108010012510931, 0.015759227608214132, 0.04012453697214369, 0.050943001770065166, 0.007203366985777393, 0.04265510098775849, 0.011235733618377708, 0.05793440395791549, 0.02312621032615425, 0.03321241842058953, 0.012452594201022293, 0.030317472883325536, 0.08229356462834403, 0.06584339382243343, 0.05150214696186595, 0.11969762941589579, 0.007773060415274813, 0.03858022784697823, 0.0690845531062223, 0.013295227745402372, 0.07816521232598461, 0.04712105255748611, 0.08499061834299937, 0.041202636348316446, 0.020591495849657804, 0.02542327612900408, 0.03702069727296475, 0.0408261819393374, 0.026544783722783905, 0.05921210766246077, 0.06563452378031798, 0.0285614457243355, 0.005768042710769805, 0.01696305236691842, 0.034520156841608696, 0.044712126546073705, 0.022779334212827962, 0.038271201265160926, 0.011135257955174893, 0.04152773784880992, 0.08700524500454776, 0.07452443620422855, 0.08482421399094164, 0.009675650144345127, 0.026621913275448605, 0.011941344437218504, 0.03712240119057242, 0.04317364328016993, 0.04493878215725999, 0.011232279848627513, 0.024721106092329137, 0.013537841387005756, 0.04137956435442902, 0.04650918890547473, 0.024965476768556982, 0.013485413292073645, 0.061010457648080774, 0.032129023820743896, 0.04851980796956923, 0.07030727108940482, 0.07300290730199777, 0.05321967706549913, 0.028170723526272923, 0.10675973928300664, 0.025905276925186627, 0.04251356971508358, 0.027270186692476273, 0.05332172608177643, 0.02884793699195143, 0.05114631312608253, 0.03764653556572739, 0.05156446139153559, 0.05358129223168362, 0.04043236869620159, 0.020086416116100736, 0.05626536949421279, 0.05242537496087607, 0.14901258138706908, 0.06814224820118397, 0.5485436122398823, 6.918708169832826, 52.00150541961193, 82.03901141881943, 72.63319373130798, 55.6534780561924, 42.000423073768616, 40.37465751171112, 70.9424364566803, 96.10299155116081, 84.73738342523575, 65.8858197927475, 75.13943284749985, 76.41877099871635, 29.90455113351345, 0.8143050328362733, 0.06224599252163898, 0.08671614137711003, 0.1513921146397479, 0.2536416443763301, 0.1370633952319622, 0.03348651582200546, 0.11040702403988689, 0.17417848255718127, 0.0691008877765853, 0.1924858259735629, 0.10312599872122519, 0.059347887290641665, 0.06578206273843534, 0.055231349979294464, 0.05269850757031236, 0.03270360939495731, 0.08043445501243696, 0.02607180558698019, 0.06282896807533689, 0.16440815292298794, 0.029974552417115774, 0.1892040786333382, 0.0704605616920162, 0.08734148985240608, 0.04304364127165172, 0.10882852046051994, 0.07567879496491514, 0.11247471426031552, 0.5589462071657181, 0.1990710210520774, 0.03789331822190434, 0.008096846922853729, 0.05763837609265465, 0.02872924716939451, 0.03467448645096738, 0.13668674044311047, 0.04596639693772886, 0.11496246748720296, 0.010066568083857419, 0.07559018253232352, 0.07105839875293896, 0.015438926875503967, 0.07516185942222364, 0.043373444277676754, 0.10299221175955608, 0.07444567207130603, 0.4944889002945274, 6.669279579073191, 8.419917840510607, 11.74552408978343, 8.566214740276337, 3.8492540130391717, 0.4883829544996843, 0.5085412587504834, 0.26149071694817394, 0.4505660181166604, 1.0170349013060331, 18.106478713452816, 61.15123584866524, 74.93249595165253, 43.723759800195694, 63.68672199547291, 90.06541192531586, 75.19741013646126, 56.85979172587395, 42.332240268588066, 58.98075431585312, 73.1880171597004, 63.056503012776375, 17.574980333447456, 0.4698686260962859, 0.08914959165849723, 0.1275086001260206, 0.2096400351729244, 0.012389839121169643, 0.10878860775846988, 0.07168063020799309, 0.03481688232568558, 0.02501532311725896, 0.012996082859899616, 0.024538033103453927, 0.06847999960882589, 0.07979681657161564, 0.04701780497271102, 0.04024125082651153, 0.03874937443470117, 0.02804627649311442, 0.03170658594171982, 0.07794826771714725, 0.05371500868932344, 0.033081028595915996, 0.041708729113452137, 0.012890136640635319, 0.01029362816552748, 0.043816432225867175, 0.046392118820222095, 0.03860327895381488, 0.017249356242245995, 0.05768002170952968, 0.051498577231541276, 0.019916553355869837, 0.06394066818756983, 0.04398681077873334, 0.025575347754056565, 0.055185184683068655, 0.033418794846511446, 0.04921979423670564, 0.045165534247644246, 0.06313683319604024, 0.055852902369224466, 0.034091674169758335, 0.01847718576755142, 0.019404597624088638, 0.09157723092357628, 0.14872299536364153, 0.15993727720342577, 0.13848545408109203, 0.2021427554427646, 0.16799213248305023, 0.09433762694243342, 0.10651425167452544, 0.2729898795951158, 0.17550989548908547, 0.20616161869838834, 0.09596460760803893, 0.13031770329689607, 0.18287354410858825, 0.16237604868365452, 0.15604074957082048, 0.1670585700776428, 0.17851933400379494, 0.17898832680657506, 0.12446370921679772, 0.2159100549761206, 0.1305003755260259, 0.16019885457353666, 0.1011259552615229, 0.148433186695911, 0.10505035053938627, 0.16763676248956472, 0.21154983347514644, 0.18423523666569963, 0.09834425960434601, 0.12042926828144118, 0.20828260254347697, 0.13439489935990423, 0.09616417111828923, 0.09410246260813437, 0.20834564056713134, 0.0849049151293002, 0.22689818957587704, 0.2069986573769711, 0.166565160616301, 0.21870766970096156, 0.21143913472769782, 0.17397878546034917, 0.1491532035288401, 0.18682343215914443, 0.4889264440862462, 0.2503641421208158, 0.9833036956842989, 2.9803254269063473, 46.978551149368286, 96.01129487156868, 97.96999856829643, 84.8472811281681, 64.97691616415977, 44.802115336060524, 65.06890922784805, 107.16473758220673, 104.7699236869812, 85.58827176690102, 78.58949571847916, 99.23321798443794, 61.14702947437763, 9.14621276780963, 0.20010590145830065, 0.21901894127950072, 1.1567298928275704, 1.789552210830152, 0.6141791527625173, 0.4070202063303441, 0.3714292380027473, 0.5152512830682099, 0.30038323311600834, 0.6997640978079289, 0.27083981840405613, 0.13316453725565225, 0.10299148445483297, 0.16179806407308206, 0.149410045996774, 0.10362468485254794, 0.2126845921156928, 0.2120198355987668, 0.09350490014185198, 0.6372006330639124, 0.15389407257316634, 0.22499072161735967, 0.1597628724994138, 0.21983969723805785, 0.1512254134286195, 0.26354836591053754, 0.2184809881146066, 0.20800321362912655, 1.02034333627671, 0.2744442515540868, 0.4451068688649684, 0.17469837184762582, 0.24773045297479257, 0.1847832533530891, 0.15085683320648968, 0.22924153570784256, 0.19972697569755837, 0.16428166127298027, 0.1578618463827297, 0.2011535468045622, 0.23687808687100187, 0.338377661537379, 0.20175982208456844, 0.231247738993261, 0.22241094207856804, 0.17913650401169434, 2.1545228641480207, 10.001651365309954, 12.801625169813633, 16.846054047346115, 12.016339357942343, 8.119550608098507, 1.717166332527995, 2.14093788061291, 0.5821607052348554, 0.7225884636864066, 0.5609013803768903, 16.315902695059776, 65.39925590157509, 88.2656840980053, 64.4559033215046, 80.97905069589615, 91.19067594408989, 70.14257937669754, 61.5169358253479, 56.31946071982384, 81.22396275401115, 92.92061671614647, 72.19594359397888, 17.17973504215479, 0.4004971735412255, 0.30179292778484523, 0.4203680291539058, 0.21798184927320108, 0.18070461752358824, 0.1870983385015279, 0.19648960878839716, 0.20844885846599936, 0.1361693744547665, 0.10653227102011442, 0.1784561327076517, 0.09168199248961173, 0.10012073849793524, 0.15580017497995868, 0.10568596291705035, 0.14483475009910762, 0.0991801405325532, 0.1690918320673518, 0.2167076856130734, 0.14230470929760486, 0.16358530410798267, 0.14895030035404488, 0.13170554913813248, 0.10490017695701681, 0.22912984248250723, 0.1030364957114216, 0.1733221035101451, 0.1096010442415718, 0.1349589612800628, 0.1382953455322422, 0.13327722495887429, 0.21046570414910093, 0.10808661769260652, 0.15054768417030573, 0.15601814375258982, 0.13118119211867452, 0.08098476493614726, 0.14334465115098283, 0.0982727982045617, 0.17980139411520213, 0.13067194522591308, 0.12044713919749483, 0.12348503907560371], [0.01330464096099604, 0.0807589665055275, 0.08349668249138631, 0.0033218346788999042, 0.033209750399691984, 0.04107581073185429, 0.014929206863598665, 0.005434929262264632, 0.0530156050081132, 0.019540631437848788, 0.009965767731046071, 0.0893901514064055, 0.023068358059390448, 0.05507561028935015, 0.050544976838864386, 0.053343107356340624, 0.008402741641475586, 0.011063885613111779, 0.02895582114433637, 0.04897952763712965, 0.13001965678995475, 0.039935322711244226, 0.03157770828693174, 0.021460519237734843, 0.016893392530619167, 0.01934812760737259, 0.03938108311558608, 0.057429439257248305, 0.0221413729377673, 0.034214900369988754, 0.068892425915692, 0.059244324293104, 0.024169772004825063, 0.06762360571883619, 0.06532501109177247, 0.030166657343215775, 0.04970613845216576, 0.032375591254094616, 0.07123073286493309, 0.04103539336938411, 0.06768898892914876, 0.055202016592375, 0.012632666130230064, 0.05672250648785848, 0.01867471950390609, 0.16101419285405427, 0.11957914553931914, 0.06716371164657176, 0.287082462455146, 0.28147405246272683, 10.424569621682167, 49.34853337705135, 81.21470645070076, 79.59840998053551, 60.00043720006943, 35.729695558547974, 36.07671193778515, 57.51999869942665, 71.31416290998459, 71.73291563987732, 68.94521802663803, 71.3196650147438, 65.32705217599869, 30.1102701947093, 5.134869189932942, 0.13056894997134805, 0.11797393948654644, 0.04442186516826041, 0.21764383069239557, 0.3378119965782389, 0.20708781899884343, 0.3206557687371969, 0.26271680428180844, 0.12047870273818262, 0.05647824342304375, 0.016292338259518147, 0.04183086806733627, 0.05076715358882211, 0.03768953189137392, 0.06858737353468314, 0.07847979388316162, 0.19057322235312313, 0.04919031242025085, 0.08924287962145172, 0.06315480059129186, 0.0660660900757648, 0.09406004886841401, 0.09826595560298301, 0.07339521398534998, 0.12385640977299772, 0.0805293014855124, 0.21815143001731485, 0.12000453716609627, 0.3723248321330175, 0.39155001926701516, 0.10261842908221297, 0.04008696574601345, 0.14734392170794308, 0.12076598810381256, 0.06844284027465619, 0.07369897502940148, 0.0619956327136606, 0.062259800179162994, 0.06340871899737976, 0.08112612922559492, 0.12061312794685364, 0.23598589177709073, 0.08544847150915302, 0.19379536039195955, 0.164681292953901, 0.10242580465273932, 0.039344814358628355, 0.21336632897146046, 0.3910022252239287, 0.2514916128711775, 0.10365185487898998, 0.11958030328969471, 1.0375807550735772, 14.65426990762353, 46.03553295135498, 61.44450791180134, 62.051920518279076, 64.78637158870697, 80.38894236087799, 71.7738926410675, 46.026018261909485, 37.54999168217182, 53.33626739680767, 67.83825382590294, 61.71400845050812, 20.174914821982384, 2.363784285262227, 0.05179559957468882, 0.09666335448855534, 0.018449911840434652, 0.08076269950834103, 0.09100213326746598, 0.011461163758212933, 0.07349840219831094, 0.05685011135938112, 0.021921695370110683, 0.045660435425816104, 0.03510727357934229, 0.07702079834416509, 0.08805896854028106, 0.03670587822853122, 0.030080887336225715, 0.047247807669918984, 0.09808677146793343, 0.052140126790618524, 0.023024267065920867, 0.03141633940686006, 0.028423352450772654, 0.03144989561405964, 0.020328855353000108, 0.022004988459229935, 0.06323873007204384, 0.0342614998226054, 0.028645262027566787, 0.09106500059715472, 0.06852446909761056, 0.029882631861255504, 0.013053308011876652, 0.1412237563636154, 0.05512381649168674, 0.040170516731450334, 0.057607703129178844, 0.12690438801655546, 0.01461624504372594, 0.07646151585504413, 0.10557789137237705, 0.07079460236127488, 0.04678862234868575, 0.021348989284888376, 0.007559395635325927, 0.09806775764445774, 0.011850842311105225, 0.04495733584917616, 0.037057767549413256, 0.04821081478439737, 0.015825857626623474, 0.01840810295107076, 0.03527080210915301, 0.059074624805361964, 0.07169435994001105, 0.05404788418672979, 0.019306396643514745, 0.010264600914524635, 0.041118599256151356, 0.019411421671975404, 0.03841416859359015, 0.05567560328927357, 0.03011096101545263, 0.07031589484540746, 0.02635333003127016, 0.03260251774918288, 0.011511616812640568, 0.027156382057000883, 0.07178848652984016, 0.01609687511518132, 0.026040260599984322, 0.06647692818660289, 0.03954675645218231, 0.02818645334627945, 0.01650011177844135, 0.017000482584990095, 0.0304148166833329, 0.013129843846400036, 0.017048898444045335, 0.02892602948122658, 0.04437333613168448, 0.03323814496980049, 0.029242375494504813, 0.024038914671109524, 0.04284076036128681, 0.015249823936756002, 0.10148116940399632, 0.03519295452861115, 0.014426993675442645, 0.05247249391686637, 0.008146192321873968, 0.08304630275233649, 0.19614550459664315, 0.088447660964448, 0.46350723307114094, 1.225797242950648, 25.988713055849075, 72.60464206337929, 88.85500207543373, 73.34697023034096, 53.00430580973625, 43.19128677248955, 57.034988924860954, 79.06525298953056, 88.91119346022606, 79.75045502185822, 82.45594024658203, 85.31624436378479, 65.66815987229347, 16.17876995354891, 2.3862327681854367, 0.06694936455460265, 0.221530057315249, 0.24985033844131976, 0.21783211355796084, 0.23995436320547014, 0.08476543589495122, 0.18118267937097698, 0.11879286234034225, 0.0694924671552144, 0.05247316927125212, 0.15181533177383244, 0.05841222831804771, 0.12681099615292624, 0.03648592050012667, 0.025204941848642193, 0.05521439932635985, 0.188010111451149, 0.1534571999218315, 0.02533936520194402, 0.0620848908147309, 0.13262544118333608, 0.08585525749367662, 0.07690289334277622, 0.03387707474757917, 0.12758222117554396, 0.058709662553155795, 0.2679658663691953, 0.11113543456303887, 0.4314313136273995, 0.1608893190859817, 0.19061482715187594, 0.22041493590222672, 0.3666531021008268, 0.12753141374560073, 0.18803010490955785, 0.07006755738984793, 0.05491486852406524, 0.0737972799106501, 0.08725260282517411, 0.07816508616087958, 0.3351205831859261, 0.05342364151147194, 0.13044912280747667, 0.08756504699704237, 1.3616266543976963, 0.1299563070642762, 0.06837995810201392, 0.06472837631008588, 0.4070037603378296, 0.16210476402193308, 0.14415192970773205, 0.3304894035682082, 2.369607472792268, 22.928383871912956, 54.93052124977112, 67.43864446878433, 73.77988860011101, 77.29327887296677, 91.42697766423225, 85.51542967557907, 52.773772180080414, 38.71141456067562, 51.895092129707336, 74.37196522951126, 80.29639452695847, 39.5602548122406, 5.459627313539386, 0.1642989384708926, 0.1396620401646942, 0.030350591223395895, 0.0883215329668019, 0.05495630633959081, 0.024468009614793118, 0.0612915943202097, 0.06633540062466636, 0.062455096340272576, 0.029330360812309664, 0.08225518075050786, 0.055829238990554586, 0.08754183261771686, 0.027556334716791753, 0.05736372208048124, 0.028888404449389782, 0.04072178402566351, 0.07035936985630542, 0.024817600133246742, 0.011478956748760538, 0.050630746845854446, 0.044960953819099814, 0.02408333220955683, 0.03616178750235122, 0.03498759484500624, 0.02937163349997718, 0.06624685498536564, 0.05646796838846058, 0.03671432757982984, 0.02457506812788779, 0.02171171952795703, 0.07847104396205395, 0.06460344317019917, 0.0165885182650527, 0.06838847053586505, 0.07121705508325249, 0.07542052757344209, 0.09169320634100586, 0.06019493754138239, 0.05925974612182472, 0.019885397996404208, 0.01960512592631858, 0.017794842206058092, 0.03816984986769967, 0.12194933515274897, 0.2277610549936071, 0.16736074292566627, 0.1831056730588898, 0.14946348062949255, 0.09753914069733582, 0.15402500226628035, 0.09148656274192035, 0.16626655007712543, 0.11236465375986882, 0.09329347711172886, 0.14827844890533015, 0.1440313455532305, 0.16181079932721332, 0.22480801970232278, 0.1349273754749447, 0.10708954228903167, 0.14902806258760393, 0.18776748853269964, 0.1425139355706051, 0.20122471876675263, 0.14920197747414932, 0.14334807987324893, 0.13538593368139118, 0.09631277876906097, 0.11209438584046438, 0.10406028843135573, 0.20905390178086236, 0.09363833829411305, 0.10770437453174964, 0.22197608806891367, 0.1697126979706809, 0.11697895693941973, 0.15303453197702765, 0.14224800921510905, 0.18714580626692623, 0.1453413549461402, 0.24754159123403952, 0.20268663094611838, 0.1564232524833642, 0.18205054686404765, 0.16632277518510818, 0.07946313955471851, 0.17525283037684858, 0.18256859562825412, 0.4026456910651177, 0.43937416397966444, 0.1527551282197237, 0.4244775976985693, 0.4176550341071561, 18.38755153119564, 76.52774155139923, 111.76409438252449, 100.89859262108803, 82.62875497341156, 60.02312198281288, 57.503769770264626, 77.0089553296566, 92.15446382761002, 93.53886634111404, 87.95364484190941, 89.68349441885948, 87.00897753238678, 42.27612107992172, 8.373137600719929, 0.26467607414815575, 0.3514180571073666, 0.5371886340435594, 0.5260796332731843, 0.5455439107026905, 0.4537410446209833, 0.7991610048338771, 0.3231700463220477, 0.33301104325801134, 0.16489376983372495, 0.2566135302186012, 0.2864380110986531, 0.19879746541846544, 0.13602814375190064, 0.2233969297958538, 0.1908403361449018, 0.4986642231233418, 0.5844380892813206, 0.23643175925826654, 0.29828043188899755, 0.4205346858361736, 0.1665758920717053, 0.37929989222902805, 0.35743574670050293, 0.5606738675851375, 0.1572337668039836, 0.9947799111250788, 0.5838524457067251, 0.7087739487178624, 0.7200431940145791, 0.42943196778651327, 0.3176696930313483, 0.42723152961116284, 0.27463792241178453, 0.3509446856332943, 0.2608328772475943, 0.19624551641754806, 0.22082602634327486, 0.24666095880093053, 0.21234222454950213, 0.5356456199660897, 0.383805827004835, 0.34869467199314386, 0.3267569944728166, 2.3507934948429465, 0.2925919590052217, 0.10932140299701132, 0.4601661436026916, 0.8870988548733294, 0.45429807098116726, 0.3831489372532815, 0.5872990388888866, 1.3519307621754706, 19.044361487030983, 60.97967125475407, 78.53264316916466, 81.30523279309273, 84.98380780220032, 93.26322913169861, 88.89540910720825, 62.039339393377304, 52.306784838438034, 70.63960790634155, 93.21617245674133, 87.88688242435455, 37.78710275888443, 3.6117848055437207, 0.20914263295708224, 0.28999530302826315, 0.12256000394700095, 0.22491787240142003, 0.1736694434657693, 0.15096245566383004, 0.21241433161776513, 0.21448677900480106, 0.14900437323376536, 0.1420575741212815, 0.2178144356003031, 0.19147208193317056, 0.24969430931378156, 0.13782985566649586, 0.13549396069720387, 0.21729913278250024, 0.16315715911332518, 0.2478124009212479, 0.10672030155546963, 0.1516838974202983, 0.13380569347646087, 0.13757921755313873, 0.08744538310565986, 0.10642133478540927, 0.12472155358409509, 0.16027755191316828, 0.1445906874141656, 0.16592810105066746, 0.12475827505113557, 0.11153979372465983, 0.13210524019086733, 0.252539673820138, 0.12146425258833915, 0.05131790509040002, 0.14165080297971144, 0.19567268231185153, 0.16653957136441022, 0.15007334790425375, 0.1725390338106081, 0.17160328949103132, 0.13768028322374448, 0.11447857235907577, 0.14566653437213972, 0.22518592129927129], [0.0473674492968712, 0.04123735772736836, 0.030974375622463413, 0.057116449606837705, 0.02741641947068274, 0.040999009579536505, 0.051085312297800556, 0.020944435309502296, 0.0542118357407162, 0.009119659080170095, 0.027829072132590227, 0.028787889823433943, 0.03412950143683702, 0.0046631411350972485, 0.05236033313849475, 0.02062235063931439, 0.057911133917514235, 0.052988141833338886, 0.0030356810884768493, 0.0736401449830737, 0.02266835159389302, 0.02909687187639065, 0.0052442163269006414, 0.017417636372556444, 0.020593772387655918, 0.06682535909931175, 0.027812878470285796, 0.05894211062695831, 0.16292025073198602, 0.017785966119845398, 0.028268931928323582, 0.010845414963114308, 0.023480307536374312, 0.03236400261812378, 0.0827820462291129, 0.0640778912929818, 0.03464886009169277, 0.036517936750897206, 0.02349696689634584, 0.043920080570387654, 0.03680506255477667, 0.06760488875443116, 0.04729891195893288, 0.0240097055939259, 0.02211164806794841, 0.0518720036779996, 0.09735680985613726, 0.22164405119838193, 0.011053606867790222, 0.040536191445426084, 0.824324085842818, 1.5399377862922847, 24.769527576863766, 52.64664240181446, 85.39447456598282, 82.28156760334969, 66.13670513033867, 49.77361276745796, 49.190074279904366, 64.16124433279037, 75.44649437069893, 82.28670492768288, 61.655480191111565, 65.8378055691719, 55.935126543045044, 17.958364561200142, 3.6252353712916374, 0.6588586396537721, 0.2472611633129418, 0.241645049827639, 0.0505122852337081, 0.29946852126158774, 0.21216587541857734, 0.05042797725764103, 0.10235472916974686, 0.07039021351374686, 0.07364696532022208, 0.011161538332089549, 0.01928636422235286, 0.18362375150900334, 0.09146228709141724, 0.07491105061490089, 0.21340008184779435, 0.1308125228388235, 0.09969436723622493, 0.2859506872482598, 0.171826008008793, 0.10151378679438494, 0.05878458607185166, 0.25496804038994014, 0.023922955952002667, 0.15732144413050264, 0.05755493271863088, 0.2662413823418319, 0.31687443726696074, 0.44967989379074425, 0.03814485433395021, 0.38922032865229994, 0.5449905653949827, 0.1537788615678437, 0.13908001827076077, 0.06477163609815761, 0.07441443507559597, 0.10596481748507358, 0.030878981815476436, 0.1850853965152055, 0.07087917008902878, 0.8018215151969343, 1.1763185542076826, 0.271666303742677, 0.12850775354309008, 0.042672942217905074, 0.046010654914425686, 0.15586396999424323, 0.641344073228538, 1.7320873006246984, 12.369531355798244, 34.621473625302315, 68.65120500326157, 64.42386344075203, 58.38185325264931, 47.69171968102455, 59.168487042188644, 54.046734273433685, 51.97184421122074, 54.668358117341995, 61.62161260843277, 60.289924666285515, 32.58816473186016, 3.155664880760014, 0.03567615203792229, 0.04534775376669131, 0.18386285664746538, 0.05717464140616357, 0.07680156792048365, 0.1536397385643795, 0.04639346952899359, 0.06335000769468024, 0.01959725359483855, 0.037138246043468826, 0.016679871077940334, 0.0411100682686083, 0.07483757799491286, 0.04704377643065527, 0.05748295923694968, 0.03622459546022583, 0.05821029735670891, 0.05801032195449807, 0.07856836178689264, 0.031909329554764554, 0.03010467131389305, 0.07391620165435597, 0.01967254633200355, 0.06392658222466707, 0.01663914015807677, 0.046320809560711496, 0.028295745723880827, 0.07978840803843923, 0.0651514450146351, 0.07385968710877933, 0.14136420038994402, 0.052812445792369545, 0.014781706868234323, 0.031045657051436137, 0.05015035094402265, 0.04549894780211616, 0.0034416632342981757, 0.04440579024958424, 0.09223751971148886, 0.02588236311567016, 0.10732691822340712, 0.061463843085221015, 0.038632296927971765, 0.06674502161331475, 0.05300153017742559, 0.054779159399913624, 0.03005907932674745, 0.017024624648911413, 0.02432375094940653, 0.09277761026169173, 0.01282815803278936, 0.08876294014044106, 0.04395234915136825, 0.060923233031644486, 0.055888269416755065, 0.07613987647346221, 0.07828331770724617, 0.030642077144875657, 0.03953425126383081, 0.005848016080562957, 0.03893657376465853, 0.0601633962651249, 0.023793768450559583, 0.019322861189721152, 0.037950188998365775, 0.10902304478804581, 0.010174522740271641, 0.027685956374625675, 0.04272244717867579, 0.034584649474709295, 0.05623930897854734, 0.02233496958069736, 0.012265963541722158, 0.04451693057490047, 0.0752093420305755, 0.017534433718537912, 0.05416004125436302, 0.017005406734824646, 0.036156392088741995, 0.019326614601595793, 0.05328896026185248, 0.06685744214337319, 0.057397330238018185, 0.06414890740416013, 0.04127805710595567, 0.043464461268740706, 0.05385223921621218, 0.10322313100914471, 0.06919673614902422, 0.010926196810032707, 0.06697683886159211, 0.019553689526219387, 0.06252396022318862, 0.23760404088534415, 0.012964346769877011, 0.1769009919371456, 0.8728697465267032, 8.653268069028854, 52.28762246668339, 80.16504317522049, 87.87833288311958, 72.99200087785721, 62.65478476881981, 60.74634097516537, 56.19633212685585, 76.28232032060623, 88.00985142588615, 82.35897704958916, 71.36026203632355, 83.16107600927353, 48.954616114497185, 14.520207401365042, 0.9865666518453509, 0.2700944943353534, 0.03761068612220697, 0.17715749301714823, 0.023973691022547428, 0.25475721107795835, 0.40949900925625116, 0.21536764892516658, 0.07091707899235189, 0.061601381603395566, 0.11886630527442321, 0.056394555140286684, 0.040145524908439256, 0.07485037262085825, 0.05502298088686075, 0.2110076797544025, 0.2965962910093367, 0.10498772811843082, 0.1999499465455301, 0.23570562712848186, 0.11733790408470668, 0.17553625657455996, 0.14681181666674092, 0.3734813357004896, 0.07547878616605885, 0.30632620328105986, 0.019644578496809117, 0.29045602830592543, 0.34745893673971295, 0.03273547350545414, 0.14906758937286213, 0.31185294734314084, 0.3583869425347075, 0.12201097793877125, 0.2064084421726875, 0.05958873647614382, 0.08900894725229591, 0.024834342984831892, 0.08339097097632475, 0.09769131065695547, 0.06536147280712612, 0.252100263023749, 1.5361191099509597, 0.948532473994419, 0.28789745934773237, 0.027179717035323847, 0.00806134907179512, 0.26284958934411407, 0.6779773731250316, 2.6542452117428184, 17.990742623806, 45.974747613072395, 73.2665665447712, 78.59814405441284, 68.87840241193771, 66.45287856459618, 73.46706658601761, 66.36600762605667, 53.56912650167942, 54.56291377544403, 68.60684618353844, 77.42858201265335, 50.62300778925419, 10.835545118898153, 0.22642104799160734, 0.010900358010985656, 0.12043467853800394, 0.04361463485111017, 0.014404106768779457, 0.10310486235539429, 0.017143999102700036, 0.11467710428405553, 0.057279944740002975, 0.01914828764711274, 0.019660230391309597, 0.045418172448989935, 0.04210749619232956, 0.0060392053819668945, 0.04744724130432587, 0.05492458694789093, 0.07010426401393488, 0.05682299699401483, 0.023737092487863265, 0.03793863746977877, 0.022453496130765416, 0.08310013814480044, 0.03141223161946982, 0.052945279094274156, 0.00846553568408126, 0.012291615876165451, 0.031668695592088625, 0.1385543996002525, 0.05554549738008063, 0.034887082074419595, 0.040009363074204884, 0.0245384375739377, 0.01337988916930044, 0.01563569898280548, 0.020958643726771697, 0.043231823947280645, 0.015583431377308443, 0.07311834837310016, 0.05825099302455783, 0.05823261373734567, 0.024637354727019556, 0.0858248517033644, 0.04523559669905808, 0.03823453916993458, 0.01677310709055746, 0.014305331551440759, 0.17755948472768068, 0.11728576078894548, 0.07970875332830474, 0.21745476115029305, 0.230725163128227, 0.29236875066999346, 0.10686357316444628, 0.1407682112767361, 0.12656997627345845, 0.2558106154901907, 0.13964755344204605, 0.1499075224273838, 0.09002517006592825, 0.14335544197820127, 0.25490044557955116, 0.11268535803537816, 0.2575791237177327, 0.1439816810307093, 0.12792613240890205, 0.19164445315254852, 0.19410237204283476, 0.12325936681008898, 0.09016536918352358, 0.1498498723958619, 0.13306028035003692, 0.11802099164924584, 0.16161365521838889, 0.1404191495385021, 0.37718586972914636, 0.23281727742869407, 0.14880264265229926, 0.11018591598258354, 0.1515668904175982, 0.2034980061580427, 0.1858219929272309, 0.18656615924555808, 0.1331944012781605, 0.1367732006474398, 0.10513017594348639, 0.08134963441989385, 0.2006465263548307, 0.28743747621774673, 0.21520075475564227, 0.11579810350667685, 0.14947023417335004, 0.3491062670946121, 0.20183663436910138, 0.2605845843208954, 0.1780328858876601, 0.20433207624591887, 1.0490675386972725, 3.036325159482658, 42.274775952100754, 87.95033901929855, 113.84841173887253, 102.82797709107399, 85.82359313964844, 77.1940129995346, 68.77810299396515, 84.61233213543892, 96.95799887180328, 104.43826228380203, 76.3672685623169, 88.91089707612991, 74.50303539633751, 29.515260122716427, 4.492895537987351, 0.5317021440714598, 0.4092869331361726, 0.18567289545899257, 0.24450837430777028, 1.043188541661948, 1.8125365837477148, 0.6963522371370345, 0.3099241352174431, 0.2584881358779967, 0.11534632852999493, 0.10149961919523776, 0.1259884293540381, 0.2512203133665025, 0.4346567764878273, 0.3666376357432455, 0.7207440782804042, 0.3746590646915138, 0.702709830366075, 0.6867431465070695, 0.3250057634431869, 0.5924065585713834, 0.4341679980279878, 1.359996423125267, 0.16555190639337525, 0.4185280075762421, 0.14166037668474019, 0.5331034970004112, 3.0526934936642647, 1.0784296318888664, 0.32200490415561944, 0.6967956852167845, 0.8260886755306274, 0.27831939049065113, 0.3228084126021713, 0.16570870735449716, 0.19393353344639763, 0.31420125102158636, 0.16470006929012015, 0.2453617550781928, 0.4222855012631044, 1.4353687036782503, 3.5874715726822615, 0.7446538796648383, 0.26248561043757945, 0.4088562203105539, 0.1508013650891371, 0.288448043866083, 0.7284368842374533, 1.9727659109048545, 18.564202152192593, 49.324473068118095, 87.90816128253937, 86.63030505180359, 75.55224269628525, 67.78832450509071, 73.49182605743408, 77.72740557789803, 70.86468502879143, 73.74135866761208, 88.94830226898193, 89.21089857816696, 47.41227127611637, 7.487568994984031, 0.11791083466960117, 0.23904175905045122, 0.4020710609620437, 0.12330362849752419, 0.18624268675921485, 0.1713526068488136, 0.11970007108175196, 0.31417352438438684, 0.18362835282459855, 0.18580247444333509, 0.11365064725396223, 0.10968422415317036, 0.2107419612002559, 0.088993213721551, 0.13633632799610496, 0.16744375956477597, 0.1736800858634524, 0.13575435063103214, 0.133469084976241, 0.14558869792381302, 0.1564949587918818, 0.21408538101240993, 0.12095479789422825, 0.11336978888721205, 0.10976011617458425, 0.0951835565501824, 0.16420052968896925, 0.2175596117740497, 0.1372440785053186, 0.11992347979685292, 0.22477573627838865, 0.18082196591421962, 0.11109434926765971, 0.13253430544864386, 0.13965124933747575, 0.17637446784647182, 0.08119166086544283, 0.14588094083592296, 0.1755184301873669, 0.16387333162128925, 0.1518591630156152, 0.22033151850337163, 0.12025881180306897, 0.14398396684555337, 0.12316351843765005, 0.1769882536609657], [0.042476696107769385, 0.013631395595439244, 0.038285064583760686, 0.10463205384439789, 0.03148678406432737, 0.014055691626708722, 0.05597205788944848, 0.05824102969199885, 0.0639343896182254, 0.02348040958167985, 0.03994056969531812, 0.0012099377363483654, 0.033037453395081684, 0.071859962772578, 0.047798484956729226, 0.07574023737106472, 0.060320479242363945, 0.023855789731896948, 0.03632466294220649, 0.043037930445279926, 0.05316449096426368, 0.061842175127821974, 0.030958404604461975, 0.03129754382825922, 0.041246278342441656, 0.024538925536035094, 0.015214225895761047, 0.027383694468881004, 0.012266714966244763, 0.06633511118707247, 0.045736279207631014, 0.0433173082274152, 0.02147470167983556, 0.024011406967474613, 0.06922058135387488, 0.023816403954697307, 0.06602520516025834, 0.011553697513591032, 0.02038998976786388, 0.022706809686496854, 0.03298745119536761, 0.025391885137651116, 0.058059800940100104, 0.027583326627791394, 0.0430815798608819, 0.137251470296178, 0.05605612837825902, 0.1277702665538527, 0.0679418831714429, 0.08082531450781971, 0.06729657834512182, 0.5631567374803126, 1.0170296765863895, 2.6820620940998197, 16.44399382174015, 51.7555446177721, 82.81327307224274, 83.75081956386566, 71.03145807981491, 68.90440061688423, 54.12019193172455, 66.78773939609528, 88.44795271754265, 72.116809040308, 79.27350461483002, 73.51856142282486, 44.705121740698814, 20.65580751746893, 6.942194234579802, 2.1219201385974884, 0.9971460560336709, 0.28323525795713067, 0.9313917125109583, 0.10340666412957944, 0.266268901177682, 0.09774622958502732, 0.09564805935951881, 0.17922539846040308, 0.08403660976910032, 0.6378840026445687, 1.5890465886332095, 0.575483632273972, 0.6199823319911957, 0.2652143390150741, 0.17665082879830152, 0.9437891410198063, 0.4257329850224778, 0.35052106773946434, 0.10422947583720088, 0.3638417279580608, 0.16551800508750603, 0.04723122066934593, 0.13009105139644817, 0.30827000678982586, 0.3047650511143729, 0.44207795639522374, 0.4151659004855901, 1.751161445863545, 1.5349765587598085, 0.9776482335291803, 0.621281802887097, 0.3278860682621598, 0.25997673568781465, 0.1285887960693799, 0.14771107700653374, 0.9318995196372271, 2.826272905804217, 1.2925823405385017, 0.14381558838067576, 0.11277138779405504, 0.043180964567000046, 0.3362138557713479, 0.6563260755501688, 2.128758584149182, 17.0795876160264, 54.18942041695118, 71.5684300661087, 84.87789988517761, 66.41644611954689, 66.05093613266945, 46.04906402528286, 47.52625375986099, 47.457226663827896, 54.51451577246189, 61.626453548669815, 84.45407062768936, 47.228714525699615, 7.955937562510371, 0.2161256191902794, 0.029046107119938824, 0.2304135204758495, 0.03611158121202607, 0.07443620968842879, 0.03607713071687613, 0.015737889007141348, 0.05129744407895487, 0.07274288844200782, 0.03746937378309667, 0.045189988013589755, 0.06930544594069943, 0.06714543997077271, 0.039381628594128415, 0.042094174641533755, 0.00279868341749534, 0.03663422758108936, 0.022019961288606282, 0.12227308223373257, 0.057971808200818487, 0.006301746616372839, 0.05739606116549112, 0.016684528054611292, 0.018274854046467226, 0.06550309684826061, 0.021978113436489366, 0.017736322006385308, 0.028224855777807534, 0.02527248470869381, 0.04089098256372381, 0.0505982890172163, 0.0682232239341829, 0.04296676219382789, 0.03953623279812746, 0.1217388991790358, 0.046035316481720656, 0.037761987769044936, 0.021391514346760232, 0.039326843252638355, 0.046830045321257785, 0.058155727238045074, 0.033857775197247975, 0.04615970414306503, 0.05926753867242951, 0.03591771368519403, 0.048624268965795636, 0.02629326430906076, 0.040977780445246026, 0.07540074933785945, 0.04583934125548694, 0.024901904398575425, 0.06682089879177511, 0.011997655819868669, 0.05333003442501649, 0.052724300912814215, 0.03749328949197661, 0.019811097881756723, 0.03141375673294533, 0.04008756688563153, 0.028854696101916488, 0.14669924770714715, 0.050233846268383786, 0.038789869722677395, 0.027407189008954447, 0.07740608431049623, 0.028613210524781607, 0.0198470011309837, 0.022361440132954158, 0.10239133931463584, 0.07386753903119825, 0.048279248221660964, 0.05901779484702274, 0.028964149896637537, 0.04851072037126869, 0.055942067701835185, 0.09117498688283376, 0.0256211976375198, 0.07088766025844961, 0.02530369758460438, 0.0160309705461259, 0.024655644956510514, 0.033735272591002285, 0.01753299580741441, 0.033934561506612226, 0.0665846212359611, 0.021485275428858586, 0.036256771272746846, 0.003880160493281437, 0.02359335147048114, 0.05583437465247698, 0.08053891229792498, 0.03627324324043002, 0.009191010085487505, 0.18942838534712791, 0.07425922973197885, 0.05337766917364206, 0.050394918289384805, 0.05165246897377074, 0.1013815806072671, 0.3585510759148747, 2.7344380086287856, 14.976525865495205, 50.36667354404926, 82.0750942826271, 89.43437978625298, 78.72441127896309, 67.38024920225143, 67.76028960943222, 62.51835688948631, 90.17087146639824, 85.10043874382973, 79.27440136671066, 96.20998620986938, 72.58500471711159, 48.89435134828091, 15.696956757456064, 4.398903306573629, 1.6393486456945539, 0.7312562735751271, 0.16531896108062938, 0.5636390740983188, 0.06720020304783247, 0.12293244333704934, 0.11218354004085995, 0.19886791007593274, 0.23093965864973143, 0.07812415671651252, 0.6152814498636872, 2.0889120223000646, 1.7440264974720776, 1.481563774868846, 0.3294737299438566, 0.3760277037508786, 1.3141794316470623, 0.3509806946385652, 0.7880181027576327, 0.49422193493228406, 0.08426420419709757, 0.13099706528009847, 0.1647763472283259, 0.2322670936700888, 0.48176940937992185, 1.4972435147501528, 0.24577017378760502, 1.1256904271431267, 2.2710614232346416, 2.4594158912077546, 1.135805721860379, 0.6724668969400227, 0.2671206492232159, 0.211127788934391, 0.2972953347489238, 0.4340906365541741, 1.3531501404941082, 4.572567762807012, 3.3601423585787416, 0.4339629871537909, 0.2602878143079579, 0.18068450532155111, 0.5230821284931153, 0.6597855524159968, 3.0418125400319695, 21.594248861074448, 68.22906285524368, 77.97110930085182, 80.84237203001976, 76.95328071713448, 73.63467559218407, 62.85291373729706, 49.90923509001732, 49.59418259561062, 56.95480562746525, 68.10110852122307, 93.79289790987968, 62.42340378463268, 16.960002332925797, 0.7587050506845117, 0.1385345694143325, 0.269821205874905, 0.09297188968048431, 0.07740685614407994, 0.03174597542965785, 0.07113028317689896, 0.04969992667611223, 0.04355458768259268, 0.07164395326981321, 0.06611454489757307, 0.021346581015677657, 0.08950350704253651, 0.029104436216584872, 0.007398713241855148, 0.02328475904505467, 0.04277018211723771, 0.028375296533340588, 0.026751167570182588, 0.028563171217683703, 0.03375118423718959, 0.009242194155376637, 0.005635603674818412, 0.06361335879773833, 0.04123514241655357, 0.08900408618501388, 0.03270475601311773, 0.0417787618789589, 0.07720569701632485, 0.04112471826374531, 0.00951789552345872, 0.02555905761255417, 0.03052043728530407, 0.028137185872765258, 0.05586076913459692, 0.013943930680397898, 0.03628886173828505, 0.03721283188497182, 0.03631326726463158, 0.01906223376863636, 0.014737583405803889, 0.05123679948155768, 0.09126597418799065, 0.038682091326336376, 0.027134293886774685, 0.023004180839052424, 0.029408685222733766, 0.00393515549149015, 0.1817596546607092, 0.10370456220698543, 0.17309794522589073, 0.19678862008731812, 0.07466706214472651, 0.14373315061675385, 0.15416549082146958, 0.1719559432240203, 0.21510736289201304, 0.15428277984028682, 0.16007656347937882, 0.18462242995155975, 0.18717731785727665, 0.1306269265478477, 0.11665360681945458, 0.13654718699399382, 0.13417696027318016, 0.11107069702120498, 0.20654297870351002, 0.19813673134194687, 0.167405464744661, 0.1520438984152861, 0.20801771519472823, 0.13503246358595788, 0.13327026361366734, 0.23132317088311538, 0.15269914059899747, 0.20577503397362307, 0.11856632176204585, 0.2522676915396005, 0.18260628188727424, 0.12934367900015786, 0.11717144036083482, 0.21149970882106572, 0.17034662567311898, 0.14236057817470282, 0.13367758394451812, 0.09651093962020241, 0.12178163946373388, 0.09240810977644287, 0.15065997111378238, 0.2059486965299584, 0.12711938819848, 0.15047991124447435, 0.16795391187770292, 0.2947018848499283, 0.2071904283366166, 0.17264378053369, 0.1439147541532293, 0.20385935786180198, 0.11709367812727578, 0.6206231913529336, 1.0216099745593965, 7.514787884429097, 39.27808575332165, 90.53581148386002, 110.9817923605442, 103.84189188480377, 88.60746055841446, 93.30628082156181, 69.99146908521652, 86.71659842133522, 103.97398799657822, 93.41632291674614, 101.60821214318275, 99.52742099761963, 71.49465322494507, 36.26154161989689, 12.110222820192575, 2.8078595688566566, 1.467584918718785, 0.3136308363173157, 2.0124762738123536, 0.9713070269208401, 0.9147394029423594, 0.5219098913948983, 0.3163236746331677, 0.4635416984092444, 0.22127876611193642, 1.2471357104368508, 3.3128626830875874, 2.4027362326160073, 3.234202153980732, 0.9887862671166658, 1.3409169344231486, 2.5136339943856, 0.8878287125844508, 1.8700303486548364, 1.175499341916293, 0.7294019137043506, 0.3266564483055845, 0.611296413699165, 0.3737616597209126, 1.6981151048094034, 1.8214630172587931, 1.4441247400827706, 3.0086118215695024, 4.707802506163716, 2.864052141085267, 1.4581107208505273, 1.219305528793484, 0.3728662437060848, 0.3896437684306875, 0.6254130718298256, 0.8727771858684719, 1.7245355620980263, 5.645376546308398, 4.3985166773200035, 1.0290479566901922, 0.3401285957079381, 0.28085738711524755, 0.5691425444092602, 0.6817592983134091, 3.4602705482393503, 24.285733737051487, 71.7264711856842, 88.41315418481827, 100.42626276612282, 81.78175002336502, 81.26809358596802, 63.94271045923233, 60.312598049640656, 66.20246440172195, 71.51050597429276, 85.59821203351021, 111.44808813929558, 64.25671800971031, 12.97190448269248, 0.2842067589517683, 0.20005769154522568, 0.46053261612541974, 0.26683548639994115, 0.32352123060263693, 0.09892437417875044, 0.1803160586860031, 0.166917146416381, 0.12165608291979879, 0.1475380378542468, 0.10079617451992817, 0.19132338522467762, 0.20342670060927048, 0.20105294126551598, 0.13750856509432197, 0.15030329494038597, 0.12242883676663041, 0.1358517649350688, 0.2714777982328087, 0.14839728159131482, 0.10441625956445932, 0.06247239580261521, 0.2325438999105245, 0.0879608714603819, 0.17982411867706105, 0.13678330869879574, 0.090268765197834, 0.20394284947542474, 0.17681781202554703, 0.1615837318240665, 0.07103885800461285, 0.2505808789283037, 0.14383699191967025, 0.10754861999885179, 0.14436790952458978, 0.12371517164865509, 0.08571874685003422, 0.08950098374043591, 0.14749474095879123, 0.14295395492808893, 0.12841562333051115, 0.14032403589226305, 0.2758905489463359, 0.2938429528148845, 0.09737903717905283, 0.17934752628207207, 0.09596714575309306, 0.17762129078619182], [0.13354414579225704, 0.043719956738641486, 0.0333121519361157, 0.023364282023976557, 0.026764912145154085, 0.06395671342033893, 0.04372250601591077, 0.017452912506996654, 0.06471070577390492, 0.011667697890516138, 0.019789282450801693, 0.12602761475136504, 0.025149894900096115, 0.1326595651335083, 0.05191517440835014, 0.08097114652628079, 0.12140228325733915, 0.04571456396661233, 0.09763852169271559, 0.06913884863024577, 0.01805260679248022, 0.05250501482805703, 0.047326579224318266, 0.0037832482985322713, 0.00831213283163379, 0.0316511512210127, 0.09146535958279856, 0.029595921660074964, 0.07617501716595143, 0.07589812186779454, 0.06570936195203103, 0.019704716578416992, 0.0273425739214872, 0.02374605948716635, 0.014321469552669441, 0.057112193389912136, 0.018118656080332585, 0.02496520959539339, 0.02455304675095249, 0.03450411903031636, 0.10943702218355611, 0.05385879609093536, 0.05068285303423181, 0.030031872192921583, 0.06312605721177533, 0.03557690462912433, 0.18157701211748645, 0.08066536684054881, 0.013162211689632386, 0.08037967709242366, 0.12854664208134636, 0.06646464564255439, 0.049175803433172405, 0.5931593338027596, 1.1253902432508767, 4.391225818544626, 19.72154974937439, 58.80461476743221, 95.6499494612217, 85.71111157536507, 68.86959448456764, 59.53904315829277, 64.13160592317581, 68.09657156467438, 53.51481221616268, 67.64520898461342, 69.09458041191101, 45.3562206029892, 30.376381315290928, 14.74730221554637, 6.1486866138875484, 2.544028563424945, 1.3182119652628899, 0.16702722175978124, 0.18513909832108766, 0.47167275741230696, 0.5958901403937489, 0.7685076340567321, 1.2471585092134774, 0.8021327422466129, 0.6646024470683187, 0.3853664448251948, 0.6789986276999116, 1.110583150293678, 0.594451145734638, 0.39373795967549086, 0.32429451879579574, 0.036441599440877326, 0.18563560995971784, 0.19735191017389297, 0.09716240427223966, 0.04429138818522915, 0.2353362157009542, 0.24721133551793173, 0.045829589435015805, 0.24653115717228502, 0.19829657510854304, 0.18250439985422418, 0.5924717488233, 0.3950992366299033, 0.4732155933743343, 1.2966996571049094, 1.0364189674146473, 1.7007191525772214, 2.023633187636733, 1.5892761200666428, 0.1410342860617675, 0.09615035975002684, 0.13374687085160986, 0.8810686378274113, 3.189437468536198, 9.14582708850503, 34.56994839012623, 58.76585304737091, 75.60711935162544, 55.07885009050369, 93.008543998003, 79.87970888614655, 57.83566676080227, 58.76002795994282, 47.70357884466648, 57.60050117969513, 63.91491875052452, 76.51520982384682, 71.01397901773453, 17.714301757514477, 1.4097485784441233, 0.20940637739840895, 0.03737443454156164, 0.1480560124036856, 0.08738976655877195, 0.0822239437547978, 0.036490785278147087, 0.052516061696223915, 0.05804522515973076, 0.07117613306036219, 0.013568467966251774, 0.010513485703995684, 0.09592908099875785, 0.04323264402046334, 0.012679291558015393, 0.04128244690946303, 0.02568412990513025, 0.006517068241009838, 0.047817877275520004, 0.05748308540205471, 0.008266075146821095, 0.05504911190655548, 0.030101257434580475, 0.03514186137181241, 0.04030884192616213, 0.02842596481059445, 0.06408627014025114, 0.057233259940403514, 0.018759201884677168, 0.07446349103702232, 0.0036226419751983485, 0.02600023100967519, 0.09391529296408407, 0.08245974633609876, 0.012618415039469255, 0.014246083119360264, 0.04197154215944465, 0.028885215069749393, 0.03363557247212157, 0.05018031886720564, 0.009797037673706654, 0.035910707811126485, 0.010456311574671417, 0.04564942195429467, 0.031292612256947905, 0.02274063677759841, 0.0504533475759672, 0.015941076053422876, 0.07183044755947776, 0.029410141687549185, 0.08993854658911005, 0.04825836789677851, 0.04791100196598563, 0.06667727837339044, 0.022447117371484637, 0.02147153085388709, 0.05443649868539069, 0.03891440952429548, 0.02006588088988792, 0.03784156826441176, 0.018873038061428815, 0.09384678531205282, 0.013846328984072898, 0.061417009856086224, 0.0470594171929406, 0.07075063011143357, 0.08995966811198741, 0.09172839898383245, 0.04155475202423986, 0.0704900843265932, 0.00963240148848854, 0.06281720503466204, 0.05002437508665025, 0.021580927132163197, 0.018792385162669234, 0.06332878969260491, 0.06844407966127619, 0.07738125204923563, 0.0585402191063622, 0.06760742689948529, 0.030071348883211613, 0.03430590993957594, 0.06910402706125751, 0.0333609741210239, 0.04188275532214902, 0.12796217110008, 0.07852557697333395, 0.09877176635200158, 0.023178828596428502, 0.005094181897220551, 0.026623794619808905, 0.09813940458116122, 0.01758242469804827, 0.023358185280812904, 0.051967818653793074, 0.022963054725551046, 0.09153714752756059, 0.08385702487430535, 0.021912001066084486, 0.06583385722478852, 0.05369226186303422, 0.05362696771044284, 0.11175966239534318, 0.733471317216754, 2.365913833491504, 14.869998581707478, 50.54105758666992, 88.34924921393394, 95.75451225042343, 87.36502602696419, 64.83684808015823, 60.11851966381073, 79.6622085571289, 78.4049092233181, 80.1525266468525, 91.73970088362694, 89.74897250533104, 76.34475857019424, 51.6673019528389, 23.761969842016697, 8.692003190517426, 3.685444090515375, 2.4364556232467294, 1.2230672081932425, 0.9585280157625675, 0.6982560537289828, 0.48007556120865047, 0.38908220012672246, 2.2165450360625982, 0.9319591883104295, 0.1802533768932335, 0.21477986796526238, 1.2937618209980428, 3.4573280811309814, 1.7553161666728556, 0.6781371426768601, 0.3912571381079033, 0.10911451448919252, 0.17970690387301147, 0.14892834762576967, 0.10186096347752027, 0.09795545585802756, 0.09438998546102084, 0.19913698313757777, 0.022773573291487992, 0.2483540796674788, 0.14506677514873445, 0.23208345664897934, 0.7819693023338914, 0.8617518399842083, 0.7033532427158207, 1.1400478379800916, 0.8624708326533437, 1.6219538915902376, 2.021933253854513, 0.7604746869765222, 0.17048678768333048, 0.012720357372018043, 0.386487859650515, 1.1849735397845507, 4.090846236795187, 12.142704427242279, 35.50001688301563, 68.31106245517731, 89.32238459587097, 72.73562863469124, 107.0396938920021, 98.54635924100876, 68.90078321099281, 69.4170007109642, 46.64794608950615, 54.872661754488945, 68.19479629397392, 89.0973074734211, 85.60960382223129, 34.5923937857151, 5.0953085627406836, 0.16255205642664805, 0.07611902212374844, 0.07615781418280676, 0.13220354507211596, 0.11080353127908893, 0.037508785535464995, 0.04653716787288431, 0.0799037006800063, 0.041678809429868124, 0.03885299309331458, 0.03883882178342901, 0.03874978261592332, 0.08370461000595242, 0.008555622207495617, 0.03713688791322056, 0.03140280634397641, 0.041683206654852256, 0.06265468953642994, 0.05121765578223858, 0.07217829217552207, 0.05258401644823607, 0.04671853021136485, 0.10328451404348016, 0.05926838472078089, 0.08419108038651757, 0.0649729956057854, 0.012974402870895574, 0.031243003395502456, 0.03115264691587072, 0.05132165664690547, 0.07007800682913512, 0.03608393992180936, 0.13887062872527167, 0.051663263511727564, 0.010099160426761955, 0.025577436899766326, 0.06134502524218988, 0.034820199725800194, 0.044846644523204304, 0.04415718933159951, 0.018708351781242527, 0.05295502720400691, 0.009074344470718643, 0.046653328827233054, 0.022487748101411853, 0.03415473816858139, 0.041914096218533814, 0.07179345891927369, 0.094883669517003, 0.24283790378831327, 0.07148258067900315, 0.15339215809945017, 0.17345205356832594, 0.12523062236141413, 0.1742644381010905, 0.16405607806518674, 0.14256750378990546, 0.2621374244336039, 0.17738447146257386, 0.14444533037021756, 0.3294304775772616, 0.15310604532714933, 0.1526614691829309, 0.08576444088248536, 0.25826376979239285, 0.16735409328248352, 0.285898944712244, 0.143223948252853, 0.3275081963511184, 0.1758614063146524, 0.16987369948765263, 0.14528558996971697, 0.06166219689475838, 0.09129456913797185, 0.09967482648789883, 0.18394579907180741, 0.13159548863768578, 0.25264597905334085, 0.24803976528346539, 0.14822710712905973, 0.07882308171247132, 0.2012708061374724, 0.16508472443092614, 0.11336033392581157, 0.24904837366193533, 0.131475260714069, 0.2533515536924824, 0.1858984786667861, 0.16181283281184733, 0.24402590410318226, 0.1626089494675398, 0.1571544905891642, 0.11423001225921325, 0.09844138447078876, 0.16258328600088134, 0.25613003585021943, 0.21098998695379123, 0.0872319785412401, 0.2835463365772739, 0.2555851510260254, 0.1406022225273773, 0.16143576242029667, 0.6752483476884663, 1.2654588022269309, 7.668831618502736, 39.78953070938587, 91.69260621070862, 119.04020994901657, 109.0490260720253, 89.07601341605186, 78.63843709230423, 88.25710415840149, 82.12847381830215, 72.81518876552582, 89.72774684429169, 100.18884390592575, 89.91275891661644, 78.78051146864891, 47.541304752230644, 20.018872395157814, 11.071501057595015, 3.418611721135676, 1.1994029092602432, 1.0655692219734192, 0.7240648032166064, 0.6716691178735346, 1.918270660098642, 3.2656003441661596, 2.5409020436927676, 1.742478080559522, 0.6268275459297001, 2.5828819535672665, 2.9364798171445727, 2.834533187560737, 2.6213976368308067, 1.2853432539850473, 0.28962660406250507, 0.4523746616905555, 0.33429391973186284, 0.290413458715193, 0.3541040082927793, 0.6910388160031289, 0.47982919786591083, 0.16323548537911847, 0.5295943259261549, 0.3792566992342472, 0.3444606007542461, 1.1150179873220623, 1.296517385635525, 1.317631071433425, 1.4577728952281177, 0.8482915966305882, 3.2076285174116492, 2.455348684452474, 2.0174057967960835, 0.5577293818350881, 0.237850047997199, 0.36158886447083205, 1.719912753906101, 5.487964767962694, 15.07436016574502, 45.42269803583622, 80.84364876151085, 98.29748019576073, 73.85367304086685, 115.87111920118332, 96.45650178194046, 78.63535925745964, 80.86007907986641, 67.37089410424232, 73.75221088528633, 84.7316001355648, 109.31197956204414, 93.18593367934227, 27.880148962140083, 2.5704872561618686, 0.30007550900336355, 0.1593562646303326, 0.2203847304917872, 0.20547842723317444, 0.2038228590390645, 0.08999485333333723, 0.18796341551933438, 0.11629598811850883, 0.20631619321648031, 0.23260742775164545, 0.09795377118280157, 0.1337885795510374, 0.17358308716211468, 0.06415097799617797, 0.13526892667869106, 0.05390355130657554, 0.09763132286025211, 0.120241586555494, 0.14660762215498835, 0.15673744812374935, 0.1260008677490987, 0.1378483499865979, 0.24381666298722848, 0.15902182320132852, 0.19636957382317632, 0.30404294142499566, 0.12489202490542084, 0.06256131993723102, 0.12172308401204646, 0.17473714164225385, 0.1021254352235701, 0.17044107138644904, 0.33900474663823843, 0.09160905421595089, 0.10719905360019766, 0.12943940120749176, 0.2476248750463128, 0.20847238454734907, 0.1514362427406013, 0.09198757921694778, 0.07148728589527309, 0.135519253090024, 0.10624955728417262, 0.18616737361298874, 0.0998256383172702, 0.14945009228540584, 0.16961771791102365, 0.21824216499226168, 0.24043987621553242], [0.03642622956249397, 0.018884572891693097, 0.0590652551909443, 0.020340427290648222, 0.017667461834207643, 0.04760909629112575, 0.10624259593896568, 0.044448515691328794, 0.0417775670211995, 0.11835670215077698, 0.033410349205951206, 0.06771092681447044, 0.03921026669559069, 0.03416520245082211, 0.019268161195213906, 0.02155893358576577, 0.051737764006247744, 0.043279057936160825, 0.01442076705643558, 0.0406459179794183, 0.07431878708302975, 0.09101136558456346, 0.10265735472785309, 0.092237356439, 0.053570638701785356, 0.0972611247561872, 0.08148234526743181, 0.057670062087709084, 0.04967059699993115, 0.010602457150525879, 0.019570027907320764, 0.0296603400784079, 0.051255119396955706, 0.055435859903809614, 0.033298399939667434, 0.027555421875149477, 0.014254601119318977, 0.060019504962838255, 0.02050921208137879, 0.08219586830819026, 0.06168528510897886, 0.010726812342909398, 0.008971852948889136, 0.08282067501568235, 0.01179152337499545, 0.04482852127694059, 0.015432169620908098, 0.07401420967653394, 0.08120018072077073, 0.0393796173739247, 0.01801573689590441, 0.037461863248609006, 0.1055861811619252, 0.05558127631957177, 0.11196213512448594, 0.3224988479632884, 1.0466682049445808, 1.9259879272431135, 23.415401838719845, 63.32999333739281, 92.79771611094475, 84.68161001801491, 68.33262249827385, 77.61604875326157, 63.46134468913078, 56.79796904325485, 57.42213495075703, 53.19450840353966, 51.816474348306656, 31.886273995041847, 16.005795635282993, 7.690950706601143, 2.8976323641836643, 1.8259749189019203, 2.3571206303313375, 1.331986344885081, 2.083481876179576, 3.0281156999990344, 2.0728531340137124, 1.4337790827266872, 2.3116888431832194, 2.0984746841713786, 1.1457234271802008, 2.228172649629414, 3.6265251645818353, 4.696968337520957, 6.510127019137144, 8.951306026428938, 9.594316072762012, 6.840027691796422, 4.156033638864756, 3.9370587514713407, 4.933541743084788, 6.813688455149531, 11.71759083867073, 14.142266381531954, 13.237059004604816, 10.283337850123644, 8.208548482507467, 4.916688222438097, 3.6790153104811907, 3.3345991792157292, 4.519663201645017, 3.659924897365272, 5.075077498331666, 9.085048399865627, 13.55337018147111, 21.701522804796696, 34.160771146416664, 49.49012517929077, 74.12873268127441, 81.42650708556175, 83.4340837597847, 65.0680960714817, 60.718127489089966, 60.70819102227688, 50.601652935147285, 53.76152537763119, 58.328428119421005, 61.3480044901371, 58.30575093626976, 86.21345221996307, 63.91514673829079, 30.26310369372368, 4.641755875200033, 0.04890921285550576, 0.12224002697621472, 0.12377322986139916, 0.07449511394952424, 0.03890003041306045, 0.10546034260187298, 0.09577522636391222, 0.022985697651165538, 0.012259889062988805, 0.07426944168400951, 0.014878427264193306, 0.08299755107145756, 0.011830007442767965, 0.023745604921714403, 0.025597107523935847, 0.07361186173511669, 0.10795389200211503, 0.030144006996124517, 0.040843893293640576, 0.035105039714835584, 0.021172677261347417, 0.0448882085038349, 0.08812508647679351, 0.029329512908589095, 0.06825190052040853, 0.048382896566181444, 0.02878281353332568, 0.028744123519572895, 0.01027126168992254, 0.012016841264994582, 0.010691591869544936, 0.06635936457314529, 0.005144082515471382, 0.04631471281754784, 0.0036668974007625366, 0.09169347351416945, 0.038964337509241886, 0.0593529264733661, 0.029156674136174843, 0.04215506043692585, 0.03696102859976236, 0.04178220915491693, 0.05255659780232236, 0.017321882623946294, 0.026406146826047916, 0.05017991810746025, 0.05873250585864298, 0.031978494007489644, 0.05287352825689595, 0.01977019441255834, 0.0358085882908199, 0.0250076122028986, 0.010577368848316837, 0.032234713071375154, 0.06600432854611427, 0.016052047540142667, 0.09292462229495868, 0.05921434894844424, 0.041667172554298304, 0.03346051096741576, 0.03619086855906062, 0.07941650299471803, 0.034861455715144984, 0.04935184828354977, 0.06049339222954586, 0.11624657592619769, 0.047908181804814376, 0.029759108801954426, 0.006642850676144008, 0.04248392833687831, 0.04022618151793722, 0.01446750751711079, 0.02930993134214077, 0.017029001464834437, 0.01415465701938956, 0.02764772278169403, 0.03900975323631428, 0.04715929171652533, 0.031766929969307967, 0.06717580123222433, 0.06444639730034396, 0.02340859380637994, 0.03401250556635205, 0.09656721667852253, 0.0714506980148144, 0.02548044747527456, 0.034734581859083846, 0.022179890402185265, 0.039635758512304164, 0.048175254778470844, 0.1166129668126814, 0.0934943393804133, 0.05753179626481142, 0.017505504802102223, 0.06339460334856994, 0.046559436013922095, 0.09923234320012853, 0.02944807471067179, 0.05025461156037636, 0.05532943221624009, 0.04415462892211508, 0.03309049840027001, 0.11718221634509973, 0.04902891756501049, 0.07879540702560917, 0.3359044692479074, 0.6642453256063163, 2.414687303826213, 10.594919230788946, 51.13899730145931, 85.71135476231575, 96.27503871917725, 79.07801270484924, 66.78178131580353, 67.85513252019882, 48.967410027980804, 67.3969455063343, 82.02527895569801, 80.80258056521416, 82.64652281999588, 67.62671917676926, 45.63027709722519, 26.41897726804018, 13.045500833541155, 3.3212652197107673, 2.709888475947082, 4.289204617962241, 4.617604371160269, 7.89174048230052, 5.5471480172127485, 4.681071415543556, 4.535723989829421, 5.6119506899267435, 3.695118371397257, 5.312052257359028, 8.610268626362085, 12.691869959235191, 12.998061329126358, 11.567597687244415, 11.153362914919853, 6.305732661858201, 3.688533562235534, 4.219003859907389, 6.8580809980630875, 9.246257599443197, 13.877404443919659, 18.500061593949795, 21.36989749968052, 13.953393716365099, 14.002919308841228, 9.569779839366674, 8.773275129497051, 7.519615525379777, 8.878260646015406, 6.948085818439722, 9.318627566099167, 12.42664609104395, 19.92096494883299, 29.214939437806606, 40.4626227915287, 55.978037640452385, 76.9604167342186, 93.80914583802223, 107.58165881037712, 82.5715072453022, 74.87432107329369, 66.29885762929916, 75.94251975417137, 70.73456481099129, 65.79122766852379, 67.61316910386086, 68.46616253256798, 89.55168709158897, 82.356788367033, 50.14166101813316, 12.633291352540255, 0.25944942492060363, 0.16480238176882267, 0.32100077834911644, 0.03955500913434662, 0.040168794948840514, 0.1807185698999092, 0.050786390056600794, 0.011120339859189698, 0.03138475731248036, 0.033397357910871506, 0.02348863628867548, 0.057411297457292676, 0.04679274497902952, 0.018413780380797107, 0.09657293863710947, 0.030978450013208203, 0.06106570683186874, 0.05645754863508046, 0.016208336419367697, 0.012617928005056456, 0.019193128209735733, 0.09403138712514192, 0.021280457513057627, 0.03697686974192038, 0.09077355178305879, 0.0303690261716838, 0.020758239734277595, 0.029326876428967807, 0.03245078194595408, 0.026794553523359355, 0.04180742733296938, 0.08912021003197879, 0.05174006466404535, 0.03740308886335697, 0.05364220771298278, 0.05255113930616062, 0.04914684854156803, 0.05130102494149469, 0.047842345884419046, 0.04364950094895903, 0.05060853065515403, 0.020126978197367862, 0.04223260373692028, 0.04541746369795874, 0.03220125334337354, 0.06282545029534958, 0.03288340951257851, 0.03352695915964432, 0.015196989515970927, 0.009265810222132131, 0.04020907130325213, 0.14341180067276582, 0.17497399065177888, 0.11993044114205986, 0.24333842302439734, 0.1650446781422943, 0.3065698058344424, 0.26373221073299646, 0.07360723815509118, 0.09746310766786337, 0.25324426882434636, 0.23492711421567947, 0.16540601500310004, 0.1131139780045487, 0.15964387654094025, 0.2179214681382291, 0.2257354074390605, 0.19217042805394158, 0.13579145801486447, 0.10117419486050494, 0.15574084769468755, 0.1459289132617414, 0.14988081995397806, 0.243219516123645, 0.18992411030922085, 0.10007554170442745, 0.1461651685531251, 0.14224507031030953, 0.1106855075340718, 0.15333369170548394, 0.1293071059626527, 0.11473580074380152, 0.11656235976261087, 0.14106938964687288, 0.17354578681988642, 0.19574321602704003, 0.11701973795425147, 0.08687157678650692, 0.13885686930734664, 0.1627931950497441, 0.22594536101678386, 0.13334376591956243, 0.12802025157725438, 0.09795880294404924, 0.23096915159840137, 0.1587207190459594, 0.19127986568491906, 0.1184748594823759, 0.1821563474368304, 0.11841012936201878, 0.1969353575259447, 0.1588623653515242, 0.19022733700694516, 0.11944780766498297, 0.14264290599385276, 0.2452883863588795, 0.6197063124272972, 1.195177179761231, 4.132951777428389, 37.13353402912617, 93.96372154355049, 117.06041738390923, 100.84303200244904, 83.02406296133995, 95.67120552062988, 78.8188362121582, 78.6604455113411, 80.1906006038189, 77.92744964361191, 92.07051873207092, 83.19788843393326, 77.31211066246033, 56.9683974981308, 36.9945564866066, 23.282496370375156, 14.82207840308547, 12.236191760748625, 11.013629212975502, 16.36298406869173, 11.464067492634058, 8.663035444915295, 6.517873853445053, 7.000091727823019, 4.172290116548538, 3.855235129594803, 7.545653628185391, 13.536465838551521, 17.271201834082603, 21.739167384803295, 20.31049344688654, 14.758715853095055, 9.535255841910839, 9.292695857584476, 11.970552764832973, 15.48569854348898, 22.297059148550034, 23.792571499943733, 22.541057355701923, 15.646525863558054, 14.290551524609327, 12.753980476409197, 11.334488745778799, 8.895491771399975, 10.527230612933636, 7.632118938490748, 9.993770588189363, 13.049091640859842, 20.512921884655952, 32.31544956564903, 47.777895256876945, 70.95351666212082, 99.04543206095695, 106.01209983229637, 110.04224717617035, 80.92810302972794, 78.12143683433533, 71.53119206428528, 69.55354258418083, 77.93583199381828, 80.19458279013634, 80.91772958636284, 79.3908879160881, 112.6732487976551, 94.34447631239891, 44.86483857035637, 7.311297403648496, 0.15392968081869185, 0.2528232929762453, 0.5637533648405224, 0.2135903388261795, 0.23841623245971277, 0.2591128757921979, 0.18484899279428646, 0.1603882061317563, 0.11999551265034825, 0.15334874246036634, 0.09809712442802265, 0.09971577077521943, 0.17566396534675732, 0.13773235230473801, 0.1324410768575035, 0.14737936668097973, 0.2702451206278056, 0.128865557780955, 0.15496454638196155, 0.13817165920045227, 0.16748687834478915, 0.1852120811236091, 0.11781502340454608, 0.09024017766932957, 0.2725536748766899, 0.1957081421278417, 0.1304222719045356, 0.15207692398689687, 0.10469136628671549, 0.08011387690203264, 0.12600775487953797, 0.13577404723037034, 0.11526822490850464, 0.1582373582641594, 0.15626694133970886, 0.2664485899731517, 0.20692227553809062, 0.15378361131297424, 0.1840232199174352, 0.1610917621292174, 0.22269790089922026, 0.12400906212860718, 0.09527311151032336, 0.17924720275914297, 0.13286613451782614, 0.16621753864455968, 0.10822444193763658, 0.1351621761568822, 0.14255410060286522, 0.09740477486047894, 0.11467671094578691], [0.037308294340618886, 0.04478533570363652, 0.04933410353260115, 0.017263991394429468, 0.052815006201853976, 0.03309131476271432, 0.05888943298486993, 0.04145977938605938, 0.11516027952893637, 0.0838825770188123, 0.05539211771974806, 0.054440958992927335, 0.0523537280241726, 0.022748087940271944, 0.0565482576348586, 0.01714814770821249, 0.023078375197655987, 0.02896017012972152, 0.03647919664217625, 0.0158441330131609, 0.03542613732861355, 0.1033993465534877, 0.021704131067963317, 0.048213263871730305, 0.06963428415474482, 0.13726377510465682, 0.05166406503121834, 0.012793252044502879, 0.03987317155406345, 0.017899789309012704, 0.012329795663390541, 0.040560634079156443, 0.040999710909090936, 0.01932792078150669, 0.01193550466268789, 0.027509479223226663, 0.06274116458371282, 0.04755897163704503, 0.06195059177116491, 0.03598477785999421, 0.04964104467944708, 0.10273458261508495, 0.04375009906652849, 0.027292543891235255, 0.0555286840244662, 0.09663015080150217, 0.008697641442267923, 0.05463858920847997, 0.013609573670692043, 0.015608096655341797, 0.0743575271917507, 0.05213888369326014, 0.030546983907697722, 0.08738265678402968, 0.0829886452993378, 0.05619563358777668, 0.23341334075666964, 0.31712020689155906, 0.3709406970301643, 4.360034242272377, 32.24140293896198, 82.85581558942795, 85.00822529196739, 85.97589656710625, 77.34403654932976, 71.96917176246643, 58.18745568394661, 61.71514078974724, 41.70931689441204, 33.00595611333847, 39.58626061677933, 27.00052846223116, 12.671475503593683, 2.8420624835416675, 4.9967185780406, 13.244832437485456, 4.696998735889792, 4.298613863065839, 4.951649196445942, 1.3468073308467865, 4.521329887211323, 4.814578201621771, 14.850254841148853, 14.282766692340374, 20.888638123869896, 29.454613476991653, 42.64765754342079, 38.80008280277252, 36.12555831670761, 31.898931115865707, 26.572939306497574, 18.798896558582783, 25.87554182857275, 38.37527319788933, 57.45980992913246, 56.63135938346386, 44.78876665234566, 51.364594995975494, 37.08589978516102, 34.533800929784775, 23.218336813151836, 15.883414652198553, 19.371531531214714, 23.184062652289867, 35.71782499551773, 47.20620833337307, 53.385493755340576, 57.69172288477421, 71.36508017778397, 76.9409541785717, 69.19594377279282, 59.889771938323975, 58.108138740062714, 45.320289731025696, 53.879577443003654, 60.97184747457504, 57.63310723006725, 67.16235369443893, 71.08303651213646, 66.65952667593956, 76.92900761961937, 46.07678733766079, 9.143695402890444, 0.03994999126007315, 0.42513873253483325, 0.043307367159286514, 0.09800078623811714, 0.033698710685712285, 0.046144619991537184, 0.03165528869431, 0.04623290958988946, 0.009634646485210396, 0.0694661951274611, 0.019738241244340315, 0.06689745132462122, 0.035758422818616964, 0.04795371998625342, 0.03466023721557576, 0.01651173752179602, 0.025667149566288572, 0.0428405414277222, 0.011562233139557065, 0.03802958766755182, 0.04670642578275874, 0.03505327862512786, 0.019627290166681632, 0.026188543561147526, 0.0513371860870393, 0.03960305948567111, 0.028281811901251785, 0.002276005507155787, 0.09268841153243557, 0.10170785841182806, 0.023110860856832005, 0.05494740427820943, 0.0663094328774605, 0.05090584985737223, 0.029215730537544005, 0.05388775469327811, 0.06092143332352862, 0.02181380936235655, 0.020194869866827503, 0.04255288869899232, 0.025360382824146654, 0.02596198257379001, 0.04585299677273724, 0.044913467500009574, 0.056222016937681474, 0.03026720351044787, 0.006371491799654905, 0.11268757705693133, 0.03120893881714437, 0.027968948415946215, 0.005379319209168898, 0.027934807767451275, 0.08527119469363242, 0.031382742381538264, 0.07926817736006342, 0.103533222572878, 0.07960077084135264, 0.03109517685516039, 0.0291043638571864, 0.07998535176739097, 0.021240726637188345, 0.012696397134277504, 0.08218924835091457, 0.013372890716709662, 0.05242962375632487, 0.10228006169199944, 0.046861946539138444, 0.0020522860177152324, 0.020192942138237413, 0.03321989184769336, 0.030375703645404428, 0.03557688607543241, 0.047272584270103835, 0.04823175819183234, 0.0492999647394754, 0.006488120770882233, 0.0657130652689375, 0.05615051843051333, 0.01307956148593803, 0.06319276144495234, 0.07063391254632734, 0.030182743394107092, 0.11597059346968308, 0.004759864314110018, 0.03462301108811516, 0.03443190435064025, 0.006490966907222173, 0.014013267682457808, 0.006609926222154172, 0.05989804136333987, 0.06918672457686625, 0.024569544693804346, 0.0285338248431799, 0.024896809554775245, 0.08607460666098632, 0.08833161133225076, 0.019987460000265855, 0.03972224469180219, 0.02975291557959281, 0.06239408437977545, 0.007721417141510756, 0.06896883744047955, 0.018450353418302257, 0.016026823795982637, 0.020107361378904898, 0.024681523645995185, 0.08876555992173962, 0.055779845351935364, 0.19820725021418184, 0.6654854840599, 0.38756189576815814, 1.5943372109904885, 16.026565320789814, 62.95711934566498, 96.84039518237114, 91.37455567717552, 86.14840731024742, 72.93593108654022, 64.66486170887947, 54.022278785705566, 62.35642857849598, 67.06586927175522, 68.57138648629189, 74.1750217974186, 59.91804242134094, 42.28289231657982, 28.55832327157259, 18.725355304777622, 12.446402180939913, 15.035288762301207, 11.975492499768734, 16.48902900516987, 13.769414238631725, 22.40819178521633, 26.693981811404228, 36.26510202884674, 42.54641577601433, 50.31382218003273, 62.45727896690369, 72.90017500519753, 76.78310304880142, 65.6634633243084, 59.29108366370201, 53.603172674775124, 51.946396976709366, 53.463089391589165, 59.61618281900883, 76.88619151711464, 78.34619477391243, 62.0404527336359, 84.28244143724442, 67.87055969238281, 67.4357870221138, 55.772164687514305, 42.153687849640846, 43.14472787082195, 45.77960908412933, 56.74628421664238, 73.70440185070038, 75.61440736055374, 82.88299173116684, 93.04331973195076, 98.92745599150658, 98.32368358969688, 86.91652089357376, 72.08801418542862, 59.774702712893486, 67.36637234687805, 66.26003131270409, 51.85804411768913, 63.05165447294712, 78.60049992799759, 76.86457827687263, 87.13417321443558, 65.48763155937195, 19.24741879105568, 0.5387638870161027, 0.2655663841869682, 0.20789071888430044, 0.18508646520785987, 0.023811893552192487, 0.163406535575632, 0.018732022581389174, 0.07036920331302099, 0.03915080953447614, 0.07023191341431811, 0.01302656657571788, 0.0653459396562539, 0.11362694305717014, 0.05585475773841608, 0.07316619463381357, 0.07167634059442207, 0.036815029598074034, 0.08097219295450486, 0.05191590913455002, 0.025114518575719558, 0.10242800883133896, 0.1054113831196446, 0.09738045468111522, 0.028932862805959303, 0.06575052888365462, 0.055973512498894706, 0.021249944111332297, 0.042020282708108425, 0.11216235914616846, 0.039843355771154165, 0.0324121791345533, 0.02213651743659284, 0.07460490727680735, 0.007225492727229721, 0.0391591178777162, 0.027607450138020795, 0.05064439494162798, 0.07953341351822019, 0.03162236331263557, 0.060592958761844784, 0.040565524832345545, 0.0525004172232002, 0.010650380409060745, 0.060359783383319154, 0.021495721157407388, 0.0528660808049608, 0.015561256932414835, 0.03439570980845019, 0.009022683570947265, 0.014250457152229501, 0.09144713985733688, 0.04960783357091714, 0.07508411203161813, 0.16255069087492302, 0.15930802503135055, 0.19529047625837848, 0.1525344283436425, 0.18819603428710252, 0.09538988102576695, 0.30161401082295924, 0.1516113302204758, 0.2832443715305999, 0.20143758156336844, 0.11525604626513086, 0.2974819700466469, 0.2243783013545908, 0.1259408428450115, 0.137279182090424, 0.07706152740865946, 0.1483706830185838, 0.22539312893059105, 0.1594985937117599, 0.11649717693217099, 0.20024882425786927, 0.2388030249858275, 0.07212519893073477, 0.1250017885467969, 0.22393362130969763, 0.32382370030973107, 0.20093136263312772, 0.1659585439483635, 0.1268113820697181, 0.27995633077807724, 0.11357041366863996, 0.17378214601194486, 0.12528251332696527, 0.1080480260134209, 0.11359768759575672, 0.09994036692660302, 0.18658716202480718, 0.21443282486870885, 0.12932236451888457, 0.1631621760316193, 0.0942997403035406, 0.26352984190452844, 0.3195888869231567, 0.216953128692694, 0.1258408310241066, 0.18464597087586299, 0.18190375005360693, 0.1505186513531953, 0.14282309944974259, 0.1683116122148931, 0.17304189823335037, 0.20700532186310738, 0.09243634107406251, 0.16400369728216901, 0.24543969542719424, 0.3247069154167548, 0.5291517684236169, 0.30366408987902105, 0.6046066945418715, 7.393616661429405, 50.977836549282074, 116.83946684002876, 112.91091084480286, 107.57127776741982, 98.19977223873138, 87.0228011906147, 79.44922998547554, 84.65315714478493, 73.27105030417442, 68.62520679831505, 86.87894091010094, 78.76885369420052, 72.85028368234634, 59.41589556634426, 47.01001726090908, 53.405602276325226, 42.22982436418533, 36.969736218452454, 38.94134022295475, 37.39060923457146, 50.1273737847805, 58.69310975074768, 57.16377541422844, 73.3557553589344, 69.61750835180283, 77.71931201219559, 89.6867698431015, 82.07803532481194, 72.89876148104668, 74.29994389414787, 68.35111230611801, 54.48646567761898, 69.54944640398026, 83.47591951489449, 98.6285488307476, 93.54841902852058, 77.39251434803009, 88.01131054759026, 84.26661908626556, 83.83325234055519, 70.20888581871986, 63.9286208152771, 60.78531168401241, 65.071781873703, 81.75090327858925, 97.91790336370468, 97.67228454351425, 89.53007385134697, 98.30201715230942, 100.70520579814911, 85.95821231603622, 74.81860086321831, 76.16628974676132, 64.90922659635544, 79.46205049753189, 83.9930185675621, 76.24544709920883, 82.22213879227638, 90.78124031424522, 94.04269650578499, 105.73596104979515, 63.53059597313404, 13.74040374532342, 0.24242817889899015, 0.6817674322519451, 0.3352229401934892, 0.21413926093373448, 0.11988297337666154, 0.23032637749565765, 0.18134589248802513, 0.15028223278932273, 0.18116296792868525, 0.22883028199430555, 0.1333620079094544, 0.2104667283128947, 0.1731012700474821, 0.1890109569649212, 0.14404381363419816, 0.19877493381500244, 0.3401948546525091, 0.10287081124261022, 0.10593313520075753, 0.06451612949604169, 0.32069792272523046, 0.21737475763075054, 0.15584458509692922, 0.14985333080403507, 0.18866529426304623, 0.16707090457202867, 0.11920329226995818, 0.12513221357949078, 0.12621392350411043, 0.20703788730315864, 0.16306240169797093, 0.11796852922998369, 0.20550800923956558, 0.1830276139662601, 0.13658205309184268, 0.18634498439496383, 0.15582331514451653, 0.21687158150598407, 0.07530697897891514, 0.1481054988107644, 0.1330621654051356, 0.10311240999726579, 0.14173966774251312, 0.11212663957849145, 0.2752572001190856, 0.12142757565015927, 0.13596843054983765, 0.21563562360825017, 0.10720104255597107, 0.10085421046824194, 0.19025265908567235, 0.10220166121143848, 0.2514211385278031], [0.04764014774991665, 0.05906607155338861, 0.07022439545835368, 0.07594342256197706, 0.010617532025207765, 0.038892441953066736, 0.05171499491552822, 0.04080972110386938, 0.056720595457591116, 0.03607279657444451, 0.028772065379598644, 0.10127969115274027, 0.046197145493351854, 0.050650369230424985, 0.02385703097388614, 0.022375323860615026, 0.102375412825495, 0.056191640833276324, 0.05340425290341955, 0.055051008093869314, 0.04838075547013432, 0.06068926726584323, 0.04931547191517893, 0.06153911541332491, 0.031784578241058625, 0.023432247908203863, 0.0179287608989398, 0.0715984076668974, 0.038889503048267215, 0.03079001315200003, 0.03468200440693181, 0.04554979605018161, 0.0286435773523408, 0.02203589705459308, 0.03424927293963265, 0.017126784987340216, 0.0509120319475187, 0.040382221777690575, 0.026731688049039803, 0.02463682965753833, 0.03836997741018422, 0.04657204510294832, 0.03912716099875979, 0.022991927980910987, 0.02983260368637275, 0.10437592383823358, 0.03808331173786428, 0.07304684986593202, 0.08275358486571349, 0.061456280600395985, 0.016028222744353116, 0.1261714578140527, 0.0025946714276869898, 0.033135491103166714, 0.14200053265085444, 0.10000447364291176, 0.16626790078589693, 0.09706861907034181, 0.07463888279744424, 0.2591597498394549, 0.10396657002274878, 3.704086127690971, 41.489179506897926, 78.00653859972954, 89.0738171339035, 92.69563838839531, 73.68254542350769, 75.40944635868073, 69.79643315076828, 58.43280091881752, 44.85152788460255, 42.08930030465126, 29.291680119931698, 16.358367316424847, 9.082623180001974, 17.583649568259716, 15.814499650150537, 12.805122882127762, 15.868448205292225, 15.498001333326101, 20.07103029638529, 26.46409224718809, 23.328226916491985, 25.089700296521187, 32.71173030138016, 38.89333739876747, 27.53030553460121, 18.022208735346794, 23.596680611371994, 20.113434121012688, 19.758582562208176, 17.06122700124979, 32.811706736683846, 38.00781771540642, 49.50879357755184, 43.44407960772514, 49.02519352734089, 38.53875182569027, 58.40039625763893, 37.858109548687935, 42.44888260960579, 42.490984350442886, 37.406754568219185, 48.91408368945122, 48.02331268787384, 47.36237235367298, 51.63237042725086, 55.83825834095478, 61.41654521226883, 46.22112639248371, 38.926483020186424, 50.65068170428276, 57.33663193881512, 71.67477875947952, 70.18325999379158, 71.514662951231, 77.86044403910637, 83.71743455529213, 80.74038550257683, 50.69150671362877, 11.146930810064077, 0.38098338001873344, 0.056191321709775366, 0.07884084130637348, 0.0242198929481674, 0.08863002149155363, 0.060361690702848136, 0.0415750163665507, 0.018879305498558097, 0.02675113417353714, 0.10116540783201344, 0.05262106074951589, 0.05476942242239602, 0.1030746049946174, 0.014197807340678992, 0.07590298293507658, 0.019558383610274177, 0.0385293981526047, 0.08090102099231444, 0.12644485017517582, 0.05915864705457352, 0.011213022044103127, 0.03279540193034336, 0.028901753830723464, 0.05404778399679344, 0.011190462610102259, 0.07884184320573695, 0.026694484186009504, 0.13826251291902736, 0.04392575428937562, 0.04582416433549952, 0.03486604960926343, 0.0505673934094375, 0.034686268045334145, 0.060045576610718854, 0.01755108194629429, 0.0975771683442872, 0.12697095866315067, 0.017747114688972943, 0.0630702922353521, 0.07139092544093728, 0.038219135894905776, 0.022221166800591163, 0.058962475159205496, 0.016057196189649403, 0.016013921558624133, 0.034051865368383005, 0.043668807920766994, 0.020983015856472775, 0.045446759977494366, 0.0794770622451324, 0.05945088996668346, 0.06661039602477103, 0.02387752538197674, 0.07982625014847144, 0.14374294696608558, 0.04161133707384579, 0.04837235435843468, 0.035047330311499536, 0.0824693200411275, 0.020930078462697566, 0.02242127764475299, 0.13167651632102206, 0.05765802816313226, 0.030868699359416496, 0.053301877342164516, 0.032222159643424675, 0.011359299351170193, 0.08012815582333133, 0.06338537845294923, 0.021798754896735772, 0.008350284788321005, 0.02262816058646422, 0.03529583103954792, 0.010683943110052496, 0.06114000694651622, 0.04330933385062963, 0.020930935643264093, 0.016952708683675155, 0.008978533205663553, 0.049295344870188273, 0.017815835708461236, 0.015148052298172843, 0.1361173202167265, 0.07202534296084195, 0.03659678994154092, 0.008828790996631142, 0.015075262454047333, 0.028545057248265948, 0.02617413476400543, 0.06442947633331642, 0.02297002534760395, 0.043300539400661364, 0.010291026937920833, 0.04383254054118879, 0.01421759578079218, 0.030133423970255535, 0.023840020949137397, 0.020508909656200558, 0.06815473854658194, 0.08764748476096429, 0.10728202571044676, 0.04802630945050623, 0.03492752541205846, 0.03480341605609283, 0.026036972885776777, 0.024258850135083776, 0.0264246968072257, 0.018693302881729323, 0.024741303641349077, 0.09630277461837977, 0.024624131510790903, 0.17344102525385097, 0.07176440383773297, 0.1493657546234317, 0.44026557239703834, 1.677786789368838, 26.213641986250877, 67.76684045791626, 94.2827220261097, 93.13043385744095, 95.51958605647087, 75.31857803463936, 70.56987404823303, 54.4596429169178, 41.48021578788757, 57.25544549524784, 65.9640271961689, 68.34821686148643, 54.88343417644501, 47.08072766661644, 59.52134370803833, 44.309213384985924, 48.03234860301018, 49.56993609666824, 45.986667573451996, 56.297832280397415, 61.46065704524517, 50.9138859808445, 55.82513764500618, 61.83031640946865, 65.88570579886436, 63.93524765968323, 47.662370055913925, 57.48424641788006, 56.404652148485184, 55.33228889107704, 41.245103403925896, 69.43078637123108, 69.90759998559952, 77.87261098623276, 59.53425541520119, 54.00794975459576, 46.71424113214016, 71.52233093976974, 63.16631332039833, 65.80506652593613, 72.7119255065918, 70.6357853114605, 73.00290629267693, 84.70721304416656, 85.04594966769218, 73.32639053463936, 72.65569612383842, 83.50407600402832, 63.670736253261566, 42.40486957132816, 49.83372174203396, 59.96571846306324, 65.76151326298714, 67.55671173334122, 78.90035703778267, 91.66390255093575, 94.42094340920448, 94.69010576605797, 70.49281418323517, 25.840087831020355, 2.5906449370086193, 0.1927026963676326, 0.15277267259079963, 0.12123102525947616, 0.060222374740988016, 0.05109404737595469, 0.04654301970731467, 0.053479521520785056, 0.035714654659386724, 0.03931848666979931, 0.02907231235440122, 0.042549419158603996, 0.08391735405893996, 0.10970271105179563, 0.04622043408744503, 0.005255199184830417, 0.03849220913252793, 0.052962949630455114, 0.020272433575883042, 0.09673349486547522, 0.06385780739947222, 0.07069822706398554, 0.06966034838114865, 0.035156808226020075, 0.030327855529321823, 0.1029893322265707, 0.03770852345041931, 0.10862548369914293, 0.07157741230912507, 0.04206862620776519, 0.006083978687456693, 0.034195003390777856, 0.09992451465222985, 0.036288123301346786, 0.044810405452153645, 0.029576024680864066, 0.07263790423166938, 0.06319517342490144, 0.014299275626399321, 0.03356123525009025, 0.03211811796063557, 0.016006719015422277, 0.009785334004845936, 0.05137342515808996, 0.03098740959103452, 0.02708980769966729, 0.040241792594315484, 0.042282995564164594, 0.05472101584018674, 0.0030067867282923544, 0.013782116511720233, 0.07330044914851896, 0.024247673391073477, 0.05662400493747555, 0.033826976068667136, 0.14818470081081614, 0.17265118716750294, 0.10777107134344988, 0.14055338921025395, 0.08912263685488142, 0.13159525115042925, 0.20870953041594476, 0.24409057485172525, 0.1775091077433899, 0.12907978612929583, 0.11295431235339493, 0.2353936282452196, 0.20816601114347577, 0.23385874810628593, 0.18938609777251258, 0.1629287557443604, 0.2614343730965629, 0.13907145388657227, 0.1683279246208258, 0.1548224696307443, 0.12811564723961055, 0.17148182960227132, 0.16783926490461454, 0.13015584088861942, 0.1443395297974348, 0.15765121002914384, 0.09485727874562144, 0.17164142103865743, 0.19115867296932265, 0.07399485446512699, 0.11701502531650476, 0.0819316934212111, 0.23342778295045719, 0.21418991993414238, 0.127370634872932, 0.09436317908694036, 0.09420391419553198, 0.109421422239393, 0.09060377808054909, 0.05271843052469194, 0.18927743250969797, 0.12144127569627017, 0.1222794275963679, 0.11916710514924489, 0.15329458052292466, 0.38379240897484124, 0.26416604057885706, 0.2197031123796478, 0.16035938111599535, 0.18133045581635088, 0.12300255402806215, 0.3180345328291878, 0.17444938130211085, 0.11431483973865397, 0.21891894430154935, 0.16872098087333143, 0.27114012103993446, 0.21415830444311723, 0.241722782375291, 0.47407057718373835, 0.4803899646503851, 13.613852486014366, 60.78483670949936, 106.92639917135239, 120.10169059038162, 121.15773752331734, 95.20693123340607, 94.38242867588997, 90.91193050146103, 83.03308367729187, 87.55216598510742, 91.39399543404579, 88.1936551630497, 68.4311892092228, 57.896349504590034, 59.79052126407623, 63.97685542702675, 67.82529652118683, 66.6150614619255, 67.66967967152596, 64.36527818441391, 65.21590813994408, 66.60420924425125, 53.90561744570732, 68.65524038672447, 73.81533309817314, 61.57032296061516, 56.58211022615433, 70.77722132205963, 72.10346415638924, 65.77971428632736, 55.1617768406868, 78.55186253786087, 80.47546371817589, 88.20363342761993, 79.57144662737846, 78.39806199073792, 70.02238422632217, 103.81739839911461, 72.91142240166664, 84.3067829310894, 83.42779889702797, 83.83217319846153, 90.32420083880424, 85.72670593857765, 78.01286146044731, 76.2883847951889, 77.15605303645134, 82.52986907958984, 68.9670592546463, 59.70930442214012, 71.43774747848511, 78.66436690092087, 90.04188358783722, 86.51946499943733, 91.79510951042175, 105.66478326916695, 117.26008147001266, 111.94428831338882, 68.44904065132141, 17.932402454316616, 1.2521425355225801, 0.2937982458388433, 0.22188633272890002, 0.19760158349527046, 0.27299644018057734, 0.12420507817296311, 0.2158514698385261, 0.1531853957567364, 0.2070596322300844, 0.2750200987793505, 0.1347951841307804, 0.19775976485107094, 0.1717154131620191, 0.1863091831910424, 0.22305867372779176, 0.07592713242047466, 0.15763065253850073, 0.15331236238125712, 0.24710397643502802, 0.13144649507012218, 0.10933819037745707, 0.1307253650156781, 0.14878998161293566, 0.1685147825628519, 0.1909756296663545, 0.37581123411655426, 0.09536422498058528, 0.17241791530977935, 0.1491282376809977, 0.1346171132172458, 0.21642048930516466, 0.1478655030950904, 0.308742843917571, 0.10204406615230255, 0.2052875913796015, 0.21681516343960539, 0.19713462417712435, 0.21949649846646935, 0.10433503892272711, 0.10519860938074999, 0.13896577205741778, 0.14924986084224656, 0.17686973267700523, 0.203246432938613, 0.07471965815057047, 0.09636907809181139, 0.14538775401888415, 0.15299497550586239, 0.1810300789657049, 0.15173893509199843, 0.13261421991046518, 0.13466136006172746, 0.12823425728129223, 0.192650597600732, 0.20423276204383], [0.015803995811438654, 0.09774100486538373, 0.06080048180592712, 0.08440317134954967, 0.047592620612704195, 0.026972722771461122, 0.02542136138799833, 0.03689118137117475, 0.04775683562911581, 0.15953927824739367, 0.010835425655386643, 0.08108331472612917, 0.1598987152101472, 0.13144829106749967, 0.02973295922856778, 0.03445642490987666, 0.02091441729135113, 0.08123653111397289, 0.043043047553510405, 0.04775902125402354, 0.08440139761660248, 0.05813817544549238, 0.022159058316901792, 0.06287628741119988, 0.05215915174630936, 0.02292377841513371, 0.03361102222697809, 0.02095060070132604, 0.025567172997398302, 0.08568257457227446, 0.019160290030413307, 0.01969061020645313, 0.012619685967365513, 0.02653581486811163, 0.045039083415758796, 0.04617193102603778, 0.03886019934725482, 0.03422565037908498, 0.02270524375489913, 0.0923993821197655, 0.022321733376884367, 0.07037001225398853, 0.019677739510370884, 0.06409493842511438, 0.07204682813608088, 0.06971297407289967, 0.07434233542880975, 0.027415716285759117, 0.05481140200572554, 0.04129828063014429, 0.01396990863213432, 0.016040937589423265, 0.05875366819964256, 0.012919708442495903, 0.10105284629389644, 0.1118992232659366, 0.07412785475025885, 0.1541579802869819, 0.10634352060151286, 0.025880980865622405, 0.01881402247818187, 0.22215659322682768, 0.16351528989616781, 4.3142984714359045, 37.4551297724247, 80.27152866125107, 100.64942479133606, 90.57917475700378, 82.01474592089653, 68.75003769993782, 62.184510603547096, 56.71459771692753, 57.444933727383614, 43.667146638035774, 31.53597269207239, 26.354498527944088, 14.502812884747982, 14.732533358037472, 36.29668973386288, 20.583231411874294, 18.45742218196392, 33.340288773179054, 41.86436377465725, 39.38074104487896, 41.79651461541653, 41.050496846437454, 39.523761570453644, 45.35666897892952, 44.34641718864441, 32.406006306409836, 35.83050794899464, 53.74015152454376, 44.326578453183174, 44.83406022191048, 44.742800518870354, 65.97576856613159, 88.30900177359581, 48.92035335302353, 43.676596730947495, 39.99971263110638, 57.13914513587952, 50.55932320654392, 46.17044471204281, 47.36163519322872, 44.24488663673401, 52.516149803996086, 49.7427774220705, 49.08292002975941, 56.47924594581127, 64.484553784132, 75.44917702674866, 77.60343343019485, 88.91159623861313, 81.97608679533005, 84.17983934283257, 52.00476944446564, 42.91571415960789, 40.883700996637344, 12.293777670711279, 0.7991151104215533, 0.14458639780059457, 0.033560864176251926, 0.03796873155806679, 0.016653374550514854, 0.07077826769091189, 0.08581655449233949, 0.05501623476448003, 0.03567751387890894, 0.030755102525290567, 0.06488038299721666, 0.03363943164004013, 0.05585286897257902, 0.04556857980787754, 0.025422745493415277, 0.027783326149801724, 0.069261763128452, 0.09987240104237571, 0.0537896242167335, 0.15975699468981475, 0.04722049292468, 0.059688280744012445, 0.04623243832611479, 0.14079841668717563, 0.10460075005539693, 0.07864969375077635, 0.039227247034432366, 0.06152904075861443, 0.020323675162217114, 0.04110986046725884, 0.11609894048888236, 0.004793207617694861, 0.06367736903484911, 0.03746902497368865, 0.017071010734071024, 0.02484042302967282, 0.08108278037980199, 0.03915144407073967, 0.05874251372006256, 0.08893791629816405, 0.04944528096530121, 0.06314271842711605, 0.04914966870273929, 0.027517642847669777, 0.060618009956669994, 0.07747708557872102, 0.007966568464325974, 0.003008159469573002, 0.0163144579710206, 0.04502385825617239, 0.0688679276208859, 0.059380901730037294, 0.05845986306667328, 0.03785976572544314, 0.030059313103265595, 0.04777731519425288, 0.03128230382571928, 0.03192164178472012, 0.06508857026346959, 0.07921023789094761, 0.07455489394487813, 0.016519244345545303, 0.03862935060169548, 0.02858037976693595, 0.027306488846079446, 0.04499682181631215, 0.1255930872866884, 0.025789644751057494, 0.1454453298356384, 0.06370934075675905, 0.07414087202050723, 0.049539756364538334, 0.057995812967419624, 0.07953717620694079, 0.03669928053568583, 0.07994569881702773, 0.028763193004124332, 0.07143063776311465, 0.0270188286958728, 0.09901918354444206, 0.020534129689622205, 0.020192901320115197, 0.04065808177983854, 0.08749302156502381, 0.034019285085378215, 0.04789155027538072, 0.056664670919417404, 0.042002241098089144, 0.02029598006629385, 0.026866174484894145, 0.012770589637511875, 0.04647024099540431, 0.007726267076577642, 0.030778519139857963, 0.051174811596865766, 0.021434980080812238, 0.06912528959219344, 0.058958538065780886, 0.0773871447017882, 0.04368351357697975, 0.054833566246088594, 0.06934109871508554, 0.04949347974616103, 0.022106491996964905, 0.020735459511342924, 0.05339468661986757, 0.04305502581701148, 0.05087149213068187, 0.050880527778645046, 0.08885490708053112, 0.04589610070979688, 0.08376434547244571, 0.057556676765671, 0.13264809153042734, 0.15568785835057497, 0.05352570537070278, 0.01593408131157048, 0.06977169279707596, 0.22813848161604255, 1.8976191245019436, 20.440625064074993, 62.67799772322178, 97.06513032317162, 103.32453444600105, 99.4467893242836, 91.77323028445244, 82.62902095913887, 71.08884260058403, 60.1496209949255, 50.57335965335369, 34.91759933531284, 32.27284625172615, 32.00511261820793, 42.811892330646515, 40.97865790128708, 60.78618943691254, 57.85287223756313, 39.21409718692303, 44.63980324566364, 50.953244268894196, 37.242094203829765, 39.91363205015659, 41.60446912050247, 32.08697162568569, 45.49091957509518, 48.86401377618313, 38.26332740485668, 40.77195659279823, 49.42536525428295, 54.114306047558784, 64.38894331455231, 64.40066948533058, 86.853436678648, 117.01947838068008, 56.94720983505249, 63.11499327421188, 45.39229966700077, 67.21916824579239, 61.12151004374027, 60.747085735201836, 66.18670284748077, 56.96630381047726, 50.48216074705124, 56.92563459277153, 47.582707330584526, 53.71743254363537, 57.57655866444111, 72.23228484392166, 70.14514803886414, 85.6308750808239, 90.2005098760128, 93.91029641032219, 76.66734606027603, 68.46610933542252, 62.861649468541145, 25.99850133061409, 2.494873688556254, 0.1761560537852347, 0.18359238834818825, 0.08964386201114394, 0.0202622401775443, 0.007004720491750049, 0.014621535628975835, 0.08300412649987265, 0.022523072475451045, 0.10142552317120135, 0.03994905244326219, 0.02542448211897863, 0.022422075453505386, 0.067144445492886, 0.06436968149500899, 0.021516037450055592, 0.034755169035634026, 0.04452248183952179, 0.026108100319106597, 0.022676240623695776, 0.03377396446012426, 0.039099059576983564, 0.06855300467577763, 0.12061657151207328, 0.01859823561972007, 0.040144111117115244, 0.030680895179102663, 0.042453054993529804, 0.032520896347705275, 0.05045596735726576, 0.014705882567795925, 0.08663932167110033, 0.030027619686734397, 0.06025583446898963, 0.10386721129179932, 0.07496113816159777, 0.031735666998429224, 0.10143287785467692, 0.015730782943137456, 0.06400000289431773, 0.02444812376779737, 0.04109324007004034, 0.0223909108171938, 0.0450861133140279, 0.004704258435594966, 0.10253642176394351, 0.038726189741282724, 0.06734967158990912, 0.05221896884904709, 0.05042499382398091, 0.050671724529820494, 0.044123915140517056, 0.03781624618568458, 0.024797096448310185, 0.022506424247694667, 0.05244454834610224, 0.06108318812039215, 0.06330380158033222, 0.19533381768269464, 0.1367191129247658, 0.23067537986207753, 0.1441113045439124, 0.15474222862394527, 0.13439699221635237, 0.18902761075878516, 0.17808507371228188, 0.2799427940044552, 0.11805285947048105, 0.20564270904287696, 0.2271756637492217, 0.15448508929694071, 0.10251010520732962, 0.10360168569604866, 0.2614819892914966, 0.15684413927374408, 0.13710054714465514, 0.09321409699623473, 0.14542425284162164, 0.19630987546406686, 0.19859108899254352, 0.11883177314302884, 0.19870165415341035, 0.17964843747904524, 0.15505477669648826, 0.10713836076320149, 0.14388445968506858, 0.17893116659251973, 0.13800932181766257, 0.12978654820472002, 0.23369462956907228, 0.12364699796307832, 0.10378821709309705, 0.16131704847794026, 0.15552322030998766, 0.20441188680706546, 0.09372584492666647, 0.25258675566874444, 0.16381603782065213, 0.17397569812601432, 0.11458325971034355, 0.15735898195998743, 0.24620781827252358, 0.1335279966588132, 0.1556990944663994, 0.1066010829526931, 0.12139262049458921, 0.1719079856411554, 0.1527948776492849, 0.10148204513825476, 0.14518263924401253, 0.2199506780016236, 0.23479879688238725, 0.20065552118467167, 0.23266959004104137, 0.15332653740188107, 0.21852143516298383, 0.13747798861004412, 0.10821748059242964, 0.4789546807296574, 0.3907653613714501, 9.486410412937403, 50.360647067427635, 102.16947242617607, 130.65288841724396, 126.88511699438095, 118.74746605753899, 104.9541985988617, 91.4876452088356, 86.94276988506317, 90.96255138516426, 77.77522221207619, 78.17961171269417, 78.53129804134369, 77.32261329889297, 66.1519955098629, 92.78576195240021, 89.51970040798187, 69.36527788639069, 85.98755434155464, 94.47984024882317, 86.29744291305542, 86.25811502337456, 91.83235511183739, 78.17287087440491, 97.92183995246887, 94.26503777503967, 78.51436614990234, 81.44289180636406, 99.45640280842781, 93.90975683927536, 85.97809284925461, 89.10430669784546, 104.92712125182152, 131.22056275606155, 81.43466144800186, 84.04954433441162, 77.6323726773262, 100.75784057378769, 90.54331228137016, 89.5723807811737, 90.68193644285202, 82.14551210403442, 81.57839253544807, 87.3285023868084, 76.78433418273926, 81.25885248184204, 89.02938231825829, 95.07213726639748, 93.26419427990913, 106.80120348930359, 112.11130455136299, 117.60403901338577, 92.72601395845413, 74.52636614441872, 54.27974157035351, 16.354573220014572, 0.8040092478040606, 0.26941688382066786, 0.29530721018090844, 0.206778684805613, 0.09863441708148457, 0.16050445614382625, 0.20759675418958068, 0.21818680077558383, 0.11076657232479192, 0.2106432555592619, 0.12707954971119761, 0.26720498688519, 0.110710384324193, 0.1300601483671926, 0.18036469904473051, 0.10133592368219979, 0.22897403599927202, 0.13585026579676196, 0.13241575477877632, 0.3061239531962201, 0.15806151379365474, 0.09361256350530311, 0.1786634442396462, 0.36255864368285984, 0.3315271931933239, 0.2589587465627119, 0.11106299352832139, 0.11302899467409588, 0.10925988637609407, 0.1875078704324551, 0.14559931063558906, 0.1800680477754213, 0.26392784086056054, 0.1677289669169113, 0.20552993228193372, 0.10931432290817611, 0.12221425218740478, 0.19417631963733584, 0.16581202915403992, 0.1761089570936747, 0.12825282581616193, 0.25369454466272146, 0.12924397888127714, 0.12237174334586598, 0.09585679581505246, 0.175484899955336, 0.08954780583735555, 0.11210533994017169, 0.08761688601225615, 0.1232461491599679, 0.16429818148026243, 0.11809784104116261, 0.1130508583446499, 0.20343188080005348, 0.14169249683618546, 0.1315132883610204, 0.2168780381907709], [0.03944535681512207, 0.012575131131598027, 0.015653777700208593, 0.053036348035675474, 0.07262129496666603, 0.08342683897353709, 0.020562357276503462, 0.05127658601850271, 0.03163162531564012, 0.06989131958107464, 0.17089495406253263, 0.07400257280096412, 0.12187060812721029, 0.052075300191063434, 0.061119319580029696, 0.03625277851824649, 0.03289391090220306, 0.08463049860438332, 0.03466613357886672, 0.031725822409498505, 0.022812949791841675, 0.014345252602652181, 0.05309446933097206, 0.0375464309763629, 0.05819188096211292, 0.08440765392151661, 0.06521620482089929, 0.07586563064251095, 0.05102064154925756, 0.08522984222508967, 0.06587070485693403, 0.005773192751803435, 0.040816311375238, 0.03394387545995414, 0.02521782553230878, 0.037191595329204574, 0.03357070134370588, 0.02639720209117513, 0.009460164783376968, 0.013321152819116833, 0.07414346211589873, 0.039460088446503505, 0.04292217025067657, 0.013444697215163615, 0.03941937793570105, 0.05082834366476163, 0.02864552920073038, 0.07981683971593156, 0.009401560164405964, 0.12579416477819905, 0.12229181404109113, 0.0230248793377541, 0.04487242302275263, 0.04727510015072767, 0.06710589834256098, 0.028497094099293463, 0.04502553550992161, 0.06024027905368712, 0.07911204433185048, 0.08810164203168824, 0.11104103337856941, 0.05279975877783727, 0.03268974236561917, 0.5008269601967186, 0.3777456271927804, 2.1691245306283236, 11.582404542714357, 33.97015817463398, 74.67157915234566, 90.57591453194618, 89.06345888972282, 79.13276016712189, 58.885584622621536, 51.41928166151047, 47.38214649260044, 49.89091247320175, 64.2943587899208, 48.46519097685814, 53.53611007332802, 46.56022399663925, 45.066155567765236, 51.27878040075302, 50.58445505797863, 52.49950289726257, 53.29231135547161, 45.08227810263634, 50.036007687449455, 49.13446046411991, 46.45538002252579, 40.76881796121597, 47.01448202133179, 46.43608085811138, 53.567465990781784, 50.70922516286373, 46.47939473390579, 49.15144555270672, 49.38374608755112, 55.515260472893715, 60.81991642713547, 52.40162394940853, 49.839326441287994, 50.11000871658325, 49.77585844695568, 43.57077240943909, 50.505369901657104, 57.32101857662201, 65.2884690463543, 74.5602223277092, 79.39446732401848, 80.99586099386215, 93.85361105203629, 101.94342255592346, 83.45572739839554, 52.906886637210846, 36.229638531804085, 8.432803899049759, 1.508936199825257, 0.2410996751859784, 0.08914120538975112, 0.07611479188199155, 0.03326073594507761, 0.0027678661990648834, 0.026955165412800852, 0.06628608491155319, 0.03509040456265211, 0.09972740022931248, 0.032725439668865874, 0.04099366611626465, 0.06004420734825544, 0.06057790058548562, 0.10485572973266244, 0.03933925196179189, 0.03792359042563476, 0.04989209097402636, 0.04384649662824813, 0.06494972185464576, 0.050117915379814804, 0.019996992887172382, 0.026761939843709115, 0.09194608574034646, 0.010282519142492674, 0.07118335415725596, 0.07898679206846282, 0.07669201208045706, 0.08636498678242788, 0.044289911311352625, 0.03414806997170672, 0.032838394545251504, 0.05020667624194175, 0.047693882952444255, 0.11825290537672117, 0.12469593464629725, 0.03533473442075774, 0.07466750001185574, 0.028884532293886878, 0.02661108348547714, 0.14258614653954282, 0.04717422001704108, 0.07056173868477345, 0.07413633007672615, 0.05752412245783489, 0.0933021231321618, 0.025238199341401923, 0.031812178713153116, 0.07666789228096604, 0.03412732694414444, 0.034516861705924384, 0.04083568885107525, 0.026266793756803963, 0.12627611547941342, 0.011655640773824416, 0.16005493729608133, 0.01775545457348926, 0.010069627587654395, 0.021863197434868198, 0.07043344361591153, 0.06299422951997258, 0.015070747413119534, 0.016036722190619912, 0.05587310733972117, 0.04042529602884315, 0.0438984247011831, 0.0393122043897165, 0.10013031220296398, 0.037930106482235715, 0.03822918457444757, 0.028212808865646366, 0.01976140552869765, 0.0808987722848542, 0.02167825794458622, 0.03741389824426733, 0.04923819207760971, 0.018958934233523905, 0.05219002137891948, 0.07493946002796292, 0.03550145047483966, 0.07535663607995957, 0.0392961591569474, 0.04056315367051866, 0.01208503443194786, 0.03704904731421266, 0.05528122230316512, 0.05181509579415433, 0.026813513541128486, 0.03709542412252631, 0.03804128020419739, 0.04328835704654921, 0.028669229686784092, 0.07926195074105635, 0.015565450994472485, 0.05609728046692908, 0.016863107339304406, 0.03415029641473666, 0.035103136106044985, 0.02559774020483019, 0.014540815936925355, 0.08581593108829111, 0.015139863626245642, 0.06890050790389068, 0.03350357408635318, 0.009414179457962746, 0.07654275876120664, 0.04967011460394133, 0.08647224938613363, 0.023346552115981467, 0.07711759666563012, 0.04527391378360335, 0.05575374772888608, 0.1360032521188259, 0.05108317120175343, 0.05318947907653637, 0.06613868696149439, 0.09126970719080418, 0.07515995952417143, 0.09916255905409344, 0.07637290342245251, 0.08294262472190894, 0.027331449127814267, 0.21051202900707722, 0.3366906114388257, 1.3367580575868487, 11.465202681720257, 35.59549055993557, 63.525154665112495, 94.57611188292503, 97.3022148013115, 91.97088047862053, 90.34778237342834, 85.19339695572853, 79.65964749455452, 67.60604068636894, 66.16616874933243, 64.76250126957893, 53.74087728559971, 56.355045810341835, 56.99315696954727, 57.44052596390247, 64.37548443675041, 61.548941507935524, 65.8333446085453, 66.80055990815163, 65.07665321230888, 62.70787172019482, 63.185148909687996, 61.82757295668125, 59.637370482087135, 59.53325226902962, 58.21949556469917, 53.452259972691536, 57.4309428781271, 62.32247740030289, 64.1579233109951, 62.49073997139931, 66.6854640841484, 69.59876015782356, 62.018322721123695, 59.76129323244095, 55.66236957907677, 54.60270904004574, 48.721095845103264, 49.961668476462364, 57.43071869015694, 70.81414014101028, 72.97183156013489, 82.45564386248589, 87.84088969230652, 97.88226127624512, 111.04282468557358, 103.7683354318142, 78.27694728970528, 61.63155287504196, 21.45332582294941, 5.515976864844561, 1.1324597639031708, 0.21146956278244033, 0.09091130181332119, 0.05630745297821704, 0.05003199323255103, 0.053724022072856314, 0.07852652692236006, 0.045225381036289036, 0.14608933590352535, 0.024005705417948775, 0.11512507204315625, 0.04896523016213905, 0.04686976506491192, 0.070951492380118, 0.07216703379526734, 0.02713693964324193, 0.06806666046031751, 0.046284785712487064, 0.0405876222794177, 0.031096455204533413, 0.02041252693743445, 0.051462219416862354, 0.06933794458745979, 0.0073114209044433665, 0.04886884373263456, 0.029417353507597, 0.056621719122631475, 0.08178049567504786, 0.06783919961890206, 0.016665490111336112, 0.022474068464362063, 0.04768967497511767, 0.05376971610530745, 0.05557482334552333, 0.09819262399105355, 0.06769217274268158, 0.03790911112446338, 0.0612263706716476, 0.044725025072693825, 0.03767879301449284, 0.0761962054821197, 0.1041828170127701, 0.02070826722047059, 0.0065467555396026, 0.07938339578686282, 0.022200536950549576, 0.024690978607395664, 0.03781978623010218, 0.07095589331584051, 0.08804946905001998, 0.07021105164312758, 0.03671430160466116, 0.024590764551248867, 0.020162851760687772, 0.060000283338013105, 0.01692228062893264, 0.025630244417698123, 0.019773083222389687, 0.03507565437757876, 0.16855194931849837, 0.16682789573678747, 0.1123987851315178, 0.20291208056733012, 0.2767523902002722, 0.17238554282812402, 0.16438951017335057, 0.173628076154273, 0.20563162135658786, 0.11168803772307001, 0.2420243911910802, 0.10641514527378604, 0.18489266076358035, 0.1940845456556417, 0.12606258474988863, 0.15540602034889162, 0.20203202700940892, 0.18964812043122947, 0.1272637359215878, 0.13512011122656986, 0.13673135836143047, 0.12257429771125317, 0.07585611630929634, 0.13923229213105515, 0.12224984558997676, 0.16188014560611919, 0.2028647909173742, 0.1611557649448514, 0.16976365383015946, 0.1525423990096897, 0.23904564790427685, 0.09305201936513186, 0.21368021290982142, 0.09592327740392648, 0.1591982613899745, 0.11470179553725757, 0.11593595001613721, 0.09221681379131041, 0.07498266044422053, 0.12131945215514861, 0.1235598920902703, 0.16448616748675704, 0.14152033341815695, 0.11039089717087336, 0.19300175219541416, 0.14711360359797254, 0.1482166873756796, 0.2030849564471282, 0.19436979753663763, 0.22985264979070053, 0.1953021131339483, 0.17489363090135157, 0.23075443343259394, 0.20615246059605852, 0.22656014130916446, 0.17830761411460117, 0.19630937080364674, 0.19055584125453606, 0.3176229080418125, 0.100922851706855, 0.18196229066234082, 0.1132393564330414, 0.16534769703866914, 0.5431115662213415, 0.35937108972575516, 3.8078134367242455, 19.163103215396404, 52.48266600072384, 100.25707304477692, 126.438739746809, 132.1748587489128, 132.93103337287903, 114.70752283930779, 104.09147769212723, 89.6076200902462, 85.125373005867, 96.75714924931526, 76.97385281324387, 94.20737206935883, 79.23328757286072, 83.62707540392876, 83.84901389479637, 90.27598902583122, 93.33599522709846, 94.90936920046806, 87.67550736665726, 82.89683818817139, 92.23631903529167, 86.10236898064613, 81.04781180620193, 83.08792233467102, 82.07348316907883, 78.72344613075256, 78.73764216899872, 83.95634293556213, 83.76315370202065, 79.8963975906372, 84.86772403120995, 92.75224775075912, 78.21606695652008, 77.33135282993317, 68.13613504171371, 71.80742964148521, 68.16227003931999, 71.17410242557526, 80.93431949615479, 89.31904077529907, 99.15417462587357, 101.67931392788887, 111.17625072598457, 122.79967501759529, 136.20537847280502, 115.75280115008354, 78.2658138871193, 53.58964920043945, 15.32155780121684, 3.0116480961441994, 0.613305555889383, 0.3415848972508684, 0.23295009217690676, 0.10842157862498425, 0.14891193131916225, 0.16644191957311705, 0.19275206403108314, 0.14666873059468344, 0.2578421408543363, 0.13236117723863572, 0.3530461509944871, 0.3180967248044908, 0.22323389479424804, 0.3272573504364118, 0.13115953624946997, 0.11919801559997723, 0.12346885283477604, 0.14543731464073062, 0.21548076707404107, 0.09654359411797486, 0.10754044153145514, 0.22555154777364805, 0.13617390155559406, 0.1373063595383428, 0.13526361290132627, 0.1951393749914132, 0.10815185989486054, 0.3000572818564251, 0.21504891134100035, 0.1693657587748021, 0.10415277487481944, 0.1443919402663596, 0.14780201978283003, 0.19444552628556266, 0.21460196032421663, 0.1208957155176904, 0.208313936018385, 0.20747505681356415, 0.13191581441788003, 0.19700411008670926, 0.13855000608600676, 0.13931137538747862, 0.14227546867914498, 0.15288642898667604, 0.23962977749761194, 0.13851607509423047, 0.08100397171801887, 0.15883218962699175, 0.21048102207714692, 0.17045373242581263, 0.19890181138180196, 0.1070786252967082, 0.29686797643080354, 0.1181055222696159, 0.2435508999042213, 0.09471051162108779, 0.12037311738822609, 0.2222886509844102, 0.12642313493415713], [0.03181452389981132, 0.030421111951000057, 0.023457842726202216, 0.04205359029583633, 0.03511702539981343, 0.026543358799244743, 0.06289203578489833, 0.04179280331300106, 0.05169627424038481, 0.04420095378009137, 0.06753722715075128, 0.03728329509613104, 0.06515088840387762, 0.11276389952399768, 0.08478339586872607, 0.09841011778917164, 0.02059857037238544, 0.012999159062019316, 0.037190207513049245, 0.03924597884179093, 0.03126864830846898, 0.07011608642642386, 0.04886475820967462, 0.06475271875387989, 0.020038300826854538, 0.08594745449954644, 0.007596630575790186, 0.039221391489263624, 0.05481074891577009, 0.026406844444863964, 0.041136202999041416, 0.04092878014489543, 0.03563548234524205, 0.04257044791302178, 0.0441587181558134, 0.0048142567811737536, 0.02979873763251817, 0.02840275043126894, 0.060890619351994246, 0.024751792043389287, 0.09249222479411401, 0.08790699153905734, 0.06954534517717548, 0.028817961647291668, 0.06728090418619104, 0.02480356426531216, 0.029485469676728826, 0.090632128121797, 0.014214773764251731, 0.04352005555119831, 0.02296893439051928, 0.037435709964483976, 0.04573697311570868, 0.015579087958030868, 0.03125654759060126, 0.1384329842403531, 0.029664470130228437, 0.031010169404908083, 0.06897893064888194, 0.06368327653035522, 0.005728469541281811, 0.01186698866149527, 0.044076439953641966, 0.16386346105718985, 0.10574437736067921, 0.2356266774586402, 0.15433352789841592, 0.11994810425676405, 0.6354665011167526, 6.532353451475501, 23.61626286059618, 41.55238151550293, 54.81449447572231, 69.92553502321243, 78.57096031308174, 94.83371526002884, 100.18119111657143, 85.81419244408607, 83.40387538075447, 69.7149883210659, 83.83475705981255, 73.20818647742271, 83.44397082924843, 91.92567050457001, 91.15286037325859, 92.04309940338135, 83.2316306233406, 86.59263387322426, 75.22878885269165, 71.38832733035088, 74.51601549983025, 86.60088703036308, 81.44925266504288, 78.2271471619606, 92.56918117403984, 98.52336287498474, 94.46204200387001, 90.14876425266266, 92.68107756972313, 104.0703584253788, 110.93126267194748, 107.11898043751717, 102.93807238340378, 98.17829579114914, 99.83279541134834, 101.19005978107452, 106.8885912001133, 98.41780453920364, 91.38907849788666, 77.61123821139336, 45.61743378639221, 17.88131609559059, 2.430169335566461, 0.5517322348896414, 0.10757392723462544, 0.0314439287467394, 0.0677386237657629, 0.0340259941003751, 0.11433717096224427, 0.03327172715216875, 0.08969119618996046, 0.013477804423018824, 0.11678193157422356, 0.020567366773320828, 0.04954437252308708, 0.025844615629466716, 0.047396385634783655, 0.042256144661223516, 0.024381733092013747, 0.07923377881525084, 0.0810177088715136, 0.06002464433549903, 0.03879578835039865, 0.11753041719202884, 0.035842459910782054, 0.02373524082941003, 0.037415523547679186, 0.12117436970584095, 0.014984787230787333, 0.03169698997226078, 0.04359483806183562, 0.058896798800560646, 0.07369539045612328, 0.06734780879924074, 0.007303209040401271, 0.050775098279700615, 0.01708492600300815, 0.030431778468482662, 0.058918855429510586, 0.14926028059562668, 0.029700590457650833, 0.0615673578431597, 0.06690824957331643, 0.015340470781666227, 0.06441432167775929, 0.03151685217744671, 0.04631440111552365, 0.08381015082704835, 0.05652640509651974, 0.028784778369299602, 0.08673643911606632, 0.10349920994485728, 0.046232605309342034, 0.0404871429054765, 0.06037894192559179, 0.039808537912904285, 0.014949744872865267, 0.059173764602746814, 0.0887514442729298, 0.12030437224893831, 0.032742241892265156, 0.018962075373565312, 0.006635067866227473, 0.025566863150743302, 0.03863475714751985, 0.025741861572896596, 0.06531183797051199, 0.019254587314208038, 0.06741210847394541, 0.04123968436033465, 0.028437642504286487, 0.026511227515584324, 0.06176349263114389, 0.03468651295406744, 0.020642613126256038, 0.04606447917467449, 0.05699310466297902, 0.11614157687290572, 0.06951891729841009, 0.043019888835260645, 0.03790764167206362, 0.014200914156390354, 0.04980428748240229, 0.05918445152929053, 0.03822086509899236, 0.0065621490739431465, 0.030991086932772305, 0.05113286169944331, 0.11100730276666582, 0.007027016927168006, 0.12570120336022228, 0.09711414240882732, 0.028455314895836636, 0.013204607803345425, 0.04707775195129216, 0.02415549122815719, 0.04052022042742465, 0.022713455618941225, 0.012410003273544135, 0.049987241727649234, 0.024255232165160123, 0.024417649328825064, 0.09384144184878096, 0.04696815900388174, 0.049854731259983964, 0.027282684459351003, 0.044373558775987476, 0.04534931969828904, 0.004633667203961522, 0.04704887127445545, 0.046350280244951136, 0.07690873404499143, 0.035759305974352174, 0.11200925408047624, 0.0784691514854785, 0.024624740071885753, 0.06287490701652132, 0.0946790148736909, 0.03558459327905439, 0.052875160981784575, 0.07644976765732281, 0.03350712526298594, 0.023442168567271437, 0.08730982983252034, 0.023098940109775867, 0.04576703751808964, 0.05952443309070077, 0.047712132363813, 0.13232059660367668, 0.10168906723265536, 0.2690085838548839, 0.3158050321508199, 0.5280829570256174, 0.7776229293085635, 7.2802915424108505, 26.12385470420122, 52.412688955664635, 74.75169405341148, 82.6859875023365, 86.30271703004837, 88.89566749334335, 96.96548447012901, 109.93662044405937, 97.22277626395226, 101.39053702354431, 87.03097835183144, 94.43739652633667, 89.78113397955894, 97.78399094939232, 106.0917891561985, 103.33376795053482, 103.23269337415695, 103.18595588207245, 106.06269791722298, 97.13530495762825, 94.24514964222908, 94.01112779974937, 103.9980711042881, 103.83879885077477, 97.62617781758308, 110.79678788781166, 113.63913416862488, 116.87257826328278, 109.37232032418251, 114.18492928147316, 115.57102650403976, 115.23393899202347, 111.66584685444832, 112.08237290382385, 104.71977397799492, 106.47876039147377, 103.83617699146271, 110.19085720181465, 115.01330003142357, 107.32139557600021, 95.19451349973679, 70.30311316251755, 39.22550417482853, 14.33457026258111, 2.893064534291625, 0.7354717317502946, 0.2831079054158181, 0.028907811611134093, 0.047893468727124855, 0.07126896089175716, 0.032193824445130304, 0.023724913844489492, 0.07026867198874243, 0.039917121539474465, 0.035717560167540796, 0.020324884862930048, 0.024621836419100873, 0.03555582392436918, 0.08213665234507062, 0.02570260567154037, 0.07300171244423836, 0.12545506266178563, 0.010193992056883872, 0.08764799684286118, 0.1737302402034402, 0.02108022235915996, 0.04845663635933306, 0.04912386793876067, 0.07620110365678556, 0.018260706856381148, 0.12131224590120837, 0.11321566707920283, 0.02018126815528376, 0.03634053748100996, 0.07015176888671704, 0.0154559387556219, 0.06636068559600972, 0.025082300089707132, 0.03720793371030595, 0.0055579949730599765, 0.040941712068160996, 0.03367486548086163, 0.03584898709959816, 0.039242921193363145, 0.039322828233707696, 0.07359246199484915, 0.03641416595201008, 0.11721598406438716, 0.16309041035128757, 0.03796759236138314, 0.05584551428910345, 0.0770500538055785, 0.0653264657012187, 0.05929247483436484, 0.007942780775920255, 0.02887416078010574, 0.017860162333818153, 0.03255294599512126, 0.08135751602821983, 0.032633335431455635, 0.09051273882505484, 0.025191850363626145, 0.11393146109185182, 0.05530160909984261, 0.07815190561814234, 0.040616180122015066, 0.035580986441345885, 0.13473873637849465, 0.07971889106556773, 0.17528802301967517, 0.0981026237423066, 0.13264629553304985, 0.12076889732270502, 0.34576660254970193, 0.0941942143253982, 0.10298328372300602, 0.11628438835032284, 0.3073924023192376, 0.12335283288848586, 0.168788842856884, 0.1627287469455041, 0.19909451744752005, 0.09893322057905607, 0.12105750371119939, 0.09033494992763735, 0.11356817238265648, 0.09502568689640611, 0.16841564647620544, 0.2210815329453908, 0.1262382511049509, 0.16403083020122722, 0.2115813153795898, 0.1752950288937427, 0.1205833010317292, 0.08538612368283793, 0.2893694944214076, 0.15467430726857856, 0.06803462936659344, 0.14011722902068868, 0.11958977309404872, 0.15000452112872154, 0.11200447464943863, 0.12196443043649197, 0.1298868568846956, 0.22213544201804325, 0.12227921979501843, 0.14986575435614213, 0.2000189811224118, 0.35640665504615754, 0.18374567152932286, 0.25260352820623666, 0.16134882724145427, 0.12444301071809605, 0.26984335156157613, 0.17630080226808786, 0.15596223034663126, 0.09736728155985475, 0.18265786115080118, 0.13583071762695909, 0.09693783780676313, 0.14951520832255483, 0.13837224687449634, 0.20207799563650042, 0.09600740726455115, 0.14881922223139554, 0.1665007570409216, 0.17245932715013623, 0.10722459090175107, 0.22896824724739417, 0.15615711832651868, 0.20980351546313614, 0.23780260991770774, 0.43108701647724956, 0.6121021485887468, 0.25771520391572267, 2.048083213157952, 12.72296654060483, 36.30987882614136, 64.79272484779358, 90.36593779921532, 112.5306348502636, 124.19267266988754, 137.24208444356918, 147.20077246427536, 135.2258062362671, 136.6149052977562, 123.1957657635212, 138.49177658557892, 122.22318515181541, 132.09532141685486, 143.84657084941864, 143.96181106567383, 140.38980513811111, 141.0476714372635, 134.51624751091003, 121.84072047472, 126.06739327311516, 121.69238403439522, 140.395185649395, 135.3745150566101, 129.51700776815414, 140.0931778550148, 143.96091431379318, 140.87818533182144, 133.6954003572464, 137.9905530810356, 146.66421085596085, 144.92920875549316, 146.2205770611763, 143.7565764784813, 138.61142456531525, 137.46911466121674, 135.948968231678, 138.54293704032898, 136.38532161712646, 123.26097786426544, 105.15121042728424, 61.03040233254433, 28.389918208122253, 7.493541799485683, 1.039809810463339, 0.15811042132554576, 0.26770332420710474, 0.19767597637837753, 0.12684810353675857, 0.19417487987084314, 0.18659265391761437, 0.24722882051719353, 0.10164469422306865, 0.33436629397328943, 0.133067523711361, 0.11966888603637926, 0.20488371461397037, 0.21965589694445953, 0.23740689677651972, 0.10982381470967084, 0.20598759991116822, 0.25017275707796216, 0.09917556148138829, 0.1595112992799841, 0.26030298380646855, 0.11457237982540391, 0.09689953556517139, 0.12330051889875904, 0.22057335474528372, 0.11873472991283052, 0.22131023317342624, 0.22292106470558792, 0.08404194581089541, 0.12177615499240346, 0.17175928893266246, 0.11465500312624499, 0.12982445710804313, 0.18540278339060023, 0.10527880585868843, 0.19924428284866735, 0.2868711284827441, 0.16498967015650123, 0.13058576703770086, 0.14890360442223027, 0.16105858812807128, 0.13520968845114112, 0.09876165087916888, 0.2907599526224658, 0.1621618351782672, 0.13282740925205871, 0.1208237643004395, 0.23796698078513145, 0.17117518902523443, 0.1083514976198785, 0.11167800388648175, 0.16663397254887968, 0.1370970590505749, 0.09791129064979032, 0.2177072991617024, 0.13732947001699358, 0.2940941252745688, 0.1310681481845677, 0.19403002748731524, 0.10653243429260328, 0.20584446931025013, 0.09676341083832085, 0.08211094434955157], [0.00846307453684858, 0.06979460289585404, 0.0085774478429812, 0.05436025414383039, 0.08803011383861303, 0.014015512679179665, 0.04153390880674124, 0.05452079181850422, 0.03953837389417458, 0.07412831488181837, 0.056438267638441175, 0.04243978168233298, 0.1400669856229797, 0.015179447927948786, 0.038629001792287454, 0.05218662234256044, 0.05555019888561219, 0.06858525099232793, 0.05702051588741597, 0.05828518005728256, 0.014533509493048768, 0.08749310320126824, 0.04619261839252431, 0.08429493653238751, 0.07539469341281801, 0.04022378438094165, 0.017336879573122133, 0.06486746220616624, 0.03357783338287845, 0.042392210016259924, 0.03940138456528075, 0.011619118758972036, 0.08673157804878429, 0.0280822669446934, 0.040105107545969076, 0.013993652719364036, 0.026935155256069265, 0.04801475421118084, 0.029834722517989576, 0.06129750923719257, 0.05275604627968278, 0.07560264319181442, 0.037271810360834934, 0.08084210930974223, 0.037106137024238706, 0.10277383480570279, 0.06964520856854506, 0.05949491787760053, 0.0322887265792815, 0.03634881984908134, 0.0756555880070664, 0.04452102723007556, 0.008875725343386875, 0.04773225198732689, 0.03172856093442533, 0.025823488540481776, 0.029308022167242598, 0.020596935792127624, 0.0400001084926771, 0.0019085007033936563, 0.03436331877310295, 0.04734679161629174, 0.07053680252283812, 0.07426205731462687, 0.04147673746047076, 0.12507008097600192, 0.0525383075728314, 0.02219327874627197, 0.010881614143727347, 0.0943344208644703, 0.14431241172133014, 0.08616263279691339, 0.9606713382527232, 5.1412153244018555, 12.887954637408257, 19.67762030661106, 27.524923123419285, 38.004804477095604, 43.10168758034706, 53.25515694916248, 48.01659844815731, 27.02776350080967, 32.43141554296017, 32.49968267977238, 30.093817077577114, 29.450619891285896, 22.034204453229904, 4.2839195765554905, 3.4543575905263424, 5.64752628095448, 7.763789473101497, 11.755753140896559, 10.514322705566883, 12.803566865622997, 18.110029622912407, 19.32913150638342, 13.234505541622639, 10.609204564243555, 4.631344433873892, 10.404340457171202, 21.328097842633724, 28.663708716630936, 35.33733621239662, 32.21505895256996, 28.87275069952011, 28.669427409768105, 18.09363540261984, 10.197444409132004, 4.202630063518882, 0.9492702875286341, 0.13995342218549922, 0.39662589377257973, 0.31745349057018757, 0.016857344562595244, 0.04445355858479161, 0.043567582688410766, 0.010557378172961762, 0.005740385186072672, 0.04556379295536317, 0.035154054858139716, 0.029245811638247687, 0.018892890511779115, 0.05279781064018607, 0.08136571676004678, 0.010592327762424247, 0.07690693804761395, 0.008485058806400048, 0.05284413920890074, 0.025373320313519798, 0.026496748214412946, 0.01848989133577561, 0.032540106840315275, 0.02940009486337658, 0.03481369851215277, 0.05860103068698663, 0.07422788883559406, 0.09529752074740827, 0.027152691727678757, 0.18159804458264261, 0.021018635234213434, 0.050317352724960074, 0.04388684348668903, 0.006392482055161963, 0.02923417661804706, 0.030891767164575867, 0.036787017234019004, 0.06356769445119426, 0.06787230682675727, 0.04646460809453856, 0.03090139838604955, 0.03638182315626182, 0.0256074975914089, 0.10467048225109465, 0.009841307710303226, 0.07573088631033897, 0.03256199648603797, 0.06056717655155808, 0.052834962552879006, 0.026768272218760103, 0.061597811873070896, 0.02828259672241984, 0.01397019621435902, 0.03355204746185336, 0.0205073734105099, 0.00973046795479604, 0.011746182790375315, 0.012322831535129808, 0.005267996129987296, 0.03550376968632918, 0.03040134113689419, 0.013578570451500127, 0.01748826656694291, 0.03670810467156116, 0.025798864080570638, 0.031070405821083114, 0.059981347440043464, 0.014992752330726944, 0.02038909176917514, 0.04606437898473814, 0.01329900806013029, 0.05334726709406823, 0.03331404812342953, 0.02224101554020308, 0.03587781211535912, 0.019624872620624956, 0.07381222676485777, 0.0880823090847116, 0.1712374997441657, 0.05494288830959704, 0.015667512998334132, 0.0269574790581828, 0.0022071576267990167, 0.11308562054182403, 0.03231241964385845, 0.021722317396779545, 0.013064664726698538, 0.030768592914682813, 0.03136627783533186, 0.05070020444691181, 0.11207181712961756, 0.02821838981617475, 0.11200759909115732, 0.038437646435340866, 0.006472498098446522, 0.06899095344124362, 0.056596519498270936, 0.050839386822190136, 0.021034550591139123, 0.09634442394599319, 0.07345255973632447, 0.06455376380472444, 0.039767994385329075, 0.06595471597393043, 0.047158089437289163, 0.01826074396376498, 0.09721995040308684, 0.03986404313764069, 0.05967399811197538, 0.07540973674622364, 0.029090441166772507, 0.03859989476040937, 0.1418890620698221, 0.023489515733672306, 0.030599327583331615, 0.08336009763297625, 0.01507693878011196, 0.05197824582864996, 0.009609176904632477, 0.017909294365381356, 0.052146290327073075, 0.0008954614133926952, 0.04797241468622815, 0.04517171262705233, 0.11742555914679542, 0.05328513077984098, 0.012992325737286592, 0.08344517002115026, 0.05826191743835807, 0.04566121468087658, 0.18255437607876956, 0.03803963634709362, 0.14618925866670907, 0.04479181094211526, 0.1313792119617574, 0.10595093932352029, 0.11543111148057505, 0.3227337228599936, 1.2511048349551857, 6.6114110592752695, 19.85294669866562, 34.983320608735085, 47.76004761457443, 57.81417891383171, 68.8822554051876, 74.00954067707062, 82.35499486327171, 77.89477899670601, 56.567291021347046, 59.17698338627815, 56.772141829133034, 52.879265919327736, 48.85462827980518, 31.279653646051884, 9.219913613051176, 7.083019902929664, 11.584438383579254, 16.40301302075386, 22.670301720499992, 21.33675377815962, 23.163756541907787, 29.400156699121, 31.9455736130476, 22.543852105736732, 20.317686460912228, 12.0397556014359, 23.16838089376688, 37.950019016861916, 47.532420828938484, 56.453240141272545, 53.37381698191166, 51.90068922936916, 52.2484427690506, 39.67388391494751, 26.064431592822075, 14.90367142483592, 6.897839214652777, 0.8971195109188557, 0.6385756249073893, 0.6092604948207736, 0.0050399990868754685, 0.05402447684900835, 0.03372512372152414, 0.021673085175279994, 0.05222483552643098, 0.07901301214587875, 0.012223483936395496, 0.05841679623699747, 0.04079137521330267, 0.0522649782942608, 0.029425277789414395, 0.022536692740686703, 0.04152816087298561, 0.04182274155027699, 0.04740823031170294, 0.05891961984161753, 0.018504758409108035, 0.024692067709111143, 0.08539205344277434, 0.012388889172143536, 0.05786135807284154, 0.02818262015352957, 0.03233288436604198, 0.08817792739137076, 0.038295825725072064, 0.052270915475673974, 0.047418750255019404, 0.020015424124721903, 0.06722116129822098, 0.027522366617631633, 0.03609684586990625, 0.09768918069312349, 0.03753291646717116, 0.04055337587487884, 0.08197729097446427, 0.06579918408533558, 0.01544699309306452, 0.013763562819804065, 0.031654409249313176, 0.06156300885777455, 0.033138637809315696, 0.019346834415046033, 0.006642568196184584, 0.023618781160621438, 0.016382665053242818, 0.05623564276902471, 0.03408506905543618, 0.053422992132254876, 0.0329861487261951, 0.027707756962627172, 0.04787612102518324, 0.021395210242189933, 0.03030401589057874, 0.04814074491150677, 0.024068303719104733, 0.05475201534864027, 0.10720843434683047, 0.027330771918059327, 0.05122017908433918, 0.09485727874562144, 0.013398252685874468, 0.07631451124325395, 0.07456915060174651, 0.1256703003309667, 0.15196334570646286, 0.11413902495405637, 0.13678713818080723, 0.1506355989840813, 0.07499558123527095, 0.09461766152526252, 0.16757522360421717, 0.15759275847813115, 0.24597873212769628, 0.22621827840339392, 0.2594803279498592, 0.3229337465018034, 0.11747110474971123, 0.088358425127808, 0.07932933032861911, 0.16773349401773885, 0.17131368862465024, 0.2103180464473553, 0.13537684979382902, 0.12990747374715284, 0.1657847478054464, 0.19920696766348556, 0.16080961242550984, 0.19446657359367236, 0.12076144616003148, 0.13458474073559046, 0.14315659092972055, 0.19153886038111523, 0.16767450812039897, 0.1727987261256203, 0.10889267170568928, 0.1480500158504583, 0.19464630691800267, 0.17142423894256353, 0.15430943778483197, 0.16536236187675968, 0.13637771015055478, 0.1391286586294882, 0.1262728203437291, 0.07483555193175562, 0.17078041099011898, 0.26037951407488436, 0.18664470815565437, 0.21700041834264994, 0.3240399027708918, 0.18030995823210105, 0.12081855442374945, 0.1983586186543107, 0.10094844838022254, 0.1273490086896345, 0.18173385760746896, 0.15676940500270575, 0.1355561675154604, 0.18786804954288527, 0.22641223127720878, 0.1730935665545985, 0.21868170937523246, 0.16233963891863823, 0.06688646011753008, 0.15795572806382552, 0.08741028694203123, 0.17605626460863277, 0.28054800059180707, 0.2859794528922066, 0.2872341574402526, 0.14825186517555267, 0.08892316982382908, 0.17069547961000353, 0.33863281190861017, 0.23100078193238005, 0.3794212482171133, 2.0400131586939096, 9.804746881127357, 21.75538871437311, 31.81900430470705, 44.78186622262001, 57.225632295012474, 67.22444236278534, 78.91430988907814, 69.57562699913979, 54.61344726383686, 54.250232353806496, 51.328477934002876, 46.87396176159382, 44.575062319636345, 32.79845304787159, 7.670910581946373, 4.638862330466509, 9.618588220328093, 14.662818498909473, 20.604584366083145, 21.57061032950878, 25.129014886915684, 30.142104886472225, 28.689444735646248, 21.789820566773415, 17.001786790788174, 10.256539788097143, 17.40386411547661, 33.0066704750061, 40.04943296313286, 49.45458948612213, 49.262680783867836, 45.62908016145229, 46.45977258682251, 30.40489498525858, 17.317414954304695, 7.803974691778421, 2.54349279217422, 0.25835535081569105, 0.5141732690390199, 0.6799644290003926, 0.1859044752200134, 0.26436365966219455, 0.24668470752658322, 0.12938872736413032, 0.13390062900725752, 0.1616343017667532, 0.07287562155397609, 0.13400234776781872, 0.11283578394795768, 0.1495010036160238, 0.22001105913659558, 0.12019405941828154, 0.19500517984852195, 0.13331430265679955, 0.11778156738728285, 0.16085341398138553, 0.09574364055879414, 0.0904249947052449, 0.16406709153670818, 0.09475701459450647, 0.1484526161220856, 0.15523940819548443, 0.16764753847382963, 0.2643040503608063, 0.15173733205301687, 0.23116930882679299, 0.13622841972392052, 0.18329498008824885, 0.14195938798366114, 0.1181317497685086, 0.12866439123172313, 0.15376395924249664, 0.19465108634904027, 0.17850000847829506, 0.15863050357438624, 0.1406605404918082, 0.1714994036592543, 0.1326555575360544, 0.11729601726983674, 0.19582023611292243, 0.07091383580700494, 0.17129090469097719, 0.07956405679578893, 0.13001572340726852, 0.1398288452764973, 0.10505216880119406, 0.1411092429771088, 0.11991952414973639, 0.11913356749573722, 0.07394950182060711, 0.1880046195583418, 0.07947786376462318, 0.08638957413495518, 0.12918246968183666, 0.08986381973954849, 0.07875486349803396, 0.15771319420309737, 0.17809357872465625, 0.20044427626999095, 0.16399961546994746, 0.1383612779318355, 0.12843621050706133, 0.1355057756882161], [0.024259275014628656, 0.018508220528019592, 0.049366093808203004, 0.04356429497420322, 0.01953295763087226, 0.051041725964751095, 0.013449176076392177, 0.018432732977089472, 0.02420202574285213, 0.0014801861743762856, 0.029860692120564636, 0.04354120675998274, 0.021547920114244334, 0.011982482610619627, 0.027717436423699837, 0.011536736656125868, 0.025958158657886088, 0.07640718322363682, 0.046370956479222514, 0.060382025549188256, 0.044140761892776936, 0.02684793435037136, 0.04308218471123837, 0.012400278355926275, 0.014713252094225027, 0.03518984864058439, 0.061607085008290596, 0.00804416835308075, 0.01731585267407354, 0.0034020958628389053, 0.08352584889507852, 0.03372015504282899, 0.05378389483666979, 0.03323745106172282, 0.053827592491870746, 0.00410328719226527, 0.03938496454793494, 0.08592596190283075, 0.007904843114374671, 0.0010786737288981385, 0.02869828291295562, 0.0427519030199619, 0.051816019768011756, 0.004268589918865473, 0.042387415742268786, 0.0031819792684473214, 0.027400774997659028, 0.06900615262566134, 0.007692294802836841, 0.10384601555415429, 0.11303177030640654, 0.04099362158740405, 0.006255219059312367, 0.03553485825250391, 0.04522619739873335, 0.056272052534040995, 0.029086342656228226, 0.08650916381157003, 0.07991306658368558, 0.05128291653818451, 0.03743733526789583, 0.018985890892508905, 0.030674399531562813, 0.03803615938522853, 0.08833474319544621, 0.04973203569534235, 0.0908466088003479, 0.024022702455113176, 0.020697177678812295, 0.033694153898977675, 0.02366830096434569, 0.03413807695324067, 0.06574525963515043, 0.03447138660703786, 0.22471728472737595, 0.08593343532993458, 0.09211036012857221, 0.06500496732769534, 0.05778066064522136, 0.1290322738350369, 0.06909426781930961, 0.06335896541713737, 0.4064295458374545, 0.07849144560168497, 0.2959084388567135, 0.511185263749212, 0.5183560133446008, 0.21924728527665138, 0.18991605058545247, 0.20898480783216655, 0.18049099773634225, 0.25951506046112627, 0.18127289484255016, 0.10942661727312952, 0.22799782978836447, 0.1636251574382186, 0.03763789696677122, 0.11390421685064211, 0.2201481634983793, 0.2805530175101012, 0.34748467442113906, 0.3392226411961019, 0.20844277285505086, 0.371126233949326, 0.36112407222390175, 0.40633573837112635, 0.12410629089572467, 0.13673680572537705, 0.14763194922124967, 0.050678737825364806, 0.05050681560533121, 0.05337481932656374, 0.05071608640719205, 0.03676663043734152, 0.04118794182431884, 0.07012182322796434, 0.14273646112997085, 0.04123915372474585, 0.02910997449362185, 0.0331138278124854, 0.05178861225431319, 0.01120141763749416, 0.026711225182225462, 0.03758101876883302, 0.036506459437077865, 0.11973147134995088, 0.055254382532439195, 0.04438710297108628, 0.031186084379442036, 0.026104183634743094, 0.015399152398458682, 0.012900958081445424, 0.05359412025427446, 0.04941232218698133, 0.027373150405765045, 0.03686341020511463, 0.0438594285515137, 0.009159968831227161, 0.02222805022029206, 0.01713656649371842, 0.11919137337827124, 0.013394105935731204, 0.02175674933823757, 0.012961928296135738, 0.04104856649064459, 0.054658252411172725, 0.01933955765707651, 0.027532064632396214, 0.05269444431178272, 0.056864512735046446, 0.0315704129752703, 0.025937922146113124, 0.014870682025502902, 0.024711543519515544, 0.013174126870580949, 0.025956448007491417, 0.05380195871111937, 0.03779816375754308, 0.045605961786350235, 0.03054831420740811, 0.04122433303564321, 0.07480562853743322, 0.01595829573489027, 0.01235602687302162, 0.02717487823247211, 0.03416719882807229, 0.021665810272679664, 0.0086691847172915, 0.0405047169624595, 0.013587850080511998, 0.04824737297894899, 0.04811719656572677, 0.02124713508237619, 0.046296823347802274, 0.00593810770624259, 0.06533829553518444, 0.01907641806610627, 0.024618864117655903, 0.03269871864176821, 0.06959459409699775, 0.03449371411988977, 0.003532976156748191, 0.04787640675203875, 0.05066223988251295, 0.014615107702411478, 0.06002973917929921, 0.005924935048824409, 0.03472772070381325, 0.0203278608751134, 0.026555941913102288, 0.03262261139752809, 0.025929443108907435, 0.011594230836635688, 0.012932171885040589, 0.009346607839688659, 0.07759037442156114, 0.015487358505197335, 0.02737926013651304, 0.057794472013483755, 0.05474872392369434, 0.04556603424134664, 0.007505114954255987, 0.09265424305340275, 0.028941601594851818, 0.026149397126573604, 0.04081432241946459, 0.08030607088585384, 0.0243264579330571, 0.050834807771025226, 0.06008068761730101, 0.07701923241256736, 0.016138639475684613, 0.027987787834717892, 0.04075545526575297, 0.020304488789406605, 0.012164472063886933, 0.04793044623511378, 0.0749775767326355, 0.027175505347258877, 0.06561521309777163, 0.06429470973671414, 0.012590788592206081, 0.04471344385819975, 0.01603922137292102, 0.05010794091504067, 0.07096413857652806, 0.013569671173172537, 0.012624430146388477, 0.02633184485603124, 0.045024819337413646, 0.02660723916051211, 0.04656417833757587, 0.17366484215017408, 0.02557646654167911, 0.026280690472049173, 0.03980661203968339, 0.05989359589875676, 0.09252166579244658, 0.033483884908491746, 0.08386353350942954, 0.04018522609840147, 0.03228392859455198, 0.044463354934123345, 0.060926420555915684, 0.02917020163295092, 0.14327785786008462, 0.04096710094017908, 0.024186049158743117, 0.0683100032620132, 0.07298200100194663, 0.23583171801874414, 0.5619501834735274, 0.7764359086286277, 0.5371676757931709, 1.312327387277037, 0.931520015001297, 0.5594345403369516, 0.07326087783440016, 0.6232250423636287, 0.27759680582676083, 0.34261262335348874, 0.5620086053386331, 0.5255100794602185, 0.4942271893378347, 0.24289270397275686, 0.3014718450140208, 0.3099780448246747, 0.255497072939761, 0.12161519058281556, 0.15966297942213714, 0.23520071437815204, 0.2176621023681946, 0.07847984583349898, 0.21537260647164658, 0.4016140167368576, 0.34964485850650817, 0.40423373866360635, 0.1401019110926427, 0.054653695624438114, 0.16183451836695895, 0.4156299208989367, 0.29922411718871444, 0.2128450444433838, 0.33885364537127316, 0.1241338394174818, 0.15314140124246478, 0.17787863791454583, 0.0068379469212231925, 0.04458409865037538, 0.04474775334529113, 0.08892543337424286, 0.04412716945807915, 0.0597258037305437, 0.03083156971115386, 0.014811635828664294, 0.0764861774223391, 0.032784002542030066, 0.025679675163701177, 0.031814093454158865, 0.047160879912553355, 0.04480355913983658, 0.019015003490494564, 0.04297174200473819, 0.014095172027737135, 0.018560606877144892, 0.06316744678770192, 0.028145561009296216, 0.04267229654942639, 0.027548794496397022, 0.05742078952607699, 0.045984442258486524, 0.012207477666379418, 0.019280991073173936, 0.02359210280701518, 0.060235833589104004, 0.032185460440814495, 0.057455763235338964, 0.020954209394403733, 0.02695873328775633, 0.03264316146669444, 0.038778863672632724, 0.025216053654730786, 0.04340049184975214, 0.05472419594298117, 0.035306863064761274, 0.04709706634457689, 0.06975026699365117, 0.06269557445193641, 0.04728913787403144, 0.06109872869274113, 0.02503295097994851, 0.05027510596846696, 0.017064203384506982, 0.0538967866305029, 0.02165782847441733, 0.019964266030001454, 0.04318367711675819, 0.098107759404229, 0.051242840563645586, 0.06201571894052904, 0.04618466628016904, 0.07489156181691214, 0.056354516273131594, 0.04460168012883514, 0.02520383604860399, 0.012597703553183237, 0.034342716753599234, 0.027319211112626363, 0.05518460209714249, 0.04792999352503102, 0.045802059466950595, 0.05632281914586201, 0.09596188392606564, 0.07040758719085716, 0.14066128263948485, 0.20351725746877491, 0.17487037199316546, 0.11116093475720845, 0.1898023980902508, 0.07293755377759226, 0.08600258865044452, 0.09378808143083006, 0.13868912908947095, 0.0983570542302914, 0.16060837166151032, 0.08647391921840608, 0.160199003003072, 0.15762394352350384, 0.10578341432847083, 0.14372673846082762, 0.06845543452072889, 0.170673378452193, 0.13276411889819428, 0.21176982088945806, 0.11106327554443851, 0.19459545495919883, 0.13616861746413633, 0.16247229039436206, 0.16990387521218508, 0.0947113279835321, 0.13204554183175787, 0.08746329855057411, 0.18476852914318442, 0.1270841807126999, 0.14365179638843983, 0.1435542039689608, 0.19084628816926852, 0.09949265891918913, 0.1210519672895316, 0.14190308866091073, 0.07609410080476664, 0.09225588786648586, 0.17012735072057694, 0.2949321881169453, 0.08308323202072643, 0.17135940492153168, 0.18041200353763998, 0.25423476879950613, 0.09314523311331868, 0.11332007241435349, 0.1344683868228458, 0.15134314773604274, 0.18511346454033628, 0.20282977638999, 0.25261388858780265, 0.17992895445786417, 0.17716169357299805, 0.2207201812416315, 0.2995041146641597, 0.1719397198758088, 0.178370414650999, 0.1384683104697615, 0.18189686292316765, 0.22751224256353453, 0.19343571562785655, 0.16803174832602963, 0.0971878450945951, 0.1454821997322142, 0.11667817190755159, 0.1694120984757319, 0.1380616580718197, 0.21772845037048683, 0.1875521321198903, 0.1105196969001554, 0.18029527855105698, 0.46623213216662407, 0.5195232632104307, 0.38013362092897296, 0.27634219033643603, 0.14801966201048344, 0.2846232522279024, 0.22478726925328374, 0.15251593402354047, 0.15829949086764827, 0.37107330397702754, 0.16439476457890123, 0.7259293750394136, 1.033597500063479, 0.6761345313861966, 0.6491621537134051, 0.20367589895613492, 0.36010456911753863, 0.3990261774742976, 0.28275829448830336, 0.2879046433372423, 0.20116122061153874, 0.36088186490815133, 0.3864996152697131, 0.3612455172697082, 0.47741145885083824, 0.5262958654202521, 0.6024285801686347, 0.7110854715574533, 0.356977425981313, 0.36979553347919136, 0.430247588083148, 0.5926254030782729, 0.534841250628233, 0.28198604530189186, 0.3748888336122036, 0.3108167013851926, 0.2561942464672029, 0.16741922416258603, 0.08991997805424035, 0.1814645025297068, 0.11498471707454883, 0.3123710257932544, 0.1287807896733284, 0.20619854796677828, 0.08806401514448225, 0.14186691638315096, 0.22583169367862865, 0.3167871607001871, 0.0783874410262797, 0.20714913523988798, 0.3248645772691816, 0.09503659646725282, 0.20877644245047122, 0.20430302858585492, 0.16822305915411562, 0.18874458532081917, 0.14180169644532725, 0.15209714008960873, 0.17555896629346535, 0.10745332823717035, 0.18730131589109078, 0.10546922610956244, 0.09898823598632589, 0.16094357008114457, 0.14678693987661973, 0.09795293255592696, 0.19684175786096603, 0.2273884671740234, 0.09390036837430671, 0.10743991762865335, 0.1296474994160235, 0.10878808825509623, 0.21718687552493066, 0.11427400677348487, 0.1663586060749367, 0.10483791818842292, 0.10976134813972749, 0.2029723726445809, 0.20788708236068487, 0.1014188067347277, 0.0955515875830315, 0.1183364489406813, 0.13808650517603382, 0.12735760275973007, 0.1953077979851514, 0.1173494964314159, 0.1207820481795352, 0.1289354235632345, 0.2469028692576103, 0.12346195086138323, 0.162985812057741, 0.13832117227138951, 0.15614659467246383, 0.18063196126604453, 0.11104573117336258, 0.10302561582648195, 0.1588617271045223, 0.11144859119667672, 0.17128008417785168, 0.12118744634790346, 0.08659352373797446, 0.14928631513612345, 0.15262112603522837], [0.06288752352702431, 0.025612460703996476, 0.011761073055822635, 0.032740679671405815, 0.092752718628617, 0.045087590187904425, 0.02157977123715682, 0.11857821838930249, 0.02166410889913095, 0.03764116241654847, 0.031273023269022815, 0.045818401558790356, 0.07314575588679872, 0.027279292844468728, 0.07043751800665632, 0.043380743300076574, 0.03412396501516923, 0.03243250284867827, 0.08570050486014225, 0.015582631713186856, 0.034427637001499534, 0.03961413603974506, 0.07760343622067012, 0.05751291602791753, 0.0496792838384863, 0.05522316409042105, 0.029936133287264965, 0.03786521680012811, 0.05378978377848398, 0.020224442596372683, 0.05411299651314039, 0.019642175793705974, 0.1135835496825166, 0.04022337991045788, 0.07161369590903632, 0.03261630314227659, 0.04211447980196681, 0.03394459163246211, 0.02797012286464451, 0.018344324635108933, 0.02291935892571928, 0.02686503157747211, 0.061099908707547, 0.09062771976459771, 0.01188813801491051, 0.039908275139168836, 0.04562556561722886, 0.020925440039718524, 0.0562283845647471, 0.03788400055782404, 0.07428402488585562, 0.0755763563211076, 0.012932807348988717, 0.014860465435049264, 0.029453301285684574, 0.04651619849028066, 0.040938164602266625, 0.02440444837702671, 0.03695977808092721, 0.021532910177484155, 0.12699647370027378, 0.08403831670875661, 0.01390594756230712, 0.10602763286442496, 0.059308238051016815, 0.019982923622592352, 0.030184285205905326, 0.030205297262000386, 0.06600149354198948, 0.019505707823554985, 0.08638178158435039, 0.04901484273432288, 0.04559554945444688, 0.09326517902081832, 0.017649926739977673, 0.026548526002443396, 0.05421604371804278, 0.03743197325093206, 0.014716960049554473, 0.11407047277316451, 0.04704549450252671, 0.022116071268101223, 0.20106996613321826, 0.049693440305418335, 0.20701783447293565, 0.1027348794741556, 0.19536905485438183, 0.009562442010064842, 0.03581601347832475, 0.016154176337295212, 0.04784077995282132, 0.06901726257638074, 0.071650283789495, 0.04780644077982288, 0.08622435721918009, 0.04261307687556837, 0.019098372649750672, 0.06540446542203426, 0.07744227885268629, 0.0874064426170662, 0.17381215846398845, 0.18487277120584622, 0.24260417179903015, 0.08151289206580259, 0.06315681923297234, 0.07660924035008065, 0.0804065576812718, 0.013844111817888916, 0.00608573201134277, 0.00963690075877821, 0.020334172841103282, 0.0524694993509911, 0.04239913425408304, 0.03355781394930091, 0.038835760424262844, 0.05706754949642345, 0.039166665519587696, 0.03559730626875535, 0.06406873319065198, 0.00618345337898063, 0.05323390032572206, 0.047332727917819284, 0.09314313283539377, 0.028207179675519, 0.01629070182389114, 0.029256329726194963, 0.0405076150491368, 0.02624054399348097, 0.06348143462673761, 0.029556595254689455, 0.06448504092986695, 0.02147581304598134, 0.02152736076823203, 0.03923654614482075, 0.0019500554071782972, 0.027769197513407562, 0.09528963171760552, 0.004973281402271823, 0.042411594913573936, 0.07155329993111081, 0.09957784262951463, 0.022801012346462812, 0.04535451844276395, 0.06908286843099631, 0.07025339116808027, 0.04796888206328731, 0.034361596990493126, 0.018974428421643097, 0.03779926213610452, 0.09904799371724948, 0.06265422940487042, 0.020122345340496395, 0.05423507980594877, 0.030839228675176855, 0.0608731677493779, 0.04064808876137249, 0.004426023097039433, 0.024778299703029916, 0.02596835205622483, 0.015863432563492097, 0.08067131886491552, 0.062434449791908264, 0.04294996368116699, 0.011496154165797634, 0.014371704601217061, 0.019532363912730943, 0.042557942724670283, 0.046287598452181555, 0.028151871119916905, 0.02544311744713923, 0.04465006073587574, 0.07984638461493887, 0.028457929111027624, 0.04675621275964659, 0.08517415888491087, 0.042360045335954055, 0.08575036976253614, 0.03474517972790636, 0.012852746313001262, 0.03215853532310575, 0.00610149893873313, 0.03890130690706428, 0.06369706563418731, 0.10093173521454446, 0.01656493837799644, 0.04733512134407647, 0.029901144735049456, 0.005030365546190296, 0.021345451095839962, 0.03514548305247445, 0.02613129614474019, 0.06606646114960313, 0.028252166812308133, 0.023616448961547576, 0.03958807181334123, 0.00915751696084044, 0.06285285038757138, 0.008766417195147369, 0.01957914519152837, 0.04015887243440375, 0.027251905739831273, 0.01004610243398929, 0.04121774647501297, 0.03526300955854822, 0.034624803374754265, 0.00796934224126744, 0.0394917595986044, 0.008986326683952939, 0.029421032704703975, 0.025549942183715757, 0.030396023648791015, 0.03594945534132421, 0.01591856485902099, 0.03436997954850085, 0.005899898696952732, 0.02839701177435927, 0.027422265739005525, 0.05525951448362321, 0.04376293822133448, 0.07337792194448411, 0.014306087614386342, 0.055466120975324884, 0.0112735367656569, 0.021796621222165413, 0.06653344273217954, 0.09369917213916779, 0.06976796721573919, 0.018452464828442317, 0.020869437576038763, 0.02342656305700075, 0.022919958209968172, 0.09908095249556936, 0.04557585285510868, 0.04504836397245526, 0.016793184040579945, 0.00899379825568758, 0.07963909534737468, 0.07079051312757656, 0.02596313104731962, 0.008880449113348732, 0.013062907692074077, 0.03251333015214186, 0.11201792978681624, 0.0100745842064498, 0.08439824348897673, 0.08814082742901519, 0.05006984276406001, 0.07797809463227168, 0.05500135841430165, 0.08625875576399267, 0.00850669426654349, 0.04751668777316809, 0.013847430145688122, 0.052208671550033614, 0.05171105411136523, 0.10841165611054748, 0.034754764565150253, 0.03130489851173479, 0.13122410309733823, 0.05938450114626903, 0.05232954143139068, 0.2034507313510403, 0.2447993407258764, 0.0517716801550705, 0.0932610675226897, 0.06377516183420084, 0.046269742379081436, 0.04463186698558275, 0.0350189208984375, 0.01824543345719576, 0.1499807130312547, 0.03172205229930114, 0.033222096026293, 0.03767452195461374, 0.06928447284735739, 0.09658057533670217, 0.13312786031747237, 0.08660994004458189, 0.13048008520854637, 0.030476604188152123, 0.05934706721745897, 0.08434364368440583, 0.025681749466457404, 0.1284323216532357, 0.04492520456551574, 0.012323076443863101, 0.06461885015596636, 0.0215241138721467, 0.11566617933567613, 0.04148818879912142, 0.02214063821156742, 0.07541536222561263, 0.04124700935790315, 0.03339174727443606, 0.09480657521635294, 0.10855437110876665, 0.03752603675820865, 0.016203775921894703, 0.027004930125258397, 0.05278337586787529, 0.053512491431320086, 0.03628295053204056, 0.04041516571305692, 0.07443823575158603, 0.031321530041168444, 0.04091697257535998, 0.0332210124906851, 0.05434314763988368, 0.03567792948160786, 0.04205039906082675, 0.05382717317843344, 0.05047165264841169, 0.053439894545590505, 0.04206720128422603, 0.04820841393666342, 0.06713932467391714, 0.031017318142403383, 0.010311782025382854, 0.04643687774660066, 0.05429834418464452, 0.06424200983019546, 0.04984433748177253, 0.04520604066783562, 0.060489288152894005, 0.047520439329673536, 0.02533899969421327, 0.04032847173220944, 0.005975736912660068, 0.019043416614294983, 0.029223981364339124, 0.017400448232365306, 0.06938274062122218, 0.029603361690533347, 0.02036615383985918, 0.01623222244234057, 0.008670553052070318, 0.06107947738200892, 0.03177460006554611, 0.03139046813885216, 0.05317446913977619, 0.03539928271493409, 0.08120577651425265, 0.03507746150717139, 0.06926390051376075, 0.04000945213192608, 0.03726235168869607, 0.02678147873666603, 0.04618623963324353, 0.010471883688296657, 0.030181366710166913, 0.04711482222774066, 0.0396783986070659, 0.13108800805639476, 0.10399028906249441, 0.09702824623673223, 0.09176775507512502, 0.13538452360080555, 0.12370585769531317, 0.13631568144774064, 0.2563117432873696, 0.10517063783481717, 0.12081825014320202, 0.09575943346135318, 0.10363761306507513, 0.13260181120131165, 0.11835361481644213, 0.16522246703971177, 0.13462800794513896, 0.09380919553223066, 0.1143103200593032, 0.11713333849911578, 0.10200451710261405, 0.12973906559636816, 0.14996441546827555, 0.14719050494022667, 0.20804759406019002, 0.17653480143053457, 0.14766335691092536, 0.13624479150166735, 0.09928049374138936, 0.08513584922184236, 0.23005298513453454, 0.20881335687590763, 0.10866544093005359, 0.23656665201997384, 0.1070995390182361, 0.1777896544081159, 0.10378963459515944, 0.16870845342054963, 0.1277444398147054, 0.09120911083300598, 0.1373806782066822, 0.12579615373397246, 0.1333717003581114, 0.12580722657730803, 0.13924030732596293, 0.08178865929949097, 0.18460197636159137, 0.14247025275835767, 0.09281520004151389, 0.21421230310807005, 0.17128199891885743, 0.18293929839273915, 0.09610521490685642, 0.13838260725606233, 0.06914097117260098, 0.2115887071704492, 0.14208071428583935, 0.27265383512713015, 0.053387105581350625, 0.11293684961856343, 0.09267398418160155, 0.3628839418524876, 0.16539060801733285, 0.0864918420847971, 0.12160833313828334, 0.12797484698239714, 0.13469627068843693, 0.24416330532403663, 0.15460231894394383, 0.32806851784698665, 0.19486362260067835, 0.452574091614224, 0.1444305171025917, 0.23177375842351466, 0.17082069476600736, 0.16183784318855032, 0.11680838913889602, 0.11058578515076078, 0.15740184840979055, 0.10561505070654675, 0.188703277381137, 0.1065753007424064, 0.0883434856950771, 0.25276478205341846, 0.1411699061281979, 0.25754065078217536, 0.3571264195488766, 0.3882596333278343, 0.15526468574535102, 0.17894882970722392, 0.13785936345811933, 0.11804327834397554, 0.15871375770075247, 0.14691773598315194, 0.0862898443301674, 0.27766267885454, 0.0866900548862759, 0.08795065208687447, 0.2513606386492029, 0.12047286945744418, 0.18631197366630659, 0.26238488615490496, 0.17815482075093314, 0.28874000476207584, 0.1696327538229525, 0.11800578504335135, 0.18266660365043208, 0.18389116215985268, 0.2460815492668189, 0.1338486044551246, 0.06875740698887967, 0.1781687285983935, 0.1325928609003313, 0.1759340477292426, 0.11408878155634739, 0.2740209602052346, 0.18305436096852645, 0.1630389053025283, 0.1838756661163643, 0.19371823640540242, 0.14809588057687506, 0.14515163231408224, 0.1253876311238855, 0.15841719548916444, 0.17359914723783731, 0.2222687762696296, 0.08405758286244236, 0.14781445817789063, 0.14288506878074259, 0.09685933342552744, 0.11888592023751698, 0.19255218881880865, 0.17639809782849625, 0.13198709028074518, 0.11038658529287204, 0.10667591370292939, 0.12443906991393305, 0.12933425372466445, 0.17737235961249098, 0.15445190045284107, 0.11214746424229816, 0.18368054064922035, 0.11400062925531529, 0.1659709378145635, 0.148209206527099, 0.2043920269352384, 0.10648589421180077, 0.1330843853065744, 0.11270688773947768, 0.11219177788007073, 0.1493112661410123, 0.14567588543286547, 0.09469908254686743, 0.26313843321986496, 0.10953671488096006, 0.13126907724654302, 0.12705167464446276, 0.09541420120513067, 0.09539714665152133, 0.22065432305680588, 0.13358342024730518, 0.20596232236130163, 0.1569782750448212, 0.1500427268911153, 0.08030460143345408, 0.13573429780080914, 0.10967732217977755, 0.15590134455123916, 0.1341900962870568, 0.13746667827945203, 0.14571432868251577, 0.05905013022129424, 0.0891645607771352, 0.0623960213852115, 0.1563372672535479, 0.2893444098299369, 0.12530511914519593], [0.010669300536392257, 0.013516512990463525, 0.05373511718062218, 0.016055646956374403, 0.031926372976158746, 0.01441492171579739, 0.02633835163578624, 0.046818879709462635, 0.05274155584629625, 0.044690459544654004, 0.022044188699510414, 0.013600881266029319, 0.03364989963301923, 0.018410642951494083, 0.04023406312626321, 0.013927326053817524, 0.03159341955324635, 0.07750887918518856, 0.028052031848346815, 0.056592155669932254, 0.047389272149303, 0.0698357104556635, 0.012497602674557129, 0.03556294854206499, 0.0639579379640054, 0.08275909902295098, 0.03744134657608811, 0.04114842617127579, 0.06723218961269595, 0.019376676173123997, 0.07628815015777946, 0.05285695238853805, 0.006382363335433183, 0.022205056629900355, 0.029214116366347298, 0.02458062495861668, 0.02734087440330768, 0.01464010972995311, 0.05288756226946134, 0.028998322086408734, 0.02918285896157613, 0.020680625930253882, 0.017894492229970638, 0.03310778301965911, 0.008156457151926588, 0.09987371464376338, 0.07307390114874579, 0.07079513670760207, 0.029041312845947687, 0.06175693575642072, 0.11683061646181159, 0.027064632195106242, 0.046027167700231075, 0.05655350461893249, 0.05004466169339139, 0.021499988506548107, 0.0384929030406056, 0.09496364335063845, 0.07098947549820878, 0.03579310709028505, 0.03407640448131133, 0.04995857256290037, 0.004643489992304239, 0.025779039460758213, 0.024059481438598596, 0.057317400933243334, 0.031237092189257964, 0.02394880124484189, 0.054524710358236916, 0.05489165043400135, 0.027416026132414117, 0.04798307934834156, 0.06239242939045653, 0.04209128026559483, 0.06001348985591903, 0.06104611784394365, 0.05416025647718925, 0.059368326037656516, 0.049274471966782585, 0.07171775985625573, 0.04855802486417815, 0.0478694231424015, 0.08852028011460789, 0.10885518582654186, 0.1092675601830706, 0.10051220655441284, 0.2757041511358693, 0.02888090690248646, 0.04980918194632977, 0.0718040567880962, 0.08666740453918464, 0.08461100980639458, 0.049569330949452706, 0.1763775700237602, 0.015187028038781136, 0.041793589989538305, 0.049879300058819354, 0.057994287853944115, 0.06528080877615139, 0.06642634340096265, 0.09603371639968827, 0.12890141835669056, 0.09443490765988827, 0.07821318475180306, 0.0952986636548303, 0.06865458984975703, 0.05700032947061118, 0.06814670108724385, 0.012814213077945169, 0.039018729512463324, 0.015665460960008204, 0.05776562844403088, 0.04714780327049084, 0.02003956433327403, 0.08063104993198067, 0.06888429939863272, 0.025968301961256657, 0.0203687606335734, 0.03427386771363672, 0.046392315489356406, 0.031535198068013415, 0.053701635188190266, 0.024778093757049646, 0.01986919691262301, 0.07841244398150593, 0.01992313249502331, 0.023585787130286917, 0.06293675760389306, 0.07320445976802148, 0.02153795492631616, 0.013182316470192745, 0.055032844029483385, 0.028536645004351158, 0.038758944428991526, 0.06053321216313634, 0.048414983320981264, 0.019910586488549598, 0.05496953883266542, 0.059530065991566516, 0.08520722156390548, 0.036789095247513615, 0.03216715165763162, 0.040489532620995305, 0.03286353108705953, 0.040437560019199736, 0.021337101934477687, 0.0014094951006882184, 0.04428204083524179, 0.08037753970711492, 0.0375160660041729, 0.008291831381939119, 0.05232898853137158, 0.005470753194458666, 0.02481337360222824, 0.08565343785448931, 0.06963728243135847, 0.006903608900756808, 0.032106232465594076, 0.04562393660307862, 0.005155227254363126, 0.03945143129385542, 0.07361534982919693, 0.03347848207340576, 0.05202724983973894, 0.04841382185986731, 0.0664329485152848, 0.02484674427250866, 0.0478532443230506, 0.015378764674096601, 0.05983276205370203, 0.03382710965524893, 0.020632371488318313, 0.02729077201365726, 0.022705614828737453, 0.020919603048241697, 0.029957629594719037, 0.06218368551344611, 0.021545966410485562, 0.0340093737031566, 0.023175971327873413, 0.03668812605610583, 0.02299378891621018, 0.02803613133437466, 0.02855588147212984, 0.03460252039076295, 0.022875987815496046, 0.01360912281597848, 0.023267045835382305, 0.08490567954140715, 0.04620830368367024, 0.02310458785359515, 0.02397019179625204, 0.036855966463917866, 0.07019676530035213, 0.009104997025133343, 0.05635008565150201, 0.027451552741695195, 0.05489327202667482, 0.010238187878712779, 0.015686575061408803, 0.044306654162937775, 0.03142547524475958, 0.06221033603651449, 0.035657987973536365, 0.04000156681286171, 0.058652788065955974, 0.017732819069351535, 0.019502529576129746, 0.01956703890755307, 0.017144552002719138, 0.02337468136829557, 0.01958569835551316, 0.03542015561833978, 0.037993281803210266, 0.10459700963110663, 0.008000233210623264, 0.040620184008730575, 0.019784935320785735, 0.036225660442141816, 0.07014596529188566, 0.054650367092108354, 0.012206931260152487, 0.026927396102109924, 0.022274564325925894, 0.0292248942059814, 0.028014516283292323, 0.07133631821488962, 0.03181335130648222, 0.011539546612766571, 0.018206377935712226, 0.042622620894690044, 0.07904804893769324, 0.08889835982699879, 0.06334431542200036, 0.02040685878455406, 0.053452622378244996, 0.02732003489654744, 0.04421991194249131, 0.014475506941380445, 0.039311362052103505, 0.026575872288958635, 0.03410929275560193, 0.03901662181306165, 0.08703942832653411, 0.10134544543689117, 0.031000855451566167, 0.04153593486989848, 0.06572528844117187, 0.023358448743238114, 0.1489054597914219, 0.048786695406306535, 0.047736504493514076, 0.04861543740844354, 0.061654040691792034, 0.017515158288006205, 0.04492626954743173, 0.05186519447306637, 0.05036620830651373, 0.02430084456136683, 0.04559405402687844, 0.11971819432801567, 0.15989892301149666, 0.1703425735468045, 0.059592677280306816, 0.06886941933771595, 0.03273188151069917, 0.03678222667076625, 0.15046926884679124, 0.06981190977967344, 0.18271891021868214, 0.05605998754617758, 0.05164584159501828, 0.09575595278874971, 0.07472759170923382, 0.07216900048661046, 0.11214806538191624, 0.0919373580836691, 0.1285182178253308, 0.04808384444913827, 0.08700092570506968, 0.17918340774485841, 0.08273894971353002, 0.03171887590724509, 0.2247027534758672, 0.053684120503021404, 0.03786536522966344, 0.02240266458102269, 0.03921510178770404, 0.08978740821476094, 0.022925572557142004, 0.03864251630147919, 0.015828970936127007, 0.028551766263262834, 0.020804668492928613, 0.07090841812896542, 0.015131966247281525, 0.06529298741952516, 0.10775804665172473, 0.006387874245774583, 0.037502072809729725, 0.019343427957210224, 0.03059464092075359, 0.029772799571219366, 0.029190230343374424, 0.017033005351549946, 0.08313881888170727, 0.06419987068511546, 0.019247982199885882, 0.025811322884692345, 0.02807755059620831, 0.027285569558443967, 0.07178732135798782, 0.029780783224850893, 0.04667212000640575, 0.03841970130451955, 0.05148952674062457, 0.021716168703278527, 0.024804532768030185, 0.0585283781401813, 0.03604221637942828, 0.06334100544336252, 0.022708167816745117, 0.06963633248233236, 0.022426964351325296, 0.040892618999350816, 0.025106089633482043, 0.03501005965517834, 0.0792488592560403, 0.08083513312158175, 0.022564545542991254, 0.01613404558156617, 0.053716470720246434, 0.019822074245894328, 0.06212268468516413, 0.05098957153677475, 0.02485675213392824, 0.07378509384579957, 0.09428955061594024, 0.04657970406697132, 0.046555465523852035, 0.020140292326686904, 0.03563346741429996, 0.007459569815182476, 0.03640918614109978, 0.030102832643024158, 0.019038015634578187, 0.03546626896422822, 0.023076247089193203, 0.027555327251320705, 0.009658339549787343, 0.002047050629698788, 0.0646790605969727, 0.10154042247449979, 0.13046490086708218, 0.1265844629961066, 0.14320399932330474, 0.08199093164876103, 0.1337156115914695, 0.11932593959500082, 0.19593247852753848, 0.17474619584390894, 0.08365740941371769, 0.13702892989385873, 0.20067165547516197, 0.20663227391196415, 0.19181357376510277, 0.09650586333009414, 0.07052718428894877, 0.14114584570052102, 0.20085506985196844, 0.07680676295422018, 0.1860025426140055, 0.07365546291111968, 0.1039339006820228, 0.09656714246375486, 0.25059851235710084, 0.13637192139867693, 0.20048527250764892, 0.1480074759456329, 0.20064667478436604, 0.17744657438015565, 0.16960164299234748, 0.14496830699499696, 0.08465094477287494, 0.14985641813836992, 0.12882539274869487, 0.05383060190069955, 0.14454455551458523, 0.16439909872133285, 0.07041776203550398, 0.18524849088862538, 0.13135478046024218, 0.1330412071547471, 0.10127192086656578, 0.0770499870122876, 0.16331183753209189, 0.15554281300865114, 0.2276719972724095, 0.16113678080728278, 0.11827054622699507, 0.1184540125541389, 0.24106182565446943, 0.16119652369525284, 0.1530571823241189, 0.17370021290844306, 0.13110837258864194, 0.2075625114957802, 0.16012118139769882, 0.19273769605206326, 0.17489671823568642, 0.13507990166544914, 0.10266214900184423, 0.1449408772168681, 0.13797295658150688, 0.0901970811537467, 0.05554957548156381, 0.20780324935913086, 0.11945867270696908, 0.15839371393667534, 0.18462924286723137, 0.30357129173353314, 0.17922916857060045, 0.1118966776994057, 0.15715177432866767, 0.1466325286310166, 0.3563353494973853, 0.28156213054899126, 0.2027517618262209, 0.13379539246670902, 0.30728909536264837, 0.1586519367992878, 0.1906873646657914, 0.19580153399147093, 0.1642919474397786, 0.23131784226279706, 0.21027526905527338, 0.3632930730236694, 0.37312284868676215, 0.3015951899578795, 0.1581423485185951, 0.2333987204474397, 0.2852327038999647, 0.20581659424351528, 0.21067565772682428, 0.11523584500537254, 0.3196546412073076, 0.23729026084765792, 0.18005874124355614, 0.20547695778077468, 0.24125568947056308, 0.20183834130875766, 0.18617881753016263, 0.18647785851499066, 0.3727882291423157, 0.30508019670378417, 0.19917213125154376, 0.2749813289847225, 0.3128687397111207, 0.2307248068973422, 0.27229567465838045, 0.16290107363602147, 0.15675699629355222, 0.0953508514794521, 0.1382036309223622, 0.18407723342534155, 0.1808187598362565, 0.18482487299479544, 0.15482865914236754, 0.1386983465636149, 0.1656763645587489, 0.18921527022030205, 0.16634823085041717, 0.13280152314109728, 0.17017057340126485, 0.08339408799656667, 0.10757256910437718, 0.17222663416760042, 0.14055757492315024, 0.12597323016962036, 0.17847020382760093, 0.12318806868279353, 0.12364573631202802, 0.10368270595790818, 0.12132783842389472, 0.0682465273712296, 0.10136580254766159, 0.14299306611064821, 0.15734807238914073, 0.08934836849221028, 0.12427212379407138, 0.1401888017426245, 0.2319409791380167, 0.14307019009720534, 0.14463515690295026, 0.18704414687817916, 0.10559342452324927, 0.14502094010822475, 0.08935777892475016, 0.16577535221586004, 0.08133085066219792, 0.12521548254881054, 0.08195133807021193, 0.13565263187047094, 0.13980730815092102, 0.13246923394035548, 0.12118176891817711, 0.11727895529475063, 0.10108883303473704, 0.15372936031781137, 0.15510594035731629, 0.20269798580557108, 0.16943666356382892, 0.08655916972202249, 0.13764172123046592, 0.1212641695747152, 0.08511542531778105, 0.11821464766399004, 0.08084517437964678, 0.14816163486102596, 0.11402451156754978, 0.09777422339539044, 0.09534164884826168, 0.1865617954172194, 0.12099535626475699, 0.13829248084221035, 0.19371713802684098, 0.09727240540087223, 0.26050918211694807], [0.10160000951145776, 0.0413437371753389, 0.04695307485235389, 0.021122053512954153, 0.08667176094604656, 0.06311570425168611, 0.042059460683958605, 0.019723210898519028, 0.06549269935931079, 0.03077991437749006, 0.01426384271326242, 0.0268700577726122, 0.04937809433613438, 0.04473879191209562, 0.03124235401628539, 0.0406217722047586, 0.021740321899414994, 0.03841883299173787, 0.03742441076610703, 0.06800547780585475, 0.053862859349465, 0.04332779106334783, 0.01704447338852333, 0.01790542035450926, 0.012434759464667877, 0.00901164319657255, 0.058187917893519625, 0.056098631175700575, 0.01597417583980132, 0.03019803720235359, 0.06961626480915584, 0.021827206983289216, 0.029609495541080832, 0.07988113939063624, 0.08198890558560379, 0.01897735990496585, 0.017592478943697643, 0.026132711791433394, 0.024217134014179464, 0.10995808406732976, 0.03336913032399025, 0.06846724209026434, 0.093074959149817, 0.0465779377555009, 0.10421327475341968, 0.047214585429173894, 0.040778068505460396, 0.04515491411439143, 0.011622838774201227, 0.03025659822014859, 0.08958432692452334, 0.03809109315625392, 0.05701999267330393, 0.05505276327312458, 0.06420184479793534, 0.06137297452369239, 0.024891217472031713, 0.13856560603016987, 0.03138096864859108, 0.029374312653089873, 0.023257557477336377, 0.11156471504364163, 0.05540178419323638, 0.01805456049623899, 0.029622227084473707, 0.010313993625459261, 0.02861276523617562, 0.04783506170497276, 0.039102777736843564, 0.03195190285623539, 0.06737503077602014, 0.0641437346348539, 0.07118599620298482, 0.0328775910747936, 0.057884405468939804, 0.06406042113667354, 0.02294468471518485, 0.014062625141377794, 0.053315543991629966, 0.05992265840177424, 0.009186319712171098, 0.03399696128326468, 0.09811685071326792, 0.03923531046893913, 0.08640036496217363, 0.13769527460681275, 0.06925417837919667, 0.0622794299852103, 0.04477168760786299, 0.01173714528704295, 0.0651884930266533, 0.01129018221035949, 0.03132807949441485, 0.058067641730303876, 0.04417493779328652, 0.023170037857198622, 0.0647249624307733, 0.020248169057595078, 0.013709256163565442, 0.07910047424957156, 0.06379873986588791, 0.16552248765947297, 0.05442524401587434, 0.13162008341168985, 0.03590418062231038, 0.07678352631046437, 0.014279621700552525, 0.025370668990944978, 0.025733670117915608, 0.11870145201100968, 0.043220532170380466, 0.011718129608198069, 0.03766144160181284, 0.031154762036749162, 0.040863537942641415, 0.017969415748666506, 0.05982935559586622, 0.07426024647429585, 0.014366141276695998, 0.010943292181764264, 0.06800479502999224, 0.007973249648784986, 0.037227355715003796, 0.06519739879877307, 0.026833675838133786, 0.06550798760144971, 0.06099296151660383, 0.048151086739380844, 0.060048170416848734, 0.04624354456609581, 0.01009998699373682, 0.018757789948722348, 0.03549519045918714, 0.021595061334664933, 0.03832338537904434, 0.006006056892147171, 0.0038252415652095806, 0.03711712823132984, 0.028268154528632294, 0.05787695059552789, 0.021784861892228946, 0.03597188675485086, 0.022861356374050956, 0.021212842293607537, 0.03620292103732936, 0.02672488997632172, 0.013504324142559199, 0.014707339032611344, 0.022595884584006853, 0.04333958750066813, 0.049200409339391626, 0.04917718753858935, 0.019900292900274508, 0.0443522851128364, 0.04366688575828448, 0.05059688264736906, 0.032255634214379825, 0.061684476168011315, 0.03293508525530342, 0.08586535812355578, 0.06925364403286949, 0.02263542621221859, 0.0980544880439993, 0.07696297019720078, 0.032826438546180725, 0.017417534327250905, 0.007714710909567657, 0.05052336920925882, 0.026366497586423066, 0.022888645144121256, 0.03507749119307846, 0.054458239901578054, 0.027722468184947502, 0.029084424204484094, 0.06116200049291365, 0.03449201460171025, 0.11127842415589839, 0.03695428247738164, 0.06986714040976949, 0.02020002964854939, 0.12485683226259425, 0.05719199652958196, 0.05187553630094044, 0.02062018171272939, 0.07404845237033442, 0.03527112123265397, 0.030301414662972093, 0.05324522921000607, 0.03292802372016013, 0.03065357857849449, 0.019927312641812023, 0.021513358296942897, 0.0023547689443148556, 0.06812553503550589, 0.03994909697212279, 0.049610813293838874, 0.07163506234064698, 0.008980209531728178, 0.018925342774309684, 0.03729264244611841, 0.036460913834162056, 0.06008536685840227, 0.029863109666621312, 0.015913525676296558, 0.01900129787827609, 0.005422481590358075, 0.048993223972502165, 0.07573637820314616, 0.004461193011593423, 0.06953970485483296, 0.08815706562018022, 0.027586094838625286, 0.08900998625904322, 0.015357598622358637, 0.028660416683123913, 0.07731063669780269, 0.02332193878828548, 0.020892943248327356, 0.055867611736175604, 0.03447038841841277, 0.06909878749866039, 0.037796274991706014, 0.010572389037406538, 0.10148816043511033, 0.032511645476915874, 0.05548222557990812, 0.06860740410047583, 0.02956546206405619, 0.020264253253117204, 0.04624783046892844, 0.06230287443031557, 0.03578666153771337, 0.04754564266477246, 0.1156501415243838, 0.006022327552273055, 0.022533408737217542, 0.04794590888195671, 0.06335069047054276, 0.09386695688590407, 0.06711217691190541, 0.005335262076187064, 0.052319529859232716, 0.038398249525926076, 0.09297257987782359, 0.03479266233625822, 0.05576679097430315, 0.02010083419008879, 0.02834099632309517, 0.03187368049111683, 0.06307210307568312, 0.03534215960826259, 0.00995935650280444, 0.023540137626696378, 0.09535434699500911, 0.02941848899354227, 0.026193911144218873, 0.05548219589400105, 0.06950469774892554, 0.06813858199166134, 0.0014643988379248185, 0.04437438998138532, 0.10325748502509668, 0.08880605149897747, 0.05920061550568789, 0.05330381063686218, 0.08827712284983136, 0.030845659384795, 0.07385884848190472, 0.0738257412740495, 0.05208802060224116, 0.051626256317831576, 0.024612726556370035, 0.05524514279386494, 0.014111403725109994, 0.06887706345878541, 0.05376253211579751, 0.07366908874246292, 0.12941673601744696, 0.10391043397248723, 0.0187709686360904, 0.01063079234882025, 0.03541720929206349, 0.035994871068396606, 0.03319435825687833, 0.02044265071162954, 0.027566049429879058, 0.041113971965387464, 0.0535404407128226, 0.05312676017638296, 0.0551047692715656, 0.03751924981770571, 0.08606341507402249, 0.024237450306827668, 0.08734123010071926, 0.017596221223357134, 0.016604992088105064, 0.04651803530578036, 0.023395893804263324, 0.022619069277425297, 0.012801021402992774, 0.06251218233956024, 0.026210262512904592, 0.04828356752113905, 0.012281993931537727, 0.029762377962470055, 0.019399077900743578, 0.03742619192053098, 0.027127200810355134, 0.03194792123395018, 0.016351492995454464, 0.01808507204259513, 0.014978328690631315, 0.031897191729513, 0.004655757229556912, 0.07822755273082294, 0.05435277700598817, 0.07219962892122567, 0.026489157899050042, 0.020120007575314958, 0.04383698971651029, 0.022239553509280086, 0.022454388563346583, 0.013024293748458149, 0.03236278549593408, 0.05016918294131756, 0.05816882614453789, 0.09125108670559712, 0.03221589591703378, 0.017291564035986084, 0.02952965714939637, 0.013048555483692326, 0.06671746567008086, 0.01519159966846928, 0.04117817145015579, 0.02369871232076548, 0.0449242843023967, 0.0641149615694303, 0.037798928169650026, 0.06759767507901415, 0.05615132366074249, 0.09683246025815606, 0.03231830116419587, 0.037146153626963496, 0.07117397341062315, 0.030303015846584458, 0.06026489609212149, 0.09040880846441723, 0.05789414615719579, 0.031522781937383115, 0.10553227897617035, 0.053268480696715415, 0.011137277524539968, 0.2804791589733213, 0.11004254047293216, 0.1546189875807613, 0.09286528758821078, 0.29897641798015684, 0.11394462679163553, 0.16027844249038026, 0.23771693638991565, 0.13545450812671334, 0.13448937475914136, 0.16617465735180303, 0.1533092898898758, 0.13465297379298136, 0.13545689784223214, 0.2005921269301325, 0.13181189890019596, 0.09365016070660204, 0.0906329890131019, 0.2017886471003294, 0.17079761397326365, 0.18232281116070226, 0.11755989529774524, 0.1127595134312287, 0.13901050871936604, 0.1135912977042608, 0.14757244382053614, 0.13643159007187933, 0.1500814818427898, 0.13662989193107933, 0.1541296747745946, 0.12622646579984576, 0.14572964661056176, 0.08989246663986705, 0.12337451844359748, 0.15044770203530788, 0.16536559764062986, 0.1400049717631191, 0.1676460393355228, 0.08988718254840933, 0.21455726819112897, 0.08898632659111172, 0.13374213594943285, 0.12605068070115522, 0.3448946087155491, 0.16728744842112064, 0.08411487666307949, 0.10335841710912064, 0.14177275268593803, 0.2156618214212358, 0.1462337133125402, 0.17064743296941742, 0.09452083351789042, 0.1607527193846181, 0.2860505209537223, 0.17655516596278176, 0.21418804972199723, 0.18329069047467783, 0.1777450364897959, 0.09970276092644781, 0.1727686691447161, 0.10060026237624697, 0.2351125472341664, 0.21371525712311268, 0.12907956348499283, 0.17233721417142078, 0.1429836853640154, 0.0715251280053053, 0.15515103325014934, 0.1401429667021148, 0.1730892769410275, 0.299526319722645, 0.13863054395187646, 0.17710244050249457, 0.2335413612308912, 0.2717517694691196, 0.11063671132433228, 0.08324967348016798, 0.3136620362056419, 0.1944054799969308, 0.27024316135793924, 0.1453570884768851, 0.19968982378486544, 0.1999037404311821, 0.2805024920962751, 0.28690761246252805, 0.3114011575235054, 0.21809725323691964, 0.16021176794311032, 0.1109510034439154, 0.22806540975579992, 0.19609579554526135, 0.14376142644323409, 0.14671078068204224, 0.09757589927176014, 0.06950137292733416, 0.11489932556287386, 0.09691048224340193, 0.0907856562116649, 0.2409105165861547, 0.24362201249459758, 0.2621346933301538, 0.20599058334482834, 0.19233528873883188, 0.13061460689641535, 0.09298219811171293, 0.1297262858133763, 0.09864690742688254, 0.0962322112172842, 0.1707940813503228, 0.24936449888627976, 0.1672799972584471, 0.16057470784289762, 0.1276245978078805, 0.1646280661225319, 0.1361476443707943, 0.31905837007798254, 0.16487962449900806, 0.16639758367091417, 0.1286733860615641, 0.12868778372649103, 0.17520833120215684, 0.1335956805269234, 0.1072086495696567, 0.14999304752564058, 0.1475135172950104, 0.1361032936256379, 0.17128358711488545, 0.12454901909222826, 0.14625798154156655, 0.07614447036758065, 0.10010150203015655, 0.08386912930291146, 0.07625024125445634, 0.06638375896727666, 0.10618041880661622, 0.08191850545699708, 0.14577422000002116, 0.09029773864313029, 0.14608072699047625, 0.2277626283466816, 0.19946125714341179, 0.13791699864668772, 0.12144366541178897, 0.10290730264387093, 0.11752880673157051, 0.10654123616404831, 0.14635689498391002, 0.10938530933344737, 0.08744985825615004, 0.1342787384055555, 0.21812420804053545, 0.18312790780328214, 0.1960183895425871, 0.22383608826203272, 0.07753524769213982, 0.10730342924944125, 0.11588158027734607, 0.21270443714456633, 0.11060050936066546, 0.18056343134958297, 0.16931345220655203, 0.12308801233302802, 0.2507507713744417, 0.19469496211968362, 0.16138835402671248, 0.12864882097346708, 0.1145553623791784, 0.13674062036443502, 0.08599256223533303, 0.10656957878381945, 0.18246180057758465, 0.18874344241339713, 0.13917829346610233, 0.22889645188115537, 0.1860179050709121, 0.1755189645336941], [0.07393353822408244, 0.05700090463506058, 0.01793757390259998, 0.02336087556614075, 0.03789300280914176, 0.0505272024020087, 0.05757684833952226, 0.018938499197247438, 0.052336821900098585, 0.0804923425312154, 0.032040775040513836, 0.0295466040915926, 0.0339542432629969, 0.04642055049771443, 0.05368474390706979, 0.03483830441837199, 0.03837218901026063, 0.02783915235340828, 0.05704707364202477, 0.020753393509949092, 0.08029460470424965, 0.019193426924175583, 0.01582177766977111, 0.04474460663914215, 0.0369390870037023, 0.018292786189704202, 0.020064391028427053, 0.024597213814558927, 0.035977245061076246, 0.05059919072664343, 0.04956764627422672, 0.04243756637151819, 0.04206047371553723, 0.06136228017567191, 0.054800173311377876, 0.005965947984805098, 0.02564831756899366, 0.06012378784362227, 0.013476449075824348, 0.0697463410324417, 0.04483557539060712, 0.021709348366130143, 0.0067547419621405425, 0.03049147126148455, 0.017678722069831565, 0.017674970513326116, 0.07007166146649979, 0.07305804145289585, 0.03454628415056504, 0.0713344183168374, 0.04981152342224959, 0.007712175083725015, 0.052875160981784575, 0.029360748048929963, 0.04088441455678549, 0.015075019400683232, 0.05365690965845715, 0.04340980951383244, 0.004811858252651291, 0.03422650013817474, 0.024440902670903597, 0.045042489873594604, 0.07196302482043393, 0.04156926843279507, 0.03195050019712653, 0.030205924376787152, 0.08838320543873124, 0.026705998607212678, 0.04410787361848634, 0.03738600091310218, 0.046583544681197964, 0.014574924116459442, 0.030761561065446585, 0.029254416840558406, 0.03197929552698042, 0.053327603891375475, 0.050886390745290555, 0.026704243427957408, 0.03293555280833971, 0.0345720774930669, 0.014910337758919923, 0.021762417491117958, 0.033651280027697794, 0.01316763307841029, 0.04851558514928911, 0.01899616778246127, 0.08607753814430907, 0.047572504699928686, 0.02155399644834688, 0.015280586885637604, 0.05814424621348735, 0.02879898493119981, 0.05540929843846243, 0.049763328352128156, 0.024087927959044464, 0.016137401944433805, 0.05408122146036476, 0.036805975396418944, 0.05161599241546355, 0.01937040316988714, 0.09116286018979736, 0.08693096344359219, 0.07486261805752292, 0.05767433685832657, 0.06201921445608605, 0.043797967591672204, 0.02502305815141881, 0.07133821069146506, 0.02430590600852156, 0.040608777198940516, 0.04867689094680827, 0.04067655012477189, 0.03153756551910192, 0.036260867927921936, 0.06130036279500928, 0.056738128696451895, 0.028116626526752952, 0.07410931590129621, 0.014876614568493096, 0.1396343728993088, 0.03549034423485864, 0.03405252587981522, 0.014002102070662659, 0.03026504386070883, 0.0064645891234249575, 0.026630050924723037, 0.04375546850496903, 0.019662991180666722, 0.036227849777787924, 0.06747501291101798, 0.06808942955103703, 0.024763475303188898, 0.03423018861212768, 0.07295782183064148, 0.03905375146132428, 0.033632140039117076, 0.03829786663118284, 0.047205854061758146, 0.023200799878395628, 0.017924133608175907, 0.07601936653372832, 0.03295653703389689, 0.04306836592149921, 0.016045846896304283, 0.06619552805204876, 0.021306128401192836, 0.06046194372174796, 0.037776767640025355, 0.09523954417090863, 0.0730015491717495, 0.04275127219443675, 0.03987471522123087, 0.07903512072516605, 0.11591009359108284, 0.02744159868598217, 0.0573520221223589, 0.012522139004431665, 0.07323171885218471, 0.10295290019712411, 0.018059210051433183, 0.03918307811545674, 0.04585264054185245, 0.01830501678341534, 0.0300461214283132, 0.06486582205980085, 0.0018994516040038434, 0.02287950374011416, 0.06114923184213694, 0.012900856036139885, 0.07943843345856294, 0.041031337532331236, 0.01680555935308803, 0.04258785869751591, 0.012187590891699074, 0.0469894809066318, 0.04679267447500024, 0.06118941913882736, 0.03702651571074966, 0.038630998169537634, 0.013086294620734407, 0.035042498930124566, 0.02666924559889594, 0.048420608800370246, 0.03841903708234895, 0.015070948720676824, 0.11253409349592403, 0.06678978053969331, 0.09323918158770539, 0.02998380885401275, 0.020197088888380677, 0.037277524897945113, 0.02315468096639961, 0.01604381341167027, 0.036526553085423075, 0.0070324763510143384, 0.07534755219239742, 0.04907681577606127, 0.032905748157645576, 0.04157968447543681, 0.0344989091536263, 0.01316163745286758, 0.06335871308692731, 0.04652595402149018, 0.019231666083214805, 0.030539117142325267, 0.09505610752967186, 0.02942860075563658, 0.02454209821735276, 0.06304384209215641, 0.046297847511596046, 0.023210737235785928, 0.022479968538391404, 0.031609709694748744, 0.027157942422491033, 0.015941463825583924, 0.02270991557452362, 0.027171781621291302, 0.038374137147911824, 0.019314322780701332, 0.033518780692247674, 0.043662484822561964, 0.07155054656323045, 0.0442617208318552, 0.027996526623610407, 0.013966207170597045, 0.03398042252229061, 0.07705311145400628, 0.03537790515110828, 0.031522288409178145, 0.04735917435027659, 0.04969649053236935, 0.06480695490608923, 0.05453170138935093, 0.017685700113361236, 0.03533038172463421, 0.05130413454025984, 0.03991954094090033, 0.03941099166695494, 0.02735099729761714, 0.011907677835552022, 0.00892194258995005, 0.01717732895485824, 0.10801171272760257, 0.03288959902420174, 0.0819623886491172, 0.06611585849896073, 0.02087228185700951, 0.041866472602123395, 0.03344727476360276, 0.025426747524761595, 0.07383996824501082, 0.07345014775637537, 0.05989263110677712, 0.0695458275731653, 0.0014128650309430668, 0.02481567982613342, 0.01666417836531764, 0.09914538575685583, 0.03294625086709857, 0.04126917359826621, 0.07489398863981478, 0.08460206692689098, 0.03624848890467547, 0.08856457890942693, 0.014233296842576237, 0.035853903827955946, 0.10097312479047105, 0.03609299041272607, 0.03683248862216715, 0.026477777064428665, 0.047074167378013954, 0.054479116515722126, 0.008473129710182548, 0.042428085434949026, 0.07438278247718699, 0.03703495021909475, 0.04651607603591401, 0.04403835293487646, 0.057914978242479265, 0.0440020248061046, 0.033479706617072225, 0.06504836812382564, 0.05916355636145454, 0.0060727949858119246, 0.06685059212031774, 0.035342404516995884, 0.09449748555198312, 0.03566171355487313, 0.014418209430004936, 0.053669258995796554, 0.050930296201840974, 0.06359361766953953, 0.023919111627037637, 0.025128756678896025, 0.017857104685390368, 0.07875504161347635, 0.039994171311263926, 0.03385156342119444, 0.016420408828707878, 0.017801916728785727, 0.05953437415882945, 0.033292904336121865, 0.05496550897078123, 0.025100764723902103, 0.03245141648221761, 0.037878913135500625, 0.008983205025288044, 0.025506353995297104, 0.023278122389456257, 0.026841893268283457, 0.004263953351255623, 0.028243431734154, 0.06103761283156928, 0.03704866881889757, 0.0947744253790006, 0.020676432795880828, 0.048549330604146235, 0.015762899383844342, 0.03221424834919162, 0.020679457047663163, 0.07239867292810231, 0.029830323437636252, 0.0332847741083242, 0.013877801611670293, 0.023533764433523174, 0.05636334411974531, 0.06600484804948792, 0.01844144208007492, 0.0809222538373433, 0.04568816948449239, 0.01851767548942007, 0.04788514183019288, 0.053430691914400086, 0.022829059962532483, 0.038171638443600386, 0.008624495367257623, 0.036704954254673794, 0.04449464388017077, 0.013089047988614766, 0.04634518540115096, 0.054577521586907096, 0.013051018486294197, 0.0147822430699307, 0.03434698410273995, 0.03239312078221701, 0.06923275257577188, 0.07781505220918916, 0.0368224510748405, 0.03259900739067234, 0.046784406949882396, 0.042476180315134116, 0.06048166258551646, 0.12195605158922262, 0.19218105560867116, 0.14208582026185468, 0.09649902072851546, 0.1611520690494217, 0.11984326105448417, 0.15500074834562838, 0.09404632655787282, 0.26357437076512724, 0.20715514663606882, 0.11629566899500787, 0.1582890859572217, 0.13703731616260484, 0.12449938425561413, 0.15410717285703868, 0.13996032415889204, 0.10077100829221308, 0.08489505198667757, 0.11803715562564321, 0.1165660482365638, 0.1723547140136361, 0.12250938205397688, 0.14445735316257924, 0.14273681736085564, 0.1323768959264271, 0.1176988921361044, 0.21640276681864634, 0.12902562419185415, 0.161430508014746, 0.1856896234676242, 0.14525303937261924, 0.11712907857145183, 0.1385424064937979, 0.1458234540768899, 0.13889161666156724, 0.18171104398788884, 0.09714954285300337, 0.15336686570663005, 0.07250002061482519, 0.121600971033331, 0.16801859746919945, 0.10612364450935274, 0.11945027901674621, 0.18415266531519592, 0.19333911768626422, 0.1252539554843679, 0.14581140159862116, 0.09914737471262924, 0.18849954300094396, 0.17146477504866198, 0.14213552931323647, 0.12280117225600407, 0.16168138361535966, 0.08814724700641818, 0.09465900657232851, 0.1807716631446965, 0.2295887569198385, 0.1919803788769059, 0.08975596341770142, 0.1381286294781603, 0.10447065156768076, 0.09451865160372108, 0.20345745520899072, 0.07183921974501573, 0.09087638376513496, 0.1978857073117979, 0.24795162782538682, 0.10972335017868318, 0.26580342615488917, 0.1312909260741435, 0.18614515371154994, 0.10868561992538162, 0.13039988873060793, 0.0976702113985084, 0.2435448142932728, 0.14875861845212057, 0.21162582939723507, 0.09426320437341928, 0.13653083005920053, 0.22092305473051965, 0.13842186686815694, 0.18239613535115495, 0.1599743845872581, 0.09482073539402336, 0.143415036436636, 0.25194515415932983, 0.2128825822728686, 0.2098796598147601, 0.21969290042761713, 0.10102253698278219, 0.22568633663468063, 0.12489526066929102, 0.2292153230519034, 0.14437843317864463, 0.061796811351086944, 0.1406951987883076, 0.15772448969073594, 0.17386755236657336, 0.15371655084891245, 0.17339783225907013, 0.28272822266444564, 0.13518228835891932, 0.1500209077494219, 0.1747669166070409, 0.1624860052834265, 0.16284351266222075, 0.14883229887345806, 0.2517673949478194, 0.13069795008050278, 0.11871331895235926, 0.1960968939238228, 0.09856904871412553, 0.1873512624297291, 0.18320930656045675, 0.09996497654356062, 0.16739390208385885, 0.16700341366231441, 0.1697759289527312, 0.09823312298976816, 0.18924881529528648, 0.13350251130759716, 0.18090915342327207, 0.09936739181284793, 0.13955177186289802, 0.12441996703273617, 0.1946174819022417, 0.07993642939254642, 0.25097285164520144, 0.13358701224206015, 0.09284032174036838, 0.12160873389802873, 0.16188675072044134, 0.10830716171767563, 0.17618712008697912, 0.16464899468701333, 0.17715317371767014, 0.15884841297520325, 0.08322060355567373, 0.23357518832199275, 0.08185211292584427, 0.17067060281988233, 0.090812855924014, 0.14108613249845803, 0.12896703905425966, 0.18809830828104168, 0.10679534752853215, 0.1554475657758303, 0.14857634698273614, 0.145916786568705, 0.16616294626146555, 0.26067871833220124, 0.10586266827885993, 0.24652266700286418, 0.15292579249944538, 0.13137700036168098, 0.15841358865145594, 0.1079672877676785, 0.20245237945346162, 0.18496007745852694, 0.06736449227901176, 0.14700896077556536, 0.1479161620954983, 0.07371257117483765, 0.09599954049917869, 0.1589517793036066, 0.10401319173979573, 0.13340686331503093, 0.20111580117372796, 0.06654089389485307, 0.1631774939596653, 0.09386292702401988, 0.1318898392491974, 0.07177866791607812, 0.16347628261428326, 0.18409256619634107, 0.1886805082904175], [0.07206213122117333, 0.003639584742813895, 0.011764066694013309, 0.049463511822978035, 0.06251916594919749, 0.062296937248902395, 0.02649283895152621, 0.027849048892676365, 0.03239253819629084, 0.017185783872264437, 0.0543423683848232, 0.016331660954165272, 0.031190592926577665, 0.022017638366378378, 0.020693390870292205, 0.02174618115532212, 0.049083895864896476, 0.05313716137607116, 0.03936057757528033, 0.023869870128692128, 0.05313442656188272, 0.020948223973391578, 0.07151646714191884, 0.04512249339313712, 0.042049742260132916, 0.032908052526181564, 0.04458874449483119, 0.034514705766923726, 0.011266722922300687, 0.0511915136303287, 0.019071202623308636, 0.0175512786154286, 0.03859859600197524, 0.04691392656241078, 0.09483089539571665, 0.012825393532693852, 0.040635605837451294, 0.03071130096941488, 0.06643227316089906, 0.01580166361236479, 0.06421728889108635, 0.01242016513060662, 0.01833049285778543, 0.036765550612472, 0.023036397469695657, 0.04404251267260406, 0.05225766813964583, 0.03276577168435324, 0.04273187616490759, 0.04390076617710292, 0.060858116994495504, 0.012143356107117143, 0.03668043740617577, 0.03150627286231611, 0.02927597251982661, 0.016295317982439883, 0.08185387923731469, 0.031230976892402396, 0.03319242125144228, 0.02760618292086292, 0.08243807562394068, 0.03145266011415515, 0.03955949912779033, 0.07906036858912557, 0.0702622375683859, 0.017217193417309318, 0.09395451546879485, 0.026553644966043066, 0.02154905188945122, 0.04373001283966005, 0.0736772375239525, 0.016329274949384853, 0.03248446802899707, 0.033410048636142164, 0.016151165073097218, 0.020253315851732623, 0.06895161219290458, 0.06245344135095365, 0.051636112038977444, 0.07729108110652305, 0.0023807867864888976, 0.026382032592664473, 0.029478309807018377, 0.029006858640059363, 0.05001738034479786, 0.03789929251070134, 0.055973360358620994, 0.07573287526611239, 0.03263792190409731, 0.07069305429467931, 0.01840956127125537, 0.044685019602184184, 0.025448264241276775, 0.07723046990577132, 0.10253740139887668, 0.047045501924003474, 0.011035062452720013, 0.054745328598073684, 0.033056170359486714, 0.061581046757055447, 0.032969665626296774, 0.06849876110209152, 0.01683745314949192, 0.030305815598694608, 0.031181397716864012, 0.09580985497450456, 0.035296569476486184, 0.03924309559806716, 0.015093669571797363, 0.013035114261583658, 0.014599246151192347, 0.07074018809362315, 0.025554346830176655, 0.04351530209532939, 0.02882995475374628, 0.02473219563398743, 0.03529620953486301, 0.030045267958485056, 0.03269723063567653, 0.03801240323809907, 0.06400473779649474, 0.030367159670277033, 0.019771326187765226, 0.028525303132482804, 0.07729555625701323, 0.11959114606725052, 0.022049114704714157, 0.052835352180409245, 0.059093056042911485, 0.04601117812853772, 0.003859241205645958, 0.013001653605897445, 0.05957401226623915, 0.01214789155710605, 0.015416131809615763, 0.049305434367852286, 0.01661474019783782, 0.03089195270149503, 0.01671179084951291, 0.008559894195059314, 0.04120974241232034, 0.020899572482449003, 0.07904997110017575, 0.015974225934769493, 0.06278521846979856, 0.007137236525522894, 0.05374353684601374, 0.022428097981901374, 0.029364113688643556, 0.013750249618169619, 0.011550953422556631, 0.0175157130433945, 0.013229759188106982, 0.07901606237282977, 0.03232890274375677, 0.034154125896748155, 0.08466770988889039, 0.060123554067104124, 0.013364924689085456, 0.06005859759170562, 0.01563040746987099, 0.03342180796607863, 0.045188841395429336, 0.06904206515173428, 0.025219942508556414, 0.024892991204978898, 0.05322836019331589, 0.13851041992893443, 0.07269499023095705, 0.06672306888503954, 0.003828013254860707, 0.018344007366977166, 0.021109511217218824, 0.033777560165617615, 0.020292345398047473, 0.07101991839590482, 0.03597160473873373, 0.08534044449334033, 0.009290107209380949, 0.027616938496066723, 0.07797761223628186, 0.11056799587095156, 0.039493013828177936, 0.0878853134054225, 0.04107218534045387, 0.0735149669344537, 0.04059329228766728, 0.0736781874729786, 0.03819284160272218, 0.035168960894225165, 0.005577020856435411, 0.04334416655183304, 0.02946971944766119, 0.032896497286856174, 0.007344825899053831, 0.041832044371403754, 0.04361701343441382, 0.05335078116331715, 0.007748897014607792, 0.04075953707797453, 0.015145210800255882, 0.0238135503968806, 0.009456905827391893, 0.04294816026231274, 0.046087470909697004, 0.02273699839861365, 0.04375786935270298, 0.06243838317459449, 0.03271370260335971, 0.06526258162921295, 0.01588258739502635, 0.030526125847245567, 0.017758317408151925, 0.021625734298140742, 0.017579949635546654, 0.01496823548222892, 0.012140377311880002, 0.009558901037962642, 0.051291451236465946, 0.06904903391841799, 0.07587740852613933, 0.021343538210203405, 0.03229389934858773, 0.025271388185501564, 0.015729383994766977, 0.00643803693492373, 0.04527608827629592, 0.006031083039488294, 0.04338041675509885, 0.020316433656262234, 0.08244594238931313, 0.07664866323466413, 0.008281406062451424, 0.0543083075172035, 0.014410954008781118, 0.05170369571715128, 0.07232043572003022, 0.018757314974209294, 0.041430920973652974, 0.036613299016607925, 0.027505475336511154, 0.05529474794457201, 0.10908403448411264, 0.011717429206328234, 0.06157068637548946, 0.09497390725300647, 0.09332971618277952, 0.07813154108589515, 0.008491384687658865, 0.04355065058916807, 0.042204353885608725, 0.012052888305333909, 0.029684009023185354, 0.04166474944213405, 0.0150297224172391, 0.0053040079183119815, 0.06119443234638311, 0.06353317716275342, 0.04328097638790496, 0.023333859535341617, 0.02751018611888867, 0.05697674772818573, 0.04114908297196962, 0.0802558200666681, 0.05301843259076122, 0.029769035027129576, 0.16683960682712495, 0.021285168295435142, 0.07459640226443298, 0.05231950759480242, 0.11291634407825768, 0.0515355770039605, 0.004219066868245136, 0.013096578004478943, 0.047980763847590424, 0.034945952938869596, 0.042412466937093996, 0.04370264243334532, 0.088336338812951, 0.08458969532512128, 0.04126772269955836, 0.13114322384353727, 0.08790595253231004, 0.022002648838679306, 0.03311820277303923, 0.01167150418041274, 0.039375672859023325, 0.06575373496161774, 0.025621952772780787, 0.026929234772978816, 0.04074776661582291, 0.030021352249605116, 0.10240895790047944, 0.022457095546997152, 0.05310023210768122, 0.04730682325316593, 0.01828095264500007, 0.007210539843072183, 0.04701507757999934, 0.0533304537384538, 0.034985245947609656, 0.07660929230041802, 0.02424896287266165, 0.1311852887738496, 0.03276609451859258, 0.04337958926043939, 0.010929919608315686, 0.03537713702826295, 0.026946825528284535, 0.0288992008427158, 0.009996128992497688, 0.051333130249986425, 0.03729002637555823, 0.030778387408645358, 0.005529048430616967, 0.016946285395533778, 0.02251351732411422, 0.053684498998336494, 0.048627022333675995, 0.027517939706740435, 0.037849720756639726, 0.04270799756341148, 0.03336613575811498, 0.014632471174991224, 0.01931520593643654, 0.08000585730769671, 0.04481489544559736, 0.012589402631419944, 0.012615439027285902, 0.05106531141791493, 0.04325696419982705, 0.05294178357871715, 0.0646397787204478, 0.031659218366257846, 0.06970488466322422, 0.0694452368770726, 0.02613877884868998, 0.030015782431291882, 0.0260067136696307, 0.0675498585042078, 0.015395687496493338, 0.037668080112780444, 0.04368282709037885, 0.0769780803238973, 0.04811265091120731, 0.055826496754889376, 0.030142326031636912, 0.0485548484721221, 0.03934480693715159, 0.039943378724274226, 0.024232181058323476, 0.01359965950541664, 0.15173371037235484, 0.16204997868044302, 0.1159129582811147, 0.12275573055376299, 0.18241642566863447, 0.1509377421461977, 0.1504889060743153, 0.20629196951631457, 0.11809511735918932, 0.1810829050373286, 0.20645194686949253, 0.17609153146622702, 0.11385122750652954, 0.16209109366172925, 0.08739539203816094, 0.12995601020520553, 0.10468219334143214, 0.13250999269075692, 0.14491778158117086, 0.09925639620632865, 0.20993552869185805, 0.11818144397693686, 0.1468434915295802, 0.17081217491067946, 0.07373302476480603, 0.10191503635724075, 0.1450018520699814, 0.23914479883387685, 0.16477655502967536, 0.14973844634369016, 0.0907507975352928, 0.18755354220047593, 0.13586233311798424, 0.17513315164251253, 0.19773715903284028, 0.09995502434321679, 0.15746862685773522, 0.1319277481525205, 0.2148932236013934, 0.08889701653970405, 0.1404995092889294, 0.15307821478927508, 0.25714900461025536, 0.11568516347324476, 0.1651957942522131, 0.1521105581196025, 0.19370318565052003, 0.12438152378308587, 0.14272889122366905, 0.1291738756117411, 0.1893061536247842, 0.08489243962685578, 0.18644348223460838, 0.09558480611303821, 0.16054690699093044, 0.10586905817035586, 0.16255587106570601, 0.13716581161133945, 0.12915333296405151, 0.2145597618073225, 0.2888467552838847, 0.0731563389126677, 0.085226272494765, 0.18087105156155303, 0.16768259753007442, 0.12210115630296059, 0.19157708098646253, 0.10727464134106413, 0.1538139651529491, 0.16422460495959967, 0.1887133705895394, 0.17401526944013312, 0.15706990059698, 0.13683806435437873, 0.1078991215035785, 0.1055572967743501, 0.18406194518320262, 0.1839192004990764, 0.11996335539151914, 0.16494356794282794, 0.1715558662544936, 0.2466666733380407, 0.0965447370253969, 0.12333726263022982, 0.16519989090738818, 0.30954489775467664, 0.24126193835400045, 0.14970978460041806, 0.14509885077131912, 0.12808205763576552, 0.16024471929995343, 0.11504779220558703, 0.1332453719805926, 0.13350169494515285, 0.24296580551890656, 0.13517936429707333, 0.12528457649750635, 0.1475678276619874, 0.15602384344674647, 0.22580828634090722, 0.08769824766204692, 0.16572263004491106, 0.15160662500420585, 0.12722045386908576, 0.21002498717280105, 0.20087570155737922, 0.16441158164525405, 0.1663831711630337, 0.11932214722037315, 0.0574222478462616, 0.1929012208711356, 0.12322382535785437, 0.135375038953498, 0.09973443578928709, 0.11173142367624678, 0.16621792456135154, 0.2617375849513337, 0.1272078967303969, 0.1625633519142866, 0.299967096070759, 0.1676308549940586, 0.11545734640094452, 0.09755932711414061, 0.11471961450297385, 0.17065451305825263, 0.3270534973125905, 0.07872252070228569, 0.2193640251061879, 0.22779421415179968, 0.13811268814606592, 0.23987449327250943, 0.1979818451218307, 0.14077903178986162, 0.07761790810036473, 0.21214978565694764, 0.13430121063720435, 0.1368997961981222, 0.08484595149639063, 0.0894320679071825, 0.14614021754823625, 0.1049563501146622, 0.1645015151007101, 0.20871165295829996, 0.10849868034711108, 0.13963947887532413, 0.09034176284330897, 0.12411193863954395, 0.08085363486316055, 0.18958790256874636, 0.16026523226173595, 0.131785552657675, 0.05994470018777065, 0.10340005901525728, 0.18617144058225676, 0.13898060016799718, 0.10529671388212591, 0.22578223695745692, 0.2283774976967834, 0.14725792163517326, 0.1507146970834583, 0.22532655828399584, 0.11377976610674523, 0.14151583600323647, 0.1344794745091349, 0.1164569376851432, 0.16640451533021405, 0.11174121260410175, 0.18158407736336812, 0.19745903176954016, 0.2642244327580556, 0.08688289453857578, 0.13855049590347335, 0.11496700943098404, 0.15758213092340156, 0.09495158345089294, 0.18558251671493053], [0.03703555135871284, 0.08403090265346691, 0.009532818257866893, 0.01849976189987501, 0.01995020418689819, 0.06420086516300216, 0.04207500125630759, 0.04786866244103294, 0.01683494840108324, 0.02131018423824571, 0.005004147787985858, 0.04194637222099118, 0.011177186515851645, 0.01610471219464671, 0.01931177350343205, 0.04183753997494932, 0.012780188390024705, 0.022991607002040837, 0.0076861048273713095, 0.03793994364968967, 0.024492808479408268, 0.03372382125235163, 0.0344512150331866, 0.00924241494431044, 0.022949625563342124, 0.04632468357158359, 0.09485928254434839, 0.04665965563617647, 0.0354242671164684, 0.040879809530451894, 0.023550516561954282, 0.013316557069629198, 0.05535983800655231, 0.04503727628616616, 0.02191754861996742, 0.07510298484703526, 0.01100094870707835, 0.021998088341206312, 0.05495976845850237, 0.005459817648443277, 0.11923025449505076, 0.0030553758324458613, 0.09833581396378577, 0.05692970298696309, 0.012402863812894793, 0.0482779568847036, 0.032810612246976234, 0.04720672237453982, 0.041226997345802374, 0.014189152971084695, 0.05057432877947576, 0.04615113604813814, 0.00528226809365151, 0.01449791887353058, 0.024561911704950035, 0.024783683984423988, 0.016493757138960063, 0.008236960693466244, 0.027264850650681183, 0.01819344972318504, 0.042350141375209205, 0.035795526491710916, 0.04173583605734166, 0.06685874832328409, 0.032235759499599226, 0.06423948652809486, 0.019106159634247888, 0.05033216228184756, 0.03740897409443278, 0.008194843812816544, 0.09242346481187269, 0.028229598101461306, 0.0634125187934842, 0.06146858540887479, 0.010028449523815652, 0.062335803522728384, 0.02512623708753381, 0.024238684127340093, 0.05123409806401469, 0.0601201958488673, 0.03668008117529098, 0.05358857641112991, 0.055881671723909676, 0.010811217725859024, 0.03881027878378518, 0.08582229129387997, 0.03634293461800553, 0.011904035745828878, 0.009125816122832475, 0.019518873523338698, 0.06218304726644419, 0.030561951170966495, 0.055173147047753446, 0.047342483449028805, 0.0529236900183605, 0.049013558818842284, 0.03755803074454889, 0.05296888681186829, 0.015759702582727186, 0.06978954144869931, 0.03425183705985546, 0.07166112656705081, 0.11059815675253049, 0.011973263281106483, 0.014814107180427527, 0.048289667975041084, 0.057644298431114294, 0.02346421777474461, 0.01624602453375701, 0.0973107670142781, 0.04645660403184593, 0.015594658216286916, 0.07735697639873251, 0.009941572789102793, 0.047059068383532576, 0.051833679171977565, 0.014192700436979067, 0.06769500774680637, 0.0519836820603814, 0.028077596980438102, 0.03619814531703014, 0.05943081858276855, 0.00834993412354379, 0.015287258793250658, 0.004281934661776177, 0.037209785368759185, 0.009757724255905487, 0.030353791735251434, 0.03444522219069768, 0.04616297701431904, 0.039585997510585, 0.04516017223068047, 0.042969029454980046, 0.019070623748120852, 0.05020531811169349, 0.012052629481331678, 0.04002628404123243, 0.01511086235041148, 0.013432038031169213, 0.009617470404919004, 0.0315301551745506, 0.08336392711498775, 0.049182263828697614, 0.03759815124794841, 0.011505009842949221, 0.04276342486264184, 0.059762540040537715, 0.03189871313225012, 0.01651538332225755, 0.03949089870729949, 0.016816838142403867, 0.0341691432549851, 0.0040844287559593795, 0.05931207866524346, 0.05819964382681064, 0.044393273929017596, 0.031184177059913054, 0.07892127527156845, 0.03264888342528138, 0.02917166922998149, 0.01500548572948901, 0.016623759147478268, 0.04613955483364407, 0.04225964759825729, 0.01762302574206842, 0.10119034399394877, 0.021843625145265833, 0.030905532148608472, 0.005903471674173488, 0.034931124828290194, 0.026918501462205313, 0.15259819367202, 0.04972307426214684, 0.03844646686047781, 0.024978265828394797, 0.047797152801649645, 0.0232536352268653, 0.01893059346912196, 0.035994180871057324, 0.020766742891282775, 0.07483025299734436, 0.042235854343743995, 0.024022759971558116, 0.07024277845630422, 0.011854900003527291, 0.05690072212019004, 0.03554913717380259, 0.0693422119366005, 0.008735310075280722, 0.03598166826122906, 0.01488795644036145, 0.020440121843421366, 0.02570056662079878, 0.057290297700092196, 0.053180153990979306, 0.049214647442568094, 0.0069018490830785595, 0.014112369444774231, 0.012635009461519076, 0.038838985055917874, 0.047669807681813836, 0.029510585809475742, 0.05655719680362381, 0.1479082359583117, 0.05875914153875783, 0.062352457316592336, 0.043215218393015675, 0.011689872335409746, 0.03564065511454828, 0.03924744829419069, 0.04419980716193095, 0.0672536896308884, 0.014761439742869698, 0.04780675619258545, 0.054761132632847875, 0.054061398695921525, 0.0869579627760686, 0.021246635988063645, 0.06783979333704337, 0.057008934672921896, 0.044848952602478676, 0.0367524479952408, 0.07365777841187082, 0.02250012526928913, 0.033813962509157136, 0.01307413453105255, 0.03354379106895067, 0.046242442476795986, 0.00888984655830427, 0.038198708280106075, 0.035869359053322114, 0.02688173917704262, 0.040106599262799136, 0.028383304306771606, 0.04016036415123381, 0.003850308762594068, 0.02221844126324868, 0.021429195039672777, 0.04754740155476611, 0.01690731707640225, 0.03018721668922808, 0.01445455147404573, 0.029365811351453885, 0.07337047078181058, 0.013312835199030815, 0.05695817177183926, 0.03727195879037026, 0.027952112795901485, 0.0427197457611328, 0.09703942298074253, 0.08308422649861313, 0.030699810668011196, 0.06058942984964233, 0.026549570575298276, 0.017357620745315216, 0.0332117170910351, 0.003048918683816737, 0.04079045866092201, 0.013612890143122058, 0.007288372116818209, 0.028672368971456308, 0.044087457135901786, 0.07289422719622962, 0.03389401426829863, 0.05563503749726806, 0.01544410057249479, 0.03150225413264707, 0.07420457797707058, 0.02947084194602212, 0.051460304675856605, 0.041505859335302375, 0.07546878201537766, 0.014236780298233498, 0.07193836325313896, 0.06098399266193155, 0.0434660568862455, 0.010328764219593722, 0.04606885413522832, 0.05014166781620588, 0.029704848529945593, 0.03793219191720709, 0.04653346084523946, 0.044189142499817535, 0.02315119287231937, 0.06651755335042253, 0.08101314466330223, 0.004122812633795547, 0.05014269940147642, 0.15832898381631821, 0.08160371609847061, 0.026690287340898067, 0.04565141091006808, 0.009069645748240873, 0.047100840165512636, 0.06997918986598961, 0.026564341169432737, 0.015547291568509536, 0.0537803956103744, 0.030963280514697544, 0.03902851101884153, 0.027081196931248996, 0.04999202115868684, 0.07690174301387742, 0.03573173889890313, 0.03998205575044267, 0.04485477475100197, 0.04559524888463784, 0.01676997337199282, 0.01988922191230813, 0.015808610114618205, 0.009737757700349903, 0.010602638049022062, 0.05375338143494446, 0.07211729505797848, 0.04063811058585998, 0.005669456277246354, 0.03072553165111458, 0.02220661142928293, 0.005793791524411063, 0.026118265886907466, 0.0414708856260404, 0.054753993172198534, 0.03309069506940432, 0.030757265885767993, 0.020857136478298344, 0.009641687611292582, 0.008293408445751993, 0.03456996979366522, 0.030272945878095925, 0.02467574602633249, 0.011149302172270836, 0.03287746862042695, 0.0226133584510535, 0.027976156525255647, 0.06359939157846384, 0.03162312772474252, 0.028872299844806548, 0.007617074425070314, 0.05943013580690604, 0.016450382317998447, 0.11670781328575686, 0.03184146014973521, 0.054491848059115, 0.03998117630544584, 0.042226651712553576, 0.051562702501541935, 0.028677285699814092, 0.05786060108221136, 0.023877840794739313, 0.009310858586104587, 0.01905274355522124, 0.005817696564918151, 0.07673919782973826, 0.23344173532677814, 0.15628217021003366, 0.1446096270228736, 0.14829339575953782, 0.15471000457182527, 0.151395543362014, 0.11190762437763624, 0.1326040376443416, 0.11801645712694153, 0.1674249832285568, 0.19458315015072003, 0.090233045630157, 0.15962511504767463, 0.056664236763026565, 0.13022760656895116, 0.07997036780579947, 0.13667198654729873, 0.09381900672451593, 0.1374412523000501, 0.08466187660815194, 0.11088611747254618, 0.10082980123115703, 0.1292785778059624, 0.1306880498304963, 0.15230258140945807, 0.14600600756239146, 0.2233819680986926, 0.09287613036576658, 0.18448237184202299, 0.12324416020419449, 0.07172093624831177, 0.13855022873030975, 0.15445509168785065, 0.14234717498766258, 0.1127196749439463, 0.12849665101384744, 0.1504136374569498, 0.23260643327375874, 0.09196233877446502, 0.22360930277500302, 0.0903903141443152, 0.21559306886047125, 0.1646013933350332, 0.14225305581931025, 0.16850149811943993, 0.17295625439146534, 0.18749725772067904, 0.11851129893329926, 0.09702273207949474, 0.09265638786018826, 0.13917961448896676, 0.07317558280192316, 0.10461360405315645, 0.1443647182895802, 0.08807224556221627, 0.0908924883697182, 0.14495934185106307, 0.15933060116367415, 0.06467583225457929, 0.14949223143048584, 0.21248018980259076, 0.15381127857835963, 0.12085558759281412, 0.11374927125871181, 0.14030920778168365, 0.10481019897270016, 0.12474657880375162, 0.11895551142515615, 0.12231828644871712, 0.0782720667484682, 0.15328960813349113, 0.16331813094438985, 0.18725043424637988, 0.19350623450009152, 0.18853307323297486, 0.14889321435475722, 0.17062543571228161, 0.14137119142105803, 0.18356421642238274, 0.16921853151870891, 0.12375268721370958, 0.1918265613494441, 0.1140881136234384, 0.1483116822782904, 0.2087487603421323, 0.19272346165962517, 0.06524264754261822, 0.0868535203335341, 0.12850441387854517, 0.20636076660593972, 0.1802286782185547, 0.16103823843877763, 0.17782263545086607, 0.09921480625052936, 0.11577997283893637, 0.13191312784329057, 0.19475949928164482, 0.09301952813984826, 0.15083847247296944, 0.07214366356492974, 0.18790726462611929, 0.1763681447482668, 0.10662696164217778, 0.19273643440101296, 0.15874178119702265, 0.13132277905242518, 0.10363484485424124, 0.1490314764669165, 0.159894113894552, 0.18513256742153317, 0.1584361054119654, 0.24018692260142416, 0.2864734560716897, 0.09313295056927018, 0.14670292875962332, 0.13113169086864218, 0.18462384003214538, 0.17331515700789168, 0.14828011131612584, 0.09501879976596683, 0.15397867740830407, 0.12308958568610251, 0.1296749885659665, 0.1289874778012745, 0.17876013123895973, 0.09580267840647139, 0.1169008162105456, 0.13109513267409056, 0.08336662111105397, 0.11818942948593758, 0.14024051459273323, 0.10266283919918351, 0.11633319198153913, 0.2170054501038976, 0.11311051959637552, 0.12932313635246828, 0.2019744660356082, 0.1502763549797237, 0.09516031248494983, 0.11642045370535925, 0.18856226932257414, 0.17331748735159636, 0.07363258249824867, 0.09375628782436252, 0.14737783785676584, 0.13376021466683596, 0.09739966146298684, 0.08153163871611468, 0.11545114946784452, 0.18706658942392096, 0.08533063330105506, 0.10036467501777224, 0.15005577384727076, 0.16717517632059753, 0.11531511379871517, 0.1568957482231781, 0.17223846400156617, 0.15477709472179413, 0.1184760543401353, 0.05002726204111241, 0.11903344435268082, 0.1051546297094319, 0.15595538774505258, 0.20266233303118497, 0.16017564019421116, 0.19545676186680794, 0.16447602974949405, 0.07965151889948174, 0.14982613851316273, 0.08496171911247075, 0.2646180085139349, 0.13852768228389323, 0.11694785353029147, 0.10899703251197934, 0.0780543354630936], [0.056722807057667524, 0.062024238795856945, 0.03528522574924864, 0.015131712061702274, 0.025015625542437192, 0.060537049066624604, 0.03612616812461056, 0.035949473895016126, 0.07887066080002114, 0.034885074564954266, 0.026565667758404743, 0.03914104287105147, 0.022500338636746164, 0.053615679644281045, 0.05646378638630267, 0.015773606719449162, 0.034939444303745404, 0.018641885035322048, 0.01523479915704229, 0.014734082324139308, 0.005248669212960522, 0.01935138563567307, 0.06479915493400767, 0.036505346215562895, 0.06898571387864649, 0.052337912857183255, 0.0309720990844653, 0.04439091761014424, 0.058332569897174835, 0.024623580466140993, 0.029719262893195264, 0.008194816909963265, 0.012462381273508072, 0.051004061970161274, 0.0339697133313166, 0.06527742458274588, 0.0389296532375738, 0.01916788962262217, 0.06884944072226062, 0.04880063293967396, 0.06900882435729727, 0.021015167549194302, 0.05118878252687864, 0.05522226609173231, 0.06426421488868073, 0.11523022694746032, 0.04833977407542989, 0.027242955438850913, 0.058620920244720764, 0.023732327899779193, 0.022996956031420268, 0.07124306735931896, 0.01934847085067304, 0.09368565020849928, 0.0720050378004089, 0.01227401677169837, 0.052346599695738405, 0.017113300164055545, 0.04449955318705179, 0.0757297285599634, 0.08662439708132297, 0.018421802997181658, 0.03705829818500206, 0.04384383231808897, 0.056741605658316985, 0.01333850701485062, 0.09144478724920191, 0.08016052088350989, 0.03370768696186133, 0.04132614085392561, 0.12206885061459616, 0.021345003951864783, 0.0998780042573344, 0.022543386912730057, 0.016840267744555604, 0.050045756361214444, 0.056132944373530336, 0.020324504512245767, 0.045687371675739996, 0.04347575675637927, 0.0367437722889008, 0.051037332450505346, 0.051184507756261155, 0.008955199155025184, 0.03322022210340947, 0.09497322447714396, 0.07529388007242233, 0.05508978159923572, 0.02921527597209206, 0.05514491203939542, 0.04348967573605478, 0.019478131471259985, 0.0023825438211133587, 0.04901453845377546, 0.009555084543535486, 0.026513285120017827, 0.05912509455811232, 0.036219059038558044, 0.024226869136327878, 0.013808485946356086, 0.03604839846957475, 0.07194850099040195, 0.11485988041386008, 0.025833065956248902, 0.08071564734564163, 0.04648102440114599, 0.07066075602779165, 0.03606086283980403, 0.021396386546257418, 0.05392656159528997, 0.04612503471435048, 0.014966797571105417, 0.050583616757649, 0.026015491421276238, 0.04412128793774173, 0.08195570932002738, 0.07385533070191741, 0.048870903192437254, 0.0391076388041256, 0.021679842429875862, 0.014914820330886869, 0.05976733431452885, 0.04234757725498639, 0.031079229956958443, 0.036738213602802716, 0.031278266542358324, 0.058520863894955255, 0.006266334576139343, 0.01646814005653141, 0.01829787917813519, 0.026963327181874774, 0.043426003176136874, 0.03540940560924355, 0.013829315248585772, 0.005866866167707485, 0.051292390053276904, 0.025144798200926743, 0.02265574807097437, 0.02891457814257592, 0.039517155892099254, 0.023386186512652785, 0.0431412485340843, 0.06694202471408062, 0.02362026360060554, 0.08166983403498307, 0.04252593389537651, 0.04109251647605561, 0.06630456438870169, 0.048099481500685215, 0.01864194626250537, 0.06669515671092086, 0.07874871851527132, 0.022145740476844367, 0.05163430862012319, 0.04061069936142303, 0.0152484964200994, 0.07517579695559107, 0.10475438204593956, 0.06614794896449894, 0.03652757724921685, 0.05553528913878836, 0.06068959381082095, 0.04989443616068456, 0.04211100284010172, 0.05364225224184338, 0.019976190487795975, 0.021076394732517656, 0.022413086189772002, 0.011819876199297141, 0.03185408408171497, 0.011527704718901077, 0.01872018532594666, 0.017674335977062583, 0.04097341661690734, 0.05034657850046642, 0.12805974867660552, 0.026667356833058875, 0.006432209220292862, 0.030081653603701852, 0.02868685569410445, 0.01363649786071619, 0.059373398617026396, 0.018049777354463004, 0.06839581779786386, 0.037557236646534875, 0.04273639584425837, 0.0528326173662208, 0.0422344145772513, 0.011995525856036693, 0.05008480446122121, 0.023003329224593472, 0.06812904539401643, 0.00966515246545896, 0.01778966387064429, 0.02653318952070549, 0.023021513698040508, 0.03834664428723045, 0.014156483630358707, 0.05376697015890386, 0.028608826287381817, 0.015025887369120028, 0.06158585587400012, 0.04892906901659444, 0.017793526749301236, 0.02520632780942833, 0.0030497737770929234, 0.027592453188844956, 0.016812869507703, 0.045160402296460234, 0.02075908392725978, 0.040919848397606984, 0.0437132477236446, 0.02627843619848136, 0.06291438185144216, 0.02226778851763811, 0.03384347030078061, 0.06336923674098216, 0.061680357248405926, 0.028173408245493192, 0.041816989905782975, 0.013982691198179964, 0.02758429698587861, 0.023868055577622727, 0.013140614264557371, 0.07372509120614268, 0.07476216094801202, 0.016240111472143326, 0.08116961907944642, 0.022541832113347482, 0.024864559527486563, 0.06940113104064949, 0.06286304007517174, 0.05849508539540693, 0.012054507114953594, 0.0358902096922975, 0.04066233799676411, 0.07869960318203084, 0.03750182419025805, 0.019551793338905554, 0.07198948980658315, 0.02622615560539998, 0.03993941565568093, 0.07321020399103872, 0.042348007700638846, 0.03572321162209846, 0.05347779231669847, 0.01723282675811788, 0.007863216051191557, 0.01932227303768741, 0.030608370652771555, 0.030320237383421045, 0.04667182685807347, 0.023433465030393563, 0.026702842624217737, 0.03550711306161247, 0.02028263254032936, 0.022356723784469068, 0.0389210220600944, 0.017139592600869946, 0.09053009023773484, 0.046573113795602694, 0.08178611373296008, 0.026614072485244833, 0.04143518832279369, 0.025892304183798842, 0.018824412545654923, 0.08230019200709648, 0.07137468724977225, 0.018495258918846957, 0.039259745681192726, 0.041228752525057644, 0.02216076525655808, 0.033303312957286835, 0.017540899680170696, 0.08918477687984705, 0.05374360363930464, 0.0508827727753669, 0.01298468161621713, 0.08318291729665361, 0.0970665410568472, 0.04975827061571181, 0.024337677350558806, 0.04417458156240173, 0.04310618205636274, 0.025925094123522285, 0.01266529372514924, 0.040217991918325424, 0.0285579706178396, 0.11444622214185074, 0.02590557749499567, 0.05837515062012244, 0.06193584900756832, 0.04972898546839133, 0.03826698215561919, 0.04305503694922663, 0.039585507693118416, 0.02692526984901633, 0.05988630058709532, 0.05435499973827973, 0.007594208855152829, 0.02019333918724442, 0.015055743970151525, 0.010540824569034157, 0.017201318878505845, 0.014336115837068064, 0.049256593629252166, 0.06105279717303347, 0.02256076430057874, 0.028672743756033015, 0.037159452913329005, 0.05153673846507445, 0.051253200945211574, 0.07122458046069369, 0.03395073290448636, 0.027082644119218457, 0.03339656752359588, 0.0324828909651842, 0.02179628540034173, 0.07745449460344389, 0.0389699778315844, 0.022967015938775148, 0.06445401915698312, 0.04280980909243226, 0.012372721485007787, 0.050925969480886124, 0.031234925118042156, 0.018894150307460222, 0.04784682845638599, 0.007791224015818443, 0.04512859013630077, 0.02562931116699474, 0.08676467041368596, 0.08498661074554548, 0.03706147086631972, 0.13468966557411477, 0.07198316670837812, 0.0726010269136168, 0.06420467980206013, 0.044510303196148016, 0.032709717270336114, 0.030026033346075565, 0.07190832853666507, 0.10329870390705764, 0.055415710594388656, 0.014806670860707527, 0.09461816618568264, 0.013312116243469063, 0.039722010915284045, 0.039249151523108594, 0.06966096436372027, 0.04028418778034393, 0.059880211265408434, 0.17374621122144163, 0.2332937510800548, 0.09736867679748684, 0.11122137526399456, 0.08541798408259638, 0.13326300540938973, 0.12678329920163378, 0.13084655773127452, 0.16800103825517, 0.09655617352109402, 0.20323343051131815, 0.12819194002076983, 0.09237897305865772, 0.12489100074162707, 0.18527474807342514, 0.12971714255400002, 0.1222063705790788, 0.09223072906024754, 0.0675105988921132, 0.10855319109396078, 0.09791371747269295, 0.07909223641036078, 0.26572273985948414, 0.10256976645905524, 0.1436001725960523, 0.1558638660935685, 0.15029033704195172, 0.18968969554407522, 0.11153243904118426, 0.09099410322960466, 0.0951799719769042, 0.08583825489040464, 0.10466941355844028, 0.21163382974918932, 0.14086914336076006, 0.16660436085658148, 0.11904014594620094, 0.09435284839128144, 0.09630910513806157, 0.1586593731190078, 0.14777979988139123, 0.09941020631231368, 0.19718094903510064, 0.12841652875067666, 0.13370455359108746, 0.22250106849242002, 0.1483682042453438, 0.10032129648607224, 0.13899744692025706, 0.14801642624661326, 0.11280708509730175, 0.22059437236748636, 0.10842168994713575, 0.20838423224631697, 0.1793540274957195, 0.179123961715959, 0.23895486840046942, 0.07828915098798461, 0.15596491692122072, 0.22810251713963225, 0.19414920156123117, 0.12073048375896178, 0.07487514551030472, 0.13343613361939788, 0.199582360801287, 0.12950226111570373, 0.1592265669023618, 0.12656772014452145, 0.1726797450101003, 0.10839949973160401, 0.15520215238211676, 0.07555412899819203, 0.23499156231991947, 0.09645122641813941, 0.08854539439198561, 0.1123739528702572, 0.16648753196932375, 0.09739093380630948, 0.11184179587871768, 0.17506413190858439, 0.096528558206046, 0.12700241088168696, 0.1821661289432086, 0.297402708674781, 0.12088438292266801, 0.15770145342685282, 0.13330596091691405, 0.12243268851307221, 0.11903506223461591, 0.2358514443039894, 0.14308841724414378, 0.31322114111389965, 0.10469397864653729, 0.1086009260325227, 0.08706494336365722, 0.08744502687477507, 0.14265656151110306, 0.18339070229558274, 0.15263715642504394, 0.15720574330771342, 0.08725062129087746, 0.10483333913725801, 0.2026914994348772, 0.09977005145628937, 0.18536330113420263, 0.13731680897763, 0.07007070409599692, 0.08970767186838202, 0.16422717279056087, 0.11095956040662713, 0.13684259145520627, 0.16349266923498362, 0.23616771795786917, 0.05952091159997508, 0.19003034132765606, 0.152771262510214, 0.15469453821424395, 0.15434454136993736, 0.1591661709244363, 0.07658650836674497, 0.10528780811000615, 0.22547838685568422, 0.16346184042049572, 0.10756916264654137, 0.14062567439395934, 0.16860012954566628, 0.11850150258396752, 0.07471266711945646, 0.07812933690729551, 0.07598038151627406, 0.16560256539378315, 0.09389715487486683, 0.1563511899439618, 0.09474934820900671, 0.09764034737600014, 0.1751289510866627, 0.10076703780214302, 0.11141775496071205, 0.14546875201631337, 0.22566203871974722, 0.1372551661916077, 0.09561596147250384, 0.18270598200615495, 0.08741652840399183, 0.2338249358581379, 0.09584460232872516, 0.1769370454712771, 0.17400648241164163, 0.0801043254614342, 0.11604864514083602, 0.08175942610250786, 0.11769173041102476, 0.07076469380990602, 0.13590144430054352, 0.10559026297414675, 0.14901253685820848, 0.15464754542335868, 0.17112822592025623, 0.18456207850249484, 0.08943039065343328, 0.2872124867280945, 0.17193835432408378, 0.14468842826317996, 0.1781741759623401, 0.09077602313482203, 0.1787932903971523, 0.2198507552384399, 0.09128944089752622, 0.07478552375687286, 0.18137065053451806, 0.15363253973191604, 0.12341171488515101, 0.12045335097354837, 0.1748715149005875, 0.12539123796159402, 0.24389466270804405], [0.017914361378643662, 0.04644898959668353, 0.03336220979690552, 0.04348735652456526, 0.060085641453042626, 0.0513122425036272, 0.03866535218548961, 0.016927278993534856, 0.11030759109416977, 0.02983372989547206, 0.04426884916028939, 0.04536514599749353, 0.0729480996960774, 0.0515219660155708, 0.024420530717179645, 0.037169713104958646, 0.013004417178308358, 0.05979221852612682, 0.013933939517301042, 0.03170258947648108, 0.04365202425105963, 0.041175956139341, 0.072114037029678, 0.03547609499946702, 0.05593432710156776, 0.011086487720604055, 0.030609836394432932, 0.01472638903578627, 0.0038726845150449662, 0.013881045724701835, 0.029999204707564786, 0.025423279839742463, 0.05451554483443033, 0.04780328294145875, 0.06144067694549449, 0.03381388458365109, 0.00989379703241866, 0.027191858571313787, 0.06203650278621353, 0.02355536835239036, 0.029537143564084545, 0.03804938074608799, 0.03373158411704935, 0.011981385159742786, 0.04974431452865247, 0.09742395195644349, 0.011082080291089369, 0.0329276526463218, 0.029454356990754604, 0.053721569274785, 0.06655039338511415, 0.0495756837335648, 0.010955237976304488, 0.020065368807991035, 0.04638918362616096, 0.04861965651798528, 0.01399040953401709, 0.0033145029556180816, 0.02769774539046921, 0.03256369229347911, 0.027491899600136094, 0.04889534211542923, 0.02512521848984761, 0.03688757824420463, 0.029497342184185982, 0.007669015949431923, 0.022216634133656044, 0.04269603414286394, 0.01779797406925354, 0.039417526277247816, 0.07066214384394698, 0.012469194189179689, 0.12883343762950972, 0.057053563723457046, 0.012322080110607203, 0.04743483630591072, 0.08523076990968548, 0.04637125333829317, 0.020840799952566158, 0.008943157808971591, 0.07958618763950653, 0.04298999141610693, 0.06975394062465057, 0.05290703251375817, 0.04590856136928778, 0.040489992752554826, 0.04102731509192381, 0.026062721699418034, 0.04032088698295411, 0.014497849297185894, 0.018517643948143814, 0.04149020001932513, 0.055131753761088476, 0.015972335313563235, 0.003505651438899804, 0.05207210895605385, 0.007928306113171857, 0.10069514595670626, 0.057555467064958066, 0.020851490589848254, 0.01882915858004708, 0.07331714004976675, 0.09734094273881055, 0.029388255752564874, 0.01905750443256693, 0.06920043946593069, 0.023150174274633173, 0.029252865751914214, 0.010775131722766673, 0.03831355934380554, 0.05335259571438655, 0.030236717939260416, 0.038280726730590686, 0.06392985509592108, 0.04768137034261599, 0.0216914088014164, 0.04175053058133926, 0.05940549279330298, 0.016502471808053087, 0.03680417197756469, 0.04316334227041807, 0.09710702521260828, 0.008971731422207085, 0.04069676622748375, 0.05799482962174807, 0.026474172082089353, 0.05210120485571679, 0.03125393152004108, 0.03751394346181769, 0.013289720081957057, 0.012399829356581904, 0.04409331639180891, 0.04900475323665887, 0.040437960778945126, 0.050882891518995166, 0.020816470496356487, 0.05381627845054027, 0.0490048794017639, 0.07404500880511478, 0.031928632815834135, 0.05669767422659788, 0.034631816670298576, 0.048457363664056174, 0.01669128345383797, 0.03338346490636468, 0.0542996986041544, 0.09457931475481018, 0.047347522631753236, 0.022770205796405207, 0.04703525286458898, 0.02782338542601792, 0.05914085035328753, 0.007621298636877327, 0.041443797235842794, 0.0372488223365508, 0.06598428313736804, 0.05357825313694775, 0.028304260013101157, 0.048890688849496655, 0.02551456771470839, 0.017959135147975758, 0.030411883344640955, 0.0550160863349447, 0.031971714488463476, 0.024782099499134347, 0.03330806641315576, 0.04290407297958154, 0.0442288325575646, 0.026171190293098334, 0.024006989333429374, 0.03558084172254894, 0.03130945158773102, 0.03445013520831708, 0.051601008453872055, 0.04660559388867114, 0.02828912762197433, 0.03424529131734744, 0.0064777237457747106, 0.015997514528862666, 0.017312414674961474, 0.027806523830804508, 0.03084789881540928, 0.06729642249410972, 0.02007776638492942, 0.030335364208440296, 0.04119200508284848, 0.009206739905494032, 0.027016106869268697, 0.04489089878916275, 0.04465943406103179, 0.024834118485159706, 0.011778409625549102, 0.026712112048699055, 0.0292484648161917, 0.010895484883803874, 0.00845048585688346, 0.0475019450095715, 0.016523710219189525, 0.06487339938757941, 0.010290389618603513, 0.03244531231757719, 0.04837046188185923, 0.014377274419530295, 0.022636077446804848, 0.038436165850725956, 0.042030494660139084, 0.013528314066206804, 0.07423672781442292, 0.03897215603501536, 0.021635777411574963, 0.08565225783968344, 0.061981194230611436, 0.05642164724122267, 0.03200623919838108, 0.02596469141280977, 0.003609823925216915, 0.04516108878306113, 0.03644588534370996, 0.046914368140278384, 0.029660299260285683, 0.018590953295642976, 0.04203342985420022, 0.03232305833080318, 0.04311321390559897, 0.022468849310826045, 0.02325412875507027, 0.02188841375755146, 0.03724332673300523, 0.0433396171865752, 0.07815603938070126, 0.09445306801353581, 0.055086653446778655, 0.036949410277884454, 0.037619205977534875, 0.03685726893309038, 0.07144007788156159, 0.017024309236148838, 0.03332351792778354, 0.030402361589949578, 0.056022397766355425, 0.019308771516080014, 0.02436344286252279, 0.059376690041972324, 0.06857828222564422, 0.07347595965256914, 0.012976616326341173, 0.028860260354122147, 0.05967027253063861, 0.08174708418664522, 0.008522217212885153, 0.0273453402769519, 0.042295690000173636, 0.03893236949807033, 0.0676518667023629, 0.02610333944176091, 0.08356656311661936, 0.03443180044996552, 0.020467078502406366, 0.05773772740212735, 0.01539317068818491, 0.020857926865573972, 0.010189835102210054, 0.026559218495094683, 0.027070508149336092, 0.02065358763502445, 0.029273029904288705, 0.05243905274255667, 0.03967030919739045, 0.07818320198566653, 0.002502174547771574, 0.05263318002107553, 0.040526621451135725, 0.018845424601749983, 0.1201510890678037, 0.061716985946986824, 0.04539197834674269, 0.04860564476985019, 0.03870931330311578, 0.08119094098219648, 0.037700819957535714, 0.023359664010058623, 0.04221454728394747, 0.044686236724373884, 0.029633915910380892, 0.05788409005617723, 0.006734123708156403, 0.03227827342925593, 0.04708272805146407, 0.020356132990855258, 0.013706867375731235, 0.03525801490468439, 0.044487741906777956, 0.06134233124612365, 0.009812933549255831, 0.007770587671984686, 0.027387208538129926, 0.014637868443969637, 0.026857634220505133, 0.024760215419519227, 0.012090574564354029, 0.061742382240481675, 0.014275201283453498, 0.026411553371872287, 0.010247032423649216, 0.05591697568888776, 0.03325893252622336, 0.07455046332324855, 0.057977040341938846, 0.03021187640115386, 0.021659967715095263, 0.020899416631436907, 0.028245917928870767, 0.02822549216944026, 0.02619748644065112, 0.08359290193766356, 0.07029100321233273, 0.04010473276139237, 0.015840617088542785, 0.03171758828102611, 0.014094468842813512, 0.01157499993496458, 0.07109576588845812, 0.11624483187915757, 0.05340251256711781, 0.015532185152551392, 0.02089262783556478, 0.050662982030189596, 0.0649605349462945, 0.015355665327660972, 0.0875741605705116, 0.02264009803184308, 0.04968086090229917, 0.0033918400777110946, 0.03856466501019895, 0.053199453541310504, 0.048681336411391385, 0.03368416088051163, 0.013162163450033404, 0.08199586693081073, 0.030629482898802962, 0.014883446037856629, 0.029312881379155442, 0.025252912419091444, 0.022231992879824247, 0.0520120988949202, 0.024431854035356082, 0.04285372939193621, 0.035297808863106184, 0.07874817674746737, 0.06962693689274602, 0.020259824486856814, 0.03100348822044907, 0.07067587357596494, 0.24375617795158178, 0.08553175532142632, 0.09624729165807366, 0.07576470597996376, 0.17359776684315875, 0.12971975491382182, 0.08293658363982104, 0.2095473706140183, 0.1591958271455951, 0.126753197691869, 0.1871262284112163, 0.15156030014622957, 0.17466880468418822, 0.09635888098273426, 0.1261564515880309, 0.09085452751605771, 0.1652668771566823, 0.11216687882551923, 0.08852086641127244, 0.15052834380185232, 0.10949600065941922, 0.13564046064857394, 0.07718580745859072, 0.14364703180035576, 0.12262020696653053, 0.0902391089766752, 0.12365772199700586, 0.13140578084858134, 0.16015540924854577, 0.10480033583007753, 0.18618821311974898, 0.14128700218861923, 0.11528698640177026, 0.19208398269256577, 0.17588374495971948, 0.17173945874674246, 0.16488339460920542, 0.2133254217915237, 0.12567901314469054, 0.1782303862273693, 0.12367227551294491, 0.11147389843245037, 0.12343151538516395, 0.09745485498569906, 0.280270793591626, 0.1396761112846434, 0.10309886580216698, 0.13988420949317515, 0.1692398014711216, 0.19396351621253416, 0.13917078293161467, 0.06734339302056469, 0.18049044854706153, 0.17551525379531085, 0.18924177973531187, 0.15839694970054552, 0.18172826181398705, 0.14503225043881685, 0.3338329866528511, 0.10354977988754399, 0.20913889253279194, 0.08776639166171663, 0.11336757728713565, 0.1203988550696522, 0.07862795624532737, 0.10873152918065898, 0.19016346777789295, 0.15356763149611652, 0.10926698872935958, 0.09962589669157751, 0.16483459097798914, 0.277158819953911, 0.2096464324858971, 0.08849952966556884, 0.17158610135084018, 0.12636925501283258, 0.22821884136646986, 0.12961475586052984, 0.1830424866057001, 0.194721041189041, 0.1091165776597336, 0.14410984993446618, 0.1516225514933467, 0.1570803945651278, 0.1501330017345026, 0.1980749549693428, 0.07641372154466808, 0.14427206857362762, 0.1732798753073439, 0.11666282429359853, 0.1056282535137143, 0.148588681477122, 0.0740057640359737, 0.15340349811594933, 0.14453078125370666, 0.0777900566754397, 0.2201064844848588, 0.1770173606928438, 0.11926302773645148, 0.14779121411265805, 0.09752640544320457, 0.23507809673901647, 0.09638967268983833, 0.1395835803123191, 0.16409965697675943, 0.15229662938509136, 0.11224346104427241, 0.14597139379475266, 0.16619641712168232, 0.12140871025621891, 0.19168902654200792, 0.06726888881530613, 0.10802484874147922, 0.14144273445708677, 0.15457974281162024, 0.1397761527914554, 0.14324432762805372, 0.12982911779545248, 0.1414681159076281, 0.11722402152372524, 0.1424621039768681, 0.14698173879878595, 0.06303260597633198, 0.21354790282202885, 0.14228668995201588, 0.2701573394006118, 0.1414895788184367, 0.1271219560294412, 0.08439416167675517, 0.13185611605877057, 0.1586187627981417, 0.14075430342927575, 0.10853599553229287, 0.10638656516675837, 0.10678316146368161, 0.21701916499296203, 0.13793031277600676, 0.11474176018964499, 0.19626141322078183, 0.21566027775406837, 0.13623817154439166, 0.1498544291825965, 0.09260506092687137, 0.10251745989080518, 0.24391587328864262, 0.28807637630961835, 0.15836374601349235, 0.12805452395696193, 0.14119561412371695, 0.10718218458350748, 0.22186975314980373, 0.13319420831976458, 0.13966030353913084, 0.14132335258182138, 0.21784168726298958, 0.19310862146085128, 0.10096361045725644, 0.12132199030020274, 0.17675144918030128, 0.1554019533796236, 0.11553772841580212, 0.22660002432530746, 0.11733236024156213, 0.12504504091339186, 0.10280832982971333, 0.149612414825242, 0.12422135347151197, 0.144636848999653, 0.1383476224145852, 0.12314496474573389, 0.24771452648565173, 0.2116765922983177, 0.1348645007237792, 0.09166465591988526, 0.12478487362386659], [0.010569368496362586, 0.0558107558026677, 0.01876961236121133, 0.04323019122239202, 0.018198782054241747, 0.05029398620536085, 0.04515631306276191, 0.015103626410564175, 0.07208459603134543, 0.021790264727314934, 0.022810504415247124, 0.027509048777574208, 0.01839062722865492, 0.03970484503952321, 0.01438547978978022, 0.09667765567428432, 0.03191420175426174, 0.024310722546942998, 0.009286327822337626, 0.04653941658034455, 0.04163199104368687, 0.04395733638375532, 0.04450525659194682, 0.03766559762880206, 0.03803692008659709, 0.05315279100614134, 0.031612463062629104, 0.01778875845047878, 0.04576170147629455, 0.020511510883807205, 0.031861980532994494, 0.0709796643059235, 0.035579461327870376, 0.050647671523620375, 0.011891085268871393, 0.10225274323602207, 0.11053986105252989, 0.022273991016845684, 0.03406805160921067, 0.04697058582678437, 0.011497313771542395, 0.007584816048620269, 0.031173998504527844, 0.022516656608786434, 0.02659446679899702, 0.03191540774423629, 0.05778623788501136, 0.08335018254001625, 0.018427174290991388, 0.017328183457721025, 0.12344017624855042, 0.04586212518916, 0.024831051559885964, 0.0421737068973016, 0.012934777751070214, 0.011045248429581989, 0.03592895722249523, 0.01786708100553369, 0.08437583805061877, 0.023368042857327964, 0.040937040248536505, 0.048307824617950246, 0.027731242225854658, 0.02245757423224859, 0.03832815738860518, 0.027183179154235404, 0.034774631858454086, 0.047946636186679825, 0.008303360646095825, 0.05051090854976792, 0.042846961005125195, 0.04591319979226682, 0.09388216349179856, 0.0851756357587874, 0.10730198948294856, 0.020747359849337954, 0.05540615915379021, 0.011608851145865628, 0.06408501591067761, 0.051538694024202414, 0.0321215429721633, 0.029707408939430024, 0.08148475724738091, 0.07057663358864374, 0.08728205866646022, 0.024602089724794496, 0.0892857757571619, 0.06097595891333185, 0.01879822215414606, 0.02741311320278328, 0.050493620219640434, 0.01971886376850307, 0.047511155062238686, 0.038521509122801945, 0.014946905230317498, 0.03963549876061734, 0.019388634027563967, 0.025650189636508003, 0.08048888412304223, 0.01575061683979584, 0.05777683116320986, 0.012852136824221816, 0.1264591736253351, 0.030906806787243113, 0.03299552576208953, 0.026170902710873634, 0.05232068018813152, 0.0927192106610164, 0.031064982576936018, 0.027818938106065616, 0.03113681319518946, 0.061478749121306464, 0.011105362391390372, 0.010880530608119443, 0.059582702815532684, 0.024732932215556502, 0.017348631481581833, 0.04156199167482555, 0.08564688469050452, 0.040121126803569496, 0.07852474576793611, 0.013706256031582598, 0.017725946781865787, 0.022870664761285298, 0.014752359566045925, 0.07240164894028567, 0.022944085430935957, 0.061992311602807604, 0.02644255288032582, 0.026329108186473604, 0.04932394724164624, 0.011031992744392483, 0.07475029400666244, 0.04207571371807717, 0.029825850142515264, 0.036482747818809, 0.04337000071245711, 0.06051764190488029, 0.030139691407384817, 0.053493863524636254, 0.03092764443863416, 0.024580712160968687, 0.053428510000230744, 0.0147607087274082, 0.0466460817551706, 0.04138636984862387, 0.02107044456352014, 0.04275791441614274, 0.038090480884420685, 0.02034475215623388, 0.006908657360327197, 0.014593318246625131, 0.021399908036983106, 0.03231777052860707, 0.0208050915171043, 0.046518695817212574, 0.05193957993469667, 0.023026487942843232, 0.041226804387406446, 0.03951953447540291, 0.06353791948640719, 0.060797401893069036, 0.022088919795351103, 0.04531247577688191, 0.0489850269514136, 0.028255016659386456, 0.00651104339340236, 0.04675206415413413, 0.05489589922945015, 0.033164698324981146, 0.03315736961667426, 0.040740115073276684, 0.029492304856830742, 0.031269854298443533, 0.024504855391569436, 0.04132685331569519, 0.06644221051828936, 0.06347082191496156, 0.07313382215215825, 0.03369405370904133, 0.0238848596563912, 0.08755976290558465, 0.03793405099713709, 0.062291118811117485, 0.051007702204515226, 0.07153482787543908, 0.014090465883782599, 0.011142981857119594, 0.04125450876017567, 0.04405485087772831, 0.015900072394288145, 0.05196547346713487, 0.043121666967635974, 0.03100338431977434, 0.02322790867765434, 0.02218303896370344, 0.008532508018106455, 0.05167021372471936, 0.07276448493939824, 0.013953653742646566, 0.02350191516597988, 0.02982246965984814, 0.07985658914549276, 0.05042150572990067, 0.028541635947476607, 0.047422698480659164, 0.015045466152514564, 0.05153804464498535, 0.022946506687731016, 0.005649342219840037, 0.016744064996601082, 0.06402234896086156, 0.0843598744540941, 0.015400048541778233, 0.019085238491243217, 0.06555780055350624, 0.03917902598914225, 0.0055886071731947595, 0.03393521830730606, 0.05747522976889741, 0.040737580638960935, 0.029291288592503406, 0.07472886078176089, 0.05071113628218882, 0.02991641071275808, 0.03518123230605852, 0.04695339397585485, 0.032231937439064495, 0.04714238559245132, 0.028769252639904153, 0.030579701488022693, 0.0252620630999445, 0.026570263507892378, 0.031946926756063476, 0.03175082536472473, 0.014283055061241612, 0.001624667252144718, 0.03282022305938881, 0.06911244301591069, 0.030260507483035326, 0.031947821044013835, 0.05581646291830111, 0.04338092512625735, 0.0501191770308651, 0.031267813392332755, 0.050295975161134265, 0.012207226263853954, 0.0057581401415518485, 0.07086924757459201, 0.09886915839160793, 0.04748936560645234, 0.04854270322539378, 0.015612907627655659, 0.018265807266288903, 0.03339341339597013, 0.050517524796305224, 0.05061605974333361, 0.08280134949018247, 0.06653804404777475, 0.059933746088063344, 0.05201435873459559, 0.08610976961790584, 0.011946421655011363, 0.062413966516032815, 0.028907386731589213, 0.03287745377747342, 0.049815623788163066, 0.030642221863672603, 0.030597997283621226, 0.06259139176108874, 0.0034081425110343844, 0.028267132220207714, 0.06126912579929922, 0.07728482480160892, 0.031047039301483892, 0.027255302920821123, 0.06762290810002014, 0.02568419855379034, 0.11039402903406881, 0.023857231353758834, 0.054566125909332186, 0.06485607023932971, 0.051524292648537084, 0.0808890130429063, 0.06173209607368335, 0.02050829367362894, 0.02941137550806161, 0.07251418821397237, 0.01794862448150525, 0.0433792330295546, 0.027029463672079146, 0.02104644907376496, 0.06815207423642278, 0.0017840932127910492, 0.03108798358880449, 0.09457521067815833, 0.04096172779100016, 0.042419201927259564, 0.023962679406395182, 0.046079370367806405, 0.017810809513321146, 0.06849041194072925, 0.039001678669592366, 0.02975223836983787, 0.07101074545062147, 0.033821361721493304, 0.05284312617732212, 0.03409879136597738, 0.013066710271232296, 0.028901225050503854, 0.01937419925525319, 0.03816592390649021, 0.015636784373782575, 0.06449614345910959, 0.05098941568576265, 0.01628981681278674, 0.049751565311453305, 0.052154164513922296, 0.009665954912634334, 0.03321870441141073, 0.06270062847761437, 0.043938604576396756, 0.019529131859599147, 0.0458955440990394, 0.0066019940550177125, 0.05310012449626811, 0.023297364423342515, 0.04311603035603184, 0.008386678782699164, 0.017993526271311566, 0.04197292997559998, 0.04695297837315593, 0.043746302981162444, 0.024119140834955033, 0.02556049181293929, 0.05052785920270253, 0.018126083123206627, 0.009828569673118182, 0.03683005808852613, 0.009890881319734035, 0.025712680326250847, 0.02475994453561725, 0.05737419007346034, 0.05213646429183427, 0.041897023111232556, 0.024167629053408746, 0.009900697150442284, 0.040762435164651833, 0.02281331344420323, 0.040703957638470456, 0.05271335052384529, 0.022728417316102423, 0.12558530957903713, 0.1351357260136865, 0.1825792677118443, 0.13550467730965465, 0.07257057659444399, 0.1845050964038819, 0.21893565746722743, 0.15084276208654046, 0.1582040061475709, 0.10245683384709992, 0.09441856556804851, 0.07040813638013788, 0.08300076457089745, 0.11585049913264811, 0.13574535580119118, 0.1931139946100302, 0.07828779285773635, 0.08850142956362106, 0.13012130133574829, 0.16790357942227274, 0.10770280117867514, 0.10210329695837572, 0.1408878157963045, 0.06154732356662862, 0.07788720380631275, 0.1313861584640108, 0.12312549821217544, 0.09497217804891989, 0.1731443146127276, 0.10526373283937573, 0.10557301546214148, 0.1270045037381351, 0.10523678545723669, 0.14181192324031144, 0.05598347954219207, 0.17614789016079158, 0.2097555430373177, 0.08192361885448918, 0.14144285320071504, 0.20344215212389827, 0.13024550717091188, 0.11202686524484307, 0.12417140693287365, 0.12339791093836538, 0.1823659596266225, 0.05934143431659322, 0.16405306494561955, 0.1529413924436085, 0.1251530827721581, 0.21296629653079435, 0.2336679567815736, 0.11085830177762546, 0.07382793803117238, 0.13735182350501418, 0.10204652266111225, 0.09161826426861808, 0.13804402464302257, 0.08506544167175889, 0.166322240838781, 0.1149843014718499, 0.12236405469593592, 0.19010316085768864, 0.1833503443049267, 0.14089590520597994, 0.12973710632650182, 0.2014665401657112, 0.09714378378703259, 0.11473090256913565, 0.16986973641905934, 0.14591254148399457, 0.15262872562743723, 0.10160044737858698, 0.15285273548215628, 0.18989372678333893, 0.20402046327944845, 0.11531967800692655, 0.10322747999452986, 0.111674849758856, 0.13095415430143476, 0.12725097098154947, 0.21685495739802718, 0.11658601943054236, 0.21096738113556057, 0.17922431492479518, 0.19075593911111355, 0.15445905475644395, 0.179094884369988, 0.08991628215881065, 0.09244801505701616, 0.10526629324886017, 0.2575545437866822, 0.1687266063527204, 0.16316814289893955, 0.15161950868787244, 0.08654342134832405, 0.14788784174015746, 0.12281915449420922, 0.21359920006943867, 0.17865088710095733, 0.11406021629227325, 0.15518267842708156, 0.08275564803625457, 0.2775956777622923, 0.09994393665692769, 0.19010222575161606, 0.16680607659509405, 0.13956438837340102, 0.15392130939289927, 0.13754255545791239, 0.12472437374526635, 0.07675579967326485, 0.1275588880525902, 0.13068656553514302, 0.13554916164139286, 0.10180772180319764, 0.09046587962075137, 0.19375908421352506, 0.1748033709009178, 0.15691476204665378, 0.11211454999283887, 0.1255306726670824, 0.17145537945907563, 0.1978773358860053, 0.11866005501360632, 0.08369601593585685, 0.1657066441839561, 0.10405061082565226, 0.2878437872277573, 0.3023699327604845, 0.09031762820086442, 0.09459731925744563, 0.13730282691540197, 0.20314229477662593, 0.12609920231625438, 0.19474550237646326, 0.13432026898954064, 0.1100585782842245, 0.16551540757063776, 0.1487838217872195, 0.0926089943095576, 0.18927376630017534, 0.21939589292742312, 0.1263931521680206, 0.10825024641235359, 0.18336836365051568, 0.22954462881898507, 0.0752935312630143, 0.20045330078573897, 0.12499150237999856, 0.10137735036551021, 0.09368710481794551, 0.15716620167950168, 0.06628489005379379, 0.09818835664191283, 0.19099385681329295, 0.10767953484901227, 0.1156044623348862, 0.15683321485994384, 0.13880707119824365, 0.16448238253360614, 0.1752689795102924, 0.13522699533496052, 0.11771228790166788, 0.1288279754226096, 0.10070529111544602, 0.08445952262263745, 0.13750242011155933, 0.11330224602716044, 0.14507372165098786, 0.08115087985061109, 0.07694837215240113, 0.11941144985030405, 0.11282767227385193, 0.13391348300501704, 0.16109430027427152, 0.1298544101882726], [0.03648704856459517, 0.013705107558052987, 0.06670047790976241, 0.01839187589212088, 0.026198952182312496, 0.0171434313597274, 0.05838773744471837, 0.037759427359560505, 0.04121403944736812, 0.07573594033601694, 0.0397559493285371, 0.01810335299524013, 0.030286118999356404, 0.057063924105023034, 0.015869499620748684, 0.04969779671228025, 0.018406826457066927, 0.009799458002817119, 0.01727734077576315, 0.058040868752868846, 0.04360079008620232, 0.02606105186714558, 0.0280048943386646, 0.09655551300966181, 0.031115437486732844, 0.00699411473760847, 0.03587521459849086, 0.018642593786353245, 0.02326402343896916, 0.03520757854857948, 0.04704422542999964, 0.027428557295934297, 0.10836372821358964, 0.019716448077815585, 0.03178696795657743, 0.023002689122222364, 0.04093003066373058, 0.03607947590353433, 0.009410872262378689, 0.053271245196810924, 0.029876215994590893, 0.028111153187637683, 0.049404399760533124, 0.11689328341162764, 0.025845096170087345, 0.030187051561370026, 0.04124280880205333, 0.03458653452980798, 0.03045831952476874, 0.04708229018433485, 0.011079018931923201, 0.05340983385394793, 0.04766746249515563, 0.035207793771405704, 0.050964598267455585, 0.08565822470700368, 0.07401101102004759, 0.029321790862013586, 0.032390886917710304, 0.0036725616109833936, 0.12435166718205437, 0.03125038405414671, 0.05746722570620477, 0.0317538421950303, 0.008342045093741035, 0.08244954180554487, 0.029151432718208525, 0.05520020946278237, 0.06081883511797059, 0.026469411204743665, 0.023416480980813503, 0.038486739504151046, 0.043120152986375615, 0.09785078334971331, 0.02511239974410273, 0.033032863211701624, 0.10207990446360782, 0.051055823059869, 0.04587319432175718, 0.025177358074870426, 0.034057865632348694, 0.0188685925968457, 0.0020372533526824554, 0.04628182825399563, 0.009662977972766384, 0.012135031993238954, 0.01217794668264105, 0.04035012017993722, 0.12202090787468478, 0.0553340335318353, 0.1000577375816647, 0.04017169303551782, 0.06839463778305799, 0.034049134264932945, 0.00942365111768595, 0.018179489925387315, 0.020846486659138463, 0.07106956807547249, 0.011053842499677557, 0.0505480493302457, 0.018300443298358005, 0.025525015298626386, 0.03343471391417552, 0.015800452056282666, 0.025884420720103662, 0.05233181240328122, 0.026056205642817076, 0.045524759698309936, 0.007777906175761018, 0.07079858027282171, 0.04800133247044869, 0.07398050132906064, 0.040019185398705304, 0.016995294972730335, 0.010044813880085712, 0.07081366071361117, 0.051012726544286124, 0.03318982373457402, 0.06328415693133138, 0.07789365306962281, 0.014455988457484636, 0.023469329316867515, 0.060865590421599336, 0.04387736255011987, 0.031110632080526557, 0.05772269891167525, 0.06176101385790389, 0.035074192346655764, 0.0391882657277165, 0.03877852228470147, 0.0506883671914693, 0.014211541711119935, 0.05589425112702884, 0.016490955531480722, 0.023759008108754642, 0.059990550071233884, 0.05368714846554212, 0.0693190420861356, 0.03159685569698922, 0.029810448722855654, 0.040423477767035365, 0.014348632157634711, 0.06872063357150182, 0.08820123082841747, 0.04992114976630546, 0.007292000755114714, 0.022290381348284427, 0.04690931040386204, 0.02003638794121798, 0.037223503968562, 0.02218164001533296, 0.032357872478314675, 0.07219037433969788, 0.029422027182590682, 0.022052519307180773, 0.03565404345863499, 0.029163197614252567, 0.013144769363861997, 0.08493552129948512, 0.05965831282082945, 0.0113880251046794, 0.037180704312049784, 0.009419548896403285, 0.032915147457970306, 0.02183165244787233, 0.03135566883429419, 0.02110576522682095, 0.05184128989640158, 0.033355159393977374, 0.035655464671435766, 0.03366491699125618, 0.027881031746801455, 0.035370476252865046, 0.02847408195520984, 0.05441438268462662, 0.013014326705160784, 0.01683684273302788, 0.032905347397900186, 0.05334169356501661, 0.059189038001932204, 0.043350998021196574, 0.07337486429605633, 0.04379450918349903, 0.028915975235577207, 0.04282522349967621, 0.0467645322351018, 0.005250402127785492, 0.0873803709691856, 0.030909968336345628, 0.0806274134083651, 0.013054163337073987, 0.022908842693141196, 0.0562427710974589, 0.04158007781370543, 0.03341545889270492, 0.026090069841302466, 0.030398498711292632, 0.03970484132878482, 0.03548140135535505, 0.09279507299652323, 0.07014908231212758, 0.05249701818684116, 0.044011245990986936, 0.01665619285631692, 0.025478126408415847, 0.05823939325637184, 0.03741429900401272, 0.047499002394033596, 0.04728395026177168, 0.011134541782666929, 0.026251477684127167, 0.008222362648666603, 0.0680013514647726, 0.06613516176003031, 0.029107998525432777, 0.01788546400348423, 0.004678068507928401, 0.0139388840761967, 0.04895982361631468, 0.074428417137824, 0.04109716974198818, 0.03392032340343576, 0.03725436246895697, 0.02251198293379275, 0.118205845792545, 0.03460844643996097, 0.07263102452270687, 0.026571039052214473, 0.024633714492665604, 0.040187029517255723, 0.020194793796690647, 0.03492485739116091, 0.02079511890769936, 0.03397330532607157, 0.048382210079580545, 0.038676246913382784, 0.039719246415188536, 0.044698044293909334, 0.0552740568673471, 0.06496366680948995, 0.030521016160491854, 0.009435823267267551, 0.06078511934902053, 0.04418671196617652, 0.053692406581831165, 0.03226359003747348, 0.025889183452818543, 0.059789680381072685, 0.0017812919531934313, 0.01428905996363028, 0.020213312236592174, 0.019458587012195494, 0.08591555699240416, 0.04490352272114251, 0.033751302980817854, 0.06218908463779371, 0.03175532277964521, 0.025210036692442372, 0.0385771145374747, 0.056478388141840696, 0.02580421496531926, 0.08722079437575303, 0.08796980691840872, 0.08140421196003444, 0.06845947180408984, 0.03616845940996427, 0.019578605279093608, 0.04528114601271227, 0.034368113047094084, 0.08055867569055408, 0.043644929319270886, 0.19447562779532745, 0.052084896160522476, 0.018878967821365222, 0.01572803328599548, 0.021480486720975023, 0.006147403555587516, 0.0095964240244939, 0.03434322512475774, 0.00807534319392289, 0.06400786223821342, 0.03470992771326564, 0.047547876529279165, 0.03905283490894362, 0.07818897589459084, 0.039023779827402905, 0.028985275130253285, 0.03863008532789536, 0.020924130149069242, 0.045855007992940955, 0.08044946123845875, 0.0671297064400278, 0.0385627725336235, 0.05112122111313511, 0.06610659649595618, 0.036275922393542714, 0.05219051119638607, 0.04139175784075633, 0.10596957465168089, 0.011135876720800297, 0.043269625239190646, 0.08305908995680511, 0.05197334394324571, 0.04718324824352749, 0.059145407140022144, 0.04767757054651156, 0.07158426975365728, 0.020855659604421817, 0.013527780647564214, 0.03603062032198068, 0.04014014804852195, 0.0646779325325042, 0.03854811882774811, 0.014083229016250698, 0.011604156134126242, 0.0680096932046581, 0.0358729473373387, 0.032327496373909526, 0.0631312225596048, 0.03958864697779063, 0.04578736494295299, 0.023533593739557546, 0.006916452230143477, 0.012145932287239702, 0.08183933314285241, 0.025279765177401714, 0.02215196338511305, 0.07679940084926784, 0.06714659772114828, 0.09186616385704838, 0.02925332031736616, 0.058980776520911604, 0.055684115723124705, 0.019487827630655374, 0.017271160540985875, 0.03682462927827146, 0.038698615244356915, 0.058503742548055016, 0.027649244184431154, 0.032895064941840246, 0.048564604003331624, 0.07015460389084183, 0.006113651143095922, 0.017033242838806473, 0.02354633641516557, 0.023379805898002815, 0.06701802063616924, 0.047534666300634854, 0.025777581140573602, 0.033879739057738334, 0.002364381844017771, 0.05283005324599799, 0.07489857511245646, 0.12841494055464864, 0.18282292963704094, 0.1274285520776175, 0.11093693232396618, 0.22099223773693666, 0.19747167796595022, 0.14576963352737948, 0.07656825895537622, 0.12872198189143091, 0.08167447245796211, 0.27188461390323937, 0.10022670234320685, 0.23562482208944857, 0.1230043351824861, 0.14152542455121875, 0.06745229577063583, 0.14757171651581302, 0.10305532399797812, 0.13753644016105682, 0.16697737912181765, 0.19190726248780265, 0.20158409635769203, 0.29067902883980423, 0.09375038775033318, 0.0892657229269389, 0.08466522369417362, 0.13263531174743548, 0.16007188794901595, 0.09792999277124181, 0.15658624295610934, 0.09655909758294001, 0.2839648781809956, 0.1550993649289012, 0.1114652598334942, 0.11030305657186545, 0.08911452518077567, 0.13241332053439692, 0.24225073138950393, 0.14041903079487383, 0.10860522306757048, 0.12412689291522838, 0.1337936706840992, 0.226629561802838, 0.17611671995837241, 0.13388688443228602, 0.22021605516783893, 0.14628812758019194, 0.2530600380850956, 0.21731648419518024, 0.15567310445476323, 0.13716965593630448, 0.08789323212113231, 0.07727337346295826, 0.15241235989378765, 0.2590587583836168, 0.18700322485528886, 0.23767565813614056, 0.14846932928776368, 0.11996423854725435, 0.29981320432852954, 0.1649030318367295, 0.12659051892114803, 0.22715086117386818, 0.16020119976019487, 0.1781589025631547, 0.1810536495759152, 0.1351674454053864, 0.13465574942529202, 0.06601816960028373, 0.15166715456871316, 0.14166374603519216, 0.062134978361427784, 0.21213860891293734, 0.10290074947988614, 0.1619176982785575, 0.21613780525512993, 0.11482174886623397, 0.07824292260920629, 0.10928180199698545, 0.16568080260185525, 0.15829380601644516, 0.16072595753939822, 0.09602820966392756, 0.18443165346980095, 0.17227381991688162, 0.2157086064107716, 0.13420826406218112, 0.1692125349654816, 0.12401439817040227, 0.15205243311356753, 0.1492277448414825, 0.10671843876480125, 0.1142060334677808, 0.21427382715046406, 0.2341923286439851, 0.10734567971667275, 0.13621054880786687, 0.10999700229149312, 0.1704683675779961, 0.13661332719493657, 0.10636295744916424, 0.06876040526549332, 0.10094901983393356, 0.18113638419890776, 0.24527614092221484, 0.22174884245032445, 0.11934845635551028, 0.10048716649180278, 0.17215457162819803, 0.15700322604971007, 0.2283181407256052, 0.06213976150320377, 0.13496988569386303, 0.2273239300120622, 0.24186392402043566, 0.1771646027918905, 0.1264692668337375, 0.1557180637610145, 0.20327087928308174, 0.13041115453233942, 0.1121235745085869, 0.21681059180991724, 0.0884194890386425, 0.1448419044027105, 0.1532488939119503, 0.1862329794676043, 0.11894197465153411, 0.18457064288668334, 0.21982090605888516, 0.19958659104304388, 0.10192281406489201, 0.11720894108293578, 0.15614435338648036, 0.09538841899484396, 0.2687424496980384, 0.1596023459569551, 0.21818294160766527, 0.1071466134453658, 0.24493463424732909, 0.2374555222922936, 0.1554496437893249, 0.1432054242468439, 0.1971473594312556, 0.22024685429641977, 0.08661135754664429, 0.06933942146133631, 0.18869857216486707, 0.1783067235373892, 0.12620944093214348, 0.07126953976694494, 0.13893510651541874, 0.1519329473376274, 0.17637323588132858, 0.08668883034260944, 0.19008947565453127, 0.05769412251538597, 0.06419780751457438, 0.18589173996588215, 0.13675181195139885, 0.14237700932426378, 0.12857506633736193, 0.14336476335301995, 0.17122108343755826, 0.14317272522021085, 0.22708381555275992, 0.14922746282536536, 0.1283238345058635, 0.09284188025048934, 0.1554349492653273, 0.13684794976143166, 0.060805617467849515, 0.12747153727104887, 0.08361948566744104, 0.11455006344476715, 0.16092243371531367], [0.02819031993567478, 0.04780842602485791, 0.01997645951632876, 0.030317285491037183, 0.022392148348444607, 0.021944178733974695, 0.03742272609088104, 0.0775580687331967, 0.047372124827234074, 0.03291389693913516, 0.03391463113075588, 0.062002182166907005, 0.06596995968720876, 0.04972116323187947, 0.02679480214283103, 0.016230708461080212, 0.040487328442395665, 0.04265123439836316, 0.028454782404878642, 0.07404458578093909, 0.028818976534239482, 0.02813632683682954, 0.06912998738698661, 0.14202456339262426, 0.075437500490807, 0.05567306143348105, 0.01287495600990951, 0.041894440437317826, 0.013908327073295368, 0.05145582581462804, 0.02520054462365806, 0.06327682451228611, 0.015907979977782816, 0.05343558266758919, 0.06923399196239188, 0.03152134959236719, 0.007856794618419372, 0.04890317177341785, 0.011640998200164177, 0.030944997706683353, 0.03192155643773731, 0.0343038170831278, 0.027283443305350374, 0.009674613920651609, 0.013602158687717747, 0.08360991938388906, 0.06514103268273175, 0.03476447927823756, 0.011900451172550675, 0.021696806070394814, 0.1085523227811791, 0.047798381056054495, 0.048198265067185275, 0.039990909572225064, 0.03873343681334518, 0.013088887499179691, 0.007004584122114466, 0.026927397957479116, 0.025155177136184648, 0.019083837687503546, 0.06590874734683894, 0.027135557393194176, 0.05606468163023237, 0.05069601502327714, 0.057703421625774354, 0.021709064494643826, 0.04247971664881334, 0.021330203671823256, 0.04259218541847076, 0.024833201932779048, 0.07120502486941405, 0.02351827952224994, 0.010840247759915655, 0.021180479088798165, 0.026697580797190312, 0.10215437898295932, 0.07112495455658063, 0.046348833056981675, 0.03352722633280791, 0.023954933240020182, 0.05430909790447913, 0.04093590105185285, 0.039100473368307576, 0.0283147632580949, 0.024354154884349555, 0.024848621906130575, 0.10351532197091728, 0.024928840648499317, 0.02501794104318833, 0.006775701140213641, 0.032869531351025216, 0.06172763947688509, 0.03706731156853493, 0.030842362393741496, 0.13828066585119814, 0.029928114381618798, 0.006524383961732383, 0.02966490985272685, 0.034404181424179114, 0.011307217282592319, 0.10782965648104437, 0.07619258380145766, 0.06390992843080312, 0.011169807712576585, 0.01397529569658218, 0.08553729916457087, 0.010832786392711569, 0.01390525922033703, 0.08309972254210152, 0.03893396511557512, 0.05927457423240412, 0.010929474319709698, 0.05155823106179014, 0.02721858701988822, 0.02760991035756888, 0.0630295705923345, 0.072905210981844, 0.049988354949164204, 0.022214615491975565, 0.06704833736876026, 0.04131477115151938, 0.03307244194729719, 0.07715509738773108, 0.02738585782935843, 0.0331198243657127, 0.04659241334593389, 0.02811414589814376, 0.041358821326866746, 0.008379372338822577, 0.03257913267589174, 0.041172776036546566, 0.043277566219330765, 0.02745968296949286, 0.023862422676756978, 0.058221310828230344, 0.016768635650805663, 0.038256822153925896, 0.06435320581658743, 0.013127771399013, 0.03969848112319596, 0.03420056578761432, 0.006909881903993664, 0.0343428132327972, 0.04354023825726472, 0.0851207465166226, 0.10374807432526723, 0.03295036236522719, 0.09315736722783186, 0.05925602054048795, 0.04683668383222539, 0.05177641134650912, 0.027087659182143398, 0.011934854355786229, 0.035721437889151275, 0.024449930897390004, 0.05471782831591554, 0.010401895451650489, 0.04097024393558968, 0.08222355783800595, 0.06932166186743416, 0.021341710671549663, 0.03047820537176449, 0.037847089843126014, 0.04014769569039345, 0.037376586769823916, 0.11093814944615588, 0.02098042761645047, 0.034658463482628576, 0.007992008358996827, 0.034881137471529655, 0.032394100417150185, 0.04914360535622109, 0.05907901831960771, 0.03827478583843913, 0.010541852443566313, 0.030027235625311732, 0.030923219383112155, 0.048274832442984916, 0.025736660973052494, 0.06317213716101833, 0.030193140883056913, 0.029680346524401102, 0.021476679503393825, 0.0015404295481857844, 0.04681359190726653, 0.05279037432046607, 0.029223422898212448, 0.016418605409853626, 0.020411638215591665, 0.05036242706410121, 0.028919669275637716, 0.01935908912855666, 0.09414439395186491, 0.081092250184156, 0.09674247485236265, 0.03622900381742511, 0.03361512630362995, 0.00801648995548021, 0.058353453932795674, 0.07744126211036928, 0.04151497661950998, 0.07935437781270593, 0.02679312488908181, 0.0750521180452779, 0.037212713141343556, 0.021911514959356282, 0.037161861182539724, 0.07202695342130028, 0.050506418556324206, 0.02256122257676907, 0.036402258192538284, 0.1033075206214562, 0.017448370563215576, 0.00864562523929635, 0.014510141118080355, 0.08256120534497313, 0.020659261354012415, 0.05924913341004867, 0.05042422570113558, 0.016496671923960093, 0.03641519753728062, 0.05521065519133117, 0.06482350479927845, 0.04807572906429414, 0.023149226180976257, 0.015999705719877966, 0.058684611358330585, 0.03670553684059996, 0.041954398548114114, 0.06573365244548768, 0.04494822598644532, 0.014059623154025758, 0.02032163982221391, 0.02199323098466266, 0.028001072278129868, 0.08982689047115855, 0.0403088048187783, 0.005479286965055508, 0.018838782380043995, 0.02400730660156114, 0.11036140422220342, 0.06840708359959535, 0.03201561252353713, 0.03023955850949278, 0.022335240464599337, 0.03828408123808913, 0.02754112440015888, 0.04690977424615994, 0.027552722312975675, 0.0307550728393835, 0.02400007622782141, 0.04875728038314264, 0.04887296636297833, 0.030746308075322304, 0.038879977582837455, 0.08260971211711876, 0.028662281329161488, 0.030131794956105296, 0.036198657398927025, 0.04682844599301461, 0.02631355277117109, 0.0699797019478865, 0.02480473500327207, 0.009272438528569182, 0.052334985084598884, 0.021017612925788853, 0.0457182450190885, 0.05542015605897177, 0.06733216432621703, 0.04220008653646801, 0.03687564822030254, 0.026784911169670522, 0.040934505814220756, 0.026640654359653126, 0.06113852265116293, 0.07309307824471034, 0.07291376052307896, 0.03232914394175168, 0.07192360935732722, 0.04549221652268898, 0.00860889078467153, 0.03589466999983415, 0.03188486836734228, 0.04927713256620336, 0.041248055786127225, 0.03673556413559709, 0.07728185621090233, 0.032610417911200784, 0.03380995120096486, 0.029855094471713528, 0.015207310007099295, 0.04427249681612011, 0.028572822848218493, 0.04398154153022915, 0.08103172804112546, 0.09222092528943904, 0.01092357795641874, 0.022403323237085715, 0.0343248866556678, 0.017083245038520545, 0.025016538384079468, 0.024923114979173988, 0.019031388255825732, 0.018099458575306926, 0.03960688896768261, 0.03265520652348641, 0.03293862158898264, 0.017792803155316506, 0.018366243966738693, 0.07311149092856795, 0.03304715697595384, 0.035042977615376, 0.0034749093629216077, 0.0033254827985729207, 0.0653521588537842, 0.06982299746596254, 0.029936960781924427, 0.03930796301574446, 0.07579258104669861, 0.05293148256896529, 0.03474841549177654, 0.007951109528221423, 0.081082112446893, 0.008527962363586994, 0.058799621983780526, 0.05885167251108214, 0.010975737950502662, 0.010346253857278498, 0.03065805558435386, 0.022277011557889637, 0.02570889722846914, 0.052152327698422596, 0.00850188514959882, 0.02747416412603343, 0.08249966645962559, 0.03540887497365475, 0.027218510949751362, 0.1001855279901065, 0.05839666548126843, 0.005455082746266271, 0.038405615341616794, 0.04438174466486089, 0.017009351249726024, 0.049522876215633005, 0.032164023505174555, 0.020160810854576994, 0.04335599638579879, 0.08744909384404309, 0.02908796610427089, 0.030272864241851494, 0.027693216434272472, 0.03640165334218182, 0.14962351735448465, 0.09744724797201343, 0.104185585223604, 0.16377081134123728, 0.07454324222635478, 0.08024596434552222, 0.12023645831504837, 0.1214646830339916, 0.12605857715243474, 0.1951559100416489, 0.08035994338570163, 0.13528939511161298, 0.11709265396348201, 0.14500394492642954, 0.19769607373746112, 0.16717176244128495, 0.11357554933056235, 0.17134962341515347, 0.0893537193769589, 0.10412028364953585, 0.12306734352023341, 0.11310695728752762, 0.25035280210431665, 0.38853868085425347, 0.20930154161760584, 0.16053987143095583, 0.1089835180027876, 0.17318352969596162, 0.09363719538669102, 0.15567911585094407, 0.23027819726848975, 0.22081657138187438, 0.11084578916779719, 0.11405432363972068, 0.10723703671828844, 0.14955771854147315, 0.08632638768176548, 0.15854845172725618, 0.07192779507022351, 0.1335272248252295, 0.13428656064206734, 0.12568164034746587, 0.21668338769814, 0.10062965884571895, 0.0844215098186396, 0.10837091962457635, 0.13056001451332122, 0.2034008441842161, 0.05230224152910523, 0.1432610407937318, 0.16920546971959993, 0.0988636961847078, 0.21677657176041976, 0.17044251115294173, 0.13830040697939694, 0.18653219856787473, 0.09663422519224696, 0.176104815909639, 0.13359526492422447, 0.1939524878980592, 0.1371383818332106, 0.14383429050212726, 0.15380081429611892, 0.08084082539426163, 0.18572917993878946, 0.126164837856777, 0.135729503526818, 0.1936425076564774, 0.12478094024118036, 0.12003762953099795, 0.21067531633889303, 0.06912107419339009, 0.1532545342342928, 0.13825656089466065, 0.14199314085999504, 0.22567692620214075, 0.2070060491678305, 0.09016553987748921, 0.09919105752487667, 0.16677591571351513, 0.13293810799950734, 0.14140528568532318, 0.0823282748751808, 0.16613366111414507, 0.1333866620552726, 0.0887922772380989, 0.1398666057502851, 0.10123332176590338, 0.13672991859493777, 0.14219341683201492, 0.09949502637027763, 0.1287537458119914, 0.11811768607003614, 0.11869811234646477, 0.26200864696875215, 0.11591080605285242, 0.11761556379497051, 0.17844271467765793, 0.20505740685621276, 0.19795920961769298, 0.14679685496957973, 0.11422518829931505, 0.18022456672042608, 0.1888362257159315, 0.08386715519009158, 0.19019540981389582, 0.21270679717417806, 0.17847398878075182, 0.1115050983207766, 0.14857499627396464, 0.2729150711093098, 0.07127872755518183, 0.1553888915805146, 0.1829815117525868, 0.08289489720482379, 0.1427568108192645, 0.16594987566350028, 0.0870595924789086, 0.17392500943969935, 0.13508652162272483, 0.1548389156232588, 0.16864017583429813, 0.15620384394424036, 0.11753773476812057, 0.12595957465237007, 0.11903573758900166, 0.27890672616194934, 0.10048787895357236, 0.16020462848246098, 0.05956529203103855, 0.254331158939749, 0.10355521240853705, 0.07080714465701021, 0.14978839288232848, 0.1722277473891154, 0.11094918518210761, 0.09177410785923712, 0.07512961310567334, 0.1398387603694573, 0.18895771529059857, 0.16367890377296135, 0.0713778636418283, 0.17122276069130749, 0.17488099954789504, 0.22180226224008948, 0.21868072974029928, 0.11943389981752262, 0.11756545398384333, 0.17656405689194798, 0.15864242246607319, 0.1432993949856609, 0.0669983314583078, 0.1474496183800511, 0.1500377248157747, 0.07896123992395587, 0.10773095826152712, 0.1060881327430252, 0.14002296142280102, 0.22408542019547895, 0.13387103215791285, 0.08315590312122367, 0.2246649336302653, 0.13615248317364603, 0.07200070365797728, 0.15880189515883103, 0.20407888514455408, 0.08553251973353326, 0.1940065756207332, 0.13114975474309176, 0.09630962464143522, 0.10632527861162089, 0.14211103843990713, 0.18868831568397582, 0.21973744413116947, 0.1481005412642844, 0.14456101635005325], [0.04817028981051408, 0.05779495069873519, 0.01709743675746722, 0.05616717222437728, 0.04003144567832351, 0.054413774123531766, 0.01481421943026362, 0.02173021755879745, 0.0498842910019448, 0.0296122247891617, 0.04242997049004771, 0.08939200677559711, 0.021071600458526518, 0.07713905957643874, 0.06023046786140185, 0.021028772971476428, 0.048943121582851745, 0.016390112505177967, 0.004855844417761546, 0.04132627815124579, 0.022142011184769217, 0.009738108365127118, 0.021976376810926013, 0.05769164374214597, 0.049833431621664204, 0.0067730034334090305, 0.03868130093906075, 0.08551835955586284, 0.030987595127953682, 0.06935303244972602, 0.033127282949863, 0.02294700578204356, 0.047740211521158926, 0.0196139296531328, 0.03428995005378965, 0.04358580241387244, 0.04125552921323106, 0.08583137518144213, 0.012387841816234868, 0.03877650364302099, 0.017365454114042222, 0.02559255444793962, 0.055385494051733986, 0.08581305155530572, 0.007109375374056981, 0.034606168046593666, 0.02423421639832668, 0.057212995598092675, 0.0545408260950353, 0.05029604566516355, 0.014346529096656013, 0.07850421796320006, 0.03946920944144949, 0.029298140470928047, 0.022700623885612004, 0.0210546516609611, 0.04141277175222058, 0.010342607129132375, 0.03261732359533198, 0.06666552275419235, 0.02406377661827719, 0.02689375640329672, 0.018354582971369382, 0.02324342141946545, 0.06947494504856877, 0.06188386898429599, 0.049771703488659114, 0.043917486764257774, 0.012419412778399419, 0.044845805896329693, 0.05645779725455213, 0.014989029532443965, 0.0166578793869121, 0.03574525711883325, 0.024005761079024523, 0.0544627002091147, 0.03428633950534277, 0.005793013660877477, 0.0471710510464618, 0.010506535491003888, 0.027770466585934628, 0.06636299367528409, 0.05809606969705783, 0.006129739513198729, 0.05876383562281262, 0.015545938076684251, 0.023086119508661795, 0.05678011570125818, 0.03270072615123354, 0.02326152054592967, 0.041563294143998064, 0.058098374065593816, 0.052620055139414035, 0.03533051160047762, 0.06793824664782733, 0.1125881886400748, 0.05226373519690242, 0.048929050462902524, 0.04904815032205079, 0.08105811881250702, 0.021766707104688976, 0.071880015602801, 0.04206826626614202, 0.037647081044269726, 0.0218314817539067, 0.07371231884462759, 0.001838189864429296, 0.016235879375017248, 0.0885159830795601, 0.035319947128300555, 0.012851770388806472, 0.04696133124525659, 0.06330312622594647, 0.05161207758646924, 0.022312757100735325, 0.06304823560640216, 0.024549916743126232, 0.05671029073710088, 0.04256065527442843, 0.06019360909704119, 0.03971536127210129, 0.06291770667303354, 0.04103781648154836, 0.09719611261971295, 0.05264203384285793, 0.030129728074825834, 0.05009566208173055, 0.040447026112815365, 0.014515300899802241, 0.03416499093873426, 0.05720997505704872, 0.011481832571007544, 0.05178089391847607, 0.08747782238060609, 0.004476966896618251, 0.008651270200061845, 0.06951159972231835, 0.05480966538016219, 0.003748454560081882, 0.05201307481911499, 0.01395756578858709, 0.03596967515477445, 0.03786956578551326, 0.030339392214955296, 0.0896661115984898, 0.05787954811239615, 0.04805727556231432, 0.006666976969427196, 0.028057150811946485, 0.05565114952332806, 0.027194678732485045, 0.013459244237310486, 0.04216841909510549, 0.04454373694898095, 0.033017886671586893, 0.04510269660386257, 0.09202184417517856, 0.02441622069454752, 0.053703631565440446, 0.0263305702173966, 0.021378135279519483, 0.030622087397205178, 0.05716992876841687, 0.027888859549420886, 0.004401547066663625, 0.030049372035136912, 0.0440696381701855, 0.028604165599972475, 0.015381368684757035, 0.008133327191899298, 0.02856381132005481, 0.021599733154289424, 0.07881733006797731, 0.02919228980317712, 0.06640397506998852, 0.006167783394630533, 0.008220624167734059, 0.033995955673162825, 0.025287489079346415, 0.048314745145034976, 0.017838760650192853, 0.0323898256465327, 0.050721574589260854, 0.08201042786822654, 0.06908549563377164, 0.06505449826363474, 0.08746889434405603, 0.051897956582251936, 0.03634098648035433, 0.054727888127672486, 0.03895218113029841, 0.022040813782950863, 0.025762999794096686, 0.0468691045534797, 0.0323285650665639, 0.06200039730174467, 0.011450213369244011, 0.025532818981446326, 0.03962464856158476, 0.016832887085911352, 0.030702922122145537, 0.04540151865512598, 0.0377373410447035, 0.02557304524088977, 0.0236768857575953, 0.04325038506067358, 0.011590486701607006, 0.011351671000738861, 0.07316784220165573, 0.04497339963563718, 0.04735344868095126, 0.02655114763911115, 0.014871900075377198, 0.03695927713124547, 0.02451872242090758, 0.051534886806621216, 0.026465214359632228, 0.05333354107278865, 0.025435272946197074, 0.03150294804072473, 0.029911701785749756, 0.033609682650421746, 0.03755246463697404, 0.08927812421461567, 0.061494174660765566, 0.033305298202321865, 0.05242661063675769, 0.058876645780401304, 0.03752319433260709, 0.04284663074940909, 0.055499276422779076, 0.042331045915489085, 0.012909502056572819, 0.023263531766133383, 0.03491852316074073, 0.03359558555530384, 0.06795875960960984, 0.044568472731043585, 0.02370656053244602, 0.01892674914415693, 0.015844864028622396, 0.05236569144472014, 0.0336838343355339, 0.05046499558375217, 0.0757521711057052, 0.05145882038050331, 0.052168692054692656, 0.010442946422699606, 0.005978641029287246, 0.015462837018276332, 0.022684699251840357, 0.02456453334161779, 0.03205124303349294, 0.0535715144360438, 0.05417997163021937, 0.0653956932364963, 0.05501238672877662, 0.0441452630184358, 0.03534303905325942, 0.03515218835673295, 0.05336925321898889, 0.0593627525086049, 0.01829528351663612, 0.08380242506973445, 0.03772975629544817, 0.0061054216530465055, 0.04370097260107286, 0.06624576402828097, 0.004568599406411522, 0.020027762329846155, 0.043098051828565076, 0.06324556525214575, 0.09779757136129774, 0.023563326030853204, 0.03367855395481456, 0.10249009690596722, 0.025216612120857462, 0.008316367711813655, 0.004452739021871821, 0.0847403216175735, 0.06361401930917054, 0.015933316899463534, 0.05227400652074721, 0.01885908754047705, 0.05459742598759476, 0.017601880099391565, 0.025668372254585847, 0.06894188263686374, 0.030039380872040056, 0.04133243055548519, 0.011669717459881213, 0.07851782895158976, 0.02505668486264767, 0.032638626944390126, 0.05494699980772566, 0.04326322792621795, 0.026663985627237707, 0.015437253332493128, 0.03529777917719912, 0.05639707844238728, 0.05228994785284158, 0.03946268596337177, 0.026212299708276987, 0.004787558018506388, 0.04137143412663136, 0.0425660395558225, 0.030119748043944128, 0.035210814312449656, 0.0038498068852277356, 0.02578623272711411, 0.06773912100470625, 0.09012581271235831, 0.04943256797560025, 0.05570560460910201, 0.028134417661931366, 0.10278104105964303, 0.020721772452816367, 0.008946873185777804, 0.032144950309884734, 0.01717568695312366, 0.03761533567740116, 0.04586115297570359, 0.053571829848806374, 0.010054029498860473, 0.03711163633852266, 0.058621539938030764, 0.10970072209602222, 0.09717340290080756, 0.039491633433499373, 0.022510537601192482, 0.02090841888275463, 0.04911636111501139, 0.048480719051440246, 0.0693421896721702, 0.018030670762527734, 0.029572308376373257, 0.047557401994708925, 0.05664951626386028, 0.024646215970278718, 0.018718047940637916, 0.0572032734635286, 0.07476115904864855, 0.013426535006146878, 0.05175774633244146, 0.01616428624402033, 0.025724189181346446, 0.08279812856926583, 0.0033930852623598184, 0.017217519962287042, 0.0460015339194797, 0.03451568911259528, 0.01903868356748717, 0.11790495686000213, 0.14567097241524607, 0.10112335774465464, 0.1692189322784543, 0.15099473908776417, 0.18218581069959328, 0.14139406441245228, 0.2518875931855291, 0.16177575511392206, 0.12195566567243077, 0.1921115312143229, 0.13449716730974615, 0.15424173907376826, 0.24723742943024263, 0.14941644330974668, 0.07742025933112018, 0.11611088164499961, 0.17177307803649455, 0.20371837948914617, 0.10960376050206833, 0.13710594997974113, 0.15392879024147987, 0.10025353098171763, 0.18529434077208862, 0.16696243226760998, 0.09887488777167164, 0.1267276974976994, 0.12393164870445617, 0.09013975024572574, 0.191465298703406, 0.10099792736582458, 0.11745926007279195, 0.09578687808243558, 0.09258329373551533, 0.1442577748093754, 0.1323201513150707, 0.11044194950954989, 0.20363497693324462, 0.18430108000757173, 0.10193091831752099, 0.1260236368398182, 0.13858911726856604, 0.23062599735567346, 0.19489157188218087, 0.06308816315140575, 0.1293247690773569, 0.09916654438711703, 0.1608024284359999, 0.12054248290951364, 0.13073197013000026, 0.10494859467144124, 0.15499022469157353, 0.1278081606142223, 0.10571478051133454, 0.12108863680623472, 0.11782508692704141, 0.11888983135577291, 0.09791586227947846, 0.11170111436513253, 0.23287794057978317, 0.085577018908225, 0.07681064438656904, 0.14515746559482068, 0.06519097922137007, 0.15107404498849064, 0.15120259980903938, 0.1194421376567334, 0.1998161373194307, 0.06184430138091557, 0.10764172242488712, 0.1376610467559658, 0.11855108547024429, 0.09806811387534253, 0.10795738751767203, 0.13289819529745728, 0.10372681921580806, 0.10600086359772831, 0.19169944629538804, 0.16372727695852518, 0.09243907217751257, 0.18018560396740213, 0.1388550881529227, 0.1857399707660079, 0.09441432790481485, 0.16095044236863032, 0.14484476909274235, 0.11852708441438153, 0.15184711053734645, 0.15984734374796972, 0.12134685966884717, 0.13479462009854615, 0.13164135336410254, 0.1503354002488777, 0.18083171773469076, 0.299825583351776, 0.26680262410081923, 0.1474489356041886, 0.1284285367000848, 0.21664424682967365, 0.18399774940917268, 0.11581335464143194, 0.15906608488876373, 0.10789017120259814, 0.23719639400951564, 0.11512476776260883, 0.16426537855295464, 0.1247113267891109, 0.20292934292228892, 0.1410129715804942, 0.14510305132716894, 0.08059489249717444, 0.2589429833460599, 0.10452731454279274, 0.16849193925736472, 0.22162012435728684, 0.16144894296303391, 0.11180545290699229, 0.13894836127292365, 0.13221089233411476, 0.1796366076450795, 0.11790235934313387, 0.07305447172257118, 0.15599899634253234, 0.1531148620415479, 0.2524697931949049, 0.21838942193426192, 0.14177425182424486, 0.14928181772120297, 0.10540551273152232, 0.09001828293548897, 0.13332120463019237, 0.15233841229928657, 0.10650732001522556, 0.10421340834000148, 0.1143186395347584, 0.14148279558867216, 0.14695402700453997, 0.18163518165238202, 0.15116390422917902, 0.17508957273093984, 0.13835330726578832, 0.08602212939877063, 0.16200865589780733, 0.11361385157215409, 0.19251595716923475, 0.11379330288036726, 0.11136288056150079, 0.10055341801489703, 0.12835544999688864, 0.19153090455802158, 0.1361551697482355, 0.15332260401919484, 0.1307900802930817, 0.19614431716036052, 0.07785410401993431, 0.13577928679296747, 0.13402155454969034, 0.21272391109960154, 0.11834922130219638, 0.21038543345639482, 0.12950557109434158, 0.23693717666901648, 0.15355051757069305, 0.07973269501235336, 0.16351143072824925, 0.21726787352235988, 0.10944315974484198, 0.08942147003835998, 0.09698367284727283, 0.10379175713751465, 0.26271635899320245, 0.10540084462263621, 0.133493650064338, 0.17240832676179707, 0.15650701127015054, 0.06757012655725703], [0.04769748236867599, 0.03779061611567158, 0.05141619883943349, 0.005794153321403428, 0.017149426057585515, 0.01617606041691033, 0.01548297983390512, 0.03757299986318685, 0.08208452389226295, 0.07562483340734616, 0.05619920702883974, 0.0540045910020126, 0.053279267813195474, 0.04478479393583257, 0.050894802989205346, 0.02508971043425845, 0.022546216350747272, 0.03749718947801739, 0.01960780136869289, 0.022359902031894308, 0.011467060121503891, 0.021561391949944664, 0.04112539732886944, 0.04271291800250765, 0.0293715184670873, 0.03330560619360767, 0.03198748512659222, 0.0846585888939444, 0.06793377891881391, 0.055168222897918895, 0.044716178672388196, 0.00802731696239789, 0.03460629050096031, 0.029312243132153526, 0.09238732964149676, 0.022317779585137032, 0.06898866020492278, 0.0202798346435884, 0.045814371696906164, 0.02256277181004407, 0.062413884879788384, 0.0333412552572554, 0.00336644471190084, 0.06971621725824662, 0.032901684899115935, 0.0761130107275676, 0.0542488169594435, 0.052495166528387927, 0.06397954930434935, 0.03504209817037918, 0.014135726687527495, 0.053073852468514815, 0.012472095058910782, 0.04950502756400965, 0.03608460414397996, 0.02156332524464233, 0.02324295386642916, 0.011948272385780001, 0.0721080182120204, 0.06577962849405594, 0.020003609133709688, 0.04828390519833192, 0.049356145318597555, 0.03305143916804809, 0.03164551089867018, 0.019817897809844, 0.07183561290730722, 0.024835793883539736, 0.07941404648590833, 0.03754128789296374, 0.0705829937942326, 0.04972667738911696, 0.009325822138634976, 0.10301282120053656, 0.03927265162928961, 0.03389995144971181, 0.016068306140368804, 0.06293135476880707, 0.04639082006178796, 0.034179429421783425, 0.09690504230093211, 0.03378966459422372, 0.05644770404614974, 0.007985066495166393, 0.04075352939253207, 0.00446356834800099, 0.05747982366301585, 0.07724177281488664, 0.047039627825142816, 0.03520563041092828, 0.04250037804013118, 0.04532689199550077, 0.023515416687587276, 0.019574122707126662, 0.05663711497618351, 0.03754404868232086, 0.03152621808112599, 0.07995450068847276, 0.04627234360668808, 0.1158322422998026, 0.016489111294504255, 0.05574267117481213, 0.02462101634591818, 0.0819464770029299, 0.050108987343264744, 0.03280552111391444, 0.08470076514640823, 0.05411087768152356, 0.040436305789626203, 0.010913615551544353, 0.09217502345563844, 0.07064419871312566, 0.06252810140722431, 0.0964640655729454, 0.005697981650882866, 0.044706378612318076, 0.025095417549891863, 0.012669330080825603, 0.0318084419996012, 0.029242366217658855, 0.02264103684865404, 0.039429241078323685, 0.04814006213564426, 0.015621154743712395, 0.03400323985260911, 0.036577275168383494, 0.025868175107461866, 0.029153956020309124, 0.020262763391656335, 0.03730810509296134, 0.04141813005844597, 0.016685233094904106, 0.03613485867390409, 0.026849387104448397, 0.012487938984122593, 0.07929571846034378, 0.06859358531073667, 0.061948510046931915, 0.0394386218249565, 0.04645228473236784, 0.043618178606266156, 0.04296385668567382, 0.05989230456179939, 0.045671601037611254, 0.018540928831498604, 0.035083881084574386, 0.042367006681161, 0.04042855776788201, 0.0452844374376582, 0.018484798347344622, 0.045814842960680835, 0.005323736058926443, 0.05147259835212026, 0.05389684229157865, 0.04894610130577348, 0.07102011135430075, 0.013513216927094618, 0.07482055312721059, 0.07295635237824172, 0.019097237163805403, 0.027204573416383937, 0.010943086235783994, 0.004392071696202038, 0.009723158727865666, 0.03140635752060916, 0.0314707314100815, 0.029696566161874216, 0.04435262279002927, 0.03233761184674222, 0.04050560011819471, 0.025200563177349977, 0.009395403121743584, 0.08636739876237698, 0.02211241990153212, 0.018671635880309623, 0.014079644442972494, 0.03276957148045767, 0.04120561607123818, 0.007764041465634364, 0.04941106424666941, 0.05066109326435253, 0.028072596760466695, 0.01394728333252715, 0.032281639068969525, 0.031041428665048443, 0.029494304944819305, 0.11441102949902415, 0.03494095457426738, 0.038271108496701345, 0.040078687088680454, 0.0581466025323607, 0.017531518933537882, 0.0021967404245515354, 0.01304441801039502, 0.034244289417983964, 0.014947336603654549, 0.07032206209260039, 0.04409141278301831, 0.04470136911550071, 0.08332046694704331, 0.023633818927919492, 0.036235954030416906, 0.018822935671778396, 0.010795470279845176, 0.028277553828957025, 0.07597925345180556, 0.038151140324771404, 0.036856066653854214, 0.047889349807519466, 0.04002100366051309, 0.042294840241083875, 0.005787216559838271, 0.011604142218857305, 0.03460418651229702, 0.07649651553947479, 0.02552925296186004, 0.0005952339199666312, 0.03641712341050152, 0.053795516869286075, 0.005963375979263219, 0.029649690259248018, 0.02211241804616293, 0.07769015617668629, 0.02391551035543671, 0.08258623056462966, 0.01850624270446133, 0.02337890604394488, 0.012866525212302804, 0.04294147351174615, 0.02435459831758635, 0.04938029851473402, 0.04522277980868239, 0.023602101391588803, 0.015375553030025912, 0.0645786480163224, 0.02203483207267709, 0.014663564379588934, 0.02962033831863664, 0.04031020747788716, 0.049387519611627795, 0.034328808906138875, 0.033557042115717195, 0.047382934208144434, 0.023736070179438684, 0.03552937007043511, 0.017526591072964948, 0.028940017109562177, 0.02213957137428224, 0.02798558180074906, 0.02714475260290783, 0.023810631901142187, 0.025780071046028752, 0.03482395870378241, 0.09858353543677367, 0.02957453667477239, 0.045422554831020534, 0.008565399075450841, 0.060673485495499335, 0.04599591586156748, 0.020787465509783942, 0.03943071795220021, 0.02507906061509857, 0.044384460925357416, 0.07203808563644998, 0.04268126911483705, 0.01084716086552362, 0.022957599940127693, 0.004024699319415959, 0.05463222900289111, 0.041904422323568724, 0.03585512837162241, 0.07032036257442087, 0.06133867245807778, 0.06200548472406808, 0.042603158071869984, 0.054200966987991706, 0.06569625562406145, 0.03332398548081983, 0.043135726955370046, 0.02505694646970369, 0.014824821937509114, 0.06946582405362278, 0.06244688818696886, 0.07592766676680185, 0.03217504439817276, 0.019333705822646152, 0.017248825606657192, 0.016077100590337068, 0.02628826037835097, 0.07192811419372447, 0.040391884540440515, 0.024121140922943596, 0.015341951366281137, 0.029560281873273198, 0.033887049212353304, 0.023593689147674013, 0.056156273785745725, 0.03887432612827979, 0.010234722049062839, 0.018040715731331147, 0.027992769500997383, 0.07476146332919598, 0.05345230325474404, 0.06866902462206781, 0.08014555918634869, 0.0062875228923076065, 0.02054292785032885, 0.10234308487270027, 0.11107988480944186, 0.0463404393667588, 0.021623044012812898, 0.06747286810423248, 0.025287568860221654, 0.02850945085810963, 0.02271092675073305, 0.032776666412246414, 0.040595867540105246, 0.017258135849260725, 0.09306991996709257, 0.03718728716194164, 0.08273147628642619, 0.03716333434567787, 0.03833420960290823, 0.0625771054183133, 0.035262211749795824, 0.04931872623274103, 0.058169178664684296, 0.08398571328143589, 0.03323175878904294, 0.03952917497372255, 0.014480075788014801, 0.006012733438183204, 0.026168724507442676, 0.04415275499923155, 0.05545701482333243, 0.009406905483047012, 0.07083162810886279, 0.06353968579787761, 0.0348119878617581, 0.03053720425668871, 0.02644074946147157, 0.016687823190295603, 0.018085146257362794, 0.06478126175352372, 0.030233263241825625, 0.010966366480715806, 0.018525933737691958, 0.03561727746273391, 0.05057996168034151, 0.05875608760106843, 0.003778485565817391, 0.04023897985462099, 0.16793656046502292, 0.11953463152167387, 0.15923707571346313, 0.0961569203354884, 0.2053784896270372, 0.09116713496041484, 0.11822389482404105, 0.18280210497323424, 0.14184506755555049, 0.08607076975749806, 0.14337589556816965, 0.16255873575573787, 0.09303822283982299, 0.10095785139128566, 0.10044684560853057, 0.10467283485922962, 0.14245394035242498, 0.13373985013458878, 0.13881321618100628, 0.14833522320259362, 0.17633854789892212, 0.15394940710393712, 0.09004456238471903, 0.13762692280579358, 0.1289092405932024, 0.08605491006164812, 0.12373693141853437, 0.15487007098272443, 0.19001704204129055, 0.19601236330345273, 0.1625993609195575, 0.1688618998741731, 0.1790292636724189, 0.14604899275582284, 0.2260715261218138, 0.13589721405878663, 0.15695088979555294, 0.06117525525041856, 0.16233653674134985, 0.08755221526371315, 0.1106705903657712, 0.11188673292053863, 0.09844436790444888, 0.22693229868309572, 0.1279787952080369, 0.1516343664843589, 0.17459982947912067, 0.11718412366462871, 0.1947128924075514, 0.09817961414228193, 0.099001357157249, 0.09576446522260085, 0.15821732027688995, 0.14792024390771985, 0.10803880853927694, 0.15290943556465209, 0.07929163664812222, 0.08972718293080106, 0.19696367788128555, 0.10857255372684449, 0.15076894807862118, 0.09000780381029472, 0.1999049575533718, 0.11085901423939504, 0.11252817857894115, 0.22482689993921667, 0.20263343380065635, 0.06899383297422901, 0.1041086541954428, 0.08054248202824965, 0.1619452764862217, 0.21704787126509473, 0.12030262820189819, 0.2284750307444483, 0.1546316040912643, 0.09703845818876289, 0.1099569485813845, 0.194112851168029, 0.1456100569339469, 0.10627857525832951, 0.22147157607832924, 0.11173396182130091, 0.20815196970943362, 0.1044022107089404, 0.2162484297878109, 0.0981265951122623, 0.26957911730278283, 0.1659922522958368, 0.14214704744517803, 0.13104150508297607, 0.1597966847475618, 0.08251361883594655, 0.15055089024826884, 0.12203075617435388, 0.10655095087713562, 0.1569359577842988, 0.14219168020645157, 0.18778133700834587, 0.1240445367875509, 0.18420224077999592, 0.17161318974103779, 0.18882636999478564, 0.10867446544580162, 0.15043035062262788, 0.1626578569994308, 0.133850148122292, 0.13184197072405368, 0.1316365145612508, 0.22152824647491798, 0.11009696216206066, 0.1606538801570423, 0.12813872803235427, 0.16108993644593284, 0.1857466797810048, 0.09668919607065618, 0.16069946286734194, 0.07876780655351467, 0.08635355028673075, 0.10230851563392207, 0.1429786387598142, 0.12084462607163005, 0.12755133298924193, 0.09520278559648432, 0.07909614010713995, 0.11241565414820798, 0.18333572399569675, 0.11153669896884821, 0.11792649398557842, 0.16631919803330675, 0.09011446527438238, 0.14764560473849997, 0.180790810554754, 0.1546020369278267, 0.09890958317555487, 0.14037347777048126, 0.24027526786085218, 0.18359688576310873, 0.14717742829816416, 0.13104689307510853, 0.1110401502228342, 0.13522944442229345, 0.17970972403418273, 0.21849335229489952, 0.15080808894708753, 0.1761927010375075, 0.09599410055670887, 0.10708379806601442, 0.12417866513715126, 0.1252272233250551, 0.13286506582517177, 0.10932013392448425, 0.22870362707180902, 0.14546446240274236, 0.2141391867189668, 0.17026626592269167, 0.13116373680531979, 0.07500036808778532, 0.18594410590594634, 0.15563905471935868, 0.11712407649611123, 0.11766386276576668, 0.09856271077296697, 0.13609483314212412, 0.0845049940107856, 0.11884902807651088, 0.14510349661577493, 0.10190817149123177, 0.22599557472858578, 0.08704238949576393, 0.19349363283254206, 0.11256348254391924, 0.09946911057340913, 0.19327888498082757, 0.14657703082775697, 0.0982281802862417, 0.23864570452133194], [0.02228819201263832, 0.04743350044009276, 0.04662506784370635, 0.0328224828990642, 0.023840790927351918, 0.02329834591364488, 0.006013139764036168, 0.06903554909513332, 0.017980638876906596, 0.030413269305427093, 0.030961271149863023, 0.028674096320173703, 0.06067517759220209, 0.03938202193239704, 0.0358623457577778, 0.016185726890398655, 0.04052249511005357, 0.023798846596037038, 0.013090771626593778, 0.09138694425928406, 0.021166446931601968, 0.037065374563098885, 0.05231914765317924, 0.04427433363161981, 0.017284175955865066, 0.03745037109183613, 0.016656263360346202, 0.026063814511871897, 0.07335793590755202, 0.06215480112587102, 0.020668610559368972, 0.05969489699054975, 0.023999886980163865, 0.055453704844694585, 0.03050729756068904, 0.06011545723595191, 0.036398966767592356, 0.016028386016841978, 0.020213379029883072, 0.027897989821212832, 0.015016760808066465, 0.01329767590505071, 0.07048324172501452, 0.03318012757517863, 0.04895453581411857, 0.032319956153514795, 0.08243783813668415, 0.029934502417745534, 0.026096804831468035, 0.03429185366258025, 0.02088194276439026, 0.04363048712548334, 0.09331120701972395, 0.044656881073024124, 0.03963037423091009, 0.018333129337406717, 0.03434466489125043, 0.03459496903815307, 0.017947986234503333, 0.044040969005436637, 0.041812262425082736, 0.05068472324637696, 0.008664775432407623, 0.0364816197543405, 0.039253122013178654, 0.07130856189178303, 0.06473328932770528, 0.06523488467792049, 0.039271312052733265, 0.024160454340744764, 0.033016866218531504, 0.08761699733440764, 0.029458342323778197, 0.00885100069353939, 0.005795347715320531, 0.0414509663823992, 0.059214987195446156, 0.04982127524272073, 0.08491194326779805, 0.01735461690259399, 0.04662855964852497, 0.030567491303372663, 0.048971660871757194, 0.08557435459806584, 0.017245176095457282, 0.038295024205581285, 0.04760157462442294, 0.07839325946406461, 0.01700454027741216, 0.038709090658812784, 0.06708879926009104, 0.034473186315153725, 0.012465111449273536, 0.056299319039680995, 0.041084905751631595, 0.03822674661932979, 0.03190663184795994, 0.055540818138979375, 0.08651902695419267, 0.03582398043363355, 0.05885125690838322, 0.06432183523429558, 0.03733347912202589, 0.01784911917638965, 0.016942311194725335, 0.05280045639665332, 0.04945773420331534, 0.010863519655686105, 0.025091819989029318, 0.007346812535615754, 0.04049991155625321, 0.008435233794443775, 0.11778656946262345, 0.04164413257967681, 0.003368777606738149, 0.09521051877527498, 0.040385090178460814, 0.09856495205895044, 0.019408803746046033, 0.011826412664959207, 0.029754646639048588, 0.05940474693488795, 0.024796604775474407, 0.044421434722607955, 0.003942215171264252, 0.03703961461724248, 0.02863725610950496, 0.07707441851380281, 0.05458460538648069, 0.02145889950043056, 0.045360908334259875, 0.031002079995232634, 0.010961008174490416, 0.032565996662015095, 0.006576906680493266, 0.0802579871378839, 0.04067137364472728, 0.008755489070608746, 0.045150891673984006, 0.041193867873516865, 0.05122371170728002, 0.021984353043080773, 0.028801051812479272, 0.01767357342032483, 0.02610604828078067, 0.015181365452008322, 0.042377259451313876, 0.005795972510895808, 0.03946135380829219, 0.03688262069772463, 0.012314537107158685, 0.027066481998190284, 0.044445454332162626, 0.14402298897039145, 0.08719210294657387, 0.11523686174768955, 0.03961934220569674, 0.019314649325679056, 0.01679664244875312, 0.03317596412671264, 0.035750849201576784, 0.023003928508842364, 0.021576129147433676, 0.025939222759916447, 0.047664768499089405, 0.02100391659041634, 0.07502995009417646, 0.02382638955168659, 0.05188591152545996, 0.030306797088996973, 0.018502843668102287, 0.07607721694512293, 0.03526183696521912, 0.05171909157070331, 0.016361606612917967, 0.028482303096097894, 0.028188776268507354, 0.036020141196786426, 0.0614209543709876, 0.01421799654053757, 0.07710385209065862, 0.03711847522936296, 0.03907177451765165, 0.01696171093499288, 0.04838777247641701, 0.012575507771543926, 0.008958882062870543, 0.05616304217255674, 0.03671348524221685, 0.005439183159978711, 0.041602334822528064, 0.025680651087895967, 0.045408027290250175, 0.029194430899224244, 0.0322672154288739, 0.04330581607064232, 0.030250980162236374, 0.07268632936757058, 0.03865692880935967, 0.007112152397894533, 0.015152090509218397, 0.07677963003516197, 0.020365003510960378, 0.03532162809278816, 0.09964071738068014, 0.04176299866230693, 0.02921176746895071, 0.007742359157418832, 0.04209943646856118, 0.02078918543702457, 0.04378567391540855, 0.06742196419509128, 0.01713319157715887, 0.03978180575359147, 0.02985664741572691, 0.02053609823633451, 0.07185662310803309, 0.07286592910531908, 0.0013111633165863168, 0.03448488627327606, 0.03860521595925093, 0.03383227871381678, 0.01582869819685584, 0.028266781555430498, 0.027177650154044386, 0.02010317566600861, 0.053533776226686314, 0.0191615090079722, 0.056633114800206386, 0.05901896372961346, 0.07260843354742974, 0.03935054373869207, 0.019504223528201692, 0.07124260722775944, 0.03207549641956575, 0.05026250801165588, 0.013054024184384616, 0.034987023391295224, 0.07815602453774773, 0.03749820250959601, 0.023763371937093325, 0.016621233990008477, 0.0536444823956117, 0.05102442650240846, 0.03521914120938163, 0.020594930138031486, 0.022993501333985478, 0.03523819585097954, 0.051606240594992414, 0.07110653445124626, 0.04073441908985842, 0.07299180477275513, 0.04370890244899783, 0.03551831949152984, 0.04914165721856989, 0.031597338092979044, 0.03706839510414284, 0.010131900271517225, 0.010772238274512347, 0.05304323145537637, 0.02846646195393987, 0.015152082160057034, 0.03597937502490822, 0.05105583790282253, 0.017686848586890846, 0.018682209629332647, 0.03213647498341743, 0.03620060182583984, 0.04106608117581345, 0.019613200493040495, 0.03752480108232703, 0.07302074853214435, 0.04880177213635761, 0.04683071696490515, 0.07219742474262603, 0.012383849989419105, 0.061690502407145686, 0.05371992912841961, 0.017849757423391566, 0.0502110029628966, 0.044120920574641787, 0.0248309105518274, 0.07405713549815118, 0.03102568214671919, 0.026444586364959832, 0.012949389711138792, 0.04795084416400641, 0.07178996340371668, 0.018093033431796357, 0.02045812077994924, 0.02733381657890277, 0.057628130743978545, 0.0430160704854643, 0.034115370945073664, 0.07878629345213994, 0.0429055646964116, 0.03715417624334805, 0.09107113815844059, 0.07543214960605837, 0.05143531285284553, 0.030331377020047512, 0.0342559003183851, 0.04711694105935749, 0.10026709001976997, 0.026655276524252258, 0.10059788008220494, 0.07203835280961357, 0.06973460767767392, 0.027181759796803817, 0.023059229642967694, 0.04272212434443645, 0.011348691277817125, 0.0360253473627381, 0.033797412615967914, 0.03931973347789608, 0.025414316551177762, 0.07568259476101957, 0.016992022101476323, 0.04978887678589672, 0.02369907782849623, 0.01990526343433885, 0.049151234634337015, 0.0592522689839825, 0.03026026071893284, 0.03122757414530497, 0.057510849146638066, 0.021422573227027897, 0.049302391562378034, 0.07884175414801575, 0.08437396041699685, 0.07705462543526664, 0.03565855942724738, 0.03985522642324213, 0.0457504245423479, 0.001492914818754798, 0.020424985741556156, 0.0544355672900565, 0.013462315801007207, 0.021570689204963855, 0.049457637724117376, 0.0561422694590874, 0.05016413633711636, 0.022307376530079637, 0.0429372135840822, 0.08794833658612333, 0.018200292324763723, 0.02915377790486673, 0.06266712793149054, 0.03260606150433887, 0.02349443246203009, 0.03593508365156595, 0.03129269018245395, 0.12638541898922995, 0.13114420347847044, 0.11951541731832549, 0.08074631288764067, 0.10900509965722449, 0.08813097912934609, 0.15173068240983412, 0.13964491139631718, 0.09213988276314922, 0.11464595634606667, 0.08369429415324703, 0.16612928244285285, 0.13421464653220028, 0.0969560130033642, 0.12893054023152217, 0.10980416263919324, 0.10205993326962925, 0.08487960789352655, 0.1295369045692496, 0.21498636313481256, 0.09019678429467604, 0.15973936126101762, 0.15229247335810214, 0.08261844719527289, 0.08758724463405088, 0.14477469550911337, 0.15271597250830382, 0.12832335953135043, 0.2021664596395567, 0.12180873527540825, 0.13545251917093992, 0.1471351704094559, 0.08735170922591351, 0.16106773138744757, 0.14980887615820393, 0.14711504336446524, 0.09302674181526527, 0.10766072140540928, 0.10959692532196641, 0.22744451416656375, 0.15508983575273305, 0.1733802878879942, 0.10377246129792184, 0.142121116805356, 0.1684478556853719, 0.12871880549937487, 0.1937046105740592, 0.11152899547596462, 0.0915468177117873, 0.10902239169809036, 0.11498873209347948, 0.14194849325576797, 0.1242031560104806, 0.14055527426535264, 0.14497412543278188, 0.1305715474882163, 0.11678158276481554, 0.14577276539057493, 0.1571571474778466, 0.23864531860454008, 0.1262473943643272, 0.2233264851383865, 0.22388740035239607, 0.147010148211848, 0.13892577029764652, 0.17885358247440308, 0.1360132117406465, 0.10101957581355236, 0.10028490156400949, 0.14103973342571408, 0.12031164529616944, 0.1614247786346823, 0.189998087589629, 0.1494129403727129, 0.13182758790208027, 0.1330931723350659, 0.17416770657291636, 0.18917841516667977, 0.201031997858081, 0.1470927640912123, 0.11701611627358943, 0.15355885931057855, 0.11392658518161625, 0.22658081754343584, 0.1814707662560977, 0.13787119329208508, 0.13479120621923357, 0.2449485717806965, 0.14558767376001924, 0.09015621108119376, 0.10129066009540111, 0.14078300970140845, 0.09351735337986611, 0.17983401892706752, 0.10304177238140255, 0.18947613512864336, 0.1766299150767736, 0.1226150787260849, 0.14746273955097422, 0.10941460932372138, 0.17934703646460548, 0.10469054250279441, 0.11697722773533314, 0.13822018081555143, 0.23277096741367131, 0.17353759350953624, 0.1760698013822548, 0.10341002605855465, 0.12898722547106445, 0.15416813286719844, 0.12570155959110707, 0.1358844491187483, 0.2088044659467414, 0.13819184561725706, 0.08098392630927265, 0.1729474970488809, 0.11611136404098943, 0.1936982577899471, 0.15837967250263318, 0.14235266688046977, 0.06299763597780839, 0.18630826292792335, 0.1624290825566277, 0.1703616912709549, 0.21291473211022094, 0.10191842055064626, 0.1135067077120766, 0.20909783692331985, 0.12314918014453724, 0.2842667541699484, 0.10515647765714675, 0.12228206964209676, 0.08173962560249493, 0.1028068306914065, 0.1757314710994251, 0.16163225343916565, 0.15021104598417878, 0.0760757400712464, 0.10368538511102088, 0.12851707491790876, 0.096375096909469, 0.09408105906913988, 0.1413085838430561, 0.07323693615035154, 0.12477483978727832, 0.15274933946784586, 0.09006088963360526, 0.1379173994064331, 0.14119585161097348, 0.20033700624480844, 0.23962450824910775, 0.11660295524052344, 0.19641969847725704, 0.2771124505670741, 0.2437379804905504, 0.14012969710165635, 0.10128629626706243, 0.13564264256274328, 0.08902687011868693, 0.09062153767445125, 0.23096040909877047, 0.05518087280506734, 0.08416707933065481, 0.1193438698828686, 0.15664421953260899, 0.09714671527035534, 0.1527145178988576, 0.15921316371532157, 0.19684058526763692, 0.08556993139791302, 0.14936474530259147, 0.14255236397730187, 0.17586113914148882, 0.06666671761195175, 0.09054198686499149, 0.05461564571305644], [0.015394965757877799, 0.05376302564400248, 0.014321048383862944, 0.033235662485822104, 0.017957769596250728, 0.007194239033196936, 0.032712782340240665, 0.026985179720213637, 0.05435653598397039, 0.05949309219431598, 0.010293080831615953, 0.08309590790304355, 0.05620384545181878, 0.04403921382618137, 0.0036700262489830493, 0.02548131949879462, 0.056147427385440096, 0.04927762238366995, 0.03608404011174571, 0.006651999037785572, 0.01799808676878456, 0.03860441815049853, 0.02396293915808201, 0.0313046758674318, 0.01383039785650908, 0.038967365471762605, 0.03276868461398408, 0.04806247430678923, 0.023225710065162275, 0.06657662830548361, 0.03907306585460901, 0.11158726149005815, 0.03720608205185272, 0.03988799966464285, 0.04121339006815106, 0.03996664876467548, 0.053216645392240025, 0.053640478508896194, 0.04289443990273867, 0.045423931514960714, 0.12776811432559043, 0.08171431836672127, 0.03923847201804165, 0.05983471390209161, 0.021965764099149965, 0.06583252135897055, 0.05034324996813666, 0.05277976160869002, 0.04136709998419974, 0.05764456931501627, 0.03550064153387211, 0.02501689832570264, 0.02049480885034427, 0.09088245453312993, 0.05006117818993516, 0.017943960083357524, 0.0523914625227917, 0.009358677943964722, 0.03560988567187451, 0.09124111966229975, 0.08226471734815277, 0.023110755100788083, 0.1284490348189138, 0.0064471695259271655, 0.017357919459755067, 0.03373930245288648, 0.030463996954495087, 0.02289862331963377, 0.03565214356058277, 0.03013389894476859, 0.028627990395762026, 0.046156256867107004, 0.04220596805680543, 0.0705449290398974, 0.03543024882674217, 0.013983571570861386, 0.039241303311428055, 0.08004471616004594, 0.04191158775938675, 0.018307797981833573, 0.008389155700569972, 0.04732765162771102, 0.030146793760650326, 0.07268154993653297, 0.08005446798051707, 0.04516809465712868, 0.0676753259904217, 0.04721594355942216, 0.014438134239753708, 0.04227331424772274, 0.046822701769997366, 0.03419039465370588, 0.019262294517830014, 0.043745019065681845, 0.021359589009080082, 0.03110179866780527, 0.03752988108317368, 0.05086943267087918, 0.03627761449024547, 0.024902030563680455, 0.005087728923172108, 0.033510060457047075, 0.03866176019073464, 0.060056389702367596, 0.03148040901578497, 0.029942853434477, 0.01987959440157283, 0.06323049965430982, 0.017945761646842584, 0.024131686841428746, 0.09134565858403221, 0.03034336827113293, 0.022772144657210447, 0.05149915239599068, 0.04077290686836932, 0.008001579280971782, 0.03543292797985487, 0.015209245157166151, 0.02147488165064715, 0.028193375728733372, 0.008558863537473371, 0.05571738620346878, 0.03582362049201038, 0.07391808670945466, 0.00793283135863021, 0.047222711946233176, 0.025007202166307252, 0.09681735013145953, 0.008363851247850107, 0.0668198820494581, 0.0401779159437865, 0.04267777731001843, 0.033689470947138034, 0.04492287051107269, 0.05049386883911211, 0.03869318272336386, 0.028010636706312653, 0.014692744698550086, 0.027124940970679745, 0.05986597316223197, 0.013007610268687131, 0.022044569050194696, 0.03057488866033964, 0.010949252555292333, 0.048897319938987494, 0.025765970240172464, 0.026841006401809864, 0.03403646951483097, 0.035756393044721335, 0.07262846411322244, 0.0642736921145115, 0.07848684428608976, 0.04623921413440257, 0.08426159925875254, 0.030148879195621703, 0.013888248267903691, 0.019511097671056632, 0.04475649955566041, 0.01911239181936253, 0.012019768109894358, 0.03070573857257841, 0.022579041542485356, 0.053373060436570086, 0.042656462828745134, 0.04461160635401029, 0.039844550628913566, 0.01467960868467344, 0.019512268409016542, 0.11343216639943421, 0.05294350536132697, 0.04115515745070297, 0.07180750035331585, 0.008867184151313268, 0.043198646235396154, 0.04148229614656884, 0.020353283143776935, 0.03129393699055072, 0.07988316545379348, 0.017402776720700786, 0.09290000525652431, 0.04370951101009268, 0.060222422980587, 0.007444953680533217, 0.04398612058139406, 0.03846235624223482, 0.07310611777938902, 0.01620240851480048, 0.12244347191881388, 0.05480883046402596, 0.025076119854929857, 0.03777496793190949, 0.03843859267362859, 0.047044974999153055, 0.04077320372743998, 0.039043264914653264, 0.02382299237069674, 0.034584649474709295, 0.0710391548636835, 0.0759630894754082, 0.030761754023842514, 0.005105820164317265, 0.05974315143248532, 0.012764135735778837, 0.010662457934813574, 0.010713565006881254, 0.096747929637786, 0.06561899805092253, 0.1270094612846151, 0.02721809534705244, 0.047781972170923837, 0.041484604225843213, 0.04978287652193103, 0.03001344095537206, 0.057861777386278845, 0.04072178031492513, 0.04562853791867383, 0.041104802730842493, 0.06945429850020446, 0.07182981673395261, 0.023444992439181078, 0.024798493541311473, 0.054915354630793445, 0.04858610402152408, 0.02048235746769933, 0.03694113533128984, 0.0674746566801332, 0.10853227737243287, 0.012178135930298595, 0.01280735192267457, 0.005100124180899002, 0.10467931380844675, 0.03289349901024252, 0.02567986255598953, 0.029489288026525173, 0.02406628136668587, 0.08961625411757268, 0.03424375507165678, 0.015733367472421378, 0.05209359042055439, 0.05617541006358806, 0.01946169290022226, 0.017736045556375757, 0.09957019850844517, 0.021614346042042598, 0.03821047874225769, 0.06774623820092529, 0.028534105003927834, 0.08977787161711603, 0.012385088448354509, 0.011457714626885718, 0.08919515210436657, 0.05959804300800897, 0.041905995676643215, 0.06527128702146001, 0.036125774786341935, 0.04864147565967869, 0.024928026141424198, 0.07336510505410843, 0.05715944222174585, 0.06930559437023476, 0.05891850290936418, 0.04237440960423555, 0.03750334188225679, 0.037690114477300085, 0.053686565879615955, 0.012243144356034463, 0.048286799574270844, 0.04892512450169306, 0.06429114742786624, 0.02715628557780292, 0.02599927920527989, 0.056347573481616564, 0.03054608776437817, 0.02702712590689771, 0.006459062906287727, 0.008270421349152457, 0.05734325364755932, 0.036750228973687626, 0.021512371240532957, 0.04346253910625819, 0.049411858344683424, 0.02278743475471856, 0.010907933483395027, 0.058294334448874, 0.029755364666925743, 0.04401555786898825, 0.10431083748699166, 0.060615820621023886, 0.037794634845340624, 0.052603794683818705, 0.0501105013245251, 0.04388800494780298, 0.014833698951406404, 0.020326027770352084, 0.026504162269702647, 0.03404633636819199, 0.05453858851979021, 0.058889050778816454, 0.02504714826500276, 0.046330539116752334, 0.03861361707095057, 0.10807555227074772, 0.04620389903720934, 0.039724511952954344, 0.021001493478252087, 0.040600962383905426, 0.011141514260089025, 0.07861634905566461, 0.026681509589252528, 0.016878046772035304, 0.011981400930380914, 0.03033231769222766, 0.10327739684726112, 0.06941702784388326, 0.033673522193566896, 0.05136997046065517, 0.027964439868810587, 0.036135619375272654, 0.033322616218356416, 0.0206313566013705, 0.03831836846075021, 0.04771153864567168, 0.09428778430446982, 0.023281515859707724, 0.004978369752279832, 0.06325431517325342, 0.0759729823039379, 0.017380202443746384, 0.053363019178505056, 0.03193140102666803, 0.049504203780088574, 0.040225817865575664, 0.02032433752901852, 0.030856674711685628, 0.017405711914761923, 0.052563065619324334, 0.007050075455481419, 0.015235950413625687, 0.0684262606955599, 0.09866930544376373, 0.021664466985384934, 0.06482501878053881, 0.05121204143506475, 0.020554980328597594, 0.04575941937218886, 0.05472785844176542, 0.03534156960085966, 0.028942943026777357, 0.0695508519129362, 0.017448929029342253, 0.023797818721504882, 0.07277144628460519, 0.11135789332911372, 0.19646149623440579, 0.1562035916140303, 0.19508460449287668, 0.15007365960627794, 0.17272284894715995, 0.11064598817029037, 0.12236924230819568, 0.20052813895745203, 0.1507682801457122, 0.11833189957542345, 0.27359514555428177, 0.1491542425355874, 0.12491900939494371, 0.08475341310258955, 0.11177905471413396, 0.13708251295611262, 0.27419364312663674, 0.1201895545818843, 0.1520453381817788, 0.1156552771863062, 0.1392737336573191, 0.18634223844856024, 0.11285232641967013, 0.23248483979841694, 0.1041855406947434, 0.10045232265838422, 0.19205627089831978, 0.1289435278158635, 0.1846852750168182, 0.14597102272091433, 0.24525252578314394, 0.13771681173238903, 0.29360398126300424, 0.11645724196569063, 0.16259802505373955, 0.12542837503133342, 0.1162489879061468, 0.1283030692138709, 0.16014236229239032, 0.2032699590199627, 0.19398910546442494, 0.1892590569332242, 0.1074266702926252, 0.1344599708681926, 0.16061528847785667, 0.11825611887616105, 0.19207715493394062, 0.17351362213958055, 0.3240031219320372, 0.18233440350741148, 0.14887534343870357, 0.09606116844224744, 0.13128163438523188, 0.15551323100226, 0.1076623318658676, 0.16990887728752568, 0.10358820829424076, 0.08629439369542524, 0.17344782332656905, 0.16199865174712613, 0.08052187258726917, 0.21858220221474767, 0.11244856839766726, 0.19557289313524961, 0.13987653568619862, 0.1588387947413139, 0.13605297601316124, 0.18199065554654226, 0.18437384016579017, 0.10497535651666112, 0.1845520149799995, 0.08046532093430869, 0.18338794150622562, 0.1780571838025935, 0.22337677306495607, 0.12140872509917244, 0.13076667295536026, 0.08662815977004357, 0.14668492425698787, 0.1236839198099915, 0.18321833107620478, 0.1412772503681481, 0.14149248803732917, 0.17354511888697743, 0.13601827318780124, 0.13143519958248362, 0.1326830021571368, 0.15755238564452156, 0.12802608485799283, 0.18651588616194203, 0.15660878940252587, 0.11928587846341543, 0.14713059877976775, 0.15074467984959483, 0.14058916072826833, 0.1043662907613907, 0.14766366861294955, 0.17193082894664258, 0.08560923553886823, 0.10745621519163251, 0.11914273301954381, 0.11192950289114378, 0.14483209321042523, 0.1137648118310608, 0.1448901736875996, 0.13047566200839356, 0.15892029739916325, 0.07735022285487503, 0.1379000479937531, 0.20339823182439432, 0.15282717591617256, 0.12898450921056792, 0.20890781743219122, 0.1510810063336976, 0.14776488271309063, 0.11860071288538165, 0.12141461033024825, 0.1021228228637483, 0.1838194706942886, 0.10134655865840614, 0.19625146844191477, 0.10560263457591645, 0.18512502720113844, 0.06423966464353725, 0.19739102135645226, 0.14085994072956964, 0.19424226687988266, 0.09863765284535475, 0.08500659678247757, 0.20008443854749203, 0.12744314270094037, 0.12756374169839546, 0.12671064294409007, 0.14336004329379648, 0.22243982646614313, 0.25968866364564747, 0.09547952504362911, 0.07688950499868952, 0.13821320462739095, 0.09660549665568396, 0.11820540050393902, 0.13065814127912745, 0.13166857534088194, 0.1731263694819063, 0.09070342624909244, 0.17334669828414917, 0.1283742263331078, 0.11700635703164153, 0.17341356578981504, 0.19463318574707955, 0.17638074641581625, 0.11621172467130236, 0.16682080080499873, 0.1459214769420214, 0.161688523076009, 0.12405601781210862, 0.11105675948783755, 0.09327051506261341, 0.1677451902651228, 0.08988381319795735, 0.10018259650678374, 0.14845556986983865, 0.2485086690285243, 0.12659587722737342, 0.15758321445900947, 0.12280775510589592, 0.14762748149223626, 0.2437096749781631, 0.21756335219834, 0.1357065117917955, 0.1392509794095531, 0.20467931230086833, 0.07646483325515874, 0.09188853218802251, 0.1681935810483992], [0.09029028005897999, 0.02386307762208162, 0.04480689138290472, 0.0553540418331977, 0.018067225246340968, 0.02580803702585399, 0.0641201640246436, 0.03620938143285457, 0.024006371495488565, 0.02744659890595358, 0.0445275692618452, 0.029150074587960262, 0.041675217435113154, 0.012415044311637757, 0.02615547531604534, 0.018251762121508364, 0.05597258852503728, 0.08585269708419219, 0.04814172083570156, 0.050276189504074864, 0.013485636864061235, 0.04982533850125037, 0.042409242305438966, 0.01564795740705449, 0.03198850557964761, 0.055673269234830514, 0.028746546631737147, 0.014627718646806898, 0.0902119092643261, 0.09879963399725966, 0.037584399251500145, 0.019322139451105613, 0.04305654721974861, 0.05615442212729249, 0.022363904063240625, 0.024033062836679164, 0.03014100315340329, 0.008987400942714885, 0.06715244584484026, 0.01497687779192347, 0.028797611957998015, 0.04989793167624157, 0.04988791268260684, 0.02839337339537451, 0.023070361858117394, 0.05964578907878604, 0.05414976993051823, 0.013889545170968631, 0.06092392322898377, 0.03035882535186829, 0.01189555670862319, 0.042563738898024894, 0.0197009520343272, 0.07484142231987789, 0.03434223064687103, 0.023165332640928682, 0.035968317024526186, 0.02899077629990643, 0.029022028138570022, 0.02755588386207819, 0.06089398870244622, 0.03304439247585833, 0.026949868333758786, 0.027160493555129506, 0.019244588729634415, 0.027367712318664417, 0.047389075480168685, 0.034532699137344025, 0.052959428139729425, 0.020419681241037324, 0.03491148760076612, 0.02358770558203105, 0.02293402376380982, 0.03764911823964212, 0.02999453845404787, 0.024185969377867877, 0.024886276623874437, 0.04114097129786387, 0.022197024736669846, 0.025935469348041806, 0.07446542804245837, 0.04278193031495903, 0.016060973721323535, 0.012686632326222025, 0.011202064233657438, 0.03357434157805983, 0.058092967519769445, 0.018486687113181688, 0.10830718398210593, 0.03511553739372175, 0.0375278624414932, 0.02563129826739896, 0.06026256574841682, 0.05424470546131488, 0.039497670804848894, 0.03923769276298117, 0.045794118486810476, 0.011799881813203683, 0.060290021501714364, 0.04850828983762767, 0.046731903712498024, 0.04857067848206498, 0.02917819827416679, 0.040105140942614526, 0.027707586268661544, 0.026567274508124683, 0.012029531062580645, 0.07642178868991323, 0.053997180657461286, 0.05110582154884469, 0.013338640601432417, 0.02998719490278745, 0.06372104442561977, 0.0808677876193542, 0.037084470022819005, 0.03141154513286892, 0.035951607569586486, 0.1064202883571852, 0.09325731225544587, 0.050458999030524865, 0.0038218736062844982, 0.03975593819632195, 0.031769442139193416, 0.06597623825655319, 0.0615579956502188, 0.021579090316663496, 0.03709729804540984, 0.02942538540082751, 0.04548602330032736, 0.05233919306192547, 0.03909525607014075, 0.028436399406928103, 0.03683347938931547, 0.036937777113053016, 0.02475469940691255, 0.05684882744390052, 0.021124914492247626, 0.0224301722846576, 0.01715583635814255, 0.03233185278077144, 0.05559536970395129, 0.024130208112183027, 0.03456554659351241, 0.03361484057677444, 0.06469285712228157, 0.0670330120192375, 0.06287645810516551, 0.19177084090188146, 0.03154927289870102, 0.07862209327868186, 0.02811745958751999, 0.03385909993085079, 0.010378477909398498, 0.03446127855568193, 0.09680331611889414, 0.011786796821979806, 0.09408919300767593, 0.02714086189371301, 0.03550895729858894, 0.03671978607599158, 0.020861327757302206, 0.014290293784142705, 0.03297587369161192, 0.061501414311351255, 0.050206694795633666, 0.027911875404242892, 0.024998745393531863, 0.020807642649742775, 0.021758296716143377, 0.07188897332525812, 0.05381216324167326, 0.031742773062433116, 0.010373532422818244, 0.03884855133946985, 0.04730903856398072, 0.05438138308818452, 0.041614580259192735, 0.02841459139744984, 0.047108573344303295, 0.027897989821212832, 0.036130294465692714, 0.04600489955919329, 0.06604792972211726, 0.059850261895917356, 0.037330970662878826, 0.02159236177249113, 0.09674293498392217, 0.060423545000958256, 0.08585051517002285, 0.03730926284333691, 0.07242229548864998, 0.0365491217962699, 0.07688472556765191, 0.06028504911228083, 0.03487362322630361, 0.035293897744850256, 0.005584042964983382, 0.05033154258853756, 0.033366417774232104, 0.056937154149636626, 0.02824356717610499, 0.0638276019890327, 0.0339311142306542, 0.019937149809265975, 0.09671900072135031, 0.12396568359690718, 0.039021920747472905, 0.005637664062305703, 0.02539711356803309, 0.06207261198142078, 0.037587497718050145, 0.00594850983361539, 0.027713156086974777, 0.049109885876532644, 0.0519173526117811, 0.038035866236896254, 0.052486821077764034, 0.09196199738653377, 0.0785423198249191, 0.02010556352615822, 0.028208391231601126, 0.007351450958594796, 0.05540480473428033, 0.028742585418513045, 0.06622054585022852, 0.021990366294630803, 0.027847486671817023, 0.020262869147700258, 0.03643078634922858, 0.06487441612989642, 0.029486774001270533, 0.03728838993993122, 0.04457552684471011, 0.04159506548603531, 0.05471962802403141, 0.07051658642012626, 0.08340582135133445, 0.03534499461238738, 0.03411240606510546, 0.04001237619377207, 0.02552519341406878, 0.03598714531108271, 0.032587203531875275, 0.02664889776497148, 0.05125384661369026, 0.028496743434516247, 0.04297220213629771, 0.0654587238386739, 0.019360161531949416, 0.05055019413703121, 0.007511319772675051, 0.05247490218607709, 0.06662853411398828, 0.035926508135162294, 0.03615904897742439, 0.028531192074296996, 0.01267481269678683, 0.04882451154117007, 0.04541757873084862, 0.02295672420586925, 0.02397656313405605, 0.02044952485448448, 0.07952976957312785, 0.0871811636898201, 0.10481836259714328, 0.04603096378559712, 0.0509261958359275, 0.05669571124599315, 0.0361203385546105, 0.04618000930349808, 0.06820721580879763, 0.024814720600261353, 0.04762269243656192, 0.04102095488633495, 0.08587321746745147, 0.013880476126360008, 0.03297335781098809, 0.04403519138577394, 0.03877473733155057, 0.040859682485461235, 0.02344123160582967, 0.037938232999294996, 0.06190362124470994, 0.047933507594279945, 0.06155576178571209, 0.05416626045189332, 0.06242842355277389, 0.05264751089271158, 0.026138385510421358, 0.057818847853923216, 0.03616758738644421, 0.02458156563079683, 0.004407763481140137, 0.08297462612972595, 0.07850600653910078, 0.023977086348168086, 0.015585856344841886, 0.022986680996837094, 0.026263927211402915, 0.06325343943899497, 0.09290707792388275, 0.032535631689825095, 0.05088024576252792, 0.026229178001813125, 0.03989342847489752, 0.041773106713662855, 0.03650068923889194, 0.009459194425289752, 0.07882477380917408, 0.009420406076969812, 0.04594389502017293, 0.014757863518752856, 0.04707751817477401, 0.052013939421158284, 0.04433495967532508, 0.04056152465636842, 0.02881908971176017, 0.013869769718439784, 0.03184173474437557, 0.043576636890065856, 0.02199877297243802, 0.03653441614005715, 0.01868403902335558, 0.1400243566604331, 0.053313729440560564, 0.0587169207574334, 0.0174000511833583, 0.012903839469800005, 0.03523408064211253, 0.03142766829114407, 0.06574057668331079, 0.01726999536913354, 0.04796652574441396, 0.03937465611670632, 0.11563570675207302, 0.013912722442910308, 0.04300241867895238, 0.053460426061064936, 0.03343578631756827, 0.04480991934542544, 0.027274340864096303, 0.068938505864935, 0.02392813428741647, 0.023177938019216526, 0.028576348049682565, 0.03480162748019211, 0.027793302469945047, 0.0060749110343749635, 0.03999539585493039, 0.04771668915054761, 0.029137513738533016, 0.08273469720734283, 0.11522935863467865, 0.09790920521481894, 0.2429077695705928, 0.17980126052862033, 0.14149970171274617, 0.12532607739558443, 0.14664530841400847, 0.139451255381573, 0.18121871806215495, 0.09896779723931104, 0.1569906243821606, 0.18331630941247568, 0.2253184688743204, 0.09934717571013607, 0.17765750759281218, 0.15537042694631964, 0.12309506273595616, 0.1907872874289751, 0.13639145472552627, 0.14510971581330523, 0.21146119135664776, 0.17904588778037578, 0.10052114943391643, 0.08307397001772188, 0.11405445722630247, 0.17578818602487445, 0.12695798592176288, 0.10323743961635046, 0.1257289299974218, 0.3006235108477995, 0.14283136697486043, 0.11405269091483206, 0.13909186294768006, 0.11420981099945493, 0.22819491452537477, 0.11546585141331889, 0.17337374214548618, 0.08837540546664968, 0.2055150447995402, 0.12345901937806047, 0.10689944858313538, 0.13143174117431045, 0.09356280992506072, 0.12042925343848765, 0.1050776986812707, 0.15322382416343316, 0.14631459256634116, 0.10281053400831297, 0.26189305004663765, 0.11473001199192367, 0.07769170726533048, 0.14892591338139027, 0.07891781686339527, 0.12517623777966946, 0.1631603651912883, 0.12804069032426924, 0.20001323689939454, 0.14775146468309686, 0.13241513137472793, 0.10209733751253225, 0.1881729534943588, 0.10345603921450675, 0.0979404644749593, 0.12410945986630395, 0.17517603293526918, 0.15212816186249256, 0.1686679618433118, 0.1372484423336573, 0.11942072669626214, 0.12613789789611474, 0.168962134339381, 0.19425878708716482, 0.1369494607206434, 0.1306587053113617, 0.11624453502008691, 0.11437166598625481, 0.15171376144280657, 0.14686060545500368, 0.08498782786773518, 0.11471982972580008, 0.15535029990132898, 0.17018881539115682, 0.16468167887069285, 0.12659837084356695, 0.15098927688086405, 0.11168862401973456, 0.2176974731264636, 0.2788176090689376, 0.22637522779405117, 0.22678817360429093, 0.19200402370188385, 0.24520070903236046, 0.2286334495875053, 0.1122859118913766, 0.13640267599839717, 0.10839414142537862, 0.14618581510148942, 0.13825795613229275, 0.1130519418802578, 0.09854282121523283, 0.12384469868266024, 0.11583282859646715, 0.10019759531132877, 0.10409654976683669, 0.12896441185148433, 0.13923042191891, 0.16378287866245955, 0.21942673658486456, 0.13775990082649514, 0.17199440131662413, 0.15188289689831436, 0.12499187345383689, 0.15327378554502502, 0.25761145167052746, 0.22232198825804517, 0.08511405234457925, 0.1199723279569298, 0.1948073084349744, 0.1732205628650263, 0.223657290043775, 0.120031684928108, 0.12026453376165591, 0.10364516070694663, 0.17201374168507755, 0.17970794287975878, 0.07653507011127658, 0.09625451275496744, 0.07698467801674269, 0.10457597716595046, 0.12106480644433759, 0.12861680472269654, 0.061112822077120654, 0.26061471551656723, 0.07514398108469322, 0.18285948783159256, 0.12531941290944815, 0.10461965997819789, 0.13902803824748844, 0.09323897378635593, 0.06678927587927319, 0.14140926359687, 0.14613309293054044, 0.14775786199606955, 0.08314540173159912, 0.18316088884603232, 0.15846121968934312, 0.14746725180884823, 0.19707572733750567, 0.19731685111764818, 0.1515801451751031, 0.19621593441115692, 0.07903082369011827, 0.15080304234288633, 0.16900773189263418, 0.1728372584329918, 0.07526843182859011, 0.16739462938858196, 0.11545067449333146, 0.16497344680828974, 0.133910306612961, 0.11428994068410248, 0.1485700238845311, 0.08165725463186391, 0.11961512485868298, 0.20728937146486714, 0.1778367065708153, 0.09381265394040383, 0.12015254367724992, 0.09113350824918598, 0.2203066268702969, 0.11145564902108163, 0.12944582820637152, 0.11902859070687555, 0.1792120694881305, 0.11794434263720177, 0.18375968327745795], [0.03412173486140091, 0.04258590313838795, 0.017791216814657673, 0.1060234397300519, 0.0687278769328259, 0.04480332907405682, 0.02208883444836829, 0.008297299154946813, 0.009734474624565337, 0.01466283058107365, 0.046339148029801436, 0.04308028110244777, 0.06541859591379762, 0.04009116630186327, 0.02646708828251576, 0.03571475113858469, 0.066962700948352, 0.025780111864150967, 0.0794077233877033, 0.044278608402237296, 0.04490162282309029, 0.00406808202569664, 0.034617070195963606, 0.042602790708770044, 0.017595226745470427, 0.012576754579640692, 0.022623761506110895, 0.008414772782998625, 0.009466481387789827, 0.05321198841556907, 0.02535423784138402, 0.05307427920342889, 0.042377511781523935, 0.0399777550046565, 0.05182353772397619, 0.01868944371381076, 0.10547914120252244, 0.01504400412159157, 0.13310480921063572, 0.043342006902094, 0.028723007562803105, 0.11461080823210068, 0.015522464873356512, 0.07298655778868124, 0.015397348051919835, 0.04631285373761784, 0.02239515775727341, 0.014808200612606015, 0.029312898077478167, 0.036758685746463016, 0.08566094838897698, 0.06652558338828385, 0.05005873281334061, 0.06277816806687042, 0.040661566163180396, 0.008020406639843713, 0.015705755868111737, 0.04475395027839113, 0.030659551011922304, 0.04685094791057054, 0.0003180170341465782, 0.04996587900677696, 0.05133852195285726, 0.0448684451112058, 0.0365225195128005, 0.035713266843231395, 0.035682671805261634, 0.04448308864084538, 0.017655240517342463, 0.023993665927264374, 0.02076849250443047, 0.018672569131013006, 0.030578124424209818, 0.012071478176949313, 0.04164094505540561, 0.008064313951763324, 0.022617681461269967, 0.011567183264560299, 0.07222220505354926, 0.05354867855203338, 0.024104227377392817, 0.0725989711645525, 0.005122328775541973, 0.009923274210450472, 0.022472098062280566, 0.02536566691560438, 0.022074613043514546, 0.03368758589203935, 0.024070530162134673, 0.04274447412171867, 0.045887829473940656, 0.027726798616640735, 0.024435921004624106, 0.019112790723738726, 0.006941817446204368, 0.03770801878999919, 0.0070304280234267935, 0.08332187702762894, 0.08247939840657637, 0.046273070911411196, 0.038763957636547275, 0.026936713766190223, 0.0671444900217466, 0.02796012984617846, 0.06405787557014264, 0.06436805619159713, 0.041821257254923694, 0.04221768656861968, 0.043642587843351066, 0.03199547434633132, 0.0244550665593124, 0.05475779667904135, 0.005267617170829908, 0.06449652937590145, 0.07127046003006399, 0.013305809843586758, 0.0434088447218528, 0.023310411379497964, 0.2056475033168681, 0.03103551560343476, 0.005672608549502911, 0.06823090516263619, 0.03769769551581703, 0.059059510967927054, 0.050821289551095106, 0.0710344867547974, 0.03930816710635554, 0.04398073629999999, 0.0756962205923628, 0.0282831588992849, 0.06295552651863545, 0.031436930294148624, 0.06020480068400502, 0.01607541591511108, 0.018965146009577438, 0.010831954259629129, 0.06540767892147414, 0.013507570110959932, 0.057671464746817946, 0.04145413535297848, 0.03362156814546324, 0.016036716624512337, 0.0703961358522065, 0.07711227546678856, 0.026254312688251957, 0.04566520743537694, 0.042030379627249204, 0.033185571228386834, 0.05945186589087825, 0.10191999390372075, 0.07468738956958987, 0.024532956813345663, 0.056027481477940455, 0.051009123417316005, 0.01952048212842783, 0.013532501634472283, 0.035244860337115824, 0.03173201192112174, 0.07305200037080795, 0.06153063637611922, 0.02747697872109711, 0.03777024045120925, 0.02893161043175496, 0.010403981814306462, 0.0212799324435764, 0.01576290680532111, 0.012883209619758418, 0.031570717255817726, 0.024092933745123446, 0.0753640427137725, 0.03078053592616925, 0.01773216969013447, 0.0350107758276863, 0.03294436952273827, 0.06691093614790589, 0.044286549382377416, 0.018294674955541268, 0.021673866285709664, 0.009105685367103433, 0.05836038188135717, 0.04122916441701818, 0.05509391165105626, 0.021483015589183196, 0.020637412526411936, 0.04501066287048161, 0.027532673193491064, 0.10828750222572125, 0.020598922892531846, 0.028088350700272713, 0.04839044420805294, 0.0040664233256393345, 0.10678984079277143, 0.033178639569086954, 0.04604703499353491, 0.031102932298381347, 0.030437075547524728, 0.04292970676033292, 0.03074520041991491, 0.012951952903677011, 0.0060127274082333315, 0.015308021302189445, 0.06855217347037978, 0.04502511990722269, 0.015680999676987994, 0.06870129320304841, 0.03377367502253037, 0.06035464772139676, 0.05102372888359241, 0.019816656567854807, 0.03577355520974379, 0.04946633940562606, 0.02651362094184151, 0.07047215403872542, 0.037514307114179246, 0.022284449732978828, 0.0318777585926, 0.011354970774846151, 0.046725832944503054, 0.06969525900785811, 0.08600898596341722, 0.04806121636647731, 0.07347053455305286, 0.021562865113082808, 0.016611881073913537, 0.019266715862613637, 0.08864710573107004, 0.05967541190329939, 0.034309208785998635, 0.06292812642641366, 0.016098279629659373, 0.046970429975772277, 0.038979128512437455, 0.05458633830130566, 0.03777430370973889, 0.034433960099704564, 0.006921051690369495, 0.03831673944659997, 0.016482845712744165, 0.02440173768263776, 0.02553771159000462, 0.03612509201047942, 0.011534843251865823, 0.03400911395146977, 0.00768276052440342, 0.03419471766392235, 0.010432826311443932, 0.051136802503606305, 0.05632941312796902, 0.08407818488194607, 0.025262875751650427, 0.044001375426887535, 0.04042950771690812, 0.06880273736896925, 0.01158902930910699, 0.013943291505711386, 0.05697094413335435, 0.02632219322549645, 0.031214634800562635, 0.04464147779799532, 0.03633939086284954, 0.026880150981014594, 0.012025637570332037, 0.036987912899348885, 0.04649715127015952, 0.030763455397391226, 0.04153871050220914, 0.03603107303206343, 0.032584253494860604, 0.06694816969684325, 0.004253837878422928, 0.04066043809871189, 0.015324881969718263, 0.02234086779935751, 0.09707122400868684, 0.027647566930681933, 0.05317444687534589, 0.027483567137096543, 0.059728456908487715, 0.06442157246056013, 0.05106717049784493, 0.04589368872984778, 0.02805008556606481, 0.04024962967378087, 0.040970091795315966, 0.04390780544781592, 0.07870506538893096, 0.025090324561460875, 0.04531188948021736, 0.14692169905174524, 0.029621475659951102, 0.03621223870140966, 0.009894149552565068, 0.06521493574837223, 0.06315954291494563, 0.057450957829132676, 0.09852684277575463, 0.03403751223231666, 0.05687688433681615, 0.02934099393314682, 0.05434330349089578, 0.0428413169720443, 0.06362541869748384, 0.08552774030249566, 0.056655215958016925, 0.0821259654185269, 0.024633393513795454, 0.05224672888289206, 0.010145341493625892, 0.0167204906756524, 0.027492369008541573, 0.0414138293126598, 0.034269570678588934, 0.05071752988442313, 0.16229411558015272, 0.023222014169732574, 0.07089105929480866, 0.05602307683147956, 0.04642804618924856, 0.04083284271473531, 0.11797963918070309, 0.026898626747424714, 0.011469199362181826, 0.03324087978398893, 0.029339556022023316, 0.054832671958138235, 0.044146487562102266, 0.024411945923930034, 0.0028474821783674997, 0.07960924616781995, 0.02089225861709565, 0.01671018409979297, 0.02333410444407491, 0.03259233548305929, 0.02908425907662604, 0.048311153150280006, 0.06793495151214302, 0.05844700906891376, 0.11616234958637506, 0.016111111362988595, 0.013482099602697417, 0.0552311867068056, 0.046040192391956225, 0.03189201153873, 0.02763848489848897, 0.02869413059670478, 0.04569933138554916, 0.010763528243842302, 0.0599371636781143, 0.03889066450938117, 0.012789933716703672, 0.03284261365479324, 0.05095418222481385, 0.13320116966497153, 0.16530615161173046, 0.11215467791771516, 0.1945956182316877, 0.18082713126204908, 0.18874292291002348, 0.06882955858600326, 0.13553440774558112, 0.14736505807377398, 0.14263374789152294, 0.3517654712777585, 0.10832111409399658, 0.12665308197028935, 0.08762404773733579, 0.09662916374509223, 0.15364713035523891, 0.13340159406652674, 0.1664425281342119, 0.19554342987248674, 0.08024306254810654, 0.1545771601377055, 0.17577938415342942, 0.10383602624642663, 0.16172659525182098, 0.06829590245615691, 0.07000999641604722, 0.1912288652965799, 0.07079275441356003, 0.20567367144394666, 0.1373395335394889, 0.0968508432561066, 0.13485465984558687, 0.16157366830157116, 0.09042211517225951, 0.12055630912072957, 0.08486832724884152, 0.27980751532595605, 0.10336071776691824, 0.11219991924008355, 0.08263018055004068, 0.11128768615890294, 0.18883061507949606, 0.1098479270876851, 0.33347696356941015, 0.17638537741731852, 0.17861248838016763, 0.10959399383864366, 0.12951649550814182, 0.1267284544883296, 0.12636790430406108, 0.17620564409298822, 0.16348797886166722, 0.29817623435519636, 0.09817887941608205, 0.12345107097644359, 0.12560809351271018, 0.18591412313980982, 0.16321794100804254, 0.1279850589344278, 0.11668740422464907, 0.12374179990729317, 0.16277220711344853, 0.07354564731940627, 0.10037706146249548, 0.13989359023980796, 0.15911851020064205, 0.13305480330018327, 0.16907618759432808, 0.1514152399613522, 0.12267414625966921, 0.07077385191223584, 0.11955530033446848, 0.18392700789263472, 0.15519400360062718, 0.24610609951196238, 0.11965048819547519, 0.1887549605453387, 0.057929472386604175, 0.1758990332018584, 0.11733005958376452, 0.1081856424571015, 0.1833632428315468, 0.1319587105535902, 0.11971394924330525, 0.16033460822654888, 0.10985592001816258, 0.1631077766069211, 0.09654360153945163, 0.10901347108301707, 0.1321683672722429, 0.12925435410579666, 0.06767866565496661, 0.19322411448229104, 0.08526943580363877, 0.16661328147165477, 0.12775003560818732, 0.20054975029779598, 0.23222479125251994, 0.15514574915869161, 0.08227771235397086, 0.16812993446365, 0.13003285217564553, 0.1325927273137495, 0.12365613380097784, 0.16872942651389167, 0.16551937063923106, 0.13120157149387524, 0.1682340874685906, 0.12531072978163138, 0.20295690628699958, 0.12871491664554924, 0.09189230971969664, 0.3189127310179174, 0.15860877349041402, 0.10561113958829083, 0.12807626888388768, 0.10771833432954736, 0.14850407664198428, 0.34764079260639846, 0.1281171612208709, 0.07845871688914485, 0.1836843107594177, 0.10658146798959933, 0.18818129523424432, 0.16425443929620087, 0.17292569275014102, 0.15091644250787795, 0.1796832145191729, 0.19497579080052674, 0.0625371778733097, 0.13488323253113776, 0.13429874670691788, 0.1289556990377605, 0.1193874933233019, 0.14077297586482018, 0.09822920445003547, 0.10696215264033526, 0.1531071140198037, 0.0982257683062926, 0.13507467694580555, 0.1617361541138962, 0.1668325118953362, 0.15393753274111077, 0.20744219451444224, 0.13826414564391598, 0.1957976896665059, 0.1270277626463212, 0.15859378210734576, 0.3724971291376278, 0.1455512343090959, 0.19434971502050757, 0.13851692114258185, 0.1517704763682559, 0.16406526585342363, 0.12141549348598346, 0.13131394749507308, 0.10777910880278796, 0.15591829520417377, 0.18401009874651209, 0.11815330915851519, 0.07913933310192078, 0.17701442178804427, 0.16233511181781068, 0.12279557646252215, 0.06713760289130732, 0.161279525491409, 0.16295237088343129, 0.09240055471309461, 0.08485922109684907, 0.17388845124514773, 0.09964561555534601, 0.10382924301666208, 0.13255372003186494, 0.1831608294742182, 0.17261958651943132, 0.08120936850900762], [0.030217175335565116, 0.0628978839085903, 0.024250046408269554, 0.06679094571154565, 0.06435475690523162, 0.044217418326297775, 0.06368223010213114, 0.03114597129751928, 0.012260606163181365, 0.04222178322379477, 0.04485839272092562, 0.03954727595555596, 0.026347296370659024, 0.016003321834432427, 0.011715661967173219, 0.06659047678112984, 0.04351860836322885, 0.01720258795103291, 0.03762438616831787, 0.09002704769955017, 0.018461159088474233, 0.0320773221028503, 0.021108960172568914, 0.043650907318806276, 0.027071454387623817, 0.02951940994535107, 0.015402031931444071, 0.018958015825774055, 0.02681650068552699, 0.058851605717791244, 0.06857898726593703, 0.035878506023436785, 0.023217043635668233, 0.013962915745651117, 0.02412664394796593, 0.037989585907780565, 0.060357512411428615, 0.09048622188856825, 0.005635452462229296, 0.04174244859314058, 0.060489392053568736, 0.07366859892499633, 0.04067260189913213, 0.023126191772462334, 0.023337381026067305, 0.07450327015249059, 0.04127706262806896, 0.012224832789797802, 0.05691962462151423, 0.0692147332301829, 0.06610445911064744, 0.04041324726131279, 0.06309885007794946, 0.09513536148006096, 0.02538392560381908, 0.024082686541078147, 0.03379652203875594, 0.05753338446083944, 0.045422625335049815, 0.019783245079452172, 0.047631958150304854, 0.009782901615835726, 0.01685871753579704, 0.07042645258479752, 0.08545857956050895, 0.01990426524571376, 0.038323173866956495, 0.051626163549371995, 0.08709491128684022, 0.03733595789526589, 0.01760398594342405, 0.036660855839727446, 0.01471152289013844, 0.07218442231533118, 0.07027633095276542, 0.011047637217416195, 0.028107344114687294, 0.04122857440961525, 0.006844101644674083, 0.02655643915204564, 0.04145563449128531, 0.009963648899429245, 0.0486218644073233, 0.017086540174204856, 0.04137323754548561, 0.03598861105274409, 0.07341345597524196, 0.03588516679883469, 0.01094688510420383, 0.03395837702555582, 0.011055333288823022, 0.0436215999070555, 0.008233482803916559, 0.07005454011959955, 0.08800852476269938, 0.010279416965204291, 0.09594418370397761, 0.11302860875730403, 0.06513412328786217, 0.009169393179035978, 0.02830662746418966, 0.07439876833814196, 0.0077313484689511824, 0.031185921106953174, 0.012893862221972086, 0.024558098921261262, 0.017814651982916985, 0.03248423425247893, 0.0162509394067456, 0.07655921959667467, 0.0069287092628655955, 0.018489987814973574, 0.02373148741753539, 0.014837989492662018, 0.04574578611936886, 0.017118532305175904, 0.02577477767772507, 0.062130699880071916, 0.07256954500917345, 0.12331884994637221, 0.03248390399676282, 0.04631612289813347, 0.032276681522489525, 0.04973544957465492, 0.024572628317400813, 0.046437241398962215, 0.01709774474875303, 0.04670756869018078, 0.03032098880794365, 0.024131569953169674, 0.026200154461548664, 0.040223776959464885, 0.045072969878674485, 0.028754142513207626, 0.11863713007187471, 0.028624227707041427, 0.04759952629683539, 0.0324324731627712, 0.047787627336219884, 0.020573628644342534, 0.08257782945293002, 0.0890913033799734, 0.028334109192655887, 0.05890195301617496, 0.081795205041999, 0.05266504413157236, 0.023707167238171678, 0.040345741508645006, 0.07706388001679443, 0.019794388426817022, 0.032298289152095094, 0.08153129732818343, 0.06968375571887009, 0.04460057432879694, 0.038148809981066734, 0.04260731780959759, 0.01834591839724453, 0.04554988510790281, 0.003332549435981491, 0.05179522107937373, 0.050387908704578876, 0.09068778177606873, 0.018596471163618844, 0.051783368980977684, 0.06728413252858445, 0.021122847610968165, 0.038070005030022, 0.05742182482208591, 0.018129777163267136, 0.05962407754850574, 0.040549320037825964, 0.07903241930762306, 0.01576372502313461, 0.037007078863098286, 0.02530124478653306, 0.016650187026243657, 0.011926034858333878, 0.017097267918870784, 0.05592448993411381, 0.0536160210322123, 0.023172793080448173, 0.025850087113212794, 0.03850897424854338, 0.044419301048037596, 0.024025090315262787, 0.07304841579752974, 0.013500439927156549, 0.029742647966486402, 0.039588042127434164, 0.018765832974168006, 0.03227053282898851, 0.04652315241401084, 0.006588183150597615, 0.037985489252605475, 0.03097058510320494, 0.026272777322446927, 0.028123396768933162, 0.04481809039134532, 0.031945512964739464, 0.0526406905555632, 0.029919401567894965, 0.02044618704530876, 0.06994169656536542, 0.04956281489285175, 0.025786546284507494, 0.03283809026470408, 0.016754534844949376, 0.03217629491700791, 0.03582626253773924, 0.06295952669461258, 0.04825141397304833, 0.07540302030974999, 0.022597148090426344, 0.05990893980197143, 0.03544205268553924, 0.0127585223162896, 0.042538940033409745, 0.03605788682762068, 0.05590597334958147, 0.02092672209982993, 0.04538101682555862, 0.017779769186745398, 0.037675323474104516, 0.016394416961702518, 0.044516362831927836, 0.09588432207237929, 0.06893326630233787, 0.10478486947249621, 0.03619173316110391, 0.03799209436692763, 0.030835794386803173, 0.06327192633762024, 0.010191286928602494, 0.10232989690848626, 0.042213511987938546, 0.060555688105523586, 0.02658158125996124, 0.05427554169727955, 0.00939331026529544, 0.023918260012578685, 0.03395772022486199, 0.004365854865682195, 0.05430023666121997, 0.02594990968646016, 0.04719569406006485, 0.02948433790152194, 0.015526061506534461, 0.03510973750962876, 0.012164844993094448, 0.07920731382910162, 0.04050437928526662, 0.034063776838593185, 0.055663584207650274, 0.0391746547393268, 0.06150629764306359, 0.03191357463947497, 0.01614352466276614, 0.07826059314538725, 0.01893620781629579, 0.021547814358200412, 0.03380262620339636, 0.04518295616435353, 0.019080370002484415, 0.02265408566017868, 0.04196377187327016, 0.1263434876454994, 0.04574678801873233, 0.035104019261780195, 0.046255730630946346, 0.044670870556728914, 0.054612784733762965, 0.055160478586913086, 0.061639309060410596, 0.022187439899425954, 0.03258768221712671, 0.043057163202320226, 0.022173168399604037, 0.03388278928468935, 0.016378848558815662, 0.04749800049467012, 0.0573918160807807, 0.03244961306336336, 0.02163257318898104, 0.03671432757982984, 0.0289596432048711, 0.11196711493539624, 0.03969123034039512, 0.00785762489613262, 0.04878768988419324, 0.0604926537926076, 0.07732759477221407, 0.03271717214374803, 0.024313613212143537, 0.049338497046846896, 0.061649417111766525, 0.0725653296103701, 0.06527128702146001, 0.010805678521137452, 0.035424215166131034, 0.0581764146045316, 0.02817359934851993, 0.018720190892054234, 0.09259686019504443, 0.008735315641388297, 0.08838366557029076, 0.047282844461733475, 0.029477192874765024, 0.06687575834803283, 0.033515018003527075, 0.0353828367224196, 0.06356889673043042, 0.0344580093951663, 0.012601643429661635, 0.04140279728744645, 0.047860316990409046, 0.06129494511696976, 0.056012389904935844, 0.10296849271981046, 0.10387812086264603, 0.06900494292494841, 0.011779935666709207, 0.012647861603909405, 0.035079817826044746, 0.002636156787048094, 0.06074875782360323, 0.02424607220746111, 0.0410164500499377, 0.07183606561738998, 0.05622605422104243, 0.03723444322531577, 0.05073126703791786, 0.036155197230982594, 0.03889652005454991, 0.044112289397162385, 0.042865162176894955, 0.06711439593345858, 0.03445154899964109, 0.05093447820399888, 0.02548085194575833, 0.0709030227153562, 0.03995710103481542, 0.03730117343366146, 0.06569152072188444, 0.07681905291974545, 0.059550801597652026, 0.01103408931157901, 0.02963650786114158, 0.03829917281109374, 0.060003311300533824, 0.03210283713997342, 0.03595900678192265, 0.02480307073710719, 0.11473727019620128, 0.1523302189889364, 0.11864362386404537, 0.16988153656711802, 0.1426950196037069, 0.0990968567202799, 0.1489662120002322, 0.0979352842841763, 0.12021337010082789, 0.16639014735119417, 0.13071953173493966, 0.16013069573091343, 0.18074208113830537, 0.06647366273682564, 0.19630990514997393, 0.1940797662246041, 0.10711383278248832, 0.1615572371520102, 0.12125293345889077, 0.28783292218577117, 0.07798654027283192, 0.16378807369619608, 0.11483860303997062, 0.11218241939786822, 0.11093901775893755, 0.09380488365422934, 0.12890922575024888, 0.10116158577147871, 0.1005471394455526, 0.11607753694988787, 0.0782324509054888, 0.07417558968882076, 0.1424939717981033, 0.12330727986409329, 0.1474683205015026, 0.14699002116685733, 0.11028361230273731, 0.17988947220146656, 0.08411875809542835, 0.19541416259016842, 0.11478301617898978, 0.12778165109921247, 0.11135433844174258, 0.11233051496674307, 0.13544698274927214, 0.11099129464128055, 0.1890174433356151, 0.11469501972896978, 0.12624884897377342, 0.3034190327161923, 0.1556109866942279, 0.23240516282385215, 0.19115389353828505, 0.18726033449638635, 0.10795249676448293, 0.12606893753400072, 0.16211709851631895, 0.19998917647171766, 0.17888832982862368, 0.12536489171907306, 0.12604728166479617, 0.12018217021250166, 0.11308504908811301, 0.14000090479385108, 0.14840008690953255, 0.10752393616712652, 0.19455583911621943, 0.14837786700809374, 0.13754144223639742, 0.13918964832555503, 0.08892126992577687, 0.0720248457218986, 0.11017773009371012, 0.3948419785592705, 0.1260870014084503, 0.2230831646011211, 0.17733131884597242, 0.15456392022315413, 0.12041367575875483, 0.08175021604984067, 0.16211546579143032, 0.18095464707585052, 0.17342658306006342, 0.10158954522921704, 0.14310562022728845, 0.11764504932216369, 0.12171470516477711, 0.12976354162674397, 0.13202470232499763, 0.24069858889561146, 0.1555605058092624, 0.12491984060034156, 0.2313805537414737, 0.2210956485942006, 0.19914446398615837, 0.11993547290330753, 0.20640327682485804, 0.13696436304599047, 0.16872206440893933, 0.13877138873795047, 0.11558385289390571, 0.17594871256733313, 0.14122323686024174, 0.21112672024173662, 0.1284731100895442, 0.1121521917229984, 0.1273985396255739, 0.1688846095930785, 0.1154134409443941, 0.1994209733675234, 0.18005106743657961, 0.099291596270632, 0.12223917350638658, 0.2078381451428868, 0.17996468144701794, 0.14580801740521565, 0.13275812234496698, 0.07288846070878208, 0.1689357138820924, 0.21910206181928515, 0.21280764020048082, 0.09542085826979019, 0.11358551637385972, 0.1544709291192703, 0.13488177792169154, 0.10440733894938603, 0.1716867959476076, 0.19155397050781175, 0.18671095225727186, 0.18064022879116237, 0.11999787267995998, 0.20917461952194571, 0.159293805481866, 0.11717872082954273, 0.25249855883885175, 0.0942339414905291, 0.15120371303055435, 0.10588997931336053, 0.13581511768279597, 0.13273909367853776, 0.30958239105530083, 0.1639301801333204, 0.23741728684399277, 0.19837657862808555, 0.18181203544372693, 0.15339322679210454, 0.08935780118918046, 0.07454802907886915, 0.12141368264565244, 0.10115432756720111, 0.07192705292254686, 0.2162414535996504, 0.20818040880840272, 0.14747718174476177, 0.1677821937482804, 0.22235686919884756, 0.1666749984724447, 0.1531948655610904, 0.14750670437933877, 0.24777006881777197, 0.08100224251393229, 0.1611306209815666, 0.08807514735963196, 0.1215329383558128, 0.11071874090703204, 0.19254893821198493, 0.17080896883271635, 0.19544960756320506, 0.21342136664316058, 0.11887340762768872, 0.12088882838725112, 0.1995663600973785, 0.12771787092788145, 0.1829488275689073, 0.16507268679561093, 0.16714709345251322], [0.016144261244335212, 0.01205036500323331, 0.007726707262918353, 0.013600834881799528, 0.03059172428038437, 0.06256688604480587, 0.012365313923510257, 0.04931838113407139, 0.043627622435451485, 0.024752664066909347, 0.013260708601592341, 0.007371378551397356, 0.03736090147867799, 0.02130471089913044, 0.023754983812978026, 0.012287711251701694, 0.0721438936307095, 0.060688172598020174, 0.03306376624095719, 0.01892206804768648, 0.024307896819664165, 0.01118640770073398, 0.07851474161725491, 0.01579026607942069, 0.04555579260340892, 0.05046524791396223, 0.021467935148393735, 0.029642912595591042, 0.03617986621975433, 0.04050850562634878, 0.018990872558788396, 0.07020668781478889, 0.03394617611775175, 0.021377886660047807, 0.014290587860159576, 0.03694806327985134, 0.02009002480917843, 0.022543776540260296, 0.056414110731566325, 0.041880565986502916, 0.06582381596672349, 0.028684595854429062, 0.02295504695212003, 0.03876223214319907, 0.04850865348998923, 0.047335815252154134, 0.07887461644713767, 0.04506180797761772, 0.030207970849005505, 0.03685212584969122, 0.02051041621598415, 0.054684361166437156, 0.030432722851401195, 0.0366339975153096, 0.02060934821201954, 0.04618402432242874, 0.030006331180629786, 0.05810130554891657, 0.02708573516429169, 0.03043629814783344, 0.0770795987045858, 0.01788043780834414, 0.05380671958846506, 0.05199187537073158, 0.055999079486355186, 0.027223218021390494, 0.022998607310000807, 0.02747359267232241, 0.11228470961214043, 0.08173613008693792, 0.03463420638581738, 0.058457391714910045, 0.018412921344861388, 0.07624260455486365, 0.05330887208401691, 0.05619465766358189, 0.061897350096842274, 0.053171062681940384, 0.04876524362771306, 0.09763500391272828, 0.05436176070361398, 0.02928728841652628, 0.0310795713448897, 0.04352090159954969, 0.0332680869178148, 0.09162049071164802, 0.02030998995905975, 0.018551061002654023, 0.08518317597918212, 0.049099362222477794, 0.04800050868652761, 0.0598523770167958, 0.03701745408761781, 0.027696585784724448, 0.030592841212637722, 0.06002875212288927, 0.026923056393570732, 0.01064777639840031, 0.028392356653057504, 0.0636563885200303, 0.03094608309766045, 0.08190523585653864, 0.0394925351429265, 0.11508709634654224, 0.03173010460159276, 0.06910719603183679, 0.06677875964669511, 0.06550467762281187, 0.0221410630911123, 0.030890353373251855, 0.041322522884001955, 0.06293321755947545, 0.06018313368258532, 0.04102316277567297, 0.05092485997010954, 0.01504819818364922, 0.03283829806605354, 0.05926827710936777, 0.08477941795717925, 0.040779571354505606, 0.04972247683326714, 0.030503692578349728, 0.050084062313544564, 0.081805120134959, 0.04744593512441497, 0.04224222939228639, 0.031771208450663835, 0.04998173128115013, 0.017760311930032913, 0.019074848423770163, 0.03753079021407757, 0.0017560346964273776, 0.06739895019563846, 0.02162170443625655, 0.05576856099651195, 0.02306436716025928, 0.029241804040793795, 0.050735207842080854, 0.016952914629655425, 0.0252555117913289, 0.02113398353685625, 0.04619469640601892, 0.0384889622364426, 0.027092050841019955, 0.0456122997275088, 0.07982493654708378, 0.047389016108354554, 0.03543813043506816, 0.0507606931932969, 0.004648705898944172, 0.02364816278713988, 0.017026372406689916, 0.03160742016916629, 0.0805752478481736, 0.0038123149761304376, 0.02931608003564179, 0.03577538089302834, 0.0109845824954391, 0.03936425120627973, 0.03779143618885428, 0.05725478593376465, 0.046610685021732934, 0.013872922918380937, 0.07617464609211311, 0.039563220998388715, 0.03317101400170941, 0.011954458186664851, 0.024752474819251802, 0.04923133092233911, 0.03326471756736282, 0.04046085974550806, 0.020363586008897983, 0.15507641772273928, 0.09188212745357305, 0.0307334058379638, 0.010958783586829668, 0.011546617424755823, 0.08951766722020693, 0.032094699490698986, 0.02021680960751837, 0.017282892040384468, 0.08532992083928548, 0.017696669056022074, 0.0755067725549452, 0.09612257374101318, 0.0062282637918542605, 0.031228420193656348, 0.014896072752890177, 0.029854103704565205, 0.08917631639633328, 0.010010888454417, 0.041486775007797405, 0.04519867114140652, 0.044591987680178136, 0.049756489461287856, 0.04096051066881046, 0.027110099872516003, 0.13636539049912244, 0.030018663819646463, 0.025306252427981235, 0.043189937132410705, 0.030231194505176973, 0.03186674141034018, 0.012541858795884764, 0.0061268595163710415, 0.031044818424561527, 0.0140485697920667, 0.0304861704717041, 0.01922730039950693, 0.013839264665875817, 0.03321556141600013, 0.04779220267664641, 0.05365806369809434, 0.03181436062732246, 0.019995673719677143, 0.012978566319361562, 0.02597957518446492, 0.06120976140664425, 0.01368854560496402, 0.04623959262971766, 0.13596181059256196, 0.038394805960706435, 0.01952869770320831, 0.04454354027984664, 0.033832482804427855, 0.01591278352861991, 0.054106955431052484, 0.06587352501810528, 0.010972868622047827, 0.02530932120862417, 0.020147595059825107, 0.06230195416719653, 0.06452337285736576, 0.03317390837764833, 0.023725062274024822, 0.013035090141784167, 0.06771144631784409, 0.053269879645085894, 0.07700122790993191, 0.06920063984580338, 0.02611820280435495, 0.0812001881422475, 0.02668461176654091, 0.07706870397669263, 0.07005822859355249, 0.05724135677155573, 0.017118341202149168, 0.0646149464591872, 0.022103404662630055, 0.02015920039411867, 0.035350289836060256, 0.10544834949541837, 0.030560320301447064, 0.02122961112036137, 0.055062370374798775, 0.06882445260998793, 0.036084162566112354, 0.06853458457044326, 0.042351540323579684, 0.03994160870206542, 0.04659262856876012, 0.1161209080601111, 0.020220195656293072, 0.022400016969186254, 0.018469868191459682, 0.03384804935194552, 0.0856884078530129, 0.046909904122003354, 0.06733702539349906, 0.02747479680692777, 0.054570979555137455, 0.040641654341015965, 0.07434426501276903, 0.04126492851355579, 0.1009612504276447, 0.0621071997738909, 0.012337394327914808, 0.015500374847761123, 0.031826683989493176, 0.06932468982995488, 0.02154039659217233, 0.013857579942850862, 0.020365669588500168, 0.07291912625078112, 0.03213653064449318, 0.034276123842573725, 0.056628261154401116, 0.046126960587571375, 0.019385049454285763, 0.023735637878417037, 0.06652846292126924, 0.00849541176648927, 0.07346502039581537, 0.07203436005511321, 0.025793327658902854, 0.014315439602796687, 0.036907260000589304, 0.024143819100572728, 0.011253066477365792, 0.05419969049398787, 0.08536210036254488, 0.04482753050979227, 0.06603201065445319, 0.031620634108548984, 0.03731482895091176, 0.04614181467331946, 0.12066263661836274, 0.02238565455627395, 0.046826601756038144, 0.04442571691470221, 0.07359757539234124, 0.06736999159329571, 0.060546218301169574, 0.03164332527376246, 0.04568867043417413, 0.037389908320619725, 0.07725366944214329, 0.01481540779423085, 0.07637052112841047, 0.01779865127900848, 0.04029445168271195, 0.1322721640462987, 0.030186788098944817, 0.05416665007942356, 0.018223196857434232, 0.0386978211463429, 0.013798263789794873, 0.03658997331513092, 0.060318805699353106, 0.022430029421229847, 0.038066197812440805, 0.017675334165687673, 0.006618434017582331, 0.030711204490216915, 0.03461595326371025, 0.03410684737900738, 0.07553715608082712, 0.09822164196521044, 0.05229000722465571, 0.03383794872206636, 0.0308920473253238, 0.04080811435414944, 0.04318335799325723, 0.040667588691576384, 0.03768029586353805, 0.04870612785452977, 0.06955612858291715, 0.037618723581545055, 0.13056822266662493, 0.10667543872841634, 0.01680367986409692, 0.007153867591114249, 0.08786558712017722, 0.14686234208056703, 0.05687456141458824, 0.07391538529191166, 0.09948289967724122, 0.08256543558673002, 0.13048709108261392, 0.09871148911770433, 0.15589796035783365, 0.10521485499339178, 0.11693665452185087, 0.08603532478446141, 0.18522769591072574, 0.16339455731213093, 0.10644596666679718, 0.16528500040294603, 0.18943254137411714, 0.1872711698524654, 0.1970870970399119, 0.12340404849965125, 0.17596778576262295, 0.15874228585744277, 0.18429928401019424, 0.1055414073925931, 0.1466990844346583, 0.20940079644788057, 0.1697918851277791, 0.07652119937120005, 0.08143854371155612, 0.09158545391983353, 0.10344588663429022, 0.1882525414112024, 0.09128827572567388, 0.05922997857851442, 0.07944713885081, 0.15714558481704444, 0.1343699631979689, 0.09506931775831617, 0.11721803981345147, 0.14099461084697396, 0.15800270601175725, 0.19942648010328412, 0.11396055328077637, 0.15430970495799556, 0.18796350457705557, 0.16314320673700422, 0.15904784289887175, 0.15413678454933688, 0.08706006745342165, 0.13169747457141057, 0.15450515697011724, 0.18380180757958442, 0.09743849805090576, 0.13550071424106136, 0.1329732412705198, 0.17571824602782726, 0.09785184462089092, 0.15649659151677042, 0.1469970418838784, 0.11701947078108788, 0.30388290470000356, 0.10191662455326878, 0.14653410500613973, 0.1373538124607876, 0.16847337072249502, 0.24843130755471066, 0.07568730739876628, 0.13785431685391814, 0.10373087134212255, 0.17034484451869503, 0.1410408763331361, 0.12772967107594013, 0.0741469427885022, 0.1880086271557957, 0.16022790223360062, 0.1277408775058575, 0.23617770726559684, 0.10134805779671296, 0.1758659037295729, 0.16106194263556972, 0.15551808464806527, 0.08998173958389089, 0.25601850589737296, 0.2048313635168597, 0.20344651595223695, 0.2178073109826073, 0.19674023205880076, 0.14959205029299483, 0.14895145810442045, 0.24305564991664141, 0.1664609185536392, 0.087960804667091, 0.12867962010204792, 0.11179792752955109, 0.10692772440961562, 0.16497061180416495, 0.147178259503562, 0.1696179257123731, 0.19411855086218566, 0.25045771209988743, 0.11341301156789996, 0.10250343329971656, 0.16035057924455032, 0.13761584996245801, 0.09923301113303751, 0.20991448138374835, 0.18614114611409605, 0.27649863506667316, 0.09832172057940625, 0.15275529149221256, 0.1053531319485046, 0.15226859104586765, 0.12992234638659284, 0.1756917216698639, 0.15691963053541258, 0.06885640206746757, 0.16684437141520903, 0.16393895231885836, 0.17741141142323613, 0.12566256715217605, 0.13935772993136197, 0.07451080295140855, 0.12711423769360408, 0.16542189696338028, 0.10743763923528604, 0.17240436369320378, 0.1994864604785107, 0.13448909274302423, 0.13772309030173346, 0.12695938115939498, 0.20653675950597972, 0.1782219554297626, 0.16287352511426434, 0.11452801423729397, 0.2350195709732361, 0.13508021336747333, 0.18299586488865316, 0.10219585019513033, 0.14464591804426163, 0.10525509424041957, 0.17920843296451494, 0.10812051157699898, 0.2313520255847834, 0.10832450570887886, 0.170130081824027, 0.2501955855404958, 0.09163597933365963, 0.11726935190381482, 0.0964639987796545, 0.11088095212471671, 0.09592983798938803, 0.09997513654525392, 0.1800067612202838, 0.1371913414914161, 0.14019690599525347, 0.1260874466970563, 0.11380195632227696, 0.11181752022821456, 0.06888630319735967, 0.18548679450759664, 0.20224638894433156, 0.15934398950776085, 0.10679177779820748, 0.15603451553033665, 0.10954369849059731, 0.09361389937112108, 0.118101959960768, 0.12376600134302862, 0.1198695924540516, 0.10699397593270987, 0.1400534636923112, 0.1061142489197664, 0.30796916980762035, 0.20269685774110258, 0.18895882851211354, 0.12945323484018445], [0.04353234551672358, 0.061008131015114486, 0.05349239407223649, 0.03829408538877033, 0.0057708392159838695, 0.06929242124897428, 0.06290043689659797, 0.0346141275804257, 0.015946755338518415, 0.014719787632202497, 0.04980750469258055, 0.014070463148527779, 0.014458679670497077, 0.015948777690937277, 0.03593904300942086, 0.03422511232201941, 0.03639513728558086, 0.08056800448684953, 0.028910128967254423, 0.0800795154646039, 0.024004055994737428, 0.02638401598233031, 0.007840008165658219, 0.04775047542352695, 0.024879743868950754, 0.017282472726947162, 0.07625500584254041, 0.03143497844575904, 0.04379608995805029, 0.044684963941108435, 0.01706516446574824, 0.07623574711033143, 0.02831997499015415, 0.03490574708848726, 0.10145048159756698, 0.005742856073993607, 0.026905237427854445, 0.004925919392917422, 0.04185293953923974, 0.03475844561762642, 0.019228812525398098, 0.021851955752936192, 0.03608834456827026, 0.11907240710570477, 0.07068935839924961, 0.018709797113842797, 0.03420911532884929, 0.03410759323742241, 0.02251840807730332, 0.002539274973969441, 0.038666884720441885, 0.020198920137772802, 0.03249192290240899, 0.011470383087726077, 0.024566917491029017, 0.017843480709416326, 0.060631324085989036, 0.021555664425250143, 0.048561264338786714, 0.05042944671004079, 0.054309112747432664, 0.033665707378531806, 0.09702166338684037, 0.06541716356878169, 0.03595457616029307, 0.11591556321945973, 0.045253942589624785, 0.0321362152317306, 0.008061304542934522, 0.05965126612863969, 0.04481069860048592, 0.08913690093322657, 0.06518844107631594, 0.02821564758050954, 0.015702217679063324, 0.03848134037980344, 0.02887989758164622, 0.01901811865536729, 0.015163997341005597, 0.03927392441255506, 0.06045669302693568, 0.09351221029646695, 0.09484243579208851, 0.05516150275070686, 0.04538557732303161, 0.03411960118683055, 0.01258819942449918, 0.044741307792719454, 0.017110153457906563, 0.025379077524121385, 0.026178383559454232, 0.0805045805464033, 0.04399239544000011, 0.027699741767719388, 0.010428426303406013, 0.022294633854471613, 0.05554828043386806, 0.00923735999094788, 0.12119296792661771, 0.025376244375365786, 0.057169194042216986, 0.017625105610932223, 0.013771391550108092, 0.027219073126616422, 0.022211071736819576, 0.029193447553552687, 0.04295271704904735, 0.0329407329991227, 0.03372665625647642, 0.07663254378712736, 0.04223842217470519, 0.018610137813084293, 0.0345849574659951, 0.07417754153721035, 0.009825151155382628, 0.04632541458704509, 0.0666625022131484, 0.0308102700728341, 0.026336485134379473, 0.06375245211529545, 0.06694922354654409, 0.03188056391081773, 0.01699018157523824, 0.039115665131248534, 0.03417275751417037, 0.052026908451807685, 0.052485652195173316, 0.01889697232400067, 0.028320481505943462, 0.12070612647221424, 0.012515880844148342, 0.03568074222130235, 0.00948170098126866, 0.05767304923210759, 0.05170063435798511, 0.05981731796055101, 0.05737369654525537, 0.05255119867797475, 0.03602082026191056, 0.03450125805102289, 0.016395352067775093, 0.0503373981337063, 0.048886718359426595, 0.0578479103569407, 0.043727370793931186, 0.017180273425765336, 0.07528248068410903, 0.036952085720258765, 0.01640852333366638, 0.04265420669980813, 0.02839138629497029, 0.016967653682513628, 0.013342691800062312, 0.03937443718314171, 0.010342337172914995, 0.03303716395748779, 0.032372607820434496, 0.03677982953377068, 0.020533456190605648, 0.06429955596104264, 0.033308166603092104, 0.06080552841012832, 0.015374995491583832, 0.0040068492762657115, 0.07554803596576676, 0.08425373991485685, 0.0578770804713713, 0.019702020726981573, 0.022949992926442064, 0.0672971349558793, 0.042423769846209325, 0.01804330026061507, 0.07423195580486208, 0.034466473589418456, 0.02142792411177652, 0.07205549642094411, 0.07674301989027299, 0.02140788612450706, 0.06903807239723392, 0.06461362543632276, 0.06314475933322683, 0.017093900423788, 0.06662276762654074, 0.059076955149066634, 0.05125584299094044, 0.024384041171288118, 0.018871121465053875, 0.030003954452695325, 0.03137384032015689, 0.01822560512664495, 0.00772599526499107, 0.02974240676849149, 0.03574981019482948, 0.023907471040729433, 0.06363528926158324, 0.04189490056887735, 0.025666748806543183, 0.017595601530047134, 0.006750446318619652, 0.0056728729396127164, 0.04322508153563831, 0.012092890992789762, 0.04009192700323183, 0.01950317524460843, 0.024073420827335212, 0.06704096784233116, 0.045890078181400895, 0.06225130629900377, 0.03984674738603644, 0.016182079234567937, 0.061940212835907005, 0.010710543538152706, 0.03590554617403541, 0.025669897368061356, 0.06428492823033594, 0.021586105467577, 0.021430892702483106, 0.0380657117057126, 0.04516013512329664, 0.03933591229724698, 0.02112307211064035, 0.05259046571154613, 0.04025729977001902, 0.03688476550451014, 0.020212638737575617, 0.06411649781512097, 0.017745817785908002, 0.13116597809130326, 0.09036496237968095, 0.07506614463636652, 0.05514070777280722, 0.010724087733251508, 0.060030703971278854, 0.013355747105379123, 0.054664987401338294, 0.031900850517558865, 0.012315995427343296, 0.03674455525469966, 0.03624824770668056, 0.05917884089285508, 0.017171905710711144, 0.044063608220312744, 0.0275194963614922, 0.015620774393028114, 0.0385386712878244, 0.05357758891477715, 0.03422952438995708, 0.03201478502887767, 0.056276609320775606, 0.033889045589603484, 0.05913300956308376, 0.0708214013138786, 0.018556935101514682, 0.013122617183398688, 0.03437861814745702, 0.07796020887326449, 0.021431774002849124, 0.050165828433819115, 0.005909192705075839, 0.02153521269065095, 0.08079080464085564, 0.023027167007967364, 0.04425119717780035, 0.05700547255401034, 0.04831683800148312, 0.009955990863090847, 0.06605423055589199, 0.0433264923049137, 0.013862998548574978, 0.029984970315126702, 0.026681895506044384, 0.047875864984234795, 0.029823130171280354, 0.008783579360169824, 0.018545611783338245, 0.024097661225823686, 0.0623203965369612, 0.019324903951201122, 0.04283709415176418, 0.010764291728264652, 0.016689248113834765, 0.002956863845611224, 0.06685834014206193, 0.05338885704986751, 0.05458254963741638, 0.03711502424266655, 0.05840035395522136, 0.06496198955574073, 0.11786935603595339, 0.06616826154640876, 0.01687377385678701, 0.016113638375827577, 0.030376776048797183, 0.043477437720866874, 0.05599399948550854, 0.0624170019000303, 0.01624894117412623, 0.04261124377080705, 0.08184878810425289, 0.022250088295550086, 0.09454246712266468, 0.03851255140034482, 0.026796401471074205, 0.0283162679625093, 0.021730028311139904, 0.03897427857737057, 0.03682209484395571, 0.03161558008287102, 0.053465324235730805, 0.0514989928342402, 0.012902211383334361, 0.07114995751180686, 0.03656487759144511, 0.053508658238570206, 0.09397196336067282, 0.035418341067270376, 0.035011399231734686, 0.02346084285818506, 0.007610347784066107, 0.04189445528027136, 0.04072617011843249, 0.06269824618357234, 0.0033459823089287966, 0.019825258059427142, 0.054513808208866976, 0.01805982788937399, 0.038825526207801886, 0.03744217778148595, 0.020999285588914063, 0.045571993687190115, 0.031424848129972816, 0.0333815353224054, 0.05404731273301877, 0.07937962567666546, 0.0674729942693375, 0.06979065467021428, 0.046483970727422275, 0.0717312669439707, 0.05797032390546519, 0.036027276946697384, 0.011106201945949579, 0.05226980596489739, 0.03343895899888594, 0.01991114124393789, 0.05342038348317146, 0.07001160687650554, 0.0619956104492303, 0.0631063680339139, 0.09951109386747703, 0.021549513876379933, 0.04183158423984423, 0.04649230504583102, 0.09686510733445175, 0.12794863432645798, 0.11433313367888331, 0.10786102706333622, 0.22282044432358816, 0.15956253715557978, 0.11987716978183016, 0.1432088974979706, 0.09590938439941965, 0.10152303395443596, 0.1682859635911882, 0.18109739175997674, 0.13258264894830063, 0.1189785625319928, 0.09290957154007629, 0.15266705013345927, 0.09805051755392924, 0.12680269894190133, 0.12592656392371282, 0.12233711473527364, 0.13600481062894687, 0.1447802467737347, 0.0932994662434794, 0.1650025835260749, 0.11525865862495266, 0.10298699446138926, 0.1694228150881827, 0.07033476023934782, 0.2861548966029659, 0.1205152460897807, 0.13821761298459023, 0.1919481102959253, 0.07400770846288651, 0.09791955817490816, 0.20419516484253109, 0.1043218732229434, 0.15092830202775076, 0.18546159117249772, 0.15772946208016947, 0.1518181519350037, 0.13531134783988819, 0.18322380812605843, 0.1067710347706452, 0.2393930175458081, 0.1580157974967733, 0.1167757940129377, 0.08529826081939973, 0.16904562595300376, 0.09738945693243295, 0.2027135412208736, 0.0799927806656342, 0.13511153199942783, 0.20034472458064556, 0.1870054958271794, 0.06565759715158492, 0.12834679655497894, 0.19944712665164843, 0.1032360369572416, 0.17371003894368187, 0.19785611046245322, 0.13254433928523213, 0.11461287140264176, 0.17931404057890177, 0.17487712553702295, 0.13643736398080364, 0.17504679533885792, 0.15647496533347294, 0.1020248222630471, 0.10754030794487335, 0.1678671399713494, 0.17569605581229553, 0.16486515261931345, 0.13937107374658808, 0.13197198015404865, 0.19711335422471166, 0.18220869853394106, 0.12006707795080729, 0.1460295930155553, 0.11437945111538284, 0.16745140368584543, 0.1826984714716673, 0.21947586676105857, 0.13501046632882208, 0.10418430872960016, 0.13006837136344984, 0.21669354027835652, 0.130897929193452, 0.11084277604823001, 0.15399016585433856, 0.05986628486425616, 0.11783806708990596, 0.13641839468618855, 0.10743576902314089, 0.06528090525534935, 0.10768412132165395, 0.11902509519131854, 0.07879240132751875, 0.09533773030852899, 0.20378156594233587, 0.07796298450557515, 0.13530122494557872, 0.12289206308196299, 0.09710851692943834, 0.07935539455502294, 0.1557256336673163, 0.15194611303741112, 0.15537747734924778, 0.09382671763887629, 0.21430743159726262, 0.14803290192503482, 0.1754266710486263, 0.13492978003341705, 0.18360694928560406, 0.17882247164379805, 0.09707534292829223, 0.11568289992283098, 0.17132265376858413, 0.1346698057022877, 0.09210882388288155, 0.118127987079788, 0.17620372935198247, 0.11229486961383373, 0.13789906835881993, 0.09117911322391592, 0.163783977041021, 0.11414263179176487, 0.09804520377656445, 0.11818611208582297, 0.12530476291431114, 0.17967687657801434, 0.13094765308778733, 0.15257919469149783, 0.15567889320664108, 0.13626105937873945, 0.15069445129483938, 0.164257422729861, 0.14941019442630932, 0.20733005600050092, 0.2515520533779636, 0.1977657465613447, 0.11421434552175924, 0.06858793014544062, 0.11820660278317519, 0.12783339363522828, 0.14213978924090043, 0.19290758849820122, 0.16712718905182555, 0.16162527725100517, 0.17540347151225433, 0.09401142335264012, 0.10102537940838374, 0.12527843151474372, 0.11881007274496369, 0.12812602246413007, 0.07085680175805464, 0.10722545921453275, 0.12276332272449508, 0.17707692546537146, 0.16716206999262795, 0.20059205271536484, 0.09108697558986023, 0.09637428054702468, 0.17639423866057768, 0.1123491206089966, 0.17537013423861936, 0.2779756276868284, 0.1686214588698931, 0.132340575219132, 0.0993399768776726, 0.20575220551108941, 0.11502957990160212, 0.18445008841808885, 0.29378551058471203, 0.08093636206467636, 0.16621657385258004, 0.18016546207945794], [0.05581914578215219, 0.047329102526418865, 0.05234400960034691, 0.03406349853321444, 0.028863759580417536, 0.02990502616739832, 0.03228991030482575, 0.01068434294211329, 0.013627006719616475, 0.050764864063239656, 0.056602690456202254, 0.030372885339602362, 0.05052650478319265, 0.009538288813928375, 0.04466154547117185, 0.04808349935046863, 0.03609660838264972, 0.02259216085803928, 0.03581735676561948, 0.022262218699324876, 0.02473765784088755, 0.021053132113593165, 0.05302166464389302, 0.06150845729280263, 0.04822243681701366, 0.011189917131559923, 0.07442699221428484, 0.07699555048020557, 0.024484965833835304, 0.029485666345863137, 0.041954962580348365, 0.06816693945438601, 0.019430658139754087, 0.052615843451349065, 0.0678549925214611, 0.03085534441197524, 0.018363331037107855, 0.057773205771809444, 0.0688778649782762, 0.03382433031219989, 0.07505918329115957, 0.043871024608961307, 0.00675781213431037, 0.037073282146593556, 0.020493680785875767, 0.01958043281774735, 0.05141720444953535, 0.044230706480448134, 0.040444250480504707, 0.02070446927973535, 0.039705613162368536, 0.024558503391745035, 0.08316717634443194, 0.016275790221698117, 0.041303976613562554, 0.020856956507486757, 0.08437842814601026, 0.02475426153978333, 0.04600701839081012, 0.07425392337609082, 0.045103494412614964, 0.0345812615705654, 0.017790109159250278, 0.06417216631234623, 0.050033729858114384, 0.0365856391726993, 0.018189510774391238, 0.03776693789404817, 0.015328148347180104, 0.05050273750384804, 0.08619529471616261, 0.045142446033423766, 0.02848960953997448, 0.04853066559007857, 0.03215190052287653, 0.042683131905505434, 0.0040867572442948585, 0.05050828505773097, 0.04568082222249359, 0.0014419987337532802, 0.03184808752848767, 0.08293269478599541, 0.02973564580315724, 0.04455865782801993, 0.06242728064535186, 0.05350167462893296, 0.03200030201696791, 0.06271729711443186, 0.010952640459436225, 0.013383496007008944, 0.020096052903681993, 0.024095340158964973, 0.06669733120361343, 0.04187542661384214, 0.01254229573532939, 0.05752685356128495, 0.019861630717059597, 0.01048876754794037, 0.005757425360570778, 0.014909968540450791, 0.016985852998914197, 0.021417315110738855, 0.026264363223162945, 0.0896243954775855, 0.055138685420388356, 0.03618279028160032, 0.010406355759187136, 0.0418191087373998, 0.015955789131112397, 0.041219230770366266, 0.027182036246813368, 0.049359496115357615, 0.017704094243526924, 0.022655718385067303, 0.023042776228976436, 0.03552014517481439, 0.08453065747744404, 0.03506278182612732, 0.029310953650565352, 0.04547066826489754, 0.054049361060606316, 0.009655551857576938, 0.0419392847106792, 0.014964555357437348, 0.0255864057544386, 0.025786158512346447, 0.06115379605034832, 0.10767033963929862, 0.05381525057600811, 0.02297240022016922, 0.06353529970510863, 0.017694902744551655, 0.06122409969975706, 0.06251328813959844, 0.03506308239593636, 0.018540869459684473, 0.014169802398100728, 0.019665529325720854, 0.011332226731610717, 0.017365248168061953, 0.012750577625411097, 0.01902292962768115, 0.0348863287945278, 0.05293643269396853, 0.01933916431880789, 0.03483066400804091, 0.029427825211314484, 0.017506584626971744, 0.015945655104587786, 0.014736548109794967, 0.06724008606397547, 0.04603652247169521, 0.04551923069811892, 0.019201725990569685, 0.024343467957805842, 0.023205733305076137, 0.03833815411780961, 0.014871827715978725, 0.025128192646661773, 0.02285653055878356, 0.029061540080874693, 0.04188044353213627, 0.042919591287500225, 0.0054984789039735915, 0.040398196506430395, 0.047345192288048565, 0.04854080703807995, 0.028033852941007353, 0.02660782731254585, 0.02520893274777336, 0.12049687051330693, 0.03960875175835099, 0.024156279760063626, 0.012332285568845691, 0.04176636059128214, 0.010732452665251913, 0.031406591297127306, 0.019378984252398368, 0.031539695482933894, 0.04168051265878603, 0.039957917397259735, 0.010576468066574307, 0.02129397944372613, 0.11476682251668535, 0.016715828132873867, 0.09827913614572026, 0.05580501900112722, 0.03273047514085192, 0.037406409974209964, 0.01610214436368551, 0.03357394823979121, 0.020493203955993522, 0.024134965278790332, 0.03781908118980937, 0.06866083131171763, 0.01935139862325741, 0.02628022848512046, 0.0320668986387318, 0.04594035126501694, 0.026328917083446868, 0.02972056536236778, 0.01914694807055639, 0.04622314663720317, 0.081539668753976, 0.009410028997081099, 0.044051180957467295, 0.01485723059886368, 0.03635293876868673, 0.011714222200680524, 0.0838316508452408, 0.04957926088536624, 0.004674258043451118, 0.00586339477194997, 0.040813502346281894, 0.03359970076417085, 0.04895264333754312, 0.04761327458254527, 0.02839042521372903, 0.11006644504959695, 0.0544893470214447, 0.036240210247342475, 0.012177334410807816, 0.0644682535494212, 0.019016771657334175, 0.018946757445519324, 0.00810405503216316, 0.03837643038423266, 0.07342757162405178, 0.010579403260635445, 0.02150906868337188, 0.02045511322648963, 0.013012103972869227, 0.09586075146216899, 0.05851378751685843, 0.04105068161152303, 0.04021771361294668, 0.06300620036199689, 0.013329771936696488, 0.017593838929315098, 0.029946438007755205, 0.08994731877464801, 0.04622036358341575, 0.03299767427961342, 0.026828180234588217, 0.03777347621507943, 0.015107662766240537, 0.05713240949262399, 0.03871616703690961, 0.05142296722624451, 0.03134143444185611, 0.01568293482705485, 0.020109456090722233, 0.02826141397235915, 0.019465206969471183, 0.005956071390755824, 0.04496145105804317, 0.042471200504223816, 0.08770031825406477, 0.04968997076503001, 0.023388784029521048, 0.13877791963750497, 0.03179179191647563, 0.03913706495950464, 0.1108962477883324, 0.0327715567254927, 0.025496301605016924, 0.017007829846988898, 0.02749308889178792, 0.030546781672455836, 0.021089432411827147, 0.01718143859761767, 0.015778041051817127, 0.02184035227401182, 0.04375978409370873, 0.04412076101289131, 0.015879219899943564, 0.03125095921859611, 0.04596747305186, 0.0283191011112649, 0.05961586568446364, 0.02661087939486606, 0.022607269129366614, 0.06408830362488516, 0.03444694768404588, 0.047912482550600544, 0.0066502665868029, 0.007787606973579386, 0.0588649161363719, 0.051146179539500736, 0.057045151479542255, 0.02069552083412418, 0.03683475959405769, 0.060942454656469636, 0.031045621799421497, 0.010538168608036358, 0.0536490428930847, 0.028024659586662892, 0.04915588790026959, 0.04531220118224155, 0.025677265039121266, 0.017066377877199557, 0.034171625738963485, 0.016346412994607817, 0.08523248427081853, 0.06301106142927893, 0.041946023411583155, 0.0988093412888702, 0.05235654076386709, 0.06647980029811151, 0.04996676587325055, 0.04595013648213353, 0.084698071150342, 0.038191490893950686, 0.022178394974616822, 0.01938324603543151, 0.0009062931746939284, 0.017568420371389948, 0.04617282160324976, 0.018212448703707196, 0.014208634347596671, 0.04158343974268064, 0.06384982931194827, 0.04155092625296675, 0.028452294354792684, 0.014779165012441808, 0.023715366114629433, 0.06715844981954433, 0.06289151628152467, 0.011006228160113096, 0.03499173602904193, 0.023668981884839013, 0.018645167183422018, 0.040713883863645606, 0.07224383865832351, 0.008098375747067621, 0.05960405440418981, 0.045397470239549875, 0.02502361105143791, 0.032661095465300605, 0.05459677289763931, 0.006696610926155699, 0.00855917802255135, 0.05522304905753117, 0.033156987410620786, 0.005417140446297708, 0.060231050447328016, 0.09386219229782, 0.013266395308164647, 0.03931236766220536, 0.03458585917542223, 0.026823957414308097, 0.04221039496769663, 0.12956972233951092, 0.18427405098918825, 0.14718149526743218, 0.10473291913513094, 0.08732194168260321, 0.12328531229286455, 0.10533316075452603, 0.291450506192632, 0.10556953478953801, 0.20256347896065563, 0.17828803625889122, 0.20664733950980008, 0.12881596747320145, 0.13156699016690254, 0.10221122749499045, 0.1353118970291689, 0.17733120010234416, 0.12192590555059724, 0.1061451890564058, 0.18212039780337363, 0.13520104985218495, 0.2056342485593632, 0.17334136966383085, 0.16133466706378385, 0.11913385693333112, 0.09703552670544013, 0.24178184248739854, 0.24573380855144933, 0.1168463722569868, 0.13821163127431646, 0.13353693211684003, 0.23736716218991205, 0.059116752818226814, 0.14123438391834497, 0.14157140802126378, 0.07285033658263274, 0.07439290537149645, 0.10661474589142017, 0.15503516915487126, 0.16459731152281165, 0.1802313351072371, 0.18422024528263137, 0.2349805785343051, 0.10670111703802831, 0.19813128397800028, 0.08854134968714789, 0.17923301289556548, 0.10436317374114878, 0.08644289002404548, 0.06328821647912264, 0.16708985902369022, 0.10234409419354051, 0.12709372473182157, 0.06454437563661486, 0.1292604990885593, 0.07961489391163923, 0.19094426650553942, 0.2024249199894257, 0.1321862975601107, 0.10775438044220209, 0.14469139685388654, 0.11916714967810549, 0.13437823072308674, 0.1435295498231426, 0.1379252364858985, 0.14600361784687266, 0.17470934079028666, 0.14643208938650787, 0.13832529861247167, 0.11698951770085841, 0.1922092869062908, 0.15028885274659842, 0.18894161068601534, 0.11359395459294319, 0.173045787087176, 0.15929897082969546, 0.13978556322399527, 0.1751810943824239, 0.08136578355333768, 0.18644579773535952, 0.11496041173813865, 0.29925558425020427, 0.09946441277861595, 0.09099676753976382, 0.24628704995848238, 0.11368758394382894, 0.15961846540449187, 0.1885392627445981, 0.12963615939952433, 0.1512809854466468, 0.12567941390443593, 0.16042473464040086, 0.2507295459508896, 0.12054919934598729, 0.10844139396795072, 0.09839034697506577, 0.1335061775171198, 0.12538601324195042, 0.1395178260281682, 0.09627922627259977, 0.09258455538656563, 0.10874725528992712, 0.11653861103695817, 0.2263612308888696, 0.13434677850455046, 0.06012403275235556, 0.16594016837188974, 0.18593316664919257, 0.16392918565543368, 0.16238476149737835, 0.124531326291617, 0.12377460283460096, 0.15087814768776298, 0.12361179789877497, 0.10499327938305214, 0.12615377985639498, 0.16901331284316257, 0.0739821711613331, 0.09320110199041665, 0.16469429538119584, 0.17690243170363829, 0.1298741513164714, 0.1867014676099643, 0.09581441918271594, 0.17082111036870629, 0.08369891031179577, 0.13966076367069036, 0.23264232353540137, 0.18747693771729246, 0.17672188201686367, 0.18131898221326992, 0.21218561654677615, 0.15607511100824922, 0.13232518307631835, 0.14841598371276632, 0.10494622722035274, 0.17829251883085817, 0.13501742767402902, 0.10589797966531478, 0.08724394938326441, 0.10958397484500892, 0.1127619254111778, 0.2013589584385045, 0.12960411346284673, 0.09942120494088158, 0.1268235532916151, 0.14336069638375193, 0.09474137012148276, 0.16756020253524184, 0.068673277128255, 0.1587324301362969, 0.2630894217872992, 0.14437343110330403, 0.12666550552239642, 0.08333715042681433, 0.0767192043713294, 0.17422526754671708, 0.19426408602157608, 0.10475240051164292, 0.15284482418792322, 0.13222457753727213, 0.16682837071130052, 0.08502130614942871, 0.12175548617960885, 0.2023506013210863, 0.11910028217243962, 0.18284742051037028, 0.1652768813073635, 0.11213555277208798, 0.15335662406869233, 0.18909844133304432, 0.07925810641609132, 0.08525668570655398, 0.15918910328764468, 0.10657231730874628, 0.1018212956842035]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05415115774667356, 0.030525472757290117, 0.037198126228759065, 0.0896427413681522, 0.010679428996809293, 0.015457419340236811, 0.033395187128917314, 0.030817459628451616, 0.04796297085704282, 0.024546749627916142, 0.03920535367797129, 0.0780317148019094, 0.008884491962817265, 0.03339201815833803, 0.018781382823362947, 0.07297468342585489, 0.042660240360419266, 0.026786475245899055, 0.0690498502808623, 0.03563217236660421, 0.04938747137202881, 0.03471511161478702, 0.07069099112413824, 0.046140901831677184, 0.05106662130856421, 0.04905288893496618, 0.011372563385521062, 0.02159744362870697, 0.005692657668987522, 0.05442867644887883, 0.022801609775342513, 0.07198408697149716, 0.026790082083607558, 0.02567843948781956, 0.033270973872276954, 0.049726755314623006, 0.010933191551885102, 0.013092334775137715, 0.09259343147277832, 0.07757151644909754, 0.055039178259903565, 0.053054586314829066, 0.03425318776862696, 0.030170900572557002, 0.038454237146652304, 0.02384136794717051, 0.019892073614755645, 0.04741281307360623, 0.012207794934511185, 0.016330117286997847, 0.03232542578189168, 0.02262524580146419, 0.029624635353684425, 0.046555142689612694, 0.052901384769938886, 0.03308205647044815, 0.02959711095172679, 0.053943130042171106, 0.03171740645484533, 0.02812850274494849, 0.025046623195521533, 0.06933920623851009, 0.04254403116647154, 0.015574649914924521, 0.03082120747421868, 0.020600264324457385, 0.026599741613608785, 0.044553737388923764, 0.016158302678377368, 0.006093267593314522, 0.06820223599788733, 0.06935664670891128, 0.030246657152019907, 0.06400768412277102, 0.026700933449319564, 0.019196814828319475, 0.060425871633924544, 0.041885890896082856, 0.04555574065307155, 0.059931623545708135, 0.02991544592077844, 0.05463170207804069, 0.014001814488437958, 0.014461773498624098, 0.016049804398790002, 0.010826920643012272, 0.03879330957715865, 0.09932577217114158, 0.016991487755149137, 0.06667022797046229, 0.03226140070182737, 0.07305652747163549, 0.06779875999200158, 0.0823974801460281, 0.034707315353443846, 0.040082464620354585, 0.0521900399326114, 0.01758407412125962, 0.04031678290630225, 0.023906209389679134, 0.016331401202478446, 0.052270744781708345, 0.05514907548786141, 0.053622611303580925, 0.038638345431536436, 0.027624066824500915, 0.028301920392550528, 0.033093559759436175, 0.027516505506355315, 0.02084858322632499, 0.06791019346565008, 0.026628705782059114, 0.04768041297211312, 0.07618829418788664, 0.052883469325024635, 0.02637648689415073, 0.02092209480906604, 0.03273889851698186, 0.02941486545751104, 0.03274069451435935, 0.011371495620551286, 0.03743900881090667, 0.00925065463889041, 0.05678282082953956, 0.023858526401454583, 0.0666885293321684, 0.04752168242703192, 0.010765729639388155, 0.029039771034149453, 0.026280330530426, 0.07565246356534772, 0.06648489885265008, 0.07491966694942676, 0.02136747989425203, 0.007382734802376945, 0.03506211760395672, 0.08565046184230596, 0.03067522331548389, 0.04098509431059938, 0.03580158983822912, 0.011195924817002378, 0.061277430431800894, 0.08339311578311026, 0.04414665083459113, 0.026446955671417527, 0.05024176127335522, 0.014303705320344307, 0.014000178980495548, 0.06526139419293031, 0.025473706919001415, 0.07779627587297, 0.07219755832920782, 0.04682786711782683, 0.039034797009662725, 0.0738569040549919, 0.05266807951556984, 0.02096159561915556, 0.03302282566437498, 0.06706625281367451, 0.08249184422311373, 0.03767047724977601, 0.017328634312434588, 0.04039527244458441, 0.10699776088586077, 0.06602193228900433, 0.04410044100950472, 0.045476123050320894, 0.04061154912051279, 0.04025606038339902, 0.03703739188495092, 0.08307140960823745, 0.04620444822649006, 0.05884183534362819, 0.018770745991787408, 0.051398921641521156, 0.06916906888363883, 0.050659456828725524, 0.020306900769355707, 0.043753475838457234, 0.0333114431850845, 0.043098682654090226, 0.053121476084925234, 0.03590107473428361, 0.0035353946304894635, 0.04143759659200441, 0.05680362693965435, 0.021427467690955382, 0.015350794055848382, 0.019117735282634385, 0.03903086733771488, 0.035182501378585584, 0.039950436548679136, 0.03356091241585091, 0.04358212507213466, 0.006348363231154508, 0.06468668245361187, 0.09987220808397979, 0.030925330793252215, 0.05961182097962592, 0.03598920477088541, 0.08669686038047075, 0.10006809054175392, 0.022113189879746642, 0.021053198906884063, 0.011633455196715659, 0.04809070931514725, 0.009303633778472431, 0.03927840698452201, 0.010928865758614847, 0.02676334621355636, 0.028123504380346276, 0.006997096315899398, 0.04039614446810447, 0.06874443424749188, 0.03671623861009721, 0.06655431192484684, 0.024147707954398356, 0.06549670695676468, 0.016315057255269494, 0.024594224814791232, 0.021519404945138376, 0.02349722108192509, 0.015687998129578773, 0.060312170899123885, 0.011679543495120015, 0.05058692302554846, 0.05198973427468445, 0.02304716417711461, 0.010097287431563018, 0.025773536435735878, 0.04957418088451959, 0.10619742140988819, 0.024963291143649258, 0.1302251871675253, 0.0473197329120012, 0.02362781309784623, 0.017317635683866683, 0.015595825243508443, 0.05193797689571511, 0.03794904609094374, 0.027320352164679207, 0.019818318978650495, 0.015179755919234594, 0.025477760900685098, 0.07124904164811596, 0.049024598265532404, 0.07591126530314796, 0.03724944945133757, 0.023718453448964283, 0.03613990527810529, 0.05166948270925786, 0.04920247622067109, 0.014362364672706462, 0.07776415572152473, 0.034210484591312706, 0.026152792452194262, 0.041832252172753215, 0.0835426511184778, 0.03462215019681025, 0.09492296623648144, 0.08408036679611541, 0.008256850251200376, 0.00754381424485473, 0.06895947153680027, 0.03484408574877307, 0.07499216735595837, 0.04181095624517184, 0.0572201165050501, 0.04153315181611106, 0.028005315507471096, 0.05799811733595561, 0.020749463838001247, 0.024300345467054285, 0.02651473601872567, 0.02874476176657481, 0.06765018944861367, 0.09419172070920467, 0.03498180980386678, 0.06675593860563822, 0.024596056064183358, 0.05116488166095223, 0.07744092072243802, 0.010909604243352078, 0.03644584081484936, 0.028373366949381307, 0.03248074986913707, 0.05061461626610253, 0.02579816646175459, 0.012242673092259793, 0.015289060356735718, 0.0163542296650121, 0.04538406334177125, 0.02725759615714196, 0.04697536525782198, 0.03772532938455697, 0.06951531788217835, 0.02050273869826924, 0.029515615715354215, 0.1440954374265857, 0.08594960672780871, 0.1233227462216746, 0.0044966435507376445, 0.05385091819334775, 0.03061240608076332, 0.023958771998877637, 0.10210296299192123, 0.03812212235061452, 0.10567442994215526, 0.040286722214659676, 0.05265376348688733, 0.01997581755858846, 0.09356666909297928, 0.03838719523628242, 0.03854900940496009, 0.028687043086392805, 0.0395086249045562, 0.017673799775366206, 0.06339437328279018, 0.07634017470991239, 0.01763223950547399, 0.10293697370798327, 0.00786555474405759, 0.035493264585966244, 0.024443348047498148, 0.05192079617700074, 0.08855930223944597, 0.014693554567202227, 0.10742592072347179, 0.04951028939103708, 0.06622720291488804, 0.050166607688879594, 0.06755399226676673, 0.0105412355333101, 0.04514575601206161, 0.07000120196607895, 0.060373164305929095, 0.045492765711969696, 0.07868412198149599, 0.04604682719218545, 0.03904527984559536, 0.005556002770390478, 0.03730321433977224, 0.02872839555493556, 0.06302649067947641, 0.016346344345947728, 0.03959295885579195, 0.08974032636615448, 0.04770257721247617, 0.06090648646932095, 0.04159929201705381, 0.06656403405941091, 0.09960818162653595, 0.12120378843974322, 0.13313511852174997, 0.1184294252016116, 0.1657902990700677, 0.07294535374967381, 0.11085824240581132, 0.09410817714524455, 0.14182872546371073, 0.141243408434093, 0.1701590997981839, 0.14330080506624654, 0.1306380142341368, 0.1356685286737047, 0.12004465024801902, 0.0942599908739794, 0.18170906987506896, 0.13798674568533897, 0.12462617276469246, 0.11002714833011851, 0.16988023038720712, 0.11605706109548919, 0.2404390153242275, 0.1878078465233557, 0.14694504701765254, 0.18014892702922225, 0.2968759322538972, 0.058643114170990884, 0.10249639031826518, 0.17602368432562798, 0.14729784918017685, 0.19535513216396794, 0.1186855774722062, 0.1860615285113454, 0.09367509686853737, 0.15487351454794407, 0.09626128856325522, 0.10249159604427405, 0.20691430487204343, 0.12364017762592994, 0.15204397263005376, 0.16092286416096613, 0.08857289096340537, 0.13265410292660818, 0.10424937281641178, 0.11224375790334307, 0.12539811024907976, 0.059955758188152686, 0.19389756896998733, 0.11580001082620583, 0.14628653938416392, 0.12609146913746372, 0.06655161050730385, 0.11713883039192297, 0.14335407642647624, 0.1446161133935675, 0.1973385366727598, 0.10840735165402293, 0.2655509178293869, 0.1249294588342309, 0.06483335309894755, 0.11219064981560223, 0.13845566427335143, 0.16282847675029188, 0.12386767557472922, 0.13409983628662303, 0.07754814621875994, 0.2083666730322875, 0.09343411409645341, 0.1004666906374041, 0.2258103940403089, 0.16618043126072735, 0.13863575382856652, 0.10616823274176568, 0.19446108170086518, 0.11052005313104019, 0.13235716964118183, 0.13560617342591286, 0.18219309858977795, 0.15472045401111245, 0.10719327226979658, 0.14440273109357804, 0.14316849497845396, 0.17117763811256737, 0.17717917857225984, 0.1390172028914094, 0.10287768353009596, 0.12139927013777196, 0.13422753021586686, 0.10742996542830952, 0.2362873818492517, 0.12771003384841606, 0.13521961838705465, 0.14593541447538882, 0.16080064728157595, 0.13897053664550185, 0.13692231295863166, 0.13908758817706257, 0.10346831433707848, 0.1601855701301247, 0.0870495660637971, 0.22236219781916589, 0.09182340130792, 0.16005934565328062, 0.19940191501518711, 0.18517331132898107, 0.08902616507839411, 0.11110059072962031, 0.0814990806975402, 0.08169048800482415, 0.10973905402352102, 0.14566208148607984, 0.09332653979072347, 0.11226950300624594, 0.10939991479972377, 0.15895225427811965, 0.13275956211145967, 0.09393143467605114, 0.24089353624731302, 0.10685244094929658, 0.1542477059410885, 0.12510077620390803, 0.2084517083130777, 0.21876610640902072, 0.1923223159974441, 0.3173296112800017, 0.24977814231533557, 0.0936788744002115, 0.18181069957790896, 0.12134516015066765, 0.1755246493848972, 0.1367274101357907, 0.20821503741899505, 0.19857225328451023, 0.11656770322588272, 0.12295665961573832, 0.2127654416835867, 0.16262515797279775, 0.09963515869458206, 0.08942924774601124, 0.11566358181880787, 0.12281836781767197, 0.24828771682223305, 0.21566076757153496, 0.14642080874182284, 0.17106643470469862, 0.15583475906169042, 0.11716408567735925, 0.11916311239474453, 0.1351307684672065, 0.17679333599517122, 0.157751785882283, 0.16363946604542434, 0.16346500196959823, 0.2107613015687093, 0.1462576846824959, 0.16564667865168303, 0.13199749519117177, 0.19312223244924098, 0.11228055358515121, 0.185832857969217, 0.17850965639809147, 0.10421992439660244, 0.1847034427919425, 0.16905135533306748, 0.09518964958260767, 0.09919320975313894, 0.051915615986217745, 0.1408997198450379, 0.12049569049850106, 0.19043199165025726, 0.18387112417258322, 0.20515997166512534, 0.15916563657810912, 0.12029773744870909, 0.1598886220017448, 0.13615761883556843], [0.0701258827757556, 0.04447661711310502, 0.009913065041473601, 0.07720647627138533, 0.015655428978789132, 0.006696870214000228, 0.020761534869961906, 0.02676657084521139, 0.04220720744342543, 0.0453786530852085, 0.08323400674271397, 0.03709327560500242, 0.022505580054712482, 0.03667649289127439, 0.05465137270221021, 0.008085494846454822, 0.03937988825782668, 0.04884251604380552, 0.05815268443257082, 0.023384921150864102, 0.006688361490887473, 0.025960119783121627, 0.044249193379073404, 0.04547053096757736, 0.04018617604742758, 0.04183538774668705, 0.029390808740572538, 0.010609043711156119, 0.05615339796349872, 0.07998057233635336, 0.05029628686315846, 0.034518950851634145, 0.03440709435380995, 0.05476966733112931, 0.02971152229292784, 0.0984362191229593, 0.02540526977099944, 0.011390480685804505, 0.10634869337081909, 0.04088519010110758, 0.016230480250669643, 0.035229668574174866, 0.0494789670483442, 0.06639624189119786, 0.03696708081406541, 0.025265079930250067, 0.02790337039186852, 0.08483362442348152, 0.03959159330406692, 0.004386703649288393, 0.03608945778978523, 0.014673483183287317, 0.049500979148433544, 0.053680747441831045, 0.049688334329403006, 0.030742363560420927, 0.04601102969900239, 0.05127419259224553, 0.03411868092371151, 0.11719530783011578, 0.058303926707594655, 0.014920384583092527, 0.033236445451620966, 0.05891992412216496, 0.02118404139764607, 0.03948420824599452, 0.1266590933664702, 0.03172289834765252, 0.03983499547757674, 0.03898159986420069, 0.061723472317680717, 0.05201165360631421, 0.030764123330300208, 0.06921011707163416, 0.02143271096429089, 0.029912852114648558, 0.010790455216920236, 0.026810858507815283, 0.02093118611810496, 0.02937857629149221, 0.031432777977897786, 0.022026904080121312, 0.030806874747213442, 0.0418228046328295, 0.029883550269005354, 0.03721825698448811, 0.01348387611869839, 0.035755405988311395, 0.025191082240780815, 0.06998822922469117, 0.0819374005368445, 0.04497655376326293, 0.032671711887815036, 0.01753740416461369, 0.03929565820726566, 0.03510672439006157, 0.05150385761226062, 0.02048438724159496, 0.032742483090260066, 0.03426158145884983, 0.03004185222380329, 0.030749163488508202, 0.09640251184464432, 0.045397262438200414, 0.01671242538577644, 0.03226078100851737, 0.04084430147486273, 0.05406221876910422, 0.03709156866534613, 0.01621333292860072, 0.09336142815300263, 0.030514462996507064, 0.0499363675044151, 0.08894920436432585, 0.02004434005357325, 0.010770039662020281, 0.010887686767091509, 0.026255574339302257, 0.05545902604353614, 0.033631576006882824, 0.04427613333973568, 0.011617169693636242, 0.05168670424609445, 0.04190889376332052, 0.04475108929909766, 0.08047059018281288, 0.03813134353549685, 0.02954359839350218, 0.017345970882161055, 0.020038786933582742, 0.05770302828750573, 0.004678332898038207, 0.0486398800421739, 0.030014544900041074, 0.080855527339736, 0.0859724277688656, 0.06379086567903869, 0.01749820392433321, 0.020510234389803372, 0.04825797826924827, 0.0600450793717755, 0.14681833272334188, 0.051568290873547085, 0.014875711931381375, 0.04734648362500593, 0.06564734067069367, 0.10076154590933584, 0.05222512496402487, 0.05140858069353271, 0.025932836579158902, 0.008953596116043627, 0.016783857099653687, 0.09559427591739222, 0.023953693853400182, 0.02312152551894542, 0.09680519375251606, 0.05406070478784386, 0.03981886860856321, 0.025909590658557136, 0.019731996071641333, 0.013072357087366981, 0.024631833148305304, 0.0556725641945377, 0.01582088338182075, 0.0013007860047764552, 0.12677192949922755, 0.0738185275986325, 0.03720617853105068, 0.022544386956724338, 0.019944333798775915, 0.05552329232159536, 0.022390539743355475, 0.021058134188933764, 0.02281015746120829, 0.008513208467775257, 0.049505317001603544, 0.03973201135522686, 0.049963018027483486, 0.013487310407072073, 0.06120553858636413, 0.013968261064292165, 0.02069798476441065, 0.04461030017409939, 0.014941242643544683, 0.02664618892595172, 0.028604542239918374, 0.012427841720636934, 0.017706422731862403, 0.021152347981114872, 0.03694037834065966, 0.04358095247880556, 0.018506161068216898, 0.010117164929397404, 0.014586352262995206, 0.024114886473398656, 0.04987433880160097, 0.013474017614498734, 0.018503266692277975, 0.06808759644627571, 0.05543667997699231, 0.0067642405247170245, 0.052709487645188347, 0.02278670930536464, 0.020051158535352442, 0.06650112220086157, 0.0087900694416021, 0.05165695896721445, 0.04330386051151436, 0.040306300070369616, 0.04539762609056197, 0.04283636313630268, 0.06558014662005007, 0.030357854993781075, 0.07722887428826652, 0.07039897085633129, 0.0065227201594098005, 0.03477318838122301, 0.05968290388409514, 0.0254996486910386, 0.01413849860909977, 0.061045839538564906, 0.029810311425535474, 0.036507561526377685, 0.03788007830735296, 0.03238618912291713, 0.0762752590526361, 0.06602761714020744, 0.029342756533878855, 0.04041697655338794, 0.041487279668217525, 0.07132088154321536, 0.012524442445283057, 0.018371177393419202, 0.020937136287102476, 0.022685189069306944, 0.04976284966687672, 0.04544705312582664, 0.01776720648194896, 0.05837755888933316, 0.08292115438962355, 0.04477291957300622, 0.04918098733469378, 0.04405627951200586, 0.011972148204222322, 0.022821629208920058, 0.04665159962314647, 0.057759643023018725, 0.02797011358779855, 0.013881326813134365, 0.06909408228239045, 0.013493415499397088, 0.05804010063002352, 0.07131462523830123, 0.024545280175516382, 0.023173642839537933, 0.02640044713189127, 0.022692052079946734, 0.023910571362648625, 0.02536192834668327, 0.032973843917716295, 0.054059205649537034, 0.02428853233141126, 0.04179452509561088, 0.040433852991554886, 0.024055202957242727, 0.013159150330466218, 0.03168996554450132, 0.07350282539846376, 0.047579195161233656, 0.024588295054854825, 0.02001141652726801, 0.04026128139230423, 0.025358273269375786, 0.05899700729059987, 0.04324110450397711, 0.015144964036153397, 0.045857624063501135, 0.013951641594758257, 0.055700031080050394, 0.058915011104545556, 0.015628926885256078, 0.08205614416510798, 0.05964300602499861, 0.042977026096195914, 0.04020452935947105, 0.0489107082830742, 0.08718863711692393, 0.051783127782982774, 0.014769508743484039, 0.025386992529092822, 0.05697833221347537, 0.035745962159126066, 0.009381408071931219, 0.037651292732334696, 0.043548817484406754, 0.031249656749423593, 0.05215253549977206, 0.03222839739464689, 0.004667735029215692, 0.046886162817827426, 0.021928432215645444, 0.02386141335591674, 0.05281630867102649, 0.03415605548070744, 0.02095519274007529, 0.009022974863910349, 0.020132959907641634, 0.015198147266346496, 0.01744829449307872, 0.008934370780480094, 0.027123208055854775, 0.12131229785154574, 0.019007902992598247, 0.005502334361153771, 0.05304683458234649, 0.014588654776162002, 0.052705112684634514, 0.09157553882687353, 0.04923967266222462, 0.019403404621698428, 0.05801673782116268, 0.027448606415418908, 0.01578401162987575, 0.048201593599515036, 0.03091348426096374, 0.027571292703214567, 0.06995402363827452, 0.10106129935593344, 0.04912540789518971, 0.03634591805166565, 0.03080267233599443, 0.049053393595386297, 0.07864386047003791, 0.032921641250140965, 0.019577811181079596, 0.015554354031337425, 0.029919954467914067, 0.05414283827121835, 0.05075053690234199, 0.05222917337960098, 0.006553517896463745, 0.0555510820413474, 0.03876942355418578, 0.03815641699475236, 0.07869288674555719, 0.02605674926599022, 0.05367404955904931, 0.08843879972118884, 0.05643583710480016, 0.03281355486251414, 0.021869388801860623, 0.10530827654292807, 0.1429158530663699, 0.13403730292338878, 0.09157231048448011, 0.14326890755910426, 0.09547046342049725, 0.11588154316996224, 0.13064188824500889, 0.08637174032628536, 0.08437312921159901, 0.0913237949134782, 0.20427732059033588, 0.07118503141100518, 0.16237900243140757, 0.12430119371856563, 0.1426920510130003, 0.1239984568383079, 0.09479514614213258, 0.11958278206293471, 0.17534306069137529, 0.16579610266489908, 0.1604215582483448, 0.13518972467863932, 0.13715099834371358, 0.13478105363901705, 0.08667665169923566, 0.18092564394464716, 0.07229887633002363, 0.12456304568331689, 0.255285709281452, 0.22451939847087488, 0.17575694160768762, 0.12164299143478274, 0.09882005790132098, 0.12786569190211594, 0.11910941801033914, 0.23541428963653743, 0.16929047531448305, 0.14532055996824056, 0.1903030212270096, 0.0973430801241193, 0.18537979165557772, 0.10805595215060748, 0.2275128659675829, 0.1805017885635607, 0.13400438125245273, 0.1525447441963479, 0.1502458972390741, 0.1747825907659717, 0.11918287578737363, 0.12400903244270012, 0.18652572704013437, 0.12301268434384838, 0.14153343974612653, 0.16192939452594146, 0.13627493754029274, 0.107839519623667, 0.12230679800268263, 0.15814895363291726, 0.07547070417786017, 0.2318801824003458, 0.11295215270365588, 0.16404040390625596, 0.1901742140762508, 0.10911977631621994, 0.10061178050818853, 0.2106081965030171, 0.22250586276641116, 0.15610432194080204, 0.13252047181595117, 0.08725000530830584, 0.20675820152973756, 0.11255559351411648, 0.0763607099361252, 0.320635522948578, 0.19602524698711932, 0.1164026941114571, 0.13078896707156673, 0.15072079753736034, 0.14967643248382956, 0.09530004404950887, 0.08690660615684465, 0.1135776421870105, 0.13782801514025778, 0.1544932826072909, 0.09518793522147462, 0.1734728633891791, 0.11109694678452797, 0.1489736483199522, 0.1645184657536447, 0.14804539969190955, 0.12465137609979138, 0.1453327015042305, 0.16070878424216062, 0.151097645284608, 0.2744113001972437, 0.1318769110366702, 0.14555400994140655, 0.11524509958690032, 0.0976675990386866, 0.1315389815135859, 0.09903459053020924, 0.1221852342132479, 0.1752133629634045, 0.13453020772431046, 0.08765527731156908, 0.1101206144085154, 0.200588742736727, 0.20550288842059672, 0.17532072204630822, 0.12879730988061056, 0.1421746108098887, 0.13899477518862113, 0.11048482338082977, 0.13023499835981056, 0.14067516080103815, 0.12662289140280336, 0.09854446878307499, 0.1063581854396034, 0.14622477785451338, 0.08772143235546537, 0.18606314639328048, 0.18132923869416118, 0.13147258898243308, 0.07802016698406078, 0.1769405187224038, 0.16168445610674098, 0.12165764142991975, 0.1699246998759918, 0.16934812534600496, 0.0680444850877393, 0.17300162930041552, 0.06014787795720622, 0.15784603863721713, 0.12573375395732, 0.17733434680849314, 0.28716107073705643, 0.08700444348505698, 0.12070749202393927, 0.10834972388693132, 0.1407550455769524, 0.17528760741697624, 0.22191961063072085, 0.15584988403134048, 0.14665991388028488, 0.15332753187976778, 0.1232508840621449, 0.24837673001457006, 0.12470348970964551, 0.13353762973565608, 0.13033833500230685, 0.19490746868541464, 0.13516035047359765, 0.1502834795974195, 0.08972448893473484, 0.09859207755653188, 0.1333583565428853, 0.12655722617637366, 0.149151808291208, 0.09342264049337246, 0.1845819383743219, 0.11816315745818429, 0.23123672552173957, 0.14309552701888606, 0.10273393694660626, 0.12569347018143162, 0.19748065795283765, 0.2507707796758041, 0.13561504951212555, 0.22345766716171056, 0.0789418253407348, 0.15964987309416756, 0.12722670275252312, 0.16493053582962602, 0.17216842010384426, 0.09853021954768337, 0.21464276360347867], [0.041773956472752616, 0.039392033504555, 0.02359925339987967, 0.028317867290752474, 0.06635386525886133, 0.04577225110551808, 0.030154653104546014, 0.03039905717741931, 0.013863390959159005, 0.08583982082200237, 0.021569446107605472, 0.02814629944623448, 0.009982708179450128, 0.05706394265871495, 0.01494260448453133, 0.08786252947174944, 0.0804538324882742, 0.030640583572676405, 0.01949781879375223, 0.048541964788455516, 0.06745897509972565, 0.031877220535534434, 0.022344571116263978, 0.05427334122941829, 0.0584137348778313, 0.0014186351131684205, 0.07879784126998857, 0.02320860541658476, 0.011816916885436513, 0.030400910691241734, 0.07129631645511836, 0.05376390879973769, 0.031784990133019164, 0.03463283341261558, 0.03433118748944253, 0.018751168136077467, 0.028865776366728824, 0.04363396408734843, 0.05169396987184882, 0.05717177671613172, 0.0759245571680367, 0.05270883826597128, 0.043619588686851785, 0.03858321128063835, 0.04192546592094004, 0.055000230349833146, 0.017364563536830246, 0.00842890513013117, 0.04213523767248262, 0.043314781214576215, 0.09742007052409463, 0.021387751658039633, 0.09408738958882168, 0.037738966348115355, 0.09064439582289197, 0.022003528283676133, 0.017511265723442193, 0.09525626475806348, 0.005317944987837109, 0.059905848756898195, 0.05920804069319274, 0.0360342234489508, 0.03895311623637099, 0.11854165277327411, 0.011526918042363832, 0.027648054892779328, 0.03076906974456506, 0.034055572396027856, 0.0394962087739259, 0.03702107576827984, 0.05650784769386519, 0.05340439391147811, 0.08456508570816368, 0.03504760119540151, 0.03942044291761704, 0.022888852945470717, 0.06454050162574276, 0.015846249989408534, 0.048629898155923, 0.03634965105447918, 0.04701514066255186, 0.02411267487332225, 0.09827021553064696, 0.033791033856687136, 0.07237164390971884, 0.018089131590386387, 0.062315951072378084, 0.031796259645489044, 0.0363069107697811, 0.05448326512123458, 0.057587598348618485, 0.010992722927767318, 0.03895665257005021, 0.010250534432998393, 0.007212309865280986, 0.04384467836644035, 0.03979568020440638, 0.03301115539215971, 0.005207765743762138, 0.038839111221022904, 0.01480670332966838, 0.05294042915920727, 0.04408471490023658, 0.009649391104176175, 0.04175591115199495, 0.029359805521380622, 0.01661125210375758, 0.03446173868724145, 0.06116757773270365, 0.09244880173355341, 0.06137298565590754, 0.05302796547766775, 0.03689477336592972, 0.028796116530429572, 0.054596168047282845, 0.017862171698652674, 0.17946046631550416, 0.06129036977654323, 0.05855223447724711, 0.0297371820488479, 0.028126031393185258, 0.08064750334597193, 0.03625312732765451, 0.04259632289176807, 0.019593258984968998, 0.020604028868547175, 0.02826537333021406, 0.015465739743376616, 0.047694847744423896, 0.00806121641289792, 0.05280026714899577, 0.008818388869258342, 0.04002695197414141, 0.11578349804040045, 0.03127902724372689, 0.02001913857384352, 0.04928753376589157, 0.03492738069326151, 0.008520513056282653, 0.016165766828635242, 0.09253493539290503, 0.06473625791841187, 0.008702117520442698, 0.017246155730390456, 0.048988611524691805, 0.06605996735743247, 0.014026727458258392, 0.014038335575605743, 0.027649108742480166, 0.04072586954862345, 0.05891922650334891, 0.06992944370722398, 0.020425972797966097, 0.016950138997344766, 0.038919912549317814, 0.01689946515398333, 0.04105050349608064, 0.06262256938498467, 0.04846277763135731, 0.07510187904699706, 0.03559555480023846, 0.04099632671568543, 0.045435568390530534, 0.016130249496200122, 0.027274971689621452, 0.008450509048998356, 0.021517408567888197, 0.018109798547811806, 0.0821448233909905, 0.053711513173766434, 0.07168353942688555, 0.019017458143935073, 0.042725868479465134, 0.03204743581591174, 0.00872591541337897, 0.020821261059609242, 0.04220442438963801, 0.03744738765817601, 0.06568054435774684, 0.022961375616432633, 0.06827666598837823, 0.029946354516141582, 0.05120409303344786, 0.02335348563065054, 0.03193681128323078, 0.03674639949167613, 0.04757193695695605, 0.019015279940504115, 0.038995927025098354, 0.05360244344046805, 0.047316111231339164, 0.01651552247494692, 0.03405644070880953, 0.08142928913002834, 0.014934670925867977, 0.03935468863346614, 0.06483897115685977, 0.02815149819070939, 0.03308470593765378, 0.02750145475147292, 0.01832777288655052, 0.02084442719933577, 0.041552599795977585, 0.026451466073922347, 0.03576541756046936, 0.05840068792167585, 0.046841040239087306, 0.04715187766123563, 0.038854766826261766, 0.060568712797248736, 0.012729169447993627, 0.013406326324911788, 0.07415669460897334, 0.04681148420786485, 0.04060297360410914, 0.019275870254205074, 0.011768317344831303, 0.044621810884564184, 0.03494501783279702, 0.03638182315626182, 0.0767550575255882, 0.026342145865783095, 0.021215766355453525, 0.06687266359222122, 0.016950322678894736, 0.0843623977561947, 0.018129647287423722, 0.005827838012919528, 0.09296730320784263, 0.010777532570500625, 0.07738301836070605, 0.05537967932468746, 0.06385025233612396, 0.023165486636571586, 0.030015487427590415, 0.04311763710575178, 0.018533919246692676, 0.0194373170597828, 0.018259209573443513, 0.07931602362077683, 0.022046062622393947, 0.006401497294064029, 0.0829047232400626, 0.044726873020408675, 0.03222279417968821, 0.033197645971085876, 0.013044137849647086, 0.048793456371640787, 0.03414715341932606, 0.047738341309013776, 0.04247313379892148, 0.04248302662745118, 0.029512795554182958, 0.046128118337946944, 0.018856948299799114, 0.04968240828020498, 0.07829393784049898, 0.03132595324132126, 0.034647743159439415, 0.04375588410766795, 0.08653072320157662, 0.04379828300443478, 0.03564121543604415, 0.047420230839634314, 0.07181607215898111, 0.04107537286472507, 0.05483048633323051, 0.02378310564381536, 0.09173873710096814, 0.050580952447489835, 0.03398831526283175, 0.025511792082397733, 0.020780906779691577, 0.039461372361984104, 0.017158502523670904, 0.04674753705330659, 0.006290726651059231, 0.03629138504038565, 0.05909144187171478, 0.04394797048007604, 0.05609115774859674, 0.02667779328476172, 0.026819515660463367, 0.1333314907969907, 0.026844681888178457, 0.05574845250521321, 0.03304275232949294, 0.031870348248048685, 0.024273477865790483, 0.020553950598696247, 0.0251250886140042, 0.0548902663285844, 0.05069483129773289, 0.03228173925890587, 0.022763168381061405, 0.028434803789423313, 0.014937800933694234, 0.025463667516305577, 0.048236318689305335, 0.05491059746418614, 0.030994632543297485, 0.021308514405973256, 0.028307965185376815, 0.031189706060104072, 0.032219005515798926, 0.025429142806387972, 0.06605605623917654, 0.11241281914408319, 0.0071670778197585605, 0.022303303994704038, 0.007657980213480187, 0.0220190280379029, 0.030112469430605415, 0.033550477819517255, 0.04350741677626502, 0.021811286060255952, 0.11512153199873865, 0.03273558111686725, 0.015639513621863443, 0.02058913767541526, 0.049498422449687496, 0.03551764784788247, 0.04763215110870078, 0.04435030357853975, 0.034469891179469414, 0.05312103821779601, 0.034070411638822407, 0.03587686958780978, 0.058530504393274896, 0.042497914109844714, 0.02955614068923751, 0.03777912395889871, 0.045254758952069096, 0.03389036290172953, 0.06662250045337714, 0.025003543378261384, 0.030143450385367032, 0.06933384051080793, 0.04497944071772508, 0.03285086633695755, 0.005011380944779376, 0.009091374904528493, 0.01859823561972007, 0.018928845711343456, 0.040045743153314106, 0.018928478348243516, 0.05740806911489926, 0.06002916401484981, 0.05112972983624786, 0.06116304692113772, 0.06321068431134336, 0.0848689729173202, 0.12624936847714707, 0.13217795582022518, 0.23289098753593862, 0.12469020526623353, 0.20650003803893924, 0.10369550058385357, 0.13949140557087958, 0.12141501108999364, 0.10445350795635022, 0.1613058420480229, 0.19721110991667956, 0.068805668852292, 0.0878046864818316, 0.17897161364089698, 0.15887352725258097, 0.13368994812481105, 0.1569076968007721, 0.1300448304391466, 0.06942054562387057, 0.15044074069010094, 0.2798218833049759, 0.16818547679577023, 0.14762651670025662, 0.11889843284734525, 0.1589692197740078, 0.1508961818763055, 0.1850871479837224, 0.09454714265302755, 0.11111749685369432, 0.1610247016651556, 0.14081127068493515, 0.15975776652339846, 0.17596541089005768, 0.19017183920368552, 0.12255825247848406, 0.12789249827619642, 0.19669597037136555, 0.11357743438566104, 0.10807410508277826, 0.17633836978347972, 0.12137850484577939, 0.14593016006983817, 0.12921901303343475, 0.10523075179662555, 0.10498570947675034, 0.1118841947754845, 0.12876358669018373, 0.07193004377768375, 0.12954913516296074, 0.16568473598454148, 0.263226778479293, 0.12262847449164838, 0.20201368111884221, 0.05489595860126428, 0.2795353252440691, 0.15852592012379318, 0.1214142244134564, 0.19651295675430447, 0.15363669575890526, 0.16040389513364062, 0.18887996789999306, 0.12313748389715329, 0.19522087764926255, 0.25620810978580266, 0.07028139982139692, 0.0905711310042534, 0.09221907734172419, 0.09661364543717355, 0.1261320200865157, 0.11597817079746164, 0.09268237787182443, 0.15485873096622527, 0.12623792455997318, 0.15203818387817591, 0.12546898535219952, 0.1323201513150707, 0.1992451140540652, 0.0968346421723254, 0.14099511550739408, 0.13809538126224652, 0.37655688473023474, 0.14494115923298523, 0.20235708769178018, 0.09411786959390156, 0.15749213809613138, 0.11953048291616142, 0.18823713442543522, 0.2595890674274415, 0.11330920737236738, 0.12642340210732073, 0.11638474898063578, 0.10174879527767189, 0.18824182479875162, 0.15063313505379483, 0.09995258267736062, 0.12574212538311258, 0.12880406342446804, 0.1386716589331627, 0.10319956039893441, 0.12722947838483378, 0.11499592350446619, 0.2285279904026538, 0.26372597669251263, 0.09512711621937342, 0.2008610515622422, 0.10517535789404064, 0.16450804600026459, 0.14754491014173254, 0.14485302177490667, 0.21279610722558573, 0.17936771269887686, 0.16699470084859058, 0.07515140256145969, 0.13656726951012388, 0.13007168134208769, 0.15225569251924753, 0.18303371442016214, 0.24603096448117867, 0.11621626661508344, 0.09236382582457736, 0.1351224712561816, 0.08661248561111279, 0.17926586035173386, 0.1188669509429019, 0.11491675119032152, 0.11631751040113159, 0.12324797484325245, 0.0931608330574818, 0.15554048266494647, 0.08225926998420618, 0.14319605834316462, 0.13394563284236938, 0.12660436739679426, 0.15690799365984276, 0.0888393294007983, 0.13662701239809394, 0.16096482519060373, 0.10988086360157467, 0.16536718583665788, 0.11708169244229794, 0.21425516955787316, 0.1628597656963393, 0.12225104786921293, 0.0632137939101085, 0.1922859507612884, 0.10174797891522758, 0.08585628165747039, 0.09131860730121844, 0.15889392147073522, 0.17435175919672474, 0.23668680572882295, 0.17256395512958989, 0.12266432022443041, 0.17559476749738678, 0.07359428025665693, 0.15525295981206, 0.14513788773911074, 0.19855441205436364, 0.08835498898406513, 0.14841898198937997, 0.10412098868982866, 0.15121469681616873, 0.0809485258650966, 0.0975513861340005, 0.11044135579140857, 0.0859850665437989, 0.0723284731793683, 0.11914532311493531, 0.22010988352121785, 0.07853642717236653, 0.18587150902021676, 0.23057538288412616, 0.14056976098800078, 0.14074817328946665, 0.12386786853312515, 0.17292287258896977], [0.030088715138845146, 0.0025931275285984157, 0.057827119089779444, 0.01603377029823605, 0.0697306075016968, 0.08264917210908607, 0.024206345042330213, 0.06244728894671425, 0.05424133240012452, 0.052138924511382356, 0.04338189733971376, 0.04558464359433856, 0.019943818006140646, 0.027473633490444627, 0.017607661429792643, 0.060850224253954366, 0.02996852432261221, 0.034483435374568217, 0.008646100213809405, 0.04712442932941485, 0.06685990607365966, 0.030937322044337634, 0.09319741351646371, 0.068657959200209, 0.04303990084736142, 0.09225721631082706, 0.10450380330439657, 0.03769507944525685, 0.039806218701414764, 0.03621368217864074, 0.021278548338159453, 0.048713274736655876, 0.010004790783568751, 0.03759234765311703, 0.03195029239577707, 0.06120019512309227, 0.04027807248348836, 0.00731954695766035, 0.03696554456837475, 0.04181975811661687, 0.034570329735288396, 0.004779668061019038, 0.015052410799398785, 0.10440002879477106, 0.04740227828733623, 0.015579902465105988, 0.017837825544120278, 0.007736691468380741, 0.040565673261880875, 0.04166396276559681, 0.025023453345056623, 0.06518850044813007, 0.0445132717868546, 0.04786364923347719, 0.05738968982768711, 0.08976052020443603, 0.06287788302870467, 0.03160551656037569, 0.011921057830477366, 0.02072258881526068, 0.08164681261405349, 0.02068584693915909, 0.05655235057929531, 0.013507686999219004, 0.03520278798532672, 0.03704878385178745, 0.02619803934067022, 0.03720723238075152, 0.05756425038271118, 0.007321155098907184, 0.07634458306711167, 0.021708329768443946, 0.008456869254587218, 0.045139243666199036, 0.01737177535687806, 0.06082259409595281, 0.03263727623561863, 0.012352909852779703, 0.04964418025338091, 0.06023386318702251, 0.03219552767404821, 0.05772806463937741, 0.005682553792212275, 0.04474965695408173, 0.030040594283491373, 0.021459565577970352, 0.05276669609884266, 0.06322198722045869, 0.04632005999155808, 0.09773645550012589, 0.03272458248829935, 0.09238747064955533, 0.02841838006133912, 0.009627321487641893, 0.011361286451574415, 0.05824311883770861, 0.046375387100852095, 0.03321819232951384, 0.06252399733057246, 0.01976675270270789, 0.020272860310797114, 0.023623219203727785, 0.06683193452772684, 0.020945993819623254, 0.029983994390931912, 0.0476451164286118, 0.049290298265987076, 0.030920111639716197, 0.0319653134647524, 0.02789794158161385, 0.01923329138662666, 0.045509519695769995, 0.05408068711403757, 0.016225788021984044, 0.07376841778750531, 0.07549367364845239, 0.023597305262228474, 0.017441518684790935, 0.1172166371543426, 0.07654901506612077, 0.003784439909395587, 0.04229068792483304, 0.17930890491697937, 0.025184697915392462, 0.0250401461016736, 0.07317857365706004, 0.008727244785404764, 0.12210597284138203, 0.05832301474583801, 0.04715458650025539, 0.03892556771461386, 0.04861464702116791, 0.0987822974275332, 0.02345395572774578, 0.04321396416344214, 0.05735070109949447, 0.09749433724209666, 0.04561277470202185, 0.031341003996203654, 0.05082481475255918, 0.07065550162224099, 0.047926713232300244, 0.010617117350193439, 0.06704839674057439, 0.050397879458614625, 0.05233667718130164, 0.03267397543822881, 0.017775049127521925, 0.009710897520562867, 0.032175764281419106, 0.004175785743427696, 0.01927654375322163, 0.04334664161433466, 0.05355971057724673, 0.043099127942696214, 0.007164832359194406, 0.023243920513777994, 0.03951932296331506, 0.051344240200705826, 0.0748657870281022, 0.031097718710952904, 0.07136903950595297, 0.021708251842937898, 0.03410481018363498, 0.030313199968077242, 0.048717953977757134, 0.016185784406843595, 0.03387875942280516, 0.03705783805344254, 0.03346438868902624, 0.033953300735447556, 0.017614364878681954, 0.02169753708585631, 0.05882825033040717, 0.01173471289803274, 0.04021267443022225, 0.04264829549356364, 0.039839730379753746, 0.04816666441911366, 0.02818993216351373, 0.06857918764580972, 0.0806446757633239, 0.07189943760749884, 0.043709169622161426, 0.04167166254774202, 0.06116221942647826, 0.0253813317976892, 0.07595001283334568, 0.02142177170753712, 0.023651636038266588, 0.04915560959489085, 0.18637802480952814, 0.03493821233860217, 0.03711087192641571, 0.03596099202695768, 0.04980833218724001, 0.0467898283386603, 0.0494424942007754, 0.030077080118644517, 0.023302490808418952, 0.0368398692808114, 0.07997733657248318, 0.060186098562553525, 0.06589938144315965, 0.048153109091799706, 0.040014183323364705, 0.0448343174502952, 0.08583613234804943, 0.013375513281062013, 0.038977751828497276, 0.05494938581250608, 0.05440255656139925, 0.08379403880098835, 0.022826191561762244, 0.028935174595972057, 0.0718267665070016, 0.10270991362631321, 0.03476785233942792, 0.03525586267642211, 0.012710246537608327, 0.034780954956659116, 0.08864874587743543, 0.02405918829026632, 0.06506127407192253, 0.04049788920383435, 0.002027611926678219, 0.0135887128271861, 0.0789426194387488, 0.016857841801538598, 0.039424513597623445, 0.018635085107234772, 0.07697250679484569, 0.1132638324634172, 0.02035981775406981, 0.028084610275982413, 0.042028694952023216, 0.009571030514052836, 0.017833803103712853, 0.05772946358774789, 0.027654005061776843, 0.02674164581549121, 0.04826222706469707, 0.05382624178309925, 0.10661697975592688, 0.0357532797352178, 0.05950761231360957, 0.06850251636933535, 0.04359153550467454, 0.026014871727966238, 0.04877107319771312, 0.034999728959519416, 0.02447531049256213, 0.007749269016130711, 0.006939879513083724, 0.03028113547770772, 0.05232815361523535, 0.04255162333720364, 0.06840940652182326, 0.01525112362287473, 0.04175907641183585, 0.025277651911892463, 0.031510722037637606, 0.029417121586448047, 0.027611903024080675, 0.07657849317183718, 0.039338353963103145, 0.006938409132999368, 0.1347641326719895, 0.04504436379647814, 0.052019000868313015, 0.018954071310872678, 0.08488134451908991, 0.05904513927816879, 0.020635241744457744, 0.00557059617676714, 0.019185461824235972, 0.0680827947508078, 0.029251520609250292, 0.04752373446535785, 0.06142166683275718, 0.019461435003904626, 0.01699214641121216, 0.05503112595761195, 0.05622191303700674, 0.019391790010558907, 0.058677805864135735, 0.06296479594311677, 0.051927208332926966, 0.01330478475210839, 0.03562898484233301, 0.04990267028915696, 0.043168051197426394, 0.03625399935117457, 0.019710002525243908, 0.06475301561295055, 0.0598678693495458, 0.055953370610950515, 0.0356838963489281, 0.07089827297022566, 0.03344185708556324, 0.042102527513634413, 0.004488185386435362, 0.020370964812173042, 0.07195703568868339, 0.031757975957589224, 0.02281094599311473, 0.042037715757032856, 0.02270534765557386, 0.0494269350747345, 0.03308376341010444, 0.005107423203298822, 0.042929999908665195, 0.08280547583126463, 0.03542758451658301, 0.052985625952715054, 0.07355110210482962, 0.06337127022561617, 0.04915339428407606, 0.025243609597964678, 0.02002367124077864, 0.005346842826838838, 0.05480918669491075, 0.024137288201018237, 0.028877910481241997, 0.01772995437931968, 0.059508031627046876, 0.014064741189940833, 0.05433379286841955, 0.008951170220825588, 0.022588401880057063, 0.01883321256173076, 0.05100105256133247, 0.06973448151256889, 0.06217842368641868, 0.01853776913776528, 0.016090088174678385, 0.06203018710948527, 0.025890354190778453, 0.04716621966508683, 0.04854445840464905, 0.039075477834558114, 0.08026356066693552, 0.046307565935421735, 0.04407704480399843, 0.046705097338417545, 0.027547154350031633, 0.02331732819584431, 0.03237861179513857, 0.06439225020585582, 0.04558076958346646, 0.04929766037093941, 0.04869801618042402, 0.14380119071574882, 0.1295086881145835, 0.17095260409405455, 0.08630553333205171, 0.25740774697624147, 0.2307041603489779, 0.22484766523120925, 0.14880188566166908, 0.07658930626348592, 0.107375766383484, 0.10029336204752326, 0.1757342615746893, 0.12564579461468384, 0.11999942376860417, 0.12370867785648443, 0.32092840410768986, 0.10714454285334796, 0.10231175881926902, 0.10463970538694412, 0.17738721740897745, 0.2169848926132545, 0.09734990788274445, 0.16917452216148376, 0.1863625436089933, 0.21766830672277138, 0.21737860195571557, 0.14337589556816965, 0.1700549913221039, 0.1388724395656027, 0.14672918594442308, 0.13577493780758232, 0.19870393996825442, 0.12611817161086947, 0.11859418940730393, 0.17084885184885934, 0.12982442742213607, 0.1482194333220832, 0.13218712876550853, 0.12015417640213855, 0.13363148173084483, 0.15870753850322217, 0.07731675941613503, 0.14338215929456055, 0.17173378873849288, 0.11900108671397902, 0.22760833584470674, 0.11132961008115672, 0.06058479513740167, 0.1474060394684784, 0.08955438126577064, 0.09341269571450539, 0.21053024131106213, 0.3313987422734499, 0.11616660209256224, 0.145435904560145, 0.27296675427351147, 0.23676471639191732, 0.05904644545807969, 0.1088137443002779, 0.09102261654334143, 0.17276990110985935, 0.20697651169029996, 0.18409538635751233, 0.1021090560243465, 0.11009851325070485, 0.08010355362785049, 0.14227098610717803, 0.23515370674431324, 0.12650909047806635, 0.13345198589377105, 0.13931944995420054, 0.15434596629347652, 0.07008093831245787, 0.19038700265809894, 0.14915660256519914, 0.10010041849454865, 0.13510244811186567, 0.18992455559782684, 0.23612796852830797, 0.13029273744905367, 0.10213661938905716, 0.1587265671696514, 0.10718506411649287, 0.15850882104132324, 0.1499542480451055, 0.1118335580395069, 0.1313582091825083, 0.13380027579842135, 0.1354098308365792, 0.17348571738693863, 0.10004902476794086, 0.22369797457940876, 0.08193336325348355, 0.06943291722564027, 0.11219084277399816, 0.24686454475158826, 0.16670673270709813, 0.16361009184038267, 0.14203649712726474, 0.09991923056077212, 0.2089504018658772, 0.10067642899230123, 0.1965515484334901, 0.20393370621604845, 0.07619355601491407, 0.09587474094587378, 0.18045322241960093, 0.12414779921527952, 0.16039601352531463, 0.11641503602731973, 0.10513441360672005, 0.17463592754211277, 0.14009589969646186, 0.0823751266580075, 0.19226113334298134, 0.14747356006409973, 0.09585483654518612, 0.09093591885175556, 0.2801808749791235, 0.18734985234914348, 0.18280777498148382, 0.14544881792971864, 0.2686823654221371, 0.12361532310023904, 0.11305015330435708, 0.13711884850636125, 0.07447882380802184, 0.14171465736581013, 0.22020952426828444, 0.14766782463993877, 0.14178925805026665, 0.23953699419507757, 0.15858048282098025, 0.12706898152828217, 0.07184673027950339, 0.13690567400772125, 0.22084422380430624, 0.1532667054561898, 0.1548769135843031, 0.19062437117099762, 0.1616589559125714, 0.15580269828205928, 0.2067521752906032, 0.16825275990413502, 0.10823466131114401, 0.13993740663863719, 0.17030748480465263, 0.12960913038114086, 0.07420015477691777, 0.0961320880742278, 0.10438336015795358, 0.17040123289916664, 0.16000374394934624, 0.18845063546905294, 0.11017586730304174, 0.07744274640572257, 0.1504989992827177, 0.22705671231960878, 0.11709293597959913, 0.15088285290403292, 0.13730708684306592, 0.1431519747711718, 0.12122545173042454, 0.18177298363298178, 0.12306375152547844, 0.13660462922416627, 0.11590746638830751, 0.07431289443047717, 0.18714145728154108, 0.08215107969590463, 0.08036887884372845, 0.13778581662336364, 0.09836808996624313, 0.1698116262559779, 0.14738080644747242, 0.17338769452180713], [0.030635728071501944, 0.012517133218352683, 0.03813070899923332, 0.0236238574507297, 0.03224625346774701, 0.006729184251526021, 0.00760086360060086, 0.020453363613341935, 0.03891841341101099, 0.049949154708883725, 0.02691917310585268, 0.038771245526731946, 0.029046153504168615, 0.0616274013009388, 0.027401331608416513, 0.030496057734126225, 0.08383787746424787, 0.03949826081225183, 0.026826430621440522, 0.020474052835197654, 0.05909505613090005, 0.06505813478725031, 0.02806206754030427, 0.04078132282302249, 0.09306387888500467, 0.03679646106320433, 0.01786458738934016, 0.016521665602340363, 0.05082173112896271, 0.028460430148697924, 0.02516730939532863, 0.004834568435398978, 0.0459561627212679, 0.022275996670941822, 0.052362366623128764, 0.008043226753216004, 0.0880452165438328, 0.039966949334484525, 0.05990342193399556, 0.03441364380705636, 0.03948982630390674, 0.06863378002890386, 0.03375040498212911, 0.030210675977286883, 0.039314163659582846, 0.0343496075947769, 0.05383455383707769, 0.07343921592109837, 0.03242699611291755, 0.1321256344090216, 0.0382107867335435, 0.0435073982225731, 0.012750730693369405, 0.01767790199664887, 0.02640284612425603, 0.045026826846878976, 0.047822489723330364, 0.027181425830349326, 0.09121924114879221, 0.014347015203384217, 0.021138072770554572, 0.009251938554371009, 0.021016826249251608, 0.018458452104823664, 0.04707890599092934, 0.023540983675047755, 0.030982008611317724, 0.011925000490009552, 0.03683589136926457, 0.04780720148119144, 0.027006258569599595, 0.006074592374716303, 0.029339958637137897, 0.0655888594337739, 0.032654980168445036, 0.049683937104418874, 0.0340446294285357, 0.012483443424571306, 0.07672237334190868, 0.059508224585442804, 0.04037408412841614, 0.026724251729319803, 0.033201041296706535, 0.038918880964047275, 0.0875937903765589, 0.026175401981163304, 0.034134388479287736, 0.03660410009615589, 0.0351075370417675, 0.0219889506479376, 0.058398762048454955, 0.07545473315985873, 0.056365592827205546, 0.004856848636336508, 0.023883520079834852, 0.050998072838410735, 0.038427579202107154, 0.014393012588698184, 0.03280072312918492, 0.02745719306403771, 0.05208965332712978, 0.03570410503016319, 0.030187392949301284, 0.02230010533821769, 0.0490124270436354, 0.08825637982226908, 0.03727384755620733, 0.02529370271076914, 0.01602174379513599, 0.0464892102900194, 0.023333193457801826, 0.05709223332814872, 0.01698321651929291, 0.03234265102946665, 0.02092009843181586, 0.0321015569352312, 0.04872833291301504, 0.03165722569974605, 0.021236548345768824, 0.015514901460846886, 0.026069230334542226, 0.049850508439703844, 0.029697440040763468, 0.05409905897977296, 0.01845289527409477, 0.00834883388961316, 0.020086844706384, 0.05474184421473183, 0.047382763514178805, 0.11844108434161171, 0.0269889720948413, 0.003944225927625666, 0.023018845677142963, 0.02912715706770541, 0.0416362546820892, 0.02154942852939712, 0.03925036493455991, 0.02815522933815373, 0.07830849135643803, 0.023699417361058295, 0.07842219580197707, 0.041715772094903514, 0.04664288309868425, 0.028372112719807774, 0.0178973995934939, 0.01074716203220305, 0.02517374567105435, 0.033471995702711865, 0.029584937874460593, 0.011305908319627633, 0.04285417096980382, 0.04089085639861878, 0.08671810064697638, 0.07699802925344557, 0.025353879755130038, 0.030705768258485477, 0.04957707154972013, 0.04593036195728928, 0.01916407869430259, 0.0209062128487858, 0.008670553052070318, 0.013707858142879559, 0.01621082818019204, 0.015018303547549294, 0.036894053482683375, 0.018719409781624563, 0.04007463125162758, 0.030984370496298652, 0.023179437157523353, 0.019821007408609148, 0.008136352371366229, 0.035036231492995284, 0.012371964494377607, 0.05596562346909195, 0.02737624145083828, 0.023100001380953472, 0.025270928053942043, 0.02056197692581918, 0.04586415125231724, 0.015151504212553846, 0.024049132189247757, 0.012531976171885617, 0.008649424107716186, 0.02715059330512304, 0.0033242014342249604, 0.059696243988582864, 0.03756006793992128, 0.03188871640304569, 0.07523706866777502, 0.029576646229543258, 0.03617678630689625, 0.004393297631395399, 0.04748356201162096, 0.05110955084091984, 0.08666434689075686, 0.0248873249074677, 0.03381004396942444, 0.04935767414281145, 0.03867547507979907, 0.020881033633486368, 0.04001567875093315, 0.011071234730479773, 0.08601526453276165, 0.03260022080212366, 0.015894574935373385, 0.06565926698385738, 0.03998345469881315, 0.029679556137125473, 0.020801102473342326, 0.010866571738006314, 0.02665443975274684, 0.015694256289862096, 0.05064206830866169, 0.06694575771689415, 0.02105486131767975, 0.042996741249226034, 0.051394594920566306, 0.055715983544359915, 0.043546639280975796, 0.03426355186093133, 0.05995899024128448, 0.070063868915895, 0.029217992232588585, 0.062442160706268623, 0.04956971686624456, 0.025292942009400576, 0.027997932993457653, 0.007207677008409519, 0.09511472235317342, 0.03976102190790698, 0.05554574971029069, 0.023811939936422277, 0.0486417168576736, 0.07967553479829803, 0.022650686623819638, 0.042209678795188665, 0.013414412023848854, 0.017554690639371984, 0.012771579476975603, 0.058449543503229506, 0.03234470306779258, 0.015117031452973606, 0.0585606689855922, 0.01863177883933531, 0.020313958593760617, 0.035295103734824806, 0.0682257249718532, 0.06143849503132515, 0.0677917838038411, 0.031671174365328625, 0.024174430836865213, 0.009334792848676443, 0.015205840554699535, 0.010934545971394982, 0.00864852703671204, 0.04871262164670043, 0.04006595925602596, 0.07826296059647575, 0.034008794827968813, 0.03634598484495655, 0.053761478266096674, 0.016108725358208176, 0.0572376015043119, 0.0818830679054372, 0.08162090423866175, 0.06016056126100011, 0.034744623117148876, 0.02843480007868493, 0.05074245491414331, 0.012788583007932175, 0.019169900842825882, 0.040871308228815906, 0.012685132260230603, 0.04837633598071989, 0.030839341852697544, 0.049562744388822466, 0.036480124326772057, 0.05823746367241256, 0.027581398899201304, 0.040500034010619856, 0.03520753401971888, 0.03245995489123743, 0.0521962146012811, 0.034607763664098457, 0.07179765205364674, 0.03785687134950422, 0.05005613529647235, 0.05012206769606564, 0.015637229662388563, 0.02718292125791777, 0.01883729622932151, 0.02102242946421029, 0.07933289263746701, 0.0302886868303176, 0.024322170174855273, 0.016914400875975844, 0.030423379212152213, 0.026665221303119324, 0.022334145796776284, 0.037174670651438646, 0.054644422489218414, 0.029232482665975112, 0.005282159090711502, 0.05469032061228063, 0.027402047780924477, 0.055074901538318954, 0.06621814129175618, 0.08101591287413612, 0.11519140520249493, 0.04686684471380431, 0.05474416342622135, 0.035802398779196665, 0.044925772308488376, 0.023588341973663773, 0.010977217607432976, 0.043561890415730886, 0.022784683242207393, 0.03199703656719066, 0.07645980891538784, 0.0281787183121196, 0.07868559143389575, 0.06287069161771797, 0.05335156041837763, 0.03012727713212371, 0.04385745443869382, 0.01600174291525036, 0.02415525003016228, 0.06859675428131595, 0.05897448310861364, 0.07689020261750557, 0.017090685068978928, 0.022739469750376884, 0.035482284511090256, 0.020789283771591727, 0.03412040641705971, 0.06772338005248457, 0.02710658580326708, 0.025800075636652764, 0.056077216504490934, 0.018769447233353276, 0.02249632918392308, 0.04411454181536101, 0.06606724782614037, 0.103105856833281, 0.004369355483504478, 0.014300470484158723, 0.04748621518956497, 0.015816779305168893, 0.06884475034894422, 0.04534795785730239, 0.0797153361781966, 0.044336640639812686, 0.13321804610313848, 0.10394437980721705, 0.15420887677464634, 0.14072161924559623, 0.11109972241683863, 0.08728484914172441, 0.12791753833880648, 0.18669729674002156, 0.11424196825828403, 0.14057390217203647, 0.07716771389823407, 0.12795920250937343, 0.16473693918669596, 0.13206915697082877, 0.1414279211894609, 0.12120962172048166, 0.26932625274639577, 0.12057441752403975, 0.17042579798726365, 0.09900034783640876, 0.20400351262651384, 0.15756654582219198, 0.1145319698844105, 0.14458944060606882, 0.14226669649360701, 0.11613765091169626, 0.1590331335319206, 0.10888908713241108, 0.09284843341447413, 0.17185609467560425, 0.07502603897592053, 0.12904037808766589, 0.24067249498330057, 0.10481590608833358, 0.10894648483372293, 0.13223639252828434, 0.21498893096577376, 0.13014500553254038, 0.10183401609538123, 0.12423224077792838, 0.15260885091265664, 0.23683891631662846, 0.11660000149277039, 0.08728050015633926, 0.128282600780949, 0.13218182983109728, 0.13159127323888242, 0.18373618688201532, 0.1266473822761327, 0.24292065325425938, 0.17327858397038653, 0.12499458971433342, 0.2281094784848392, 0.08337011662661098, 0.09831102623138577, 0.21930487593635917, 0.16308267717249691, 0.20356522989459336, 0.18836655013728887, 0.09866158710792661, 0.126279752003029, 0.1001678648754023, 0.06859005268779583, 0.11654494155663997, 0.16088041331386194, 0.11213516685529612, 0.08360221589100547, 0.10707515204558149, 0.1285492692841217, 0.2085997222457081, 0.09986626348108985, 0.15172478975728154, 0.15651296329451725, 0.16504123457707465, 0.08284946292405948, 0.09321359975729138, 0.17084402788896114, 0.1307075534714386, 0.14093057834543288, 0.13962462107883766, 0.11716433058609255, 0.2312684152275324, 0.09757140185683966, 0.12714031676296145, 0.2521414670627564, 0.14248938532546163, 0.18693310674279928, 0.26604394137393683, 0.14659469394246116, 0.11771448465879075, 0.14012215688126162, 0.17364084109431133, 0.11073120898799971, 0.11654765039565973, 0.16094649414299056, 0.12985356413992122, 0.20053845481015742, 0.1357358563109301, 0.08279457368189469, 0.15682404191466048, 0.21359180827857926, 0.10607174612232484, 0.09225639252690598, 0.07643216391443275, 0.1599661319050938, 0.21031237643910572, 0.2062942850170657, 0.15877893310971558, 0.19871550262905657, 0.19418568554101512, 0.19348845264175907, 0.10106264264322817, 0.08701415077666752, 0.09206962364260107, 0.17386911087669432, 0.12532432592706755, 0.14814760826993734, 0.051485541407600977, 0.11267386958934367, 0.07057284863549285, 0.19370131543837488, 0.1415372543851845, 0.13223523477790877, 0.12455127522116527, 0.13542819157009944, 0.1410284824669361, 0.09602538208127953, 0.14804634964093566, 0.18184326501796022, 0.3120226913597435, 0.1267921456019394, 0.24261147453216836, 0.1615318111726083, 0.14404917194042355, 0.11548911774298176, 0.1041073925443925, 0.13181523856474087, 0.11395994471968152, 0.18845134793082252, 0.09511397278402, 0.10560935843386687, 0.15678282303269953, 0.18762940453598276, 0.17431796179153025, 0.16100822598673403, 0.08167959327693097, 0.15457465167855844, 0.19070384034421295, 0.1304124013404362, 0.10096930272993632, 0.11521988140884787, 0.15799737739143893, 0.16357852087821811, 0.1715428489842452, 0.091525503230514, 0.14137778169242665, 0.13755508291069418, 0.15706555161159486, 0.17555602738866583, 0.19943648425396532, 0.08082516607828438, 0.05568640524870716, 0.11515596022945829, 0.06437609365093522, 0.06836249536718242, 0.12560941453557462, 0.14364367729285732, 0.18546678620623425, 0.09318277094280347, 0.12862988136475906, 0.12724880391033366, 0.15947217325447127, 0.09890655521303415, 0.12984767148736864, 0.14539366151439026, 0.0892090228444431], [0.010582490594970295, 0.039696466192253865, 0.04125252722587902, 0.07913528839708306, 0.0619768415344879, 0.02119163913448574, 0.021131157809577417, 0.07021044308203273, 0.04492641055549029, 0.015170704500633292, 0.03405455565371085, 0.02770931547274813, 0.03596219430619385, 0.03510332535370253, 0.025548986668582074, 0.026504104753257707, 0.068021137121832, 0.03122810107015539, 0.038846239549457096, 0.006642892885793117, 0.021857592364540324, 0.03603228644351475, 0.06448417261708528, 0.019826554962492082, 0.08653609635075554, 0.06710572022711858, 0.055482143943663687, 0.03740664375072811, 0.05974374515062664, 0.15579158090986311, 0.08430949004832655, 0.029335387007449754, 0.03928042933694087, 0.030926364233891945, 0.022004092315910384, 0.023674620351812337, 0.06730886831064709, 0.02004453301196918, 0.004383253590276581, 0.025329579984827433, 0.01451555137464311, 0.0719255834701471, 0.062478355248458683, 0.01536611198389437, 0.023116278534871526, 0.045464085415005684, 0.01391306939694914, 0.025004691851790994, 0.05493363001733087, 0.02688517161004711, 0.08646900620078668, 0.031021832255646586, 0.016602815740043297, 0.022351799634634517, 0.04290491902793292, 0.09953603745088913, 0.05378927169658709, 0.043759145846706815, 0.08243154472438619, 0.013794756214338122, 0.06481592005002312, 0.04064801454660483, 0.02855308172001969, 0.033160126695293, 0.026390745406388305, 0.04836512955080252, 0.018230328896606807, 0.06845685202279128, 0.023848485143389553, 0.013351794241316384, 0.0460875377029879, 0.06704131665173918, 0.08899018575903028, 0.014028620862518437, 0.034656890129554085, 0.04765834892168641, 0.05558870892855339, 0.059364114349591546, 0.023650509829167277, 0.0026973021022058674, 0.03426348135690205, 0.07315790484426543, 0.10392938842414878, 0.026542536870692857, 0.013930453278589994, 0.046132445058901794, 0.08358215563930571, 0.02349514492379967, 0.051132535154465586, 0.023390774840663653, 0.07010703222476877, 0.024675751592440065, 0.024741164488659706, 0.007535329177699168, 0.011502152574394131, 0.029801073542330414, 0.034957530442625284, 0.04839800669287797, 0.062483624496962875, 0.05539904937904794, 0.05587869571172632, 0.06202228323672898, 0.016543933743378147, 0.03804338790359907, 0.01755842549755471, 0.01988892134249909, 0.05049930507084355, 0.033706054236972705, 0.04452454129932448, 0.02076288001262583, 0.03852965419355314, 0.05366970428440254, 0.04234449363138992, 0.0969176810758654, 0.04824168070626911, 0.023115130061341915, 0.05025517188187223, 0.01581071595865069, 0.04929597198497504, 0.018441239844833035, 0.029269955557538196, 0.018715693477133755, 0.028078656396246515, 0.035766456567216665, 0.0038946147469687276, 0.013306890596140875, 0.03327390535559971, 0.015162142899498576, 0.045419274538289756, 0.03710670476721134, 0.053803376213181764, 0.03215852048015222, 0.09381352967466228, 0.0586882812785916, 0.03323073091451079, 0.023899426159914583, 0.024060687428573146, 0.052494925330393016, 0.041006594328791834, 0.02675249044841621, 0.02660021844349103, 0.014561830776074203, 0.10063803027151152, 0.01213518784425105, 0.041910782529157586, 0.0729420363495592, 0.04863938651396893, 0.05559308388910722, 0.05398171801061835, 0.040049505842034705, 0.055607800677535124, 0.05866216139111202, 0.026284755585948005, 0.04571900572045706, 0.04580546221404802, 0.015533406913164072, 0.03042778200324392, 0.04892749566351995, 0.022128170130599756, 0.02282632700371323, 0.030784111222601496, 0.05569596040004399, 0.049689321385812946, 0.022781599618610926, 0.020344002587080467, 0.03145404793031048, 0.08707289176527411, 0.01315975425313809, 0.039602985270903446, 0.03025166293809889, 0.05119672350701876, 0.04637730926333461, 0.060730059412890114, 0.021398458993644454, 0.010561612125457032, 0.034851919117500074, 0.025684493557491805, 0.06509946499136277, 0.029441744190989994, 0.0339913358038757, 0.10953826596960425, 0.030599398087360896, 0.005075516419310588, 0.06972512303036638, 0.0571450222923886, 0.017530665463709738, 0.0456864848092664, 0.034664819977479056, 0.059680005797417834, 0.00999392852463643, 0.029155069241824094, 0.07037381205009297, 0.006725642815581523, 0.03992057252617087, 0.015828314135433175, 0.021991171524859965, 0.02335449866222916, 0.013810886794090038, 0.01921920913446229, 0.041250879658036865, 0.06204043987963814, 0.0815373235673178, 0.00877515041793231, 0.016652103622618597, 0.12978444050531834, 0.06510083796456456, 0.08942924032453448, 0.08117191231576726, 0.024237954967247788, 0.019293692930659745, 0.004534163290372817, 0.059931118885288015, 0.02469439248670824, 0.09811694719246589, 0.06362967862514779, 0.06340932013699785, 0.02408881668088725, 0.023103502462618053, 0.08351108757779002, 0.011479333388706436, 0.017648216089583002, 0.011208467112737708, 0.03571082517737523, 0.0262272799591301, 0.05566825231653638, 0.02736663805990247, 0.02761543008091394, 0.060397595807444304, 0.026407089353597257, 0.0028769387154170545, 0.07606638901052065, 0.05633525383018423, 0.06003929433063604, 0.06875123232020997, 0.03648138226708397, 0.027930679570999928, 0.06539348905789666, 0.08161728255799972, 0.004163510157013661, 0.03195403282006737, 0.029474064722307958, 0.015154071115830448, 0.00125591691585214, 0.061633305085706525, 0.04788658159668557, 0.046556716042687185, 0.0841218231653329, 0.03899358554917853, 0.028531327516247984, 0.048461152327945456, 0.027285224459774327, 0.0063666803634987446, 0.06061768712243065, 0.03186472647939809, 0.0261812018652563, 0.0169073950019083, 0.029530007814173587, 0.028422883042367175, 0.02612854277685983, 0.024338144903595094, 0.037630991282640025, 0.04367329791421071, 0.02425675356789725, 0.01643925566895632, 0.034589699789648876, 0.006796227553422796, 0.010747272426669952, 0.016966572002274916, 0.04699506927863695, 0.05529770911380183, 0.08651475218357518, 0.04094483650987968, 0.03255053030443378, 0.032694536639610305, 0.04801917741133366, 0.07993870778591372, 0.028591584341484122, 0.020588252664310858, 0.10096367725054733, 0.032058493816293776, 0.007809551352693234, 0.0074446034795983, 0.039220152102643624, 0.021518024550459813, 0.05325402365997434, 0.047192643833113834, 0.04076817938766908, 0.022796629964432213, 0.036115388429607265, 0.028829103139287326, 0.02535987259761896, 0.018029652164841536, 0.03263450060330797, 0.039286047394853085, 0.016713787226763088, 0.02240065707155736, 0.008716364900465123, 0.09593535956810229, 0.05660525828716345, 0.02697816085856175, 0.01635436881770147, 0.04311986354878172, 0.06436115421820432, 0.041148504096781835, 0.047766665375093, 0.04492783918976784, 0.0411466301738983, 0.07410203543258831, 0.05653665786667261, 0.02781839262752328, 0.08497860297211446, 0.05392447244958021, 0.05360664399631787, 0.02613120337628061, 0.0640022664447315, 0.044773257250199094, 0.015933329887047876, 0.0758538898662664, 0.047067744089872576, 0.06308848227490671, 0.08786874124780297, 0.058837527176365256, 0.022620568415732123, 0.029939573141746223, 0.037408120624604635, 0.041713237660587765, 0.05144455630215816, 0.039277590622077696, 0.008030155677261064, 0.04497735157201532, 0.016520016179129016, 0.02744289187830873, 0.039930914354044944, 0.0650013901758939, 0.021390820438682567, 0.03134422862785868, 0.01971725887415232, 0.04926177753077354, 0.059344662658986636, 0.02597005157440435, 0.05252041439234745, 0.022397792381525505, 0.016326660734193865, 0.05938607449934352, 0.008258527504949598, 0.044340392196318135, 0.03164831992762629, 0.022176712154760025, 0.03889594489010051, 0.014544193636538694, 0.05852589565620292, 0.035308863152749836, 0.1528861914994195, 0.19212579529266804, 0.12757436925312504, 0.1535437343409285, 0.20653389481594786, 0.11847802845295519, 0.15755584405269474, 0.2372843978810124, 0.14039844361832365, 0.10318287691916339, 0.213789768749848, 0.14922308415407315, 0.16980138461804017, 0.11154609455843456, 0.14536050235619769, 0.12275950808543712, 0.21735543210525066, 0.20407723757671192, 0.09281637263484299, 0.06685445870971307, 0.08599811349995434, 0.09297287673689425, 0.16554840345634148, 0.1346796317375265, 0.138030918315053, 0.21920986619079486, 0.15453683183295652, 0.13073226698907092, 0.18335865635890514, 0.27450786845292896, 0.21811754355439916, 0.09033231530338526, 0.0970105237502139, 0.07220080151455477, 0.09233944627339952, 0.24729521304834634, 0.10885625451919623, 0.3338679566513747, 0.1253380556590855, 0.14489438908640295, 0.11262909582001157, 0.11557846490177326, 0.21523936127778143, 0.11487840441986918, 0.09673324995674193, 0.2580040181055665, 0.1083294558338821, 0.12261009149369784, 0.14405141322640702, 0.1512569992337376, 0.17753257445292547, 0.08164529863279313, 0.15332579525420442, 0.08474429210764356, 0.2025249763391912, 0.21393748582340777, 0.09908734980854206, 0.09797113743843511, 0.17496342246886343, 0.11801568529335782, 0.15798299456946552, 0.24500417348463088, 0.09962028605514206, 0.12647205730900168, 0.13091796718072146, 0.10652558426954783, 0.06755466019967571, 0.1539424606016837, 0.13218174077337608, 0.18488786648958921, 0.18474304379196838, 0.22382862225640565, 0.1952885912032798, 0.17835261794971302, 0.12531399523140863, 0.14299704402219504, 0.16106338240206242, 0.15494195540668443, 0.14945784030715004, 0.167712609982118, 0.1279832629370503, 0.2174564977758564, 0.12805952603230253, 0.1334995130309835, 0.22471127333119512, 0.1785455021308735, 0.1827899634372443, 0.09653511137003079, 0.14222424564650282, 0.07112194885849021, 0.13473271013936028, 0.12848109559854493, 0.10920363900368102, 0.11846639899886213, 0.12850013910792768, 0.11085526639362797, 0.14788611995754763, 0.15181758790276945, 0.23351741954684258, 0.23946110217366368, 0.13695242931135, 0.18233314185636118, 0.20203695486998186, 0.145899212511722, 0.13891472714021802, 0.08961856961832382, 0.20781199185876176, 0.1658581758965738, 0.17699196439934894, 0.11667277649394237, 0.14813093963311985, 0.18418404331896454, 0.1355577853973955, 0.16029889608034864, 0.16298921109410003, 0.16488091583596542, 0.07371788495220244, 0.09724968826049007, 0.1524773720302619, 0.11450960897491314, 0.12909348617540672, 0.15109136671526358, 0.11585553831537254, 0.14146053115837276, 0.11322551537887193, 0.15518591419095173, 0.1311269708094187, 0.0972560336231254, 0.21904907247517258, 0.20045386481797323, 0.14172495837556198, 0.11774677550420165, 0.1975862358813174, 0.08701633269083686, 0.21890883625019342, 0.06154862232506275, 0.13450067024677992, 0.07386509736534208, 0.1550766106811352, 0.1121691646403633, 0.05756794998887926, 0.15528708376223221, 0.2413143785088323, 0.1843285543145612, 0.15930879686493427, 0.13255363097414374, 0.09595503390301019, 0.08558617701055482, 0.1403464042232372, 0.14152579562505707, 0.12529322993941605, 0.08062040011282079, 0.08400332444580272, 0.11477715321234427, 0.27014436665922403, 0.11696261484757997, 0.12958361534401774, 0.13154288521036506, 0.15091141074663028, 0.10111917945323512, 0.1784319683793001, 0.14986985101131722, 0.16389522497775033, 0.10730267225881107, 0.1626682619098574, 0.10539976850850508, 0.1996268451330252, 0.1027609288576059, 0.10042395035270602, 0.10456786549184471, 0.1840141657157801, 0.11778164902352728, 0.14737748162588105, 0.09676113244495355, 0.2516028459649533, 0.12837740272516385], [0.028012944785587024, 0.05611308450170327, 0.03418198612052947, 0.049752734194044024, 0.05782114480098244, 0.030174503699527122, 0.06500516770756803, 0.04961860213370528, 0.045400442540994845, 0.10606928961351514, 0.021109798799443524, 0.028479850298026577, 0.08242643874837086, 0.05449290190881584, 0.03820648598775733, 0.021185846671869513, 0.02283683767018374, 0.045887506639701314, 0.020962424969184212, 0.060092409839853644, 0.019489998412609566, 0.029419815582514275, 0.04306044720578939, 0.05239503596385475, 0.05770138814114034, 0.05583002195635345, 0.05222633837547619, 0.0767203324357979, 0.01761768784490414, 0.02253409522381844, 0.05161114619113505, 0.03539235105563421, 0.04749776671815198, 0.022696621854265686, 0.020313418681325857, 0.016152873868122697, 0.0026870085139307776, 0.060243132611503825, 0.04018929677840788, 0.039012269116938114, 0.028060108270437922, 0.016201193247979973, 0.022117802327557, 0.0779612924088724, 0.041856683674268425, 0.020433949030120857, 0.010527701542741852, 0.07320909076952375, 0.02786304579785792, 0.053064853927935474, 0.028185507107991725, 0.011179278444615193, 0.06493042601505294, 0.019979964308731724, 0.02473086347890785, 0.05552483598876279, 0.052859301285934635, 0.05495717465237249, 0.004087855159013998, 0.024625691876281053, 0.021679363744624425, 0.013361141591303749, 0.023902827051642817, 0.00990322323559667, 0.034683262347243726, 0.02843526948709041, 0.0015118788951440365, 0.0838232423120644, 0.0635722215520218, 0.09579742400092073, 0.022086320423113648, 0.0551754365733359, 0.03726906441443134, 0.0337606985704042, 0.021991609391989186, 0.061537378787761554, 0.03364693846378941, 0.03960621361329686, 0.05925213910813909, 0.027292517916066572, 0.022342068223224487, 0.08395513679715805, 0.031055637082317844, 0.05152420359081589, 0.07474614540114999, 0.03756989768589847, 0.028495363039837684, 0.05430969162262045, 0.0878021409153007, 0.040293249403475784, 0.04321469517890364, 0.0414243418344995, 0.021252571314107627, 0.04480740346480161, 0.06446628685807809, 0.06621840104344301, 0.010368281728005968, 0.02108256383507978, 0.041865704479278065, 0.06099536236433778, 0.02597150803921977, 0.00849001820824924, 0.07180918502854183, 0.07824421394616365, 0.06427936212276109, 0.03528675086272415, 0.0278198936211993, 0.029729408051935025, 0.03607143102271948, 0.01774487340298947, 0.039376121858367696, 0.043618315903586335, 0.00984567153864191, 0.05221895771683194, 0.008911934728530468, 0.048972050499287434, 0.04420558478159364, 0.05599375828751363, 0.02414613831206225, 0.052288348524598405, 0.047519749132334255, 0.13580719154560938, 0.07371744708507322, 0.06872693440527655, 0.016027988967834972, 0.023619341482117306, 0.029810840205755085, 0.006342073993437225, 0.021814308456669096, 0.036355243137222715, 0.05795500226668082, 0.03767933478229679, 0.05758370207331609, 0.05752216689870693, 0.0941608176799491, 0.046410171562456526, 0.020705452625406906, 0.009170182638627011, 0.01969220767932711, 0.06475026224507019, 0.09565536209265701, 0.03803716870606877, 0.015204275550786406, 0.05918044022109825, 0.024655413035361562, 0.036983886748203076, 0.045411849350784905, 0.0873865901667159, 0.018924899341072887, 0.03231505797884893, 0.051743088915827684, 0.051876037250622176, 0.04712525682407431, 0.09148904893663712, 0.04275706836779136, 0.025994073039328214, 0.07724066701484844, 0.07674019972910173, 0.03993980528321117, 0.030900390920578502, 0.02169961138861254, 0.08846942815580405, 0.06799950351705775, 0.08691451002960093, 0.02513548795832321, 0.052389692500582896, 0.011014016072294908, 0.06269950783462264, 0.04334647463110741, 0.0731702616030816, 0.02379822875809623, 0.018498973367968574, 0.052430017094593495, 0.020481982683122624, 0.03465194000455085, 0.014967114839237183, 0.06054564313672017, 0.017788118348107673, 0.04421585981617682, 0.039446098962798715, 0.01989334268728271, 0.020237847638782114, 0.0067560008301370544, 0.030369707092177123, 0.07217599151772447, 0.04834437910176348, 0.0323316412686836, 0.03553567461494822, 0.0498998501279857, 0.03730350006662775, 0.031483281127293594, 0.04291251862014178, 0.030442647221207153, 0.058628504993976094, 0.00917620052860002, 0.030323139180836733, 0.02226311669801362, 0.06414072893676348, 0.04738049625302665, 0.08682661748025566, 0.03507120149151888, 0.05072840605862439, 0.04957137927704025, 0.05285066268697847, 0.02405915489362087, 0.03154880163492635, 0.08155568430083804, 0.036749631544807926, 0.05775983969215304, 0.0868858334433753, 0.02298512805282371, 0.030498779560730327, 0.06344097273540683, 0.050993274853681214, 0.02278593005030416, 0.08267860568594187, 0.04894427562248893, 0.045152943712309934, 0.044534816333907656, 0.045808427094016224, 0.022510804774356075, 0.028226230606378522, 0.03947541750676464, 0.053606191286235116, 0.03456328675383702, 0.0503908253449481, 0.04910177049168851, 0.0529845535493223, 0.07589124215883203, 0.026602988509694114, 0.038905017645447515, 0.05679397159838118, 0.06154664821224287, 0.04408756103657652, 0.018833860085578635, 0.030664280347991735, 0.05611890293948818, 0.024618283387098927, 0.024879736447473988, 0.05935434026469011, 0.052234884205972776, 0.045375369081739336, 0.02711139492021175, 0.10289191050105728, 0.02113423586706631, 0.04841210749873426, 0.03686648640723433, 0.02558975655119866, 0.014859272432659054, 0.02400614885118557, 0.08757350748055615, 0.0341301916341763, 0.01712393142952351, 0.029154234325687867, 0.02274496164318407, 0.05477764170791488, 0.03380326816113666, 0.0516470995353302, 0.012976627458556322, 0.021046096553618554, 0.04569257784169167, 0.03253599534218665, 0.04794101812876761, 0.020592781620507594, 0.027078105886175763, 0.031826531849219464, 0.011392705273465253, 0.02089835164952092, 0.04523927404079586, 0.06077068086597137, 0.01796501481294399, 0.05561203834076878, 0.03512696646794211, 0.07016627787379548, 0.06394933647243306, 0.04160758922807872, 0.04704852617578581, 0.08712533934158273, 0.06740151802659966, 0.04315084821428172, 0.099500035867095, 0.09365955629618838, 0.022423131158575416, 0.07019108787062578, 0.023754670255584642, 0.025394439981027972, 0.06075242032238748, 0.010833665837708395, 0.02677939886780223, 0.048877641893341206, 0.05533886120247189, 0.04720610268122982, 0.04698600394476671, 0.06355956051265821, 0.010757245963759487, 0.03159874446282629, 0.07018782242084853, 0.11051869500079192, 0.04576466635626275, 0.02697547428397229, 0.04190504943835549, 0.10792189801577479, 0.06809690297814086, 0.058458022540435195, 0.049435592227382585, 0.019768489328271244, 0.07839291807613336, 0.016029519647418056, 0.09067949198652059, 0.031478301316383295, 0.04996961943106726, 0.1716583123197779, 0.03269516004365869, 0.01676405288890237, 0.03972623744630255, 0.03610880557971541, 0.08077041042270139, 0.022713980688422453, 0.05868264095624909, 0.058874237511190586, 0.02577459585154429, 0.022324828132695984, 0.02136019571480574, 0.04365187953226268, 0.035417491308180615, 0.08635802543722093, 0.04997687392460648, 0.01820730005420046, 0.051758377157966606, 0.045041113189654425, 0.038028775015845895, 0.016333902240148745, 0.035389835175010376, 0.042823976691579446, 0.07945401855977252, 0.012610688354470767, 0.014393607234524097, 0.05799275902973022, 0.050728450587484986, 0.06063677144993562, 0.03735452643013559, 0.06278797925915569, 0.02885890964535065, 0.03734523103048559, 0.02188595724874176, 0.00941022566621541, 0.05736350314691663, 0.02360451893764548, 0.06626901551499031, 0.02872090357413981, 0.08013622296857648, 0.025375470686412882, 0.1952081423951313, 0.12158639525296167, 0.11250442243181169, 0.22470140276709571, 0.11585112995817326, 0.12455023621441796, 0.12429681504727341, 0.1091112861467991, 0.14915229810867459, 0.13995833520311862, 0.17175545945065096, 0.07870429355534725, 0.3486596723087132, 0.0953239412046969, 0.15582517051370814, 0.2369145560078323, 0.23832873324863613, 0.18591887288494036, 0.09028731888975017, 0.11908629268873483, 0.13037334952969104, 0.2047337859403342, 0.07041414035484195, 0.10977474390529096, 0.18314509594347328, 0.13386795966653153, 0.2254108217312023, 0.14519868447678164, 0.1078581326873973, 0.08915576632716693, 0.29250530584249645, 0.2073807892156765, 0.11363170022377744, 0.11062339719501324, 0.15222532383631915, 0.15388568630442023, 0.17407725361408666, 0.12363286747131497, 0.1642529253149405, 0.10844806587556377, 0.11748653399990872, 0.10063427500426769, 0.13927790452726185, 0.1454268503584899, 0.15636521653505042, 0.21704399725422263, 0.11170125537319109, 0.22877251321915537, 0.2774335927097127, 0.17920984304510057, 0.13824827852658927, 0.14532406290527433, 0.1274942618329078, 0.08243818694609217, 0.13639227108797058, 0.18940803565783426, 0.13836964935762808, 0.1397557437303476, 0.165159250900615, 0.17325571097899228, 0.14697097765747458, 0.10562913666944951, 0.05663244315655902, 0.13165637443307787, 0.16473444557050243, 0.11618696662480943, 0.13795937527902424, 0.24759542662650347, 0.1362527918536216, 0.18812110705766827, 0.13119685143465176, 0.1812143690767698, 0.10619100925396197, 0.10646170019754209, 0.08346319678821601, 0.18925723124993965, 0.10145980297238566, 0.2313370193587616, 0.12279920556466095, 0.09106917888857424, 0.12357263476587832, 0.21594319929135963, 0.13501895649824291, 0.16897458757739514, 0.10442955885082483, 0.08270431368146092, 0.13628666347358376, 0.13626551226479933, 0.17543088644742966, 0.16111395234474912, 0.11091008884250186, 0.11492000179714523, 0.12745439365971833, 0.1999159116530791, 0.20439361513126642, 0.13274994387757033, 0.11469401782960631, 0.17649705579970032, 0.14144231885438785, 0.17971637367736548, 0.13301441562362015, 0.28613616479560733, 0.17957506875973195, 0.19202498195227236, 0.2195639003184624, 0.18591768544865772, 0.09029068081872538, 0.24746430397499353, 0.055168052203953266, 0.14189905137754977, 0.1565385822323151, 0.11265466280747205, 0.09106822151807137, 0.09374530403874815, 0.15400588454212993, 0.16728545946534723, 0.14138161117443815, 0.11336457901052199, 0.10234928922727704, 0.12412577227223665, 0.14025047421455383, 0.2347165223909542, 0.2459776189061813, 0.18457444268278778, 0.12132344490964897, 0.14580138260498643, 0.12782217236235738, 0.0898445832717698, 0.1688355833175592, 0.11032625610823743, 0.15061106358189136, 0.13064258586382493, 0.3188050305470824, 0.11490751145174727, 0.18294100533239543, 0.27021270361728966, 0.16566462378250435, 0.12308682489674538, 0.10957164035062306, 0.17054371041012928, 0.21851769473869354, 0.10575917578535154, 0.10518301685806364, 0.23271299083717167, 0.11325350918923505, 0.17885708541143686, 0.1310023048426956, 0.23013466590782627, 0.09482541092438623, 0.25407817563973367, 0.09556984441587701, 0.1719744227011688, 0.14332790829939768, 0.24879979871911928, 0.1485733487061225, 0.06307159099378623, 0.11522094268002547, 0.13795668870443478, 0.18252632289659232, 0.090403635695111, 0.10989409609464929, 0.24562916572904214, 0.14280729170423, 0.17186605429742485, 0.13338731514522806, 0.16050273436121643, 0.06973383584409021, 0.2068804480950348, 0.24171441094949841, 0.09061359669431113, 0.13317814824404195, 0.12985690380446613, 0.12210448854602873, 0.12669444928178564, 0.3170253010466695, 0.13780735374893993], [0.00949706251049065, 0.01078193814464612, 0.02575173584773438, 0.015620822632627096, 0.03075804514082847, 0.07087676553055644, 0.03144973234157078, 0.024102629904518835, 0.04669544941862114, 0.03164790432492737, 0.07934886365546845, 0.0273048394228681, 0.02652351377037121, 0.0927800519275479, 0.020946370459569152, 0.01298950650379993, 0.05355077140848152, 0.058896590999211185, 0.090625931188697, 0.027147825094289146, 0.04496708024817053, 0.037670388192054816, 0.11763839225750417, 0.03734051097126212, 0.05575358445639722, 0.10926018323516473, 0.021869720912945922, 0.014751576600247063, 0.02151686308934586, 0.03159310042974539, 0.06274343555560336, 0.04989983899577055, 0.039163682085927576, 0.06689430461847223, 0.006826110593465273, 0.06016271348926239, 0.05346265621483326, 0.035322025141795166, 0.04717571544460952, 0.03945801414374728, 0.06645913890679367, 0.08406426961300895, 0.02273656238685362, 0.09684311007731594, 0.015065529187268112, 0.01620815459318692, 0.07108299352694303, 0.020068890298716724, 0.00617679399510962, 0.04146295577811543, 0.08312672929605469, 0.037506662993109785, 0.025968966183427256, 0.011386117785150418, 0.06636866368353367, 0.04449804291652981, 0.02751281517703319, 0.021324967819964513, 0.01500869922892889, 0.03465275265625678, 0.07359885930782184, 0.0333858286467148, 0.05268091867037583, 0.05302608784404583, 0.05939232709351927, 0.052508417575154454, 0.013224674548837356, 0.014890393467794638, 0.08182985591702163, 0.034559449850348756, 0.024993205261125695, 0.04462624892767053, 0.04824759562325198, 0.03702293484820984, 0.01244979073817376, 0.05690786900231615, 0.05883962374355178, 0.05493665797985159, 0.0280404376462684, 0.0057908294274966465, 0.028277000928937923, 0.03443098037678283, 0.04856691950408276, 0.012368107181828236, 0.055942182734725066, 0.0601157689379761, 0.10794546862598509, 0.11765200324589387, 0.003656325970951002, 0.034228051226818934, 0.029322826158022508, 0.0706626039755065, 0.037711896511609666, 0.011993920961685944, 0.016421412583440542, 0.02424493486614665, 0.04820523754460737, 0.019197043038730044, 0.00897268879270996, 0.02302260836586356, 0.026732445039669983, 0.014920093290129444, 0.021461493306560442, 0.03939376641937997, 0.023014173857518472, 0.0922060600714758, 0.056801567479851656, 0.05405941716162488, 0.0360043891123496, 0.03989722084952518, 0.008180251334124478, 0.023630026553291827, 0.04580891691148281, 0.04134852031711489, 0.024603227066108957, 0.05968725286948029, 0.020175021127215587, 0.03280341341451276, 0.01861613622168079, 0.011247472539253067, 0.020722260414913762, 0.04792040868778713, 0.01816945237806067, 0.046426109183812514, 0.029338325912249275, 0.04362444604339544, 0.01998093466681894, 0.04541872905974742, 0.02194367963966215, 0.0574654927913798, 0.036584229092113674, 0.011012926042894833, 0.095530629332643, 0.036614226701203734, 0.10057351537398063, 0.025480009608145338, 0.06577649663086049, 0.026026137529697735, 0.015664358870708384, 0.13890384725527838, 0.008457210642518476, 0.05331107255187817, 0.012218681313242996, 0.02104679231706541, 0.013217873693065485, 0.05713991260563489, 0.03203622196451761, 0.07078071677824482, 0.0341841049521463, 0.06709144872729667, 0.05016837400035001, 0.025456982621108182, 0.039455635560443625, 0.08380603190744296, 0.03779384816880338, 0.04698713943071198, 0.034150051506003365, 0.04669474066758994, 0.00366621717603266, 0.02770932660496328, 0.009088082551897969, 0.08749648739467375, 0.06674311429378577, 0.0198407596690231, 0.029793755966238678, 0.023217826601467095, 0.03281121338659432, 0.03428676995099522, 0.015148009624681436, 0.04175820438831579, 0.06181632612424437, 0.06618374274694361, 0.03818028446403332, 0.06297652187640779, 0.06460158037953079, 0.03914649765647482, 0.00929584122786764, 0.02937558172561694, 0.030767320131417364, 0.08981368024251424, 0.014941051540517947, 0.026004726569226477, 0.015170236947597004, 0.04349260350863915, 0.033265407764702104, 0.07935850415378809, 0.04077850637258962, 0.015338734156102873, 0.047045765386428684, 0.04859067194047384, 0.03254072282288689, 0.012009904967271723, 0.0463758286787197, 0.05561242054682225, 0.06535102336783893, 0.01286512069782475, 0.022937771609576885, 0.06698574463371187, 0.020025890262331814, 0.05779618637461681, 0.02805973905196879, 0.05704761169909034, 0.041788517410168424, 0.0671151677670423, 0.024147405529220123, 0.08527513549779542, 0.05381294620747212, 0.05254869392956607, 0.038487069759867154, 0.07122306647943333, 0.07144090166548267, 0.09575663556461222, 0.039709283082629554, 0.028450043791963253, 0.0322584951936733, 0.014701454729220131, 0.06349721268634312, 0.01952979051566217, 0.02191385272453772, 0.01060791471900302, 0.015472680679522455, 0.04509438083914574, 0.05778769620519597, 0.010209452848357614, 0.0344604881684063, 0.046330873083206825, 0.03393674713151995, 0.019269205768068787, 0.06617480728891678, 0.002218437807641749, 0.08994571573566645, 0.06766522536054254, 0.01264222777535906, 0.06825412696343847, 0.06111870359745808, 0.05954159154498484, 0.033889108672156, 0.0733575425692834, 0.025590452314645518, 0.04932968404318672, 0.0368044577044202, 0.016229738102992997, 0.019732608343474567, 0.03295981361588929, 0.04204995377222076, 0.12159744583186693, 0.05519803497008979, 0.12244500074302778, 0.024398130844929256, 0.0382945789169753, 0.015061330486787483, 0.0347506159596378, 0.024973350955406204, 0.01989318127016304, 0.05531634815270081, 0.046214244575821795, 0.006942420905033941, 0.014972375738580013, 0.021200461414991878, 0.02600615334813483, 0.011190209352207603, 0.06057024533220101, 0.054024881319492124, 0.02350925686187111, 0.01364142015518155, 0.06889721276820637, 0.029842246040061582, 0.06266309806960635, 0.07896637558587827, 0.008254762033175211, 0.10460400808369741, 0.01712900400889339, 0.04106912027054932, 0.07796520352712832, 0.050938845743075944, 0.01569613021274563, 0.07479969135602005, 0.02397317894065054, 0.020875812624581158, 0.014968192808737513, 0.037097643144079484, 0.04921580519294366, 0.08558493020245805, 0.04091721377335489, 0.03596576403651852, 0.036019725594087504, 0.021337361686164513, 0.028028908382111695, 0.01274465435926686, 0.011986497629550286, 0.051807607524096966, 0.03879919480823446, 0.04507434285187628, 0.027854600157297682, 0.05499257138581015, 0.08633327481220476, 0.011316832733427873, 0.05493509575899225, 0.015894751195446588, 0.08313543468830176, 0.05633204033074435, 0.07578737117000856, 0.042056328820763156, 0.01711647284537321, 0.01673723352723755, 0.055698298165225424, 0.035128714225720614, 0.0303585136498441, 0.07640595125849359, 0.011547448630153667, 0.01448733306460781, 0.041793359923758544, 0.06839592912001535, 0.0558497742167674, 0.0632511536241509, 0.005913411350775277, 0.04221854003844783, 0.06386768538504839, 0.010251804433210054, 0.03703999682329595, 0.01721233049465809, 0.09302629652665928, 0.016179871345229913, 0.02468333263095701, 0.03749455856450368, 0.025011258003360126, 0.028733815088344272, 0.030674586923851166, 0.08407637404161505, 0.015922533493721858, 0.013557420170400292, 0.047350253735203296, 0.047408768368768506, 0.04166840823017992, 0.0573006766353501, 0.07109007361577824, 0.0036290133130023605, 0.014219738732208498, 0.05244968029728625, 0.015810075856279582, 0.055159706753329374, 0.015596929188177455, 0.03269028042268474, 0.026997965069313068, 0.02102083570207469, 0.003940494780181325, 0.03376634631422348, 0.027852156636072323, 0.05423863840405829, 0.07755137456115335, 0.02354559055675054, 0.013386454393184977, 0.15416954294778407, 0.10654617886757478, 0.13770000950898975, 0.18678347492823377, 0.1051706304133404, 0.1163479384558741, 0.10454132629092783, 0.17347523826174438, 0.11696985078742728, 0.1550649292767048, 0.1868696085875854, 0.14625554729718715, 0.15092135552549735, 0.24799995648209006, 0.09564918742398731, 0.12239541043527424, 0.15350591449532658, 0.25534131098538637, 0.16772015020251274, 0.118525607540505, 0.14447998866671696, 0.21414165064925328, 0.22612792934523895, 0.10883201597607695, 0.19409527711104602, 0.20859170705080032, 0.10110457398695871, 0.1582171570044011, 0.06929740848136134, 0.13183932867832482, 0.11929182306630537, 0.19636706536402926, 0.12418373400578275, 0.2503616188187152, 0.1258463377598673, 0.1887600071495399, 0.12062545501976274, 0.14183942723320797, 0.1282138333772309, 0.233427471248433, 0.15107805258594453, 0.1775708989589475, 0.11247593880398199, 0.1710663308040239, 0.10686956229619682, 0.17059546778909862, 0.19513741572154686, 0.0882047189224977, 0.15043478866573423, 0.14498708333121613, 0.33279273309744895, 0.17966050480026752, 0.17462087678723037, 0.09933566499967128, 0.10924876158242114, 0.1627510559046641, 0.09655101559474133, 0.15164845244726166, 0.11043781574699096, 0.14030208316398785, 0.1789035290130414, 0.1504441545694135, 0.14897057582857087, 0.17207130265887827, 0.13137536763679236, 0.1288377124001272, 0.0803226578864269, 0.07460291089955717, 0.11859818216180429, 0.2574678906239569, 0.2541520935483277, 0.2114996494492516, 0.09490391530562192, 0.08684793938300572, 0.07119120607967488, 0.131237966415938, 0.14596630266169086, 0.09073429959244095, 0.10502863529836759, 0.12458335084374994, 0.13258270832011476, 0.18928292440250516, 0.09809760682401247, 0.10322753194486722, 0.24316375114722177, 0.22514652810059488, 0.15683222038205713, 0.16400645807152614, 0.09978048605262302, 0.12949938158271834, 0.1462031071423553, 0.19631961244158447, 0.14862985583022237, 0.04638185120711569, 0.15781694644829258, 0.10951240954454988, 0.1529227348510176, 0.12488313397625461, 0.12552470579976216, 0.07863330713007599, 0.1902979300939478, 0.05932442429184448, 0.09423417155630887, 0.14706108922837302, 0.09837004181463271, 0.24923806660808623, 0.15893282485194504, 0.15088657848536968, 0.14308577519841492, 0.1959132865886204, 0.07698246641666628, 0.12926438794238493, 0.22995209757937118, 0.12545417208457366, 0.1443451998056844, 0.1531560067087412, 0.11307739012409002, 0.12073482532287017, 0.09493308170931414, 0.15378632757347077, 0.1165016446611844, 0.20878199371509254, 0.1336338120745495, 0.2174748436664231, 0.11110050167189911, 0.3017180599272251, 0.11697425914462656, 0.0929884915240109, 0.09489526928518899, 0.1190391811542213, 0.14089571224758402, 0.08241245668614283, 0.18014478584518656, 0.1082584768300876, 0.1854144351091236, 0.1448426317074336, 0.18591306929010898, 0.10021200039773248, 0.11601257676375099, 0.12063450922141783, 0.16405696864239872, 0.15066719963215292, 0.09431790065718815, 0.12280702037969604, 0.10689342976547778, 0.19255546911153942, 0.07048559433314949, 0.1498818738036789, 0.13958013674709946, 0.13503221125574782, 0.20694378297775984, 0.17369708104524761, 0.16965653223451227, 0.18441204592818394, 0.14297808957053348, 0.11361500932252966, 0.11028554930817336, 0.14734736527316272, 0.1255544659215957, 0.12909857730846852, 0.1379822927992791, 0.21342062449548393, 0.1493484477396123, 0.0746132415952161, 0.1525036885868758, 0.05896999311516993, 0.12302890027058311, 0.11191197336302139, 0.07831494804122485, 0.11427106044720858, 0.12849945633206517, 0.1375591498799622, 0.15636999596608803, 0.18045859556877986, 0.15636252996046096, 0.15868953400058672], [0.01972260604816256, 0.07794571472913958, 0.050352482285234146, 0.019423117919359356, 0.05335913403541781, 0.0008152933457949985, 0.04709679174993653, 0.044836536471848376, 0.04718761207186617, 0.07649790335563011, 0.06853543061879463, 0.029102742264512926, 0.030239619736676104, 0.07014298185822554, 0.02765171924693277, 0.036563838584697805, 0.01023545863063191, 0.043620783544611186, 0.07265142616233788, 0.03449499432463199, 0.03858348216454033, 0.01587976723385509, 0.014443353393289726, 0.019950361893279478, 0.004957043211106793, 0.03533699797117151, 0.061878243504907005, 0.044139622696093284, 0.03769187336729374, 0.06058938161004335, 0.1232437371800188, 0.04109931083803531, 0.04003480760729872, 0.05076414417999331, 0.032947597865131684, 0.047133865737123415, 0.001869983934739139, 0.039805209380574524, 0.030859910475555807, 0.03286275183199905, 0.07351206513703801, 0.026046969614981208, 0.05103877963847481, 0.02960799083666643, 0.02484573495166842, 0.01930009209900163, 0.018089864461217076, 0.02245681724161841, 0.026726103387773037, 0.017968860993278213, 0.03348384037963115, 0.07434820581693202, 0.024617515264253598, 0.026464834008947946, 0.0744804491114337, 0.011795461396104656, 0.06136546398920473, 0.024963081486930605, 0.043879433142137714, 0.018813825809047557, 0.06404829444363713, 0.03262132377130911, 0.048849870727281086, 0.03415168794163037, 0.030208798343664967, 0.02364205491176108, 0.01040239547364763, 0.02722845758398762, 0.03337436617584899, 0.043451447709230706, 0.03424539892876055, 0.04622312437277287, 0.0623203965369612, 0.055060797021724284, 0.030520194231939968, 0.12315592626691796, 0.05797090278065298, 0.03923195967217907, 0.02305468213307904, 0.04844088798563462, 0.01642254621401662, 0.008267437915492337, 0.06554662380949594, 0.1122697108075954, 0.010654903799149906, 0.039780239821993746, 0.056162103355745785, 0.01756487661623396, 0.05064594231953379, 0.018936808955913875, 0.02527085383917438, 0.03848619031487033, 0.11510663709486835, 0.026715657659224235, 0.08429725203313865, 0.033767941931728274, 0.049716265057213604, 0.04198035516310483, 0.024645731718919706, 0.014736061075382167, 0.013197653879615245, 0.029229239480628166, 0.05932316264079418, 0.09778884370462038, 0.023318361636484042, 0.030604719286202453, 0.03113908416708, 0.051465503420331515, 0.0656061885820236, 0.06262982758926228, 0.03186297130014282, 0.04256697095115669, 0.019193048428860493, 0.042813326872419566, 0.1746901191654615, 0.03326063204440288, 0.01343933334283065, 0.04379306570626795, 0.05109815887408331, 0.06686421795166098, 0.02213470288552344, 0.010333174432162195, 0.025256496992369648, 0.05692474544048309, 0.0438335127546452, 0.0801873421005439, 0.038728794679627754, 0.010823161665030057, 0.033401614127797075, 0.08597261330578476, 0.024900661301217042, 0.031388653587782755, 0.010189086460741237, 0.034840697844629176, 0.055590909396414645, 0.033322605086141266, 0.028398911672411487, 0.01703207024547737, 0.009778959883988136, 0.017425280493625905, 0.023250542326422874, 0.07868703120038845, 0.010389516428404022, 0.029667527778656222, 0.07790134914102964, 0.025151659356197342, 0.01994146910874406, 0.022342457850754727, 0.010318392705812585, 0.028793851124646608, 0.05849258435773663, 0.05791252544440795, 0.041056629925151356, 0.02052196032309439, 0.026280313832103275, 0.0681460702617187, 0.026745404793473426, 0.049693406908772886, 0.021606169430015143, 0.0315952007076703, 0.06561826332472265, 0.03595048692659475, 0.050782742400770076, 0.028669713938143104, 0.07946770376292989, 0.017415537950000726, 0.04567726362438407, 0.032995373621815816, 0.004352221149019897, 0.027912094337807503, 0.02927240278950194, 0.010409267761133378, 0.06807095749536529, 0.036416949005797505, 0.051878297090297565, 0.03444545596721582, 0.02586626222182531, 0.08104523512884043, 0.025368728274770547, 0.03868676314596087, 0.0767303588509094, 0.017255347229365725, 0.059151982568437234, 0.03251018715673126, 0.04259750661731232, 0.03667251869046595, 0.05820348444103729, 0.056044580560410395, 0.025590027435100637, 0.023413831513607875, 0.04735405353130773, 0.023464028527087066, 0.012440892387530766, 0.01595296896994114, 0.018042593364953063, 0.04415723014972173, 0.0837522855727002, 0.05535614582186099, 0.09474960053921677, 0.017719632960506715, 0.05149638789589517, 0.029813662222295534, 0.04901505795714911, 0.03814758172666188, 0.025854105842881836, 0.10107764886924997, 0.05405191404861398, 0.009849111393123167, 0.050768418950610794, 0.03380827765795402, 0.0385350199212553, 0.03681462141685188, 0.01020906414851197, 0.050735070544760674, 0.025041539483936504, 0.07519104809034616, 0.013545646925194887, 0.02660415553691564, 0.03067318055400392, 0.034024966225842945, 0.029142209677957, 0.0444284183322452, 0.03178100479999557, 0.06736484108841978, 0.11746879667043686, 0.010630142969603185, 0.02423080808512168, 0.018826629711838905, 0.03517261597153265, 0.010780365719256224, 0.049376387396478094, 0.01746034326060908, 0.017761746130418032, 0.06647999325650744, 0.08957646758062765, 0.013117244961904362, 0.03426292103540618, 0.022345554461935535, 0.0020223454612278147, 0.012894514384242939, 0.007192544617282692, 0.030394075511139818, 0.07328512379899621, 0.022108339944679756, 0.033155469718622044, 0.0667642655025702, 0.03917711495887488, 0.02636159013491124, 0.056603896446176805, 0.024696730251889676, 0.021136586619832087, 0.022295919625321403, 0.08449809945886955, 0.03561320307198912, 0.01224318702952587, 0.04501127143157646, 0.035402102876105346, 0.05944373566308059, 0.04216899054881651, 0.01089830782802892, 0.0348442341783084, 0.01591713065863587, 0.06328759307507426, 0.020475089986575767, 0.032330457543139346, 0.018694371574383695, 0.055471494124503806, 0.056640584516571835, 0.044892260630149394, 0.02599740899313474, 0.040621720254421234, 0.020986516938137356, 0.07154147751862183, 0.0058191131392959505, 0.016024413671402726, 0.06153524140245281, 0.04347291433077771, 0.06278006054344587, 0.08311966405017301, 0.07091209175996482, 0.027475615024741273, 0.04583931528031826, 0.05465052294312045, 0.06151537410914898, 0.03974956685851794, 0.07805236135027371, 0.0055789291036489885, 0.03567851577827241, 0.017680258315522224, 0.021042066691734362, 0.056959106877911836, 0.05172406024939846, 0.030704916644026525, 0.03151956101646647, 0.03189686147379689, 0.02366793545661494, 0.022150193362904247, 0.02906311900005676, 0.053661893180105835, 0.09403086762176827, 0.022872471890877932, 0.043405980031820945, 0.03252886701375246, 0.013960122487333138, 0.050011157436529174, 0.03442310247919522, 0.01687714506260818, 0.023497629263147246, 0.03320979492855258, 0.005818632134833024, 0.028335287352092564, 0.01974046026589349, 0.004933948966936441, 0.08439783530775458, 0.09135611544479616, 0.06868848373414949, 0.03695048639201559, 0.08929683375754394, 0.04728229898319114, 0.059533001185627654, 0.028075877053197473, 0.04387141794722993, 0.017450322411605157, 0.08514482178725302, 0.007345426574829617, 0.0517853802011814, 0.038721532764611766, 0.06195383866725024, 0.03652067156508565, 0.05318672199791763, 0.003183046801495948, 0.0882509769871831, 0.09992310457164422, 0.044699502614093944, 0.0463969650445506, 0.027806225116364658, 0.01747725866152905, 0.0061841533170081675, 0.010639247266226448, 0.043660017181537114, 0.06437253134208731, 0.041149891912937164, 0.01896843186841579, 0.010956563637591898, 0.034986162499990314, 0.0282787987816846, 0.012369722280709539, 0.04032018194266129, 0.04102547827642411, 0.05962050781818107, 0.022318928058666643, 0.02925974731624592, 0.09853243856923655, 0.13304361171321943, 0.08091927040368319, 0.11848783222376369, 0.18960437824716792, 0.04262223868863657, 0.175820202275645, 0.125838530366309, 0.16329837497323751, 0.2005551234469749, 0.16055404645157978, 0.09928967410814948, 0.11189199474756606, 0.12100395775632933, 0.09706092299893498, 0.12924672482768074, 0.13620710524264723, 0.09052946683368646, 0.17597016063518822, 0.14785082341404632, 0.2020930463913828, 0.10541342402575538, 0.16407911432906985, 0.06794405766413547, 0.14189882873324677, 0.11865962456795387, 0.08164224840584211, 0.14920834510121495, 0.10583218085230328, 0.19458884984487668, 0.191971413732972, 0.20493027695920318, 0.14628922595875338, 0.14301191666163504, 0.05834571333252825, 0.15882904292084277, 0.08019229222554713, 0.11853368210722692, 0.15677909745136276, 0.19050819537369534, 0.12913345824927092, 0.12928602896863595, 0.10362742337747477, 0.10688425682019442, 0.20552331232465804, 0.10693426273064688, 0.09999708927352913, 0.16311785497236997, 0.11706943216267973, 0.13621476420667022, 0.12155620468547568, 0.15209093573503196, 0.14460569364018738, 0.0784717193164397, 0.1409178282483481, 0.193002360756509, 0.11400067378417589, 0.1568109355866909, 0.19829111290164292, 0.11968311300734058, 0.17222984024556354, 0.08773375942837447, 0.09178125474136323, 0.13762511196546257, 0.15367220010375604, 0.07893944304669276, 0.19293794233817607, 0.10678072721930221, 0.11857411431265064, 0.17540428787469864, 0.22510839655296877, 0.09966120807803236, 0.0966390417306684, 0.18780606536893174, 0.1202684745658189, 0.19310688483528793, 0.16811188543215394, 0.07812804557033814, 0.15533838100964203, 0.11235433790716343, 0.14127453410765156, 0.16747236193623394, 0.15160815382841974, 0.24601969867944717, 0.09929239779012278, 0.11034628667403013, 0.14957683626562357, 0.07041183969704434, 0.14472773240413517, 0.14726146910106763, 0.10394203462055884, 0.2577558142365888, 0.19973769231000915, 0.12088511022739112, 0.1423525481368415, 0.1431630179286003, 0.09800877174711786, 0.09316871466580778, 0.07819826016202569, 0.1983574905898422, 0.13152102153981104, 0.1358918854384683, 0.16435676661785692, 0.16390718839829788, 0.21903292334172875, 0.11914190181414597, 0.14538177230861038, 0.16106994298752397, 0.1471519874758087, 0.20647716504754499, 0.11478183616418391, 0.13852429809048772, 0.0877983782265801, 0.15611015522154048, 0.22021701995981857, 0.13130067789461464, 0.13928097701864317, 0.149841129896231, 0.18157457787310705, 0.12597317079780623, 0.07653900349396281, 0.23407076485455036, 0.13754326791968197, 0.14388147625140846, 0.11436540968134068, 0.1521690541994758, 0.1217746632755734, 0.13743780873483047, 0.1050875915098004, 0.13051800895482302, 0.18370063800830394, 0.1259829374612309, 0.08951433497713879, 0.1492113879066892, 0.17615923017729074, 0.1814189791912213, 0.10911247358308174, 0.1862717789481394, 0.24106362165184692, 0.12189031214802526, 0.2848140138667077, 0.2909757394809276, 0.11924527556402609, 0.18190109316492453, 0.1695809667580761, 0.25794075743760914, 0.1431188007700257, 0.12066741604940034, 0.20944924384821206, 0.09401772418641485, 0.12974429031601176, 0.11090061903814785, 0.13326472719199955, 0.17090892128180712, 0.0973875644558575, 0.2649441082030535, 0.21000796230509877, 0.11973676286288537, 0.11819540377473459, 0.11707128753187135, 0.1027079691994004, 0.11988395301159471, 0.09036440576892346, 0.12411138202878647, 0.1792090415256098, 0.10871577338548377, 0.14496401738142595, 0.11521719483425841, 0.1702603732701391, 0.14693728415295482, 0.12007951634586789, 0.20836425363086164, 0.20594223984517157, 0.14054627943551168, 0.09398063906701282, 0.15188654826488346], [0.026178671141678933, 0.09496595142991282, 0.013312958581082057, 0.04429319902556017, 0.06904526380822062, 0.030246766618802212, 0.03742245891771745, 0.056073246014420874, 0.01271437566174427, 0.015203049151750747, 0.023234088912431616, 0.03313491222797893, 0.05658671201672405, 0.010950809210044099, 0.03824643950792961, 0.04636337544070557, 0.041378981768502854, 0.04090207025001291, 0.029323824346647598, 0.02588159499282483, 0.04126799358346034, 0.019575710903154686, 0.01571813118061982, 0.07619121082825586, 0.050261305732419714, 0.04935974102409091, 0.02979424021759769, 0.023387598448607605, 0.02350074442801997, 0.029758750715700444, 0.021249428318697028, 0.03379905647307169, 0.026389255544927437, 0.03347978083183989, 0.038150602267705835, 0.034472859770176, 0.0301496102110832, 0.02226011285529239, 0.031004673801362514, 0.07477612074580975, 0.07102600400685333, 0.015960104719852097, 0.020094078790862113, 0.003931514329451602, 0.04507182697125245, 0.03454358273302205, 0.1840586945763789, 0.02949193563836161, 0.008628535433672369, 0.040790265702526085, 0.019487061363179237, 0.10805093523231335, 0.05282280617393553, 0.041799441823968664, 0.07999292167369276, 0.04501314906519838, 0.04047230366268195, 0.04631937721569557, 0.028519876177597325, 0.06976117656449787, 0.03580787582905032, 0.005318558187354938, 0.0335785755305551, 0.027132032191730104, 0.04310607815568801, 0.09233091899659485, 0.08865723604685627, 0.050992725664400496, 0.057754466542974114, 0.023129887667892035, 0.031086772032722365, 0.06161686280393042, 0.025878418600768782, 0.023857036539993715, 0.032030685542849824, 0.04356859943072777, 0.02314890891284449, 0.07328600695473142, 0.05756520033173729, 0.035274345864309, 0.030764472139708232, 0.010752748548839008, 0.02870295473258011, 0.04261871719791088, 0.02092119124426972, 0.04683267994550988, 0.08658970167743973, 0.058508009897195734, 0.040222927200375125, 0.0329320350283524, 0.019086086394963786, 0.02946291209809715, 0.08385160719626583, 0.001063117733792751, 0.027248165315540973, 0.04504122451180592, 0.03514271113090217, 0.04049314316944219, 0.06626670743571594, 0.0027885860345122637, 0.05512201307283249, 0.011615820840233937, 0.005014855587432976, 0.017250007476832252, 0.04540138877928257, 0.05666589546308387, 0.025683322819531895, 0.06328181916614994, 0.017791402351576835, 0.03191182688169647, 0.03792310431890655, 0.021190672487136908, 0.03421112283831462, 0.04585782815411221, 0.051814387043123133, 0.09123023977736011, 0.01126756989833666, 0.032787386735435575, 0.04230364582326729, 0.047344513222924434, 0.020711556790047325, 0.03182862841640599, 0.01975095052330289, 0.07473994104657322, 0.034228626391268335, 0.04866683484578971, 0.02359281526878476, 0.05472446311614476, 0.033550960215507075, 0.06391568007529713, 0.022521959253936075, 0.041026276085176505, 0.08442496080533601, 0.022828898545412812, 0.049132517669931985, 0.1243766478728503, 0.0619904970517382, 0.028796396691177506, 0.04858918393438216, 0.09544576474581845, 0.010506903781788424, 0.05898579714994412, 0.08807351463474333, 0.03496187571727205, 0.03187866401276551, 0.03548528278770391, 0.04617318154487293, 0.04160886943282094, 0.06567592077772133, 0.06569891251274385, 0.003395774620003067, 0.015565922258247156, 0.049821486754808575, 0.010390838378953049, 0.05169927251699846, 0.08720088997506537, 0.07760730281006545, 0.011662218057608698, 0.03572365691070445, 0.037266303625074215, 0.09101676841964945, 0.041324289195472375, 0.03600664895202499, 0.025148577587970067, 0.04788470396306366, 0.041427306714467704, 0.03158495164825581, 0.014583461597794667, 0.06220772738743108, 0.026264318694302347, 0.023086167748260777, 0.007397042481898097, 0.08070154653978534, 0.013765981293545337, 0.029769285501970444, 0.05181579341297038, 0.02445959922624752, 0.027909558048122562, 0.011678032296913443, 0.0554481238941662, 0.03262620339228306, 0.015424330686073517, 0.05551931812078692, 0.0298983023094479, 0.02022775443037972, 0.07258341574924998, 0.0030580575366911944, 0.03288349857029971, 0.05406836004112847, 0.0702090775303077, 0.045553002128144726, 0.05759253734140657, 0.07042512414045632, 0.10803716097143479, 0.08387137058889493, 0.0663402616919484, 0.011793830526585225, 0.007051609845802886, 0.004394603347463999, 0.043775877566076815, 0.036365250998642296, 0.027773238507506903, 0.04910463889245875, 0.022563031561730895, 0.04257596949173603, 0.0197106686027837, 0.003927336501874379, 0.034410207663313486, 0.01596712914761156, 0.04153521869739052, 0.021776484900328796, 0.04589214135194197, 0.03725389491592068, 0.016520671124453656, 0.06099800441006664, 0.05244212894467637, 0.03989528755482752, 0.04933606651320588, 0.029630886092490982, 0.06599133354029618, 0.019414382841205224, 0.018281429474882316, 0.04695381328929216, 0.045150053047109395, 0.016791046655271202, 0.008742708359932294, 0.032166776873054914, 0.1465088571421802, 0.005374800457502715, 0.019735226269403938, 0.05048075137892738, 0.05256327713141218, 0.03572798734239768, 0.06365601744619198, 0.050195469812024385, 0.017778503824956715, 0.039722389410599135, 0.01259023569218698, 0.008840584650897654, 0.010374380326538812, 0.009799806812225142, 0.07733748760074377, 0.038571533586946316, 0.046313269340316765, 0.07377234374871477, 0.02559090316935908, 0.05209604692936409, 0.06009541924868245, 0.06527427045512013, 0.021712060915888287, 0.0546170483721653, 0.05852501250046771, 0.0660503565450199, 0.04490793107834179, 0.02376396194449626, 0.010848840902326629, 0.015666486979171168, 0.008273686798929702, 0.07618099145474844, 0.01235347945112153, 0.0443162538431352, 0.07074441091390327, 0.024695893480384257, 0.013907682332501281, 0.06412482471205294, 0.055482622628915124, 0.023472481589124072, 0.04101878410438076, 0.021539212866628077, 0.06040229731297586, 0.02787578290735837, 0.04885395996097941, 0.01887794551294064, 0.044058019848307595, 0.049809909251052886, 0.043458687359816395, 0.046024321563891135, 0.034758668261929415, 0.00810211617135792, 0.033012116473400965, 0.01750471070408821, 0.0483914275537245, 0.037528834654949605, 0.033950350698432885, 0.03852710120554548, 0.06689906178507954, 0.017378621669195127, 0.014890925031068036, 0.03796499484451488, 0.00647987736556388, 0.043094749271404, 0.02174617002310697, 0.030773357502766885, 0.03707616539031733, 0.0351007204153575, 0.04706480889581144, 0.03684463386889547, 0.0236155361199053, 0.0380210715229623, 0.06009181612171233, 0.057740295233088546, 0.013394920442806324, 0.07356536618317477, 0.01860883719928097, 0.023704578998149373, 0.023041572094371077, 0.05509408605576027, 0.026074657289427705, 0.057846492854878306, 0.06329128897050396, 0.08424294908763841, 0.0334670752636157, 0.033266773316427134, 0.04010420583654195, 0.05338529474101961, 0.017647934073465876, 0.02954591574962251, 0.05118330547702499, 0.025673396594356745, 0.05973227154754568, 0.030078349191171583, 0.07866164974984713, 0.0646769825834781, 0.021064525935798883, 0.05806098837638274, 0.01692251997155836, 0.036378928780322894, 0.03784355350944679, 0.055196038592839614, 0.0504664501931984, 0.005175875658096629, 0.048071298442664556, 0.02355071879719617, 0.025888305863190908, 0.016664918657625094, 0.012184868137410376, 0.09561855156789534, 0.02985848052048823, 0.021818976565555204, 0.04033210083434824, 0.008171355766535271, 0.049931402536458336, 0.008934051656979136, 0.03221789600502234, 0.06495150300906971, 0.010998781635862542, 0.036106356492382474, 0.02848808257112978, 0.050131826938013546, 0.008869823413988343, 0.006759999150744989, 0.038986646468401887, 0.19501806353218853, 0.11330895504215732, 0.07851796253817156, 0.17974488699110225, 0.14736945158801973, 0.14137331396341324, 0.16069907695055008, 0.14510989392874762, 0.12897171458462253, 0.14389667543582618, 0.08296454776427709, 0.11475164559669793, 0.14493511815089732, 0.155362471123226, 0.10778053372632712, 0.17750916711520404, 0.15577170619508252, 0.130965301359538, 0.19419402728090063, 0.19451398198725656, 0.07123595758457668, 0.10523990247747861, 0.10023773065768182, 0.11205059912754223, 0.15897062985459343, 0.1100090696127154, 0.1348674693144858, 0.10805981874000281, 0.130439801432658, 0.09136792301433161, 0.1017332547053229, 0.07680885581066832, 0.15522774163400754, 0.12179046359960921, 0.08921452215872705, 0.10557936082477681, 0.11306257685646415, 0.1334616041276604, 0.1331623998703435, 0.15014769625850022, 0.1251870286068879, 0.09592663191142492, 0.14219506439985707, 0.1614132011309266, 0.07740179469692521, 0.09130169375566766, 0.2865631371969357, 0.1689282330335118, 0.09438559936825186, 0.11313222741591744, 0.3295002394588664, 0.19596721103880554, 0.11369231142452918, 0.08594837476266548, 0.13215365790529177, 0.14163829036988318, 0.15955854440107942, 0.18359770212555304, 0.13048547320067883, 0.17842702567577362, 0.13675320718903095, 0.14795457565924153, 0.08218996823416092, 0.08145909378072247, 0.15360215620603412, 0.24430049874354154, 0.27410719776526093, 0.1459739319398068, 0.14147886220598593, 0.1219448154733982, 0.10608310098177753, 0.15711576532339677, 0.12353947560768574, 0.09327096777269617, 0.1859255670569837, 0.19404436578042805, 0.1865732838632539, 0.13101616816129535, 0.17774119216483086, 0.09655992136686109, 0.12035231498884968, 0.11921295503270812, 0.1544113049749285, 0.15375995164504275, 0.13509888580301777, 0.11574988617212512, 0.21225352305918932, 0.10970602103043348, 0.23119849007343873, 0.15812379482667893, 0.12944706017151475, 0.13835195655701682, 0.18334574298933148, 0.09544585380353965, 0.1425010073580779, 0.11571045586606488, 0.15218869142699987, 0.09756389132235199, 0.12042281159665436, 0.09878488752292469, 0.1315025717485696, 0.16676139930495992, 0.10005909571191296, 0.09679130074800923, 0.17595623794477433, 0.16890969418454915, 0.1441357212024741, 0.1496858726022765, 0.13910010078689083, 0.17455041728680953, 0.096569457964506, 0.0753627587982919, 0.18392522673821077, 0.1500811701407656, 0.22223800682695583, 0.18406353337923065, 0.06715059047564864, 0.1629641858744435, 0.11072307504946366, 0.11349623600835912, 0.15805286035174504, 0.13910446461522952, 0.08465734208584763, 0.1948929374339059, 0.11401441093767062, 0.11024355859262869, 0.1483715884387493, 0.14604473282815889, 0.08748914755415171, 0.08772445289650932, 0.14191815425874665, 0.15233246027491987, 0.16747424699133262, 0.12231918444740586, 0.14316042041173205, 0.20895046123769134, 0.17362409824272618, 0.12718217389192432, 0.11515227175550535, 0.210267209331505, 0.07390227896394208, 0.12625218863831833, 0.18425331538310274, 0.12898700282676145, 0.10272905361489393, 0.19263579917605966, 0.18746589455986395, 0.12419265462085605, 0.13738195470068604, 0.2210985726560466, 0.12799892225302756, 0.10961528605548665, 0.1149348373292014, 0.1615445761126466, 0.18785052001476288, 0.1858151503256522, 0.12901216163299978, 0.08598824293585494, 0.1866990333655849, 0.14761401893338189, 0.20708146621473134, 0.1382499112514779, 0.08306631105369888, 0.1573367472155951, 0.09781547196325846, 0.1639380320557393, 0.107016344263684, 0.17295291472692043, 0.21525356598431244, 0.1302159993792884, 0.11969898012466729, 0.10810491163283587, 0.12494174879975617, 0.0731997619732283, 0.06617456980166025, 0.18028096994385123], [0.06648730341112241, 0.015584980610583443, 0.038892223019502126, 0.018760784514597617, 0.03152697507175617, 0.02813096853060415, 0.01048317268214305, 0.02825853443937376, 0.05467898430651985, 0.043020831362809986, 0.024627836683066562, 0.05606937200354878, 0.011619701344898203, 0.035057761197094806, 0.06542407296365127, 0.008442627440672368, 0.09800361382076517, 0.010990304454026045, 0.059513527230592445, 0.033512939990032464, 0.03836390664218925, 0.0320328600355424, 0.12735873082419857, 0.08720283440197818, 0.07713348604738712, 0.04143321420997381, 0.01638363170059165, 0.0579990932601504, 0.05927939077082556, 0.039883520803414285, 0.04353430849732831, 0.02835188734024996, 0.03195789198798593, 0.06076287347241305, 0.03409463904972654, 0.032168038524105214, 0.04349671129602939, 0.021025294154242147, 0.04541502203210257, 0.04549099197902251, 0.029899051878601313, 0.025519233968225308, 0.04068342241225764, 0.01417254648913513, 0.004555739842544426, 0.06507679980131797, 0.012792807683581486, 0.015284567580238217, 0.042079094200744294, 0.01981988491024822, 0.036920562997693196, 0.04680747661041096, 0.016002627926354762, 0.04120525612961501, 0.08086572444881313, 0.0677795235242229, 0.0198581556105637, 0.07158965774578974, 0.03228795474569779, 0.06264703799388371, 0.055442561497329734, 0.04751125154143665, 0.037244614359224215, 0.017196296394104138, 0.02304259625816485, 0.028600794394151308, 0.04120447687455453, 0.038426365790655836, 0.010483563237357885, 0.08488447638228536, 0.013835105855832808, 0.020178796803520527, 0.008053396031755256, 0.058242988961865194, 0.06331721961032599, 0.06415429539629258, 0.010682256579457317, 0.03335592009534594, 0.02928698970208643, 0.06028328280081041, 0.029363139619817957, 0.03951419472286943, 0.02305867674294859, 0.044226943791727535, 0.04626069559890311, 0.03465268586296588, 0.02698667700315127, 0.05324415680661332, 0.053885108936810866, 0.08261717070126906, 0.034726477606454864, 0.0284223023118102, 0.053246012175804935, 0.023498671980632935, 0.04344121720350813, 0.08234455759520642, 0.05813698058773298, 0.03531567606842145, 0.05655914494127501, 0.023879887266957667, 0.05802117215353064, 0.030718729867658112, 0.03238019628042821, 0.07000761412200518, 0.03839062024781015, 0.05465255642775446, 0.04831678976188414, 0.07960146846016869, 0.06478235271060839, 0.06399074089131318, 0.011257377427682513, 0.02060938160866499, 0.05287461550324224, 0.007856469001126243, 0.013537100167013705, 0.0434541045979131, 0.05250606496701948, 0.04936888799420558, 0.028438889312383253, 0.016466319939354435, 0.061125160282244906, 0.04905154193693306, 0.015734176413388923, 0.07668354417546652, 0.07224831380881369, 0.04672553237469401, 0.12151469636592083, 0.038923411775613204, 0.029452855997078586, 0.012199172106193146, 0.061192465655039996, 0.06542219533002935, 0.06272376864217222, 0.01009296256597736, 0.02596544654807076, 0.015881834115134552, 0.020048961778229568, 0.012727754728985019, 0.08831693907268345, 0.04118094337172806, 0.010213962323177839, 0.09895978946588002, 0.0727646704763174, 0.03289346561359707, 0.02509595189621905, 0.022240000653255265, 0.050799819218809716, 0.00965368813922396, 0.013815048387186835, 0.023924918932607397, 0.010471533023519441, 0.02040688290435355, 0.06335315440082923, 0.03241687321860809, 0.046614633247372694, 0.020926473480358254, 0.06815778135205619, 0.04517425819358323, 0.022100834976299666, 0.020354739608592354, 0.09235756209818646, 0.04181930540653411, 0.04174148751189932, 0.09179305488942191, 0.009781104690773645, 0.050127270151278935, 0.07104725911631249, 0.022813354262325447, 0.06251711762160994, 0.11996005283435807, 0.020369903540995438, 0.03935109663871117, 0.024943043499661144, 0.10095179546624422, 0.05237676428805571, 0.01285574551729951, 0.0351057447551284, 0.04030591786431614, 0.06066921443562023, 0.043026968924095854, 0.05514417731319554, 0.05659798152919393, 0.01326496481851791, 0.014965971931815147, 0.07276629577972926, 0.0644054455915466, 0.03862028526782524, 0.09524427165160887, 0.013156286568118958, 0.027440030899015255, 0.05214705102844164, 0.03374862753844354, 0.05897951858059969, 0.024450068194710184, 0.06396389740984887, 0.037404665927169845, 0.04073000331118237, 0.043763999492512085, 0.07228464935906231, 0.017966831219382584, 0.05883080702915322, 0.013552476539189229, 0.02504113315808354, 0.08575153493438847, 0.07131563455914147, 0.024003762846405152, 0.039687100288574584, 0.0316590959118912, 0.03951114078518003, 0.012525106667453656, 0.005407444750744617, 0.014610943326260895, 0.07910057072876953, 0.04320045707572717, 0.08002772097825073, 0.03266050545789767, 0.04562604801321868, 0.048588096688035876, 0.05883940109924879, 0.01638833691686159, 0.02005891212320421, 0.05405639290984254, 0.08312449543154798, 0.03266677289502695, 0.020566526291077025, 0.04622465690772515, 0.031319993795477785, 0.028821173291362356, 0.022677172019029967, 0.04644868902687449, 0.021012362230976578, 0.07984604322700761, 0.025194705776812043, 0.02534427821956342, 0.04195719273411669, 0.015510368793911766, 0.04690236019087024, 0.013478844357450726, 0.10039683969807811, 0.007706817705184221, 0.04835621264646761, 0.052695876656798646, 0.07031678542261943, 0.04109350724320393, 0.003699463304656092, 0.010450024656165624, 0.04997335243388079, 0.026142958995478693, 0.04628976923413575, 0.03578915886464529, 0.06703019185806625, 0.021934220967523288, 0.044967358553549275, 0.040241046735900454, 0.019783399075095076, 0.09051789675140753, 0.01336199784418568, 0.03304697143903468, 0.06682494349661283, 0.04588317620800808, 0.029208030755398795, 0.016662224661558867, 0.0418959729722701, 0.05948729973169975, 0.04684359322709497, 0.09768899515620433, 0.017173948472191114, 0.07082231415552087, 0.09062551558599807, 0.08666693698614836, 0.0738236855249852, 0.06692370108794421, 0.05226137516729068, 0.026471522614883725, 0.017669803310127463, 0.052522269761539064, 0.015615438351233024, 0.03096553478826536, 0.07680268856347539, 0.04084529595274944, 0.03439009917201474, 0.03534834540914744, 0.03937653003958985, 0.07254294643644243, 0.13859199680155143, 0.025127995977527462, 0.03345272954902612, 0.029350528675422538, 0.0358885955211008, 0.015040404705359833, 0.04418764707224909, 0.08061842600000091, 0.04589086485793814, 0.058663964809966274, 0.04572446792735718, 0.01441283257008763, 0.07225370180094615, 0.0860011340409983, 0.03907662074198015, 0.05814597912831232, 0.024387421653955244, 0.04835273197386414, 0.07182133398600854, 0.03893052526109386, 0.03400318790227175, 0.04925122419081163, 0.15138620714424178, 0.06745796577888541, 0.03980839690484572, 0.03119903485639952, 0.02202910640335176, 0.09407046862179413, 0.09951349842594936, 0.0025386079687450547, 0.03542954749718774, 0.0714015455741901, 0.031016698449093383, 0.01452474287361838, 0.05757121914939489, 0.017999116498685908, 0.024730169570830185, 0.028929306063218974, 0.039933853258844465, 0.03527389686496463, 0.023554201325168833, 0.026976732224284206, 0.02962297665362712, 0.08190767010091804, 0.010543819134909427, 0.02318152073712554, 0.04348583512182813, 0.038534741615876555, 0.08819323047646321, 0.037226825079414994, 0.04824273826670833, 0.025751737703103572, 0.025518072507111356, 0.02781201015750412, 0.07002083919360302, 0.02184913188102655, 0.09759967026184313, 0.061839191694161855, 0.021291244629537687, 0.003773218868445838, 0.04998432137654163, 0.019906799680029508, 0.018986601498909295, 0.01646149412408704, 0.05615377645881381, 0.05830785266880412, 0.03020580748852808, 0.05106194206746295, 0.10450565867358819, 0.0812063628109172, 0.18412835255730897, 0.1280328829307109, 0.1068217382999137, 0.25462534627877176, 0.10252896317979321, 0.1664898029412143, 0.11755032901419327, 0.23473322071367875, 0.14117965794866905, 0.14058945758733898, 0.17430930834962055, 0.13824263820424676, 0.18249822518555447, 0.15780225192429498, 0.23124258848838508, 0.09896079878672026, 0.17099103250075132, 0.14101411448791623, 0.08073173710727133, 0.12018723165965639, 0.20131350931478664, 0.2307979529723525, 0.15904534928267822, 0.14065880386624485, 0.13351364352274686, 0.2251610890380107, 0.11524247980560176, 0.2598055073758587, 0.09497692037257366, 0.143186766654253, 0.10982921012328006, 0.13391002459684387, 0.11916346862562932, 0.21083104860736057, 0.12644427129998803, 0.19855071615893394, 0.18910979619249701, 0.23177058203145862, 0.07472597382729873, 0.11550250608706847, 0.15182095725322142, 0.06733016052749008, 0.19806201191386208, 0.1181203949090559, 0.19157997536240146, 0.07007721273112111, 0.13111082167597488, 0.12654786027269438, 0.12333802704233676, 0.13586427754489705, 0.12394752324325964, 0.12323483140789904, 0.13152694387827069, 0.12293159728869796, 0.10912984726019204, 0.09828105830820277, 0.13018338941037655, 0.09543092179228552, 0.23832469596527517, 0.11852884330437519, 0.27474419795908034, 0.14937026688130572, 0.15073002985445783, 0.20231472590239719, 0.1333537552272901, 0.21746706595877185, 0.1372685842216015, 0.1953717414289713, 0.1214524450188037, 0.12515082664322108, 0.11125269389594905, 0.15065256447996944, 0.254437523544766, 0.14119889441644773, 0.12049391676555388, 0.07779695864883251, 0.14908220968209207, 0.25357443548273295, 0.14298960770247504, 0.09278558092773892, 0.17242964124307036, 0.1356180923175998, 0.18760252394713461, 0.14187021151883528, 0.12850184604758397, 0.17035850003594533, 0.20023338758619502, 0.16554743866436183, 0.129418101569172, 0.1841703729587607, 0.1448817874188535, 0.1348566636443138, 0.20755436271429062, 0.1815403945511207, 0.15987683669663966, 0.11105703408247791, 0.13864791020751, 0.2465403894893825, 0.14238564792321995, 0.08835409840685315, 0.23551575606688857, 0.1252849624142982, 0.10227143051452003, 0.17985646147280931, 0.14045938878552988, 0.19935141928726807, 0.20687267038738355, 0.17248110176296905, 0.19967757834820077, 0.11351346125593409, 0.1692490783170797, 0.09479139087488875, 0.11701083218213171, 0.17832612327765673, 0.09603478509234264, 0.1709807018050924, 0.21342770458431914, 0.10950183394015767, 0.12010969207040034, 0.15514990518568084, 0.17014700279105455, 0.24052115622907877, 0.16835412243381143, 0.18294039677130058, 0.25842241127975285, 0.1500698598101735, 0.12310967562370934, 0.15329155256040394, 0.2389828918967396, 0.14040181296877563, 0.18687233969103545, 0.15123618941288441, 0.07461812492692843, 0.14324555959319696, 0.16144806722877547, 0.1141762436600402, 0.180975827970542, 0.13444325770251453, 0.08511173684382811, 0.15981333854142576, 0.18019225361058488, 0.13208233751356602, 0.12007467754301615, 0.10720022619352676, 0.12462351587601006, 0.09845949287409894, 0.13717721099965274, 0.17751069593941793, 0.12166260639787652, 0.12404609529767185, 0.13336821226403117, 0.11185485767782666, 0.22167859075125307, 0.10311758276657201, 0.2581743261544034, 0.08165655701304786, 0.2302076041814871, 0.11816117592388764, 0.21413284877780825, 0.14952257042750716, 0.2471811301074922, 0.21810108271893114, 0.19676536117913201, 0.16487573564518243, 0.17297287849942222, 0.14305616350611672, 0.21068196598207578, 0.15997387992683798, 0.11817985578090884, 0.1229462398623582, 0.13439090660540387, 0.15733204199932516, 0.13378581876168028, 0.11838492602691986], [0.012982183361600619, 0.03575876049580984, 0.03885878555593081, 0.02688150168978609, 0.01818154938519001, 0.029639172171300743, 0.05245185107924044, 0.030890514790371526, 0.008612824167357758, 0.04720744596852455, 0.02576853436039528, 0.05844366198289208, 0.05659092370478902, 0.016663059577695094, 0.02170308835047763, 0.02105130271957023, 0.05123469549289439, 0.04805607328307815, 0.07328838924877346, 0.012861875657108612, 0.008899645690689795, 0.0641039406764321, 0.03438540137722157, 0.05150013945240062, 0.038550486278836615, 0.02602693348308094, 0.11869178924825974, 0.0627107365289703, 0.027170646135346033, 0.02947087534266757, 0.018246613472001627, 0.031311926650232635, 0.0325768617040012, 0.02994754380779341, 0.07097584966686554, 0.04170440981397405, 0.08341411856235936, 0.015570536561426707, 0.012688526658166666, 0.03134921586024575, 0.04796061082743108, 0.027002790884580463, 0.030993565706012305, 0.07082908254233189, 0.0360706295032287, 0.07289072425919585, 0.05740678891015705, 0.03804952546488494, 0.0015055039625622157, 0.06197044793225359, 0.012825367557525169, 0.03209079208318144, 0.03387041397218127, 0.022767871741962153, 0.042927198301185854, 0.06398930854629725, 0.05562023536185734, 0.04721545003121719, 0.059754242829512805, 0.02990398159454344, 0.03426788971410133, 0.0023961884380696574, 0.040793913358356804, 0.03562722595233936, 0.028838901343988255, 0.028946822603757028, 0.04875850863754749, 0.04945170796418097, 0.08111629576887935, 0.03857947827782482, 0.06145308194390964, 0.030120490191620775, 0.03082204239035491, 0.024191162556235213, 0.07219093837193213, 0.018904852076957468, 0.06935658733709715, 0.05579530057730153, 0.07977132379892282, 0.022432827317970805, 0.041577432057238184, 0.0589809991652146, 0.03593432666093577, 0.051751308201346546, 0.029739347264694516, 0.04542421724181622, 0.015212823236652184, 0.06327527342364192, 0.03814928495557979, 0.06987218701397069, 0.0456288755958667, 0.08143884057062678, 0.08882336580427364, 0.024373662236030214, 0.05361357194487937, 0.06040079446393065, 0.025505240773782134, 0.068845551868435, 0.058026166807394475, 0.056705240422161296, 0.03719706124684308, 0.06690534035442397, 0.03119601431535557, 0.01568309438880533, 0.08135193507769145, 0.01661816335399635, 0.07248597175930627, 0.039374340703943744, 0.04965435138728935, 0.03772456868318841, 0.01945823634741828, 0.012803769204765558, 0.1370736220269464, 0.04632291726011317, 0.06856539112050086, 0.05214614931901451, 0.029305344869499095, 0.024111452185024973, 0.03972415201133117, 0.018722419190453365, 0.08359730287338607, 0.020820298122998793, 0.02946636865090113, 0.06967903565964662, 0.04888841045612935, 0.04432767549587879, 0.07739884094917215, 0.0363527235458605, 0.08788915030891076, 0.016231858789979015, 0.034543957517598756, 0.017516650004836265, 0.034774687519529834, 0.054583291785093024, 0.025577282904123422, 0.027595800274866633, 0.036680259290733375, 0.05273721799312625, 0.06171803608594928, 0.01420771408447763, 0.040354988668696024, 0.07047051389236003, 0.040417911659460515, 0.027138060286233667, 0.03819238147116266, 0.010466999428899726, 0.02127579125954071, 0.01995916747546289, 0.04281154200725723, 0.03261655547248665, 0.04152600122324657, 0.026607842155499384, 0.05271486450510565, 0.016715317906346172, 0.04274366147001274, 0.03982554793765303, 0.0534257083927514, 0.03610799292800948, 0.017476967368565965, 0.015683799429098144, 0.014391556123882765, 0.03461433167103678, 0.03809270361671224, 0.027851473860209808, 0.02667419201316079, 0.04150394830503501, 0.04385482723591849, 0.06933332842891105, 0.07686818309593946, 0.04310495009121951, 0.04533048027951736, 0.013068582338746637, 0.033651005433057435, 0.04551999882096425, 0.03000268723553745, 0.07807328991475515, 0.01145754578828928, 0.0602540718682576, 0.03286213584942743, 0.03483323183900211, 0.02786901266517816, 0.030904216691851616, 0.03842597987386398, 0.01110935329052154, 0.06785420584492385, 0.01627971803827677, 0.052716404461534694, 0.0069455527682293905, 0.03935110034944955, 0.01965389801625861, 0.05167766488739289, 0.010155556228710338, 0.04303769666876178, 0.06297756088315509, 0.04253285071172286, 0.028402537063811906, 0.009871202346403152, 0.04030641881399788, 0.03445629874477163, 0.008688657744642114, 0.010633587462507421, 0.046731629117857665, 0.038474423563457094, 0.07947865786263719, 0.048435444332426414, 0.01180601751912036, 0.006835981621406972, 0.05738966014178004, 0.0107691722769232, 0.028362403572828043, 0.06285069073783234, 0.05197811595280655, 0.07860793310101144, 0.06955876320716925, 0.025073694887396414, 0.021863271649635863, 0.06464711113949306, 0.02259617773233913, 0.03046215271751862, 0.015911913360469043, 0.05946459001279436, 0.04233306084643118, 0.01690934870566707, 0.07818342462996952, 0.023167219551396556, 0.04874556929280516, 0.03545393446984235, 0.050336771018919535, 0.06674718868453056, 0.042699544501374476, 0.04923067412164528, 0.014037927394383587, 0.03857636867905967, 0.04726271741674282, 0.03374476837052498, 0.05945607757894322, 0.03056842826481443, 0.027365142632334027, 0.05154838647285942, 0.07342972385231405, 0.012680211821134435, 0.06054601792129688, 0.028870952846773434, 0.028813176650146488, 0.007998735000001034, 0.031127168986131437, 0.024652915708429646, 0.02904939483414637, 0.008670595725561725, 0.01850257278420031, 0.04476357593375724, 0.04491898536798544, 0.01244977960595861, 0.029220046126283705, 0.023901858548924793, 0.04397194556077011, 0.044573259583557956, 0.07584276507259347, 0.05382846080465242, 0.06194858426169958, 0.01870264095487073, 0.08934879151638597, 0.025191503409587312, 0.0034993410963579663, 0.04404004132084083, 0.015420372255903203, 0.025753511436050758, 0.071847568906378, 0.030631651825387962, 0.03381170266948175, 0.05967741570202634, 0.06631145151914097, 0.005895263057027478, 0.04118543707591016, 0.054722273780498654, 0.08886586860171519, 0.0241308779004612, 0.021469877719937358, 0.03940193746529985, 0.055113185226218775, 0.04806938370165881, 0.0731244265625719, 0.03012402095919242, 0.0888667740218807, 0.018707281233218964, 0.02595652036688989, 0.015663165868318174, 0.023865721523179673, 0.08413157498580404, 0.019704074620676693, 0.0357812327274587, 0.04286775227228645, 0.11183534661540762, 0.07712645790888928, 0.05452645811601542, 0.043942252232227474, 0.012804374982806621, 0.011401800293242559, 0.07153723985538818, 0.08536577399354428, 0.06915381032740697, 0.06810748600400984, 0.031144954555202276, 0.059239648762741126, 0.08283602262963541, 0.021315240119292866, 0.004747999691971927, 0.07118904642993584, 0.02676849671843229, 0.022743225017620716, 0.009168880169454496, 0.029492490393749904, 0.041763525587157346, 0.03212258940038737, 0.01669608329393668, 0.04458353832887951, 0.009704998374218121, 0.012379839608911425, 0.03273980393714737, 0.055999951509875245, 0.006411655904230429, 0.031651574245188385, 0.030914304334146436, 0.03204179920430761, 0.033723349988576956, 0.028441609283618163, 0.010043195070466027, 0.02514818981580902, 0.04539920686511323, 0.03416568855755031, 0.02954399915324757, 0.03782578649406787, 0.019263263020548038, 0.010551198865869083, 0.020050533275934868, 0.020559637305268552, 0.013751546521234559, 0.04964917490724474, 0.06143788275949191, 0.018326329409319442, 0.007310025202968973, 0.07286814812687226, 0.033323543902952224, 0.05288937682053074, 0.020837219090026338, 0.026593913898977917, 0.058902353775920346, 0.015404633159050718, 0.08503182980348356, 0.01544220160212717, 0.04510835919063538, 0.05788071699498687, 0.09254867254639976, 0.11299278528895229, 0.08764896905631758, 0.16762684739660472, 0.11589953282964416, 0.11239923784160055, 0.19094782881438732, 0.1514095105812885, 0.10284637231961824, 0.14804298029048368, 0.11946819446166046, 0.10192169342190027, 0.09621779128792696, 0.11721921240678057, 0.16852995206136256, 0.13225475326180458, 0.1556793533382006, 0.09673676773672923, 0.14061066816793755, 0.12527768936706707, 0.12124891101848334, 0.1419857787550427, 0.1260360752348788, 0.22794460295699537, 0.11760750407120213, 0.13437269430141896, 0.208274498290848, 0.13929154520155862, 0.1394037579302676, 0.11376185066183098, 0.12687911046668887, 0.13546984089771286, 0.11756933541619219, 0.11852534778881818, 0.19417881325352937, 0.1134426158387214, 0.17646604886977002, 0.1583999628201127, 0.09715015141409822, 0.1209467530134134, 0.12005724449409172, 0.12368078052531928, 0.1216347684385255, 0.16443650296423584, 0.14871178893372416, 0.1513854946824722, 0.1612500919145532, 0.22947362012928352, 0.14304506097687408, 0.14616334286984056, 0.09445483432500623, 0.07955778564792126, 0.15614974137861282, 0.07392640618490987, 0.24104736861772835, 0.2259063982637599, 0.19151190557749942, 0.1072470260260161, 0.1507991534890607, 0.13881023274734616, 0.10979478931403719, 0.1663271093275398, 0.09945266458089463, 0.14203563623595983, 0.07542867635493167, 0.2295267430599779, 0.10738600802142173, 0.15958288684487343, 0.17908033827552572, 0.11025587082258426, 0.16179788595763966, 0.1710337505210191, 0.08290821133414283, 0.10200948207057081, 0.20009239437058568, 0.11494564299937338, 0.20162841741694137, 0.16154631273820996, 0.12320866328082047, 0.09557753306580707, 0.1648389399633743, 0.13659141899552196, 0.15887882618699223, 0.1611248025437817, 0.08492130917147733, 0.149382556846831, 0.10290666439686902, 0.15877449506660923, 0.20308749459218234, 0.14525980775943026, 0.19262386544141918, 0.19170643732650205, 0.15779215871589258, 0.17471606464823708, 0.1400909124640748, 0.14258720038924366, 0.07793757336912677, 0.1610989758046344, 0.1531466408050619, 0.13401413307292387, 0.12077535400749184, 0.12350478020380251, 0.16179718833882362, 0.07227608497487381, 0.16703494009561837, 0.2187486065668054, 0.16989505849778652, 0.17325398919638246, 0.180351399758365, 0.14211992936907336, 0.1305121905170381, 0.13712971354834735, 0.1833552127936855, 0.08729797031264752, 0.14882128540193662, 0.16821207536850125, 0.22844832827104256, 0.15383962861960754, 0.15885837259702384, 0.17954168695723638, 0.17903447354910895, 0.07520858503994532, 0.15543695306405425, 0.2180283670895733, 0.2136222511762753, 0.15752884472021833, 0.1489038419094868, 0.13823845249135047, 0.21072557457955554, 0.11638859330560081, 0.10303316346835345, 0.21443849487695843, 0.09171782337944023, 0.11934914655284956, 0.08490384643664584, 0.1580433757044375, 0.15561190695734695, 0.13327090186066926, 0.16407068353146315, 0.10899807894020341, 0.13497711421223357, 0.16350432095350698, 0.16913913656026125, 0.10288492689142004, 0.11419689020840451, 0.14348568889545277, 0.17539618362206966, 0.19454993162071332, 0.1701338222483173, 0.11893594841239974, 0.1406740624224767, 0.11496103514218703, 0.14374693972058594, 0.10286658100085333, 0.11701081733917817, 0.12955054524354637, 0.11669448431348428, 0.14751096430700272, 0.10813775166752748, 0.11015026320819743, 0.11198091888218187, 0.13515986065613106, 0.17967899912036955, 0.1704736813553609, 0.06123204067989718, 0.15891979273874313, 0.10071851618704386, 0.2582634432474151, 0.16267774655716494, 0.14989204122684896, 0.21886496047955006, 0.11578976176679134, 0.15148474951274693, 0.17728808132233098, 0.16043058276409283, 0.17517665633931756], [0.03993113699834794, 0.024968925899884198, 0.04253526269167196, 0.03614135246607475, 0.0209083372465102, 0.02576076778495917, 0.016259680051007308, 0.03116935637081042, 0.04320841660955921, 0.030320328296511434, 0.07194037447334267, 0.047347359359264374, 0.026411369690322317, 0.053175092543824576, 0.05475078709423542, 0.032198715198319405, 0.011547679623618023, 0.038373083298210986, 0.1475065411068499, 0.07275088137248531, 0.03269301894761156, 0.04703744220023509, 0.05240430538833607, 0.04650639100873377, 0.050597420704434626, 0.07203860513982363, 0.037385904433904216, 0.06442224039346911, 0.052404758098418824, 0.024111502279993147, 0.052892720195814036, 0.035716194615815766, 0.037049618767923675, 0.020814839626837056, 0.030129013757687062, 0.045081920179654844, 0.05992535239784047, 0.06312702200375497, 0.04191630410787184, 0.027774902773671784, 0.04658305857446976, 0.06777797985705547, 0.027079901883553248, 0.07836369230062701, 0.04082392209966201, 0.01097940137697151, 0.06366144996718504, 0.025409043591935188, 0.01964116090675816, 0.08338963511050679, 0.053001912383479066, 0.025704566796775907, 0.03875548602081835, 0.06514245760627091, 0.07689146426855586, 0.06296816529356875, 0.04157890893111471, 0.05993747166940011, 0.020282487821532413, 0.03556080744601786, 0.06090246773965191, 0.03885385398461949, 0.05859919016074855, 0.06608687763218768, 0.024805178436508868, 0.043547555833356455, 0.04147177991399076, 0.06615488062379882, 0.058524329724605195, 0.026549466674623545, 0.009111501021834556, 0.04579653417749796, 0.05823561943543609, 0.08263281517429277, 0.08321425077156164, 0.03883288831275422, 0.0024700877929717535, 0.023717251169728115, 0.02087605753331445, 0.037949294710415415, 0.017769401383702643, 0.06731358094839379, 0.05583844533248339, 0.008978056375781307, 0.029237050584924873, 0.04970055008016061, 0.041915394976967946, 0.024916389265854377, 0.05958867710432969, 0.037886304926360026, 0.03254707560699899, 0.03908633174432907, 0.10154942472581752, 0.024688154735486023, 0.023792109750502277, 0.0347052002325654, 0.03527680608385708, 0.04313161916797981, 0.01564980164403096, 0.014623182269133395, 0.06675774202449247, 0.020595902351487894, 0.04166348036960699, 0.06401785896741785, 0.028122918083681725, 0.02943203133327188, 0.10127805100637488, 0.032695030167815275, 0.08414317475399002, 0.01000022750304197, 0.03331235973746516, 0.016202172882913146, 0.027431824601080734, 0.11971142594120465, 0.03493109885312151, 0.033111575394286774, 0.00905647355466499, 0.08121239647152834, 0.016450666189484764, 0.027085993060609326, 0.03239313191443216, 0.061207393955555744, 0.018702906272665132, 0.012440900736692129, 0.004767221316797077, 0.00578534217311244, 0.04519254100159742, 0.023057979124132544, 0.0880100461654365, 0.03807522232818883, 0.011356193463143427, 0.04935931799991522, 0.023659621547267307, 0.023164657286542933, 0.031103318215173203, 0.14196945150615647, 0.04815045962459408, 0.023424113969667815, 0.04383354986202903, 0.01250222347152885, 0.029420468672469724, 0.014419268845813349, 0.043236013370915316, 0.043444204347906634, 0.09063672201591544, 0.019459635295788758, 0.07354416302405298, 0.048094189987750724, 0.04934597047395073, 0.03411025754758157, 0.041507636778987944, 0.07476330385543406, 0.06456655100919306, 0.011682839558488922, 0.06302257213974372, 0.09068354411283508, 0.036606022258638404, 0.012077420924470061, 0.012073331690771738, 0.03118283006187994, 0.06578477899893187, 0.02801612859911984, 0.017852536766440608, 0.017076819895009976, 0.04243080911692232, 0.04235436048475094, 0.09992398772737943, 0.050630149416974746, 0.047562760300934315, 0.017915663847816177, 0.08935585676226765, 0.054039471942815, 0.04083591149537824, 0.10740022757090628, 0.02261922141769901, 0.01924468520883238, 0.07520370170823298, 0.035844456288032234, 0.06926557776750997, 0.010183973990933737, 0.013984499255457195, 0.023456234121113084, 0.03437383129494265, 0.019141044285788666, 0.004984059241905925, 0.03788888017879799, 0.019088657936663367, 0.07848673296393827, 0.010660452280717436, 0.020250004017725587, 0.04264330826117657, 0.03142208734061569, 0.019120291981380433, 0.018525176747061778, 0.03410849494684953, 0.037465291970875114, 0.021855378909094725, 0.03374511346919462, 0.07556839307653718, 0.051940195917268284, 0.025557523222232703, 0.037821834557689726, 0.023176923132268712, 0.05495092576893512, 0.0942441905499436, 0.0779091713775415, 0.05373553649405949, 0.0252425427606795, 0.01821767527871998, 0.047251399664673954, 0.029819699593645055, 0.039244724612217396, 0.0050832959823310375, 0.01949702655110741, 0.04985581850633025, 0.07181346722063608, 0.029348448806558736, 0.07508023802074604, 0.006047849083188339, 0.08866297284839675, 0.05397035201895051, 0.01816350963053992, 0.05538714161957614, 0.12223880243254825, 0.012588479585247114, 0.019723194200196303, 0.03544810489984229, 0.012866000142821576, 0.039200106693897396, 0.018487165798433125, 0.04239723064529244, 0.11264859946095385, 0.014824968511675252, 0.01971389323443873, 0.06633862154558301, 0.02893252512876643, 0.02467590558808297, 0.0785075502062682, 0.04266497155185789, 0.028434781524993014, 0.02140212520316709, 0.03264480903453659, 0.061925158370286226, 0.018549858723417856, 0.014703016022394877, 0.013969009705760982, 0.0369060651428299, 0.015058240369398845, 0.04090733207704034, 0.018181291488872375, 0.026183771551586688, 0.02764207689324394, 0.019388658147363458, 0.07824109692592174, 0.06858611188363284, 0.028187121279188432, 0.02139403764886083, 0.057707496016519144, 0.03114228653430473, 0.03165743350109551, 0.020848395834036637, 0.055727757717249915, 0.05831263952131849, 0.009365458390675485, 0.058155797742074355, 0.03458448620222043, 0.03402072485187091, 0.05759114210377447, 0.033512721056467853, 0.012142305968154687, 0.04805009899428114, 0.02838808373780921, 0.015002275013102917, 0.03027501832548296, 0.032515779239474796, 0.005402446849984699, 0.01040116721924278, 0.017027496760420036, 0.07997191889444366, 0.06794430257286876, 0.015556693651888054, 0.03194324941432569, 0.04146005398069974, 0.03822682083409745, 0.03152145349304192, 0.031970842464943416, 0.020810366331716068, 0.045097056281520054, 0.0641225760045927, 0.013413607721304288, 0.0070979277461447055, 0.08267069439170882, 0.015994456880434882, 0.01681859888776671, 0.03917783855285961, 0.011340697419655044, 0.02526710413803812, 0.020958339446224272, 0.02334168919333024, 0.010355285794503288, 0.031088742434803862, 0.015050948768475791, 0.018902863121184055, 0.021847931457159575, 0.07137834603781812, 0.024771861571935005, 0.08398638863582164, 0.06173326124553569, 0.07284747931407765, 0.027375614336051513, 0.018098731270583812, 0.03507882334815804, 0.04367596593510825, 0.03504608350340277, 0.02030348503467394, 0.013525196118280292, 0.009934090085153002, 0.013364169553824468, 0.022743488480045926, 0.10526466052397154, 0.009770826873136684, 0.05706568299501669, 0.04080685270309914, 0.06226642013643868, 0.01494021847975091, 0.03624988043156918, 0.014085278271522839, 0.055227505654329434, 0.034178524001617916, 0.026704354750108905, 0.05304785503540188, 0.054294173314701766, 0.07307864347239956, 0.05285945713694673, 0.06987227607169189, 0.03113456077699084, 0.024545040832890663, 0.03149907774059102, 0.054319844202836975, 0.006276623525991454, 0.039764265093253925, 0.02319390347111039, 0.027005481169908307, 0.017534916114527732, 0.007422136814057012, 0.05596518560196273, 0.03247300555813126, 0.009546099918225082, 0.0024116988606692757, 0.005381541013775859, 0.033725220200722106, 0.02986519510159269, 0.16087080992292613, 0.16354080493329093, 0.22073594445828348, 0.16358456196030602, 0.15347309672506526, 0.14477309247013181, 0.08044022892136127, 0.11101099124061875, 0.09939609808498062, 0.17048050911398605, 0.1520329443155788, 0.1553828059695661, 0.13855529017746449, 0.15207705757347867, 0.1754022395471111, 0.10085700094350614, 0.18583725148346275, 0.1194657082669437, 0.32249222800601274, 0.10801995798829012, 0.13932598085375503, 0.17991614498896524, 0.22331201325869188, 0.12622613925486803, 0.12368446899927221, 0.23499384813476354, 0.09156424333923496, 0.13158370333258063, 0.1666597547591664, 0.16703556349966675, 0.12002389237750322, 0.12977262551430613, 0.12374590398394503, 0.11558417201740667, 0.09917813673382625, 0.15877372323302552, 0.16714673722162843, 0.10593030019663274, 0.11138787609525025, 0.1624092968995683, 0.12879744346719235, 0.15879751648753881, 0.09602472156984732, 0.21757724520284683, 0.19374118361156434, 0.10796701317303814, 0.3074718714924529, 0.22268690227065235, 0.07560140380519442, 0.16910173231735826, 0.13015039352467284, 0.07802016698406078, 0.12230074207764119, 0.08288184282719158, 0.20028057333547622, 0.2356736405636184, 0.13287184905493632, 0.1276379861519672, 0.28404728625901043, 0.11680067822453566, 0.15562443441012874, 0.1120703922060784, 0.1659853948513046, 0.13646299776155502, 0.16299192735459656, 0.12557318288600072, 0.1506840909132734, 0.09699880523839965, 0.22644688957370818, 0.05734430749726016, 0.12688446877291426, 0.12253618842805736, 0.14897021959768608, 0.18568101455457509, 0.1800848648417741, 0.17965853068744764, 0.08292384096421301, 0.1301033710478805, 0.11830071453005075, 0.18147940485505387, 0.0746440258808434, 0.20173837401671335, 0.09454476778046228, 0.11376594731700607, 0.15533055877313018, 0.17020977364154533, 0.12087021532352082, 0.12784930528141558, 0.15641136327758431, 0.14089081407291815, 0.1860880380263552, 0.1616154215298593, 0.1564417319605127, 0.186085692839697, 0.28909127810038626, 0.1628038374474272, 0.09231560849002562, 0.13188595039537176, 0.07969734651851468, 0.12054690610966645, 0.15561432635877281, 0.13133974454831332, 0.22703821799950674, 0.20628330123145133, 0.07614451489644125, 0.07064855511998758, 0.19480039161862805, 0.1176869212940801, 0.20708290598122403, 0.09759699110873044, 0.2623036061413586, 0.13233735429821536, 0.17077187629183754, 0.15265835216268897, 0.16346452699508518, 0.14116166828898713, 0.05457722472783644, 0.20510757603915408, 0.11368346502422355, 0.1259276326163672, 0.12029329940560274, 0.15049416047986597, 0.11633279122179374, 0.13228593830717728, 0.15436109126312658, 0.10316222294932231, 0.08696498349308968, 0.09278434154111892, 0.18381381552899256, 0.10320295943529345, 0.09920878001139499, 0.12967397924512625, 0.29968421906232834, 0.09705727905384265, 0.11833828204544261, 0.23825903073884547, 0.10214129491942003, 0.0994813782745041, 0.1394829896162264, 0.12194284878205508, 0.16408289928222075, 0.16446376946987584, 0.1537409526645206, 0.17368342552799731, 0.1560524309752509, 0.14899615023750812, 0.13880436978070065, 0.156279394577723, 0.1988581582554616, 0.1309279416454956, 0.1464737980859354, 0.1797775414888747, 0.11811784192104824, 0.07016679737716913, 0.10943052839138545, 0.13022444501984864, 0.10958881364786066, 0.11008412300725468, 0.16267739032628015, 0.15874791133683175, 0.14542340679327026, 0.20093648345209658, 0.13530380761949345, 0.06647965186857618, 0.1990191004006192, 0.13271507777972147, 0.15544520574621856, 0.11534564575413242, 0.22375281929271296, 0.10096815982251428, 0.18602997239213437, 0.11329286528052762, 0.13002894847886637, 0.228417202597484, 0.055172720312839374, 0.15440144925378263], [0.057999853961518966, 0.051203328621340916, 0.03716133054695092, 0.02777439254714409, 0.03667266712000128, 0.02699728043808136, 0.032368407264584675, 0.017228058459295426, 0.03934397202101536, 0.021866913739359006, 0.018292138665856328, 0.105470829148544, 0.03387238066352438, 0.048327172407880425, 0.050776638236129656, 0.0268251522720675, 0.0690323207527399, 0.01889041730464669, 0.026340318327129353, 0.049242637542192824, 0.03243366059905384, 0.03525985172018409, 0.05138938875461463, 0.02391178291873075, 0.0924154718813952, 0.026958069065585732, 0.09426108925254084, 0.04867399657086935, 0.05725368013372645, 0.030387247752514668, 0.026608569460222498, 0.046656119302497245, 0.034915725263999775, 0.08032192316022702, 0.0018191797516919905, 0.05665340882842429, 0.020890004343527835, 0.02413912872725632, 0.021039509992988314, 0.07587413565488532, 0.04490354498557281, 0.02126727697032038, 0.04086370863660704, 0.032839533741935156, 0.042554706960800104, 0.04712849258794449, 0.02159030602342682, 0.07182286281022243, 0.023048902658047155, 0.03293487745395396, 0.03939430447644554, 0.01972309957636753, 0.029824096818629187, 0.030209913420549128, 0.013422388256003615, 0.0564591108559398, 0.012903425722470274, 0.03236054049921222, 0.024317349925695453, 0.027525327786861453, 0.03422239977226127, 0.02495700700819725, 0.044865925519843586, 0.053562582688755356, 0.03797865407250356, 0.05384098083595745, 0.0077341997075563995, 0.04264104842150118, 0.0166968755365815, 0.018074327599606477, 0.041258568307966925, 0.036022916829097085, 0.03144569505820982, 0.03389583253010642, 0.05643742530082818, 0.04448769737791736, 0.04903358938463498, 0.057096311429631896, 0.05574827067903243, 0.006669848617093521, 0.015014890595921315, 0.03052126477996353, 0.06151315879833419, 0.0684720289427787, 0.028256148434593342, 0.1196415453159716, 0.09863212384516373, 0.04650099188438617, 0.025994603674917016, 0.09603308557416312, 0.014893964125803905, 0.046712006733287126, 0.0056362275427090935, 0.04580699845973868, 0.08996206524898298, 0.05445108559797518, 0.003682117226162518, 0.03653565181593876, 0.02618377340695588, 0.05041152755438816, 0.06292319856584072, 0.04418565069499891, 0.026095426292158663, 0.026012159178208094, 0.023548251156171318, 0.04718154501460958, 0.04370554052002262, 0.029494100854208227, 0.046591819627792574, 0.07016801449935883, 0.04435990325873718, 0.0216440245276317, 0.05075730528915301, 0.04720466662547551, 0.01916457222250756, 0.011374229507055134, 0.024430629491689615, 0.05861870122316759, 0.04103405008208938, 0.07038490715785883, 0.03514864460157696, 0.021125220628164243, 0.04223689706122968, 0.04287293617380783, 0.014622348280681763, 0.012620007873920258, 0.04257286731444765, 0.01740076178975869, 0.024750122211116832, 0.014215587343642255, 0.02681975871382747, 0.043180745633435436, 0.049519926178618334, 0.051870860770577565, 0.019606016503530554, 0.022848799235362094, 0.03986626958067063, 0.012653025096369674, 0.06882618923555128, 0.028581305596162565, 0.09473321391851641, 0.04529289792117197, 0.02288862844579853, 0.03478276208625175, 0.052513812988763675, 0.07979022630024701, 0.009864635267149424, 0.02592106055089971, 0.014826680089754518, 0.03330756546347402, 0.0500708632171154, 0.013793052985420218, 0.0909482607676182, 0.03668553224997595, 0.024614082831249107, 0.05940544084296562, 0.07037233517621644, 0.013509893033187836, 0.05477395694470033, 0.03714626494911499, 0.03421678913582582, 0.013613324299512897, 0.06081949934014119, 0.057992451038444415, 0.060165418617543764, 0.045916565431980416, 0.0731306012312416, 0.038923816246096976, 0.019013799355889205, 0.06118333723861724, 0.018869915475079324, 0.004416165520524373, 0.03141268804029096, 0.016540304641239345, 0.11842684252769686, 0.007114794443623396, 0.02339437425689539, 0.053439204348251224, 0.04834217492316384, 0.019324818604218308, 0.01696767780231312, 0.05881230528757442, 0.021050044779258315, 0.006875223607494263, 0.01835806735471124, 0.04293523576052394, 0.06509746119263582, 0.05220212209678721, 0.040388889974565245, 0.04647389236197341, 0.031783108788658865, 0.022176563725224696, 0.01730038446112303, 0.026590431371005252, 0.014987449685577303, 0.006148624852357898, 0.013073453610559227, 0.009472592046222417, 0.02586498758319067, 0.06466850725701079, 0.042559367648209445, 0.03956451975682285, 0.005104567326270626, 0.0075978504810336744, 0.0645701726898551, 0.02451223790558288, 0.02756180620053783, 0.023630805808352306, 0.043689291196642444, 0.004601626833391492, 0.04674574847740587, 0.07625588899827562, 0.01222064336616313, 0.05014169750211295, 0.018705930524447467, 0.022240013640839607, 0.04074902455613483, 0.02858164327335544, 0.028040330034855288, 0.014812679473834578, 0.06384447842719965, 0.019908092872356065, 0.01957486485480331, 0.016669351134623867, 0.0326557631342439, 0.061482790115405805, 0.05930771854764316, 0.03373274186742492, 0.044444708473747596, 0.10634540565661155, 0.021181464289838914, 0.057544902592781, 0.025030247707036324, 0.024855252995621413, 0.0280696300251293, 0.03908422033418901, 0.010761690500658005, 0.02739188592386199, 0.03725349415617529, 0.03407058604352642, 0.08266066055512056, 0.07623553930898197, 0.0860366754932329, 0.043112152634421363, 0.0350183902628487, 0.02474400505889207, 0.08707719622179866, 0.07008073051110841, 0.049542580236447975, 0.008003360435395734, 0.048708580652601086, 0.029189933484303765, 0.026391580322524533, 0.06823710209573619, 0.1264314618310891, 0.01680079847574234, 0.049147000681841746, 0.04992501264496241, 0.020952834565832745, 0.01953797083842801, 0.04787873709574342, 0.032667522464180365, 0.06334930265438743, 0.04255080326402094, 0.008489432839269284, 0.006737522744515445, 0.02169153496652143, 0.0710665549559053, 0.031165805194177665, 0.04016385966679081, 0.0288589430419961, 0.08522119620465674, 0.0877423609199468, 0.052909622609149665, 0.047576553115504794, 0.025392374955117702, 0.08189553598640487, 0.1194471174676437, 0.037317496971809305, 0.043434886683826335, 0.015798568856553175, 0.004772013735419023, 0.022388647266780026, 0.028643989244301338, 0.034436372079653665, 0.022138144595373888, 0.034279255705769174, 0.021736676098953467, 0.02704124341107672, 0.10153344628633931, 0.045656476067961194, 0.026596437201078515, 0.05871725472388789, 0.02436166541883722, 0.013365918239287566, 0.030730370453966316, 0.007735215058346512, 0.022971795369812753, 0.038939308578846976, 0.07691245220485143, 0.018365466567047406, 0.024770028467173688, 0.022897263334016316, 0.06148126871266868, 0.06298042557318695, 0.010813103708642302, 0.024672686522535514, 0.06646016307058744, 0.019685071929416154, 0.008917389513953822, 0.08133977127727121, 0.03018694209458772, 0.014075598810450174, 0.028990518403588794, 0.053163002958172, 0.03944140116800554, 0.013789878448733361, 0.0165307754650712, 0.036829078453592956, 0.026423268172948156, 0.03762854961678386, 0.07325728583964519, 0.052409637719392776, 0.023568732576677576, 0.04289602809876669, 0.08206024824175984, 0.12189764456707053, 0.03404282972041983, 0.06362568587064743, 0.040326839007320814, 0.06281362046138383, 0.04695329007518012, 0.04376933924504556, 0.01024821800456266, 0.04766784841194749, 0.02241735168354353, 0.049924311315407977, 0.020402459704200737, 0.03816109623585362, 0.07506071211537346, 0.006424897674150998, 0.03480631785350852, 0.05259185352770146, 0.019564279973565135, 0.09394045919179916, 0.02918238769780146, 0.023300774591916706, 0.04489645376452245, 0.023111712471290957, 0.02900342435168568, 0.029592238752229605, 0.001803886291327217, 0.1658370840596035, 0.20338861359050497, 0.14223194913938642, 0.14786539919441566, 0.12239925476023927, 0.12905226729344577, 0.09873712289845571, 0.06808972641010769, 0.10619528402457945, 0.10364463378209621, 0.11085361882578582, 0.1894944958621636, 0.1566035795258358, 0.1429741265019402, 0.1634770247619599, 0.1358378867735155, 0.1301380738732405, 0.1355860018520616, 0.08778283023275435, 0.12066736409906298, 0.13008769688894972, 0.08694320888025686, 0.20654018822824582, 0.08518589223967865, 0.18186947767389938, 0.09456337342271581, 0.17860978696262464, 0.09699306101538241, 0.15698583010816947, 0.09380483170389198, 0.1158953174308408, 0.13635652925586328, 0.13163471856387332, 0.1560198506922461, 0.09347582279588096, 0.23147430183598772, 0.10343724061385728, 0.14755853597307578, 0.1476928053307347, 0.14127343572909012, 0.15362347068730742, 0.11849414790049195, 0.11124376585939899, 0.08545776319806464, 0.13474296662025154, 0.10735423667938448, 0.09335001392173581, 0.22308206622255966, 0.13806137605570257, 0.1861646573524922, 0.10885692987358198, 0.11435947992140427, 0.22886922990437597, 0.12675738340476528, 0.14690111187519506, 0.12265413053683005, 0.13674056099262089, 0.07143780690967105, 0.0635886007512454, 0.1282971617183648, 0.08823500596918166, 0.19766070297919214, 0.12354674865491688, 0.2337182150222361, 0.11864681509905495, 0.19232667982578278, 0.11111698477179743, 0.11375556467100978, 0.08198405193979852, 0.17399895703420043, 0.18593888118630275, 0.14102143206400797, 0.16541768156457692, 0.08772674613283016, 0.08262458475655876, 0.12129300943342969, 0.2357456585741602, 0.1501752299373038, 0.19369800545973703, 0.07143187714973465, 0.0648949365131557, 0.14535769703797996, 0.19800774607574567, 0.13916521682403982, 0.17143397592008114, 0.20826767053222284, 0.278373864130117, 0.20004946854896843, 0.07196050151833333, 0.19938493467634544, 0.11151294282171875, 0.1499245027662255, 0.17243072477867827, 0.1405405203695409, 0.11450055477325805, 0.2200818748679012, 0.16727123991586268, 0.11533938202774152, 0.10325604525860399, 0.13165128330001608, 0.19097537733614445, 0.24310491367941722, 0.07786375936120749, 0.1532089663669467, 0.10824675831827335, 0.1782861808896996, 0.11809790783445351, 0.13149780716048554, 0.1253909114166163, 0.14071059093112126, 0.17157410824438557, 0.1381940275314264, 0.12246518715983257, 0.12913838610984385, 0.12279320901143365, 0.06247352386708371, 0.1955794240348041, 0.25245705794077367, 0.13233928388217464, 0.17907263478264213, 0.10397635152912699, 0.2259732360835187, 0.0736080099886749, 0.1557805377524346, 0.13138274458469823, 0.1073957524204161, 0.11509143791045062, 0.17278968676691875, 0.1368140336126089, 0.11406297708163038, 0.11108736565802246, 0.14935052575310692, 0.1588083221577108, 0.1733695119037293, 0.21278304542647675, 0.17824289883719757, 0.12149647664045915, 0.13853056181687862, 0.1478821420460008, 0.11344554732204415, 0.15647682070266455, 0.12147165922215208, 0.13744344905717298, 0.120085201197071, 0.11342820333084092, 0.19948472385294735, 0.14139453938696533, 0.17683486657915637, 0.11966422534896992, 0.12237648566951975, 0.21436805021949112, 0.11325216590194032, 0.22579544718610123, 0.08922452630940825, 0.13592047296697274, 0.1503284982754849, 0.141977125313133, 0.06709064720780589, 0.13529876101529226, 0.12517775176092982, 0.10929343887255527, 0.10480645854840986, 0.11037900054361671, 0.12977209116797894, 0.1540222266339697, 0.15068797976709902, 0.139166196458973, 0.10137965844478458, 0.13061721925623715, 0.14384194946615025, 0.08692302988492884, 0.08181020384654403, 0.0915022665867582, 0.08822580333799124, 0.19520835019648075, 0.049295612043351866], [0.03151944598357659, 0.021768286023871042, 0.027204367470403668, 0.05410277713963296, 0.02152115270291688, 0.05071006758953445, 0.0349742807156872, 0.031235574497259222, 0.046387528636842035, 0.06010766468534712, 0.01818565902794944, 0.06354180091875605, 0.024225305060099345, 0.025365039800817613, 0.02634793461766094, 0.044558030713233165, 0.0451766108017182, 0.027911283541470766, 0.03781733714276925, 0.05477421669638716, 0.0393152583274059, 0.035712602621060796, 0.038836001622257754, 0.008491507142025512, 0.006215461744432105, 0.05972592989564873, 0.08947215872467496, 0.04072338706464507, 0.019257375934103038, 0.10455171635840088, 0.034249799864483066, 0.03273674628871959, 0.11172238431754522, 0.017516880070616025, 0.03986963893112261, 0.024621862394269556, 0.08353429453563876, 0.013349843320611399, 0.0573825874744216, 0.021069932481623255, 0.058370842452859506, 0.01928302826854633, 0.053555970152956434, 0.08175497321644798, 0.026007019805547316, 0.006743434878444532, 0.09671297448221594, 0.05400485075369943, 0.06555352578288876, 0.06309951801085845, 0.05694656087143812, 0.014914111579855671, 0.003299850873190735, 0.048203716141870245, 0.05085942852019798, 0.04296276572858915, 0.040380993523285724, 0.025554001731507014, 0.05182474742468912, 0.05183200933970511, 0.01836456485762028, 0.07144424875150435, 0.019020601139345672, 0.029871583137719426, 0.04507305893639568, 0.03875638773024548, 0.05327663689968176, 0.01737495174893411, 0.02569419713836396, 0.027884464179805946, 0.05742422195908148, 0.040492356492904946, 0.05060197749116924, 0.020452139069675468, 0.016557368471694645, 0.028013636838295497, 0.03839532917481847, 0.03673898914712481, 0.023018229694571346, 0.07512354975915514, 0.024377671688853297, 0.013145068078301847, 0.030187738047970925, 0.029775610455544665, 0.027663105647661723, 0.03544577084539924, 0.021332695432647597, 0.08284242736408487, 0.0572449487663107, 0.048243569472106174, 0.041169562537106685, 0.034343473744229414, 0.037605984616675414, 0.041576504372642376, 0.047212659555952996, 0.03266109175456222, 0.05048273291322403, 0.04063527929247357, 0.056618461094330996, 0.06570267520146444, 0.04839977300434839, 0.037937394372420385, 0.013541915777750546, 0.025940918567357585, 0.06197794733452611, 0.01950563175341813, 0.006261252256081207, 0.0478354068036424, 0.020790441521967296, 0.024560859710618388, 0.029434239222609904, 0.030412016931222752, 0.05282236459606793, 0.060175174148753285, 0.06456010916735977, 0.021169762476347387, 0.013516952712961938, 0.10826891142642125, 0.0915877842635382, 0.09298606470110826, 0.0198915967848734, 0.08063594810664654, 0.049877396450028755, 0.02809302994137397, 0.07266756045282818, 0.026918516305158846, 0.043288616798236035, 0.03391483522136696, 0.02557980435085483, 0.0371510666445829, 0.040134322189260274, 0.08268201214377768, 0.014366627383424202, 0.05221116516622715, 0.07061469092150219, 0.06040754058631137, 0.03011002962011844, 0.018470150207576808, 0.02371200233028503, 0.029719448430114426, 0.02494439420843264, 0.0649991117825266, 0.06658051715930924, 0.09488035211688839, 0.03712385208928026, 0.04488652011787053, 0.014553705186699517, 0.046717903096578084, 0.06670462651527487, 0.024931651532824617, 0.010582212289591553, 0.010364300105720758, 0.04518845547863748, 0.015574813187413383, 0.018793197814375162, 0.046173608279787004, 0.054358528650482185, 0.03830903224297799, 0.011992977506452007, 0.034909287132904865, 0.03282583369582426, 0.04373576448415406, 0.027238582333666272, 0.010227131733699935, 0.02408769232715713, 0.0329916146438336, 0.023162362194852903, 0.08920313761336729, 0.03451854638115037, 0.05095635300676804, 0.0329066943959333, 0.043858307908521965, 0.022232480841921642, 0.04223675234243274, 0.03718427775311284, 0.039552192683913745, 0.08241682051448151, 0.023735222275718115, 0.014540507017954951, 0.12001897935988382, 0.05702181835658848, 0.023965391956153326, 0.039598094517714344, 0.052990412805229425, 0.05525887623662129, 0.04792384854226839, 0.009196213468385395, 0.017201550799654797, 0.0967837827920448, 0.013990775041747838, 0.02524730734876357, 0.02736010901571717, 0.0391529209446162, 0.05600513170065824, 0.024347501530428417, 0.03254620729421731, 0.004408402655826649, 0.020272238762117922, 0.03494574142678175, 0.009112005682254676, 0.00545035109098535, 0.06480491399997845, 0.015906475273368414, 0.07889617583714426, 0.004475601344893221, 0.005555873358389363, 0.02120584755175514, 0.03655803870060481, 0.06498960487078875, 0.017458372858527582, 0.08575313055189326, 0.0408485576917883, 0.028155030813650228, 0.04301643042708747, 0.05046566351666115, 0.054057313172961585, 0.03195969540684018, 0.03827313455985859, 0.05343689255823847, 0.011861695293191588, 0.019198028239770792, 0.0328628074930748, 0.03128694595943671, 0.042466105660423636, 0.04918172206089366, 0.03524422580085229, 0.009534869368508225, 0.05748681098339148, 0.04511336126597598, 0.05404219191404991, 0.021795804859721102, 0.030667365826957393, 0.03222349921998102, 0.029043982722214423, 0.04882972512859851, 0.03566433704691008, 0.006846876349300146, 0.07492778604500927, 0.08206876809708774, 0.06358719067065977, 0.02444439633109141, 0.009301036261604168, 0.06849531753687188, 0.02820462112140376, 0.07274625037098303, 0.0962361965503078, 0.01826504842028953, 0.029521447140723467, 0.0790790187602397, 0.03644299096777104, 0.07190698524937034, 0.052769319590879604, 0.07979009271366522, 0.030221624510886613, 0.03628957420005463, 0.07295785151654854, 0.07378383219474927, 0.07280078338226303, 0.0603710603172658, 0.06915968071552925, 0.0071001059495756635, 0.03821678699750919, 0.0490180042834254, 0.04284140231902711, 0.03325630161270965, 0.11170581958140247, 0.00016235751644444463, 0.006884171125420835, 0.04166856408119202, 0.019283147012174595, 0.06582170826732181, 0.07001540667260997, 0.015697148810431827, 0.07196417514933273, 0.08859367851982825, 0.006174808286232292, 0.07482361077563837, 0.01479626595028094, 0.03119889384834096, 0.04619209146767389, 0.007476616483472753, 0.027708979650924448, 0.036746659243362956, 0.029268567741382867, 0.04082181811099872, 0.027673046715790406, 0.012432217608875362, 0.040765407466096804, 0.013350837798498105, 0.0298871700942982, 0.027150370660820045, 0.042255461885361, 0.01930338537931675, 0.07054171554045752, 0.05047024998930283, 0.07520772414864041, 0.019789536636380944, 0.02362605977396015, 0.03843367223453242, 0.03575297916540876, 0.09079701849259436, 0.014578436330339173, 0.07048504514386877, 0.0197908743575681, 0.019410095083003398, 0.034109463449567556, 0.04348266615124885, 0.05417714033683296, 0.0135366585891461, 0.03600003270548768, 0.0713527864718344, 0.029567592027888168, 0.02920419199654134, 0.05937318710493855, 0.0305909431699547, 0.01332171128524351, 0.08906178816687316, 0.053693278605351225, 0.08174983013304882, 0.03446558301220648, 0.03176283702487126, 0.03673284416436218, 0.06294357794104144, 0.034206751588499174, 0.0667841402173508, 0.02706324252358172, 0.012569036243803566, 0.048569275822956115, 0.015198000692180358, 0.035022312513319775, 0.03266240906668827, 0.04276894273061771, 0.040270610188599676, 0.031995285098673776, 0.007734366690783645, 0.040222274110419676, 0.01832193032896612, 0.055156036833068356, 0.033856973677757196, 0.02845458573574433, 0.02584751000540564, 0.03603994169679936, 0.02985499242640799, 0.052683768517454155, 0.0065100795291073155, 0.017415285619790666, 0.035139204483130015, 0.05168095631233882, 0.024912069966376293, 0.04592559736920521, 0.029047769530734513, 0.04041918073198758, 0.20104878523852676, 0.17459837486967444, 0.15197456697933376, 0.15698225295636803, 0.15406298538437113, 0.08037618899834342, 0.11721006172592752, 0.11545556524652056, 0.128049596096389, 0.1307020170497708, 0.09847310386248864, 0.15683496632846072, 0.13577496749348938, 0.12387866678182036, 0.11162420560140163, 0.23841933463700116, 0.13875889097107574, 0.160753802920226, 0.1578488142695278, 0.09393946471391246, 0.0816562824184075, 0.12982073152670637, 0.11737786131561734, 0.13337965618120506, 0.13002767198486254, 0.15132423781324178, 0.09962502837879583, 0.1509205243200995, 0.10743987309979275, 0.15032916620839387, 0.09065124584594741, 0.11940303389565088, 0.15131800377275795, 0.1790587863069959, 0.13135469140252098, 0.09138491077465005, 0.12070920638507232, 0.08377610851312056, 0.17225320305442438, 0.12140757477027364, 0.14890219434164464, 0.10086896436405368, 0.11375033995136619, 0.1517779126879759, 0.1019514090148732, 0.10572560102446005, 0.1739073166390881, 0.11505885762744583, 0.0886857790465001, 0.13691213069250807, 0.15712774358689785, 0.10793035107781179, 0.09667928839917295, 0.10737180331489071, 0.11287996399914846, 0.18087954173097387, 0.1976220222422853, 0.13318987417733297, 0.12300469883484766, 0.07722698923316784, 0.17942948907148093, 0.2068386651808396, 0.2144772349856794, 0.1508634680067189, 0.1737808992038481, 0.15585735003696755, 0.15109979751287028, 0.12395349011057988, 0.16201690857997164, 0.22642728203209117, 0.1647616527043283, 0.13963035045890138, 0.1252079423284158, 0.15286106237908825, 0.1427692937431857, 0.20576430251821876, 0.15470525482669473, 0.1040912805183325, 0.16106063645565882, 0.15474852203624323, 0.13517707848222926, 0.1611356675857678, 0.1285587836173363, 0.22669138270430267, 0.10379083687439561, 0.14922115457011387, 0.10129878661246039, 0.1837058924138546, 0.09920431970385835, 0.1717214987729676, 0.09197560837492347, 0.08487968210829422, 0.14704116998473182, 0.0888099403528031, 0.19624680775450543, 0.13753351609921083, 0.26003067498095334, 0.11549527756869793, 0.13950336899142712, 0.23355031153187156, 0.12105601199436933, 0.22357736073900014, 0.1105864011333324, 0.1338416282669641, 0.1651831332128495, 0.13596028176834807, 0.1273065133136697, 0.09115908265812322, 0.11434564628871158, 0.23503361240727827, 0.1141229500353802, 0.18876732472563162, 0.12387826602207497, 0.20157026272499934, 0.1465054284199141, 0.17495387844974175, 0.11137016845168546, 0.22900103533174843, 0.20102650596527383, 0.24175129568902776, 0.0847801823692862, 0.15176502900430933, 0.21238837129203603, 0.111439366301056, 0.13914747949456796, 0.14424486143980175, 0.14317199791548774, 0.14608952886192128, 0.1338762420346029, 0.16629920457489789, 0.09890812114463188, 0.16239225718891248, 0.12811714637791738, 0.16911458631511778, 0.18231519672553986, 0.17322838510153815, 0.13075368537101895, 0.11087689999840222, 0.13884385203709826, 0.11712303748936392, 0.17105464939959347, 0.1638222421752289, 0.24070060753729194, 0.14109615149209276, 0.15632836148142815, 0.10367769646109082, 0.34700257529038936, 0.18362250470090657, 0.29324840346816927, 0.17349063040455803, 0.10504908888833597, 0.21242271788651124, 0.11200637454749085, 0.10345071059418842, 0.13883874606108293, 0.08330636614118703, 0.09902051941026002, 0.1302583611686714, 0.15240401815390214, 0.13688481965800747, 0.1338397283689119, 0.1434580364730209, 0.11111900341347791, 0.1186001711175777, 0.08917545550502837, 0.13954037247458473, 0.11730781741789542, 0.14607269695261493, 0.14196767035173252, 0.14559714356437325, 0.09354910987894982, 0.07571902679046616, 0.06415764990379103, 0.10691198345739394, 0.1373525508097373, 0.11817905426141806], [0.036844659844064154, 0.04247302989824675, 0.05528606110601686, 0.021663472507498227, 0.025719765981193632, 0.08295081803225912, 0.08050013508182019, 0.04039382896735333, 0.06139263401564676, 0.031580918075633235, 0.031942462737788446, 0.0814121232542675, 0.04263616508978885, 0.06491619162261486, 0.0036716919066748233, 0.00182995701152322, 0.014088365605857689, 0.07241274404805154, 0.037782389408675954, 0.03195572120603174, 0.04608246512361802, 0.04868342184636276, 0.06855742045445368, 0.03222099447157234, 0.023832515980757307, 0.02884859379264526, 0.050275662579224445, 0.05239643120148685, 0.04574249469442293, 0.014010088507347973, 0.050327557255513966, 0.0675190519541502, 0.060695868669427, 0.05672881845384836, 0.05610680593235884, 0.03707794654474128, 0.04331740470661316, 0.06454622358432971, 0.04778287388035096, 0.03603077988373116, 0.035416400351095945, 0.04566107367281802, 0.01907118406961672, 0.10326987146981992, 0.021090373084007297, 0.034644024999579415, 0.10176951604080386, 0.06507252503070049, 0.0575069899787195, 0.004354345082902, 0.049430931539973244, 0.032900593942031264, 0.05940388604358304, 0.061512223692261614, 0.026927169747068547, 0.00890100567630725, 0.05130664671014529, 0.0719158019637689, 0.029417759833449963, 0.03139737753372174, 0.04858425607380923, 0.03892061016813386, 0.033830935426522046, 0.060925941870664246, 0.009331425353593659, 0.044895347964484245, 0.04813435873074923, 0.053195920918369666, 0.03479769409750588, 0.04249096389685292, 0.053489562778850086, 0.028635641938308254, 0.03410055396670941, 0.08678781057824381, 0.007280438094312558, 0.023025456357572693, 0.0435521051986143, 0.033035479282261804, 0.02487432062480366, 0.017129801817645784, 0.0789266632637009, 0.02761155235930346, 0.038109862070996314, 0.028059147189196665, 0.04702944184828084, 0.04139045166084543, 0.02637184847117169, 0.05266757856588811, 0.06703905310132541, 0.04555881314445287, 0.05684037067112513, 0.0174862330823089, 0.041620305928518064, 0.06293771497439593, 0.031568995473207906, 0.024667578691150993, 0.006302504998529912, 0.030275587923824787, 0.015467174871446332, 0.057381310980417766, 0.12149013127782382, 0.014536254511767766, 0.009429711681150366, 0.031174057876341976, 0.031856243731454015, 0.08945662557380274, 0.0811247191450093, 0.05125930139911361, 0.030912584406905808, 0.043070083993370645, 0.03740345622645691, 0.04528809993644245, 0.042191926622763276, 0.04477645219594706, 0.01910888146085199, 0.03030836487596389, 0.03203840387868695, 0.00816042485894286, 0.08251601597294211, 0.017563811634317972, 0.062017273739911616, 0.0680468748032581, 0.014256565027608303, 0.08111490053124726, 0.027323458052705973, 0.028398022950568702, 0.12115865843952633, 0.014789831529924413, 0.05571112247707788, 0.03693008475238457, 0.040556689564255066, 0.04898242201306857, 0.07543896252172999, 0.028586322514456697, 0.0133217799339036, 0.06518909416627139, 0.020856142000411637, 0.06484435172751546, 0.037222294267849065, 0.03296580274763983, 0.02849415148375556, 0.03678097986266948, 0.08580193418310955, 0.0349042999005178, 0.07207814676803537, 0.036098437776672654, 0.006750235734216403, 0.021346119028748944, 0.050626015654415824, 0.035426660542725585, 0.011976453588431468, 0.06367804438923486, 0.02707175681280205, 0.0687908407417126, 0.023176080794655718, 0.03747305483557284, 0.031206267085508443, 0.02211455357610248, 0.03241992344555911, 0.03196258236130234, 0.01777392106305342, 0.023914992707432248, 0.008653490149299614, 0.05578766758844722, 0.00831841140097822, 0.07666397374123335, 0.050114905970986, 0.028413057007128373, 0.018008365514106117, 0.052999730469309725, 0.03320162017189432, 0.06749071675585583, 0.03103813167399494, 0.03774348231672775, 0.038547974108951166, 0.03796682423853781, 0.08991603725007735, 0.04618944942194503, 0.009625959646655247, 0.025541461291140877, 0.009582996717654169, 0.027624400790955406, 0.03421239562158007, 0.014304549513326492, 0.037829749562661164, 0.07266185333719477, 0.004183031887805555, 0.01656406635447638, 0.0546356391714653, 0.003441187100179377, 0.035648841003421694, 0.0390048587723868, 0.007748381221972522, 0.005598534789896803, 0.043232258103671484, 0.053116325580049306, 0.02529108849557815, 0.0898880953900516, 0.029350159456953406, 0.017528264615975786, 0.009154195849987445, 0.03594830501242541, 0.030361626959347632, 0.03299190408142749, 0.011346220853738487, 0.06348375012748875, 0.16347240860341117, 0.029426658184092958, 0.008510477364325197, 0.057116026582662016, 0.037797250915900804, 0.018559931522759143, 0.028822217864217237, 0.03745692425582092, 0.035063130635535344, 0.04822749084269162, 0.032522536494070664, 0.04431917048350442, 0.040840149158611894, 0.07696614658925682, 0.028746387069986667, 0.0115298022137722, 0.02634008455061121, 0.015904662577668205, 0.12578813853906468, 0.009167516473098658, 0.037783387597301044, 0.02861183755157981, 0.022767760419810656, 0.05169326483155601, 0.024125729250954464, 0.023258577930391766, 0.04973886716470588, 0.02202816202043323, 0.1240937337570358, 0.060646207857644185, 0.05306883555022068, 0.07518106620409526, 0.0401389197941171, 0.018116867504431866, 0.009080665713554481, 0.012278028079890646, 0.01920428083394654, 0.0653709277685266, 0.022590426087845117, 0.01721249191177776, 0.03799083271587733, 0.04963095147104468, 0.018570963547972497, 0.05169570278667379, 0.006334507797873812, 0.03112598897132557, 0.04954620191711001, 0.07030148975900374, 0.019892292548320256, 0.0381017429754138, 0.03069707214308437, 0.04636173529434018, 0.019929129048250616, 0.03095059350016527, 0.029035310726612806, 0.016369237746403087, 0.01781336064595962, 0.01602144508069614, 0.06424046616302803, 0.06093453223002143, 0.0703425973188132, 0.011858040215884103, 0.014568283750122646, 0.04822172806598246, 0.0544708230154356, 0.014206145369826118, 0.03431768411246594, 0.0337984998623142, 0.05538534191146027, 0.07947396006784402, 0.007485501382689108, 0.02418582465907093, 0.023135485316743143, 0.05083123432996217, 0.03273439368058462, 0.07891867775470018, 0.15129850013181567, 0.12044780713040382, 0.08553984473110177, 0.042969626883859746, 0.06870104087283835, 0.033742649538908154, 0.06984873514738865, 0.034775433377944864, 0.034010679883067496, 0.017629788562771864, 0.08187027327949181, 0.024301560733874794, 0.04738427378470078, 0.02384719751717057, 0.048447426306665875, 0.04018540792458225, 0.030533489807567094, 0.0027636132290354, 0.056504871681681834, 0.024373801388719585, 0.02698674565181136, 0.025774822206585668, 0.04418844859173987, 0.06399280406185426, 0.03582167235435918, 0.03707852170919068, 0.12089413474313915, 0.0216865180482273, 0.04054627352161333, 0.06968093555769883, 0.003598839443839097, 0.034700246396823786, 0.012181184301880421, 0.020927367768308613, 0.045933790679555386, 0.058122274931520224, 0.0680496875429526, 0.042874698774539866, 0.0670280544727575, 0.035253628811915405, 0.014731552528246539, 0.04949921654770151, 0.07682853756705299, 0.05697917455108836, 0.07869020017096773, 0.005536862317967461, 0.03885951286065392, 0.06783967459341511, 0.030792957622907124, 0.02857054631022038, 0.03236916796595324, 0.074221216927981, 0.0501701922621578, 0.01788412257155869, 0.03346027348015923, 0.045444073402904905, 0.07814949363819323, 0.049766207885113545, 0.04452188812138047, 0.041613478169892915, 0.028443986011552624, 0.05117133092426229, 0.05266200503683649, 0.03629960061516613, 0.03568112813809421, 0.04919774873997085, 0.03116691099421587, 0.05218507125391625, 0.041575495051802136, 0.03938510184525512, 0.17959846125449985, 0.16897768975468352, 0.1505867062951438, 0.1436568726785481, 0.10041983885457739, 0.22730402561137453, 0.12905437499284744, 0.07325344893615693, 0.15919232420856133, 0.13393381785135716, 0.12483784812502563, 0.15601247374434024, 0.09514135803328827, 0.12893917883047834, 0.10579095454886556, 0.09383689990499988, 0.06992905036895536, 0.11359881566022523, 0.09040219592861831, 0.11253453136305325, 0.16144652356160805, 0.20020790223497897, 0.1297642244026065, 0.15011302311904728, 0.09251642622984946, 0.11735125532140955, 0.18565025995485485, 0.14999951905338094, 0.11506350347190164, 0.11731435573892668, 0.1905037128017284, 0.22503041167510673, 0.08604503949754871, 0.17778011038899422, 0.16377535328501835, 0.10292430524714291, 0.10020424495451152, 0.11817069025710225, 0.09320657161879353, 0.14501715515507385, 0.16793765884358436, 0.18617531459312886, 0.1259027112973854, 0.19629066868219525, 0.06873477890621871, 0.08549507096176967, 0.17336449498543516, 0.2262022628565319, 0.23313748446526006, 0.12793244066415355, 0.0822314913966693, 0.14777763281017542, 0.16854725894518197, 0.2112305021728389, 0.10586136209894903, 0.17831030068919063, 0.19607789494330063, 0.18605109391501173, 0.22505528846522793, 0.11318523160298355, 0.2033251748071052, 0.10220955024124123, 0.11461286398116499, 0.11203621630556881, 0.10047771895187907, 0.13396855036262423, 0.13848741335095838, 0.17816313280491158, 0.1259959102026187, 0.10574414729489945, 0.13052543043158948, 0.14617866079788655, 0.12489166867453605, 0.2121947449631989, 0.10641226574080065, 0.11309771754895337, 0.11558458019862883, 0.12009246682282537, 0.09171461730147712, 0.13112294836901128, 0.2545484300935641, 0.12597636203281581, 0.17117668816354126, 0.10329508222639561, 0.11395787412766367, 0.1082621949899476, 0.11219606007216498, 0.1405128085752949, 0.24395587504841387, 0.12186807740363292, 0.3686116891913116, 0.1917324124951847, 0.1509507148875855, 0.19308963732328266, 0.16559092851821333, 0.13138258131220937, 0.18006677128141746, 0.1648416562238708, 0.0988504414272029, 0.17911527858814225, 0.20779364596819505, 0.1313759761978872, 0.08082365209702402, 0.1432005112292245, 0.19283896952401847, 0.1645350008038804, 0.26646966696716845, 0.23414860130287707, 0.08527489801053889, 0.2502418658696115, 0.14376194594660774, 0.12041944966767915, 0.2393732764176093, 0.1913600176339969, 0.2207685395842418, 0.0775296296342276, 0.13047799235209823, 0.1261519393301569, 0.1635878422530368, 0.10600876004900783, 0.11496618564706296, 0.11203747795661911, 0.12029395991703495, 0.30973892484325916, 0.11546309804543853, 0.11768375232350081, 0.15834602352697402, 0.06815460496000014, 0.0771070433256682, 0.13793387508485466, 0.11821634718216956, 0.1944958884268999, 0.25294657854828984, 0.17778129782527685, 0.10089447197970003, 0.15632709983037785, 0.15740408969577402, 0.10383702072431333, 0.1628072067978792, 0.07246036766446196, 0.13782339898170903, 0.1411106382147409, 0.2561499550938606, 0.11083467179560103, 0.19562741130357608, 0.16878804133739322, 0.09605707920854911, 0.1480326644377783, 0.2184124878840521, 0.1637323384056799, 0.16514740622369573, 0.10358174418797716, 0.09154215702437796, 0.1256633538287133, 0.10592074133455753, 0.08786295249592513, 0.09250899733160622, 0.20507438719505444, 0.11483429858344607, 0.09618491414585151, 0.17437917413190007, 0.1463681904715486, 0.20831018075114116, 0.09650804524426349, 0.14706969814142212, 0.16688184987287968, 0.13915035902755335, 0.11832063377369195, 0.09465484312386252, 0.15777776105096564, 0.09915350485243835, 0.15487676515476778, 0.10365658235969022, 0.13670513086253777, 0.16114852158352733, 0.10986800960381515], [0.027466104402265046, 0.03944752759707626, 0.034866966161644086, 0.038750368912587874, 0.04198860413453076, 0.03074916163313901, 0.05368715959775727, 0.04308718678657897, 0.017668027721811086, 0.09273704446968623, 0.02336421708605485, 0.00672816426231293, 0.04440937111212406, 0.03268917462264653, 0.05864459104486741, 0.03945463366108015, 0.0457163191458676, 0.040106035230564885, 0.04840389192395378, 0.005990934241708601, 0.013880705264455173, 0.020452022181416396, 0.08211513006244786, 0.10620175555231981, 0.02381007157964632, 0.032384920050390065, 0.028855757373094093, 0.04083205232745968, 0.02576143200712977, 0.02090365615003975, 0.01771142295183381, 0.024984850533655845, 0.018403312387818005, 0.0024261561293315026, 0.040966740998555906, 0.03059056467463961, 0.10156536605791189, 0.04504020034801215, 0.02454469202348264, 0.009444194693060126, 0.016745454668125603, 0.040445430495310575, 0.02141103283065604, 0.01963616810826352, 0.03496111501590349, 0.01050427750669769, 0.028301812781137414, 0.049005183682311326, 0.06484754296252504, 0.014623368733737152, 0.043600849458016455, 0.021202376155997626, 0.012294865555304568, 0.039586034617968835, 0.003758854368243192, 0.013526341808756115, 0.06815929533331655, 0.02401442194241099, 0.05377980931370985, 0.034194647159893066, 0.017671905443421565, 0.017511404876131564, 0.04825598189199809, 0.06672773699392565, 0.1172440595109947, 0.018320264207432047, 0.028980352835787926, 0.09071045438759029, 0.04320082443882711, 0.02711498691496672, 0.024960485825431533, 0.08425656007602811, 0.061740935052512214, 0.06209674662386533, 0.033044318261090666, 0.08600061453762464, 0.0010732837654359173, 0.0576794650987722, 0.016969451535260305, 0.016425596440967638, 0.03739392705028877, 0.03374747720954474, 0.02813289440382505, 0.012109918643545825, 0.0013032094648224302, 0.04864520866249222, 0.12693689408479258, 0.005638460943373502, 0.07777194827212952, 0.05682100432750303, 0.019292121432954445, 0.038306924543576315, 0.051749296981142834, 0.03887352460878901, 0.0419133243849501, 0.011729908419511048, 0.009909129803418182, 0.08905582872102968, 0.02030459640081972, 0.021842331952939276, 0.09000951817142777, 0.09510493342531845, 0.04110698835575022, 0.05642600735882297, 0.05019443080527708, 0.02424547292321222, 0.08917843893868849, 0.04841029294766486, 0.022314096677291673, 0.05455294165585656, 0.026776517479447648, 0.02783324114716379, 0.07139741181163117, 0.02283665213326458, 0.026043457401101477, 0.014905262396496255, 0.03441988526901696, 0.0598317712865537, 0.03266588602855336, 0.06640805688221008, 0.0736017685267143, 0.04531273552856874, 0.008878193912096322, 0.029469550609064754, 0.035026212499360554, 0.05033210662077181, 0.0098744891329261, 0.01192942276247777, 0.023943474479892757, 0.02653077939612558, 0.04404359991895035, 0.009211874639731832, 0.05207743386563379, 0.01357227332846378, 0.033453794530942105, 0.06681940707494505, 0.02390759535046527, 0.024250680944533087, 0.009316357900388539, 0.040935663564596325, 0.01468367194320308, 0.008314411225001095, 0.03985077724792063, 0.04570725381199736, 0.022176743696036283, 0.053410115870065056, 0.0392191613354953, 0.026060671516461298, 0.011413452011765912, 0.04064101980475243, 0.04068597168952692, 0.045179557127994485, 0.08027542018680833, 0.0503140056389384, 0.03203888998541515, 0.022696927990182303, 0.024699231289559975, 0.01628848836844554, 0.015693521563662216, 0.05487876675033476, 0.022679199937556405, 0.07295871982933022, 0.013474675342877163, 0.045344922473304905, 0.03385884760064073, 0.020410935030668043, 0.030561320345441345, 0.05426165982498787, 0.05795200770080555, 0.05444564936624374, 0.020362175928312354, 0.012335898900346365, 0.08783489931374788, 0.052570709740393795, 0.020039421469846275, 0.05147240539372433, 0.019385969717404805, 0.003471004970378999, 0.06667784240562469, 0.0028162999160485924, 0.05359825401683338, 0.01722757049719803, 0.03854376613162458, 0.0813251658109948, 0.012810634998459136, 0.0033109847117884783, 0.023303193993342575, 0.016041123126342427, 0.015182973129412858, 0.05504782799107488, 0.045226861620903946, 0.03693062280945014, 0.031912361228023656, 0.019474450418783817, 0.0375618342513917, 0.0399202571134083, 0.023337297534453683, 0.038150646796566434, 0.03385824275028426, 0.0516061775124399, 0.014645122937508859, 0.045894093200331554, 0.00045713681970482867, 0.03404365350434091, 0.03917403875675518, 0.007036269189484301, 0.044092815442127176, 0.05173402729269583, 0.04572711368382443, 0.06423006125260144, 0.011746299678634387, 0.03186771362379659, 0.04762215066875797, 0.02526295924326405, 0.01563961381179979, 0.019858131490764208, 0.02153647434170125, 0.05595758972049225, 0.019273152138339356, 0.0467426203249488, 0.03009800497238757, 0.021912737647653557, 0.027912910700251814, 0.0367717920744326, 0.04728895233711228, 0.04509668520768173, 0.04247011696861591, 0.053638515528291464, 0.033531337830936536, 0.0757312796486076, 0.008558973931940272, 0.03678492066683248, 0.011288637615507469, 0.06191869797476102, 0.057112868744297884, 0.008016653227969073, 0.00765627744840458, 0.038188574253581464, 0.0672540013329126, 0.047724708056193776, 0.11498594903969206, 0.04259548426489346, 0.044451202265918255, 0.03661092043330427, 0.028822364438383374, 0.013620565805467777, 0.04229314443364274, 0.1234827161533758, 0.024904785786930006, 0.030054784147068858, 0.041252278606407344, 0.009296773550886428, 0.029601671449199785, 0.03921876799722668, 0.014375017362908693, 0.040063677151920274, 0.029164689331082627, 0.04268977041647304, 0.01181822770377039, 0.037210943119134754, 0.055255566257983446, 0.03090908703597961, 0.06578020736924373, 0.05295293805829715, 0.03835819581581745, 0.02191757273976691, 0.03060542618186446, 0.06453918060287833, 0.05003041616873816, 0.03566739098459948, 0.05814552270749118, 0.03108331176918, 0.03475710233033169, 0.03331512423756067, 0.048761035650386475, 0.013733934429183137, 0.03327247301058378, 0.03866148559609428, 0.007165452980189002, 0.023406048239849042, 0.02250576188089326, 0.06695801057503559, 0.007735280460110516, 0.08010763544007204, 0.10811981395818293, 0.0134864856954664, 0.03683747214381583, 0.041463397355983034, 0.06247389494092204, 0.014905626048857812, 0.04153722991759423, 0.04701137797383126, 0.04188713770417962, 0.06877207924844697, 0.01931044134835247, 0.040793134103296325, 0.032319084129994735, 0.04918532518786378, 0.039758342754794285, 0.0709610735066235, 0.027526222074811812, 0.08370468422072008, 0.042667298184824176, 0.03124743772787042, 0.038906947229406796, 0.05677537337760441, 0.06370106581016444, 0.027912515506614, 0.058763494234881364, 0.03901002783095464, 0.008344784546352457, 0.02364926302107051, 0.023654430224269163, 0.047483279995503835, 0.05823207939101849, 0.056406180883641355, 0.04570004755805712, 0.0178761092320201, 0.04134965580306016, 0.026063868317578454, 0.05669031583238393, 0.008461326779070077, 0.037058146044728346, 0.0337601456703851, 0.04216295688820537, 0.004115062756682164, 0.04816549924726132, 0.04664212239731569, 0.08570391131797805, 0.05213810443819966, 0.048321320573450066, 0.06318971863947809, 0.028262143132451456, 0.07023562415270135, 0.03589785752410535, 0.05441605251689907, 0.021883068438910414, 0.059588543517747894, 0.027665014822559897, 0.04310686112148687, 0.024301317680510692, 0.0827758270315826, 0.0671534551656805, 0.098059200681746, 0.051888865273213014, 0.02778563979518367, 0.03868916399369482, 0.011889202996826498, 0.09209762487444095, 0.04680419631768018, 0.04106015512661543, 0.016139298131747637, 0.12177493787021376, 0.09122267729253508, 0.12140755992732011, 0.13776870269794017, 0.1484936272026971, 0.12436216115020216, 0.08791514774202369, 0.14112191885942593, 0.1289691319107078, 0.20682630100054666, 0.15196693770121783, 0.05940338880463969, 0.11277704295935109, 0.13708242389839143, 0.1836376148276031, 0.2426597141311504, 0.20079207635717466, 0.22079896763898432, 0.10595162952085957, 0.09406326978933066, 0.16370823344914243, 0.12824838777305558, 0.19256689818575978, 0.1962426517275162, 0.16837533301441, 0.1267307106172666, 0.17641307436861098, 0.11356508504832163, 0.07168100128183141, 0.13373775727814063, 0.08706810491275974, 0.14057485212106258, 0.14141193532850593, 0.17749352264218032, 0.10819592120242305, 0.14876942412229255, 0.2064570676884614, 0.17277735227253288, 0.15679244126658887, 0.0939999200636521, 0.10823157397680916, 0.11316498581436463, 0.1143747904279735, 0.08117824283544905, 0.14869375474518165, 0.09430906167835928, 0.12522340868599713, 0.1454912094050087, 0.09271476519643329, 0.2121933942544274, 0.1599226420512423, 0.24526060034986585, 0.12556234752992168, 0.2508826955454424, 0.12323361428570934, 0.10742996542830952, 0.1495927182259038, 0.17323599953670055, 0.18171732255723327, 0.13008256122702733, 0.09128381541813724, 0.1118621084606275, 0.18036086956271902, 0.21102559519931674, 0.2525539230555296, 0.12616854859516025, 0.1561260223388672, 0.180098342243582, 0.11361624128767289, 0.11534974983078428, 0.14198209770256653, 0.24162006913684309, 0.14587092184228823, 0.13792694342555478, 0.13107758830301464, 0.20230843249009922, 0.2572784945368767, 0.09846636516158469, 0.1172701756877359, 0.11463330272817984, 0.1550271242740564, 0.08371148229343817, 0.10232048647594638, 0.1257862980128266, 0.10105585199198686, 0.12103453424060717, 0.2162341508665122, 0.19527554424712434, 0.10817742688232102, 0.18619464011862874, 0.17162593983812258, 0.13925184030085802, 0.13444174372125417, 0.21172383741941303, 0.11482784189865924, 0.1689998057554476, 0.06867506570415571, 0.14173882169416174, 0.12111994801671244, 0.15932574751786888, 0.16561607248149812, 0.13695349800400436, 0.11477037740405649, 0.12022643189993687, 0.12446060703950934, 0.12065263988915831, 0.16379504988435656, 0.1497939886758104, 0.14068374002818018, 0.09191648146952502, 0.12209905602503568, 0.0917188920720946, 0.18121868837624788, 0.09218925042659976, 0.121251909295097, 0.15354474366176873, 0.17037460464052856, 0.1939963933546096, 0.14464936160948128, 0.18720026506343856, 0.1309967238921672, 0.16787380445748568, 0.08513104752637446, 0.186306971590966, 0.15924065286526456, 0.22749845345970243, 0.13201520283473656, 0.14241687749745324, 0.08486955921398476, 0.12991468742256984, 0.2864459966076538, 0.11778586442233063, 0.15551242948276922, 0.21589780953945592, 0.11964760124101304, 0.22859312128275633, 0.09658237133407965, 0.11132466737763025, 0.1648199706687592, 0.18096876272466034, 0.10955438541714102, 0.09025073843076825, 0.09443528615520336, 0.14542282791808248, 0.1583699503680691, 0.1763969103922136, 0.0769436001428403, 0.09590093875885941, 0.09899049953673966, 0.1342459354782477, 0.1269375768606551, 0.13934733986388892, 0.18914163432782516, 0.18249518238008022, 0.10200669901678339, 0.1245735099655576, 0.2846861269790679, 0.15340694168116897, 0.08822097937809303, 0.15961003460688516, 0.12759290810208768, 0.1274064212338999, 0.129514773725532, 0.09861306549282745, 0.09418055138667114, 0.20084321033209562, 0.20109745528316125, 0.150508365186397, 0.2632545348023996, 0.10565971315372735, 0.1234085533360485, 0.0808863116253633, 0.15361640544142574, 0.12255301291588694, 0.1260587849537842, 0.1352621434489265], [0.0036472304873313988, 0.04848304939514492, 0.028185623996250797, 0.032526807553949766, 0.01218992216308834, 0.07114156382158399, 0.026183788249909412, 0.039093152081477456, 0.05938366251939442, 0.016121737062348984, 0.02380682653893018, 0.042942887303070165, 0.01269001280888915, 0.011128520181955537, 0.04143705482420046, 0.03147124720271677, 0.047707423436804675, 0.06803382042562589, 0.04931895629852079, 0.01540524357551476, 0.013848998860339634, 0.04156527567829471, 0.02973285532789305, 0.023198590133688413, 0.006929021892574383, 0.04885011934675276, 0.03842756064841524, 0.06433500835555606, 0.14624107541749254, 0.014416265930776717, 0.026854925381485373, 0.04690905065217521, 0.021850972407264635, 0.051617016579257324, 0.015054456343932543, 0.03577238632715307, 0.04851224919548258, 0.08679559570737183, 0.03299585972854402, 0.023152298672357574, 0.0271220298964181, 0.012138336405769223, 0.06033552999724634, 0.023775699010002427, 0.0505791898467578, 0.023138804572226945, 0.039438491949113086, 0.07382427924312651, 0.015453574087587185, 0.062257781537482515, 0.09027947438880801, 0.0366713127004914, 0.03654419393569697, 0.025337216684420127, 0.07805586428730749, 0.04177669499767944, 0.050465656095184386, 0.03474032608210109, 0.0716639838356059, 0.03625033685239032, 0.07269002526300028, 0.022578045209229458, 0.02739194158493774, 0.02482356514519779, 0.035711352102225646, 0.037530485933530144, 0.08575881540309638, 0.0035888301908926223, 0.05527624620299321, 0.044836120869149454, 0.06678848920273595, 0.06711798792821355, 0.060335867674439214, 0.0256211531086592, 0.05966929289570544, 0.06028455558407586, 0.04617107013473287, 0.03337645161082037, 0.022967893528402783, 0.03994339727796614, 0.05467142182169482, 0.08041071370826103, 0.053002027416368946, 0.0252864741923986, 0.0584466899454128, 0.05438405481982045, 0.04980858451745007, 0.0591036761761643, 0.03181741456501186, 0.008219990559155121, 0.020974067410861608, 0.05703419737983495, 0.057779766357271, 0.013575403336290037, 0.03613548578869086, 0.01472084055421874, 0.05948752608674113, 0.028514703408291098, 0.020366070348245557, 0.08116331082419492, 0.04437974828761071, 0.020525593135971576, 0.016958523410721682, 0.08369135524844751, 0.05894296780752484, 0.05338195136573631, 0.027059481690230314, 0.02902582607930526, 0.03336762747494504, 0.03929763232008554, 0.06106098306190688, 0.031371509976452217, 0.012955317615706008, 0.03799670681473799, 0.02036364166997373, 0.04376332784886472, 0.017912424373207614, 0.052372478385223076, 0.047459961715503596, 0.019384396364330314, 0.022388448742276523, 0.024230837771028746, 0.05446809562272392, 0.025949477385438513, 0.05143080801644828, 0.038514922562171705, 0.0988228186906781, 0.09581934704328887, 0.039864607169874944, 0.006501710886368528, 0.02214517087850254, 0.06757912138709798, 0.017325003354926594, 0.03479857725324109, 0.07757304527331144, 0.08840301336022094, 0.026419965615787078, 0.05239169629930984, 0.043650803418131545, 0.0326853302976815, 0.025476784976490308, 0.03937434441468213, 0.04919842780509498, 0.016822667712403927, 0.025607636744098272, 0.035046847915509716, 0.008261189959739568, 0.048055839506560005, 0.05716767263947986, 0.016757594348746352, 0.0347469200642081, 0.03005418857355835, 0.04479597810131963, 0.016737378246034496, 0.06519284201203845, 0.008900450920918956, 0.03335018329380546, 0.03149665462842677, 0.03797811230469961, 0.0453251590806758, 0.0345082936109975, 0.011461045942269266, 0.06019996930263005, 0.022407670367101673, 0.022198896804184187, 0.061460562792490236, 0.02424200894893147, 0.023247649805853143, 0.02948117264168104, 0.035057460627285764, 0.052811321438639425, 0.037936889712000266, 0.09866895663435571, 0.04860845750954468, 0.09887700289255008, 0.05189108800550457, 0.05052933978731744, 0.0468634827848291, 0.013975777164887404, 0.046952559059718624, 0.02194125838286709, 0.07621249562362209, 0.010540564817347331, 0.07930242747534066, 0.02061711849819403, 0.01320468851190526, 0.06091763723816257, 0.03848885833576787, 0.055735676432959735, 0.1041891920613125, 0.04739686432003509, 0.010891253714362392, 0.03872872417559847, 0.0972497476323042, 0.03201366438588593, 0.07243686384754255, 0.015210859328362858, 0.05303196194290649, 0.059777735514217056, 0.035797994132735766, 0.11141997398226522, 0.06480538155301474, 0.02105244933773065, 0.018155904472223483, 0.029914881888544187, 0.06519746559206396, 0.04952560360834468, 0.009878574655886041, 0.014505801409541164, 0.035092716352664866, 0.004271708330634283, 0.058241293154424056, 0.0100562587249442, 0.06652573923929594, 0.056336545167141594, 0.025685322907520458, 0.01527592898128205, 0.016780341175035574, 0.03068244255700847, 0.08685825523571111, 0.022156859704409726, 0.014302116196631687, 0.022755091958970297, 0.0455112674535485, 0.0389916893618647, 0.010971568935929099, 0.024374638160225004, 0.041718952197697945, 0.02279628115502419, 0.00750175024222699, 0.05264444582280703, 0.020224331274221186, 0.020497224541031756, 0.005970818328933092, 0.08793572007562034, 0.016399120322603267, 0.050527039129519835, 0.02602951615699567, 0.02427150004223222, 0.04857942469243426, 0.02254061499115778, 0.01306738005951047, 0.05557988850341644, 0.055945281201275066, 0.029454102805175353, 0.0375198286928935, 0.06349693067022599, 0.044333471669233404, 0.031971770149539225, 0.02105266827129526, 0.06897363171447068, 0.02110233279381646, 0.10091511852806434, 0.0886141395312734, 0.06723022292135283, 0.034359081109869294, 0.023034733203530777, 0.0933937264198903, 0.021924602733633947, 0.016604123775323387, 0.03966207506891806, 0.026202403169008903, 0.03288225176220294, 0.07213209348265082, 0.03901197596860584, 0.017522746747999918, 0.07141324924305081, 0.035947703872807324, 0.019749889252125286, 0.0770390774414409, 0.015941192941681948, 0.04246922268066555, 0.030884119332768023, 0.04169424981228076, 0.03215048673155252, 0.047812771299504675, 0.045238817619974725, 0.013828230785293272, 0.048229880558210425, 0.054944869843893684, 0.03052738193218829, 0.06830277474364266, 0.036600675084628165, 0.009903668524202658, 0.020694537488452625, 0.03326048361486755, 0.09972466170438565, 0.024034163070609793, 0.061317332001635805, 0.026721613394329324, 0.03743992907402571, 0.023755193469696678, 0.007403996869470575, 0.04832777725823689, 0.00874553315952653, 0.04117034550290555, 0.05842120088345837, 0.024041578981268685, 0.02863626905309502, 0.1040662478771992, 0.007257640245370567, 0.07994501604116522, 0.04093942996405531, 0.05750146468926687, 0.011236915488552768, 0.013617200165754184, 0.023618308041477576, 0.024496320693288, 0.06348671129671857, 0.04054223623825237, 0.08346460686880164, 0.03303245503047947, 0.07409531157463789, 0.031138731646933593, 0.03525175488903187, 0.05464018111524638, 0.03192623196810018, 0.03292495122877881, 0.027699381826096214, 0.015087677656993037, 0.02317004527867539, 0.015517658539465629, 0.04422645397426095, 0.021760218878625892, 0.07713051745668054, 0.048000768438214436, 0.03002606117661344, 0.010066492941405158, 0.02207282817835221, 0.023315428297792096, 0.03449371040915139, 0.017587619731784798, 0.05846993772138376, 0.02412866258964641, 0.009801112064451445, 0.013255328958621249, 0.05702703936549369, 0.03681713729747571, 0.05858979086042382, 0.07352321219514124, 0.023685826781729702, 0.028406991805240978, 0.10564742318820208, 0.07438060798449442, 0.03038163711607922, 0.05065241755801253, 0.08176779010682367, 0.028557734985952266, 0.02265504859678913, 0.02153771372832125, 0.026811216594069265, 0.048058800675789826, 0.09939697381923907, 0.12341457957518287, 0.15513035701587796, 0.12107841001125053, 0.1384601171594113, 0.20540572644677013, 0.07759116851957515, 0.15267491689883173, 0.10342741457861848, 0.07467893650755286, 0.1371886846027337, 0.12220420350786299, 0.16711610136553645, 0.30105909216217697, 0.13299261132488027, 0.05988268261717167, 0.15602823696099222, 0.23758272640407085, 0.184841793961823, 0.1241958755417727, 0.10965350666083395, 0.13076282863039523, 0.11722254464984871, 0.12081036853487603, 0.12339454900939018, 0.10174927767366171, 0.12476201547542587, 0.08286159703857265, 0.2361730020493269, 0.1700524680200033, 0.10015843217843212, 0.11438502464443445, 0.09079036142793484, 0.1400063670007512, 0.09111505845794454, 0.09884434839477763, 0.09844119151239283, 0.14011258317623287, 0.17247238894924521, 0.11515214559040032, 0.12669142131926492, 0.07391991981421597, 0.18849737592972815, 0.18583563360152766, 0.1561307572410442, 0.06089257120038383, 0.06694052557577379, 0.17172644147649407, 0.11399963477742858, 0.15730796672869474, 0.3019369934918359, 0.15803255519131199, 0.1036475355795119, 0.13267860864289105, 0.14002405980136245, 0.24159829452401027, 0.1561718573793769, 0.10062710585771129, 0.1373669336317107, 0.14266524463891983, 0.23732382076559588, 0.1080551506311167, 0.11315685187582858, 0.1861985883442685, 0.19663265033159405, 0.1234950209618546, 0.20478382153669372, 0.1804965193150565, 0.1288947687135078, 0.20023965131258592, 0.1903746830066666, 0.13456237240461633, 0.12137645651819184, 0.09028363041579723, 0.17773451283574104, 0.216217155684717, 0.19029677234357223, 0.1362668926594779, 0.1575786725152284, 0.13041471684118733, 0.16977825929643586, 0.1308600202901289, 0.17920313403010368, 0.11741590380552225, 0.16344487492460757, 0.20959017769200727, 0.18883647804614156, 0.19259176013292745, 0.12724135274766013, 0.11588017019676045, 0.18861647578887641, 0.21077369543490931, 0.1477675692876801, 0.11689809995004907, 0.19479715585475788, 0.11020385369192809, 0.18749451177427545, 0.12163013743702322, 0.0907819380518049, 0.12407960326527245, 0.11541548927198164, 0.10395170480478555, 0.11181446257978678, 0.10982128398609348, 0.20449313713470474, 0.20570687513099983, 0.10987564630340785, 0.1613827730761841, 0.17186240293085575, 0.17592079297173768, 0.1596586749656126, 0.07819086094968952, 0.13395958521869034, 0.09899087803205475, 0.14029718498932198, 0.168350322637707, 0.11544950190000236, 0.17408892017556354, 0.12479036551667377, 0.19587833143305033, 0.13198964326875284, 0.06639529194217175, 0.24339386145584285, 0.22737303050234914, 0.15284871304174885, 0.12342533329501748, 0.2521150466054678, 0.23436961288098246, 0.10109612834639847, 0.11170144833158702, 0.17896169854793698, 0.13186809432227165, 0.15629863104550168, 0.17190071259392425, 0.1760136356460862, 0.16164982749614865, 0.14654614264145494, 0.13641849858686328, 0.11493008758407086, 0.19871766970027238, 0.1274349939194508, 0.09574789306498133, 0.183016303635668, 0.1192859304137528, 0.1246184841147624, 0.12651936180191115, 0.12276287001441233, 0.18643883639015257, 0.1552397050545551, 0.13900317630032077, 0.10915215621935204, 0.13666731101693586, 0.07096738918335177, 0.1321869358071126, 0.15883333253441378, 0.09476280334638432, 0.10371880402090028, 0.09456006344407797, 0.17205904237926006, 0.1535362089634873, 0.16464526910567656, 0.13841771084116772, 0.1506774709559977, 0.16203899489482865, 0.14529792446410283, 0.13745094474870712, 0.22443451161962003, 0.1221700944006443, 0.10719707948737778, 0.09592595655703917, 0.16458076162962243, 0.2003557825810276, 0.17692275170702487, 0.11483726717415266, 0.24831634887959808, 0.15737648180220276], [0.04331612821260933, 0.010334639246138977, 0.04230549748172052, 0.056333999600610696, 0.03254309398471378, 0.06582141882972792, 0.09730672230944037, 0.09455633044126444, 0.039651447514188476, 0.027192535781068727, 0.04909640476398636, 0.02469786944857333, 0.060884121849085204, 0.030310032852867153, 0.0055325676021311665, 0.03761268992093392, 0.031163523090071976, 0.03317411246825941, 0.01050394539561239, 0.08178709336789325, 0.06455251699662767, 0.03727339855686296, 0.055755562279955484, 0.062018327589612454, 0.0643854595546145, 0.07177863823017105, 0.13436102773994207, 0.016296442336170003, 0.04177222726866603, 0.033985294721787795, 0.023497154288634192, 0.012618534710782114, 0.05360019102226943, 0.040360833081649616, 0.03507989946228918, 0.060700592439388856, 0.00943770461162785, 0.07533541807788424, 0.03741740860277787, 0.040117672106134705, 0.0461464308318682, 0.05498625941982027, 0.03308242383354809, 0.011788008378061932, 0.007091383859005873, 0.05254139861790463, 0.03660088659671601, 0.031907140219118446, 0.00866522999785957, 0.016862691736605484, 0.026494141420698725, 0.04209608196106274, 0.0316114463203121, 0.06816266468376853, 0.022682656490360387, 0.022872570225445088, 0.050116839265683666, 0.06460121672716923, 0.013358099713514093, 0.05017971030611079, 0.02024499266553903, 0.0662362645380199, 0.02061872524791397, 0.05581787299888674, 0.007811393734300509, 0.05060595169197768, 0.019434864261711482, 0.06721471203491092, 0.024624073994345963, 0.013089417207083898, 0.03939616355637554, 0.01813655111618573, 0.037904906857875176, 0.0642652167880442, 0.01949685400177259, 0.0460542523796903, 0.07184776186477393, 0.030602654260292184, 0.04634938966773916, 0.05110919832077343, 0.017568409239174798, 0.005280261975713074, 0.039720897693769075, 0.05622275908535812, 0.035557493756641634, 0.013536901642510202, 0.0166451534096268, 0.039333730383077636, 0.06670772127108648, 0.02983545167808188, 0.04861699962930288, 0.05095306900329888, 0.037921523544355296, 0.03905302786733955, 0.06021563232934568, 0.009136394510278478, 0.055490300146630034, 0.017984789337788243, 0.06901949644088745, 0.026715815365605522, 0.02354153843043605, 0.008362148946616799, 0.04697509066318162, 0.017123925863415934, 0.031990646675694734, 0.030756878113606945, 0.10759782438981347, 0.02170172650949098, 0.03281129873357713, 0.03687482814711984, 0.06715988216456026, 0.039190592360682786, 0.05618931420031004, 0.03249263536417857, 0.058796453013201244, 0.052157927202642895, 0.036106323095737025, 0.010499051859369501, 0.03143187255773228, 0.022098083463788498, 0.020883404795313254, 0.010812715008796658, 0.026247163950756658, 0.013473431317834184, 0.04706096828158479, 0.03906198930053506, 0.07766577662550844, 0.049678144641802646, 0.058624111479730345, 0.01612624375411542, 0.049265966954408213, 0.03878784365952015, 0.009343310848635156, 0.032629123743390664, 0.07296520620002411, 0.07742875692201778, 0.06307151677901857, 0.022288980544544756, 0.044210097039467655, 0.061049739524605684, 0.042906611124635674, 0.034033011106657796, 0.02129518357833149, 0.009838689784373855, 0.02772699714114424, 0.008495923848386155, 0.04086127439222764, 0.022978945962677244, 0.029549856553785503, 0.017139141746156383, 0.025568022756488062, 0.033243870639125817, 0.05055324065324385, 0.029999778016644996, 0.023431427835021168, 0.0439946330152452, 0.0792760589683894, 0.034426627680659294, 0.028245960602362175, 0.03988371005107183, 0.004498748930927832, 0.04501805095060263, 0.018971595272887498, 0.05758277438872028, 0.010085650555993197, 0.031766262036398984, 0.020400220273586456, 0.06398289639037102, 0.08905968046747148, 0.02764235334325349, 0.048132852170965634, 0.005332395066943718, 0.010340234111936297, 0.035874179302481934, 0.031037152039061766, 0.05381597416999284, 0.07207954942714423, 0.02904158001911128, 0.08941663865698501, 0.004160867647442501, 0.04930293704092037, 0.030255902456701733, 0.06299520915490575, 0.03491814466542564, 0.03268611697421875, 0.07264263913384639, 0.045155296320444904, 0.061557208973681554, 0.013485268573276699, 0.04148929459915962, 0.034530966222519055, 0.028649564628722146, 0.05332055348844733, 0.013392980654316489, 0.04435316826857161, 0.04377047473099083, 0.054906229925109074, 0.042844526760745794, 0.057510767510393634, 0.04412378155393526, 0.030414059692702722, 0.01855665679613594, 0.09909442989737727, 0.05690573903848417, 0.03533697199600283, 0.055625667882850394, 0.02264400915009901, 0.02906964062276529, 0.008766198261582758, 0.013934569415141596, 0.026571577109280042, 0.07722620997810736, 0.028792474440706428, 0.043235004050075077, 0.05091500424896367, 0.04731840446766, 0.03612373388023116, 0.03872115798003506, 0.04799050453584641, 0.04208459722576663, 0.09748039228725247, 0.012066004837834043, 0.04846093710511923, 0.013193010818213224, 0.03624154611316044, 0.019991244953416754, 0.009587123058736324, 0.033561068266863, 0.029733630872215144, 0.10357752136769705, 0.0032420705019831075, 0.04776460962602869, 0.12046284304233268, 0.03860610282572452, 0.020144194168096874, 0.013186066171329003, 0.03865863945975434, 0.03241237580368761, 0.03726622941030655, 0.00572146505874116, 0.11845698856632225, 0.02239498706330778, 0.04033020093629602, 0.02339219419809524, 0.042337413542554714, 0.025953837503038812, 0.02022280987148406, 0.052996632002759725, 0.08817673995508812, 0.05673728264810052, 0.055839773776824586, 0.0333888825844042, 0.03794727235799655, 0.0910284646670334, 0.03924362623365596, 0.08047150302445516, 0.020923697848047595, 0.03461184547632001, 0.02967273579997709, 0.030278129779617302, 0.02126307455910137, 0.06319045336567797, 0.0010571927282398974, 0.03329156475956552, 0.04049144365126267, 0.02133688671165146, 0.09052735171280801, 0.06543764684465714, 0.05473523538967129, 0.010856208573386539, 0.05432008911157027, 0.023702380385657307, 0.032683129829820246, 0.044012485377606936, 0.012378205956338206, 0.04201532145089004, 0.013584725638793316, 0.05630760882922914, 0.027144771156599745, 0.06804097472922876, 0.05562687016208656, 0.029407169386104215, 0.05210138297115918, 0.07513688615290448, 0.07372394829872064, 0.052304872442618944, 0.03707014286192134, 0.028254363569431007, 0.021458522860484663, 0.04366932000266388, 0.019885635483660735, 0.02815210860717343, 0.03530318943376187, 0.014069916742300848, 0.03846758096187841, 0.04599373023665976, 0.0954812319832854, 0.04569871540297754, 0.010964132616209099, 0.01800290516257519, 0.06404754487448372, 0.04230911916238256, 0.027178626078239176, 0.05086616351036355, 0.06628611459746026, 0.023070423085300718, 0.03486484733002726, 0.045285502419574186, 0.014076080278755398, 0.044646038295468315, 0.04292822617571801, 0.08072240088949911, 0.013172465387469856, 0.02901127256336622, 0.03595826834498439, 0.042045745794894174, 0.025947755602828693, 0.013151805851521203, 0.0588440469437046, 0.019916837227356154, 0.10085081885335967, 0.04447383034857921, 0.06339795043459162, 0.05801435181638226, 0.026792141543410253, 0.015702416203566827, 0.03421929017349612, 0.002992666672980704, 0.07781994296237826, 0.050244002559338696, 0.05886354316317011, 0.11553459655260667, 0.0537926558899926, 0.03096531771006994, 0.048988233029376715, 0.053792143808095716, 0.05241789411229547, 0.05920605173741933, 0.032833908262546174, 0.03335029832669534, 0.01408053502018447, 0.0234999855820206, 0.027501228396431543, 0.02202179624873679, 0.03806224216532428, 0.05033101566368714, 0.021887877555855084, 0.06821891947765835, 0.030344242150022183, 0.05171764067199547, 0.04817233813810162, 0.08737243741052225, 0.19092477770755067, 0.0838427385315299, 0.1363853394286707, 0.1752943906467408, 0.11839714919915423, 0.14264458324760199, 0.1533659009146504, 0.15809413860552013, 0.07977998466230929, 0.1545054538291879, 0.224740513949655, 0.1930707274004817, 0.14758932025870308, 0.09505831912974827, 0.12898321787361056, 0.12152673400123604, 0.09869505054666661, 0.11059097276302055, 0.1641397032653913, 0.1381055635283701, 0.09375671827001497, 0.08507802107487805, 0.1539106373093091, 0.1980675186496228, 0.21947699482552707, 0.16552878107177094, 0.20497335121035576, 0.26542596984654665, 0.1262880937429145, 0.15038887941045687, 0.0875613436801359, 0.13889955764170736, 0.14579341193893924, 0.12370671116514131, 0.11518866667756811, 0.17843214649474248, 0.07165765331592411, 0.10088152892421931, 0.1219815740478225, 0.13278090627864003, 0.07386445911834016, 0.21159413969144225, 0.16708018141798675, 0.1166716855368577, 0.17019540566252545, 0.07071148924296722, 0.09760964472661726, 0.09965937497327104, 0.12686576665146276, 0.20350153878098354, 0.0719255834701471, 0.1400059217121452, 0.12361089990008622, 0.20663497532950714, 0.12269243277842179, 0.17763929528882727, 0.38444149133283645, 0.154776812705677, 0.17926309956237674, 0.09662479249527678, 0.17157283175038174, 0.13288222427945584, 0.05241350801952649, 0.19951797206886113, 0.15981418458977714, 0.11548144393600523, 0.08754077876801603, 0.09922907032887451, 0.15452074207132682, 0.17111578752519563, 0.15135321125853807, 0.18332892592297867, 0.21826769487233832, 0.12027437463984825, 0.12095081998268142, 0.21164537756703794, 0.1561095318174921, 0.13172533479519188, 0.1465172879397869, 0.16969188814982772, 0.1321175301563926, 0.07967387980897911, 0.10184810947976075, 0.08270152320619673, 0.15835188649361953, 0.21152093424461782, 0.08972280425950885, 0.1886108799953945, 0.10726963926572353, 0.09631548760808073, 0.1712924483581446, 0.1628745492780581, 0.18633354047778994, 0.09814962395466864, 0.21994390961481258, 0.10905024450039491, 0.09724254879984073, 0.14195779978763312, 0.14443188265431672, 0.20890159823466092, 0.2474376163445413, 0.12463374267099425, 0.08066974551184103, 0.25779220915865153, 0.11216490471269935, 0.1429944613482803, 0.2160285017453134, 0.14438389538554475, 0.14062350732274354, 0.12279582137125544, 0.11936372975469567, 0.11821897438494489, 0.15230427350616083, 0.19901191641110927, 0.12091545664588921, 0.14270459330873564, 0.12325731106102467, 0.1322092447662726, 0.17255829996429384, 0.12779156619217247, 0.24589479522546753, 0.19003002962563187, 0.08291896505397744, 0.1699426450068131, 0.10035962841357104, 0.1345165225211531, 0.22343583317706361, 0.11870410889969207, 0.2128884452395141, 0.1282488479046151, 0.1627085159998387, 0.11295817894279025, 0.11238478822633624, 0.18677792366361246, 0.19451074622338638, 0.12423279738868587, 0.159247154078912, 0.19165589706972241, 0.14871615276206285, 0.14026543591171503, 0.1437757647363469, 0.1496194800711237, 0.15877697383984923, 0.142026923422236, 0.10812821506988257, 0.06413193448679522, 0.1906502721249126, 0.08871059646480717, 0.13540916290367022, 0.15287177899153903, 0.1255148946074769, 0.13436433771857992, 0.1395591488108039, 0.11545647808816284, 0.17513902945211157, 0.2016859783907421, 0.24648888444062322, 0.2408543656929396, 0.14303753559943289, 0.19767435849644244, 0.09125956203206442, 0.1409979208256118, 0.09190813230816275, 0.11135011562146246, 0.1267984983860515, 0.11736453976482153, 0.22031674976460636, 0.13020311569562182, 0.16014350519981235, 0.1505972002632916, 0.1406535494606942, 0.09552298521157354, 0.091503194271354, 0.2224572520935908, 0.17624577943934128, 0.17829556163633242], [0.03619540679210331, 0.08198802985134535, 0.036269450865802355, 0.05412672253441997, 0.07375784960458986, 0.04461258969968185, 0.13901254220400006, 0.011136198627355043, 0.009311939338658703, 0.031725109947728924, 0.021289383694238495, 0.044814041975769214, 0.01220119167555822, 0.05471025840961374, 0.019505672571540345, 0.006996355559749645, 0.033132314711110666, 0.016448673522972967, 0.0633776378526818, 0.041064663673751056, 0.05884829944989178, 0.06309655684162863, 0.08198549912776798, 0.04343816697655711, 0.05649692699080333, 0.02413575566606596, 0.062446613592328504, 0.05978209192107897, 0.07543664702097885, 0.08685497494298033, 0.056882057106122375, 0.03967104021285195, 0.027800046736956574, 0.0066734443225868745, 0.050279210045118816, 0.010359578191128094, 0.037221318343654275, 0.06417563956347294, 0.03206492452591192, 0.11273692245595157, 0.03913880529580638, 0.001976853664018563, 0.03665942349471152, 0.05421145724540111, 0.0077246042019396555, 0.07300937882973813, 0.058413612423464656, 0.06949554706807248, 0.03346436642459594, 0.021146087965462357, 0.067092391254846, 0.038034730750950985, 0.023943287087604403, 0.03746267218957655, 0.1045137555047404, 0.0484564285579836, 0.06633876997511834, 0.024842664315656293, 0.041761985630728304, 0.045655010326299816, 0.051263301575090736, 0.032029045396484435, 0.03676792919577565, 0.03404101516935043, 0.07171833873144351, 0.08223765864386223, 0.06381384257110767, 0.05186336136830505, 0.06301935864030384, 0.026392899490019772, 0.03764140732528176, 0.046045446797506884, 0.04447443519893568, 0.05058921997260768, 0.05983912225929089, 0.05395785054133739, 0.05609660882328171, 0.03453389770584181, 0.024170965007215273, 0.07747715237201191, 0.03320683004858438, 0.0207596331165405, 0.02055746466794517, 0.029001053189858794, 0.023143804792198353, 0.04697323158325162, 0.0783266220241785, 0.03152568744553719, 0.06337527782307006, 0.052019446156919, 0.062081662472337484, 0.07637127069756389, 0.0977495321421884, 0.08520156639860943, 0.0478737387311412, 0.04381780148833059, 0.04147605468460824, 0.025373210846737493, 0.03429677410167642, 0.048500675402465276, 0.055212922452483326, 0.020399713757797144, 0.028006940810882952, 0.021479241768247448, 0.09254511023755185, 0.05150921591848601, 0.013177377477404661, 0.04360395163530484, 0.04002616900834255, 0.04450956104847137, 0.0410550936794607, 0.05925392026256304, 0.06710831774398685, 0.03481673018541187, 0.02751193387666717, 0.010226148388028378, 0.014338375676743453, 0.06673644980764948, 0.04773056360136252, 0.01725832509691827, 0.03774773853365332, 0.015668689302401617, 0.04794186417711899, 0.001708971517473401, 0.018771215400192887, 0.037665957570425235, 0.08059889267315157, 0.05979493849736173, 0.05450060540169943, 0.04014104233647231, 0.020848173189733643, 0.02211649243690772, 0.09006425156258047, 0.09261314291507006, 0.03682925285829697, 0.10356981787481345, 0.030713772321178112, 0.017819505628722254, 0.0500549515709281, 0.05551543668843806, 0.058574996146489866, 0.047911324800224975, 0.05951774634013418, 0.0718114485789556, 0.040868577125365846, 0.04827738543099258, 0.046598280023317784, 0.017106494669860695, 0.02688347394723678, 0.05635636793158483, 0.024136507090588566, 0.045807521673850715, 0.05331302440026775, 0.03078723751968937, 0.014173797007970279, 0.0863443773414474, 0.04434463357029017, 0.04757879811222665, 0.06029429627233185, 0.047324178376584314, 0.038258911299635656, 0.012684771390922833, 0.012970441657671472, 0.048712517746025696, 0.05333307351975236, 0.02694735987461172, 0.01996500632230891, 0.08889380304026417, 0.022685305957566015, 0.05698480745195411, 0.030956289483583532, 0.017579435698280577, 0.01409309494192712, 0.07291142275789753, 0.01743440891004866, 0.0445516927720746, 0.04649231617804617, 0.02917721307312604, 0.016692205572326202, 0.01395244868035661, 0.059871375997317955, 0.05522267056221608, 0.0946135054982733, 0.019794761356024537, 0.00804912126113777, 0.028359063908283133, 0.011634048914856976, 0.038049614522606134, 0.030092292290646583, 0.031656131031922996, 0.016259791373158805, 0.027625658731267322, 0.03063159245357383, 0.04892463097348809, 0.025027561132446863, 0.03420229499170091, 0.0143777159973979, 0.031178302961052395, 0.013141924155206652, 0.01804687184630893, 0.06928769376827404, 0.06426953608752228, 0.053736382542410865, 0.05390978534705937, 0.04902007116470486, 0.03504850290482864, 0.027947520757152233, 0.027257757574261632, 0.016961477158474736, 0.019535030078259297, 0.04374470736365765, 0.048237179580610245, 0.03527856126311235, 0.034579005441628397, 0.0505530959344469, 0.021280305372783914, 0.05952446648734622, 0.024804178392514586, 0.016631946891720872, 0.0753368207369931, 0.05740428045100998, 0.02038137157796882, 0.053872392236371525, 0.03839663535472937, 0.07990463578607887, 0.024097635250655003, 0.030532448945450597, 0.050930559664266184, 0.019729213017853908, 0.036048105321242474, 0.05763878798461519, 0.026183658374066, 0.048515258604311384, 0.01648099219892174, 0.045364752659224905, 0.03816695178102236, 0.03914758861355949, 0.0330243470671121, 0.04537785156571772, 0.071754614909878, 0.0172882410697639, 0.03069356178457383, 0.1055834129510913, 0.018346070537518244, 0.08408798865275458, 0.053155525820329785, 0.028135176507930737, 0.07174038051743992, 0.01709223615762312, 0.048572570958640426, 0.035215734751545824, 0.04882056331553031, 0.05347617814550176, 0.048651075339876115, 0.03770189607166685, 0.025197702198056504, 0.03107511660346063, 0.041031508226296864, 0.06662422223598696, 0.02043755401246017, 0.06371659153955989, 0.11022241480532102, 0.06440952740376815, 0.02763080738077406, 0.06894140766235068, 0.043497946971911006, 0.019158221293764655, 0.1120553191867657, 0.09790234777028672, 0.045266759480000474, 0.0980877288384363, 0.015213991191558307, 0.026961033945553936, 0.015160370094235986, 0.027800647876574658, 0.03235469979699701, 0.018329515078221448, 0.019180704657628667, 0.04034558565763291, 0.05527902925678063, 0.06770337175112218, 0.04520120557572227, 0.02120267672580667, 0.02231231552286772, 0.028418051660992205, 0.031094013538677245, 0.07036752605927177, 0.00977954989139107, 0.08329084783326834, 0.08548007215722464, 0.01564963280543452, 0.020224596592015587, 0.03828424451057799, 0.04970718488038983, 0.12147807879955508, 0.0352444447344169, 0.0319726384623209, 0.025737028336152434, 0.02523326220398303, 0.04471766667847987, 0.017311416486336384, 0.009223978140653344, 0.09123421026743017, 0.03621546333306469, 0.040988693726831116, 0.00900630251635448, 0.03283274680143222, 0.0303792956401594, 0.04076385637745261, 0.034341811333433725, 0.06453110603615642, 0.029698653452214785, 0.1174176181666553, 0.04096766497241333, 0.02442287775920704, 0.03806815708230715, 0.025781282602110878, 0.0862649230111856, 0.03372441125975456, 0.04287257252144627, 0.02759584294835804, 0.04347235772002023, 0.016451701485493686, 0.011110673385701375, 0.016386056668125093, 0.02257711938000284, 0.016906183445826173, 0.026380693016108125, 0.05098218345665373, 0.05450443488371093, 0.05954059706709813, 0.04517307817877736, 0.012532619057310512, 0.07436744970618747, 0.008577587923355168, 0.01829276206990471, 0.05640886374749243, 0.06880790271679871, 0.0240875438976218, 0.007832431765564252, 0.04614362922438886, 0.04479539922613185, 0.018564399251772556, 0.011057366773457034, 0.06317946215858683, 0.0247088977630483, 0.04398646196932532, 0.041631816638982855, 0.03527755936374888, 0.05746781200286932, 0.025865692623483483, 0.07026510225841776, 0.12030584912281483, 0.14004740776726976, 0.14888850913848728, 0.1442720092018135, 0.1327386632328853, 0.192263686330989, 0.24356427340535447, 0.07213621982373297, 0.07085651974193752, 0.1375936745898798, 0.10371964264777489, 0.18110537726897746, 0.1279642342706211, 0.16819485754240304, 0.13519248546799645, 0.12978862621821463, 0.1142905121378135, 0.11633581918431446, 0.12089486946933903, 0.11146335251396522, 0.11017408614861779, 0.12795550661394373, 0.15673476154915988, 0.1666330819716677, 0.20867171057034284, 0.13229625415988266, 0.17793285922380164, 0.15755412227008492, 0.13760400528553873, 0.20941232942277566, 0.1248426572419703, 0.13967455277452245, 0.16386448522098362, 0.09240722662070766, 0.12715091463178396, 0.17645404092036188, 0.059804838747368194, 0.18335798842599615, 0.3049877844750881, 0.17960701079573482, 0.15278655075235292, 0.08119457750581205, 0.10906390001764521, 0.12478619464673102, 0.11423293632105924, 0.14889291749568656, 0.12637682491913438, 0.20694955688668415, 0.13997850677696988, 0.11372599008609541, 0.14036639768164605, 0.16546146827749908, 0.07102301315171644, 0.09309700093581341, 0.23369615839328617, 0.19517933222232386, 0.15099211188498884, 0.09766867515281774, 0.13490932644344866, 0.1302585838129744, 0.18231565685709938, 0.10019672699854709, 0.17439334915252402, 0.14151865616440773, 0.09082929449505173, 0.15441614377778023, 0.2421154230250977, 0.16086573363281786, 0.13200696499552578, 0.11712474442902021, 0.11208277122932486, 0.22759229061193764, 0.07024724618531764, 0.23162053461419418, 0.0755017036863137, 0.17667647742200643, 0.19195076718460768, 0.2067336067557335, 0.13253926299512386, 0.14829939231276512, 0.1000477779598441, 0.08133423485560343, 0.21085032960399985, 0.10028856035205536, 0.08106686131213792, 0.1849663263419643, 0.2103724904009141, 0.23437529773218557, 0.07673113810596988, 0.21572607656707987, 0.11228024188312702, 0.2364198403665796, 0.2543342165881768, 0.12095082740415819, 0.11336890573147684, 0.16704516689060256, 0.13099970732582733, 0.09557849785778672, 0.14967260300181806, 0.11193417100002989, 0.10505212427233346, 0.09381402691360563, 0.11657515438855626, 0.08644654139061458, 0.18448590446496382, 0.16637986118439585, 0.0797760883870069, 0.28014905168674886, 0.17403132951585576, 0.17130761785665527, 0.1657044028979726, 0.1443757614470087, 0.24264277832116932, 0.20856399525655434, 0.1389485245454125, 0.12082192377420142, 0.09467929688980803, 0.19031908130273223, 0.2062351506901905, 0.08388437301618978, 0.11291909002466127, 0.19406060397159308, 0.11999342721537687, 0.09031299719936214, 0.06644155742833391, 0.09759025982930325, 0.21098403492942452, 0.2689859631936997, 0.18897677364293486, 0.12765318533638492, 0.0848764760303311, 0.11978230846580118, 0.20228496578056365, 0.21800147165777162, 0.1956044789403677, 0.16733580676373094, 0.1939516863785684, 0.18657362525118515, 0.1363024118472822, 0.20976191066438332, 0.1309373223921284, 0.22671999991871417, 0.14766745356610045, 0.21206014906056225, 0.11893652728758752, 0.15777047316078097, 0.1873084405087866, 0.13588505767984316, 0.13115380686940625, 0.14086400769883767, 0.07398844230920076, 0.14954312791815028, 0.0998131999222096, 0.2218929972150363, 0.09725537311169319, 0.12234373469254933, 0.11479783686809242, 0.11118482449091971, 0.11371139946277253, 0.16767643770435825, 0.15649172302801162, 0.22483550885226578, 0.10051713441498578, 0.0941139213682618, 0.11226640825043432, 0.10474735390744172, 0.08659217302920297, 0.16732121614040807, 0.15076100709848106, 0.15280850348062813, 0.1685154059669003, 0.11548871698323637, 0.18449872877681628, 0.15848057490075007, 0.10443327701068483, 0.1288652906077914], [0.0410259235650301, 0.039665114163653925, 0.08132460177876055, 0.04231693397741765, 0.0447650676505873, 0.013636287276312942, 0.02448322920827195, 0.037947469027130865, 0.04603568755555898, 0.05376319633796811, 0.025652169315435458, 0.009795994956220966, 0.03681263617181685, 0.031239285235642456, 0.06968766683712602, 0.05638429123791866, 0.044053040037397295, 0.07328693463932723, 0.029139190992282238, 0.028197301689942833, 0.08301984518766403, 0.07389959238935262, 0.037713800120400265, 0.053096814517630264, 0.004845003959417227, 0.02378672917984659, 0.03802725361310877, 0.07408411998767406, 0.06812520849052817, 0.04161594952165615, 0.04989150467736181, 0.02788169040286448, 0.03515030701237265, 0.05661008966853842, 0.039764736357028596, 0.06831938400864601, 0.02988547428685706, 0.025266189441026654, 0.0667121667356696, 0.04850418205023743, 0.0666254542011302, 0.03573431044060271, 0.028246509791642893, 0.011233571185584879, 0.04714838956715539, 0.014831441894784803, 0.02125556959072128, 0.056852656925912015, 0.03119785113085527, 0.059253786675981246, 0.03703615249833092, 0.050172552291769534, 0.05415487590653356, 0.027689995513355825, 0.042643048509489745, 0.024402477974945214, 0.08150178953655995, 0.10198790041613393, 0.10899373737629503, 0.027381352992961183, 0.06649971954175271, 0.024156426334229764, 0.003191900159436045, 0.021183688877499662, 0.06737368006724864, 0.045350035870797, 0.035949908051406965, 0.041368999882251956, 0.11266517904005013, 0.01264157283003442, 0.04961680242558941, 0.06670415154076181, 0.04844439463340677, 0.051221941685071215, 0.0547379998897668, 0.04904145243926905, 0.05510817572940141, 0.016949740092968568, 0.010354208752687555, 0.0449286889488576, 0.029446566295519006, 0.06840470872703008, 0.04457578659639694, 0.06796741305151954, 0.09801309846807271, 0.017248081603611354, 0.06439486256567761, 0.050275733083253726, 0.047298117860918865, 0.02618711307150079, 0.025326770955871325, 0.03381748771062121, 0.020150027448835317, 0.03171523567289114, 0.054829540094942786, 0.058934841290465556, 0.07264397499966435, 0.05513172407518141, 0.05108179080707487, 0.021996427785779815, 0.09879075791104697, 0.05086830831714906, 0.010368149069108767, 0.009965225035557523, 0.04100964084500447, 0.022072262290748768, 0.0458997706300579, 0.03823409388132859, 0.06883755893795751, 0.03853984017041512, 0.06960404163692147, 0.04721218087070156, 0.040031890966929495, 0.05601520635536872, 0.0053248989115672885, 0.020536907177302055, 0.10312956103007309, 0.028701952833216637, 0.02374405383307021, 0.05500396335264668, 0.021538821383728646, 0.05481287887960207, 0.054732441203668714, 0.05941997951595113, 0.015704217767051887, 0.05093649684567936, 0.04852927406318486, 0.028260239523660857, 0.05381807073717937, 0.07214069497422315, 0.06998494893196039, 0.03133079575491138, 0.029049572949588764, 0.06894652848131955, 0.006329261741484515, 0.026339451869716868, 0.012398326507536694, 0.07609596359543502, 0.0287907545134658, 0.027713280396710616, 0.07784345420077443, 0.012482633555919165, 0.02775861634290777, 0.07615022201207466, 0.06401989987352863, 0.034032469338853844, 0.03945124575693626, 0.013277617508720141, 0.04689104614953976, 0.022585318256460596, 0.0966808914381545, 0.057426466955803335, 0.02410277462331578, 0.01820077101001516, 0.0952454813523218, 0.09588829998392612, 0.02005735175771406, 0.032741885661380365, 0.011841144296340644, 0.03430042175750714, 0.04883035595412366, 0.017273355442739557, 0.0780341935751494, 0.03852223642752506, 0.02151336200768128, 0.026857931079575792, 0.03691871133923996, 0.06553976636496373, 0.036033017458976246, 0.04122740181628615, 0.01488243671701639, 0.02564867008914007, 0.027468952393974178, 0.01662556256633252, 0.005061417004981195, 0.02530211495468393, 0.05063436852651648, 0.035518579243216664, 0.058975900610676035, 0.041689585414133035, 0.028325524399406277, 0.059100355065311305, 0.03439951331529301, 0.027622560264717322, 0.06411798953195103, 0.04649186346796341, 0.06786080353776924, 0.036036089950357564, 0.035034531974815764, 0.03272926915087737, 0.015920581645332277, 0.03166059133945964, 0.09142954353592359, 0.04311803786549717, 0.029952553304610774, 0.03914760716725141, 0.04350018825789448, 0.02639576789079001, 0.03972027428972069, 0.05382976327382494, 0.027537378409761004, 0.05025823695177678, 0.047456815009354614, 0.04515298824117053, 0.08700991311343387, 0.0328526697558118, 0.01577802249812521, 0.0056843372658477165, 0.019775445107370615, 0.027747421045205556, 0.04554009246930946, 0.10219245115877129, 0.04442791367182508, 0.022445495778811164, 0.08527292389771901, 0.0271120925390278, 0.05378931622544769, 0.0450264891696861, 0.016663601345499046, 0.018048298625217285, 0.03782194959057961, 0.04269548495358322, 0.012380625357764075, 0.022095417298260145, 0.05401432797953021, 0.02055573360848939, 0.04092189672519453, 0.042972736482624896, 0.025736490279086865, 0.015038194032968022, 0.0659595250908751, 0.029044500370218884, 0.06848264907603152, 0.10461539262905717, 0.055977790980250575, 0.03353092964971438, 0.01445536134269787, 0.028105535129725467, 0.05472371725772973, 0.030608545057475567, 0.02020074211031897, 0.05579134121944662, 0.043972068015136756, 0.051488947865436785, 0.07385842545772903, 0.03112020764092449, 0.08618534251581877, 0.09473506186623126, 0.02088345674565062, 0.008447102591162547, 0.07703392693656497, 0.02886583017243538, 0.1499225286534056, 0.03258871009165887, 0.008460336011921754, 0.024311191955348477, 0.016561107040615752, 0.056093892562785186, 0.04210901759506669, 0.055570196054759435, 0.05473961035022512, 0.02235522279079305, 0.07465704315109178, 0.05866089974006172, 0.04423619837325532, 0.019218984634790104, 0.06699593432131223, 0.05304985141265206, 0.03188204820617102, 0.046785598096903414, 0.055933128533069976, 0.011654036807158263, 0.030207132222130895, 0.05952802879619412, 0.01341051111012348, 0.08346169764990918, 0.11104566438007168, 0.03842685189738404, 0.07031980596366338, 0.07928351013106294, 0.04328560367866885, 0.0207664720073808, 0.02858355059288442, 0.01680537567153806, 0.009824768021644559, 0.026952230218739714, 0.046158620607457124, 0.05752696488343645, 0.08744723847485147, 0.037116029852768406, 0.03966592681535985, 0.04682727339968551, 0.07813874733983539, 0.04635546043573413, 0.07042252662358806, 0.047097786227823235, 0.024440381312160753, 0.08558265180909075, 0.05103921008412726, 0.14676611521281302, 0.03894730150932446, 0.08391104580368847, 0.05135523882927373, 0.0604790205397876, 0.019275890663266182, 0.054628484867862426, 0.09449141478398815, 0.017513447637611534, 0.015518912769039162, 0.03233937815821264, 0.02083065850456478, 0.02898787450249074, 0.03707052135723643, 0.014540355805365834, 0.032542218250455335, 0.041440917702857405, 0.07727819742285646, 0.03680878442537505, 0.015081866640684893, 0.08602415546192788, 0.050034739178954624, 0.025821753770287614, 0.03858995369228069, 0.04402200713229831, 0.018991297438333277, 0.027442724895081483, 0.047556355566484854, 0.0771345324756112, 0.017140277232101653, 0.04440097000042442, 0.0523022044217214, 0.013094964760966832, 0.04240128277160693, 0.007479555388272274, 0.017445502162445337, 0.02499859325325815, 0.027311195917718578, 0.005265793342914549, 0.023495506720792037, 0.03117124884738587, 0.08164140235749073, 0.04930925271764863, 0.053624722713720985, 0.04536551336059347, 0.025411759852431715, 0.06464602760388516, 0.09131373139098287, 0.03654156673292164, 0.03781175248150248, 0.020705706810986158, 0.040367590336245485, 0.021000287488277536, 0.13942505756858736, 0.11546636349521577, 0.160602597752586, 0.14442698447965086, 0.11181876703631133, 0.10714014933910221, 0.12505209131632, 0.15535651909885928, 0.11583446874283254, 0.1746131881373003, 0.13305541186127812, 0.10814464621944353, 0.13129186118021607, 0.17227649164851755, 0.20060606446349993, 0.19001226261025295, 0.1806268998188898, 0.18044449476292357, 0.06564632392837666, 0.0839432401699014, 0.18661567533854395, 0.14491800422547385, 0.12955888698343188, 0.17508678225567564, 0.08090104325674474, 0.1534740169881843, 0.1141987084702123, 0.15976659808075055, 0.12524242250947282, 0.12644363305298612, 0.16818129108287394, 0.14887424506014213, 0.168927876802627, 0.13971749343909323, 0.17244294052943587, 0.2514350018464029, 0.11233562836423516, 0.09464947739616036, 0.18056026980048046, 0.1719039335148409, 0.10452937771333382, 0.2432122133905068, 0.10019007735536434, 0.07898177515016869, 0.18011216103332117, 0.19526089425198734, 0.13570116832852364, 0.14502230565994978, 0.1790820006863214, 0.10749198670964688, 0.18924703414086252, 0.17015602730680257, 0.12659099389566109, 0.08639867286547087, 0.21582225890597329, 0.09965059536625631, 0.29916507191956043, 0.21488507481990382, 0.17280975444009528, 0.12898957065772265, 0.1225320398225449, 0.10261022092890926, 0.07112267616321333, 0.1061560318339616, 0.12217973489896394, 0.11040091616450809, 0.10007937118643895, 0.2125491204787977, 0.22376426320988685, 0.23066703812219203, 0.1594169723102823, 0.2303582601598464, 0.11437873123213649, 0.10261517847538926, 0.19798095454461873, 0.16035175183787942, 0.23332686570938677, 0.1855965581489727, 0.13791165518341586, 0.09569998001097701, 0.13539041625335813, 0.13939986907644197, 0.1947898679645732, 0.0851507144398056, 0.31465440639294684, 0.08018772059585899, 0.16174860735191032, 0.10092017997521907, 0.13056620402494445, 0.11900482713826932, 0.1748223847243935, 0.14093785139266402, 0.09421653812751174, 0.20169987139524892, 0.1729565957793966, 0.17516065563540906, 0.15183139184955508, 0.16128855000715703, 0.16059336543548852, 0.16158361308043823, 0.2552865108009428, 0.18881658848840743, 0.18173623248003423, 0.12550499435747042, 0.11111012732726522, 0.14815348607953638, 0.14050528319785371, 0.08897104577044956, 0.15279806888429448, 0.19836146850138903, 0.12723105173790827, 0.2561657183105126, 0.18361226306296885, 0.23671934148296714, 0.10232549597276375, 0.14759064128156751, 0.1818646685569547, 0.1393926702439785, 0.15130452637095004, 0.142218011606019, 0.11232863733312115, 0.1635905881994404, 0.11019753801519983, 0.3246956644579768, 0.08359880943316966, 0.16324001247994602, 0.11859501319122501, 0.12313427781919017, 0.1344749325653538, 0.14057272957870737, 0.22210210474440828, 0.10209123705863021, 0.13732828258071095, 0.13190184719860554, 0.14526607148582116, 0.06696014053886756, 0.11193480924703181, 0.18818153272150084, 0.10363765759393573, 0.19254981394624338, 0.137320875946898, 0.12934074009535834, 0.16384057322284207, 0.18953130638692528, 0.1325018290663138, 0.11782056724769063, 0.14650345430709422, 0.15759893314680085, 0.1374192550429143, 0.23442396777682006, 0.13152973435353488, 0.18842538760509342, 0.11030831839889288, 0.11953823835938238, 0.14799153461353853, 0.27042843110393733, 0.11015671989298426, 0.13396063906839117, 0.09511015072348528, 0.13568178343120962, 0.12298425266635604, 0.12420000930433162, 0.17538000480271876, 0.19273643440101296, 0.16624955489533022, 0.09379427836393006, 0.12113459059037268, 0.22123658243799582, 0.1219395239604637, 0.14496499701635912, 0.18639758782228455, 0.07706983204116113, 0.11172155311214738, 0.09475912229390815, 0.08995739714009687, 0.17282979242736474], [0.0136103798286058, 0.03352579769853037, 0.03954225903726183, 0.032545661815674976, 0.018719090658123605, 0.017262729743379168, 0.03843843311187811, 0.02341031558898976, 0.03253733862948138, 0.03479411323496606, 0.032548151721130125, 0.06213024345925078, 0.026469849071872886, 0.02325676894542994, 0.0677978471503593, 0.047407759047928266, 0.058145044022239745, 0.051433576227282174, 0.03159723048156593, 0.040827135599101894, 0.019000244028575253, 0.007508025564675336, 0.016701838649169076, 0.051690095860976726, 0.047445029704249464, 0.10421552346087992, 0.015273324970621616, 0.06785647681681439, 0.018056799926853273, 0.04205901539535262, 0.02359016394620994, 0.04530081663688179, 0.10965917666908354, 0.03705133683979511, 0.10151449925615452, 0.023911434109322727, 0.018815601397363935, 0.04162080316746142, 0.0603612120175967, 0.04731337270641234, 0.023232170460687485, 0.0875341217033565, 0.037428800569614395, 0.026049207190226298, 0.044405003573047, 0.02549510303651914, 0.02707190709770657, 0.012788355725206202, 0.0433109999721637, 0.04934006297844462, 0.043604957245406695, 0.04644431777705904, 0.03667274504550733, 0.06623050547204912, 0.04094980518857483, 0.018513755094318185, 0.0680781043774914, 0.05360585360904224, 0.04572697638650425, 0.0694302306510508, 0.05878273441339843, 0.012471957761590602, 0.018419415137032047, 0.036374913761392236, 0.05553260998567566, 0.039409674354828894, 0.007371940264420118, 0.02777935194899328, 0.05831857670273166, 0.049631597139523365, 0.02402051311946707, 0.03577928087906912, 0.009804862693272298, 0.01337318108198815, 0.009954180022759829, 0.02201944178523263, 0.07254376279888675, 0.12520481046522036, 0.0880585603590589, 0.03825842148216907, 0.023715618444839492, 0.028770404824172147, 0.03073414984100964, 0.01965985560673289, 0.045775342150591314, 0.05274075061606709, 0.04111715948965866, 0.021905824542045593, 0.050547006612760015, 0.030485031275020447, 0.03390564743313007, 0.08412044277065434, 0.10718225879827514, 0.037660094603779726, 0.03219032150809653, 0.1041727905976586, 0.1052701821026858, 0.09874578376184218, 0.08513741515344009, 0.05339940296835266, 0.051701777265407145, 0.023220912080432754, 0.01013202736430685, 0.025963157022488303, 0.017505256182630546, 0.04455310285266023, 0.1810680323978886, 0.07570465138996951, 0.0403466061106883, 0.044021424546372145, 0.028625060767808463, 0.07466922921594232, 0.07087977122864686, 0.05613776091195177, 0.03163278306601569, 0.02067818983050529, 0.040263619157485664, 0.05665517513989471, 0.10281186245265417, 0.006961402259548777, 0.05438090811367147, 0.034889571979874745, 0.039466504313168116, 0.020629942810046487, 0.042377085046609864, 0.065696841920726, 0.0600011479400564, 0.05005017213989049, 0.03432127610722091, 0.07780441723298281, 0.06457078867242672, 0.1363800701801665, 0.05774459226813633, 0.08808273210888728, 0.056228284374810755, 0.025711815724207554, 0.02559937292971881, 0.014606234399252571, 0.04412181857333053, 0.018718031242315192, 0.016927013675740454, 0.02770114257145906, 0.032859237762750126, 0.01657307231653249, 0.046064887355896644, 0.03255251926020719, 0.022176333659444936, 0.06429856148315594, 0.008017453819775255, 0.03492949210340157, 0.03381790331332013, 0.04959902056725696, 0.034743944052024744, 0.04076416065800004, 0.05293182024615817, 0.03750936441065278, 0.033341848975396715, 0.05171556265850086, 0.06844705567345954, 0.02463786495354725, 0.010683890232030535, 0.04108925102627836, 0.05753645324148238, 0.04393120907479897, 0.0204738209140487, 0.040332163916900754, 0.021304803667590022, 0.031772343936609104, 0.008683685355208581, 0.03923165539163165, 0.06053190598322544, 0.044738992291968316, 0.021508376630663406, 0.04137434334552381, 0.03241043508751318, 0.015291589224943891, 0.0621270076953806, 0.007241484618134564, 0.09161776702967472, 0.03557003234163858, 0.018860124691855162, 0.01804294588509947, 0.03684615898237098, 0.011283734802418621, 0.06057172220607754, 0.0027974368413197226, 0.06383246305631474, 0.025301146451965906, 0.02510262009309372, 0.05595622416876722, 0.027606442672549747, 0.07198735242127441, 0.02549665226979414, 0.026077868933498394, 0.05569446868321393, 0.02700193741475232, 0.07849497822462581, 0.0386978211463429, 0.021384000101534184, 0.06898885316331871, 0.038295176345855, 0.08763889811234549, 0.008439606899628416, 0.03601858639740385, 0.029014998144702986, 0.03770797426113859, 0.04951057882863097, 0.04632911048247479, 0.043359503033570945, 0.16154442768311128, 0.06511171042802744, 0.03737566279596649, 0.024354685519938357, 0.020595470050466247, 0.036234484578017145, 0.03735908692760859, 0.049487004507682286, 0.03698569387779571, 0.025342020235257223, 0.04214259977743495, 0.06686788416118361, 0.015598079517076258, 0.058281662277295254, 0.04048120943480171, 0.010238224058412015, 0.03900522984622512, 0.060975298401899636, 0.022036410991859157, 0.09237480218871497, 0.027622666020761244, 0.0860294840822462, 0.027617595296760555, 0.029745822503173258, 0.05249064684903715, 0.06237052861251868, 0.10110642193467356, 0.019405020648264326, 0.010459347886353498, 0.11499505519168451, 0.08843539326335303, 0.010085721987707075, 0.046050897872191854, 0.030850978728267364, 0.04968270513927564, 0.048235765789286233, 0.011711422448570374, 0.0770564065896906, 0.027544449221750256, 0.12613654718734324, 0.028706186785711907, 0.021822776361659635, 0.0757249268644955, 0.01601515723450575, 0.05405598843935877, 0.041402760180062614, 0.08413582749199122, 0.03288191779574845, 0.019639272140921094, 0.028615138253371697, 0.032539193998673, 0.07266506683663465, 0.05987509786791634, 0.030363627047336195, 0.02189456245105248, 0.052082977708778344, 0.028843780964962207, 0.0503070331615163, 0.05497663747519255, 0.054825053812237456, 0.021849133736395743, 0.022062243297114037, 0.05626756996207405, 0.07828547735698521, 0.04357649588200729, 0.054778298508608714, 0.04938704463711474, 0.08413670322624967, 0.008280702877527801, 0.008710449983482249, 0.04260398927726783, 0.023651801166124642, 0.04901077576505486, 0.024266089785669465, 0.14108313422184438, 0.026925447964458726, 0.08878491513314657, 0.03537680306180846, 0.020262486941646785, 0.025787661361391656, 0.03391038975678384, 0.07074789158650674, 0.026085750541824382, 0.0501231178350281, 0.02990438606502721, 0.08072115408140235, 0.01285179079786758, 0.18131006159819663, 0.07049614767311141, 0.02522961269278312, 0.044581682959687896, 0.053764291005791165, 0.004397052434796933, 0.09912068708217703, 0.056235260562971234, 0.01114512944695889, 0.04536136475508101, 0.07117693457985297, 0.06463520709075965, 0.046462418758892454, 0.0195510307821678, 0.046089608295005746, 0.020350366503407713, 0.053335500342654996, 0.04404922168760095, 0.01220396730786888, 0.030851405463181436, 0.023378701953333803, 0.04012978395621758, 0.010474677874299232, 0.04611742770066485, 0.05545789797906764, 0.08450626308331266, 0.031294426808017306, 0.024202086970035452, 0.020497272780630738, 0.06293456826824695, 0.0034919722656923113, 0.04061822473886423, 0.053656623931601644, 0.03469675088126678, 0.030468180812022183, 0.028177542008052114, 0.06796467452659272, 0.052472957759164274, 0.05346150959667284, 0.03357313929882366, 0.044154933202662505, 0.07071203101077117, 0.03841762700176332, 0.019845962124236394, 0.045814074837835506, 0.016317380177497398, 0.02922631912952056, 0.043807021793327294, 0.09374001994729042, 0.06429645378375426, 0.03975164487201255, 0.08545280565158464, 0.04309077878133394, 0.022417917571146972, 0.05846810090588406, 0.027832137202494778, 0.09798302664421499, 0.09815907891606912, 0.15887535293586552, 0.18060338858049363, 0.2325747287250124, 0.15501619986025617, 0.09842328348895535, 0.14162732142722234, 0.13175269035855308, 0.14479739038506523, 0.19019028899492696, 0.14025986980414018, 0.062059078918537125, 0.13186931144446135, 0.19364042964298278, 0.1588900326169096, 0.10620331406244077, 0.09885751409456134, 0.14925973140634596, 0.08728459681151435, 0.15239324216963723, 0.14542987832101062, 0.04694418763392605, 0.19506774289766327, 0.09031419947859831, 0.2095648110844195, 0.1054101437330246, 0.1332469898625277, 0.1584940226166509, 0.1609181144158356, 0.1114331025746651, 0.13109069463098422, 0.22218559635803103, 0.2333561805426143, 0.24991923943161964, 0.17031192284775898, 0.1019255377468653, 0.16737165249651298, 0.17692612105747685, 0.16122212779009715, 0.09615769959054887, 0.13909631583373994, 0.1513759803492576, 0.14079881744692102, 0.1702045340789482, 0.13015103177167475, 0.23348239017650485, 0.1132145241717808, 0.17593948025023565, 0.08020142064196989, 0.1718991540838033, 0.09172517064143904, 0.1445779373170808, 0.1531642593909055, 0.1995131332660094, 0.09250892311683856, 0.14578219066606835, 0.13376772520132363, 0.17334871692582965, 0.2302293194225058, 0.2112016177852638, 0.08821946539683267, 0.1967959079775028, 0.1926550208008848, 0.12218162737553939, 0.10373242243076675, 0.07097147099557333, 0.12210940156364813, 0.10922810761258006, 0.11077993098297156, 0.12681918946327642, 0.1611478833365254, 0.27728958637453616, 0.09772428427822888, 0.0982092109916266, 0.18706753937294707, 0.24315960996318609, 0.2604901831364259, 0.1529770452179946, 0.17186051787575707, 0.20195560064166784, 0.14535308087943122, 0.19769893842749298, 0.1498325209831819, 0.16525485436432064, 0.24465119320666417, 0.09457662075874396, 0.1124594037537463, 0.19099943776382133, 0.16084661590866745, 0.13232243712991476, 0.3027923038462177, 0.23513690452091396, 0.1830115242046304, 0.2674012107308954, 0.21339169557904825, 0.20536741678370163, 0.3354418440721929, 0.16572347609326243, 0.07333448404096998, 0.09893523179925978, 0.11854407959617674, 0.08408506459090859, 0.19397577649215236, 0.13624609768157825, 0.15739288326585665, 0.26965989265590906, 0.2450354624306783, 0.18947177130030468, 0.30386058089789003, 0.17862403619801626, 0.1440076413564384, 0.15560767671559006, 0.14101372857112437, 0.13240738335298374, 0.08683429128723219, 0.12737425655359402, 0.21284105168888345, 0.222208795894403, 0.06778553492040373, 0.2440962300170213, 0.20708490977995098, 0.12520305899670348, 0.08180584001820534, 0.14383599744178355, 0.08720993675524369, 0.16392709279898554, 0.2124491531867534, 0.1497977736289613, 0.12774752714904025, 0.14290510676801205, 0.274270381196402, 0.16795420873677358, 0.14421934640267864, 0.20406188996275887, 0.13133965549059212, 0.1296514179557562, 0.1098665178869851, 0.11614542119787075, 0.09903540689265355, 0.12578056863276288, 0.1505776817793958, 0.1771561274654232, 0.12289135804167017, 0.1416527177207172, 0.15123990015126765, 0.24140959605574608, 0.131076623511035, 0.14944733149604872, 0.22292732843197882, 0.09551648399792612, 0.125036996032577, 0.1566968674887903, 0.22273098584264517, 0.24666401644935831, 0.1665957222576253, 0.13783165166387334, 0.09124524600338191, 0.16636043175822124, 0.11744981253286824, 0.13841405947459862, 0.1470454447553493, 0.18204981955932453, 0.13871376839233562, 0.10554741136729717, 0.10031740763224661, 0.06966571410885081, 0.1607871550368145, 0.2030369988642633, 0.15262197208357975, 0.21461891097715124, 0.12782671430613846, 0.10328732678317465, 0.1332327999989502, 0.14900193898938596, 0.12979711638763547], [0.044569964447873645, 0.05537932309380267, 0.05175389458599966, 0.06266449330723844, 0.0565948904841207, 0.024571565190854017, 0.012315256990405032, 0.024681159993633628, 0.01154667772425455, 0.01714802154310746, 0.03299776333733462, 0.017093846618081443, 0.038583812420256436, 0.06687917964882217, 0.03515704200253822, 0.053778922447236255, 0.037895336863584816, 0.054097225875011645, 0.06297548286966048, 0.04569817734591197, 0.0723087543155998, 0.07813220901880413, 0.057041373947868124, 0.0356822153844405, 0.016967225092230365, 0.045383310061879456, 0.033124221590696834, 0.060772120632464066, 0.05121025656990241, 0.05272280548524577, 0.05731530807679519, 0.02621139614348067, 0.005008864600313245, 0.02737615053774789, 0.041365808647242375, 0.06712432586937211, 0.022338440976454876, 0.01746054920658935, 0.012539847575681051, 0.0037646220152964815, 0.04230168284266256, 0.12005207914626226, 0.054457059886772186, 0.004010080401712912, 0.10267918871250004, 0.021105533305671997, 0.04895819089142606, 0.0083918719610665, 0.058079783266293816, 0.0462841140688397, 0.03890859108651057, 0.026552138406259473, 0.02598596878669923, 0.04550154531898443, 0.03156119921186473, 0.04733681715151761, 0.04848229240451474, 0.0377167353144614, 0.034815038088709116, 0.027348429466655944, 0.0802793684124481, 0.07641932475962676, 0.0359387238859199, 0.05981672053167131, 0.10169535322347656, 0.018096150452038273, 0.010297925200575264, 0.019340322069183458, 0.023456399248971138, 0.04356200915935915, 0.014015902306709904, 0.04105732012249064, 0.05590380256762728, 0.04902251654129941, 0.03697606451169122, 0.1018205015861895, 0.07121879913029261, 0.0466733259963803, 0.06207715021446347, 0.026066632817673963, 0.05965452786767855, 0.026810055132955313, 0.04896576079772785, 0.0474710271373624, 0.04168891377048567, 0.05053142522228882, 0.06887160867336206, 0.01358868406896363, 0.07035312839434482, 0.03911671898094937, 0.030583735060645267, 0.09747412856086157, 0.05676483488059603, 0.05239692472969182, 0.07021287732641213, 0.0706772984995041, 0.029054244769213255, 0.0663527223514393, 0.06589057957171462, 0.0853193378134165, 0.07388388112303801, 0.018878142182074953, 0.054035920766182244, 0.054495169169967994, 0.042448179083294235, 0.06955214324989356, 0.03626445621193852, 0.09546836314257234, 0.014452078266913304, 0.0648178273695521, 0.018027576006716117, 0.030464557275990956, 0.017418612296751235, 0.0044960869399801595, 0.03237229240767192, 0.026554813848633785, 0.042344311805209145, 0.06863919770694338, 0.030337163916556165, 0.04589431955537293, 0.03404713417694438, 0.032429675266030245, 0.0816698488779366, 0.020804943087568972, 0.032456529879709706, 0.04210853890981525, 0.0373902682622429, 0.07162172594689764, 0.04234657535562292, 0.0707429859903641, 0.009375917106808629, 0.0567516283626901, 0.06006172945490107, 0.03629253536928445, 0.04993744361854624, 0.05405015515862033, 0.028376352238410618, 0.018393464088148903, 0.022329002713377122, 0.049421394942328334, 0.016663864807924256, 0.037146253816899844, 0.05070066086773295, 0.01552592884763726, 0.06762152028386481, 0.096098491048906, 0.05876772818737663, 0.028151112273917533, 0.041517347781336866, 0.042717537871794775, 0.026439875582582317, 0.004685422263719374, 0.030518344428855926, 0.04888156785455067, 0.06592309306142852, 0.05425541465228889, 0.05244495652732439, 0.09152033046120778, 0.03289989261247683, 0.06618026207434013, 0.040354988668696024, 0.04342071166320238, 0.056091124351951294, 0.029066675742797088, 0.01547845366076217, 0.03366352175362408, 0.023507987789344043, 0.01160348820121726, 0.023264500268851407, 0.04608940791513305, 0.0373109920474235, 0.07745115493889898, 0.02010486405197298, 0.04532710350758862, 0.03207826091966126, 0.01891186537250178, 0.014705272151331883, 0.02239782206743257, 0.042797237110789865, 0.015398582800116856, 0.01008740944598685, 0.09062666591489688, 0.011403664939280134, 0.008727727181394584, 0.03744563990039751, 0.028462793889048044, 0.01170360856121988, 0.08990467496914789, 0.04021641485451255, 0.009409860158484662, 0.014074121008889051, 0.024060134528554045, 0.0644000872853212, 0.06832230064901523, 0.037247816726448946, 0.02255789775517769, 0.08501953241648152, 0.029321340007300023, 0.050387389201205224, 0.04375431817607023, 0.02814873369061388, 0.048558811540715396, 0.04568111166008748, 0.04194699191430118, 0.035780917314696126, 0.029343628557398915, 0.11604384344536811, 0.03935118569643237, 0.025887901392707136, 0.03536677293595858, 0.05741641085478477, 0.017239554326806683, 0.01454922725315555, 0.041705307812662795, 0.021135551323823165, 0.02812791459291475, 0.05068951009889133, 0.023542258313682396, 0.01261066794540966, 0.04838928645767737, 0.12441762184607796, 0.014389979987754487, 0.0386472512036562, 0.052979670217609964, 0.0896019306674134, 0.06252361883525737, 0.011105666671937797, 0.06373493743012659, 0.08452970752841793, 0.10207148850895464, 0.02087292381474981, 0.07881589030148461, 0.009264618147426518, 0.05537736011319794, 0.06332616991130635, 0.019341108745720703, 0.11075306523707695, 0.07902264522272162, 0.00828728758278885, 0.045154632098274305, 0.045366403937805444, 0.01646582084504189, 0.028334268754406366, 0.060767300383304246, 0.0500189648300875, 0.03897875743859913, 0.039940751521498896, 0.042288424374419264, 0.023976971315278206, 0.019031091396755073, 0.05508827875019051, 0.05501456864294596, 0.06451722045312636, 0.09916041424730793, 0.03410661360248923, 0.021415674964373466, 0.04403063459903933, 0.037579271011054516, 0.037407319105113856, 0.05832133749208879, 0.08732551883440465, 0.01635682532651117, 0.07167248142650351, 0.038026273978175595, 0.021948229004919995, 0.041712640231708065, 0.023830872123653535, 0.05881573772057891, 0.06751699620508589, 0.10367408220190555, 0.03312084110802971, 0.0719887253944762, 0.04574288432195317, 0.040162750156014226, 0.0729187997058034, 0.09532893585856073, 0.13660172000527382, 0.04403523220389616, 0.014712382853758754, 0.0519365408399608, 0.06818083245889284, 0.042553181847324595, 0.06702962040435523, 0.07928984065074474, 0.12128033355111256, 0.031113541299419012, 0.04500129696680233, 0.014788924254389713, 0.04154878144618124, 0.04989223198208492, 0.029764524624624755, 0.05421052213932853, 0.02107379350491101, 0.02367236236750614, 0.04320946674852166, 0.041710079822223634, 0.05927914215135388, 0.03483201842755079, 0.03308180414023809, 0.07341902208281681, 0.007318041325561353, 0.045595850024255924, 0.0673814132460393, 0.024673241277923808, 0.05049580955528654, 0.0723521105828695, 0.04461638207430951, 0.046989707261673175, 0.06420278732548468, 0.03799328922468703, 0.018906490367953666, 0.023623230335942935, 0.01820286943257088, 0.041022398363566026, 0.004996891439077444, 0.09565535467118025, 0.04014197002106812, 0.044317945939837955, 0.06824303927714936, 0.025438070842938032, 0.04043373424792662, 0.024396010157943238, 0.03249922563554719, 0.05127479002112523, 0.04232629245962016, 0.01754730626998935, 0.023380726161121856, 0.07238628648337908, 0.032090706736198626, 0.03748548209841829, 0.021493396379810292, 0.011141905742988456, 0.026372382817498874, 0.037951406120555475, 0.03171111675328575, 0.057843598478939384, 0.0358382445119787, 0.0055621825413254555, 0.021723911158915143, 0.01563055775477551, 0.02617810710944468, 0.046098799793981016, 0.023342036147369072, 0.04148968051595148, 0.011542504071258008, 0.03919118236808572, 0.02234544685052242, 0.030261043684731703, 0.014401835796888918, 0.04130780609557405, 0.009175595678243553, 0.07070606414345093, 0.12147266854299232, 0.13530474272556603, 0.18130532669601962, 0.13896315969759598, 0.2056091936537996, 0.16840821015648544, 0.07059108320390806, 0.10094912373460829, 0.11421794493799098, 0.093454656744143, 0.23259056615643203, 0.171448566543404, 0.19447999162366614, 0.28562239080201834, 0.074264595459681, 0.19650452595669776, 0.2875558933010325, 0.18668669887119904, 0.1658854869310744, 0.12384757821564563, 0.16328580299159512, 0.10558036272414029, 0.2613228728296235, 0.11528933158842847, 0.2372733547235839, 0.1178826330578886, 0.11897857737494633, 0.183693008730188, 0.1500700379256159, 0.19602815620601177, 0.2507244102889672, 0.18479350983398035, 0.0742823253676761, 0.12295668930164538, 0.14123833214398474, 0.1533477331395261, 0.09515430108876899, 0.16270430060103536, 0.13447401230223477, 0.10174138122238219, 0.13426258927211165, 0.30643491307273507, 0.09293461902416311, 0.17412227229215205, 0.3083365032216534, 0.07598770651384257, 0.15154677821556106, 0.10447146793012507, 0.1999186130706221, 0.1443504393682815, 0.13942913938080892, 0.16483647603308782, 0.1711647247429937, 0.20336155488621444, 0.10864958123420365, 0.2104421186959371, 0.12800151976989582, 0.1347410073503852, 0.13153895182767883, 0.069346264062915, 0.28848874324467033, 0.18356078770011663, 0.13569968403317034, 0.22491644747788087, 0.20496578130405396, 0.1128041981428396, 0.17854168749181554, 0.08226927413488738, 0.08013777405722067, 0.13180849986383691, 0.1593942180625163, 0.12537636532215402, 0.09585332256392576, 0.1517032674746588, 0.11724749565473758, 0.21539844805374742, 0.24646537320222706, 0.16807289299322292, 0.1677189182373695, 0.16819512471556664, 0.141370048513636, 0.1121882007282693, 0.1680456116446294, 0.10653803750756197, 0.2263444138225168, 0.19799285859335214, 0.15654481627279893, 0.062098316266201437, 0.18484354543033987, 0.15701616910519078, 0.18374877370661125, 0.1671736326534301, 0.10932584104011767, 0.17669546155957505, 0.10118836988112889, 0.13305591652169824, 0.22147996234707534, 0.21547040669247508, 0.18616611196193844, 0.3022346837678924, 0.27141183614730835, 0.2189687275676988, 0.11231055119424127, 0.1328614738304168, 0.1932962067076005, 0.22199893137440085, 0.20292959525249898, 0.1522246707463637, 0.17339608079055324, 0.19984819809906185, 0.16293075954308733, 0.13879734906367958, 0.18324256961932406, 0.13079159427434206, 0.11396274261642247, 0.08579052737331949, 0.0996089237742126, 0.10282496878062375, 0.09574570372933522, 0.09335962473414838, 0.1492829160997644, 0.1128240728576202, 0.17778736859327182, 0.11339747841702774, 0.08248891273979098, 0.07625056779943407, 0.1971461423090659, 0.0991269359656144, 0.09621916426112875, 0.15022713574580848, 0.1495679304935038, 0.21658082288922742, 0.10883817580179311, 0.10168782784603536, 0.13736205029999837, 0.10429369387566112, 0.09753143720445223, 0.12032108541461639, 0.09623506848583929, 0.13725546305067837, 0.11815740581369027, 0.27033438615035266, 0.13920869183493778, 0.09213151133735664, 0.11233415149035864, 0.16039242153055966, 0.1208202910493128, 0.20258796983398497, 0.16604071453912184, 0.11125915800221264, 0.20413954829564318, 0.1599709113361314, 0.1751988020259887, 0.15216467552818358, 0.24398070730967447, 0.14933321886928752, 0.13032680202741176, 0.20379731431603432, 0.07765596543322317, 0.11230750096729025, 0.14164048712700605, 0.14242398727219552, 0.12861990689998493, 0.10029036377090961, 0.11129718564916402, 0.0880536473414395, 0.1261763263028115, 0.09318565789726563, 0.09114465530728921, 0.11674670924548991, 0.1669384608976543, 0.1715667758253403, 0.10291869461070746, 0.11054797272663563, 0.17576281941728666, 0.26132842409424484], [0.030831955627945717, 0.025488165811111685, 0.009568586065142881, 0.03970971723902039, 0.04753658846311737, 0.022680211113765836, 0.03885785416059662, 0.05184952031413559, 0.014965784539526794, 0.01931135975610232, 0.0654640376160387, 0.06053785058611538, 0.008656129411974689, 0.05757820646977052, 0.012054029357386753, 0.08783124052570201, 0.12424783330061473, 0.059949906353722326, 0.021930163275101222, 0.016743322848924436, 0.04549842458800413, 0.05047649516200181, 0.013228222942416323, 0.05185694550164044, 0.017030832714226563, 0.03430454438785091, 0.024843630963005126, 0.03176723053911701, 0.007229080083561712, 0.030601752550865058, 0.013748823766945861, 0.05865684761374723, 0.059994995535817, 0.010297951175743947, 0.04591368960973341, 0.06792890300857835, 0.07314097645576112, 0.03748731891391799, 0.039447809613193385, 0.011947171224164777, 0.01647146858886117, 0.07325267710257322, 0.020642240197048523, 0.06798309463192709, 0.04265488947567064, 0.08156931013218127, 0.029636626604769845, 0.06562416339875199, 0.04425016559252981, 0.04355990888143424, 0.0010146924819309788, 0.018034357381111477, 0.03818784323811997, 0.03267166735895444, 0.01964758976100711, 0.017139086085080635, 0.059970445290673524, 0.02370533227804117, 0.06726937863277271, 0.04405409759783652, 0.023783704928064253, 0.0390320362203056, 0.021498956921277568, 0.1421931348158978, 0.05771723670477513, 0.025846322569123004, 0.05481353939103428, 0.08114739917800762, 0.039410364552168176, 0.09167979573248886, 0.05983709990687203, 0.017448183170927223, 0.011078517054556869, 0.01956053212779807, 0.03684179886477068, 0.0539570749970153, 0.17138183262431994, 0.15516676678089425, 0.021799207606818527, 0.030840447652735747, 0.0954439167981036, 0.02133785335900029, 0.1116860710317269, 0.03104544182860991, 0.04000179687864147, 0.03145994800433982, 0.060723127753590234, 0.12556786910863593, 0.08235869550844654, 0.0624766260443721, 0.08521882133209147, 0.12638915941352025, 0.04933640419039875, 0.09074405883438885, 0.08387210531509481, 0.1299630754510872, 0.08790835709078237, 0.15818180108908564, 0.10910638797213323, 0.09587195789208636, 0.09654851455707103, 0.06731394460075535, 0.022988003875070717, 0.06785360470530577, 0.021883667723159306, 0.08082271699095145, 0.01710960983473342, 0.07857426186092198, 0.012400124360283371, 0.08829398444504477, 0.036410006214282475, 0.020021183190692682, 0.05730466938985046, 0.08458605138002895, 0.02042577056272421, 0.03229891255614348, 0.00476358201012772, 0.03357937705004588, 0.05261287486064248, 0.09154930390650406, 0.11265073684626259, 0.06771265601855703, 0.0371665144484723, 0.07082284108037129, 0.05985337520542089, 0.03629367085522972, 0.034501862901379354, 0.012976471607544227, 0.03926571625925135, 0.03823043138254434, 0.016930921083258, 0.022678233290207572, 0.0658939489221666, 0.05286837404128164, 0.04147117135289591, 0.03239279794797767, 0.038299822190310806, 0.09359553121612407, 0.1263912522699684, 0.03648410965979565, 0.07407723285723478, 0.06306233641225845, 0.049407268161303364, 0.011806826460087905, 0.019174400113115553, 0.04915337573038414, 0.07467812014510855, 0.10010416634031571, 0.033520550714456476, 0.046870165824657306, 0.02313861346920021, 0.047759822773514315, 0.024466592112730723, 0.03384781928616576, 0.02971560781588778, 0.05948262049059849, 0.020804074774787296, 0.029822124561178498, 0.11383648845367134, 0.0265408893028507, 0.011182179314346286, 0.04982896018191241, 0.02981470122904284, 0.04557925931294449, 0.04845416500756983, 0.06950949944439344, 0.04721607343526557, 0.0978288528858684, 0.019708969084604178, 0.09159067121800035, 0.020807561013498344, 0.024663906915520784, 0.0031173349589153077, 0.02239959765574895, 0.012095479232812067, 0.006078243741285405, 0.030029593799554277, 0.007290225166798336, 0.04339002014603466, 0.019581815067795105, 0.031972263677744195, 0.038173104185261764, 0.025681111219455488, 0.01898948845337145, 0.03639595364802517, 0.056601373144076206, 0.07845121377613395, 0.03157201972499024, 0.03250159679737408, 0.027669588307617232, 0.0006194468357989535, 0.008607700565335108, 0.04383427345601376, 0.08569166588131338, 0.06163991020002868, 0.08082148502580822, 0.04323264402046334, 0.021157149676582776, 0.022616532987740356, 0.10291116923326626, 0.06149105764052365, 0.040264732379000634, 0.060268907400313765, 0.06526194338221103, 0.06684498890535906, 0.05533184790692758, 0.007557378385172342, 0.013737757417402463, 0.061685496621066704, 0.008088946760835825, 0.031209473163471557, 0.04824642674066126, 0.03342436466482468, 0.06769059938960709, 0.02462065083818743, 0.06126301421318203, 0.08554761501727626, 0.04414991257362999, 0.03436307015363127, 0.0994069482840132, 0.04703061073087156, 0.08534816282917745, 0.039317915216088295, 0.019351504379301332, 0.05193277444050182, 0.04174084184342064, 0.05984876646834891, 0.04611595824826509, 0.03182325526722707, 0.05591782544797752, 0.019005487301910762, 0.017232105019502342, 0.013915092677052598, 0.021623934590024874, 0.05962717601505574, 0.04150542517891154, 0.05404484138125554, 0.1081755269842688, 0.01362692137263366, 0.09543961234157905, 0.04031164353364147, 0.03853537986287847, 0.06710301138809882, 0.046846695404383354, 0.04808620076801162, 0.06516723791719414, 0.14983906672568992, 0.008227921334764687, 0.04282149049686268, 0.03797982295509428, 0.070315687044058, 0.1526726459269412, 0.19841061352053657, 0.09456549596507102, 0.07441187466611154, 0.010031939473265084, 0.050895778913400136, 0.03115774547040928, 0.06431843619793653, 0.0497202058613766, 0.059687408720492385, 0.06250284612178802, 0.033397469233023, 0.04970656147634145, 0.1050529109488707, 0.067494175164029, 0.061460596189135686, 0.1298742849030532, 0.13144449127139524, 0.028822472049796488, 0.034828315110644326, 0.042057234240928665, 0.09076643458683975, 0.03383119517820887, 0.11410036648157984, 0.038071808448876254, 0.08078952072537504, 0.06147334257548209, 0.007717672542639775, 0.11127101010060869, 0.06118413875810802, 0.11994011874776334, 0.07325307044084184, 0.09234576195012778, 0.019763396339840256, 0.04489120306971017, 0.04963238752679899, 0.02189321916375775, 0.04332978372985963, 0.02582640703622019, 0.024045191385084763, 0.018772898220049683, 0.025813334104896057, 0.03316481706860941, 0.06048692812328227, 0.01353194687908399, 0.056259083503391594, 0.037150432108319364, 0.050564922057674266, 0.07289408618817106, 0.029686773523280863, 0.026679889851948246, 0.022730910932295956, 0.03559932862117421, 0.010096354180859635, 0.05106418706418481, 0.07518679558415897, 0.026908189320238307, 0.05229469017649535, 0.08495932939695194, 0.00798868353740545, 0.03499558035400696, 0.019629299531516153, 0.08578554756240919, 0.0348789592680987, 0.02679532906768145, 0.06106473461841233, 0.04729703432531096, 0.04615494697645772, 0.06242070521693677, 0.051961198696517386, 0.01464539474909543, 0.08419166668318212, 0.10047423085779883, 0.035015644316445105, 0.04509923077421263, 0.04288520758564118, 0.047804978748899885, 0.033323061506962404, 0.04640895815100521, 0.018934135368908755, 0.03586505088605918, 0.011196804261999205, 0.016751688708609436, 0.04131167268496938, 0.03795205549977254, 0.030048333028389607, 0.05789804243249819, 0.0025707710256028804, 0.02469976378051797, 0.05953454485279508, 0.06376097939210013, 0.04541075097222347, 0.02583330344350543, 0.025865969073493034, 0.054997922270558774, 0.030057235089770984, 0.015543837798759341, 0.0899401496280916, 0.0918427639408037, 0.0114377554928069, 0.023653699208807666, 0.09469037715462036, 0.209689655166585, 0.09436674881726503, 0.11431454287958331, 0.09438297216547653, 0.1277073918026872, 0.09252284580725245, 0.07753867641440593, 0.09811198222450912, 0.13454481319058686, 0.22783895081374794, 0.09793441597139463, 0.0915702324709855, 0.21348624519305304, 0.10722444989369251, 0.1575290970504284, 0.11886019739904441, 0.16165479988558218, 0.13952220469946042, 0.16302873787935823, 0.056071479702950455, 0.16644177114358172, 0.11303432329441421, 0.15686457802075893, 0.24021156190428883, 0.09157232532743365, 0.10479575677891262, 0.2155518499785103, 0.15326244552852586, 0.13396460213698447, 0.08907720257411711, 0.11551045448868535, 0.17209309211466461, 0.14436226920224726, 0.19107142608845606, 0.12191150046419352, 0.14362503454321995, 0.15834888821700588, 0.08502234515617602, 0.12983005290152505, 0.21631330833770335, 0.15968119172612205, 0.08573919301852584, 0.15976780035998672, 0.10338399151805788, 0.27918069739826024, 0.10615560880978592, 0.19450982596026734, 0.120879870664794, 0.1373831569799222, 0.10780714714201167, 0.14374368911376223, 0.17040979728335515, 0.15912171627860516, 0.10416996301501058, 0.1915711141191423, 0.13420326198684052, 0.1301365450490266, 0.17514529317850247, 0.1351818282273598, 0.21924131840933114, 0.18342553870752454, 0.11140858201542869, 0.19435312889982015, 0.08605723298387602, 0.11250870462390594, 0.14494294038740918, 0.16505368781508878, 0.08564485120587051, 0.21648281486704946, 0.21559473127126694, 0.13874149502953514, 0.0930949229223188, 0.13725108437938616, 0.18176112411310896, 0.3641217848053202, 0.40340998442843556, 0.3611796739278361, 0.09039852229761891, 0.13808794494252652, 0.17465893412008882, 0.16376484447391704, 0.25170831999275833, 0.13615108793601394, 0.29700945946387947, 0.14713186043081805, 0.17396876646671444, 0.19281715038232505, 0.23179719544714317, 0.2178297980572097, 0.17361148173222318, 0.3147908131359145, 0.19932657218305394, 0.24925213772803545, 0.11414744833018631, 0.2385518970550038, 0.2565511898137629, 0.35391663084737957, 0.2004813836538233, 0.19252211699495092, 0.22512074589030817, 0.24817856174195185, 0.14505121973343194, 0.17869425821118057, 0.1691523171029985, 0.31943401554599404, 0.2755495172459632, 0.33079124987125397, 0.1172725431388244, 0.25652150390669703, 0.11376514579751529, 0.14877053734380752, 0.2298836418776773, 0.24739040090935305, 0.11030207693693228, 0.1287425245391205, 0.12040247675031424, 0.10665166773833334, 0.2056751260533929, 0.20208053378155455, 0.16572426276979968, 0.19344313710462302, 0.17532498197397217, 0.20747069298522547, 0.19031905161682516, 0.16853290580911562, 0.1135751188849099, 0.08342951812664978, 0.19420046912273392, 0.12690777220996097, 0.23549752891995013, 0.09043329191626981, 0.10452838323544711, 0.11770615776185878, 0.10790871005156077, 0.11718043519067578, 0.10924361107754521, 0.24321098142536357, 0.23883097426733002, 0.14347541757160798, 0.20909604092594236, 0.15543410321697593, 0.17147630802355707, 0.113707666459959, 0.17163426673505455, 0.1223833802214358, 0.17743020260240883, 0.22486448229756206, 0.10808465100126341, 0.20477973972447217, 0.15399645926663652, 0.20379580033477396, 0.12520574557129294, 0.15816482075024396, 0.11525900001288392, 0.1003663448500447, 0.14193188399076462, 0.16580631461692974, 0.24963229545392096, 0.18544323043897748, 0.09824838896747679, 0.13172914943424985, 0.12062092049745843, 0.14698398008476943, 0.19661844562506303, 0.19564268470276147, 0.11074293492129073, 0.16705502261174843, 0.09593650247552432, 0.1624656852800399, 0.1462008510134183, 0.15468070458155125, 0.15267393726389855, 0.12481090816436335, 0.08057597515289672, 0.19171041523804888], [0.03805510270467494, 0.0009901879252538492, 0.04580057146085892, 0.04924318673147354, 0.004434667262103176, 0.04612641510902904, 0.0031359508056993946, 0.024426983691228088, 0.040120321573340334, 0.09078338523977436, 0.038827222015243024, 0.02756271162070334, 0.009698574158392148, 0.02761492542049382, 0.04289013544621412, 0.013923164460720727, 0.06374192103976384, 0.020179956409265287, 0.0963823773781769, 0.024486529910063837, 0.08780670512351207, 0.09778149644262157, 0.04074878335813992, 0.13571519491961226, 0.11961718802922405, 0.04893714729405474, 0.017767186072887853, 0.015392862696899101, 0.04965225110936444, 0.05229296468314715, 0.06760302596376278, 0.022248563182074577, 0.113726257259259, 0.019236586522310972, 0.01588076542248018, 0.05154162921826355, 0.0940728657587897, 0.04684459883719683, 0.013915247600380098, 0.03773304029891733, 0.1068279797618743, 0.016769231224316172, 0.037209763104328886, 0.024522620551579166, 0.0455707580113085, 0.023619343337486498, 0.03602278324251529, 0.03527454624418169, 0.01805340089049423, 0.01676398609561147, 0.03451402299106121, 0.06634994671912864, 0.014090786862652749, 0.0417317319806898, 0.08151774571160786, 0.04029847783385776, 0.020437502062122803, 0.06078922713641077, 0.02244326562504284, 0.01303784258197993, 0.09801680920645595, 0.07198487364803441, 0.03777657468162943, 0.04036669233755674, 0.12932249810546637, 0.05145032278960571, 0.05990869860397652, 0.03477057231066283, 0.14356045285239816, 0.05116162734339014, 0.09444378374610096, 0.05868385065696202, 0.021735779955633916, 0.09185107599478215, 0.07740623274003156, 0.07639870789716952, 0.11973385364399292, 0.09600992314517498, 0.03177537932060659, 0.015034933221613755, 0.04548482102109119, 0.030962848213675898, 0.02658377245097654, 0.11958503819187172, 0.041508304711896926, 0.046505522695952095, 0.05521963146748021, 0.0428429756721016, 0.04210112114378717, 0.044132854309282266, 0.10797590410220437, 0.0663536055071745, 0.10227502993075177, 0.11747966171242297, 0.06352243828587234, 0.030058268530410714, 0.13476471154717728, 0.11550223149242811, 0.05499020764546003, 0.24882719881134108, 0.18885062338085845, 0.08611736178863794, 0.02572460478404537, 0.040791827923385426, 0.08090962248388678, 0.073866752354661, 0.06043166038580239, 0.04343035587226041, 0.01607378504559165, 0.06259408575715497, 0.06949533926672302, 0.0036253872258384945, 0.04497647583775688, 0.10014469502493739, 0.007225367489809287, 0.022722604444425087, 0.04244655377988238, 0.07468360461643897, 0.02210322654718766, 0.0807784181961324, 0.03697091400681529, 0.07901944656623527, 0.03304826277599204, 0.01745450441376306, 0.02697623127460247, 0.017233127327926923, 0.012628050899365917, 0.01424986436177278, 0.029153913346817717, 0.0754891984979622, 0.0965610271668993, 0.030835154284432065, 0.024264451494673267, 0.03133393132884521, 0.06435420029447414, 0.012085065045539523, 0.039541565129184164, 0.039771872106939554, 0.04476791378692724, 0.02292801051225979, 0.03291421235189773, 0.04986865395039786, 0.029170376037654933, 0.02732137632847298, 0.03354932749061845, 0.053114948896109127, 0.018566336257208604, 0.04543026203464251, 0.05969182078843005, 0.023399203782901168, 0.028397579517331906, 0.009269607235182775, 0.033765440894057974, 0.046579804256907664, 0.024602295670774765, 0.06539601235999726, 0.039620518509764224, 0.11569271111511625, 0.0686991038674023, 0.06455440205172636, 0.04440613534825388, 0.045076457972754724, 0.05453847719763871, 0.039619464660063386, 0.04875508733675815, 0.024169610587705392, 0.0645936542423442, 0.06834053521743044, 0.06907658986165188, 0.05954660846327897, 0.06814047446823679, 0.06319987121969461, 0.049190779973287135, 0.01784056963515468, 0.06045237743819598, 0.08182584089809097, 0.030006583510839846, 0.023241623566718772, 0.007256530270751682, 0.06284293529461138, 0.03746594877156895, 0.04004309739684686, 0.035374123908695765, 0.07479553532903083, 0.04339009436080232, 0.053928728666505776, 0.040565777162555605, 0.02149047973944107, 0.035827175379381515, 0.014368207230290864, 0.08444813065580092, 0.057901448890333995, 0.055730533349560574, 0.032586858433205634, 0.080545680684736, 0.030305780346679967, 0.048581473020021804, 0.0968436295806896, 0.04779169430548791, 0.039890430198283866, 0.0568904173996998, 0.03044362871150952, 0.07565871244878508, 0.018079387191392016, 0.033274703164352104, 0.08908007468562573, 0.0182196846435545, 0.01923635645653121, 0.028921044104208704, 0.041023797311936505, 0.022255209114518948, 0.04246134849381633, 0.03957971894124057, 0.07619631680427119, 0.0418583275313722, 0.06184633857628796, 0.05446324939839542, 0.0521892643882893, 0.02966908628877718, 0.02404305399977602, 0.05245247077255044, 0.019776764274865855, 0.02722886947594816, 0.04238808367517777, 0.006655168936049449, 0.01625157023227075, 0.017475522035965696, 0.024357481561310124, 0.029285594464454334, 0.05511283270607237, 0.09646570571931079, 0.02996736471686745, 0.012349961671134224, 0.036518382039503194, 0.025040865984919947, 0.033764513209462166, 0.05833242517837789, 0.06774722525733523, 0.04318776635045651, 0.059712734509957954, 0.04107505745196249, 0.03465137226157822, 0.052791309426538646, 0.042298684566048905, 0.07576182644697838, 0.05381336552090943, 0.1533468277193606, 0.03405701958399732, 0.05993254751956556, 0.0752887518319767, 0.09952348773367703, 0.1076546951662749, 0.3256132558453828, 0.17145575053291395, 0.03882236094796099, 0.06484541299869306, 0.042185121128568426, 0.07063250988721848, 0.08336107726790942, 0.11589637870201841, 0.022609888910665177, 0.09386012912727892, 0.10464542734553106, 0.05444904098112602, 0.07339581512496807, 0.04698648634075653, 0.049408978811698034, 0.11734731451724656, 0.1671581217669882, 0.02642268744239118, 0.04968577020918019, 0.034236370702274144, 0.09717500593978912, 0.027974488548352383, 0.07207520044175908, 0.16229303204454482, 0.13057074596872553, 0.11014436313416809, 0.07145868352381513, 0.06146868930954952, 0.06199767733050976, 0.1708432857412845, 0.15155926113948226, 0.07210846350062639, 0.016662076232023537, 0.054737194659537636, 0.06335432699415833, 0.05335160865797661, 0.04587352457747329, 0.04223932388413232, 0.02460887666529743, 0.0422046915628016, 0.05112685030326247, 0.021547309697780292, 0.021507951751118526, 0.05407364784332458, 0.06458460746216588, 0.05487177200848237, 0.025862024558591656, 0.03523494895489421, 0.019654491734399926, 0.06085953820729628, 0.060385409742593765, 0.023637757876713295, 0.051149081336916424, 0.04706604828243144, 0.05320398435287643, 0.06795259236241691, 0.06401910577551462, 0.020013620705867652, 0.024513310308975633, 0.012402433367242338, 0.024242060899268836, 0.05019620824896265, 0.09846798304351978, 0.02432462297292659, 0.057262789996457286, 0.08097456040559337, 0.013820191470585996, 0.021556632927968167, 0.015712435197201557, 0.023778747381584253, 0.031236105132848024, 0.024118038745655213, 0.06103591702412814, 0.02946136286482215, 0.02652641927852528, 0.02841998681105906, 0.027619272550509777, 0.0055373317263729405, 0.061980515165487304, 0.064388049650006, 0.040953634670586325, 0.0422090962092625, 0.0646393111674115, 0.025554356107022613, 0.047799839376239106, 0.054349715646822006, 0.02779190537694376, 0.028188637115817983, 0.04954941541654989, 0.03749967938347254, 0.0789132303907536, 0.05444212045404129, 0.0449144805315882, 0.013862483683624305, 0.06020215121679939, 0.05207544862059876, 0.03572162342607044, 0.029773751375614665, 0.03290957763965707, 0.08161363119143061, 0.08958658305346034, 0.09437834116397426, 0.17831206700066105, 0.13216207385994494, 0.13688219245523214, 0.17022587824612856, 0.14690912707010284, 0.18309506034711376, 0.12585595599375665, 0.3061966539826244, 0.12262110496521927, 0.12895406631287187, 0.15730628947494552, 0.09891004330711439, 0.17499719018815085, 0.12936169834574685, 0.10889135810430162, 0.0928729613951873, 0.1851612885366194, 0.13719867391046137, 0.1679186598630622, 0.1543267595116049, 0.1244173695158679, 0.2512683451641351, 0.1862572180107236, 0.13769407232757658, 0.17580405314220116, 0.12181402678834274, 0.09259985847165808, 0.1705876603955403, 0.10532655564020388, 0.1669412068440579, 0.218125811079517, 0.14796928502619267, 0.13426068937405944, 0.15796935389516875, 0.138744359719567, 0.2088201994774863, 0.22833390394225717, 0.25202809658367187, 0.21798912232043222, 0.16327470046235248, 0.1730637767468579, 0.17709160514641553, 0.157875724544283, 0.09136220105574466, 0.29911172634456307, 0.17816049075918272, 0.1966708857798949, 0.0980063746101223, 0.06663344713160768, 0.11963081386056729, 0.1173968157672789, 0.08858705114107579, 0.1761045487364754, 0.1964260364184156, 0.21197463880525902, 0.14355297200381756, 0.21804595598950982, 0.08692116709426045, 0.26370976818725467, 0.1558639996801503, 0.1360444413148798, 0.17118649935582653, 0.2006152374087833, 0.1293870055815205, 0.1528343599056825, 0.2590171981137246, 0.3383453929563984, 0.2425464178668335, 0.22415663668652996, 0.19463943463051692, 0.12743422208586708, 0.21580584259936586, 0.1836002105847001, 0.22607231279835105, 0.33204954641405493, 0.2366603704285808, 0.1790771767264232, 0.10282831586664543, 0.11172644386533648, 0.18555927264969796, 0.199153533030767, 0.5040155828464776, 0.2945641422411427, 0.1842080443748273, 0.21701586985727772, 0.11149448560900055, 0.23818011075491086, 0.13642587553476915, 0.19968278822489083, 0.25866586540360004, 0.24855122377630323, 0.18876459362218156, 0.15412657259730622, 0.13424486678559333, 0.39464067842345685, 0.1879782584728673, 0.1575923725613393, 0.3867189644370228, 0.3862188756465912, 0.2588663640199229, 0.19099844328593463, 0.13470637873979285, 0.2848608879139647, 0.19732302578631788, 0.2284303682972677, 0.24277312913909554, 0.09757557272678241, 0.20519681187579408, 0.23433865047991276, 0.08527235244400799, 0.16872758598765358, 0.16387922427384183, 0.07635372632648796, 0.16514051909325644, 0.12012385224807076, 0.20671028847573325, 0.09650696913013235, 0.1704013071139343, 0.29720793943852186, 0.22505515487864614, 0.10666127112926915, 0.21878494211705402, 0.14847324782749638, 0.19074553420068696, 0.14311942417407408, 0.11428179932408966, 0.17006214562570676, 0.1464520680019632, 0.16042819304857403, 0.12576508743222803, 0.13261522923130542, 0.07462570967618376, 0.15138077462324873, 0.13056859374046326, 0.09050168824614957, 0.15949244872899726, 0.12490211811382324, 0.1254203004646115, 0.142537773353979, 0.16542471712455153, 0.15560506435576826, 0.10806452395627275, 0.10507088576559909, 0.1076092386210803, 0.07442168585839681, 0.0795789145922754, 0.0988837935437914, 0.12804048252291977, 0.1516318431822583, 0.25053459859918803, 0.17443585937144235, 0.10997916106134653, 0.10812149863340892, 0.16187484667170793, 0.1134078462200705, 0.1407140790252015, 0.18347569304751232, 0.11752348553272896, 0.22417924250476062, 0.18973134487168863, 0.14811476081376895, 0.12163580002379604, 0.2681208268040791, 0.11774539510952309, 0.12805217877030373, 0.0941696492373012, 0.11369267507689074, 0.13406066573224962, 0.2878572646295652, 0.22212058422155678, 0.13215235172538087, 0.07669454280403443, 0.15016495861345902, 0.22009803884429857], [0.015110080312297214, 0.016080020941444673, 0.017012362513924018, 0.03317059097753372, 0.055439270072383806, 0.03512748226057738, 0.009941216558218002, 0.04757488699397072, 0.03251524118240923, 0.028392492095008492, 0.03751047021069098, 0.06862520080176182, 0.05679275818692986, 0.046209940119297244, 0.015870690767769702, 0.05274497714708559, 0.04003483729320578, 0.04127525178773794, 0.08197145769372582, 0.02195134602516191, 0.021481039620994125, 0.013607442779175472, 0.04274300466931891, 0.022045489313313738, 0.04149603330006357, 0.003994216531282291, 0.052389232369023375, 0.05219821097853128, 0.037630508886650205, 0.014185535001161043, 0.058503775944700465, 0.02930715385446092, 0.010750631572591374, 0.04285700597392861, 0.04054205441207159, 0.04713520160294138, 0.041332630935357884, 0.011471992620499805, 0.04720865566923749, 0.037104712100699544, 0.042251565610058606, 0.02272461380925961, 0.053471899664145894, 0.05493545198987704, 0.09522012216621079, 0.04600212392688263, 0.04928475813358091, 0.05832206108607352, 0.035190212292945944, 0.0064987501809810055, 0.07643721794011071, 0.032527712974115275, 0.03799249141593464, 0.04599057981977239, 0.029246351550682448, 0.04978126235073432, 0.05244935746304691, 0.05636986388708465, 0.07125232194084674, 0.03993363061454147, 0.09135063097346574, 0.05926595418713987, 0.10561625298578292, 0.07284553488716483, 0.10242342978017405, 0.04618095183104742, 0.07811399671481922, 0.02537905897042947, 0.08153572794981301, 0.10147228589630686, 0.06809246493503451, 0.05927374673774466, 0.1309609375311993, 0.21460075804498047, 0.2376680140150711, 0.5477060540579259, 0.6215958204120398, 0.18859020376112312, 0.35430795047432184, 0.44502327335067093, 0.18894074979471043, 0.8466053183656186, 0.8058426494244486, 1.5951044135726988, 0.736638744128868, 1.175313745625317, 0.6640705349855125, 0.2823879331117496, 0.7192748039960861, 0.532690625404939, 0.18002457276452333, 0.2871825930196792, 0.5037939478643239, 0.268381261266768, 0.3133264963980764, 0.4062388138845563, 0.40777307061944157, 0.2423816017108038, 0.06000903696985915, 0.05689688892744016, 0.07401792783639394, 0.12282035677344538, 0.05794446376967244, 0.06385523956851102, 0.07070554464007728, 0.16065422154497355, 0.17643691215198487, 0.08776308910455555, 0.06591163430130109, 0.07033007728750817, 0.0410147022921592, 0.017961816156457644, 0.046442072780337185, 0.06541877402924001, 0.0006868965795092663, 0.028564195381477475, 0.03910994317266159, 0.026437925589561928, 0.02520818503398914, 0.018245127321279142, 0.006840191917945049, 0.06890764736454003, 0.08782295073615387, 0.02293114608619362, 0.062055887683527544, 0.06302551846602, 0.07546749067842029, 0.03073474726988934, 0.0650400560698472, 0.04832851198443677, 0.024378469497605693, 0.018624145850481, 0.037999924024916254, 0.006791540890844772, 0.003140658805023122, 0.08098121747025289, 0.052784492800128646, 0.035107255025650375, 0.03261419173213653, 0.0225497953579179, 0.05462523426103871, 0.07787285067024641, 0.010501996330276597, 0.02628482794534648, 0.07461303379386663, 0.08206461207009852, 0.04963353043422103, 0.0789900946256239, 0.03792374627664685, 0.00772841652178613, 0.013689437109860592, 0.0493761202233145, 0.017230511257366743, 0.05164363741641864, 0.031976887257769704, 0.01891656131192576, 0.045487748793675564, 0.08045660812058486, 0.07439533961587586, 0.051021873514400795, 0.0441569258691743, 0.05509010443347506, 0.03450540665653534, 0.02035432400589343, 0.02396117284661159, 0.017208295066666324, 0.021559328779403586, 0.061623597794095986, 0.05306815277435817, 0.08611124649178237, 0.026409373313072138, 0.021124719678482506, 0.09142676790361293, 0.013178627068555215, 0.008717466989764944, 0.09512006581644528, 0.03999939603090752, 0.026241540326736867, 0.042761131626321, 0.03150087002723012, 0.0520176316058496, 0.09178003019769676, 0.03540925717970822, 0.08527734709787183, 0.04236165950715076, 0.0767637554963585, 0.023305524337047245, 0.02548794316680869, 0.050834165813284926, 0.11540304345544428, 0.03184661065461114, 0.029612399193865713, 0.0673056325467769, 0.02090807378408499, 0.05370983592001721, 0.05532913906790782, 0.01565898572152946, 0.02405571132840123, 0.02299215990205994, 0.039030607586028054, 0.09062069162609987, 0.03144133494060952, 0.01724170841043815, 0.0036655703479482327, 0.04206171310215723, 0.061765722784912214, 0.031665723290643655, 0.0337056126591051, 0.025743848673300818, 0.09454225189983845, 0.015751405371702276, 0.016754351163399406, 0.0361165313370293, 0.02004380014113849, 0.053953928290866315, 0.05684926531102974, 0.03197532503691036, 0.017949277571460698, 0.04313307748816442, 0.0315097275597509, 0.03254563584050629, 0.016739458114898298, 0.03439121981500648, 0.04425222134159412, 0.02383782048127614, 0.04536735388683155, 0.030995825545687694, 0.030737277993466705, 0.036641574843088165, 0.053787690922035836, 0.03201184983481653, 0.021019316154706758, 0.04250255995430052, 0.06397559365723282, 0.05909948675252963, 0.09163640235783532, 0.17314415134023875, 0.08252952306065708, 0.047233050063368864, 0.07469059564755298, 0.14256696944357827, 0.03265346989792306, 0.03522526763845235, 0.09741287911310792, 0.07441425696015358, 0.0659696850925684, 0.04968346212990582, 0.06506229081423953, 0.09276479337131605, 0.15780777350300923, 0.3564345894847065, 0.6362501496914774, 0.6489909254014492, 0.12863890588050708, 0.05456996652355883, 0.11860284284921363, 0.15328712936025113, 0.37961889698635787, 0.6911426573060453, 1.1492712493054569, 0.5945431720465422, 0.5277919163927436, 0.22188039554748684, 0.12200192373711616, 0.20055285247508436, 0.39723487047012895, 0.24881376593839377, 0.2962360525270924, 0.4513883771141991, 0.15798777400050312, 0.30288611131254584, 0.4239625175250694, 0.8400845713913441, 0.2073134170495905, 0.08915578117012046, 0.1038867817260325, 0.15069498564116657, 0.12720706552499905, 0.03488999871478882, 0.07721495159785263, 0.07498128004954197, 0.10640583132044412, 0.12678248283918947, 0.0845219446637202, 0.04584144153341185, 0.1617904644808732, 0.09342462944914587, 0.052204070234438404, 0.07445821436704136, 0.07971467566676438, 0.020833487942581996, 0.020937832050549332, 0.03768291564483661, 0.050537277056719176, 0.027632430828816723, 0.061365519650280476, 0.017472362342232373, 0.04313902209105436, 0.054845010163262486, 0.026264520929544233, 0.013103662731737131, 0.03113051236141473, 0.038848658950882964, 0.028516202546597924, 0.03573998044885229, 0.04950683840434067, 0.033634871142567135, 0.041402036586077884, 0.03801615479460452, 0.028050885230186395, 0.027222819117014296, 0.1841570736723952, 0.02559473450673977, 0.011854977929033339, 0.018250626635563094, 0.030831575277261436, 0.024020841519813985, 0.052846714461338706, 0.059217384332441725, 0.01483950069086859, 0.010838798716577003, 0.05532421491807327, 0.010455860719957855, 0.026577607059152797, 0.06470100590377115, 0.058149036776740104, 0.00946711128563038, 0.05358474692911841, 0.08429093635641038, 0.05681207629095297, 0.0491493124718545, 0.028376268746796995, 0.031209873923216946, 0.019099821693089325, 0.04173228116997052, 0.024796189172775485, 0.04329717376094777, 0.07303957681870088, 0.03260447701904923, 0.04491625426453538, 0.037606982805300504, 0.015489121105929371, 0.048489955079276115, 0.03405616611416917, 0.03447353883530013, 0.02366034699662123, 0.0234479536084109, 0.013349614182516234, 0.017285595313296653, 0.024529041984351352, 0.020735893667733762, 0.04325307905673981, 0.0647051545092836, 0.09655989168095402, 0.10353059537010267, 0.09909901637001894, 0.13138838490704075, 0.14546018763212487, 0.10687190748285502, 0.1437414626707323, 0.11279120313702151, 0.16437548358226195, 0.12884940864751115, 0.1631634376826696, 0.11074421141529456, 0.22496191144455224, 0.1439631570247002, 0.167735141585581, 0.2074496605200693, 0.17279688559938222, 0.22237984609091654, 0.0726795090304222, 0.10594420062261634, 0.07712825390626676, 0.1099271365092136, 0.1452583828358911, 0.1691297854995355, 0.09921605305862613, 0.08090673552942462, 0.12743383616907522, 0.1395009644329548, 0.12585433811182156, 0.10688217138522305, 0.15465849952306598, 0.15374209557194263, 0.2532278228318319, 0.18350309313973412, 0.16191995440749452, 0.148611213080585, 0.09197408697218634, 0.14994062221376225, 0.23192233638837934, 0.09255164113710634, 0.1423097707447596, 0.10263293064781465, 0.21327704860595986, 0.14343075512442738, 0.10096420417539775, 0.1834278690512292, 0.15551550197415054, 0.2002079170779325, 0.10763949598185718, 0.19605257286457345, 0.11610469955485314, 0.12644185189856216, 0.10929722382570617, 0.0931742436659988, 0.15579443075694144, 0.12903617753181607, 0.1526552499854006, 0.18837383802747354, 0.14664042508229613, 0.2900436019990593, 0.27636878890916705, 0.1707315628300421, 0.21678454242646694, 0.2064384100958705, 0.18010344821959734, 0.23757845163345337, 0.11946173777687363, 0.22820926766144112, 0.2586808567866683, 0.1883161731529981, 0.19072208233410493, 0.2924567396985367, 0.49091566703282297, 0.6383146857842803, 0.6778976961504668, 0.6950374483130872, 0.28725333453621715, 0.6924244947731495, 0.6545356591232121, 0.5769352137576789, 1.7695981753058732, 2.0598963042721152, 2.810209267772734, 1.804942691233009, 2.091009272262454, 1.5520659042522311, 0.7516117219347507, 1.4622725662775338, 1.3874650304205716, 0.8674058772157878, 0.45702377159614116, 0.6053434987552464, 0.2260385302361101, 0.40761609154287726, 0.6859940523281693, 1.2901292159222066, 0.6113677786197513, 0.23616197373485193, 0.15215476043522358, 0.19085327920038253, 0.2518112410325557, 0.13523033499950543, 0.14704920002259314, 0.16461858147522435, 0.3492297901539132, 0.3101929707918316, 0.3114241047296673, 0.21712742949603125, 0.3415772086009383, 0.28781178581994027, 0.1649297194671817, 0.15461083879927173, 0.2227975268033333, 0.06269719975534827, 0.12329077449976467, 0.11318414064589888, 0.11100458650616929, 0.127201410359703, 0.2293474698672071, 0.13441452174447477, 0.1515412121079862, 0.1741748460335657, 0.09573330244165845, 0.11809092422481626, 0.0947334365628194, 0.16067369550000876, 0.12294264044612646, 0.3242519195191562, 0.14153688331134617, 0.12450249385437928, 0.09011062837089412, 0.15881281957263127, 0.1052439323393628, 0.1036957158066798, 0.2508029295131564, 0.1692168542649597, 0.11367941289790906, 0.102840628096601, 0.17365057807182893, 0.16311936895363033, 0.18810575944371521, 0.13962610537419096, 0.13954647292848676, 0.2165571483783424, 0.16058410343248397, 0.09760653512785211, 0.3097891533980146, 0.14666591043351218, 0.14345530536957085, 0.13948811043519527, 0.1481529517332092, 0.15005167719209567, 0.1321102274232544, 0.2096758215338923, 0.124829224369023, 0.07681917166337371, 0.23281558533199131, 0.19021293934201822, 0.21810140926390886, 0.0952665509248618, 0.1542388298548758, 0.14395447389688343, 0.10287550161592662, 0.11430561484303325, 0.1041517878184095, 0.1504339129314758, 0.18775472359266132, 0.12833754939492792, 0.1597113674506545, 0.06515182350995019, 0.16810646775411442, 0.2614024607464671, 0.18566192651633173, 0.09954921799362637, 0.10626031100400724], [0.07635515125002712, 0.043600240896921605, 0.09836883211391978, 0.07175543127232231, 0.013338424450921593, 0.02642647425091127, 0.031418398866662756, 0.033326805641991086, 0.007214984379970701, 0.03833416507404763, 0.08285980104119517, 0.05838581157149747, 0.10042038804385811, 0.06756187387509272, 0.05055928915680852, 0.021462847726070322, 0.03897742528351955, 0.028299269069975708, 0.01448146824259311, 0.0461092269688379, 0.05634975910652429, 0.05856110685272142, 0.052229696593713015, 0.05845187384693418, 0.07392753424937837, 0.09556923585478216, 0.037431049277074635, 0.024808837224554736, 0.049282286781817675, 0.03774331162276212, 0.10328069198294543, 0.022740505046385806, 0.043743482819991186, 0.015349308832810493, 0.05347485341189895, 0.023193357992568053, 0.065498317417223, 0.016720839485060424, 0.015300765880965628, 0.10241257958114147, 0.07543481391621754, 0.032250572767225094, 0.021179562536417507, 0.02325858349649934, 0.027005603624274954, 0.04591730386891868, 0.011403010921640089, 0.046725294887437485, 0.04211548912280705, 0.0170883454484283, 0.08716338183148764, 0.03151320452161599, 0.01511041984485928, 0.007312510933843441, 0.026805984452948906, 0.03826636246230919, 0.04038236278574914, 0.04719389806268737, 0.09223452885635197, 0.05229095717368182, 0.12611270940396935, 0.18299623596249148, 0.06509986575110815, 0.15466958720935509, 0.129685363790486, 0.0977309190784581, 0.06204488905495964, 0.13656694296514615, 0.3531238093273714, 0.13502421090379357, 0.07704343384830281, 0.2134729755925946, 1.764653215650469, 9.745466262102127, 20.74032638221979, 32.71850533783436, 48.1303833425045, 49.80970703065395, 80.25387480854988, 72.9221074283123, 83.50650027394295, 94.81304436922073, 94.81907084584236, 96.31533935666084, 104.26828220486641, 98.04257467389107, 83.06721344590187, 92.49460637569427, 89.08862873911858, 91.61097899079323, 93.44186514616013, 60.64134120941162, 40.705475360155106, 45.13538785278797, 33.170141503214836, 24.167385287582874, 16.03612370789051, 3.041084404103458, 0.27384937566239387, 0.21102078608237207, 0.5417930369731039, 0.5782020895276219, 0.19214219675632194, 0.020627165322366636, 0.07081897449097596, 0.11394150234991685, 0.025175851515086833, 0.03308136256237049, 0.1089861526270397, 0.15491538651986048, 0.05074102256912738, 0.07732090060017072, 0.054340754213626496, 0.005880383923795307, 0.03569548498489894, 0.022558029486390296, 0.02912219952122541, 0.033841744807432406, 0.07847896267776377, 0.03582433295377996, 0.026378592738183215, 0.07714250314165838, 0.022307005456241313, 0.04566701456496958, 0.041266921180067584, 0.06930373157956637, 0.02545528310292866, 0.025580635556252673, 0.029484239566954784, 0.005710258628823794, 0.03555527473508846, 0.06778698952984996, 0.024982672330224887, 0.0102494926431973, 0.019021499138034414, 0.024131499449140392, 0.06945025379536673, 0.0449837080668658, 0.06121651123976335, 0.04121678168303333, 0.038906898989807814, 0.10294649546267465, 0.00894569224328734, 0.05227409186773002, 0.0929187741712667, 0.049380569398636, 0.06525524178869091, 0.04611654454492964, 0.01640106474951608, 0.02293761575856479, 0.023673744617553893, 0.039730708886054344, 0.04761810596392024, 0.0062376273763220524, 0.06764633770217188, 0.04430285065609496, 0.015730448976682965, 0.04028918243420776, 0.0349581018963363, 0.041699686044012196, 0.052826528044533916, 0.040250056408694945, 0.02756558187684277, 0.023465624144591857, 0.03655497363070026, 0.04430692133610137, 0.031454741838388145, 0.025279813417000696, 0.0626390970137436, 0.041217245525331236, 0.01600429033715045, 0.028946464517503045, 0.028387987258611247, 0.04980220946890768, 0.018601990886963904, 0.01908021600684151, 0.037660324669559486, 0.038147904560901225, 0.1007254997966811, 0.07954826389322989, 0.05139698463608511, 0.0408597121713683, 0.07907312610768713, 0.02772594514681259, 0.048593696192256175, 0.02534385334001854, 0.04673984098189976, 0.0023354232416750165, 0.019446473306743428, 0.029410071183519904, 0.017938334603968542, 0.02726204904320184, 0.02010696432989789, 0.007688947252972866, 0.011391372190701077, 0.02220829795987811, 0.018041480143438093, 0.07686007142183371, 0.022030432992323767, 0.013039373261563014, 0.046635383696411736, 0.04154588335950393, 0.014970927622925956, 0.05200315972615499, 0.050236035604029894, 0.03143821049889084, 0.020890737214358523, 0.02330794002773473, 0.05027210769185331, 0.08346787974005565, 0.0607838428550167, 0.08104628897854127, 0.01007247929010191, 0.034387279010843486, 0.06315593607723713, 0.008314503993460676, 0.010551681261858903, 0.029719954945903737, 0.025640838575782254, 0.09135378510109149, 0.04152582310780417, 0.02375169424340129, 0.14393704826943576, 0.026439187240612227, 0.051589508875622414, 0.00601365509282914, 0.04646215900720563, 0.08618946885690093, 0.08991234877612442, 0.05523417014046572, 0.052251901652198285, 0.04375846678158268, 0.05976810985885095, 0.03860481891024392, 0.0445944738748949, 0.02646914032084169, 0.13047944696154445, 0.1849406331893988, 0.11302126149530523, 0.08183019730495289, 0.10110973933478817, 0.07332174878683873, 0.03769454138819128, 0.18288570048753172, 0.42837099346797913, 0.24938017304521054, 0.18799549114191905, 0.222655865654815, 1.641624248586595, 11.500504687428474, 23.62954694777727, 34.217110723257065, 50.54187074303627, 55.210326835513115, 91.17309048771858, 84.08868223428726, 95.87815001606941, 111.03600025177002, 112.36467495560646, 112.81179696321487, 122.25766450166702, 117.55297735333443, 100.10402485728264, 109.88808944821358, 105.4041476547718, 105.26572868227959, 106.63206696510315, 75.27880936861038, 50.45576736330986, 56.410758420825005, 41.52458220720291, 29.87046506255865, 19.861828722059727, 4.056134149432182, 0.18860697629861534, 0.17562233086209744, 0.5054585554171354, 0.5417143099475652, 0.08182007441064343, 0.034692991903284565, 0.003892249151249416, 0.15624016465153545, 0.12368449868517928, 0.042547615739749745, 0.02152439032215625, 0.21255720988847315, 0.13636248128022999, 0.07102973700966686, 0.05153695368790068, 0.049942519908654504, 0.045683538482990116, 0.05036830116296187, 0.03415405168198049, 0.07487876719096676, 0.08669498274684884, 0.0238226027431665, 0.04930450668325648, 0.08476079747197218, 0.03897469046933111, 0.0737762103381101, 0.056969730721903034, 0.054990645512589253, 0.04169113279203884, 0.004110120980840293, 0.032434747845400125, 0.030151337559800595, 0.05585346640145872, 0.020653888204833493, 0.042610687160049565, 0.047444491647183895, 0.03754197809030302, 0.048940965643851086, 0.03404698574740905, 0.026458156535227317, 0.05292086614645086, 0.021800582435389515, 0.029904623552283738, 0.03169742783939, 0.05241081402346026, 0.04925695357087534, 0.04207488993415609, 0.05922678734350484, 0.06937267709872685, 0.05104831623611972, 0.008370954528800212, 0.05827474917168729, 0.028320967612671666, 0.06423115220968612, 0.018481544029782526, 0.05638323738821782, 0.010220758540526731, 0.07110757345799357, 0.05377018736908212, 0.02391393885773141, 0.0025138682440228877, 0.018648076402314473, 0.015293210817617364, 0.006258888979573385, 0.045040805198368616, 0.03268895568908192, 0.019884371977241244, 0.03627682781370822, 0.03226719687518198, 0.03579094372980762, 0.0660486941342242, 0.020383705632411875, 0.01248383861820912, 0.04565705494314898, 0.08003315349924378, 0.010207117866229964, 0.04661087798012886, 0.01777986381057417, 0.289778447477147, 0.11523833862156607, 0.25344509398564696, 0.15007217531092465, 0.07527102934545837, 0.08153960938216187, 0.18150993681047112, 0.1096879348915536, 0.11945914026000537, 0.1192597919725813, 0.1775777415605262, 0.08133692885166965, 0.194981089734938, 0.21214217122178525, 0.12145473083364777, 0.15906031097983941, 0.12888464581919834, 0.1534972758963704, 0.1218876701022964, 0.22597071278141811, 0.13726113305892795, 0.15387260966235772, 0.18936846434371546, 0.16530674532987177, 0.25187625316902995, 0.1924609491834417, 0.11563023712369613, 0.12033490420435555, 0.16614022169960663, 0.130343129276298, 0.1956017775228247, 0.16683975525666028, 0.10310622048564255, 0.12015937885735184, 0.13537578110117465, 0.17926072468981147, 0.1249642507173121, 0.08499375762767158, 0.0865178024105262, 0.20777930767508224, 0.13035252486588433, 0.07670350794796832, 0.0624640540627297, 0.27392747928388417, 0.08748253501835279, 0.1334382561617531, 0.18737318547209725, 0.18174519762396812, 0.1483253377955407, 0.18607588164741173, 0.18413761456031352, 0.1206502947025001, 0.17503726616268978, 0.10966636808007024, 0.18567589373560622, 0.1349572098115459, 0.1386312860995531, 0.14998996019130573, 0.2227622747886926, 0.17542502348078415, 0.39918912341818213, 0.3365117241628468, 0.1316657551797107, 0.2517762710340321, 0.17359614896122366, 0.2431710241944529, 0.17001147178234532, 0.6247804057784379, 0.6254917988553643, 0.4047706676647067, 0.27548607846256346, 0.49111797648947686, 3.6817996110767126, 16.451563015580177, 34.93633612990379, 50.33679574728012, 67.2453260421753, 76.15787699818611, 116.99902787804604, 108.39029341936111, 121.95257127285004, 135.27695149183273, 136.69403225183487, 136.35141223669052, 146.50048524141312, 141.03221386671066, 117.84480929374695, 132.14470356702805, 131.07724964618683, 129.5093473792076, 128.06282579898834, 92.86374136805534, 64.37685996294022, 71.23398721218109, 52.61249743402004, 38.08684587478638, 26.562746353447437, 6.046976521611214, 0.6599596899468452, 0.255092364968732, 0.5648164765443653, 0.689116712892428, 0.3220989787951112, 0.1581176053150557, 0.1492674052133225, 0.2961291535757482, 0.37167854025028646, 0.35375911742448807, 0.16864991281181574, 0.38374811760149896, 0.2542788226855919, 0.21520465845242143, 0.27457997552119195, 0.26475245598703623, 0.23692859744187444, 0.11337469448335469, 0.16404901281930506, 0.15374472277471796, 0.12962792156031355, 0.125984555343166, 0.17346296313917264, 0.27344879403244704, 0.11925116821657866, 0.16729233175283298, 0.16055305197369307, 0.18498848687158898, 0.10103737251483835, 0.08775672147748992, 0.08959962258813903, 0.16736482473788783, 0.11273106691078283, 0.11961222306126729, 0.12133376076235436, 0.10319779408746399, 0.07523508713347837, 0.20510218804702163, 0.21332395233912393, 0.11105604702606797, 0.28808456961996853, 0.12810914602596313, 0.1605758210644126, 0.1834182656602934, 0.17248778109205887, 0.13268965180031955, 0.17434821173083037, 0.29440769751090556, 0.23790211707819253, 0.16850088955834508, 0.15933288697851822, 0.27369073417503387, 0.16242603975115344, 0.1486579090123996, 0.19005738518899307, 0.1355947443516925, 0.15105449681868777, 0.08899854976334609, 0.1280236357706599, 0.09496381404460408, 0.09453189151827246, 0.13219646498328075, 0.1301651622634381, 0.10338659645640291, 0.1344877271912992, 0.1537716924212873, 0.14524863101541996, 0.09676876914454624, 0.15255486709065735, 0.11689774371916428, 0.14107749389950186, 0.1611232291907072, 0.09218682360369712, 0.13897075928980485, 0.14666662289528176, 0.13041572616202757, 0.11992952830041759, 0.11564217827981338], [0.06292340636719018, 0.027509828032634687, 0.051978045448777266, 0.030841572006465867, 0.026562788225419354, 0.05662903298798483, 0.07061212309054099, 0.07259278165292926, 0.027104019827675074, 0.01657516331761144, 0.01176546749775298, 0.034562581713544205, 0.041859002885757945, 0.03364388823683839, 0.05518986021343153, 0.07595875533297658, 0.048657880834070966, 0.06003405105730053, 0.0893713824916631, 0.009368010450998554, 0.07249650283483788, 0.004528996087174164, 0.0454969699785579, 0.020351049279270228, 0.017339486366836354, 0.06541339345858432, 0.031600161964888684, 0.0646073765528854, 0.047551308962283656, 0.019816365274891723, 0.030835569887130987, 0.07489119074307382, 0.038207866382435896, 0.03343411648529582, 0.1241322883288376, 0.04187651757092681, 0.006378993984981207, 0.02887469883717131, 0.01382068870952935, 0.11017692857421935, 0.010407865102024516, 0.08306751333293505, 0.008994230556709226, 0.014585361495846882, 0.01804287723643938, 0.012761983507516561, 0.04492292246141005, 0.08605162234744057, 0.020527702690742444, 0.018709244213823695, 0.052378434120328166, 0.018764096348604653, 0.04417792122694664, 0.023810583661543205, 0.031843712567933835, 0.05916632457228843, 0.07737011241260916, 0.03372137958649546, 0.11880333404405974, 0.025458752643316984, 0.12196270123240538, 0.013747563043580158, 0.3064022882608697, 0.4100642289267853, 0.4164563468657434, 0.08856851229211316, 0.4852814303012565, 5.283920466899872, 8.87317081913352, 22.638318836688995, 52.8060894459486, 70.91546550393105, 82.25931599736214, 117.66251027584076, 122.34996914863586, 112.63411089777946, 110.92569217085838, 115.81846922636032, 109.37932714819908, 105.31065747141838, 108.94285216927528, 103.11067432165146, 103.21290403604507, 105.38178965449333, 99.50985834002495, 97.88931369781494, 104.83885198831558, 100.47754481434822, 103.09755742549896, 103.8108779489994, 116.65612667798996, 123.2483321428299, 125.25491327047348, 120.99940001964569, 139.6920257806778, 136.72800242900848, 123.95775407552719, 108.77437680959702, 80.50757199525833, 72.39545568823814, 39.94233191013336, 10.735080409795046, 1.2237147171981633, 0.07391644656308927, 0.11731159494956955, 0.6505893333815038, 0.6509434268809855, 0.5490897735580802, 0.04471431217098143, 0.1615872496040538, 0.05491041192726698, 0.08829350204905495, 0.11582036793697625, 0.05835073396156076, 0.08841025672154501, 0.05860614408447873, 0.033073521772166714, 0.021199773073021788, 0.07841084094252437, 0.06633730052271858, 0.09039493772434071, 0.028394642467901576, 0.03446904513111804, 0.011207733314222423, 0.0184669868031051, 0.05233946394582745, 0.043385277822380885, 0.0533892578096129, 0.06913993958733045, 0.046010528749320656, 0.029616840947710443, 0.0617308900837088, 0.05598625517450273, 0.018096361964126118, 0.03775164223043248, 0.09001445345347747, 0.09750071971211582, 0.03993622070993297, 0.025761584147403482, 0.0434107038017828, 0.036934597010258585, 0.029305689968168736, 0.06816040113335475, 0.033940216671908274, 0.04020010987005662, 0.044786545404349454, 0.01816997188143432, 0.04079544960404746, 0.06209085768205114, 0.014205669467628468, 0.025439820456085727, 0.042562432718113996, 0.038540697350981645, 0.037966690651956014, 0.06183305784361437, 0.0643852146458812, 0.049446872872067615, 0.03368572310137097, 0.03335086235892959, 0.02651343726029154, 0.10471020199474879, 0.052666854971903376, 0.02949194491520757, 0.011049359000026016, 0.05747252464061603, 0.052495062627713196, 0.06923805893165991, 0.03505874454276636, 0.011602474241954042, 0.02240843477920862, 0.03737709514098242, 0.06912246943102218, 0.03367624958627857, 0.03579508491384331, 0.05847227919730358, 0.021413253707578406, 0.04382404666102957, 0.08791913307504728, 0.038866492759552784, 0.007558616844107746, 0.041807508969213814, 0.09791345029952936, 0.062444008653983474, 0.025615581434976775, 0.0292642224667361, 0.0376815463823732, 0.05487492242536973, 0.007433958298861398, 0.08095796598354355, 0.011618101088970434, 0.012945036087330664, 0.026282428952981718, 0.051448612139211036, 0.014555209891113918, 0.09186169612803496, 0.017998984767473303, 0.03142949026369024, 0.030540859333996195, 0.03832881418929901, 0.009062260451173643, 0.035119890089845285, 0.04737397648568731, 0.022085223899921402, 0.007637626349605853, 0.03396614360099193, 0.026098996022483334, 0.036531466103042476, 0.05243022118520457, 0.07942057738546282, 0.020886410493403673, 0.0631956261349842, 0.06781781834433787, 0.03194685996277258, 0.09360894924611785, 0.060933675049454905, 0.03858206466247793, 0.04336169236921705, 0.05627507307508495, 0.06530494341859594, 0.023103838284441736, 0.04263592760253232, 0.01655942978686653, 0.10429949004901573, 0.05284128194034565, 0.10109613576787524, 0.032062794562079944, 0.04119649878703058, 0.026888566935667768, 0.039411971301888116, 0.059792767715407535, 0.05023910809541121, 0.11364414604031481, 0.03277268850069959, 0.03203321997716557, 0.06784825382055715, 0.04594293022819329, 0.1592112341313623, 0.08658654754981399, 0.1440177345648408, 0.3338821465149522, 0.37750318238977343, 0.08811887470073998, 0.49598180456086993, 6.101832278072834, 11.313906200230122, 27.75770243257284, 61.23888574540615, 80.88945910334587, 97.47557669878006, 135.1791599392891, 135.89589267969131, 131.24039769172668, 129.74938809871674, 139.33986067771912, 125.52686467766762, 129.46891754865646, 137.8733217716217, 118.97068127989769, 121.46091565489769, 119.86459091305733, 121.90449625253677, 112.36922711133957, 129.06799346208572, 118.62385869026184, 124.61729988455772, 123.94032821059227, 139.60303455591202, 148.34805250167847, 145.3320935368538, 146.91975474357605, 171.0582634806633, 164.67313170433044, 146.90134853124619, 133.9076265692711, 99.23407673835754, 88.52778643369675, 53.225453943014145, 14.441604819148779, 1.9037599512375891, 0.05487089256348554, 0.0714486645301804, 0.5031622911337763, 0.5830382800195366, 0.6225823424756527, 0.020689878656412475, 0.13444043754134327, 0.04986721418390516, 0.14657991036074236, 0.09531853094813414, 0.0988873558526393, 0.05147847245098092, 0.03607993603509385, 0.06081593703129329, 0.03094215899182018, 0.088460277474951, 0.06681229730020277, 0.0478539308096515, 0.0288421667937655, 0.02383781120443018, 0.08067091068369336, 0.004496727970035863, 0.07023877085885033, 0.05125087802298367, 0.04352612631919328, 0.01313294138526544, 0.0778159502078779, 0.11269741793512367, 0.0253240324309445, 0.053192213890724815, 0.01527181470009964, 0.0638574585900642, 0.053300671352189966, 0.09474860606133007, 0.01353833398752613, 0.015106670143723022, 0.0053690868480771314, 0.022943257936276495, 0.04351972900622059, 0.012873416053480469, 0.01187847525216057, 0.0397207158675883, 0.016829493615659885, 0.05868548709258903, 0.0647124349779915, 0.0544917367369635, 0.029287841316545382, 0.02544736253184965, 0.09055879650986753, 0.0384029139240738, 0.013855801571480697, 0.029998701902513858, 0.06071828152926173, 0.11230071031604894, 0.036191046674503013, 0.04845062496315222, 0.06315404360066168, 0.04013852645584848, 0.04940880069625564, 0.04160565964411944, 0.017717007613100577, 0.044031569705111906, 0.040601752771181054, 0.013237029452284332, 0.02617889749672031, 0.0354514890932478, 0.008961186431406531, 0.03407656404306181, 0.06307149451458827, 0.033732838346622884, 0.0009423559856713837, 0.0347865359071875, 0.0713059792178683, 0.1472820117487572, 0.1605412072967738, 0.16798344935523346, 0.17980804375838488, 0.12339178079855628, 0.17989676009165123, 0.20340179413324222, 0.1315085683017969, 0.1267545038717799, 0.1045647930004634, 0.09847527835518122, 0.0955941274878569, 0.132415606349241, 0.13670400279806927, 0.21917823585681617, 0.09017776304972358, 0.08976376338978298, 0.26363671116996557, 0.2342045889236033, 0.14881766372127458, 0.24775528523605317, 0.09160722111118957, 0.19591861520893872, 0.10139550329768099, 0.13266588823171332, 0.15185904427198693, 0.13320534053491428, 0.11650127358734608, 0.1536380613106303, 0.1107821128971409, 0.16311368410242721, 0.2303519964334555, 0.1680230355123058, 0.19858196057612076, 0.2077798717073165, 0.14329973637359217, 0.09024504615808837, 0.15792347432579845, 0.13573897333117202, 0.163622634136118, 0.05936644098255783, 0.17428631661459804, 0.07492055010516196, 0.07343242526985705, 0.2110427091247402, 0.07631488231709227, 0.22100255358964205, 0.19365230400580913, 0.17409582214895636, 0.13325706822797656, 0.13072039262624457, 0.21606137888738886, 0.09656985130277462, 0.1180785229371395, 0.1307532549253665, 0.21030937816249207, 0.19026627007406205, 0.16217839991440997, 0.28967819816898555, 0.10391093863290735, 0.2437016597832553, 0.22162523033330217, 0.6167099357116967, 0.7382018852513283, 0.6016211828682572, 0.23892693396192044, 1.6118220915086567, 8.379291370511055, 15.628493931144476, 34.48419839143753, 75.82190662622452, 100.17701134085655, 115.46307429671288, 152.88482666015625, 157.00955092906952, 147.13388085365295, 144.02605801820755, 147.87041813135147, 135.93846559524536, 134.77443605661392, 137.20141142606735, 131.1052617430687, 129.07253801822662, 129.8355370759964, 126.82631894946098, 122.4312087893486, 138.19013357162476, 131.03104412555695, 133.94752442836761, 138.26439678668976, 148.77619832754135, 158.64513516426086, 161.52092725038528, 162.44695276021957, 184.82331365346909, 182.8533473610878, 166.07391893863678, 152.0564103126526, 117.2239302098751, 104.9384294450283, 66.38685330748558, 19.60938736796379, 2.366464091464877, 0.2688459644559771, 0.2798968105344102, 0.6516804092098027, 0.9679351234808564, 1.1620569694787264, 0.19927871850086376, 0.26658944960217923, 0.15675316681154072, 0.18811552610713989, 0.3700131905497983, 0.23966425767866895, 0.12369161588139832, 0.1737541373586282, 0.13378228613873944, 0.04623689121217467, 0.14448080502916127, 0.22095749038271606, 0.24153288162779063, 0.06376831923262216, 0.2004919369937852, 0.10773699192213826, 0.09148723067482933, 0.27236698020715266, 0.15401490905787796, 0.19199612725060433, 0.16848840663442388, 0.2600956871174276, 0.24045062251389027, 0.10950039417366497, 0.15394848684081808, 0.11037452539312653, 0.14058317901799455, 0.24440604698611423, 0.17430043226340786, 0.14120551437372342, 0.10781444987514988, 0.19550373981473967, 0.076410418987507, 0.14009440055815503, 0.1091892561817076, 0.08818205373245291, 0.11090801082900725, 0.13071108609437943, 0.18237228272482753, 0.12951989454450086, 0.13258426683023572, 0.10495433889445849, 0.08019667089683935, 0.13432536012260243, 0.23721376026514918, 0.12192514113849029, 0.12725536449579522, 0.1331890281289816, 0.2795876021264121, 0.1299488262156956, 0.12940558895934373, 0.1309919444611296, 0.14536112576024607, 0.18405790789984167, 0.13561380270402879, 0.0973627544590272, 0.16850359097588807, 0.12669418210862204, 0.1605468476191163, 0.14148392365314066, 0.09404818192706443, 0.10637218234478496, 0.08604202637798153, 0.1971782327746041, 0.20346999750472605, 0.21349737740820274, 0.10272545419866219, 0.1477154705207795], [0.058184978988720104, 0.08977795325336047, 0.04009281758044381, 0.018562618097348604, 0.02892962147598155, 0.005261713849904481, 0.06998421420576051, 0.02757491067313822, 0.03854461589071434, 0.06732735520927235, 0.032664101163391024, 0.0548921476729447, 0.03924826094589662, 0.04467340499104466, 0.050160904283984564, 0.03562049096217379, 0.0357278277806472, 0.032573277130723, 0.05653574873576872, 0.10124086940777488, 0.015579520259052515, 0.028025320098095108, 0.039487662943429314, 0.09068983010365628, 0.020790797752852086, 0.026252195712004323, 0.0344482278887881, 0.03012937741004862, 0.046424654574366286, 0.062422642222372815, 0.03864405254716985, 0.028696520312223583, 0.06715220093610696, 0.05542550323298201, 0.021480210270965472, 0.07377809539320879, 0.018928602657979354, 0.02512827984901378, 0.0581956696260022, 0.03151660355797503, 0.0346161425113678, 0.05078906178823672, 0.06198713512276299, 0.027882295253220946, 0.03304387297248468, 0.07785188499838114, 0.015668718988308683, 0.07658158050617203, 0.022532197181135416, 0.02530598339944845, 0.02996906052430859, 0.010761743378679967, 0.07482079803594388, 0.03485301378532313, 0.02951869748358149, 0.03841206089418847, 0.03829762172244955, 0.10701380611862987, 0.15085586841451004, 0.12086883492884226, 0.3491453337483108, 0.03412182762986049, 3.1153585435822606, 11.763502825051546, 22.253885865211487, 54.63334679603577, 74.98178690671921, 87.8255233168602, 96.26154944300652, 119.22666594386101, 106.08645424246788, 105.39055198431015, 101.03657841682434, 61.22390694916248, 63.05435612797737, 79.84715983271599, 85.48136070370674, 71.56072407960892, 93.82196635007858, 58.69999498128891, 73.2776391506195, 85.64814895391464, 72.59201154112816, 92.94530019164085, 86.27803355455399, 96.08452454209328, 79.44522500038147, 114.54904094338417, 87.57480517029762, 83.99260818958282, 88.13358798623085, 73.81132811307907, 92.11598709225655, 90.93219101428986, 65.28217658400536, 86.68464973568916, 89.81538534164429, 105.8988431096077, 117.56225645542145, 104.20286491513252, 120.28624668717384, 104.7449666261673, 88.26656565070152, 76.31444379687309, 60.87513506412506, 39.39977802336216, 25.866129733622074, 9.022698495537043, 0.8826001931447536, 1.0546393459662795, 0.3635640162974596, 0.12603806419065222, 0.15240924287354574, 0.041406248274142854, 0.06406280343071558, 0.15943457605317235, 0.04554384773655329, 0.03137036706903018, 0.08230279694544151, 0.047626336381654255, 0.013877377659810008, 0.08507126753102057, 0.025581988120393362, 0.026997252607543487, 0.01790104724932462, 0.06412860966520384, 0.03186414389347192, 0.02978377407998778, 0.029768326276098378, 0.005567559865085059, 0.015175409716903232, 0.05783943874121178, 0.047151929611572996, 0.11489963726489805, 0.012886404565506382, 0.05290427914587781, 0.0586451253911946, 0.029591329621325713, 0.015699994946771767, 0.027127634966745973, 0.04630025949154515, 0.02519146630220348, 0.04861455425270833, 0.018836301751434803, 0.04546636751911137, 0.026460368135303725, 0.10062991117592901, 0.03025420108315302, 0.029151555172575172, 0.07283495928277262, 0.02744733363215346, 0.07963882817421108, 0.009859403126029065, 0.0643331826722715, 0.01935097559908172, 0.05277596923406236, 0.04936434233968612, 0.018841398450604174, 0.08139865327393636, 0.02620538289193064, 0.01966962227015756, 0.01416021013938007, 0.027279244604869746, 0.0252576807179139, 0.02334306587727042, 0.019238991080783308, 0.04540104368061293, 0.10378685154137202, 0.02846368446626002, 0.059509211641852744, 0.026285273233952466, 0.08820575050776824, 0.04057716541865375, 0.0570473333937116, 0.022137370906420983, 0.0162351594917709, 0.010836572273547063, 0.03295499707746785, 0.005789491706309491, 0.016893607753445394, 0.03148863943351898, 0.030267021684267092, 0.04548438315396197, 0.051731225685216486, 0.015747627840028144, 0.043860500954906456, 0.00933567878746544, 0.02658744422660675, 0.04316745005780831, 0.031471451293327846, 0.08316975901834667, 0.01578439198056003, 0.028858225014118943, 0.052019138165633194, 0.01629661303013563, 0.09447885022382252, 0.03786230387049727, 0.04898047016467899, 0.03640906739747152, 0.04892174772976432, 0.027777272080129478, 0.015776315558468923, 0.02118663705914514, 0.033010877086780965, 0.06926983027369715, 0.03243300008762162, 0.043861818267032504, 0.03534128758474253, 0.03111086400167551, 0.058210902207065374, 0.050962805980816483, 0.017807046824600548, 0.021154333226149902, 0.02663721450517187, 0.03988699034380261, 0.0333176178537542, 0.021178332426643465, 0.07390627171844244, 0.028963771401322447, 0.06269493620493449, 0.030710697974427603, 0.12460432393709198, 0.030563984655600507, 0.056631025654496625, 0.03163513567415066, 0.02879728541302029, 0.020008034189231694, 0.029320480971364304, 0.011640467564575374, 0.06429845016100444, 0.025942809188563842, 0.08242646843427792, 0.04808588535524905, 0.04468697887205053, 0.11258027734584175, 0.08645837122458033, 0.39014275884255767, 0.054392403981182724, 2.929336200468242, 14.300441443920135, 25.56650821119547, 61.574058160185814, 88.93385544419289, 102.48436912894249, 112.37487360835075, 138.03861290216446, 125.121069252491, 132.3395723104477, 117.92206674814224, 88.01230609416962, 104.13420259952545, 110.8102847635746, 129.57277357578278, 105.04786357283592, 134.08449947834015, 95.34303233027458, 97.40800872445107, 135.8963030576706, 116.31102159619331, 135.91922342777252, 130.26538521051407, 148.30833703279495, 107.59326338768005, 154.82769280672073, 128.04703384637833, 116.48994639515877, 133.77019554376602, 114.38840836286545, 122.31533780694008, 116.31397023797035, 98.82426112890244, 114.23848360776901, 117.09233567118645, 129.6328255534172, 141.30619436502457, 121.89697265625, 142.2820883989334, 128.9092379808426, 110.94280645251274, 97.93153703212738, 80.21843031048775, 50.04139959812164, 34.63565446436405, 11.529409736394882, 1.214148374274373, 0.8827222615946084, 0.3335020481608808, 0.035019032220589, 0.13491331919794902, 0.055727345825289376, 0.02345962573599536, 0.23754118097713217, 0.06712336849886924, 0.04985359206330031, 0.05115996493259445, 0.022528454901475925, 0.045302349171834067, 0.17428322928026319, 0.014638607808592496, 0.06601202461752109, 0.06614201920456253, 0.05827024062455166, 0.037432656026794575, 0.022359645990945864, 0.017249621560040396, 0.0857516388350632, 0.03532546499627642, 0.06256970620597713, 0.0428844951238716, 0.035300391537020914, 0.08643483772175387, 0.08183053869288415, 0.027152767797815613, 0.027165326791873667, 0.05201133819355164, 0.02256913201563293, 0.01622501433303114, 0.04260768517269753, 0.0064321609806938795, 0.029845155258954037, 0.028420860689948313, 0.02688073171157157, 0.050861673516919836, 0.020090802208869718, 0.0741024361923337, 0.03978260727308225, 0.04047832248033956, 0.095300103421323, 0.04909809686068911, 0.04763234035635833, 0.0074025900357810315, 0.10039713655714877, 0.10639253945555538, 0.02706219609535765, 0.01844454982347088, 0.004422365700520459, 0.05858367927430663, 0.026772120254463516, 0.046099797982606106, 0.026140302106796298, 0.037233630573609844, 0.03845604798698332, 0.03347682337334845, 0.06656414538156241, 0.02179636332584778, 0.0676541450957302, 0.05416094667452853, 0.02830836223438382, 0.02491642637323821, 0.02816114796587499, 0.05230623057286721, 0.03188330614648294, 0.10170901616220362, 0.15652672271244228, 0.09776983730262145, 0.18936963693704456, 0.07718263106653467, 0.12751118279993534, 0.14275882946094498, 0.2651197894010693, 0.15829241077881306, 0.10055088729131967, 0.11529986266396008, 0.11008948131348006, 0.1378408246091567, 0.11270391914877109, 0.14624653762439266, 0.0740579295961652, 0.1899146256619133, 0.13757967768469825, 0.20662868191720918, 0.32578831363935024, 0.07054504778352566, 0.15934002643916756, 0.15957493102177978, 0.15998018818208948, 0.09665622244938277, 0.14538033254211769, 0.09047784304129891, 0.22896845504874364, 0.17845472262706608, 0.10982397056068294, 0.16212138812988997, 0.15005988534539938, 0.14643029338913038, 0.1574075035750866, 0.11311932146782055, 0.17417846771422774, 0.11760638342821039, 0.09071197579032741, 0.13066584477201104, 0.10869934965739958, 0.06867640899145044, 0.14874034677632153, 0.20005929458420724, 0.18321623821975663, 0.12350484699709341, 0.24077390204183757, 0.12004190430161543, 0.225972686894238, 0.08506184225552715, 0.12733015813864768, 0.09392805048264563, 0.15023745159851387, 0.2085364022059366, 0.12171454189228825, 0.1980788289802149, 0.24514832824934274, 0.07202677530585788, 0.1904452167218551, 0.22267036722041667, 0.2681503049097955, 0.5802887119352818, 0.1755721913650632, 5.578808868303895, 19.80223461985588, 34.89519573748112, 74.68680873513222, 105.67425236105919, 120.41121438145638, 132.5198194384575, 153.87637585401535, 137.87661999464035, 136.72032684087753, 131.07633769512177, 84.81679916381836, 87.10777223110199, 107.05424711108208, 112.66726791858673, 95.9059189260006, 122.739919424057, 80.70076122879982, 98.21877881884575, 115.26815235614777, 100.2146977186203, 119.92576763033867, 115.66604420542717, 123.39638739824295, 103.67198020219803, 146.19110584259033, 119.99921768903732, 111.86439380049706, 117.0577347278595, 100.61765849590302, 121.52704730629921, 119.88767847418785, 88.44219982624054, 113.27528849244118, 120.59675842523575, 135.65459042787552, 150.7421064376831, 137.37962186336517, 159.4633984565735, 151.34273260831833, 126.05287805199623, 110.39989918470383, 91.3944286108017, 61.09621860086918, 43.436996787786484, 17.54864014685154, 1.9280792400240898, 1.3822118123061955, 0.5815288703888655, 0.22501999192172661, 0.34087834297679365, 0.11941718665184453, 0.1267065611318685, 0.5239910515956581, 0.18073719780659303, 0.1392500739893876, 0.25935009587556124, 0.26275643496774137, 0.1239972842449788, 0.23919956933241338, 0.050995182173210196, 0.1348634171881713, 0.2687196509214118, 0.1704689909820445, 0.12107459537219256, 0.14686514739878476, 0.12976227997569367, 0.22910627187229693, 0.08738497228478082, 0.15195598360151052, 0.1203701265330892, 0.10680866165785119, 0.17186452547321096, 0.19425739184953272, 0.17883632011944428, 0.0995495890674647, 0.12331096091656946, 0.1628101902315393, 0.16733748401748016, 0.15332665614550933, 0.20951542857801542, 0.13198565051425248, 0.08265587370260619, 0.16644088056636974, 0.13856213277904317, 0.12926042487379164, 0.10890456833294593, 0.1646600230014883, 0.15274095319909975, 0.18825760285835713, 0.1314443428418599, 0.13118853938067332, 0.09005215455545112, 0.166862613405101, 0.15238967986078933, 0.10992090246872976, 0.16622141265543178, 0.05946476070675999, 0.19170902000041679, 0.15530572651186958, 0.1091324002481997, 0.14989321382017806, 0.09228335475199856, 0.12877847417257726, 0.07900448486907408, 0.19123175967251882, 0.1112608723633457, 0.2760994486743584, 0.1128116567269899, 0.2688590856269002, 0.15560675645247102, 0.12014882551738992, 0.2074266242561862, 0.1214749766222667], [0.03455820675299037, 0.015976502472767606, 0.003145917385154462, 0.0111925118653744, 0.03299435687949881, 0.02491572504368378, 0.05638171969621908, 0.025980680984503124, 0.01686910203716252, 0.03437401683186181, 0.013647861069330247, 0.031242305776686408, 0.04530646438070107, 0.008907544925023103, 0.05741474102251232, 0.10415094177005813, 0.016842607365106232, 0.06856496067484841, 0.024569546549173538, 0.06811642888351344, 0.051177724526496604, 0.04057433041452896, 0.05976092586934101, 0.026512667282077018, 0.07066398437018506, 0.03374703934241552, 0.06595569560886361, 0.023160172859206796, 0.067701375373872, 0.03472805467026774, 0.04114097871934064, 0.026319081771362107, 0.03695439751027152, 0.0799718669441063, 0.05356090914574452, 0.04169749670836609, 0.08195692644221708, 0.03294434725830797, 0.03399544359126594, 0.07395284890662879, 0.02076180389849469, 0.05169090480194427, 0.02509907633793773, 0.028399308721418492, 0.06433266316889785, 0.05584822312812321, 0.06601873363251798, 0.15647823078325018, 0.06622626780881546, 0.04784372627909761, 0.02687303007405717, 0.04870344499067869, 0.07705043972237036, 0.008307838579639792, 0.0665610060968902, 0.13902178936405107, 0.04876380757195875, 0.24345164507394657, 0.17981944314669818, 3.776280116289854, 26.661968529224396, 50.430156737565994, 77.05951541662216, 97.7653643488884, 98.73105213046074, 101.59283816814423, 94.07548114657402, 85.62869399785995, 83.70285853743553, 61.504385098814964, 80.54170176386833, 47.749366387724876, 65.90827658772469, 62.36472733318806, 43.118763864040375, 46.45511403679848, 30.38479406386614, 53.84290561079979, 36.990977078676224, 55.3522340208292, 63.20903442800045, 28.162849992513657, 21.920106075704098, 31.085278876125813, 26.32064424455166, 28.56649663299322, 40.28563588857651, 15.498046930879354, 25.86145408451557, 47.141908183693886, 42.53466300666332, 40.59643641114235, 46.86037749052048, 73.85304987430573, 62.68475756049156, 65.26222765445709, 48.281497433781624, 61.23507834970951, 70.65280079841614, 80.94121232628822, 86.17939844727516, 95.22828608751297, 109.8016668856144, 112.41679295897484, 107.9989904165268, 115.12717992067337, 104.60636526346207, 106.41803205013275, 73.03048521280289, 32.47018486261368, 4.599160635843873, 0.1651176015730016, 0.6141991016920656, 0.30238278675824404, 0.0757745468581561, 0.032645833198330365, 0.03076160002819961, 0.014019068494235398, 0.11141483832034282, 0.08717903372598812, 0.015607588284183294, 0.036613781412597746, 0.04309542833652813, 0.0745485485822428, 0.011638459127425449, 0.02543481095926836, 0.06191322463564575, 0.043024423357564956, 0.02732773653406184, 0.0659522223577369, 0.016628544144623447, 0.039729803465888835, 0.038097100841696374, 0.06945993882254697, 0.015934129551169463, 0.026956247093039565, 0.027367144575691782, 0.01999710606469307, 0.01230543095516623, 0.04512447121669538, 0.047851904746494256, 0.025849330122582614, 0.05806673631013837, 0.03639964583271649, 0.023359818005701527, 0.055233713719644584, 0.029470185145328287, 0.033112195087596774, 0.03750024341570679, 0.036191829640301876, 0.028701184710371308, 0.01918079000461148, 0.02647287146828603, 0.04325200294260867, 0.05730938202759717, 0.06816663517383859, 0.01241682082763873, 0.04173070781689603, 0.005924223978581722, 0.017293330347456504, 0.041847607208183035, 0.02855283866665559, 0.040634782053530216, 0.05127148746396415, 0.028663422381214332, 0.022806578454037663, 0.06412680624634959, 0.005760792855653563, 0.056882999633671716, 0.03256166251958348, 0.03209774600691162, 0.17782668757718056, 0.03386653996130917, 0.06033008263329975, 0.02101531226799125, 0.028719463807647116, 0.02875892194424523, 0.023110725414881017, 0.021099629520904273, 0.05126039977767505, 0.014957510520616779, 0.057086370361503214, 0.07889383807196282, 0.06353961900458671, 0.04558087348414119, 0.0329259716818342, 0.10706300308811478, 0.005775316221843241, 0.004185868283457239, 0.025234607346646953, 0.01614204407815123, 0.11007047491148114, 0.042281782152713276, 0.022942933246667963, 0.036199748356011696, 0.029366694507189095, 0.06463564495788887, 0.027851323575305287, 0.049368999316357076, 0.05403830677096266, 0.026057832801598124, 0.03300241660326719, 0.004155158676439896, 0.027542222778720316, 0.022786586850997992, 0.069740389008075, 0.005611114656858263, 0.04537264539976604, 0.07545396132627502, 0.03753135424631182, 0.014714881108375266, 0.012208114985696739, 0.04884462003246881, 0.06203013144840952, 0.02094631108775502, 0.09212739983922802, 0.011800049724115524, 0.02803833736834349, 0.020538343233056366, 0.053373598493635654, 0.10206676844973117, 0.03424193309911061, 0.04558105159958359, 0.11920704753720202, 0.020167857546766754, 0.07054017929476686, 0.00815493203845108, 0.04078835467225872, 0.032994048888213, 0.028399082366377115, 0.10366588889155537, 0.11809372954303399, 0.025735835333762225, 0.07665048149647191, 0.171972478274256, 5.101712644100189, 32.93961927294731, 62.61452592909336, 94.27550241351128, 118.63545566797256, 114.07049462199211, 122.06688433885574, 110.86792767047882, 116.2043309211731, 110.16213074326515, 90.71213722229004, 110.18175289034843, 81.07912212610245, 108.03061991930008, 72.66195058822632, 56.85775883495808, 73.6022101342678, 50.8723010122776, 58.28406549990177, 60.187930539250374, 53.161233589053154, 68.91737312078476, 42.437224835157394, 35.30516713857651, 46.67634956538677, 44.8028676956892, 40.9751582890749, 55.101352483034134, 40.88941588997841, 52.684590965509415, 70.34506291151047, 67.72856131196022, 64.76330682635307, 70.45043885707855, 109.55631405115128, 87.35545814037323, 96.84674844145775, 92.50138521194458, 111.17995172739029, 108.13809335231781, 118.3073964715004, 124.9457086622715, 119.57452207803726, 140.64621537923813, 133.700370490551, 133.11628103256226, 134.11273956298828, 120.27925506234169, 127.65492528676987, 88.50963860750198, 43.70176658034325, 6.305446727201343, 0.13464939664117992, 0.6468890444375575, 0.30367730010766536, 0.015659904129279312, 0.06128215049102437, 0.041038751587620936, 0.0365076023444999, 0.1056346062978264, 0.11171881458722055, 0.016813784204714466, 0.05513899712241255, 0.04002684807346668, 0.06289697848842479, 0.039898990871733986, 0.03677463450003415, 0.024139420020219404, 0.06454210466472432, 0.03104543069639476, 0.07851435570046306, 0.045373725224635564, 0.02660697755345609, 0.011544507869984955, 0.012609309815161396, 0.06602898269193247, 0.031833166649448685, 0.10043351663625799, 0.10499135722056963, 0.05418022396042943, 0.028810966905439273, 0.023602491019119043, 0.005690619545930531, 0.053171073814155534, 0.03874650974466931, 0.050933075544890016, 0.06015521037625149, 0.0789725650975015, 0.014978183971834369, 0.06525780219817534, 0.013660822678502882, 0.014108167961239815, 0.08860336354700848, 0.018663514929357916, 0.03150015756546054, 0.042854627390624955, 0.02331527430214919, 0.04062762774992734, 0.042491097483434714, 0.01794872838217998, 0.025624383306421805, 0.03406141680898145, 0.04364535976492334, 0.05392614228185266, 0.05051268970419187, 0.012570355411298806, 0.037484376298380084, 0.05361618059396278, 0.04776443151058629, 0.025264445393986534, 0.025967750916606747, 0.06607032031752169, 0.09805583133129403, 0.05652970023220405, 0.026373609216534533, 0.009225511603290215, 0.030833766468276735, 0.13283048174344003, 0.16077419713838026, 0.11316325661027804, 0.1766850269632414, 0.09293965078541078, 0.19517879787599668, 0.12278234396944754, 0.15340685262344778, 0.16693344397936016, 0.10687537331250496, 0.12747116619721055, 0.09367208374897018, 0.12988556554773822, 0.18199225858552381, 0.15350091241998598, 0.21713541500503197, 0.09760803426615894, 0.13692531123524532, 0.08892422367352992, 0.1360497996211052, 0.1681256596930325, 0.18210025591542944, 0.13022471219301224, 0.12134778735344298, 0.14071712183067575, 0.10425134692923166, 0.14628395671024919, 0.20112354919547215, 0.17034426564350724, 0.1522391426260583, 0.09366921163746156, 0.12473209208110347, 0.13765211129793897, 0.19079340272583067, 0.10060268177767284, 0.1439237192971632, 0.19243930815719068, 0.20773019234184176, 0.09359661475173198, 0.23917444021208212, 0.06579906534170732, 0.17976161499973387, 0.0970878555381205, 0.14952933881431818, 0.20683597860625014, 0.13868800102500245, 0.14890520746121183, 0.3668527101399377, 0.26020861230790615, 0.1257268965127878, 0.12786633014911786, 0.14779388584429398, 0.2836345334071666, 0.15689748484874144, 0.3252778941532597, 0.1872928108787164, 0.1251887355465442, 0.5181922658812255, 0.2934464381542057, 6.245389524847269, 43.11123266816139, 78.31239938735962, 110.77841967344284, 132.2532257437706, 131.4041993021965, 130.71781933307648, 119.22598198056221, 110.34303903579712, 104.43790510296822, 79.21881034970284, 100.02102211117744, 64.65335592627525, 85.41703775525093, 83.31227749586105, 58.38512107729912, 64.95410978794098, 39.026702642440796, 75.27212932705879, 54.15095888078213, 76.69494777917862, 84.67044621706009, 39.76436845958233, 30.936467461287975, 45.728270038962364, 38.80523532629013, 36.648801639676094, 63.662794679403305, 22.090112753212452, 36.81042216718197, 66.38693690299988, 59.17628802359104, 55.78546777367592, 66.52465671300888, 98.44801291823387, 89.23618242144585, 93.28744903206825, 73.7118798494339, 83.58095347881317, 101.93055644631386, 108.83992329239845, 112.63061508536339, 120.42997017502785, 140.5246067047119, 141.3676142692566, 138.31950902938843, 147.4799206852913, 135.5733659863472, 142.2293472290039, 102.3641511797905, 54.22679901123047, 8.849204555153847, 0.32926658168435097, 0.8034908724948764, 0.5444296798668802, 0.1626464576111175, 0.13056357682216913, 0.15577795507851988, 0.12522642180556431, 0.30147787125315517, 0.264347183983773, 0.09683516909717582, 0.21367289533372968, 0.10876845844904892, 0.2194998084451072, 0.13258986262371764, 0.08209561157855205, 0.1598447165451944, 0.1450182980624959, 0.15833057201234624, 0.3021154651651159, 0.15028805122710764, 0.14166166802169755, 0.1541537797311321, 0.09671494117355905, 0.12495268805650994, 0.17141194897703826, 0.20426080038305372, 0.174818555242382, 0.17396504088537768, 0.15470955928321928, 0.2078843512572348, 0.05392862105509266, 0.18751434196019545, 0.15629833418643102, 0.108124578546267, 0.20342235162388533, 0.19628637906862423, 0.14841504860669374, 0.16285072633763775, 0.09865001702564768, 0.11271787894656882, 0.15774390427395701, 0.10156643475056626, 0.15823430061573163, 0.08260484362835996, 0.09916730137774721, 0.12040802059345879, 0.1946231073816307, 0.08053522382397205, 0.15715745917987078, 0.16248333355179057, 0.24655067565618083, 0.1510322027024813, 0.16284942015772685, 0.10828540936927311, 0.0946521045989357, 0.15807886520633474, 0.10040652472525835, 0.10797047158121131, 0.1687287140521221, 0.1242710773658473, 0.32102233031764627, 0.1360640488564968, 0.0833621682249941, 0.09472050092881545, 0.1333700231043622], [0.026954052191285882, 0.07899627671577036, 0.0633019462111406, 0.010870725909626344, 0.05937378453381825, 0.03693368416861631, 0.021654091760865413, 0.02824298459017882, 0.05152098266989924, 0.04419484961545095, 0.07817574340151623, 0.04040281637571752, 0.03195667115505785, 0.07731436970061623, 0.042228889287798665, 0.031260206378647126, 0.08341180306160823, 0.057166815458913334, 0.024133833503583446, 0.018830563094525132, 0.031018091831356287, 0.031753408038639463, 0.03568107247701846, 0.029038166139798705, 0.046597051768912934, 0.04696489355410449, 0.04188754588540178, 0.013814726480632089, 0.02381679914833512, 0.14284894103184342, 0.05070792649348732, 0.045378144714049995, 0.05150275923369918, 0.02644106116349576, 0.06081583684135694, 0.033080557332141325, 0.04487146936298814, 0.10120409599039704, 0.052608614932978526, 0.02703247308090795, 0.04640366663807072, 0.022630333223787602, 0.04445841223059688, 0.039669463149039075, 0.029793824614898767, 0.02253460173960775, 0.05551653877773788, 0.07200682637630962, 0.04694441027822904, 0.00760110711780726, 0.04253678780514747, 0.09573365867254324, 0.03302104822068941, 0.03857372663333081, 0.11242908702115528, 0.21198830916546285, 0.16533030109712854, 6.715874103829265, 33.46586063504219, 74.32341903448105, 85.76998561620712, 85.22013992071152, 95.37056565284729, 76.94451838731766, 81.80491358041763, 70.19059360027313, 74.80446562170982, 38.312192782759666, 48.51990044116974, 48.96553672850132, 41.224341318011284, 55.433188676834106, 47.720484137535095, 58.02007086575031, 78.04411098361015, 67.32428580522537, 103.69898915290833, 94.76346462965012, 95.53746029734612, 106.85826882719994, 76.35891661047935, 124.73301887512207, 120.5629250407219, 107.22377881407738, 113.68482291698456, 135.52755564451218, 83.65147769451141, 100.51013186573982, 98.59019368886948, 75.79827949404716, 99.05956730246544, 94.33181539177895, 69.95445147156715, 49.12209592759609, 54.88149248063564, 44.68948557972908, 62.36488692462444, 46.0613601654768, 49.342575296759605, 28.014979027211666, 37.495464608073235, 55.48182226717472, 50.01412846148014, 57.537272572517395, 48.65940995514393, 80.87703377008438, 80.33923342823982, 98.20505395531654, 96.70580640435219, 111.2831237912178, 83.98978114128113, 44.93315890431404, 20.945568569004536, 5.8850695844739676, 1.0165032860822976, 0.13120571267791092, 0.4013184044742957, 0.03483253050944768, 0.02692694339202717, 0.025098302648984827, 0.0066586728007678175, 0.07063579760142602, 0.01411055025528185, 0.046275605345726945, 0.04838916029257234, 0.05723563481296878, 0.03964376628573518, 0.03328336402773857, 0.0159067665663315, 0.09299186087446287, 0.018311325038666837, 0.01748054080962902, 0.04623909910151269, 0.03143128255032934, 0.010640498712746194, 0.02234175095509272, 0.023119319484976586, 0.021466269026859663, 0.05019046031520702, 0.04042454274895135, 0.03599550931539852, 0.03472858530585654, 0.04249103811162058, 0.08174499875167385, 0.041154645368806086, 0.056418782551190816, 0.07629999483469874, 0.03884706704411656, 0.01797101322154049, 0.00533716846803145, 0.026949487983074505, 0.04386213739053346, 0.011709693244483788, 0.041952576575567946, 0.07204754801932722, 0.08475159484078176, 0.016635694737487938, 0.02922078641859116, 0.06667975714663044, 0.034065739819197915, 0.02760029583441792, 0.02326623689441476, 0.061761318138451315, 0.05987434458802454, 0.05535873962799087, 0.05787996000435669, 0.04045868896355387, 0.0177892408464686, 0.028406095661921427, 0.04321529631852172, 0.00328254259784444, 0.028489398027886637, 0.046166116298991255, 0.011000233462254982, 0.024886358260118868, 0.04391318972920999, 0.009439242712687701, 0.09117152105318382, 0.049965611833613366, 0.03394011648197193, 0.04998693002562504, 0.014237889809010085, 0.034172683299402706, 0.01453410877729766, 0.022843704391561914, 0.01366518094073399, 0.022443625566666014, 0.019856407852785196, 0.049834374149213545, 0.07286846725037321, 0.0292831453771214, 0.03422079673327971, 0.03287432933575474, 0.05146708048414439, 0.051787272677756846, 0.06359625229379162, 0.04096916782145854, 0.04968143235601019, 0.01901640986034181, 0.0768715821322985, 0.013999283764860593, 0.03672330756671727, 0.03599400275561493, 0.059889027979807, 0.02438717860059114, 0.02846593317372026, 0.012051044068357442, 0.03119874541880563, 0.022179673323989846, 0.02853645204595523, 0.0248392764115124, 0.0030102050141067593, 0.06850479476270266, 0.07739673324977048, 0.03452289536653552, 0.01925226068124175, 0.03497228433843702, 0.038532893668161705, 0.046965357396402396, 0.05100287453387864, 0.04161143355304375, 0.04058791913848836, 0.011565249042178039, 0.10092295560752973, 0.09234093799022958, 0.00513609561494377, 0.05870064545888454, 0.029802157077938318, 0.0583480473869713, 0.018223154183942825, 0.1315936926403083, 0.058328462109784596, 0.18758972932118922, 8.121794387698174, 40.9392312169075, 91.26774340867996, 105.17052859067917, 98.05509120225906, 106.2146669626236, 91.87723070383072, 104.2029333114624, 100.75840294361115, 113.17867487668991, 66.11444592475891, 62.845416739583015, 51.02946437895298, 51.95490851998329, 40.22548891603947, 36.488404646515846, 46.506468281149864, 38.50086785852909, 34.5426544547081, 38.26684221625328, 62.99947567284107, 50.9143191576004, 74.8774217069149, 51.82215504348278, 54.78194922208786, 51.02540239691734, 58.24080102145672, 47.33202338218689, 54.36984993517399, 50.45859061181545, 30.360275879502296, 33.94699841737747, 44.107106029987335, 46.64171822369099, 41.049383506178856, 40.302184000611305, 38.295238092541695, 36.27991743385792, 42.76570200920105, 40.54260089993477, 36.42769530415535, 56.36954203248024, 43.215183690190315, 54.0744461864233, 87.29468420147896, 97.55634516477585, 101.68993815779686, 89.02839437127113, 113.63230973482132, 111.92776679992676, 115.6551843881607, 118.29529032111168, 128.99265110492706, 107.40299239754677, 62.213100269436836, 28.072922118008137, 8.829868342727423, 1.044149890076369, 0.09856401695287786, 0.22367363213561475, 0.0362282319838414, 0.05314434165484272, 0.04849433375056833, 0.02991247733007185, 0.13555731042288244, 0.04539796747849323, 0.10736022581113502, 0.0781917069980409, 0.046675422563566826, 0.031650345990783535, 0.10579775262158364, 0.0804590126790572, 0.06651545307249762, 0.03247955130063929, 0.04591110693581868, 0.03850479224638548, 0.062358023424167186, 0.032006357942009345, 0.01673546721576713, 0.06973854848183692, 0.046094061181065626, 0.026247689020237885, 0.014324639450933319, 0.0022458798775915056, 0.013572128609666834, 0.05399413414124865, 0.06487688748165965, 0.041449007112532854, 0.04312510682211723, 0.01120017361245118, 0.050203596329083666, 0.02462131691572722, 0.035042439558310434, 0.04095270698599052, 0.04111138186999597, 0.028741154928866308, 0.02730500269535696, 0.02802514012728352, 0.021932515883236192, 0.06677708239294589, 0.01432945506167016, 0.058984587449231185, 0.012681109819823178, 0.03778511680138763, 0.03561707337212283, 0.050282813172088936, 0.050759780351654626, 0.057358360063517466, 0.0492956936795963, 0.019572517812775914, 0.05862172176421154, 0.027552978353924118, 0.05504717490111943, 0.02453568606142653, 0.0442884344374761, 0.03217835066607222, 0.02200323699071305, 0.01979212673177244, 0.003289833734925196, 0.1509120044647716, 0.30734451895114034, 0.13725715514738113, 0.1075878796109464, 0.13147459278116003, 0.07453320096828975, 0.1825336553156376, 0.06455080263549462, 0.10832161133293994, 0.11928244974114932, 0.20489701390033588, 0.11446569609688595, 0.19436353381024674, 0.2558163448702544, 0.24437444633804262, 0.16999759362079203, 0.11214564598049037, 0.1285295726847835, 0.14107373863225803, 0.11308056651614606, 0.14853278291411698, 0.24469646421493962, 0.11900752855581231, 0.18613477848703042, 0.19353920069988817, 0.16201560240006074, 0.15685470745665953, 0.0906194225535728, 0.069137824466452, 0.1694740678067319, 0.08445545565336943, 0.1667885619099252, 0.07662832096684724, 0.0949566597410012, 0.16084968840004876, 0.1081137580331415, 0.1596223987871781, 0.2586145978420973, 0.16218141303397715, 0.128386486612726, 0.1922725624172017, 0.20651333732530475, 0.20201684266794473, 0.17685846687527373, 0.14652245328761637, 0.16955001919995993, 0.1080813113367185, 0.22046572848921642, 0.1539566504652612, 0.09692992651253007, 0.1498457757406868, 0.2673626784235239, 0.14703208609716967, 0.06316170998616144, 0.28034364280756563, 0.5047640239354223, 0.5603353888727725, 11.486427392810583, 53.5045375674963, 107.95811221003532, 116.17632642388344, 110.27396634221077, 116.27930849790573, 97.81231462955475, 100.23807406425476, 88.28600540757179, 96.35067746043205, 52.1632095426321, 69.21187251806259, 68.60554665327072, 58.37517701089382, 74.55080643296242, 67.00211629271507, 85.20756259560585, 118.45453977584839, 97.02183544635773, 156.20113670825958, 130.76413124799728, 127.05204963684082, 145.6329309940338, 112.9870131611824, 178.19858193397522, 167.08379834890366, 152.76463150978088, 160.8711925148964, 185.52764385938644, 114.38702523708344, 137.7150222659111, 132.0225629210472, 104.47444394230843, 132.08328366279602, 133.80750954151154, 92.34093502163887, 67.79161512851715, 77.84060150384903, 62.033981680870056, 83.50586950778961, 59.576452150940895, 68.1614188849926, 40.47384738922119, 54.58296909928322, 80.84855049848557, 72.32238560914993, 84.26091179251671, 72.2956882417202, 109.97528716921806, 105.83880633115768, 125.35205125808716, 123.32661554217339, 142.35688358545303, 119.9691841006279, 73.36065709590912, 35.89666999876499, 12.254391834139824, 1.8902441952377558, 0.24301106168422848, 0.5917986505664885, 0.19147402636008337, 0.13098237075610086, 0.18451515992637724, 0.13576818426372483, 0.4091766203055158, 0.20008611580124125, 0.2904131915420294, 0.2951196546200663, 0.14972979290178046, 0.2433750851196237, 0.1629938420956023, 0.19215144391637295, 0.16138801263878122, 0.200844501669053, 0.13416455156402662, 0.16490322479512542, 0.14164721098495647, 0.17044678592355922, 0.1302026110352017, 0.2287838829215616, 0.12795209273463115, 0.11043080987292342, 0.1424603525083512, 0.09645572383305989, 0.15465461066924036, 0.1450684672454372, 0.14506480103591457, 0.15114552865270525, 0.13638477539643645, 0.21932203439064324, 0.1521729727392085, 0.12615971703780815, 0.12902152753667906, 0.10211979490122758, 0.14989603398134932, 0.1289984764298424, 0.10129978851182386, 0.16695916681783274, 0.2010303651331924, 0.23299816850339994, 0.09922510726028122, 0.1695343598839827, 0.11219738851650618, 0.15692751214373857, 0.19988931308034807, 0.16393809142755345, 0.15258568106219172, 0.1294788537779823, 0.15659914148272946, 0.24243488791398704, 0.15508691169088706, 0.12222753663081676, 0.15148390346439555, 0.08522428353899159, 0.14468563778791577, 0.12107793503673747, 0.08767464736592956, 0.13960824930109084, 0.07136313943192363], [0.04393484559841454, 0.03150760130665731, 0.04027167888125405, 0.056143111796700396, 0.026817072139238007, 0.057019558516913094, 0.02409904347587144, 0.0271656292170519, 0.04854904858802911, 0.056626643272466026, 0.04992912043235265, 0.04984178078302648, 0.05165327791473828, 0.06057589307602029, 0.03614752342400607, 0.023618912891834043, 0.09011091780848801, 0.08404717795201577, 0.05360964598366991, 0.1468522785580717, 0.054802592712803744, 0.06194121844600886, 0.04296858416637406, 0.027012420250684954, 0.030771659839956556, 0.05188296519918367, 0.06774393754312769, 0.025099963204411324, 0.025299415392510127, 0.017012256757880095, 0.014697767182951793, 0.0975525364628993, 0.029677617276320234, 0.04063828870130237, 0.05879531010577921, 0.03908909624442458, 0.01161155534646241, 0.021807115190313198, 0.021383161474659573, 0.06527487901621498, 0.023337323509622365, 0.0914725213078782, 0.0595686020096764, 0.03286717132141348, 0.07624007383128628, 0.004541768912531552, 0.0459532423701603, 0.125843042624183, 0.03696909574500751, 0.03697902197018266, 0.07516068682889454, 0.011912545396626228, 0.09368147933855653, 0.08118239886243828, 2.054442409425974, 21.065459735691547, 52.39134170114994, 78.9629852771759, 85.5005344748497, 79.39099431037903, 93.86453166604042, 77.58825704455376, 63.156498447060585, 72.42259383201599, 39.085151106119156, 40.95848098397255, 34.04201611876488, 62.81313367187977, 83.84718999266624, 62.66622215509415, 76.07448667287827, 89.05843555927277, 109.16799768805504, 65.07614403963089, 63.93636479973793, 78.53128284215927, 75.56844502687454, 57.22614146769047, 69.70944821834564, 41.563104540109634, 48.59902739524841, 47.095455676317215, 54.70294766128063, 47.62612760066986, 60.982851684093475, 60.642253160476685, 57.21802890300751, 102.01268523931503, 102.1091240644455, 84.04468819499016, 102.83452793955803, 97.59168326854706, 93.30071032047272, 123.54819685220718, 110.8979232609272, 124.18119728565216, 138.38194727897644, 161.5180242061615, 108.25749814510345, 85.5718794465065, 85.3723369538784, 51.5441619604826, 57.43751272559166, 42.458621487021446, 41.54568247497082, 36.065209954977036, 44.55841541290283, 57.987153232097626, 64.5499786734581, 76.14110469818115, 82.70385414361954, 100.85676446557045, 97.36930400133133, 85.68156436085701, 65.24137437343597, 30.591670162975788, 4.928577784448862, 0.2338978592888452, 0.3529197780881077, 0.19207486911909655, 0.17266490205656737, 0.11033711372874677, 0.03836535383015871, 0.047964347540983, 0.10852821782464162, 0.015052231756271794, 0.01100054145354079, 0.043088949387311004, 0.050586700381245464, 0.03450379619607702, 0.04548507335130125, 0.043418900822871365, 0.0505543130566366, 0.014823666042502737, 0.06061678912374191, 0.02189647904742742, 0.06082523243094329, 0.04158419673331082, 0.0400050215102965, 0.023806657700333744, 0.03719242653460242, 0.03588741550629493, 0.0659646384883672, 0.03388128643564414, 0.03948953315557446, 0.07258043231558986, 0.052982690758653916, 0.03793144234805368, 0.018400813205516897, 0.03506850007397588, 0.04289997632440645, 0.03979599932790734, 0.018325448108953424, 0.038262262096395716, 0.03192547497747, 0.030300030557555147, 0.00950865764025366, 0.01200921940835542, 0.011318141696392559, 0.031722334315418266, 0.03655043168691918, 0.033902381983352825, 0.0736030079133343, 0.03674695239169523, 0.037133425794309005, 0.035983612688141875, 0.01721826210996369, 0.07237549565616064, 0.028597749733307865, 0.017725809484545607, 0.0454213451303076, 0.065693123760866, 0.06580434943316504, 0.0069074119437573245, 0.04614847544871736, 0.03248731045459863, 0.03400337714992929, 0.07865586841944605, 0.06588328426005319, 0.05748104820668232, 0.03387349017430097, 0.037813867602380924, 0.04444916507054586, 0.03038814575120341, 0.032371698689530604, 0.05270669345918577, 0.03957880238885991, 0.046545364893972874, 0.027134223382745404, 0.024286747466248926, 0.07069801184115931, 0.06690399706712924, 0.039573458925588056, 0.03808776462392416, 0.04938670324918348, 0.05920478637563065, 0.06162935314932838, 0.0668818291160278, 0.035799942270386964, 0.03128035939880647, 0.03677542488730978, 0.07072996129863895, 0.04121151985600591, 0.04883960682491306, 0.043095020155305974, 0.04221685536322184, 0.1285976721555926, 0.006647762302236515, 0.06349011775455438, 0.041118231893051416, 0.042339584324508905, 0.02656476790434681, 0.040723821221035905, 0.014141408755676821, 0.041118851586361416, 0.09508419039775617, 0.02196934867242817, 0.04001968634838704, 0.015931205489323474, 0.04676733384258114, 0.03481948726403061, 0.016211538786592428, 0.037229923545964994, 0.08957240803283639, 0.01801410602638498, 0.0423330571356928, 0.03017454822838772, 0.025421272330277134, 0.14752076065633446, 0.00977036303083878, 2.127680154517293, 24.877618476748466, 64.01176035404205, 97.26854860782623, 103.45242038369179, 96.58900067210197, 112.63649716973305, 109.50579196214676, 106.18939071893692, 100.82622930407524, 74.99221354722977, 66.27061754465103, 44.27090764045715, 40.14015309512615, 60.751801282167435, 50.744783654809, 48.922853618860245, 74.79058116674423, 83.56575429439545, 70.41287407279015, 71.62119403481483, 83.95155519247055, 83.03374484181404, 69.61903586983681, 72.75364726781845, 50.972494035959244, 58.24057303369045, 55.595857948064804, 57.18023233115673, 50.68944722414017, 61.44928805530071, 66.66095539927483, 58.586806654930115, 88.2382495701313, 86.71827793121338, 80.84831491112709, 90.82771182060242, 91.01210832595825, 91.17489919066429, 93.23219239711761, 86.35172680020332, 90.63608050346375, 105.40308371186256, 108.1323404610157, 78.61658066511154, 45.599171966314316, 46.05104371905327, 39.885825142264366, 30.063017830252647, 38.15290153026581, 40.09605646133423, 63.04703392088413, 78.63114148378372, 98.44228282570839, 104.5598329603672, 106.34370043873787, 103.38823422789574, 113.97002041339874, 117.27195203304291, 106.23101368546486, 85.95318138599396, 41.86355821788311, 7.518723523244262, 0.37041053641587496, 0.1929083009599708, 0.24549378314986825, 0.06843590861535631, 0.09655189875047654, 0.05042042590503115, 0.008781717497186037, 0.038801907357992604, 0.035215356256230734, 0.008796409238129854, 0.01852522498666076, 0.045314754170249216, 0.02265375169372419, 0.021447045546665322, 0.03172064964019228, 0.056329409417230636, 0.040109226465574466, 0.03680190471641254, 0.03215338110749144, 0.02024596858973382, 0.040615901816636324, 0.030992075844551437, 0.02943571609648643, 0.011654220488708233, 0.018007276412390638, 0.006426706659112824, 0.009478181345912162, 0.04465096986677963, 0.04227451281622052, 0.05208394992223475, 0.05321218879544176, 0.026814242701220792, 0.027759896547649987, 0.0697764648066368, 0.0808173067343887, 0.0029737282238784246, 0.026641377953637857, 0.04981584272172768, 0.02514042324037291, 0.05116649954288732, 0.022869779750180896, 0.020211249066051096, 0.029232978049549274, 0.02634831496834522, 0.07617581126396544, 0.05762843131378759, 0.08830844148178585, 0.0739646416332107, 0.008397540113946889, 0.04485447418119293, 0.016007004742277786, 0.022070755730965175, 0.05261965809040703, 0.008625705995655153, 0.02380132722464623, 0.0657440944632981, 0.023858147906139493, 0.056339966467930935, 0.022446768562076613, 0.15145911573199555, 0.1522727619158104, 0.11658258328679949, 0.182488547579851, 0.18375252897385508, 0.13520762528060004, 0.14032091887202114, 0.11405881363316439, 0.1192424850887619, 0.15237553452607244, 0.20814052579225972, 0.19318571576150134, 0.12289918027818203, 0.13198848551837727, 0.1626505542662926, 0.15851178963202983, 0.18258487834827974, 0.12005014214082621, 0.261698518297635, 0.26654587069060653, 0.12403761997120455, 0.12398268620017916, 0.11789819589466788, 0.19585666072089225, 0.14945233357138932, 0.15440646617207676, 0.1611346731078811, 0.14128427108516917, 0.12378358282148838, 0.16070609766757116, 0.1516069663921371, 0.1861336504225619, 0.11593569768592715, 0.1987140777055174, 0.11973766086157411, 0.1294623187277466, 0.0861139404878486, 0.08822860865620896, 0.10861346832825802, 0.23761005228152499, 0.16243884922005236, 0.1686496307956986, 0.12577105429954827, 0.15451579936780035, 0.2319935231935233, 0.08024168215342797, 0.15886558627244085, 0.2298759383847937, 0.1627922896295786, 0.1348865870386362, 0.15086358675034717, 0.1262532128021121, 0.2679129067109898, 0.13786586467176676, 4.295361712574959, 35.305946096777916, 80.02696618437767, 113.8203464448452, 113.47411662340164, 101.15963861346245, 113.5176394879818, 102.88596197962761, 84.14803504943848, 92.35276758670807, 55.491439551115036, 58.04857313632965, 45.39354220032692, 89.76893663406372, 110.35585194826126, 89.5253849029541, 109.77319121360779, 131.83711767196655, 156.60219758749008, 99.84907373785973, 97.7780632674694, 120.5061636865139, 113.91645088791847, 84.52929899096489, 106.75251290202141, 62.44435966014862, 74.99307230114937, 73.59654083848, 84.83397424221039, 73.31417039036751, 92.10364535450935, 89.9012379348278, 85.3441196680069, 153.20560544729233, 151.16430938243866, 122.176523655653, 154.0974023938179, 140.6770697236061, 130.9471446275711, 170.59798657894135, 159.13971662521362, 175.3637060523033, 192.0286238193512, 219.04102474451065, 147.83801347017288, 120.84387436509132, 119.11582589149475, 70.4812628030777, 75.53692951798439, 56.89846225082874, 55.4569336026907, 53.76773424446583, 58.79686698317528, 77.65591621398926, 87.1317033469677, 102.00848266482353, 105.64203009009361, 126.93826854228973, 126.95586159825325, 121.08604297041893, 99.54138144850731, 55.794116109609604, 10.178865306079388, 0.6585089396685362, 0.3826195187866688, 0.46321654866915196, 0.34027752990368754, 0.2092916116816923, 0.1705012595630251, 0.18062805756926537, 0.1844512313255109, 0.12648077012272552, 0.14634950319305062, 0.2017902649822645, 0.16684606351191178, 0.1388795641832985, 0.17703720572171733, 0.1618936230079271, 0.12931510631460696, 0.13941364333732054, 0.18254131427966058, 0.2788160357158631, 0.13762879301793873, 0.11629153523244895, 0.10105770736117847, 0.09600437188055366, 0.1296445753541775, 0.13447224599076435, 0.13534588739275932, 0.12722826126264408, 0.14225256600184366, 0.14096683968091384, 0.1286558565334417, 0.27397375961299986, 0.11428870871895924, 0.09321945530246012, 0.23654250253457576, 0.0890450898441486, 0.07051749926176853, 0.14738123689312488, 0.11541246873093769, 0.12227941275341436, 0.15120408410439268, 0.13201005232986063, 0.09330582644906826, 0.11892067501321435, 0.08638506187708117, 0.15522202709689736, 0.11538759936229326, 0.2341811073711142, 0.13347735250135884, 0.09551603870932013, 0.20262724428903311, 0.17994743393501267, 0.08737101990845986, 0.06991125366766937, 0.12054899154463783, 0.15063692000694573, 0.2051480082445778, 0.15109451342141256, 0.15367821149993688, 0.11228865041630343], [0.07490417090593837, 0.030493395279336255, 0.06915443373145536, 0.01546028774100705, 0.002402605928182311, 0.010465566156199202, 0.019362170896783937, 0.050775120544130914, 0.07051165855955333, 0.062204328351072036, 0.04521961454884149, 0.04579376596666407, 0.04970521818904672, 0.014973129946156405, 0.0030592955317843007, 0.07734715778497048, 0.016948413503996562, 0.004752794429805363, 0.050178303936263546, 0.018349181991652586, 0.04181115662504453, 0.0760610900761094, 0.021878838197153527, 0.0720395625103265, 0.04644174623535946, 0.043971322156721726, 0.02833477712556487, 0.025636378268245608, 0.01613029216969153, 0.051589497743407264, 0.03139235690468922, 0.03670464997412637, 0.02058318379567936, 0.010766363247967092, 0.03285664766735863, 0.02548315631429432, 0.02508485493308399, 0.07056219881633297, 0.014361492649186403, 0.02710524437134154, 0.046425971886492334, 0.055696554118185304, 0.04965226224157959, 0.019891129231837112, 0.03531034373736475, 0.09361636330140755, 0.07274248026078567, 0.1320554717676714, 0.06639152925345115, 0.024391150946030393, 0.11450384990894236, 0.10720616337493993, 3.0706256814301014, 13.79679461941123, 50.09320981800556, 71.22649401426315, 82.97986373305321, 78.00233602523804, 73.56991946697235, 57.00598508119583, 60.21583244204521, 31.906200125813484, 23.351474069058895, 43.706755712628365, 50.984216406941414, 63.728626146912575, 81.94893345236778, 97.68002092838287, 89.70577642321587, 58.95628742873669, 48.731233701109886, 21.65829822421074, 10.764430984854698, 8.932552132755518, 4.516328880563378, 1.7714487947523594, 1.139972792007029, 0.45367526065092534, 0.608613045187667, 0.34109344705939293, 0.6917024147696793, 0.6816908426117152, 1.1636500339955091, 0.6946291483473033, 1.4674709248356521, 0.7959650794509798, 0.5082180385943502, 1.6269246186129749, 1.1431641457602382, 0.41360614355653524, 0.4310280899517238, 0.7868091145064682, 1.1501149227842689, 2.7301501762121916, 6.055983463302255, 10.904998742043972, 9.709158260375261, 17.454714886844158, 33.19580152630806, 62.093482688069344, 64.31934624910355, 96.94205492734909, 139.67880249023438, 120.08234202861786, 110.71943163871765, 67.96689212322235, 54.79980066418648, 36.503068059682846, 55.67779675126076, 41.881124675273895, 47.57921911776066, 61.182671561837196, 79.64000254869461, 83.31629768013954, 76.86735972762108, 95.27191534638405, 84.20810982584953, 52.18525975942612, 22.34739314764738, 8.866419531404972, 1.2561719818040729, 0.8492264652159065, 0.03465471192612313, 0.1899332832545042, 0.079489500640193, 0.03261571313487366, 0.06055358040612191, 0.0571357268927386, 0.08649605006212369, 0.027821671064884868, 0.10696903234929778, 0.008582008340454195, 0.09310704961535521, 0.020998356048949063, 0.02971817935758736, 0.06985747022554278, 0.036489026388153434, 0.035481857776176184, 0.016707881586626172, 0.03452706252573989, 0.034513269711169414, 0.02651410519320052, 0.044630764896282926, 0.014097261173446896, 0.03114375598670449, 0.04321339642046951, 0.012029833487758879, 0.0608545324212173, 0.08080284969764762, 0.07161711720982566, 0.05567704305576626, 0.024045007703534793, 0.01910148966999259, 0.02340392198675545, 0.08379541919566691, 0.029838453665433917, 0.00029016399992087827, 0.025160175500786863, 0.018479757309251, 0.04675819800468162, 0.023798902257112786, 0.025363974818901625, 0.03304874146124348, 0.022893062778166495, 0.027089236245956272, 0.0526070267369505, 0.05968998397293035, 0.03925125922251027, 0.07008807777310722, 0.0731094426009804, 0.02797957968141418, 0.06281793233938515, 0.057816780972643755, 0.05453333040350117, 0.022849212982691824, 0.02551094046793878, 0.06703172068228014, 0.024318129180755932, 0.02456223824992776, 0.02435798251099186, 0.0315442967985291, 0.06838221423095092, 0.021902132357354276, 0.07065855927066877, 0.01926016640936723, 0.09207356444676407, 0.05455201397126075, 0.008797172722552205, 0.07105705546564423, 0.017177644367620815, 0.009909566742862808, 0.027183045567653608, 0.03416463470784947, 0.05257937802525703, 0.004265545721864328, 0.039912898719194345, 0.029259856783028226, 0.060314890870358795, 0.06479315838078037, 0.006868599939480191, 0.09136178545304574, 0.03473867480352055, 0.043017354400944896, 0.03573195412172936, 0.04240982489136513, 0.017474178748670965, 0.032480857480550185, 0.007948935963213444, 0.02382287919317605, 0.05281261277559679, 0.06315670048934408, 0.07169994089053944, 0.01576878275955096, 0.13527217728551477, 0.05433688762423117, 0.04292926147172693, 0.05223197498708032, 0.0541862056707032, 0.10028461954789236, 0.08154686016496271, 0.0365664732089499, 0.07873803901020437, 0.06353394899633713, 0.09739246263052337, 0.04299563173844945, 0.051464987627696246, 0.08995790922199376, 0.06579152512131259, 2.7306773979216814, 16.79377645254135, 66.26685574650764, 89.41190019249916, 96.17865309119225, 88.3164493739605, 92.51223742961884, 93.51316452026367, 96.71469792723656, 58.35812732577324, 30.29406253248453, 44.14057843387127, 30.111250542104244, 26.870541237294674, 40.61121381819248, 81.2318055331707, 99.40879136323929, 66.18873953819275, 56.06077820062637, 29.228386916220188, 16.64025519043207, 11.40067644417286, 5.824880339205265, 2.1571556478738785, 0.45656681642867625, 0.18579241092083976, 0.29783888370729983, 0.32835421501658857, 0.38315244019031525, 0.7964218268170953, 1.2885302142240107, 0.7349767489358783, 1.0687074973247945, 0.9046681027393788, 0.367478400003165, 0.973291351692751, 0.502825059229508, 0.20705500122858211, 0.2085011056624353, 0.5579169967677444, 1.1379390698857605, 3.365713097155094, 7.726840255782008, 12.88237938657403, 12.661373745650053, 21.21307611465454, 36.52518667280674, 63.12207229435444, 70.76617911458015, 83.57838481664658, 104.52582478523254, 82.377018481493, 67.09537088871002, 34.10848595201969, 24.158613458275795, 34.20887656509876, 59.36120890080929, 72.47386068105698, 83.44862177968025, 101.16864413022995, 94.42051783204079, 99.41702172160149, 85.7125099003315, 115.15943259000778, 103.23963940143585, 67.46673256158829, 31.024656929075718, 15.40793476626277, 2.0992940152063966, 0.7513102318625897, 0.052652509257313795, 0.12509501713793725, 0.06159184871648904, 0.029538763301388826, 0.04070880386279896, 0.056389404635410756, 0.07664107106393203, 0.04760917792737018, 0.024530379705538508, 0.08816160014248453, 0.018644731171661988, 0.02876235252188053, 0.017814724342315458, 0.02550047433032887, 0.0531735600088723, 0.027306440606480464, 0.019606508176366333, 0.05056972004240379, 0.05336483372957446, 0.0496098781877663, 0.03964910974900704, 0.008035737555474043, 0.047583978303009644, 0.024206912785302848, 0.02491874372935854, 0.07145513605792075, 0.02677134285477223, 0.022766701004002243, 0.0051270673884573625, 0.023513830346928444, 0.02594614514237037, 0.08170406930730678, 0.06681404134724289, 0.034644781990209594, 0.015218262251437409, 0.03679407134768553, 0.056117578205885366, 0.09144354786258191, 0.027506603400979657, 0.030544573783117812, 0.04870349323027767, 0.07545917120296508, 0.034841647793655284, 0.05365274992072955, 0.04136278439546004, 0.05238362915406469, 0.05568771142861806, 0.04226416727760807, 0.03715941580594517, 0.04310133583203424, 0.07135301653761417, 0.02522325434256345, 0.017974668298847973, 0.07878125426941551, 0.24620676442282274, 0.12739931145915762, 0.12663835776038468, 0.10016273663495667, 0.06434912400436588, 0.12711380724795163, 0.0960003345971927, 0.16071769001428038, 0.20622712065232918, 0.2719233540119603, 0.14677071652840823, 0.13645052968058735, 0.19205448974389583, 0.14284503733506426, 0.11958903094637208, 0.116065425099805, 0.11860792656079866, 0.10061483815661632, 0.095745265862206, 0.09176833395031281, 0.11954505869653076, 0.17821327230194584, 0.09020922268973663, 0.18496825592592359, 0.11064780643209815, 0.13076422386802733, 0.13687282655155286, 0.08445683604804799, 0.12055009734467603, 0.09918240408296697, 0.17435198184102774, 0.14949708507629111, 0.257465218892321, 0.09523111337330192, 0.15044443658553064, 0.17519233049824834, 0.10197859388426878, 0.243450264679268, 0.11851692441268824, 0.1175616096588783, 0.09675537337898277, 0.12536548543721437, 0.15296598721761256, 0.22770586889237165, 0.18108593299984932, 0.218832261452917, 0.12831767468014732, 0.2848149341298267, 0.14958051731809974, 0.25872603873722255, 0.3254788677440956, 0.1900917020975612, 4.701726157218218, 26.444502398371696, 87.99645334482193, 102.87757962942123, 108.28647539019585, 98.51982906460762, 97.02910825610161, 77.94403195381165, 74.81708094477654, 43.46987642347813, 33.84869769215584, 57.588235437870026, 70.8340434730053, 93.23453307151794, 130.3498774766922, 137.85663306713104, 120.21811634302139, 91.29191011190414, 76.04905843734741, 34.808849170804024, 17.587209977209568, 15.130353011190891, 8.080666344612837, 3.594843177124858, 1.3922655978240073, 1.2140792654827237, 0.9913312399294227, 0.8622651686891913, 0.9519413067027926, 0.9133683890104294, 1.630588334519416, 1.1905204108916223, 1.7650175211019814, 0.8473231829702854, 0.6132987281307578, 2.08599591627717, 1.1266664997674525, 0.9667142014950514, 1.0822675446979702, 1.450529177673161, 2.1377562638372183, 5.65861408598721, 11.267960015684366, 19.690948091447353, 15.471966080367565, 28.857754804193974, 51.48778438568115, 95.51244243979454, 94.88678321242332, 145.11348366737366, 198.28973025083542, 170.34207791090012, 151.54527693986893, 99.60007309913635, 78.68628412485123, 52.487867921590805, 69.11721959710121, 54.778875187039375, 64.31149587035179, 85.48677921295166, 100.85070759057999, 103.87327060103416, 98.23838576674461, 124.48275670409203, 119.4373570382595, 78.17034780979156, 39.54589918255806, 22.93340340256691, 2.8574903681874275, 0.9963895403780043, 0.2656904119066894, 0.25516675785183907, 0.25270555866882205, 0.1893594249850139, 0.15628613327862695, 0.18675588187761605, 0.16513332026079297, 0.1384981002775021, 0.1696451922180131, 0.1470683771185577, 0.14799036202020943, 0.11309851164696738, 0.1483360247220844, 0.10878511966438964, 0.10196439659921452, 0.0724935565085616, 0.10116802019183524, 0.21764394943602383, 0.20347724086605012, 0.09193222984322347, 0.20769701834069565, 0.07718892447883263, 0.16687203868059441, 0.21902606589719653, 0.1996195869287476, 0.15636345022358, 0.16202533937757835, 0.09634538131649606, 0.1606080896453932, 0.137866873992607, 0.1726788395899348, 0.17222463036887348, 0.13833225995767862, 0.09033891299623065, 0.10979484868585132, 0.09815018056542613, 0.177220263867639, 0.19676360971061513, 0.1023979221645277, 0.21942908177152276, 0.12537657312350348, 0.10210875916527584, 0.0672328427026514, 0.12234950117999688, 0.16126684960909188, 0.16489087545778602, 0.18278255680343136, 0.1582918022177182, 0.21139842050615698, 0.14580726041458547, 0.10654467230779119, 0.13006549183046445, 0.14561652846168727, 0.2628750301664695], [0.044436593088903464, 0.036242436690372415, 0.028424456395441666, 0.09577677745255642, 0.05393969389842823, 0.03814652045548428, 0.02843538637534948, 0.017800104033085518, 0.09862240171059966, 0.06266078256885521, 0.0775731194880791, 0.004135517738177441, 0.020930649916408584, 0.04264511168003082, 0.045119124042685144, 0.02287807139509823, 0.03532514958351385, 0.08899384454707615, 0.07442509973770939, 0.014195518742781132, 0.054457679580082186, 0.08525788798579015, 0.011003376457665581, 0.018645413947524503, 0.029827280632162, 0.017751821760612074, 0.04341982479672879, 0.025694180440041237, 0.026487935210752767, 0.012367030140012503, 0.04869255768426228, 0.06682273931801319, 0.061980333339306526, 0.05882752302568406, 0.02897678681620164, 0.047209512849804014, 0.01458413138607284, 0.009676938698248705, 0.08683089967234991, 0.06991178801399656, 0.048876391374506056, 0.051677564697456546, 0.01543229114759015, 0.02841184730641544, 0.024150689532689285, 0.10796990754897706, 0.08005569252418354, 0.14186844520736486, 0.014527698476740625, 0.019722483593795914, 2.518723583780229, 25.705537050962448, 50.310121178627014, 57.88977965712547, 75.23136511445045, 74.16768059134483, 71.90484881401062, 79.63704630732536, 57.70091079175472, 24.341951720416546, 48.40475521981716, 62.966060265898705, 88.78111883997917, 70.56757897138596, 92.4183976650238, 94.33344170451164, 58.96691545844078, 28.076756112277508, 6.658903285861015, 2.504450837150216, 0.3806427342351526, 0.4066480934852734, 0.37628683203365654, 0.5760065198410302, 0.2957553189480677, 0.08286688855150715, 0.16265140031464398, 0.032079849115689285, 0.18450848059728742, 0.40567674092017114, 0.30631168687250465, 0.4743628646247089, 0.6184098694939166, 0.4805272025987506, 0.7917771697975695, 1.0563002130948007, 0.5935170489829034, 1.452869614586234, 0.939262812025845, 0.43073295266367495, 0.15203594259219244, 0.36986971856094897, 0.24965550983324647, 0.08261818744358607, 0.2199646006920375, 0.5104048806242645, 0.25464535458013415, 0.3542117978213355, 0.780083000427112, 1.1111765122041106, 0.06299172106082551, 1.0664481623098254, 6.882622931152582, 29.032279439270496, 61.981996670365334, 109.32945862412453, 111.70180812478065, 99.2278678715229, 79.59970951080322, 56.59035198390484, 32.033447697758675, 25.531439892947674, 61.63231663405895, 61.36326067149639, 60.789635851979256, 69.86749693751335, 74.83117058873177, 87.5668939948082, 94.69534948468208, 90.88600069284439, 67.89607152342796, 20.76027911156416, 0.7417362299747765, 0.4428843146888539, 0.12407672373228706, 0.09732445963891223, 0.058247775814379565, 0.09164141927612945, 0.03520456542901229, 0.04850818593695294, 0.022109267629275564, 0.07295530595001765, 0.010460470384714426, 0.04539709545497317, 0.003084821933043713, 0.054371037549572065, 0.10932244200375862, 0.03891490676323883, 0.027821791663882323, 0.023843201051931828, 0.023342548229265958, 0.02372424591158051, 0.03175412421114743, 0.01997445015149424, 0.05553266193601303, 0.045003723789704964, 0.004859346427110722, 0.02442579439957626, 0.05810265996842645, 0.05856570445757825, 0.00946377625950845, 0.062376658752327785, 0.06204161618370563, 0.05237436344032176, 0.02783947147690924, 0.04776162990310695, 0.010182413625443587, 0.04220047987473663, 0.038350406975951046, 0.029463598584698047, 0.023752011511533055, 0.003947445920857717, 0.0734118306718301, 0.0166866505969665, 0.029139359830878675, 0.018985501264978666, 0.022104829586169217, 0.071681713743601, 0.06158583360956982, 0.055576404120074585, 0.053279727944754995, 0.06083826083340682, 0.05829535861266777, 0.08736899384530261, 0.007369799168372992, 0.06335978920105845, 0.03666588389023673, 0.08222197706345469, 0.06540627626236528, 0.05182315180718433, 0.03893685578077566, 0.023854340688558295, 0.013256460733828135, 0.06882594432681799, 0.0841281536850147, 0.06119324862083886, 0.01799202713300474, 0.008447021882602712, 0.03903120872564614, 0.030626286097685806, 0.04010377910162788, 0.08505794598022476, 0.021185009900364093, 0.08309535129228607, 0.03969379817135632, 0.09844361833529547, 0.01061097793353838, 0.04725433114799671, 0.06322971297777258, 0.04447122541023418, 0.016204269450099673, 0.041513087853672914, 0.03400798959773965, 0.0385170488152653, 0.04465259517019149, 0.07237438243464567, 0.03356869754497893, 0.03695614526805002, 0.030142650721245445, 0.031629183649783954, 0.06170613574795425, 0.050983096298296005, 0.04472801221709233, 0.027283365379844327, 0.08252953790361062, 0.015062725724419579, 0.058935987908625975, 0.038151644985191524, 0.03264434519223869, 0.053491510916501284, 0.03969782803324051, 0.05042416632932145, 0.03175396464939695, 0.14117266691755503, 0.01774454314727336, 0.0297076575589017, 2.8421795647591352, 36.62082754075527, 71.35907649993896, 78.2698492705822, 90.39154842495918, 94.17062044143677, 105.42031198740005, 124.05688315629959, 94.41551730036736, 35.69695271551609, 40.421216413378716, 32.0467621833086, 48.12646195292473, 52.210649996995926, 70.55873304605484, 88.90326708555222, 70.10149598121643, 33.74537743628025, 7.3534665908664465, 2.4378140503540635, 0.5916707043070346, 0.7248363399412483, 0.8310552465263754, 0.670749032869935, 0.24372097046580166, 0.06695521267829463, 0.055560934051754884, 0.12270468563656323, 0.2612965414300561, 0.5155180406291038, 0.3291888046078384, 0.5293865245766938, 0.6345680868253112, 0.3623856935882941, 0.4616620164597407, 1.1217536008916795, 0.9078253176994622, 0.949007507879287, 0.4411662131315097, 0.37337612884584814, 0.2134817180922255, 0.11609101435169578, 0.047664345474913716, 0.038835062805446796, 0.41535841359291226, 0.7170338148716837, 0.349803410936147, 0.4176754876971245, 0.8510814188048244, 1.2737481761723757, 0.171738805656787, 1.507032501976937, 10.354054905474186, 34.70749720931053, 67.25839734077454, 106.76167041063309, 93.13002347946167, 62.31877259910107, 41.808073595166206, 30.67347027361393, 32.00140781700611, 36.61625258624554, 99.06851202249527, 100.14237239956856, 94.42013025283813, 92.1288911998272, 87.78057932853699, 103.97133573889732, 111.48201271891594, 109.55904990434647, 85.3776566684246, 29.349583312869072, 1.232075693551451, 0.5231262417510152, 0.11134142507216893, 0.03236288197513204, 0.032396349124610424, 0.02134783710062038, 0.013449502621369902, 0.010552024505159352, 0.04616552258084994, 0.04113277427677531, 0.06282771384576336, 0.11941893069888465, 0.019957638651249, 0.02931799848738592, 0.033769585788832046, 0.043687962752301246, 0.01490966333221877, 0.041488348360871896, 0.08061228843871504, 0.03388942779565696, 0.046577440516557544, 0.0073151488049916225, 0.03870324253512081, 0.0383093624986941, 0.12540719413664192, 0.052300078168627806, 0.03732764584128745, 0.02668327961146133, 0.07885111263021827, 0.010738654236774892, 0.026065525162266567, 0.06634561257669702, 0.019307979273435194, 0.014041062040632823, 0.013387099133979063, 0.02612771713756956, 0.08242957803304307, 0.04055303448694758, 0.03461496249656193, 0.018883583979913965, 0.02279297859786311, 0.025440000426897313, 0.021871477947570384, 0.02610096456919564, 0.039832316324464045, 0.021062677988084033, 0.023398474622808862, 0.02879728541302029, 0.04961631631886121, 0.007375029917966458, 0.005910769768888713, 0.012943215970153688, 0.022682530325255357, 0.012504027818067698, 0.08919960499042645, 0.15607092529535294, 0.28123849479015917, 0.23727277584839612, 0.18269556225277483, 0.16671200195560232, 0.1172554143704474, 0.14284441393101588, 0.18228239379823208, 0.17508845950942487, 0.23032759461784735, 0.10442218932439573, 0.08480112577672116, 0.10444891406223178, 0.1355031187995337, 0.1984043646370992, 0.12352584235486574, 0.17930942442035303, 0.25646729744039476, 0.1656737521989271, 0.12941106600919738, 0.16520988021511585, 0.14852696447633207, 0.13223878224380314, 0.10241298776236363, 0.23994176153792068, 0.1947369528352283, 0.1359837336349301, 0.1134722497954499, 0.07383338539511897, 0.12904760660603642, 0.14891702245222405, 0.18183985113864765, 0.13149972190149128, 0.11186981195351109, 0.178849040530622, 0.15345120336860418, 0.12621536327060312, 0.15008798305643722, 0.18608067592140287, 0.1624737895326689, 0.1632950798375532, 0.1618175083422102, 0.12233685498358682, 0.13067552237771451, 0.17986734135774896, 0.14060004061320797, 0.19524033676134422, 0.13911817950429395, 0.1782963631558232, 6.806819848716259, 50.65448150038719, 94.88047555088997, 99.78801101446152, 103.40409457683563, 100.76742365956306, 97.28860393166542, 104.09826412796974, 72.99700140953064, 34.48786899447441, 65.82504585385323, 87.46832728385925, 125.12606218457222, 107.68615320324898, 140.87835252285004, 141.8863320350647, 90.26451364159584, 43.32154758274555, 11.757396552711725, 5.132738929241896, 0.9341497113928199, 1.0383768123574555, 0.8870305179152638, 1.02087875129655, 0.6696497637312859, 0.12373159537673928, 0.24352744803763926, 0.3378968092147261, 0.616347708273679, 0.7499491330236197, 0.5578816111665219, 0.8736714441329241, 1.0206783120520413, 0.722863533301279, 1.2839332921430469, 1.5304614510387182, 1.2728108139708638, 2.4023391539230943, 1.4196894387714565, 0.9782927145715803, 0.3777850797632709, 0.6357029790524393, 0.2679267106577754, 0.12166885528131388, 0.47629844513721764, 0.7316079328302294, 0.3875620145117864, 0.5604512232821435, 1.3170646643266082, 1.6363747115246952, 0.25165185739751905, 2.5556006049737334, 11.427482105791569, 46.20228320360184, 93.03875237703323, 161.82103514671326, 160.42161583900452, 140.10334610939026, 114.30875703692436, 83.76848861575127, 43.52461628615856, 34.72540184855461, 80.62085911631584, 79.81705784797668, 86.28471359610558, 92.12770566344261, 94.50449332594872, 113.33445891737938, 125.8131717145443, 123.61442729830742, 99.49274405837059, 33.07966835796833, 1.3777869497425854, 0.6174307689070702, 0.20024851255584508, 0.23730738961603492, 0.15513860969804227, 0.19277276995126158, 0.10366381829953752, 0.1510857857647352, 0.1370859268354252, 0.12002209638012573, 0.14397899445611984, 0.26257146208081394, 0.10817558635608293, 0.20698457141406834, 0.1770550914807245, 0.13538979284930974, 0.09137239074334502, 0.12247936960193329, 0.10689933726098388, 0.24135540443239734, 0.10238865274004638, 0.097789237042889, 0.1964371241047047, 0.16421629290562123, 0.19653352908790112, 0.1537843534606509, 0.138945140352007, 0.15491379832383245, 0.245015038526617, 0.144255563209299, 0.1760965186986141, 0.1685509696835652, 0.11773195481509902, 0.11906605432159267, 0.10794949848786928, 0.20399243978317827, 0.17290077143115923, 0.10226993879768997, 0.10047830524854362, 0.07889573054853827, 0.17528300610138103, 0.09997895860578865, 0.0902999502432067, 0.08874619728885591, 0.17092084017349407, 0.13578767306171358, 0.1840269158128649, 0.17581527441507205, 0.12562971969600767, 0.13156140921637416, 0.17248687567189336, 0.16032913117669523, 0.08680562212248333, 0.1294514536857605], [0.01519421110060648, 0.049906362473848276, 0.043179194544791244, 0.03971697915403638, 0.03740056556125637, 0.01632096104003722, 0.07699140929616988, 0.023783775432093535, 0.05893670408113394, 0.02666280746780103, 0.06752383880666457, 0.006656845725956373, 0.04695160539995413, 0.03624092641985044, 0.07460735636414029, 0.0049119234154204605, 0.025011473226186354, 0.03418668762606103, 0.04233768071571831, 0.0288759846080211, 0.019562352244975045, 0.022401937276299577, 0.0188512857130263, 0.06918869126820937, 0.018019597919192165, 0.03684029230498709, 0.04420297242177185, 0.03739291030797176, 0.02608306396723492, 0.022057755159039516, 0.06717707772622816, 0.026570844238449354, 0.05646907418849878, 0.05325345220626332, 0.049204665556317195, 0.07639996212674305, 0.019270612137916032, 0.03413346450543031, 0.03188964037690312, 0.031929297038004734, 0.028245470784895588, 0.07420552050461993, 0.01882477619801648, 0.006258356488615391, 0.007757779130770359, 0.008199254953069612, 0.022500900813611224, 0.2945919876219705, 0.8307319669984281, 11.768589802086353, 45.57791970670223, 67.60882213711739, 65.18792644143105, 66.82993233203888, 69.64409932494164, 51.73995405435562, 41.849723160266876, 31.257168352603912, 34.921330735087395, 61.09228201210499, 65.38823649287224, 82.03729391098022, 59.37722124159336, 52.82918460667133, 29.908660613000393, 6.829940183088183, 0.8428111032117158, 0.1982695609331131, 0.1884343527490273, 0.0998507154872641, 0.08042299625230953, 0.030531836673617363, 0.19682274403749034, 0.3237136546522379, 0.42921995103824884, 0.31236262468155473, 0.5777845275588334, 0.14189973415341228, 0.30911400681361556, 0.228201549325604, 0.31433590629603714, 0.33385148097295314, 0.4249542346224189, 0.30662261706311256, 0.6028502387925982, 0.5803647672291845, 0.3042326046852395, 0.45486655610147864, 0.37874776404350996, 0.15798759588506073, 0.10753543203463778, 0.4314180737128481, 0.39172875811345875, 0.15088028507307172, 0.18296102847671136, 0.20433756813872606, 0.2832930564181879, 0.23314014135394245, 0.46790528926067054, 0.5195003456901759, 0.21774354565422982, 0.08999734694953077, 0.21759772847872227, 0.20078980538528413, 0.2167158789234236, 5.94756530597806, 20.222060792148113, 47.46000051498413, 73.06849077343941, 91.92151352763176, 93.86749550700188, 72.00985997915268, 21.187009513378143, 17.962681129574776, 26.557462736964226, 51.145654544234276, 69.5387689769268, 65.39646685123444, 75.01900970935822, 76.88755184412003, 77.01353028416634, 86.13324612379074, 47.10716664791107, 5.4512606374919415, 0.44259665824938565, 0.03529402762069367, 0.020677334505307954, 0.03907724785676692, 0.02587354083516402, 0.01819689328840468, 0.09475241327891126, 0.04472786749829538, 0.08350909862201661, 0.015638882796338294, 0.03371667437022552, 0.06507426165626384, 0.013606891734525561, 0.021470061401487328, 0.010027264870586805, 0.014893159823259339, 0.029936912542325445, 0.060910713000339456, 0.02309947260073386, 0.034634339972399175, 0.054993424855638295, 0.07506152105634101, 0.01720959753583884, 0.047562507970724255, 0.06884090602397919, 0.02332520052732434, 0.008566297074139584, 0.04289418757252861, 0.07472261931980029, 0.07573015900561586, 0.043038490766775794, 0.056467185422661714, 0.006098374960856745, 0.030345257036969997, 0.0901450046512764, 0.06697369215544313, 0.04996087693143636, 0.012338288615865167, 0.04948762791173067, 0.037080247202538885, 0.10149661349714734, 0.015039347144920612, 0.05200930841965601, 0.02915392818977125, 0.09935692010913044, 0.039188421578728594, 0.04082521714735776, 0.0623067410197109, 0.06954654003493488, 0.038216942848521285, 0.08228718215832487, 0.02767910078546265, 0.027417332312325016, 0.054631928433082066, 0.031357954649138264, 0.06757385213859379, 0.004260015793988714, 0.049018071076716296, 0.09889833221677691, 0.05560710676945746, 0.036231775738997385, 0.03674514155136421, 0.06703989172820002, 0.021822917369718198, 0.036945224564988166, 0.026430120051372796, 0.0559198663540883, 0.01543047381346696, 0.03453813165833708, 0.015340745376306586, 0.04748321320221294, 0.05229296839388553, 0.022742193432350177, 0.006558224040418281, 0.009383913748024497, 0.061266528282430954, 0.01089511844838853, 0.06706412284984253, 0.03926223929738626, 0.028099646187911276, 0.011493383171909954, 0.06064412242267281, 0.03331044499645941, 0.015908412278804462, 0.08152795024216175, 0.06038280109351035, 0.08535847868188284, 0.08358017410500906, 0.057317081809742376, 0.025320768836536445, 0.047294262403738685, 0.07304043028852902, 0.045087430626153946, 0.03651621867902577, 0.06807092038798146, 0.026839928432309534, 0.008768056413828162, 0.05970520542177837, 0.06785516321542673, 0.3803234623046592, 0.9008553635794669, 18.472944349050522, 65.39803996682167, 84.18073609471321, 74.24365371465683, 87.87719294428825, 105.31854584813118, 99.16351452469826, 66.68058514595032, 42.79864624142647, 33.13513398170471, 28.816380724310875, 45.749879479408264, 68.75664934515953, 64.87913221120834, 62.61579506099224, 35.465727522969246, 9.262116998434067, 0.748749109916389, 0.3185713430866599, 0.10397794714663178, 0.13124709483236074, 0.21416913979919627, 0.027657155478664208, 0.3267880459316075, 0.36281658452935517, 0.30138154048472643, 0.04852465419389773, 0.5260368855670094, 0.3677836898714304, 0.5683460121508688, 0.7843662018422037, 0.9103558631613851, 0.8218589681200683, 1.1859308509156108, 0.9493221191223711, 1.2403409625403583, 1.7990807932801545, 1.2305783363990486, 1.055312028620392, 0.8822328597307205, 0.3934953367570415, 0.48301131930202246, 0.4635996156139299, 0.5642316641751677, 0.11051678025978617, 0.17566216934937984, 0.4979028389789164, 0.1480190979782492, 0.2512921532616019, 0.43662863317877054, 0.7067818462383002, 0.29591966012958437, 0.03267672880610917, 0.35178889345843345, 0.41179322521202266, 0.29366014699917287, 6.284161694347858, 23.600841388106346, 60.34981705248356, 77.93764069676399, 77.860466837883, 52.40696646273136, 39.48867805302143, 18.37640292942524, 24.71641782671213, 40.91938488185406, 89.20931026339531, 114.9057126045227, 99.78213652968407, 93.15996587276459, 91.97148844599724, 85.8790397644043, 102.58561849594116, 64.249756783247, 9.065277110785246, 0.37296456343028694, 0.008720920759515138, 0.06175387810799293, 0.03349697268276941, 0.09662641779868864, 0.07541310609667562, 0.02707663272303762, 0.046460285084322095, 0.03606460326409433, 0.0864882575115189, 0.011437591292633442, 0.02269193333631847, 0.02250439632916823, 0.03902866315911524, 0.04076397141034249, 0.019730192652787082, 0.03363966541655827, 0.008218486782425316, 0.05745153670432046, 0.03043614786292892, 0.037287762825144455, 0.02728861236391822, 0.016260574338957667, 0.0327970977377845, 0.01307317623286508, 0.0254179159674095, 0.017340889025945216, 0.049301163307973184, 0.10338625506847166, 0.070630491245538, 0.02059858335996978, 0.03328876686282456, 0.02343658390600467, 0.008784116489550797, 0.1124063550378196, 0.02191263745771721, 0.04872357574640773, 0.018669546734599862, 0.08517015128745697, 0.015531930039287545, 0.00900473565707216, 0.010508125542401103, 0.04359871949418448, 0.020075226384506095, 0.04985191480955109, 0.023269296398211736, 0.04309590702177957, 0.020127946700085886, 0.05355972170946188, 0.0009439507914521528, 0.0529832473694114, 0.06291309051448479, 0.21322453423636034, 0.13404030120000243, 0.13288556394400075, 0.15645702020265162, 0.132333584188018, 0.18319704628083855, 0.19753603701246902, 0.08907571085728705, 0.1333238318329677, 0.15308112400816754, 0.15783686569193378, 0.07871325869928114, 0.10930915756034665, 0.18104078073520213, 0.18427719769533724, 0.1214314645039849, 0.10116951933014207, 0.09186044189846143, 0.1600359531585127, 0.08819760914775543, 0.10812555818120018, 0.22263422462856397, 0.14674362813821062, 0.16761446837335825, 0.21294403210049495, 0.14094319485593587, 0.14790370885748416, 0.14012321073096246, 0.12474628194468096, 0.1327511906856671, 0.16324626136338338, 0.13980488874949515, 0.19755745539441705, 0.19435827940469608, 0.15026467357529327, 0.23009169555734843, 0.10532236992730759, 0.26856757001951337, 0.2654778311261907, 0.17958548851311207, 0.13084341102512553, 0.1789302908582613, 0.0967382594535593, 0.17928246961673722, 0.08454089911538176, 0.1393949709017761, 0.18957887805299833, 0.570465704659, 1.6249729483388364, 27.324478179216385, 85.78388527035713, 100.3938353061676, 89.44492042064667, 91.69873148202896, 98.0893349647522, 70.27896925806999, 58.668373078107834, 39.93237264454365, 52.62087598443031, 91.26855656504631, 102.11600169539452, 123.21490153670311, 87.03461855649948, 82.40949153900146, 43.42811666429043, 10.7002904266119, 1.6456270962953568, 0.6617227953393012, 0.26605070976074785, 0.319822040037252, 0.40882418921682984, 0.421960826497525, 0.6102292647119612, 1.0459379316307604, 1.148850778117776, 0.5557717150077224, 0.7158413913566619, 0.4978914692765102, 0.5640349653549492, 0.7776607491541654, 0.8087847603019327, 0.5736579489894211, 0.6773532566148788, 0.4505425662500784, 0.7235946378204972, 0.8713108801748604, 0.5107546399813145, 0.8087421907112002, 0.6699640187434852, 0.19520051311701536, 0.3181697818217799, 0.6851861800532788, 0.5934231821447611, 0.6101247109472752, 0.8331120642833412, 0.8669604698661715, 0.6730827607680112, 0.8862126711755991, 1.15595176583156, 1.0261798230931163, 0.346103745396249, 0.21634660108247772, 0.3630417521344498, 0.4091889993287623, 0.8073090738616884, 9.00455541908741, 32.86308377981186, 76.2143723666668, 109.18686747550964, 137.68459349870682, 140.6949895620346, 110.82473158836365, 34.05767507851124, 25.930403284728527, 37.43552282452583, 67.77254775166512, 88.44716235995293, 86.23926043510437, 93.03485378623009, 97.0730111002922, 95.38734555244446, 118.93417283892632, 75.02331867814064, 10.204539578408003, 0.6003076408524066, 0.10443420469528064, 0.15535582148004323, 0.26017747179139405, 0.24997567234095186, 0.19818949804175645, 0.13625800173031166, 0.17182161449454725, 0.11936303955735639, 0.17005052359309047, 0.16129463561810553, 0.11191275261808187, 0.1261662330944091, 0.0807537417858839, 0.07652718108147383, 0.15378324023913592, 0.09016971816890873, 0.20325749093899503, 0.09262868348741904, 0.1471125052194111, 0.13334576971828938, 0.13242433400591835, 0.13971893320558593, 0.20234919124050066, 0.14579207607312128, 0.09092535066884011, 0.1556359525420703, 0.17201559705426916, 0.267057596356608, 0.2569560759002343, 0.11072927940404043, 0.1912277372321114, 0.08615449885837734, 0.08349350609933026, 0.16850479325512424, 0.12551361811347306, 0.2672260638792068, 0.05219818871410098, 0.17473016545409337, 0.1338862461852841, 0.24487094313371927, 0.11121730087324977, 0.1455745822750032, 0.10668015878763981, 0.32605079642962664, 0.23453723435522988, 0.1585824866197072, 0.15490033576497808, 0.13421098032267764, 0.16544594254810363, 0.125880224222783, 0.1298757691984065], [0.03593434521462768, 0.027998190889775287, 0.03755302124773152, 0.062167525247787125, 0.03727019618963823, 0.014066966705286177, 0.07170204858994111, 0.09831742354435846, 0.03535211923008319, 0.0808480242267251, 0.007411474934997386, 0.006453014866565354, 0.037472464828169905, 0.032493169710505754, 0.045269204856595024, 0.02785501204925822, 0.09465256473049521, 0.04991164285456762, 0.021797919980599545, 0.0500889679096872, 0.04178437993687112, 0.0535856115311617, 0.04250241152476519, 0.014971556593081914, 0.007115332964531262, 0.05135886793141253, 0.029797733877785504, 0.02389514396782033, 0.0285261009412352, 0.05204908382438589, 0.01586162357853027, 0.04940213249938097, 0.0654105213470757, 0.00577823332605476, 0.021788190424558707, 0.06659809121629223, 0.08131608192343265, 0.04011589095171075, 0.05134716055181343, 0.007663660426260321, 0.054330319617292844, 0.12854180327849463, 0.01426364140570513, 0.030377321527339518, 0.050782890830305405, 0.058431078869034536, 0.24800342973321676, 14.932100549340248, 38.24625492095947, 64.17311489582062, 55.79798050224781, 62.064817026257515, 74.54045578837395, 53.00009183585644, 29.009313471615314, 27.50884048640728, 51.86184011399746, 65.94080284237862, 67.91193187236786, 63.03989790380001, 51.104552149772644, 32.47118040919304, 19.37309704720974, 4.100050292909145, 0.17612393363378942, 0.18161808256991208, 0.09270362555980682, 0.025382669518876355, 0.07111382234143093, 0.08452302077785134, 0.076478362607304, 0.08226916281273589, 0.026464796901564114, 0.14575167355360463, 0.1057498469890561, 0.11743676557671279, 0.10419092868687585, 0.06453875015722588, 0.13314012059709057, 0.08597964886575937, 0.17282293498283252, 0.1623945133178495, 0.24700881825992838, 0.16929084638832137, 0.4065015638479963, 0.5541104916483164, 0.8600789797492325, 0.3934924572240561, 0.31038690882269293, 0.2528676140354946, 0.0859378362656571, 0.09643901066738181, 0.09920063865138218, 0.044267383418628015, 0.06436783354729414, 0.1456274083466269, 0.1920187775976956, 0.05369501894165296, 0.1870629083714448, 0.3660459362436086, 0.34748696023598313, 0.06299510525423102, 0.06659608741756529, 0.1937631660257466, 0.13296225748490542, 0.015306973946280777, 0.20918824535328895, 0.9900948812719434, 8.615714684128761, 30.372304134070873, 71.56941801309586, 69.8886390030384, 97.1817384660244, 78.87153938412666, 62.13521204888821, 27.522806636989117, 23.717299439013004, 28.05156346410513, 54.604540541768074, 70.36982238292694, 74.58600774407387, 72.51042991876602, 81.65386408567429, 67.53787234425545, 16.906668394804, 0.13617755292216316, 0.3375514433719218, 0.045056397721054964, 0.034311149502173066, 0.05038173032517079, 0.07635898073203862, 0.06804443313740194, 0.03743510882486589, 0.015133007109398022, 0.05317862145602703, 0.023195896137622185, 0.013205682062107371, 0.031021661561680958, 0.06416257034288719, 0.02067543646262493, 0.046330631885211915, 0.07197082479251549, 0.03887668986862991, 0.03217598321498372, 0.009744689359649783, 0.06616246537305415, 0.02597110727947438, 0.010242024782201042, 0.003816379162344674, 0.027714165407815017, 0.055565386937814765, 0.055565364673384465, 0.06546218224684708, 0.040571502831880935, 0.019806314739980735, 0.01185106681077741, 0.05146738105395343, 0.012704342752840603, 0.022595289010496344, 0.046552860585507005, 0.08243057251092978, 0.008250402843259508, 0.053090046130819246, 0.06408883054973558, 0.0140982120501576, 0.0329105461423751, 0.045499890329665504, 0.07422702052281238, 0.013480143115884857, 0.04131133871851489, 0.015290355404431466, 0.08172750633093528, 0.019859790190821514, 0.009932508382917149, 0.022101502909208648, 0.1024873583810404, 0.03928852987883147, 0.041285088955191895, 0.01565577036672039, 0.049031370363081805, 0.052666628616862, 0.04099632671568543, 0.023517643130617216, 0.07213596749352291, 0.00683698908687802, 0.08988284840597771, 0.025865811367111746, 0.005348317381503875, 0.04953329225827474, 0.029346266892389394, 0.03702740628796164, 0.06053347191482317, 0.0346378317772178, 0.028301551174081396, 0.017114092406700365, 0.11680586583679542, 0.015392059322039131, 0.027701804938260466, 0.04443227378942538, 0.019856647195410915, 0.026888514985330403, 0.05636256857542321, 0.0652245020319242, 0.018314755616302136, 0.027399977188906632, 0.04846454023208935, 0.013010699458391173, 0.05855544797668699, 0.047040945137268864, 0.033011864143190905, 0.02474551718478324, 0.04739468982734252, 0.08464276630547829, 0.04942190702422522, 0.029045858500467148, 0.02300144416949479, 0.02915788940299535, 0.09991094077122398, 0.06223585478437599, 0.07638318958925083, 0.06378936654073186, 0.04987096202967223, 0.35417192964814603, 21.55320156365633, 53.895468190312386, 86.88309788703918, 71.40920341014862, 86.29127964377403, 112.86770716309547, 95.27562394738197, 53.05094450712204, 26.82740595191717, 39.555611461400986, 27.898152396082878, 45.21503537893295, 55.005730614066124, 54.87500622868538, 39.62941490113735, 24.153141751885414, 4.6852421667426825, 0.3645928407786414, 0.4171076853526756, 0.011233525729039684, 0.02327317968592979, 0.12723771622404456, 0.6298373406752944, 0.6131103413645178, 0.5923567456193268, 0.45415599422995, 0.5125448782928288, 0.37624862627126276, 0.45845329645089805, 0.23526934819528833, 0.3550826042192057, 1.1112038232386112, 0.8318343234714121, 0.7536763173993677, 0.9754903649445623, 1.3424028921872377, 1.2101406580768526, 2.469872930087149, 2.724355012178421, 3.901502634398639, 2.3094647750258446, 1.9021107209846377, 2.0333141181617975, 1.513499398715794, 0.3585607832064852, 0.6935716769658029, 0.4910881124669686, 0.5767072853632271, 0.688901252578944, 0.707469490589574, 0.31736149394419044, 0.6448493851348758, 1.050748829729855, 0.7405746204312891, 0.3404447209322825, 0.07778780796797946, 0.3927007340826094, 0.1041989067743998, 0.03601655662350822, 0.052009694336447865, 0.8041554212104529, 10.290181282907724, 35.72489261627197, 73.61190721392632, 71.33729606866837, 57.36788906157017, 34.23200972378254, 35.47624535858631, 31.59803096204996, 33.664190992712975, 49.23230521380901, 94.46543142199516, 104.11140382289886, 98.4345768392086, 88.02915439009666, 98.25462609529495, 84.94484469294548, 27.00587287545204, 0.2756747620878741, 0.27647984388750046, 0.06568113065441139, 0.11257255158852786, 0.0620215707749594, 0.011087826369475806, 0.09697681540274061, 0.03368862489878666, 0.010770128719741479, 0.027992481918772683, 0.002694496552066994, 0.07397520239464939, 0.04842503942199983, 0.03028118186193751, 0.010771970173664158, 0.07358175280387513, 0.09216691178153269, 0.12685254157986492, 0.015860306266404223, 0.005848964638062171, 0.07611223147250712, 0.05167956849618349, 0.03449892399657983, 0.008595971848990303, 0.03850705208606087, 0.0920659648545552, 0.05259942714474164, 0.04278668748156633, 0.04531361868430395, 0.018839159019989893, 0.010281509821652435, 0.03433123572904151, 0.045585396874230355, 0.04034746700199321, 0.035481182421790436, 0.029575943044619635, 0.061372265772661194, 0.0631310667085927, 0.046253411419456825, 0.01509311481640907, 0.021614086290355772, 0.013880683000024874, 0.04516026128840167, 0.011861036637128564, 0.05095425643958151, 0.04529105739493389, 0.029919971166236792, 0.04836205334868282, 0.04074420801771339, 0.025101929895754438, 0.062242541534942575, 0.09226256719557568, 0.17338264791760594, 0.11000052007148042, 0.16659916582284495, 0.12067480041878298, 0.11283556130365469, 0.21684627427021042, 0.18270987085998058, 0.1886320163612254, 0.18928553676232696, 0.11845152635942213, 0.09812264688662253, 0.13744411699008197, 0.0865218100079801, 0.14160476013785228, 0.14065745315747336, 0.15288213937310502, 0.13860363367712125, 0.06781930263969116, 0.18250570603413507, 0.08914447826100513, 0.14610218990128487, 0.1098056988848839, 0.11452533508418128, 0.08629853487946093, 0.14578420930774882, 0.14028266858076677, 0.1010850555030629, 0.08916131759178825, 0.13139163551386446, 0.14639033615821972, 0.13533585355617106, 0.1507479601423256, 0.2073582576122135, 0.08969374175649136, 0.12467533262679353, 0.1484463969245553, 0.23929104645503685, 0.1501321853720583, 0.1405542649445124, 0.1653060773969628, 0.27213207562454045, 0.13552778778830543, 0.1847805074066855, 0.1682791209896095, 0.2033736222074367, 0.5407043953891844, 28.988868668675423, 73.21115031838417, 104.33450505137444, 85.6153567135334, 90.93222141265869, 104.7754941880703, 73.68968144059181, 40.672014355659485, 40.56190766394138, 82.18512117862701, 107.0553794503212, 108.03531646728516, 98.88749733567238, 74.47278901934624, 51.760845333337784, 33.329732939600945, 7.878410322591662, 1.4140776148997247, 0.5494372767861933, 0.30754344421438873, 0.13889746478525922, 0.23859804379753768, 0.5064392590429634, 0.3828687616623938, 0.3276422875933349, 0.30392876942642033, 0.21957028278848156, 0.21763637952972203, 0.23832033213693649, 0.15005670895334333, 0.1629531872458756, 0.6274060648865998, 0.33177581266500056, 0.2825914300046861, 0.47825094661675394, 0.670841415412724, 0.28300634992774576, 0.548866594908759, 0.5806679790839553, 1.4688398013822734, 0.798189266351983, 0.5666297511197627, 0.6402328109834343, 0.4824267147341743, 0.16325310396496207, 0.21496527129784226, 0.24618116032797843, 0.22208442678675056, 0.2993246930418536, 0.39413708669599146, 0.1943732559448108, 0.4936592682497576, 0.7503118354361504, 0.9896385495085269, 0.3350050753215328, 0.26134285144507885, 0.4835343256127089, 0.24507359397830442, 0.05526494329387788, 0.3404670744203031, 2.0537356473505497, 15.880558155477047, 47.24720053374767, 105.56783527135849, 105.5959765613079, 137.81352818012238, 108.98267403244972, 88.11289429664612, 38.447302132844925, 29.641854129731655, 38.99401679635048, 74.60531830787659, 91.71764686703682, 98.42422619462013, 92.14195489883423, 107.08919763565063, 103.65141570568085, 32.031399607658386, 0.3186612616991624, 0.37905391480308026, 0.11545948378625326, 0.16660186724038795, 0.16229886532528326, 0.2340878639370203, 0.2561801456613466, 0.1343516173074022, 0.08703433719347231, 0.09511372787528671, 0.1737930258968845, 0.1512079284293577, 0.18186888395575806, 0.14473697956418619, 0.19065715925535187, 0.24416128668235615, 0.14592397055821493, 0.24134183797286823, 0.09966750149033032, 0.0872729228285607, 0.14442928513744846, 0.1937603161786683, 0.1549640714074485, 0.17879971739603207, 0.10292012695572339, 0.2705988282104954, 0.11051667635911144, 0.11385259305825457, 0.19957076845457777, 0.14956401195377111, 0.09571052592946216, 0.1587053862749599, 0.09826075314776972, 0.1317703683162108, 0.09078257629880682, 0.16501950449310243, 0.19977411691797897, 0.1623097452102229, 0.14929504279280081, 0.09633303940063342, 0.14812757028266788, 0.135130085691344, 0.19536080217221752, 0.09453857826883905, 0.15782821225002408, 0.1087827596347779, 0.15964626625645906, 0.1047232341079507, 0.10961299281916581, 0.07755903352517635, 0.22558740834938362], [0.029509864070860203, 0.059286192554282025, 0.025917431448760908, 0.028947497958142776, 0.005425337003543973, 0.041172601631842554, 0.007849288722354686, 0.05116481115692295, 0.04664134685299359, 0.026054444897454232, 0.013276573863549856, 0.039261808851733804, 0.030527856906701345, 0.03228357236366719, 0.0539562549238326, 0.03944582065741997, 0.028411956773197744, 0.04170142266957555, 0.08072233409620821, 0.058558216187520884, 0.06840882764663547, 0.06881906461785547, 0.05456834864162374, 0.0662222305254545, 0.06907688672072254, 0.014300016846391372, 0.058064231561729684, 0.09085773359402083, 0.04008249059552327, 0.026132023449463304, 0.042958746998920105, 0.03962637776567135, 0.0203161089666537, 0.053576731734210625, 0.01347019184322562, 0.0371874281700002, 0.044386468434822746, 0.06403683568350971, 0.029458856261044275, 0.0025911190914484905, 0.02186719204473775, 0.016440005238109734, 0.04704961713287048, 0.05960230664641131, 0.08927468064939603, 2.124310447834432, 16.187589280307293, 58.062373995780945, 68.43789204955101, 63.22406642138958, 53.73814143240452, 44.21723932027817, 21.203456930816174, 28.2332906126976, 52.84094497561455, 72.88913279771805, 72.68351063132286, 54.60319921374321, 53.31002980470657, 31.312071606516838, 9.954361002892256, 0.9479390527121723, 0.208651049179025, 0.39126206596847624, 0.05747856943344232, 0.026112363957508933, 0.05971077895082999, 0.07218511251267046, 0.03278748692537192, 0.17163491982501, 0.05047416481829714, 0.11817946244264022, 0.062104305397951975, 0.2994829782983288, 0.4472242161864415, 0.12773485126672313, 1.003754495177418, 0.633842860115692, 1.0610534017905593, 1.441552871838212, 1.2694856361486018, 1.3686118670739233, 2.7742009749636054, 3.3854979230090976, 3.9498821133747697, 6.51527906768024, 6.461048852652311, 2.720840200781822, 3.1122992327436805, 2.6021041721105576, 1.559238019399345, 0.23253992199897766, 1.129769270773977, 0.4006806918187067, 0.13880306360078976, 0.19054320990107954, 0.14323533279821277, 0.30135004373732954, 0.06495505789644085, 0.45917902782093734, 0.15954428032273427, 0.0603543953911867, 0.09637666284106672, 0.22184174449648708, 0.30256968922913074, 0.21282968198647723, 0.42709167930297554, 0.07931162268505432, 0.21609553252346814, 0.3793864563340321, 4.0796928852796555, 26.130261160433292, 45.83622224628925, 70.42947918176651, 58.9514996856451, 99.90581229329109, 87.27899864315987, 43.633670434355736, 24.30386446416378, 25.33345151692629, 43.875284269452095, 53.964335694909096, 65.0799286365509, 71.78773909807205, 74.04599592089653, 39.043003767728806, 9.006462916731834, 0.2850696392124519, 0.23246980388648808, 0.015978864357748535, 0.056300120559171773, 0.027080011350335553, 0.018772174626064952, 0.009023821839946322, 0.07520518600358628, 0.03892068809363991, 0.04470950305403676, 0.015456278288183967, 0.05926603953412268, 0.018043124000541866, 0.055185770979733206, 0.05223339991061948, 0.05311827000696212, 0.0013621291486742848, 0.13333555776625872, 0.030704219025210477, 0.08807218619040214, 0.03980585875979159, 0.010228592836938333, 0.020521251572063193, 0.05145489070855547, 0.01675440311373677, 0.012239259212947218, 0.002212263834735495, 0.1179396225779783, 0.04696611067629419, 0.05261141654045787, 0.018223690385639202, 0.06419376280973665, 0.07361893440247513, 0.05020705473725684, 0.026499169471208006, 0.0757436735148076, 0.026998005887435284, 0.024020394375838805, 0.06490025771199726, 0.06661850769887678, 0.0535305701487232, 0.04756298294523731, 0.08201994220144115, 0.0553389910783153, 0.06891607816214673, 0.0035534035396267427, 0.056096037369570695, 0.01729550484014908, 0.15589003422064707, 0.019140042386425193, 0.06926381887751631, 0.019352114795765374, 0.05783688204246573, 0.009044486014317954, 0.017611002949706744, 0.03422866349865217, 0.05239558144239709, 0.010314731134712929, 0.026325872422603425, 0.02088130080664996, 0.04461586257093586, 0.028222276814631186, 0.03343459145980887, 0.0672130125167314, 0.0539247618871741, 0.055331695766653866, 0.046805406018393114, 0.11428861223976128, 0.05235076314420439, 0.03237239630834665, 0.010852929208340356, 0.04307634400902316, 0.033819825475802645, 0.02512985320208827, 0.053555810591205955, 0.04378010409709532, 0.03859713768179063, 0.044735938354278915, 0.012247832873981679, 0.051277769744046964, 0.028475072722358163, 0.042282665308448486, 0.02814534764183918, 0.017116660237661563, 0.028841381972597446, 0.059132935348316096, 0.03262225887738168, 0.07067895348882303, 0.0586734309035819, 0.10750866276794113, 0.04123672319110483, 0.020287447223381605, 0.08367869420908391, 0.10273308347677812, 3.6702071456238627, 25.992339961230755, 77.4382334947586, 87.45980054140091, 87.78261601924896, 91.78972139954567, 84.46158662438393, 47.15244881808758, 39.278674721717834, 31.525984928011894, 35.218805372714996, 64.22221586108208, 60.540525019168854, 58.031375259160995, 36.42241358757019, 14.272696282714605, 1.754051309544593, 0.28972061933018267, 0.4462821636116132, 0.03933755615435075, 0.04172334200120531, 0.35489353467710316, 0.356638976954855, 0.41151221841573715, 0.901444866321981, 0.7812573155388236, 1.2092811916954815, 1.5997584513388574, 2.878708904609084, 2.2953627817332745, 1.37450166977942, 2.3876339429989457, 2.7136091887950897, 3.734513707458973, 4.203291703015566, 5.0628141313791275, 4.580601481720805, 6.084657674655318, 8.433360569179058, 12.395419366657734, 13.458185289055109, 11.148269288241863, 7.676239321008325, 6.192883942276239, 6.5697600692510605, 5.8261622954159975, 7.017408348619938, 5.2353661973029375, 2.8102999879047275, 1.762754861265421, 1.875074696727097, 2.013189923018217, 1.9370528147555888, 1.2968508177436888, 2.6610551588237286, 1.4246646780520678, 1.7634103260934353, 0.8538585947826505, 0.7289348950143903, 0.5418986594304442, 0.2871751715429127, 0.22807841218309477, 0.10038414897280745, 0.14953306439565495, 0.2402117697056383, 4.459305815398693, 28.232186771929264, 59.053246825933456, 71.73005819320679, 55.63965819776058, 48.46782423555851, 49.04010012745857, 35.979250967502594, 34.58987832069397, 52.93052896857262, 74.52845603227615, 84.8772083222866, 81.49847522377968, 86.88984632492065, 92.82032489776611, 56.46330580115318, 14.711289647966623, 0.41622616234235466, 0.3065041406080127, 0.03843846279778518, 0.049083929261541925, 0.03871248227369506, 0.04101484330021776, 0.054234063063631766, 0.005066381045253365, 0.10108178263180889, 0.06852138918475248, 0.050870245322585106, 0.06465907456004061, 0.06799454597057775, 0.015954076625348534, 0.031131024443311617, 0.04821890048333444, 0.041176664890372194, 0.031181438534986228, 0.029395992642093915, 0.04337940372352023, 0.06651195755694062, 0.03511670627631247, 0.11021552767488174, 0.0866817131463904, 0.019389665612834506, 0.006726314923071186, 0.015988985396688804, 0.026566543492663186, 0.009626051487430232, 0.03816606862528715, 0.014313528572529322, 0.02620386705530109, 0.06813747619162314, 0.007796804038662231, 0.009236721743945964, 0.03532298993377481, 0.031326728785643354, 0.028180402987345587, 0.03475926198007073, 0.049689963343553245, 0.03954694569983985, 0.05154872043931391, 0.012619225835805992, 0.03926780540496111, 0.004526751554294606, 0.024283571074192878, 0.03951081424020231, 0.04923764288832899, 0.09178230859106407, 0.15688960324041545, 0.17912992858327925, 0.14928469725418836, 0.13938529329607263, 0.14603817224269733, 0.17268661729758605, 0.19593964767409489, 0.13217794097727165, 0.10666495960322209, 0.15044875588500872, 0.06937743426533416, 0.13828645460307598, 0.10894373146584257, 0.23484516626922414, 0.15048489847686142, 0.176020982908085, 0.11140743168652989, 0.13541630236431956, 0.20085634634597227, 0.14830660598818213, 0.24811610259348527, 0.14323288371087983, 0.12570908496854827, 0.14511152665363625, 0.13180140493204817, 0.11017487282515503, 0.14030637277755886, 0.1124993090343196, 0.1741538432543166, 0.11039205492124893, 0.1887734400224872, 0.07426582000334747, 0.11538171413121745, 0.11981831747107208, 0.12552872824016958, 0.22733806050382555, 0.23838917375542223, 0.17272978060645983, 0.13068163767457008, 0.12332782251178287, 0.14676960330689326, 0.18461201019817963, 0.1407439578906633, 0.14141585386823863, 0.3470382874365896, 5.057175233960152, 38.380494117736816, 101.41588166356087, 99.79325473308563, 91.06781333684921, 76.32119223475456, 61.643982008099556, 26.768172830343246, 40.51815681159496, 79.14916008710861, 110.52531525492668, 106.99815452098846, 84.70108017325401, 80.84402874112129, 48.140882179141045, 21.492828503251076, 2.768411748111248, 0.8041096455417573, 0.9655932616442442, 0.13750509184319526, 0.11738865956431255, 0.31760684796608984, 0.2608519355999306, 0.14821698423475027, 0.4121619835495949, 0.6313200923614204, 0.5508828023448586, 1.1208968656137586, 1.8061986425891519, 2.842813180759549, 0.6744579307269305, 2.1374026453122497, 1.9220519321970642, 4.01118541136384, 3.9212755858898163, 5.211153896525502, 4.783639311790466, 8.748391214758158, 8.753561787307262, 12.22177343443036, 12.719833608716726, 14.176943320780993, 7.839546957984567, 6.098846113309264, 6.602084459736943, 3.927634544670582, 3.1705828802660108, 3.3171082427725196, 1.9386543100699782, 0.7583530945703387, 0.9801727230660617, 0.6538844096940011, 0.8614732080604881, 0.5328085971996188, 1.4341324637643993, 0.8354564791079611, 0.6873520638328046, 0.29625288443639874, 0.4013070941437036, 0.709002292715013, 0.5142283660825342, 0.4326734907226637, 0.17562944063683972, 0.3623769956175238, 0.6083145237062126, 8.148034829646349, 42.06408865749836, 75.2039609849453, 106.4644655585289, 86.19433924555779, 136.3859447836876, 123.09033662080765, 61.8974170088768, 33.441142961382866, 36.135517582297325, 55.233205407857895, 76.31048440933228, 86.03676170110703, 91.85640782117844, 106.2153585255146, 67.3386338353157, 16.500244103372097, 0.869954174850136, 0.5097913916688412, 0.09006099353427999, 0.16885269724298269, 0.24682380084414035, 0.13519284169888124, 0.10491769906366244, 0.19171130581526086, 0.1320965719060041, 0.16762022743932903, 0.1530737173743546, 0.16788410546723753, 0.1138190554047469, 0.1388721723924391, 0.23068876820616424, 0.153591959096957, 0.1418133926927112, 0.24390290054725483, 0.10420350066851825, 0.18380683934083208, 0.12671371543547139, 0.16988183342618868, 0.20127015304751694, 0.22439112566644326, 0.09621491917641833, 0.1252221767208539, 0.08079185849055648, 0.11841412211651914, 0.1595654760603793, 0.19166615355061367, 0.11660580508760177, 0.1024253445211798, 0.3102565580047667, 0.1317127628135495, 0.12541422969661653, 0.1755371323088184, 0.16614762833341956, 0.13847484136931598, 0.10092464770423248, 0.12239986332133412, 0.1239367546804715, 0.11678342329105362, 0.1334649883210659, 0.14044436771655455, 0.16930494719417766, 0.0666192350035999, 0.22536883101565763, 0.1449319120729342, 0.23373773350613192], [0.03183154134603683, 0.03050094106583856, 0.06684076608507894, 0.0652830203762278, 0.05277535325149074, 0.021820722467964515, 0.06841472029918805, 0.03637838330178056, 0.08082656873739325, 0.043618419804261066, 0.023797432804713026, 0.07961441151564941, 0.02840988803654909, 0.02983513997605769, 0.08545895063434727, 0.01642053870455129, 0.02568729887570953, 0.012021960228594253, 0.04916433725156821, 0.04395421565277502, 0.1084630869445391, 0.03983940383477602, 0.024698624583834317, 0.041715579136507586, 0.034196368942502886, 0.027993266739940736, 0.05676967368344776, 0.011703352520271437, 0.05559316552535165, 0.019714292138814926, 0.01117190242439392, 0.08771948050707579, 0.044990012611378916, 0.023638203165319283, 0.061244954049470834, 0.031593345338478684, 0.03333335880597588, 0.038006903923815116, 0.08154003240633756, 0.08614539270638488, 0.0450103771436261, 0.08815720662823878, 0.10507935367058963, 0.1310872659087181, 9.672546274960041, 55.6734573841095, 81.78021490573883, 74.58986073732376, 56.31773181259632, 44.63185027241707, 45.827030539512634, 39.50678788125515, 50.39587117731571, 67.06744998693466, 62.680832371115685, 52.056123688817024, 44.51546251773834, 21.90534956753254, 5.444188266992569, 0.17236802814295515, 0.5765428848098963, 0.3686674393247813, 0.12636040861252695, 0.04054819939483423, 0.17245380557142198, 0.08685185792273842, 0.043971377817797475, 0.1553894704557024, 0.06052468117559329, 1.390240069013089, 1.1825452325865626, 1.290393064264208, 1.8973992113023996, 2.905494379810989, 3.2512644259259105, 1.5349733526818454, 3.2733913511037827, 1.6243932419456542, 3.7091448437422514, 3.411982264369726, 6.454817187041044, 3.3985516475513577, 3.6418134067207575, 8.442681469023228, 18.173081539571285, 23.63666206598282, 14.118613600730896, 9.266455415636301, 9.595841690897942, 10.068700667470694, 8.588885273784399, 3.9331630105152726, 5.40437875315547, 5.470762141048908, 2.5720907701179385, 3.449743213132024, 2.8149818116798997, 2.5511880917474627, 1.851287973113358, 2.3185451002791524, 1.4665215695276856, 0.8292961784172803, 0.18568617990240455, 0.18195369659224525, 0.040893810146371834, 0.025418943841941655, 0.1127827946038451, 0.14661464287200943, 0.11577138619031757, 0.16558778181206435, 0.03495607212244067, 0.08943893277319148, 2.276253132149577, 18.767692632973194, 41.74771003425121, 72.73701936006546, 73.15356060862541, 61.62751369178295, 71.22875109314919, 44.071228355169296, 25.456295125186443, 32.745848670601845, 57.95193672180176, 57.47226566076279, 71.04515254497528, 66.7917063832283, 79.83340457081795, 35.84096118807793, 3.919330327771604, 0.4675420228159055, 0.07650382569408976, 0.03497599136608187, 0.09190100769046694, 0.03800107806455344, 0.028532878604892176, 0.022713626312906854, 0.032803257563500665, 0.08995894822874106, 0.01198402442241786, 0.10931365497526713, 0.022915718691365328, 0.040593548328615725, 0.00667770564177772, 0.041945700577343814, 0.05722873655031435, 0.016131791307998355, 0.056152258766815066, 0.039466675007133745, 0.03978392829594668, 0.02061759903881466, 0.023715367969998624, 0.030276389443315566, 0.04629765455320012, 0.04258746535924729, 0.03527026034134906, 0.044570676909643225, 0.04180528252618387, 0.020463657201617025, 0.05866107043402735, 0.014079211214266252, 0.0403383942466462, 0.04836140025872737, 0.005019802465540124, 0.003786778834182769, 0.04166325401456561, 0.05921771458815783, 0.05648144579026848, 0.008577391254220856, 0.1027238585811574, 0.07312071582418866, 0.046489640735671856, 0.026959273200191092, 0.020315674810262863, 0.03482394015009049, 0.05276677031361032, 0.062302251026267186, 0.04155566115514375, 0.04037899343529716, 0.10021816764492542, 0.03246116088121198, 0.10211751650786027, 0.060295750881778076, 0.0016436266901109775, 0.03509950700390618, 0.03483853448415175, 0.04872143093962222, 0.05953299747488927, 0.06145194645796437, 0.027493085181049537, 0.06019994332746137, 0.07819247141014785, 0.054427852664957754, 0.01207499131851364, 0.058804464497370645, 0.06999654870014638, 0.014051791640667943, 0.06621785185416229, 0.05054756693425588, 0.03277216528658755, 0.02335325927560916, 0.07376561246928759, 0.0036618869762605755, 0.07246732158819214, 0.011080768545070896, 0.020491890354605857, 0.05348703947674949, 0.0227993109729141, 0.027614253776846454, 0.04826860211323947, 0.014550999130733544, 0.04478105722228065, 0.06552466365974396, 0.06811559025663882, 0.06273580627748743, 0.04000355205789674, 0.04035789046611171, 0.01808802022424061, 0.02073494928481523, 0.08963108964962885, 0.25626178190577775, 16.267415396869183, 76.82272732257843, 110.28487175703049, 107.28495553135872, 91.12043291330338, 81.35830834507942, 63.25356423854828, 41.18822045624256, 23.157363384962082, 30.453935153782368, 49.55347158014774, 52.66266614198685, 54.64894495904446, 26.70648504048586, 7.096835486590862, 0.44545475800987333, 0.8866560598835349, 0.4736948129720986, 0.1525589489028789, 0.2186012308811769, 0.6213981716427952, 0.7645627926103771, 0.6600490445271134, 1.16337098646909, 2.200622227974236, 5.312421312555671, 5.777378138154745, 5.334576973691583, 6.140045402571559, 7.837657509371638, 5.181228602305055, 5.08417041040957, 5.2488241251558065, 6.815780717879534, 9.584079422056675, 9.372764211148024, 8.067677691578865, 6.498878197744489, 8.499414324760437, 12.82127771526575, 15.788937471807003, 19.22734636813402, 20.437271744012833, 13.335146941244602, 12.229205835610628, 11.46932166069746, 13.079442512243986, 8.39907880872488, 7.5404103845357895, 9.693265613168478, 8.902056869119406, 8.316007666289806, 6.075059864670038, 6.110256426036358, 5.241228807717562, 4.437385266646743, 3.503989102318883, 1.9249717192724347, 1.5127023914828897, 0.7936290360521525, 0.6709336198400706, 0.11854972733999602, 0.5013016972225159, 0.5079687957186252, 0.17024048371240497, 0.15616197197232395, 0.026068710831168573, 0.1556268983404152, 1.8844066397286952, 21.633014380931854, 48.12678873538971, 76.22701808810234, 60.58732710778713, 36.557887718081474, 45.265150889754295, 28.07369727641344, 37.022473588585854, 57.19164311885834, 95.66413789987564, 85.4721499979496, 86.16587117314339, 86.43027618527412, 98.67375880479813, 54.90837223827839, 8.014615438878536, 0.30341653909999877, 0.07303199949092232, 0.07057946117129177, 0.08287854769150726, 0.01728009414364351, 0.05425655013823416, 0.045084951852913946, 0.06612912809941918, 0.04634533754142467, 0.053107957864995115, 0.05591530214587692, 0.0758712190145161, 0.05097969355119858, 0.019473485626804177, 0.03324233439343516, 0.049566944944672287, 0.005864270970050711, 0.03055130877328338, 0.06128317836555652, 0.01408805761457188, 0.023226593220897485, 0.04123391045141034, 0.004323855800976162, 0.015915427429717965, 0.04074617099831812, 0.056143293622881174, 0.03168880408338737, 0.04932317169732414, 0.07691762497415766, 0.011808964773081243, 0.030014042094990145, 0.11399570881621912, 0.02713849815336289, 0.03660942871647421, 0.05338706476322841, 0.04769488485180773, 0.03316029367852025, 0.012429324160621036, 0.02682936581550166, 0.058993411585106514, 0.07682120514800772, 0.04282445537683088, 0.07717742861132137, 0.024477471997670364, 0.03963886440033093, 0.040353660224354826, 0.03281037847045809, 0.1212613345705904, 0.12804904690710828, 0.14976004284108058, 0.09210092743160203, 0.21430153894471005, 0.10123452404513955, 0.14519472140818834, 0.10659688239684328, 0.22822581755463034, 0.2028380290721543, 0.20196529309032485, 0.2456917881499976, 0.1605047530028969, 0.10798413451993838, 0.1358127428102307, 0.15353883616626263, 0.11082894983701408, 0.14137764810584486, 0.18091513513354585, 0.15953696274664253, 0.12894183571916074, 0.23002819740213454, 0.16315384913468733, 0.07635570043930784, 0.22792927018599585, 0.07516934769228101, 0.1694448568741791, 0.1157912312191911, 0.19501329894410446, 0.15622843871824443, 0.09699165835627355, 0.27701326995156705, 0.1508484617806971, 0.14113119570538402, 0.2407411436433904, 0.15808244235813618, 0.15102001663763076, 0.19919154583476484, 0.16069172968855128, 0.1869285202701576, 0.11580024831346236, 0.21590218821074814, 0.31250220781657845, 0.422144255717285, 23.687799721956253, 98.8285245001316, 121.72902166843414, 105.4244613647461, 80.91142192482948, 67.82110154628754, 61.35814994573593, 58.71534235775471, 75.33623188734055, 102.94947177171707, 94.19970408082008, 77.70127817988396, 73.56263145804405, 37.25565567612648, 11.450844202190638, 1.2026884267106652, 1.36974788736552, 0.5822500004433095, 0.2034528984222561, 0.3965337190311402, 0.4457269184058532, 0.6610250577796251, 0.27659250190481544, 0.4830375616438687, 1.219068041536957, 4.689458040520549, 5.396620994433761, 6.057328591123223, 7.907263599336147, 9.94601285085082, 9.997682478278875, 6.239247154444456, 9.56019390374422, 8.196480330079794, 13.436634745448828, 15.113580711185932, 18.427046611905098, 15.807219240814447, 17.222205363214016, 24.64679606258869, 36.72225929796696, 55.87912894785404, 37.55252614617348, 31.45677924156189, 29.501888640224934, 33.162610307335854, 26.805137246847153, 13.595109041780233, 19.3123497068882, 16.918960735201836, 11.811493299901485, 13.119943588972092, 8.121128473430872, 6.42630304209888, 7.339076288044453, 6.0552420280873775, 5.025015184655786, 2.484750081785023, 1.5421747975051403, 1.0495967790484428, 0.48969394352752715, 0.18207015440566465, 0.20341261464636773, 0.281217684969306, 0.3045011137146503, 0.3303209360456094, 0.19391423760680482, 0.3340459830360487, 4.546660752967, 30.073108188807964, 66.59692883491516, 112.07097351551056, 97.97667860984802, 87.11597979068756, 96.0974970459938, 59.3203990906477, 38.95569205284119, 42.68876753747463, 75.31203478574753, 79.26778212189674, 92.48620882630348, 94.18186023831367, 117.54353865981102, 69.18513715267181, 12.695810347795486, 0.7389337616041303, 0.2109316541464068, 0.2245867409510538, 0.18245657585794106, 0.10421492232126184, 0.11237062804866582, 0.16772633971413597, 0.13865739485481754, 0.17084102961234748, 0.1400103300693445, 0.19844596943585202, 0.20784059423021972, 0.16268298611976206, 0.0978377067076508, 0.1493777328869328, 0.18381028290605173, 0.10388185386545956, 0.1675136698759161, 0.20615878369426355, 0.11077288058004342, 0.2089221408823505, 0.0814381281088572, 0.05327771672455128, 0.13012570969294757, 0.12470173824112862, 0.1350389647996053, 0.10403754160506651, 0.11379384464817122, 0.14485017192782834, 0.13301931379828602, 0.14168365043587983, 0.23102312057744712, 0.1978675098507665, 0.1182384483399801, 0.1590910804225132, 0.12077386229066178, 0.17009481496643275, 0.10041294430266134, 0.11882608087034896, 0.21632433665217832, 0.15171753155300394, 0.21323256427422166, 0.13680296076927334, 0.10941370390355587, 0.13937300333054736, 0.15227957483148202, 0.19628927344456315], [0.0535913446219638, 0.05224603126407601, 0.04872598401561845, 0.05659946953528561, 0.05405159121437464, 0.03133531172352377, 0.09426068107131869, 0.020438752580957953, 0.04308781019062735, 0.003103274275417789, 0.03179026680300012, 0.08432950577116571, 0.09817996295168996, 0.06395937030902132, 0.06244360047276132, 0.03136217375868, 0.0867621619545389, 0.024711255937290844, 0.0825821932812687, 0.03693258207931649, 0.048696632075007074, 0.04858875719946809, 0.05259251774987206, 0.013020161841268418, 0.04741415636090096, 0.027364018278603908, 0.04457724491658155, 0.04904628010990564, 0.0041452519326412585, 0.07677947418414988, 0.02719909080042271, 0.06011654077155981, 0.006646997426287271, 0.03957758526667021, 0.053111067463760264, 0.01988790274481289, 0.08104811466182582, 0.07329670872422867, 0.12050202101818286, 0.043070818719570525, 0.018942798087664414, 0.18520127545343712, 2.506590597331524, 40.36685653030872, 67.24183782935143, 71.88096329569817, 42.421018704771996, 38.02549436688423, 32.98567660152912, 34.962345734238625, 51.47302217781544, 60.53185388445854, 74.56047311425209, 70.83468183875084, 49.25831101834774, 28.011557310819626, 5.212938850745559, 0.1630707731237635, 0.39564305276144296, 0.06755190683179535, 0.208804955764208, 0.04577896754199173, 0.05031364940805361, 0.15443898708326742, 0.06684259918984026, 0.23731433611828834, 1.21930647874251, 0.4481563239824027, 5.4357151966542006, 2.7065194817259908, 1.8791901133954525, 3.1491859909147024, 2.3586664348840714, 6.398100480437279, 1.459630283061415, 5.164380306378007, 4.706186167895794, 5.349457450211048, 5.672268653288484, 6.199270924553275, 5.381519179791212, 4.510430647060275, 4.113358603790402, 10.776936113834381, 14.269135873764753, 13.564229048788548, 10.323340203613043, 9.500010833144188, 9.70932450145483, 5.144478874281049, 9.036104176193476, 22.02811148017645, 9.500201772898436, 6.128652188926935, 6.069069961085916, 4.294364741072059, 9.404993131756783, 7.825404591858387, 5.79060522839427, 6.581579335033894, 3.0582815688103437, 4.287690874189138, 2.650004639290273, 2.1188957383856177, 0.24358509806916118, 0.3369316610042006, 0.5607927893288434, 0.3465146280359477, 0.10833735970663838, 0.11024459759937599, 0.13990968000143766, 0.15677845920436084, 0.10328078846214339, 0.23941382736666128, 2.8971417155116796, 18.112814873456955, 53.07213596999645, 67.57495075464249, 62.4569445848465, 81.5457370877266, 57.49427787959576, 34.22498770058155, 22.959504202008247, 40.42069584131241, 53.91322463750839, 56.15883193910122, 48.19105848670006, 61.25655859708786, 61.613503843545914, 18.32166876643896, 0.8185649605002254, 0.339094694936648, 0.0095043773035286, 0.04288933763746172, 0.01412801020705956, 0.034271440890734084, 0.04371184506453574, 0.02736325386649696, 0.027361912434571423, 0.09129096972174011, 0.027055481514253188, 0.024156257495633326, 0.04959225218044594, 0.09960553958080709, 0.04526158299995586, 0.03672858052595984, 0.05025316066166852, 0.012510824963101186, 0.027359090418030974, 0.10116221659700386, 0.05078872782178223, 0.030838863167446107, 0.04519992908171844, 0.047124076809268445, 0.08467888663290069, 0.05181823136808816, 0.03504681451886427, 0.011091077903984115, 0.026109024292964023, 0.02799110152409412, 0.0317124340654118, 0.057632342432043515, 0.00849572161314427, 0.013341850390133914, 0.07907075865659863, 0.07335055153816938, 0.025903829737217166, 0.026683743453759234, 0.056578774747322313, 0.05497060381458141, 0.0401152823906159, 0.06798412621719763, 0.045990984290256165, 0.037820821526111104, 0.04372559335024562, 0.029311218968359753, 0.05079898801341187, 0.07129665042157285, 0.06407960565411486, 0.038529761804966256, 0.013187594995542895, 0.01375799763991381, 0.07872761183534749, 0.04545243369648233, 0.05747863251599483, 0.025569738972990308, 0.011360815187799744, 0.03121655696304515, 0.12777227035257965, 0.014561519074050011, 0.026041091805382166, 0.03767616210097913, 0.053449486804311164, 0.05237679026322439, 0.05373523221351206, 0.07724785100435838, 0.012195569906907622, 0.06780815558158793, 0.01506039259766112, 0.06572100624907762, 0.008099529786704807, 0.06645081200986169, 0.029162320024624933, 0.021119047814863734, 0.05518908837984782, 0.010749805005616508, 0.04031522068544291, 0.07201024767709896, 0.019578915125748608, 0.05150053279066924, 0.035594801520346664, 0.07582061196444556, 0.05794786280603148, 0.04666401204303838, 0.10387081070803106, 0.020524088431557175, 0.07041779914288782, 0.06764702789951116, 5.412728805094957, 56.972869858145714, 89.17518809437752, 91.3488994538784, 66.43680542707443, 65.81151098012924, 64.38940688967705, 41.314442083239555, 35.72747267782688, 34.54182229936123, 47.21949242055416, 62.30773039162159, 55.23675821721554, 37.24544182419777, 7.335343463346362, 0.12531500455224887, 0.5742961959913373, 0.11527272232342511, 0.17108708125306293, 0.19800169015070423, 0.2431264508049935, 0.9459377476014197, 0.9882697323337197, 1.8892889027483761, 3.8606619508937, 3.267448232509196, 6.072411881759763, 6.208839286118746, 2.016882374882698, 1.2073315400630236, 1.1876819632016122, 1.1733114905655384, 1.072554315906018, 3.9072453137487173, 5.086392341181636, 6.23896929435432, 9.098526276648045, 13.51271141320467, 11.72528637573123, 15.357081145048141, 12.48710559681058, 15.349624995142221, 19.259203858673573, 12.167237810790539, 14.569153524935246, 9.702885746955872, 7.242662161588669, 6.258660787716508, 9.722934421151876, 16.604791693389416, 21.944987140595913, 12.175426371395588, 13.117013946175575, 4.2659408412873745, 1.2812420865520835, 0.6939100369345397, 1.6315119224600494, 2.2349118255078793, 0.4748350189765915, 0.9685255761723965, 1.0143864434212446, 1.588165748398751, 1.0312568256631494, 0.4938710475107655, 0.6579871207941324, 0.533369779586792, 0.34249764983542264, 0.4396321048261598, 0.7833954726811498, 0.046455305273411795, 0.14401292544789612, 0.19805046409601346, 3.2329418091103435, 21.876222230494022, 58.43760386109352, 57.5946456938982, 43.862326964735985, 46.483091935515404, 22.842024005949497, 26.681178398430347, 35.869300067424774, 67.86140218377113, 90.25597929954529, 80.03455057740211, 64.2766897380352, 76.45561382174492, 83.89736250042915, 34.23987150192261, 1.2912501557730138, 0.40271411708090454, 0.06253575294977054, 0.10534794433624484, 0.01977037809410831, 0.009748219199536834, 0.07039038420771249, 0.015340873396780808, 0.05561834288528189, 0.11265543464105576, 0.09324902988737449, 0.08436415664618835, 0.03742573178897146, 0.0465908177284291, 0.02122866117133526, 0.01744737608532887, 0.06375451528583653, 0.07288298365892842, 0.05180947031476535, 0.028020945137541275, 0.01734425466565881, 0.0964133620436769, 0.08087653754046187, 0.029659486608579755, 0.041721627640072256, 0.017301373372902162, 0.0320445006218506, 0.021771896572317928, 0.061123379127820954, 0.03217441728338599, 0.029508164552680682, 0.04953022347763181, 0.08603024849435315, 0.03850995759421494, 0.0666439114138484, 0.026549399881332647, 0.018299088878848124, 0.04997445081244223, 0.04817027867829893, 0.019923677973565646, 0.010724028361437377, 0.06059292907593772, 0.04324888592236675, 0.05749033247411717, 0.018455459394317586, 0.06903345623868518, 0.18444784713210538, 0.15355348616139963, 0.06501468204078265, 0.17085777246393263, 0.09804894420085475, 0.1472735809511505, 0.24700703710550442, 0.12536552996607497, 0.1048125812667422, 0.11834648277726956, 0.18099677137797698, 0.11398344853660092, 0.2520999958505854, 0.14170411886880174, 0.1567208833876066, 0.09597318683518097, 0.18279054231243208, 0.11737154563888907, 0.20514005242148414, 0.16115600243210793, 0.09092997424886562, 0.260478961863555, 0.2134219603613019, 0.11692405285430141, 0.17657986463746056, 0.12408718059305102, 0.15051241731271148, 0.1477779890410602, 0.12640421016840264, 0.1220563157403376, 0.1660457463003695, 0.20410545403137803, 0.10473850750713609, 0.14109396957792342, 0.18757653393549845, 0.21028977062087506, 0.13744450290687382, 0.287194675183855, 0.2059531197301112, 0.0807962148974184, 0.22259031917201355, 0.22553536895429716, 7.179277762770653, 72.36655443906784, 108.3118124306202, 100.08655339479446, 60.44931851327419, 54.96462441980839, 46.14583723247051, 50.91669782996178, 82.80562788248062, 94.99638453125954, 115.50340533256531, 105.54253622889519, 75.54691538214684, 49.83414351940155, 11.16412203758955, 0.7223797123879194, 0.9513345267623663, 0.2524453023215756, 0.8454700699076056, 0.36272058030590415, 0.1888266223249957, 0.39175458485260606, 0.28831947420258075, 1.2645993358455598, 3.6892061261460185, 5.039347065612674, 11.981219742447138, 9.726854860782623, 6.125064706429839, 13.345911763608456, 13.275299202650785, 16.10647313296795, 11.282964460551739, 14.946514125913382, 17.045590840280056, 17.437722198665142, 18.017631880939007, 19.431403018534184, 19.502164721488953, 16.80223859846592, 18.689384534955025, 33.34311202168465, 32.81010702252388, 35.742371678352356, 34.21802267432213, 26.388240717351437, 25.030729360878468, 26.690430901944637, 27.25483361631632, 43.613010942935944, 30.41454266756773, 17.724052034318447, 26.352446638047695, 18.88407088816166, 26.387486457824707, 21.267523393034935, 23.914484158158302, 19.40236307680607, 14.130743499845266, 15.600087605416775, 12.540638074278831, 9.120077770203352, 6.6508852411061525, 2.998055275529623, 1.5978084434755147, 0.5192376847844571, 0.3245504410006106, 0.16689025098457932, 0.6485467054881155, 0.42124097293708473, 0.23521607683505863, 0.4819470795337111, 5.862115491181612, 30.314545333385468, 82.75384426116943, 98.65763247013092, 92.19267457723618, 121.66609704494476, 78.63042712211609, 49.9369166046381, 29.446350820362568, 52.354609072208405, 74.47857990860939, 83.02543088793755, 69.44643393158913, 87.59505808353424, 101.64652168750763, 46.62140071392059, 2.6395573373883963, 0.6373939476907253, 0.11279777114395984, 0.20525125582935289, 0.10324069022317417, 0.1120973470096942, 0.15177757130004466, 0.07715769490459934, 0.11218345098313875, 0.21437939023599029, 0.2475818304810673, 0.24716214596992359, 0.14187461987603456, 0.24752366094617173, 0.14454492658842355, 0.23351694457232952, 0.15402659046230838, 0.13115235225996003, 0.09376357571454719, 0.21966268017422408, 0.1234207690868061, 0.16896639426704496, 0.15772279759403318, 0.20578019932145253, 0.13089451531413943, 0.13520771433832124, 0.1078953365504276, 0.09750017794431187, 0.11729923819075339, 0.1441790774697438, 0.07827495370293036, 0.2384774448000826, 0.1302767070592381, 0.10659480438334867, 0.15662670484744012, 0.10653737699612975, 0.08231789222918451, 0.21924068016232923, 0.14042155409697443, 0.11225889029446989, 0.12076394719770178, 0.19140966731356457, 0.15860111452639103, 0.25643372267950326, 0.12039864726830274, 0.1352107571437955], [0.07485878857551143, 0.056709886266617104, 0.02087073262373451, 0.04768766004417557, 0.035774616480921395, 0.044688255366054364, 0.03367287281434983, 0.07192629593191668, 0.06001268091495149, 0.019866987167915795, 0.014342195881908992, 0.0511754906619899, 0.033455067314207554, 0.03879474934365135, 0.051122987424605526, 0.012562077681650408, 0.04104302264750004, 0.017006998641591053, 0.02866828715923475, 0.024917203772929497, 0.01995505968807265, 0.06640630541369319, 0.020116152118134778, 0.006034971429471625, 0.029784167418256402, 0.04995363357011229, 0.007989103778527351, 0.03812625982391182, 0.011657922877930105, 0.013199756940593943, 0.024059800562099554, 0.049554332144907676, 0.022590105108974967, 0.04442314908374101, 0.1537050327169709, 0.04853653968893923, 0.059973888855893165, 0.13286356668686494, 0.14372595178429037, 0.10090602721902542, 1.7153672478161752, 31.41651090234518, 65.7122603058815, 74.95829656720161, 67.40547984838486, 65.60683116316795, 78.09778690338135, 88.3889950811863, 61.57229885458946, 69.07282277941704, 50.06926350295544, 48.767745941877365, 42.54937581717968, 25.699318684637547, 6.5858707297593355, 0.19351036084117368, 0.4262075142469257, 0.025575739236955997, 0.038295298800221644, 0.029062404682917986, 0.19844534603180364, 0.1971387950470671, 0.2423995765275322, 0.5802417488303035, 1.7533859889954329, 0.8287040039431304, 3.993274597451091, 4.4210342690348625, 5.394682623445988, 9.66450210660696, 8.437904175370932, 6.0966018587350845, 6.192592307925224, 7.014700993895531, 3.334278571419418, 6.595611982047558, 7.21583797596395, 6.57706375233829, 8.743442930281162, 9.687900301069021, 5.895434953272343, 11.097624655812979, 6.272567566484213, 9.890238493680954, 8.761818744242191, 10.22340651601553, 13.989610522985458, 8.924205880612135, 6.409142212942243, 6.02035847492516, 9.675181433558464, 4.4185577519237995, 4.739403985440731, 8.218028023838997, 8.438342101871967, 6.710813250392675, 4.0518175810575485, 5.4975302796810865, 4.1667756624519825, 4.005093388259411, 2.9073876282200217, 1.2761614029295743, 1.6593894828110933, 1.3503996818326414, 0.732740331441164, 1.830392419360578, 3.0153595469892025, 2.7147564897313714, 0.06869125936646014, 0.529117095284164, 0.5377501726616174, 0.1489990297704935, 0.18698136118473485, 0.0706809276016429, 0.04267582917236723, 0.136200915731024, 7.183709749951959, 37.99319989979267, 63.29835623502731, 53.750160187482834, 70.88641986250877, 84.77915078401566, 65.147245824337, 32.07095168530941, 25.024169012904167, 41.090561896562576, 70.61715871095657, 66.49879530072212, 53.0717483907938, 59.715190306305885, 29.662984795868397, 8.454975709319115, 0.35227793909143656, 0.02045970526523888, 0.017016869205690455, 0.04902078362647444, 0.01522440816188464, 0.009276898836105829, 0.02112939520884538, 0.002916359512710187, 0.05493098055012524, 0.06726359730237164, 0.09051091314177029, 0.028849094742326997, 0.0324579028529115, 0.025223972370440606, 0.0648774292494636, 0.02450932497595204, 0.038244680617935956, 0.022899717987456825, 0.015681175937061198, 0.058018170166178606, 0.05913823428272735, 0.06418978489818983, 0.009388384260091698, 0.06352148833684623, 0.04113986920856405, 0.05402117058110889, 0.03510995644319337, 0.0978534847672563, 0.10260863273288123, 0.14257983828429133, 0.021554027989623137, 0.08051822864217684, 0.02652857521752594, 0.03250218680477701, 0.06108859095547814, 0.018880760108004324, 0.05585438295383938, 0.024406886332144495, 0.02433466423099162, 0.11568390924367122, 0.037758670368930325, 0.02051634783128975, 0.07372629348537885, 0.07684866461204365, 0.036696464085252956, 0.0009389208855736797, 0.04792170744622126, 0.05005830607842654, 0.06020175416779239, 0.05556213633099105, 0.08778690462349914, 0.02603080378321465, 0.06266290511121042, 0.026335755974287167, 0.03549481196387205, 0.027670909330481663, 0.04563335816783365, 0.07861791498726234, 0.06198546529049054, 0.06472839857451618, 0.07966208708239719, 0.0490700585214654, 0.016152859025169164, 0.032015011383919045, 0.006824852189311059, 0.0707629942917265, 0.037829178108950146, 0.06595728380489163, 0.042644688655855134, 0.03958436849643476, 0.018627834324433934, 0.01960520756256301, 0.01568307212437503, 0.018892497173510492, 0.07522981788497418, 0.05734012178436387, 0.04921475876471959, 0.014400876571016852, 0.11414867287385277, 0.10366908012656495, 0.013028456269239541, 0.2004547999240458, 0.2025944265187718, 0.10528432001592591, 4.026972139254212, 43.22338744997978, 88.49872559309006, 94.88867551088333, 84.58344608545303, 103.0207559466362, 100.45981496572495, 54.8145704716444, 40.29659830033779, 41.46176777780056, 43.164350017905235, 44.38153110444546, 48.19422371685505, 33.7923239171505, 9.598692487925291, 0.10604811614030041, 0.654976851074025, 0.10497809504158795, 0.12372239274554886, 0.2629751607310027, 0.7794804952573031, 1.2523970031179488, 1.504571777768433, 2.097864579409361, 2.0329552749171853, 1.4499871130101383, 1.1157961143180728, 2.294469829648733, 2.25087714381516, 2.2844711411744356, 2.8535530669614673, 6.63084464147687, 10.174160208553076, 6.189818931743503, 3.7104856967926025, 1.9507916900329292, 1.344196277204901, 1.4906989596784115, 3.1598762422800064, 6.26450439915061, 11.096679456532001, 24.127597622573376, 15.59121698141098, 22.62754451483488, 13.45456313341856, 4.308220697566867, 0.7606568397022784, 3.6171078449115157, 2.4671176029369235, 2.0008448604494333, 0.9442214271984994, 7.079930668696761, 6.713595651090145, 6.603455236181617, 2.348871510475874, 1.3630535965785384, 1.9608582998625934, 3.1345598632469773, 5.197510253638029, 6.724422695115209, 4.845153260976076, 5.029684659093618, 4.283860204741359, 3.9414099929854274, 5.308353630825877, 3.5496379528194666, 2.135640252381563, 2.276601050980389, 0.4327661998104304, 1.284503024071455, 3.3895729668438435, 0.4701984958956018, 0.6200797611381859, 0.04657873556425329, 0.09757929830811918, 0.06323729772702791, 8.183311186730862, 46.208351477980614, 65.19079148769379, 48.18355388939381, 45.39470113813877, 38.02986793220043, 21.34636726230383, 23.98821160197258, 41.07562489807606, 74.78916764259338, 98.15589219331741, 100.85294187068939, 72.99707740545273, 78.45597088336945, 50.177249908447266, 14.297745488584042, 0.29453884984832257, 0.021329595110728405, 0.028481260378612205, 0.07236820776597597, 0.00041394869526811817, 0.031356017643702216, 0.023041228851070628, 0.037679509187000804, 0.02948952365841251, 0.037332577412598766, 0.06564183393493295, 0.055960383906494826, 0.03982709902629722, 0.017803701593948063, 0.07020722958259284, 0.02990023189340718, 0.055308607552433386, 0.02384762054134626, 0.03998064566985704, 0.04759204915899318, 0.0465015596273588, 0.04362823470728472, 0.024554866868129466, 0.02424947866529692, 0.025420919810130727, 0.03221065635443665, 0.02060973783954978, 0.013347332078410545, 0.05171168493689038, 0.007437155099978554, 0.006895711057950393, 0.02552521567849908, 0.01555487539008027, 0.032548953240620904, 0.06430937457480468, 0.05114999046782032, 0.07119529531337321, 0.04999197662982624, 0.022129316748760175, 0.09355191519716755, 0.005053968161519151, 0.02479593313182704, 0.06656791549175978, 0.021822939634148497, 0.17279589112149552, 0.11612269663601182, 0.13816218939609826, 0.15931486763292924, 0.16039145673858002, 0.20584651763783768, 0.1881030877120793, 0.1456516914186068, 0.10477583011379465, 0.2193244537920691, 0.08867259108228609, 0.10762267891550437, 0.12808147876057774, 0.12707567570032552, 0.2045888890279457, 0.12607830343768, 0.24926790094468743, 0.1714436535257846, 0.11074566602474079, 0.19460461306152865, 0.11488687974633649, 0.16515758848981932, 0.1543228855007328, 0.1809280930319801, 0.09446664931601845, 0.11387528793420643, 0.10583918672637083, 0.10012896891566925, 0.15322190942242742, 0.0972436620213557, 0.22510667477035895, 0.17514510022010654, 0.08370425377506763, 0.08951949290349148, 0.23625655303476378, 0.23069102433510125, 0.16809318331070244, 0.25635547062847763, 0.37122951122000813, 0.1936448528431356, 5.171493524685502, 54.80338767170906, 106.66980654001236, 104.47740018367767, 95.63033491373062, 91.04727923870087, 110.18055975437164, 104.8686271905899, 84.83896717429161, 103.72559532523155, 73.99742692708969, 73.15941229462624, 65.96322163939476, 45.33473655581474, 12.146969698369503, 0.5604742001742125, 0.941653240006417, 0.13688458217075095, 0.19415135378949344, 0.34642479848116636, 0.7777979574166238, 0.5685531604103744, 1.2749445182271302, 2.35261217225343, 6.491810102015734, 6.947462651878595, 10.491547677665949, 17.342533506453037, 18.055265061557293, 25.289335884153843, 26.966533586382866, 22.397115379571915, 22.787812314927578, 20.884154364466667, 14.414201639592648, 17.926434874534607, 16.503722816705704, 19.675332829356194, 23.544150330126286, 24.254957288503647, 19.50813230127096, 28.741346150636673, 22.919997721910477, 27.824386954307556, 31.093068458139896, 28.03710523992777, 29.340524598956108, 27.92394921183586, 19.962608814239502, 23.254685662686825, 29.327162615954876, 23.887896984815598, 19.959964156150818, 23.72815165668726, 27.200097553431988, 22.97574833035469, 22.46343322098255, 23.652165234088898, 15.15371510758996, 12.47183421626687, 11.061632987111807, 12.50921756029129, 10.801050569862127, 8.217798136174679, 10.239624995738268, 7.902576075866818, 10.397107545286417, 8.487478215247393, 1.5044014994055033, 1.0704866331070662, 1.2612740392796695, 0.2798348560463637, 0.2854712895350531, 0.1648214549641125, 0.19853458186844364, 0.5982815776951611, 12.831900995224714, 61.990702003240585, 102.57525265216827, 81.5387986600399, 109.42002296447754, 110.06066858768463, 96.16666093468666, 50.887823179364204, 34.322053492069244, 57.44327321648598, 95.15965417027473, 94.84272077679634, 76.01155444979668, 96.31669208407402, 69.0913125872612, 19.92145512253046, 0.5495419492945075, 0.28002754726912826, 0.12282069073989987, 0.1312313464586623, 0.05344851088011637, 0.23226549063110724, 0.12552559637697414, 0.10545341836404987, 0.1335725700482726, 0.11379420830053277, 0.18327528348891065, 0.18010435363976285, 0.13739218149567023, 0.17874735145596787, 0.15783879527589306, 0.09110137325478718, 0.11915936454897746, 0.14798289601458237, 0.0851766747655347, 0.19689801265485585, 0.10728577355621383, 0.21858281077584252, 0.0904846856428776, 0.12685602967394516, 0.12591491220518947, 0.18028448772383854, 0.10204033314948902, 0.17550809949170798, 0.2599497511982918, 0.19585531001212075, 0.10765300306957215, 0.15152080304687843, 0.08263263705885038, 0.14692475670017302, 0.14147139620035887, 0.14823365287156776, 0.19161381729645655, 0.11663442972349003, 0.12686980393482372, 0.14708065224112943, 0.13613866438390687, 0.11754422856029123, 0.1730942790163681, 0.14684825611766428], [0.022334574387059547, 0.05709605538868345, 0.03855936236504931, 0.014451219230977586, 0.04200163995847106, 0.047545535053359345, 0.02406547613645671, 0.09430959602468647, 0.04863853675487917, 0.01837726857047528, 0.05293178684951272, 0.03036480520677287, 0.006577926669706358, 0.014358131647895789, 0.019936010612582322, 0.06425220693927258, 0.024489227616868448, 0.07850227353628725, 0.05673575753462501, 0.06362019397784024, 0.011614840277616167, 0.030356361421581823, 0.10737432661699131, 0.0445448984100949, 0.004061483405166655, 0.13890853762859479, 0.04078225792909507, 0.05708080425392836, 0.023973147399374284, 0.047099381845328026, 0.022472118471341673, 0.03218387966626324, 0.02745649358985247, 0.021054707322036847, 0.009674938610260142, 0.06584530856343918, 0.028865397871413734, 0.3512392588891089, 1.7391487467102706, 26.99056539684534, 76.83750852942467, 90.02045273780823, 67.77867302298546, 70.02106949687004, 50.14437027275562, 32.22317531704903, 33.34894470870495, 81.34437069296837, 109.1087132692337, 46.439170092344284, 45.508926808834076, 33.88630047440529, 9.951066579669714, 0.43346604506950825, 0.5447968351654708, 0.08402820123592392, 0.0684410888061393, 0.17352521448628977, 0.13712382089579478, 0.10132083581993356, 0.0737107454915531, 0.27813691121991724, 1.8988070357590914, 1.8726020981557667, 8.115153294056654, 5.6867107283324, 5.842161811888218, 4.890523301437497, 18.809686079621315, 32.951242849230766, 46.28512255847454, 64.09651100635529, 72.83829152584076, 76.93330138921738, 60.06162531673908, 39.314468801021576, 14.125706870108843, 4.051552070304751, 4.758548308163881, 8.674776814877987, 9.396860618144274, 13.024956285953522, 10.93710321933031, 12.647510189563036, 12.24180880934, 2.3780373204499483, 6.47015648894012, 3.585380259901285, 3.0883146822452545, 2.1825841208919883, 3.467687275260687, 10.461421944200993, 22.605382204055786, 10.354236345738173, 9.904892407357693, 4.470641082152724, 11.088368352502584, 36.128966733813286, 62.706180810928345, 77.21331596374512, 82.4438188970089, 73.08977723121643, 67.12997943162918, 71.2983025610447, 83.25691446661949, 83.36971521377563, 63.773748725652695, 21.317087933421135, 0.5867756169755012, 6.53555715456605, 23.582532070577145, 2.4098910111933947, 0.21304480091203004, 0.225414294982329, 0.05595848029770423, 0.08727192835067399, 0.35174558172002435, 0.25168074178509414, 13.427335694432259, 43.64947758615017, 40.87487407028675, 52.29570463299751, 83.5253244638443, 100.66182732582092, 51.24373488128185, 20.498811341822147, 23.079110383987427, 29.725400246679783, 50.14192320406437, 58.16275700926781, 62.30684503912926, 45.73650039732456, 13.181676976382732, 0.9002320189028978, 0.055976874427869916, 0.060708396122208796, 0.03989695367636159, 0.10428765279357322, 0.051350125431781635, 0.026714646483014803, 0.03585744387237355, 0.04459785806830041, 0.028250137038412504, 0.02413078513200162, 0.02341487237572437, 0.043858478602487594, 0.06481776799773797, 0.04529017794993706, 0.03634060427430086, 0.018182619933213573, 0.053269204290700145, 0.05585589322436135, 0.04158627474680543, 0.05258517419861164, 0.003538147302606376, 0.04122319012822118, 0.03965809715737123, 0.03333440523419995, 0.04177223097940441, 0.020353670915937982, 0.0622169077541912, 0.01856518221757142, 0.02480854407622246, 0.02664163213921711, 0.019342411214893218, 0.037111988858669065, 0.07413908344460651, 0.047092405657167546, 0.07837878758437, 0.04837191278056707, 0.03806074302701745, 0.06127120752353221, 0.09601859143003821, 0.0506250694161281, 0.08894267346477136, 0.025221662435797043, 0.01652672148338752, 0.02659723500983091, 0.06486029305960983, 0.02649283895152621, 0.05893989531614352, 0.019658634773804806, 0.0025648888095020084, 0.06151779351057485, 0.0444217575568473, 0.06239011388970539, 0.04266264120815322, 0.036519977657007985, 0.04622097585524898, 0.0205362114138552, 0.03790281400142703, 0.07523028543801047, 0.03578419389668852, 0.04745523794554174, 0.07705330441240221, 0.04641605308279395, 0.03078763827943476, 0.024148759948730003, 0.015614670228387695, 0.06394374067895114, 0.03421628076466732, 0.03323932869534474, 0.02645631044288166, 0.09209815179929137, 0.03813763694779482, 0.03595624970330391, 0.01609933347936021, 0.04985872030374594, 0.03202026950020809, 0.07761730696074665, 0.1108393473259639, 0.03967931144870818, 0.030230437514546793, 0.37525661231484264, 4.232902089133859, 37.111176028847694, 97.279492020607, 114.81794491410255, 89.92810249328613, 98.99458318948746, 97.1151964366436, 60.75149729847908, 53.225883319973946, 87.37299039959908, 79.53378304839134, 44.27569538354874, 51.80006682872772, 44.20864798128605, 14.896231424063444, 0.728892800398171, 0.6982351548504084, 0.10685359869967215, 0.11616267613135278, 0.2985361166065559, 0.9091737703420222, 1.177126842085272, 0.6654787750449032, 0.6699978013057262, 1.2343073613010347, 3.0105570796877146, 1.970560010522604, 0.35372675978578627, 5.736128026619554, 12.650371436029673, 24.497171491384506, 40.981321558356285, 61.630621924996376, 80.08805930614471, 85.6032657623291, 91.75513565540314, 73.41218993067741, 50.58304913341999, 21.63257360458374, 6.323718521744013, 0.6355443375650793, 0.648236369015649, 1.6053000977262855, 10.33462654799223, 18.674609027802944, 9.121661335229874, 1.9120487314648926, 0.5945792701095343, 2.032220964320004, 3.2810154045000672, 3.762278105132282, 2.6919149653986096, 1.266690173652023, 2.493239063769579, 2.728954190388322, 0.5931391473859549, 1.4372266852296889, 7.539565404877067, 18.68635419756174, 50.82500874996185, 81.6722323000431, 96.84227988123894, 101.36910617351532, 89.76666435599327, 82.69715130329132, 85.60336455702782, 98.97447466850281, 99.35386151075363, 78.82101729512215, 31.8811746686697, 3.8384172320365906, 3.907815283164382, 12.64060216024518, 1.7171150352805853, 1.0487677110359073, 0.2508199098519981, 0.19157665054081008, 0.0011239246759942034, 0.7593807019293308, 0.15207775519229472, 14.939188119024038, 54.07869055867195, 44.61317427456379, 52.239574044942856, 67.9019384086132, 64.85228285193443, 30.93299824744463, 24.46992315351963, 47.20267452299595, 54.54926110804081, 84.85940247774124, 81.7141592502594, 78.29657703638077, 70.3685912489891, 25.742434971034527, 0.4374598682625219, 0.03615327506850008, 0.002877435026675812, 0.0642873031029012, 0.04327508373535238, 0.036870571930194274, 0.08290353580377996, 0.025878696906147525, 0.016766971384640783, 0.04260322486516088, 0.005815456670461572, 0.05079285416286439, 0.03593529516365379, 0.03647161189292092, 0.04091529161087237, 0.027726588959922083, 0.025391796079929918, 0.06429783417843282, 0.042550576908979565, 0.036218580353306606, 0.04048005539516453, 0.014086888731981162, 0.02866658949642442, 0.049315887517877854, 0.08020648208912462, 0.041133483027806506, 0.015878911908657756, 0.09698692345409654, 0.015852081414777786, 0.05543888044485357, 0.050978873478015885, 0.08553013001801446, 0.010510882621019846, 0.047795716745895334, 0.021487950871232897, 0.026873506903939415, 0.035963118280051276, 0.022640834613412153, 0.010071849392261356, 0.037273854977684096, 0.04351578820205759, 0.01881587228126591, 0.07424463910865597, 0.07687625766266137, 0.1531540771247819, 0.12356655657640658, 0.13121215451974422, 0.15341454127337784, 0.08979940874269232, 0.10858318128157407, 0.20395686122355983, 0.27909395517781377, 0.11226372909732163, 0.2695374976610765, 0.09725144715048373, 0.10404096290585585, 0.0765231809054967, 0.1446237278287299, 0.2563983964500949, 0.06846790260169655, 0.08392107221879996, 0.10830970728420652, 0.17744045908330008, 0.1455215335590765, 0.1267697921139188, 0.22968070901697502, 0.15059834317071363, 0.13712196552660316, 0.2044028919772245, 0.1408405855181627, 0.21846970746992156, 0.177773475588765, 0.18344452284509316, 0.07056258473312482, 0.11441635811934248, 0.08679771824972704, 0.1288654687232338, 0.25024332047905773, 0.26739717344753444, 0.10275928871124052, 0.5242417193949223, 6.282738670706749, 48.806728050112724, 115.45616626739502, 127.73368746042252, 91.81747511029243, 102.1260179579258, 76.42212241888046, 47.46698834002018, 43.65820571780205, 96.54672414064407, 156.99559807777405, 69.96439173817635, 74.29601490497589, 60.934734866023064, 18.446562364697456, 1.5058935130946338, 1.0378284542821348, 0.25801259733270854, 0.18144253495847806, 0.42592247016727924, 0.6957465258892626, 0.6219030101783574, 0.7187187869567424, 3.747669314034283, 9.410594031214714, 14.440433531999588, 22.38306563347578, 20.741969794034958, 19.99843329191208, 17.67162624746561, 27.69404634833336, 41.395066156983376, 52.54239499568939, 73.39645117521286, 78.87550637125969, 87.14884802699089, 65.967887789011, 44.583353474736214, 17.31109779328108, 10.916391480714083, 15.701423417776823, 26.272327937185764, 22.7111704275012, 31.426939442753792, 33.55788789689541, 28.88241358101368, 38.62789124250412, 20.73857467621565, 19.84285444021225, 10.837990287691355, 9.324768986552954, 5.862338254228234, 15.856676436960697, 30.897122472524643, 48.785623982548714, 28.977172896265984, 28.52766651660204, 12.266015410423279, 14.054588936269283, 41.36983551084995, 75.06709232926369, 88.34760010242462, 96.25189036130905, 80.59478491544724, 74.03050795197487, 77.30363711714745, 89.63318511843681, 89.26978021860123, 67.2348690032959, 22.252544537186623, 3.7251410353928804, 13.216313067823648, 34.71031665802002, 4.812689702957869, 0.4791262949584052, 0.7911163021344692, 0.4145523818442598, 0.21441706165205687, 0.8573228807654232, 0.9550368937198073, 22.245345823466778, 75.61905831098557, 60.5115819722414, 80.12232586741447, 109.46815118193626, 126.7278054356575, 73.38596373796463, 31.34823616594076, 32.374190613627434, 41.379407197237015, 75.3207515180111, 81.13381639122963, 92.66283854842186, 89.09501239657402, 37.113801687955856, 1.142447527963668, 0.1745798360207118, 0.10281927650794387, 0.1485624985070899, 0.18982228764798492, 0.1253062768955715, 0.13391210261033848, 0.22759539278922603, 0.12544335157144815, 0.10731926668086089, 0.21187410748098046, 0.11563663443666883, 0.13947470724815503, 0.13711847743252292, 0.10848750360310078, 0.08574869993026368, 0.11327164727845229, 0.17044821084709838, 0.12874872889369726, 0.18203113228082657, 0.1495098797022365, 0.10160496705793776, 0.16254218586254865, 0.14585429773433134, 0.2324339433107525, 0.12484976701671258, 0.14669808995677158, 0.26623841375112534, 0.06529994134325534, 0.12902734597446397, 0.1360766208381392, 0.20967426302377135, 0.10065790498629212, 0.13193988968851045, 0.08841986753395759, 0.16509696986759081, 0.12089523312170058, 0.0963699389831163, 0.13321991631528363, 0.2436226952704601, 0.13807863841066137, 0.20929250225890428, 0.16793179587693885], [0.0717011654342059, 0.016652237209200393, 0.03240131038182881, 0.013766358861175831, 0.016758128695073538, 0.05924309232796077, 0.00464871749500162, 0.07208941999124363, 0.028131757062510587, 0.04047008835186716, 0.023715308598184492, 0.13485517934896052, 0.06565198651514947, 0.03404623988899402, 0.0190765887600719, 0.021458016344695352, 0.009589511846570531, 0.05451434255519416, 0.11247334870859049, 0.10361604625359178, 0.0500305608875351, 0.041359830647706985, 0.0327274694427615, 0.07733061531325802, 0.03990242330473848, 0.03904930599674117, 0.04097127552086022, 0.06096395467466209, 0.10171807036385871, 0.09685016048024409, 0.030564352018700447, 0.050742944731609896, 0.02445116657327162, 0.050661212007980794, 0.11811819073045626, 0.07395232198177837, 0.5969996808562428, 21.72454956918955, 74.3929173052311, 99.37881097197533, 80.82304626703262, 66.26564741134644, 58.354376927018166, 39.69624571502209, 20.683734118938446, 41.16006776690483, 55.60368172824383, 26.620653346180916, 32.11171209812164, 34.55186516046524, 18.20150401443243, 1.902288836427033, 0.6162617972586304, 0.20477360958466306, 0.13689751038327813, 0.16576791589614004, 0.2056061360053718, 0.02205357130151242, 0.12321075613726862, 0.22931653715204448, 0.4625539592234418, 6.176124466583133, 8.993724100291729, 14.185418765991926, 21.485145315527916, 40.35948872566223, 80.1631660759449, 96.73652395606041, 113.61605420708656, 124.04919236898422, 131.31522327661514, 127.71056950092316, 126.36646762490273, 119.81083899736404, 128.77811461687088, 124.43030431866646, 121.64756163954735, 78.83269786834717, 23.00278577953577, 1.7914200481027365, 3.1020827684551477, 24.44159757345915, 15.966281555593014, 22.037719264626503, 6.21271887794137, 3.473845557309687, 9.462933372706175, 32.17343218624592, 44.69084210693836, 32.043634951114655, 5.722478684037924, 0.6168932758737355, 0.8007920673117042, 2.2340922569856048, 4.981579715386033, 49.24625426530838, 99.26043972373009, 122.7058656513691, 123.55085670948029, 121.04274809360504, 125.84694430232048, 133.62432897090912, 121.03529289364815, 119.09711569547653, 133.71740877628326, 126.53653889894485, 132.42099434137344, 140.32852202653885, 94.10698145627975, 14.502233415842056, 1.0465390118770301, 2.9970951145514846, 2.598875295370817, 0.26103138690814376, 0.03289898348157294, 0.23471388034522533, 0.08100866951281205, 0.0918258132878691, 0.16883921984117478, 3.9655491476878524, 35.99767617881298, 35.391456708312035, 43.639278933405876, 72.49067097902298, 86.7405067384243, 77.26549476385117, 63.508150577545166, 65.97141399979591, 34.10490274429321, 47.65223979949951, 42.52341940999031, 54.65595558285713, 48.60212042927742, 21.86764609068632, 1.788198770955205, 0.1485075053642504, 0.029922403555247, 0.0018981355674441147, 0.03217996112653054, 0.025224361997970846, 0.03405234034289606, 0.06365008026477881, 0.04704331258835737, 0.016496133866894525, 0.015593201751471497, 0.012886507538496517, 0.08389986905967817, 0.07278131684870459, 0.04728208376036491, 0.021470701503858436, 0.04021064094558824, 0.01207039000291843, 0.05224235021159984, 0.19142114091664553, 0.03145815200696234, 0.05456655635498464, 0.06439392745960504, 0.026942623117065523, 0.025772154185688123, 0.03199045742803719, 0.08611843790276907, 0.016348364842997398, 0.05133017279149499, 0.019797869099420495, 0.06973298237426206, 0.03569882093870547, 0.06164378050016239, 0.03818309720372781, 0.00657185543786909, 0.030920232238713652, 0.022726868082827423, 0.05888575564313214, 0.029365382761170622, 0.04191341715340968, 0.029307964650797658, 0.026735760584415402, 0.010009099878516281, 0.03172224525769707, 0.033408705348847434, 0.0036057794523003395, 0.011343019414198352, 0.07999048742931336, 0.0138107624843542, 0.04216276021907106, 0.0468362608080497, 0.05115074003697373, 0.056672715800232254, 0.05890881046070717, 0.027841543924296275, 0.048457708762725815, 0.029770838445983827, 0.08709169036592357, 0.030457087559625506, 0.023392691437038593, 0.045856247379560955, 0.058204683009535074, 0.06356672965921462, 0.08217791575589217, 0.06716896605212241, 0.048451304028276354, 0.027081228472525254, 0.02836193973053014, 0.014092531837377464, 0.01530713721876964, 0.03953491548600141, 0.03265364430262707, 0.05651430066791363, 0.02335648390726419, 0.027673432632582262, 0.023517450172221288, 0.08290854530059732, 0.18164309294661507, 2.4501935485750437, 35.03789708018303, 95.4724533855915, 122.48389676213264, 99.08729821443558, 85.6487113237381, 100.19940733909607, 80.54783463478088, 35.457356572151184, 24.10731241106987, 25.605855099856853, 28.50490003824234, 39.99392554163933, 44.280581921339035, 24.727336540818214, 2.504364629276097, 0.8234551199711859, 0.19859295920468867, 0.11716643086401746, 0.04255170497344807, 0.5559105263091624, 1.155608834233135, 0.4934371286071837, 1.0704525536857545, 1.544885952025652, 7.755561964586377, 12.771933563053608, 20.9003034979105, 31.60230193287134, 55.75983814895153, 93.83465766906738, 112.05131337046623, 124.44563269615173, 132.24938035011292, 132.32896327972412, 126.80742636322975, 126.4953339099884, 124.08712193369865, 129.7243246436119, 129.47774827480316, 127.85400420427322, 91.85309439897537, 33.99421088397503, 5.226160241290927, 0.7368017791304737, 2.346228752285242, 2.7459435537457466, 2.2036335663869977, 0.9842706844210625, 2.7594914892688394, 17.10922222584486, 47.42381125688553, 64.5252799987793, 49.136497154831886, 11.275340169668198, 1.8249661917798221, 1.9529566238634288, 2.56266038864851, 10.071212332695723, 61.235587522387505, 109.45476070046425, 127.12371379137039, 125.28442248702049, 119.78677108883858, 125.18995195627213, 134.56360816955566, 118.82918447256088, 117.17732191085815, 134.2048466205597, 127.27817550301552, 135.53685754537582, 148.62657755613327, 113.6615377664566, 25.87216190993786, 2.8120851796120405, 2.3478450905531645, 0.8732515666633844, 0.2787310449639335, 0.1833051920402795, 0.4058304842328653, 0.13784009730443358, 0.006163111575006042, 0.3393216436961666, 3.502230509184301, 43.755925074219704, 42.50148318707943, 46.83753311634064, 75.7358868420124, 63.142906576395035, 44.464100673794746, 48.31782728433609, 35.78514218330383, 48.376769721508026, 77.31961905956268, 67.18769833445549, 74.30069625377655, 68.62983494997025, 41.72276057302952, 3.239900660701096, 0.20528753200778738, 0.09213824261678383, 0.0576693941548001, 0.04735889604489785, 0.03623475175118074, 0.027351366516086273, 0.05858018746948801, 0.015662444129702635, 0.03284694037574809, 0.016730479983380064, 0.03838690579868853, 0.041643635340733454, 0.07914380825241096, 0.08739724740735255, 0.01946992146258708, 0.034153079468524083, 0.04953332194418181, 0.052575162626453675, 0.08869983532349579, 0.0738904342870228, 0.014455714790528873, 0.021969354238535743, 0.05372360275941901, 0.004695450070357765, 0.05695160376490094, 0.04195361558231525, 0.015325478470913367, 0.02402466914645629, 0.022495436751341913, 0.030367078034032602, 0.021930899856670294, 0.07945533958263695, 0.024451010722259525, 0.07865494073485024, 0.013665434198628645, 0.08294724088045768, 0.03531215828843415, 0.03264767372456845, 0.01454752309655305, 0.025212174077751115, 0.04696100098954048, 0.13511721685063094, 0.11157126820762642, 0.13033576717134565, 0.12558392918435857, 0.11617452080827206, 0.15328190464060754, 0.11511064469232224, 0.30591092712711543, 0.1970140845514834, 0.21888407820370048, 0.10305825548130088, 0.2459131262730807, 0.14325893309433013, 0.1524063930264674, 0.14656711573479697, 0.1573911021114327, 0.06178343784995377, 0.1343435575836338, 0.20910312101477757, 0.19903848529793322, 0.23785663826856762, 0.20206151995807886, 0.1372864848235622, 0.164767827372998, 0.0854396251088474, 0.15538390434812754, 0.08123158841044642, 0.13139803282683715, 0.12388834438752383, 0.14480147219728678, 0.14668566640466452, 0.120810242369771, 0.1388215579208918, 0.17005614907247946, 0.20512883114861324, 0.5415861262008548, 2.976585952565074, 45.77169790863991, 116.89829528331757, 138.70155572891235, 102.87732884287834, 91.31581082940102, 83.85494157671928, 55.85025429725647, 32.49377779662609, 65.67961245775223, 88.08553576469421, 45.43073460459709, 56.78908511996269, 59.32604558765888, 34.24170300364494, 3.888007183559239, 1.258761661592871, 0.2559605293208733, 0.36112911882810295, 0.2289689745521173, 0.627210137899965, 0.41699458204675466, 0.3801573993405327, 2.499491865746677, 7.966814953833818, 18.401804566383362, 18.23292452841997, 20.716514959931374, 29.0163753926754, 47.506662011146545, 92.3821172118187, 105.77516734600067, 126.92909583449364, 138.93241614103317, 144.8914235830307, 139.25086945295334, 137.5201079249382, 128.10238927602768, 139.98322695493698, 131.81892424821854, 134.7838595509529, 86.86260178685188, 31.758783236145973, 7.19823494553566, 16.44304197281599, 48.13713937997818, 35.36966107785702, 47.02805869281292, 21.27676449716091, 8.296048287302256, 15.696135051548481, 51.78189620375633, 69.07221481204033, 58.71129937469959, 10.443788040429354, 3.2803851133212447, 11.737030595541, 7.661218727007508, 7.97235980629921, 59.10983718931675, 113.6206367611885, 140.58174043893814, 135.59829264879227, 132.57803231477737, 133.62410098314285, 146.13125145435333, 120.52947923541069, 121.61470100283623, 143.6054053902626, 140.92680752277374, 148.36414843797684, 159.90029901266098, 107.62925505638123, 19.50027622282505, 8.629166912287474, 14.45953605696559, 6.365752341225743, 0.3707457199925557, 0.2322853505029343, 0.7327825448010117, 0.29654876387212425, 0.1944392328732647, 0.3284857829567045, 5.964036947116256, 60.69923870265484, 58.930441215634346, 63.27275700867176, 87.8822922706604, 109.81193393468857, 104.95954871177673, 78.69240939617157, 88.07872653007507, 48.49528156220913, 66.77762433886528, 69.54284235835075, 81.64042040705681, 87.21904546022415, 57.22103454172611, 5.1142476964741945, 0.4299850162351504, 0.21605383866699412, 0.10686005538445897, 0.16752077965065837, 0.08728801069082692, 0.14686639420688152, 0.14086173672694713, 0.1972331220167689, 0.12004403426544741, 0.10328823962481692, 0.15254879632266238, 0.10829116101376712, 0.16363391478080302, 0.16932203143369406, 0.10134037656825967, 0.1268676368636079, 0.08202383105526678, 0.09792182172532193, 0.2607745147543028, 0.08808854312519543, 0.12279806265723892, 0.11212993471417576, 0.1989005200448446, 0.11013634051778354, 0.18650503596290946, 0.14580585033399984, 0.08381318621104583, 0.12435490294592455, 0.19115221628453583, 0.11489485041238368, 0.09867609609500505, 0.19384118058951572, 0.1464044814929366, 0.1068889768794179, 0.11877978569827974, 0.15693580935476348, 0.1670773167279549, 0.1277691830182448, 0.13189608813263476, 0.2114201951189898, 0.10884924864512868], [0.05378685971663799, 0.06426239662687294, 0.008728505508770468, 0.031101681779546198, 0.043498659433680587, 0.042076882600667886, 0.0407476812688401, 0.04995091730961576, 0.0925200256460812, 0.030520064356096555, 0.04756177695526276, 0.05822872859425843, 0.02306109799974365, 0.03212452640582342, 0.01952592207089765, 0.0045757096449960954, 0.08253395368228666, 0.010907992855209159, 0.1409099911688827, 0.05254053401586134, 0.024339905648957938, 0.02275234230182832, 0.06352795244310983, 0.08236982772359625, 0.07261330203618854, 0.050203596329083666, 0.08379268067074008, 0.21011707285651937, 0.22435055987443775, 0.09012958282255568, 0.06905477814143524, 0.015078933301992947, 0.07269159861607477, 0.03224445004889276, 0.10569169229711406, 3.319091498851776, 70.66491454839706, 98.08089181780815, 96.32179141044617, 66.54786586761475, 68.50229099392891, 72.08137214183807, 44.4478565454483, 32.58451692759991, 58.30858938395977, 81.42022222280502, 63.82180854678154, 43.45049366354942, 33.630961775779724, 10.341937355697155, 0.28821545478422195, 0.5366408103145659, 0.09058754731086083, 0.15938301163259894, 0.20486988098127767, 0.07466713635949418, 0.09703579387860373, 0.20709270233055577, 1.916678783018142, 7.398415803909302, 27.646273411810398, 63.55442449450493, 92.22466886043549, 109.21081379055977, 120.74046671390533, 119.60167542099953, 107.31004938483238, 104.73559632897377, 104.43596720695496, 98.94990518689156, 97.68517345190048, 97.42910519242287, 99.57688674330711, 102.15667471289635, 100.28222769498825, 100.97727119922638, 102.06820785999298, 116.49030357599258, 122.42414116859436, 65.50423666834831, 10.169601403176785, 1.0923611093312502, 9.429042991250753, 2.933831359259784, 1.1067731422372162, 31.964409202337265, 77.86101400852203, 91.89025640487671, 100.52941963076591, 104.34316858649254, 76.02408617734909, 31.154129281640053, 4.037984423339367, 19.20458558946848, 72.89143547415733, 103.98659572005272, 109.62722584605217, 105.06967440247536, 103.91887575387955, 93.76968875527382, 99.45168346166611, 107.64519900083542, 108.43345910310745, 107.61739209294319, 109.83581945300102, 102.25166201591492, 102.79609680175781, 100.91959789395332, 120.78276604413986, 125.11413842439651, 58.89082834124565, 18.055251762270927, 20.636827535927296, 5.075136870145798, 0.8110348926857114, 0.2619064977625385, 0.04114329050935339, 0.0982974078215193, 0.03044092172785895, 0.09306375271989964, 0.35120241867844015, 21.085349768400192, 36.835527420043945, 46.43466353416443, 61.15260757505894, 61.742252334952354, 162.5803256034851, 174.89937096834183, 45.95808930695057, 30.146639943122864, 46.3429706543684, 51.385775059461594, 56.54590956866741, 61.193405985832214, 40.67253112792969, 9.188050422817469, 0.40356942743528634, 0.07879630502429791, 0.13239157560747117, 0.1630262442631647, 0.09288457600632682, 0.07312191810342483, 0.05055428708146792, 0.052122764245723374, 0.07946026744320989, 0.03221804814529605, 0.12020175548968837, 0.1517036385484971, 0.2922156307613477, 0.1681379645015113, 0.09239665101631545, 0.07719199697021395, 0.04288344498490915, 0.05698311535525136, 0.08710776528459974, 0.06093516305554658, 0.047972756074159406, 0.017885248780658003, 0.047355541537399404, 0.06777683694963343, 0.018387564014119562, 0.0547782799549168, 0.007248213114507962, 0.05607693819911219, 0.03686021897010505, 0.06761898956028745, 0.038685405015712604, 0.06826420532888733, 0.03927786150597967, 0.03368099933140911, 0.04880224711087067, 0.08702507519046776, 0.08532532694516703, 0.2071981763583608, 0.14181674720020965, 0.1324997510528192, 0.07456797800841741, 0.02190429386246251, 0.029275299020810053, 0.03638309222878888, 0.016625247153569944, 0.060269849927863106, 0.05918767616094556, 0.03308188577648252, 0.07741183595499024, 0.062022791607887484, 0.02179635404900182, 0.04326448957726825, 0.03440733184106648, 0.03592430024582427, 0.04755930931423791, 0.02111010307999095, 0.09235464545781724, 0.0043667431236826815, 0.06540610556839965, 0.04995696210244205, 0.04756561014801264, 0.038791799306636676, 0.06163676720461808, 0.014348216554935789, 0.06662822241196409, 0.06771053347620182, 0.1609606246347539, 0.10591669662971981, 0.18781759834382683, 0.2568393509136513, 0.03328820654132869, 0.0482729102805024, 0.0565527513390407, 0.03511329981847666, 0.15011026232969016, 11.083989087492228, 92.65149235725403, 119.04004275798798, 115.6386248767376, 82.867351770401, 101.68838024139404, 117.79661267995834, 62.58398316800594, 25.553573705255985, 26.927165798842907, 57.82442696392536, 61.29391059279442, 52.78847739100456, 44.067892134189606, 12.33037255704403, 0.39520886668469757, 0.6514154921751469, 0.02738630497333361, 0.15436601912369952, 0.21644848311552778, 0.3288098343182355, 0.4279615357518196, 1.7372615542262793, 3.1209432939067483, 8.743026852607727, 34.863019064068794, 76.54911160469055, 102.93250948190689, 121.24823346734047, 127.54169136285782, 125.35384476184845, 110.27164086699486, 108.24035346508026, 107.66883373260498, 102.25765809416771, 103.97177651524544, 102.41085067391396, 102.95510306954384, 108.28845128417015, 104.7564648091793, 105.38501188158989, 104.85731139779091, 115.96764162182808, 124.72900629043579, 80.04713550209999, 16.526586189866066, 2.698681689798832, 0.91141268145293, 0.592010251712054, 3.5992884635925293, 46.16308070719242, 92.96496793627739, 102.85863384604454, 108.5909378528595, 116.39728456735611, 99.50944036245346, 44.38890650868416, 7.987269256263971, 27.60714501142502, 88.72502624988556, 112.59571775794029, 115.03964021801949, 109.98626098036766, 111.21661216020584, 101.5959084033966, 103.05594965815544, 114.32751283049583, 114.88835513591766, 109.897201359272, 118.23653027415276, 110.80457746982574, 110.43173387646675, 107.86225095391273, 121.61964073777199, 136.66854321956635, 82.38042309880257, 30.193111449480057, 29.770334735512733, 11.888485718518496, 3.6314660869538784, 0.09371250111144036, 0.07400849513942376, 0.026823256084753666, 0.09908542764605954, 0.2171595793333836, 0.4689710430102423, 24.1334930062294, 47.206333726644516, 49.21283885836601, 56.324750036001205, 45.01019597053528, 113.53843197226524, 158.84134143590927, 29.84485823661089, 45.063514709472656, 77.01625093817711, 82.15331688523293, 77.26142898201942, 81.8835161626339, 64.60744678974152, 15.74007399380207, 0.44426607491914183, 0.12579214613651857, 0.06075109929952305, 0.1728117879247293, 0.12397006968967617, 0.13357760180952027, 0.09072582426597364, 0.06770832929760218, 0.07918856717878953, 0.03558351716492325, 0.1217262826685328, 0.34619651385582983, 0.582094743149355, 0.29369790747296065, 0.17255401035072282, 0.14659923588624224, 0.04255189422110561, 0.036112059897277504, 0.08593309394200332, 0.016893253377929796, 0.0351180718280375, 0.029450191686919425, 0.06594796243007295, 0.01618017748114653, 0.03559793338354211, 0.05179379615583457, 0.06294702150626108, 0.04552353515464347, 0.0326979245437542, 0.025887031224556267, 0.050118145445594564, 0.04128999826207291, 0.028164944051241037, 0.029628789525304455, 0.03967744494730141, 0.11895511808688752, 0.09694497726741247, 0.10972180651151575, 0.10899346278165467, 0.005367153553379467, 0.22046811820473522, 0.09404876822372898, 0.09704094438347965, 0.07079295479343273, 0.11991587278316729, 0.20321671734564006, 0.15997908980352804, 0.17488714453065768, 0.19623330066679046, 0.16393056605011225, 0.22000345954438671, 0.12335575695033185, 0.1354111370164901, 0.08057815706706606, 0.16074513463536277, 0.12401904401485808, 0.1631453589652665, 0.11872108923853375, 0.17326519562629983, 0.1370487452368252, 0.10601675297948532, 0.11162441340275109, 0.11511509015690535, 0.1461504295002669, 0.16454528697067872, 0.08602516478276812, 0.30112546985037625, 0.30952601751778275, 0.4460849007591605, 0.26383572549093515, 0.11573596348171122, 0.21048736001830548, 0.2941233658930287, 0.10761745419586077, 0.2231152105377987, 17.171240597963333, 114.94684159755707, 138.66313219070435, 122.6173759996891, 88.93276870250702, 90.58516323566437, 95.42111814022064, 60.68267539143562, 43.96810568869114, 91.85522228479385, 128.28944563865662, 101.37966200709343, 71.27641573548317, 58.78696471452713, 19.15488425642252, 1.082865537609905, 0.7374320109374821, 0.15409724292112514, 0.791972978040576, 0.23107973160222173, 0.1970894867554307, 0.20745449932292104, 1.794777880422771, 10.66885281354189, 16.532616466283798, 33.42365249991417, 73.28210771083832, 104.77216556668282, 124.5139530301094, 136.63992315530777, 135.38541287183762, 119.94050323963165, 119.47641134262085, 116.33449673652649, 109.32078748941422, 107.28869453072548, 104.59934324026108, 103.81488293409348, 108.54705020785332, 105.49545675516129, 107.54852458834648, 105.5575530230999, 120.82042962312698, 125.81802785396576, 76.3037283718586, 14.156603962182999, 9.325506146997213, 24.88837379962206, 7.627869816496968, 2.7367527969181538, 52.214301601052284, 107.50586047768593, 108.06256100535393, 113.67712453007698, 119.18444260954857, 121.1554728448391, 48.518087938427925, 5.84814696572721, 25.932183489203453, 87.85365700721741, 124.36872482299805, 118.94780650734901, 115.80898493528366, 112.58764699101448, 103.42171043157578, 108.12825947999954, 118.26353162527084, 115.73109671473503, 112.36798077821732, 120.49685418605804, 110.71969002485275, 110.30401512980461, 111.55423164367676, 136.73589080572128, 148.35715681314468, 77.04452902078629, 22.377033457159996, 28.6133861169219, 9.257094617933035, 3.5229857079684734, 0.4340983845759183, 0.18064732372295111, 0.314720279420726, 0.1947489904705435, 0.2643914456712082, 0.7597117591649294, 36.765930354595184, 62.212480902671814, 73.5633534193039, 86.53625249862671, 89.66634973883629, 194.30505126714706, 185.7204607129097, 57.68874004483223, 46.814171969890594, 64.8305556178093, 81.05224996805191, 81.1614029109478, 96.92056328058243, 81.98440834879875, 21.58517684787512, 0.703311919933185, 0.25900375039782375, 0.169029061216861, 0.39675093081314117, 0.26878659264184535, 0.12759428849676624, 0.2443675443646498, 0.21152981033083051, 0.2779435075353831, 0.08946504152845591, 0.2762385568348691, 0.3803533856989816, 0.6334322446491569, 0.4348522878717631, 0.261049970285967, 0.15644612547475845, 0.21006028371630237, 0.1285611733328551, 0.21189236431382596, 0.15902816114248708, 0.12468273926060647, 0.15296756057068706, 0.23368363094050437, 0.16833024012157694, 0.12969931616680697, 0.15020527207525447, 0.2020737060229294, 0.08171844470780343, 0.07411844431771897, 0.15418966999277472, 0.08435282405116595, 0.1881355937803164, 0.15355201670899987, 0.08640581232612021, 0.14955428981920704, 0.2829894289607182, 0.21660277561750263, 0.2502088254550472, 0.2806591149419546, 0.24494408920872957], [0.06534669664688408, 0.01980201770493295, 0.07234248492750339, 0.015483064253203338, 0.0031705629498901544, 0.03051855408557458, 0.07660721428692341, 0.011486179701023502, 0.09321519537479617, 0.07161327288486063, 0.10417702826089226, 0.055079744051909074, 0.08109179747407325, 0.10862765819183551, 0.014951206903788261, 0.015598183417750988, 0.13073205918772146, 0.06133135859272443, 0.06627144233789295, 0.08910170829039998, 0.08931212942115963, 0.08545972246793099, 0.0421599623223301, 0.03220315324142575, 0.06520799666759558, 0.13170103688025847, 0.14490431902231649, 0.15877397556323558, 0.04816790380573366, 0.03630024257290643, 0.04806906828889623, 0.05203421489568427, 0.13220057648140937, 0.014861916333757108, 12.194033022969961, 93.27687799930573, 95.6191711127758, 79.9711699783802, 68.1056834757328, 65.70358917117119, 43.03877055644989, 28.68928514420986, 54.965703561902046, 79.96092572808266, 81.30667671561241, 46.558932065963745, 36.10583737492561, 18.42069335281849, 1.3893610099330544, 0.6683985027484596, 0.1057805867458228, 0.30210985452868044, 0.1649635614012368, 0.2635399647988379, 0.046098087332211435, 0.29418635938782245, 0.817717012250796, 5.341204768046737, 14.421452600508928, 58.877924233675, 96.73618197441101, 107.91186109185219, 94.34054732322693, 100.00279068946838, 88.78092885017395, 92.81241372227669, 95.47734752297401, 97.73721545934677, 99.1215267777443, 100.92002347111702, 103.23549002408981, 115.1446133852005, 110.39885804057121, 114.36552599072456, 115.9966492652893, 109.43415820598602, 112.16389372944832, 108.78604218363762, 106.50804921984673, 121.64252310991287, 84.00843814015388, 19.944516085088253, 1.8060992541722953, 5.31238853931427, 50.11182501912117, 75.9211041033268, 85.83253785967827, 91.74272552132607, 90.34034997224808, 101.04302287101746, 103.31109076738358, 77.90193781256676, 67.92132496833801, 83.62151250243187, 107.75765016674995, 101.39213293790817, 112.89855390787125, 119.03548300266266, 118.88487428426743, 108.19664061069489, 97.15157568454742, 113.51054906845093, 120.26188999414444, 111.00354999303818, 120.49075171351433, 114.03740599751472, 106.42951503396034, 113.00693169236183, 105.0708295404911, 99.22815665602684, 111.34130626916885, 107.08330035209656, 105.91242358088493, 97.92894557118416, 80.46122968196869, 34.96103100478649, 0.4883710801368579, 0.041792317206272855, 0.035081216774415225, 0.08317269050166942, 0.041506939160171896, 0.5944374902173877, 3.647273238748312, 20.858040265738964, 45.83689860999584, 55.58807976543903, 43.476005494594574, 25.65183263272047, 47.08840325474739, 39.41695310175419, 23.497207649052143, 47.14420706033707, 61.078481152653694, 54.37299616634846, 59.59250248968601, 50.55985137820244, 17.704089805483818, 1.236350939143449, 0.10907713993219659, 0.13145275879651308, 0.3282346995547414, 0.10540756848058663, 0.035819957993226126, 0.20291607332183048, 0.11649498759652488, 0.1846903216210194, 0.17985846527153626, 0.35189047863241285, 0.5470378836616874, 0.271260705194436, 0.12538644368760288, 0.2461009193211794, 0.15478846442420036, 0.04666491746320389, 0.012063112317264313, 0.09111988241784275, 0.07289316592505202, 0.07465459406375885, 0.025059710969799198, 0.08854517174768262, 0.04626188674592413, 0.06251400060136802, 0.09882172031211667, 0.006317249153653393, 0.053027616668259725, 0.04090463808097411, 0.021900284409639426, 0.02622780873934971, 0.03374989661097061, 0.02095404426654568, 0.03226990200346336, 0.16247102874331176, 0.04698983713751659, 0.05880416763829999, 0.07017987401923165, 0.00963797223448637, 0.0789381517097354, 0.04494235930906143, 0.040114161747624166, 0.011076670034526614, 0.03870497544994578, 0.07113486222806387, 0.05733871541451663, 0.02952545659354655, 0.049845632529468276, 0.03064613298192853, 0.033283115408266895, 0.06777743066777475, 0.05861110534169711, 0.017840090949903242, 0.017605449829716235, 0.06476550595834851, 0.0710032126517035, 0.04162074750638567, 0.07124243653379381, 0.06306232156930491, 0.05913337321544532, 0.04334524637670256, 0.0615344918332994, 0.06014542144839652, 0.019468561476969626, 0.26802235865034163, 0.24996682594064623, 0.4023835645057261, 0.014206029409251641, 0.06022669775120448, 0.04126201558392495, 0.0974494002002757, 0.18704248446738347, 0.08763060832279734, 23.923050798475742, 117.6298776268959, 112.11580350995064, 97.70442321896553, 96.6110622882843, 108.18416208028793, 70.18725737929344, 36.34286865592003, 27.71731059998274, 43.445531129837036, 65.7254607975483, 51.38714678585529, 45.35220801830292, 22.37582702189684, 1.462170802988112, 0.8117389236576855, 0.2542329876450822, 0.2406193275237456, 0.4085509304422885, 0.8321893075481057, 0.19628790789283812, 0.21994448849000037, 0.5526327865663916, 1.0661470284685493, 17.7347294613719, 65.83424896001816, 103.32218617200851, 112.24337786436081, 101.07583791017532, 104.57750961184502, 94.5836278796196, 100.7912939786911, 102.71438598632812, 104.17581796646118, 107.40581944584846, 106.37110456824303, 109.86602783203125, 117.72344380617142, 114.04588714241982, 115.23583889007568, 117.10292190313339, 113.87320160865784, 117.0520806312561, 115.64255386590958, 112.19134345650673, 123.79691630601883, 94.56726595759392, 29.47401523590088, 5.207858523353934, 10.249999389052391, 63.39355252683163, 91.93300411105156, 94.81899484992027, 99.9244312942028, 95.94326332211494, 103.65872651338577, 109.47314411401749, 98.95220786333084, 83.06584551930428, 92.67524108290672, 111.11990734934807, 106.86360374093056, 117.36576899886131, 120.96447989344597, 121.92161813378334, 112.02141657471657, 97.1950301527977, 114.43379312753677, 123.219955265522, 115.1835384964943, 122.78238594532013, 119.65716764330864, 111.74417585134506, 119.7330267727375, 114.18182864785194, 104.91854131221771, 114.60432797670364, 117.06182330846786, 116.72060921788216, 112.21921876072884, 93.71068552136421, 50.42110562324524, 2.610895000398159, 0.18402645568130538, 0.02996816623635823, 0.07890534136095084, 0.057370935755898245, 1.0240108519792557, 2.87432465236634, 26.4759761095047, 54.112729132175446, 61.47324576973915, 48.46539996564388, 37.81787730753422, 36.17334455251694, 30.502916425466537, 38.52046720683575, 73.3975987136364, 87.74334132671356, 76.74334198236465, 74.64773163199425, 74.11112442612648, 32.37473778426647, 1.41493268776685, 0.1018784633197356, 0.07911959197372198, 0.4235722072189674, 0.1676794805098325, 0.01371364318401902, 0.11077782328356989, 0.20601698895916343, 0.22980328212724999, 0.22165812231833115, 0.44176726369187236, 0.6163797690533102, 0.3738398524001241, 0.15214441489661112, 0.5804773955605924, 0.20207168738124892, 0.05991853206069209, 0.011746657764888369, 0.04796784676727839, 0.04829688536119647, 0.014399770770978648, 0.04843733309826348, 0.06281095615122467, 0.07747415409539826, 0.08050753429415636, 0.007284453113243217, 0.0581406282435637, 0.06941774030565284, 0.04269516954082064, 0.018049903519568034, 0.048045119183370844, 0.16639969137031585, 0.03777637430175673, 0.13154886692063883, 0.15940509794745594, 0.06460066753788851, 0.0362163019599393, 0.07914960442576557, 0.03581235469027888, 0.2909269358497113, 0.1119424459466245, 0.2111413553939201, 0.13591636146884412, 0.1232734824588988, 0.11636298178927973, 0.11552887459401973, 0.10674066608771682, 0.27018358174245805, 0.12290580023545772, 0.15588602662319317, 0.2351530981832184, 0.19670944777317345, 0.2133057697210461, 0.09262411927920766, 0.09781274828128517, 0.3240411198930815, 0.195859020750504, 0.16390285425586626, 0.2553780027665198, 0.2788380329729989, 0.11438911387813278, 0.1392344295163639, 0.13809751864755526, 0.09520657797111198, 0.4181193810654804, 0.35765767854172736, 0.3964177658781409, 0.19003250839887187, 0.21554377541178837, 0.14957443170715123, 0.22570670116692781, 0.32591928786132485, 0.12997517245821655, 37.27414548397064, 141.97193384170532, 122.89865970611572, 108.13375398516655, 98.0486087501049, 92.82323554158211, 54.95156072080135, 39.07371371984482, 80.48212096095085, 132.06966519355774, 114.48917895555496, 70.86126521229744, 58.426322266459465, 30.658622570335865, 3.45584022346884, 1.3292571413330734, 0.4437010927358642, 0.6930587638635188, 0.544537320965901, 0.4451096593402326, 0.21214231965132058, 0.596674857661128, 5.627147499471903, 19.125382639467716, 22.60780457407236, 65.50374269485474, 108.02568018436432, 123.10802847146988, 108.66981402039528, 112.60505005717278, 100.06182432174683, 104.93236497044563, 106.70762971043587, 106.21266067028046, 109.87093716859818, 108.95759537816048, 113.13761427998543, 123.78870874643326, 120.36172583699226, 122.00606480240822, 121.97214782238007, 117.08103507757187, 121.78861007094383, 118.399837911129, 116.78474217653275, 126.98489964008331, 97.77791887521744, 29.13941279053688, 5.169120552018285, 7.867546230554581, 77.04832121729851, 106.91867038607597, 97.2017253935337, 106.07374772429466, 100.42390689253807, 109.50095862150192, 110.47853976488113, 120.96532344818115, 95.0942824780941, 101.04898855090141, 119.00976598262787, 114.89883497357368, 121.91942185163498, 129.22252357006073, 129.69330310821533, 120.38018524646759, 104.14270654320717, 121.57856494188309, 128.2707354426384, 122.12033227086067, 129.8854511976242, 128.65024387836456, 120.81245765089989, 126.55342519283295, 118.92921790480614, 109.37048882246017, 125.54128110408783, 126.16138502955437, 121.75203323364258, 109.8303933441639, 86.77888467907906, 42.6778469234705, 1.7234735190868378, 0.2561930293450132, 0.1623287590336986, 0.1733455405337736, 0.254568230593577, 1.2663005758076906, 5.7103136368095875, 38.46161976456642, 71.59817487001419, 80.15991345047951, 66.06650769710541, 42.761651426553726, 59.92324434220791, 56.08788214623928, 34.9069295078516, 66.026032269001, 87.8018581867218, 80.06143793463707, 89.10466387867928, 94.17714089155197, 43.864230662584305, 2.171109924092889, 0.17633032490266487, 0.23736558883683756, 0.5622754816431552, 0.28076631075236946, 0.11018230172339827, 0.322252128389664, 0.26468780008144677, 0.3487085649976507, 0.3733346576336771, 0.41866684856358916, 0.723904618062079, 0.4299155215267092, 0.32531126111280173, 0.6567707110662013, 0.2807948092231527, 0.1488267772947438, 0.15762700117193162, 0.15881078608799726, 0.19993106630863622, 0.17157154041342437, 0.1344892114866525, 0.17882671672850847, 0.17690073960693553, 0.14148196438327432, 0.20731760276248679, 0.17059859965229407, 0.1369445922318846, 0.21237271197605878, 0.1306959759676829, 0.18165205809054896, 0.22121044399682432, 0.1269117501215078, 0.19789295067312196, 0.2154582948423922, 0.14164526655804366, 0.16790380206657574, 0.2789751224918291, 0.15376058989204466], [0.0344114433391951, 0.1417627336923033, 0.06047517621482257, 0.08564491799916141, 0.05601249751634896, 0.09427041804883629, 0.054942439310252666, 0.09734261999255978, 0.05232716655882541, 0.042531310755293816, 0.06935866535059176, 0.03596147813368589, 0.033328353019896895, 0.01133069234128925, 0.05338464536180254, 0.06110939706559293, 0.12427093635778874, 0.06351187010295689, 0.03300141099316534, 0.05269569483061787, 0.09570926427841187, 0.060483239649329334, 0.009157239583146293, 0.004214172868159949, 0.0726668257266283, 0.10591179845505394, 0.17271839606110007, 0.14426342997467145, 0.05044110585004091, 0.10005047195591033, 0.07754033140372485, 0.12054916966008022, 0.43240842525847256, 31.261695809662342, 101.117232888937, 93.65704759955406, 73.23240637779236, 80.90003773570061, 55.07076792418957, 23.81553176790476, 47.047589644789696, 71.35952487587929, 73.62199187278748, 62.86607623100281, 39.84170950949192, 34.938361421227455, 10.606578905135393, 0.13119481795001775, 0.23436177580151707, 0.0863135485269595, 0.15931984002236277, 0.38416143448557705, 0.09961216695955954, 0.1067188469460234, 0.11524414963787422, 2.7938950806856155, 4.105199966579676, 20.69701250642538, 66.00885719060898, 96.34607970714569, 95.33741623163223, 95.10068893432617, 100.42328372597694, 101.07056379318237, 101.95359840989113, 100.79312548041344, 100.78283563256264, 97.46033191680908, 95.99552571773529, 96.26832067966461, 105.74365943670273, 96.77718937397003, 105.13196066021919, 102.87365064024925, 102.86827772855759, 101.10818937420845, 102.2248050570488, 109.53226894140244, 111.74684330821037, 104.60498973727226, 110.45349910855293, 74.40778970718384, 31.253758035600185, 67.41851314902306, 58.0836870521307, 84.17157858610153, 103.90603244304657, 97.83321350812912, 101.71108782291412, 100.317003428936, 116.65236487984657, 95.9592604637146, 71.44230723381042, 99.03889641165733, 102.59446442127228, 107.05857127904892, 102.88294494152069, 110.43738797307014, 106.8191385269165, 100.9812381863594, 88.98605704307556, 95.07784456014633, 114.41296264529228, 113.42213541269302, 115.35500809550285, 110.61272576451302, 107.78611823916435, 83.41857299208641, 106.37890934944153, 113.01602840423584, 102.48570665717125, 96.90418615937233, 95.50288215279579, 99.24720883369446, 110.10079443454742, 123.67494285106659, 88.72105166316032, 3.0996831972151995, 0.12472824775613844, 0.030270057068264578, 0.19269569049356505, 0.13388744846452028, 0.36657496879342943, 0.11841055238619447, 5.629577469080687, 28.446309082210064, 57.63557709753513, 61.16914428770542, 47.9225192964077, 53.96924503147602, 50.7529304176569, 26.739472970366478, 39.55259062349796, 52.54333354532719, 58.04675683379173, 56.74735575914383, 57.46193401515484, 28.352522514760494, 1.7392817395739257, 0.4189914936432615, 0.03805471678788308, 0.04187349331914447, 0.1874415372731164, 0.008002136819413863, 0.13777947868220508, 0.19920460763387382, 0.2634640579344705, 0.22443948400905356, 0.1568929132190533, 0.33409214462153614, 0.3586469020228833, 0.3178042295621708, 0.066759218898369, 0.0589783645409625, 0.05702398542780429, 0.030514145728375297, 0.07631835556821898, 0.0445244707952952, 0.046812738437438384, 0.053387265143101104, 0.10153942057513632, 0.044349813761073165, 0.10251201994833536, 0.04244956318871118, 0.11070029853726737, 0.05547905289859045, 0.03339644506922923, 0.027401290790294297, 0.04175203343038447, 0.11119208269519731, 0.11011844733729959, 0.06695579897495918, 0.02702246707485756, 0.07271769252838567, 0.07338214476476423, 0.03463944223767612, 0.11166786614921875, 0.018994998899870552, 0.07624259713338688, 0.09457567080971785, 0.119262025837088, 0.07051459746435285, 0.07660838688025251, 0.007621451704835636, 0.02345450862776488, 0.01575276535731973, 0.10573985025985166, 0.056337153728236444, 0.048569023492746055, 0.13966349477414042, 0.08423535691690631, 0.07999177876627073, 0.06941356201423332, 0.05985677424177993, 0.03252650327340234, 0.05960606191365514, 0.05253824820101727, 0.06617048056796193, 0.06609922696952708, 0.0652901895227842, 0.09946351477992721, 0.14043215196579695, 0.17320178652880713, 0.277338182204403, 0.09765651877387427, 0.22151889541419223, 0.13813477446092293, 0.026066816499223933, 0.5052711779717356, 46.299250200390816, 123.07027369737625, 106.91544815897942, 101.1843752861023, 107.31415316462517, 93.92826944589615, 40.20734488964081, 29.738247357308865, 27.615500763058662, 59.65658985078335, 66.23175323009491, 49.46684002876282, 47.23601773381233, 14.965943433344364, 0.05688151533831842, 0.38189070008229464, 0.14417947822948918, 0.10283627911121584, 0.9112257196102291, 0.09964713695808314, 0.17642160906689242, 0.4541618126677349, 1.867402670904994, 2.6214510714635253, 26.626698821783066, 75.04756897687912, 104.51154515147209, 105.48685401678085, 103.94159853458405, 107.77442246675491, 107.7156700193882, 107.41004481911659, 104.61648792028427, 101.02280035614967, 100.09586289525032, 100.29609695076942, 100.6062363088131, 111.5837712585926, 101.74666151404381, 107.97691360116005, 107.81137928366661, 106.16629555821419, 104.46365252137184, 104.2251393198967, 110.34196749329567, 118.57475772500038, 110.44358164072037, 113.34778860211372, 82.88978576660156, 43.45595397055149, 80.83148941397667, 67.7731329202652, 93.46256643533707, 111.05937659740448, 104.63963627815247, 107.57622510194778, 109.47937577962875, 121.5898123383522, 99.62806239724159, 80.39130583405495, 104.00608867406845, 106.98836624622345, 108.91133666038513, 106.89707234501839, 112.50832244753838, 113.5116358101368, 109.28198397159576, 97.92320787906647, 102.31516420841217, 121.91476330161095, 116.00501641631126, 121.29940152168274, 120.85822999477386, 112.43320807814598, 88.24492201209068, 106.97645768523216, 120.7469491660595, 113.421261459589, 105.16285300254822, 100.62447533011436, 100.83867743611336, 112.32348516583443, 125.78947618603706, 108.444394916296, 7.019583256915212, 0.08887432908522896, 0.07816016572178341, 0.412575775408186, 0.21143686375580728, 0.2576696657342836, 0.37252960551995784, 6.627695085480809, 34.23557013273239, 65.93425199389458, 63.63014683127403, 50.56216545403004, 42.70311936736107, 35.241296365857124, 37.01355166733265, 66.458221077919, 81.85330778360367, 86.19745507836342, 72.63656035065651, 78.76719698309898, 50.51055662333965, 3.87992596719414, 0.4032750322949141, 0.09939606839907356, 0.0476295350381406, 0.18023320531938225, 0.05005827268178109, 0.25846391217783093, 0.21842017653398216, 0.37621107359882444, 0.3061305434675887, 0.3556439053500071, 0.41789608367253095, 0.4012738459277898, 0.3374554688343778, 0.03388388024177402, 0.042050476986332797, 0.05838816789037082, 0.06065544759621844, 0.03492039337288588, 0.07506193665903993, 0.08861038426402956, 0.06687030356260948, 0.04733270936412737, 0.04074808573932387, 0.03584641555789858, 0.021909991701249965, 0.06205531251907814, 0.03189696908521, 0.04562969937978778, 0.022044663674023468, 0.05064793869678397, 0.17970636952668428, 0.09246528483345173, 0.013915788440499455, 0.025557860899425577, 0.12558875314425677, 0.05840803147293627, 0.06407037333701737, 0.3517986898077652, 0.2585099550196901, 0.1975274132564664, 0.18080440670019016, 0.2307128137908876, 0.13902909209718928, 0.28048200882039964, 0.1961396267870441, 0.13773705752100796, 0.08444013772532344, 0.24948297534137964, 0.1841834347578697, 0.17060824757209048, 0.19858969375491142, 0.15854920871788636, 0.18846650258637965, 0.23199070303235203, 0.2045624834136106, 0.0925150458351709, 0.12212400702992454, 0.19112022971967235, 0.14494981267489493, 0.1528064996819012, 0.1752802453120239, 0.2411185554228723, 0.2329926469246857, 0.37950531870592386, 0.5341491533908993, 0.1889359109918587, 0.26768393930979073, 0.2087787727941759, 0.2520771377021447, 0.6515230739023536, 66.40654385089874, 144.9780437350273, 118.844725638628, 105.671007335186, 112.1299235522747, 75.49190193414688, 33.899622559547424, 70.82711264491081, 107.84656539559364, 111.99904337525368, 84.40362453460693, 67.23240673542023, 61.43085904419422, 23.132146038115025, 0.5225718871224672, 0.5097758362535387, 0.28634515358135104, 0.5053306091576815, 0.5453203164506704, 0.1393934420775622, 0.3919356985716149, 2.7782256714999676, 8.33727702498436, 11.702087670564651, 27.181480452418327, 76.89258277416229, 111.53074890375137, 111.76072776317596, 109.4668136537075, 112.39756599068642, 113.98906499147415, 111.44431114196777, 110.38929015398026, 109.93662804365158, 107.91335821151733, 105.63779711723328, 102.94067144393921, 114.10151615738869, 104.98816877603531, 111.4477689564228, 110.6284873187542, 109.43869516253471, 106.72733545303345, 107.30238899588585, 115.16852930188179, 122.02929675579071, 115.00814750790596, 115.7053492963314, 86.00101321935654, 47.754321321845055, 86.6298034787178, 87.75276482105255, 95.80607548356056, 122.26243704557419, 112.44871124625206, 113.1346808373928, 119.16456207633018, 130.24459272623062, 103.67782428860664, 86.6213147342205, 108.04037779569626, 115.05048483610153, 116.6408059000969, 113.96187365055084, 121.57121613621712, 117.7607274055481, 112.89260342717171, 100.61930000782013, 106.8635505437851, 127.93370872735977, 120.15880912542343, 124.70976412296295, 122.84529536962509, 114.62210342288017, 91.23171374201775, 118.64634588360786, 127.46606782078743, 112.35807090997696, 104.19051557779312, 106.05460435152054, 111.9575648009777, 123.33959564566612, 138.61882656812668, 101.80164456367493, 5.20215455442667, 0.22125844610854983, 0.316957468749024, 0.48995111254043877, 0.6104076176416129, 0.6275845959316939, 0.5023421288933605, 12.209203708916903, 47.87048488855362, 81.33364766836166, 91.89322024583817, 71.52764305472374, 76.47887617349625, 70.6733500957489, 40.382481291890144, 52.7020738273859, 74.53027993440628, 87.43214562535286, 79.90056216716766, 98.62504541873932, 68.96863237023354, 5.872796718031168, 0.7052656088490039, 0.25746726721990854, 0.15123656048672274, 0.2518380177207291, 0.1915434468537569, 0.3008175973081961, 0.2885077422251925, 0.4018401639768854, 0.3579843125771731, 0.41105517419055104, 0.4495221725665033, 0.4836074123159051, 0.49378985655494034, 0.08696990393218584, 0.14959335647290573, 0.25583317677956074, 0.194180223334115, 0.12590628844918683, 0.14717267855303362, 0.16966764960670844, 0.24247811059467494, 0.16766583983553573, 0.13692514796275645, 0.15557381993858144, 0.12074274403857999, 0.1277239268529229, 0.2660379745066166, 0.14024709002114832, 0.11040479759685695, 0.12631123390747234, 0.23769890220137313, 0.15916066418867558, 0.1501442230073735, 0.12956739199580625, 0.265298587619327, 0.2479250292526558, 0.1537755219032988], [0.04824947696761228, 0.008054806112340884, 0.03956167733122129, 0.027796374961326364, 0.08267732919193804, 0.0476121613610303, 0.09122900039074011, 0.01947525750438217, 0.025672741649032105, 0.0462240260822, 0.12203497157315724, 0.03212394753063563, 0.02580136697361013, 0.004564492546705878, 0.011952520253544208, 0.025094974116655067, 0.01797225446352968, 0.019000796928594355, 0.026049119987874292, 0.026710286365414504, 0.10006863230955787, 0.06418435979867354, 0.0519463891396299, 0.007441006382578053, 0.03558360993338283, 0.13888233981560916, 0.10438741228426807, 0.08438060263870284, 0.11921291792532429, 0.07764426176436245, 0.08132316201226786, 0.1764307523262687, 26.926692724227905, 115.56841224431992, 84.84698474407196, 82.23979264497757, 70.72734519839287, 59.33203786611557, 29.496599324047565, 63.49906526505947, 73.32712769508362, 83.33646699786186, 74.4345934689045, 41.417207568883896, 27.47412744909525, 3.789180899038911, 0.8035045873839408, 0.23141965008107945, 0.05334518908057362, 0.3482275939313695, 0.2663196640787646, 0.43387345445808023, 0.2097032661549747, 2.0757001312449574, 5.034196441993117, 4.432277865707874, 53.67916859686375, 100.73213875293732, 97.65632539987564, 102.04952046275139, 108.05892840027809, 99.99204486608505, 96.20119348168373, 89.89311397075653, 86.64460748434067, 89.42495629191399, 94.14840683341026, 96.21163532137871, 103.33904966711998, 106.6898162662983, 111.38501912355423, 101.15881785750389, 99.30136352777481, 117.68789291381836, 108.72755572199821, 107.05502226948738, 101.83865457773209, 96.03980094194412, 98.26585069298744, 104.08789068460464, 101.4230328798294, 98.36513936519623, 54.88245002925396, 62.28914938867092, 80.27720555663109, 98.71476620435715, 88.69104847311974, 89.89461869001389, 86.64830848574638, 86.16068825125694, 102.08270788192749, 99.54939901828766, 91.6147255897522, 103.24763417243958, 96.93493410944939, 92.32394233345985, 98.52863699197769, 115.34683093428612, 114.18019473552704, 110.36919683218002, 100.75310602784157, 89.39217165112495, 108.69039371609688, 113.99468868970871, 122.05311387777328, 116.80070132017136, 115.06687715649605, 103.41235533356667, 84.25346419215202, 100.00002443790436, 111.16321742534637, 109.84364703297615, 103.03098499774933, 99.62986350059509, 89.8073297739029, 89.80204805731773, 112.79839128255844, 97.37791433930397, 1.985814766958356, 0.08551391409127973, 0.1379066679510288, 0.1773505998426117, 0.12203449659864418, 0.07972128078108653, 0.3564928629202768, 1.042325987946242, 10.998013000935316, 39.75311726331711, 76.51947319507599, 58.62952396273613, 50.9648222476244, 45.3148028254509, 23.49095318466425, 30.986822359263897, 35.56097321212292, 51.949809193611145, 51.67608708143234, 54.61655169725418, 42.69561097025871, 4.977858765050769, 0.3848657920025289, 0.2524512098170817, 0.07378617738140747, 0.08276658729300834, 0.03813371469732374, 0.24246616201708093, 0.21019341016653925, 0.21315260528353974, 0.38235801563132554, 0.38153574569150805, 0.07893588815932162, 0.0854714038723614, 0.028204695336171426, 0.027345627859176602, 0.059881587949348614, 0.02184498698625248, 0.05770900628704112, 0.036110931832809, 0.040757525857770815, 0.11075069778598845, 0.08773644600296393, 0.02174429795559263, 0.03010205338796368, 0.05245997759629972, 0.0651243566244375, 0.04330429837864358, 0.02118239939591149, 0.010372883043601178, 0.019961455145676155, 0.08435693554929458, 0.04398923018015921, 0.06380968654411845, 0.08042773115448654, 0.05915056506637484, 0.02465435361955315, 0.019097368895018008, 0.028857082106696907, 0.012849814829678508, 0.030414774009841494, 0.014035952353879111, 0.041184995498042554, 0.0521905037749093, 0.049928808730328456, 0.009452956674067536, 0.01452672348023043, 0.07860497193178162, 0.07314859831240028, 0.03514213225571439, 0.06722102029016241, 0.02470865842042258, 0.028129168822488282, 0.024833827192196622, 0.028182605310576037, 0.046996661185403354, 0.019866944494424388, 0.06865353600005619, 0.034522234855103306, 0.07117608111002482, 0.1366463230806403, 0.027640958105621394, 0.08017699656193145, 0.14884166477713734, 0.17381793237291276, 0.07114237276255153, 0.17234932602150366, 0.05818444464239292, 0.09228235285263509, 0.14865819102851674, 42.617441564798355, 132.53821045160294, 99.88449543714523, 105.00586062669754, 102.22217559814453, 101.47955104708672, 44.25969444215298, 35.470416471362114, 46.352785527706146, 80.99257797002792, 80.0159315764904, 52.698312029242516, 35.684155002236366, 4.066260606050491, 0.8912980451714247, 0.24796313111437485, 0.14769604109460488, 0.4958572721807286, 0.3701397415716201, 0.13898762088501826, 0.13038449658779427, 0.21788988233311102, 0.9688975405879319, 7.908039707690477, 64.83062401413918, 112.73831650614738, 106.26137405633926, 109.16210800409317, 111.72471329569817, 103.85250851511955, 100.99139884114265, 96.65379479527473, 90.69179311394691, 92.80123472213745, 99.16368931531906, 99.60737630724907, 107.06902831792831, 114.16637107729912, 111.27515181899071, 106.06234073638916, 100.98234012722969, 117.02250301837921, 111.24340072274208, 108.99687767028809, 103.30968484282494, 101.19689181447029, 103.61812949180603, 106.45688116550446, 107.51067861914635, 104.0182176232338, 62.179183289408684, 69.88166257739067, 93.0955745279789, 104.31042194366455, 97.33809247612953, 97.5340023636818, 95.13837531208992, 96.70451447367668, 109.43218231201172, 104.6446444094181, 100.31964048743248, 109.87058758735657, 101.76471814513206, 96.15706264972687, 100.16447961330414, 118.0161041021347, 118.06856408715248, 115.40455743670464, 103.75594809651375, 92.75854781270027, 108.89392599463463, 118.7749157845974, 121.85088872909546, 122.27742344141006, 121.16078495979309, 110.3459420800209, 89.19840484857559, 100.98679348826408, 114.57669585943222, 115.69118365645409, 109.61530968546867, 107.1642892062664, 96.45097687840462, 94.86521556973457, 113.8059376180172, 112.31940418481827, 4.9497421737760305, 0.11670157924527302, 0.36422369652427733, 0.32642955891788006, 0.06779740186175331, 0.04477839662285987, 0.30169846722856164, 0.7509836868848652, 11.801397241652012, 46.67307034134865, 69.84562531113625, 52.431695535779, 46.072170585393906, 22.80450101941824, 20.793776214122772, 53.55545483529568, 62.36069194972515, 85.51439613103867, 72.53703609108925, 69.83673378825188, 65.49526154994965, 11.015502512454987, 0.11557529593119398, 0.3349534812150523, 0.04227440520480741, 0.02769740214716876, 0.06262937487917952, 0.22230350878089666, 0.15323373925639316, 0.3487691836198792, 0.2543394413078204, 0.3054787003202364, 0.12071644232491963, 0.145752964890562, 0.026423208801134024, 0.017262677793041803, 0.07716500505921431, 0.04310178483137861, 0.047490898141404614, 0.09169213022687472, 0.003010264153999742, 0.07444870745530352, 0.050915746396640316, 0.0652344171248842, 0.027000191512343008, 0.04755025511258282, 0.04619817707862239, 0.03870694956276566, 0.06971437673200853, 0.05181013824767433, 0.01176826910523232, 0.05255039344774559, 0.020128071009821724, 0.007328165611397708, 0.10543706142925657, 0.04527321245404892, 0.046346732779056765, 0.02606279776955489, 0.10224955942248926, 0.10984438704326749, 0.14777607430005446, 0.11848814392578788, 0.18089515651809052, 0.18810803041560575, 0.1302248754655011, 0.12334170067333616, 0.15317022625822574, 0.18393264821497723, 0.1865813139011152, 0.1299437796114944, 0.11885159590747207, 0.12846325436839834, 0.1385808052145876, 0.1731324996217154, 0.0850377521419432, 0.12394156379741617, 0.11373235771316104, 0.18230409419629723, 0.28880703554023057, 0.14215184171916917, 0.2188223908888176, 0.08657099955598824, 0.21795820444822311, 0.3235242882510647, 0.2898840402485803, 0.1785328410915099, 0.2939772221725434, 0.23619614221388474, 0.22069009457482025, 0.16153535863850266, 65.97228035330772, 156.22177720069885, 110.22490337491035, 115.78900560736656, 98.2737086713314, 80.3013950586319, 49.036843702197075, 98.63623961806297, 110.13098001480103, 114.64691609144211, 94.55711290240288, 67.6132982969284, 48.15729349851608, 7.416499508544803, 1.5228042681701481, 0.3208021499449387, 0.4739267489640042, 0.9170901111792773, 0.5479868233669549, 0.5376259074546397, 1.1400044965557754, 5.433931667357683, 12.449891343712807, 5.934835039079189, 62.35484026372433, 121.45735144615173, 114.37745735049248, 115.09206220507622, 116.99961304664612, 108.75624418258667, 106.45399332046509, 101.32945910096169, 97.73628070950508, 98.5006932914257, 104.66561168432236, 102.10176005959511, 108.07353481650352, 117.88381800055504, 114.84024971723557, 109.5240005850792, 108.0702593922615, 120.81245765089989, 116.68007299304008, 114.94909107685089, 109.70661118626595, 104.62521225214005, 110.89321911334991, 115.6579202413559, 115.25828808546066, 105.66161423921585, 72.38515064120293, 84.78353574872017, 100.0157555937767, 113.84488552808762, 106.10968619585037, 105.43200016021729, 105.84295570850372, 106.45217701792717, 117.38165214657784, 113.09723004698753, 102.78113320469856, 118.06835889816284, 108.21204498410225, 102.0018558204174, 107.59389415383339, 125.49051582813263, 119.26679939031601, 120.81867411732674, 108.96726205945015, 97.85747900605202, 115.38267061114311, 124.9199840426445, 126.96748897433281, 127.81234323978424, 129.69248235225677, 116.13443747162819, 94.34664219617844, 108.19971084594727, 122.74367362260818, 122.57572263479233, 114.0196381509304, 110.97477033734322, 99.8055812716484, 100.19825980067253, 126.33048355579376, 111.38523951172829, 3.3497743774205446, 0.17999644536757842, 0.2930009417468682, 0.5684404133353382, 0.3994181798771024, 0.21332456090021878, 0.7511137705296278, 2.6179778203368187, 22.51314215362072, 58.42039078474045, 100.8259329199791, 82.09597796201706, 80.37921488285065, 63.35706688463688, 34.15968060493469, 44.65004749596119, 47.86646470427513, 79.73616778850555, 73.53839635848999, 84.28639322519302, 80.79656928777695, 14.894597511738539, 0.4746113653527573, 0.41053391934838146, 0.1538659748621285, 0.20914088148856536, 0.21892805787501857, 0.27644220215734094, 0.392565781949088, 0.4512574919499457, 0.500546843977645, 0.5118901852983981, 0.2257185903727077, 0.19525534298736602, 0.2044931668206118, 0.14988184411777183, 0.188567612785846, 0.13288209069287404, 0.148256748507265, 0.22984337294474244, 0.1002634312317241, 0.21889391908189282, 0.11393667096854188, 0.14277940179454163, 0.1254377854638733, 0.21854654944036156, 0.15527264156844467, 0.15144440636504441, 0.17764207092113793, 0.19412539346376434, 0.0953487289370969, 0.17005712870741263, 0.0684697060205508, 0.13343027065275237, 0.18790980277117342, 0.15200137335341424, 0.06307752075372264, 0.09500859523541294], [0.08394245349336416, 0.05391807513660751, 0.02734724203037331, 0.05266075080726296, 0.08033027974306606, 0.03171338030369952, 0.008423574654443655, 0.014220132998161716, 0.027786333703261334, 0.08243000105721876, 0.03295747213996947, 0.08283841976663098, 0.06488660219474696, 0.01380161087581655, 0.03470191251835786, 0.09373913679155521, 0.03156103593937587, 0.10564841024461202, 0.10680204912205227, 0.051001011743210256, 0.05400905502028763, 0.05675582891853992, 0.0910522356571164, 0.018490069451218005, 0.09137151500908658, 0.08490545689710416, 0.06613385558011942, 0.13123542827088386, 0.13711736421100795, 0.24414059560513124, 0.24279488890897483, 28.31282414495945, 97.97831252217293, 83.61795589327812, 71.8994303047657, 60.9031205624342, 53.30444410443306, 24.468775615096092, 61.336114928126335, 54.63078573346138, 78.33077520132065, 72.89221063256264, 39.21399839222431, 16.762238144874573, 0.27767027844674885, 0.4399628652026877, 0.21063270221929997, 0.0783750471600797, 0.08993562252726406, 0.17585483088623732, 0.10660057087079622, 3.0463459342718124, 1.5825327881611884, 4.1012586280703545, 47.34593443572521, 113.60546797513962, 113.16697150468826, 98.67799937725067, 100.97067475318909, 103.40470254421234, 98.11692908406258, 89.02577251195908, 87.03701242804527, 88.1146802008152, 91.48718923330307, 93.09407740831375, 96.03879019618034, 101.25841811299324, 106.43491074442863, 106.07218980789185, 100.08077010512352, 100.65162867307663, 92.42265343666077, 103.38729947805405, 104.6123081445694, 97.51413702964783, 94.66986805200577, 96.12589672207832, 94.81415390968323, 97.72236585617065, 94.20320749282837, 104.2029257118702, 78.79340797662735, 51.39677166938782, 96.17473170161247, 93.17641898989677, 91.81913182139397, 86.60262733697891, 91.12199082970619, 96.02543011307716, 97.45781645178795, 81.61795601248741, 91.22382536530495, 103.97297725081444, 94.74524080753326, 91.8027850985527, 97.10676088929176, 99.76494625210762, 115.55850997567177, 110.60974672436714, 99.57422688603401, 86.76651254296303, 89.7527951002121, 108.0158007144928, 113.8418760895729, 106.78598910570145, 108.62889781594276, 110.37703961133957, 89.3411023914814, 87.03004360198975, 91.31338655948639, 86.4503163099289, 88.00052672624588, 86.81370601058006, 83.14057230949402, 100.56084394454956, 89.6385808289051, 104.33011248707771, 90.68485468626022, 2.091955184005201, 0.32885145395994186, 0.2244464453542605, 0.10372664110036567, 0.041666278266347945, 0.20701537054264918, 0.12900340429041535, 0.047709787177154794, 3.585591623559594, 28.107118383049965, 58.131800070405006, 46.52414493262768, 52.50799544155598, 73.80410850048065, 29.323060736060143, 22.076642476022243, 23.033594526350498, 47.595345452427864, 47.334455251693726, 50.56721158325672, 53.710767701268196, 23.30385882407427, 1.0016422835178673, 0.09709875026601367, 0.01566447946970584, 0.16575136600295082, 0.052265831764088944, 0.18828258354915306, 0.17463104421040043, 0.12244558703969233, 0.07070980456774123, 0.06405386797268875, 0.04797050736669917, 0.10640577937010676, 0.03149380107061006, 0.05201571686484385, 0.1034860145591665, 0.010817447127919877, 0.10561512492131442, 0.0763882436149288, 0.029095328209223226, 0.008860060461302055, 0.03820964753685985, 0.011867778121086303, 0.0844391284044832, 0.01640199428948108, 0.059899009866057895, 0.01402639813022688, 0.0342701977933757, 0.020437559578567743, 0.044812709820689633, 0.04714543953014072, 0.05099518588394858, 0.03707956442667637, 0.05031069194956217, 0.09258192076231353, 0.059838176021003164, 0.014354896811710205, 0.03082927276409464, 0.028584780702658463, 0.0261736542233848, 0.0482544753322145, 0.04380912578199059, 0.00529522413671657, 0.06591825425857678, 0.03296582872280851, 0.04871635836025234, 0.03393720355234109, 0.1236849365523085, 0.03382130977115594, 0.045773735400871374, 0.055204153977683745, 0.01717329167149728, 0.028791619115509093, 0.03782176034292206, 0.05306591890985146, 0.05637146321532782, 0.03250317015044857, 0.0811555479594972, 0.21054128446849063, 0.06508290767669678, 0.13395363319432363, 0.09745659903273918, 0.04386625259940047, 0.1831916582887061, 0.08443250102573074, 0.2145582775119692, 0.08810294079012237, 38.45872811973095, 112.38444149494171, 102.27993249893188, 102.00229659676552, 87.3602306842804, 83.52724716067314, 41.292498260736465, 24.549367390573025, 47.44279123842716, 82.35534444451332, 81.20101198554039, 51.00623622536659, 22.77736097574234, 0.24876414594473317, 0.3841562394518405, 0.15088310523424298, 0.11165587304276414, 0.2713759755715728, 0.3528991463826969, 0.22688664175802842, 2.201575026847422, 0.3203824209049344, 7.034025331959128, 58.360593393445015, 128.27721029520035, 119.82767969369888, 103.60742926597595, 109.08475935459137, 109.85960617661476, 106.43714502453804, 96.9182226061821, 93.02540749311447, 91.77643731236458, 94.10220891237259, 97.39379748702049, 98.34321454167366, 103.00512358546257, 108.57634663581848, 106.34091138839722, 103.06022822856903, 102.11604729294777, 99.53955754637718, 103.78002360463142, 105.45460134744644, 101.39976292848587, 97.44821816682816, 100.12138992547989, 96.50211453437805, 101.76398858428001, 100.25893494486809, 108.01472157239914, 86.37658506631851, 59.496892020106316, 100.7292053103447, 98.89451935887337, 97.10772603750229, 92.27823838591576, 96.41902059316635, 105.03030851483345, 103.50571632385254, 84.48269069194794, 96.69315308332443, 106.78851217031479, 101.0459791123867, 92.58134052157402, 101.04603230953217, 105.01933470368385, 119.46913853287697, 118.08516159653664, 106.30825594067574, 92.47259795665741, 93.92485722899437, 113.84515151381493, 119.53320309519768, 109.05182272195816, 111.54293105006218, 114.69781056046486, 94.18283298611641, 92.40494638681412, 96.0226258635521, 92.06573858857155, 93.42388451099396, 89.84631568193436, 89.60730850696564, 103.32750588655472, 97.90079668164253, 104.1188134253025, 105.14762341976166, 4.765544682741165, 0.42287913034670055, 0.18889271799707785, 0.14558385912096128, 0.2620751137146726, 0.06835825770394877, 0.16384281450882554, 0.12088588206097484, 3.4746330650523305, 35.55355980992317, 51.85730695724487, 33.71436730027199, 40.506411641836166, 37.09843531250954, 18.149465806782246, 32.143664583563805, 49.74119670689106, 78.54904308915138, 70.94543069601059, 62.2869873046875, 75.63653737306595, 39.04369533061981, 2.803033827804029, 0.18268398474901915, 0.0405877336015692, 0.21458622679347172, 0.01227265585839632, 0.17152417654870078, 0.10695480537833646, 0.0958976881520357, 0.05624091572826728, 0.03406949508644175, 0.06318552550510503, 0.05356078298063949, 0.04297607985790819, 0.013734083786403062, 0.0662706333969254, 0.030252874494181015, 0.035711719465325586, 0.0032819975831444026, 0.031268937746062875, 0.040422512975055724, 0.07232074742205441, 0.053291639414965175, 0.0354520865221275, 0.08312456964631565, 0.0268281839453266, 0.06383080806699581, 0.031071715711732395, 0.028904060054628644, 0.0239806245372165, 0.046737195225432515, 0.05006144907383714, 0.08961949730291963, 0.05732248835556675, 0.07385134536889382, 0.05968537523585837, 0.1883543492294848, 0.13500184257281944, 0.1679261852405034, 0.14948014926631004, 0.20684193063061684, 0.13313016097526997, 0.0985193916130811, 0.11704451084369794, 0.18146145972423255, 0.12409555944032036, 0.19326747074956074, 0.32950282213278115, 0.14628511446062475, 0.2383066766196862, 0.08076180893112905, 0.27557670953683555, 0.13680584030225873, 0.18685592338442802, 0.19723288452951238, 0.17909527028677985, 0.11544738677912392, 0.20878637238638476, 0.27842174749821424, 0.12482466758228838, 0.28377340408042073, 0.3343149967258796, 0.2131805248791352, 0.3440311347367242, 0.20139066298725083, 0.4873139056144282, 0.26321350887883455, 62.8564627468586, 135.83655506372452, 109.4214516878128, 107.95073300600052, 86.62253826856613, 70.9826534986496, 39.471179991960526, 91.68115362524986, 94.21552643179893, 103.8227105140686, 92.94599935412407, 66.40060856938362, 31.490536630153656, 1.4585172990337014, 0.6417456641793251, 0.499140681931749, 0.6436365970876068, 0.2842317841714248, 0.45037481118924916, 0.5730787175707519, 7.07903771661222, 5.03557481803, 7.368884738534689, 54.36069242656231, 131.04226112365723, 128.88517767190933, 109.75868359208107, 112.42074474692345, 114.4705979526043, 112.62662529945374, 101.60732299089432, 95.74146375060081, 96.26145824790001, 99.11932289600372, 102.1251592040062, 104.71244797110558, 109.84116956591606, 115.19505947828293, 111.53992921113968, 106.51783749461174, 104.99239414930344, 103.98354828357697, 110.84919467568398, 109.37313348054886, 104.62539464235306, 102.01492711901665, 105.6506860256195, 101.22321680188179, 108.34756091237068, 104.6804840862751, 114.47036236524582, 90.36126405000687, 67.6465693116188, 110.64577639102936, 106.36018395423889, 108.9936326444149, 102.07531347870827, 107.05103248357773, 116.29433289170265, 113.36626321077347, 90.5344207584858, 102.28215157985687, 114.39320370554924, 106.90639704465866, 101.16701021790504, 108.42034980654716, 113.50018322467804, 122.28421747684479, 119.22986537218094, 111.10789999365807, 95.071901679039, 101.0819859802723, 117.16028362512589, 124.39973875880241, 109.36231926083565, 115.58899194002151, 119.19477045536041, 101.21290415525436, 100.7226012647152, 100.1027861237526, 95.22465348243713, 99.21780601143837, 99.314906001091, 95.46872198581696, 111.50270640850067, 98.87410685420036, 112.15415105223656, 101.46299913525581, 3.335403073579073, 0.3061456832801923, 0.39496342360507697, 0.35060890833847225, 0.5246306047774851, 0.5305844696704298, 0.44175265822559595, 0.37427858042065054, 9.734956976026297, 49.84465755522251, 83.93460050225258, 73.35475221276283, 81.07595309615135, 112.32289999723434, 45.67208245396614, 36.88459798693657, 33.032987862825394, 69.89514425396919, 71.5281294286251, 74.86467719078064, 91.95630446076393, 46.16136699914932, 3.443825743161142, 0.3436108713503927, 0.21337989543098956, 0.31776724092196673, 0.1806189291528426, 0.2930357336299494, 0.2996941638411954, 0.228352531848941, 0.17962823621928692, 0.18859579955460504, 0.11534921548445709, 0.17956433730432764, 0.14459070225711912, 0.12892394996015355, 0.21916232421062887, 0.1253272796748206, 0.18982473673531786, 0.10956936195725575, 0.14023083698702976, 0.12213708367198706, 0.1989301762660034, 0.21330382529413328, 0.11314902963931672, 0.16992072196444497, 0.19061659346334636, 0.21491793711902574, 0.14266034646425396, 0.10726179476478137, 0.1376585679827258, 0.14476043143076822, 0.1896153620327823, 0.16203152888920158, 0.10622024987242185, 0.22923757263924927, 0.12268401682376862], [0.03613163033151068, 0.03154460107907653, 0.0884900672826916, 0.04414947470650077, 0.031260870600817725, 0.026201625769317616, 0.0591037429694552, 0.058606552265700884, 0.08887972449883819, 0.0038317395319609204, 0.043090856706839986, 0.09731305282912217, 0.07098510424839333, 0.029787623971060384, 0.006962729776205379, 0.05042585471528582, 0.07144416711525992, 0.07093103879014961, 0.020912348554702476, 0.025737798314366955, 0.06728162406943738, 0.039111638980102725, 0.04881972839939408, 0.1114354032324627, 0.10108590897289105, 0.03937082663469482, 0.021572355326497927, 0.05206894740695134, 0.020814852614421397, 0.06994662442593835, 27.2321792319417, 95.74035421013832, 92.29506388306618, 72.62396022677422, 46.92002668976784, 34.881482273340225, 32.26985581219196, 72.00683534145355, 61.712119951844215, 93.80409970879555, 79.34070780873299, 41.641756519675255, 14.759645853191614, 0.18952787766465917, 0.05517321013030596, 0.14401703694602475, 0.32459360430948436, 0.2964101900579408, 0.3129678312689066, 0.7517672760877758, 1.3229826092720032, 10.153967142105103, 50.55957019329071, 108.53379651904106, 124.22062397003174, 98.32039296627045, 94.76458176970482, 102.2011399269104, 97.01837003231049, 92.52535432577133, 92.38172963261604, 87.18037873506546, 84.12930205464363, 83.1116634607315, 85.31774148344994, 86.11877650022507, 94.61610853672028, 100.64921200275421, 105.03986120223999, 105.40498360991478, 107.64084443449974, 104.71724331378937, 102.31178238987923, 92.50425025820732, 93.8140095770359, 98.07928830385208, 93.67725491523743, 87.92203813791275, 89.53021824359894, 91.97233960032463, 97.56997883319855, 90.64001709222794, 98.69329735636711, 67.87476986646652, 81.50381773710251, 103.26825946569443, 79.35249477624893, 70.76684787869453, 77.83938556909561, 92.25493803620338, 85.52576512098312, 84.40078988671303, 96.64282858371735, 95.62674790620804, 84.1200989484787, 79.64199364185333, 90.31869873404503, 109.59103658795357, 103.37751120328903, 122.16538265347481, 109.41348731517792, 100.1854620873928, 87.0381523668766, 95.44704034924507, 112.639369815588, 106.84594228863716, 99.3894200026989, 107.5846454501152, 102.10289999842644, 82.08705604076385, 81.62121623754501, 83.32182258367538, 82.53556117415428, 80.39052307605743, 85.32021895051003, 81.20218232274055, 96.30806654691696, 92.3180678486824, 98.2507275044918, 90.53801536560059, 6.477220309898257, 0.9917661384679377, 0.14086881681578234, 0.10922180677880533, 0.013989635845064186, 0.07881787183578126, 0.05819656391395256, 0.2535919798538089, 0.48640611057635397, 17.043172270059586, 69.67584282159805, 75.62070742249489, 46.26040108501911, 66.9529165327549, 44.0982449054718, 31.146318800747395, 18.220212310552597, 44.35360260307789, 59.23784852027893, 62.696818113327026, 70.47153532505035, 47.294956371188164, 4.700825130566955, 0.534324775217101, 0.1644343655789271, 0.27404447144363075, 0.06140363635495305, 0.016897923342185095, 0.12132179734180681, 0.06273522740229964, 0.052953895428800024, 0.057799715286819264, 0.13568870024755597, 0.012636379651667085, 0.014346165444294456, 0.09938397139194421, 0.06590160046471283, 0.0378538433869835, 0.023656074081372935, 0.06714690200169571, 0.08349978466867469, 0.03170271564158611, 0.024548003857489675, 0.039776647827238776, 0.010308880227967165, 0.03835490810160991, 0.02427954492304707, 0.022673149578622542, 0.0485604257119121, 0.0034252575960636023, 0.014664020800410071, 0.11112756779766642, 0.019245759467594326, 0.08233157001086511, 0.014639424171036808, 0.06554158462677151, 0.031065361072251108, 0.11107759899459779, 0.03837163239950314, 0.04747039631183725, 0.06575927138328552, 0.051472880368237384, 0.04609459181665443, 0.07750182878226042, 0.08382552812690847, 0.021760076015198138, 0.024975111700769048, 0.01123103025747696, 0.013848160233465023, 0.00622838995695929, 0.030071361870795954, 0.03068200468987925, 0.04147048857703339, 0.041033126108231954, 0.012762867590936366, 0.03473113087238744, 0.056298825511476025, 0.021715699294873048, 0.06982865263125859, 0.06282452261075377, 0.05085342454549391, 0.07653639113414101, 0.05893008041311987, 0.0628597300965339, 0.04993054535589181, 0.0766296568326652, 32.739476412534714, 112.74242028594017, 110.57199195027351, 96.33587345480919, 65.61833694577217, 68.13090652227402, 48.7057750672102, 27.17398725450039, 50.066603645682335, 97.18686819076538, 89.80869770050049, 54.48155254125595, 19.19104501605034, 0.30150877428241074, 0.13262980501167476, 0.04301422253774945, 0.5470234563108534, 0.5544351367279887, 0.37661141774151474, 0.8227235404774547, 1.9003655458800495, 15.031739752739668, 61.1440010368824, 122.59775385260582, 131.21916443109512, 102.2131472826004, 98.66056591272354, 109.01598304510117, 104.04252871870995, 97.55117744207382, 96.40575170516968, 91.36507898569107, 87.70157396793365, 86.04468807578087, 86.78992688655853, 91.38236805796623, 99.21672686934471, 104.90452006459236, 108.71106460690498, 106.12157195806503, 111.55878379940987, 107.93525263667107, 104.58788305521011, 96.44368886947632, 96.48812368512154, 99.34340447187424, 95.90155676007271, 93.13406646251678, 93.55779692530632, 93.33706676959991, 104.01044324040413, 94.71244096755981, 104.66219946742058, 72.98772990703583, 85.95594763755798, 110.95158398151398, 88.40861722826958, 83.61309215426445, 86.17321237921715, 100.16276210546494, 90.42898401618004, 90.97601786255836, 101.49971276521683, 101.54518872499466, 86.9111479818821, 83.5810674726963, 95.55904313921928, 112.1267469227314, 106.292365193367, 123.88376444578171, 113.92810106277466, 104.02402371168137, 90.01404628157616, 98.49997133016586, 115.43521419167519, 109.48002934455872, 99.2882314324379, 110.52280738949776, 107.74797588586807, 84.92147594690323, 85.09704172611237, 85.65251871943474, 87.65742793679237, 88.55340465903282, 91.97441428899765, 85.16259580850601, 100.53613007068634, 99.78823140263557, 100.49710616469383, 103.20158824324608, 11.836205273866653, 0.6446871813386679, 0.05616316462692339, 0.07976883018272929, 0.20214391319314018, 0.09250613264157437, 0.06277784894336946, 0.17437139642424881, 0.4302623122930527, 21.48725040256977, 69.98909041285515, 70.44450357556343, 49.00563597679138, 29.852889105677605, 25.71962859481573, 24.649442620575428, 28.91532551497221, 79.67362314462662, 92.6613338291645, 78.44002693891525, 85.55686265230179, 70.91677263379097, 10.529345199465752, 0.39727191848214716, 0.1219951627717819, 0.18709167401539162, 0.07387366917100735, 0.027634506986942142, 0.17160835093818605, 0.030969705658208113, 0.03020395954081323, 0.02272133166115964, 0.05761195563536603, 0.038981113757472485, 0.0023470139649361954, 0.06879671855131164, 0.06618478175369091, 0.07083252610755153, 0.012021524216834223, 0.03756108468223829, 0.016240055811067577, 0.0818632822483778, 0.05288174383167643, 0.0328794724191539, 0.04468783976335544, 0.068083106452832, 0.023015919759927783, 0.040515982764190994, 0.02337997288123006, 0.033081867222790606, 0.03387249569641426, 0.06694931260426529, 0.043275065181660466, 0.061689845606451854, 0.018452180956956, 0.07396410728688352, 0.18788161600241438, 0.1859261459321715, 0.17783168965252116, 0.2673747902736068, 0.1275229681050405, 0.1466392376460135, 0.16972101002465934, 0.11862032784847543, 0.16918411070946604, 0.17920770565979183, 0.1899319770745933, 0.13311463524587452, 0.12250216837855987, 0.25513493455946445, 0.1556726888520643, 0.20804377942113206, 0.18207273707957938, 0.17112810717662796, 0.12124206841690466, 0.1356334102456458, 0.17216836073203012, 0.1158383724396117, 0.2814327593659982, 0.16859291587024927, 0.1750265940790996, 0.1553641929058358, 0.16628584591671824, 0.22596783324843273, 0.19950710702687502, 0.20822936086915433, 52.04914726316929, 134.87797290086746, 119.23539787530899, 104.0851092338562, 72.4390621483326, 53.003124073147774, 51.649727895855904, 108.54263484477997, 100.88096156716347, 118.79047974944115, 103.78372460603714, 70.59901848435402, 28.274434804916382, 0.893269901862368, 0.30393868451938033, 0.2876056468812749, 0.7810248748864979, 0.8756937668658793, 0.41035624919459224, 1.869080162141472, 7.160629313439131, 11.798220612108707, 56.03398583829403, 122.8898137807846, 141.40693455934525, 106.78853496909142, 101.72467589378357, 114.31780055165291, 110.79449281096458, 103.61938342452049, 100.52282318472862, 94.82594087719917, 93.86592999100685, 93.82280990481377, 95.5227854847908, 97.79158294200897, 102.9577249288559, 107.77568399906158, 111.0798043012619, 111.37596040964127, 115.85950702428818, 113.61936002969742, 109.10157725214958, 101.61143437027931, 103.84462013840675, 105.5817349255085, 103.01134765148163, 96.703762114048, 98.3559362590313, 102.13320717215538, 110.89919239282608, 100.4879030585289, 112.95280739665031, 79.10761311650276, 95.91821506619453, 120.83966419100761, 95.43784484267235, 90.71494147181511, 96.52172908186913, 107.21470490098, 96.55816912651062, 100.17515704035759, 107.62141227722168, 108.15210700035095, 93.45399409532547, 86.1071415245533, 103.08958545327187, 119.97847080230713, 110.66269308328629, 124.26742225885391, 118.67895573377609, 109.37790602445602, 95.60744494199753, 104.43700835108757, 124.51171875, 115.6722454726696, 103.54280233383179, 116.98926240205765, 111.15342155098915, 90.04876881837845, 91.6287088394165, 92.29665219783783, 92.55444556474686, 91.86976030468941, 92.9356487095356, 90.54446741938591, 108.36440160870552, 103.93415853381157, 106.52143970131874, 102.39565148949623, 8.166578784584999, 1.210701009258628, 0.1828627532813698, 0.31474260322283953, 0.36190935352351516, 0.5376147455535829, 0.33012679021339864, 0.48075234051793814, 1.7940834676846862, 32.98466205596924, 103.14401373267174, 98.96445080637932, 72.37485319375992, 101.33360087871552, 62.63120323419571, 46.88746243715286, 25.29117688536644, 61.04630447924137, 84.36013966798782, 82.35872626304626, 101.40717253088951, 83.03472518920898, 13.952498864382505, 0.5748211615718901, 0.31100146647077054, 0.47826112888287753, 0.2347921917680651, 0.14755190117284656, 0.32512320089153945, 0.0663079040532466, 0.08242648327723145, 0.173037682834547, 0.3207007428864017, 0.12447768385754898, 0.14689670351799577, 0.2128545439336449, 0.230568777769804, 0.18379002227447927, 0.14349503995617852, 0.11239287763601169, 0.17580026818905026, 0.15344752231612802, 0.10729983725468628, 0.11780693399487063, 0.12393036478897557, 0.1810391925391741, 0.1444523807731457, 0.10126423221663572, 0.21523692703340203, 0.22031710599549115, 0.1801100978627801, 0.12066418770700693, 0.10287740151397884, 0.18902297975728288, 0.095059662417043, 0.22151088021928445], [0.016995686455629766, 0.027810165920527652, 0.10999954043654725, 0.01499207141023362, 0.0722120598948095, 0.025913151112035848, 0.07253878298797645, 0.07582111662486568, 0.0295202671259176, 0.10816279173013754, 0.05524118343601003, 0.009914027050399454, 0.06368605216266587, 0.04499137074162718, 0.06204573510331102, 0.0084919746950618, 0.06380843973602168, 0.01356593260425143, 0.08068893002928235, 0.06224748423846904, 0.09514751785900444, 0.06280666653765365, 0.09967380974558182, 0.09503267050604336, 0.0635162710386794, 0.056798984805936925, 0.05120412643009331, 0.14608979603508487, 0.055815835803514346, 19.678720347583294, 95.3673130273819, 94.0549698472023, 78.12522903084755, 78.62869441509247, 63.60306188464165, 31.512488052248955, 65.88619217276573, 73.45081105828285, 79.88646492362022, 64.99696388840675, 36.26773148775101, 14.95511306449771, 0.5865634814836085, 0.10570050159003586, 0.08321399844135158, 0.13117483933456242, 0.08533570216968656, 0.08771260821959004, 0.6265614414587617, 5.091948118060827, 62.13761731982231, 119.92623880505562, 120.57721227407455, 104.42038044333458, 94.7505833208561, 100.60600072145462, 93.37637946009636, 82.1714799106121, 86.85774564743042, 84.61877658963203, 81.34047970175743, 80.47071397304535, 81.11644372344017, 86.21161311864853, 90.32148018479347, 94.12515968084335, 95.31899482011795, 103.77436190843582, 103.83853286504745, 99.41337391734123, 102.51025334000587, 95.3184400498867, 89.30587068200111, 90.46806871891022, 85.70524469017982, 86.55464351177216, 88.70727360248566, 90.98262190818787, 93.68487730622292, 88.3089029788971, 89.21680346131325, 90.69712042808533, 96.13456785678864, 87.65140905976295, 63.118561282753944, 87.19551712274551, 84.4856545329094, 90.15192568302155, 91.96357727050781, 95.44867426156998, 82.4440848827362, 85.09152442216873, 98.53804528713226, 91.258684694767, 80.99143043160439, 78.526761084795, 79.4338408112526, 96.8289501965046, 105.45229867100716, 95.55904313921928, 113.63679349422455, 102.37018525600433, 88.68035584688187, 77.67591834068298, 93.72555032372475, 104.09326359629631, 98.68081882596016, 94.11502942442894, 105.46816661953926, 87.13003903627396, 75.60581222176552, 78.02894979715347, 81.37969359755516, 84.39755246043205, 89.64422732591629, 97.20645233988762, 87.50227466225624, 99.27310064435005, 94.1481864452362, 91.85338318347931, 94.18053030967712, 23.106839396059513, 0.2190937942941673, 0.2085354967857711, 0.09227752147126012, 0.18280911084730178, 0.029961392283439636, 0.05395680411311332, 0.1873539638472721, 0.228498779470101, 12.174816504120827, 63.733094707131386, 77.41708382964134, 49.155214950442314, 59.67062629759312, 71.02391168475151, 52.528985515236855, 22.996314726769924, 21.21112111955881, 53.55283297598362, 56.47272169589996, 76.3873390853405, 62.75692708790302, 4.147837478667498, 0.37560530297923833, 0.037672944890800864, 0.05430748744402081, 0.026743508606159594, 0.021331099815142807, 0.03714049104019068, 0.025172712230414618, 0.05567510233959183, 0.026044418482342735, 0.019286241767986212, 0.07471656339475885, 0.07023535697953776, 0.018091194760927465, 0.03823852450295817, 0.101485533232335, 0.03297392926469911, 0.03579353382519912, 0.05474506142491009, 0.03384524774446618, 0.03022928718564799, 0.11935949951293878, 0.0378580476535717, 0.039920438939589076, 0.048407428257633, 0.10238972143270075, 0.02116127416229574, 0.028553007505252026, 0.05499215949384961, 0.07876263378420845, 0.03188857910572551, 0.056830485264072195, 0.021751801068603527, 0.016923820585361682, 0.021517364039027598, 0.06247869663638994, 0.031048890959937125, 0.1376553173759021, 0.05527980851184111, 0.008323806814587442, 0.02467543617967749, 0.03399894652829971, 0.03340103896334767, 0.04054044395161327, 0.006542552200698992, 0.014505650196952047, 0.036715374008053914, 0.027955649129580706, 0.008130446731229313, 0.04483304837776814, 0.029199284545029514, 0.03304245547042228, 0.10331501631299034, 0.09962705444195308, 0.0741185927472543, 0.09722021757625043, 0.0862066050467547, 0.06665688415523618, 0.03962898641475476, 0.03643034848209936, 0.18523519160225987, 0.03699098167999182, 24.69491098076105, 117.02190265059471, 103.48670974373817, 100.12503772974014, 93.00909116864204, 90.02811312675476, 47.27786488831043, 22.785131558775902, 59.402068108320236, 88.70755478739738, 78.81453484296799, 46.55813790857792, 19.001427590847015, 0.5018007766921073, 0.03123658381809946, 0.13389380124863237, 0.12397182857966982, 0.16733738011680543, 0.28097176691517234, 0.7296204019803554, 9.184965938329697, 74.60796296596527, 128.27930778265, 127.73690968751907, 109.28599655628204, 99.03951957821846, 108.80254089832306, 97.70823821425438, 86.49342119693756, 90.03814458847046, 88.55883836746216, 86.63370966911316, 86.02608427405357, 85.550357401371, 89.23875108361244, 93.28352004289627, 98.84297132492065, 100.97542449831963, 106.5355597436428, 104.79215249419212, 103.96328017115593, 105.54842591285706, 98.52210134267807, 92.1555657684803, 93.34229528903961, 93.44333946704865, 89.20482650399208, 92.72398486733437, 94.69813093543053, 99.050964564085, 92.91376188397408, 94.13668066263199, 96.72832399606705, 100.76285630464554, 92.90982529520988, 68.52607771754265, 90.89951276779175, 92.20878571271896, 95.44625759124756, 98.38236764073372, 99.82141882181168, 87.93281435966492, 90.32239973545074, 103.11316698789597, 95.10642662644386, 85.0445893406868, 81.6637359559536, 84.11063745617867, 100.15093713998795, 108.71972054243088, 99.31334808468819, 117.96613678336143, 108.50981220602989, 95.93770802021027, 80.82895874977112, 96.75540134310722, 106.28621712327003, 102.60986119508743, 96.65980607271194, 110.41116937994957, 93.56768399477005, 81.52338668704033, 82.96752959489822, 85.87556675076485, 90.76755344867706, 97.40647360682487, 102.91985616087914, 96.5200799703598, 101.28212884068489, 100.245650857687, 94.48155775666237, 105.15947118401527, 37.52704091370106, 1.746636601164937, 0.29360475309658796, 0.2359629445709288, 0.15529017109656706, 0.11624509905232117, 0.10239693510811776, 0.09637058465159498, 0.07485395719413646, 13.83216217160225, 69.49330821633339, 78.00925925374031, 53.089459240436554, 35.705240070819855, 26.352182552218437, 21.337677128612995, 20.751598477363586, 44.077083840966225, 84.2979446053505, 74.66830372810364, 87.29569494724274, 84.84450727701187, 11.700395811349154, 0.27882755384780467, 0.16522708319826052, 0.06753240319085307, 0.0999024134944193, 0.016908927536860574, 0.06417932061594911, 0.014196580941643333, 0.07718248263699934, 0.007949205919430824, 0.03190748531778809, 0.04471079810173251, 0.01693313824944198, 0.04165906830166932, 0.04452572873560712, 0.11123391013825312, 0.0048157290166273015, 0.021826323827554006, 0.05426312185591087, 0.04012540157418698, 0.016458955979032908, 0.029990226576046553, 0.0436333518155152, 0.009810846258915262, 0.02274419352033874, 0.057606831105658785, 0.06128233602794353, 0.04714817063359078, 0.026586566636979114, 0.05601710254268255, 0.04591123681166209, 0.024078487840597518, 0.02171481799450703, 0.15025570843135938, 0.11233966564759612, 0.14859420305583626, 0.2044921278138645, 0.26876694057136774, 0.14079540356760845, 0.12455796939320862, 0.18258651107316837, 0.120483044302091, 0.19503961550071836, 0.1081430580234155, 0.07666919846087694, 0.12819511641282588, 0.1371281105093658, 0.11169004152179696, 0.14171358867315575, 0.20852817920967937, 0.15196107473457232, 0.13189816614612937, 0.20607539598131552, 0.18810240493621677, 0.16535222413949668, 0.2267002736334689, 0.1715743012027815, 0.1979699856019579, 0.20856120478129014, 0.18606614466989413, 0.3213715850142762, 0.1383418930345215, 42.55881451070309, 139.83774036169052, 119.9590614438057, 107.70082041621208, 101.71950057148933, 87.87689656019211, 49.78636868298054, 97.83166319131851, 123.89463186264038, 100.28365641832352, 89.72764804959297, 60.691175535321236, 27.0121406391263, 0.9652499144431204, 0.21366922912420705, 0.27186053863260895, 0.2920107980025932, 0.294502543983981, 0.6048243516124785, 1.9652277091518044, 8.480222504585981, 67.87665456533432, 133.97565811872482, 134.49466466903687, 116.27540990710258, 101.98081254959106, 112.19369933009148, 105.09427428245544, 91.08982175588608, 95.49510017037392, 92.02015623450279, 91.90231695771217, 89.90417897701263, 91.39372184872627, 94.94056552648544, 99.10217821598053, 104.27101045846939, 106.59216910600662, 111.6749207675457, 111.44675061106682, 106.81849256157875, 111.7219090461731, 102.47219458222389, 96.38802945613861, 96.61939144134521, 96.43719121813774, 97.21696257591248, 95.70795714855194, 99.67511907219887, 104.86295029520988, 97.10494458675385, 98.77127677202225, 102.21544235944748, 105.76071292161942, 97.83702090382576, 75.80188170075417, 98.14036622643471, 99.79722172021866, 103.28162714838982, 107.46375873684883, 109.3235993385315, 94.9245835840702, 94.33421686291695, 110.49028873443604, 102.09899380803108, 89.32374492287636, 87.91225746273994, 87.99048766493797, 107.68347054719925, 115.76077312231064, 104.6648745238781, 119.16467607021332, 113.37806537747383, 97.17992976307869, 84.38603907823563, 104.33046206831932, 111.60555928945541, 102.45352998375893, 101.87795966863632, 118.87889340519905, 97.32413962483406, 85.3948013484478, 85.77449977397919, 89.51060369610786, 96.83957442641258, 103.20519044995308, 107.13533475995064, 98.08880299329758, 108.08306470513344, 100.40423914790154, 97.06215128302574, 109.3988049030304, 30.953220762312412, 1.2466447055339813, 0.46610926219727844, 0.38320124382153153, 0.41072040621656924, 0.33920432499144226, 0.15220761619275436, 0.3356507734861225, 0.7024409354198724, 21.738299131393433, 87.25294724106789, 98.78078386187553, 73.2982188463211, 94.46058288216591, 106.89649477601051, 79.72758784890175, 32.88725048303604, 29.527136385440826, 73.37210968136787, 78.53043168783188, 96.7556445300579, 99.76255238056183, 14.389824997633696, 0.6028003070969135, 0.24649979401146993, 0.22497264289995655, 0.16431729920441285, 0.09456093175685965, 0.19522607268299907, 0.08639065767056309, 0.16093700949568301, 0.10691916744690388, 0.15800516994204372, 0.15190048579825088, 0.1774136527092196, 0.13460268586641178, 0.11774991478887387, 0.24051311134826392, 0.09381542957271449, 0.1683192266500555, 0.22285143641056493, 0.19113556249067187, 0.0956444970506709, 0.23607374721905217, 0.13423805386992171, 0.08895331586245447, 0.11880031350301579, 0.14605737902456895, 0.11484013928566128, 0.1393448017188348, 0.16834048175951466, 0.13929587934399024, 0.052876493136864156, 0.16665294184349477, 0.08298433342133649], [0.07094091677572578, 0.05690554236934986, 0.08840267197228968, 0.02196327975980239, 0.04805478936759755, 0.022059658767830115, 0.0072921951050375355, 0.012097216786060017, 0.03818100434727967, 0.031770303030498326, 0.05454124911921099, 0.023950667746248655, 0.048301226925104856, 0.00969857137533836, 0.03771896917896811, 0.020988166361348704, 0.016585256526013836, 0.018857809191104025, 0.028935124501003884, 0.026046119855891448, 0.11616131800110452, 0.029067191535432357, 0.06328901799861342, 0.014622480011894368, 0.06768096631276421, 0.2281459773075767, 0.17504703282611445, 0.17642537917708978, 11.800291500985622, 85.7457809150219, 93.29358950257301, 98.50814089179039, 95.33157214522362, 82.45746776461601, 27.999437861144543, 52.17801734805107, 75.38306817412376, 73.16483840346336, 63.106572926044464, 32.635802775621414, 10.742210727185011, 0.7606360001955181, 0.057970876805484295, 0.05933203501626849, 0.05479653307702392, 0.07550446447567083, 0.13405661360593513, 0.3076282568508759, 4.87511845305562, 95.15040546655655, 116.34062200784683, 94.48101058602333, 96.41624674201012, 98.12503784894943, 96.58804312348366, 81.591707020998, 74.88518849015236, 80.59491410851479, 79.19475764036179, 83.2912266254425, 82.80540749430656, 81.0597051680088, 79.12492498755455, 82.48256921768188, 84.46822866797447, 89.97861698269844, 96.52932867407799, 102.02751964330673, 98.29023778438568, 102.69585818052292, 99.08313363790512, 96.42389953136444, 88.95473912358284, 89.63288873434067, 83.30842450261116, 83.57041284441948, 86.813994795084, 87.67229273915291, 89.73296016454697, 92.43732064962387, 88.93778443336487, 89.15976852178574, 90.97376838326454, 95.5967827141285, 61.774854585528374, 67.83601194620132, 95.5981582403183, 77.55867943167686, 82.65980690717697, 70.9836794435978, 70.86001127958298, 86.55688539147377, 102.84189194440842, 90.76995491981506, 92.23572626709938, 74.15030032396317, 80.53850993514061, 88.4467975795269, 106.42938584089279, 98.30878838896751, 98.1461875140667, 114.93608057498932, 100.78912809491158, 84.30679813027382, 77.51912355422974, 96.7420868575573, 103.99349614977837, 103.79770025610924, 101.56450688838959, 78.86408418416977, 77.49358132481575, 86.56971350312233, 91.67359203100204, 92.4962630867958, 95.3048899769783, 95.40765926241875, 99.49285045266151, 97.18575865030289, 97.69735559821129, 92.18037083745003, 87.67084121704102, 104.45286870002747, 68.57288360595703, 3.8580552907660604, 0.20250504225259647, 0.13623359991470352, 0.06155926843348425, 0.09428240373381414, 0.057743668294278905, 0.06870844008517452, 0.23951428447617218, 8.623846247792244, 49.736948534846306, 60.80149881541729, 55.16990080475807, 70.88823616504669, 94.16853055357933, 117.47008100152016, 58.77087637782097, 19.066255912184715, 39.2656946182251, 51.93481519818306, 66.63368806242943, 68.9692935347557, 15.194106940180063, 0.5799040419515222, 0.03495600903988816, 0.08011123485630378, 0.012115453209844418, 0.004300370537748677, 0.03879427065839991, 0.06613887249841355, 0.0076491115487442585, 0.03007473122124793, 0.08504305849783123, 0.03526546606735792, 0.05736730294302106, 0.025177473107760306, 0.014080753026064485, 0.023748178318783175, 0.03989195160102099, 0.023192441440187395, 0.04003970949270297, 0.04639323575247545, 0.0841887723072432, 0.031205524937831797, 0.016589893093623687, 0.012509542902989779, 0.027779184965766035, 0.025230223109247163, 0.10423880463349633, 0.07384147480479442, 0.010029192599176895, 0.01338847210718086, 0.038201198185561225, 0.03336127469083294, 0.01656694588746177, 0.052091527250013314, 0.07836988181225024, 0.13869444286683574, 0.04770153449499048, 0.02858085288607981, 0.09854055766481906, 0.03631340827269014, 0.06658476224401966, 0.06844931922387332, 0.035232674272265285, 0.00951506237470312, 0.022684200157527812, 0.04008882853668183, 0.04178207185759675, 0.006285681902227225, 0.04144583814195357, 0.033943957096198574, 0.09066376587725244, 0.02692385605769232, 0.0318232033168897, 0.06567612857907079, 0.032659202988725156, 0.030620148536399938, 0.0763534962607082, 0.1715044947923161, 0.2347642573295161, 0.16332429077010602, 16.12158302217722, 102.25101605057716, 104.66912269592285, 119.82706412672997, 115.01527592539787, 109.19913321733475, 55.33798858523369, 36.340995356440544, 53.23058746755123, 82.3392941057682, 75.15305891633034, 41.07358440756798, 13.598210625350475, 0.8790889440570027, 0.03419977168960031, 0.05200254003284499, 0.20462743617827073, 0.2747130871284753, 1.3901257188990712, 0.8072143164463341, 7.213465478271246, 103.47734704613686, 119.88638654351234, 98.66758793592453, 100.31783178448677, 107.28191569447517, 104.11717191338539, 83.38209494948387, 79.03374508023262, 84.82578948140144, 83.37404698133469, 87.16469317674637, 87.03370660543442, 83.76649752259254, 83.9282776415348, 86.42124027013779, 89.94379565119743, 96.27264484763145, 101.8597586452961, 104.1717977821827, 104.7981409728527, 107.68269538879395, 102.51423552632332, 100.38769483566284, 92.59245112538338, 91.78001672029495, 87.4155405163765, 85.87500438094139, 88.50729033350945, 91.36684969067574, 92.38473147153854, 94.47451293468475, 93.83867785334587, 92.17470914125443, 95.54057613015175, 101.78488746285439, 67.72577986121178, 70.94428315758705, 104.28358778357506, 84.69512969255447, 89.35248658061028, 76.80429071187973, 78.31771150231361, 92.82563701272011, 107.48699828982353, 97.1169063448906, 98.92343580722809, 77.09833413362503, 83.57868120074272, 91.61869257688522, 109.21954572200775, 104.36102002859116, 100.90999200940132, 116.0381506383419, 104.55561518669128, 87.51174375414848, 81.32360100746155, 97.23221495747566, 106.50020644068718, 107.2947210073471, 105.4633940756321, 82.01093852519989, 80.3443631529808, 89.86156046390533, 97.66672924160957, 101.47791713476181, 101.70955270528793, 99.16061908006668, 103.19181516766548, 102.77326762676239, 98.3585961163044, 96.9384603202343, 88.39216411113739, 107.8784228861332, 85.49326166510582, 10.787377003580332, 0.20193544391077012, 0.14447327965172008, 0.16441977495560423, 0.18218254524981603, 0.05350088053091895, 0.09108596626901999, 0.10578986359178089, 9.038478098809719, 58.34545120596886, 68.9541095495224, 60.85839316248894, 70.95166236162186, 87.75474831461906, 75.93249589204788, 29.636239930987358, 33.46177965402603, 70.72932869195938, 74.33539599180222, 77.36014768481255, 89.21823978424072, 26.7975452542305, 0.4131171869812533, 0.029307265176612418, 0.013444982014334528, 0.014400819982256508, 0.05217933816311415, 0.026275807140336838, 0.08380737519473769, 0.059616648650262505, 0.04944325119140558, 0.02711301094677765, 0.010049180491478182, 0.04890372096269857, 0.01044121258019004, 0.04916709061944857, 0.020576198330672923, 0.04939737162203528, 0.0572053329233313, 0.03340503171784803, 0.05749610638304148, 0.021815225009049755, 0.027252874242549296, 0.024683358606125694, 0.026360347037552856, 0.05306259779899847, 0.05748667739680968, 0.0079555188131053, 0.04851361474720761, 0.08733271766686812, 0.040181133153964765, 0.01209163676321623, 0.038472334417747334, 0.1583180297166109, 0.1724964493769221, 0.22953288804274052, 0.14007195801241323, 0.15704822988482192, 0.06387054265360348, 0.08320941939018667, 0.15506305906455964, 0.18656304222531617, 0.10507112325285561, 0.18724739144090563, 0.12790265085641295, 0.12352795005426742, 0.12738570047076792, 0.08568539473344572, 0.09205283626215532, 0.10837186215212569, 0.17237555352039635, 0.23325910762650892, 0.1823990445700474, 0.19602619693614542, 0.11525183828780428, 0.1559928068309091, 0.1880232326220721, 0.13259105006000027, 0.28483945468906313, 0.47482777561526746, 0.21912296069785953, 31.328539922833443, 129.24472957849503, 116.5680094063282, 129.2545786499977, 118.13739359378815, 108.03236022591591, 40.589676573872566, 83.7623405456543, 128.36021304130554, 92.37853780388832, 90.59733778238297, 56.99678957462311, 21.789814867079258, 1.5274081961251795, 0.10296203603502363, 0.3293025610037148, 0.2642434317385778, 0.22540727426530793, 0.6702034058980644, 1.5504120429977775, 6.892914678901434, 103.16160678863525, 130.3646206855774, 104.67667669057846, 104.19381380081177, 111.05027988553047, 110.77574461698532, 90.13454541563988, 83.53346362709999, 89.22522380948067, 87.95562833547592, 92.03806087374687, 92.47193679213524, 88.8448566198349, 87.77601197361946, 91.11716508865356, 95.29547408223152, 100.95827981829643, 107.30251058936119, 109.59599912166595, 108.70853394269943, 110.42319193482399, 108.2559934258461, 105.10128870606422, 98.2429227232933, 97.71453827619553, 93.98123860359192, 92.34280452132225, 94.23011004924774, 96.41060024499893, 99.69429284334183, 100.46623662114143, 99.8457071185112, 100.04069745540619, 105.03115206956863, 108.47604721784592, 74.27237257361412, 83.54791805148125, 108.95657703280449, 92.54821389913559, 99.46141853928566, 86.50601372122765, 86.27997145056725, 98.6739943921566, 114.07076060771942, 103.16913798451424, 101.58082321286201, 81.02903321385384, 90.11173143982887, 97.26309970021248, 114.70623090863228, 107.8467021882534, 102.6385572552681, 119.103864133358, 111.05387449264526, 91.67453438043594, 84.81107667088509, 104.638891518116, 113.08798134326935, 113.45743551850319, 111.74302831292152, 86.42500966787338, 85.76852649450302, 97.15349078178406, 101.8110528588295, 102.35981941223145, 104.69227865338326, 104.59759533405304, 108.35090473294258, 104.95834797620773, 105.1031506061554, 97.08330854773521, 92.1734856069088, 114.31795254349709, 78.96771982312202, 7.167560616508126, 0.5966295569669455, 0.3590983949834481, 0.21773882559500635, 0.46343319641891867, 0.17131701344624162, 0.2753340866183862, 0.5708375503309071, 18.108707293868065, 74.82335060834885, 79.19910460710526, 84.92840677499771, 99.11362320184708, 129.76381212472916, 152.8447312116623, 72.31159418821335, 25.865717455744743, 60.456325337290764, 73.61807808279991, 86.87022417783737, 105.22511646151543, 30.441405326128006, 0.5903078243136406, 0.17561899119755253, 0.21223912539426237, 0.11227350318222307, 0.1291629215120338, 0.07971984101459384, 0.3942422044929117, 0.12735764728859067, 0.18500802019843832, 0.14651605597464368, 0.12257524023880251, 0.16320100519806147, 0.1392885172390379, 0.09436953187105246, 0.15410073101520538, 0.13668969419086352, 0.13846888934494928, 0.10731048707384616, 0.08790081687038764, 0.21808061428600922, 0.16475114389322698, 0.21704518469050527, 0.09167389565845951, 0.13809619762469083, 0.07167550938902423, 0.13397885137237608, 0.14695801975904033, 0.1049303229956422, 0.10055430859210901, 0.14536764181684703, 0.09340149670606479], [0.04081563602085225, 0.020561043675115798, 0.014265381742006866, 0.013014224659855245, 0.012337339594523655, 0.024174319514713716, 0.05455109741888009, 0.09065854115760885, 0.08754862326895818, 0.07713957165833563, 0.035297708673169836, 0.012805195983673912, 0.054398381980718113, 0.029910506927990355, 0.006337348831948475, 0.034086074665538035, 0.04899798113910947, 0.037199387879809365, 0.009262312851205934, 0.016316719666065183, 0.0008940411282765126, 0.04608933741110377, 0.09560330043314025, 0.04555917679681443, 0.1258296097512357, 0.5957122624386102, 4.381840322166681, 38.79577003419399, 103.03157016634941, 94.14330750703812, 83.7597718834877, 61.31048150360584, 50.794473588466644, 24.992835894227028, 51.43066205084324, 76.37226909399033, 46.38313069939613, 68.49257871508598, 30.900530889630318, 6.821697950363159, 0.7603713206481189, 0.06837207649368793, 0.13510123098967597, 0.14556797716068104, 0.350656108930707, 0.22650983853964135, 0.6821821443736553, 2.2898017801344395, 61.26346282660961, 112.96112895011902, 85.5476063489914, 96.2936121225357, 85.95410853624344, 85.06858885288239, 73.90566185116768, 85.00493466854095, 86.27482652664185, 85.09951159358025, 82.7735424041748, 78.96635189652443, 73.8929933309555, 77.22074836492538, 79.46709662675858, 78.89062196016312, 77.71175801753998, 91.08402326703072, 95.24084061384201, 98.77735644578934, 97.45037645101547, 93.06979671120644, 89.68091815710068, 85.31242176890373, 84.81420770287514, 79.77174907922745, 76.53711944818497, 83.78920510411263, 80.6406332552433, 89.83925566077232, 88.33338886499405, 88.7801080942154, 89.90313023328781, 87.04374566674232, 86.75109297037125, 92.27829158306122, 78.76057773828506, 39.462064281105995, 65.9722575545311, 93.29096004366875, 83.00840020179749, 68.296570032835, 78.05263012647629, 93.44100639224052, 94.23432022333145, 102.14447736740112, 97.3975820839405, 86.37109816074371, 74.34451550245285, 79.82319831848145, 91.98345020413399, 104.57655966281891, 89.35201540589333, 99.04373735189438, 102.48417153954506, 86.6683030128479, 75.5203928053379, 78.15258756279945, 86.94282308220863, 94.1120807826519, 89.0233862400055, 77.10504457354546, 75.71138575673103, 85.08752703666687, 91.96179136633873, 99.30892512202263, 96.37222230434418, 99.2218641936779, 96.99491769075394, 96.59772500395775, 95.91676354408264, 94.54253688454628, 98.9145214855671, 86.04920223355293, 102.54821330308914, 95.97650393843651, 9.012786727398634, 0.3686799667775631, 0.10667603244655766, 0.05181084699870553, 0.08541534203686751, 0.09618864714866504, 0.12215470225783065, 0.21654506621416658, 8.045467883348465, 58.47740672528744, 90.82299247384071, 91.89708843827248, 110.1097771525383, 114.80251774191856, 143.99714916944504, 64.87656354904175, 14.127186890691519, 47.06871651113033, 64.64039862155914, 63.25185813009739, 71.84311732649803, 23.138561993837357, 0.44626785500440747, 0.14012675819685683, 0.10403662134194747, 0.044671972646028735, 0.15506387542700395, 0.03455582074820995, 0.06725578990881331, 0.03461154119577259, 0.0593563997244928, 0.05443884016131051, 0.05627942948194686, 0.017675655144557822, 0.06722397403791547, 0.07418600944220088, 0.029210505817900412, 0.06534878208185546, 0.09200950225931592, 0.013652045854541939, 0.05006555686122738, 0.0355427398608299, 0.032759533933131024, 0.0422611504473025, 0.010952580159937497, 0.04133349553740118, 0.04536828899290413, 0.0186117742487113, 0.042288561671739444, 0.013568605263571953, 0.10016592044848949, 0.02592098077002447, 0.052125116853858344, 0.05107883334858343, 0.018044847638520878, 0.06345699570374563, 0.0267457647350966, 0.04534180916380137, 0.03353592059283983, 0.028963400327484123, 0.12724682979751378, 0.03271568042691797, 0.029018931527389213, 0.04953883239068091, 0.02368077646679012, 0.12041637717629783, 0.044014537415932864, 0.046582431459682994, 0.05609616724541411, 0.07544469932327047, 0.027508508865139447, 0.046912394027458504, 0.09670801693573594, 0.0316801209555706, 0.0858436651469674, 0.03183649147104006, 0.16346158809028566, 0.5641256261151284, 4.2178567964583635, 46.7534626275301, 117.55291655659676, 110.72876393795013, 105.99534273147583, 92.6687890291214, 88.51198688149452, 52.28211656212807, 34.337438866496086, 37.83553496003151, 60.35479478538036, 79.49607387185097, 41.1152795702219, 8.912212774157524, 0.712644694140181, 0.067136215075152, 0.08475835580611601, 0.21198168920818716, 1.0799925355240703, 2.5312265753746033, 1.5525668836198747, 1.3940775068476796, 70.26597395539284, 116.92379951477051, 92.39648044109344, 103.67688193917274, 90.84731876850128, 88.52515697479248, 78.29194128513336, 92.04642802476883, 91.31334096193314, 90.94898611307144, 84.74715650081635, 82.80030056834221, 77.91092813014984, 80.65737515687943, 82.84456819295883, 81.7380827665329, 82.38976299762726, 95.27038782835007, 97.67573475837708, 103.15468356013298, 101.10505074262619, 95.30465438961983, 91.85798093676567, 91.18787929415703, 87.71637797355652, 84.06013056635857, 82.20693200826645, 85.38027852773666, 84.91093531250954, 95.59501960873604, 94.66786935925484, 94.00110393762589, 94.50773075222969, 92.80732959508896, 90.09396359324455, 98.46588715910912, 84.92418140172958, 45.736982971429825, 64.60462734103203, 96.03371366858482, 88.43225196003914, 74.82731759548187, 83.98779764771461, 98.95657002925873, 96.99269860982895, 106.59273907542229, 101.92813217639923, 92.08960890769958, 74.94128108024597, 82.54461988806725, 93.58568742871284, 108.23336184024811, 93.96193563938141, 102.11334183812141, 106.76973357796669, 92.41589739918709, 79.4551956653595, 80.98889976739883, 89.86215323209763, 95.88730752468109, 91.97527304291725, 81.1911553144455, 79.90466594696045, 91.94662258028984, 96.24960288405418, 100.74961021542549, 97.84637600183487, 103.99873986840248, 100.02763375639915, 99.3042665719986, 100.77355653047562, 98.10009598731995, 101.98588907718658, 93.05131450295448, 100.69225609302521, 110.97422316670418, 17.794621847569942, 0.028299413788772654, 0.09929253137670457, 0.07165380899095908, 0.09663821794674732, 0.0905922896345146, 0.1258632735698484, 0.11250750234466977, 7.868739366531372, 64.94927644729614, 97.11749151349068, 91.90522760152817, 110.36507025361061, 119.5931638777256, 112.09741249680519, 57.34254442155361, 30.490606985986233, 66.32338151335716, 83.81469413638115, 71.53449028730392, 87.61385187506676, 40.21562084555626, 0.3650677262339741, 0.1426118693780154, 0.05303821453708224, 0.039381064561894163, 0.005686944987246534, 0.039905347366584465, 0.06506578632979654, 0.07124438096070662, 0.04131997731747106, 0.05894570262171328, 0.015055345065775327, 0.012659924286708701, 0.0287739560008049, 0.01861344964709133, 0.0048674645950086415, 0.049380038763047196, 0.03360482529387809, 0.03155884660372976, 0.023009943615761586, 0.03575692739104852, 0.03567784784536343, 0.04682854989368934, 0.026575276715448126, 0.01282296392673743, 0.0411621447710786, 0.0958566770714242, 0.026455661063664593, 0.014322608749353094, 0.07851290109101683, 0.0498137572867563, 0.0838765582011547, 0.159387776220683, 0.16855246882187203, 0.10180001831031404, 0.08440524936304428, 0.1835808702162467, 0.1613231044029817, 0.22852941532619298, 0.24186931201256812, 0.21094845636980608, 0.09851674214587547, 0.17048312147380784, 0.14478085533482954, 0.17073531809728593, 0.11712558305589482, 0.13660857744980603, 0.12838687252951786, 0.13547402661060914, 0.1495336729567498, 0.14065230265259743, 0.2466184040531516, 0.13163973548216745, 0.21034344274085015, 0.17524456285173073, 0.19982869445811957, 0.6767461798153818, 8.816589005291462, 71.31096348166466, 143.03390085697174, 121.53367415070534, 115.3072902560234, 82.98503905534744, 68.06824028491974, 35.61999164521694, 71.88072010874748, 115.80654546618462, 68.48507791757584, 96.58922106027603, 52.08516173064709, 14.974178541451693, 1.1353353783488274, 0.22274959890637547, 0.37177979887928814, 0.43751238263212144, 0.5006763932760805, 0.7138035132084042, 3.02487067412585, 5.465164091438055, 71.38705059885979, 128.28698337078094, 95.88514924049377, 109.63886842131615, 96.92700013518333, 94.68485444784164, 79.75723385810852, 94.7698786854744, 96.37698724865913, 96.3116155564785, 87.60850936174393, 88.1351763010025, 82.14650765061378, 85.14169692993164, 87.68509805202484, 86.9969853758812, 85.84229573607445, 99.35500144958496, 104.78644520044327, 106.92453727126122, 107.71405130624771, 99.70896005630493, 97.20122382044792, 97.24517226219177, 92.6924541592598, 90.19466578960419, 87.6620864868164, 91.81810587644577, 89.49980467557907, 98.63299459218979, 98.33623811602592, 98.88316556811333, 98.03825050592422, 98.90148058533669, 95.90151876211166, 102.7456659078598, 88.0347552895546, 55.10848470032215, 78.17777261137962, 102.83762857317924, 94.04019623994827, 83.12054738402367, 92.04746916890144, 100.85347384214401, 103.47449719905853, 111.71236395835876, 106.04564443230629, 98.24242115020752, 80.60680747032166, 86.82301551103592, 99.8306979238987, 114.69069734215736, 98.69776591658592, 103.45831006765366, 110.12347161769867, 97.12187647819519, 83.79096820950508, 84.91950005292892, 94.82729360461235, 101.36799663305283, 99.79760929942131, 87.0444904267788, 84.18214961886406, 97.11443647742271, 101.67809039354324, 105.723657310009, 102.94543638825417, 107.65452370047569, 103.8780127465725, 105.01101315021515, 101.13655105233192, 102.35753953456879, 107.35423341393471, 95.7272981107235, 111.55799344182014, 110.90775713324547, 13.32679308950901, 0.5098484479822218, 0.576173592125997, 0.2096404804615304, 0.16935124236624688, 0.17654759605647996, 0.4471513372845948, 0.1998131984146312, 16.0647114738822, 82.74760499596596, 105.11755183339119, 100.84971964359283, 112.49704465270042, 134.83579516410828, 184.4741427898407, 87.03302264213562, 20.677810236811638, 63.31968829035759, 87.00620368123055, 80.17959639430046, 103.48157241940498, 46.090812385082245, 0.5925637751352042, 0.44119079306256026, 0.25196949660312384, 0.16395645216107368, 0.14515532820951194, 0.12207014195155352, 0.15212958678603172, 0.18330728489672765, 0.16612892621196806, 0.1269714187947102, 0.1505474466830492, 0.16365770803531632, 0.12162112034275196, 0.0990524837106932, 0.14497712370939553, 0.23174304835265502, 0.13910819019656628, 0.09872426147921942, 0.09377314199809916, 0.09441381582291797, 0.10375449390267022, 0.12655020545935258, 0.1586929033510387, 0.14567397069185972, 0.13914411014411598, 0.17400749173248187, 0.15499292610911652, 0.21462113742018119, 0.21989292406942695, 0.11983370961388573], [0.031072029269125778, 0.04389636524138041, 0.02825320952979382, 0.005743236424677889, 0.049741178954718634, 0.08648144459584728, 0.03863822297716979, 0.023056891877786256, 0.06105346139520407, 0.05845498715643771, 0.04143331811064854, 0.018106225106748752, 0.03630098843132146, 0.03629339254985098, 0.16663499671267346, 0.10732800175901502, 0.060102944626123644, 0.04230520433338825, 0.027624413778539747, 0.02883829834900098, 0.018721179803833365, 0.027963083593931515, 0.11096747170086019, 0.19132717017782852, 1.4310504728928208, 29.515548907220364, 85.77860355377197, 115.08157476782799, 91.70718222856522, 90.82901135087013, 85.05778223276138, 56.48696333169937, 33.88173691928387, 69.1013440489769, 98.81962537765503, 62.45251402258873, 47.72879049181938, 36.23705193400383, 5.053179748356342, 0.4194060276495293, 0.08003845243365504, 0.2828439383301884, 0.1849367146496661, 0.0364797829388408, 0.366662215674296, 27.775679267942905, 7.638437999412417, 5.358716128394008, 113.4369470179081, 94.60931450128555, 104.90968018770218, 75.45045375823975, 82.77385398745537, 76.1244235932827, 91.27165719866753, 85.46688348054886, 95.4102811217308, 94.24531683325768, 94.54296246170998, 89.06714469194412, 84.89442139863968, 75.94582557678223, 75.17434537410736, 70.42710050940514, 72.41389229893684, 74.2365936934948, 85.77435538172722, 90.15570268034935, 96.91371604800224, 89.36313360929489, 89.1998715698719, 83.14970701932907, 82.79548242688179, 75.62837541103363, 77.81658679246902, 80.78214526176453, 86.47778883576393, 88.2616639137268, 90.4575052857399, 88.36218371987343, 93.58441069722176, 83.17559123039246, 87.17299193143845, 85.5786506831646, 92.5905816257, 52.76026010513306, 25.82677334547043, 35.77587828040123, 51.240470856428146, 61.81143522262573, 81.78024530410767, 95.59719309210777, 93.12988668680191, 98.74878197908401, 97.97437593340874, 83.3411255478859, 74.02594059705734, 74.98506993055344, 83.30960243940353, 98.25991541147232, 95.25954321026802, 93.98071423172951, 104.80728328227997, 90.13862639665604, 77.3667973279953, 71.88094809651375, 76.2309242784977, 81.15275457501411, 77.34183266758919, 74.45907175540924, 75.89741617441177, 86.74095511436462, 94.12182345986366, 91.91519066691399, 94.36018466949463, 91.85734257102013, 97.93098226189613, 95.44759511947632, 95.76457411050797, 95.01760259270668, 88.47668677568436, 94.81906324625015, 85.06460666656494, 92.39236906170845, 95.99863395094872, 4.644932504743338, 0.01565830851177452, 0.13037798053119332, 0.11319259370793588, 0.09068223793292418, 0.07032468929537572, 0.06353478762321174, 0.07710331774433143, 5.962489480152726, 49.676201194524765, 91.93023785948753, 102.53850102424622, 107.16452479362488, 76.04379951953888, 71.3838055729866, 41.32000118494034, 29.87485572695732, 40.05702495574951, 70.95497578382492, 63.51054064929485, 78.54877710342407, 41.09052389860153, 0.6824286561459303, 0.0927604889147915, 0.039969220306375064, 0.019993172682006843, 0.048341481015086174, 0.05736601531680208, 0.02883206801925553, 0.014989807859819848, 0.09628088868339546, 0.03494740012683906, 0.08223172146244906, 0.028383554781612474, 0.05778654587629717, 0.018817762902472168, 0.020372721846797504, 0.06755816313670948, 0.045172981699579395, 0.011862436513183638, 0.006902975756020169, 0.07711070211371407, 0.04169801250100136, 0.018713296340138186, 0.022741642387700267, 0.02435637576127192, 0.04041972249979153, 0.05133157545060385, 0.019942213111789897, 0.03893085922754835, 0.03054665921808919, 0.029666624213859905, 0.02912086551077664, 0.0457158330391394, 0.020308618841227144, 0.03270234403316863, 0.027732900925911963, 0.06466963532147929, 0.04767310281749815, 0.025114364580076654, 0.0189690497063566, 0.04009172291262075, 0.02126693001628155, 0.056319401555811055, 0.051496417581802234, 0.023823218725738116, 0.0477455512736924, 0.07602900703204796, 0.07334637324674986, 0.04041918073198758, 0.0350529817660572, 0.03197673511749599, 0.03805188549449667, 0.06374437012709677, 0.30425881734117866, 0.38131838547997177, 33.543916046619415, 100.73790684342384, 129.38433408737183, 106.90559908747673, 99.17070373892784, 101.84153482317924, 88.44953343272209, 40.92955693602562, 29.430790655314922, 44.07948151230812, 66.58948883414268, 58.508815839886665, 47.94186785817146, 6.370010012760758, 0.6442119693383574, 0.11998297035461292, 0.2615918271476403, 0.05846473155543208, 1.056300331838429, 2.4255701573565602, 28.719187639653683, 3.5073072742670774, 7.227195566520095, 119.69549238681793, 100.48358649015427, 108.93375545740128, 81.70725882053375, 85.92600524425507, 83.6390295624733, 95.46243712306023, 89.11370739340782, 98.31124305725098, 99.79587659239769, 98.62192958593369, 95.67034676671028, 88.55736404657364, 78.59001249074936, 79.28757146000862, 73.42551961541176, 76.04345753788948, 78.1099234521389, 89.7529698908329, 96.03156298398972, 98.85310918092728, 94.79365020990372, 93.06978151202202, 87.12306261062622, 87.35215991735458, 79.25619274377823, 82.35934183001518, 83.51144000887871, 89.80644822120667, 91.54670163989067, 94.7415854036808, 91.44357517361641, 97.28355780243874, 87.14891642332077, 91.29712343215942, 89.8450617492199, 96.83303877711296, 60.72746358811855, 31.95436254143715, 38.62131379544735, 56.689298674464226, 66.48955419659615, 86.89070507884026, 100.68908706307411, 96.56718224287033, 102.20029637217522, 101.35118633508682, 87.64988154172897, 78.41146767139435, 76.54243916273117, 87.5793345272541, 99.65440258383751, 98.29911410808563, 96.76458925008774, 104.80432704091072, 95.38055151700974, 83.14148426055908, 76.23154744505882, 80.42340651154518, 83.7181869149208, 81.81590259075165, 77.60840356349945, 78.81382048130035, 88.91152784228325, 100.75546950101852, 97.19473376870155, 97.96833425760269, 92.7002665400505, 102.13943883776665, 97.5064006447792, 97.18863129615784, 96.04353994131088, 90.5344207584858, 97.7896298468113, 93.73183518648148, 92.86358937621117, 109.43575412034988, 11.095233634114265, 0.23272180755157024, 0.20091010752366856, 0.22291552828392014, 0.0419958994461922, 0.129921292536892, 0.07070597508572973, 0.11014912772225216, 5.981534533202648, 55.32344676554203, 100.40217205882072, 104.97097089886665, 108.00149068236351, 84.16684404015541, 52.02435739338398, 36.069393530488014, 44.47770394384861, 59.75777842104435, 89.4867941737175, 73.79116639494896, 90.96554562449455, 65.53781166672707, 2.0844038017094135, 0.061596435189130716, 0.054232489710557275, 0.08830053760902956, 0.029532414228015114, 0.03277851064922288, 0.05035465306718834, 0.006640229967160849, 0.0176907986678998, 0.04562170273857191, 0.00939441699301824, 0.07797912621754222, 0.047690417122794315, 0.025593847640266176, 0.03160196909448132, 0.03274731076089665, 0.088901276467368, 0.031751207570778206, 0.04386385917314328, 0.010621303990774322, 0.002747505377556081, 0.06836225787992589, 0.014658485306426883, 0.026862638151214924, 0.007053654462652048, 0.03270250730565749, 0.049317943266942166, 0.025761701035662554, 0.021136684954399243, 0.11753057304304093, 0.22096378379501402, 0.08776113725616597, 0.1306313497480005, 0.1333982840878889, 0.11313063179841265, 0.2059598732739687, 0.11430977829149924, 0.1730644001509063, 0.19554838741896674, 0.18616985238622874, 0.07525985260144807, 0.17863484186818823, 0.17200401955051348, 0.18393585429294035, 0.1997412694618106, 0.17348867113469169, 0.15371796092949808, 0.14270680490881205, 0.17244323738850653, 0.11042257203371264, 0.20655056345276535, 0.19725378340808675, 0.3858937555924058, 1.9399477844126523, 56.24612845480442, 127.70645052194595, 146.56035482883453, 118.70195969939232, 118.90169978141785, 110.51095202565193, 74.38267305493355, 45.83783715963364, 95.50304174423218, 152.35239923000336, 103.51488143205643, 67.67956674098969, 66.6386429965496, 9.635298773646355, 0.8855930669233203, 0.19915341428713873, 0.7096212438773364, 0.6312420777976513, 0.775977736338973, 0.6690029671881348, 34.18168142437935, 15.571953915059566, 5.609214836731553, 127.64180839061737, 103.2554617524147, 118.17998930811882, 86.40134453773499, 91.37938141822815, 85.7258851826191, 102.18944415450096, 92.94871240854263, 104.17263373732567, 103.01790609955788, 105.1052936911583, 99.20303240418434, 93.90094131231308, 82.4631978571415, 85.06168842315674, 79.02466356754303, 83.17698195576668, 83.7079730629921, 96.13355711102486, 99.47916358709335, 104.92764562368393, 99.66834783554077, 97.8451144695282, 91.86659887433052, 92.4821962416172, 86.02208688855171, 89.21119496226311, 88.0468462407589, 95.56220456957817, 95.4237399995327, 100.12916430830956, 98.00911366939545, 105.36763161420822, 91.77197635173798, 98.04993107914925, 96.28805682063103, 102.37733647227287, 65.54779753088951, 38.219751343131065, 49.8635995388031, 69.08772557973862, 73.90044093132019, 93.08792173862457, 106.06170237064362, 100.11455029249191, 109.4367952644825, 106.68202668428421, 90.38008823990822, 83.03364604711533, 82.73935943841934, 93.09691205620766, 106.28951534628868, 101.86709985136986, 100.4551412165165, 108.63821491599083, 100.13110220432281, 86.22252613306046, 82.3131363093853, 86.04567602276802, 88.77253130078316, 85.83040237426758, 81.5569768846035, 83.65029975771904, 95.49016803503036, 104.0748193860054, 101.83263570070267, 99.44073244929314, 99.48552444577217, 108.87950196862221, 103.8615520298481, 103.49752396345139, 100.92827662825584, 96.0999745130539, 104.38074097037315, 94.7801761329174, 102.23678961396217, 111.94959282875061, 8.259140867739916, 0.7196802541147918, 0.5571959854569286, 0.49319026060402393, 0.20246662868885323, 0.38007074617780745, 0.21709683816879988, 0.2209286208380945, 12.173623368144035, 73.80970180034637, 108.62756788730621, 111.65307953953743, 110.02559646964073, 89.55091953277588, 99.29746493697166, 56.90126270055771, 39.711319506168365, 53.99221859872341, 93.85229632258415, 82.07066372036934, 106.49375438690186, 75.61888352036476, 2.6073820888996124, 0.2651535125914961, 0.16882220981642604, 0.13725527009228244, 0.172279846156016, 0.1402528045582585, 0.11569333451916464, 0.07449673183145933, 0.2993459184654057, 0.12889272038592026, 0.12922459398396313, 0.13970380823593587, 0.19882974884239957, 0.10594466075417586, 0.10880073445150629, 0.10582850722130388, 0.17410018597729504, 0.14754019008250907, 0.1094263352570124, 0.15590584196615964, 0.09576037598890252, 0.18670811725314707, 0.12145633387262933, 0.18063473689835519, 0.1312837569275871, 0.2026080375071615, 0.14932443184079602, 0.13896891876356676, 0.09629631051211618], [0.08250338461948559, 0.021972411886963528, 0.015176476554188412, 0.023474101326428354, 0.015992887238098774, 0.0405311856593471, 0.0713492241629865, 0.022462088345491793, 0.037110152043169364, 0.08703547267941758, 0.038725881749996915, 0.046893346807337366, 0.0030654405145469354, 0.046367457252927125, 0.06426762134651653, 0.02513061019271845, 0.03849374166748021, 0.09499318082816899, 0.020177496189717203, 0.017602295702090487, 0.05281245321384631, 0.055100127137848176, 0.26973781816195697, 12.820303067564964, 87.14738130569458, 114.81082409620285, 99.94062602519989, 95.6100744009018, 92.16471567749977, 99.52967807650566, 55.08456498384476, 36.8268258869648, 85.072031468153, 120.1737879216671, 71.09496027231216, 59.10274296998978, 39.788770750164986, 5.227379500865936, 0.5535773327574134, 0.11384115656255744, 0.4904004681156948, 0.030084787322266493, 0.17579955572728068, 0.1758954263641499, 16.461258195340633, 78.76475751399994, 3.174236146733165, 35.36781817674637, 125.83372861146927, 94.45261850953102, 94.30216178297997, 93.00172716379166, 96.56891494989395, 94.77230295538902, 92.9371990263462, 93.09200271964073, 94.27033469080925, 94.59574162960052, 96.72095239162445, 94.35207590460777, 88.43970715999603, 83.71270000934601, 75.72515621781349, 72.76804849505424, 73.57232853770256, 72.29106768965721, 74.2284469306469, 78.29400837421417, 85.45273303985596, 82.67276421189308, 81.13940969109535, 78.45325022935867, 76.02541610598564, 73.47747802734375, 74.62920382618904, 80.08439630270004, 85.68902716040611, 92.28560999035835, 92.03202679753304, 90.24151727557182, 94.6459673345089, 91.75030991435051, 88.1008717417717, 88.10068935155869, 90.48354908823967, 92.71641567349434, 89.66563537716866, 52.47942477464676, 30.186230018734932, 61.793644577264786, 91.88002735376358, 88.91232579946518, 92.71041199564934, 97.70538076758385, 92.29742735624313, 86.95427566766739, 71.33162677288055, 69.2673647403717, 78.24808403849602, 88.15389409661293, 95.86196288466454, 92.19564601778984, 99.35262277722359, 95.04392758011818, 83.26897501945496, 71.67439877986908, 70.57291388511658, 72.88592576980591, 76.31525695323944, 74.10057619214058, 70.37807554006577, 78.98709878325462, 93.09524774551392, 89.72919836640358, 92.40920215845108, 88.67229267954826, 88.94187301397324, 86.24894991517067, 87.34031975269318, 84.09648701548576, 90.6273865699768, 79.63858902454376, 91.84343531727791, 89.6533240377903, 99.58968445658684, 67.96783447265625, 0.5435450992081314, 0.2662398386746645, 0.04385250431369059, 0.08908166288165376, 0.0709749294037465, 0.13056691648671404, 0.006122208105807658, 0.170254465774633, 3.1423207093030214, 44.05160240828991, 78.1193545460701, 87.2030483186245, 45.25230757892132, 75.0444607436657, 64.88442912697792, 24.32715341448784, 24.806925170123577, 41.13934367895126, 62.788290604949, 71.85281440615654, 85.35522267222404, 53.818830102682114, 3.244351171888411, 0.12882533337688074, 0.16287604841636494, 0.03847907682938967, 0.006790981960875797, 0.02608994924230501, 0.087074420589488, 0.08197562114219181, 0.017351123242406175, 0.07504754641558975, 0.039702099093119614, 0.05811934715893585, 0.03190707342582755, 0.02722903274843702, 0.05292771616950631, 0.030289909518614877, 0.08409008150920272, 0.06731910252710804, 0.034869615628849715, 0.08842386028845794, 0.04398731543915346, 0.03479144521406852, 0.08497051356243901, 0.054948773540672846, 0.07283734157681465, 0.028253775417397264, 0.05729179312766064, 0.019446792430244386, 0.010746138796093874, 0.009665535599197028, 0.07085304649081081, 0.013363090656639542, 0.03787352514336817, 0.01636966448131716, 0.02394243547314545, 0.050971195960300975, 0.0410847944294801, 0.050282056181458756, 0.04844059483730234, 0.06278690314502455, 0.010398393442301312, 0.005756036152888555, 0.06437371135689318, 0.03145340597257018, 0.047856873425189406, 0.035680400833371095, 0.019399970333324745, 0.07497061538742855, 0.04586605115036946, 0.07104747433913872, 0.47042669146321714, 13.503248021006584, 99.26034092903137, 131.5175700187683, 111.09017014503479, 114.90573540329933, 116.89385712146759, 117.90413171052933, 87.62607961893082, 52.515728026628494, 39.124099016189575, 88.91082867980003, 77.20664352178574, 67.95795500278473, 50.56670621037483, 6.209138995036483, 0.7383314345497638, 0.08840477225021459, 0.9793381334748119, 0.013472815335262567, 0.5906601960305125, 0.956283820560202, 17.14519489556551, 57.02694475650787, 2.468701167963445, 41.7012233287096, 129.78145837783813, 101.71247094869614, 100.72484314441681, 99.39140349626541, 102.8465960919857, 97.26820662617683, 96.49725839495659, 98.18751409649849, 100.13216614723206, 98.7860655784607, 101.63652062416077, 98.32845613360405, 93.96228522062302, 88.35694760084152, 79.01258781552315, 76.7671287059784, 78.57017755508423, 76.31249830126762, 77.44933649897575, 80.5876336991787, 87.17942118644714, 86.84809416532516, 85.40802463889122, 82.77745619416237, 79.35274556279182, 77.60949030518532, 76.06214493513107, 83.25648128986359, 91.49206057190895, 96.91483318805695, 96.8690912425518, 96.40526533126831, 98.91819968819618, 96.97774261236191, 92.44363591074944, 93.1580051779747, 95.34104123711586, 99.5034746825695, 96.42221242189407, 61.17053501307964, 37.949779629707336, 67.49182641506195, 96.31602331995964, 92.29849129915237, 96.08741998672485, 99.7918564081192, 96.78958430886269, 91.88375115394592, 74.7907255589962, 74.58158478140831, 79.13429528474808, 90.60471698641777, 99.27304744720459, 95.03445088863373, 100.84297120571136, 99.0410166978836, 87.78272241353989, 76.14887908101082, 74.55266073346138, 76.40496253967285, 78.61166372895241, 78.89487773180008, 73.32411825656891, 82.74068176746368, 95.70845112204552, 93.47242310643196, 94.43925082683563, 94.54904973506927, 90.47699823975563, 87.56215184926987, 90.25586530566216, 89.16938200592995, 92.78791263699532, 85.61296284198761, 91.2513054907322, 97.47755259275436, 98.64965289831161, 84.81426849961281, 2.8998728189617395, 0.337397403200157, 0.1748985587619245, 0.4199131519999355, 0.10171056725084782, 0.16582093492615968, 0.010585377549432451, 0.27111663948744535, 3.0843612318858504, 47.44416296482086, 87.34320759773254, 99.66471523046494, 54.48488116264343, 51.63321778178215, 36.81899070739746, 28.672353252768517, 41.08889378607273, 65.9879583120346, 83.83779689669609, 81.02378949522972, 93.05550187826157, 78.59790846705437, 3.4500647708773613, 0.1357696537161246, 0.031141202998696826, 0.055377311873598956, 0.011374349178367993, 0.04094182339031249, 0.027566529970499687, 0.06931823314516805, 0.05257276920019649, 0.06863086338853464, 0.005252115097391652, 0.009997328488680068, 0.04720428441942204, 0.005358214848456555, 0.04998307456844486, 0.07368236576439813, 0.02253642556752311, 0.0049169607427757, 0.07486623973818496, 0.05612796827335842, 0.03139540342090186, 0.06478768875240348, 0.027486506041896064, 0.06716760050039738, 0.04480581897951197, 0.039520232094218954, 0.023946086839714553, 0.013618485936603975, 0.2929817349649966, 0.10845115320989862, 0.10566731274593621, 0.07000558805884793, 0.10677199956262484, 0.15252979734214023, 0.15631295449566096, 0.18666762567590922, 0.12170061920187436, 0.16313067928422242, 0.15630167385097593, 0.13082536199362949, 0.1424621485057287, 0.16861969255842268, 0.1356787554686889, 0.14006800978677347, 0.13488082797266543, 0.15434804430697113, 0.09663239950896241, 0.14099259220529348, 0.17670081986580044, 0.1317585978540592, 0.6246485409792513, 20.984064303338528, 125.72126224637032, 147.68000274896622, 125.04293784499168, 122.09516242146492, 117.91787177324295, 120.59643164277077, 72.47076004743576, 49.44873780012131, 122.34286352992058, 187.90707617998123, 105.41208922863007, 74.9945542216301, 67.8380486369133, 9.248629622161388, 1.058676391839981, 0.31302352203056216, 1.3107787328772247, 0.22845100000267848, 0.7055400847457349, 0.36750577040947974, 26.4779919013381, 100.05489349365234, 4.15320516563952, 42.92810149490833, 134.90300595760345, 106.90620705485344, 105.99983409047127, 105.35722777247429, 108.35674121975899, 105.15643894672394, 102.24894136190414, 103.73272374272346, 107.11525663733482, 104.11058306694031, 106.96978524327278, 104.09684300422668, 98.93178015947342, 93.89044627547264, 83.04680854082108, 81.23177513480186, 82.0307582616806, 78.13735038042068, 82.30681344866753, 85.87341606616974, 93.35811004042625, 92.11094096302986, 91.27298712730408, 87.75619983673096, 84.76693823933601, 84.2661327123642, 80.19559353590012, 87.436044216156, 94.94289860129356, 98.98113191127777, 101.85693919658661, 100.56106433272362, 102.47174620628357, 99.83110070228577, 94.32702764868736, 96.81968629360199, 97.65137806534767, 103.0025777220726, 94.78595182299614, 61.59795507788658, 46.89465545117855, 76.6860942542553, 100.40205806493759, 97.06893011927605, 100.14693215489388, 104.50754776597023, 102.15156018733978, 97.63301745057106, 79.06977474689484, 79.50780764222145, 86.29178881645203, 96.54234677553177, 103.79010066390038, 100.27047112584114, 105.34721910953522, 101.87586978077888, 90.98667249083519, 77.31746077537537, 76.68457433581352, 79.77019876241684, 83.65497350692749, 84.01331707835197, 77.15726137161255, 86.40210449695587, 102.58960828185081, 98.57935667037964, 100.4183591902256, 97.33512863516808, 96.50567874312401, 92.97388225793839, 94.12938505411148, 94.78355795145035, 99.6302130818367, 89.95580300688744, 100.3329549729824, 102.3919428884983, 107.25738421082497, 83.49369496107101, 2.2536239214241505, 1.2435120111331344, 0.37612243148032576, 0.3103808232117444, 0.2251868712482974, 0.2196740944054909, 0.14390037133125588, 0.47240074491128325, 7.56516938097775, 62.406931668519974, 93.99705335497856, 103.09191852807999, 64.81921702623367, 102.69522741436958, 84.0096540749073, 35.980383306741714, 36.42819307744503, 56.33892707526684, 84.01224553585052, 90.71300357580185, 109.70552444458008, 92.58513271808624, 5.40845213457942, 0.2105965744704008, 0.18080431764246896, 0.25608149939216673, 0.1009267479821574, 0.14340577443363145, 0.17509788478491828, 0.1723925635451451, 0.17047849047230557, 0.15104631835129112, 0.0968668884888757, 0.17306319787167013, 0.1685223079402931, 0.10943002373096533, 0.13198631844716147, 0.07700127986026928, 0.1098698130226694, 0.28108359372708946, 0.11448460601968691, 0.20119745226111263, 0.2154974060249515, 0.217124164046254, 0.14811900589847937, 0.18920685426564887, 0.13801034598145634, 0.09726596355903894, 0.1918028126237914, 0.06356075537041761], [0.05951056977210101, 0.020039501250721514, 0.012604869916685857, 0.03206026383850258, 0.013682231783604948, 0.009704120784590486, 0.053760402151965536, 0.016203195191337727, 0.0551494094543159, 0.0320904247200815, 0.0565048791031586, 0.044260221693548374, 0.05476965619891416, 0.039283420192077756, 0.032956574141280726, 0.07954536951729096, 0.04625533729267772, 0.0089885707529902, 0.0359794677933678, 0.0230546023522038, 0.05748379044234753, 0.25856609106995165, 9.723004717379808, 112.96809777617455, 107.84110128879547, 97.06804856657982, 84.67459559440613, 76.76576837897301, 41.42202951014042, 69.29746672511101, 52.060497254133224, 68.87639611959457, 99.21408981084824, 80.4599529504776, 75.79619720578194, 45.979318767786026, 4.867992410436273, 0.7064604666084051, 0.07243850399390794, 0.28179044486023486, 0.03618406306486577, 0.327918604016304, 0.04366036970168352, 2.8338542114943266, 26.380941309034824, 7.611819477751851, 2.4743334157392383, 93.37619706988335, 99.8445063829422, 111.91628381609917, 104.59170565009117, 101.35687083005905, 96.72105118632317, 103.35472762584686, 98.59546020627022, 100.62153428792953, 95.7363112270832, 99.8245270550251, 92.5374148786068, 95.52292987704277, 95.01846894621849, 93.54610875248909, 80.85565611720085, 72.22198739647865, 67.81307637691498, 70.26418045163155, 69.65808257460594, 73.98117899894714, 77.84500926733017, 82.97224894165993, 82.05108717083931, 80.23989155888557, 71.69685557484627, 71.31135106086731, 79.02540072798729, 84.20241013169289, 89.37899395823479, 91.42293468117714, 89.2255049943924, 91.21417388319969, 92.2847892343998, 93.92130061984062, 88.79389375448227, 91.00083813071251, 85.06013050675392, 91.3019947707653, 88.11385184526443, 101.19135931134224, 46.07616417109966, 54.41969946026802, 94.48138296604156, 83.44423681497574, 93.19401204586029, 93.15091475844383, 93.11284840106964, 80.60382843017578, 72.31982454657555, 71.0415731370449, 74.89306926727295, 77.81910225749016, 92.39133551716805, 90.80169841647148, 88.92065495252609, 91.80200234055519, 85.03721013665199, 78.94920721650124, 72.59777963161469, 74.75451350212097, 71.25737115740776, 70.89088082313538, 69.57506462931633, 75.42884811758995, 83.28626409173012, 89.62937012314796, 83.26491683721542, 85.6682650744915, 79.43463116884232, 82.07191005349159, 77.75726437568665, 81.89882174134254, 74.88838031888008, 84.36087682843208, 74.42076981067657, 88.39883655309677, 87.92772263288498, 99.76428508758545, 53.20018529891968, 0.5174030957277864, 0.33891462022438645, 0.2797756326617673, 0.12978798797121271, 0.09068747749552131, 0.061549097299575806, 0.028733980216202326, 0.18285485683009028, 5.781813450157642, 46.57788924872875, 84.52040746808052, 82.99006998538971, 60.32296009361744, 74.91595163941383, 51.65000148117542, 30.637393109500408, 30.860197953879833, 38.28797288239002, 56.67294055223465, 69.01124328374863, 89.13497105240822, 45.20683541893959, 2.0071518095210195, 0.1599522092146799, 0.04347157846495975, 0.077720895933453, 0.02573816011135932, 0.04097891222045291, 0.07701692433329299, 0.08551307546440512, 0.11035793839255348, 0.05166908937098924, 0.03138095009489916, 0.045785557813360356, 0.08155774004990235, 0.030766917516302783, 0.01388470729580149, 0.052862377488054335, 0.04656552533560898, 0.014621256395912496, 0.020445218542590737, 0.020420508735696785, 0.022855100069136824, 0.036706115715787746, 0.04649867638363503, 0.04951216702465899, 0.043157334584975615, 0.039252825154107995, 0.04074394455528818, 0.049833557786769234, 0.04852388236031402, 0.026474622936802916, 0.05869571017683484, 0.017033658441505395, 0.056802346734912135, 0.07389391495962627, 0.00901079343748279, 0.013166076423658524, 0.01268790603717207, 0.03967543743783608, 0.020599705858330708, 0.017107491003116593, 0.04998084441467654, 0.048075543527374975, 0.052508647640934214, 0.01620254395675147, 0.04623844972229563, 0.05320167627360206, 0.0087705491023371, 0.02088196502882056, 0.3076072986004874, 12.070936728268862, 133.86403530836105, 120.55201202630997, 107.93843686580658, 98.38276281952858, 105.18475502729416, 58.791068494319916, 79.20744135975838, 63.79916176199913, 30.21671388298273, 78.26683223247528, 91.86861276626587, 86.21807277202606, 59.58421893417835, 6.169994445517659, 0.7640875212382525, 0.1727692034910433, 0.593011676101014, 0.29946415743324906, 0.8551906608045101, 0.7577111071441323, 1.7954451008699834, 11.776834409683943, 4.281254494562745, 4.131798539310694, 98.40676993131638, 100.1099069416523, 115.01516193151474, 110.0630396604538, 107.10625872015953, 102.37147718667984, 107.92083621025085, 105.21367147564888, 105.52897855639458, 100.72713062167168, 103.14462929964066, 97.11852505803108, 101.28763854503632, 99.91580575704575, 96.34284988045692, 84.91234883666039, 76.74311399459839, 71.07203230261803, 74.04623910784721, 73.38461861014366, 76.97460517287254, 81.75770491361618, 86.5220108628273, 86.85133159160614, 84.26597312092781, 76.8480035662651, 75.32937705516815, 80.69864094257355, 86.18159472942352, 92.7236732840538, 93.75126734375954, 93.80512565374374, 93.69457438588142, 94.53040793538094, 96.14192426204681, 92.81830340623856, 96.05474174022675, 90.75616925954819, 94.49314713478088, 89.60296154022217, 102.34547898173332, 52.66449764370918, 59.78527754545212, 96.69908076524734, 86.46170809864998, 97.40235462784767, 98.83903473615646, 98.60182106494904, 86.87575668096542, 74.7292372584343, 75.9370556473732, 77.8027631342411, 82.32150346040726, 93.86933460831642, 94.4178731739521, 91.29156053066254, 96.64065510034561, 88.16606864333153, 84.15495827794075, 77.46557682752609, 77.55593597888947, 75.45698940753937, 73.521076887846, 73.13557997345924, 79.32297796010971, 88.33595752716064, 94.13216650485992, 88.79515528678894, 89.84102636575699, 84.58344608545303, 84.79248806834221, 82.42420434951782, 83.75183790922165, 77.04328268766403, 85.78544318675995, 78.48367139697075, 90.85948571562767, 91.73734501004219, 101.86700865626335, 69.30327281355858, 1.6168049303814769, 0.5631042527966201, 0.26797964063007385, 0.5801763804629445, 0.09479989588726312, 0.018282689270563424, 0.027448244618426543, 0.2622628177050501, 5.917872274294496, 53.034605383872986, 89.13541942834854, 90.64008548855782, 67.8341044485569, 49.66021165251732, 31.011756621301174, 34.21556420624256, 54.005658477544785, 53.24063032865524, 69.22055125236511, 79.03277233242989, 97.99332931637764, 69.57937359809875, 2.5771506736055017, 0.03454351593973115, 0.0035388551259529777, 0.050495226969360374, 0.0884191328077577, 0.10363244771724567, 0.027840295260830317, 0.02666889864485711, 0.025332587538287044, 0.0695421094133053, 0.04345484674558975, 0.07296018186025321, 0.06370491013512947, 0.009972702173399739, 0.07157130443374626, 0.04118025317438878, 0.00382107208679372, 0.014121575786703033, 0.0456748219585279, 0.05836026684846729, 0.05417692140326835, 0.01911658309836639, 0.03315255307825282, 0.1247685166890733, 0.010531890038691927, 0.025887398587656207, 0.01762271589541342, 0.18183321633841842, 0.19997056340798736, 0.08620081629487686, 0.2067976541002281, 0.0928259982902091, 0.10330832214094698, 0.12647863273741677, 0.10478906260686927, 0.11034351104171947, 0.17803811060730368, 0.13080429984256625, 0.08422403174336068, 0.12409400835167617, 0.11399228751542978, 0.16588864848017693, 0.16822139674331993, 0.1830502791563049, 0.10608098586089909, 0.12246074169524945, 0.11847707108245231, 0.10656463608029298, 0.4707481007790193, 19.602082259953022, 159.38206762075424, 128.87602776288986, 123.10200199484825, 111.05691432952881, 105.86152911186218, 57.198372557759285, 87.8903478384018, 65.82139804959297, 96.3865627348423, 151.8630614876747, 95.48142850399017, 100.97458094358444, 76.85947135090828, 11.39144103974104, 1.300458605401218, 0.4875450400868431, 0.754530974663794, 0.6145181064493954, 1.3732625800184906, 0.49724021984729916, 5.522034214809537, 41.48328982293606, 12.810881473124027, 4.120546393096447, 98.7270699441433, 102.23548248410225, 120.32828003168106, 112.21812441945076, 111.6678075492382, 103.37992787361145, 112.7135494351387, 112.12170079350471, 111.1533835530281, 104.1116090118885, 108.20735603570938, 101.37624219059944, 104.85054776072502, 103.9013434946537, 101.4510677754879, 88.61353263258934, 81.28076210618019, 75.39914131164551, 76.80498227477074, 76.2347012758255, 80.7303236424923, 85.88682934641838, 91.23934373259544, 93.57333809137344, 90.10409384965897, 82.52988427877426, 79.90390598773956, 85.1460362970829, 92.29094490408897, 98.10409337282181, 98.0416551232338, 98.71537417173386, 97.25654885172844, 101.36790543794632, 100.98768264055252, 101.29504814743996, 100.39345532655716, 94.81555223464966, 101.8616509437561, 97.30442628264427, 103.15592989325523, 58.41719515621662, 67.91125550866127, 103.41545596718788, 93.72429639101028, 101.5730108320713, 102.495958507061, 102.19941481947899, 92.80304342508316, 78.99459958076477, 81.02645695209503, 82.67278701066971, 86.59951910376549, 98.65629494190216, 97.33704373240471, 99.08138573169708, 100.59606805443764, 91.02533161640167, 87.27678716182709, 82.19550222158432, 82.68489316105843, 79.39272701740265, 77.64718428254128, 77.15831771492958, 84.75721076130867, 94.28437873721123, 99.62418660521507, 92.72523120045662, 94.22165930271149, 90.76553955674171, 92.18947514891624, 86.07178062200546, 90.4877744615078, 82.59005784988403, 92.97814562916756, 83.58690395951271, 98.50673496723175, 97.5777380168438, 109.14436295628548, 66.70228958129883, 1.6704781190492213, 2.5999278388917446, 0.5719983286689967, 0.5103820224758238, 0.27203188568819314, 0.19547579053323716, 0.2121022585197352, 0.4552216886077076, 12.718153148889542, 71.79134130477905, 101.36320129036903, 99.49886932969093, 83.42402949929237, 102.03274056315422, 65.78222215175629, 43.51688750088215, 43.151829689741135, 50.37667840719223, 78.63065510988235, 91.10771879553795, 112.26207286119461, 85.33077478408813, 2.966026794165373, 0.1477258902741596, 0.1158335039508529, 0.1810920482967049, 0.13098832278046757, 0.12258083603228442, 0.12923085771035403, 0.18898726761108264, 0.12048187913023867, 0.16552904824493453, 0.09776368489838205, 0.11774569939007051, 0.1354038788122125, 0.06824646799941547, 0.05852578062331304, 0.21807717072078958, 0.13768095115665346, 0.07211572170490399, 0.15484664880204946, 0.09796839891350828, 0.1761076954426244, 0.16927512770053, 0.10559510919847526, 0.3276854509022087, 0.18704953487031162, 0.1412546742358245, 0.13819453219184652], [0.0175073026548489, 0.08039337713853456, 0.020351917592051905, 0.03943732677726075, 0.08852158629451878, 0.06605735499761067, 0.06199926923727617, 0.033675310769467615, 0.05018368079618085, 0.012980092360521667, 0.04966424050508067, 0.03931772596843075, 0.030434754480666015, 0.040607363407616504, 0.06247336801607162, 0.026829093076230492, 0.027992691575491335, 0.011745322826755, 0.043519257742445916, 0.07545759784989059, 0.06985608983086422, 5.608626343309879, 108.62319812178612, 105.89808315038681, 104.84026551246643, 98.19495409727097, 88.35919708013535, 59.161560013890266, 75.62268331646919, 171.23220294713974, 155.70039957761765, 115.75972437858582, 104.55857142806053, 98.97810727357864, 41.564305275678635, 6.537912078201771, 0.4362566687632352, 0.06469315398135222, 0.16745297703891993, 0.37460515508428216, 0.5770896992180496, 0.1411615643883124, 0.3985178063157946, 6.870982255786657, 2.111183339729905, 3.836284358985722, 82.71843776106834, 102.12255254387856, 102.15965375304222, 99.80457052588463, 97.91041776537895, 103.78340542316437, 103.7960435450077, 100.90393513441086, 98.83407220244408, 101.33275732398033, 96.63858041167259, 92.60923862457275, 95.84120079874992, 94.79170471429825, 91.78285896778107, 90.16900956630707, 89.06204536557198, 78.33375424146652, 70.29608353972435, 71.29879653453827, 70.99247977137566, 71.70626387000084, 78.65600734949112, 81.65264055132866, 76.28044322133064, 71.81439846754074, 69.85683470964432, 71.42409861087799, 74.45258930325508, 83.67454245686531, 89.52822715044022, 88.3371202647686, 92.90826737880707, 91.7870919406414, 87.0567561686039, 87.8728611767292, 85.95573484897614, 91.26332804560661, 90.88391080498695, 89.02708724141121, 86.19284972548485, 90.22630289196968, 77.29832500219345, 57.34754495322704, 91.06491789221764, 79.93108972907066, 88.82499128580093, 92.50421985983849, 94.41069915890694, 85.4989917576313, 72.88078084588051, 66.00634172558784, 68.2840459048748, 73.00796002149582, 82.14824795722961, 88.48742499947548, 85.05927935242653, 92.37977653741837, 88.96056801080704, 81.99878677725792, 80.19959092140198, 75.611033141613, 73.37431356310844, 69.9152147769928, 68.3917473256588, 70.03164052963257, 77.26768344640732, 81.07306525111198, 82.81996831297874, 82.85132423043251, 80.11633738875389, 75.2950268983841, 77.528957426548, 73.87473151087761, 80.72863653302193, 71.62953838706017, 76.33071452379227, 75.55523693561554, 90.6739492714405, 86.76737889647484, 110.24968564510345, 35.15824422240257, 1.127280998043716, 0.3008194378344342, 0.3932024259120226, 0.23905957059469074, 0.07643710661795922, 0.1449931986280717, 0.08177974610589445, 0.22665393393253908, 11.132066957652569, 40.20550198853016, 85.20374000072479, 90.07846042513847, 83.18797096610069, 80.02746775746346, 51.11563615500927, 26.373326517641544, 26.702565550804138, 45.41801668703556, 83.77814769744873, 74.04686227440834, 77.50447154045105, 24.769388884305954, 0.9760932857170701, 0.08438227989245206, 0.08791744097834453, 0.02862806461052969, 0.14669513620901853, 0.02717670391575666, 0.02325873007066548, 0.04111031688807998, 0.04719277370895725, 0.05116866661410313, 0.08068046954576857, 0.05366765966755338, 0.027307542695780285, 0.017162484145956114, 0.03971744670707267, 0.0341481627401663, 0.026974496504408307, 0.046311870391946286, 0.040311817938345484, 0.026357868264312856, 0.04279756365576759, 0.04449646956345532, 0.11329673929139972, 0.036911761126248166, 0.01300647292737267, 0.010746545121946838, 0.04379965226689819, 0.04348128575657029, 0.019683956852531992, 0.025490807856840547, 0.10646144044585526, 0.007350369742198382, 0.03776058510993607, 0.06136636569863185, 0.029560851471615024, 0.01030054869261221, 0.04610039170074742, 0.06488233484560624, 0.058603190336725675, 0.023237532477651257, 0.034120903656003065, 0.03956214859499596, 0.05174335608899128, 0.0025383426509506535, 0.061898270359961316, 0.009052254445123253, 0.19416447496041656, 8.526882100850344, 127.25464716553688, 118.94529864192009, 117.76361525058746, 119.70551624894142, 103.10932159423828, 78.00317198038101, 66.03905037045479, 152.29243844747543, 109.02091518044472, 73.00096079707146, 115.17963230609894, 107.05243080854416, 56.28292188048363, 7.166623966768384, 0.3657752007711679, 0.13519868982257321, 0.4718915722332895, 0.22649477294180542, 1.1080482113175094, 0.5858951923437417, 0.8758250973187387, 3.4156694915145636, 0.9904084238223732, 8.86368652805686, 92.77950748801231, 105.25359213352203, 103.5525906085968, 101.29051879048347, 99.3838495016098, 109.06633794307709, 106.45121946930885, 103.16432744264603, 101.33683830499649, 107.6613937318325, 103.64355772733688, 97.39401787519455, 100.92367127537727, 97.85845935344696, 96.6696247458458, 95.89761257171631, 93.24934467673302, 82.84567773342133, 74.59050670266151, 74.7980135679245, 73.97389099001884, 76.0650023818016, 82.92681857943535, 83.74208003282547, 80.09586408734322, 77.44246646761894, 73.17458108067513, 75.61493933200836, 79.61636781692505, 88.25129806995392, 93.74255821108818, 92.87487477064133, 95.27562394738197, 95.22126406431198, 94.23159196972847, 91.5076245367527, 89.44618195295334, 96.89727053046227, 93.59563529491425, 96.36356636881828, 94.24935221672058, 93.17459508776665, 82.1036459505558, 64.44873690605164, 96.40347182750702, 82.19006091356277, 92.59163036942482, 94.8917305469513, 98.34911942481995, 91.26442238688469, 77.07162156701088, 68.70092913508415, 72.59677648544312, 76.99159786105156, 85.22659957408905, 92.34292611479759, 89.39571306109428, 96.339141279459, 95.31163841485977, 86.23305916786194, 85.47886803746223, 78.52446600794792, 77.50885650515556, 73.87859970331192, 71.6540090739727, 71.60906508564949, 81.14460781216621, 83.97899731993675, 86.64293557405472, 86.16198018193245, 83.98680970072746, 78.72217699885368, 81.88692077994347, 78.56602817773819, 84.87172141671181, 74.88172307610512, 79.85928118228912, 76.42839208245277, 94.48446080088615, 89.40803200006485, 112.4881075322628, 50.05170464515686, 0.8705296064727008, 0.3269196435576305, 0.5674090655520558, 0.3022450738353655, 0.18530712055508047, 0.14042575465282425, 0.08728181375772692, 0.4377079237019643, 12.274755891412497, 46.98278792202473, 88.05472701787949, 98.4119376540184, 75.74255168437958, 39.96921546757221, 23.906664177775383, 29.934096448123455, 43.79256650805473, 64.71074044704437, 93.2070605456829, 85.06275996565819, 92.58374959230423, 40.496600568294525, 0.8088559471070766, 0.04617115919245407, 0.07640483803697862, 0.013965553152957, 0.09626951898098923, 0.02948000190372113, 0.04514435706369113, 0.01351393588265637, 0.07074186534737237, 0.04034519974084105, 0.04735711860121228, 0.061227431942825206, 0.03790473987464793, 0.03325147394207306, 0.05114642815897241, 0.050143322805524804, 0.0193504932030919, 0.021691872643714305, 0.05410858444520272, 0.04675377109379042, 0.04344128399679903, 0.06766451289877295, 0.0855026334465947, 0.008246751476690406, 0.024117350403685123, 0.04357141588116065, 0.1323217395110987, 0.12750649242661893, 0.2511079818941653, 0.17227325588464737, 0.1986749962088652, 0.18542089179391041, 0.15575396886561066, 0.23874239152064547, 0.14384425012394786, 0.1140597413177602, 0.11829065100755543, 0.1947767913225107, 0.11631106855929829, 0.24965162097942084, 0.09919874617480673, 0.22741583758033812, 0.15863204724155366, 0.15370348904980347, 0.23520286660641432, 0.17140892101451755, 0.5158116936217993, 12.018449194729328, 153.85632812976837, 130.0134739279747, 135.62749028205872, 126.28293290734291, 113.6926580965519, 78.12363311648369, 88.4454296529293, 170.27576386928558, 173.55945646762848, 168.95925611257553, 121.76261186599731, 128.76872152090073, 76.933833360672, 12.322288490831852, 0.6126069871243089, 0.42761005461215973, 0.5985552817583084, 0.9618268324993551, 2.2821226296946406, 0.5885013181250542, 2.2112951427698135, 17.0456288382411, 9.688885398209095, 6.178585784509778, 93.28944772481918, 107.00034320354462, 102.74381160736084, 103.59017819166183, 101.11154839396477, 111.45253390073776, 109.99372377991676, 109.12657231092453, 103.34092676639557, 109.02709364891052, 107.00708404183388, 100.17264917492867, 105.46014904975891, 101.11883640289307, 99.93105053901672, 100.24791553616524, 99.29763972759247, 87.03057557344437, 76.4832155406475, 79.54351052641869, 77.62035012245178, 80.53002119064331, 86.66399404406548, 90.48332870006561, 86.97295546531677, 81.3935324549675, 78.09291556477547, 78.96683067083359, 82.10940644145012, 91.42078399658203, 99.24314305186272, 97.6225908100605, 98.9424803853035, 99.51388612389565, 96.62042498588562, 93.57969895005226, 92.47049286961555, 100.32519578933716, 98.85213643312454, 98.08045864105225, 97.4538342654705, 99.98820707201958, 83.52256581187248, 71.60665601491928, 99.52520191669464, 85.91424107551575, 97.14834585785866, 100.17976999282837, 102.1847628057003, 98.96953493356705, 78.79025414586067, 74.08483743667603, 76.28178834915161, 81.00935027003288, 92.88444265723228, 98.08236613869667, 92.50392347574234, 98.8134241104126, 97.85423398017883, 90.60486897826195, 87.26069882512093, 82.17728599905968, 82.88790866732597, 79.43926692008972, 77.66771838068962, 77.49218299984932, 83.82874578237534, 88.61689925193787, 92.57093667984009, 91.83901995420456, 88.62192258238792, 83.98025885224342, 86.22697949409485, 84.00507912039757, 89.98902842402458, 80.62320739030838, 86.01842388510704, 82.97152698040009, 101.6286550462246, 96.54070526361465, 119.83571246266365, 47.929529920220375, 2.5571644585579634, 2.0729661779478192, 0.5687468312680721, 0.5404366878792644, 0.40016991610173136, 0.1727985480101779, 0.22026497754268348, 0.5627788358833641, 19.60603404790163, 58.300370424985886, 102.7673627436161, 105.89452654123306, 111.29679545760155, 107.59209305047989, 66.11490949988365, 34.635038897395134, 41.250461116433144, 64.21883404254913, 105.8177250623703, 95.1812294125557, 108.31924483180046, 54.202947691082954, 1.1389442346990108, 0.20681876078015193, 0.24158503976650536, 0.10313005826901644, 0.19023968634428456, 0.14365889132022858, 0.06753101537469774, 0.1895295549184084, 0.16543193079996854, 0.23054075427353382, 0.19445746002020314, 0.1788180781295523, 0.17352444265270606, 0.17728359875036404, 0.10061754699563608, 0.0666339963208884, 0.1882019714685157, 0.0718225807941053, 0.1482709383708425, 0.09342733828816563, 0.1441820163745433, 0.09211962213157676, 0.16876703855814412, 0.1099916514067445, 0.08357448183232918, 0.12974339973879978], [0.03498315309116151, 0.10697843536036089, 0.06666667308309115, 0.0613862292811973, 0.036198909729137085, 0.09015753952553496, 0.03865929626044817, 0.0531518930074526, 0.07202985521871597, 0.030621582736785058, 0.040983172148116864, 0.07848616151022725, 0.015028779889689758, 0.045908887914265506, 0.015392294953926466, 0.04061219849972986, 0.07881599420215935, 0.05558310200285632, 0.03143857786199078, 0.08420437967288308, 0.039278425538213924, 79.08580988645554, 106.48550122976303, 92.89613083004951, 83.38109940290451, 48.87202374637127, 49.70579780638218, 29.014401398599148, 28.128866516053677, 75.45742258429527, 93.8175205886364, 102.55556970834732, 106.0787482559681, 36.366146206855774, 4.043901180848479, 0.41612030239775777, 0.04006007773568854, 0.3191830508876592, 0.08734175702556968, 0.4803985735634342, 1.205012477003038, 0.3527829557424411, 5.495029063895345, 1.9695123354904354, 13.103327080607414, 113.91371503472328, 106.9556500017643, 110.30724495649338, 104.87129464745522, 106.99494749307632, 101.69868528842926, 100.88007241487503, 96.02981507778168, 95.6084480881691, 91.39746844768524, 93.8262677192688, 94.14333030581474, 101.55706688761711, 98.74358385801315, 96.17128908634186, 92.55952969193459, 89.54620018601418, 85.67600905895233, 79.1727340221405, 70.9785421192646, 68.76762315630913, 69.24397319555283, 69.12301808595657, 76.64871945977211, 79.16516482830048, 75.98596662282944, 72.10683837532997, 70.55566281080246, 74.41450774669647, 75.99547371268272, 82.87853837013245, 85.1666995882988, 87.6985265314579, 86.54273495078087, 92.65902355313301, 91.77113279700279, 89.41136822104454, 90.54344147443771, 90.61339572072029, 91.18908002972603, 86.44782364368439, 88.0767734348774, 87.36377209424973, 91.90447524189949, 74.83765304088593, 82.83772096037865, 81.72517865896225, 82.25869283080101, 90.96197381615639, 90.6223252415657, 87.27403610944748, 72.48840630054474, 71.84793546795845, 69.62146013975143, 72.79672175645828, 77.95155555009842, 87.66337841749191, 90.76791062951088, 89.81935232877731, 89.61552366614342, 90.98924115300179, 87.13400602340698, 82.14854434132576, 75.4431277513504, 70.66128954291344, 67.0873761177063, 71.65723130106926, 71.46128341555595, 77.56172686815262, 77.97630742192268, 78.26053217053413, 77.88683742284775, 76.89098685979843, 73.24670881032944, 80.04541039466858, 72.49018460512161, 76.01793050765991, 68.69975119829178, 70.19231110811234, 77.94198766350746, 92.3742364346981, 87.85222068428993, 103.15762460231781, 19.549242295324802, 1.102527582552284, 0.5885507154744118, 0.40599592379294336, 0.14436654397286475, 0.01866436839918606, 0.04019093692477327, 0.03668149125587661, 0.19516149099217728, 18.425180912017822, 29.059231393039227, 78.21081563830376, 97.76563033461571, 87.29971513152122, 81.68849542737007, 79.81454998254776, 22.366390228271484, 25.874166302382946, 56.1971490830183, 62.91858561336994, 64.16201949119568, 67.40392193198204, 14.099432229995728, 0.37124708527699113, 0.04833478313230444, 0.15682378958445042, 0.04806059296242893, 0.06883929556352086, 0.042669339090934955, 0.07103697294951417, 0.030208219468477182, 0.08453236441710033, 0.011536486181285, 0.049680864613037556, 0.021517853856494185, 0.03407315016374923, 0.04382989107398316, 0.019445376783551183, 0.009366584599774797, 0.01057927152942284, 0.040688795561436564, 0.017581510001036804, 0.026094255554198753, 0.04155534945311956, 0.04168374842265621, 0.021710153596359305, 0.05334635796316434, 0.04085635766386986, 0.034515703955548815, 0.011661578882922186, 0.04007000396086369, 0.02465397512423806, 0.04268603370292112, 0.017871812196972314, 0.055966636500670575, 0.01014643987218733, 0.05149021693796385, 0.020639692775148433, 0.08659019891638309, 0.07134675281122327, 0.009654444202169543, 0.05661175207933411, 0.03582261117117014, 0.02782977717288304, 0.048877949884627014, 0.04262680289684795, 0.02244209303171374, 0.02523282433685381, 0.577008716063574, 97.70532757043839, 118.94389271736145, 105.91101005673409, 98.88188883662224, 70.77276796102524, 86.05753898620605, 60.18997102975845, 43.93916264176369, 91.56467467546463, 81.43036767840385, 106.27876952290535, 118.935107588768, 47.919711247086525, 5.08281578309834, 0.6694356095977128, 0.12640061817364767, 0.3891988063696772, 0.09427422526641749, 1.935081195551902, 1.9039361667819321, 1.9524526759050786, 5.481228679418564, 1.534789300058037, 19.007197581231594, 127.39012509584427, 106.10110625624657, 114.15773034095764, 107.723049223423, 110.92177078127861, 102.86270722746849, 102.93909832835197, 99.27786558866501, 97.71711453795433, 95.72384789586067, 95.48122331500053, 96.11857831478119, 106.92912742495537, 103.22996512055397, 100.09886473417282, 95.25032490491867, 94.63035777211189, 89.50216054916382, 84.17801544070244, 72.92106628417969, 71.32709741592407, 69.85595315694809, 73.51242855191231, 80.66081777215004, 82.16317355632782, 80.63972130417824, 75.21110460162163, 73.97703722119331, 76.24287083745003, 80.04969656467438, 86.31407842040062, 88.71064782142639, 90.44617429375648, 89.6388392150402, 94.27789628505707, 92.92044192552567, 91.59039169549942, 94.42547276616096, 95.75521901249886, 94.26626890897751, 91.55218854546547, 89.68095615506172, 90.9238238632679, 96.55998542904854, 80.03631368279457, 88.69550943374634, 86.78793579339981, 88.36569473147392, 94.97921705245972, 93.26791808009148, 91.75154104828835, 76.85643911361694, 76.32286414504051, 72.72011786699295, 77.22406178712845, 81.42896175384521, 90.83402708172798, 93.06003883481026, 93.76549378037453, 92.31061264872551, 96.6009396314621, 91.02017909288406, 87.17458784580231, 79.15264829993248, 74.41172629594803, 71.96797862648964, 74.21244218945503, 74.58888798952103, 81.98255404829979, 83.03898856043816, 83.77679497003555, 82.48216643929482, 81.81804567575455, 78.28380972146988, 83.3330699801445, 75.04560828208923, 79.6279875934124, 72.84670427441597, 72.30730041861534, 80.17518863081932, 94.49121683835983, 89.72281470894814, 105.65330788493156, 32.808602303266525, 0.7651665445882827, 1.1182277463376522, 1.7823230987414718, 0.5023950291797519, 0.04993024849682115, 0.04179833231319208, 0.025982094775827136, 0.18133289006073028, 21.07612006366253, 34.92148272693157, 81.2222908437252, 106.55829772353172, 89.26185384392738, 52.10956782102585, 29.40855424851179, 26.404315754771233, 45.61215586960316, 74.42998051643372, 75.73872148990631, 75.67331939935684, 87.10806861519814, 25.591765455901623, 0.5291981378104538, 0.0625088500964921, 0.0769846112234518, 0.028430235870473552, 0.04655899072531611, 0.014695538884552661, 0.02029393730481388, 0.007041020789984032, 0.02360589747695485, 0.041104494739556685, 0.037251820613164455, 0.081345085054636, 0.0862723593309056, 0.0650734081864357, 0.02831066660291981, 0.01172184312963509, 0.04608888099028263, 0.07564264495158568, 0.0133521449060936, 0.013338121098058764, 0.0256806881952798, 0.04884491689153947, 0.03810747235547751, 0.03189843853760976, 0.04694415794801898, 0.13604050793219358, 0.2905268291942775, 0.11823320877738297, 0.1070312614319846, 0.14738675847183913, 0.16304861259413883, 0.09277025557821617, 0.17390872671967372, 0.12023402407066897, 0.11224965055589564, 0.11516018304973841, 0.19600384344812483, 0.15444154007127509, 0.10962921616737731, 0.0804377427266445, 0.13603918690932915, 0.1802947442047298, 0.10945933114271611, 0.11685945632052608, 0.17528904718346894, 1.3023643218912184, 122.90853917598724, 136.12588673830032, 121.00651323795319, 113.49675580859184, 73.53757560253143, 74.43515583872795, 43.088373094797134, 37.94461190700531, 87.70824640989304, 138.18346112966537, 123.25593933463097, 130.7188680768013, 60.26593655347824, 9.50433500111103, 1.165828148368746, 0.19060427381191403, 0.6860667234286666, 0.43291305599268526, 3.078633276745677, 4.0916437190026045, 3.320288434624672, 16.35947495698929, 7.493288638070226, 15.40076645091176, 131.36262953281403, 110.82850858569145, 115.29260024428368, 111.07554852962494, 113.17835569381714, 106.10863745212555, 106.60125061869621, 100.11463388800621, 101.28858849406242, 98.18999916315079, 99.16378811001778, 97.75329619646072, 109.37091439962387, 106.82141840457916, 107.58123323321342, 100.33510565757751, 96.8175508081913, 94.36243414878845, 88.59314292669296, 77.67781063914299, 76.35141581296921, 75.5936224758625, 77.05181702971458, 85.1883128285408, 89.63450744748116, 84.01995152235031, 80.17224758863449, 78.74210312962532, 81.09679117798805, 83.40079754590988, 92.55015939474106, 92.30132594704628, 94.6718667447567, 96.04394271969795, 100.68999141454697, 99.80110511183739, 98.08594554662704, 100.18028676509857, 99.207022190094, 99.12119999527931, 96.9781605899334, 97.15141609311104, 96.48596540093422, 101.85741797089577, 82.98911243677139, 93.80854547023773, 90.98544135689735, 94.24595519900322, 99.14616465568542, 97.64283612370491, 99.01501849293709, 80.36951020359993, 81.7247986793518, 79.14524629712105, 79.84687104821205, 85.49063220620155, 97.37735196948051, 96.79730549454689, 98.09691175818443, 95.66858366131783, 99.86459210515022, 97.38195732235909, 89.82281014323235, 81.82455092668533, 78.97755369544029, 76.4496785402298, 78.5074657201767, 78.8150592148304, 85.45476213097572, 85.37949576973915, 88.13858091831207, 87.77691632509232, 85.41589021682739, 83.22719246149063, 89.01329398155212, 81.14574015140533, 83.47174733877182, 76.61813870072365, 76.93459331989288, 86.41307830810547, 101.13669544458389, 94.7093403339386, 110.05058392882347, 26.761147007346153, 3.436834355816245, 3.9921365585178137, 0.8934174408204854, 0.7253240200225264, 0.14681411732453853, 0.2028918793075718, 0.10298863460775465, 0.6600114027969539, 35.320582911372185, 43.65132808685303, 96.05743959546089, 115.06164103746414, 115.75575739145279, 118.31461608409882, 101.81322634220123, 31.573370285332203, 38.27544875442982, 76.50830939412117, 86.89907222986221, 87.87954121828079, 103.28912034630775, 32.57493004202843, 0.5552858754526824, 0.14351289602927864, 0.20758885773830116, 0.1726427415269427, 0.15664718812331557, 0.19191542611224577, 0.2140656250412576, 0.13392240362009034, 0.1447501452639699, 0.13650262844748795, 0.09920581884216517, 0.15321907441830263, 0.1397360471310094, 0.1418611127883196, 0.13417799927992746, 0.11817415608675219, 0.1651135494466871, 0.14328998455312103, 0.13757350301602855, 0.10349434887757525, 0.20308745006332174, 0.16571099316934124, 0.22119169734651223, 0.206260843842756, 0.14155551121803], [0.03528651337546762, 0.01158028959252988, 0.05843412538524717, 0.06467454091762193, 0.049188794728252105, 0.022061736781324726, 0.0722069019684568, 0.05689076249836944, 0.006556615899171447, 0.07013033566181548, 0.03869378757372033, 0.021798187153763138, 0.04431165994901676, 0.016141559826792218, 0.05324323654349428, 0.06640400475589558, 0.04276831190509256, 0.013546787049563136, 0.10683644766686484, 0.17694589187158272, 29.62620846927166, 106.58707737922668, 95.60173764824867, 86.7107543349266, 58.57986442744732, 41.4321331679821, 23.718716762959957, 39.15821738541126, 43.42074505984783, 55.50357989966869, 97.019152790308, 113.13168659806252, 47.896901071071625, 2.9045401560142636, 0.8797176321968436, 0.08280785812530667, 0.23634041572222486, 0.11933840767596848, 0.9364130243193358, 0.3343035379657522, 0.8512180333491415, 0.9865780512336642, 4.42124230787158, 6.424744175747037, 117.92379945516586, 94.49385389685631, 105.65792083740234, 98.64820897579193, 108.07124733924866, 101.44210785627365, 103.35799545049667, 103.973798006773, 103.69816079735756, 98.12496945261955, 97.99371689558029, 96.95114403963089, 94.76909592747688, 91.22289061546326, 97.0916149020195, 91.82015776634216, 95.84833681583405, 88.60799252986908, 85.44223800301552, 80.2796982228756, 71.25531926751137, 67.91105031967163, 68.85574042797089, 68.93320307135582, 74.223393201828, 73.55175644159317, 74.68728750944138, 65.68561613559723, 68.73232305049896, 70.85369601845741, 76.15242809057236, 78.14400762319565, 78.6254569888115, 77.62694656848907, 76.09635829925537, 76.52323499321938, 83.48062366247177, 84.94299799203873, 86.99560225009918, 84.76484835147858, 86.46040856838226, 79.71312582492828, 81.21077746152878, 79.93501871824265, 85.93251809477806, 74.81304556131363, 88.76044794917107, 80.2377636730671, 81.09447330236435, 87.58159920573235, 88.79039794206619, 87.17207238078117, 75.90631529688835, 67.37373635172844, 64.82583627104759, 67.90627777576447, 72.5463379919529, 80.82739323377609, 84.14787545800209, 88.9689427614212, 90.34627005457878, 88.56312453746796, 86.62181630730629, 81.4169391989708, 80.02101570367813, 72.20684140920639, 69.57210078835487, 68.22176724672318, 71.06936484575272, 71.73345521092415, 75.6772331893444, 77.98548012971878, 77.19612568616867, 75.3542809188366, 77.88272604346275, 74.7607147693634, 75.77521473169327, 70.5858787894249, 74.31208044290543, 69.7149807214737, 73.0649645626545, 80.27585282921791, 91.87536120414734, 88.44403892755508, 101.21368691325188, 13.689001053571701, 0.9278848569374532, 7.5407015439122915, 0.0335557359358063, 0.14725137589266524, 0.14388698298716918, 0.04552810678433161, 0.18728357856161892, 1.4474382810294628, 20.395240299403667, 20.83869930356741, 61.98217146098614, 77.78263941407204, 71.90795704722404, 88.22344556450844, 60.13105519115925, 24.148040525615215, 18.21651890873909, 43.45616675913334, 70.440194606781, 71.19099631905556, 63.831923604011536, 4.211928164586425, 0.3112712816800922, 0.027869491350429598, 0.16869705403223634, 0.01865945538156666, 0.07458988620783202, 0.019124735590594355, 0.05727348805521615, 0.04800264607183635, 0.05186389942537062, 0.02294988345965976, 0.012054091512254672, 0.038701554149156436, 0.058983210765291005, 0.007722604113951093, 0.045420606693369336, 0.04096127137017902, 0.012222206514707068, 0.03996458188339602, 0.002760901143119554, 0.054526591702597216, 0.09387310929014347, 0.09964260985725559, 0.0055032133423083, 0.022099421184975654, 0.014374949641933199, 0.03689264340209775, 0.0365796203550417, 0.03131844641757198, 0.023583697984577157, 0.00986127426585881, 0.05959054731647484, 0.07327385057578795, 0.09686031306046061, 0.04231665938277729, 0.04815217398572713, 0.01053501448041061, 0.03895421832567081, 0.03201951250957791, 0.07782736443914473, 0.07803712505847216, 0.06008047239447478, 0.07595020579174161, 0.13379206764511764, 0.328719915705733, 40.666603446006775, 125.30180275440216, 108.38824152946472, 101.99205994606018, 71.73568189144135, 57.05591060221195, 36.595558896660805, 19.02399268001318, 30.91065924614668, 57.726954594254494, 100.2783215045929, 126.03694170713425, 59.89215441048145, 4.664066853001714, 1.7169839423149824, 0.07312795918551274, 0.4336275067180395, 0.13941904617240652, 1.4227491058409214, 0.5681031220592558, 1.7580917989835143, 2.9044779343530536, 2.928645587526262, 9.928019866347313, 127.60748863220215, 96.7769005894661, 114.27521243691444, 101.87891721725464, 112.4834793806076, 103.95745128393173, 107.67547577619553, 108.24603036046028, 110.92343509197235, 101.54923930764198, 101.56414210796356, 100.57947814464569, 98.08236613869667, 94.84038770198822, 100.2642622590065, 97.42521420121193, 100.84170207381248, 91.9761697947979, 88.06532084941864, 83.4917950630188, 74.38501372933388, 69.8305781185627, 73.023030012846, 72.40120857954025, 76.34005442261696, 75.46143516898155, 76.9658200442791, 68.23020279407501, 71.10443696379662, 73.45460325479507, 79.69944655895233, 81.69681698083878, 83.1903724372387, 79.8576320707798, 80.55030450224876, 81.47601842880249, 84.0823745727539, 86.96444392204285, 89.21459957957268, 86.75985530018806, 88.60036253929138, 83.92851322889328, 85.9087085723877, 83.7616565823555, 90.4364088177681, 76.09983131289482, 94.4282466173172, 85.02073422074318, 85.67891210317612, 91.93695589900017, 91.15083888173103, 93.94922152161598, 79.76374670863152, 70.11478006839752, 68.9424441754818, 71.40981137752533, 76.05847433209419, 83.65117371082306, 87.04614713788033, 91.33847281336784, 92.72616595029831, 91.35933369398117, 88.9504985511303, 83.47290247678757, 84.53979402780533, 76.7877160012722, 72.50863641500473, 70.22336304187775, 74.0400530397892, 75.69645255804062, 80.70822402834892, 81.23435139656067, 83.39573621749878, 78.16138029098511, 79.28906098008156, 77.85573989152908, 81.68163299560547, 75.1111775636673, 77.15675979852676, 74.25389036536217, 76.11057713627815, 81.76686242222786, 96.95392549037933, 91.13787397742271, 108.7834507226944, 23.37381687015295, 0.9578994463663548, 5.213353028520942, 0.09104679571464658, 0.5912491050548851, 0.042183640543953516, 0.15974745067069307, 0.19935306685511023, 0.7665537076536566, 24.88266460597515, 24.99792382121086, 65.11686265468597, 85.7161957025528, 82.39363878965378, 69.92491945624352, 40.74163042008877, 33.26739348471165, 39.766439348459244, 52.93432496488094, 82.27548032999039, 78.14004063606262, 83.04984077811241, 7.21887543797493, 0.19421042874455452, 0.07748950913082808, 0.1698626414872706, 0.03713171143317595, 0.10098567450768314, 0.048763443919597194, 0.043553133073146455, 0.034273804631084204, 0.042860664761974476, 0.0548154392890865, 0.020591048705682624, 0.03271165056503378, 0.06346602764097042, 0.047441393180633895, 0.06183447905641515, 0.07227503854664974, 0.04304643916839268, 0.11272367511992343, 0.08110125243547373, 0.04448918909474742, 0.0245092897239374, 0.0375570102914935, 0.04415671806782484, 0.04364281048765406, 0.0947905374050606, 0.10550868610152975, 0.19539593544322997, 0.1026915009424556, 0.0988515694916714, 0.11302588507533073, 0.1683188704191707, 0.21181103977141902, 0.1753777189878747, 0.17721297597745433, 0.14847850223304704, 0.09145527379587293, 0.20090497186174616, 0.1307351465220563, 0.1310825310065411, 0.28960062889382243, 0.23070374474627897, 0.21205122844548896, 0.2610924211330712, 0.45243447879329324, 57.38024599850178, 144.8638066649437, 120.46412274241447, 119.35579061508179, 84.74268034100533, 65.6625285744667, 34.05737489461899, 54.37254399061203, 62.61222705245018, 87.51211613416672, 122.96516373753548, 134.33584839105606, 77.42213755846024, 7.226061327382922, 2.5804916443303227, 0.334783440339379, 0.7658081757836044, 0.2173837969894521, 4.039242630824447, 1.0624178848229349, 3.9684115815907717, 6.993802590295672, 11.619469653815031, 7.95380350202322, 134.36990976333618, 101.58307269215584, 118.63598763942719, 108.83819818496704, 116.82782426476479, 112.10713237524033, 112.84211933612823, 112.32196524739265, 115.5914618074894, 106.39951184391975, 103.32961097359657, 102.7507272362709, 101.86298847198486, 99.63601157069206, 102.01447874307632, 101.96090921759605, 105.59409186244011, 96.76311492919922, 94.43003252148628, 88.41019794344902, 78.96307647228241, 74.38930749893188, 76.52486890554428, 76.44206374883652, 83.70158180594444, 80.78382477164268, 82.61123031377792, 74.29758042097092, 75.59514999389648, 79.26737174391747, 83.16312789916992, 87.20441624522209, 87.23955675959587, 85.47263637185097, 85.26566907763481, 87.24765032529831, 90.76018184423447, 92.87300527095795, 94.826480448246, 93.52280840277672, 95.65659910440445, 89.05068397521973, 90.91623187065125, 87.73854598402977, 94.1137982904911, 82.5746838748455, 99.85893040895462, 87.75018855929375, 90.44716984033585, 95.05076721310616, 95.05079001188278, 97.15706259012222, 84.86944913864136, 74.6488031744957, 73.29900920391083, 75.35156786441803, 81.42456918954849, 87.36523121595383, 93.22526916861534, 97.61303812265396, 98.08189496397972, 96.2069919705391, 93.22153016924858, 89.26127627491951, 89.7825475037098, 79.61836650967598, 77.01384946703911, 73.65201026201248, 77.77584537863731, 82.84892275929451, 85.87497398257256, 85.00084608793259, 87.81083330512047, 81.89687624573708, 85.3011591732502, 81.06557965278625, 85.97094923257828, 79.33659642934799, 82.75897398591042, 76.84788957238197, 83.19139078259468, 85.96490755677223, 105.66108226776123, 97.55423247814178, 116.00563198328018, 17.45675727725029, 3.1969641521573067, 14.719228371977806, 0.15484920179005712, 0.8489904622547328, 0.3490260260878131, 0.27516226458828896, 0.3189836209639907, 5.031450614333153, 41.42881214618683, 37.427497655153275, 80.46293199062347, 88.80260288715363, 98.73447194695473, 127.42892101407051, 79.00233596563339, 33.58855985105038, 30.57142674922943, 62.70010493695736, 96.56796500086784, 91.47202804684639, 97.90490046143532, 8.797196745872498, 0.335956122726202, 0.1704212708864361, 0.23893163917819038, 0.23223549302201718, 0.14781123725697398, 0.11723887189873494, 0.23281433852389455, 0.11371441258233972, 0.167606245377101, 0.12594063504366204, 0.1299310740432702, 0.09968192884116434, 0.14382922905497253, 0.13113253691699356, 0.1907995031797327, 0.14937627827748656, 0.1090369452140294, 0.21091636590426788, 0.14631665573688224, 0.15914455958409235, 0.15805358765646815, 0.16190856986213475, 0.12590146448928863, 0.149092095089145], [0.04605112051649485, 0.012562676038214704, 0.012664147106988821, 0.034714083740254864, 0.04853142258070875, 0.060215027478989214, 0.03842300757241901, 0.08238066307967529, 0.042404937848914415, 0.014215905539458618, 0.08282216673251241, 0.03256863128626719, 0.03034262055734871, 0.03812096460023895, 0.022573622009076644, 0.06046040005458053, 0.08902919304091483, 0.15517874504439533, 0.203979704529047, 6.03401399217546, 99.44826364517212, 104.44905370473862, 94.37596142292023, 71.18801727890968, 39.05634105205536, 31.317404620349407, 59.656802639365196, 124.98339504003525, 88.65125700831413, 89.72249552607536, 111.01902276277542, 57.99891360104084, 7.479657344520092, 1.274654190056026, 0.15467884921235964, 0.15426191064761952, 0.09941595053533092, 0.3686913364799693, 0.033544603720656596, 0.373538302956149, 1.292039800900966, 2.1522769471630454, 1.6305643483065069, 96.50169655680656, 105.96248209476471, 99.13603439927101, 103.41082021594048, 99.55503791570663, 102.31337070465088, 101.47817552089691, 98.56933280825615, 91.31109148263931, 97.244853079319, 98.35798054933548, 99.91793364286423, 94.03340220451355, 95.66096886992455, 92.7744309604168, 88.07450875639915, 94.02809008955956, 92.25684553384781, 90.3858183324337, 80.61621576547623, 74.39458161592484, 67.96316832304001, 65.82721173763275, 66.94652527570724, 69.21422839164734, 69.3432542681694, 71.8493489921093, 70.44583350419998, 69.88448202610016, 67.8256157040596, 71.0012648999691, 69.27092134952545, 70.01517981290817, 67.89574474096298, 65.17453595995903, 67.66322761774063, 66.66404083371162, 66.68873950839043, 63.96596521139145, 65.01760438084602, 65.6235046684742, 67.15264141559601, 67.19458356499672, 73.22126537561417, 81.93388625979424, 89.26306217908859, 70.62314718961716, 83.76981094479561, 80.1081146299839, 75.6265439093113, 87.66599267721176, 88.73241305351257, 85.47955960035324, 78.47587421536446, 66.98582276701927, 65.51790073513985, 66.4306877553463, 66.7440265417099, 70.54107159376144, 70.96471086144447, 73.97167190909386, 80.77102705836296, 83.20235699415207, 84.28902268409729, 81.89977169036865, 85.5614984035492, 75.6041707098484, 67.19222769141197, 71.13038957118988, 66.87842532992363, 70.09205728769302, 68.77972170710564, 75.09280174970627, 73.59609246253967, 75.89625343680382, 72.57651597261429, 77.07694128155708, 72.29508027434349, 75.45822814106941, 70.35450920462608, 71.81338012218475, 66.56482815742493, 72.76524424552917, 84.34603482484818, 89.7233846783638, 88.8909861445427, 89.63528260588646, 5.200355350971222, 1.1257543112151325, 1.187451125588268, 0.3153445740463212, 0.09098360926145688, 0.09087472877581604, 0.050035258682328276, 0.33440844796132296, 1.7467413330450654, 4.058919874951243, 22.096762396395206, 67.06835433840752, 91.7247524857521, 59.863112568855286, 69.2326346039772, 41.33911795914173, 21.6519183665514, 31.616017296910286, 54.48010481894016, 65.38173124194145, 76.96759834885597, 47.523365914821625, 1.4028686913661659, 0.04346454661572352, 0.046811580687062815, 0.03979561341111548, 0.02743544628174277, 0.0173827442995389, 0.08068161987466738, 0.06245147465961054, 0.019974546630692203, 0.021590701217064634, 0.03666179836727679, 0.06504779667011462, 0.11260995583143085, 0.022760114443372004, 0.03681878115457948, 0.0454553169402061, 0.01791379549104022, 0.030855407494527753, 0.033652682686806656, 0.05096792308904696, 0.03948128047341015, 0.050913382656290196, 0.07405741751426831, 0.03605002006224822, 0.03005781396495877, 0.011668248007481452, 0.01196864712255774, 0.025212131404259708, 0.0317000401992118, 0.08728920554858632, 0.01436690661648754, 0.0450551731773885, 0.09136096909060143, 0.05171095392142888, 0.027385414396121632, 0.06151875830255449, 0.008778369483479764, 0.05511794981430285, 0.05494355253176764, 0.1039260413381271, 0.08001425841939636, 0.056939425121527165, 0.30544836132321507, 7.300214823335409, 119.2783659696579, 116.24578669667244, 106.03068843483925, 86.39248341321945, 65.15769526362419, 50.08094407618046, 24.303115904331207, 61.212682351469994, 75.39095655083656, 99.40367683768272, 118.24782326817513, 72.58873611688614, 9.510364327579737, 1.3127214973792434, 0.05074979846540373, 0.0932562880916521, 0.18448698800057173, 1.0113669116981328, 0.18553677073214203, 1.5309482999145985, 1.979305122513324, 1.671920141670853, 3.2682276656851172, 108.01687985658646, 106.42829149961472, 105.8968748152256, 104.83567535877228, 103.89057487249374, 104.00932610034943, 104.65213000774384, 103.74951124191284, 95.83305403590202, 100.06785839796066, 101.08317151665688, 104.66428935527802, 100.06212070584297, 96.99000835418701, 95.81641852855682, 92.83558487892151, 97.23232135176659, 95.3558300435543, 94.39533278346062, 87.28616505861282, 76.58081710338593, 71.34309455752373, 70.92609733343124, 69.69313949346542, 72.29256480932236, 74.3472969532013, 75.00311896204948, 72.82705932855606, 72.49234288930893, 71.87760427594185, 74.66213285923004, 71.98114112019539, 73.00757244229317, 70.03383681178093, 67.49481305480003, 71.06535986065865, 69.5323321223259, 68.90013724565506, 66.89069867134094, 67.14520901441574, 66.95691391825676, 69.04918804764748, 71.04409620165825, 75.72949558496475, 86.9146665930748, 93.43801975250244, 72.95646518468857, 86.71859711408615, 82.75418624281883, 80.08947283029556, 90.48231795430183, 89.72937315702438, 90.72553530335426, 79.49667423963547, 70.69738000631332, 69.25866320729256, 69.92824047803879, 68.19298759102821, 75.06446287035942, 73.98824661970139, 76.49450093507767, 83.52774113416672, 87.12372377514839, 87.66677543520927, 86.60883620381355, 88.44616681337357, 80.42220577597618, 69.7095014154911, 72.77709200978279, 69.3263603746891, 73.87024775147438, 73.20481985807419, 75.96379101276398, 77.65994399785995, 78.68018925189972, 77.06299602985382, 80.77669635415077, 74.33099582791328, 80.34601986408234, 73.5686731338501, 74.53138947486877, 70.6538799405098, 77.15672940015793, 86.74765035510063, 94.39846381545067, 89.63855803012848, 99.34338927268982, 11.336155906319618, 1.0421002563089132, 0.8246685017365962, 0.7893271325156093, 0.2963619207730517, 0.19312540884129703, 0.08766928905970417, 0.6079599552322179, 1.4761624834500253, 3.101546047255397, 26.601608768105507, 72.58909329771996, 96.15069419145584, 68.58154714107513, 53.9656276255846, 41.022499948740005, 28.741452544927597, 40.93264617025852, 67.16407120227814, 75.00137865543365, 88.39358523488045, 65.11398240923882, 1.6597077157348394, 0.01818705612095073, 0.060428487704484724, 0.030395448484341614, 0.028840780832979362, 0.02767129524727352, 0.03492585186904762, 0.044019357665092684, 0.029977387421240564, 0.01652876610023668, 0.05850288907822687, 0.06923624066985212, 0.040118269535014406, 0.006187513854456483, 0.020248556829756126, 0.07224970904644579, 0.01489904876507353, 0.09972426836611703, 0.08834038351778872, 0.02479136335750809, 0.011670360345306108, 0.010926757131528575, 0.020185336979920976, 0.05701456015231088, 0.2204983978299424, 0.10968788294121623, 0.09846294386079535, 0.1406150616821833, 0.12623535672901198, 0.1545168532175012, 0.07312630419619381, 0.1434108952526003, 0.19690409826580435, 0.15415153844514862, 0.19829958822811022, 0.09945307276211679, 0.09574839772540145, 0.18729908944806084, 0.1403036862029694, 0.16209720895858482, 0.18791161361150444, 0.3598212171345949, 0.6299138709437102, 12.383232470601797, 141.10529154539108, 130.46523928642273, 125.3459943830967, 98.77300947904587, 66.09461098909378, 48.237738981842995, 87.29081600904465, 176.9775554537773, 132.36545652151108, 112.63829827308655, 126.4388157427311, 88.61640527844429, 15.425068996846676, 2.2043153923004866, 0.2897926967125386, 0.29645943897776306, 0.6165150180459023, 1.6533860424533486, 0.24667361984029412, 2.1551811788231134, 4.686136543750763, 6.860674833878875, 2.416245457716286, 112.15811803936958, 111.59356713294983, 111.66569486260414, 113.82457181811333, 107.19599470496178, 110.86741089820862, 109.21367883682251, 110.35264492034912, 100.59505730867386, 103.93025994300842, 107.00019881129265, 110.29091343283653, 104.75996822118759, 104.02311936020851, 100.6786984205246, 98.85221242904663, 101.9830696284771, 100.43551906943321, 98.12814608216286, 91.49292692542076, 81.35292783379555, 76.02963387966156, 74.14298951625824, 73.65910068154335, 75.90937033295631, 76.19394466280937, 81.571986079216, 77.12989524006844, 77.07168236374855, 75.57847648859024, 78.02647992968559, 75.33308565616608, 77.40763753652573, 75.25576740503311, 72.23800733685493, 75.2518992125988, 75.20555689930916, 74.65983018279076, 71.57552048563957, 71.9217275083065, 73.22720065712929, 74.37578782439232, 75.45039296150208, 80.15029236674309, 90.53319722414017, 97.92179435491562, 79.24950510263443, 91.47789493203163, 87.98753902316093, 85.46423882246017, 95.62367007136345, 91.89726322889328, 94.59362134337425, 85.10424613952637, 75.44162303209305, 71.02521881461143, 73.44067320227623, 72.3558846116066, 78.7107852101326, 79.11262884736061, 82.19473466277122, 89.43867355585098, 92.3252646625042, 93.15507933497429, 89.9899859726429, 91.49968296289444, 84.17406365275383, 74.5523339509964, 80.1099081337452, 72.1661151945591, 76.82927817106247, 76.44995972514153, 82.09444284439087, 84.52006548643112, 83.73410806059837, 82.18835860490799, 85.45898750424385, 80.77905222773552, 83.84914308786392, 76.64120346307755, 80.38391143083572, 76.32533401250839, 82.11366981267929, 91.70994848012924, 98.78093585371971, 94.86045822501183, 101.60059735178947, 7.6831126771867275, 3.7295609107241035, 5.45287175104022, 0.7246600650250912, 1.2876399932429194, 0.17419308802345768, 0.243812610860914, 0.9669890336226672, 5.1101937890052795, 14.224000945687294, 41.0345833003521, 90.67143380641937, 105.9119676053524, 78.9055323600769, 95.40915638208389, 54.21137563884258, 32.35953859984875, 47.422230541706085, 77.63547331094742, 90.13273671269417, 100.81355318427086, 77.99960777163506, 2.0506582874804735, 0.1585574762430042, 0.19523399882018566, 0.14722902240464464, 0.17598246544366702, 0.12593063089298084, 0.185388712270651, 0.15108661697013304, 0.11934949536225758, 0.10862110502785072, 0.16055260668508708, 0.12162629311205819, 0.1679654893814586, 0.16935870837187394, 0.14120299107162282, 0.1723976101493463, 0.1974128998699598, 0.20055000262800604, 0.16165184613782912, 0.14653049816843122, 0.10733490373240784, 0.1445023569976911, 0.1276078846422024, 0.20226703549269587], [0.05719956643588375, 0.06961360792047344, 0.029942630790174007, 0.009328701671620365, 0.020312743326940108, 0.03985243965871632, 0.09799478968488984, 0.04323435467085801, 0.0851582843461074, 0.03687403033836745, 0.016908421021071263, 0.06313412435702048, 0.036008125825901516, 0.06726004983647726, 0.05575337665504776, 0.04950331691361498, 0.11971771935350262, 0.07422349532134831, 0.19908032758394256, 33.20462465286255, 103.37687283754349, 95.39994567632675, 67.3710460960865, 63.7396227568388, 31.38739876449108, 30.469926595687866, 121.0094390809536, 71.86661526560783, 82.4441608786583, 117.96420648694038, 71.67566031217575, 14.679977428168058, 0.4493081965483725, 0.1084827167505864, 0.2616576408036053, 0.19851985765853897, 0.23456798895495012, 0.4565227625425905, 0.1106832736695651, 1.7014753120020032, 1.1194289568811655, 0.8472897566389292, 57.33723610639572, 122.27261289954185, 94.14248675107956, 102.1552611887455, 85.02554476261139, 92.9244165122509, 90.86209997534752, 93.11660259962082, 87.36060306429863, 93.98685470223427, 92.6570476591587, 91.3432377576828, 87.64697849750519, 94.21456128358841, 92.51257181167603, 92.28203058242798, 90.30929043889046, 88.05421024560928, 91.05428606271744, 91.29837736487389, 83.50171253085136, 71.05010747909546, 65.35775452852249, 67.61894479393959, 68.89919489622116, 70.0368158519268, 67.90276676416397, 68.21425884962082, 64.97775971889496, 66.93128809332848, 66.25417962670326, 68.90234112739563, 67.26845920085907, 64.5081353187561, 64.89313825964928, 66.44318148493767, 71.75834387540817, 72.99497231841087, 73.39290976524353, 71.99351325631142, 67.97421053051949, 69.10326674580574, 67.78244242072105, 69.25087362527847, 76.88647270202637, 80.94495132565498, 86.970743983984, 63.4746515750885, 82.497418820858, 78.37863743305206, 71.61468878388405, 86.53402581810951, 85.27417302131653, 83.07860523462296, 76.38847902417183, 67.74161741137505, 64.40024390816689, 63.811093121767044, 63.20295475423336, 64.25826072692871, 63.87993782758713, 64.61474239826202, 68.10594946146011, 75.21127939224243, 81.64941072463989, 82.12217375636101, 82.79079347848892, 73.77674996852875, 69.18316885828972, 66.99092969298363, 65.60753032565117, 67.86496639251709, 65.09739249944687, 73.24442133307457, 74.34623301029205, 74.17149558663368, 73.09184432029724, 74.87037688493729, 74.06992703676224, 72.00530782341957, 70.5400076508522, 70.43119668960571, 63.737236484885216, 69.09321248531342, 72.51087069511414, 89.07881006598473, 83.752651065588, 96.81255027651787, 68.1238541007042, 0.15856546175200492, 0.948860147036612, 0.48188960761763155, 0.10965972585836425, 0.20733615645440295, 0.039005155631457455, 0.06291042620432563, 0.3343212901381776, 0.4981109965592623, 0.7260349381249398, 20.108207501471043, 37.695626467466354, 58.66958141326904, 89.36049655079842, 69.0663631260395, 45.76569803059101, 29.93338778614998, 36.27664960920811, 54.70073997974396, 71.29721581935883, 72.08751261234283, 22.199784368276596, 0.5344713048543781, 0.1065320780617185, 0.13158704299712554, 0.038917274214327335, 0.08591074045398273, 0.046541212577722035, 0.07258438796270639, 0.05804185952001717, 0.08674331140355207, 0.01859284206148004, 0.0336943245929433, 0.06601529006729834, 0.1159671795903705, 0.07317126350244507, 0.08096038538496941, 0.01047825038767769, 0.04398299613967538, 0.06650369003182277, 0.07408732606563717, 0.04927420108288061, 0.03399050830921624, 0.01942024024174316, 0.06520682407426648, 0.12087040828191675, 0.05053733642853331, 0.05073612068372313, 0.026966288351104595, 0.06826711454777978, 0.046563625437556766, 0.07495622514397837, 0.032222998270299286, 0.09529396586003713, 0.05088010475446936, 0.02154355257516727, 0.015095366306923097, 0.02747380975051783, 0.019543898742995225, 0.12613722996320575, 0.0652854323561769, 0.09455210019950755, 0.10787591454572976, 0.2425109877367504, 40.109215155243874, 123.67333933711052, 106.47326588630676, 87.54473358392715, 76.9741339981556, 49.750950783491135, 36.407461389899254, 96.12234771251678, 85.00455468893051, 84.718908816576, 118.74072521924973, 85.78637793660164, 18.218741789460182, 0.3007768979296088, 0.21334442077204585, 0.2651544625405222, 0.1379061781335622, 0.10610124649247155, 0.1529973652213812, 0.7876621093600988, 1.3991371728479862, 0.4232252680230886, 0.8644960646051913, 66.35046645998955, 118.66998061537743, 100.23128762841225, 104.83450502157211, 91.07073917984962, 95.61336502432823, 94.46972519159317, 96.60290032625198, 91.2819242477417, 97.56192326545715, 95.60350835323334, 95.00605881214142, 91.43478244543076, 100.03320425748825, 97.60445818305016, 97.24312037229538, 92.44848445057869, 93.69204372167587, 98.03012654185295, 97.00322404503822, 87.01570317149162, 75.30126616358757, 67.9400123655796, 69.94077980518341, 73.02598625421524, 73.1483244895935, 71.01955711841583, 70.11782750487328, 69.47099581360817, 68.93254190683365, 69.00865942239761, 72.27092117071152, 70.04335910081863, 68.41843709349632, 68.71883377432823, 71.55192375183105, 75.78998073935509, 78.68481740355492, 76.8395148217678, 77.25907310843468, 72.88636654615402, 73.0922394990921, 73.22187334299088, 72.32249200344086, 83.8360033929348, 86.91460579633713, 89.12418723106384, 66.0925742983818, 87.49641537666321, 83.16017925739288, 76.20893865823746, 91.05560839176178, 87.12143629789352, 88.9269246160984, 80.5731488764286, 71.21678173542023, 64.82329040765762, 68.6109271645546, 67.63342201709747, 67.29147836565971, 68.18033427000046, 68.46480220556259, 70.57099118828773, 77.46341854333878, 83.20434048771858, 84.4198040664196, 84.21314835548401, 76.73152461647987, 72.27951630949974, 71.61609470844269, 68.52822080254555, 69.78723764419556, 67.18292579054832, 74.41430255770683, 76.90490931272507, 77.77313232421875, 78.2581079006195, 79.49697062373161, 78.14890936017036, 77.02237620949745, 75.0719864666462, 72.47041806578636, 67.46274277567863, 71.86699524521828, 76.98879361152649, 90.82151055335999, 87.79678165912628, 98.30505698919296, 78.14858257770538, 2.2662729676812887, 0.912353724706918, 0.3062758262967691, 0.4762473556911573, 0.2690105134388432, 0.19088220811681822, 0.030499167332891375, 0.403132569626905, 0.7391124113928527, 0.1820986528764479, 21.95560947060585, 40.15140429139137, 64.9523238837719, 78.85637819766998, 47.291183173656464, 53.655875846743584, 41.45189590752125, 43.81634183228016, 63.69848616421223, 78.97077485918999, 86.0670156776905, 34.42927233874798, 0.4122905828990042, 0.0841129470791202, 0.09137147790170275, 0.03970056655816734, 0.0757906588842161, 0.08103517902782187, 0.01644234300329117, 0.10496683666133322, 0.01644781634240644, 0.033293661326752044, 0.046100944600766525, 0.04751144821057096, 0.12190146662760526, 0.017697149596642703, 0.014576835146726808, 0.005679285095538944, 0.0787780259270221, 0.043757516832556576, 0.07364299483015202, 0.05788137008494232, 0.050928656055475585, 0.013397829661698779, 0.007431396034007776, 0.22787153109675273, 0.13764976611128077, 0.20134542166488245, 0.1573714055120945, 0.1379502023337409, 0.13485065224813297, 0.16686056507751346, 0.16782124555902556, 0.2607643621740863, 0.08845508986269124, 0.0935190603195224, 0.11887017186381854, 0.191126374702435, 0.15765337710035965, 0.26834082906134427, 0.13376411836361513, 0.40118787554092705, 0.1727565424516797, 0.4202494933269918, 53.4891027957201, 139.23199206590652, 122.70437613129616, 98.20900574326515, 91.18275716900826, 46.40534430742264, 48.82571183145046, 162.60049492120743, 95.27209013700485, 103.94830897450447, 128.20474058389664, 104.02011752128601, 25.6941756606102, 0.5350842594634742, 0.3891702485270798, 0.8222205424681306, 0.43025373306591064, 0.7901282957755029, 1.312669012695551, 1.7483756016008556, 4.8393485974520445, 6.41361647285521, 1.942159621976316, 68.05771484971046, 125.7723619043827, 106.94546654820442, 110.11109948158264, 97.36599057912827, 104.29714545607567, 102.96626687049866, 101.87840044498444, 96.6209189593792, 102.40710407495499, 101.33917897939682, 101.13210529088974, 97.57969871163368, 102.7131624519825, 101.75653338432312, 102.94365808367729, 96.4462499320507, 96.48506864905357, 100.57795062661171, 101.65676593780518, 91.83429300785065, 79.14502590894699, 71.61351844668388, 73.97603407502174, 76.22216194868088, 77.0653747022152, 75.62285050749779, 72.92994260787964, 72.66477763652802, 72.09943637251854, 73.51325690746307, 76.12254649400711, 72.76657417416573, 71.52912497520447, 72.76824608445168, 73.71792912483215, 80.2134981751442, 80.14244198799133, 80.99491864442825, 79.27130073308945, 74.10108536481857, 77.06662863492966, 75.38396492600441, 75.34168839454651, 86.55554786324501, 90.30191883444786, 94.42072302103043, 74.41845953464508, 90.80773249268532, 87.11832046508789, 78.88556823134422, 96.3036359846592, 90.31309023499489, 92.55926370620728, 85.86330100893974, 74.72644820809364, 69.73451167345047, 71.63567125797272, 70.37337139248848, 70.11406570672989, 71.55989572405815, 71.17672428488731, 74.38781037926674, 83.75199750065804, 89.11792516708374, 90.06551072001457, 89.89062130451202, 82.42575466632843, 77.16386541724205, 74.66500550508499, 72.55921170115471, 74.464011490345, 72.90750101208687, 79.31737706065178, 82.30268687009811, 81.6038815677166, 81.00733637809753, 84.73479956388474, 82.87450298666954, 83.18786457180977, 79.96126770973206, 78.43368127942085, 72.70982801914215, 75.73623642325401, 83.65408435463905, 98.8926574587822, 94.38556730747223, 103.20610240101814, 82.99135431647301, 1.7943793768063188, 5.639354344457388, 1.0193817503750324, 0.6048177019692957, 0.7150759699288756, 0.32718904316425323, 0.3696275409311056, 0.5990817316342145, 1.473355502821505, 1.3323411508463323, 32.12838940322399, 56.572264954447746, 76.93634882569313, 111.65048807859421, 90.34143671393394, 62.81892456114292, 41.88146285712719, 51.61388821899891, 77.52695873379707, 92.25934579968452, 100.99356472492218, 43.06988328695297, 0.37160019914153963, 0.28385462472215295, 0.18218575132777914, 0.09522147287498228, 0.1875724521232769, 0.21879122068639845, 0.2089944260660559, 0.2164305973565206, 0.19373771036043763, 0.12170956208137795, 0.19128728716168553, 0.15360956283984706, 0.22280138597125188, 0.15794198348885402, 0.1653516897931695, 0.1950240452424623, 0.1982679875800386, 0.16870238265255466, 0.19063602288952097, 0.16096813516924158, 0.10999450125382282, 0.10042681504273787, 0.08675942342961207], [0.06572318074177019, 0.024865952909749467, 0.036561211381922476, 0.08514545261277817, 0.01778160971298348, 0.03034062418009853, 0.041416508465772495, 0.02969039705931209, 0.08562911025364883, 0.0786823927774094, 0.012736297776427818, 0.060803001397289336, 0.01654051615332719, 0.07194080491899513, 0.01998727075260831, 0.05825007276143879, 0.0326414656592533, 0.04461970689590089, 0.18460521212546155, 63.01910161972046, 111.10572651028633, 86.55001536011696, 60.402809008955956, 37.819408625364304, 39.77131448686123, 93.79121840000153, 107.09210827946663, 97.41500794887543, 144.1629722714424, 89.58216145634651, 25.568102225661278, 0.4013052536174655, 0.05955140644800849, 0.20594606932718307, 0.04131073386815842, 0.17408503132173792, 0.22996699990471825, 0.6687553273513913, 0.556877099443227, 0.6754736637230963, 1.8323297216556966, 27.438565157353878, 115.99161833524704, 99.49327602982521, 109.22264635562897, 91.6508236527443, 84.05446127057076, 73.21669802069664, 83.32259774208069, 80.56686401367188, 84.02752831578255, 79.89783391356468, 84.652359187603, 88.13066214323044, 96.36661380529404, 94.28814813494682, 94.28044974803925, 91.89869955182076, 94.11957398056984, 85.15653133392334, 93.92782866954803, 90.29770866036415, 81.62614837288857, 64.61740985512733, 66.35594576597214, 64.09648060798645, 67.1321377158165, 68.96575212478638, 71.0551992058754, 66.20462268590927, 67.00074076652527, 67.08270996809006, 68.86076375842094, 65.0980992615223, 66.4926852285862, 65.58854654431343, 69.27903011441231, 67.49502584338188, 79.30071115493774, 83.19914996623993, 82.99112632870674, 83.33902046084404, 84.7563748061657, 79.88169997930527, 78.06331515312195, 66.02220207452774, 73.53855594992638, 83.476193100214, 87.97439932823181, 51.03475749492645, 82.18265131115913, 76.93541407585144, 70.54130718111992, 83.0720391869545, 85.2384777367115, 83.38755145668983, 79.7819173336029, 75.51615983247757, 65.79603061079979, 63.846347630023956, 60.89612893760204, 65.05760103464127, 64.69401374459267, 65.17171651124954, 63.315386921167374, 64.38228607177734, 70.38835018873215, 75.0093050301075, 74.02515023946762, 70.74043169617653, 69.28942635655403, 68.5882879793644, 67.50047475099564, 65.85651576519012, 62.61017896234989, 65.79416871070862, 70.64760267734528, 74.34443950653076, 74.1648231446743, 74.88604724407196, 71.50975361466408, 72.56704688072205, 68.6934207379818, 65.58917731046677, 65.0390276312828, 64.811442643404, 68.0526915192604, 78.15299034118652, 84.78078469634056, 89.13656696677208, 81.30451083183289, 46.343198642134666, 0.2971561375306919, 0.8649965689983219, 0.2830213709967211, 0.3405371628468856, 0.04156447044806555, 0.0949170661624521, 0.3680838143918663, 0.03946128701500129, 0.07344136072788388, 0.10760915698483586, 18.197890408337116, 25.39899230003357, 55.51138088107109, 70.8830988407135, 36.68986603617668, 23.49828489124775, 29.97901763767004, 43.30104388296604, 58.993612825870514, 70.48064723610878, 63.120020404458046, 8.85978888720274, 0.28763438283931464, 0.11103576413006522, 0.20474021293921396, 0.15241664950735867, 0.09400586466654204, 0.08164322061929852, 0.12591894948855042, 0.050107187635148875, 0.033835421709227376, 0.06699776742607355, 0.13790922093903646, 0.05764975321653765, 0.1050689784460701, 0.028482969173637684, 0.0391373172897147, 0.013455431453621713, 0.0302884215125232, 0.0032822255616338225, 0.03196071585989557, 0.024328161161975004, 0.04070966846484225, 0.06216372174094431, 0.05693783692549914, 0.0388311665301444, 0.06208798185980413, 0.06532295534270816, 0.05002662008337211, 0.01963223472557729, 0.00833733431136352, 0.05543398598092608, 0.044882000438519754, 0.03906612306309398, 0.05972553284664173, 0.06121396567323245, 0.01017385666273185, 0.047884310624795035, 0.02647845056344522, 0.046786403327132575, 0.038865702372277156, 0.017057735567505006, 0.41265586798544973, 79.62538093328476, 124.37671199440956, 98.43006268143654, 72.03621536493301, 61.36631950736046, 42.721081003546715, 41.10855773091316, 118.21412667632103, 106.19835063815117, 138.32075536251068, 109.46277067065239, 31.678810827434063, 0.34386593266390264, 0.11614055270911194, 0.3440288489218801, 0.06635679674218409, 0.04894685458566528, 0.3034877555910498, 0.35157485806848854, 0.5850514001213014, 0.29801281343679875, 1.77661212394014, 34.29535612463951, 117.79711425304413, 104.13094997406006, 113.17610621452332, 98.33215713500977, 87.33626917004585, 76.0865244269371, 86.3571985065937, 84.56648379564285, 87.02138766646385, 83.63324627280235, 88.40211197733879, 91.37021631002426, 101.0318286716938, 96.15295127034187, 98.50610420107841, 95.04126012325287, 97.43337616324425, 89.64513927698135, 97.38338604569435, 93.62284943461418, 85.0156120955944, 67.18668758869171, 70.2972386777401, 68.36338564753532, 71.93392485380173, 71.4807079732418, 74.92849856615067, 69.6119986474514, 69.9316830933094, 70.26450723409653, 68.82088869810104, 68.4828132390976, 69.16184440255165, 69.0349768102169, 74.67662528157234, 72.72557437419891, 84.11399647593498, 87.71827027201653, 88.6179631948471, 86.66347727179527, 88.55360984802246, 83.92378628253937, 83.4201081097126, 70.08495166897774, 76.55450731515884, 89.14478212594986, 89.17592525482178, 52.84894734621048, 87.39662513136864, 84.36330109834671, 74.91199225187302, 87.19634547829628, 86.51785388588905, 87.90516704320908, 85.2840068936348, 80.37601545453072, 69.11087393760681, 66.99971482157707, 65.2985081076622, 67.88971826434135, 66.56507894396782, 68.9329294860363, 67.77988895773888, 67.84982800483704, 74.40802529454231, 79.09842520952225, 78.13151389360428, 73.70272234082222, 73.44019442796707, 71.41550347208977, 69.79515641927719, 67.05953121185303, 66.91951632499695, 67.41360381245613, 73.2832096517086, 76.32056146860123, 78.27063962817192, 77.08555921912193, 75.96442177891731, 77.40502327680588, 74.51574191451073, 68.88067469000816, 67.57226809859276, 66.85300469398499, 71.2116976082325, 81.620342284441, 89.72315669059753, 92.06762328743935, 88.16242843866348, 65.78742027282715, 1.5879932139068842, 0.6462931889109313, 0.21099892241181806, 0.3058214538032189, 0.06377995610819198, 0.2707520074909553, 0.5927643924951553, 0.034630989175639115, 0.014377325442183064, 0.11089462990639731, 21.65817853063345, 25.168399773538113, 52.658968940377235, 54.11198057234287, 36.11390434205532, 32.43031360208988, 39.76710431277752, 52.22290053963661, 71.49067863821983, 80.98044142127037, 81.97427049279213, 15.158231165260077, 0.34924252540804446, 0.1707510813139379, 0.13375935377553105, 0.06080124250729568, 0.021782195726700593, 0.058228646958013996, 0.0581392997992225, 0.05157527819392271, 0.025313169244327582, 0.058823181461775675, 0.11744389761588536, 0.017259332562389318, 0.0033541004768267157, 0.0659933447604999, 0.011848662252305076, 0.03996654486400075, 0.05828970344737172, 0.05242783146968577, 0.006785318910260685, 0.008686316268722294, 0.016460636943520512, 0.07415564818074927, 0.22130995115730911, 0.10339748376281932, 0.14607661549234763, 0.22703661496052518, 0.09482472814852372, 0.14873841719236225, 0.09778619423741475, 0.08787076731096022, 0.21188635291764513, 0.19051537936320528, 0.1115460871369578, 0.2688698616111651, 0.12264302800758742, 0.19758061040192842, 0.13195795356296003, 0.22076203837059438, 0.16118125029606745, 0.13102701836032793, 1.0886502522043884, 97.67494440078735, 140.8595511317253, 113.69072020053864, 89.3633995950222, 59.88934636116028, 56.24799035489559, 135.27702748775482, 120.44928833842278, 113.9802798628807, 163.4784758090973, 117.74076327681541, 42.283720672130585, 0.5979179253336042, 0.25487723120022565, 0.7363292388617992, 0.3002954222029075, 0.20738288207212463, 0.7961720495950431, 1.4356313645839691, 1.6847676085308194, 4.630986778065562, 4.679433703422546, 33.35366025567055, 121.16740420460701, 105.7689356803894, 120.72319284081459, 103.10723930597305, 91.5407283604145, 79.08602267503738, 93.58627259731293, 88.37551340460777, 93.37137132883072, 89.99311700463295, 93.62267464399338, 95.57931125164032, 104.97401833534241, 101.24908581376076, 103.08326259255409, 99.31200295686722, 103.92454504966736, 93.49599704146385, 100.99256917834282, 98.4453834593296, 91.53332635760307, 71.67928531765938, 75.57112768292427, 70.47908172011375, 74.46689173579216, 74.99752566218376, 77.20831543207169, 73.00574094057083, 73.56823995709419, 72.49289005994797, 72.67872288823128, 71.33648291230202, 71.76650583744049, 71.21180400252342, 76.92443266510963, 74.14903119206429, 89.12712827324867, 90.81142589449883, 91.7595662176609, 91.28108829259872, 94.34342756867409, 88.0943588912487, 89.32585000991821, 73.2395575940609, 83.34311664104462, 94.54265847802162, 96.85621753334999, 59.34548154473305, 91.69015154242516, 88.32907229661942, 79.53100919723511, 90.71865767240524, 91.63939386606216, 92.10521847009659, 90.82639709115028, 85.82387432456017, 72.85222917795181, 69.52794715762138, 67.00785398483276, 71.36064201593399, 70.66723242402077, 70.82399681210518, 69.53366965055466, 73.04585918784142, 78.7533201277256, 83.13725888729095, 83.18131372332573, 78.25161024928093, 76.92038968205452, 77.5884698331356, 74.62712913751602, 71.16709560155869, 69.54984158277512, 72.256930321455, 79.71900790929794, 82.21820220351219, 82.52344742417336, 83.88456478714943, 79.80179786682129, 80.05867168307304, 78.28748792409897, 73.1889671087265, 73.53968068957329, 73.55713695287704, 75.90091958642006, 85.12912720441818, 95.74945092201233, 96.62585109472275, 96.31080999970436, 62.71613247692585, 1.4340318879112601, 2.575976299121976, 1.196530144661665, 1.1680196807719767, 0.577609974425286, 0.41686915908940136, 1.0644842614419758, 0.2078182258992456, 0.10195370225119404, 0.33863649296108633, 32.85347409546375, 40.10281629860401, 77.84437090158463, 93.7590417265892, 50.17097644507885, 33.62700238823891, 45.79136945307255, 64.42424342036247, 86.62085875868797, 92.83212706446648, 99.83468011021614, 17.622872963547707, 0.5503888882230967, 0.321002826676704, 0.20452564320294186, 0.25390668015461415, 0.16638618428260088, 0.16171152965398505, 0.2866807230748236, 0.19535048631951213, 0.08937297810916789, 0.11974371678661555, 0.33729774761013687, 0.1754594739759341, 0.19572513730963692, 0.12462615792173892, 0.14648498967289925, 0.1061799141461961, 0.14182963088387623, 0.13050999375991523, 0.09862151855486445, 0.10982020787196234, 0.11633996036835015, 0.20008970779599622], [0.015049342018755851, 0.07404133517411537, 0.02300675794685958, 0.03618190712586511, 0.009015489376906771, 0.037505100772250444, 0.025709041947266087, 0.027812635416921694, 0.05974003812298179, 0.018257549018017016, 0.03922873504052404, 0.01772861109202495, 0.04753453642479144, 0.05267540822387673, 0.051734242515522055, 0.03331346182676498, 0.0841006422706414, 0.18970048637129366, 7.422540234401822, 88.04847255349159, 88.77350404858589, 79.52296122908592, 61.07893332839012, 46.739714965224266, 41.87378726899624, 97.26429283618927, 75.77864974737167, 84.0406984090805, 94.9413026869297, 46.19334228336811, 0.7359331101179123, 0.08791046479018405, 0.12410103649017401, 0.16911762912059203, 0.26644924306310713, 0.2264440100407228, 0.20102742622839287, 0.08888845215551555, 0.5073034157976508, 1.998519147746265, 8.334761559963226, 98.37939620018005, 94.07981291413307, 108.89602348208427, 99.52991366386414, 95.51297441124916, 76.22919917106628, 75.42084574699402, 70.87847828865051, 76.4917802810669, 75.18674030900002, 81.39425441622734, 84.75904986262321, 88.82774233818054, 86.47993192076683, 88.57400715351105, 87.06766918301582, 91.613190472126, 86.3090018928051, 89.73979219794273, 90.42650654911995, 88.93419742584229, 72.13690996170044, 67.9826308786869, 66.83313935995102, 67.0956064760685, 67.52117604017258, 69.29063469171524, 67.94921547174454, 65.55477395653725, 64.45056080818176, 63.332109823822975, 67.63725981116295, 70.86558178067207, 77.30476945638657, 83.09217050671577, 82.3133111000061, 80.43083891272545, 81.58569574356079, 83.86699452996254, 84.49557960033417, 83.33205163478851, 81.8392713367939, 79.99799653887749, 79.94275510311127, 68.52306827902794, 69.97924894094467, 80.32188355922699, 80.93749612569809, 45.06592757999897, 78.42603608965874, 81.52921557426453, 70.02720236778259, 79.14474472403526, 82.21758663654327, 82.95067369937897, 80.9191583096981, 80.85945591330528, 74.5687946677208, 68.08806762099266, 63.37082214653492, 63.23854364454746, 61.063004583120346, 63.84763956069946, 63.98695528507233, 65.19069269299507, 63.82522836327553, 65.08064299821854, 66.67707413434982, 66.51527121663094, 62.16262377798557, 64.22350019216537, 63.869070410728455, 63.92855241894722, 62.290585711598396, 66.46936967968941, 61.047611609101295, 68.49496498703957, 71.43435806035995, 75.15617474913597, 71.32376879453659, 72.24265828728676, 70.06053417921066, 67.2671140730381, 60.20849123597145, 63.75661924481392, 62.43397481739521, 76.51563540101051, 78.6174850165844, 89.26480248570442, 81.86317965388298, 105.26837334036827, 20.653216056525707, 1.2974283867515624, 0.04150944390858058, 0.32661082106642425, 0.35151447693351656, 0.02970777259179158, 0.2777836489258334, 0.24560840043704957, 0.10653023753548041, 0.06731777408276685, 0.07180174870882183, 29.134896732866764, 23.225763514637947, 51.30659490823746, 64.04898315668106, 29.696033522486687, 20.49064178019762, 36.89216338098049, 59.942269921302795, 55.75876660645008, 79.41062405705452, 29.95078705251217, 0.5541452241595834, 0.09078424613107927, 0.11342266690917313, 0.05489062255946919, 0.06642356776865199, 0.011366520448063966, 0.0708202064561192, 0.017341916900477372, 0.03765460642171092, 0.03735686419531703, 0.007517340445701848, 0.062259926344268024, 0.050884828524431214, 0.07432217127643526, 0.030334892944665626, 0.039880756303318776, 0.021828483477293048, 0.04179770519840531, 0.0036312752399680903, 0.042925810485030524, 0.048611585662001744, 0.06571283520315774, 0.040466303398716263, 0.03825520056125242, 0.03234862531826366, 0.05550122084969189, 0.1040924976405222, 0.020733236779051367, 0.027741637859435286, 0.024267950720968656, 0.06094341202697251, 0.05137271269632038, 0.03650610691693146, 0.00812713211416849, 0.03277356052421965, 0.0525320661108708, 0.04139296383073088, 0.06260608628508635, 0.11305286214337684, 0.19674952374771237, 8.668754138052464, 105.20243167877197, 100.86557999253273, 95.7282480597496, 72.01486051082611, 51.012806072831154, 42.34294429421425, 89.71356600522995, 82.18221053481102, 89.00586917996407, 113.74118149280548, 54.72182884812355, 0.9481554629746825, 0.026191298784397077, 0.13483925285981968, 0.49433438514824957, 0.09051095024915412, 0.26344773068558425, 0.11182449641637504, 0.10382774387835525, 0.6639262614771724, 2.008838444016874, 12.777991387993097, 107.71291896700859, 100.96000492572784, 111.55749946832657, 103.79241853952408, 102.34000727534294, 81.32515892386436, 80.50149232149124, 76.21004059910774, 80.79172074794769, 81.40635296702385, 84.98315423727036, 88.4360821545124, 92.31663152575493, 90.97455874085426, 93.59368219971657, 91.36937275528908, 93.9339691400528, 90.24721696972847, 93.16042944788933, 94.08653855323792, 91.95225387811661, 74.9978144466877, 71.76679462194443, 70.21947205066681, 71.60747677087784, 70.51492139697075, 74.6229949593544, 69.70224380493164, 67.7148212492466, 66.3357612490654, 67.27308735251427, 70.78827872872353, 77.62854248285294, 82.54411831498146, 87.657959908247, 85.69829106330872, 87.08103686571121, 86.72662988305092, 88.9195454120636, 87.57905334234238, 87.97174707055092, 84.72063392400742, 83.03850218653679, 85.38410872220993, 72.30404779314995, 73.38442862033844, 82.96173110604286, 84.07874956727028, 49.08426895737648, 83.9732976257801, 86.83120787143707, 73.1102505326271, 82.30919972062111, 85.70777535438538, 87.54457399249077, 83.05885389447212, 84.52739149332047, 80.44786959886551, 73.30873668193817, 67.16830417513847, 66.17563024163246, 62.71260626614094, 67.10234731435776, 65.82727253437042, 69.47601914405823, 68.2876481115818, 67.86948814988136, 68.6858743429184, 69.05554130673409, 65.41000932455063, 67.62458369135857, 66.98769226670265, 66.9009505212307, 64.90796506404877, 68.25965121388435, 63.52629840373993, 72.13666677474976, 75.03926262259483, 79.41672652959824, 75.38939863443375, 77.76714384555817, 72.69713670015335, 71.59974038600922, 63.30832690000534, 66.91754803061485, 65.94071924686432, 78.06921243667603, 81.81154802441597, 91.8385411798954, 83.38920816779137, 109.77458193898201, 31.345612406730652, 0.49354396818671376, 0.10002077862736769, 0.3193342115264386, 0.15304391272366047, 0.02511853916075779, 0.16417452483437955, 0.4619052924681455, 0.10213750254479237, 0.11676721478579566, 0.05435307386505883, 29.617267549037933, 24.42405391484499, 37.48820699751377, 46.95432364940643, 34.90263573825359, 37.20715507864952, 50.320376828312874, 70.8550563454628, 65.8203873038292, 91.85782134532928, 42.63315372169018, 0.28854553238488734, 0.0048537826387473615, 0.06867522897664458, 0.03999713619123213, 0.08037222592975013, 0.03121489455224946, 0.034800796274794266, 0.01863404981122585, 0.08923965870053507, 0.05566199972236063, 0.02350271854083985, 0.04705612576799467, 0.04733679488708731, 0.017697012299322523, 0.055136021110229194, 0.026770797376229893, 0.01359687737931381, 0.05493141470651608, 0.07339101342950016, 0.0302175334218191, 0.03452855053183157, 0.03392191902094055, 0.17542431101901457, 0.20449727831874043, 0.12533501285361126, 0.1314698430360295, 0.22300314623862505, 0.1909635029733181, 0.1257244177395478, 0.08953946409747005, 0.1715989108197391, 0.18575686204712838, 0.15779336099512875, 0.19518495770171285, 0.16572683060076088, 0.18368352408288047, 0.1989565373514779, 0.24832000024616718, 0.4484819486970082, 0.5125567526556551, 13.873420357704163, 125.00164926052094, 116.71357199549675, 108.69429230690002, 90.04900440573692, 63.926249742507935, 67.07447201013565, 131.16894632577896, 93.25595632195473, 107.51678109169006, 116.35874703526497, 71.89112395048141, 1.7655417742207646, 0.243283964227885, 0.5281578842550516, 0.8299964689649642, 0.708611091831699, 0.5617146554868668, 0.5610003531910479, 0.3210985934128985, 3.261623145081103, 6.451354622840881, 11.351023558527231, 114.30873423814774, 101.0574620962143, 116.57193839550018, 108.0812256038189, 105.38628101348877, 84.32648107409477, 85.9400948882103, 80.61690732836723, 87.28129372000694, 82.3540449142456, 89.46185231208801, 94.51135575771332, 97.13110238313675, 95.12440726161003, 99.8335325717926, 95.6197638809681, 99.06602695584297, 94.21576201915741, 96.58886387944221, 97.6435124874115, 95.95524027943611, 79.42720636725426, 77.13795840740204, 72.30359181761742, 75.15906259417534, 71.51598528027534, 78.39990109205246, 72.14971527457237, 70.87624400854111, 68.19039613008499, 70.11145144701004, 75.1157221198082, 79.25082743167877, 83.39398071169853, 91.56797289848328, 88.05671811103821, 90.27359515428543, 88.60419273376465, 93.2991524040699, 93.16532358527184, 92.5887881219387, 91.26195251941681, 86.46156370639801, 88.25460389256477, 76.91294968128204, 76.77346676588058, 87.27607280015945, 88.12185421586037, 55.733053386211395, 87.87447229027748, 90.5908477306366, 76.80104568600655, 87.38088637590408, 88.87570336461067, 91.53927683830261, 88.28082248568535, 89.05164912343025, 83.12204450368881, 76.08337059617043, 70.7549849152565, 70.57431221008301, 67.92674347758293, 70.51937475800514, 70.18854930996895, 71.61312326788902, 71.02111503481865, 73.17257478833199, 72.86059632897377, 74.09786313772202, 69.42158326506615, 71.80432140827179, 70.7736799120903, 70.25514453649521, 67.77598276734352, 73.32542538642883, 67.53458172082901, 77.30981558561325, 78.10747638344765, 85.1754543185234, 80.03854036331177, 80.94565808773041, 76.91013783216476, 76.10113844275475, 68.41334536671638, 72.58856892585754, 69.46783438324928, 84.43085387349129, 85.83345741033554, 98.0096684396267, 88.0577440559864, 117.13641330599785, 27.46732771396637, 2.420593136921525, 0.9053336607757956, 0.9244919952470809, 0.8626721031032503, 0.13712330139242113, 0.5277700675651431, 0.7729587983340025, 0.5004829005338252, 0.12606590957148, 0.540949838468805, 47.80708149075508, 39.58041273057461, 71.96189895272255, 86.00898519158363, 40.009641498327255, 31.87679350376129, 54.60211627185345, 82.64225944876671, 79.7164848446846, 107.29234233498573, 58.34924720227718, 0.7287082134280354, 0.13695668923901394, 0.25957535253837705, 0.14019617869053036, 0.16788840992376208, 0.18874975066864863, 0.13884079438867047, 0.1522442782879807, 0.14469433575868607, 0.13426483055809513, 0.1320763409603387, 0.17442330223275349, 0.19649713416583836, 0.17731248313793913, 0.09959374685422517, 0.11765840055886656, 0.08086205081781372, 0.14817226241575554, 0.22498401260236278, 0.1680336779099889, 0.10192246525548398, 0.217704864917323], [0.05595228336460423, 0.03976102190790698, 0.05826775071909651, 0.04890442971372977, 0.04600120737450197, 0.05270268586173188, 0.06366166519001126, 0.02326965448446572, 0.061929507355671376, 0.03489233276923187, 0.0739087579131592, 0.0386278403311735, 0.12453606119379401, 0.0735037011327222, 0.09768204123247415, 0.18664663773961365, 0.09931964203133248, 0.31449000583961606, 24.308758601546288, 90.62553226947784, 93.05447593331337, 60.29415383934975, 53.587464317679405, 68.67939949035645, 40.45934356749058, 52.00616396963596, 100.49832209944725, 110.3530552983284, 73.96560743451118, 6.251755133271217, 0.30171613034326583, 0.14854778914013878, 0.12188469409011304, 0.28280659345909953, 0.1921556147863157, 0.026296279283997137, 0.0683843887236435, 0.4328475391957909, 0.3010597452521324, 1.8130033649504185, 83.51946517825127, 92.87196412682533, 112.47734650969505, 103.89445826411247, 102.61835753917694, 90.05826070904732, 77.43529245257378, 74.34536665678024, 74.93671372532845, 70.2504251897335, 74.62557882070541, 75.17401099205017, 77.14832425117493, 81.26588210463524, 83.71273040771484, 83.11574444174767, 83.98661971092224, 85.67560628056526, 86.35357350111008, 86.65254145860672, 85.41141405701637, 74.01876658201218, 65.52950531244278, 64.00063455104828, 65.75982615351677, 66.43275484442711, 66.98004707694054, 68.7737788259983, 67.3055300116539, 63.777480125427246, 63.89935478568077, 68.31486985087395, 83.64311814308167, 88.59646394848824, 85.17967209219933, 84.93356689810753, 83.73418405652046, 81.24542400240898, 84.17128220200539, 84.3210169672966, 81.30286931991577, 82.85177260637283, 81.2080492079258, 76.62310123443604, 79.47025805711746, 65.49021542072296, 70.07485941052437, 78.13485771417618, 84.35687944293022, 43.951439782977104, 76.52691319584846, 82.14614287018776, 66.50721564888954, 72.23388075828552, 81.49682611227036, 81.42119497060776, 79.7984616458416, 83.33677858114243, 81.77714467048645, 79.93982926011086, 75.97100302577019, 71.42198592424393, 65.41242599487305, 59.084412753582, 62.97690108418465, 63.67485523223877, 66.32458224892616, 65.56232795119286, 60.19548453390598, 62.220528870821, 64.66785594820976, 63.76174136996269, 61.84577018022537, 61.77454300224781, 60.63622668385506, 64.43894103169441, 62.04046033322811, 64.44615304470062, 66.73166200518608, 71.45173832774162, 70.26256933808327, 73.10585036873817, 68.9258922636509, 63.57618972659111, 60.37273362278938, 60.10550156235695, 61.45226329565048, 69.28789123892784, 73.97594287991524, 78.98779794573784, 79.89183023571968, 85.43764784932137, 83.91817018389702, 2.1687901485711336, 0.5069850047584623, 0.06380697028362192, 0.08129556154017337, 0.09547312773065642, 0.1785973782534711, 0.10560559574514627, 0.27405830507632345, 0.2532881742808968, 0.4759792622644454, 1.296317302621901, 22.87475924938917, 30.555771589279175, 75.49184873700142, 41.49638392031193, 22.236572094261646, 16.157665885984898, 51.390748992562294, 60.39111703634262, 62.35756851732731, 51.500065326690674, 3.4625124279409647, 0.244568636699114, 0.07744501737761311, 0.07339392264839262, 0.040491150502930395, 0.09019810531754047, 0.04114846327865962, 0.040245466225314885, 0.018035492867056746, 0.028079665717086755, 0.06591746758203954, 0.04212323343381286, 0.04284624483261723, 0.038766013385611586, 0.012669093521253671, 0.0026482431258045835, 0.017139993360615335, 0.02260737859614892, 0.039391072423313744, 0.03544058694387786, 0.015830434822419193, 0.024885755265131593, 0.04766726211528294, 0.06544503121403977, 0.032618774494039826, 0.033739506543497555, 0.056673027502256446, 0.031785368628334254, 0.013518547402782133, 0.0527819806302432, 0.0337657006457448, 0.02681340221897699, 0.02442858301947126, 0.024759367515798658, 0.05329344654455781, 0.05189832023461349, 0.08733244307222776, 0.14803723606746644, 0.037772121795569547, 0.31932144658640027, 32.93420076370239, 107.33406409621239, 102.6943002641201, 74.87115204334259, 57.0865673571825, 70.27341395616531, 42.434010207653046, 58.87432582676411, 105.93009263277054, 110.98651930689812, 86.59169152379036, 8.327507749199867, 0.3851931681856513, 0.15692720044171438, 0.21991247223922983, 0.08091429801424965, 0.2150109430658631, 0.13560510473325849, 0.14245042257243767, 0.25404454150702804, 0.1604355254676193, 3.1314452178776264, 94.26827520132065, 96.95109084248543, 116.42338916659355, 109.13098007440567, 105.03948122262955, 95.24384245276451, 80.6238305568695, 77.91839852929115, 77.96003669500351, 74.66679140925407, 78.57636362314224, 77.33319193124771, 81.71289771795273, 84.59400951862335, 88.35551887750626, 88.19447591900826, 90.04785686731339, 88.07099014520645, 91.17763504385948, 89.43118795752525, 89.03410166501999, 79.27507013082504, 68.31377550959587, 67.6683421432972, 67.7860826253891, 70.03506034612656, 69.0047836303711, 71.5541884303093, 71.48287385702133, 66.48029029369354, 66.17678537964821, 73.08311998844147, 89.09340128302574, 94.03538569808006, 89.24347802996635, 88.86450916528702, 89.56503197550774, 85.77396020293236, 88.6534532904625, 86.92726671695709, 87.420434653759, 84.11099463701248, 83.62895250320435, 78.44944283366203, 84.5308493077755, 70.0483064353466, 73.37473914027214, 83.15611347556114, 87.15596124529839, 46.24613285064697, 77.6520024240017, 88.47252979874611, 70.9599307179451, 74.75339636206627, 84.51273187994957, 84.87792268395424, 83.15159931778908, 87.65225261449814, 83.68218004703522, 83.48932519555092, 78.2497787475586, 76.0740002989769, 72.02887415885925, 61.97402849793434, 66.54072225093842, 67.24080428481102, 69.22738328576088, 69.21830177307129, 65.83662003278732, 64.69252422451973, 68.07783856987953, 66.23727053403854, 65.13470649719238, 65.75280413031578, 64.3963149189949, 66.21165990829468, 64.54995587468147, 66.69783622026443, 70.20330771803856, 75.73291540145874, 74.6380877494812, 75.80929890275002, 71.31994619965553, 66.00682809948921, 65.13911426067352, 63.552319407463074, 66.08940526843071, 70.7335464656353, 78.19065392017365, 81.81386590003967, 87.10061341524124, 85.93947932124138, 93.2290917634964, 4.868649775162339, 0.7931467588059604, 0.10589245066512376, 0.14195353985996917, 0.1478462666273117, 0.43697287095710635, 0.15767535951454192, 0.31155454460531473, 0.28353508561849594, 0.3488819900667295, 0.8421149686910212, 29.376871548593044, 28.640940338373184, 42.72366486489773, 25.517720729112625, 28.08589082211256, 29.57966286689043, 62.65217810869217, 72.27801159024239, 70.87397933006287, 71.54611766338348, 9.113275185227394, 0.37162837106734514, 0.03790298098465428, 0.1401107426499948, 0.20369425968965515, 0.1463173088268377, 0.0714807549957186, 0.10552723979344591, 0.03792861847614404, 0.07303478996618651, 0.07317466996028088, 0.09506887246971019, 0.017652511269261595, 0.04522207105765119, 0.06269257617532276, 0.0470247588964412, 0.020608760059985798, 0.06183595964103006, 0.06985398955293931, 0.013611690646939678, 0.047337433134089224, 0.03570517372281756, 0.1173569104867056, 0.16237247153185308, 0.18093357008183375, 0.12731783848721534, 0.17846181755885482, 0.1821851872955449, 0.20538790005957708, 0.1100002825842239, 0.13136417604982853, 0.1777099329046905, 0.19538239866960794, 0.25925311201717705, 0.2997691207565367, 0.2066845359513536, 0.2510693308431655, 0.342502310522832, 0.3193036053562537, 0.6621013500262052, 45.93914732336998, 127.92194455862045, 120.05649581551552, 91.04504495859146, 78.40802505612373, 85.50818726420403, 61.243228912353516, 65.98910585045815, 122.20718801021576, 135.94480365514755, 103.01839247345924, 12.932933773845434, 0.4742037778487429, 0.8213480142876506, 0.36043420142959803, 0.7092675066087395, 0.660177287645638, 0.4327357420697808, 0.3250201017362997, 0.8653419942129403, 2.5414067041128874, 2.408210076391697, 96.04808449745178, 100.710768699646, 118.94102767109871, 117.21034213900566, 110.27423232793808, 100.14175683259964, 84.00346800684929, 82.25973397493362, 81.0556697845459, 77.97416433691978, 83.53919371962547, 84.48697686195374, 84.01463180780411, 91.12428590655327, 93.31068858504295, 95.0286827981472, 92.64036655426025, 92.98056229948997, 94.3225970864296, 94.964200258255, 92.75354728102684, 83.67774948477745, 72.60847225785255, 70.68335115909576, 72.2187651693821, 73.75753819942474, 72.25822985172272, 73.98882418870926, 73.02150249481201, 70.11880025267601, 69.38969537615776, 77.85426557064056, 92.94463142752647, 96.76808506250381, 94.77799504995346, 94.0970791876316, 94.33256775140762, 88.78673493862152, 91.53567463159561, 92.23088532686234, 92.81532436609268, 90.37708640098572, 89.88591715693474, 82.74205729365349, 89.88529399037361, 74.6255712211132, 77.29299768805504, 87.79603689908981, 91.85922726988792, 51.447696536779404, 83.6993171274662, 94.16748180985451, 75.45972526073456, 79.31451201438904, 87.70751684904099, 87.72350639104843, 86.59502774477005, 90.30364394187927, 89.09121260046959, 88.08131039142609, 81.45933732390404, 78.60486209392548, 73.7017571926117, 65.07318779826164, 71.07804358005524, 70.121710896492, 72.71091476082802, 72.7018940448761, 67.83373966813087, 67.49374151229858, 72.9708968102932, 70.90679436922073, 69.48918163776398, 69.7624097764492, 66.7502050101757, 71.77285149693489, 70.20409807562828, 71.5446737408638, 73.45289334654808, 78.43747347593307, 77.69782796502113, 80.2603268623352, 76.80986121296883, 70.61140581965446, 69.51610699295998, 67.8979030251503, 69.70334574580193, 75.97077503800392, 83.54196757078171, 85.35795852541924, 91.39810681343079, 92.27807119488716, 98.51780757308006, 3.7711406545713544, 1.2614007387310266, 0.6095341395121068, 0.3474321897374466, 0.3714807133655995, 0.5622196721378714, 0.46097285812720656, 0.5983429681509733, 0.9712799533735961, 0.4551176988752559, 2.535607027821243, 41.345904394984245, 50.77706292271614, 99.86112669110298, 56.22746005654335, 30.50825133919716, 28.269464671611786, 72.20575466752052, 85.0909772515297, 86.3420981168747, 90.47040179371834, 12.58593449369073, 0.5386736418586224, 0.3020999988075346, 0.3036441112635657, 0.36543324880767614, 0.18370038567809388, 0.12704115099040791, 0.2874667168362066, 0.11450699661509134, 0.20427559880772606, 0.18574317684397101, 0.14259762014262378, 0.14565105317160487, 0.16726102796383202, 0.17653316870564595, 0.09244971457519569, 0.09223515226040035, 0.11381600517779589, 0.076078263373347, 0.09085676138056442, 0.07134515719371848, 0.14363774011144415], [0.05439081207441632, 0.08315396611578763, 0.03959855836001225, 0.04039871600980405, 0.04092552211659495, 0.03538675155141391, 0.05317263232427649, 0.11331409070407972, 0.1025231002131477, 0.008758765652601141, 0.030926824365451466, 0.104067843494704, 0.026700271082518157, 0.04615709920472, 0.026410814934934024, 0.02814502480759984, 0.08161030636983924, 0.18878106930060312, 51.1027966439724, 92.24549174308777, 80.50123393535614, 71.92113474011421, 72.31332689523697, 52.321448251605034, 68.40858042240143, 56.76274873316288, 86.53807640075684, 99.72576275467873, 18.840701915323734, 0.10271588049363345, 0.23065586137818173, 0.01605977515282575, 0.10306311654858291, 0.10436090276925825, 0.1657768216682598, 0.17149373365100473, 0.18512355774873868, 0.09588615517714061, 0.5636733316350728, 60.07389485836029, 114.9578458070755, 106.7040503025055, 106.8553201854229, 99.5441173017025, 100.44017761945724, 81.97779670357704, 77.33663454651833, 71.4770981669426, 73.66774141788483, 72.64657661318779, 72.47624695301056, 68.32427054643631, 73.02433714270592, 73.75813096761703, 74.5965787768364, 73.76677930355072, 75.31862363219261, 72.64471471309662, 73.90882328152657, 69.20277580618858, 68.3051423728466, 63.39428968727589, 66.66172295808792, 64.07935872673988, 68.84570896625519, 65.25473445653915, 66.50722324848175, 66.50119677186012, 65.01315101981163, 61.62603177130222, 67.53991663455963, 79.17113810777664, 87.71330773830414, 78.70791256427765, 81.67436018586159, 82.64875710010529, 86.82833522558212, 84.43497285246849, 86.44727647304535, 80.15224546194077, 76.6594272851944, 68.98576945066452, 69.73285496234894, 69.29245859384537, 73.8670027256012, 62.876305282115936, 73.15926790237427, 75.17882913351059, 83.01789969205856, 38.64951588213444, 68.69142964482307, 86.9472536444664, 65.48171907663345, 68.42010140419006, 72.34074622392654, 78.03999960422516, 81.41130030155182, 79.06643852591515, 79.51533123850822, 78.70181769132614, 79.30055156350136, 79.59003522992134, 80.16233012080193, 70.69156631827354, 62.81805440783501, 61.76629364490509, 64.67401161789894, 66.34747222065926, 64.99669030308723, 63.32613654434681, 64.82427075505257, 62.227763682603836, 60.60768261551857, 59.49220687150955, 62.147515788674355, 59.92851085960865, 63.66388142108917, 59.390414133667946, 63.77456948161125, 66.28624230623245, 73.36380332708359, 68.93837079405785, 69.43606048822403, 62.55078814923763, 60.328359603881836, 58.68011064827442, 62.117615193128586, 62.82493583858013, 75.12937098741531, 76.08514130115509, 83.91494035720825, 78.3846715092659, 98.64965289831161, 37.13918052613735, 0.38268459029495716, 0.2152549018501304, 0.060295877046883106, 0.073053492087638, 0.007520519620811683, 0.33905438147485256, 0.06181417760672048, 0.33904648502357304, 0.12567941390443593, 0.33489874040242285, 6.790961874648929, 21.193735152482986, 64.23968732357025, 73.60689908266068, 38.86097453534603, 24.80997260659933, 21.227826923131943, 52.952841371297836, 57.51813679933548, 70.3172180056572, 33.92178677022457, 1.536266589537263, 0.03342809395689983, 0.01064449425030034, 0.1554723980370909, 0.03152959114231635, 0.06294858001638204, 0.008034957372728968, 0.06995742267463356, 0.022304769736365415, 0.0793446037278045, 0.03249822373618372, 0.020989019831176847, 0.022109345554781612, 0.03181111744197551, 0.01727292128634872, 0.02725408394326223, 0.03148771917039994, 0.01508713032308151, 0.023678409015701618, 0.04199595881800633, 0.03582551667932421, 0.027422139573900495, 0.06581161505891941, 0.04322927838074975, 0.05136100902745966, 0.05564097096794285, 0.03408352909900714, 0.044377941158018075, 0.05966803495539352, 0.01907223977468675, 0.009606257481209468, 0.05989842728013173, 0.026076330832438543, 0.03947884251829237, 0.07061042357236147, 0.012450740687199868, 0.029130741640983615, 0.10256328750983812, 0.2927409822586924, 63.68861049413681, 104.72744956612587, 93.2336363196373, 80.88846355676651, 81.69196084141731, 58.23410578072071, 57.79375120997429, 70.33847406506538, 96.38008028268814, 113.06817680597305, 21.925898864865303, 0.1673154125455767, 0.18360349087743089, 0.11769705160986632, 0.18703602778259665, 0.07995898326043971, 0.2879167255014181, 0.18104318529367447, 0.10188302752794698, 0.10677158395992592, 0.8366069267503917, 71.40494003891945, 117.2485376894474, 109.91316050291061, 108.73352140188217, 102.84435421228409, 102.06485643982887, 86.66653990745544, 78.98782834410667, 77.35721424221992, 77.96737030148506, 74.55429464578629, 74.9126686155796, 72.65204831957817, 77.88459554314613, 77.89366945624352, 77.57230550050735, 76.82825222611427, 78.18240076303482, 75.14124155044556, 73.93527746200562, 73.03069040179253, 71.30871400237083, 67.78533786535263, 69.58332538604736, 67.62850508093834, 70.14166742563248, 67.9178823530674, 68.47063109278679, 70.66481575369835, 67.56862789392471, 64.62131604552269, 68.34668934345245, 83.71219843626022, 90.5902549624443, 80.83722710609436, 85.46395003795624, 84.09682139754295, 89.4902291893959, 88.6832968890667, 89.68072056770325, 81.94020912051201, 79.65961709618568, 70.90840548276901, 73.61564621329308, 74.70183312892914, 77.30904802680016, 66.27560287714005, 77.36680492758751, 80.18757596611977, 86.63491040468216, 42.09875799715519, 73.07170540094376, 91.09353795647621, 70.46604841947556, 71.13073915243149, 74.4538888335228, 80.95321208238602, 82.68742382526398, 82.11073637008667, 82.8997640311718, 81.8232361972332, 82.52380460500717, 85.01041397452354, 83.57662171125412, 75.08391782641411, 66.75912693142891, 65.81528797745705, 67.36636474728584, 68.6568059027195, 67.26276710629463, 66.87767297029495, 66.47945433855057, 65.26564747095108, 63.59278343617916, 62.87493735551834, 65.64283043146133, 64.24703612923622, 65.78547477722168, 62.91267313063145, 66.61157324910164, 69.6805089712143, 75.52514255046844, 73.0792061984539, 72.1072943508625, 65.48421174287796, 64.5257967710495, 63.049515187740326, 65.59002846479416, 65.8551174402237, 77.90691554546356, 78.04170191287994, 86.36378735303879, 81.15973100066185, 98.22406813502312, 48.86732339859009, 0.03724574242369272, 0.2546628098934889, 0.045764224778395146, 0.13800439395708963, 0.014351815971167525, 0.5991001368965954, 0.09606279374565929, 0.442840171745047, 0.07989109159098007, 0.32111426757182926, 6.808682698756456, 26.20590940117836, 43.15578147768974, 48.003173768520355, 30.31874790787697, 31.867795586586, 31.566802337765694, 63.51852402091026, 68.18633794784546, 81.76842033863068, 52.30816416442394, 1.5714199282228947, 0.04626574591384269, 0.019983370766567532, 0.04518733483564574, 0.03698656219057739, 0.03299895819509402, 0.050947050185641274, 0.035158036480424926, 0.03660155452962499, 0.01025310226395959, 0.030781124078202993, 0.03782984604185913, 0.006423849390557734, 0.04083959625859279, 0.0394732801214559, 0.05116731219459325, 0.10067184994113632, 0.040737970266491175, 0.03294113375886809, 0.04193014887277968, 0.028355872673273552, 0.20156598795438185, 0.1824579414096661, 0.09844166648690589, 0.20711946417577565, 0.1920899050310254, 0.14347081625601277, 0.21047793474281207, 0.13905174244428053, 0.1556952649843879, 0.09103629432502203, 0.1583578682038933, 0.211395273800008, 0.1378217662568204, 0.2407414701883681, 0.09933554625604302, 0.13004287116928026, 0.16427746071713045, 0.941326932515949, 84.63973626494408, 120.2911788225174, 107.20436945557594, 100.02817332744598, 96.02470815181732, 71.00723057985306, 98.56031209230423, 85.07919028401375, 107.12597206234932, 123.30250963568687, 31.533314734697342, 0.33051763486582786, 0.39188131398987025, 0.36003504472319037, 0.25611436169128865, 0.3760345315095037, 0.5889614496845752, 0.6311009509954602, 0.5023914074990898, 0.3284315764904022, 1.1686641024425626, 74.03249904513359, 120.80945581197739, 112.29374036192894, 116.37409821152687, 106.1231754720211, 109.32722434401512, 89.77434754371643, 85.23213967680931, 81.42995730042458, 83.24249044060707, 81.20193913578987, 80.67324310541153, 76.31304547190666, 83.66967871785164, 83.2669535279274, 81.83906614780426, 82.1331399679184, 83.67416247725487, 81.07780739665031, 79.85434144735336, 77.02834188938141, 75.64634844660759, 70.742377191782, 72.48140707612038, 71.33446902036667, 73.8423040509224, 71.78350612521172, 72.00165241956711, 73.8863056898117, 70.84295019507408, 65.9687389433384, 72.44533181190491, 87.61419385671616, 92.45327219367027, 84.70939412713051, 87.74284735321999, 89.03963416814804, 94.62776631116867, 92.99398317933083, 94.20601174235344, 87.5360244512558, 83.88809859752655, 76.53452798724174, 78.43485161662102, 78.01533132791519, 81.88933745026588, 69.99456971883774, 82.20725879073143, 84.49576959013939, 89.17013436555862, 47.70540654659271, 78.32605585455894, 93.63164216279984, 74.93400067090988, 75.89483231306076, 79.86383333802223, 85.34408926963806, 88.72430428862572, 86.15463137626648, 86.62377700209618, 83.55897545814514, 85.97080484032631, 88.09458687901497, 86.27703800797462, 77.78858989477158, 70.88271886110306, 68.57395514845848, 69.96825993061066, 71.50106728076935, 72.22732231020927, 70.1102963089943, 70.75004518032074, 68.77768501639366, 67.55336031317711, 66.44771084189415, 69.4946077466011, 67.82840475440025, 69.30171489715576, 66.30451932549477, 71.06928125023842, 72.8672307729721, 81.68518960475922, 76.30760416388512, 78.44559744000435, 68.5323777794838, 68.89231726527214, 65.38149565458298, 70.7897986471653, 70.05029752850533, 84.37948822975159, 84.14720669388771, 92.54069790244102, 86.95852383971214, 107.33183741569519, 45.11481575667858, 0.34511556092184037, 0.7542982371523976, 0.13234942161943763, 0.49332001770380884, 0.19076346448855475, 1.2636001082137227, 0.2900870027951896, 0.5935708992183208, 0.30122375988867134, 0.3247194131836295, 11.801572032272816, 37.80764065682888, 90.73839381337166, 101.23424381017685, 52.0926321297884, 35.661113038659096, 35.513688549399376, 79.8251362144947, 83.14263939857483, 101.90963476896286, 66.2319204211235, 1.8216115655377507, 0.16380270884837955, 0.15821212524315342, 0.18824102327926084, 0.13716897316044196, 0.12614307808689773, 0.12600315356394276, 0.18648023338755593, 0.10110908624483272, 0.16834322770591825, 0.17754814471118152, 0.16412863042205572, 0.14775394345633686, 0.11640590018942021, 0.1262695697369054, 0.12776717921951786, 0.13708270591450855, 0.14694190031150356, 0.14926163130439818, 0.2665944962063804, 0.05761756627180148], [0.011829243958345614, 0.01847019844717579, 0.014303965072031133, 0.07839885525754653, 0.10450586647493765, 0.034202324677607976, 0.02406981398962671, 0.03774102580791805, 0.0356666785228299, 0.03284418329712935, 0.056746622576611117, 0.05448846386570949, 0.0880968254932668, 0.04169794941844884, 0.027031033314415254, 0.0648851327423472, 0.06214341658051126, 20.35400301218033, 86.85021445155144, 85.60432210564613, 71.01739883422852, 85.31929939985275, 33.296298533678055, 31.59721400588751, 60.76447740197182, 78.54950666427612, 108.75540062785149, 52.00392588973045, 1.8547612242400646, 0.062426820513792336, 0.0483858725783648, 0.21126896026544273, 0.23655158642213792, 0.17021430074237287, 0.18540226388722658, 0.32746423152275383, 0.1294725900515914, 0.8769621269311756, 33.23141701519489, 117.86170318722725, 99.17214006185532, 103.20832148194313, 96.51668295264244, 99.55164849758148, 89.3417027592659, 77.59272560477257, 72.33205989003181, 74.69906687736511, 68.60715016722679, 71.70460715889931, 68.61330583691597, 67.4537980556488, 64.8399031162262, 65.88003650307655, 66.2515577673912, 66.6246597468853, 63.60586613416672, 62.916632518172264, 64.30964156985283, 67.33505442738533, 66.46324440836906, 66.68522849678993, 63.736404329538345, 63.22681367397308, 62.932625859975815, 62.92923264205456, 65.15498980879784, 64.19563248753548, 63.10280352830887, 64.44069653749466, 71.37929141521454, 84.98664245009422, 83.30118209123611, 82.04547107219696, 82.95291557908058, 80.31669303774834, 76.95884361863136, 72.05991089344025, 67.75455951690674, 65.98187863826752, 61.24751888215542, 60.20269274711609, 61.86310485005379, 63.18410016596317, 66.92396968603134, 61.61834478378296, 73.27924266457558, 77.65000373125076, 81.02275595068932, 39.07689034938812, 70.84335297346115, 85.33341184258461, 65.93710944056511, 63.273893147706985, 64.40665036439896, 71.4494888484478, 73.51032346487045, 78.75272735953331, 76.40725761651993, 79.66904059052467, 79.68389019370079, 76.55861109495163, 77.57167473435402, 80.37964046001434, 63.69327664375305, 61.77729405462742, 61.596723943948746, 63.171188458800316, 60.90939022600651, 61.005661860108376, 59.07797209918499, 59.598578363657, 60.709448754787445, 61.215855181217194, 58.64315763115883, 63.06972250342369, 60.35165995359421, 61.75910443067551, 60.84550425410271, 67.31232404708862, 66.45420849323273, 70.06680384278297, 63.2504940032959, 62.00405828654766, 57.90603518486023, 59.14823032915592, 60.03533832728863, 62.70091809332371, 65.26220485568047, 77.18523547053337, 75.89766696095467, 81.89075097441673, 80.48900619149208, 93.5233023762703, 9.654976017773151, 0.3583523881388828, 0.1216595561709255, 0.10524960234761238, 0.10182425685343333, 0.0563933565717889, 0.18020175310084596, 0.1652746697072871, 0.17128962819697335, 0.07243342028232291, 0.09584050567355007, 15.580738093703985, 23.456380739808083, 57.913440987467766, 60.07709428668022, 28.90647578984499, 26.30618792027235, 36.99933283030987, 57.926075309515, 53.36695075035095, 60.213681757450104, 19.540890343487263, 0.4569508333224803, 0.025423547012906056, 0.04736095179396216, 0.033832416011136957, 0.04586412898788694, 0.021421827368612867, 0.06274400700931437, 0.07990022742887959, 0.04975898678821977, 0.03887581413437147, 0.0990077322057914, 0.04065566237841267, 0.019393875445530284, 0.03201416533556767, 0.02813940303894924, 0.010424723914184142, 0.046637216801173054, 0.018066646371153183, 0.028911592853546608, 0.042612935867509805, 0.022021981785655953, 0.04142441233852878, 0.01598553812073078, 0.07344251847825944, 0.0254085983033292, 0.034886725843534805, 0.0696200349193532, 0.03439758002059534, 0.04540732967143413, 0.01753228520101402, 0.03230739530408755, 0.11213539692107588, 0.04283284906705376, 0.023015589504211675, 0.01733105927996803, 0.06948025882593356, 0.11935043788980693, 22.927038744091988, 104.12673220038414, 94.38527092337608, 86.77817791700363, 91.59232959151268, 48.15167360007763, 47.8919043391943, 63.97576108574867, 88.32181468605995, 118.75928342342377, 62.27996528148651, 2.4116553040221334, 0.07755046914098784, 0.3118044405709952, 0.41686280630528927, 0.25891920493450016, 0.2661428548162803, 0.15661346493288875, 0.10166718129767105, 0.06851298065157607, 1.104109960142523, 43.608595579862595, 120.0156632065773, 104.5973901450634, 109.04098570346832, 101.83268129825592, 105.35894528031349, 92.3274989426136, 80.41340544819832, 74.64780002832413, 76.4696654677391, 71.81612357497215, 74.43815767765045, 72.6042240858078, 70.92035964131355, 69.16845604777336, 68.73641923069954, 69.92857486009598, 70.5164185166359, 67.08541542291641, 67.4727514386177, 69.11041036248207, 69.45074290037155, 70.64691871404648, 68.58279347419739, 67.24047750234604, 66.93968564271927, 64.63651522994041, 65.29049813747406, 68.70828554034233, 67.46268197894096, 65.81667870283127, 67.37331077456474, 74.57191050052643, 88.86104375123978, 84.44414556026459, 85.21586894989014, 85.450369566679, 83.18445235490799, 78.26193809509277, 76.22159957885742, 70.05763113498688, 67.90799528360367, 65.46163335442543, 62.127202078700066, 67.09327340126038, 68.7977783381939, 70.00014021992683, 67.20244914293289, 76.207684725523, 80.83093464374542, 82.8483983874321, 43.73767465353012, 76.1386576294899, 86.07871904969215, 69.50139418244362, 66.39981061220169, 67.99738928675652, 74.17188316583633, 75.07460832595825, 82.51311957836151, 78.74872237443924, 80.89949056506157, 81.75800889730453, 79.26253080368042, 79.57453966140747, 84.1870665550232, 65.8257070183754, 64.83427181839943, 62.78107859194279, 66.09729364514351, 63.93503487110138, 63.44114497303963, 62.358765453100204, 62.23964184522629, 62.673012390732765, 64.56039011478424, 60.82572251558304, 65.0905604660511, 61.64076738059521, 64.94628220796585, 62.43980750441551, 71.54525890946388, 70.33129245042801, 73.54257613420486, 67.218317091465, 65.28150781989098, 62.129200771450996, 63.31445597112179, 61.997982412576675, 66.3370531797409, 67.99382507801056, 81.08286112546921, 79.58818092942238, 86.73954918980598, 83.08702558279037, 99.91794884204865, 16.06901854276657, 0.43476563470903784, 0.2269134481321089, 0.18419829255435616, 0.2039574400987476, 0.11369310552254319, 0.19667841115733609, 0.10319797962438315, 0.4736694018356502, 0.1119451918930281, 0.15642908576410264, 16.639590226113796, 30.870121121406555, 40.029613226652145, 41.81558579206467, 36.13020546734333, 32.65314884483814, 48.85848127305508, 69.33910489082336, 65.52744582295418, 78.77022922039032, 31.31521213799715, 0.5029253382235765, 0.011924325135623803, 0.02888908908062149, 0.1015847286907956, 0.06984974446822889, 0.03915924775355961, 0.014272587995947106, 0.049654674221528694, 0.06107192602939904, 0.06269417179282755, 0.028284576401347294, 0.025739631419128273, 0.08098371108644642, 0.03722791232576128, 0.07909403240773827, 0.03940554059226997, 0.016831475149956532, 0.06164805898151826, 0.013512646401068196, 0.04078156031027902, 0.11400216550100595, 0.12417324745911174, 0.07139914843719453, 0.20071906386874616, 0.25869795586913824, 0.17638616409385577, 0.14718440448632464, 0.12318317050812766, 0.11772265570471063, 0.07477906707208604, 0.12421813255059533, 0.15222143498249352, 0.15559373918222263, 0.09756204337463714, 0.08045798851526342, 0.22078505979152396, 0.25305570394266397, 32.77461312711239, 123.19378226995468, 110.27293279767036, 103.08887869119644, 113.74378815293312, 52.31791824102402, 46.55091069638729, 84.64244931936264, 98.32219406962395, 130.1704967021942, 77.89791002869606, 4.317372031509876, 0.21020148473326117, 0.6140493066050112, 0.5776048684492707, 0.48103500972501934, 0.6393289938569069, 0.4860332258976996, 0.6653529067989439, 0.34481760347262025, 2.3520500399172306, 42.69102841615677, 123.09553474187851, 107.82820478081703, 113.2373209297657, 106.43219009041786, 111.45516335964203, 98.97156402468681, 85.85308715701103, 78.8988447189331, 80.9773787856102, 75.21667510271072, 81.22757256031036, 78.21756407618523, 76.1638730764389, 72.38711893558502, 71.83199152350426, 74.41951587796211, 74.55803364515305, 71.18033409118652, 70.89182317256927, 73.255934715271, 73.28244209289551, 74.17214155197144, 72.00968518853188, 68.94272536039352, 71.7835745215416, 68.36869776248932, 69.40748602151871, 72.59465619921684, 68.28571781516075, 66.83481886982918, 70.66659405827522, 77.3089948296547, 91.4188764989376, 87.89662510156631, 88.59928339719772, 89.88115221261978, 88.30868259072304, 83.73448804020882, 81.95375919342041, 74.3633396923542, 72.79394030570984, 70.29661551117897, 65.41253238916397, 71.01945832371712, 72.45917826890945, 76.2840986251831, 70.71570262312889, 82.25726410746574, 84.32315245270729, 88.03814470767975, 48.36958430707455, 77.57094517350197, 93.94856795668602, 73.40293362736702, 71.95274144411087, 72.33255386352539, 77.38896533846855, 79.20905247330666, 85.84384605288506, 82.55926430225372, 86.34415000677109, 85.95682919025421, 82.53712669014931, 86.20162725448608, 86.79694890975952, 71.46458923816681, 69.06090661883354, 68.53871583938599, 69.48871806263924, 66.71450972557068, 66.05212926864624, 66.55089050531387, 65.212412327528, 68.51330280303955, 66.84656023979187, 64.26383882761002, 71.1412113904953, 66.45949020981789, 68.70878711342812, 66.9771060347557, 76.50218412280083, 75.75708970427513, 77.1645113825798, 70.56246444582939, 70.88689103722572, 66.41634732484818, 69.30806815624237, 66.2961445748806, 69.95702773332596, 71.62538141012192, 85.90708985924721, 84.32862415909767, 92.13701516389847, 87.0432896912098, 104.94076251983643, 13.547553643584251, 0.4026468488154933, 0.4700841457815841, 0.39084717573132366, 0.6529101775959134, 0.3178955434123054, 0.42994529649149626, 0.2647877822164446, 0.3565369761781767, 0.25964336295146495, 0.3301379521144554, 28.6789420992136, 41.49558216333389, 79.14833933115005, 80.94364419579506, 39.25941355526447, 39.68849413096905, 56.64132244884968, 85.99018380045891, 81.76471933722496, 97.84821510314941, 37.46389590203762, 0.4204319725977257, 0.14440087572438642, 0.1445123166195117, 0.3195314743788913, 0.1966601691674441, 0.08830297185340896, 0.06752556801075116, 0.11484896342153661, 0.18764495995128527, 0.1530828606337309, 0.15690640546381474, 0.1801045614411123, 0.14400198619114235, 0.13816723600029945, 0.21709075255785137, 0.17326589324511588, 0.08710339403478429, 0.13157699431758374, 0.08728220709599555, 0.24528675363399088], [0.0557970557565568, 0.04480291718209628, 0.03652610779681709, 0.03473055941867642, 0.02233650397101883, 0.006589143304154277, 0.08001198002602905, 0.03613602013501804, 0.008938838509493507, 0.08994744493975304, 0.04672368442697916, 0.052435891193454154, 0.08671032293932512, 0.03427544477744959, 0.03693063023092691, 0.03541768797731493, 1.0960452491417527, 52.421572878956795, 77.1659705042839, 64.64873537421227, 47.735413536429405, 38.82824309170246, 28.046124055981636, 35.011233910918236, 79.3185093998909, 98.06255400180817, 73.09670805931091, 15.404426604509354, 0.2586574642919004, 0.3279594815103337, 0.13187530799768865, 0.17582501139258966, 0.2040386458975263, 0.19808277720585465, 0.15298771730158478, 0.20516451360890642, 0.6910683831665665, 13.132936041802168, 116.61454170942307, 97.81598523259163, 106.37479797005653, 97.87270098924637, 94.22874212265015, 85.87950333952904, 80.26146680116653, 71.94741412997246, 72.5270502269268, 68.86652424931526, 69.12114098668098, 67.5801032781601, 67.53787234425545, 66.29572659730911, 65.6806991994381, 63.988239616155624, 64.70895454287529, 66.38954356312752, 66.22824981808662, 67.41910591721535, 68.11072960495949, 64.05588358640671, 65.35524666309357, 63.98831561207771, 66.54491722583771, 64.96537238359451, 58.920903727412224, 64.46192219853401, 64.93064984679222, 63.90150547027588, 61.056693121790886, 64.74993154406548, 76.0378110408783, 82.48854249715805, 81.58507257699966, 83.8982592523098, 75.74082657694817, 71.06066331267357, 65.88347911834717, 69.46262866258621, 64.15679097175598, 64.21283796429634, 61.69100448489189, 60.65266080200672, 59.93165709078312, 62.42202065885067, 61.681497395038605, 66.12214431166649, 74.91646841168404, 81.88493728637695, 74.04604151844978, 44.421900138258934, 82.99485772848129, 72.77800396084785, 67.31712698936462, 66.67034849524498, 74.06670480966568, 73.04503843188286, 75.52386581897736, 77.30992197990417, 74.81041610240936, 75.48183247447014, 76.3159941136837, 73.3055904507637, 78.20565551519394, 76.873469799757, 61.68077163398266, 64.41973686218262, 61.84300012886524, 61.12413950264454, 59.767920076847076, 60.66546991467476, 61.899993270635605, 58.760445937514305, 57.145711183547974, 59.10637177526951, 59.567526429891586, 58.09976778924465, 59.59450118243694, 62.09462642669678, 58.93009163439274, 63.05705398321152, 65.34782186150551, 64.89524334669113, 63.663368448615074, 61.06882967054844, 57.553995475173, 58.61694663763046, 58.1215900182724, 61.03083170950413, 64.88813012838364, 75.5919961631298, 77.64195576310158, 81.25810012221336, 79.74891990423203, 91.86954751610756, 65.47124683856964, 0.09468848467804492, 0.12719814490992576, 0.07649015533388592, 0.10605276198475622, 0.12508747691754252, 0.054780625141575, 0.007207520693555125, 0.1990922464756295, 0.18738792452495545, 0.03227444023650605, 0.5507133551873267, 24.591170847415924, 35.08371502161026, 70.27013093233109, 37.318112924695015, 27.331819385290146, 34.026208966970444, 50.15017256140709, 57.88151130080223, 58.54875169694424, 53.96267518401146, 8.790360912680626, 0.04635899305867497, 0.059413515409687534, 0.02391973503108602, 0.02495684373570839, 0.07500992694986053, 0.049001049919752404, 0.1291026739636436, 0.052760977850994095, 0.030288332454802003, 0.05934857006650418, 0.03840708850475494, 0.02474277680448722, 0.027812316293420736, 0.0438463927275734, 0.006956845008971868, 0.021644469816237688, 0.026703564362833276, 0.0037083110964886146, 0.07630972439073958, 0.05907501814363059, 0.05853444890817627, 0.026517257465457078, 0.028024114108120557, 0.05558096461754758, 0.07256138138473034, 0.04703560167399701, 0.020462269385461695, 0.03277681484178174, 0.08767950101173483, 0.01879622577689588, 0.0650363379099872, 0.06772057473426685, 0.004534550598691567, 0.010532489322940819, 0.03942821320379153, 1.23082235455513, 64.83259230852127, 93.11816051602364, 75.4827444255352, 64.64362844824791, 61.17287188768387, 40.64658232033253, 27.914417423307896, 68.1204342842102, 107.61694371700287, 85.7356658577919, 19.395386651158333, 0.49665332946460694, 0.0980729675211478, 0.6784116779454052, 0.20490299561060965, 0.17599208367755637, 0.26279342360794544, 0.5230782099533826, 0.13236965256510302, 1.0608173394575715, 18.5032819211483, 124.64020505547523, 102.27466598153114, 111.29782900214195, 99.18538615107536, 97.24163845181465, 89.1396751999855, 84.09859210252762, 75.7442919909954, 79.16543841362, 73.27853590250015, 72.75518998503685, 70.99504083395004, 73.17596420645714, 70.2108085155487, 69.95958879590034, 67.37509667873383, 68.24381366372108, 69.39836651086807, 67.97014474868774, 70.89568376541138, 72.34507039189339, 67.59204223752022, 68.97389888763428, 65.73295399546623, 68.94907861948013, 68.00659239292145, 64.00841653347015, 66.65997505187988, 68.6267039179802, 66.53167113661766, 63.62542748451233, 67.24751472473145, 79.71358940005302, 85.28181061148643, 86.03338748216629, 86.42218261957169, 80.00732123851776, 73.37182849645615, 69.6562510728836, 72.39278823137283, 67.72777855396271, 68.86568829417229, 66.43669903278351, 64.40915822982788, 61.975274831056595, 66.25462040305138, 64.95310664176941, 69.50393244624138, 78.5746157169342, 84.90580558776855, 76.91839098930359, 48.885714411735535, 86.265699416399, 76.58006474375725, 68.50333973765373, 69.4204281270504, 77.67205774784088, 77.33006089925766, 79.721120595932, 79.26711335778236, 79.07434970140457, 78.45719441771507, 82.33227208256721, 77.71622657775879, 82.28645414113998, 80.01980736851692, 65.93942731618881, 64.65476185083389, 64.02977898716927, 62.81422421336174, 63.875416070222855, 63.889315724372864, 65.93546032905579, 62.72623233497143, 60.836035162210464, 59.13884863257408, 62.1499552577734, 62.51582242548466, 62.4715244024992, 63.12771499156952, 63.77884805202484, 65.51894187927246, 69.53647390007973, 67.8342716395855, 67.20685690641403, 64.5679821074009, 61.48608148097992, 63.02803874015808, 62.164983451366425, 63.140976279973984, 67.59774193167686, 79.08287644386292, 81.32609367370605, 83.72978389263153, 84.22276943922043, 90.77268317341805, 75.66609978675842, 0.5793422064743936, 0.2592389518395066, 0.0527724625862902, 0.03755316967726685, 0.2118380242609419, 0.24574252136517316, 0.3102154133375734, 0.43026243103668094, 0.2968569629592821, 0.19246283423854038, 0.18522815604228526, 29.822903014719486, 36.17531284689903, 42.27479875087738, 25.67399114370346, 37.14428745210171, 44.232647493481636, 61.50563903152943, 72.70891606807709, 70.54556295275688, 70.42510941624641, 13.546492550522089, 0.05870585904631298, 0.04828400909900665, 0.1877323107328266, 0.020289144886191934, 0.10196306815487333, 0.04901556261756923, 0.02302445260284003, 0.07885451908805408, 0.03440973268880043, 0.09253751064534299, 0.027835155888169538, 0.009945612855517538, 0.019140838339808397, 0.05434086182503961, 0.015944115148158744, 0.04408058484841604, 0.031577255576848984, 0.005920393105043331, 0.05222961866820697, 0.14985040674218908, 0.17556672915816307, 0.1721456361701712, 0.09510170508292504, 0.1842856136499904, 0.23391938157146797, 0.1512719164020382, 0.1762584553216584, 0.08105361397610977, 0.22264047351200134, 0.13969077612273395, 0.13440460665151477, 0.152758868644014, 0.10148962246603332, 0.18206433596787974, 0.16316563443979248, 2.471192884258926, 80.85328504443169, 106.89666196703911, 90.81660121679306, 76.7143115401268, 60.40797293186188, 41.28906324505806, 51.88386373221874, 106.76767408847809, 119.33863073587418, 99.72414404153824, 25.938075073063374, 0.7384404412005097, 0.510479926597327, 0.7243098900653422, 0.45368401799350977, 0.3451327490620315, 0.5650153127498925, 0.6480557005852461, 0.4277347947936505, 1.44215133972466, 15.621003583073616, 125.50277397036552, 103.83371472358704, 116.59771621227264, 105.72801947593689, 103.54929238557816, 92.00321674346924, 90.37109792232513, 79.03220996260643, 82.62251570820808, 78.00229802727699, 77.22723081707954, 73.27339097857475, 76.73027068376541, 73.68491649627686, 73.33742514252663, 71.89773559570312, 72.53134399652481, 74.85884830355644, 71.21524661779404, 75.196163803339, 75.2004499733448, 72.14240446686745, 72.54549443721771, 70.0665682554245, 72.87368282675743, 71.15609139204025, 67.01402485370636, 70.79232171177864, 70.6862998008728, 72.35418990254402, 67.19904452562332, 69.40977349877357, 82.91560158133507, 88.9886637032032, 89.80633422732353, 91.87350690364838, 83.75293985009193, 77.83539578318596, 71.84331491589546, 76.48738011717796, 71.18080526590347, 70.81056833267212, 70.40079072117805, 67.93989837169647, 66.43348440527916, 70.54766803979874, 68.44603881239891, 73.60950574278831, 83.42891603708267, 89.15463879704475, 83.12445357441902, 55.457446575164795, 90.23934379220009, 78.97456705570221, 73.83103385567665, 73.18129912018776, 81.17321267724037, 80.48991814255714, 82.20172628760338, 84.16566610336304, 82.1650430560112, 82.6653242111206, 85.49805700778961, 78.9718995988369, 85.58776259422302, 86.52152448892593, 68.87048363685608, 71.38211846351624, 66.5104378759861, 66.03329747915268, 67.95581191778183, 66.8684470653534, 70.1992267370224, 64.73470196127892, 64.6999642252922, 63.95461142063141, 65.88365390896797, 64.88626062870026, 65.72967857122421, 67.54598870873451, 66.11032694578171, 71.55481159687042, 73.59066635370255, 72.58036896586418, 71.69116348028183, 68.72847005724907, 65.28403848409653, 66.93341597914696, 65.96037939190865, 67.3228570818901, 71.16398736834526, 83.33270519971848, 85.47336593270302, 92.38475427031517, 88.34084406495094, 98.84357169270515, 73.90622422099113, 0.41132018028292805, 0.8073348412290215, 0.381952149909921, 0.28100299648940563, 0.29047339456155896, 0.6049640534911305, 0.4774042748613283, 0.8109736209735274, 0.46319003915414214, 0.3833233122713864, 1.0408798092976213, 43.036331087350845, 54.038389921188354, 95.27258411049843, 48.19956623017788, 39.27552089095116, 48.090082705020905, 73.6029776930809, 85.951327085495, 85.24932995438576, 88.12590479850769, 16.066875457763672, 0.19480684830341488, 0.14400116982869804, 0.31664918060414493, 0.09962661657482386, 0.13188566837925464, 0.07093589985743165, 0.20820331148570403, 0.17163546901429072, 0.05634827852190938, 0.1882268037297763, 0.12887532444437966, 0.11590843118028715, 0.1378832309274003, 0.11658827555947937, 0.14790523768169805, 0.10686742491088808, 0.132363106822595, 0.08585165807744488, 0.2143242338206619], [0.05107497789140325, 0.07255724020069465, 0.03985499635746237, 0.03113464241323527, 0.03282355159171857, 0.0528661921271123, 0.04094445059308782, 0.028572782030096278, 0.10541559851844795, 0.037376471736934036, 0.04785458389960695, 0.014613248622481478, 0.006290070778049994, 0.04377146549813915, 0.07085674238624051, 0.192452518385835, 6.295010112226009, 70.22156193852425, 82.1311716735363, 74.28380236029625, 51.478155702352524, 24.367968924343586, 26.226462498307228, 91.27392947673798, 107.59028434753418, 100.58140844106674, 53.90303738415241, 0.7319592358544469, 0.10061477136332542, 0.08132585600833409, 0.35605229437351227, 0.21307288378011435, 0.051416833375697024, 0.13945254671853036, 0.14355257124407217, 0.18479644873877987, 2.579586342908442, 95.06269097328186, 105.38079410791397, 99.74261105060577, 96.9271445274353, 88.44032272696495, 86.91193833947182, 78.26257646083832, 74.15472328662872, 74.36209335923195, 76.42448589205742, 74.52296912670135, 71.38707339763641, 67.2181499004364, 67.59109228849411, 67.53205105662346, 66.32240876555443, 64.95812997221947, 66.73407107591629, 63.22992190718651, 66.36026233434677, 65.72834864258766, 63.875074088573456, 65.76847448945045, 67.2004808485508, 64.76871773600578, 62.23207265138626, 58.4879207611084, 61.05888560414314, 60.136747285723686, 63.553546741604805, 61.48198910057545, 60.9863018989563, 72.36547529697418, 81.63557186722755, 84.40227940678596, 83.08033034205437, 80.06535172462463, 72.72910818457603, 68.00873547792435, 65.7998076081276, 72.5483138859272, 75.55696204304695, 77.1128797531128, 74.42264690995216, 69.22898679971695, 63.22206012904644, 59.57922600209713, 60.65639980137348, 69.15670707821846, 73.01367491483688, 80.77299535274506, 65.12619495391846, 52.55557268857956, 83.62703740596771, 68.76500129699707, 66.35594576597214, 72.04592004418373, 78.02748307585716, 74.65564280748367, 73.92346009612083, 74.36310410499573, 78.58989089727402, 75.72049006819725, 77.42652252316475, 73.97426337003708, 75.97658112645149, 67.19624787569046, 60.20835064351559, 61.938325613737106, 61.28961302340031, 59.786706268787384, 61.74720726907253, 58.75345051288605, 65.59724807739258, 59.16946358978748, 61.9330894947052, 55.39177089929581, 58.7871129065752, 56.181740909814835, 58.870191648602486, 58.578017726540565, 59.156000912189484, 57.721228301525116, 62.45955504477024, 62.889965549111366, 62.2698388248682, 57.334333062171936, 59.53922934830189, 56.74788013100624, 59.08216327428818, 59.17300119996071, 68.51925328373909, 71.04563891887665, 80.83724230527878, 72.81925454735756, 88.0495972931385, 73.55903685092926, 99.94111999869347, 18.302968069911003, 0.5295241484418511, 0.08884071721695364, 0.0654861239308957, 0.08488719264278188, 0.022820018748461735, 0.047706080149509944, 0.4152781725861132, 0.14471980626694858, 0.14375897735590115, 0.1743696301127784, 6.242868835106492, 22.508523501455784, 40.36672733724117, 79.18370023369789, 23.174844346940517, 23.982215523719788, 36.01565681397915, 52.33113773167133, 57.379231452941895, 53.964772671461105, 47.770983427762985, 7.024557664990425, 0.13953295099781826, 0.07125072632334195, 0.022816530654381495, 0.029937478429928888, 0.02928730140411062, 0.028884550847578794, 0.07367658443399705, 0.03623532691563014, 0.12093020312022418, 0.11198882275493816, 0.013089172298350604, 0.11228229763219133, 0.0608867119444767, 0.05904126897803508, 0.05776669713668525, 0.07761445711366832, 0.04153579015110154, 0.041501669911667705, 0.035361548216314986, 0.03300904398201965, 0.04314132274885196, 0.03491920964734163, 0.04578965817927383, 0.0813490035943687, 0.025909512733051088, 0.03460272077063564, 0.02588420178653905, 0.026824562264664564, 0.04024210800707806, 0.06793357111746445, 0.015605274638801347, 0.05903605167986825, 0.07233755706693046, 0.34786622738465667, 9.318278934806585, 89.7203828394413, 94.28177207708359, 86.13222017884254, 59.78729523718357, 33.31181310117245, 35.800835341215134, 56.48803107440472, 107.69384399056435, 113.07167261838913, 64.07864436507225, 0.7083755044732243, 0.06803405791288242, 0.30120939190965146, 1.1225008545443416, 0.8505109744146466, 0.5261001165490597, 0.4251472820760682, 0.35939421504735947, 0.30931596003938466, 4.314385866746306, 105.90607032179832, 103.68664741516113, 108.97941380739212, 100.16764104366302, 92.93313324451447, 86.79500341415405, 84.71014648675919, 76.583621352911, 78.01485255360603, 77.76573792099953, 79.38158601522446, 74.18653517961502, 72.81426921486855, 70.2618245780468, 71.0616284608841, 68.5028001666069, 67.73462578654289, 68.18159580230713, 66.93691179156303, 66.53343424201012, 68.95598664879799, 67.84684896469116, 70.15535429120064, 67.58688971400261, 66.62919670343399, 65.75305491685867, 62.51281678676605, 63.82335886359215, 63.735332787036896, 65.48813313245773, 64.92346823215485, 65.6759874522686, 76.80015653371811, 86.80955663323402, 87.59906306862831, 84.37991380691528, 83.13898399472237, 76.33218124508858, 69.61981102824211, 67.8925909101963, 75.6894001364708, 78.9097273349762, 81.28178805112839, 79.17923927307129, 75.75088083744049, 67.99922078847885, 64.04685527086258, 63.62362638115883, 73.00033763051033, 76.51439666748047, 86.25554636120796, 67.54209771752357, 57.16618828475475, 87.24033191800117, 72.11729541420937, 69.45230081677437, 77.0149514079094, 81.59087866544724, 78.58248889446259, 79.95006591081619, 77.77970597147942, 80.37097692489624, 78.39034840464592, 78.98452252149582, 77.55446925759315, 78.22799071669579, 69.61144387722015, 61.79832972586155, 64.16172310709953, 64.09499868750572, 62.28050485253334, 63.5250748693943, 61.936387717723846, 67.75028854608536, 64.45438340306282, 64.0413835644722, 58.730997517704964, 61.37249797582626, 59.590781182050705, 61.10893651843071, 61.770929396152496, 63.088368102908134, 61.44681058824062, 65.8943085372448, 64.68842804431915, 66.50055840611458, 59.85928997397423, 62.790038511157036, 60.020431727170944, 63.43071073293686, 61.76966406404972, 72.2250348329544, 73.92318651080132, 85.01231387257576, 77.87505805492401, 90.79722985625267, 75.51431313157082, 103.56092736124992, 24.386162348091602, 0.4615457070758566, 0.1525150434463285, 0.24260408274130896, 0.1880382388480939, 0.08699772704858333, 0.19499241490848362, 0.6067211029585451, 1.3809480238705873, 0.15591847331961617, 0.13626612082589418, 5.02003270201385, 30.48532146960497, 30.16639318317175, 45.50917759537697, 30.615054108202457, 37.256894409656525, 45.48557326197624, 59.92736332118511, 72.28948697447777, 71.35384798049927, 60.71170583367348, 9.506583530455828, 0.1418594058486633, 0.04305255817598663, 0.0351855516055366, 0.041869296474033035, 0.07349512190558016, 0.07127210759790614, 0.06962016108445823, 0.053935990581521764, 0.09937611946952529, 0.09426430275198072, 0.027239075861871243, 0.05756265847594477, 0.038165909063536674, 0.06700823912979104, 0.061483042445615865, 0.02072606763249496, 0.04508490732405335, 0.05351023901312146, 0.13781237066723406, 0.18990793148986995, 0.24579185934271663, 0.23649368406040594, 0.13334973278688267, 0.09477396524744108, 0.1269509652047418, 0.13911580463172868, 0.15706978185335174, 0.1557650268659927, 0.2761791256489232, 0.19418516603764147, 0.14844816323602572, 0.22737993247574195, 0.16347568889614195, 0.5208852526266128, 13.931131660938263, 108.29859673976898, 107.42731109261513, 103.71344357728958, 77.7651147544384, 39.076130390167236, 36.19409903883934, 129.18984532356262, 132.46153056621552, 119.44566339254379, 80.27543485164642, 1.923682875931263, 0.35326181910932064, 0.2597344690002501, 1.8856460857205093, 1.4827835094183683, 0.6515212333761156, 0.4078577348263934, 0.785745409084484, 0.9071583347395062, 3.563645901158452, 102.98537224531174, 109.15369525551796, 110.20823746919632, 106.68251305818558, 96.63646772503853, 92.68471777439117, 89.81594011187553, 80.64331591129303, 82.42006257176399, 83.38877499103546, 79.72090780735016, 77.44429036974907, 75.04041016101837, 74.22778576612473, 76.07248798012733, 73.11762973666191, 72.52886652946472, 75.07924407720566, 68.81847202777863, 72.21899315714836, 70.78942626714706, 71.9482272863388, 72.69433245062828, 71.8652169406414, 70.09567469358444, 70.76798021793365, 66.33111029863358, 68.76684799790382, 66.44007325172424, 68.711256980896, 66.95598676800728, 66.9856707751751, 79.01561245322227, 88.8682633638382, 91.61484718322754, 91.91780492663383, 88.07649224996567, 81.19578346610069, 73.41228872537613, 74.9049474298954, 80.37224605679512, 82.96275705099106, 85.55209010839462, 82.48810932040215, 76.68090373277664, 72.64430433511734, 67.03687682747841, 68.36192652583122, 77.8759092092514, 81.31546184420586, 90.41764542460442, 75.82356333732605, 61.2463865429163, 91.76645144820213, 77.20501720905304, 71.7328168451786, 79.50435742735863, 85.57431131601334, 81.07412919402122, 82.91946977376938, 83.4700982272625, 86.59041479229927, 82.52778679132462, 84.86381784081459, 82.27320805191994, 83.51824164390564, 74.70545053482056, 66.00533097982407, 66.43653944134712, 67.492555975914, 65.84226652979851, 68.37184399366379, 64.11473482847214, 72.28260934352875, 65.81299290060997, 67.83563956618309, 61.96737505495548, 65.06057247519493, 63.475951105356216, 66.66266530752182, 63.81999984383583, 66.88036322593689, 64.52910259366035, 70.86979195475578, 70.2373006939888, 71.44527107477188, 65.75708270072937, 67.49202400445938, 62.742575258016586, 66.47908955812454, 65.40778264403343, 77.63272985816002, 78.8226892054081, 89.9315071105957, 80.21962344646454, 98.62679332494736, 80.15174388885498, 111.41803175210953, 21.89946748316288, 0.5318859592080116, 0.7489566144067794, 0.4164928902173415, 0.3612148517277092, 0.2093855824205093, 0.43946295452769846, 1.5971876517869532, 0.837237574160099, 0.21099991688970476, 0.2992593840463087, 11.60206088796258, 39.49440434575081, 58.72317373752594, 107.17865243554115, 32.292153015732765, 37.20277011394501, 55.114002004265785, 75.9117642045021, 86.8267773091793, 87.04727947711945, 75.87878197431564, 12.13928746059537, 0.37129873875528574, 0.07646719328477047, 0.1522820387617685, 0.17560003674589097, 0.10517779955989681, 0.11102354837930761, 0.15917706565232947, 0.06612564000533894, 0.17563487315783277, 0.24061064439592883, 0.09297899945522659, 0.1546526959282346, 0.16271332511678338, 0.14495585375698283, 0.20264766819309443, 0.1781609360477887, 0.21625481225783005, 0.175765223975759], [0.016534306232642848, 0.01873366087238537, 0.07970496837515384, 0.06550439560669474, 0.1281711895717308, 0.05574827438977081, 0.026996811029675882, 0.008207234895962756, 0.026822406325663906, 0.021501613809959963, 0.06594188424060121, 0.009066870115930215, 0.013229508713266114, 0.06974280840950087, 0.10815161498612724, 0.022017671763023827, 24.58199054002762, 78.33902835845947, 61.97220079600811, 63.911620527505875, 48.701116517186165, 42.13009491562843, 49.604024067521095, 83.75807717442513, 95.312519967556, 82.45372876524925, 14.998023211956024, 0.12455618823878467, 0.1316639146534726, 0.09883091552183032, 0.3170277352910489, 0.910114279249683, 0.7095689373090863, 0.6189762172289193, 0.43091097904834896, 0.42879348329734057, 52.71383039653301, 114.48225572705269, 92.37215414643288, 100.69757580757141, 84.23267930746078, 86.28785982728004, 76.25012844800949, 76.24292403459549, 75.9614047408104, 77.57300466299057, 75.67604765295982, 79.89086508750916, 77.39242315292358, 76.16116762161255, 69.5433059334755, 70.64735189080238, 68.638376891613, 68.43827202916145, 67.38642767071724, 64.8103255033493, 62.598699778318405, 64.91172686219215, 63.02268862724304, 67.03782677650452, 64.23901095986366, 62.33195789158344, 59.908174350857735, 60.50282344222069, 58.843368887901306, 61.602237448096275, 61.53343454003334, 60.95730945467949, 64.26747903227806, 77.9914990067482, 83.97087335586548, 75.78371867537498, 77.73169174790382, 79.49544310569763, 70.56814134120941, 64.6007439494133, 64.52603995800018, 74.09081071615219, 76.76746308803558, 77.27017611265182, 76.87694281339645, 83.78968387842178, 75.17008200287819, 70.42402267456055, 59.84379060566425, 71.37872904539108, 74.76771399378777, 81.25936925411224, 59.39868628978729, 64.8447972536087, 80.85333824157715, 67.95622229576111, 66.36607602238655, 74.42844539880753, 70.64244255423546, 75.98451510071754, 76.02979347109795, 72.86893308162689, 71.05999454855919, 70.60635969042778, 70.00480636954308, 67.4489951133728, 66.00100681185722, 60.958096012473106, 60.37734657526016, 59.762155786156654, 59.259537756443024, 58.5380894690752, 57.99595355987549, 60.837072506546974, 61.9036752730608, 65.94683691859245, 62.5085724145174, 59.36662741005421, 58.664987459778786, 57.45198614895344, 56.56226769089699, 58.40579576790333, 58.24883759021759, 59.6325371414423, 60.934290289878845, 55.57650938630104, 58.70073974132538, 58.36528234183788, 57.861816957592964, 58.0896071344614, 57.95735523104668, 58.65008845925331, 64.35276165604591, 74.4429986178875, 76.031723767519, 79.18610170483589, 78.98187786340714, 80.11856406927109, 89.51085448265076, 71.50036811828613, 0.07730088487733155, 0.019533911290636752, 0.08302236848976463, 0.09495572463492863, 0.09550024580676109, 0.099274022213649, 0.6549988186452538, 0.590665836352855, 0.09005258500110358, 0.026485317284823395, 0.05102207760501187, 18.53487152606249, 26.319114826619625, 57.460558488965034, 48.882431387901306, 19.721741639077663, 28.837133310735226, 51.17395922541618, 50.46893745660782, 63.96126106381416, 52.99737498164177, 39.393557757139206, 5.751134371384978, 0.04912898504699115, 0.035230540597694926, 0.021678135490219574, 0.03268969783675857, 0.03610173662309535, 0.02827106374752475, 0.08334534373716451, 0.12795868300599977, 0.037691480029025115, 0.02812939703289885, 0.061815012522856705, 0.032173422805499285, 0.03166818351019174, 0.08796874564723112, 0.047129676313488744, 0.044090473966207355, 0.01464641056372784, 0.036478814436122775, 0.055214655367308296, 0.0295385480785626, 0.02773665990389418, 0.07652491010958329, 0.05142222136782948, 0.14792952075367793, 0.010012342136178631, 0.04475353838643059, 0.022698167376802303, 0.056694267768762074, 0.060692718252539635, 0.04147675230342429, 0.018447186303092167, 0.028306783315201756, 0.03395884086785372, 37.00581148266792, 95.2423757314682, 74.80454921722412, 77.03828975558281, 59.31127578020096, 47.74108663201332, 52.89682097733021, 78.93048942089081, 100.24132668972015, 92.67388835549355, 17.278003469109535, 0.2153257472673431, 0.1504879561252892, 1.7310427129268646, 0.8972148620523512, 1.181743594352156, 0.9824051626492292, 1.814857309218496, 0.5798323208000511, 0.6259635672904551, 63.441452756524086, 117.28813156485558, 97.68833488225937, 102.99050197005272, 88.9036850631237, 88.64896953105927, 80.64055725932121, 78.46623033285141, 81.1388473212719, 83.3176352083683, 82.21024543046951, 83.81518051028252, 82.9049925506115, 80.4245388507843, 73.08509588241577, 74.69817012548447, 72.40145176649094, 73.29879641532898, 71.6357472538948, 68.84009286761284, 65.9968650341034, 67.9750768840313, 66.39800190925598, 68.7511396408081, 66.5094119310379, 65.5661353468895, 63.31680044531822, 63.33136886358261, 63.60737465322018, 64.08401727676392, 65.31590357422829, 63.56798976659775, 67.84880205988884, 81.55681729316711, 87.38742962479591, 79.85998034477234, 80.5283872783184, 83.829315751791, 73.41642290353775, 68.10377597808838, 69.1216653585434, 75.42881771922112, 77.5442174077034, 82.55411177873611, 81.98549509048462, 84.211765229702, 79.02168452739716, 74.16820496320724, 63.67036007344723, 75.13771533966064, 79.74415495991707, 85.68594172596931, 63.32967035472393, 67.00390979647636, 83.43894749879837, 71.84828504920006, 69.96473371982574, 77.18857929110527, 74.58337068557739, 78.13781395554543, 80.35482779145241, 76.51319593191147, 75.26598885655403, 73.51926058530807, 73.1361423432827, 70.04896759986877, 69.23152506351471, 63.867672085762024, 63.52122187614441, 63.26135762035847, 62.34216794371605, 60.508925914764404, 60.45108921825886, 64.3984580039978, 65.91409027576447, 69.85472202301025, 68.43864440917969, 63.63420881330967, 61.066390201449394, 58.58915872871876, 60.34203127026558, 60.89853420853615, 60.98986990749836, 63.96108627319336, 63.419774919748306, 59.77029114961624, 61.254179924726486, 62.978056222200394, 60.64677491784096, 62.184844985604286, 60.28839714825153, 61.83317765593529, 67.5184477865696, 78.2995180785656, 79.38610017299652, 82.81052201986313, 81.53824388980865, 84.6151515841484, 87.97597244381905, 79.09531697630882, 0.5478055612184107, 0.04378134348371532, 0.11153551895404235, 0.3759616822935641, 0.31935136998072267, 0.6000678380951285, 1.5215622098185122, 1.662086269352585, 0.7629288209136575, 0.15849083138164133, 0.044374004064593464, 20.21238651126623, 34.65983636677265, 42.787205055356026, 35.372788310050964, 27.153413258492947, 36.20139844715595, 63.031127974390984, 61.52356646955013, 76.5171629190445, 67.43694216012955, 48.04964907467365, 6.258547743782401, 0.03366098731930833, 0.04786858080478851, 0.04870665477938019, 0.04549224249785766, 0.024610572472738568, 0.04194570799882058, 0.05602506949799135, 0.029280755661602598, 0.010003485531342449, 0.0762182250036858, 0.037140138520044275, 0.03928880447347183, 0.031244354104273953, 0.04793434993189294, 0.07465417103958316, 0.03922191841411404, 0.01840043842094019, 0.0896875819307752, 0.1514389886870049, 0.191832602431532, 0.10875949330511503, 0.20495841919910163, 0.17359402641886845, 0.39527836139313877, 0.1352275296812877, 0.12000875256489962, 0.15573024982586503, 0.18243364349473268, 0.16115104488562793, 0.07635171510628425, 0.19541864516213536, 0.12712032330455258, 0.15604067535605282, 52.08339102566242, 113.77619281411171, 89.06641513109207, 94.63098093867302, 71.51324942708015, 59.622448682785034, 70.87099269032478, 107.56408095359802, 108.19736257195473, 111.57565489411354, 25.269955024123192, 0.27026854280848056, 0.3922005562344566, 2.0131721114739776, 2.755235005170107, 2.548648165538907, 1.4020650344900787, 2.387068010866642, 1.94073636084795, 0.914461127249524, 58.59179578721523, 120.48756748437881, 100.38403943181038, 107.65171185135841, 92.93068617582321, 93.73239755630493, 84.42990392446518, 83.829315751791, 83.20393770933151, 85.3524412214756, 83.64484325051308, 88.47323656082153, 86.59842476248741, 85.17448157072067, 76.90826073288918, 78.18591937422752, 76.26775190234184, 75.23708000779152, 73.64117324352264, 72.60605558753014, 69.75034922361374, 72.23186686635017, 68.35418254137039, 72.25607916712761, 71.77436381578445, 69.59936052560806, 66.02429956197739, 67.25408837199211, 65.62494099140167, 67.02993839979172, 69.16158601641655, 66.56991228461266, 72.59540095925331, 86.65234386920929, 90.97573667764664, 80.74546203017235, 83.44309687614441, 87.63370960950851, 78.01624327898026, 72.18357145786285, 72.20914408564568, 80.08226081728935, 83.86202439665794, 86.62512212991714, 85.25188341736794, 89.98017489910126, 83.55214342474937, 77.20697790384293, 67.08693534135818, 79.69257652759552, 83.69085118174553, 90.16647890210152, 67.64059603214264, 70.94931408762932, 87.0171470940113, 74.48469758033752, 74.06701639294624, 80.78019216656685, 76.75183832645416, 82.50243455171585, 84.41392958164215, 81.59017950296402, 79.56109598279, 77.64042064547539, 78.07498052716255, 76.63946315646172, 73.39703634381294, 66.59934550523758, 66.2922915816307, 67.312301248312, 65.96349522471428, 64.87067386507988, 64.17407244443893, 68.49313348531723, 68.91371011734009, 72.95917823910713, 71.08222335577011, 67.10168614983559, 65.94904839992523, 63.14308896660805, 62.487985119223595, 65.43603032827377, 64.34519246220589, 66.96477949619293, 67.22695022821426, 64.19435575604439, 66.02706581354141, 66.08701899647713, 65.35086929798126, 65.43582513928413, 65.11185452342033, 67.2195254266262, 70.34010037779808, 83.87205585837364, 82.66479223966599, 87.6129399240017, 88.33329766988754, 88.98873209953308, 96.88600793480873, 78.91952320933342, 0.5647300905548036, 0.10162234073504806, 0.30921229685191065, 0.32297996745910496, 0.37408208940178156, 0.7279384578578174, 2.1611133730039, 2.587960143573582, 0.5493837827816606, 0.2017050515860319, 0.305133304791525, 31.881015077233315, 43.502376079559326, 78.66567403078079, 65.64519390463829, 29.589247852563858, 45.025680139660835, 76.20950862765312, 74.92466077208519, 92.65544414520264, 81.72588542103767, 56.95564158260822, 8.024140577763319, 0.11154602776514366, 0.2080834546359256, 0.14908093318808824, 0.161758374015335, 0.1016118170809932, 0.12412581680109724, 0.176179401751142, 0.15298301208531484, 0.1862239104229957, 0.22093797189882025, 0.1088884191995021, 0.1534050120972097, 0.11724710973794572, 0.15305768698453903, 0.1278087543323636, 0.20238730794517323, 0.10039314380264841], [0.0475007501518121, 0.07889783824793994, 0.04559034699923359, 0.033253885922022164, 0.06724299528286792, 0.03107097356405575, 0.012712179832305992, 0.05705757503164932, 0.011725715285137994, 0.08378878439543769, 0.03192962358298246, 0.02121864217770053, 0.09169502460281365, 0.04970548536221031, 0.031127363799896557, 2.997640147805214, 62.409401535987854, 80.51667630672455, 69.33113291859627, 53.36327254772186, 34.271417409181595, 30.005785301327705, 58.464088439941406, 94.80209335684776, 100.02704098820686, 50.22273726761341, 1.6681630932725966, 0.1259395366651006, 0.028567891276907176, 0.541130566271022, 1.5792862186208367, 0.5703360959887505, 0.355778619996272, 1.6184618789702654, 0.8297466323710978, 15.175278950482607, 108.07536631822586, 96.23480647802353, 102.78345108032227, 81.55364066362381, 80.72486713528633, 77.65482947230339, 80.92728227376938, 82.73334816098213, 87.96480104327202, 87.28076934814453, 87.90677815675735, 84.28948625922203, 85.69062307476997, 83.00330847501755, 79.16248977184296, 76.45078048110008, 76.29416048526764, 73.55959162116051, 71.44252762198448, 66.24916389584541, 64.53040212392807, 63.24908807873726, 62.6855593174696, 66.54638394713402, 61.77951693534851, 60.154788717627525, 58.11194993555546, 55.79780951142311, 57.63378359377384, 59.3804282695055, 59.51701194047928, 60.735807940363884, 62.63384409248829, 75.06283655762672, 79.6454818546772, 81.70359581708908, 81.87261834740639, 81.29121914505959, 71.01831078529358, 69.03923258185387, 59.42865528166294, 65.42955547571182, 68.79612162709236, 71.12428709864616, 77.21032172441483, 80.52324995398521, 77.99847543239594, 77.00897052884102, 61.963320672512054, 68.38355496525764, 74.52494502067566, 75.81068962812424, 69.57237437367439, 77.78932705521584, 77.93229058384895, 66.22030064463615, 64.18820008635521, 71.2959922850132, 71.45833477377892, 72.63136222958565, 70.1132145524025, 66.77663639187813, 66.20088368654251, 65.74085757136345, 66.23295396566391, 62.63379469513893, 63.42353671789169, 58.96903574466705, 58.25052089989185, 55.12861222028732, 55.45639403164387, 54.52402286231518, 58.307084664702415, 60.107899233698845, 63.26193518936634, 64.94824290275574, 65.54870948195457, 64.36065003275871, 57.591381669044495, 57.90684454143047, 55.084116607904434, 56.95247635245323, 55.61202608048916, 62.06537939608097, 55.785653963685036, 58.589918687939644, 54.559239372611046, 57.26436361670494, 55.27408741414547, 59.229260981082916, 54.4737933576107, 60.583143532276154, 61.531166061758995, 75.38705796003342, 70.97668021917343, 80.75635224580765, 73.43053534626961, 84.98832195997238, 73.46245363354683, 101.73510253429413, 12.96158803626895, 0.9381768421735615, 0.1349576551001519, 0.07541746250353754, 0.07592066831421107, 0.21181106945732608, 0.25539248948916793, 2.8020344814285636, 0.3900086972862482, 0.07842987703043036, 0.41208441427443177, 3.314667111262679, 25.199590399861336, 31.089570745825768, 83.67720231413841, 32.501628175377846, 33.778249472379684, 19.586622789502144, 43.98525036871433, 54.03800994157791, 54.18310895562172, 51.6968035697937, 32.01351776719093, 6.8412569258362055, 0.07381507661193609, 0.06013476049702149, 0.03540110839821864, 0.052360622576088645, 0.09245477602235042, 0.025781464428291656, 0.02807698470860487, 0.007073097804095596, 0.012935443828610005, 0.032495815466973, 0.049171740174642764, 0.0501652792445384, 0.030708326812600717, 0.035962980982731096, 0.04288684773200657, 0.04440977187186945, 0.04080395090568345, 0.031237381626851857, 0.05156393446668517, 0.03436366758251097, 0.03557359836122487, 0.04205752738926094, 0.029638763990078587, 0.05422945803729817, 0.007395789643851458, 0.05522922372620087, 0.12041161258821376, 0.07583637518109754, 0.05057832153397612, 0.10251224259263836, 0.05678947789419908, 4.110236596316099, 79.17974844574928, 93.64178761839867, 81.42311006784439, 65.80008119344711, 45.694125071167946, 38.03832247853279, 46.616840958595276, 93.55990961194038, 112.11665466427803, 59.765457808971405, 2.1989719290286303, 0.6060274026822299, 0.5724231933709234, 1.7284288094379008, 0.3546758776064962, 0.7092096784617752, 0.8184970391448587, 2.3542992817237973, 0.7321712526027113, 19.29458376020193, 116.8389804661274, 99.47968035936356, 106.5076008439064, 85.390515178442, 84.02055189013481, 81.0795097053051, 87.52340152859688, 87.04811543226242, 92.96498313546181, 92.54072070121765, 90.73681309819221, 88.049506098032, 89.13689374923706, 88.75796288251877, 83.78488853573799, 82.25344151258469, 80.02009615302086, 77.88736939430237, 75.34344390034676, 69.76459085941315, 68.20988908410072, 66.95772707462311, 65.8324022591114, 68.17667126655579, 65.12450024485588, 62.14939668774605, 60.8351194113493, 59.33596305549145, 60.72311282157898, 61.3078748434782, 63.24470691382885, 65.88737770915031, 66.12586051225662, 78.37344691157341, 82.36601427197456, 84.50613543391228, 84.68852564692497, 85.08303567767143, 73.69341284036636, 70.61767548322678, 62.59881377220154, 68.96797880530357, 71.94006532430649, 73.41979712247849, 79.15337026119232, 81.58849999308586, 78.80970150232315, 80.0935386121273, 66.51299133896828, 70.45572817325592, 76.8274238705635, 77.70108819007874, 73.65274742245674, 79.69846621155739, 80.65884187817574, 71.19044914841652, 69.12339046597481, 76.48996397852898, 72.34217494726181, 77.3093444108963, 73.71540606021881, 70.81532567739487, 68.91342893242836, 68.86769458651543, 67.64778524637222, 67.44244426488876, 64.11267533898354, 61.65226936340332, 59.96687740087509, 60.49540624022484, 56.86708353459835, 58.94516922533512, 60.98778001964092, 64.04712125658989, 67.01355367898941, 67.87109166383743, 69.82050105929375, 69.3950454890728, 59.76140342652798, 59.554740116000175, 60.631286948919296, 60.19432179629803, 60.08473947644234, 64.02296975255013, 58.658212423324585, 61.493057906627655, 59.536235108971596, 60.59157907962799, 58.53167921304703, 62.11611807346344, 60.00639148056507, 63.97459834814072, 65.06244197487831, 79.7346630692482, 74.21714633703232, 83.06916654109955, 75.68913415074348, 88.83656546473503, 76.87636524438858, 104.80760246515274, 17.205596454441547, 0.9565269481390715, 0.09154471001238562, 0.5538937845267355, 0.27794695110060275, 0.686491469386965, 0.4610341298393905, 2.2419632971286774, 1.8715231935493648, 0.4745809076121077, 0.40840817091520876, 2.834065337665379, 35.6348792463541, 31.323182210326195, 53.88878434896469, 33.42229597270489, 46.140703707933426, 28.75978846102953, 54.077638015151024, 68.85234341025352, 68.60845729708672, 64.63883310556412, 40.38423679769039, 7.41481002420187, 0.08687971072504297, 0.06775743720936589, 0.026895656301348936, 0.043130962367285974, 0.0692653477017302, 0.04412647555000149, 0.03721006738487631, 0.05171274991880637, 0.05419719687779434, 0.09552345276460983, 0.036122516758041456, 0.03194571705535054, 0.02595010450022528, 0.014483869090327062, 0.016840375355968717, 0.049795047743828036, 0.12319396875682287, 0.11708835692843422, 0.1378828301676549, 0.1209962394204922, 0.11544944252818823, 0.15115894668269902, 0.09434824707568623, 0.12828717241063714, 0.11078966796048917, 0.2811974985525012, 0.16031452571041882, 0.24885054677724838, 0.19631551578640938, 0.20474764925893396, 0.32288803020492196, 5.914052529260516, 97.62745454907417, 110.6349165737629, 98.59248116612434, 82.44651675224304, 53.822219520807266, 43.4917176514864, 78.76468151807785, 116.78154274821281, 119.08313244581223, 74.64140877127647, 3.7270874809473753, 0.34844498382881284, 0.6361124664545059, 3.458383474498987, 3.560862550511956, 2.418862567283213, 2.56610537879169, 8.652761746197939, 1.9183142390102148, 16.726016588509083, 120.12804597616196, 102.21959173679352, 113.19132819771767, 88.67768839001656, 89.5536781847477, 86.18846476078033, 92.75151059031487, 91.13018319010735, 96.94222211837769, 95.69395110011101, 95.68843379616737, 90.3309340775013, 92.67439752817154, 90.93676596879959, 86.7703427374363, 85.78615754842758, 83.24256643652916, 80.53174629807472, 79.17700499296188, 74.52149480581284, 72.54723474383354, 71.88180685043335, 70.83046406507492, 70.99045068025589, 69.15058940649033, 66.83825388550758, 65.82950681447983, 63.74757193028927, 63.6207727342844, 67.02456548810005, 64.90374729037285, 69.96434614062309, 68.21625754237175, 81.16429075598717, 86.50804281234741, 87.06782117486, 86.482994556427, 88.04918691515923, 78.85397672653198, 74.86760303378105, 66.83969780802727, 73.61911922693253, 77.44853094220161, 78.94350752234459, 84.160315990448, 86.83390572667122, 83.31162393093109, 85.00181883573532, 70.47550991177559, 76.22295990586281, 82.72381827235222, 81.64634048938751, 68.83440837264061, 77.72019356489182, 83.65271642804146, 75.50806626677513, 73.41095879673958, 80.02359956502914, 75.61216548085213, 82.25658774375916, 78.9779032766819, 75.51125809550285, 75.15698790550232, 73.93295958638191, 70.67727148532867, 69.28400784730911, 69.2520135641098, 66.75540313124657, 63.981491178274155, 63.2097601890564, 60.54384984076023, 60.292386934161186, 63.8484451174736, 67.15353816747665, 72.30677604675293, 72.73442029953003, 73.89132902026176, 73.08662340044975, 62.92319096624851, 64.10649687051773, 63.325429782271385, 62.40253150463104, 62.02330805361271, 68.57582464814186, 61.59056447446346, 64.16679963469505, 61.41309879720211, 64.44454953074455, 62.740489169955254, 66.73614576458931, 61.82944245636463, 66.43956407904625, 68.04613307118416, 84.43564161658287, 76.6170671582222, 87.81200364232063, 78.82845729589462, 94.5288348197937, 79.80837911367416, 108.61663207411766, 15.691216215491295, 1.087182224728167, 0.2960769657511264, 0.5470174597576261, 0.25444331229664385, 0.6625079282093793, 0.7464542705565691, 6.058335537090898, 2.1570046059787273, 0.3538950491929427, 0.6029340717941523, 6.466333894059062, 44.96541157364845, 48.21543037891388, 111.35929450392723, 45.12467622756958, 47.23051942884922, 33.949582278728485, 68.98106530308723, 80.76759964227676, 82.95793890953064, 80.1668518781662, 49.719093292951584, 10.561454426497221, 0.16347249766113237, 0.20343557669548318, 0.10678444537916221, 0.17117636161856353, 0.22318915813229978, 0.1261329255066812, 0.10517327988054603, 0.20604916848242283, 0.16602480289293453, 0.34308011701796204, 0.11709604557836428, 0.15417142800288275, 0.09959702714695595, 0.14665639610029757, 0.127875859325286, 0.1362937138765119], [0.033384388880222104, 0.005999184604661423, 0.09707725766929798, 0.054146077745826915, 0.03592130196921062, 0.07398627523798496, 0.009245646997442236, 0.07571719368570484, 0.06842916991445236, 0.01698094369203318, 0.014568962815246778, 0.07253415940795094, 0.04269440883945208, 0.08504606419592164, 0.1651411276543513, 19.030224345624447, 74.31442871689796, 71.44344717264175, 69.94030103087425, 38.105958849191666, 32.043129578232765, 46.93626321852207, 89.91661190986633, 88.69062289595604, 76.56592950224876, 17.92378071695566, 0.1054474589182064, 0.1940511935390532, 0.43560797232203186, 1.0620732908137143, 0.28374389628879726, 0.3766310401260853, 2.420320976525545, 1.0007863794453442, 0.4488379420945421, 59.15711045265198, 107.4880014359951, 96.54131323099136, 93.25505197048187, 75.89625343680382, 80.34185528755188, 82.034702450037, 86.51606798171997, 89.96603965759277, 88.40943038463593, 87.33240857720375, 85.38526386022568, 86.60500600934029, 88.86678904294968, 89.56993371248245, 86.77868708968163, 84.33659613132477, 83.10645774006844, 82.8694948554039, 76.38499081134796, 66.82757645845413, 65.25698393583298, 61.72530524432659, 63.254031613469124, 63.38182635605335, 60.02979062497616, 57.510852590203285, 59.221292808651924, 57.613340690732, 57.83597834408283, 57.281363904476166, 59.40628968179226, 61.185586005449295, 56.90710298717022, 66.28287568688393, 71.13330021500587, 79.66986134648323, 80.49301877617836, 78.59538540244102, 74.772380143404, 71.67028740048409, 62.35259838402271, 60.13128697872162, 59.72121298313141, 65.66244497895241, 72.07938104867935, 77.53669381141663, 79.52919289469719, 76.33680179715157, 63.72665025293827, 68.26864913105965, 71.77267670631409, 72.49387040734291, 80.00466898083687, 80.7002292573452, 82.26489409804344, 66.87138050794601, 64.46077466011047, 70.89642852544785, 73.48382368683815, 71.89155712723732, 65.13718396425247, 58.78357529640198, 58.2147154211998, 57.63495773077011, 61.55776843428612, 55.14323763549328, 56.99354834854603, 56.35562337934971, 60.29618673026562, 60.579655319452286, 59.95627596974373, 56.29629336297512, 57.9333671182394, 56.94071218371391, 62.79518723487854, 63.801996409893036, 65.06255596876144, 64.90875542163849, 59.96060773730278, 57.4985146522522, 56.20901204645634, 56.95600636303425, 60.11213220655918, 58.8876973092556, 56.57683230936527, 54.9199578166008, 55.20230546593666, 54.13768619298935, 54.908592626452446, 58.19749854505062, 56.264295279979706, 60.757143795490265, 69.53389003872871, 75.1012296974659, 74.9020367860794, 77.15869769454002, 75.07229804992676, 80.55361032485962, 77.99418926239014, 90.30268639326096, 44.21807147562504, 0.3173163119936362, 0.4728820425225422, 1.6013006935827434, 0.33973861194681376, 1.0390033037401736, 1.6308266529813409, 2.188451481051743, 0.4752476530848071, 0.4041122936177999, 0.20663830015109852, 0.22691190446494147, 18.889629989862442, 36.98243133723736, 72.62779802083969, 57.24802829325199, 9.021477811038494, 22.529046200215816, 43.70364747941494, 52.461413741111755, 61.5959145873785, 61.620168685913086, 63.64860624074936, 40.74647136032581, 7.745180921629071, 0.22207605536095798, 0.03321051481179893, 0.06583176436834037, 0.047656953684054315, 0.009260055794584332, 0.03496302604617085, 0.0467960252717603, 0.024096809611364733, 0.0484651710576145, 0.05289448279654607, 0.060998134285910055, 0.028889614150102716, 0.028412910432962235, 0.030061341021792032, 0.0903220142936334, 0.04905979090835899, 0.015012566746008815, 0.07107054771040566, 0.0620347179210512, 0.016188218651222996, 0.06503010386950336, 0.05317027600540314, 0.05778519516752567, 0.023365222696156707, 0.04652774630812928, 0.06706585947540589, 0.0067289950038684765, 0.05026273436669726, 0.08469770007650368, 0.06888316391268745, 23.935865610837936, 94.20576095581055, 82.019602060318, 85.88672295212746, 47.56341576576233, 45.37031404674053, 50.858522951602936, 62.13018111884594, 92.6393786072731, 85.74214071035385, 21.65788784623146, 0.27229080616962165, 0.4064811993157491, 1.4894294715486467, 1.4635610533878207, 0.6303591001778841, 1.1212153360247612, 1.0499974200502038, 0.14531631488353014, 1.321419586893171, 69.72735285758972, 109.5438127219677, 101.65577799081802, 96.19206637144089, 79.9496403336525, 84.96121421456337, 87.25129052996635, 92.17634305357933, 92.5260154902935, 92.49559432268143, 91.53210282325745, 91.6084711253643, 91.79953247308731, 92.49532073736191, 94.67489898204803, 92.29108929634094, 87.9449737071991, 85.3749892115593, 85.80411538481712, 79.44159999489784, 70.52312135696411, 67.89468079805374, 65.29685139656067, 67.15836390852928, 66.07896342873573, 65.43415322899818, 60.14427088201046, 60.66436417400837, 60.61720870435238, 61.95078134536743, 59.98638175427914, 62.14469633996487, 63.749772012233734, 60.957940220832825, 68.81026446819305, 73.98359566926956, 81.81749850511551, 83.97633746266365, 80.77348172664642, 79.17005896568298, 73.89576718211174, 66.92569479346275, 63.6831121891737, 63.15252386033535, 70.64203977584839, 76.67267337441444, 81.79063394665718, 83.1154252588749, 79.42522287368774, 67.46918722987175, 73.14957082271576, 77.27064728736877, 78.79498109221458, 83.20820108056068, 84.48502376675606, 84.90341931581497, 72.52225488424301, 69.00322571396828, 75.56716829538345, 78.38787093758583, 76.05506971478462, 66.88277989625931, 61.98777996003628, 63.385010585188866, 62.74754919111729, 64.31054592132568, 59.67783831059933, 61.079408302903175, 58.78538399934769, 62.09326229989529, 62.353191152215004, 62.91530258953571, 59.60831344127655, 59.217306822538376, 61.430802047252655, 65.84526836872101, 67.03271225094795, 67.92846098542213, 69.6386656165123, 63.209262415766716, 60.34455433487892, 59.63404566049576, 59.499677270650864, 62.57721573114395, 61.588884964585304, 59.937235191464424, 58.672891035676, 59.04072269797325, 58.6355846375227, 58.886792957782745, 59.24034498631954, 59.121582359075546, 63.843611776828766, 72.55403637886047, 78.47056970000267, 79.24895033240318, 80.51021665334702, 77.68020451068878, 83.722815066576, 82.7070839703083, 93.09552893042564, 50.131766349077225, 0.09811491370783187, 0.22737203602446243, 0.8761720068287104, 0.8395467814989388, 2.384847030043602, 1.2577585154213011, 2.092684507369995, 4.826327646151185, 1.5686522517353296, 0.2841881162021309, 0.11283403990091756, 18.38863257318735, 54.35446456074715, 57.33832284808159, 43.26603636145592, 19.3528688326478, 31.278794892132282, 55.860677137970924, 65.42472213506699, 71.83865636587143, 73.72587069869041, 74.72533106803894, 50.11524863541126, 8.284570053219795, 0.1257156307110563, 0.0066701853666018, 0.040344606022699736, 0.04077438003150746, 0.05195224097406026, 0.05106938580865972, 0.036100575161981396, 0.051445009012240916, 0.06860730762127787, 0.03136688639642671, 0.05349778577510733, 0.019276740422355942, 0.04649509923183359, 0.046716871511307545, 0.04776373018103186, 0.11271234252490103, 0.11896032054210082, 0.20905384240904823, 0.14072531514102593, 0.09992676335969009, 0.15486183314351365, 0.09064160534762777, 0.1683962022070773, 0.20231957954820246, 0.1260769527289085, 0.13008711801376194, 0.2183043272816576, 0.20129139331402257, 0.17279810272157192, 0.32635130686685443, 31.734500639140606, 111.34069830179214, 95.47787189483643, 100.4136474430561, 60.49532264471054, 52.485629841685295, 67.85518571734428, 117.38767862319946, 105.81597715616226, 97.87314176559448, 32.405181750655174, 0.3154458326753229, 0.5402230680920184, 1.453336039558053, 4.13914829492569, 2.75522384326905, 2.0958354882895947, 7.963202772662044, 4.04161655344069, 1.2658336758613586, 67.08401709794998, 113.46787735819817, 103.96748274564743, 101.96979314088821, 83.53271126747131, 87.19743221998215, 90.53638145327568, 97.09419876337051, 97.65880286693573, 96.874228566885, 98.15771609544754, 98.03299158811569, 97.52271696925163, 98.60030874609947, 99.32535544037819, 97.05924823880196, 90.5403484404087, 92.55077496170998, 91.00962325930595, 84.99620273709297, 73.80211740732193, 73.07201698422432, 67.79689684510231, 70.50560429692268, 68.88917863368988, 69.35950219631195, 62.99286402761936, 64.97600421309471, 65.38741573691368, 66.0218220949173, 63.44474717974663, 64.26810219883919, 68.24809983372688, 62.649928629398346, 72.76267558336258, 77.19395980238914, 87.65593841671944, 87.97066032886505, 84.6177126467228, 82.2554250061512, 78.45783278346062, 69.82297092676163, 66.47183194756508, 64.65821206569672, 76.19660452008247, 81.85080751776695, 84.05455246567726, 85.96405640244484, 82.01983764767647, 69.69316229224205, 75.8378353714943, 80.55278956890106, 78.23491394519806, 72.61458232998848, 77.94701859354973, 86.1891183257103, 75.19858807325363, 71.96540236473083, 79.25487041473389, 80.54556235671043, 80.94429016113281, 72.68322944641113, 66.34155213832855, 64.84488844871521, 67.03547090291977, 68.17609369754791, 60.854764357209206, 61.88776932656765, 62.004404067993164, 64.86001163721085, 66.36708676815033, 66.93126529455185, 62.57925242185593, 63.626487627625465, 64.19108793139458, 69.69464421272278, 70.61936259269714, 71.92396178841591, 72.20339879393578, 66.58962562680244, 62.382441982626915, 62.881389409303665, 61.89135253429413, 65.14628067612648, 64.62849006056786, 62.93541491031647, 59.89517904818058, 62.01247863471508, 61.60412594676018, 62.29346975684166, 63.749772012233734, 62.80003197491169, 69.41310971975327, 77.55198419094086, 82.20997184515, 82.7544142305851, 86.11078932881355, 81.21081545948982, 87.67287790775299, 87.83537238836288, 96.55520528554916, 52.10104487836361, 0.26545369648374617, 1.0851812758482993, 2.4964807648211718, 2.7652180194854736, 2.428751536644995, 5.902958074584603, 5.406042113900185, 6.475354610010982, 1.0862385691143572, 0.3071026678662747, 0.20864589867414907, 30.90010341256857, 59.38947178423405, 94.93355870246887, 75.09252816438675, 16.415605545043945, 36.3626503944397, 64.01158556342125, 76.25307708978653, 84.23601552844048, 86.18649646639824, 87.09582567214966, 58.621468394994736, 11.890387516468763, 0.18981951201567426, 0.1279520185198635, 0.19119843724183738, 0.16367890377296135, 0.2246038251905702, 0.12993922282475978, 0.2061304188100621, 0.20446935872314498, 0.2578333538258448, 0.13187811331590638, 0.1910131674958393, 0.1529662692337297, 0.10795227412017994, 0.09534823911963031, 0.24922892334870994], [0.03771438270632643, 0.05313003304763697, 0.037963443755870685, 0.0700416490144562, 0.10903381335083395, 0.02965889660117682, 0.08915288679418154, 0.06674738906440325, 0.07788622417137958, 0.04632478376151994, 0.04071057388500776, 0.0046163649585651, 0.058175742960884236, 0.0015376637725239561, 1.1062854621559381, 52.30626046657562, 75.70431053638458, 69.78574052453041, 54.84802767634392, 61.509796008467674, 32.40759842097759, 47.1965454518795, 83.65285322070122, 67.21287578344345, 53.961797431111336, 3.9779376704245806, 0.031816045302548446, 0.8023837069049478, 0.7762992347124964, 0.5181056424044073, 0.3564359253505245, 0.8904462971258909, 0.1787291985237971, 0.3259668149985373, 12.274861335754395, 92.22868904471397, 100.58589220046997, 95.44390171766281, 80.90433910489082, 84.41918089985847, 84.74815964698792, 89.87197950482368, 89.58314940333366, 85.98373934626579, 86.10909461975098, 84.05342772603035, 81.1204183101654, 86.29923641681671, 87.39432245492935, 83.86289834976196, 82.62334406375885, 85.06930321455002, 85.5453796684742, 83.39204281568527, 77.99510881304741, 66.83748632669449, 63.57972353696823, 62.12144158780575, 61.00638002157211, 63.72212469577789, 58.58906373381615, 59.34926234185696, 54.993776455521584, 54.855965450406075, 53.56551669538021, 56.075631603598595, 57.87530243396759, 57.75375835597515, 58.20670545101166, 61.55004344880581, 68.77460718154907, 76.88090220093727, 82.92324677109718, 80.60908734798431, 77.06187129020691, 74.3021933734417, 68.18169459700584, 61.41335718333721, 56.758998334407806, 67.04354926943779, 75.96439138054848, 76.1979952454567, 78.33626970648766, 73.38660210371017, 61.26229628920555, 68.55106517672539, 75.09689033031464, 67.96968877315521, 73.65392535924911, 71.61176294088364, 72.88605496287346, 68.60794812440872, 66.4428623020649, 71.5417630970478, 68.82297098636627, 68.30967172980309, 64.14105221629143, 54.977577924728394, 53.99745851755142, 55.411723628640175, 58.02866980433464, 58.906171917915344, 61.74282990396023, 58.2721721380949, 62.80262343585491, 68.23159351944923, 68.5510803759098, 62.445925176143646, 58.228930458426476, 57.73311786353588, 62.372630909085274, 67.06518530845642, 65.74153393507004, 69.06262412667274, 64.2887806892395, 57.61289991438389, 56.92187279462814, 56.525443866848946, 57.289525866508484, 54.4159072637558, 56.637477055191994, 53.517327681183815, 53.88400420546532, 53.76763164997101, 56.06869697570801, 56.61056309938431, 58.51882450282574, 64.41623345017433, 77.89908796548843, 74.82158750295639, 76.02350100874901, 74.53985542058945, 81.01239770650864, 77.26001545786858, 80.96286356449127, 80.91164991259575, 70.00277727842331, 1.7334976186975837, 1.1451687756925821, 1.0629175580106676, 0.9948667720891535, 1.5987864159978926, 0.11149713507620618, 0.8744428621139377, 3.5509137343615294, 2.9243945656344295, 0.4267125902697444, 0.4929097287822515, 2.6335835829377174, 34.99983832240105, 36.00253611803055, 84.34544205665588, 38.828075900673866, 19.175323359668255, 28.584446869790554, 33.576047122478485, 42.46712923049927, 58.49781922996044, 61.477767527103424, 65.26209086179733, 42.69520819187164, 7.318551689386368, 0.03990657191025093, 0.0811763948877342, 0.05032622881117277, 0.030276736397354398, 0.048357559644500725, 0.03893192049872596, 0.04562733563943766, 0.014760379399376689, 0.023507117621193174, 0.0453840744739864, 0.03116971260169521, 0.056288669220521115, 0.06009269185597077, 0.01475124077842338, 0.04767816797539126, 0.0631866609910503, 0.06300801120232791, 0.0023823803167033475, 0.004681951795646455, 0.029956570178910624, 0.04512304629315622, 0.020775145858351607, 0.05304245220031589, 0.028563492196553852, 0.04993050824850798, 0.029173990296840202, 0.04340165702160448, 0.07907299252110533, 0.9662773436866701, 66.04947701096535, 90.05876988172531, 81.25623822212219, 67.67116159200668, 67.97392174601555, 41.95957526564598, 40.841211676597595, 78.28779190778732, 75.71328565478325, 63.67938078939915, 3.6622753087431192, 0.10104474946274422, 2.598362797871232, 4.781568422913551, 0.9368740464560688, 1.378444789443165, 0.9028810111340135, 0.8407716220244765, 0.5115486786235124, 17.910604923963547, 99.66101422905922, 102.59521678090096, 101.24087065458298, 84.71900001168251, 87.75256723165512, 91.61148056387901, 95.17647206783295, 90.75707361102104, 93.63781303167343, 91.06092050671577, 90.37942707538605, 88.36343765258789, 92.10594043135643, 90.02821952104568, 90.64184099435806, 88.86161372065544, 87.9895681142807, 88.5273152589798, 88.0578200519085, 81.46319031715393, 70.08899465203285, 65.72600796818733, 65.87721705436707, 64.66633602976799, 66.14169806241989, 61.49497680366039, 61.12671956419945, 59.0112666785717, 56.39768332242966, 57.86746345460415, 60.86658172309399, 62.303550615906715, 61.16601325571537, 62.307168021798134, 65.36666885018349, 71.96780383586884, 79.85788285732269, 84.59683656692505, 82.39021897315979, 81.54031857848167, 78.09358432888985, 72.33072236180305, 64.52997654676437, 61.95252925157547, 71.37671515345573, 79.98829945921898, 77.61040225625038, 82.14728280901909, 77.70795062184334, 65.38024932146072, 71.99242651462555, 75.92000216245651, 74.80628952383995, 80.33675596117973, 81.74433723092079, 79.12236392498016, 71.00891768932343, 71.9652807712555, 77.44764938950539, 75.36919131875038, 71.67516633868217, 66.39436170458794, 59.23089489340782, 57.40345135331154, 60.55412828922272, 62.71961309015751, 61.321827694773674, 64.86216232180595, 63.479636907577515, 67.26202234625816, 70.78140869736671, 72.89745435118675, 66.65539249777794, 60.074670016765594, 59.36349257826805, 67.09360778331757, 69.1241504251957, 70.95736965537071, 70.97909688949585, 70.23205697536469, 59.50846999883652, 61.14410363137722, 58.88197101652622, 61.507318541407585, 57.56318338215351, 59.28007945418358, 57.23806902766228, 57.77930058538914, 57.74991296231747, 59.57902081310749, 59.57761488854885, 60.06252586841583, 67.12294980883598, 81.05690091848373, 78.70188608765602, 81.93115800619125, 78.16296860575676, 82.73415371775627, 80.78427314758301, 86.15930512547493, 82.04598024487495, 77.72963225841522, 3.8296883879229426, 1.2997865164652467, 0.959739675745368, 0.7552476518321782, 0.8226532442495227, 2.4250047001987696, 2.0163024310022593, 3.5567271849140525, 6.930812895298004, 1.4940773346461356, 0.8020382223185152, 2.0363779412582517, 40.51881417632103, 44.36622932553291, 53.13530758023262, 37.91507229208946, 32.60234177112579, 42.41776987910271, 45.47236517071724, 51.40213318169117, 69.12177175283432, 69.68166410923004, 74.50496569275856, 51.79752856492996, 8.796193599700928, 0.11499084721435793, 0.054934772924752906, 0.003533740800776286, 0.01740013281960273, 0.02751021023868816, 0.026631175278453156, 0.04775322879140731, 0.046034785846131854, 0.06848617427749559, 0.043186463881284, 0.07174428421421908, 0.005500412662513554, 0.017090006003854796, 0.032742998882895336, 0.14981794520281255, 0.171563258045353, 0.09951676387572661, 0.13066369254374877, 0.2011651243083179, 0.17682765290373936, 0.21953137940727174, 0.10864948475500569, 0.15056666830787435, 0.18835476483218372, 0.17336710734525695, 0.079234409640776, 0.16539566946448758, 0.14372365112649277, 1.9876691862009466, 77.2968202829361, 105.47508984804153, 97.26602554321289, 81.45250529050827, 86.36184945702553, 54.64922234416008, 66.39590442180634, 109.41809266805649, 86.95279374718666, 83.24904888868332, 6.207078555598855, 0.18389683216810226, 2.7382551413029432, 4.433747436851263, 2.0494523271918297, 1.7833248199895024, 3.1935051502659917, 4.942663628607988, 1.758679817430675, 15.414294674992561, 102.59985253214836, 107.00361102819443, 105.18917039036751, 88.85775312781334, 90.28163552284241, 94.92493316531181, 96.88552916049957, 97.76848778128624, 97.90001392364502, 96.68917089700699, 93.77906665205956, 91.25290140509605, 96.17820471525192, 95.300512611866, 95.49572333693504, 94.4852739572525, 92.22203940153122, 94.44707840681076, 91.7356351017952, 88.59008029103279, 73.69240209460258, 70.76307848095894, 68.8340511918068, 68.99431139230728, 68.90500858426094, 66.34358122944832, 66.46640583872795, 64.23899576067924, 58.88654977083206, 58.008941262960434, 61.90602354705334, 64.65010330080986, 64.08632755279541, 65.0942462682724, 68.85582402348518, 76.99174225330353, 86.43017739057541, 88.9602792263031, 86.98937058448792, 84.71040487289429, 81.91794231534004, 75.19627779722214, 67.42590755224228, 63.33728514611721, 75.37578016519547, 85.28337612748146, 81.70690923929214, 85.5927175283432, 81.924599558115, 69.85332369804382, 75.32882988452911, 81.77019104361534, 74.07020822167397, 70.24770453572273, 72.8063352406025, 76.71074733138084, 76.50253370404243, 76.07752650976181, 81.51014059782028, 77.50575587153435, 76.57936558127403, 71.90465122461319, 61.835997104644775, 62.29497827589512, 64.03725698590279, 65.10357856750488, 62.55439415574074, 69.05900672078133, 65.98800390958786, 68.03240060806274, 73.22128057479858, 76.24404117465019, 69.02170032262802, 62.54047550261021, 63.14225301146507, 68.48102733492851, 74.93098363280296, 74.23352345824242, 76.5699952840805, 72.42324739694595, 63.194477409124374, 64.99317929148674, 61.54020577669144, 63.8763128221035, 60.98005123436451, 62.724188044667244, 58.554546386003494, 60.877950713038445, 61.42426639795303, 61.948991641402245, 63.52332316339016, 64.06558826565742, 71.79789215326309, 85.02198815345764, 82.65212371945381, 85.15145480632782, 80.8964279294014, 88.83853375911713, 85.35915926098824, 91.44105970859528, 85.02531677484512, 79.64440271258354, 4.035109877586365, 2.452893778681755, 4.462762204930186, 4.342461135238409, 3.8956925086677074, 2.299601216800511, 3.7064408138394356, 11.31908817216754, 7.139658713713288, 1.233172647189349, 0.9267656982410699, 5.251253619790077, 53.5248626768589, 55.088182389736176, 109.44764748215675, 53.17196041345596, 30.973789058625698, 42.632310166954994, 52.788317799568176, 67.13532194495201, 84.03036296367645, 83.16179037094116, 85.47996997833252, 59.041771441698074, 9.818031918257475, 0.2235613897209987, 0.22383384697604924, 0.14630156045313925, 0.1214377282303758, 0.17866823851363733, 0.10013471313868649, 0.2577697962988168, 0.15148494247114286, 0.20690385543275625, 0.11169526624144055, 0.1314680915675126, 0.18961579247843474, 0.21881390071939677, 0.27570115285925567], [0.07669436468859203, 0.023984648832993116, 0.006315287564575556, 0.03728250470885541, 0.035767410226981156, 0.11098721282905899, 0.0431535756069934, 0.06283463808358647, 0.03541732803569175, 0.10073637968162075, 0.038437011899077334, 0.0685591867659241, 0.0880686090386007, 0.3269988455576822, 8.011484406888485, 65.3665928542614, 73.43739777803421, 56.70255236327648, 61.824985295534134, 44.91232842206955, 32.868996262550354, 95.9880705177784, 93.4768308699131, 71.04063838720322, 26.95888079702854, 0.08573773840907961, 0.02553821625042474, 1.496498160995543, 2.4274159083142877, 0.3989058604929596, 0.3747508238302544, 0.8467513136565685, 0.25842719071079046, 0.7782728131860495, 48.43614913523197, 99.31634232401848, 96.1114650964737, 89.50564116239548, 85.91991797089577, 87.2865678369999, 93.53000521659851, 87.93596059083939, 80.85816398262978, 87.88248226046562, 89.26595762372017, 88.31575781106949, 86.14019975066185, 84.20668870210648, 86.54102504253387, 84.18941482901573, 83.49380135536194, 82.47806265950203, 85.53730130195618, 82.6323951780796, 75.24828940629959, 64.17034864425659, 62.20484711229801, 61.099619418382645, 64.13395419716835, 60.38358964025974, 55.92912666499615, 55.90089038014412, 59.0097201615572, 59.84662525355816, 54.09929685294628, 56.14812411367893, 58.8945559412241, 57.9362777620554, 60.59705078601837, 61.18124283850193, 67.11075246334076, 73.08144807815552, 77.21143886446953, 79.21069398522377, 76.77421152591705, 73.13402965664864, 72.66018748283386, 61.316751167178154, 56.36010713875294, 66.95407927036285, 79.02033939957619, 72.3539087176323, 77.05000072717667, 68.83820056915283, 63.585670217871666, 67.37983122467995, 79.6020957827568, 50.41230149567127, 57.2165621817112, 54.412088468670845, 62.412703558802605, 72.50019326806068, 63.51783245801926, 70.80455705523491, 70.3831672668457, 70.27960762381554, 59.06178496778011, 50.91994285583496, 50.524243488907814, 54.179331958293915, 56.13507941365242, 60.39248116314411, 58.33436340093613, 62.60518603026867, 65.46336606144905, 70.09407877922058, 70.99292054772377, 70.84465250372887, 64.92111995816231, 61.72467827796936, 66.08417674899101, 66.58935204148293, 69.13609698414803, 67.8250153362751, 68.26421096920967, 56.23708873987198, 54.971361458301544, 55.82418389618397, 55.349425971508026, 53.5674773901701, 55.49769401550293, 55.19398391246796, 55.20304262638092, 55.012266263365746, 54.44303400814533, 58.85821849107742, 57.227270007133484, 67.65976220369339, 76.27751737833023, 79.7091892361641, 79.25595715641975, 76.2792956829071, 80.44847756624222, 77.85739660263062, 79.1220523416996, 72.93173611164093, 75.018310546875, 41.56156562268734, 0.3847009164746851, 1.3311427901498973, 2.025226727128029, 2.777165765874088, 0.4097321326844394, 0.7880682125687599, 4.60619168356061, 1.2371056736446917, 1.7490083863958716, 0.22045198391424492, 1.0128373140469193, 11.431946866214275, 26.890283077955246, 62.05293506383896, 63.876343220472336, 23.833993077278137, 11.611349489539862, 16.30261480808258, 28.261186815798283, 42.57116764783859, 59.571238830685616, 59.97963331639767, 63.92535299062729, 46.38313069939613, 0.8441282669082284, 0.05264629748126026, 0.028186093404656276, 0.06194503679580521, 0.03460474683379289, 0.046488687075907364, 0.01381954672979191, 0.040160787175409496, 0.03372929830220528, 0.06540896283695474, 0.08194005000405014, 0.05200583145779092, 0.06714709496009164, 0.05546070329728536, 0.05286435902235098, 0.03877360555634368, 0.026689376354624983, 0.01341076993412571, 0.04679324592871126, 0.00980904098469182, 0.07070338499033824, 0.059516180408536457, 0.05418262480816338, 0.0829305499792099, 0.03265792278398294, 0.10086089721880853, 0.150215202011168, 0.4823200235841796, 10.904742255806923, 86.71574726700783, 84.84312415122986, 71.37397930026054, 67.21436530351639, 66.19171097874641, 46.45668715238571, 62.78053142130375, 98.9355343580246, 79.41421866416931, 30.53112231194973, 0.12906516582006589, 0.7841164839919657, 3.285762774758041, 3.3399557042866945, 2.0971784787252545, 0.9566797711886466, 0.5364465457387269, 0.9012685914058238, 1.6089414898306131, 58.34531061351299, 104.46551442146301, 98.99425640702248, 92.59763404726982, 88.20049479603767, 92.77544930577278, 94.08191800117493, 93.02730739116669, 89.58825632929802, 92.34980374574661, 92.67799973487854, 91.70958369970322, 88.29485133290291, 88.7784893810749, 88.67004320025444, 86.845213919878, 86.57040506601334, 86.79818004369736, 88.13329920172691, 85.3756807744503, 76.96176946163177, 69.02255147695541, 64.26757022738457, 64.30411666631699, 66.09037041664124, 64.77823242545128, 59.079374223947525, 58.091058656573296, 60.89858740568161, 61.15647576749325, 57.687493711709976, 60.6413260102272, 63.01778309047222, 62.33159691095352, 63.49350996315479, 64.62253198027611, 70.58718591928482, 74.40224960446358, 81.34516105055809, 82.52362221479416, 80.1245829463005, 77.53153368830681, 76.68356359004974, 67.58511900901794, 61.94386571645737, 70.98288148641586, 81.74489960074425, 77.13576212525368, 80.89569836854935, 74.47174787521362, 66.34109616279602, 72.98166543245316, 79.5809917151928, 62.46587410569191, 66.83014512062073, 65.34351289272308, 70.37761956453323, 71.76764577627182, 69.87112954258919, 74.43187281489372, 74.3917241692543, 71.24853283166885, 63.304865285754204, 55.908330380916595, 55.61980426311493, 58.01822416484356, 60.265347585082054, 62.20030255615711, 64.89223390817642, 65.56770846247673, 68.82511407136917, 71.79637223482132, 75.34359589219093, 74.29196432232857, 69.21134054660797, 65.08244410157204, 68.74192133545876, 69.42062571644783, 73.54804784059525, 71.89828276634216, 70.58984577655792, 60.09346000850201, 59.804227128624916, 58.34211118519306, 56.162206158041954, 57.6041641831398, 58.70759457349777, 59.792443960905075, 57.95374162495136, 57.64290690422058, 56.78721182048321, 62.40527115762234, 59.1514677554369, 70.97223445773125, 79.78956252336502, 81.29868194460869, 82.8268763422966, 79.23131927847862, 83.01915362477303, 80.54613992571831, 82.67023354768753, 74.42601352930069, 77.37710997462273, 54.16665963828564, 1.6990034258924425, 1.0777740483172238, 1.3328705099411309, 0.847328407689929, 1.750278586987406, 1.1568137258291245, 4.146058224141598, 2.4506198382005095, 3.373846085742116, 0.4919858736684546, 0.7859250681940466, 8.957054167985916, 37.89019122719765, 50.60621649026871, 42.61972524225712, 27.486093007028103, 21.54632393270731, 25.483060888946056, 39.94284488260746, 52.72219754755497, 69.88395005464554, 69.044841080904, 73.36316496133804, 55.68154715001583, 1.5896380506455898, 0.0757111600250937, 0.08613089856225997, 0.009714748339320067, 0.04564921786368359, 0.01051707862643525, 0.026050398337247316, 0.015298772286769236, 0.018326353529118933, 0.10576838583801873, 0.056178044687840156, 0.01886241607280681, 0.040648530339240097, 0.017057605691661593, 0.2639558940427378, 0.2434712674585171, 0.13546681293519214, 0.15030615963041782, 0.18270252359798178, 0.19855418941006064, 0.20187785325106233, 0.1516455877572298, 0.1788239856250584, 0.25820000446401536, 0.14858644019113854, 0.22235786367673427, 0.2836787060368806, 0.8948821434751153, 15.723698772490025, 103.14551085233688, 97.99395248293877, 82.26058512926102, 82.87436619400978, 73.54354128241539, 49.950101897120476, 123.30096691846848, 112.25058987736702, 90.76617792248726, 41.35103411972523, 0.21218545327428728, 0.46825213939882815, 4.747808184474707, 6.2093209102749825, 3.193776123225689, 1.9447369524277747, 3.4525982849299908, 2.789085963740945, 1.2659430387429893, 55.90548433363438, 107.0847138762474, 102.95443430542946, 98.62045526504517, 92.96563670039177, 96.9860565662384, 101.09925985336304, 99.28227335214615, 91.32369920611382, 93.64472106099129, 98.46892699599266, 94.25717979669571, 93.56946989893913, 91.09663859009743, 93.81917729973793, 92.44136363267899, 93.78348961472511, 91.64477437734604, 93.65726798772812, 90.54781883955002, 82.85763189196587, 72.228112667799, 68.5048596560955, 68.28786849975586, 71.6961944103241, 68.23057517409325, 62.44111083447933, 65.37850141525269, 66.12793520092964, 65.81075102090836, 58.15414287149906, 63.817560374736786, 65.18616333603859, 64.57608327269554, 67.24478647112846, 66.27185627818108, 74.59200382232666, 79.53150317072868, 85.30706405639648, 86.48854985833168, 82.83678621053696, 78.79162967205048, 78.99807259440422, 67.56557285785675, 63.525591641664505, 75.11122316122055, 87.53604725003242, 80.03977909684181, 85.06089046597481, 77.80571937561035, 69.70155224204063, 76.83198362588882, 86.96545466780663, 62.465896904468536, 61.84214897453785, 61.19624063372612, 68.30812141299248, 81.33927136659622, 72.57564201951027, 78.0526377260685, 76.71539828181267, 76.81075036525726, 66.52143448591232, 57.528422847390175, 56.980511248111725, 61.4028013497591, 62.85336211323738, 67.07935094833374, 66.56830877065659, 69.54367831349373, 72.50907719135284, 75.41570842266083, 77.59239882230759, 77.27895364165306, 71.98611125349998, 68.88243779540062, 71.60389736294746, 72.25867062807083, 77.94310480356216, 72.66024827957153, 75.48522189259529, 64.60028037428856, 61.53335094451904, 63.15123572945595, 57.959832698106766, 60.71244679391384, 60.6991171091795, 62.66973316669464, 60.15010356903076, 61.63421273231506, 61.562799364328384, 67.62070789933205, 63.78266304731369, 77.70598992705345, 82.46461898088455, 87.12740957736969, 87.62154266238213, 85.28841465711594, 87.92153656482697, 85.82496866583824, 84.03372958302498, 76.24904930591583, 77.51225352287292, 52.19458065927029, 0.8746772620361298, 2.61350498534739, 7.160939471796155, 9.74227823317051, 4.244274878874421, 1.6196855320595205, 10.61410915106535, 6.484517818316817, 3.436784246005118, 0.449136701063253, 1.3441407051868737, 19.48373381048441, 46.07742190361023, 81.37651696801186, 81.54369279742241, 33.415304347872734, 19.592421278357506, 27.268233597278595, 49.12650369107723, 65.60585841536522, 81.07722222805023, 78.63374814391136, 84.64282169938087, 62.77540169656277, 2.3557847645133734, 0.1232683690614067, 0.11413077969336882, 0.14393758261576295, 0.12988724280148745, 0.14548420353094116, 0.08491055545164272, 0.1084310855367221, 0.10800475138239563, 0.2226827759295702, 0.31236295122653246, 0.1837265389622189, 0.10343994203140028, 0.17969854729017243], [0.07740749439108185, 0.024995457679324318, 0.04995216782845091, 0.01963649094250286, 0.08256286033429205, 0.050661178611335345, 0.043290153043926693, 0.027623137284535915, 0.03066464028961491, 0.035524742779671215, 0.05190901458263397, 0.051230272292741574, 0.15099582262337208, 0.10007421326008625, 35.864892303943634, 75.091373026371, 67.53267422318459, 50.61224676668644, 66.17255240678787, 41.01351723074913, 34.971693232655525, 89.15249571204185, 93.4718607366085, 59.955322220921516, 7.3497499153018, 0.2669033483834937, 2.223087097518146, 1.630382789298892, 3.869077074341476, 0.2718516328604892, 1.3853030651807785, 0.30950200161896646, 0.22673681698506698, 11.352349687367678, 78.98098111152649, 102.0182329416275, 92.43199333548546, 88.68736267089844, 91.94056570529938, 91.05866342782974, 86.93604424595833, 86.56799599528313, 90.62050133943558, 88.50283697247505, 84.6395006775856, 79.65304344892502, 76.1168771982193, 71.37310534715652, 75.26851192116737, 77.52453446388245, 82.03759789466858, 83.02345499396324, 86.59701123833656, 81.1355946958065, 67.83225774765015, 61.42153814435005, 62.09297351539135, 59.24464635550976, 61.89864434301853, 57.988954335451126, 58.68956834077835, 56.35200597345829, 58.61091636121273, 59.45250280201435, 55.269485861063, 58.39430518448353, 58.542995005846024, 61.00693479180336, 63.220289424061775, 63.839948773384094, 64.43357571959496, 72.69132301211357, 79.10660237073898, 75.89498430490494, 73.37801456451416, 76.93136349320412, 76.28899276256561, 62.16252878308296, 59.48632098734379, 65.2586330473423, 73.39397370815277, 71.86594650149345, 73.57393965125084, 63.862314373254776, 68.45386639237404, 66.25482559204102, 80.53934589028358, 42.718740329146385, 31.07226077467203, 33.57455000281334, 49.05001379549503, 70.2697965502739, 64.01161596179008, 71.66539326310158, 72.90104895830154, 70.823844820261, 60.616767928004265, 52.26106949150562, 50.02768233418465, 55.187687650322914, 55.909504517912865, 58.85762572288513, 57.59114608168602, 62.65329144895077, 65.49862056970596, 69.43717762827873, 73.41643810272217, 71.81300774216652, 71.22299820184708, 67.0191241800785, 70.3162832558155, 71.11243173480034, 70.86021646857262, 70.18566146492958, 64.36859920620918, 55.40057882666588, 53.80464546382427, 55.766495391726494, 57.27968819439411, 55.641136318445206, 56.336248219013214, 58.861083537340164, 58.9487524330616, 54.572033286094666, 55.898640900850296, 58.398899137973785, 59.81460817158222, 65.8792993426323, 75.69447666406631, 77.09066614508629, 73.46706658601761, 71.74784123897552, 70.1549819111824, 70.22379621863365, 68.89037936925888, 74.04334366321564, 75.94158500432968, 79.81584191322327, 66.14998161792755, 9.412371385842562, 1.3706066412851214, 1.4298392878845334, 3.1658248230814934, 1.315472787246108, 0.6010648095980287, 7.521865954622626, 1.6891980520449579, 1.5888184821233153, 0.12168400993687101, 0.4725677875103429, 29.977395124733448, 33.299676552414894, 76.26177102327347, 61.57212406396866, 33.23191478848457, 23.3356574177742, 17.315389662981033, 31.371021643280983, 46.88188813626766, 54.26916293799877, 58.05677689611912, 65.45790195465088, 18.418554067611694, 0.0977088550280314, 0.03353294086991809, 0.010455504489073064, 0.08306671923492104, 0.03358400434080977, 0.012738465775328223, 0.012797153885912849, 0.03588796469557565, 0.03497062192764133, 0.06064081615477335, 0.024280227698909584, 0.050076959960279055, 0.08220854419050738, 0.04822491930099204, 0.03010707030625781, 0.01810865378502058, 0.017506391668575816, 0.01305064370171749, 0.03259997218265198, 0.05973631996312179, 0.023586252827954013, 0.11164790237671696, 0.0578598626452731, 0.028004718078591395, 0.10276094370055944, 0.06847798838862218, 0.07311045934329741, 45.486261025071144, 90.09473115205765, 76.26421809196472, 60.985697731375694, 77.85287484526634, 48.92921447753906, 24.54947378486395, 83.57653051614761, 105.32656341791153, 66.76472023129463, 9.067032616585493, 0.4714314406737685, 3.813849650323391, 5.0707984529435635, 5.18203510902822, 1.3223791541531682, 1.1420054454356432, 0.21149576059542596, 0.16549651249079034, 15.460510645061731, 87.67499819397926, 101.18003591895103, 97.54504457116127, 89.35181021690369, 94.96467903256416, 94.29743483662605, 93.03744524717331, 93.3521443605423, 94.45227652788162, 92.39496812224388, 89.20210584998131, 81.78355872631073, 79.92251738905907, 77.29574114084244, 78.62658932805061, 80.81529468297958, 85.2309237420559, 87.6815414428711, 87.1810095012188, 84.3132121860981, 70.26009947061539, 65.9415552020073, 64.54948469996452, 60.60052379965782, 65.27956992387772, 61.23656786978245, 59.76471684873104, 59.15968291461468, 62.876423075795174, 61.3458614051342, 57.02567182481289, 61.76960326731205, 62.44661293923855, 66.56826317310333, 65.80672323703766, 66.93891048431396, 69.00362089276314, 75.65292209386826, 81.56895384192467, 79.30532410740852, 76.08385697007179, 80.30622079968452, 78.22308897972107, 67.02524185180664, 63.01212899386883, 68.18888381123543, 77.82471835613251, 78.14450159668922, 78.7239097058773, 68.81990075111389, 68.71270850300789, 71.30159318447113, 79.11912649869919, 54.3893238902092, 43.68590623140335, 47.988183572888374, 56.48485444486141, 71.46616995334625, 68.32013636827469, 74.07891735434532, 72.77570888400078, 72.58730739355087, 62.604015693068504, 56.18552930653095, 55.9267707914114, 58.286007195711136, 58.49484398961067, 62.00428247451782, 63.35374966263771, 64.4710037112236, 68.42823296785355, 70.35194054245949, 76.90106391906738, 75.9940829873085, 75.48487991094589, 70.91475114226341, 73.10657232999802, 75.05548775196075, 72.89664879441261, 72.2028136253357, 67.81692177057266, 59.90464814007282, 56.4640049636364, 58.52630250155926, 58.916051387786865, 58.51515009999275, 60.62443971633911, 61.81560359895229, 62.22489483654499, 57.24467307329178, 58.07318061590195, 59.970832988619804, 61.440654918551445, 70.31740039587021, 78.49480479955673, 79.31944414973259, 77.47471913695335, 76.56948611140251, 75.74911773204803, 72.39408776164055, 70.52025631070137, 77.06386998295784, 80.00333905220032, 82.70222023129463, 79.94068041443825, 17.805323973298073, 0.7533311890438199, 1.8192289746366441, 0.8651924366131425, 1.9254704425111413, 3.5988982720300555, 4.294668724760413, 2.7762044174596667, 2.750492859631777, 0.18228395230835304, 0.18089612131007016, 29.172510914504528, 42.9987359046936, 53.02864730358124, 44.45395901799202, 33.48351448774338, 28.048616722226143, 25.22320233285427, 39.321433827281, 58.32494370639324, 63.661996722221375, 69.28609773516655, 77.4100162088871, 24.452573284506798, 0.09406727738678455, 0.13759210123680532, 0.04990084831661079, 0.05349852792278398, 0.03445898531936109, 0.01993059107917361, 0.0077374772172333905, 0.04550747136818245, 0.0710656718001701, 0.06790528044803068, 0.05126805874169804, 0.029432552692014724, 0.031138397680479102, 0.22047697944799438, 0.12043848575558513, 0.1086588655016385, 0.0967395211046096, 0.15590259135933593, 0.1478485227562487, 0.10790837608510628, 0.20274390990380198, 0.2302153522032313, 0.19230025936849415, 0.11678000941174105, 0.19249814562499523, 0.303595574805513, 0.19978784664999694, 55.75274772942066, 105.72627156972885, 90.52448809146881, 75.4047118127346, 87.36954018473625, 56.05269983410835, 50.469328835606575, 117.0615117251873, 108.49082082509995, 88.10717180371284, 13.094063177704811, 0.547322096535936, 6.258312156423926, 5.919973086565733, 8.366141226142645, 3.195185847580433, 5.655968002974987, 2.7344527328386903, 0.3792653081472963, 16.211414001882076, 87.90147364139557, 110.23841544985771, 100.98968133330345, 95.68737745285034, 101.34016692638397, 99.87616628408432, 98.42389941215515, 98.17430600523949, 97.57316306233406, 98.15814167261124, 92.03581899404526, 86.97278827428818, 84.15450230240822, 79.521654099226, 83.89642775058746, 85.88435187935829, 87.73465499281883, 92.29434952139854, 94.7885736823082, 89.00542840361595, 76.34388461709023, 68.43276232481003, 68.43679010868073, 63.22983071208, 69.7324749827385, 65.73624461889267, 65.67191407084465, 63.547577261924744, 67.34005495905876, 66.0992543399334, 59.550795927643776, 64.00620505213737, 64.94481548666954, 69.2755874991417, 69.50596153736115, 70.06063297390938, 70.84937945008278, 78.86129513382912, 85.3369152545929, 80.64339950680733, 78.44599261879921, 82.46493816375732, 82.09654793143272, 69.5197243988514, 63.96075949072838, 73.1243933737278, 80.01423686742783, 79.97246190905571, 80.50220668315887, 72.46971130371094, 74.07644748687744, 75.61147391796112, 88.58265548944473, 52.54145264625549, 42.62664087116718, 44.303718879818916, 56.74205504357815, 82.65732944011688, 71.53091847896576, 78.82053852081299, 78.33945393562317, 80.60376763343811, 66.55692458152771, 57.837232276797295, 54.89816978573799, 62.244604378938675, 60.499004647135735, 66.5501457452774, 63.557661920785904, 69.23274099826813, 72.78088420629501, 76.18373841047287, 79.7625307738781, 78.29841613769531, 80.42618036270142, 74.9407111108303, 77.48627051711082, 78.38308319449425, 77.41384640336037, 78.17577391862869, 72.67740055918694, 64.06858250498772, 58.256380185484886, 61.93553276360035, 62.87996828556061, 61.25725015997887, 62.04282000660896, 64.37783271074295, 65.28616636991501, 60.039392709732056, 62.18733385205269, 64.80771124362946, 65.18506899476051, 73.95522639155388, 81.90486341714859, 87.04683110117912, 82.87966310977936, 81.13860413432121, 79.66609194874763, 77.83911198377609, 73.09745281934738, 77.2182708978653, 80.7620519399643, 86.06118679046631, 75.94980776309967, 11.478540915995836, 2.4880905775353312, 5.1974698808044195, 10.493531171232462, 5.715072406455874, 7.446333607658744, 19.82970904558897, 6.57445709221065, 3.2867089239880443, 0.25952889409381896, 0.7866333739366382, 46.79070062935352, 52.48543605208397, 98.13913509249687, 78.35716858506203, 45.899329259991646, 34.92918871343136, 28.20464964956045, 51.11910916864872, 70.10304629802704, 74.57992807030678, 76.87630444765091, 90.15870451927185, 31.569982767105103, 0.17659251083387062, 0.17395714443409815, 0.1863285680883564, 0.20839478558627889, 0.12830158491851762, 0.10900288805714808, 0.10881897644139826, 0.12902259622933343, 0.2084123299573548, 0.19047377456445247, 0.16484251711517572, 0.12158677374827676, 0.14636376727139577], [0.07192258519353345, 0.0569169528898783, 0.03909196464519482, 0.028688905877061188, 0.01841413846705109, 0.025112550029007252, 0.04772887892613653, 0.11648138402961195, 0.032215502578765154, 0.04822045157197863, 0.03848729240417015, 0.012701993855444016, 0.0715278294228483, 0.7483704958576709, 57.98879474401474, 81.97792589664459, 67.59955823421478, 42.10255019366741, 36.527952924370766, 83.19072961807251, 83.49184826016426, 85.45459493994713, 80.26539579033852, 32.430556789040565, 0.13917983713326976, 0.03333303968247492, 2.6774961641058326, 2.2398648597300053, 2.2857519099488854, 1.8152172211557627, 0.9065238281618804, 0.07137583757867105, 0.49110521154943854, 34.01463098824024, 100.53939029574394, 96.95467785000801, 89.08703282475471, 86.67477026581764, 92.69420966506004, 84.44678261876106, 88.49094361066818, 91.88993722200394, 83.25176194310188, 75.52217870950699, 72.09603175520897, 66.043860912323, 65.24820640683174, 64.78424370288849, 69.31020364165306, 73.65873590111732, 78.90402004122734, 82.87631928920746, 82.38701194524765, 77.32631430029869, 63.33055950701237, 58.809334114193916, 61.63569085299969, 58.93687047064304, 59.86913524568081, 56.13655373454094, 54.806830286979675, 55.83180628716946, 60.72062395513058, 56.93535827100277, 59.18342024087906, 57.061796486377716, 60.41454657912254, 63.98913636803627, 66.65644124150276, 66.90390676259995, 70.80957278609276, 74.17122200131416, 76.28070920705795, 74.34836849570274, 71.76557868719101, 71.2392309308052, 73.71469929814339, 66.04091227054596, 60.70578955113888, 60.388221591711044, 73.3085922896862, 73.05280521512032, 73.88675406575203, 63.344861939549446, 69.89385232329369, 65.25988698005676, 76.46349459886551, 36.68928846716881, 14.49512779712677, 22.097284868359566, 41.31986439228058, 70.94872131943703, 63.01173761487007, 69.99241143465042, 69.63966116309166, 71.46720349788666, 65.72453364729881, 59.424327313899994, 58.711291775107384, 57.80127100646496, 52.02674366533756, 54.97085988521576, 58.39794158935547, 60.32505378127098, 62.664489448070526, 64.43468526005745, 68.98263081908226, 70.93479126691818, 69.54469665884972, 69.06437203288078, 70.43295219540596, 70.35047382116318, 69.23047631978989, 68.61141353845596, 60.83364129066467, 54.124690890312195, 53.65343637764454, 55.55830076336861, 57.628760263323784, 55.77545151114464, 56.496322229504585, 57.89293348789215, 61.27696730196476, 56.281952932477, 55.289940163493156, 57.12871849536896, 58.39524753391743, 65.26785135269165, 71.7724259197712, 67.53484010696411, 76.69214352965355, 75.35725235939026, 73.21773156523705, 68.97102624177933, 73.50151553750038, 77.47212007641792, 79.67924684286118, 75.55573090910912, 81.2702214717865, 91.22645482420921, 31.790194250643253, 0.656864281045273, 0.9781505190767348, 1.6687422059476376, 1.0256485641002655, 3.345987880602479, 3.972786096855998, 1.520793701056391, 0.1926356359035708, 0.5737981852144003, 5.742085631936789, 33.34442675113678, 54.99702528119087, 92.57826268672943, 57.08628237247467, 31.6487867385149, 15.118987821042538, 22.007982060313225, 27.637568078935146, 38.083680644631386, 65.71581691503525, 62.13173523545265, 49.506525099277496, 0.7029061729554087, 0.0360389583511278, 0.05829314330185298, 0.05736029335821513, 0.06207001075381413, 0.05644482822390273, 0.021961726815789007, 0.0661478673282545, 0.03788516944041476, 0.053618240053765476, 0.04004217713372782, 0.12687076872680336, 0.02313773216883419, 0.015958588883222546, 0.02336876274057431, 0.051272318669361994, 0.02637925324961543, 0.0542891415534541, 0.04536996995739173, 0.09385284123709425, 0.012526022292149719, 0.013610226760647492, 0.03807281034823973, 0.06167026404000353, 0.13374574278714135, 0.016943622940743808, 0.8358613355085254, 73.10048505663872, 89.88234534859657, 78.44810530543327, 49.22405205667019, 54.50049452483654, 77.06086054444313, 57.81989000737667, 97.19497695565224, 88.84088203310966, 37.658418864011765, 0.040383965824730694, 0.24065895820967853, 2.879768335260451, 3.2842815667390823, 4.577444801107049, 0.8692024683114141, 1.294238695409149, 0.4825494659598917, 1.2651886604726315, 41.66620060801506, 102.04081892967224, 97.77575299143791, 90.54671689867973, 91.4010402560234, 95.69031849503517, 90.3193598985672, 92.88310512900352, 91.76375359296799, 86.83885306119919, 79.29173603653908, 75.37093922495842, 70.46340376138687, 67.83416524529457, 67.59777992963791, 70.63976749777794, 77.32856377959251, 81.28129407763481, 87.00558051466942, 86.21885553002357, 81.97059988975525, 67.14214637875557, 62.22755089402199, 65.79606100916862, 62.842312306165695, 62.99930848181248, 58.420265391469, 58.41555744409561, 60.4278002679348, 62.75094620883465, 61.28272019326687, 61.17608651518822, 59.213438630104065, 66.52762055397034, 67.96438425779343, 69.1142101585865, 69.3249848484993, 73.57076302170753, 76.80369034409523, 79.54278856515884, 76.56080737709999, 71.10901951789856, 74.00041356682777, 77.92356625199318, 67.74823665618896, 61.01841017603874, 64.19152110815048, 76.62189289927483, 75.89824452996254, 75.2850030362606, 69.0642200410366, 73.30084830522537, 71.34961500763893, 76.46733239293098, 49.77005995810032, 24.605228193104267, 33.661789521574974, 51.18593618273735, 72.55486473441124, 67.44416937232018, 70.79229891300201, 72.31284812092781, 74.629857391119, 68.41358855366707, 64.23755183815956, 63.5908455401659, 60.08756272494793, 55.98968781530857, 55.99362060427666, 61.76432155072689, 63.94149452447891, 64.19151350855827, 67.0637945830822, 71.6250242292881, 73.34270685911179, 72.5478047132492, 73.01511123776436, 71.79114371538162, 73.55949282646179, 70.11317655444145, 70.56972205638885, 64.31811511516571, 56.74490489065647, 55.60792230069637, 58.93788501620293, 59.967986941337585, 56.564733758568764, 58.14907394349575, 62.23949745297432, 65.02965733408928, 57.45376065373421, 59.56491596996784, 60.9733559936285, 60.60271628201008, 68.30353885889053, 75.77319324016571, 74.03256744146347, 79.87204849720001, 78.69242459535599, 77.39311471581459, 72.0618487894535, 77.34101951122284, 79.99599784612656, 83.61029550433159, 79.53260511159897, 81.20602771639824, 93.06653648614883, 48.210152462124825, 0.9113807987887412, 0.7015241158660501, 1.8603145075030625, 1.2605720269493759, 3.7442378606647253, 3.015316086821258, 3.2317548478022218, 0.8686128468252718, 0.6082165008410811, 4.61150617338717, 43.14758911728859, 53.35122339427471, 73.08385714888573, 46.59758739173412, 33.007153049111366, 25.866686403751373, 34.518065974116325, 39.46966387331486, 47.71439306437969, 73.4256412088871, 70.64298212528229, 61.81724891066551, 1.335054561495781, 0.038100681704236194, 0.09056949827936478, 0.09781890810700133, 0.03161825552524533, 0.05517952951777261, 0.05363135380321182, 0.0484185159439221, 0.02818563698383514, 0.022099089073890354, 0.04473925946513191, 0.047406645826413296, 0.0297548210437526, 0.1783868161146529, 0.1056466216687113, 0.14373929559951648, 0.11189312281203456, 0.07976037712069228, 0.1385232590837404, 0.2225029535475187, 0.21744539524661377, 0.13324169092811644, 0.17576244834344834, 0.11633949281531386, 0.18769919610349461, 0.16746946756029502, 1.2689024861901999, 87.23884239792824, 105.55594950914383, 91.40310734510422, 64.57989066839218, 55.19407130777836, 90.49924224615097, 115.77449038624763, 106.55175447463989, 100.6165337562561, 52.035346403717995, 0.24314301554113626, 0.2225540578365326, 6.954988623037934, 8.08577612042427, 6.618674844503403, 3.7930080061778426, 5.40357937105, 1.705550355836749, 2.2733239643275738, 39.722878485918045, 110.19319787621498, 102.96061277389526, 96.9725900888443, 94.67541575431824, 102.16034531593323, 94.4575734436512, 96.333137601614, 97.0198367536068, 94.17288511991501, 80.32791763544083, 79.58290681242943, 71.09711095690727, 72.31445923447609, 71.35102853178978, 76.41142219305038, 79.97617810964584, 86.44837841391563, 92.24407821893692, 92.6659543812275, 86.05578348040581, 71.8891404569149, 64.91857409477234, 70.27336075901985, 66.92312613129616, 67.84143805503845, 61.42582431435585, 63.608651384711266, 63.13440263271332, 66.50808960199356, 61.92294783890247, 65.15356868505478, 62.39134110510349, 69.62560951709747, 72.37137258052826, 73.60987812280655, 73.58574941754341, 76.92981317639351, 80.89607074856758, 83.70135381817818, 77.12490990757942, 70.8339674770832, 75.10096371173859, 82.34258472919464, 71.21697932481766, 65.76571583747864, 66.95714190602303, 80.70830762386322, 80.02595543861389, 78.5384264588356, 70.61068385839462, 76.85169696807861, 75.36156132817268, 83.79425123333931, 48.168271109461784, 21.81446984410286, 31.539440006017685, 52.78321847319603, 81.12441569566727, 71.53331995010376, 74.47823792695999, 75.16064330935478, 80.1231998205185, 73.32684651017189, 66.31730943918228, 64.67756822705269, 64.34548884630203, 57.374352514743805, 59.879919067025185, 64.53849568963051, 66.99921324849129, 67.70226672291756, 72.00191840529442, 74.692622423172, 78.17588031291962, 74.96710449457169, 74.42307248711586, 75.9417673945427, 77.16187432408333, 75.62596634030342, 76.96913346648216, 68.90578374266624, 60.707237273454666, 58.63126426935196, 61.66093289852142, 64.4007758796215, 59.69853200018406, 60.43494388461113, 64.04256910085678, 69.9561157822609, 60.21525487303734, 62.674581706523895, 64.38924729824066, 63.9071823656559, 72.67029494047165, 81.10860094428062, 76.48851245641708, 83.24158608913422, 82.55310863256454, 79.55077573657036, 74.0620918571949, 79.27408218383789, 81.11044764518738, 89.26091149449348, 81.94627359509468, 86.65143191814423, 96.69800162315369, 39.79513920843601, 1.7708772816695273, 6.146725919097662, 8.403578717261553, 4.757146658375859, 9.448531195521355, 11.239235457032919, 3.924018801189959, 0.6178736826404929, 0.79879634315148, 10.16751816496253, 53.364458084106445, 74.29923713207245, 108.54189768433571, 75.04643663764, 46.149089857935905, 26.539333909749985, 35.21719045937061, 46.301986053586006, 58.284118697047234, 84.17157098650932, 79.54943060874939, 72.28374928236008, 2.070152428932488, 0.19326796056702733, 0.16788388282293454, 0.239141266210936, 0.16773101524449885, 0.14753647934412584, 0.13251027470687404, 0.13902110658818856, 0.11813338991487399, 0.15576060366583988, 0.09651621629018337, 0.29381394968368113, 0.17101702251238748], [0.07831118535250425, 0.03089474317675922, 0.03157257262500934, 0.04462240089196712, 0.025143020757241175, 0.04832215920032468, 0.01975818089704262, 0.07649766586837359, 0.10334462058381177, 0.008811238276393851, 0.03466251560894307, 0.06560664129210636, 0.38292359153274447, 5.6687690410763025, 68.03360134363174, 76.1116410791874, 58.81131000816822, 54.174194633960724, 26.46754626184702, 40.664973333477974, 72.53405705094337, 84.15406912565231, 67.46864765882492, 8.848392348736525, 0.035680493601830676, 0.16158160928171128, 0.6733574147801846, 4.290137467905879, 4.680273458361626, 0.12546382000437006, 0.848053990630433, 0.8871416619513184, 2.7949960716068745, 71.36876598000526, 97.07852840423584, 98.24251234531403, 86.51025429368019, 91.73831775784492, 87.24439769983292, 92.62157276272774, 85.45837193727493, 79.70415070652962, 73.07215377688408, 69.36476111412048, 65.11161133646965, 65.3432697057724, 65.53409546613693, 65.99042817950249, 64.39895197749138, 69.43033039569855, 75.45695900917053, 76.60263553261757, 79.27829995751381, 72.58085533976555, 61.864062398672104, 61.22106470167637, 63.00206333398819, 60.77344112098217, 58.4515605121851, 55.77794037759304, 56.037918627262115, 59.16468344628811, 59.08343620598316, 58.54530908167362, 58.33895355463028, 60.94755917787552, 63.89647454023361, 63.54474261403084, 69.9182166159153, 70.1598608493805, 71.60215705633163, 75.96686124801636, 81.11127600073814, 72.99108892679214, 70.05437090992928, 70.65004974603653, 70.63255548477173, 67.87673816084862, 56.637203469872475, 58.57262961566448, 69.36848491430283, 72.19615638256073, 74.5270425081253, 65.72673752903938, 70.12017577886581, 65.16445890069008, 69.43419098854065, 36.407677978277206, 15.459547396749258, 20.11529602110386, 39.86334554851055, 63.21503050625324, 59.11704160273075, 65.96879974007607, 66.8363843858242, 72.7078065276146, 67.66035497188568, 71.34406730532646, 65.98695516586304, 68.69094327092171, 61.59813366830349, 56.006669104099274, 50.59036374092102, 55.84293968975544, 55.72150960564613, 60.71159943938255, 64.32094976305962, 70.26693150401115, 71.16217106580734, 67.7471499145031, 64.7703668475151, 66.29042208194733, 71.19281262159348, 66.25675588846207, 59.564087614417076, 53.90477769076824, 52.24900133907795, 54.55364987254143, 54.2518662661314, 53.686654195189476, 56.7132867872715, 60.9164160490036, 61.30784444510937, 59.837273955345154, 58.54592464864254, 56.33000895380974, 55.28000369668007, 59.84375260770321, 61.83843657374382, 71.50108247995377, 71.13588407635689, 75.02679169178009, 76.13609656691551, 78.04364740848541, 76.93511009216309, 75.0687338411808, 74.93249595165253, 80.46102449297905, 76.50858297944069, 71.4320857822895, 92.01229825615883, 31.375875882804394, 0.4295892140362412, 1.4235325763002038, 1.426407597027719, 1.182202894706279, 1.4974758960306644, 1.9691000576131046, 0.16452814335934818, 0.06079163169488311, 0.07238072037580423, 20.139337331056595, 39.61355835199356, 75.1825225353241, 74.30701151490211, 42.680400386452675, 28.71061149984598, 15.412346329540014, 21.1490685492754, 27.069639153778553, 47.60090455412865, 55.49961671233177, 63.68212044239044, 7.449416192248464, 0.24289341643452644, 0.060325470185489394, 0.115307714586379, 0.05006523773772642, 0.04780208437296096, 0.013862809300917434, 0.05250136346148793, 0.017591757205082104, 0.027019682165700942, 0.05156869534403086, 0.03688626835355535, 0.020917623369314242, 0.09846848028246313, 0.06567031756276265, 0.09376489673741162, 0.055555828075739555, 0.03966857628256548, 0.04912764175969642, 0.09199031032039784, 0.08729787383344956, 0.02265019495098386, 0.10611439734930173, 0.0368372569209896, 0.09041461205924861, 0.45449073251802474, 7.326444815844297, 83.6098775267601, 84.500922113657, 73.06784480810165, 57.227665185928345, 36.705638989806175, 47.05736272037029, 74.22967046499252, 95.21850541234016, 76.28762483596802, 10.219532623887062, 0.12090494783478789, 1.3597991899587214, 2.6492620166391134, 2.3890517419204116, 5.17598488368094, 2.480192701332271, 3.216981003060937, 1.2221112032420933, 4.524497017264366, 78.3264434337616, 97.02854588627815, 101.75890445709229, 90.03407880663872, 95.74537754058838, 90.62522828578949, 95.49218952655792, 88.37147802114487, 82.15884938836098, 74.13048058748245, 72.27256268262863, 68.29987585544586, 68.86212408542633, 66.47883117198944, 68.42362001538277, 66.89210459589958, 73.32653492689133, 78.30180555582047, 81.55921876430511, 82.011379301548, 75.8893758058548, 63.27418953180313, 63.46571445465088, 64.35441836714745, 61.333713456988335, 59.25657391548157, 57.56809651851654, 59.628991931676865, 62.230875715613365, 60.91656044125557, 61.372953951358795, 60.556484162807465, 64.60144311189651, 67.6029172539711, 67.38788679242134, 75.01142531633377, 74.37999039888382, 76.33599624037743, 80.40617063641548, 81.48757740855217, 74.08074885606766, 73.56433376669884, 75.00826388597488, 75.50422847270966, 70.97797974944115, 60.837475284934044, 61.01422660052776, 72.87338644266129, 74.59280177950859, 75.97173258662224, 70.12284323573112, 72.02610030770302, 68.48726660013199, 67.4138318002224, 43.19827079772949, 21.249286271631718, 28.924579918384552, 47.94615022838116, 66.53608649969101, 61.782598569989204, 66.89251497387886, 70.38369923830032, 74.38157871365547, 71.2004654109478, 73.11100289225578, 70.30675336718559, 72.38851726055145, 65.51765754818916, 60.62713377177715, 54.137921780347824, 58.58588710427284, 58.428723737597466, 62.40119777619839, 66.43565028905869, 74.48240250349045, 73.12578409910202, 72.9576051235199, 66.75753101706505, 67.55640015006065, 74.64924395084381, 68.92562627792358, 62.793709114193916, 56.74656540155411, 53.521632850170135, 57.26037383079529, 55.3658676892519, 55.63196361064911, 58.367341831326485, 63.35153818130493, 64.74724128842354, 63.03072899580002, 62.301149144768715, 60.01290053129196, 60.00376582145691, 60.799135342240334, 64.44807574152946, 74.17325109243393, 75.15904739499092, 75.97705230116844, 78.44506546854973, 79.77089032530785, 79.85932677984238, 77.91001617908478, 79.21182632446289, 82.17777237296104, 82.31813684105873, 73.7391547858715, 92.07765474915504, 46.49468131363392, 0.5250767839606851, 0.8746927580796182, 2.9830372938886285, 2.2240558080375195, 3.296398166567087, 5.3505180682986975, 1.8836838472634554, 0.30991442792583257, 0.020969132128811907, 21.279025375843048, 47.851915284991264, 63.83016049861908, 58.89790736138821, 37.195976078510284, 27.264923974871635, 21.86162531375885, 29.788246974349022, 32.303411811590195, 55.04448473453522, 63.95480901002884, 75.01137211918831, 11.271401681005955, 0.41492440563160926, 0.09050082735484466, 0.09104124445002526, 0.01382794784149155, 0.05823348205012735, 0.04019513005914632, 0.061485131591325626, 0.06584271846804768, 0.12677336926572025, 0.03376483604370151, 0.007698970885030576, 0.04690762572863605, 0.2659748028963804, 0.146275986044202, 0.3063836751971394, 0.24670612590853125, 0.1492550113471225, 0.165994820126798, 0.18793433817336336, 0.2482861137832515, 0.2644169458653778, 0.21770105027826503, 0.11499176747747697, 0.16346941032679752, 0.5795966146979481, 9.034122582525015, 103.20107147097588, 97.49304816126823, 85.81905618309975, 70.29910057783127, 43.43184806406498, 49.61987681686878, 96.94560393691063, 95.28974398970604, 99.24039199948311, 14.46605745702982, 0.2464224473806098, 1.3414505682885647, 2.854356486350298, 9.768554773181677, 12.06497484818101, 6.837079050019383, 3.259272971190512, 1.3146044150926173, 4.264541566371918, 81.78213000297546, 106.16982936859131, 107.7937026321888, 96.87515571713448, 100.45983776450157, 96.1161920428276, 100.76956674456596, 91.89688324928284, 87.87566542625427, 76.98272153735161, 75.76949223876, 72.1657732129097, 73.30204904079437, 70.33037289977074, 71.94871366024017, 72.92016193270683, 76.2730260193348, 82.15010225772858, 83.73846262693405, 87.40161046385765, 80.3604818880558, 69.49672043323517, 67.59852468967438, 68.37738409638405, 66.23469427227974, 64.67236250638962, 62.9536197334528, 62.494665160775185, 66.5452516078949, 64.85798254609108, 64.12925764918327, 65.37701189517975, 67.24458128213882, 71.7591342329979, 71.49523839354515, 78.68779644370079, 76.55624762177467, 78.71539056301117, 82.00605198740959, 84.75107029080391, 73.68870869278908, 76.35537520051003, 78.49446281790733, 78.63545045256615, 75.22251158952713, 63.263876885175705, 65.63155263662338, 77.65283837914467, 78.49947854876518, 80.72917610406876, 73.82169395685196, 78.32050055265427, 74.30214017629623, 76.11740157008171, 43.13738286495209, 18.406487815082073, 25.313432291150093, 50.86896099150181, 75.64942628145218, 66.64732173085213, 73.16182136535645, 74.14909958839417, 78.34944739937782, 74.5874060690403, 76.23996779322624, 72.06549659371376, 76.22411504387856, 67.0467334985733, 62.362865433096886, 56.43512271344662, 62.87485755980015, 61.266407668590546, 68.21474522352219, 70.24901926517487, 77.32342645525932, 77.64520078897476, 76.48420348763466, 71.24841123819351, 69.49152991175652, 77.3704831302166, 73.42454686760902, 66.88222512602806, 60.17541401088238, 57.56947964429855, 59.75712105631828, 58.23127493262291, 59.174198135733604, 62.8228497505188, 66.42866626381874, 69.62819337844849, 67.94289261102676, 65.62635451555252, 64.40435528755188, 63.76228854060173, 64.4141511619091, 67.50685840845108, 79.79176640510559, 79.70749452710152, 80.29287591576576, 82.56095141172409, 83.96461889147758, 83.01694974303246, 82.02616810798645, 83.11322137713432, 86.16874381899834, 86.01893305778503, 75.96844956278801, 102.9560074210167, 40.254796743392944, 0.8279251644853503, 6.82615558616817, 12.275513000786304, 3.612764677964151, 5.526491850614548, 9.672710616141558, 0.8800993335898966, 0.2506099414313212, 0.28731989033985883, 33.93994599580765, 58.6090924590826, 89.43143114447594, 86.6829626262188, 60.13061061501503, 40.48205874860287, 26.87097441405058, 35.534070655703545, 41.740080043673515, 69.59138095378876, 71.56034409999847, 89.15509477257729, 13.432486318051815, 0.4161072405986488, 0.24070736108114943, 0.27981158229522407, 0.1467409118777141, 0.20028300757985562, 0.21434557798784226, 0.24226774141425267, 0.16915780899580568, 0.26567776571027935, 0.14094061218202114, 0.052560635085683316, 0.10182660204009153], [0.11082094948505983, 0.047101218660827726, 0.013733552223129664, 0.029402408508758526, 0.07398577057756484, 0.0076136962616146775, 0.0943382948753424, 0.027420235965109896, 0.040833885432220995, 0.04052748605317902, 0.1180847421346698, 0.15087353152921423, 0.5228816892486066, 10.808834452182055, 76.66701167821884, 66.71045914292336, 62.77132071554661, 35.32564423978329, 34.90087263286114, 27.140478752553463, 79.35888603329659, 86.86211541295052, 35.83675101399422, 1.2678257189691067, 0.12697640602709725, 0.2836996939731762, 1.752426540479064, 1.349706337787211, 2.62034984305501, 1.1290862574242055, 1.3601637328974903, 0.12173674695077352, 18.907264843583107, 100.63085898756981, 96.79194778203964, 96.78629368543625, 82.93044358491898, 84.75975662469864, 80.59399455785751, 78.7028132379055, 72.11564630270004, 68.85590761899948, 64.36926037073135, 67.78869688510895, 65.26380077004433, 64.09036293625832, 62.44808726012707, 65.36178231239319, 62.24809639155865, 64.46684673428535, 72.12074562907219, 75.54116249084473, 73.9519889652729, 67.08278596401215, 61.57235585153103, 58.69840286672115, 58.72655935585499, 59.529057294130325, 54.72524866461754, 53.961162865161896, 55.0028807669878, 55.79698495566845, 59.259803742170334, 60.834800228476524, 66.01489126682281, 69.85078543424606, 70.19539654254913, 70.22771000862122, 72.94169157743454, 72.52840295433998, 75.60906484723091, 81.50412172079086, 73.46784174442291, 71.36359825730324, 72.276142090559, 72.14458554983139, 67.693040817976, 61.46621234714985, 56.051654890179634, 57.75221563875675, 68.95439073443413, 72.4949723482132, 74.2317071557045, 66.70442506670952, 63.222698494791985, 61.56464226543903, 61.33475840091705, 38.16526986658573, 26.471549347043037, 28.251890614628792, 42.157305255532265, 60.10137878358364, 54.15473207831383, 57.9434821754694, 62.797018736600876, 72.7216225862503, 70.16866117715836, 68.60041692852974, 68.48407477140427, 69.99281421303749, 66.29628896713257, 66.82573735713959, 52.207142785191536, 54.16324362158775, 52.967307195067406, 53.819286078214645, 57.276591360569, 68.3867771923542, 66.70266956090927, 69.32468086481094, 66.59839555621147, 67.73046880960464, 71.90001547336578, 68.25528904795647, 62.71527372300625, 54.2293106764555, 51.63974583148956, 52.44856283068657, 53.59498031437397, 53.305048272013664, 55.06130263209343, 59.991363286972046, 59.86848548054695, 61.42248049378395, 57.401209473609924, 56.48851364850998, 54.68082144856453, 55.593878254294395, 57.49005250632763, 62.431379556655884, 63.24398495256901, 69.32083547115326, 71.30449622869492, 74.52804565429688, 74.34250921010971, 74.30070385336876, 72.90840536355972, 73.7811729311943, 74.20421943068504, 85.40928617119789, 73.73097762465477, 87.08945721387863, 11.908548641949892, 0.6456038821488619, 0.8795146993361413, 0.863977629924193, 1.9954434502869844, 3.5061324248090386, 1.6975490539334714, 0.18857769115129486, 0.08057091370574199, 4.021351765841246, 30.63896242529154, 41.29742659628391, 60.82715503871441, 78.21169719099998, 108.02507981657982, 53.20501483976841, 21.132719926536083, 24.081471897661686, 39.766123965382576, 55.725670382380486, 69.25505340099335, 23.76315537840128, 0.20016196329379454, 0.11326570267556235, 0.020652728599088732, 0.04097779899893794, 0.057534672087058425, 0.11090392159530893, 0.051215755884186365, 0.017431156447855756, 0.028734933875966817, 0.05239217869529966, 0.06001702990033664, 0.10131699149496853, 0.05710150275263004, 0.03441397777351085, 0.014439243750530295, 0.12991535535547882, 0.053207498422125354, 0.05254602961940691, 0.05489322007633746, 0.08871953934431076, 0.0688255658315029, 0.022744507077732123, 0.13382953125983477, 0.11047006206354126, 0.5333146825432777, 13.029722180217505, 94.66815054416656, 76.46421656012535, 73.30407813191414, 39.31425981223583, 36.73210836946964, 34.5182141661644, 84.60680723190308, 96.15981370210648, 41.61630168557167, 1.6953342477791011, 0.20175292011117563, 1.03438037680462, 5.743545703589916, 3.1195967411622405, 5.576569838449359, 1.926351876463741, 2.208512742072344, 0.17380605801008642, 22.917391061782837, 103.93788233399391, 97.9448439180851, 97.86537498235703, 84.20665830373764, 88.65944936871529, 83.36286038160324, 82.19436228275299, 74.90770608186722, 71.4149259030819, 67.39431604743004, 70.37748277187347, 69.09196615219116, 68.75734850764275, 64.31790992617607, 68.62640753388405, 65.14868214726448, 68.51515710353851, 76.061742156744, 78.26028898358345, 76.70300334692001, 70.73360726237297, 64.26468998193741, 62.55486533045769, 62.01308660209179, 62.195237427949905, 57.97710657119751, 58.545457273721695, 56.077295914292336, 58.82052071392536, 61.604251340031624, 65.17079696059227, 69.38030987977982, 71.48074597120285, 74.35771599411964, 75.324786901474, 76.30258083343506, 76.07738211750984, 77.27408230304718, 83.4037233889103, 74.88318979740143, 74.54895213246346, 75.15372768044472, 75.31208038330078, 69.56360444426537, 64.02398809790611, 58.389912620186806, 61.81366950273514, 71.41877889633179, 76.43375739455223, 77.54107117652893, 69.96166348457336, 68.25730293989182, 64.49538320302963, 62.121232599020004, 42.84238949418068, 29.485152438282967, 34.10199210047722, 48.617087826132774, 63.99956300854683, 56.475715935230255, 59.86684776842594, 65.72583317756653, 74.45142656564713, 71.09769612550735, 73.09802278876305, 69.8053702712059, 74.42118778824806, 69.4656229019165, 70.15338599681854, 55.345215797424316, 56.29276715219021, 55.59867739677429, 55.6792900711298, 59.36284281313419, 68.466527312994, 68.50775510072708, 72.19380810856819, 70.33547222614288, 71.8606723845005, 71.80308267474174, 72.20098212361336, 67.55540460348129, 57.62993060052395, 53.086613193154335, 54.72499027848244, 55.69851703941822, 56.24743938446045, 57.30594098567963, 62.268090918660164, 63.92132520675659, 63.45363110303879, 60.47481894493103, 61.16506330668926, 56.329233795404434, 59.49553929269314, 59.52426195144653, 66.29727691411972, 66.19474321603775, 73.7368293106556, 73.16873699426651, 76.4731764793396, 76.24436035752296, 79.00237396359444, 74.46729451417923, 77.79001861810684, 74.44365218281746, 88.50675076246262, 75.85282176733017, 90.7429687678814, 20.900772772729397, 0.44840892136562616, 1.1608482780866325, 2.6659390842542052, 3.638708498328924, 4.435499142855406, 2.1619752142578363, 1.4715733984485269, 0.18862786033423617, 2.9791208915412426, 37.24484145641327, 45.00466346740723, 50.78852690756321, 64.89391341805458, 81.67015001177788, 40.24667277932167, 27.436811551451683, 28.584600761532784, 46.23993158340454, 62.499236315488815, 77.72951826453209, 29.74135559052229, 0.326445767423138, 0.16363807080779225, 0.06543755036545917, 0.04497686546528712, 0.08032904777792282, 0.06031934746715706, 0.018006857098953333, 0.05265545558359008, 0.034574367018649355, 0.09293866372900084, 0.031971666248864494, 0.10964862332912162, 0.1829560857731849, 0.15235923696309328, 0.10524972109124064, 0.20982857036869973, 0.19521424284903333, 0.13970818690722808, 0.3100382478442043, 0.1889856200432405, 0.19883145578205585, 0.1376645200070925, 0.2986201277235523, 0.3028480242937803, 1.051103991921991, 17.38614946603775, 112.57469728589058, 86.02352321147919, 88.99505496025085, 52.8915810585022, 50.345254093408585, 36.99551783502102, 102.6124070584774, 103.97237688302994, 58.88824447989464, 2.4135468900203705, 0.1728443830506876, 0.7332914799917489, 6.310914633795619, 5.811389163136482, 10.369653068482876, 6.8641445226967335, 5.003583384677768, 0.9398822975344956, 23.114362992346287, 114.28698420524597, 105.27793362736702, 104.7705240547657, 88.29311862587929, 94.59425210952759, 89.42346677184105, 88.8928784430027, 79.83213543891907, 77.151820063591, 70.95395743846893, 73.87012615799904, 74.23961833119392, 71.47337436676025, 69.29315775632858, 73.12549531459808, 69.01538506150246, 74.3960939347744, 81.47646680474281, 83.92725929617882, 81.37036129832268, 75.24668589234352, 68.43742847442627, 66.0148760676384, 65.89943826198578, 67.30252057313919, 60.06563790142536, 62.24362023174763, 60.738046020269394, 63.298443630337715, 64.67572152614594, 66.82381466031075, 73.0471283197403, 76.54776647686958, 78.94306674599648, 77.03069776296616, 80.74856266379356, 80.02473950386047, 80.54520517587662, 86.1593659222126, 79.18794080615044, 78.57438012957573, 79.02259647846222, 78.87631952762604, 74.53949064016342, 68.20374101400375, 62.842483296990395, 62.26058632135391, 76.32102504372597, 80.11650457978249, 80.64241155982018, 74.48875576257706, 72.99802735447884, 68.44243660569191, 71.45033240318298, 44.55951355397701, 28.599153980612755, 34.608254134655, 52.36268363893032, 71.47133007645607, 62.14615546166897, 61.92567229270935, 67.64720767736435, 80.06599768996239, 74.462119191885, 75.29948025941849, 74.6851672232151, 77.14175060391426, 71.64936572313309, 73.57460081577301, 58.1880484521389, 58.75783167779446, 59.018345698714256, 59.51302595436573, 64.48675006628036, 75.3804387152195, 73.48345130681992, 76.82779625058174, 74.46936920285225, 74.26244750618935, 76.83526664972305, 77.1167403459549, 71.50072529911995, 58.79274420440197, 56.36756233870983, 58.81406106054783, 58.537234514951706, 59.2665483802557, 60.31829014420509, 65.81689149141312, 67.70351305603981, 67.47398257255554, 61.14171355962753, 62.9302129894495, 59.84234668314457, 63.558399081230164, 62.41292014718056, 70.69575369358063, 69.47300210595131, 78.7502270936966, 78.29355999827385, 80.73552936315536, 80.36640956997871, 82.8505490720272, 79.73361432552338, 82.16449588537216, 79.61860209703445, 94.72148448228836, 80.80521762371063, 97.31984585523605, 16.113586351275444, 2.28039538487792, 7.735481942072511, 8.861029520630836, 5.552282491698861, 11.825889777392149, 3.4474877966567874, 1.0345588484779, 0.2972351317293942, 7.339267702773213, 50.59694118797779, 58.491408973932266, 79.99541267752647, 93.6911241710186, 123.42097967863083, 69.19285833835602, 34.03928026556969, 38.88889543712139, 60.11842466890812, 72.22747430205345, 91.94507986307144, 35.935294926166534, 0.4752395488321781, 0.3199993242742494, 0.17070846719434485, 0.0912951554346364, 0.17572030919836834, 0.19604880275437608, 0.09970222658012062, 0.1111701299669221, 0.13059783435892314, 0.23662829480599612, 0.2334652465651743, 0.25892573583405465], [0.026987814344465733, 0.03035747093235841, 0.006070366771382396, 0.06247714554774575, 0.05639306713419501, 0.08851153019350022, 0.13624231272842735, 0.04078992431459483, 0.08634171303128824, 0.06407127133570611, 0.07870649031247012, 0.17764373333193362, 0.5295120365917683, 15.068942606449127, 73.51046025753021, 64.91317838430405, 60.85268206894398, 40.622518211603165, 29.488600753247738, 31.120672076940536, 84.84068468213081, 67.06537529826164, 18.21796853095293, 0.013230981876404257, 0.3306044661439955, 1.676259865052998, 3.665673276409507, 1.7785272211767733, 4.091382957994938, 1.812177503015846, 0.3316386340884492, 1.6795107093639672, 60.7060669362545, 107.05986320972443, 92.29914486408234, 94.132060110569, 84.16664645075798, 81.94641038775444, 75.12969017028809, 76.06849819421768, 73.1918777525425, 76.59300684928894, 77.44198009371758, 75.1353594660759, 69.73749071359634, 65.52453517913818, 64.12209123373032, 62.19111084938049, 59.44615714251995, 61.58529035747051, 65.93982249498367, 66.85767844319344, 64.61801782250404, 62.25237496197224, 61.35955207049847, 58.71072940528393, 58.285482823848724, 56.80904544889927, 52.82284274697304, 53.22500936686993, 55.72351969778538, 63.62056374549866, 70.30031651258469, 73.25558513402939, 71.44447311758995, 71.6925922036171, 72.90926411747932, 75.52823558449745, 74.8751038312912, 76.13390028476715, 75.01906290650368, 74.08865243196487, 71.85365036129951, 70.77524542808533, 65.02859339118004, 59.77485090494156, 54.24600698053837, 52.5912793725729, 54.34701696038246, 61.6297821700573, 64.41858932375908, 70.19291907548904, 70.82759901881218, 58.227558732032776, 61.804979369044304, 59.12931874394417, 52.713944390416145, 44.676969051361084, 40.02268999814987, 37.765994891524315, 44.339425563812256, 57.446058467030525, 53.761016204953194, 62.38540582358837, 69.79881942272186, 66.58567383885384, 69.33916568756104, 71.31249099969864, 68.84292751550674, 70.72964027523994, 69.19655933976173, 65.91705411672592, 56.35160319507122, 49.99664939939976, 52.32451468706131, 53.42083565890789, 53.21063473820686, 51.98288641870022, 62.0584599673748, 64.59163203835487, 68.82199823856354, 67.37794652581215, 71.03523507714272, 68.25560063123703, 67.41282865405083, 61.34646937251091, 54.00632344186306, 52.246390879154205, 51.80007442831993, 54.969476759433746, 51.91916763782501, 60.45966535806656, 59.86657038331032, 61.991009786725044, 60.99802426993847, 58.73925447463989, 55.70018894970417, 54.91197444498539, 54.697008579969406, 56.81100234389305, 57.76913993060589, 60.388521775603294, 62.1942912787199, 66.44937515258789, 66.07887223362923, 65.28711631894112, 61.45766660571098, 67.85226747393608, 64.37188223004341, 68.8194827735424, 79.04755353927612, 78.6109721660614, 59.07735273241997, 0.4656949359923601, 1.1649346025660634, 1.8531206622719765, 3.420928646810353, 4.154838128015399, 5.813072472810745, 0.885071960510686, 0.0627704497310333, 0.1363136331201531, 15.700773652642965, 28.49901605397463, 41.563438922166824, 98.6545242369175, 126.23462989926338, 96.2051072716713, 28.828695863485336, 23.817980736494064, 36.9242412596941, 52.35775910317898, 63.8103711605072, 33.27087789773941, 0.12327515971264802, 0.10885016148677096, 0.0346967471705284, 0.0338766702770954, 0.0214527600837755, 0.08625511181890033, 0.011816479945991887, 0.038348822490661405, 0.028002974031551275, 0.01798222521756543, 0.046320727924467064, 0.04944986001646612, 0.034733353604678996, 0.06650677736615762, 0.03564571656170301, 0.026536349214438815, 0.016790499321359675, 0.05496057739946991, 0.20715618564281613, 0.02486268560460303, 0.0041092990522884065, 0.06413042050553486, 0.05620602736598812, 0.24102554947603494, 0.8634469646494836, 19.262954257428646, 89.57719892263412, 73.84703859686852, 71.87736868858337, 49.02140513062477, 39.97587651014328, 34.58697147667408, 91.80686607956886, 79.44170638918877, 20.468950644135475, 0.08866742573445663, 0.7795295957475901, 4.566005514934659, 4.5345645770430565, 2.5117827812209725, 4.300855742767453, 1.1629664269275963, 0.22676826920360327, 3.2769021252170205, 75.43715447187424, 105.5878221988678, 95.87560415267944, 95.20655885338783, 89.84125435352325, 84.26289528608322, 79.778391122818, 79.67499867081642, 77.59483829140663, 80.61453625559807, 82.28273794054985, 78.56301873922348, 73.36310416460037, 68.49663689732552, 66.5762959420681, 65.62958434224129, 65.73799252510071, 64.20666709542274, 70.36248117685318, 69.61849629878998, 67.23790884017944, 65.95714956521988, 64.44720178842545, 62.42026135325432, 60.237514078617096, 59.32432807981968, 55.51503628492355, 55.20368479192257, 59.510784074664116, 66.04287296533585, 74.58069562911987, 76.68398156762123, 72.8123465180397, 75.97766786813736, 77.71188721060753, 79.22422125935555, 76.83514505624771, 79.86919865012169, 77.01542258262634, 74.99383985996246, 76.15466997027397, 74.59663197398186, 66.87583386898041, 60.532841831445694, 55.92237822711468, 55.523768216371536, 58.56646254658699, 64.29490596055984, 68.84450063109398, 72.24626049399376, 72.27060958743095, 62.16630578041077, 65.91614216566086, 60.838102251291275, 55.479519590735435, 48.142941668629646, 42.676156014204025, 43.35072621703148, 48.926797807216644, 62.64159947633743, 58.86657424271107, 65.35878047347069, 72.42505609989166, 69.69310909509659, 72.66429126262665, 73.56349021196365, 71.28463849425316, 74.70030561089516, 71.75820708274841, 68.90172556042671, 59.46798697113991, 52.17079773545265, 54.357557594776154, 55.958126708865166, 56.700523272156715, 54.93079483509064, 61.93220414221287, 66.4836037158966, 70.51091641187668, 69.49878752231598, 72.0374844968319, 70.27904525399208, 71.12137645483017, 64.27615776658058, 56.83062829077244, 53.463115990161896, 53.82753923535347, 57.820801958441734, 55.09104363620281, 61.1928816139698, 63.0903135985136, 64.29697304964066, 65.8381399512291, 62.39716239273548, 59.217170029878616, 57.193337827920914, 58.015450313687325, 59.574780240654945, 60.820558592677116, 62.988338470458984, 64.71630334854126, 65.62855839729309, 67.74199739098549, 66.94327265024185, 63.70160199701786, 68.65846261382103, 67.86976933479309, 70.31074315309525, 82.31385827064514, 81.39711186289787, 67.1730463206768, 0.9396798990201205, 0.811868947930634, 1.96880771080032, 1.9317211071029305, 3.2087038597092032, 3.1932325148954988, 2.0003437623381615, 0.08461520294076763, 0.18731081538135186, 16.69750101864338, 37.50535547733307, 48.2773594558239, 92.7318124473095, 116.25008806586266, 82.54514425992966, 30.152704417705536, 34.845277816057205, 45.981264263391495, 59.9702288210392, 73.24818313121796, 41.23456656932831, 0.11175706487847492, 0.07889884756878018, 0.05698264780221507, 0.015629086447006557, 0.008485540274705272, 0.022241377337195445, 0.02543590006098384, 0.05232603107288014, 0.06691596790915355, 0.06818636145908386, 0.029468301945598796, 0.0251727827344439, 0.13677961280336604, 0.10467097206856124, 0.138174241874367, 0.12804925470845774, 0.12722052808385342, 0.3137637104373425, 0.4335334914503619, 0.1907445990946144, 0.2609726384980604, 0.23524165124399588, 0.2504604135174304, 0.4332211660221219, 1.2306415080092847, 25.460448302328587, 104.18005093932152, 85.90009063482285, 82.90984869003296, 62.37052582204342, 47.14674912393093, 48.08768503367901, 101.41132190823555, 90.34694641828537, 31.124772056937218, 0.24620505748316646, 0.9404529200401157, 7.213350059464574, 9.880230780690908, 6.141602843999863, 13.766809478402138, 6.359173469245434, 1.0126120573841035, 2.8531403141096234, 76.70969858765602, 112.02286809682846, 100.94601407647133, 101.3003146648407, 94.14179518818855, 88.72605219483376, 84.2521570622921, 81.15555882453918, 83.80087047815323, 82.12097302079201, 84.47367757558823, 83.22559654712677, 78.7526285648346, 73.22610631585121, 69.51075688004494, 67.71719232201576, 68.07591587305069, 67.87848606705666, 75.34863442182541, 74.74148780107498, 74.31388914585114, 70.24672418832779, 67.96829044818878, 65.35997360944748, 64.0075957775116, 61.84764727950096, 58.171982914209366, 57.972839400172234, 63.0129649490118, 69.70566362142563, 77.51416862010956, 79.69777464866638, 76.99057951569557, 77.76273608207703, 80.59230744838715, 82.6336719095707, 79.37109857797623, 81.92054897546768, 81.09928384423256, 79.04300138354301, 82.11601048707962, 77.98507735133171, 69.72232952713966, 65.42811915278435, 60.02977542579174, 57.25296042859554, 62.24439159035683, 67.76126235723495, 72.3575109243393, 76.08990624547005, 74.98994126915932, 65.24329707026482, 71.07558131217957, 64.84276056289673, 59.44743387401104, 50.84002934396267, 43.84413734078407, 42.41756469011307, 53.71207483112812, 68.72581019997597, 62.21986770629883, 68.52632850408554, 75.50439566373825, 72.8294987976551, 76.16865321993828, 79.16828826069832, 74.4224265217781, 77.93094545602798, 75.4131093621254, 71.93224534392357, 62.57206700742245, 54.90758188068867, 58.11041481792927, 58.92172448337078, 58.81623834371567, 57.36466683447361, 66.82425543665886, 71.16740718483925, 77.07745805382729, 72.79927521944046, 76.1232228577137, 75.17553091049194, 73.3263449370861, 66.83461368083954, 58.847715854644775, 56.367934718728065, 56.42750792205334, 61.090024933218956, 58.84839981794357, 67.78909206390381, 67.8629145026207, 68.72263357043266, 67.08597019314766, 66.11301720142365, 61.49166338145733, 60.64095363020897, 62.345534563064575, 62.58902549743652, 63.834735453128815, 67.41779878735542, 69.44665431976318, 72.45628282427788, 74.22250404953957, 71.84485003352165, 68.51311281323433, 74.55450743436813, 72.25287213921547, 74.81749892234802, 88.65576356649399, 86.17663979530334, 71.3025963306427, 0.5947976990137249, 4.479946307837963, 9.966671392321587, 8.688671719282866, 10.62017172574997, 12.916716244071722, 2.036214550025761, 0.10700074431952089, 0.9411239996552467, 26.52838859707117, 48.7674343585968, 59.18229550123215, 104.0193347632885, 129.48732376098633, 110.73773145675659, 43.149257227778435, 39.38429765403271, 57.10227571427822, 69.35485124588013, 82.76137545704842, 48.6855411529541, 0.1714655023533851, 0.23958878125995398, 0.1438301196321845, 0.07802999301929958, 0.1463301628245972, 0.1869198222993873, 0.1317668060073629, 0.22352823056280613, 0.20465283247176558, 0.13681694283150136, 0.14067961368709803, 0.18874853354645893], [0.030319769830384757, 0.09026841638842598, 0.074120826611761, 0.13456134824082255, 0.0377075512369629, 0.032948781590675935, 0.06220663643034641, 0.0497989291761769, 0.0950644641125109, 0.026854869720409624, 0.050336173590039834, 0.10667520124115981, 0.3237314068246633, 21.946995332837105, 83.4226843714714, 62.92538724839687, 45.73594942688942, 27.382126785814762, 37.840204909443855, 72.44795367121696, 74.46385949850082, 47.551176622509956, 3.532843329012394, 0.10187466352363117, 0.1694767692242749, 2.15597462374717, 6.3348998967558146, 2.245417549274862, 2.708560209721327, 0.5311781284399331, 0.19060427381191403, 23.29035434871912, 102.38856866955757, 94.42890778183937, 98.62030327320099, 90.71702376008034, 92.39204227924347, 84.0589602291584, 88.4432865679264, 86.49425715208054, 90.4838302731514, 88.86988207697868, 90.009456127882, 84.72905427217484, 84.46480125188828, 70.08254259824753, 65.7084909081459, 62.23325438797474, 61.46439604461193, 60.527218133211136, 61.809379532933235, 60.698832124471664, 60.909352228045464, 60.55378630757332, 58.64663824439049, 58.35632622241974, 58.06882604956627, 53.02965804934502, 53.87921646237373, 50.190807580947876, 61.81691452860832, 72.3394238948822, 76.40811637043953, 74.1586446762085, 74.61567655205727, 75.66288515925407, 77.23029345273972, 78.31605479121208, 76.87008798122406, 73.5042741894722, 75.16575783491135, 72.7395348250866, 70.76703026890755, 61.7909125238657, 54.95333522558212, 51.173909828066826, 54.924354180693626, 53.49791832268238, 56.83947801589966, 61.59450486302376, 65.37932977080345, 70.35471439361572, 66.05624064803123, 56.139114797115326, 56.35426685214043, 55.34802004694939, 53.40676121413708, 52.00081005692482, 48.703593984246254, 48.79528306424618, 48.44222500920296, 53.48885960876942, 57.55937218666077, 61.965448558330536, 65.08699625730515, 64.32395160198212, 62.078614085912704, 62.21041761338711, 64.90604996681213, 65.15935197472572, 65.50957158207893, 63.24623063206673, 56.56838536262512, 50.32360665500164, 53.14219281077385, 53.230864852666855, 51.15909442305565, 51.85943104326725, 51.49793744087219, 55.23952066898346, 65.37742987275124, 69.39328238368034, 64.89316865801811, 68.81847962737083, 70.50996646285057, 64.34052631258965, 59.36682499945164, 50.32846659421921, 52.617756351828575, 52.17667602002621, 53.500752970576286, 53.32422964274883, 63.26165780425072, 62.04221583902836, 62.15347766876221, 59.15393002331257, 57.476422637701035, 55.93240588903427, 55.71700304746628, 53.715688437223434, 55.07076412439346, 55.58158591389656, 57.55145341157913, 55.15787445008755, 55.6306716799736, 54.4004762917757, 57.91319780051708, 59.120484218001366, 66.9999124109745, 72.57088467478752, 75.54582864046097, 75.37194237112999, 80.5368684232235, 9.575812015682459, 0.5972060572821647, 1.6820094315335155, 2.031247979030013, 2.203277572989464, 1.2958565773442388, 3.6783496337011456, 0.23601934779435396, 0.28950121079105884, 4.092119168490171, 24.23833318054676, 34.524438232183456, 81.78338393568993, 82.76109427213669, 77.71321713924408, 33.076936304569244, 16.0075606405735, 33.14014971256256, 54.69589523971081, 59.594493582844734, 50.22209890186787, 0.23734746559057385, 0.034401520824758336, 0.03983137008617632, 0.05603393816272728, 0.03247472734074108, 0.0970057443191763, 0.13267489790450782, 0.020934917265549302, 0.0024408200397374458, 0.06307486386504024, 0.03851387613394763, 0.04249224039085675, 0.02672606256965082, 0.024447266587230843, 0.03458361417870037, 0.016976143851934467, 0.09191144970827736, 0.07460011300281622, 0.025468934909440577, 0.029977999693073798, 0.071610846061958, 0.06837249951786362, 0.1569470454705879, 0.22239982470637187, 0.44267301040235907, 30.83322700113058, 95.55162593722343, 73.25485557317734, 54.298596158623695, 38.02679769694805, 31.271808966994286, 53.717592135071754, 84.01327148079872, 54.60765637457371, 4.052234133705497, 0.2343361865496263, 1.3751924014650285, 5.819156421348453, 3.6604547314345837, 4.6075448859483, 5.625780997797847, 1.76739108748734, 0.2585578087018803, 27.920823879539967, 102.71812498569489, 99.20886889100075, 102.3934780061245, 92.83227145671844, 96.96666240692139, 85.98934784531593, 91.88143327832222, 89.75575894117355, 92.85025209188461, 90.2690277993679, 93.83368492126465, 88.36597591638565, 86.5422485768795, 74.16001260280609, 68.29254984855652, 65.72187379002571, 66.59562170505524, 62.294537499547005, 64.61239412426949, 64.8247267305851, 64.91280600428581, 64.6942189335823, 62.27638207376003, 60.545198768377304, 59.45333495736122, 56.23145364224911, 58.14479157328606, 55.26501730084419, 65.9742334485054, 76.39532625675201, 80.06106555461884, 78.31932261586189, 78.84529799222946, 77.25818395614624, 80.15602245926857, 81.26632288098335, 78.32354038953781, 75.88125184178352, 78.24444383382797, 76.52169227600098, 70.58957979083061, 64.08943578600883, 57.95965030789375, 53.58684875071049, 57.368048653006554, 56.76766186952591, 57.956067100167274, 65.85439547896385, 69.7636941075325, 74.28346037864685, 67.62707635760307, 58.72029349207878, 60.13756804168224, 55.41827827692032, 54.73748400807381, 53.83410148322582, 53.62840712070465, 50.943535789847374, 52.40585312247276, 56.48985497653484, 60.51882818341255, 65.28266295790672, 69.6639646589756, 67.54917293787003, 66.9805258512497, 64.64703306555748, 65.55842936038971, 67.85032197833061, 67.90607258677483, 65.0783783197403, 59.51006971299648, 54.62089106440544, 56.30450092256069, 55.553463622927666, 53.59072454273701, 53.75436656177044, 53.47967930138111, 57.07784302532673, 68.46718087792397, 72.51097708940506, 70.15536189079285, 69.54050168395042, 73.74361574649811, 66.57234415411949, 64.2460785806179, 53.7790272384882, 54.820798337459564, 54.406909346580505, 56.26233458518982, 55.91265454888344, 64.7322016954422, 65.72596997022629, 64.04531255364418, 63.42919461429119, 60.05768872797489, 57.364704832434654, 58.27590733766556, 56.2258717417717, 58.36284667253494, 58.09575140476227, 59.7115159034729, 57.09739297628403, 58.033408150076866, 57.03823775053024, 61.44613802433014, 64.1075912117958, 71.43069505691528, 76.09755903482437, 80.29060363769531, 77.1022479236126, 84.23287689685822, 11.631186325103045, 0.7217927626334131, 0.5679176445119083, 1.978784075472504, 5.162835214287043, 2.0039424067363143, 4.243803229182959, 2.266875710338354, 0.47426567296497524, 2.813436007127166, 30.070311538875103, 39.17020574212074, 84.14828583598137, 84.52171459794044, 78.44981521368027, 33.17275196313858, 20.939618088304996, 38.41894805431366, 62.54576861858368, 67.91988864541054, 60.0938817858696, 0.2842015342321247, 0.028069362851965707, 0.008561557533539599, 0.0570089124084916, 0.01591902499058051, 0.015311003808164969, 0.0032045540092440206, 0.035581743431976065, 0.09425757147255354, 0.014387192295544082, 0.013880270180379739, 0.023121594167605508, 0.11270808259723708, 0.18017935508396477, 0.1788122596917674, 0.2658149739727378, 0.18729144532699138, 0.19521375303156674, 0.1467020233394578, 0.10493941430468112, 0.2522789128124714, 0.3092117328196764, 0.2614788425853476, 0.3976772498572245, 0.7513037603348494, 39.38015207648277, 111.05363130569458, 81.79239705204964, 65.93110576272011, 42.08531051874161, 49.0916595607996, 98.92552569508553, 91.71498700976372, 73.25341165065765, 5.692254630848765, 0.22620549862040207, 1.1569538433104753, 8.700038809329271, 15.737233646214008, 10.867710392922163, 10.781369525939226, 8.352594003081322, 0.8084506157319993, 33.758699521422386, 112.32888847589493, 102.77657344937325, 107.07863420248032, 97.6515680551529, 101.83608591556549, 87.8631716966629, 96.1939586699009, 92.80637964606285, 96.74631983041763, 95.4365985095501, 96.30511790513992, 91.01372703909874, 92.5273834168911, 77.07973033189774, 73.07029187679291, 68.73062074184418, 70.60655727982521, 68.16079571843147, 70.12641504406929, 69.25465822219849, 67.95720264315605, 68.68704468011856, 66.31724864244461, 62.03416407108307, 62.974541410803795, 59.769736379384995, 62.52704702317715, 56.76793545484543, 69.76382330060005, 78.26009899377823, 83.80971640348434, 80.93694895505905, 80.73851600289345, 80.44138714671135, 83.09492155909538, 85.62674850225449, 81.40700653195381, 78.00580143928528, 82.86422073841095, 79.06420424580574, 76.22450262308121, 70.01694291830063, 61.37752890586853, 57.64932855963707, 62.299777418375015, 59.19583037495613, 63.074802830815315, 69.49387058615685, 73.83872464299202, 76.83116286993027, 72.45310619473457, 60.68481467664242, 65.86355298757553, 59.43984568119049, 57.16114975512028, 57.72489130496979, 52.79736131429672, 54.25553686916828, 54.560455307364464, 61.1706680059433, 65.48754796385765, 70.30251279473305, 73.128512352705, 70.79925253987312, 69.03258293867111, 67.69754737615585, 70.30100807547569, 71.18413388729095, 72.54842787981033, 70.46949103474617, 62.099691554903984, 55.77228628098965, 58.917860090732574, 57.63373799622059, 57.11525961756706, 56.32036127150059, 56.35932818055153, 61.52510918676853, 71.65347710251808, 77.65999719500542, 71.94746732711792, 74.6688736975193, 76.37677565217018, 68.89715060591698, 66.60165578126907, 56.898523047566414, 57.94771134853363, 56.92945718765259, 61.28390192985535, 59.19865742325783, 70.58473125100136, 67.65141785144806, 67.24833548069, 65.65502017736435, 65.08461758494377, 61.66763573884964, 63.27515847980976, 61.132985427975655, 61.50392912328243, 60.80237276852131, 63.469510450959206, 60.77419728040695, 61.57786935567856, 60.39542980492115, 65.2264791727066, 67.59624481201172, 75.29808953404427, 81.37588620185852, 83.08502689003944, 81.49508580565453, 88.4200394153595, 13.135516103357077, 1.5377500536851585, 6.341673508286476, 10.465917102992535, 8.285234067589045, 5.192625615745783, 9.017368331551552, 1.2811149121262133, 0.4745778499636799, 6.679683420807123, 45.36830395460129, 52.61779434978962, 89.67888906598091, 84.6475638449192, 90.6326150894165, 47.76467576622963, 27.324909456074238, 50.087285935878754, 71.41472831368446, 78.62249314785004, 70.00781580805779, 0.33916362561285496, 0.10716478122049011, 0.1106312416959554, 0.16663162736222148, 0.14550015970598906, 0.16069817153038457, 0.12577767425682396, 0.1052627457829658, 0.10655365971615538, 0.16257052106084302, 0.07602622397826053, 0.14152402931358665], [0.028707685924018733, 0.032605501182843, 0.10427128101582639, 0.03663368210254703, 0.06336721067782491, 0.022695280422340147, 0.011363705853000283, 0.05469304058351554, 0.053178936868789606, 0.049448513018433005, 0.10786734274006449, 0.05990868747176137, 0.173080489912536, 32.36664421856403, 77.19150513410568, 59.70805048942566, 52.32259579002857, 36.164939403533936, 62.4961356818676, 71.26856535673141, 54.54286605119705, 25.269265361130238, 0.28798660612665117, 0.03158136707497761, 0.6829624681267887, 3.2306685810908675, 1.8908091774210334, 2.266940069384873, 4.564911648631096, 2.043622015044093, 6.257833382114768, 69.84851315617561, 81.8547973036766, 101.80216893553734, 91.55711308121681, 95.1679377257824, 91.43017709255219, 94.38470855355263, 90.72718441486359, 91.73807457089424, 86.74734637141228, 90.73091581463814, 90.21758615970612, 89.97543275356293, 86.40354081988335, 84.37294498085976, 70.89143559336662, 63.167612850666046, 61.680889427661896, 61.4209795743227, 60.350208431482315, 61.23008921742439, 58.23465295135975, 58.398769944906235, 57.28372737765312, 60.56936167180538, 55.64950726926327, 53.320870622992516, 50.32729245722294, 56.35967396199703, 70.03546312451363, 77.42317870259285, 72.04858750104904, 75.56127861142159, 76.68297842144966, 76.36859849095345, 76.49542048573494, 73.92559558153152, 75.69562420248985, 72.83829152584076, 67.98145294189453, 62.919660955667496, 55.03549821674824, 52.09688790142536, 52.38761030137539, 53.82745563983917, 53.67926359176636, 54.80270750820637, 57.412221282720566, 62.9440176486969, 67.65549123287201, 69.11408856511116, 63.44364903867245, 56.20938442647457, 54.01458039879799, 55.33359982073307, 51.630709916353226, 50.06549030542374, 52.99161449074745, 52.81218811869621, 52.8917520493269, 52.03402407467365, 54.869257137179375, 59.74798634648323, 61.811591014266014, 66.27732038497925, 63.99368852376938, 60.565805062651634, 58.16685698926449, 62.10818409919739, 61.613899022340775, 58.861075937747955, 53.34277644753456, 49.98331971466541, 52.97220893204212, 53.72810997068882, 54.45911094546318, 48.28323394060135, 50.77003329992294, 50.72543889284134, 57.73946352303028, 64.11646753549576, 67.40503147244453, 63.90736475586891, 70.3058186173439, 67.64987513422966, 65.66221699118614, 55.297889336943626, 48.87911796569824, 52.01867289841175, 51.22898407280445, 53.48700910806656, 60.06658025085926, 62.288784608244896, 63.22735324501991, 63.372087478637695, 59.13361631333828, 56.36246681213379, 55.08169233798981, 55.66782608628273, 55.481320694088936, 58.701765686273575, 55.15833422541618, 54.446951597929, 60.19636608660221, 60.73875658214092, 66.73012688755989, 71.07973828911781, 74.0650101006031, 74.83356446027756, 78.24305310845375, 76.22189596295357, 81.46969556808472, 19.427132047712803, 0.2816716121742502, 0.14206318475771695, 1.716304135043174, 1.1935722408816218, 1.826160871423781, 2.9100816836580634, 1.4609851478599012, 0.09656805530539714, 0.16537141607841477, 19.8625335842371, 23.004142306745052, 42.48899705708027, 77.31314420700073, 45.00767670571804, 36.12419418990612, 38.13869409263134, 40.325678139925, 49.92009490728378, 56.135915368795395, 55.86756996810436, 1.8795546563342214, 0.2265575883211568, 0.14730141148902476, 0.013924622780905338, 0.056985441988217644, 0.04509853315539658, 0.03684703100589104, 0.06240664893994108, 0.03361097398737911, 0.05633770291751716, 0.021272976664477028, 0.015939729055389762, 0.02716180530114798, 0.04456181937712245, 0.07493206081562676, 0.10519197458052076, 0.06815053799073212, 0.024089983708108775, 0.04519972499110736, 0.026643656347005162, 0.026798974868142977, 0.1237544312607497, 0.021756873647973407, 0.0953112133720424, 0.2261932086548768, 40.784408524632454, 87.90495425462723, 68.1615100800991, 59.89677496254444, 48.06019350886345, 55.33303365111351, 66.59967228770256, 68.46636012196541, 27.346807681024075, 0.2496069436892867, 0.41110276069957763, 4.303774936124682, 3.032008591108024, 4.761938201263547, 1.0692763980478048, 2.36320695374161, 1.655761271249503, 9.740546476095915, 81.24777227640152, 86.1132287979126, 102.58295863866806, 93.88759642839432, 97.32322007417679, 95.57641580700874, 98.50914403796196, 92.66299813985825, 95.20143672823906, 89.52586367726326, 93.11866208910942, 92.43045821785927, 95.31888082623482, 88.6049222946167, 88.82296219468117, 72.65221551060677, 67.12323859333992, 65.11434718966484, 66.7645226418972, 63.07318411767483, 64.27539020776749, 59.7440155595541, 62.18103379011154, 59.727976620197296, 62.47333690524101, 59.86797630786896, 57.11629316210747, 54.48428839445114, 61.4733749628067, 73.5974831879139, 80.23770287632942, 75.24260491132736, 78.96366164088249, 79.94862198829651, 78.83053958415985, 78.19710597395897, 76.51364430785179, 76.10718011856079, 75.70547327399254, 70.79516395926476, 64.33850482106209, 58.965076357126236, 54.22771856188774, 55.19508205354214, 58.57850410044193, 55.384805873036385, 58.7541838735342, 60.99670574069023, 67.06057995557785, 71.48658245801926, 72.53946036100388, 65.41840687394142, 59.78673666715622, 54.90044206380844, 54.92220349609852, 52.40095138549805, 50.759059488773346, 55.610418766736984, 53.87742295861244, 54.26144555211067, 54.07332144677639, 59.399700835347176, 61.31085008382797, 62.97776363790035, 69.82196778059006, 68.39028060436249, 65.75036466121674, 60.4585862159729, 62.58350819349289, 62.166142389178276, 60.86737588047981, 55.11857695877552, 53.273756951093674, 55.740367993712425, 57.6746542006731, 57.663087621331215, 52.24751941859722, 52.515325248241425, 53.037041053175926, 59.069487154483795, 65.83515331149101, 70.93048989772797, 67.3715552687645, 71.19502410292625, 71.09961122274399, 67.57254928350449, 59.49659563601017, 51.21000409126282, 55.08538194000721, 52.028461173176765, 55.907969400286674, 64.91221323609352, 66.20743453502655, 67.7450980246067, 66.82810083031654, 62.413733303546906, 60.02404913306236, 58.658410012722015, 58.21938157081604, 58.947787284851074, 58.95060673356056, 58.281109258532524, 58.52266989648342, 62.818909361958504, 64.9006998538971, 70.03917932510376, 75.20447015762329, 77.3786298930645, 78.76022815704346, 80.35257831215858, 81.90688490867615, 83.90742436051369, 27.508998177945614, 0.07134227023925632, 0.5081197782419622, 1.6714779403991997, 1.5503664454445243, 4.612792879343033, 2.4301937967538834, 3.8702474115416408, 1.1732844170182943, 0.2582736255135387, 22.144200950860977, 33.91887612640858, 45.611460506916046, 85.97626134753227, 49.79909420013428, 33.68097849190235, 42.42360256612301, 49.90389257669449, 59.66437943279743, 62.85712011158466, 65.07841631770134, 2.5689751747995615, 0.31995559693314135, 0.13817252009175718, 0.025917002858477645, 0.0781977926089894, 0.03315623784146737, 0.04494826680456754, 0.06637942482484505, 0.055898774517118, 0.018450008319632616, 0.06477315007941797, 0.08720181023818441, 0.23959912679856643, 0.1323307491838932, 0.22306504135485739, 0.35015183442737907, 0.09563618499669246, 0.13983960641780868, 0.11386666417820379, 0.1539261927246116, 0.22725732967955992, 0.10974673525197431, 0.15592987270792946, 0.2520166971953586, 0.31983602209948003, 47.0375619828701, 101.10073417425156, 75.98866447806358, 72.66017228364944, 48.636888563632965, 88.82100149989128, 92.06146001815796, 73.95904138684273, 40.899857729673386, 0.5707377463113517, 0.22209641989320517, 5.064919218420982, 12.020870614796877, 11.041768603026867, 4.960382077842951, 16.401601396501064, 2.5345654087141156, 8.747116383165121, 85.38655579090118, 92.37935855984688, 108.27559277415276, 100.31430557370186, 102.68862336874008, 99.57251697778702, 100.18436014652252, 96.5717040002346, 97.73716986179352, 94.37890246510506, 98.69667157530785, 94.74636554718018, 97.65666738152504, 92.0990552008152, 91.73045977950096, 76.68281883001328, 69.30669263005257, 69.48592141270638, 70.43023154139519, 66.3046333193779, 68.01910132169724, 63.48576597869396, 64.55978974699974, 62.877753004431725, 67.75371596217155, 64.17930856347084, 60.802790746092796, 57.67969653010368, 63.2727076113224, 77.90341213345528, 83.8637039065361, 80.41589811444283, 83.54928597807884, 82.55604207515717, 82.17580407857895, 82.79753431677818, 80.88328063488007, 81.30904778838158, 80.0847002863884, 74.20364186167717, 68.35669800639153, 62.52075456082821, 57.422921508550644, 56.546228751540184, 60.098053961992264, 59.44203816354275, 59.899419620633125, 63.37265744805336, 70.62141448259354, 76.26081347465515, 77.14436486363411, 69.64632600545883, 64.2073130607605, 59.36008796095848, 58.47798049449921, 52.143264412879944, 50.828371569514275, 55.521545335650444, 55.95683477818966, 56.68463632464409, 57.05647677183151, 62.22403988242149, 64.68208238482475, 68.13632503151894, 73.5644705593586, 72.27111116051674, 68.76131549477577, 63.45725990831852, 69.1195298731327, 67.91972905397415, 65.33448457717896, 58.114176616072655, 55.923354774713516, 59.04270999133587, 59.460087195038795, 60.40328398346901, 54.13151912391186, 55.51589123904705, 57.49550141394138, 62.2917066514492, 69.95661735534668, 71.73329561948776, 70.24104729294777, 76.2786877155304, 74.27958458662033, 72.20756337046623, 63.110509514808655, 52.88101762533188, 58.19614961743355, 56.49520128965378, 58.40856961905956, 68.55720564723015, 70.78767076134682, 70.03495395183563, 70.33687055110931, 64.46955218911171, 62.78858318924904, 62.32922583818436, 62.13861666619778, 62.877984791994095, 63.57681289315224, 61.369488537311554, 61.292071491479874, 67.27804228663445, 68.09505924582481, 72.00658455491066, 78.61518993973732, 81.9686771929264, 84.04623851180077, 84.71751049160957, 84.73186612129211, 89.83216524124146, 27.468866631388664, 0.2716273261466995, 3.7849761871621013, 5.230173300951719, 4.559264201670885, 6.074907872825861, 8.662757109850645, 3.3013208024203777, 0.885030044009909, 0.4288818285567686, 33.38849678635597, 44.220393151044846, 60.66795498132706, 89.15606752038002, 63.93442690372467, 50.86177937686443, 52.52128332853317, 57.68221199512482, 69.06922057271004, 72.56627172231674, 78.42795878648758, 3.123927083797753, 0.4888540698448196, 0.3305586607893929, 0.12364605543552898, 0.16918957291636616, 0.18088881857693195, 0.12191313318908215, 0.2114631060976535, 0.11863114836160094, 0.10989516478730366, 0.14340402296511456, 0.18627787940204144], [0.06545702432049438, 0.027945260917476844, 0.04579942855343688, 0.03789798262005206, 0.04996800525987055, 0.06401773280231282, 0.04242052666086238, 0.037184700777288526, 0.015929522669466678, 0.04726404215034563, 0.027735969706554897, 0.0689617425086908, 0.12082142653525807, 31.901872158050537, 76.22850760817528, 59.774710312485695, 56.30872629582882, 30.380543991923332, 54.107215628027916, 71.76967486739159, 47.795157730579376, 7.920777099207044, 0.12208028711029328, 0.24235154472989962, 1.703837241511792, 4.4660514034330845, 1.1177916009910405, 3.9568659011274576, 3.153470498509705, 2.6685896795243025, 69.69656690955162, 89.75126758217812, 77.47279644012451, 86.96569785475731, 89.0642112493515, 94.08874243497849, 92.16801390051842, 93.4920984506607, 90.17226219177246, 89.96401816606522, 91.19990184903145, 92.3839259147644, 86.1325241625309, 88.10211807489395, 86.35198518633842, 82.47422486543655, 80.6737294793129, 66.62424936890602, 62.80547708272934, 61.585480347275734, 59.87018778920174, 60.46260640025139, 58.09769690036774, 58.72573859989643, 59.018687680363655, 55.513295978307724, 53.1522660702467, 52.44076944887638, 53.88757221400738, 59.5373522490263, 72.5135837495327, 73.48066225647926, 69.81398060917854, 72.09508940577507, 73.50738242268562, 74.6013893187046, 70.36334753036499, 67.99177318811417, 66.39088869094849, 62.18707546591759, 52.84924753010273, 55.158250629901886, 54.64924514293671, 56.15380100905895, 64.12953123450279, 65.25201380252838, 61.18329092860222, 62.0971342921257, 59.963852763175964, 65.80708801746368, 66.47207513451576, 66.64236679673195, 59.02251027524471, 54.36045303940773, 53.01231198012829, 56.765583381056786, 55.240219831466675, 55.67626543343067, 54.634125754237175, 51.082600727677345, 51.9722355902195, 53.33448149263859, 50.47511212527752, 57.50444993376732, 56.978375762701035, 63.00171755254269, 66.13811865448952, 65.3444704413414, 62.00502723455429, 58.293963968753815, 55.83207607269287, 53.27108569443226, 50.78216224908829, 51.48390859365463, 55.54994881153107, 63.218024745583534, 64.72679078578949, 63.247473165392876, 49.42827209830284, 49.372753277421, 50.206318348646164, 59.22500900924206, 64.43803668022156, 67.8961931169033, 64.44037735462189, 64.40482646226883, 65.86913868784904, 59.03486721217632, 51.57608024775982, 50.77888682484627, 51.98541708290577, 52.06618934869766, 58.780957236886024, 64.35818776488304, 63.5234447568655, 64.79732260107994, 59.949687123298645, 57.04408563673496, 54.670425206422806, 55.120313465595245, 53.80966879427433, 57.4876244366169, 59.35319893062115, 65.48122510313988, 67.94708758592606, 73.2379312813282, 72.2366090118885, 74.3850365281105, 76.77703857421875, 81.40340432524681, 75.13078451156616, 78.23753580451012, 71.1936941742897, 70.22244349122047, 10.872017461806536, 0.9532972995657474, 0.43697756133042276, 3.5901126684620976, 1.0435568843968213, 1.103711575269699, 3.8531991513445973, 0.284961523138918, 0.3967719484353438, 3.2002495508641005, 42.925445437431335, 25.667409896850586, 46.56496614217758, 42.440697848796844, 42.10730753839016, 25.56000865995884, 21.42226628959179, 49.984239265322685, 53.60603392124176, 63.95961955189705, 5.249063037335873, 0.2901810180628672, 0.030222019704524428, 0.00730367612959526, 0.051116259855916724, 0.03096886332059512, 0.11718858397216536, 0.053103642276255414, 0.058529951493255794, 0.028359490643197205, 0.02423503276077099, 0.02157378210540628, 0.04518682646448724, 0.04473054294066969, 0.0859378807945177, 0.0513074630725896, 0.015352313603216317, 0.020370725469547324, 0.03674903040518984, 0.01733018540107878, 0.02837984404322924, 0.044617636303883046, 0.02889912106184056, 0.02592224056570558, 0.13281871128128842, 37.8614267706871, 87.55973517894745, 65.82104086875916, 64.55727428197861, 35.08922852575779, 50.11838346719742, 77.83132240176201, 58.15901041030884, 8.34705675020814, 0.1757593164802529, 1.0041163070127368, 2.8304750053212047, 4.01060214266181, 2.6894712215289474, 2.169936024583876, 0.4140692140208557, 7.021660795435309, 76.34285107254982, 93.83493885397911, 87.95663148164749, 88.46590295433998, 91.63618683815002, 97.98522055149078, 97.40654200315475, 93.70410427451134, 94.28123250603676, 94.6435734629631, 94.11400347948074, 93.60443562269211, 87.4949562549591, 91.36395424604416, 89.63176399469376, 85.79811930656433, 84.36249554157257, 69.8183199763298, 65.26594385504723, 65.09502902626991, 62.74221047759056, 61.858548894524574, 62.48933784663677, 61.950165778398514, 62.76288516819477, 59.35016669332981, 56.89809367060661, 53.89452584087849, 57.25411556661129, 60.50649784505367, 74.99963834881783, 78.02309811115265, 72.28316411376, 73.87530148029327, 78.84249374270439, 78.371721804142, 74.1878043115139, 69.93137910962105, 68.97950738668442, 63.98838400840759, 55.47603137791157, 56.12412840127945, 57.11459845304489, 60.98614990711212, 67.3509831726551, 69.89027291536331, 65.64713940024376, 67.00236707925797, 65.35138607025146, 69.05239507555962, 70.0500999391079, 68.06866586208344, 64.47652861475945, 56.70991636812687, 53.782542049884796, 57.804234847426414, 57.71539181470871, 58.215733766555786, 56.75080977380276, 54.3326423317194, 54.05243016779423, 53.631025180220604, 52.36898750066757, 59.511829018592834, 59.322093799710274, 66.01347774267197, 69.84725162386894, 67.13964611291885, 66.65581807494164, 59.488437473773956, 59.12922374904156, 54.172454327344894, 53.39062348008156, 55.85210859775543, 61.05319730937481, 67.34592944383621, 69.69375506043434, 64.00910809636116, 52.23673939704895, 50.747378915548325, 54.08412806689739, 59.99031454324722, 69.13559541106224, 69.85753387212753, 69.83973562717438, 66.71226024627686, 69.54758450388908, 63.39273937046528, 53.925456181168556, 53.409185484051704, 54.4683026522398, 53.487210497260094, 61.06601782143116, 66.02950528264046, 67.82408058643341, 67.3720720410347, 62.94926516711712, 61.303915455937386, 58.68804842233658, 56.47668868303299, 57.399092987179756, 61.193877160549164, 62.08036959171295, 67.7330830693245, 72.86400854587555, 76.51189640164375, 76.58801391720772, 77.44257286190987, 79.88811403512955, 84.62900564074516, 77.4632665514946, 79.26655098795891, 72.88484662771225, 77.48043403029442, 21.155273616313934, 0.42553542531095445, 0.39852332789450884, 2.1844184724614024, 2.489433567970991, 3.496528440155089, 3.321366864256561, 0.90130201773718, 0.5933139380067587, 2.4621937796473503, 52.92307376861572, 34.60443913936615, 53.50037679076195, 50.00095836818218, 34.92697723209858, 35.00641196966171, 30.86309339851141, 55.2915208786726, 59.73240338265896, 73.592429459095, 7.71732984110713, 0.39653021609410644, 0.11591438320465386, 0.03396788764803205, 0.01721500222629402, 0.0895743969886098, 0.12301583847147413, 0.03704268339788541, 0.036738465933012776, 0.05148673626536038, 0.02431972294289153, 0.054218247896642424, 0.1582940435037017, 0.14334781270008534, 0.15252391953254119, 0.15368425258202478, 0.22237165278056636, 0.17759150097845122, 0.13546286470955238, 0.09811675423406996, 0.1348559363395907, 0.123890563409077, 0.15048697649035603, 0.19883384549757466, 0.30880856851581484, 44.767901971936226, 99.65466856956482, 73.4291522204876, 77.54794120788574, 41.76930047571659, 71.37869864702225, 86.79625734686852, 72.59061321616173, 13.120970483869314, 0.2785913133993745, 0.5861230019945651, 6.292223911732435, 11.569400690495968, 5.991921750828624, 17.38616656512022, 10.204031355679035, 5.490910084918141, 78.22112068533897, 98.21852803230286, 92.44653895497322, 90.90752273797989, 94.64652210474014, 97.93614998459816, 96.85707628726959, 97.90270417928696, 98.0540044605732, 96.4814892411232, 96.02654725313187, 97.54003643989563, 92.03556060791016, 92.96998366713524, 93.599883466959, 89.1047702729702, 88.01611348986626, 74.632258862257, 69.31974112987518, 67.78315678238869, 65.89227184653282, 66.39037191867828, 65.74113115668297, 65.29932886362076, 67.65918463468552, 62.99439154565334, 60.681999027729034, 59.23556104302406, 61.77800461649895, 65.42561128735542, 79.83935505151749, 81.49165838956833, 75.30913174152374, 77.94004216790199, 81.84035047888756, 81.00001037120819, 77.97617822885513, 75.29754236340523, 71.24331951141357, 66.2096232175827, 59.140197560191154, 60.7525460422039, 60.343767777085304, 63.44339445233345, 69.43076357245445, 72.115099132061, 68.1359526515007, 67.88635164499283, 67.74622276425362, 73.83718192577362, 73.86670634150505, 73.80231499671936, 67.79438138008118, 59.791372418403625, 54.918795078992844, 59.38061825931072, 56.418073028326035, 58.829074054956436, 57.84518525004387, 53.816576823592186, 54.21683594584465, 56.248799711465836, 56.65511190891266, 64.28709357976913, 65.75027346611023, 69.9346849322319, 71.15583300590515, 72.14644744992256, 70.23030906915665, 64.68968957662582, 62.925945818424225, 58.46839740872383, 56.747344359755516, 57.28258363902569, 62.169186025857925, 70.14954820275307, 71.9769461452961, 68.38417813181877, 54.889760836958885, 54.000418558716774, 55.770431980490685, 66.11453711986542, 73.75703662633896, 73.83797228336334, 72.07088470458984, 69.78494256734848, 71.14264011383057, 66.34170413017273, 59.421986639499664, 56.59646965563297, 57.84132845699787, 56.454706862568855, 64.47104930877686, 69.48842167854309, 71.08166858553886, 71.83123156428337, 65.34607395529747, 64.2987285554409, 62.8701876103878, 59.229534566402435, 58.23880232870579, 64.89751562476158, 64.15887326002121, 73.56073915958405, 75.26568487286568, 79.72339287400246, 80.01403167843819, 81.85545086860657, 84.2530158162117, 88.48557829856873, 79.15049001574516, 83.50558832287788, 73.33075270056725, 81.14333108067513, 17.405638620257378, 0.9796269773505628, 4.585808152332902, 11.948908176273108, 8.47649110481143, 5.9592406544834375, 9.748540297150612, 0.5838541081175208, 0.8485641132574528, 6.556200496852398, 63.04328732192516, 44.104506969451904, 64.20128658413887, 60.88676244020462, 60.41353963315487, 35.204928517341614, 35.9573033452034, 65.99230527877808, 69.17386695742607, 88.2370488345623, 8.961656671017408, 0.6160357093904167, 0.1943736567045562, 0.11211836463189684, 0.14670800504973158, 0.15517506399191916, 0.16769323992775753, 0.15360833087470382, 0.11522306522238068, 0.13560385792516172, 0.07980522510479204, 0.1411330362316221], [0.025435421375732403, 0.03011597607837757, 0.012809185027435888, 0.015487998607568443, 0.03350989718455821, 0.02879978830605978, 0.05472782133438159, 0.040371089562540874, 0.009695715962152462, 0.028104154735046905, 0.027787604631157592, 0.024878714139049407, 0.019167657701473217, 29.17829990386963, 72.44280874729156, 51.54838353395462, 44.402384385466576, 31.851834543049335, 64.56529185175896, 71.81498363614082, 32.832183837890625, 0.8724420913495123, 0.11082791083026677, 1.028608011547476, 4.890439230948687, 0.6373076210729778, 3.2948993844911456, 0.16072471073130146, 5.025089280679822, 83.1955173611641, 81.92164331674576, 81.55475780367851, 94.62295576930046, 98.89008119702339, 94.16220009326935, 93.83932381868362, 96.46177589893341, 92.90058419108391, 89.2158155143261, 92.79752612113953, 88.11954393982887, 88.14065560698509, 87.05245479941368, 86.34943932294846, 90.11880666017532, 85.20216688513756, 79.73926842212677, 72.90391400456429, 59.80484649538994, 60.938527062535286, 58.90161596238613, 57.95538693666458, 57.03394778072834, 58.39193411171436, 56.859069764614105, 55.99272385239601, 52.998537719249725, 52.12281011044979, 52.926926761865616, 61.36676788330078, 73.41927275061607, 76.2710653245449, 72.2076165676117, 71.22903227806091, 70.73024064302444, 70.74553862214088, 64.92234349250793, 61.41717217862606, 56.24960146844387, 55.159785747528076, 54.65462185442448, 53.057157173752785, 58.34958538413048, 70.09046897292137, 71.20640829205513, 69.82164099812508, 68.15166100859642, 70.07422104477882, 64.64674428105354, 67.7776774764061, 64.74458143115044, 62.434271201491356, 58.3953121304512, 52.1674957126379, 53.632913678884506, 56.50693506002426, 55.22165022790432, 59.15683686733246, 59.5864038169384, 62.70928144454956, 61.257668137550354, 52.656601667404175, 47.840595692396164, 51.74312688410282, 56.81610926985741, 57.09262803196907, 67.23560616374016, 68.12751710414886, 64.88939166069031, 63.45700152218342, 57.79866434633732, 53.82578752934933, 54.15325775742531, 59.12629410624504, 62.60347992181778, 64.14470762014389, 66.36983782052994, 65.86794555187225, 59.646356999874115, 48.91977198421955, 50.752026066184044, 51.26130513846874, 57.66304962337017, 60.89570336043835, 66.54689311981201, 61.38083852827549, 63.98637771606445, 63.36903244256973, 53.13355967402458, 48.746866062283516, 52.46020160615444, 51.987712159752846, 55.50391048192978, 62.545491233468056, 63.62195827066898, 65.06833165884018, 63.398610055446625, 58.567461892962456, 56.254921182990074, 57.170881032943726, 61.43273614346981, 65.9369270503521, 71.68086603283882, 71.60900428891182, 71.20163574814796, 75.43055042624474, 71.68166399002075, 75.83154290914536, 77.83068403601646, 70.94435155391693, 76.49078473448753, 75.4323211312294, 80.74805349111557, 75.2789157629013, 83.75578209757805, 15.141492113471031, 1.6920088324695826, 1.0728571121580899, 3.374977712519467, 1.3216669298708439, 4.336189096793532, 1.3616908947005868, 0.5003469984512776, 0.6376186106353998, 29.998653084039688, 48.96069198846817, 31.160066463053226, 65.60959741473198, 28.660913966596127, 29.962642416357994, 23.068147972226143, 50.11207960546017, 48.36322344839573, 70.14624238014221, 13.00184402614832, 0.3457756864372641, 0.11337396717863157, 0.003498485539239482, 0.029957304905110504, 0.02678224500414217, 0.0634742877446115, 0.03749900402908679, 0.03499297170492355, 0.11212542987777852, 0.006765809703210834, 0.03317804956168402, 0.0088746353139868, 0.04358611040515825, 0.03986557938333135, 0.013137475907569751, 0.01783677354978863, 0.01828937416576082, 0.014239896390790818, 0.0273435257258825, 0.016099257409223355, 0.03762736960197799, 0.017812056321417913, 0.04539496549114119, 0.030679370065627154, 36.335508450865746, 80.93033730983734, 58.73050354421139, 53.35713587701321, 28.675619177520275, 54.35984127223492, 83.06880936026573, 36.737401485443115, 0.9610244818031788, 0.3275504690827802, 2.2074853722006083, 6.816294165328145, 3.104593246243894, 1.807735066395253, 0.29635081824380904, 11.041612811386585, 91.37579441070557, 87.01317250728607, 89.4935730099678, 95.15474483370781, 100.65753355622292, 94.8307666182518, 96.77404314279556, 98.48822996020317, 95.64616486430168, 91.03869169950485, 96.00020706653595, 89.23346176743507, 89.54324394464493, 89.33310002088547, 89.54937681555748, 89.71374079585075, 87.54206612706184, 82.12243974208832, 75.05050241947174, 60.63039779663086, 63.793728053569794, 62.65987269580364, 60.965247228741646, 60.714764669537544, 64.04886916279793, 59.62279066443443, 59.57849644124508, 57.45639771223068, 56.63703627884388, 56.242685839533806, 64.20467600226402, 78.97425547242165, 76.93375736474991, 75.40079802274704, 75.29302820563316, 72.63237297534943, 72.93903931975365, 66.15809798240662, 63.72872494161129, 57.69107311964035, 57.60726861655712, 57.0496941357851, 56.478185802698135, 63.64920660853386, 73.30762714147568, 74.69593584537506, 75.98921164870262, 71.42953231930733, 72.71917551755905, 70.10390505194664, 72.15792283415794, 68.14688846468925, 66.97256907820702, 61.404150277376175, 53.56774337589741, 53.63501496613026, 56.35140560567379, 56.49162948131561, 61.24505281448364, 63.0516354739666, 64.16755199432373, 64.40219700336456, 54.34134766459465, 49.31327506899834, 52.937721982598305, 59.29910123348236, 61.20872676372528, 67.47125431895256, 69.72598493099213, 69.83765333890915, 67.70545095205307, 62.202156856656075, 56.51355430483818, 56.42329394817352, 63.47311645746231, 64.59192842245102, 67.11003050208092, 68.57162967324257, 67.03632965683937, 61.625055223703384, 51.527617648243904, 52.87195511162281, 52.563176080584526, 58.70705880224705, 61.92853733897209, 69.83127728104591, 65.19176423549652, 66.672932356596, 64.17509838938713, 56.40900291502476, 51.77741624414921, 54.37586881220341, 55.377559661865234, 58.60165245831013, 64.12003174424171, 67.49026089906693, 66.29578739404678, 65.80182909965515, 60.27283318340778, 60.908231288194656, 60.563232600688934, 65.55405959486961, 70.6141796708107, 75.02210274338722, 73.44756603240967, 74.2084676027298, 78.15041407942772, 74.14143159985542, 77.47165650129318, 78.7260527908802, 71.70663625001907, 77.47027337551117, 77.38522633910179, 84.3047234416008, 75.50540640950203, 92.98430129885674, 24.952295869588852, 0.5689412739593536, 0.45824193279258907, 2.422400889918208, 2.1286263037472963, 3.190316646359861, 3.167755831964314, 0.6680364534258842, 0.6369546556379646, 27.197967767715454, 62.28026166558266, 36.4267111569643, 76.09074980020523, 24.996274709701538, 26.423751711845398, 24.588039815425873, 58.61711002886295, 53.84693339467049, 79.19347330927849, 16.59540429711342, 0.5969073576852679, 0.16133539436850697, 0.0628979284374509, 0.05857789052242879, 0.0341505079268245, 0.07559333665994927, 0.05345893805497326, 0.02194884498749161, 0.08253657346358523, 0.04876040111412294, 0.045898649987066165, 0.1267653243849054, 0.14515371032757685, 0.17763150273822248, 0.11741119116777554, 0.09649804109358229, 0.11360461183357984, 0.18114677426638082, 0.08949935101554729, 0.07569603505544364, 0.15359302778961137, 0.1554412575205788, 0.09536488549201749, 0.19336049153935164, 43.39519523084164, 92.88719370961189, 67.82268986105919, 62.09034785628319, 45.88331691920757, 84.53786373138428, 87.249785810709, 51.55223652720451, 1.0863708495162427, 0.3103422315325588, 4.788006702437997, 17.96195536851883, 8.829770497977734, 10.171912629157305, 4.392361482605338, 7.933437544852495, 92.31346249580383, 93.93832370638847, 96.49095073342323, 99.7637303173542, 105.93412801623344, 98.11894297599792, 102.45793014764786, 104.44726780056953, 98.48696082830429, 94.06133070588112, 99.66688111424446, 93.27581405639648, 96.28868758678436, 93.1309126317501, 93.68660241365433, 92.45668441057205, 90.04822164773941, 86.31883576512337, 79.19224977493286, 64.78875786066055, 68.56906101107597, 66.01073428988457, 65.6348280608654, 63.10013227164745, 66.5897624194622, 62.94175677001476, 63.99673596024513, 60.39043307304382, 60.97231484949589, 59.841012954711914, 66.15750521421432, 79.69657391309738, 81.69732615351677, 78.42105075716972, 78.32480952143669, 75.49415901303291, 75.29541447758675, 70.25684684515, 66.78703263401985, 61.640406399965286, 61.377053931355476, 60.56338079273701, 58.456488847732544, 65.79240560531616, 75.6119678914547, 78.85444030165672, 76.63738086819649, 74.16179850697517, 78.3531104028225, 72.66670033335686, 74.45402562618256, 74.19547230005264, 70.40895268321037, 65.80036997795105, 55.02631410956383, 53.35536137223244, 58.11720125377178, 58.33559453487396, 62.19588339328766, 65.20629465579987, 66.82361707091331, 63.911688923835754, 53.19881357252598, 50.37545867264271, 59.15740683674812, 63.94150212407112, 64.5407983660698, 73.7695075571537, 71.4823266863823, 70.91750979423523, 71.41456872224808, 66.1908370256424, 59.08140331506729, 59.34764742851257, 66.33462131023407, 68.31638216972351, 69.66141879558563, 71.72564283013344, 71.32107853889465, 63.18744398653507, 54.86237570643425, 55.00118225812912, 57.932219579815865, 62.28927478194237, 67.14797526597977, 73.65343898534775, 70.05991101264954, 69.55320060253143, 67.8869292140007, 60.17442226409912, 53.61139543354511, 59.356189370155334, 57.39139840006828, 63.03732544183731, 67.2230364382267, 71.542789041996, 69.57086965441704, 69.29432049393654, 63.08514207601547, 63.349311500787735, 63.96481767296791, 67.46028810739517, 73.38450461626053, 78.81078824400902, 76.9894015789032, 76.84020638465881, 81.01955652236938, 76.48866444826126, 81.55911237001419, 83.02658602595329, 74.2564894258976, 81.09239101409912, 79.75265130400658, 87.97604084014893, 79.51867505908012, 93.98196816444397, 21.816582530736923, 2.573594064451754, 6.364912111312151, 12.33633728697896, 5.628974726423621, 11.937774773687124, 6.058886032551527, 0.621713554719463, 1.027652125339955, 40.34962825477123, 67.7825640141964, 48.23653444647789, 84.47428554296494, 41.2370478361845, 40.369277000427246, 33.3399011939764, 67.05128565430641, 63.3247572183609, 91.35158970952034, 19.633626267313957, 0.7362538960296661, 0.27860066446010023, 0.20516207936452702, 0.17233831254998222, 0.1294909804710187, 0.10613007892970927, 0.1915060426108539, 0.167626298207324, 0.14243602490751073, 0.1438592711929232, 0.08876723717548884], [0.1427232805872336, 0.040966911692521535, 0.03675335712614469, 0.034812878438970074, 0.13380621297983453, 0.0638187481672503, 0.039706440657028, 0.06127183463831898, 0.002965258463518694, 0.06370708462782204, 0.05103480172692798, 0.08364298206288368, 0.13888645131373778, 27.76325773447752, 77.33840525150299, 55.764112919569016, 53.85102957487106, 50.79733483493328, 78.22074070572853, 56.06748104095459, 17.411072328686714, 0.03218593541532755, 0.05149220960447565, 3.840521606616676, 2.2260613879188895, 1.6489947843365371, 0.9325286827515811, 6.264363331720233, 105.24924516677856, 75.7052680850029, 82.94577196240425, 92.79575541615486, 91.67365282773972, 90.99715232849121, 93.2727438211441, 88.69961321353912, 89.8952266573906, 86.2229973077774, 89.17266502976418, 87.04745426774025, 86.47240072488785, 84.97743174433708, 85.58417558670044, 83.81081074476242, 85.32801613211632, 84.55878540873528, 82.50635594129562, 76.5675938129425, 63.8908052444458, 60.230712443590164, 57.44475893676281, 56.871571093797684, 59.195533990859985, 61.17656908929348, 56.52021914720535, 53.064464181661606, 50.63306584954262, 52.551993280649185, 53.786786422133446, 59.49950248003006, 74.9840135872364, 72.34951615333557, 74.7139772772789, 74.23055961728096, 69.13408309221268, 66.60163298249245, 64.39224913716316, 60.061781108379364, 57.21755772829056, 56.103123128414154, 55.892568826675415, 52.45634101331234, 63.50961349904537, 69.22730728983879, 69.04351875185966, 69.92447108030319, 72.37882778048515, 69.38562959432602, 69.2772214114666, 69.15471598505974, 60.70295870304108, 57.28742457926273, 53.77848006784916, 53.43521408736706, 54.78748932480812, 57.61883519589901, 60.89052423834801, 62.16712273657322, 63.73317830264568, 62.641610875725746, 68.918946236372, 67.05801889300346, 56.57806724309921, 46.05328179895878, 54.305147007107735, 58.22068490087986, 61.17757223546505, 67.51302927732468, 69.53212693333626, 64.08545359969139, 63.85381042957306, 59.109027832746506, 61.5602421015501, 61.422184109687805, 66.57464683055878, 63.77104327082634, 62.7196054905653, 64.2729127407074, 66.03148877620697, 52.22593657672405, 47.54617989063263, 50.068043768405914, 50.113732516765594, 56.246569231152534, 59.64606821537018, 63.00805561244488, 60.190958976745605, 62.44695112109184, 56.30482770502567, 48.367498219013214, 51.13198287785053, 51.875367388129234, 54.14495900273323, 61.566241979599, 63.082117438316345, 63.64021249115467, 60.16522295773029, 58.51679541170597, 59.09349426627159, 65.25060027837753, 70.3474871814251, 72.74680003523827, 69.61458250880241, 71.8016691505909, 69.67437610030174, 73.17806169390678, 73.80726993083954, 70.07501900196075, 69.39150407910347, 75.74022620916367, 75.78095242381096, 80.69897532463074, 73.20246398448944, 76.98171079158783, 70.39531141519547, 77.23461762070656, 7.449446590617299, 1.4015566930174828, 1.3393714861012995, 3.4984378376975656, 1.6259416588582098, 2.83875476103276, 0.49031886155717075, 0.12565766897751018, 6.5107207372784615, 74.2569226026535, 33.24223883450031, 52.268627285957336, 41.539127826690674, 42.94373765587807, 25.848244093358517, 39.745798856019974, 48.61326903104782, 62.62951232492924, 17.475053295493126, 0.4067291656974703, 0.14149805414490402, 0.06023687630658969, 0.1446832629153505, 0.036238614629837684, 0.041781092222663574, 0.08610605145804584, 0.08931882359320298, 0.08647412701975554, 0.021891673641221132, 0.03419012748054229, 0.007293191438293434, 0.04225161384965759, 0.01483505429860088, 0.06259807109017856, 0.06342232998576947, 0.10565402088104747, 0.029207982515799813, 0.12692732037976384, 0.08004998540855013, 0.02172977041482227, 0.07096114772139117, 0.0515870560775511, 0.10928688570857048, 35.25775708258152, 85.51417574286461, 61.77019223570824, 69.51042249798775, 50.600493997335434, 76.12661987543106, 66.00520938634872, 19.427494928240776, 0.010556040451774606, 0.4563335148850456, 8.638502061367035, 5.6810457073152065, 1.0050530754961073, 0.6885051832068712, 11.383087188005447, 112.26217925548553, 80.2772207558155, 94.08922880887985, 96.37528494000435, 95.8655346930027, 91.12506106495857, 94.96030166745186, 91.85997202992439, 92.55876213312149, 91.12999320030212, 91.29552751779556, 91.03792414069176, 89.60845604538918, 86.15235149860382, 87.21459969878197, 87.06037357449532, 88.95020976662636, 85.82569822669029, 84.51334744691849, 81.27137660980225, 66.85862079262733, 62.922738790512085, 61.8019775301218, 60.73675408959389, 61.73859693109989, 62.652767077088356, 59.763630107045174, 55.72291933000088, 55.57743653655052, 55.928438901901245, 56.33258141577244, 60.786470621824265, 77.34705358743668, 75.59838742017746, 77.64842301607132, 75.85231259465218, 72.78065621852875, 69.85959336161613, 66.85134798288345, 62.48337596654892, 61.64937771856785, 58.85805130004883, 61.0197477042675, 54.154542088508606, 65.83104193210602, 70.84282860159874, 71.81716471910477, 73.50400820374489, 76.92143842577934, 72.29882687330246, 72.87859976291656, 72.90185451507568, 65.07686600089073, 62.36332520842552, 53.3557565510273, 55.46647109091282, 55.59556156396866, 57.23011985421181, 63.98165076971054, 65.58524072170258, 67.74109303951263, 66.72125056385994, 70.74467226862907, 67.6739202439785, 58.408144041895866, 48.5543417930603, 57.271184250712395, 61.20481677353382, 64.25294861197472, 70.09122893214226, 73.75968128442764, 66.60529598593712, 67.89230212569237, 61.42044760286808, 65.93870535492897, 66.72697305679321, 70.16027882695198, 66.72342404723167, 65.43268650770187, 66.73303753137589, 68.47787350416183, 54.983874186873436, 50.33130504190922, 52.542516589164734, 53.45803186297417, 59.28557775914669, 61.43383428454399, 65.76575383543968, 65.90411961078644, 66.31341844797134, 58.778479769825935, 51.20843097567558, 54.02988977730274, 53.770226910710335, 55.563529282808304, 62.944089844822884, 65.29431313276291, 65.95121428370476, 64.09234642982483, 60.21132968366146, 62.91127860546112, 69.70327734947205, 73.55193883180618, 75.04452913999557, 73.29131081700325, 75.30916973948479, 71.65412306785583, 75.4304364323616, 74.59784030914307, 72.19779789447784, 70.34983545541763, 76.96832790970802, 77.18410313129425, 82.71067097783089, 75.59574276208878, 82.01679021120071, 71.3446980714798, 85.7480075955391, 12.691416833549738, 0.796735844342038, 0.7812529220245779, 2.9722627345472574, 4.102090308442712, 4.655783772468567, 1.6200813045725226, 0.19680773781146854, 5.362199116498232, 79.77845191955566, 42.08267346024513, 60.62296539545059, 41.14079900085926, 34.961950555443764, 37.51501835882664, 48.7394792586565, 55.86184747517109, 71.25278100371361, 22.12766043841839, 0.2846156823216006, 0.20985246752388775, 0.05767683789599687, 0.12038004904752597, 0.053451839412446134, 0.061495814807130955, 0.10221853764960542, 0.022016146649548318, 0.05219728329393547, 0.05776934660389088, 0.05093330561066978, 0.17936933058081195, 0.19171759922755882, 0.12221371041960083, 0.10880640445975587, 0.2751354582142085, 0.1758095747209154, 0.15409805928356946, 0.19571559329051524, 0.22780119033996016, 0.195278542523738, 0.18283952405909076, 0.12672146345721558, 0.2644364791922271, 46.736249551177025, 94.6734170615673, 71.66166946291924, 67.70657569169998, 70.41554912924767, 97.99413487315178, 75.51364436745644, 30.5202054977417, 0.08008563076145947, 0.7179720676504076, 13.343584388494492, 9.151286445558071, 10.257912464439869, 6.547946389764547, 8.14666785299778, 117.00395241379738, 88.56252416968346, 97.0721523463726, 98.03894966840744, 100.41837438941002, 96.88738346099854, 100.85856556892395, 96.2888091802597, 98.60257342457771, 94.50927346944809, 96.45128846168518, 94.13278967142105, 94.37354475259781, 91.11293211579323, 93.35219755768776, 90.98967432975769, 92.67524108290672, 88.5191684961319, 91.5015372633934, 85.0223833322525, 71.30295351147652, 66.65262624621391, 65.44657856225967, 62.56209634244442, 66.09288588166237, 68.15326452255249, 61.65549539029598, 59.61969003081322, 59.55100491642952, 59.18323025107384, 60.78511789441109, 64.48578491806984, 82.14730560779572, 79.46654945611954, 80.87922245264053, 80.30232220888138, 75.15625834465027, 70.63378661870956, 72.6065343618393, 66.1577408015728, 63.78046676516533, 60.682401806116104, 64.13355141878128, 58.12790147960186, 71.27629414200783, 75.23814395070076, 74.28179606795311, 76.28561094403267, 79.0116074681282, 74.6528385579586, 76.39116927981377, 76.39013573527336, 68.53188380599022, 65.2469676733017, 57.587977051734924, 56.24013237655163, 55.606482177972794, 58.92932027578354, 63.76882418990135, 67.47691601514816, 70.11820748448372, 70.29799863696098, 74.09254342317581, 70.22096157073975, 58.592757135629654, 51.8046797811985, 62.800997123122215, 64.85959365963936, 70.25738641619682, 73.9795982837677, 78.445985019207, 69.34860438108444, 72.7069553732872, 65.2992756664753, 69.3873243033886, 69.63402226567268, 73.46848011016846, 67.99695611000061, 69.34089079499245, 69.98820886015892, 74.12627801299095, 57.271245047450066, 52.372547909617424, 54.544138982892036, 55.99748119711876, 62.65799939632416, 65.12654453516006, 69.21712383627892, 67.69452273845673, 67.89380684494972, 61.647633612155914, 53.951917961239815, 56.77922084927559, 56.21835954487324, 62.24301986396313, 66.68370857834816, 69.4642473757267, 70.59315919876099, 65.17572909593582, 63.47360663115978, 65.96252247691154, 71.70268446207047, 75.98682537674904, 79.27556410431862, 75.82056149840355, 77.14011669158936, 74.79271665215492, 80.01352250576019, 79.32817608118057, 75.17097875475883, 72.41324633359909, 79.64792892336845, 80.30814349651337, 88.59030067920685, 79.17366117238998, 86.94998189806938, 77.86343827843666, 89.33360919356346, 12.241089697927237, 3.474110593087971, 7.604057919234037, 8.028976768255234, 5.8390906266868114, 11.182987075299025, 0.9829437243752182, 0.25572948390617967, 9.986779913306236, 90.2497324347496, 49.233498349785805, 71.68176278471947, 58.832957446575165, 57.34702818095684, 39.93667781352997, 54.87937979400158, 64.41871851682663, 83.76127660274506, 26.88346054404974, 0.6845703162252903, 0.3210070123896003, 0.20958701614290476, 0.3544660873012617, 0.17368275759508833, 0.21162759570870548, 0.2650288020959124, 0.2078856574371457, 0.22792716248659417, 0.13755609223153442, 0.16212123970035464], [0.08063945846515708, 0.024729494216444436, 0.03428040232392959, 0.0069578742750309175, 0.0390662084100768, 0.05280323573970236, 0.03738532184797805, 0.19138320232741535, 0.051587067209766246, 0.07096778994309716, 0.03515325333864894, 0.2897098136600107, 0.054974752420093864, 30.008523054420948, 63.42648535966873, 53.7403567135334, 30.135954916477203, 50.78554406762123, 67.9970321059227, 44.162020683288574, 7.192676793783903, 0.29954330006148666, 0.18216903816210106, 1.218598410487175, 1.9497134978882968, 2.047932408750057, 2.857603649608791, 90.21986603736877, 76.46510571241379, 83.00082340836525, 99.88888800144196, 91.02742910385132, 97.64948576688766, 89.66318070888519, 87.96078845858574, 85.78435644507408, 88.57457712292671, 86.83199062943459, 86.42342135310173, 86.77056312561035, 86.40738621354103, 76.50745823979378, 79.3258886039257, 79.06240314245224, 83.47278848290443, 85.59090882539749, 83.22505697607994, 76.41139939427376, 62.84444019198418, 56.39622040092945, 58.01030918955803, 57.1237787604332, 57.41569809615612, 57.51169994473457, 55.03532722592354, 52.18923434615135, 52.99464292824268, 53.931570053100586, 55.51193565130234, 59.7537886351347, 73.51680591702461, 71.69762313365936, 71.41067013144493, 71.4610706269741, 68.58958750963211, 67.4798646569252, 69.22378867864609, 63.29020947217941, 64.31912586092949, 58.19051451981068, 55.72084844112396, 50.96015229821205, 57.654564678668976, 63.30222062766552, 66.65172949433327, 66.76748648285866, 68.51210966706276, 69.75661888718605, 66.75676345825195, 59.1975174844265, 55.14306664466858, 53.34274984896183, 49.819586500525475, 56.24704800546169, 57.51747943460941, 63.52694436907768, 65.88613897562027, 66.42333135008812, 65.28484404087067, 64.5824745297432, 67.46349513530731, 66.19156658649445, 62.749072909355164, 48.37475962936878, 49.81416419148445, 58.22359934449196, 60.518178418278694, 62.48999901115894, 67.29449540376663, 67.72308200597763, 65.97478061914444, 64.48925033211708, 67.32143595814705, 64.26677227020264, 68.86066496372223, 62.733235359191895, 63.6385253816843, 63.30360755324364, 64.07939672470093, 59.331289306283, 50.94214886426926, 49.8461888730526, 50.33862344920635, 52.728110030293465, 57.652497589588165, 61.94116786122322, 61.77355505526066, 61.050244867801666, 58.197836726903915, 50.16271948814392, 50.25159291923046, 50.18505848944187, 50.25020219385624, 56.76523000001907, 62.10518606007099, 62.763857915997505, 61.00511848926544, 59.86797630786896, 63.44782501459122, 69.94768023490906, 69.06390845775604, 72.09323510527611, 70.33503904938698, 73.03661808371544, 72.08097696304321, 70.64409166574478, 72.2343747317791, 73.36023151874542, 75.36179691553116, 75.91586038470268, 74.19088214635849, 75.17002880573273, 70.66610768437386, 74.60012018680573, 74.96270433068275, 67.30678394436836, 50.5163399130106, 0.4184060578700155, 1.1881786677986383, 2.0284855272620916, 1.7673224536702037, 1.229198060464114, 1.2654330348595977, 0.07108729056199081, 0.6722378998529166, 54.565448239445686, 57.080643475055695, 41.44347935914993, 49.82013367116451, 36.86045788228512, 20.66734179854393, 31.328534223139286, 53.05798552930355, 63.96313056349754, 16.760267950594425, 0.2977983030723408, 0.10980598832247779, 0.06801718147471547, 0.01180008404844557, 0.03012500616023317, 0.06691733346087858, 0.09275387637899257, 0.027734600444091484, 0.02642702529556118, 0.0713826876017265, 0.11099987386842258, 0.02337612855626503, 0.010725495958467945, 0.09212547025526874, 0.04737678180390503, 0.006294934628385818, 0.04227585610351525, 0.02213223895523697, 0.07425824267556891, 0.031022221883176826, 0.019542099034879357, 0.06441645906306803, 0.21299405285390094, 0.03227818808227312, 39.45495866239071, 72.15680569410324, 59.90011118352413, 36.83020010590553, 36.60869479179382, 72.20554947853088, 52.35113985836506, 7.887531258165836, 0.4819393315119669, 3.14539379440248, 3.657746664248407, 0.7719127263408154, 0.8119920850731432, 6.108417799696326, 99.94807362556458, 80.01123502850533, 93.67218598723412, 96.08792155981064, 94.96834963560104, 96.75361543893814, 94.13378521800041, 88.33955213427544, 87.10005104541779, 90.34129232168198, 89.89378273487091, 90.01662254333496, 90.67619115114212, 90.24532467126846, 79.37735304236412, 79.9503318965435, 83.88569712638855, 86.23131886124611, 88.77057060599327, 84.17400285601616, 81.53522685170174, 64.23790901899338, 61.26416578888893, 61.24113142490387, 59.40695084631443, 59.77986663579941, 60.96035689115524, 57.43979640305042, 57.388749942183495, 57.12248682975769, 57.90991857647896, 59.569376930594444, 62.20613144338131, 76.30590185523033, 75.44307455420494, 74.6258296072483, 73.70129361748695, 73.07398527860641, 70.21653860807419, 71.20782181620598, 67.83332169055939, 66.86503484845161, 61.77583493292332, 57.88672462105751, 55.499088540673256, 60.71822628378868, 65.43270170688629, 67.64292150735855, 69.57190319895744, 69.98014569282532, 70.89526578783989, 70.75924828648567, 59.435441717505455, 59.25300590693951, 54.62286315858364, 52.785958126187325, 57.31772035360336, 58.67397777736187, 65.54845109581947, 66.614278703928, 69.45941403508186, 68.11486378312111, 67.54625469446182, 69.37362983822823, 67.9228600859642, 64.44391116499901, 49.703890308737755, 51.78269036114216, 60.452571138739586, 64.15422230958939, 65.79735293984413, 68.12962219119072, 70.21805092692375, 69.83842089772224, 67.40109488368034, 68.96154195070267, 67.56472930312157, 68.38882148265839, 65.36919951438904, 67.29139477014542, 66.51782467961311, 66.87682181596756, 62.5984375923872, 55.2922922372818, 50.744764655828476, 51.67966648936272, 53.395491018891335, 59.84703183174133, 64.25300940871239, 63.786310851573944, 64.6281024813652, 58.90420362353325, 52.270299196243286, 52.82271735370159, 54.01971772313118, 52.18621350824833, 60.67479461431503, 65.4284231364727, 64.85756456851959, 62.62912094593048, 63.34565989673138, 66.21114313602448, 73.72732982039452, 71.74784883856773, 74.98337522149086, 72.51737594604492, 75.67659482359886, 73.36632639169693, 73.04374650120735, 74.38838794827461, 79.08710941672325, 79.07346054911613, 78.71350586414337, 76.6820740699768, 75.99143832921982, 73.49908366799355, 75.0460110604763, 79.56209152936935, 71.88540905714035, 60.86129620671272, 1.7921822634525597, 1.1186822969466448, 0.8897724270354956, 3.5675259679555893, 2.1590268099680543, 2.8948423638939857, 0.16234912356594577, 0.33489787951111794, 55.431668758392334, 68.66196602582932, 49.548140466213226, 54.33302231132984, 29.40488174557686, 26.60085830837488, 39.06505398452282, 58.40389966964722, 73.62364858388901, 22.304839231073856, 0.4502352577401325, 0.11199995497008786, 0.08052233271882869, 0.012832625761802774, 0.024701433612790424, 0.034884510532720014, 0.055093425544328056, 0.037971202909830026, 0.04027220951684285, 0.02122316185705131, 0.06345632777083665, 0.14101850800216198, 0.1829704685951583, 0.21735181042458862, 0.07337274917517789, 0.18514846422476694, 0.14645821298472583, 0.14799285563640296, 0.4410917905624956, 0.10844030301086605, 0.1606041711056605, 0.12256562942638993, 0.45016739575657994, 0.1967153701116331, 48.70661862194538, 81.90671011805534, 72.43002623319626, 39.11954306066036, 69.6870294213295, 85.70484951138496, 65.77572450041771, 11.873969547450542, 0.6689657410606742, 2.868701429106295, 6.0628914926201105, 5.681414287537336, 6.785876797512174, 5.085079511627555, 101.02200999855995, 90.34171789884567, 95.64390778541565, 103.38793024420738, 98.37416768074036, 103.88112097978592, 96.89945161342621, 93.09456378221512, 93.85916635394096, 94.45613712072372, 93.60948175191879, 93.70574578642845, 94.54179972410202, 96.00696310400963, 82.49603569507599, 86.41581416130066, 87.36909940838814, 90.25510534644127, 93.31743702292442, 88.53618398308754, 84.25844192504883, 68.80245968699455, 63.95680770277977, 63.61908942461014, 62.085989490151405, 62.3802836984396, 62.766103595495224, 61.05167739093304, 59.77880269289017, 60.7420814037323, 59.47436302900314, 61.70251406729221, 67.49842286109924, 80.6676422059536, 78.26835215091705, 79.39384415745735, 78.29667583107948, 75.30586391687393, 71.85412153601646, 76.11990943551064, 70.22217750549316, 69.2399226129055, 65.38797050714493, 62.272422686219215, 58.85317616164684, 64.6321302652359, 69.36984524130821, 73.60619232058525, 72.57552802562714, 74.53281059861183, 74.25414115190506, 72.06121802330017, 62.21386782824993, 62.641876861453056, 58.264944925904274, 53.8713812828064, 56.91777661442757, 58.66972580552101, 66.8610754609108, 70.92050403356552, 72.78196334838867, 71.27181798219681, 70.12255445122719, 71.80778682231903, 71.23135015368462, 65.60725674033165, 50.14912761747837, 54.39440421760082, 64.71061885356903, 69.16792407631874, 69.19213637709618, 71.84076145291328, 72.85757929086685, 72.95151025056839, 71.32671743631363, 73.62602725625038, 69.62190091609955, 73.488330245018, 69.91478160023689, 70.15398636460304, 70.13102039694786, 70.71094527840614, 64.10929352045059, 57.70540975034237, 55.382336005568504, 54.69527967274189, 58.71180094778538, 64.63094472885132, 69.89401191473007, 69.50229853391647, 67.46130645275116, 63.78145471215248, 54.43921521306038, 55.91289013624191, 56.56412199139595, 56.95592276751995, 63.76129299402237, 68.60660299658775, 68.09918582439423, 67.01760426163673, 64.84294295310974, 68.8790711760521, 76.03441402316093, 75.14353662729263, 77.21366554498672, 75.39490073919296, 79.6682046353817, 76.6818080842495, 74.56937983632088, 75.884580463171, 80.94088554382324, 82.70480409264565, 81.41663521528244, 82.28665933012962, 80.67113041877747, 77.04743206501007, 80.10390445590019, 83.4443736076355, 75.3921040892601, 64.03582826256752, 1.4634879073128104, 3.837392474524677, 7.355445809662342, 6.4610061049461365, 4.893915094435215, 5.290168756619096, 0.18120218301191926, 1.0196000011637807, 66.52569025754929, 72.89344176650047, 58.49234752357006, 65.00492826104164, 49.58530627191067, 28.92214994877577, 45.66695652902126, 68.29252704977989, 85.27374744415283, 28.78685250878334, 0.5688386200927198, 0.2420922086457722, 0.1906136397155933, 0.11626585692283697, 0.19669467903440818, 0.24946296704001725, 0.1405428210273385, 0.1878369238693267, 0.20664871990447864, 0.11962292483076453, 0.12065659553627484], [0.06363738953950815, 0.05403466653660871, 0.08690626476891339, 0.00989800222669146, 0.025256150038330816, 0.037709933531004936, 0.028822848689742386, 0.03786446352023631, 0.022892995984875597, 0.04979336306860205, 0.02666273696377175, 0.049082493205787614, 0.03700722358189523, 45.49852676689625, 65.22517204284668, 45.06634935736656, 46.64073407649994, 72.19289615750313, 67.45411723852158, 29.007082991302013, 1.2284232582896948, 0.16262520250165835, 1.2653337651863694, 5.406759800389409, 0.979310703696683, 0.26867648761253804, 65.08340924978256, 82.45375916361809, 89.90784958004951, 98.13571527600288, 88.60514268279076, 96.5371410548687, 93.41274350881577, 92.87659227848053, 82.85152181982994, 82.08397060632706, 79.33768317103386, 84.42875638604164, 82.54730254411697, 83.3652238547802, 83.06934133172035, 76.44020944833755, 74.17387425899506, 79.52752098441124, 81.4518441259861, 81.061931848526, 79.87886533141136, 76.88287809491158, 60.1462771743536, 60.04525579512119, 56.471608355641365, 58.39885734021664, 57.01074242591858, 55.86459472775459, 54.29547652602196, 50.65953142940998, 52.486374601721764, 53.694937750697136, 55.04633143544197, 60.59808813035488, 69.74014297127724, 70.00802859663963, 71.19692400097847, 69.22743648290634, 70.44345483183861, 65.86263343691826, 68.9505909383297, 64.69933345913887, 64.13289025425911, 56.87222085893154, 52.99826793372631, 50.57846657931805, 53.56770917773247, 55.4962994903326, 63.22432480752468, 63.293967470526695, 67.1811094880104, 67.78476789593697, 66.77567884325981, 52.32217401266098, 51.957199797034264, 51.753865107893944, 62.175600081682205, 60.81146568059921, 62.31645092368126, 64.33446183800697, 64.59833487868309, 65.1817935705185, 66.57341569662094, 64.9926321208477, 65.18604934215546, 67.83595114946365, 65.4795303940773, 59.35781188309193, 49.89984579384327, 52.32158504426479, 59.34491537511349, 59.094079434871674, 63.18436615169048, 64.80521857738495, 67.53675520420074, 66.10541760921478, 62.66007788479328, 65.29014855623245, 65.23056775331497, 61.306822299957275, 69.58703398704529, 66.33118629455566, 63.90275940299034, 60.961086452007294, 55.17274685204029, 49.960828721523285, 50.1499255746603, 50.54219372570515, 57.131081968545914, 58.837167620658875, 62.169315218925476, 57.14016728103161, 56.45819507539272, 49.09145437180996, 49.32855024933815, 49.61447350680828, 51.345516219735146, 57.803505286574364, 60.892880111932755, 60.30977860093117, 63.22357624769211, 64.3867090344429, 67.23423063755035, 67.05280557274818, 70.8434745669365, 71.13119512796402, 69.25015166401863, 70.74661776423454, 72.36169829964638, 72.53910318017006, 73.8441127538681, 69.49114233255386, 71.62777528166771, 70.7373158633709, 70.55931061506271, 64.14940416812897, 67.15318098664284, 68.05285111069679, 79.14982125163078, 74.58471581339836, 76.38672351837158, 28.323066495358944, 0.14626353280618787, 1.1226847884245217, 2.781474022194743, 2.6223993580788374, 2.0357975224033, 0.03199500308255665, 0.2728666830807924, 22.263786233961582, 74.20876398682594, 40.74529342353344, 54.112368151545525, 41.64904072880745, 30.71385070681572, 38.84395904839039, 45.249586924910545, 61.167259588837624, 11.292847730219364, 0.3709499887190759, 0.1446509052766487, 0.028048232052242383, 0.0692963546316605, 0.02698209795198636, 0.19672155962325633, 0.08187005063518882, 0.027994906886306126, 0.05671031671226956, 0.024542905302951112, 0.044594236387638375, 0.04365186840004753, 0.07353140550549142, 0.04441437318746466, 0.07113771207514219, 0.03423017747991253, 0.027558607544051483, 0.025569390163582284, 0.009054249894688837, 0.012685563633567654, 0.011047623302147258, 0.058922113457811065, 0.043846797198057175, 0.05743114619690459, 57.08730071783066, 70.79944252967834, 58.01824316382408, 41.46949276328087, 61.41481630504131, 76.63141518831253, 35.33393159508705, 0.7843590772245079, 0.33168440975714475, 5.300704641267657, 6.524473624303937, 0.8224067918490618, 0.7730285602156073, 76.19745567440987, 84.57440257072449, 97.72004798054695, 99.24487575888634, 94.86281409859657, 99.22192499041557, 96.59183531999588, 94.43751811981201, 87.1960186958313, 83.59094694256783, 81.29684284329414, 86.791180819273, 84.6985875070095, 85.16144067049026, 87.19356402754784, 79.27937150001526, 74.30996775627136, 81.54475674033165, 85.05994811654091, 85.06579220294952, 82.76141345500946, 79.9635323882103, 61.922932639718056, 62.204531729221344, 58.934431001544, 59.84346762299538, 60.573575645685196, 57.57799878716469, 57.293093875050545, 54.051886796951294, 55.83521090447903, 57.347632348537445, 57.28408455848694, 64.54044878482819, 73.40723499655724, 71.13411337137222, 73.64716932177544, 69.88276451826096, 72.59625971317291, 70.13640090823174, 71.41023695468903, 69.06803503632545, 66.19077622890472, 61.12972520291805, 57.05358512699604, 53.644035682082176, 57.678359001874924, 61.175398752093315, 65.95208823680878, 67.30761229991913, 69.77101251482964, 72.3681503534317, 69.87926110625267, 54.85420234501362, 55.97831882536411, 53.4050627052784, 64.85641703009605, 63.12234587967396, 63.38927395641804, 66.93064972758293, 66.93479910492897, 67.15985342860222, 69.06761705875397, 68.14695686101913, 68.3117388188839, 69.74429994821548, 66.71781554818153, 61.83047980070114, 52.4187458306551, 53.55523444712162, 61.263869404792786, 63.51647213101387, 64.92605209350586, 66.95373728871346, 67.89393603801727, 68.5627381503582, 65.50713211297989, 68.89083534479141, 67.6030008494854, 62.873071655631065, 70.47570750117302, 68.98704618215561, 66.75967410206795, 61.95884071290493, 58.66129405796528, 54.36241753399372, 53.55819068849087, 55.89472331106663, 58.96116256713867, 61.18443466722965, 65.10139748454094, 62.057160437107086, 59.27821755409241, 52.889658361673355, 50.47378979623318, 53.08473989367485, 53.571258187294006, 59.0764369815588, 61.46398566663265, 63.615107238292694, 66.3045497238636, 68.12139183282852, 69.9536383152008, 70.90972781181335, 73.64776208996773, 73.13010826706886, 76.36783093214035, 72.15201795101166, 74.6821653842926, 75.80073416233063, 77.29868218302727, 73.12946230173111, 73.70302632451057, 73.40088933706284, 73.0749124288559, 66.28127217292786, 66.50830239057541, 72.27763921022415, 81.66911646723747, 78.71070921421051, 80.77066227793694, 39.1981266438961, 0.09207568698911928, 0.2596925524994731, 0.5621423700358719, 3.7882473366335034, 4.052060768008232, 0.48335540865082294, 0.3538939805002883, 22.16168951243162, 82.07513228058815, 51.01179912686348, 57.129641845822334, 34.56618279218674, 29.66752365231514, 45.16487807035446, 50.629752427339554, 69.66835722327232, 16.424987241625786, 0.29841612617019564, 0.16804014943772927, 0.1066409437044058, 0.025623904621170368, 0.040342182910535485, 0.07111337705282494, 0.025400709273526445, 0.023938431586429942, 0.03322685690363869, 0.04097720899153501, 0.04722098274214659, 0.09729677010909654, 0.2337644062936306, 0.1696049381280318, 0.18716326158028096, 0.08156830081134103, 0.15408674895297736, 0.11852088005980477, 0.12386698537738994, 0.08746594059630297, 0.13763383962213993, 0.15911027236143127, 0.13787993579171598, 0.1719141157809645, 64.11901339888573, 81.65934339165688, 59.22040745615959, 60.547463446855545, 97.09517151117325, 86.76633775234222, 49.585184678435326, 1.7732447921298444, 0.22661366499960423, 6.343505959957838, 12.585398722440004, 9.861692525446415, 0.7588957529515028, 75.64205467700958, 89.88808304071426, 101.0813856124878, 104.3833476305008, 96.63934037089348, 102.93022960424423, 100.09527772665024, 98.79548907279968, 91.38293042778969, 87.98751622438431, 85.56213676929474, 90.06512314081192, 90.75622245669365, 90.28871074318886, 91.30462422966957, 85.16294538974762, 82.00446367263794, 86.17720976471901, 89.71122533082962, 87.6594190299511, 85.7153445482254, 85.86851432919502, 66.36692717671394, 66.66750624775887, 62.73591801524162, 64.18462067842484, 62.79389150440693, 60.779285207390785, 60.71490906178951, 56.93777494132519, 59.44224335253239, 61.202616691589355, 60.593725964426994, 68.26193109154701, 78.14308807253838, 76.58034592866898, 75.5308498442173, 72.85238116979599, 75.13492628931999, 72.01916947960854, 72.3922410607338, 73.20105046033859, 72.35798209905624, 63.66268068552017, 60.703901052474976, 56.065676137804985, 60.41170813143253, 62.871346548199654, 69.97621670365334, 68.7500149011612, 73.5524708032608, 77.24527224898338, 72.99949407577515, 57.210987880825996, 57.67893277108669, 54.533590748906136, 66.20520785450935, 63.393275141716, 64.91727456450462, 66.87827333807945, 69.07538384199142, 69.84851315617561, 73.1911937892437, 70.39373829960823, 72.54557803273201, 73.31748381257057, 68.80801498889923, 62.444500252604485, 53.52210782468319, 60.07967434823513, 66.3679987192154, 66.18353381752968, 69.57530781626701, 68.10603305697441, 73.12515333294868, 71.01011842489243, 67.90983438491821, 71.67806938290596, 72.72134900093079, 66.37738421559334, 74.85539808869362, 73.77699315547943, 71.67920932173729, 67.1863304078579, 60.31129091978073, 57.915268689394, 55.74965849518776, 57.70375683903694, 63.20390470325947, 64.80902597308159, 68.86358320713043, 65.16869187355042, 62.96705961227417, 56.02882191538811, 55.740941762924194, 57.06034496426582, 58.61513413488865, 63.81471052765846, 65.87011903524399, 66.76959156990051, 68.94578039646149, 71.10539451241493, 72.9797275364399, 73.22873577475548, 74.7576293349266, 76.80115208029747, 77.6062148809433, 75.4324047267437, 77.51547574996948, 79.64184165000916, 82.75691449642181, 75.68769782781601, 76.79762586951256, 78.19563165307045, 78.0925203859806, 70.53078934550285, 72.88976356387138, 75.55044919252396, 85.48408895730972, 83.87448012828827, 83.30407753586769, 39.90690641105175, 0.373884440632537, 4.038777630776167, 5.84400518797338, 8.435267116874456, 7.369692195206881, 0.47653023269958794, 0.3603913349797949, 29.903449192643166, 91.06104210019112, 57.045863941311836, 71.14917576313019, 59.320250898599625, 41.31095767021179, 52.21855357289314, 59.610410928726196, 80.3924685716629, 23.686663582921028, 0.5462570255622268, 0.33343685790896416, 0.14769452711334452, 0.15862885600654408, 0.1254165155114606, 0.25695907417684793, 0.10450791480252519, 0.09742703929077834, 0.14932278427295387, 0.1593224672251381, 0.2063560762326233], [0.019693897920660675, 0.03304888618004043, 0.03377892200660426, 0.026150341509492137, 0.03152491932269186, 0.040526862649130635, 0.034245770002598874, 0.06654330587480217, 0.04081165068782866, 0.005479969277075725, 0.02940146041510161, 0.0865180473192595, 1.0052194353193045, 54.95249547064304, 59.66672010719776, 41.11014984548092, 26.18732649832964, 53.661647737026215, 50.97083732485771, 15.278784446418285, 0.1997333878534846, 0.6637718947604299, 2.337730983272195, 2.0204651076346636, 1.9095114176161587, 26.534251682460308, 92.08657667040825, 84.22089233994484, 97.64019146561623, 89.27983447909355, 99.51001033186913, 91.58185735344887, 96.8081197142601, 91.01555094122887, 87.31619864702225, 81.5134996175766, 73.38613092899323, 75.92510908842087, 80.1924017071724, 78.86610567569733, 78.11574473977089, 72.434783577919, 72.17750698328018, 76.27199247479439, 78.51552128791809, 79.89341095089912, 79.60340291261673, 72.47071444988251, 57.81045511364937, 58.48041236400604, 58.349737375974655, 56.05266943573952, 57.903424724936485, 54.47565905749798, 51.81562319397926, 52.46512994170189, 51.454729959368706, 52.43553712964058, 56.39503486454487, 65.69386169314384, 69.83655899763107, 68.2451131939888, 70.48016846179962, 70.40788874030113, 70.08072629570961, 68.51150169968605, 68.60062971711159, 63.15139912068844, 60.010134279727936, 54.48925472795963, 52.58025236427784, 51.154572665691376, 58.732129856944084, 64.13384780287743, 64.43097665905952, 62.75375425815582, 60.90685576200485, 63.60032983124256, 66.91783681511879, 59.51982758939266, 51.71190395951271, 57.80835002660751, 63.23057547211647, 62.60206259787083, 67.63663664460182, 63.31613548099995, 63.58388431370258, 63.699994683265686, 64.74450543522835, 65.20474433898926, 62.308471351861954, 59.46501173079014, 66.26051768660545, 62.98667795956135, 58.27667869627476, 53.68700757622719, 54.39874738454819, 62.50827223062515, 57.7790953963995, 61.7701618373394, 62.798063680529594, 63.9383938908577, 63.076113760471344, 64.04381543397903, 61.23326204717159, 57.51362644135952, 60.97595125436783, 68.27780663967133, 63.667073249816895, 61.935665756464005, 57.91781075298786, 55.02437621355057, 50.91525390744209, 50.798615366220474, 54.651988595724106, 56.99545964598656, 56.982004567980766, 57.67400063574314, 51.74028843641281, 49.682752043008804, 49.42340075969696, 52.06014007329941, 50.08546203374863, 52.91057623922825, 59.0861264616251, 62.82749690115452, 62.679092064499855, 68.48698541522026, 69.3146114051342, 72.55171850323677, 68.89484032988548, 70.10150358080864, 69.59489196538925, 73.27882468700409, 67.5784769654274, 70.4996994137764, 65.35593062639236, 65.08677586913109, 60.43430931866169, 60.31016618013382, 59.60966236889362, 62.98227399587631, 61.41520008444786, 72.26171046495438, 71.18068367242813, 75.68748503923416, 71.27142280340195, 68.57393234968185, 6.045352108776569, 0.47496094659436494, 2.237450801767409, 2.4353199591860175, 1.993376361206174, 0.4173807956976816, 0.08763799269217998, 3.5289107775315642, 72.34123259782791, 51.54852792620659, 51.06454409658909, 62.58934088051319, 29.652290269732475, 31.670836955308914, 44.21239458024502, 60.995584800839424, 15.385584365576506, 0.16311919083818793, 0.03591087479435373, 0.023487239195674192, 0.01596733880433021, 0.043443113390821964, 0.059312839366612025, 0.09078984934603795, 0.033584490447537974, 0.038730449668946676, 0.06142652790003922, 0.05492016003699973, 0.028087985192541964, 0.043708023004001006, 0.036326956178527325, 0.06224513163033407, 0.005470905798574677, 0.04565741488477215, 0.04267242271453142, 0.038535290805157274, 0.044105977431172505, 0.07943580625578761, 0.040367523542954586, 0.016603468829998747, 1.7904494376853108, 68.79856869578362, 65.84548115730286, 61.582429111003876, 33.16772483289242, 52.51866526901722, 62.30344042181969, 17.11636584252119, 0.3448140114778653, 2.1257356088608503, 3.286672825925052, 0.8568150736391544, 0.7602502615191042, 31.60604663193226, 98.40154901146889, 93.00954714417458, 101.49784326553345, 91.67007341980934, 101.21111825108528, 92.01992064714432, 97.47495353221893, 92.22445607185364, 91.33358627557755, 84.83966633677483, 78.04059997200966, 77.67334207892418, 84.13114875555038, 81.95223927497864, 81.58703327178955, 76.27214446663857, 74.72141727805138, 79.33940827846527, 83.0629500746727, 84.50222164392471, 83.517344892025, 75.0106729567051, 60.78284181654453, 63.07107903063297, 59.288891181349754, 59.22868341207504, 60.300267711281776, 57.61830322444439, 54.062366634607315, 56.01390391588211, 54.253370985388756, 55.26401795446873, 58.033757731318474, 70.58420687913895, 73.75471875071526, 71.22343897819519, 74.81165483593941, 72.5941926240921, 73.49272280931473, 70.21599903702736, 71.26107215881348, 67.23216354846954, 61.86610288918018, 57.48842619359493, 54.078504368662834, 54.16571348905563, 60.88612787425518, 69.722451120615, 67.47031956911087, 66.73762768507004, 63.98740366101265, 68.2761499285698, 71.28473728895187, 61.56528823077679, 53.729014322161674, 59.78544093668461, 64.789137840271, 62.5821478664875, 68.65322649478912, 66.5071776509285, 65.95101669430733, 67.15223103761673, 67.78305798768997, 66.64238959550858, 65.1868624985218, 63.92311871051788, 67.56507888436317, 64.26251649856567, 59.67883385717869, 58.13418634235859, 58.533427119255066, 63.52322816848755, 61.157699301838875, 66.80214062333107, 64.49478283524513, 66.43862172961235, 64.61354166269302, 66.79631933569908, 63.20741951465607, 59.56664867699146, 65.56991994380951, 69.70389291644096, 66.1228434741497, 65.09307593107224, 61.33139178156853, 56.88655748963356, 52.887462079524994, 51.63251481950283, 57.08970598876476, 60.949622467160225, 60.19988849759102, 59.53806281089783, 53.42781588435173, 51.51753678917885, 51.87341809272766, 53.89971636235714, 52.4784292280674, 54.68243256211281, 61.74511358141899, 64.23327326774597, 66.0526992380619, 71.573316603899, 71.85027614235878, 74.25327479839325, 70.20763948559761, 74.11949157714844, 72.20798134803772, 74.15313497185707, 70.84515407681465, 72.08769500255585, 67.89059221744537, 67.37475469708443, 63.30344416201115, 62.85335071384907, 61.5759314596653, 66.87228485941887, 65.21345347166061, 75.00482127070427, 77.62762293219566, 81.15309655666351, 72.3680591583252, 73.9432342350483, 12.25669451057911, 0.8510544046293944, 0.08182698380551301, 3.1768297450616956, 4.914245428517461, 0.7381310546770692, 0.10403341526398435, 3.7291317712515593, 75.96023440361023, 61.5743013471365, 57.541653737425804, 51.420368403196335, 22.789621017873287, 40.984357595443726, 52.29173004627228, 69.13424268364906, 20.905873998999596, 0.21187202946748585, 0.05623035867756698, 0.09776058272109367, 0.10656284750439227, 0.02766542114841286, 0.0023074285036273068, 0.08069480783888139, 0.046493095433106646, 0.051312669238541275, 0.03008290041179862, 0.00825940787763102, 0.10616590981953777, 0.15601452207192779, 0.11714389926055446, 0.16110748081700876, 0.08706066117156297, 0.15114043751964346, 0.13891438575228676, 0.1831465505529195, 0.24656180787133053, 0.21731353044742718, 0.21616571000777185, 0.1168449102260638, 2.208104976452887, 78.15797567367554, 77.94074133038521, 56.54312811791897, 38.79794731736183, 71.27621814608574, 72.9642091691494, 25.423884764313698, 0.4284264170564711, 2.158458740450442, 8.411695081740618, 11.145640779286623, 3.2025904627516866, 33.71954262256622, 101.58846080303192, 98.35586026310921, 105.72016149759293, 95.51222965121269, 104.4457782804966, 96.49741798639297, 101.54245287179947, 95.76604083180428, 92.56844401359558, 89.91533517837524, 79.44125801324844, 84.00072455406189, 87.84016773104668, 86.03655651211739, 85.77757760882378, 79.78684946894646, 78.35110411047935, 84.14979815483093, 86.00413665175438, 88.33506837487221, 87.08564981818199, 78.58354523777962, 62.4774406850338, 66.22624352574348, 64.15549904108047, 60.819863229990005, 63.27977903187275, 60.80041967332363, 57.963073924183846, 60.31371898949146, 56.72221250832081, 59.35571439564228, 61.761760488152504, 74.64607492089272, 76.33286520838737, 75.52907913923264, 78.58494356274605, 74.27605077624321, 77.05462127923965, 74.51223850250244, 75.35339936614037, 69.70618039369583, 67.99963876605034, 61.599235609173775, 57.952647283673286, 58.71253050863743, 65.33161953091621, 72.76228800415993, 69.2562161386013, 70.82300886511803, 67.09649562835693, 70.99563360214233, 76.36150807142258, 64.96640592813492, 56.979739889502525, 63.80769610404968, 66.37805297970772, 65.30505895614624, 70.59969484806061, 68.78856763243675, 69.32210460305214, 70.88208809494972, 70.34786716103554, 71.05894580483437, 67.4466772377491, 66.24490812420845, 71.6150763630867, 65.84708467125893, 62.13592641055584, 59.98280234634876, 62.50643692910671, 68.81964236497879, 63.46035674214363, 67.40046411752701, 67.21802070736885, 70.0706796348095, 67.70119518041611, 70.0537097454071, 66.64519384503365, 62.959175035357475, 67.91769996285439, 73.13418164849281, 68.36213171482086, 67.82230988144875, 63.21709759533405, 60.0589844584465, 55.56126460433006, 55.104320123791695, 61.758177280426025, 65.62566295266151, 63.61342012882233, 65.50321072340012, 56.819768473505974, 57.2618405520916, 54.90374408662319, 57.901889607310295, 54.66671660542488, 59.56644348800182, 66.31042420864105, 69.18421000242233, 68.57302039861679, 74.52736169099808, 74.08917680382729, 78.83956030011177, 73.75310003757477, 75.36433517932892, 74.48327645659447, 79.06017646193504, 74.6927136182785, 77.41954609751701, 71.85345277190208, 71.8511500954628, 65.65714046359062, 66.53306946158409, 67.24743872880936, 70.01265674829483, 66.91685646772385, 78.55635389685631, 80.59960305690765, 85.4580907523632, 75.72390228509903, 74.65985298156738, 12.255385480821133, 1.4771735854446888, 6.7155734449625015, 8.19166123867035, 8.196607623249292, 0.5749853840097785, 0.201049794559367, 5.655891532078385, 86.8415205180645, 65.69522202014923, 69.26630079746246, 83.05554807186127, 39.86483886837959, 43.66798259317875, 60.52102826535702, 78.90176296234131, 26.600772812962532, 0.41326659615151584, 0.14015145687153563, 0.12637213454581797, 0.20835876173805445, 0.22881319775478914, 0.13819125189911574, 0.14072240592213348, 0.13542903761845082, 0.1438626108574681, 0.0666102921240963, 0.10287350523867644], [0.06707642023684457, 0.03586714003176894, 0.015192176688287873, 0.038409162807511166, 0.01147299173680949, 0.02364144635066623, 0.047596327640349045, 0.006851287489553215, 0.03819757650489919, 0.06731214860337786, 0.13744932686677203, 0.320685098413378, 3.8592420145869255, 66.22527077794075, 52.70274259150028, 29.51406128704548, 31.70951697975397, 56.853161081671715, 41.65646933019161, 3.9303186256438494, 0.2988535776967183, 1.33501086384058, 5.128323566168547, 1.9538145465776324, 0.6016084179282188, 67.71983698010445, 93.22931215167046, 92.76705175638199, 97.50821694731712, 95.42009219527245, 93.65757957100868, 93.66254210472107, 87.67013445496559, 94.29999589920044, 86.92098185420036, 86.90968126058578, 75.48549547791481, 71.86259508132935, 73.12400579452515, 78.36699485778809, 75.78481301665306, 73.08258041739464, 68.8444322347641, 75.20246386528015, 77.84576162695885, 78.45357701182365, 78.13591405749321, 70.87537005543709, 59.06524658203125, 59.392633214592934, 56.01654477417469, 59.69655990600586, 54.45731744170189, 52.93483413755894, 52.80784495174885, 51.36667728424072, 50.410314202308655, 52.52312242984772, 59.568966552615166, 70.44983848929405, 72.95099347829819, 69.36257243156433, 74.51753541827202, 69.25265192985535, 66.72573432326317, 65.60603320598602, 59.8558359593153, 57.83659391105175, 52.429487854242325, 51.84073984622955, 50.81661120057106, 56.43621705472469, 62.8184761852026, 63.92960876226425, 66.00289151072502, 64.30587217211723, 61.73846773803234, 66.13766267895699, 60.950154438614845, 56.8432892113924, 53.36912043392658, 61.21601477265358, 64.24807727336884, 63.462127447128296, 65.78539118170738, 61.44239142537117, 66.74541726708412, 65.70602104067802, 64.00381118059158, 65.83015277981758, 63.01820486783981, 64.90082144737244, 62.19201900064945, 64.99627992510796, 60.03720782697201, 57.901213243603706, 53.547452464699745, 57.47312441468239, 59.85200196504593, 56.922697350382805, 57.160298600792885, 59.82409246265888, 64.52376767992973, 61.351637095212936, 58.48619945347309, 55.031447634100914, 59.708673655986786, 64.50737535953522, 65.01377418637276, 61.68212816119194, 58.82508426904678, 57.07329086959362, 53.51650312542915, 49.37252148985863, 51.001273691654205, 50.950937792658806, 55.06157621741295, 51.64180912077427, 49.67738673090935, 48.43759685754776, 47.97920845448971, 50.07836401462555, 49.16658394038677, 50.93827687203884, 55.79936362802982, 62.8061306476593, 66.46120771765709, 67.40159645676613, 71.60243064165115, 71.08710989356041, 71.2570595741272, 69.1466224193573, 69.48301076889038, 65.31595677137375, 62.1417248994112, 60.85971549153328, 56.96442671120167, 57.03198328614235, 53.8325397670269, 57.85804755985737, 60.982285514473915, 64.04527455568314, 67.00593888759613, 71.21371150016785, 73.74837309122086, 78.64504873752594, 69.33232605457306, 73.38043883442879, 50.56872770190239, 0.7825034111738205, 0.5525893857702613, 3.1025458686053753, 2.9288035165518522, 0.6349920609500259, 0.07685456468607299, 0.1943780353758484, 41.200744584202766, 72.46203571557999, 42.04580403864384, 63.85468438267708, 35.99235266447067, 37.26160615682602, 52.41247996687889, 55.30111536383629, 20.352788977324963, 0.3637013729894534, 0.16658979991916567, 0.08881462330464274, 0.026676182824303396, 0.02996144052303862, 0.039669726611464284, 0.09610417590010911, 0.0626709648349788, 0.04612993659975473, 0.03125353447103407, 0.03412743084481917, 0.053722589727840386, 0.08085388719337061, 0.04482592376007233, 0.055132510751718655, 0.048419699669466354, 0.06420096164220013, 0.08031064251554199, 0.028803730965591967, 0.02380428839387605, 0.09210378470015712, 0.15853240649448708, 0.5401721270754933, 6.292938748374581, 77.5060598552227, 62.98631697893143, 44.170596823096275, 27.4252924695611, 60.9096410125494, 52.51352794468403, 3.2963402196764946, 0.4469733405858278, 4.770666807889938, 5.231298990547657, 0.9786982834339142, 1.0433009918779135, 73.99523824453354, 96.15631029009819, 96.91364765167236, 99.44485142827034, 97.924864590168, 94.048882573843, 95.55513694882393, 87.01927497982979, 94.07181814312935, 89.96407896280289, 87.74102345108986, 77.98823118209839, 74.1950011253357, 77.26167976856232, 82.1376921236515, 76.89285635948181, 76.78991988301277, 73.66640388965607, 78.28843027353287, 78.86156871914864, 80.18097952008247, 81.07129454612732, 71.84313252568245, 61.97799168527126, 61.28272019326687, 59.55822832882404, 62.090594843029976, 57.410530373454094, 54.06381815671921, 54.76460315287113, 54.28158067166805, 53.74750033020973, 56.99890986084938, 63.067024648189545, 75.16392633318901, 74.87975478172302, 73.6473137140274, 75.62220454216003, 74.10189852118492, 69.89978760480881, 68.51520270109177, 61.1752163618803, 60.74938461184502, 55.01671202480793, 54.001972675323486, 52.38131783902645, 58.26876752078533, 64.95733961462975, 68.90541896224022, 67.60682344436646, 68.83652105927467, 65.14710143208504, 69.97460559010506, 63.622250854969025, 58.350379541516304, 56.37486554682255, 64.47067692875862, 67.331003844738, 65.18180876970291, 68.4466315805912, 64.32704463601112, 69.77677300572395, 68.14753443002701, 66.43457874655724, 65.88478624820709, 64.47038814425468, 68.35936546325684, 63.52434150874615, 67.85043597221375, 62.32066109776497, 59.80911746621132, 56.015803813934326, 60.590423941612244, 63.727227821946144, 58.287610709667206, 58.79198804497719, 61.37762010097504, 66.3436496257782, 63.12059037387371, 59.84259746968746, 57.30005130171776, 62.72921897470951, 65.08894935250282, 67.48807221651077, 63.55559483170509, 63.193413466215134, 60.79965591430664, 55.95090709626675, 53.018285259604454, 54.66907247900963, 53.532891646027565, 56.72611489892006, 55.04954606294632, 51.73931568861008, 51.96759223937988, 51.480059400200844, 51.51058316230774, 51.60771735012531, 53.21840152144432, 57.8883471339941, 65.15479981899261, 68.92342999577522, 69.73374411463737, 72.20991164445877, 72.42247223854065, 73.94291505217552, 72.92338415980339, 71.4297603070736, 67.08030089735985, 64.97261479496956, 61.12011931836605, 58.76733496785164, 59.20741595327854, 57.11556740105152, 62.29714795947075, 63.04886922240257, 67.61386066675186, 70.56476712226868, 73.76036524772644, 77.44444996118546, 79.03600215911865, 73.74165505170822, 73.15285384654999, 61.3996247202158, 5.7864416018128395, 0.7879391976166517, 1.1797447828575969, 3.6157111823558807, 1.9556458108127117, 0.07591923596919514, 0.11400457005947828, 43.196747079491615, 79.54573720693588, 50.19152194261551, 60.379090681672096, 28.317448496818542, 45.94331569969654, 59.038119837641716, 63.62416215240955, 26.632607504725456, 0.28486682509537786, 0.23946009285282344, 0.09361768432427198, 0.07963362571899779, 0.015221414523693966, 0.056427951785735786, 0.04069794624228962, 0.07022754216450267, 0.051490417317836545, 0.035133478813804686, 0.028554040945891757, 0.14470536407316104, 0.17346152337267995, 0.18213513685623184, 0.1505274383816868, 0.17919603909831494, 0.16681070759659633, 0.14646452123997733, 0.061949920127517544, 0.2877000183798373, 0.2630328107625246, 0.503416343126446, 0.7802469260059297, 7.995000891387463, 89.99538168311119, 70.65463230013847, 39.080906733870506, 41.829827427864075, 80.1750898361206, 63.006345704197884, 6.5559150371700525, 0.5869597883429378, 6.632372634485364, 12.77873519808054, 9.157273974269629, 0.9492334770038724, 77.94093891978264, 101.17413103580475, 102.34988674521446, 102.14466735720634, 102.91700631380081, 98.45663845539093, 99.15564134716988, 89.41473484039307, 99.44021567702293, 92.97513619065285, 92.10616081953049, 80.97734078764915, 79.83142107725143, 81.67309865355492, 87.85469055175781, 81.40028849244118, 81.694096326828, 76.36612102389336, 82.23188906908035, 83.95127400755882, 84.8507921397686, 84.6877732872963, 76.69838279485703, 65.62897637486458, 66.84681862592697, 60.980157628655434, 67.90646776556969, 61.43422566354275, 57.94929586350918, 58.36461737751961, 56.72502815723419, 58.00452210009098, 59.431592524051666, 64.84809547662735, 78.39946791529655, 79.09309789538383, 76.23866826295853, 79.96274203062057, 77.34046474099159, 71.84709951281548, 74.28072452545166, 64.98846754431725, 66.59904152154922, 59.86727334558964, 57.85703681409359, 56.75468176603317, 62.497864589095116, 66.82641372084618, 73.86302813887596, 70.43711677193642, 70.52015751600266, 69.26088228821754, 74.20274510979652, 66.6579307615757, 63.54143299162388, 58.031238466501236, 64.08698111772537, 67.35462337732315, 68.0564533174038, 73.72066497802734, 65.95616921782494, 71.57488971948624, 69.80451911687851, 66.99840769171715, 68.74987810850143, 65.55947050452232, 70.45703530311584, 65.34394606947899, 69.30017217993736, 64.04346585273743, 61.16968385875225, 60.862386748194695, 65.12247875332832, 65.48539727926254, 62.63331972062588, 62.6600930839777, 65.11301726102829, 70.32092660665512, 68.06396171450615, 64.36168357729912, 60.95322847366333, 66.84077695012093, 69.11359459161758, 71.01872116327286, 68.56923580169678, 65.02172335982323, 62.62471318244934, 59.09853659570217, 55.8796951174736, 58.860973343253136, 56.72687105834484, 60.82932472229004, 58.6564265191555, 55.82482986152172, 56.1998051404953, 54.684359058737755, 55.54495207965374, 55.48695959150791, 56.89791887998581, 62.32641018927097, 68.74566033482552, 72.86382615566254, 72.90292605757713, 75.88754430413246, 75.31083405017853, 77.5521057844162, 75.39717301726341, 73.83429408073425, 71.43812745809555, 70.30260398983955, 67.05198481678963, 61.62741109728813, 63.69123235344887, 60.465612038969994, 66.63045063614845, 66.96385994553566, 70.9948280453682, 73.07342290878296, 80.02066612243652, 80.10094821453094, 85.55702224373817, 75.00392451882362, 75.76253861188889, 60.10978013277054, 6.937263049185276, 1.7323460429906845, 9.761832933872938, 11.160137951374054, 3.629814125597477, 0.2554098854307085, 0.8273698599077761, 52.52982147037983, 88.50434929132462, 55.54134987294674, 85.73933646082878, 52.99622364342213, 47.433884516358376, 67.50505730509758, 75.38442850112915, 33.43070112168789, 0.5189961602445692, 0.376287039835006, 0.2215902751777321, 0.19923086481867358, 0.09726954071084037, 0.11154146355693229, 0.22804167587310076, 0.15524022455792874, 0.0994602419086732, 0.13688097533304244, 0.13388217921601608], [0.055740058814990334, 0.04088244415470399, 0.03287967650976498, 0.05818629259010777, 0.0552355022955453, 0.042740993449115194, 0.09529922768706456, 0.0555435121350456, 0.10769493441330269, 0.07218290833407082, 0.13709523336729035, 0.45495368423871696, 9.960580319166183, 65.61357960104942, 43.969036638736725, 42.32443168759346, 64.1871665418148, 52.13371552526951, 29.82751026749611, 0.2874677558429539, 0.11470313140307553, 3.1240436900407076, 1.6067543509416282, 2.021537837572396, 7.939331028610468, 99.46722462773323, 81.87925279140472, 102.11728602647781, 82.25075125694275, 91.35329201817513, 92.95284658670425, 90.54121479392052, 85.81856980919838, 88.68760585784912, 86.29326313734055, 87.90806248784065, 79.94796842336655, 73.61415669322014, 70.070261657238, 73.77786710858345, 72.80657082796097, 70.7135671377182, 68.50242018699646, 73.18661883473396, 75.06689473986626, 76.12386122345924, 71.42783761024475, 63.30808751285076, 56.582235619425774, 58.89339320361614, 54.61417302489281, 57.52788707613945, 51.25984601676464, 49.256274327635765, 50.97871050238609, 53.38471479713917, 51.131941080093384, 55.369534492492676, 64.70932692289352, 71.66236102581024, 68.43895599246025, 70.11314615607262, 70.99616557359695, 66.16835743188858, 60.71584761142731, 59.69229653477669, 54.319031462073326, 51.721323654055595, 50.46348474919796, 49.334599524736404, 54.27138201892376, 60.742651373147964, 65.4047504067421, 65.96056938171387, 65.11747062206268, 61.21205158531666, 59.295031651854515, 63.117147758603096, 61.512695252895355, 56.21361739933491, 57.17696450650692, 65.9055483341217, 64.59384351968765, 68.08057442307472, 60.995147824287415, 63.78420576453209, 66.1382782459259, 62.021271362900734, 60.52644297480583, 63.2808505743742, 62.24814958870411, 61.05032466351986, 60.16833499073982, 61.39257609844208, 64.04269829392433, 59.61077190935612, 52.68969029188156, 55.32059691846371, 60.727987959980965, 60.68962141871452, 52.75625132024288, 54.204019233584404, 53.30358915030956, 56.45679295063019, 52.33595587313175, 52.57014870643616, 59.39754635095596, 61.72036170959473, 64.70618069171906, 61.68180137872696, 59.093935042619705, 60.046817511320114, 57.52589978277683, 51.18500143289566, 48.709434270858765, 48.26527610421181, 48.922656029462814, 48.693406730890274, 48.58568251132965, 46.602109149098396, 47.53056652843952, 48.82756233215332, 49.51277956366539, 51.05816423892975, 54.032705426216125, 62.12488800287247, 66.3622610270977, 69.71287563443184, 70.50716981291771, 70.15951126813889, 69.66732367873192, 64.63983625173569, 60.97747877240181, 56.58362254500389, 53.574001640081406, 52.49390959739685, 54.017939418554306, 55.189591348171234, 61.334982588887215, 60.130614414811134, 62.242024317383766, 65.16065150499344, 70.74232399463654, 69.27514672279358, 77.42781445384026, 69.42121088504791, 75.0430928170681, 67.28827893733978, 79.61164847016335, 43.595938459038734, 3.434259044006467, 1.4736644737422466, 6.238840576261282, 1.5317122964188457, 0.14160097518470138, 0.11399593888199888, 18.84384624660015, 77.13442459702492, 47.55693331360817, 53.305424451828, 42.13370852172375, 43.248557299375534, 37.951956912875175, 54.51051078736782, 25.497824996709824, 0.11809727700892836, 0.09196878061629832, 0.05362454459827859, 0.05735469014325645, 0.039084843738237396, 0.05680849171767477, 0.0362962646613596, 0.03202387633791659, 0.03856252762489021, 0.03131293226033449, 0.025744559279701207, 0.012038896966259927, 0.06000200140988454, 0.026874210088863038, 0.043404213720350526, 0.03133385340333916, 0.027198543466511182, 0.13524520763894543, 0.06917850158060901, 0.10989258953486569, 0.08293359278468415, 0.16856235422892496, 0.49492207705043256, 17.862864285707474, 75.39640545845032, 51.9998487085104, 41.52870498597622, 43.03424879908562, 62.99242325127125, 30.930042006075382, 0.3011288837296888, 0.45170589757617563, 5.461251251399517, 2.705949512310326, 1.22888172743842, 10.927705373615026, 104.54574331641197, 86.7952162027359, 106.24440416693687, 86.97256788611412, 94.48342725634575, 92.19510644674301, 92.90093377232552, 88.63380074501038, 90.67108422517776, 88.86120334267616, 92.15875759720802, 82.97275051474571, 76.13232716917992, 71.6172194480896, 76.71800494194031, 74.72831770777702, 75.08145555853844, 72.99921289086342, 77.07419782876968, 77.97550186514854, 80.63473597168922, 75.7029578089714, 65.58622866868973, 59.21001121401787, 60.95608212053776, 58.39661926031113, 59.32937040925026, 54.783248752355576, 52.805998250842094, 54.730347990989685, 56.294154077768326, 54.00406256318092, 58.42390939593315, 67.084891051054, 73.08458670973778, 70.96946820616722, 73.69928732514381, 73.26383829116821, 71.15910843014717, 65.57279258966446, 63.701066225767136, 58.02827462553978, 54.23939913511276, 54.2656709253788, 55.53664572536945, 57.90573500096798, 65.19505485892296, 67.5365500152111, 69.75860998034477, 68.84827002882957, 62.91296571493149, 63.28630328178406, 65.84665149450302, 65.01469373703003, 58.47225420176983, 58.80994588136673, 68.79642561078072, 65.95867708325386, 69.06998813152313, 62.51848228275776, 65.22215500473976, 66.46519750356674, 65.16586482524872, 63.16570535302162, 66.0237143933773, 65.30704244971275, 62.16235779225826, 63.9498008787632, 62.95883685350418, 66.76004648208618, 60.893043503165245, 53.61393369734287, 57.33973257243633, 64.65989917516708, 62.15756244957447, 56.05312541127205, 55.546080619096756, 55.441042855381966, 56.72201871871948, 54.24366630613804, 53.382731303572655, 62.43903234601021, 64.7985689342022, 66.93364396691322, 64.9671658873558, 64.15076449513435, 61.20927393436432, 60.0677277892828, 54.85646702349186, 51.363196671009064, 51.75515703856945, 51.06649339199066, 51.37113444507122, 52.08419278264046, 49.62030999362469, 49.68694321811199, 52.81379163265228, 51.477103158831596, 52.75220453739166, 55.81164836883545, 64.3745344877243, 69.3523433804512, 72.36734479665756, 70.58362171053886, 72.78249531984329, 72.04940065741539, 66.8392114341259, 62.0542573928833, 59.33081813156605, 56.575787365436554, 54.976738169789314, 55.73670119047165, 59.23647299408913, 63.597407788038254, 63.87277141213417, 64.56053450703621, 68.06541323661804, 72.60102465748787, 73.3773609995842, 78.28649997711182, 75.06271496415138, 76.02160111069679, 69.22805204987526, 79.99180287122726, 58.40138800442219, 7.492924807593226, 0.6700324744451791, 0.9807385958265513, 2.559669236652553, 0.3742822614731267, 0.10742978731286712, 17.969121783971786, 85.81568956375122, 54.892238304018974, 59.85641352832317, 32.69525818526745, 44.47667419910431, 51.82952664792538, 61.636238023638725, 33.86505201458931, 0.1267198901041411, 0.12581093731569126, 0.04098290497495327, 0.02223962586867856, 0.010658356641215505, 0.06560593625181355, 0.026934559682558756, 0.048102327637025155, 0.03738432365935296, 0.07435346022248268, 0.04551498932414688, 0.13125231955200434, 0.11276004035607912, 0.14230525848688558, 0.156998238817323, 0.1851175315096043, 0.14795436785789207, 0.31092517368961126, 0.2040815123473294, 0.27431695838458836, 0.10538268426898867, 0.5136656400281936, 1.0736877238377929, 20.379948019981384, 92.6868836581707, 57.237381264567375, 54.19170029461384, 84.16900992393494, 75.21560356020927, 42.32765011489391, 0.674469864461571, 0.5005983193404973, 8.015713579952717, 9.03535371646285, 3.950804276391864, 10.197101477533579, 109.236219227314, 89.5968970656395, 112.3850266635418, 89.77238684892654, 96.82306051254272, 96.48392111063004, 97.61842623353004, 90.77428668737411, 91.70560151338577, 90.14572441577911, 95.37561938166618, 87.68293216824532, 81.54697582125664, 75.37927597761154, 82.40041002631187, 78.80789279937744, 78.61476436257362, 75.23715600371361, 79.72722306847572, 82.20391497015953, 83.02431374788284, 79.47061523795128, 70.50933569669724, 62.433480843901634, 65.07552847266197, 59.362139850854874, 62.9093749076128, 59.72748264670372, 56.7230598628521, 59.935931861400604, 59.045510441064835, 57.04582594335079, 61.317712515592575, 68.88191342353821, 77.77801126241684, 75.50447165966034, 79.286530315876, 76.97674825787544, 72.69095823168755, 68.1801138818264, 68.40804845094681, 62.489478439092636, 58.223192766308784, 56.8002375215292, 58.01644966006279, 59.66814123094082, 67.80182898044586, 70.71169003844261, 73.48467484116554, 71.40391409397125, 66.89642116427422, 67.87492945790291, 69.24457356333733, 69.72583293914795, 61.7343145608902, 61.93082481622696, 71.57540649175644, 66.3170662522316, 75.62481880187988, 65.99690303206444, 67.07112818956375, 70.57450979948044, 67.57818058133125, 65.3657341003418, 67.79467776417732, 66.77649199962616, 65.82225680351257, 65.19042670726776, 64.40097346901894, 66.6364923119545, 61.87586076557636, 56.22596673667431, 62.187417447566986, 67.08416149020195, 66.89548641443253, 59.748495519161224, 59.88509438931942, 58.95540967583656, 63.20597939193249, 58.21220375597477, 58.504142090678215, 65.93511074781418, 69.25173237919807, 67.59062871336937, 68.56319412589073, 67.85413697361946, 66.14212363958359, 62.347506657242775, 57.644685208797455, 54.35438096523285, 54.36271391808987, 54.55288991332054, 53.930342718958855, 56.110369339585304, 52.8339571505785, 52.925399243831635, 56.089196875691414, 54.63159888982773, 56.56447157263756, 59.96363617479801, 67.9116202890873, 71.58948853611946, 75.68087339401245, 75.18287971615791, 76.97697624564171, 75.64614325761795, 70.04699170589447, 65.75199857354164, 63.056776598095894, 59.966322630643845, 59.74230945110321, 59.28557015955448, 62.10321396589279, 68.170857578516, 66.66137337684631, 68.03457409143448, 74.05604258179665, 76.41434043645859, 75.98611861467361, 81.57973766326904, 78.14118057489395, 77.91225805878639, 71.07986748218536, 83.06434080004692, 59.8914210498333, 6.610901411622763, 6.051261741667986, 14.42529609426856, 5.440087812021375, 0.8128923398908228, 0.19209446181776002, 24.79539468884468, 92.28880941867828, 60.031375139951706, 70.52013471722603, 58.98156747221947, 56.56010180711746, 51.60365156829357, 74.18982580304146, 39.90234665572643, 0.2978802064899355, 0.14656693761935458, 0.16576300287852064, 0.12621601636055857, 0.12098330378648825, 0.20270560024073347, 0.1329321856610477, 0.17948149878066033, 0.23331135482294485, 0.27060280612204224, 0.09024425948155113], [0.042286257303203456, 0.019201900395273697, 0.015674817586841527, 0.03591559114283882, 0.032066857820609584, 0.040442996250931174, 0.08542500479961745, 0.03963640789152123, 0.04997672549507115, 0.0976861230446957, 0.07198239487479441, 0.24348256294615567, 27.33051225543022, 70.270054936409, 37.40493066608906, 47.629414424300194, 65.8017911016941, 56.33101969957352, 22.251858673989773, 0.3801049740286544, 0.9082459670025855, 3.427298767492175, 1.3990633143112063, 1.0943893692456186, 34.54614646732807, 96.95710971951485, 87.81940564513206, 91.62916481494904, 84.42925035953522, 89.38024029135704, 83.16676050424576, 88.76614764332771, 87.32725605368614, 91.34591281414032, 90.32034024596214, 88.16865250468254, 83.64501804113388, 75.73821231722832, 67.76659727096558, 71.69240221381187, 70.46301618218422, 69.44459483027458, 69.95145723223686, 72.38669335842133, 73.86398568749428, 75.42054176330566, 64.6580296754837, 56.9681391119957, 57.0023562759161, 57.74181939661503, 57.55969136953354, 54.04385402798653, 50.47495633363724, 49.295815005898476, 50.211653262376785, 50.06424017250538, 51.6242540627718, 58.0122584849596, 66.51563599705696, 68.07975366711617, 66.92431166768074, 68.64878833293915, 65.51661640405655, 62.51691676676273, 56.14083610475063, 51.98749557137489, 53.008698374032974, 51.100547164678574, 52.38026149570942, 50.8964829146862, 60.098107159137726, 61.026233956217766, 63.608719781041145, 61.98932647705078, 61.4280965924263, 59.324290081858635, 61.24362029135227, 63.3513405919075, 58.408923000097275, 55.964384973049164, 60.83952337503433, 67.9733593761921, 68.02280992269516, 64.67300087213516, 61.883768141269684, 63.953562676906586, 60.40633901953697, 62.63200879096985, 62.70949423313141, 62.73945562541485, 62.64124609529972, 67.95140415430069, 67.52629816532135, 63.57131838798523, 63.63131336867809, 63.23579639196396, 57.582068368792534, 53.20214219391346, 57.477684170007706, 61.15501284599304, 55.796639174222946, 50.64375847578049, 47.92940832674503, 47.51163974404335, 49.891265854239464, 47.86040782928467, 56.32132641971111, 63.04047167301178, 66.6695049405098, 64.15169924497604, 62.8049261122942, 59.377730414271355, 57.016347125172615, 58.23562949895859, 50.59004835784435, 49.41341869533062, 48.47504764795303, 48.67931328713894, 47.97367975115776, 46.53187371790409, 47.078588381409645, 48.57300639152527, 50.24053171277046, 51.9140113145113, 55.32999761402607, 64.2678590118885, 67.68553242087364, 68.3040252327919, 67.65894904732704, 66.9526581466198, 62.898788675665855, 55.849444940686226, 52.45976842939854, 51.88116207718849, 52.272639870643616, 51.98340319097042, 54.165295511484146, 59.83643040060997, 60.02370335161686, 63.41398403048515, 64.78379532694817, 64.86145555973053, 69.83582183718681, 73.9709423482418, 73.46792533993721, 73.15505012869835, 69.4571341574192, 77.11676314473152, 72.56525337696075, 78.88144925236702, 41.357353180646896, 0.42926344089210033, 1.129222100134939, 1.672707530669868, 0.3650296985870227, 0.24901102879084647, 4.5783391781151295, 65.07079392671585, 61.71601474285126, 48.893287405371666, 46.395008862018585, 25.411296039819717, 28.834211267530918, 52.93399058282375, 28.852106407284737, 0.05538693752896506, 0.09799524239497259, 0.026724101444415282, 0.050411490447004326, 0.03757423924980685, 0.0629002958885394, 0.05691808466508519, 0.04823960640351288, 0.007131483025659691, 0.028480419896368403, 0.012505508402682608, 0.05233826166659128, 0.13981354219140485, 0.034234686027048156, 0.027693381562130526, 0.022208980735740624, 0.02909306280344026, 0.08162833313690498, 0.03360656191944145, 0.03376336288056336, 0.10718683784944005, 0.036429409665288404, 0.0961181653838139, 37.71448105573654, 79.04142066836357, 46.14631600677967, 36.50751382112503, 54.27283734083176, 69.86191883683205, 22.849526703357697, 0.2647270151646808, 0.6972532637882978, 5.83403879776597, 1.0549981892108917, 0.6596113555133343, 39.032352939248085, 101.73800557851791, 91.73599988222122, 93.87854531407356, 83.8998931646347, 91.96125939488411, 85.78035905957222, 92.78082221746445, 88.52137237787247, 92.74534732103348, 89.4133973121643, 92.68281787633896, 84.2394657433033, 80.1786920428276, 72.14871972799301, 74.22606825828552, 72.46944531798363, 74.26845118403435, 75.50305813550949, 75.53953617811203, 76.23251259326935, 79.10882905125618, 68.31539422273636, 59.18536193668842, 62.5016225874424, 61.89640626311302, 59.27232787013054, 56.75291106104851, 53.556731566786766, 54.854688718914986, 51.94775730371475, 53.54016825556755, 53.71346175670624, 59.51354272663593, 68.67131352424622, 70.69698482751846, 69.13969159126282, 72.51381933689117, 69.84890073537827, 65.08657827973366, 58.044632747769356, 55.515458062291145, 53.69359642267227, 52.94358506798744, 54.286539405584335, 52.79487244784832, 62.95205421745777, 66.27130150794983, 68.47393691539764, 65.30911713838577, 64.12043452262878, 64.40946221351624, 64.88473311066628, 66.9156177341938, 61.9353199750185, 57.131974920630455, 62.80689440667629, 70.47508433461189, 70.04652053117752, 66.44846320152283, 63.64340052008629, 67.72341638803482, 64.34865787625313, 65.0511945784092, 66.01439729332924, 63.366083800792694, 64.84546601772308, 70.1491530239582, 69.7293059527874, 65.1481881737709, 66.11269801855087, 66.66628271341324, 59.312240928411484, 55.181797966361046, 60.95965392887592, 61.83748662471771, 59.694747403264046, 53.2982162386179, 51.055485382676125, 49.354476258158684, 52.534084841609, 49.78250429034233, 59.840800166130066, 63.61825346946716, 70.16584932804108, 66.16230055689812, 67.37245962023735, 65.07250383496284, 60.793272256851196, 61.05654872953892, 55.20341120660305, 51.04170732200146, 51.63419432938099, 51.398314386606216, 51.24730668962002, 48.67551729083061, 50.04841782152653, 49.65969108045101, 52.13909983634949, 54.542071893811226, 57.60531932115555, 65.67670181393623, 70.65821170806885, 69.52496811747551, 69.88857820630074, 69.95085686445236, 64.33943957090378, 58.16391594707966, 55.76159365475178, 54.870020896196365, 54.43149022758007, 55.750760436058044, 56.832391396164894, 59.235716834664345, 62.981153056025505, 66.60350248217583, 67.72325679659843, 67.1561524271965, 72.00909242033958, 75.84234952926636, 76.85988172888756, 74.33388367295265, 72.33687043190002, 78.88483867049217, 76.77842170000076, 80.08747413754463, 56.422473192214966, 1.628418650943786, 1.1611446621827781, 3.1340210046619177, 0.9816875355318189, 0.2904827753081918, 3.3747960347682238, 69.66494500637054, 70.81823632121086, 59.722197130322456, 43.26320931315422, 28.56169369071722, 41.935397163033485, 58.479728400707245, 35.395625084638596, 0.04066876499564387, 0.043573720249696635, 0.05700028494175058, 0.01188303203889518, 0.08306618488859385, 0.1657707805861719, 0.08005279072676785, 0.08150521825882606, 0.025668392663646955, 0.022092951512604486, 0.023152927642513532, 0.17709696345264092, 0.3184609115123749, 0.16766529064625502, 0.16884582495549694, 0.17126871447544545, 0.12702783686108887, 0.18199696380179375, 0.11537299389601685, 0.14417450584005564, 0.2223948374739848, 0.2258163460646756, 0.3445663122693077, 44.110708236694336, 92.45782434940338, 52.90730841457844, 62.8812488168478, 84.60004359483719, 78.49890857934952, 30.862113051116467, 0.4565842420561239, 2.5562289962545037, 11.12979182973504, 8.997732885181904, 2.264498700387776, 41.51187188923359, 108.02336990833282, 96.87253385782242, 99.32812169194221, 89.7570888698101, 96.82809144258499, 90.88288486003876, 95.15420526266098, 91.45365223288536, 100.30226781964302, 92.51107469201088, 95.70212826132774, 87.59558245539665, 84.05674114823341, 73.57482120394707, 79.40977290272713, 77.53774255514145, 78.18114683032036, 79.61800172924995, 81.6032811999321, 80.96139684319496, 84.66638043522835, 70.40238663554192, 63.79594713449478, 64.25598844885826, 63.9955048263073, 64.28948745131493, 59.10170182585716, 58.996306881308556, 56.23798169195652, 56.53538033366203, 55.62098979949951, 55.63749611377716, 62.43447259068489, 72.37336367368698, 75.11314585804939, 70.5528661608696, 75.75207397341728, 72.35298156738281, 70.56724458932877, 63.340993747115135, 58.983186185359955, 60.114184096455574, 56.819099709391594, 59.333439990878105, 56.49919107556343, 67.28896290063858, 67.76957631111145, 71.30597054958344, 69.95576620101929, 68.56528401374817, 66.80476248264313, 66.79783165454865, 68.51641103625298, 66.47303268313408, 60.84663279354572, 64.96336609125137, 74.11626175045967, 74.17844161391258, 70.4347836971283, 65.77110394835472, 70.55795028805733, 67.18956023454666, 68.38805392384529, 70.01815885305405, 67.14477583765984, 69.65434357523918, 72.70053371787071, 72.95984700322151, 66.25663429498672, 68.19457590579987, 67.22040697932243, 63.13977554440498, 59.102476984262466, 63.515514582395554, 66.932253241539, 63.617003336548805, 56.78736001253128, 52.48768173158169, 52.30184890329838, 55.83490692079067, 52.38019309937954, 62.62325406074524, 66.85536056756973, 73.336201608181, 69.30860012769699, 70.26832222938538, 67.61185437440872, 64.23082619905472, 63.883160054683685, 56.476624086499214, 55.020128041505814, 55.54944343864918, 54.22076873481274, 54.51871454715729, 53.42595778405666, 52.17094972729683, 52.464012801647186, 55.28340831398964, 57.16530293226242, 61.261863112449646, 69.33514550328255, 75.16458749771118, 74.24324333667755, 74.49434146285057, 73.31711903214455, 69.64433491230011, 61.61942772567272, 59.11055535078049, 58.534164279699326, 59.292390793561935, 58.24384845793247, 59.68061976134777, 64.25339698791504, 67.70596012473106, 70.06635546684265, 71.77165076136589, 70.63420459628105, 77.51322627067566, 81.33143618702888, 81.21347531676292, 75.58543011546135, 75.29836311936378, 81.68470323085785, 81.04327484965324, 82.74728581309319, 60.4438392072916, 1.2516216072253883, 7.245160527527332, 9.370293393731117, 0.9408516017720103, 0.35802557598799467, 6.07824076898396, 77.49589920043945, 76.76202178001404, 65.05038902163506, 65.97295671701431, 38.17053258419037, 41.76129810512066, 72.380750477314, 42.00226217508316, 0.09522539141471498, 0.2555958379525691, 0.163424109632615, 0.10484180704224855, 0.12834137887693942, 0.1676472564577125, 0.23766854836139828, 0.24092145584290847, 0.11627525251242332, 0.07412904218654148, 0.08484546167892404], [0.046473769907606766, 0.057125767270918004, 0.043112957864650525, 0.04735059512313455, 0.07800173945724964, 0.056988150827237405, 0.019841371940856334, 0.049985349251073785, 0.015307208650483517, 0.025921641281456687, 0.060857797870994546, 0.23166019498603418, 39.205160066485405, 59.1672483086586, 40.83390086889267, 45.943524688482285, 46.9888561964035, 54.536136612296104, 10.222657956182957, 0.35707461764104664, 0.3090819757198915, 5.015764106065035, 0.7289467693772167, 0.08528856837074272, 67.03993186354637, 90.7616637647152, 86.75297006964684, 89.0433731675148, 81.21090665459633, 78.88011172413826, 85.81625193357468, 81.05990275740623, 83.53876814246178, 83.11745434999466, 87.39289373159409, 88.76262903213501, 84.77540418505669, 79.87946569919586, 74.24151062965393, 71.84503242373466, 70.25553211569786, 68.82667198777199, 73.39749231934547, 68.54038774967194, 71.07315704226494, 64.96995493769646, 58.94022949039936, 56.327998861670494, 59.7163188457489, 56.78947649896145, 57.60692283511162, 49.05716121196747, 50.02295918762684, 50.38582071661949, 52.00758509337902, 50.819221660494804, 51.256384402513504, 59.62077297270298, 66.37356922030449, 66.04049429297447, 69.08117473125458, 65.01299142837524, 61.41312539577484, 55.994331166148186, 55.274425595998764, 51.483163833618164, 50.67375026643276, 49.11829613149166, 48.01295064389706, 57.078268602490425, 61.74138978123665, 61.32575288414955, 65.45615404844284, 63.22609171271324, 55.243419259786606, 57.802201956510544, 65.58540031313896, 60.526454374194145, 59.43609528243542, 56.53271667659283, 62.80745677649975, 66.15668445825577, 66.18332862854004, 62.30490334331989, 62.32654698193073, 63.462990000844, 62.53319509327412, 60.194200202822685, 60.872129425406456, 55.99150411784649, 54.78045970201492, 61.28029592335224, 55.425410494208336, 55.61135731637478, 60.34041255712509, 62.82028488814831, 56.490721330046654, 52.011206299066544, 55.87054520845413, 61.117926836013794, 56.902254447340965, 52.68865294754505, 51.24445304274559, 47.25195787847042, 46.80559203028679, 46.204338893294334, 54.173183888196945, 58.396326676011086, 60.93107186257839, 67.52516582608223, 60.50436995923519, 62.629322335124016, 61.12054109573364, 58.717192858457565, 59.20737415552139, 51.11956514418125, 49.072706177830696, 46.77461229264736, 47.87477485835552, 47.57515333592892, 48.130824118852615, 48.832266479730606, 49.863037168979645, 47.77630694210529, 54.69122529029846, 64.11876261234283, 66.69410482048988, 65.65638810396194, 68.72456386685371, 61.84365749359131, 54.284362122416496, 51.82101130485535, 53.8350248336792, 52.7764168381691, 52.65738822519779, 51.90119460225105, 57.15266101062298, 58.571732863783836, 61.53980299830437, 61.557912826538086, 64.59464907646179, 67.12355777621269, 68.95983204245567, 69.75489377975464, 74.32674765586853, 70.56474432349205, 70.84042713046074, 74.07631829380989, 74.83401283621788, 73.22616711258888, 84.39477860927582, 15.282872077077627, 1.2050789734348655, 2.4731098813936114, 0.5565402237698436, 0.033304530079476535, 0.04997550837288145, 43.851600140333176, 67.84511625766754, 56.880037039518356, 43.137705847620964, 35.67168407142162, 31.037595234811306, 47.34161786735058, 35.977666452527046, 0.053999429364921525, 0.04842405607632827, 0.08676055149408057, 0.007828741436242126, 0.04087912675458938, 0.05029952262702864, 0.04299687483580783, 0.0427785275678616, 0.02490793620381737, 0.02732682925852714, 0.03285822102043312, 0.05891235050512478, 0.02741176063864259, 0.04137553078180645, 0.032971101682051085, 0.06086866662371904, 0.031530069827567786, 0.01659125122387195, 0.01749519451550441, 0.030220149492379278, 0.05033362060203217, 0.018831396155292168, 0.3648654167773202, 53.165873140096664, 67.57602989673615, 56.48709252476692, 42.46182471513748, 50.452066361904144, 64.26037341356277, 9.837710112333298, 0.3582778765121475, 1.0042477562092245, 4.589083576574922, 0.8515123394317925, 0.4771312535740435, 75.73929145932198, 96.71079933643341, 93.86103585362434, 91.09466269612312, 84.52616035938263, 81.76610246300697, 87.54206612706184, 83.89803886413574, 86.66666150093079, 84.17915537953377, 89.74333360791206, 91.51788398623466, 86.65791437029839, 82.92242601513863, 78.19623962044716, 76.34199231863022, 73.71886387467384, 72.48531326651573, 75.42608946561813, 72.2435474395752, 75.73430612683296, 67.69813254475594, 61.44950084388256, 59.056605845689774, 61.963715851306915, 58.641687110066414, 60.63542112708092, 52.039788365364075, 53.00513796508312, 53.937288746237755, 55.11522173881531, 52.678245306015015, 53.96915003657341, 64.52664032578468, 70.71471467614174, 67.9122206568718, 72.51734554767609, 68.43871280550957, 63.608864173293114, 59.449109584093094, 56.87662862241268, 54.14475001394749, 53.7493622303009, 51.82226903736591, 53.45974937081337, 59.19448524713516, 65.44202640652657, 64.24740850925446, 65.8254486322403, 64.41034376621246, 59.420770704746246, 60.291820764541626, 67.28748857975006, 64.56047371029854, 62.51283198595047, 57.29792341589928, 62.811294570565224, 68.3162833750248, 68.76505449414253, 64.06390875577927, 63.29373188316822, 64.79537710547447, 64.50133368372917, 61.57152749598026, 62.085681706666946, 57.72359177470207, 56.861600428819656, 62.64374636113644, 53.64439286291599, 54.854901507496834, 63.24618123471737, 67.34415873885155, 59.14275102317333, 54.04401361942291, 59.115536883473396, 64.74920958280563, 59.295692816376686, 57.639110907912254, 54.050781056284904, 52.924403697252274, 49.31770183146, 48.63604500889778, 55.717565417289734, 61.637438759207726, 65.64261764287949, 70.40813952684402, 64.13689523935318, 65.5142529308796, 67.72986844182014, 60.64686231315136, 62.418741434812546, 55.445526614785194, 50.70627272129059, 50.8204185962677, 49.61609601974487, 51.45310364663601, 50.448293164372444, 50.20402327179909, 51.89985327422619, 49.532644897699356, 57.51864217221737, 66.41723647713661, 69.16653335094452, 67.67309948801994, 70.89437663555145, 64.64590072631836, 56.48354731500149, 53.429578989744186, 55.31491242349148, 54.96940456330776, 56.51139982044697, 55.49761421978474, 59.803239181637764, 60.700291246175766, 64.22571927309036, 64.58362206816673, 68.27842220664024, 70.31607046723366, 71.91171884536743, 72.11455196142197, 77.24559143185616, 72.21941873431206, 73.10876861214638, 76.75485536456108, 77.86375746130943, 75.25603339076042, 88.65135580301285, 24.749702140688896, 0.8740609826054424, 1.3817747170105577, 1.2600531172938645, 0.10042651076219045, 0.07915448033600114, 45.31487502157688, 72.41386190056801, 65.88372990489006, 44.07991848886013, 28.738766089081764, 34.558883383870125, 55.459323674440384, 44.6606033295393, 0.05910148312977981, 0.02840389519406017, 0.01982679244974861, 0.019915445700462442, 0.03645636446890421, 0.03408096497878432, 0.060183790483279154, 0.09788937502889894, 0.008811107472865842, 0.08604423055658117, 0.03220406979380641, 0.11614792223554105, 0.15237458457704633, 0.2585416001966223, 0.16101793327834457, 0.16776473843492568, 0.1290855451952666, 0.12298990783165209, 0.13979133713291958, 0.11460102672572248, 0.2245386052527465, 0.161354333977215, 0.5544996738899499, 62.964696139097214, 77.30286955833435, 56.78574129939079, 60.05391173064709, 63.48764307796955, 75.01680582761765, 11.811442952603102, 0.5534981901291758, 2.3365492466837168, 9.628133308142424, 6.518527418375015, 0.5170119542162865, 80.0874437391758, 99.25562158226967, 95.91537281870842, 95.28248637914658, 87.31834933161736, 84.65868204832077, 91.25398814678192, 88.96778762340546, 90.13642251491547, 87.04864740371704, 92.57601320743561, 96.22382506728172, 91.43649235367775, 85.22010952234268, 83.74231562018394, 80.29055044054985, 78.72454807162285, 76.48180201649666, 81.10199689865112, 75.76819270849228, 78.97340431809425, 69.73869904875755, 66.7694927752018, 63.31277646124363, 66.27932667732239, 61.84770427644253, 63.790186643600464, 53.79968672990799, 56.46154649555683, 56.12902633845806, 57.07480698823929, 54.921025559306145, 55.95963142812252, 67.1584703028202, 73.3983662724495, 70.59144929051399, 76.7600154876709, 73.64163681864738, 67.64618933200836, 62.9714597761631, 62.6057294011116, 59.30460713803768, 57.119207605719566, 55.99131792783737, 56.032302528619766, 63.91253247857094, 67.7835139632225, 68.63123327493668, 72.56766244769096, 67.65033110976219, 62.31800124049187, 64.23640429973602, 71.31186783313751, 66.68723478913307, 66.69536635279655, 62.19985418021679, 65.97005367279053, 70.9432952105999, 70.96451327204704, 65.29454872012138, 67.13420480489731, 69.08654764294624, 67.32952192425728, 62.69442044198513, 63.00822280347347, 57.77177318930626, 57.18039572238922, 64.02056068181992, 55.34887120127678, 58.72771829366684, 64.82307761907578, 67.14253395795822, 62.195947989821434, 58.83671924471855, 61.937972232699394, 67.89383724331856, 63.78327861428261, 61.57405436038971, 57.22689762711525, 54.7753831744194, 52.181140780448914, 52.867980524897575, 59.2518013715744, 63.975951075553894, 67.72349238395691, 71.38727098703384, 68.27773064374924, 70.63302665948868, 68.99191752076149, 64.57862913608551, 64.94036972522736, 57.51104637980461, 54.85252283513546, 53.78166049718857, 54.12637799978256, 54.89899434149265, 53.75517591834068, 53.32869440317154, 55.1504610478878, 50.800511464476585, 60.8402681350708, 69.10259038209915, 73.42773869633675, 70.35165935754776, 74.0223079919815, 66.76915839314461, 60.52682675421238, 55.858800038695335, 58.692102804780006, 60.29358766973019, 59.92802068591118, 59.471304193139076, 63.63211132586002, 63.98086801171303, 68.03326696157455, 66.93998202681541, 72.88179159164429, 74.55011487007141, 75.20839914679527, 75.0290259718895, 81.32640525698662, 74.46269676089287, 73.93336996436119, 81.9977456331253, 82.56915897130966, 80.63384681940079, 91.54782637953758, 25.417381413280964, 1.96159225422889, 10.095684919506311, 1.5549853350967169, 0.15943720325594768, 0.1872569354600273, 56.26114524900913, 80.25300845503807, 71.79697260260582, 59.38938818871975, 47.825426906347275, 42.37760603427887, 64.3690475821495, 53.188983500003815, 0.15492626640480012, 0.12323173665208742, 0.12008316771243699, 0.1650368410628289, 0.13231498596724123, 0.17656384909059852, 0.09728054676088504, 0.2301135443849489, 0.1312330979271792, 0.11428520578192547, 0.20775560347829014], [0.023936346151458565, 0.038685015388182364, 0.06960660946788266, 0.07996172178536654, 0.01979453500098316, 0.06271048419876024, 0.07065587269607931, 0.10371911572292447, 0.07488316812668927, 0.2433078910689801, 0.38889034010935575, 2.950077150017023, 51.54378578066826, 60.1914681494236, 10.966830924153328, 39.176938980817795, 55.12371428310871, 55.541319474577904, 3.9432870922610164, 0.16864048753632233, 0.543706234311685, 1.791692089755088, 0.3655667166458443, 5.796696301549673, 98.00094410777092, 84.08507242798805, 99.56859558820724, 78.74442860484123, 89.72171276807785, 79.66986894607544, 82.49671205878258, 75.31635135412216, 80.93143165111542, 78.93609032034874, 84.98880833387375, 83.34874793887138, 87.80916139483452, 79.68044757843018, 73.8478821516037, 69.25335869193077, 70.78187987208366, 68.04114013910294, 72.23551467061043, 68.40935558080673, 66.26074567437172, 58.62819783389568, 60.94383917748928, 56.25145956873894, 56.91698245704174, 57.070851400494576, 55.10687738656998, 49.01263140141964, 51.28602661192417, 50.67134119570255, 52.573070749640465, 50.70084661245346, 53.27165566384792, 61.52394264936447, 66.74349457025528, 63.67543660104275, 63.20383630692959, 59.146877601742744, 57.071554362773895, 54.94535185396671, 53.40856231749058, 50.059657618403435, 50.18909767270088, 48.791327476501465, 56.08288921415806, 57.50396355986595, 62.021373957395554, 61.39228731393814, 59.155985713005066, 53.79005804657936, 56.24663382768631, 57.25668042898178, 64.77282151579857, 62.00874723494053, 56.353613287210464, 56.16602495312691, 62.39113971590996, 67.51162335276604, 69.30718660354614, 54.71259154379368, 59.68575328588486, 63.316656053066254, 59.247097223997116, 64.65444266796112, 63.06788720190525, 65.35922884941101, 66.46942287683487, 64.70781460404396, 57.09269642829895, 45.82218199968338, 49.57709491252899, 62.3421261459589, 59.21035319566727, 49.752656891942024, 55.591244995594025, 61.50757312774658, 61.1625250428915, 57.72579565644264, 55.56460842490196, 53.35522457957268, 49.016940370202065, 47.70340405404568, 47.942187041044235, 61.07081696391106, 55.59590354561806, 61.03821471333504, 67.69538909196854, 63.903192579746246, 61.510791555047035, 61.75458647310734, 60.01546159386635, 60.09181849658489, 53.21642942726612, 45.14408938586712, 47.2931856662035, 44.9109148979187, 47.59918324649334, 47.799383103847504, 51.71432822942734, 49.54448126256466, 52.65189751982689, 61.86857655644417, 62.390486150979996, 66.93683579564095, 62.71302044391632, 56.00108340382576, 51.31411470472813, 52.99842372536659, 51.52233973145485, 52.71400898694992, 52.70976081490517, 55.24259850382805, 56.29077225923538, 59.975343346595764, 59.11310501396656, 62.913889065384865, 65.90424120426178, 67.6165509223938, 70.31118392944336, 72.06375628709793, 75.13915926218033, 69.27009299397469, 72.42550447583199, 77.04616293311119, 74.19225007295609, 74.34373274445534, 78.04799437522888, 63.507120832800865, 0.2551863208645955, 1.9372441107407212, 1.4787742495536804, 0.39342797943390906, 0.29133838252164423, 17.18122836202383, 73.07235896587372, 56.85101419687271, 46.97146832942963, 38.94390128552914, 36.88438139855862, 50.09102873504162, 33.10043424367905, 0.12513215420767665, 0.016971251243376173, 0.07754672871669754, 0.025332988298032433, 0.06393618561560288, 0.022951933642616495, 0.02228170935268281, 0.08448844411759637, 0.029475940500560682, 0.0069534492195089115, 0.03959249130275566, 0.08309467593790032, 0.04167876861174591, 0.08375947698368691, 0.04905854781100061, 0.027441168240329716, 0.1491253581480123, 0.062149461373337545, 0.18032321298960596, 0.1370275198132731, 0.26433198479935527, 0.5915232840925455, 4.624388907104731, 64.22833353281021, 68.34437146782875, 22.065402679145336, 38.983061984181404, 60.251508727669716, 63.81126031279564, 3.1995000410825014, 0.2203334035584703, 2.0730091631412506, 2.1809103107079864, 0.08805309073068202, 8.756870459765196, 103.75261187553406, 86.03478580713272, 102.59872019290924, 80.73752045631409, 92.4183140695095, 82.951730042696, 84.78028312325478, 76.75939992070198, 81.28283679485321, 83.01074087619781, 88.79135549068451, 86.25693708658218, 90.35858139395714, 80.34457594156265, 77.11727231740952, 72.71301224827766, 75.03954380750656, 70.23014187812805, 74.35815677046776, 69.74047735333443, 68.12409728765488, 61.30589134991169, 63.53256046772003, 57.907224521040916, 59.655970484018326, 60.0952535122633, 57.48934954404831, 53.355950340628624, 53.84581245481968, 53.94676923751831, 57.45082341134548, 52.61997163295746, 56.83132745325565, 65.2045239508152, 68.45303803682327, 66.21602967381477, 66.39135986566544, 63.676325753331184, 59.81669045984745, 57.01054483652115, 56.58452309668064, 52.93562449514866, 54.296658262610435, 52.041494473814964, 59.85121540725231, 62.125089392066, 65.250144302845, 62.748198956251144, 63.0971722304821, 55.77933870255947, 58.28438088297844, 59.55371417105198, 66.98931097984314, 65.47693893313408, 58.60482148826122, 58.908402398228645, 62.145878076553345, 69.66356948018074, 71.82342678308487, 55.758230835199356, 60.861649587750435, 64.23200413584709, 60.965110436081886, 69.49141591787338, 66.06759443879128, 69.27608147263527, 67.90558621287346, 66.90038055181503, 59.64806690812111, 49.25537757575512, 48.32549147307873, 63.35209675133228, 61.51128552854061, 52.37256310880184, 59.10666435956955, 64.01513457298279, 64.67515155673027, 61.15367911756039, 58.90668109059334, 56.60308510065079, 51.71937055885792, 50.533093214035034, 52.12687589228153, 62.32552483677864, 58.733398988842964, 62.0624003559351, 68.66217881441116, 67.07013264298439, 63.460592329502106, 65.89341938495636, 63.343041837215424, 62.79562421143055, 57.19507433474064, 49.49677102267742, 50.16684986650944, 47.569130659103394, 50.246425196528435, 49.85907398164272, 53.52626100182533, 53.225624933838844, 54.8992945253849, 63.76088261604309, 66.63853660225868, 69.23898786306381, 63.57227213680744, 57.66253665089607, 53.84443312883377, 56.150415390729904, 54.223022013902664, 56.78852654993534, 55.56086182594299, 59.71797175705433, 59.939697459340096, 64.31389734148979, 62.39221125841141, 65.8161923289299, 66.61050170660019, 70.79838618636131, 71.89938470721245, 77.55763828754425, 75.56950137019157, 72.73084089159966, 75.1211254298687, 82.01745137572289, 75.23164629936218, 79.22324851155281, 76.79274693131447, 73.10219496488571, 0.7515939697623253, 0.6391672056633979, 3.8241896079853177, 1.5100798197090626, 0.34049215901177377, 16.35631922632456, 82.97901257872581, 64.83927994966507, 54.005160704255104, 32.10711434483528, 47.12222903966904, 56.73065185546875, 40.891068801283836, 0.04690124696935527, 0.021141037650522776, 0.06243131050723605, 0.05345361314539332, 0.06384243752108887, 0.07004685146966949, 0.12297133187530562, 0.03405707895581145, 0.033682517023407854, 0.04341965039202478, 0.007952570631459821, 0.16317323403200135, 0.26449700875673443, 0.21207295852946118, 0.16046559729147702, 0.14284885197412223, 0.37222805607598275, 0.13349105254746974, 0.2646087761968374, 0.22840470483060926, 0.41079500690102577, 0.820773591985926, 5.182172851637006, 75.21270051598549, 78.18794846534729, 18.182343542575836, 54.45973791182041, 74.46514382958412, 70.48586055636406, 5.112111736088991, 0.41894595546182245, 3.1304596457630396, 10.458417255431414, 2.4087980948388577, 8.001390248537064, 108.28199923038483, 91.74046844244003, 107.6378121972084, 84.36186477541924, 95.49732685089111, 85.95885828137398, 91.9212855398655, 82.64883309602737, 88.00994262099266, 87.30476886034012, 92.61086493730545, 89.7250109910965, 92.25082665681839, 83.67741510272026, 81.67375981807709, 76.31996110081673, 78.79270121455193, 74.17002126574516, 80.14613538980484, 73.02011936903, 73.10452044010162, 63.480529859662056, 68.30312088131905, 60.32053962349892, 65.01622125506401, 63.035657331347466, 60.28208948671818, 56.88432700932026, 58.300438821315765, 55.612022280693054, 59.660009667277336, 55.763873532414436, 60.785904452204704, 68.41396853327751, 72.45193585753441, 70.03562271595001, 70.43056592345238, 66.33291900157928, 64.31832790374756, 62.785440757870674, 61.4180613309145, 56.390581503510475, 57.09095612168312, 56.57199516892433, 64.41618785262108, 64.344941675663, 70.37564367055893, 67.14033767580986, 66.97766080498695, 59.12010423839092, 62.87579230964184, 62.744049578905106, 71.57568007707596, 70.97192287445068, 64.59364593029022, 59.569069147109985, 64.84681874513626, 73.29250395298004, 74.65796828269958, 56.8496310710907, 64.56260919570923, 66.55086770653725, 62.18375064432621, 70.60309186577797, 68.47856506705284, 72.57895544171333, 72.25233256816864, 68.66691336035728, 62.972903698682785, 48.325343281030655, 48.39316964149475, 67.16366082429886, 63.58435928821564, 53.798774778842926, 62.57136024534702, 67.93561980128288, 67.02157884836197, 63.55118706822395, 61.35647803544998, 59.67892125248909, 53.93882006406784, 53.279323652386665, 53.79598192870617, 66.69678747653961, 64.70669746398926, 66.08962565660477, 69.50375765562057, 69.66651052236557, 67.42175817489624, 68.40346589684486, 66.43901690840721, 66.11231803894043, 59.296600967645645, 50.22791638970375, 54.26277168095112, 49.7390878200531, 54.44456532597542, 52.928161695599556, 57.18752793967724, 55.32705657184124, 59.474689811468124, 66.61405071616173, 69.40806359052658, 74.6891038119793, 67.82151952385902, 61.67683504521847, 56.48789428174496, 59.11614865064621, 57.49667175114155, 59.31502237915993, 58.36017541587353, 60.421716794371605, 62.48023733496666, 67.4603945016861, 64.39110159873962, 68.81037086248398, 70.2508507668972, 74.38531011343002, 75.95593303442001, 80.41667327284813, 79.89179223775864, 74.07346084713936, 77.15431272983551, 85.50938040018082, 78.96233931183815, 81.52818202972412, 83.6674976348877, 73.96223321557045, 0.5589677591342479, 6.82723805308342, 9.13033151999116, 1.353737327735871, 0.45080463343765587, 23.24289109557867, 91.28285139799118, 70.82822978496552, 65.85453987121582, 55.88041327893734, 51.98939926922321, 67.30537042021751, 50.8575502038002, 0.27772923465818167, 0.13841677573509514, 0.23418420954840258, 0.09884733182843775, 0.098898710712092, 0.23224873293656856, 0.18083266768371686, 0.16741723520681262, 0.11245274668908678, 0.07953325024573132, 0.1407465702504851], [0.006561244117619935, 0.0355729044531472, 0.0572295009624213, 0.06036440325260628, 0.038645919048576616, 0.015704395882494282, 0.07188726638560183, 0.07875366864027455, 0.08387698864680715, 0.17125756741734222, 0.5068213760387152, 9.935819897800684, 61.629360392689705, 34.8254656791687, 30.91578707098961, 53.276382610201836, 49.824989810585976, 55.53335890173912, 0.1319374406011775, 0.11172549391631037, 1.0269473819062114, 5.4644459299743176, 0.968922832980752, 27.601969689130783, 103.8939642906189, 84.07939553260803, 95.4600964486599, 85.90666428208351, 82.25295513868332, 78.75269696116447, 82.34827682375908, 73.11829090118408, 73.90579864382744, 68.44692036509514, 75.95679178833961, 81.12304016947746, 84.17350128293037, 79.23467829823494, 72.73305237293243, 67.20634773373604, 65.98706156015396, 64.37409371137619, 63.61909322440624, 60.797113850712776, 58.97347770631313, 59.00842823088169, 60.19336424767971, 56.562358886003494, 58.58295366168022, 56.040320098400116, 52.28042185306549, 48.709229081869125, 49.661237597465515, 49.89898703992367, 53.251170963048935, 51.600429341197014, 55.04223145544529, 57.957841604948044, 63.58013391494751, 63.53886812925339, 59.2082405090332, 57.11192339658737, 55.74570670723915, 52.03053966164589, 51.56461626291275, 51.062302216887474, 48.552111312747, 51.01809158921242, 57.52366170287132, 59.64704476296902, 61.72194242477417, 58.776876255869865, 61.0769422352314, 52.24280387163162, 55.081262961030006, 61.27895459532738, 62.96286463737488, 58.640949949622154, 55.033077746629715, 55.68191573023796, 61.39821119606495, 65.04335179924965, 57.8824270516634, 52.00489103794098, 54.795484095811844, 64.28614363074303, 62.67299719154835, 60.33193141222, 60.91553449630737, 56.23041249811649, 55.88091105222702, 59.13733631372452, 59.20817971229553, 58.79883907735348, 53.100281059741974, 53.47542732954025, 60.30670836567879, 49.7767324000597, 51.69392712414265, 56.682181656360626, 60.87350495159626, 58.15972097218037, 57.49779649078846, 59.07835587859154, 54.15008872747421, 44.999491944909096, 47.80261293053627, 54.98192109167576, 59.48627918958664, 50.79051420092583, 56.58126287162304, 64.53363195061684, 64.40434768795967, 59.04191583395004, 62.29585602879524, 61.10865153372288, 59.245159327983856, 53.21729578077793, 47.19440616667271, 45.65065540373325, 45.96485674381256, 46.204426288604736, 48.24769824743271, 49.28393304347992, 51.000768318772316, 60.36789268255234, 60.54207533597946, 63.528756871819496, 56.60872399806976, 53.38450960814953, 50.01852862536907, 53.554037511348724, 51.30107380449772, 55.147368013858795, 53.79488378763199, 61.0082571208477, 61.38580486178398, 64.38165530562401, 64.66786354780197, 66.3078099489212, 65.75386807322502, 71.70679584145546, 70.35339206457138, 78.35713818669319, 68.45158651471138, 71.15623578429222, 74.87489864230156, 77.03599467873573, 70.13098999857903, 79.58128809928894, 69.80233803391457, 86.30468532443047, 15.096341036260128, 0.5982270743697882, 2.695805481635034, 0.4674130672356114, 0.114392030518502, 2.7207817789167166, 65.49143895506859, 63.05106930434704, 52.56460100412369, 42.327034547924995, 31.218896806240082, 43.532774448394775, 37.07236871123314, 0.19349005568074062, 0.02346971523365937, 0.052145982335787266, 0.015792546328157187, 0.04840854890062474, 0.0789615664689336, 0.028621424244192895, 0.04015942904516123, 0.06240320537472144, 0.03481631458271295, 0.05697437285562046, 0.032044482068158686, 0.08500396215822548, 0.046751618865528144, 0.03146721363009419, 0.03120819295872934, 0.1316449453588575, 0.09423286537639797, 0.07155198632972315, 0.08489669213304296, 0.22779773193178698, 0.789795279270038, 15.825593154877424, 71.86229109764099, 46.69328525662422, 33.22429619729519, 37.80978374183178, 61.03426672518253, 58.741709142923355, 0.17003391432808712, 0.26274646050296724, 2.243224116973579, 8.813057094812393, 1.157811291050166, 31.82272620499134, 108.18878263235092, 86.29469946026802, 99.86809551715851, 86.67264237999916, 88.9887472987175, 80.6275999546051, 85.75120702385902, 74.91025194525719, 77.41623267531395, 70.69181710481644, 79.08938929438591, 83.35731267929077, 86.5076020359993, 81.11125320196152, 75.8979557454586, 71.30299150943756, 70.32544076442719, 65.4596346616745, 68.20668965578079, 62.60191060602665, 61.98555327951908, 57.95806959271431, 60.2420624345541, 59.0035492926836, 60.15589825809002, 59.49590787291527, 54.497025310993195, 52.13732533156872, 54.26145315170288, 53.243917152285576, 56.359514370560646, 54.50779773294926, 59.77528028190136, 62.56197474896908, 65.3549274802208, 66.0325375199318, 63.657710552215576, 60.469001457095146, 57.84086488187313, 55.24855278432369, 55.40043443441391, 53.07677552103996, 52.846868857741356, 54.10201370716095, 60.33482685685158, 62.634269669651985, 63.98073121905327, 62.526959627866745, 63.500775173306465, 56.487540900707245, 58.30363065004349, 63.053930550813675, 65.29063493013382, 63.185346499085426, 59.74043235182762, 56.6070406883955, 63.26628975570202, 66.92879542708397, 55.47141082584858, 52.246117293834686, 55.163232162594795, 65.28001829981804, 63.01437467336655, 60.637298226356506, 60.52841506898403, 57.50785835087299, 57.73262768983841, 59.36210945248604, 62.06089563667774, 58.60181204974651, 57.28100672364235, 53.12668204307556, 60.200321674346924, 50.99197939038277, 55.38541004061699, 60.47198049724102, 63.37948188185692, 59.15791600942612, 60.36549121141434, 60.952856093645096, 57.76456877589226, 48.40225115418434, 49.42375034093857, 56.923229321837425, 60.4940041154623, 56.78858734667301, 58.87956954538822, 64.54024359583855, 66.53468057513237, 63.37081454694271, 66.06620371341705, 61.99488937854767, 62.186516895890236, 57.59917125105858, 49.89984579384327, 48.06936241686344, 49.96511869132519, 49.288747385144234, 50.76130136847496, 49.61266480386257, 53.34491953253746, 61.34695954620838, 62.68566191196442, 65.69584518671036, 59.65429097414017, 55.75598135590553, 52.527142614126205, 55.13735935091972, 54.001440703868866, 58.60813111066818, 58.06279957294464, 62.36191168427467, 64.25646722316742, 66.92081585526466, 67.47547209262848, 69.85504120588303, 68.00251141190529, 75.45204967260361, 72.49287486076355, 78.86061117053032, 69.64843109250069, 72.03669413924217, 75.91499403119087, 78.01223069429398, 72.93993607163429, 81.91304057836533, 72.7425442636013, 87.60560631752014, 22.11159110069275, 0.7806216808967292, 2.4493713676929474, 2.331761266104877, 0.11498093212139793, 2.0765204122290015, 72.3784402012825, 69.11072194576263, 61.89283065497875, 35.90745002031326, 39.02762599289417, 54.4004762917757, 45.98134025931358, 0.5589447228703648, 0.023059951381583232, 0.06388673631590791, 0.0336262028577039, 0.043061660617240705, 0.02263666745420778, 0.04539446083072107, 0.0646504433825612, 0.0075591474796965485, 0.020371738501125947, 0.011774049507948803, 0.15522170055191964, 0.12203140926430933, 0.1480463644838892, 0.2120485863997601, 0.23880305467173457, 0.2636124874697998, 0.20583465811796486, 0.15448546037077904, 0.15989553881809115, 0.5284662020858377, 0.9235819440800697, 17.006253451108932, 87.60800778865814, 50.49819968640804, 39.3601955473423, 69.26265299320221, 70.58774828910828, 68.93786162137985, 0.3070098697207868, 0.506033452693373, 3.6849655536934733, 13.224321138113737, 2.114445702172816, 31.743169873952866, 113.49627703428268, 87.73545295000076, 104.7616021335125, 91.51610568165779, 91.13516092300415, 85.61107814311981, 91.71423465013504, 78.9394873380661, 83.13108801841736, 74.4327087700367, 82.45993763208389, 88.52257311344147, 92.39698961377144, 85.5500154197216, 81.44646361470222, 74.39487040042877, 72.92053431272507, 69.99002516269684, 71.49498000741005, 67.82297104597092, 64.83598932623863, 62.343904450535774, 64.20780703425407, 63.55445109307766, 63.65478090941906, 62.14329421520233, 59.90235686302185, 55.8798661082983, 57.805393785238266, 57.63241566717625, 60.43542645871639, 58.59637074172497, 60.60642868280411, 63.19034703075886, 69.837356954813, 70.725057721138, 66.93204045295715, 62.16502524912357, 62.628216594457626, 59.02440257370472, 58.955865651369095, 58.374683037400246, 54.78483326733112, 57.47226186096668, 63.92455503344536, 65.096814930439, 69.32226419448853, 68.4262190759182, 69.89963561296463, 59.69789743423462, 62.25527800619602, 67.26772964000702, 69.94206413626671, 66.29913121461868, 61.74142397940159, 59.384136870503426, 64.91715297102928, 70.73274090886116, 57.36421845853329, 55.903322249650955, 56.252683103084564, 67.05726653337479, 66.15223869681358, 61.96672908961773, 63.4638487547636, 58.49707446992397, 58.737730756402016, 63.730837628245354, 63.81339579820633, 60.83724729716778, 55.67703299224377, 55.100470930337906, 65.00130325555801, 51.53163783252239, 57.178898602724075, 63.61693874001503, 67.62101948261261, 63.74375693500042, 63.07302072644234, 64.1104182600975, 59.03568036854267, 50.741694420576096, 54.222885221242905, 62.532438933849335, 64.8792690038681, 58.81273113191128, 62.90915071964264, 68.916727155447, 67.75985643267632, 65.34388527274132, 70.17871543765068, 65.93665346503258, 64.4096066057682, 61.129014641046524, 52.977768033742905, 52.35723473131657, 52.49105215072632, 53.28025080263615, 53.4897031635046, 53.565254509449005, 56.57877020537853, 66.70735090970993, 66.35786086320877, 67.79749721288681, 62.955572828650475, 58.12458045780659, 54.589200764894485, 59.51695494353771, 55.310793444514275, 62.23287060856819, 60.02312198281288, 66.10015869140625, 67.46438428759575, 69.76505443453789, 72.3985943198204, 73.89171659946442, 72.3653993010521, 80.28168931603432, 76.95872962474823, 84.43216100335121, 71.33516058325768, 73.18332061171532, 80.09597048163414, 82.95106887817383, 77.27822408080101, 86.59476175904274, 75.46703606843948, 92.53547698259354, 20.492283292114735, 0.9349345474038273, 8.49058834835887, 2.065528789535165, 0.15679230768000707, 4.366707634180784, 80.50293624401093, 76.31977871060371, 69.4633050262928, 58.526959866285324, 41.65252514183521, 58.65407444536686, 54.161066338419914, 0.5331379326526076, 0.2989152946975082, 0.28965593373868614, 0.15799341432284564, 0.22027846978744492, 0.10871293838135898, 0.11610524874413386, 0.15441566880326718, 0.2615432016318664, 0.16408049472374842, 0.1488410116871819], [0.03505115237203427, 0.042304799862904474, 0.021085675289214123, 0.06959486127016135, 0.0421903272945201, 0.05004911457945127, 0.055034083416103385, 0.11417144938604906, 0.046253192485892214, 0.11096787246060558, 0.23001261230092496, 24.386310540139675, 72.17534869909286, 26.37334931641817, 46.830438897013664, 48.769752234220505, 62.47249335050583, 38.81050564348698, 0.3978749876841903, 0.7607607403770089, 2.510209190659225, 12.658638842403889, 1.417660228908062, 61.489892676472664, 107.12199747562408, 90.46082630753517, 96.14411294460297, 77.99374848604202, 81.958546936512, 80.45683711767197, 77.13599011301994, 75.45184448361397, 74.40018251538277, 66.26755490899086, 61.15206800401211, 67.62443169951439, 70.5780816078186, 67.03269705176353, 66.00404664874077, 62.48690217733383, 61.161111518740654, 57.91932687163353, 58.12794327735901, 57.233178690075874, 57.55621835589409, 56.38061083853245, 59.34221372008324, 59.09725986421108, 57.27822907269001, 52.210555002093315, 47.43358813226223, 50.410751178860664, 51.52330867946148, 51.00285440683365, 53.34801636636257, 50.25183230638504, 56.30273021757603, 60.590606331825256, 62.97831080853939, 57.94938325881958, 57.701769545674324, 55.1444573700428, 52.39938586950302, 55.49125336110592, 53.91842655837536, 50.37730157375336, 51.09821029007435, 54.83730465173721, 57.6722527295351, 57.22723200917244, 56.986153945326805, 57.63705901801586, 54.65404808521271, 51.09260559082031, 57.95931972563267, 62.58175648748875, 60.545259565114975, 59.10392090678215, 56.64873585104942, 56.61039970815182, 57.823100835084915, 57.91656441986561, 57.24127985537052, 55.98229341208935, 66.28675147891045, 66.84244126081467, 58.69738072156906, 59.60995115339756, 61.17464259266853, 61.32918789982796, 63.586555570364, 62.33258105814457, 64.185099452734, 59.18228790163994, 63.02505210042, 55.364233776926994, 49.46343161165714, 46.04213319718838, 53.11181724071503, 59.496686831116676, 60.336050391197205, 60.41812978684902, 59.37516175210476, 60.40948145091534, 60.21935485303402, 51.62649214267731, 44.23678547143936, 49.341545552015305, 53.66850256919861, 56.66045442223549, 51.61957651376724, 53.98571714758873, 59.90388058125973, 67.94908627867699, 61.14311568439007, 62.15953454375267, 60.23852102458477, 57.868367806077, 49.07687075436115, 46.28844358026981, 46.399226635694504, 46.33153326809406, 47.41036757826805, 50.0508838891983, 48.88209320604801, 53.144031912088394, 54.81359392404556, 56.31218031048775, 51.42396681010723, 51.17461659014225, 52.37409442663193, 52.79641516506672, 52.77586966753006, 57.990326061844826, 60.41947491466999, 63.691445142030716, 65.60737073421478, 66.22783944010735, 65.87150976061821, 67.16707304120064, 71.9968418776989, 71.79908528923988, 75.85099026560783, 73.52475509047508, 68.29534649848938, 78.95890429615974, 72.50967755913734, 76.11582085490227, 70.5976277589798, 72.41670414805412, 71.93577915430069, 81.78086087107658, 51.411777064204216, 0.03518419347528834, 1.9890456623397768, 1.70771588338539, 0.20325177640188485, 0.058099153320654295, 40.20381107926369, 74.15344655513763, 51.416021436452866, 47.46350772678852, 36.295025423169136, 39.32114504277706, 48.4614671766758, 1.1941620404832065, 0.05968442157609388, 0.057934385404223576, 0.03230452319257893, 0.020278038646210916, 0.00659868361253757, 0.04339617626101244, 0.017075545256375335, 0.052747262961929664, 0.030606118234572932, 0.04409356501128059, 0.035195296004530974, 0.08671300209243782, 0.0770734240359161, 0.019087438959104475, 0.06882573652546853, 0.034749855258269235, 0.044675701938103884, 0.06975817828788422, 0.016942151632974856, 0.018428458206471987, 0.12664940091781318, 34.66806672513485, 78.0205750465393, 42.726594507694244, 42.43125915527344, 42.71561689674854, 75.74121415615082, 38.44319835305214, 0.32619064673781395, 0.5271097936201841, 4.210207331925631, 17.055210024118423, 3.47147258464247, 67.4459932744503, 107.96840205788612, 91.26956731081009, 98.21912840008736, 80.59296861290932, 86.17828130722046, 82.47370809316635, 82.64332339167595, 78.39448258280754, 76.58706396818161, 69.5177561044693, 64.31116908788681, 69.66984674334526, 73.53910312056541, 69.2286828160286, 68.22549864649773, 65.92588484287262, 64.56003293395042, 61.66546605527401, 60.356949269771576, 58.55673886835575, 59.56250309944153, 59.00256894528866, 63.568400144577026, 61.06629140675068, 61.67277306318283, 55.634524673223495, 49.98667113482952, 53.772328197956085, 55.00874005258083, 56.121962517499924, 54.90444704890251, 53.912799060344696, 57.38821417093277, 62.25132241845131, 65.3719961643219, 61.17162175476551, 60.74298955500126, 58.869762271642685, 56.656514033675194, 59.64760713279247, 56.29093565046787, 53.44927333295345, 54.052076786756516, 57.834618017077446, 61.48068577051163, 61.10191069543362, 59.61239442229271, 59.81423579156399, 57.265963330864906, 54.259458258748055, 60.79557113349438, 65.3941261768341, 63.42982538044453, 63.31390880048275, 59.573879688978195, 58.24984833598137, 58.19164305925369, 60.61468183994293, 59.812544882297516, 60.03511793911457, 69.26841348409653, 68.40978875756264, 62.63853684067726, 60.608545169234276, 61.51380859315395, 64.511479139328, 65.61617106199265, 64.16562929749489, 66.40295684337616, 61.225221678614616, 64.87955778837204, 56.948611959815025, 51.48797817528248, 47.58392706513405, 52.843171656131744, 60.11834107339382, 64.69700038433075, 65.14594629406929, 62.91428044438362, 64.38754498958588, 62.559493482112885, 54.587460458278656, 47.36407846212387, 51.89954549074173, 56.38890579342842, 61.722907572984695, 56.66753724217415, 56.82152397930622, 61.788036078214645, 68.3050511777401, 63.082212433218956, 65.21761804819107, 64.04128476977348, 61.09452769160271, 51.75907462835312, 48.82003493607044, 49.6814639121294, 47.27866664528847, 49.11490671336651, 51.83202691376209, 51.39286547899246, 53.85671027004719, 57.65612259507179, 57.49722272157669, 54.99160297214985, 54.70681585371494, 55.67388296127319, 54.356778636574745, 54.96911197900772, 58.54464031755924, 64.28422093391418, 66.61133006215096, 69.7784373164177, 68.1916044652462, 70.25901272892952, 69.89612460136414, 74.7482742369175, 72.25931659340858, 78.06296557188034, 72.45341017842293, 70.30823528766632, 78.96695226430893, 75.69370150566101, 77.06945568323135, 74.42420482635498, 73.39649677276611, 76.94282367825508, 82.3202495276928, 62.706310003995895, 0.08637760329293087, 1.3831361127085984, 4.086510194465518, 0.5864859418943524, 0.19631198316346854, 43.399344608187675, 80.88949710130692, 60.42517840862274, 45.991424918174744, 29.5676327124238, 48.14666546881199, 57.89224952459335, 2.166004660539329, 0.13022508326685056, 0.07070471343467943, 0.005862937423444237, 0.030495900027744938, 0.05835239637235645, 0.04039360261231195, 0.049611421854933724, 0.06292534337262623, 0.01718973395327339, 0.04585422502714209, 0.12510230502812192, 0.34704101854003966, 0.1650992111535743, 0.16550730331800878, 0.14446568005951121, 0.16745753382565454, 0.13589749607490376, 0.18344925774727017, 0.12150147871579975, 0.2750947588356212, 0.4253069031983614, 36.66714325547218, 94.42839100956917, 36.871492490172386, 59.080282375216484, 71.79992124438286, 80.26069924235344, 49.69726346433163, 0.48790854401886463, 1.6522573842667043, 5.891500739380717, 26.96928843855858, 5.479465574026108, 67.13767781853676, 111.72570884227753, 93.95735308527946, 105.7836864888668, 86.02913171052933, 89.57621857523918, 87.69548669457436, 84.84017550945282, 83.89008209109306, 81.6299557685852, 71.00773975253105, 65.00910803675652, 73.1656363606453, 76.83490186929703, 73.23166161775589, 71.5192075073719, 68.67609366774559, 70.59002816677094, 63.89029607176781, 65.70619583129883, 61.333208084106445, 64.88148808479309, 62.34733946621418, 66.82458981871605, 63.92602175474167, 66.02127492427826, 58.384912088513374, 53.267035111784935, 56.853195279836655, 60.96656195819378, 57.65366792678833, 58.49520497024059, 54.769090712070465, 59.9363574385643, 65.47037288546562, 67.82238587737083, 65.18200635910034, 63.83998677134514, 62.20228984951973, 59.00952257215977, 63.77269238233566, 60.35725325345993, 57.927401438355446, 58.325221091508865, 61.72781690955162, 63.541053012013435, 64.78609040379524, 63.38534116744995, 62.22728110849857, 61.6869843006134, 58.940533474087715, 64.88319039344788, 69.6666245162487, 67.26060882210732, 66.63007065653801, 62.48887047171593, 58.92323300242424, 59.95138183236122, 61.077341213822365, 59.31282989680767, 60.922894701361656, 70.40685519576073, 71.70952409505844, 61.53862126171589, 62.34307609498501, 62.40877076983452, 65.92883348464966, 65.94375148415565, 66.29035368561745, 70.10656490921974, 62.084720358252525, 68.6321148276329, 56.03476099669933, 52.93619066476822, 51.17335505783558, 55.94797745347023, 64.18076768517494, 68.95474031567574, 66.35705530643463, 65.0257283449173, 65.69467484951019, 65.21703287959099, 57.95971870422363, 51.52380645275116, 56.471805945038795, 60.89992493391037, 62.75756165385246, 60.05818650126457, 62.295396253466606, 64.37129706144333, 69.8537340760231, 63.50153133273125, 68.2924434542656, 67.17794805765152, 64.67785701155663, 54.71104122698307, 52.334492951631546, 53.99633377790451, 51.439979150891304, 51.8041668087244, 54.54566650092602, 53.159827664494514, 56.471308171749115, 61.93878538906574, 61.01103097200394, 58.1609483063221, 56.53253808617592, 57.501041516661644, 56.46046735346317, 57.51177594065666, 62.935422509908676, 65.91399148106575, 71.17949053645134, 72.62577652931213, 70.54068401455879, 71.98529809713364, 71.85058012604713, 77.98560172319412, 77.29232892394066, 81.4140285551548, 75.4278601706028, 71.49901539087296, 83.69816198945045, 78.89147311449051, 81.63462951779366, 76.05232626199722, 78.33954513072968, 80.43992042541504, 87.37031534314156, 60.94630524516106, 0.15558977611362934, 5.7984717562794685, 6.892283912748098, 0.3634378215065226, 0.4957503138575703, 53.00763443112373, 88.18629115819931, 66.41900718212128, 67.49373391270638, 50.38465037941933, 53.95314909517765, 69.45019572973251, 2.358526079915464, 0.2824997896095738, 0.2128266094950959, 0.17974003334529698, 0.11487580690300092, 0.07592241236125119, 0.11713317522662692, 0.13880770944524556, 0.21754180022981018, 0.14530518266838044, 0.24988067743834108], [0.012583291045302758, 0.002639090589582338, 0.059835467181983404, 0.022831381029391196, 0.03652238221548032, 0.0426547002280131, 0.019561918088584207, 0.02813179416989442, 0.05890233522222843, 0.08167034611687995, 0.2418194990605116, 48.51782575249672, 56.36652499437332, 22.228393033146858, 49.65183310210705, 39.225226789712906, 75.45348599553108, 17.793759293854237, 0.28366077574901283, 0.48265194171108305, 2.0095620676875114, 0.20553049631416798, 5.91286176815629, 103.05764436721802, 82.67256662249565, 93.3757258951664, 81.17931514978409, 85.91665774583817, 78.05336728692055, 78.51992145180702, 74.82782676815987, 75.31932279467583, 71.05805665254593, 64.95119914412498, 62.4903903901577, 61.1232503503561, 60.28841994702816, 61.989706456661224, 59.764857441186905, 59.37470197677612, 56.45545542240143, 59.17921766638756, 56.16532199084759, 59.5349507778883, 56.18614487349987, 59.56682346761227, 55.867262184619904, 58.047847375273705, 56.917510628700256, 49.19824384152889, 47.63281524181366, 50.81553965806961, 49.01535585522652, 51.72310955822468, 51.76156349480152, 52.64072231948376, 55.741412937641144, 57.1279813349247, 58.73470611870289, 59.00949977338314, 56.60891018807888, 58.5897932946682, 55.73752574622631, 55.84386304020882, 53.1183110922575, 50.09966567158699, 51.445640847086906, 56.65401376783848, 56.436741426587105, 55.37583075463772, 56.90556786954403, 53.41980591416359, 51.77488937973976, 54.52149599790573, 55.636128187179565, 60.60361683368683, 59.91274170577526, 57.64619752764702, 55.552760660648346, 55.710953772068024, 56.84304982423782, 60.79894155263901, 64.49105143547058, 64.00796055793762, 61.56678155064583, 59.71922188997269, 59.66077722609043, 59.04679097235203, 54.54005420207977, 56.66098639369011, 59.87211048603058, 55.76440170407295, 60.39876602590084, 58.129664584994316, 61.80109977722168, 60.23186378180981, 50.8755574375391, 51.536854952573776, 47.508744299411774, 49.25258092582226, 58.27692188322544, 59.38526540994644, 59.545958787202835, 58.158064261078835, 59.04766492545605, 55.15713348984718, 48.06475326418877, 45.68193532526493, 51.08939476311207, 54.16959688067436, 57.35232129693031, 54.40461426973343, 51.84366188943386, 56.96175165474415, 65.60562282800674, 61.43983416259289, 61.88898526132107, 58.87553796172142, 52.658797949552536, 45.89590564370155, 46.06885336339474, 43.84925566613674, 46.423305943608284, 46.39861486852169, 49.67531964182854, 47.89264149963856, 51.71442702412605, 51.716007739305496, 51.52637891471386, 50.99858723580837, 51.48758679628372, 53.387807831168175, 55.585822686553, 62.36371658742428, 68.18143621087074, 67.45743826031685, 69.16055247187614, 68.08271750807762, 70.42369589209557, 68.65932136774063, 73.90345796942711, 70.58363690972328, 72.47715890407562, 69.1027119755745, 74.15201783180237, 74.39641311764717, 75.28821766376495, 69.60699811577797, 69.39569905400276, 70.133535861969, 79.18616250157356, 68.76677200198174, 88.30780103802681, 5.25198033079505, 6.51753282174468, 7.305983863770962, 0.23157233954407275, 0.1608173456043005, 15.760508347302675, 78.94487544894218, 56.068419590592384, 42.45678998529911, 37.15287119150162, 34.828205332159996, 46.93196564912796, 2.5718879560008645, 0.20421267952769995, 0.03924770433513913, 0.13487640477251261, 0.003946646720578428, 0.08829126818454824, 0.04506573764956556, 0.06524304088088684, 0.041303713151137345, 0.011627611711446662, 0.01975474846403813, 0.017706209364405368, 0.03015205558767775, 0.0404284724208992, 0.025232798361685127, 0.02040552662947448, 0.0707034814695362, 0.02158371760742739, 0.05756541184382513, 0.05553101436817087, 0.1308583578793332, 0.709755839779973, 60.090936943888664, 64.51525613665581, 28.39591808617115, 42.0018669962883, 44.323629811406136, 88.53723272681236, 17.409332022070885, 0.3231180366128683, 0.721847265958786, 4.609934957697988, 0.49313077004626393, 7.362260743975639, 107.66294404864311, 85.01242786645889, 98.18921640515327, 84.35666665434837, 87.56511569023132, 79.92703914642334, 84.72944185137749, 77.86277711391449, 78.71183395385742, 74.10770460963249, 68.77374082803726, 65.74575930833817, 65.31749948859215, 62.28829063475132, 64.10143554210663, 62.549606412649155, 63.18098433315754, 59.63004067540169, 61.74352906644344, 59.60362069308758, 62.36022837460041, 58.92087332904339, 61.02423906326294, 58.3081030100584, 60.89596174657345, 60.171921998262405, 53.120674565434456, 50.83212196826935, 53.78703720867634, 53.41898515820503, 55.19058309495449, 54.70248028635979, 55.40048763155937, 57.50984564423561, 61.881256476044655, 62.318514212965965, 62.3079089820385, 58.09876464307308, 61.00214704871178, 60.4763388633728, 60.57231791317463, 53.929468765854836, 54.48295846581459, 54.83032062649727, 60.75318060815334, 58.05726706981659, 59.68087054789066, 59.06114660203457, 56.78258366882801, 55.691814199090004, 57.84361593425274, 59.0791804343462, 61.276602521538734, 61.0862897336483, 60.94312481582165, 56.525690853595734, 58.29649083316326, 57.67127998173237, 62.125245183706284, 66.03866279125214, 63.23961138725281, 63.41268450021744, 63.17728333175182, 60.103354677557945, 60.612937733531, 55.31316451728344, 57.32172153890133, 60.02452410757542, 58.70649263262749, 62.86748595535755, 59.11849692463875, 63.56270805001259, 62.03236296772957, 51.53084747493267, 54.28492449223995, 51.841488406062126, 50.40119469165802, 57.07210913300514, 60.96052788197994, 61.509188041090965, 62.958437874913216, 62.66201578080654, 58.79015274345875, 51.23292826116085, 47.96118602156639, 53.92451763153076, 58.91280636191368, 60.360319688916206, 58.02156798541546, 56.41421623528004, 57.697817757725716, 67.30458006262779, 61.59026429057121, 63.07756148278713, 62.150810211896896, 56.11293040215969, 50.08593700826168, 48.46175596117973, 47.37446330487728, 49.19860862195492, 48.27700227499008, 52.070555314421654, 52.36882410943508, 54.30398426949978, 52.22550339996815, 52.66937658190727, 53.8314264267683, 53.68648700416088, 54.26314026117325, 59.30389657616615, 64.75743234157562, 70.14333933591843, 68.51198807358742, 71.84147581458092, 70.69041877985, 75.27793541550636, 71.20247170329094, 77.38860055804253, 72.89892867207527, 74.24310654401779, 70.20339131355286, 78.09135004878044, 74.94264900684357, 77.84231141209602, 70.56155249476433, 73.65104511380196, 70.91103494167328, 83.42580780386925, 68.52186754345894, 92.49212130904198, 9.379914477467537, 5.80067278817296, 6.808561105281115, 0.2676639606943354, 0.28050905268173665, 13.95496018230915, 84.65712413191795, 63.612192794680595, 49.00125481188297, 31.014199890196323, 44.998823180794716, 55.30770041048527, 3.979490837082267, 0.28776431805454195, 0.0417839420697419, 0.09695005355752073, 0.06087252950237598, 0.13897923461627215, 0.07876911273342557, 0.07409129655570723, 0.08210347092244774, 0.07782753513311036, 0.03765956025745254, 0.11136138884467073, 0.12568123958772048, 0.13700942625291646, 0.12939668318722397, 0.13476500840624794, 0.1943861396284774, 0.10036434847279452, 0.10766016479465179, 0.17499218811281025, 0.34881593892350793, 0.8130332292057574, 67.87032410502434, 73.63825500011444, 31.864687353372574, 66.35292872786522, 55.83045355975628, 94.67013403773308, 22.966910004615784, 0.4242924466961995, 1.6375668975524604, 7.138214316219091, 2.102709081955254, 7.8137928899377584, 107.10252732038498, 90.76148137450218, 102.15241894125938, 87.0753675699234, 92.61822894215584, 85.10582685470581, 87.32246071100235, 81.69061571359634, 82.65080139040947, 79.08661544322968, 71.83087438344955, 69.20744955539703, 68.43333229422569, 65.6033505499363, 71.2305597960949, 67.11277395486832, 66.8630513548851, 63.173924311995506, 65.0666293501854, 61.849486380815506, 67.45182976126671, 61.48957349359989, 67.47954547405243, 63.82002264261246, 63.56982886791229, 65.27618810534477, 56.26726292073727, 55.8609963208437, 57.47276343405247, 56.06048181653023, 58.18312011659145, 56.89500443637371, 56.744042336940765, 59.09941054880619, 64.7794483602047, 66.85650050640106, 65.92369616031647, 61.58044561743736, 62.95275337994099, 63.284490779042244, 64.01622131466866, 58.47012631595135, 58.354977294802666, 59.369549453258514, 64.27604377269745, 63.467614352703094, 62.503112107515335, 62.31984794139862, 61.09333075582981, 58.96746642887592, 60.84915965795517, 63.301111087203026, 66.35605216026306, 65.16839548945427, 66.20621860027313, 59.81133654713631, 59.14978064596653, 58.43556337058544, 64.50788453221321, 68.34075406193733, 66.240743547678, 68.51913169026375, 66.04880824685097, 63.82747784256935, 64.6746575832367, 59.53849218785763, 61.910849288105965, 65.39301663637161, 64.91289719939232, 65.18550217151642, 59.7417850792408, 65.81046983599663, 63.73158238828182, 50.17415687441826, 53.35986793041229, 56.50082878768444, 56.44323147833347, 60.636963844299316, 63.99306535720825, 67.04040303826332, 65.38330435752869, 63.17646637558937, 62.912475541234016, 52.63300493359566, 51.172340512275696, 58.35215404629707, 62.139163836836815, 61.657691672444344, 60.93367092311382, 59.14896368980408, 62.03604117035866, 67.9007376730442, 64.38566029071808, 66.92640155553818, 63.55950102210045, 59.25125040113926, 51.24382987618446, 51.03747054934502, 49.22082602977753, 53.36837947368622, 51.28054730594158, 55.61256185173988, 54.13072496652603, 56.470415219664574, 56.35589696466923, 56.14272840321064, 56.40926130115986, 56.91563732922077, 58.70361618697643, 61.969795525074005, 67.36900940537453, 75.00634118914604, 71.19318500161171, 75.73242142796516, 72.26182445883751, 77.88548469543457, 74.28700178861618, 79.92049589753151, 75.9069612622261, 78.7662622332573, 71.00732177495956, 82.00577080249786, 79.32016611099243, 82.64571726322174, 75.0611874461174, 78.83839756250381, 74.81831967830658, 88.37824925780296, 72.20541268587112, 96.97537153959274, 7.651726836338639, 13.19068819284439, 17.28850230574608, 0.2745828847400844, 0.3294905024813488, 20.850037895143032, 95.32134309411049, 67.87468627095222, 59.83537405729294, 51.38191066682339, 48.84810782968998, 65.93616709113121, 5.241357050836086, 0.43519798025954515, 0.24103019532049075, 0.21128622262040153, 0.16646859236061573, 0.1896901408326812, 0.14335591695271432, 0.12064745969837531, 0.16834594396641478, 0.12432795556378551, 0.1871576064149849], [0.08344521455001086, 0.08209816456655972, 0.018797318589349743, 0.10154443007195368, 0.038585244765272364, 0.05766882641182747, 0.05859566867002286, 0.058135414656135254, 0.09568064706400037, 0.32260432199109346, 4.294291120022535, 59.46786917746067, 53.680145144462585, 47.02790290117264, 52.09781505167484, 41.351056918501854, 87.0915775001049, 7.648956784978509, 0.19470735598588362, 0.7374778459779918, 1.383897140622139, 1.3451633253134787, 26.859633922576904, 100.7457648217678, 80.85238069295883, 93.64363431930542, 81.32146552205086, 86.37004941701889, 77.29767143726349, 80.90755373239517, 71.75975739955902, 75.16938284039497, 69.0657551586628, 62.897580340504646, 59.94764283299446, 63.394992649555206, 58.997576013207436, 60.8604184538126, 58.516996800899506, 58.76697018742561, 56.406213864684105, 59.69420783221722, 54.645506143569946, 57.312662824988365, 56.37693643569946, 57.03469634056091, 56.01516544818878, 57.32670687139034, 52.66962356865406, 47.99803264439106, 48.633423149585724, 51.60248503088951, 51.96026623249054, 51.72267258167267, 48.14645268023014, 53.84029895067215, 55.80386258661747, 59.25852321088314, 59.50865238904953, 58.697452917695045, 62.09482781589031, 59.133483320474625, 57.81213842332363, 58.586179688572884, 53.16940315067768, 51.428993940353394, 53.684081733226776, 57.97726236283779, 53.92774745821953, 53.597856760025024, 52.945028990507126, 54.58625592291355, 51.90794683992863, 53.10970455408096, 59.919227957725525, 60.69908291101456, 58.52578952908516, 61.21512562036514, 51.82240583002567, 55.72411626577377, 56.776944771409035, 62.31870040297508, 62.29171425104141, 64.10058438777924, 66.45054548978806, 56.1315456032753, 51.873053312301636, 58.94442826509476, 57.98098236322403, 58.054614812135696, 57.72551827132702, 51.78949199616909, 58.976008370518684, 62.16021090745926, 61.39718905091286, 56.442281529307365, 56.0515408962965, 49.46066915988922, 48.88963960111141, 46.68662801384926, 47.684108689427376, 48.56721930205822, 53.659949228167534, 61.05097442865372, 60.65085589885712, 53.04929539561272, 49.24085475504398, 46.50554113090038, 48.404276445508, 49.464446157217026, 51.87292031943798, 55.56419424712658, 57.53047093749046, 50.28424836695194, 50.000943168997765, 62.85422466695309, 60.63340723514557, 58.68224613368511, 57.04690508544445, 48.80985528230667, 45.06770968437195, 43.4872604906559, 46.93308278918266, 46.10401667654514, 46.677759289741516, 50.05887486040592, 50.34739337861538, 48.192548006772995, 52.9074452072382, 50.02564564347267, 53.78380738198757, 51.02498821914196, 62.67694137990475, 66.0837359726429, 67.61469662189484, 69.58239823579788, 71.38788655400276, 68.13307240605354, 70.74598699808121, 71.98548048734665, 72.7416855096817, 67.23134279251099, 68.13073933124542, 71.93249613046646, 75.66025570034981, 72.17059135437012, 72.08188131451607, 66.91592171788216, 73.12097355723381, 66.05790495872498, 77.1959812939167, 70.18940806388855, 88.985745459795, 30.448085367679596, 0.5856038548517972, 4.152793362736702, 0.7445859583094716, 0.2760419767582789, 3.5429574362933636, 65.60951381921768, 67.1955943107605, 51.72735773026943, 51.80911794304848, 40.13872057199478, 50.82005761563778, 4.521410632878542, 0.2953624853398651, 0.0034437458862157655, 0.1547412044601515, 0.07314453876460902, 0.06404108076822013, 0.07433248712914065, 0.04901582979073282, 0.08149617147864774, 0.046747659507673234, 0.09492042066995054, 0.03399549925234169, 0.04318884246458765, 0.04271127785614226, 0.13004567648749799, 0.05689600577170495, 0.08130231508403085, 0.10214164372882806, 0.1521853666054085, 0.2690768614411354, 0.5071379465516657, 6.815558904781938, 68.8723835349083, 65.83646804094315, 48.39483395218849, 38.84255312383175, 51.87067463994026, 94.0618322789669, 8.35504962131381, 0.10104489047080278, 1.7007499071769416, 2.298847194761038, 0.435062701581046, 31.793786957859993, 107.79294267296791, 81.85036674141884, 97.42206797003746, 81.39500677585602, 89.78927314281464, 80.73090881109238, 82.54397392272949, 76.18955209851265, 79.02317404747009, 70.45368388295174, 68.00830990076065, 61.27012386918068, 65.86100712418556, 61.53891384601593, 64.79681342840195, 59.97530534863472, 63.00679408013821, 58.962401300668716, 63.300020545721054, 57.18751274049282, 60.45660272240639, 59.45569843053818, 61.35861352086067, 57.241359651088715, 59.920668080449104, 57.54111796617508, 51.4692147821188, 52.79450386762619, 54.6980345249176, 53.9539660513401, 54.46070306003094, 52.4943807721138, 56.50043360888958, 58.65906357765198, 61.28520905971527, 63.093737214803696, 62.20762096345425, 66.21827155351639, 63.53448696434498, 61.81474104523659, 60.685342848300934, 56.41988553106785, 54.388480335474014, 56.41282930970192, 60.56138589978218, 59.671010076999664, 55.87224751710892, 55.09678512811661, 57.796080484986305, 53.247766345739365, 55.209221094846725, 59.83554124832153, 66.23596340417862, 61.16386637091637, 63.98711487650871, 54.09809611737728, 57.07468539476395, 60.152877420187, 64.42790642380714, 66.34380921721458, 66.96966603398323, 69.83683258295059, 59.2357662320137, 56.374177783727646, 61.99727185070515, 60.94739578664303, 59.74646642804146, 60.61758868396282, 55.621103793382645, 60.27869626879692, 62.899157255887985, 62.84837678074837, 61.726243793964386, 55.77500693500042, 52.369074895977974, 53.784958720207214, 51.818993613123894, 50.20141661167145, 49.302871227264404, 58.54301020503044, 62.83696599304676, 63.27344097197056, 56.751725524663925, 52.32363313436508, 48.82928363978863, 48.69087986648083, 51.989589259028435, 53.98600593209267, 56.83813288807869, 60.19705764949322, 53.07984955608845, 51.38465791940689, 63.151516914367676, 63.7330187112093, 61.079039722681046, 60.93610279262066, 50.60846596956253, 47.04404443502426, 46.88146635890007, 49.590964168310165, 47.808130234479904, 50.4614632576704, 51.66880287230015, 52.3649787157774, 50.027655735611916, 54.35643285512924, 52.575909197330475, 57.353104054927826, 53.826327100396156, 65.11552512645721, 67.48985052108765, 70.15726938843727, 70.78634843230247, 73.27246382832527, 71.88695177435875, 73.86140942573547, 72.81938374042511, 75.20065516233444, 67.16898813843727, 70.22400140762329, 73.3524951338768, 77.35445559024811, 75.00530004501343, 75.78418225049973, 69.96154949069023, 76.47790342569351, 67.71391689777374, 79.56609651446342, 71.49364247918129, 92.30452537536621, 36.92908599972725, 0.39936750603374094, 3.3337425626814365, 1.2065111403353512, 0.25072550866752863, 2.4016960384324193, 68.3835169672966, 75.97160339355469, 57.06690341234207, 47.41877652704716, 53.03644448518753, 62.990166172385216, 7.92939598672092, 0.5533163936343044, 0.10834392029209994, 0.13460108282743022, 0.11103678087238222, 0.09347699538921006, 0.07734677186817862, 0.062065494785201736, 0.06577490843483247, 0.06336527367238887, 0.07312648231163621, 0.18363762967055663, 0.15577222569845617, 0.1786988743697293, 0.30595554504543543, 0.13570590323070064, 0.17621143284486607, 0.1169516533263959, 0.33093139703851193, 0.3230724687455222, 0.7508788956329226, 8.062470071017742, 82.1307460963726, 68.6165888607502, 60.45274592936039, 70.74288636445999, 59.22079883515835, 104.47473272681236, 10.899332296103239, 0.33589102153200656, 1.8898591096512973, 8.98298017680645, 2.718075611628592, 31.74759093672037, 112.192772179842, 86.21543571352959, 101.84172481298447, 85.71235790848732, 95.14053359627724, 85.00490427017212, 87.84469708800316, 79.0588541328907, 83.14288258552551, 74.46423947811127, 70.28732120990753, 66.47455260157585, 72.46446758508682, 63.433450385928154, 69.33123931288719, 63.0138199031353, 66.07976898550987, 62.89743594825268, 67.37587943673134, 59.562799483537674, 64.09760534763336, 61.700302585959435, 63.87624442577362, 62.324498891830444, 64.78384852409363, 60.026879981160164, 54.66706618666649, 56.83829627931118, 59.866798371076584, 57.26950854063034, 57.64536537230015, 54.79994885623455, 58.94803427159786, 62.51101568341255, 65.8311939239502, 66.36593922972679, 63.802741169929504, 64.44406315684319, 65.44417709112167, 63.56948308646679, 64.06735137104988, 58.82061570882797, 58.50055888295174, 60.66729001700878, 63.96513685584068, 61.85352176427841, 57.81359374523163, 57.531861662864685, 59.90118272602558, 56.08263462781906, 61.32441535592079, 63.279665037989616, 68.56567159295082, 64.99162897467613, 67.4195846915245, 57.51705765724182, 57.177561074495316, 59.867725521326065, 67.39241614937782, 67.75835931301117, 69.54775169491768, 71.42862036824226, 61.34759411215782, 57.37747974693775, 64.89045560359955, 61.00679039955139, 62.42190286517143, 62.48537465929985, 56.82572655379772, 62.827990874648094, 65.91581538319588, 65.21276190876961, 63.216577023267746, 56.31216511130333, 56.159325912594795, 56.9409553706646, 55.10375775396824, 55.321341678500175, 54.14508439600468, 60.51218993961811, 65.36799877882004, 68.95958125591278, 58.28223019838333, 56.15079157054424, 53.05225923657417, 54.00598905980587, 55.99552430212498, 59.26489166915417, 60.58340571820736, 62.135063856840134, 56.63804702460766, 57.0755897462368, 64.90497842431068, 64.45418581366539, 63.87998342514038, 62.962974831461906, 52.23392754793167, 51.16919428110123, 49.14227284491062, 52.73366533219814, 51.02947577834129, 53.06837037205696, 54.39573034644127, 55.68277068436146, 51.589257940649986, 59.14617083966732, 54.06222224235535, 60.271358862519264, 57.83943995833397, 68.38701277971268, 69.61170226335526, 72.83898308873177, 73.00926715135574, 75.07602944970131, 73.82105559110641, 76.60624533891678, 76.35613515973091, 78.2750777900219, 69.84102755784988, 74.18927863240242, 77.68597260117531, 81.07406079769135, 79.18647408485413, 80.00596091151237, 74.44701880216599, 80.49514666199684, 71.35343760251999, 84.21659097075462, 75.60268118977547, 99.05529633164406, 34.83346804976463, 0.8037785289343446, 13.938177432864904, 3.538729688152671, 0.451826837961562, 5.789809171110392, 80.0008387863636, 80.5574481189251, 70.53539469838142, 69.2436084151268, 53.780706748366356, 73.76563936471939, 9.534077905118465, 0.7213709852658212, 0.31350354314781725, 0.35698953783139586, 0.22615912923356518, 0.20495369913987815, 0.2764469519024715, 0.22167474642628804, 0.22952243860345334, 0.12154430805821903, 0.2481102989986539], [0.0718932480958756, 0.01971234400116373, 0.07881868819822557, 0.013761827121925307, 0.07648125698324293, 0.08332459328812547, 0.12534518027678132, 0.07401142662274651, 0.07425086572766304, 0.259672217653133, 8.167517334222794, 67.536800801754, 30.113804005086422, 32.83632941544056, 38.89981225132942, 49.53623950481415, 75.59805303812027, 1.402290053665638, 0.05690516016329639, 0.6663529656361789, 3.700473471544683, 0.09557469806168228, 57.71934360265732, 92.3022910952568, 89.11122992634773, 88.63899126648903, 84.09185886383057, 82.92130127549171, 78.5210157930851, 74.68538001179695, 72.684316188097, 71.10105514526367, 66.98144540190697, 61.73356980085373, 61.344459280371666, 57.986028492450714, 59.943273067474365, 58.16577784717083, 57.725035697221756, 56.738126054406166, 56.834697872400284, 56.662928089499474, 55.78466221690178, 57.49484024941921, 55.702902004122734, 56.53633788228035, 56.830179914832115, 58.02311450242996, 48.35465110838413, 49.727259054780006, 51.0201320797205, 50.823853611946106, 53.40160869061947, 54.104084596037865, 49.52150009572506, 53.08820150792599, 55.092365965247154, 58.35865169763565, 57.71136403083801, 63.45525361597538, 61.91573582589626, 62.95238859951496, 60.835924968123436, 58.21016326546669, 53.53675603866577, 52.844501584768295, 54.16547790169716, 55.85967779159546, 55.27944132685661, 52.45067171752453, 53.74604120850563, 55.29822751879692, 55.57864487171173, 55.149879679083824, 58.340826854109764, 61.87409766018391, 57.6188275963068, 58.26534390449524, 52.76287816464901, 59.51117545366287, 57.909143418073654, 62.412695959210396, 62.23946325480938, 63.87393414974213, 61.346533969044685, 60.050051137804985, 65.60632959008217, 64.47356477379799, 61.89063057303429, 63.363632932305336, 63.541053012013435, 63.77446308732033, 53.80111925303936, 59.78401601314545, 58.59359309077263, 59.61644120514393, 55.77742740511894, 50.72063975036144, 47.607455402612686, 53.00476938486099, 47.10578352212906, 50.03899432718754, 56.53307765722275, 57.740314677357674, 55.89782774448395, 52.89144806563854, 46.49108290672302, 44.98838894069195, 45.47929219901562, 47.542076110839844, 52.19269976019859, 52.218409180641174, 52.10611380636692, 56.57410405576229, 50.97574666142464, 51.870043873786926, 62.33390338718891, 57.51714885234833, 57.153318375349045, 52.77746558189392, 46.01154483854771, 44.46583718061447, 42.72416643798351, 46.939508244395256, 45.65582312643528, 49.5435731112957, 50.05403392016888, 48.616274669766426, 48.09207759797573, 52.52786077558994, 50.83089083433151, 55.28430886566639, 66.52892768383026, 67.36289173364639, 68.61601129174232, 69.55254703760147, 69.3461725115776, 70.38116097450256, 69.47793424129486, 70.26902139186859, 69.8769660294056, 69.60069805383682, 72.19483405351639, 72.34674230217934, 74.11776646971703, 70.82364723086357, 70.17229378223419, 68.57458591461182, 67.81947523355484, 67.98047259449959, 74.57369640469551, 75.36863654851913, 77.65504226088524, 65.32357156276703, 0.36110222339630127, 1.6595125012099743, 1.20540005620569, 0.08735579845961183, 0.11396378162316978, 36.896077170968056, 75.52382782101631, 51.284419298172, 39.74011816084385, 25.759043879806995, 54.30921658873558, 10.116873532533646, 0.29744055820629, 0.08589761928305961, 0.026966908044414595, 0.051115870228386484, 0.02420399057882605, 0.03617523150751367, 0.057517758541507646, 0.07119621557649225, 0.08281457456178032, 0.020197790217935108, 0.05156093247933313, 0.017254922349820845, 0.046770499102422036, 0.03640374619862996, 0.06825584132457152, 0.09102517695282586, 0.07010852394159883, 0.08320241351611912, 0.24756544386036694, 0.4746010049711913, 13.413553833961487, 77.44965568184853, 37.025775611400604, 38.66197161376476, 35.8208716660738, 61.870092675089836, 78.16903308033943, 1.2793284142389894, 0.023068653063091915, 2.635780102573335, 2.675343342125416, 0.6023172580171376, 64.93068784475327, 93.83082747459412, 90.95225393772125, 92.79327034950256, 85.83927109837532, 86.29105925559998, 79.6777269244194, 79.69334408640862, 74.9922363460064, 74.44993704557419, 68.29618245363235, 65.2251036465168, 64.86256510019302, 62.72141419351101, 61.198672503232956, 60.4579858481884, 60.33025570213795, 60.96987538039684, 58.716763481497765, 60.0139606744051, 59.78513315320015, 60.15222005546093, 58.580666184425354, 58.61377760767937, 57.81378373503685, 62.3018217086792, 52.85459004342556, 53.133263289928436, 52.30820596218109, 54.036630615592, 55.54737634956837, 56.53049759566784, 53.51427644491196, 55.17965488135815, 58.33769582211971, 62.37417362630367, 60.35745844244957, 66.44619092345238, 64.48937192559242, 64.43348452448845, 63.87692078948021, 61.19912087917328, 56.414421424269676, 54.95273105800152, 55.689671114087105, 59.59642767906189, 57.66090653836727, 55.97918517887592, 56.38170897960663, 56.5667400509119, 59.92444887757301, 56.433773785829544, 60.92942655086517, 64.19733479619026, 62.04323798418045, 60.77982097864151, 54.98326621949673, 60.05481228232384, 59.97753582894802, 65.18343508243561, 64.93326410651207, 65.65462499856949, 61.331646367907524, 60.1048593968153, 67.60940730571747, 66.68592005968094, 62.243772223591805, 63.65103431046009, 64.06640902161598, 65.1130248606205, 57.87964180111885, 62.6176493614912, 60.48636272549629, 59.904545545578, 58.95805433392525, 50.15600524842739, 51.76472492516041, 54.73369561135769, 51.54393397271633, 57.22174130380154, 59.59166273474693, 59.11685161292553, 60.050746500492096, 55.36019079387188, 49.78771761059761, 48.03110606968403, 47.989616096019745, 49.91137817502022, 54.882343634963036, 55.88013209402561, 56.216512843966484, 59.749962240457535, 54.020424485206604, 54.14126180112362, 63.11201423406601, 60.33432528376579, 60.046148747205734, 53.704387843608856, 48.932603895664215, 47.7243485301733, 45.76224401593208, 48.37921679019928, 49.27882231771946, 52.682421281933784, 49.675771817564964, 52.797904685139656, 50.15728197991848, 52.82020568847656, 52.29387313127518, 58.471684232354164, 69.70380932092667, 70.2493004500866, 70.5760145187378, 71.91225841641426, 71.2605781853199, 70.97860291600227, 70.640679448843, 71.90825343132019, 69.47783544659615, 73.54736387729645, 75.12706071138382, 73.63611191511154, 74.7611403465271, 74.44175228476524, 72.29013293981552, 70.83894520998001, 69.81832757592201, 71.11640632152557, 74.55281272530556, 77.24436789751053, 78.11614751815796, 73.4346391260624, 1.0072822496294975, 0.34775342093780637, 1.792668281123042, 0.0867991209088359, 0.27486665232572705, 34.59487125277519, 83.91827657818794, 58.670527562499046, 41.36212572455406, 30.80226246267557, 66.5395899116993, 15.703517105430365, 0.38673232309520245, 0.0876311500906013, 0.046381561769521795, 0.09813925615162589, 0.028403312608134, 0.04042500659124926, 0.06540128160850145, 0.025383931169926655, 0.07768636380205862, 0.050187172600999475, 0.17042878142092377, 0.10809964980580844, 0.17833496967796236, 0.22558414289960638, 0.2166543251951225, 0.2618816803442314, 0.23299059859709814, 0.2152600820409134, 0.44635198486503214, 0.6206218258012086, 13.932470139116049, 91.59621298313141, 40.627465546131134, 44.0106064081192, 54.9571768194437, 66.81131333112717, 91.62487864494324, 2.6448580529540777, 0.4261201189365238, 2.3609118768945336, 12.006026711314917, 0.6722855160478503, 67.10554674267769, 97.05487087368965, 96.6176663339138, 96.294204890728, 91.30802884697914, 90.86155280470848, 85.64007818698883, 82.48102650046349, 80.56633964180946, 77.5751705467701, 73.59511211514473, 68.23905631899834, 69.21319484710693, 65.6470862030983, 65.43074861168861, 64.59919363260269, 65.30561372637749, 63.93612161278725, 63.587410524487495, 64.4906334578991, 64.21762570738792, 64.90697711706161, 63.79500478506088, 63.03668327629566, 62.01894208788872, 64.51332584023476, 54.25343178212643, 57.37118348479271, 57.680296897888184, 56.674274280667305, 59.52643163502216, 60.02504847943783, 56.889255344867706, 58.85986380279064, 63.405791670084, 65.14520153403282, 65.35884886980057, 67.253647595644, 63.93748953938484, 68.70190188288689, 67.62953102588654, 65.54635360836983, 60.837509483098984, 58.925330489873886, 58.76839891076088, 61.877954453229904, 60.5511112511158, 57.53986403346062, 60.4399748146534, 62.916469126939774, 62.36067295074463, 59.47571575641632, 67.20063284039497, 68.8098768889904, 66.75299406051636, 65.75689271092415, 55.510278940200806, 63.875811249017715, 59.58250142633915, 65.8429504930973, 66.69089019298553, 68.1615100800991, 63.61851565539837, 66.0209633409977, 70.61397448182106, 66.85939595103264, 65.65054401755333, 65.87658628821373, 68.44878986477852, 68.18558558821678, 58.98463390767574, 67.37666219472885, 61.56608238816261, 62.94415444135666, 61.086791306734085, 54.19083774089813, 53.94295044243336, 57.856767028570175, 56.20382532477379, 58.170010820031166, 63.01857724785805, 62.95230120420456, 61.9596728682518, 58.863374814391136, 53.362957164645195, 51.04975908994675, 50.97319319844246, 54.75679837167263, 59.75309707224369, 58.368405774235725, 59.576854929327965, 62.13808089494705, 58.43258813023567, 58.572348430752754, 66.1786624789238, 63.79454880952835, 61.418186724185944, 57.240048721432686, 51.6326630115509, 49.55596424639225, 48.67693841457367, 53.602359518408775, 52.016111835837364, 55.871327966451645, 54.26234230399132, 54.89129215478897, 52.69770406186581, 57.392720729112625, 53.28450657427311, 61.707617193460464, 72.3040933907032, 73.28764021396637, 73.9832004904747, 75.47522082924843, 74.11661133170128, 75.39348721504211, 75.01397117972374, 74.80017945170403, 73.0456691980362, 73.94655525684357, 77.7293586730957, 78.49179536104202, 79.82114642858505, 77.65523225069046, 76.41032785177231, 74.21342253684998, 73.53876873850822, 75.80022498965263, 79.44995194673538, 81.64114236831665, 83.52428331971169, 74.02995318174362, 0.7628994912374765, 5.9464348666369915, 4.226924534887075, 0.34968704218044877, 0.42909470619633794, 46.55350595712662, 88.72201681137085, 67.33992576599121, 59.15534734725952, 33.688072711229324, 78.24610814452171, 16.95747546851635, 0.6719061301555485, 0.21031576063251123, 0.1779807425918989, 0.2688169910106808, 0.06973123090574518, 0.16755583870690316, 0.14291981613496318, 0.129040882748086, 0.2244016047916375, 0.10146395157789811], [0.059301640358171426, 0.07995517604285851, 0.015066331634443486, 0.06306699709966779, 0.05253218856523745, 0.039156553757493384, 0.09099034796236083, 0.04461471224203706, 0.17343596380669624, 0.42443030804861337, 17.454371005296707, 70.9988634288311, 33.40650402009487, 32.687331810593605, 29.369517043232918, 73.42703193426132, 40.70119298994541, 0.34397787821944803, 0.12695433455519378, 1.0827276762574911, 2.3228880297392607, 7.385889301076531, 85.67521870136261, 86.16295292973518, 88.55611771345139, 89.4670732319355, 89.13156643509865, 82.26497769355774, 78.90658110380173, 76.38256654143333, 73.20716813206673, 69.16011929512024, 63.64224538207054, 62.718032374978065, 59.365134090185165, 57.044344022870064, 57.47035436332226, 56.86038449406624, 57.30556860566139, 56.85780443251133, 57.59917125105858, 58.5919401794672, 57.40399472415447, 54.9480877071619, 57.52052307128906, 56.417233273386955, 56.83845967054367, 52.9741620272398, 47.09708958864212, 48.25377032160759, 49.70827907323837, 51.66917525231838, 55.435407757759094, 50.21493248641491, 52.404063418507576, 50.64726948738098, 54.830104038119316, 57.32956811785698, 62.52763219177723, 57.68137224018574, 59.34939533472061, 63.615339025855064, 60.098817721009254, 58.275629952549934, 54.59185682237148, 52.96813175082207, 51.17476098239422, 53.97638864815235, 53.81850712001324, 56.141824051737785, 52.39570766687393, 55.73833130300045, 55.324256122112274, 55.1977115124464, 59.22706089913845, 62.87342883646488, 57.46991738677025, 55.56092642247677, 55.16614280641079, 55.40408603847027, 59.50782023370266, 63.96994739770889, 62.36248165369034, 60.80317072570324, 59.091765359044075, 61.418547704815865, 64.69013795256615, 62.16754071414471, 54.98067855834961, 56.68594725430012, 57.7261034399271, 61.3762141764164, 61.10473394393921, 54.036341831088066, 61.293127834796906, 53.60679008066654, 64.11010667681694, 49.84084635972977, 48.58931131660938, 47.85225726664066, 49.45243500173092, 58.07205207645893, 58.25864866375923, 56.23837307095528, 52.63292893767357, 49.545575603842735, 46.65113411843777, 47.48738184571266, 46.645928397774696, 43.13231013715267, 46.447472646832466, 48.57182465493679, 52.916283532977104, 55.430084243416786, 56.26122124493122, 50.51363445818424, 55.443581119179726, 60.84767013788223, 56.97107635438442, 53.718146905303, 47.25174129009247, 45.58053396642208, 44.77237433195114, 44.73283365368843, 44.99506898224354, 47.14289233088493, 49.3043265491724, 50.564787313342094, 49.53896775841713, 51.510484367609024, 50.631082355976105, 56.278495118021965, 64.23809140920639, 65.32885327935219, 67.83464401960373, 68.4951701760292, 68.51475432515144, 69.86999720335007, 69.27577748894691, 69.86498147249222, 72.39023476839066, 73.3095346391201, 69.3314976990223, 73.05250883102417, 70.56126371026039, 72.72172138094902, 66.34445518255234, 70.17314493656158, 67.51666948199272, 68.60062971711159, 67.21850708127022, 79.57986697554588, 70.3816169500351, 90.25326624512672, 8.179041165858507, 0.9922105364967138, 0.8862177771516144, 0.08817450609058142, 0.3251641971291974, 9.149871971458197, 82.22692653536797, 52.98902302980423, 47.45172455906868, 37.13250048458576, 61.46371208131313, 16.36967360973358, 0.27328421536367387, 0.11719073620042764, 0.08794665933237411, 0.022986450931057334, 0.0697801161732059, 0.0502339316153666, 0.059270733618177474, 0.057406050473218784, 0.06277580061578192, 0.06392071925802156, 0.05676979242707603, 0.06159512900921982, 0.017523260685265996, 0.07804560038493946, 0.045694670698139817, 0.02306819849763997, 0.03456341662968043, 0.012108423215977382, 0.049031908420147374, 0.38657890632748604, 22.791693806648254, 79.31013464927673, 43.528511077165604, 28.635787814855576, 31.083538569509983, 86.66042223572731, 42.07763113081455, 0.4084653756581247, 0.10796045258757658, 2.3005471285432577, 0.07796924081048928, 10.132556241005659, 92.23761096596718, 86.43525391817093, 93.20917323231697, 90.71419671177864, 91.51454016566277, 84.08143982291222, 82.8398260474205, 78.48101153969765, 75.67950546741486, 70.90816229581833, 67.44168430566788, 65.30623689293861, 62.375967130064964, 61.28853388130665, 59.73140023648739, 60.96807427704334, 62.20745377242565, 58.97246316075325, 60.60681626200676, 59.17892128229141, 58.76188226044178, 58.18853862583637, 58.97787407040596, 58.00273239612579, 60.1826336234808, 55.80363839864731, 49.66420903801918, 53.14290717244148, 53.24678599834442, 53.725351318717, 57.068389132618904, 54.02235858142376, 55.91950938105583, 53.27244222164154, 57.91108511388302, 60.19154414534569, 64.40003111958504, 60.97011476755142, 62.87169612944126, 63.40737998485565, 64.5770712196827, 59.61783193051815, 55.48461131751537, 55.81256791949272, 56.46286882460117, 56.40542730689049, 55.34286372363567, 59.294568076729774, 56.322245970368385, 59.97020602226257, 58.04932549595833, 57.570004016160965, 61.19306020438671, 65.27583852410316, 62.75332108139992, 57.70822159945965, 56.553706750273705, 58.264868929982185, 60.281948894262314, 65.69955378770828, 64.84687954187393, 64.26375523209572, 63.084116131067276, 66.25384524464607, 64.88165527582169, 62.563088089227676, 56.56092256307602, 58.41222882270813, 59.331167712807655, 61.21326372027397, 63.17952141165733, 58.56961637735367, 63.51147919893265, 55.2203468978405, 63.65947365760803, 52.902642264962196, 52.99003377556801, 50.25729261338711, 56.29848584532738, 62.423430383205414, 63.11109468340874, 59.508185014128685, 55.18636532127857, 52.56406143307686, 51.41910307109356, 51.387036591768265, 50.70975713431835, 47.38006420433521, 47.54792779684067, 52.38836266100407, 56.430669352412224, 55.93684025108814, 58.11522535979748, 54.11487601697445, 57.030170783400536, 63.002804294228554, 59.62806858122349, 56.00361026823521, 50.42119301855564, 48.331457152962685, 47.039572075009346, 47.110221683979034, 47.63486333191395, 48.60718555748463, 51.075852289795876, 52.679351046681404, 50.62995381653309, 52.335176914930344, 51.989315673708916, 59.58137288689613, 66.57090783119202, 67.90052488446236, 71.16880550980568, 69.01794612407684, 70.45530259609222, 70.98886236548424, 69.33242484927177, 72.96075895428658, 73.41494858264923, 74.9887253344059, 71.21168240904808, 76.15868255496025, 73.60304608941078, 73.48045706748962, 68.4422618150711, 72.60447487235069, 69.58492130041122, 71.06903806328773, 69.54509943723679, 83.24865370988846, 72.15623572468758, 94.68765869736671, 11.368338279426098, 0.9078844520263374, 0.5010349990334362, 0.030228776959120296, 0.36981135606765747, 7.876880429685116, 86.41118600964546, 61.8074606359005, 48.662810772657394, 36.40068255364895, 73.5761359333992, 24.035446867346764, 0.33601593982893974, 0.12320072230068035, 0.11604155763052404, 0.01602185882802587, 0.02944529722299194, 0.0450345006538555, 0.021621118139592, 0.03324548481032252, 0.004906480226054555, 0.10079354731715284, 0.15956068178638816, 0.16965991642791778, 0.06659500388195738, 0.2445953243295662, 0.12745148444082588, 0.1157044741557911, 0.15388956031529233, 0.11235694284550846, 0.3954409807920456, 0.736823984188959, 25.632618963718414, 91.40050068497658, 45.52829056978226, 42.745099514722824, 45.01789055764675, 93.04422408342361, 53.255749717354774, 1.0495402570813894, 0.1741056184982881, 4.897255590185523, 5.918222805485129, 10.827375557273626, 93.65130230784416, 92.1469934284687, 95.83859413862228, 97.28962227702141, 94.98575270175934, 87.62165665626526, 85.8112134039402, 84.24433708190918, 80.13507798314095, 76.4140896499157, 71.52112260460854, 69.91754025220871, 66.78658425807953, 64.59344834089279, 62.111448124051094, 66.36695757508278, 66.19676470756531, 65.43558955192566, 64.43624317646027, 63.69042679667473, 62.82332472503185, 61.18886522948742, 63.88902693986893, 62.51940183341503, 62.32555143535137, 60.04438564181328, 53.11277478933334, 55.14402039349079, 55.234998911619186, 56.05815254151821, 62.12872199714184, 56.44858539104462, 58.55642728507519, 56.447863429784775, 61.323397010564804, 63.94429877400398, 69.72606092691422, 60.82866735756397, 62.575357630848885, 69.29210901260376, 68.19757774472237, 63.87987703084946, 59.36711758375168, 59.85924817621708, 58.285243436694145, 60.30944421887398, 58.15231516957283, 63.77038210630417, 58.982259035110474, 61.7936597764492, 60.53268603980541, 61.10413737595081, 64.31967303156853, 68.08024004101753, 66.05298802256584, 62.68509194254875, 59.05916690826416, 59.179806634783745, 60.96181221306324, 70.64635634422302, 65.71514815092087, 65.35319477319717, 65.21909236907959, 67.66578868031502, 67.1113832294941, 65.36382660269737, 58.947479501366615, 60.43004594743252, 60.05746454000473, 63.36878165602684, 65.58891892433167, 60.516628101468086, 63.80564421415329, 57.11945079267025, 66.04817748069763, 54.51635867357254, 55.50319992005825, 57.62096308171749, 59.20272320508957, 63.39212380349636, 66.294776648283, 62.937341406941414, 60.033313035964966, 56.29631996154785, 53.37166249752045, 52.901886105537415, 53.572166338562965, 48.2891084253788, 52.641862258315086, 54.900977835059166, 58.51950466632843, 60.246473997831345, 62.25100323557854, 56.44653730094433, 63.71531926095486, 65.71957871317863, 62.995413690805435, 57.5298135727644, 52.175387889146805, 50.43124347925186, 50.867551267147064, 50.09830914437771, 50.83185978233814, 50.74553221464157, 54.84197460114956, 56.308593302965164, 53.46086651086807, 56.41596794128418, 55.21148197352886, 62.301107347011566, 66.70070126652718, 69.63453143835068, 73.43831732869148, 73.70664373040199, 75.09261935949326, 73.73665452003479, 73.04102584719658, 74.69533547759056, 76.34253948926926, 78.27716007828712, 72.844158411026, 81.51321083307266, 77.37394094467163, 76.34355783462524, 71.29099935293198, 77.45878279209137, 74.20069321990013, 74.47165668010712, 73.26209038496017, 87.36094504594803, 76.48237198591232, 99.13614079356194, 11.026566568762064, 1.8337349337525666, 3.0023032100871205, 0.14967024297220632, 0.6623885314911604, 11.956377625465393, 96.89737692475319, 65.33111795783043, 68.13748016953468, 46.77409552037716, 83.31087157130241, 34.906006157398224, 0.48546735313721, 0.40232662693597376, 0.2648571878671646, 0.07272818649653345, 0.1691374444635585, 0.2834227541461587, 0.16297172609483823, 0.12433087220415473, 0.1506288454402238, 0.14506788837024942], [0.03497080375382211, 0.03644274234829936, 0.03867895204166416, 0.058540475147310644, 0.07359446579357609, 0.03756413861992769, 0.052251018496463075, 0.044040772336302325, 0.006132398721092613, 0.10623462527291849, 22.738937437534332, 66.34497955441475, 28.5314929112792, 53.09185691177845, 41.142045333981514, 77.92380943894386, 28.39193969964981, 0.29114684904925525, 0.08832895444356836, 3.770023277029395, 1.2602459569461644, 31.79257482290268, 103.75784039497375, 86.19839742779732, 92.64393076300621, 83.18324401974678, 86.26848846673965, 81.76291063427925, 76.30220085382462, 72.35136285424232, 68.88360053300858, 64.87953498959541, 65.89238584041595, 65.73742255568504, 61.869173124432564, 56.235971599817276, 57.45089940726757, 54.67953711748123, 56.78366281092167, 55.537211894989014, 57.812545001506805, 54.90193538367748, 56.54986135661602, 56.278096139431, 57.773182913661, 55.94673112034798, 59.243590012192726, 49.86695855855942, 47.0562569797039, 48.379452377557755, 52.599061354994774, 50.698414742946625, 56.152756065130234, 49.36930686235428, 52.80105471611023, 51.40516921877861, 58.68791542947292, 55.960835963487625, 63.28499235212803, 54.18028570711613, 56.90678760409355, 67.15818911790848, 59.07315395772457, 56.5882582962513, 51.6954318434, 51.58727824687958, 51.74107879400253, 53.818548917770386, 55.06614737212658, 53.84508289396763, 56.73608556389809, 56.93725436925888, 58.22507366538048, 58.062864169478416, 59.15478877723217, 64.4036865234375, 58.317169323563576, 51.314456686377525, 52.79231518507004, 57.74092644453049, 62.47035786509514, 63.14846567809582, 63.002386316657066, 61.537948697805405, 61.12010031938553, 63.86184319853783, 62.88709670305252, 61.37679174542427, 64.2590282857418, 66.00841641426086, 60.77018849551678, 59.254119247198105, 59.17034514248371, 57.67832100391388, 59.878855124115944, 60.18364816904068, 54.88289460539818, 49.82848182320595, 45.792995765805244, 47.28127330541611, 58.229059651494026, 57.98504814505577, 56.92897081375122, 51.316094398498535, 48.663867115974426, 48.997561410069466, 49.95230197906494, 48.09248797595501, 48.61041158437729, 47.324549183249474, 45.37170097231865, 46.29293113946915, 47.77430444955826, 53.34779217839241, 54.75484527647495, 56.66119158267975, 52.57892623543739, 54.74479481577873, 55.87863117456436, 56.03053942322731, 48.55366922914982, 46.042440980672836, 45.343571081757545, 44.22734297811985, 45.25347411632538, 45.34966595470905, 49.65157471597195, 50.03609888255596, 49.677067548036575, 50.90302616357803, 49.41035605967045, 53.741603046655655, 64.22904029488564, 65.30283987522125, 67.2578501701355, 67.01131939888, 68.33242490887642, 69.53626111149788, 69.46203589439392, 70.213802754879, 70.59309840202332, 73.37330281734467, 69.20057952404022, 69.9234527349472, 66.99559584259987, 69.43215429782867, 67.21728354692459, 68.75821486115456, 64.56707775592804, 70.80022528767586, 63.89229476451874, 79.23089370131493, 69.19115602970123, 92.33185350894928, 29.87101223319769, 0.554677729960531, 1.1840974492952228, 0.03464989909844007, 0.1277184349601157, 2.37174557056278, 72.95598641037941, 56.47196553647518, 52.83727057278156, 31.90107800066471, 38.171197548508644, 25.81920225173235, 0.359839741140604, 0.07883343467256054, 0.09238146667485125, 0.0026833014862859272, 0.05058308241132181, 0.09332099594757892, 0.047900114659569226, 0.06989857036387548, 0.005230002807365963, 0.0603513414534973, 0.07083024771418422, 0.03733185010787565, 0.031048664604895748, 0.10592630744213238, 0.04577680789225269, 0.05682848517608363, 0.0572417835064698, 0.04349412120063789, 0.03998380350822117, 0.16970334690995514, 30.080096013844013, 73.10315251350403, 39.38550978899002, 50.0383597612381, 42.9941001534462, 90.5969350039959, 29.500382021069527, 0.32193089718930423, 0.10575173204415478, 1.7927248030900955, 0.5271409638226032, 38.833767995238304, 108.06532725691795, 86.82813763618469, 96.90618485212326, 84.594397097826, 90.4575052857399, 85.15061125159264, 77.93178901076317, 74.40462827682495, 73.8839042186737, 67.15458691120148, 69.8532173037529, 67.18425571918488, 66.1951307952404, 59.333534985780716, 62.34756365418434, 58.962340503931046, 59.44133140146732, 57.52863183617592, 61.93186216056347, 57.513219863176346, 59.38435725867748, 59.99164067208767, 58.45295503735542, 58.85226421058178, 60.91287463903427, 52.176752015948296, 51.12548142671585, 51.13792575895786, 55.010997131466866, 55.04653662443161, 57.239284962415695, 54.06541407108307, 54.83502857387066, 54.008196741342545, 61.16536349058151, 59.18665386736393, 66.47076800465584, 57.22649484872818, 60.42790666222572, 66.04536563158035, 63.246340826153755, 60.36187760531902, 55.91665953397751, 53.98150697350502, 55.32654359936714, 56.55614621937275, 58.876503109931946, 57.20840401947498, 60.603632032871246, 61.446339413523674, 60.24984061717987, 61.32920689880848, 63.37096653878689, 67.84192442893982, 61.67075537145138, 54.456173703074455, 54.602355659008026, 58.62921617925167, 61.55537076294422, 65.28002589941025, 63.84703919291496, 63.50720822811127, 62.39661902189255, 66.42879545688629, 64.88499149680138, 64.87856984138489, 66.86106026172638, 67.12665840983391, 62.08958029747009, 59.47301410138607, 62.358320876955986, 61.81112743914127, 59.78570692241192, 62.65525594353676, 54.932105764746666, 51.73373758792877, 46.94584250450134, 52.487438544631004, 60.668794736266136, 60.13374164700508, 58.83102335035801, 54.140555039048195, 50.378046333789825, 52.78691187500954, 54.16348680853844, 52.880010679364204, 52.71589368581772, 50.235637575387955, 47.81531944870949, 49.30270403623581, 51.75564721226692, 56.440780609846115, 55.14404699206352, 57.96599976718426, 55.121316611766815, 56.64576821029186, 60.19829638302326, 57.73454278707504, 52.37254410982132, 47.594463899731636, 48.349464386701584, 46.30508288741112, 48.182592540979385, 48.13127629458904, 51.69823609292507, 52.63059966266155, 51.12988539040089, 52.22109563648701, 52.218469977378845, 57.67700247466564, 66.94492176175117, 67.65692755579948, 68.00384894013405, 71.02546200156212, 69.1260427236557, 71.9591175019741, 69.8639403283596, 71.02847903966904, 71.29905492067337, 76.01701095700264, 71.4202456176281, 73.18462014198303, 69.58312019705772, 71.68374627828598, 69.36431273818016, 72.4485844373703, 66.96598023176193, 73.14689576625824, 65.18367066979408, 81.11623093485832, 71.77244111895561, 93.44384104013443, 34.779875725507736, 0.4976715857628733, 0.1958039088640362, 0.06520570343127474, 0.19172996340785176, 2.38768904004246, 75.74266567826271, 67.27035149931908, 54.0205954760313, 30.368620231747627, 47.773229107260704, 42.24391780793667, 0.3570498002227396, 0.028700850743916817, 0.023758991410431918, 0.033154152406495996, 0.03910604318662081, 0.038080988815636374, 0.0720680684025865, 0.04855241051700432, 0.02119511609635083, 0.03196644895069767, 0.14361678186105564, 0.18230709247291088, 0.09823653686908074, 0.18548645311966538, 0.10261574250762351, 0.20971871766960248, 0.13863334927009419, 0.17572891811141744, 0.17361966019961983, 0.3135040478082374, 34.14863079786301, 87.33107104897499, 36.97961188852787, 69.04129207134247, 57.12464511394501, 96.08400017023087, 37.75505907833576, 0.7010942045599222, 0.24280887097120285, 12.796964719891548, 2.3951565893366933, 39.02856834232807, 112.23577067255974, 94.81112167239189, 98.01271587610245, 89.11658003926277, 94.98491674661636, 88.7027670443058, 79.85254034399986, 79.31572794914246, 77.50621184706688, 72.37116739153862, 74.08617496490479, 71.43627315759659, 70.15793815255165, 64.14665311574936, 65.95800831913948, 61.98682241141796, 64.55861181020737, 61.69627860188484, 67.21603721380234, 62.22039207816124, 61.83844797313213, 64.87994536757469, 63.55621799826622, 61.89263306558132, 65.20187929272652, 56.10536880791187, 56.058961898088455, 54.60186928510666, 58.81718449294567, 58.59223276376724, 61.14555135369301, 56.611649841070175, 58.296597227454185, 58.97820085287094, 64.96363207697868, 61.32341220974922, 67.51087859272957, 60.50550229847431, 58.78808565437794, 73.39515924453735, 65.53443744778633, 62.506053149700165, 58.18716309964657, 57.53756895661354, 58.503241539001465, 59.93293382227421, 60.40590584278107, 60.4958052188158, 62.53822982311249, 62.42824852466583, 64.73999127745628, 61.06192544102669, 67.186079621315, 72.13863506913185, 67.66000539064407, 58.19475509226322, 59.36702258884907, 59.702130407094955, 64.6485985815525, 68.00719276070595, 65.65644890069962, 66.66031703352928, 66.2103907763958, 68.5157498717308, 66.75848856568336, 65.88996917009354, 68.52589532732964, 70.75247704982758, 65.09303793311119, 60.88591888546944, 64.80993792414665, 63.8653390109539, 64.63996544480324, 64.45914074778557, 56.113644763827324, 54.06345337629318, 52.022818475961685, 56.71611003577709, 62.99513630568981, 64.3093603849411, 62.07493208348751, 58.40205676853657, 53.39233338832855, 55.702552422881126, 55.69268435239792, 53.26793186366558, 56.004647612571716, 54.8100221157074, 50.366392359137535, 52.82791547477245, 54.44747216999531, 58.2644509524107, 58.144138008356094, 62.89020113646984, 58.281401842832565, 60.19758582115173, 60.283183827996254, 61.9479238986969, 55.241652354598045, 50.03945790231228, 51.224846094846725, 49.322029799222946, 50.98961591720581, 50.9878946095705, 54.27411787211895, 55.502603352069855, 54.50574964284897, 56.101116836071014, 54.181304052472115, 59.94555674493313, 70.76565474271774, 71.32898211479187, 72.69389167428017, 73.5350601375103, 75.49292787909508, 75.01092374324799, 71.81296214461327, 76.24724820256233, 75.62659710645676, 77.45395705103874, 75.64110472798347, 76.77929565310478, 72.68082797527313, 75.6237244606018, 72.3004075884819, 74.83825340867043, 70.96623837947845, 78.58938932418823, 69.43995147943497, 87.76656568050385, 75.60170844197273, 99.68797758221626, 34.87566478550434, 0.8306407125201076, 4.563849130645394, 0.2383496321272105, 0.4829195007914677, 3.437111503444612, 84.97227162122726, 69.31714966893196, 71.8409438431263, 42.024304792284966, 53.8205324113369, 51.03476509451866, 0.5046055011916906, 0.1961196630145423, 0.12966410868102685, 0.1356221889727749, 0.20709764503408223, 0.17740084324032068, 0.12969749048352242, 0.16114920435938984, 0.0922432416700758, 0.2063429995905608], [0.047498152634943835, 0.02719964184507262, 0.033562044191057794, 0.0529059415566735, 0.005672231445714715, 0.033499722339911386, 0.06470374442869797, 0.035127281880704686, 0.02694103677640669, 0.11120242823380977, 38.03453408181667, 59.53836679458618, 28.501558117568493, 37.60707601904869, 40.61614975333214, 83.33421751856804, 20.805012211203575, 0.19200776412617415, 0.17352623865008354, 2.9018354136496782, 0.7245900062844157, 70.804123878479, 97.45566576719284, 84.8283277451992, 90.66799879074097, 84.14415925741196, 88.1350015103817, 81.08704090118408, 77.36681252717972, 67.29924514889717, 67.83931016921997, 65.86685881018639, 68.39605629444122, 64.33504700660706, 63.98586094379425, 56.66734725236893, 57.29267969727516, 56.90380856394768, 55.54961822926998, 54.865723326802254, 56.52418993413448, 54.09559965133667, 54.918342903256416, 54.294720366597176, 54.49923679232597, 54.46837864816189, 55.70241943001747, 45.80853693187237, 47.022970765829086, 48.637557327747345, 51.328888311982155, 52.9314561188221, 54.990132451057434, 48.69154863059521, 55.14173671603203, 51.12045429646969, 56.73945978283882, 57.398732006549835, 64.0225213766098, 56.82235233485699, 54.38761778175831, 66.18778958916664, 60.60294806957245, 58.788864612579346, 52.85012148320675, 52.19847545027733, 51.31481006741524, 53.315159529447556, 55.216699093580246, 55.87307587265968, 61.41342177987099, 65.25970458984375, 59.640011340379715, 60.38220651447773, 61.844976022839546, 64.55968335270882, 59.87289324402809, 53.56805495917797, 47.61274851858616, 58.647793382406235, 61.36514537036419, 64.11465123295784, 62.035334408283234, 58.24833981692791, 57.792512476444244, 60.82334004342556, 61.421823129057884, 61.04240968823433, 58.43935176730156, 60.54203353822231, 60.1780890673399, 59.73437547683716, 56.590101197361946, 61.187216117978096, 57.41760179400444, 60.25596208870411, 56.74770154058933, 48.51773455739021, 42.973167076706886, 52.1280462294817, 57.437953501939774, 56.23804248869419, 53.68248201906681, 50.798839554190636, 47.23137438297272, 51.48303464055061, 54.89283487200737, 53.36708754301071, 51.339007169008255, 49.905845671892166, 45.49929812550545, 44.67902094125748, 46.76783725619316, 49.95926320552826, 54.81382951140404, 54.89759981632233, 56.721661537885666, 56.09876476228237, 56.87865771353245, 55.05463019013405, 51.01491495966911, 44.886075630784035, 45.62464579939842, 45.65219812095165, 43.88004541397095, 43.2923499494791, 46.903645768761635, 49.9460893124342, 50.79813279211521, 50.03302864730358, 50.730279833078384, 52.23796673119068, 57.229534685611725, 61.19147948920727, 63.81300821900368, 65.71338504552841, 67.87100806832314, 69.43488255143166, 66.20553463697433, 72.18632251024246, 68.7730872631073, 72.02201172709465, 67.67901197075844, 67.85821795463562, 66.85624971985817, 66.53344944119453, 65.2337671816349, 67.08665415644646, 66.92712351679802, 67.3386262357235, 67.93489024043083, 75.84117919206619, 71.39402702450752, 84.80836361646652, 56.25269830226898, 0.045985945107531734, 0.15485503507079557, 0.050500184515840374, 0.11907821812201291, 0.23032153869280592, 58.6251275986433, 65.44141843914986, 53.83671194314957, 36.90311819314957, 28.029821030795574, 54.664045348763466, 1.084844993893057, 0.011580642112676287, 0.017720347277645487, 0.024245790191343985, 0.03922682401025668, 0.017129089355876204, 0.018004842168011237, 0.040379902566201054, 0.15497827611397952, 0.05933584223384969, 0.07808969137840904, 0.05549187721044291, 0.06701011676341295, 0.04003205423941836, 0.02989616863487754, 0.012393414417601889, 0.08007193813682534, 0.047315825504483655, 0.07343856283114292, 0.1277470967033878, 45.65323926508427, 69.10890564322472, 36.70431286096573, 32.82471723854542, 51.77151136100292, 91.5945790708065, 23.174800649285316, 0.3327379625989124, 0.5804238421842456, 1.3179669971577823, 1.8985580303706229, 76.03682309389114, 98.25199663639069, 87.00863555073738, 92.25833505392075, 84.82224807143211, 88.91588240861893, 82.63677254319191, 79.95511963963509, 69.84556451439857, 71.33609533309937, 69.51781690120697, 71.04545652866364, 66.4715051651001, 68.49111199378967, 59.25194576382637, 60.26666231453419, 59.404579773545265, 59.094166830182076, 56.42566502094269, 60.68938963115215, 56.03255711495876, 57.392781525850296, 55.163232162594795, 57.32748202979565, 57.80733548104763, 57.4892583489418, 48.888245075941086, 50.53464353084564, 51.74683168530464, 53.423617109656334, 55.884878039360046, 56.87572807073593, 53.180167973041534, 57.31164447963238, 53.29862281680107, 57.80209556221962, 60.93123905360699, 68.8500027358532, 58.65932956337929, 55.923860147595406, 66.59591808915138, 61.636264622211456, 63.22495937347412, 56.22100420296192, 53.716193810105324, 55.47289274632931, 56.495387479662895, 58.21978434920311, 58.87143798172474, 63.441452756524086, 67.80729308724403, 62.557494789361954, 62.55154810845852, 64.76940169930458, 64.72964823246002, 65.14819577336311, 55.60589700937271, 49.87893171608448, 58.95599864423275, 63.2693599909544, 65.69409728050232, 66.04819267988205, 61.5229395031929, 61.9339482486248, 61.62397988140583, 63.49750354886055, 62.290285527706146, 59.32217359542847, 60.52648477256298, 63.03838558495045, 60.13603672385216, 58.10279242694378, 62.41451986134052, 59.795951172709465, 61.306693106889725, 59.6585201472044, 47.892888486385345, 44.294952750205994, 52.748640328645706, 59.66201215982437, 58.65570455789566, 55.68005383014679, 53.18853132426739, 51.48309163749218, 55.37209555506706, 57.201940566301346, 57.30409048497677, 54.3668594956398, 51.55949033796787, 48.170072212815285, 47.41616986691952, 48.966528475284576, 54.02708172798157, 56.57451443374157, 56.37056037783623, 57.85090394318104, 57.482699900865555, 60.82693465054035, 59.11672241985798, 53.12338002026081, 48.19908745586872, 48.77374202013016, 49.418894201517105, 44.88188065588474, 44.28551405668259, 47.94646941125393, 52.315402776002884, 51.50078348815441, 52.547517120838165, 53.02354417741299, 52.22089044749737, 59.506744891405106, 62.530071660876274, 67.22992166876793, 66.47328346967697, 70.37470892071724, 71.50019332766533, 70.12525230646133, 72.37909376621246, 70.95800802111626, 73.76892238855362, 71.04747042059898, 70.49969181418419, 69.62438598275185, 68.91874104738235, 67.84893125295639, 69.7922533750534, 68.57720777392387, 69.10080447793007, 67.61555537581444, 76.80163845419884, 73.51142540574074, 86.097961217165, 62.111782506108284, 0.02356483444600599, 0.15626282984158024, 0.034497354354243726, 0.0802888604812324, 0.6154254265129566, 64.01747524738312, 73.6615477502346, 57.022385001182556, 32.35708013176918, 39.04556103050709, 68.22802931070328, 3.374559497460723, 0.09438948080060072, 0.01632745668757707, 0.06204940131283365, 0.03963778828619979, 0.039000884571578354, 0.04002399822638836, 0.025657557307567913, 0.02707127256144304, 0.033477424512966536, 0.15789484226843342, 0.1296959022874944, 0.18763314496027306, 0.1341476454399526, 0.09493562727584504, 0.054501481135957874, 0.15719222137704492, 0.2833415928762406, 0.2084067341638729, 0.29773789225146174, 52.25535839796066, 79.23283159732819, 37.18399532139301, 50.46279698610306, 60.28016299009323, 100.06687045097351, 27.869995906949043, 0.39072115905582905, 0.6626590888481587, 8.567854352295399, 1.6306176641955972, 77.89855599403381, 101.95321083068848, 91.8779906630516, 96.50173455476761, 91.61816820502281, 93.90537187457085, 88.46715688705444, 83.23234498500824, 72.71049678325653, 76.11357137560844, 71.33334428071976, 76.61642879247665, 70.25704443454742, 71.71929717063904, 62.68464736640453, 65.83701521158218, 62.98487305641174, 62.08955369889736, 61.176797077059746, 64.20152977108955, 58.947487100958824, 61.454949751496315, 59.148515313863754, 61.01239129900932, 60.490884482860565, 62.34704688191414, 53.60199473798275, 53.97234186530113, 56.00378505885601, 57.54984989762306, 58.72852765023708, 61.06110468506813, 55.24253010749817, 60.59873029589653, 56.67823746800423, 62.20544368028641, 63.33671897649765, 69.47826102375984, 63.83174881339073, 59.88366946578026, 65.98969861865044, 66.29261836409569, 65.64055815339088, 59.921868816018105, 58.395752906799316, 58.31313394010067, 60.22487215697765, 59.822576344013214, 62.936570048332214, 67.18451410531998, 70.09062096476555, 65.86154669523239, 66.5931898355484, 68.46809282898903, 69.19096603989601, 65.7023960351944, 59.31372284889221, 52.74601086974144, 62.92479068040848, 66.94582611322403, 68.2753823697567, 69.17532607913017, 65.11145934462547, 62.98144184052944, 64.53982561826706, 66.08666941523552, 65.36875113844872, 63.29538479447365, 63.78233626484871, 63.369119837880135, 63.395471423864365, 60.03469616174698, 66.33472010493279, 61.411088705062866, 64.35218408703804, 59.881256595253944, 50.21886147558689, 47.80424304306507, 55.744844153523445, 62.21048980951309, 61.6179496049881, 57.5013493001461, 57.410651966929436, 52.726764902472496, 57.06923648715019, 61.62170760333538, 60.39235197007656, 57.257018610835075, 55.15810623764992, 50.584398061037064, 49.389677569270134, 51.923860386013985, 56.94144554436207, 60.257561802864075, 59.88792523741722, 63.3688310533762, 61.53112806379795, 64.57223027944565, 61.21879622340202, 55.35663038492203, 51.17175534367561, 51.507372334599495, 51.46239794790745, 50.53440034389496, 47.648709788918495, 51.21651314198971, 55.62428422272205, 53.788302540779114, 55.22887364029884, 55.26409775018692, 55.78413404524326, 63.04853104054928, 64.8216412961483, 70.61441525816917, 69.17918667197227, 73.32809284329414, 74.706339687109, 71.67467996478081, 76.09799221158028, 73.41180235147476, 77.75221824645996, 73.86350691318512, 74.49108123779297, 72.98085987567902, 71.0143817961216, 71.125009059906, 74.35528412461281, 74.12854269146919, 72.77235746383667, 74.7820696234703, 80.57942613959312, 79.6258445084095, 91.56453028321266, 64.61913496255875, 0.17773127707187086, 0.4711710655828938, 0.2431339761824347, 0.4159361607162282, 1.4769657840952277, 73.17673936486244, 78.44671458005905, 71.15624338388443, 53.02691079676151, 38.37600655853748, 82.99241825938225, 3.3505153376609087, 0.23284044727915898, 0.07779803476296365, 0.09583710663719103, 0.12183049504528753, 0.13927907712059096, 0.17303098866250366, 0.0725221069296822, 0.22967897239141166, 0.0923337168933358], [0.05028785606555175, 0.10598556793411262, 0.010433240058773663, 0.057796572291408665, 0.027304204886604566, 0.03197293161065318, 0.018851291279133875, 0.06420208970666863, 0.14955678343540058, 0.7321255363058299, 53.5558158159256, 47.695633471012115, 40.12717679142952, 55.823093354701996, 51.06671378016472, 82.3292626440525, 15.926808323711157, 0.5774714006111026, 0.34460632887203246, 0.9529714670497924, 6.905458755791187, 93.33132147789001, 89.20491009950638, 85.4335668683052, 82.28079244494438, 78.779386729002, 76.42304196953773, 72.21043601632118, 68.31384390592575, 67.01589435338974, 70.33133044838905, 68.12037348747253, 66.54707551002502, 65.22910863161087, 64.92026880383492, 60.88182270526886, 56.855562552809715, 54.99629572033882, 54.20582793653011, 54.85495090484619, 56.81812696158886, 54.11733068525791, 55.94763167202473, 53.35839360952377, 56.87763176858425, 56.96646720170975, 53.20903122425079, 45.10859169065952, 47.681338638067245, 47.847207337617874, 51.15708813071251, 52.931376323103905, 52.237351164221764, 54.45375703275204, 54.294583573937416, 51.787231117486954, 57.160161808133125, 58.651463985443115, 59.38998095691204, 61.61180913448334, 44.42366324365139, 63.96894425153732, 64.12768453359604, 58.6863499134779, 55.197361931204796, 50.507839769124985, 53.080438524484634, 56.21690422296524, 60.1903510093689, 56.21661923825741, 65.56977555155754, 68.02237674593925, 63.237430304288864, 61.6345851123333, 60.421040430665016, 63.481833189725876, 61.47089369595051, 48.336260095238686, 49.26603600382805, 56.52478650212288, 58.166435211896896, 65.47291874885559, 58.50002311170101, 62.042314633727074, 65.29135689139366, 59.683632999658585, 62.73328095674515, 54.63514029979706, 61.72182083129883, 58.595253601670265, 59.22048345208168, 59.547098726034164, 54.09781873226166, 57.430004328489304, 62.779380083084106, 58.030174523591995, 55.63483625650406, 47.74026967585087, 46.91127575933933, 53.18781316280365, 59.37307186424732, 56.680551543831825, 51.22458390891552, 50.00596649944782, 52.18300648033619, 51.58334165811539, 55.1652954518795, 54.683063328266144, 56.14627741277218, 50.345409885048866, 47.78324916958809, 45.986014008522034, 46.55119188129902, 47.4368217587471, 51.8943777680397, 52.85898260772228, 55.73947884142399, 55.56883379817009, 57.3833542317152, 56.77307277917862, 53.73600974678993, 47.115795984864235, 46.23247638344765, 46.813161224126816, 47.49646335840225, 44.001992270350456, 43.12463074922562, 48.2832757383585, 51.7402770370245, 51.09587341547012, 50.141087248921394, 51.38637162744999, 53.753591403365135, 59.46398198604584, 63.14100667834282, 64.14767146110535, 66.51882782578468, 71.50791451334953, 68.63757133483887, 69.9943645298481, 68.60234722495079, 66.83262258768082, 66.24613165855408, 67.31012016534805, 64.80162397027016, 65.06896242499352, 68.17775040864944, 66.58946603536606, 69.30236846208572, 67.73877516388893, 65.4050923883915, 66.98729708790779, 76.04316115379333, 76.09530195593834, 76.44637271761894, 1.701336381956935, 0.1581700157839805, 0.07034806694719009, 0.1003079823567532, 0.7399153558071703, 42.773673981428146, 74.47119310498238, 50.90269938111305, 48.02993193268776, 31.807861402630806, 54.1398748755455, 5.650797905400395, 0.21421050711069256, 0.09841188410064206, 0.061284970652195625, 0.13550823961850256, 0.025331591205031145, 0.026908816435025074, 0.046407715053646825, 0.019834525628539268, 0.0578920421685325, 0.01223525068780873, 0.05821991930133663, 0.02302783865161473, 0.009480852149863495, 0.04105650747078471, 0.01394406983308727, 0.04285909511963837, 0.10678259000997059, 0.33121169137302786, 1.6008073138073087, 64.55636993050575, 57.04001225531101, 38.48973445594311, 50.3037641197443, 63.678351044654846, 88.04062977433205, 18.31876192241907, 0.7639217551331967, 0.6364679255057126, 1.1549575254321098, 8.756361287087202, 96.62858694791794, 91.5872074663639, 88.04361641407013, 83.22919115424156, 83.2940536737442, 79.18844237923622, 73.40750098228455, 70.10775044560432, 69.98875603079796, 72.24763602018356, 71.12810209393501, 69.8129166662693, 67.35321745276451, 67.63342201709747, 64.24192160367966, 59.634729623794556, 55.89056633412838, 57.24008671939373, 58.52677747607231, 60.518934577703476, 58.07090073823929, 58.0406429618597, 57.48958893120289, 60.048987194895744, 59.43940110504627, 55.04994884133339, 47.957416623830795, 51.10771358013153, 53.23031768202782, 53.61945100128651, 54.16558809578419, 53.94887052476406, 56.263805106282234, 58.142431899905205, 55.73173485696316, 58.40099282562733, 60.66396899521351, 62.69280172884464, 67.76215150952339, 49.303737580776215, 64.43432047963142, 66.52297720313072, 57.91738137602806, 58.477395325899124, 52.37130157649517, 55.6820373237133, 56.90658241510391, 63.90669599175453, 61.396474689245224, 71.17565274238586, 68.56401488184929, 66.69169574975967, 64.45845678448677, 62.58829213678837, 66.96863248944283, 64.47739496827126, 50.90554162859917, 52.7254805713892, 57.21572242677212, 59.623470827937126, 66.6810031235218, 59.73318614065647, 62.09257073700428, 65.8685003221035, 61.226027235388756, 63.0247101187706, 56.339174062013626, 63.22491757571697, 60.43059691786766, 60.369177013635635, 59.68362919986248, 57.02591501176357, 59.292254000902176, 62.19204939901829, 60.93932121992111, 56.73754468560219, 49.57550659775734, 48.407829254865646, 54.67677466571331, 60.99677033722401, 58.877418860793114, 55.99851094186306, 52.703696340322495, 52.41227477788925, 55.36635026335716, 57.67184615135193, 56.85784623026848, 59.29077968001366, 54.05502162873745, 51.55975252389908, 48.101763278245926, 50.40634721517563, 50.86224675178528, 54.76350501179695, 56.82561255991459, 57.31282241642475, 57.644727006554604, 58.925801664590836, 60.314896926283836, 55.35246200859547, 49.395844638347626, 49.26844507455826, 48.879007771611214, 48.9301872253418, 46.50200732052326, 45.220328494906425, 50.91359339654446, 54.129896610975266, 51.92453294992447, 52.609267607331276, 52.63178899884224, 55.33771499991417, 60.344121158123016, 64.8417118191719, 66.47462859749794, 68.5848681628704, 70.51432862877846, 70.9121672809124, 70.03959730267525, 71.80359184741974, 66.91480457782745, 68.71021583676338, 67.03107073903084, 68.29590886831284, 67.89671748876572, 70.04302471876144, 69.15992170572281, 72.09618374705315, 69.65171411633492, 68.91272976994514, 69.82164859771729, 79.15590092539787, 79.36909228563309, 82.83481791615486, 2.6682588597759604, 0.16806011321023107, 0.12198875803733245, 0.1599094466655515, 1.2493425607681274, 46.311819925904274, 80.97534209489822, 58.664584681391716, 46.712573021650314, 40.3370775282383, 67.68891423940659, 11.21127275750041, 0.29055509017780423, 0.13893997500417754, 0.06543374314787798, 0.10664230183465406, 0.03386885175132193, 0.03487984984531067, 0.045008187807979994, 0.033077781699830666, 0.04268703189154621, 0.17002098611555994, 0.219005775579717, 0.1095365738729015, 0.11374913767213002, 0.12936448882101104, 0.17214142077136785, 0.1656691063544713, 0.207111508352682, 0.42760794691275805, 1.8336489633657038, 77.42165878415108, 65.19668877124786, 52.086043283343315, 77.82781139016151, 71.25864028930664, 98.43099743127823, 21.290700249373913, 0.7501391228288412, 0.666373330168426, 2.3214880423620343, 9.560078959912062, 101.41195267438889, 97.37108990550041, 90.456562936306, 88.7770226597786, 87.42076143622398, 84.73474636673927, 78.6400406062603, 76.82276532053947, 73.79486739635468, 78.18768247961998, 75.59470921754837, 75.17795518040657, 69.42337676882744, 70.97848892211914, 70.17681553959846, 64.77784484624863, 60.488578006625175, 61.494456231594086, 62.096313536167145, 64.88318279385567, 62.601477429270744, 62.43355304002762, 59.971760138869286, 63.7426245957613, 62.680137008428574, 59.524109959602356, 51.8296330422163, 55.02583533525467, 55.81856019794941, 58.23302663862705, 59.11757357418537, 56.51559479534626, 59.5475585013628, 60.63774660229683, 57.18660458922386, 62.226897329092026, 64.60149630904198, 64.780915081501, 68.86215448379517, 52.783849239349365, 70.52220180630684, 67.72774815559387, 62.78599172830582, 60.5769232660532, 55.121050626039505, 58.26465234160423, 60.90047970414162, 66.39790311455727, 66.09393462538719, 74.78336915373802, 69.63947117328644, 69.76229578256607, 64.66538608074188, 66.61988720297813, 70.25022760033607, 68.37885841727257, 56.12990789115429, 53.6429413408041, 60.12848652899265, 60.29766485095024, 69.2954072356224, 62.49221049249172, 66.11569225788116, 69.80153247714043, 63.83154362440109, 67.4368965625763, 58.5015582293272, 66.97528973221779, 64.57705602049828, 63.90965983271599, 62.08196930587292, 57.34012775123119, 62.56331987679005, 68.62383127212524, 63.0081582069397, 59.066340923309326, 51.022575348615646, 52.24508374929428, 59.13858264684677, 65.15183597803116, 59.87083375453949, 58.123121336102486, 57.195765897631645, 56.88291348516941, 58.070718348026276, 60.5678341537714, 60.69727040827274, 63.07965137064457, 56.094436794519424, 54.946632385253906, 50.998743027448654, 54.020211696624756, 52.090321853756905, 58.51255103945732, 58.722972348332405, 60.25720842182636, 61.195739060640335, 62.30008900165558, 62.54146344959736, 58.23183350265026, 53.002371713519096, 51.056781113147736, 53.10079403221607, 51.813069730997086, 48.8206847012043, 48.349654376506805, 53.867041915655136, 56.68709859251976, 54.496417343616486, 54.7436548769474, 57.17620074748993, 57.3169831931591, 63.86745169758797, 67.857685983181, 69.7611178457737, 71.35077014565468, 74.84107285737991, 72.56524577736855, 74.20010045170784, 74.5328637957573, 71.09751373529434, 73.46363916993141, 71.31698995828629, 72.53934636712074, 71.62463665008545, 74.15246620774269, 73.58095407485962, 74.81698215007782, 73.7307496368885, 73.81411716341972, 74.56671997904778, 83.33451390266418, 84.86042842268944, 84.92355063557625, 3.1292318366467953, 0.31552901258692145, 0.3192162694176659, 0.2945658640237525, 2.651723097078502, 53.50221589207649, 86.9192187488079, 68.15821185708046, 64.86901715397835, 42.64682158827782, 78.2102532684803, 13.473850898444653, 0.7418439898174256, 0.4973579541547224, 0.23928540613269433, 0.3100766020361334, 0.1130433329672087, 0.1024968281853944, 0.14284669974585995, 0.0970689975656569, 0.09258903795853257], [0.02519125850085402, 0.06666259869234636, 0.03457608137978241, 0.03120821522315964, 0.0637259277573321, 0.015916917291178834, 0.047972403554013, 0.04290199125534855, 0.10452386355609633, 2.6322396425530314, 65.44119045138359, 38.17372441291809, 35.326096415519714, 44.90303032100201, 51.89058557152748, 80.9081768989563, 9.794577676802874, 0.40302454261109233, 0.4302081948844716, 1.0953004891052842, 14.783021248877048, 99.7766800224781, 83.39735493063927, 87.31410875916481, 76.36337757110596, 69.94160816073418, 66.5413074195385, 64.20238092541695, 66.43905490636826, 65.69816306233406, 66.8474417924881, 66.05804935097694, 64.77856680750847, 66.97045639157295, 65.31419366598129, 62.03292153775692, 56.36601962149143, 54.770857617259026, 56.22018724679947, 54.58858899772167, 55.489836037158966, 57.049705535173416, 54.35224927961826, 53.32961015403271, 54.599851593375206, 57.85734459757805, 50.61748668551445, 45.64737617969513, 49.18164253234863, 48.60455609858036, 52.85186178982258, 54.261095970869064, 50.21977722644806, 55.49390561878681, 56.170687302947044, 53.2784952968359, 53.16640891134739, 58.19992661476135, 58.681828156113625, 63.168965578079224, 55.09455844759941, 50.71557082235813, 66.48220539093018, 60.56635223329067, 55.646744817495346, 47.405971214175224, 54.71193417906761, 56.60916857421398, 58.45195949077606, 63.238152265548706, 58.148709163069725, 70.2184385061264, 60.780014768242836, 66.41409024596214, 64.12378594279289, 61.27988934516907, 56.19201175868511, 49.571824595332146, 51.705569699406624, 47.90519222617149, 58.83231908082962, 62.552178874611855, 59.571402221918106, 63.872414231300354, 63.27200464904308, 59.955124631524086, 56.076060980558395, 62.273486629128456, 62.64864809811115, 60.351948738098145, 57.98152193427086, 60.08399851620197, 57.42474541068077, 58.477919697761536, 56.26081086695194, 61.475651040673256, 56.5986355394125, 48.01140792667866, 45.685507133603096, 48.880664482712746, 57.805762365460396, 58.062647581100464, 51.10088534653187, 50.267400071024895, 53.63188773393631, 56.743776351213455, 54.519124925136566, 55.112527683377266, 54.32822696864605, 53.04011508822441, 47.239175364375114, 47.021203860640526, 48.086678087711334, 47.823686599731445, 50.11728912591934, 54.30255934596062, 55.99926330149174, 56.23930022120476, 56.294454261660576, 56.23398430645466, 53.867444694042206, 46.86882823705673, 44.948992654681206, 46.67715512216091, 45.568754598498344, 43.255700916051865, 42.80840791761875, 42.59930893778801, 51.55029483139515, 51.152547374367714, 51.969651728868484, 50.7512167096138, 50.96817746758461, 54.06962424516678, 63.36092747747898, 63.961990624666214, 69.62507754564285, 67.13182613253593, 68.88081908226013, 67.16448158025742, 66.0105063021183, 63.88379082083702, 67.362040579319, 64.10888314247131, 69.18313086032867, 68.69433268904686, 71.45993828773499, 70.99060267210007, 75.25731772184372, 69.37054440379143, 69.81296986341476, 66.13602876663208, 80.80241337418556, 70.50188049674034, 89.71985846757889, 9.450795873999596, 0.3990164108108729, 0.07577309224870987, 0.28338766540400684, 0.17443054559407756, 33.20737190544605, 80.13994932174683, 50.910032987594604, 46.14532805979252, 20.780581422150135, 56.86269856989384, 19.217223711311817, 0.15885580476606265, 0.08844287411193363, 0.04855252926063258, 0.021751845597464126, 0.03858621697872877, 0.07088489946909249, 0.1514846901409328, 0.04371465780423023, 0.04998272946977522, 0.04616718499164563, 0.0098126747252536, 0.020499521488090977, 0.03765315552300308, 0.023381620449072216, 0.07548710564151406, 0.049212012818316, 0.0563903248985298, 0.20751121424837038, 4.6413796953856945, 76.12097337841988, 43.0572185665369, 38.63753132522106, 48.702910020947456, 61.42340764403343, 90.90923264622688, 10.47383302822709, 0.5338486726395786, 0.3728998778387904, 1.1561754788272083, 17.377537228167057, 102.00038149952888, 85.64201608300209, 88.6685460805893, 78.82446750998497, 72.88136601448059, 69.14714679121971, 65.46913415193558, 68.62269893288612, 67.70190194249153, 71.46273493766785, 68.64223748445511, 71.60601004958153, 70.3609536588192, 68.74078139662743, 65.27982071042061, 60.75171388685703, 58.706739619374275, 59.16161321103573, 57.15329557657242, 57.54442758858204, 58.9896534383297, 58.6288969963789, 56.33612282574177, 58.00691217184067, 59.13099825382233, 52.82300613820553, 49.544770047068596, 52.70641319453716, 52.35204800963402, 54.78193782269955, 56.963719949126244, 52.96369358897209, 58.183370903134346, 59.15614150464535, 55.85647076368332, 56.90053693950176, 60.95754124224186, 61.796961799263954, 64.11640673875809, 60.057392343878746, 54.71323370933533, 67.68066108226776, 63.86821165680885, 59.430141001939774, 50.10067641735077, 54.98114973306656, 60.207704678177834, 61.85517467558384, 64.3375776708126, 64.72764194011688, 74.03205826878548, 61.85772813856602, 67.9376868903637, 66.40900611877441, 65.89166387915611, 60.02801991999149, 54.84361611306667, 55.28514102101326, 48.1127142906189, 58.44556823372841, 64.36086282134056, 63.94277885556221, 67.4519969522953, 64.08096224069595, 63.678427040576935, 60.0257134437561, 64.45667088031769, 63.45360830426216, 63.60018543899059, 63.64310793578625, 64.38843414187431, 58.956724405288696, 61.71636812388897, 58.63274618983269, 64.07289907336235, 59.45932723581791, 47.99544118344784, 48.926585018634796, 53.04358810186386, 59.86256919801235, 61.47782452404499, 56.46554388105869, 54.2078760266304, 55.66403388977051, 59.66174617409706, 58.90281669795513, 57.55128242075443, 57.47970566153526, 55.89138329029083, 50.81314578652382, 48.147064447402954, 50.287774577736855, 50.651183277368546, 53.06989029049873, 57.202438339591026, 57.73674286901951, 59.266818165779114, 58.42944949865341, 58.66754472255707, 56.3948068767786, 49.31801341474056, 48.22391152381897, 49.33110751211643, 46.278651505708694, 47.22151771187782, 45.98996199667454, 44.80105519294739, 54.19431835412979, 53.57686288654804, 53.01323153078556, 52.231503278017044, 55.764755085110664, 56.40508532524109, 65.93328684568405, 66.77367255091667, 70.37530928850174, 68.97585198283195, 71.70543551445007, 68.94787028431892, 69.06564116477966, 66.09071999788284, 69.5045556128025, 66.68804794549942, 72.53110840916634, 70.81111550331116, 75.63644617795944, 74.24976378679276, 78.4148570895195, 70.18025055527687, 73.622265458107, 67.85793676972389, 85.21319389343262, 72.75328248739243, 93.66227611899376, 11.826734282076359, 0.46225956408306956, 0.11439925161539577, 0.44196871225722134, 0.351644026231952, 36.56498573720455, 86.33879989385605, 60.92988632619381, 45.359408631920815, 25.840405113995075, 72.09802284836769, 29.637353271245956, 0.14338391076307744, 0.020179961975372862, 0.01766489956935402, 0.05554685922106728, 0.09993836312787607, 0.06655010394752026, 0.0910222677339334, 0.07153960730647668, 0.005856316538483952, 0.17405304475687444, 0.1848664481076412, 0.10817888891324401, 0.08374781042221002, 0.09270139911677688, 0.17853652214398608, 0.11527807320817374, 0.23841215064749122, 0.32569759350735694, 5.601183492690325, 90.28371021151543, 49.73948299884796, 50.479257702827454, 63.936402797698975, 69.3387097120285, 98.5849803686142, 13.691455721855164, 0.8026514144148678, 1.4143033465370536, 1.2947935843840241, 19.5145121589303, 108.7013827264309, 89.82730150222778, 93.71489569544792, 82.33313083648682, 78.15782368183136, 72.7420274913311, 68.26456055045128, 72.1260653436184, 70.44262647628784, 75.22939682006836, 72.78581634163857, 72.92589962482452, 73.41313987970352, 72.17482432723045, 69.49381738901138, 65.59096321463585, 60.91975226998329, 63.36199142038822, 60.80212578177452, 62.41485044360161, 61.929183304309845, 61.909040585160255, 59.11110632121563, 62.51301057636738, 64.23105418682098, 58.52004423737526, 53.21744777262211, 55.07326439023018, 56.68479971587658, 59.014287516474724, 59.804698303341866, 56.51741489768028, 62.66290493309498, 60.56461572647095, 57.822834849357605, 60.31526930630207, 62.86591283977032, 64.5036743581295, 67.33813226222992, 63.35163317620754, 58.07203307747841, 72.19583719968796, 66.25766783952713, 62.10060350596905, 51.44464910030365, 58.42519372701645, 61.237381026148796, 65.34802705049515, 69.20871868729591, 67.32506856322289, 73.17968800663948, 63.37136551737785, 72.94368267059326, 68.87400984764099, 67.85887911915779, 61.88436470925808, 59.01671938598156, 56.58735394477844, 50.0093787163496, 60.97595505416393, 68.55876356363297, 64.8016619682312, 70.87030112743378, 66.56264707446098, 65.26478111743927, 60.90427190065384, 66.40065416693687, 66.42375692725182, 66.51688233017921, 65.82565382122993, 64.29643347859383, 60.14111325144768, 63.63266609609127, 63.05761635303497, 67.31863170862198, 60.44386960566044, 51.670824363827705, 51.15303374826908, 59.45412151515484, 63.17461207509041, 63.23200419545174, 57.5907015055418, 56.33820131421089, 58.630660101771355, 62.562202736735344, 60.95678888261318, 60.24582803249359, 60.73421582579613, 57.78093829751015, 53.48483942449093, 52.839330062270164, 54.4812523573637, 53.968253284692764, 55.37529498338699, 60.77806167304516, 61.3986823707819, 61.270188465714455, 61.26617968082428, 62.48449690639973, 60.61618275940418, 52.46349222958088, 49.65747579932213, 52.16590739786625, 50.63792198896408, 50.253131836652756, 48.29423815011978, 47.6830143481493, 56.40148311853409, 55.87711505591869, 58.002021834254265, 56.40045337378979, 57.48898096382618, 57.9909036308527, 69.39080491662025, 69.27681863307953, 74.49605897068977, 70.98914355039597, 72.89991661906242, 72.08925291895866, 72.10876867175102, 69.82396647334099, 73.77715274691582, 70.2450142800808, 76.69538855552673, 74.03260543942451, 79.41490262746811, 78.75914141535759, 83.94800618290901, 72.91793525218964, 78.50200921297073, 71.67354002594948, 90.19665688276291, 75.75677812099457, 99.3367700278759, 12.517085038125515, 0.3799112141132355, 0.47835036471951753, 0.8246335911098868, 1.480176611803472, 41.494924798607826, 96.08748838305473, 64.41044256091118, 61.98461472988129, 29.522890113294125, 79.18351024389267, 31.314797960221767, 0.3474806371377781, 0.15248897921992466, 0.1521568829775788, 0.12299825699301437, 0.28368016064632684, 0.15946095198160037, 0.38839630724396557, 0.17463962343754247, 0.1446927772485651], [0.029573902138508856, 0.08280946116428822, 0.037416095001390204, 0.033732459851307794, 0.021264954048092477, 0.016550783766433597, 0.07940725583466701, 0.11885881700436585, 0.5365958658512682, 7.151083275675774, 66.6989229619503, 38.017624989151955, 44.96949255466461, 44.42715145647526, 60.82340843975544, 80.1225158572197, 6.440942231565714, 0.41537892655469477, 0.7382955739740282, 0.3879075881559402, 18.198646567761898, 102.72444024682045, 83.33920285105705, 89.20240983366966, 77.9206632077694, 72.29322597384453, 66.12676486372948, 64.46095705032349, 64.78383332490921, 64.57509532570839, 65.48225864768028, 69.72422942519188, 68.05693209171295, 68.7116065621376, 67.13619589805603, 62.283020317554474, 59.995676055550575, 55.99350281059742, 55.093388110399246, 54.242720156908035, 54.977433532476425, 54.227756559848785, 54.36836041510105, 56.05065554380417, 54.84539061784744, 55.78499659895897, 46.873460188508034, 47.52254895865917, 49.312914088368416, 50.152733623981476, 51.09832048416138, 51.67205549776554, 50.29578074812889, 55.070543736219406, 55.46466998755932, 51.63471110165119, 54.117642268538475, 55.42737118899822, 57.89247751235962, 58.755977377295494, 63.612888157367706, 56.45505644381046, 57.277358919382095, 62.52819076180458, 57.80742287635803, 52.05243028700352, 52.12251752614975, 58.70034836232662, 58.99349503219128, 63.29893760383129, 60.85726462304592, 58.009534031152725, 67.33325332403183, 62.128178626298904, 60.25870934128761, 63.568210154771805, 54.21321853995323, 46.97734281420708, 54.516491666436195, 57.41423897445202, 57.64868639409542, 60.430395528674126, 61.77269250154495, 61.8463059514761, 62.18630410730839, 62.54071108996868, 64.92614328861237, 62.05758221447468, 61.75782769918442, 65.95522686839104, 64.7027836740017, 63.93937423825264, 58.8524504005909, 61.1120143532753, 59.71492052078247, 58.86700361967087, 57.05896183848381, 47.63783097267151, 43.86161260306835, 51.06331676244736, 55.49694925546646, 55.426318645477295, 55.237586572766304, 54.36822362244129, 54.20489318668842, 57.482392117381096, 57.56491228938103, 52.0265156775713, 54.89558972418308, 56.91355504095554, 50.19175373017788, 48.36469776928425, 46.7287677526474, 48.796267211437225, 50.74356772005558, 52.00368270277977, 53.850053027272224, 54.39501978456974, 55.432037338614464, 55.01556448638439, 52.92980320751667, 50.22822417318821, 46.19593374431133, 45.709886625409126, 46.083866357803345, 46.41753785312176, 43.72060216963291, 40.437783524394035, 48.37490402162075, 51.35748937726021, 49.18648727238178, 52.96034976840019, 53.50461736321449, 51.16484351456165, 59.15374003350735, 64.57479134202003, 67.12518408894539, 68.6544880270958, 65.54388374090195, 64.82812374830246, 66.3926973938942, 63.74824069440365, 69.52082633972168, 68.83768379688263, 70.45679971575737, 72.18658849596977, 76.7155958712101, 74.62052509188652, 75.9289924800396, 71.71885639429092, 72.18354105949402, 62.23758615553379, 79.58363637328148, 68.72387230396271, 91.05830624699593, 25.04480190575123, 0.38457029848359525, 0.09240590559784323, 0.16448935872176662, 0.1803073161863722, 24.564766064286232, 80.69786578416824, 51.66463449597359, 56.48100525140762, 26.99485346674919, 40.066657438874245, 44.2078348249197, 0.27863435796462, 0.0977519441221375, 0.08691612791153602, 0.012449913192540407, 0.008439418579655467, 0.1142630452523008, 0.044593078637262806, 0.018757984762487467, 0.02755048844846897, 0.03907855032593943, 0.012785679355147295, 0.0550502585247159, 0.14288140257121995, 0.07970323174959049, 0.09474614955252036, 0.12053063081111759, 0.10407960653537884, 0.5054165795445442, 10.216514635831118, 78.36088478565216, 45.972878113389015, 46.468128338456154, 50.49743212759495, 68.92339199781418, 88.58340784907341, 7.170694023370743, 0.4928774305153638, 0.5961868213489652, 0.35857770417351276, 20.76082058250904, 103.83509784936905, 86.31256610155106, 90.57474419474602, 80.8916249871254, 75.11256828904152, 67.6583106815815, 67.25831374526024, 67.8490300476551, 67.18866348266602, 67.61085882782936, 73.91207590699196, 72.0584137737751, 71.47820010781288, 71.67471036314964, 66.06395423412323, 63.732794523239136, 59.59083817899227, 58.94582659006119, 58.97695451974869, 57.69837252795696, 57.442319467663765, 57.20793664455414, 58.78530040383339, 58.743210062384605, 59.381796196103096, 50.76392702758312, 50.85975028574467, 52.50975474715233, 52.252975925803185, 54.7445098310709, 54.981233328580856, 53.31626147031784, 58.827280551195145, 58.559983894228935, 53.31094555556774, 56.43301382660866, 57.84319795668125, 61.57446473836899, 63.046308159828186, 67.82817676663399, 60.262201353907585, 59.55692879855633, 63.97277444601059, 60.43911226093769, 54.310455322265625, 55.84773503243923, 61.14783503115177, 62.286641523242, 65.1063372194767, 63.28506834805012, 62.47982315719128, 66.2769328057766, 62.05644607543945, 63.0046433955431, 63.25100697577, 56.30551926791668, 50.59428513050079, 55.80638565123081, 57.97005034983158, 60.836327746510506, 62.7572500705719, 63.67640934884548, 64.02496844530106, 64.3842239677906, 64.38866212964058, 66.74043193459511, 63.9043553173542, 62.8915386646986, 66.13068625330925, 65.54760754108429, 64.99853700399399, 61.535459831357, 63.01750190556049, 62.30171911418438, 60.90189702808857, 56.60101041197777, 49.33741897344589, 46.124873757362366, 52.98151843249798, 58.07891070842743, 59.76613037288189, 59.53982971608639, 57.263337671756744, 57.90252037346363, 60.908580869436264, 60.1417326182127, 54.839098155498505, 59.00110602378845, 60.18737196922302, 54.06490109860897, 50.80193258821964, 48.99995528161526, 49.895392432808876, 52.7324265986681, 52.14959107339382, 55.41078507900238, 58.43240574002266, 57.78782732784748, 57.972204834222794, 55.095694586634636, 52.068985998630524, 49.49018217623234, 48.38898606598377, 48.843627870082855, 47.08940640091896, 48.60007233917713, 43.29733148217201, 50.26433363556862, 53.43618303537369, 52.725168988108635, 53.55212241411209, 56.692384108901024, 52.565558552742004, 60.885428711771965, 66.6701889038086, 69.72967073321342, 68.64770919084549, 69.61667999625206, 65.74294745922089, 68.93487498164177, 65.37644192576408, 73.14946442842484, 70.27307197451591, 72.10293218493462, 74.85408335924149, 78.67593348026276, 76.93770155310631, 75.91633155941963, 73.59898030757904, 75.216393917799, 63.517900854349136, 81.58663809299469, 70.59473991394043, 95.54898127913475, 27.112462855875492, 0.33903743082191795, 0.058384223375469446, 0.1759101654170081, 0.5054543993901461, 27.0286887511611, 85.33127635717392, 61.38342998921871, 56.16368047893047, 25.648637004196644, 51.73284463584423, 49.62628327310085, 0.4722897196188569, 0.07217495993245393, 0.036733278320753016, 0.04059369304741267, 0.022541889629792422, 0.01481327875808347, 0.029918507279944606, 0.057179142531822436, 0.04954996089509223, 0.2306071319617331, 0.13203049107687548, 0.1683253567898646, 0.18146099959267303, 0.13449204649077728, 0.11555494624190032, 0.2748596464516595, 0.24838091572746634, 0.6235025462228805, 11.923706028610468, 91.10350862145424, 51.872924119234085, 60.60244269669056, 61.67375721037388, 78.45986187458038, 96.3008089363575, 8.97474316880107, 0.5947262747213244, 0.8174475829582661, 0.44453784939832985, 24.082558639347553, 111.58887058496475, 91.47553905844688, 96.78838357329369, 84.9921977519989, 78.5390268266201, 75.01837894320488, 69.51168403029442, 72.41304114460945, 72.44005009531975, 71.59322753548622, 77.43311896920204, 75.73226943612099, 76.78928151726723, 75.80494433641434, 68.18009108304977, 66.37069657444954, 63.26964497566223, 63.61080966889858, 61.9833417981863, 62.60282255709171, 59.151551350951195, 58.98917466402054, 62.4552308768034, 61.0627917945385, 62.707776725292206, 54.380462765693665, 54.262555092573166, 56.50577612221241, 54.23957772552967, 57.741918191313744, 57.848783656954765, 56.770428121089935, 60.761627554893494, 58.86573448777199, 53.39997477829456, 58.60738255083561, 61.81737810373306, 65.54506927728653, 65.48035115003586, 70.29213935136795, 62.19472825527191, 61.70546270906925, 67.82892152667046, 62.73185983300209, 56.080871522426605, 60.54166115820408, 60.818567499518394, 66.77033632993698, 67.66142651438713, 66.57139420509338, 68.41735035181046, 63.577926233410835, 65.24838119745255, 68.41853588819504, 67.93522462248802, 63.19787062704563, 56.0517118871212, 59.40133474767208, 58.96299406886101, 63.85612830519676, 65.29479190707207, 66.95709630846977, 65.7328400015831, 66.90690100193024, 65.33508494496346, 70.6551718711853, 65.86140230298042, 67.44720920920372, 69.5093585550785, 68.40671092271805, 68.70502531528473, 62.883087918162346, 65.75561597943306, 65.45438334345818, 63.81802394986153, 58.70483972132206, 48.43626692891121, 50.03189630806446, 59.32448387145996, 61.2285503000021, 60.47372080385685, 62.29404352605343, 60.46212762594223, 60.840382128953934, 64.80676889419556, 60.593425780534744, 58.40050645172596, 60.478937923908234, 63.106694519519806, 56.11421473324299, 54.48651887476444, 52.38221079111099, 52.457545548677444, 57.14526280760765, 56.546126157045364, 59.30757857859135, 61.23509734869003, 60.291657373309135, 59.888229221105576, 56.690043434500694, 55.99294804036617, 50.88634505867958, 49.44371446967125, 49.363044798374176, 49.87900011241436, 50.859628692269325, 47.086229771375656, 53.000585809350014, 56.60040624439716, 55.08575811982155, 57.50274382531643, 59.244695752859116, 55.576418191194534, 64.75162625312805, 71.03678539395332, 74.03604805469513, 70.2528190612793, 70.77449306845665, 69.64229062199593, 73.7694999575615, 69.1726966202259, 76.64232060313225, 74.22842413187027, 75.85096746683121, 76.90333619713783, 82.27983489632607, 79.60790187120438, 81.84535101056099, 78.08789983391762, 79.6846729516983, 67.1974790096283, 87.24951222538948, 75.15077903866768, 98.64323124289513, 29.306385330855846, 0.4027610208140686, 0.2169457369018346, 0.5247101630084217, 1.0969482944346964, 32.34273590147495, 94.26739364862442, 65.2505698800087, 76.51685133576393, 37.30004109442234, 56.98338009417057, 59.92671735584736, 0.45926345454063267, 0.1380689608049579, 0.2496771508594975, 0.12132547839428298, 0.1667321883724071, 0.2939531172160059, 0.09257589452317916, 0.09720595349790528, 0.12971004762221128], [0.040092220151564106, 0.047101712189032696, 0.032724144621170126, 0.003302324776086607, 0.018742249376373366, 0.027711870316124987, 0.06148800370283425, 0.09752138852491044, 0.507623014273122, 10.318180080503225, 63.27036693692207, 36.91428579390049, 41.96616031229496, 40.24639159440994, 67.84289717674255, 75.41057869791985, 3.8793286867439747, 0.21292375662596896, 0.42533783591352403, 0.4558441723929718, 17.75123007595539, 103.19806203246117, 84.26521316170692, 89.18217971920967, 77.51149356365204, 75.6207226216793, 69.30213287472725, 64.7279155254364, 63.01085606217384, 65.69158181548119, 65.24386703968048, 66.36109828948975, 66.67740851640701, 67.18973502516747, 64.57486733794212, 63.39892543852329, 60.95214933156967, 59.09331567585468, 55.28956018388271, 56.03058882057667, 53.307476341724396, 55.51234982907772, 53.37265804409981, 54.275896176695824, 53.29905979335308, 54.61600832641125, 47.17526279389858, 47.00965628027916, 46.92313112318516, 49.433926194906235, 51.81670233607292, 52.55103953182697, 51.72083728015423, 55.40773764252663, 53.93617540597916, 52.80588045716286, 53.409751653671265, 57.07506537437439, 57.84904584288597, 63.14826808869839, 60.06164811551571, 66.03034883737564, 61.30146078765392, 63.78238946199417, 62.48993061482906, 56.24454773962498, 50.609978288412094, 55.20914889872074, 61.557046473026276, 61.92134812474251, 63.31038258969784, 52.907160222530365, 56.43231466412544, 67.99321711063385, 57.08165422081947, 57.06563428044319, 50.03229148685932, 49.734972640872, 49.47445102035999, 48.4316273778677, 56.59007079899311, 59.87328842282295, 58.50783549249172, 60.27568683028221, 60.473314225673676, 63.92856001853943, 54.50315438210964, 53.52693356573582, 53.709300979971886, 57.81756453216076, 57.28899009525776, 60.46569183468819, 60.77879123389721, 62.70183764398098, 57.84204661846161, 58.425892889499664, 55.97280912101269, 49.60373528301716, 42.03748628497124, 43.511472791433334, 54.338805601000786, 59.88617733120918, 56.44199654459953, 55.440305694937706, 52.76690594851971, 62.39388316869736, 58.19472849369049, 49.274745136499405, 57.985652312636375, 53.981313183903694, 49.84788358211517, 46.18754759430885, 48.40099722146988, 48.18916618824005, 49.67956401407719, 51.43681392073631, 53.345618695020676, 54.692669212818146, 53.2185573130846, 53.23368050158024, 52.46383801102638, 47.985698506236076, 47.71943919360638, 46.235466822981834, 49.64010313153267, 48.21259193122387, 46.64788529276848, 41.53793469071388, 42.29789011180401, 49.27220307290554, 51.916067004203796, 48.76628302037716, 51.82668060064316, 50.564042553305626, 52.063240706920624, 57.91161708533764, 66.1912702023983, 63.817841559648514, 62.069061398506165, 61.485082134604454, 67.04145178198814, 68.11516016721725, 71.68867081403732, 69.02207270264626, 76.90128430724144, 72.40252330899239, 70.83335191011429, 69.26358014345169, 74.96474862098694, 71.47449910640717, 71.3948705792427, 64.5899373292923, 77.75829792022705, 69.06291291117668, 87.05902844667435, 38.57673838734627, 0.09431024169316515, 0.04885964110144414, 0.174518401036039, 0.3533445834182203, 18.687986209988594, 80.26159599423409, 55.199600011110306, 57.06797115504742, 37.016918286681175, 35.78518018126488, 47.807685658335686, 1.1894027958624065, 0.04352877578639891, 0.007770355286993436, 0.0643641673377715, 0.01167938949947711, 0.08727656677365303, 0.024880560231395066, 0.06056691679987125, 0.07334358277148567, 0.05395642190705985, 0.043792034120997414, 0.02471180327120237, 0.06849990400951356, 0.03165445006743539, 0.08595893552410416, 0.09522506486973725, 0.19259429827798158, 0.7917569833807647, 15.034264717251062, 70.72759598493576, 50.69607026875019, 43.761731162667274, 43.846865594387054, 78.30108359456062, 79.72683548927307, 3.8534003030508757, 0.2606760762864724, 0.39009582542348653, 0.4951144417282194, 20.360730551183224, 102.51909926533699, 86.84901371598244, 92.58359760046005, 78.65937396883965, 77.7211283147335, 72.82174721360207, 67.85859793424606, 64.611976146698, 68.50626558065414, 67.29350745677948, 71.34164303541183, 69.14309620857239, 70.97297921776772, 67.84308716654778, 66.08311280608177, 64.0049359202385, 62.30772279202938, 59.0506249666214, 57.223781794309616, 54.49516341090202, 58.43630813062191, 56.697890013456345, 57.403618544340134, 55.738859474658966, 58.30474779009819, 49.369500651955605, 50.094817131757736, 51.423172652721405, 52.8066024184227, 55.22904083132744, 56.30188286304474, 52.81004883348942, 59.77959305047989, 55.4187798500061, 55.1685556769371, 55.84723725914955, 58.71745504438877, 60.92115439474583, 64.63634803891182, 62.127734050154686, 68.57678219676018, 65.69953098893166, 64.83768403530121, 64.09442111849785, 57.25880831480026, 51.729143634438515, 55.89003436267376, 65.44537022709846, 66.4265687763691, 65.7664605975151, 56.500498205423355, 61.70506753027439, 68.11556294560432, 60.44474735856056, 58.71471159160137, 55.127628073096275, 55.3696408867836, 53.13078962266445, 51.961341574788094, 57.70684987306595, 63.172731176018715, 61.491154208779335, 62.772886231541634, 62.778418734669685, 63.32370847463608, 55.39791896939278, 53.91358181834221, 55.55741921067238, 56.26074247062206, 57.165565118193626, 61.55291989445686, 62.29580283164978, 62.33548030257225, 59.540281891822815, 58.330863788723946, 57.60420598089695, 48.57839070260525, 47.7635358273983, 47.254268154501915, 57.68235258758068, 62.96753838658333, 59.4429425150156, 58.289461210370064, 57.21582502126694, 63.496135622262955, 59.11335960030556, 53.66887114942074, 59.85310770571232, 55.84989711642265, 53.805831000208855, 49.29724372923374, 52.146053463220596, 48.962128311395645, 52.290947288274765, 52.91376046836376, 55.592977702617645, 56.14053972065449, 55.24720385670662, 54.87083025276661, 54.90237236022949, 50.188132524490356, 49.6403843164444, 48.10818113386631, 50.121552497148514, 48.892052471637726, 49.52051214873791, 44.447001591324806, 45.2384003251791, 51.90736547112465, 52.89546065032482, 50.84349475800991, 55.27097538113594, 52.2819759696722, 52.99132950603962, 59.31379124522209, 66.9738458096981, 66.39550164341927, 65.07845431566238, 64.7341775894165, 68.95192846655846, 69.3809786438942, 72.92096748948097, 71.763686388731, 77.79128015041351, 73.0416490137577, 73.0413830280304, 72.14149251580238, 79.56337586045265, 72.23978564143181, 76.67785629630089, 67.36768707633018, 82.11250707507133, 72.0380012691021, 90.91973528265953, 42.14729659259319, 0.07444423230481334, 0.10517855655052699, 0.29586399905383587, 0.5459779780358076, 20.721017718315125, 87.1715784072876, 61.218256652355194, 64.65479224920273, 38.73880349099636, 45.00988058745861, 56.87287822365761, 1.7644131160341203, 0.24605031969258562, 0.09630426633520983, 0.09140257388935424, 0.04426712737767957, 0.041634788940427825, 0.00857197914228891, 0.053196251174085774, 0.14853201108053327, 0.17279072577366605, 0.11798789928434417, 0.10964840810629539, 0.24649244674947113, 0.1120504729624372, 0.13600510748801753, 0.16906446166103706, 0.36835983395576477, 0.8177220588549972, 16.867929473519325, 87.26757645606995, 51.241481602191925, 54.638909697532654, 57.782351821660995, 87.22666785120964, 87.67806842923164, 5.805461956188083, 0.314066773862578, 0.4921126621775329, 0.54168492089957, 22.939701564610004, 106.11737698316574, 90.667345225811, 98.32648023962975, 85.75622275471687, 84.20317009091377, 76.40813916921616, 73.90186965465546, 69.98242557048798, 73.5252034664154, 71.98673442006111, 75.14326304197311, 75.02753645181656, 75.49659088253975, 73.16724747419357, 69.645786434412, 68.48493352532387, 65.82538023591042, 64.43590879440308, 64.19694721698761, 58.70575547218323, 62.03180059790611, 59.28215034306049, 61.73686042428017, 57.73880235850811, 60.13657249510288, 54.02692973613739, 54.344961270689964, 54.898861348629, 54.45832058787346, 57.90715992450714, 59.38173159956932, 57.17344589531422, 64.21997398138046, 57.59885586798191, 56.72432899475098, 58.17522794008255, 61.34938761591911, 62.67085790634155, 69.03955176472664, 63.873668164014816, 71.7412219941616, 66.72742143273354, 65.97771406173706, 67.3760998249054, 60.312966629862785, 53.76040443778038, 60.81357076764107, 68.64922910928726, 70.16813680529594, 68.50449487566948, 60.927351862192154, 70.21640941500664, 67.7384939789772, 62.26781353354454, 61.62969097495079, 58.66744592785835, 58.381575867533684, 58.02671290934086, 52.79676094651222, 60.66344082355499, 61.41191706061363, 63.28449837863445, 67.07422122359276, 65.72748988866806, 66.56542092561722, 56.49951405823231, 55.33948950469494, 58.65582995116711, 61.53570681810379, 58.87361906468868, 63.07526260614395, 64.28633362054825, 66.25502318143845, 62.40126997232437, 62.885892167687416, 58.18172559142113, 51.147455647587776, 50.95921754837036, 52.89825730025768, 59.805838242173195, 66.7407739162445, 62.005091831088066, 59.44073483347893, 60.169015154242516, 64.93271693587303, 64.75932464003563, 56.404815539717674, 60.512056946754456, 58.9187378436327, 55.47107644379139, 53.768125623464584, 54.148204028606415, 53.70446763932705, 55.753435492515564, 56.96938544511795, 59.80840690433979, 59.79627035558224, 57.51922734081745, 59.74342659115791, 57.45033323764801, 52.36501291394234, 52.89097309112549, 51.14820420742035, 54.73567150533199, 52.31743946671486, 53.49435791373253, 48.33632089197636, 49.91172395646572, 55.00584460794926, 58.57660800218582, 54.81501504778862, 58.45105893909931, 53.38625751435757, 56.648952439427376, 61.420907378196716, 70.00682786107063, 68.16711097955704, 67.73431420326233, 67.78469190001488, 72.36190348863602, 72.78851419687271, 76.4443664252758, 74.03305381536484, 82.70731195807457, 76.45075008273125, 76.52011916041374, 74.43818807601929, 82.83926367759705, 77.06599026918411, 81.65745109319687, 73.46766695380211, 86.5796309709549, 76.24812215566635, 95.7712085545063, 43.734847605228424, 0.10788385552586988, 0.2725645696045831, 0.47112908971030265, 1.3637507404200733, 25.027425438165665, 97.70236372947693, 66.28861337900162, 80.12484133243561, 50.929560139775276, 50.59932366013527, 68.82360935211182, 2.3364910623058677, 0.29448556364513934, 0.24325319478521124, 0.15032797877211124, 0.1257062202785164, 0.19070008507696912, 0.21001934685045853, 0.15511438599787652, 0.185118748631794], [0.07650391475181095, 0.02428590327326674, 0.04595627775415778, 0.02812332626490388, 0.07580711971968412, 0.06548293269588612, 0.02090592897729948, 0.07197634637122974, 0.3336398204555735, 16.414351612329483, 60.22745981812477, 23.5174073651433, 48.52562673389912, 41.587347239255905, 73.35182636976242, 68.05440902709961, 1.6783098550513387, 0.12990683550015092, 0.2999367570737377, 0.5687064584344625, 16.344399265944958, 101.79121032357216, 81.10687583684921, 90.25572091341019, 81.58118158578873, 75.95104649662971, 70.5112735927105, 66.00482940673828, 63.39938521385193, 61.180190294981, 62.793245539069176, 68.19140687584877, 62.074464708566666, 63.68878148496151, 63.69166173040867, 62.69140340387821, 59.35223378241062, 57.7044939994812, 54.86819699406624, 53.334196507930756, 53.12635526061058, 54.04605410993099, 53.9556797593832, 54.893575832247734, 54.13945309817791, 54.538367092609406, 45.58777257800102, 45.81554375588894, 47.230850011110306, 49.38434645533562, 51.71142138540745, 51.61290407180786, 51.84659153223038, 56.115951240062714, 52.77990885078907, 51.064627692103386, 54.82746697962284, 55.536630526185036, 54.38715800642967, 55.8858659863472, 58.190598115324974, 63.23508583009243, 60.28409197926521, 60.817701146006584, 58.336240500211716, 57.95233190059662, 49.85037624835968, 53.1827974319458, 58.539540991187096, 65.71441099047661, 62.92723774909973, 61.29510372877121, 57.78444170951843, 57.474921718239784, 57.57237508893013, 57.905054837465286, 54.381302520632744, 57.646269723773, 52.34250672161579, 56.23500645160675, 56.507915407419205, 56.46131090819836, 61.253313571214676, 60.62687538564205, 61.01273328065872, 59.44271832704544, 55.19348993897438, 47.068195939064026, 47.79553771018982, 51.595850586891174, 52.00078345835209, 56.343555226922035, 57.91216805577278, 63.68682079017162, 57.01837621629238, 59.754540994763374, 59.151893332600594, 51.036243215203285, 45.57594761252403, 44.748135432600975, 58.316481560468674, 59.027769193053246, 58.60161066055298, 57.18934044241905, 57.0161647349596, 57.92735584080219, 49.29466746747494, 55.00650957226753, 56.99177764356136, 56.296623945236206, 52.94031344354153, 46.424343287944794, 47.464822456240654, 50.3014500439167, 48.95629942417145, 48.84801663458347, 50.64458683133125, 52.198471650481224, 53.77986319363117, 54.88259442150593, 52.45591163635254, 50.736325308680534, 49.036904498934746, 45.578995048999786, 48.72512362897396, 46.94199711084366, 45.26602864265442, 44.30808484554291, 39.952823147177696, 46.47792801260948, 50.31467713415623, 50.68644158542156, 51.591135039925575, 50.199406519532204, 53.276261016726494, 51.177348643541336, 59.08735379576683, 61.266476064920425, 63.79094660282135, 63.69671545922756, 68.94410848617554, 67.14592337608337, 70.99482044577599, 71.11463561654091, 70.80894201993942, 70.46789512038231, 68.38135868310928, 70.86435064673424, 73.05979683995247, 71.7599093914032, 70.98047241568565, 67.95442879199982, 72.23812893033028, 73.27156707644463, 84.26440760493279, 54.79660503566265, 0.10228654064121656, 0.1126067126460839, 0.6410627102013677, 0.48835982917807996, 15.021085124462843, 77.52553761005402, 58.64585168659687, 54.68203738331795, 32.799452394247055, 29.27901539951563, 52.73512825369835, 2.6443265564739704, 0.16998224600683898, 0.09425386815564707, 0.0527831977524329, 0.0694215326802805, 0.10071223761769943, 0.07235122000565752, 0.08142387887346558, 0.03652090163086541, 0.05372905754484236, 0.019531209873093758, 0.03709526456077583, 0.015436176290677395, 0.09964295866666362, 0.037506366134039126, 0.11023575862054713, 0.0980468958732672, 0.4612178262323141, 24.427203945815563, 69.07324075698853, 33.60100418329239, 53.39960999786854, 46.37087255716324, 84.72890987992287, 72.12570816278458, 1.9016701821237803, 0.19302895932924002, 0.5289219995029271, 0.6059444602578878, 18.393068835139275, 103.96674558520317, 82.46866956353188, 93.25899615883827, 82.01777815818787, 78.24857041239738, 71.591145247221, 70.30663177371025, 64.63511690497398, 64.82743978500366, 66.85776963829994, 69.13300395011902, 66.76209077239037, 67.40978881716728, 66.82907357811928, 66.76785886287689, 61.012015119194984, 60.33465586602688, 58.529129549860954, 58.167043179273605, 58.49919855594635, 57.15223163366318, 57.294268012046814, 57.443964779376984, 58.25345814228058, 56.91432259976864, 48.70029576122761, 49.69360426068306, 48.88821467757225, 51.53385691344738, 54.62935321033001, 53.665618523955345, 54.60769437253475, 59.90217447280884, 54.32256527245045, 56.24820314347744, 57.56062991917133, 57.5251018255949, 58.76376695930958, 57.93465904891491, 59.54055167734623, 63.63428480923176, 62.148442938923836, 62.125674560666084, 59.95723731815815, 61.07538051903248, 53.63023102283478, 53.21085512638092, 59.88039784133434, 67.59886667132378, 65.56596055626869, 66.418596804142, 61.75076387822628, 61.04184731841087, 60.597955137491226, 60.83652153611183, 61.71144358813763, 60.839842557907104, 55.73830850422382, 58.92898589372635, 56.86252757906914, 57.427192479372025, 65.69412007927895, 62.16177262365818, 64.21758010983467, 62.38312974572182, 59.03048984706402, 49.537086859345436, 51.06348015367985, 53.41618470847607, 51.00894547998905, 54.74477581679821, 58.21118541061878, 65.83079114556313, 59.64693456888199, 58.59603635966778, 63.472717478871346, 50.412046909332275, 47.69985504448414, 51.05744227766991, 62.10229441523552, 62.21357524394989, 60.48418924212456, 59.947775825858116, 59.39177446067333, 58.90738785266876, 53.76623712480068, 61.03531926870346, 59.011502265930176, 57.258192747831345, 55.16665957868099, 50.44942170381546, 49.11604665219784, 52.59845718741417, 51.44703157246113, 52.623277455568314, 55.51991142332554, 54.91606302559376, 56.86750151216984, 54.93905559182167, 53.774342089891434, 53.38900476694107, 50.1425501704216, 48.960817381739616, 52.470134273171425, 48.944102078676224, 47.60831035673618, 46.66902355849743, 42.19940319657326, 48.82030092179775, 54.43384230136871, 53.00587132573128, 54.395281970500946, 53.15126672387123, 54.04768422245979, 52.232096046209335, 61.6250704228878, 63.21552447974682, 66.406589448452, 66.88600212335587, 72.81619191169739, 68.90486419200897, 73.41332986950874, 73.76028925180435, 73.27577725052834, 71.4088462293148, 68.76491770148277, 72.34475880861282, 74.78557303547859, 74.25113171339035, 74.69859570264816, 69.58496689796448, 74.89142775535583, 76.05492532253265, 87.23048284649849, 59.688014164566994, 0.07638461451279, 0.15485672716749832, 0.8656452654395252, 0.599525417201221, 16.845404282212257, 82.18029543757439, 67.61009126901627, 63.31224448978901, 30.99275194108486, 35.85469365119934, 64.77814882993698, 4.506721096113324, 0.29666872462257743, 0.048735628224676475, 0.02163781460694736, 0.024733897007536143, 0.06838462621090002, 0.035183614600100555, 0.050866983583546244, 0.02319878309208434, 0.19223334733396769, 0.08763552876189351, 0.1487438942422159, 0.17976246104808524, 0.15734399057691917, 0.13806250412017107, 0.11657634924631566, 0.1688426930923015, 0.3548716561635956, 29.008380621671677, 84.0618708729744, 32.96247884631157, 63.98359626531601, 60.48483520746231, 90.62222644686699, 81.90327510237694, 2.504082494415343, 0.18889727478381246, 1.20528653729707, 0.7550233451183885, 22.436173483729362, 106.99388355016708, 89.8937751352787, 95.78426465392113, 88.75648096203804, 82.73287698626518, 76.91106498241425, 74.79934349656105, 70.55157423019409, 68.1993256509304, 71.77713766694069, 75.27703866362572, 70.07894799113274, 69.50630351901054, 70.80898761749268, 71.62370949983597, 64.97158885002136, 64.60221067070961, 60.80771908164024, 60.996622145175934, 62.657756209373474, 60.67354068160057, 59.84005160629749, 59.987118914723396, 59.456845968961716, 62.60766729712486, 52.671455070376396, 53.42827565968037, 53.32056283950806, 54.54767279326916, 56.985724568367004, 56.125032752752304, 57.035159915685654, 63.004024028778076, 55.65661668777466, 58.345227017998695, 60.300377905368805, 60.879683420062065, 60.17370790243149, 62.094178050756454, 62.41889342665672, 67.26689368486404, 65.54516807198524, 64.83367145061493, 63.41344065964222, 63.29255394637585, 54.304504841566086, 56.22694708406925, 63.10628414154053, 72.34004706144333, 70.55017590522766, 66.04638397693634, 64.76861894130707, 66.42214581370354, 65.57587042450905, 64.20978292822838, 63.004039227962494, 63.53419817984104, 60.470270588994026, 56.41998052597046, 57.61434763669968, 59.00707930326462, 66.07268616557121, 64.96297851204872, 63.904613703489304, 64.37014952301979, 60.51834560930729, 48.24536897242069, 53.12413237988949, 55.804219767451286, 52.803528383374214, 59.23136226832867, 58.072663843631744, 68.96053120493889, 62.309672087430954, 61.35951407253742, 62.51718655228615, 51.346397772431374, 48.14511515200138, 56.28568433225155, 66.15614488720894, 65.29919967055321, 62.681793719530106, 64.16471734642982, 61.42437279224396, 66.02037817239761, 60.0201353430748, 61.61475017666817, 62.780888602137566, 61.82160347700119, 58.13219904899597, 53.48905719816685, 52.55551189184189, 54.308559224009514, 56.020382568240166, 54.056579545140266, 56.24755717813969, 58.29261124134064, 59.77266602218151, 58.835290521383286, 56.43669202923775, 54.28158067166805, 54.20783802866936, 51.4140759408474, 55.04291921854019, 51.74161456525326, 51.34970359504223, 50.23675851523876, 44.99296769499779, 53.08233842253685, 56.74919866025448, 55.92281520366669, 57.79837556183338, 54.486408680677414, 57.34325498342514, 55.7193361222744, 66.41430303454399, 67.44088634848595, 69.16124403476715, 67.59010434150696, 75.23142591118813, 71.64090737700462, 76.22318789362907, 77.32088059186935, 77.33090445399284, 72.80160069465637, 71.0199598968029, 73.47190752625465, 79.11745458841324, 78.06967601180077, 79.24311384558678, 74.69144448637962, 78.57257142663002, 82.14028358459473, 93.26409548521042, 62.13549703359604, 0.2604208962293342, 0.19298633036669344, 2.6445497944951057, 0.9192767750937492, 20.338876023888588, 91.66702598333359, 72.36616685986519, 74.45242211222649, 45.80515131354332, 42.84269727766514, 76.00970774888992, 5.298702148720622, 0.49421142612118274, 0.2157377134426497, 0.11947777558816597, 0.1047318652854301, 0.2531613560859114, 0.23659005935769528, 0.18769762275042012, 0.15158867987338454], [0.039828642693464644, 0.08422822487773374, 0.06006462383083999, 0.0708127478719689, 0.09644639503676444, 0.04269116194336675, 0.11789672644226812, 0.11789831463829614, 0.3273851185804233, 25.497566610574722, 54.28279660642147, 25.51350485533476, 47.30990096926689, 51.097461730241776, 80.18974184989929, 66.16651073098183, 0.48488494532648474, 0.1786311756586656, 0.3263354249065742, 0.21876304876059294, 24.99445080757141, 103.94200131297112, 85.16234502196312, 87.71568641066551, 80.18608644604683, 76.01390272378922, 68.3363538980484, 70.76320007443428, 60.937292128801346, 59.934449940919876, 59.90380458533764, 65.29631942510605, 60.25332123041153, 60.41757121682167, 60.77428087592125, 61.39595031738281, 57.717052325606346, 58.02114240825176, 54.414497539401054, 51.65061704814434, 52.299797013401985, 53.138081431388855, 53.56862872838974, 54.27894741296768, 53.71763773262501, 55.51868788897991, 46.09985210001469, 45.27395121753216, 46.313115656375885, 48.99130694568157, 51.55914455652237, 50.8143275231123, 52.49176651239395, 56.75962910056114, 49.83656398952007, 52.58833833038807, 52.70477548241615, 56.21834434568882, 52.849106937646866, 55.16713835299015, 53.691430538892746, 58.01201909780502, 59.5741380751133, 57.727820947766304, 54.63171288371086, 54.816021993756294, 52.77544789016247, 51.19591824710369, 50.81829451024532, 60.67963935434818, 62.96143591403961, 63.85916814208031, 65.80477014183998, 63.938264697790146, 59.7667421400547, 54.24476444721222, 52.387230321764946, 51.406734734773636, 44.1545844823122, 53.543386682868004, 59.77545507252216, 57.95953631401062, 62.57162243127823, 62.9147744178772, 60.70909537374973, 59.98644635081291, 55.328029319643974, 53.16498398780823, 51.8537313491106, 48.568716421723366, 45.38436949253082, 48.21763426065445, 51.52966573834419, 59.10298615694046, 56.921591609716415, 58.431835770606995, 56.290251687169075, 51.4309736341238, 46.436863616108894, 41.63774013519287, 52.13855266571045, 55.60255318880081, 56.824639812111855, 53.07781286537647, 50.3418380767107, 49.49614405632019, 53.42522442340851, 56.1729633808136, 55.063947290182114, 57.40625560283661, 50.042904317379, 47.003409415483475, 49.188865944743156, 46.72051079571247, 49.332190454006195, 51.355232298374176, 52.64719717204571, 53.12741920351982, 51.888351291418076, 52.29505106806755, 51.710399240255356, 49.153938218951225, 49.64894525706768, 45.31585156917572, 47.384859547019005, 48.85917663574219, 46.48015469312668, 45.491937920451164, 41.252117827534676, 42.07216702401638, 51.63858689367771, 50.10235972702503, 50.13222232460976, 50.95186114311218, 53.41039001941681, 52.09809623658657, 53.55465687811375, 53.92017066478729, 60.94901069998741, 69.99281421303749, 69.78803560137749, 69.87400978803635, 72.18953713774681, 70.01790806651115, 68.54568466544151, 66.41016885638237, 73.6590626835823, 73.67179960012436, 74.88319739699364, 70.03515914082527, 70.18154248595238, 66.86473846435547, 71.1345237493515, 69.91827741265297, 81.70203790068626, 59.643689543008804, 0.4760779085336253, 0.20127028663409874, 0.3344830486457795, 0.5891614139545709, 13.195277396589518, 73.05980443954468, 61.975567415356636, 51.82180166244507, 47.92521335184574, 27.292730882763863, 55.23357778787613, 7.252202974632382, 0.4431574250338599, 0.16263884317595512, 0.12185112675069831, 0.09449260964174755, 0.02535894491302315, 0.06748425264959224, 0.06530525512062013, 0.018630157246661838, 0.1191320238285698, 0.05729500291636214, 0.08480037620756775, 0.09376638845424168, 0.05067658188636415, 0.005604732186839101, 0.1268064245232381, 0.01749496630509384, 0.19931267917854711, 33.314168974757195, 64.07373502850533, 25.09812254458666, 41.92842833697796, 60.71381852030754, 86.25034064054489, 72.39442214369774, 0.321392216719687, 0.14189296576660126, 0.14471703063463792, 0.1751841965597123, 31.017230227589607, 107.44094476103783, 86.57292053103447, 89.69617813825607, 82.6575118303299, 80.41950032114983, 71.44337877631187, 73.22885736823082, 64.26335245370865, 60.821603536605835, 61.96973092854023, 67.4372461438179, 64.57661524415016, 65.25909662246704, 64.27472904324532, 64.31901186704636, 62.05088697373867, 61.376666352152824, 56.27378337085247, 54.979063645005226, 54.57468934357166, 57.69519969820976, 57.395619973540306, 55.9257410466671, 56.20813049376011, 57.95290187001228, 48.92210505902767, 47.49147042632103, 49.739091619849205, 51.98219105601311, 52.502470538020134, 54.475476667284966, 54.46640655398369, 58.63984040915966, 51.09544783830643, 54.14455622434616, 56.655742675065994, 59.40533973276615, 56.10594257712364, 58.57128828763962, 56.94176472723484, 60.77309153974056, 60.77660255134106, 59.57978077232838, 58.03191863000393, 56.39500446617603, 56.52876488864422, 52.82454885542393, 53.69879454374313, 61.98387756943703, 65.35007134079933, 65.09770408272743, 68.65240573883057, 64.72948864102364, 62.35573701560497, 56.56772039830685, 56.40038497745991, 56.1930301040411, 50.82126595079899, 54.754522293806076, 60.45613154768944, 61.22699998319149, 64.5511794090271, 66.12201511859894, 64.53318357467651, 60.79568512737751, 57.008724734187126, 53.76533277332783, 52.35245078802109, 49.702047407627106, 43.986675292253494, 46.95666812360287, 51.30861259996891, 61.257223561406136, 60.87349355220795, 61.40429086983204, 59.44866880774498, 54.13028419017792, 46.26947499811649, 46.20329774916172, 53.39060828089714, 57.650757282972336, 57.74683892726898, 55.261795073747635, 54.87497203052044, 55.0075127184391, 59.17287960648537, 60.50112493336201, 57.7656365185976, 59.35078606009483, 52.01772674918175, 49.56247329711914, 50.77430807054043, 49.565269947052, 51.37748010456562, 54.01135437190533, 55.546251609921455, 55.373452082276344, 53.58269937336445, 54.820000380277634, 54.00410436093807, 51.4028475433588, 52.18847818672657, 48.377636075019836, 51.33385084569454, 49.34045121073723, 48.72187100350857, 47.65890844166279, 45.214993581175804, 43.923442885279655, 53.42344231903553, 51.6180831938982, 52.127434462308884, 52.72201135754585, 55.4815448820591, 54.32113274931908, 55.846614092588425, 58.17982189357281, 63.079305589199066, 70.78168988227844, 73.09226989746094, 72.61807054281235, 74.7539359331131, 73.08913126587868, 71.36283069849014, 70.19381582736969, 75.15674471855164, 76.16014167666435, 77.90622398257256, 71.99002504348755, 71.14940375089645, 70.32795622944832, 75.62269851565361, 73.34706142544746, 85.61148852109909, 64.60071355104446, 0.892092736903578, 0.29556019348092377, 0.6472551904153079, 0.5870637483894825, 15.242615137249231, 83.08254182338715, 67.0552222430706, 63.078773617744446, 45.27567632496357, 31.826366409659386, 67.20813363790512, 11.212946567684412, 0.709092419128865, 0.19358007819391787, 0.08069281146163121, 0.12591820734087378, 0.0466192568273982, 0.048618391156196594, 0.018673058948479593, 0.061114269265090115, 0.18080951267620549, 0.18861117685446516, 0.18691339530050755, 0.25832361658103764, 0.14057091873837635, 0.1545109011931345, 0.19505439908243716, 0.2687827037880197, 0.39452098484616727, 40.43994940817356, 75.62379285693169, 34.81850065290928, 61.668771877884865, 70.06507113575935, 96.68972566723824, 80.17806887626648, 0.7502349489368498, 0.3059390396811068, 0.6619419367052615, 0.20087684446480125, 32.80190326273441, 112.72354289889336, 90.38370564579964, 94.90696012973785, 89.70201462507248, 87.1304190158844, 74.68322172760963, 79.18676286935806, 66.36784672737122, 66.94432899355888, 66.72856897115707, 72.10471048951149, 66.85129478573799, 68.93906995654106, 69.31205034255981, 67.78186485171318, 64.64872777462006, 65.8220212161541, 59.03880760073662, 56.792535334825516, 58.27490419149399, 61.09884425997734, 60.38375303149223, 60.285045728087425, 58.25053229928017, 62.127433866262436, 53.352427929639816, 50.64876280725002, 54.26487676799297, 55.808471739292145, 57.308247461915016, 58.717622235417366, 56.69266529381275, 60.298379212617874, 52.742268070578575, 55.59894718229771, 59.19270694255829, 63.13727527856827, 59.25133399665356, 61.21336251497269, 59.102476984262466, 63.29768367111683, 64.45178434252739, 61.813262924551964, 58.49954813718796, 59.24044378101826, 60.02879127860069, 57.76402160525322, 54.98437196016312, 66.50654688477516, 68.96368503570557, 69.67506006360054, 70.15277802944183, 67.67608612775803, 63.95903438329697, 58.74082379043102, 59.783962815999985, 61.89005680382252, 56.139293387532234, 59.554671719670296, 58.6789745092392, 59.21838976442814, 67.0462167263031, 65.729670971632, 66.68116271495819, 60.71244679391384, 57.868987172842026, 53.98933835327625, 55.08935272693634, 49.83222462236881, 45.755909755825996, 48.425441309809685, 52.57631957530975, 62.40373224020004, 60.601975321769714, 64.55760106444359, 56.92498862743378, 56.53054319322109, 48.82114827632904, 45.89012995362282, 58.35669860243797, 60.301658436656, 63.60917955636978, 60.294898599386215, 59.51725892722607, 58.564794436097145, 63.07131841778755, 60.521453842520714, 61.27221755683422, 63.26445445418358, 56.84945248067379, 50.84827110171318, 54.9877043813467, 52.46116295456886, 54.86354984343052, 56.424753069877625, 59.38506402075291, 58.71784642338753, 56.456207782030106, 57.04942815005779, 57.312662824988365, 53.40920828282833, 54.73795138299465, 49.28795322775841, 52.659797295928, 53.23080025613308, 51.20015501976013, 50.945329293608665, 47.814707681536674, 47.71986857056618, 56.58247500658035, 54.4298031181097, 54.64052841067314, 55.82914263010025, 57.65742972493172, 56.61403611302376, 57.97871768474579, 59.89764131605625, 65.90079858899117, 74.56383213400841, 74.07257929444313, 76.30109131336212, 77.38992288708687, 75.41384652256966, 73.25433120131493, 70.43945744633675, 78.60094830393791, 78.45246747136116, 82.26389095187187, 74.83409643173218, 76.14273101091385, 74.0251350402832, 79.49583068490028, 75.12077584862709, 89.32094067335129, 68.47693875432014, 1.4640392339788377, 0.3076518274610862, 1.7355990246869624, 1.2115211714990437, 18.134040534496307, 89.57922041416168, 72.81741544604301, 74.08758848905563, 66.70990437269211, 40.93120224773884, 78.19332137703896, 12.336087450385094, 0.8518007677048445, 0.26134970888961107, 0.3018827276537195, 0.29846587975043803, 0.16963374830083922, 0.17989454849157482, 0.18760786741040647, 0.1539499859791249], [0.12120656407205388, 0.03514528267260175, 0.0347777043498354, 0.06493887907708995, 0.03975678424467333, 0.02850911874702433, 0.07789000170305371, 0.059950158683932386, 0.1642932536196895, 29.068875275552273, 45.99951848387718, 51.190777122974396, 58.25824588537216, 47.1062470972538, 85.28236538171768, 60.723511800169945, 0.14799193537328392, 0.044317749270703644, 0.16954497259575874, 5.709487181156874, 67.59499087929726, 88.8767521083355, 86.19418725371361, 81.08375787734985, 78.88706535100937, 77.71102845668793, 71.88008934259415, 65.6330193579197, 60.66515073180199, 59.601637199521065, 56.68211705982685, 58.26730079948902, 57.968621626496315, 59.527480378746986, 59.513896107673645, 57.84586541354656, 58.83815556764603, 57.36926458775997, 53.38957853615284, 53.212033063173294, 52.46243208646774, 49.64862987399101, 54.94478568434715, 53.89645613729954, 53.76629412174225, 52.84983649849892, 46.49667240679264, 45.47545060515404, 47.67654329538345, 47.235402166843414, 50.739197954535484, 48.4443224966526, 56.50847777724266, 52.95129865407944, 49.72763143479824, 52.23140828311443, 53.15437115728855, 57.29128137230873, 52.91712328791618, 52.701021283864975, 52.35876604914665, 50.90928062796593, 52.91868880391121, 57.30098985135555, 58.659979328513145, 54.268266186118126, 49.18143734335899, 50.383886620402336, 46.78737200796604, 52.24927872419357, 59.526484832167625, 63.51228475570679, 59.3311221152544, 63.53208929300308, 59.294628873467445, 59.00779366493225, 54.587065279483795, 46.52683138847351, 45.66656515002251, 47.83192075788975, 44.19072434306145, 56.97977788746357, 61.504179909825325, 63.34265045821667, 54.7477700561285, 50.363116934895515, 48.584922552108765, 45.99020518362522, 49.62635546922684, 48.128388449549675, 44.5847138017416, 38.19567583501339, 39.44368086755276, 47.20368526875973, 61.674517169594765, 55.658938363194466, 55.33908672630787, 47.686593756079674, 42.929587215185165, 50.45814223587513, 45.67677900195122, 53.244893699884415, 48.48622664809227, 53.690693378448486, 53.46647500991821, 58.32007996737957, 58.178909942507744, 57.42452882230282, 57.37861968576908, 55.27599111199379, 52.45075151324272, 46.56596928834915, 49.419802352786064, 47.24039889872074, 50.77965438365936, 51.663604751229286, 49.51080746948719, 50.29909797012806, 50.955980122089386, 51.2297972291708, 52.6473605632782, 53.92190717160702, 52.32687056064606, 49.43562850356102, 50.43131947517395, 48.042946234345436, 45.684975162148476, 44.93674971163273, 42.72123299539089, 40.1236467808485, 47.236492708325386, 50.611342415213585, 50.19682265818119, 49.40810278058052, 52.874994948506355, 51.51319742202759, 52.155640348792076, 54.01653349399567, 58.622866719961166, 67.08359152078629, 68.3765709400177, 68.93225312232971, 69.96921747922897, 67.38788679242134, 71.79561227560043, 70.66291585564613, 70.24483188986778, 72.99770817160606, 75.34646853804588, 73.2923823595047, 67.03055396676064, 66.40720501542091, 71.4831930398941, 72.25810825824738, 76.32552400231361, 65.422503054142, 0.5483867519069463, 0.20356485882075503, 0.74556321837008, 0.35492945462465286, 14.912410005927086, 72.42827832698822, 65.02569794654846, 50.46299837529659, 40.9971135109663, 30.160319209098816, 51.29232667386532, 15.286308042705059, 0.4380403464892879, 0.1668113755295053, 0.09982146002585068, 0.059330880976631306, 0.0286723262979649, 0.014762058508495102, 0.05794735814561136, 0.033850108811748214, 0.20549655047943816, 0.10904885668423958, 0.09208689341903664, 0.046094565841485746, 0.008443327842542203, 0.0087332125804096, 0.07670360442716628, 0.03461554879322648, 0.11155713771586306, 37.70000383257866, 57.4247682094574, 50.299462750554085, 45.45885309576988, 56.688208132982254, 89.52090874314308, 66.53251469135284, 0.03981646405009087, 0.168917516421061, 0.32425720361061394, 6.525219809263945, 74.53551605343819, 87.49182522296906, 90.34399777650833, 85.31982377171516, 82.57002532482147, 79.12645250558853, 74.461100846529, 68.84234994649887, 63.34892012178898, 61.0138314217329, 60.42947977781296, 60.74788749217987, 61.403747498989105, 62.88341090083122, 63.21364738047123, 60.11710613965988, 60.582003593444824, 58.61851595342159, 56.35049745440483, 55.19143424928188, 56.48051507771015, 52.641508877277374, 57.52005949616432, 57.472417652606964, 57.129942029714584, 54.12650719285011, 49.381420612335205, 48.542543426156044, 51.1762011051178, 49.528149738907814, 52.9278539121151, 49.92807447910309, 59.38475243747234, 55.84428481757641, 50.63111275434494, 53.44006262719631, 53.595345094799995, 59.00845102965832, 54.82473872601986, 55.62102019786835, 53.94441716372967, 53.063795417547226, 55.06425887346268, 60.1901838183403, 58.749453127384186, 56.217105612158775, 53.16694088280201, 51.60988323390484, 49.22029785811901, 54.947985112667084, 62.06867761909962, 63.97943168878555, 62.61566586792469, 66.73192039132118, 59.46940429508686, 62.94356927275658, 55.10824531316757, 48.6226811259985, 49.34822179377079, 49.439774081110954, 48.93868736922741, 59.840412586927414, 64.71823364496231, 65.17886772751808, 54.400529488921165, 50.349380671978, 47.27420948445797, 45.10621681809425, 49.6106281131506, 48.30624170601368, 44.56937022507191, 38.54370296001434, 38.97381708025932, 48.09735931456089, 62.79726952314377, 57.0464339107275, 59.1070519387722, 52.02668286859989, 46.06016702950001, 51.94884404540062, 49.01046171784401, 57.76260428130627, 54.14654351770878, 58.20416338741779, 57.83855840563774, 59.93150509893894, 58.61818917095661, 60.7777538895607, 58.329438865184784, 57.587866857647896, 54.57299843430519, 50.07915057241917, 50.77677793800831, 49.702818766236305, 52.81425520777702, 53.34784157574177, 50.41263207793236, 53.072018176317215, 52.98862785100937, 53.63400802016258, 54.80040103197098, 55.228831842541695, 53.05099010467529, 51.97970598936081, 52.64525927603245, 49.88017424941063, 49.01652619242668, 48.011457324028015, 45.614614337682724, 42.67327956855297, 49.612015038728714, 50.84502227604389, 54.06936965882778, 52.74140551686287, 53.72491434216499, 53.37026797235012, 55.1128126680851, 56.54073424637318, 61.890398785471916, 68.89454394578934, 71.07674404978752, 69.88073542714119, 72.16021791100502, 70.5588698387146, 72.5431689620018, 73.63878697156906, 74.73277106881142, 76.14382535219193, 79.58873569965363, 76.10412508249283, 69.64967742562294, 68.83941650390625, 75.35276859998703, 74.9740581214428, 80.79637169837952, 67.93963998556137, 0.9456628561019897, 0.21839452791027725, 0.6272607820574194, 0.3663783590309322, 15.4671716876328, 80.02034693956375, 69.77549627423286, 61.452335491776466, 42.92910844087601, 34.90459643304348, 63.205504417419434, 20.36488752812147, 0.28382348420564085, 0.31064823386259377, 0.14043955859960988, 0.0810429418925196, 0.08591197984060273, 0.03271584369940683, 0.06798539528972469, 0.021145876453374512, 0.372149744653143, 0.2006417914526537, 0.21756550442660227, 0.17164112417958677, 0.1368538720998913, 0.07107399869710207, 0.15123279037652537, 0.16143024084158242, 0.22841803380288184, 49.37296986579895, 62.666263952851295, 70.36792248487473, 79.96745377779007, 68.04778218269348, 100.82315146923065, 73.68454411625862, 0.2997608977602795, 0.40360472397878766, 0.465045438031666, 9.603010956197977, 80.83063066005707, 92.05202132463455, 95.57222843170166, 90.16202554106712, 87.81689777970314, 81.88369855284691, 80.23690491914749, 70.85515514016151, 68.88626798987389, 65.21002605557442, 63.89997035264969, 63.19596692919731, 66.9320860505104, 66.80771872401237, 66.37185171246529, 64.92495775222778, 65.79292237758636, 65.01760438084602, 60.1894960552454, 58.748430982232094, 60.908873453736305, 56.11897587776184, 62.61110991239548, 62.77827054262161, 59.25449922680855, 60.29425263404846, 52.8630293905735, 51.29678003489971, 53.40038135647774, 54.63067553937435, 55.34687630832195, 51.08125559985638, 64.51577290892601, 58.64880032837391, 52.07767993211746, 55.08054859936237, 55.7861365377903, 61.706750839948654, 56.682994812726974, 57.65736132860184, 56.604308634996414, 55.081441551446915, 58.604266718029976, 63.20912182331085, 64.56312596797943, 57.69481211900711, 56.21842794120312, 54.08515781164169, 51.05930417776108, 58.58958050608635, 66.08051374554634, 68.87071162462234, 63.488152250647545, 71.11842781305313, 63.57063442468643, 64.38433036208153, 57.95798979699612, 53.76643851399422, 51.28881946206093, 52.57900223135948, 51.77332766354084, 57.498469054698944, 64.44893449544907, 67.15122029185295, 56.15714102983475, 51.68320409953594, 48.50981578230858, 44.487450420856476, 50.213651955127716, 49.840561375021935, 44.76493813097477, 39.85583335161209, 40.46422630548477, 49.88135598599911, 67.02661737799644, 60.16433000564575, 59.09198194742203, 51.48445576429367, 51.30825161933899, 48.808202371001244, 51.002808809280396, 63.18602666258812, 58.419110253453255, 62.175634279847145, 59.37307566404343, 62.10205502808094, 63.36345054209232, 64.59237679839134, 61.86116695404053, 60.56031055748463, 57.71207459270954, 52.65712983906269, 55.770226791501045, 52.25382328033447, 56.06578633189201, 57.65293836593628, 54.22942467033863, 54.805561155080795, 54.33115281164646, 55.09755648672581, 56.713659167289734, 58.324278742074966, 55.25896802544594, 54.165671691298485, 55.57574562728405, 52.87592209875584, 51.11415043473244, 51.60293720662594, 48.623999655246735, 45.170763954520226, 52.01174587011337, 54.91524986922741, 56.3886284083128, 53.45010928809643, 57.36585237085819, 55.87195873260498, 56.26528702676296, 58.78006428480148, 64.44818213582039, 70.83024367690086, 74.04625430703163, 73.17628338932991, 73.8674359023571, 73.40878531336784, 76.79420605301857, 74.81449708342552, 77.40054711699486, 78.61643627285957, 85.47685414552689, 80.56648403406143, 73.3465826511383, 71.03728696703911, 80.2002976834774, 78.1457631289959, 87.27421090006828, 73.74963462352753, 1.3934763078577816, 0.36255410173907876, 2.380813783966005, 1.164336372166872, 20.27130614966154, 87.38453418016434, 76.43108233809471, 65.0075501203537, 60.019952952861786, 45.874778777360916, 73.87956485152245, 24.29476585239172, 0.832556284731254, 0.5351717735175043, 0.3105017635971308, 0.1932695190771483, 0.22765439352951944, 0.2443946327548474, 0.1555169714265503, 0.22489724069600925], [0.06423881117370911, 0.04877083942119498, 0.050714516764855944, 0.009673946915427223, 0.06548176752403378, 0.02040299219515873, 0.05368261394323781, 0.054722058557672426, 0.25060023413971066, 30.107255056500435, 42.17107951641083, 27.364685721695423, 43.59450973570347, 50.77981777489185, 79.29944202303886, 59.90425296127796, 0.12514108966570348, 0.15882600011536852, 0.10248404098092578, 0.16407795657869428, 53.044800236821175, 91.15434229373932, 79.513940513134, 86.05102613568306, 75.45593306422234, 75.760577917099, 72.84481957554817, 64.02053028345108, 59.74033735692501, 59.94792781770229, 56.276720613241196, 58.255350440740585, 57.23617672920227, 56.946750059723854, 56.16049624979496, 56.779422238469124, 56.11031994223595, 57.221517115831375, 55.134786888957024, 52.804831713438034, 51.164699122309685, 52.9546956717968, 51.14732265472412, 54.28338177502155, 53.4571199119091, 52.52206228673458, 47.29315906763077, 43.891156017780304, 44.132659658789635, 46.62539429962635, 48.37054185569286, 49.48132865130901, 52.68621727824211, 53.18779416382313, 48.67193028330803, 49.984281063079834, 53.36823508143425, 55.477418303489685, 55.10203264653683, 53.14829148352146, 50.862603932619095, 50.52862845361233, 49.746106043457985, 52.593737840652466, 54.7576305270195, 51.552057936787605, 48.98737035691738, 47.739916294813156, 46.011647433042526, 47.897391244769096, 51.345060244202614, 57.73952051997185, 57.42792584002018, 58.74126076698303, 59.46552850306034, 59.4030636548996, 56.19551137089729, 48.089045360684395, 45.765238255262375, 51.279091984033585, 48.86649124324322, 45.064464658498764, 51.450561583042145, 54.263892620801926, 43.38670648634434, 37.49874383211136, 45.760712698102, 42.72331528365612, 46.16988994181156, 47.770177870988846, 45.211752355098724, 39.81085516512394, 40.73739744722843, 38.472642973065376, 56.270637139678, 59.69654090702534, 47.11778327822685, 50.32769523561001, 42.56151236593723, 46.398592069745064, 48.26642744243145, 49.827433079481125, 56.8026389926672, 57.93433986604214, 61.03334717452526, 54.92976889014244, 59.08961087465286, 57.91238844394684, 56.19996853172779, 56.169547364115715, 49.40204590559006, 48.77320244908333, 47.64788903295994, 46.73962377011776, 49.88245792686939, 49.51856665313244, 51.43351949751377, 50.781140103936195, 54.86369423568249, 52.22946658730507, 54.2846243083477, 51.24147780239582, 52.51938343048096, 51.62184119224548, 47.755316868424416, 49.18749801814556, 48.973326310515404, 45.20001858472824, 43.93280178308487, 40.962858349084854, 45.08257068693638, 49.94654528796673, 48.92250783741474, 51.26607768237591, 50.129855051636696, 52.281626388430595, 51.622863337397575, 53.16494978964329, 54.97057110071182, 61.72894924879074, 67.63320922851562, 65.74935391545296, 66.66709586977959, 69.5945879817009, 72.05303326249123, 72.06415146589279, 71.69297978281975, 73.7830500304699, 72.46313005685806, 72.60506764054298, 66.59375980496407, 69.65464755892754, 71.0304245352745, 73.82099479436874, 76.2029729783535, 69.28139358758926, 2.2064506402239203, 0.24072986299870536, 0.5184177600312978, 0.4187887685839087, 5.166596062481403, 61.556841284036636, 69.78210031986237, 51.91065989434719, 41.178869158029556, 22.57989127188921, 48.333900421857834, 24.13491602987051, 0.5759474448859692, 0.05369338621676434, 0.09143319490249269, 0.07232919306261465, 0.05011670938984025, 0.03363427000294905, 0.026472403915249743, 0.07840075515559874, 0.00029234553721835255, 0.057112456852337345, 0.10544920296524651, 0.027858657849719748, 0.08087787340627983, 0.03105049214354949, 0.08783115146798082, 0.010675044759409502, 0.04661253668018617, 42.47906059026718, 51.82113289833069, 31.70842833817005, 45.743252635002136, 60.98257049918175, 87.51788422465324, 66.93887248635292, 0.17095074872486293, 0.14815482194535434, 0.03947587392758578, 0.6717889895662665, 54.30178038775921, 92.76047810912132, 81.26119315624237, 87.60306805372238, 80.27364134788513, 78.9976242184639, 75.32376855611801, 67.63853654265404, 64.93201017379761, 61.9959457218647, 58.725913390517235, 61.609928235411644, 60.94118312001228, 61.38639762997627, 59.90769177675247, 59.65765759348869, 58.36780160665512, 60.89993633329868, 56.367539539933205, 54.833584651350975, 53.910944759845734, 55.27931213378906, 55.22577300667763, 55.94747208058834, 55.382267609238625, 53.93853887915611, 50.339182019233704, 46.68261542916298, 46.91606730222702, 48.74191112816334, 51.47074989974499, 53.26407887041569, 56.46955266594887, 57.187182158231735, 50.29318928718567, 52.1507728099823, 52.91488900780678, 56.664284616708755, 55.91720290482044, 55.86369037628174, 52.26758614182472, 54.645726531744, 50.11872164905071, 55.80099754035473, 55.90728543698788, 54.2167941480875, 53.501995503902435, 50.808331444859505, 48.88830207288265, 51.1346997320652, 52.51654118299484, 58.54107230901718, 60.42992815375328, 62.01848231256008, 61.62632055580616, 61.43986076116562, 58.49687688052654, 53.343980982899666, 48.702051267027855, 50.865081399679184, 51.51903010904789, 49.014223515987396, 55.90511195361614, 54.822394251823425, 43.03750142455101, 38.86992685496807, 45.816911682486534, 44.31012153625488, 47.6325074583292, 47.754982486367226, 43.96621719002724, 40.76191373169422, 42.09849961102009, 38.73324818909168, 56.52039393782616, 62.308300361037254, 50.05923204123974, 53.24107110500336, 42.9898139834404, 49.38984476029873, 50.73482818901539, 52.54609979689121, 57.713157534599304, 60.857781395316124, 63.83939400315285, 58.386086225509644, 62.12409384548664, 60.1136939227581, 60.67423604428768, 58.47750931978226, 50.102800503373146, 49.88619692623615, 49.62562210857868, 51.18524082005024, 50.16428500413895, 50.91197848320007, 53.738061636686325, 51.670850962400436, 56.18432097136974, 53.77235859632492, 55.075703859329224, 54.426246508955956, 52.92781591415405, 54.56712394952774, 50.386090502142906, 51.25677578151226, 50.48190996050835, 49.11348558962345, 46.87002517282963, 43.960160315036774, 46.158410757780075, 52.50817783176899, 51.01924292743206, 53.52572903037071, 53.57644870877266, 54.85582485795021, 53.68119768798351, 55.582197681069374, 57.63291724026203, 64.56227481365204, 68.86163011193275, 66.53752282261848, 67.21498847007751, 73.50498095154762, 73.38172316551208, 74.79737520217896, 74.50630322098732, 75.74966490268707, 75.04059255123138, 73.63326206803322, 71.08283132314682, 72.9464641213417, 74.09942105412483, 77.56620302796364, 78.74944433569908, 75.25632977485657, 2.51102258451283, 0.2895510831149295, 0.16550399333937094, 0.4831319925142452, 4.792054435238242, 66.85803562402725, 78.01047518849373, 62.15377785265446, 47.00397178530693, 29.82156928628683, 60.84487348794937, 28.431913554668427, 0.3773654397809878, 0.1614242442883551, 0.18352918705204502, 0.06734304421115667, 0.031454099880647846, 0.10680935185519047, 0.006342341630443116, 0.023975995391083416, 0.12198946307762526, 0.1669675382436253, 0.2139581472147256, 0.11236305814236403, 0.16007481201086193, 0.11652431727270596, 0.20414754864759743, 0.11067456085584126, 0.3534408251289278, 55.49164094030857, 60.01604676246643, 38.76851789653301, 64.5812813937664, 68.59263494610786, 95.12878462672234, 73.64260196685791, 0.5752064846456051, 0.3519246174255386, 0.2447651870897971, 1.5209475927986205, 64.00944247841835, 99.98806267976761, 86.3086599111557, 94.42041143774986, 84.54643607139587, 83.82704347372055, 82.27134615182877, 72.5014927983284, 67.36903220415115, 65.51276341080666, 60.83220116794109, 65.22183582186699, 62.59156756103039, 67.37697377800941, 65.24078160524368, 64.61710587143898, 62.797455713152885, 67.37825810909271, 61.64944611489773, 59.4048685580492, 56.62450075149536, 59.61857669055462, 58.12414728105068, 59.276287257671356, 58.81215736269951, 56.74148887395859, 53.996345177292824, 49.16846103966236, 50.94211846590042, 51.47952742874622, 54.65632036328316, 54.36735726892948, 59.439815282821655, 59.78559672832489, 53.253975212574005, 53.80572460591793, 57.73651868104935, 59.519109427928925, 58.08375544846058, 58.98680739104748, 55.745976492762566, 55.252610966563225, 54.688732624053955, 60.7967034727335, 60.64112462103367, 57.09255963563919, 55.393913984298706, 54.54623647034168, 51.345763206481934, 53.987024277448654, 55.96663825213909, 63.53492774069309, 63.42007130384445, 62.52888612449169, 64.43767949938774, 62.518752068281174, 63.58899503946304, 54.553760066628456, 51.196864396333694, 52.94537857174873, 53.48848342895508, 50.32145597040653, 53.818127140402794, 57.56923645734787, 42.9140118509531, 38.64945128560066, 46.49572245776653, 45.500008687376976, 49.843692407011986, 48.15586477518082, 44.962755516171455, 38.10249723494053, 40.0207445025444, 38.64076115190983, 61.06335796415806, 63.59961926937103, 51.295187920331955, 49.62618067860603, 45.79490706324577, 48.87223653495312, 49.847165420651436, 54.431501626968384, 59.52857851982117, 61.677123829722404, 65.7963801920414, 61.20440639555454, 63.53669084608555, 63.04807126522064, 63.356633707880974, 62.65893414616585, 54.47526767849922, 54.73797418177128, 52.43652127683163, 54.449296072125435, 55.65871797502041, 55.1535464823246, 56.70436106622219, 55.68212851881981, 60.70158697664738, 56.350235268473625, 56.87000557780266, 54.22731578350067, 56.27667121589184, 57.71163001656532, 52.42193005979061, 53.97946648299694, 54.77412924170494, 53.63250710070133, 49.68967147171497, 45.985166653990746, 51.57341659069061, 53.34227867424488, 53.65510828793049, 55.82687795162201, 55.35929784178734, 56.0181824862957, 56.75032339990139, 59.97404761612415, 60.71330934762955, 67.6777808368206, 71.88762813806534, 69.63127121329308, 70.40319979190826, 76.5803611278534, 76.54785767197609, 78.47937002778053, 78.12451466917992, 79.6675206720829, 79.56542015075684, 76.14252582192421, 75.12891501188278, 77.66449615359306, 78.81335690617561, 80.35759404301643, 83.64849865436554, 79.59700405597687, 3.0792830418795347, 0.3495804697740823, 0.9960262442473322, 0.7016528339590877, 9.095228053629398, 76.38064384460449, 82.43489697575569, 68.6278210580349, 58.69001291692257, 34.95753139257431, 71.51802197098732, 35.00016890466213, 0.8335845451802015, 0.3860557219013572, 0.25187598599586636, 0.21076510136481375, 0.1762001373572275, 0.254631758434698, 0.16193835966987535, 0.14436212077271193], [0.024087744277494494, 0.010735497326095356, 0.051872582553187385, 0.02060086917481385, 0.04392192109662574, 0.06523927819216624, 0.006683505989713012, 0.06692393115372397, 0.1931840236647986, 37.791780307888985, 39.005461782217026, 37.597861513495445, 42.71595887839794, 53.73773105442524, 80.11131405830383, 55.15376687049866, 0.29586889722850174, 0.06465015394496731, 0.0899883743841201, 1.798791652545333, 26.748721674084663, 96.25767365098, 78.45917791128159, 84.39872279763222, 71.52038544416428, 75.21935015916824, 70.80568179488182, 70.61190739274025, 65.23057535290718, 61.246314346790314, 57.8495854139328, 56.57946936786175, 56.54043786227703, 55.19937202334404, 53.848715499043465, 56.04076847434044, 53.16271170973778, 52.82317712903023, 53.029673248529434, 53.8201904296875, 51.43214017152786, 51.693702936172485, 51.01189412176609, 52.20142409205437, 51.90721347928047, 52.24952571094036, 47.29892335832119, 46.71080991625786, 45.49842797219753, 47.376910373568535, 49.572405964136124, 51.34304255247116, 52.11577668786049, 52.704631090164185, 49.32386890053749, 45.99591627717018, 50.41263207793236, 53.51750627160072, 51.88775472342968, 50.320445224642754, 49.12206172943115, 51.352032870054245, 51.063324362039566, 50.89945435523987, 49.674168303608894, 52.55308382213116, 53.35653930902481, 52.0621919631958, 47.96785846352577, 46.73711210489273, 50.147440508008, 51.98505990207195, 56.05246804654598, 55.22526763379574, 55.358686074614525, 58.43455262482166, 55.86924187839031, 53.91343742609024, 49.53797981142998, 41.463101506233215, 47.47556447982788, 43.56449514627457, 46.372498869895935, 47.97257401049137, 36.55177764594555, 44.910189136862755, 43.57265330851078, 38.30474138259888, 43.43196205794811, 44.28014874458313, 41.866305470466614, 44.38927508890629, 43.68799611926079, 41.440188735723495, 45.15801943838596, 57.360555455088615, 45.37023425102234, 47.967242896556854, 47.00710281729698, 47.61905238032341, 51.838262379169464, 51.17462798953056, 54.874101877212524, 55.51638141274452, 61.577215790748596, 58.67490112781525, 56.3399226218462, 58.216451928019524, 56.391960829496384, 55.008002892136574, 49.927455112338066, 43.25434438884258, 48.303467854857445, 47.310075759887695, 45.81747405230999, 48.60569603741169, 50.72882831096649, 52.239083871245384, 51.11059382557869, 54.26549233496189, 49.15797360241413, 49.62368801236153, 51.57422974705696, 52.322212010622025, 48.65974433720112, 49.92567300796509, 49.05983626842499, 45.87015062570572, 43.4523593634367, 42.48643219470978, 43.527002558112144, 50.055618435144424, 50.433922335505486, 50.29537416994572, 49.69802722334862, 49.33895789086819, 49.45632219314575, 52.25712530314922, 50.52117705345154, 53.369002640247345, 54.79105353355408, 61.870366260409355, 65.65945073962212, 69.6995459496975, 71.16652563214302, 74.14768606424332, 71.40044867992401, 70.61921820044518, 71.95740759372711, 71.3078248500824, 67.58204117417336, 71.95029437541962, 72.15023204684258, 77.03188329935074, 69.72202554345131, 76.78612768650055, 5.2508684154599905, 0.4238287825137377, 0.3173934656661004, 0.6046765751671046, 1.457173121161759, 51.9049222022295, 73.22356805205345, 53.647945672273636, 43.86580377817154, 25.76132945716381, 46.736420542001724, 24.365440160036087, 0.24562805250752717, 0.09454935425310396, 0.043064692290499806, 0.045646483049495146, 0.04769859187945258, 0.08029339500353672, 0.047638811884098686, 0.1280719941132702, 0.02934155611001188, 0.07757147934171371, 0.05033467816247139, 0.019699887052411214, 0.030307244232972153, 0.0943965683109127, 0.014456429107667645, 0.03308108796773013, 0.10907551462878473, 49.50351566076279, 49.76073145866394, 43.11185963451862, 49.25342068076134, 60.62973663210869, 90.78561007976532, 63.55844087898731, 0.5812683468684554, 0.043465388953336515, 0.16151431133039296, 2.3292417638003826, 28.178961127996445, 98.74416142702103, 79.00169000029564, 88.76955986022949, 75.62747105956078, 76.87417656183243, 72.89941504597664, 72.39282622933388, 68.84481981396675, 65.39089635014534, 60.18368236720562, 58.267338797450066, 58.90397183597088, 57.71163001656532, 58.53069506585598, 58.48857432603836, 55.50934799015522, 56.63521617650986, 58.551981523633, 54.949676021933556, 54.39458280801773, 54.83176074922085, 54.74669091403484, 55.261468291282654, 53.33709955215454, 54.60324481129646, 50.35574533045292, 49.65140752494335, 48.34200158715248, 51.24596916139126, 53.09124134480953, 54.01729345321655, 56.199816539883614, 56.72615669667721, 52.01721377670765, 47.088182866573334, 50.48733986914158, 54.749358370900154, 54.902915731072426, 54.42222632467747, 48.986283615231514, 52.89222702383995, 56.096477285027504, 53.77314135432243, 52.882507145404816, 55.0861456990242, 56.265932992100716, 53.951454386115074, 49.417093098163605, 49.79217857122421, 52.05766640603542, 55.11703044176102, 55.953547954559326, 58.00200283527374, 57.01752886176109, 60.057966113090515, 58.65498639643192, 55.980841889977455, 49.42222662270069, 43.51175777614117, 48.68435941636562, 48.44379052519798, 46.78309723734856, 47.21567742526531, 37.17698089778423, 45.38360193371773, 45.37302330136299, 44.1667590290308, 44.554695412516594, 44.387967959046364, 42.13260278105736, 45.965563505887985, 42.963716983795166, 42.79014989733696, 44.11236114799976, 58.635995015501976, 48.30070920288563, 50.30746132135391, 48.43638852238655, 49.44517359137535, 53.56440335512161, 54.67811979353428, 56.219488084316254, 57.48836159706116, 63.62762376666069, 60.3243014216423, 59.58120569586754, 61.04883134365082, 59.988232254981995, 56.99886806309223, 53.16418223083019, 45.8756223320961, 48.572797402739525, 49.179149866104126, 49.60930198431015, 50.380113422870636, 52.428142726421356, 52.493381425738335, 53.173282742500305, 54.45267789065838, 51.59051187336445, 51.19550406932831, 54.06004875898361, 54.68806765973568, 52.7985430508852, 53.09526912868023, 49.70218800008297, 47.414957731962204, 46.316930651664734, 44.40276436507702, 44.95974227786064, 51.54291942715645, 50.91879531741142, 52.816554084420204, 52.56165236234665, 53.07661592960358, 52.47017227113247, 55.026431903243065, 53.33548843860626, 55.79298757016659, 57.35368922352791, 64.38456594944, 67.52958118915558, 71.60775035619736, 71.68171718716621, 76.2262961268425, 75.06694793701172, 74.00971546769142, 74.51527073979378, 76.17195144295692, 69.97771382331848, 75.5984254181385, 73.5467179119587, 79.9727126955986, 72.36593127250671, 83.89537140727043, 7.393893571570516, 0.6120586290489882, 0.27232218417339027, 1.3134935684502125, 1.4644714607857168, 57.89199873805046, 80.57141616940498, 60.84089130163193, 48.82221981883049, 27.65967909246683, 55.20580127835274, 32.029039934277534, 0.2368237468181178, 0.04116702068131417, 0.10494045331142843, 0.008343155532202218, 0.029069323354633525, 0.07937887610751204, 0.07638836235855706, 0.020971471749362536, 0.34135070513002574, 0.2293543124687858, 0.11536296005942859, 0.1246540478314273, 0.15295129269361496, 0.09854072093730792, 0.19142403529258445, 0.12337469655903988, 0.2742932690307498, 61.13532990217209, 57.349904626607895, 49.679013043642044, 62.94186316430569, 68.12295734882355, 98.33506017923355, 71.12710654735565, 1.524449698626995, 0.2961643016897142, 1.1128702713176608, 2.1892173774540424, 31.824924387037754, 103.51758688688278, 84.82590347528458, 93.36962342262268, 77.71759450435638, 78.48241746425629, 76.48514583706856, 78.4484700858593, 73.86182740330696, 69.61288779973984, 65.15990674495697, 61.50610640645027, 62.58218206465244, 62.65475057065487, 63.302114233374596, 63.11804071068764, 61.06556564569473, 62.413699105381966, 61.3932828605175, 57.94450432062149, 57.32807099819183, 58.35919886827469, 57.64004185795784, 57.34110049903393, 55.79652898013592, 59.265241250395775, 54.14035364985466, 51.184309870004654, 51.63687698543072, 54.86945852637291, 55.88898181915283, 55.74233628809452, 59.20389734208584, 58.02612394094467, 54.65810626745224, 47.658631056547165, 51.91897004842758, 55.82696154713631, 56.59222148358822, 56.322587952017784, 52.50076822936535, 54.5206106454134, 56.251569762825966, 56.56326323747635, 52.942403331398964, 58.24491620063782, 58.120419681072235, 54.56870086491108, 52.79772609472275, 50.39743289351463, 56.026606634259224, 57.737160846590996, 60.694580152630806, 61.33302189409733, 60.319243893027306, 62.09239214658737, 60.44027879834175, 58.18256534636021, 51.1872623115778, 45.1101154088974, 50.947145596146584, 47.47144170105457, 49.56486716866493, 47.564510107040405, 38.62447902560234, 45.415843203663826, 46.19707368314266, 46.0479848831892, 46.132659539580345, 45.173815190792084, 44.93391886353493, 50.902186408638954, 43.65596003830433, 40.723516792058945, 46.55010133981705, 59.282933101058006, 51.92220747470856, 47.417693585157394, 47.94981703162193, 50.489171370863914, 56.4091245085001, 57.616661712527275, 56.66042782366276, 61.14978052675724, 69.54550221562386, 62.71621227264404, 63.86691212654114, 64.9003654718399, 60.95479778945446, 61.59547761082649, 55.000141113996506, 48.44641238451004, 51.63382574915886, 51.680768430233, 50.93107245862484, 55.170478373765945, 56.2762076407671, 56.70056886970997, 54.974055513739586, 57.82114394009113, 54.31488208472729, 52.30371840298176, 55.156354531645775, 57.32243210077286, 54.50726576149464, 56.02620765566826, 54.94058310985565, 52.253044322133064, 49.10803288221359, 49.083835780620575, 49.01095189154148, 55.4691993445158, 55.9157095849514, 55.12624494731426, 54.98436436057091, 54.24047067761421, 54.288184717297554, 56.55936844646931, 54.37455028295517, 58.053189888596535, 61.683727875351906, 66.44806042313576, 72.11084336042404, 74.61436942219734, 73.28445598483086, 79.32962760329247, 76.29879623651505, 76.76376208662987, 77.29072540998459, 79.46821376681328, 74.79954108595848, 80.12690082192421, 79.73518744111061, 85.40708228945732, 76.10771968960762, 89.34820041060448, 8.291265293955803, 0.665220032678917, 0.7740731479134411, 2.3234720109030604, 3.761138403788209, 64.17143538594246, 87.26295590400696, 67.20603615045547, 63.09138514101505, 38.52657727897167, 70.96965819597244, 39.125102162361145, 0.3819833794841543, 0.168265821703244, 0.12782828765921295, 0.2714763436233625, 0.20599680254235864, 0.2792926429538056, 0.1514540839707479, 0.2716601884458214], [0.06182280136272311, 0.09088977953069843, 0.05013224254071247, 0.02455157729855273, 0.048894922801991925, 0.06193129222083371, 0.06223349104402587, 0.025905367838277016, 0.17083010519854724, 44.851767271757126, 45.13484448194504, 31.498217917978764, 37.09658481180668, 59.20093730092049, 75.54493188858032, 60.64923718571663, 0.8114532858598977, 0.2433948262478225, 0.5500872794073075, 0.8192078385036439, 21.53099175542593, 94.7883988916874, 75.93626528978348, 79.42182585597038, 69.85588476061821, 74.00919109582901, 69.99330818653107, 73.08299839496613, 69.50563475489616, 68.6200238764286, 59.33654062449932, 55.83133511245251, 55.15018366277218, 55.42122691869736, 52.34644331037998, 53.144503086805344, 50.70380665361881, 51.925292909145355, 52.11375519633293, 52.612774819135666, 49.7391752153635, 50.72082594037056, 50.92948034405708, 52.543770521879196, 51.99759542942047, 51.320578157901764, 47.1879693120718, 45.90149514377117, 44.90626394748688, 45.41593059897423, 48.54071572422981, 50.252968445420265, 50.3430388122797, 53.4803556650877, 51.177690625190735, 49.563316851854324, 49.52991284430027, 56.70097924768925, 55.39698801934719, 50.49245439469814, 51.61240629851818, 62.03800566494465, 62.6713290810585, 61.28804750740528, 56.37931130826473, 56.357352286577225, 53.08276019990444, 56.617163345217705, 50.43818950653076, 51.04100055992603, 47.75737635791302, 50.43402872979641, 52.65098936855793, 52.25208297371864, 53.52706275880337, 52.767950892448425, 54.35328282415867, 54.92379181087017, 46.439128294587135, 43.791753351688385, 45.38951821625233, 43.58177661895752, 42.91156478226185, 46.56705982983112, 40.98431959748268, 44.57046456634998, 43.02929386496544, 41.44833169877529, 44.30032566189766, 43.98074381053448, 38.55123795568943, 37.171862572431564, 40.37130989134312, 40.49805968999863, 37.38460175693035, 46.74174785614014, 44.85046774148941, 42.25318171083927, 51.11564755439758, 44.65216778218746, 49.309380277991295, 53.70715789496899, 57.60614387691021, 52.90434457361698, 54.86609190702438, 54.565360844135284, 56.24757617712021, 55.31303532421589, 52.17139050364494, 52.55387417972088, 44.46568138897419, 46.6918109357357, 45.66841945052147, 46.32908619940281, 46.82170316576958, 45.579542219638824, 48.378441631793976, 50.47175690531731, 52.33844093978405, 50.50634264945984, 51.40669673681259, 49.120579808950424, 52.25210577249527, 51.5590875595808, 49.49094973504543, 50.07244773209095, 46.86566300690174, 44.421789944171906, 45.104510709643364, 42.60964438319206, 42.76314474642277, 47.60625086724758, 49.82768766582012, 50.5907741189003, 48.12375269830227, 48.64864893257618, 52.37732045352459, 53.16718026995659, 53.6238169670105, 55.60194902122021, 53.9876664429903, 63.27811852097511, 67.9394879937172, 71.6134424507618, 71.26253888010979, 72.69137620925903, 71.71939596533775, 72.78631031513214, 71.33829921483994, 72.9403768479824, 69.06982094049454, 72.25637555122375, 68.96091118454933, 76.74524188041687, 73.92803505063057, 77.4080403149128, 23.421276323497295, 0.38897518243175, 0.05344017656170763, 0.7439953275024891, 0.6397337315138429, 51.29901431500912, 72.26238682866096, 53.83662834763527, 40.701409578323364, 30.559607483446598, 39.074808061122894, 29.674072600901127, 0.22422403853852302, 0.0807155211805366, 0.05701400354155339, 0.09236155485268682, 0.05175889666134026, 0.014161802046146477, 0.035093759070150554, 0.049864004395203665, 0.032112496191984974, 0.015660572062188294, 0.043347290993551724, 0.033613066843827255, 0.05709270088118501, 0.06631026408285834, 0.1400507177459076, 0.07716726860962808, 0.20187694783089682, 54.10234048962593, 52.9002445936203, 38.00274878740311, 52.24253788590431, 64.14962455630302, 84.28504049777985, 67.02811449766159, 1.2751153903082013, 0.33371145254932344, 0.3283792996080592, 1.479546558111906, 24.060884602367878, 97.59803652763367, 80.30051350593567, 83.97631466388702, 72.03810766339302, 76.70454606413841, 72.85715371370316, 75.58915391564369, 73.09157833456993, 70.63465297222137, 62.533244490623474, 58.653409481048584, 58.182778134942055, 56.82970494031906, 57.02934242784977, 58.209859281778336, 53.94662864506245, 56.352515146136284, 54.248028472065926, 55.31240455806255, 52.62051120400429, 53.69847536087036, 53.411681950092316, 54.666351824998856, 54.97810609638691, 53.80936101078987, 50.88159531354904, 47.46129244565964, 47.010089457035065, 49.07737232744694, 50.42126901447773, 52.67121188342571, 53.088224306702614, 56.49699479341507, 52.7558371424675, 51.62402227520943, 50.31323701143265, 57.586031556129456, 56.48786008358002, 51.88630700111389, 54.386671632528305, 64.91980522871017, 63.54717068374157, 64.72581803798676, 61.47233381867409, 58.95503729581833, 57.14265234768391, 58.54137249290943, 53.68237562477589, 50.975393280386925, 49.169604778289795, 49.856296330690384, 53.183162212371826, 54.32356461882591, 55.78127659857273, 54.998381808400154, 57.648826986551285, 56.99220322072506, 48.87877218425274, 45.822656974196434, 45.92661939561367, 47.18028612434864, 41.742181330919266, 46.438432931900024, 42.83295080065727, 43.98767463862896, 43.84851090610027, 42.74942748248577, 43.725097328424454, 42.849734500050545, 43.95652770996094, 40.54641589522362, 40.381736531853676, 40.4970071464777, 37.27870523929596, 47.99612894654274, 43.19067120552063, 46.991189271211624, 53.32626633346081, 46.499275267124176, 52.08338722586632, 56.58721335232258, 59.40370202064514, 54.36922296881676, 56.48883283138275, 57.13517054915428, 60.31115412712097, 55.51153287291527, 54.1579695045948, 54.99871999025345, 47.21992939710617, 47.95326344668865, 48.139183670282364, 50.468823462724686, 48.03292237222195, 47.94083811342716, 50.78098051249981, 50.183036997914314, 53.26405607163906, 50.51844879984856, 53.82546454668045, 50.60521334409714, 54.181117862463, 53.91455836594105, 51.36534735560417, 52.10384912788868, 50.1702506840229, 46.83203861117363, 48.02175857126713, 46.00931815803051, 46.1339058727026, 50.19684165716171, 50.458541214466095, 51.6961158066988, 50.63430458307266, 52.79986917972565, 54.03227984905243, 55.99350281059742, 54.74173977971077, 59.296566769480705, 55.07137209177017, 65.81682309508324, 70.75255304574966, 75.33667266368866, 72.99792096018791, 73.93932044506073, 75.05693167448044, 76.25547096133232, 74.32819917798042, 75.3493183851242, 72.59570494294167, 74.29162994027138, 72.80581846833229, 80.25604829192162, 78.18441465497017, 83.41010704636574, 33.73870499432087, 0.3020386380376294, 0.13889571331674233, 1.0489876242354512, 0.6760676787234843, 56.283108070492744, 80.29979914426804, 61.49293631315231, 48.6208838224411, 35.11670485138893, 49.175589457154274, 38.88519823551178, 0.19194763532141224, 0.13471366662997752, 0.08149886547471397, 0.05452605364553165, 0.04337647224019747, 0.05624303455988411, 0.05611346670775674, 0.12531264452263713, 0.17789364414056763, 0.2010515014990233, 0.12646824266994372, 0.11969646424404345, 0.11424525597249158, 0.19540916051482782, 0.25134101626463234, 0.2673171699279919, 0.5271110404282808, 65.83702281117439, 65.08499756455421, 41.038527488708496, 55.10075971484184, 74.2441400885582, 91.90255254507065, 77.35997289419174, 1.9589763320982456, 0.5598858848679811, 0.6088565883692354, 2.1942934300750494, 28.174494467675686, 100.26612415909767, 84.72481369972229, 87.87511065602303, 79.48167264461517, 80.97395896911621, 77.01645612716675, 80.73759645223618, 77.96477124094963, 76.49670481681824, 68.25534984469414, 62.293336763978004, 63.319745287299156, 61.6681145131588, 59.915713146328926, 62.028688564896584, 56.86398670077324, 61.21262535452843, 58.36387261748314, 60.27339555323124, 54.242693558335304, 56.854054033756256, 56.352883726358414, 58.244030848145485, 59.073997512459755, 57.04571194946766, 52.34553515911102, 52.39768736064434, 50.90486906468868, 52.843840420246124, 53.450888246297836, 54.95013199746609, 55.6876078248024, 59.06804323196411, 53.955691158771515, 52.21528574824333, 51.93479999899864, 58.77308025956154, 59.036447927355766, 52.94467180967331, 53.87708857655525, 68.32344219088554, 68.14690366387367, 65.42403817176819, 61.190628334879875, 63.146003410220146, 59.01856608688831, 61.45350582897663, 55.36499373614788, 55.788439214229584, 51.239414513111115, 52.87787899374962, 57.864776998758316, 57.76133894920349, 58.44541244208813, 57.64726147055626, 61.56044349074364, 58.68372045457363, 49.23466108739376, 46.16754546761513, 47.04823561012745, 47.62346774339676, 44.65570539236069, 45.28935559093952, 44.30194057524204, 44.59929741919041, 43.98457020521164, 41.21897220611572, 45.74672944843769, 43.38077500462532, 44.25647981464863, 43.550618290901184, 40.754317939281464, 42.07304857671261, 38.37634094059467, 48.618383556604385, 45.34295551478863, 48.06256838142872, 50.4921618103981, 47.563009187579155, 56.32841303944588, 60.55717572569847, 62.51893065869808, 58.813190907239914, 58.910040110349655, 61.426489278674126, 63.60523156821728, 61.27792865037918, 55.7017582654953, 60.41889354586601, 49.88460101187229, 51.111893355846405, 50.112334191799164, 55.64133010804653, 50.93613378703594, 51.086586713790894, 51.98934607207775, 54.99167136847973, 56.23790189623833, 53.50651726126671, 57.265446558594704, 53.37979406118393, 56.44817501306534, 57.355684116482735, 55.833656787872314, 54.19417396187782, 52.44124822318554, 49.55464191734791, 51.97839505970478, 49.55444812774658, 49.396650195121765, 52.22149461507797, 53.976829424500465, 55.10754615068436, 53.01595218479633, 52.93742559850216, 58.03613640367985, 58.9875977486372, 58.68939355015755, 61.74313008785248, 59.111832082271576, 68.67144271731377, 73.07694151997566, 78.91738772392273, 77.4624913930893, 77.1218852698803, 79.6904182434082, 79.88272592425346, 79.50983673334122, 78.4170001745224, 78.7556380033493, 76.71411395072937, 75.55240228772163, 82.37739086151123, 81.29761800169945, 86.84877812862396, 34.82328839600086, 0.5215867899823934, 0.5137503636069596, 2.656607022508979, 2.2363175125792623, 62.94317789375782, 85.81396445631981, 67.75698378682137, 60.46704836189747, 47.78981901705265, 62.42835491895676, 46.536524668335915, 0.37479953840374947, 0.3005845926236361, 0.171109197253827, 0.12177604367025197, 0.1461434829980135, 0.15047275694087148, 0.18203551095211878, 0.2020448216353543], [0.034094817165168934, 0.019266630515630823, 0.03718044456036296, 0.0385361479857238, 0.042008749733213335, 0.10201151555520482, 0.05785960289358627, 0.2095837952219881, 0.36809770739637315, 44.75236840546131, 53.45107443630695, 36.85241751372814, 37.93222077190876, 58.82593922317028, 74.23799201846123, 62.05739602446556, 1.772935464978218, 0.43144615658093244, 0.4582091298652813, 0.8613055420573801, 18.22500955313444, 93.477081656456, 75.90737923979759, 78.40952217578888, 71.02463364601135, 72.89366975426674, 72.4118024110794, 74.86039102077484, 72.03044727444649, 66.91130876541138, 60.583006739616394, 57.815896421670914, 54.68822345137596, 53.94936829805374, 51.74717366695404, 49.85334008932114, 51.42000362277031, 51.99461258947849, 49.525030106306076, 52.11121313273907, 50.204946622252464, 51.71460561454296, 51.7564831674099, 53.20171281695366, 51.34730592370033, 50.894966796040535, 47.441362515091896, 46.02484792470932, 46.12529173493385, 47.67879277467728, 49.74455192685127, 51.27154938876629, 50.46115167438984, 54.41244184970856, 52.436141297221184, 48.493332266807556, 46.832240000367165, 60.31222186982632, 56.273289397358894, 52.53603033721447, 59.93680961430073, 63.982821106910706, 65.99513992667198, 64.89420980215073, 61.65407046675682, 57.86866419017315, 55.78734487295151, 57.61310130357742, 57.99525059759617, 54.98496852815151, 49.915303364396095, 47.135459929704666, 49.57132302224636, 48.683717250823975, 51.05229735374451, 52.00552940368652, 54.54618327319622, 52.589740455150604, 51.19213365018368, 43.96796129643917, 46.63990572094917, 41.506989151239395, 39.20603781938553, 43.53997886180878, 43.08756373822689, 44.90108862519264, 43.68204943835735, 43.904508501291275, 45.014558136463165, 41.93615712225437, 43.98635610938072, 45.290035754442215, 34.385776072740555, 40.122962817549706, 43.21086332201958, 44.36014965176582, 42.89710655808449, 35.68376362323761, 47.726290225982666, 49.01307977735996, 54.21494744718075, 52.25855402648449, 51.757554709911346, 51.93222753703594, 51.327660977840424, 52.34623432159424, 51.709293499588966, 51.403071731328964, 48.57601583003998, 46.85386843979359, 46.14716336131096, 48.379984349012375, 46.87172748148441, 51.32845513522625, 48.276113122701645, 47.257638573646545, 46.26828946173191, 42.97242231667042, 44.83943693339825, 47.374307513237, 53.22861157357693, 45.81589333713055, 50.709741935133934, 50.52056908607483, 50.61215937137604, 50.02083130180836, 48.42539571225643, 44.99206714332104, 44.8635808378458, 42.70500026643276, 42.4650127440691, 47.35118955373764, 50.255035534501076, 46.757566407322884, 48.22824329137802, 50.86686730384827, 50.75066573917866, 51.49976894259453, 53.28336663544178, 52.12368406355381, 51.9453976303339, 64.90674912929535, 66.46055415272713, 69.01393353939056, 71.38563707470894, 73.0922394990921, 69.34038922190666, 69.91909056901932, 70.4348748922348, 72.93272405862808, 72.82485544681549, 74.57438796758652, 74.31236162781715, 76.70364931225777, 77.19885393977165, 74.06926587224007, 61.4163476228714, 0.7207009743433446, 0.04027176051749848, 0.448233091738075, 0.1831507807946764, 51.28215841948986, 71.3484750688076, 57.33037747442722, 37.63329081237316, 34.169218093156815, 42.71125093102455, 31.016337275505066, 0.3005192242562771, 0.0817864180135075, 0.03516309421684127, 0.07536462901043706, 0.08316340623423457, 0.058935297711286694, 0.1949107341351919, 0.019363857427379116, 0.03690616533276625, 0.07124403957277536, 0.008999775327538373, 0.011041886500606779, 0.03195096775016282, 0.099415534932632, 0.06029968797520269, 0.23752734734443948, 1.1111701000481844, 55.37488840520382, 57.05390810966492, 42.95367792248726, 46.72352783381939, 65.05682587623596, 83.73451843857765, 68.91422688961029, 2.279510269872844, 0.3361942927585915, 0.4578411136753857, 0.9510793467052281, 18.74536693096161, 96.58058032393456, 80.0929382443428, 83.84297221899033, 74.9044306576252, 76.37608408927917, 78.00236642360687, 78.52460280060768, 75.3674890100956, 71.04644447565079, 64.34432610869408, 59.25356067717075, 57.19573549926281, 57.130200415849686, 55.867896750569344, 54.08961497247219, 56.19199275970459, 56.473177671432495, 53.95055763423443, 54.241656213998795, 52.679788023233414, 55.12390427291393, 53.14588241279125, 54.59882564842701, 52.75267191231251, 54.1108862310648, 50.60208611190319, 49.995824843645096, 48.54188606142998, 49.631747379899025, 51.74384504556656, 53.911339938640594, 52.26407513022423, 56.214677542448044, 53.6324805021286, 48.64338621497154, 49.59684245288372, 63.91725182533264, 56.928571835160255, 54.185704216361046, 64.84655275940895, 64.73250567913055, 68.1610769033432, 65.20028337836266, 63.66132415831089, 60.95453180372715, 58.34955118596554, 59.933727979660034, 61.547972559928894, 57.60276585817337, 52.96068415045738, 52.95935042202473, 51.7386469244957, 51.861243546009064, 52.95601040124893, 54.41362738609314, 57.88674741983414, 55.711949318647385, 52.28849641978741, 44.40114565193653, 47.37776532769203, 44.32715222239494, 39.9503418803215, 44.086799919605255, 43.51336508989334, 46.62815675139427, 44.98357079923153, 44.44397695362568, 45.76410971581936, 41.67919211089611, 44.78590540587902, 43.632135316729546, 35.27650147676468, 39.91456679999828, 42.768605053424835, 46.58599801361561, 43.412533700466156, 39.799497574567795, 53.912411481142044, 50.1848267018795, 54.7325024753809, 53.30077350139618, 55.15495240688324, 53.66197071969509, 52.98917882144451, 54.39733386039734, 53.16863939166069, 53.29402506351471, 51.10013298690319, 48.49555514752865, 49.048505276441574, 50.52510604262352, 50.87635159492493, 55.19938342273235, 52.14576467871666, 49.47598233819008, 47.3531274497509, 44.74760726094246, 45.32658979296684, 48.25994499027729, 54.31481748819351, 48.67042936384678, 53.91551211476326, 53.974222764372826, 52.89494767785072, 51.16063714027405, 51.18671514093876, 47.951378747820854, 47.95892134308815, 44.28906686604023, 45.94330050051212, 49.364997893571854, 52.06853002309799, 51.01672746241093, 53.046677336096764, 52.5141017138958, 54.183842316269875, 53.21905508637428, 56.164702624082565, 55.42037956416607, 53.3121956884861, 63.79048302769661, 71.73149451613426, 70.31963467597961, 74.4555227458477, 75.40004566311836, 73.36511045694351, 73.20735052227974, 73.37956488132477, 75.55625528097153, 75.25408029556274, 76.40564650297165, 79.44615215063095, 77.96236976981163, 80.29365107417107, 75.45955047011375, 70.53283363580704, 1.9555597216822207, 0.10527378151891753, 0.8244395046494901, 0.18869549967348576, 56.32489062845707, 77.10814520716667, 64.69425693154335, 43.656248822808266, 38.31385709345341, 52.60241657495499, 41.12699054181576, 0.26869239925872535, 0.06095906763221137, 0.016329002210113686, 0.0396351536619477, 0.11390180487069301, 0.07720375258941203, 0.04812385363038629, 0.08462728510494344, 0.15078843687660992, 0.18570601008832455, 0.20024588535306975, 0.1169403875246644, 0.12731221300782636, 0.2230062335729599, 0.19061044848058373, 0.41260549100115895, 1.818958951625973, 64.44898009300232, 73.57546716928482, 50.75305961072445, 53.951822966337204, 74.55693170428276, 89.77280482649803, 77.12957605719566, 3.3691046526655555, 0.6714108504820615, 0.5949654837604612, 0.9682104305829853, 20.463978610932827, 102.46553733944893, 83.14152985811234, 89.76876184344292, 77.65948802232742, 82.85418927669525, 81.67459577322006, 82.44578719139099, 78.25730234384537, 75.68253770470619, 67.72804453969002, 65.35775452852249, 63.58527883887291, 62.70723715424538, 59.34609331190586, 58.706534430384636, 59.92579020559788, 60.142602771520615, 55.912171974778175, 57.833614870905876, 54.98703181743622, 59.531124383211136, 57.86627031862736, 59.112010672688484, 56.23822867870331, 57.45227873325348, 53.728166967630386, 53.52002173662186, 53.21785055100918, 53.05782213807106, 56.51481583714485, 58.34041267633438, 53.98630231618881, 59.29324574768543, 57.61870980262756, 50.307001546025276, 49.46444995701313, 66.53700605034828, 57.859913259744644, 53.71696136891842, 65.85667535662651, 67.14865922927856, 70.72201788425446, 71.18711292743683, 64.20402243733406, 62.70892806351185, 61.71447582542896, 61.35828293859959, 62.8375169634819, 59.728592187166214, 55.50568498671055, 56.49149648845196, 54.77913737297058, 54.000452756881714, 56.197202280163765, 55.060725063085556, 60.846993774175644, 57.64944635331631, 52.15323127806187, 44.919415041804314, 47.744897827506065, 42.398018538951874, 40.578459575772285, 43.51222515106201, 42.687775790691376, 46.11377835273743, 45.01841872930527, 44.635585471987724, 45.59752285480499, 42.469819486141205, 44.716931506991386, 43.94120693206787, 35.401412174105644, 40.405249670147896, 42.03665412962437, 46.479911506175995, 44.53554444015026, 41.94726012647152, 48.857314735651016, 54.93844002485275, 61.20937652885914, 57.66200847923756, 58.39122734963894, 57.15989202260971, 57.240759283304214, 58.372357562184334, 55.26426114141941, 57.30740010738373, 54.01155196130276, 52.125146985054016, 50.79573132097721, 52.47519940137863, 51.49543337523937, 57.314061149954796, 53.942646458745, 51.12917482852936, 49.92266736924648, 45.63101805746555, 47.09049694240093, 51.606691405177116, 56.902452036738396, 49.73526142537594, 54.56754572689533, 57.751763463020325, 54.21238638460636, 54.34874206781387, 54.83425721526146, 50.49506105482578, 51.36864937841892, 48.47055248916149, 48.15214477479458, 51.25608801841736, 54.642074927687645, 51.36491037905216, 54.592168405652046, 55.56517459452152, 56.66049621999264, 56.292660757899284, 60.23615375161171, 57.18750134110451, 56.335632652044296, 67.64795243740082, 73.22628110647202, 72.5258494913578, 77.76205211877823, 76.90483331680298, 73.34998726844788, 74.36312690377235, 75.81132799386978, 79.09742966294289, 79.01553645730019, 79.94906276464462, 82.11787238717079, 82.64020755887032, 84.3022383749485, 77.66619086265564, 68.97739470005035, 1.563606953714043, 0.1524956288631074, 1.6870234999805689, 0.9778294363059103, 61.824540719389915, 84.71371069550514, 71.45879834890366, 54.03669521212578, 51.25930644571781, 64.74100962281227, 52.448566630482674, 0.5007150443270802, 0.14176341646816581, 0.18626245757332072, 0.13433367217658088, 0.2268359827576205, 0.13487894291756675, 0.2631494466913864, 0.24534217722248286], [0.048255633082590066, 0.02290585183800431, 0.08415683769271709, 0.10019793669926003, 0.03836928721284494, 0.06723808226524852, 0.15345268766395748, 0.08200863187084906, 1.0122270905412734, 52.9793069511652, 49.791563004255295, 41.80699825286865, 45.005640015006065, 55.5883951485157, 76.76514521241188, 64.6249258518219, 1.810883553698659, 0.32519409083761275, 0.5539486440829933, 1.212889573071152, 17.277710884809494, 86.65521651506424, 75.61341941356659, 76.3233657181263, 70.35602152347565, 73.43761816620827, 75.41363373398781, 73.23651775717735, 72.59116798639297, 67.19076856970787, 56.46989084780216, 56.31922893226147, 54.15128566324711, 54.658942222595215, 50.60017101466656, 50.522468984127045, 52.26638920605183, 49.92596559226513, 50.596971586346626, 53.28163392841816, 49.55491930246353, 49.6188622713089, 50.12197807431221, 49.78088557720184, 51.6038453578949, 52.39467032253742, 48.92785795032978, 45.62109299004078, 45.10067671537399, 45.2072723954916, 48.70116971433163, 46.64762690663338, 48.01207669079304, 52.842795476317406, 50.39831064641476, 48.753622099757195, 59.60336610674858, 63.96034151315689, 53.52602921426296, 53.47016081213951, 63.414113223552704, 62.56970353424549, 59.153960421681404, 59.736362770199776, 63.0842225253582, 61.773304268717766, 61.38562627136707, 55.220240503549576, 58.9120502024889, 56.82104520499706, 54.21487905085087, 50.93379311263561, 48.16066391766071, 47.818344086408615, 48.07766117155552, 51.44783332943916, 54.98572088778019, 57.16793239116669, 48.576912581920624, 47.7864333987236, 50.72688661515713, 40.15327759087086, 45.611175522208214, 44.192274659872055, 49.101930409669876, 50.16765922307968, 46.794698014855385, 42.608333453536034, 44.30811904370785, 40.722855627536774, 45.27298226952553, 44.08654913306236, 43.2047114521265, 45.111844316124916, 49.10413809120655, 49.055751487612724, 49.48966920375824, 36.54158279299736, 41.60781294107437, 50.099893659353256, 52.00497463345528, 52.39869810640812, 48.55789840221405, 48.65116819739342, 46.68179467320442, 48.68376664817333, 49.389343187212944, 51.11147537827492, 44.943657740950584, 46.68010376393795, 51.29587948322296, 52.181228175759315, 53.64416487514973, 54.34538684785366, 56.520230546593666, 53.827406242489815, 45.908289179205894, 44.832300916314125, 44.61297668516636, 47.53595843911171, 53.2587705552578, 48.3859234303236, 56.121647134423256, 52.09146559238434, 48.838045969605446, 48.04785177111626, 46.38036444783211, 43.34158390760422, 43.20448346436024, 40.999587178230286, 44.845592603087425, 47.68895722925663, 49.05070535838604, 50.52503764629364, 49.61074970662594, 51.7047755420208, 50.64795345067978, 52.09920957684517, 51.241113021969795, 53.416997864842415, 53.61213639378548, 57.83988833427429, 68.31178441643715, 68.82775872945786, 70.67816823720932, 68.77264648675919, 70.31874552369118, 69.04691576957703, 71.83962911367416, 69.24234688282013, 74.40154284238815, 71.59513503313065, 76.26594319939613, 75.13631701469421, 77.95155555009842, 73.66112977266312, 83.9405357837677, 14.48751300573349, 0.7060538290534168, 0.5473200185224414, 0.05650134276947938, 53.75997506082058, 70.90640679001808, 56.73388548195362, 44.19376038014889, 35.587598383426666, 40.49538843333721, 30.11433407664299, 0.3501229203538969, 0.11128482889034785, 0.05291069501254242, 0.07085447141434997, 0.03850506684102584, 0.07113812025636435, 0.013247852748463629, 0.05306460901920218, 0.059372007090132684, 0.007947620506456587, 0.023779127732268535, 0.040746957674855366, 0.035429458439466543, 0.07093476437148638, 0.03813372582953889, 0.16501374542713165, 1.410823327023536, 64.46655035018921, 53.324890807271004, 43.16944934427738, 50.682455599308014, 64.08699631690979, 85.25866985321045, 74.46642056107521, 1.9751287903636694, 0.46004425326827914, 0.7197766145691276, 1.7626078566536307, 18.614872433245182, 90.86761727929115, 79.39541727304459, 83.09010341763496, 73.81637424230576, 77.78441771864891, 80.35898476839066, 79.43944171071053, 74.29468497633934, 71.01476177573204, 59.7242946177721, 58.75065766274929, 57.90665075182915, 57.366076558828354, 54.9600912630558, 55.19505925476551, 55.12262374162674, 53.97913970053196, 54.25408534705639, 56.13496541976929, 52.006346359848976, 52.59219892323017, 54.152269810438156, 51.115461364388466, 52.66055725514889, 53.27002175152302, 51.152007803320885, 47.15999901294708, 48.66053469479084, 48.478676453232765, 51.55216433107853, 51.09377212822437, 52.196096777915955, 55.30632868409157, 51.73840753734112, 50.429647564888, 61.07689283788204, 66.07298254966736, 52.621639743447304, 55.90250909328461, 66.50564253330231, 63.52649599313736, 60.949527472257614, 61.36812821030617, 64.35010179877281, 64.07815799117088, 62.32320316135883, 58.60408812761307, 60.49450948834419, 58.11947353184223, 55.96439637243748, 54.41387057304382, 51.137883961200714, 50.36434046924114, 50.75814373791218, 53.872023448348045, 57.481970340013504, 58.90760064125061, 49.00709129869938, 49.9580130726099, 52.05673545598984, 39.49077934026718, 46.219158098101616, 43.900796100497246, 52.201446890830994, 52.52596087753773, 48.542965203523636, 44.55789104104042, 45.192536786198616, 41.710582226514816, 46.059084087610245, 46.1348520219326, 46.17108687758446, 46.79124020040035, 50.92396683990955, 47.541236355900764, 49.148037135601044, 39.0878489613533, 46.64119005203247, 54.64962512254715, 54.97913584113121, 53.280797973275185, 50.54838739335537, 51.963796243071556, 48.574940487742424, 50.91508291661739, 51.540806740522385, 52.78119698166847, 47.632579654455185, 49.75544974207878, 52.88490481674671, 55.06329372525215, 57.54111796617508, 59.29841727018356, 60.23593716323376, 56.76804944872856, 47.85506151616573, 46.06835938990116, 45.371396988630295, 48.637686520814896, 55.25179781019688, 50.663418620824814, 57.561351880431175, 54.172043949365616, 50.99323332309723, 51.073082238435745, 49.466547444462776, 45.06731830537319, 46.630337834358215, 43.82039621472359, 46.27901628613472, 49.45624619722366, 51.77404582500458, 52.86627821624279, 51.92861773073673, 54.12071630358696, 53.053041994571686, 53.15403677523136, 52.97540456056595, 54.54405918717384, 56.22339427471161, 59.005593582987785, 72.66271814703941, 70.92909917235374, 74.75051611661911, 70.26718229055405, 74.70704644918442, 69.91335287690163, 76.84744119644165, 71.487046033144, 78.71509417891502, 73.83349612355232, 79.41097363829613, 76.9136792421341, 82.53911018371582, 73.54724988341331, 88.40010568499565, 20.124873407185078, 0.8134209865238518, 0.9968293667770922, 0.39010562177281827, 58.719294145703316, 78.14529955387115, 63.280580788850784, 52.163536325097084, 38.587951585650444, 50.21131128072739, 40.53950026631355, 0.45870951551478356, 0.0797012576367706, 0.05010185901483055, 0.058225362954544835, 0.039200381288537756, 0.06532653249450959, 0.04763107128383126, 0.05575024108111393, 0.14399287261767313, 0.1711585946031846, 0.31736722332425416, 0.2656961412867531, 0.07370288614765741, 0.20138485939241946, 0.2299497672356665, 0.3207045129965991, 2.514917138032615, 77.57925912737846, 63.77143085002899, 58.23576249182224, 61.40378549695015, 75.37717089056969, 90.67234575748444, 81.66335597634315, 2.5955442991107702, 0.7355141232255846, 0.9693168837111443, 1.8399974727071822, 20.327467136085033, 96.58943384885788, 84.58783864974976, 85.76218083500862, 76.92743450403214, 84.25549328327179, 83.29687312245369, 82.65241250395775, 79.66076463460922, 73.20019170641899, 63.28312665224075, 63.7545445561409, 61.57334379851818, 62.909200116992, 58.00070330500603, 58.13320979475975, 61.13861292600632, 58.41636300086975, 58.33546154201031, 59.32146683335304, 55.47871023416519, 57.4599315226078, 57.34157167375088, 54.60910029709339, 58.270082250237465, 56.562822461128235, 53.0216670781374, 51.00185506045818, 52.39059694111347, 50.97416214644909, 55.70348337292671, 53.50134573876858, 55.01330740749836, 59.10434648394585, 54.36811342835426, 52.06609435379505, 62.46725343167782, 67.0713409781456, 54.65131603181362, 57.63305023312569, 69.17409494519234, 68.73622924089432, 61.054154857993126, 65.18776684999466, 66.62557169795036, 67.59717956185341, 64.63683441281319, 61.16348259150982, 64.96782705187798, 62.07411892712116, 58.92202466726303, 54.71553638577461, 53.26858922839165, 52.94428423047066, 53.826144710183144, 56.271644085645676, 61.26863054931164, 60.07804423570633, 52.71242067217827, 47.199763879179955, 51.75506204366684, 43.62328939139843, 46.01493425667286, 46.75426818430424, 52.93777137994766, 51.99154615402222, 47.97787852585316, 44.613546654582024, 45.80785296857357, 41.68345548212528, 47.444345355033875, 47.78568483889103, 44.33065943419933, 45.8362640440464, 50.05004793405533, 50.47866113483906, 50.60702584683895, 39.28204894065857, 42.907438203692436, 57.70729824900627, 58.10824513435364, 57.45683468878269, 53.49485568702221, 54.6297711879015, 50.953339263796806, 53.93744073808193, 55.853484123945236, 56.40109933912754, 49.6071171015501, 50.93403249979019, 55.340078473091125, 56.94206491112709, 58.79486069083214, 60.54448440670967, 62.18707926571369, 58.83476994931698, 47.044561207294464, 47.41034097969532, 47.571129351854324, 48.68183255195618, 57.072584107518196, 51.1053691059351, 61.093881726264954, 57.39612154662609, 54.16715361177921, 53.56878072023392, 51.52290590107441, 48.714332208037376, 49.88370046019554, 45.80963507294655, 50.509709268808365, 51.527644246816635, 54.83016483485699, 56.09409861266613, 54.549093917012215, 57.36094683408737, 59.127928018569946, 56.84924729168415, 57.06951007246971, 57.44971387088299, 59.686239659786224, 62.177613973617554, 75.73153987526894, 73.52232322096825, 76.74876809120178, 73.96002933382988, 78.30145597457886, 71.43888741731644, 80.56154429912567, 74.09144148230553, 80.83052426576614, 74.9879577755928, 82.84345105290413, 79.75778862833977, 85.08247330784798, 77.41853535175323, 91.30604535341263, 18.01408477127552, 0.7508324668742716, 2.8778522880747914, 1.0807407391257584, 65.60072109103203, 84.27278995513916, 70.37624403834343, 65.53455904126167, 54.98831994831562, 62.70643159747124, 56.634338423609734, 0.8504486933816224, 0.3016414702869952, 0.11194141436135396, 0.20866503124125302, 0.1948696785257198, 0.2535682014422491, 0.18992559460457414, 0.2416540595004335], [0.02465630732331192, 0.07881111087044701, 0.06676120785414241, 0.003831640501630318, 0.023221489100251347, 0.03504088846966624, 0.022099033412814606, 0.07076807058183476, 0.28955981077160686, 46.07018709182739, 44.00913968682289, 31.236068084836006, 39.57872562110424, 61.278601214289665, 72.12190076708794, 73.17696735262871, 5.088137397542596, 0.5646388954482973, 0.5622165254317224, 2.9740500636398792, 14.67624792829156, 81.33308529853821, 74.7792349755764, 75.57032972574234, 72.27497175335884, 71.54202908277512, 75.63751012086868, 75.42064815759659, 71.87060505151749, 66.00067242980003, 55.483832359313965, 55.225180238485336, 53.74660737812519, 52.192057594656944, 51.47066630423069, 50.007323026657104, 51.46656632423401, 50.595573261380196, 50.41482836008072, 51.0865943133831, 49.273510202765465, 52.10801750421524, 52.35463187098503, 51.31596900522709, 51.558171808719635, 51.77999630570412, 49.38148520886898, 46.078387051820755, 43.617540299892426, 46.230895668268204, 49.576969519257545, 48.237712383270264, 50.295594558119774, 51.30700908601284, 52.913813665509224, 56.65765397250652, 62.91948616504669, 60.867961049079895, 53.19571673870087, 59.454471096396446, 62.02431879937649, 59.841237142682076, 60.01830004155636, 62.94563636183739, 60.97960285842419, 61.110262647271156, 60.47278605401516, 62.96169050037861, 61.37534402310848, 60.55515803396702, 56.935054287314415, 52.69816763699055, 53.50867934525013, 49.83115687966347, 50.76421581208706, 53.72164651751518, 59.47238713502884, 51.94713793694973, 51.01225130259991, 46.420083716511726, 39.89636577665806, 48.9836997538805, 47.8169609606266, 49.33782175183296, 47.068598717451096, 52.093255296349525, 51.19274161756039, 49.05559569597244, 45.7928703725338, 45.20639084279537, 48.72443586587906, 50.694231167435646, 50.70603333413601, 47.71606497466564, 47.56669498980045, 49.05960068106651, 55.047475174069405, 39.48188781738281, 31.874754913151264, 51.8201107531786, 54.077132642269135, 51.46885000169277, 46.20470367372036, 46.01406030356884, 42.82093584537506, 49.570829048752785, 47.34185725450516, 47.61377826333046, 48.09301994740963, 49.40515793859959, 53.10917638242245, 53.65959204733372, 55.6268110871315, 56.034016236662865, 57.05433368682861, 59.543462321162224, 53.54225814342499, 47.1317171305418, 43.886843249201775, 47.883567586541176, 55.40542356669903, 55.065843388438225, 50.99841244518757, 53.2138379663229, 49.05948668718338, 48.01209568977356, 47.761164754629135, 44.48300465941429, 42.2024392336607, 40.014478638768196, 43.081256076693535, 48.21607254445553, 48.261244520545006, 49.97272588312626, 48.18379707634449, 50.055310651659966, 49.6857500821352, 50.80066345632076, 49.370572194457054, 49.575442001223564, 50.47975167632103, 53.277796134352684, 61.11491359770298, 65.80321982502937, 67.75145128369331, 67.79451817274094, 70.71609020233154, 68.20435658097267, 65.84882497787476, 69.02055278420448, 72.92998820543289, 71.17262050509453, 73.8242170214653, 73.27322378754616, 80.00222951173782, 73.93770173192024, 87.00467616319656, 51.31300516426563, 0.16976154613075778, 0.07243441476020962, 0.1540212766849436, 53.270466327667236, 69.93511810898781, 58.561389818787575, 35.44430807232857, 36.29715330898762, 38.28654795885086, 23.04683681577444, 0.48831399413757026, 0.05368909289245494, 0.04978978591680061, 0.024253751580545213, 0.021807447301398497, 0.049431814695708454, 0.005252260280030896, 0.08130924674333073, 0.05429512697446626, 0.06355331162922084, 0.018150408868677914, 0.025995694632001687, 0.05523487889149692, 0.05445879651233554, 0.029003203562751878, 0.09086246107472107, 0.42417619668412954, 56.29911281168461, 53.063442036509514, 36.98220334947109, 44.69727136194706, 69.70390051603317, 80.97430095076561, 81.42103537917137, 5.333655048161745, 0.8385734993498772, 0.7016868540085852, 3.280825177207589, 17.14605364948511, 85.37688910961151, 80.03714963793755, 78.79694178700447, 78.38027134537697, 75.6277522444725, 80.05261480808258, 78.33182394504547, 75.82363173365593, 68.70070114731789, 59.23880986869335, 59.604802429676056, 56.691475957632065, 54.92017820477486, 55.274076014757156, 53.91359701752663, 53.33158224821091, 54.11481902003288, 53.43479610979557, 53.207651898264885, 51.91479027271271, 55.03035329282284, 55.92960923910141, 54.12130907177925, 53.77649277448654, 54.25568886101246, 53.50298725068569, 48.527682423591614, 46.3381677120924, 47.314920499920845, 50.38275808095932, 52.140992134809494, 53.45732890069485, 53.50926831364632, 53.878676891326904, 59.658618941903114, 63.397067338228226, 62.73969501256943, 52.32053630053997, 60.60664527118206, 65.15834122896194, 61.239258125424385, 61.023498103022575, 64.85612824559212, 64.80385065078735, 63.811625093221664, 62.04135708510876, 64.68987196683884, 65.03243118524551, 62.852431163191795, 59.141861870884895, 56.213674396276474, 57.26602032780647, 52.86256201565266, 53.29405166208744, 54.126150012016296, 62.59851738810539, 52.43177533149719, 49.1493746638298, 49.84895512461662, 39.98702131211758, 47.778735011816025, 47.48923234641552, 50.458514615893364, 50.118432864546776, 53.85417960584164, 52.799105420708656, 50.59496149420738, 47.698445320129395, 45.7959596067667, 49.87858213484287, 52.44402587413788, 51.252071633934975, 47.778058648109436, 50.49452528357506, 49.81560431420803, 55.218910574913025, 39.90998424589634, 38.42647925019264, 56.31872735917568, 55.67197546362877, 53.662145510315895, 48.92173267900944, 48.57253901660442, 45.38758412003517, 50.96783548593521, 49.055751487612724, 50.246656984090805, 50.587194710969925, 53.033077865839005, 54.38140511512756, 56.92947618663311, 57.97142967581749, 60.618979409337044, 59.70059148967266, 61.73451974987984, 56.2074389308691, 49.20927844941616, 44.93468642234802, 48.28604958951473, 57.36959517002106, 58.95200505852699, 53.13856400549412, 55.56749626994133, 51.92056216299534, 49.66458901762962, 50.36149062216282, 46.79084502160549, 45.00599339604378, 43.25343243777752, 47.03151270747185, 50.5877760797739, 50.84398873150349, 50.72702340781689, 50.64784325659275, 53.35905097424984, 52.398496717214584, 53.288807943463326, 52.6473605632782, 50.7635660469532, 54.76195849478245, 53.76201555132866, 63.76317009329796, 67.83482640981674, 70.04381507635117, 72.51729995012283, 73.81432235240936, 70.8110623061657, 67.18948423862457, 71.00499629974365, 76.18962049484253, 76.82196736335754, 75.30502036213875, 76.0698889195919, 81.96089521050453, 76.79324850440025, 87.63962969183922, 58.86590547859669, 0.02949557216197718, 0.21753201872343197, 0.329473017482087, 57.199941873550415, 75.99624127149582, 65.81030264496803, 44.067538753151894, 41.044306978583336, 49.499449878931046, 38.56337450444698, 0.7829132548067719, 0.05566622254264075, 0.052189713387633674, 0.0721835317381192, 0.08496822032611817, 0.01732245222228812, 0.025712496644700877, 0.06344788955175318, 0.1591217756504193, 0.23790894483681768, 0.18091359146637842, 0.10736784766777419, 0.11139630689285696, 0.16126049682497978, 0.09605968414689414, 0.2149677649140358, 1.1528080282732844, 72.15280830860138, 60.027807131409645, 41.51000998914242, 55.05350545048714, 82.11463496088982, 85.01015558838844, 88.43209996819496, 6.186304595321417, 0.9842960361856967, 1.2781577208079398, 2.635697457008064, 18.527176938951015, 91.69568404555321, 83.41871738433838, 85.72512522339821, 81.49852842092514, 80.220368206501, 82.58732199668884, 84.63924989104271, 80.6386649608612, 73.4379069507122, 60.893583074212074, 60.75728438794613, 61.92710101604462, 60.852362886071205, 58.456781432032585, 58.08116018772125, 56.76744148135185, 58.00243221223354, 55.021123588085175, 57.98838436603546, 55.520131811499596, 58.415158465504646, 59.2163872718811, 57.09109291434288, 57.018585205078125, 58.91635537147522, 56.099608317017555, 52.164607867598534, 49.89238299429417, 51.858861073851585, 53.045769184827805, 54.66140829026699, 56.64275497198105, 56.22101180255413, 56.52803532779217, 61.53051629662514, 64.30493742227554, 62.910955622792244, 54.18437048792839, 63.14842388033867, 69.8053702712059, 64.77535977959633, 63.807148933410645, 68.60759854316711, 67.56171986460686, 64.60578247904778, 64.23963412642479, 63.86495143175125, 64.98951628804207, 67.2887197136879, 60.548930168151855, 57.57468156516552, 59.74903129041195, 56.33398734033108, 55.80400697886944, 56.154180988669395, 65.48231184482574, 55.365426912903786, 47.52194479107857, 47.551792189478874, 42.44244195520878, 49.531383365392685, 47.71043747663498, 54.328755140304565, 51.77298568189144, 57.650369703769684, 52.45091870427132, 51.47949703037739, 50.40879808366299, 46.573553681373596, 49.634996205568314, 53.54414664208889, 53.298239037394524, 50.04979334771633, 53.29958416521549, 51.967687234282494, 53.42791087925434, 41.05427764356136, 34.58077400922775, 54.26505155861378, 61.6830363124609, 55.63289076089859, 50.66556930541992, 50.852177292108536, 49.30398836731911, 54.67348784208298, 53.9964933693409, 56.22627072036266, 53.67216557264328, 52.51748353242874, 56.55390813946724, 59.457947909832, 59.95207719504833, 62.620316818356514, 60.13657629489899, 63.02294321358204, 57.28043295443058, 49.350566267967224, 45.97906418144703, 50.229892283678055, 59.40688244998455, 58.16128268837929, 56.10322952270508, 58.69874864816666, 53.39069187641144, 52.62194752693176, 52.36672282218933, 49.86892685294151, 46.13693431019783, 44.32538531720638, 50.72768837213516, 53.66381362080574, 53.32993693649769, 54.64187353849411, 52.262315824627876, 56.875028908252716, 55.61709500849247, 56.3741359859705, 54.25201065838337, 54.1396164894104, 56.72599330544472, 56.5770298987627, 66.33314698934555, 75.00229060649872, 72.45144948363304, 75.217594653368, 76.31994590163231, 69.65351521968842, 69.22514140605927, 74.36981454491615, 77.38152533769608, 77.73882776498795, 78.08645591139793, 78.38970243930817, 85.40831342339516, 78.82987082004547, 94.2100927233696, 57.19048798084259, 0.23560944478958845, 0.9885282372124493, 0.48716185439843684, 65.21982952952385, 82.33094215393066, 75.38896545767784, 51.052373349666595, 57.06218786537647, 62.664170265197754, 53.41412141919136, 0.9403767460025847, 0.20338525908300653, 0.15285962261259556, 0.1790748760686256, 0.24098603753373027, 0.1319692490505986, 0.1382855194970034, 0.16083687893114984], [0.01933340339746792, 0.05914348868827801, 0.00812387872429099, 0.042424066705279984, 0.028488269963418134, 0.04604065994499251, 0.08726870000828058, 0.05170591102796607, 0.5862555198837072, 45.636345371603966, 47.230093851685524, 31.264140978455544, 40.53956866264343, 54.88149248063564, 74.52467143535614, 61.158900037407875, 1.8231847998686135, 0.41671268467325717, 0.3338188264751807, 3.5667201736941934, 13.8436328060925, 75.99602088332176, 74.05906721949577, 77.51324146986008, 75.18926337361336, 75.70004716515541, 76.77714496850967, 71.75411850214005, 70.42567178606987, 62.96386398375034, 56.46344259381294, 53.590610548853874, 53.46927925944328, 54.08435605466366, 52.18658208847046, 51.344425678253174, 50.96164181828499, 49.00817044079304, 50.23350588977337, 51.132362857460976, 52.28066124022007, 53.067207634449005, 50.7113416492939, 50.996907725930214, 50.252736657857895, 50.79630509018898, 50.538701713085175, 47.20354847609997, 44.229155480861664, 46.06782741844654, 47.24159963428974, 49.92791868746281, 50.28248146176338, 50.972820818424225, 55.31890220940113, 60.696920827031136, 62.68758840858936, 62.531040608882904, 58.26321221888065, 59.69857379794121, 57.882484048604965, 63.004229217767715, 63.31791378557682, 62.61033855378628, 61.01493716239929, 60.957271456718445, 61.64707884192467, 85.17463356256485, 60.06545931100845, 57.00942389667034, 59.42473389208317, 58.716619089245796, 54.8721107840538, 52.64842450618744, 53.14589001238346, 52.883586287498474, 57.228189557790756, 59.33143749833107, 48.319974169135094, 38.179165720939636, 48.906552493572235, 52.22466364502907, 49.821387603878975, 48.24900917708874, 50.68928763270378, 52.72946655750275, 52.86242142319679, 51.02420546114445, 49.24720041453838, 49.6418472379446, 53.04111823439598, 55.1944474875927, 49.505939930677414, 46.99427850544453, 46.97322003543377, 45.972612127661705, 60.02057611942291, 54.17595773935318, 28.359265252947807, 51.88184604048729, 52.472364753484726, 54.19437535107136, 45.55968448519707, 47.63555109500885, 44.696838185191154, 47.837578654289246, 48.73411774635315, 50.027252957224846, 50.94224385917187, 54.28695358335972, 55.76045751571655, 55.35064950585365, 56.16492681205273, 56.574510633945465, 53.35385285317898, 58.55983950197697, 59.07457888126373, 55.54009974002838, 47.47087933123112, 51.633077189326286, 53.30366134643555, 51.152205392718315, 54.127890318632126, 50.90474747121334, 48.94180700182915, 47.12647341191769, 45.88329032063484, 43.4578462690115, 43.303319960832596, 42.409596517682076, 44.340272918343544, 49.155834317207336, 48.7406799942255, 48.561512008309364, 46.122472286224365, 49.55047354102135, 50.05631759762764, 48.890080377459526, 51.759610399603844, 51.45465016365051, 51.81622736155987, 52.25381948053837, 53.96158464252949, 61.13369978964329, 62.48125568032265, 68.77923533320427, 71.92116513848305, 75.6642834842205, 66.28191813826561, 65.95550045371056, 67.19095855951309, 74.25822213292122, 71.4234146475792, 78.0167980492115, 72.807627171278, 77.35885575413704, 74.96312230825424, 83.51023927330971, 2.299840128980577, 0.25318462983705103, 0.16140316729433835, 49.32772949337959, 72.64030694961548, 50.89829541742802, 39.72441740334034, 32.78401002287865, 32.331898882985115, 32.47456982731819, 1.6033581644296646, 0.10906496871029958, 0.04716079085483216, 0.0543864111386938, 0.2278053612099029, 0.01854317197285127, 0.058036701593664475, 0.04609555660863407, 0.0344213806965854, 0.0788786388875451, 0.02251988680654904, 0.07171680990722962, 0.01790752063243417, 0.043369544291635975, 0.19752230728045106, 0.05014765694795642, 0.8934530045371503, 55.97079522907734, 52.76139244437218, 28.15388437360525, 45.10328717529774, 65.9955883026123, 83.58558923006058, 65.82795649766922, 1.6803370462730527, 0.7189514650963247, 0.6248698791023344, 2.5992635870352387, 14.345128946006298, 82.47713550925255, 78.77567812800407, 82.12703749537468, 77.30208680033684, 78.55677947402, 81.49528339505196, 75.77357321977615, 73.20022970438004, 65.8579520881176, 60.07305130362511, 57.77214556932449, 55.981313064694405, 58.477019146084785, 54.15429510176182, 53.36389571428299, 52.30779558420181, 52.92910784482956, 52.956667765975, 53.970886543393135, 53.604502603411674, 53.987959027290344, 53.56209687888622, 52.65728563070297, 51.435898169875145, 54.65154401957989, 52.35495485365391, 50.27560383081436, 48.04201528429985, 48.168692886829376, 50.54366424679756, 51.40157461166382, 51.48477874696255, 54.25068832933903, 57.76558332145214, 61.82987183332443, 63.04018288850784, 65.66838026046753, 61.33209094405174, 60.94570107758045, 61.73982426524162, 66.28292888402939, 64.78213101625443, 64.62824687361717, 60.8338388800621, 63.34191709756851, 62.4124451726675, 79.36053514480591, 63.731532990932465, 58.81414845585823, 61.96264050900936, 59.93685521185398, 58.61846275627613, 55.58126673102379, 55.99379539489746, 57.22225807607174, 58.206196278333664, 57.8533586114645, 49.066197127103806, 41.39303706586361, 49.29246358573437, 52.114169374108315, 51.46576836705208, 51.93884678184986, 53.015310019254684, 54.99506078660488, 53.113967925310135, 53.41472938656807, 52.94409804046154, 51.870412454009056, 53.593714982271194, 54.93174098432064, 50.85373520851135, 48.891383707523346, 47.6564309746027, 50.46753913164139, 58.40647593140602, 51.35982245206833, 31.906876489520073, 56.89889542758465, 57.820760160684586, 56.578755006194115, 50.58736190199852, 51.55841499567032, 46.937243565917015, 50.391638204455376, 51.98192127048969, 51.59093365073204, 53.713013380765915, 56.038055419921875, 57.01957315206528, 57.200318053364754, 59.08669263124466, 56.968720480799675, 57.402744591236115, 61.33578434586525, 61.61001943051815, 58.037352338433266, 47.2554574906826, 50.713773518800735, 55.51526427268982, 52.99754977226257, 55.41335754096508, 54.58918556571007, 50.19390441477299, 49.70824107527733, 47.95577511191368, 47.433010563254356, 43.82893055677414, 45.424324348568916, 47.2974718362093, 51.74723446369171, 50.379057079553604, 52.10957162082195, 48.804326578974724, 52.15947434306145, 51.97153642773628, 52.620062828063965, 53.68872508406639, 54.09222163259983, 52.92744353413582, 55.06708212196827, 55.56323669850826, 63.11574563384056, 63.88909533619881, 73.0587936937809, 75.34791246056557, 78.10751438140869, 68.934046626091, 68.00326377153397, 70.85212290287018, 75.81581935286522, 71.0809314250946, 81.58629611134529, 76.17917105555534, 82.01759576797485, 74.9214917421341, 87.87445709109306, 3.289351207204163, 0.2863448270363733, 0.325243339757435, 54.876427352428436, 79.51357573270798, 59.55010436475277, 47.514379397034645, 39.660957008600235, 46.15752160549164, 45.45645922422409, 2.576674036681652, 0.16808065585792065, 0.07305965933483094, 0.08434620409389026, 0.15091636829311028, 0.05674004343745764, 0.036445269361138344, 0.042950449787895195, 0.13368430780246854, 0.22966752847423777, 0.21130275767063722, 0.1883967555477284, 0.07499636791180819, 0.17522678099339828, 0.37777599587570876, 0.21109541645273566, 1.7022448894567788, 67.75777414441109, 62.17552788555622, 42.719150707125664, 56.15530572831631, 74.63513910770416, 89.20242503285408, 76.63761645555496, 4.018443496897817, 0.9222396661061794, 1.0180703457444906, 3.007761142216623, 17.23652109503746, 93.57213735580444, 82.85287454724312, 88.61988589167595, 82.53325089812279, 83.20283576846123, 84.58309650421143, 80.80756589770317, 76.6044670343399, 70.33743292093277, 61.030204743146896, 62.660123482346535, 58.95680420100689, 64.195906072855, 59.719674065709114, 57.31652721762657, 58.05985853075981, 57.10462398827076, 54.312283024191856, 59.812286496162415, 56.14290699362755, 58.99490475654602, 54.32326443493366, 56.50666147470474, 55.514367520809174, 56.938785687088966, 55.30333064496517, 52.66798585653305, 48.982727006077766, 51.472934782505035, 53.478147983551025, 55.895665660500526, 53.3382622897625, 55.171986892819405, 59.38703991472721, 63.273771554231644, 64.65295314788818, 64.32791858911514, 63.94091695547104, 64.57955628633499, 63.19816701114178, 68.3081442117691, 66.84342160820961, 67.5291708111763, 65.71435019373894, 66.79299831390381, 63.63408721983433, 77.6261942088604, 67.38043159246445, 62.185152769088745, 64.43881943821907, 61.78689233958721, 60.13851039111614, 57.23974473774433, 57.11440846323967, 59.64751213788986, 59.87202309072018, 55.93236789107323, 50.02062611281872, 42.33630605041981, 49.16594177484512, 56.105490401387215, 55.827850699424744, 52.76487685739994, 53.980370834469795, 55.92234022915363, 54.89020921289921, 53.95476780831814, 53.15095894038677, 53.38497698307037, 57.24173963069916, 58.149773105978966, 52.863538563251495, 51.16969205439091, 50.06637945771217, 53.41885216534138, 59.97203752398491, 51.875720769166946, 33.559977784752846, 53.46907787024975, 59.457427337765694, 59.36628922820091, 52.85091944038868, 55.215942934155464, 50.925201773643494, 52.51934923231602, 54.053893089294434, 53.28721582889557, 55.97103461623192, 59.668129831552505, 62.66779527068138, 59.21566531062126, 61.02157160639763, 60.91951668262482, 60.5767522752285, 63.64080525934696, 64.40018311142921, 60.4326868057251, 49.254936799407005, 52.41611637175083, 56.46676741540432, 54.40663196146488, 59.30991545319557, 55.75002707540989, 53.90378974378109, 53.3869718760252, 51.234527975320816, 50.23334629833698, 48.05854819715023, 49.14540767669678, 49.430282190442085, 54.81735572218895, 53.39898683130741, 54.38935428857803, 51.598518043756485, 56.09197832643986, 54.508481696248055, 55.92765234410763, 57.68809787929058, 55.63818767666817, 56.27987824380398, 59.42355215549469, 57.466071993112564, 67.96455904841423, 68.24136659502983, 75.52837997674942, 79.91292670369148, 79.73377391695976, 68.1213690340519, 69.76465165615082, 72.64439553022385, 77.05329895019531, 74.31023374199867, 84.40892904996872, 79.15145516395569, 85.02292290329933, 80.44118195772171, 90.31239107251167, 3.1819915305823088, 0.48926943505648524, 1.0004934389144182, 61.03830210864544, 87.37948805093765, 66.37284725904465, 59.82174038887024, 51.59533381462097, 54.40003551542759, 62.402121126651764, 2.6168302819132805, 0.27162673242855817, 0.15257955092238262, 0.2053013804834336, 0.2722907764837146, 0.18039490445517004, 0.15789317985763773, 0.13244601956102997], [0.06458860021666624, 0.03130842371319886, 0.05587185311014764, 0.026325380749767646, 0.05560935918765608, 0.08749104745220393, 0.062404177588177845, 0.07134326471714303, 0.919598035980016, 53.605042174458504, 40.36370649933815, 38.648459538817406, 40.47607406973839, 53.19124057888985, 82.03338772058487, 37.4927781522274, 0.02969477944134269, 0.7295019552111626, 0.6019496277440339, 0.5927015177439898, 9.290326684713364, 81.29308104515076, 73.27931106090546, 82.4614043533802, 77.39335790276527, 80.27873307466507, 75.04115492105484, 75.27190893888474, 69.4195693731308, 62.76871405541897, 56.08557567000389, 56.10909640789032, 54.200914800167084, 52.40618750452995, 51.16036355495453, 51.630546525120735, 50.57097718119621, 51.39752022922039, 48.827702924609184, 51.74549035727978, 50.347096994519234, 52.301180139184, 51.01738482713699, 52.60690413415432, 48.37404526770115, 51.363215669989586, 51.325707882642746, 48.031797632575035, 44.4126096367836, 45.65820939838886, 45.09566478431225, 47.251300513744354, 50.32764583826065, 48.83151791989803, 52.78309687972069, 60.088923051953316, 67.20689490437508, 63.335909619927406, 54.505111277103424, 58.010613173246384, 60.25058537721634, 62.96207047998905, 61.52633652091026, 62.850603461265564, 63.20749931037426, 59.50642190873623, 58.553938418626785, 53.40254344046116, 49.592978060245514, 61.89486734569073, 60.43014474213123, 57.79948890209198, 53.78381498157978, 60.16863517463207, 54.86210212111473, 59.29143324494362, 58.570076152682304, 43.34545210003853, 46.06713965535164, 57.768262177705765, 48.95840831100941, 43.332791179418564, 47.21005752682686, 54.68160420656204, 55.4203187674284, 59.81336183845997, 56.43765337765217, 56.401745304465294, 54.64970111846924, 54.338505417108536, 53.361824825406075, 57.38126814365387, 52.90601268410683, 55.84288269281387, 51.321034133434296, 48.66575561463833, 44.853112399578094, 67.73245990276337, 30.77690452337265, 36.82478539645672, 60.345261096954346, 49.57824245095253, 51.535688415169716, 46.83646157383919, 47.19986267387867, 52.03549839556217, 51.29142612218857, 53.208620846271515, 54.03522089123726, 54.71739448606968, 54.81184221804142, 55.96208229660988, 56.47133097052574, 53.29918518662453, 55.5036710947752, 56.538442969322205, 55.96456736326218, 59.942467510700226, 50.3242602199316, 56.26996837556362, 47.64576494693756, 44.2057791352272, 49.280817210674286, 49.01222862303257, 49.08281363546848, 46.099259331822395, 44.972813576459885, 43.523195162415504, 41.87371127307415, 42.06620134413242, 45.04984304308891, 47.09737077355385, 46.47255130112171, 47.67428621649742, 46.65791295468807, 50.78487530350685, 46.61250539124012, 51.39706805348396, 50.007581412792206, 52.93443515896797, 49.60948437452316, 51.12096346914768, 51.007645949721336, 55.52196331322193, 57.407023161649704, 69.28857520222664, 67.22524031996727, 72.85608977079391, 74.26285788416862, 72.98288896679878, 71.08762666583061, 71.67946770787239, 72.30153232812881, 77.69914269447327, 70.52091747522354, 78.88971000909805, 68.49168956279755, 93.01972299814224, 14.371217396110296, 0.8132594358175993, 0.7731581688858569, 51.22282840311527, 74.87435147166252, 47.82267585396767, 44.31281179189682, 36.3207196444273, 32.85503201186657, 33.80456306040287, 2.5540035031735897, 0.0741100283630658, 0.14632977690780535, 0.023645170076633804, 0.05834280782437418, 0.051663575213751756, 0.04839095628994983, 0.036091313158976845, 0.05195458616071846, 0.028746359239448793, 0.08039803040446714, 0.06530112135806121, 0.07635626447154209, 0.018837164498108905, 0.07441505105816759, 0.15097060444531962, 1.9662701594643295, 65.52855536341667, 45.79569362103939, 35.507316291332245, 46.21736079454422, 62.675790041685104, 93.02858412265778, 41.88041411340237, 0.14053127320948988, 0.9435562253929675, 0.9071057906839997, 0.6264446571003646, 11.567739229649305, 89.57478985190392, 78.75963538885117, 88.88820469379425, 79.99443992972374, 84.1255934536457, 79.14767816662788, 78.50793689489365, 72.22594678401947, 65.67625343799591, 57.675778940320015, 59.87120233476162, 57.32808239758015, 56.75318844616413, 53.78757677972317, 53.7237174063921, 53.296620324254036, 55.00600419938564, 53.32969754934311, 55.766145810484886, 52.14433215558529, 53.05003635585308, 53.41511316597462, 54.680046290159225, 50.6694944947958, 53.02426993846893, 53.44527214765549, 48.93820859491825, 46.194786205887794, 48.69768910109997, 46.83652997016907, 50.35201013088226, 52.86896847188473, 53.317997977137566, 56.455485820770264, 62.55679562687874, 71.767797768116, 64.91204604506493, 56.24952547252178, 60.32561235129833, 59.158873558044434, 65.89366257190704, 63.66129755973816, 63.675759583711624, 63.89548659324646, 62.41080366075039, 56.16525359451771, 54.4634161144495, 52.66020007431507, 63.18887650966644, 60.28188429772854, 60.5497395247221, 57.8370650857687, 61.02983616292477, 58.92596125602722, 61.41876429319382, 58.327322378754616, 44.23471838235855, 45.848700776696205, 55.35518266260624, 47.96407766640186, 47.08169661462307, 51.53788469731808, 58.12448166310787, 57.2548071295023, 60.321086794137955, 57.883460596203804, 58.07987205684185, 56.97958029806614, 56.954528242349625, 56.00777864456177, 57.06085793673992, 54.81231339275837, 58.51828873157501, 52.82368630170822, 51.923252418637276, 45.571258664131165, 65.21336987614632, 33.6620669066906, 42.388226464390755, 65.22885024547577, 52.697289884090424, 54.26100097596645, 51.423248648643494, 50.51829680800438, 54.00039196014404, 53.73884819447994, 55.23425035178661, 54.90304112434387, 56.166503727436066, 56.43889211118221, 58.23054917156696, 56.18014119565487, 55.992503464221954, 56.435574889183044, 59.4149000197649, 59.231438264250755, 61.00878149271011, 52.64068052172661, 54.80760544538498, 48.07710640132427, 43.639423325657845, 52.6458178460598, 51.74282290041447, 49.98422786593437, 49.161818996071815, 46.45408049225807, 45.6138201802969, 43.506730645895004, 44.545306116342545, 49.34030681848526, 49.47434842586517, 47.07025542855263, 52.3263081908226, 50.17242416739464, 54.87187519669533, 48.861429914832115, 56.257896423339844, 51.66824050247669, 54.92427438497543, 51.045271530747414, 54.527210891246796, 52.884418442845345, 58.9980623871088, 59.43687804043293, 70.74575141072273, 70.65739095211029, 76.55349656939507, 76.11721158027649, 77.20263093709946, 70.87775632739067, 75.98982721567154, 74.42811101675034, 80.98623991012573, 73.15793797373772, 83.98182436823845, 71.02914020419121, 96.5626148879528, 18.105665557086468, 0.8870523073710501, 1.0325347445905209, 54.22216705977917, 82.5061583518982, 56.02978706359863, 51.37041628360748, 38.82848247885704, 43.163388669490814, 48.21812443435192, 2.694168007001281, 0.06365978755638935, 0.13285789667861536, 0.05828931381984148, 0.08815936627797782, 0.04511943945544772, 0.06258545457967557, 0.07582691279822029, 0.1724622808978893, 0.17802218411816284, 0.16280861687846482, 0.23833600629586726, 0.18324530072277412, 0.17593281576409936, 0.13734328880673274, 0.47332991380244493, 2.60391335003078, 77.64667510986328, 53.48029486835003, 51.416234225034714, 58.331171572208405, 70.54856479167938, 98.86019200086594, 47.25095473229885, 0.31979149323888123, 1.6169354296289384, 1.7892608139663935, 1.1553877335973084, 14.177538938820362, 96.86181083321571, 80.52103087306023, 95.11670887470245, 84.01039883494377, 87.71827787160873, 79.7499306499958, 83.80215480923653, 74.86788421869278, 69.39300119876862, 61.18317313492298, 61.481164544820786, 61.72065429389477, 59.087289199233055, 57.184712290763855, 57.65305615961552, 57.55063645541668, 58.28289516270161, 55.67624643445015, 59.92075927555561, 55.78713208436966, 58.185806572437286, 57.06104412674904, 58.202210292220116, 55.28355650603771, 55.9921994805336, 56.6657817363739, 51.89049817621708, 50.17289154231548, 50.89256912469864, 49.46000039577484, 52.98332333564758, 57.08410508930683, 56.484892442822456, 59.32345412671566, 68.80349323153496, 72.535280585289, 66.99504107236862, 60.70740446448326, 63.52476708590984, 63.581904619932175, 68.14384862780571, 66.23049929738045, 66.18126153945923, 66.03596493601799, 64.08650994300842, 57.440476566553116, 61.65381208062172, 54.37347114086151, 63.827584236860275, 64.1761015355587, 63.97972047328949, 57.87366472184658, 64.1072416305542, 63.04885022342205, 63.4396630525589, 58.88651177287102, 45.91257154941559, 46.29283234477043, 53.39450307190418, 51.41735516488552, 49.35402408242226, 53.36156263947487, 57.54710644483566, 60.052015632390976, 64.75373893976212, 61.42676666378975, 58.49323287606239, 57.8401543200016, 58.33839498460293, 58.23974087834358, 58.82368974387646, 55.98177284002304, 59.577386900782585, 55.69930739700794, 54.71725009381771, 54.22483071684837, 63.76108020544052, 31.8197338655591, 41.92575328052044, 63.219130486249924, 57.31923647224903, 55.894677713513374, 53.923001512885094, 51.298600137233734, 58.39867874979973, 57.84417450428009, 58.87531377375126, 58.159025609493256, 59.56595331430435, 59.131811410188675, 60.67727588117123, 60.0113046169281, 58.1961914151907, 58.431432992219925, 62.125742956995964, 61.955158710479736, 65.50978437066078, 53.81259083747864, 59.10900503396988, 49.23973761498928, 42.88008727133274, 55.62977492809296, 53.36524464190006, 52.33765058219433, 51.650544852018356, 49.28543396294117, 48.25769931077957, 48.48156429827213, 47.4418830871582, 51.74162216484547, 52.3389957100153, 50.290373638272285, 53.489467576146126, 51.759295016527176, 57.09477111697197, 52.024782970547676, 58.791984245181084, 55.94755947589874, 58.32380376756191, 53.239406794309616, 57.25065395236015, 56.13571397960186, 62.66487702727318, 63.26392628252506, 75.50226777791977, 75.69747850298882, 79.81130495667458, 78.95906388759613, 76.90478771924973, 71.6334217786789, 78.51165309548378, 77.7184684574604, 83.08136388659477, 76.90925627946854, 87.25477874279022, 74.63146850466728, 100.52187323570251, 18.147621005773544, 0.9237034781835973, 1.6654975363053381, 60.12107692658901, 89.43049639463425, 60.850835368037224, 67.65021711587906, 52.54335634410381, 53.53864073753357, 63.386374711990356, 3.033241624943912, 0.17460837902035564, 0.2678996667964384, 0.09314029040979221, 0.23803525837138295, 0.14157093304675072, 0.1884765809518285, 0.13118940027197823], [0.019165626072208397, 0.03682642156491056, 0.0852201868838165, 0.08147398868459277, 0.034277812228538096, 0.160986807604786, 0.0663846347015351, 0.22047672711778432, 2.7841982385143638, 62.98422709107399, 41.24692350625992, 31.246194541454315, 41.596067771315575, 55.143594816327095, 82.26604163646698, 34.54424276947975, 0.10704916203394532, 0.17210907797561958, 0.3527161030797288, 0.4281759570585564, 13.893940206617117, 85.82637459039688, 69.47297170758247, 83.7494820356369, 73.20694774389267, 79.57703992724419, 75.4079644382, 75.9921070933342, 72.91506260633469, 60.769500732421875, 53.06401960551739, 57.515955716371536, 55.029141157865524, 55.28993636369705, 51.03399373590946, 51.213450506329536, 49.01503287255764, 50.947198793292046, 49.44480501115322, 52.15589493513107, 50.36410868167877, 51.13763317465782, 49.325681403279305, 51.50105707347393, 49.73709672689438, 53.96638758480549, 49.11024056375027, 49.790020287036896, 42.6516929268837, 44.8647777736187, 46.899906769394875, 48.74445699155331, 46.821023002266884, 48.52049320936203, 50.76920494437218, 58.52043181657791, 66.79013326764107, 50.39642594754696, 54.545579105615616, 57.11294174194336, 56.207423731684685, 59.272384867072105, 63.73446263372898, 61.27247214317322, 65.71669086813927, 59.09263551235199, 53.074351251125336, 46.015325635671616, 52.78280049562454, 57.748324647545815, 57.12686039507389, 59.79682132601738, 58.93192693591118, 52.50039964914322, 58.930053636431694, 53.2675176858902, 42.95111685991287, 55.541843846440315, 59.527408182621, 42.00007349252701, 41.314613074064255, 48.023806661367416, 57.76646487414837, 55.76600521802902, 57.693976163864136, 56.488338857889175, 56.21423676609993, 56.21989846229553, 57.83961854875088, 56.175197660923004, 56.53635688126087, 55.482502430677414, 57.77980595827103, 54.332638531923294, 54.26437899470329, 49.314464405179024, 37.674814984202385, 52.355114445090294, 63.60920615494251, 27.332172766327858, 46.16326689720154, 55.81441082060337, 53.10873940587044, 53.534065783023834, 52.358306273818016, 52.45254121720791, 55.155856758356094, 56.203471943736076, 52.993590384721756, 56.00009545683861, 54.97692435979843, 56.883491054177284, 52.47704230248928, 56.11849710345268, 55.288310050964355, 57.92338125407696, 58.01519572734833, 58.6628557741642, 54.684701040387154, 54.78832148015499, 51.384935304522514, 50.954718589782715, 49.37031380832195, 48.9335348457098, 48.14246669411659, 48.652520924806595, 42.908072769641876, 42.70779311656952, 39.6339176595211, 42.20324859023094, 44.55411024391651, 48.890095576643944, 46.19782604277134, 48.67857612669468, 48.17741721868515, 49.42134507000446, 49.51589159667492, 48.87243412435055, 49.490299969911575, 50.728341937065125, 48.77726823091507, 53.05958904325962, 49.69989292323589, 52.92163744568825, 52.220065891742706, 59.447198286652565, 66.14955604076385, 68.33115577697754, 70.0332060456276, 73.3151887357235, 72.5865626335144, 75.92095971107483, 72.96794816851616, 74.08292233943939, 69.28263992071152, 76.88313648104668, 66.63719147443771, 91.20060101151466, 30.60181751847267, 0.6478553207125515, 1.0351479356177151, 57.28502690792084, 69.31619971990585, 51.58656768500805, 38.331700935959816, 49.00405906140804, 31.885312646627426, 39.02101434767246, 2.961733262054622, 0.0938513049914036, 0.07672310064663179, 0.1070985445403494, 0.06487720660516061, 0.02898002443544101, 0.07349507737671956, 0.028919125652464572, 0.03011413926287787, 0.05019265336159151, 0.06408344997907989, 0.03032213542610407, 0.10952838056255132, 0.1065329612174537, 0.06430161913158372, 0.38162447686772794, 5.692612761631608, 71.80077999830246, 47.84775070846081, 34.861442148685455, 47.44761697947979, 61.246169954538345, 87.76774361729622, 38.068519458174706, 0.14846563339233398, 0.42149526241701096, 0.253647017525509, 0.5406090442556888, 15.501171313226223, 90.63738003373146, 73.68511408567429, 87.46078088879585, 75.4348061978817, 83.88178333640099, 79.82934638857841, 79.51775550842285, 75.99980548024178, 64.50226083397865, 58.64941589534283, 60.273821130394936, 57.786637991666794, 57.19223968684673, 52.459654435515404, 54.99308109283447, 52.01097071170807, 54.308977201581, 53.32297571003437, 54.53773632645607, 53.16155657172203, 55.11921912431717, 52.88268193602562, 54.65728171169758, 52.22199618816376, 55.734390914440155, 49.763300120830536, 53.87341797351837, 46.11456871032715, 48.52779641747475, 47.63989046216011, 51.555223166942596, 49.77737836539745, 50.7540437579155, 53.95301230251789, 60.76861158013344, 65.98985821008682, 50.226651057600975, 53.23138542473316, 59.29755471646786, 58.19751754403114, 59.824670031666756, 65.68561613559723, 62.629356533288956, 66.88905715942383, 59.7135753929615, 53.57703387737274, 49.51545462012291, 52.88447543978691, 59.383046329021454, 59.48803469538689, 61.08563616871834, 59.620073810219765, 54.50798772275448, 60.55023729801178, 53.441411554813385, 44.338771998882294, 54.408315271139145, 58.60404632985592, 45.47372169792652, 46.404835134744644, 51.35077893733978, 60.256250873208046, 57.20444083213806, 60.34968785941601, 57.77599476277828, 59.665093794465065, 56.21020898222923, 59.500167444348335, 60.81062972545624, 58.78140941262245, 58.455922678112984, 59.38726410269737, 55.97612254321575, 56.43132671713829, 51.21773287653923, 41.79487690329552, 53.71079809963703, 61.25508427619934, 29.160153977572918, 52.82334432005882, 60.197741612792015, 55.89866369962692, 56.089231073856354, 56.10598437488079, 55.29707618057728, 55.668388456106186, 58.410116136074066, 56.734934225678444, 58.420242592692375, 57.94806092977524, 57.81930483877659, 56.591936498880386, 58.765461668372154, 55.10854549705982, 61.138122752308846, 59.40112955868244, 59.29000832140446, 57.88848392665386, 57.14774787425995, 52.706656381487846, 51.67214669287205, 51.679047122597694, 49.51816387474537, 49.73675474524498, 49.24882672727108, 46.06876976788044, 44.34648938477039, 43.028777092695236, 45.32206803560257, 47.02644757926464, 51.961660757660866, 49.12185654044151, 51.31111666560173, 50.652528405189514, 52.054573372006416, 51.19050353765488, 51.53322994709015, 50.41510954499245, 53.863644897937775, 50.76016902923584, 54.7542867064476, 53.556328788399696, 54.27637495100498, 53.79920415580273, 61.504977867007256, 67.63874933123589, 73.23689013719559, 72.77956947684288, 76.19778245687485, 75.13822451233864, 80.4876534640789, 74.37856927514076, 78.65767925977707, 72.6315826177597, 82.28045806288719, 72.65947312116623, 96.17601603269577, 34.94994319975376, 0.664559283759445, 1.485179637093097, 62.0445641130209, 77.1543887257576, 57.780641913414, 47.69428074359894, 62.96982206404209, 40.56299440562725, 49.90567468106747, 3.075587502680719, 0.17703472694847733, 0.15226004150463268, 0.10146585147595033, 0.0986732314049732, 0.1292435484356247, 0.1437422790331766, 0.03749117808183655, 0.09193505742587149, 0.18531417095800862, 0.16749639267800376, 0.16935493826167658, 0.2537508588284254, 0.31680224114097655, 0.2812771458411589, 0.4927126143593341, 7.713005198165774, 84.01704847812653, 55.551138147711754, 42.75850139558315, 56.64444588124752, 69.02164712548256, 96.80447190999985, 44.35435116291046, 0.19782304036198184, 0.9032439510338008, 0.8544643060304224, 0.6545356591232121, 18.082418404519558, 95.77267527580261, 77.4605230987072, 91.5132786333561, 78.97197559475899, 86.31588712334633, 80.07421284914017, 81.32532611489296, 80.03038600087166, 67.12352737784386, 59.34532195329666, 62.52222888171673, 62.22304813563824, 60.13054221868515, 56.31121136248112, 57.18523286283016, 54.86770682036877, 58.61430197954178, 56.08571246266365, 58.15881662070751, 55.63760630786419, 58.555583730340004, 54.69641201198101, 57.043435871601105, 55.94184838235378, 62.01819732785225, 51.65004327893257, 56.96049012243748, 48.17014820873737, 52.03205198049545, 53.18306341767311, 53.67711290717125, 53.80129784345627, 54.53452929854393, 56.575042605400085, 63.876685202121735, 69.87239867448807, 53.181497901678085, 55.26577726006508, 60.431235283613205, 61.901691779494286, 62.44006209075451, 67.77370288968086, 66.73046886920929, 68.50083187222481, 63.31276886165142, 52.10213162004948, 53.79948154091835, 53.284966349601746, 65.59412464499474, 64.07723844051361, 63.063414841890335, 61.8186092376709, 59.31918315589428, 61.01073458790779, 53.36068868637085, 47.60134533047676, 55.004324689507484, 60.31712740659714, 51.399230137467384, 48.528370186686516, 52.07157365977764, 63.46472650766373, 60.624280124902725, 63.37982766330242, 60.20220257341862, 61.311777234077454, 58.960497602820396, 60.55302634835243, 61.11229173839092, 62.15206414461136, 64.23078820109367, 63.62383157014847, 59.38673213124275, 59.13577079772949, 54.35925990343094, 47.2626581043005, 62.53704808652401, 59.81981009244919, 29.727528132498264, 50.42512960731983, 59.42413352429867, 59.87543910741806, 58.689408749341965, 60.793485045433044, 57.86749005317688, 59.59640108048916, 60.40886968374252, 59.40701924264431, 59.753059074282646, 59.626256078481674, 61.30963034927845, 58.60533446073532, 60.948911905288696, 58.38419772684574, 62.457225769758224, 62.968727722764015, 61.33680269122124, 58.707769364118576, 59.36921127140522, 53.720122799277306, 52.58165068924427, 56.22309789061546, 52.11899511516094, 51.8357203155756, 53.75362940132618, 49.6184366941452, 49.08806875348091, 45.61337560415268, 47.28669561445713, 49.39225383102894, 55.89836351573467, 49.85440783202648, 54.92488235235214, 53.4554024040699, 55.43638050556183, 54.95531491935253, 53.638742566108704, 55.71947671473026, 55.94748727977276, 53.334093913435936, 60.340294763445854, 55.51698938012123, 57.86984212696552, 55.77432297170162, 64.61959853768349, 70.65659299492836, 75.19462868571281, 77.9430516064167, 78.56696292757988, 78.52825820446014, 82.770966142416, 77.87086308002472, 79.39821392297745, 76.37363702058792, 85.05430921912193, 75.3172405064106, 99.25502881407738, 35.72226695716381, 0.7830864423885942, 2.447675233706832, 67.35437259078026, 83.31771120429039, 66.30184426903725, 56.30865029990673, 74.01177495718002, 58.26320841908455, 65.07530808448792, 4.223832925781608, 0.34901118313428015, 0.27128929272294044, 0.260551068931818, 0.21383254614192992, 0.18191934999777004, 0.20820817997446284, 0.12967390503035858], [0.02733520625042729, 0.11281941217021085, 0.06905284855747595, 0.03733569443284068, 0.061778038725606166, 0.05347882761270739, 0.057983419101219624, 0.11989531529252417, 2.2632146067917347, 57.78420232236385, 36.592488661408424, 47.147216498851776, 69.39994722604752, 54.043603241443634, 82.10276439785957, 38.396255671978, 0.10763335099909455, 0.31214170216117054, 0.2399471792159602, 0.6470526731573045, 29.402814656496048, 88.92259284853935, 70.99014669656754, 83.08810472488403, 73.80684435367584, 81.99817880988121, 73.64189520478249, 76.91677987575531, 70.02543926239014, 59.34495337307453, 55.44556461274624, 55.53753487765789, 53.03764522075653, 52.98860885202885, 51.23561471700668, 50.16469158232212, 48.7791833281517, 51.64103016257286, 50.71502365171909, 53.09720702469349, 51.55174635350704, 53.91727142035961, 52.994532734155655, 53.42726111412048, 49.02788758277893, 51.8930896371603, 50.75973205268383, 49.937813356518745, 45.02139776945114, 45.55878393352032, 43.521318063139915, 48.55792500078678, 47.21400171518326, 49.81099136173725, 50.417465418577194, 61.24755688011646, 53.561488911509514, 49.84060317277908, 45.13834789395332, 53.35857979953289, 52.90240667760372, 51.65258914232254, 55.600558295845985, 58.38168226182461, 62.73833088576794, 53.82911615073681, 49.803011789917946, 43.98654989898205, 53.328595608472824, 51.70249566435814, 55.97180977463722, 52.04342857003212, 51.69232361018658, 59.783689230680466, 50.63025780022144, 42.52720780670643, 54.71983775496483, 47.46539242565632, 34.59643676877022, 43.93862687051296, 50.71918062865734, 55.45118071138859, 56.8427724391222, 53.34155671298504, 55.80010078847408, 54.22983504831791, 59.22577276825905, 59.16732430458069, 59.37514275312424, 57.6546710729599, 59.91064801812172, 57.28166028857231, 57.16702803969383, 53.292193561792374, 55.96236728131771, 54.99156877398491, 43.62345278263092, 32.75615751743317, 52.894769087433815, 50.19387021660805, 27.41377528756857, 49.80170466005802, 49.1536608338356, 53.75352680683136, 52.67906226217747, 57.148112654685974, 52.787922620773315, 55.10142847895622, 52.169274017214775, 55.306609869003296, 53.29597815871239, 53.0286169052124, 51.43581837415695, 59.056203067302704, 55.08479297161102, 61.47703416645527, 56.45496144890785, 55.49594230949879, 53.19408282637596, 58.09776149690151, 59.633289501070976, 57.62985460460186, 47.71760769188404, 47.779232785105705, 46.61695495247841, 46.35227635502815, 41.139773055911064, 42.86223202943802, 38.938300386071205, 44.05132882297039, 48.97754028439522, 49.3555174022913, 47.74808965623379, 48.961725533008575, 50.050876289606094, 51.382628828287125, 46.7288551479578, 49.0080526471138, 49.75373223423958, 50.34286022186279, 49.300633147358894, 49.766085371375084, 51.19477070868015, 52.74913810193539, 51.453031450510025, 53.76662090420723, 57.03568048775196, 65.71319505572319, 69.75616291165352, 73.71701717376709, 72.86641001701355, 74.29057359695435, 70.66864594817162, 72.99408316612244, 66.36846989393234, 75.72346910834312, 70.35681188106537, 84.3408291041851, 46.88455179333687, 0.350013884017244, 0.9437633736524731, 61.12090207636356, 69.38962697982788, 46.64823107421398, 43.103370890021324, 22.235833033919334, 35.79082287847996, 29.22260172665119, 2.72501973900944, 0.11812465483671986, 0.06769808765966445, 0.06040480948286131, 0.0429800392157631, 0.04069874034030363, 0.07117918328731321, 0.05191268450289499, 0.04117682445212267, 0.08539639500668272, 0.06957064499147236, 0.06961224236874841, 0.027140722741023637, 0.12597668857779354, 0.09085843121283688, 0.14403967245016247, 4.609289467334747, 69.65259566903114, 40.93958459794521, 53.05367276072502, 78.77142995595932, 60.691878497600555, 89.78784441947937, 40.02321816980839, 0.07936967347632162, 0.489446897408925, 0.11300155005301349, 0.5674658843781799, 32.881345599889755, 94.27181661128998, 74.51058179140091, 85.80758839845657, 78.15988317131996, 85.99195450544357, 76.8593193590641, 79.64638620615005, 72.92424291372299, 62.10679717361927, 58.86918090283871, 56.29999816417694, 55.46959452331066, 57.19611927866936, 53.914839550852776, 51.8367500603199, 53.47924992442131, 55.00968620181084, 55.100436732172966, 56.914216205477715, 54.399868324398994, 56.71602264046669, 54.326851442456245, 56.14744395017624, 52.14627385139465, 51.83388501405716, 53.24420593678951, 54.37119506299496, 48.038040697574615, 47.066463232040405, 47.50167667865753, 50.8059261739254, 50.673305690288544, 51.684013456106186, 51.76339119672775, 63.33622120320797, 55.9825973957777, 52.25511521100998, 46.20917983353138, 54.52265873551369, 56.19641952216625, 54.196807220578194, 57.32646368443966, 59.87580768764019, 61.379375606775284, 53.146672770380974, 50.88932029902935, 47.570658177137375, 53.395517617464066, 54.55972954630852, 59.447703659534454, 52.93645665049553, 53.17302815616131, 58.441088274121284, 53.7057139724493, 45.713469833135605, 52.108648270368576, 46.67738310992718, 39.59196411073208, 49.051062539219856, 51.89699202775955, 56.23774990439415, 59.93966706097126, 55.88680453598499, 57.039886862039566, 56.78970828652382, 61.940202713012695, 62.085997089743614, 58.67255665361881, 58.671477511525154, 60.4459822922945, 60.32602272927761, 61.28500387072563, 54.98362340033054, 59.47109520435333, 57.82250426709652, 46.84657283127308, 39.79526460170746, 51.111566573381424, 47.54818998277187, 33.54125998914242, 56.12739622592926, 52.695146799087524, 57.59660258889198, 53.69423858821392, 58.797326758503914, 54.5537980645895, 57.26390764117241, 55.9879095107317, 56.26744531095028, 54.28098790347576, 53.69409799575806, 57.223413214087486, 60.752359852194786, 58.73306080698967, 61.14272050559521, 57.60659225285053, 56.88235491514206, 56.286805272102356, 57.89346165955067, 61.92392058670521, 58.887359127402306, 50.59148088097572, 48.31173241138458, 50.21850049495697, 49.067063480615616, 44.0179818123579, 45.69977916777134, 41.063480749726295, 46.83304935693741, 49.7476639598608, 51.12636297941208, 50.76679207384586, 51.39020562171936, 50.879847407341, 52.32983440160751, 50.23045465350151, 51.886189207434654, 51.977866888046265, 55.50134941935539, 51.8545027077198, 54.59005951881409, 52.940416038036346, 55.66917881369591, 54.13002200424671, 55.93286946415901, 60.604418590664864, 69.57803606987, 71.88016533851624, 76.12641468644142, 76.80811330676079, 78.02544638514519, 73.65422174334526, 76.36789172887802, 71.58942013978958, 79.72143977880478, 76.33232563734055, 89.16494384407997, 50.83452343940735, 0.273859350127168, 1.3086496596224606, 67.27477446198463, 76.43537610769272, 54.43901002407074, 50.123953968286514, 33.686624988913536, 47.6304517686367, 40.66371560096741, 3.1560111371800303, 0.1284958198084496, 0.09354182198876515, 0.030958781244407874, 0.103271934640361, 0.08029979973798618, 0.08063207409577444, 0.05902864504605532, 0.26864341751206666, 0.2578791888663545, 0.23053539596730843, 0.28229837073013186, 0.16281741874990985, 0.23137713986216113, 0.24429319601040334, 0.279437925782986, 9.21196823939681, 83.32255974411964, 50.85982248187065, 58.27173136174679, 83.73204857110977, 68.39729502797127, 99.49757739901543, 47.534924894571304, 0.17967289866646752, 0.9101716917939484, 0.41349663224536926, 0.8961524628102779, 34.240984842181206, 98.39304506778717, 78.22707876563072, 88.91842067241669, 80.91347381472588, 87.34272122383118, 80.8950600028038, 82.47249215841293, 74.99147638678551, 65.38570582866669, 59.993814155459404, 59.59912173449993, 58.229401633143425, 59.00934778153896, 56.45064868032932, 55.165067464113235, 57.16963849961758, 60.51664710044861, 56.848145350813866, 60.11809028685093, 59.34027582406998, 58.80418919026852, 58.705804869532585, 59.03056964278221, 54.838102608919144, 55.05922794342041, 57.647455260157585, 57.695758268237114, 50.896270126104355, 51.229527443647385, 50.18466331064701, 55.87535195052624, 52.30757899582386, 55.919118002057076, 57.98467956483364, 66.76544219255447, 59.13966938853264, 50.62945984303951, 47.934047877788544, 57.107185050845146, 58.49316827952862, 55.34159459173679, 59.191760793328285, 61.25998981297016, 65.6685322523117, 54.27225597202778, 53.43011096119881, 52.04588323831558, 55.563118904829025, 57.848928049206734, 62.06395447254181, 61.230735182762146, 54.57880452275276, 56.753868609666824, 53.88187251985073, 50.226282477378845, 55.36093555390835, 53.780072182416916, 45.59148497879505, 49.13749650120735, 53.848517909646034, 58.2493581622839, 61.992981880903244, 58.56651574373245, 57.294465601444244, 58.73538248240948, 62.55964547395706, 67.19633147120476, 60.212294831871986, 59.03656952083111, 62.84399941563606, 62.21925213932991, 64.03634503483772, 56.98447443544865, 63.340435177087784, 61.156464368104935, 46.616179794073105, 45.741295740008354, 63.554188907146454, 49.19955477118492, 33.0509153008461, 52.26014994084835, 56.667252257466316, 61.55836120247841, 56.10287994146347, 64.6165207028389, 57.99123801290989, 60.24936944246292, 57.82117433845997, 60.0156781822443, 56.471384167671204, 56.30912147462368, 58.331395760178566, 67.65734553337097, 59.281200394034386, 64.03227165341377, 60.40458731353283, 61.44482709467411, 58.36134195327759, 62.80569367110729, 64.12580743432045, 61.61288067698479, 52.936650440096855, 51.79435193538666, 51.905560567975044, 53.11255440115929, 46.988008841872215, 49.68336760997772, 43.08866947889328, 50.74379190802574, 53.04861143231392, 53.98015424609184, 53.1947135925293, 53.2210423797369, 54.89508055150509, 54.40289296209812, 52.53437742590904, 53.369595408439636, 54.87249456346035, 58.9226858317852, 54.4667599350214, 56.082448437809944, 56.75728842616081, 60.12931488454342, 55.4019695520401, 59.88668650388718, 62.87740722298622, 73.03449019789696, 75.53468763828278, 80.03854036331177, 77.96305373311043, 80.53339540958405, 75.93764841556549, 80.49266159534454, 74.44659322500229, 83.91756981611252, 80.10737746953964, 92.10150986909866, 52.87548132240772, 0.44190827175043523, 1.8197078676894307, 72.98388451337814, 83.822802901268, 61.05668932199478, 61.56646616756916, 33.858675956726074, 61.26419998705387, 58.64338181912899, 4.155532540753484, 0.21526745898881927, 0.1760121958795935, 0.12275069879251532, 0.32002423075027764, 0.2745197428157553, 0.27469634427689016, 0.37412394653074443], [0.05612379369267728, 0.025901668232108932, 0.05950602782831993, 0.01648817618843168, 0.11951925422181375, 0.02570145905337995, 0.1450012731947936, 0.18548287596786395, 0.6988860480487347, 46.95877321064472, 37.724713906645775, 37.95370861887932, 37.00272984802723, 56.96696117520332, 80.17458066344261, 36.53351962566376, 0.0732732865435537, 0.4253373312531039, 0.20702000154415146, 0.09733974788105115, 54.52065624296665, 86.74540847539902, 74.3623061478138, 79.34472799301147, 75.30321925878525, 73.90535786747932, 74.16937530040741, 79.45692077279091, 60.45617334544659, 56.392424404621124, 52.228452041745186, 56.74996241927147, 55.259196013212204, 57.03197568655014, 55.89175567030907, 54.173423275351524, 52.30455815792084, 53.12677323818207, 51.31441488862038, 53.95767085254192, 54.46421027183533, 52.28762626647949, 49.98509041965008, 49.88112039864063, 49.22042705118656, 50.05995400249958, 50.784723311662674, 51.31716974079609, 45.64367517828941, 46.764778420329094, 45.777553394436836, 46.589056849479675, 47.67865598201752, 48.00271779298782, 48.99487115442753, 59.99010555446148, 57.38860175013542, 50.97263842821121, 42.492329478263855, 53.007360845804214, 48.48300822079182, 49.050606563687325, 47.94708497822285, 58.02484340965748, 51.452963054180145, 51.705098524689674, 45.29441311955452, 47.07538515329361, 56.24183848500252, 52.48119927942753, 52.589767053723335, 54.250327348709106, 58.73957745730877, 47.025824412703514, 39.127442836761475, 46.7186488956213, 37.3135531693697, 28.614442460238934, 42.524354159832, 47.18123987317085, 48.468584194779396, 56.1566736549139, 53.55286717414856, 55.584325566887856, 51.45360141992569, 56.09095998108387, 56.71055093407631, 61.22766114771366, 52.14403577148914, 52.382256388664246, 58.4954671561718, 57.13146574795246, 52.46896393597126, 53.71071830391884, 52.39353038370609, 54.07177872955799, 51.456280276179314, 42.167895287275314, 29.95835244655609, 42.717634588479996, 36.66099898517132, 32.716214060783386, 44.64513435959816, 47.50403635203838, 57.910739332437515, 53.60261410474777, 54.28510308265686, 53.92376147210598, 52.97815181314945, 52.348495200276375, 48.56715850532055, 51.14907056093216, 57.40361474454403, 58.12289334833622, 59.03739407658577, 56.75671465694904, 55.71975789964199, 51.9936740398407, 53.06067578494549, 57.73566372692585, 58.9778208732605, 55.50433225929737, 48.89147110283375, 47.290730997920036, 44.497747868299484, 42.98537202179432, 43.59940007328987, 41.21933698654175, 38.84229093790054, 46.61481186747551, 46.749499440193176, 46.79374046623707, 47.714883238077164, 49.14913907647133, 48.25177922844887, 50.05609340965748, 47.73556552827358, 48.590135872364044, 49.253435879945755, 50.65659798681736, 50.57882376015186, 51.79763875901699, 51.71290710568428, 52.21713624894619, 52.3940509557724, 51.497177481651306, 51.30034804344177, 54.69937205314636, 59.60767887532711, 67.03461974859238, 69.36230644583702, 69.45356994867325, 67.16683745384216, 69.07504186034203, 65.77210709452629, 70.56456193327904, 72.9639583826065, 82.04427033662796, 57.1568787842989, 0.13894502160837874, 0.711988516850397, 61.91438689827919, 66.12488776445389, 48.06224539875984, 43.04305672645569, 33.99201080203056, 35.870288014411926, 24.555540159344673, 2.5773891108110547, 0.19212355400668457, 0.11449428362539038, 0.07588934226077981, 0.13616867683595046, 0.03635067150753457, 0.03301797572930809, 0.03769245224248152, 0.04224378048093058, 0.07739190928987227, 0.0452954583306564, 0.0857938670378644, 0.07361102310824208, 0.013558716145780636, 0.0034939361739816377, 0.3239072364522144, 3.9382445253431797, 63.03379163146019, 44.02516342699528, 39.847097620368004, 43.385691940784454, 60.46737514436245, 86.36018514633179, 41.75347052514553, 0.06217034169822, 0.5258080072235316, 0.08415744625381194, 0.09178308784612454, 59.759944304823875, 91.6893307864666, 78.46076622605324, 83.87204825878143, 78.39984029531479, 78.25849547982216, 76.5332892537117, 84.08012509346008, 66.56846076250076, 59.053064435720444, 55.45150749385357, 58.39158073067665, 58.56070585548878, 61.30937576293945, 57.86697708070278, 57.38734781742096, 54.66123349964619, 56.19827002286911, 53.095531314611435, 56.784266978502274, 56.26427248120308, 55.23412115871906, 51.98190987110138, 50.344524532556534, 50.5850288271904, 53.3498440682888, 51.907585859298706, 54.74616274237633, 48.36119055747986, 48.87065961956978, 47.41031438112259, 49.28956814110279, 47.394883409142494, 49.96566966176033, 51.77070580422878, 63.33630479872227, 59.028574749827385, 51.80369943380356, 44.69601362943649, 54.235200360417366, 49.78289566934109, 50.7518170773983, 49.46107193827629, 60.82976549863815, 52.31313429772854, 53.77972640097141, 48.14872495830059, 50.01041606068611, 57.91274182498455, 56.08604684472084, 55.601561442017555, 56.11906707286835, 58.97378548979759, 47.313446179032326, 43.25692445039749, 45.71229189634323, 38.82489167153835, 34.834585189819336, 44.97486926615238, 47.06876590847969, 50.00590190291405, 57.168171778321266, 55.63969239592552, 56.79957635700703, 54.14603814482689, 56.286117509007454, 57.896493896842, 64.45610091090202, 54.460049495100975, 50.80754488706589, 60.76404042541981, 59.41248334944248, 55.1358812302351, 56.423620730638504, 54.20593433082104, 55.08019521832466, 53.67779687047005, 47.993165105581284, 37.31579504907131, 43.373498395085335, 34.174826592206955, 38.30677427351475, 53.745668828487396, 51.77585832774639, 58.07771757245064, 56.52323618531227, 57.85571068525314, 55.76125547289848, 56.41171596944332, 51.99982970952988, 49.77350257337093, 51.950458958745, 59.6690683811903, 60.69005839526653, 60.658151507377625, 61.02182239294052, 57.98933431506157, 54.32490214705467, 56.42135985195637, 57.96545259654522, 61.34519264101982, 57.69396096467972, 51.08403705060482, 48.173640221357346, 47.84598760306835, 46.89039967954159, 46.90822072327137, 43.4479857981205, 42.69564136862755, 48.598172441124916, 50.2939036488533, 49.60255354642868, 49.7300861030817, 50.75818933546543, 50.569521859288216, 53.380588218569756, 51.757262125611305, 51.2298808246851, 51.70457415282726, 52.967436388134956, 52.863409370183945, 53.15983146429062, 53.77518564462662, 56.673468723893166, 54.75804850459099, 54.252649024128914, 54.202818498015404, 59.388776421546936, 62.5944934040308, 69.70610439777374, 72.2462984919548, 74.71700191497803, 70.59201166033745, 70.61063066124916, 68.91283616423607, 74.77925777435303, 77.64589235186577, 86.23859167098999, 64.34619560837746, 0.010089185034303227, 0.49312204238958657, 69.97278928756714, 73.84010776877403, 57.553797885775566, 50.072983503341675, 36.43805354833603, 47.44836173951626, 39.953533709049225, 2.7988246036693454, 0.15522625733865425, 0.14761349943000823, 0.02363254243391566, 0.12157048360677436, 0.009937010436260607, 0.021763274671684485, 0.03670691352454014, 0.11233082666876726, 0.15210328507237136, 0.12576447887113318, 0.18329386686673388, 0.2523572836071253, 0.20660744165070355, 0.36061771970707923, 0.7163615478202701, 7.457057107239962, 79.30781677365303, 53.30161325633526, 50.18953084945679, 53.62016536295414, 69.50863659381866, 94.92519155144691, 46.204654276371, 0.33279350493103266, 1.1805334780365229, 0.5507908354047686, 0.34433176391758025, 60.27023792266846, 95.75369149446487, 81.82172387838364, 86.14688739180565, 81.91677197813988, 81.01237490773201, 80.00171273946762, 88.35114151239395, 69.63848322629929, 61.79966725409031, 58.32579106092453, 63.50506894290447, 60.84536366164684, 65.19607320427895, 60.12886270880699, 61.181546822190285, 58.96789960563183, 61.52834661304951, 54.790407568216324, 58.45726780593395, 59.88581635057926, 58.596119955182076, 54.677869006991386, 55.78803263604641, 52.85602256655693, 55.85803247988224, 55.365400314331055, 58.38460810482502, 51.0837634652853, 52.78673328459263, 49.87786777317524, 53.0446520447731, 50.196594670414925, 52.07315057516098, 55.78844681382179, 67.18970462679863, 60.83884701132774, 52.41121843457222, 46.150898560881615, 55.357743725180626, 50.7134847342968, 51.930171847343445, 52.05603249371052, 63.021997064352036, 54.74477581679821, 53.062499687075615, 52.41466864943504, 53.09401899576187, 61.06675498187542, 59.34627950191498, 58.131180703639984, 55.87153695523739, 60.72426415979862, 49.911332577466965, 50.11923462152481, 50.18082171678543, 46.96452610194683, 40.05687676370144, 46.008558198809624, 48.57346996665001, 52.82046787440777, 59.11336340010166, 56.82314269244671, 60.694355964660645, 56.58147566020489, 59.29218180477619, 61.818168461322784, 67.59559124708176, 56.07981137931347, 53.46368595957756, 62.752238139510155, 61.78940400481224, 54.838566184043884, 60.14175161719322, 61.330042853951454, 59.3050517141819, 57.06807754933834, 51.76168508827686, 44.96858820319176, 54.54695463180542, 39.398246705532074, 39.07278276979923, 47.25207947194576, 55.50004228949547, 63.70229355990887, 59.87707681953907, 61.672184094786644, 57.47700020670891, 59.310063645243645, 55.887819081544876, 53.0258696526289, 54.61209453642368, 62.83660501241684, 62.26586803793907, 63.491959646344185, 62.31092981994152, 61.21407687664032, 55.816580504179, 58.79824250936508, 60.12436755001545, 63.6630492657423, 60.36088965833187, 53.92567276954651, 50.56390956044197, 51.31651237607002, 50.63050098717213, 48.967280834913254, 47.35946550965309, 45.976480320096016, 51.246516332030296, 51.00524827837944, 50.931581631302834, 51.51935689151287, 54.3338468670845, 53.75204488635063, 55.835655480623245, 53.52969601750374, 53.169551342725754, 54.795552492141724, 54.043588042259216, 55.628916174173355, 56.56788378953934, 55.31578257679939, 58.02898898720741, 58.58154773712158, 57.48613491654396, 56.45735912024975, 62.102925181388855, 65.85771650075912, 74.25990924239159, 76.5201723575592, 76.50073260068893, 74.98676463961601, 73.70880961418152, 74.11587417125702, 77.47889131307602, 79.67355474829674, 88.96967992186546, 65.21122679114342, 0.30218585045076907, 1.6483269701711833, 75.22125765681267, 82.1694128215313, 65.77450096607208, 62.129869535565376, 50.90560622513294, 60.146847143769264, 58.983923345804214, 4.407315580174327, 0.21749125997303054, 0.38820958288852125, 0.1856495178071782, 0.479828366660513, 0.09291387599660084, 0.09687485915492289, 0.09281644684961066], [0.030312712005979847, 0.14118262653937563, 0.07233627315144986, 0.06476010312326252, 0.10956245256238617, 0.058128635137109086, 0.08176430201274343, 0.2764521766221151, 2.3048862582072616, 47.84576341509819, 42.47794345021248, 37.560448721051216, 38.56763407588005, 56.723428443074226, 75.69863364100456, 45.693756490945816, 0.08298972883494571, 0.2768941700924188, 0.3790786728495732, 1.0942757315933704, 69.41943258047104, 77.61242374777794, 75.639159232378, 76.0238429903984, 76.5066146850586, 79.14664462208748, 76.45468667149544, 63.22719365358353, 55.092202574014664, 55.824909657239914, 57.09129810333252, 63.10006767511368, 64.80854719877243, 65.50438866019249, 65.38844168186188, 64.02144223451614, 62.20360457897186, 57.19057157635689, 54.912707805633545, 55.54550305008888, 56.498336121439934, 57.89105258882046, 59.72242131829262, 57.26451560854912, 55.59219494462013, 48.533412516117096, 50.06064936518669, 50.80845683813095, 49.54160861670971, 46.007007881999016, 44.96800683438778, 45.03860704600811, 47.13843137025833, 45.61770737171173, 49.72087539732456, 59.20149587094784, 58.38858649134636, 50.67585535347462, 49.80948284268379, 50.4179859906435, 47.70986370742321, 49.05232787132263, 44.82266843318939, 51.692562997341156, 49.652593061327934, 49.66650031507015, 45.56517519056797, 52.315060794353485, 52.18285068869591, 55.707712545990944, 62.41132043302059, 53.18301022052765, 40.315836668014526, 39.69396583735943, 43.59909608960152, 38.12531881034374, 34.212300181388855, 43.51661391556263, 46.70951418578625, 44.44478251039982, 52.42641381919384, 50.3795700520277, 51.43356889486313, 52.350303903222084, 51.14069581031799, 58.26842553913593, 57.73103177547455, 56.81574068963528, 48.728710636496544, 48.16883347928524, 59.576957523822784, 57.22185529768467, 56.00345067679882, 51.3913531601429, 54.998374208807945, 51.9337322562933, 48.80486994981766, 47.015895545482635, 36.270353347063065, 28.54533936828375, 34.50000174343586, 30.468839854002, 37.23265931010246, 47.671390771865845, 44.98899310827255, 53.357572853565216, 51.25513046979904, 49.79491822421551, 53.42003770172596, 48.592168763279915, 45.69226697087288, 45.445683002471924, 47.73914113640785, 54.63146969676018, 53.370176777243614, 55.48594884574413, 51.74224533140659, 47.96375468373299, 49.88064922392368, 57.53750815987587, 60.131248980760574, 58.55636648833752, 49.58023354411125, 44.76208448410034, 44.82835292816162, 43.818363323807716, 42.25019887089729, 40.65326236188412, 43.6959832906723, 46.91225990653038, 46.99086628854275, 48.96359123289585, 52.222619354724884, 54.10671025514603, 52.65761241316795, 52.05209210515022, 46.06741704046726, 49.90857772529125, 50.928025022149086, 50.11191241443157, 53.414083421230316, 52.783986032009125, 51.878677010536194, 52.15944394469261, 51.92016698420048, 53.70702490210533, 52.387203723192215, 54.84593778848648, 54.27377589046955, 55.5751908570528, 56.17610961198807, 59.04164984822273, 59.324882850050926, 59.84106235206127, 62.64221504330635, 71.61142855882645, 75.5676394701004, 77.75007516145706, 70.37157788872719, 0.3885555424494669, 0.21169780287891626, 61.840883642435074, 65.69447726011276, 44.79905650019646, 46.10987976193428, 36.42258457839489, 30.089565105736256, 29.165863171219826, 1.411777432076633, 0.10854665277292952, 0.07647750913747586, 0.06258383669774048, 0.11109945524367504, 0.07264011583174579, 0.024308355095854495, 0.010757372128864517, 0.04546030788333155, 0.11143021562020294, 0.04107132444914896, 0.052993719073128887, 0.09688725302112289, 0.11439275782322511, 0.07666858247830532, 0.3674464876530692, 4.507785513997078, 63.37698921561241, 48.999043330550194, 40.345942452549934, 42.86277920007706, 67.85836234688759, 83.35605874657631, 52.19711132347584, 0.05921456788200885, 0.36102673213463277, 0.6185739138163626, 1.9579801918007433, 76.29856064915657, 82.40930914878845, 79.1938228905201, 78.30815881490707, 80.57868137955666, 81.23888075351715, 79.41001608967781, 67.93877363204956, 59.86395612359047, 58.62916298210621, 62.16299615800381, 65.695541203022, 67.03037917613983, 67.76702284812927, 69.8178867995739, 67.16582670807838, 65.37159338593483, 60.89376166462898, 59.107302725315094, 58.03363613784313, 60.07580615580082, 59.08270664513111, 61.9192810356617, 57.704805582761765, 55.727874264121056, 53.562974631786346, 51.57372057437897, 52.7824243158102, 51.35128811001778, 46.976252272725105, 47.527241706848145, 48.18506620824337, 51.23772360384464, 48.024988397955894, 53.39978478848934, 60.892948508262634, 61.32624685764313, 53.51932257413864, 52.74161830544472, 52.67796412110329, 51.382389441132545, 51.12403370440006, 47.64646790921688, 52.42374636232853, 49.89440068602562, 53.06647427380085, 48.06185021996498, 54.59339573979378, 54.141216203570366, 57.16572850942612, 60.14029249548912, 54.55582335591316, 45.056447088718414, 41.33916735649109, 43.37497651576996, 40.86314409971237, 41.36388123035431, 44.96675290167332, 44.79641944169998, 46.75378940999508, 53.03927153348923, 50.66558450460434, 54.31047432124615, 55.30956991016865, 54.69445511698723, 59.706804156303406, 59.534502401947975, 58.99667166173458, 49.14530508220196, 49.98409867286682, 61.46393246948719, 58.88318695127964, 58.74687306582928, 53.628274127840996, 56.529790833592415, 53.70373047888279, 52.36524850130081, 49.89671856164932, 41.915098652243614, 34.420111030340195, 38.75485382974148, 29.427072554826736, 41.71939395368099, 55.14250427484512, 48.49138297140598, 56.57182417809963, 54.385961070656776, 52.71057777106762, 53.04951958358288, 50.20155340433121, 49.71140630543232, 46.76518499851227, 48.61041538417339, 55.45151129364967, 55.47154001891613, 56.20397351682186, 54.18803729116917, 50.97004696726799, 52.262015640735626, 57.37763553857803, 60.30793569982052, 60.56117691099644, 52.92182743549347, 46.625200510025024, 46.96606881916523, 46.33562944829464, 46.34632587432861, 42.351756021380424, 45.256677344441414, 48.21647152304649, 49.76629056036472, 51.6034197807312, 53.740223720669746, 57.56727196276188, 55.6113763153553, 54.87849064171314, 50.629383847117424, 51.79892309010029, 51.96041442453861, 52.39725798368454, 56.05986624956131, 55.16387052834034, 53.59805054962635, 54.645608738064766, 55.17380699515343, 56.26204200088978, 54.976137802004814, 58.39113615453243, 58.80061358213425, 59.3864281475544, 57.681094855070114, 62.84946732223034, 63.73547337949276, 61.812715753912926, 65.67844972014427, 77.0399996638298, 81.13998726010323, 82.75604814291, 74.76409658789635, 0.6545429024845362, 0.11050319153582677, 67.67831280827522, 71.40333652496338, 55.47693572938442, 53.08743394911289, 35.17215147614479, 42.60849304497242, 44.95395138859749, 1.3496976695023477, 0.08821057446766645, 0.029304083218448795, 0.06662114232312888, 0.07836162170860916, 0.09192854136927053, 0.10810373903950676, 0.04562094203720335, 0.11937656148802489, 0.2034359477693215, 0.23262632283149287, 0.12347172494628467, 0.33015879162121564, 0.15837346814805642, 0.32214430917520076, 0.8430905663408339, 6.939170071855187, 76.68082013726234, 57.50702239573002, 52.13266298174858, 54.43020209670067, 75.78468382358551, 89.01706337928772, 57.47614525258541, 0.1664323903969489, 0.992787096183747, 1.1057557468302548, 2.808725447393954, 77.19739481806755, 85.89470252394676, 81.36868178844452, 82.0535646378994, 83.24447393417358, 85.61015099287033, 82.03828185796738, 72.27876394987106, 62.99710460007191, 61.8600270152092, 65.13062551617622, 68.6894765496254, 70.12772217392921, 70.51971673965454, 71.55778303742409, 68.00773993134499, 68.0524255335331, 63.259400725364685, 61.81720711290836, 60.867919251322746, 64.96436923742294, 63.69389981031418, 65.04894509911537, 61.90277472138405, 59.166704937815666, 53.20995457470417, 54.45539094507694, 56.41028344631195, 55.699455589056015, 51.874622628092766, 52.38845765590668, 50.540708005428314, 53.481286615133286, 51.758968234062195, 54.33588735759258, 63.344208374619484, 63.20333853363991, 57.21075229346752, 52.84397341310978, 56.316534876823425, 52.74375379085541, 53.982171937823296, 49.48498785495758, 56.201610043644905, 53.713408559560776, 54.08014968037605, 52.225894778966904, 58.00935924053192, 58.20441797375679, 60.3098089993, 61.25054731965065, 58.14038001000881, 52.85379968583584, 47.59749233722687, 46.57893419265747, 43.30430790781975, 45.156073942780495, 46.97682984173298, 46.74184665083885, 48.21394465863705, 55.60284577310085, 54.28477630019188, 54.80551935732365, 59.02543991804123, 55.37300370633602, 62.833299189805984, 60.10650470852852, 61.074065789580345, 49.18575011193752, 51.226749792695045, 63.66703525185585, 61.18750490248203, 61.69690556824207, 56.93397134542465, 60.45314110815525, 59.092107340693474, 54.283545166254044, 51.86776399612427, 42.08321303129196, 40.60039579868317, 45.46749383211136, 36.91510275006294, 45.29473230242729, 50.322455316782, 51.71265251934528, 57.90633536875248, 56.81098714470863, 57.67500378191471, 58.083041086792946, 51.06439970433712, 51.621970385313034, 50.47090195119381, 51.07699602842331, 57.38214209675789, 58.2327226549387, 59.698767587542534, 57.086749747395515, 53.3632193505764, 54.80061762034893, 60.12019917368889, 62.789601534605026, 64.03734818100929, 55.21767184138298, 50.623630955815315, 50.464225709438324, 49.207720533013344, 49.50250491499901, 44.81237478554249, 48.68290029466152, 50.75537748634815, 51.2454903870821, 53.87113429605961, 55.79622119665146, 58.54327239096165, 56.58822409808636, 57.25701101124287, 50.30180722475052, 54.099281653761864, 55.20276144146919, 53.69195491075516, 59.49153430759907, 57.86478079855442, 57.38300085067749, 56.55262380838394, 58.201678320765495, 58.83308283984661, 58.17963570356369, 61.22551426291466, 61.72950781881809, 63.17973420023918, 63.63327406346798, 66.40728861093521, 66.63094460964203, 65.05950093269348, 69.85775426030159, 77.39945277571678, 83.78852874040604, 84.08592358231544, 78.29149290919304, 0.7179604901466519, 0.47172809194307774, 73.72992128133774, 77.71283715963364, 63.56451295316219, 67.6907305419445, 56.01817488670349, 52.27385960519314, 63.37147191166878, 1.926511349156499, 0.2247449371498078, 0.19553778955014423, 0.21156994567718357, 0.29992773255798966, 0.1822096187970601, 0.14937684230972081, 0.08526650432031602], [0.06378332545864396, 0.05256409349385649, 0.01807156681024935, 0.04747869723360054, 0.056602957629365847, 0.06689386675134301, 0.16300460323691368, 0.25798754242714494, 1.7348869191482663, 47.55180738866329, 41.515572890639305, 34.85966384410858, 44.62099805474281, 53.22502836585045, 71.20270729064941, 58.100387156009674, 0.27667710673995316, 0.39837344374973327, 0.720922431210056, 6.305483300238848, 79.19566959142685, 74.85757157206535, 75.3909033536911, 71.4737619459629, 74.8740702867508, 68.50343093276024, 64.3975080549717, 56.09404541552067, 57.24319115281105, 61.67967729270458, 65.06639376282692, 67.19822376966476, 69.78168234229088, 67.09557607769966, 67.84977480769157, 67.20463782548904, 68.36632668972015, 67.51454919576645, 64.54709082841873, 63.29274773597717, 66.01850107312202, 65.54518327116966, 65.19494086503983, 64.27235797047615, 63.81024956703186, 53.41697886586189, 49.50187414884567, 51.06330156326294, 49.20429691672325, 44.35633085668087, 45.02497337758541, 43.886003494262695, 46.604491621255875, 44.69140067696571, 49.08784456551075, 55.12195497751236, 51.00040353834629, 49.54776808619499, 51.447183564305305, 48.901149183511734, 46.03952273726463, 45.05250670015812, 45.502812936902046, 47.43651017546654, 46.17747813463211, 49.50942054390907, 47.63380318880081, 52.60260656476021, 54.31149646639824, 56.07261076569557, 47.80961215496063, 43.958917781710625, 42.724151238799095, 49.693532064557076, 40.155325680971146, 37.093803361058235, 42.8634137660265, 43.36028650403023, 45.503865480422974, 51.21634595096111, 49.28130738437176, 51.78098805248737, 53.976065665483475, 51.91064849495888, 54.4369163364172, 55.00096186995506, 56.13331250846386, 58.504210487008095, 48.55651527643204, 46.18026338517666, 59.33991864323616, 56.34306125342846, 55.75201436877251, 50.51048822700977, 53.925456181168556, 48.45499612390995, 46.55304238200188, 46.945519521832466, 44.96103800833225, 31.143748238682747, 30.027428939938545, 33.29354368150234, 27.121040895581245, 36.970002204179764, 47.56042152643204, 40.57978190481663, 48.876454308629036, 49.866802766919136, 50.430380925536156, 52.54665456712246, 50.85550591349602, 46.059084087610245, 44.56090047955513, 43.981788754463196, 47.2528812289238, 48.327254578471184, 47.31953725218773, 45.63086226582527, 47.49777048826218, 51.05790965259075, 61.467675268650055, 56.26678414642811, 52.01261982321739, 46.00544236600399, 44.59823727607727, 44.31926004588604, 41.16797514259815, 42.05961249768734, 46.97369121015072, 47.63146631419659, 47.51155614852905, 57.37003594636917, 57.78755374252796, 61.34996898472309, 61.87893860042095, 59.47507359087467, 56.43840953707695, 57.00848534703255, 59.098718985915184, 59.77253682911396, 59.870674163103104, 59.584940895438194, 57.70838499069214, 55.92784233391285, 53.45549739897251, 53.151141330599785, 52.180054038763046, 55.56338869035244, 56.49690739810467, 55.00088967382908, 55.741371139883995, 54.784913063049316, 56.16546258330345, 59.06282991170883, 59.67724174261093, 68.41456890106201, 75.54903566837311, 75.74660986661911, 76.85317128896713, 1.483209205325693, 0.06570762532646768, 60.02762094140053, 67.9358933866024, 44.11331869661808, 43.22750262916088, 37.781463861465454, 41.12701714038849, 38.297434374690056, 0.7270273973699659, 0.16787488799309358, 0.02871217962820083, 0.03217342651623767, 0.011061184195568785, 0.06864825190859847, 0.048173592367675155, 0.040165651953429915, 0.016045516640588176, 0.045612674512085505, 0.08369479881366715, 0.03436470287851989, 0.057267721567768604, 0.12992672505788505, 0.04612278600689024, 0.19698390882695094, 2.5030503747984767, 60.78400835394859, 46.7808173596859, 37.719869166612625, 46.08079992234707, 63.5621190816164, 75.82155704498291, 66.63139298558235, 0.27376215846743435, 0.798663409659639, 0.8859207399655133, 8.5441455245018, 87.53755956888199, 80.0291396677494, 79.30224627256393, 74.63633224368095, 77.38367602229118, 73.06424260139465, 67.37410113215446, 59.8406557738781, 59.40983109176159, 65.03349512815475, 68.67855593562126, 69.51283156871796, 73.95281732082367, 70.48208355903625, 69.59495276212692, 70.5425763130188, 70.9225483238697, 71.9366455078125, 65.91238796710968, 66.73508182168007, 68.67519691586494, 68.78258675336838, 67.86604553461075, 66.14935845136642, 64.3263378739357, 55.48038214445114, 50.76387383043766, 53.78239005804062, 50.54230011999607, 49.32660095393658, 46.9529215246439, 47.3630715161562, 48.590025678277016, 47.27032229304314, 49.99971203505993, 57.75733396410942, 53.66994269192219, 54.17081281542778, 53.37002478539944, 50.82588650286198, 47.92300947010517, 47.76541292667389, 49.08976346254349, 48.14790040254593, 49.14215125143528, 50.71332894265652, 50.602382495999336, 55.82544922828674, 56.93202964961529, 56.48771949112415, 49.35881942510605, 47.294375002384186, 45.657286047935486, 52.10161104798317, 44.53039191663265, 41.45570330321789, 43.064362183213234, 43.400115966796875, 48.45564588904381, 52.094368636608124, 51.85777433216572, 53.83559860289097, 55.52679285407066, 54.43452246487141, 55.02008244395256, 57.503511384129524, 58.04058216512203, 61.72570422291756, 49.94546614587307, 49.199858754873276, 61.268877536058426, 57.90344372391701, 59.292835369706154, 52.3739006370306, 54.27582398056984, 51.972721964120865, 50.14964438974857, 49.44542437791824, 45.949357375502586, 35.64817473292351, 34.52565796673298, 38.70104871690273, 28.225797414779663, 41.485440507531166, 55.34938417375088, 44.31198723614216, 49.40464496612549, 51.514318361878395, 54.51597489416599, 54.74708989262581, 52.0066237449646, 46.36897645890713, 46.43486112356186, 44.088179245591164, 49.64242100715637, 50.17408087849617, 50.32848559319973, 48.53948839008808, 50.1277119666338, 52.58981645107269, 60.864624828100204, 57.24933922290802, 54.73057597875595, 48.60609121620655, 47.581772580742836, 45.86702339351177, 45.773411616683006, 45.27983710169792, 49.47965294122696, 49.876602441072464, 50.78402414917946, 59.16512422263622, 61.144871190190315, 62.39142470061779, 65.27558013796806, 64.20151457190514, 60.858879536390305, 59.57807086408138, 61.55250571668148, 62.105771228671074, 63.21458972990513, 65.07840871810913, 62.854129672050476, 58.896714225411415, 57.258587926626205, 56.34101316332817, 56.13246135413647, 56.40055976808071, 58.51488411426544, 57.992134764790535, 58.76226603984833, 57.604563161730766, 58.67927089333534, 60.43179765343666, 63.70589956641197, 72.7949358522892, 81.28095209598541, 78.27957674860954, 80.54791063070297, 2.002605590969324, 0.11362092423951253, 65.53712010383606, 73.38207274675369, 50.95711246132851, 54.204638600349426, 38.97132821381092, 52.48374134302139, 53.888598158955574, 0.6662290566600859, 0.0014002603484186693, 0.05876042916497681, 0.12238070848979987, 0.07713892598985694, 0.025608991163608152, 0.04881556124018971, 0.06085434688429814, 0.1787363231414929, 0.19125449907733127, 0.17854413657914847, 0.13429928105324507, 0.16944893868640065, 0.2665182331111282, 0.2960184548282996, 0.4543315863702446, 4.748934349045157, 81.19190007448196, 57.02720694243908, 48.62684570252895, 61.41122929751873, 70.58943539857864, 82.89602503180504, 68.83604228496552, 0.3935163246933371, 1.2904489925131202, 1.2798305810429156, 10.253170318901539, 89.79595318436623, 83.06703865528107, 83.31768840551376, 77.01619014143944, 81.36298209428787, 74.1380649805069, 70.13725966215134, 62.90899492800236, 63.03144335746765, 68.8066166639328, 72.40555554628372, 72.80438214540482, 76.45325794816017, 74.6090193092823, 73.09006601572037, 71.65622815489769, 74.00757998228073, 74.55329149961472, 68.59431445598602, 69.45477068424225, 72.11254566907883, 70.1900540292263, 71.72644838690758, 67.90801048278809, 69.1852131485939, 59.45730574429035, 54.29267607629299, 56.224857196211815, 55.40312089025974, 51.4143343269825, 50.37048853933811, 49.99669499695301, 51.58356584608555, 50.9694541990757, 53.74976500868797, 61.08888499438763, 59.02793638408184, 55.55629447102547, 55.96186950802803, 54.93034265935421, 51.172108724713326, 51.163559183478355, 50.834854021668434, 52.93663904070854, 52.671428471803665, 52.97239512205124, 53.67687352001667, 59.24047417938709, 62.15791203081608, 60.693987384438515, 55.498659163713455, 53.36781330406666, 46.72580771148205, 53.80491904914379, 47.03949227929115, 44.10317704081535, 46.985409781336784, 44.92296405136585, 49.079523012042046, 54.59110826253891, 54.80444021522999, 59.26261939108372, 59.793652296066284, 56.39718934893608, 57.76672326028347, 60.69538190960884, 59.53696466982365, 63.33249360322952, 51.33280970156193, 48.295913860201836, 63.644992634654045, 62.768410071730614, 61.82407334446907, 54.64919954538345, 60.02542465925217, 53.90488028526306, 50.99004149436951, 52.17974625527859, 48.22914004325867, 37.74563558399677, 38.97442504763603, 42.97596372663975, 35.23750796914101, 45.5120350420475, 47.4635761231184, 45.57768031954765, 54.469868168234825, 53.943429216742516, 58.82011033594608, 57.4282032251358, 54.84160602092743, 50.45135959982872, 49.593597427010536, 48.227859511971474, 51.860833168029785, 52.806925401091576, 52.346051931381226, 50.39870962500572, 50.96653215587139, 55.985291451215744, 63.69234949350357, 61.612082719802856, 58.987020179629326, 51.45537972450256, 49.60307411849499, 49.571737200021744, 46.62336900830269, 49.071239456534386, 54.06181946396828, 52.96648643910885, 53.12172330915928, 63.79800662398338, 64.61910456418991, 64.79905530810356, 67.7692799270153, 64.2184616625309, 62.7912088483572, 61.57008357346058, 63.9935365319252, 65.10955184698105, 65.99816456437111, 65.72705671191216, 64.01875957846642, 61.35856032371521, 60.60506455600262, 58.373250514268875, 59.071554243564606, 60.403956547379494, 62.230541333556175, 59.700868874788284, 62.85163700580597, 60.58036968111992, 62.158937975764275, 63.35113540291786, 67.27325454354286, 74.60489273071289, 84.24819767475128, 80.58524742722511, 84.36194837093353, 2.124446528032422, 0.2853262145072222, 70.05683317780495, 82.36248806118965, 59.64319936931133, 63.33526745438576, 55.969659090042114, 63.07563118636608, 67.51590952277184, 1.3199179549701512, 0.22483711189124733, 0.13169196783564985, 0.2067782692029141, 0.20091457525268197, 0.14345157978823408, 0.1711663871537894, 0.11171188292792067], [0.040601088549010456, 0.06510942461318336, 0.04251340273185633, 0.032832312645041384, 0.08802495591226034, 0.06058452796423808, 0.0788922498759348, 0.11727266188245267, 1.1456994409672916, 42.38821126520634, 43.25180992484093, 53.22845198214054, 38.332369700074196, 51.25237561762333, 61.32511451840401, 67.74667114019394, 0.9608946356456727, 0.7886913791298866, 0.5552071484271437, 15.19853750243783, 86.37532353401184, 70.27744174003601, 79.10547763109207, 67.1590630710125, 63.89099523425102, 61.04472376406193, 57.383836805820465, 54.17361706495285, 62.00621277093887, 63.27155627310276, 68.38064432144165, 66.46941527724266, 69.42056491971016, 71.38239204883575, 66.0298852622509, 64.22123551368713, 65.96645146608353, 66.70833885669708, 67.92118817567825, 64.4105413556099, 65.98616480827332, 62.97445021569729, 66.14662259817123, 63.043811693787575, 65.66869184374809, 56.88917174935341, 50.6613477319479, 49.16322112083435, 49.5405712723732, 44.96310509741306, 43.63085478544235, 45.88679373264313, 47.20549777150154, 45.30801638960838, 53.10486361384392, 50.44725202023983, 49.524976909160614, 49.06530797481537, 45.926391407847404, 49.17881168425083, 45.858587846159935, 44.01195153594017, 43.81784275174141, 43.65227423608303, 42.85239435732365, 47.21717454493046, 50.449820682406425, 52.17257224023342, 54.13392439484596, 48.6106813699007, 47.352701872587204, 48.02682749927044, 49.21704523265362, 51.184910237789154, 51.91518925130367, 45.01537129282951, 49.44866180419922, 49.600592851638794, 46.03221192955971, 48.691693022847176, 48.70571807026863, 51.03612542152405, 50.26722528040409, 51.48934230208397, 53.74890245497227, 54.525007009506226, 58.10751177370548, 60.00592030584812, 51.02404586970806, 49.44071643054485, 56.83053709566593, 56.64208620786667, 56.107530891895294, 51.64153553545475, 52.37828180193901, 51.538868844509125, 47.5292631983757, 45.10658919811249, 48.84672850370407, 45.66727951169014, 34.309715554118156, 33.76193314790726, 35.78814782202244, 27.723874747753143, 34.78891164064407, 47.32142575085163, 44.95194509625435, 45.960950553417206, 52.827744483947754, 51.10780097544193, 48.970404267311096, 47.522054985165596, 42.917325273156166, 44.208678379654884, 42.71924950182438, 45.40219433605671, 46.81547150015831, 44.58189055323601, 48.739217072725296, 49.120503813028336, 55.56304670870304, 56.203350350260735, 52.33212947845459, 43.07362988591194, 44.278841614723206, 43.65767754614353, 42.18131996691227, 42.65158653259277, 45.20575627684593, 45.526504665613174, 50.774965435266495, 56.20373032987118, 59.84865814447403, 60.40446192026138, 62.3421261459589, 62.98206500709057, 62.052862867712975, 64.60795596241951, 63.021328300237656, 60.81460811197758, 64.43260297179222, 67.17504501342773, 63.806746155023575, 64.43535402417183, 62.76541203260422, 61.91130146384239, 60.13743884861469, 58.18987995386124, 56.37171931564808, 56.985348388552666, 59.87850174307823, 60.04629693925381, 59.79429826140404, 60.99731370806694, 60.62227763235569, 65.29777094721794, 76.53352484107018, 74.57043617963791, 83.61237779259682, 2.3032684950158, 0.11140516813611612, 66.36969342827797, 64.96174737811089, 44.7755129635334, 43.23942258954048, 53.91145013272762, 42.26369574666023, 47.012156546115875, 1.1052477615885437, 0.09211322481860407, 0.015604443433403503, 0.006945188188183238, 0.011343230926286196, 0.017138661205535755, 0.037816016119904816, 0.14049544231966138, 0.0573280989920022, 0.13729556871112436, 0.032318349403794855, 0.02075275897368556, 0.046927507864893414, 0.02950621084892191, 0.041278238932136446, 0.1074640077422373, 1.8762877816334367, 57.510081231594086, 46.14164225757122, 55.335070341825485, 50.62053792178631, 56.95889800786972, 66.03924795985222, 77.10743084549904, 1.0317681357264519, 0.857161923777312, 0.7032849651295692, 17.979943603277206, 95.38284659385681, 75.79383373260498, 85.15742808580399, 70.69589048624039, 69.84433338046074, 64.65268716216087, 61.023034527897835, 57.14120462536812, 65.27146875858307, 66.0985703766346, 71.62078365683556, 68.81804645061493, 74.19152811169624, 73.3213672041893, 70.15505790710449, 67.3651260137558, 68.8532629609108, 69.7006630897522, 71.11674830317497, 66.2663085758686, 67.41643086075783, 65.62507018446922, 68.04559350013733, 66.09696686267853, 69.027339220047, 59.16655674576759, 52.95580521225929, 51.591598615050316, 51.962998285889626, 48.49674828350544, 45.79263478517532, 47.36463703215122, 47.389335706830025, 46.97694003582001, 53.94411318004131, 53.03767181932926, 52.49542571604252, 54.77368466556072, 49.66898538172245, 51.53386451303959, 48.71918074786663, 48.70632603764534, 46.601713970303535, 44.7767098993063, 44.512061700224876, 48.283796310424805, 53.33860047161579, 56.10354110598564, 56.6007786244154, 54.67596150934696, 53.043067529797554, 50.73294349014759, 51.91884085536003, 53.65805692970753, 56.18860714137554, 50.2862698584795, 51.67365521192551, 51.11307889223099, 49.948866963386536, 49.107941687107086, 49.7033279389143, 54.090481325984, 52.88823343813419, 53.89281213283539, 56.418434008955956, 58.712595105171204, 62.29756213724613, 61.82897888123989, 53.42447966337204, 52.69519619643688, 60.147945284843445, 58.73782575130463, 58.643153831362724, 52.69302271306515, 53.552168011665344, 52.94365346431732, 49.31336626410484, 45.61755158007145, 50.27155324816704, 47.692821621894836, 37.89938673377037, 37.23686948418617, 39.98501121997833, 26.85741674154997, 39.47162076830864, 53.89292232692242, 46.866077184677124, 46.71288460493088, 54.60591606795788, 54.656909331679344, 52.21608750522137, 50.774399265646935, 47.40791290998459, 45.85664615035057, 45.983441546559334, 46.142607405781746, 47.30622656643391, 46.999826207756996, 51.65364928543568, 50.45815743505955, 57.05770030617714, 57.8853452950716, 53.96060809493065, 45.15795484185219, 47.24612519145012, 46.49913847446442, 44.395848736166954, 45.484117940068245, 48.139278665184975, 49.12000223994255, 52.90191650390625, 57.47725859284401, 62.41312153637409, 64.5409731566906, 66.34094417095184, 64.90457564592361, 65.40357246994972, 65.54307818412781, 65.70792093873024, 65.73384314775467, 68.08462500572205, 68.33639949560165, 67.25686222314835, 68.07584747672081, 68.10778096318245, 65.45391216874123, 64.50304359197617, 59.978816360235214, 59.77542467415333, 60.26137299835682, 63.11145946383476, 64.8383603990078, 65.2937051653862, 65.02131298184395, 67.07875058054924, 68.61288025975227, 82.67048433423042, 78.07731360197067, 88.10287803411484, 2.9753723926842213, 0.27745466970372945, 72.25669473409653, 70.16851678490639, 50.44235408306122, 53.59433054924011, 57.97128148376942, 47.62463428080082, 63.87672320008278, 1.2312100525014102, 0.11508237628731877, 0.027884477167390287, 0.03723662142874673, 0.055118784730439074, 0.03832993854302913, 0.0614625183516182, 0.03758837716304697, 0.0864446785999462, 0.30189068347681314, 0.10341879824409261, 0.08707727785804309, 0.12341567053226754, 0.21649474860168993, 0.20165739086223766, 0.31051369733177125, 2.9286391753703356, 71.8864805996418, 56.35528899729252, 67.53262862563133, 55.07991023361683, 68.48035097122192, 72.10339576005936, 84.04174715280533, 1.201128966640681, 1.7687117541208863, 0.788744279416278, 19.089149683713913, 96.9025294482708, 76.08593925833702, 88.00486609339714, 74.80660110712051, 70.30681416392326, 65.47109484672546, 62.62173414230347, 58.96777421236038, 69.24877613782883, 69.5501759648323, 73.61413389444351, 70.3824833035469, 75.25183841586113, 77.17315211892128, 69.69712167978287, 67.98732742667198, 71.32458955049515, 73.5991171002388, 73.60399603843689, 72.92278379201889, 69.41277533769608, 67.00131833553314, 70.90752393007278, 68.42317163944244, 71.41308680176735, 61.358700916171074, 54.661051109433174, 52.89551004767418, 54.13977228105068, 51.317758709192276, 49.22158218920231, 53.453726693987846, 50.30871905386448, 50.099198296666145, 57.47296862304211, 55.30101276934147, 55.80752559006214, 57.295863926410675, 53.05863529443741, 56.154959946870804, 51.16830512881279, 50.064004585146904, 49.02081236243248, 48.96110616624355, 46.90029814839363, 53.43153588473797, 56.77267760038376, 57.235143184661865, 59.33595925569534, 57.31669440865517, 54.852887615561485, 51.31745092570782, 55.56337729096413, 59.07270558178425, 57.62342154979706, 49.774232134222984, 53.42031128704548, 53.32971274852753, 52.49648965895176, 53.318442553281784, 52.670801505446434, 58.01831915974617, 56.28111697733402, 57.67740525305271, 60.973428189754486, 59.07000012695789, 62.89372734725475, 65.13058751821518, 54.86098498106003, 54.32646006345749, 61.112466529011726, 61.109232902526855, 61.867098435759544, 55.863671377301216, 55.74290245771408, 55.80527611076832, 53.34757179021835, 48.891159519553185, 55.59047743678093, 49.40982028841972, 38.156705126166344, 38.75966057181358, 42.81908914446831, 34.06648300588131, 44.59324814379215, 49.22646872699261, 48.4252855181694, 50.75467452406883, 56.31539113819599, 58.142390102148056, 55.563726872205734, 53.55090267956257, 49.203932136297226, 51.23766280710697, 48.946461752057076, 49.406883046031, 50.30024170875549, 50.10214313864708, 54.077493622899055, 52.9035048186779, 60.43401673436165, 62.566929683089256, 58.80806878209114, 47.59801670908928, 50.63204750418663, 49.29175682365894, 48.292174860835075, 48.01661744713783, 50.63957870006561, 48.771956115961075, 56.64709813892841, 60.25731481611729, 63.65247443318367, 66.09616130590439, 67.57269367575645, 66.61399751901627, 67.75242403149605, 67.79502734541893, 67.27505564689636, 66.03819161653519, 70.74800089001656, 70.68521305918694, 69.2370879650116, 71.76996365189552, 68.63835409283638, 66.40652105212212, 67.14041367173195, 63.00370864570141, 63.352142348885536, 62.5770029425621, 67.11008369922638, 65.70830851793289, 67.14162960648537, 64.91497948765755, 69.8063126206398, 71.91773772239685, 87.21089869737625, 81.3235554099083, 89.59812059998512, 3.3969695074483752, 0.552797483978793, 78.77348184585571, 76.03749185800552, 61.854638904333115, 64.58245933055878, 80.15311941504478, 62.26977422833443, 72.2003285586834, 2.0491093955934048, 0.26733575330581516, 0.14808443665970117, 0.1452334169880487, 0.09961791860405356, 0.0969514339521993, 0.1683611431508325, 0.3492765157716349], [0.020601986107067205, 0.03353033593157306, 0.08869316341588274, 0.021274175232974812, 0.07225972804008052, 0.03047878053621389, 0.01852318222518079, 0.04807728015293833, 0.46140452090185136, 46.536414474248886, 46.349620297551155, 36.34118154644966, 29.40562080591917, 54.09221403300762, 55.393081828951836, 77.86631852388382, 3.2998483814299107, 0.5922890617512167, 0.1806938712252304, 27.600404173135757, 92.33305424451828, 70.14995858073235, 75.74600949883461, 64.32931691408157, 63.118758872151375, 56.12580791115761, 58.91374111175537, 58.899963051080704, 62.8839048743248, 65.2238193154335, 71.22500449419022, 68.55962991714478, 66.52351677417755, 67.60664865374565, 67.2156572341919, 62.714954540133476, 68.5786896944046, 67.07239732146263, 66.12402901053429, 64.11286532878876, 68.08407783508301, 64.18531984090805, 62.69951216876507, 64.84863504767418, 62.17124551534653, 57.49619297683239, 51.31602220237255, 48.96913133561611, 50.42275853455067, 46.704813838005066, 43.21526728570461, 44.34658817946911, 45.62243811786175, 43.64194259047508, 49.6239197999239, 47.09013596177101, 46.14490628242493, 49.569586515426636, 45.266883596777916, 44.88163746893406, 42.90922410786152, 42.04524926841259, 40.82125894725323, 39.87195588648319, 40.122001469135284, 44.85138349235058, 46.648474261164665, 56.47078759968281, 54.05649974942207, 54.671926125884056, 50.162396505475044, 47.79057517647743, 55.165496841073036, 58.37184838950634, 54.14254233241081, 56.10963977873325, 55.0369231402874, 46.405196115374565, 48.15764307975769, 48.163160383701324, 49.28098440170288, 53.17479886114597, 50.037250220775604, 51.46817363798618, 53.01639296114445, 55.45209266245365, 55.2150309830904, 58.038199692964554, 52.69798144698143, 50.838395431637764, 54.01849418878555, 52.072075232863426, 54.18921522796154, 50.25234527885914, 51.51446275413036, 50.86060903966427, 49.28925275802612, 48.562226369977, 46.20769791305065, 45.553156435489655, 47.099487259984016, 36.54402606189251, 42.047251760959625, 44.57878611981869, 32.61298879981041, 32.219675704836845, 49.21115554869175, 48.14801439642906, 47.658235877752304, 49.64552544057369, 51.56926341354847, 46.43545389175415, 39.97226670384407, 39.643550142645836, 41.567101925611496, 44.346637576818466, 43.80010910332203, 46.60720467567444, 44.99778963625431, 47.88929767906666, 51.73451654613018, 52.05419339239597, 47.94898487627506, 45.88974617421627, 43.28744061291218, 42.29206122457981, 41.132526844739914, 43.50972108542919, 45.29862329363823, 47.58146479725838, 54.27702471613884, 58.33672687411308, 60.51410123705864, 63.83297234773636, 63.34629826247692, 64.2928920686245, 65.28973817825317, 63.78305822610855, 64.28172826766968, 63.687071576714516, 61.93270571529865, 64.554523229599, 66.1134883761406, 66.3603763282299, 64.8904100060463, 67.6944999396801, 68.0326209962368, 66.11772134900093, 67.96352550387383, 69.02701243758202, 69.57216158509254, 70.77070087194443, 70.82080498337746, 70.50692662596703, 72.79221519827843, 66.18671804666519, 72.92294338345528, 74.09769594669342, 86.89129784703255, 2.4665167601779103, 0.8501031494233757, 68.77888575196266, 66.51308253407478, 48.69971439242363, 38.90773102641106, 36.149143651127815, 46.249951645731926, 59.55247163772583, 1.3117854413576424, 0.050859283801401034, 0.07658419286599383, 0.04242733586579561, 0.014453216535912361, 0.06271559759625234, 0.00929929406993324, 0.08025527087738737, 0.1350192682002671, 0.07526424611569382, 0.005652915197060793, 0.015477876640943578, 0.020137043575232383, 0.04066210050950758, 0.04107053035113495, 0.07185291979112662, 0.4181442578556016, 58.326885402202606, 50.85598848760128, 44.86478917300701, 46.704050078988075, 60.759879648685455, 63.7240169942379, 81.3583767414093, 3.6374476784840226, 0.7570294593460858, 0.13313258037669584, 31.188741624355316, 96.85070022940636, 74.51049819588661, 80.88447377085686, 68.26853513717651, 65.59011206030846, 58.82141746580601, 62.2333075851202, 61.893655210733414, 66.90710619091988, 68.0218143761158, 72.92199343442917, 70.51210954785347, 69.49367299675941, 68.8091017305851, 70.38185253739357, 67.03276544809341, 72.38404870033264, 69.89844247698784, 70.91658264398575, 66.46021217107773, 68.89693021774292, 66.25252291560173, 66.39778152108192, 66.4685033261776, 65.4476349055767, 59.0234450250864, 52.89581023156643, 52.21699945628643, 52.05510534346104, 48.811660185456276, 45.830024778842926, 45.97056403756142, 45.61478912830353, 46.27285681664944, 49.91587333381176, 49.03462082147598, 48.66626098752022, 51.07155852019787, 49.22144539654255, 47.49172121286392, 45.400845408439636, 44.44940306246281, 43.15788276493549, 42.64256961643696, 44.00722078979015, 49.37924712896347, 49.67106007039547, 55.71454077959061, 56.838790252804756, 56.522818207740784, 53.37810695171356, 53.575217574834824, 55.606379583477974, 61.064083725214005, 56.6262486577034, 59.38298173248768, 56.614845469594, 49.73741590976715, 49.34238150715828, 49.198658019304276, 53.51831562817097, 54.38584707677364, 54.496622532606125, 54.47767674922943, 55.05941033363342, 58.083253875374794, 58.11519116163254, 59.43327583372593, 55.746542662382126, 52.7524059265852, 56.4675235748291, 56.01659797132015, 56.46059274673462, 52.35759571194649, 53.42705972492695, 53.15711461007595, 51.03521727025509, 50.86324989795685, 47.23277270793915, 46.22061721980572, 47.79143773019314, 39.64717894792557, 44.66064512729645, 48.39536592364311, 34.58602152764797, 35.01297801733017, 55.498161390423775, 49.57569658756256, 49.23996180295944, 52.0856861025095, 54.324791952967644, 48.18451903760433, 43.012088388204575, 41.71480379998684, 44.69862788915634, 45.064362064003944, 46.185438707470894, 46.57817043364048, 47.76463396847248, 50.03515653312206, 53.72610367834568, 54.24330532550812, 51.84676632285118, 46.58236920833588, 44.123612344264984, 44.618976563215256, 43.61011169850826, 45.51649980247021, 49.172443225979805, 49.01496447622776, 55.65673828125, 60.67403465509415, 63.387978225946426, 64.60841193795204, 67.41630166769028, 63.84164348244667, 66.35391667485237, 66.74760594964027, 66.11174806952477, 66.26786649227142, 65.41754052042961, 68.55113357305527, 67.22460955381393, 69.87673804163933, 70.91893091797829, 70.3145581483841, 71.43615156412125, 70.59261202812195, 71.78701713681221, 70.55250138044357, 72.86831751465797, 74.17471781373024, 77.18742415308952, 74.03749197721481, 76.6773547232151, 69.21577870845795, 78.23650985956192, 75.31489983201027, 92.66856864094734, 2.9664623457938433, 1.0067892260849476, 75.16342476010323, 72.41833046078682, 55.957104563713074, 46.7177901417017, 41.978794634342194, 47.93663553893566, 71.31325855851173, 1.8703724490478635, 0.08189901665900834, 0.11154797961353324, 0.02583355762908468, 0.046304341303766705, 0.07095480978023261, 0.010005663734773407, 0.04296259503462352, 0.2594023133860901, 0.16795023082522675, 0.21091366448672488, 0.08941329157096334, 0.14719013386638835, 0.09020358236739412, 0.14270048181060702, 0.190151994174812, 1.4177988027222455, 71.79102972149849, 62.02618829905987, 46.94716103374958, 43.53235647082329, 73.60624551773071, 65.84125578403473, 92.54997700452805, 3.9213765179738402, 1.2456534337252378, 0.30449894664343446, 32.83844210207462, 101.45571112632751, 75.16967922449112, 83.50012421607971, 71.73518791794777, 68.9762395620346, 61.80419661104679, 64.68376189470291, 63.496899381279945, 69.12111818790436, 71.4282175898552, 78.53228598833084, 73.56274545192719, 71.34836107492447, 72.11607187986374, 75.32872349023819, 70.70718348026276, 73.67820605635643, 71.37346252799034, 71.98601245880127, 67.92155295610428, 73.21493491530418, 69.5197243988514, 67.14985236525536, 69.65587109327316, 68.6916272342205, 63.669482320547104, 56.95675492286682, 55.359989404678345, 55.73994241654873, 48.452161476016045, 49.18798819184303, 49.331229105591774, 48.932569697499275, 49.54543121159077, 54.87314432859421, 51.81025788187981, 49.864872470498085, 52.969074100255966, 51.69854387640953, 49.77547466754913, 47.354297786951065, 47.38851875066757, 46.58287078142166, 45.1358438283205, 46.238974034786224, 50.31918749213219, 52.56928615272045, 61.246880516409874, 60.909508019685745, 60.873235166072845, 55.472934544086456, 56.15420378744602, 57.170178070664406, 62.104870676994324, 59.63077023625374, 61.84934578835964, 60.30991539359093, 51.94921262562275, 52.513850927352905, 52.672602608799934, 55.41892424225807, 58.09314474463463, 57.16709643602371, 57.71011009812355, 56.23476706445217, 59.55078832805157, 60.25009520351887, 62.59097099304199, 57.53398194909096, 53.54402504861355, 56.84165149927139, 59.37973290681839, 58.6642275005579, 55.016552433371544, 56.56919091939926, 56.09809219837189, 52.861995846033096, 53.433523178100586, 52.78306648135185, 50.00716723501682, 49.78375442326069, 39.738476648926735, 46.31263308227062, 52.05514334142208, 39.24128472805023, 41.37815326452255, 51.05072803795338, 48.81933577358723, 54.12094809114933, 58.368781954050064, 57.094793915748596, 50.24864047765732, 44.696272015571594, 44.68666613101959, 46.50382362306118, 50.14791928231716, 46.59200929105282, 49.21732261776924, 49.516085386276245, 52.81883776187897, 56.20792530477047, 57.94166587293148, 52.87290886044502, 49.38688851892948, 48.29591006040573, 47.100224420428276, 45.89616782963276, 48.389229252934456, 51.268399357795715, 51.66129447519779, 59.57524761557579, 63.57373505830765, 66.32731810212135, 68.83601188659668, 69.85401526093483, 65.93408480286598, 70.3469780087471, 69.4700838625431, 69.03932377696037, 69.11199867725372, 66.60177737474442, 68.84978994727135, 68.89033377170563, 72.08535432815552, 74.3894974887371, 71.3971808552742, 73.73870640993118, 73.61083567142487, 75.19678696990013, 73.49057212471962, 77.39624574780464, 75.71926653385162, 78.41163486242294, 75.30721664428711, 80.38964912295341, 72.75430083274841, 81.62645995616913, 79.43960130214691, 96.0694469511509, 3.5686248214915395, 1.2676106742583215, 84.17795464396477, 79.24882873892784, 66.2319964170456, 53.90390753746033, 54.52363908290863, 63.57217714190483, 83.94954890012741, 2.832300807349384, 0.24716664338484406, 0.30126843717880547, 0.11172757192980498, 0.08962761639850214, 0.2373215794796124, 0.19253658887464553, 0.21543632727116346], [0.053869201001361944, 0.043501423933776096, 0.09094953726162203, 0.0932336451660376, 0.03427019408263732, 0.052981369735789485, 0.09004113366245292, 0.07176251878263429, 0.11967201789957471, 44.7773976624012, 50.38277328014374, 31.264615952968597, 23.72193519026041, 49.466228261590004, 48.41830149292946, 86.04393571615219, 6.193496184423566, 0.7411272532772273, 0.03974630140874069, 37.07017622888088, 86.59423738718033, 72.021624147892, 74.97506886720657, 61.84156760573387, 63.33434410393238, 60.192623287439346, 59.41184498369694, 59.19435225427151, 64.20112699270248, 64.20129418373108, 65.45785635709763, 68.71435761451721, 71.04493215680122, 72.0596145093441, 71.07993587851524, 66.12424939870834, 61.2075412273407, 63.151224330067635, 64.30839523673058, 66.07538402080536, 66.60369247198105, 63.40860731899738, 64.54224988818169, 62.465809509158134, 62.53105200827122, 49.95520882308483, 49.13066826760769, 48.67787316441536, 49.416458532214165, 47.324043810367584, 45.393181219697, 45.89227303862572, 42.89404772222042, 43.79738084971905, 44.517677798867226, 43.718839064240456, 47.17221915721893, 47.784814685583115, 45.99249266088009, 44.21355351805687, 42.7201272547245, 39.82240654528141, 40.4145173728466, 36.386247128248215, 40.5568653345108, 46.106881722807884, 47.71862603724003, 48.55400741100311, 54.44150269031525, 52.484326511621475, 49.233369156718254, 51.92925989627838, 56.87010817229748, 55.5108755081892, 56.016043201088905, 54.222987815737724, 49.66141618788242, 51.43822364509106, 42.23032593727112, 47.209772542119026, 51.06887586414814, 51.66712336242199, 51.69816009700298, 51.22451551258564, 51.88121147453785, 55.082444697618484, 54.74168658256531, 54.305283799767494, 53.421998396515846, 52.51682996749878, 55.29063172638416, 52.97481559216976, 53.38667929172516, 52.15843699872494, 52.12647311389446, 52.34201654791832, 51.298052966594696, 49.32182461023331, 47.72035114467144, 44.79581147432327, 44.28128868341446, 47.7661918848753, 49.4206915050745, 47.8803301602602, 53.82067680358887, 37.67638809978962, 30.000741071999073, 46.09479457139969, 56.398557275533676, 45.90994209051132, 49.379927292466164, 44.851740673184395, 39.30090732872486, 36.4282500743866, 37.872499376535416, 41.503774523735046, 43.33349034190178, 44.86642308533192, 44.21132303774357, 46.01217560470104, 48.47084887325764, 48.42479154467583, 48.193106576800346, 43.751714900135994, 41.24991774559021, 43.78927208483219, 40.472384467720985, 46.20478726923466, 47.30015069246292, 47.45104059576988, 50.85710182785988, 55.859863981604576, 60.92245392501354, 61.23749881982803, 62.39120811223984, 64.2335544526577, 64.64921414852142, 66.52468711137772, 64.77447062730789, 65.32041773200035, 63.14058490097523, 66.97705283761024, 67.31884449720383, 67.59622201323509, 70.28791397809982, 67.29362145066261, 67.64038324356079, 66.8894599378109, 69.97561633586884, 69.43192631006241, 70.11616319417953, 71.20662108063698, 74.77067783474922, 71.38918608427048, 73.06953191757202, 73.09244468808174, 75.18575236201286, 72.05022901296616, 86.09447300434113, 1.9729661126621068, 1.4069721149280667, 70.98484978079796, 61.347176134586334, 47.119835168123245, 40.77476844191551, 25.092451348900795, 44.85185846686363, 60.320820808410645, 0.8334607549477369, 0.11336696130456403, 0.040033920740825124, 0.03781341860303655, 0.022526736829604488, 0.05065516350441612, 0.08165664607076906, 0.08813959546387196, 0.07284776133019477, 0.06118685501860455, 0.048010613027145155, 0.11151456812513061, 0.026589793124003336, 0.0137227437699039, 0.13994628272484988, 0.0729113633860834, 0.2898756688227877, 56.06699466705322, 56.24377638101578, 27.42420382797718, 31.072367168962955, 61.87103882431984, 51.11405923962593, 93.99342074990273, 6.637583104893565, 0.8355770038906485, 0.0714533103746362, 42.054068595170975, 92.59472340345383, 76.31095558404922, 79.90302443504333, 65.15266433358192, 68.12670394778252, 62.33332581818104, 62.31956675648689, 62.7223489433527, 65.72570398449898, 67.21364334225655, 69.7182409465313, 70.43077871203423, 73.47703725099564, 75.0978022813797, 74.85545128583908, 66.9655242562294, 60.6992918998003, 63.93202543258667, 66.92987456917763, 67.70304948091507, 70.27811050415039, 66.75144374370575, 67.62007713317871, 66.56601369380951, 66.0872545838356, 54.24292914569378, 51.211315020918846, 51.163053810596466, 49.26651477813721, 49.61966022849083, 48.10738317668438, 48.94548900425434, 46.337924525141716, 45.10198764503002, 45.208347737789154, 46.96701116859913, 48.18167679011822, 50.23018106818199, 49.14135329425335, 46.11932225525379, 45.45410335063934, 45.22756330668926, 44.101634323596954, 40.026660785079, 42.35077187418938, 48.17980729043484, 51.97327673435211, 53.10383386909962, 55.35713195800781, 53.67942698299885, 53.33436369895935, 54.321679919958115, 57.08960719406605, 59.18361783027649, 60.38696385920048, 54.19497951865196, 52.35448747873306, 54.05064806342125, 44.03171807527542, 49.285198375582695, 54.87068586051464, 52.96134911477566, 53.88628028333187, 54.36810202896595, 54.863143265247345, 56.09758682549, 56.00752405822277, 55.939218923449516, 56.08891949057579, 55.33044598996639, 57.18392953276634, 53.75440835952759, 56.20895504951477, 54.16338421404362, 55.16755633056164, 54.89408120512962, 53.766924887895584, 51.86943590641022, 50.014508441090584, 49.54340972006321, 48.344380259513855, 50.98132476210594, 53.53327162563801, 51.91896244883537, 59.80748735368252, 40.40484309196472, 32.73850366473198, 48.73387075960636, 54.47178706526756, 48.209939673542976, 52.427188977599144, 47.23574034869671, 42.514204904437065, 38.492029532790184, 41.15046568214893, 41.47862747311592, 46.026823818683624, 45.63914202153683, 47.71614857017994, 47.27695673704147, 51.94481626152992, 51.16552747786045, 50.04537798464298, 45.043816566467285, 44.57612246274948, 46.90087951719761, 43.95552076399326, 48.27625371515751, 49.34099078178406, 48.55184532701969, 53.66460397839546, 58.53194899857044, 63.85774701833725, 61.86638407409191, 62.92294017970562, 66.38255953788757, 66.40437796711922, 69.20041233301163, 67.90837526321411, 66.02667063474655, 66.88994631171227, 68.31308394670486, 71.12164244055748, 70.64052745699883, 71.6280184686184, 72.84030541777611, 71.74556136131287, 69.76080626249313, 73.12212869524956, 73.2963265478611, 74.66929167509079, 73.54026585817337, 77.47170969843864, 73.936637789011, 78.1529751420021, 75.95358476042747, 81.4628255367279, 75.6941194832325, 89.47009786963463, 2.2175811929628253, 2.098848964087665, 78.84814023971558, 66.7214785516262, 55.462359711527824, 46.13634914159775, 30.120282657444477, 48.15149500966072, 71.48921191692352, 2.0995022915303707, 0.054161410516826436, 0.05971537655568682, 0.03634836713899858, 0.07430818921420723, 0.016578289614699315, 0.01105810242734151, 0.03520502184983343, 0.22366244054865092, 0.35615162341855466, 0.16020453942473978, 0.3525995562085882, 0.11198941647307947, 0.19240687630372122, 0.18340530776185915, 0.19207797129638493, 0.5949186393991113, 70.0833785533905, 68.73502850532532, 41.88040651381016, 30.595167875289917, 73.59515771269798, 57.13113136589527, 101.22618824243546, 8.189032729715109, 1.4412479382008314, 0.2952212101081386, 43.52802090346813, 95.17376661300659, 77.40690037608147, 82.41368651390076, 66.21796756982803, 69.84218269586563, 65.54876267910004, 64.43606838583946, 63.79938215017319, 69.3311557173729, 70.13480499386787, 72.42044314742088, 73.99089127779007, 77.63443976640701, 77.34046474099159, 75.53114622831345, 66.26070007681847, 63.65267962217331, 66.96279600262642, 66.47212073206902, 69.43280786275864, 73.055449873209, 70.02682998776436, 70.18397435545921, 70.01581057906151, 68.02766606211662, 55.475924983620644, 53.46373915672302, 54.241211637854576, 52.327915504574776, 52.20825992524624, 50.5897481739521, 52.49955229461193, 49.204498305916786, 50.24166025221348, 49.166568741202354, 49.584816098213196, 52.43981949985027, 50.6987377256155, 50.71101866662502, 48.400298058986664, 48.953749760985374, 48.81969295442104, 47.42097660899162, 43.281478732824326, 45.196727961301804, 51.73475593328476, 52.712416872382164, 55.43527476489544, 58.37213717401028, 57.1104870736599, 55.56007906794548, 56.5016533434391, 60.97751297056675, 62.610748931765556, 61.38146169483662, 58.109708055853844, 56.74823731184006, 59.31993171572685, 47.602093890309334, 52.22847864031792, 55.71720823645592, 55.113633424043655, 56.616931557655334, 58.05735066533089, 58.05968374013901, 58.83071556687355, 59.80261221528053, 59.75907415151596, 57.899651527404785, 57.22504712641239, 60.19253969192505, 58.3159913867712, 60.73502138257027, 58.72289255261421, 56.087361574172974, 57.59363494813442, 57.12787874042988, 53.89709450304508, 52.948604598641396, 50.94841852784157, 50.7564490288496, 52.59028382599354, 54.52819503843784, 53.81739757955074, 60.111064463853836, 43.83300393819809, 38.73041354119778, 48.03535424172878, 51.34660296142101, 47.732977867126465, 55.5053848028183, 50.62868468463421, 46.1776377260685, 41.39384262263775, 43.19986671209335, 44.758220091462135, 49.58992302417755, 50.06387539207935, 49.75243270397186, 51.117973029613495, 55.149932876229286, 54.285243675112724, 53.656373620033264, 48.71994070708752, 46.88287228345871, 50.890600830316544, 48.19680757820606, 51.82672239840031, 50.91531090438366, 51.62318632006645, 57.17534959316254, 60.3473661839962, 65.78232854604721, 65.054971575737, 65.33240988850594, 67.8925833106041, 67.47893750667572, 70.68071410059929, 71.63303419947624, 68.8485436141491, 69.76468205451965, 73.08169886469841, 74.45759743452072, 71.1715641617775, 74.82164070010185, 72.01543048024178, 76.22007966041565, 70.18931686878204, 78.29036056995392, 76.40845835208893, 77.59151726961136, 76.08218505978584, 81.5619470179081, 75.03190621733665, 82.663264721632, 78.53612378239632, 84.9012154340744, 78.43055784702301, 93.99210602045059, 3.2327420823276043, 2.1080822311341763, 87.03701242804527, 72.76234120130539, 67.04671069979668, 57.67268590629101, 38.15290153026581, 62.68949590623379, 87.42611154913902, 2.949682683683932, 0.3138983657117933, 0.12927963165566325, 0.12279615533770993, 0.18630412174388766, 0.13199308683397248, 0.14262104232329875, 0.13506591960322112], [0.04298377221857663, 0.10584854520857334, 0.05467051269079093, 0.09691721352282912, 0.047787352741579525, 0.07627615705132484, 0.0977902315207757, 0.02183188251365209, 0.1845082876388915, 34.421611949801445, 49.08619925379753, 59.1090240329504, 43.792095333337784, 49.4973523914814, 48.71372044086456, 80.64579337835312, 16.251397356390953, 0.23745025304378942, 0.16510275861946866, 43.59602205455303, 93.27071473002434, 71.73216328024864, 74.76145952939987, 61.1327688395977, 67.81071290373802, 61.03893667459488, 66.40291884541512, 60.71792230010033, 66.47160395979881, 64.36043724417686, 69.09151017665863, 66.66185215115547, 75.4829952120781, 70.69415777921677, 59.44896899163723, 60.198075994849205, 64.5620696246624, 64.52581956982613, 64.93248894810677, 64.08059746026993, 63.19382004439831, 62.9499339312315, 60.36118984222412, 58.340253084897995, 51.638666689395905, 48.40194717049599, 48.06110925972462, 49.15930353105068, 51.60033814609051, 48.12786027789116, 46.25063180923462, 45.984300300478935, 43.4907753020525, 41.521644964814186, 43.734479025006294, 43.859815299510956, 43.87533746659756, 47.05895483493805, 43.86245235800743, 42.70120806992054, 40.7659263163805, 39.884829595685005, 38.071202114224434, 37.04291649162769, 40.06384938955307, 45.9112948179245, 52.27654606103897, 47.97977842390537, 52.1491426974535, 47.403569743037224, 52.418658435344696, 53.35671789944172, 48.21825362741947, 54.60975006222725, 51.48133993148804, 51.166663616895676, 48.00416551530361, 43.53996366262436, 43.35755065083504, 48.44327375292778, 50.40352776646614, 52.198901027441025, 50.158760100603104, 50.043732672929764, 50.30789449810982, 51.93725846707821, 48.463120087981224, 51.45594969391823, 52.387340515851974, 51.507843509316444, 54.15206842124462, 52.65862315893173, 50.91876871883869, 49.53166835010052, 51.21671073138714, 51.983946561813354, 51.62188678979874, 51.609545052051544, 44.65023748576641, 41.46592475473881, 47.16973789036274, 48.837092220783234, 52.35914222896099, 52.22752869129181, 51.33079580962658, 56.9035729765892, 41.46020986139774, 27.050414085388184, 42.597177252173424, 62.07859508693218, 49.63250733911991, 48.04031677544117, 46.42946541309357, 35.6642060726881, 36.81338980793953, 39.36624102294445, 40.999989956617355, 40.328334197402, 44.11586456000805, 42.806561216712, 45.573899522423744, 47.04731225967407, 45.922876596450806, 41.17326445877552, 43.02262902259827, 40.970336347818375, 41.34764090180397, 46.21983826160431, 46.214697137475014, 47.878069281578064, 50.62502168118954, 58.57596583664417, 60.42495422065258, 63.29809784889221, 59.84079256653786, 64.99595314264297, 64.82324481010437, 61.87749467790127, 66.53974190354347, 66.4609569311142, 64.97709855437279, 65.4705248773098, 66.13213017582893, 69.66749086976051, 64.56341475248337, 67.21461609005928, 64.76266846060753, 69.00694191455841, 71.21219918131828, 72.64106690883636, 71.49138540029526, 73.74547764658928, 72.74578928947449, 73.04019749164581, 75.08318826556206, 72.6608182489872, 76.75493136048317, 72.8539314866066, 80.96012771129608, 0.8949083858169615, 2.514231037348509, 71.8841627240181, 60.498867854475975, 46.39205642044544, 40.63115894794464, 31.731610894203186, 34.152996763587, 63.7951035797596, 2.5373468594625592, 0.054509054752998054, 0.061556199652841315, 0.03172891345457174, 0.037255204806569964, 0.07066480815410614, 0.0771427851577755, 0.06912071054102853, 0.024725920775381383, 0.06371685871272348, 0.06358625556458719, 0.08083663225988857, 0.005913362647333997, 0.02525508876715321, 0.0221444936687476, 0.12842265889048576, 0.22664550313493237, 39.26512844860554, 55.11580690741539, 56.137458086013794, 45.44115364551544, 60.34405656158924, 55.0892349332571, 90.64085304737091, 18.62008385360241, 0.20572626002831385, 0.33263999910559505, 48.23407977819443, 94.27362531423569, 75.96339583396912, 77.69439294934273, 66.3531643152237, 73.18372339010239, 67.22199529409409, 69.27358120679855, 65.48293501138687, 68.68419483304024, 67.05706134438515, 71.4590035378933, 72.37409323453903, 73.68345737457275, 70.39262115955353, 59.49793316423893, 59.262076020240784, 68.76422613859177, 65.79505026340485, 67.83747866749763, 65.94891160726547, 65.69079905748367, 65.53820684552193, 62.1037383377552, 59.43473495543003, 55.015473291277885, 52.72328428924084, 52.49202869832516, 52.06529259681702, 53.2104105502367, 49.34569112956524, 47.364409044384956, 47.32109896838665, 47.09053874015808, 42.94696368277073, 45.604761466383934, 45.49253448843956, 46.349141523242, 48.663137555122375, 45.808981508016586, 45.268468111753464, 43.300154730677605, 40.189634039998055, 41.6345901042223, 38.91406148672104, 41.542293056845665, 50.02660699188709, 54.30927358567715, 50.310189574956894, 53.534666150808334, 51.74795642495155, 53.55850987136364, 55.2408391982317, 53.20453606545925, 57.03312702476978, 54.31633360683918, 52.26575084030628, 50.63340783119202, 48.95927466452122, 47.630770951509476, 51.50765351951122, 53.8470321893692, 53.50485295057297, 55.61718240380287, 54.04329165816307, 53.9904098957777, 52.613040804862976, 51.019136533141136, 53.347761780023575, 54.382134675979614, 55.10125368833542, 57.26328447461128, 53.517730459570885, 52.16135524213314, 51.51743799448013, 51.902877911925316, 55.10699138045311, 53.159649074077606, 52.51420810818672, 48.016267865896225, 43.88673685491085, 50.509982854127884, 49.7234820574522, 54.560706093907356, 56.96619741618633, 54.21976178884506, 59.581323489546776, 44.33444403111935, 31.396835558116436, 45.318686217069626, 55.25372050702572, 50.38502275943756, 51.53334014117718, 51.26413978636265, 37.77285732328892, 40.89554876089096, 39.45058509707451, 42.52027317881584, 42.7282702177763, 46.984596624970436, 45.03411568701267, 48.2124475389719, 48.80460776388645, 48.57239082455635, 43.57775643467903, 45.537531673908234, 44.305090606212616, 45.30291706323624, 48.75513821840286, 49.66980993747711, 48.29673461616039, 51.66255600750446, 61.154328882694244, 64.586251527071, 63.68425972759724, 60.82989849150181, 65.2450829744339, 64.54177111387253, 65.60439169406891, 68.55422660708427, 67.76557892560959, 67.25771337747574, 68.06161344051361, 68.09244498610497, 72.45746836066246, 67.03183829784393, 67.781712859869, 69.41928818821907, 71.701939702034, 75.19386872649193, 75.16241401433945, 76.10131323337555, 76.45288556814194, 76.53993889689445, 77.11955979466438, 78.63166585564613, 76.20959222316742, 80.80084785819054, 76.96980983018875, 83.44310447573662, 1.2449821759946644, 3.3227863255888224, 79.55932527780533, 66.05368718504906, 54.663813561201096, 46.156799644231796, 31.40517421066761, 40.46735733747482, 75.30688226222992, 4.1094638127833605, 0.050631514968699776, 0.11639302392723039, 0.041790677059907466, 0.03333211199787911, 0.04334349119744729, 0.0390387192601338, 0.03209411690477282, 0.2347747512976639, 0.2240329800406471, 0.08382486019399948, 0.201282799243927, 0.16576846508542076, 0.1250942749902606, 0.25589664524886757, 0.2915674092946574, 0.4883083835011348, 55.041961669921875, 62.36771397292614, 78.39064478874207, 57.077197059988976, 68.96870076656342, 60.57657368481159, 97.48023524880409, 20.119394101202488, 0.38922691892366856, 0.6045295705553144, 50.33321253955364, 96.86201602220535, 78.51322621107101, 79.7014832496643, 67.65053629875183, 75.45534789562225, 68.19469749927521, 72.3907819390297, 67.48554155230522, 71.1365756392479, 68.54886129498482, 74.41261544823647, 73.6711536347866, 71.25681638717651, 71.3651941716671, 58.64134892821312, 60.542516112327576, 71.46539479494095, 69.5150962471962, 71.46255254745483, 67.87216320633888, 69.1063217818737, 70.28257146477699, 64.33822363615036, 64.0046015381813, 58.91063667833805, 55.897052586078644, 53.24488990008831, 55.677906945347786, 56.65311701595783, 53.545085191726685, 52.49603368341923, 52.57111005485058, 49.28397864103317, 47.330818846821785, 46.86116024851799, 48.71181674301624, 48.89082133769989, 51.99175514280796, 49.78702984750271, 48.40551517903805, 47.01610453426838, 44.147281274199486, 43.74647498130798, 43.18613804876804, 43.784833922982216, 51.50008052587509, 57.52193279564381, 50.408805683255196, 56.70421287417412, 52.04621002078056, 55.819266960024834, 58.976669535040855, 56.197707653045654, 61.617801412940025, 57.76684485375881, 56.373243033885956, 52.734318897128105, 49.85277011990547, 48.31985257565975, 53.86318892240524, 57.298960760235786, 57.46449127793312, 57.85435035824776, 55.91122202575207, 57.167005240917206, 56.740645319223404, 56.088452115654945, 55.763512551784515, 56.532302498817444, 56.64823427796364, 61.246435940265656, 57.99118101596832, 54.85965505242348, 54.45843458175659, 54.53515246510506, 55.80844894051552, 55.77243447303772, 57.075901329517365, 49.93601605296135, 45.47652214765549, 55.35546764731407, 52.80361197888851, 58.251018673181534, 58.48224766552448, 55.23609325289726, 63.35800163447857, 45.28748609125614, 37.129715234041214, 50.990888848900795, 53.93970921635628, 47.79053337872028, 56.76359988749027, 53.50220449268818, 42.34189935028553, 44.25130069255829, 43.5627206414938, 44.33884799480438, 45.83019956946373, 51.03418752551079, 46.76540918648243, 53.784514144062996, 51.79517649114132, 51.8918851017952, 46.533549427986145, 48.029825538396835, 47.41204708814621, 47.5728240609169, 53.16803142428398, 51.449866220355034, 49.847062826156616, 54.662244245409966, 63.128585144877434, 66.97054758667946, 67.3164202272892, 63.40545728802681, 68.32575246691704, 69.48876366019249, 67.35314145684242, 69.74137410521507, 69.97818499803543, 70.49957022070885, 71.96341887116432, 71.11180856823921, 76.47050142288208, 69.69455301761627, 70.11675596237183, 71.96122258901596, 73.18386778235435, 78.31594839692116, 78.7406288087368, 81.02599337697029, 80.05129247903824, 82.28931918740273, 79.84867215156555, 86.61829769611359, 78.32259804010391, 82.85173460841179, 77.98769921064377, 91.20426401495934, 2.0295751187950373, 3.0910878209397197, 90.81825032830238, 72.02474758028984, 65.51849350333214, 54.50849309563637, 46.88302807509899, 51.09582021832466, 87.15149268507957, 5.883611887693405, 0.25276297121308744, 0.1668465236434713, 0.15736008033854887, 0.233824297611136, 0.18153371522203088, 0.2321505913278088, 0.11401070019928738], [0.0360769822873408, 0.025574889477866236, 0.041850141642498784, 0.09213096214807592, 0.03998531377874315, 0.00667076516947418, 0.12206399696879089, 0.05472900505992584, 0.37720926222391427, 25.166575871407986, 54.65531341731548, 31.65372457355261, 32.67826169729233, 54.759013652801514, 48.85104887187481, 80.45059785246849, 28.633886016905308, 0.14029340003617108, 0.47650710737798363, 52.14189648628235, 86.49308681488037, 72.00999677181244, 77.10926994681358, 65.19665837287903, 70.41838377714157, 69.6489630639553, 71.39579772949219, 68.70490372180939, 68.08934435248375, 66.12801119685173, 67.00983747839928, 74.60993126034737, 122.48419314622879, 65.3998638689518, 61.62365309894085, 65.21102920174599, 66.33285820484161, 64.82512950897217, 63.48929598927498, 58.53889882564545, 58.628953993320465, 57.93510362505913, 55.375177189707756, 55.04685960710049, 54.300002083182335, 48.707017600536346, 46.964693292975426, 51.254165321588516, 46.82353846728802, 45.917404890060425, 46.11293099820614, 43.78772556781769, 42.316512912511826, 42.652152702212334, 43.50490674376488, 42.68847115337849, 44.67824958264828, 42.553274407982826, 45.063590705394745, 41.7917724698782, 41.04723662137985, 36.253185868263245, 34.33587335050106, 34.95320722460747, 43.8563346862793, 48.883981704711914, 51.2170185148716, 52.78934754431248, 50.42892940342426, 43.09232868254185, 47.95970030128956, 52.654131799936295, 52.15105019509792, 50.539704859256744, 49.131701812148094, 46.6230346262455, 48.38748134672642, 48.419095650315285, 44.57675322890282, 48.802346885204315, 50.13010963797569, 50.36920800805092, 48.114857375621796, 49.911427572369576, 50.26380926370621, 46.77444130182266, 46.621849089860916, 50.55782988667488, 52.24848076701164, 50.39959877729416, 52.376723885536194, 47.785776033997536, 50.58064766228199, 49.37256708741188, 48.65136958658695, 48.43807943165302, 50.77360510826111, 48.2819040119648, 48.56868602335453, 41.212645545601845, 44.64288108050823, 48.061185255646706, 49.603929072618484, 52.48581983149052, 52.527872174978256, 49.76905681192875, 55.83929568529129, 48.41436490416527, 33.00330005586147, 33.08903105556965, 50.99467724561691, 47.99099162220955, 50.22823177278042, 41.87465362250805, 36.136494129896164, 38.23811195790768, 37.563705146312714, 38.53422246873379, 43.14703814685345, 41.60407014191151, 43.80250297486782, 44.503192976117134, 42.066889107227325, 42.88231395184994, 41.37955538928509, 42.05765180289745, 43.70454803109169, 46.21707580983639, 46.43368698656559, 45.63364751636982, 50.10861799120903, 60.75637623667717, 60.965745002031326, 59.53278109431267, 59.47657071053982, 61.30394205451012, 70.36261036992073, 71.69426411390305, 63.905601650476456, 63.4104236215353, 61.81228257715702, 63.00334006547928, 65.01695081591606, 65.77199310064316, 67.23416224122047, 69.30862292647362, 64.08206418156624, 66.28082379698753, 66.34131655097008, 67.61654332280159, 68.80366042256355, 69.92586940526962, 68.50815787911415, 70.95968753099442, 70.65780133008957, 75.47044068574905, 73.66552993655205, 80.87269440293312, 60.83656333386898, 1.0521593852899969, 4.988019894808531, 70.67076623439789, 54.599729999899864, 38.44422049820423, 44.85476151108742, 28.31457395106554, 41.43857382237911, 58.05293530225754, 2.2955299727618694, 0.06625540452660061, 0.0676877198566217, 0.03376986409421079, 0.014140764014882734, 0.06712454109219834, 0.04428196290973574, 0.011445032250776421, 0.060354013185133226, 0.0884887611027807, 0.06324834830593318, 0.039562842503073625, 0.0417521150666289, 0.11895627583726309, 0.09037604264449328, 0.02701158718991792, 0.23728738131467253, 34.24611836671829, 64.7005569934845, 31.219939850270748, 31.958652511239052, 62.72780925035477, 57.779695764184, 90.63199192285538, 31.6659789159894, 0.152674590353854, 0.8989076712168753, 58.15258115530014, 88.83084297180176, 77.35500276088715, 81.09910905361176, 67.93812766671181, 75.18603354692459, 72.028828561306, 72.00887203216553, 72.30157792568207, 71.972576379776, 70.06857454776764, 70.78488931059837, 74.91471290588379, 106.03316590189934, 66.89575240015984, 66.62983506917953, 69.60740089416504, 69.91146057844162, 68.11925634741783, 66.39292538166046, 62.571071460843086, 62.732224613428116, 59.98504042625427, 57.38806217908859, 57.52388209104538, 56.86107225716114, 51.58879816532135, 50.5158269405365, 51.52394324541092, 49.68064695596695, 47.702811285853386, 49.338707104325294, 43.887717202305794, 43.033184856176376, 46.07773348689079, 46.63690388202667, 46.30899667739868, 47.11301073431969, 43.65650720894337, 46.72901473939419, 45.01735098659992, 43.0367186665535, 39.4515198469162, 38.36917072534561, 36.64839506149292, 48.48577827215195, 53.960338309407234, 54.01663988828659, 56.841841489076614, 54.38856393098831, 44.23069819808006, 52.57631577551365, 53.98375645279884, 53.46755415201187, 54.585298374295235, 50.07164977490902, 49.90317441523075, 50.09971886873245, 49.998507499694824, 46.76062524318695, 51.23463436961174, 50.71112886071205, 51.73066735267639, 52.1915902197361, 52.00050227344036, 52.33360379934311, 49.32815507054329, 49.7470597922802, 51.40471324324608, 55.84315247833729, 53.834713250398636, 55.781417191028595, 48.92473451793194, 50.676676109433174, 52.023460641503334, 50.83306811749935, 50.46385332942009, 53.603294268250465, 49.53104518353939, 51.27146199345589, 43.867335096001625, 45.906754061579704, 49.820145070552826, 52.81879596412182, 54.96959075331688, 54.034677520394325, 53.568624928593636, 57.683298736810684, 51.50753192603588, 38.374026864767075, 32.62614369392395, 46.147718131542206, 51.80745743215084, 53.59193667769432, 45.06824925541878, 39.014250710606575, 40.01461923122406, 40.66512152552605, 41.34023889899254, 45.97494900226593, 44.28558625280857, 45.788743793964386, 46.779476031661034, 44.2269553989172, 42.97738865017891, 43.9974021166563, 43.80945660173893, 45.08170433342457, 49.495410695672035, 47.700250223279, 47.42630012333393, 51.06298618018627, 61.82990983128548, 62.662258967757225, 62.53202475607395, 59.99816112220287, 62.45003655552864, 70.37301421165466, 72.22379609942436, 67.92216092348099, 66.64683535695076, 65.57429730892181, 65.74616968631744, 67.20312550663948, 67.51601591706276, 70.06317883729935, 69.98257756233215, 66.80862307548523, 71.21387869119644, 69.13235038518906, 71.45209550857544, 70.50850734114647, 72.6704241335392, 73.25570672750473, 75.23245945572853, 74.91020634770393, 81.05898320674896, 77.40310817956924, 84.92716044187546, 62.003932893276215, 1.1399807478301227, 6.038332460448146, 78.08071061968803, 59.49673242866993, 43.949965462088585, 51.49081662297249, 33.891802579164505, 46.52898587286472, 69.09462600946426, 2.881908332929015, 0.1576617782120593, 0.08941282401792705, 0.07034247857518494, 0.02800538786686957, 0.07359843628364615, 0.04164101184869651, 0.03519221980241127, 0.17684021004242823, 0.23027797462418675, 0.12284371958230622, 0.1867726692580618, 0.26282227830961347, 0.23001469031441957, 0.14398818224435672, 0.2823594940127805, 0.511797268409282, 43.462869599461555, 75.04450634121895, 42.77361698448658, 43.86672332882881, 74.20785203576088, 62.57020130753517, 96.06029704213142, 34.27421025931835, 0.2855926752090454, 1.3782178703695536, 57.96124242246151, 92.25215658545494, 77.69535809755325, 82.15060383081436, 70.32698348164558, 78.33937793970108, 75.03196701407433, 76.43628045916557, 73.88366863131523, 73.04571479558945, 71.22258022427559, 73.50476816296577, 75.70747196674347, 105.49071460962296, 68.66679936647415, 67.87014931440353, 71.70493394136429, 72.46622309088707, 69.73358452320099, 70.12027457356453, 63.364001512527466, 63.76683309674263, 63.78564968705177, 59.15969431400299, 61.0199148952961, 58.65361467003822, 52.38368511199951, 53.679749965667725, 54.96883079409599, 52.016009241342545, 51.10061556100845, 52.0482163131237, 47.68503203988075, 46.26229718327522, 48.828508481383324, 48.95057313144207, 46.973140239715576, 48.77384841442108, 48.343016132712364, 49.598157182335854, 47.050264701247215, 46.69192872941494, 42.8707055747509, 39.943236261606216, 40.41936591267586, 50.98717264831066, 55.454547330737114, 57.2254803031683, 59.02257867157459, 56.9009131193161, 46.32234916090965, 52.942456528544426, 57.2395433485508, 58.438508212566376, 57.18825750052929, 54.74055424332619, 51.963298469781876, 52.96452194452286, 52.69242234528065, 49.381325617432594, 53.30546244978905, 55.535600781440735, 57.53913067281246, 55.672708824276924, 54.49701391160488, 54.73527252674103, 53.81465792655945, 52.18221992254257, 54.312495812773705, 58.05811062455177, 55.92943824827671, 57.65234559774399, 51.46991394460201, 54.22829233109951, 54.5094658434391, 54.20954793691635, 53.48948657512665, 55.74741281569004, 53.0505645275116, 54.23669368028641, 47.37863548099995, 50.191578939557076, 53.17827567458153, 54.67808559536934, 57.93590918183327, 58.856709972023964, 55.32838650047779, 61.38857491314411, 51.07877813279629, 41.895537301898, 43.51631373167038, 54.17479880154133, 53.367931097745895, 57.52406448125839, 46.88025042414665, 42.654375582933426, 44.996885284781456, 43.916968032717705, 42.927117347717285, 48.59262473881245, 46.547715067863464, 48.73422034084797, 49.370625391602516, 46.63022764027119, 48.08288209140301, 45.99151611328125, 47.01298110187054, 48.49455960094929, 52.04901807010174, 50.18892668187618, 50.8829290419817, 54.429651126265526, 64.80085641145706, 64.00153130292892, 63.17779630422592, 61.9071064889431, 65.29318079352379, 68.07448714971542, 70.80487623810768, 68.50186541676521, 67.26866438984871, 67.02217161655426, 68.30509677529335, 72.26681739091873, 69.46835115551949, 71.68843522667885, 75.01356080174446, 69.43785399198532, 70.86163759231567, 71.51115953922272, 71.6323958337307, 72.33560130000114, 74.59559082984924, 73.97535011172295, 77.47661903500557, 81.04140534996986, 81.77434042096138, 81.5965935587883, 84.89005923271179, 75.11862516403198, 1.1741535016335547, 6.180730294436216, 93.03085640072823, 67.01536238193512, 55.42420215904713, 62.7969541400671, 42.421866059303284, 53.54523718357086, 82.96616926789284, 4.631365332752466, 0.2613042003940791, 0.3203429386485368, 0.18437574006384239, 0.09217484534019604, 0.1618016412248835, 0.18547809653682634, 0.1395385616342537], [0.05280174773361068, 0.015048355890030507, 0.08133335169986822, 0.046339745458681136, 0.10168973516556434, 0.08603377369581722, 0.12872875027824193, 0.12390542862704024, 0.5161796801257879, 33.62070992588997, 53.25329504907131, 49.22125540673733, 45.776633843779564, 48.86456474661827, 45.03614857792854, 77.917410582304, 41.348716244101524, 0.07748607298708521, 0.5108290328644216, 57.20538318157196, 87.34614863991737, 72.45226263999939, 74.3631649017334, 71.31452769041061, 72.53797084093094, 69.56016942858696, 69.640983492136, 70.15585586428642, 70.5634143948555, 69.8688192665577, 68.09352412819862, 70.15742897987366, 77.96816825866699, 60.134414210915565, 70.57409942150116, 64.86055120825768, 64.4295859336853, 62.81080059707165, 57.98086076974869, 56.63881078362465, 60.048489421606064, 56.756140887737274, 55.61010718345642, 56.12818278372288, 56.57513380050659, 52.38716572523117, 47.16333143413067, 46.51698611676693, 48.72947059571743, 46.68230764567852, 44.89096976816654, 43.585622012615204, 43.3821277320385, 42.44845703244209, 43.57049122452736, 41.95273943245411, 41.82405933737755, 41.36913254857063, 41.811364218592644, 40.692654848098755, 37.23338887095451, 35.05844637751579, 37.005993872880936, 36.04428447782993, 47.03427515923977, 48.63875426352024, 49.794933423399925, 48.11527535319328, 50.59635981917381, 48.2543782889843, 49.53099198639393, 49.48532983660698, 47.57869094610214, 48.47432188689709, 44.085572585463524, 46.16461202502251, 50.25887332856655, 48.31120803952217, 46.18971347808838, 45.117399618029594, 43.326798900961876, 44.90995354950428, 46.3474278151989, 46.32340170443058, 48.582521080970764, 45.4675318300724, 46.860556080937386, 46.10771767795086, 52.63288713991642, 52.42202125489712, 49.281090795993805, 45.42255364358425, 45.53172558546066, 45.608124285936356, 49.299527406692505, 45.60961380600929, 46.55081570148468, 46.13589696586132, 47.281664684414864, 42.27555871009827, 42.86928825080395, 48.599080592393875, 48.64725060760975, 48.45760278403759, 48.548642098903656, 51.53611399233341, 48.50616417825222, 51.15509703755379, 50.08608140051365, 36.11389294266701, 34.16134111583233, 48.693687915802, 48.483015820384026, 48.252504989504814, 37.999583557248116, 35.894504114985466, 37.45097279548645, 40.15654921531677, 42.2246490418911, 44.8226760327816, 43.24302859604359, 42.35948860645294, 41.125478222966194, 43.37407596409321, 41.55620411038399, 41.020672246813774, 41.75729312002659, 46.21510751545429, 45.47581158578396, 44.774350225925446, 52.67342336475849, 62.18975432217121, 59.82017107307911, 63.37144911289215, 56.77272319793701, 63.0829343944788, 74.8970590531826, 70.48364907503128, 64.87242937088013, 63.049959763884544, 63.25548693537712, 60.12993425130844, 59.87269565463066, 62.95465707778931, 65.09413987398148, 72.37005785107613, 70.54279670119286, 72.27044999599457, 71.31973341107368, 73.02781015634537, 71.4771057665348, 75.68156495690346, 73.74882906675339, 74.6096120774746, 71.25028073787689, 79.37681347131729, 70.91768458485603, 79.61300879716873, 30.253171026706696, 1.5327655524015427, 7.931834505870938, 72.14154571294785, 47.07072280347347, 40.893306881189346, 37.30491243302822, 31.951869875192642, 47.948293313384056, 53.819954842329025, 2.033716421574354, 0.21280192566337064, 0.14655579056125134, 0.1361361559247598, 0.06508089645649306, 0.005580707938861451, 0.1276241525192745, 0.06609387608477846, 0.008206072507164208, 0.03675893436593469, 0.06757737734005786, 0.01367922144709155, 0.022527076362166554, 0.05607849670923315, 0.0043720058783947024, 0.21909462549956515, 0.47830286726821214, 38.6654332280159, 63.01374010741711, 51.646855250000954, 59.08914349973202, 60.34801594913006, 47.381420731544495, 86.6257756948471, 46.80168204009533, 0.09886317668133415, 0.6314214400481433, 60.61222717165947, 90.127964168787, 77.86368146538734, 76.54176279902458, 73.10435324907303, 77.96596437692642, 72.32366234064102, 72.27200031280518, 74.48108777403831, 74.95916292071342, 71.1930938065052, 72.48722836375237, 70.40060833096504, 78.4040504693985, 64.10141274333, 71.04170233011246, 67.92447879910469, 67.33769908547401, 64.87289294600487, 60.937189534306526, 60.60608670115471, 60.42367748916149, 60.59146128594875, 55.308213382959366, 58.59953977167606, 58.61239068210125, 55.94364948570728, 50.02434231340885, 49.691396579146385, 50.785582065582275, 49.88523177802563, 47.08711892366409, 45.60938961803913, 45.22846005856991, 44.988438338041306, 45.2972249686718, 45.66387489438057, 44.39522556960583, 44.43602778017521, 44.865305945277214, 44.00718279182911, 39.7478811442852, 39.22954335808754, 38.60055170953274, 39.071430042386055, 49.96440812945366, 51.39549873769283, 53.296730518341064, 51.690803691744804, 50.866171941161156, 49.06766764819622, 51.98506750166416, 52.46447637677193, 49.08494532108307, 48.62614654004574, 45.35789251327515, 48.82785111665726, 52.47870281338692, 50.48602133989334, 48.16789112985134, 46.17097668349743, 45.75687490403652, 47.15179905295372, 50.10673329234123, 49.18626308441162, 52.50465162098408, 48.26588787138462, 48.187395483255386, 49.75538894534111, 54.78289537131786, 54.457648023962975, 52.24845416843891, 48.9395347237587, 47.279221415519714, 48.429172709584236, 49.97823938727379, 47.0197219401598, 47.50878229737282, 48.1333813816309, 47.791228741407394, 45.71771040558815, 45.664908438920975, 49.59482856094837, 51.78834065794945, 50.35106398165226, 50.21618261933327, 52.80704699456692, 51.33912116289139, 52.13039070367813, 51.518152356147766, 40.7858220487833, 37.45525136590004, 50.164531990885735, 51.45471476018429, 52.09784924983978, 42.3595380038023, 39.07958060503006, 39.392056837677956, 41.990045830607414, 44.230717197060585, 46.58029831945896, 45.7864411175251, 44.38537649810314, 43.360780477523804, 44.52656552195549, 45.2831657230854, 43.64315092563629, 43.846120834350586, 48.46583694219589, 48.07187408208847, 45.93081057071686, 54.51701603829861, 63.364936262369156, 61.74346446990967, 64.43443447351456, 60.39434686303139, 63.216010853648186, 75.81347107887268, 74.60575148463249, 65.46914175152779, 66.56913712620735, 63.396132588386536, 66.04259938001633, 61.90197296440601, 66.45900383591652, 66.71688839793205, 75.25613218545914, 72.865080088377, 73.19176375865936, 73.30399453639984, 75.83830654621124, 75.58079436421394, 78.81809145212173, 75.4607892036438, 79.69370126724243, 75.31146481633186, 79.56304907798767, 74.6844832599163, 81.25636741518974, 28.098671436309814, 1.138840690255165, 9.093820229172707, 80.35247951745987, 52.838900685310364, 49.06969293951988, 45.97943276166916, 38.02354887127876, 54.58087161183357, 62.87754401564598, 2.5682684127241373, 0.2605962805682793, 0.21907812013523653, 0.12250422412762418, 0.0671779311960563, 0.0447122823970858, 0.056365362761425786, 0.04593438810843509, 0.18006659316597506, 0.10466923544299789, 0.15217444219160825, 0.24105349875753745, 0.2342825144296512, 0.31691932235844433, 0.2423247680417262, 0.29587192519102246, 0.486856356728822, 49.829275980591774, 73.80772590637207, 65.39148151874542, 60.55420808494091, 68.9572025835514, 53.955820351839066, 92.65473738312721, 49.34965431690216, 0.13379981566686183, 0.904629451688379, 65.56646212935448, 93.22037503123283, 79.47509899735451, 80.73812082409859, 76.05788916349411, 78.72310414910316, 74.40953001379967, 76.19375467300415, 76.52801513671875, 75.7861353456974, 72.99878731369972, 73.56628686189651, 73.00890237092972, 89.47537958621979, 64.48434859514236, 75.10181486606598, 71.07182711362839, 72.20130890607834, 69.2050252854824, 64.5524637401104, 63.36055509746075, 62.280432656407356, 62.46261388063431, 60.54509997367859, 61.680133268237114, 60.456291139125824, 58.082277327775955, 51.65826603770256, 52.071585059165955, 54.32282745838165, 51.427246034145355, 49.661366790533066, 47.34346076846123, 49.99200224876404, 49.11460652947426, 49.635649770498276, 46.81800216436386, 45.23919828236103, 49.065801948308945, 47.977183163166046, 46.874961107969284, 43.04459944367409, 41.57375916838646, 42.546704560518265, 42.532067745923996, 53.2682928442955, 53.94002079963684, 56.73007428646088, 54.54198069870472, 53.604605197906494, 52.40551494061947, 55.494714975357056, 56.9158311188221, 51.452362686395645, 53.79468999803066, 51.3477049022913, 51.60726137459278, 53.81250724196434, 53.79568554461002, 50.4912156611681, 49.538971558213234, 48.895096108317375, 51.04024440050125, 52.99799434840679, 54.09370735287666, 54.683751091361046, 53.29700030386448, 50.86670011281967, 51.89675644040108, 58.32006856799126, 55.32948084175587, 54.5437666028738, 51.88363194465637, 50.48580475151539, 49.618626683950424, 52.0169971883297, 48.91711212694645, 50.8865350484848, 52.04016074538231, 51.53938941657543, 45.88370829820633, 47.837088480591774, 53.542744517326355, 55.56744307279587, 53.45443345606327, 55.70969603955746, 56.975392922759056, 55.470643267035484, 57.39263333380222, 54.52096402645111, 42.5470807403326, 42.302381470799446, 51.52937315404415, 54.36271011829376, 53.189842253923416, 44.560740888118744, 40.850300788879395, 43.591686487197876, 46.46638423204422, 48.38564604520798, 49.35639135539532, 48.689139559865, 45.50848603248596, 46.42448008060455, 47.05936141312122, 47.73202031850815, 46.10966697335243, 46.7305688560009, 51.908159628510475, 50.94410955905914, 48.912563771009445, 57.4707305431366, 67.15718597173691, 63.4345181286335, 68.37299913167953, 62.079909816384315, 65.39459735155106, 77.79808178544044, 76.04986399412155, 67.03199788928032, 69.49461534619331, 68.44615280628204, 66.9482883810997, 64.12427231669426, 68.52767363190651, 67.5552450120449, 77.4813611805439, 73.34620267152786, 75.65120458602905, 73.22930574417114, 77.75158748030663, 76.28773123025894, 81.10965728759766, 77.63757839798927, 81.55156597495079, 78.54858711361885, 83.90857189893723, 77.26022824645042, 83.18228647112846, 41.749959513545036, 1.1257885093800724, 9.853480216115713, 92.83253744244576, 57.61322669684887, 61.73975586891174, 52.413513511419296, 43.728064969182014, 68.25400471687317, 72.87183612585068, 3.6780945723876357, 0.3253042552387342, 0.3203336469596252, 0.23681530117755756, 0.12561538140289485, 0.10746668689535, 0.28402267664205283, 0.14929646771633998], [0.05960409151157364, 0.05980274589092005, 0.04565155191812664, 0.14056285901460797, 0.06906838912982494, 0.08223519471357577, 0.09359429925098084, 0.12997251556953415, 0.6189031898975372, 18.34519900381565, 55.77903471887112, 31.69605240225792, 21.639728620648384, 41.57680280506611, 48.71174834668636, 73.02958086133003, 55.1276508718729, 0.06975175128900446, 0.1856033710646443, 52.738297283649445, 86.24102354049683, 72.12762326002121, 74.16635066270828, 68.83170291781425, 72.28336930274963, 72.1903046965599, 72.14569509029388, 69.37754362821579, 70.84178745746613, 68.67331221699715, 66.32949158549309, 58.15389968454838, 39.449570551514626, 63.148446679115295, 69.74947527050972, 63.699394315481186, 61.69707275927067, 55.15785925090313, 56.2396802008152, 57.50302121043205, 60.30891224741936, 57.857409194111824, 60.14330193400383, 59.37974810600281, 58.6151759326458, 55.497355833649635, 47.65340633690357, 47.027127742767334, 48.92518289387226, 47.08174601197243, 46.29432566463947, 45.18539696931839, 43.165045380592346, 43.17785829305649, 41.77099138498306, 41.39719404280186, 39.90055315196514, 41.408958211541176, 41.555789932608604, 40.46980060636997, 39.39102329313755, 36.35091282427311, 34.73888732492924, 38.31883102655411, 44.029681384563446, 47.5736828148365, 47.798311561346054, 48.851953223347664, 47.387663796544075, 47.080457881093025, 43.156039863824844, 42.14974366128445, 45.53209036588669, 46.41369245946407, 45.76362334191799, 48.01481634378433, 49.80930805206299, 49.67634178698063, 48.58533293008804, 43.00532475113869, 43.628628104925156, 44.871780797839165, 45.01961566507816, 45.03090865910053, 44.300321862101555, 43.269292786717415, 46.52966223657131, 41.74979992210865, 50.48950955271721, 51.61498636007309, 47.19855174422264, 45.73680818080902, 44.78783190250397, 44.81391750276089, 46.678872630000114, 43.328383415937424, 42.85521760582924, 41.55967712402344, 43.00398342311382, 41.65916718542576, 45.438068211078644, 48.039420023560524, 44.92102235555649, 43.96827667951584, 45.69086864590645, 45.60196861624718, 46.490528136491776, 48.016328662633896, 46.180088594555855, 51.8636754155159, 46.80333875119686, 46.55502587556839, 46.98662951588631, 49.129490330815315, 41.456360667943954, 35.38145184516907, 34.87549379467964, 37.78076469898224, 40.71624778211117, 43.455228209495544, 43.87830130755901, 41.773290261626244, 42.131048664450645, 42.72022984921932, 41.37291334569454, 41.48708961904049, 43.39595139026642, 43.78129631280899, 46.32418446242809, 44.15892004966736, 49.48153004050255, 60.27565263211727, 59.89240139722824, 57.72123210132122, 59.5975486189127, 61.828724294900894, 57.62264259159565, 56.88484378159046, 67.55874082446098, 68.10453593730927, 65.64514070749283, 62.17766337096691, 63.11185084283352, 62.86326818168163, 65.79720854759216, 63.3450785279274, 65.73899567127228, 69.42452430725098, 69.7209008038044, 68.73192027211189, 69.8160932958126, 73.2181191444397, 71.70437157154083, 71.77940994501114, 73.12203750014305, 72.31714949011803, 75.16870647668839, 76.95268034934998, 10.454395171254873, 0.9335320664104074, 11.96767346933484, 72.15373545885086, 47.10518315434456, 41.657829657197, 38.02183896303177, 30.80642133951187, 37.588035240769386, 59.06783044338226, 1.2874010810628533, 0.10785043661599047, 0.05080357819679193, 0.028474868631747086, 0.09703462870675139, 0.07037082119495608, 0.05048018734669313, 0.04681880549469497, 0.02239278288470814, 0.004841573381781927, 0.030879258265485987, 0.05112733269925229, 0.04087338253157213, 0.08667435846291482, 0.06615091755520552, 0.13893623457988724, 0.6517788476776332, 23.765997625887394, 65.45197427272797, 36.06622450053692, 31.63434561342001, 52.49279625713825, 50.930194705724716, 81.72682017087936, 61.057962253689766, 0.2655277628218755, 0.04470905405469239, 56.12090617418289, 89.7261281311512, 75.70649921894073, 77.71804288029671, 71.91697776317596, 75.66807568073273, 73.18566888570786, 73.7132477760315, 72.6792624592781, 74.1771724820137, 70.80321192741394, 69.13628697395325, 59.92580160498619, 47.48747684061527, 64.45507496595383, 72.75295570492744, 65.50409227609634, 64.06203165650368, 59.62281346321106, 58.09759050607681, 59.157399237155914, 62.49102495610714, 62.96287603676319, 62.010438144207, 62.12713748216629, 60.97595125436783, 58.916127383708954, 53.13284531235695, 49.925619810819626, 50.4292181879282, 49.98633295297623, 48.029396161437035, 45.7990488409996, 45.34898579120636, 45.17232947051525, 43.35299849510193, 44.38535749912262, 43.7455478310585, 44.423591047525406, 43.33939902484417, 43.41787241399288, 42.497801184654236, 38.524985164403915, 38.15517000854015, 41.65958136320114, 46.6400159150362, 48.449615612626076, 49.70491625368595, 50.43428711593151, 50.75455293059349, 48.70563447475433, 46.10246255993843, 45.172796845436096, 45.580074191093445, 46.75250127911568, 47.77109742164612, 49.88913416862488, 52.40798860788345, 51.738335341215134, 49.32703413069248, 45.29583044350147, 44.8995079100132, 48.473360538482666, 47.3812535405159, 46.90527208149433, 46.72218270599842, 45.824511274695396, 50.036805644631386, 45.69774627685547, 52.13655397295952, 54.561853632330894, 47.91563406586647, 48.4973980486393, 47.499313205480576, 47.33447425067425, 48.53414207696915, 46.63305848836899, 45.63580200076103, 45.00320054590702, 46.141304075717926, 44.43843685090542, 48.05405683815479, 49.43961828947067, 46.12399220466614, 44.27406147122383, 50.864275842905045, 47.56399713456631, 47.93830744922161, 50.45889459550381, 45.914927423000336, 52.99157649278641, 50.594706907868385, 49.230025336146355, 50.329948514699936, 50.61389587819576, 43.37204687297344, 36.909479051828384, 38.44430789351463, 40.670452639460564, 43.37607465684414, 44.47528347373009, 45.08399561047554, 43.71902525424957, 44.360237047076225, 44.53387252986431, 43.95894058048725, 42.301154136657715, 46.99441149830818, 47.749647572636604, 48.27494278550148, 46.603317484259605, 50.87951302528381, 64.59207281470299, 63.17827507853508, 61.357861161231995, 60.92973053455353, 65.06525382399559, 59.32980738580227, 58.69673475623131, 69.75488618016243, 70.66204190254211, 68.5835762321949, 65.72799906134605, 65.20852893590927, 65.28346851468086, 68.11282709240913, 70.18487110733986, 68.20516213774681, 70.4082003235817, 72.22187340259552, 70.6878425180912, 74.14891719818115, 76.62927210330963, 75.61376139521599, 75.22597700357437, 75.12221217155457, 74.116892516613, 77.86220714449883, 79.35170441865921, 11.073210015892982, 0.9335403784643859, 14.328923765569925, 82.27537393569946, 54.898010194301605, 49.51918601989746, 48.76564085483551, 33.92321169376373, 44.592058807611465, 69.54684734344482, 1.7473744740709662, 0.08375851961318403, 0.023087878398655448, 0.044607053278014064, 0.02847357729478972, 0.045870763788116165, 0.10117923404322937, 0.025419129378860816, 0.18741821899311617, 0.1812700301525183, 0.13056400726782158, 0.2632677153451368, 0.17030491697369143, 0.19492948078550398, 0.10590447345748544, 0.40925852372311056, 0.8556064416188747, 31.378571838140488, 78.82119968533516, 43.65842230618, 27.756695486605167, 58.965125754475594, 63.0631260573864, 84.5209090411663, 66.11367836594582, 0.35375496139749885, 0.6290334463119507, 58.83978947997093, 93.69110137224197, 78.73981565237045, 78.18541780114174, 74.1953507065773, 79.0011428296566, 75.45369118452072, 77.05493286252022, 76.97933211922646, 74.75518226623535, 74.38193589448929, 71.47648259997368, 61.33348926901817, 53.1171103566885, 65.80936029553413, 74.97745513916016, 68.66185203194618, 68.85517045855522, 62.169999182224274, 60.09758658707142, 62.63890162110329, 66.28257930278778, 62.26171866059303, 64.23823580145836, 65.76562464237213, 62.75249272584915, 61.83094337582588, 55.936927646398544, 51.621799394488335, 56.44206874072552, 52.4554480612278, 50.891486182808876, 50.91035217046738, 50.56450612843037, 49.00223135948181, 45.68863056600094, 46.74822270870209, 47.08576239645481, 48.97814065217972, 48.14680986106396, 47.25560948252678, 46.512616351246834, 42.18484237790108, 40.57056359946728, 43.974971920251846, 49.79365289211273, 50.67041404545307, 52.88857541978359, 52.835359275341034, 54.43919621407986, 51.844661235809326, 47.3616997897625, 49.67559702694416, 48.378278240561485, 51.85536906123161, 50.44663265347481, 52.73852527141571, 53.97462174296379, 55.5839341878891, 53.47372122108936, 47.565452456474304, 48.20759899914265, 51.8963498622179, 50.79129695892334, 51.45488955080509, 50.812112241983414, 48.32877069711685, 54.21976558864117, 50.02347595989704, 55.867281183600426, 56.131746992468834, 51.639225259423256, 51.42774760723114, 50.79719424247742, 51.999012753367424, 51.029528975486755, 48.630877286195755, 46.737381890416145, 46.84258684515953, 50.579177141189575, 45.96869073808193, 50.457709059119225, 53.78158450126648, 50.35736404359341, 49.49767917394638, 53.15092854201794, 49.82421465218067, 51.437125504016876, 53.38247671723366, 49.804432913661, 56.42588160932064, 51.04197330772877, 51.25413492321968, 52.8184349834919, 54.43418808281422, 45.75084462761879, 40.14063946902752, 40.24579502642155, 42.782607302069664, 44.49245095252991, 47.743123322725296, 48.04769217967987, 46.58660598099232, 46.74269400537014, 47.227187007665634, 46.31099537014961, 44.79098953306675, 49.22606214880943, 49.451652243733406, 50.80113843083382, 47.806260734796524, 53.00746724009514, 66.22862219810486, 64.87765029072762, 65.13209223747253, 62.51674957573414, 68.81419345736504, 65.97934797406197, 60.82009121775627, 69.90137591958046, 69.29710194468498, 69.27314803004265, 69.13570180535316, 69.11436975002289, 68.895623087883, 73.2997539639473, 73.35212275385857, 69.9132464826107, 74.67558413743973, 74.48730424046516, 73.63554194569588, 75.31825885176659, 80.9585165977478, 78.01698043942451, 78.93110498785973, 77.26205214858055, 79.01517927646637, 80.30473127961159, 83.54285672307014, 16.529278345406055, 1.1121090059168637, 15.363015476614237, 92.94821083545685, 60.119253024458885, 62.84577012062073, 54.558768197894096, 43.179484605789185, 53.32632713019848, 80.79668328166008, 2.654507872648537, 0.15366937994258478, 0.1558437242056243, 0.13941310899099335, 0.1560548652196303, 0.13527639268431813, 0.24108711804728955, 0.10097422316903248], [0.05837279430124909, 0.15872741321800277, 0.037174243916524574, 0.038317021462717094, 0.041455549144302495, 0.11743211973225698, 0.08753092304687016, 0.21864163340069354, 0.6627579429186881, 18.76269020140171, 51.49412244558334, 39.72831219434738, 34.652362167835236, 34.82465632259846, 42.47171178460121, 57.38204710185528, 68.8481180369854, 1.256636269390583, 0.131505451281555, 41.193008199334145, 88.41614082455635, 70.40685519576073, 74.66789335012436, 68.46906557679176, 71.48266106843948, 70.02923145890236, 70.75873911380768, 69.59683746099472, 70.91295763850212, 62.87613429129124, 60.42474143207073, 63.21466572582722, 58.07424075901508, 69.58753556013107, 67.82440736889839, 58.99927832186222, 57.806936502456665, 58.553965017199516, 56.94192051887512, 60.96403509378433, 62.84510515630245, 60.689435228705406, 59.53235171735287, 61.93095400929451, 59.05384719371796, 59.38175819814205, 52.53474600613117, 46.06030762195587, 48.41500326991081, 47.18960702419281, 42.96800695359707, 44.97937582433224, 43.08340676128864, 42.19757169485092, 43.10252733528614, 42.43118315935135, 44.15427669882774, 42.03480362892151, 41.15945979952812, 39.96771454811096, 39.66762185096741, 41.080074459314346, 37.25154809653759, 42.52607546746731, 44.659288600087166, 45.33236548304558, 46.9112491607666, 41.92766837775707, 41.36213332414627, 40.155701860785484, 41.04171931743622, 41.217687875032425, 42.56315767765045, 44.0212382376194, 44.94368813931942, 48.487499579787254, 52.977262660861015, 49.78174053132534, 50.735211968421936, 45.27575232088566, 44.65506702661514, 42.536578103899956, 43.12194809317589, 41.22117228806019, 44.64321546256542, 43.5050131380558, 44.74636472761631, 42.093050703406334, 46.69004783034325, 49.35235217213631, 43.76465320587158, 47.293018475174904, 41.632796600461006, 42.69155278801918, 45.79127445816994, 43.32714468240738, 43.06293345987797, 43.26016187667847, 42.98189900815487, 45.01988925039768, 48.62738527357578, 47.85406976938248, 45.45066453516483, 43.646259158849716, 41.23701363801956, 42.633769288659096, 41.80071339011192, 44.34158764779568, 43.36031690239906, 44.46360670030117, 46.872415244579315, 47.550960034132004, 46.73165559768677, 49.136797338724136, 44.66430053114891, 37.99379266798496, 35.437069460749626, 39.00979734957218, 43.29919718205929, 44.0004875510931, 44.009322077035904, 41.89189329743385, 42.81074859201908, 40.90041629970074, 42.46417298913002, 42.22632475197315, 44.25524488091469, 45.343707874417305, 46.522393226623535, 46.806883960962296, 51.03292979300022, 58.04270625114441, 61.70742340385914, 62.61930987238884, 60.592388436198235, 61.54494792222977, 59.760252088308334, 57.98714183270931, 53.43484930694103, 63.63111197948456, 66.12902954220772, 65.21875038743019, 64.22502771019936, 63.01749050617218, 63.35523918271065, 64.32797938585281, 66.718560308218, 68.22822690010071, 69.36672180891037, 64.83042642474174, 70.03435358405113, 68.85767072439194, 71.73874452710152, 67.00889512896538, 69.87006559967995, 70.14721512794495, 75.60821369290352, 72.90465116500854, 5.830334471538663, 0.6657750403974205, 15.64581910148263, 72.50889480113983, 52.00181320309639, 45.97864240407944, 31.286422982811928, 40.73919855058193, 49.426482394337654, 62.57415309548378, 1.408135446254164, 0.16025050805183128, 0.05588354564679321, 0.04251542879501358, 0.08571028636652045, 0.02934355434263125, 0.0684699731937144, 0.027447803040558938, 0.03773588643525727, 0.08656541118398309, 0.014507705018331762, 0.050557218564790674, 0.03504596847051289, 0.04287449839466717, 0.09732828912092373, 0.21342820924473926, 0.9637789777480066, 21.960516907274723, 63.734234645962715, 41.6177000105381, 38.975131809711456, 46.45928241312504, 48.14698085188866, 66.07742831110954, 72.20542028546333, 2.0531925139948726, 0.21828357683261856, 43.1073834747076, 92.37153097987175, 72.85422787070274, 76.43359780311584, 70.94110652804375, 72.37112939357758, 71.26541152596474, 75.21357446908951, 71.19563207030296, 72.52825856208801, 67.04539597034454, 64.27726730704308, 62.68299825489521, 60.44722482562065, 70.26823103427887, 69.65876653790474, 60.81197865307331, 60.67261353135109, 61.05711489915848, 58.48746478557587, 63.89347270131111, 64.4008594751358, 64.4776001572609, 64.02771189808846, 62.950830683112144, 62.93186590075493, 62.922712191939354, 54.59372252225876, 50.29622532427311, 51.38770155608654, 49.65466395020485, 48.39602328836918, 45.47161281108856, 48.07020977139473, 44.515268728137016, 44.584580808877945, 44.57457214593887, 46.40224367380142, 44.09531146287918, 43.912628665566444, 42.019235864281654, 42.615936845541, 43.55850286781788, 41.05642452836037, 44.493803679943085, 46.503922417759895, 48.040723353624344, 47.92679786682129, 45.23658402264118, 41.70715481042862, 43.11527565121651, 43.948798924684525, 43.28968249261379, 43.54779504239559, 45.03038048744202, 48.593574687838554, 50.02782292664051, 53.27212683856487, 52.25416146218777, 51.98902688920498, 46.93889267742634, 46.91442959010601, 44.14856180548668, 45.69471783936024, 45.877229645848274, 47.691845074296, 46.925562992691994, 48.2220534235239, 46.14295318722725, 49.593802616000175, 53.46334017813206, 46.16276152431965, 48.51431094110012, 47.158182710409164, 44.72259320318699, 46.452180594205856, 45.361452922225, 43.28500494360924, 45.628001019358635, 45.57661257684231, 48.354035541415215, 50.49376532435417, 51.19127109646797, 47.1038456261158, 46.70980677008629, 44.57970567047596, 44.794751331210136, 43.507228419184685, 45.76370693743229, 46.48778848350048, 49.73938800394535, 49.34429660439491, 49.151141569018364, 48.85639898478985, 49.91108559072018, 47.89747104048729, 39.57482323050499, 38.52120816707611, 41.745300963521004, 45.777560994029045, 47.337791472673416, 46.31917253136635, 45.10235242545605, 44.24529701471329, 44.026911333203316, 44.55029144883156, 45.36509692668915, 46.00085601210594, 48.41333515942097, 49.816877245903015, 47.755487859249115, 52.793094143271446, 59.767490699887276, 64.58248972892761, 65.4742942750454, 63.20757910609245, 62.814193814992905, 62.67302379012108, 60.165576338768005, 56.87378637492657, 64.92259427905083, 67.13453158736229, 67.82932430505753, 65.81360086798668, 66.76899880170822, 66.48595198988914, 66.86864465475082, 70.80106124281883, 71.76103413105011, 72.02275648713112, 71.75332054495811, 71.13493412733078, 73.72210130095482, 74.73578810691833, 71.1593060195446, 72.96709701418877, 73.38245272636414, 77.75301620364189, 76.71443313360214, 6.295458963140845, 0.6457641860470176, 17.694360427558422, 82.45299160480499, 57.7856120467186, 55.12475922703743, 37.501665875315666, 40.78646421432495, 58.87468680739403, 70.92712327837944, 1.6347644291818142, 0.25598546548280865, 0.053339355799835175, 0.06515354529256001, 0.0932388253568206, 0.016344273753929883, 0.02042602289293427, 0.02454063989716815, 0.16191113769309595, 0.5415003933012486, 0.18853794172173366, 0.15532496297964826, 0.15503634174820036, 0.2459369640564546, 0.3072150587104261, 0.4555797897046432, 1.1091103730723262, 29.21342331916094, 72.34820902347565, 55.73000594973564, 46.794861406087875, 50.845573246479034, 56.74204744398594, 69.16416227817535, 78.95120590925217, 1.9017535401508212, 0.3093450819142163, 48.78380388021469, 96.85619473457336, 73.974878937006, 80.77349692583084, 73.12751680612564, 75.49273028969765, 76.59647226333618, 76.14906907081604, 73.83031949400902, 75.71117296814919, 69.10317555069923, 64.60703641176224, 64.92311865091324, 63.422252386808395, 73.67006689310074, 73.5717661678791, 65.31609356403351, 64.82316121459007, 64.31539446115494, 62.50870920717716, 67.48345926404, 65.45642003417015, 67.17610135674477, 65.41276797652245, 66.37605428695679, 64.97703015804291, 64.80417743325233, 57.312267646193504, 52.10709035396576, 54.93477702140808, 52.914843410253525, 50.67598454654217, 48.67032676935196, 49.47842180728912, 47.58687570691109, 48.85659657418728, 47.38118514418602, 51.064198315143585, 47.53383435308933, 47.48782642185688, 45.90123675763607, 44.344448894262314, 46.92864082753658, 42.76148043572903, 46.46488331258297, 50.869120582938194, 52.07600422203541, 53.204771652817726, 47.27021589875221, 45.106277614831924, 47.077114060521126, 45.74601128697395, 45.040541142225266, 46.826692298054695, 47.230420634150505, 52.475005611777306, 54.34684216976166, 57.168555557727814, 54.974963665008545, 55.21256111562252, 50.33101625740528, 48.98943744599819, 46.665702536702156, 48.76136228442192, 50.59075132012367, 54.241211637854576, 52.08098955452442, 52.946203127503395, 51.06201343238354, 53.385535553097725, 55.12128621339798, 49.86226201057434, 53.18899869918823, 49.865431040525436, 48.18409726023674, 51.37430727481842, 47.441738694906235, 46.00686728954315, 47.98987068235874, 49.13176640868187, 49.2732860147953, 54.23899635672569, 53.741964027285576, 51.35861411690712, 49.252508729696274, 46.558339297771454, 46.42294496297836, 47.049706131219864, 49.41522739827633, 47.3782517015934, 53.198167607188225, 52.118501141667366, 51.97384670376778, 52.10896745324135, 53.1942044198513, 51.27257913351059, 43.11740733683109, 40.80080844461918, 44.85456772148609, 47.270595878362656, 48.43764245510101, 48.99067997932434, 48.24754625558853, 47.85860292613506, 46.755879297852516, 48.30114237964153, 49.343947023153305, 50.12213386595249, 51.57380037009716, 50.62482409179211, 51.07976607978344, 55.626070126891136, 62.37474359571934, 67.99152240157127, 66.98168098926544, 64.76980447769165, 65.52830457687378, 64.70798179507256, 61.05710729956627, 58.9323715120554, 67.01485320925713, 68.55970591306686, 69.72720846533775, 67.93713971972466, 71.30492940545082, 68.40901359915733, 70.65846249461174, 71.71707049012184, 76.85259371995926, 75.75712010264397, 73.17643538117409, 74.80372086167336, 77.69988745450974, 77.89300069212914, 75.30277848243713, 77.19921112060547, 79.02663946151733, 81.51657745242119, 81.92288964986801, 8.013269361108541, 0.8233070466667414, 20.844389498233795, 93.84229525923729, 66.27681881189346, 67.79356062412262, 46.11034333705902, 57.64313869178295, 66.92824825644493, 81.4448145031929, 2.319531859830022, 0.49671602610033005, 0.1392442110227421, 0.18286826001713052, 0.17225887306267396, 0.10395353790954687, 0.16994294186588377, 0.1077352330321446], [0.06328159652184695, 0.04183610020845663, 0.10310881058103405, 0.03335155255626887, 0.08070205120020546, 0.15415449219290167, 0.08356702324817888, 0.18202195933554322, 0.575056808302179, 14.6628412976861, 63.39340053498745, 36.20274357497692, 32.11996145546436, 33.66267487406731, 48.937448635697365, 57.81759113073349, 76.42580062150955, 5.132191758602858, 0.8145178807899356, 24.467569179832935, 85.05536556243896, 73.61307755112648, 72.40515276789665, 69.62867975234985, 69.73030909895897, 68.96531894803047, 70.6820060312748, 69.80350837111473, 64.45790201425552, 57.17742808163166, 61.00878149271011, 57.667571380734444, 61.49329349398613, 66.03503778576851, 62.09373727440834, 56.6074700653553, 56.28299407660961, 58.00687797367573, 60.782268047332764, 61.25583663582802, 62.903606817126274, 60.55964179337025, 60.710512697696686, 61.36843979358673, 61.654735431075096, 59.87387739121914, 54.191080927848816, 46.00615672767162, 46.8344970792532, 45.53494021296501, 46.642728969454765, 44.492458552122116, 44.91627261042595, 43.93478527665138, 42.484475299715996, 43.298524618148804, 42.119223698973656, 39.7337307035923, 39.4282840937376, 39.310266226530075, 42.79493384063244, 41.99391782283783, 44.78492125868797, 43.549675941467285, 45.77802076935768, 43.63849237561226, 41.30998872220516, 39.00453083217144, 40.162511095404625, 39.053969979286194, 40.91108612716198, 42.63279274106026, 43.81007596850395, 43.49726155400276, 46.70939639210701, 45.29020294547081, 47.595098465681076, 48.14820438623428, 49.507269859313965, 42.776656821370125, 42.90502533316612, 41.691621243953705, 42.00836844742298, 41.94145403802395, 41.2308731675148, 41.203393042087555, 45.77441096305847, 41.41070991754532, 47.3918891698122, 46.96288459002972, 44.8467705398798, 41.71929135918617, 43.07492181658745, 43.49735274910927, 42.327300533652306, 42.36064374446869, 42.70010992884636, 41.78902521729469, 44.405454620718956, 46.9984544813633, 48.98211143910885, 49.495676681399345, 49.11697760224342, 42.190260887145996, 41.63525506854057, 39.41169038414955, 39.5662546902895, 39.285681545734406, 39.76842284202576, 42.39788554608822, 44.176744893193245, 45.099760964512825, 48.88044409453869, 46.542467549443245, 46.322865933179855, 42.28592835366726, 40.612589344382286, 39.284925386309624, 42.201664075255394, 40.64806044101715, 43.96945841610432, 41.311998814344406, 39.44392405450344, 42.44754508137703, 40.33190980553627, 42.36252084374428, 44.33123700320721, 45.45222245156765, 45.67136809229851, 43.21043774485588, 46.10095024108887, 55.76801151037216, 57.90932960808277, 59.392823204398155, 58.43114800751209, 60.49601040780544, 60.86914658546448, 62.10173964500427, 60.02259001135826, 54.11435164511204, 59.43403199315071, 61.75769090652466, 66.5718349814415, 65.76032772660255, 65.91931879520416, 63.45502942800522, 63.196202516555786, 66.15140274167061, 69.0011890232563, 69.14556607604027, 69.51863765716553, 67.61173278093338, 68.24832022190094, 65.72901740670204, 70.55102705955505, 68.33190053701401, 77.64443323016167, 76.76348090171814, 5.437858756631613, 0.9203306247945875, 18.49445879459381, 73.456601947546, 56.31041720509529, 48.68507757782936, 33.161189183592796, 37.92841337621212, 45.78819282352924, 61.34605519473553, 0.8887581783346832, 0.1060358781251125, 0.0705483577621635, 0.061862317015766166, 0.038189950937521644, 0.03067031029786449, 0.11195411992957816, 0.025586170122551266, 0.07714882623986341, 0.024291621521115303, 0.0738199228362646, 0.1050296520406846, 0.045554850075859576, 0.08874623439623974, 0.0645577342947945, 0.2837570174597204, 0.5417680414393544, 18.234505243599415, 74.70409780740738, 39.86238420009613, 29.741488583385944, 41.82070791721344, 55.409546345472336, 64.74759846925735, 83.86947959661484, 6.6057531628757715, 1.0318276262842119, 24.739507287740707, 90.60463339090347, 76.56354323029518, 77.39782646298409, 72.18234032392502, 72.17197448015213, 71.96422442793846, 74.52287033200264, 70.97756177186966, 69.00639474391937, 63.67777347564697, 62.525063529610634, 60.26218995451927, 65.04568487405777, 68.692227602005, 66.26838326454163, 59.29640717804432, 59.9214356392622, 60.47804497182369, 63.98760125041008, 63.94920811057091, 65.02593353390694, 62.5444120913744, 65.09185999631882, 63.263105526566505, 65.0800122320652, 60.44665865600109, 56.35011367499828, 48.245448768138885, 49.658494144678116, 48.8551564514637, 49.51417788863182, 47.19437196850777, 48.729706183075905, 45.91631054878235, 45.1908952742815, 44.77433882653713, 45.12300431728363, 43.883491829037666, 44.38012138009071, 42.65672005712986, 45.534693226218224, 45.37762105464935, 47.06223405897617, 45.99780097603798, 46.5829049795866, 46.036137118935585, 45.19947521388531, 42.678660079836845, 42.938205152750015, 41.99436999857426, 42.10849307477474, 45.29175326228142, 46.24851152300835, 44.84846904873848, 47.58296191692352, 47.81504966318607, 50.81148147583008, 49.63771305978298, 50.91822914779186, 44.43249396979809, 44.8175311088562, 43.218930289149284, 45.83679221570492, 43.87824431061745, 44.93084482848644, 44.95364360511303, 47.31870509684086, 46.644674465060234, 50.56660361588001, 51.18344731628895, 46.49085111916065, 45.90132415294647, 46.134734228253365, 45.956181809306145, 43.68701197206974, 43.81767936050892, 44.50375534594059, 44.92069557309151, 46.13037206232548, 49.75708365440369, 50.73099799454212, 51.41096770763397, 52.007015123963356, 45.163361951708794, 44.193046018481255, 41.2849822640419, 43.36957700550556, 41.067014560103416, 42.49386079609394, 43.50669264793396, 46.18881292641163, 47.40474008023739, 50.21794572472572, 50.2985318005085, 48.85092347860336, 44.68057505786419, 44.1854540258646, 42.48035632073879, 44.50049512088299, 43.41185353696346, 45.80454334616661, 44.311109483242035, 42.6505795866251, 44.099096059799194, 43.75749059021473, 45.11564031243324, 47.39546857774258, 46.91927433013916, 47.651187255978584, 46.89775228500366, 50.04890039563179, 57.31924407184124, 61.34781450033188, 63.006474897265434, 62.210474610328674, 63.22792701423168, 63.91581550240517, 65.44083327054977, 62.761859223246574, 59.075532630085945, 61.14710547029972, 64.3770195543766, 70.16078040003777, 68.10649663209915, 67.29916915297508, 67.14819565415382, 66.76175639033318, 68.94796147942543, 69.66046884655952, 70.78128710389137, 72.86146268248558, 71.22757315635681, 71.97474226355553, 69.0667051076889, 74.27890822291374, 72.69500881433487, 79.05131533741951, 80.53842633962631, 7.088772794231772, 0.7751223666127771, 20.927278250455856, 82.80874371528625, 62.76439368724823, 57.670805007219315, 39.4438898563385, 40.48913016915321, 50.4043485224247, 70.3631043434143, 1.0461939428932965, 0.09704027645057067, 0.07126830038032494, 0.028269119320611935, 0.040082947016344406, 0.019575215519580524, 0.07517742225900292, 0.03965781885199249, 0.1468692292110063, 0.12870192906120792, 0.17342371837003157, 0.2123313446645625, 0.2447296679019928, 0.2669739117845893, 0.21302845882019028, 0.4083588923094794, 0.7186153018847108, 23.424097672104836, 85.0047218799591, 52.13200941681862, 41.79428033530712, 47.41539090871811, 65.44871404767036, 70.01354590058327, 88.86021539568901, 7.603094195947051, 0.9227796527557075, 30.529735386371613, 94.81817409396172, 78.88010412454605, 77.81106948852539, 74.89668667316437, 78.44550624489784, 72.46936932206154, 77.96645835042, 73.53014320135117, 72.22634196281433, 63.54210555553436, 65.46363204717636, 61.62884742021561, 67.4443593621254, 71.04235589504242, 69.26348894834518, 60.185745656490326, 63.3594873547554, 62.445624992251396, 67.80816704034805, 66.52143448591232, 69.90185469388962, 63.810819536447525, 69.1595721244812, 63.49137827754021, 64.33072283864021, 64.6803268790245, 60.054964274168015, 50.78347697854042, 51.86826176941395, 50.23148059844971, 54.74398925900459, 49.00829963386059, 51.97629377245903, 49.47850540280342, 47.888856902718544, 48.575240671634674, 47.634388357400894, 45.237727761268616, 47.04808361828327, 44.29870694875717, 50.273574739694595, 47.00315102934837, 50.83206117153168, 47.54614569246769, 48.593137711286545, 48.91682714223862, 48.956280425190926, 44.220332354307175, 46.10849663615227, 44.58530656993389, 45.653254464268684, 48.82483787834644, 49.004575833678246, 48.23197469115257, 52.636097967624664, 52.09483981132507, 53.23438726365566, 54.30652253329754, 56.42209701240063, 48.07123191654682, 48.90050321817398, 46.11445851624012, 49.45151165127754, 46.86135023832321, 49.400020614266396, 50.281584709882736, 52.08982788026333, 49.38500002026558, 54.28858369588852, 55.56310370564461, 51.47063970565796, 50.92330947518349, 51.4565272629261, 51.31463907659054, 46.605950742959976, 47.45607912540436, 45.533047914505005, 46.890027299523354, 49.67080928385258, 52.01497569680214, 55.430365428328514, 54.63362418115139, 57.602024897933006, 48.32158148288727, 46.838912442326546, 45.07222764194012, 45.32318137586117, 40.804501846432686, 44.02936980128288, 48.0815901607275, 50.36203399300575, 50.4013466835022, 55.129839554429054, 53.738593608140945, 52.39061214029789, 46.323337107896805, 46.20939262211323, 43.47858175635338, 46.55107028782368, 45.99495492875576, 49.31104078888893, 46.361608654260635, 46.41271971166134, 46.00319288671017, 45.196085795760155, 47.73118816316128, 49.57738749682903, 50.633293837308884, 50.27316056191921, 48.435218185186386, 51.93712167441845, 60.05008913576603, 62.57096506655216, 66.34568631649017, 63.70220236480236, 66.60491600632668, 65.39170950651169, 66.653902977705, 63.19149076938629, 60.27854047715664, 64.7552664577961, 67.0195497572422, 70.90892225503922, 70.28744280338287, 70.6568817794323, 69.87646445631981, 68.90131518244743, 70.95374464988708, 75.14536052942276, 76.00726827979088, 75.10957404971123, 76.36413753032684, 75.74803858995438, 74.71421286463737, 76.81895792484283, 78.64183411002159, 83.85796621441841, 85.998155772686, 8.07265067473054, 1.286138123832643, 25.19967019557953, 93.39578121900558, 72.43943452835083, 68.52710366249084, 49.01488848030567, 53.93472008407116, 60.59213384985924, 82.7512376010418, 1.8270728224888444, 0.2814613172085956, 0.1393872228800319, 0.10910407989285886, 0.11012423608917743, 0.12329410674283281, 0.19975170405814424, 0.1420423897798173], [0.01482065106756636, 0.05565034800383728, 0.03704659822687972, 0.08960066159488633, 0.01449581395718269, 0.04970613474142738, 0.10116633551660925, 0.20920650218613446, 0.7606308348476887, 14.574212953448296, 64.23594072461128, 47.53913126885891, 50.157319977879524, 33.91341581940651, 47.095326483249664, 51.091157868504524, 81.31271839141846, 15.805248096585274, 1.0268922848626971, 8.28174490481615, 78.02489161491394, 76.15716263651848, 73.98839861154556, 69.31957393884659, 68.60993921756744, 70.33555582165718, 67.85016238689423, 69.27747219800949, 60.80437146127224, 55.224313884973526, 59.88315649330616, 62.72679090499878, 66.62777557969093, 64.85776215791702, 60.344292148947716, 57.198638543486595, 58.06963540613651, 61.32107153534889, 63.30235742032528, 62.50617854297161, 64.34355854988098, 64.68751609325409, 61.730598360300064, 60.963624715805054, 58.29696200788021, 57.78596542775631, 53.077163100242615, 45.921770855784416, 46.00832641124725, 44.71118621528149, 46.52754954993725, 47.20355987548828, 45.662662759423256, 43.81685100495815, 43.61184440553188, 45.28778247535229, 43.26384387910366, 43.438790291547775, 41.19472950696945, 42.70789951086044, 40.42090103030205, 40.486850291490555, 42.73379132151604, 46.28308966755867, 45.40488839149475, 39.216779842972755, 39.424659088253975, 41.923469603061676, 40.21811731159687, 41.238259971141815, 40.45526638627052, 37.67069220542908, 41.39412760734558, 41.207910999655724, 42.17176727950573, 42.324994057416916, 44.804980382323265, 41.80382162332535, 45.1919212192297, 44.17115919291973, 41.431673392653465, 44.055535197257996, 40.388560965657234, 40.82932211458683, 43.655321672558784, 43.40976744890213, 42.24196471273899, 42.11498312652111, 47.43662416934967, 46.758356764912605, 44.49447624385357, 43.491295874118805, 39.8626995831728, 41.32486492395401, 42.639377787709236, 43.85756202042103, 42.89712555706501, 43.34809295833111, 42.64858849346638, 43.0831141769886, 45.32790072262287, 44.81134884059429, 44.839718118309975, 42.776922807097435, 40.69828234612942, 40.116351172327995, 40.95352225005627, 43.764398619532585, 41.08402244746685, 38.54618422687054, 38.41762952506542, 41.650598645210266, 43.47157493233681, 46.95299372076988, 45.503078922629356, 46.55690677464008, 42.87986308336258, 43.00183653831482, 41.48630306124687, 40.36822445690632, 41.96999430656433, 41.64150953292847, 43.843734562397, 43.48651573061943, 40.156370624899864, 43.20989057421684, 45.69320932030678, 46.635114178061485, 44.652923941612244, 46.0111952573061, 44.532804787158966, 50.23528799414635, 56.53308525681496, 58.27718406915665, 59.956701546907425, 59.12014223635197, 61.024140268564224, 62.92186103761196, 61.21940799057484, 63.09593729674816, 58.10454413294792, 55.54162725806236, 63.55498306453228, 66.61680176854134, 65.49188733100891, 67.55456104874611, 66.84039697051048, 63.661498948931694, 64.76982727646828, 67.15429052710533, 66.37561351060867, 68.45461875200272, 64.90754708647728, 65.41011571884155, 67.54497036337852, 68.66230800747871, 72.50916078686714, 73.59678402543068, 6.3012417778372765, 0.7901556661818177, 21.354956701397896, 75.10544747114182, 55.20972266793251, 42.63070285320282, 30.809837356209755, 41.57178707420826, 59.31110478937626, 58.58561731874943, 1.0012051882222295, 0.11007876470102929, 0.027580011083045974, 0.02754834364168346, 0.049732069091987796, 0.03188049711752683, 0.03303949430119246, 0.008159607568813954, 0.033580876188352704, 0.061825651209801435, 0.08225339959608391, 0.02323471417184919, 0.07827309091226198, 0.051607390923891217, 0.11375405811122619, 0.30848822789266706, 0.7516963267698884, 16.320623941719532, 73.2556763291359, 46.314555779099464, 32.11893551051617, 39.443661868572235, 56.70696772634983, 56.95929318666458, 87.65718474984169, 17.83738475292921, 0.9489073476288468, 6.288155755028129, 83.41166496276855, 77.58936658501625, 76.66780203580856, 72.59066641330719, 71.11079782247543, 69.91975173354149, 70.72833314538002, 71.44308999180794, 63.741807639598846, 59.33897249400616, 62.381944209337234, 65.39209708571434, 69.25832882523537, 66.92111223936081, 61.58093959093094, 59.14351478219032, 60.918855518102646, 63.843414187431335, 67.27143064141273, 65.13858988881111, 65.94236835837364, 66.39037951827049, 63.64588938653469, 62.298018112778664, 60.945712476968765, 60.205717384815216, 54.23281408846378, 47.36695110797882, 48.16506788134575, 47.147816866636276, 48.991994708776474, 51.20482876896858, 47.743396908044815, 45.64190447330475, 47.090268954634666, 45.3413026034832, 46.41237013041973, 42.4095319211483, 43.29975575208664, 44.0225263684988, 42.89113707840443, 45.9196961671114, 45.705991834402084, 50.559463798999786, 47.64115959405899, 41.92920729517937, 41.20222270488739, 43.513368889689445, 43.913400024175644, 44.38890650868416, 43.311500921845436, 39.880661219358444, 41.75475485622883, 43.54434862732887, 43.348047360777855, 45.97971014678478, 47.57166512310505, 44.44445952773094, 47.42118939757347, 46.99937783181667, 45.64751297235489, 47.53851190209389, 45.2741564065218, 46.26100145280361, 46.89593978226185, 47.54437118768692, 45.6777099519968, 45.80588087439537, 49.00116741657257, 49.101227447390556, 46.775429248809814, 48.60582523047924, 44.12459269165993, 45.8150801807642, 44.78488326072693, 45.483715161681175, 44.717942252755165, 47.05147683620453, 45.43430641293526, 46.29797346889973, 47.379482835531235, 46.59920230507851, 49.12163995206356, 46.14109508693218, 43.153957575559616, 43.90728995203972, 43.61004330217838, 44.477966129779816, 42.5839501619339, 41.56190760433674, 40.450706630945206, 43.433386981487274, 47.944896295666695, 50.14869064092636, 48.32028575241566, 48.39581809937954, 44.90426905453205, 44.06624302268028, 45.38164883852005, 42.10204102098942, 42.656545266509056, 44.24216218292713, 46.36230781674385, 47.87795148789883, 45.076050236821175, 46.55695617198944, 48.31833265721798, 48.42558570206165, 47.00152091681957, 47.96785846352577, 47.6164723187685, 54.15519945323467, 59.39497388899326, 60.85363581776619, 61.47794231772423, 61.95107012987137, 63.77732053399086, 64.06916007399559, 64.77521538734436, 63.77117246389389, 60.252321884036064, 57.56684638559818, 64.7869947552681, 68.13181847333908, 69.50470000505447, 68.97685512900352, 70.5959178507328, 66.64648577570915, 68.63552704453468, 68.99125635623932, 69.31356266140938, 71.57212346792221, 70.21787613630295, 68.64070996642113, 70.57307347655296, 74.38378259539604, 75.02100080251694, 79.06182557344437, 9.58020742982626, 1.1579710012301803, 24.45975109934807, 81.46289393305779, 62.45534487068653, 53.678705021739006, 40.37145048379898, 48.040654957294464, 65.52836537361145, 68.0654664337635, 1.0258066118694842, 0.11194554070243612, 0.04949437774484977, 0.08701317114173435, 0.05486608715727925, 0.041991672915173694, 0.02229214209364727, 0.10634970269165933, 0.10129976624739356, 0.10799546711496077, 0.15732420491985977, 0.18465615314198658, 0.2708729181904346, 0.15587231173412874, 0.20084512507310137, 0.5014156317338347, 1.302126122172922, 21.94374840706587, 84.91994082927704, 58.946339562535286, 62.49431177973747, 47.97523766756058, 64.23297688364983, 63.691726326942444, 94.02280077338219, 19.644565880298615, 1.1425302922725677, 11.000372674316168, 91.4498296380043, 80.92143058776855, 81.45649507641792, 73.31938371062279, 76.27902209758759, 74.01530876755714, 73.93735975027084, 74.23485338687897, 68.79656240344048, 61.037853732705116, 65.14645546674728, 67.08707973361015, 73.57443362474442, 70.37035435438156, 65.01906350255013, 61.502644792199135, 65.557312220335, 66.21544450521469, 69.66697409749031, 67.71513283252716, 66.7846691608429, 68.69706094264984, 66.88091799616814, 62.571352645754814, 64.60534930229187, 64.4947600364685, 58.30030582845211, 49.67311955988407, 52.34988212585449, 48.38040992617607, 52.148238345980644, 55.771305933594704, 52.006593346595764, 47.79868774116039, 51.132131069898605, 48.7222395837307, 49.522602036595345, 46.214731335639954, 47.10078679025173, 46.605718955397606, 44.71220836043358, 47.87850625813007, 48.50144103169441, 52.151471972465515, 51.785319820046425, 44.144606217741966, 43.84976863861084, 46.92329831421375, 47.2894162684679, 46.18130452930927, 44.42644089460373, 41.48008279502392, 46.66889816522598, 45.77463515102863, 47.81029611825943, 50.27157224714756, 51.68926477432251, 48.88211600482464, 50.61256214976311, 51.53031550347805, 45.510803908109665, 49.69656050205231, 47.35743261873722, 48.6051032692194, 54.0290842205286, 52.44892381131649, 50.16618870198727, 50.05913704633713, 55.17570309340954, 54.51220169663429, 53.5041955858469, 52.92587801814079, 50.38720764219761, 49.88093040883541, 48.87941814959049, 48.967900201678276, 49.31196793913841, 50.53433954715729, 49.32467445731163, 48.431479185819626, 51.93425662815571, 51.02766327559948, 51.31957121193409, 50.986078307032585, 46.705387607216835, 45.82323834300041, 44.7776560485363, 49.16200898587704, 44.372662380337715, 42.95052029192448, 42.630372270941734, 46.49605304002762, 48.98061811923981, 55.41728273034096, 50.06666824221611, 49.22435984015465, 47.81563103199005, 48.40148739516735, 47.15113028883934, 46.76626794040203, 45.074910297989845, 48.70030336081982, 48.193988129496574, 51.168935894966125, 46.2240332365036, 50.40560245513916, 50.80227077007294, 53.236917927861214, 48.71672607958317, 52.84635208547115, 48.18870261311531, 55.824259892106056, 63.30101989209652, 64.56536784768105, 65.17663344740868, 65.55721342563629, 64.97355714440346, 65.36040678620338, 64.99230533838272, 67.93927520513535, 60.52590720355511, 59.473257288336754, 65.0535200536251, 73.44132676720619, 71.17179974913597, 72.58400917053223, 69.90823835134506, 71.33066162467003, 71.27538979053497, 73.3258205652237, 73.79246592521667, 77.09596306085587, 72.56831601262093, 74.29616689682007, 75.53005948662758, 80.34136891365051, 78.58885735273361, 86.20553344488144, 11.325017753988504, 1.0066023236140609, 27.39115510135889, 92.54690676927567, 67.87454187870026, 61.175501346588135, 44.51426558196545, 56.18804857134819, 75.59034705162048, 77.87432089447975, 1.5538130979984999, 0.19218617642764002, 0.1884890638757497, 0.16436806210549548, 0.18848778738174587, 0.21443984558572993, 0.13017206423683092, 0.2527733612805605], [0.020140084525337443, 0.0675374423735775, 0.07219980703666806, 0.04463915487576742, 0.06097414065152407, 0.04783652002515737, 0.09306951920734718, 0.145192539494019, 0.672299824655056, 7.796862423419952, 62.460090816020966, 43.316919431090355, 49.259523153305054, 31.985832452774048, 54.84885983169079, 43.950429037213326, 85.12954518198967, 22.437625005841255, 0.06305495204287581, 0.4135496512753889, 55.772423073649406, 80.98991051316261, 74.1263236105442, 74.75749254226685, 69.14256423711777, 68.82940024137497, 70.52562922239304, 60.955428555607796, 57.69172288477421, 56.62172690033913, 62.53644771873951, 65.9949043393135, 61.81272715330124, 59.58969824016094, 57.34611622989178, 55.91025687754154, 59.665599167346954, 60.193694829940796, 62.03036047518253, 62.21777781844139, 61.23574711382389, 58.38555805385113, 61.66828170418739, 58.87065902352333, 58.191833049058914, 54.81311894953251, 46.67538821697235, 45.44743850827217, 46.861627623438835, 45.05348324775696, 49.2113683372736, 47.648683190345764, 45.86264222860336, 45.34315690398216, 45.101630464196205, 44.19896610081196, 43.283511623740196, 43.08727875351906, 42.64245182275772, 40.43798491358757, 43.535776287317276, 42.730933874845505, 42.103659734129906, 42.90156751871109, 41.057898849248886, 42.236398011446, 42.05017380416393, 39.82288531959057, 42.461596727371216, 40.08297756314278, 40.31467393040657, 41.57840631902218, 40.99590517580509, 41.68150618672371, 40.569617450237274, 40.11572800576687, 42.08775378763676, 42.294474095106125, 43.25332224369049, 40.91570287942886, 42.45293319225311, 43.52609060704708, 41.1845650523901, 40.3729248046875, 42.725747153162956, 39.39000114798546, 42.91077062487602, 44.21699233353138, 45.74212409555912, 47.18249760568142, 41.236348673701286, 41.264140382409096, 42.7636881172657, 43.200220093131065, 42.84788779914379, 40.90582720935345, 43.37207347154617, 40.36689072847366, 43.58600199222565, 44.077289029955864, 41.737146601080894, 43.628970086574554, 42.96586386859417, 40.821608528494835, 40.466209799051285, 38.41856427490711, 40.067687183618546, 38.86388897895813, 39.87390138208866, 42.05909192562103, 43.09840835630894, 39.34234030544758, 42.09930516779423, 41.97711132466793, 46.08138509094715, 44.975412636995316, 44.54371400177479, 41.558491587638855, 39.97853256762028, 42.71049477159977, 40.773081332445145, 42.12882578372955, 41.77799440920353, 43.679100796580315, 43.93293097615242, 41.35061614215374, 44.3503537774086, 45.062887743115425, 43.26997675001621, 43.067725002765656, 44.877362698316574, 47.19477854669094, 54.98974867165089, 56.29217438399792, 56.57858021557331, 58.32174427807331, 59.44996073842049, 61.01489156484604, 62.83204145729542, 61.83062419295311, 62.87412419915199, 62.19122104346752, 58.07030037045479, 61.674646362662315, 66.009221971035, 66.73136562108994, 70.96316814422607, 73.21433454751968, 66.49859771132469, 65.82284197211266, 69.47285771369934, 64.94213283061981, 65.60730993747711, 63.81992384791374, 67.0540215075016, 70.78408375382423, 72.45162427425385, 73.76610293984413, 11.830444782972336, 1.0146797401830554, 23.600290417671204, 75.64689561724663, 52.213032469153404, 39.47651490569115, 29.860427901148796, 38.1475780159235, 54.088091254234314, 55.36461755633354, 0.8110645192209631, 0.05648040307278279, 0.04522810471826233, 0.02816642834659433, 0.039662590861553326, 0.02422962621494662, 0.011464547023933847, 0.02576606671937043, 0.031778485208633356, 0.035346939039300196, 0.008156039693858474, 0.02247504067781847, 0.03207392306649126, 0.16999502578983083, 0.10543441938352771, 0.23747441737214103, 0.4384972422849387, 8.764636293053627, 72.76718974113464, 48.3192940056324, 47.65779510140419, 37.78968662023544, 63.8537572324276, 51.35744757950306, 92.43806540966034, 25.247338637709618, 0.10416369186714292, 0.17208298406330869, 55.135242864489555, 85.28638556599617, 74.47006076574326, 75.81876799464226, 71.80374383926392, 71.31170064210892, 72.43747383356094, 63.418840169906616, 62.2132408618927, 59.277598187327385, 64.29544553160667, 69.71504911780357, 65.12030526995659, 61.75462067127228, 58.52940313518047, 59.327592104673386, 61.66988901793957, 63.84070873260498, 64.32686984539032, 65.00862166285515, 61.50303617119789, 60.731992945075035, 63.40692400932312, 62.668331041932106, 60.621441677212715, 56.12949751317501, 50.92672549188137, 48.09302754700184, 48.77805858850479, 47.04648770391941, 50.010188072919846, 51.32801815867424, 50.74596159160137, 46.53096176683903, 46.61526024341583, 45.03536581993103, 47.22928449511528, 46.68176807463169, 45.869341269135475, 44.71976235508919, 46.609507352113724, 47.15518467128277, 44.23224091529846, 45.8371189981699, 43.82730804383755, 44.83475178480148, 42.09195636212826, 43.133754059672356, 44.45914573967457, 41.04306824505329, 41.71762704849243, 41.882367208600044, 43.10916557908058, 43.8202328234911, 44.22345578670502, 45.19748792052269, 46.437300592660904, 46.580336317420006, 44.44189466536045, 43.44017341732979, 47.01386645436287, 45.94266213476658, 43.92168737947941, 44.04643088579178, 45.89327238500118, 42.86559484899044, 47.868303805589676, 46.28544174134731, 50.18223524093628, 49.81208570301533, 44.80190634727478, 46.08303800225258, 45.697940066456795, 46.52849189937115, 46.38897858560085, 44.965498968958855, 44.43242557346821, 43.08214142918587, 46.33564084768295, 47.09637522697449, 44.68535520136356, 47.11674593389034, 45.55977948009968, 42.85993315279484, 42.71171070635319, 39.660683423280716, 43.35155837237835, 42.45260640978813, 42.219716906547546, 42.97936834394932, 44.03663881123066, 41.29802316427231, 45.56575655937195, 44.000191166996956, 47.10870936512947, 46.160177662968636, 46.84960886836052, 44.86008882522583, 43.37161749601364, 44.55938436090946, 43.05769354104996, 45.35454869270325, 45.66538341343403, 45.94807304441929, 44.8434267193079, 44.98949848115444, 47.18748293817043, 48.24178196489811, 46.39237180352211, 46.10365949571133, 47.70610950887203, 51.164999306201935, 56.50980390608311, 59.221319407224655, 58.89793775975704, 60.91505952179432, 61.95147670805454, 64.42724525928497, 66.79664611816406, 63.83690893650055, 65.02122178673744, 65.4338264465332, 60.060641169548035, 63.36906284093857, 68.96784201264381, 70.9229739010334, 73.76917317509651, 76.33662700653076, 68.71831700205803, 68.44576522707939, 71.74809202551842, 69.06691789627075, 70.8059173822403, 68.62092822790146, 71.27836123108864, 74.04281929135323, 74.1692765057087, 79.52564388513565, 15.530443992465734, 1.0129054728895426, 27.316099628806114, 83.72317224740982, 56.88111238181591, 46.587316542863846, 38.57337176799774, 38.07288162410259, 61.29307843744755, 62.99541749060154, 0.9312670910730958, 0.12094681238522753, 0.030591523900511675, 0.04603953188052401, 0.057144922102452256, 0.019197722103854176, 0.04999239223252516, 0.1122240093536675, 0.15909799723885953, 0.18753047625068575, 0.19919289654353634, 0.1745527031016536, 0.13986688776640221, 0.2733864536276087, 0.2781445998698473, 0.40678930934518576, 0.9376195189543068, 13.014842178672552, 84.6950688958168, 56.44336447119713, 60.082474797964096, 43.5249924659729, 77.35743463039398, 52.86386914551258, 101.38251185417175, 28.509628884494305, 0.32024182844907045, 1.4075420843437314, 63.82193014025688, 86.12641409039497, 80.22178933024406, 78.38584944605827, 76.08140990138054, 72.47528940439224, 75.54736375808716, 68.2602059841156, 66.00397825241089, 62.405217960476875, 66.54779747128487, 72.60522723197937, 68.47465887665749, 66.28811940550804, 62.702476009726524, 61.230537593364716, 64.8405946791172, 66.44832640886307, 67.65395611524582, 65.99654585123062, 67.1377158164978, 63.437842950224876, 64.86530855298042, 64.9076534807682, 65.19720554351807, 59.01299938559532, 53.94793197512627, 52.28030025959015, 52.00731910765171, 50.59098690748215, 53.866053968667984, 54.49725329875946, 51.636428609490395, 51.06294058263302, 51.36981971561909, 48.12419727444649, 50.972615629434586, 49.416253343224525, 48.66889424622059, 47.41513632237911, 50.435389056801796, 50.138275399804115, 47.46951900422573, 50.11394150555134, 46.95139780640602, 48.27477939426899, 45.462234914302826, 47.05442547798157, 48.59640933573246, 44.12996180355549, 45.007851496338844, 45.52956350147724, 47.4104967713356, 47.787884920835495, 45.71479216217995, 48.225553035736084, 50.05649618804455, 49.18833777308464, 49.59328584372997, 47.0852380245924, 50.44195130467415, 49.73432667553425, 46.593164429068565, 47.02134445309639, 51.306070536375046, 48.00380453467369, 51.00120909512043, 49.09813441336155, 52.78579853475094, 52.724036648869514, 47.75038093328476, 50.79882055521011, 51.61713324487209, 51.70437656342983, 50.25313563644886, 46.85486398637295, 49.359313398599625, 46.91383682191372, 48.993651419878006, 50.06540670990944, 49.28227253258228, 50.21391034126282, 50.22196590900421, 47.557469084858894, 45.53588256239891, 42.602382972836494, 45.75704209506512, 44.304653629660606, 44.456793665885925, 47.19470635056496, 48.11229631304741, 43.128875121474266, 47.45913416147232, 46.86218239367008, 51.304877400398254, 49.09416362643242, 48.67153510451317, 46.271131709218025, 45.27537614107132, 47.128787487745285, 45.8577860891819, 47.478440925478935, 48.08678828179836, 49.64816629886627, 47.381926104426384, 47.16931231319904, 50.922997891902924, 50.584854036569595, 48.44238460063934, 47.24762611091137, 49.578048661351204, 53.44705045223236, 60.194671377539635, 62.52241127192974, 59.724013432860374, 63.197650238871574, 64.21444907784462, 65.36055117845535, 67.88767397403717, 67.02379032969475, 66.24628365039825, 66.68470412492752, 61.78738251328468, 65.16629040241241, 70.92865079641342, 75.78650772571564, 77.05455288290977, 74.38198909163475, 70.30557543039322, 73.73619854450226, 75.79517886042595, 73.66287767887115, 73.05586025118828, 73.75470355153084, 74.22428995370865, 79.47234034538269, 79.563497453928, 84.20045703649521, 17.305667884647846, 1.0805184510536492, 29.640450105071068, 91.41332119703293, 66.20033651590347, 60.40613763034344, 43.9866828918457, 48.698612451553345, 71.41596704721451, 75.05184754729271, 1.6833033808507025, 0.23462465935153887, 0.1979712472530082, 0.14019055321114138, 0.13015778531553224, 0.12139416416175663, 0.14809748361585662, 0.32149053644388914], [0.03292329623945989, 0.020170404968666844, 0.027880801681021694, 0.048542157746851444, 0.07347398553974926, 0.01548847729281988, 0.06798083108151332, 0.10409318041638471, 0.10607581309159286, 3.7355356151238084, 62.85395868122578, 52.835651859641075, 39.20262560248375, 32.92670376598835, 49.743902161717415, 43.76571714878082, 81.54884532094002, 32.63892240822315, 0.16056305612437427, 0.405584299005568, 25.030227787792683, 85.54036393761635, 67.95483157038689, 72.95295417308807, 69.69776764512062, 70.57811960577965, 62.50756546854973, 58.81002567708492, 53.002611100673676, 60.35126857459545, 65.87195053696632, 63.78308102488518, 64.78669077157974, 60.22437818348408, 58.1538350880146, 58.815960958600044, 59.483702927827835, 60.402782410383224, 60.88946409523487, 60.610251277685165, 61.91240720450878, 63.69885474443436, 58.8787791877985, 58.846610113978386, 54.99478720128536, 51.589626520872116, 47.68821246922016, 44.81134124100208, 46.442411318421364, 46.51520401239395, 49.535129964351654, 50.99695332348347, 48.729079216718674, 46.54345169663429, 44.89654786884785, 44.138910323381424, 46.03201054036617, 46.333284974098206, 46.167663261294365, 43.58316354453564, 42.97225132584572, 41.76063314080238, 45.89085951447487, 42.48630300164223, 42.630459666252136, 41.42440818250179, 41.25750593841076, 40.33869244158268, 42.45517127215862, 39.962649419903755, 39.71505090594292, 37.63099193572998, 40.00271447002888, 40.17584078013897, 39.04893524944782, 41.395142152905464, 40.09319521486759, 42.827019318938255, 43.71809810400009, 44.18217860162258, 41.671676114201546, 44.890190809965134, 44.30317550897598, 41.72888584434986, 41.33275330066681, 41.186157166957855, 42.595995515584946, 42.13353753089905, 50.175585597753525, 51.05174258351326, 44.27409566938877, 42.971331775188446, 41.50628238916397, 42.47395746409893, 39.20778952538967, 42.27528512477875, 42.90444776415825, 46.7516653239727, 42.56622411310673, 42.33383998274803, 42.866833582520485, 41.415706649422646, 41.50780990719795, 42.3234361410141, 39.74419914186001, 39.571973383426666, 39.682627245783806, 41.241227611899376, 41.7807150632143, 40.488446205854416, 41.16363577544689, 42.357835695147514, 43.40346738696098, 40.03179810941219, 43.186054453253746, 45.03715172410011, 45.17533890902996, 44.0530539304018, 41.53643757104874, 42.54365332424641, 43.311911299824715, 46.05090692639351, 43.543622866272926, 41.45989067852497, 45.362520664930344, 44.32442396879196, 44.89145614206791, 45.432315319776535, 44.75682556629181, 42.93962627649307, 45.48354037106037, 46.62694841623306, 49.64247800409794, 52.72318169474602, 58.432941511273384, 56.53120815753937, 58.517141193151474, 60.026496201753616, 61.239565908908844, 62.49688804149628, 59.886720702052116, 62.08486095070839, 62.921769842505455, 60.20983636379242, 58.90741065144539, 61.808418184518814, 64.35961648821831, 80.85610449314117, 89.90778118371964, 64.05787467956543, 67.96654254198074, 67.74597957730293, 68.52225512266159, 65.71210071444511, 67.84393832087517, 66.9148425757885, 70.52698194980621, 77.87017911672592, 15.547264739871025, 0.898694823263213, 31.42430618405342, 69.52343299984932, 58.10228705406189, 29.080804735422134, 30.860275849699974, 44.78001952171326, 53.04068885743618, 55.14097675681114, 0.5633076606318355, 0.029512882756534964, 0.11794133693911135, 0.05893117508094292, 0.03971971025748644, 0.05036146969359834, 0.035037058987654746, 0.027711302573152352, 0.053944540122756734, 0.07300682584173046, 0.0796482757141348, 0.004140493374507059, 0.10708426561905071, 0.09272420531488024, 0.10800114454468712, 0.052899098955094814, 0.2033246701466851, 4.718230571597815, 71.24740049242973, 57.19502493739128, 40.67731887102127, 41.30925536155701, 57.301635816693306, 49.23476368188858, 87.93201640248299, 36.65967285633087, 0.2563172945519909, 0.41226193599868566, 23.697329610586166, 88.54835093021393, 69.00702551007271, 77.61661112308502, 69.67454329133034, 74.7663688659668, 65.4604098200798, 64.3236856162548, 58.44044990837574, 62.42558866739273, 68.27288970351219, 66.84310242533684, 66.14888727664948, 63.459991961717606, 62.064216658473015, 61.218325048685074, 61.608951687812805, 62.09545098245144, 62.27748021483421, 62.852773144841194, 64.73876014351845, 64.03116971254349, 61.729329228401184, 59.88989733159542, 55.81890977919102, 53.401673287153244, 48.3586522936821, 48.12336131930351, 48.599551767110825, 46.77574843168259, 52.157688438892365, 54.14562776684761, 52.1130446344614, 50.715411230921745, 47.0442496240139, 47.41422437131405, 49.31976892054081, 47.711995393037796, 48.98413673043251, 45.81544116139412, 47.82766118645668, 44.14016045629978, 47.807214483618736, 46.471320167183876, 46.720351204276085, 44.291498735547066, 42.0485170930624, 44.21660095453262, 43.994350880384445, 42.29379013180733, 41.996847465634346, 41.23173952102661, 40.98926693201065, 40.39680652320385, 43.01637455821037, 45.97808763384819, 43.97576227784157, 46.110354736447334, 48.43561716377735, 46.6906064003706, 44.891391545534134, 47.3918891698122, 46.41447901725769, 45.348708406090736, 45.840778201818466, 43.8017962127924, 45.30627988278866, 44.35221567749977, 52.053251042962074, 53.21089692413807, 47.19138152897358, 47.30951339006424, 45.05314126610756, 45.779438093304634, 42.04743795096874, 45.523658618330956, 46.81960567831993, 47.66513630747795, 44.679294526576996, 46.018908843398094, 47.35725782811642, 44.565346240997314, 44.63094972074032, 44.27270494401455, 42.11724400520325, 42.67601162195206, 41.34911522269249, 42.53310889005661, 42.985941991209984, 43.1046362221241, 41.88424810767174, 45.70052392780781, 45.3447300195694, 43.60835999250412, 45.64397156238556, 45.61742998659611, 48.50946620106697, 45.99059276282787, 42.876059487462044, 44.098890870809555, 45.15733927488327, 48.74591991305351, 47.82584108412266, 46.536817252635956, 47.35529713332653, 47.14480362832546, 47.919118478894234, 48.62572096288204, 47.660800740122795, 45.750077068805695, 48.224147111177444, 48.86598967015743, 52.64870569109917, 55.972900316119194, 61.71147018671036, 60.66227808594704, 61.02782987058163, 63.70889000594616, 62.38038629293442, 65.58248966932297, 63.3793792873621, 65.85139364004135, 64.05447766184807, 60.9345068782568, 61.69775292277336, 62.72901378571987, 69.54740971326828, 86.29336953163147, 86.31321966648102, 70.74161723256111, 70.21966964006424, 72.77675002813339, 70.34186348319054, 71.49631753563881, 70.86857602000237, 71.90336689352989, 73.84229645133018, 83.53126734495163, 17.333413995802402, 0.8054282341618091, 37.431099861860275, 77.27105006575584, 68.07843893766403, 38.668328672647476, 39.07711073756218, 49.921580627560616, 60.56659922003746, 63.1180103123188, 0.5236859398428351, 0.0221135312676779, 0.04243869072524831, 0.027489205604069866, 0.027947830603807233, 0.0785822028410621, 0.04056543948536273, 0.08019808097742498, 0.1358671867637895, 0.27217114227823913, 0.12503723351983353, 0.159551375254523, 0.30286304536275566, 0.15075495117343962, 0.17412090674042702, 0.22964796546148136, 0.4822835692903027, 7.198242545127869, 85.00069409608841, 67.49826326966286, 48.25696215033531, 44.64435160160065, 68.1834577023983, 54.52255234122276, 98.40734750032425, 39.368748888373375, 0.399469388066791, 0.3469747892813757, 31.316718757152557, 92.09424465894699, 72.7730642259121, 84.06171128153801, 73.73787805438042, 76.97651267051697, 69.1346226632595, 69.01938244700432, 57.89399363100529, 62.75074481964111, 71.42155274748802, 70.29650911688805, 69.65242087841034, 67.46201321482658, 64.70363482832909, 62.96704441308975, 65.60825988650322, 66.11474230885506, 65.62766924500465, 64.16972547769547, 65.27250990271568, 67.99522340297699, 65.2911289036274, 63.732623532414436, 59.50883097946644, 56.69029422104359, 52.29250520467758, 51.02842703461647, 49.559596851468086, 49.21629287302494, 55.56510999798775, 56.64892964065075, 54.557746052742004, 52.824837639927864, 49.282101541757584, 50.188972279429436, 51.93833000957966, 51.696172803640366, 52.336362451314926, 47.91842691600323, 49.775235280394554, 45.627286657691, 52.6443625241518, 46.848104149103165, 48.410375118255615, 46.18306763470173, 43.94778057932854, 46.77713915705681, 48.65907937288284, 44.95376519858837, 45.319552570581436, 42.155640944838524, 44.56227220594883, 43.46162706613541, 44.401027858257294, 50.871624648571014, 48.16113509237766, 50.52112005650997, 51.17453299462795, 50.02908065915108, 47.760632783174515, 52.06717349588871, 50.270675495266914, 47.46286176145077, 48.60359475016594, 47.720913514494896, 48.85239399969578, 46.40124812722206, 55.926398411393166, 57.53746256232262, 50.53260684013367, 50.69115713238716, 49.71720479428768, 52.44925819337368, 46.91691845655441, 49.605156406760216, 51.60887248814106, 52.15829640626907, 47.47651442885399, 48.104069754481316, 50.739395543932915, 49.297581911087036, 48.525265753269196, 48.302533105015755, 46.147357150912285, 43.48339609801769, 43.32989953458309, 46.37308783829212, 47.82778277993202, 45.85721991956234, 44.05170500278473, 47.46642217040062, 48.67109812796116, 45.201059728860855, 46.83897323906422, 50.59021934866905, 52.5113582611084, 49.93763856589794, 45.67585565149784, 47.21898324787617, 48.17041799426079, 50.204509645700455, 50.55255576968193, 49.62627187371254, 50.823500230908394, 49.34802420437336, 50.090777948498726, 52.40980491042137, 51.5997301787138, 49.38687711954117, 50.06427437067032, 52.13243119418621, 55.189222767949104, 57.488118410110474, 66.30752876400948, 63.277810737490654, 63.27200084924698, 64.8912687599659, 67.48941734433174, 67.47851192951202, 63.930649906396866, 69.65053617954254, 66.99044331908226, 62.8923974186182, 62.845260947942734, 63.571846559643745, 73.03961232304573, 90.42823165655136, 77.0419679582119, 73.40726539492607, 73.0023743212223, 75.43713927268982, 73.88748362660408, 75.21325528621674, 75.89188367128372, 77.46952101588249, 79.66650232672691, 87.80701071023941, 21.197172068059444, 1.1657048924826086, 41.743682250380516, 86.05820015072823, 74.4493442773819, 45.82409329712391, 42.759094163775444, 63.22421841323376, 68.49298149347305, 73.9536152780056, 0.8370574994478375, 0.0919460115255788, 0.17403379344614223, 0.13985443452838808, 0.1508334110258147, 0.19556562008801848, 0.153842092549894, 0.236162226065062], [0.06864127572043799, 0.1085897492885124, 0.08362466585822403, 0.08499434392433614, 0.05959367175819352, 0.06285740717430599, 0.09159061926766299, 0.044299882065388374, 0.055650548383709975, 1.4461044338531792, 51.75381951034069, 47.70145855844021, 55.471733808517456, 28.682565204799175, 43.34006778895855, 38.95531967282295, 67.6433090865612, 51.777997612953186, 0.9785221272613853, 0.26120665250346065, 4.3068513460457325, 75.32981023192406, 72.562205940485, 70.4097430408001, 68.67579728364944, 65.83047196269035, 61.63692578673363, 53.21150489151478, 61.4937836676836, 63.99200901389122, 61.847753673791885, 64.62795048952103, 59.57353390753269, 61.820296347141266, 59.33044195175171, 62.26799972355366, 59.06872719526291, 61.85488969087601, 63.184958919882774, 64.66828912496567, 60.66143833100796, 57.02575162053108, 58.19097049534321, 59.028316363692284, 55.86109511554241, 48.97347830235958, 46.20050489902496, 44.619018360972404, 47.25816674530506, 51.7029782384634, 53.22229251265526, 53.412761092185974, 52.34259411692619, 50.46963281929493, 46.75573490560055, 45.52708223462105, 46.919012144207954, 50.30104726552963, 49.71878170967102, 45.60811668634415, 46.320525258779526, 42.64559045433998, 44.34833608567715, 44.42057020962238, 46.0040782392025, 44.09814231097698, 43.71739134192467, 41.45607568323612, 39.7619403898716, 41.51370719075203, 40.38800999522209, 39.59272027015686, 41.10092394053936, 40.11179521679878, 39.446234330534935, 39.336959794163704, 39.19398106634617, 40.778921619057655, 43.38424801826477, 44.2113496363163, 42.922211810946465, 41.85084030032158, 43.379741460084915, 43.64538140594959, 44.728900864720345, 42.679097056388855, 44.96337488293648, 38.48063014447689, 50.085743218660355, 50.723770782351494, 43.35762284696102, 42.0285339653492, 42.6907966285944, 42.1487633138895, 43.095182329416275, 43.18139970302582, 41.6798684746027, 43.84526968002319, 43.59964706003666, 41.26645065844059, 44.05953638255596, 40.831085219979286, 41.20739042758942, 40.47690622508526, 39.100080505013466, 39.559118673205376, 39.079550206661224, 40.58222897350788, 41.82931445538998, 42.2692396491766, 41.239665895700455, 39.79757867753506, 42.53768764436245, 42.819868102669716, 42.77100272476673, 43.39627057313919, 46.133301705121994, 41.68800763785839, 41.73554688692093, 43.59398156404495, 49.00495581328869, 48.46427142620087, 46.705961376428604, 41.07800357043743, 44.61209513247013, 46.29961118102074, 47.14666172862053, 47.055846601724625, 46.10359109938145, 44.52243894338608, 43.13440762460232, 45.398177951574326, 47.583873867988586, 52.022776678204536, 56.099266335368156, 59.35282655060291, 60.88714621961117, 58.67216147482395, 62.41368770599365, 61.55146077275276, 62.243472039699554, 62.70661398768425, 65.42523130774498, 62.18362905085087, 62.1306636929512, 56.71254202723503, 60.59172347187996, 57.44568608701229, 98.28369453549385, 74.48560953140259, 69.35931220650673, 70.21917566657066, 68.89771297574043, 67.43714734911919, 67.97071471810341, 67.44965627789497, 70.03478676080704, 73.97698402404785, 8.848290704190731, 0.2530439186375588, 35.8820141851902, 68.51005017757416, 47.0895279943943, 27.54643376916647, 26.159557588398457, 40.59084691107273, 58.439906537532806, 47.57101155817509, 0.20539486140478402, 0.03861588433210272, 0.044557503788382746, 0.013326265288924333, 0.16645276977214962, 0.02635331704368582, 0.0041994950424850686, 0.035171554700355045, 0.03179327250109054, 0.0651402682706248, 0.07995432999450713, 0.05822799386805855, 0.04603719040460419, 0.07034742127871141, 0.030230086849769577, 0.08121910548652522, 0.12280782189918682, 1.4517481997609138, 60.943200811743736, 54.19103913009167, 55.793850123882294, 42.93747939169407, 51.796339228749275, 42.82429866492748, 75.92853650450706, 58.5139037668705, 1.5350911463610828, 0.35255556169431657, 4.255556473508477, 72.43780821561813, 76.78467616438866, 71.6996294260025, 73.464315533638, 68.6811625957489, 66.65573447942734, 56.905693262815475, 65.33068478107452, 68.70393097400665, 63.13872680068016, 67.54051700234413, 62.188865169882774, 63.290931433439255, 61.85849949717522, 63.30397613346577, 61.260909363627434, 63.27501408755779, 64.97349634766579, 66.28909215331078, 62.627965807914734, 58.748784363269806, 60.38184933364391, 60.419976487755775, 59.134239479899406, 50.95092259347439, 48.16013194620609, 46.569324508309364, 49.7706451267004, 54.69937205314636, 56.340655982494354, 56.534703969955444, 54.87953558564186, 52.90807217359543, 48.70721139013767, 46.53180152177811, 49.898067489266396, 53.79217453300953, 53.27247641980648, 48.61486874520779, 48.66468787193298, 45.05773901939392, 46.453730911016464, 46.74324117600918, 46.98506399989128, 45.64836412668228, 44.37611259520054, 42.936730831861496, 43.43241423368454, 44.27312292158604, 41.819039806723595, 41.981222704052925, 43.0724785476923, 41.3026437163353, 41.53282016515732, 42.30792157351971, 43.94094094634056, 46.80138945579529, 47.5690508633852, 46.85003064572811, 45.42554408311844, 43.89378547668457, 44.895955100655556, 45.568207427859306, 45.53130380809307, 45.5763503909111, 49.17696498334408, 43.30377593636513, 53.912403881549835, 53.95469181239605, 45.055565536022186, 45.88796406984329, 46.85702607035637, 45.31907379627228, 44.614663794636726, 44.533705338835716, 45.440674871206284, 45.396069064736366, 46.986481323838234, 45.33922031521797, 46.93584144115448, 43.51397305727005, 42.91273891925812, 41.03088989853859, 42.24421039223671, 40.605677515268326, 40.71949660778046, 43.38851898908615, 41.99426360428333, 45.50273694097996, 43.09702903032303, 41.90915957093239, 43.633567839860916, 46.31046339869499, 45.88207058608532, 44.18935261666775, 47.392029762268066, 44.38010238111019, 43.77546742558479, 46.23827487230301, 51.84102863073349, 51.779506132006645, 48.074716329574585, 44.415239095687866, 46.50163494050503, 49.76710371673107, 50.919517278671265, 50.42951837182045, 47.422857508063316, 46.94741941988468, 47.14398667216301, 47.712257578969, 51.02496922016144, 54.640247225761414, 58.09870004653931, 62.901087552309036, 63.05606223642826, 60.873930528759956, 65.61952248215675, 63.82041782140732, 67.06976026296616, 66.62571609020233, 67.48683348298073, 63.92969995737076, 64.74613174796104, 59.18676786124706, 59.64848108589649, 64.391078799963, 94.0089163184166, 79.01036873459816, 71.85992002487183, 72.72241294384003, 72.65209391713142, 72.64267042279243, 72.057646214962, 73.7045082449913, 74.00042876601219, 76.45338714122772, 8.67104446515441, 0.23087941110134125, 42.521758899092674, 76.13345190882683, 54.14574936032295, 36.158456951379776, 26.932215727865696, 38.40933836996555, 63.941684514284134, 53.31902012228966, 0.2698450139723718, 0.023080427235981915, 0.04046759473567363, 0.03390222613234073, 0.010516587881284067, 0.024615661750431173, 0.042555946347420104, 0.03628580780059565, 0.1537701635970734, 0.16813616850413382, 0.14494316303171217, 0.1294591571786441, 0.15139506838750094, 0.12349835320492275, 0.18596908659674227, 0.1969198021106422, 0.1470623360364698, 2.785963243804872, 74.86506476998329, 62.186129316687584, 71.67455837130547, 40.22629827260971, 62.752975299954414, 49.093525260686874, 83.85891616344452, 62.07682818174362, 1.7050550761632621, 0.455375995952636, 6.3316738698631525, 76.93897068500519, 77.42975234985352, 76.0155214369297, 76.43705561757088, 70.98277509212494, 70.64305052161217, 61.684430837631226, 62.06484742462635, 67.77542039752007, 67.16144934296608, 71.11804783344269, 64.03218045830727, 67.22240567207336, 65.98539724946022, 65.65181314945221, 63.72626647353172, 66.483945697546, 67.32632249593735, 68.63253280520439, 63.94315883517265, 64.40818548202515, 63.08913566172123, 62.10362434387207, 60.50441935658455, 52.41678133606911, 50.524562671780586, 48.7462542951107, 53.07991795241833, 57.12511628866196, 60.78766755759716, 58.503678515553474, 56.908102333545685, 55.155883356928825, 53.10680150985718, 49.898926243186, 51.38642102479935, 54.66477110981941, 55.458681508898735, 51.876697316765785, 52.15598613023758, 48.724971637129784, 48.7862965464592, 50.416557267308235, 51.23180732131004, 48.891330510377884, 47.82002739608288, 47.09600664675236, 43.39161202311516, 47.11320452392101, 44.11263853311539, 43.4896619617939, 46.00708767771721, 44.7114522010088, 42.51271918416023, 46.83711513876915, 46.517753675580025, 51.674023792147636, 49.78418380022049, 50.196731463074684, 46.874729320406914, 47.82651364803314, 49.2330651730299, 51.23507134616375, 50.126313641667366, 49.411571994423866, 53.51479321718216, 45.973117500543594, 55.57275518774986, 57.7425641566515, 47.850611954927444, 48.39599668979645, 51.24950297176838, 51.168780103325844, 51.22956544160843, 48.81840482354164, 47.700478211045265, 48.546153232455254, 50.55694833397865, 46.87081553041935, 50.40882468223572, 48.40309850871563, 46.62437975406647, 46.71226143836975, 43.57125498354435, 43.97593706846237, 44.17410023510456, 45.541639253497124, 45.524129793047905, 48.58880594372749, 45.82607679069042, 44.0840944647789, 46.2958911806345, 48.29679921269417, 49.55407574772835, 48.107911348342896, 50.39005368947983, 47.82855033874512, 45.95916464924812, 49.39159646630287, 54.58448901772499, 53.93323056399822, 50.94402976334095, 46.210806146264076, 49.61513467133045, 52.54318155348301, 52.203669771552086, 51.04532092809677, 48.57061631977558, 49.64161545038223, 49.14432093501091, 50.44481635093689, 53.30210343003273, 58.22888486087322, 60.026511400938034, 65.20534470677376, 65.84198534488678, 62.78838939964771, 67.99563378095627, 65.5450464785099, 69.23876747488976, 69.19715970754623, 68.21403086185455, 68.1626196205616, 65.91846004128456, 61.56293235719204, 59.716151654720306, 69.79007989168167, 93.28519955277443, 75.33867135643959, 76.97110936045647, 77.77922719717026, 76.41532078385353, 76.24208807945251, 77.89517417550087, 78.67167010903358, 77.3769123852253, 81.95963367819786, 12.371013276278973, 0.4028698493493721, 48.63294817507267, 84.25236985087395, 61.727178543806076, 41.90696708858013, 40.10290369391441, 54.67349164187908, 76.92514702677727, 66.69844418764114, 0.6469558377284557, 0.1343425631057471, 0.1848017773590982, 0.1225050404900685, 0.18509047280531377, 0.08673951160744764, 0.10091453965287656, 0.15526596223935485], [0.027369280105631333, 0.05570141518546734, 0.031609320067218505, 0.04720978744444437, 0.058665872129495256, 0.033686409587971866, 0.04260232315573376, 0.056962491071317345, 0.05850804329384118, 0.9383551951032132, 49.81910012662411, 60.00425599515438, 39.19232055544853, 19.23059519380331, 35.3321722894907, 36.54068224132061, 55.75679071247578, 68.69864165782928, 2.8755776351317763, 0.1812253677053377, 0.8165434096008539, 41.26496493816376, 71.15832567214966, 62.841772735118866, 70.5333124101162, 59.72089760005474, 49.244783744215965, 62.611364498734474, 73.38964194059372, 56.79601214826107, 65.91957718133926, 64.55877140164375, 64.91780653595924, 60.025998428463936, 62.60696813464165, 60.69574289023876, 63.10378387570381, 59.86086688935757, 59.88581255078316, 58.022894114255905, 60.12885890901089, 62.53843121230602, 60.71334734559059, 60.44895373284817, 54.04410861432552, 46.25254310667515, 46.43791615962982, 45.366784036159515, 51.79946646094322, 55.420504957437515, 54.01294648647308, 53.22731204330921, 55.20616605877876, 53.07126201689243, 50.2745208889246, 45.994863733649254, 45.66534921526909, 54.29119035601616, 55.71112856268883, 47.01322428882122, 44.058844819664955, 46.57999813556671, 47.271272242069244, 48.13426673412323, 47.587217688560486, 46.443030685186386, 43.068891540169716, 41.4877849817276, 41.17497056722641, 41.17525555193424, 39.934162348508835, 40.26726007461548, 41.04098215699196, 39.68748718500137, 39.03233394026756, 40.397615879774094, 40.22749900817871, 39.3209208548069, 42.36702740192413, 45.00556781888008, 42.75247111916542, 44.459761306643486, 43.88057358562946, 42.28772185742855, 42.779119089245796, 46.704418659210205, 42.517009153962135, 44.69640500843525, 49.1646384447813, 53.53264465928078, 46.307377964258194, 42.5328429043293, 46.04477025568485, 42.02251888811588, 44.048193991184235, 42.65267327427864, 41.35004997253418, 43.122468665242195, 43.11005473136902, 42.955140843987465, 40.33276095986366, 39.318952560424805, 41.05237774550915, 38.522659689188, 39.34892155230045, 38.432802110910416, 40.37338078022003, 40.96058987081051, 43.6294374614954, 37.24454127252102, 40.546206906437874, 43.073238506913185, 39.96486850082874, 43.05768974125385, 44.098180308938026, 44.751232266426086, 47.04460300505161, 42.68465235829353, 44.22972545027733, 49.84111614525318, 55.775345116853714, 50.200360268354416, 44.39543455839157, 45.12630634009838, 47.665706276893616, 50.23424305021763, 53.42166781425476, 52.17008337378502, 50.690636560320854, 48.284430876374245, 46.87673941254616, 43.079283982515335, 47.565349861979485, 51.06889486312866, 56.25697307288647, 58.50717052817345, 61.74988612532616, 59.28428962826729, 59.675110056996346, 60.59087231755257, 64.091806858778, 63.56679283082485, 62.19124384224415, 59.59749162197113, 65.8431176841259, 63.64457845687866, 62.297402545809746, 53.72432537376881, 75.34441664814949, 73.89584317803383, 64.09173846244812, 69.87733080983162, 69.85662952065468, 70.16695886850357, 68.01571950316429, 69.4320023059845, 72.1422752737999, 67.2458428144455, 3.962510973215103, 0.14609383331844583, 47.593092173337936, 67.06377178430557, 43.603758439421654, 34.71954256296158, 54.55643132328987, 48.67149330675602, 57.64132618904114, 38.86029437184334, 0.13200095359934494, 0.035889397040591575, 0.06640766354394145, 0.026988025856553577, 0.013102534667268628, 0.03486481022264343, 0.03233326286135707, 0.024592736808699556, 0.021271099030855112, 0.045269078691489995, 0.01866760416305624, 0.031357817351818085, 0.020147971699771006, 0.040416776173515245, 0.09778159292181954, 0.06306906769168563, 0.057047032823902555, 0.9961107303388417, 58.17401960492134, 67.59651839733124, 39.46843273937702, 19.519626684486866, 43.05298179388046, 40.339057222008705, 65.60461968183517, 75.3193835914135, 3.58490196056664, 0.16831855871714652, 0.8497834915760905, 44.30758327245712, 71.38614624738693, 66.24610126018524, 72.72559717297554, 63.37044596672058, 56.95417106151581, 70.74946761131287, 82.17484652996063, 59.0599724650383, 67.80188217759132, 65.26627823710442, 66.45237699151039, 61.59851364791393, 65.16174584627151, 61.177997812628746, 66.02123692631721, 64.21830967068672, 64.09710377454758, 61.856181621551514, 62.59463779628277, 65.38373753428459, 64.10026520490646, 60.86711369454861, 55.28342351317406, 46.40842214226723, 48.54562886059284, 47.701257169246674, 53.03762622177601, 56.8779319524765, 56.86999037861824, 56.62992686033249, 58.03706735372543, 54.57493253052235, 52.366863414645195, 49.60610635578632, 49.14993703365326, 56.01193942129612, 57.180612310767174, 50.72955407202244, 46.930099949240685, 48.77630688250065, 50.36755509674549, 49.85120840370655, 49.70016650855541, 48.603530153632164, 45.616647228598595, 41.87012046575546, 42.581829875707626, 43.511738777160645, 43.60970892012119, 42.39026315510273, 43.551108464598656, 42.22283273935318, 41.43600896000862, 44.028343856334686, 44.409611597657204, 44.005111902952194, 45.17333261668682, 48.14225010573864, 45.78390285372734, 43.755256310105324, 46.67780488729477, 44.38360579311848, 45.85951119661331, 52.21102997660637, 48.514383137226105, 47.59110867977142, 52.181794345378876, 56.83404050767422, 47.56370835006237, 48.308407589793205, 48.369968086481094, 46.91832818090916, 45.866210237145424, 46.58372573554516, 45.32088249921799, 46.257547438144684, 46.108006462454796, 44.9630519002676, 43.64198058843613, 42.959206625819206, 43.51126380264759, 42.056606858968735, 41.888378486037254, 40.13587832450867, 42.817345038056374, 42.73294396698475, 45.20134471356869, 39.85950015485287, 42.21559412777424, 45.19498385488987, 43.658118322491646, 44.826289638876915, 44.38799075782299, 45.08765481412411, 49.72738824784756, 46.33067451417446, 46.287322640419006, 52.23718777298927, 59.37417760491371, 54.357371404767036, 48.752242773771286, 47.386463060975075, 49.486465975642204, 52.72268772125244, 56.648933440446854, 55.60736373066902, 52.69113041460514, 51.86028979718685, 50.4110399633646, 45.69784887135029, 50.47265745699406, 54.4135057926178, 57.642884105443954, 61.420778185129166, 65.32328277826309, 61.4702021330595, 61.39906994998455, 64.7935988008976, 66.7087796330452, 66.41544297337532, 65.04069954156876, 62.47527860105038, 67.22004979848862, 66.52558386325836, 62.70496487617493, 58.22531685233116, 75.83065375685692, 75.86337000131607, 67.38930031657219, 72.09067404270172, 73.17846447229385, 75.05394503474236, 71.92053437232971, 76.7710728943348, 75.54648220539093, 70.40478050708771, 3.315098388120532, 0.14538625488057733, 55.495186150074005, 73.3471754193306, 53.072010576725006, 35.98492406308651, 46.81810475885868, 51.52564935386181, 64.96274292469025, 46.67758069932461, 0.4448617820162326, 0.04569260752759874, 0.04672963645134587, 0.06047482369467616, 0.07973806074005552, 0.08113754345686175, 0.022065876109991223, 0.07878472752054222, 0.13927254622103646, 0.18258815864101052, 0.20466034300625324, 0.1053693775611464, 0.11292237773886882, 0.15822953602764755, 0.33872537256684154, 0.13742287672357634, 0.19776196160819381, 2.058402984403074, 70.53540989756584, 75.71128696203232, 54.263463243842125, 26.659489162266254, 50.89451842010021, 52.13881105184555, 73.71618881821632, 81.9366905093193, 4.189628586173058, 0.2615982393035665, 1.7878474085591733, 51.08244873583317, 73.8246501982212, 66.80890426039696, 75.92177286744118, 67.9807461798191, 63.32112081348896, 64.29643347859383, 73.66064339876175, 63.22474278509617, 72.60129064321518, 69.89876165986061, 67.47876271605492, 64.15095448493958, 67.26343587040901, 67.51703426241875, 69.45154085755348, 65.04637643694878, 65.29186606407166, 65.4424823820591, 65.16819790005684, 66.7641730606556, 65.23414716124535, 64.59612339735031, 58.78116622567177, 50.25799937546253, 50.05161724984646, 50.5211428552866, 56.728512570261955, 60.64091943204403, 58.09244178235531, 59.237388744950294, 59.42395493388176, 57.07864858210087, 54.506030827760696, 53.61102305352688, 52.125918343663216, 58.96989069879055, 62.26873308420181, 52.24232889711857, 49.71835233271122, 50.63245788216591, 53.25788900256157, 52.11417317390442, 53.55863146483898, 52.47142620384693, 47.971076890826225, 46.27980664372444, 43.984061032533646, 44.66694138944149, 46.362516805529594, 45.16806609928608, 45.876697674393654, 45.997060015797615, 44.14804123342037, 47.92272448539734, 48.250920474529266, 48.57236422598362, 51.58340625464916, 52.34044723212719, 47.24850386381149, 47.43264198303223, 49.98075485229492, 48.792923390865326, 51.48434177041054, 58.547619357705116, 50.950835198163986, 48.13932806253433, 54.2722749710083, 58.09578560292721, 52.35586300492287, 52.82046027481556, 54.02602918446064, 50.74051268398762, 50.0980431586504, 49.71282362937927, 50.32412342727184, 50.05576282739639, 48.7987294793129, 48.99026580154896, 47.11574658751488, 45.77993966639042, 46.50500915944576, 43.956653103232384, 44.26209971308708, 40.740273892879486, 44.53280858695507, 45.94347529113293, 46.58882886171341, 42.199444994330406, 44.54083755612373, 46.878358125686646, 44.330173060297966, 50.03152392804623, 47.35221549868584, 47.68237218260765, 51.92949168384075, 48.29336799681187, 50.59836991131306, 55.63350632786751, 63.835009038448334, 57.54989929497242, 50.183268785476685, 51.193022802472115, 51.92323341965675, 55.069008618593216, 59.58251662552357, 58.32766816020012, 54.870286881923676, 53.69380921125412, 53.16361986100674, 49.307837560772896, 53.829917907714844, 57.71257236599922, 61.02208077907562, 65.25986418128014, 67.78987482190132, 64.00447994470596, 64.60724920034409, 67.06952467560768, 70.21129488945007, 69.83044132590294, 67.10666388273239, 65.11194571852684, 69.15033861994743, 66.73654094338417, 63.282537683844566, 57.059395015239716, 81.7080719769001, 75.40807083249092, 69.84082996845245, 76.27386197447777, 75.47709792852402, 77.93583959341049, 74.28349077701569, 80.11889085173607, 79.23068091273308, 77.74283275008202, 5.51748538389802, 0.23757797665894032, 62.27612368762493, 82.60702773928642, 62.582303658127785, 49.072755575180054, 73.04437726736069, 70.85903853178024, 76.42477467656136, 60.56172788143158, 0.6935024494305253, 0.11853932242956944, 0.2468203127500601, 0.139195941737853, 0.14116871869191527, 0.14918977656634524, 0.07496884165448137, 0.12327696313150227], [0.03180165876983665, 0.08357666374649853, 0.06391402508597821, 0.039428380187018774, 0.06146827741758898, 0.041341180476592854, 0.048209935339400545, 0.0843161842203699, 0.03711412624397781, 0.2890209818724543, 47.192852050065994, 58.6982698738575, 56.94542773067951, 49.99653920531273, 37.81360253691673, 39.487279728055, 49.74454052746296, 74.11848843097687, 15.043578017503023, 0.0709575779910665, 0.3381525829900056, 17.767578698694706, 59.777290374040604, 65.56306511163712, 61.99335426092148, 61.249145194888115, 57.91053034365177, 63.263918682932854, 48.1052552908659, 61.54571548104286, 66.41694009304047, 65.36576449871063, 64.89645168185234, 60.65025933086872, 62.155423164367676, 64.05915141105652, 65.3761151432991, 57.253416404128075, 58.306089118123055, 60.93744032084942, 62.60059967637062, 59.87523391842842, 59.6642692387104, 56.501527950167656, 48.06219980120659, 42.696298733353615, 43.6676824092865, 46.77410311996937, 57.496052384376526, 59.85088102519512, 56.66999951004982, 55.34960076212883, 57.52588838338852, 54.724173322319984, 51.16512469947338, 43.779688999056816, 46.63616292178631, 56.82097300887108, 53.30508626997471, 49.44548137485981, 48.10876250267029, 45.82186281681061, 51.07931390404701, 47.49210499227047, 45.86939826607704, 45.2337683737278, 41.64698123931885, 40.705870538949966, 39.3945837020874, 38.92739497125149, 39.17141407728195, 41.05143539607525, 39.001354202628136, 39.388952404260635, 40.997451692819595, 42.00029008090496, 38.81744787096977, 40.84052391350269, 39.20743614435196, 44.58716467022896, 46.52593083679676, 45.365454107522964, 43.35935935378075, 41.79450832307339, 42.46222749352455, 42.13228739798069, 44.10202570259571, 47.51853257417679, 49.46086294949055, 49.32916581630707, 49.731682017445564, 46.53802178800106, 45.306097492575645, 45.278552770614624, 43.43689799308777, 44.188125282526016, 42.871480733156204, 42.4001008272171, 43.0573021620512, 43.6178594827652, 39.72081899642944, 40.161215364933014, 38.29869590699673, 41.093803122639656, 39.192939922213554, 37.029772996902466, 38.06609898805618, 38.11944432556629, 40.10739125311375, 42.80145809054375, 41.509664207696915, 42.87974528968334, 43.44223290681839, 42.89410851895809, 44.51615408062935, 46.62425436079502, 46.74354135990143, 43.37425835430622, 44.33478221297264, 56.033875644207, 54.119287580251694, 50.02633720636368, 43.79285529255867, 47.66488552093506, 49.11102332174778, 50.917108207941055, 55.548086911439896, 54.96901698410511, 55.536759719252586, 52.44656793773174, 47.68369071185589, 44.4891869276762, 43.158312141895294, 47.64139138162136, 51.18738770484924, 57.597453743219376, 58.024129047989845, 59.95855964720249, 58.18068444728851, 61.233144253492355, 60.93100726604462, 62.205930054187775, 61.82587444782257, 66.37192770838737, 61.82662680745125, 67.95796260237694, 63.15101534128189, 60.54684408009052, 66.8049068748951, 65.52159413695335, 63.62195447087288, 65.90838298201561, 65.75816184282303, 72.22130343317986, 69.32156503200531, 70.33614099025726, 71.38846412301064, 55.86513049900532, 0.5526719719637185, 3.183257100172341, 53.7485034763813, 65.82602620124817, 41.14201493561268, 62.19824306666851, 90.5672661960125, 32.64025613665581, 61.64055839180946, 25.25058176368475, 0.2099070153781213, 0.06975022246479057, 0.0884094180946704, 0.06798166228691116, 0.06336937032756396, 0.0860924924199935, 0.0370592629769817, 0.04844599767238833, 0.03642150208179373, 0.06996314463322051, 0.07067945814924315, 0.06788693455746397, 0.013273048662085785, 0.01380298755975673, 0.02229916466603754, 0.0652222681674175, 0.02342490064620506, 0.4945766815217212, 54.54792357981205, 63.552775382995605, 60.94869911670685, 47.268631383776665, 40.24753153324127, 42.622723281383514, 53.81593465805054, 84.85785216093063, 18.41309566050768, 0.07368251419393346, 0.17910334485350177, 20.086995139718056, 64.94164645671844, 68.33891496062279, 65.86831033229828, 65.38224041461945, 66.1265216767788, 71.31983980536461, 53.49316097795963, 62.994786724448204, 70.53610146045685, 66.78080096840858, 66.27640843391418, 63.34725581109524, 65.29391035437584, 65.86416095495224, 66.60288691520691, 59.791782796382904, 59.73214499652386, 62.019162476062775, 63.95767405629158, 63.01072686910629, 62.762049213051796, 58.84322069585323, 51.548892706632614, 47.521086037158966, 45.44521562755108, 50.67758806049824, 61.652580946683884, 61.95570968091488, 60.931957215070724, 55.426687225699425, 59.88219514489174, 57.570896968245506, 55.16345255076885, 47.677626237273216, 48.031239062547684, 57.338379845023155, 55.45672461390495, 52.65296146273613, 50.87282918393612, 50.067846179008484, 52.38131403923035, 49.565220549702644, 50.672758519649506, 47.80887119472027, 43.14815528690815, 44.07400980591774, 42.11244486272335, 42.9839850962162, 41.030859500169754, 44.10181291401386, 42.317694649100304, 43.42591658234596, 43.32789704203606, 45.11828497052193, 41.69481687247753, 44.00198847055435, 41.58224031329155, 46.58570542931557, 47.9304076731205, 47.00432136654854, 46.67709432542324, 46.63987532258034, 45.905142948031425, 46.375329717993736, 45.23408755660057, 51.00305579602718, 51.58593691885471, 50.934351682662964, 51.10364779829979, 49.36157047748566, 48.03180903196335, 47.90522642433643, 46.49832911789417, 47.453597858548164, 44.76752579212189, 44.92922231554985, 44.677801206707954, 44.356900826096535, 42.82590977847576, 43.80556561052799, 40.35925313830376, 43.35388004779816, 41.16066053509712, 39.05115433037281, 40.86684890091419, 40.981963723897934, 42.40376763045788, 44.57571968436241, 43.388830572366714, 43.27430471777916, 43.96031990647316, 45.665706396102905, 47.36942857503891, 49.46797996759415, 48.300158232450485, 45.82160443067551, 46.57077983021736, 58.7372899800539, 54.59113486111164, 51.993267461657524, 46.991120874881744, 49.74675580859184, 52.51886285841465, 54.971224665641785, 58.14982630312443, 58.15970577299595, 58.61443877220154, 55.47535501420498, 50.87694816291332, 47.872916758060455, 44.276379346847534, 50.56147389113903, 54.983718395233154, 61.763288006186485, 61.47212103009224, 62.29708716273308, 60.11793069541454, 62.62796960771084, 60.86416885256767, 64.90774467587471, 64.2412680387497, 70.13631731271744, 63.86343151330948, 69.6333459019661, 65.31391248106956, 62.84277968108654, 67.11847364902496, 67.47988745570183, 65.50900161266327, 66.73046886920929, 69.43696483969688, 75.19763812422752, 71.37454926967621, 74.91316258907318, 76.85814142227173, 56.533222049474716, 0.5144074314739555, 3.9926020335406065, 63.047474697232246, 72.99950927495956, 49.60115522146225, 74.0547202527523, 101.04985490441322, 40.210943296551704, 72.50403866171837, 33.24598163366318, 0.24955478555057198, 0.07719095796346664, 0.11471489444375038, 0.036932452203473076, 0.029439493628160562, 0.08130866786814295, 0.002203327449024073, 0.04549738558125682, 0.19291397096822038, 0.22844714083475992, 0.4090723633999005, 0.14055447274586186, 0.2352737565524876, 0.099927624250995, 0.14210001012543216, 0.3085511620156467, 0.1801585897919722, 1.0539278341457248, 68.67022678256035, 78.29751178622246, 72.04911187291145, 62.947547659277916, 54.80628691613674, 51.553722247481346, 63.542827516794205, 87.18659520149231, 20.268357507884502, 0.20210860180668533, 0.5322247347794473, 24.985948763787746, 70.6381943821907, 71.5055738389492, 73.54816943407059, 70.79145535826683, 62.244330793619156, 58.43178257346153, 59.282013550400734, 67.58579537272453, 72.08280086517334, 69.89474907517433, 71.68374627828598, 66.10904261469841, 71.00108250975609, 67.10946053266525, 70.94616025686264, 61.27334229648113, 63.02345238626003, 65.6199936568737, 66.26463666558266, 65.46592712402344, 64.69366416335106, 61.13265484571457, 54.07574191689491, 46.90497949719429, 48.22754792869091, 52.74281904101372, 64.45499897003174, 63.29686291515827, 61.62895381450653, 57.68034629523754, 64.08152461051941, 62.57814288139343, 57.33709931373596, 51.02898560464382, 50.122703835368156, 60.71064189076424, 58.66504445672035, 56.210330575704575, 53.95643591880798, 51.82167246937752, 56.156582459807396, 54.124595895409584, 53.514025658369064, 47.961189821362495, 46.73824444413185, 45.67441172897816, 43.71554084122181, 44.35720480978489, 42.708389684557915, 45.670292750000954, 44.1153097897768, 44.87851403653622, 47.39061623811722, 48.612645864486694, 45.467216446995735, 48.63315336406231, 46.23968079686165, 49.46814715862274, 53.04269514977932, 50.411309748888016, 51.28732994198799, 49.08318601548672, 50.41117675602436, 49.12944093346596, 48.995855301618576, 54.406745955348015, 54.64948832988739, 53.47635827958584, 53.539579287171364, 53.43393735587597, 53.453760892152786, 53.639000952243805, 50.543436259031296, 49.8200348764658, 45.68298026919365, 49.243324622511864, 48.92055854201317, 48.26513551175594, 45.74530452489853, 46.06029622256756, 45.92352256178856, 46.550553515553474, 45.8106230199337, 42.51161724328995, 44.597598910331726, 40.619577169418335, 44.03627783060074, 46.730675250291824, 47.498747035861015, 46.91361263394356, 47.434997856616974, 48.58705423772335, 50.9711717069149, 51.20316065847874, 54.07493636012077, 48.16441811621189, 50.01993454992771, 60.87014213204384, 58.42730641365051, 54.49283793568611, 49.490299969911575, 52.53360226750374, 54.05613496899605, 55.49235910177231, 60.9622947871685, 60.06467655301094, 60.26312470436096, 57.86994852125645, 54.29392620921135, 49.85820762813091, 46.25448100268841, 53.06912653148174, 56.88694506883621, 64.81930062174797, 64.52182978391647, 65.4371702671051, 61.80980131030083, 65.05523756146431, 63.08643780648708, 69.46575209498405, 68.35903108119965, 73.19905176758766, 67.74034827947617, 73.2735201716423, 68.10212686657906, 61.754772663116455, 73.25905814766884, 73.10645073652267, 64.92479056119919, 70.22575691342354, 70.74282556772232, 77.90693074464798, 74.15090069174767, 79.64603662490845, 78.56729730963707, 66.1351852118969, 0.5614516977220774, 3.522739908657968, 72.23095491528511, 81.89667865633965, 60.32711707055569, 82.71482035517693, 109.06512200832367, 47.923347651958466, 87.6959502696991, 46.920668855309486, 0.5303747090511024, 0.14100430329563096, 0.2035835906281136, 0.17557303741341457, 0.22036644397303462, 0.19768044410739094, 0.18356767483055592, 0.13711524166865274], [0.03983926653745584, 0.04478087168536149, 0.06268967437790707, 0.07854082810808904, 0.13817826431477442, 0.03711093500896823, 0.05895551752473693, 0.08363827684661373, 0.02368632958678063, 0.13747963617788628, 27.203386276960373, 60.045008808374405, 40.7717590034008, 30.413545221090317, 55.8438478410244, 34.67997908592224, 46.6826344281435, 62.8608401119709, 35.11003240942955, 0.08777554234256968, 0.17132189677795395, 4.683481911197305, 36.369904205203056, 57.30212599039078, 56.78701803088188, 61.34155623614788, 28.21094211190939, 30.849953703582287, 54.283339977264404, 66.93622022867203, 68.22300598025322, 67.46851086616516, 61.737080812454224, 59.781397953629494, 67.17031806707382, 62.78796762228012, 57.62048050761223, 62.012174651026726, 60.406829193234444, 59.78761442005634, 59.130447283387184, 57.749817967414856, 54.87394608557224, 46.740528121590614, 43.19977931678295, 46.50442399084568, 45.075852647423744, 53.43543067574501, 60.40753595530987, 57.79600828886032, 53.311625719070435, 58.59034426510334, 59.61720496416092, 52.956329584121704, 51.84992395341396, 48.5696891695261, 48.497945219278336, 51.07246287167072, 53.90175685286522, 51.74584373831749, 49.809923619031906, 47.230249643325806, 46.547414883971214, 48.63517105579376, 50.1518938690424, 45.687916204333305, 42.851603999733925, 42.998196333646774, 39.8979464918375, 38.35520267486572, 41.62888281047344, 39.964879900217056, 40.05664877593517, 41.158194467425346, 38.08126777410507, 39.16652373969555, 40.57300686836243, 38.58050778508186, 38.70451033115387, 39.765629991889, 45.523529425263405, 46.4285496622324, 46.97705402970314, 45.40557995438576, 44.89549532532692, 42.80024975538254, 49.95727591216564, 50.64484901726246, 50.516081526875496, 49.12903055548668, 56.50106817483902, 51.878403425216675, 45.42905509471893, 45.207644775509834, 43.98621551692486, 44.33175377547741, 47.859290689229965, 44.86451558768749, 43.03008422255516, 40.77427066862583, 41.97182960808277, 41.08547396957874, 40.925874933600426, 39.80947203934193, 41.32518030703068, 39.974816367030144, 40.224124789237976, 40.249488428235054, 41.43600516021252, 39.664069041609764, 37.91471131145954, 41.597507894039154, 46.15341402590275, 43.14659357070923, 46.70385628938675, 44.76225547492504, 49.93240624666214, 46.545374393463135, 48.625173792243004, 53.791357576847076, 51.72963000833988, 48.0604062974453, 45.658520981669426, 48.524638786911964, 50.96238657832146, 55.31189538538456, 58.516841009259224, 55.251170843839645, 58.1871896982193, 57.85040996968746, 53.599623665213585, 47.996220141649246, 43.322596326470375, 44.8868165910244, 47.310185953974724, 54.46644075214863, 56.02004058659077, 59.21896353363991, 58.332794085145, 62.60121524333954, 60.29261872172356, 60.239854753017426, 59.97973211109638, 62.23760135471821, 61.191251501441, 65.29513388872147, 65.23212566971779, 65.96040979027748, 61.56844586133957, 61.760844737291336, 69.71877291798592, 65.40942415595055, 69.78439539670944, 67.14986756443977, 71.5141461789608, 67.36460164189339, 75.59980854392052, 33.040397465229034, 0.5250028660520911, 6.438170280307531, 63.78783077001572, 58.2972963899374, 40.989973694086075, 30.291843451559544, 22.781611047685146, 36.347299218177795, 51.28162644803524, 23.44954300671816, 0.6242758641019464, 0.05632812550175004, 0.10379190556704998, 0.07325237282202579, 0.0600500369182555, 0.04191138366877567, 0.11170555240823887, 0.04110694382688962, 0.05170341370103415, 0.1289699928020127, 0.025162481724692043, 0.0345789386483375, 0.09374054687214084, 0.03635223372839391, 0.026108443562407047, 0.01959771558176726, 0.07379328715614974, 0.0880266034801025, 36.207326129078865, 69.52970266342163, 49.225875958800316, 34.80011723935604, 67.444708943367, 40.99580258131027, 53.03943112492561, 67.99999594688416, 42.22095184028149, 0.12390728399623185, 0.14402058441191912, 5.013435306027532, 38.484802320599556, 60.262433141469955, 61.76771096885204, 64.0678833425045, 33.489172384142876, 37.12134428322315, 58.102378249168396, 69.21367362141609, 68.68578314781189, 68.76822352409363, 65.45095592737198, 62.52982847392559, 69.03953656554222, 65.94141080975533, 59.95325893163681, 62.5813765078783, 63.225776329636574, 63.85433480143547, 60.90139165520668, 61.67481355369091, 58.11123937368393, 49.40959230065346, 47.4887839704752, 46.51921659708023, 47.520554065704346, 55.6864944845438, 61.67852595448494, 57.856774628162384, 55.26439033448696, 60.88226728141308, 59.431797713041306, 56.553706750273705, 54.622961953282356, 51.157251521945, 50.3706519305706, 53.40845212340355, 57.91914448142052, 53.6560620367527, 50.7725677639246, 50.83716429769993, 50.51178015768528, 49.9855387955904, 52.275793701410294, 47.52816505730152, 44.29623708128929, 45.450109764933586, 41.785700395703316, 41.26645065844059, 41.1600411683321, 41.713264882564545, 41.97282895445824, 43.74778591096401, 40.59839330613613, 41.85347355902195, 43.58489245176315, 43.20164501667023, 42.443433701992035, 43.790191635489464, 48.53952258825302, 49.61682938039303, 50.306040197610855, 46.6317817568779, 47.44203507900238, 45.47695532441139, 49.368102326989174, 54.35325622558594, 49.9923138320446, 49.56532694399357, 57.912050262093544, 53.254643976688385, 47.20253773033619, 47.524224668741226, 46.35277032852173, 47.59860187768936, 49.11895729601383, 46.42905503511429, 46.692095920443535, 44.03649061918259, 45.51862008869648, 43.13025064766407, 44.466722533106804, 41.82616822421551, 42.60851964354515, 43.20338152348995, 41.41654260456562, 41.4083768427372, 42.59655028581619, 42.20925226807594, 41.307401061058044, 42.647102773189545, 46.43313981592655, 44.89132694900036, 49.03106801211834, 48.72695133090019, 53.31408418715, 48.88409949839115, 51.53384931385517, 56.18749760091305, 54.60849992930889, 49.65439036488533, 48.3950999379158, 52.80698619782925, 52.99197167158127, 58.6077169328928, 58.96988309919834, 58.20488154888153, 60.65081030130386, 61.52723327279091, 57.475985661149025, 51.53569221496582, 46.80821768939495, 47.4410205334425, 50.47458775341511, 56.298877224326134, 58.790680915117264, 60.61066545546055, 59.714665934443474, 61.71378046274185, 61.15275576710701, 62.19025209546089, 61.61492116749287, 65.01469373703003, 64.57777038216591, 67.03901991248131, 69.56707745790482, 66.25500038266182, 62.57886864244938, 63.420158699154854, 71.99987411499023, 69.44942057132721, 72.78767064213753, 69.2159155011177, 75.31110003590584, 72.30587169528008, 78.0962061882019, 30.33919271081686, 0.5321085441391915, 9.095309749245644, 74.50383335351944, 64.17758345603943, 48.34178499877453, 36.61645017564297, 35.593685656785965, 43.47512014210224, 62.62221671640873, 37.64432542026043, 1.0125993518158793, 0.08835332657326944, 0.10361825043219142, 0.04137057323532645, 0.04014114623714704, 0.052542044286383316, 0.028554128148243763, 0.01774609052517917, 0.14115243597188964, 0.2789693931117654, 0.1426555373473093, 0.17848803021479398, 0.2627665875479579, 0.19556263665435836, 0.11798363935668021, 0.11752443548175506, 0.15451434475835413, 0.332666567992419, 46.1554317176342, 77.12107971310616, 54.2181620746851, 38.73803973197937, 73.69689345359802, 49.83919344842434, 59.220924228429794, 75.34684851765633, 43.258763551712036, 0.5348129302728921, 0.26508179144002497, 6.87583839520812, 47.63544850051403, 66.81069016456604, 66.98801144957542, 68.1289154291153, 30.18599823117256, 45.24472698569298, 62.84122556447983, 70.16631290316582, 74.69651341438293, 72.52924650907516, 69.63431105017662, 64.82357919216156, 70.43387934565544, 68.46716567873955, 63.53967748582363, 64.57840114831924, 64.27834644913673, 64.81406450271606, 65.9336744248867, 63.93384173512459, 60.64304731786251, 53.25031980872154, 48.50848205387592, 51.65352389216423, 48.522605895996094, 57.720574736595154, 65.02783343195915, 60.60613229870796, 58.74953672289848, 63.82742464542389, 64.27516981959343, 59.81898933649063, 58.74098718166351, 53.720069602131844, 55.042322650551796, 56.408075764775276, 60.26785545051098, 58.30234631896019, 56.0227270424366, 53.47840256989002, 52.839098274707794, 54.87364210188389, 55.704205334186554, 50.60693085193634, 48.76929245889187, 47.08605118095875, 44.137230813503265, 41.97309114038944, 45.20535729825497, 44.05999235808849, 46.55493088066578, 45.800671353936195, 44.704316183924675, 44.63646702468395, 46.88716985285282, 44.973182156682014, 45.735371857881546, 47.74185039103031, 53.168137818574905, 52.464157193899155, 51.48415558040142, 48.95372316241264, 50.70471480488777, 47.63118892908096, 55.46606831252575, 56.76729328930378, 52.74021238088608, 53.29355388879776, 60.20331211388111, 55.56094542145729, 50.56934706866741, 52.39344298839569, 49.365495666861534, 49.93496730923653, 54.03547167778015, 50.402938798069954, 47.95731022953987, 50.74836306273937, 50.64779385924339, 47.407608926296234, 48.3583977073431, 46.249214485287666, 46.86984658241272, 42.59465038776398, 44.284054934978485, 46.54488421976566, 45.86897648870945, 44.11845602095127, 42.35416129231453, 46.63515977561474, 48.66261698305607, 47.04321227967739, 52.483794540166855, 51.46280072629452, 56.53023160994053, 52.52567209303379, 55.925608053803444, 58.01325783133507, 57.72516489028931, 53.8338278979063, 51.063031777739525, 54.77792143821716, 55.602298602461815, 60.846788585186005, 61.58595912158489, 59.296042397618294, 63.41209553182125, 64.49970737099648, 60.698026567697525, 53.56373839080334, 49.217770993709564, 50.10986812412739, 54.05121423304081, 59.932314455509186, 61.727151945233345, 62.04089730978012, 62.46307745575905, 65.80811396241188, 66.94436699151993, 65.62988072633743, 65.17411798238754, 68.44712555408478, 67.12950065732002, 69.75553214550018, 72.51036152243614, 65.36232188344002, 70.98823919892311, 71.30571976304054, 73.45838025212288, 73.06626409292221, 74.39562276005745, 74.175546169281, 78.86795997619629, 76.77763134241104, 83.74458029866219, 41.421246752142906, 0.6097997690085322, 9.453259091824293, 84.1017535328865, 72.47564658522606, 57.56759114563465, 45.670292750000954, 34.45251189172268, 51.06775492429733, 75.17839595675468, 47.40902245044708, 1.171725313179195, 0.18950231809867546, 0.278043519356288, 0.16936656029429287, 0.21839820896275342, 0.100855924829375, 0.20028716360684484, 0.15980792086338624], [0.03502185980323702, 0.08669187314808369, 0.046406820765696466, 0.023461456985387485, 0.06792325526475906, 0.07953784413984977, 0.028510796000773553, 0.09560225400491618, 0.12385652851662599, 0.15426002559252083, 41.37737810611725, 56.63224473595619, 54.61866818368435, 41.80443339049816, 43.14318895339966, 37.63379618525505, 44.63216185569763, 65.07729917764664, 51.018672958016396, 1.6800826974213123, 0.045838573132641613, 0.30096394883003086, 10.284550935029984, 43.839816972613335, 40.99930979311466, 62.410431280732155, 35.763027369976044, 51.63862869143486, 59.100041314959526, 63.08745235204697, 61.543257012963295, 63.635078966617584, 61.25541865825653, 66.90348118543625, 56.97347782552242, 58.50656256079674, 63.13844561576843, 65.1113149523735, 61.55188634991646, 60.25601148605347, 58.41042771935463, 50.97654081881046, 47.126978784799576, 46.65796995162964, 45.64266063272953, 44.68643434345722, 50.29607713222504, 57.306780740618706, 60.86009547114372, 56.11883528530598, 56.05371817946434, 58.8590582460165, 57.138981744647026, 55.69067806005478, 50.24781212210655, 52.75907836854458, 46.65791675448418, 52.76080347597599, 55.99284164607525, 52.86235682666302, 51.9465147703886, 48.6116199195385, 45.47238416969776, 48.22887025773525, 49.64812450110912, 46.13283433020115, 43.147995695471764, 40.471928492188454, 38.7457001209259, 39.697359055280685, 40.58822125196457, 41.2305311858654, 41.85896806418896, 40.44210769236088, 40.2365767210722, 39.857311472296715, 37.96058624982834, 41.221556067466736, 39.099590331315994, 39.429906606674194, 43.54865379631519, 46.01982079446316, 45.746569857001305, 48.347613885998726, 46.9712745398283, 49.9627286195755, 50.96056267619133, 54.49530780315399, 49.05522331595421, 48.24267491698265, 56.3027074187994, 57.09675081074238, 50.6841617077589, 47.75315098464489, 47.22044996917248, 47.60219648480415, 47.61776424944401, 43.80223698914051, 40.90269237756729, 41.54715299606323, 38.31386849284172, 39.77769814431667, 38.42833735048771, 40.35833738744259, 40.354887172579765, 40.54720625281334, 39.9856723845005, 40.56301720440388, 39.83264699578285, 41.979961171746254, 40.51995411515236, 42.06574536859989, 42.253964468836784, 47.94922426342964, 47.69034415483475, 49.41539838910103, 47.940222546458244, 47.4508848041296, 52.692977115511894, 51.4708448946476, 52.64809392392635, 48.08303028345108, 45.49686625599861, 51.653793677687645, 52.02734023332596, 57.57554791867733, 57.00143292546272, 57.10880756378174, 58.06495025753975, 58.42794857919216, 59.642310217022896, 53.025292083621025, 49.02326323091984, 45.643204003572464, 44.67640668153763, 47.04825080931187, 49.9920554459095, 52.978205010294914, 54.24045167863369, 56.653257608413696, 55.51106929779053, 57.86617532372475, 55.73144227266312, 59.83220882713795, 59.55920107662678, 64.61070701479912, 63.79869058728218, 66.71649321913719, 52.99708999693394, 63.13760206103325, 67.10876137018204, 66.80940583348274, 66.20123326778412, 69.08207148313522, 67.07889497280121, 69.78588491678238, 62.735800221562386, 10.465338584035635, 0.8686576131731272, 12.057181466370821, 65.42349100112915, 58.386952579021454, 38.38612921535969, 38.511754274368286, 35.0466214120388, 44.151267260313034, 52.49470375478268, 33.58181521296501, 1.8883776641450822, 0.007903495188656962, 0.1324073239811696, 0.04348864786152262, 0.0269012854914763, 0.05949950063950382, 0.0248823450965574, 0.025319848573417403, 0.015072725236677798, 0.05212365482293535, 0.06031768505636137, 0.04817481691134162, 0.022900988915353082, 0.05476103615364991, 0.03455531237705145, 0.04763757620821707, 0.019538427259249147, 0.09086428675800562, 50.056708976626396, 64.25414174795151, 53.84281441569328, 46.10824204981327, 52.63713911175728, 43.397345915436745, 53.509070724248886, 66.32031127810478, 54.952685460448265, 1.971547482535243, 0.22235033829929307, 0.24624600919196382, 8.366864137351513, 49.489141032099724, 49.88837420940399, 65.08154734969139, 39.40925091505051, 56.410279646515846, 60.654705092310905, 64.94603142142296, 62.90445797145367, 65.91999515891075, 64.46272775530815, 69.56979051232338, 61.60604104399681, 59.91225153207779, 65.25235578417778, 67.22581788897514, 64.12719056010246, 62.10410311818123, 62.51233421266079, 54.71744768321514, 48.77644747495651, 49.632674530148506, 47.47439794242382, 48.31292174756527, 53.216965198516846, 61.820877715945244, 62.01462171971798, 57.78432011604309, 57.14448764920235, 61.37912482023239, 60.19504755735397, 57.977129369974136, 53.28531213104725, 55.073063001036644, 48.93442399799824, 54.44062873721123, 58.63744653761387, 55.768262296915054, 56.6211911290884, 53.504662960767746, 49.243890792131424, 52.12051123380661, 50.69251365959644, 48.45961667597294, 47.16690704226494, 43.13995152711868, 41.46919257938862, 42.228000462055206, 43.486048355698586, 44.50524866580963, 44.14855420589447, 42.490098997950554, 42.66321770846844, 41.848359033465385, 43.08733955025673, 45.70516727864742, 42.40700885653496, 43.10261093080044, 45.888009667396545, 47.77962036430836, 48.82046811282635, 50.06514452397823, 48.55637088418007, 51.52170516550541, 52.76538223028183, 56.22779443860054, 48.040149584412575, 48.52263629436493, 55.644221752882004, 58.44003193080425, 53.0549380928278, 49.37319025397301, 48.62198956310749, 48.9034328609705, 47.480979189276695, 47.426474913954735, 45.52466556429863, 45.6614126265049, 43.51028345525265, 43.97704280912876, 41.303817853331566, 42.819738909602165, 43.12211528420448, 42.214674577116966, 42.49471195042133, 42.93030917644501, 40.87783791124821, 42.705912217497826, 42.66364708542824, 42.58914828300476, 44.55437242984772, 49.604453444480896, 48.62867720425129, 51.862204894423485, 51.087772250175476, 50.69175750017166, 55.92314578592777, 55.305443331599236, 56.39357954263687, 49.343673437833786, 48.903003484010696, 53.01034368574619, 54.645050168037415, 59.38420906662941, 60.13309568166733, 59.76066246628761, 59.12815600633621, 62.57396690547466, 62.1179685741663, 57.32446499168873, 51.5806058049202, 48.837316408753395, 47.277344316244125, 48.92415314912796, 52.14341260492802, 55.44747970998287, 58.58143374323845, 59.19287413358688, 58.531736209988594, 59.922906160354614, 57.835252583026886, 61.213909685611725, 64.72862988710403, 66.72067299485207, 66.95858582854271, 68.51967126131058, 56.22614912688732, 66.20459988713264, 70.77173441648483, 69.44007307291031, 70.4458487033844, 71.46468043327332, 71.38893529772758, 71.2702676653862, 64.85163688659668, 10.245584025979042, 1.0701195965521038, 15.875212792307138, 74.0122689306736, 65.2117283642292, 43.33184503018856, 42.88178578019142, 32.06986494362354, 57.86563955247402, 64.99876499176025, 48.716980665922165, 2.5257959542796016, 0.04857757674471941, 0.13624249084386975, 0.06535849679494277, 0.07827223002095707, 0.03787700581597164, 0.005902719785808586, 0.09702049079351127, 0.17100700351875275, 0.21994334558257833, 0.12585938471602276, 0.14090141194174066, 0.11463736969744787, 0.20094314793823287, 0.1472928619477898, 0.2694172697374597, 0.22107823780970648, 0.2500420203432441, 58.46818082034588, 76.24101653695107, 69.90443855524063, 50.24206683039665, 60.03470756113529, 51.0445761680603, 59.86778251826763, 76.02455735206604, 62.519139647483826, 1.7272367421537638, 0.9243343630805612, 0.5391081841662526, 13.846192918717861, 54.26915533840656, 57.03115873038769, 68.44574242830276, 42.49309703707695, 61.76217846572399, 62.228063866496086, 68.60461950302124, 65.02689108252525, 69.87321183085442, 66.68688520789146, 70.73087900876999, 64.67238530516624, 62.58576527237892, 67.59822830557823, 70.96015870571136, 67.94877469539642, 65.0560051202774, 65.94969436526299, 56.413555070757866, 52.35709793865681, 51.93320408463478, 49.78028900921345, 50.58123663067818, 56.38216495513916, 63.772282004356384, 63.509229719638824, 61.6645123064518, 58.43190796673298, 64.25136789679527, 61.26634307205677, 61.184609457850456, 56.727714613080025, 58.87385845184326, 52.857398092746735, 58.20578970015049, 61.42216511070728, 61.42639808356762, 59.65497873723507, 57.097400575876236, 52.71309323608875, 55.66195160150528, 54.353871792554855, 49.99508008360863, 48.96717444062233, 46.32745608687401, 43.038637563586235, 44.10254247486591, 45.86855471134186, 48.357208371162415, 46.1850169301033, 44.52591195702553, 46.83337613940239, 46.25141076743603, 45.078896284103394, 51.05741187930107, 49.28979992866516, 48.99668365716934, 51.565425619482994, 53.82949233055115, 51.33247531950474, 52.95303516089916, 51.265663504600525, 55.36401718854904, 54.71875101327896, 58.40518780052662, 50.95957852900028, 51.35555528104305, 58.910674676299095, 61.740280240774155, 58.3803903311491, 52.74573728442192, 52.16769330203533, 53.67332451045513, 51.50421470403671, 48.39779019355774, 50.2663741260767, 50.00069238245487, 48.19102428853512, 47.9099153727293, 45.214564204216, 45.06470024585724, 44.962326139211655, 44.22545447945595, 45.916530936956406, 45.817341059446335, 44.82783995568752, 44.51399579644203, 46.3025826215744, 46.860187500715256, 47.141813188791275, 52.750715017318726, 51.59069426357746, 56.25542275607586, 56.220244243741035, 55.080001428723335, 60.16194373369217, 58.49941894412041, 58.79771053791046, 51.70929729938507, 49.7330005466938, 57.12550386786461, 58.50916922092438, 62.59800061583519, 60.59405654668808, 61.91485047340393, 62.90782459080219, 64.48797360062599, 65.62285870313644, 59.999312460422516, 54.09027613699436, 50.566691011190414, 50.82546092569828, 52.67061151564121, 56.857739835977554, 58.47905583679676, 61.622585356235504, 62.80288562178612, 62.61125050485134, 63.73068183660507, 60.85511013865471, 65.4066351056099, 67.65305176377296, 70.2616573870182, 71.12167283892632, 68.27445521950722, 63.14371593296528, 69.0341104567051, 72.29198724031448, 71.95494532585144, 72.36267104744911, 76.47886097431183, 73.18106353282928, 73.62558647990227, 70.06771579384804, 16.280425898730755, 1.3309512566775084, 17.225298397243023, 83.32683071494102, 75.14037519693375, 53.357417061924934, 57.0762737095356, 45.01661002635956, 65.35002574324608, 75.19964441657066, 57.59861268103123, 3.2949575688689947, 0.2493028115713969, 0.2697287639603019, 0.11246720372582786, 0.26795425917953253, 0.10031675454229116, 0.11385261532268487, 0.25122099614236504], [0.0947757538233418, 0.07486946808057837, 0.026957432673953008, 0.11786338916863315, 0.01864508925791597, 0.0314769728720421, 0.09689307888038456, 0.04786404999322258, 0.09272792347474024, 0.3455515281530097, 34.52292971313, 55.0382986664772, 51.14631570875645, 23.573433458805084, 29.68025866895914, 40.98056919872761, 55.085385739803314, 63.8276070356369, 63.869875967502594, 6.608091462403536, 0.25896967097651213, 1.3940613577142358, 0.25066103087738156, 21.2826294824481, 38.63314636051655, 41.659987941384315, 55.358085706830025, 54.96405065059662, 52.9649019241333, 63.21312680840492, 61.599330604076385, 61.32912330329418, 63.73599015176296, 58.39364401996136, 51.71805962920189, 65.76666578650475, 61.94518804550171, 63.97104173898697, 58.54157768189907, 59.58872549235821, 48.567112907767296, 47.98738941550255, 48.10405075550079, 46.59843094646931, 42.351087257266045, 48.33567872643471, 54.43739511072636, 59.470574632287025, 55.02291329205036, 55.73230482637882, 55.876738876104355, 61.3063283264637, 58.045780286192894, 56.63261331617832, 50.902323201298714, 52.86716736853123, 44.82897609472275, 51.568727642297745, 55.7339995354414, 53.70248794555664, 51.88428930938244, 52.38290995359421, 48.75506602227688, 47.382689863443375, 50.407114773988724, 51.60913087427616, 48.158289045095444, 41.78762309253216, 42.00885482132435, 40.54390422999859, 42.01795533299446, 43.645871579647064, 42.028043791651726, 41.85403972864151, 40.69077394902706, 40.42288452386856, 43.22258949279785, 39.19624574482441, 40.34040614962578, 38.59021246433258, 38.376169949769974, 42.60529741644859, 43.20494323968887, 46.820939406752586, 47.08029069006443, 47.92211651802063, 48.09017010033131, 53.91935370862484, 47.894055023789406, 45.73175445199013, 51.622973531484604, 55.17140172421932, 49.24272045493126, 49.392945393919945, 46.85805581510067, 47.07728885114193, 46.0269758105278, 42.75565154850483, 38.95178586244583, 38.0875526368618, 39.96053673326969, 39.7825238853693, 38.79072770476341, 41.41828291118145, 38.73666040599346, 42.44749188423157, 39.843985587358475, 38.59639473259449, 40.64888499677181, 41.84033006429672, 39.13541100919247, 42.875854298472404, 46.92570358514786, 50.43948903679848, 45.11918172240257, 46.514588445425034, 47.80448243021965, 49.61656719446182, 52.814452797174454, 54.25669580698013, 52.43081398308277, 47.40026772022247, 46.48210398852825, 52.31337368488312, 51.282162219285965, 58.05532917380333, 57.953460440039635, 58.33653688430786, 55.29397554695606, 58.1363408267498, 60.544659197330475, 57.731183767318726, 52.018650099635124, 47.48603671789169, 45.926725789904594, 46.42419509589672, 46.445173770189285, 48.62667091190815, 49.86581102013588, 52.712785452604294, 50.972391441464424, 53.35155017673969, 50.18443912267685, 57.15775653719902, 57.975301668047905, 64.07138675451279, 64.07372742891312, 65.82012131810188, 52.24824897944927, 67.66411677002907, 68.46920236945152, 70.76809421181679, 65.01791596412659, 70.8754612505436, 63.95258232951164, 69.88388165831566, 53.13528098165989, 2.770776408724487, 0.45195617945864797, 22.4265144020319, 67.93857604265213, 57.4450059235096, 37.67032362520695, 37.8026819229126, 45.002877563238144, 25.82078866660595, 52.08792418241501, 53.56186129152775, 4.454208863899112, 0.08686565444804728, 0.0687509799899999, 0.062242359708761796, 0.11921590878046118, 0.029045843657513615, 0.04187656581052579, 0.06639673170866445, 0.0647287696483545, 0.06319231615634635, 0.08928144903620705, 0.07283590923179872, 0.032012740412028506, 0.1266781220328994, 0.035228759443270974, 0.03253018803661689, 0.08669229617225938, 0.2544763230253011, 41.67521372437477, 62.85657674074173, 52.308038771152496, 29.89512763917446, 40.347770154476166, 49.08729739487171, 65.84745705127716, 66.52054533362389, 70.99365770816803, 8.04167378693819, 0.48226857790723443, 1.560779430437833, 0.3602293389849365, 18.661925308406353, 42.9479668289423, 51.34426608681679, 58.79306338727474, 55.621259585022926, 55.46715125441551, 64.6181546151638, 62.06621915102005, 63.356899693608284, 64.25635322928429, 60.994935035705566, 53.533936589956284, 66.5347869694233, 65.17359361052513, 67.53286421298981, 61.85082010924816, 60.80441705882549, 52.302601262927055, 51.64358362555504, 48.78478802740574, 48.9620903134346, 45.200862139463425, 53.166766092181206, 57.2896284610033, 60.804375261068344, 57.84252539277077, 57.589443773031235, 59.837976917624474, 64.58131939172745, 59.78264808654785, 58.65515358746052, 53.22552613914013, 55.108598694205284, 49.90033216774464, 53.207093328237534, 59.836331605911255, 57.10787281394005, 56.717800945043564, 58.20286005735397, 52.48969942331314, 49.92365911602974, 53.47763881087303, 51.69477827847004, 50.15027515590191, 45.95227561891079, 43.93907144665718, 41.77577152848244, 44.44879129528999, 46.7201080173254, 43.365454226732254, 43.48240815103054, 42.32080288231373, 43.68212543427944, 45.7220383733511, 43.06976929306984, 44.18936401605606, 43.12903851270676, 42.57420368492603, 47.54892334342003, 46.49959824979305, 49.15068559348583, 47.939553782343864, 50.03672204911709, 51.51851333677769, 54.9334204941988, 49.96027395129204, 44.241102039813995, 51.85366675257683, 58.940233290195465, 52.02877275645733, 53.01220178604126, 51.01922392845154, 50.514493212103844, 46.75656706094742, 48.66584300994873, 43.95621232688427, 42.641862854361534, 44.90864261984825, 43.60884256660938, 41.292308270931244, 42.73146204650402, 42.16496184468269, 44.80545535683632, 42.04169265925884, 41.3635316491127, 43.06096516549587, 42.625519931316376, 42.258072048425674, 45.5118640512228, 49.67718154191971, 52.318704798817635, 47.61788584291935, 48.995897099375725, 51.34555421769619, 53.9320982247591, 54.645179361104965, 56.23038969933987, 56.761046424508095, 50.20238175988197, 48.27692247927189, 54.33665111660957, 54.81913782656193, 60.719560012221336, 60.295943543314934, 61.21813885867596, 56.495224088430405, 59.78870116174221, 61.32386818528175, 61.2948377430439, 55.94705410301685, 49.84723761677742, 48.74552093446255, 49.54532481729984, 49.73476365208626, 49.677101746201515, 52.00517222285271, 56.217432394623756, 54.198429733514786, 54.50067311525345, 52.529810070991516, 59.6503733843565, 61.63752995431423, 65.3515000641346, 67.44932949542999, 69.83281999826431, 55.40732726454735, 70.19126996397972, 70.9014518558979, 74.00487452745438, 67.83348888158798, 75.67590326070786, 67.00967028737068, 74.42694827914238, 53.578477799892426, 2.8572222450748086, 0.7178821787238121, 29.080445654690266, 75.30502036213875, 66.7097295820713, 43.414642587304115, 45.82521043717861, 37.75006614625454, 27.894529290497303, 65.6442591547966, 59.731062054634094, 7.603724962100387, 0.26236630277708173, 0.23716745025012642, 0.10816185662406497, 0.18932825478259474, 0.07040417331154458, 0.14312018116470426, 0.0421253485546913, 0.21709349850425497, 0.17501995927887037, 0.2243886172072962, 0.16694270598236471, 0.21203947282629088, 0.19149467290844768, 0.2858820534311235, 0.1573027716949582, 0.2021547337062657, 0.6432710448279977, 51.69589541852474, 73.89878422021866, 68.4238176047802, 33.12822215259075, 45.84515556693077, 57.11025908589363, 71.60884469747543, 72.49596789479256, 80.63876375555992, 7.8440050687640905, 1.0963235842064023, 2.65276946593076, 0.5507872730959207, 27.5716720148921, 46.41651190817356, 57.52826705574989, 64.38949048519135, 57.86540016531944, 58.35422493517399, 66.68456733226776, 68.06885585188866, 67.7280293405056, 67.15945824980736, 62.411624416708946, 54.73961569368839, 67.96154201030731, 68.48818615078926, 69.86262559890747, 64.88215684890747, 63.52732814848423, 54.74953696131706, 53.129824474453926, 54.26334165036678, 51.147626638412476, 49.2805740237236, 54.89301346242428, 59.16214518249035, 64.65878203511238, 60.98549634218216, 60.51198475062847, 63.093212842941284, 66.91746443510056, 61.97978138923645, 63.65727357566357, 57.341191694140434, 56.56523913145065, 51.95789895951748, 57.50716678798199, 63.16136218607426, 63.11089709401131, 60.6514448672533, 61.15620978176594, 56.8071873486042, 53.21113631129265, 57.92258329689503, 54.92932811379433, 53.61055567860603, 49.926486164331436, 46.90856270492077, 45.33303804695606, 46.34753420948982, 49.90097813308239, 44.95502293109894, 46.482742354273796, 46.04341372847557, 46.217493787407875, 51.22989222407341, 46.30051173269749, 49.857421070337296, 46.10108703374863, 46.99539564549923, 50.75539268553257, 48.78620155155659, 53.21579486131668, 51.89741760492325, 54.424540400505066, 52.82363310456276, 58.844011053442955, 51.26360401511192, 44.45284187793732, 53.67760308086872, 60.016023963689804, 54.3466217815876, 55.30882515013218, 53.544674813747406, 52.77090713381767, 51.1474784463644, 52.489171251654625, 47.3859728872776, 47.236542105674744, 48.934583589434624, 46.33390814065933, 45.941981971263885, 45.85679434239864, 46.36084869503975, 47.13665686547756, 45.252638161182404, 44.25370216369629, 45.34885659813881, 44.999362751841545, 45.06890282034874, 47.39855021238327, 51.95687301456928, 54.70537573099136, 50.031197145581245, 50.993092730641365, 54.456542283296585, 57.29109898209572, 58.083709850907326, 60.780759528279305, 58.4077412635088, 51.58492237329483, 51.49473041296005, 56.24870091676712, 56.53254948556423, 60.70097140967846, 63.694515377283096, 62.49924011528492, 59.31560754776001, 62.735294848680496, 65.7343827188015, 63.50476495921612, 57.55670092999935, 52.57923401892185, 52.0437553524971, 52.22950458526611, 52.56153076887131, 52.46355302631855, 55.02895876765251, 59.16672393679619, 57.011433988809586, 58.69815967977047, 55.7458359003067, 61.711580380797386, 62.630804255604744, 69.82485562562943, 71.32126092910767, 70.70649191737175, 61.73029437661171, 74.35178831219673, 77.14482083916664, 77.3940722644329, 71.9594594836235, 78.5628591477871, 72.33433976769447, 76.29881903529167, 60.18052473664284, 5.703734764829278, 1.0532004106789827, 32.03820884227753, 84.23337087035179, 74.24830466508865, 54.56601440906525, 57.75729596614838, 59.343688040971756, 37.78818570077419, 71.79136410355568, 71.0847008228302, 8.688557725399733, 0.2891651960089803, 0.34177904308307916, 0.2939294872339815, 0.24418454559054226, 0.13540902931708843, 0.23216737870825455, 0.14611922961194068], [0.09336693488876335, 0.005153747133590514, 0.07609886539285071, 0.09516469857771881, 0.029295129206730053, 0.052347805685712956, 0.12923538481118158, 0.025873982413031626, 0.06328927032882348, 0.6623574206605554, 38.523260056972504, 50.14758110046387, 46.905883848667145, 36.35610714554787, 27.586156837642193, 38.23633745312691, 47.07449980080128, 60.51318548619747, 63.29930618405342, 29.69665478914976, 0.5239383294247091, 0.5927948502358049, 0.23502850643126294, 1.9162725610658526, 21.460011564195156, 42.4505241215229, 31.53332993388176, 52.71740600466728, 53.51527199149132, 53.19147616624832, 51.1839184910059, 56.93599283695221, 53.94472874701023, 51.76259703934193, 58.771104365587234, 64.52946737408638, 60.53603745996952, 61.70942969620228, 59.326235577464104, 51.06808550655842, 47.93111063539982, 48.51984344422817, 43.13555896282196, 43.97181048989296, 48.086507096886635, 53.61910901963711, 56.03149697184563, 62.387928888201714, 55.826798155903816, 52.471437603235245, 56.199748143553734, 58.56199398636818, 56.90404035151005, 54.31857168674469, 50.34416355192661, 54.146539717912674, 48.00918124616146, 50.598153322935104, 56.87007777392864, 51.793242394924164, 52.77217246592045, 51.044021397829056, 50.25538131594658, 49.65322382748127, 46.74982242286205, 48.31208199262619, 46.53087817132473, 44.923822805285454, 39.575951769948006, 40.20088143646717, 40.99880442023277, 44.144450426101685, 43.94877232611179, 42.43740722537041, 39.733331725001335, 44.11969855427742, 39.152646884322166, 39.90481652319431, 41.226203218102455, 38.98298218846321, 39.8344898968935, 42.4373160302639, 46.116863787174225, 47.15269960463047, 47.50535488128662, 49.96584825217724, 44.44655321538448, 48.9214438945055, 53.06503415107727, 45.91067925095558, 55.07069572806358, 49.64280478656292, 46.04649156332016, 46.46100752055645, 47.3433505743742, 46.73553518950939, 41.82897627353668, 41.34073667228222, 39.068994373083115, 39.37162533402443, 40.61578497290611, 43.14205661416054, 39.61697056889534, 40.81424452364445, 39.16279993951321, 39.35128502547741, 38.50764289498329, 40.04222095012665, 41.18612676858902, 41.8470823019743, 43.01909141242504, 45.76122187077999, 46.402350068092346, 51.01065918803215, 46.84588126838207, 47.490490078926086, 48.869610875844955, 53.0101802945137, 52.443448305130005, 54.809531942009926, 55.2508744597435, 49.95553560554981, 48.591705188155174, 52.64077931642532, 52.274946346879005, 59.13842685520649, 57.229329496622086, 58.11405502259731, 54.03653182089329, 54.46731090545654, 59.37986969947815, 60.9192468971014, 56.87225505709648, 50.322512313723564, 47.617711052298546, 45.78792303800583, 45.1436448097229, 46.996866166591644, 46.85580253601074, 48.58503274619579, 46.55982121825218, 49.738164469599724, 51.78115904331207, 56.46468132734299, 59.30021457374096, 62.6007554680109, 65.64909249544144, 62.986563965678215, 54.76453095674515, 66.34326964616776, 64.91692498326302, 70.39753049612045, 62.52240747213364, 70.51214754581451, 58.713377863168716, 71.18069127202034, 33.20145562291145, 0.3394116513663903, 0.028550367314892355, 40.52988298237324, 61.856698393821716, 57.37142287194729, 38.72961938381195, 38.94081965088844, 30.54206572473049, 47.30365790426731, 56.043002754449844, 48.09775449335575, 5.890099089592695, 0.08215483496314846, 0.12265924393432215, 0.04879099244135432, 0.020910018210997805, 0.04321177853853442, 0.09899805460008793, 0.04174938396317884, 0.02912701791501604, 0.05211647825490218, 0.09882036960334517, 0.1053354688338004, 0.04345685796579346, 0.02946389915450709, 0.045339137432165444, 0.026548099267529324, 0.004538157900242368, 0.5450255353935063, 47.02857546508312, 60.89517518877983, 54.25807513296604, 35.292149037122726, 40.82848235964775, 50.388841554522514, 55.195302441716194, 65.46778902411461, 69.22449544072151, 34.14700448513031, 0.43051194108556956, 2.135716248303652, 0.3295344376238063, 1.1667729914188385, 20.20049884915352, 42.43650667369366, 38.96169193089008, 56.28934733569622, 56.76350109279156, 57.46861785650253, 53.323914259672165, 59.359320402145386, 55.390406772494316, 53.63568373024464, 59.767429903149605, 66.28149256110191, 62.76279777288437, 64.95049998164177, 58.5408329218626, 54.66852530837059, 50.49403131008148, 50.522039607167244, 45.43489158153534, 47.734015211462975, 50.14473505318165, 56.074731051921844, 59.13829766213894, 65.02575874328613, 57.14859902858734, 56.43574967980385, 57.81415231525898, 62.345576360821724, 59.54350411891937, 55.85578680038452, 54.654424265027046, 56.54871001839638, 51.20288327336311, 51.87171958386898, 59.44250553846359, 55.60809329152107, 57.88669042289257, 54.59506385028362, 52.58838392794132, 55.06288334727287, 50.122684836387634, 52.18690127134323, 49.266385585069656, 48.181501999497414, 43.956877291202545, 42.43445858359337, 44.00728538632393, 46.390000730752945, 44.20417562127113, 43.881975710392, 42.6408065110445, 45.3081189841032, 43.6531899869442, 42.05131374299526, 44.14769545197487, 42.638150453567505, 43.96418049931526, 45.90698964893818, 47.93894961476326, 50.86231894791126, 48.566307350993156, 53.052339032292366, 46.06647469103336, 52.17077113687992, 52.75330267846584, 46.09414480626583, 57.1232657879591, 50.885148122906685, 47.501851469278336, 49.512885957956314, 49.004336446523666, 49.135843589901924, 45.890745520591736, 45.96007660031319, 42.56068401038647, 43.15041236579418, 43.319997265934944, 46.208001896739006, 43.89216296374798, 43.324868604540825, 43.2122578471899, 41.19967304170132, 41.683299690485, 43.07816304266453, 42.85610295832157, 43.475861102342606, 45.56045584380627, 48.30758683383465, 50.00713303685188, 52.691331803798676, 51.94681115448475, 50.54427221417427, 51.08592934906483, 54.664679914712906, 56.27053454518318, 57.82096914947033, 59.44030545651913, 53.40746037662029, 49.909387081861496, 55.81411823630333, 54.97697375714779, 62.00255736708641, 60.35476818680763, 60.52904203534126, 57.61787764728069, 58.11798021197319, 61.31799750030041, 63.645000234246254, 58.17301645874977, 54.049238339066505, 51.32921889424324, 49.62948650121689, 47.26070500910282, 49.97624069452286, 50.05676217377186, 52.533427476882935, 50.35702206194401, 52.99922168254852, 55.05529135465622, 57.84396931529045, 61.332007348537445, 66.54458284378052, 68.67123752832413, 66.71321019530296, 58.22441630065441, 68.05876359343529, 68.037249147892, 71.99497997760773, 67.2178003191948, 75.262531042099, 61.2785442173481, 73.08068051934242, 31.307500451803207, 0.359729754854925, 0.13245556358015165, 50.79247489571571, 67.96658053994179, 69.02881354093552, 45.09286813437939, 53.31093415617943, 34.513187035918236, 43.941271528601646, 64.79528591036797, 59.34939153492451, 9.50610475614667, 0.2721156890038401, 0.09057580653461628, 0.0660475215408951, 0.10096325422637165, 0.03680764893942978, 0.11123876378405839, 0.09943347264197655, 0.16527906322153285, 0.12019146190141328, 0.1948555777198635, 0.215604898694437, 0.30606867803726345, 0.15187842916930094, 0.29270230152178556, 0.2605039573973045, 0.22235608252231032, 0.8587349206209183, 57.1244703233242, 70.2896998822689, 67.32934713363647, 44.41746577620506, 42.40680746734142, 52.65043079853058, 61.52470640838146, 69.51204121112823, 75.4544435441494, 35.11876054108143, 0.8497586741577834, 2.110819034278393, 0.3305667353561148, 3.4364612633362412, 26.944983042776585, 47.7788832038641, 47.94048473238945, 60.772407576441765, 61.29597768187523, 61.46378427743912, 54.71009127795696, 59.25481840968132, 57.9230734705925, 55.30476316809654, 61.93096540868282, 69.59440559148788, 64.20955494046211, 67.32180833816528, 63.34389679133892, 56.466360837221146, 53.312123492360115, 54.18115586042404, 47.45327487587929, 49.42178964614868, 53.81860211491585, 59.338816702365875, 63.00048641860485, 67.29457139968872, 61.920831352472305, 57.62272238731384, 61.42033360898495, 64.59686055779457, 61.517076417803764, 58.84532958269119, 55.32285399734974, 60.45333869755268, 53.43505069613457, 55.56621953845024, 62.81183034181595, 61.59140042960644, 61.35724939405918, 58.713685646653175, 56.51293873786926, 57.75862209498882, 52.684214785695076, 53.87349396944046, 52.488494887948036, 51.35875090956688, 46.82132698595524, 44.35272105038166, 47.04407103359699, 49.496980011463165, 47.88352198898792, 46.35525919497013, 44.78001572191715, 49.52426254749298, 46.713329181075096, 45.509808361530304, 49.92004930973053, 47.828394547104836, 48.49314607679844, 48.32625523209572, 51.32370539009571, 52.044059336185455, 51.108515337109566, 56.88096798956394, 50.77177360653877, 54.811314046382904, 55.84035202860832, 48.529217541217804, 58.72015669941902, 56.12827017903328, 49.539127349853516, 53.15626345574856, 53.787155002355576, 53.70615854859352, 49.034400433301926, 49.72093619406223, 47.843468338251114, 46.0656463354826, 46.9556649774313, 52.17490531504154, 47.318503707647324, 45.696678534150124, 44.94778431952, 42.7226123213768, 43.45120042562485, 45.61930328607559, 46.1650376021862, 45.93394160270691, 48.08017663657665, 51.17134876549244, 52.3304233700037, 54.285578057169914, 54.26081858575344, 53.46811272203922, 52.90259286761284, 58.390923365950584, 60.85623487830162, 60.46712055802345, 62.343699261546135, 56.340492591261864, 51.29435196518898, 58.71183134615421, 57.74107463657856, 64.38946008682251, 62.4357683211565, 63.69143754243851, 57.87509724497795, 59.29995618760586, 64.63751837611198, 66.52540907263756, 59.796688333153725, 57.67104819417, 53.60047481954098, 51.37165881693363, 49.943608045578, 51.153611317276955, 53.984478414058685, 54.50894147157669, 52.47627094388008, 55.19943282008171, 58.231312930583954, 60.24467669427395, 65.75808584690094, 69.5669786632061, 73.02969485521317, 69.2935149371624, 63.00177454948425, 71.50613620877266, 73.19893017411232, 77.6190809905529, 72.26107969880104, 80.49967601895332, 64.75516766309738, 73.71592283248901, 40.99897541105747, 0.46222964068874717, 0.23394737538183108, 55.7905139029026, 77.65777051448822, 73.82549375295639, 54.10826437175274, 62.11294524371624, 44.07575011253357, 66.67840406298637, 76.24591067433357, 71.05819344520569, 13.726581037044525, 0.3116504300851375, 0.279972450225614, 0.1673473694245331, 0.1911549028591253, 0.2202346088597551, 0.2604566974332556, 0.17166536272270605], [0.03337289301271085, 0.05581805482506752, 0.037072180057293735, 0.040949641916085966, 0.007017126881692093, 0.07480562853743322, 0.11764601411414333, 0.001243045176124724, 0.06891941782669164, 1.2751194275915623, 39.708454459905624, 54.45392422378063, 44.19884450733662, 37.571312338113785, 22.563090473413467, 33.238511234521866, 34.000415951013565, 63.506296277046204, 66.80280178785324, 54.615381360054016, 0.4940829158294946, 2.0700652711093426, 0.23776299407472834, 0.21156685834284872, 1.343114166520536, 22.055300921201706, 31.722297593951225, 33.52188482880592, 45.66336192190647, 52.23928906023502, 58.10827933251858, 62.378497794270515, 58.63040171563625, 59.27145391702652, 60.65081410109997, 64.93726149201393, 62.2023506462574, 60.26021786034107, 54.809695333242416, 50.54281689226627, 47.27392449975014, 46.66544795036316, 45.05769722163677, 47.528415843844414, 48.80006700754166, 55.70749215781689, 59.144365936517715, 64.01749044656754, 50.60555152595043, 56.77118428051472, 55.65418481826782, 58.31033729016781, 57.21850007772446, 53.457412496209145, 52.46957190334797, 54.033244997262955, 51.420034021139145, 48.79884347319603, 53.65328438580036, 49.74038355052471, 52.00517602264881, 50.72685241699219, 47.749043405056, 49.574184268713, 48.48656103014946, 48.519752249121666, 46.3281324505806, 45.987317338585854, 44.89443518221378, 40.147824883461, 40.29358506202698, 43.35207514464855, 42.76194401085377, 44.116958901286125, 42.51855567097664, 43.82423020899296, 38.67330640554428, 40.82236848771572, 39.43220928311348, 38.99516433477402, 39.297111332416534, 44.51183371245861, 45.28541520237923, 46.384084448218346, 52.66703590750694, 50.3999749571085, 46.5965386480093, 52.98989698290825, 52.06104442477226, 47.75690518319607, 58.08648370206356, 49.06734086573124, 50.94746857881546, 48.120644465088844, 46.801275461912155, 47.194877341389656, 44.39595893025398, 42.374060824513435, 37.91125349700451, 38.611217737197876, 40.779787972569466, 38.31418387591839, 40.733704045414925, 38.76613162457943, 39.40406419336796, 42.59008303284645, 40.608789548277855, 42.53709487617016, 40.8046006411314, 40.31723499298096, 46.29084885120392, 46.765576377511024, 47.74229496717453, 47.88576766848564, 48.54729317128658, 49.48384791612625, 49.85324129462242, 55.013037621974945, 52.73379072546959, 54.484060406684875, 54.967272877693176, 49.215388521552086, 51.109750270843506, 51.41600243747234, 53.049139603972435, 57.334238067269325, 58.30940634012222, 58.34252916276455, 58.379493579268456, 56.53457097709179, 56.364864483475685, 59.12544675171375, 59.125157967209816, 54.572846442461014, 49.95164841413498, 48.50394509732723, 45.44505603611469, 46.38474561274052, 47.81391352415085, 50.33713012933731, 52.074621096253395, 57.33879782259464, 56.20878405869007, 56.57943896949291, 57.72248223423958, 61.38352118432522, 64.93867501616478, 63.98431822657585, 57.611421793699265, 66.09543174505234, 64.54743281006813, 70.1077276468277, 63.833458721637726, 66.96139767765999, 60.708719193935394, 66.8595327436924, 8.280853852629662, 0.31909339944832027, 2.639683918096125, 57.578629553318024, 61.40780188143253, 51.216828525066376, 18.485322184860706, 31.877181082963943, 47.778127044439316, 30.14085665345192, 45.597766041755676, 54.80803482234478, 12.038818951696157, 0.22910478757694364, 0.08438631717581302, 0.008027342937566573, 0.024065433462965302, 0.03026786958798766, 0.030263500193541404, 0.023770292464178056, 0.06767577870050445, 0.046391142896027304, 0.07384589800494723, 0.06807624900829978, 0.0561398129502777, 0.07647648497368209, 0.03722358560480643, 0.03597390910726972, 0.09495955411694013, 1.778246273752302, 52.95292876660824, 61.83708764612675, 51.38214245438576, 33.15348319709301, 26.09569251537323, 42.222828939557076, 40.783663764595985, 69.74691420793533, 71.76622465252876, 61.01540073752403, 0.4932378767989576, 2.001862730830908, 0.11927974090212956, 0.1965386202209629, 0.6294446554966271, 22.94553805142641, 33.550022318959236, 41.93928435444832, 51.16123750805855, 55.8163221180439, 57.52857483923435, 63.39739412069321, 60.286812633275986, 61.008070930838585, 62.170496955513954, 66.85058042407036, 64.18371632695198, 61.63662560284138, 58.14487136900425, 54.635900259017944, 51.1367554217577, 46.4084829390049, 46.33125588297844, 49.220609441399574, 51.989254876971245, 58.77805799245834, 62.75650151073933, 64.63463813066483, 52.07318477332592, 58.11142176389694, 58.68898317217827, 60.9044086933136, 59.871532917022705, 54.84668254852295, 54.805963933467865, 56.66930794715881, 53.11779052019119, 50.641140416264534, 57.844315096735954, 53.66474837064743, 56.50225751101971, 52.73330055177212, 53.81188027560711, 51.62705451250076, 51.36895716190338, 51.19290500879288, 49.6799173951149, 49.24254946410656, 49.035616368055344, 43.2766567915678, 43.76884438097477, 44.13992866873741, 46.35976195335388, 44.42655488848686, 44.53748993575573, 46.829462349414825, 42.92740233242512, 43.90510506927967, 42.30889052152634, 41.615895107388496, 43.448050394654274, 45.60734532773495, 47.400826290249825, 50.04233434796333, 52.59485498070717, 53.25615629553795, 48.23779597878456, 53.433291390538216, 52.04355776309967, 47.46651716530323, 57.42440342903137, 49.98672433197498, 50.90693235397339, 49.81285706162453, 49.14466671645641, 49.06578674912453, 46.71788893640041, 45.67580625414848, 41.17938593029976, 42.62263588607311, 42.58372977375984, 42.5126051902771, 45.326882377266884, 41.52204394340515, 41.89506612718105, 43.71466688811779, 42.491136342287064, 43.91704402863979, 42.68626727163792, 42.77531549334526, 48.16787593066692, 49.67064209282398, 51.35052055120468, 50.04363767802715, 52.93760038912296, 52.87167012691498, 52.9385731369257, 57.65950821340084, 56.46349959075451, 57.11128503084183, 58.11759263277054, 51.46122761070728, 53.51591415703297, 54.70199391245842, 53.51668171584606, 59.76877503097057, 60.58508902788162, 62.83639222383499, 59.50460560619831, 57.509085685014725, 57.45760224759579, 62.959904596209526, 64.56863567233086, 59.67468447983265, 53.89862582087517, 50.99710911512375, 48.527982607483864, 49.100908264517784, 50.69618046283722, 52.69022986292839, 54.72539685666561, 62.5035110861063, 60.68592421710491, 61.72573082149029, 60.71680895984173, 65.13955503702164, 67.27273777127266, 67.28941887617111, 60.299804136157036, 70.81566765904427, 67.20326229929924, 74.1213458776474, 68.50086227059364, 69.48102727532387, 64.46184620261192, 67.98000141978264, 7.730616303160787, 0.3721023362595588, 3.804625882767141, 68.41857388615608, 66.9809590280056, 60.05065530538559, 24.988990500569344, 40.68290837109089, 51.186110973358154, 36.58187583088875, 57.52835065126419, 67.35437259078026, 20.617302283644676, 0.2924513368634507, 0.17479087313404307, 0.017722842749208212, 0.0852065981598571, 0.05593324727669824, 0.035178913094569, 0.006889188043714967, 0.13745228061452508, 0.17963092279387638, 0.1831512854550965, 0.14921780006261542, 0.07184817746747285, 0.25121496990323067, 0.2587064460385591, 0.1333832333330065, 0.20423357840627432, 2.9411673406139016, 62.90375500917435, 70.79002663493156, 61.912342607975006, 48.43968294560909, 36.81821174919605, 48.07381197810173, 47.342370226979256, 74.1613957285881, 79.03839603066444, 65.90690866112709, 0.8481460169423372, 4.972897181287408, 0.3522931085899472, 0.20879266579868272, 2.5924517400562763, 29.67500925064087, 36.499139070510864, 48.111597150564194, 56.358047649264336, 57.26299948990345, 60.6839445233345, 66.13225176930428, 65.05991891026497, 62.68091596662998, 65.07287621498108, 70.56489631533623, 68.30391883850098, 64.75310817360878, 60.79042620956898, 58.330529406666756, 52.716946229338646, 49.72344405949116, 49.57481883466244, 52.543819919228554, 54.59615059196949, 60.94789735972881, 64.11611035466194, 64.82135251164436, 54.83559474349022, 60.35274289548397, 61.31912983953953, 64.21118885278702, 62.34886698424816, 58.891611099243164, 56.83048389852047, 58.96201752126217, 55.82524783909321, 54.00286562740803, 61.032894998788834, 58.85835908353329, 58.502967953681946, 56.35922558605671, 54.521910175681114, 57.81964682042599, 54.79438595473766, 54.893397241830826, 53.07885400950909, 53.51708069443703, 51.52428902685642, 47.83272251486778, 47.31663420796394, 49.070905074477196, 49.524129554629326, 47.84498445689678, 45.37024185061455, 49.180453196167946, 46.49041414260864, 48.96512255072594, 47.11517281830311, 46.1069805175066, 48.480184972286224, 51.22955024242401, 52.79721312224865, 53.947905376553535, 55.799424424767494, 55.80779157578945, 50.86729668080807, 58.25208641588688, 52.044754698872566, 48.15580777823925, 61.457829996943474, 54.08507041633129, 55.82759611308575, 52.62723684310913, 51.79090932011604, 52.90595568716526, 50.0648557394743, 51.799622252583504, 47.0334430038929, 47.404360100626945, 47.614469826221466, 44.586184322834015, 48.81688870489597, 44.866567477583885, 44.912666603922844, 45.98779611289501, 45.787489861249924, 47.12705098092556, 46.417423859238625, 45.164057314395905, 51.938979774713516, 53.56187269091606, 53.266461342573166, 52.238605096936226, 55.85373871028423, 56.23311795294285, 56.07047148048878, 61.42502635717392, 59.21308524906635, 63.36138345301151, 61.42463497817516, 54.88379515707493, 55.808327347040176, 56.16998814046383, 56.18940509855747, 60.99606357514858, 62.16483145952225, 65.12792766094208, 60.635094344615936, 59.85071763396263, 59.317807629704475, 66.35010927915573, 64.54823076725006, 61.50649778544903, 56.806803569197655, 52.744772136211395, 51.558411195874214, 50.879942402243614, 53.88803578913212, 55.278320387005806, 56.79254673421383, 63.30202303826809, 61.443603560328484, 63.594261556863785, 64.09544706344604, 68.5671079158783, 70.13192474842072, 68.48395317792892, 62.52161331474781, 74.17697489261627, 72.0395515859127, 78.62171798944473, 71.3850063085556, 75.03024950623512, 67.79189631342888, 74.80691269040108, 13.911124784499407, 0.5137560039293021, 3.99219355545938, 74.06724438071251, 73.48795026540756, 66.81138172745705, 32.59752742946148, 51.211098432540894, 64.87416967749596, 43.298182636499405, 64.40318495035172, 78.7916448712349, 25.43945822864771, 0.528159843524918, 0.30387524573598057, 0.11707803365425207, 0.14093666395638138, 0.12642769172089174, 0.14441603037994355, 0.08572235368774273], [0.05766428817878477, 0.08891124351066537, 0.040755859736236744, 0.029000732210988645, 0.0458545998117188, 0.03415691637201235, 0.0454683304997161, 0.084030041762162, 0.0682542531285435, 3.213522001169622, 52.94362686574459, 55.00372812151909, 45.94327010214329, 34.50508967041969, 51.52127578854561, 40.74068807065487, 26.909876726567745, 62.11716301739216, 61.46511420607567, 69.5765009522438, 5.4130650870501995, 1.0657176515087485, 0.6184673414099962, 0.26642549433745444, 0.3171597485197708, 2.829120852984488, 23.376442529261112, 24.97538723051548, 39.71388436853886, 53.09949450194836, 59.34510916471481, 60.74142783880234, 57.06919468939304, 60.68518705666065, 63.88652667403221, 61.17634870111942, 61.808171197772026, 54.556640312075615, 50.413281843066216, 47.4243850260973, 44.433390721678734, 43.76357026398182, 46.8016554415226, 48.40233474969864, 54.28632661700249, 56.51466004550457, 64.1466911137104, 59.429723024368286, 47.86496378481388, 57.63879932463169, 60.49826368689537, 59.88328568637371, 56.48615397512913, 51.018448770046234, 52.37287849187851, 54.255179688334465, 53.67545239627361, 48.705482482910156, 52.5069011002779, 53.71715895831585, 53.22843298316002, 52.99938507378101, 50.39694271981716, 51.34797848761082, 49.58364576101303, 48.25525604188442, 47.67603412270546, 46.698373183608055, 44.844030886888504, 44.91989001631737, 40.93351252377033, 42.494328171014786, 43.416990861296654, 44.917002171278, 43.933037370443344, 40.31930208206177, 40.912917628884315, 43.300815895199776, 41.076438054442406, 38.7710827589035, 39.30835112929344, 41.785742193460464, 47.096390426158905, 49.363911151885986, 47.45439201593399, 54.43896822631359, 56.65084093809128, 55.77179230749607, 47.764029800891876, 44.079314321279526, 56.212173476815224, 56.32987596094608, 52.92266719043255, 49.6013680100441, 49.73957039415836, 45.7924447953701, 46.530547589063644, 41.2299308180809, 37.947727739810944, 39.46173369884491, 41.5140225738287, 39.48620818555355, 43.57346646487713, 40.30507944524288, 39.55179266631603, 39.417268484830856, 40.77409207820892, 37.972939386963844, 38.26489672064781, 41.06957942247391, 44.37132105231285, 46.51742309331894, 48.887010142207146, 48.70780795812607, 47.905545607209206, 48.274072632193565, 48.511031717062, 54.32923011481762, 54.01586852967739, 54.693577364087105, 53.43125469982624, 51.89366340637207, 52.862938195466995, 51.522164940834045, 54.48183372616768, 55.780721828341484, 57.01209135353565, 57.86348506808281, 58.97365249693394, 58.039700612425804, 54.87576998770237, 57.76958830654621, 60.53588546812534, 57.31147728860378, 53.74115087091923, 52.10001893341541, 48.60912725329399, 45.720879435539246, 51.80711545050144, 47.62831248342991, 59.37806859612465, 59.56425480544567, 64.55353528261185, 59.25345428287983, 63.71357895433903, 57.65085607767105, 65.54570004343987, 59.557935744524, 62.86933645606041, 61.05231575667858, 70.40123149752617, 63.1231514364481, 68.72035369277, 58.509989976882935, 62.53816142678261, 34.18229319155216, 1.9145855703391135, 0.5749670381192118, 9.630810264497995, 68.24566796422005, 55.25393709540367, 42.699908539652824, 33.86897720396519, 46.98959335684776, 38.7867721170187, 34.609451070427895, 36.52786172926426, 62.38332733511925, 26.078844219446182, 0.10489580570720136, 0.03940844981116243, 0.03767584297747817, 0.10443289109389298, 0.06273771359701641, 0.02979829048854299, 0.061317617728491314, 0.016917705288506113, 0.054855474445503205, 0.01644867537834216, 0.10079887593747117, 0.046953742785262875, 0.02659100096934708, 0.01831529738410609, 0.09355497284559533, 0.0779117392085027, 6.307776952162385, 62.39215426146984, 63.939070254564285, 52.766054794192314, 24.664573408663273, 45.58142691850662, 41.202800273895264, 35.1082731038332, 67.91818633675575, 64.53676298260689, 76.86814248561859, 6.307435920462012, 1.6753248777240515, 2.2295165900141, 0.26584694569464773, 0.10939394793240353, 1.1596583481878042, 25.977085679769516, 29.28625401109457, 47.21327215433121, 55.57185083627701, 64.87273335456848, 62.26408213376999, 61.22410073876381, 62.152014747262, 64.59794729948044, 63.121863305568695, 63.757987171411514, 57.06506431102753, 54.39254231750965, 49.9353738874197, 47.006848230957985, 45.906180292367935, 49.21604968607426, 52.11133472621441, 57.41580069065094, 60.244843885302544, 65.65418422222137, 60.21546006202698, 49.33576226234436, 59.65426057577133, 61.11933276057243, 61.404116079211235, 60.362994745373726, 53.80486585199833, 55.075696259737015, 56.30314439535141, 55.44293895363808, 54.0313944965601, 55.22164262831211, 55.547889322042465, 57.28248104453087, 55.35025052726269, 54.626244977116585, 54.093270376324654, 50.57884655892849, 50.224823355674744, 50.28527431190014, 49.75219711661339, 48.5795534402132, 47.55201257765293, 45.42090833187103, 44.583003893494606, 45.48897787928581, 45.39068855345249, 47.561569064855576, 43.00478897988796, 45.161287263035774, 45.84566093981266, 42.190200090408325, 42.3567945510149, 42.69742727279663, 44.17180895805359, 48.447214141488075, 52.05860115587711, 50.15609264373779, 54.65114124119282, 57.86593593657017, 56.98159798979759, 48.044215366244316, 44.63226065039635, 57.842616587877274, 57.63814575970173, 53.185305297374725, 53.19353565573692, 51.57979644834995, 48.74955251812935, 47.99457482993603, 45.44543221592903, 41.32323481142521, 44.13738280534744, 43.69037479162216, 42.085401713848114, 45.03893382847309, 41.373566910624504, 42.153737246990204, 42.237492352724075, 43.473254442214966, 41.532706171274185, 41.60760775208473, 45.61282463371754, 48.87917876243591, 49.46429416537285, 52.944626212120056, 52.48405672609806, 50.46698056161404, 51.99460878968239, 53.884106799960136, 56.98363468050957, 59.72610332071781, 57.319814041256905, 55.696016773581505, 53.07360269129276, 57.5063232332468, 54.385026320815086, 56.48524962365627, 57.81615860760212, 60.13241171836853, 60.66548131406307, 63.723473623394966, 58.85178543627262, 56.534259393811226, 59.88257132470608, 65.0056654214859, 61.905396580696106, 56.342688873410225, 54.92243908345699, 50.502995029091835, 48.502755761146545, 53.36517244577408, 50.081806629896164, 60.46685837209225, 63.47706064581871, 67.0122541487217, 63.694967553019524, 66.51604637503624, 61.04502394795418, 66.1556813120842, 64.5116539299488, 64.13697883486748, 62.565101981163025, 72.59980112314224, 67.3007270693779, 70.91245606541634, 62.22071126103401, 66.70230478048325, 34.05999295413494, 1.8912798771634698, 0.40562253445386887, 12.308231145143509, 78.60766634345055, 62.01940566301346, 50.648044645786285, 37.35173352062702, 51.277378275990486, 46.349578499794006, 38.72737370431423, 51.608910486102104, 69.55355018377304, 38.33670526742935, 0.26295485557056963, 0.027364988636691123, 0.06280173125560395, 0.04514886190008838, 0.036273272926337086, 0.05254237825283781, 0.03716693747264799, 0.22231097478652373, 0.20186136272968724, 0.11401360941817984, 0.16090340504888445, 0.14446676359511912, 0.21601805230602622, 0.16884741315152496, 0.15893598640104756, 0.3737011895282194, 7.5500172190368176, 75.21810382604599, 71.85403794050217, 62.16735452413559, 49.88028824329376, 73.10745388269424, 55.11096976697445, 38.416181802749634, 77.93795987963676, 70.09251326322556, 85.47252997756004, 6.753341993317008, 8.099545631557703, 2.6937766280025244, 0.32186077907681465, 0.47018003126140684, 3.6269965767860413, 29.28330346941948, 35.51699437201023, 53.071957379579544, 58.34611237049103, 70.89877679944038, 65.61795696616173, 66.42426609992981, 65.53294032812119, 69.83953803777695, 67.0877256989479, 66.43739059567451, 61.60205125808716, 58.43502759933472, 52.66937658190727, 49.55050393939018, 49.39490608870983, 53.44546973705292, 56.41715347766876, 58.51431794464588, 63.849159479141235, 64.32283446192741, 62.2757551074028, 52.64596223831177, 62.23236903548241, 64.21847686171532, 63.69924232363701, 62.886636927723885, 54.20455500483513, 57.29344725608826, 59.53370064496994, 56.716550812125206, 56.37896552681923, 59.47630852460861, 61.616376489400864, 61.3704726845026, 58.980887308716774, 59.507140070199966, 58.13042834401131, 54.05672773718834, 53.22265349328518, 53.496679589152336, 54.641345366835594, 52.47571997344494, 50.946777015924454, 47.927728816866875, 48.861027136445045, 48.79841409623623, 50.55815666913986, 50.549455136060715, 44.380318969488144, 47.21891105175018, 49.260210916399956, 47.12146908044815, 46.7081880569458, 45.88664934039116, 49.22365687787533, 51.897706389427185, 55.37918597459793, 53.122053891420364, 58.508686646819115, 60.585932582616806, 59.75145176053047, 48.92137549817562, 44.9826892465353, 60.78287601470947, 58.77655707299709, 57.36124321818352, 55.15168838202953, 55.19297696650028, 51.17731064558029, 54.794336557388306, 49.00139540433884, 45.90907193720341, 45.540252327919006, 48.941658809781075, 44.68677632510662, 49.78698045015335, 45.11780999600887, 46.08358137309551, 45.49975410103798, 45.09050466120243, 45.27433879673481, 44.031482487916946, 49.11581486463547, 50.214852690696716, 51.846169754862785, 57.575483322143555, 55.72000488638878, 52.10516385734081, 53.896984308958054, 58.76053333282471, 62.02782221138477, 60.21395914256573, 59.73348252475262, 58.12500223517418, 57.136983051896095, 59.66791704297066, 58.102952018380165, 60.48073522746563, 59.91799682378769, 60.67126840353012, 64.59092527627945, 65.75486361980438, 60.36649435758591, 57.741534411907196, 62.86050572991371, 64.23579633235931, 63.609054163098335, 59.14716258645058, 57.90675714612007, 55.113796815276146, 51.47439390420914, 58.97918879985809, 53.28258767724037, 64.29467797279358, 66.24035596847534, 67.9263786971569, 64.74597215652466, 70.97711339592934, 64.67479437589645, 70.08197262883186, 65.25465086102486, 69.06406044960022, 69.17360097169876, 77.90571480989456, 72.64235123991966, 75.71655347943306, 69.80551466345787, 70.56123331189156, 42.275695502758026, 3.75739180482924, 0.6798380264081061, 14.132566452026367, 86.55870169401169, 67.27390810847282, 61.112113147974014, 48.1243796646595, 63.16241852939129, 57.64522098004818, 45.337499007582664, 58.1141272187233, 85.51027715206146, 46.719716638326645, 0.45953742577694356, 0.21608775481581688, 0.14336693042423576, 0.19201658084057271, 0.1438237223192118, 0.11539542902028188, 0.13181517919292673], [0.059850640391232446, 0.023122620186768472, 0.023486929349019192, 0.04389487723528873, 0.06248593999771401, 0.06651140094618313, 0.053566850037896074, 0.20363770803669468, 0.04373536372440867, 13.046559076756239, 71.16945147514343, 54.985416904091835, 46.647273525595665, 63.51218596100807, 101.84759169816971, 60.28764858841896, 22.60271854698658, 64.38532590866089, 63.545358180999756, 70.6008043885231, 29.591550529003143, 0.8400322054512799, 0.2472025781753473, 0.41153709520585835, 0.25673847820144147, 0.008922802553570364, 8.30607594922185, 22.961064018309116, 24.166594929993153, 47.34483249485493, 54.253241792321205, 56.849824860692024, 59.774265736341476, 59.179464653134346, 58.90179455280304, 60.56942246854305, 55.95104768872261, 51.09523504972458, 47.50862270593643, 47.00006179511547, 44.06603783369064, 47.26112678647041, 49.38946098089218, 49.220772832632065, 50.51382824778557, 59.88544397056103, 61.36932894587517, 52.13887944817543, 55.95649279654026, 58.6202372610569, 58.50943520665169, 60.338159278035164, 52.043493166565895, 51.373349726200104, 51.1744000017643, 52.08241827785969, 54.44590665400028, 51.14958733320236, 55.705105885863304, 56.10567659139633, 51.34037509560585, 52.206181436777115, 49.926235377788544, 51.65844462811947, 51.73062555491924, 49.96892608702183, 50.72725519537926, 46.38651631772518, 51.55073560774326, 49.29974399507046, 45.02145856618881, 42.94469900429249, 45.338999927043915, 47.5764262676239, 40.34619323909283, 39.56397481262684, 43.18270303308964, 42.71020598709583, 42.11100473999977, 37.294523790478706, 40.8972092717886, 39.21224668622017, 49.099658131599426, 44.93127040565014, 50.88586628437042, 55.08426859974861, 61.398465782403946, 56.56668305397034, 43.83114203810692, 37.644458413124084, 49.647242948412895, 61.344132497906685, 60.31252205371857, 51.340162307024, 47.649085968732834, 46.97182551026344, 42.714830338954926, 40.88988706469536, 39.653984382748604, 39.853770062327385, 39.53807920217514, 40.560022965073586, 39.56986829638481, 41.0085204988718, 40.35098858177662, 38.885099440813065, 41.771568953990936, 37.71628595888615, 42.7657476067543, 45.23436114192009, 48.93021382391453, 46.95921778678894, 51.35697640478611, 49.89991798996925, 48.49552854895592, 52.6728305965662, 51.469488367438316, 55.572671592235565, 54.84052687883377, 53.94244126975536, 55.38113906979561, 53.86235296726227, 56.37058697640896, 51.920961141586304, 54.98522691428661, 54.223717376589775, 57.35130675137043, 58.4580809623003, 59.26067769527435, 58.752454966306686, 56.59318283200264, 55.04751317203045, 65.29398635029793, 58.206720650196075, 58.144438192248344, 53.28023940324783, 54.20296289026737, 47.10036501288414, 48.7447913736105, 48.40518459677696, 60.48591434955597, 62.08350822329521, 66.61002293229103, 61.16018816828728, 64.90820825099945, 60.048877000808716, 63.884436786174774, 61.35979525744915, 64.75168704986572, 59.671937227249146, 65.36625847220421, 61.65631614625454, 66.25161856412888, 51.103575602173805, 52.51746453344822, 10.799435656517744, 0.3474627068499103, 0.43590916553512216, 25.682989060878754, 60.01011148095131, 53.506198078393936, 36.3707971572876, 21.837439611554146, 49.38932038843632, 44.31229121983051, 37.49621316790581, 40.049550756812096, 60.46251900494099, 37.443642988801, 1.165454462170601, 0.040439508156850934, 0.04418748751049861, 0.060386589757399634, 0.03886048878484871, 0.07425517018418759, 0.06447564534028061, 0.03276229472248815, 0.015890684226178564, 0.05650898689054884, 0.10125455461093225, 0.07749565411359072, 0.055630499264225364, 0.11585628788452595, 0.14443105144891888, 0.09281407197704539, 17.616964280605316, 79.43222969770432, 61.57318040728569, 51.20926313102245, 60.34938387572765, 100.36125585436821, 57.98827037215233, 28.292309045791626, 68.65112900733948, 68.87027084827423, 74.5331297814846, 35.88945418596268, 0.4949922545347363, 1.8584891804493964, 0.2681918058078736, 0.10819078554050066, 0.1516559036099352, 8.734277822077274, 24.99593462795019, 36.12473376095295, 55.25804467499256, 58.821501061320305, 59.2944160848856, 61.86086297035217, 61.96036443114281, 61.34769670665264, 63.20320174098015, 60.73155976831913, 53.77705514431, 49.6261502802372, 47.8217639029026, 48.483650386333466, 49.09254491329193, 52.722991704940796, 51.403425112366676, 54.82412315905094, 62.438325583934784, 65.44508144259453, 53.85392501950264, 57.02532984316349, 60.534677132964134, 60.435171872377396, 62.45276860892773, 54.639073088765144, 54.8890882730484, 54.70327824354172, 54.713446497917175, 54.85132209956646, 54.219336211681366, 56.583926528692245, 59.0548275411129, 55.25932140648365, 55.29243282973766, 54.27001789212227, 54.88993562757969, 55.495144352316856, 53.43839071691036, 53.60282689332962, 50.1232548058033, 52.98559941351414, 51.19033254683018, 46.3110713660717, 46.107611283659935, 45.64622104167938, 51.16786055266857, 43.29685650765896, 43.12719561159611, 45.61606585979462, 45.471194833517075, 43.805071637034416, 39.642186015844345, 41.82947784662247, 42.07296498119831, 50.986944660544395, 47.84650057554245, 53.93430970609188, 57.35094957053661, 62.18510337173939, 59.323697313666344, 45.88422507047653, 38.976305946707726, 51.501703038811684, 61.267042234539986, 60.544461607933044, 54.17320288717747, 50.708936378359795, 51.10544130206108, 46.86210259795189, 43.32858480513096, 41.77434280514717, 42.978783175349236, 42.26629100739956, 42.063545286655426, 41.26536011695862, 43.097181022167206, 43.64080645143986, 41.96668468415737, 44.51328903436661, 40.714591071009636, 44.82511170208454, 48.93155135214329, 52.14343540370464, 50.61975136399269, 55.200397968292236, 53.50358381867409, 51.71108320355415, 52.920888885855675, 55.25624357163906, 57.574909552931786, 59.617843329906464, 56.27099052071571, 56.881940737366676, 55.33882074058056, 56.25780902802944, 55.06818026304245, 56.051039323210716, 56.05561047792435, 57.088524252176285, 59.30657163262367, 61.1698130518198, 59.87377479672432, 57.39226095378399, 57.2312293946743, 69.03942257165909, 62.47354969382286, 61.35724939405918, 55.676379427313805, 57.01312109827995, 50.14487944543362, 51.48753359913826, 50.83977475762367, 63.84516969323158, 64.21925961971283, 69.31239232420921, 64.06069412827492, 66.05445474386215, 64.13490414619446, 70.3492122888565, 65.50292953848839, 66.43999725580215, 64.00778576731682, 66.96658059954643, 64.41478952765465, 69.35110464692116, 55.80227427184582, 53.38041342794895, 8.55760345235467, 0.18516496958909556, 0.3318564099026844, 32.03828103840351, 66.44642651081085, 59.30879071354866, 44.136322662234306, 22.424745596945286, 62.772852033376694, 57.05740012228489, 35.3566999733448, 58.25623959302902, 67.21284538507462, 50.698980912566185, 1.7694870312698185, 0.05248933695838787, 0.07373503598500974, 0.04219214555632789, 0.03186787689628545, 0.05671129634720273, 0.08050660660956055, 0.1082015986321494, 0.2530352503526956, 0.16165389446541667, 0.30717394372913986, 0.16206302563659847, 0.19703176250914112, 0.30131750798318535, 0.3280400193762034, 0.13457531546009704, 21.536066383123398, 92.8047077357769, 70.35648509860039, 62.474822625517845, 80.16424521803856, 113.27960506081581, 71.84155941009521, 35.074055939912796, 76.30674540996552, 74.21289816498756, 81.5711273252964, 36.73131041228771, 2.6630918495357037, 1.7572740116156638, 0.8343127404805273, 0.6175879260990769, 0.14330130972666666, 13.357321601361036, 29.05652593821287, 45.508926808834076, 60.64325250685215, 64.05309453606606, 64.64477598667145, 65.51336377859116, 64.82294842600822, 64.19484972953796, 66.63334608078003, 63.41627910733223, 55.67950285971165, 52.58106172084808, 53.00737604498863, 50.93808688223362, 52.087114825844765, 56.00153937935829, 52.88794465363026, 58.54622483253479, 63.318141773343086, 62.93093495070934, 57.76810258626938, 59.021294340491295, 62.59836919605732, 64.26149815320969, 66.1758354306221, 56.77398853003979, 57.31478311121464, 57.23956234753132, 56.91012382507324, 57.82381899654865, 57.65830747783184, 60.319669470191, 63.88183772563934, 59.59084577858448, 60.0763875246048, 58.064851462841034, 57.26240672171116, 61.66274160146713, 57.254385352134705, 58.48302662372589, 53.29620614647865, 58.113568648695946, 57.20420904457569, 52.8988728672266, 48.583516627550125, 48.90298828482628, 53.89508441090584, 47.651856020092964, 46.46832972764969, 50.049831345677376, 49.98803526163101, 47.327406629920006, 43.87063331902027, 48.52411061525345, 43.890513852238655, 54.313764944672585, 50.479405894875526, 57.72740676999092, 60.573856830596924, 66.15593209862709, 60.62921226024628, 44.892945662140846, 38.376101553440094, 54.00183968245983, 66.211416721344, 65.19207581877708, 55.975662767887115, 52.11074575781822, 55.1602379232645, 50.033898800611496, 47.39064663648605, 44.425099566578865, 47.014504820108414, 44.86261568963528, 46.77945323288441, 45.879520922899246, 46.41870819032192, 46.300982907414436, 45.43817460536957, 47.41953648626804, 45.810224041342735, 47.094220742583275, 53.37771937251091, 55.863002613186836, 53.729983270168304, 58.78580957651138, 56.24520890414715, 53.46448011696339, 57.90138803422451, 59.22681771218777, 62.26753614842892, 61.62328451871872, 60.60843117535114, 59.79756988584995, 58.91937620937824, 61.75848126411438, 58.689013570547104, 60.15775255858898, 56.65327660739422, 58.28789949417114, 63.19676488637924, 62.8294537961483, 61.67301245033741, 59.20217223465443, 59.92172062397003, 69.387666285038, 64.53408792614937, 65.27816399931908, 58.215836361050606, 60.722884833812714, 51.7892412096262, 54.54389199614525, 53.48985135555267, 67.45607793331146, 67.50538408756256, 72.32479467988014, 66.37707263231277, 71.92196309566498, 66.14571064710617, 70.0879155099392, 66.04792669415474, 72.332903444767, 68.16863849759102, 73.42729791998863, 67.65986859798431, 76.74668580293655, 60.35612851381302, 63.602237328886986, 13.260829579085112, 0.8514962496701628, 0.4399785096757114, 34.54877592623234, 74.43745091557503, 65.76306357979774, 53.47231149673462, 31.167550161480904, 69.04193803668022, 67.2745768725872, 50.40958844125271, 59.54690873622894, 78.62475782632828, 64.2486472427845, 2.8289479622617364, 0.3366036614170298, 0.2775367215508595, 0.12782224657712504, 0.25416830205358565, 0.15200551453744993, 0.20605604076990858], [0.042004226343124174, 0.07581019963254221, 0.03684432216687128, 0.04582186367770191, 0.05128784439875744, 0.03812813003605697, 0.04656258643080946, 0.18503501953091472, 0.01796492204448441, 19.58595972508192, 64.31088030338287, 47.56265200674534, 41.36746063828468, 61.11018285155296, 91.77025124430656, 52.97928795218468, 21.003030985593796, 46.38049744069576, 63.75769078731537, 58.27727146446705, 65.29540747404099, 3.18319084122777, 2.207098030485213, 0.37348825251683593, 0.4655385506339371, 0.04034813122416381, 1.178771797567606, 16.36186122894287, 21.320395655930042, 46.20356373488903, 52.32826508581638, 56.41153357923031, 56.42653897404671, 57.9681770503521, 57.49527722597122, 55.120374262332916, 52.76075787842274, 50.38518615067005, 47.523031532764435, 45.646164044737816, 46.25048741698265, 46.12292446196079, 46.746110022068024, 55.87198533117771, 53.91689144074917, 63.05782914161682, 54.24355611205101, 48.6201086640358, 56.27023056149483, 57.35990568995476, 57.325498536229134, 56.32803685963154, 52.16765150427818, 51.75131544470787, 46.785316318273544, 54.30833123624325, 53.01614597439766, 52.507539466023445, 54.384133368730545, 54.579382091760635, 52.256973311305046, 52.81863637268543, 52.07335576415062, 53.34944508969784, 48.77342663705349, 49.713872373104095, 50.60069538652897, 45.966008082032204, 40.73936954140663, 49.3685545027256, 48.374239057302475, 45.996528044342995, 43.36356192827225, 47.41817235946655, 46.071737408638, 43.98767463862896, 43.56459014117718, 40.69390498101711, 41.10305942595005, 40.923910439014435, 36.707808673381805, 47.35634587705135, 48.95964704453945, 50.25892652571201, 54.837718829512596, 58.71297888457775, 62.070117741823196, 57.747348099946976, 40.03109514713287, 35.29930405318737, 48.241914957761765, 64.5767292380333, 58.935525342822075, 55.9517240524292, 51.45860955119133, 47.94114209711552, 44.69597563147545, 39.41033385694027, 38.48050855100155, 41.377830281853676, 40.438744872808456, 42.67513006925583, 41.57758556306362, 40.65154865384102, 41.60314679145813, 45.86462952196598, 39.78932172060013, 42.57352352142334, 47.150499522686005, 48.391140550374985, 46.92615196108818, 46.37441396713257, 49.109457805752754, 51.65999494493008, 53.236112371087074, 52.39304021000862, 52.17553608119488, 59.49270844459534, 57.44887791574001, 55.52379861474037, 55.37904918193817, 57.12085671722889, 54.75382313132286, 51.895878687500954, 52.326954156160355, 55.32046392560005, 56.249031499028206, 56.912373304367065, 57.553839683532715, 61.523258686065674, 56.564984545111656, 51.94207660853863, 63.52382093667984, 59.33323860168457, 55.68593591451645, 56.06703266501427, 55.77345281839371, 51.0559793561697, 46.879061087965965, 47.09371916949749, 56.99803590774536, 64.62048009037971, 64.79738339781761, 63.09105075895786, 62.920740097761154, 64.50175166130066, 63.90120908617973, 67.6220378279686, 60.15944346785545, 60.877308547496796, 61.52584634721279, 61.92462354898453, 53.567792773246765, 42.20504209399223, 21.166988387703896, 0.9283650561701506, 0.43193425226490945, 0.13716944813495502, 45.342362746596336, 61.97308614850044, 56.41052283346653, 27.645355761051178, 25.581882186233997, 43.05605962872505, 52.098700404167175, 35.26302359998226, 31.00688148289919, 53.64854983985424, 47.45773583650589, 2.3634375538676977, 0.005172963192308089, 0.07534546675742604, 0.030928878259146586, 0.14177766570355743, 0.05103027833683882, 0.04952304319886025, 0.040062909029074945, 0.03341255338455085, 0.053854788493481465, 0.07985221789567731, 0.08320627268403769, 0.025616728053137194, 0.02025641246291343, 0.08429268782492727, 0.04816669781575911, 24.843994081020355, 75.24352446198463, 53.733387887477875, 45.44839225709438, 66.6435295343399, 95.5032317340374, 58.69123265147209, 31.1277586966753, 51.665181666612625, 71.60719558596611, 62.2218170017004, 74.79370459914207, 3.7368258833885193, 0.6338667869567871, 0.19233794562751427, 0.4467002599267289, 0.11961217111092992, 0.8165079052560031, 17.679482325911522, 32.56857678294182, 54.4129928201437, 54.26940232515335, 59.992229640483856, 58.23662504553795, 59.96093451976776, 57.0490063726902, 58.57285760343075, 54.80150677263737, 53.45108583569527, 47.81882286071777, 49.24759179353714, 48.14457178115845, 49.32322293519974, 49.81796018779278, 57.4333443492651, 57.66142711043358, 66.90324559807777, 59.572842344641685, 50.84598742425442, 58.49252991378307, 59.250517040491104, 59.91508238017559, 59.15574252605438, 55.17503432929516, 54.6581556648016, 50.31006418168545, 54.87301513552666, 54.9897600710392, 54.55542057752609, 55.575046464800835, 56.26385450363159, 57.015180587768555, 55.18897198140621, 55.38216881453991, 52.93938249349594, 47.504157945513725, 50.56139409542084, 52.50795364379883, 49.388640224933624, 43.03952671587467, 51.56504563987255, 50.065634697675705, 49.27292123436928, 46.45695313811302, 48.29165808856487, 47.95334704220295, 47.1575291454792, 46.4561627805233, 42.49081715941429, 42.85796105861664, 42.114618346095085, 39.45342354476452, 50.30219480395317, 53.02351377904415, 51.8714763969183, 55.109294056892395, 59.43894512951374, 63.13890539109707, 56.19050703942776, 39.56360623240471, 34.93727847933769, 45.93076877295971, 66.02955847978592, 59.875047728419304, 56.11088991165161, 51.121248453855515, 51.30971074104309, 46.34780399501324, 40.176608338952065, 40.34942306578159, 44.084972217679024, 43.18788595497608, 46.62791736423969, 44.538394287228584, 41.403152123093605, 44.519057124853134, 47.33145721256733, 43.74852307140827, 46.86370611190796, 48.83445896208286, 52.241751328110695, 51.01929992437363, 51.54856212437153, 50.80748029053211, 54.026257172226906, 55.35153105854988, 54.6703340113163, 57.04018324613571, 60.34812234342098, 60.09482033550739, 58.78931298851967, 56.01906783878803, 58.04301403462887, 55.49276188015938, 54.23930034041405, 55.633719116449356, 57.417829781770706, 58.95769715309143, 59.65144872665405, 60.613819286227226, 62.66464903950691, 58.7299145758152, 51.89451076090336, 65.47025129199028, 62.67371915280819, 60.37291221320629, 58.770572394132614, 58.36344704031944, 54.75541524589062, 50.314357951283455, 47.80156798660755, 59.527693167328835, 68.1915132701397, 66.91908314824104, 65.6588351726532, 65.18681690096855, 66.70061007142067, 67.37960323691368, 74.35398459434509, 63.264648243784904, 64.14117380976677, 65.12146040797234, 64.874716848135, 57.81499207019806, 48.3211787045002, 19.94073908776045, 0.8084627869538963, 0.14707547205034643, 0.26549101166892797, 53.75188909471035, 68.93098399043083, 61.353951171040535, 31.982621625065804, 27.40919653326273, 50.58925420045853, 63.198357000947, 31.02967645972967, 45.375496968626976, 62.074772492051125, 62.47076824307442, 4.5090769696980715, 0.13390862935921177, 0.10014842060627416, 0.09988829042413272, 0.09212642020429485, 0.0224881581380032, 0.06009887765685562, 0.17063992243492976, 0.1654721552040428, 0.11092091677710414, 0.20883995544863865, 0.1784935814794153, 0.1173235806345474, 0.11935710979741998, 0.2891513326903805, 0.14849681843770668, 29.513789601624012, 88.06259259581566, 61.42808139324188, 58.90427201986313, 73.15805196762085, 98.40613156557083, 61.81454345583916, 37.488176599144936, 60.46985641121864, 77.2209383547306, 66.80412411689758, 80.5965556204319, 3.6797493835911155, 5.873605124652386, 0.439660603296943, 1.5452418266795576, 0.24612897250335664, 2.6189066329970956, 22.40795809775591, 44.64124336838722, 61.44760474562645, 58.02638232707977, 65.34588396549225, 60.19776441156864, 63.62948566675186, 61.26513473689556, 61.630724519491196, 57.726107239723206, 57.30303794145584, 51.164759919047356, 51.57134190201759, 51.15718312561512, 51.66829749941826, 52.91626073420048, 60.006908252835274, 61.42899714410305, 62.946647107601166, 61.82682439684868, 54.57713641226292, 60.13137437403202, 60.90109907090664, 61.275933757424355, 62.48711496591568, 56.98189057409763, 55.70698298513889, 54.462526962161064, 57.62272238731384, 57.37739995121956, 58.897143602371216, 60.18363676965237, 61.130036786198616, 62.32681296765804, 60.09847193956375, 58.54009196162224, 56.309159472584724, 51.99516735970974, 54.4641874730587, 58.968127593398094, 55.289647579193115, 49.085165709257126, 55.03159582614899, 55.347488075494766, 52.673495560884476, 49.76801186800003, 52.30415537953377, 49.73584659397602, 50.522795766592026, 50.02940744161606, 47.049569338560104, 46.85977712273598, 45.37862420082092, 44.12425830960274, 53.056454211473465, 56.78537651896477, 52.33507812023163, 59.32603418827057, 62.801434099674225, 64.85484391450882, 59.14738677442074, 40.34356378018856, 35.14691703021526, 47.72362656891346, 70.67672431468964, 61.51864193379879, 60.51023684442043, 55.08465617895126, 54.80038583278656, 50.31110152602196, 43.57748664915562, 46.39225780963898, 47.973976135253906, 46.08685679733753, 48.02343808114529, 48.05863559246063, 43.56051295995712, 48.115438744425774, 52.43101917207241, 46.23735152184963, 51.30029484629631, 53.35349567234516, 57.37226642668247, 54.60582107305527, 54.49627675116062, 53.9631387591362, 56.852492317557335, 59.04077589511871, 58.698722049593925, 58.831578120589256, 64.98374819755554, 64.96766746044159, 62.84433759748936, 59.78784620761871, 61.68934777379036, 60.069920271635056, 58.16441752016544, 57.168213576078415, 59.645790830254555, 61.602435037493706, 60.49710854887962, 62.22508482635021, 66.91571652889252, 61.71691529452801, 53.193520456552505, 64.3645030260086, 62.339257299900055, 62.983098551630974, 61.91794350743294, 60.304983258247375, 57.16996148228645, 52.94452361762524, 52.07429051399231, 64.3945062160492, 69.7263953089714, 70.09322002530098, 68.97008389234543, 67.84989640116692, 69.23660159111023, 68.8219678401947, 73.49496468901634, 65.77415138483047, 67.38287106156349, 69.57775488495827, 70.4320402443409, 65.49709305167198, 54.6801944822073, 27.963809072971344, 1.193672816734761, 0.5536507163196802, 0.4082222777651623, 59.099019169807434, 75.08049800992012, 69.07485947012901, 42.543524131178856, 38.6373907327652, 54.350193589925766, 75.12882381677628, 47.203776463866234, 48.16184185445309, 72.61575266718864, 77.47996285557747, 6.929672006517649, 0.25367299269419163, 0.1848788419738412, 0.10766049876110628, 0.29642185661941767, 0.1553376388619654, 0.19036798883462325], [0.02859418742445996, 0.12072190453181975, 0.06970840986468829, 0.07706208401941694, 0.20934031141223386, 0.09247206064173952, 0.1052155377692543, 0.13141713570803404, 0.14263486111303791, 32.142919823527336, 62.805355489254, 53.305606842041016, 45.94005927443504, 59.21037219464779, 87.64459982514381, 38.09832885861397, 17.647351250052452, 41.03931784629822, 76.97845056653023, 54.605912268161774, 74.57324042916298, 19.89528212696314, 0.5387869232799858, 0.2773241704562679, 0.1575751102063805, 0.16146733338246122, 0.2862620627274737, 5.386419966816902, 15.682590678334236, 45.50147920846939, 53.225419744849205, 53.33126686513424, 53.4562573581934, 52.50136099755764, 50.42056605219841, 49.99933585524559, 48.86276364326477, 46.09947592020035, 46.325704380869865, 46.428614258766174, 47.6343047618866, 47.85257264971733, 52.107310742139816, 54.47443552315235, 57.60766379535198, 62.306286469101906, 43.770178109407425, 48.865298107266426, 57.49976098537445, 58.601899445056915, 55.67025415599346, 55.16168184578419, 53.60737144947052, 52.228820621967316, 48.48282963037491, 52.900917157530785, 53.66219110786915, 55.42995125055313, 54.98159810900688, 54.68110263347626, 53.49606782197952, 53.83713372051716, 53.935008868575096, 52.243757620453835, 51.71401284635067, 48.78984555602074, 53.09908792376518, 50.805398002266884, 41.142664700746536, 45.29158987104893, 48.580237403512, 49.15887035429478, 43.96391451358795, 44.02138262987137, 46.33758634328842, 44.33601714670658, 43.953446075320244, 42.20213524997234, 45.563172698020935, 38.48842732608318, 45.397209003567696, 46.36357694864273, 51.52562655508518, 51.56528502702713, 54.29451897740364, 58.19110728800297, 64.56631019711494, 52.555458694696426, 38.61470974981785, 37.15742714703083, 45.18975153565407, 63.11465509235859, 62.32818089425564, 55.76953902840614, 52.103203162550926, 50.63657686114311, 45.426296442747116, 44.2256710678339, 41.45680904388428, 42.02525094151497, 40.105460956692696, 41.650203466415405, 43.79250951111317, 44.577634781599045, 41.7842260748148, 40.77246196568012, 41.13126531243324, 45.685241147875786, 46.63318768143654, 46.632439121603966, 48.38471509516239, 47.31250002980232, 51.201006174087524, 53.59572887420654, 51.95823714137077, 51.73012018203735, 54.31404232978821, 57.1085149794817, 53.85565012693405, 54.929164722561836, 54.23023782670498, 56.062332317233086, 53.319943472743034, 50.58093264698982, 50.77350251376629, 55.61991445720196, 53.28217729926109, 59.48911003768444, 59.24089975655079, 60.37165828049183, 59.33318920433521, 54.950112998485565, 61.52134358882904, 59.94247131049633, 58.41627560555935, 57.95420140028, 57.621479853987694, 52.923221960663795, 46.698544174432755, 46.06291048228741, 51.00269101560116, 62.23917447030544, 63.167628049850464, 67.07658469676971, 65.36867514252663, 64.47625502943993, 61.406996324658394, 63.28555092215538, 57.51263089478016, 60.482764318585396, 57.612227350473404, 58.485276103019714, 40.493127554655075, 23.6781919375062, 2.168772337026894, 0.1736171220545657, 0.030771465026191436, 0.9801301534753293, 62.629261538386345, 58.20213049650192, 68.52906435728073, 33.344088569283485, 19.149898923933506, 41.17689326405525, 47.65288956463337, 33.300877287983894, 38.86955067515373, 52.482362017035484, 49.17062312364578, 9.158254321664572, 0.24399887508479878, 0.1923696798621677, 0.019365716507309116, 0.04213173102471046, 0.12739733734633774, 0.04380789010610897, 0.04573600090225227, 0.06830303449532948, 0.022727578689227812, 0.06950319118914194, 0.031190373993013054, 0.09893427442875691, 0.07814536729711108, 0.04177141090622172, 0.06901545173604973, 37.33900800347328, 73.8767758011818, 59.858214631676674, 61.88231661915779, 76.44238293170929, 92.11777299642563, 46.5997114777565, 27.736239284276962, 47.61673830449581, 83.31597849726677, 59.88674350082874, 80.57146176695824, 23.56305241584778, 0.5189244984649122, 1.541654106695205, 0.08615014245151542, 0.25775305344723165, 0.16000166593585163, 6.1110819317400455, 29.267549514770508, 54.47212144732475, 58.16108889877796, 57.8761687874794, 54.94743414223194, 54.655058830976486, 53.23213018476963, 53.563951179385185, 50.51486179232597, 50.09095273911953, 48.54826591908932, 49.38701011240482, 50.5924042314291, 49.42640259861946, 54.70201291143894, 57.29770302772522, 60.38403041660786, 70.52394211292267, 47.58895419538021, 51.25754714012146, 59.02660645544529, 60.16335725784302, 58.962811678647995, 57.32850417494774, 55.07948465645313, 53.73937636613846, 50.93802608549595, 55.47870263457298, 57.523304522037506, 55.64369738101959, 57.733490243554115, 58.55445139110088, 55.461630150675774, 57.18853488564491, 56.652227863669395, 52.08177611231804, 51.898367553949356, 51.204418390989304, 54.072827473282814, 52.41246096789837, 46.32203757762909, 48.444307297468185, 51.37584999203682, 50.79140715301037, 46.31439618766308, 45.95642879605293, 47.9229486733675, 46.58699356019497, 48.07937107980251, 44.380482360720634, 45.58336481451988, 41.74816980957985, 45.32750554382801, 49.00279372930527, 55.05616530776024, 51.41483210027218, 56.211599707603455, 59.24738980829716, 63.05397614836693, 53.570399433374405, 39.26375292241573, 36.20676375925541, 43.50633926689625, 65.8221960067749, 65.8798997104168, 56.29263415932655, 54.589261561632156, 55.40134258568287, 48.91056887805462, 48.13560426235199, 42.92570762336254, 43.44356283545494, 41.765857860445976, 44.85422573983669, 44.59552802145481, 46.759325712919235, 45.07797673344612, 42.88537658751011, 45.115625113248825, 47.68643796443939, 51.2737874686718, 49.70055788755417, 50.20919479429722, 51.31834767758846, 54.52017366886139, 54.525219798088074, 54.17971193790436, 53.68013754487038, 57.92694166302681, 57.5965341925621, 57.66377538442612, 58.38488169014454, 57.52718411386013, 59.486883357167244, 55.24416022002697, 51.67593128979206, 54.85748916864395, 57.20985174179077, 54.90156300365925, 60.68911224603653, 60.26076503098011, 62.10066810250282, 61.266012489795685, 55.4895206540823, 62.3724827170372, 60.77159442007542, 61.50720074772835, 59.76581498980522, 59.750862792134285, 56.64663456380367, 50.06969287991524, 48.354157134890556, 52.199262008070946, 65.12392267584801, 64.4416768848896, 66.8215423822403, 67.94167667627335, 66.34871855378151, 65.93138694763184, 73.76570776104927, 61.79541528224945, 62.24862076342106, 62.556476444005966, 60.83588697016239, 49.59411419928074, 24.499211981892586, 1.453322977758944, 0.30806858791038394, 0.5404770013410598, 1.9610385526902974, 69.13380950689316, 64.69676479697227, 73.44232231378555, 38.87500338256359, 22.183420546352863, 46.25453419983387, 59.81825977563858, 33.86387027800083, 47.42759205400944, 60.796726271510124, 62.24526934325695, 13.369827680289745, 0.4032305034343153, 0.16861092037288472, 0.054563921730732545, 0.07755412792903371, 0.11523263892740943, 0.04106073400180321, 0.12151216564234346, 0.31338144501205534, 0.16658683132845908, 0.16438283084426075, 0.31373898207675666, 0.23675638949498534, 0.19236948690377176, 0.31215185474138707, 0.200251629576087, 43.77699114382267, 85.7442381978035, 67.56371855735779, 62.316910699009895, 71.59481585025787, 93.24108392000198, 52.87241488695145, 32.607247307896614, 55.92002235352993, 87.0556466281414, 65.3948025405407, 86.0658985376358, 25.275145545601845, 2.5470835994929075, 2.7478598384186625, 0.14015800261404365, 0.2646906499285251, 0.30534208577591926, 9.072101544588804, 41.32738798856735, 62.469556108117104, 62.68488675355911, 63.998058289289474, 58.05760905146599, 59.33766536414623, 54.091651663184166, 57.18395993113518, 52.91342228651047, 55.276329293847084, 51.00815512239933, 53.49723055958748, 52.36718259751797, 53.50688584148884, 56.23887084424496, 62.58337900042534, 59.654579758644104, 65.41875645518303, 51.28664217889309, 51.6480977833271, 60.80384708940983, 64.18463587760925, 61.02555379271507, 58.46866339445114, 58.859016448259354, 57.02260918915272, 54.6531817317009, 57.16019980609417, 60.04839822649956, 60.4971769452095, 61.233178451657295, 60.84962323307991, 60.32106399536133, 60.880420580506325, 61.33772984147072, 55.83915889263153, 54.59613159298897, 55.15693210065365, 59.65372480452061, 56.733098924160004, 50.83660952746868, 51.939998120069504, 57.753572165966034, 54.98805396258831, 48.54423813521862, 50.49217700958252, 53.02380256354809, 50.117798298597336, 49.370606392621994, 47.23567955195904, 50.296650901436806, 43.57644930481911, 50.54782122373581, 53.64956058561802, 56.577786058187485, 55.27917914092541, 59.37611550092697, 61.90256953239441, 65.91007769107819, 55.34042805433273, 40.00237628817558, 37.34572984278202, 44.99177075922489, 66.91430300474167, 68.29606086015701, 59.501497372984886, 56.02007478475571, 56.95621535181999, 51.85976542532444, 51.34816087782383, 47.23172776401043, 47.25932568311691, 43.526033610105515, 49.03970494866371, 47.99872800707817, 49.37116116285324, 46.14554464817047, 46.5498049557209, 47.437133342027664, 55.18772564828396, 52.98696354031563, 52.435362339019775, 54.92551311850548, 52.99802094697952, 56.2174703925848, 59.35362070798874, 57.05933801829815, 57.64084741473198, 60.66596768796444, 62.679897621273994, 59.221361204981804, 62.6949942111969, 59.66048464179039, 62.14404657483101, 56.56447917222977, 54.32885393500328, 56.17314577102661, 60.20060285925865, 56.45100586116314, 62.87141874432564, 61.43831804394722, 64.3157896399498, 62.983254343271255, 56.22043803334236, 60.20353250205517, 63.82052421569824, 63.06182272732258, 61.95696361362934, 61.91804990172386, 58.686304315924644, 51.65491081774235, 50.44964209198952, 55.801157131791115, 69.59494516253471, 67.12444692850113, 71.8416354060173, 69.48751732707024, 68.5905222594738, 65.79082489013672, 67.30458006262779, 62.837140783667564, 68.09508204460144, 70.70966854691505, 69.68923330307007, 58.32209765911102, 33.874961882829666, 2.84902133513242, 0.4015217529376969, 0.4687516641570255, 1.7616618261672556, 78.5721230506897, 70.78170508146286, 81.1300165951252, 48.279019966721535, 32.57944419980049, 52.34548196196556, 69.53503757715225, 45.22113025188446, 55.13730615377426, 69.90367859601974, 75.78520819544792, 19.17192254215479, 0.8368685189634562, 0.3883992461487651, 0.206808652728796, 0.27087449154350907, 0.24725743773160502, 0.24312391265993938], [0.009010160756588448, 0.09089076658710837, 0.0636068353196606, 0.030113950015220325, 0.1831167607451789, 0.1350952047505416, 0.0878654609550722, 0.35753635223954916, 0.20409062592079863, 26.0345271974802, 60.22712543606758, 46.57291531562805, 20.28258964419365, 19.263571724295616, 35.37494279444218, 39.00326170027256, 31.222632005810738, 23.2335701957345, 70.93576401472092, 62.45639741420746, 65.78391686081886, 48.63301657140255, 0.4557264380855486, 0.40457275172229856, 0.240571963659022, 0.42943223495967686, 0.1607979607069865, 3.826549518853426, 12.265330497175455, 49.27395097911358, 55.63404209911823, 54.02100585401058, 56.01861946284771, 51.10112473368645, 54.80897717177868, 49.51065547764301, 49.52181927859783, 42.842488288879395, 49.47525657713413, 44.731062948703766, 49.43886213004589, 48.98143507540226, 56.54226936399937, 54.63078573346138, 66.60286411643028, 44.33616913855076, 42.09361307322979, 55.31654633581638, 58.15511181950569, 59.706743359565735, 58.76623682677746, 55.50218917429447, 54.77271191775799, 50.35481058061123, 49.2657358199358, 53.67890261113644, 53.901813849806786, 53.75765338540077, 55.570577904582024, 50.48271931707859, 53.813985362648964, 51.88520886003971, 52.01849810779095, 51.172606498003006, 52.8515388071537, 53.83492223918438, 54.72308658063412, 51.325278505682945, 50.789184272289276, 43.38968552649021, 45.122331753373146, 45.30007481575012, 44.34669837355614, 46.54895760118961, 42.800743728876114, 42.710129991173744, 43.32691289484501, 43.835196420550346, 45.499073937535286, 45.89987263083458, 46.04777969419956, 47.873380333185196, 52.41572879254818, 53.064600974321365, 55.76794691383839, 55.94045005738735, 64.513189047575, 49.87648464739323, 36.20798349380493, 37.41191849112511, 46.15065537393093, 64.79048296809196, 59.62595209479332, 57.12674260139465, 53.57345826923847, 51.2724993377924, 49.27363179624081, 43.80672074854374, 42.13035710155964, 39.36459571123123, 46.4173174649477, 44.52170178294182, 46.44453540444374, 43.679256588220596, 39.939136281609535, 44.54813316464424, 44.39693547785282, 47.17763766646385, 49.20242361724377, 48.38649719953537, 50.04084102809429, 50.17389088869095, 51.29123613238335, 51.71153537929058, 54.54451136291027, 51.13576367497444, 50.6562902033329, 50.13378024101257, 52.52262465655804, 56.35333210229874, 54.75307077169418, 55.750247463583946, 56.841396912932396, 51.85710556805134, 50.77551640570164, 54.46116663515568, 52.520025596022606, 59.52639743685722, 58.41979041695595, 60.38796700537205, 61.00742496550083, 57.52403788268566, 59.64935503900051, 56.88567593693733, 56.26834586262703, 59.12665508687496, 57.85103693604469, 52.388697043061256, 47.51716464757919, 46.89428687095642, 48.52357864379883, 58.78717750310898, 63.718963265419006, 63.384383618831635, 64.3573746085167, 66.96557745337486, 59.78544853627682, 62.22728110849857, 58.43487560749054, 53.63249950110912, 60.84276080131531, 42.28101521730423, 17.414406649768353, 4.73324166610837, 0.18470832612365484, 0.2336268566432409, 0.1630273277987726, 7.11950839497149, 71.83008402585983, 56.16715349256992, 70.5502898991108, 35.33875733613968, 21.378640830516815, 33.70655111968517, 49.58597123622894, 31.97329692542553, 32.92116366326809, 49.533226266503334, 59.013269171118736, 15.44249676167965, 0.26188399584498256, 0.1319395483005792, 0.03828519817034248, 0.10012897633714601, 0.047186127776512876, 0.080985662934836, 0.0296333388905623, 0.06456844348576851, 0.029698931757593527, 0.13857773272320628, 0.11108964405138977, 0.1309488108381629, 0.11068125502788462, 0.33485308347735554, 0.2835219941334799, 30.10410502552986, 71.79565787315369, 52.60109044611454, 29.264718666672707, 35.5846231430769, 43.99760730564594, 39.73171681165695, 46.27458192408085, 34.923903197050095, 75.54555505514145, 70.60712724924088, 69.75483298301697, 54.615191370248795, 0.905279751168564, 0.6832736951764673, 0.13509201351553202, 0.4947531345533207, 0.06490891857538372, 4.165070028975606, 23.09525951743126, 55.918696224689484, 57.26508557796478, 58.1981635093689, 58.46593514084816, 53.69210310280323, 56.10629975795746, 51.0136192291975, 51.28983020782471, 49.084333553910255, 50.08979760110378, 47.45485179126263, 51.80574372410774, 51.57525949180126, 58.62280212342739, 58.49017024040222, 71.67583510279655, 51.36864937841892, 43.43888908624649, 57.01467141509056, 60.44600509107113, 61.71241633594036, 61.4153216779232, 56.975639909505844, 57.41657964885235, 52.906430661678314, 51.289484426379204, 53.96621659398079, 55.107785537838936, 57.42573715746403, 55.86043395102024, 54.375188648700714, 56.73673152923584, 54.315239265561104, 54.89398621022701, 55.20609386265278, 54.26772281527519, 53.63680846989155, 56.37929990887642, 54.11714069545269, 53.71424451470375, 46.53475396335125, 46.22569374740124, 47.093555778265, 48.17192651331425, 48.901886343955994, 45.96903271973133, 44.831658750772476, 45.30672445893288, 47.31326378881931, 48.006749376654625, 47.34723016619682, 47.40597881376743, 49.149796441197395, 54.466292560100555, 54.45569112896919, 59.26736533641815, 57.19047658145428, 65.0932203233242, 51.00373595952988, 35.959872007369995, 36.94124914705753, 46.80239260196686, 66.00485220551491, 60.96797168254852, 55.81226393580437, 54.73191350698471, 55.559087321162224, 52.30823636054993, 46.91119596362114, 43.838650435209274, 41.46867960691452, 47.88609445095062, 45.47137722373009, 49.55955505371094, 46.421128660440445, 42.846766859292984, 46.19173116981983, 48.062522783875465, 50.433219373226166, 50.115172639489174, 50.92661529779434, 53.81909988820553, 52.42116630077362, 53.95958214998245, 54.33050684630871, 58.785099014639854, 53.1085342168808, 52.20739357173443, 53.34921710193157, 55.10794132947922, 60.29778644442558, 54.82157349586487, 56.79776385426521, 57.43756212294102, 53.44573952257633, 52.065307796001434, 53.934689685702324, 54.49537619948387, 61.08025185763836, 59.77665200829506, 61.515035927295685, 62.186919674277306, 56.02415956556797, 57.19911731779575, 62.85562299191952, 59.056598246097565, 65.04551768302917, 60.59713818132877, 56.61920763552189, 50.71381911635399, 48.74043680727482, 50.68220481276512, 62.22540020942688, 64.14117380976677, 66.16275653243065, 65.87185934185982, 70.90200662612915, 58.090192303061485, 73.2326951622963, 66.90145209431648, 54.40954640507698, 62.245865911245346, 48.77370402216911, 24.52959895133972, 3.6644480796530843, 0.1476986682973802, 1.0061077564023435, 0.1679729702300392, 8.829375319182873, 83.33574503660202, 61.46619334816933, 82.06003189086914, 41.619117334485054, 29.635953046381474, 42.56078280508518, 58.26962247490883, 30.314353443682194, 32.16426707804203, 61.85303919017315, 68.51806774735451, 24.06781543046236, 0.5981045903172344, 0.32931470253970474, 0.08731697671464644, 0.16569904459174722, 0.10908152602496557, 0.08707044267794117, 0.14056541200261563, 0.22318626375636086, 0.23250903381267563, 0.3007491712924093, 0.301347995409742, 0.18901680508861318, 0.21918972430285066, 0.5899989721365273, 0.3512233175570145, 38.93080718815327, 81.89961969852448, 63.802649974823, 31.895249113440514, 28.467728532850742, 51.42950311303139, 54.43602718412876, 46.090614795684814, 38.83384019136429, 81.73150151968002, 75.16807571053505, 75.97568437457085, 54.63095672428608, 1.1994080152362585, 1.6045673307962716, 1.1606072285212576, 1.226660271640867, 0.1460518574458547, 6.243193717673421, 34.44123789668083, 65.5683696269989, 60.51036223769188, 63.952225148677826, 61.580027639865875, 58.57686638832092, 61.054728627204895, 55.14678284525871, 53.18488731980324, 51.52830921113491, 52.40283228456974, 50.62950924038887, 52.80928507447243, 55.82960620522499, 59.848730340600014, 65.00582501292229, 63.40920768678188, 51.19199685752392, 45.884597450494766, 57.84983620047569, 63.22618670761585, 64.6240746974945, 65.86131110787392, 59.74569886922836, 60.91964967548847, 54.68473523855209, 54.5227537304163, 58.94622936844826, 58.79275940358639, 59.214665964245796, 60.232205763459206, 57.679286152124405, 60.43891467154026, 57.524683848023415, 59.235948622226715, 59.91205394268036, 55.75903259217739, 58.484128564596176, 59.660815224051476, 59.443949460983276, 57.34807312488556, 51.57351918518543, 51.09205462038517, 51.27935416996479, 53.126530051231384, 51.31931282579899, 49.39656659960747, 49.579086005687714, 50.4114693403244, 50.05341075360775, 50.910564959049225, 50.9966379404068, 54.05974857509136, 52.452924996614456, 57.17868961393833, 58.25593940913677, 62.188435792922974, 60.69504752755165, 69.38010469079018, 50.98011642694473, 37.00316682457924, 37.490277886390686, 49.53857257962227, 67.34159007668495, 64.0844352543354, 59.62122514843941, 57.7893890440464, 57.63268165290356, 55.397489592432976, 49.29036609828472, 45.844824984669685, 44.44412134587765, 53.455535396933556, 52.85754628479481, 53.31767499446869, 50.49335494637489, 46.922021582722664, 53.46621282398701, 52.493313029408455, 53.60916495323181, 55.75131140649319, 53.926767110824585, 58.02456982433796, 53.423772901296616, 55.530927032232285, 55.332927256822586, 62.74701341986656, 55.59854820370674, 55.71265608072281, 57.70636349916458, 60.29194615781307, 63.702711537480354, 58.81504140794277, 58.70665222406387, 63.14346894621849, 57.20154158771038, 54.870184287428856, 55.60942701995373, 57.271742820739746, 63.77225160598755, 63.07019367814064, 65.45755997300148, 68.22315037250519, 57.22945488989353, 58.05534057319164, 63.3944720774889, 59.10975739359856, 67.00125753879547, 62.88711570203304, 57.874869257211685, 53.65284740924835, 51.5787249058485, 54.93756987154484, 65.39606407284737, 69.63371828198433, 68.24967294931412, 70.12283563613892, 71.5371273458004, 62.63566039502621, 66.46329760551453, 63.51487621665001, 60.6749352067709, 64.65695813298225, 62.26703457534313, 37.20137178897858, 6.325555723160505, 0.15133611217606813, 0.5265943869017065, 0.3136449074372649, 9.686328135430813, 88.5592183470726, 67.77903020381927, 85.75591877102852, 49.1391646116972, 35.70774033665657, 44.02444526553154, 69.11433175206184, 43.82473938167095, 49.60954897105694, 69.94761943817139, 81.87886521220207, 30.15757005661726, 0.8484767179470509, 0.4463900125119835, 0.1695656488300301, 0.3299916599644348, 0.24033921130467206, 0.35099681408610195], [0.04019775726192165, 0.15340774320065975, 0.07092366926372051, 0.14262834505643696, 0.06549176425323822, 0.023238586327352095, 0.0629253730585333, 0.29014898696914315, 0.18063013558275998, 19.5400220900774, 69.68649744987488, 52.502968311309814, 46.56682424247265, 28.218159824609756, 37.30751149356365, 62.21877336502075, 23.184963203966618, 10.230419039726257, 45.26386275887489, 69.48493346571922, 56.32401667535305, 67.10310727357864, 15.427263379096985, 0.27810645347926766, 0.2255461597815156, 0.7522438536398113, 0.15866326197283342, 0.49206549127120525, 4.448351003229618, 53.85762222111225, 56.009397357702255, 55.352264419198036, 59.08703461289406, 57.98813357949257, 59.18103776872158, 58.08526396751404, 53.47987309098244, 46.33098229765892, 48.90289708971977, 45.92970862984657, 47.24015571177006, 53.57632711529732, 58.24505299329758, 55.576505586504936, 55.77862434089184, 38.29195126891136, 48.451956287026405, 51.463545486330986, 62.839732244610786, 57.86316588521004, 60.861220210790634, 53.511958569288254, 54.36333708465099, 51.48470275104046, 47.72753655910492, 50.91418236494064, 58.50994437932968, 51.96737565100193, 53.47433298826218, 53.689971417188644, 55.78096501529217, 52.77098312973976, 52.7004437148571, 49.89298716187477, 50.7948649674654, 48.831107541918755, 55.78448362648487, 50.497325733304024, 50.655788630247116, 46.93386934697628, 45.09731009602547, 49.552392438054085, 45.5208695679903, 42.72292010486126, 44.43564020097256, 44.10461716353893, 44.126511588692665, 43.41586612164974, 46.06844298541546, 45.90743042528629, 45.212508514523506, 45.93405559659004, 49.619622230529785, 55.7440309971571, 54.21658895909786, 46.451245844364166, 60.264131650328636, 52.680551782250404, 38.04365359246731, 36.51132881641388, 46.73052705824375, 64.38645824790001, 56.64194941520691, 53.33276018500328, 53.76660190522671, 52.756604701280594, 47.990953624248505, 47.22113013267517, 45.73737435042858, 45.16203202307224, 44.65829685330391, 46.69467978179455, 44.19722579419613, 31.63831640034914, 35.78277111053467, 43.36088687181473, 44.08174239099026, 47.26670488715172, 49.21567730605602, 48.712246119976044, 49.546115174889565, 50.70400424301624, 51.26983568072319, 53.013201132416725, 48.75479243695736, 46.99207082390785, 49.9660724401474, 50.90232700109482, 54.931437000632286, 55.28364770114422, 52.70079329609871, 56.45913362503052, 54.761605113744736, 51.54589466750622, 48.21927957236767, 53.86650234460831, 51.67337402701378, 59.674448892474174, 59.19461064040661, 61.19241423904896, 59.22955736517906, 60.3433346003294, 53.60654689371586, 56.25763803720474, 62.443823888897896, 58.442452400922775, 59.236112013459206, 55.49039080739021, 48.960198014974594, 46.58055290579796, 46.566573455929756, 51.16738177835941, 58.13924007117748, 62.78963953256607, 66.37598589062691, 68.78172799944878, 61.79194226861, 41.70375399291515, 57.86172576248646, 62.20504850149155, 43.809186816215515, 14.53358268365264, 3.676798129454255, 0.15686738333897665, 0.13075815310003236, 1.2159459153190255, 0.5887081101536751, 16.95901818573475, 71.11515998840332, 54.93606895208359, 67.73963391780853, 26.015980392694473, 15.185571648180485, 26.48604366928339, 49.68920789659023, 48.89013737440109, 51.6119085252285, 41.12913362681866, 61.13624185323715, 27.01621402055025, 0.32318192068487406, 0.09678014626842923, 0.039531891234219074, 0.07276568721863441, 0.06704971034196205, 0.12434452029992826, 0.0430630558548728, 0.018222716316813603, 0.06589599724975415, 0.10011327991378494, 0.10859082540264353, 0.1405372252338566, 0.06627795097301714, 0.40591713739559054, 0.2595087670488283, 25.228250361979008, 77.93125703930855, 60.72989545762539, 45.15147238969803, 31.30849599838257, 46.824522614479065, 71.32688462734222, 26.816739924252033, 16.281985715031624, 51.60458251833916, 75.40581375360489, 65.24838119745255, 74.51525554060936, 19.167083501815796, 0.6916614482179284, 0.36901998915709555, 0.3660403849789873, 0.10290252321283333, 0.7048031617887318, 9.91942472755909, 59.76472444832325, 59.89439629018307, 59.616634994745255, 61.48582309484482, 63.4701032191515, 62.2188987582922, 60.79754702746868, 57.30222098529339, 48.69311414659023, 51.418122723698616, 50.03456376492977, 51.21834844350815, 55.43531656265259, 60.73956973850727, 58.97830344736576, 63.792656511068344, 42.56907396018505, 50.18180586397648, 53.72328042984009, 66.01271018385887, 60.19899934530258, 63.56798596680164, 54.84556160867214, 57.13592290878296, 53.871362283825874, 50.2398781478405, 52.47610755264759, 59.13399629294872, 55.06353311240673, 55.0122282654047, 56.18426397442818, 59.287888035178185, 54.082699343562126, 53.60584393143654, 52.23968803882599, 51.458278968930244, 51.33078061044216, 57.572850063443184, 53.467128574848175, 55.57284638285637, 50.76469838619232, 48.27928215265274, 50.40476270020008, 47.772750332951546, 44.74047504365444, 46.482510566711426, 49.37672786414623, 46.62570968270302, 46.066725477576256, 49.409041330218315, 47.74220757186413, 48.60597722232342, 49.022575467824936, 50.76800420880318, 55.995368510484695, 54.94421571493149, 51.44425772130489, 62.125271782279015, 52.64583684504032, 36.896958723664284, 36.35143719613552, 46.578664407134056, 65.61737939715385, 57.71827965974808, 55.76314017176628, 55.96659645438194, 53.94903391599655, 51.916519179940224, 50.10532736778259, 47.53043353557587, 48.141079768538475, 46.15799278020859, 49.77228283882141, 46.788910925388336, 35.53736887872219, 39.950987845659256, 46.757456213235855, 47.57650226354599, 53.2093808054924, 52.88727208971977, 53.884980753064156, 52.256946712732315, 52.097438871860504, 52.999806851148605, 55.37340268492699, 52.08872213959694, 50.02534165978432, 52.03995555639267, 53.69616128504276, 56.54818944633007, 58.26703101396561, 53.38870458304882, 56.905119493603706, 58.94956558942795, 52.76569001376629, 51.929571479558945, 56.68931007385254, 54.1818930208683, 60.679931938648224, 61.681592389941216, 60.92658810317516, 61.87734268605709, 61.652770936489105, 51.107880771160126, 60.63242308795452, 62.69231155514717, 63.94044578075409, 61.824616715312004, 60.68924903869629, 50.754898712038994, 49.35762628912926, 49.82547618448734, 53.76246392726898, 60.178028270602226, 65.37910178303719, 66.36592403054237, 72.69801065325737, 63.28514814376831, 49.302700236439705, 67.22995966672897, 64.63583126664162, 48.896775618195534, 20.92662088572979, 3.2573963468894362, 0.2233827844611369, 0.16818071220768616, 3.3457921911031008, 0.5044495908077806, 20.417987778782845, 79.11593466997147, 62.462765872478485, 74.83693107962608, 31.20113465934992, 31.563070937991142, 28.157237693667412, 60.52845686674118, 52.068043649196625, 52.36112952232361, 46.93013034760952, 70.8617439866066, 35.778978914022446, 0.32973618304822594, 0.10099581224494614, 0.03574088215827942, 0.22404486924642697, 0.07447926909662783, 0.14564023265847936, 0.14699291554279625, 0.19702469726325944, 0.23335438454523683, 0.2890583861153573, 0.21078637131722644, 0.21674819203326479, 0.19781236827839166, 0.5787584627978504, 0.31980250671040267, 31.317222230136395, 88.24603155255318, 70.52988499403, 63.606291711330414, 38.21994513273239, 53.446385487914085, 78.957749158144, 30.321609154343605, 21.008819974958897, 60.44163152575493, 77.99585357308388, 67.1008349955082, 78.74401822686195, 19.3944139033556, 2.110144807957113, 3.4333641920238733, 2.6936260610818863, 0.2851310890400782, 1.8075096909888089, 16.608857475221157, 66.04968219995499, 65.42751878499985, 62.41233117878437, 65.10418653488159, 65.56450143456459, 65.62329947948456, 65.0050650537014, 60.60342684388161, 51.81131422519684, 54.31413732469082, 51.61955751478672, 51.03362135589123, 60.49337714910507, 64.87250536680222, 60.0045295804739, 57.41075076162815, 45.035738199949265, 49.67204801738262, 55.142101496458054, 68.26532810926437, 63.649776577949524, 67.06818714737892, 58.196396604180336, 58.55637788772583, 55.271013379096985, 52.567952424287796, 55.07744416594505, 63.05662840604782, 57.60271646082401, 60.2447184920311, 57.60659605264664, 61.18998996913433, 61.20407581329346, 59.451967030763626, 55.90140335261822, 55.46212412416935, 52.68437437713146, 60.609726905822754, 55.51003955304623, 57.02127926051617, 54.76913630962372, 52.19848304986954, 55.844231620430946, 51.24385267496109, 49.868448078632355, 50.018410831689835, 51.51983946561813, 49.62067477405071, 51.11321568489075, 53.879243060946465, 52.788659781217575, 53.85313466191292, 53.52984040975571, 52.96458274126053, 60.762151926755905, 59.396672397851944, 51.74342706799507, 64.96693029999733, 56.42694175243378, 37.17544957995415, 36.20476886630058, 47.19327762722969, 68.1068766117096, 60.70129059255123, 59.01534005999565, 57.829617485404015, 57.31609024107456, 52.87522293627262, 53.17992478609085, 51.493719667196274, 52.27518953382969, 50.056518986821175, 55.082771480083466, 50.98561093211174, 39.97120276093483, 45.325544849038124, 51.709437891840935, 51.90408244729042, 55.844710394740105, 56.66524596512318, 54.74565736949444, 54.361991956830025, 55.894780308008194, 54.538743272423744, 58.22697356343269, 54.16872292757034, 50.99016308784485, 55.67027695477009, 55.94986595213413, 60.03046318888664, 60.679563358426094, 56.19438283145428, 60.514842197299004, 61.319057643413544, 56.242393255233765, 54.32729221880436, 58.13042834401131, 56.47398702800274, 63.90548765659332, 64.65189680457115, 62.0106965303421, 61.98510870337486, 59.60706330835819, 55.08739583194256, 64.10746961832047, 67.03962028026581, 64.20141577720642, 65.27722164988518, 62.562160938978195, 53.93995240330696, 50.468660071492195, 51.876792311668396, 56.81527331471443, 63.008181005716324, 70.58749750256538, 70.85310325026512, 74.00800555944443, 64.58491399884224, 53.11096228659153, 56.462207660079, 67.5026786327362, 61.98043875396252, 32.68136993050575, 7.4101609736680984, 0.8546250849030912, 0.27005634794477373, 3.380424245260656, 1.908987876959145, 21.746736578643322, 83.23859184980392, 68.83746340870857, 78.87554436922073, 42.23334297537804, 29.210634268820286, 37.02528543770313, 73.0928322672844, 66.89575999975204, 70.49634039402008, 60.98841838538647, 84.23267170786858, 44.42648269236088, 0.5050327407661825, 0.2115894790040329, 0.20996656530769542, 0.20836892916122451, 0.17288385046413168, 0.2644141257042065], [0.07053523659124039, 0.04658587131416425, 0.017090586734411772, 0.04183236349490471, 0.002106012639160326, 0.0853016079054214, 0.09299183861003257, 0.4251549707259983, 0.2523588569601998, 21.54584515839815, 73.68770554661751, 53.03803279995918, 42.051667124032974, 48.76933045685291, 25.33886432647705, 44.57995265722275, 52.28256493806839, 8.235079608857632, 22.259099185466766, 61.4761184155941, 61.64219990372658, 62.38384410738945, 44.54188250005245, 0.11339129632688127, 0.40017956402152777, 0.045314501840039156, 0.03207750392903108, 0.27005391370039433, 1.2432584934867918, 37.45148576796055, 65.15011847019196, 59.135155230760574, 62.25163780152798, 61.0510428249836, 60.65572343766689, 60.325555354356766, 56.767555475234985, 48.44382852315903, 47.99127660691738, 47.480910792946815, 50.41854076087475, 57.953316047787666, 59.51912082731724, 58.80284786224365, 55.38431949913502, 38.571118488907814, 50.46470448374748, 54.63599145412445, 60.866623520851135, 58.2312673330307, 56.96911185979843, 52.18022882938385, 54.54969808459282, 50.550055503845215, 47.421261593699455, 50.01322031021118, 53.61801467835903, 53.98469120264053, 54.90343250334263, 54.381458312273026, 58.25618639588356, 53.629224076867104, 50.60096137225628, 49.07333314418793, 46.87939167022705, 47.180658504366875, 49.824362844228745, 50.89367866516113, 54.152604192495346, 49.615909829735756, 44.28853489458561, 47.76321284472942, 51.18284694850445, 49.35404308140278, 48.23292464017868, 47.67497397959232, 46.67384169995785, 42.43323124945164, 46.556025221943855, 45.39282023906708, 49.19353969395161, 50.031265541911125, 53.24724577367306, 55.169140845537186, 54.1370440274477, 44.647969007492065, 56.750764176249504, 54.58603173494339, 38.56072224676609, 43.62479031085968, 43.971343114972115, 64.41152930259705, 49.216965436935425, 43.615773394703865, 50.062427669763565, 54.885892644524574, 48.904846385121346, 46.94737762212753, 42.78356485068798, 44.42574553191662, 47.7254618704319, 45.34003347158432, 42.319849133491516, 43.12977187335491, 44.68742989003658, 43.59995484352112, 47.925954312086105, 47.75594383478165, 51.932444125413895, 54.10730302333832, 51.51257045567036, 50.62469109892845, 51.05896219611168, 48.09692233800888, 43.36239919066429, 47.406237199902534, 49.27416376769543, 50.44726341962814, 54.04764622449875, 52.19961538910866, 52.55211487412453, 53.86585257947445, 56.83690935373306, 49.07724693417549, 49.795233607292175, 55.40379725396633, 54.04032401740551, 54.883346781134605, 60.40683679282665, 58.03670637309551, 61.57742477953434, 59.88620772957802, 48.08471739292145, 54.80314828455448, 58.12728591263294, 58.41110408306122, 61.834101006388664, 58.646797835826874, 54.21377710998058, 46.35517939925194, 48.90473239123821, 44.52146239578724, 53.583493530750275, 57.96495482325554, 63.140934482216835, 61.00164167582989, 71.25232502818108, 46.806557178497314, 30.837097093462944, 44.37365032732487, 35.54139666259289, 7.492384286597371, 0.302664891933091, 0.08112614406854846, 0.3098021261394024, 4.766925433650613, 0.21722325560403988, 34.416869804263115, 67.1516002714634, 58.656069338321686, 51.346792951226234, 10.17779091373086, 15.998256839811802, 35.590041652321815, 54.29552212357521, 29.554772302508354, 61.31444849073887, 59.733653515577316, 50.763870030641556, 29.187223725020885, 0.6129758048336953, 0.13816260499879718, 0.03124376409687102, 0.24482792825438082, 0.07511206131312065, 0.054350034770322964, 0.020167052316537593, 0.07701844573603012, 0.07597824413096532, 0.0763422304589767, 0.06871980978758074, 0.1349617072264664, 0.1715816929936409, 0.599450133740902, 0.5438378022518009, 24.423947520554066, 81.19473472237587, 59.679115042090416, 48.36417719721794, 41.56164161860943, 30.711101554334164, 58.93945053219795, 42.63950318098068, 4.6263097040355206, 28.691207841038704, 65.27953192591667, 69.57604497671127, 65.85315674543381, 50.83519600331783, 0.15232953621307388, 0.2547793270787224, 0.10171674934099428, 0.037709796233684756, 0.17868677736259997, 1.1516356724314392, 44.055930376052856, 65.45959666371346, 59.601971581578255, 65.64347639679909, 62.072165831923485, 65.34178018569946, 60.24321377277374, 59.6523492783308, 49.71672222018242, 50.543352663517, 49.04128186404705, 53.4770992398262, 59.442585334181786, 61.54020197689533, 63.323062509298325, 59.164577051997185, 41.47881366312504, 50.47133132815361, 56.910237818956375, 60.40375895798206, 59.73127104341984, 60.019325986504555, 53.138810992240906, 57.26366825401783, 51.78782768547535, 50.348065942525864, 51.40485763549805, 55.87407901883125, 54.14512239396572, 57.9458836466074, 56.92124582827091, 60.36839425563812, 57.21593901515007, 52.849122136831284, 51.49158798158169, 49.37895454466343, 49.55497249960899, 50.522829964756966, 52.62469857931137, 56.305488869547844, 52.406343296170235, 47.14671492576599, 50.759599059820175, 53.41241151094437, 50.79368703067303, 51.70131012797356, 50.30425429344177, 49.75938633084297, 47.331392616033554, 49.08053755760193, 48.67838613688946, 53.40844452381134, 54.15964521467686, 54.78252299129963, 55.502774342894554, 57.47264564037323, 47.327114045619965, 60.12131631374359, 55.03067247569561, 38.69497664272785, 41.22211843729019, 43.45787286758423, 65.13493448495865, 51.898272559046745, 45.58146871626377, 52.97304108738899, 57.13493876159191, 50.621134489774704, 47.73905374109745, 47.23803922533989, 48.17402020096779, 50.361076444387436, 47.87543602287769, 47.266488298773766, 46.1483108997345, 47.280722334980965, 47.52713531255722, 51.110358238220215, 51.53911203145981, 55.5787056684494, 55.77341482043266, 55.43668448925018, 52.59325906634331, 54.25442732870579, 51.16965785622597, 47.002079486846924, 49.45895925164223, 52.94763185083866, 54.72930304706097, 57.35670246183872, 54.98705841600895, 53.946609646081924, 54.867224246263504, 58.46261411905289, 52.07156985998154, 52.468823343515396, 56.810337379574776, 55.83243705332279, 57.49284155666828, 62.303755804896355, 58.833728805184364, 64.17468801140785, 57.969666570425034, 48.23086515069008, 61.58021003007889, 60.55927321314812, 61.936258524656296, 64.88079652190208, 61.705173924565315, 57.178974598646164, 50.27783431112766, 50.8295077085495, 47.16500714421272, 56.68306700885296, 61.46561197936535, 67.01519519090652, 65.41406750679016, 72.28607475757599, 50.930441692471504, 36.56982287764549, 52.02385202050209, 44.758786261081696, 9.639753084629774, 0.574718804564327, 0.10530525600188412, 1.0655812150798738, 6.366428229957819, 0.2870722208172083, 42.87460416555405, 69.2284244298935, 66.49858251214027, 51.930874809622765, 16.86706881970167, 18.77154942601919, 25.246077105402946, 67.05537423491478, 35.33927410840988, 53.067070841789246, 64.30530220270157, 62.89326377213001, 35.49548752605915, 0.6562472891528159, 0.20838724536588416, 0.02254647795780329, 0.1400494560948573, 0.14025914249941707, 0.0790939804574009, 0.1208042903454043, 0.17315299774054438, 0.14827442646492273, 0.35339968046173453, 0.2501135930651799, 0.2262559052905999, 0.2971757302293554, 0.7947141153272241, 0.6100002082530409, 30.38037110120058, 95.24851620197296, 69.19917359948158, 58.28253798186779, 59.23879846930504, 40.759386867284775, 59.76537421345711, 59.650901556015015, 15.210863091051579, 37.0074225962162, 72.65837877988815, 71.81178420782089, 72.7155277132988, 53.76171916723251, 0.4577347787562758, 1.4094729744829237, 0.2535245631588623, 0.15825448703253642, 0.355529822409153, 2.531346743926406, 49.48683075606823, 70.71341514587402, 63.734234645962715, 68.27662870287895, 67.9731997847557, 69.52551528811455, 63.74787591397762, 62.72030845284462, 52.350999265909195, 52.95664496719837, 51.41420133411884, 58.86174090206623, 62.1590443700552, 68.33304047584534, 62.03489363193512, 52.60884203016758, 43.11400651931763, 52.81957112252712, 60.3702599555254, 63.96938502788544, 63.64364750683308, 63.54657791554928, 56.14090070128441, 60.056594386696815, 55.95255620777607, 53.76413203775883, 54.40055988729, 59.890938475728035, 58.06676276028156, 62.113351821899414, 58.82248900830746, 61.89426697790623, 62.36484132707119, 57.18950763344765, 54.54756259918213, 51.880136132240295, 55.28914600610733, 53.74488227069378, 57.31651581823826, 60.00960610806942, 56.0894438624382, 55.6304132938385, 56.711740270256996, 58.298896104097366, 55.84881417453289, 57.03834414482117, 56.100174486637115, 53.90494488179684, 50.94091773033142, 53.800883665680885, 52.65502095222473, 58.51533629000187, 57.362937927246094, 58.281443640589714, 59.37211811542511, 59.05327342450619, 51.207378432154655, 61.70751839876175, 58.618740141391754, 39.927877485752106, 43.05742375552654, 43.59674781560898, 70.83532020449638, 55.064479261636734, 47.87216819822788, 54.29339423775673, 60.88718041777611, 54.46441926062107, 53.26033227145672, 49.47947435081005, 51.28462068736553, 56.869849786162376, 52.633012533187866, 50.37349037826061, 48.77942271530628, 51.746919080615044, 53.21528568863869, 55.55751420557499, 56.40142232179642, 60.88460795581341, 59.98737350106239, 57.86434002220631, 55.78421764075756, 55.407616049051285, 54.760567769408226, 47.74667613208294, 53.66312585771084, 54.618056416511536, 56.99682757258415, 58.68467040359974, 56.711189299821854, 55.315186008811, 57.66109652817249, 61.319342628121376, 53.62559527158737, 54.24324072897434, 60.68647898733616, 56.851789355278015, 60.50676003098488, 63.15842494368553, 62.22565859556198, 66.63485080003738, 59.76376309990883, 58.11483018100262, 59.312807098031044, 60.67846521735191, 64.54228788614273, 68.40835243463516, 65.0313064455986, 61.08931817114353, 52.8059184551239, 53.82511116564274, 50.50179049372673, 57.15854689478874, 65.06742730736732, 67.6174932718277, 69.37322705984116, 75.88485404849052, 53.34326662123203, 39.58004795014858, 49.79424946010113, 51.663870736956596, 17.283347882330418, 1.6261118184775114, 0.32960710872430354, 0.8976157999131829, 11.327021196484566, 2.1190759912133217, 43.14968280494213, 79.59963351488113, 66.87007337808609, 66.26645296812057, 22.422995790839195, 26.589981392025948, 49.58078071475029, 76.21070176362991, 46.31839357316494, 68.63960802555084, 78.05628553032875, 75.39962768554688, 48.43885838985443, 1.2227626307867467, 0.30029634246602654, 0.14709359529661015, 0.48488580621778965, 0.16166591725777835, 0.11299395788228139], [0.026817875514097977, 0.1449506587232463, 0.062282042345032096, 0.07264520696480758, 0.07334063644520938, 0.05170210752112325, 0.13872715673642233, 0.4028511472279206, 0.23279039683984593, 9.393224213272333, 76.43627285957336, 55.00035010278225, 51.37153722345829, 39.257821440696716, 37.02910043299198, 38.518244326114655, 41.00722476840019, 9.353995118290186, 27.35693223774433, 56.18435136973858, 69.16062846779823, 54.231495559215546, 65.26013776659966, 5.2249148581177, 0.6004180724266917, 0.3416794171789661, 0.04285474613425322, 0.13941304961917922, 0.2557373803574592, 5.386659353971481, 72.88730129599571, 59.46674443781376, 60.3772097826004, 62.30435997247696, 62.03321412205696, 62.271351143717766, 57.510484009981155, 46.29833064973354, 48.36160093545914, 46.093316450715065, 55.63360512256622, 60.45133240520954, 61.46294452250004, 54.129664823412895, 48.45125712454319, 44.39535856246948, 53.06315325200558, 57.09483191370964, 56.797190085053444, 55.11680245399475, 55.607006549835205, 54.26542393863201, 56.2083774805069, 51.670619174838066, 46.967607736587524, 49.58089090883732, 54.3314415961504, 53.75097334384918, 55.643237605690956, 48.82236421108246, 51.702560260891914, 53.71253460645676, 53.391607627272606, 49.30882170796394, 48.25728893280029, 44.9454740434885, 47.21190042793751, 47.890555411577225, 51.073048040270805, 47.11279034614563, 36.45687393844128, 46.016685962677, 52.31056943535805, 47.37759813666344, 49.6475887298584, 47.53737956285477, 50.57823859155178, 49.21307824552059, 49.872023686766624, 49.92257617413998, 51.61152854561806, 49.67194922268391, 53.164364621043205, 55.503564700484276, 55.1469424366951, 45.19626438617706, 57.841864228248596, 58.059508949518204, 42.34416402876377, 38.316718339920044, 44.78887304663658, 60.49320235848427, 45.603921711444855, 47.957553416490555, 54.91559945046902, 53.205421417951584, 52.11380459368229, 49.38451364636421, 45.665303617715836, 45.42719319462776, 44.63051274418831, 46.13015167415142, 44.16327081620693, 50.36757409572601, 46.14778272807598, 46.16720348596573, 49.59332764148712, 51.73263564705849, 50.23965775966644, 52.71024338901043, 51.17827579379082, 50.68340174853802, 45.8240021020174, 43.123274222016335, 42.68890053033829, 47.03208267688751, 49.71331000328064, 52.41681553423405, 55.08718304336071, 57.71968938410282, 54.08766947686672, 52.562438920140266, 54.86328385770321, 49.97921213507652, 49.41263593733311, 52.080297991633415, 55.56034505367279, 54.730306193232536, 60.166845470666885, 59.20747295022011, 63.14552843570709, 53.077755868434906, 41.535210236907005, 56.561279743909836, 60.76337546110153, 61.16480112075806, 59.013713747262955, 60.45529559254646, 56.89935140311718, 50.94672381877899, 46.81813895702362, 46.98750726878643, 47.83792823553085, 52.26867288351059, 61.68504640460014, 61.46114341914654, 62.24439539015293, 68.62368687987328, 46.9443453848362, 43.765196576714516, 49.61084470152855, 2.590565378777683, 0.8105188922490925, 0.04958356905262917, 0.17868181981611997, 2.0832541259005666, 2.3247024323791265, 57.27411389350891, 61.548436135053635, 53.20553161203861, 30.782338231801987, 6.95493352599442, 31.443440057337284, 33.976028859615326, 39.99917306005955, 32.30712041258812, 33.49247060716152, 44.65018808841705, 51.12896963953972, 18.655845634639263, 0.6041382509283721, 0.3630728035932407, 0.053285086250980385, 0.14020054251886904, 0.11303042701911181, 0.1481530407909304, 0.020584931553457864, 0.10412677002022974, 0.09784587775357068, 0.12021512156934477, 0.029151499511499424, 0.043355773741495796, 0.13534949423046783, 0.3008751879679039, 0.29371304728556424, 10.678485296666622, 82.717624604702, 60.03736361861229, 57.97057472169399, 38.77796418964863, 44.353283420205116, 34.73674803972244, 39.77821111679077, 10.746432300657034, 30.212137028574944, 61.63445211946964, 74.48131576180458, 59.93391036987305, 72.37400963902473, 6.499728402122855, 0.5836536095011979, 0.12491785164456815, 0.14996851212345064, 0.017825969734985847, 0.2736585249658674, 8.13181160017848, 73.39699074625969, 61.41722537577152, 63.57550576329231, 63.236951529979706, 63.764857202768326, 64.62678015232086, 60.43235622346401, 48.988016322255135, 49.95560400187969, 48.86812135577202, 56.645718812942505, 61.72212861478329, 63.02325859665871, 55.539100393652916, 48.67136791348457, 47.360404059290886, 54.689093604683876, 58.60472649335861, 60.816185027360916, 57.36290752887726, 56.35773606598377, 57.22187429666519, 57.8880013525486, 53.726468458771706, 47.48533755540848, 50.92892177402973, 54.67608690261841, 56.25429041683674, 57.45968073606491, 51.69829688966274, 53.0979023873806, 52.09617353975773, 56.70312613248825, 52.44865022599697, 50.70483259856701, 48.83459195494652, 49.227977246046066, 49.93742577731609, 52.90056377649307, 50.41960470378399, 42.90155991911888, 50.41808478534222, 53.95888678729534, 52.18724325299263, 52.45220683515072, 51.327516585588455, 52.576904743909836, 50.68213261663914, 51.681824773550034, 52.32067309319973, 55.86964465677738, 53.50071497261524, 53.61196540296078, 56.534225195646286, 58.04342061281204, 46.0652169585228, 60.10270871222019, 58.47252018749714, 42.274665758013725, 36.78246706724167, 44.57391858100891, 62.81532995402813, 48.58540892601013, 48.58165852725506, 55.657882019877434, 54.52241934835911, 55.77728681266308, 50.93397170305252, 48.10580626130104, 48.43039624392986, 47.95582830905914, 49.96395215392113, 50.57903274893761, 51.90690569579601, 49.590827375650406, 49.50381964445114, 52.65641547739506, 52.095322385430336, 53.6216738820076, 56.299633383750916, 52.001448422670364, 53.803900703787804, 49.66639392077923, 43.37603285908699, 48.15193958580494, 49.062328934669495, 52.82612197101116, 55.502527356147766, 58.18517580628395, 58.56569118797779, 58.10689240694046, 54.56110127270222, 55.79447329044342, 50.904390290379524, 50.6249038875103, 53.58967959880829, 58.23297344148159, 54.0094430744648, 62.45507128536701, 59.27384398877621, 64.52044665813446, 51.46653972566128, 42.59337365627289, 53.930171728134155, 57.34463810920715, 63.88821378350258, 61.99298568069935, 63.20143483579159, 58.06213840842247, 55.20168989896774, 48.51081132888794, 50.107079073786736, 49.695469960570335, 54.90964896976948, 63.197255060076714, 64.46392849087715, 65.25405809283257, 69.7094102203846, 53.0888132750988, 46.492929607629776, 52.94369526207447, 5.089046498760581, 1.3431463460437953, 0.2132845888263546, 2.9663602262735367, 1.904703606851399, 3.0179569451138377, 67.01942816376686, 67.41911351680756, 57.515533939003944, 35.92006914317608, 9.355689827352762, 17.08811055868864, 28.426920622587204, 49.055204316973686, 40.7417444139719, 34.079675897955894, 55.07865250110626, 59.05777998268604, 27.66146119683981, 0.8399097213987261, 0.4450370476115495, 0.07034235241007991, 0.16317620262270793, 0.07222776373964734, 0.15757856861455366, 0.13282040337799117, 0.20262571546481922, 0.19548956479411572, 0.2327452297322452, 0.08712979964911938, 0.23819066409487277, 0.2952334110159427, 0.4676469328114763, 0.5292395793367177, 13.33243103697896, 96.41933217644691, 70.19024401903152, 70.48335269093513, 45.19576281309128, 56.457887291908264, 55.08336804807186, 48.943323120474815, 16.772780679166317, 35.46170353889465, 67.7160295844078, 77.58526280522346, 66.31480157375336, 80.03476336598396, 7.184231746941805, 1.6548361396417022, 0.5372561397962272, 0.20435368758626282, 0.6667876860592514, 0.39544875849969685, 9.50044495984912, 75.45656383037567, 60.74249558150768, 64.67688426375389, 64.25342738628387, 65.69244056940079, 68.20434138178825, 65.27023762464523, 50.64892239868641, 54.41861651837826, 51.5583959966898, 62.38084226846695, 64.03544068336487, 67.22064256668091, 54.63463872671127, 47.63297863304615, 46.355673372745514, 54.179339557886124, 60.61414986848831, 63.87135028839111, 59.45496127009392, 58.20865094661713, 59.69027504324913, 61.18419907987118, 57.921526953577995, 51.38111270964146, 54.16955128312111, 59.23543944954872, 58.73824752867222, 61.22468590736389, 55.73370695114136, 57.036429047584534, 56.63863219320774, 60.12073114514351, 54.532287418842316, 54.15275618433952, 51.04409359395504, 51.545241102576256, 52.96299062669277, 55.456777811050415, 58.071284517645836, 48.373057320714, 53.505829498171806, 58.386017829179764, 55.35509526729584, 55.42002998292446, 53.57285030186176, 58.960402607917786, 54.58628252148628, 57.238460406661034, 58.571645468473434, 60.645589381456375, 55.551936104893684, 57.048409804701805, 58.84757146239281, 60.26269532740116, 49.995171278715134, 63.87188985943794, 62.4859332293272, 42.92804069817066, 38.31778608262539, 44.630106166005135, 65.26237204670906, 52.984003499150276, 52.65463337302208, 58.46241652965546, 57.59139686822891, 57.77339570224285, 54.85596165060997, 52.43398681282997, 52.66607455909252, 53.228531777858734, 56.222945898771286, 52.55459614098072, 56.747093573212624, 54.29383501410484, 53.85943092405796, 57.99444884061813, 58.41174624860287, 58.39094616472721, 60.88488534092903, 56.248841509222984, 57.40760073065758, 53.46673719584942, 46.103135123848915, 48.91712732613087, 51.73911809921265, 55.091457813978195, 58.456686437129974, 60.69469414651394, 63.749224841594696, 58.93890716135502, 58.11205632984638, 57.10557393729687, 54.34483967721462, 52.54233039915562, 56.66982851922512, 58.80156733095646, 59.885937944054604, 64.79870572686195, 63.88535633683205, 65.56592255830765, 56.503929421305656, 52.6675146818161, 58.934298008680344, 66.54601916670799, 64.38993126153946, 66.322902739048, 66.07287615537643, 61.49356707930565, 57.02073588967323, 52.7712719142437, 53.631515353918076, 53.58622558414936, 55.97443163394928, 66.8875752389431, 67.37433671951294, 70.01071885228157, 73.91366422176361, 53.33975940942764, 50.282432064414024, 56.25655509531498, 10.09757911786437, 1.7641343059949577, 0.24395514774369076, 2.705662390217185, 9.760694894939661, 3.4717098344117403, 69.63954716920853, 73.61864045262337, 63.884961158037186, 46.69272668659687, 16.447506733238697, 43.12094874680042, 44.02890242636204, 56.97321943938732, 51.081023812294006, 46.567173823714256, 65.40706068277359, 69.84089836478233, 42.175088301301, 1.2603766936808825, 0.5244369932916015, 0.19672144087962806, 0.3660831623710692, 0.23040583182591945, 0.3243486658902839], [0.062201411710702814, 0.02012018198001897, 0.06671476425253786, 0.07665919431019574, 0.05635027860989794, 0.008393694861297263, 0.09087951562833041, 0.352953709079884, 0.1445940270787105, 4.56979438662529, 69.56576272845268, 54.72062811255455, 41.931186988949776, 32.502167746424675, 26.217149198055267, 81.86603710055351, 50.65350495278835, 3.1955971755087376, 46.72140754759312, 61.40243276953697, 68.77040460705757, 48.49549815058708, 63.34617666900158, 27.88278792053461, 0.17734536028001457, 0.10019040390034206, 0.05947747369646095, 0.12376323313219473, 0.4075212747557089, 0.056304825775441714, 40.017932653427124, 53.569122701883316, 62.91330009698868, 65.8613795042038, 65.02217173576355, 61.91606640815735, 54.526017755270004, 45.96390679478645, 51.78867883980274, 48.45636025071144, 57.44650684297085, 54.880268946290016, 58.95561866462231, 49.51255917549133, 48.90785202383995, 46.85720086097717, 52.53445342183113, 57.169775292277336, 57.14395947754383, 57.092726826667786, 54.63554307818413, 54.04888495802879, 54.33014966547489, 49.28197614848614, 44.55031804740429, 46.78380399942398, 51.50593601167202, 51.74142837524414, 54.03450272977352, 54.319578632712364, 54.61471639573574, 48.549550250172615, 56.167240887880325, 52.092217952013016, 50.63564591109753, 43.66221830248833, 46.12072438001633, 44.68737289309502, 47.40093648433685, 43.22873756289482, 46.84251844882965, 50.42351469397545, 49.912662506103516, 47.46778629720211, 50.10197214782238, 51.90066263079643, 51.18779808282852, 47.95262888073921, 49.76429186761379, 54.0282216668129, 52.55691781640053, 52.018479108810425, 57.86652110517025, 58.39026600122452, 61.970137506723404, 55.66341832280159, 62.07461670041084, 62.57303975522518, 44.413172006607056, 39.97491896152496, 47.28940486907959, 63.60570654273033, 51.31497345864773, 56.42659217119217, 54.938500821590424, 53.68501268327236, 50.282124280929565, 51.444421112537384, 50.69151051342487, 48.42907011508942, 47.38865174353123, 49.08418916165829, 48.101668283343315, 50.17577178776264, 50.095964670181274, 49.79394167661667, 50.483616068959236, 50.66190630197525, 49.5626974850893, 49.55484330654144, 44.36551496386528, 42.57708393037319, 43.640958443284035, 41.96937873959541, 44.274741634726524, 47.01518878340721, 53.93914304673672, 51.96465499699116, 55.63309594988823, 51.43667712807655, 53.87158267199993, 48.31451766192913, 52.762908563017845, 45.60142144560814, 52.02980250120163, 51.14210933446884, 56.8937087059021, 55.524075999855995, 59.36562806367874, 55.74168652296066, 66.35637894272804, 46.420030519366264, 44.12160985171795, 27.87200789898634, 13.532549198716879, 52.36333720386028, 61.67116194963455, 60.86508460342884, 57.608978524804115, 55.84433041512966, 49.756019711494446, 45.03475025296211, 48.84373426437378, 45.997804775834084, 56.6961383074522, 59.285615757107735, 66.1938388645649, 62.05968730151653, 72.14317962527275, 65.50548300147057, 38.53220857679844, 2.0409887563437223, 0.34628373105078936, 0.2357633810606785, 2.91766797658056, 1.4214650122448802, 9.701849352568388, 67.85011678934097, 53.85634548962116, 55.17015539109707, 30.218155905604362, 20.216729678213596, 23.542497418820858, 23.96350532770157, 43.483688682317734, 34.27535779774189, 23.66732072085142, 41.44087269902229, 48.56079004704952, 16.78308952599764, 0.5477533140219748, 0.24758830200880766, 0.08129784735501744, 0.057979289049399085, 0.032151147242984734, 0.1336585552780889, 0.06676846605842002, 0.040277241278090514, 0.06349727947963402, 0.12545746722025797, 0.042821267852559686, 0.021678500997950323, 0.039360844748443924, 0.33935403102077544, 0.21884734189370647, 5.4629820585250854, 76.5817442536354, 61.8762369453907, 48.98183025419712, 30.219231247901917, 34.51240047812462, 98.47760573029518, 50.44526852667332, 5.307805510237813, 51.26257807016373, 67.32296347618103, 73.09677645564079, 52.615484073758125, 70.78403055667877, 31.450547575950623, 0.16889523714780807, 0.5810034892056137, 0.030771910314797424, 0.22244460589718074, 0.4825770144816488, 0.323482490493916, 42.85553678870201, 57.64023944735527, 63.77162083983421, 67.48399123549461, 66.32234036922455, 65.04193067550659, 56.485200226306915, 48.957222774624825, 50.866909101605415, 52.560216039419174, 59.76325772702694, 61.05908699333668, 61.498058438301086, 55.01956947147846, 49.58434872329235, 47.95078217983246, 53.93893405795097, 60.80064386129379, 59.340488612651825, 59.31144677102566, 57.303683906793594, 56.65652543306351, 54.470707923173904, 52.75357246398926, 48.41449789702892, 48.46373185515404, 53.344683945178986, 54.357052221894264, 57.026473581790924, 55.270671397447586, 57.73294307291508, 53.23875702917576, 56.548862010240555, 54.47238743305206, 53.909797221422195, 45.24145916104317, 50.854210183024406, 47.150621116161346, 50.587821677327156, 47.913289591670036, 48.806830644607544, 52.275143936276436, 52.90742240846157, 49.82902139425278, 53.723842799663544, 53.30837309360504, 54.85963985323906, 51.532523185014725, 52.7492368966341, 56.08690559864044, 56.4857017993927, 54.81326334178448, 59.87258926033974, 59.511563032865524, 63.89836683869362, 54.73415158689022, 64.74682331085205, 62.841848731040955, 46.47369123995304, 41.52755744755268, 47.9705411195755, 62.044115737080574, 54.429229348897934, 57.81515546143055, 57.23738506436348, 54.21346552670002, 54.46318432688713, 54.650126695632935, 52.44892381131649, 51.72052189707756, 51.46296791732311, 51.5499110519886, 50.397562086582184, 51.86906732618809, 56.69609650969505, 52.84589231014252, 54.62186761200428, 53.55548903346062, 54.138111770153046, 51.77647389471531, 47.771188616752625, 44.66398514807224, 46.62211127579212, 43.61020669341087, 46.418092623353004, 49.85533498227596, 56.59146912395954, 53.715346455574036, 56.49173967540264, 53.251797929406166, 57.52399228513241, 49.727601036429405, 53.6751864105463, 47.39672631025314, 53.2699191570282, 52.1956218034029, 60.206161960959435, 56.939120069146156, 61.23904913663864, 58.37062865495682, 68.89240846037865, 48.3174929022789, 47.41132512688637, 35.221248641610146, 16.97421357035637, 53.78484092652798, 62.09656052291393, 63.55819769203663, 60.18805593252182, 58.729276210069656, 51.421876922249794, 49.412711933255196, 50.86986154317856, 51.16418994963169, 58.24414104223251, 61.00398235023022, 68.4775847196579, 64.44770336151123, 71.88275679945946, 68.11658889055252, 41.571448892354965, 3.6437653144821525, 0.5333297629840672, 0.05127943957631942, 3.7575409468263388, 2.1503060404211283, 13.77865819260478, 73.67379829287529, 62.22634255886078, 60.619640573859215, 37.16208949685097, 22.641955241560936, 25.20267963409424, 24.872327260673046, 55.22812508046627, 40.58792106807232, 24.877453185617924, 49.878361746668816, 59.46725741028786, 25.992246866226196, 0.66221077227965, 0.351533149369061, 0.09072159402421676, 0.20028204278787598, 0.06004015893267933, 0.08186760896933265, 0.1573105197167024, 0.17696420807624236, 0.16102265333756804, 0.3277354716556147, 0.10327798314392567, 0.10470900713698938, 0.2951630257302895, 0.6346985267009586, 0.3577641025185585, 6.589062083512545, 87.68113106489182, 72.18388304114342, 57.57963269948959, 39.497094601392746, 42.76835046708584, 91.65072485804558, 60.43413072824478, 9.145716894418001, 58.96540313959122, 70.9207472205162, 78.25367733836174, 58.26055996119976, 78.23458716273308, 33.653749153018, 0.3835765033727512, 0.4015712096588686, 0.22327593003865331, 0.3100233158329502, 0.782243125140667, 0.9518464305438101, 45.96813976764679, 56.48435667157173, 65.09413227438927, 69.0497200191021, 70.46699076890945, 66.65122792124748, 60.21031133830547, 50.01388527452946, 56.580863893032074, 56.58651798963547, 61.72496326267719, 63.341404125094414, 65.2313657104969, 53.63613970577717, 52.77614705264568, 45.97840301692486, 55.61426416039467, 61.52450121939182, 61.30198895931244, 61.7149394005537, 61.15477345883846, 58.83977808058262, 55.928507298231125, 54.3750936537981, 49.821550995111465, 50.85124634206295, 55.86015276610851, 57.224682345986366, 59.155282750725746, 59.409990683197975, 62.63067126274109, 53.941225335001945, 61.59966878592968, 57.6053649187088, 59.17637921869755, 49.37845677137375, 54.19575847685337, 51.515226513147354, 53.90146046876907, 50.320053845644, 52.28242814540863, 56.80206522345543, 55.26422694325447, 53.74962441623211, 57.86872498691082, 56.443592458963394, 59.090959802269936, 55.81989772617817, 59.0378462523222, 61.0615948587656, 60.327022075653076, 56.232696175575256, 64.30294632911682, 61.60857930779457, 69.01811331510544, 57.673704251646996, 71.05731189250946, 67.10715785622597, 47.70663008093834, 42.09296330809593, 50.46030431985855, 65.96547871828079, 56.70918680727482, 60.65932944417, 61.391185373067856, 57.66964226961136, 57.534707710146904, 58.61168012022972, 58.84881019592285, 56.74787253141403, 55.871825739741325, 57.25902110338211, 54.18396770954132, 57.101344764232635, 61.698535680770874, 56.900289952754974, 60.03582090139389, 57.25629284977913, 58.83173011243343, 55.50247795879841, 48.96330624818802, 48.68105739355087, 50.42744368314743, 48.14199931919575, 49.61357295513153, 54.69222083687782, 62.11003839969635, 55.52431918680668, 58.44344034790993, 56.39357194304466, 59.98289354145527, 53.897250294685364, 57.44219787418842, 50.385558530688286, 56.28031142055988, 54.5363911986351, 63.4407763928175, 60.56099072098732, 63.735176995396614, 63.07416446506977, 70.98071560263634, 55.1132420450449, 55.497165843844414, 33.55015531182289, 17.277598790824413, 61.2241767346859, 65.33067718148232, 68.30638110637665, 64.05949339270592, 61.22939005494118, 53.846504017710686, 51.51591047644615, 54.33152139186859, 53.10123860836029, 61.09987020492554, 65.33161953091621, 73.12931790947914, 68.02819803357124, 76.9437888264656, 69.47647511959076, 46.821273788809776, 5.6906872149556875, 0.8843616361264139, 0.18988824973348528, 6.92104646936059, 8.94099147990346, 12.055878136307001, 80.52774131298065, 65.37212535738945, 66.30295380949974, 45.578444078564644, 29.59146313369274, 36.50073118507862, 31.352182254195213, 62.066086158156395, 53.49894426763058, 32.143296003341675, 59.489740803837776, 70.66560611128807, 38.64032797515392, 1.1609343672171235, 0.6193392758723348, 0.11889098168467171, 0.2896868664538488, 0.10677130936528556, 0.16619506641291082], [0.006226901950867614, 0.03550154324329924, 0.04255229127011262, 0.08422305952990428, 0.11397667272831313, 0.05611109925666824, 0.03426113988098223, 0.18477408040780574, 0.06623840192332864, 1.558078844100237, 60.842646807432175, 55.32747454941273, 51.775398552417755, 29.690981693565845, 37.73018181324005, 30.23030385375023, 50.30632518231869, 4.523731833323836, 32.94812701642513, 70.5884550511837, 67.73903355002403, 54.41778816282749, 55.38569122552872, 44.22230824828148, 0.6548690912313759, 0.25171951157972217, 0.06394990050466731, 0.0638674850051757, 0.7402912981342524, 0.40214016975369304, 20.181216783821583, 63.73492620885372, 66.14707097411156, 67.53639042377472, 60.74695274233818, 59.85801704227924, 48.373228311538696, 48.1717973202467, 50.26859700679779, 52.62407921254635, 59.246094077825546, 61.592262983322144, 57.51106917858124, 50.68195782601833, 41.35690100491047, 48.38234022259712, 49.60272453725338, 57.754164934158325, 57.30079986155033, 57.28836312890053, 55.69814085960388, 57.957929000258446, 52.99280762672424, 50.779639184474945, 44.871153831481934, 46.516948118805885, 46.802544593811035, 49.27837774157524, 52.84111596643925, 48.55547793209553, 52.38112784922123, 53.84298160672188, 55.66620357334614, 56.027731373906136, 52.41632156074047, 48.48121851682663, 44.8940210044384, 43.95916096866131, 42.44035966694355, 46.90529108047485, 45.89052893221378, 44.58304189145565, 47.04091340303421, 48.83272245526314, 48.8972581923008, 48.535023629665375, 47.17660792171955, 47.43643797934055, 50.00352323055267, 49.36931066215038, 52.46157333254814, 54.25494410097599, 56.01980119943619, 57.79548391699791, 62.406057715415955, 61.060800701379776, 62.106390595436096, 60.92753045260906, 45.72942137718201, 42.48455889523029, 46.587563529610634, 65.25172501802444, 59.07019391655922, 60.8897490799427, 54.82712119817734, 59.66699369251728, 54.03414934873581, 51.94765090942383, 52.417628690600395, 51.477103158831596, 47.36188977956772, 48.94174240529537, 50.27216501533985, 50.533849373459816, 50.41019260883331, 47.88227565586567, 49.36090551316738, 50.476445853710175, 48.32671880722046, 46.49284601211548, 43.107839450240135, 42.195379212498665, 43.306397795677185, 44.41738598048687, 50.394723638892174, 49.94023762643337, 51.0526355355978, 48.67136411368847, 46.16511359810829, 47.2166083753109, 50.12349419295788, 47.44175009429455, 50.389073342084885, 44.24060046672821, 50.18734596669674, 52.62452378869057, 58.59346769750118, 56.34757161140442, 59.67643618583679, 56.78021639585495, 62.914113253355026, 46.74910806119442, 46.358880400657654, 57.44795836508274, 35.14743760228157, 34.249610379338264, 58.606949374079704, 59.09246452152729, 60.049021393060684, 56.92844644188881, 57.75933265686035, 50.23005947470665, 46.50939032435417, 46.029198691248894, 51.114336624741554, 58.53254936635494, 63.40641103684902, 62.350789681077, 61.20714604854584, 62.25490942597389, 32.620197013020515, 0.3554605651879683, 0.15876576740993187, 0.12077378807589412, 5.129795987159014, 0.1329526540939696, 35.043167397379875, 68.17230150103569, 56.35341949760914, 59.47927616536617, 46.77538365125656, 36.19208514690399, 19.37418568879366, 17.427500747144222, 35.76422430574894, 37.564461305737495, 35.98678216338158, 47.43043430149555, 53.998199477791786, 19.480547681450844, 0.5486406851559877, 0.3130612528184429, 0.030690925304952543, 0.09469881537370384, 0.04104700426978525, 0.018627504068717826, 0.06939670041901991, 0.06283058595727198, 0.0029360227154029417, 0.07764903377392329, 0.0327943963202415, 0.07193517201812938, 0.060525976223289035, 0.1942951968521811, 0.061369972536340356, 1.7791552562266588, 68.03157225251198, 65.72556719183922, 51.25906705856323, 27.609225399792194, 43.66297826170921, 42.270995154976845, 49.66376446187496, 4.981435798108578, 36.565924286842346, 74.52675372362137, 73.36770191788673, 60.415139347314835, 59.866714775562286, 51.07979267835617, 0.6727111525833607, 0.8633438358083367, 0.09193834514007904, 0.12871294253272936, 1.432711340021342, 0.3245252970373258, 21.628762409090996, 64.82650503516197, 68.93508777022362, 68.95559906959534, 63.05286280810833, 63.83388429880142, 49.76749509572983, 50.54866477847099, 52.37002104520798, 59.33102332055569, 61.68283872306347, 64.34133186936378, 62.10164465010166, 54.65475104749203, 38.80795978009701, 49.75761942565441, 49.944808781147, 57.40743353962898, 59.88217234611511, 61.370320692658424, 57.69550748169422, 60.692049488425255, 52.02327065169811, 52.4116326123476, 46.058483719825745, 47.1933726221323, 50.15663601458073, 51.99655808508396, 54.95927430689335, 51.01621448993683, 55.04405915737152, 58.76316279172897, 58.16104330122471, 56.98519639670849, 55.306856855750084, 51.434705033898354, 49.307210594415665, 46.06242410838604, 46.23374931514263, 51.26558370888233, 49.75193493068218, 49.67360593378544, 50.68185903131962, 50.54019123315811, 51.94631718099117, 51.90894238650799, 50.907582119107246, 52.43518374860287, 53.89319211244583, 51.83299966156483, 57.21756912767887, 56.174050122499466, 58.192064836621284, 58.48121032118797, 62.204900309443474, 61.54869832098484, 64.04342025518417, 61.57064214348793, 46.643929705023766, 41.870329454541206, 48.47219780087471, 65.74406459927559, 59.7720580548048, 62.60354831814766, 59.0392179787159, 58.156821727752686, 57.537675350904465, 55.005688816308975, 53.69288966059685, 54.17427822947502, 53.047665283083916, 54.440138563513756, 54.204422011971474, 53.531554117798805, 53.434165343642235, 51.65660932660103, 52.3041857779026, 54.251235499978065, 51.5128668397665, 50.3186821192503, 47.020440101623535, 45.19773110747337, 48.1486489623785, 47.95983709394932, 54.620457887649536, 53.9888671785593, 54.06842350959778, 50.284860134124756, 48.5420760512352, 51.3206085562706, 52.76296555995941, 50.516157522797585, 50.320540219545364, 48.27756844460964, 52.52683483064175, 53.419897109270096, 60.090895146131516, 58.35302799940109, 60.2128230035305, 60.874367505311966, 64.12547305226326, 50.408900678157806, 47.2419910132885, 64.44419234991074, 50.7652797549963, 36.97707362473011, 59.727923423051834, 60.96637196838856, 63.83104205131531, 61.74081601202488, 61.94182522594929, 51.20264768600464, 49.461736902594566, 47.92012922465801, 51.35204806923866, 60.23427665233612, 65.4102373123169, 65.7338659465313, 64.58495199680328, 65.70862010121346, 37.622446194291115, 0.35893553809728473, 0.5618375551421195, 0.006670486864095437, 3.599093724042177, 0.6579569005407393, 39.923237934708595, 72.83889949321747, 62.33090154826641, 66.81943729519844, 56.179100051522255, 41.781832203269005, 24.968709088861942, 22.87421777844429, 50.16911834478378, 45.68492956459522, 40.48484019935131, 53.17045949399471, 65.61620905995369, 25.941872969269753, 0.5471804353874177, 0.3189133247360587, 0.028159941975900438, 0.11667584156384692, 0.018159134669986088, 0.05632913482259028, 0.15464184572920203, 0.18113449914380908, 0.22981834772508591, 0.18783833394991234, 0.18875846348237246, 0.1953420406789519, 0.15385568869533017, 0.2425904865958728, 0.4199822311056778, 2.612658105790615, 81.90364748239517, 75.16527146100998, 68.33570793271065, 36.09769061207771, 59.256699308753014, 36.59911930561066, 57.955356538295746, 11.128633841872215, 44.76107373833656, 81.86222210526466, 79.14634823799133, 64.48208391666412, 68.93418341875076, 55.17246566712856, 0.8930262399371713, 0.9948522259946913, 0.2431506448192522, 0.39193029573652893, 2.0360998436808586, 0.5671726469881833, 23.366200178861618, 66.5780970454216, 71.51327222585678, 74.79033038020134, 65.64946487545967, 65.81167057156563, 52.420459538698196, 53.2758392393589, 57.02264718711376, 59.867364540696144, 65.06636336445808, 68.33929494023323, 63.59094053506851, 55.17042137682438, 50.37071652710438, 51.44800052046776, 50.75999043881893, 62.517133355140686, 62.10525445640087, 65.65459460020065, 59.3690250813961, 64.2053371667862, 55.905670523643494, 55.235648676753044, 49.13495443761349, 50.845941826701164, 51.51084154844284, 53.58922362327576, 58.46010625362396, 52.4045117944479, 58.61324183642864, 62.70884446799755, 62.739470824599266, 61.11517198383808, 59.652968645095825, 53.980815410614014, 53.10597315430641, 49.79328811168671, 49.41075883805752, 52.55742318928242, 52.4353851377964, 52.743237018585205, 55.590880215168, 54.020648673176765, 56.33146047592163, 55.964343175292015, 56.10545240342617, 57.16993868350983, 58.985348269343376, 58.10451753437519, 62.433036267757416, 59.98405247926712, 61.10493913292885, 62.633961886167526, 66.38033285737038, 63.47726583480835, 66.82013645768166, 64.36973914504051, 46.74481809139252, 43.26742708683014, 50.67024305462837, 70.29156178236008, 62.92552784085274, 68.33677187561989, 62.179270684719086, 61.990006640553474, 59.51597839593887, 59.878950119018555, 60.62992662191391, 58.866760432720184, 56.735131815075874, 57.912411242723465, 61.155366227030754, 60.56374937295914, 57.93487183749676, 57.45520457625389, 54.50435891747475, 58.0982630699873, 55.42045556008816, 55.36210969090462, 51.248727813363075, 47.74599216878414, 52.35500805079937, 50.08498705923557, 56.64553642272949, 55.05597911775112, 55.17021618783474, 54.269303530454636, 51.13262504339218, 53.74188423156738, 55.39289563894272, 53.26882481575012, 54.540365785360336, 48.52480597794056, 53.98372605443001, 56.92517101764679, 62.66033247113228, 61.78959019482136, 63.519846349954605, 61.50402031838894, 66.95505201816559, 54.497728273272514, 51.01822458207607, 64.5827405154705, 37.720933109521866, 34.98588167130947, 65.85354432463646, 63.120886757969856, 69.01651740074158, 64.48760122060776, 65.48539727926254, 54.24430467188358, 54.11782465875149, 50.896741300821304, 55.91889001429081, 62.68117815256119, 69.00308132171631, 67.46223360300064, 71.15490585565567, 64.97047170996666, 42.4963116645813, 1.3696925528347492, 1.5071751130744815, 0.18669251730898395, 10.267396755516529, 2.908385074697435, 41.81691192090511, 81.03596404194832, 67.11554780602455, 71.66366815567017, 59.80278700590134, 47.21274018287659, 33.15503731369972, 25.106968469917774, 52.05853655934334, 56.954391449689865, 49.1891623288393, 65.5993227660656, 75.8222334086895, 38.77729922533035, 1.0563310864381492, 0.6496004958171397, 0.22980516718234867, 0.13392336841206998, 0.11912074318388477, 0.12744882755214348], [0.06616167127504013, 0.057461410979158245, 0.03236369462683797, 0.06506664722110145, 0.05189820149098523, 0.06795300796511583, 0.01735219564579893, 0.032686629056115635, 0.09958440321497619, 0.5207233456894755, 50.16350604593754, 61.65425285696983, 36.47668607532978, 27.313646860420704, 43.07919658720493, 32.07421950995922, 17.454540096223354, 15.797101333737373, 41.13044835627079, 67.84770771861076, 64.38837334513664, 56.513197124004364, 58.40793125331402, 52.47369848191738, 2.3436456033959985, 0.8966619917191565, 0.04477772497921251, 0.07243937972816639, 0.704139384906739, 0.23788951541064307, 13.32848209887743, 68.86961728334427, 62.696662321686745, 63.794047236442566, 59.24428537487984, 50.88086195290089, 44.71947357058525, 56.289085149765015, 60.3123814612627, 60.311404913663864, 57.76817478239536, 56.360791102051735, 54.53951083123684, 49.6096021682024, 50.323808044195175, 47.73065999150276, 41.82606562972069, 54.00360658764839, 56.17961302399635, 58.31227518618107, 57.68700733780861, 57.531390488147736, 55.25966338813305, 50.43775252997875, 43.3517749607563, 44.29297685623169, 47.04197354614735, 49.40311744809151, 52.279620096087456, 51.437725871801376, 49.866734370589256, 54.03670281171799, 51.86029739677906, 53.70663732290268, 50.20765207707882, 52.0826880633831, 48.700884729623795, 43.96296836435795, 42.969108894467354, 44.309179186820984, 46.09198272228241, 45.69169320166111, 41.88022032380104, 45.68875975906849, 47.08531402051449, 46.53924912214279, 44.472433626651764, 45.50021007657051, 47.72118330001831, 50.21892607212067, 46.77369274199009, 51.84110842645168, 54.960710629820824, 55.855756402015686, 60.76616071164608, 63.393430933356285, 62.012490034103394, 61.98087953031063, 47.35485255718231, 38.84299769997597, 52.1500850468874, 65.25563880801201, 61.85749255120754, 60.62612682580948, 58.136979192495346, 55.75910858809948, 53.26187498867512, 51.10406957566738, 51.130861937999725, 49.790784046053886, 50.53713619709015, 45.70273160934448, 45.739289447665215, 50.35318426787853, 46.60858780145645, 49.1865860670805, 49.40263867378235, 46.84265524148941, 46.41018524765968, 45.81332087516785, 38.130269944667816, 41.07740320265293, 45.14968268573284, 51.4415218681097, 51.471604853868484, 49.043531343340874, 50.96218138933182, 51.439963951706886, 49.895373433828354, 50.32305188477039, 53.405678272247314, 46.12459637224674, 46.82522937655449, 45.21230712532997, 45.97857780754566, 53.8524316996336, 57.9577200114727, 57.74473384022713, 61.677123829722404, 57.81547464430332, 61.00123129785061, 53.294116258621216, 58.159823566675186, 53.51364187896252, 60.26990734040737, 45.22124424576759, 51.24971956014633, 60.277301743626595, 61.71326369047165, 61.81881442666054, 59.28534597158432, 58.11769522726536, 50.68909764289856, 46.69205792248249, 46.58538244664669, 52.67925605177879, 58.837999776005745, 62.30538971722126, 61.69488787651062, 65.97753927111626, 20.804951414465904, 0.27350757212843746, 0.18355326232267544, 0.1267580216517672, 2.14452370069921, 1.1333983135409653, 55.276526883244514, 53.84194426238537, 62.393358796834946, 56.920664459466934, 60.2879373729229, 46.387386471033096, 18.757370486855507, 20.768574066460133, 35.43734684586525, 30.672128945589066, 29.228776395320892, 52.274851351976395, 53.90083350241184, 18.94448384642601, 0.5844614224042743, 0.38822715694550425, 0.09040405129780993, 0.21216416847892106, 0.038177731476025656, 0.09601868048775941, 0.011888395911228145, 0.05798101825348567, 0.010537010857660789, 0.11760858018533327, 0.072868823481258, 0.08194783513317816, 0.060158223495818675, 0.10947119808406569, 0.14599834859836847, 0.5098042159806937, 57.76312865316868, 70.44905573129654, 41.00172646343708, 29.67675145715475, 54.93035785853863, 29.760054387152195, 17.08207458257675, 17.20115639269352, 48.442711383104324, 72.49742701649666, 69.6809421479702, 62.88767047226429, 66.3583092391491, 60.02004034817219, 3.174481471069157, 2.0930457254871726, 0.2455253095831722, 0.08810230996459723, 1.0622078273445368, 0.2994900138583034, 14.889944661408663, 71.20849817991257, 65.75707510113716, 66.87163889408112, 60.66455416381359, 55.53724609315395, 48.65391165018082, 59.37727823853493, 61.043238043785095, 63.22798401117325, 60.82128055393696, 60.62191665172577, 55.92124588787556, 55.44795848429203, 45.2711545675993, 43.59872370958328, 46.50974750518799, 58.30113038420677, 59.34491157531738, 60.34257084131241, 60.242271423339844, 59.896391183137894, 57.241952419281006, 51.71066142618656, 47.11231917142868, 47.14710630476475, 48.8711953908205, 51.32367119193077, 54.73309524357319, 52.46005341410637, 55.02318687736988, 55.150343254208565, 56.20376072824001, 57.00406238436699, 55.59712328016758, 54.70173552632332, 51.230469793081284, 45.82413889467716, 45.610806941986084, 45.25749810039997, 48.3341284096241, 49.61790472269058, 48.5641148686409, 48.286068588495255, 52.251740992069244, 49.74447973072529, 49.761335626244545, 50.74151583015919, 53.897816464304924, 53.88624608516693, 51.60437352955341, 55.71455217897892, 56.04909002780914, 54.86511155962944, 61.206431686878204, 62.837870344519615, 64.01199594140053, 63.770534098148346, 47.37367294728756, 38.45751218497753, 52.24480256438255, 65.11015981435776, 63.88448238372803, 61.85258321464062, 59.525025710463524, 59.472573325037956, 55.21017864346504, 55.95686137676239, 53.80913682281971, 51.68412744998932, 54.87906061112881, 49.92148943245411, 50.80641254782677, 55.076836198568344, 48.86128932237625, 52.26633220911026, 53.904994279146194, 48.75735729932785, 50.50644904375076, 49.095060378313065, 41.68836861848831, 45.090945437550545, 47.99264073371887, 54.08904120326042, 53.74291017651558, 51.99171334505081, 55.80459974706173, 52.57932521402836, 52.13733293116093, 52.39090092480183, 55.1073257625103, 47.87856325507164, 50.53044855594635, 45.96152812242508, 49.01655279099941, 53.56904290616512, 60.74075907468796, 59.224765822291374, 62.31306150555611, 58.300799801945686, 64.71221476793289, 55.52372261881828, 61.30851700901985, 48.7757521122694, 63.76227334141731, 53.16621512174606, 49.872384667396545, 62.3152843862772, 62.79020570218563, 63.421420231461525, 63.034266605973244, 60.957966819405556, 52.70477928221226, 51.67706362903118, 49.05621126294136, 55.11382721364498, 59.50185835361481, 65.14988288283348, 67.66570508480072, 70.45255154371262, 23.662987053394318, 0.7466924702748656, 0.23579778702696785, 0.25021592038683593, 1.7570292809978127, 1.9889634917490184, 63.573845252394676, 59.12667788565159, 73.1024381518364, 65.19905984401703, 68.49194034934044, 50.44287845492363, 22.93725449591875, 20.952799580991268, 42.058347165584564, 37.21902184188366, 29.163906276226044, 58.76575045287609, 66.69245570898056, 24.80028312653303, 0.7750235719140619, 0.38837908941786736, 0.042878335298155434, 0.11766859024646692, 0.09297442040406168, 0.07942042895592749, 0.17614829092053697, 0.30585752218030393, 0.11029922708985396, 0.13150335842510685, 0.19240016728872433, 0.15229936048854142, 0.14290006016381085, 0.17898985563078895, 0.3305287967668846, 0.8936743426602334, 69.1100911796093, 77.95692846179008, 55.25311253964901, 33.501092344522476, 69.60794806480408, 42.99049414694309, 25.61698280274868, 24.637271873652935, 52.88664132356644, 75.7964251935482, 75.87945073843002, 67.25417196750641, 70.9759658575058, 64.9534410238266, 3.903185944072902, 4.704105304554105, 0.20419627806404606, 0.30117765767499804, 1.7135005979798734, 0.35226161184255034, 17.86783441901207, 71.93843901157379, 68.35692599415779, 70.13022243976593, 64.49093744158745, 56.134870424866676, 52.30654925107956, 63.917092233896255, 63.92697170376778, 69.30392637848854, 63.495656847953796, 62.10589662194252, 57.0785877853632, 53.37982065975666, 51.420402601361275, 45.235489681363106, 47.597302347421646, 60.99860943853855, 62.361501306295395, 61.82341977953911, 62.82179720699787, 60.91042757034302, 58.19350875914097, 56.190651431679726, 50.20322531461716, 49.57057446241379, 52.5402557104826, 53.78924869000912, 56.82130739092827, 57.15727776288986, 58.312829956412315, 59.420941695570946, 61.60519368946552, 62.128000035881996, 56.60371206700802, 58.86095434427261, 56.451070457696915, 49.40496414899826, 49.178857281804085, 49.1239920258522, 53.869014009833336, 54.654124081134796, 52.604472264647484, 54.13032978773117, 57.84733213484287, 54.20499958097935, 54.35629606246948, 57.84044690430164, 61.904940605163574, 59.34031382203102, 56.36991821229458, 59.03813123703003, 62.700310125947, 59.65787798166275, 67.04754665493965, 66.86847746372223, 65.33060878515244, 67.07995891571045, 48.465384766459465, 38.90218332409859, 55.947175696492195, 70.8679148554802, 68.72064247727394, 65.86641043424606, 66.03148877620697, 61.805074363946915, 59.20930825173855, 59.41201597452164, 57.52066366374493, 56.46826073527336, 61.55378244817257, 55.602435395121574, 54.93395246565342, 61.64226070046425, 53.906487599015236, 55.17933189868927, 59.82279673218727, 51.76990404725075, 54.1888352483511, 54.52032186090946, 45.17933249473572, 48.62064443528652, 51.1530489474535, 57.95321725308895, 57.542976066470146, 56.67943440377712, 56.427884101867676, 56.54522940516472, 56.48989297449589, 53.52071709930897, 56.23692914843559, 51.651513800024986, 51.747777834534645, 47.77805104851723, 49.8402763903141, 56.16758666932583, 63.85311886668205, 61.426325887441635, 64.15281638503075, 62.04703398048878, 67.4938403069973, 56.2538306415081, 62.67366215586662, 52.93409697711468, 62.571679428219795, 43.15826274454594, 55.08546933531761, 63.63608971238136, 67.86400884389877, 65.78707829117775, 64.56016212701797, 61.78348012268543, 56.69841058552265, 53.838486447930336, 51.809459924697876, 56.35853782296181, 64.68215078115463, 68.31198960542679, 68.8289974629879, 71.82321399450302, 30.328899063169956, 1.5035008289851248, 0.9283027751371264, 0.5554967641364783, 6.900260159745812, 1.9530282262712717, 69.84139993786812, 64.97551023960114, 75.85306495428085, 65.81908017396927, 75.05819320678711, 55.493943616747856, 35.59621252119541, 25.490187406539917, 54.20774303376675, 45.48123389482498, 39.57352750003338, 72.33681723475456, 74.42228212952614, 34.14391525089741, 1.1697577312588692, 0.46438917168416083, 0.26643668592441827, 0.2497203735401854, 0.18729845120105892, 0.22712634061463177], [0.08771462686127052, 0.011038089487556135, 0.07965939308633097, 0.08800151146715507, 0.09938806062564254, 0.055296844511758536, 0.03731303666427266, 0.1016628100478556, 0.2731523208785802, 0.43200671556405723, 47.14503541588783, 65.8149003982544, 47.82574608922005, 40.79150654375553, 32.91598454117775, 47.001866698265076, 21.929303482174873, 12.424877285957336, 54.91808831691742, 68.73293101787567, 59.17670980095863, 57.77919419109821, 54.839337542653084, 62.36714020371437, 9.320960640907288, 1.1757506034336984, 0.10125984612386674, 0.06825414922786877, 1.0193235659971833, 0.05653800857544411, 12.527592424303293, 67.6209206879139, 64.59904924035072, 64.13767799735069, 52.76453107595444, 47.71221958100796, 54.27343770861626, 60.620199143886566, 61.835396736860275, 61.11748605966568, 59.24077436327934, 62.51575402915478, 54.12304177880287, 50.62898866832256, 37.96910159289837, 63.24034474790096, 45.642029866576195, 49.8485903441906, 57.608549147844315, 60.568411722779274, 58.8987623155117, 59.43598508834839, 56.09626829624176, 47.65324294567108, 41.837715804576874, 43.98966193199158, 47.290396615862846, 45.646730214357376, 50.86505100131035, 49.72761243581772, 48.79812531173229, 51.22493728995323, 54.20372664928436, 48.143215253949165, 50.04177577793598, 55.03715492784977, 54.27189879119396, 53.08849789202213, 48.683443665504456, 46.89008429646492, 44.05567578971386, 43.926889300346375, 41.67286165058613, 41.727920696139336, 40.39001248776913, 44.69371855258942, 44.189265221357346, 46.87973365187645, 48.032842576503754, 47.62451648712158, 50.18966384232044, 50.82504294812679, 50.4237274825573, 55.24626150727272, 56.34594149887562, 58.091556429862976, 59.65617947280407, 58.112196922302246, 48.731199502944946, 40.9411197155714, 53.90813671052456, 62.652998864650726, 61.975369825959206, 58.920185565948486, 55.03939300775528, 54.419539868831635, 53.218899294734, 49.58015754818916, 49.78380002081394, 50.89426763355732, 48.227688521146774, 48.84295530617237, 40.99381908774376, 47.08311773836613, 45.62718406319618, 44.5584724098444, 45.658536180853844, 45.631010457873344, 43.275843635201454, 45.29469430446625, 42.4977707862854, 43.51475961506367, 49.62892793118954, 45.53523279726505, 47.78676018118858, 46.6900098323822, 46.03204093873501, 45.6961427628994, 48.67759197950363, 47.24580220878124, 48.91564540565014, 44.80316027998924, 45.9356477111578, 43.9909652620554, 47.1248546987772, 53.58961500227451, 58.46114739775658, 57.17639073729515, 61.2694551050663, 58.76893848180771, 60.52688755095005, 60.99115043878555, 63.086190819740295, 46.462512239813805, 50.813605561852455, 57.83719427883625, 47.422941103577614, 54.92220729589462, 56.135417595505714, 61.80915914475918, 60.70374146103859, 59.05273385345936, 58.34020368754864, 48.84259432554245, 49.92893323302269, 51.213150322437286, 56.38488560914993, 65.54709076881409, 63.80439028143883, 59.129976108670235, 12.734036296606064, 0.3345264197560027, 0.20703877788037062, 0.18002871394855902, 1.1987675121054053, 5.321415904909372, 61.455945298075676, 51.62463404238224, 66.58989161252975, 39.19689550995827, 65.15657812356949, 33.01909580826759, 16.934794485569, 43.35675649344921, 30.19657876342535, 40.60516454279423, 45.80346420407295, 50.836544930934906, 58.47824268043041, 13.20801431313157, 0.29888498538639396, 0.32896681339479983, 0.02727649680309696, 0.1762991547002457, 0.036799411100219004, 0.06856443374999799, 0.046109679678920656, 0.11788769450504333, 0.03463277404080145, 0.09050087930518202, 0.024214209952333476, 0.08216804519179277, 0.02942436680314131, 0.03990490207797848, 0.2907252201111987, 0.2868700894759968, 51.694801077246666, 76.64067149162292, 50.146927535533905, 38.533344715833664, 50.29737666249275, 38.13838630914688, 26.210877634584904, 17.3478190228343, 59.29345093667507, 77.64551997184753, 67.69524469971657, 64.525196403265, 59.09738905727863, 70.07050484418869, 10.907408762723207, 1.1900318996049464, 1.6254846146330237, 0.0909333658637479, 1.1080843093805015, 0.05046984922955744, 14.052897077053785, 69.76492524147034, 66.1102357506752, 66.25698387622833, 56.073651909828186, 51.2251690775156, 55.1515743881464, 65.31379088759422, 64.09209564328194, 66.03881478309631, 62.590689808130264, 65.78824862837791, 54.35368940234184, 51.90847501158714, 40.95644049346447, 56.328333243727684, 45.80047756433487, 51.65937937796116, 59.858446419239044, 62.17672862112522, 60.78736737370491, 64.15739893913269, 58.337148651480675, 49.794340655207634, 46.150666773319244, 45.356159806251526, 49.54148702323437, 47.5421255081892, 52.7780469506979, 52.01778754591942, 50.93085587024689, 54.39323008060455, 58.19498308002949, 52.354430481791496, 52.53700688481331, 58.26602026820183, 56.39782011508942, 55.00213980674744, 47.70946092903614, 50.567747354507446, 47.327611818909645, 46.913156658411026, 45.08617289364338, 46.74473449587822, 48.0669229477644, 49.04351994395256, 49.405427724123, 51.04518413543701, 52.962340861558914, 53.154348358511925, 52.287603467702866, 55.337335020303726, 55.884353667497635, 55.427716970443726, 58.82109448313713, 59.161309227347374, 60.78089252114296, 62.54391431808472, 49.861897230148315, 37.959545105695724, 56.04265697300434, 63.745417445898056, 62.36256904900074, 60.70061042904854, 60.74849545955658, 55.856793746352196, 54.57323782145977, 54.11351189017296, 54.7665486484766, 53.62362317740917, 51.966581493616104, 51.612710282206535, 47.723117396235466, 50.57514175772667, 50.13849198818207, 48.66328954696655, 51.69320896267891, 47.38995127379894, 47.295188158750534, 47.403733134269714, 46.14627420902252, 46.620895341038704, 50.947027802467346, 47.403664737939835, 49.85210135579109, 48.954308331012726, 48.46801422536373, 46.17466628551483, 48.05660270154476, 48.942129984498024, 51.350022777915, 46.52659960091114, 48.26514311134815, 46.24278523027897, 48.19232761859894, 54.52730968594551, 62.26470910012722, 59.68063496053219, 63.51967915892601, 62.14188449084759, 62.75095000863075, 58.63501086831093, 60.23105062544346, 51.19176886975765, 50.1513846963644, 63.407664969563484, 51.061162278056145, 54.04891535639763, 59.60805505514145, 62.24181152880192, 62.61297181248665, 62.931485921144485, 62.66291253268719, 51.44684538245201, 50.32236412167549, 53.193915635347366, 59.7956357896328, 68.81152600049973, 66.286880671978, 62.708179503679276, 15.070172790437937, 0.5076654651202261, 0.7249693921767175, 0.9944011189509183, 1.4080880675464869, 5.668492130935192, 71.099102050066, 55.764291509985924, 79.23973202705383, 38.14632408320904, 69.42041292786598, 33.94927069544792, 22.21210900694132, 36.027211993932724, 32.96664722263813, 45.58073915541172, 39.055429100990295, 59.29452247917652, 65.83611086010933, 17.17041414231062, 0.5119467666372657, 0.4587478400208056, 0.06680762919131666, 0.21330020361347124, 0.07385667398921214, 0.07787213078700006, 0.18969120952533558, 0.24356301175430417, 0.22911255044164136, 0.20605926169082522, 0.19067032495513558, 0.13711632520426065, 0.18053260253509507, 0.2611619752133265, 0.46693794429302216, 0.4426156572299078, 60.37768475711346, 83.01797568798065, 65.61008378863335, 49.70748491585255, 53.22617970407009, 58.67446415126324, 31.548424623906612, 24.05723299831152, 66.52991563081741, 81.0599635541439, 69.73060548305511, 68.90663489699364, 65.65118238329887, 76.71724498271942, 11.041874047368765, 3.1530731823295355, 0.8923011913429946, 0.29191972163971514, 2.3160058865323663, 0.17470551130827516, 16.65087752044201, 71.04160353541374, 67.06583887338638, 68.76130029559135, 60.18925666809082, 53.88333924114704, 59.949223548173904, 68.2950197160244, 67.67952114343643, 66.4416615664959, 64.02803868055344, 70.02027153968811, 55.96987187862396, 52.87182591855526, 53.156586438417435, 60.06014719605446, 41.71901397407055, 54.89756561815739, 60.454406440258026, 66.38553857803345, 64.53255280852318, 67.98259288072586, 60.424213260412216, 52.07849308848381, 47.51656047999859, 50.29413923621178, 52.638130858540535, 50.427037104964256, 54.435635805130005, 54.319947212934494, 55.44477805495262, 56.88471078872681, 61.30016125738621, 54.469868168234825, 55.73267720639706, 61.4514197409153, 59.969700649380684, 59.84444037079811, 53.544108644127846, 54.38648544251919, 50.490801483392715, 47.81060770153999, 49.847138822078705, 51.32424496114254, 53.27288679778576, 55.351930037140846, 56.041726022958755, 56.81827895343304, 59.12388123571873, 59.38027247786522, 57.62605480849743, 62.08807557821274, 61.29537731409073, 59.22561317682266, 63.094576969742775, 64.02626037597656, 63.56451295316219, 63.75140592455864, 51.204745173454285, 41.93757824599743, 57.46403530240059, 66.37558311223984, 67.73661687970161, 65.9336668252945, 60.938732251524925, 61.32438875734806, 61.193911358714104, 60.10894797742367, 60.30660577118397, 61.85190685093403, 56.32839784026146, 58.166742995381355, 52.7933107316494, 55.77565670013428, 56.825445368885994, 53.494715094566345, 56.4911013096571, 52.07835629582405, 50.2665451169014, 52.923351153731346, 50.67288011312485, 50.643595084548, 55.39431296288967, 52.24515214562416, 53.96094627678394, 51.679210513830185, 50.54008483886719, 48.01228567957878, 48.090595677495, 50.320627614855766, 53.36703434586525, 48.30325126647949, 52.48143866658211, 48.79803031682968, 51.84327431023121, 55.99625386297703, 62.855303809046745, 62.798390462994576, 65.78733667731285, 63.38643170893192, 65.8386567234993, 61.16577006876469, 62.50910438597202, 50.15477031469345, 49.95709352195263, 60.481126606464386, 50.959863513708115, 58.82902845740318, 59.42451350390911, 68.61585170030594, 65.47687813639641, 65.72794586420059, 65.70618823170662, 53.447696417570114, 53.768425807356834, 56.040054112672806, 61.64773240685463, 72.87787020206451, 70.49285978078842, 69.09980893135071, 18.597254678606987, 1.2134423246607184, 1.164794722571969, 0.6448508100584149, 3.557240394875407, 6.858974425122142, 77.31033995747566, 63.01980838179588, 80.94628885388374, 46.65126711130142, 77.58476883172989, 44.860856384038925, 35.05745843052864, 50.54482318460941, 50.94866931438446, 57.226662039756775, 61.77780322730541, 67.53623843193054, 79.25444483757019, 26.28452528268099, 0.9539983619470149, 0.5500455410219729, 0.15025876607978716, 0.2680179651360959, 0.23098626552382484, 0.18891976185841486], [0.0919944143970497, 0.006069562932680128, 0.21338736143661663, 0.007879808617872186, 0.18743741093203425, 0.13806695700623095, 0.13069901877315715, 0.06735186092555523, 0.8252678602002561, 0.7302530680317432, 28.021467179059982, 66.27434134483337, 50.01271113753319, 42.22244895994663, 25.8256334066391, 41.507760509848595, 23.436625599861145, 4.19819095171988, 32.913742661476135, 67.92315647006035, 45.73828250169754, 65.9122359752655, 50.57445779442787, 64.3455420434475, 17.970957085490227, 0.13060932280495763, 0.9654238738585263, 0.10435965596116148, 0.33661075634881854, 0.5291675613261759, 9.835339039564133, 64.22220066189766, 62.50535398721695, 64.09345597028732, 49.44466061890125, 52.09388606250286, 58.3853604644537, 63.7922765314579, 59.724401012063026, 63.60451340675354, 54.85980324447155, 51.833049058914185, 46.80241920053959, 57.47161589562893, 37.14245215058327, 29.83334105461836, 59.05561409890652, 46.338258907198906, 56.85826800763607, 57.32570752501488, 60.78903168439865, 59.107792899012566, 57.61654011905193, 49.8858093470335, 44.943916127085686, 44.579093903303146, 47.46017150580883, 49.656468853354454, 50.82465156912804, 51.907764449715614, 49.56110157072544, 50.84221042692661, 53.098662346601486, 53.33358854055405, 50.10895997285843, 52.784844785928726, 54.82042595744133, 55.08040800690651, 53.78859892487526, 52.68376260995865, 50.671694576740265, 48.42559330165386, 44.77443762123585, 40.5427148938179, 45.76408691704273, 41.575419679284096, 42.14467093348503, 45.395271107554436, 42.59461618959904, 46.491668075323105, 46.45321033895016, 54.31362435221672, 52.898979261517525, 55.137146562337875, 56.65280923247337, 56.49526968598366, 55.45632183551788, 58.106132447719574, 60.20778827369213, 54.92449477314949, 59.90288503468037, 56.155355125665665, 58.12126703560352, 54.043732434511185, 51.061420664191246, 51.598149463534355, 50.9565044939518, 54.43402089178562, 49.84394319355488, 46.61152504384518, 44.81609098613262, 43.82922314107418, 45.423328801989555, 45.30716523528099, 45.928861275315285, 43.76224033534527, 44.26149554550648, 46.6178897023201, 46.97190150618553, 47.701952531933784, 47.53956064581871, 48.31659995019436, 54.15469028055668, 53.54984633624554, 48.46521757543087, 47.03178629279137, 43.937213346362114, 49.73289415240288, 47.580818831920624, 45.65664388239384, 48.53683993220329, 47.96508081257343, 44.79996085166931, 47.33776107430458, 46.20749272406101, 54.44036655128002, 57.7405920624733, 59.2015490680933, 54.69030573964119, 60.64071424305439, 57.66284063458443, 66.2498326599598, 63.31596449017525, 48.860787749290466, 55.865343287587166, 62.244262397289276, 52.402999475598335, 45.474797040224075, 57.808513417840004, 55.802323669195175, 62.36409656703472, 56.072424575686455, 60.19365303218365, 51.08149118721485, 47.59262479841709, 51.192715018987656, 58.49284149706364, 62.99193687736988, 65.41801929473877, 50.78023575246334, 6.839698534458876, 0.10873290215386078, 0.03281438606791198, 0.14364636386744678, 0.7644939806777984, 10.17734918743372, 63.2783655077219, 47.877537310123444, 45.60244359076023, 54.994027242064476, 67.77916699647903, 8.288058266043663, 26.149448230862617, 57.23667070269585, 36.898357048630714, 26.645819395780563, 37.20109820365906, 50.182155445218086, 53.32542657852173, 5.166730955243111, 0.15034317795652896, 0.2587353007402271, 0.07569006076664664, 0.10924341811914928, 0.004451708828128176, 0.049594463780522346, 0.04765923949889839, 0.02158002356736688, 0.12076914965291508, 0.0020980807039450156, 0.15710697829490528, 0.017279044004681055, 0.12981203355593607, 0.11886469481396489, 0.9595421457197517, 0.5671285931020975, 33.13280090689659, 74.44734558463097, 57.76119075715542, 34.76420156657696, 37.13972009718418, 42.76334993541241, 23.65175675600767, 10.643606018275023, 34.66409593820572, 73.1414544582367, 50.43108008801937, 73.8852721452713, 56.62885531783104, 69.87789317965508, 21.732785627245903, 1.140346359461546, 2.931623440235853, 0.06799447917728685, 0.7298094418365508, 0.7376305502839386, 11.098142378032207, 69.33401316404343, 62.745694890618324, 68.02201956510544, 50.6875017285347, 55.525250136852264, 59.31976072490215, 65.48136189579964, 62.37207233905792, 65.57618200778961, 57.44061715900898, 53.47389981150627, 47.4046640843153, 57.5347039103508, 41.219454780220985, 30.49310725182295, 55.61850853264332, 49.39810171723366, 57.58535139262676, 59.949694722890854, 62.27837696671486, 62.569080367684364, 58.611778914928436, 52.144594341516495, 47.616688907146454, 46.643131747841835, 49.282299131155014, 51.10797576606274, 52.22540840506554, 54.299606904387474, 51.60738296806812, 53.67493562400341, 57.44157090783119, 55.52753761410713, 53.918054178357124, 57.12306819856167, 58.441122472286224, 58.886838555336, 57.93934419751167, 54.05431106686592, 51.237966790795326, 49.67587061226368, 44.54025998711586, 45.486150830984116, 48.18485341966152, 47.33951658010483, 46.00684829056263, 49.98648874461651, 49.529479667544365, 50.76421581208706, 52.59041681885719, 58.37812565267086, 55.42481392621994, 58.212302550673485, 56.53801739215851, 58.864358961582184, 57.587505877017975, 60.93794569373131, 61.97050988674164, 58.21795664727688, 61.43606476485729, 59.31653469800949, 60.15480771660805, 57.41490013897419, 53.65845590829849, 54.39879298210144, 54.55224394798279, 60.0472354888916, 55.652265921235085, 51.51060976088047, 49.89908583462238, 49.6061709523201, 48.55170853435993, 49.03949975967407, 48.79164285957813, 49.47713367640972, 49.14829932153225, 49.856254532933235, 47.47212566435337, 50.31879611313343, 50.57738743722439, 52.61449232697487, 54.09681178629398, 57.48555734753609, 51.00883148610592, 50.38777381181717, 44.40777629613876, 49.35834065079689, 49.905047714710236, 46.638518795371056, 49.00712929666042, 48.29180248081684, 47.129019275307655, 48.71840938925743, 50.147930681705475, 57.19957709312439, 58.49903516471386, 59.75655868649483, 56.086426824331284, 64.56454709172249, 60.564589127898216, 64.15410071611404, 58.202939853072166, 50.867353677749634, 55.02510577440262, 63.221425563097, 58.5530948638916, 46.54649533331394, 57.253640592098236, 59.34336505830288, 63.98604333400726, 58.95614683628082, 63.360194116830826, 52.91532978415489, 52.068446427583694, 52.465950697660446, 59.31188374757767, 66.2273758649826, 70.89020445942879, 55.956188812851906, 7.629175521433353, 0.16491535148816183, 0.09298656936152838, 1.043371525593102, 1.0515786102041602, 13.050459567457438, 70.2951867878437, 53.44847917556763, 50.08182942867279, 56.57235994935036, 68.70381698012352, 11.151675805449486, 41.10306702554226, 53.73395785689354, 48.14605750143528, 33.289276510477066, 39.043645933270454, 59.19325031340122, 62.37918555736542, 7.623533299192786, 0.28948963328730315, 0.3319616464432329, 0.027460642195364926, 0.1992064036312513, 0.03256899864936713, 0.08450821493170224, 0.18756025121547282, 0.196837913536001, 0.32004135951865464, 0.1234568671497982, 0.3024525783257559, 0.18602807249408215, 0.3409823327092454, 0.42161780584137887, 1.2840305431745946, 0.7849135505966842, 42.64645300805569, 84.51667606830597, 73.23983117938042, 54.350261986255646, 43.01461145281792, 60.6688479334116, 28.956258818507195, 16.643319725990295, 41.72978259623051, 80.6371222436428, 54.76709581911564, 76.68445274233818, 60.83633154630661, 78.22745114564896, 23.393885493278503, 2.270714216865599, 5.8453047182410955, 0.48797278432175517, 1.3591947848908603, 0.8652905782219023, 13.028414100408554, 71.69041112065315, 67.04057022929192, 71.511569917202, 53.465088084340096, 59.89686995744705, 61.76565907895565, 68.0983118712902, 63.93649399280548, 69.67774271965027, 59.238350093364716, 53.44042740762234, 47.56264440715313, 56.556647792458534, 45.13291038572788, 42.83452771604061, 58.06209281086922, 49.48965400457382, 61.32710561156273, 63.2748468965292, 65.85676655173302, 64.44761216640472, 61.573176607489586, 55.32877407968044, 48.904185220599174, 49.35772508382797, 52.86905586719513, 56.236286982893944, 55.944379046559334, 58.42663764953613, 55.335404723882675, 56.273152604699135, 60.851967707276344, 59.077307134866714, 55.92960923910141, 60.50930209457874, 61.963620856404305, 62.58303701877594, 61.76497891545296, 59.45476368069649, 56.816477850079536, 54.72094349563122, 51.51287443935871, 50.41816458106041, 54.028195068240166, 51.86169192194939, 51.14363305270672, 56.364290714263916, 52.996805012226105, 57.786269411444664, 58.70157189667225, 66.68166428804398, 63.81767436861992, 63.32931697368622, 61.08943596482277, 62.2739502042532, 59.234113320708275, 62.922772988677025, 62.820976451039314, 60.044100657105446, 64.87942099571228, 60.342354252934456, 64.78215381503105, 60.60800559818745, 57.06486292183399, 59.50529336929321, 61.337657645344734, 64.31968063116074, 58.84399965405464, 56.52262061834335, 56.822299137711525, 55.42419455945492, 55.81824481487274, 54.873767495155334, 56.06366604566574, 53.887047842144966, 53.719788417220116, 54.46893721818924, 53.97457994520664, 53.66199731826782, 54.01155196130276, 55.82096926867962, 57.492552772164345, 57.61851221323013, 55.52531473338604, 53.81102912127972, 46.54632434248924, 51.55036322772503, 52.2920948266983, 51.40855483710766, 51.43576517701149, 51.59077025949955, 49.84073616564274, 52.67050892114639, 53.1513275206089, 59.19873721897602, 61.08535498380661, 62.70998440682888, 58.283974304795265, 66.11414954066277, 62.530166655778885, 65.41377112269402, 58.08073841035366, 51.001710668206215, 58.52535255253315, 62.81178094446659, 56.762007772922516, 51.057123094797134, 59.705371633172035, 61.40304073691368, 67.9882849752903, 61.47523306310177, 67.39424005150795, 56.007801443338394, 54.847818687558174, 55.489516854286194, 61.6357858479023, 68.68221893906593, 74.26797240972519, 62.75857239961624, 10.91286526992917, 0.7785707409493625, 0.3266980976331979, 0.6970084737986326, 2.935346052981913, 13.691952545195818, 81.99833080172539, 59.96161088347435, 61.94940961897373, 61.67383320629597, 79.90439236164093, 19.06934704631567, 45.40200814604759, 61.54972806572914, 59.50533516705036, 41.362916082143784, 55.03918021917343, 69.65651705861092, 75.61237066984177, 13.721571005880833, 0.8778445108328015, 0.5280807008966804, 0.15416888985782862, 0.16489008878124878, 0.14446058892644942, 0.21536223124712706], [0.01649952733714599, 0.06095860750065185, 0.05263745479169302, 0.06830465237726457, 0.05945639670244418, 0.05973466126306448, 0.14176659286022186, 0.03358517693413887, 0.47866711334791034, 0.3245121758664027, 14.32893991470337, 70.04037246108055, 48.13071392476559, 42.55062595009804, 33.28366041183472, 38.61765459179878, 28.002173714339733, 16.798429302871227, 30.759567953646183, 67.22416117787361, 50.19607409834862, 55.06887562572956, 54.890687987208366, 63.105398789048195, 21.838803738355637, 0.3726850409293547, 3.286502785049379, 0.14546716382028535, 0.42914342076983303, 0.4923093016259372, 9.153080899268389, 61.2971518188715, 61.01840257644653, 62.977269664406776, 51.10378839075565, 48.380995094776154, 57.63939969241619, 61.4634270966053, 62.04069972038269, 58.64373899996281, 54.98617306351662, 52.80134730041027, 50.143754705786705, 43.8490504771471, 35.96740700304508, 35.831655487418175, 42.924560084939, 60.271522253751755, 58.13445992767811, 60.16143076121807, 57.82519072294235, 57.26264990866184, 52.56077840924263, 50.389563515782356, 46.61532863974571, 44.013627246022224, 45.84366984665394, 50.88294044137001, 51.140980795025826, 51.97339452803135, 47.179662957787514, 54.413323402404785, 54.98874932527542, 57.1396467089653, 53.92278112471104, 54.319776222109795, 56.12354323267937, 56.433200016617775, 54.53704856336117, 56.55986241996288, 55.32742515206337, 49.37739282846451, 47.242450788617134, 44.0995292365551, 43.419795110821724, 43.0901437997818, 47.430924475193024, 47.470054775476456, 48.2999112457037, 49.90863852202892, 52.9680747538805, 54.31543305516243, 52.657870799303055, 61.309926733374596, 56.5526732057333, 56.22551456093788, 58.62239554524422, 52.48308777809143, 51.277317479252815, 44.41803194582462, 50.70491619408131, 55.07249303162098, 54.02651555836201, 55.77629506587982, 55.9757349640131, 55.745170935988426, 55.37844121456146, 46.58766232430935, 44.34607520699501, 47.217018753290176, 41.99258789420128, 41.21239855885506, 43.61009269952774, 44.35501612722874, 44.20845799148083, 44.54685263335705, 45.548706874251366, 43.636011108756065, 48.230424374341965, 51.9715516269207, 50.34138210117817, 49.48362372815609, 47.47291602194309, 53.25712904334068, 55.055314153432846, 52.95823708176613, 47.16391660273075, 49.25345487892628, 44.4128680229187, 46.1968494951725, 47.691601887345314, 47.23256751894951, 44.33158278465271, 44.898595958948135, 45.57730793952942, 57.04858459532261, 54.73664805293083, 57.21762612462044, 54.32793818414211, 61.63735896348953, 55.91867722570896, 65.54036512970924, 64.00943487882614, 48.302901685237885, 58.43219295144081, 60.40092431008816, 68.6075909435749, 47.220525965094566, 50.61022907495499, 52.682892456650734, 58.17010581493378, 59.14037235081196, 61.1441720277071, 52.38550901412964, 48.01646925508976, 51.52700588107109, 57.67871618270874, 63.17637898027897, 63.81668642163277, 40.69216467440128, 4.440051773563027, 0.17370638757711276, 0.13918712502345443, 1.6133101866580546, 0.6339750811457634, 26.446335799992085, 61.04880094528198, 48.59782285988331, 52.33801156282425, 66.90011456608772, 28.926023840904236, 4.43484652787447, 23.779306411743164, 20.487677939236164, 42.13870145380497, 29.393997229635715, 42.180039435625076, 53.5183422267437, 53.84640522301197, 2.2763421898707747, 0.23470718617318198, 0.13539483945351094, 0.10542121657636017, 0.12457735429052263, 0.12754493567626923, 0.0020543635673675453, 0.04830335317819845, 0.03681659924041014, 0.1605301196104847, 0.1161111042893026, 0.09237650912837125, 0.031725937442388386, 0.11206285198568366, 0.12220053729834035, 0.5947003292385489, 0.3115340316435322, 18.571731448173523, 79.12240952253342, 56.47700786590576, 40.262916907668114, 38.25748711824417, 47.7527330070734, 30.51592692732811, 24.630318246781826, 35.71033179759979, 72.15587854385376, 49.91916015744209, 63.4247412532568, 58.80241468548775, 67.3629829287529, 25.75717817991972, 0.4917991196271032, 2.9758345428854227, 0.07757730520097539, 0.47673061257228255, 0.6433524435851723, 9.589292742311954, 65.66469445824623, 64.75215822458267, 67.46357873082161, 51.894225776195526, 53.22229251265526, 60.6939721852541, 64.1077584028244, 63.89113962650299, 58.114818781614304, 54.04852397739887, 52.84566432237625, 50.07640331983566, 41.67177110910416, 34.47781853377819, 40.70347286760807, 43.21895308792591, 63.92558857798576, 59.79144461452961, 63.734895810484886, 60.32300569117069, 62.127141281962395, 55.727684274315834, 52.62263149023056, 47.80770845711231, 47.11668513715267, 48.20543311536312, 52.40372143685818, 52.12566375732422, 52.61593244969845, 49.886584505438805, 54.745748564600945, 58.66565242409706, 60.114776864647865, 56.370043605566025, 56.45153023302555, 58.69442068040371, 57.326839864254, 58.90953853726387, 59.46367800235748, 57.876214385032654, 52.51820929348469, 47.91839271783829, 45.52080877125263, 46.56261406838894, 46.2784007191658, 51.88694916665554, 51.22477009892464, 52.29291558265686, 54.18755851686001, 56.62747599184513, 56.07942380011082, 57.19638526439667, 63.19750964641571, 57.505749464035034, 58.695480823516846, 57.59382873773575, 55.47273315489292, 52.67895586788654, 46.68544627726078, 54.10769060254097, 55.476578548550606, 56.28856837749481, 58.92317220568657, 57.048854380846024, 60.39802126586437, 60.88037118315697, 50.21494768559933, 50.19641228020191, 53.52482467889786, 45.29989242553711, 45.372502729296684, 46.4776886254549, 47.213450744748116, 50.01814104616642, 49.81802098453045, 50.01838803291321, 49.1968797147274, 52.03488662838936, 53.546593710780144, 54.25832971930504, 53.1267998367548, 51.09335795044899, 54.27403807640076, 55.355144664645195, 54.776078537106514, 49.482043012976646, 50.462576597929, 47.3264566808939, 47.85639524459839, 51.480180993676186, 48.74458238482475, 47.31372356414795, 46.661997735500336, 49.03879299759865, 55.120784640312195, 59.07788850367069, 58.5394573956728, 59.62730102241039, 60.59241123497486, 61.37017250061035, 55.93624368309975, 58.96938532590866, 51.73742339015007, 62.26124748587608, 59.0163242071867, 70.09352400898933, 53.50809797644615, 49.88011725246906, 55.16037091612816, 60.13339586555958, 64.65757369995117, 64.52825143933296, 56.21838614344597, 50.4120659083128, 53.52102108299732, 61.05818644165993, 66.59986227750778, 67.41376340389252, 46.80855967104435, 5.4003827925771475, 0.04181854470516555, 0.13377223745919764, 0.8618672587908804, 0.5290012608747929, 29.988429732620716, 69.18502315878868, 54.78694595396519, 57.90812887251377, 70.28767079114914, 33.31090494990349, 6.395849576219916, 30.447236113250256, 27.558374628424644, 55.18543817102909, 30.36052666604519, 37.8679396212101, 63.209972977638245, 58.60996641218662, 3.024552916176617, 0.11441997237852775, 0.17094062583055347, 0.05717076739529148, 0.08913888988899998, 0.0635277817491442, 0.0503474245488178, 0.20880366442725062, 0.14446578396018595, 0.1632478050305508, 0.4066418594447896, 0.2931412373436615, 0.19120563607430086, 0.27215051057282835, 0.2451626368565485, 0.7011785125359893, 0.471616443246603, 24.249605275690556, 90.95499739050865, 66.20281398296356, 55.84189474582672, 47.057640105485916, 60.65683677792549, 32.00674273073673, 27.6801884919405, 39.78812858462334, 84.16841715574265, 58.124869242310524, 70.45239195227623, 64.8680292069912, 76.34739562869072, 28.40546127408743, 1.8348549236543477, 10.474890321493149, 0.2597552788211033, 1.0663967463187873, 0.9276245115324855, 12.113119214773178, 68.37977796792984, 65.89824512600899, 69.8785163462162, 55.275025963783264, 56.41611993312836, 62.81191773712635, 66.69528275728226, 66.56622648239136, 61.4449068903923, 53.237218111753464, 55.40575414896011, 49.56944212317467, 45.89256942272186, 37.64654450118542, 44.22750636935234, 48.32137629389763, 63.4677891433239, 61.41421213746071, 66.94261908531189, 63.385455161333084, 63.14559303224087, 58.407551273703575, 55.38219541311264, 50.17600357532501, 50.58453105390072, 51.95213466882706, 57.220677360892296, 54.93028566241264, 57.71453306078911, 53.392979353666306, 60.160834193229675, 60.576448291540146, 62.198820635676384, 58.39782379567623, 61.04133054614067, 62.26996421813965, 62.530740424990654, 62.95930802822113, 62.03718110918999, 61.701366528868675, 59.30255524814129, 54.20706667006016, 51.9736111164093, 52.47385807335377, 51.967919021844864, 57.14588597416878, 56.40138812363148, 57.99335449934006, 61.155856400728226, 63.58090527355671, 60.738372802734375, 60.005331337451935, 70.08331015706062, 61.67982168495655, 63.18554028868675, 62.77134731411934, 58.106322437524796, 55.715825110673904, 46.00387305021286, 55.2296943962574, 60.27183763682842, 60.64658872783184, 64.8791778087616, 59.45912964642048, 63.08209843933582, 63.521947637200356, 56.00371666252613, 53.970422968268394, 60.34777656197548, 51.32682502269745, 53.675437197089195, 51.16452053189278, 55.33826217055321, 54.38867412507534, 53.723204433918, 53.76251332461834, 54.30716469883919, 58.76312859356403, 59.05544310808182, 57.17236675322056, 56.537208035588264, 54.855235889554024, 60.86229555308819, 58.88964660465717, 58.12685653567314, 52.32790030539036, 55.00547222793102, 50.66836215555668, 51.24967776238918, 55.486309826374054, 53.36247839033604, 50.1821668446064, 50.04260033369064, 50.73075860738754, 58.33848237991333, 59.67619679868221, 60.53824134171009, 59.615966230630875, 63.999866992235184, 59.53815400600433, 57.823598608374596, 61.124238297343254, 49.52620804309845, 60.847996920347214, 62.67826750874519, 69.80587184429169, 54.5167538523674, 56.04872524738312, 56.2462842464447, 64.37068909406662, 64.42938074469566, 66.80339455604553, 57.481996938586235, 53.8760132342577, 55.480686128139496, 64.49070185422897, 70.86086243391037, 69.65005740523338, 52.31897458434105, 6.499751675873995, 0.422270450508222, 0.31224946200381964, 3.954458017833531, 2.138859867118299, 32.09274351596832, 79.02706503868103, 61.58190093934536, 64.65283155441284, 76.66098520159721, 43.9694432169199, 10.502375196665525, 37.247949689626694, 25.244329199194908, 62.45884068310261, 40.126314237713814, 54.89476516842842, 69.9782381951809, 73.68797913193703, 5.865613203495741, 0.5340395530220121, 0.3959567140555009, 0.22675871034152806, 0.20953208237187937, 0.148299110296648, 0.15872646326897666], [0.2859888633247465, 0.05703538852685597, 0.05459503998281434, 0.0174555137346033, 0.15921086305752397, 0.16743152897106484, 0.0820689758984372, 0.07400287708151154, 0.3447371843503788, 0.24296875926665962, 7.927128933370113, 73.90900567173958, 50.175748988986015, 46.91354803740978, 31.53791058808565, 31.51121512055397, 28.936277590692043, 9.492669627070427, 39.382488951087, 73.02245244383812, 55.32904766499996, 48.633784130215645, 53.40166948735714, 59.136492758989334, 36.66954852640629, 0.4102344182319939, 1.5826736181043088, 0.05987386219203472, 0.5440070712938905, 0.486628309590742, 3.7800632882863283, 54.80746865272522, 61.8559118360281, 59.75098818540573, 52.80343718826771, 48.00811730325222, 59.78020861744881, 59.696958884596825, 64.67512115836143, 57.4694500118494, 55.14313884079456, 28.04720889776945, 49.072303399443626, 31.9114438444376, 14.917767718434334, 63.35131399333477, 51.07123173773289, 62.89307378232479, 57.61301010847092, 57.82777838408947, 56.13381028175354, 59.19248655438423, 51.5895277261734, 52.31517858803272, 43.94269645214081, 44.443270191550255, 44.54151771962643, 50.42176678776741, 52.74121552705765, 51.45320624113083, 48.64218547940254, 52.412681356072426, 54.26729343831539, 55.25097705423832, 54.920364394783974, 52.764819860458374, 51.22502848505974, 56.99267819523811, 53.475214540958405, 53.38715806603432, 56.294830441474915, 56.15111455321312, 52.68992207944393, 51.169483065605164, 50.54182894527912, 51.663536354899406, 49.63255673646927, 51.98199346661568, 51.26181811094284, 53.86749409139156, 56.90893068909645, 53.49413372576237, 59.84670504927635, 62.62106537818909, 59.803223982453346, 58.850664496421814, 54.87660974264145, 55.23439474403858, 47.72371396422386, 44.93307910859585, 50.53304001688957, 50.80213397741318, 49.624235183000565, 56.65184788405895, 60.35410702228546, 48.24647091329098, 42.71507352590561, 48.43182496726513, 48.063430935144424, 44.713568687438965, 44.02247317135334, 47.968170046806335, 42.227913066744804, 45.64590185880661, 46.69213391840458, 47.4660649895668, 48.18153239786625, 44.97111886739731, 48.70978385210037, 52.740003392100334, 53.76052223145962, 52.00382709503174, 51.02110102772713, 50.13936594128609, 51.21488682925701, 52.312051355838776, 48.83087955415249, 48.61317403614521, 47.26474039256573, 48.83113034069538, 50.547585636377335, 46.326680928468704, 46.81659244000912, 48.58756721019745, 48.72147582471371, 54.174992591142654, 59.04570423066616, 59.00479182600975, 60.6012761592865, 60.784198343753815, 52.858538031578064, 60.01477763056755, 51.38340398669243, 54.15002793073654, 60.241636857390404, 59.60405766963959, 63.14186543226242, 58.92007157206535, 49.81078617274761, 54.10306625068188, 58.45168970525265, 62.72463642060757, 62.53509119153023, 53.94811436533928, 45.653725638985634, 51.85219623148441, 59.475160986185074, 61.43388748168945, 62.447973266243935, 39.8153655230999, 3.1356696411967278, 0.06385316155501641, 0.130575688672252, 2.4163551768288016, 0.08309205615660176, 32.39866130053997, 60.17095685005188, 53.1872583925724, 52.63409927487373, 55.74754200875759, 25.294630900025368, 9.467577673494816, 36.96576163172722, 14.874186906963587, 39.52545627951622, 40.65605901181698, 53.75888831913471, 54.97601240873337, 41.74565814435482, 0.7173557882197201, 0.41802619700320065, 0.054429240481113084, 0.13529552525142208, 0.047331247333204374, 0.09319328717538156, 0.04066594483447261, 0.14329176570754498, 0.049325631916872226, 0.2877709676977247, 0.04591356344462838, 0.25904652778990567, 0.04887313705694396, 0.174248437397182, 0.1825643060146831, 0.5751655774656683, 0.21822165203047916, 10.014942102134228, 81.75312995910645, 63.624283745884895, 46.17906644940376, 34.719667956233025, 40.87046630680561, 22.82648093998432, 12.408139184117317, 43.842184245586395, 83.59093174338341, 57.56376855075359, 56.128300577402115, 59.601808190345764, 64.66770395636559, 40.120922327041626, 0.15618203964550048, 1.756173495668918, 0.016641325782984495, 0.2342736828722991, 0.7843930972740054, 5.35471779294312, 57.777035906910896, 65.26558667421341, 61.342092007398605, 57.64615572988987, 52.2998084127903, 62.31933116912842, 63.764659613370895, 64.98049557209015, 59.890870079398155, 55.66080406308174, 27.887809351086617, 48.1844088435173, 36.50856256484985, 20.547678619623184, 65.3241491317749, 52.95672096312046, 64.13413658738136, 59.9405600130558, 59.03854921460152, 57.83516138792038, 62.34836921095848, 55.51849029958248, 54.948938861489296, 46.429404616355896, 48.76569405198097, 47.42517538368702, 51.84589236974716, 54.456534683704376, 53.25177513062954, 51.35172888636589, 55.5684158205986, 56.45352892577648, 57.5990192592144, 56.55132047832012, 56.082946211099625, 55.609974190592766, 58.38586963713169, 56.10870882868767, 57.350144013762474, 58.49743165075779, 58.671496510505676, 57.373451963067055, 52.8728024661541, 50.855479314923286, 53.80764730274677, 52.10401251912117, 55.17253786325455, 55.237681567668915, 55.875332951545715, 60.995140224695206, 54.83586072921753, 60.08741073310375, 65.5413606762886, 62.63166680932045, 61.76918908953667, 56.67817287147045, 54.72966022789478, 48.78281593322754, 42.97483138740063, 50.93546502292156, 52.239444851875305, 55.04055194556713, 57.80815243721008, 60.602397099137306, 50.10612532496452, 48.12308773398399, 53.96685875952244, 53.518904596567154, 50.35642169415951, 49.187980592250824, 52.40677647292614, 46.50492176413536, 50.05897745490074, 50.54505117237568, 49.154983162879944, 49.37372222542763, 48.42612527310848, 51.28849647939205, 57.90753610432148, 57.895277962088585, 56.13801285624504, 51.452697068452835, 54.56393592059612, 56.86998277902603, 54.72124747931957, 50.5692482739687, 50.25002360343933, 48.515591472387314, 50.143754705786705, 53.634319603443146, 47.75060132145882, 48.817253485322, 49.382663145661354, 50.60341224074364, 54.76304143667221, 59.77860510349274, 59.367535561323166, 62.016453221440315, 60.38862816989422, 57.274820655584335, 53.15233066678047, 49.9239706993103, 56.61503545939922, 60.19946292042732, 62.254081070423126, 62.144282162189484, 62.20409095287323, 54.68257695436478, 56.04970559477806, 62.63996176421642, 65.34313291311264, 63.25239770114422, 57.412597462534904, 49.931330904364586, 54.03553627431393, 61.888134106993675, 63.550503104925156, 67.67669409513474, 44.18324254453182, 2.919628908857703, 0.26831188530195504, 0.044530018349178135, 1.6880090720951557, 0.21454825851833448, 39.036289528012276, 66.29463225603104, 56.95878021419048, 59.955364018678665, 63.25286507606506, 31.981531083583832, 11.323400940746069, 46.59093014895916, 14.861371144652367, 52.419874370098114, 41.29413217306137, 47.965065613389015, 65.95444411039352, 43.78096953034401, 0.9886751230806112, 0.3967990219825879, 0.025754734124348033, 0.16776812262833118, 0.016430103132734075, 0.047230066629708745, 0.029190556888352148, 0.31954705948010087, 0.1877704868093133, 0.4157055605901405, 0.1519455638481304, 0.43126165866851807, 0.21906173351453617, 0.3754359745653346, 0.337799409753643, 0.8188947709277272, 0.5784860055427998, 12.755362652242184, 97.37860590219498, 72.86786153912544, 64.33749407529831, 41.60472370684147, 50.49870505928993, 35.33125653862953, 18.55551201850176, 48.53072986006737, 87.77012228965759, 65.39184629917145, 63.899529576301575, 63.85941132903099, 73.10746908187866, 44.45217691361904, 2.108683311380446, 7.7030692063272, 0.12702860869467258, 1.4185308571904898, 1.0778559814207256, 6.9131452683359385, 62.23842591047287, 67.39628434181213, 64.46699872612953, 59.219776690006256, 54.99287590384483, 64.06077772378922, 66.6643676161766, 67.52774968743324, 60.35579413175583, 60.04043385386467, 31.071707904338837, 53.207093328237534, 33.62221084535122, 18.55656836181879, 68.88789430260658, 54.3538261950016, 65.95711916685104, 63.225802928209305, 63.26693952083588, 59.64148186147213, 64.42937314510345, 55.766556188464165, 57.42710508406162, 47.285464480519295, 50.926565900444984, 49.13077086210251, 55.804322361946106, 56.95911839604378, 55.319988951087, 53.609503135085106, 58.657281473279, 59.23150286078453, 61.457780599594116, 61.63315258920193, 60.57140976190567, 55.98951302468777, 61.37873724102974, 59.25807483494282, 63.121924102306366, 64.23591792583466, 65.66347852349281, 59.328295066952705, 58.3191604167223, 56.8971399217844, 61.34331934154034, 55.03857985138893, 59.81088437139988, 59.489543214440346, 58.36207151412964, 61.88431151211262, 61.24976836144924, 65.25158822536469, 70.13790562748909, 66.50854557752609, 65.49146175384521, 60.6027352809906, 61.27851761877537, 51.351166516542435, 44.99988332390785, 55.65593272447586, 55.979511961340904, 58.00970122218132, 62.7984968572855, 65.34513920545578, 54.78020131587982, 53.25330264866352, 62.317818850278854, 60.017551481723785, 55.77165551483631, 56.058688312768936, 62.00450286269188, 48.588866740465164, 53.97911310195923, 54.540749564766884, 53.57367105782032, 55.81560395658016, 54.66445192694664, 56.133206114172935, 60.51985412836075, 60.29601573944092, 60.181550681591034, 55.96699923276901, 58.842639327049255, 59.8157063126564, 59.86222721636295, 53.82149375975132, 53.2907572388649, 49.79214817285538, 53.00671488046646, 57.90718272328377, 50.21405093371868, 51.81902401149273, 53.15684862434864, 54.494658038020134, 57.750528529286385, 61.633046194911, 61.85349516570568, 62.397371381521225, 65.51243662834167, 53.68131548166275, 63.426804542541504, 56.93190045654774, 54.14361007511616, 62.112006694078445, 62.323598340153694, 65.5551615357399, 64.33269873261452, 55.05224771797657, 57.196039482951164, 65.69276735186577, 66.19310930371284, 67.8888139128685, 60.92249572277069, 51.09864726662636, 56.44013084471226, 65.91699331998825, 66.76574617624283, 70.18023535609245, 50.34112751483917, 4.95327265933156, 0.887137446552515, 0.3248839621664956, 8.184721861034632, 1.4413891243748367, 42.19898521900177, 74.04807060956955, 63.560287579894066, 66.56162112951279, 65.07286101579666, 37.606589645147324, 16.117642633616924, 49.23595301806927, 18.364669159054756, 62.488190308213234, 56.35067604482174, 74.01609152555466, 72.15373545885086, 62.7801438421011, 2.4707768065854907, 0.7295270101167262, 0.29819066170603037, 0.2758914098376408, 0.2526519459206611, 0.2243508567335084, 0.13816677586873993], [0.2061981917358935, 0.010835907123691868, 0.23806553799659014, 0.04526652570348233, 0.1967159193009138, 0.21575913182459772, 0.08664064269396476, 0.20189277041936293, 0.3268973791273311, 0.049710676685208455, 3.742235843092203, 59.03194136917591, 64.73257407546043, 41.229307651519775, 40.56443452835083, 29.31703805923462, 105.45922949910164, 41.3413180410862, 11.125968284904957, 64.2309857904911, 56.64386831223965, 56.97372481226921, 52.20561906695366, 61.0331229865551, 47.37262040376663, 0.20601259544491768, 1.3579838373698294, 0.046807988692307845, 0.2831231046002358, 0.7784968230407685, 1.6890670778229833, 49.80372615158558, 60.886602848768234, 66.27053394913673, 53.64949978888035, 48.805622309446335, 53.07276293635368, 65.15797644853592, 57.65041530132294, 74.02019530534744, 69.83545705676079, 33.51296670734882, 40.55400408804417, 56.12909093499184, 49.4889472424984, 56.761620193719864, 62.73550383746624, 64.50020134449005, 59.918129816651344, 58.40234935283661, 54.95754159986973, 55.15177197754383, 51.876841709017754, 53.61812487244606, 47.75043413043022, 45.2703870087862, 43.58299635350704, 49.41312611103058, 52.70280338823795, 52.973652854561806, 44.165881276130676, 48.49507637321949, 54.01596352458, 53.71084749698639, 51.727160140872, 51.89215488731861, 60.089025646448135, 59.1126262396574, 54.429016560316086, 52.79029369354248, 56.47139176726341, 56.85270890593529, 54.88713517785072, 53.067644611001015, 55.829720199108124, 54.208727180957794, 52.57509984076023, 55.62181055545807, 57.62123666703701, 57.32046000659466, 58.961569145321846, 60.47440096735954, 61.188922226428986, 59.71864052116871, 58.865115121006966, 58.065888807177544, 56.18000440299511, 60.393324717879295, 54.60016317665577, 45.10609522461891, 48.64346221089363, 56.04575000703335, 56.96773633360863, 58.58132354915142, 57.76628628373146, 55.03728412091732, 56.85505338013172, 53.24753075838089, 52.11070775985718, 49.22409765422344, 49.45161044597626, 52.562841698527336, 49.15865756571293, 46.58811070024967, 50.825772508978844, 51.30302309989929, 45.85302874445915, 48.63874286413193, 49.51195500791073, 53.48805785179138, 56.442479118704796, 50.81697218120098, 50.077733248472214, 52.679746225476265, 49.95412968099117, 47.701747342944145, 49.79077644646168, 45.032401978969574, 46.86850145459175, 47.03476533293724, 46.24584786593914, 47.319833636283875, 46.45164482295513, 47.218527272343636, 50.94714939594269, 54.8993781208992, 61.51150971651077, 58.33534374833107, 60.646721720695496, 57.70396202802658, 62.94955015182495, 38.77667225897312, 35.74106454849243, 64.40798789262772, 54.176288321614265, 62.13588461279869, 53.1029637157917, 60.82921452820301, 61.583261266350746, 62.47796505689621, 64.6740572154522, 62.91789785027504, 58.90076860785484, 52.13849946856499, 47.92634189128876, 53.102682530879974, 57.772267162799835, 62.08893433213234, 65.19000113010406, 36.45227238535881, 0.5164560559205711, 0.04146361257880926, 0.037359209381975234, 0.34989128122106194, 1.4131517708301544, 56.6296798735857, 52.55669362843037, 62.77701660990715, 49.67755392193794, 72.12089762091637, 21.217443980276585, 18.61956138163805, 29.945220351219177, 22.249873280525208, 38.709624856710434, 13.992102239280939, 34.85203005373478, 57.18576483428478, 27.300448268651962, 0.3992569854017347, 0.31985157751478255, 0.1362860103836283, 0.18106822535628453, 0.12015790198347531, 0.16733913158532232, 0.0630281753547024, 0.22130959492642432, 0.029822239594068378, 0.2185551731963642, 0.10153407711186446, 0.29732015216723084, 0.0863540920545347, 0.06348786904709414, 0.17612403753446415, 0.4758751834742725, 0.06062415493943263, 3.7054343428462744, 69.82156500220299, 74.69291120767593, 46.79670810699463, 39.611802846193314, 39.73328232765198, 79.91022884845734, 44.98473733663559, 14.786824844777584, 74.12769913673401, 63.03681246936321, 64.40209820866585, 56.95068284869194, 68.44006553292274, 52.008763030171394, 0.6221250013913959, 1.0892831557430327, 0.1967296193470247, 0.27043128095101565, 1.5611816151067615, 2.008341858163476, 52.57465906441212, 62.83397935330868, 71.63026034832001, 56.61500126123428, 52.28805564343929, 52.9096794873476, 69.02250587940216, 60.12567847967148, 75.7212196290493, 73.41316267848015, 35.49096576869488, 39.04652617871761, 61.071158945560455, 56.75555571913719, 56.42813488841057, 65.09846404194832, 65.16296178102493, 61.49243474006653, 61.39954872429371, 58.303045481443405, 56.49928227066994, 55.382070019841194, 55.53052045404911, 50.32718226313591, 48.10563147068024, 47.07711026072502, 51.352196261286736, 54.225320890545845, 53.986150324344635, 46.44816420972347, 50.47988846898079, 55.116574466228485, 58.22390712797642, 54.65636596083641, 53.96721214056015, 63.55949342250824, 60.56246504187584, 57.0954854786396, 55.470840856432915, 57.92189173400402, 60.49841567873955, 55.20914129912853, 56.09300047159195, 56.85635671019554, 56.131705194711685, 52.666256949305534, 56.51250936090946, 58.55602070689201, 58.12994956970215, 62.959870398044586, 64.51334103941917, 62.438576370477676, 61.35797515511513, 61.97735331952572, 60.17484024167061, 58.11320386826992, 62.85755708813667, 55.07023215293884, 44.65081125497818, 48.49229872226715, 51.317158341407776, 56.164163053035736, 55.96498914062977, 61.274664625525475, 56.187144219875336, 59.61040712893009, 57.927564829587936, 57.498735040426254, 49.610430523753166, 52.29353874921799, 54.72788952291012, 50.51510117948055, 49.50861118733883, 52.36134611070156, 52.64740236103535, 51.320296972990036, 53.68122808635235, 51.584052219986916, 59.92141664028168, 61.6130630671978, 53.997272327542305, 50.94202347099781, 54.21238638460636, 52.672370821237564, 50.83311751484871, 50.1384311914444, 45.75927257537842, 47.891851142048836, 49.30353619158268, 47.08221338689327, 47.74195298552513, 48.94457705318928, 48.28264877200127, 52.86606542766094, 53.82274389266968, 62.15624772012234, 60.46657718718052, 63.393670320510864, 58.64496253430843, 64.29279327392578, 37.711346223950386, 38.080352023243904, 68.69154363870621, 56.7131157964468, 63.59026037156582, 57.03430876135826, 60.60579791665077, 58.76479670405388, 63.16263511776924, 66.63773864507675, 67.51651749014854, 62.20684200525284, 57.36236795783043, 51.059900745749474, 55.233976766467094, 59.75915014743805, 66.02381318807602, 70.45061364769936, 40.658061504364014, 1.3458266272209585, 0.06459190277382731, 0.23008219606708735, 0.5567286105360836, 2.682728008367121, 66.4796595275402, 56.390315517783165, 70.2308714389801, 55.23701660335064, 79.79514822363853, 22.560867592692375, 24.74757805466652, 40.775258615612984, 15.890035796910524, 52.12669350206852, 16.648926325142384, 38.969470113515854, 66.50634929537773, 31.027432680130005, 0.6266883783973753, 0.35660329449456185, 0.06870150100439787, 0.12324274270213209, 0.10456598043674603, 0.10763840502477251, 0.02995837916387245, 0.3908290673280135, 0.14012585277669132, 0.3619751671794802, 0.17635695316130295, 0.483726809034124, 0.2915048017166555, 0.3233913250733167, 0.4594559676479548, 0.8070539531763643, 0.16737371566705406, 5.753220934420824, 81.23897194862366, 82.00610518455505, 61.68231435120106, 48.59685391187668, 55.68307846784592, 113.51461485028267, 56.67579799890518, 18.74501734972, 77.47975006699562, 66.6434383392334, 73.10824424028397, 64.7578427195549, 75.38825869560242, 58.89964006841183, 0.6125868007075042, 2.6413218677043915, 0.3110967285465449, 0.8661040908191353, 2.236320124939084, 2.9399694548919797, 57.28462032973766, 67.20424264669418, 75.63261598348618, 58.40132720768452, 54.2403718829155, 56.12797759473324, 72.45275661349297, 60.936022996902466, 82.4066112935543, 70.31743079423904, 30.403855741024017, 41.99924133718014, 56.31286047399044, 49.687486588954926, 58.35182726383209, 69.332105666399, 68.57096090912819, 64.83076080679893, 62.79036529362202, 59.35587778687477, 58.173449635505676, 57.3517931252718, 58.00202563405037, 53.46540346741676, 50.604286193847656, 50.12724079191685, 53.529160246253014, 56.14584423601627, 59.86682116985321, 47.364792823791504, 52.23670519888401, 59.89423289895058, 61.720342710614204, 58.84658731520176, 58.14407721161842, 66.24471053481102, 65.57465448975563, 60.665165930986404, 61.447661742568016, 62.38262817263603, 64.62324634194374, 59.67856027185917, 57.64096140861511, 60.68611040711403, 62.15416543185711, 56.494813710451126, 63.269177600741386, 66.59042358398438, 63.225897923111916, 65.58384239673615, 69.55228865146637, 66.26893803477287, 66.84548869729042, 64.86387223005295, 65.72051346302032, 62.09521919488907, 66.84378638863564, 58.65427203476429, 47.88342319428921, 50.44252507388592, 54.34325896203518, 60.81009015440941, 61.027381494641304, 63.818631917238235, 63.23700092732906, 68.38932305574417, 63.108161240816116, 63.55436369776726, 55.91005548834801, 59.045947417616844, 61.50997079908848, 54.597879499197006, 55.74349142611027, 56.19368366897106, 60.459851548075676, 55.08183293044567, 56.19975954294205, 52.65987329185009, 63.480054885149, 65.00207841396332, 60.524987652897835, 53.79151716828346, 58.40398706495762, 53.62556867301464, 57.491515427827835, 52.77541369199753, 50.63324823975563, 52.56063021719456, 51.44894666969776, 49.28457520902157, 51.650415658950806, 51.42585530877113, 51.11199975013733, 56.39497026801109, 57.79102295637131, 63.77873405814171, 62.56017744541168, 63.583029359579086, 61.844383254647255, 63.504453375935555, 50.74466586112976, 44.86764281988144, 66.11380755901337, 56.82663470506668, 64.30377468466759, 61.90878979861736, 66.7224968969822, 57.222254276275635, 61.808615773916245, 66.01731553673744, 69.46213468909264, 64.94913205504417, 60.23525319993496, 55.77824056148529, 57.586400136351585, 61.927708983421326, 68.38032513856888, 71.64810419082642, 45.65246410667896, 2.773216115310788, 0.522505568806082, 0.41342574229929596, 2.7717926166951656, 2.8370282286778092, 71.28110468387604, 63.07883821427822, 73.81955847144127, 59.447559267282486, 84.5881350338459, 31.449751518666744, 27.396474815905094, 39.8435790091753, 31.098741553723812, 58.53262536227703, 22.812453992664814, 49.40496414899826, 70.97821533679962, 43.92764925956726, 1.1882008728571236, 0.4525295627536252, 0.30233232071623206, 0.224626490380615, 0.25983011699281633, 0.2157990148407407, 0.1621543543296866], [0.04413568189193029, 0.07343751640291885, 0.11556055687833577, 0.04433408765180502, 0.024657344474690035, 0.01845209004386561, 0.0943185760115739, 0.027422208222560585, 0.18686640250962228, 0.1950650117942132, 0.9416325192432851, 45.4496081918478, 63.877825140953064, 41.45349182188511, 40.2015919983387, 32.322114408016205, 65.1105397939682, 38.108960688114166, 3.205031594261527, 39.30789515376091, 69.20929625630379, 57.79468975961208, 53.55194002389908, 54.3118080496788, 50.763782635331154, 2.026931648142636, 0.6368088384624571, 0.03633877859101631, 0.04784997887327336, 0.868114004842937, 0.9829761413857341, 47.41243466734886, 62.24028021097183, 61.3215047121048, 59.219373911619186, 52.22302593290806, 52.58307561278343, 57.813977524638176, 60.351838544011116, 65.1191121339798, 65.1795744895935, 64.92452457547188, 59.63638253509998, 51.30874179303646, 48.06754991412163, 50.93071147799492, 59.260198920965195, 61.23224750161171, 59.161138236522675, 57.04650230705738, 56.281341165304184, 54.54924210906029, 56.38044364750385, 55.05695566534996, 49.76862743496895, 47.55778446793556, 45.40324687957764, 49.22691710293293, 50.53886890411377, 51.92814655601978, 49.910690411925316, 49.98429246246815, 53.95236633718014, 53.131838366389275, 55.01298442482948, 55.89824192225933, 55.77744260430336, 58.760111555457115, 58.5103015601635, 58.32965545356274, 55.89700698852539, 56.1356607824564, 55.30247949063778, 55.49911893904209, 54.395179376006126, 56.35092303156853, 52.89324916899204, 56.27726398408413, 57.0760153234005, 57.538241520524025, 58.61984208226204, 60.43485268950462, 58.67012098431587, 60.74770890176296, 57.19114914536476, 57.621411457657814, 56.23285576701164, 61.156654357910156, 59.453251361846924, 54.51792798936367, 58.32556687295437, 57.09552727639675, 55.19795849919319, 55.37116080522537, 56.596196070313454, 60.59299640357494, 55.83792395889759, 53.6241589486599, 52.39978864789009, 51.28478787839413, 51.496223732829094, 49.79327291250229, 50.64692370593548, 54.191096127033234, 54.34856727719307, 54.13682363927364, 53.232707753777504, 52.70191803574562, 52.7109045535326, 52.724903002381325, 51.88857927918434, 54.240250289440155, 52.49505713582039, 53.72207969427109, 50.30319795012474, 46.748538091778755, 49.28683988749981, 45.69322071969509, 47.2508255392313, 48.02888698875904, 48.62095221877098, 48.13608683645725, 43.48699450492859, 45.52453637123108, 49.574834033846855, 52.1136450022459, 55.95200523734093, 56.578557416796684, 58.16564865410328, 57.037151008844376, 58.77988189458847, 34.324181377887726, 39.91013243794441, 56.39579862356186, 56.8723576515913, 62.58674181997776, 53.269900158047676, 56.16565257310867, 51.94131664931774, 57.3258975148201, 62.40441620349884, 57.811420261859894, 57.545058354735374, 51.87655672430992, 49.865138456225395, 53.13573695719242, 63.19043442606926, 63.271020501852036, 66.44628211855888, 34.4466146081686, 1.7868790542706847, 0.2517359872581437, 0.19303019129438326, 0.9348068386316299, 7.817932292819023, 68.34983557462692, 48.17764900624752, 61.905635967850685, 53.642249777913094, 64.59857046604156, 7.21568550914526, 19.242748841643333, 24.997490644454956, 25.428436920046806, 32.52315782010555, 32.867358550429344, 44.79423835873604, 61.119598746299744, 16.243816763162613, 0.40700102923437953, 0.28511209005955607, 0.04531923674221616, 0.14088379335589707, 0.07732927944744006, 0.01922105893754633, 0.12290102822589688, 0.12222382589243352, 0.05217187957896385, 0.09413774430868216, 0.07070754843880422, 0.002014951583078073, 0.013829870931658661, 0.10381142405094579, 0.055596683305338956, 0.19990691682323813, 0.14166098524583504, 0.9286881575826555, 50.94324700534344, 77.32609391212463, 44.77520518004894, 38.47531422972679, 40.772746950387955, 70.99681913852692, 41.84924058616161, 5.220158463343978, 46.80341474711895, 74.19278964400291, 66.0742136836052, 62.009533792734146, 59.37190532684326, 55.82709453999996, 2.958615766838193, 0.7881267531774938, 0.23159123462392017, 0.2426285290857777, 1.3514326326549053, 1.011017330456525, 51.24808184802532, 66.63735866546631, 64.86869037151337, 62.30069316923618, 54.729413241147995, 54.5246422290802, 60.40369816124439, 60.46037591993809, 66.37533232569695, 66.52660220861435, 66.20144605636597, 58.69884364306927, 53.13719987869263, 46.4504174888134, 50.75114831328392, 60.91563709080219, 64.06354397535324, 59.45873066782951, 60.57425960898399, 58.758200258016586, 57.44102753698826, 57.23796263337135, 58.13232444226742, 53.217402175068855, 48.77384081482887, 48.37862402200699, 50.9453596919775, 53.21707919239998, 55.522901862859726, 50.89932516217232, 51.820220947265625, 55.841795951128006, 56.217740178108215, 56.41758285462856, 57.26689428091049, 57.296540290117264, 59.61004234850407, 60.57754263281822, 59.95597578585148, 58.37925039231777, 58.48233886063099, 57.105991914868355, 57.97058992087841, 55.7265405356884, 57.30181060731411, 56.233577728271484, 59.76046867668629, 60.880044400691986, 58.43058943748474, 60.532670840620995, 63.25603410601616, 59.716030061244965, 63.37458394467831, 59.86423350870609, 58.65958034992218, 59.7273800522089, 61.96434661746025, 61.13909550011158, 51.17220751941204, 56.69400282204151, 59.46717381477356, 54.04806800186634, 57.93271355330944, 58.55117976665497, 62.95747272670269, 60.120651349425316, 56.59730181097984, 57.44496412575245, 54.55802343785763, 54.298801347613335, 54.071558341383934, 52.91001006960869, 56.02265104651451, 57.471707090735435, 56.429651007056236, 54.97079908847809, 56.55718356370926, 54.620465487241745, 54.77191776037216, 56.807601526379585, 57.37445890903473, 56.31034500896931, 55.21283470094204, 53.108051642775536, 49.95246537029743, 50.905180647969246, 47.4700053781271, 48.95165227353573, 51.293542608618736, 51.52536056935787, 50.09337700903416, 45.28816245496273, 47.77213096618652, 52.33326181769371, 54.74345728754997, 56.99834369122982, 57.8128831833601, 58.67759518325329, 59.43328343331814, 62.160929068923, 38.790807500481606, 43.16514037549496, 57.59504087269306, 57.879174426198006, 66.06953993439674, 56.72206811606884, 58.23209568858147, 50.44810317456722, 58.41165505349636, 65.16933783888817, 60.87966062128544, 59.13087286055088, 54.66727137565613, 51.911742836236954, 54.722091034054756, 65.83561688661575, 65.68412661552429, 68.21780025959015, 38.107433170080185, 3.1365065462887287, 0.1505659261601977, 0.4434572230093181, 1.094538748729974, 9.5814642123878, 75.823525339365, 52.84874215722084, 67.79164552688599, 58.35237443447113, 68.87195035815239, 10.753200687468052, 22.01765824109316, 27.450139336287975, 26.60822421312332, 40.12001037597656, 31.06974720954895, 48.46847400069237, 69.55541968345642, 18.58468685299158, 0.46865943004377186, 0.2530253946315497, 0.03879174364556093, 0.08181657889508642, 0.11701333321980201, 0.031201079473248683, 0.0774254543648567, 0.40328126633539796, 0.1724547109915875, 0.20003149373224005, 0.23690128640737385, 0.07146327741793357, 0.12339192180661485, 0.1910956943174824, 0.21040434337919578, 0.3324987832456827, 0.36712151602841914, 1.1786317988298833, 63.52652259171009, 86.51916101574898, 59.13144662976265, 49.088475331664085, 54.19267304241657, 77.86646291613579, 45.93773379921913, 9.013804122805595, 50.91478273272514, 81.36770144104958, 68.83080616593361, 66.36087790131569, 66.1276464164257, 63.91981288790703, 3.1725780107080936, 2.1044213650748134, 0.5374289117753506, 0.6874766852706671, 2.7104380214586854, 1.3464913540519774, 56.065315157175064, 68.9668844640255, 69.23461049795151, 64.82791095972061, 58.5088462382555, 56.69807240366936, 63.84070873260498, 63.754901736974716, 70.55712193250656, 68.8467501103878, 67.42113500833511, 60.37209525704384, 52.90232688188553, 47.22737319767475, 52.589561864733696, 61.48299224674702, 67.98453077673912, 62.00454466044903, 63.85592311620712, 60.12762397527695, 61.483239233493805, 60.89092321693897, 61.54306702315807, 55.256110578775406, 52.3094978928566, 51.27613954246044, 53.885075747966766, 56.718496307730675, 57.58170738816261, 54.771321192383766, 55.52698664367199, 59.391424879431725, 58.195564448833466, 58.39845076203346, 62.98284396529198, 59.74997363984585, 62.19776429235935, 64.11288812756538, 64.95024919509888, 61.48702763020992, 62.6804143935442, 60.58372490108013, 62.53919117152691, 59.027476608753204, 63.00003424286842, 58.92710879445076, 66.43956407904625, 65.33332943916321, 61.449675634503365, 65.20316362380981, 67.27314814925194, 63.112781792879105, 67.73434460163116, 63.74664478003979, 62.762459591031075, 61.80575452744961, 68.19154366850853, 65.97058564424515, 54.556074142456055, 63.040673062205315, 60.49417890608311, 56.07069946825504, 58.40934477746487, 62.05093257129192, 68.7125489115715, 66.03736326098442, 61.65726609528065, 63.96860986948013, 61.355683878064156, 60.054724887013435, 57.76155173778534, 56.71094611287117, 59.72469359636307, 63.3801544457674, 60.60422100126743, 60.63011281192303, 61.44451171159744, 60.124071165919304, 59.27064836025238, 59.338653311133385, 63.1278707832098, 60.45537918806076, 59.73705053329468, 54.22466352581978, 52.236203625798225, 54.666249230504036, 52.82621696591377, 51.158611848950386, 53.637439236044884, 52.85313852131367, 53.14167603850365, 46.03381924331188, 51.301430985331535, 54.472433030605316, 57.35217310488224, 58.48875671625137, 62.54871726036072, 59.6695851534605, 62.70387053489685, 63.281610533595085, 44.42989870905876, 45.23692600429058, 58.906008526682854, 60.447441413998604, 67.48340606689453, 60.58810606598854, 60.349900647997856, 53.81045535206795, 60.20786426961422, 66.16493001580238, 63.3321326225996, 62.484367713332176, 59.183454439044, 54.58047263324261, 57.37733915448189, 69.33710619807243, 69.59808379411697, 71.21261715888977, 44.80879157781601, 4.953406127169728, 0.39522391743957996, 0.8208904950879514, 1.9321667519398034, 9.223967995494604, 82.58544489741325, 56.79846681654453, 74.38695162534714, 62.37238012254238, 78.70225846767426, 14.151425790041685, 27.430169507861137, 33.27200643718243, 40.764953568577766, 49.91810381412506, 45.50717130303383, 62.85833224654198, 79.82707411050797, 29.207966811954975, 1.0923191928304732, 0.3791640792042017, 0.18666388525161892, 0.2121579641243443, 0.16351766476873308, 0.11696802510414273, 0.18454082339303568], [0.04321289547078777, 0.07912984103313647, 0.07410147140035406, 0.059671845883713104, 0.07031795059447177, 0.1024387996585574, 0.1183958281762898, 0.054226786305662245, 0.14253045577788725, 0.3598601056728512, 0.7010416605044156, 25.913268104195595, 70.2270944416523, 41.033895537257195, 31.273573972284794, 40.08122965693474, 21.766626611351967, 26.622357554733753, 12.239522282034159, 31.07156541198492, 71.14702507853508, 49.01228182017803, 48.38187284767628, 54.43798027932644, 58.24415244162083, 9.650150276720524, 1.4273726264946163, 0.3487534500891343, 0.17966654588235542, 0.5193794646766037, 0.5995380040258169, 35.24053640663624, 60.490249916911125, 63.41233491897583, 62.448471039533615, 58.21916878223419, 54.895969703793526, 57.66257844865322, 59.91741545498371, 63.45706231892109, 62.879082933068275, 60.019394382834435, 61.87492221593857, 59.33588705956936, 50.476472452282906, 52.83707298338413, 57.24024251103401, 64.1202825307846, 57.868250012397766, 59.40679885447025, 55.271313562989235, 58.97468984127045, 56.73267334699631, 53.71195323765278, 52.612113654613495, 48.856311589479446, 43.952906504273415, 46.88473418354988, 49.46659304201603, 53.59298162162304, 50.42829103767872, 49.5575487613678, 52.32144445180893, 53.59296642243862, 53.49693417549133, 56.47734224796295, 55.573374554514885, 56.83913603425026, 56.52605563402176, 56.79182857275009, 57.10912674665451, 55.16522705554962, 57.15018734335899, 55.306146293878555, 55.6817751377821, 56.66741944849491, 54.698946475982666, 56.955136209726334, 61.27303071320057, 59.66977134346962, 59.46494333446026, 60.511635169386864, 60.61856523156166, 61.053752079606056, 58.137112185359, 54.520299062132835, 56.26409389078617, 60.78608684241772, 54.33508180081844, 47.24149703979492, 55.92273160815239, 57.13731363415718, 55.37406004965305, 51.94503664970398, 57.332763746380806, 59.4785276055336, 57.685768604278564, 55.1169316470623, 53.60697627067566, 52.14071474969387, 50.544207617640495, 52.41104744374752, 53.85103717446327, 52.695747166872025, 54.619789123535156, 55.93950770795345, 55.529118329286575, 55.20478293299675, 53.68706837296486, 52.68223509192467, 52.39394836127758, 52.60430507361889, 51.990497410297394, 53.86866442859173, 49.81892913579941, 47.90000170469284, 49.41115781664848, 43.53139132261276, 48.59645493328571, 50.244779884815216, 46.331723257899284, 47.30975657701492, 46.01459227502346, 47.29690566658974, 50.36237597465515, 52.46633067727089, 55.26741497218609, 55.470362082123756, 56.691441759467125, 60.29768384993076, 61.12647257745266, 54.01505917310715, 50.913676992058754, 57.72862650454044, 59.810812175273895, 60.237555876374245, 55.86375117301941, 55.437414050102234, 53.03088158369064, 55.337145030498505, 60.995113626122475, 58.908341601490974, 56.59792497754097, 49.94683027267456, 51.456170082092285, 54.34928923845291, 60.18248163163662, 64.30758967995644, 64.36927556991577, 23.4310133010149, 1.4288159552961588, 0.1729776430875063, 0.21438957250211388, 0.530522366752848, 21.098865643143654, 68.09779509902, 50.058517679572105, 60.927720442414284, 57.75605343282223, 54.095903635025024, 14.565272983163595, 20.42926177382469, 35.08028380572796, 32.848123982548714, 55.431497767567635, 38.06197240948677, 39.7104075551033, 53.27012434601784, 5.7716708444058895, 0.08743399113882333, 0.13126382284099236, 0.014738981426489772, 0.03225176020350773, 0.024018199474085122, 0.059250502672512084, 0.043537228848435916, 0.12968009454198182, 0.02178849470510613, 0.04167824168689549, 0.05368438025470823, 0.05638860311591998, 0.10627539886627346, 0.13943105412181467, 0.08598339671152644, 0.1479308566194959, 0.7005640142597258, 0.7680625829380006, 28.217002786695957, 81.81356951594353, 45.834576934576035, 34.076031893491745, 53.29474702477455, 24.747857339680195, 28.60312096774578, 11.85512350872159, 36.44296668469906, 80.26302471756935, 53.7540739774704, 57.40828089416027, 62.19524122774601, 64.51947391033173, 10.819119550287724, 1.4019918884150684, 0.4557629517512396, 0.14336213615024462, 1.4002350764349103, 0.8585505711380392, 35.883648097515106, 66.33637681603432, 67.39734068512917, 64.04877036809921, 61.856835186481476, 56.65453054010868, 60.74822947382927, 61.55382804572582, 63.72623227536678, 64.74160999059677, 60.17059586942196, 62.4990539252758, 61.04700744152069, 51.757098734378815, 50.52129104733467, 59.22808304429054, 61.93782024085522, 61.623417511582375, 62.29658178985119, 57.539332062006, 62.43346564471722, 58.368466570973396, 55.17271265387535, 52.85515621304512, 51.352891623973846, 45.42848892509937, 51.54525630176067, 50.33203460276127, 56.1684226244688, 53.28167952597141, 53.74903924763203, 54.25910487771034, 56.84372238814831, 55.97544617950916, 58.99433098733425, 56.93354956805706, 59.412973523139954, 59.26377832889557, 57.8348346054554, 58.872695714235306, 59.57724630832672, 57.08961479365826, 57.86630071699619, 59.06449802219868, 59.822363555431366, 56.35052405297756, 60.533673986792564, 63.00360985100269, 61.393533647060394, 60.44314384460449, 61.70752979815006, 61.25394433736801, 58.898849710822105, 59.988806024193764, 55.23810334503651, 57.54794999957085, 60.58296874165535, 56.61267578601837, 50.97582645714283, 61.60599544644356, 59.13126803934574, 56.561108753085136, 56.51615336537361, 60.33032029867172, 59.65751700103283, 58.726110979914665, 58.45402278006077, 58.12234237790108, 55.463252663612366, 52.170106172561646, 55.880375280976295, 57.516126707196236, 55.81273891031742, 57.66105093061924, 58.54327239096165, 57.61478841304779, 57.96465843915939, 56.20902344584465, 56.24754957854748, 56.174616292119026, 55.476217567920685, 55.772362276911736, 57.52315632998943, 51.777154058218, 50.04056744277477, 49.600756242871284, 48.199938610196114, 50.69669723510742, 50.96408888697624, 49.00021366775036, 48.891349509358406, 47.34085790812969, 49.71615605056286, 52.456747591495514, 53.885459527373314, 57.46737912297249, 58.17020080983639, 58.84651131927967, 60.149943977594376, 62.55548469722271, 57.594014927744865, 51.74145117402077, 59.295134246349335, 63.823784440755844, 61.0246342420578, 59.11431334912777, 55.76716795563698, 53.950143456459045, 58.198547288775444, 62.75994412600994, 62.24916033446789, 59.3082245439291, 53.80778029561043, 53.4698112308979, 58.27179975807667, 61.806799471378326, 67.469742000103, 68.98241803050041, 25.836915001273155, 1.431278104428202, 0.29227057937532663, 0.1715482963481918, 0.29873263731133193, 25.62787301838398, 75.49112677574158, 53.801278844475746, 68.91100466251373, 61.64617449045181, 61.798728704452515, 18.04775856435299, 24.288289099931717, 34.45742882788181, 34.36451241374016, 60.93071848154068, 34.19708579778671, 47.06887990236282, 64.6106006205082, 6.609192928299308, 0.08720414800336584, 0.20877659088000655, 0.06897552419104613, 0.014647464413428679, 0.04239368689013645, 0.027637622151814867, 0.0018812441703630611, 0.2553815353894606, 0.17787215154385194, 0.17773501749616116, 0.15258317260304466, 0.11185798211954534, 0.21788781916256994, 0.2264523963094689, 0.17753039253875613, 0.37483536929357797, 0.9309917245991528, 0.8408428088296205, 37.15648099780083, 93.96773412823677, 57.16713443398476, 40.63212789595127, 56.87385857105255, 36.72983229160309, 34.45149354636669, 18.402665220201015, 40.664201974868774, 86.13702312111855, 62.365540489554405, 62.69139960408211, 67.95413240790367, 72.2039307653904, 11.798264309763908, 2.5967915821820498, 1.2515006074681878, 0.3046448528766632, 2.2373938048258424, 1.1011554999276996, 38.12203198671341, 66.9232477247715, 70.08622080087662, 68.21558877825737, 64.10349503159523, 60.10424762964249, 62.513075172901154, 65.5196562409401, 66.78728342056274, 71.01139515638351, 61.73073895275593, 64.1118697822094, 59.97641108930111, 50.706534907221794, 51.699474826455116, 61.54579907655716, 67.70466819405556, 63.70903819799423, 62.637039721012115, 57.99840822815895, 65.12401387095451, 61.70592248439789, 59.59222510457039, 57.23469480872154, 55.46150475740433, 48.834101781249046, 54.32888813316822, 54.72351595759392, 61.67739361524582, 56.14554405212402, 58.80905672907829, 59.580498933792114, 59.714890122413635, 58.36739882826805, 62.797033935785294, 60.70544756948948, 65.22391811013222, 63.437816351652145, 61.13500311970711, 62.92940743267536, 62.934100180864334, 60.38850657641888, 61.03974603116512, 62.276290878653526, 65.74632927775383, 60.86672991514206, 66.72831818461418, 70.32154977321625, 65.35624220967293, 63.64929020404816, 65.93770980834961, 67.63843774795532, 64.54553291201591, 65.9728579223156, 60.96293695271015, 60.521575435996056, 64.34136986732483, 60.18696539103985, 52.93357640504837, 63.76301050186157, 63.237928077578545, 61.751729026436806, 58.868922516703606, 64.05079945921898, 63.88946771621704, 62.87188611924648, 62.111603915691376, 62.89267860352993, 59.810751378536224, 57.8956313431263, 62.290730103850365, 64.078598767519, 58.80889713764191, 62.65378162264824, 63.98861199617386, 62.89988301694393, 62.716238871216774, 62.271890714764595, 63.54455642402172, 59.117345586419106, 58.05825121700764, 58.97155120968819, 60.328298807144165, 55.34032925963402, 54.34541344642639, 53.583356738090515, 50.67484840750694, 53.466664999723434, 55.23703560233116, 49.77294020354748, 53.68992201983929, 51.37133203446865, 52.78976172208786, 54.18756991624832, 56.48308753967285, 59.35390189290047, 61.29848934710026, 61.27675451338291, 64.71853762865067, 65.86308941245079, 58.576851189136505, 53.586024194955826, 60.145638808608055, 64.03535708785057, 62.28674791753292, 59.56065259873867, 56.964244320988655, 54.10316504538059, 57.841039672493935, 65.91123282909393, 65.40104940533638, 62.57637217640877, 56.66779562830925, 55.924323722720146, 59.64457869529724, 65.02485439181328, 69.81636688113213, 72.99706220626831, 30.39660383015871, 3.972615343518555, 0.4618398053571582, 1.0319287958554924, 2.3436465533450246, 26.74668688327074, 83.08468490839005, 58.61096575856209, 72.77825474739075, 66.99653059244156, 66.70067846775055, 22.973873130977154, 31.622381955385208, 42.14647203683853, 47.49142102897167, 76.046824157238, 50.70529617369175, 53.41282568871975, 76.79257214069366, 11.400722991675138, 0.3765464056050405, 0.3686546446988359, 0.22432721190853044, 0.07536148230428807, 0.11158093097037636, 0.20431297336472198, 0.14020009723026305], [0.03621897369157523, 0.060539999103639275, 0.03904853787389584, 0.17489392776042223, 0.03093331259151455, 0.10888461940339766, 0.04553143531666137, 0.11933698275242932, 0.1021312091324944, 0.3023918706458062, 0.45456747058779, 10.868890229612589, 56.180198192596436, 45.06421007215977, 36.22798942029476, 39.10690873861313, 51.400525867938995, 74.8782728612423, 11.854836624115705, 28.768085315823555, 59.411328211426735, 66.97497814893723, 45.689956694841385, 39.648299887776375, 63.68198744952679, 24.541822895407677, 0.5064393777865916, 0.06184896206832491, 0.28127949102781713, 0.5028548638802022, 0.15576550184050575, 23.250306397676468, 63.66975590586662, 61.470521315932274, 62.59683407843113, 58.506972938776016, 56.38598755002022, 58.58853556215763, 60.510917007923126, 63.596739023923874, 65.06539821624756, 64.25426334142685, 63.97691622376442, 63.10173198580742, 51.572056263685226, 49.353028535842896, 51.95189528167248, 59.49481353163719, 59.12409782409668, 60.48869200050831, 58.96671786904335, 55.74302785098553, 58.4062859416008, 55.0658243894577, 53.3747099339962, 50.49368932843208, 46.21543429791927, 46.46183207631111, 50.30108526349068, 51.52870059013367, 53.31076696515083, 50.47839514911175, 51.18921160697937, 51.16979464888573, 54.11305211484432, 54.99688848853111, 55.92678219079971, 54.83063600957394, 56.09738923609257, 55.86616024374962, 55.5874527990818, 56.29831105470657, 56.124356389045715, 55.33408999443054, 56.01152904331684, 56.992070227861404, 53.7128271907568, 57.66725219786167, 57.1006266027689, 57.48328126966953, 59.09319028258324, 59.07185062766075, 58.815618976950645, 59.42196764051914, 58.81313771009445, 58.88232819736004, 53.48926238715649, 61.31495386362076, 54.237575232982635, 47.578915134072304, 57.839272767305374, 56.16656452417374, 56.58547684550285, 52.506072744727135, 57.00940489768982, 58.7667004019022, 59.0061217546463, 56.181645914912224, 52.28167198598385, 50.69696322083473, 50.921987146139145, 55.98299257457256, 54.720536917448044, 53.98154877126217, 56.13906919956207, 55.46191893517971, 56.00856140255928, 53.976639434695244, 53.73760566115379, 53.56640964746475, 54.3046036362648, 54.14545677602291, 54.92036059498787, 53.03918793797493, 48.356068432331085, 48.67005318403244, 46.138097047805786, 47.57477715611458, 48.66918683052063, 50.347381979227066, 48.80805417895317, 44.018927961587906, 46.284902170300484, 48.82228821516037, 50.24941563606262, 52.771955877542496, 54.94401432573795, 57.54351943731308, 57.47415415942669, 56.57099962234497, 55.164296105504036, 61.23550392687321, 57.87966080009937, 50.475176721811295, 56.57723128795624, 61.96448341012001, 55.1839866489172, 54.191012531518936, 51.27260573208332, 55.33054858446121, 62.46441878378391, 57.173521891236305, 56.43020957708359, 52.044522911310196, 50.39068825542927, 55.18981173634529, 63.52012373507023, 63.578689992427826, 62.22695432603359, 20.25974716991186, 0.5990958621259779, 0.37443894369062036, 0.22313845460303128, 0.2074363612337038, 43.48873481154442, 63.66314806044102, 54.123113974928856, 63.478873148560524, 50.84330856800079, 61.899632290005684, 10.732640940696001, 21.799118667840958, 31.61536943167448, 33.05824510753155, 61.02977156639099, 37.70170234143734, 52.236845791339874, 45.78659310936928, 2.378492346033454, 0.07781304098898545, 0.05448030395200476, 0.039561291414429434, 0.06225936973351054, 0.04988126675016247, 0.03504873668134678, 0.04968221161107067, 0.04598024541337509, 0.05129516568558756, 0.019460674302536063, 0.0844600643904414, 0.016927414435485844, 0.20863202051259577, 0.06514685112051666, 0.11434623258537613, 0.06362576750689186, 0.3359184513101354, 0.3427761036437005, 11.771640088409185, 68.96696045994759, 53.73266972601414, 39.60268713533878, 56.61786250770092, 54.9972228705883, 79.75145816802979, 15.169144179672003, 26.23743060976267, 69.89139765501022, 68.32740917801857, 50.49420990049839, 45.06078265607357, 69.29169863462448, 26.995869912207127, 0.5584829882718623, 0.24543902749428526, 0.5502370151225477, 1.0471556475386024, 0.172478148015216, 25.574178099632263, 70.44091656804085, 63.251212164759636, 66.16616874933243, 59.71507251262665, 59.55056793987751, 59.72464419901371, 60.8578459918499, 63.64441506564617, 66.02728620171547, 68.05617213249207, 67.38621488213539, 63.165013790130615, 53.54230374097824, 49.16683852672577, 51.828941479325294, 59.55883629620075, 60.61035767197609, 61.07990987598896, 62.12845601141453, 58.150707855820656, 59.77194406092167, 55.963032245635986, 56.07933260500431, 52.7581512182951, 48.902110531926155, 49.70797888934612, 51.62873402237892, 51.1148875951767, 56.54346629977226, 54.073256850242615, 52.93880112469196, 54.634486734867096, 57.29525975883007, 57.88486272096634, 58.41936103999615, 57.6287716627121, 58.398769944906235, 56.85970813035965, 60.72005778551102, 59.82712469995022, 59.738239869475365, 59.94812160730362, 60.00344663858414, 59.70541723072529, 56.76724009215832, 58.233038038015366, 58.91529902815819, 61.52972973883152, 60.144411474466324, 60.290798619389534, 61.23682625591755, 57.87423089146614, 59.526948407292366, 59.414938017725945, 55.19560642540455, 60.097445994615555, 56.02551229298115, 51.108591333031654, 59.02142733335495, 58.59662912786007, 56.95678912103176, 55.83213306963444, 57.009066715836525, 60.90447708964348, 59.80776473879814, 58.992541283369064, 55.16653038561344, 54.02678534388542, 54.26939092576504, 57.64752745628357, 56.80716075003147, 55.71895234286785, 60.21090030670166, 58.039522022008896, 55.51798112690449, 56.78150832653046, 55.744654163718224, 56.79362207651138, 55.613002628088, 57.63453595340252, 55.005989000201225, 55.4078858345747, 51.139411479234695, 48.847914040088654, 48.6604169011116, 49.174715504050255, 51.27706669270992, 52.96959847211838, 49.028765335679054, 47.03354939818382, 48.37334230542183, 50.58607757091522, 52.313252091407776, 55.3843042999506, 55.51230423152447, 59.20544005930424, 59.366779401898384, 59.42530766129494, 58.631192073225975, 63.78401577472687, 57.16662146151066, 50.15366077423096, 59.39413033425808, 63.01980838179588, 58.25489826500416, 57.05189801752567, 52.528385147452354, 57.57765680551529, 65.65279349684715, 60.79383462667465, 61.346043795347214, 56.987328082323074, 54.244323670864105, 60.23804984986782, 66.39063030481339, 65.40431722998619, 66.18011400103569, 23.65993771702051, 0.567521812627092, 0.4007661872310564, 0.3003512613940984, 0.7623889530077577, 48.166823387145996, 69.48538184165955, 59.73781429231167, 70.52682995796204, 55.88316053152084, 69.76536601781845, 13.010906539857388, 27.5450012460351, 28.521353155374527, 37.174693420529366, 69.38256695866585, 34.694353714585304, 61.50559723377228, 48.75219717621803, 2.648645262233913, 0.06994785639108159, 0.21907709597144276, 0.04862376059463713, 0.09427102660993114, 0.05078158465039451, 0.03972735066781752, 0.06327033814159222, 0.11895083589479327, 0.17143010190920904, 0.1022526244923938, 0.2924374141730368, 0.09458179352805018, 0.33016348199453205, 0.20409599906997755, 0.28774882201105356, 0.17889729497255757, 0.774656772846356, 0.7495342427864671, 19.59801457822323, 83.24257403612137, 65.13226702809334, 51.18697352707386, 56.26074627041817, 72.78717666864395, 87.08589300513268, 21.285272240638733, 35.986326187849045, 77.23706468939781, 75.2880808711052, 60.0784470140934, 50.829845890402794, 78.3036370575428, 29.644973762333393, 0.9149995702318847, 0.9774468443356454, 1.3419415731914341, 1.8401949433609843, 0.41774029203224927, 28.214867301285267, 72.37350806593895, 67.7994655072689, 68.26591327786446, 63.782898634672165, 61.33379325270653, 64.58107620477676, 65.22645637392998, 68.41688677668571, 70.2816291153431, 70.40332898497581, 69.28456261754036, 65.56114241480827, 53.576881885528564, 50.52229419350624, 56.48578159511089, 62.44320452213287, 64.5953406393528, 67.15213984251022, 65.45619204640388, 61.164037361741066, 62.66939498484135, 60.63052698969841, 58.75059686601162, 56.70307293534279, 50.87008573114872, 52.16125264763832, 55.33908672630787, 55.0027097761631, 60.013193115592, 55.82115925848484, 57.21652418375015, 58.42584729194641, 61.61201052367687, 58.13018895685673, 64.56950202584267, 62.553850784897804, 62.91020326316357, 61.49886779487133, 64.56015452742577, 63.66099737584591, 62.333219423890114, 63.28984469175339, 64.38026458024979, 65.23164689540863, 59.92859445512295, 62.73834228515625, 62.62477397918701, 66.73228517174721, 63.7692953646183, 65.56696370244026, 65.75775146484375, 61.606375426054, 62.38207720220089, 64.57659244537354, 58.179795295000076, 65.93675225973129, 59.0075770765543, 56.640144512057304, 64.0659910440445, 61.473918333649635, 61.49299331009388, 58.62587235867977, 62.071747854352, 64.6636837720871, 66.31524994969368, 66.61955282092094, 57.536261826753616, 58.347826078534126, 57.810443714261055, 61.90257713198662, 59.33681420981884, 59.23390433192253, 63.59443634748459, 62.53598794341087, 62.095747366547585, 60.63147693872452, 58.51918928325176, 61.96697607636452, 61.57235965132713, 63.49697917699814, 58.843300491571426, 59.204425513744354, 53.860627859830856, 53.611748814582825, 51.52946054935455, 53.542949706315994, 54.77371886372566, 56.71289920806885, 52.83763535320759, 50.789689645171165, 52.19200439751148, 54.067116379737854, 55.69473244249821, 56.92040607333183, 58.3899088203907, 61.950819343328476, 61.64825677871704, 63.06266248226166, 60.14163762331009, 64.75934743881226, 59.63118061423302, 52.50100001692772, 61.111265793442726, 66.5878701210022, 58.54457192122936, 59.30186368525028, 56.484770849347115, 59.26833428442478, 68.84513139724731, 61.17471098899841, 63.0539533495903, 58.32327179610729, 56.6060983389616, 61.9990311563015, 68.10442954301834, 68.67677763104439, 68.71295168995857, 29.406584054231644, 1.3308196887373924, 0.664635042194277, 0.7246490812394768, 0.839225105009973, 50.548957362771034, 76.98541939258575, 63.12611527740955, 76.84855833649635, 61.776340305805206, 76.29150062799454, 16.87814522534609, 33.62177386879921, 36.85715205967426, 49.03228014707565, 79.9978369474411, 50.85290305316448, 69.19715210795403, 68.83707582950592, 4.892752356827259, 0.14780625002458692, 0.5648062645923346, 0.15377145493403077, 0.3806191636249423, 0.17972481931792572, 0.0809288515301887, 0.19680993456859142], [0.03344495555211324, 0.052711458047269844, 0.025829648366197944, 0.0059398053690529196, 0.0801602091814857, 0.09730951278470457, 0.04775879118824378, 0.13740279420744628, 0.053067254775669426, 0.17911461065523326, 0.06347445843857713, 2.864219807088375, 44.3948569893837, 55.83071194589138, 29.89539362490177, 39.27788436412811, 26.853527650237083, 53.652121648192406, 19.117397367954254, 12.796715833246708, 65.55118694901466, 60.069988667964935, 60.51822021603584, 50.19892014563084, 62.11816996335983, 41.29481993615627, 0.029075128804834094, 0.07921852768049575, 0.6186686712317169, 0.3596623381599784, 0.09184356546029449, 16.057288572192192, 68.40256914496422, 61.72920003533363, 64.04441580176353, 57.50069573521614, 57.38437257707119, 55.63724532723427, 57.16174252331257, 59.79019448161125, 62.06587336957455, 56.83020271360874, 61.638346910476685, 60.48273392021656, 60.702502727508545, 49.5610673725605, 56.40169970691204, 56.84316761791706, 57.54370182752609, 53.5528177767992, 56.46757297217846, 59.55742657184601, 58.52997310459614, 54.978109896183014, 53.75591307878494, 54.38618145883083, 49.184541776776314, 49.17457491159439, 47.53385715186596, 51.12798169255257, 49.5689557492733, 51.1654818803072, 47.77773566544056, 53.674270659685135, 54.44490730762482, 56.2704661488533, 56.233672723174095, 55.22527903318405, 54.15974780917168, 56.83673456311226, 59.19441685080528, 56.862318590283394, 56.17431230843067, 56.41018845140934, 56.91569432616234, 58.32112871110439, 53.71587462723255, 55.04448473453522, 56.7376396805048, 57.50448413193226, 56.45204320549965, 59.953099340200424, 58.24562296271324, 58.94018009305, 56.589215844869614, 54.878414645791054, 57.6979773491621, 60.71902044117451, 54.55402225255966, 44.81501944363117, 54.05511662364006, 55.56889459490776, 55.496086701750755, 52.62606270611286, 57.13001422584057, 56.73681512475014, 58.565858379006386, 57.03776277601719, 53.302646800875664, 51.67511813342571, 49.93915468454361, 54.385812878608704, 56.215331107378006, 57.043432071805, 54.646919667720795, 53.30806151032448, 53.47587950527668, 53.11756253242493, 55.89671440422535, 51.07376620173454, 54.72323477268219, 54.08271834254265, 54.257957339286804, 53.783047422766685, 49.45319876074791, 48.27605612576008, 47.68445827066898, 51.00938245654106, 48.22775311768055, 47.106741070747375, 45.43307147920132, 41.761328503489494, 45.08374102413654, 50.00459477305412, 51.16922847926617, 55.46587072312832, 54.423981830477715, 57.799587696790695, 59.89672936499119, 61.70184910297394, 61.937998831272125, 60.06128333508968, 45.90270347893238, 57.27499544620514, 66.25566154718399, 59.91780683398247, 60.40845550596714, 48.0742147564888, 53.27456250786781, 53.97835314273834, 60.158767104148865, 61.70166291296482, 58.93734164535999, 54.837228655815125, 55.80483913421631, 58.258599266409874, 60.596951991319656, 64.60268184542656, 57.96276994049549, 13.61536480486393, 0.7375124003738165, 0.21707081847125664, 0.3052905510412529, 2.798753594979644, 54.71956416964531, 56.53208211064339, 57.55993075668812, 51.59045867621899, 58.40403266251087, 58.60919125378132, 10.918863248080015, 32.1130496263504, 26.84469312429428, 40.41284926235676, 47.77469962835312, 29.83516115695238, 56.57999373972416, 25.543025471270084, 0.6944930681493133, 0.06651439922279678, 0.07778809740557335, 0.03695087230880745, 0.11250517942244187, 0.11089116407674737, 0.016303988122672308, 0.1196636093663983, 0.041097091816482134, 0.16343990253517404, 0.010095633369928692, 0.07810277544194832, 0.2428550473996438, 0.08390653354581445, 0.033355263294652104, 0.15425659687025473, 0.060200626103323884, 0.4949438665062189, 0.1009189554315526, 4.284595465287566, 54.72285859286785, 69.56240370869637, 33.151807487010956, 48.024319633841515, 39.62239287793636, 57.97562465071678, 24.476236514747143, 11.306591592729092, 70.69696962833405, 68.41185584664345, 63.08683678507805, 51.22270680963993, 68.91168102622032, 46.634958386421204, 0.06477213333710097, 0.2976655773818493, 0.8679929457139224, 0.8813941734842956, 0.0664914668595884, 16.872973702847958, 71.83202192187309, 65.78050464391708, 67.74100944399834, 60.021237283945084, 60.35425141453743, 58.896482437849045, 61.347681507468224, 62.016289830207825, 64.80173796415329, 58.41225542128086, 62.487608939409256, 61.99683107435703, 63.01550321280956, 48.58625628054142, 57.891641557216644, 58.881192058324814, 59.771940261125565, 55.51462210714817, 60.28909631073475, 60.46310797333717, 60.201214626431465, 58.48527230322361, 57.250201776623726, 55.80493412911892, 50.64756967127323, 49.71526309847832, 49.87066335976124, 51.64145953953266, 53.41961592435837, 52.204080149531364, 51.04380860924721, 55.64167208969593, 56.47662788629532, 59.20470289885998, 57.49231718480587, 57.364397048950195, 57.5846142321825, 59.97388042509556, 59.89573001861572, 60.264781415462494, 59.95589219033718, 57.12939105927944, 58.267285600304604, 60.16691006720066, 55.47412008047104, 57.71843925118446, 58.779387921094894, 60.36869063973427, 59.71604146063328, 60.32958313822746, 60.78240104019642, 60.29185116291046, 59.53663028776646, 56.454003900289536, 58.50056268274784, 59.94230791926384, 56.83858886361122, 46.36186704039574, 56.44082620739937, 58.841636180877686, 58.44490326941013, 56.51244476437569, 58.30482758581638, 60.5959602445364, 59.22570437192917, 62.4739258736372, 57.02298156917095, 56.314323395490646, 54.30381327867508, 57.323982417583466, 56.9953266531229, 58.23353961110115, 57.02812649309635, 55.037683099508286, 56.71875849366188, 57.0884520560503, 55.91385908424854, 55.97474321722984, 57.29769542813301, 55.959034860134125, 55.25343172252178, 54.85159948468208, 49.99561965465546, 50.99017068743706, 48.34188759326935, 51.37019969522953, 50.718694254755974, 49.2926611751318, 48.07390697300434, 46.97343662381172, 47.425676956772804, 50.11273697018623, 53.070080280303955, 58.47345493733883, 55.34838102757931, 59.39981482923031, 60.45170858502388, 63.485511392354965, 61.28039471805096, 62.229975163936615, 45.77181190252304, 57.42266312241554, 65.92404574155807, 63.17381031811237, 63.91250967979431, 53.530414178967476, 54.47395674884319, 56.392827183008194, 61.178066208958626, 64.60131391882896, 61.27066344022751, 59.5575899630785, 57.9554895311594, 60.62672719359398, 65.186687707901, 66.59401819109917, 60.79126596450806, 16.21154699474573, 1.5267162770032883, 0.4996884462889284, 0.5780787148978561, 5.892813093960285, 64.63732078671455, 63.07188838720322, 63.722383081912994, 60.10163336992264, 63.569916263222694, 64.4298443198204, 13.857336770743132, 40.15901908278465, 27.631750591099262, 46.81695722043514, 48.83910991251469, 29.928854629397392, 66.41624093055725, 30.07864449173212, 1.1905362037941813, 0.09675883920863271, 0.04516355642408598, 0.0411299652478192, 0.11055301933083683, 0.07658557326067239, 0.01885275331005687, 0.08367628222913481, 0.17314988072030246, 0.1938626286573708, 0.10535140274441801, 0.3198986890492961, 0.2723634475842118, 0.14357446460053325, 0.12458799668820575, 0.2138437525718473, 0.257381385890767, 0.8435631659813225, 0.2657891472335905, 6.57279753126204, 71.21792167425156, 77.81610801815987, 45.95279239118099, 50.66483214497566, 44.506084620952606, 65.91422706842422, 27.860855497419834, 17.27713141590357, 79.67053771018982, 69.90687802433968, 72.0890325307846, 58.66768531501293, 76.62578389048576, 50.537622570991516, 0.22126732219476253, 0.3988476761151105, 1.3585541630163789, 1.8726506642997265, 0.22907492355443537, 18.95129308104515, 74.49551180005074, 70.8400547504425, 71.52600154280663, 62.43750102818012, 63.49413312971592, 61.42865516245365, 63.110536113381386, 64.01837199926376, 68.21651592850685, 61.00839011371136, 65.42454734444618, 63.60894776880741, 65.21139398217201, 47.868835777044296, 59.276370853185654, 61.60562686622143, 61.02913700044155, 54.60564628243446, 62.44969457387924, 62.82362870872021, 63.54437783360481, 59.70893204212189, 61.333474069833755, 59.757618829607964, 54.56783451139927, 54.77704368531704, 53.673328310251236, 55.630956664681435, 55.188888385891914, 54.984311163425446, 54.14508439600468, 59.153823629021645, 59.37611550092697, 62.13914103806019, 63.04029308259487, 63.3519371598959, 61.441289484500885, 61.8122673779726, 63.69457237422466, 62.747701182961464, 61.4651408046484, 63.22434760630131, 63.113313764333725, 64.35373440384865, 60.17367750406265, 62.185316160321236, 62.974583208560944, 63.36662717163563, 62.02989690005779, 65.77642366290092, 63.859038949012756, 63.753298223018646, 61.79289981722832, 60.96768669784069, 63.05141128599644, 66.11883088946342, 60.47155871987343, 46.2248919904232, 58.18342790007591, 63.34657944738865, 61.35311521589756, 60.63284866511822, 61.734489351511, 63.1922697275877, 64.2611637711525, 67.37259641289711, 61.616327092051506, 60.158725306391716, 56.69683746993542, 61.545700281858444, 60.879356637597084, 62.05173812806606, 60.598331317305565, 57.476027458906174, 60.75515270233154, 61.16051875054836, 61.9889122992754, 57.88180388510227, 60.71076728403568, 62.37894617021084, 59.9973251670599, 59.33020256459713, 54.48301926255226, 53.5505834966898, 52.46869795024395, 57.86628931760788, 51.51931889355183, 52.87441737949848, 50.81485569477081, 48.08518476784229, 49.63754966855049, 53.50802958011627, 54.948482885956764, 60.86691610515118, 56.46442674100399, 62.35439568758011, 61.891770511865616, 63.599535673856735, 62.8509796410799, 63.88868495821953, 48.52539114654064, 59.18850816786289, 66.43754258751869, 65.65595492720604, 64.51399460434914, 53.67196798324585, 57.22090154886246, 57.864526212215424, 64.03857171535492, 66.21662244200706, 64.88863170146942, 61.76104612648487, 60.71969300508499, 62.32575662434101, 68.08894917368889, 69.58246663212776, 64.03072893619537, 23.937113843858242, 2.191298478282988, 1.3166241254657507, 1.0746449162252247, 5.139555763453245, 68.86435076594353, 66.10727950930595, 68.4209069609642, 64.34787511825562, 67.88651123642921, 70.84173426032066, 18.33022590726614, 45.672489032149315, 34.568135887384415, 60.81457011401653, 58.49800921976566, 40.374858900904655, 71.92244186997414, 45.30299685895443, 1.9453958608210087, 0.19120226672384888, 0.22755187324946746, 0.15415070723975077, 0.20902513613691553, 0.2829630085034296, 0.1335671523702331, 0.24854096729541197], [0.07425234260153957, 0.06589628668734804, 0.025188486579281744, 0.07618116214871407, 0.026346624727011658, 0.07949885912239552, 0.022266220730671193, 0.1561479750671424, 0.110517262655776, 0.07450269869877957, 0.12693512777332217, 0.8859292895067483, 30.701235383749008, 60.31388998031616, 46.46764576435089, 37.79085695743561, 28.494598791003227, 57.320953980088234, 23.137216866016388, 9.807287994772196, 53.802186995744705, 66.71672120690346, 65.29632702469826, 62.457457557320595, 51.677743792533875, 57.612888514995575, 1.0950177605263889, 0.0603189615503652, 0.9325608029030263, 0.8128411613870412, 0.2187296372721903, 7.153795380145311, 61.98803074657917, 59.21159952878952, 64.90928739309311, 60.272046625614166, 59.34112697839737, 60.44092856347561, 62.02204652130604, 59.231335669755936, 61.16427294909954, 63.373322412371635, 64.01586413383484, 59.294172897934914, 62.597328051924706, 48.358435705304146, 50.94238445162773, 61.620871648192406, 61.36360265314579, 58.35677079856396, 57.469571605324745, 54.92240868508816, 58.92211206257343, 56.77274599671364, 56.609404161572456, 57.59066730737686, 56.06656149029732, 48.66249158978462, 49.080089181661606, 49.789264127612114, 52.394750118255615, 49.75141055881977, 47.60600388050079, 50.51515057682991, 54.978341683745384, 56.672233790159225, 56.85034543275833, 54.03348058462143, 55.50175219774246, 56.512425765395164, 57.84730173647404, 57.41023398935795, 55.79167664051056, 54.9792992323637, 56.545920968055725, 55.05206912755966, 55.191992819309235, 56.15520313382149, 58.609609231352806, 55.20889051258564, 58.230062797665596, 58.539043217897415, 57.65595160424709, 58.656814098358154, 54.43548001348972, 55.79012252390385, 55.96792258322239, 56.33181765675545, 57.479922249913216, 45.39552949368954, 52.98566021025181, 55.73665179312229, 55.7581852376461, 50.289180502295494, 54.638225734233856, 56.4953076839447, 56.12877555191517, 54.418426528573036, 53.830715864896774, 50.629171058535576, 49.402080103755, 53.19733165204525, 54.41373758018017, 53.39408129453659, 53.884019404649734, 55.15957295894623, 52.725142389535904, 54.20610912144184, 53.352101147174835, 52.42413394153118, 51.06553964316845, 54.06855270266533, 52.60171741247177, 51.19184486567974, 49.87738139927387, 49.626275673508644, 48.168658688664436, 49.87137012183666, 48.90847519040108, 47.66192927956581, 45.23594565689564, 45.31747028231621, 46.203301548957825, 50.919190496206284, 52.932713851332664, 54.37383972108364, 59.46237847208977, 58.26971746981144, 61.24787226319313, 52.45371155440807, 44.12788711488247, 48.61331842839718, 52.33851693570614, 35.83357058465481, 52.515583634376526, 61.75786569714546, 62.38693334162235, 52.1217043697834, 50.13651229441166, 60.485610365867615, 56.84107393026352, 61.680501848459244, 59.89823028445244, 59.47296850383282, 56.664524003863335, 63.94797697663307, 62.6688402146101, 62.35820308327675, 50.03015600144863, 3.969850754365325, 0.9041729418095201, 0.766411452786997, 0.2912619709968567, 24.431868195533752, 51.70755319297314, 51.72913983464241, 58.601538464426994, 52.389768585562706, 58.72223898768425, 55.30181832611561, 15.158217865973711, 24.975976198911667, 20.32355524599552, 47.005278915166855, 39.160774648189545, 35.75779505074024, 60.7232154160738, 15.997048504650593, 0.3613172977929935, 0.12229035201016814, 0.14396250393474475, 0.08410665366682224, 0.04610167190548964, 0.09301370228058659, 0.016138745231728535, 0.05825967244163621, 0.0715043478703592, 0.07574546951218508, 0.04129566084884573, 0.04846283329243306, 0.07327124563744292, 0.10145643362193368, 0.04442065917828586, 0.11956516347709112, 0.11274020274868235, 0.11436414803029038, 0.152699600730557, 1.0957360407337546, 37.53982722759247, 75.08053600788116, 47.973117381334305, 42.15076960623264, 45.24745523929596, 63.83323073387146, 29.150356203317642, 11.66810704395175, 59.762079790234566, 74.82266664505005, 73.32929357886314, 67.39959016442299, 56.39105647802353, 60.84936484694481, 1.4404302695766091, 0.3918382397387177, 1.9770315382629633, 0.9730085043702275, 0.30397971044294536, 7.512290943413973, 65.99511712789536, 61.41034014523029, 68.86041417717934, 62.20083452761173, 62.999487072229385, 59.21070657670498, 63.392659574747086, 62.301175743341446, 64.80572015047073, 64.71837803721428, 66.2297697365284, 61.93522498011589, 63.92667531967163, 48.84352907538414, 53.20048548281193, 61.52641251683235, 64.1544958949089, 60.71891024708748, 59.66584235429764, 57.91515849530697, 60.84853649139404, 60.049021393060684, 58.68183195590973, 57.98227809369564, 58.253720328211784, 50.898173823952675, 50.995554998517036, 52.70100608468056, 54.53271299600601, 52.03867122530937, 48.20028059184551, 52.66447104513645, 56.4882742613554, 59.805735647678375, 57.78271660208702, 56.98171578347683, 57.717462703585625, 60.359726920723915, 61.97588659822941, 58.91146883368492, 56.68691620230675, 57.20363907516003, 55.28975397348404, 55.87237671017647, 56.118440106511116, 59.27784137427807, 58.93891856074333, 61.856998577713966, 59.34100538492203, 60.653409361839294, 61.18339352309704, 61.102313473820686, 54.3507369607687, 55.804732739925385, 57.76363402605057, 58.384672701358795, 55.91034047305584, 45.636577159166336, 53.52619640529156, 60.034745559096336, 57.37924665212631, 55.14318063855171, 55.44981278479099, 63.1163763999939, 60.079233571887016, 59.836494997143745, 57.88249924778938, 56.19734667241573, 54.708240777254105, 57.641204595565796, 56.52858629822731, 59.07651677727699, 55.62193214893341, 55.43471239507198, 55.32500848174095, 58.31477165222168, 56.862979754805565, 54.86139535903931, 53.99735972285271, 56.58104248344898, 55.34504860639572, 52.97564394772053, 52.77788355946541, 51.677443608641624, 49.76700872182846, 51.977790892124176, 51.48788698017597, 49.89592060446739, 48.21724288165569, 47.84696415066719, 47.447810769081116, 51.231286749243736, 55.0111149251461, 58.04160051047802, 61.014956161379814, 61.586570888757706, 62.90909372270107, 56.117144376039505, 47.917883545160294, 49.78372402489185, 55.524246990680695, 33.139526546001434, 50.60041420161724, 65.4959987103939, 64.06092211604118, 58.26489172875881, 51.41714617609978, 62.29394473135471, 59.160777255892754, 63.50774019956589, 61.82283081114292, 60.86232215166092, 61.40450745820999, 65.79932123422623, 66.27653762698174, 62.92284898459911, 53.919281512498856, 4.383009234443307, 1.350144858006388, 1.700694216415286, 0.2533906797179952, 31.459030620753765, 58.68340127170086, 57.934362664818764, 64.38890531659126, 58.97927239537239, 64.26997169852257, 62.26162746548653, 15.17114857211709, 35.012134462594986, 20.82786988466978, 56.88140116631985, 39.68750238418579, 38.51962365210056, 73.55517625808716, 17.902209274470806, 0.48308404977433383, 0.20683378184912726, 0.08437648371909745, 0.2187618613243103, 0.016479583973705303, 0.04341008039773442, 0.07088343001669273, 0.07938391529023647, 0.22989909339230508, 0.1504002491128631, 0.20179921528324485, 0.179218600387685, 0.13959469768451527, 0.1539417778258212, 0.12014242820441723, 0.2085074584465474, 0.19946701620938256, 0.392939854064025, 0.3092282678699121, 1.3756723632104695, 54.9636060744524, 84.79303523898125, 69.22110602259636, 47.236295118927956, 51.214537248015404, 72.32773572206497, 33.88307824730873, 14.967136569321156, 67.67673209309578, 77.74635896086693, 77.32562273740768, 70.22689685225487, 62.95719914138317, 69.95087206363678, 1.6942127142101526, 0.7723345037084073, 3.120366674847901, 2.7044155821204185, 0.4308655596105382, 9.778517838567495, 70.25147393345833, 64.8586817085743, 72.49065577983856, 65.01402497291565, 65.82342714071274, 63.75031918287277, 66.92495003342628, 64.03361678123474, 68.5934329032898, 66.88976392149925, 67.80798465013504, 62.54159264266491, 67.01545357704163, 51.00052133202553, 52.16142363846302, 64.59699735045433, 66.12434819340706, 62.168578058481216, 61.87258914113045, 58.99819917976856, 64.18050929903984, 63.10354448854923, 62.44087144732475, 60.72086714208126, 60.4142501950264, 54.28208224475384, 54.240645468235016, 54.503705352544785, 56.26786328852177, 54.91228602826595, 52.04895347356796, 55.37035144865513, 61.95721060037613, 61.16301141679287, 62.065193206071854, 57.63200528919697, 61.847263500094414, 62.415842190384865, 65.84280610084534, 60.789179876446724, 59.51997198164463, 58.02678510546684, 58.097841292619705, 57.730017229914665, 63.5927340388298, 63.73352028429508, 64.88110810518265, 65.36913871765137, 62.72893778979778, 63.31128694117069, 62.81858257949352, 62.760016322135925, 57.72897608578205, 61.75563141703606, 61.717926040291786, 63.98846000432968, 60.9833874553442, 50.14753930270672, 56.86256177723408, 62.492316886782646, 62.18461699783802, 57.63015478849411, 58.575984835624695, 66.08686700463295, 63.43572646379471, 63.36419530212879, 61.68838642537594, 60.472379475831985, 58.69033969938755, 62.95457348227501, 59.37570512294769, 62.42214985191822, 59.37920853495598, 56.858845576643944, 60.37397615611553, 62.33076095581055, 63.01719032227993, 57.6961762458086, 56.22874438762665, 58.49193334579468, 58.70294742286205, 57.19698563218117, 55.530832037329674, 55.19721753895283, 53.5353235155344, 54.75473128259182, 55.500855445861816, 51.675866693258286, 51.638066321611404, 49.527283385396004, 51.34017750620842, 53.484459444880486, 57.309258207678795, 59.566831067204475, 61.08598195016384, 61.932572722435, 64.33741807937622, 62.47309371829033, 52.707074359059334, 50.778636038303375, 54.26851697266102, 32.36196666955948, 56.343562826514244, 64.23490718007088, 67.56212264299393, 54.40855085849762, 57.37810291349888, 62.289966344833374, 60.93067288398743, 66.2420354783535, 67.00733721256256, 63.20475585758686, 63.78933548927307, 66.39816150069237, 69.81800839304924, 65.78427404165268, 62.42952525615692, 9.001812916249037, 2.054924271069467, 2.7971011586487293, 0.28263533546123654, 29.483478628098965, 62.704448103904724, 62.5085686147213, 69.45127487182617, 62.359426617622375, 68.3152574300766, 71.90250813961029, 22.744764424860477, 34.24154721200466, 27.830840907990932, 66.39255300164223, 47.72354297339916, 49.847328811883926, 84.71920520067215, 29.131596609950066, 1.017945189960301, 0.28893830662127584, 0.3324852167861536, 0.2962931978981942, 0.2067308162804693, 0.1877713031717576, 0.14870101294945925, 0.17927803157363087], [0.015489168417843757, 0.05603441684797872, 0.0392283676774241, 0.07721498870523646, 0.06662278989097103, 0.11187990516191348, 0.005656921866830089, 0.13082390738418326, 0.05193430326471571, 0.1100050174864009, 0.40327918832190335, 1.028636866249144, 18.277974911034107, 58.76620262861252, 44.06777434051037, 32.52266004681587, 24.669290855526924, 43.995961993932724, 22.104282192885876, 11.690688282251358, 50.9389304369688, 46.9025856256485, 58.5193944722414, 55.38452088832855, 56.55441731214523, 59.57792267203331, 7.558082761242986, 1.1650316161103547, 1.7588727758266032, 0.14691804768517613, 0.09411956911208108, 2.221123077906668, 56.63968853652477, 63.92480581998825, 65.56237354874611, 61.50804050266743, 63.636682480573654, 58.756262362003326, 61.496967896819115, 56.94768100976944, 62.40975871682167, 56.766157150268555, 60.83277493715286, 57.62302257120609, 70.02684518694878, 52.240474596619606, 46.860084906220436, 60.74519343674183, 60.88118813931942, 61.09662897884846, 60.52187941968441, 56.60265572369099, 61.72561302781105, 58.61798778176308, 56.24123051762581, 54.90343250334263, 54.64983411133289, 51.31407290697098, 49.08268824219704, 45.51960803568363, 51.181600615382195, 49.1646384447813, 48.070977330207825, 49.39407393336296, 53.44987370073795, 54.85826812684536, 54.84968438744545, 60.29426023364067, 55.611809492111206, 57.812423408031464, 57.58230775594711, 58.64443816244602, 54.97062809765339, 56.4774676412344, 55.567089691758156, 54.93426784873009, 54.25118990242481, 57.37621061503887, 58.1668645888567, 56.801358461380005, 56.90460652112961, 57.86102280020714, 59.03494320809841, 55.51637761294842, 55.24940773844719, 51.82656280696392, 56.66536755859852, 54.89104516804218, 55.962181091308594, 47.05348312854767, 51.23330444097519, 55.59919036924839, 55.291619673371315, 50.98228991031647, 52.98389710485935, 55.412916764616966, 57.67710506916046, 55.11672645807266, 54.35660384595394, 51.755221635103226, 50.02435751259327, 50.2915021777153, 51.53929442167282, 53.68574604392052, 55.287804678082466, 56.61807909607887, 55.07522128522396, 53.465730249881744, 53.47439758479595, 54.46726530790329, 53.73008206486702, 50.7621905207634, 52.27002561092377, 48.43904457986355, 47.83383585512638, 45.54655998945236, 49.94467958807945, 47.469249218702316, 46.99865207076073, 46.55539445579052, 47.69548907876015, 46.62804655730724, 49.7966281324625, 51.22827731072903, 51.12383231520653, 53.62830452620983, 60.32017484307289, 59.3810248374939, 60.13995811343193, 50.85560850799084, 54.63338099420071, 46.5787898004055, 65.51996782422066, 17.94996701180935, 34.183737114071846, 64.56364274024963, 58.9962574839592, 65.31240776181221, 50.45765206217766, 52.922047823667526, 58.593479096889496, 61.73694021999836, 60.30401051044464, 59.328226670622826, 59.78675566613674, 63.62671561539173, 61.371392235159874, 64.09003615379333, 39.03155118227005, 0.28918279975187033, 0.7316250912845135, 0.788625298300758, 0.8895624883007258, 45.60626998543739, 56.083383187651634, 57.20874600112438, 62.29154326021671, 35.250936448574066, 54.71010647714138, 35.31575717031956, 5.664643412455916, 35.14014199376106, 21.287151239812374, 48.99044059216976, 24.92446046322584, 38.736105635762215, 52.4621395021677, 7.265717899426818, 0.3920770331751555, 0.11029230285203084, 0.13240805128589272, 0.08983063089544885, 0.031645136114093475, 0.04247860713803675, 0.04663061539758928, 0.054396823470597155, 0.04471345127967652, 0.08150599751388654, 0.09542958592646755, 0.17104856378864497, 0.08245687422459014, 0.07062229793518782, 0.04816159555048216, 0.13423429860267788, 0.04369391106592957, 0.19174899207428098, 0.39325630583334714, 0.9104540047701448, 20.343707464635372, 73.81413236260414, 49.635091200470924, 26.95295501500368, 35.29794752597809, 56.724834367632866, 30.114417672157288, 15.42255638167262, 55.910439267754555, 51.8989223241806, 61.0596227645874, 62.81954012811184, 61.70218728482723, 64.45400342345238, 9.533660877496004, 1.0607760166749358, 1.9592133443802595, 0.49805109039880335, 0.022272467758739367, 2.9661619244143367, 59.96777415275574, 66.6428379714489, 70.23590996861458, 62.79834106564522, 65.39290264248848, 60.39334371685982, 64.34474408626556, 58.965957909822464, 65.75767546892166, 57.92819179594517, 62.40859217941761, 60.0608691573143, 71.08716309070587, 54.415227100253105, 49.176877588033676, 64.17940735816956, 62.646824195981026, 63.625013306736946, 61.2239221483469, 59.76497903466225, 62.40234911441803, 64.31879907846451, 58.354308530688286, 55.30645027756691, 56.43079474568367, 55.34268133342266, 52.59506396949291, 48.46796102821827, 54.870165288448334, 52.363758981227875, 51.37405268847942, 51.657437682151794, 54.84292455017567, 57.206663712859154, 56.45970739424229, 60.94491071999073, 57.40909405052662, 58.871673569083214, 58.60316477715969, 59.78868216276169, 59.36643362045288, 57.56810411810875, 56.76286272704601, 57.66635924577713, 55.95257520675659, 57.626719772815704, 59.60677072405815, 61.05797365307808, 58.8810096681118, 61.81375689804554, 59.46718141436577, 60.49661837518215, 56.1396923661232, 54.74899739027023, 59.88248772919178, 58.64106014370918, 57.31285281479359, 48.92699159681797, 51.85573764145374, 59.2674907296896, 57.31671340763569, 55.628239810466766, 55.79435549676418, 62.8420615196228, 60.216581001877785, 60.09467974305153, 58.22641879320145, 59.0694035589695, 52.750046253204346, 55.009256824851036, 52.449683770537376, 56.752436086535454, 55.29586024582386, 58.390083611011505, 55.8346751332283, 58.18798005580902, 57.710885256528854, 56.29562459886074, 56.18432477116585, 53.13876919448376, 55.62127098441124, 50.37940286099911, 50.36682553589344, 46.534579172730446, 52.45488189160824, 48.30084599554539, 47.831711769104004, 48.27303148806095, 48.958431109786034, 49.39626641571522, 50.80948658287525, 51.86897233128548, 53.89818884432316, 54.27123382687569, 61.43917299807072, 59.65149812400341, 62.53519378602505, 54.54346641898155, 59.845249727368355, 45.213511660695076, 65.25598838925362, 20.00147122889757, 37.35962189733982, 65.60024991631508, 61.700359582901, 68.57528507709503, 57.14658513665199, 53.25348883867264, 59.17589284479618, 64.79568868875504, 65.03274276852608, 61.9712470471859, 62.8668399900198, 63.9574308693409, 64.10832837224007, 63.43705639243126, 42.550777941942215, 0.5434394173789769, 1.0113016027025878, 0.9298812341876328, 1.4512087474577129, 47.893386259675026, 56.03480279445648, 61.235241740942, 70.05317777395248, 40.512772500514984, 59.9667102098465, 39.67625118792057, 11.223117671906948, 45.491759330034256, 24.88699447363615, 62.89289899170399, 26.78317442536354, 45.00145643949509, 63.520017340779305, 10.305488761514425, 0.4237732104957104, 0.32528163457755, 0.02283181147504365, 0.25921962631400675, 0.054006257123546675, 0.08512011569109745, 0.04710175300715491, 0.08052631805185229, 0.17615531163755804, 0.12804509868146852, 0.17985389364184812, 0.31643033609725535, 0.2529224142199382, 0.2304410986835137, 0.16611994622508064, 0.18480591854313388, 0.23929619695991278, 0.2005946502322331, 0.8937430358491838, 0.9653734078165144, 30.381034165620804, 86.19813904166222, 63.282511085271835, 40.46842508018017, 41.4753520488739, 64.59498345851898, 31.618964038789272, 17.676486186683178, 62.56454341113567, 60.15795774757862, 71.56239598989487, 67.10792541503906, 66.44951954483986, 70.95182195305824, 11.211488395929337, 2.210153779014945, 3.4768901439383626, 1.3745162752456963, 0.14416804915526882, 4.404939282685518, 66.03461220860481, 69.64410692453384, 74.87469345331192, 64.9998289346695, 70.85919812321663, 65.58470115065575, 66.97655126452446, 61.31468407809734, 69.34975191950798, 61.789073422551155, 64.78465408086777, 60.920740216970444, 72.50892519950867, 55.03468506038189, 47.70507596433163, 67.14784607291222, 63.86203318834305, 67.75403514504433, 62.40320786833763, 61.608514711260796, 67.09219425916672, 65.17199009656906, 60.911419317126274, 57.92960152029991, 60.250281393527985, 57.57515273988247, 56.0362733155489, 50.69770038127899, 59.211500734090805, 55.31867802143097, 53.88891354203224, 55.711117163300514, 59.488186687231064, 60.84384374320507, 60.71364752948284, 64.77884039282799, 61.37340232729912, 62.83412754535675, 65.4006390273571, 64.61034223437309, 62.10378013551235, 59.790274277329445, 61.69522985816002, 58.91997277736664, 60.64109422266483, 61.30184456706047, 63.69517274200916, 65.32180085778236, 62.69538938999176, 63.507113233208656, 63.52760933339596, 61.171325370669365, 61.5002129226923, 57.033822387456894, 64.1154719889164, 61.424961760640144, 62.78765603899956, 52.692813724279404, 56.984877213835716, 64.6328142285347, 60.75692340731621, 61.097236946225166, 59.38416346907616, 63.74816469848156, 66.1228434741497, 64.87539321184158, 60.69554530084133, 61.33987292647362, 57.57482595741749, 60.6303445994854, 57.79472395777702, 58.19709196686745, 60.319046303629875, 63.71021993458271, 61.111231595277786, 60.73001325130463, 62.80076153576374, 62.15348146855831, 60.2904262393713, 55.82555562257767, 59.526724219322205, 50.52562281489372, 52.83556066453457, 49.49972726404667, 56.3104248046875, 50.4124116897583, 52.218709364533424, 50.391474813222885, 52.55394637584686, 51.46042965352535, 54.727767929434776, 54.30825524032116, 55.58711461722851, 57.84645438194275, 64.90340530872345, 62.478690817952156, 66.92025348544121, 54.92691904306412, 59.046084210276604, 45.70938505232334, 66.1171817779541, 21.68325148522854, 38.62093761563301, 69.55388456583023, 63.552270010113716, 67.82440736889839, 54.73019599914551, 57.99615114927292, 62.89931304752827, 65.30951231718063, 65.81266611814499, 65.55938690900803, 66.15505814552307, 65.95233902335167, 68.50220739841461, 67.69725859165192, 51.990387216210365, 0.789551914203912, 1.7126267636194825, 3.235580767504871, 1.234504000749439, 56.462922021746635, 68.73625203967094, 65.98355054855347, 74.99350547790527, 45.47212578356266, 67.97177866101265, 46.721988916397095, 12.160594817250967, 45.127887055277824, 34.9333418905735, 62.41824746131897, 32.01510988175869, 52.237199172377586, 72.56867319345474, 17.080771252512932, 1.1950862221419811, 0.5098244617693126, 0.2246972467401065, 0.34916017670184374, 0.22299918317003176, 0.20340191287687048, 0.12226255115820095, 0.18628199090017006], [0.04283807378669735, 0.08704751773620956, 0.018673877166293096, 0.07874271454056725, 0.11320266465190798, 0.1418739667860791, 0.06845380179584026, 0.15865533583564684, 0.0773848440439906, 0.16520646633580327, 0.4564179416047409, 0.28262524225283414, 5.362846981734037, 51.84248775243759, 56.992697194218636, 42.96705320477486, 29.415591470897198, 35.42419195175171, 23.48012186586857, 8.095031473785639, 45.81320308148861, 57.77951717376709, 51.74510657787323, 62.286451533436775, 54.68284294009209, 60.15761196613312, 20.70679698139429, 0.18260444136103615, 0.8828591136261821, 0.6664938549511135, 0.057573701633373275, 0.9660364722367376, 44.687285497784615, 69.62025180459023, 68.76904428005219, 63.335993215441704, 64.15122047066689, 59.7133170068264, 64.09341797232628, 59.90576907992363, 62.09068603813648, 59.4161843508482, 62.93314263224602, 58.27924355864525, 63.2616426050663, 59.8670681566, 52.083033844828606, 58.63205462694168, 63.991112262010574, 55.13217642903328, 60.10080121457577, 58.592346757650375, 59.87491473555565, 60.72106473147869, 57.96570338308811, 53.233642503619194, 54.9775855243206, 56.86476185917854, 52.69325070083141, 48.45616266131401, 48.59325930476189, 48.83948989212513, 50.16593411564827, 48.49776662886143, 49.53257270157337, 53.41702066361904, 54.99532677233219, 53.53357940912247, 53.3974327147007, 57.72496350109577, 58.99901233613491, 56.37091375887394, 57.18262240290642, 53.21911208331585, 56.21569208800793, 51.253382563591, 52.8029166162014, 53.73991973698139, 55.18205635249615, 56.210117787122726, 56.053079813718796, 53.249533250927925, 55.16344875097275, 53.0188400298357, 52.53626972436905, 49.17997442185879, 53.95604833960533, 54.34106647968292, 56.588600277900696, 51.282017827034, 54.77266252040863, 53.34499932825565, 53.87056052684784, 51.217375695705414, 50.47242186963558, 53.32106441259384, 54.08097803592682, 54.11753587424755, 54.39299829304218, 53.645844385027885, 50.56569926440716, 48.86176809668541, 52.33334921300411, 54.15549583733082, 56.43884651362896, 52.71226108074188, 53.948881924152374, 55.43111778795719, 55.51954284310341, 52.241150960326195, 54.61079880595207, 50.65672717988491, 48.98977942764759, 51.11091300845146, 49.02816116809845, 46.5052979439497, 48.224979266524315, 46.79369106888771, 46.76439084112644, 46.53519853949547, 45.30605189502239, 46.21167249977589, 48.58026400208473, 51.58250570297241, 53.19654889404774, 52.513421550393105, 53.952525928616524, 57.77852542698383, 56.845485493540764, 60.713180154562, 60.75646363198757, 55.94139240682125, 46.18137292563915, 49.20396253466606, 57.16381721198559, 59.93928328156471, 58.73510889708996, 63.086654394865036, 64.44972485303879, 56.802430003881454, 53.220616802573204, 56.65308281779289, 60.995387211441994, 63.29741768538952, 59.515400826931, 64.99598354101181, 72.21151515841484, 63.475134149193764, 11.638457234948874, 1.082107953261584, 0.2645151468459517, 0.389756218646653, 3.785457336343825, 57.63290964066982, 57.73942552506924, 58.82302477955818, 57.934381663799286, 41.77709385752678, 64.5299157500267, 17.34796341508627, 9.449057467281818, 34.60594765841961, 30.907448418438435, 40.35994090139866, 20.725332386791706, 52.166177183389664, 46.37459255754948, 5.274701211601496, 0.25205864338204265, 0.23691896436503157, 0.05495182747836225, 0.07388851954601705, 0.10355990278185345, 0.0490284722764045, 0.07843631887226366, 0.07959129361552186, 0.041487910493742675, 0.143072965729516, 0.08601369117968716, 0.05321444492437877, 0.12254058936377987, 0.0673431258474011, 0.049250007068621926, 0.147465574555099, 0.06028334217262454, 0.1843532084603794, 0.49782758520450443, 0.3798421350074932, 5.789641505107284, 61.84880621731281, 65.01462534070015, 42.25158579647541, 40.67100740969181, 44.40030209720135, 27.56131947040558, 10.918848998844624, 48.4169677644968, 64.97566983103752, 63.55169624090195, 74.30471643805504, 56.713446378707886, 68.32578286528587, 22.709876596927643, 0.08167785665136762, 0.8591896493453532, 0.8482977712992579, 0.036320128419902176, 0.6963921943679452, 49.26262378692627, 72.56750285625458, 70.29650911688805, 66.25926375389099, 65.93595430254936, 61.85554325580597, 64.69016835093498, 61.60442993044853, 63.162551522254944, 63.53230208158493, 65.74854075908661, 61.75837866961956, 64.65350031852722, 60.612952932715416, 53.12220588326454, 58.376860320568085, 65.01404017210007, 57.19501733779907, 61.930650025606155, 61.94849766790867, 63.27318638563156, 63.97272124886513, 61.28652758896351, 56.165568977594376, 57.97764994204044, 58.17803218960762, 55.91925859451294, 51.3619389384985, 53.62824372947216, 52.78579853475094, 50.35344645380974, 49.452055022120476, 52.55027197301388, 54.275888577103615, 56.851128190755844, 56.49354837834835, 57.41598688066006, 58.51320840418339, 61.63859009742737, 60.8539891988039, 58.48233126103878, 56.10042527318001, 57.8681094199419, 55.59115380048752, 53.0168679356575, 56.18576869368553, 57.81542144715786, 60.24772793054581, 58.268015161156654, 57.64744386076927, 58.70740458369255, 56.269774585962296, 54.33318950235844, 52.353168949484825, 56.36835649609566, 59.12907935678959, 56.257949620485306, 52.72596314549446, 54.88047793507576, 57.740934044122696, 57.06957846879959, 54.07443858683109, 54.40443567931652, 57.60924831032753, 58.923369795084, 58.99622708559036, 60.299845933914185, 58.94364930689335, 54.53421391546726, 52.76210680603981, 56.22086741030216, 56.100113689899445, 59.22253154218197, 55.4048877954483, 57.4555541574955, 56.3357238471508, 55.728653222322464, 56.546160355210304, 55.56998513638973, 52.735382840037346, 53.87431472539902, 54.28184665739536, 50.93358412384987, 49.97325785458088, 49.07698854804039, 48.23315642774105, 50.279164239764214, 47.46809408068657, 48.88716973364353, 48.63035291433334, 53.267764672636986, 54.199569672346115, 55.8975313603878, 53.51814463734627, 56.62988506257534, 58.63966941833496, 59.344132617115974, 60.58955378830433, 62.53255292773247, 56.278419122099876, 46.36347055435181, 50.02420172095299, 59.69458781182766, 62.01968304812908, 62.03961677849293, 63.64685073494911, 66.15061238408089, 60.72422236204147, 58.5743623226881, 57.98734322190285, 62.883790880441666, 64.32786539196968, 64.18384552001953, 67.14187279343605, 73.57653111219406, 65.0410795211792, 12.663931958377361, 0.9593906882219017, 0.7878193852957338, 0.3728625923395157, 5.533874379470944, 61.800529807806015, 61.31503365933895, 59.76120583713055, 67.49947920441628, 42.35194221138954, 71.28150746226311, 20.72578266263008, 16.56591407954693, 35.5660155415535, 34.77954514324665, 48.61459895968437, 20.457621552050114, 59.266981557011604, 55.87355084717274, 5.670202989131212, 0.2673593832878396, 0.39990666147787124, 0.14139865088509396, 0.13319183344719931, 0.07009198889136314, 0.06664022293989547, 0.043494228812051006, 0.020553215872496367, 0.19386956031667069, 0.24131158803356811, 0.18417579063680023, 0.24027286330237985, 0.2466979474411346, 0.20226283493684605, 0.1960493519436568, 0.1897261498379521, 0.1941734697902575, 0.17810900055337697, 0.8014252677094191, 0.5735143879428506, 10.596662387251854, 79.62563171982765, 77.67999932169914, 59.54505443572998, 46.33643880486488, 59.90331061184406, 30.0557754188776, 13.721484560519457, 53.59051175415516, 71.19693920016289, 62.39423654973507, 76.1669509112835, 62.48338356614113, 74.13494914770126, 28.498130701482296, 0.1409917906858027, 1.6348929097875953, 1.3083689496852458, 0.21962683444144204, 0.9947346104308963, 50.694668143987656, 74.58139479160309, 76.74306839704514, 68.99436458945274, 68.8823390007019, 64.97869446873665, 69.68815416097641, 62.942315340042114, 66.12057879567146, 65.22568121552467, 67.70109638571739, 64.31753754615784, 66.08239084482193, 60.80403707921505, 51.91081188619137, 61.3109564781189, 67.5626090168953, 61.325661689043045, 64.85283762216568, 63.398868441581726, 67.347631752491, 65.67597985267639, 63.52470248937607, 57.139350324869156, 59.76835325360298, 60.26456482708454, 58.1154153496027, 54.620404690504074, 54.21959839761257, 54.4313458353281, 56.2313586473465, 52.453335374593735, 54.92059238255024, 58.01142632961273, 60.962819159030914, 57.45227873325348, 60.91013878583908, 62.426637411117554, 66.70364990830421, 62.78007924556732, 63.70448224246502, 58.324525728821754, 62.93446496129036, 57.65145264565945, 57.571497336030006, 58.402809128165245, 62.049587443470955, 62.30257026851177, 60.51177196204662, 61.23183332383633, 62.86617502570152, 59.10463526844978, 57.374952882528305, 55.465756729245186, 58.55362303555012, 62.41687573492527, 62.944409027695656, 57.19636246562004, 58.00481088459492, 59.735975190997124, 58.620062470436096, 58.733999356627464, 58.880720883607864, 63.74827869236469, 62.75622792541981, 63.08382734656334, 63.77650737762451, 63.17761391401291, 58.58294986188412, 55.60833267867565, 59.229910746216774, 59.88067902624607, 63.50874714553356, 56.977809593081474, 60.08322715759277, 58.26000519096851, 61.70220248401165, 58.88917922973633, 61.99801281094551, 55.986355394124985, 56.95453584194183, 57.96274334192276, 55.436771884560585, 53.26802685856819, 53.57582174241543, 51.96008384227753, 53.52268919348717, 50.80281414091587, 51.875823363661766, 50.67385286092758, 55.525489524006844, 56.67646296322346, 58.29568147659302, 55.56949496269226, 58.94322752952576, 61.010309010744095, 61.73189029097557, 61.948357075452805, 64.47430193424225, 56.763926669955254, 47.84582041203976, 51.49721547961235, 62.03824125230312, 64.9022425711155, 63.834606260061264, 65.75801745057106, 70.06044298410416, 57.32381522655487, 62.338227555155754, 61.94739192724228, 64.90891501307487, 67.12462171912193, 67.40433230996132, 70.34347459673882, 76.87199547886848, 69.00064185261726, 19.60743047297001, 0.9809112490620464, 1.3543384079821408, 0.45700830523855984, 7.165388558059931, 66.0870797932148, 69.47536557912827, 64.39529657363892, 72.44536980986595, 47.225283309817314, 78.80470097064972, 25.50193067640066, 16.548142433166504, 42.28026285767555, 50.11701174080372, 54.33900699019432, 32.48115487396717, 68.14925953745842, 71.8646089732647, 10.183903835713863, 0.6750523019582033, 0.5748074466828257, 0.20549613487673923, 0.3419337363447994, 0.21002860885346308, 0.16748745721997693, 0.24083947821054608, 0.161785195232369], [0.02767494475847343, 0.02541107893193839, 0.020874912770523224, 0.05888081665034406, 0.035271061860839836, 0.07690830359933898, 0.05202788808674086, 0.05773682569270022, 0.08361296961084008, 0.05838857607159298, 0.05301670709741302, 0.1397451458615251, 0.9505844232626259, 32.23598822951317, 54.072261303663254, 37.07453079521656, 24.019136242568493, 30.69712210446596, 48.50746750831604, 7.662453660741448, 28.466858379542828, 60.32607212662697, 39.43916670978069, 47.005210518836975, 64.22213986515999, 55.442258790135384, 61.41302280128002, 1.871699527837336, 0.7707429234869778, 0.04575857332383748, 6.664407290518284, 2.056786408647895, 24.0341929346323, 76.93994343280792, 65.22176742553711, 66.61606460809708, 60.74700213968754, 64.04340505599976, 59.62049178779125, 63.92045885324478, 61.71511419117451, 59.88173916935921, 61.303501278162, 61.73682242631912, 62.97261871397495, 60.85889853537083, 55.8665706217289, 56.135451793670654, 57.46775910258293, 53.55495326220989, 47.10989110171795, 59.28546376526356, 59.34831239283085, 61.661046892404556, 58.257417529821396, 57.35542193055153, 57.19531372189522, 53.908725678920746, 51.57093532383442, 52.02310726046562, 52.012494429945946, 48.885585218667984, 49.89191561937332, 45.7875582575798, 49.52211186289787, 50.33995717763901, 53.482133969664574, 55.41511304676533, 55.24897076189518, 55.03619737923145, 56.95403426885605, 58.35369296371937, 56.27547807991505, 57.65444688498974, 54.06350277364254, 50.775729194283485, 54.105311930179596, 53.729208111763, 57.2064433246851, 56.99617400765419, 56.3990930467844, 54.46486383676529, 53.66762101650238, 51.47211782634258, 50.41368842124939, 49.41466122865677, 53.512080162763596, 52.29550704360008, 53.82541514933109, 51.255065873265266, 54.39486399292946, 54.55194376409054, 54.30870741605759, 49.41303491592407, 50.163133665919304, 51.931714564561844, 54.94526065886021, 53.18666182458401, 53.6081276088953, 52.864549309015274, 54.28648620843887, 49.278259947896004, 49.38740149140358, 52.51120626926422, 54.911841452121735, 52.957100942730904, 55.49259848892689, 54.895798712968826, 55.01516930758953, 54.944401904940605, 53.68538126349449, 48.9314753562212, 49.19987015426159, 48.93559813499451, 47.03999385237694, 43.17122004926205, 45.30865095555782, 45.588847920298576, 46.35174058377743, 46.59185349941254, 47.33747608959675, 47.62938782572746, 49.81932431459427, 51.84366948902607, 53.24907727539539, 51.7614571005106, 53.9642520993948, 55.19457668066025, 58.15622515976429, 57.4376305192709, 58.026804104447365, 60.20647354424, 55.134376510977745, 47.420953810214996, 55.373376086354256, 59.13860164582729, 59.71621245145798, 59.46905471384525, 60.60549773275852, 68.30566674470901, 63.17835487425327, 59.77657601237297, 56.184503361582756, 58.881750628352165, 65.72130382061005, 64.3979412317276, 70.60861676931381, 38.87339606881142, 0.38242670882027596, 0.5174720857758075, 1.5714445081539452, 0.013115679030306637, 2.4652592651546, 48.7563693523407, 56.4564623683691, 55.975035801529884, 54.98038977384567, 50.71411930024624, 68.59949737787247, 15.359688755124807, 23.90638679265976, 34.50172685086727, 31.393079459667206, 32.68615387380123, 28.49121317267418, 51.60792633891106, 32.976435497403145, 1.567489157896489, 0.14416139951208606, 0.0993114487209823, 0.049072741385316476, 0.06114261930633802, 0.02671228830877226, 0.010744595128926449, 0.08598510365118273, 0.05150096694706008, 0.06480986412498169, 0.06989357571001165, 0.1255196295096539, 0.01855176975368522, 0.054739799597882666, 0.04732567380415276, 0.0911712167726364, 0.043160536952200346, 0.1022505910077598, 0.09242566156899557, 0.23890823184046894, 0.08116439435980283, 1.790842954069376, 42.31519058346748, 69.02375981211662, 36.46121330559254, 32.469196915626526, 42.906374260783195, 49.060391038656235, 7.779076527804136, 30.42060524225235, 66.71725317835808, 44.54842574894428, 53.68778273463249, 68.14955592155457, 60.487787649035454, 65.14078617095947, 1.61276550963521, 1.182897426187992, 0.013647578125528526, 8.101366683840752, 2.9159141331911087, 24.589046761393547, 79.8209336400032, 67.29210913181305, 71.30120560526848, 65.16896545886993, 65.98796591162682, 61.44314378499985, 65.02942934632301, 62.97729626297951, 62.591461166739464, 60.133213475346565, 64.09710377454758, 63.850762993097305, 62.056259885430336, 56.69937953352928, 58.62957336008549, 60.32391004264355, 54.68258075416088, 50.7958909124136, 62.39393636584282, 61.20227850973606, 64.25426334142685, 62.287291288375854, 60.918794721364975, 59.07552123069763, 55.74328623712063, 53.819251880049706, 56.25527076423168, 54.27125662565231, 49.61540825664997, 51.34741611778736, 47.678439393639565, 51.01148374378681, 52.293466553092, 56.911043375730515, 58.994368985295296, 59.330472350120544, 57.88330480456352, 59.04682517051697, 61.237628012895584, 59.00292232632637, 56.15733861923218, 57.22722440958023, 53.45706671476364, 57.33325012028217, 56.79437443614006, 57.601671516895294, 58.468245416879654, 57.46727652847767, 57.91212245821953, 56.8504024296999, 56.41247592866421, 50.44664025306702, 54.53979201614857, 55.58592528104782, 55.81600673496723, 57.56178505718708, 55.122954323887825, 55.41082687675953, 58.433431684970856, 56.60482540726662, 54.84213799238205, 55.352013632655144, 54.72568564116955, 59.44423444569111, 57.40267239511013, 55.958639681339264, 59.2852433770895, 56.41020745038986, 53.05248722434044, 53.51036265492439, 56.48480124771595, 57.90521822869778, 56.042170599102974, 58.66755232214928, 55.348730608820915, 57.73662127554417, 57.54964470863342, 54.61468979716301, 53.52599121630192, 53.14394451677799, 51.379892975091934, 51.86722442507744, 46.68953865766525, 49.39700737595558, 48.84054243564606, 48.54583024978638, 49.105376824736595, 48.760894909501076, 50.36711052060127, 51.23559571802616, 52.171975672245026, 55.70954404771328, 54.68125842511654, 54.7361046820879, 57.33926519751549, 57.75058172643185, 58.65341328084469, 60.421819388866425, 60.15096612274647, 58.35984863340855, 46.97483114898205, 57.46170602738857, 61.41117990016937, 62.917035296559334, 61.34562201797962, 61.78238958120346, 68.62030506134033, 68.28525424003601, 62.902322486042976, 61.41022615134716, 60.49559623003006, 65.04396736621857, 64.70926612615585, 72.50910758972168, 40.58054566383362, 0.18495031079510227, 1.0166893573477864, 3.3141002291813493, 0.18002209399128333, 3.786790114827454, 52.9055605083704, 62.73599401116371, 59.33076873421669, 59.37825858592987, 51.05897359549999, 75.19373193383217, 17.249968573451042, 25.148971416056156, 31.515812873840332, 38.478806242346764, 40.5978537350893, 28.037829101085663, 62.81358204782009, 40.7092409580946, 2.159193526022136, 0.0466360330756288, 0.1312764541944489, 0.03536106210958678, 0.042110620634048246, 0.059164101839996874, 0.07887623432907276, 0.0026319810467612115, 0.058262429520254955, 0.2032560363295488, 0.1462587682181038, 0.1983220159308985, 0.2272508284659125, 0.1366878388216719, 0.12414532044203952, 0.1838405180023983, 0.16131369397044182, 0.45234889432322234, 0.19315925077535212, 0.4341542237671092, 0.2318987509352155, 2.2430139407515526, 60.74489705264568, 79.85912159085274, 53.59708920121193, 30.795840807259083, 56.37248307466507, 61.92043237388134, 11.859712712466717, 37.81566582620144, 73.0047757923603, 48.236564844846725, 61.77203133702278, 73.90624701976776, 66.31470277905464, 69.9541474878788, 1.939058513380587, 1.988289027940482, 0.43408398691099137, 8.016439341008663, 2.819804702885449, 28.38617540895939, 83.94189611077309, 68.91872584819794, 74.5694026350975, 66.18411138653755, 69.00822624564171, 63.43248523771763, 70.30860766768456, 64.64707866311073, 65.9745754301548, 64.32837456464767, 66.62075355648994, 65.10501489043236, 63.9960215985775, 56.9649662822485, 58.69100086390972, 61.17690347135067, 56.333839148283005, 53.40349338948727, 66.38683050870895, 66.03021964430809, 67.09231585264206, 65.07233664393425, 63.2168810069561, 63.00201393663883, 58.39398220181465, 55.05912534892559, 58.40896859765053, 57.40742973983288, 56.176356598734856, 55.955417454242706, 53.30502547323704, 52.61977784335613, 55.69178760051727, 59.27333861589432, 62.98078827559948, 63.04022088646889, 60.69253586232662, 62.60210059583187, 64.82123851776123, 62.26084850728512, 62.398906499147415, 58.02431143820286, 57.356421276926994, 58.419566228985786, 61.55102379620075, 63.740416914224625, 62.404420003294945, 62.52997666597366, 61.2745126336813, 60.93935541808605, 57.66637444496155, 54.7557420283556, 55.885322615504265, 59.587832540273666, 59.642146825790405, 63.644958436489105, 56.81382179260254, 61.20693325996399, 65.03300115466118, 62.42867410182953, 57.55624495446682, 59.503648057579994, 58.03630359470844, 63.328841999173164, 60.22674545645714, 61.30243353545666, 61.12632058560848, 61.463457494974136, 56.41433782875538, 56.74813471734524, 58.991674929857254, 63.27827051281929, 59.8856795579195, 62.58601225912571, 60.39839364588261, 61.240151077508926, 60.730697214603424, 58.66770811378956, 56.97672285139561, 56.67632237076759, 54.79890391230583, 55.98161704838276, 48.260815143585205, 51.83642327785492, 51.263254433870316, 51.48404538631439, 51.04365661740303, 51.79499790072441, 53.277552947402, 55.106121227145195, 55.314703434705734, 58.56459304690361, 55.89972384274006, 57.99032986164093, 58.97051006555557, 61.89188450574875, 59.9742566049099, 61.41821712255478, 62.690582647919655, 58.31411808729172, 47.85600766539574, 59.61948864161968, 62.07091189920902, 65.94123601913452, 63.03390942513943, 63.140873685479164, 72.25427806377411, 65.24416342377663, 64.83070001006126, 63.425056636333466, 61.420022025704384, 67.57926732301712, 66.26437827944756, 72.47084364295006, 46.694539189338684, 1.5618513291701674, 1.3287239824421704, 3.834631685167551, 0.23529449215857312, 6.056848866865039, 57.21875846385956, 68.16786333918571, 63.430801928043365, 67.83527478575706, 57.27118045091629, 80.69907411932945, 21.23157162219286, 32.36267723143101, 41.703111827373505, 50.787630155682564, 47.902954146265984, 43.951458781957626, 69.02692884206772, 55.308657959103584, 3.773568724282086, 0.32923686609137803, 0.2598612575093284, 0.20098724635317922, 0.19829577358905226, 0.1804345499840565, 0.18713728641159832, 0.2328274745377712, 0.2733275864738971], [0.014705036519444548, 0.0731911975890398, 0.07182177185313776, 0.09227884249412455, 0.13920026103733107, 0.1296470541274175, 0.08469736611004919, 0.04849610006203875, 0.14595889602787793, 0.007365609744738322, 0.29014610743615776, 0.32439758826512843, 1.0816619521938264, 20.24426680058241, 55.129197388887405, 41.3886559009552, 29.53638318926096, 20.80439854413271, 59.72426801919937, 8.412856869399548, 15.322289261966944, 49.86293837428093, 58.70917908847332, 51.302570924162865, 64.66860070824623, 55.75894519686699, 70.39480224251747, 12.10157448425889, 0.5875287484377623, 0.8111368934623897, 4.100614562630653, 3.6568617867305875, 5.866101002320647, 61.450671181082726, 68.09380531311035, 71.0539148747921, 63.66297706961632, 66.18564650416374, 61.16035535931587, 63.897120505571365, 59.40255828201771, 64.39468100667, 61.75236739218235, 64.65154722332954, 61.536747962236404, 61.12200781702995, 55.854753255844116, 54.30608555674553, 53.65068532526493, 57.35821858048439, 45.676965191960335, 54.46755409240723, 59.21692304313183, 61.338592395186424, 58.13680060207844, 55.805306509137154, 55.95168225467205, 55.200644955039024, 55.722170770168304, 52.29819729924202, 52.69308730959892, 50.24984501302242, 50.008155182003975, 45.485447868704796, 47.73469917476177, 48.931661546230316, 52.55593366920948, 52.45629161596298, 56.79469741880894, 52.13158763945103, 56.607371270656586, 54.76701222360134, 55.38681596517563, 50.353366658091545, 47.865499556064606, 50.30949041247368, 51.47506646811962, 53.146638572216034, 52.62508235871792, 54.063111394643784, 53.50921131670475, 52.222269773483276, 51.44226662814617, 48.01756739616394, 50.843532755970955, 51.855258867144585, 50.82611829042435, 52.79002010822296, 54.637556970119476, 52.04823911190033, 54.796985015273094, 53.409683257341385, 52.77472972869873, 50.22693984210491, 47.94866569340229, 49.09353286027908, 51.623273715376854, 51.53748571872711, 52.27222569286823, 52.039959356188774, 51.15844085812569, 52.37051881849766, 48.06764870882034, 49.58574704825878, 50.82514174282551, 52.56676308810711, 54.80132058262825, 53.70488181710243, 57.15301439166069, 53.2629769295454, 52.751725763082504, 48.513919562101364, 48.630611300468445, 44.68265354633331, 46.046632155776024, 42.70862527191639, 46.95593096315861, 45.498112589120865, 46.001543775200844, 48.56647074222565, 50.36497883498669, 52.58384317159653, 51.41363136470318, 51.43333710730076, 52.51760132610798, 49.930335357785225, 55.77016219496727, 53.441350758075714, 57.001083344221115, 56.07456386089325, 59.490458965301514, 58.01696263253689, 57.38615468144417, 53.03121596574783, 59.248981922864914, 56.45352132618427, 56.690180227160454, 58.38768593966961, 60.144061893224716, 55.091252624988556, 65.36831796169281, 62.46990568935871, 66.59082636237144, 58.273289278149605, 66.96705937385559, 50.28021298348904, 49.215266928076744, 6.374644814059138, 0.26101001305505633, 1.6341233323328197, 2.557033603079617, 0.16505972889717668, 11.693624574691057, 61.50378853082657, 50.28659284114838, 54.92568030953407, 50.38450978696346, 59.669577553868294, 55.114378184080124, 15.760247111320496, 30.672693215310574, 31.594122871756554, 31.511615999042988, 27.893440648913383, 35.84138296544552, 51.86885453760624, 24.265066646039486, 0.7026520615909249, 0.12351522222161293, 0.038246216863626614, 0.15627681190380827, 0.06765670550521463, 0.04928214206302073, 0.01640751215745695, 0.06727519707055762, 0.055028309507179074, 0.05713669910619501, 0.016553876666876022, 0.009648355808167253, 0.09692815277958289, 0.1271007306058891, 0.06322471090243198, 0.11393209933885373, 0.02668066354090115, 0.156851545907557, 0.07937938818940893, 0.31470047892071307, 0.1835163330542855, 1.011292221955955, 20.92216942459345, 73.06084558367729, 41.50162383913994, 24.474971182644367, 34.51451316475868, 65.75955256819725, 11.067839954048395, 18.343622088432312, 58.006497994065285, 56.54447704553604, 53.93207922577858, 70.71916043758392, 60.03607928752899, 76.46531850099564, 13.279537875205278, 0.756148915970698, 1.5622676443308592, 4.91165729239583, 5.761179607361555, 8.357442542910576, 64.33377787470818, 68.4852223098278, 71.82586625218391, 64.12016853690147, 68.10292482376099, 66.04903623461723, 66.17124527692795, 61.90246693789959, 66.46981045603752, 64.04989510774612, 65.63975259661674, 63.08211363852024, 61.81026488542557, 54.921428337693214, 56.26353532075882, 53.606303706765175, 59.327892288565636, 48.14215511083603, 59.03291791677475, 61.65335990488529, 62.899860218167305, 62.73969501256943, 59.88125279545784, 59.665701761841774, 57.73794740438461, 56.89074486494064, 54.16987046599388, 54.21122744679451, 52.474268451333046, 52.20110110938549, 48.548186123371124, 49.118436723947525, 51.77173934876919, 54.252136051654816, 53.80225159227848, 58.64801377058029, 54.869713112711906, 58.39423678815365, 60.08716754615307, 59.349330738186836, 54.79008078575134, 50.11518403887749, 52.5238785892725, 53.31117734313011, 54.68630075454712, 57.09114231169224, 57.86103419959545, 56.96490168571472, 55.52112735807896, 52.47494101524353, 51.25820070505142, 53.888248577713966, 53.41190613806248, 55.77377960085869, 59.23777252435684, 58.376286551356316, 53.52100968360901, 56.02227486670017, 57.11378529667854, 56.26320093870163, 54.54384259879589, 52.78015583753586, 54.059604182839394, 56.36988401412964, 54.0397160500288, 57.25999765098095, 54.616460502147675, 54.66583125293255, 55.33553771674633, 50.58514282107353, 54.38275404274464, 54.47722837328911, 53.57426002621651, 56.315573528409004, 56.250342428684235, 58.67639444768429, 55.664657056331635, 55.70691838860512, 51.10846593976021, 50.20328611135483, 47.18151345849037, 48.9351649582386, 45.396084263920784, 49.244852140545845, 49.20600302517414, 48.128612637519836, 50.17669893801212, 50.53115151822567, 52.54853546619415, 54.09875728189945, 53.366335183382034, 54.126765578985214, 52.12811842560768, 58.040164187550545, 54.75987620651722, 58.77320945262909, 59.52964246273041, 59.65966388583183, 59.40754361450672, 58.4698299318552, 54.01933774352074, 60.73504038155079, 58.144601583480835, 59.38920959830284, 59.629748091101646, 65.35087689757347, 60.30841447412968, 65.09977117180824, 63.41398403048515, 68.62888500094414, 59.56080459058285, 66.82872399687767, 51.76119491457939, 54.3572536110878, 6.7714655958116055, 0.5913034302648157, 2.7436216408386827, 2.632796550169587, 0.11204306632862426, 15.339793972671032, 66.70180320739746, 56.548854410648346, 59.85638692975044, 55.17577908933163, 63.15423756837845, 60.338725447654724, 18.857614807784557, 33.11589941382408, 32.844533175230026, 39.93261203169823, 28.605870120227337, 37.16189570724964, 63.33156645298004, 24.375078342854977, 0.6651702790986747, 0.11224389148992486, 0.04655594049836509, 0.09465385606745258, 0.08453599351923913, 0.024954244363470934, 0.014715936813445296, 0.041765154601307586, 0.0847516319481656, 0.20084439776837826, 0.18571942811831832, 0.12246984784724191, 0.2663431753171608, 0.26432539452798665, 0.24406019132584333, 0.18837098818039522, 0.09507795635727234, 0.20827957458095625, 0.1355385934584774, 0.3961935779079795, 0.620886089745909, 1.7088359920307994, 34.38986465334892, 91.51185750961304, 64.68165680766106, 38.22933442890644, 41.54408276081085, 77.63140752911568, 13.186024893075228, 21.40766367316246, 66.64400070905685, 62.25708290934563, 65.931356549263, 75.70858150720596, 65.44174522161484, 79.98770669102669, 13.861192613840103, 0.7584127632435411, 2.9041972244158387, 6.8408603221178055, 10.265032332390547, 10.02449193969369, 68.01585629582405, 71.33737206459045, 76.81947469711304, 65.32224923372269, 72.95740753412247, 66.17993161082268, 68.67942228913307, 63.22779402136803, 71.17101699113846, 65.46302407979965, 68.04531991481781, 64.93106782436371, 66.0077552497387, 55.64102612435818, 56.45930461585522, 53.56215387582779, 61.18594318628311, 47.78674118220806, 61.08726628124714, 64.89853397011757, 67.31474071741104, 64.53841209411621, 62.37549975514412, 63.12154412269592, 61.05192057788372, 60.12067414820194, 59.37274128198624, 57.87399150431156, 56.3129098713398, 56.366775780916214, 51.96565814316273, 51.66902706027031, 56.68282002210617, 56.82058542966843, 58.84612374007702, 63.16010445356369, 57.00671084225178, 60.85927091538906, 62.021871730685234, 62.7822033315897, 55.6545116007328, 52.36324980854988, 54.76331502199173, 57.13726043701172, 56.02070935070515, 59.689233899116516, 60.977482572197914, 60.73173075914383, 57.88282223045826, 54.09118048846722, 53.38895916938782, 57.73823618888855, 55.36421857774258, 59.25584815442562, 61.11156217753887, 62.6200470328331, 55.60762591660023, 61.24268174171448, 58.86978127062321, 62.23166227340698, 57.072652503848076, 57.82935529947281, 55.022616907954216, 60.594128742814064, 56.18961788713932, 62.015989646315575, 61.01832278072834, 58.76413553953171, 60.864412039518356, 53.39711353182793, 55.80057956278324, 58.305693939328194, 58.684727400541306, 60.78097231686115, 58.54199945926666, 63.28219190239906, 59.13124144077301, 59.39162626862526, 53.697020038962364, 54.31434631347656, 49.980929642915726, 51.66064850986004, 47.65302635729313, 52.66793645918369, 52.00509622693062, 50.75513429939747, 53.08827370405197, 52.51689836382866, 56.123531833291054, 54.7896172106266, 55.92381455004215, 56.69446639716625, 53.69302645325661, 59.7527626901865, 58.10327120125294, 60.75593926012516, 62.0027207583189, 63.25355663895607, 61.378562450408936, 59.76184420287609, 54.05548520386219, 61.42377242445946, 60.55019550025463, 61.34942941367626, 63.12535911798477, 65.46221852302551, 61.81903101503849, 68.96968871355057, 62.81016983091831, 69.42023053765297, 61.325669288635254, 69.69070762395859, 52.487943917512894, 61.90576896071434, 10.041744913905859, 0.6263247854076326, 4.032891746610403, 6.405505808070302, 0.31100657244678587, 16.021574288606644, 75.25063008069992, 60.189184471964836, 65.04856511950493, 59.94831159710884, 67.9024475812912, 66.70682653784752, 24.061724357306957, 41.37236997485161, 40.425392389297485, 48.17086637020111, 39.606908708810806, 47.681870609521866, 73.69337484240532, 43.54450061917305, 1.2214021850377321, 0.19490496022626758, 0.11636177951004356, 0.28766386094503105, 0.22372959007043391, 0.0881131156347692, 0.06810758990468457, 0.1930807760800235, 0.2704710600664839], [0.03196633762854617, 0.02920724407886155, 0.06770398031221703, 0.06666891436907463, 0.060662791147478856, 0.06354266181006096, 0.0434590398799628, 0.04837100736040156, 0.10926360453595407, 0.024268134402518626, 0.07417644315864891, 0.15551306772977114, 0.1775293386890553, 3.8939543394371867, 33.79839979112148, 46.59675523638725, 51.939492747187614, 21.919093430042267, 41.53577260673046, 19.630297645926476, 6.518620988354087, 45.02520516514778, 57.294868379831314, 67.25053176283836, 61.479439437389374, 56.51712991297245, 59.2598607391119, 31.009769327938557, 0.32125019934028387, 1.3353174598887563, 0.6272300274576992, 28.353223577141762, 20.31968515366316, 35.48064172267914, 71.46477162837982, 65.43495878577232, 72.08970129489899, 64.965790361166, 63.75696882605553, 61.25927925109863, 64.50276240706444, 61.96500018239021, 63.090735375881195, 63.5292736440897, 64.33943197131157, 58.637530133128166, 59.512999355793, 49.783887416124344, 60.21790713071823, 68.08728486299515, 49.85049784183502, 62.18102239072323, 56.78212009370327, 62.27906093001366, 60.57924494147301, 57.602708861231804, 56.395897418260574, 58.646448254585266, 56.38688050210476, 55.45081213116646, 54.211634024977684, 50.97316659986973, 50.04962235689163, 47.983167842030525, 47.27021589875221, 47.392998710274696, 49.17610242962837, 52.82638415694237, 53.68003495037556, 55.28308533132076, 57.221011742949486, 56.61868326365948, 52.63066045939922, 46.36993020772934, 50.804128870368004, 50.78175187110901, 52.36589826643467, 52.92138285934925, 50.435799434781075, 51.68396405875683, 51.94130904972553, 51.1220958083868, 47.16221809387207, 49.1651476174593, 50.22632047533989, 49.76593337953091, 52.071140483021736, 53.498495891690254, 53.13256032764912, 51.89147092401981, 51.440176740288734, 51.70119233429432, 51.18798807263374, 48.49452540278435, 47.12295860052109, 46.41416363418102, 49.82278972864151, 49.98921699821949, 50.93038469552994, 52.11047977209091, 49.930308759212494, 50.37807673215866, 46.155135333538055, 46.77558124065399, 50.25365620851517, 51.481355130672455, 55.72152480483055, 52.88139000535011, 57.28862911462784, 53.4000925719738, 50.6142720580101, 47.71588258445263, 45.79587981104851, 45.58068595826626, 42.22446285188198, 46.616103798151016, 46.775729432702065, 46.73196338117123, 48.396612256765366, 50.13819560408592, 51.80436819791794, 52.17900909483433, 53.16651530563831, 53.29460263252258, 51.98273442685604, 50.842958986759186, 55.423575192689896, 54.88363936543465, 53.38702127337456, 58.50850045681, 54.03456352651119, 61.58190853893757, 54.0883382409811, 48.896065056324005, 52.55699381232262, 58.72015669941902, 54.45862077176571, 54.231571555137634, 59.87104654312134, 60.45347549021244, 59.32217359542847, 60.34405276179314, 63.82085859775543, 60.85397779941559, 62.347240671515465, 58.21011386811733, 21.971460320055485, 2.609203141182661, 3.3913180232048035, 1.8089261837303638, 0.11763560920371674, 1.077003520913422, 45.38350313901901, 52.311363592743874, 53.021826669573784, 55.707336366176605, 50.72376698255539, 62.10757613182068, 50.851645320653915, 16.3184105604887, 35.117419213056564, 21.298983804881573, 34.130973145365715, 25.158769190311432, 37.25771136581898, 42.51847967505455, 5.924605512991548, 0.3487219533417374, 0.08722419341211207, 0.1139516920375172, 0.045824494591215625, 0.04484841454541311, 0.0599905463604955, 0.08989193971501663, 0.0633579412533436, 0.04311613425670657, 0.004943368212479982, 0.049241134693147615, 0.004196819136268459, 0.044944578330614604, 0.09350546417408623, 0.10978631398756988, 0.03317272465210408, 0.04891510179731995, 0.1324873571866192, 0.062189889868022874, 0.0970654129923787, 0.1851464158971794, 0.10792885193950497, 5.284416815266013, 47.32563212513924, 57.178435027599335, 46.5891632437706, 38.512430638074875, 45.627803429961205, 24.838881455361843, 8.382032923400402, 45.34759886562824, 62.8824457526207, 73.94485294818878, 66.79875120520592, 62.880393862724304, 68.09380531311035, 36.839935183525085, 0.24377544410526752, 1.5340264909900725, 1.4604566199705005, 38.431745767593384, 25.160463899374008, 40.1000652462244, 73.86605277657509, 68.76462891697884, 72.29318797588348, 67.00726121664047, 65.04379257559776, 64.8062065243721, 65.95500648021698, 65.60484766960144, 64.09010455012321, 64.56665977835655, 66.21083155274391, 57.98397280275822, 57.209897339344025, 51.516925022006035, 59.86990660429001, 65.30388101935387, 51.78516402840614, 62.781420573592186, 59.44613054394722, 64.59483906626701, 63.87786313891411, 59.861414059996605, 58.351751267910004, 62.81270049512386, 60.446825847029686, 57.27554641664028, 54.98124472796917, 53.7128271907568, 52.77010537683964, 50.23809224367142, 49.47268791496754, 50.39751648902893, 51.13242365419865, 53.96246999502182, 57.27225199341774, 57.37605482339859, 58.668699860572815, 57.74386748671532, 56.36662758886814, 50.76442860066891, 53.289237320423126, 52.80183747410774, 53.11231501400471, 54.23216052353382, 54.29774880409241, 54.58948954939842, 54.204243421554565, 52.63045147061348, 49.904310554265976, 51.862144097685814, 54.96559716761112, 54.314201921224594, 56.70777328312397, 56.523718759417534, 59.06112760305405, 54.90527160465717, 55.58717541396618, 55.768486484885216, 55.305314138531685, 53.3636449277401, 52.67255321145058, 50.643329098820686, 52.76620298624039, 52.231822460889816, 54.47868749499321, 55.157118290662766, 54.97221261262894, 53.61135743558407, 49.02968488633633, 48.646312057971954, 52.089877277612686, 53.92631873488426, 58.358492106199265, 56.03622391819954, 59.26038131117821, 57.81317576766014, 54.03365537524223, 50.40685638785362, 48.98447871208191, 49.610460922122, 45.429716259241104, 49.31199453771114, 48.12010869383812, 49.62076596915722, 49.86991859972477, 53.66161733865738, 54.57484893500805, 56.33134268224239, 54.00702640414238, 55.09177319705486, 54.54415038228035, 53.319635689258575, 55.760639905929565, 55.02765163779259, 56.890429481863976, 60.45369207859039, 57.42913797497749, 63.843558579683304, 55.61710640788078, 49.519094824790955, 54.189314022660255, 61.841202825307846, 57.35273167490959, 56.04654796421528, 60.7191876322031, 64.01004284620285, 62.88962736725807, 62.434749975800514, 66.10640555620193, 65.31089544296265, 60.9168454259634, 60.05967602133751, 23.292824216187, 4.392297361046076, 5.730153797194362, 3.2830129098147154, 0.17196459666593, 1.628501177765429, 52.44160160422325, 57.82644845545292, 58.466360718011856, 62.63819485902786, 56.49105191230774, 69.44970175623894, 53.90936404466629, 22.058367356657982, 42.91441462934017, 24.499280378222466, 43.20955619215965, 25.35762581974268, 44.01862017810345, 51.76998384296894, 5.528128137812018, 0.20996527397073805, 0.18435470759868622, 0.09181731569697149, 0.07226147208712064, 0.029201468314568046, 0.06200084259035066, 0.027799473427876364, 0.08793742701527663, 0.08384084605495445, 0.16606695688096806, 0.17954643670236692, 0.1253766770241782, 0.1539425941882655, 0.21968025423120707, 0.18554520152974874, 0.17970972403418273, 0.19739961542654783, 0.2624909835867584, 0.1704483592766337, 0.18118257547030225, 0.46833695203531533, 0.3465814213268459, 11.796038579195738, 69.25163358449936, 76.50776982307434, 63.745991215109825, 39.060916006565094, 61.85922525823116, 26.46310430020094, 11.029653903096914, 58.14332865178585, 68.57574105262756, 79.48013752698898, 71.11656591296196, 66.09873756766319, 70.7816594839096, 38.94507922232151, 0.25406864646356553, 3.271482428535819, 2.557281064800918, 40.56476131081581, 31.119203455746174, 46.34062238037586, 73.09531733393669, 73.44953432679176, 74.98141452670097, 70.2105501294136, 66.48628637194633, 68.36847737431526, 67.2069177031517, 67.02772691845894, 67.04440802335739, 67.95135095715523, 68.32468092441559, 60.43780893087387, 56.92110903561115, 53.94342161715031, 58.83437097072601, 66.35156080126762, 51.233000457286835, 66.2452045083046, 62.668863013386726, 67.19831496477127, 67.44818955659866, 62.83140309154987, 63.435946851968765, 66.57814264297485, 62.113541811704636, 61.7049041390419, 58.27027224004269, 57.136150896549225, 56.26201920211315, 51.646805852651596, 52.39500850439072, 53.67308512330055, 54.38782297074795, 58.06161783635616, 59.22910898923874, 60.601777732372284, 62.80499450862408, 64.25658881664276, 58.34852144122124, 52.96345800161362, 55.77546291053295, 54.905564188957214, 56.10315352678299, 59.53193373978138, 56.29958018660545, 57.62897305190563, 56.938800886273384, 56.4134980738163, 53.789761662483215, 53.876902386546135, 59.71401236951351, 58.02373006939888, 60.65680257976055, 58.99743542075157, 62.45368055999279, 56.7878881841898, 58.733201399445534, 58.64864073693752, 59.4000618159771, 56.061861142516136, 54.55833502113819, 54.180240109562874, 57.31507949531078, 56.7968975007534, 57.29895696043968, 61.00308179855347, 57.18987241387367, 56.52073971927166, 51.20822198688984, 53.32901358604431, 55.70531867444515, 56.61408171057701, 60.00956051051617, 59.978576973080635, 62.33971707522869, 61.24944917857647, 54.99871999025345, 54.14626993238926, 50.05713455379009, 52.104540690779686, 47.38894432783127, 55.385569632053375, 50.653155371546745, 51.96301728487015, 51.176060512661934, 55.360623970627785, 55.64396716654301, 58.93497057259083, 57.283267602324486, 56.93945825099945, 55.88130623102188, 54.69439432024956, 58.28392870724201, 58.021324798464775, 57.7042356133461, 62.983049154281616, 57.578682750463486, 65.23271843791008, 55.53750827908516, 50.478847324848175, 55.82068808376789, 64.14319530129433, 60.6202295422554, 58.925372287631035, 63.0216208845377, 66.44877478480339, 64.0109471976757, 64.7685657441616, 68.60963523387909, 65.49879536032677, 64.17727947235107, 63.311537727713585, 32.37009443342686, 4.608847266063094, 6.238485770300031, 5.174517687410116, 0.37505228421650827, 1.3681176560930908, 55.54240621626377, 64.77143079042435, 60.761714950203896, 67.71255657076836, 59.11726579070091, 73.95059064030647, 60.749863386154175, 26.055600866675377, 42.18997210264206, 32.01836630702019, 50.220142006874084, 36.58399611711502, 52.10722714662552, 64.81450527906418, 14.90668086335063, 0.7862114778254181, 0.3746809432050213, 0.48098297032993287, 0.17099601973313838, 0.13766337709967047, 0.17575915320776403, 0.19261173874838278, 0.17056514363503084, 0.24463586043566465], [0.06499422845081426, 0.026670420047594234, 0.06513654268928804, 0.04040714309667237, 0.0066843858985521365, 0.10066032438771799, 0.03440370273892768, 0.1417377233156003, 0.03713054255058523, 0.04700888064689934, 0.06964522341149859, 0.04466714868613053, 0.02248345106636407, 1.8500683573074639, 25.858934819698334, 42.55152650177479, 37.42234893143177, 21.18483792990446, 35.35299137234688, 47.42699548602104, 5.716849286109209, 29.873109720647335, 56.41687609255314, 65.49560353159904, 64.84469085931778, 57.54590950906277, 53.04925359785557, 46.11427992582321, 1.8048571958206594, 0.589924044907093, 0.5401955789420754, 27.21470396965742, 13.43103289604187, 7.513458430767059, 54.171082600951195, 70.52873745560646, 68.89530390501022, 64.46522802114487, 65.10988622903824, 61.663402765989304, 65.54215863347054, 64.92652326822281, 66.78675904870033, 63.52013133466244, 58.96656967699528, 56.32046766579151, 55.73712296783924, 57.5017748773098, 51.72369472682476, 61.39006443321705, 56.83199241757393, 58.23708102107048, 62.49453216791153, 59.105862602591515, 59.73969519138336, 57.16896213591099, 55.98192483186722, 56.618595868349075, 57.34230123460293, 57.87943281233311, 56.70502983033657, 52.73815669119358, 49.968306720256805, 49.93382357060909, 47.09770515561104, 46.506931856274605, 46.765002608299255, 51.451796516776085, 51.36644549667835, 55.378984585404396, 51.881276071071625, 52.75733806192875, 45.959115251898766, 47.320897579193115, 49.6361019462347, 49.64937463402748, 49.85886499285698, 53.10880780220032, 49.093293473124504, 49.433823600411415, 48.149097338318825, 46.516286954283714, 47.24373511970043, 50.40542006492615, 49.01483528316021, 52.762505784630775, 52.73503325879574, 52.82541520893574, 50.51629811525345, 53.44844877719879, 53.77027630805969, 52.503811866045, 50.266928896307945, 49.912062138319016, 46.43097773194313, 47.58226275444031, 45.05444459617138, 48.492636904120445, 48.491306975483894, 48.76693658530712, 48.69695954024792, 51.18768788874149, 48.090006709098816, 46.59848414361477, 44.73187990486622, 49.00017186999321, 51.72108806669712, 54.21809747815132, 53.16266231238842, 53.398185074329376, 48.6597291380167, 46.70032627880573, 43.406051248312, 41.34934701025486, 44.35327582061291, 45.495274141430855, 47.367315888404846, 47.0789797604084, 51.47579982876778, 55.92496208846569, 55.96900172531605, 54.07877415418625, 54.718823209404945, 55.195424035191536, 50.55632136762142, 58.092935755848885, 53.47378961741924, 58.97085204720497, 52.72478900849819, 58.31751890480518, 57.3418490588665, 59.52095612883568, 52.43434019386768, 51.281820237636566, 51.24216936528683, 56.68613724410534, 57.67192214727402, 54.25724297761917, 55.897516161203384, 60.190263614058495, 58.17264787852764, 64.20831620693207, 57.73700885474682, 63.95300030708313, 52.7169918268919, 33.11772711575031, 2.8252027882263064, 12.337085846811533, 7.849164716899395, 1.1252666311338544, 0.21759863389888778, 15.83486370742321, 59.07238259911537, 50.790392607450485, 56.06629930436611, 53.12068596482277, 58.80868434906006, 64.75507646799088, 19.625614397227764, 17.74924848228693, 38.20206709206104, 26.666513085365295, 36.719675436615944, 29.863900914788246, 47.20111280679703, 38.40737007558346, 1.3463062327355146, 0.08008822827832773, 0.09939878465957008, 0.09942795848473907, 0.0812857280834578, 0.05211893476371188, 0.07965623153722845, 0.039185334244393744, 0.06920412793988362, 0.04376577322545927, 0.10305994015652686, 0.12117678168579005, 0.059870377808692865, 0.060537520330399275, 0.06295283994404599, 0.16196197480894625, 0.016871803454705514, 0.16033205523854122, 0.04042607899464201, 0.12232787499669939, 0.05638471797283273, 0.19544398208381608, 0.04597633800585754, 2.403642483986914, 34.932426139712334, 58.091906011104584, 36.997581124305725, 27.246882542967796, 44.536311998963356, 50.87742693722248, 8.143027648329735, 28.38356874883175, 58.540783524513245, 71.50875806808472, 69.77600544691086, 63.28984849154949, 56.642922163009644, 52.757695242762566, 1.9779081037268043, 0.7533167616929859, 0.47032005968503654, 32.344214022159576, 22.13387120515108, 10.559183098375797, 58.46722327172756, 72.105493247509, 71.31969541311264, 66.00142478942871, 67.64132559299469, 65.33984988927841, 66.02180689573288, 68.34425747394562, 69.77743417024612, 66.67205840349197, 60.55993817746639, 57.947483360767365, 56.94003961980343, 58.24671730399132, 55.61201848089695, 61.75459027290344, 57.14251555502415, 60.601135566830635, 64.917943328619, 61.51480793952942, 62.926538586616516, 60.85530012845993, 59.02842275798321, 58.40606555342674, 59.64875467121601, 61.93981893360615, 59.53574113547802, 55.87260849773884, 52.07221582531929, 52.315653562545776, 49.009918347001076, 47.778571620583534, 47.4632303416729, 52.536334320902824, 53.51433344185352, 57.327052652835846, 53.55401091277599, 56.558148711919785, 48.693235740065575, 50.116494968533516, 52.19804227352142, 52.77437634766102, 52.795263826847076, 54.55855920910835, 52.68944330513477, 53.03802140057087, 51.62760928273201, 48.68841379880905, 49.088748916983604, 52.44763568043709, 55.06211958825588, 56.73765867948532, 55.926174223423004, 55.30149154365063, 56.100087091326714, 54.51434098184109, 56.7450986802578, 54.91452030837536, 55.001273453235626, 52.782443314790726, 50.70629931986332, 51.263520419597626, 49.35699552297592, 51.86386160552502, 53.07760767638683, 52.398926094174385, 51.430745646357536, 54.237548634409904, 50.888381749391556, 49.580605924129486, 48.69662515819073, 51.79431013762951, 54.65563639998436, 56.213305816054344, 55.561207607388496, 57.106592282652855, 50.00284306704998, 48.77958230674267, 45.284659042954445, 44.58196274936199, 46.20346873998642, 47.904386669397354, 48.79093989729881, 48.969347923994064, 52.467956990003586, 56.89694233238697, 59.43593569099903, 56.526876389980316, 55.38411810994148, 57.503313794732094, 52.78757683932781, 57.75516428053379, 54.22743357717991, 60.33286236226559, 55.01992665231228, 61.53181202709675, 57.86277450621128, 61.17619290947914, 50.65112628042698, 49.44455802440643, 51.99542194604874, 58.26378978788853, 59.54374350607395, 58.120222091674805, 55.69284774363041, 63.08154746890068, 60.447407215833664, 68.21212336421013, 59.8964823782444, 65.52450478076935, 52.860966101288795, 41.26849114894867, 5.469254096969962, 16.308757178485394, 8.047722112387419, 2.138026049360633, 0.3193724766606465, 20.29254510998726, 64.12204563617706, 57.08419248461723, 62.00054347515106, 60.25338962674141, 66.76937878131866, 69.77602824568748, 20.18912985920906, 30.641726776957512, 39.084953516721725, 30.53057324141264, 45.7900433242321, 30.9031318500638, 57.8149388730526, 44.04029041528702, 2.229460305534303, 0.11107801459729671, 0.14858031005132943, 0.08633077377453446, 0.06221259958692826, 0.06011810670315754, 0.0647783228487242, 0.07827146560885012, 0.0586611038306728, 0.07324709615204483, 0.19899848353816196, 0.21027877199230716, 0.18523603765061125, 0.20810460584471002, 0.1468522340292111, 0.16221552214119583, 0.1084310187434312, 0.3534275555284694, 0.16440508043160662, 0.24923572142142802, 0.24535807402571663, 0.5092385807074606, 0.18419829255435616, 3.8041929434984922, 51.28989860415459, 76.33758455514908, 55.10922946035862, 30.53876370191574, 59.56390902400017, 59.7494150698185, 10.510531459003687, 37.52890281379223, 72.28185698390007, 74.85393896698952, 74.46336552500725, 65.21514818072319, 64.62637737393379, 56.808562874794006, 2.756928764283657, 1.2092123203910887, 1.1798261222429574, 43.32148298621178, 31.761691980063915, 17.53854598850012, 62.06217996776104, 69.27089855074883, 74.8911465704441, 66.85388624668121, 71.32843494415283, 64.24170881509781, 70.55500164628029, 69.23055231571198, 73.89559999108315, 66.81072816252708, 62.4764983355999, 56.196301728487015, 59.87454995512962, 57.46274717152119, 57.122954204678535, 60.85050858557224, 57.217614725232124, 62.50718168914318, 68.12098905444145, 65.94112202525139, 67.76219710707664, 63.04281994700432, 61.254898086190224, 60.72801075875759, 62.60009050369263, 64.10154953598976, 62.76090927422047, 57.48622611165047, 56.04263797402382, 54.10903953015804, 51.9899046421051, 50.7408432662487, 51.007797941565514, 54.622927755117416, 56.2912168353796, 59.86798010766506, 55.77504113316536, 60.35425901412964, 52.37596772611141, 54.09250281751156, 54.0752137452364, 56.727646216750145, 53.174688667058945, 58.41571323573589, 53.82970131933689, 55.76217122375965, 52.18900255858898, 53.13488960266113, 50.927603244781494, 58.118721172213554, 57.88525030016899, 61.18963658809662, 59.4380521774292, 59.4649775326252, 57.933515310287476, 58.59394647181034, 60.60185752809048, 59.03143599629402, 59.428434893488884, 57.246975749731064, 53.90140727162361, 54.331696182489395, 52.52790257334709, 56.725012958049774, 55.4388427734375, 54.49615515768528, 52.67871268093586, 57.138723358511925, 52.466368675231934, 53.9426426589489, 50.19846796989441, 54.77074362337589, 57.14131861925125, 59.37415100634098, 58.13836611807346, 59.8053290694952, 51.281767040491104, 52.29587942361832, 47.60410398244858, 45.85811287164688, 48.14253889024258, 53.20608638226986, 51.075928285717964, 51.804398596286774, 56.26718312501907, 58.99458937346935, 61.825536265969276, 59.399495646357536, 57.71047107875347, 61.4824602752924, 52.88793705403805, 62.29438170790672, 56.123524233698845, 64.95975628495216, 55.42994365096092, 64.44607704877853, 59.67474527657032, 64.00687381625175, 52.124596014618874, 50.97530968487263, 52.06737868487835, 61.15821987390518, 60.09956248104572, 60.56160628795624, 58.094676062464714, 63.39728772640228, 63.54589395225048, 69.1536596417427, 62.204565927386284, 71.01994469761848, 55.352674797177315, 49.2084576934576, 7.522003697231412, 16.98689728975296, 11.471617687493563, 5.433197356760502, 0.4606211988721043, 20.88444124907255, 70.52123665809631, 61.94390371441841, 67.9917123913765, 64.49050426483154, 68.78197878599167, 77.15463951230049, 26.513411700725555, 26.937531642615795, 44.46516081690788, 41.19505248963833, 52.7512925863266, 41.94558821618557, 63.69997188448906, 59.738000482320786, 4.63568807579577, 0.5656044592615217, 0.33212865935638547, 0.3075287793762982, 0.2335825504269451, 0.27133548399433494, 0.16072931204689667, 0.24948377686087042, 0.1990711101097986, 0.1770216503064148], [0.0895636655332055, 0.08177695563063025, 0.022807326167821884, 0.06010397621139418, 0.015172288058238337, 0.05221369217906613, 0.03872033419611398, 0.1176158309681341, 0.10256102395942435, 0.05990170386212412, 0.032636986798024736, 0.023378718651656527, 0.25211742147803307, 0.42504620156250894, 13.1328353472054, 44.551944360136986, 35.90314105153084, 45.18754005432129, 27.426890283823013, 72.3594868183136, 12.997691798955202, 11.277009230107069, 58.55008542537689, 58.17589670419693, 63.53125333786011, 63.81784915924072, 55.32891467213631, 57.05524563789368, 12.971695493906736, 0.41685188189148903, 0.28540060739032924, 2.9835934890434146, 15.78424472361803, 4.574683299288154, 31.75956789404154, 53.330157324671745, 70.02635881304741, 62.61359117925167, 68.0604051053524, 66.07997417449951, 69.3619492650032, 64.52934578061104, 63.55813309550285, 54.45294767618179, 56.559288650751114, 59.93637263774872, 55.730891302227974, 60.983452051877975, 49.63902398943901, 50.94637803733349, 62.71400839090347, 59.15213651955128, 62.325289249420166, 58.35694558918476, 60.960710272192955, 57.96596556901932, 58.56691852211952, 58.5302808880806, 62.00243577361107, 60.19502095878124, 57.39988714456558, 55.953160375356674, 52.03014828264713, 51.03769093751907, 48.447848707437515, 46.770508512854576, 46.48528441786766, 46.20779290795326, 47.50608064234257, 54.063601568341255, 46.6706308722496, 45.81815041601658, 44.909315183758736, 48.6286886036396, 47.856813222169876, 53.163627460598946, 48.49930554628372, 50.98202772438526, 46.28326825797558, 45.99871672689915, 45.78720487654209, 45.11522613465786, 46.19437962770462, 50.95380663871765, 51.60635702311993, 52.17925988137722, 49.67360973358154, 54.32025119662285, 50.04774905741215, 51.546483635902405, 52.416032776236534, 54.122091829776764, 50.15390396118164, 49.67093847692013, 48.37967276573181, 46.99418731033802, 43.539291098713875, 45.08064419031143, 45.84716185927391, 50.39327971637249, 49.18212130665779, 50.554961040616035, 49.36826951801777, 45.5944450199604, 42.794192880392075, 43.15292403101921, 49.18940931558609, 51.37105084955692, 48.65097440779209, 49.914026632905006, 46.06208972632885, 45.5305590480566, 42.488195300102234, 42.066151946783066, 44.076912850141525, 44.51702043414116, 45.966232270002365, 53.548721596598625, 55.560649037361145, 52.84869275987148, 60.40890768170357, 54.585959538817406, 56.05820953845978, 55.56938476860523, 54.68135342001915, 55.67173607647419, 54.634418338537216, 53.80088746547699, 55.26916667819023, 55.74241228401661, 59.06102500855923, 55.430160239338875, 52.655701115727425, 49.002440348267555, 53.214065954089165, 50.915804877877235, 57.26449280977249, 53.410994186997414, 55.329522639513016, 56.66798561811447, 55.862649232149124, 58.35951045155525, 60.394122675061226, 48.002014830708504, 31.132666133344173, 8.409756235778332, 12.263192161917686, 12.569310385733843, 1.670538797043264, 0.673933558864519, 1.4698814204894006, 47.89318107068539, 53.57034623622894, 55.437543243169785, 54.540836960077286, 62.85727210342884, 53.09723362326622, 35.29687978327274, 5.614775363355875, 42.04683378338814, 32.59132236242294, 32.389644384384155, 27.01273150742054, 28.307865411043167, 52.11337901651859, 20.60337223112583, 0.2706839080201462, 0.049520798202138394, 0.15571089461445808, 0.05817189121444244, 0.044405563894542865, 0.005010092390875798, 0.09677588634076528, 0.06593700833036564, 0.03797538120124955, 0.023410783142026048, 0.02519424193451414, 0.01692008758254815, 0.07600269047543406, 0.1450665228185244, 0.10045589981018566, 0.05105403448396828, 0.05760416308476124, 0.18974402075400576, 0.017038499099726323, 0.2312179046566598, 0.048294740554410964, 0.0891323367250152, 0.30532566946931183, 0.6222368578892201, 16.170653589069843, 62.85263255238533, 41.12698674201965, 41.962888687849045, 41.343005150556564, 69.2810820043087, 19.075605310499668, 14.238538965582848, 60.40275581181049, 65.8119897544384, 68.70352819561958, 70.45265033841133, 57.453699856996536, 64.11312371492386, 14.382022116333246, 0.4328428488224745, 0.37220377300400287, 2.274833433330059, 16.609226055443287, 11.41256220638752, 35.39540849626064, 55.160488709807396, 70.41404440999031, 64.3767611682415, 73.0660893023014, 66.29819646477699, 69.30647224187851, 63.924251049757004, 64.41338360309601, 55.47846704721451, 57.85979546606541, 59.39993642270565, 58.72823126614094, 60.92785343527794, 50.696176663041115, 55.24498097598553, 62.38042049109936, 62.33210228383541, 61.97959519922733, 61.22791953384876, 63.39778169989586, 59.92946840822697, 60.60575991868973, 63.54784704744816, 64.17109340429306, 62.055591121315956, 58.80204610526562, 57.00867533683777, 55.31275033950806, 52.52475634217262, 51.49105980992317, 48.09138983488083, 48.64455655217171, 48.17631907761097, 51.25022113323212, 54.39924895763397, 49.883685261011124, 49.19758267700672, 48.134160339832306, 50.25846295058727, 49.94595631957054, 55.51406733691692, 51.17342345416546, 53.65628242492676, 49.96848151087761, 48.93613010644913, 50.03802917897701, 49.268939048051834, 50.49759551882744, 54.67875435948372, 54.79139171540737, 56.579887345433235, 54.593745321035385, 57.06296682357788, 53.1502977758646, 55.94578497111797, 57.838535606861115, 57.94348977506161, 51.70767478644848, 52.86670379340649, 52.042592614889145, 51.069172248244286, 48.44013512134552, 48.7738636136055, 50.64353808760643, 53.466664999723434, 52.570825070142746, 53.70260573923588, 52.71552890539169, 47.75299519300461, 45.98877266049385, 44.884464517235756, 52.12587654590607, 54.16085734963417, 52.401859536767006, 52.8969881683588, 49.15703125298023, 47.58350148797035, 45.089634507894516, 44.25003156065941, 45.48593804240227, 48.43101941049099, 49.53373163938522, 54.09765914082527, 57.89879657328129, 55.899454057216644, 59.20744255185127, 57.1440164744854, 57.5519397854805, 57.25629284977913, 55.92083550989628, 58.70177708566189, 56.109958961606026, 56.740345135331154, 56.42005652189255, 57.05035150051117, 61.39840118587017, 58.050849214196205, 52.37328127026558, 49.572671949863434, 53.61580319702625, 54.471042305231094, 59.11533169448376, 57.397060096263885, 56.29917360842228, 56.931889057159424, 58.299606665968895, 59.85852621495724, 59.27085354924202, 50.45496180653572, 38.46619091928005, 8.170179091393948, 17.474950700998306, 12.483758926391602, 2.255896436981857, 1.0029795742593706, 2.36890712287277, 59.60454024374485, 56.520006358623505, 63.02524209022522, 59.034114852547646, 73.07797506451607, 58.43002326786518, 41.573344990611076, 9.066029470413923, 51.48966148495674, 31.818736419081688, 37.483271062374115, 35.4964716732502, 32.13177502155304, 61.12825468182564, 21.61962389945984, 0.5531980062369257, 0.07103021940565668, 0.06570501296664588, 0.03480311919702217, 0.033144248445751145, 0.03854133559798356, 0.06745975435478613, 0.009495699741819408, 0.01690154502284713, 0.044629317708313465, 0.14115197584033012, 0.22039584786398336, 0.1726689244969748, 0.16132899705553427, 0.2431492050527595, 0.13459281530231237, 0.271940334350802, 0.39699195069260895, 0.1892739295726642, 0.27915911574382335, 0.1785665049101226, 0.2416951151099056, 0.5847630905918777, 1.1978420242667198, 30.84668777883053, 76.0629352927208, 61.144529208540916, 56.40248626470566, 53.086708188056946, 88.35730478167534, 22.379638217389584, 17.142745926976204, 73.77260819077492, 72.12668851017952, 72.30346262454987, 73.10104742646217, 64.12974402308464, 72.12060123682022, 16.965671628713608, 0.9877312299795449, 0.46586684708017856, 3.8362653600052, 22.190186083316803, 22.173525877296925, 43.64671893417835, 57.01895758509636, 73.24249863624573, 67.15467810630798, 74.03416335582733, 68.2577133178711, 72.29849249124527, 64.87831145524979, 66.34490355849266, 56.14139847457409, 59.93602305650711, 59.9781209975481, 57.695887461304665, 58.771936520934105, 53.54479640722275, 55.1852747797966, 61.72036170959473, 66.04659676551819, 65.97839042544365, 63.430440947413445, 68.03490087389946, 63.10558497905731, 64.90598917007446, 63.503184244036674, 69.39708977937698, 63.99172022938728, 62.22136102616787, 58.93821559846401, 59.66858200728893, 54.36600834131241, 53.29257354140282, 50.56569546461105, 51.11637331545353, 48.98483969271183, 52.73067869246006, 58.37732009589672, 52.338000163435936, 51.17039881646633, 49.67440769076347, 53.35834041237831, 53.706135749816895, 59.141269102692604, 52.470863834023476, 58.21246214210987, 51.42783500254154, 51.03924125432968, 52.801658883690834, 54.18819308280945, 52.57367491722107, 59.30874511599541, 58.34417067468166, 60.3798658400774, 54.73450496792793, 60.18428273499012, 54.28503468632698, 58.248636201024055, 59.96841251850128, 63.5806430876255, 57.65757031738758, 56.94333404302597, 56.51413567364216, 53.12008559703827, 51.226244419813156, 50.254313573241234, 51.591830402612686, 58.81962016224861, 55.49553953111172, 57.10229091346264, 55.11269487440586, 52.83130869269371, 48.82878206670284, 46.79512359201908, 55.053889229893684, 55.45402675867081, 54.774433225393295, 55.1262791454792, 52.26510867476463, 50.47752499580383, 47.07010343670845, 46.08371816575527, 50.28459794819355, 49.73140463232994, 53.12850594520569, 58.27308028936386, 61.39443039894104, 59.01492968201637, 64.07032281160355, 57.14536540210247, 59.34864677488804, 60.24919085204601, 58.61779399216175, 59.269314631819725, 58.32691200077534, 59.57642175257206, 58.247237876057625, 58.662996366620064, 62.46072918176651, 59.762524366378784, 54.386295452713966, 49.57963317632675, 55.463286861777306, 54.41125251352787, 61.26986928284168, 56.7278666049242, 60.4940003156662, 56.711485683918, 57.82389499247074, 60.937428921461105, 63.55629779398441, 52.85914219915867, 46.83498725295067, 15.784168727695942, 17.27088075131178, 19.069556035101414, 4.130954509600997, 1.781323633622378, 1.416924730874598, 64.49514001607895, 60.74382171034813, 68.5118056833744, 61.9516970962286, 74.84169602394104, 62.07244321703911, 48.994335383176804, 9.092602394521236, 53.4574580937624, 40.547210052609444, 48.93431760370731, 38.80887933075428, 43.87813791632652, 70.94926089048386, 40.160231217741966, 0.8401817630510777, 0.247416524507571, 0.32424408243969083, 0.211419616243802, 0.25950027687940747, 0.10877812863327563, 0.25615749531425536, 0.22824812651379034, 0.2055717894108966, 0.18240735662402585], [0.03786186600336805, 0.015589324029861018, 0.03645305820100475, 0.022067863210395444, 0.07256032011355273, 0.13271258416352794, 0.06483722710981965, 0.025528392070555128, 0.03653279825812206, 0.11520392523379996, 0.11800076812505722, 0.09910369932185858, 0.22771857446059585, 0.1565387603477575, 5.014466000720859, 42.14937128126621, 40.76792120933533, 40.90300016105175, 25.19529853016138, 48.4607870131731, 47.67259530723095, 9.197375122457743, 39.199422374367714, 60.086194798350334, 63.54948475956917, 63.296437337994576, 58.81042845547199, 55.07772535085678, 47.6456243544817, 2.5799375865608454, 0.3729726083111018, 1.2888455973006785, 4.929230874404311, 4.864420127123594, 27.516707964241505, 33.04869621992111, 58.638540878891945, 63.10456283390522, 64.81175422668457, 65.96769779920578, 59.513493329286575, 54.05616536736488, 56.00421443581581, 58.254586681723595, 61.67503394186497, 61.27135120332241, 60.74687294661999, 57.07647889852524, 60.691646710038185, 50.43122448027134, 58.4477911144495, 60.884991735219955, 61.50322616100311, 56.64907403290272, 59.94448520243168, 56.59058377146721, 56.835066452622414, 58.106520026922226, 59.192402958869934, 59.839770421385765, 60.494296699762344, 59.72526356577873, 54.18024390935898, 49.64438170194626, 51.40192039310932, 46.24840512871742, 45.27738243341446, 46.61511965095997, 45.59354066848755, 44.1599839925766, 44.64726984500885, 42.50877879559994, 43.95916476845741, 46.40100874006748, 51.203947216272354, 47.59642459452152, 48.17071057856083, 46.857580840587616, 47.04519957304001, 43.12592647969723, 45.60126185417175, 44.00848992168903, 48.589303717017174, 50.932611376047134, 55.1141007989645, 51.22623682022095, 38.54080751538277, 45.54200403392315, 48.65567855536938, 51.09894745051861, 51.32800295948982, 52.873167246580124, 52.68067717552185, 52.75080621242523, 49.45298597216606, 47.10455238819122, 43.127742782235146, 43.72183330357075, 48.41797851026058, 48.64910110831261, 46.504583582282066, 48.08892376720905, 48.62785264849663, 46.25210992991924, 43.17851945757866, 38.47191721200943, 41.85714416205883, 45.29065132141113, 47.93215557932854, 45.18146798014641, 44.49845843017101, 43.43629002571106, 45.0275344401598, 42.10710234940052, 43.914258778095245, 46.66126437485218, 51.22707277536392, 54.72438231110573, 57.13455118238926, 54.68460984528065, 55.695845782756805, 53.679047003388405, 56.88111238181591, 55.74685424566269, 55.90006582438946, 56.28205552697182, 57.51662828028202, 54.56856407225132, 54.774733409285545, 55.172777250409126, 57.79252387583256, 54.74581316113472, 49.87356260418892, 46.736283749341965, 50.913369208574295, 47.97870688140392, 54.758078902959824, 59.86685536801815, 50.752326250076294, 50.503922179341316, 53.00815500319004, 53.49965862929821, 42.838517501950264, 30.43059680610895, 12.350588422268629, 14.901264254003763, 17.751344069838524, 1.365356391761452, 0.5977167736273259, 1.083760152105242, 34.37684275209904, 53.19568254053593, 55.64502350986004, 54.52716529369354, 60.73478579521179, 38.35787013173103, 50.183705762028694, 23.801867701113224, 10.372443068772554, 52.21887655556202, 32.117715775966644, 38.01707781851292, 25.19128404557705, 32.75226652622223, 43.8267532736063, 5.780683485791087, 0.6060180219355971, 0.045572130984510295, 0.04052493677590974, 0.012693372882495169, 0.05237443394435104, 0.031075285442057066, 0.0697576958918944, 0.04706995940068737, 0.020613348387996666, 0.07364428616710939, 0.04081568797118962, 0.03696820516779553, 0.04995133291231468, 0.02131105626176577, 0.057873941186699085, 0.12058619540766813, 0.13709627237403765, 0.11023584767826833, 0.0636923307320103, 0.10619642693200149, 0.06970633927267045, 0.09413542138645425, 0.25169012253172696, 0.08003822978935204, 7.995892893522978, 54.62345212697983, 51.413524970412254, 39.38029266893864, 35.64951606094837, 54.6327768266201, 56.1282853782177, 12.219282668083906, 43.535749688744545, 67.2455008327961, 69.64875787496567, 69.13982838392258, 64.89674806594849, 57.64728806912899, 53.85881915688515, 2.530682967044413, 0.4804609436541796, 1.4606086118146777, 4.2718547489494085, 4.032597737386823, 34.8197165876627, 39.346067905426025, 59.56259049475193, 63.02475571632385, 65.72893381118774, 66.12842157483101, 60.54854638874531, 55.84863938391209, 55.64397856593132, 60.560017973184586, 60.668399557471275, 61.086833104491234, 61.2442434579134, 57.245809212327, 59.76315513253212, 55.01255884766579, 60.86958356201649, 61.959410682320595, 64.58578035235405, 60.06957449018955, 63.50512973964214, 59.74156469106674, 59.45740833878517, 58.85063409805298, 60.4988032579422, 62.43870556354523, 62.331874296069145, 62.702210023999214, 54.995528161525726, 52.16187201440334, 52.9080493748188, 48.786558732390404, 48.376838117837906, 47.168559953570366, 46.89228817820549, 46.820483431220055, 47.452157735824585, 44.33676950633526, 46.86153642833233, 47.231963351368904, 53.59650403261185, 50.65975941717625, 49.36030514538288, 49.77461211383343, 50.797167643904686, 48.171196952462196, 49.48505625128746, 47.5085087120533, 51.97451166808605, 54.61651749908924, 59.936988204717636, 54.75127726793289, 44.7762843221426, 52.061124220490456, 51.69168144464493, 54.488802552223206, 57.05874145030975, 58.93762283027172, 57.08359971642494, 54.66613903641701, 53.47296506166458, 51.11979693174362, 46.430339366197586, 47.06948406994343, 49.8690028488636, 51.14407382905483, 50.868717804551125, 51.13865911960602, 52.17510290443897, 48.13508369028568, 44.121537655591965, 42.295116260647774, 43.78259964287281, 48.98840010166168, 52.57543422281742, 47.31231763958931, 46.70069105923176, 43.68242561817169, 46.73366568982601, 44.561732634902, 47.014668211340904, 50.522529780864716, 54.70548592507839, 57.89012923836708, 56.87812574207783, 57.58776046335697, 58.02226334810257, 54.787766709923744, 57.68170282244682, 56.28008343279362, 56.590443179011345, 57.518201395869255, 59.86283518373966, 56.977809593081474, 58.10472272336483, 57.1790923923254, 59.37333784997463, 57.03212767839432, 49.592601880431175, 48.617593199014664, 50.02537585794926, 51.21445745229721, 55.26138089597225, 61.64171352982521, 54.46214318275452, 50.85298664867878, 53.14547583460808, 52.86826550960541, 44.49959076941013, 34.460259675979614, 18.745463825762272, 19.454788863658905, 15.685092844069004, 1.9957963563501835, 1.158000212162733, 2.509630434215069, 43.567253798246384, 60.04679471254349, 60.42957477271557, 61.85861349105835, 66.44147917628288, 43.197347447276115, 53.01947459578514, 29.795238599181175, 10.784184224903584, 58.90497498214245, 33.73542197048664, 46.253964230418205, 31.6947490721941, 33.81049834191799, 56.44206874072552, 7.67638323828578, 0.6004051887430251, 0.10615852545015514, 0.04117991549719591, 0.02010145573876798, 0.04286449424398597, 0.02046400786639424, 0.0345019185624551, 0.05392558567109518, 0.05837961463839747, 0.06316605155006982, 0.19590190204326063, 0.12376836879411712, 0.12760265992255881, 0.1497344535891898, 0.2608441578922793, 0.23107772780349478, 0.28740259527694434, 0.24339770578080788, 0.18093049759045243, 0.42844517854973674, 0.32153574808035046, 0.3198829258326441, 0.9738214826211333, 0.8809349325019866, 14.90877265110612, 71.67145773768425, 71.40845105051994, 51.58711865544319, 43.1229018419981, 69.64919865131378, 58.51869910955429, 13.669803533703089, 47.78766833245754, 74.3755142390728, 75.44049829244614, 73.34645345807076, 70.39278075098991, 62.11269065737724, 61.700234189629555, 2.921223873272538, 0.45115994405932724, 2.578734001144767, 5.811923509463668, 12.214716263115406, 48.698012083768845, 44.37445588409901, 62.64770194888115, 67.10825979709625, 66.03318348526955, 65.93285366892815, 63.77552703022957, 56.83138445019722, 59.561119973659515, 61.14675208926201, 61.36886537075043, 62.33707621693611, 62.17999264597893, 59.89175543189049, 58.983759954571724, 56.85491658747196, 58.577356562018394, 62.76537403464317, 69.35745030641556, 61.42116956412792, 68.67692962288857, 61.162699833512306, 61.03161446750164, 62.09715709090233, 62.33205668628216, 65.68564653396606, 65.38315996527672, 67.032241076231, 58.453771993517876, 55.46903595328331, 56.896345764398575, 51.13577887415886, 50.14127343893051, 49.70104806125164, 49.720594212412834, 50.199159532785416, 51.75992578268051, 47.11848244071007, 50.168597772717476, 49.61646839976311, 57.53826431930065, 53.711881041526794, 52.517555728554726, 49.764782041311264, 51.955520287156105, 49.686593636870384, 52.48654939234257, 50.96628896892071, 57.238042429089546, 58.96981470286846, 65.21632611751556, 56.71928286552429, 42.43932992219925, 53.16885218024254, 54.035973250865936, 56.6590066999197, 59.785155951976776, 61.56047008931637, 61.31749592721462, 59.73760910332203, 56.308695897459984, 52.50483401119709, 50.22203430533409, 48.492397516965866, 53.09887893497944, 53.980842009186745, 53.50482635200024, 52.166709154844284, 55.56765206158161, 52.535160183906555, 49.18273687362671, 43.665869906544685, 45.262578427791595, 51.310178115963936, 55.17553590238094, 50.326038524508476, 48.98677758872509, 47.429655343294144, 50.098400339484215, 46.57945856451988, 49.86785911023617, 53.15606586635113, 58.12432587146759, 59.169353395700455, 59.701674431562424, 61.225924640893936, 59.7290101647377, 57.82609507441521, 60.209859162569046, 58.39440017938614, 60.665200129151344, 59.3557333946228, 60.632065907120705, 58.019162714481354, 60.83082564175129, 58.91487345099449, 63.31690303981304, 56.907467767596245, 50.74288375675678, 47.55812644958496, 51.399891301989555, 50.25775998830795, 57.96617455780506, 59.21702183783054, 55.981784239411354, 52.141892686486244, 52.777142599225044, 54.40172262489796, 48.390266597270966, 41.1776190251112, 27.03013077378273, 18.440324999392033, 24.80636280030012, 4.809875953942537, 2.5330402655526996, 2.0122634852305055, 43.35360266268253, 65.92255622148514, 62.980826273560524, 66.76753208041191, 69.63731288909912, 49.244681149721146, 61.490417048335075, 34.9119908362627, 14.588993210345507, 66.25382244586945, 41.8704928457737, 55.30855156481266, 35.58465734124184, 48.64193469285965, 65.41595220565796, 19.308232627809048, 1.4799229754135013, 0.2771547232987359, 0.25674676056951284, 0.197425605438184, 0.18823196907760575, 0.10601032598060556, 0.19106208987068385, 0.1759454025886953, 0.14558111317455769, 0.19936957221943885], [0.04942117600876372, 0.02643742092914181, 0.021702451958844904, 0.02086471937218448, 0.024992663493321743, 0.06589225682546385, 0.04058320279000327, 0.050535622067400254, 0.06672306146356277, 0.05901166841795202, 0.06965944296098314, 0.030344897095346823, 0.15220086264889687, 0.08942400076193735, 2.0734003046527505, 28.73563315719366, 45.09432725608349, 35.97722567617893, 29.07053578644991, 24.602585434913635, 33.77452187240124, 11.763271037489176, 23.978824205696583, 60.4553297907114, 62.03456684947014, 66.94106876850128, 61.176702082157135, 59.35700632631779, 57.746911123394966, 40.11382430791855, 4.612574391067028, 0.12115199395339005, 2.1090670907869935, 1.027834634296596, 11.094237137585878, 37.460023909807205, 42.87930071353912, 58.118591979146004, 58.301681354641914, 54.57459814846516, 62.1680498868227, 59.44000147283077, 64.77269992232323, 65.43337047100067, 65.18305510282516, 64.18748572468758, 64.33790445327759, 62.23760895431042, 61.366342306137085, 53.86491023004055, 54.59067888557911, 63.38259391486645, 59.18955311179161, 63.75166431069374, 58.55135075747967, 60.386070907115936, 60.26146039366722, 60.736564099788666, 52.74819955229759, 50.41042059659958, 61.32403537631035, 59.52520050108433, 57.561199888587, 49.24209728837013, 50.62631741166115, 50.08656017482281, 46.74336276948452, 44.213918298482895, 43.09637166559696, 41.904603615403175, 41.87039025127888, 42.813993617892265, 44.394845589995384, 47.21555583178997, 48.553821220993996, 47.97609642148018, 48.459802865982056, 46.14787012338638, 43.89135740697384, 43.058240711688995, 42.91876919567585, 44.34336595237255, 48.15212197601795, 54.55757886171341, 55.76283618807793, 54.717056304216385, 24.582400918006897, 29.872665144503117, 50.64700350165367, 43.584687262773514, 28.693841099739075, 47.7491308003664, 56.069380939006805, 52.16305375099182, 53.66938032209873, 47.51973330974579, 45.08528754115105, 43.22725564241409, 45.84274649620056, 45.130615308880806, 46.02072134613991, 45.72125181555748, 47.63954848051071, 46.65731258690357, 42.98302374780178, 40.238529816269875, 40.623813942074776, 41.185032427310944, 41.42619788646698, 43.73729087412357, 42.950664684176445, 42.72363066673279, 43.05818371474743, 43.79945173859596, 46.57909378409386, 48.69445167481899, 54.88455891609192, 53.6646343767643, 55.05198933184147, 52.78034582734108, 53.84157568216324, 53.90735015273094, 57.96012908220291, 59.12640430033207, 56.73109643161297, 58.22719395160675, 57.87895783782005, 54.8364382982254, 57.180099338293076, 56.46002657711506, 54.776697903871536, 49.03399385511875, 46.509333327412605, 48.20819936692715, 47.78645619750023, 49.841469526290894, 48.79077650606632, 55.6161754578352, 54.291418343782425, 54.55551937222481, 48.65605853497982, 47.77343049645424, 36.69310346245766, 18.34175068885088, 12.28574775159359, 22.255951054394245, 3.1052520358935, 0.6523084442596883, 1.9116679206490517, 38.097185119986534, 61.503115966916084, 51.67446456849575, 57.046335116028786, 56.2964453548193, 49.18021380901337, 43.9360848069191, 70.54147437214851, 12.057684939354658, 16.70916259288788, 40.553316324949265, 27.455200664699078, 38.03774490952492, 22.195957973599434, 40.76751083135605, 36.00637771189213, 1.2840981082990766, 0.14518955606035888, 0.07818349142326042, 0.14557762508047745, 0.026657788694137707, 0.022706891322741285, 0.05867514155397657, 0.07494126344681717, 0.019878681559930556, 0.017216536616615485, 0.044871706850244664, 0.020003065510536544, 0.06020932778483257, 0.06271648075198755, 0.027463139522296842, 0.07366566744167358, 0.031334291270468384, 0.09049982545548119, 0.029501498211175203, 0.13303504732903093, 0.031063947280927096, 0.26944645098410547, 0.08409869042225182, 0.1507647178368643, 0.012507752471719868, 2.07751477137208, 34.632322043180466, 59.529064893722534, 32.13642597198486, 34.40566800534725, 32.40720324218273, 37.54069738090038, 15.292343068867922, 30.014203749597073, 66.88600972294807, 69.22227635979652, 71.43693432211876, 67.41877913475037, 63.336456790566444, 63.57234813272953, 48.3072904497385, 5.734404819086194, 0.18578439572593197, 2.9711788427084684, 2.332882205955684, 15.822106841951609, 45.95470368862152, 46.513980478048325, 63.234728649258614, 59.53637570142746, 56.34444817900658, 64.01680648326874, 61.39273948967457, 62.954303696751595, 66.5094955265522, 66.3132056593895, 66.52318239212036, 63.950484842062, 63.734800815582275, 62.06185318529606, 53.493514358997345, 59.5086257904768, 65.60952141880989, 62.7154029160738, 64.63148429989815, 60.14295235276222, 63.76170337200165, 64.45490777492523, 61.51935629546642, 54.62569400668144, 52.278058379888535, 63.83041888475418, 63.60385224223137, 62.71321043372154, 52.83366836607456, 52.909390702843666, 52.11016058921814, 47.5974353402853, 46.94233909249306, 45.9086387604475, 44.73870813846588, 45.07635802030563, 44.888769686222076, 45.174449756741524, 48.9995639026165, 50.8254761248827, 51.39569252729416, 49.356645941734314, 47.41137072443962, 48.52257549762726, 44.91790272295475, 44.91677798330784, 48.27891357243061, 51.89396359026432, 58.38787592947483, 57.60822236537933, 57.492689564824104, 29.377783499658108, 35.813560858368874, 52.47413545846939, 50.064965933561325, 39.490954130887985, 53.57535056769848, 59.935221299529076, 55.18230713903904, 55.40800742805004, 50.802175775170326, 48.978000059723854, 45.80493092536926, 48.10702599585056, 49.63647432625294, 51.03495128452778, 51.11110299825668, 51.40699692070484, 49.4742876291275, 45.00638857483864, 42.20462791621685, 44.009572863578796, 43.149568811059, 44.485124945640564, 46.09117716550827, 45.09721890091896, 44.917169362306595, 44.86440919339657, 46.87314100563526, 47.88494311273098, 51.742659509181976, 57.063305005431175, 57.02060289680958, 56.228698790073395, 53.51385846734047, 54.70187231898308, 56.760050877928734, 59.16602097451687, 61.33483059704304, 57.68190801143646, 58.435103595256805, 58.2337561994791, 57.29006923735142, 58.810318261384964, 57.91225545108318, 57.15008094906807, 49.560007229447365, 45.71756221354008, 48.73550467193127, 48.486386239528656, 52.06833243370056, 50.192323699593544, 54.80975992977619, 59.34478998184204, 55.96299424767494, 53.24989043176174, 49.34539474546909, 44.218694642186165, 22.942557111382484, 17.811793126165867, 17.425674945116043, 4.1120904218405485, 2.15186704415828, 4.607717776671052, 43.89691650867462, 67.91851311922073, 58.42397399246693, 62.25383408367634, 61.74156457185745, 54.02678534388542, 48.75792346894741, 71.74214154481888, 13.110138215124607, 21.976873129606247, 48.02336968481541, 28.703840263187885, 47.58356228470802, 22.89400141686201, 47.909447997808456, 43.6481324583292, 2.08680076058954, 0.04287389725504909, 0.0847974224598147, 0.07986185097252019, 0.014979646930441959, 0.06409334280760959, 0.09891992871416733, 0.04947959416313097, 0.08220854419050738, 0.01185241473649512, 0.06077557904063724, 0.16988266463158652, 0.17578417842742056, 0.23064532288117334, 0.12696151854470372, 0.13036022835876793, 0.11535329729667865, 0.21427928935736418, 0.1640918495832011, 0.29557652072981, 0.2174998985719867, 0.37555700400844216, 0.1361859985627234, 0.5144244711846113, 0.1486746221780777, 3.950319802388549, 55.86899109184742, 73.08704897761345, 49.795241206884384, 43.06974269449711, 41.605122685432434, 43.433816358447075, 18.714945763349533, 34.90477882325649, 71.97800248861313, 75.3091849386692, 75.24196654558182, 74.56258580088615, 69.14538368582726, 67.22410038113594, 54.15887385606766, 6.496913228183985, 0.3557813510997221, 3.909749616868794, 4.996155258268118, 24.294214881956577, 57.973071187734604, 50.06676323711872, 65.95328897237778, 63.70289772748947, 60.93747831881046, 65.31140461564064, 62.41610437631607, 64.75907385349274, 67.91468292474747, 70.02270340919495, 69.17250663042068, 68.05468261241913, 64.71962437033653, 65.7129442691803, 55.79355373978615, 60.668038576841354, 64.41051855683327, 65.52192851901054, 65.98728194832802, 65.49054980278015, 65.70646181702614, 67.78861328959465, 62.80753657221794, 56.20361253619194, 54.13251847028732, 68.20891633629799, 65.56461542844772, 66.41428783535957, 56.027643978595734, 55.874979570508, 54.07543793320656, 52.04377435147762, 49.05198588967323, 47.98839636147022, 48.296624422073364, 47.238928377628326, 47.864059433341026, 49.59547832608223, 51.708837524056435, 54.5427330583334, 53.659333661198616, 51.100060790777206, 51.006392017006874, 49.206177815794945, 48.7700904160738, 47.80925117433071, 51.06927864253521, 55.99531911313534, 62.85242736339569, 63.47534313797951, 63.35710868239403, 27.069956436753273, 33.25036279857159, 54.872619956731796, 49.863576740026474, 36.17030471563339, 54.515393525362015, 65.45575886964798, 58.48827414214611, 61.503381952643394, 53.85501176118851, 52.910006269812584, 47.94570565223694, 52.993392795324326, 50.895396173000336, 53.52787211537361, 51.40415847301483, 52.340872809290886, 52.068241238594055, 48.384950682520866, 44.97277557849884, 47.255799472332, 47.40192823112011, 46.443931236863136, 50.08823588490486, 49.84624207019806, 47.31820732355118, 47.13090777397156, 48.70607525110245, 53.212093859910965, 53.241017907857895, 60.60925953090191, 57.947954535484314, 58.14085878431797, 55.708005130290985, 57.60119654238224, 57.29839079082012, 61.58575773239136, 63.1796658039093, 60.5997334420681, 60.331144854426384, 62.407087460160255, 59.39259521663189, 61.7766784876585, 58.52089539170265, 57.69777975976467, 48.78043346107006, 44.54862333834171, 47.82929889857769, 48.936213701963425, 52.46821537613869, 52.08651825785637, 55.28796806931496, 55.045297890901566, 55.58780997991562, 53.291087821125984, 53.29867221415043, 49.66676250100136, 31.621925979852676, 23.429972156882286, 29.59166642278433, 8.404185734689236, 2.7958092279732227, 5.049175238236785, 43.430917114019394, 75.49854397773743, 61.21646694839001, 68.17409500479698, 64.89374622702599, 59.89782750606537, 53.67525480687618, 82.49902993440628, 15.975019186735153, 26.17618929594755, 49.242887645959854, 39.631371796131134, 57.590302526950836, 34.10173371434212, 59.18476536870003, 59.924863055348396, 6.1337220668792725, 0.5205156037118286, 0.2348403274663724, 0.2732595760608092, 0.15838706429349259, 0.19627358444267884, 0.22939544229302555, 0.16012579755624756, 0.12166887012426741, 0.19271884550107643, 0.13886994594940916], [0.03693409606057685, 0.0914287420164328, 0.080686748115113, 0.047265619214158505, 0.07561770136817358, 0.029695172779611312, 0.02208893834904302, 0.05072821310022846, 0.07514951750636101, 0.08123363673803397, 0.0999822240555659, 0.04103492210560944, 0.15734551940113306, 0.1886947575258091, 0.6515217083506286, 14.925187770277262, 39.9583138525486, 53.98801602423191, 46.80907264351845, 22.48150695115328, 43.10228034853935, 10.650350656360388, 9.032070692628622, 51.642713472247124, 62.73478947579861, 64.11756947636604, 58.400305062532425, 59.36549127101898, 55.51837630569935, 53.9488173276186, 52.486598789691925, 2.0504794595763087, 0.7719570177141577, 1.6549380216747522, 1.5802726219408214, 23.86432494968176, 40.86244113743305, 56.321182027459145, 50.30335754156113, 65.37635073065758, 68.3501623570919, 63.81304621696472, 64.89673286676407, 62.94080302119255, 63.11398632824421, 61.39178954064846, 60.95975272357464, 62.261000499129295, 63.06500315666199, 62.19976298511028, 52.413555309176445, 61.289054453372955, 61.72416530549526, 61.64254568517208, 60.632202699780464, 61.50710955262184, 58.57746295630932, 59.724279418587685, 53.692038506269455, 42.84844636917114, 58.90584133565426, 56.54346249997616, 61.285779029130936, 53.167940229177475, 51.77885256707668, 48.780532255768776, 46.504830569028854, 44.990752413868904, 43.35398644208908, 43.294341042637825, 43.16710866987705, 42.54194341599941, 46.67226858437061, 48.90201933681965, 47.16557331383228, 44.769668877124786, 44.60174448788166, 44.13051277399063, 42.93942868709564, 44.65235397219658, 40.80232456326485, 44.59333173930645, 49.6359271556139, 53.8641806691885, 52.16729812324047, 63.87833431363106, 18.944977819919586, 8.181022759526968, 57.055116444826126, 27.04690497368574, 11.04222932830453, 45.97874119877815, 57.55572438240051, 53.955827951431274, 57.905123233795166, 49.76495683193207, 45.932471081614494, 42.90040858089924, 42.99677900969982, 43.06045979261398, 43.2727961987257, 43.696807846426964, 46.30809612572193, 46.4108844101429, 50.00246688723564, 40.9148783236742, 37.49184340238571, 40.159931033849716, 38.46789322793484, 38.53932559490204, 39.81986068189144, 42.09916837513447, 44.6378805488348, 45.52846156060696, 45.68383142352104, 49.849350303411484, 52.18864157795906, 56.32689692080021, 51.98876850306988, 54.153614938259125, 53.3761652559042, 53.23818325996399, 53.549014180898666, 58.35283800959587, 57.57515273988247, 56.529593244194984, 55.968424156308174, 57.346336618065834, 59.42783832550049, 58.88929322361946, 52.609636187553406, 44.49885740876198, 51.367004066705704, 48.610932156443596, 47.911032512784004, 45.9999630600214, 47.13698364794254, 51.069514229893684, 54.15996439754963, 50.074647814035416, 52.32758492231369, 44.190310165286064, 31.201326549053192, 7.45223231613636, 9.775022976100445, 2.9965018713846803, 1.0720327938906848, 0.4781254939734936, 11.097302623093128, 53.168301209807396, 52.02918313443661, 52.63271614909172, 54.07982289791107, 54.08099323511124, 49.319396540522575, 72.69463643431664, 28.142798468470573, 4.3767124973237514, 32.81195372343063, 20.520935654640198, 35.39466753602028, 30.10500557720661, 25.280256271362305, 47.99413025379181, 17.937057204544544, 0.6386529863812029, 0.13657387462444603, 0.09713939769426361, 0.07337283823289908, 0.04009130730992183, 0.11750635676435195, 0.04537741740932688, 0.060262703045737, 0.06975814118050039, 0.04599124033120461, 0.015439874969160883, 0.029795017617288977, 0.04043153006932698, 0.06224559176189359, 0.04469874191272538, 0.07282700345967896, 0.06008485477650538, 0.06517214351333678, 0.04049779643537477, 0.09535258068353869, 0.07700961417867802, 0.10356467479141429, 0.04435925387952011, 0.09805902998778038, 0.12295008418732323, 0.9914812131319195, 16.657128185033798, 57.37320117652416, 58.7615554779768, 53.68753954768181, 35.06490983068943, 42.29823589324951, 15.641717221587896, 9.45591514930129, 55.50698831677437, 68.3695337176323, 70.65123528242111, 65.69336771965027, 66.39778912067413, 62.515203058719635, 59.85593855381012, 61.84909500181675, 2.3076465725898743, 0.8896815881598741, 1.3217001780867577, 2.0862493151798844, 31.41211073845625, 45.14153212308884, 60.87555304169655, 58.40440884232521, 67.71900862455368, 66.64222240447998, 64.86459419131279, 67.34817132353783, 66.64238959550858, 66.39765232801437, 64.39727246761322, 63.64968158304691, 63.734766617417336, 65.33000841736794, 63.25337044894695, 55.28643295168877, 64.06417474150658, 64.09168526530266, 64.0665990114212, 62.580339163541794, 62.66141541302204, 62.36387997865677, 61.006862595677376, 55.92832870781422, 48.058578595519066, 61.672845259308815, 60.229633301496506, 66.33973583579063, 54.50938984751701, 52.925733625888824, 50.42025446891785, 47.831567376852036, 47.55502201616764, 45.071102902293205, 44.396544098854065, 47.038439735770226, 44.03577245771885, 47.38302804529667, 52.56316848099232, 48.905712738633156, 48.49970832467079, 47.4816707521677, 46.72175332903862, 44.69848729670048, 45.02245411276817, 44.56709414720535, 48.48271943628788, 53.937562331557274, 55.407384261488914, 57.69275642931461, 65.15106081962585, 22.494065277278423, 14.385615773499012, 60.99643595516682, 33.874327316880226, 16.318896934390068, 49.03194576501846, 60.43368995189667, 57.504180148243904, 59.432808458805084, 52.887659668922424, 48.604901880025864, 47.4914438277483, 47.96670712530613, 47.89649449288845, 46.92740969359875, 48.30211892724037, 47.865643948316574, 50.003337040543556, 49.46556709706783, 43.31348441541195, 40.39625555276871, 41.56516782939434, 42.582206055521965, 41.86262346804142, 42.51556143164635, 44.09856788814068, 46.07778288424015, 46.88398942351341, 48.01189050078392, 53.71210902929306, 55.82302115857601, 58.02958935499191, 53.90700437128544, 55.72553738951683, 53.66895854473114, 55.03028869628906, 57.441282123327255, 58.4342410415411, 59.14313480257988, 58.00951883196831, 57.24884144961834, 57.418882325291634, 61.1906511336565, 58.20463456213474, 54.98697482049465, 44.3277145922184, 51.94065548479557, 47.94029854238033, 49.89956080913544, 45.813594460487366, 50.984843373298645, 52.91538678109646, 56.724002212285995, 53.35787683725357, 56.168707609176636, 47.39570416510105, 36.892835944890976, 10.029360428452492, 8.121056277304888, 3.961570286192, 1.8375260615721345, 0.7998867065180093, 14.156565964221954, 59.91566754877567, 57.84928523004055, 58.257159143686295, 61.697217151522636, 58.709619864821434, 57.10176274180412, 72.97536537051201, 29.648287184536457, 8.30165583640337, 40.61481602489948, 20.433661937713623, 38.601243272423744, 37.38335162401199, 21.16287510842085, 59.831426069140434, 22.825565189123154, 0.6263059051707387, 0.00602454842919542, 0.10845513854292221, 0.08745075625483878, 0.02948121531517245, 0.11222369023016654, 0.011366489834472304, 0.047202284331433475, 0.01566049970278982, 0.02229371173598338, 0.04299162043025717, 0.09850345028098673, 0.12367241652100347, 0.23696730786468834, 0.20372563769342378, 0.26962910837028176, 0.14884482632623985, 0.3116935340221971, 0.15764344716444612, 0.19011908734682947, 0.24395905144046992, 0.2802384359529242, 0.15322944964282215, 0.34884304215665907, 0.4683227324858308, 1.3437443389557302, 33.49072650074959, 75.79922944307327, 75.99406018853188, 60.40590964257717, 44.12351734936237, 55.23127891123295, 17.832148633897305, 10.791263245046139, 65.90171054005623, 72.18545615673065, 75.3167237341404, 69.23850908875465, 74.11895960569382, 65.18041804432869, 67.67879158258438, 66.81276485323906, 2.018911703489721, 1.7548009380698204, 2.8015811182558537, 3.3550050342455506, 40.89837200939655, 53.452909737825394, 61.96861758828163, 58.32764536142349, 70.72696521878242, 66.35767087340355, 65.54274380207062, 67.3384590446949, 70.83120882511139, 69.24619987607002, 68.00583243370056, 65.63684955239296, 70.36387950181961, 67.6385061442852, 66.69198453426361, 57.90144883096218, 62.9705136269331, 64.94668498635292, 67.581045627594, 65.08723184466362, 65.79588621854782, 63.12707282602787, 63.80478546023369, 56.236955747008324, 48.78900960087776, 64.15666177868843, 63.59234265983105, 69.13741171360016, 58.66023391485214, 55.76817490160465, 54.488878548145294, 50.33766970038414, 48.20556230843067, 48.50802607834339, 50.09694881737232, 49.760735258460045, 47.64563575387001, 51.593483313918114, 55.7125610858202, 52.301305532455444, 49.56826038658619, 50.24727255105972, 47.05904223024845, 46.12367682158947, 48.464921191334724, 44.97100107371807, 51.46340869367123, 57.33918160200119, 58.745326548814774, 58.86646404862404, 74.12041872739792, 18.423117622733116, 10.524088181555271, 68.75605657696724, 29.163469299674034, 13.814243283122778, 49.99859869480133, 66.63909897208214, 59.12830799818039, 63.701864182949066, 58.160697519779205, 52.56585493683815, 49.91882957518101, 50.36290794610977, 47.802821919322014, 49.65921230614185, 49.610609114170074, 51.58280968666077, 51.802992671728134, 55.180775821208954, 45.50415426492691, 41.574766114354134, 44.926490262150764, 45.21553315222263, 43.03865276277065, 44.118991792201996, 45.20509131252766, 52.42497369647026, 48.25097747147083, 50.13695687055588, 58.640649765729904, 60.80559499561787, 61.68435864150524, 55.902490094304085, 58.17322924733162, 56.25135697424412, 57.369104996323586, 60.700469836592674, 62.337395399808884, 61.072960048913956, 59.899263828992844, 60.17791047692299, 61.15751691162586, 63.59469473361969, 59.77103590965271, 55.4296662658453, 44.67223830521107, 53.32372047007084, 48.369865491986275, 50.37481650710106, 47.34169006347656, 51.79288521409035, 53.95172417163849, 57.35823757946491, 53.43715198338032, 57.267677038908005, 51.54512330889702, 44.559000581502914, 17.013604156672955, 14.926480650901794, 7.294852361083031, 3.34879070520401, 2.409466146491468, 14.881566110998392, 65.97649812698364, 62.810344621539116, 61.98126710951328, 66.28081619739532, 65.55743381381035, 63.46587024629116, 78.35846051573753, 38.03336754441261, 8.088162392377853, 44.737089425325394, 25.62629420310259, 54.4137641787529, 44.63018216192722, 39.457090348005295, 67.99339950084686, 40.16331285238266, 1.3274020096287131, 0.23763703677104786, 0.26571671362034976, 0.19209263613447547, 0.18930048361653462, 0.26112281950190663, 0.14284180157119408, 0.10865954827750102, 0.2550159237580374, 0.20114101935178041, 0.13440215756418183], [0.014943789137760177, 0.02141105695045553, 0.09312463851529174, 0.07607041887240484, 0.050350404271739535, 0.025491757805866655, 0.05850400229974184, 0.03743201777979266, 0.06701726364553906, 0.09918535783072002, 0.1666546636261046, 0.0740403555391822, 0.25963353691622615, 0.37663665076252073, 0.12354602135019377, 4.62197651155293, 32.04280659556389, 39.778712689876556, 40.06365939974785, 26.543019711971283, 26.33703276515007, 42.32030510902405, 8.842783849686384, 19.299525395035744, 58.444956466555595, 64.09068211913109, 64.08325731754303, 59.936026856303215, 63.34823235869408, 44.31808590888977, 51.31524324417114, 23.53716630488634, 0.8914389344863594, 0.5938190734013915, 0.3718495904468, 14.540703501552343, 30.781891755759716, 51.919179037213326, 58.80637787282467, 68.20389300584793, 60.059474632143974, 67.5940865278244, 65.8825671672821, 66.56808838248253, 60.548105612397194, 61.154499873518944, 59.16145741939545, 62.66144201159477, 60.918787121772766, 63.07896740734577, 52.605091631412506, 57.518098801374435, 60.6568443775177, 60.34593366086483, 61.59183740615845, 58.57592023909092, 60.687238946557045, 60.774748250842094, 55.62736965715885, 45.511362478137016, 60.79350784420967, 59.03256073594093, 61.49643212556839, 53.56249585747719, 51.20689205825329, 48.56996275484562, 46.47217132151127, 46.39882765710354, 44.43754009902477, 42.54789389669895, 43.301492258906364, 41.90345227718353, 47.70546354353428, 49.366183429956436, 45.0590955466032, 45.04201166331768, 42.03183598816395, 42.59962432086468, 40.962782353162766, 43.36714133620262, 43.07732708752155, 45.63890643417835, 54.28746275603771, 54.24955978989601, 53.03338944911957, 62.22214758396149, 33.1101693212986, 7.747993720695376, 45.854419469833374, 15.07323257625103, 14.280406069010496, 59.894445687532425, 52.338513135910034, 56.8044400960207, 54.15149845182896, 50.66669024527073, 44.20068360865116, 45.85593938827515, 40.64671911299229, 43.479512706398964, 43.66025000810623, 43.57219733297825, 42.89470508694649, 44.4877278059721, 43.98746944963932, 42.227080911397934, 39.39343996345997, 40.002171099185944, 36.416261717677116, 38.18879820406437, 39.04435649514198, 39.735543206334114, 42.3028564453125, 43.33818309009075, 47.25429855287075, 50.64165338873863, 57.08385810256004, 53.68663139641285, 55.653124675154686, 53.55713814496994, 53.69452737271786, 55.607470124959946, 55.645441487431526, 54.799713268876076, 57.45404563844204, 55.47673813998699, 57.38663725554943, 57.056993544101715, 55.625682547688484, 55.287546291947365, 48.630801290273666, 49.3622924387455, 52.42017075419426, 47.0552234351635, 54.462390169501305, 50.147261917591095, 53.365632221102715, 52.44473643600941, 52.11817055940628, 49.76008169353008, 43.13967414200306, 34.64891195297241, 14.658214095979929, 2.844936791807413, 1.0637507820501924, 1.842334228567779, 0.6675057881511748, 0.5119350110180676, 11.933833435177803, 58.708472326397896, 47.70287208259106, 56.055093705654144, 50.91670922935009, 54.814608469605446, 57.57049798965454, 59.28145118057728, 11.894225310534239, 18.911875896155834, 53.848783895373344, 27.38756239414215, 39.83655318617821, 19.922644458711147, 25.44010229408741, 43.453389108181, 9.968095365911722, 0.34934648545458913, 0.10766317049274221, 0.1850912149529904, 0.07010793764493428, 0.040214711625594646, 0.048063550420920365, 0.044966634959564544, 0.08325596689246595, 0.014975730246078456, 0.08342684639501385, 0.10077588420244865, 0.008040275788516738, 0.03473769516858738, 0.057892554250429384, 0.054332605432136916, 0.06679647471173666, 0.0515243779955199, 0.01866994749434525, 0.03239378871512599, 0.042101507060579024, 0.057285154616693035, 0.002020019524024974, 0.12716627708869055, 0.10975852797855623, 0.4414154263213277, 0.0965398017433472, 6.066471375524998, 46.326012164354324, 46.772324815392494, 44.613873437047005, 37.4737411737442, 31.81475803256035, 52.63486683368683, 16.060797683894634, 19.806028716266155, 64.22046035528183, 70.833959877491, 71.10540971159935, 63.50533872842789, 70.45477822422981, 51.6682481020689, 57.35982969403267, 25.65206442028284, 0.565688885981217, 2.0079606911167502, 1.337900252547115, 16.773162558674812, 39.059099704027176, 56.53204791247845, 63.01497504115105, 68.4000612795353, 59.42006394267082, 69.32427808642387, 67.00854554772377, 68.35492730140686, 63.07863302528858, 63.29241715371609, 59.247712790966034, 65.34804984927177, 64.50061932206154, 63.30373674631119, 55.706811994314194, 60.45502960681915, 62.251550406217575, 62.775956466794014, 60.97164988517761, 60.46190343797207, 60.8888029307127, 62.944276034832, 57.45633311569691, 50.8677526563406, 62.320493906736374, 61.11161157488823, 63.849896639585495, 57.81047411262989, 52.6510463654995, 50.27020812034607, 49.644845277071, 47.842567786574364, 47.22434476017952, 45.53718589246273, 46.93548806011677, 42.562002539634705, 48.79110708832741, 52.206755205988884, 47.47396096587181, 46.816702634096146, 45.82340933382511, 46.21707201004028, 44.82648342847824, 44.641053378582, 44.70101796090603, 50.27346454560757, 58.20778839290142, 59.271681904792786, 54.69984322786331, 64.97139886021614, 41.12243078649044, 11.132773719727993, 51.56310014426708, 19.75411780178547, 16.904937587678432, 63.11652459204197, 55.13679318130016, 61.60724937915802, 56.49139769375324, 55.09093724191189, 48.8632196187973, 48.76165106892586, 44.952602460980415, 45.84970012307167, 46.99527405202389, 47.022780776023865, 46.732647344470024, 46.90774194896221, 46.910162419080734, 44.61967572569847, 42.282314747571945, 40.34243144094944, 39.41502660512924, 40.38046360015869, 41.60906307399273, 42.269555032253265, 43.37596446275711, 46.81898631155491, 48.31715852022171, 51.93549536168575, 58.09208460152149, 56.66616931557655, 57.78189204633236, 55.43576493859291, 55.86546868085861, 57.56124548614025, 55.54229602217674, 58.132605627179146, 57.89490558207035, 57.31575965881348, 58.85930523276329, 58.713290467858315, 57.52023808658123, 56.917845010757446, 48.53642575442791, 49.5975986123085, 55.52328184247017, 49.96725417673588, 57.446803227066994, 52.31740526854992, 57.86175616085529, 56.3618740439415, 55.76206862926483, 52.50105321407318, 46.77004873752594, 40.32245971262455, 19.15010031312704, 3.436040673404932, 2.618025317788124, 1.9999929936602712, 0.7728939643129706, 0.8397808251902461, 16.366582475602627, 65.62697008252144, 53.139392361044884, 60.829860493540764, 57.650381103158, 59.73377510905266, 65.39550170302391, 58.68122398853302, 18.00512295216322, 22.22666222602129, 59.92094926536083, 24.178001917898655, 46.658688113093376, 26.193685457110405, 28.713892623782158, 55.34548178315163, 14.396499339491129, 0.368373905075714, 0.11532951888511889, 0.1410392881371081, 0.08282461581984535, 0.036138580544502474, 0.1046713134564925, 0.031171048467513174, 0.08835196844302118, 0.0426354229421122, 0.06862410984467715, 0.15138466347707435, 0.14988580718636513, 0.16701172571629286, 0.17881013714941218, 0.17964946164283901, 0.2565775508992374, 0.12824334116885439, 0.4238467721734196, 0.18545075581641868, 0.1653186048497446, 0.5255232006311417, 0.2854396740440279, 0.32987238198984414, 0.5005762923974544, 0.9417247236706316, 0.554451938951388, 13.794358000159264, 65.74388980865479, 59.017125964164734, 51.23852916061878, 47.49515622854233, 40.89600473642349, 55.23553088307381, 12.752623949199915, 21.897877268493176, 71.9543145596981, 73.66018742322922, 79.66107621788979, 69.69696968793869, 76.36043652892113, 55.63577480614185, 63.74848388135433, 26.686338521540165, 2.0485071279108524, 1.1739639868028462, 1.696163434535265, 19.9930052831769, 44.193217009305954, 63.12929950654507, 62.217017859220505, 65.10148108005524, 59.37376722693443, 73.21523889899254, 72.69706830382347, 70.35545155405998, 67.20602095127106, 67.68446087837219, 64.26644548773766, 71.06415912508965, 68.6871586740017, 65.29804453253746, 57.55657933652401, 60.978041142225266, 61.19538187980652, 66.95444405078888, 63.39394770562649, 65.81518158316612, 63.95953595638275, 64.30899560451508, 57.20716908574104, 49.074720069766045, 65.62383905053139, 65.86629644036293, 67.65268698334694, 57.99386367201805, 56.55811831355095, 55.33873714506626, 52.55444414913654, 52.410675063729286, 49.482685178518295, 49.48119945824146, 49.46126572787762, 47.301518619060516, 51.161758080124855, 56.043192744255066, 49.18488755822182, 49.184268191456795, 46.390361711382866, 49.51911762356758, 46.620245575904846, 47.549975886940956, 48.52942653000355, 53.19772683084011, 63.053322583436966, 63.62530969083309, 59.44106921553612, 68.98229643702507, 36.623848378658295, 8.611881639808416, 55.19266918301582, 16.955509074032307, 14.61052855476737, 68.69836047291756, 59.899222031235695, 64.10721123218536, 61.07485234737396, 57.99456663429737, 51.649727895855904, 50.80796666443348, 45.89385375380516, 47.29444719851017, 48.414087519049644, 48.00905965268612, 46.63129158318043, 49.47510078549385, 49.147858545184135, 47.36443184316158, 45.802882835268974, 43.75193148851395, 40.74753910303116, 41.64529412984848, 43.01849864423275, 42.8225963562727, 46.80871166288853, 47.19687983393669, 51.143895238637924, 56.06619670987129, 63.473481237888336, 61.250038146972656, 60.281572714447975, 60.426287949085236, 58.83116014301777, 61.6533637046814, 58.22290778160095, 60.18377736210823, 63.87831911444664, 57.27764010429382, 61.287158355116844, 65.78047424554825, 59.62042339146137, 58.10878470540047, 48.7079219520092, 51.10848493874073, 56.48297354578972, 49.17134128510952, 57.100649401545525, 52.903318628668785, 55.771005749702454, 55.88995836675167, 56.83407090604305, 55.13162925839424, 51.27520479261875, 46.64153963327408, 22.38146021962166, 5.9114116709679365, 3.5631628520786762, 3.7566308956593275, 2.508666948415339, 1.2200759374536574, 18.11627458781004, 73.10078144073486, 57.156757190823555, 66.45662516355515, 63.56189489364624, 68.56250256299973, 65.33042639493942, 71.63730517029762, 19.37809567898512, 25.697346590459347, 69.33842852711678, 36.92319631576538, 62.11930230259895, 29.455350637435913, 43.244305327534676, 64.61678668856621, 28.63936722278595, 0.8586349978577346, 0.3152865974698216, 0.5567286105360836, 0.15940920944558457, 0.1375472458312288, 0.19875911122653633, 0.23779910698067397, 0.1513173061539419, 0.12200308148749173, 0.2120538556482643, 0.28073597175534815], [0.12223907702718861, 0.01420901098754257, 0.024018876683840062, 0.025243422205676325, 0.0077811192113586, 0.003803666172643716, 0.0239468289873912, 0.022433886733779218, 0.19787907251156867, 0.011544042172317859, 0.00875740473929909, 0.10648789058905095, 0.08281202899524942, 0.025711624621180817, 0.04444143931323197, 1.1646470054984093, 22.182738482952118, 46.420623287558556, 30.613199807703495, 25.15055973082781, 27.11470853537321, 62.286683320999146, 33.15252184867859, 4.797993991523981, 37.61287070810795, 66.5870189666748, 66.37818977236748, 59.191434010863304, 61.61720484495163, 50.49388311803341, 60.386420488357544, 34.10532832145691, 0.877748328493908, 1.3932854868471622, 0.3937917505390942, 3.4674379136413336, 25.886496640741825, 44.42622430622578, 61.05455003678799, 66.97168752551079, 67.05565541982651, 68.5703757405281, 63.08953084051609, 60.7173827290535, 58.70342239737511, 54.312195628881454, 53.79288509488106, 60.58194279670715, 59.0321009606123, 63.12526032328606, 61.25956043601036, 53.085541650652885, 60.124869123101234, 58.81287932395935, 60.48754446208477, 59.66114200651646, 59.27038237452507, 63.266551941633224, 53.48436065018177, 51.30822502076626, 61.72365993261337, 57.78363235294819, 59.457947909832, 51.42666086554527, 51.104837134480476, 47.781368270516396, 47.605335116386414, 45.167093351483345, 43.78710240125656, 41.78437426686287, 43.81566546857357, 44.49938178062439, 45.97726687788963, 47.04754784703255, 46.78024739027023, 44.97532144188881, 41.52938134968281, 40.805915370583534, 43.01437966525555, 41.57169967889786, 43.15758638083935, 47.33236536383629, 56.088493913412094, 52.29676477611065, 57.349862828850746, 54.56069849431515, 54.68621715903282, 20.48776153475046, 40.802031978964806, 15.497183427214622, 28.74927632510662, 62.9749745875597, 51.05569437146187, 56.65858492255211, 53.20251077413559, 53.40702340006828, 42.733342945575714, 44.21513423323631, 38.652464523911476, 42.15780682861805, 40.67879319190979, 44.29335303604603, 42.959806993603706, 46.833630725741386, 43.024008348584175, 42.635653987526894, 40.11808767914772, 38.51834312081337, 36.04255937039852, 38.52870516479015, 38.86340640485287, 39.63847741484642, 41.53559401631355, 44.61861938238144, 47.93508902192116, 45.42281202971935, 50.276755169034004, 53.841727674007416, 54.02061827480793, 54.29415799677372, 53.029768243432045, 56.17900885641575, 55.6985018402338, 55.30843377113342, 56.47351585328579, 55.27633689343929, 56.174692288041115, 55.286645740270615, 55.10570324957371, 52.09590755403042, 50.71928322315216, 53.08611162006855, 51.629072204232216, 57.915557473897934, 58.13832052052021, 59.190525859594345, 58.000376522541046, 60.542428717017174, 53.22665087878704, 47.88643643260002, 36.336940973997116, 24.213562309741974, 13.722772691398859, 7.024604212492704, 6.893017273396254, 3.24025119189173, 0.7185296877287328, 1.1430733068846166, 29.696280509233475, 54.062898606061935, 48.89114052057266, 56.07330612838268, 40.72268843650818, 60.312210470438, 55.02420902252197, 45.662677958607674, 9.049076680094004, 45.438797771930695, 40.84797911345959, 31.373398415744305, 39.04660977423191, 35.93089856207371, 37.84291036427021, 42.8913726657629, 4.325985694304109, 0.16951639991020784, 0.23744026373606175, 0.10744575833086856, 0.06437591553549282, 0.03833343034784775, 0.06462753328378312, 0.05836095333506819, 0.023367898138531018, 0.047903406084515154, 0.07494331177440472, 0.0682219845475629, 0.04893893586995546, 0.05221440835157409, 0.046931856850278564, 0.025157012096315157, 0.041203645669156685, 0.02482181924278848, 0.044666603207588196, 0.046052482357481495, 0.023586403112858534, 0.04356815785286017, 0.06445946652092971, 0.1579141232650727, 0.1343316090060398, 0.11363544064806774, 0.14614282990805805, 1.4580717729404569, 29.092819690704346, 63.053090795874596, 31.766912899911404, 38.60749393701553, 33.840908110141754, 59.61988382041454, 44.16046276688576, 6.540476940572262, 39.1651102155447, 68.74946013092995, 71.52574315667152, 64.03408035635948, 66.83613359928131, 52.83673860132694, 64.87586438655853, 39.18245628476143, 0.9169644804205745, 3.5608193278312683, 0.8310431346762925, 3.4829959413036704, 30.31991634517908, 51.641942113637924, 64.62182521820068, 65.59942916035652, 67.79562011361122, 71.52339488267899, 65.51565885543823, 64.97989520430565, 60.12231945991516, 57.78035692870617, 57.74382568895817, 61.90250873565674, 62.94790484011173, 67.43828728795052, 63.41111898422241, 57.4420078843832, 65.59778764843941, 59.979975298047066, 62.72175997495651, 62.43191912770271, 62.70421251654625, 64.114620834589, 55.603601932525635, 57.49143563210964, 63.75601127743721, 58.96188072860241, 63.75519052147865, 54.031314700841904, 53.173924908041954, 47.28933647274971, 47.65318214893341, 46.51786386966705, 44.68527540564537, 42.380585074424744, 45.68787440657616, 45.18687888979912, 48.84524658322334, 47.815737426280975, 48.0967665463686, 48.6839984357357, 46.66460819542408, 42.49344281852245, 46.37431137263775, 43.82636569440365, 49.76789027452469, 48.4522070735693, 60.25383040308952, 53.29706870019436, 60.06138972938061, 56.309588849544525, 72.96064496040344, 32.39997982978821, 42.647908329963684, 19.996974170207977, 39.051355719566345, 68.47932502627373, 54.430886059999466, 61.9635296612978, 58.34961198270321, 56.47479638457298, 45.54087169468403, 46.20193362236023, 41.91016651690006, 45.83534449338913, 43.16348746418953, 46.744472309947014, 47.48792141675949, 49.59565691649914, 44.806044325232506, 45.35323776304722, 42.62353263795376, 43.265246003866196, 38.516203835606575, 42.537520453333855, 41.97923541069031, 43.90775352716446, 43.1308738142252, 46.87518149614334, 48.489798456430435, 49.66698668897152, 51.883077174425125, 57.42628052830696, 55.496215894818306, 57.71526262164116, 55.62387004494667, 57.45659530162811, 56.79105341434479, 57.00473874807358, 57.915652468800545, 59.17394354939461, 58.50240558385849, 57.25534290075302, 56.79232254624367, 53.453795090317726, 51.78693473339081, 55.32949984073639, 54.24975357949734, 59.18266028165817, 60.097780376672745, 61.68065004050732, 60.5179276317358, 61.12409010529518, 58.40292312204838, 53.06364342570305, 41.84266313910484, 31.48437526077032, 16.94178231060505, 7.727917497977614, 7.562541346997023, 3.9949465077370405, 1.655616641510278, 2.4832705361768603, 33.959511145949364, 58.91260877251625, 56.53421379625797, 63.18513751029968, 46.78209409117699, 65.92200145125389, 59.41444404423237, 48.36537413299084, 13.878503534942865, 47.598940059542656, 46.254040226340294, 27.26456679403782, 48.24240133166313, 41.0815791785717, 44.17842820286751, 54.70535673201084, 5.124168489128351, 0.1263895453303121, 0.19626689027063549, 0.0936166378960479, 0.09227645277860574, 0.07466571143595502, 0.05766927912191022, 0.1220983880921267, 0.013376460447034333, 0.02604590277769603, 0.11200604058103636, 0.08238127164077014, 0.20318179187597707, 0.0843286448798608, 0.06585845199879259, 0.12959960120497271, 0.16912654973566532, 0.13798579573631287, 0.19254804763477296, 0.11276884964900091, 0.2795232430798933, 0.2324656627024524, 0.14521875214995816, 0.4065321700181812, 0.22140660847071558, 0.28981709852814674, 0.1557557945488952, 2.9422524198889732, 47.64384225010872, 79.97526615858078, 44.017092660069466, 41.01875714957714, 43.188573718070984, 76.0584819316864, 43.293645679950714, 5.17006385140121, 46.797802448272705, 76.2734591960907, 78.38125169277191, 71.24378308653831, 73.44882756471634, 61.79280862212181, 74.58185076713562, 42.23838530480862, 1.186501057818532, 2.7516772085800767, 0.9799034125171602, 5.899404315277934, 36.23489364981651, 57.33768068253994, 65.27204632759094, 65.67439913749695, 69.06774625182152, 74.24170821905136, 68.53351011872292, 67.42365807294846, 65.11728063225746, 63.31149972975254, 61.23917832970619, 68.13497990369797, 67.08810567855835, 70.30423790216446, 66.99043571949005, 59.64570723474026, 62.846796065568924, 62.47321531176567, 63.36143285036087, 63.874808102846146, 66.22118979692459, 68.49630251526833, 55.88691473007202, 54.436604753136635, 68.80835697054863, 62.0251851528883, 67.64257192611694, 55.11397920548916, 58.41972962021828, 49.94090259075165, 50.92659629881382, 49.00420345366001, 50.16113117337227, 45.97085662186146, 51.426421478390694, 47.01717987656593, 52.06970416009426, 49.55657221376896, 50.57888075709343, 49.66167077422142, 47.66653083264828, 44.04328465461731, 48.32997143268585, 45.90363822877407, 51.91702075302601, 53.06734822690487, 62.27405659854412, 56.99932023882866, 65.46028822660446, 57.23356246948242, 72.95131266117096, 20.009895376861095, 39.2909936606884, 15.279348716139793, 30.254704244434834, 74.98681783676147, 55.83246365189552, 65.60077428817749, 61.421025171875954, 61.34967640042305, 48.97825084626675, 52.18183234333992, 40.66343441605568, 47.94962324202061, 45.326137617230415, 48.767077177762985, 46.19982473552227, 52.160458490252495, 46.57884679734707, 49.648854061961174, 44.91387493908405, 45.35183943808079, 40.568751096725464, 45.16510605812073, 43.43075752258301, 44.92158092558384, 47.55107782781124, 49.04556043446064, 51.69141925871372, 52.72962614893913, 55.70088431239128, 59.70605179667473, 59.78600710630417, 61.98470592498779, 57.299295142292976, 63.01171101629734, 58.88922482728958, 59.28434282541275, 59.17821832001209, 57.88599506020546, 60.90839087963104, 61.48215629160404, 58.53697992861271, 52.755954936146736, 52.51774191856384, 57.61056303977966, 57.1841499209404, 61.89446076750755, 62.464111000299454, 65.05812540650368, 62.30291984975338, 63.97402077913284, 57.11065426468849, 51.58791281282902, 46.313887014985085, 35.937969982624054, 23.341450206935406, 11.883289497345686, 12.613123934715986, 5.840529324486852, 2.056594043970108, 3.1108588725328445, 35.220450684428215, 65.93884974718094, 60.05388133227825, 67.06581607460976, 51.856835782527924, 69.73009631037712, 65.85168242454529, 56.62469074130058, 16.218622215092182, 57.56083890795708, 51.73821374773979, 44.16790656745434, 53.325225189328194, 47.10421800613403, 52.42976523935795, 69.30951207876205, 10.708000212907791, 0.5660824023652822, 0.4361304146004841, 0.18035925168078393, 0.295126274577342, 0.16010957420803607, 0.11980464711086825, 0.24504937027813867, 0.1307173349778168, 0.1569477134034969, 0.1470834278734401, 0.16980470943963155], [0.10998944722814485, 0.055618405967834406, 0.04785999044543132, 0.07190494434325956, 0.13045218045590445, 0.014648329943156568, 0.041419755361857824, 0.0029017408269282896, 0.0386905629420653, 0.02087114451569505, 0.1399380003567785, 0.02283548139530467, 0.03310869957203977, 0.05339238225133158, 0.5142071703448892, 0.08949089053203352, 10.506048649549484, 41.61021061241627, 41.07850134372711, 28.99047028273344, 26.972313076257706, 54.13319483399391, 60.871141478419304, 8.684102464467287, 20.695359595119953, 63.79847779870033, 70.50412997603416, 60.2659897506237, 61.8257300555706, 49.198399633169174, 56.60075202584267, 43.707356080412865, 2.58629250805825, 5.105144334957004, 1.35309326229617, 0.44169987668283284, 12.125779185444117, 38.87832060456276, 62.727980241179466, 62.44789347052574, 65.31652674078941, 64.88808453083038, 64.95562970638275, 57.84510165452957, 55.21795302629471, 49.27890211343765, 49.13569159805775, 51.8114510178566, 63.16916696727276, 59.59797039628029, 62.7596515417099, 53.86989176273346, 53.26137721538544, 61.896881237626076, 56.08654461801052, 58.08663949370384, 57.56740875542164, 60.579533725976944, 53.27733635902405, 57.89399743080139, 58.99722643196583, 58.13390515744686, 55.40776804089546, 48.90957713127136, 48.51237304508686, 43.52019712328911, 46.92490182816982, 44.83989290893078, 44.493503496050835, 42.39437073469162, 41.45280785858631, 43.30748073756695, 43.803517520427704, 48.73838111758232, 46.67599618434906, 43.48282992839813, 41.53729632496834, 40.654341503977776, 41.64744481444359, 42.86211043596268, 43.392759561538696, 50.836366340518, 55.831247717142105, 53.199026361107826, 55.06732150912285, 53.47552232444286, 53.82695786654949, 35.29222883284092, 45.328820273280144, 21.822614707052708, 43.655614256858826, 57.045632153749466, 52.85941198468208, 56.30901888012886, 55.068640038371086, 50.461277067661285, 44.16619285941124, 42.91599154472351, 41.58114217221737, 42.600376680493355, 41.37870043516159, 43.416914865374565, 43.96981559693813, 45.12753747403622, 42.10481107234955, 43.97727079689503, 39.405219331383705, 39.07520703971386, 37.21704214811325, 37.28012636303902, 39.44319449365139, 41.41939625144005, 40.21980062127113, 42.464948147535324, 45.22148363292217, 45.79222820699215, 45.84698706865311, 50.71213200688362, 53.7957539409399, 51.69151805341244, 53.38606372475624, 53.83008889853954, 54.86221231520176, 54.863143265247345, 55.20385578274727, 56.878532320261, 54.47663560509682, 55.46363644301891, 54.659876972436905, 51.596006378531456, 52.8422787040472, 52.39689700305462, 53.70040565729141, 53.343946784734726, 53.84577825665474, 54.44587245583534, 56.43069975078106, 58.03956761956215, 58.90146017074585, 54.236914068460464, 38.46882417798042, 21.37477833777666, 4.818898569792509, 0.2874097792664543, 1.1024984903633595, 1.2811656156554818, 0.9122585516888648, 8.432761151343584, 46.307833939790726, 49.906959012150764, 53.081244081258774, 47.03051336109638, 58.27912576496601, 55.28855703771114, 54.8745958507061, 20.408201403915882, 20.009072721004486, 53.152710646390915, 28.3613171428442, 31.545346789062023, 37.878039479255676, 46.91608630120754, 48.79869908094406, 32.70687036216259, 0.8343811961822212, 0.05826565786264837, 0.06738175463397056, 0.12001938754110597, 0.04754223249619827, 0.08431195397861302, 0.03714567494171206, 0.1072506105992943, 0.022911850246600807, 0.03034687677427428, 0.03537552656780463, 0.047721950977575034, 0.03420237662794534, 0.1351979625178501, 0.03230961432564072, 0.05624213285045698, 0.014390363121492555, 0.04279411266907118, 0.018853387846320402, 0.04510262981057167, 0.009191839435516158, 0.02676160031114705, 0.06035472935764119, 0.06935927391168661, 0.09009021930978633, 0.0501409998832969, 0.5952507059555501, 0.19189005950465798, 14.978293720632792, 58.25753532350063, 40.05850687623024, 36.38792663812637, 36.49220444262028, 58.313559517264366, 65.47248557209969, 9.202334806323051, 24.783455729484558, 66.23499065637589, 76.25012084841728, 64.96054664254189, 66.11944645643234, 55.31607136130333, 62.505787163972855, 48.40359628200531, 2.2876660572364926, 6.979918135330081, 4.748157290741801, 0.9141818422358483, 14.600440096110106, 44.24502722918987, 64.1081915795803, 62.3156301677227, 65.19125506281853, 68.24276491999626, 68.8855992257595, 61.980290561914444, 57.06886790692806, 53.487244695425034, 52.536524310708046, 57.781527265906334, 64.51806038618088, 62.996990606188774, 67.20833122730255, 56.8897645175457, 58.443421348929405, 62.79715172946453, 60.09057216346264, 63.82787302136421, 59.174266532063484, 62.32058510184288, 55.34375287592411, 61.715292781591415, 61.699607223272324, 59.89499285817146, 57.29323446750641, 50.500688552856445, 49.72177214920521, 45.64878210425377, 48.50599318742752, 45.625797137618065, 45.0076425075531, 42.55711980164051, 43.220921382308006, 44.093814343214035, 46.64085566997528, 48.35155047476292, 50.14161542057991, 46.02633744478226, 46.087229177355766, 43.46457950770855, 44.651837199926376, 45.68366423249245, 47.74674832820892, 52.46924892067909, 57.17887960374355, 57.29938633739948, 58.97671893239021, 55.154158249497414, 61.698338091373444, 60.86143299937248, 52.27392800152302, 30.13733234256506, 62.05636627972126, 59.36745576560497, 57.74936579167843, 60.018820613622665, 57.53251142799854, 52.874968349933624, 48.064365684986115, 45.37382125854492, 46.83305315673351, 43.81722718477249, 44.028180465102196, 46.12108156085014, 47.32930652797222, 47.13751941919327, 45.48380255699158, 47.118265852332115, 43.938003703951836, 41.96416921913624, 40.400952100753784, 40.47631725668907, 42.06833302974701, 44.24849644303322, 42.75324247777462, 46.98203556239605, 47.39553317427635, 48.40972155332565, 48.62376406788826, 53.84846851229668, 54.07809019088745, 53.80833126604557, 55.02778843045235, 56.75039179623127, 57.073568254709244, 56.47002384066582, 56.26404829323292, 57.71320693194866, 56.68882369995117, 57.62018792331219, 55.99985986948013, 54.63775455951691, 54.941563457250595, 55.31367368996143, 56.75638407468796, 55.12299992144108, 55.63369631767273, 57.47246704995632, 59.80584964156151, 60.970202162861824, 61.91233120858669, 58.32289941608906, 44.26038980484009, 25.778799019753933, 4.712427807971835, 0.2780648338375613, 1.1913588596507907, 3.482776740565896, 2.2565538017079234, 9.703654255717993, 51.79019495844841, 57.21231400966644, 57.310724928975105, 52.585017308592796, 62.76066608726978, 61.61084398627281, 59.536774680018425, 24.832142516970634, 22.368292026221752, 56.82455621659756, 34.836728274822235, 33.851714730262756, 49.92441147565842, 41.33406423032284, 54.86897595226765, 37.545656114816666, 1.1755749816074967, 0.0321376104693627, 0.03698653992614709, 0.02280941160279326, 0.04408553126268089, 0.060007890351698734, 0.046285705975606106, 0.034056488948408514, 0.09511386888334528, 0.026418023044243455, 0.003928598616766976, 0.023247288008860778, 0.1579316082643345, 0.1976518120500259, 0.17870411393232644, 0.20825164014240727, 0.26804815570358187, 0.20405687304446474, 0.19156778929755092, 0.12123425360186957, 0.14816812123171985, 0.09889989814837463, 0.1828817225759849, 0.2585438860114664, 0.31595874577760696, 0.21205906552495435, 0.9262194775510579, 0.8052505343221128, 25.744053684175014, 79.46644306182861, 60.618876814842224, 44.406989738345146, 45.08014261722565, 68.92700180411339, 76.78760960698128, 9.778107460588217, 28.507639691233635, 74.84109565615654, 82.12612554430962, 70.69117873907089, 73.03243070840836, 63.30061711370945, 68.23938310146332, 52.616092041134834, 3.141664769500494, 10.544447489082813, 6.357483034953475, 1.6387201356701553, 18.46398252993822, 51.745273768901825, 63.87946665287018, 61.178879365324974, 67.46781930327415, 71.36805921792984, 72.7680104970932, 62.93023578822613, 62.573590725660324, 55.74960149824619, 57.04019844532013, 60.44637367129326, 68.33484157919884, 66.71102151274681, 68.51417675614357, 61.14176295697689, 59.68625485897064, 61.315371841192245, 62.61106811463833, 65.6735859811306, 61.2222920358181, 66.12818598747253, 55.945230200886726, 60.55551901459694, 66.18404299020767, 61.68642573058605, 60.17348751425743, 52.403865829110146, 51.77920214831829, 46.601155400276184, 51.666108816862106, 48.013471215963364, 48.74528154730797, 46.40006639063358, 47.05703593790531, 46.194417625665665, 49.11904089152813, 50.7061967253685, 51.74016684293747, 47.429708540439606, 46.6747422516346, 44.260971173644066, 46.57764986157417, 47.79705002903938, 50.31170569360256, 56.983881667256355, 62.579704597592354, 59.29675295948982, 61.44309438765049, 57.4029041826725, 62.44339071214199, 51.66732855141163, 48.50471265614033, 22.087988667190075, 53.54648731648922, 65.3837451338768, 58.29756997525692, 64.39856439828873, 60.524782463908195, 56.720255613327026, 50.46158865094185, 46.87585785984993, 49.72668528556824, 46.23455487191677, 46.62508271634579, 48.80170851945877, 48.31708252429962, 48.803186640143394, 47.808525413274765, 52.23501428961754, 45.35496287047863, 45.20017057657242, 41.87265492975712, 42.51822888851166, 44.46713291108608, 45.93572370707989, 45.862969011068344, 50.19840717315674, 49.517783895134926, 52.648850083351135, 50.62345616519451, 57.925436943769455, 59.797159507870674, 58.11011843383312, 56.67257957160473, 57.50290721654892, 59.03159938752651, 58.95564146339893, 58.953901156783104, 60.90185143053532, 59.23800051212311, 60.78381076455116, 58.588170781731606, 55.406449511647224, 58.15190099179745, 57.827918976545334, 59.3311183154583, 56.42811208963394, 57.44374819099903, 60.85231348872185, 62.18281589448452, 62.8690704703331, 65.45601725578308, 61.49457022547722, 45.420197769999504, 32.36705459654331, 7.861808063462377, 1.7122720764018595, 2.0514410454779863, 3.0302870459854603, 1.9800527323968709, 11.9208181835711, 56.048269271850586, 61.201613545417786, 59.598703756928444, 55.96379220485687, 67.75283440947533, 66.79503500461578, 65.92388615012169, 31.864867843687534, 26.7521395906806, 65.07808953523636, 37.04872637987137, 44.85617123544216, 51.93057842552662, 54.750859290361404, 59.90519531071186, 57.372707203030586, 1.7477144370786846, 0.17876657308079302, 0.23782523057889193, 0.16680278145940974, 0.10872781102079898, 0.18446076050167903, 0.11059199692681432, 0.2500283351400867, 0.18851606320822611, 0.10486669125384651, 0.16203038598177955, 0.11861374499858357], [0.01044792530592531, 0.025101215578615665, 0.015658648044336587, 0.021815764921484515, 0.07443882946972735, 0.07297270931303501, 0.0040585853184893494, 0.05525543267140165, 0.07107842931873165, 0.06033190089510754, 0.03726981769432314, 0.09134524298133329, 0.13534220634028316, 0.05823540792334825, 0.18911815277533606, 0.2170624618884176, 3.7201794516295195, 31.01426638662815, 35.75075022876263, 31.878419816493988, 27.027375921607018, 24.13502622395754, 80.21978303790092, 30.41680544614792, 18.367199823260307, 54.56730253994465, 70.31735479831696, 61.544294357299805, 64.53621581196785, 50.07744066417217, 54.08943258225918, 53.46073731780052, 3.2633378030732274, 6.900814929977059, 1.275866087526083, 0.7759076182264835, 6.463783755898476, 32.00960397720337, 61.009982228279114, 62.099512964487076, 67.49488145112991, 67.8965274989605, 65.45693680644035, 59.48230840265751, 56.98345988988876, 49.51524943113327, 49.00263033807278, 46.15593709051609, 53.70132900774479, 59.82777826488018, 60.34130170941353, 61.375834196805954, 50.20350269973278, 58.388719484210014, 65.31374529004097, 57.36933298408985, 60.13553515076637, 52.00772188603878, 59.496170058846474, 59.18698824942112, 56.87944807112217, 56.95233575999737, 52.59767822921276, 48.38082030415535, 46.6779188811779, 44.080427661538124, 44.74812023341656, 43.51175777614117, 42.930316776037216, 43.23388248682022, 42.985341623425484, 43.19667488336563, 45.26537127792835, 50.709795132279396, 46.26529902219772, 41.82261161506176, 41.42866015434265, 40.544588193297386, 41.288861855864525, 40.77506482601166, 42.63289913535118, 51.96879297494888, 54.217649102211, 55.5156784504652, 54.37413610517979, 54.15909044444561, 54.33140739798546, 46.90206125378609, 41.31947301328182, 33.00174593925476, 47.66667142510414, 57.32474237680435, 52.14150510728359, 53.6209861189127, 53.97382378578186, 48.59046645462513, 42.76370331645012, 43.191446363925934, 41.42228789627552, 42.495536506175995, 39.881219789385796, 42.827216908335686, 44.130945950746536, 45.10082870721817, 43.69045078754425, 44.297320023179054, 42.56846219301224, 38.492854088544846, 38.12550500035286, 37.17675291001797, 40.177904069423676, 38.8622360676527, 41.13530069589615, 41.42280466854572, 45.92137947678566, 43.7713560461998, 42.566566094756126, 44.2548269033432, 48.832574263215065, 50.94273783266544, 52.13253378868103, 57.027195543050766, 54.84726011753082, 55.82380011677742, 58.409359976649284, 56.4250760525465, 53.64477664232254, 54.389038905501366, 55.67046694457531, 54.16298143565655, 52.2583070397377, 50.29500558972359, 57.422047555446625, 54.914071932435036, 53.44024881720543, 53.90370234847069, 57.20099061727524, 53.62144589424133, 58.124622255563736, 57.93880082666874, 45.67945025861263, 22.18111217021942, 2.6021162839606404, 0.16543035744689405, 1.8667770107276738, 1.7689161119051278, 1.8159245769493282, 9.262732565402985, 52.12563335895538, 53.49626921117306, 42.873411029577255, 44.02739770710468, 49.17225323617458, 51.68394885957241, 47.843890115618706, 17.262034825980663, 32.261066883802414, 48.54014575481415, 26.838780641555786, 40.66735200583935, 38.83767418563366, 30.815195068717003, 57.35216170549393, 13.463048078119755, 0.2195565975853242, 0.016539568059670273, 0.14264563709730282, 0.0968248606659472, 0.08808624246739782, 0.011043812373827677, 0.07300421348190866, 0.033339173533022404, 0.07243591389851645, 0.05612414992356207, 0.06662599596893415, 0.10471916713868268, 0.02128757470927667, 0.06956317156436853, 0.007669171800444019, 0.04574518869048916, 0.09056721988599747, 0.04251491300237831, 0.05201251449761912, 0.10196371382335201, 0.0795095757348463, 0.014238793373806402, 0.045459773537004367, 0.11059939613915049, 0.14620073226979002, 0.10760213626781479, 0.2343826598371379, 0.11654934249236248, 4.788807034492493, 45.00551462173462, 42.96550668776035, 33.63096937537193, 38.07838752865791, 29.459870494902134, 81.0945188999176, 27.112740240991116, 23.292161151766777, 59.26222801208496, 77.82701343297958, 66.57739028334618, 69.39005255699158, 54.75335955619812, 60.47640725970268, 56.85439221560955, 3.532792031764984, 5.713626109063625, 3.920400207862258, 0.5627019493840635, 7.503743777051568, 36.27709038555622, 63.92372667789459, 63.44698905944824, 66.21010959148407, 71.91542744636536, 67.72758856415749, 63.105440586805344, 57.40702696144581, 53.15573908388615, 50.848780274391174, 49.06052403151989, 56.96295239031315, 63.05898427963257, 63.33207182586193, 65.51916986703873, 55.955261662602425, 63.166651502251625, 63.489858359098434, 59.13482844829559, 61.89092695713043, 55.691213831305504, 63.35651971399784, 64.27269995212555, 58.90038102865219, 58.72333712875843, 55.244885981082916, 50.604525581002235, 49.290145710110664, 46.68115630745888, 46.13592356443405, 45.18314749002457, 44.26911413669586, 43.714260309934616, 43.45611356198788, 44.9272084236145, 46.6634226590395, 51.55004024505615, 51.02460823953152, 46.08707718551159, 42.47877940535545, 44.89033900201321, 43.53586748242378, 45.59245392680168, 45.11796198785305, 53.199102357029915, 57.01568976044655, 57.98143833875656, 57.14279294013977, 56.45460806787014, 57.12233103811741, 60.606820061802864, 50.50481133162975, 49.37198951840401, 67.17455863952637, 55.15898019075394, 58.71384523808956, 57.85986386239529, 56.99397012591362, 50.11911682784557, 46.4998984336853, 43.662279099226, 44.75563623011112, 43.398941829800606, 45.02109758555889, 46.59077815711498, 48.543804958462715, 46.22689828276634, 44.600821137428284, 45.6904848664999, 44.652213379740715, 40.83614654839039, 41.43021807074547, 40.414011999964714, 43.0007079988718, 42.32293076813221, 44.14874419569969, 43.90692517161369, 48.951743468642235, 46.71502389013767, 44.22072373330593, 46.370731964707375, 51.81793726980686, 54.0806170552969, 54.76373679935932, 56.6418582201004, 55.89417614042759, 57.33988456428051, 58.48288983106613, 58.517091795802116, 56.813217625021935, 57.1322713047266, 57.37610042095184, 57.1525964140892, 56.76570117473602, 54.26964931190014, 59.053683802485466, 56.552901193499565, 55.64174048602581, 54.85708259046078, 58.670603558421135, 57.02586181461811, 63.17733272910118, 61.5220807492733, 51.36590972542763, 28.27120117843151, 4.0875893365591764, 0.16729469178244472, 0.8464590855874121, 1.4638359448872507, 0.9689243172761053, 11.77258338779211, 54.68567378818989, 59.02065597474575, 48.233255222439766, 48.26827794313431, 52.77648903429508, 59.20080430805683, 50.8436543494463, 22.45653659105301, 36.1201436072588, 55.60504965484142, 27.181944027543068, 46.96830689907074, 42.45153106749058, 29.48092896491289, 67.03278064727783, 14.737055115401745, 0.372243047459051, 0.106997753464384, 0.08750928202061914, 0.059491366700967774, 0.05927256301220041, 0.04370252740045544, 0.10012538434239104, 0.03840724806650542, 0.07739467750070617, 0.06387043133145198, 0.016506978499819525, 0.06989729386987165, 0.14263606339227408, 0.12978291168110445, 0.11389994208002463, 0.23629407602129504, 0.16648812568746507, 0.25077995262108743, 0.11358316376572475, 0.1781232497887686, 0.28197423031087965, 0.1674467875272967, 0.26718301931396127, 0.2914136659819633, 0.48704815737437457, 0.28586088737938553, 0.6258958240505308, 0.44396975019481033, 7.712503625079989, 63.38179595768452, 62.58998304605484, 49.50122058391571, 40.69428876042366, 39.352508559823036, 100.06835997104645, 35.06699591875076, 27.20210574567318, 62.7813483774662, 84.47721898555756, 72.42100551724434, 77.04113200306892, 60.71044810116291, 67.44713321328163, 60.71605660021305, 5.292846662923694, 11.47078838199377, 5.669926078990102, 1.4147290424443781, 11.038816161453724, 43.33940662443638, 66.59417018294334, 63.46802473068237, 70.78320980072021, 74.81289356946945, 71.70947089791298, 64.97809410095215, 62.44758568704128, 55.429730862379074, 54.085237607359886, 52.72741086781025, 60.25133393704891, 65.50832524895668, 67.65294536948204, 67.27408289909363, 57.715851590037346, 61.56725652515888, 62.94036224484444, 61.71952575445175, 64.97750893235207, 58.84483940899372, 61.641211956739426, 66.31097137928009, 61.418274119496346, 59.932614639401436, 57.41611987352371, 52.98941820859909, 53.76195475459099, 49.66376066207886, 49.20369654893875, 46.498777493834496, 50.04551097750664, 46.382891312241554, 46.54601275920868, 48.00165005028248, 49.521230310201645, 55.128125846385956, 50.96245497465134, 48.23273845016956, 44.01387803256512, 46.37993887066841, 46.5902803838253, 47.88165628910065, 47.067827358841896, 56.37930750846863, 59.79410447180271, 62.23095931112766, 59.62700083851814, 58.58154393732548, 59.44892719388008, 61.74730606377125, 47.645947337150574, 38.59634153544903, 61.91443249583244, 60.421374812722206, 60.07925637066364, 60.447726398706436, 60.254244580864906, 52.21331365406513, 48.323234394192696, 47.264694795012474, 47.65489965677261, 46.52414113283157, 45.46947732567787, 47.44974486529827, 48.50086726248264, 49.06337007880211, 46.71863749623299, 49.152163714170456, 47.057818695902824, 43.33056449890137, 43.40702399611473, 41.97686053812504, 44.89829957485199, 45.675464272499084, 47.926923260092735, 45.535046607255936, 50.28656244277954, 49.31397423148155, 45.770246386528015, 48.93800340592861, 54.82767976820469, 56.740595921874046, 55.46563893556595, 60.97174488008022, 57.743548303842545, 59.93908189237118, 60.122691839933395, 61.762892827391624, 57.26979732513428, 57.73627929389477, 57.998780608177185, 58.77378322184086, 57.31722258031368, 57.52725251019001, 60.55895783007145, 60.19598610699177, 58.306621089577675, 57.97963723540306, 60.69874472916126, 58.52602131664753, 65.99632546305656, 66.23993039131165, 53.37345600128174, 32.14584566652775, 7.079450469464064, 0.7734371570404619, 4.231879943981767, 4.112091371789575, 3.7986108055338264, 15.011828821152449, 63.055138885974884, 62.458487302064896, 52.27194830775261, 53.5529013723135, 62.4111570417881, 63.54687049984932, 60.67702129483223, 24.316071309149265, 44.2431653290987, 57.2944276034832, 35.26568725705147, 57.24716953933239, 51.444447711110115, 41.90960794687271, 71.70569390058517, 27.27271355688572, 0.7485123944934458, 0.12388119750539772, 0.2581233554519713, 0.1272562996018678, 0.17708099243463948, 0.17175332206534222, 0.18514343246351928, 0.14499952172627673, 0.15635405463399366, 0.11639488671789877, 0.1387071335921064, 0.1977291883667931], [0.06522175608552061, 0.12495966424467042, 0.005649645572702866, 0.030974151122791227, 0.04770017636474222, 0.04202327356324531, 0.03752657110453583, 0.023004568611213472, 0.05496452191437129, 0.039551858717459254, 0.0894036288082134, 0.0686621003842447, 0.11518990606418811, 0.03278221396612935, 0.12490481953136623, 0.13611819595098495, 0.17663359612924978, 15.065751727670431, 45.985037460923195, 37.227943763136864, 35.001962408423424, 23.341486304998398, 59.63498800992966, 43.6730021238327, 23.832292668521404, 50.24480648338795, 69.38729390501976, 65.90791180729866, 62.31881059706211, 56.34058378636837, 56.10380709171295, 53.31642486155033, 6.381225110962987, 5.8126696944236755, 5.4332999512553215, 0.5295203486457467, 3.8165710167959332, 28.688458688557148, 63.80973279476166, 69.47152778506279, 64.48933392763138, 66.79411545395851, 65.49876496195793, 63.13342608511448, 60.203410908579826, 48.6866544932127, 48.94812226295471, 46.91595330834389, 46.48613557219505, 52.81966611742973, 56.81671343743801, 62.76258498430252, 60.81335037946701, 52.74718880653381, 57.41668604314327, 62.832166850566864, 58.77873815596104, 59.757440239191055, 63.85660707950592, 59.130413085222244, 57.5173844397068, 54.046863466501236, 49.483448937535286, 48.302764892578125, 46.51199318468571, 45.32651759684086, 43.213716968894005, 40.546138510107994, 40.30289836227894, 42.179283276200294, 44.41920608282089, 45.565840154886246, 46.840379163622856, 48.921489492058754, 46.38002626597881, 42.18944393098354, 42.65458457171917, 40.182680413126945, 41.31634198129177, 42.526288256049156, 43.864196464419365, 52.94018045067787, 55.93591310083866, 54.0123575180769, 55.66817566752434, 56.98320910334587, 53.077170699834824, 53.59039396047592, 45.661040246486664, 39.0684700012207, 52.888921201229095, 53.44526454806328, 54.53698396682739, 51.47205702960491, 55.820965468883514, 49.085963666439056, 44.47617642581463, 44.593806713819504, 41.71724706888199, 43.07309031486511, 40.265276581048965, 40.436746180057526, 41.156093180179596, 46.46470092236996, 43.89992214739323, 43.013726100325584, 41.82242922484875, 39.50555294752121, 39.7508829832077, 37.82693222165108, 40.679826736450195, 39.6842497587204, 40.24617500603199, 41.15410588681698, 42.494335770606995, 42.205129489302635, 41.08614273369312, 42.02644407749176, 44.42674107849598, 47.2406192868948, 51.59772388637066, 53.269231393933296, 55.812286734580994, 56.476548090577126, 54.42826800048351, 56.82929076254368, 55.08749462664127, 54.79477733373642, 54.87672373652458, 53.20575200021267, 51.15282095968723, 56.6020667552948, 54.457921609282494, 51.41079671680927, 49.52211946249008, 49.922086000442505, 51.70213848352432, 54.66675840318203, 56.71009495854378, 60.966713950037956, 55.98463788628578, 39.15260128676891, 6.816437607631087, 0.21384544466855004, 0.9495978418271989, 5.640831990167499, 1.4162917085923254, 12.182664033025503, 47.217934504151344, 56.87956966459751, 47.96837903559208, 41.70418716967106, 59.501968547701836, 57.535942643880844, 39.597527012228966, 18.02893817424774, 45.44127143919468, 44.6642055362463, 23.28647095710039, 39.25422303378582, 23.855127543210983, 40.750195160508156, 49.73873823881149, 3.248170679435134, 0.24606931867310777, 0.04588543975842185, 0.1222071869415231, 0.07638244002009742, 0.07687978286412545, 0.09694614986074157, 0.07380223003565334, 0.05667804813128896, 0.054718960091122426, 0.08494314315612428, 0.03227921224606689, 0.04766172569361515, 0.03946689765143674, 0.08402362960623577, 0.06372125222696923, 0.04097087476111483, 0.0348435031628469, 0.07176640763645992, 0.027128798283229116, 0.01701126227999339, 0.018193145442637615, 0.028752008838637266, 0.02082406081171939, 0.08125056512653828, 0.11296451688394882, 0.10155537675018422, 0.11243401488172822, 0.173002980009187, 0.5710730189457536, 22.77272142469883, 62.99362398684025, 34.702063500881195, 48.09663735330105, 28.165840432047844, 59.54951159656048, 42.25738808512688, 25.931165143847466, 56.01148724555969, 73.3423800766468, 71.99482798576355, 66.84651464223862, 61.14941194653511, 59.17362816631794, 60.69776438176632, 6.422303756698966, 3.3264274802058935, 2.700306340120733, 1.2854650849476457, 4.538084613159299, 33.00796240568161, 66.7918811738491, 72.27345183491707, 66.61681696772575, 68.14497336745262, 68.50349932909012, 67.5063568353653, 61.946943551301956, 51.680768430233, 51.582722291350365, 50.25540791451931, 51.29272945225239, 54.033074006438255, 62.67673999071121, 62.77836933732033, 61.93512998521328, 54.763877391815186, 63.289757296442986, 63.685981035232544, 59.58097390830517, 62.06905759871006, 67.70929634571075, 60.77515482902527, 60.22227309644222, 57.052293196320534, 52.08756700158119, 49.02183070778847, 49.255681559443474, 46.535282135009766, 45.962124690413475, 42.63752728700638, 45.266256630420685, 41.90237693488598, 45.49078278243542, 47.77606375515461, 46.83413229882717, 52.43727743625641, 48.63968901336193, 45.68186312913895, 44.64221991598606, 45.04777975380421, 44.81631897389889, 44.49204437434673, 46.51908740401268, 55.47421507537365, 57.65119805932045, 59.557415172457695, 57.71927900612354, 59.56168994307518, 57.40617960691452, 59.35216538608074, 54.428594782948494, 58.55019561946392, 62.97014884650707, 56.397964507341385, 57.2528350353241, 56.251877546310425, 58.11740264296532, 51.645981296896935, 47.78194963932037, 47.40223601460457, 43.585553616285324, 45.67612923681736, 44.966802299022675, 43.61009269952774, 44.75088268518448, 48.59287932515144, 46.705345809459686, 45.158851593732834, 43.64266835153103, 41.74014464020729, 42.49015599489212, 42.61283241212368, 43.36739972233772, 42.2941929101944, 43.60305927693844, 43.93894985318184, 44.53813210129738, 46.36627100408077, 44.450679793953896, 44.36844080686569, 48.638328686356544, 51.477581933140755, 53.656107634305954, 53.930639103055, 56.57174438238144, 56.49843491613865, 56.756509467959404, 57.95922473073006, 57.91214905679226, 57.88912609219551, 56.01261578500271, 57.02515125274658, 55.508675426244736, 57.8547303378582, 55.125063210725784, 54.00249324738979, 52.99797534942627, 52.15637370944023, 53.63632209599018, 57.00566589832306, 57.81169004738331, 65.41738092899323, 58.183876276016235, 46.57708749175072, 9.052568692713976, 0.06303455782472156, 1.374231765512377, 1.9830334349535406, 2.2175636189058423, 14.70637746155262, 53.33609640598297, 62.119990065693855, 54.25450712442398, 46.158437356352806, 66.77084550261497, 61.97027049958706, 46.0069926828146, 21.989021077752113, 49.9185673892498, 51.01475536823273, 23.81709348410368, 51.04023680090904, 24.18308414518833, 45.42552508413792, 56.61694295704365, 2.8695029485970736, 0.30857146717607975, 0.07401268085232005, 0.02531292619096348, 0.11522748100105673, 0.053730115105281584, 0.06259386311285198, 0.04533432089374401, 0.09530556562822312, 0.0028162748685645056, 0.0544924900168553, 0.01929678583110217, 0.04143176331126597, 0.1337853289442137, 0.3823065402684733, 0.17958070908207446, 0.1735547964926809, 0.22457212064182386, 0.158770784328226, 0.2430776323308237, 0.1839996938360855, 0.24648840946611017, 0.1366492619854398, 0.23789138562278822, 0.18365094379987568, 0.40805090102367103, 0.2468060189858079, 0.29534155677538365, 0.24486775189870968, 0.9462577616795897, 38.90770822763443, 83.4663288295269, 55.76116807758808, 50.36885462701321, 35.81660829484463, 74.13950130343437, 50.03917671740055, 29.59303054958582, 62.06846483051777, 81.01055860519409, 77.200358659029, 73.99266958236694, 70.38706585764885, 65.95771953463554, 65.37500560283661, 8.227182682603598, 8.22556871920824, 11.700382512062788, 2.631262382492423, 6.131041785702109, 40.943779572844505, 70.51226153969765, 73.81062895059586, 67.39328250288963, 72.53084242343903, 74.23252791166306, 69.84413579106331, 65.49184933304787, 54.250327348709106, 55.18369026482105, 53.7966924905777, 53.84438373148441, 56.839903593063354, 65.58935210108757, 66.6546705365181, 65.235226303339, 61.12098187208176, 66.56151473522186, 65.99821016192436, 64.44730058312416, 61.24362409114838, 68.32350298762321, 64.16029438376427, 64.11731868982315, 58.47410850226879, 53.654599115252495, 51.60223804414272, 52.30190210044384, 49.34021942317486, 47.59938843548298, 45.8925998210907, 47.01428823173046, 45.53494781255722, 48.84539857506752, 50.06522811949253, 51.22189365327358, 52.89922244846821, 50.66590368747711, 46.69994629919529, 47.694166749715805, 46.86994157731533, 46.724416986107826, 47.041346579790115, 49.78042960166931, 59.33798834681511, 62.12887018918991, 61.095211654901505, 60.567864552140236, 63.872543424367905, 57.16077357530594, 61.3391737639904, 54.142382740974426, 48.73429633677006, 64.52885940670967, 57.60401979088783, 60.0996308773756, 59.93207506835461, 60.853624418377876, 55.140919759869576, 53.18431355059147, 52.23582744598389, 45.654052421450615, 48.709502667188644, 45.52034139633179, 44.34121906757355, 45.32505847513676, 48.913061544299126, 49.079420417547226, 47.332654148340225, 46.309300661087036, 44.05623055994511, 44.68999855220318, 43.609788715839386, 47.15326577425003, 46.46431714296341, 45.425137504935265, 48.00155885517597, 47.26173095405102, 48.60706016421318, 47.24677115678787, 45.86364157497883, 51.67521692812443, 53.1771357357502, 57.61905178427696, 57.61578015983105, 58.26442055404186, 59.36165727674961, 59.337547570466995, 60.99896281957626, 59.91324707865715, 58.41235801577568, 57.88673982024193, 58.861220329999924, 57.86609172821045, 60.486708506941795, 57.5456777215004, 55.195458233356476, 54.56671357154846, 54.97574642300606, 58.65014165639877, 59.071751832962036, 62.37511217594147, 68.44533205032349, 62.10703656077385, 48.084474205970764, 12.526328042149544, 0.441557532758452, 3.3137988578528166, 10.80497670918703, 4.637427907437086, 17.07688596099615, 59.092992693185806, 66.3715249300003, 58.544161543250084, 51.02534919977188, 71.68019726872444, 66.93552106618881, 51.076828837394714, 24.891303442418575, 57.66445554792881, 52.50058203935623, 34.096535593271255, 59.17277321219444, 35.86543567478657, 55.416328981518745, 72.734564691782, 8.86397436261177, 0.7173708686605096, 0.28088983381167054, 0.31578526133671403, 0.2848897426156327, 0.2501173038035631, 0.37274278001859784, 0.2189420399372466, 0.33024550415575504, 0.21427486615721136, 0.2357516105985269, 0.2117799734696746, 0.1406139781465754], [0.11280197169980966, 0.14436543075134978, 0.045725540330749936, 0.046534110224456526, 0.035343896233825944, 0.025421747304790188, 0.08110919341561384, 0.050756748678395525, 0.08253590553067625, 0.0409062114340486, 0.026928564984700643, 0.011814813824457815, 0.06561044108821079, 0.06463318844907917, 0.05474299454363063, 0.243889230187051, 0.09042913588928059, 7.295065624639392, 30.55355440825224, 32.87322163581848, 35.42263403534889, 24.721285365521908, 51.154477670788765, 73.81708860397339, 22.029745392501354, 36.42753951251507, 64.77901518344879, 62.973872646689415, 59.604183062911034, 59.472656920552254, 60.37184067070484, 51.80670507252216, 7.237901017069817, 2.1664074389263988, 5.22331134416163, 0.502246362157166, 4.3622837215662, 32.085216119885445, 67.83484920859337, 72.8948400914669, 67.92199373245239, 67.26058602333069, 67.30612277984619, 66.13798186182976, 61.87026746571064, 52.324982061982155, 45.65547354519367, 45.81416442990303, 46.620880141854286, 47.42835581302643, 51.70711241662502, 58.17591190338135, 59.6251617372036, 61.265275329351425, 56.426554173231125, 56.63612052798271, 61.06440290808678, 62.103054374456406, 57.20141239464283, 55.69261595606804, 52.60783888399601, 53.196271508932114, 46.44797042012215, 45.934769958257675, 43.90989661216736, 44.72222462296486, 41.71418063342571, 42.63406567275524, 41.1723031103611, 42.804072350263596, 43.069928884506226, 46.87024176120758, 46.449779123067856, 48.37459243834019, 45.828763246536255, 42.32837587594986, 42.09875799715519, 40.031326934695244, 42.41569899022579, 42.771135717630386, 44.510104805231094, 55.39298303425312, 53.967010751366615, 55.519763231277466, 58.09768930077553, 55.68476937711239, 53.56312282383442, 55.8810630440712, 49.25483800470829, 45.14607287943363, 54.08981256186962, 53.607265055179596, 54.67171333730221, 53.976768627762794, 54.570695757865906, 51.71642191708088, 44.28287699818611, 43.03454898297787, 40.639556497335434, 41.81373909115791, 41.01206190884113, 40.742853954434395, 41.24775946140289, 45.1964657753706, 48.5684884339571, 42.519023045897484, 43.174940049648285, 41.36662848293781, 39.60746727883816, 36.200216710567474, 38.5877425968647, 40.30837766826153, 40.70422522723675, 39.014087319374084, 41.88922204077244, 42.67008014023304, 41.58392362296581, 41.918358877301216, 42.67696537077427, 46.17254599928856, 50.386090502142906, 54.14153918623924, 54.072690680623055, 54.228235334157944, 56.249700263142586, 55.24267449975014, 55.809448286890984, 57.265704944729805, 53.57128098607063, 53.61231118440628, 52.48217962682247, 58.73841851949692, 54.796042665839195, 52.48630240559578, 50.041863173246384, 48.399294912815094, 48.54309819638729, 55.25023229420185, 56.26708433032036, 58.555344343185425, 59.462025091052055, 54.89984169602394, 23.321423381567, 0.2659477590350434, 0.1651976496214047, 0.2761829551309347, 0.057357703262823634, 12.234651893377304, 44.82923828065395, 58.821166679263115, 49.02375340461731, 56.05439454317093, 60.42811945080757, 53.00530895590782, 31.235841996967793, 34.48644407093525, 52.90826976299286, 21.502459086477757, 32.97628350555897, 28.579319044947624, 23.83632805198431, 52.81948372721672, 29.43950168788433, 0.3337821050081402, 0.017058813537005335, 0.14222654630430043, 0.07198115548817441, 0.061102034960640594, 0.016451664378109854, 0.02597607595816953, 0.04506391938775778, 0.0464531567558879, 0.015416548339999281, 0.07712259874097072, 0.009159531891782535, 0.05794215569039807, 0.05644294687954243, 0.036523328453768045, 0.025709869441925548, 0.02257132135127904, 0.03782587555178907, 0.08317454587086104, 0.020756642261403613, 0.009079313149413792, 0.037502922568819486, 0.010511391919862945, 0.023992493333935272, 0.009169634377030889, 0.06894743390148506, 0.015453653868462425, 0.04289959411835298, 0.18131628079572693, 0.07389633436105214, 7.682829592376947, 45.611794888973236, 38.22958901524544, 38.14841017127037, 34.273245111107826, 58.746261298656464, 72.54115507006645, 23.323718458414078, 41.648128777742386, 67.53220304846764, 67.52343311905861, 66.10074386000633, 63.446905463933945, 66.06843799352646, 57.9359395802021, 9.270928725600243, 2.2382095735520124, 3.100126823410392, 0.4616438189987093, 5.421960409730673, 36.8543516099453, 71.39204353094101, 74.2744092643261, 69.62630867958069, 70.25583609938622, 68.229511231184, 68.17559212446213, 65.2197839319706, 54.98295083642006, 50.65650299191475, 49.074454084038734, 49.62892033159733, 50.34091852605343, 52.65807218849659, 59.504548609256744, 64.84675794839859, 64.74773526191711, 57.879945784807205, 60.25304764509201, 63.48198518157005, 65.01153230667114, 59.27781477570534, 58.338778764009476, 55.00514164566994, 54.149077981710434, 49.76152561604977, 48.328345119953156, 46.37355901300907, 46.37078136205673, 44.05388988554478, 43.582775965332985, 43.18788595497608, 45.25684453547001, 44.1857124119997, 46.45020090043545, 47.686456963419914, 50.99451005458832, 49.14210565388203, 44.351816698908806, 43.33741933107376, 43.88964369893074, 46.20863266289234, 46.92182779312134, 48.20560410618782, 56.751964911818504, 60.050180330872536, 59.523406997323036, 60.2776513248682, 59.773946553468704, 59.11427155137062, 57.46017470955849, 56.88580892980099, 59.92842726409435, 60.27955502271652, 56.29089005291462, 58.22344355285168, 58.01469795405865, 57.50150889158249, 52.240052819252014, 45.64111791551113, 44.19876851141453, 43.31989087164402, 44.43775288760662, 42.25448124110699, 43.48638653755188, 42.190500274300575, 47.343373373150826, 50.62463030219078, 44.9045692384243, 44.20256070792675, 42.868368700146675, 43.207910880446434, 41.09334334731102, 40.176764130592346, 43.199216946959496, 44.6536573022604, 42.771280109882355, 43.80829006433487, 45.48042833805084, 45.28223097324371, 44.991371780633926, 45.504526644945145, 49.726624488830566, 52.525846883654594, 56.19948975741863, 54.221581891179085, 55.071056708693504, 57.913250997662544, 57.091567888855934, 58.33596311509609, 57.66326241195202, 55.973390489816666, 56.98613114655018, 54.95466135442257, 59.653713405132294, 56.7102013528347, 54.003454595804214, 53.61218199133873, 49.86155904829502, 52.88993574678898, 56.93302519619465, 59.68654744327068, 61.71671390533447, 62.405947521328926, 58.49797882139683, 30.574557781219482, 0.4232099500950426, 0.2110558599815704, 0.5975756468251348, 0.5881655705161393, 14.207919258624315, 50.28879672288895, 64.19940188527107, 53.6500583589077, 57.810580506920815, 66.20839968323708, 57.818366289138794, 36.647832691669464, 39.52510669827461, 58.68586353957653, 24.51402548700571, 35.64689800143242, 37.973110377788544, 24.25459060817957, 63.55347454547882, 28.804179579019547, 0.5018549831584096, 0.005790579416498076, 0.14123886649031192, 0.060251522590988316, 0.08641816908493638, 0.0146936046621704, 0.025417396464035846, 0.03987173178757075, 0.06492273736512288, 0.023211375482787844, 0.09873978720861487, 0.04482286240090616, 0.02957644399430137, 0.17289091571001336, 0.2989421901293099, 0.16115551261464134, 0.09338150324765593, 0.11202891357243061, 0.18323860655073076, 0.11307493361528032, 0.07935625544632785, 0.127650068316143, 0.35822693549562246, 0.1718149203225039, 0.12343810565653257, 0.28056696988642216, 0.14861820411169901, 0.16964633512543514, 0.5155588290654123, 0.47768394579179585, 12.888047732412815, 63.605512753129005, 58.3640094101429, 49.96528588235378, 40.927812829613686, 66.90486431121826, 85.7391008734703, 26.415061578154564, 47.07028582692146, 73.68867829442024, 75.51891088485718, 72.022824883461, 70.40121629834175, 72.33014479279518, 63.04333671927452, 10.570795275270939, 5.741736050695181, 11.871495880186558, 2.0129120629280806, 6.830947129055858, 40.18864989280701, 73.47446858882904, 78.79522427916527, 73.38588774204254, 75.16530945897102, 71.38424634933472, 73.56311023235321, 67.40109488368034, 58.40649113059044, 51.22579604387283, 51.59493863582611, 51.99829459190369, 53.89427125453949, 55.629885122179985, 63.42119604349136, 67.69491031765938, 66.78148493170738, 60.658846870064735, 64.57247346639633, 65.99745020270348, 67.12008476257324, 62.06392787396908, 59.94182154536247, 56.83768071234226, 57.0988254994154, 50.46897925436497, 50.898679196834564, 47.64637291431427, 49.66756045818329, 48.037835508584976, 48.12777288258076, 45.651772543787956, 49.08181428909302, 47.029666006565094, 49.017677530646324, 49.590534791350365, 54.204072430729866, 49.320475682616234, 45.80382518470287, 45.5230088531971, 46.47150255739689, 48.13848450779915, 48.28361012041569, 52.08360381424427, 59.22083683311939, 61.50877386331558, 62.324491292238235, 63.47153954207897, 61.27189837396145, 60.857637003064156, 62.32992120087147, 53.6582887172699, 55.547125563025475, 59.44504000246525, 58.46812002360821, 62.59515456855297, 60.73795482516289, 61.52356646955013, 54.47090931236744, 48.47017250955105, 44.924423173069954, 44.75246340036392, 45.95479868352413, 45.053574442863464, 45.875352546572685, 44.02307353913784, 48.29169608652592, 52.13673256337643, 46.616806760430336, 48.986910581588745, 44.90813344717026, 44.07792739570141, 41.388557106256485, 43.935533836483955, 45.761164873838425, 47.19161331653595, 43.98460440337658, 46.67718172073364, 48.617182821035385, 47.72090591490269, 46.68234944343567, 48.295389488339424, 53.38943414390087, 55.599220767617226, 60.21753095090389, 56.83366812765598, 55.803832188248634, 61.26312464475632, 59.960816726088524, 60.14031529426575, 62.1846017986536, 58.144970163702965, 60.779011622071266, 58.27264331281185, 62.994437143206596, 61.67030319571495, 57.63346441090107, 58.78623515367508, 53.86625915765762, 54.92119275033474, 58.913744911551476, 64.66031715273857, 65.56868121027946, 67.41338342428207, 58.40776026248932, 34.61129017174244, 0.5990316811949015, 0.5841592198703438, 1.9638557452708483, 1.1481086304411292, 18.41233380138874, 54.932105764746666, 67.52688333392143, 59.161894395947456, 64.90432485938072, 70.22733762860298, 64.00832533836365, 40.540412217378616, 41.69709675014019, 63.51317770779133, 28.06718822568655, 49.13220718502998, 40.925118774175644, 38.738507106900215, 68.65536198019981, 48.29929567873478, 0.9000493912026286, 0.0807573708880227, 0.23544148192740977, 0.1441997240181081, 0.17254173522815108, 0.06433978778659366, 0.09281441336497664, 0.12667227390920743, 0.14045797870494425, 0.07022537509328686, 0.26809547503944486, 0.10947041882900521, 0.13005196989979595], [0.023378661135211587, 0.04284586633730214, 0.059546634438447654, 0.09231256568455137, 0.05963086077827029, 0.011699300393956946, 0.002140756050721393, 0.06106975153670646, 0.029120162325853016, 0.10491254855878651, 0.022413286569644697, 0.013574580480053555, 0.042498775001149625, 0.06146142368379515, 0.03607946477131918, 0.15364750142907724, 0.26895681163296103, 1.1406971281394362, 23.13720166683197, 48.8942601531744, 35.662914142012596, 31.77462838590145, 19.87797025591135, 75.72755008935928, 36.91214270889759, 26.957554668188095, 60.69375179708004, 74.79109033942223, 65.43372005224228, 58.752162382006645, 59.1349196434021, 57.24831707775593, 14.195598419755697, 1.3065207051113248, 1.9870809302665293, 0.5449530424084514, 10.17359783872962, 46.26106224954128, 72.1722024679184, 70.8475099503994, 64.99770104885101, 64.92544412612915, 65.82009851932526, 66.32278874516487, 60.7909581810236, 50.777598693966866, 47.479185685515404, 47.75660879909992, 44.192985221743584, 47.21887305378914, 44.346979558467865, 49.69863139092922, 53.766343519091606, 57.92716585099697, 58.9522710442543, 60.02834290266037, 54.26532134413719, 55.17677463591099, 52.96685881912708, 53.95442582666874, 50.38107857108116, 48.46753165125847, 47.406742572784424, 46.42524763941765, 44.83271509408951, 44.00348179042339, 42.41371929645538, 42.95644037425518, 41.86324663460255, 43.78528609871864, 44.93593655526638, 47.69308000802994, 44.805288165807724, 48.13341937959194, 43.43205705285072, 43.09406518936157, 41.44657999277115, 39.80420172214508, 41.307803839445114, 43.07034686207771, 48.57485309243202, 57.159234657883644, 53.237434700131416, 55.653022080659866, 54.438698440790176, 55.69690212607384, 54.58377085626125, 56.52931585907936, 48.48314881324768, 51.4987999945879, 55.702689215540886, 53.50287705659866, 55.14680564403534, 54.61950033903122, 54.25918087363243, 50.9175755828619, 45.98358973860741, 43.06989848613739, 44.10165332257748, 42.078489884734154, 42.46358402073383, 40.905310437083244, 40.79760521650314, 46.27828672528267, 47.49997057020664, 43.57268750667572, 44.84490483999252, 41.564529463648796, 39.48704794049263, 38.551146760582924, 39.72325086593628, 39.0843303501606, 41.10534690320492, 40.93169242143631, 40.92153176665306, 39.388918206095695, 42.07385413348675, 41.741854548454285, 42.446598932147026, 44.134453162550926, 46.40602067112923, 52.208427116274834, 52.50473141670227, 52.79633156955242, 50.99399708211422, 55.807202607393265, 51.42044819891453, 53.82391043007374, 53.94023358821869, 53.00062760710716, 54.429282546043396, 55.9136538952589, 52.97615312039852, 47.72705398499966, 45.445633605122566, 46.523069590330124, 48.947225511074066, 54.30672772228718, 55.74919871985912, 58.96413020789623, 59.31563414633274, 57.747545689344406, 45.10764554142952, 2.918776092119515, 0.293417286593467, 0.35912416235078126, 0.15196672989986837, 5.28070536442101, 42.38211639225483, 52.23702438175678, 55.55875673890114, 57.08564780652523, 55.57679437100887, 50.835325196385384, 30.923329666256905, 49.73704352974892, 47.80429244041443, 24.745372273027897, 32.717498391866684, 26.36117096990347, 33.05754974484444, 53.63218031823635, 6.774610402062535, 0.163114708266221, 0.09315298855653964, 0.023195222638605628, 0.09911736968206242, 0.05071790095826145, 0.06711639231070876, 0.031300690534408204, 0.013974894009152194, 0.05856666553881951, 0.03201000188710168, 0.05086850498628337, 0.07330439737415873, 0.028260686667636037, 0.03220832972147036, 0.030462466274912003, 0.10683039916330017, 0.10184744896832854, 0.036059834965271875, 0.06431422079913318, 0.004984594979760004, 0.02235899846709799, 0.05265489155135583, 0.023580117122037336, 0.02864892638172023, 0.006582757123396732, 0.044043514571967535, 0.09210640448145568, 0.07970478283823468, 0.14595481421565637, 0.342199900187552, 1.2943941308185458, 32.521444112062454, 59.570045694708824, 34.478456899523735, 42.366446033120155, 29.630433842539787, 86.99165806174278, 38.761378079652786, 29.674883857369423, 68.4504921734333, 76.92067846655846, 70.60146555304527, 63.107063099741936, 64.27133962512016, 62.34074302017689, 14.638250917196274, 0.37441572931129485, 1.6695560747757554, 0.44541750219650567, 12.56269209086895, 50.16540214419365, 76.43987506628036, 74.16784778237343, 69.81756761670113, 69.25684690475464, 70.11648237705231, 70.54621651768684, 64.78260219097137, 54.60564628243446, 51.055287793278694, 51.31032630801201, 48.3109762519598, 50.13561554253101, 46.691332161426544, 52.042284831404686, 57.24343813955784, 61.77369944751263, 61.104859337210655, 61.40376649796963, 56.38344928622246, 56.48428067564964, 55.959164053201675, 55.1569776982069, 52.45097950100899, 50.93005791306496, 50.1418662071228, 48.141721934080124, 47.98824816942215, 46.16176977753639, 43.186962604522705, 44.12817969918251, 42.99262583255768, 43.837100118398666, 45.16464628279209, 49.00488741695881, 47.07423001527786, 50.400761514902115, 47.06992864608765, 45.63185781240463, 45.521298944950104, 43.8724572211504, 44.81800988316536, 46.1753236502409, 51.37206919491291, 59.425357058644295, 57.22833774983883, 56.72745622694492, 58.32711718976498, 58.833223432302475, 58.05408664047718, 59.2916764318943, 55.77895872294903, 63.32683950662613, 60.07447622716427, 56.21642924845219, 56.97888493537903, 57.506042048335075, 57.701298370957375, 53.49503427743912, 48.18622514605522, 45.42040295898914, 43.853595033288, 45.850707069039345, 45.77110894024372, 43.285928294062614, 43.05068291723728, 47.815281450748444, 49.305075109004974, 45.117399618029594, 46.553950533270836, 44.87186059355736, 41.946245580911636, 41.46893799304962, 41.84990935027599, 43.069723695516586, 43.00685606896877, 44.966973289847374, 43.85268688201904, 43.451420813798904, 45.23298181593418, 45.0620935857296, 44.95485574007034, 46.950235068798065, 49.02993947267532, 53.10235574841499, 53.85473817586899, 54.96142119169235, 52.529441490769386, 58.70922088623047, 56.208385080099106, 57.58951976895332, 56.519945561885834, 56.003617867827415, 56.20847247540951, 58.74824099242687, 53.70360888540745, 49.928458258509636, 50.15377476811409, 49.56140175461769, 53.868542835116386, 58.620807230472565, 60.01407466828823, 61.11560516059399, 63.18059295415878, 60.186498016119, 51.38445273041725, 4.575233794748783, 0.18561177217634395, 0.7685749616939574, 0.6399988860357553, 6.032792357727885, 48.3013741672039, 55.930137410759926, 61.86717443168163, 62.40187034010887, 62.704242914915085, 54.168734326958656, 36.93047292530537, 51.37799687683582, 59.106094390153885, 22.496259659528732, 39.244366362690926, 30.441428124904633, 34.97848726809025, 60.27407571673393, 4.8815458081662655, 0.29813310073222965, 0.01654518611758249, 0.06484406228992157, 0.039476074307458475, 0.07570291476440616, 0.023499334347434342, 0.06150014523882419, 0.024731776320550125, 0.06781853822758421, 0.04229983860568609, 0.029625906281580683, 0.09603460697690025, 0.03312094500870444, 0.0906577322166413, 0.3068195830564946, 0.2900650352239609, 0.2334945762413554, 0.16160434868652374, 0.20880454016150907, 0.12175702242529951, 0.15124352183192968, 0.16278739145491272, 0.32750994781963527, 0.19079077552305534, 0.18178755941335112, 0.1571712631266564, 0.3356258076382801, 0.17753496416844428, 0.35877357178833336, 0.3592985967407003, 2.366638407111168, 47.81071789562702, 81.00195586681366, 50.74237838387489, 47.92837858200073, 33.43494929373264, 89.31575775146484, 45.97539357841015, 34.86270368099213, 72.57784590125084, 84.46311414241791, 77.51932874321938, 68.94179061055183, 70.65024733543396, 68.28939601778984, 17.54580929875374, 1.5487230336293578, 3.886614083312452, 0.963204971048981, 13.78497725352645, 54.45460058748722, 79.28279891610146, 77.46519684791565, 71.83943152427673, 73.21613565087318, 73.15368980169296, 74.05037328600883, 67.40177884697914, 55.50278954207897, 53.67984116077423, 53.01845625042915, 49.64521765708923, 52.46403180062771, 49.45309616625309, 55.69079205393791, 62.122254744172096, 65.08936733007431, 63.490580320358276, 64.60574448108673, 58.06933142244816, 59.944644793868065, 57.46925622224808, 57.36451484262943, 54.89653207361698, 54.27222557365894, 52.18571953475475, 51.517620384693146, 49.704163894057274, 48.2900507748127, 45.804984122514725, 47.64659710228443, 46.32006548345089, 47.625599429011345, 47.84238539636135, 51.438273042440414, 47.61858120560646, 52.00163461267948, 48.222080022096634, 48.20732921361923, 47.80290171504021, 46.69238090515137, 46.33565604686737, 49.0922599285841, 53.24765995144844, 62.66195498406887, 58.21555897593498, 60.15754736959934, 60.97608044743538, 61.78099885582924, 59.11079853773117, 61.52814142405987, 53.06243509054184, 61.07250787317753, 62.10225261747837, 57.91826292872429, 60.32822661101818, 60.39716251194477, 60.32066881656647, 55.91024547815323, 50.959494933485985, 48.60949203372002, 48.33356224000454, 47.64369025826454, 48.6656454205513, 44.58195894956589, 44.63703699409962, 50.790521800518036, 50.56660361588001, 48.42242047190666, 48.39011460542679, 47.38849975168705, 45.1426986604929, 45.15524558722973, 45.44799327850342, 45.79687535762787, 45.98642818629742, 48.3112346380949, 47.16921731829643, 44.10964049398899, 47.267518043518066, 47.44027577340603, 48.590873032808304, 48.06361712515354, 51.54234565794468, 55.917427092790604, 57.70952872931957, 57.56928965449333, 55.60135245323181, 61.30678050220013, 57.51413941383362, 60.392853543162346, 60.23027166724205, 58.60944204032421, 57.58004307746887, 61.15421108901501, 59.41943317651749, 52.07628160715103, 53.03090438246727, 51.45788758993149, 54.705197140574455, 61.03457070887089, 62.71829456090927, 65.14323323965073, 64.4346396625042, 63.71675558388233, 54.311048090457916, 6.183224385604262, 0.2563286345684901, 1.9867705344222486, 0.4661206022137776, 7.571932068094611, 51.99045941233635, 61.131013333797455, 65.4717256128788, 66.9170692563057, 65.9738078713417, 61.28592722117901, 39.69715766608715, 60.44211409986019, 58.19561384618282, 30.827329717576504, 48.82297217845917, 40.12041695415974, 50.844767689704895, 70.85879534482956, 15.869458001106977, 0.699292270001024, 0.33528569620102644, 0.2936170430621132, 0.17879814404295757, 0.27411693474277854, 0.13457535998895764, 0.14099285937845707, 0.17481208371464163, 0.22662182862404734, 0.1646930634160526, 0.19416646391618997, 0.2685866877436638, 0.28227438451722264], [0.08229290411691181, 0.03948283527279273, 0.0617483528185403, 0.012568378515425138, 0.006133174265414709, 0.038683019010932185, 0.0421210997592425, 0.05860254095750861, 0.016068350669229403, 0.04660951242840383, 0.061469086358556524, 0.039686803429503925, 0.05899444317037705, 0.045370485750027, 0.017037378456734587, 0.038108062362880446, 0.10085965041071177, 0.1947134267538786, 8.563798069953918, 45.198992639780045, 32.29557663202286, 34.266899451613426, 25.17567828297615, 33.70449163019657, 59.81790639460087, 46.485246419906616, 61.76491431891918, 65.03401950001717, 63.36662717163563, 55.33093996345997, 57.866593301296234, 58.39391000568867, 11.42106520012021, 0.5975039256736636, 1.2756449868902564, 2.2724034637212753, 21.13516129553318, 51.983517184853554, 74.08136442303658, 66.22696548700333, 65.66952779889107, 62.339489087462425, 64.72846269607544, 64.637191593647, 61.49714268743992, 49.92950700223446, 47.673324868083, 47.08391189575195, 43.98698307573795, 45.81107519567013, 46.18825815618038, 44.54562909901142, 44.952507466077805, 50.927493050694466, 49.69310648739338, 51.76552288234234, 52.13472247123718, 51.195485070347786, 50.55354751646519, 47.270808666944504, 46.74809351563454, 46.78826496005058, 44.47115309536457, 44.54538971185684, 44.275866374373436, 42.43539713323116, 39.50169995427132, 41.609359458088875, 44.488153383135796, 41.55202053487301, 44.19059135019779, 47.58443623781204, 46.16075523197651, 45.24494357407093, 41.71189695596695, 40.97441352903843, 41.01209990680218, 40.75028635561466, 44.26858216524124, 45.20270124077797, 50.76728604733944, 56.118421107530594, 56.39281578361988, 55.21698407828808, 54.462716951966286, 57.58374787867069, 55.390114188194275, 55.04653662443161, 49.79925759136677, 56.08068913221359, 57.062541246414185, 54.437505304813385, 54.09200884401798, 55.85723452270031, 56.49078592658043, 51.47877126932144, 47.49183900654316, 43.776155188679695, 43.93724374473095, 41.369048953056335, 43.89320030808449, 41.27115860581398, 39.820069670677185, 43.20751570165157, 46.29655994474888, 46.712899804115295, 42.67946183681488, 43.463340774178505, 40.21568924188614, 36.56380020081997, 39.652380868792534, 38.99080976843834, 38.28318513929844, 36.24077573418617, 39.740509539842606, 40.90362712740898, 42.12757185101509, 41.91023111343384, 38.58822137117386, 43.76084201037884, 42.80101731419563, 47.833212688565254, 49.19751048088074, 52.11325742304325, 54.07193072140217, 53.61583739519119, 54.39698047935963, 54.36981573700905, 55.65466359257698, 55.727118104696274, 55.59666730463505, 53.59685741364956, 51.64986088871956, 46.78913131356239, 47.463853508234024, 48.4420046210289, 53.37356999516487, 54.4102493673563, 57.0234489440918, 55.07948085665703, 61.54882371425629, 54.568491876125336, 56.71925246715546, 11.847956143319607, 0.01931604270794196, 0.21563943824730814, 0.06215165070898365, 11.100303512066603, 46.946366876363754, 59.83473189175129, 53.106277137994766, 56.689530462026596, 55.86807534098625, 48.565490394830704, 45.1177491992712, 54.28768694400787, 31.83962009847164, 22.697726748883724, 39.623715206980705, 24.399292543530464, 45.543877333402634, 35.33416338264942, 0.09962844967958517, 0.07875322335166857, 0.07792393269483, 0.024046389953582548, 0.049356546078342944, 0.053678784461226314, 0.011695198172674282, 0.018517072494432796, 0.0034154183413193095, 0.06715358133078553, 0.008103290620056214, 0.07796926307491958, 0.07378268186585046, 0.07089756050845608, 0.08999837111332454, 0.07197276179795153, 0.07202401451650076, 0.03236062955693342, 0.03993290702055674, 0.025542446492181625, 0.014196691336110234, 0.07045566351735033, 0.0885196344461292, 0.03660473463241942, 0.03866698119963985, 0.06298029198660515, 0.07027182611636817, 0.010979099879477872, 0.03752146141778212, 0.054596201443928294, 0.19181554787792265, 0.17989929823670536, 11.265421751886606, 63.17618519067764, 30.47620575875044, 43.50703462958336, 33.929697945714, 41.242135763168335, 64.35813456773758, 47.499210610985756, 70.26573836803436, 70.46056151390076, 71.05140700936317, 62.193333730101585, 62.23746456205845, 62.892348021268845, 12.880735024809837, 0.2487064216984436, 1.8478904804214835, 4.163489788770676, 24.433578103780746, 56.09148055315018, 77.11973458528519, 68.45869973301888, 67.49754890799522, 66.35020047426224, 69.0897698700428, 67.85042077302933, 64.82406556606293, 52.99697980284691, 49.85366687178612, 49.091055393218994, 45.989437624812126, 46.95656172931194, 48.93305987119675, 48.51863130927086, 47.19520032405853, 52.94198915362358, 52.65018381178379, 56.76700450479984, 56.869428008794785, 54.55060623586178, 51.71795703470707, 49.18802618980408, 47.837517857551575, 47.52315692603588, 46.676839739084244, 47.70137116312981, 46.07561320066452, 43.74632678925991, 42.137470319867134, 45.153193697333336, 45.72865001857281, 44.156678169965744, 46.08716078102589, 48.37900400161743, 47.65878684818745, 48.48275363445282, 45.30841916799545, 43.9618968218565, 43.06600749492645, 43.591367304325104, 46.88651628792286, 46.36019133031368, 53.981681764125824, 58.141626343131065, 58.38556185364723, 58.68087060749531, 57.316709607839584, 60.01843683421612, 58.76077651977539, 57.144039273262024, 55.581794902682304, 61.279038190841675, 58.37835744023323, 59.461219534277916, 57.739740908145905, 57.27867744863033, 58.00736054778099, 56.32296793162823, 48.800716772675514, 47.68712192773819, 45.35827249288559, 44.802381321787834, 44.0895851701498, 41.91083908081055, 42.48900845646858, 44.47275660932064, 48.763630762696266, 46.94722943007946, 44.07039240002632, 45.656925067305565, 41.6367331892252, 41.6484859585762, 41.80198632180691, 43.44705104827881, 42.211003974080086, 40.458028838038445, 40.978920087218285, 43.98106299340725, 44.82685200870037, 44.16743539273739, 41.81673713028431, 44.85996723175049, 45.32872907817364, 49.54414688050747, 50.45785345137119, 54.81960900127888, 55.14329843223095, 55.920360535383224, 56.972125098109245, 56.76647633314133, 59.140566140413284, 58.65551456809044, 56.67381450533867, 57.08392649888992, 53.04565139114857, 49.672291204333305, 51.41620762646198, 51.5636321157217, 54.646946266293526, 57.78902046382427, 60.05876787006855, 56.5697380900383, 65.66309094429016, 58.35717737674713, 63.405590280890465, 14.948497619479895, 0.0699743881705217, 0.38891180302016437, 1.0377012798562646, 14.835628475993872, 50.62432251870632, 65.84210693836212, 56.9310113042593, 63.50257247686386, 58.25869046151638, 54.34227481484413, 49.884646609425545, 60.29702268540859, 36.66710525751114, 21.570243649184704, 47.26995371282101, 24.27683461457491, 54.624607264995575, 38.702671229839325, 0.5084454326424748, 0.10618686806992628, 0.10254701963276602, 0.12165269872639328, 0.06184220481372904, 0.026974288703058846, 0.07243053332786076, 0.024789545095700305, 0.03964755123888608, 0.01891778956633061, 0.024036250360950362, 0.1027249643811956, 0.010391872747277375, 0.04274114930012729, 0.2652836259221658, 0.19965912855695933, 0.33068699296563864, 0.12299175577936694, 0.11493639583932236, 0.05468131465022452, 0.1096468124887906, 0.13147876365110278, 0.18358860339503735, 0.2523983095306903, 0.14870610408252105, 0.17780872760340571, 0.1179520387086086, 0.287800386431627, 0.2460198471089825, 0.1479045845917426, 0.41455947677604854, 0.4506240243790671, 20.268446803092957, 79.62914273142815, 46.762224957346916, 52.12898477911949, 40.77442646026611, 43.5015819221735, 71.53696775436401, 52.7702421694994, 77.16789320111275, 73.84508550167084, 76.85665190219879, 67.26335227489471, 68.94345492124557, 69.67149585485458, 13.49478492513299, 1.5501192212104797, 3.4058814542368054, 5.404206812381744, 26.27557296305895, 59.24210049211979, 80.66006541252136, 69.6033427119255, 71.79827973246574, 69.2896619439125, 73.16448122262955, 71.35223686695099, 67.79898673295975, 55.13028793036938, 53.7124890089035, 52.83534027636051, 50.414026603102684, 51.28511846065521, 51.94007031619549, 49.661298394203186, 48.8576453179121, 55.539905950427055, 57.141432613134384, 58.5456358641386, 60.02875708043575, 57.309284806251526, 55.56339628994465, 50.85130713880062, 49.024623557925224, 49.30888630449772, 50.44567510485649, 50.10869398713112, 48.178819343447685, 46.690519005060196, 44.434618055820465, 47.155549451708794, 49.1676364839077, 46.75550311803818, 48.13040994107723, 51.9556000828743, 50.36733090877533, 49.51816387474537, 45.43524496257305, 45.94227075576782, 43.96001972258091, 46.09167493879795, 50.193619430065155, 51.08667030930519, 57.80789025127888, 61.80423840880394, 61.43287293612957, 61.85370035469532, 59.96704079210758, 64.23343285918236, 59.39316138625145, 61.143001690506935, 54.33767706155777, 63.8963757455349, 60.00229150056839, 60.6715077906847, 59.35230977833271, 60.902793779969215, 62.27391980588436, 57.24473387002945, 53.474682569503784, 49.457431733608246, 46.00585654377937, 46.52734436094761, 46.38259492814541, 43.05749215185642, 43.29542018473148, 46.50954231619835, 49.966771602630615, 51.2003830075264, 45.663399919867516, 48.309376537799835, 45.1567655056715, 42.020170614123344, 45.166800767183304, 46.60532757639885, 44.9847487360239, 42.090238854289055, 43.23810026049614, 46.04797728359699, 49.06276971101761, 47.68291175365448, 43.936673775315285, 48.28123524785042, 47.2640298306942, 52.899518832564354, 54.6350035071373, 58.40958036482334, 56.84402257204056, 58.68058942258358, 59.07889924943447, 58.845853954553604, 60.92672109603882, 60.679521560668945, 60.5916702747345, 58.62991914153099, 55.04240244626999, 51.97168081998825, 54.206025525927544, 55.32289199531078, 59.66376766562462, 60.85896693170071, 62.460793778300285, 59.484964460134506, 69.56520035862923, 60.84941804409027, 63.607013672590256, 16.780488565564156, 0.26397486333735287, 0.9311972104478627, 1.1993827228434384, 15.567396059632301, 55.31550519168377, 71.49748787283897, 61.872311756014824, 66.90118610858917, 64.28345337510109, 59.15021762251854, 54.08149100840092, 63.3750931173563, 39.666067734360695, 36.55076690018177, 56.29818566143513, 40.83791345357895, 63.98789003491402, 56.383738070726395, 1.199437107425183, 0.24689172219950706, 0.2833875466603786, 0.18847442872356623, 0.16193925024708733, 0.13923257414717227, 0.12413810676662251, 0.1587920542806387, 0.11500371605507098, 0.11464265378890559, 0.04621126856363844, 0.13647567364387214, 0.16285455581964925, 0.14960134198190644], [0.03179912062478252, 0.1465767339686863, 0.027112845818919595, 0.011713206386048114, 0.04224641510518268, 0.015049515495775267, 0.023001436748018023, 0.00567950959521113, 0.04530113576038275, 0.08274186635389924, 0.15333747665863484, 0.13219210115494207, 0.03743377295904793, 0.022236692529986612, 0.08140783364069648, 0.10169893779675476, 0.042954661475960165, 0.1465411257231608, 1.0618732078000903, 38.643219619989395, 42.188064604997635, 28.49657278507948, 25.960828252136707, 26.336823776364326, 60.47597788274288, 52.79068127274513, 56.95681571960449, 63.28266307711601, 63.182291463017464, 62.724207043647766, 59.3580474704504, 54.38628405332565, 9.62786827236414, 0.4003532265778631, 0.23813642794266343, 9.162713382393122, 38.864759132266045, 61.17813840508461, 70.98074600100517, 65.57767152786255, 59.39733736217022, 58.34409847855568, 59.950450882315636, 59.71035696566105, 57.26568974554539, 51.35428234934807, 46.514854431152344, 48.8017351180315, 47.06233285367489, 46.40475533902645, 45.85329093039036, 46.41957454383373, 46.370431780815125, 44.84750010073185, 45.183299481868744, 45.46088598668575, 46.91490836441517, 45.617145001888275, 45.22061347961426, 44.42716285586357, 44.66176226735115, 44.79548469185829, 45.024084225296974, 44.26508255302906, 43.56037236750126, 44.447636157274246, 43.6442756652832, 41.0126318782568, 42.692080959677696, 44.154759272933006, 46.25929534435272, 44.145377576351166, 43.08514706790447, 41.494358628988266, 41.53087466955185, 41.22587263584137, 42.739141434431076, 40.834060460329056, 43.323702067136765, 42.6244255900383, 50.185841247439384, 53.992264196276665, 52.488631680607796, 58.053163290023804, 55.62888577580452, 56.50966331362724, 56.06539495289326, 54.577049016952515, 50.95532275736332, 57.22121313214302, 57.966049164533615, 56.32292613387108, 55.599357560276985, 55.79703435301781, 53.30762833356857, 53.97071175277233, 47.042178735136986, 44.80739325284958, 43.273442164063454, 42.41643615067005, 39.83291678130627, 41.24402426183224, 41.02612875401974, 42.818530574440956, 43.56856092810631, 44.67747062444687, 46.769854947924614, 43.497314751148224, 40.98909594118595, 38.952158242464066, 37.61168137192726, 40.71606919169426, 39.269361421465874, 38.925248086452484, 39.36211824417114, 42.464047595858574, 47.060752138495445, 43.801176846027374, 41.26137413084507, 42.59699486196041, 40.309403613209724, 44.45718124508858, 45.78076422214508, 47.29203052818775, 48.79562124609947, 50.91143511235714, 53.73344488441944, 51.77216112613678, 55.59904597699642, 52.73898504674435, 55.24949133396149, 49.175581857562065, 45.08830837905407, 41.97653755545616, 45.626937076449394, 51.14513397216797, 55.96118174493313, 58.736640214920044, 56.55923165380955, 56.233140751719475, 59.033522084355354, 57.75587484240532, 58.806032091379166, 28.25974479317665, 0.3306775528471917, 0.5790614371653646, 2.3829195834696293, 20.887074507772923, 52.46065378189087, 56.67859844863415, 53.910560980439186, 61.71329788863659, 51.327087208628654, 55.049971640110016, 43.25019121170044, 41.556595489382744, 38.66401590406895, 31.308902576565742, 31.226916275918484, 25.813639350235462, 53.04893061518669, 12.612003944814205, 0.18406724411761388, 0.10861593968002126, 0.05730245407903567, 0.059617854640237056, 0.017451827116019558, 0.05912877561058849, 0.08821842639008537, 0.05570231318415608, 0.01928955731273163, 0.005964261454209918, 0.05432040081359446, 0.03397980282898061, 0.06845810625236481, 0.03911877473001368, 0.04927433095872402, 0.025704082545416895, 0.019469767466944177, 0.007172056702984264, 0.06987710745306686, 0.03914628614438698, 0.014835791807854548, 0.07946305791847408, 0.0448901566414861, 0.04393834482470993, 0.04729288943053689, 0.11143494310090318, 0.04057117999764159, 0.043003272148780525, 0.143863694393076, 0.13325340201845393, 0.15886165288975462, 0.049574162330827676, 1.734248197171837, 50.58629795908928, 46.45038329064846, 32.91582494974136, 41.98036774992943, 25.222639963030815, 68.40373188257217, 55.47252036631107, 60.83544619381428, 69.67097148299217, 71.2017573416233, 67.62245580554008, 64.9691341817379, 61.103700399398804, 11.917643453925848, 0.9632529434747994, 0.38722599972970784, 9.764994364231825, 43.15067075192928, 65.27923554182053, 74.20003205537796, 66.20508626103401, 62.572940960526466, 60.740078911185265, 63.792124539613724, 61.195397078990936, 60.25125414133072, 53.38355205953121, 48.44008572399616, 52.36440494656563, 48.65611933171749, 48.99941571056843, 48.31064186990261, 50.326809883117676, 48.52555833756924, 47.56643660366535, 48.13045173883438, 48.336697071790695, 48.43312069773674, 48.072641640901566, 47.23374925553799, 47.1468061208725, 47.525467202067375, 47.35136814415455, 46.14387273788452, 46.85504637658596, 45.91081224381924, 46.36155545711517, 45.083957612514496, 44.594673067331314, 46.66743904352188, 45.71396380662918, 46.633476465940475, 46.6208079457283, 44.40667435526848, 45.542593002319336, 45.32042272388935, 44.8233599960804, 44.1714745759964, 45.11454977095127, 46.397151947021484, 45.043953359127045, 53.80404129624367, 56.907433569431305, 58.17683145403862, 60.05253240466118, 60.19200012087822, 60.9748151153326, 61.456845849752426, 58.45681942999363, 57.30628676712513, 60.38969211280346, 60.39010249078274, 59.68916930258274, 58.60148526728153, 57.15763494372368, 57.29800321161747, 55.99912650883198, 48.470966666936874, 46.109290793538094, 45.53033106029034, 44.78756211698055, 43.01751829683781, 44.00656722486019, 44.47694778442383, 43.824955970048904, 46.16643972694874, 47.28022836148739, 49.70628418028355, 45.52778899669647, 43.365651816129684, 40.751342698931694, 40.484475418925285, 43.02483290433884, 43.995027244091034, 40.00982388854027, 43.24405074119568, 46.10831044614315, 48.96166853606701, 45.744529366493225, 43.76770444214344, 43.66722643375397, 41.52966633439064, 46.426197588443756, 48.36387701332569, 47.847363129258156, 51.90026745200157, 53.823230266571045, 54.35606427490711, 53.431456089019775, 58.75502362847328, 56.39510706067085, 56.25790782272816, 51.81801326572895, 49.06234793365002, 44.69759814441204, 47.05611638724804, 54.75290738046169, 58.13429653644562, 60.43524406850338, 59.79413487017155, 60.27437590062618, 62.315614968538284, 60.731692761182785, 64.81841906905174, 33.11556123197079, 0.2993474621325731, 0.5950007506180555, 3.560535293072462, 25.376032032072544, 56.3123968988657, 63.1110604852438, 59.232278019189835, 69.788309186697, 54.972417801618576, 62.03795626759529, 46.62718020379543, 52.42638722062111, 38.06900963187218, 33.669662699103355, 39.95405048131943, 27.16797597706318, 62.725517973303795, 8.010820392519236, 0.09616103925509378, 0.008961838593677385, 0.1003676510299556, 0.05418118875240907, 0.07645641730050556, 0.11729619538527913, 0.036524386014207266, 0.0015393963394672028, 0.10547969039180316, 0.030236669699661434, 0.0518353749794187, 0.034019619051832706, 0.029566039083874784, 0.11161991598783061, 0.15219437627820298, 0.20623320626327768, 0.09815497483941726, 0.17174345150124282, 0.13092377077555284, 0.21200794639298692, 0.11131372812087648, 0.2355637730215676, 0.17681953380815685, 0.18319848604733124, 0.16130067670019343, 0.27831553132273257, 0.14593992673326284, 0.14704882894875482, 0.2879915339872241, 0.3003211005125195, 0.5307862744666636, 0.22458154591731727, 3.4841641411185265, 70.93432009220123, 62.59480878710747, 45.86315140128136, 46.19713447988033, 34.05699871480465, 77.09392637014389, 60.55054508149624, 72.12085202336311, 73.53835836052895, 78.74216392636299, 72.82360911369324, 72.34982013702393, 66.68158069252968, 15.76890779659152, 1.4453544490970671, 0.601860866881907, 10.277694202959538, 48.62554997205734, 70.37268742918968, 76.68962806463242, 68.83910492062569, 66.62627846002579, 66.0143668949604, 69.3653766810894, 63.38757164776325, 63.55557583272457, 57.091765478253365, 52.397185787558556, 55.23685321211815, 52.686718851327896, 53.00945833325386, 52.122608721256256, 52.15681828558445, 51.48846834897995, 48.5650610178709, 52.10754252970219, 49.311325773596764, 52.16665595769882, 49.76929999887943, 49.70477946102619, 46.688991487026215, 50.002067908644676, 49.63238574564457, 49.957329109311104, 48.92848111689091, 47.161108553409576, 49.22815203666687, 49.360909312963486, 47.55399987101555, 50.22749461233616, 49.73753370344639, 49.8922424018383, 48.24643291532993, 46.603693664073944, 47.540730983018875, 46.62107393145561, 47.153638154268265, 46.58015012741089, 46.10992155969143, 47.90122523903847, 47.22901090979576, 54.964544624090195, 58.02843801677227, 59.00785066187382, 64.78340774774551, 62.80665881931782, 62.75598853826523, 62.56852939724922, 58.75138722360134, 57.73180693387985, 61.923096030950546, 64.25438493490219, 60.99306173622608, 63.51840242743492, 60.70065222680569, 59.75061200559139, 59.075977206230164, 51.974720656871796, 48.693064749240875, 47.35962510108948, 48.02608273923397, 44.6130108833313, 44.84657675027847, 46.1800391972065, 46.29841044545174, 48.53954538702965, 49.42279279232025, 52.670467123389244, 48.956554010510445, 46.07016809284687, 43.49557064473629, 42.9495133459568, 47.369656562805176, 45.584687143564224, 44.00697760283947, 43.63231770694256, 48.58994968235493, 51.4217135310173, 48.43221254646778, 45.89451111853123, 47.84830167889595, 43.29682230949402, 48.70390176773071, 50.282800644636154, 51.398116797208786, 53.46538446843624, 56.23542442917824, 58.85084308683872, 55.85348792374134, 61.014321595430374, 58.85257199406624, 60.10243512690067, 55.68082518875599, 50.96954919397831, 46.54382787644863, 49.21904392540455, 58.677959963679314, 62.57989078760147, 62.82583259046078, 62.57797189056873, 61.8413358181715, 63.31325523555279, 65.75364768505096, 65.11060059070587, 36.453537717461586, 0.46380346873775125, 2.134860581718385, 6.5163620095700026, 24.778462797403336, 61.42952151596546, 66.43757298588753, 63.487544283270836, 71.45736202597618, 60.41095197200775, 64.59543943405151, 53.00603851675987, 61.251983642578125, 44.44865830242634, 48.108355924487114, 45.65554194152355, 40.74282355606556, 72.00118884444237, 22.984569557011127, 0.3862455632770434, 0.335481088841334, 0.3148402401711792, 0.18145938171073794, 0.13174529856769368, 0.20560990611556917, 0.12280440801987424, 0.16044460935518146, 0.18905572331277654, 0.15775658015627414, 0.20257271127775311, 0.1153684667951893, 0.12123181935749017, 0.22794117423472926], [0.044174971189931966, 0.021031569012848195, 0.07949510385515168, 0.07904714351752773, 0.011024262348655611, 0.059741585500887595, 0.019641064427560195, 0.058903281460516155, 0.1519622324849479, 0.04742690274724737, 0.014735521162947407, 0.027604360948316753, 0.01462739488488296, 0.015441096729773562, 0.03698929700476583, 0.07523228923673742, 0.1240334713656921, 0.20329667633632198, 0.14613148989155889, 16.108665615320206, 58.89722339808941, 33.56627784669399, 32.394557520747185, 27.701883427798748, 49.4111692160368, 63.53148512542248, 55.98433390259743, 64.14251133799553, 63.73635493218899, 59.58367556333542, 60.73834240436554, 55.63290975987911, 9.5989147759974, 0.43846153013873845, 2.324046492576599, 18.712656386196613, 53.70263613760471, 74.74589556455612, 73.30886587500572, 62.82654695212841, 59.43756580352783, 56.61344334483147, 55.587806180119514, 55.36893032491207, 52.09107041358948, 46.91058039665222, 48.00957642495632, 47.51857437193394, 46.99913464486599, 47.79040038585663, 49.27135951817036, 47.79942490160465, 48.30605551600456, 47.43246719241142, 44.26016181707382, 43.88534612953663, 45.811356380581856, 45.12933477759361, 46.79327309131622, 45.725655779242516, 46.78642965853214, 44.80120338499546, 43.57861518859863, 47.7043654024601, 43.04039306938648, 41.403288915753365, 42.15044662356377, 39.6707034856081, 44.478832483291626, 43.45905840396881, 43.63471917808056, 42.08270765841007, 43.782063871622086, 41.451352536678314, 42.585644870996475, 42.36267663538456, 44.00131210684776, 41.26447856426239, 43.28086696565151, 43.956782296299934, 48.76113809645176, 54.99514818191528, 55.056180506944656, 56.92578658461571, 55.673780366778374, 57.7086091786623, 50.39229556918144, 39.211410731077194, 54.34480927884579, 58.399104326963425, 57.49274656176567, 56.576858907938, 55.103324577212334, 55.630553886294365, 55.35853028297424, 54.227498173713684, 46.848867908120155, 42.58716098964214, 43.786718621850014, 42.09630332887173, 40.914752930402756, 41.35995224118233, 41.425806507468224, 40.83088003098965, 41.22363455593586, 43.157206401228905, 42.71625906229019, 42.344331219792366, 41.643367633223534, 40.386778861284256, 40.279966592788696, 38.36626388132572, 40.95531575381756, 40.76991230249405, 40.8162622153759, 43.0684469640255, 44.288762882351875, 42.31181636452675, 41.48887172341347, 40.333919897675514, 41.13249644637108, 40.02796031534672, 43.135665357112885, 41.147680431604385, 45.77499993145466, 46.392877176404, 47.286254838109016, 47.95957110822201, 47.094897106289864, 46.880425214767456, 46.36931464076042, 43.22473257780075, 44.7197699546814, 43.809581995010376, 50.20109362900257, 56.05183348059654, 58.09006690979004, 56.118721291422844, 58.3026123046875, 58.5662117600441, 61.00989103317261, 61.12218260765076, 54.663657769560814, 45.434845983982086, 2.6583998138085008, 0.932904981309548, 3.073579310439527, 24.332944303750992, 56.86908222734928, 54.578542336821556, 57.100239023566246, 52.54619859158993, 59.29898723959923, 50.0052635371685, 43.33600200712681, 40.36517322063446, 25.109730921685696, 29.5413913205266, 25.46778380870819, 38.44094127416611, 41.43080323934555, 0.455072695040144, 0.04544079682091251, 0.05462942739541177, 0.10095844510942698, 0.011800589636550285, 0.06177094008307904, 0.09063068093382753, 0.06970973088755272, 0.020007791135867592, 0.023482379983761348, 0.13041689875535667, 0.05080528513644822, 0.03767121939745266, 0.045392820684355684, 0.047705070828669704, 0.021153335037524812, 0.09058238938450813, 0.04343414824688807, 0.07751797791570425, 0.026588091750454623, 0.04905909328954294, 0.05777994818345178, 0.04803868476301432, 0.06392512019374408, 0.010848928104678635, 0.03189135102729779, 0.057009391093743034, 0.051259891406516545, 0.04649791939300485, 0.05823330764542334, 0.04220016075123567, 0.10313422171748243, 0.24104285635985434, 0.28160413610748947, 19.83188632875681, 70.93422129750252, 30.12183677405119, 41.427341625094414, 30.160807482898235, 57.521150037646294, 68.61846596002579, 61.67443737387657, 70.40001556277275, 69.62209090590477, 65.90774461627007, 64.47557106614113, 60.63235469162464, 11.638142801821232, 0.38101858750451356, 2.217974946834147, 20.47069475054741, 56.69135816395283, 75.72697252035141, 74.60605546832085, 66.87166169285774, 61.083181500434875, 57.602537870407104, 60.06453596055508, 59.35434266924858, 55.143028646707535, 49.17102210223675, 50.714947655797005, 50.546753481030464, 50.40602423250675, 50.132891088724136, 51.96687027812004, 50.278392881155014, 50.9577926248312, 48.815448582172394, 46.78910091519356, 46.891991794109344, 46.8853535503149, 47.63906590640545, 48.30535255372524, 46.11820891499519, 47.400450110435486, 47.695367485284805, 46.09151154756546, 49.130398482084274, 46.14607281982899, 44.598868042230606, 45.4009024053812, 43.03323805332184, 44.48109336197376, 45.776565447449684, 46.97377100586891, 44.766264259815216, 45.290077552199364, 44.39802601933479, 44.87213797867298, 45.069294199347496, 45.51303058862686, 43.400792330503464, 46.21999405324459, 46.552913188934326, 53.66764761507511, 56.064946576952934, 57.06314541399479, 58.67955967783928, 59.52610105276108, 61.096773371100426, 54.36701908707619, 48.81255313754082, 59.155753925442696, 62.44272954761982, 61.218917816877365, 59.55728217959404, 57.08970978856087, 58.270887807011604, 58.56504902243614, 56.640839874744415, 48.974656239151955, 45.460240021348, 45.414479076862335, 44.8842441290617, 42.78266429901123, 43.847663551568985, 43.113960921764374, 44.07516874372959, 44.39069241285324, 46.44754484295845, 46.1048374325037, 45.47306053340435, 45.44503703713417, 42.7837510406971, 43.11036631464958, 41.591899394989014, 45.598715990781784, 45.42910449206829, 44.252300038933754, 45.95105968415737, 46.45675554871559, 45.40524177253246, 44.11859281361103, 43.34832474589348, 43.80544401705265, 42.74324521422386, 46.579032987356186, 44.649743512272835, 47.438128888607025, 47.05915242433548, 48.699452206492424, 49.824621230363846, 50.35940833389759, 49.24253426492214, 48.30212652683258, 46.6987531632185, 45.69847583770752, 47.3426666110754, 52.67620861530304, 57.97541946172714, 59.5110272616148, 59.30570907890797, 61.15198440849781, 61.995881125330925, 63.692961260676384, 65.17379879951477, 57.81645879149437, 54.02301974594593, 3.3614957984536886, 0.22523003455717117, 3.9827311132103205, 26.49975523352623, 62.36340120434761, 59.76251296699047, 63.822576105594635, 59.26484227180481, 66.47873997688293, 56.13572917878628, 48.69280256330967, 55.558547750115395, 24.726863466203213, 41.010279804468155, 26.49387314915657, 44.140806421637535, 46.356539726257324, 1.2248031212948263, 0.0773761015443597, 0.1113178173545748, 0.011828273600258399, 0.02851272187399445, 0.007462347302862327, 0.10246696416288614, 0.02917605346738128, 0.030067714214965235, 0.011681267133099027, 0.01309127814238309, 0.0630840813391842, 0.06292573671089485, 0.05046975646109786, 0.054598487258772366, 0.114975781616522, 0.09787811664864421, 0.12926241382956505, 0.1919157081283629, 0.114302572037559, 0.13999648159369826, 0.08281168760731816, 0.14475534029770643, 0.2699090464739129, 0.128916721441783, 0.16933343082200736, 0.09191430697683245, 0.15658934513339773, 0.13557817961554974, 0.16238547395914793, 0.1440547380479984, 0.22742270986782387, 0.2959016110980883, 0.2847160503733903, 32.67762713134289, 85.10948985815048, 48.68030123412609, 51.745136976242065, 38.32994922995567, 63.01546901464462, 74.21786829829216, 69.29125025868416, 76.71078532934189, 78.69652837514877, 70.03352522850037, 72.01199546456337, 65.53085044026375, 14.295027684420347, 0.8180377981625497, 3.431591112166643, 22.42789752781391, 60.20717650651932, 84.03252124786377, 81.0161443054676, 71.71179637312889, 64.95371460914612, 61.79173327982426, 62.717295214533806, 63.794989585876465, 57.135687321424484, 52.46935531497002, 53.567097410559654, 52.735280245542526, 54.05737370252609, 54.53264839947224, 56.13362789154053, 54.02658775448799, 54.88074392080307, 50.585325211286545, 50.048535615205765, 49.55548547208309, 50.653421357274055, 50.48102080821991, 51.80850997567177, 50.04661291837692, 50.2621753513813, 49.68743719160557, 49.29873704910278, 53.553893119096756, 49.61352355778217, 46.505928710103035, 47.34908826649189, 43.83725591003895, 47.595235258340836, 49.3183857947588, 47.55431525409222, 46.59249946475029, 47.833908051252365, 45.84085039794445, 46.43488012254238, 48.13155747950077, 47.24757671356201, 46.04582279920578, 48.12659874558449, 48.599810153245926, 55.159261375665665, 58.2500459253788, 60.6570989638567, 61.13240785896778, 62.99442954361439, 64.2932340502739, 54.45489317178726, 48.55991989374161, 58.77685345709324, 64.85878810286522, 63.30396853387356, 62.59488098323345, 60.78044794499874, 60.59774994850159, 62.29952283203602, 59.43281605839729, 50.07250472903252, 47.10883855819702, 47.86755904555321, 47.004207372665405, 45.0996507704258, 46.711364686489105, 45.20010977983475, 45.49414560198784, 46.805219650268555, 47.71646395325661, 47.61839501559734, 48.476677760481834, 46.78527072072029, 45.55944509804249, 46.016199588775635, 44.35985326766968, 49.21005740761757, 46.98895499110222, 46.05244964361191, 50.10642170906067, 50.09607866406441, 48.25378552079201, 46.678770035505295, 44.095110073685646, 45.35988360643387, 43.61061327159405, 49.21833336353302, 45.274669378995895, 49.0681654214859, 50.52950620651245, 51.03076010942459, 52.337331399321556, 51.554637998342514, 51.49822622537613, 50.34285642206669, 48.789765760302544, 48.62093321979046, 49.42655839025974, 55.89999362826347, 60.39899781346321, 64.11704510450363, 63.90257701277733, 62.977372258901596, 64.2639148235321, 68.20475175976753, 67.36115142703056, 61.59861244261265, 56.35910779237747, 5.055528972297907, 1.831293327268213, 6.755551574751735, 30.821094252169132, 67.9638446867466, 64.54378500580788, 67.40555584430695, 60.6164563447237, 69.14073273539543, 59.59219090640545, 58.063035160303116, 57.868550196290016, 32.973665446043015, 48.07182848453522, 38.58021140098572, 55.46802140772343, 63.79005745053291, 3.3982037287205458, 0.2987891295924783, 0.1464741988456808, 0.17436499911127612, 0.10125840635737404, 0.16833169473102316, 0.1746392375207506, 0.20601252123015001, 0.08359118015505373, 0.11871453607454896, 0.19431093038292602, 0.22206235531484708, 0.1548020902555436, 0.23167708626715466, 0.152188305510208], [0.0397900324605871, 0.026693914587667678, 0.04271575671737082, 0.007122089291442535, 0.0598708787583746, 0.007909523283160524, 0.05059123119281139, 0.03444679925451055, 0.0365335404057987, 0.04769137820403557, 0.03637026791693643, 0.13424955715890974, 0.062461463967338204, 0.055817405445850454, 0.04514823478530161, 0.06503780736238696, 0.06485004400019534, 0.18396185914753005, 0.13125237892381847, 5.661488631740212, 50.826904848217964, 40.421558395028114, 34.59417589008808, 25.976371318101883, 33.846938386559486, 67.02125206589699, 60.748818442225456, 60.37319719791412, 64.76283565163612, 63.67249555885792, 61.476619988679886, 60.9968501329422, 13.130702711641788, 0.12843674485338852, 2.917775558307767, 25.029275938868523, 59.98546980321407, 77.12096571922302, 68.6472076177597, 66.92608997225761, 58.96289147436619, 57.55077324807644, 50.95819540321827, 53.737385272979736, 52.060865834355354, 50.67384526133537, 47.06367038190365, 49.255715757608414, 47.42285370826721, 49.95757609605789, 50.4558889567852, 53.625435680150986, 52.03227236866951, 50.95840059220791, 51.4106485247612, 47.071710750460625, 43.560292571783066, 43.58189441263676, 43.99646736681461, 45.59995472431183, 43.86844843626022, 42.9263573884964, 46.117087975144386, 45.381489247083664, 44.510294795036316, 43.084402307868004, 41.312177404761314, 43.197860419750214, 42.89089009165764, 44.49747808277607, 44.53073009848595, 44.699771627783775, 43.6433295160532, 42.500886619091034, 40.718079283833504, 41.81865222752094, 40.73797881603241, 42.66589276492596, 43.494126722216606, 41.51789456605911, 49.07951161265373, 54.77310709655285, 56.910982578992844, 58.32467012107372, 57.97733835875988, 59.291729629039764, 54.24294054508209, 47.405602633953094, 51.545807272195816, 61.082083359360695, 57.9830152541399, 54.21874724328518, 54.10189971327782, 54.71005707979202, 54.757805317640305, 53.29347029328346, 48.37252534925938, 43.779404014348984, 44.08010847866535, 43.65343697369099, 41.221529468894005, 41.935560554265976, 40.67049823701382, 41.34486325085163, 41.92187748849392, 42.26724095642567, 41.5752524882555, 40.82110695540905, 40.591261088848114, 39.49092373251915, 40.25427997112274, 40.05112387239933, 40.54128997027874, 38.61795477569103, 42.39989183843136, 43.66744302213192, 44.6122395247221, 43.46971683204174, 44.77767884731293, 39.61231581866741, 41.77774362266064, 42.271363735198975, 42.98597238957882, 42.44101323187351, 41.71358026564121, 43.48496161401272, 41.69029511511326, 44.04663607478142, 43.02829451858997, 43.75762738287449, 43.28623987734318, 44.111589789390564, 45.09628415107727, 48.24531577527523, 52.54433289170265, 59.11951147019863, 59.129941910505295, 60.02361975610256, 54.41979065537453, 59.200789108872414, 56.20697155594826, 64.46822226047516, 53.941445723176, 55.14264106750488, 10.726288631558418, 0.49751419108361006, 3.867017822340131, 29.34476137161255, 55.17444536089897, 49.78647127747536, 45.470450073480606, 41.050189062952995, 55.30796639621258, 58.5087626427412, 50.208750218153, 32.460772767663, 24.406523555517197, 23.487117290496826, 23.42519011348486, 52.19223618507385, 21.942684464156628, 0.10682943437132053, 0.007607138923049206, 0.12985985755221918, 0.0467204894812312, 0.034852687240345404, 0.03461234642600175, 0.07068398525007069, 0.022924624463485088, 0.0639901620161254, 0.05932661733822897, 0.05206943351367954, 0.026970687431457918, 0.04198615133645944, 0.029426083019643556, 0.085801125242142, 0.03043829452508362, 0.03564948296116199, 0.018037591289612465, 0.03965494302974548, 0.016828218977025244, 0.06953790885745548, 0.07987142467754893, 0.03534506511641666, 0.04812373488675803, 0.05949296973994933, 0.04550351943180431, 0.05213113567151595, 0.05945383629295975, 0.060821774022770114, 0.047382214324898086, 0.036581876483978704, 0.06648623471846804, 0.136956496280618, 0.04363086562079843, 6.0429211892187595, 62.76405170559883, 42.92770251631737, 40.73970012366772, 32.58996583521366, 39.429538026452065, 78.11571434140205, 64.66478571295738, 67.51672267913818, 70.64485162496567, 70.01999795436859, 66.02110013365746, 66.68586686253548, 14.06152356415987, 0.20815035182749853, 3.199980240315199, 27.280710227787495, 63.38865078985691, 79.73169922828674, 71.63817912340164, 68.90982672572136, 60.66686823964119, 59.81594569981098, 53.85013282299042, 56.38959735631943, 55.08503995835781, 54.410082176327705, 49.73622277379036, 51.64643347263336, 51.60735636949539, 53.48037086427212, 53.818951696157455, 55.80390438437462, 53.14931742846966, 53.92852261662483, 51.297350004315376, 48.17018240690231, 46.22717186808586, 45.61553008854389, 46.21136091649532, 47.59051971137524, 46.01514704525471, 44.97219420969486, 49.33873750269413, 48.79925385117531, 45.7094344496727, 45.64275562763214, 44.83064040541649, 45.37849120795727, 42.982221990823746, 46.11329957842827, 45.12662932276726, 46.656928807497025, 44.696640595793724, 44.53899845480919, 45.05127176642418, 44.80737045407295, 44.381048530340195, 45.202226266264915, 45.492264702916145, 47.184336706995964, 52.70429290831089, 58.50476145744324, 60.461968034505844, 59.87274505198002, 58.010708168148994, 61.463233307003975, 55.544990077614784, 45.650587007403374, 56.409086510539055, 62.442193776369095, 60.63348323106766, 58.512030467391014, 58.008367493748665, 56.80503286421299, 56.22965253889561, 56.46189987659454, 50.18321178853512, 47.64367125928402, 45.48397354781628, 46.006054133176804, 44.28253881633282, 44.30254094302654, 42.0395989716053, 43.63248109817505, 44.06836710870266, 44.328413754701614, 44.51566770672798, 42.980728670954704, 44.77750405669212, 42.56258010864258, 41.917089745402336, 42.45258741080761, 43.31128813326359, 42.49096155166626, 44.49618995189667, 45.60667656362057, 47.327851206064224, 47.51598671078682, 46.8264377117157, 42.13876225054264, 43.78198027610779, 45.2259635925293, 46.649435609579086, 44.447240978479385, 45.354400500655174, 44.85228784382343, 43.38083200156689, 45.42343519628048, 43.81407715380192, 45.73557324707508, 44.89320024847984, 46.77756853401661, 46.83843746781349, 50.98379462957382, 55.363394021987915, 61.049891486763954, 62.10344955325127, 63.90984982252121, 58.770994171500206, 61.35927088558674, 60.71749672293663, 66.13092944025993, 57.984854355454445, 62.83992223441601, 13.616246357560158, 0.2658569498453289, 4.3735923897475, 32.980938255786896, 62.28727608919144, 54.25147868692875, 50.035517513751984, 44.37771610915661, 62.93316923081875, 63.172655180096626, 62.74726800620556, 35.586200058460236, 28.74119035899639, 31.858470886945724, 23.159527368843555, 63.07608716189861, 19.586556293070316, 0.12519161507952958, 0.04974171330104582, 0.09350562744657509, 0.04750850930577144, 0.01579237748956075, 0.035426374815870076, 0.07092997009749524, 0.032761244583525695, 0.04516004235483706, 0.04124197017517872, 0.07926028833026066, 0.02163238950743107, 0.05758064071414992, 0.008921619755710708, 0.02016979084146442, 0.20942684583133087, 0.1656652323435992, 0.11014323506969959, 0.12253618842805736, 0.13543411390855908, 0.14230861299438402, 0.1941170368809253, 0.2045589211047627, 0.14850992476567626, 0.12813994515454397, 0.10340290144085884, 0.1879218255635351, 0.22967974422499537, 0.1445085316663608, 0.1923930723569356, 0.1528961065923795, 0.1900479302275926, 0.31940076733008027, 0.5263326165731996, 13.924001343548298, 81.33122339844704, 55.86135350167751, 51.622460559010506, 40.19516274333, 44.52223375439644, 81.29965469241142, 70.68007573485374, 74.97229501605034, 75.69460585713387, 78.71912956237793, 73.44628170132637, 73.71224462985992, 15.974240228533745, 0.35084930481389165, 4.583967151120305, 30.79455267637968, 65.9894934296608, 84.6693442761898, 75.06179541349411, 73.59135791659355, 66.79989874362946, 66.12960711121559, 57.03727260231972, 60.01589097082615, 59.1854303330183, 58.209619894623756, 51.22803792357445, 55.85947260260582, 54.77688789367676, 56.987852454185486, 56.935080885887146, 58.92020456492901, 57.83288151025772, 59.46635685861111, 56.30015775561333, 51.6023064404726, 48.71231451630592, 50.35357944667339, 48.0766162276268, 50.31694561243057, 47.42440402507782, 50.619181394577026, 51.56226418912411, 52.310094460844994, 49.01347115635872, 48.25964480638504, 45.74351482093334, 49.14528228342533, 46.102492958307266, 48.983205780386925, 48.86234946548939, 48.16711217164993, 47.78115168213844, 47.164220586419106, 46.85409262776375, 47.12393134832382, 46.032534912228584, 46.50951951742172, 49.00730788707733, 47.36781366169453, 55.48344857990742, 60.07999733090401, 62.26182505488396, 62.91223615407944, 64.36539977788925, 62.90592849254608, 59.137393310666084, 55.56491620838642, 56.354787424206734, 64.56235840916634, 62.29197643697262, 60.59362716972828, 60.73048822581768, 59.9249542504549, 59.505114778876305, 58.424752950668335, 51.03589363396168, 49.2735406011343, 47.76214890182018, 48.63443769514561, 45.5441053211689, 46.57948136329651, 44.925323724746704, 44.00307521224022, 46.87138929963112, 47.46699593961239, 45.6870536506176, 46.56205929815769, 47.425179183483124, 45.39572708308697, 44.30306151509285, 45.613835379481316, 46.37038238346577, 45.99208988249302, 47.85694621503353, 48.21157358586788, 49.81181971728802, 50.35010263323784, 49.977430030703545, 43.685951828956604, 45.294546112418175, 46.599209904670715, 47.11715251207352, 47.957055643200874, 46.77123047411442, 46.33290119469166, 45.72689451277256, 48.074948117136955, 47.22033217549324, 47.920687794685364, 47.20699489116669, 49.22025606036186, 50.37963464856148, 52.10853047668934, 58.587699607014656, 63.465573862195015, 64.16610047221184, 63.56249526143074, 60.544229820370674, 65.46497717499733, 60.61321131885052, 72.33304783701897, 59.27329681813717, 65.00586301088333, 16.036047711968422, 0.6640171003527939, 6.174926105886698, 36.34221889078617, 68.06633278727531, 60.59785634279251, 55.54678738117218, 52.12545856833458, 66.85700207948685, 68.71083900332451, 63.195970728993416, 41.663958728313446, 37.454707995057106, 37.01927036046982, 35.85187800228596, 70.47459796071053, 36.89994916319847, 0.24054468231042847, 0.07316897026612423, 0.22196157166035846, 0.07709767000051215, 0.08701032871613279, 0.12767853710101917, 0.22955289634410292, 0.12578248337376863, 0.19744279357837513, 0.12839803443057463, 0.18167742469813675, 0.1484556292416528, 0.1613098051166162, 0.14582726871594787, 0.2752666996093467], [0.045471213743439876, 0.024058286580839194, 0.014164134245220339, 0.05868886386451777, 0.043938467279076576, 0.01242921933226171, 0.03301813529105857, 0.05957983070402406, 0.014127576050668722, 0.05024356098147109, 0.06282461908995174, 0.04053985765494872, 0.06289465556619689, 0.028977467736694962, 0.04182538359600585, 0.06707131426082924, 0.08259751120931469, 0.05479679282871075, 0.1995327408076264, 0.237331984390039, 24.4121852517128, 51.68674170970917, 63.9568305015564, 41.108971908688545, 25.777311399579048, 53.824902176856995, 69.90837514400482, 67.36923739314079, 66.58046051859856, 62.299450635910034, 61.979648396372795, 59.70996178686619, 19.846540242433548, 0.6074640224687755, 4.693904751911759, 25.7575049623847, 67.35238149762154, 82.05299466848373, 69.68425557017326, 68.07653903961182, 68.69297236204147, 64.881921261549, 58.858229890465736, 55.37554197013378, 50.42096883058548, 51.20301626622677, 48.52906174957752, 46.93764254450798, 49.209118857979774, 53.403869569301605, 54.9320487678051, 54.70357842743397, 57.12440572679043, 57.23386265337467, 54.60532329976559, 53.793432265520096, 51.39117456972599, 46.80195942521095, 43.68238382041454, 43.99939700961113, 43.938208892941475, 44.3419524282217, 46.741318479180336, 45.165953412652016, 44.68884341418743, 41.409429386258125, 42.94095240533352, 44.15880225598812, 43.283184841275215, 44.19431895017624, 43.04543159902096, 44.04497176408768, 44.09672498703003, 42.46935971081257, 42.69646592438221, 42.75387704372406, 42.03769527375698, 43.85463997721672, 43.48090723156929, 43.64499382674694, 45.49281947314739, 49.92022030055523, 57.627149149775505, 56.80885545909405, 60.27967281639576, 57.15180605649948, 59.5653111487627, 60.05878686904907, 54.2057291418314, 59.47360686957836, 55.44079966843128, 54.661241099238396, 54.14591655135155, 53.22737663984299, 54.18364852666855, 52.791490629315376, 47.0371326059103, 45.48422433435917, 45.14076456427574, 43.99177461862564, 41.60977743566036, 40.863600075244904, 41.71703428030014, 42.08651505410671, 40.910181775689125, 39.775235876441, 41.39841377735138, 41.48156851530075, 42.02157273888588, 41.69774271547794, 38.7995470315218, 41.103268414735794, 42.006840929389, 41.81011788547039, 42.6762206107378, 45.429845452308655, 43.96625138819218, 48.13214644789696, 46.905686259269714, 46.69496476650238, 47.86631651222706, 47.63309642672539, 48.5732039809227, 47.584257647395134, 42.7726024389267, 43.26814524829388, 41.581035777926445, 43.13202515244484, 42.32882045209408, 44.564704075455666, 42.35657796263695, 42.55139730870724, 44.311436265707016, 51.305040791630745, 52.86454550921917, 59.32135283946991, 57.77192898094654, 62.342232540249825, 63.258302584290504, 57.496333569288254, 61.25185064971447, 61.51541590690613, 56.452913358807564, 57.114131078124046, 27.199390791356564, 0.7109708245843649, 3.493322362191975, 35.49765340983868, 56.228288412094116, 57.08426848053932, 50.62969163060188, 51.837217435240746, 63.392237797379494, 61.79763436317444, 66.88324347138405, 37.20367066562176, 24.300655536353588, 30.857891477644444, 33.50925050675869, 51.06614001095295, 2.4027476320043206, 0.07979487214470282, 0.047369404855999164, 0.04843124748731498, 0.050696901889750734, 0.04202434967737645, 0.09655056288465858, 0.021620320330839604, 0.005334008774298127, 0.029084092093398795, 0.07500635721953586, 0.038428532861871645, 0.005328444522092468, 0.02578934047051007, 0.051783138915197924, 0.0859921911614947, 0.05261020312900655, 0.032129057217389345, 0.025437692347622942, 0.038462122465716675, 0.02814673545799451, 0.02281238204886904, 0.021138352931302506, 0.0435743028356228, 0.031324973606388085, 0.023176316426543053, 0.023760143594699912, 0.07000414829235524, 0.0313795029069297, 0.04263143018761184, 0.043737341547966935, 0.09202723216731101, 0.07517658363212831, 0.004044075867568608, 0.29558325943071395, 0.6152592448052019, 33.650101348757744, 61.06670558452606, 61.48705042898655, 50.36817446351051, 30.632080994546413, 62.94540457427502, 78.03195923566818, 74.72188845276833, 75.19635379314423, 69.52368378639221, 68.18765267729759, 66.4615572988987, 23.064435571432114, 1.0315824206918478, 4.553535534068942, 27.03840672969818, 69.31698247790337, 82.54778891801834, 73.68597283959389, 71.36967793107033, 71.15580260753632, 69.40300986170769, 60.84195904433727, 57.27026470005512, 52.48076230287552, 52.115267515182495, 52.45882228016853, 48.73578205704689, 53.926071748137474, 55.364765748381615, 58.536778539419174, 56.775915026664734, 58.97853143513203, 59.733360931277275, 57.185115069150925, 57.48339146375656, 53.99422109127045, 47.393633276224136, 45.82617558538914, 46.764273047447205, 45.983407348394394, 46.81784637272358, 49.508728981018066, 49.35053586959839, 47.26056441664696, 44.73129853606224, 44.11721348762512, 46.0733675211668, 46.46104171872139, 46.26511663198471, 44.84002210199833, 46.87759816646576, 44.6193565428257, 46.48686893284321, 44.00203786790371, 46.63656949996948, 44.01064820587635, 47.07138776779175, 45.21261490881443, 46.767472475767136, 49.101098254323006, 55.068415850400925, 61.608187928795815, 60.9408563375473, 62.69085243344307, 61.33130818605423, 59.347810819745064, 56.882145926356316, 57.36215136945248, 63.28487075865269, 59.239516630768776, 59.091689363121986, 57.79466316103935, 57.13857136666775, 57.33057886362076, 55.37903018295765, 49.60932478308678, 47.515082359313965, 47.34792932868004, 45.623122081160545, 44.432687759399414, 43.66415619850159, 42.85178259015083, 43.13407704234123, 42.92075648903847, 43.50813277065754, 42.63427086174488, 43.62297020852566, 43.73736307024956, 44.39570054411888, 42.4394591152668, 43.91864754259586, 46.40375979244709, 43.98173175752163, 47.115822583436966, 49.540172293782234, 46.707298904657364, 48.95944945514202, 50.23916758596897, 48.776835054159164, 50.37912167608738, 50.81704057753086, 50.28783917427063, 49.577379897236824, 45.57073429226875, 44.368991777300835, 43.868174850940704, 44.838448986411095, 44.08191718161106, 46.41640171408653, 46.80602140724659, 45.84366224706173, 46.48045867681503, 53.46644461154938, 56.75174452364445, 62.05040819942951, 63.07395547628403, 63.17825607955456, 65.98396092653275, 61.309873536229134, 64.0221717953682, 66.17043972015381, 60.330175906419754, 61.46311931312084, 35.67409314215183, 0.9476515150163323, 3.384125246666372, 41.05793684720993, 63.91260087490082, 61.33867219090462, 57.329606115818024, 56.917047053575516, 68.40592056512833, 66.31267368793488, 73.00273910164833, 33.26786085963249, 30.400812104344368, 33.565920665860176, 39.56080578267574, 56.15026719868183, 1.5742060099728405, 0.12411021685693413, 0.10146433749468997, 0.018352130173298065, 0.02282707100675907, 0.07327330138650723, 0.05201787280384451, 0.032359271426685154, 0.016533107664145064, 0.059743938109022565, 0.04126591928070411, 0.021430480810522567, 0.009993579715228407, 0.0530638965574326, 0.03657679648313206, 0.016997295060718898, 0.22123569186078385, 0.10970827715937048, 0.09690195496659726, 0.15791332174558192, 0.07471848555724137, 0.13346046122023836, 0.10882022324949503, 0.19065346335992217, 0.2234515073359944, 0.08504180426825769, 0.11536018442711793, 0.1438226387836039, 0.16105239861644804, 0.1386300689773634, 0.10710249276598915, 0.12652476463699713, 0.24947641475591809, 0.18333207262912765, 0.28952736407518387, 0.5265462363604456, 52.12704688310623, 74.60312962532043, 75.79369693994522, 57.48999550938606, 38.65693308413029, 69.32401210069656, 81.79435774683952, 79.71564888954163, 80.04829823970795, 73.2408495247364, 75.1599745452404, 72.41926521062851, 27.173291891813278, 1.891231785994023, 5.737564824521542, 31.010702177882195, 72.56478980183601, 88.11169356107712, 75.59117540717125, 76.61328256130219, 76.18532672524452, 74.30033907294273, 64.05006989836693, 62.62766182422638, 54.309459775686264, 57.46398590505123, 54.736393466591835, 52.70955562591553, 57.057696506381035, 58.82340095937252, 61.55580013990402, 59.895194247365, 61.772540509700775, 62.629588320851326, 61.12277917563915, 63.79617512226105, 57.253348007798195, 52.61095851659775, 49.257167279720306, 47.99591235816479, 49.29930321872234, 50.73043182492256, 51.65001668035984, 51.9700963050127, 50.090090185403824, 47.72963024675846, 46.3492327183485, 50.428640618920326, 49.276246055960655, 48.35061572492123, 48.16778473556042, 50.121674090623856, 47.36023686826229, 48.430407643318176, 46.05302721261978, 49.45024251937866, 46.82823121547699, 50.595007091760635, 47.36773006618023, 48.76209184527397, 49.393374770879745, 56.35433904826641, 62.83344738185406, 62.018383517861366, 65.64334720373154, 62.85899721086025, 60.022438019514084, 58.47005032002926, 58.94325792789459, 63.6659637093544, 61.48079216480255, 59.70552742481232, 59.27370719611645, 58.781857788562775, 60.75406216084957, 57.1950439363718, 52.696320936083794, 50.42139820754528, 49.10104885697365, 46.99386052787304, 46.201922222971916, 45.08236549794674, 45.18359586596489, 46.349320113658905, 45.91849163174629, 44.33831602334976, 46.542843729257584, 45.29057152569294, 47.41048917174339, 46.10221937298775, 43.58366131782532, 46.58635899424553, 49.09529596567154, 46.4729692786932, 48.68350066244602, 53.559201434254646, 48.54172646999359, 52.390676736831665, 52.83122129738331, 51.36121317744255, 52.74886071681976, 53.5590760409832, 51.74879238009453, 53.29279012978077, 48.54665860533714, 48.185225799679756, 47.15747594833374, 46.072751954197884, 45.68174533545971, 50.01118361949921, 48.110259622335434, 47.10123136639595, 48.59887920320034, 55.35917244851589, 58.52171994745731, 63.10259073972702, 63.34339141845703, 66.51104584336281, 65.44087886810303, 64.56168964505196, 69.65883493423462, 66.07831746339798, 65.73423832654953, 62.244604378938675, 39.82199236750603, 1.4445982896722853, 4.843042474240065, 45.55781118571758, 67.64920637011528, 67.95540153980255, 61.90694309771061, 61.41931526362896, 74.09466370940208, 72.49067857861519, 81.31024852395058, 47.37321317195892, 37.72869989275932, 48.027648255228996, 47.54885494709015, 72.0169124007225, 8.634302336722612, 0.521623125532642, 0.15217267588013783, 0.1722775454982184, 0.17889269365696236, 0.18318863032618538, 0.2522491378476843, 0.08958518781582825, 0.16384882590500638, 0.17831190372817218, 0.11714830761775374, 0.11314357485389337, 0.10477216390427202, 0.28924662445206195, 0.182278297143057, 0.1884830673225224], [0.027974482982244808, 0.05605031365121249, 0.024249003690783866, 0.01515708052465925, 0.0541347711259732, 0.030414835237024818, 0.006649583810940385, 0.021833081082149874, 0.0330368522554636, 0.011388880429876735, 0.016543163765163627, 0.0160614023116068, 0.09082063363166526, 0.10488692962098867, 0.09108809623285197, 0.04276904292055406, 0.05427240612334572, 0.03610162159020547, 0.3799135592998937, 0.32559538492932916, 14.501438308507204, 56.2157566845417, 63.44472438097, 48.07724319398403, 17.07273468375206, 53.039997294545174, 63.085985630750656, 68.93317267298698, 67.49445587396622, 56.56583949923515, 55.37388525903225, 61.60200946033001, 28.21050513535738, 2.3482787422835827, 2.8597875824198127, 20.412928350269794, 63.12205709517002, 80.40030375123024, 72.78249531984329, 71.00834012031555, 70.24121448397636, 68.59337210655212, 67.5014778971672, 62.53843501210213, 53.70819143950939, 46.2550737708807, 49.24094595015049, 49.46694262325764, 50.93720532953739, 53.26444365084171, 54.376279190182686, 58.36888074874878, 59.23262760043144, 57.38431937992573, 58.47409330308437, 55.332866460084915, 51.94356232881546, 46.96474649012089, 46.00085601210594, 45.19924722611904, 46.1596304923296, 44.658319652080536, 43.995293229818344, 43.82072299718857, 43.25855076313019, 44.78747472167015, 44.175981134176254, 44.05094124376774, 43.10194216668606, 47.56944224238396, 45.3301540017128, 43.881930112838745, 45.59451721608639, 43.53172190487385, 40.82624427974224, 41.616734862327576, 44.4218697398901, 44.027355909347534, 42.43152894079685, 44.64763082563877, 46.034165024757385, 51.034366115927696, 55.81208914518356, 56.937866136431694, 59.109996780753136, 59.515868201851845, 57.80513919889927, 57.84693315625191, 54.629778787493706, 60.571003183722496, 56.06118097901344, 54.95564930140972, 56.04234538972378, 56.29581838846207, 55.06953679025173, 54.253002405166626, 49.20011714100838, 45.75212135910988, 45.41642837226391, 46.53251588344574, 43.74623939394951, 40.45170217752457, 42.14016817510128, 41.504526883363724, 42.29759372770786, 40.21475829184055, 40.667032822966576, 42.17521369457245, 41.85421071946621, 39.660425037145615, 41.126097589731216, 40.03490634262562, 40.386923253536224, 39.43009279668331, 42.841637134552, 46.094919964671135, 49.11848992109299, 49.346245899796486, 52.99598425626755, 49.258451610803604, 50.742834359407425, 51.19373336434364, 52.536702901124954, 53.06731402873993, 47.943463772535324, 44.03104931116104, 41.57904848456383, 43.27047452330589, 43.24653960764408, 44.71209056675434, 43.686278611421585, 44.795154109597206, 45.19924722611904, 48.132556825876236, 52.40796960890293, 56.57429404556751, 61.61886915564537, 58.18508081138134, 62.90181711316109, 65.98244860768318, 57.85561569035053, 62.77925468981266, 65.17278805375099, 53.35112079977989, 45.00021010637283, 3.1963718589395285, 1.3794262055307627, 33.41599591076374, 59.818597957491875, 43.933090567588806, 50.05853287875652, 66.77665919065475, 58.70696760714054, 63.293332904577255, 47.72572785615921, 19.702826254069805, 36.6793368011713, 37.516371086239815, 47.2804107517004, 28.462346121668816, 0.13035681447945535, 0.08452583351754583, 0.05844159139087424, 0.019826556817861274, 0.05141344176081475, 0.032331993788830005, 0.044726873020408675, 0.11461083791800775, 0.07433254650095478, 0.033790551460697316, 0.05014823211240582, 0.020973432874598075, 0.05069591854407918, 0.061630381023860537, 0.08411967093707062, 0.011407893325667828, 0.02366194261412602, 0.046296467116917484, 0.04858603722823318, 0.06547712910105474, 0.0017948073900697636, 0.02347570251004072, 0.05066243655164726, 0.046125984663376585, 0.023388368426822126, 0.016428791386715602, 0.03499952486890834, 0.009206975537381368, 0.1281303566065617, 0.058331571708549745, 0.13000956358155236, 0.01903960197523702, 0.08974043026682921, 0.015113727040443337, 0.3212644485756755, 0.30517569626681507, 16.484720036387444, 66.24328941106796, 58.553809225559235, 48.438493609428406, 23.58015339821577, 56.28328666090965, 74.55374747514725, 73.75353321433067, 73.46837371587753, 62.14658483862877, 62.61057414114475, 68.57454791665077, 32.28972874581814, 2.9205971444025636, 3.318299953825772, 20.935430712997913, 65.3147104382515, 82.47841224074364, 73.87333318591118, 74.4056086242199, 71.76321521401405, 71.45009681582451, 71.29594668745995, 67.91640803217888, 57.32067659497261, 49.88950654864311, 50.716406777501106, 52.92655438184738, 50.9513595700264, 56.04361832141876, 57.05199681222439, 59.67449069023132, 62.64900527894497, 60.56581266224384, 60.27856707572937, 58.848084434866905, 52.635866180062294, 49.85625073313713, 48.399819284677505, 47.625489234924316, 46.87702439725399, 49.05693702399731, 46.134897619485855, 45.946560725569725, 46.18782877922058, 46.165691167116165, 44.46944698691368, 46.83852106332779, 44.9589367210865, 48.24617072939873, 48.11748683452606, 45.5206111818552, 46.88981831073761, 45.430179834365845, 44.89225409924984, 45.60416489839554, 46.776166409254074, 46.41101360321045, 45.52278086543083, 47.4583476036787, 49.682144075632095, 54.793846383690834, 59.55792814493179, 60.84158666431904, 61.47564724087715, 64.22530129551888, 60.0709044188261, 58.425026535987854, 57.54162713885307, 63.08618322014809, 59.1348360478878, 58.65002006292343, 59.69116799533367, 58.504066094756126, 56.94853976368904, 56.801692843437195, 52.348187416791916, 48.7385331094265, 46.97354681789875, 47.55054585635662, 46.0420648008585, 44.5225415378809, 44.86871816217899, 44.46609936654568, 44.7375226020813, 42.594228610396385, 43.48496161401272, 45.43141856789589, 42.998291328549385, 42.89297237992287, 43.628533110022545, 42.7122350782156, 43.27074430882931, 42.83950164914131, 45.565486773848534, 47.9644538462162, 49.891429245471954, 52.68752060830593, 54.97119426727295, 52.10674837231636, 52.31380306184292, 54.849878177046776, 54.12657558917999, 55.45649282634258, 50.35187713801861, 48.34677413105965, 43.46215903759003, 44.780190512537956, 45.42678661644459, 47.38753080368042, 45.831860080361366, 47.026211991906166, 47.77650073170662, 49.504663199186325, 55.250912457704544, 58.81329730153084, 64.79837894439697, 62.16402590274811, 64.14987534284592, 70.89033365249634, 61.634934693574905, 67.11042568087578, 66.90262243151665, 58.20947930216789, 53.92123460769653, 4.14786122739315, 1.4410565234720707, 37.5578648597002, 67.23299950361252, 50.56929387152195, 54.53498527407646, 68.14048200845718, 63.12798097729683, 70.0868059694767, 54.100911766290665, 23.434499613940716, 44.87910680472851, 37.25328080356121, 55.15541598200798, 29.300733134150505, 0.22103136376244947, 0.054588227067142725, 0.06629824871197343, 0.0165076037592371, 0.04543724935501814, 0.012927117859362625, 0.03319713759992737, 0.048639082233421504, 0.04811543025425635, 0.018984569869644474, 0.010310269899491686, 0.04115630035812501, 0.06538759640534408, 0.03895198075042572, 0.05533210023713764, 0.09278603363782167, 0.09181675166473724, 0.14728472800925374, 0.30167323420755565, 0.1663531141821295, 0.12652139528654516, 0.16100027016364038, 0.07750559889245778, 0.1384033280191943, 0.15564950415864587, 0.14781042089452967, 0.1284171818406321, 0.11257478545303456, 0.27761218312662095, 0.18909925769548863, 0.41402937553357333, 0.11591502887313254, 0.18360141286393628, 0.29456245014443994, 0.4653573181713, 0.5992719589266926, 27.84282546490431, 76.78956270217896, 76.32987856864929, 60.45854061841965, 31.400749348104, 65.46845778822899, 76.96255221962929, 79.20808732509613, 79.37353044748306, 71.71955555677414, 70.18205925822258, 75.07380276918411, 35.26909567415714, 3.910621670074761, 4.863088298588991, 24.571125023066998, 68.8152725994587, 85.99276006221771, 77.76702985167503, 77.84410491585732, 76.35537520051003, 74.65153142809868, 76.33122369647026, 69.67678517103195, 62.6773327589035, 51.30104720592499, 54.19129751622677, 56.09195552766323, 57.05045409500599, 59.065740555524826, 60.11366732418537, 65.0409959256649, 67.28379517793655, 62.21337765455246, 62.58468613028526, 62.15834140777588, 55.239258483052254, 54.06973443925381, 52.008968219161034, 50.73894336819649, 48.19801211357117, 50.97731977701187, 48.40758226811886, 49.598107784986496, 48.399690091609955, 49.421535059809685, 48.54143388569355, 49.71435494720936, 47.22100853919983, 51.99542574584484, 51.61977790296078, 46.57447323203087, 50.840283930301666, 48.444136306643486, 46.256741881370544, 47.04625591635704, 49.85672190785408, 46.82296849787235, 46.09996609389782, 48.7071467936039, 50.83072744309902, 56.47133097052574, 61.126176193356514, 62.85949878394604, 63.9298215508461, 66.50079399347305, 62.352583184838295, 57.90694333612919, 58.23583848774433, 66.79689690470695, 61.0724850744009, 59.68875892460346, 60.72028577327728, 63.951632380485535, 59.81375701725483, 60.543431863188744, 54.799694269895554, 50.9525603055954, 49.12171594798565, 52.04902186989784, 48.67986425757408, 46.04272596538067, 46.590926349163055, 46.63295589387417, 47.24179342389107, 43.67659293115139, 45.08616529405117, 47.312116250395775, 44.41653862595558, 44.47264261543751, 47.16230548918247, 45.961687713861465, 46.083626970648766, 44.43947419524193, 48.55221390724182, 48.84309969842434, 52.56048962473869, 54.82552908360958, 59.20574404299259, 54.16217967867851, 55.02386324107647, 55.22242158651352, 57.14471563696861, 58.828549683094025, 53.7718266248703, 49.96952265501022, 46.06791481375694, 47.058650851249695, 47.73833937942982, 50.184864699840546, 49.49813134968281, 47.65190161764622, 50.35069540143013, 51.152847558259964, 59.55863110721111, 59.904522746801376, 68.4773263335228, 62.694853618741035, 68.23449656367302, 70.82695305347443, 66.68549448251724, 70.19894555211067, 69.70773831009865, 60.229067131876945, 59.68515671789646, 6.358411135151982, 2.163500119931996, 42.19493083655834, 72.81176894903183, 55.0186613202095, 59.88968834280968, 77.15042173862457, 68.9752896130085, 75.3455413877964, 58.731248304247856, 30.62008123844862, 53.77048149704933, 51.484185978770256, 59.67893645167351, 50.69255165755749, 0.3648410743335262, 0.22725216433173046, 0.17820372828282416, 0.10863201459869742, 0.14652193378424272, 0.12978363898582757, 0.14937247848138213, 0.12451679504010826, 0.13294999720528722, 0.09331991983344778, 0.14931497687939554, 0.13285215245559812, 0.18135129532311112, 0.2437191893113777, 0.36079972400330007, 0.12769188091624528], [0.04724795238871593, 0.017551299024489708, 0.0767473540327046, 0.043628746789181605, 0.051385826445766725, 0.07082042910042219, 0.021599527208309155, 0.04423399419465568, 0.0691749170073308, 0.0892190715239849, 0.10235459558316506, 0.05626369224046357, 0.007882165864430135, 0.07787707349052653, 0.05413409206084907, 0.06517750924103893, 0.034301909763598815, 0.05109310113766696, 0.040386570763075724, 0.14117213257122785, 0.2682657534023747, 44.90855522453785, 35.040157958865166, 33.76002945005894, 30.468691661953926, 38.14522594213486, 52.63606756925583, 67.05091327428818, 64.74647372961044, 57.2242833673954, 56.63308449089527, 63.62369477748871, 39.17672619223595, 5.7461300399154425, 1.5224672737531364, 12.540773916989565, 51.184541657567024, 82.82176941633224, 75.13738855719566, 72.45577365159988, 72.32287958264351, 70.52204981446266, 69.87248227000237, 69.7968815267086, 63.42797487974167, 54.78834427893162, 47.419726476073265, 50.07927976548672, 50.375945046544075, 56.030113846063614, 55.47596678137779, 59.97566632926464, 61.33329167962074, 60.62447011470795, 56.614796072244644, 56.23242259025574, 53.13522398471832, 50.649826750159264, 46.506897658109665, 44.54079955816269, 45.53989514708519, 42.15262770652771, 45.51710017025471, 44.29643467068672, 42.69497640430927, 42.20392495393753, 44.29091736674309, 43.085903227329254, 46.14375874400139, 43.64672273397446, 45.53368628025055, 42.307123616337776, 44.82527129352093, 43.13379965722561, 43.038329780101776, 40.00853955745697, 43.37152250111103, 44.338456615805626, 44.27379548549652, 46.260944455862045, 46.18763118982315, 52.96347700059414, 53.24001096189022, 54.349171444773674, 55.69720610976219, 55.62860079109669, 60.170413479208946, 59.181615337729454, 57.351500540971756, 60.49821808934212, 56.704870238900185, 53.30374874174595, 53.645981177687645, 55.45027256011963, 53.303471356630325, 53.13848800957203, 49.8724302649498, 45.75160838663578, 45.39367139339447, 44.70474176108837, 43.891482800245285, 42.514641880989075, 40.22612348198891, 41.353500187397, 41.266659647226334, 40.83385527133942, 42.95618578791618, 43.205672800540924, 43.4191719442606, 39.314879179000854, 41.07469014823437, 41.374064683914185, 41.59100644290447, 42.77327500283718, 41.258771270513535, 46.97175711393356, 48.62151838839054, 52.97981232404709, 55.506650134921074, 55.73423892259598, 55.005020052194595, 54.56360533833504, 53.712249621748924, 53.584633469581604, 51.56062267720699, 52.32997499406338, 48.31836685538292, 47.89115957915783, 46.02146990597248, 46.912392899394035, 45.838916301727295, 43.887667804956436, 44.41174328327179, 47.09512509405613, 46.762840524315834, 51.85900926589966, 54.348521679639816, 60.45024946331978, 58.023733869194984, 63.656278029084206, 65.54577603936195, 56.63922876119614, 63.260096088051796, 53.15575048327446, 50.41675865650177, 3.730756896547973, 0.23227648925967515, 37.81229540705681, 55.61551049351692, 48.761442080140114, 55.58681063354015, 60.0316297262907, 57.095360085368156, 63.293340504169464, 35.21348565816879, 26.37213908135891, 33.43128629028797, 29.424558989703655, 54.847811087965965, 5.415722569450736, 0.1955479124444537, 0.0455800756753888, 0.03535882082360331, 0.05399428999226075, 0.13343709841137752, 0.024653756190673448, 0.06726816151058301, 0.05329052248271182, 0.040214607724919915, 0.047239788764272816, 0.07024182850727811, 0.04531674312602263, 0.0371758766414132, 0.040565513700130396, 0.08769176129135303, 0.039636723304283805, 0.07461661094566807, 0.023067617767082993, 0.046610399294877425, 0.0464360279875109, 0.0037624183005391387, 0.07122380862710997, 0.03455510457570199, 0.06017530773533508, 0.08053978061070666, 0.013563229331339244, 0.07398372967145406, 0.07633437853655778, 0.044905044123879634, 0.03539423611073289, 0.046485555212711915, 0.013100576325086877, 0.006998456301516853, 0.03296794384368695, 0.017681284334685188, 0.2126694077742286, 0.9171115444041789, 49.47378985583782, 46.7802169919014, 36.44365444779396, 37.24134564399719, 45.68833418190479, 60.901061072945595, 78.82815331220627, 71.7207182943821, 64.11763787269592, 64.23651829361916, 68.76690119504929, 43.6148576438427, 7.359291203320026, 1.7594539071433246, 14.386029951274395, 53.96806329488754, 83.1084868311882, 79.42786753177643, 74.35453936457634, 74.63429555296898, 73.7209765613079, 73.74252140522003, 74.11570698022842, 65.04148229956627, 56.18297204375267, 48.87732446193695, 50.86757406592369, 53.107861652970314, 58.1781879812479, 57.71753489971161, 61.307764649391174, 63.18080194294453, 62.9175216704607, 59.170390740036964, 58.447167947888374, 56.48121424019337, 52.0496716350317, 47.8678098320961, 48.96691985428333, 46.089448258280754, 44.672819674015045, 47.47302621603012, 46.703457310795784, 46.58987760543823, 44.44137789309025, 44.442293643951416, 45.85017889738083, 47.54820138216019, 46.08771555125713, 47.49673314392567, 45.91743528842926, 46.81215047836304, 44.09265540540218, 45.61809875071049, 45.20023137331009, 46.11845590174198, 48.07757757604122, 47.9767157882452, 50.500927940011024, 49.74425554275513, 54.563757330179214, 57.91349038481712, 60.37691719830036, 58.4330403059721, 61.46841622889042, 63.315105736255646, 61.67980268597603, 62.40836039185524, 63.97759258747101, 59.505585953593254, 58.15226197242737, 56.92313052713871, 56.87738098204136, 57.31319099664688, 55.59255592525005, 53.261400014162064, 47.804410234093666, 47.99642913043499, 46.71041093766689, 46.154774352908134, 45.72014607489109, 44.37349073588848, 43.80676254630089, 43.68547685444355, 43.546066135168076, 44.46211338043213, 45.851786211133, 45.24158455431461, 43.188505321741104, 45.397577583789825, 44.40871484577656, 43.67546819150448, 45.86201526224613, 44.26907233893871, 50.51054522395134, 51.75043769180775, 54.13504533469677, 58.9198549836874, 58.478132486343384, 56.07451066374779, 58.53262156248093, 55.63968099653721, 57.416370660066605, 54.66599464416504, 53.72431397438049, 51.18032768368721, 50.70578634738922, 46.63720406591892, 49.171147495508194, 48.45821835100651, 47.368121445178986, 49.05505232512951, 48.84396605193615, 49.22245614230633, 54.814205691218376, 57.487107664346695, 62.75533117353916, 62.089496701955795, 63.445499539375305, 70.27966842055321, 62.428164929151535, 65.75803264975548, 58.31662215292454, 60.70036344230175, 5.36722719669342, 0.35105437505990267, 43.37920568883419, 59.58278641104698, 52.99220345914364, 58.60472269356251, 66.73667013645172, 62.33906731009483, 72.29421392083168, 41.60797253251076, 34.33984033763409, 39.8223115503788, 33.592956215143204, 60.63014701008797, 2.8972678212448955, 0.06578071202966385, 0.04914813245704863, 0.0928271708835382, 0.03131850950012449, 0.0878888979787007, 0.06942513209651224, 0.039843044069129974, 0.10234051704173908, 0.08083901455393061, 0.02255907962535275, 0.09197006453177892, 0.05367045014281757, 0.04686288164521102, 0.0027100431543658487, 0.07404865275020711, 0.03069632628466934, 0.147446412302088, 0.09703397561679594, 0.15602402156218886, 0.16197643184568733, 0.0739388148940634, 0.24294097325764596, 0.11683284290484153, 0.16516783012775704, 0.1498648340930231, 0.19377507007448003, 0.2016843159799464, 0.16583417484071106, 0.06701602425891906, 0.16647785436362028, 0.21019964420702308, 0.20549484353978187, 0.09613909394829534, 0.33377239771652967, 0.15767078788485378, 0.34290179377421737, 2.408116268925369, 72.16187462210655, 56.11888088285923, 49.29195821285248, 47.01278731226921, 51.857101768255234, 68.40343549847603, 91.08390927314758, 79.24019560217857, 68.54981124401093, 72.81713426113129, 76.44447281956673, 47.007524594664574, 8.292028103023767, 2.2395214531570673, 16.914457976818085, 57.02632538974285, 87.17185199260712, 81.25096410512924, 78.13279062509537, 79.44041445851326, 77.74942919611931, 77.10203513503075, 78.59016448259354, 67.2932642698288, 62.19184800982475, 53.22315126657486, 53.38441081345081, 57.79275566339493, 61.522950902581215, 60.88753379881382, 64.57086995244026, 66.40706062316895, 65.06485104560852, 64.02206540107727, 63.004400208592415, 60.628155916929245, 55.6660021841526, 50.66113494336605, 49.196693524718285, 50.220066010951996, 46.35984554886818, 52.450128346681595, 49.43438217043877, 48.334398195147514, 46.106615737080574, 48.48282963037491, 48.049307093024254, 50.88167890906334, 48.69376391172409, 50.79238370060921, 47.321995720267296, 48.100030571222305, 46.742029041051865, 47.57150553166866, 45.986469984054565, 47.66265124082565, 49.52806994318962, 52.58183307945728, 52.73958541452885, 51.15863844752312, 58.562282770872116, 59.16933439671993, 61.86424478888512, 59.826136752963066, 61.50713235139847, 65.23138850927353, 61.65389567613602, 63.041205033659935, 66.91650688648224, 61.48309864103794, 58.19295018911362, 58.464027643203735, 61.317678317427635, 59.36291120946407, 57.4770800024271, 55.50201818346977, 48.722296580672264, 48.67879271507263, 47.34218783676624, 48.430354446172714, 48.65399904549122, 45.09188398718834, 46.50763861835003, 46.1433369666338, 46.16639792919159, 47.47225485742092, 47.078964561223984, 47.38652765750885, 43.908057510852814, 47.913768365979195, 46.120336800813675, 46.14457570016384, 48.62120300531387, 46.24190367758274, 52.63119623064995, 55.423875376582146, 56.573078110814095, 58.53356771171093, 61.83795779943466, 58.62730488181114, 63.238091468811035, 58.86179029941559, 60.04959896206856, 57.226095870137215, 55.951686054468155, 53.78568448126316, 51.70551270246506, 49.3322816491127, 52.386869341135025, 51.65097802877426, 50.65170764923096, 51.107819974422455, 52.252307161688805, 51.127723306417465, 57.40248240530491, 60.655605643987656, 65.91280594468117, 63.985572159290314, 68.14192593097687, 70.3909720480442, 63.59380178153515, 70.56132450699806, 59.86591301858425, 63.798128217458725, 8.688906356692314, 0.6646567722782493, 47.93954998254776, 64.87019509077072, 60.51618352532387, 66.28207013010979, 70.6790953874588, 67.06564888358116, 76.47138297557831, 47.22119852900505, 39.70155782997608, 51.71949975192547, 41.24048665165901, 76.28463059663773, 11.865466553717852, 0.41494417644571513, 0.17183670977829024, 0.24533585412427783, 0.1768637212808244, 0.3679126751376316, 0.1235942832136061, 0.17998001421801746, 0.21719429700169712, 0.09517166734440252, 0.1380055517074652, 0.18675864266697317, 0.1707780361175537, 0.09170203047688119, 0.16794328432297334, 0.15862996922805905, 0.13038840028457344], [0.019912922398361843, 0.040834735191310756, 0.07876529809436761, 0.05594318834482692, 0.01659808083786629, 0.012175362153357128, 0.022881485274410807, 0.05668426732881926, 0.07807835136190988, 0.06225099459697958, 0.03805197455221787, 0.05748832867539022, 0.11741942900698632, 0.03338536851515528, 0.04986186329915654, 0.05007548308640253, 0.045926421153126284, 0.11946104015805759, 0.0633527610625606, 0.4546937841223553, 0.46021278016269207, 8.799279034137726, 58.23866933584213, 33.21951225399971, 37.02674075961113, 23.706734105944633, 53.39918442070484, 55.66377550363541, 62.27611608803272, 69.03964295983315, 64.05546560883522, 67.87993758916855, 55.67894048988819, 15.307401660829782, 1.1144899344071746, 5.603187410160899, 42.694250643253326, 86.34900614619255, 79.1507788002491, 73.11334356665611, 69.97045621275902, 71.28288298845291, 73.61559301614761, 69.02131274342537, 70.36462426185608, 63.06563012301922, 50.46373173594475, 51.19662880897522, 52.395460680127144, 55.6104301661253, 58.03332455456257, 61.363838240504265, 60.72522170841694, 59.38602916896343, 56.505274549126625, 52.221350222826004, 48.57545346021652, 46.50585651397705, 46.65342539548874, 45.045024901628494, 44.95925210416317, 45.168130695819855, 44.007916152477264, 43.09035278856754, 45.32348535954952, 44.57763098180294, 43.25451537966728, 43.3822987228632, 42.53502398729324, 43.3608640730381, 45.41472606360912, 44.24810506403446, 43.89837183058262, 44.01739664375782, 42.95693814754486, 44.13330562412739, 43.139453753829, 44.09374214708805, 47.613611072301865, 46.25137656927109, 52.099901139736176, 57.24499985575676, 58.25804069638252, 57.80064024031162, 55.309987887740135, 55.244627594947815, 56.86185121536255, 55.076672807335854, 57.1531093865633, 60.21991342306137, 58.09719532728195, 55.11719383299351, 53.242826610803604, 52.11945869028568, 53.662453293800354, 52.491109147667885, 49.874957129359245, 48.30072820186615, 44.387257397174835, 43.433922752738, 44.11602035164833, 42.20053933560848, 41.83618828654289, 40.95130696892738, 42.43030920624733, 43.44386301934719, 42.2704441845417, 43.40834252536297, 39.930989518761635, 41.62654213607311, 39.41132180392742, 39.18720223009586, 40.68021811544895, 41.93213313817978, 41.68024845421314, 43.83905701339245, 49.75497856736183, 53.32780905067921, 55.17364740371704, 54.64636869728565, 57.26984292268753, 49.928758442401886, 56.28099538385868, 57.248932644724846, 57.70879156887531, 55.89459411799908, 58.15061666071415, 54.42128777503967, 55.434028431773186, 49.54036608338356, 48.44327375292778, 44.70747381448746, 45.68472437560558, 43.12254846096039, 47.16744661331177, 44.05677393078804, 48.496246710419655, 48.55067119002342, 58.880481496453285, 57.113013938069344, 64.57054316997528, 66.35113522410393, 65.3978955745697, 50.00426799058914, 52.485759034752846, 2.8686992917209864, 0.856218149419874, 46.23517423868179, 52.88737088441849, 53.13951015472412, 59.4631802290678, 57.82049037516117, 56.09683446586132, 38.17897193133831, 10.17329765483737, 28.67272563278675, 18.738479800522327, 41.83539032936096, 33.32156337797642, 0.13615931093227118, 0.07980214519193396, 0.061623916917596944, 0.01977286799956346, 0.03918581292964518, 0.12028989294776693, 0.020000493968836963, 0.034797445478034206, 0.04985446037608199, 0.057005891867447644, 0.051807596391881816, 0.026837664881895762, 0.043072332700830884, 0.05344525656255428, 0.043451904130051844, 0.03971813690441195, 0.015173597948887618, 0.05362242205592338, 0.0609921933937585, 0.02130091110302601, 0.11143489115056582, 0.04148920554143842, 0.054379034190787934, 0.03782954918278847, 0.013418543003353989, 0.07038023904897273, 0.11519543506437913, 0.07907722276286222, 0.01129217394918669, 0.06353947799652815, 0.07319944284972735, 0.04147271502006333, 0.03556762036168948, 0.03505261440295726, 0.05987888653180562, 0.11781704946770333, 0.39525339554529637, 0.381835424923338, 11.208609100431204, 68.5278408229351, 35.618167743086815, 44.888287112116814, 31.388346813619137, 59.232680797576904, 67.97082111239433, 67.61527419090271, 72.2799950838089, 68.51100772619247, 72.68300145864487, 60.51868759095669, 17.964514531195164, 1.3460403657518327, 7.00887780636549, 46.365845426917076, 85.00090688467026, 80.10092541575432, 76.5067970752716, 74.14732128381729, 74.34565544128418, 75.99651485681534, 72.4514190852642, 72.51201063394547, 66.5145568549633, 53.4899615496397, 53.09895873069763, 53.51934537291527, 55.14024339616299, 60.951499566435814, 63.37051436305046, 63.21026176214218, 60.830753445625305, 60.075106993317604, 54.698376506567, 51.140346229076385, 48.5522823035717, 49.34897035360336, 45.43156296014786, 46.52928605675697, 46.50406301021576, 47.619854137301445, 45.558096170425415, 47.0765782892704, 46.44711546599865, 47.14370168745518, 47.26578153669834, 44.921181946992874, 46.31427839398384, 47.38624647259712, 46.247789561748505, 45.76087608933449, 46.72412060201168, 45.556131675839424, 46.10266014933586, 47.27184981107712, 47.66768217086792, 49.472060948610306, 48.157544285058975, 53.93112927675247, 61.52257852256298, 58.98623362183571, 57.66333840787411, 59.23881746828556, 59.24670584499836, 61.649537310004234, 60.45135520398617, 62.03593097627163, 62.16258578002453, 60.904458090662956, 56.48284055292606, 58.28037969768047, 54.95447136461735, 56.51303373277187, 55.09568698704243, 53.244661912322044, 50.26844121515751, 46.12639747560024, 46.5497175604105, 45.77795997262001, 46.494977697730064, 44.05919060111046, 42.8520143777132, 46.47227771580219, 46.056401431560516, 45.28938598930836, 45.714541375637054, 44.23535294830799, 44.939439967274666, 43.84728357195854, 44.05469164252281, 45.350680500268936, 45.57347774505615, 45.35973161458969, 46.05254463851452, 52.94652231037617, 54.89861436188221, 60.01075364649296, 57.80289351940155, 59.542580768465996, 52.15357705950737, 59.17059972882271, 60.105763748288155, 59.759009554982185, 59.53760303556919, 59.879045113921165, 55.273517444729805, 57.05290116369724, 51.48191750049591, 50.27085788547993, 47.24978819489479, 47.95121155679226, 44.40347112715244, 50.32075680792332, 46.452085599303246, 51.7964456230402, 53.43904048204422, 61.342092007398605, 60.81996202468872, 65.16464129090309, 71.43625795841217, 69.31565254926682, 54.84180361032486, 62.15117499232292, 4.4993561413139105, 0.8847552712541074, 50.916405245661736, 60.037599205970764, 60.409033074975014, 63.90998661518097, 65.33151313662529, 62.880393862724304, 52.95077048242092, 16.75780188292265, 36.74299478530884, 20.20981214940548, 51.751627027988434, 34.71507400274277, 0.2944727393332869, 0.09151592952548526, 0.10576557309832424, 0.01867176019004546, 0.018817417803802527, 0.04534208004770335, 0.06542125280248001, 0.0442907350952737, 0.05121862057421822, 0.012880556441814406, 0.044467358820838854, 0.027342798421159387, 0.014354328141052974, 0.05713199760066345, 0.07738793137832545, 0.03034334600670263, 0.017989715342991985, 0.1414021389791742, 0.13961696211481467, 0.14168461522785947, 0.20385779935168102, 0.11063258498325013, 0.14205015264451504, 0.11950770640396513, 0.11574034215300344, 0.23162618977949023, 0.2066287858178839, 0.21377382741775364, 0.09448319920920767, 0.25964282860513777, 0.13656339549925178, 0.17019162070937455, 0.121440073417034, 0.10298145803972147, 0.36375792464241385, 0.2072628471069038, 0.8155152085237205, 0.5074219219386578, 21.454461961984634, 87.194042801857, 45.94374127686024, 55.982943177223206, 36.61462627351284, 64.96578276157379, 73.36276218295097, 75.66435188055038, 80.90475708246231, 76.42511665821075, 80.30456408858299, 65.70777654647827, 21.12905692309141, 2.401850880123675, 9.405070077627897, 50.96793048083782, 92.16341614723206, 85.2409628033638, 80.19896775484085, 78.73186647891998, 79.01136428117752, 81.56106546521187, 75.67964226007462, 76.80428311228752, 69.8150597512722, 54.69953164458275, 56.43744058907032, 56.66649229824543, 60.70244573056698, 63.31870794296265, 66.94839477539062, 65.42856752872467, 66.40614107251167, 62.31676250696182, 59.076835960149765, 54.95039038360119, 52.378654181957245, 52.00948879122734, 47.725720256567, 49.45556603372097, 51.28428250551224, 48.47194701433182, 50.165029764175415, 50.020341128110886, 49.21770639717579, 51.19327738881111, 48.497721031308174, 47.401529252529144, 48.599825352430344, 49.82117481529713, 47.9887193441391, 48.18318150937557, 48.94923560321331, 46.47235371172428, 48.41254100203514, 48.30184914171696, 47.99274332821369, 52.224591448903084, 51.09060309827328, 55.74409179389477, 61.95335380733013, 63.648157864809036, 59.31719206273556, 60.88105134665966, 61.43739089369774, 64.05406728386879, 60.35613991320133, 61.65643773972988, 66.31974130868912, 63.60590413212776, 58.65274451673031, 60.628095120191574, 57.411731109023094, 60.93227259814739, 57.4067647755146, 55.41784130036831, 53.38174715638161, 50.294876396656036, 49.34673607349396, 47.65422709286213, 48.26357759535313, 47.16636747121811, 45.38697235286236, 50.51117219030857, 48.12058366835117, 48.16615082323551, 48.47616858780384, 45.08450098335743, 46.9888523966074, 46.93249762058258, 45.30232809484005, 49.17649760842323, 47.50804513692856, 48.29364538192749, 48.41052331030369, 56.307016387581825, 58.71316507458687, 62.5565030425787, 59.146303832530975, 62.605843394994736, 54.684366658329964, 63.38479779660702, 62.550001591444016, 63.68892587721348, 62.54446528851986, 62.23506689071655, 57.39847742021084, 61.43870562314987, 53.54871779680252, 52.38340772688389, 48.24718527495861, 51.242150366306305, 47.09943786263466, 52.213591039180756, 49.63349148631096, 53.88624228537083, 55.31985215842724, 64.00986045598984, 62.16303035616875, 67.91044235229492, 71.4708437025547, 70.66904872655869, 59.330928325653076, 66.35518580675125, 6.805836651474237, 1.1327068693935871, 56.2869306653738, 63.842084258794785, 66.11133769154549, 70.76907455921173, 70.18118530511856, 67.2722589969635, 51.47612281143665, 16.020981520414352, 46.88202112913132, 30.56138388812542, 58.36062379181385, 51.400016695261, 0.4251279862364754, 0.141181661747396, 0.2462998594273813, 0.15851040923735127, 0.10945518995868042, 0.19710263761226088, 0.21783091127872467, 0.1911419301177375, 0.13181262620491907, 0.07587546409922652, 0.10537806811043993, 0.1766666810726747, 0.14663430978544056, 0.09779757136129774, 0.12967173795914277, 0.09616684284992516, 0.1558594874222763], [0.023869272699812427, 0.054795319665572606, 0.020725889517052565, 0.024335688394785393, 0.0637422178988345, 0.037922703559161164, 0.03946332792111207, 0.03219611768145114, 0.04128551940084435, 0.0331819495477248, 0.049804743903223425, 0.06260372625547461, 0.019788490208156873, 0.050016541717923246, 0.04556131789286155, 0.012543970206024824, 0.03264500199293252, 0.013408591730694752, 0.07547610701294616, 0.014919032018951839, 0.16887769277673215, 0.22350562474457547, 30.12836292386055, 54.55215275287628, 40.77954098582268, 37.719998359680176, 35.74324183166027, 62.32824929058552, 73.4223809838295, 72.36396297812462, 65.19368693232536, 56.94608889520168, 65.19269898533821, 27.539666332304478, 1.7120884987525642, 1.758920510765165, 17.839077562093735, 62.29503907263279, 81.78159803152084, 71.68053925037384, 72.87771061062813, 70.88068976998329, 66.7433425784111, 67.57242769002914, 71.32654264569283, 64.94011133909225, 55.4234953969717, 50.95787242054939, 52.48754493892193, 55.87569773197174, 59.40374381840229, 60.303782522678375, 61.302121952176094, 61.81413307785988, 55.67355237901211, 47.550542056560516, 49.27320621907711, 47.17068023979664, 46.44231632351875, 47.649139165878296, 45.38381092250347, 45.587878972291946, 45.15581555664539, 44.68793906271458, 45.269102677702904, 45.21179415285587, 42.97937214374542, 46.614002510905266, 45.19777670502663, 45.598047226667404, 43.22406381368637, 43.31763759255409, 42.90524572134018, 42.85401687026024, 44.51490014791489, 44.456972256302834, 44.491428807377815, 44.15688715875149, 43.89210216701031, 45.70561945438385, 55.3042121976614, 60.62846750020981, 59.81599509716034, 60.54381564259529, 58.727106526494026, 56.424445286393166, 59.27976407110691, 56.53085097670555, 57.253845781087875, 58.8986749202013, 59.71130311489105, 56.55148766934872, 54.33897279202938, 53.502166494727135, 53.53468514978886, 52.90382020175457, 52.01315179467201, 48.20591948926449, 47.57695823907852, 44.78508085012436, 44.00853171944618, 42.78036542236805, 42.853644490242004, 40.201648995280266, 40.30774310231209, 42.873620018363, 43.99309694766998, 43.15803475677967, 43.876845985651016, 42.02022761106491, 40.43480448424816, 40.58197818696499, 41.78029328584671, 42.1500476449728, 41.33207693696022, 44.36720587313175, 44.37842667102814, 48.91690693795681, 54.65632036328316, 57.87877544760704, 57.917282581329346, 57.37553425133228, 54.6383473277092, 58.90975512564182, 58.571010902523994, 58.308224603533745, 57.998575419187546, 56.3966915756464, 54.48417820036411, 55.494749173521996, 51.86010740697384, 47.030661553144455, 45.97264252603054, 46.18585668504238, 47.07978151738644, 48.25175642967224, 51.31474167108536, 47.03942008316517, 48.963424041867256, 55.022651106119156, 64.30066645145416, 63.64476464688778, 75.00875025987625, 49.76924680173397, 54.8158548027277, 5.127769270911813, 0.5551614915020764, 45.010382160544395, 52.311014011502266, 48.17025080323219, 60.211538672447205, 57.34101690351963, 63.76003906130791, 11.531698163598776, 19.676516465842724, 38.2610247284174, 23.611231930553913, 57.50349618494511, 12.257091589272022, 0.2301912324037403, 0.055747038713889197, 0.042964884560205974, 0.04087678527866956, 0.05116338623338379, 0.010890945723076584, 0.03700145709444769, 0.02648004247021163, 0.07934004694106989, 0.02427760606224183, 0.03748895906028338, 0.036280583080952056, 0.043012107416871004, 0.050463659717934206, 0.06472354492871091, 0.0343519305170048, 0.07550643858849071, 0.0671941768086981, 0.025113483279710636, 0.028518683175207116, 0.045700752598349936, 0.027759191507357173, 0.06902432782226242, 0.013780549652437912, 0.02191693078202661, 0.009064659443538403, 0.02446333037369186, 0.09827202637097798, 0.013169254671083763, 0.09634733316488564, 0.08871941317920573, 0.029386962560238317, 0.05167839590285439, 0.11551928604603745, 0.0380100283655338, 0.06270030193263665, 0.027377306432754267, 0.11772769488743506, 0.34821978653781116, 39.44110840559006, 58.612284287810326, 44.45413760840893, 44.48717683553696, 40.770113691687584, 69.14531528949738, 78.47941562533379, 77.97120049595833, 70.72353780269623, 64.71587017178535, 70.8835244178772, 32.03069664537907, 1.8821191624738276, 1.7225989722646773, 19.107555896043777, 65.71659207344055, 84.19930189847946, 75.11120796203613, 77.95581892132759, 75.70580765604973, 71.94698095321655, 70.13709247112274, 74.05131563544273, 68.09109225869179, 57.65214040875435, 52.62589551508427, 53.31710122525692, 58.038629069924355, 62.99587346613407, 61.92900471389294, 66.66331127285957, 62.7801476418972, 57.43731513619423, 51.685958951711655, 51.59705512225628, 48.3800945430994, 49.252466931939125, 49.25871379673481, 48.116973862051964, 47.49308153986931, 45.695641189813614, 47.19282545149326, 46.91248409450054, 46.03862978518009, 44.74063843488693, 46.859218552708626, 45.209943652153015, 47.1005854010582, 44.926748648285866, 47.30311073362827, 45.49955651164055, 44.63693059980869, 46.93098910152912, 47.041688561439514, 47.60990247130394, 47.59996600449085, 47.45804741978645, 48.830172792077065, 57.628349885344505, 63.60613971948624, 62.293492555618286, 64.49118062853813, 63.073035925626755, 59.949386939406395, 63.12514252960682, 61.50256499648094, 60.51255851984024, 62.36732639372349, 62.172864228487015, 58.633688539266586, 57.629645615816116, 55.210155844688416, 55.52172392606735, 56.225115582346916, 53.56162190437317, 50.46964421868324, 48.55110056698322, 46.87783755362034, 46.792520731687546, 46.370826959609985, 44.60169889032841, 42.48426631093025, 44.149963930249214, 45.62637470662594, 45.942677333950996, 46.13074444234371, 46.01242259144783, 44.2250707000494, 44.306272342801094, 43.791882544755936, 45.97077302634716, 45.1040281355381, 44.11010026931763, 45.812203735113144, 47.33388148248196, 50.99830225110054, 57.42643252015114, 60.168182998895645, 60.79202972352505, 60.93342013657093, 56.53216950595379, 61.48748740553856, 61.66282519698143, 62.0696085691452, 61.798694506287575, 58.22651378810406, 57.113006338477135, 57.77409106492996, 53.819894045591354, 48.972676545381546, 47.51827418804169, 47.989084124565125, 49.592404291033745, 50.3137119859457, 52.673092782497406, 49.260716289281845, 52.88987495005131, 57.339724972844124, 67.67488539218903, 63.79601553082466, 77.51431301236153, 57.28188067674637, 65.17490074038506, 6.165469363331795, 0.853964276611805, 50.085572227835655, 57.67188414931297, 54.33668151497841, 65.99651545286179, 61.518216356635094, 70.85561871528625, 20.557016618549824, 23.66955880075693, 47.93142221868038, 25.85254356265068, 66.22911617159843, 9.90264292806387, 0.11906327868928201, 0.06801123687182553, 0.054009492887416855, 0.02910636208980577, 0.025746704086486716, 0.0044289555080467835, 0.022898304196132813, 0.020186483598081395, 0.0030273228821897646, 0.022985614159551915, 0.03267830586992204, 0.05289321743475739, 0.04982891565305181, 0.014910899008100387, 0.04948538291500881, 0.026005735890066717, 0.03686478688905481, 0.09617162228096277, 0.12387863709591329, 0.12587885867105797, 0.11294194075162522, 0.18067527300445363, 0.1934945976245217, 0.08688828253070824, 0.08042201661737636, 0.1384080183925107, 0.1394473368418403, 0.16634523257380351, 0.10951736709102988, 0.19525203300872818, 0.13821549044223502, 0.12884372379630804, 0.21245905343675986, 0.11952462737099268, 0.11485327529953793, 0.24058704409981146, 0.10145345018827356, 0.2093651139875874, 0.4247359244618565, 59.90556389093399, 71.41361117362976, 58.019892275333405, 53.73199336230755, 51.7186675965786, 74.43438827991486, 86.82661011815071, 85.798180103302, 80.0385631620884, 69.88394245505333, 78.64301204681396, 37.50581905245781, 2.5700657162815332, 3.5750975366681814, 22.23317127674818, 69.68639105558395, 86.88899517059326, 77.101571559906, 80.15976905822754, 80.72661504149437, 71.86217710375786, 73.26081365346909, 76.29203259944916, 73.78542870283127, 61.412236243486404, 55.858929231762886, 57.78857968747616, 63.076182156801224, 65.92571005225182, 67.14019328355789, 66.29093885421753, 66.53672486543655, 62.603924497962, 54.512049704790115, 54.44631703197956, 51.56125344336033, 51.53322994709015, 53.14462088048458, 49.192912727594376, 50.92522457242012, 48.18710669875145, 49.818172976374626, 48.884718865156174, 49.73713092505932, 47.67193414270878, 50.58595597743988, 47.89470098912716, 50.674369633197784, 46.22893117368221, 49.04774531722069, 47.67138697206974, 46.21465913951397, 50.928272008895874, 48.873950242996216, 49.94285188615322, 49.11855451762676, 48.057153671979904, 50.066911429166794, 59.307054206728935, 65.15055924654007, 63.52767392992973, 66.49128690361977, 63.12811776995659, 59.93826113641262, 65.71413740515709, 60.06711222231388, 61.681033819913864, 63.21878470480442, 65.45892789959908, 62.70486608147621, 60.08215181529522, 59.00421805679798, 58.51177588105202, 59.932124465703964, 56.55986621975899, 50.97585305571556, 51.00432872772217, 49.641402661800385, 49.89809028804302, 47.32876315712929, 47.4331321567297, 43.83229337632656, 45.948396027088165, 46.70018568634987, 49.681148529052734, 48.0347690731287, 47.467128932476044, 45.709001272916794, 46.83194361627102, 46.529742032289505, 50.31387537717819, 46.53149373829365, 45.83749517798424, 48.77089977264404, 50.68236440420151, 52.30445936322212, 60.337251126766205, 62.24596470594406, 64.25968185067177, 62.91585735976696, 57.83470161259174, 64.30993795394897, 63.055431470274925, 63.649168610572815, 64.32370841503143, 61.11406624317169, 58.58138434588909, 60.948345735669136, 57.410154193639755, 50.565250888466835, 50.36968298256397, 49.754579588770866, 52.979610934853554, 52.988814041018486, 54.78542223572731, 52.33200028538704, 53.5107996314764, 60.965513214468956, 70.57428941130638, 67.94562846422195, 80.29447183012962, 58.71093079447746, 69.01745975017548, 8.135885931551456, 1.190446789842099, 54.54636186361313, 61.85348756611347, 57.90555641055107, 72.6735171675682, 68.12787428498268, 73.84735777974129, 16.4805668592453, 28.369965478777885, 61.4652281999588, 34.04408700764179, 79.02236089110374, 21.769499257206917, 0.3387916908832267, 0.20466377172851935, 0.131735977192875, 0.16228780732490122, 0.20670234749559313, 0.12368079536827281, 0.09124490461545065, 0.14492371876258403, 0.11848387657664716, 0.08338014304172248, 0.10185469232965261, 0.10338026593672112, 0.15312048752093688, 0.18645339732756838, 0.149632245011162, 0.09131465165410191, 0.14198417571606115], [0.017643930186750367, 0.03979171713581309, 0.06082148458517622, 0.04434885639057029, 0.030134420303511433, 0.03901143791154027, 0.08330793949426152, 0.04251535458024591, 0.09193353602313437, 0.03890294334269129, 0.016733444863348268, 0.08459871984086931, 0.0380168004630832, 0.02153646135411691, 0.08779857860645279, 0.08297557607875206, 0.08408765468630008, 0.03947555109334644, 0.09637934199417941, 0.048693867574911565, 0.3594723780406639, 0.356528100091964, 11.628839001059532, 63.514880016446114, 37.394690215587616, 82.60838806629181, 28.180230259895325, 39.15277987718582, 76.12178653478622, 64.5772460103035, 69.14987504482269, 58.57258781790733, 65.90483397245407, 40.7973126322031, 4.105202816426754, 0.2302513166796416, 2.827063025906682, 34.21515382826328, 86.67091727256775, 76.74717217683792, 71.47506147623062, 70.85486635565758, 76.44758865237236, 72.77428776025772, 69.79141741991043, 66.09347864985466, 55.86921148002148, 49.85049404203892, 52.17197947204113, 52.620268017053604, 59.28585134446621, 62.08617188036442, 63.16633991897106, 61.38629123568535, 59.938530921936035, 52.379664927721024, 48.703210204839706, 49.31959792971611, 47.28011056780815, 48.01407538354397, 46.54701590538025, 45.96292644739151, 47.353123649954796, 45.59500738978386, 45.2858217805624, 45.56522458791733, 43.822847083210945, 44.159569814801216, 43.68124768137932, 44.8261034488678, 44.73716162145138, 44.997063875198364, 43.714670687913895, 43.7372262775898, 43.33007052540779, 45.17042577266693, 45.23884490132332, 44.135026931762695, 45.94097502529621, 46.93880148231983, 57.22598947584629, 61.687147691845894, 59.38740089535713, 62.264834493398666, 58.024634420871735, 59.427895322442055, 59.40313585102558, 54.31284159421921, 58.90068881213665, 58.142466098070145, 58.948919624090195, 55.839204490184784, 52.82904401421547, 51.63107089698315, 53.93214762210846, 52.34694488346577, 52.921523451805115, 52.91448622941971, 48.90655629336834, 44.673325046896935, 43.77014011144638, 43.42156581580639, 42.63350710272789, 43.53636525571346, 42.445295602083206, 41.49887278676033, 43.16716946661472, 41.78949639201164, 43.11633579432964, 41.24211296439171, 41.80279187858105, 43.116130605340004, 40.859108716249466, 41.28537364304066, 41.860723569989204, 42.13914982974529, 44.08330790698528, 44.07422259449959, 47.53454491496086, 55.594547018408775, 58.59068624675274, 61.317617520689964, 59.27044317126274, 61.922210678458214, 61.52857460081577, 58.288921639323235, 58.51923868060112, 58.58798459172249, 60.06449796259403, 56.74199804663658, 54.93943937122822, 49.119405671954155, 46.18231147527695, 45.427007004618645, 53.264299258589745, 59.4895926117897, 60.779729783535004, 56.41380585730076, 52.02767461538315, 54.16606307029724, 62.21352964639664, 63.689153864979744, 68.56166660785675, 57.350976169109344, 48.963602632284164, 4.226896986365318, 1.0823184857144952, 44.287930727005005, 55.29928386211395, 59.56332005560398, 50.487826243042946, 66.4864231646061, 41.727122738957405, 10.2087820507586, 32.53275990486145, 23.46567314118147, 35.25927700102329, 42.61869169771671, 0.4866121307713911, 0.026340366566728335, 0.03549875276803505, 0.029265443299664184, 0.0478447912610136, 0.09852972230874002, 0.04584439528116491, 0.0542048187344335, 0.039772525196895, 0.03404681134270504, 0.08546793804271147, 0.04730762848339509, 0.016178999321709853, 0.05038311814132612, 0.07002311758697033, 0.08069092640653253, 0.021075862241559662, 0.04286642753868364, 0.05153480888111517, 0.027877862776222173, 0.027697068180714268, 0.024643655560794286, 0.03108651413640473, 0.02631519291753648, 0.035759205784415826, 0.020598345872713253, 0.05935108594712801, 0.04979494013241492, 0.07936380308819935, 0.012057902440574253, 0.09430429709027521, 0.026457351304998156, 0.04687832573836204, 0.05013279915146995, 0.024889944688766263, 0.06639015628024936, 0.10789090592879802, 0.07754862119327299, 0.09924878177116625, 0.383173962472938, 14.938908834010363, 72.86586284637451, 39.71913568675518, 85.67638903856277, 38.22627179324627, 53.405438885092735, 84.55404326319695, 71.5614004433155, 78.74735444784164, 65.56877240538597, 72.98646837472916, 45.7791493088007, 5.690086372196674, 0.15403312136186287, 2.3179561318829656, 37.47156009078026, 89.1846951842308, 78.06308716535568, 73.76679450273514, 73.48510801792145, 80.11371552944183, 74.15926024317741, 73.83893743157387, 68.76557886600494, 59.103453531861305, 53.05926986038685, 53.88175472617149, 55.86057834327221, 62.24367342889309, 64.94249001145363, 65.15466302633286, 65.2215014398098, 62.78843119740486, 54.33600515127182, 49.74311180412769, 50.50199568271637, 49.403322637081146, 48.98270420730114, 49.82441604137421, 48.448259085416794, 47.022119611501694, 48.07640723884106, 48.85860286653042, 49.174251928925514, 46.313955411314964, 45.811732560396194, 47.7416680008173, 46.49599604308605, 46.81470774114132, 46.98957435786724, 47.12880648672581, 44.82203386723995, 46.28196492791176, 47.48952493071556, 46.64600059390068, 46.863926500082016, 47.21898704767227, 50.59121489524841, 58.25820408761501, 64.33043405413628, 63.69565911591053, 64.08836424350739, 63.132084757089615, 63.30039672553539, 62.29936324059963, 59.31537576019764, 62.427522763609886, 61.94949321448803, 63.4398378431797, 60.122897028923035, 55.976741909980774, 55.0154010951519, 55.42764477431774, 54.305542185902596, 55.59793263673782, 55.03402389585972, 49.487966895103455, 46.806781366467476, 46.91791780292988, 47.44133971631527, 45.25174900889397, 44.33113440871239, 43.84816512465477, 46.30700558423996, 46.96271739900112, 46.27615883946419, 44.34248439967632, 45.92782013118267, 44.2257546633482, 45.71685165166855, 44.86792400479317, 45.23495391011238, 45.27114316821098, 43.83053407073021, 46.99994400143623, 47.46643736958504, 50.08067429065704, 58.786504939198494, 59.80224743485451, 63.423084542155266, 62.09176518023014, 62.56408363580704, 63.164952993392944, 61.647504419088364, 60.03678224980831, 60.3952170163393, 62.5027397274971, 58.51172648370266, 56.95578597486019, 51.78803287446499, 49.15574312210083, 48.5877799987793, 55.8222422003746, 60.86651712656021, 64.48475137352943, 58.92939247190952, 53.78574147820473, 56.49594984948635, 63.51856201887131, 67.19306364655495, 71.63781434297562, 60.50473853945732, 59.081604704260826, 4.611333757638931, 1.5606402629055083, 50.01214876770973, 63.07858742773533, 61.67813837528229, 59.65999446809292, 67.9958313703537, 52.982802763581276, 11.718985363841057, 35.22314094007015, 29.049564711749554, 40.15698619186878, 48.88506084680557, 0.7804312754888088, 0.1348312821937725, 0.10063041583634913, 0.10155541385756806, 0.055043516113073565, 0.03178406615916174, 0.04014136145997327, 0.08716137061128393, 0.04194422370346729, 0.054176019693841226, 0.08332909812452272, 0.05191710399230942, 0.03781711449846625, 0.004378732983241207, 0.028672513690253254, 0.04399451798235532, 0.04568446245684754, 0.021597332306555472, 0.09725152878672816, 0.1259570216643624, 0.2196454771910794, 0.1150714147661347, 0.08398382822633721, 0.19899150735000148, 0.21485722943907604, 0.105661694688024, 0.15344434592407197, 0.11545497894985601, 0.2340731248841621, 0.23837474640458822, 0.11923839585506357, 0.11387566642952152, 0.20710341894300655, 0.133367455273401, 0.13342598103918135, 0.19328262540511787, 0.20117348089115694, 0.23741952812997624, 0.5133124371059239, 0.5318334745243192, 25.94723828136921, 87.1287851035595, 51.40362270176411, 98.72850626707077, 40.836203545331955, 52.117137014865875, 90.54050803184509, 76.63279831409454, 84.6569949388504, 72.41687893867493, 79.59657847881317, 50.79703465104103, 7.087448090314865, 0.6996530725155026, 3.4460258251056075, 42.99860671162605, 91.35717540979385, 80.60295447707176, 75.47516763210297, 76.84772238135338, 83.4566393494606, 78.33630010485649, 76.01974681019783, 72.23872929811478, 60.541710555553436, 56.528574898839, 58.34364250302315, 57.55895420908928, 66.62601247429848, 67.25783497095108, 68.7880888581276, 67.70698606967926, 65.88156402111053, 57.344596311450005, 54.41654562950134, 54.296863451600075, 52.39239424467087, 51.769763454794884, 52.18084439635277, 50.53307421505451, 50.79385422170162, 50.47932989895344, 50.37342958152294, 51.247185096144676, 48.14855396747589, 50.19844897091389, 49.14507329463959, 48.3515390753746, 49.872821643948555, 48.2108174264431, 48.86652924120426, 47.32561692595482, 49.88959014415741, 49.28896017372608, 50.33946320414543, 49.39881607890129, 50.953278467059135, 51.2895680218935, 62.113910391926765, 67.57140174508095, 64.89136755466461, 67.32519775629044, 63.8724522292614, 65.52795499563217, 65.2967070043087, 60.80716051161289, 65.24468779563904, 63.34495693445206, 65.83225026726723, 63.496101424098015, 57.25709080696106, 56.0280429571867, 59.463731199502945, 55.7851105928421, 58.457476794719696, 58.01608107984066, 54.635402485728264, 48.541232496500015, 48.113117069005966, 50.25750920176506, 47.83711887896061, 47.92998969554901, 47.55480542778969, 47.616012543439865, 49.36226584017277, 46.700447872281075, 47.606957629323006, 48.07993724942207, 46.97168871760368, 47.66564168035984, 47.05990478396416, 47.34488949179649, 48.69793988764286, 45.83075053989887, 49.50803741812706, 48.97757828235626, 53.23835805058479, 60.0875361263752, 64.76294964551926, 67.0745100080967, 63.31106275320053, 64.1343341767788, 67.78999641537666, 62.56381005048752, 63.0085913836956, 63.17190662026405, 67.65487566590309, 60.67469201982021, 60.49491226673126, 52.91583515703678, 51.56510643661022, 50.05636319518089, 59.43802557885647, 64.41909849643707, 67.40146726369858, 59.183587431907654, 57.117243111133575, 58.745155557990074, 69.09284010529518, 69.31221753358841, 76.18101015686989, 65.28897061944008, 63.323355093598366, 7.218655999749899, 1.5736689325422049, 55.153079107403755, 68.08700367808342, 71.19472771883011, 65.13021513819695, 75.81467941403389, 53.965775817632675, 13.780329152941704, 49.97895374894142, 36.67989157140255, 47.64130778610706, 66.54184699058533, 3.034330978989601, 0.2628739317879081, 0.1652151346206665, 0.09018740354804322, 0.12382251588860527, 0.22948021040065214, 0.18820443539880216, 0.159504501207266, 0.13016108045121655, 0.2107856736984104, 0.2655663248151541, 0.12665974645642564, 0.057039551975321956, 0.17573081800946966, 0.19530376070179045, 0.22220530780032277, 0.10692150521208532, 0.15373670757981017], [0.024800055762170814, 0.04555391125904862, 0.035323342453921214, 0.09407988647581078, 0.08178259595297277, 0.02592312372144079, 0.050481192956794985, 0.08084412052994594, 0.030862487583362963, 0.034798362030414864, 0.02086032400256954, 0.017742322270350996, 0.029289980557223316, 0.013071387656964362, 0.05661985262122471, 0.06858464243123308, 0.022519673439092003, 0.0493314800405642, 0.05554201299673878, 0.04988720393157564, 0.20123398076975718, 0.17005013767629862, 0.11367775790859014, 49.79484982788563, 53.19260470569134, 41.0429922491312, 35.1616982370615, 13.546652141958475, 60.04978895187378, 75.18632993102074, 67.42370367050171, 58.19231182336807, 60.64634174108505, 63.749361634254456, 11.901975944638252, 0.19807376753306016, 0.5348856013733894, 4.59637776017189, 66.52214884757996, 75.57892486453056, 73.07801306247711, 72.62221232056618, 73.19212093949318, 75.90937033295631, 70.75656563043594, 61.70268125832081, 52.22062826156616, 47.510932981967926, 50.4353054612875, 54.549694284796715, 57.218576073646545, 60.52464947104454, 62.20437973737717, 62.037257105112076, 61.5431772172451, 58.07478033006191, 49.69566375017166, 48.205915689468384, 47.990189865231514, 47.53005735576153, 47.62062169611454, 46.68221265077591, 45.91337330639362, 45.87847217917442, 47.05254837870598, 45.81001125276089, 45.57218961417675, 46.0575907677412, 45.554030388593674, 44.86719824373722, 42.34692268073559, 43.94336901605129, 45.47657914459705, 44.2158941924572, 44.25167687237263, 44.020162895321846, 47.815600633621216, 44.29683744907379, 44.69328157603741, 47.158509492874146, 51.46320350468159, 57.06863231956959, 59.81301985681057, 59.99617762863636, 61.781964004039764, 61.345162242650986, 62.089496701955795, 58.24938476085663, 59.31761384010315, 61.132290065288544, 59.75552134215832, 55.844349414110184, 55.00684775412083, 54.90009248256683, 56.46794535219669, 55.50020948052406, 53.883985206484795, 56.49900868535042, 51.89231067895889, 46.04928441345692, 45.35704895853996, 44.691522270441055, 42.073595747351646, 42.19025328755379, 41.848366633057594, 42.24736422300339, 42.08437196910381, 43.397216722369194, 42.7783515304327, 42.618581503629684, 42.32641518115997, 42.952568382024765, 42.761666625738144, 43.94564509391785, 43.053927943110466, 43.16422842442989, 43.30787591636181, 41.91789910197258, 43.725982680916786, 47.78932884335518, 56.64875864982605, 57.99653872847557, 58.86301763355732, 60.37919707596302, 59.29356873035431, 61.822371035814285, 62.26266860961914, 60.91771557927132, 59.75595831871033, 57.941874861717224, 52.99109771847725, 48.93407441675663, 45.71001961827278, 53.75171810388565, 61.336217522621155, 65.77883273363113, 63.655772656202316, 63.371323719620705, 57.53605663776398, 57.15556785464287, 58.69401030242443, 66.20572462677956, 62.867204770445824, 55.79459108412266, 45.312169566750526, 1.6378960548900068, 2.297181459143758, 47.48339205980301, 52.515952214598656, 59.774033948779106, 51.3957305252552, 64.44822773337364, 21.434807516634464, 20.73041271418333, 43.487883657217026, 23.851156756281853, 49.306473433971405, 25.615835264325142, 0.4420697927707806, 0.06924451561644673, 0.06235295455553569, 0.08133387120324187, 0.09360770243802108, 0.01381415966534405, 0.0017919265815180552, 0.03447661503741983, 0.07737065418041311, 0.05719988555938471, 0.09176821520668454, 0.08901345951016992, 0.07880577482865192, 0.07913520676083863, 0.04990472232748289, 0.025621307104302105, 0.08071487551205792, 0.05924469907768071, 0.010958704733639024, 0.07368286300334148, 0.03078084391745506, 0.06957995894481428, 0.06062426997232251, 0.0315858385147294, 0.04760155235999264, 0.04610294839949347, 0.024032892142713536, 0.04552197293378413, 0.04448642459465191, 0.021934677388344426, 0.01228451166753075, 0.058981340553145856, 0.037529728942899965, 0.04062470739881974, 0.11737895969417877, 0.10364827772718854, 0.02409320277365623, 0.07497054117266089, 0.11163952352944762, 0.087467306148028, 0.7672849902883172, 58.86232987046242, 56.49055413901806, 44.66723017394543, 43.41253750026226, 21.09539072960615, 73.47487136721611, 79.43679705262184, 75.18262133002281, 65.741495937109, 68.00846189260483, 68.43252673745155, 13.800588715821505, 0.20212153001921251, 0.3481344098690897, 6.826796801760793, 69.55421134829521, 78.17431479692459, 75.0333121418953, 73.31311404705048, 75.7217364013195, 79.72867459058762, 71.17164015769958, 65.64748138189316, 56.97674944996834, 50.25224648416042, 52.97655209898949, 55.795506834983826, 59.013474360108376, 63.262231573462486, 64.89154234528542, 64.67992410063744, 64.80619132518768, 60.46295218169689, 51.68279372155666, 50.48254072666168, 49.85891819000244, 48.8021606951952, 49.41872701048851, 48.17287266254425, 48.364925757050514, 48.802004903554916, 48.779175728559494, 47.76168532669544, 48.879900723695755, 47.054877653717995, 47.215749621391296, 47.085371017456055, 44.534157514572144, 47.57851995527744, 47.19122193753719, 48.16504508256912, 45.44503703713417, 46.65884010493755, 48.844501823186874, 46.53356842696667, 47.44513191282749, 49.946328699588776, 56.926478147506714, 59.95600998401642, 64.87983137369156, 64.71997395157814, 63.78384858369827, 62.808748707175255, 63.70795525610447, 64.55560237169266, 63.88792499899864, 65.01482293009758, 63.195035979151726, 59.42821830511093, 56.704972833395004, 57.83939816057682, 60.508789122104645, 55.91038227081299, 57.315733060240746, 57.81068690121174, 50.658471286296844, 46.87808834016323, 48.14115956425667, 47.46722012758255, 44.884574711322784, 44.92510713636875, 43.66572551429272, 45.34220315515995, 44.02061127126217, 46.10313132405281, 45.334462970495224, 47.14866802096367, 45.07663160562515, 45.11409379541874, 44.69444431364536, 47.08421587944031, 45.14942429959774, 45.43680667877197, 45.44816046953201, 46.24153129756451, 44.98707041144371, 51.42108656466007, 58.29620964825153, 61.01351983845234, 60.444792956113815, 63.89282673597336, 61.461869180202484, 64.80299949645996, 64.01093199849129, 62.16510884463787, 61.99833579361439, 60.35633750259876, 54.6715347468853, 52.36571587622166, 48.48032936453819, 57.270378693938255, 64.51110675930977, 68.72109085321426, 66.7924739420414, 66.65710240602493, 62.01134629547596, 59.07922223210335, 63.51395666599274, 69.90440055727959, 68.12259256839752, 60.418167784810066, 56.67302794754505, 1.63829859578982, 2.83751436509192, 53.81042495369911, 61.58721685409546, 64.55873340368271, 58.054827600717545, 68.95528748631477, 34.403133541345596, 16.791886053979397, 45.43207213282585, 27.91142698377371, 55.164999067783356, 29.446519911289215, 0.4240936995483935, 0.15124427882255986, 0.03829244524240494, 0.024509671929990873, 0.025347085393150337, 0.024440681881969795, 0.1278559400816448, 0.063728695968166, 0.08278670691652223, 0.07245207787491381, 0.09779576052096672, 0.06826540018664673, 0.07209106013760902, 0.08806883910438046, 0.018053888852591626, 0.031102826542337425, 0.03627981866884511, 0.027852742932736874, 0.10162409220356494, 0.1790335532859899, 0.14376203500432894, 0.13433879299554974, 0.18712559016421437, 0.1545463313232176, 0.1510112444520928, 0.2644183114171028, 0.1405133874504827, 0.08351737356861122, 0.13982268545078114, 0.15524055110290647, 0.06768083272618242, 0.14093574369326234, 0.21056320751085877, 0.19899073551641777, 0.183036801754497, 0.28914964059367776, 0.12252029162482359, 0.16941374604357406, 0.26037779229227453, 0.24648539634654298, 2.3152798879891634, 74.91037353873253, 71.01881235837936, 56.16425804793835, 48.70291382074356, 21.741147078573704, 72.2930283844471, 90.40946826338768, 79.95423808693886, 73.985176384449, 74.55938637256622, 77.49288216233253, 15.892537012696266, 0.6501397106330842, 0.8931706321891397, 9.26215784624219, 75.38667038083076, 80.60379043221474, 76.69291108846664, 77.54503056406975, 79.88544657826424, 86.55224204063416, 78.6117473244667, 69.27757859230042, 59.18334424495697, 52.567728236317635, 57.81121887266636, 59.64206703007221, 63.03543694317341, 65.36422178149223, 66.57300531864166, 66.17147326469421, 68.07333961129189, 64.72644120454788, 55.54952323436737, 52.56520137190819, 51.76358878612518, 52.02380262315273, 52.69929997622967, 51.589292138814926, 50.56039094924927, 50.87018072605133, 51.424175798892975, 50.37179186940193, 50.12610085308552, 49.94888976216316, 49.02888312935829, 48.77733662724495, 46.81042157113552, 49.83793191611767, 49.71411935985088, 49.399686232209206, 47.588828802108765, 49.03667651116848, 52.605992183089256, 49.53550234436989, 51.20357483625412, 53.01689833402634, 58.593110516667366, 61.16102792322636, 65.3031438589096, 64.6182382106781, 65.97799524664879, 64.93524000048637, 67.45982453227043, 67.0181742310524, 64.06874969601631, 66.00989833474159, 65.90953812003136, 62.08633527159691, 60.63105136156082, 58.84819082915783, 62.54069969058037, 58.89403536915779, 59.698683992028236, 59.997572153806686, 54.514055997133255, 50.02516306936741, 50.652186423540115, 50.14875143766403, 46.74104109406471, 48.38216543197632, 46.58480867743492, 47.52440705895424, 46.43590986728668, 49.689226895570755, 46.872878819704056, 48.36247868835926, 48.46559375524521, 48.01819056272507, 47.49446466565132, 51.09623059630394, 48.74534234404564, 49.01402972638607, 47.91371136903763, 48.37252534925938, 47.93286234140396, 52.80942186713219, 60.37184827029705, 62.30664744973183, 63.588558062911034, 65.86714759469032, 64.8464235663414, 66.7098055779934, 66.58981561660767, 63.33251640200615, 63.383175283670425, 63.329818546772, 58.020314052700996, 54.14925657212734, 51.317036747932434, 59.6173607558012, 67.56845310330391, 70.11012151837349, 70.51438182592392, 68.31659495830536, 64.03731018304825, 61.911176070570946, 66.23926162719727, 72.21363544464111, 71.94065049290657, 62.80594825744629, 59.586741998791695, 2.866878001950681, 3.3214803831651807, 61.311005875468254, 64.92939591407776, 72.2235681116581, 60.912680849432945, 77.70879417657852, 30.39564248174429, 29.488469660282135, 64.6839214861393, 34.6568763256073, 66.87348559498787, 43.80486264824867, 0.5086449219379574, 0.2535446605179459, 0.14472981041762978, 0.10830591490957886, 0.23205828299978748, 0.059727781554101966, 0.20867959217866883, 0.23421962483553216, 0.17934739269549027, 0.0944372676895, 0.1804794350755401, 0.22836915595689788, 0.14981804910348728, 0.11616042000241578, 0.10898152162553743, 0.1238971165730618, 0.1790021752822213, 0.2050457551376894], [0.010598572007438634, 0.025424923696846236, 0.036399779419298284, 0.03399823406653013, 0.05058489325165283, 0.05552987517148722, 0.05994819941406604, 0.07163923321058974, 0.04955319294822402, 0.03747485825442709, 0.02349878144741524, 0.015989182065823115, 0.07919027411844581, 0.024791276155156083, 0.10687895788578317, 0.02391936766798608, 0.021476714755408466, 0.021701550249417778, 0.06794658096623607, 0.01746192774589872, 0.10639210900990292, 0.10887303447816521, 0.3021085780346766, 17.06056773662567, 67.44534730911255, 29.12762012332678, 46.768346428871155, 17.07618299871683, 21.442673094570637, 76.56602829694748, 54.160731956362724, 59.11095812916756, 62.279281318187714, 67.53624603152275, 27.729323655366898, 0.09149752426310442, 0.2554754912853241, 0.24090489110676572, 37.00059816241264, 82.87910833954811, 71.01685166358948, 76.72052040696144, 69.34300348162651, 70.91890811920166, 65.66993817687035, 60.15276342630386, 52.21367083489895, 52.33510471880436, 51.16920568048954, 52.17566907405853, 54.547817185521126, 59.8099572211504, 60.24857148528099, 62.47105322778225, 59.79942798614502, 61.33192755281925, 55.164809077978134, 49.31712806224823, 46.85042582452297, 49.81376141309738, 49.555489271879196, 50.8701541274786, 45.843787640333176, 47.00134992599487, 46.1304784566164, 45.68041540682316, 47.2994439303875, 46.252033933997154, 46.05692580342293, 44.467288702726364, 45.664163678884506, 43.87513227760792, 44.92646746337414, 43.75863432884216, 44.18868385255337, 44.62984398007393, 45.53196117281914, 46.553125977516174, 46.841158121824265, 46.99083589017391, 49.579781368374825, 52.68148273229599, 55.713245049118996, 59.099106565117836, 60.631370544433594, 59.12723645567894, 59.23494167625904, 60.37933386862278, 58.99000681936741, 61.09105467796326, 57.344657108187675, 56.155355125665665, 58.441791236400604, 59.43258047103882, 56.00302889943123, 57.43830308318138, 56.85227192938328, 59.017057567834854, 53.2534546405077, 46.68313980102539, 44.969667345285416, 45.18576554954052, 44.35090854763985, 42.2627267986536, 43.0750548094511, 43.18059414625168, 42.63422906398773, 41.31633438169956, 42.89433270692825, 43.193000480532646, 41.785312816500664, 41.62255235016346, 42.24141374230385, 44.770774617791176, 41.66099488735199, 42.24175952374935, 41.20639868080616, 42.81631909310818, 44.80507917702198, 44.234532192349434, 44.8881009221077, 50.15466772019863, 52.00193099677563, 54.3344434350729, 54.6400610357523, 61.6507912427187, 62.77797035872936, 63.09329263865948, 61.066553592681885, 59.44721728563309, 51.581787541508675, 48.11250910162926, 47.25481152534485, 55.83420395851135, 62.86499708890915, 63.39362092316151, 65.90744823217392, 67.28356719017029, 61.93511098623276, 62.491587325930595, 61.25497408211231, 67.80171498656273, 61.33679509162903, 52.48010493814945, 38.23829434812069, 0.5451298516709358, 5.346901137381792, 38.026706501841545, 58.01427237689495, 51.93864159286022, 56.25951513648033, 47.246687561273575, 6.828582705929875, 37.964047864079475, 33.1161729991436, 28.88784918934107, 53.71287278831005, 10.34888718277216, 0.4877303395187482, 0.14536670671077445, 0.04284958449716214, 0.0840735761448741, 0.08018064050702378, 0.029630027056555264, 0.11314338189549744, 0.02663469120307127, 0.06492338303360157, 0.036746384648722596, 0.030062812329560984, 0.027107955065730494, 0.010401078161521582, 0.06195425055921078, 0.0402964332170086, 0.004349770670160069, 0.009270415248465724, 0.0334831872896757, 0.0545322171819862, 0.02490203798515722, 0.015924477920634672, 0.07144372182665393, 0.01746556612488348, 0.03723731904756278, 0.0387270135252038, 0.04007260147773195, 0.046028154756641015, 0.06901975619257428, 0.022425162787840236, 0.03489039205305744, 0.010578181500022765, 0.05230225266132038, 0.07369719387497753, 0.03819393627054524, 0.043867521671927534, 0.0258127273991704, 0.06053716781025287, 0.07014288537902758, 0.06506190489744768, 0.09117906127357855, 0.2230218780459836, 18.605690225958824, 76.18459716439247, 31.579584851861, 54.41851772367954, 21.926561929285526, 35.1239662617445, 87.87083208560944, 62.856580540537834, 68.71141657233238, 71.19457572698593, 76.04121565818787, 30.509518571197987, 0.09401084447745234, 1.2101929052732885, 0.00783692918048473, 42.91058823466301, 85.16150906682014, 73.18209707736969, 81.75216481089592, 74.48738023638725, 75.4992963373661, 70.5499479174614, 63.19800361990929, 55.24982951581478, 54.240379482507706, 52.17817313969135, 56.14028513431549, 55.06878063082695, 62.49260567128658, 61.14482179284096, 66.27404496073723, 61.90737247467041, 65.18091961741447, 57.16389700770378, 50.99711671471596, 48.10691960155964, 50.97381256520748, 51.09517425298691, 51.95761017501354, 48.73032175004482, 48.3887504786253, 47.72730477154255, 48.539233803749084, 48.60417991876602, 47.408570274710655, 46.81592747569084, 45.820069313049316, 47.152395620942116, 45.68138435482979, 47.60509192943573, 46.42778590321541, 46.33714556694031, 48.25579181313515, 47.37141586840153, 49.29910562932491, 48.15291993319988, 49.954817444086075, 52.79739931225777, 57.16716103255749, 60.82372382283211, 62.84727863967419, 63.66240710020065, 64.32409599423409, 63.004537001252174, 63.88391241431236, 63.30570124089718, 63.91450837254524, 61.86905153095722, 57.21000373363495, 63.51684831082821, 61.18799887597561, 59.58304479718208, 61.5693312138319, 60.42243495583534, 59.06296290457249, 53.84547047317028, 49.33149129152298, 47.88586266338825, 47.65895403921604, 45.516480803489685, 44.67325285077095, 46.68479651212692, 45.95163345336914, 46.093187257647514, 46.93615302443504, 46.054778918623924, 45.457002595067024, 44.308278635144234, 44.611996337771416, 44.62266996502876, 46.47454999387264, 45.24284228682518, 46.23094126582146, 44.76619206368923, 45.47412447631359, 45.878928154706955, 46.876925602555275, 47.7017967402935, 53.133776262402534, 54.433268532156944, 56.6632928699255, 57.65680655837059, 62.76348173618317, 64.35913771390915, 63.02623003721237, 64.80155557394028, 61.83232270181179, 55.388449877500534, 50.44205769896507, 50.3059946000576, 58.87284390628338, 65.54372414946556, 65.53027287125587, 67.45605513453484, 70.3496378660202, 65.19291937351227, 67.34304919838905, 63.261707201600075, 74.46172401309013, 64.03333559632301, 60.60538753867149, 42.65652246773243, 0.29872723447624594, 5.653065433725715, 45.5655437707901, 64.58474680781364, 60.08603900671005, 62.19528302550316, 63.36004972457886, 13.691911697387695, 33.664893954992294, 40.798456370830536, 28.510803021490574, 65.53640574216843, 9.666736386716366, 0.33996918238699436, 0.08736515694181435, 0.07130329264327884, 0.018873579829232767, 0.022925448247406166, 0.05169025171198882, 0.08700435442733578, 0.028164185205241665, 0.031339823981397785, 0.0628531546681188, 0.13729479687754065, 0.019213262676203158, 0.018890344945248216, 0.006916538504810887, 0.056885040539782494, 0.054223988408921286, 0.009492899062024662, 0.021538737892115023, 0.17098485783208162, 0.1367510252748616, 0.15689356630900875, 0.16879978211363778, 0.1195014946279116, 0.08936835452914238, 0.09725613752380013, 0.19969166431110352, 0.11883650062372908, 0.14057336782570928, 0.17611357325222343, 0.16887741076061502, 0.15187253651674837, 0.16862377437064424, 0.298127401038073, 0.11376284513971768, 0.14139973442070186, 0.04790379942278378, 0.0909370617591776, 0.1820055875577964, 0.17545286886161193, 0.23010990786133334, 0.39407020434737206, 31.70116502791643, 90.00957012176514, 41.834337785840034, 68.00503447651863, 26.066283993422985, 31.331862844526768, 89.35423448681831, 69.67429250478745, 76.07736691832542, 77.9435683786869, 83.33462789654732, 32.548825442790985, 0.2637481817509979, 1.1489998013712466, 0.3698471572715789, 48.88680875301361, 85.61258286237717, 76.82219535112381, 84.84379291534424, 79.57556560635567, 77.66232267022133, 75.33329084515572, 66.10252976417542, 58.530596271157265, 58.51761996746063, 55.27081958949566, 59.64379593729973, 61.488676741719246, 66.81181490421295, 64.64065700769424, 70.17939940094948, 62.7778297662735, 66.52402594685555, 61.80358104407787, 54.78931702673435, 50.506494641304016, 55.00390291213989, 55.24591572582722, 54.81451727449894, 50.13806261122227, 50.630208402872086, 49.70617398619652, 49.887792840600014, 52.025827914476395, 50.8137309551239, 49.92485985159874, 48.877894431352615, 48.93973611295223, 47.1233993768692, 49.14330258965492, 48.613333627581596, 48.381245881319046, 49.44597154855728, 50.16257129609585, 51.9268774241209, 51.94934941828251, 53.05160567164421, 55.01875251531601, 58.10457073152065, 60.80872222781181, 63.787769973278046, 66.28789901733398, 62.91610814630985, 63.45845304429531, 67.95380562543869, 64.59895044565201, 65.4708744585514, 63.061503544449806, 61.03805512189865, 65.46541795134544, 65.57224541902542, 62.13185302913189, 63.32075223326683, 60.848718881607056, 62.39747017621994, 55.57748593389988, 52.63547100126743, 50.397280901670456, 49.82824243605137, 48.08968372642994, 47.04474359750748, 47.98298165202141, 49.07254658639431, 48.14008042216301, 48.577573746442795, 49.462979435920715, 49.70514424145222, 46.49753876030445, 47.048832178115845, 48.876317515969276, 50.314289554953575, 47.57571950554848, 48.392367884516716, 46.92448005080223, 46.7452322691679, 49.01280999183655, 48.48423555493355, 49.46737200021744, 54.68261115252972, 57.80099742114544, 59.38018888235092, 60.22504694759846, 66.34276807308197, 67.70214512944221, 65.47544181346893, 65.93409240245819, 62.456454411149025, 59.29369032382965, 52.85159960389137, 54.024851247668266, 59.77083832025528, 70.03221049904823, 68.15714031457901, 71.17903456091881, 71.90489441156387, 68.3292406797409, 68.97367849946022, 67.74717271327972, 74.41276744008064, 70.3841096162796, 64.31831270456314, 46.791319996118546, 1.0137662454508245, 6.606294633820653, 51.00396774709225, 69.04443070292473, 63.530873358249664, 66.43837854266167, 59.69711847603321, 9.862169399857521, 53.28684724867344, 53.135945945978165, 39.33290921151638, 75.09087905287743, 19.17319167405367, 0.6389974616467953, 0.33356940548401326, 0.15041369682876393, 0.09650172214605846, 0.1752230108832009, 0.1413888842216693, 0.1794243830954656, 0.10457956173922867, 0.18457635742379352, 0.18669940443942323, 0.1768791876384057, 0.08987665889435448, 0.09377116046380252, 0.11972992026130669, 0.20508587564108893, 0.18311980355065316, 0.12765076593495905, 0.10942114022327587], [0.015184893436526181, 0.01839168293372495, 0.07177904641139321, 0.030932184527046047, 0.0370777424541302, 0.02021618991420837, 0.027202838646189775, 0.023411985421262216, 0.01896819994726684, 0.041522201427142136, 0.055264572220039554, 0.026958820490108337, 0.014317451750684995, 0.07124706011381932, 0.07012420552200638, 0.07093432650435716, 0.13092535897158086, 0.07771796445013024, 0.017382269325025845, 0.03857214956951793, 0.02764233107882319, 0.1069472948438488, 0.23785993340425193, 0.4315543913980946, 52.76677295565605, 47.051807418465614, 37.24847786128521, 48.01905691623688, 11.335892770439386, 46.291643008589745, 67.01650992035866, 74.76690843701363, 66.18220388889313, 64.124735891819, 40.950699001550674, 0.8590483444277197, 0.13956940529169515, 0.12303235867875628, 7.781094694510102, 76.68914169073105, 71.39411821961403, 71.7845168709755, 66.2428106367588, 69.799624979496, 56.395186856389046, 57.402915582060814, 51.338175013661385, 52.44032487273216, 51.47268019616604, 52.11222767829895, 50.899142771959305, 55.14344282448292, 58.37393447756767, 63.167620450258255, 60.91165490448475, 61.438724622130394, 55.00569261610508, 49.60230275988579, 48.62414784729481, 48.342681750655174, 50.56704059243202, 50.96265636384487, 50.606866255402565, 49.26707334816456, 45.91213457286358, 47.022883370518684, 46.22869938611984, 48.367585614323616, 46.94478236138821, 45.02071000635624, 43.73822942376137, 45.064388662576675, 44.51029859483242, 46.06345385313034, 44.49709050357342, 43.462843000888824, 45.609959587454796, 46.15384340286255, 51.078268960118294, 50.13827919960022, 49.24641005694866, 50.983479246497154, 51.483198031783104, 54.82961006462574, 57.60774739086628, 60.42470723390579, 56.9784289598465, 61.38058394193649, 60.28234027326107, 62.329070046544075, 56.50608770549297, 57.59049251675606, 60.08340574800968, 61.079203113913536, 62.85272754728794, 59.69389244914055, 62.519310638308525, 60.76847858726978, 59.31872338056564, 50.56954465806484, 43.77233259379864, 45.40855899453163, 44.60628904402256, 43.956440314650536, 42.28039965033531, 43.023134395480156, 42.263946533203125, 41.120755076408386, 43.039701506495476, 42.28148639202118, 41.91144324839115, 42.21726983785629, 40.83581976592541, 42.36694760620594, 43.07753227651119, 41.700075790286064, 42.36740358173847, 42.68610008060932, 45.307674407958984, 45.08398041129112, 43.74131105840206, 45.385520830750465, 43.80722992122173, 44.68285113573074, 53.24310399591923, 62.013143599033356, 63.89854922890663, 64.13201630115509, 59.64362874627113, 59.56140115857124, 53.39052088558674, 48.00542704761028, 49.391197487711906, 56.20429649949074, 64.03959766030312, 70.87055191397667, 66.11429393291473, 66.83536604046822, 67.30936020612717, 62.39731438457966, 66.91751003265381, 65.49328565597534, 50.12122571468353, 49.5830187946558, 22.49623116105795, 0.19159627292538062, 8.524392284452915, 41.63432031869888, 57.55212977528572, 37.34441891312599, 52.968344539403915, 10.723574627190828, 14.403736051172018, 47.41507172584534, 23.455009013414383, 32.53660909831524, 48.896536231040955, 1.0827196016907692, 0.13564850552938879, 0.0320049961010227, 0.014430494757107226, 0.013937497187725967, 0.08538423120626248, 0.06513797503430396, 0.0467502124956809, 0.030844199209241197, 0.14161785162286833, 0.02264061382447835, 0.02563053942139959, 0.01640467900870135, 0.05659009621012956, 0.049435269393143244, 0.08177497409633361, 0.0302717120575835, 0.010294177354808198, 0.032160190312424675, 0.02156777813070221, 0.02799232792312978, 0.06013788493874017, 0.027137635406688787, 0.03486456902464852, 0.01807786764402408, 0.0690236227819696, 0.039634968125028536, 0.06848337638075463, 0.034250156095367856, 0.02108863089233637, 0.03268953827500809, 0.02905094406742137, 0.04803122617886402, 0.048839632800081745, 0.06465389436925761, 0.02910323022661032, 0.041193122015101835, 0.004002067062174319, 0.017068324159481563, 0.07453043275745586, 0.12649188749492168, 0.1275795346009545, 0.636143161682412, 63.328712806105614, 47.93101564049721, 42.01790973544121, 43.334086909890175, 15.434374697506428, 62.000399082899094, 70.8112370967865, 79.35842245817184, 72.76136845350266, 74.54626187682152, 46.51707351207733, 1.0463145864196122, 1.43519640667364, 0.23221465351525694, 12.904028724879026, 82.83996284008026, 75.84544256329536, 76.6935646533966, 69.86956402659416, 72.78143897652626, 61.02782607078552, 63.40338259935379, 53.65347437560558, 55.00555582344532, 54.489402920007706, 55.81925556063652, 53.955691158771515, 56.613690331578255, 59.60582457482815, 63.648534044623375, 61.96019724011421, 63.24396215379238, 55.8757509291172, 52.06239715218544, 50.10281190276146, 51.60915747284889, 51.02343790233135, 53.31929750740528, 51.8498707562685, 50.97139209508896, 47.95641727745533, 48.94123323261738, 48.43052163720131, 51.69030971825123, 47.78931364417076, 47.22207248210907, 45.84521636366844, 46.65948607027531, 47.31718897819519, 46.98848381638527, 47.83551536500454, 47.9105993360281, 48.31649735569954, 49.24448736011982, 50.649511367082596, 52.262692004442215, 53.34186069667339, 52.919346168637276, 55.519634038209915, 58.19244481623173, 62.08016060292721, 63.3283556252718, 60.66613107919693, 64.12254720926285, 65.62697008252144, 64.93818864226341, 59.848251566290855, 61.30593694746494, 62.46694564819336, 64.55499440431595, 63.83842885494232, 63.05432192981243, 63.61547201871872, 61.93158097565174, 61.55663229525089, 52.036292552948, 46.72457277774811, 47.24609099328518, 49.02032978832722, 45.601512640714645, 45.24782381951809, 46.00776024162769, 46.143754944205284, 44.89681765437126, 45.62553495168686, 44.479569643735886, 44.17635731399059, 45.50494462251663, 44.827600568532944, 45.01497991383076, 45.906043499708176, 45.57929903268814, 45.91527700424194, 46.1863848567009, 46.32492542266846, 46.719655841588974, 46.653277203440666, 47.49702952802181, 47.29914754629135, 48.27112399041653, 55.37254773080349, 64.14904698729515, 65.9197823703289, 65.8814500272274, 61.87279812991619, 64.25887629389763, 57.08226978778839, 51.24590836465359, 51.11030884087086, 59.62402179837227, 65.76731935143471, 70.6891268491745, 67.12041154503822, 71.36849999427795, 70.24148806929588, 66.13479763269424, 70.75362458825111, 70.21710097789764, 56.892196387052536, 59.14443053305149, 21.775510534644127, 0.10586171832983382, 9.17575903236866, 50.7208601385355, 61.680030673742294, 46.36273339390755, 57.769033536314964, 23.51626742631197, 12.575076576322317, 47.73941472172737, 31.248584613204002, 37.22390078008175, 58.46143998205662, 1.1024456494487822, 0.03925611286831554, 0.09193932477501221, 0.03656368644442409, 0.00848817211590358, 0.03573854439309798, 0.03262111225922126, 0.01893892593216151, 0.02369898691540584, 0.07731992096523754, 0.010063261815957958, 0.059617565202643164, 0.02803601815685397, 0.07407317330944352, 0.10299584086169489, 0.03942848037695512, 0.07266455475473776, 0.016155660632648505, 0.01102849630115088, 0.09734460152685642, 0.11945647594984621, 0.17816574516473338, 0.10047778574516997, 0.11427817764342763, 0.12924532959004864, 0.13922003185143694, 0.12435997181455605, 0.19272058212663978, 0.10557650355622172, 0.1363380200928077, 0.1634354644920677, 0.22933158790692687, 0.3081860550446436, 0.1647327237878926, 0.11371493208571337, 0.2430696171359159, 0.1681934474618174, 0.10150104411877692, 0.13065646402537823, 0.15851829084567726, 0.3059522499097511, 0.5760765785817057, 3.3459285087883472, 79.91437062621117, 61.56444847583771, 59.95220258831978, 67.28773936629295, 16.732177957892418, 57.78474189341068, 83.6955401301384, 86.41364827752113, 80.66809818148613, 81.90498501062393, 51.514394357800484, 1.3702705968171358, 1.7868320317938924, 0.18154631688958034, 15.275588817894459, 88.72824087738991, 81.24019548296928, 80.4359382390976, 73.17235440015793, 79.68926310539246, 63.17063368856907, 67.3769661784172, 58.08069281280041, 58.119785115122795, 57.284236550331116, 58.75497803092003, 58.841465190052986, 61.30473241209984, 63.43065373599529, 68.785520195961, 65.33768400549889, 67.10167095065117, 58.60258720815182, 55.586673840880394, 53.54009225964546, 54.20725665986538, 55.27149595320225, 57.234918996691704, 53.55698615312576, 53.90531346201897, 49.47385065257549, 51.94050349295139, 49.788587763905525, 55.141649320721626, 51.5719498693943, 49.73279535770416, 48.16504508256912, 49.837217554450035, 49.06688489019871, 50.302969962358475, 49.68132331967354, 49.34096418321133, 50.59989742934704, 52.34874218702316, 55.065679997205734, 55.47295734286308, 54.66503329575062, 55.21929815411568, 55.19211821258068, 59.81830157339573, 64.11190778017044, 64.53581303358078, 59.92748871445656, 66.46057695150375, 65.58758899569511, 66.92180380225182, 60.27940683066845, 63.85502636432648, 65.47693133354187, 67.41664364933968, 66.984903216362, 65.92436492443085, 67.78740495443344, 62.718803733587265, 63.03370803594589, 54.23654168844223, 48.18655572831631, 50.38026921451092, 49.36808332800865, 48.939652517437935, 48.010522574186325, 49.46709841489792, 48.01334582269192, 47.274171486496925, 47.958925142884254, 49.22334909439087, 45.88170200586319, 47.25111052393913, 46.398713663220406, 47.8768115490675, 49.53421041369438, 47.549322322010994, 47.106277495622635, 47.52191059291363, 50.74528902769089, 49.30477872490883, 49.36341717839241, 49.04438629746437, 48.4676456451416, 48.72285135090351, 58.25191542506218, 68.62365648150444, 68.1887774169445, 67.66839534044266, 64.90883141756058, 67.09607005119324, 58.8216682523489, 52.80569426715374, 52.662339359521866, 63.28023120760918, 68.73494490981102, 73.32674771547318, 66.89658835530281, 72.97293350100517, 72.76833727955818, 68.07222247123718, 72.94549137353897, 72.06111922860146, 66.06073960661888, 57.13196352124214, 23.115178048610687, 0.19318059494253248, 10.55262940004468, 54.4159072637558, 68.77269208431244, 49.54301454126835, 65.06014689803123, 17.126222513616085, 20.59239462018013, 66.90353438258171, 36.039861515164375, 45.80717280507088, 70.7848209142685, 3.7011830834671855, 0.6686776096466929, 0.18699173640925437, 0.22075706598116085, 0.15146980265853927, 0.17925281339557841, 0.08750117776799016, 0.09441412752494216, 0.12149963818956167, 0.2784335328033194, 0.18756771722109988, 0.11815857840701938, 0.12018530949717388, 0.2099817496491596, 0.2516912209102884, 0.18427998817060143, 0.17809340060921386, 0.09246197485481389, 0.1498385620652698], [0.05253985495073721, 0.02144726076949155, 0.0408145413530292, 0.018403757676423993, 0.04052851763844956, 0.06944216438569129, 0.06065853493055329, 0.019746399302675854, 0.02461494557792321, 0.04756038171763066, 0.04682041224441491, 0.11614925810135901, 0.09681406983872876, 0.010941106556856539, 0.08225081692216918, 0.03394821331312414, 0.029836039830115624, 0.032112934059114195, 0.056252292852150276, 0.016413427074439824, 0.07542957435362041, 0.03975003812229261, 0.10553367421380244, 0.12851631792727858, 23.93669206649065, 69.9075011909008, 34.58577834069729, 64.32747021317482, 26.57966874539852, 25.781280286610126, 86.9196367263794, 75.94226136803627, 69.98332232236862, 64.1268789768219, 49.623437225818634, 3.5960327507928014, 1.9533409969881177, 0.14936269697500393, 1.1591948918066919, 59.60488602519035, 72.46138975024223, 74.63796615600586, 69.23063591122627, 63.31893213093281, 64.09673899412155, 63.64571839570999, 64.22619804739952, 62.48774193227291, 57.76529833674431, 53.29244814813137, 50.17737150192261, 53.22760462760925, 54.751991629600525, 59.07044470310211, 58.218948394060135, 60.07612533867359, 55.69002069532871, 50.86928777396679, 47.37977162003517, 50.276618376374245, 49.15418140590191, 53.604836985468864, 54.73257467150688, 54.956929832696915, 50.27654618024826, 47.64532037079334, 45.572151616215706, 47.23593033850193, 44.80765163898468, 43.80301594734192, 46.50209851562977, 45.70453271269798, 43.95430102944374, 46.108185052871704, 44.06212404370308, 46.44248731434345, 45.67562386393547, 49.60765667259693, 53.012239784002304, 52.58060574531555, 53.45884121954441, 52.541266456246376, 52.240611389279366, 53.760681822896004, 54.42648209631443, 59.19678412377834, 58.88387091457844, 61.3858238607645, 63.362713381648064, 60.304527282714844, 59.83411632478237, 48.31525482237339, 58.743723034858704, 63.68779733777046, 60.21311558783054, 58.01700823009014, 61.898629143834114, 60.255984887480736, 58.724644258618355, 53.84940326213837, 46.0123959928751, 45.80371119081974, 44.855692461133, 44.58836920559406, 42.191598415374756, 43.46637301146984, 43.07500161230564, 43.01028348505497, 42.05835856497288, 42.61077292263508, 41.45930930972099, 40.17528980970383, 41.59602977335453, 42.5262388586998, 42.748325541615486, 41.203822419047356, 43.44428099691868, 44.39877077937126, 45.52932791411877, 43.62627223134041, 44.51847195625305, 47.90803827345371, 46.378012374043465, 49.176611602306366, 55.68311646580696, 63.92536818981171, 67.43394792079926, 61.869431510567665, 63.079510778188705, 58.05231213569641, 52.757661044597626, 49.00305591523647, 48.19383233785629, 54.92270886898041, 61.421591341495514, 67.18063071370125, 71.67012020945549, 69.66000527143478, 63.603840842843056, 68.36983770132065, 64.18917283415794, 55.85833266377449, 38.91965478658676, 39.996642395853996, 5.4285673052072525, 0.1781121175736189, 12.593974862247705, 49.50548015534878, 59.01967942714691, 66.34513914585114, 47.73872695863247, 6.818093368783593, 42.55563408136368, 38.23119252920151, 23.212958201766014, 48.69842246174812, 26.204695366322994, 0.33997111197095364, 0.05679110319761094, 0.04961771526723169, 0.043918017399846576, 0.027635505175567232, 0.05472858945722692, 0.07289430141099729, 0.04692832793807611, 0.061141019978094846, 0.060479302555904724, 0.03536796779371798, 0.02711438948608702, 0.04067597496032249, 0.05048161598097067, 0.05889711421332322, 0.033055780731956474, 0.06268390046898276, 0.06485813340987079, 0.034868880902649835, 0.04471340304007754, 0.09791376942303032, 0.014506103834719397, 0.03874388254189398, 0.02067632147372933, 0.04105344240088016, 0.03127660042082425, 0.04365165688795969, 0.02352506275201449, 0.005368928677853546, 0.028735536870954093, 0.10162942082388327, 0.03990466830146033, 0.11734800471458584, 0.05355548404622823, 0.03205100183549803, 0.0018402460773359053, 0.055176969108288176, 0.04467711944016628, 0.04186475453025196, 0.032747128934715874, 0.0743475898343604, 0.03189827155438252, 0.13555606361478567, 27.846150286495686, 76.20808750391006, 34.485874101519585, 69.12421122193336, 25.845576636493206, 43.95527757704258, 90.23929819464684, 82.44318813085556, 75.43762564659119, 72.00175881385803, 57.53077872097492, 4.5554164331406355, 2.2668514866381884, 0.8918120863381773, 1.765936715528369, 69.01280120015144, 74.9414710700512, 78.05130779743195, 71.98228865861893, 67.24898904561996, 67.002914249897, 66.6456650197506, 67.22757339477539, 66.29460945725441, 60.94336800277233, 55.1881930232048, 53.3551561832428, 54.67064179480076, 57.48110018670559, 60.86464382708073, 61.19425714015961, 62.578462064266205, 59.68420296907425, 52.605426013469696, 48.74721944332123, 51.089846938848495, 51.9691501557827, 56.24360918998718, 57.03970067203045, 54.925228133797646, 50.40684498846531, 50.5534753203392, 48.01683023571968, 49.1847887635231, 47.83502899110317, 47.50457592308521, 46.975017338991165, 46.29504382610321, 47.19672404229641, 48.786775320768356, 45.191773027181625, 49.14203725755215, 46.98586195707321, 52.20506049692631, 54.478881284594536, 56.51970997452736, 55.92395894229412, 56.94184072315693, 56.544644236564636, 57.28812374174595, 58.1375415623188, 62.86438912153244, 62.79757350683212, 66.66848659515381, 66.49441033601761, 65.97269833087921, 63.10678951442242, 52.08358861505985, 63.97335201501846, 66.54450684785843, 64.08463284373283, 62.684141993522644, 63.43155048787594, 62.500300258398056, 61.57042935490608, 57.040236443281174, 48.55196312069893, 48.702917620539665, 47.74600736796856, 46.63874298334122, 44.19045455753803, 47.01497979462147, 46.74438491463661, 46.32538519799709, 47.02076308429241, 45.18690928816795, 44.75821629166603, 43.48653092980385, 45.0717830657959, 46.56543731689453, 47.55596436560154, 46.11312098801136, 46.14396013319492, 46.13194137811661, 46.319719702005386, 46.94010101258755, 48.57896067202091, 50.909793600440025, 47.875728607177734, 51.31207801401615, 58.3899050205946, 66.59068956971169, 67.5944285094738, 63.67596477270126, 64.95554611086845, 60.69405198097229, 55.61016798019409, 51.96388743817806, 51.19733177125454, 56.93429812788963, 64.90819305181503, 69.51353833079338, 72.56754085421562, 71.3912683725357, 65.7886666059494, 72.47086644172668, 67.32331305742264, 62.02688746154308, 48.54514628648758, 42.7768088132143, 4.782325532287359, 0.12464080791687593, 15.053534433245659, 54.114161655306816, 67.25946128368378, 67.3773081600666, 58.64940449595451, 13.636492621153593, 25.7698941975832, 48.215331584215164, 25.754138343036175, 59.17010955512524, 28.288087472319603, 0.31152738200034946, 0.018789390596793965, 0.04776437213877216, 0.015644254090148024, 0.026864410028792918, 0.040200043076765724, 0.038445275713456795, 0.040795991371851414, 0.11145150783704594, 0.03497410631098319, 0.04122460763028357, 0.03448627780016977, 0.010984937798639294, 0.02240454592538299, 0.052961469045840204, 0.025201006610586774, 0.040904151974245906, 0.07462507142918184, 0.05013144102122169, 0.08884994211257435, 0.15732370025943965, 0.1221303004422225, 0.04132706111704465, 0.15519379579927772, 0.16507464606547728, 0.14643533999333158, 0.07310921253520064, 0.14507113897707313, 0.0983492394152563, 0.172108810802456, 0.149114849336911, 0.1825864368584007, 0.1606388294021599, 0.14140553801553324, 0.18999491119757295, 0.2088840983924456, 0.27482482488267124, 0.12424948086845689, 0.16754620563006029, 0.13832943979650736, 0.20272235793527216, 0.07750455988571048, 0.18305590463569388, 41.74929454922676, 87.65497326850891, 51.43555238842964, 92.45729237794876, 37.97486208379269, 38.65536756813526, 99.71725881099701, 90.08650079369545, 80.93083128333092, 76.4865517616272, 65.7307881116867, 4.5239450968801975, 3.3711434807628393, 0.6162018910981715, 3.0600748350843787, 77.706119120121, 79.39023435115814, 82.6302520930767, 75.87089359760284, 71.38233125209808, 72.4527034163475, 71.80008843541145, 70.23586437106133, 70.8194750547409, 64.58682909607887, 59.98401828110218, 56.317572221159935, 58.053182289004326, 60.28593868017197, 65.75509920716286, 63.4174532443285, 64.9752214550972, 63.869070410728455, 57.29758523404598, 49.85583655536175, 56.30233883857727, 55.613489001989365, 60.45050024986267, 60.24505667388439, 59.69038903713226, 53.97174149751663, 53.16147297620773, 49.54021409153938, 53.86988416314125, 49.938592314720154, 49.57932159304619, 51.68792724609375, 50.070635229349136, 49.443410485982895, 51.08525298535824, 47.23729446530342, 51.91797450184822, 49.80356656014919, 56.263702511787415, 57.00633846223354, 60.223766416311264, 60.11790029704571, 59.911571368575096, 57.862922698259354, 59.30918209254742, 58.02377186715603, 65.0668953359127, 62.807350382208824, 67.15553686022758, 66.60560756921768, 66.90252363681793, 64.52064424753189, 54.05841484665871, 65.43138697743416, 68.32500770688057, 66.9769236445427, 63.98418143391609, 64.83533576130867, 65.20696341991425, 63.610460087656975, 59.9808606505394, 52.78818100690842, 52.18266449868679, 50.15322759747505, 48.69710773229599, 46.72871835529804, 50.46139106154442, 49.93233025074005, 49.93512690067291, 49.39631961286068, 48.82350035011768, 47.714678049087524, 45.911625400185585, 48.251855224370956, 51.099365428090096, 49.70053888857365, 46.55566804111004, 48.83272245526314, 51.080396845936775, 49.14403215050697, 47.42245092988014, 50.35163775086403, 53.3781373500824, 49.72297288477421, 52.70261339843273, 61.291284933686256, 68.69038850069046, 70.54959833621979, 65.8897639811039, 67.98194691538811, 64.28245022892952, 58.92625384032726, 53.83815586566925, 54.35174010694027, 59.00205597281456, 65.7841144502163, 72.33351901173592, 72.05474317073822, 73.1141947209835, 68.62375527620316, 72.87190452218056, 68.63741174340248, 69.51213240623474, 50.095390900969505, 44.09965083003044, 6.822724370285869, 0.16242074081674218, 16.392510384321213, 60.10406903922558, 73.35049644112587, 75.65808221697807, 61.179798915982246, 10.089592896401882, 59.852898716926575, 57.23874159157276, 34.533835127949715, 65.87593272328377, 42.32572741806507, 0.5572399799712002, 0.19591511227190495, 0.26642332726623863, 0.2140602222061716, 0.23512424348155037, 0.18633935891557485, 0.1615187493734993, 0.09594533403287642, 0.2720550703816116, 0.1332807872677222, 0.14120986335910857, 0.11993524283752777, 0.1093270952696912, 0.175189925939776, 0.1630209304857999, 0.2401577413547784, 0.10575853011687286, 0.2385267976205796, 0.11373997214832343], [0.006428939595934935, 0.029171387213864364, 0.07067611848469824, 0.07711231257417239, 0.07978778463439085, 0.04564083901641425, 0.05309937863785308, 0.12783793557900935, 0.05863336235051975, 0.007819177935743937, 0.0563444453291595, 0.07932294785859995, 0.047056003313628025, 0.008520920309820212, 0.038272232850431465, 0.04833401500945911, 0.021368730413087178, 0.07923963436041959, 0.06515637287520804, 0.19058102974668145, 0.04295676917536184, 0.2770608861465007, 0.221793029922992, 0.848769717849791, 6.611412959173322, 62.48197004199028, 45.78577995300293, 30.904946252703667, 58.15450385212898, 10.736330542713404, 41.45175151526928, 83.6659549176693, 71.93764105439186, 66.50664567947388, 61.65089003741741, 14.992085080593824, 1.5283721568994224, 0.77222935622558, 1.2010729196481407, 50.894005447626114, 79.72611352801323, 72.13944062590599, 73.45118343830109, 71.65646374225616, 72.39230945706367, 71.38844132423401, 72.39028796553612, 73.31240728497505, 69.18848857283592, 61.65863022208214, 55.286250561475754, 50.81957124173641, 54.68944698572159, 57.56262481212616, 60.29453381896019, 58.079070299863815, 55.84639370441437, 48.71406242251396, 49.91165556013584, 50.7991511374712, 53.603438660502434, 54.63079333305359, 56.779517233371735, 57.33105383813381, 54.014310613274574, 49.50410842895508, 44.96994473040104, 47.008759528398514, 46.920752450823784, 44.29217889904976, 45.56101441383362, 45.107668340206146, 46.10674872994423, 46.20997779071331, 46.451530829072, 46.39181323349476, 47.21161164343357, 51.923362612724304, 55.50979256629944, 55.323336571455, 55.59251792728901, 54.34797450900078, 56.09445579349995, 54.13222208619118, 55.771222338080406, 56.655735075473785, 60.46427831053734, 62.57581740617752, 63.34361560642719, 61.708510145545006, 67.83982694149017, 59.45950202643871, 48.47314774990082, 58.61197270452976, 58.710573613643646, 60.897553861141205, 61.61482237279415, 59.52374517917633, 57.98319384455681, 53.661708533763885, 48.42066116631031, 44.378871247172356, 44.78912003338337, 45.24226471781731, 43.41663748025894, 42.950725480914116, 43.110411912202835, 42.23179265856743, 43.99406589567661, 43.515135794878006, 43.29108081758022, 42.55123011767864, 42.19289034605026, 43.3463716506958, 43.96272137761116, 42.94151097536087, 41.656693518161774, 43.464978486299515, 45.08504055440426, 46.787356808781624, 45.676889196038246, 46.9414309412241, 49.21848155558109, 50.14161542057991, 62.17611685395241, 61.71607553958893, 65.32857209444046, 63.91176491975784, 61.466398537158966, 58.48796635866165, 54.46493983268738, 50.3812837600708, 49.03490200638771, 53.27701337635517, 61.7000138014555, 66.75947651267052, 64.00679782032967, 74.27150622010231, 66.33853510022163, 68.29732239246368, 53.98255571722984, 33.28563630580902, 28.839439786970615, 17.398895882070065, 0.33200584875885397, 0.6870299717411399, 11.172868218272924, 56.65141850709915, 55.841058790683746, 65.91716051101685, 14.388729706406593, 16.207272224128246, 51.685119196772575, 29.561779126524925, 33.395385816693306, 53.66479016840458, 5.243388991802931, 0.5882653151638806, 0.13150335842510685, 0.12656414299272, 0.038081278253230266, 0.04380965270684101, 0.0516847449762281, 0.11337045682012103, 0.023988183311303146, 0.06459796612034552, 0.024415387633780483, 0.057976075549959205, 0.09750768105732277, 0.03991567806224339, 0.061730173911200836, 0.011038040320272557, 0.0234888088380103, 0.05034681598772295, 0.01976054278202355, 0.12810610322048888, 0.014530664284393424, 0.08427216002019122, 0.027903309164685197, 0.07490169955417514, 0.03250394198403228, 0.031116608224692754, 0.034987286853720434, 0.1204583901562728, 0.05094243402709253, 0.016971807854133658, 0.0005551326080421859, 0.10143677412997931, 0.004398530236358056, 0.009497253613517387, 0.03238695724576246, 0.06095867800468113, 0.04194177461613435, 0.012047865820932202, 0.06698046796373092, 0.013364865317271324, 0.07515615230659023, 0.0872183452884201, 0.055021047592163086, 0.6078111694660038, 6.582853216677904, 75.95604702830315, 44.12021152675152, 41.994514390826225, 50.20370028913021, 16.80854056030512, 66.38623774051666, 83.26082825660706, 80.42666673660278, 70.59878289699554, 71.70843735337257, 17.740379758179188, 1.4210428786464036, 1.287920584436506, 1.2212746543809772, 60.21647460758686, 83.12105655670166, 75.45716419816017, 76.56872615218163, 77.15579465031624, 72.08743661642075, 75.90947672724724, 75.8314973115921, 74.81960400938988, 72.0728150010109, 65.32696858048439, 56.20012432336807, 52.16328553855419, 57.91070133447647, 59.675786420702934, 61.43973156809807, 62.452012449502945, 57.26762764155865, 50.8707544952631, 51.70325942337513, 53.83670814335346, 55.10255701839924, 57.98366881906986, 57.757482156157494, 59.384718239307404, 56.57790385186672, 50.51519617438316, 48.36677245795727, 49.458263888955116, 48.07402856647968, 46.67892962694168, 46.15936070680618, 46.79246373474598, 47.13674806058407, 48.633141964673996, 48.63857567310333, 48.233494609594345, 48.34194079041481, 54.41808074712753, 59.22091282904148, 57.85211227834225, 59.579290598630905, 58.09113845229149, 58.48613105714321, 55.148063376545906, 58.046038672327995, 60.669410303235054, 61.96005664765835, 65.41244879364967, 65.32468110322952, 64.6020282804966, 67.73629009723663, 61.39090038836002, 51.12353593111038, 64.7161665558815, 59.90648724138737, 62.295609042048454, 63.4640197455883, 60.93993678689003, 60.12695901095867, 56.941426545381546, 51.65402166545391, 47.91876509785652, 47.590097934007645, 47.11600497364998, 45.57785131037235, 45.77425517141819, 46.46206006407738, 45.7587406039238, 46.536346077919006, 46.999260038137436, 45.19396550953388, 45.9769818931818, 44.81181241571903, 47.10565812885761, 45.674385130405426, 47.08618797361851, 43.70920658111572, 47.22851313650608, 43.77622738480568, 47.045864537358284, 49.027344211936, 50.1298588514328, 50.098058357834816, 53.58095146715641, 65.03423988819122, 66.0593032836914, 67.66524910926819, 67.64325588941574, 63.606918677687645, 61.38852171599865, 55.92869348824024, 52.260256335139275, 52.68801458179951, 55.50399407744408, 63.36881585419178, 70.92189475893974, 71.21781527996063, 74.09891188144684, 67.50014796853065, 69.40656647086143, 61.275420784950256, 39.30058814585209, 38.5922871530056, 16.305500753223896, 0.1793914317386225, 0.8227419457398355, 13.476330265402794, 61.90798804163933, 63.43299061059952, 66.14503428339958, 30.091991275548935, 16.061268858611584, 49.3121313303709, 34.597633704543114, 34.48223389685154, 65.60971900820732, 5.68314746953547, 0.3560892533278093, 0.0380733038764447, 0.06863582093501464, 0.008611761968495557, 0.04879878499195911, 0.049251509917667136, 0.08307587733725086, 0.02464179091475671, 0.10768521970021538, 0.03505092601699289, 0.08721617821720429, 0.04407685555634089, 0.033268680635956116, 0.04427663057867903, 0.0217403423084761, 0.05544863597606309, 0.04796964276465587, 0.026724979034042917, 0.08418167737545446, 0.09094487657421269, 0.21035515383118764, 0.1393941990681924, 0.17251629440579563, 0.15301105042453855, 0.10812116466695443, 0.14061246416531503, 0.2578899054788053, 0.21962585480650887, 0.13697994814720005, 0.1565137054421939, 0.1468191936146468, 0.1371567277237773, 0.25908862240612507, 0.15373062196886167, 0.15606429049512371, 0.2560425514820963, 0.16354059713194147, 0.16325366799719632, 0.312421343405731, 0.18012155662290752, 0.3265229507815093, 0.39492290234193206, 1.0331214568577707, 13.951632510870695, 89.3926428258419, 60.3216377645731, 51.76365718245506, 81.59894183278084, 16.252039521932602, 53.71172524988651, 94.4456572830677, 83.76900538802147, 77.80291512608528, 76.59866854548454, 18.744025602936745, 3.235737746581435, 4.297630665823817, 2.678134529851377, 65.6237630546093, 85.2580238878727, 81.51720061898232, 80.77078387141228, 80.0218440592289, 76.53914093971252, 79.55563187599182, 79.70454588532448, 80.01145541667938, 76.08842432498932, 68.59784066677094, 60.830145478248596, 56.444914788007736, 61.585814729332924, 63.62268403172493, 66.07088506221771, 66.02853253483772, 60.467663928866386, 51.99507616460323, 56.46508790552616, 57.04332187771797, 58.90492558479309, 60.39292573928833, 60.60106337070465, 62.390520349144936, 60.018117651343346, 54.575643092393875, 51.94718353450298, 51.71675629913807, 51.402000188827515, 47.97032453119755, 49.87762078642845, 50.353427454829216, 49.813943803310394, 51.67822256684303, 49.84416738152504, 51.7135226726532, 51.25589042901993, 56.59705102443695, 61.78164102137089, 59.85915318131447, 63.757652789354324, 59.82490561902523, 60.631568133831024, 56.422249004244804, 59.749669656157494, 61.97484165430069, 65.02081140875816, 67.10192933678627, 66.5948161482811, 65.81591874361038, 70.85693344473839, 61.16489231586456, 53.41745384037495, 67.75819972157478, 62.990097776055336, 64.10017400979996, 64.99639391899109, 63.51659752428532, 62.11493633687496, 60.434666499495506, 52.15730845928192, 48.858420476317406, 49.332087859511375, 49.649154245853424, 48.98972623050213, 48.40582676231861, 49.782044515013695, 47.75299899280071, 50.156077444553375, 49.28234852850437, 48.65444742143154, 50.69613866508007, 47.71224617958069, 50.310911536216736, 49.26945962011814, 47.896068915724754, 46.526800990104675, 49.77922886610031, 47.75498628616333, 49.98854823410511, 50.464286506175995, 53.548755794763565, 53.894677832722664, 55.4679986089468, 68.19070771336555, 66.90522909164429, 71.30046084523201, 69.4251398742199, 66.90387636423111, 63.27314078807831, 59.04298737645149, 53.74142065644264, 53.73242273926735, 58.62819403409958, 66.93774774670601, 72.47812405228615, 72.15182796120644, 76.34398341178894, 66.5875281393528, 71.373340934515, 70.17344132065773, 44.764873534440994, 39.066045731306076, 23.80142692476511, 0.3704860573634505, 1.5322456927970052, 16.89456034451723, 69.9483110010624, 66.73645734786987, 78.08416843414307, 24.20419581234455, 21.424700058996677, 74.93396267294884, 43.427907675504684, 47.64826141297817, 75.64759477972984, 10.772549249231815, 0.6210360629484057, 0.1850457361433655, 0.2528074703877792, 0.18702467292314395, 0.10472117835888639, 0.16125490103149787, 0.2898885228205472, 0.09780728607438505, 0.18488666421035305, 0.18740527593763545, 0.22124528040876612, 0.25109738402534276, 0.05448569936561398, 0.15496107313083485, 0.11863164560054429, 0.11724127645720728, 0.15395789727335796, 0.13367028121137992, 0.14549533574609086], [0.01784467742254492, 0.014269444072851911, 0.015975064561644103, 0.03350389320985414, 0.08012241160031408, 0.057013261393876746, 0.04338540027674753, 0.03534365874656942, 0.04640231592929922, 0.1021436920564156, 0.014664579266536748, 0.03607289676438086, 0.017866626440081745, 0.18615962559124455, 0.013471267029672163, 0.026986140801454894, 0.017247311625396833, 0.062331513909157366, 0.0391880653478438, 0.05236822958977427, 0.027790543535957113, 0.0746626834734343, 0.11843404136016034, 0.15340533864218742, 0.19932378170778975, 34.24999415874481, 64.22185108065605, 28.4793122112751, 51.145962327718735, 37.478255331516266, 9.725397638976574, 73.44723924994469, 74.35743480920792, 70.31674683094025, 59.06320609152317, 25.786123126745224, 0.7491437543649226, 2.1078304946422577, 0.5125547933857888, 39.44022685289383, 81.54502272605896, 73.02359998226166, 81.82403415441513, 67.51309007406235, 79.08469274640083, 74.00514051318169, 81.94385692477226, 75.786302536726, 73.1659023463726, 62.74559609591961, 59.57750089466572, 52.03376568853855, 55.64519450068474, 59.08504731953144, 62.177735567092896, 57.653800919651985, 57.96493202447891, 49.10810507833958, 50.69340281188488, 51.23529553413391, 53.00062380731106, 57.57113255560398, 59.87912490963936, 60.811826661229134, 56.807764917612076, 55.371669977903366, 51.096739768981934, 47.625189051032066, 45.09258694946766, 45.92763014137745, 45.90434119105339, 46.82896077632904, 46.45601458847523, 43.96273657679558, 47.88758397102356, 47.435548827052116, 49.513212740421295, 60.67322909832001, 58.0665385723114, 60.72203367948532, 58.37313272058964, 58.2936941832304, 57.1188048273325, 58.94281715154648, 59.308167546987534, 60.42900860309601, 58.78701411187649, 63.79281610250473, 62.508830800652504, 60.90857706964016, 60.43803691864014, 69.12352725863457, 61.85194484889507, 50.37561446428299, 62.24662967026234, 63.645061030983925, 62.11429417133331, 59.136526957154274, 57.947783544659615, 54.164334163069725, 50.42546018958092, 46.22866898775101, 44.00073453783989, 45.07785513997078, 45.13283059000969, 43.26649993658066, 44.37688395380974, 43.602747693657875, 43.418157398700714, 43.866039365530014, 43.51956635713577, 43.08757893741131, 40.70283070206642, 43.40575486421585, 43.286760449409485, 43.97054135799408, 45.52707463502884, 43.4721677005291, 45.791890025138855, 47.996938303112984, 49.613869339227676, 45.60011051595211, 48.02476041018963, 54.92978408932686, 62.17137090861797, 61.33739545941353, 64.31792512536049, 63.34897331893444, 61.20358183979988, 56.16016186773777, 53.13109740614891, 51.7497993260622, 49.856554716825485, 50.71543022990227, 59.78785000741482, 63.27591083943844, 68.35940346121788, 65.73397234082222, 74.11357909440994, 63.84539008140564, 39.74914647638798, 20.27982149273157, 21.436221040785313, 1.6304389550350606, 0.05758535335189663, 0.8990337769500911, 19.44294299930334, 54.309281185269356, 62.212104722857475, 38.357064574956894, 5.8174199145287275, 45.43521076440811, 37.74019427597523, 27.604707442224026, 46.97657525539398, 34.784720465540886, 0.3187100059585646, 0.06669795460766181, 0.017260124805034138, 0.025713927134347614, 0.04343110544141382, 0.004972793440174428, 0.05072964915598277, 0.018294135043106508, 0.005587039386227843, 0.05794833406980615, 0.043649059371091425, 0.08938056285842322, 0.04839348701352719, 0.060351578940753825, 0.05300822806020733, 0.0745065652881749, 0.05034766945755109, 0.011504218527988996, 0.06020142762281466, 0.05225239889114164, 0.05331841610313859, 0.02332493706489913, 0.031769464403623715, 0.01752881937136408, 0.029514272428059485, 0.04469179541047197, 0.04359546517662238, 0.08413205738179386, 0.03734972844540607, 0.02005157042731298, 0.03143146066577174, 0.05551792659389321, 0.020321793817856815, 0.09003481798572466, 0.04358298967417795, 0.060998720582574606, 0.04374501535494346, 0.017119818076025695, 0.07461889676051214, 0.0320532876503421, 0.03474478638963774, 0.007892732191976393, 0.14162212639348581, 0.08175860231858678, 0.05365605989936739, 38.32704238593578, 74.76503133773804, 29.754187501966953, 65.81778824329376, 28.208004869520664, 25.615899860858917, 88.29217627644539, 78.52752104401588, 77.91336759924889, 65.37799224257469, 30.18855359405279, 0.5249089992139488, 3.0860481038689613, 0.2171823929529637, 48.0580960214138, 84.12690818309784, 77.1865426003933, 83.23135703802109, 73.07554319500923, 82.31581896543503, 76.11493930220604, 81.92138493061066, 79.66654032468796, 75.93201711773872, 67.53766715526581, 62.22529761493206, 53.36861506104469, 57.662050276994705, 60.27323596179485, 63.32433924078941, 61.19391895830631, 60.980492010712624, 52.47614175081253, 53.24524328112602, 52.91131719946861, 56.7472455650568, 57.46763750910759, 61.46288372576237, 61.21370069682598, 59.32510323822498, 56.44598253071308, 52.30122573673725, 48.71052101254463, 48.430715426802635, 48.486633226275444, 48.85839007794857, 47.65052229166031, 48.05437222123146, 47.079523131251335, 50.60347683727741, 50.37058733403683, 51.62184119224548, 62.74004079401493, 61.548968106508255, 61.83905974030495, 60.65606161952019, 61.58263050019741, 59.617972522974014, 60.33809848129749, 60.238927602767944, 63.37983526289463, 62.998012751340866, 66.35292872786522, 66.24227106571198, 65.00147044658661, 63.91076937317848, 74.53402653336525, 65.07711678743362, 53.16599853336811, 66.01387292146683, 65.15133440494537, 64.79324921965599, 62.09504820406437, 59.84439477324486, 57.092365846037865, 52.733513340353966, 49.12091039121151, 46.749001666903496, 46.972049698233604, 47.85818874835968, 47.6016379147768, 48.500285893678665, 47.64953054487705, 45.72768107056618, 45.94135880470276, 46.15670084953308, 45.31938537955284, 44.60836373269558, 47.340876907110214, 46.31526634097099, 46.84433475136757, 47.83678449690342, 46.99923723936081, 50.37723317742348, 50.20623855292797, 51.05217956006527, 47.61177197098732, 50.93500904738903, 57.818719670176506, 66.55347436666489, 65.56600615382195, 66.1555977165699, 65.61047896742821, 65.31202778220177, 58.59935738146305, 56.62181429564953, 54.43087086081505, 53.14303636550903, 55.30830457806587, 60.25392159819603, 66.82363986968994, 69.72856119275093, 68.47948461771011, 74.29399341344833, 69.07189562916756, 45.52217669785023, 31.866710744798183, 23.17707672715187, 0.5872511852066964, 0.3510712366551161, 1.2111162557266653, 23.610870949923992, 64.69769954681396, 66.2877394258976, 47.43859626352787, 15.09932292625308, 27.59008202701807, 47.78796471655369, 27.81553342938423, 55.508683025836945, 36.91830597817898, 0.3003128181444481, 0.05226204310019966, 0.06848055621958338, 0.03977818778366782, 0.041375300716026686, 0.05599325362709351, 0.05644742945150938, 0.07648010665434413, 0.030331152520375326, 0.04373565687274095, 0.023233706706378143, 0.004818854849872878, 0.02593919121864019, 0.03753335804503877, 0.098713819461409, 0.020595189889718313, 0.03618271977757104, 0.023109528701752424, 0.05905503210669849, 0.03555935654731002, 0.09065770253073424, 0.17640155623666942, 0.08620318374596536, 0.22915037028724328, 0.22952692117542028, 0.13443243718938902, 0.15096282673766837, 0.1739084447035566, 0.12439676007488742, 0.13442744995700195, 0.10786801809445024, 0.17313460732111707, 0.06986762280575931, 0.36701271717902273, 0.17256825958611444, 0.1354435391840525, 0.16928312805248424, 0.15738161746412516, 0.21483281278051436, 0.15264689340256155, 0.09672265950939618, 0.1573758732411079, 0.25346902082674205, 0.2273900553700514, 0.37699783919379115, 54.686889722943306, 82.55565449595451, 43.8635428994894, 80.76155796647072, 52.958267480134964, 17.998059131205082, 86.86593800783157, 88.17195072770119, 85.65940394997597, 70.09986966848373, 34.013567045331, 1.5324842487461865, 6.706803040578961, 0.8762234821915627, 53.22595551609993, 83.82229372859001, 76.84750959277153, 90.90576723217964, 75.86169809103012, 86.83464288711548, 79.46571350097656, 85.4768617451191, 85.1518651843071, 79.89526525139809, 72.20905289053917, 67.13982850313187, 57.935384809970856, 61.340667083859444, 66.39506846666336, 66.44543096423149, 64.62256237864494, 63.225802928209305, 55.83980105817318, 55.34767806529999, 55.967679396271706, 58.24963554739952, 62.97176755964756, 64.66748356819153, 65.31641274690628, 62.14885711669922, 61.630732119083405, 58.09108525514603, 53.63229811191559, 50.20143561065197, 49.927926287055016, 51.87253274023533, 49.68068115413189, 50.63432738184929, 49.18719783425331, 54.36086721718311, 52.409850507974625, 54.05424267053604, 64.5776791870594, 64.51890394091606, 63.84240344166756, 63.41681867837906, 62.95365393161774, 62.4415972083807, 61.91434130072594, 64.76429477334023, 66.412593126297, 63.96462768316269, 67.9368357360363, 67.65040710568428, 64.71249595284462, 66.68694600462914, 74.74406406283379, 62.97658570110798, 56.81656904518604, 70.16274869441986, 67.08288475871086, 68.80929172039032, 62.69781745970249, 64.3836160004139, 61.53424009680748, 57.013903856277466, 50.95944553613663, 48.84873479604721, 49.215730503201485, 51.07144072651863, 51.00774474442005, 51.90172277390957, 49.43627066910267, 48.19145366549492, 50.068199560046196, 49.846477657556534, 48.58635127544403, 48.45588527619839, 50.00686325132847, 48.4119900316, 49.35656614601612, 52.4781708419323, 49.53432820737362, 53.46147447824478, 53.65348197519779, 55.87803840637207, 50.35973131656647, 51.6980917006731, 59.789863899350166, 67.5885084271431, 68.72610658407211, 67.90113285183907, 69.65441197156906, 67.70029082894325, 61.992605701088905, 58.80013860762119, 57.86847800016403, 54.60824154317379, 56.69530235230923, 62.83664681017399, 69.76062387228012, 72.02906414866447, 72.46425479650497, 74.35051158070564, 69.73220139741898, 49.764079079031944, 35.90338423848152, 33.04205797612667, 1.8999269069172442, 0.2819271187763661, 2.200310882180929, 26.29870232194662, 68.63972961902618, 72.85115003585815, 49.52104791998863, 9.44935955107212, 62.57764510810375, 62.16319754719734, 39.732104390859604, 61.27144619822502, 52.75707207620144, 0.8358520141337067, 0.17723955970723182, 0.1539835162111558, 0.14777280885027722, 0.18688001349801198, 0.23150861874455586, 0.1513284828979522, 0.15125774138141423, 0.12645988608710468, 0.16024954325985163, 0.08632243203464895, 0.14136822283035144, 0.1221554889343679, 0.09754499624250457, 0.17158797156298533, 0.14610794896725565, 0.16813554510008544, 0.10835457753273658, 0.2438857569359243, 0.12040281071676873], [0.056470261624781415, 0.029122856321919244, 0.04945446133206133, 0.08995318916277029, 0.06706344007398002, 0.10280571746989153, 0.058464082176215015, 0.022877696610521525, 0.01415722206729697, 0.06012443351210095, 0.044068669667467475, 0.09265825807233341, 0.10668544287909754, 0.044950203810003586, 0.07220823783427477, 0.03796737713855691, 0.019010494943358935, 0.05231743329204619, 0.05903241515625268, 0.0915469512983691, 0.1543444671551697, 0.03472367599897552, 0.37933144834823906, 0.3151134989457205, 0.7884217123501003, 4.750948240980506, 62.36078314483166, 50.79379342496395, 31.193044893443584, 64.44500550627708, 16.243581175804138, 25.034382864832878, 79.67404872179031, 68.93324106931686, 67.18028113245964, 37.63495892286301, 1.6815223451703787, 0.918032816844061, 0.42812569881789386, 15.81675672903657, 87.3294447362423, 73.59932988882065, 79.3149983882904, 77.77697771787643, 80.35067081451416, 79.8983658850193, 78.15064206719398, 79.17132809758186, 77.55611076951027, 68.93273189663887, 60.137423649430275, 54.22036595642567, 53.978330343961716, 61.11911237239838, 61.273353695869446, 59.35745470225811, 59.282716512680054, 51.809836104512215, 50.65230041742325, 51.48958928883076, 53.622802421450615, 60.41615009307861, 59.9665392190218, 61.782066598534584, 58.386071026325226, 58.17882254719734, 51.26347482204437, 49.05336521565914, 46.60813182592392, 49.4005373865366, 45.483946949243546, 47.61292710900307, 47.23297789692879, 48.229352831840515, 45.23621544241905, 46.91565312445164, 51.77652329206467, 60.306921154260635, 59.05401438474655, 61.51458755135536, 60.7436279207468, 59.912179335951805, 57.72398695349693, 55.91111183166504, 59.293762519955635, 62.70386293530464, 61.134984120726585, 61.28310777246952, 61.58331826329231, 59.560424610972404, 64.00198727846146, 62.038438841700554, 63.487346693873405, 68.32416415214539, 58.55511635541916, 59.61929105222225, 60.821474343538284, 57.54039600491524, 56.31455898284912, 51.541604697704315, 49.644936472177505, 48.00445809960365, 44.5392644405365, 45.866236835718155, 42.50841401517391, 43.13363626599312, 44.603944569826126, 44.78634238243103, 43.748526871204376, 43.94743859767914, 42.30663724243641, 42.863086983561516, 41.87591515481472, 45.2428574860096, 45.062511563301086, 45.363877192139626, 42.94050022959709, 45.258831828832626, 44.75466728210449, 48.11198852956295, 45.82478865981102, 47.40017272531986, 45.28875142335892, 59.080901741981506, 61.41375996172428, 64.1209664940834, 62.95591861009598, 60.880857557058334, 58.42383340001106, 57.030273377895355, 52.33482353389263, 52.416925728321075, 52.24754221737385, 51.94084547460079, 53.11294198036194, 62.33530931174755, 65.44717133045197, 68.77868056297302, 66.73483863472939, 65.34684911370277, 35.503938272595406, 24.008171930909157, 3.847388313151896, 0.156259787036106, 0.6181092106271535, 1.6396246058866382, 31.817885264754295, 62.07671418786049, 60.28746999800205, 11.358944233506918, 17.753101475536823, 50.881211534142494, 37.13850036263466, 32.53347806632519, 58.42197149991989, 6.652082176879048, 0.4444415186299011, 0.0460788842610782, 0.09578882993082516, 0.061082468237145804, 0.05605198719422333, 0.07083556149154902, 0.06109496229328215, 0.030479209126497153, 0.06131198111688718, 0.08047358845942654, 0.044527149948407896, 0.02716980379773304, 0.014205223251337884, 0.04704176521045156, 0.013243447174318135, 0.07092317944625393, 0.04718873642559629, 0.020059012313140556, 0.020354945554572623, 0.03196528006810695, 0.039635851280763745, 0.03964741023082752, 0.011308436260151211, 0.015551795477222186, 0.02764219192613382, 0.05133411359565798, 0.09500131476670504, 0.048931221244856715, 0.03714344849868212, 0.049587610046728514, 0.017962172387342434, 0.10247575119137764, 0.033356387648382224, 0.04341588770330418, 0.10815142202773131, 0.05343285527487751, 0.11149384736199863, 0.06362165600876324, 0.07053704743157141, 0.11261849052971229, 0.1774278425727971, 0.06081139508751221, 0.17552107223309577, 0.11868853864143603, 0.5683720763772726, 4.788532974198461, 78.42249467968941, 47.98767440021038, 40.9243968129158, 56.58226601779461, 16.791825257241726, 53.9453861117363, 83.56165051460266, 77.99709990620613, 69.49055716395378, 43.09535712003708, 1.2591482908464968, 3.644427666440606, 0.9330579824745655, 18.34403056651354, 93.5822144150734, 73.35945636034012, 81.72194123268127, 80.36187261343002, 82.35653758049011, 82.58644804358482, 84.29105937480927, 79.11137491464615, 81.0793349146843, 70.3097628057003, 61.48053377866745, 56.183876395225525, 57.45467260479927, 62.62753643095493, 61.83536633849144, 63.64164121448994, 58.99034880101681, 53.094227984547615, 52.3515198379755, 52.276781648397446, 55.35363994538784, 60.7491984218359, 62.413835898041725, 62.015655264258385, 60.19758582115173, 59.50401283800602, 55.267513766884804, 53.336073607206345, 48.70304301381111, 49.48904983699322, 48.53781647980213, 49.48558822274208, 49.85868260264397, 50.45962795615196, 48.60748574137688, 50.030775368213654, 55.13526186347008, 61.74176976084709, 63.7275318056345, 65.13152986764908, 64.39600333571434, 62.19401769340038, 59.43970888853073, 61.029011607170105, 64.40107986330986, 63.992784172296524, 64.0424095094204, 65.89363217353821, 63.58660876750946, 63.245406076312065, 67.36901700496674, 64.52274173498154, 67.34045773744583, 72.3262158036232, 59.22782085835934, 61.91196262836456, 62.39135630428791, 59.5046816021204, 57.01394185423851, 54.236777275800705, 51.19718737900257, 49.69233512878418, 48.144355192780495, 49.510613679885864, 45.592320933938026, 47.45310388505459, 45.486751198768616, 47.49793007969856, 46.49677500128746, 47.54793159663677, 45.978391617536545, 46.932167038321495, 44.60948087275028, 49.0202271938324, 48.44722554087639, 49.34530355036259, 46.54715269804001, 46.88254550099373, 48.536247164011, 52.764151096343994, 49.45056550204754, 50.53723879158497, 48.330583199858665, 60.77359691262245, 64.03098732233047, 65.23586466908455, 64.87878262996674, 64.10515934228897, 59.69394564628601, 61.00341238081455, 55.685289949178696, 54.473409578204155, 53.782112672924995, 54.89001162350178, 54.08812165260315, 66.07357531785965, 66.5343689918518, 72.4565564095974, 68.84269192814827, 70.3713271021843, 48.837111219763756, 31.50543373078108, 2.4985074810683727, 0.1417920336825773, 1.530678158160299, 3.3276374777778983, 36.92167639732361, 71.09986200928688, 60.15557527542114, 25.58948177844286, 18.260419853031635, 45.61530590057373, 46.138697415590286, 32.414324060082436, 69.10740852355957, 7.543764654546976, 0.3581570548703894, 0.09007974018459208, 0.061959950253367424, 0.07642958124051802, 0.13758261658949777, 0.04288674012059346, 0.0029483643993444275, 0.014069994667806895, 0.03975066894781776, 0.03989706870925147, 0.03675766900414601, 0.05217584635829553, 0.022906556878297124, 0.0174524375324836, 0.051775324100162834, 0.04107477914658375, 0.061265210970304906, 0.03724032845639158, 0.0590261031902628, 0.03340329880302306, 0.13732786697801203, 0.1425558520713821, 0.12264567005331628, 0.16368029901059344, 0.1452802910353057, 0.19016940495930612, 0.1561985004809685, 0.1172825918183662, 0.07602303274325095, 0.1875894027762115, 0.2424113024608232, 0.1556273881578818, 0.2071498180157505, 0.12501344026532024, 0.1794167241314426, 0.1769638221594505, 0.25970407063141465, 0.24463076930260286, 0.21237409237073734, 0.3931990417186171, 0.42782171512953937, 0.34792458987794816, 0.5391658341977745, 0.4264854930806905, 1.162616133224219, 11.590177025645971, 93.89600917696953, 64.90677192807198, 50.567857548594475, 94.74230736494064, 21.031516157090664, 40.103462263941765, 90.5189099907875, 86.59743681550026, 79.19909700751305, 49.15639288723469, 1.2453050399199128, 3.4769751643761992, 0.8913826500065625, 20.231184102594852, 96.618000715971, 75.19214361906052, 82.29305818676949, 84.48829919099808, 85.01375779509544, 85.69411128759384, 86.78567871451378, 82.53990054130554, 85.23477673530579, 74.51147094368935, 66.06751844286919, 60.10246932506561, 60.304192900657654, 66.57180458307266, 67.83931776881218, 67.87829607725143, 63.980951607227325, 55.83170749247074, 57.27919802069664, 55.766495391726494, 59.01901826262474, 65.27763202786446, 65.1620726287365, 64.86324906349182, 62.174133360385895, 62.371756955981255, 58.65408964455128, 55.76260060071945, 50.404903292655945, 53.12547370791435, 49.82004627585411, 53.69632087647915, 54.27240416407585, 54.99438442289829, 49.92028869688511, 52.743237018585205, 56.99425131082535, 65.30984669923782, 64.3161316215992, 66.14617422223091, 66.71457052230835, 63.89568418264389, 63.185490891337395, 62.76647597551346, 63.790186643600464, 67.29983791708946, 66.20131686329842, 68.1410063803196, 62.723819464445114, 63.210444152355194, 70.0804603099823, 66.47517576813698, 69.34887036681175, 71.53053089976311, 61.27392366528511, 66.09467178583145, 64.55228134989738, 62.59476698935032, 58.891774490475655, 57.35554352402687, 54.14638392627239, 53.240083158016205, 49.84558090567589, 51.22883588075638, 47.186928167939186, 50.07037304341793, 49.75013002753258, 51.723158955574036, 50.164121612906456, 50.79845957458019, 49.13346491754055, 49.760039895772934, 47.01899617910385, 52.142021879553795, 51.14597372710705, 52.60200619697571, 48.44262018799782, 48.55423919856548, 50.36981977522373, 55.69511242210865, 51.89839415252209, 51.08094021677971, 50.28357580304146, 63.46827171742916, 66.36846989393234, 69.83679458498955, 66.95569798350334, 66.08524069190025, 62.522122487425804, 63.11250440776348, 58.13886009156704, 57.65318155288696, 57.032484859228134, 57.17493161559105, 58.01164671778679, 67.87665456533432, 71.58451080322266, 73.70573177933693, 72.59921595454216, 74.32186111807823, 54.354506358504295, 36.454943642020226, 5.023526614531875, 0.18314674351131544, 1.138960502576083, 3.881895923987031, 38.53769928216934, 75.77680304646492, 69.01828810572624, 20.037985369563103, 24.450000822544098, 77.44375839829445, 56.192357540130615, 44.76926609873772, 79.01319578289986, 17.270724959671497, 0.9146446455270052, 0.2517464366974309, 0.2811575710074976, 0.2626640524249524, 0.19633947231341153, 0.11147491517476737, 0.10119910875800997, 0.17119941272540018, 0.1874507695902139, 0.19036040408536792, 0.27938202721998096, 0.1781843730714172, 0.13542571279685944, 0.08243726668297313, 0.16482138074934483, 0.170098303060513, 0.14008249650942162, 0.11009814217686653, 0.16412854136433452, 0.2303794855833985], [0.04468641855055466, 0.03055250177567359, 0.06752913774107583, 0.040053005068330094, 0.04041257932840381, 0.029985716173541732, 0.03063368159928359, 0.14599138725316152, 0.009217709775839467, 0.059791183230117895, 0.031164899774012156, 0.0380893045803532, 0.05563999504374806, 0.08225823839893565, 0.045215302670840174, 0.08424065585131757, 0.05327771672455128, 0.05914058689086232, 0.03696355561260134, 0.02873543111491017, 0.06648787486483343, 0.07003495484241284, 0.07034814858343452, 0.12056684019626118, 0.11477655949420296, 0.31239599164109677, 32.74732679128647, 61.469613164663315, 37.69298940896988, 53.74316856265068, 61.48457296192646, 10.309395901858807, 50.76111897826195, 66.70611217617989, 68.92745777964592, 47.42928296327591, 2.9554184759035707, 3.1283576460555196, 0.043177461629966274, 0.13378816394833848, 30.084454379975796, 92.29583904147148, 81.75520464777946, 75.87815880775452, 76.8804158270359, 76.64631798863411, 79.7801922261715, 77.74445906281471, 75.52328065037727, 67.33166500926018, 59.54960659146309, 54.01575833559036, 56.66386663913727, 59.12590652704239, 61.730385571718216, 64.23980131745338, 59.03591975569725, 51.1511642485857, 49.16315272450447, 50.9244380146265, 54.795400500297546, 58.029171377420425, 61.35126851499081, 60.59877969324589, 58.7973989546299, 54.52937297523022, 55.75714409351349, 50.45115441083908, 47.09180027246475, 46.88960172235966, 47.025980204343796, 49.13115084171295, 47.21221201121807, 47.90606237947941, 46.73977956175804, 47.71782428026199, 52.932884842157364, 61.79427534341812, 61.92260205745697, 63.661122769117355, 63.93678277730942, 64.57969307899475, 62.200526744127274, 61.35664142668247, 51.91155284643173, 55.91514341533184, 63.23255896568298, 60.072561129927635, 57.532728016376495, 59.6698397397995, 63.42735931277275, 63.97449195384979, 59.485975205898285, 62.84493036568165, 67.9438653588295, 57.749020010232925, 58.006961569190025, 53.82912375032902, 52.9204823076725, 48.96441958844662, 48.96949231624603, 46.28381162881851, 46.64568901062012, 44.88452151417732, 45.52618928253651, 44.42799501121044, 45.60538463294506, 44.07267227768898, 44.91308078169823, 44.475591257214546, 44.098032116889954, 44.086792320013046, 44.98206987977028, 44.94117647409439, 46.41310729086399, 44.92989107966423, 45.849240347743034, 46.38268992304802, 46.56300164759159, 46.359902545809746, 47.93593257665634, 47.817546129226685, 47.68871784210205, 54.852313846349716, 66.2546356022358, 61.87602035701275, 61.44909806549549, 61.542185470461845, 61.50277778506279, 57.39905498921871, 53.49473789334297, 53.12684543430805, 51.648451164364815, 50.64499340951443, 52.87455037236214, 58.55488456785679, 67.57728382945061, 68.46734046936035, 71.47753894329071, 66.60710468888283, 46.0720793902874, 12.74854201823473, 0.17688610445475206, 0.4271233541658148, 0.5420597945339978, 2.5063528725877404, 32.30781577527523, 66.52644261717796, 39.20294478535652, 5.899058533832431, 41.06416471302509, 51.30759425461292, 29.978764951229095, 41.001224890351295, 34.64608870446682, 1.2337232613936067, 0.08517849302734248, 0.1300895819440484, 0.062229631876107305, 0.08017470332561061, 0.07176513114245608, 0.03073469160881359, 0.06050511074136011, 0.033637591113802046, 0.009603065318515291, 0.028069748768757563, 0.03204929860658012, 0.015762687871756498, 0.030705562312505208, 0.05693894643627573, 0.05626010395644698, 0.04129194639972411, 0.02373480296228081, 0.011653865185508039, 0.011202390778635163, 0.026397294859634712, 0.06202087315614335, 0.023904339177533984, 0.1301465046708472, 0.06652891563135199, 0.045453116472344846, 0.09248353424482048, 0.03411582365515642, 0.02216254455561284, 0.047119991286308505, 0.024930647778091952, 0.01597758600837551, 0.04883308334683534, 0.027904593080165796, 0.08497138187522069, 0.06427061962313019, 0.032258250284940004, 0.05885039230633993, 0.08226614227169193, 0.023220073453558143, 0.020518360906862654, 0.010713261654018424, 0.04540838723187335, 0.03250056521210354, 0.05165345974091906, 0.13325439649634063, 0.1485650218091905, 37.68226258456707, 72.28124141693115, 32.450672909617424, 65.97480341792107, 33.743735924363136, 22.399585247039795, 69.37586411833763, 74.28013935685158, 77.69010677933693, 53.230906650424004, 3.8630543975159526, 3.1414643302559853, 1.8254225235432386, 0.026761780281958636, 33.14117185771465, 94.15065631270409, 80.32585814595222, 78.50910723209381, 81.65897101163864, 79.25009787082672, 81.75907284021378, 80.27969062328339, 75.46037122607231, 72.06257835030556, 61.89797557890415, 57.08171121776104, 59.090830609202385, 64.12450030446053, 64.36532378196716, 63.87532487511635, 61.380629539489746, 54.27301973104477, 49.893720522522926, 52.88616634905338, 57.55632475018501, 61.82012915611267, 62.45280280709267, 63.45469884574413, 59.76026728749275, 58.79733815789223, 57.310466542840004, 53.45581658184528, 48.17444197833538, 49.60052825510502, 50.13034142553806, 50.58855123817921, 49.81939651072025, 49.583622962236404, 51.052407547831535, 49.47441302239895, 55.02525396645069, 63.425493612885475, 65.6091870367527, 66.50789961218834, 65.52711144089699, 66.95081144571304, 65.15817403793335, 62.32327915728092, 57.17014007270336, 63.984166234731674, 68.07942688465118, 65.01515731215477, 59.94455359876156, 61.360099241137505, 65.42349860072136, 67.08208680152893, 62.15399444103241, 67.04037263989449, 72.11949169635773, 59.929517805576324, 60.04872500896454, 57.81091868877411, 56.987381279468536, 54.535623639822006, 52.624238803982735, 50.39329491555691, 50.1310595870018, 47.99581736326218, 49.140920117497444, 45.615241304039955, 48.09319853782654, 47.01791323721409, 48.966099098324776, 47.17226855456829, 47.96441964805126, 46.6274955868721, 47.06957146525383, 48.26377138495445, 50.54321967065334, 46.51792086660862, 50.155982449650764, 48.78829523921013, 49.31038722395897, 50.215768441557884, 50.169642716646194, 51.36784002184868, 51.8226034194231, 57.466930747032166, 67.2576753795147, 66.40546470880508, 64.53576743602753, 62.88051925599575, 64.58571955561638, 59.296327382326126, 54.81284536421299, 55.255681201815605, 54.58611153066158, 53.24344977736473, 55.71740962564945, 60.78191086649895, 69.72566574811935, 70.40069192647934, 73.00242751836777, 69.23822030425072, 54.590580090880394, 12.147141639143229, 0.07633253058884293, 2.1703908126801252, 2.2514525754377246, 4.383827615529299, 39.26836587488651, 72.94270992279053, 46.27584345638752, 16.715833134949207, 26.349308006465435, 55.19264258444309, 31.2695499882102, 48.2049011439085, 38.55925552546978, 1.2516585364937782, 0.18417636951198801, 0.023545520052721258, 0.030235020276450086, 0.07512866315664724, 0.061624410445801914, 0.032652338122716174, 0.05034074521972798, 0.03777434823859949, 0.007405341084449901, 0.024230195813288447, 0.036489646081463434, 0.08198139505111612, 0.028744581795763224, 0.011551367169886362, 0.042660273757064715, 0.06003785085340496, 0.004675541495089419, 0.026141736307181418, 0.03660944727016613, 0.023384303312923294, 0.14754087285837159, 0.13880205427994952, 0.2868457470322028, 0.1093778433278203, 0.12190329231088981, 0.22595107555389404, 0.2966181101510301, 0.2705789980245754, 0.1635308304685168, 0.16210981062613428, 0.11387171078240499, 0.18432378972647712, 0.15107475745026022, 0.15818138548638672, 0.23699678597040474, 0.1739679352613166, 0.1056763224187307, 0.18314466549782082, 0.12149123707786202, 0.06397967546945438, 0.17275110993068665, 0.08685295630129986, 0.21820388501510024, 0.3145124780712649, 0.24921838485170156, 0.35020820796489716, 52.65295006334782, 85.67439034581184, 50.59993542730808, 87.21861228346825, 83.08965504169464, 15.454050041735172, 65.6430584192276, 79.20642301440239, 81.79566487669945, 58.944872841238976, 3.1210190523415804, 6.778314728289843, 1.053591314703226, 0.35224448307417333, 37.0333182066679, 94.96284753084183, 84.10008922219276, 79.37928333878517, 84.34112548828125, 80.08762612938881, 85.11966571211815, 83.86686533689499, 80.3894591331482, 72.35052689909935, 66.16541638970375, 61.277271285653114, 63.00139456987381, 66.21824115514755, 68.41118708252907, 69.26868706941605, 64.89340424537659, 57.23419323563576, 52.63975717127323, 56.45962379872799, 62.14839734137058, 63.62169228494167, 67.64258712530136, 65.2684137225151, 61.02410987019539, 59.68976967036724, 61.83888494968414, 56.274490132927895, 51.99059620499611, 52.69261613488197, 52.13755711913109, 51.98472552001476, 53.490641713142395, 53.39170262217522, 52.07130007445812, 52.53376565873623, 58.1771582365036, 64.67616990208626, 66.976498067379, 67.7983483672142, 67.16624468564987, 68.80290046334267, 66.26601219177246, 66.38308390974998, 57.757311165332794, 64.53284159302711, 69.49473693966866, 66.12346664071083, 59.041068479418755, 62.972542718052864, 67.72154688835144, 68.6330571770668, 64.1615255177021, 65.58272525668144, 71.07660725712776, 60.301354452967644, 62.5900324434042, 58.84338788688183, 59.63254854083061, 54.83603172004223, 53.98317888379097, 52.60350711643696, 51.60213924944401, 49.784180000424385, 51.8803109228611, 48.657631650567055, 49.94628310203552, 49.02380280196667, 51.57970905303955, 50.56413374841213, 50.37301540374756, 50.859697088599205, 50.52708573639393, 49.83719475567341, 53.735865354537964, 51.27902738749981, 52.98489645123482, 51.86294965445995, 52.93527111411095, 52.41151101887226, 54.17313829064369, 53.55971060693264, 54.240208491683006, 59.01438631117344, 71.23481556773186, 67.38371461629868, 64.90923419594765, 66.23415470123291, 68.28285276889801, 62.62043081223965, 57.70925134420395, 56.857173666357994, 56.315641924738884, 54.45290207862854, 56.11457571387291, 61.99918694794178, 74.34000134468079, 71.34234979748726, 77.59587183594704, 73.05740296840668, 55.29293440282345, 16.07168599963188, 0.2622591069666669, 1.863951268605888, 2.457787678577006, 5.649050949141383, 39.89764630794525, 78.69658157229424, 49.56148535013199, 11.578448005020618, 52.96984165906906, 77.3449333012104, 42.461152151227, 56.247359588742256, 57.3175835609436, 2.1700352942571044, 0.2438639526371844, 0.19897152873454615, 0.14728929963894188, 0.20137740822974592, 0.184149325650651, 0.11408635473344475, 0.24215753248427063, 0.1158856249821838, 0.10810998050146736, 0.08114011870929971, 0.10040831330115907, 0.20306493330281228, 0.14549324288964272, 0.1174734128289856, 0.10758465126855299, 0.17089695786125958, 0.11466499243397266, 0.1302511474932544, 0.12320924215600826, 0.10539825452724472], [0.048491654597455636, 0.06813172454712912, 0.039220393300638534, 0.06917694307048805, 0.039196971119963564, 0.0643284477700945, 0.007090114322636509, 0.03405281160667073, 0.022858098345750477, 0.04701726691564545, 0.04339808729127981, 0.07250625465530902, 0.11793317331466824, 0.048827261198312044, 0.030025311607460026, 0.1124731483287178, 0.13168070203391835, 0.02572266777860932, 0.008022058846108848, 0.10930792559520341, 0.06993218223215081, 0.04140227036259603, 0.02418466505332617, 0.2556938905036077, 0.04864591370278504, 0.8638772321864963, 6.693524178117514, 59.62503254413605, 46.38287231326103, 35.49134574830532, 71.29638746380806, 27.667200788855553, 13.778888080269098, 57.67748884856701, 57.90714852511883, 68.3829165995121, 8.433472663164139, 3.5858314856886864, 2.8198436507955194, 0.4179238696815446, 0.28419250971637666, 28.505331315100193, 90.30488267540932, 80.133406072855, 83.10033246874809, 77.77861163020134, 82.43450179696083, 74.63725939393044, 72.12414264678955, 65.18570736050606, 59.11102652549744, 55.01121751964092, 59.94179494678974, 60.79712525010109, 66.86241298913956, 65.61404317617416, 62.011813670396805, 52.23816052079201, 49.19080764055252, 52.616916596889496, 56.028612926602364, 57.82972767949104, 60.12806475162506, 60.01940578222275, 59.0828662365675, 54.207826629281044, 52.69646532833576, 50.75347378849983, 48.903980031609535, 45.701283887028694, 48.06202121078968, 47.362178564071655, 51.777465641498566, 48.943596705794334, 48.77246528863907, 48.455531895160675, 51.8510676920414, 62.78985612094402, 63.01016829907894, 62.06328570842743, 61.98293522000313, 63.253381848335266, 60.89182376861572, 63.490014150738716, 64.62765410542488, 47.61903718113899, 57.394419237971306, 58.96256849169731, 58.87974053621292, 61.02988176047802, 62.59691387414932, 59.17804352939129, 63.032226115465164, 59.03443023562431, 57.92269729077816, 59.82778586447239, 55.04419595003128, 54.00653623044491, 51.98704719543457, 49.96735297143459, 47.79595568776131, 46.79195836186409, 46.75079517066479, 45.124440640211105, 44.71081003546715, 44.472186639904976, 44.056682735681534, 44.3484652787447, 44.98452454805374, 45.12341469526291, 46.01655296981335, 46.12422779202461, 44.76661764085293, 44.99780863523483, 46.96761153638363, 46.121134757995605, 45.31870521605015, 45.575400441884995, 47.75887727737427, 47.36803784966469, 47.913965955376625, 46.65119491517544, 46.98689930140972, 55.80144591629505, 62.27682664990425, 65.19394531846046, 64.44533228874207, 63.81280303001404, 58.573017194867134, 58.410800099372864, 54.13456656038761, 53.714316710829735, 53.67282673716545, 57.566625997424126, 53.32440063357353, 63.42246137559414, 63.126236870884895, 70.494554489851, 68.29387217760086, 74.92223650217056, 57.67114698886871, 1.9234005035832524, 0.17311400530161336, 2.8498841263353825, 3.5294729098677635, 4.657187797129154, 49.46576088666916, 65.56096002459526, 16.10787905752659, 15.863090492784977, 51.42114736139774, 39.76454325020313, 34.40782628953457, 48.18952716886997, 13.682368509471416, 0.5093651614151895, 0.14356027473695576, 0.03698908549267799, 0.025955904384318274, 0.02180044884880772, 0.029955848440295085, 0.03549866742105223, 0.15207380696665496, 0.019666711195895914, 0.009819489496294409, 0.03507356894260738, 0.04175059737463016, 0.04355974931968376, 0.08864769202773459, 0.025620093692850787, 0.046588847326347604, 0.08623353758594021, 0.026737797779787797, 0.031732672432553954, 0.07533216004958376, 0.049341064877808094, 0.04165285652561579, 0.04463136232516263, 0.03442416375037283, 0.011384814388293307, 0.0690733540977817, 0.09824632579693571, 0.046286529759527184, 0.03709863762196619, 0.029069883676129393, 0.02371162383496994, 0.04323757559177466, 0.023727134721411858, 0.051173468309571035, 0.035577772941906005, 0.034022339023067616, 0.06790425628423691, 0.12423399224644527, 0.09405891338246875, 0.06621417822316289, 0.002179855405302078, 0.04092114344530273, 0.0062742231420998, 0.05892909706744831, 0.13765755866188556, 0.09686451361631043, 0.5902337876614183, 5.267004249617457, 74.98951569199562, 42.125972136855125, 49.2802282422781, 63.098213374614716, 20.182104036211967, 37.71938279271126, 61.381305903196335, 65.39988666772842, 74.46602538228035, 9.867982137948275, 3.477949812076986, 4.280715873464942, 1.0291886678896844, 0.2832535147899762, 32.32410930097103, 93.09756562113762, 80.84161207079887, 84.12759214639664, 80.83883062005043, 86.17795452475548, 77.79871255159378, 74.73274067044258, 67.51307487487793, 63.22493277490139, 58.02808463573456, 60.77127903699875, 64.34299618005753, 68.72460946440697, 67.02290877699852, 64.63837713003159, 54.6730812638998, 52.33080334961414, 55.88208518922329, 56.566158682107925, 61.486678048968315, 63.0076490342617, 62.63403408229351, 60.2560418844223, 57.20146559178829, 54.73685324192047, 52.48553864657879, 50.783875957131386, 48.80814917385578, 48.79717156291008, 49.4345797598362, 52.80196666717529, 50.50078734755516, 49.9685575067997, 49.30884450674057, 54.689496383070946, 64.18237879872322, 66.91521495580673, 66.3056592643261, 64.05314013361931, 65.4259380698204, 63.780831545591354, 66.66520357131958, 64.21342313289642, 52.53525897860527, 60.55894263088703, 63.05694378912449, 59.08476233482361, 63.8200606405735, 66.60813063383102, 63.234113082289696, 66.52369156479836, 62.89596542716026, 61.31844587624073, 64.23464119434357, 59.94763903319836, 57.661381512880325, 56.52012415230274, 54.6395480632782, 51.735113114118576, 48.27023483812809, 47.39685170352459, 48.225176855921745, 45.983468145132065, 48.26474413275719, 46.46995984017849, 49.00202237069607, 48.6295435577631, 47.32908234000206, 48.27211573719978, 49.966771602630615, 47.011331990361214, 47.969043999910355, 51.054406240582466, 50.69308742880821, 48.40871840715408, 49.537223652005196, 49.466118067502975, 52.59439140558243, 52.17901669442654, 50.86856961250305, 47.64140658080578, 58.92292521893978, 63.333105370402336, 66.23327314853668, 67.0458671450615, 67.35539853572845, 59.24020819365978, 58.838866129517555, 57.39170238375664, 56.25341646373272, 56.870689541101456, 59.999912828207016, 57.69993044435978, 64.50561225414276, 64.05078426003456, 72.23852410912514, 71.54140591621399, 73.89949858188629, 61.11786983907223, 1.9103172118775547, 0.14011945546371862, 8.123690485954285, 3.9103471348062158, 5.068318611010909, 58.052821308374405, 67.80286252498627, 27.916579507291317, 17.782574594020844, 38.06261457502842, 47.57031239569187, 36.57558336853981, 58.55038940906525, 16.660933680832386, 0.6056341237854213, 0.14826081547653303, 0.04407303720654454, 0.04835705127334222, 0.04435376569745131, 0.0760288214951288, 0.02814018414937891, 0.08678474550833926, 0.033890158811118454, 0.04459330870304257, 0.028887745793326758, 0.01583102668519132, 0.01152173970695003, 0.08990226298919879, 0.03761800740903709, 0.01804911869839998, 0.0521533444407396, 0.02176863854401745, 0.06072799253161065, 0.04497013789659832, 0.08275491331005469, 0.1205361820757389, 0.1330248056910932, 0.09895728100673296, 0.12330410347203724, 0.17951364861801267, 0.1685182558139786, 0.12321959511609748, 0.20519798446912318, 0.09742035254021175, 0.0970070727635175, 0.11632234920398332, 0.16412990691605955, 0.20522911014268175, 0.22408286720747128, 0.07814905577106401, 0.24297365744132549, 0.46826606208924204, 0.20450124138733372, 0.15153445856412873, 0.16463336505694315, 0.2946678944863379, 0.21305367699824274, 0.1801224026712589, 0.40420443867333233, 0.3551335749216378, 0.9359853691421449, 12.245680801570415, 89.47665631771088, 61.085282787680626, 56.8782739341259, 106.32920041680336, 35.64222425222397, 26.61330074071884, 69.07377272844315, 72.84929573535919, 82.09250494837761, 9.001046307384968, 12.149494662880898, 5.168531583622098, 0.7608835212886333, 0.24980747199151665, 33.44758361577988, 94.68401089310646, 86.04924783110619, 89.07632499933243, 82.57806569337845, 90.21950125694275, 79.0971788764, 79.61291760206223, 70.79613670706749, 65.3158351778984, 60.625283271074295, 64.70059499144554, 67.36420646309853, 73.20873364806175, 71.25420212745667, 68.68113979697227, 57.376548796892166, 55.64276643097401, 58.64252686500549, 61.965045779943466, 64.90470483899117, 67.63855934143066, 64.54355701804161, 64.66388136148453, 60.29380805790424, 58.56613576412201, 55.79863786697388, 53.61281655728817, 49.426474794745445, 51.89357981085777, 51.93838320672512, 57.59680777788162, 53.75843234360218, 54.25697699189186, 53.51415105164051, 58.237316608428955, 68.1729930639267, 70.30647218227386, 67.0601923763752, 67.46744692325592, 67.15042993426323, 64.94230762124062, 65.96468836069107, 66.19625553488731, 51.325715482234955, 62.63707771897316, 62.540749087929726, 59.40961070358753, 63.508089780807495, 69.14009436964989, 65.15514180064201, 66.74895867705345, 64.11107182502747, 61.34602479636669, 63.90682518482208, 58.96416440606117, 59.66923177242279, 60.085697025060654, 55.46263329684734, 54.00265283882618, 52.266997173428535, 52.60270535945892, 49.969712644815445, 48.449744805693626, 51.06170564889908, 48.95870849490166, 50.923864245414734, 51.4944264292717, 50.561804473400116, 51.29723221063614, 53.03623929619789, 50.65810650587082, 49.30078133940697, 53.62060233950615, 53.3637323230505, 50.77384069561958, 51.78097665309906, 52.873057052493095, 54.751486256718636, 54.880337342619896, 53.97336021065712, 51.63061112165451, 61.99968472123146, 66.87361478805542, 67.586540132761, 68.88917103409767, 68.41081470251083, 61.86196491122246, 62.423096001148224, 59.678495675325394, 58.17468076944351, 59.19197738170624, 61.16781435906887, 60.60689605772495, 67.3415444791317, 69.43023160099983, 71.84692472219467, 77.54333585500717, 76.10617697238922, 62.195416018366814, 3.35226918105036, 0.3971423691837117, 9.55142967402935, 15.888447482138872, 6.944609005004168, 59.62818257510662, 77.35494196414948, 23.40238943696022, 22.02766690403223, 79.23407793045044, 55.058703571558, 46.64752811193466, 65.20985886454582, 26.28103516995907, 1.0325162205845118, 0.37242837657686323, 0.15865998168010265, 0.13489669508999214, 0.12457775505026802, 0.20207723864587024, 0.09310414781793952, 0.3139009780716151, 0.10367169248638675, 0.09587580221705139, 0.17795976949855685, 0.15858829021453857, 0.1712956841220148, 0.27861188573297113, 0.13245651352917776, 0.12706828390946612, 0.14681236585602164, 0.08866349977324717, 0.181754830700811, 0.13194395665777847, 0.16681971726939082], [0.10825498873600736, 0.02346664830838563, 0.014928591808711644, 0.01733634708216414, 0.0393027531390544, 0.062310867360793054, 0.0078175925227697, 0.024704153584025335, 0.0551779153465759, 0.04678608791437, 0.02169761686673155, 0.038418903495767154, 0.030519515166815836, 0.04318468643759843, 0.016924260307860095, 0.0327293285226915, 0.10264355820254423, 0.04640280574676581, 0.041219731720048, 0.012369297401164658, 0.03926122255506925, 0.04462662742298562, 0.08670045979670249, 0.025875986211758573, 0.04966724991390947, 0.11743489536456764, 0.4421092156553641, 34.200946390628815, 71.9854424893856, 33.48645932972431, 46.12981729209423, 76.11360937356949, 10.274741761386395, 41.915512830019, 70.13777643442154, 72.8032574057579, 19.916374795138836, 1.3313482166267931, 4.378813784569502, 0.18151729891542345, 0.9243404783774167, 1.138697366695851, 71.2226714193821, 89.56090539693832, 80.85683405399323, 77.3105451464653, 76.0097685456276, 75.21565675735474, 66.68181627988815, 65.46716585755348, 58.136242032051086, 57.66760937869549, 61.57397076487541, 64.46038708090782, 64.46446806192398, 67.9985748231411, 61.844280660152435, 54.10937011241913, 51.818514838814735, 52.15576194226742, 57.09114611148834, 64.06709298491478, 58.57321098446846, 55.82964800298214, 52.596051916480064, 51.410447135567665, 49.543706104159355, 49.44245293736458, 48.390574380755424, 49.37840737402439, 49.403227642178535, 47.43777550756931, 48.35340857505798, 46.95329010486603, 48.37233915925026, 46.60243593156338, 51.3364727050066, 65.05834579467773, 62.8272271156311, 62.24506415426731, 61.934001445770264, 63.67965817451477, 64.34789791703224, 58.82185064256191, 65.96223369240761, 60.82047499716282, 51.547676771879196, 63.23570139706135, 54.979044646024704, 62.851059436798096, 60.51773764193058, 62.4361103028059, 61.46250754594803, 61.183518916368484, 55.1014968752861, 55.5632670968771, 56.722166910767555, 52.72181756794453, 53.52028012275696, 51.17109797894955, 48.58852855861187, 49.08996485173702, 46.64322294294834, 43.77377271652222, 45.09449824690819, 43.56447234749794, 45.204677134752274, 45.59068702161312, 46.093924418091774, 45.43090559542179, 44.853317588567734, 45.38653917610645, 46.39785870909691, 46.21090494096279, 48.64856533706188, 49.398895874619484, 48.853788524866104, 47.74548299610615, 46.716004237532616, 48.487723767757416, 44.04172673821449, 47.42775544524193, 46.48898161947727, 53.10276232659817, 60.713658928871155, 66.69529795646667, 65.41884765028954, 63.51605795323849, 61.515533700585365, 57.01605834066868, 57.08764649927616, 58.35995502769947, 59.72541555762291, 60.47047957777977, 59.85718868672848, 64.51894953846931, 68.71591553092003, 73.95201176404953, 70.52058309316635, 80.9221601486206, 33.960027918219566, 0.2941520424792543, 0.29104223591275513, 3.7737019546329975, 1.7180287675000727, 11.797557547688484, 63.930117934942245, 39.84704442322254, 7.455890094861388, 38.62922117114067, 55.62717206776142, 63.70102442800999, 45.371104404330254, 54.79568928480148, 5.783350942656398, 0.29848535370547324, 0.11106671910965815, 0.03701749119500164, 0.017643468199821655, 0.04042279128043447, 0.025629005031078123, 0.014634128019679338, 0.04200730625598226, 0.03236119729990605, 0.02770158043858828, 0.018005875608650967, 0.03499580670904834, 0.019904968430637382, 0.040903714107116684, 0.04069913367857225, 0.06600992433959618, 0.09762966044945642, 0.011541847270564176, 0.019115096947643906, 0.024640258379804436, 0.06237660680199042, 0.03541427038726397, 0.02313065207999898, 0.023765002806612756, 0.04673358838772401, 0.024519382932339795, 0.030431229279201943, 0.00514505009050481, 0.014917777789378306, 0.04499773094721604, 0.0272080782087869, 0.025412715367565397, 0.07086018595146015, 0.04921386076603085, 0.06813323110691272, 0.05091048456961289, 0.02581754764833022, 0.04098522047570441, 0.0579141952766804, 0.023723594676994253, 0.016401593529735692, 0.05232509596680757, 0.06321479580947198, 0.02186114725191146, 0.04504637501668185, 0.03556135663529858, 0.15398795425426215, 0.2808546263258904, 36.91713944077492, 84.80434343218803, 31.422862261533737, 68.00781592726707, 43.73016245663166, 17.45087329298258, 59.562225714325905, 70.00488236546516, 82.48925685882568, 21.424310579895973, 0.32040263700764626, 8.442511428147554, 4.888989608734846, 1.1576550244353712, 1.3026912230998278, 74.9588893353939, 92.09841683506966, 85.30477657914162, 79.64373394846916, 80.21854430437088, 75.93081638216972, 68.75126883387566, 66.87649503350258, 61.67082756757736, 60.19690565764904, 61.73436015844345, 67.57742822170258, 67.71966218948364, 69.72134917974472, 62.78258331120014, 55.52606329321861, 52.56219193339348, 57.158489897847176, 60.61592057347298, 63.9838470518589, 61.44890047609806, 59.122585505247116, 55.519041270017624, 54.851025715470314, 54.148177430033684, 53.1912861764431, 51.40521861612797, 50.291882157325745, 50.39356850087643, 49.83125187456608, 50.91368079185486, 50.59835471212864, 50.651327669620514, 49.167830273509026, 56.76210656762123, 67.21578642725945, 65.68869397044182, 65.71384862065315, 65.69698512554169, 66.03870838880539, 65.68582132458687, 63.43180887401104, 68.55276748538017, 62.046338617801666, 57.11977377533913, 65.57701796293259, 57.098582312464714, 66.76747888326645, 63.14532704651356, 65.7866071164608, 63.22025902569294, 63.832052797079086, 59.17053513228893, 57.46693454682827, 60.35219572484493, 58.12387749552727, 55.42810074985027, 54.600664749741554, 50.914645940065384, 50.19884034991264, 48.81029225885868, 47.578907534480095, 48.813100308179855, 48.409679755568504, 46.84189908206463, 47.3172839730978, 48.61486494541168, 50.862030163407326, 47.73817218840122, 49.18421499431133, 48.18948917090893, 49.929305613040924, 49.35248136520386, 54.36343587934971, 51.52405723929405, 50.80057606101036, 50.63086576759815, 50.641474798321724, 46.885372549295425, 50.84896266460419, 49.84809257090092, 56.658117547631264, 63.58113706111908, 68.0745479464531, 66.5834091603756, 66.16173058748245, 64.4655168056488, 60.519679337739944, 59.84269626438618, 60.81029534339905, 61.955705881118774, 62.00669914484024, 63.24161767959595, 66.89624637365341, 69.57340031862259, 76.1089052259922, 72.76489466428757, 81.12820789217949, 35.76558083295822, 0.6778250844217837, 0.7541986706200987, 9.332163389772177, 1.3938758801668882, 13.543881140649319, 70.02015754580498, 44.18135404586792, 17.06098571419716, 27.387343905866146, 60.61745949089527, 71.4465706050396, 49.78234089910984, 64.8132361471653, 6.756314858794212, 0.2147982138558291, 0.11887023865710944, 0.025799604372878093, 0.028700045513687655, 0.08255863751401193, 0.024524377586203627, 0.012774162150890334, 0.022943725489312783, 0.05552702903514728, 0.040899550658650696, 0.02946897358924616, 0.04055942808918189, 0.02645025451784022, 0.03800970553129446, 0.022179790212248918, 0.02527673164877342, 0.09790409923880361, 0.030714785352756735, 0.023085972934495658, 0.045588057473651133, 0.0074465887246333295, 0.22771700110752136, 0.10787966239149682, 0.15800248336745426, 0.1965054016909562, 0.10056999759399332, 0.12096393373212777, 0.1086811521963682, 0.14307813107734546, 0.1772341420291923, 0.09320940662291832, 0.12116317811887711, 0.1711850002175197, 0.24261003476567566, 0.15723986725788563, 0.11225370268221013, 0.10123056839802302, 0.2440561243565753, 0.11750003366614692, 0.12430460017640144, 0.14446185057749972, 0.11434169064159505, 0.1544409166672267, 0.23699355020653456, 0.10002718336181715, 0.11237883620196953, 0.22792659845435992, 0.5091651971451938, 54.5002057403326, 96.28394544124603, 45.87230511009693, 73.17651137709618, 102.64451533555984, 15.312873367220163, 54.623303934931755, 78.03232401609421, 91.5159460902214, 21.462293341755867, 3.5179343540221453, 12.688594534993172, 4.487936804071069, 1.2689123419113457, 2.274530637077987, 76.02861553430557, 93.76927837729454, 90.38999050855637, 83.13860401511192, 84.75661799311638, 82.33813896775246, 71.5433894097805, 73.63941013813019, 65.25004550814629, 62.75198355317116, 67.29703366756439, 71.91798850893974, 69.21949490904808, 73.52575823664665, 66.99309557676315, 58.597157299518585, 55.854836851358414, 59.64432030916214, 64.33977395296097, 72.01898708939552, 64.14172857999802, 61.3788778334856, 56.91352464258671, 58.16608943045139, 56.790741831064224, 55.63055008649826, 55.157281681895256, 52.66671672463417, 51.79972864687443, 52.43532434105873, 53.36975499987602, 52.28834442794323, 53.62337239086628, 53.43472011387348, 58.17905433475971, 72.52845615148544, 68.17965790629387, 67.62456849217415, 67.96927839517593, 70.2907258272171, 65.78508719801903, 63.76898378133774, 69.92982119321823, 63.89262914657593, 57.48155616223812, 69.57488223910332, 56.68023996055126, 66.34383961558342, 65.59439063072205, 68.5480709373951, 67.08392590284348, 67.32076719403267, 60.823309645056725, 60.17754189670086, 61.39142856001854, 58.717603236436844, 57.34099790453911, 58.15275974571705, 54.030980318784714, 54.88799773156643, 51.91631019115448, 50.34577466547489, 52.009089812636375, 51.07335202395916, 50.4116403311491, 51.1473074555397, 53.1803959608078, 53.588467463850975, 50.622259229421616, 52.95884124934673, 50.08649177849293, 52.986659556627274, 52.59463079273701, 55.527419820427895, 53.613052144646645, 54.42883037030697, 52.46330983936787, 54.96612913906574, 49.33397635817528, 54.80107359588146, 53.59225586056709, 60.18960244953632, 65.20080775022507, 72.40182414650917, 69.94631230831146, 67.94406294822693, 66.98817104101181, 63.482080176472664, 62.26829990744591, 62.50193037092686, 64.93340849876404, 63.746128007769585, 65.32728776335716, 68.145642131567, 75.06010070443153, 75.17771199345589, 77.15144768357277, 78.4254053235054, 38.675179705023766, 1.0214624949730933, 0.7878949062433094, 14.090136028826237, 8.13971422612667, 16.051083505153656, 72.16684475541115, 50.62903806567192, 11.765955593436956, 52.465194538235664, 80.76670289039612, 73.7102535367012, 59.96059253811836, 74.99913677573204, 12.130622025579214, 0.46470217988826334, 0.23852881626226008, 0.13992048567160964, 0.11261460909736343, 0.2188249587197788, 0.1535458123544231, 0.11469847813714296, 0.08474555375869386, 0.08264582502306439, 0.09984601027099416, 0.17171617015264928, 0.16802710248157382, 0.12335091072600335, 0.24239963589934632, 0.06429224580642767, 0.1898941572289914, 0.15186735632596537, 0.0898682652041316, 0.1090815853967797, 0.11914934555534273, 0.1800081564579159], [0.047274064854718745, 0.020238274373696186, 0.05319470008544158, 0.04092272050911561, 0.07273841329151765, 0.053238794789649546, 0.03974976723839063, 0.03995923470938578, 0.08755496863159351, 0.06407733468222432, 0.05958102556178346, 0.04387604523799382, 0.09144630123046227, 0.023068124282872304, 0.07651144012925215, 0.042841339236474596, 0.13120154180796817, 0.0278930396962096, 0.10023408671258949, 0.03675858555652667, 0.047661247008363716, 0.03775120436330326, 0.15301582985557616, 0.01811539063055534, 0.2216971741290763, 0.24450332770356908, 0.8908511535264552, 5.644398098811507, 63.114848881959915, 58.32573026418686, 29.81070376932621, 62.0157540589571, 33.74354973435402, 11.855675429105759, 57.41157911717892, 71.37047588825226, 33.11234660446644, 0.6787967635318637, 6.6166015807539225, 4.289349960163236, 0.6983917183242738, 0.6300921645015478, 58.93319986760616, 96.54474824666977, 73.51986095309258, 77.1544799208641, 69.50454041361809, 69.64376494288445, 59.73773069679737, 63.041170835494995, 57.369249388575554, 64.99547436833382, 63.48020687699318, 69.88386645913124, 66.70836925506592, 69.21022340655327, 59.4168721139431, 53.961007073521614, 49.35421407222748, 52.998245134949684, 56.642177402973175, 61.35929748415947, 57.34037093818188, 60.76130457222462, 53.509439304471016, 50.99225677549839, 49.45347234606743, 48.67571488022804, 49.75310526788235, 48.348229452967644, 48.15333791077137, 48.34806986153126, 49.157342836260796, 48.845375776290894, 50.33657155930996, 47.71669574081898, 49.42658118903637, 59.43571910262108, 62.09602855145931, 63.918095380067825, 62.719377502799034, 61.416568011045456, 61.803075671195984, 60.37940986454487, 60.5903859436512, 60.302144810557365, 53.438607305288315, 64.95960429310799, 59.58270661532879, 63.27023774385452, 65.40038824081421, 63.66040460765362, 60.30588001012802, 58.33513095974922, 56.71823412179947, 56.569468304514885, 53.1283463537693, 55.12847542762756, 53.96621659398079, 51.025900170207024, 47.62034051120281, 46.98894739151001, 44.995528757572174, 45.243070274591446, 43.9570102840662, 44.87834684550762, 42.69453562796116, 45.601307451725006, 46.571015417575836, 48.001836240291595, 46.25038482248783, 47.57446937263012, 48.90592932701111, 51.29564769566059, 52.01336458325386, 52.747876569628716, 51.817219108343124, 49.363652765750885, 47.178310230374336, 47.98715382814407, 48.464586809277534, 47.670182436704636, 47.56872408092022, 51.540669947862625, 60.90120546519756, 68.06890904903412, 68.80499795079231, 66.74909546971321, 61.491754576563835, 60.111680030822754, 59.50766824185848, 59.78737123310566, 61.78028829395771, 63.511973172426224, 67.0801793038845, 71.3818296790123, 69.15521755814552, 71.53051570057869, 76.11760675907135, 55.771632716059685, 2.5035315239802003, 0.053750646620756015, 0.26954509725328535, 7.245636926963925, 1.4863103139214218, 12.202211134135723, 71.99080780148506, 21.725594513118267, 13.934447932988405, 49.107177928090096, 41.02886460721493, 52.25888080894947, 47.019197568297386, 32.91025064885616, 0.30922144011128694, 0.10848011923371814, 0.027889314114872832, 0.05425017137895338, 0.07300690747797489, 0.08509779188898392, 0.05567899119341746, 0.04820531547011342, 0.07136375541449524, 0.020436379563761875, 0.068407603102969, 0.05620290292426944, 0.05116157539305277, 0.02968510740174679, 0.019156560738338158, 0.030756865126022603, 0.04958312747476157, 0.009035982857312774, 0.042644621862564236, 0.06249022961128503, 0.0281957821425749, 0.012554621880553896, 0.04239026558934711, 0.03606942351325415, 0.01205530028528301, 0.01624392796657048, 0.06371418698108755, 0.04279486594896298, 0.02489112099283375, 0.0494337294367142, 0.08727304899366572, 0.016898487374419346, 0.053007994283689186, 0.007873611684772186, 0.007361435627899482, 0.05070377417723648, 0.03782560095714871, 0.0349537863075966, 0.13491085526766255, 0.046519419411197305, 0.08065989721217193, 0.0708102245698683, 0.0786305389192421, 0.030580608763557393, 0.06773148430511355, 0.022107137665443588, 0.14154192991554737, 0.2371853805379942, 0.670772009762004, 5.737742464989424, 77.0744714140892, 56.39303997159004, 39.85806003212929, 67.89580553770065, 18.738538697361946, 29.415401481091976, 63.34829695522785, 81.15187302231789, 37.377271950244904, 0.2332216440117918, 5.868902876973152, 9.991642702370882, 3.043921901844442, 0.7570966682396829, 62.92722634971142, 98.27088922262192, 76.13519981503487, 82.63155162334442, 73.243927359581, 72.7212730050087, 64.61009904742241, 66.57813504338264, 59.55045774579048, 65.74632167816162, 69.05728921294212, 71.82964324951172, 69.05624806880951, 73.01735311746597, 62.47859962284565, 55.3660424798727, 51.835192143917084, 55.67854531109333, 58.91181081533432, 63.99904623627663, 60.211238488554955, 61.8629452586174, 55.74177011847496, 53.62160928547382, 52.672173231840134, 51.86662405729294, 52.28356808423996, 51.11021384596825, 49.185845106840134, 51.73666723072529, 51.468758806586266, 50.151772275567055, 51.080199256539345, 50.5100816488266, 53.99054288864136, 63.82696866989136, 65.67512109875679, 69.66479301452637, 65.9057155251503, 65.38629099726677, 65.75430884957314, 63.91144573688507, 62.48266160488129, 64.76630866527557, 59.25268292427063, 65.11706784367561, 59.932895824313164, 65.03786489367485, 68.42952489852905, 66.32699131965637, 63.872011452913284, 60.070057064294815, 60.344558134675026, 58.62042725086212, 56.35865181684494, 57.14238256216049, 57.84483566880226, 54.30507481098175, 51.676220074296, 49.142208248376846, 47.09436133503914, 48.32291901111603, 46.828793585300446, 47.8787874430418, 46.10498942434788, 49.105452820658684, 49.57808665931225, 51.09088808298111, 50.32138757407665, 51.44856669008732, 51.67684704065323, 54.38919849693775, 56.946871653199196, 56.788469552993774, 54.558768197894096, 54.146478921175, 49.27223727107048, 51.34772390127182, 51.40408247709274, 51.802711486816406, 50.37575505673885, 54.701724126935005, 63.407820761203766, 70.03483235836029, 70.66976308822632, 70.01214757561684, 63.48191678524017, 63.66461098194122, 61.5921375900507, 61.980883330106735, 64.19931069016457, 66.90212845802307, 68.43887999653816, 73.90341237187386, 70.2247841656208, 74.33697670698166, 76.48283556103706, 55.75667291879654, 2.326202164404094, 0.35317160363774747, 1.904872222803533, 9.814243521541357, 0.954811874544248, 18.33322584629059, 71.28642439842224, 32.680917754769325, 17.037083096802235, 42.57066607475281, 52.95938462018967, 51.405028626322746, 56.5813160687685, 34.917489141225815, 0.5018244660459459, 0.055316478028544225, 0.024064138415269554, 0.09820849852985702, 0.0455646278714994, 0.011560703387658577, 0.02598806535388576, 0.04313294390158262, 0.06510474908282049, 0.021567501680692658, 0.0027149051493324805, 0.03991375218902249, 0.03862099030811805, 0.02166782520362176, 0.02877047903893981, 0.05830101377796382, 0.009155837851722026, 0.04247528973792214, 0.058213484880980104, 0.006369479651766596, 0.034714577268459834, 0.0426236042403616, 0.1739192652166821, 0.14452738221734762, 0.348739349283278, 0.12876256252638996, 0.1460629451321438, 0.2520486689172685, 0.15443532087374479, 0.21325190464267507, 0.23409228713717312, 0.1535079925088212, 0.14251890796003863, 0.23815049906261265, 0.1490500895306468, 0.2687487134244293, 0.2749266178580001, 0.1207433377567213, 0.2458230295451358, 0.16655747196637094, 0.19828716467600316, 0.12764067272655666, 0.4136491584358737, 0.3164009767351672, 0.40130973618943244, 0.27078902581706643, 0.44624098925851285, 0.7269346585962921, 0.9899107099045068, 12.788209039717913, 90.68230882287025, 76.08045235276222, 48.538530841469765, 96.6629447042942, 44.44431133568287, 23.307001255452633, 66.50336265563965, 90.10358467698097, 39.877119809389114, 0.41420199908316135, 16.434615924954414, 8.779054619371891, 4.007273521274328, 1.2068053870461881, 65.17645865678787, 102.9771114885807, 78.00941124558449, 86.93700939416885, 76.69636890292168, 77.34037354588509, 66.20852127671242, 70.6537127494812, 61.927955970168114, 70.5593030154705, 71.25257581472397, 76.62087455391884, 70.53355559706688, 78.5848219692707, 65.18870159983635, 58.909869119524956, 53.5034204274416, 61.57800234854221, 61.372790560126305, 67.83965215086937, 63.287131637334824, 65.77426537871361, 58.08872178196907, 58.32085132598877, 55.22092446684837, 54.601018130779266, 54.56546723842621, 53.76857779920101, 52.018973082304, 54.088391438126564, 54.06142808496952, 53.30282919108868, 54.237582832574844, 55.080104023218155, 57.03310802578926, 64.88443672657013, 67.1561448276043, 71.60824432969093, 66.85023084282875, 66.63162857294083, 67.62708395719528, 64.08041507005692, 64.04946193099022, 64.46248456835747, 56.201686039566994, 67.59575843811035, 61.28814250230789, 66.22415363788605, 71.76845893263817, 68.20025280117989, 65.16344055533409, 63.4346017241478, 62.340697422623634, 62.546802163124084, 58.685335367918015, 60.63159093260765, 59.30413596332073, 57.048941776156425, 54.4878526031971, 52.49765619635582, 49.67662297189236, 50.58635875582695, 48.98176185786724, 51.580286622047424, 48.30560714006424, 53.096097484230995, 54.12467189133167, 55.467858016490936, 52.10674837231636, 53.18883530795574, 54.7809536755085, 59.03520539402962, 60.53566128015518, 58.73527608811855, 57.09182247519493, 56.683165803551674, 49.94736984372139, 54.69317078590393, 54.4252585619688, 55.360023602843285, 53.94562549889088, 57.43843987584114, 66.54972016811371, 73.0581933259964, 73.27346697449684, 73.33090469241142, 65.72453364729881, 69.01153966784477, 62.957674115896225, 64.9125400185585, 66.51089385151863, 71.17269650101662, 71.05821624398232, 78.04321423172951, 71.39788761734962, 78.45562890172005, 77.72594645619392, 57.39007227122784, 3.3563416125252843, 0.40344973385799676, 1.1312263738363981, 22.970041036605835, 7.141770450398326, 15.923922378569841, 82.19440788030624, 29.53216351568699, 18.494848273694515, 76.55718237161636, 60.69029398262501, 65.66693633794785, 60.32888397574425, 60.23405246436596, 1.5724106063134968, 0.16929187055211514, 0.16210353205678985, 0.2388452086597681, 0.21481375442817807, 0.07476111451978795, 0.1409656967734918, 0.1645132410340011, 0.3447869676165283, 0.10827019534190185, 0.11510287440614775, 0.23090595030225813, 0.21425055339932442, 0.08158542957971804, 0.09963152217096649, 0.1565709843998775, 0.1470834278734401, 0.13042384525761008, 0.19123311038129032, 0.09652495878981426, 0.0967680047324393, 0.11716404114849865], [0.059984089675708674, 0.025437200674787164, 0.04099060475709848, 0.007166439572756644, 0.0303749355225591, 0.03231981514545623, 0.059155107010155916, 0.007107429555617273, 0.05485170062456746, 0.04745015794469509, 0.017394264286849648, 0.04285367744159885, 0.058868211272056215, 0.0702932222338859, 0.02516321088478435, 0.016334796528099105, 0.039799702644813806, 0.02966792853840161, 0.033524977625347674, 0.07625306883710437, 0.08779787356615998, 0.0921293294231873, 0.04646301247703377, 0.09005758707644418, 0.06037897532223724, 0.1357436488615349, 0.08682084357133135, 0.39285299309995025, 36.75144553184509, 64.50784653425217, 46.528275310993195, 55.56721888482571, 74.79746639728546, 13.22866715490818, 27.922904267907143, 78.38147208094597, 57.30619557201862, 2.635139599442482, 5.631572837010026, 7.49276521615684, 1.1724307690747082, 0.12240991200087592, 61.49148479104042, 88.9402163028717, 80.63031300902367, 73.72838616371155, 64.1126449406147, 63.96288737654686, 62.03917600214481, 59.9130342900753, 63.723078444600105, 66.28076300024986, 66.72340124845505, 67.98072338104248, 69.01299118995667, 65.17966568470001, 57.7473708987236, 54.05834265053272, 52.43749402463436, 55.75121261179447, 58.610475584864616, 57.88222946226597, 60.6950057297945, 55.77547810971737, 54.71860662102699, 49.46086674928665, 51.5447661280632, 48.20756480097771, 48.760001957416534, 49.77334678173065, 52.34063722193241, 50.590694323182106, 50.60519814491272, 48.15943658351898, 50.23309551179409, 48.54786314070225, 49.828025847673416, 58.13730597496033, 60.853461027145386, 62.301107347011566, 65.1303519308567, 65.24603292346, 63.36322255432606, 60.465878024697304, 63.54650191962719, 58.667989298701286, 57.57795698940754, 66.26153603196144, 61.13080434501171, 59.99187245965004, 62.613530382514, 63.645729795098305, 59.40228849649429, 60.67934677004814, 56.05666682124138, 56.420979872345924, 54.71926398575306, 55.473610907793045, 54.15149085223675, 50.03025099635124, 44.784966856241226, 44.90844503045082, 45.23760996758938, 44.76096734404564, 45.74307024478912, 46.58617660403252, 44.91518586874008, 45.41627638041973, 48.29471692442894, 48.824830278754234, 47.35516034066677, 49.23082709312439, 52.13563822209835, 54.18076828122139, 54.20420162379742, 53.759595081210136, 55.95941863954067, 53.82013723254204, 55.731826052069664, 50.44695943593979, 47.70052760839462, 45.56970074772835, 47.99717769026756, 47.31864430010319, 60.36355331540108, 64.74886760115623, 67.26409703493118, 63.51877100765705, 67.89868578314781, 59.946016520261765, 60.25944270193577, 58.02825942635536, 63.05461451411247, 62.52189829945564, 73.06495696306229, 66.92981377243996, 76.81526452302933, 67.60598748922348, 77.4959371984005, 14.557065423578024, 0.14961765438783914, 1.2640349473804235, 3.523702919483185, 3.9998814929276705, 1.7909010197035968, 31.175562031567097, 63.46099890768528, 13.569811899214983, 30.51033552736044, 53.84632542729378, 22.530210837721825, 29.135453402996063, 52.99120411276817, 5.650165239349008, 0.5349475261755288, 0.06782742173527367, 0.0811456996598281, 0.13133612286765128, 0.08613707323092967, 0.03132171186734922, 0.0372092064935714, 0.030245482703321613, 0.03210692266293336, 0.04340389830758795, 0.05859974306076765, 0.10008222103351727, 0.03612369306210894, 0.05799934559036046, 0.09008976659970358, 0.00880637628142722, 0.06791659820009954, 0.030994205808383413, 0.03994193895778153, 0.032655863324180245, 0.03694799277582206, 0.015338951234298293, 0.008078600294538774, 0.019668184359034058, 0.02227110406238353, 0.0061511347030318575, 0.09723465234856121, 0.08300172936287709, 0.03381707581866067, 0.06543158349813893, 0.022704560979036614, 0.03470183459285181, 0.06742761193891056, 0.02972660458908649, 0.039912438587634824, 0.05845740655786358, 0.02667312146513723, 0.04452129069250077, 0.03875406109727919, 0.09405591510585509, 0.051469726240611635, 0.040685823259991594, 0.03894509361998644, 0.04607632385159377, 0.01949920475453837, 0.005958477804597351, 0.07226260015158914, 0.04307037714170292, 0.12105869114748202, 0.3579578624339774, 41.882762387394905, 76.07371911406517, 40.62391273677349, 63.7251303344965, 39.75061699748039, 16.93407442420721, 51.14638030529022, 76.8716610968113, 63.29885020852089, 2.063179803080857, 5.3890845738351345, 12.08965452387929, 2.857680832967162, 0.12922802270622924, 65.51868349313736, 92.98424050211906, 84.94425192475319, 76.76058545708656, 67.57151573896408, 68.38461890816689, 62.83092811703682, 63.84497210383415, 65.62637731432915, 71.53645858168602, 71.34369492530823, 72.2940543293953, 70.46968102455139, 67.9486683011055, 58.9695031195879, 55.62379024922848, 54.187383726239204, 58.55117976665497, 61.85348376631737, 61.76986165344715, 63.89053165912628, 58.15944358706474, 57.3367041349411, 52.76817888021469, 52.89614461362362, 50.69711521267891, 53.959259167313576, 52.96817734837532, 53.81602965295315, 52.44597136974335, 52.294146716594696, 50.241519659757614, 54.22157049179077, 51.413285583257675, 53.07390667498112, 60.204345658421516, 65.94803765416145, 67.83208295702934, 66.2777991592884, 68.20044279098511, 65.14666825532913, 64.17590394616127, 66.41700848937035, 62.05166973173618, 64.01410862803459, 67.15873628854752, 65.81002905964851, 62.56772384047508, 66.29207119345665, 68.92609745264053, 63.95794004201889, 64.2306438088417, 60.79008802771568, 58.3735278993845, 58.28993998467922, 59.61862988770008, 57.15201124548912, 54.69855509698391, 48.62795144319534, 48.93401362001896, 47.11586058139801, 48.08387763798237, 49.48070928454399, 49.184199795126915, 48.83931890130043, 49.20129507780075, 51.04912452399731, 50.85136413574219, 49.719093292951584, 51.79483450949192, 53.91049638390541, 57.94866129755974, 58.06789889931679, 56.755293533205986, 58.55559892952442, 57.496360167860985, 58.80172312259674, 53.07212837040424, 51.23933091759682, 49.24475334584713, 52.63490863144398, 51.34821407496929, 62.70655319094658, 68.35989743471146, 68.76737996935844, 65.91671213507652, 69.65948849916458, 62.10702896118164, 63.39247338473797, 61.31346054375172, 64.9839685857296, 63.060207813978195, 72.87476196885109, 70.61010628938675, 79.43309605121613, 70.16164675354958, 77.78591483831406, 14.631797913461924, 0.26627587736584246, 1.700279088690877, 6.278751734644175, 3.816123828291893, 1.7831923021003604, 37.14328050613403, 63.46497729420662, 19.365966729819775, 18.93856566399336, 56.941460743546486, 28.41235790401697, 36.68103151023388, 64.75184664130211, 7.937351809814572, 0.420284730498679, 0.09114070708164945, 0.05471820681123063, 0.11490220509585924, 0.06985724758123979, 0.06269319215789437, 0.011051077071897453, 0.08342885761521757, 0.00450672562692489, 0.03447957991738804, 0.057392458038521, 0.021251695579849184, 0.015952720350469463, 0.023423600032401737, 0.02735687325184699, 0.026795911653607618, 0.04813685605768114, 0.02460175019223243, 0.04543611386907287, 0.05834711228089873, 0.037291814951458946, 0.028252432130102534, 0.103245684877038, 0.12300340007641353, 0.12395957572152838, 0.13075102848233655, 0.20599280978785828, 0.21657208038959652, 0.10865697302506305, 0.09058460098458454, 0.15296340454369783, 0.11829605384264141, 0.1405402977252379, 0.12439336103852838, 0.15780385496327654, 0.12999464641325176, 0.11832950985990465, 0.09564674575813115, 0.17549347918247804, 0.13301726547069848, 0.13464792718878016, 0.17200139234773815, 0.24478396342601627, 0.12491875706473365, 0.2111470847739838, 0.3370082506444305, 0.12823783443309367, 0.2546397439436987, 0.4356685612583533, 0.4658980172825977, 59.15362223982811, 90.35358846187592, 61.061047688126564, 82.45441272854805, 105.92376977205276, 17.828219644725323, 41.737207397818565, 84.1225916147232, 72.23722457885742, 3.1116475677117705, 12.260275818407536, 19.205562137067318, 4.495480349287391, 0.6456905649974942, 71.92785277962685, 94.67425301671028, 90.71123287081718, 79.39089551568031, 71.01717084646225, 70.1795893907547, 68.00301298499107, 66.1357019841671, 69.87998306751251, 74.51843976974487, 72.73595541715622, 76.22731447219849, 73.33794191479683, 72.03318312764168, 62.732935175299644, 60.11448048055172, 57.27227479219437, 61.583268865942955, 64.97432470321655, 63.36327575147152, 66.90503910183907, 61.35216906666756, 59.9276103079319, 54.10802498459816, 57.80039705336094, 51.42970070242882, 55.962766259908676, 56.961364075541496, 57.56118468940258, 54.97464068233967, 55.20553909242153, 53.20271976292133, 57.563031390309334, 54.465502202510834, 55.82598879933357, 63.689207062125206, 67.9401795566082, 68.17023441195488, 69.22589376568794, 70.3321436047554, 68.85497286915779, 64.66236904263496, 65.63753351569176, 63.01565520465374, 62.81130596995354, 70.59072732925415, 66.99458509683609, 61.64371982216835, 67.63856694102287, 70.22619009017944, 66.2217065691948, 65.88884443044662, 63.725985288619995, 60.77153742313385, 61.679183319211006, 60.859943479299545, 61.957499384880066, 56.16061024367809, 49.08060595393181, 51.457336619496346, 51.12694434821606, 49.964309334754944, 51.83384321630001, 51.41438752412796, 50.78396715223789, 53.07356469333172, 56.01352773606777, 55.20367719233036, 53.10882680118084, 54.13452856242657, 56.72087877988815, 59.978816360235214, 60.91887831687927, 58.23327362537384, 62.76804909110069, 59.581270292401314, 62.48966462910175, 55.57161144912243, 54.61544595658779, 50.086506977677345, 54.818450063467026, 54.44779895246029, 65.9375274181366, 69.93470013141632, 69.56261649727821, 68.13598304986954, 73.20439428091049, 64.04708325862885, 65.0105519592762, 61.681102216243744, 68.7397326529026, 66.77623361349106, 77.1031978726387, 72.39841192960739, 81.79697960615158, 71.54822275042534, 80.27076870203018, 17.101558037102222, 0.3090633626561612, 2.0613485388457775, 9.216363653540611, 15.703660547733307, 3.676409125328064, 38.43095161020756, 73.24775755405426, 19.57922838628292, 44.98230166733265, 78.37209418416023, 34.43526841700077, 43.9776773750782, 74.5194961130619, 18.34315851330757, 1.1507893865928054, 0.3308439423562959, 0.20631056773709133, 0.2567949704825878, 0.2149107976583764, 0.14062246831599623, 0.12177527925814502, 0.12443342217011377, 0.0937382981646806, 0.205678332131356, 0.11855980570544489, 0.09741417045006528, 0.13571301300544292, 0.15069817687617615, 0.2579038281692192, 0.1416762438020669, 0.17334104311885312, 0.10521826887270436, 0.06763913144823164, 0.13174164720112458, 0.1349802312324755, 0.07234812524984591], [0.06419960351195186, 0.049557508536963724, 0.16478967620059848, 0.042296079627703875, 0.016553032473893836, 0.06834566345787607, 0.15000314073404297, 0.013143032738298643, 0.027271029030089267, 0.006156753224786371, 0.00235046332818456, 0.0473593487549806, 0.036882257045363076, 0.07902642275439575, 0.04575292186927982, 0.07062043514451943, 0.0245516719223815, 0.011851588169520255, 0.02909986458689673, 0.1103286309808027, 0.03559204073098954, 0.12553614971693605, 0.1438203826546669, 0.1718530963989906, 0.02316070720553398, 0.118466562271351, 0.10212688241153955, 0.9264811291359365, 4.931670818477869, 70.64812704920769, 54.16167430579662, 93.14276039600372, 102.43706166744232, 43.19443680346012, 10.916197691112757, 64.25313860177994, 88.3501535654068, 10.683822110295296, 1.2166317785158753, 14.789167419075966, 1.7079374589957297, 0.2237349929055199, 49.7522047162056, 98.5321556031704, 77.73374363780022, 87.12702959775925, 78.21757927536964, 72.43745863437653, 67.0265793800354, 65.83465933799744, 69.12194654345512, 70.58462485671043, 72.00821086764336, 68.5901726782322, 67.50504970550537, 61.32866732776165, 58.66162084043026, 53.19039322435856, 53.75164970755577, 55.782317742705345, 57.620408311486244, 59.15929153561592, 60.20547799766064, 58.94546560943127, 54.81473006308079, 49.10651296377182, 51.997975409030914, 49.35850404202938, 54.317564740777016, 49.27232086658478, 52.60959438979626, 50.08434869349003, 51.331985145807266, 50.58830425143242, 48.61188590526581, 48.53014849126339, 48.02325949072838, 53.38577874004841, 61.84980556368828, 60.791034176945686, 63.87891948223114, 63.409602865576744, 64.77633252739906, 63.16763184964657, 64.56266239285469, 58.298261538147926, 58.82428251206875, 67.24261298775673, 63.02624523639679, 46.525265872478485, 65.17558470368385, 63.712017238140106, 62.35197901725769, 60.09175010025501, 56.193926855921745, 57.15791612863541, 53.2889561355114, 54.881279692053795, 54.80619952082634, 51.21902100741863, 46.80269278585911, 44.53218922019005, 44.79170769453049, 45.376978889107704, 45.86997963488102, 44.20031122863293, 45.23835852742195, 47.238343209028244, 48.125455006957054, 48.95835131406784, 52.13141664862633, 52.05386281013489, 54.06621962785721, 56.17180824279785, 55.128426030278206, 57.49343432486057, 57.52951338887215, 57.57508434355259, 56.94025620818138, 57.5586312264204, 53.19020323455334, 49.04067389667034, 49.92190361022949, 48.3829215914011, 57.8013925999403, 66.16176098585129, 67.23055243492126, 70.84988862276077, 65.78183457255363, 65.69054067134857, 61.91857047379017, 61.08060143887997, 60.84013134241104, 63.88287127017975, 68.29779356718063, 75.05194634199142, 68.9241823554039, 77.35570192337036, 43.18708039820194, 0.12111985895899124, 0.7578104955609888, 0.13677953858859837, 4.433241114020348, 2.048324500210583, 1.170446800533682, 45.347283482551575, 46.07573479413986, 35.50405986607075, 58.41737374663353, 33.76902736723423, 35.93012720346451, 53.354312628507614, 37.55721889436245, 0.5295664805453271, 0.09776829363545403, 0.06088451889809221, 0.02389485638559563, 0.04750879503262695, 0.038360964026651345, 0.03185811023286078, 0.04500654395087622, 0.04763136814290192, 0.04157450057391543, 0.03733896359335631, 0.009036170249601128, 0.07952182859298773, 0.003420301441110496, 0.035500964368111454, 0.006624086863666889, 0.0776897554169409, 0.042088756963494234, 0.009530595525575336, 0.009065683607332176, 0.041187233073287643, 0.02627230791404145, 0.005169072946955566, 0.016189721500268206, 0.04102075821720064, 0.02953239752969239, 0.008075703135546064, 0.01966069237823831, 0.05864162987563759, 0.024650826562719885, 0.042512018626439385, 0.062246215165941976, 0.06964695261558518, 0.014537316710629966, 0.05304392907419242, 0.05684948424459435, 0.08929905277909711, 0.02347284524148563, 0.11833854179712944, 0.035831683926517144, 0.05490675684995949, 0.06559845540323295, 0.07103243100573309, 0.01585825979418587, 0.12355058555840515, 0.0700353184947744, 0.07167618474340998, 0.04375127537059598, 0.1297084297402762, 0.13052284775767475, 0.8430246636271477, 6.9369410164654255, 84.45098519325256, 58.14341604709625, 94.65894743800163, 117.14797988533974, 25.372844003140926, 23.045632280409336, 73.9565259218216, 87.97853350639343, 14.02845298871398, 1.3129473477602005, 13.194863218814135, 5.583217106759548, 0.41181516309734434, 57.9307946562767, 99.94554296135902, 79.72127258777618, 92.0727302134037, 78.8330702483654, 75.31813725829124, 70.04195317626, 69.78044360876083, 71.37106865644455, 75.1050066947937, 74.95412439107895, 71.15568101406097, 69.68544870615005, 65.03544062376022, 59.383167922496796, 57.135086953639984, 57.81499586999416, 58.547360971570015, 60.97193107008934, 60.14060027897358, 62.13179603219032, 62.040076553821564, 57.191829308867455, 51.78552880883217, 52.70115427672863, 52.517221346497536, 56.343999803066254, 51.099844202399254, 53.55705074965954, 53.27254481613636, 53.18649463355541, 51.57662361860275, 52.56603732705116, 52.25296452641487, 52.19153322279453, 56.68394096195698, 64.42526176571846, 64.23368364572525, 68.20175752043724, 66.3078935444355, 65.91439425945282, 64.05889302492142, 66.31116136908531, 62.71185390651226, 63.10903139412403, 68.61515253782272, 65.47631576657295, 51.87624514102936, 66.45328134298325, 67.926454693079, 65.64865931868553, 62.82889902591705, 60.611630603671074, 60.11922262609005, 57.374728694558144, 58.56408387422562, 56.684693321585655, 53.0359923094511, 48.4854818880558, 48.02124559879303, 47.95059598982334, 48.08334946632385, 47.87066347897053, 48.808985128998756, 49.090679213404655, 51.51159010827541, 50.2840431779623, 52.49477215111256, 55.302509889006615, 55.95197483897209, 57.82144412398338, 59.23471748828888, 57.988156378269196, 60.96816547214985, 61.72072269022465, 61.87828503549099, 59.632396548986435, 60.542979687452316, 57.06621564924717, 51.04905992746353, 52.19883643090725, 52.81215772032738, 59.53976511955261, 67.98608109354973, 70.0555032491684, 73.4692856669426, 67.26832240819931, 67.35343784093857, 65.2342839539051, 62.42589645087719, 63.23716811835766, 65.5705963075161, 71.34020671248436, 76.72989830374718, 69.95787888765335, 75.61838194727898, 42.54529483616352, 0.06119264377048239, 0.7809484633617103, 2.151378057897091, 6.287699304521084, 2.2634406946599483, 1.5533733903430402, 49.483319744467735, 54.791642501950264, 30.8206382766366, 46.24165289103985, 40.769608318805695, 36.99501246213913, 65.5498418211937, 42.31943495571613, 0.7847997942008078, 0.05053604509157594, 0.08253377556684427, 0.0344339526782278, 0.06859774133772589, 0.01828311971621588, 0.018732725766312797, 0.06485261183115654, 0.017861676315078512, 0.011612714024522575, 0.0675832551496569, 0.02509505946363788, 0.01960420937393792, 0.08334732527146116, 0.05158855150511954, 0.03951765684178099, 0.06445064238505438, 0.032038236895459704, 0.02742212102020858, 0.012726070053759031, 0.02896142064855667, 0.006826696426287526, 0.016488330184074584, 0.16733473807107657, 0.11381811287719756, 0.18040039634797722, 0.11339936347212642, 0.10627670504618436, 0.1512704321066849, 0.32127587764989585, 0.1408814184833318, 0.19549048505723476, 0.1382658228976652, 0.13238312996691093, 0.1709171145921573, 0.2125694404821843, 0.17064393003238365, 0.20886790473014116, 0.23830020509194583, 0.25162211211863905, 0.1501193907461129, 0.38587021466810256, 0.23956335528055206, 0.11515837963088416, 0.2573787735309452, 0.24905837781261653, 0.24657181202201173, 0.15600579441525042, 0.39269877481274307, 0.5809870432130992, 1.23593854252249, 15.094603579491377, 96.98809325695038, 78.63023713231087, 103.09564992785454, 129.868124127388, 59.114180356264114, 19.86745622009039, 76.70860424637794, 101.41215026378632, 14.006030391901731, 4.839918566867709, 35.171418115496635, 7.609811760485172, 0.7746844401117414, 59.81677405536175, 102.67438933253288, 83.56877893209457, 94.59983021020889, 84.62091207504272, 79.3974007666111, 73.87277081608772, 73.41327667236328, 74.2083004117012, 78.69790390133858, 79.41440865397453, 74.64953273534775, 72.18073680996895, 68.4012620151043, 63.39424788951874, 59.019432440400124, 61.28544084727764, 62.04244002699852, 65.16116067767143, 64.08365249633789, 65.51742196083069, 64.95719522237778, 62.52273045480251, 54.168373346328735, 58.82748953998089, 54.196689426898956, 63.123269230127335, 53.32049824297428, 59.2267607152462, 55.57305917143822, 56.76991514861584, 55.62522657215595, 55.48096351325512, 53.76322768628597, 55.2043991535902, 58.93135316669941, 68.80609229207039, 66.0321119427681, 69.74154129624367, 66.72862216830254, 68.62248614430428, 64.17016625404358, 69.76396769285202, 64.00951087474823, 63.216447830200195, 69.90018278360367, 67.6387569308281, 53.92301671206951, 67.40444630384445, 70.06117254495621, 67.35447898507118, 64.80192795395851, 61.665530651807785, 63.265609592199326, 59.20056112110615, 59.339519664645195, 58.689374551177025, 56.72205291688442, 52.52665624022484, 49.823667481541634, 49.862034022808075, 51.016176491975784, 52.008516043424606, 50.74728012084961, 52.44448944926262, 53.6780970543623, 52.95146204531193, 56.445898935198784, 57.68136844038963, 58.410484716296196, 59.85572196543217, 62.015662863850594, 60.984652787446976, 62.61769875884056, 64.37517285346985, 64.67417120933533, 62.707252353429794, 62.56007105112076, 57.204729616642, 53.57806742191315, 55.60020871460438, 54.79178689420223, 62.71635286509991, 69.66980114579201, 71.61749303340912, 75.50386369228363, 70.11186182498932, 70.44950410723686, 67.24410250782967, 64.57366660237312, 66.39367014169693, 67.27947860956192, 73.25279608368874, 77.53029495477676, 72.20732778310776, 76.781195551157, 47.87301555275917, 0.16097074752906337, 1.2654414656572044, 1.2933749542571604, 14.468892104923725, 9.061465915292501, 1.8303149985149503, 54.48663666844368, 59.55406375229359, 41.85672998428345, 86.23389512300491, 50.73153756558895, 52.107626125216484, 70.36650896072388, 63.50378081202507, 2.007820811122656, 0.22050047584343702, 0.1682957450975664, 0.17646573716774583, 0.1260124600958079, 0.1828683787607588, 0.09112374158576131, 0.11445158044807613, 0.09587617329088971, 0.23659697617404163, 0.11838365695439279, 0.0923651023185812, 0.15122600714676082, 0.13284112414112315, 0.26602844533044845, 0.217179364990443, 0.22216812620172277, 0.19177844049409032, 0.11552245501661673, 0.20358275942271575, 0.11490076532936655, 0.17797486478229985, 0.03771251249418128], [0.043468212825246155, 0.06105580287112389, 0.05801679348223843, 0.015835002741368953, 0.041057535345316865, 0.02454851222864818, 0.04893254968919791, 0.01702785670204321, 0.060170687866047956, 0.018234332783322316, 0.033825380451162346, 0.02360689566557994, 0.06210107334482018, 0.02785329954349436, 0.04192672757199034, 0.02112632086209487, 0.04160661330388393, 0.04112352711672429, 0.04645720146072563, 0.0360446914419299, 0.051772214501397684, 0.05005667335353792, 0.05402415030403063, 0.09946960781235248, 0.04119048739084974, 0.01540154304166208, 0.11304958927212283, 0.07084223339916207, 0.2946627588244155, 43.087525740265846, 57.79970549046993, 37.95878514647484, 33.17160062491894, 76.80792331695557, 22.991420589387417, 20.444783940911293, 87.77984216809273, 13.773880898952484, 1.1822103755548596, 7.308792388066649, 2.730428036302328, 0.3451942285755649, 19.949026443064213, 93.52612182497978, 85.20594388246536, 86.9313856959343, 79.88444343209267, 78.62471982836723, 68.06835427880287, 66.73809885978699, 67.2013472020626, 70.20789787173271, 68.9291524887085, 67.30924621224403, 59.058194160461426, 55.71310445666313, 56.32610276341438, 56.5400692820549, 55.02801641821861, 56.07501603662968, 59.4294760376215, 63.159697875380516, 60.89619733393192, 58.389893621206284, 54.22107271850109, 50.17867103219032, 52.146840021014214, 53.51029805839062, 54.55458842217922, 58.78017447888851, 57.94238783419132, 56.28705605864525, 52.06428565084934, 50.12772336602211, 49.62392359972, 49.93209846317768, 51.22416593134403, 51.870378255844116, 57.04388804733753, 63.43225724995136, 66.01730033755302, 69.19964477419853, 63.49468030035496, 64.13346782326698, 63.61697293817997, 59.75221551954746, 70.677719861269, 64.28325578570366, 64.62101206183434, 48.033374547958374, 64.32601869106293, 62.9294416308403, 63.15845534205437, 60.68167224526405, 58.449862003326416, 56.67522422969341, 57.17567637562752, 58.27977553009987, 57.42987133562565, 54.36446562409401, 48.18297252058983, 47.276846542954445, 46.861327439546585, 45.11426478624344, 46.6465325653553, 45.65197013318539, 48.342210575938225, 45.76520025730133, 50.51905296742916, 56.810181587934494, 60.37908308207989, 60.121430307626724, 57.42218054831028, 55.39815075695515, 57.910515144467354, 57.65351593494415, 59.49715420603752, 59.79122802615166, 59.180475398898125, 60.1094039529562, 60.18299080431461, 52.73102827370167, 50.1811408996582, 48.44455428421497, 53.73988553881645, 62.93031558394432, 67.3400853574276, 69.19828444719315, 70.83304032683372, 66.04070708155632, 63.80844086408615, 61.84491902589798, 62.057578414678574, 65.22067308425903, 72.89211183786392, 71.91338315606117, 78.92355859279633, 53.898975402116776, 1.2930257292464375, 0.1543037232477218, 0.1604995728121139, 2.120900605805218, 3.792136190459132, 1.3707219413481653, 2.5813105003908277, 53.70297811925411, 22.33265943825245, 33.857235834002495, 53.45243476331234, 30.95903255045414, 41.43557198345661, 57.2428035736084, 12.218880839645863, 0.6113012821879238, 0.07088903323165141, 0.05292659181577619, 0.019200345595891122, 0.10322180998628028, 0.06424956489354372, 0.07183179084677249, 0.018141618129448034, 0.025889426506182645, 0.0747843214776367, 0.05432654950709548, 0.0437149954814231, 0.09034407092258334, 0.013471928468788974, 0.013497081708919723, 0.028897085721837357, 0.03550205903593451, 0.011995879303867696, 0.04346754118159879, 0.04756346905196551, 0.1390507331234403, 0.02586108759714989, 0.12296727232751437, 0.07909010644652881, 0.012069555086782202, 0.046637287305202335, 0.019907231981051154, 0.012442680963431485, 0.04029369098134339, 0.0413059136189986, 0.024847735039656982, 0.04434914582816418, 0.04486461191845592, 0.03883567507728003, 0.03222271254344378, 0.06542600996908732, 0.060774528901674785, 0.007005252055023448, 0.05579856602707878, 0.053966344421496615, 0.08732102141948417, 0.06814464533817954, 0.08035434759221971, 0.06536038927151822, 0.06639230108703487, 0.04443179139343556, 0.05877378040167969, 0.09264944135793485, 0.11731830396456644, 0.023175976893980987, 0.2271616816869937, 0.4474123060936108, 48.38475689291954, 69.65142533183098, 40.11356212198734, 64.45578172802925, 62.081110551953316, 19.44933995604515, 41.31587840616703, 92.21437901258469, 19.06896896660328, 2.1058887988328934, 15.92049591243267, 10.596889425069094, 0.3774762572720647, 23.198741264641285, 99.31783944368362, 89.17458772659302, 90.74107646942139, 82.5709980726242, 84.78734314441681, 73.57119619846344, 70.60784161090851, 70.93561962246895, 71.8025355041027, 73.22431281208992, 70.20830065011978, 62.752606719732285, 57.84483186900616, 58.79518747329712, 58.91630977392197, 57.204581424593925, 58.369735702872276, 62.0180681347847, 65.57932823896408, 62.51668497920036, 60.604711174964905, 56.2648918479681, 52.62874536216259, 53.92468862235546, 55.6642010807991, 57.7875005453825, 60.20426966249943, 58.50566200911999, 58.55812959372997, 54.29711043834686, 54.57393318414688, 53.63434620201588, 53.87955464422703, 53.947871178388596, 56.25376224517822, 62.843915820121765, 65.60410290956497, 70.6124621629715, 71.92734360694885, 68.31454306840897, 66.60601794719696, 66.28587752580643, 65.61092734336853, 72.57183462381363, 68.17577451467514, 68.7904067337513, 51.40067405998707, 67.57245048880577, 67.11809366941452, 68.94804507493973, 62.60895922780037, 61.284939274191856, 59.596218690276146, 61.2190356105566, 62.967963963747025, 60.21397814154625, 56.775915026664734, 52.87567511200905, 49.33831572532654, 49.53077919781208, 49.43721301853657, 49.871845096349716, 49.15138095617294, 50.35266749560833, 48.82535085082054, 54.19629044830799, 61.35856032371521, 64.60791796445847, 62.98811428248882, 59.83535885810852, 60.871373265981674, 61.46277353167534, 61.068354696035385, 61.826554611325264, 63.342433869838715, 62.60145843029022, 62.9812328517437, 63.13093721866608, 54.647691026329994, 54.186019599437714, 52.025501132011414, 58.07875111699104, 67.04503118991852, 70.33260717988014, 71.23017981648445, 74.38155591487885, 69.24236968159676, 66.25079780817032, 62.89906986057758, 63.66664007306099, 68.29774037003517, 74.30903300642967, 71.61661148071289, 78.68198275566101, 55.004852861166, 1.3743068114854395, 0.43862079503014684, 0.8464052353519946, 6.21071258559823, 5.649722563102841, 1.6858010343275964, 3.064521071501076, 57.41552330553532, 28.056867979466915, 37.3638054728508, 62.67006374895573, 39.33028355240822, 44.88919526338577, 66.14494308829308, 10.600862111896276, 0.46740386460442096, 0.218051447882317, 0.04550496661977377, 0.05930777049798053, 0.036273124496801756, 0.045999463327461854, 0.04932887139148079, 0.08168394226231612, 0.0738258971250616, 0.020847085943387356, 0.05948331439867616, 0.01946032549312804, 0.03371897131728474, 0.02793705276417313, 0.08350552889169194, 0.015815641963854432, 0.011683621596603189, 0.023323862806137186, 0.029919203043391462, 0.06584855917026289, 0.018948731558339205, 0.04901150306977797, 0.13340147532289848, 0.1653363718651235, 0.11550483643077314, 0.15620227059116587, 0.19592818891396746, 0.13685724145034328, 0.1607370303827338, 0.18152909906348214, 0.1254057840560563, 0.15838580264244229, 0.12401911080814898, 0.11433302235673182, 0.1362573486403562, 0.15757104323711246, 0.14464271196629852, 0.22831989219412208, 0.22699625696986914, 0.1478740229504183, 0.1938134984811768, 0.2052392775658518, 0.19126432511257008, 0.2130775444675237, 0.19698846561368555, 0.2161450040875934, 0.1530609227484092, 0.2182352778618224, 0.23477751208702102, 0.19895555771654472, 0.4202139296103269, 0.8899152756202966, 70.56048095226288, 83.1230628490448, 55.40566675364971, 60.85295185446739, 104.89144876599312, 30.24193312972784, 34.696044623851776, 101.1841168999672, 19.57431335002184, 4.0531565342098475, 12.544393222779036, 4.288829863071442, 0.4104001249652356, 26.043857596814632, 100.00226631760597, 90.2910590171814, 95.01637145876884, 84.96962696313858, 89.13098126649857, 75.24202734231949, 75.21969214081764, 72.94074162840843, 77.405646443367, 76.2418980896473, 75.62145978212357, 65.00865966081619, 60.76313607394695, 61.682800725102425, 63.12882073223591, 58.94526042044163, 62.09358908236027, 65.23420795798302, 72.82422468066216, 66.72896414995193, 65.2286222577095, 60.36178261041641, 54.68985736370087, 55.69703131914139, 59.2408237606287, 57.56704017519951, 64.12411272525787, 62.65693545341492, 61.47012993693352, 56.62735439836979, 56.75782039761543, 57.11412347853184, 56.36271759867668, 56.17183104157448, 59.1378340870142, 63.64019349217415, 68.36564272642136, 72.72971615195274, 76.79884180426598, 67.94568166136742, 68.59527960419655, 69.45231601595879, 66.26451507210732, 75.23994505405426, 69.33065414428711, 70.11772111058235, 55.698247253894806, 69.83071491122246, 68.79559725522995, 70.3654146194458, 66.74090310931206, 62.568650990724564, 64.52344089746475, 63.95268872380257, 66.46474152803421, 64.06686499714851, 59.0071476995945, 54.21428628265858, 53.95086161792278, 53.23552340269089, 51.97460666298866, 53.49078990519047, 52.00801447033882, 55.49061879515648, 51.07633866369724, 56.92923679947853, 64.89425539970398, 68.08096200227737, 67.33215898275375, 64.58932176232338, 63.71127627789974, 64.86660808324814, 63.63119177520275, 65.08231490850449, 69.02997627854347, 66.65410056710243, 67.30499804019928, 66.38706609606743, 58.59151840209961, 57.82751999795437, 54.54265706241131, 60.36847025156021, 70.3021252155304, 71.84674233198166, 74.52144920825958, 75.94186618924141, 70.7947687804699, 66.84571668505669, 64.30247515439987, 66.38264313340187, 70.08307456970215, 75.48669621348381, 74.83153536915779, 81.38117551803589, 57.77570977807045, 2.273799176327884, 0.8236813265830278, 0.6252332346048206, 8.464611042290926, 14.927483797073364, 7.939784629270434, 2.5926483795046806, 65.73931485414505, 31.204332187771797, 49.941328167915344, 68.98928806185722, 50.33104285597801, 55.46320706605911, 74.15133386850357, 21.309824623167515, 1.1156947072595358, 0.36482563766185194, 0.15098286472493783, 0.2724331500940025, 0.17422492615878582, 0.20227135479217395, 0.17031683586537838, 0.22036291135009378, 0.17144911573268473, 0.17016689234878868, 0.12555900786537677, 0.23773004271788523, 0.2320074607268907, 0.13609556044684723, 0.18834489426808432, 0.0815705866261851, 0.13742342591285706, 0.11162952680024318, 0.09775178084964864, 0.21397683449322358, 0.13992628926644102, 0.11199031447176822, 0.32682838907931], [0.0018668490565687534, 0.015597799356328323, 0.03473665245110169, 0.10217793475021608, 0.027595117499004118, 0.01566466315125581, 0.03995930150267668, 0.008679452330397908, 0.02117061409080634, 0.008775326678005513, 0.012011343806079822, 0.020842722115048673, 0.0019662233262351947, 0.008799087463557953, 0.06000143737765029, 0.0032086455621538335, 0.049863878230098635, 0.10448926463141106, 0.062255599623313174, 0.05250197573332116, 0.06575190927833319, 0.11262014551903121, 0.07098819158272818, 0.01775889628333971, 0.0611315798596479, 0.037181969673838466, 0.17786695651011541, 0.23726899089524522, 1.0636377381160855, 19.157884195446968, 64.9674242734909, 51.01265788078308, 52.77232065796852, 51.328519731760025, 67.43644818663597, 20.1817449554801, 65.92473730444908, 29.127952605485916, 0.1902119893929921, 13.440083060413599, 13.419977389276028, 0.10336654362617992, 1.3928938703611493, 70.71110486984253, 94.16888773441315, 85.69120824337006, 85.76778933405876, 83.09756621718407, 78.58607590198517, 73.14198642969131, 72.46738582849503, 69.27675783634186, 66.12065479159355, 62.548158690333366, 58.93407002091408, 63.795513957738876, 63.035220354795456, 59.02936890721321, 56.98008947074413, 59.63506780564785, 59.27861653268337, 60.667901784181595, 60.42434625327587, 60.223834812641144, 54.18407790362835, 52.09901958703995, 53.90360355377197, 55.55021859705448, 57.49211199581623, 59.30283263325691, 60.55415488779545, 64.02857825160027, 63.87559086084366, 56.72296106815338, 48.79814051091671, 49.606072157621384, 49.637029096484184, 50.204467847943306, 53.66822138428688, 61.54998645186424, 64.9920317530632, 68.72727692127228, 64.59641978144646, 68.41175705194473, 57.44429536163807, 66.65686681866646, 66.89971178770065, 65.99934250116348, 64.96247693896294, 49.30560328066349, 66.48399129509926, 63.91439437866211, 68.03241580724716, 60.324483811855316, 59.74537208676338, 59.42036032676697, 59.76998336613178, 61.083310693502426, 62.388411462306976, 57.53639481961727, 49.50231492519379, 46.843331605196, 47.15514287352562, 46.988738402724266, 46.17666497826576, 45.123403295874596, 45.805257707834244, 49.70628418028355, 62.13608220219612, 67.58726969361305, 68.34075406193733, 61.99995070695877, 62.455417066812515, 59.24818396568298, 59.84755240380764, 58.61945450305939, 59.69333007931709, 61.234352588653564, 63.034996166825294, 63.73090982437134, 64.65320393443108, 59.56375703215599, 51.51825115084648, 48.27326327562332, 53.53432796895504, 62.1498716622591, 69.65886533260345, 69.44046825170517, 70.7408344745636, 69.1325631737709, 70.64837783575058, 65.21003365516663, 67.18543365597725, 69.88062143325806, 72.65784680843353, 75.25765210390091, 58.950618132948875, 3.2819169061258435, 0.32072612433694303, 0.4093796422239393, 1.1849159491248429, 3.3833030657842755, 3.583500310778618, 1.2812420865520835, 6.931099304929376, 46.14700756967068, 18.73490609228611, 38.12189519405365, 29.20415371656418, 41.5986592322588, 57.35538773238659, 36.124007999897, 0.03394956402189564, 0.19715160451596603, 0.04407263273606077, 0.04235668711771723, 0.037956638261675835, 0.08657690705149435, 0.0834439232130535, 0.06947950183530338, 0.040854346443666145, 0.026655376714188606, 0.03233108094718773, 0.015202325557766017, 0.008015335915843025, 0.03271874549682252, 0.03241860613343306, 0.0486212892428739, 0.021367144072428346, 0.028311931964708492, 0.01573677764099557, 0.08521977128111757, 0.0800285224977415, 0.04038735743961297, 0.01779272708517965, 0.009085534202313283, 0.023313752899412066, 0.0509381258598296, 0.051203614348196425, 0.0689719915681053, 0.06475542759289965, 0.030710094979440328, 0.03361378301633522, 0.02407764179224614, 0.06688345441943966, 0.009049493655766128, 0.03302830271422863, 0.0630654237465933, 0.039259356053662486, 0.031435805940418504, 0.033053246297640726, 0.018371665355516598, 0.045077916292939335, 0.16404283815063536, 0.0874064426170662, 0.042206506113871, 0.095565332158003, 0.0015455480479431571, 0.09491723685641773, 0.01970679273654241, 0.04495904278883245, 0.1107562638935633, 0.18551691086031497, 0.24357197689823806, 1.0848898789845407, 23.55930771678686, 78.49918216466904, 56.192023158073425, 50.00506974756718, 67.73329585790634, 45.49060419201851, 25.749491192400455, 85.4604010283947, 27.334923818707466, 0.6471939780749381, 17.238103710114956, 20.843585841357708, 0.475451328093186, 1.626685825176537, 75.14242708683014, 92.97018125653267, 90.77674135565758, 86.65230587124825, 86.72431200742722, 84.0219198167324, 76.68020457029343, 73.69392961263657, 72.57105186581612, 68.42074736952782, 65.25647476315498, 59.99248802661896, 64.47917327284813, 64.58480760455132, 61.484166383743286, 59.67596121132374, 60.169452130794525, 61.30938336253166, 65.82892164587975, 64.22880470752716, 62.620970383286476, 58.51075753569603, 55.08181773126125, 56.19574695825577, 58.42941530048847, 59.380329474806786, 63.06925132870674, 62.51065470278263, 67.14299753308296, 65.71224510669708, 58.194105327129364, 52.46991388499737, 52.51601681113243, 53.85527014732361, 53.97074595093727, 57.650422900915146, 65.57903945446014, 69.80594024062157, 71.65103003382683, 68.39866295456886, 70.73271051049232, 62.0614618062973, 70.22087797522545, 71.54599606990814, 67.8497064113617, 68.12142983078957, 52.64457531273365, 68.88461887836456, 66.00581735372543, 71.26884654164314, 65.1180861890316, 62.435110956430435, 63.21937747299671, 63.83758530020714, 64.4517083466053, 64.59648057818413, 60.55770009756088, 53.4502574801445, 49.26009692251682, 50.60048259794712, 51.79422274231911, 49.26188662648201, 50.15763156116009, 49.4115149974823, 53.55325095355511, 64.3915043771267, 70.54253831505775, 71.66096270084381, 66.46432355046272, 66.88657969236374, 62.16031350195408, 63.95551577210426, 64.78213101625443, 64.82168689370155, 64.9773645401001, 66.2887653708458, 67.13792100548744, 69.35297414660454, 61.76330700516701, 55.66590338945389, 50.41366182267666, 56.537979394197464, 64.78918343782425, 71.93849220871925, 72.04396694898605, 72.01299861073494, 71.36343866586685, 72.87885054945946, 68.4707298874855, 71.07763320207596, 72.24892035126686, 75.27902215719223, 74.83988732099533, 62.03621216118336, 2.993359202519059, 0.2639605547301471, 0.6729585549328476, 3.6967822071164846, 6.187767991796136, 5.098246755078435, 1.0639269975945354, 8.248977363109589, 57.03997805714607, 20.78666489571333, 46.86749070882797, 41.460726633667946, 42.83290520310402, 67.54793420433998, 35.4619125276804, 0.39476538891904056, 0.2455500527867116, 0.010343231460865354, 0.11188217613380402, 0.03946697928768117, 0.06082761101424694, 0.0749961897963658, 0.038830862249596976, 0.03155955906549934, 0.058100897367694415, 0.06416118994820863, 0.03859584634483326, 0.01943276212841738, 0.020344538788776845, 0.04680357662437018, 0.10401142542832531, 0.030138368529151194, 0.026042229146696627, 0.05465154710691422, 0.06466519727837294, 0.03125080336758401, 0.021470022438734304, 0.03818003213382326, 0.02698248572414741, 0.11706760647939518, 0.15445216762600467, 0.2645623771240935, 0.21655803895555437, 0.1322593991062604, 0.12445044703781605, 0.0992198009043932, 0.07764988724375144, 0.14196962962159887, 0.08868173434166238, 0.07864813524065539, 0.13786415773211047, 0.10583834067801945, 0.12603843526449054, 0.2018292574211955, 0.08608553107478656, 0.17158699192805216, 0.2422280958853662, 0.23916373844258487, 0.17106195213273168, 0.1234219862089958, 0.23874075879575685, 0.19268584961537272, 0.13553213677369058, 0.2788086439250037, 0.145311965898145, 0.2928455953951925, 0.2507890068227425, 1.2359337927773595, 33.85127775371075, 94.58415985107422, 74.45969492197037, 64.55094382166862, 87.52388790249825, 94.73251909017563, 27.426194921135902, 82.80606105923653, 35.33669024705887, 2.209263676777482, 37.23820321261883, 31.387125179171562, 0.29613823746331036, 2.4290702445432544, 77.01705649495125, 94.22443315386772, 92.43860498070717, 93.06309387087822, 90.55918022990227, 88.15254896879196, 81.80448800325394, 81.31284758448601, 78.68016645312309, 72.34655991196632, 68.66334155201912, 65.77313303947449, 71.41765415668488, 69.86663058400154, 64.14483681321144, 65.13567924499512, 64.10851076245308, 64.59142684936523, 66.84976726770401, 66.22720867395401, 65.96687704324722, 62.03579418361187, 57.93717831373215, 60.782853215932846, 61.49343028664589, 62.4316531419754, 64.63493451476097, 66.88402622938156, 71.21462345123291, 70.85421279072762, 63.40974725782871, 55.883008539676666, 55.77450156211853, 54.41197827458382, 56.14770993590355, 60.6300064176321, 67.0942385494709, 72.41161242127419, 71.89243867993355, 70.41559472680092, 71.3977812230587, 63.32211636006832, 70.85645467042923, 71.58910855650902, 71.994189620018, 70.11177062988281, 55.92301279306412, 69.83226522803307, 68.57990562915802, 74.2118190228939, 67.5025874376297, 66.7232720553875, 66.68465852737427, 66.83009192347527, 67.02301517128944, 69.28773164749146, 63.786037266254425, 56.828515604138374, 51.87730148434639, 53.00380803644657, 54.97957281768322, 54.52533759176731, 52.588539719581604, 53.88215750455856, 57.77089923620224, 68.05275231599808, 73.20829287171364, 74.66696619987488, 69.66950476169586, 70.31496092677116, 66.17689177393913, 67.88781076669693, 67.95625269412994, 67.7758839726448, 68.45647305250168, 68.84075403213501, 70.26623994112015, 70.82034900784492, 65.72758868336678, 57.371145486831665, 52.50593215227127, 59.01151366531849, 65.62380105257034, 75.35212263464928, 74.2995335161686, 75.41959181427956, 73.71079310774803, 75.97714349627495, 70.34889310598373, 72.58430555462837, 75.83255365490913, 77.98443138599396, 76.45071968436241, 62.98904903233051, 3.8495541969314218, 0.5275945644825697, 0.9284795250277966, 4.718482783064246, 12.806921135634184, 12.899351175874472, 3.2380796084180474, 8.325817789882421, 61.572454646229744, 27.863302566111088, 55.476715341210365, 42.80897408723831, 53.41365784406662, 71.78653836250305, 61.9422622025013, 0.5571919481735677, 0.3425783955026418, 0.11689652659697458, 0.1879355701385066, 0.17255392129300162, 0.1910128557938151, 0.2628478081896901, 0.23193627392174676, 0.13738538342295215, 0.11194675040314905, 0.12598370929481462, 0.09245107270544395, 0.08219871073379181, 0.1381678890902549, 0.1460627670167014, 0.17722439020872116, 0.18415699945762753, 0.15040157013572752, 0.12063153320923448, 0.17055659409379587, 0.176449142745696, 0.09431768543436192, 0.12879140238510445, 0.10387800211901776], [0.06504108765511774, 0.020616970068658702, 0.08311988669447601, 0.05005058403185103, 0.034682308687479235, 0.018666474243218545, 0.0383806272293441, 0.0419041180430213, 0.04764598845213186, 0.04718830226920545, 0.03887347636919003, 0.04134551090828609, 0.05205889501667116, 0.05427333009720314, 0.09370580693939701, 0.03818613629846368, 0.008829475627862848, 0.07286880863830447, 0.009255425720766652, 0.12343487731413916, 0.018369490862824023, 0.08357964718015864, 0.01249746537723695, 0.04121549776755273, 0.05930670551606454, 0.03867887411615811, 0.09279565187171102, 0.10569972975645214, 0.3575557074509561, 0.8852659282274544, 60.515024587512016, 54.399731531739235, 112.4759329855442, 54.91505987942219, 65.00748172402382, 26.26176070421934, 37.3464860022068, 38.99170272052288, 2.133568888530135, 30.15829771757126, 19.517052322626114, 0.7415613206103444, 0.17925489140907302, 4.004846401512623, 77.93778508901596, 98.83411779999733, 85.87178215384483, 81.74330368638039, 77.95135796070099, 74.46708932518959, 72.12157398462296, 71.64316445589066, 67.21621960401535, 61.6212098300457, 68.62450003623962, 75.11540293693542, 77.34655201435089, 67.72635743021965, 59.75846618413925, 55.31706690788269, 62.242624685168266, 63.22287328541279, 62.97342427074909, 58.04117113351822, 57.42626532912254, 53.03632669150829, 59.89290677011013, 58.49279209971428, 63.29168379306793, 61.480408385396004, 68.54406595230103, 70.66003561019897, 73.27127069234848, 66.05454593896866, 53.51840682327747, 49.76108103990555, 52.64212444424629, 47.629467621445656, 53.0747502297163, 55.998670533299446, 65.915237814188, 66.69307887554169, 69.64083909988403, 59.383931681513786, 64.0334115922451, 73.29080924391747, 63.24199765920639, 68.03196743130684, 62.459729835391045, 38.562819734215736, 59.96697999536991, 67.22074896097183, 61.45863935351372, 59.910849407315254, 65.06158322095871, 62.35783830285072, 64.2786656320095, 65.28968498110771, 63.739740550518036, 61.97787009179592, 51.48606687784195, 45.88855683803558, 46.12102836370468, 45.25438226759434, 48.3963842689991, 46.054034158587456, 50.03997087478638, 57.013584673404694, 65.05847498774529, 67.14184239506721, 63.80008891224861, 67.20057964324951, 62.50530079007149, 60.09708121418953, 59.46682423353195, 60.28975747525692, 60.84594123065472, 62.4677550047636, 63.22745583951473, 65.13700917363167, 64.17929336428642, 63.87103870511055, 58.56628775596619, 49.33265782892704, 50.121468901634216, 64.81445208191872, 69.38213378190994, 70.69291144609451, 72.39989385008812, 71.60302340984344, 71.66701197624207, 71.34639278054237, 70.69557130336761, 72.07640200853348, 72.71448656916618, 70.33909723162651, 11.96534514427185, 0.3512220113771036, 0.7539719296619296, 0.22570071945665404, 2.4095321679487824, 5.013297563418746, 3.8509242609143257, 1.1061598313972354, 12.588950581848621, 24.09060660749674, 24.478784278035164, 52.36911669373512, 72.04068392515182, 42.27145493030548, 50.408376306295395, 2.4321179185062647, 0.07620249889441766, 0.02761819643637864, 0.03750256262719631, 0.05345333855075296, 0.007198898329079384, 0.04297495550417807, 0.09590700952685438, 0.03077297344134422, 0.0254049246723298, 0.032622340513626114, 0.06018036918248981, 0.0624540944409091, 0.030503141533699818, 0.08640733372885734, 0.06324817019049078, 0.04609826173691545, 0.06698083161609247, 0.005328590632416308, 0.02892774013162125, 0.00659135583191528, 0.0802780844969675, 0.04049504306749441, 0.018100521701853722, 0.04275316096027382, 0.06300531720626168, 0.04130850742512848, 0.05259195371763781, 0.06315414750133641, 0.0189848741501919, 0.0497655102662975, 0.11238695529755205, 0.061559116293210536, 0.051177438799641095, 0.03834624352748506, 0.06780894225812517, 0.05475027872307692, 0.030224613510654308, 0.047767808282515034, 0.05719270156987477, 0.009006642048916547, 0.026171975114266388, 0.018466487708792556, 0.03653267580375541, 0.0654851739818696, 0.031224123158608563, 0.03648979451099876, 0.03172683915181551, 0.048316956745111383, 0.11721375762135722, 0.04696275987953413, 0.061780803225701675, 0.08091549287200905, 0.35789305809885263, 1.5058112237602472, 69.62525233626366, 69.42439511418343, 93.98423284292221, 68.7070544064045, 79.71592247486115, 20.237385369837284, 58.80107335746288, 40.218052715063095, 0.7607286795973778, 6.936915367841721, 5.8030894584953785, 5.844329120591283, 0.4026177863124758, 5.110730035230517, 83.9494577050209, 97.13821560144424, 89.08131793141365, 85.44964760541916, 80.13203054666519, 79.0122838318348, 74.92281407117844, 74.21077027916908, 70.10047763586044, 65.37932217121124, 69.49890911579132, 76.91601991653442, 77.83281192183495, 69.44579556584358, 62.929882407188416, 59.7854333370924, 65.32360196113586, 67.00567290186882, 67.1396917104721, 61.40017569065094, 59.08329181373119, 57.78902426362038, 61.39381483197212, 61.345272436738014, 66.61207482218742, 64.95568290352821, 70.89658051729202, 73.46607863903046, 77.92575493454933, 70.34742638468742, 56.96941204369068, 53.265070617198944, 56.78067997097969, 53.62958125770092, 56.744779497385025, 61.78429327905178, 71.61405801773071, 71.9601434469223, 72.17848733067513, 66.06373384594917, 66.27782195806503, 77.68695294857025, 67.24051550030708, 73.71338456869125, 68.02726328372955, 44.05581258237362, 64.50986042618752, 70.73372885584831, 67.3392342031002, 63.604304417967796, 69.3960790336132, 65.40734186768532, 66.88856318593025, 69.10138204693794, 68.22390273213387, 63.69576930999756, 56.39684356749058, 49.52388636767864, 50.19173473119736, 49.25714448094368, 50.39859943091869, 49.741903468966484, 52.874960750341415, 60.8972042798996, 71.31664797663689, 70.19225791096687, 68.11332106590271, 70.03408759832382, 67.61082842946053, 64.44169208407402, 65.31813785433769, 64.37293857336044, 65.64102932810783, 67.82602608203888, 68.08068841695786, 67.35305786132812, 68.02742287516594, 69.69812482595444, 62.3896311968565, 51.95303522050381, 54.78967800736427, 67.03553169965744, 71.71272352337837, 71.48820877075195, 75.69662734866142, 73.87603864073753, 74.04813900589943, 73.58061969280243, 73.26205238699913, 74.0985395014286, 74.24549281597137, 69.90662723779678, 12.434380576014519, 0.4606539127416909, 1.8516605906188488, 1.1511088069528341, 5.822732504457235, 5.219706287607551, 2.071478320285678, 0.5253415822517127, 15.955518633127213, 32.65152633190155, 28.12966637313366, 59.737502709031105, 66.63338407874107, 49.29353132843971, 56.00422963500023, 4.415999539196491, 0.14991852105595171, 0.04836904066905845, 0.06828194265835918, 0.13937343377619982, 0.04276247491361573, 0.06762068907846697, 0.09852503193542361, 0.10172779249842279, 0.013861863062629709, 0.0888024817686528, 0.034887367801275104, 0.08231941363192163, 0.05798466219857801, 0.020256419884390198, 0.020596774375007953, 0.025336639664601535, 0.08657664729980752, 0.12053623402607627, 0.026813641561602708, 0.013405540576059138, 0.014561064508598065, 0.015514782717218623, 0.06213380576809868, 0.03895586218277458, 0.15237238781992346, 0.13727740093600005, 0.20418968779267743, 0.21248479111818597, 0.09539448234136216, 0.11174739469424821, 0.23383685474982485, 0.14481353951850906, 0.11056447809096426, 0.13528406649129465, 0.16069885430624709, 0.331451969104819, 0.12533790722955018, 0.14156846911646426, 0.2268077217740938, 0.0984993387828581, 0.17681318102404475, 0.23990722198504955, 0.12196541007142514, 0.22020452219294384, 0.1664985009119846, 0.13369388150749728, 0.1974440403864719, 0.18335460423259065, 0.16882569791050628, 0.11182897156686522, 0.2117509109666571, 0.2457196483737789, 0.7705277600325644, 4.511431893333793, 90.3131054341793, 79.3630202114582, 120.123790204525, 70.64688831567764, 108.14286589622498, 30.755410976707935, 55.7315144687891, 42.313518673181534, 2.0363579923287034, 50.76855517923832, 37.8487316519022, 2.658959571272135, 0.5183125531766564, 6.377977235242724, 87.3123836517334, 97.4674679338932, 90.31173750758171, 88.89280244708061, 86.30679041147232, 82.96825155615807, 79.05588269233704, 76.81071236729622, 74.63316321372986, 67.35254868865013, 74.7312967479229, 78.25701355934143, 82.20046475529671, 73.43330919742584, 66.48329973220825, 62.659625709056854, 70.35266250371933, 72.75800943374634, 73.27261582016945, 63.26908640563488, 63.50293725728989, 59.805101081728935, 67.38930031657219, 64.62550342082977, 70.31197428703308, 68.38284820318222, 76.27757057547569, 75.6696791946888, 80.71418970823288, 73.12832996249199, 61.33001625537872, 55.968887731432915, 58.804926350712776, 55.00517964363098, 58.454338163137436, 63.824445605278015, 74.42277610301971, 73.00689607858658, 71.85524627566338, 67.54423320293427, 70.48473581671715, 76.53686106204987, 69.83959123492241, 74.39503759145737, 70.96356332302094, 44.22514669597149, 64.2123743891716, 71.90376967191696, 66.35075524449348, 66.40503913164139, 73.58080968260765, 68.5147999227047, 71.81321293115616, 72.54023551940918, 72.50642493367195, 67.401482462883, 60.62086030840874, 52.388643845915794, 52.71777458488941, 51.780877858400345, 53.5230615735054, 52.348229214549065, 57.26094380021095, 63.75288784503937, 72.17626824975014, 74.06073912978172, 71.30120560526848, 73.68594244122505, 70.65375834703445, 67.55246356129646, 67.95659467577934, 68.98200765252113, 69.32734072208405, 70.5311693251133, 69.57792207598686, 70.27787491679192, 71.50055050849915, 70.65099209547043, 66.39384493231773, 56.713719964027405, 59.15945112705231, 71.32224887609482, 74.59464848041534, 74.96341869235039, 77.57014721632004, 75.74920132756233, 75.64954787492752, 75.58477655053139, 74.85048115253448, 74.98391479253769, 76.26598119735718, 74.2462907731533, 14.220190700143576, 0.6184991647023708, 1.433428314048797, 0.9299618611112237, 10.34030819311738, 14.06036937609315, 11.276885736733675, 2.295304359868169, 16.2661025673151, 35.0013430416584, 41.36742644011974, 67.23952755331993, 75.67207306623459, 58.02063323557377, 71.13218307495117, 10.509458016604185, 0.34090363536961377, 0.24901563010644168, 0.26970338250976056, 0.329061541124247, 0.13629464898258448, 0.1399128118646331, 0.2027864201227203, 0.20161620166618377, 0.15064349543536082, 0.1454230208764784, 0.11916011411813088, 0.17691714107058942, 0.1391831471119076, 0.18921387498266995, 0.2294472887297161, 0.12952183897141367, 0.15618720499332994, 0.17943224986083806, 0.13470357342157513, 0.1527082096436061, 0.1251932032755576, 0.09055190937942825, 0.17532198369735852, 0.11796009843237698], [0.03526986329234205, 0.011197085350431735, 0.055512586841359735, 0.027352221841283608, 0.039564746111864224, 0.09634690271923319, 0.06111605041951407, 0.029983606618770864, 0.07613443653099239, 0.0085054530245543, 0.020861839839199092, 0.01487529447331326, 0.02267895502882311, 0.08555058360798284, 0.09508856906904839, 0.08275741434772499, 0.07870991903473623, 0.049299983293167315, 0.013795073482469888, 0.12037848311592825, 0.09661373449489474, 0.08223717624787241, 0.009428005669178674, 0.08661270825541578, 0.030485439456242602, 0.08107243484118953, 0.015378551306639565, 0.17513484373921528, 0.2586684183916077, 0.7977618486620486, 25.504016764461994, 74.04993250966072, 50.46650558710098, 31.18612166494131, 40.51075100898743, 50.25362581014633, 21.655311584472656, 36.91573351621628, 2.090842081233859, 6.923414692282677, 8.841514717787504, 7.064639339223504, 0.135779078991618, 0.15521871711825952, 1.453195447102189, 52.12116099894047, 85.42658284306526, 81.79353699088097, 77.82957449555397, 81.75410270690918, 80.40081292390823, 72.3229631781578, 69.39561545848846, 71.87100023031235, 79.72542196512222, 82.5244277715683, 79.06789764761925, 72.14980646967888, 63.24996583163738, 59.65916611254215, 60.070125460624695, 62.35373072326183, 60.9807275980711, 60.61466284096241, 56.35590836405754, 57.31529228389263, 58.03560443222523, 64.58109900355339, 64.36760365962982, 64.45716485381126, 72.06710770726204, 71.78964659571648, 73.1009866297245, 72.7379085123539, 64.2524166405201, 51.9793526083231, 50.83814084529877, 51.826600804924965, 54.62702013552189, 55.604475885629654, 63.429840579628944, 65.66082626581192, 69.89899724721909, 64.03070613741875, 69.58676800131798, 68.46049323678017, 63.81412535905838, 66.43147051334381, 65.37726268172264, 33.72509032487869, 64.27921280264854, 62.903606817126274, 56.72518774867058, 66.51916980743408, 66.76218196749687, 66.4274351298809, 65.9436222910881, 65.96957489848137, 65.91238796710968, 65.73916286230087, 52.39784695208073, 46.57959155738354, 48.27923655509949, 49.06649351119995, 45.06468124687672, 46.209012642502785, 52.82808266580105, 61.25804431736469, 66.94948151707649, 60.298850387334824, 60.58698132634163, 63.889832496643066, 65.30192792415619, 62.486237213015556, 64.08041507005692, 60.30412070453167, 61.00707158446312, 62.87913233041763, 62.20753736793995, 63.82302448153496, 66.64585500955582, 66.68101832270622, 64.99217614531517, 53.87662120163441, 46.376443058252335, 56.60458602011204, 69.1942110657692, 73.84276002645493, 73.61702933907509, 75.28469905257225, 77.18670979142189, 71.7918048799038, 68.15554440021515, 73.33994060754776, 59.3902051448822, 20.75551986694336, 0.18150486052036285, 0.15718816925073043, 0.1348322321427986, 0.6214729801286012, 1.6557801514863968, 4.51449072919786, 1.4430876332335174, 0.3186009102500975, 11.299891602247953, 34.88336697220802, 36.8070175498724, 51.38484790921211, 80.21339938044548, 50.526078790426254, 34.511959701776505, 0.40519375121220946, 0.09954544046195224, 0.09591201902367175, 0.10996739802067168, 0.05133864440722391, 0.03216608667571563, 0.015167105084401555, 0.08289589910418727, 0.08625836984720081, 0.06676726377918385, 0.03707695948833134, 0.029010339312662836, 0.02408361979178153, 0.03372153914824594, 0.05426412375527434, 0.006118059500295203, 0.10224143290542997, 0.045927189275971614, 0.03495654709695373, 0.07183496723882854, 0.04024268688226584, 0.026623471785569564, 0.019215040119888727, 0.04313233162974939, 0.09661474381573498, 0.062178290099836886, 0.02758946233370807, 0.06442240366595797, 0.03531304144416936, 0.03487612055323552, 0.11872786504682153, 0.02489716949639842, 0.02798824425553903, 0.007828399120626273, 0.03323738055769354, 0.049613214141572826, 0.1469408316188492, 0.05306434184603859, 0.04950227048539091, 0.09153884704574011, 0.018146280672226567, 0.02373623901803512, 0.06100874328694772, 0.027657326172629837, 0.0876595891895704, 0.04800483911822084, 0.0782662037818227, 0.08329849937581457, 0.03741017266293056, 0.052501808750093915, 0.049236603881581686, 0.13723742886213586, 0.20219145517330617, 0.3156782139558345, 0.9993852046318352, 31.076216362416744, 81.70293465256691, 62.774455547332764, 37.25420035421848, 63.17618139088154, 41.186620742082596, 22.387097217142582, 49.15751002728939, 1.566264198627323, 3.992668054997921, 5.067425658926368, 13.24637895449996, 3.1227541342377663, 0.5412611248902977, 1.454679504968226, 56.974492371082306, 89.5857560634613, 85.4976238310337, 81.1629456281662, 84.15494307875633, 82.03800827264786, 74.96827483177185, 70.51503539085388, 73.68260622024536, 82.43904635310173, 84.68325912952423, 82.86796733736992, 76.16110682487488, 66.2059298157692, 63.09938371181488, 60.70024184882641, 65.06187200546265, 65.1378983259201, 64.16681483387947, 59.90264944732189, 59.37940992414951, 59.74631443619728, 64.79974687099457, 66.35624215006828, 67.02958881855011, 73.15013319253922, 74.67224031686783, 76.31553053855896, 74.26753923296928, 65.64353719353676, 53.45589257776737, 55.821805223822594, 56.14067651331425, 58.38762894272804, 59.52936887741089, 67.44777157902718, 68.10174688696861, 71.74094080924988, 67.47667282819748, 72.15388745069504, 72.19054028391838, 69.29544523358345, 70.61914220452309, 67.49215319752693, 36.62935048341751, 65.08330285549164, 66.34402200579643, 61.669132858514786, 70.04132241010666, 70.2625921368599, 69.58391815423965, 69.69237953424454, 69.13969919085503, 69.42762494087219, 69.39858689904213, 55.32651700079441, 49.32657055556774, 51.911435052752495, 51.62138141691685, 49.97924253344536, 51.95078954100609, 55.38625739514828, 64.33861881494522, 70.86346909403801, 66.64294436573982, 64.4023185968399, 68.93281549215317, 68.13213765621185, 67.50680521130562, 69.15492877364159, 66.85028403997421, 67.38110795617104, 68.13307240605354, 67.20310270786285, 70.2094329893589, 70.02478569746017, 71.26613348722458, 67.77350530028343, 57.81062230467796, 50.372798815369606, 60.93363292515278, 73.47924873232841, 76.83462828397751, 75.47737151384354, 78.30597013235092, 78.33216592669487, 75.37043765187263, 72.04638361930847, 76.02540850639343, 61.07948049902916, 21.370304077863693, 0.18458232429111376, 0.23647575377253816, 0.8295026735868305, 5.341001003980637, 4.84566860832274, 5.872113229706883, 1.017269182484597, 0.5354192946106195, 14.906918350607157, 34.959868267178535, 47.89517216384411, 53.49034532904625, 69.97006103396416, 56.28412641584873, 43.48322130739689, 0.9096909582149237, 0.24446243536658585, 0.02261082216136856, 0.15117027185624465, 0.07736116953310557, 0.021643295367539395, 0.025132712326012552, 0.07911453794804402, 0.10190269444137812, 0.04179933050181717, 0.030101290831225924, 0.03999685046437662, 0.07915133362985216, 0.0737901552929543, 0.060525850058184005, 0.06824802650953643, 0.015194446732493816, 0.0340961085021263, 0.049482206522952765, 0.07994990679435432, 0.03890619023877662, 0.014136228564893827, 0.019033833632420283, 0.0544106014422141, 0.04690986330388114, 0.21984005346894264, 0.09247977897757664, 0.2364514410146512, 0.2187140818568878, 0.11472729573142715, 0.22988335986156017, 0.18711840617470443, 0.17382248915964738, 0.17341145809041336, 0.22411434911191463, 0.14596701512346044, 0.22319784126011655, 0.10411652096081525, 0.2028975641587749, 0.2861600322648883, 0.12228133491589688, 0.21133112255483866, 0.2484715319587849, 0.06479159244918264, 0.2763404685538262, 0.16684673144482076, 0.16988407471217215, 0.17548988718772307, 0.10882426795433275, 0.21030639472883195, 0.2767515886807814, 0.24056243448285386, 0.29568083700723946, 0.6151419261004776, 0.8470011502504349, 50.15135429799557, 95.40348708629608, 77.22583249211311, 43.316919431090355, 62.574920654296875, 73.17391231656075, 28.370902128517628, 48.51701259613037, 1.9114843429997563, 10.618343073874712, 22.61089000850916, 15.807104296982288, 1.3351873168721795, 0.6621053873095661, 2.1757140895351768, 57.753537967801094, 91.10018000006676, 87.38939791917801, 87.40775853395462, 88.49616453051567, 88.45490634441376, 81.05427145957947, 73.47816959023476, 78.54475691914558, 87.7281041443348, 87.65526965260506, 86.5619695186615, 78.56652975082397, 69.90481853485107, 68.45578908920288, 63.00865978002548, 68.99877995252609, 66.34885534644127, 66.2735053896904, 62.37298049032688, 62.24639028310776, 62.08388440310955, 69.52532529830933, 68.2204221189022, 68.60829010605812, 75.97908139228821, 77.42924317717552, 78.90027344226837, 78.94985318183899, 70.64374968409538, 58.20627227425575, 56.880808398127556, 58.30131657421589, 61.08859620988369, 62.2087799012661, 69.52527210116386, 70.51701128482819, 73.15093874931335, 72.69099622964859, 70.60417100787163, 72.79155403375626, 69.7644692659378, 75.59744507074356, 71.7869183421135, 39.84101414680481, 67.2401887178421, 69.71032977104187, 64.34599041938782, 72.3140412569046, 74.6467512845993, 72.88427665829659, 72.46669426560402, 72.61146649718285, 72.53428503870964, 72.66632035374641, 57.779452577233315, 55.32200664281845, 55.13647399842739, 56.315539330244064, 51.529452949762344, 55.02676248550415, 60.614032074809074, 68.70222106575966, 75.82850307226181, 68.54842811822891, 66.12516894936562, 70.20752549171448, 70.5593030154705, 70.44871374964714, 74.03877630829811, 70.74284076690674, 71.26413479447365, 71.5299229323864, 69.03905019164085, 74.21732112765312, 73.90758454799652, 74.54898253083229, 71.31176143884659, 61.16952806711197, 53.1668458878994, 64.00623545050621, 75.84275230765343, 79.94421422481537, 78.03625300526619, 81.57064855098724, 79.70667377114296, 78.53846445679665, 72.78517037630081, 78.47383752465248, 61.67840056121349, 22.721885852515697, 0.20682251604739577, 0.37725773931015283, 1.0816263291053474, 5.737435631453991, 13.813317082822323, 11.46216094493866, 5.644490718841553, 1.1651706648990512, 17.6717459410429, 46.82861499488354, 52.2448405623436, 64.56371113657951, 82.58622765541077, 65.087900608778, 63.63933853805065, 1.088732541538775, 0.4365579807199538, 0.17287179798586294, 0.26215197052806616, 0.14404719782760367, 0.25548415957018733, 0.14472514973022044, 0.16046046162955463, 0.22861035395180807, 0.15618346456903964, 0.12318863271502778, 0.2330271716346033, 0.1680525581468828, 0.09434995401534252, 0.1665774208959192, 0.13322622457053512, 0.15170252532698214, 0.18025613768259063, 0.09800778469070792, 0.18953084625536576, 0.20628583937650546, 0.15957942843670025, 0.14089640986640006, 0.20108362165046856, 0.3008777409559116], [0.014049600449652644, 0.04569196556985844, 0.10327963071176782, 0.0571327620127704, 0.036629882306442596, 0.042548246565274894, 0.04999013239284977, 0.0642997414979618, 0.05364769960578997, 0.024616962364234496, 0.0531420892366441, 0.03389833356777672, 0.0369254537508823, 0.05025113459851127, 0.11017355922376737, 0.02772920131974388, 0.028416624882083852, 0.03166125556163024, 0.06665421242360026, 0.07764678506646305, 0.02655276737641543, 0.06630863135796972, 0.06474174981121905, 0.06347342685330659, 0.054647854922222905, 0.05594260204816237, 0.1381092594237998, 0.019224124007450882, 0.1407260721316561, 0.02853141657396918, 0.6613908475264907, 43.56894090771675, 69.08217787742615, 48.06329034268856, 43.293467089533806, 66.76344349980354, 29.328104965388775, 31.977073922753334, 5.482956636697054, 0.46611332916654646, 2.4861120712012053, 9.512094184756279, 6.0004418436437845, 0.2736495004501194, 0.3840771858813241, 0.38992047077044845, 49.53267529606819, 86.53686806559563, 81.95071935653687, 89.60629016160965, 80.10469481348991, 80.93232840299606, 71.05893060564995, 81.52793884277344, 79.37076419591904, 82.43844598531723, 79.68277305364609, 82.16363713145256, 71.3615919649601, 60.22224269807339, 62.69100062549114, 68.57179686427116, 63.4713077545166, 61.59911781549454, 58.93975451588631, 61.84748388826847, 63.03773581981659, 65.82397431135178, 65.25971218943596, 72.2558131814003, 71.27821683883667, 75.83152011036873, 73.77203822135925, 73.74062910676003, 64.57095354795456, 56.13387867808342, 52.8319888561964, 51.80144615471363, 51.93943195044994, 56.293063536286354, 61.7906541377306, 65.1732212305069, 66.62793517112732, 70.65812811255455, 70.00220730900764, 68.82150426506996, 64.03490871191025, 71.3509601354599, 62.34648071229458, 27.67198283225298, 59.95681174099445, 57.411620914936066, 69.17478650808334, 68.51362958550453, 67.8618885576725, 68.28596100211143, 67.68620878458023, 65.62115639448166, 67.31424674391747, 65.79588621854782, 52.96642184257507, 47.90303774178028, 48.244479820132256, 48.29145289957523, 48.62117640674114, 51.05954736471176, 54.757839515805244, 63.06516274809837, 65.31816065311432, 64.91590663790703, 61.67418658733368, 59.41868841648102, 65.8574353158474, 62.888875007629395, 64.1640941798687, 62.46354483067989, 65.30081078410149, 63.18541869521141, 66.18527412414551, 65.7064238190651, 66.84001699090004, 65.99202409386635, 67.40309357643127, 57.873660922050476, 52.311887964606285, 54.59360472857952, 64.8801201581955, 71.70832335948944, 79.74487692117691, 74.11949917674065, 79.02806058526039, 76.13980516791344, 63.7263310700655, 50.743229538202286, 23.512995801866055, 0.39145668677520007, 0.2059596061008051, 0.14646922645624727, 1.9808457023464143, 4.805734176188707, 2.94975939206779, 2.4980576802045107, 0.6286325678229332, 0.40296505205333233, 18.988116905093193, 60.11556722223759, 32.424845695495605, 20.038511641323566, 33.717768117785454, 56.643017157912254, 10.005433112382889, 0.3083993779728189, 0.08199672782211564, 0.1273841568036005, 0.045075849411659874, 0.05626600774121471, 0.030712911429873202, 0.07100327202351764, 0.01567539460666012, 0.015484956729778787, 0.02940795606264146, 0.051510581470211037, 0.047696350593469106, 0.03701926121721044, 0.07403717914712615, 0.04226400771585759, 0.059034964433521964, 0.039386322678183205, 0.0575293434667401, 0.023062064647092484, 0.02652371971635148, 0.04641915897082072, 0.022426893847296014, 0.06676845121546648, 0.021277668893162627, 0.043353476794436574, 0.06681571860099211, 0.0062235094083007425, 0.02520862290111836, 0.04676965305407066, 0.014068813725316431, 0.038057911733631045, 0.06437617528717965, 0.03226463646569755, 0.08602512767538428, 0.028122860567236785, 0.022252700655371882, 0.05865563049155753, 0.08056974111241288, 0.0827692070743069, 0.05957226450846065, 0.03861320888972841, 0.07389204474748112, 0.03493644602713175, 0.07623939847690053, 0.016753673953644466, 0.02826447533152532, 0.05110932448587846, 0.07898377894889563, 0.013512113910110202, 0.019309714043629356, 0.054063313436927274, 0.06639077968429774, 0.034599440477904864, 0.07409416866721585, 0.08467259322060272, 0.931827382883057, 51.373976692557335, 82.19442307949066, 45.6209409981966, 46.40809915959835, 85.8263897895813, 22.626303881406784, 44.57602746784687, 6.059450777247548, 0.18117890926077962, 4.799549533054233, 6.056042835116386, 5.411326205357909, 4.795249588787556, 0.9844752796925604, 0.27074307203292847, 51.729683205485344, 93.27024355530739, 85.79089969396591, 89.0836738049984, 83.0578051507473, 83.05045634508133, 75.52671566605568, 84.87204819917679, 82.94142499566078, 83.47274288535118, 82.45646461844444, 84.21435669064522, 73.55351194739342, 64.03631463646889, 67.61994794011116, 70.30080288648605, 66.46753057837486, 64.11154299974442, 62.12449662387371, 64.43489044904709, 64.50713217258453, 66.662817299366, 67.5072991847992, 74.00362059473991, 74.47620123624802, 79.7918651998043, 77.42431864142418, 76.700928658247, 68.44366773962975, 57.71945379674435, 56.33192405104637, 54.40962240099907, 56.36147886514664, 59.27460014820099, 64.02444407343864, 70.85322484374046, 71.03297039866447, 71.19765356183052, 73.91662046313286, 70.84195464849472, 68.54482591152191, 74.16226208209991, 66.75341203808784, 30.217074863612652, 62.337877973914146, 61.88637860119343, 73.3962231874466, 71.43621996045113, 71.6278512775898, 71.06501027941704, 70.58863744139671, 68.86798337101936, 69.11984145641327, 69.59179893136024, 55.14839015901089, 49.99784253537655, 52.509853541851044, 52.00942799448967, 52.60804407298565, 53.40021416544914, 57.43829548358917, 66.83151304721832, 71.4620889723301, 66.10791027545929, 65.10718837380409, 63.91785219311714, 69.95024889707565, 68.6245608329773, 67.8645408153534, 66.25946894288063, 69.70721393823624, 68.58383461833, 69.77454632520676, 69.42125648260117, 68.68307009339333, 70.37112951278687, 71.08542278409004, 61.302543729543686, 55.176523849368095, 58.09732832014561, 68.19073811173439, 75.01894131302834, 83.70478123426437, 77.27345153689384, 80.07043585181236, 80.56972146034241, 64.61073741316795, 52.6271266490221, 23.19634549319744, 0.3218637773534283, 0.1601702076732181, 0.7660522533115, 3.7674762262031436, 6.89007100649178, 4.114993941038847, 2.831612331792712, 0.1690837278147228, 0.3516770963324234, 22.220018282532692, 65.4334008693695, 47.39175617694855, 24.430912546813488, 41.54649183154106, 67.42909938097, 10.0146390683949, 0.3354737564222887, 0.22502131294459105, 0.047729628495289944, 0.11446408563642763, 0.0695780516252853, 0.020020943848066963, 0.06971005743253045, 0.17540486674988642, 0.030268023583630566, 0.030369144915312063, 0.047837982056080364, 0.06071496041840874, 0.04488385209697299, 0.05615346475678962, 0.005768147075286834, 0.04119718898436986, 0.021711415247409604, 0.0179129809839651, 0.057364393724128604, 0.015767654695082456, 0.01810059777199058, 0.03213736927136779, 0.07204220455605537, 0.02323025943042012, 0.041239725178456865, 0.2269205727498047, 0.15448646969161928, 0.12038858374580741, 0.15775923704495654, 0.15716082853032276, 0.22396706248400733, 0.16623947652988136, 0.1771697384538129, 0.2526287909131497, 0.09366339319967665, 0.1471234593191184, 0.10205929502262734, 0.22557761200005189, 0.20014042616821826, 0.17113600362790748, 0.17690186767140403, 0.14083019545068964, 0.17528736992971972, 0.30460664711426944, 0.10516562091652304, 0.17981732060434297, 0.14725186571013182, 0.10644788140780292, 0.1921038722502999, 0.11962299162405543, 0.22107565513579175, 0.21940467995591462, 0.11209690914256498, 0.17424244084395468, 0.27248587226495147, 1.606393726542592, 82.79162183403969, 88.70281264185905, 75.29292181134224, 60.5389367043972, 97.74311274290085, 41.09656937420368, 48.66917163133621, 5.508137410506606, 0.43637526396196336, 11.662697084248066, 21.920054778456688, 10.54942237213254, 2.0809046644717455, 0.6379414745606482, 0.7321680465247482, 51.375109031796455, 97.29934975504875, 87.68354013562202, 96.95945039391518, 87.17915520071983, 87.41198390722275, 78.84011507034302, 91.09060451388359, 83.84282782673836, 87.09591686725616, 86.3128624856472, 91.38592466711998, 77.71789848804474, 67.57905453443527, 70.56251764297485, 74.93988275527954, 70.53709700703621, 67.19724342226982, 66.32702931761742, 68.13109651207924, 67.2087188065052, 72.73548424243927, 71.65809005498886, 77.8818216919899, 76.18876934051514, 80.58309674263, 79.65250387787819, 80.54037943482399, 72.06654533743858, 62.574723064899445, 60.18549107015133, 56.479154750704765, 58.463085293769836, 61.425698921084404, 68.63976761698723, 71.78419768810272, 74.44281622767448, 72.99843773245811, 73.9670741558075, 73.88328865170479, 69.86863687634468, 78.24607014656067, 67.88536369800568, 34.54729400575161, 64.00913089513779, 64.36718568205833, 72.84010022878647, 72.44046047329903, 74.33490961790085, 72.78051942586899, 72.48386174440384, 71.09704256057739, 72.452103048563, 73.09739962220192, 58.8406178355217, 53.63167494535446, 54.53126147389412, 55.89223064482212, 54.648591578006744, 57.96877361834049, 61.43093504011631, 70.59176847338676, 74.18294057250023, 70.46151146292686, 67.73498296737671, 64.88911807537079, 73.12670364975929, 72.06430345773697, 73.73980835080147, 70.18734097480774, 72.99821734428406, 71.38268083333969, 73.80096226930618, 73.95169258117676, 72.88126721978188, 73.15177470445633, 73.44272509217262, 64.53261360526085, 59.51091326773167, 59.75488677620888, 71.86081677675247, 77.81010434031487, 85.97304672002792, 78.01744401454926, 81.69269800186157, 82.69570738077164, 66.95081904530525, 53.39446887373924, 24.452440291643143, 0.5592564842663705, 0.6139404186978936, 0.4607373895123601, 5.201013190671802, 15.568401105701923, 10.485142171382904, 8.198970146477222, 1.9913261337205768, 0.6723087897989899, 28.737343065440655, 82.98010692000389, 47.22156710922718, 31.315934099256992, 48.03730733692646, 78.55494797229767, 21.51506870985031, 0.7607189426198602, 0.35189065674785525, 0.3013832919532433, 0.23565041134133935, 0.1721511280629784, 0.14179111341945827, 0.18020512245129794, 0.3237315849401057, 0.10057685503852554, 0.09911244924296625, 0.19736825226573274, 0.14665850379969925, 0.10490538683370687, 0.264066414674744, 0.19072512513957918, 0.20817818236537278, 0.1981873606564477, 0.1638988615013659, 0.14946788898669183, 0.2479477835004218, 0.1168658907408826, 0.15326140652177855, 0.310329704079777, 0.1414650582592003, 0.20118541462579742], [0.08035534949158318, 0.06537762194056995, 0.03317679533211049, 0.036798965811613016, 0.04664919506467413, 0.041928764767362736, 0.12487609841628, 0.1250694872578606, 0.019426695071160793, 0.08915389611502178, 0.006778511560696643, 0.03584162128390744, 0.012391569252940826, 0.11015077529009432, 0.03449373267358169, 0.02887019029003568, 0.02238738747109892, 0.08913903831853531, 0.023179797099146526, 0.024133466140483506, 0.08974701311672106, 0.020940748690918554, 0.03259209428506438, 0.06318931045825593, 0.05270163943350781, 0.14252656692406163, 0.06952227180590853, 0.15173921710811555, 0.26530013128649443, 0.0520580007287208, 0.6056318082846701, 5.536723751574755, 67.93524742126465, 78.79496589303017, 40.274099707603455, 43.572159335017204, 48.25465947389603, 24.119084179401398, 8.002202454954386, 0.06552864157129079, 5.035068970173597, 6.884459657594562, 8.182705119252205, 1.7054211627691984, 1.778979990631342, 0.277607700554654, 2.3875607969239354, 71.75924062728882, 101.42332926392555, 93.30397814512253, 87.47717320919037, 85.92090591788292, 75.77420398592949, 83.10185998678207, 82.28830084204674, 86.31479278206825, 83.92310231924057, 80.66118255257607, 74.38834995031357, 66.1660623550415, 65.05481958389282, 66.74236983060837, 65.08629709482193, 65.2959318459034, 61.57607965171337, 67.11854204535484, 66.97943150997162, 69.54379990696907, 68.85294377803802, 70.46423211693764, 75.26560127735138, 73.83533522486687, 69.96844232082367, 73.11162605881691, 65.72946578264236, 57.2346606105566, 53.5339517891407, 51.300796419382095, 51.56735211610794, 56.40477754175663, 58.8093189150095, 62.99239665269852, 67.574532777071, 73.64346072077751, 63.95198956131935, 67.52440586686134, 63.86444225907326, 70.38492277264595, 64.81759831309319, 24.6207769587636, 53.67968536913395, 72.75919497013092, 68.85502606630325, 66.14339277148247, 66.10669434070587, 67.82809317111969, 67.34380915760994, 67.81440630555153, 66.03439942002296, 60.86036905646324, 53.135550767183304, 47.78961002826691, 48.50282795727253, 49.27993945777416, 48.99558551609516, 51.96570374071598, 53.26908700168133, 61.614020615816116, 63.387058675289154, 64.99144658446312, 59.19559098780155, 60.720441564917564, 63.10372307896614, 64.67437639832497, 64.2597122490406, 63.45772348344326, 61.454923152923584, 60.93419909477234, 64.97097328305244, 66.47928714752197, 63.616478964686394, 68.19972842931747, 65.00048249959946, 63.71805891394615, 56.297463700175285, 52.79643036425114, 63.06815318763256, 71.3330402970314, 73.71485128998756, 73.79930555820465, 75.79527005553246, 66.71450212597847, 40.306960344314575, 20.729377269744873, 1.1850040568970144, 0.36254688806366175, 0.04146206520090345, 0.7566916930954903, 0.8807353244628757, 4.5997201558202505, 2.1476953430101275, 3.391764499247074, 0.35734386881813407, 0.3098209766903892, 23.303349651396275, 42.19983637332916, 21.47875025868416, 27.23330397158861, 58.665929809212685, 39.97260868549347, 0.42080530256498605, 0.05461469205329195, 0.0712438095069956, 0.03907299163984135, 0.0555380016885465, 0.03445799826295115, 0.07528625821578316, 0.10735231451690197, 0.02012355504120933, 0.05970781407086179, 0.020925050412188284, 0.039701631540083326, 0.05247156252153218, 0.05181823136808816, 0.06632313292357139, 0.08485116137308069, 0.03228159825084731, 0.02934579191787634, 0.028941814962308854, 0.06329075462417677, 0.0408343270100886, 0.025203513214364648, 0.06788524988223799, 0.0737257294531446, 0.009304940886067925, 0.04955819131282624, 0.046887929129297845, 0.043843112434842624, 0.024872908688848838, 0.046506372455041856, 0.02268893691507401, 0.013807958093821071, 0.10031751153292134, 0.056694175000302494, 0.022951670180191286, 0.05873402355064172, 0.07288333246833645, 0.07050455620628782, 0.045077411632519215, 0.06978681034524925, 0.03876943468640093, 0.06412443137378432, 0.017542079694976564, 0.06593429206986912, 0.036795110354432836, 0.026495963393244892, 0.039525809334008954, 0.02680118090211181, 0.004263803066351102, 0.0009382662881307624, 0.06462518809712492, 0.08824967822874896, 0.017168361955555156, 0.1000402971112635, 0.19654147006804124, 0.1836613635532558, 0.5375150009058416, 8.81562765687704, 79.71836194396019, 89.29307296872139, 40.01847222447395, 61.767969354987144, 60.32691188156605, 30.997822768986225, 12.100629284977913, 0.04120706696994603, 2.252433872781694, 4.619630612432957, 8.534935768693686, 2.988233515061438, 4.305800702422857, 0.3506640944397077, 2.4180118879303336, 76.35659873485565, 99.18227031826973, 95.67083314061165, 88.78855884075165, 88.09443488717079, 78.67042377591133, 85.24958074092865, 84.09853130578995, 88.85850548744202, 86.46699741482735, 83.78991946578026, 77.51381903886795, 69.725361764431, 66.38227075338364, 71.37798428535461, 68.25118526816368, 69.77922767400742, 64.46793347597122, 69.05098155140877, 70.83090484142303, 74.59056749939919, 71.10070556402206, 74.39972653985023, 78.56494903564453, 78.29655423760414, 73.58786210417747, 78.64900812506676, 68.0505408346653, 60.768402591347694, 57.23100520670414, 55.8973603695631, 55.58572009205818, 60.08173383772373, 62.57113605737686, 70.00261008739471, 70.13244912028313, 78.68822202086449, 67.2397555410862, 69.71400797367096, 67.62256979942322, 73.24347138404846, 66.53277307748795, 27.06374567002058, 57.612139955163, 75.18771305680275, 71.57193347811699, 69.12214413285255, 70.12227326631546, 70.75758397579193, 70.52989259362221, 70.85251048207283, 69.01423752307892, 65.39150431752205, 56.68380796909332, 51.28172144293785, 53.0660030990839, 52.29209862649441, 53.22119817137718, 56.029730066657066, 58.253446742892265, 65.83230346441269, 67.7055649459362, 70.2454474568367, 64.14916098117828, 67.38388940691948, 66.67776569724083, 68.11967432498932, 69.6988695859909, 70.74679255485535, 66.65866792201996, 68.59375208616257, 68.58963310718536, 71.59460306167603, 68.57974603772163, 71.27853602170944, 69.06045064330101, 70.43891787528992, 59.3264027684927, 57.28940427303314, 64.00334760546684, 77.32244610786438, 74.76924911141396, 76.53538674116135, 75.4756236076355, 68.6062990128994, 40.57755522429943, 20.64263742417097, 1.3431472959928215, 0.3626023413380608, 0.3073622117517516, 2.5537510542199016, 3.417878597974777, 4.289200343191624, 0.9205380105413496, 1.1198458657599986, 0.21851956495083869, 0.9198963199742138, 34.60769556462765, 52.0302052795887, 31.722324192523956, 25.23059483617544, 70.778399258852, 41.559521332383156, 0.8640043472405523, 0.15437949652550742, 0.03992345948063303, 0.06053031036572065, 0.06775788991944864, 0.03714298094564583, 0.03477002312138211, 0.01792224298696965, 0.08192122913897038, 0.08396776072913781, 0.041891616565408185, 0.021129512097104453, 0.009590087011019932, 0.0676651659887284, 0.027987364810542203, 0.05471785058034584, 0.02690725235879654, 0.02142919689504197, 0.02355531269131461, 0.073756446945481, 0.03211382092558779, 0.044576769942068495, 0.060016131901647896, 0.03223774103389587, 0.019964093480666634, 0.02077881206787424, 0.1172728771052789, 0.12142532694269903, 0.1160752956639044, 0.1395047493861057, 0.1799898550962098, 0.11997035384410992, 0.15110340435057878, 0.22562215570360422, 0.1351642096415162, 0.16949922661297023, 0.18764585052849725, 0.1800156818353571, 0.2219255774980411, 0.12968834722414613, 0.1121270922885742, 0.1384918365511112, 0.12304612551815808, 0.24778375402092934, 0.1563157152850181, 0.09969115373678505, 0.25686876964755356, 0.18014113447861746, 0.15064309467561543, 0.11497535117086954, 0.1297126748249866, 0.2686515514506027, 0.15573741897242144, 0.31756840471643955, 0.32734287553466856, 0.4529276507673785, 0.9890314133372158, 16.519518569111824, 103.61771911382675, 102.55262866616249, 62.07456350326538, 66.73692092299461, 69.23539325594902, 39.49837513267994, 13.058010712265968, 0.15581895131617785, 8.84243331849575, 17.221443504095078, 26.106398440897465, 4.171523507684469, 3.3826915360987186, 0.4385659651597962, 3.9372591907158494, 78.95778715610504, 105.94118803739548, 96.2924873828888, 93.03170755505562, 93.09501215815544, 83.03110778331757, 89.83218044042587, 87.42768466472626, 92.20714420080185, 89.74950447678566, 86.55709818005562, 81.11242353916168, 73.77839148044586, 72.2465568780899, 74.1315521299839, 72.74835035204887, 73.22646349668503, 68.93079400062561, 74.2107854783535, 77.03843414783478, 79.59376662969589, 74.75415632128716, 77.74897322058678, 80.9665721654892, 80.01033827662468, 75.02250552177429, 81.16521030664444, 71.30149438977242, 64.50831770896912, 59.44471322000027, 57.66327761113644, 58.34448605775833, 61.793686375021935, 64.85127970576286, 72.11995527148247, 71.7923292517662, 76.29321053624153, 66.65057435631752, 73.73217836022377, 70.24352476000786, 76.79178178310394, 70.6912699341774, 30.43930023908615, 61.551643162965775, 75.82006752490997, 75.24864658713341, 72.41295754909515, 72.90210530161858, 72.04001516103745, 73.19423362612724, 72.78543636202812, 70.99718391895294, 67.99783006310463, 60.55854745209217, 53.578006625175476, 55.315167009830475, 56.10146641731262, 56.810466572642326, 58.68928715586662, 59.843938797712326, 69.7989410161972, 71.40091225504875, 74.26057040691376, 67.25541070103645, 70.49154505133629, 70.32181575894356, 70.97319200634956, 73.0783398449421, 72.91375547647476, 70.4062320291996, 70.52081108093262, 72.69345849752426, 76.21796697378159, 71.43635675311089, 76.18639066815376, 71.55588313937187, 73.29520180821419, 63.33123967051506, 60.271146073937416, 67.61330589652061, 78.67671623826027, 78.36688086390495, 79.28516998887062, 78.13890069723129, 70.43585523962975, 43.84774334728718, 21.82438351213932, 1.3748310646042228, 0.35133725206833333, 0.2247280755545944, 2.6674174424260855, 8.410969320684671, 11.95657616481185, 6.608397820964456, 8.817995879799128, 1.8962630722671747, 1.463430079165846, 36.639336347579956, 59.65187810361385, 32.73493945598602, 40.11859305202961, 74.21064108610153, 60.183515176177025, 1.3165689096786082, 0.36823607340920717, 0.16603519296040758, 0.13759915163973346, 0.1020049475482665, 0.06724845006829128, 0.15812268160516396, 0.14607760997023433, 0.17713159206323326, 0.15571499126963317, 0.06048285373253748, 0.16516311006853357, 0.1278275009826757, 0.20801326230866835, 0.24032013810938224, 0.18062801304040477, 0.1378478601691313, 0.10325441995519213, 0.10461013080202974, 0.19001261884113774, 0.17161437717732042, 0.1737102319020778, 0.15527307201409712, 0.181403067545034, 0.059432911439216696, 0.13479346234817058], [0.016142843742272817, 0.02096589822031092, 0.023278840417333413, 0.02051533851044951, 0.026851635811908636, 0.0509102396608796, 0.08929952775361016, 0.062097982299746946, 0.015803146052348893, 0.06286222371272743, 0.05800700455438346, 0.05257223856460769, 0.04117003751161974, 0.05047639868280385, 0.03822921797109302, 0.0767722976161167, 0.03287035142420791, 0.08515081834048033, 0.05102136514324229, 0.005988628945488017, 0.07671972387470305, 0.01610113133210689, 0.055007206537993625, 0.08388472924707457, 0.04354029762907885, 0.04473176748433616, 0.052253359972382896, 0.06299537242739461, 0.009636238391976804, 0.09614195121685043, 0.13594367250334471, 0.9234222932718694, 27.054628059267998, 79.660065472126, 64.53104808926582, 39.48001451790333, 50.94579666852951, 43.53197269141674, 14.059474524110556, 0.07404320538626052, 0.7859069004189223, 2.8443960333243012, 2.076746500097215, 10.654870513826609, 5.004579406231642, 0.33960790489800274, 0.3511855273973197, 3.607896901667118, 65.34478962421417, 99.18483898043633, 87.53556087613106, 88.17733123898506, 84.04208153486252, 86.7468523979187, 85.29029175639153, 85.53341031074524, 83.17814469337463, 84.6972119808197, 76.94703385233879, 70.3715018928051, 68.5655727982521, 69.65051338076591, 66.64340794086456, 65.48048794269562, 65.79929083585739, 67.68686234951019, 70.33957600593567, 71.49663671851158, 70.35127937793732, 71.50031492114067, 76.38380527496338, 74.63430315256119, 72.5454032421112, 71.71897038817406, 67.83076822757721, 60.79353824257851, 56.35897099971771, 53.985242173075676, 53.509139120578766, 54.38028037548065, 55.28051666915417, 63.58009971678257, 62.678187713027, 65.26141449809074, 65.64149290323257, 66.71507969498634, 66.39257580041885, 69.01971682906151, 62.92241960763931, 19.535718820989132, 58.73621083796024, 71.83085158467293, 66.0213053226471, 70.07783845067024, 65.51050633192062, 63.41255530714989, 65.16005873680115, 63.168152421712875, 59.26734633743763, 58.378866612911224, 49.1643800586462, 49.94991570711136, 49.897896498441696, 50.56264042854309, 51.67152352631092, 52.581893876194954, 53.71748574078083, 61.10094174742699, 62.650829181075096, 62.59327366948128, 59.18967470526695, 59.64239001274109, 58.64220008254051, 60.01716010272503, 62.77922809123993, 61.716261729598045, 62.48008534312248, 62.795517817139626, 62.51195043325424, 62.26257361471653, 61.831152364611626, 64.23006623983383, 66.96679338812828, 64.26046460866928, 57.8804587572813, 54.953627809882164, 61.14257611334324, 66.78457036614418, 77.79207050800323, 67.0152635872364, 71.99111178517342, 48.72682213783264, 10.413638558238745, 2.3394475411623716, 0.1611445882008411, 0.10266220837365836, 0.44303520815446973, 1.7026950465515256, 5.018288595601916, 3.87128546833992, 2.293290230445564, 1.1529594263993204, 0.4397194704506546, 6.576272444799542, 41.3634442538023, 37.03721299767494, 25.56195605546236, 48.73710058629513, 53.0795531719923, 6.069341171532869, 0.2615482185501605, 0.10020857909694314, 0.10738338824012317, 0.04168269828369375, 0.05771944088337477, 0.10094884171849117, 0.06024550006259233, 0.021617960301227868, 0.05835221083543729, 0.008888957836461486, 0.028501801170932595, 0.08399156882660463, 0.04702066224126611, 0.07432214159052819, 0.044740424636984244, 0.035331917970324866, 0.02768628106423421, 0.03626710196840577, 0.010896981239056913, 0.010396493544249097, 0.029942135406599846, 0.05057051785115618, 0.016741391409595963, 0.085528460185742, 0.02577396502601914, 0.03319464398373384, 0.004360680241006776, 0.08065582282142714, 0.036395111310412176, 0.04784367803949863, 0.019450647887424566, 0.02969535460579209, 0.021467582628247328, 0.024981110109365545, 0.03269773529609665, 0.028797906961699482, 0.044556731954799034, 0.08681849096319638, 0.011807473983935779, 0.10969072536681779, 0.06714094255585223, 0.04450557942618616, 0.019605049856181722, 0.032117936134454794, 0.0022069470423957682, 0.03282195597421378, 0.020207347224641126, 0.0181911564868642, 0.040027909344644286, 0.03101787660853006, 0.015604458276357036, 0.11191886791493744, 0.021487767189682927, 0.029297255459823646, 0.05276270705508068, 0.05317357114108745, 0.17889989248942584, 1.255354550667107, 30.249310433864594, 97.290990203619, 59.719503074884415, 45.98892085254192, 65.98369494080544, 53.63799400627613, 19.54455904662609, 0.6123472354374826, 1.2898590741679072, 1.1271119071170688, 3.539522420614958, 3.3029995998367667, 7.670058002695441, 2.015391429886222, 0.40521218616049737, 4.890937954187393, 72.36064195632935, 97.34684720635414, 91.29208490252495, 89.2079347372055, 88.20452257990837, 87.96082645654678, 86.97724163532257, 85.06060928106308, 85.04043236374855, 88.04784178733826, 78.81779506802559, 73.05477350950241, 71.4030173420906, 73.04440006613731, 69.47478801012039, 69.41712990403175, 67.60836616158485, 70.82604110240936, 72.8175750374794, 73.60987052321434, 74.2850486934185, 77.02169984579086, 78.07247266173363, 76.50084659457207, 75.77488794922829, 76.35451644659042, 71.86185032129288, 63.702779933810234, 60.243540555238724, 56.32279694080353, 56.71335518360138, 58.16454291343689, 59.53425541520119, 67.10566073656082, 66.68180868029594, 69.31593373417854, 70.81374496221542, 70.78143909573555, 72.25541040301323, 75.24381324648857, 67.59162425994873, 22.848077081143856, 61.448972672224045, 75.68025022745132, 71.29481434822083, 73.88106197118759, 68.2628658413887, 69.46569889783859, 67.72002696990967, 66.18771359324455, 63.049781173467636, 62.11092375218868, 54.68452624976635, 54.489102736115456, 53.4100404381752, 54.732757061719894, 55.68570792675018, 58.76003935933113, 57.4531564861536, 65.29487550258636, 69.22644853591919, 66.16574317216873, 67.21963182091713, 66.4362582564354, 65.73381274938583, 66.62022918462753, 68.53319093585014, 65.95689117908478, 67.95274928212166, 67.66420036554337, 66.7977024614811, 67.60376840829849, 67.23823562264442, 66.85472220182419, 72.69704550504684, 67.29997470974922, 61.61407381296158, 58.58999468386173, 63.86440426111221, 71.52733147144318, 79.81799259781837, 72.13118746876717, 73.88507455587387, 50.53793415427208, 11.362356450408697, 3.702375744469464, 0.3760360454907641, 0.7535063952673227, 2.6258393609896302, 3.3943011006340384, 4.440621268004179, 0.9158767887856811, 1.3978191185742617, 1.2617504387162626, 0.44803511642385274, 13.92358336597681, 48.23878772556782, 52.23632901906967, 26.181560307741165, 48.62132839858532, 62.8621244430542, 5.9743985161185265, 0.3306256915675476, 0.19587037560995668, 0.028477668383857235, 0.06525753502501175, 0.11314252100419253, 0.017792495164030697, 0.013887222248740727, 0.025447791122132912, 0.02602269025373971, 0.03149603493511677, 0.034594104436109774, 0.02393693801423069, 0.014685390015074518, 0.07871866153436713, 0.04729083368147258, 0.012416277204465587, 0.04685506683017593, 0.06717112570186146, 0.07159298998885788, 0.043722298214561306, 0.0156370663898997, 0.016334349384123925, 0.02974634200654691, 0.06735619506798685, 0.03737168859515805, 0.062251009439933114, 0.08808119586319663, 0.16389506170526147, 0.10450551766552962, 0.17525412171380594, 0.1304493157658726, 0.13947255501989275, 0.19639544509118423, 0.16460483690025285, 0.15264808083884418, 0.1665828682598658, 0.2558085374766961, 0.17412151530152187, 0.22081210365286097, 0.1786728695151396, 0.217387581942603, 0.1496769074583426, 0.15461714705452323, 0.2435285909450613, 0.1393435400677845, 0.10897826359723695, 0.17027288587996736, 0.18080734560498968, 0.14653628692030907, 0.1750673825154081, 0.20837035408476368, 0.1645869659841992, 0.12586211581947282, 0.16215436917264014, 0.20595098234480247, 0.23938725847983733, 0.18911847932031378, 1.4618437830358744, 53.443056866526604, 108.70127633213997, 82.24837258458138, 60.52676975727081, 69.29688915610313, 62.91570536792278, 24.521378092467785, 0.7663324289023876, 4.245326472446322, 6.365329613909125, 9.103814642876387, 27.651353739202023, 12.62192901223898, 1.1576557368971407, 0.5012786015868187, 6.097876690328121, 71.6604383289814, 101.00000157952309, 93.1202732026577, 94.45340126752853, 91.27949997782707, 93.4206622838974, 91.43992736935616, 86.14795133471489, 86.98717430233955, 91.90991654992104, 82.58182749152184, 76.51854604482651, 76.22349947690964, 76.50777742266655, 74.87573459744453, 73.53715762495995, 73.24340298771858, 74.25479471683502, 77.43956342339516, 78.13599765300751, 80.22459357976913, 79.94707927107811, 82.47771307826042, 78.25094908475876, 79.37732264399529, 78.50791409611702, 76.12946972250938, 66.98969855904579, 63.61432068049908, 58.57019014656544, 59.601903185248375, 59.539278745651245, 63.26345890760422, 68.79560485482216, 69.15908575057983, 70.5171936750412, 71.08071103692055, 76.0220418870449, 74.74541679024696, 76.87418416142464, 70.77449306845665, 25.72687290608883, 63.821983337402344, 74.7531607747078, 75.45574307441711, 75.34156680107117, 72.49245688319206, 71.62332952022552, 71.88614621758461, 67.88578167557716, 68.17578211426735, 64.76837575435638, 56.844748333096504, 56.62155590951443, 58.282214999198914, 57.760271206498146, 59.650198593735695, 61.42729863524437, 63.06740462779999, 67.59448930621147, 73.63598272204399, 70.8044658601284, 70.35899296402931, 72.44005769491196, 68.49094480276108, 70.65668419003487, 72.67463430762291, 69.75685447454453, 73.22473838925362, 72.69651353359222, 71.58991411328316, 69.2652216553688, 70.66131994128227, 71.52014225721359, 75.77931091189384, 71.34820908308029, 65.61048656702042, 63.007204458117485, 67.391367405653, 73.26677933335304, 82.7514959871769, 74.54868614673615, 77.56649181246758, 51.053418293595314, 11.642494518309832, 2.9182982677593827, 0.38689515029545873, 0.34320491657126695, 2.1120164450258017, 8.738202061504126, 16.64166111499071, 9.209274183958769, 7.795551018789411, 5.218901205807924, 0.6288607930764556, 11.610343493521214, 58.78566138446331, 53.556628972291946, 41.37658774852753, 63.69968309998512, 76.69018283486366, 15.76316250488162, 0.8802616561297327, 0.4190851526800543, 0.21357466466724873, 0.30190911842510104, 0.38080698635894805, 0.2500002522720024, 0.17260061722481623, 0.13024099491303787, 0.16143640066729859, 0.08418817858910188, 0.11075569986132905, 0.11957145688938908, 0.08227049867855385, 0.11471484991488978, 0.11523926630616188, 0.08026865922147408, 0.10070893506053835, 0.14844924677163363, 0.19697927782544866, 0.09498251616605558, 0.11849547634483315, 0.10535149180213921, 0.2131390685099177, 0.1739479714888148, 0.14291867322754115, 0.13149503152817488], [0.06139423705462832, 0.07469246585969813, 0.07602562283864245, 0.019596782331063878, 0.056188152739196084, 0.016844512829266023, 0.009163718532363418, 0.05379734626330901, 0.03792700430494733, 0.04049175164254848, 0.026275003765476868, 0.03999644970463123, 0.007223783932204242, 0.01719535943266237, 0.01879187679151073, 0.11603291903156787, 0.05479534935147967, 0.040014205587795004, 0.04369727670564316, 0.03646069861133583, 0.04089881222171243, 0.029101285799697507, 0.032596773526165634, 0.0591154503490543, 0.09910311302519403, 0.11484730843221769, 0.047620814802940004, 0.09296639036620036, 0.05808071466162801, 0.15206650423351675, 0.10237879701890051, 0.14330530248116702, 1.887154842261225, 57.62184463441372, 81.53031751513481, 38.71404021978378, 54.70005601644516, 66.76611095666885, 27.212205603718758, 0.5813733756076545, 0.2494448289508, 2.0317210536450148, 2.4229703843593597, 1.7511984938755631, 3.5018336679786444, 0.8765313250478357, 0.3401467634830624, 0.3410466620698571, 2.433608388528228, 75.81392705440521, 102.03267976641655, 95.56058585643768, 91.70033499598503, 85.4361279308796, 95.39340242743492, 87.93745771050453, 89.60460305213928, 83.79149258136749, 83.76935496926308, 77.8023299574852, 72.04308539628983, 65.27221351861954, 66.4153441786766, 68.6236184835434, 71.5653370320797, 69.57425907254219, 74.75357875227928, 74.4223353266716, 75.71385562419891, 73.83426368236542, 77.7422171831131, 74.59062829613686, 75.15913859009743, 71.9151158630848, 67.09460332989693, 60.12610785663128, 58.57108689844608, 56.23584620654583, 54.90843303501606, 52.21927933394909, 54.1778614372015, 53.8748162984848, 61.55162036418915, 61.701332330703735, 62.94846720993519, 65.75212776660919, 65.58370560407639, 64.73011180758476, 65.70809572935104, 21.663072668015957, 56.92066065967083, 71.66364535689354, 67.19332203269005, 66.76522180438042, 61.920865550637245, 61.14735625684261, 60.84422752261162, 60.968393459916115, 59.61935184895992, 53.94186370074749, 49.90781016647816, 51.2122193723917, 50.081164464354515, 53.337308540940285, 53.0870995670557, 54.40554901957512, 54.222197458148, 59.25338588654995, 63.484037071466446, 60.76366424560547, 60.310067385435104, 56.26219779253006, 59.381496012210846, 57.760442197322845, 59.46876212954521, 58.75011809170246, 58.56393188238144, 58.36228430271149, 64.46143582463264, 63.74732494354248, 64.10697564482689, 64.6654924750328, 65.6839594244957, 67.98216730356216, 61.74200914800167, 55.6990110129118, 69.96922507882118, 72.75459721684456, 72.48601242899895, 70.30565142631531, 64.64031502604485, 29.176572896540165, 2.0678393030539155, 0.7178574800491333, 0.26781262771692127, 2.90991164278239, 1.4503972535021603, 3.664743513800204, 0.9067232580855489, 0.9855905792210251, 0.5568947922438383, 0.6864575680810958, 3.5766654275357723, 26.00899826735258, 62.362607046961784, 26.127460710704327, 36.43773436546326, 62.11389899253845, 30.575726218521595, 0.439004841609858, 0.1602332160109654, 0.053371839603642, 0.04177805683866609, 0.010373702189099276, 0.010502398017706582, 0.11563832653337158, 0.08531461775419302, 0.033398701198166236, 0.030838445709377993, 0.022229176429391373, 0.03389905716176145, 0.01788684068742441, 0.03797918470809236, 0.03379352747288067, 0.043148246986675076, 0.05111831189424265, 0.09539282735204324, 0.038273713435046375, 0.04355397541075945, 0.016278539878840093, 0.05173280274902936, 0.01725584446830908, 0.04466691862035077, 0.04883182169578504, 0.017339352780254558, 0.007732850854154094, 0.034941511185024865, 0.023599231135449372, 0.09286033004173078, 0.04215150183881633, 0.04480021947529167, 0.009084638058993733, 0.09878424185444601, 0.026379544542578515, 0.0907374314556364, 0.05191561969695613, 0.015690040891058743, 0.051975336609757505, 0.044887533149449155, 0.02856864270142978, 0.0797336375399027, 0.01074800993592362, 0.04911542600893881, 0.025896944462147076, 0.032455910186399706, 0.06559847024618648, 0.017302098822256085, 0.07266502972925082, 0.03237076729419641, 0.031634671831852756, 0.053501095753745176, 0.0708140095230192, 0.08418580371653661, 0.045922702993266284, 0.1261625371989794, 0.20041476847836748, 0.21798836532980204, 0.15467181365238503, 3.304803315550089, 70.39477944374084, 97.93374091386795, 33.61313313245773, 67.28124931454659, 72.74327382445335, 39.35632735490799, 0.5890389299020171, 0.09635381953557953, 1.486926474608481, 0.2875296212732792, 2.4694414157420397, 5.189206274226308, 2.6312773441895843, 1.3694731146097183, 0.6437532033305615, 3.6828032322227955, 82.85340651869774, 102.65884056687355, 95.45843973755836, 93.61762091517448, 87.40256801247597, 96.31835639476776, 87.66480714082718, 89.30497393012047, 86.39122948050499, 87.69356399774551, 77.39318311214447, 75.18306970596313, 70.7232566177845, 70.52478566765785, 70.97112491726875, 75.04551708698273, 72.13530644774437, 79.30088594555855, 77.92106598615646, 79.83753114938736, 76.80454909801483, 79.95905622839928, 75.19756972789764, 77.77801126241684, 75.82375332713127, 71.25161066651344, 64.29699584841728, 63.510191068053246, 59.157726019620895, 58.95060293376446, 56.26879043877125, 58.88381011784077, 59.65317003428936, 66.45869225263596, 66.7795242369175, 68.49317908287048, 70.00352963805199, 71.53608620166779, 70.57818040251732, 69.71170529723167, 24.37409609556198, 63.022339046001434, 74.54849615693092, 72.52136573195457, 70.61653554439545, 68.69550302624702, 65.67528069019318, 65.6944240629673, 63.83504703640938, 63.85455518960953, 57.75171406567097, 54.38343420624733, 55.24018943309784, 55.497466027736664, 56.8510901927948, 58.16238842904568, 58.61022099852562, 59.90442395210266, 66.13111943006516, 69.37708765268326, 65.34751787781715, 66.29208639264107, 66.10797107219696, 65.76415792107582, 62.3136580735445, 65.59694409370422, 66.13186419010162, 66.10300093889236, 65.72783187031746, 69.52844113111496, 68.89406517148018, 68.87503579258919, 69.65051338076591, 70.69740280508995, 72.91633173823357, 66.44090160727501, 59.52684961259365, 73.55420351028442, 74.96356308460236, 76.66861519217491, 74.69744056463242, 70.37648722529411, 29.80903185904026, 2.418774222023785, 1.2237983127124608, 1.1076441267505288, 3.4349411074072123, 2.4899413157254457, 2.636360046453774, 0.9198861080221832, 1.4304075948894024, 1.6513916244730353, 1.89182621659711, 8.545874431729317, 33.74253138899803, 69.99570965766907, 34.87492382526398, 29.83062420040369, 71.63376376032829, 31.372541561722755, 0.5690977780614048, 0.21261563175357878, 0.07919964744360186, 0.04786251374753192, 0.016610257625870872, 0.03204345419362653, 0.029425049579003826, 0.08993242387077771, 0.032410947169410065, 0.05129984121595044, 0.038549016826436855, 0.12815526308258995, 0.017705034915707074, 0.03346128280099947, 0.009581865870131878, 0.0462537936255103, 0.034544977970654145, 0.06094514494179748, 0.04234764404827729, 0.05680758629750926, 0.05193841105210595, 0.06108928115281742, 0.01590454197867075, 0.07933191300253384, 0.037647374192602, 0.025759691670828033, 0.03780726619879715, 0.13940522738266736, 0.13809306576149538, 0.14332982304040343, 0.1514991174917668, 0.13168937031878158, 0.1449430442880839, 0.20158575876848772, 0.26599635486491024, 0.19141288823448122, 0.15025394211988896, 0.24784242821624503, 0.1892553165089339, 0.11503139074193314, 0.13243736611912027, 0.26503432367462665, 0.1745941149420105, 0.11670195031911135, 0.12099785730242729, 0.13765426352620125, 0.1368473857291974, 0.2899295190582052, 0.09008018547319807, 0.13140178809408098, 0.17277980135986581, 0.2894806978292763, 0.2709768485510722, 0.19822325091809034, 0.2280656324001029, 0.21013865451095626, 0.2486275165574625, 0.5060432490427047, 0.4734261258272454, 5.223241997882724, 94.38250467181206, 109.922234416008, 54.574544951319695, 75.48185527324677, 87.66957968473434, 46.158779338002205, 1.269864309579134, 0.41686212352942675, 7.121991086751223, 4.4965067692101, 9.04409134760499, 8.30813828855753, 2.309626741334796, 0.6321292708162218, 0.5719857418444008, 3.97506644949317, 83.90018194913864, 103.38862180709839, 103.9582872390747, 97.79782980680466, 91.17535516619682, 98.53881284594536, 89.77077573537827, 92.28963017463684, 89.02274787425995, 90.55266737937927, 84.20305609703064, 81.6807970404625, 72.79858365654945, 71.79766416549683, 74.93349149823189, 79.22540679574013, 76.83027371764183, 86.76961317658424, 82.47299373149872, 81.14475220441818, 80.26336669921875, 82.29563444852829, 78.02728548645973, 79.88372147083282, 79.50130239129066, 73.75045537948608, 68.30888137221336, 67.72032335400581, 64.06143888831139, 62.27374501526356, 59.63035985827446, 60.699337497353554, 62.05237649381161, 69.73835706710815, 68.09623718261719, 69.19080644845963, 73.48424926400185, 74.43906962871552, 74.21527683734894, 72.74301543831825, 29.07664205878973, 62.98771910369396, 78.32014337182045, 77.56336078047752, 73.09741482138634, 69.44458723068237, 67.78294399380684, 69.53803941607475, 66.4305129647255, 69.2035661637783, 61.35037176311016, 58.23987767100334, 59.26221281290054, 60.07881559431553, 61.15513823926449, 63.08546885848045, 61.95157550275326, 63.237285912036896, 68.7127996981144, 73.87072652578354, 70.39725691080093, 72.97472700476646, 69.19997155666351, 71.68920278549194, 66.63959294557571, 70.49329295754433, 70.33936321735382, 70.5583530664444, 69.38191339373589, 72.25897461175919, 73.9728194475174, 73.82122278213501, 74.63589906692505, 74.36877340078354, 76.38407126069069, 71.2270487844944, 62.26613022387028, 76.9051145017147, 77.19005361199379, 79.22935858368874, 80.07903099060059, 71.91744893789291, 31.764701418578625, 2.8359621483832598, 1.2439968413673341, 0.5749562324490398, 6.56129602342844, 8.011523354798555, 12.051576767116785, 4.689567284658551, 4.576598396524787, 3.4917865321040154, 3.1832205271348357, 5.455730147659779, 39.039032980799675, 81.07818737626076, 41.14230751991272, 53.39798368513584, 78.48425656557083, 52.34089560806751, 0.6723853794392198, 0.3496518940664828, 0.1611991657409817, 0.2799211529782042, 0.08734053990337998, 0.1143115594459232, 0.303724916302599, 0.1490737491985783, 0.16330578160705045, 0.1221476741193328, 0.13285188528243452, 0.24808687681797892, 0.12747349654091522, 0.17607409099582583, 0.14601853501517326, 0.15620669379131868, 0.13767894735792652, 0.2575559093384072, 0.13011358299991116, 0.17503014154499397, 0.13244633126305416, 0.11140499002067372, 0.07135641557397321, 0.13335485360585153, 0.20426289323950186, 0.1308396112290211, 0.09219591491273604], [0.04585522321576718, 0.04910555544483941, 0.021656585377058946, 0.03227388362574857, 0.06885083595989272, 0.12252222120878287, 0.08096029632724822, 0.007095670689523104, 0.03279095275502186, 0.05447573974379338, 0.05579043579928111, 0.06793938955524936, 0.04973052542482037, 0.13587787369033322, 0.034064856663462706, 0.029127242414688226, 0.03828665277978871, 0.046616425534011796, 0.0342589542560745, 0.055403487422154285, 0.006326486109173857, 0.033157239740830846, 0.016521051475137938, 0.054953352591837756, 0.09084349178010598, 0.04627337148122024, 0.06570873112650588, 0.07782429194776341, 0.19018562830751762, 0.039278440381167457, 0.23817101202439517, 0.25178015988785774, 0.50926802912727, 12.752985879778862, 68.58885034918785, 72.06881761550903, 35.44353291392326, 72.07884147763252, 65.0557467341423, 12.063293438404799, 0.21568104304606095, 0.1169754020520486, 0.614499463699758, 0.6276460457593203, 7.933905394747853, 2.9773297626525164, 0.8461657888256013, 0.6067875993903726, 0.46707301517017186, 3.0360487243160605, 43.768016025424004, 70.22699564695358, 73.78686502575874, 66.06953993439674, 64.3639026582241, 83.39774250984192, 94.68420848250389, 90.748121291399, 82.99405977129936, 79.62030440568924, 74.3298026919365, 74.4682976603508, 69.32666435837746, 69.99295860528946, 73.49615022540092, 75.55798038840294, 77.62747094035149, 79.45661678910255, 73.86407688260078, 76.59394159913063, 73.74656438827515, 75.88599398732185, 72.35148444771767, 72.19114825129509, 69.62548032402992, 63.27583484351635, 59.416568130254745, 57.764720767736435, 54.12236541509628, 54.53291818499565, 53.79569314420223, 55.26952385902405, 56.304949298501015, 61.255532652139664, 65.72011828422546, 69.36539188027382, 70.34917429089546, 65.46996250748634, 66.83376252651215, 26.82792842388153, 45.79976700246334, 73.45438286662102, 68.7073203921318, 71.0187515616417, 64.07033041119576, 63.659887835383415, 62.56424702703953, 59.28521677851677, 56.13309971988201, 53.14615219831467, 50.244753286242485, 52.062932923436165, 50.15610784292221, 51.46523639559746, 53.374584540724754, 52.60976918041706, 53.50930631160736, 59.34697486460209, 59.90579567849636, 61.89059257507324, 58.38616222143173, 57.88629524409771, 56.91325105726719, 55.88013209402561, 53.73637452721596, 56.87222085893154, 57.323081865906715, 60.65645679831505, 61.82390235364437, 62.621148973703384, 62.367539182305336, 64.44616824388504, 68.28020811080933, 68.18813145160675, 58.22134226560593, 58.59410606324673, 67.85542890429497, 69.93817314505577, 78.19304019212723, 65.05415081977844, 51.2804751098156, 13.214890994131565, 0.19568329502362758, 2.253201906569302, 1.0686605935916305, 3.2229041727259755, 4.18940344825387, 2.1178460447117686, 1.5608103037811816, 0.08406639215536416, 1.2179092224687338, 5.225358009338379, 18.51485799998045, 71.2929980456829, 44.5529019087553, 31.687550358474255, 61.402409970760345, 47.34687678515911, 3.339318288490176, 0.3041352942818776, 0.14748734916793182, 0.15470334008568898, 0.030100624753686134, 0.12964494642801583, 0.06381949773640372, 0.07217535327072255, 0.026756453517009504, 0.13560644059907645, 0.1013207393407356, 0.03764893270272296, 0.06896926046465524, 0.04864170201472007, 0.05517205237993039, 0.037881918833591044, 0.15200385212665424, 0.03919179092918057, 0.018570000611362047, 0.0255656905574142, 0.07582067875773646, 0.023173321860667784, 0.021660958482243586, 0.05661028262693435, 0.05869213673577178, 0.007036050719761988, 0.0476259504648624, 0.047225569214788266, 0.03821594094915781, 0.008309744971484179, 0.020809859815926757, 0.04272579055395909, 0.05154368496732786, 0.07153257174650207, 0.02491150222340366, 0.05515908334928099, 0.04775256085849833, 0.03972465667175129, 0.026576870477583725, 0.060905996651854366, 0.02634699580084998, 0.032954830094240606, 0.06406703367247246, 0.07049761712551117, 0.008659089653519914, 0.052918550645699725, 0.07187586699728854, 0.047509422147413716, 0.029790974767820444, 0.013664295001944993, 0.06734446171321906, 0.023514130916737486, 0.05343480341252871, 0.053016473320894875, 0.017558527542860247, 0.1105706008092966, 0.12482444493798539, 0.04910947769531049, 0.038513957770192064, 0.28293329291045666, 0.6275470729451627, 16.849604956805706, 85.307846814394, 67.74214178323746, 37.511792331933975, 99.87422838807106, 64.53235521912575, 20.803247205913067, 0.5237770755775273, 0.5101777834352106, 0.6960250984411687, 1.4061996876262128, 3.4859683318063617, 3.152286149561405, 1.8833039863966405, 2.2075509186834097, 0.5563979095313698, 5.452396301552653, 53.88534173369408, 78.10885950922966, 82.19478785991669, 70.52383571863174, 70.57580932974815, 85.17967209219933, 95.56868702173233, 88.26390579342842, 84.65048208832741, 84.86951753497124, 80.3923773765564, 76.18011340498924, 71.7335008084774, 71.94115206599236, 74.71489682793617, 81.63168087601662, 78.25673997402191, 80.97525849938393, 79.0519917011261, 80.28319403529167, 78.76175567507744, 77.17234656214714, 75.02060562372208, 77.71063327789307, 76.39501467347145, 67.75167167186737, 64.13241147994995, 61.58413901925087, 57.519512325525284, 59.50747825205326, 56.33899547159672, 59.82587456703186, 59.708707854151726, 65.73502868413925, 69.65459436178207, 75.38375213742256, 74.67849478125572, 71.27327710390091, 73.06953951716423, 30.005743503570557, 51.75799548625946, 77.04669490456581, 74.86286848783493, 76.74917086958885, 67.79761880636215, 68.99460017681122, 66.36549845337868, 63.68167586624622, 61.741446778178215, 57.74112783372402, 54.78347294032574, 57.666028663516045, 56.12564831972122, 56.493141800165176, 57.901821210980415, 59.20086890459061, 59.522084668278694, 64.97697696089745, 65.52404120564461, 69.05485734343529, 66.42650797963142, 65.27626410126686, 64.17164817452431, 64.72393333911896, 60.86706429719925, 63.905540853738785, 64.78155344724655, 66.65816634893417, 68.5122312605381, 67.88160189986229, 66.44999831914902, 70.60081198811531, 73.45182180404663, 72.76934802532196, 63.406354039907455, 63.43109451234341, 74.48589071631432, 75.60711175203323, 82.69557818770409, 70.83205237984657, 56.167351081967354, 13.74296385794878, 0.1453341857995838, 3.8406792981550097, 1.0910912649706006, 2.5362062081694603, 1.9425597880035639, 0.5007018044125289, 1.2213229830376804, 1.1626464128494263, 2.3978914925828576, 9.923848640173674, 25.47708570957184, 71.01441979408264, 66.94616049528122, 27.486814968287945, 63.536877036094666, 53.78487132489681, 3.5986413108184934, 0.6840206519700587, 0.16173168638488278, 0.09385398414451629, 0.09293570998124778, 0.15694076690124348, 0.023482086835429072, 0.10136324213817716, 0.12637682491913438, 0.047451709033339284, 0.0425974880636204, 0.0782051843998488, 0.10439542747917585, 0.0253534678631695, 0.030509392272506375, 0.03549151311744936, 0.14414164354093373, 0.01623864758585114, 0.06268499142606743, 0.009683374973974423, 0.05203030006668996, 0.07887351806857623, 0.08886675917892717, 0.03454884827078786, 0.07934228080557659, 0.04389070636534598, 0.02653538998856675, 0.07539304584497586, 0.14559426403138787, 0.07799977276590653, 0.06290557255852036, 0.12250483268871903, 0.12622628768440336, 0.2085000221268274, 0.16779896628577262, 0.06842197850346565, 0.14408613089472055, 0.15650163812097162, 0.12626257870579138, 0.15138117538299412, 0.11881010985234752, 0.28956043417565525, 0.20685064344434068, 0.14426679932512343, 0.17532695608679205, 0.16617627523373812, 0.137566942430567, 0.26995734544470906, 0.09461539797484875, 0.14965817565098405, 0.14694100973429158, 0.21595795318717137, 0.20110034965910017, 0.3191399766365066, 0.1878141993074678, 0.2819145022658631, 0.3048858430702239, 0.23259607289219275, 0.39478355669416487, 0.6906515930313617, 1.5895098075270653, 31.347595900297165, 102.74690464138985, 91.08911499381065, 53.20110484957695, 93.9946822822094, 83.87072592973709, 23.15718099474907, 0.7753812870942056, 0.5856901220977306, 4.224895443767309, 2.5479150423780084, 17.109894789755344, 12.039853446185589, 1.3306781463325024, 1.4094007783569396, 0.6586045876611024, 5.372901717200875, 51.35708659887314, 76.56798899173737, 80.82832798361778, 73.08253481984138, 69.81414020061493, 84.25297021865845, 96.05815395712852, 94.60104614496231, 87.37289920449257, 86.81628987193108, 84.96858581900597, 83.91989529132843, 77.02340975403786, 77.33328312635422, 80.1152278482914, 84.88104611635208, 81.87373548746109, 86.70810207724571, 82.8755821287632, 85.06464466452599, 80.02556025981903, 80.93919083476067, 77.49562561511993, 80.43513268232346, 78.66505846381187, 70.09013459086418, 67.84047290682793, 64.42729845643044, 59.791740998625755, 63.823913633823395, 60.42808525264263, 61.97936341166496, 61.172035932540894, 70.09103894233704, 73.70508581399918, 80.93046650290489, 77.2165609896183, 74.96958196163177, 73.78480553627014, 35.09271673858166, 52.320737689733505, 80.07574796676636, 78.0240860581398, 79.5291168987751, 70.4826307296753, 71.76630824804306, 69.81918632984161, 68.0514831840992, 65.06209999322891, 62.49831296503544, 58.784088268876076, 62.51393772661686, 59.67175103724003, 61.223454773426056, 63.27743075788021, 63.27767014503479, 65.01853913068771, 71.38701260089874, 69.97573032975197, 75.51004976034164, 72.25729510188103, 72.88125962018967, 70.22837117314339, 70.71255639195442, 67.00657725334167, 71.14019304513931, 70.00715464353561, 74.23197314143181, 73.70713770389557, 73.78086894750595, 73.74262779951096, 76.10623016953468, 77.46649637818336, 80.76969712972641, 68.86882692575455, 67.40356475114822, 76.84164270758629, 79.28899258375168, 84.20025184750557, 72.09302231669426, 57.62202702462673, 14.918060302734375, 0.4665115656098351, 3.663329277187586, 3.1101188622415066, 8.406810443848372, 10.963808186352253, 5.413419418036938, 2.7238463144749403, 2.021034602075815, 2.8067994257435203, 7.231649877503514, 33.62704038619995, 86.90398916602135, 63.610802069306374, 46.55879147350788, 75.07699459791183, 70.35013183951378, 7.722422992810607, 0.9593590430449694, 0.45994970365427434, 0.40162413963116705, 0.19598208367824554, 0.264748745248653, 0.17855684214737266, 0.21122673206264153, 0.13199071196140721, 0.11213079560548067, 0.199073766998481, 0.12933848396642134, 0.13844775297911838, 0.153790038311854, 0.18379478686256334, 0.11986895420704968, 0.21694094262784347, 0.11873826995724812, 0.2125852630706504, 0.15238611755194142, 0.15453545143827796, 0.14736787823494524, 0.21999400458298624, 0.1781699902494438, 0.2394910849398002, 0.1102879316022154, 0.11437893903348595, 0.19266594521468505], [0.07083870077622123, 0.012427202545950422, 0.048949273987091146, 0.025595359766157344, 0.0721887119289022, 0.059007401068811305, 0.05754066492954735, 0.07985325690242462, 0.03837846757960506, 0.04414558214193676, 0.07280755176907405, 0.10621334789902903, 0.021596833212242927, 0.024295491821249016, 0.03524159859807696, 0.07763511850498617, 0.06425159095670097, 0.012798204024875304, 0.010014587132900488, 0.0905811128905043, 0.015336478954850463, 0.08884286202373914, 0.010926918548648246, 0.04143304722674657, 0.06550314879859798, 0.05565182487771381, 0.02026122900133487, 0.053286522306734696, 0.017268496230826713, 0.08706857988727279, 0.08432073358562775, 0.06727947926265188, 0.12146520253736526, 1.5072340099141002, 37.520205080509186, 79.34848219156265, 54.43935200572014, 24.697578437626362, 85.68375304341316, 58.2703672349453, 6.677640555426478, 0.19764814584050328, 0.29150943271815777, 0.8426131575834006, 1.8917565140873194, 2.191871297545731, 5.573547100648284, 0.7266620232257992, 0.21195549139520153, 0.5283381370827556, 0.038759790477342904, 2.330716559663415, 7.533142324537039, 11.807383820414543, 16.612978354096413, 32.016082629561424, 74.6905705332756, 91.55513718724251, 89.51153084635735, 84.73546832799911, 71.61222651600838, 71.03447511792183, 75.37650972604752, 79.08891052007675, 80.51348447799683, 81.92379400134087, 77.09894210100174, 75.72578698396683, 71.84471324086189, 77.15491309762001, 77.85174250602722, 75.74902653694153, 78.11622351408005, 72.37622871994972, 67.58239835500717, 58.44629779458046, 62.3246318846941, 56.782253086566925, 57.6229427754879, 54.51138474047184, 52.65471316874027, 53.093319833278656, 57.567233964800835, 60.34862391650677, 67.53733277320862, 69.13411349058151, 71.98789715766907, 65.1315526664257, 71.94404751062393, 21.502044908702374, 47.46112145483494, 65.20751819014549, 71.13842234015465, 69.22874361276627, 67.14948758482933, 64.59762811660767, 61.09987020492554, 61.52507118880749, 59.52484332025051, 52.49993987381458, 53.62295441329479, 51.04605428874493, 50.325419157743454, 51.87653012573719, 53.6718387901783, 53.981468975543976, 54.04796540737152, 58.82653199136257, 58.22347015142441, 60.28863273561001, 56.89890682697296, 55.84298528730869, 58.21880020201206, 58.0904620885849, 55.60960181057453, 54.010837599635124, 54.34020392596722, 54.85595405101776, 63.045517802238464, 63.90690118074417, 64.11577597260475, 66.05959966778755, 71.405578404665, 69.46924790740013, 68.10325920581818, 68.75340431928635, 74.39895898103714, 80.12145951390266, 68.70051875710487, 68.14932033419609, 28.096492253243923, 3.0874637654051185, 5.751774637028575, 2.3029756732285023, 6.235526679083705, 3.0338602792471647, 1.280334647744894, 0.43629526044242084, 0.9518284408841282, 1.0044890432618558, 9.340018518269062, 23.210978507995605, 73.79443421959877, 45.13903185725212, 15.32549249008298, 53.98983612656593, 59.18627388775349, 24.19423084706068, 0.15543460787739605, 0.17303561966400594, 0.09694718886748888, 0.27158499404322356, 0.06660994331468828, 0.02555392751673935, 0.023893620709714014, 0.03236608434235677, 0.04283987349481322, 0.07970068618305959, 0.033321246955893, 0.031536481983494014, 0.11110558538348414, 0.06622608969337307, 0.018659781926544383, 0.027264815398666542, 0.08111642193398438, 0.03662928116682451, 0.06940687526366673, 0.11430862054112367, 0.053555673293885775, 0.07740227709291503, 0.061594906364916824, 0.07622293021995574, 0.07286192150786519, 0.0906036444939673, 0.025787876584217884, 0.04294044934795238, 0.08753144255024381, 0.0314005279506091, 0.05052760687249247, 0.05463923116622027, 0.09134108695434406, 0.010696698773244862, 0.05986163530906197, 0.04386048240121454, 0.07757916799164377, 0.026868035420193337, 0.046170695350156166, 0.09879786768578924, 0.11898274082341231, 0.08225089855841361, 0.10918351938016713, 0.05740792068536393, 0.0033047330452973256, 0.08242332172812894, 0.04348992806626484, 0.11208684562006965, 0.041514123149681836, 0.06299584740190767, 0.0465473724034382, 0.07268170578754507, 0.018106098941643722, 0.14521470002364367, 0.057801518705673516, 0.08687421141075902, 0.06878583124489523, 0.11041389632737264, 0.09181371628073975, 0.1960131648229435, 0.11786799048422836, 2.2665828885510564, 46.925950571894646, 100.29874920845032, 43.206565752625465, 39.083889573812485, 118.1527827680111, 61.54565088450909, 13.763276617974043, 0.5175990227144212, 0.5510035052429885, 0.03178835948347114, 1.3747556624002755, 0.7399820897262543, 4.00881671346724, 1.2086785677820444, 0.5459037632681429, 0.8299298537895083, 0.45344834157731384, 4.922644877806306, 11.573691610246897, 16.269928961992264, 20.446740835905075, 40.708553194999695, 77.83143639564514, 95.11262029409409, 91.76746979355812, 84.76417198777199, 74.5453043282032, 74.70166593790054, 76.51977717876434, 79.84250128269196, 78.89192149043083, 79.94589373469353, 84.88853931427002, 81.95797696709633, 77.21042811870575, 82.30101495981216, 79.83088910579681, 76.40661165118217, 79.33798715472221, 76.02943629026413, 71.25113189220428, 63.942277282476425, 65.71510255336761, 61.72872506082058, 60.65094329416752, 59.145103096961975, 58.127597495913506, 57.322386503219604, 61.92128732800484, 66.48146063089371, 72.10297018289566, 75.144023001194, 74.94703397154808, 68.72185081243515, 74.37777131795883, 24.56693384796381, 50.946039855480194, 71.0299077630043, 76.41300290822983, 72.00222998857498, 70.43665319681168, 66.97433978319168, 65.42391657829285, 65.62983512878418, 64.78388652205467, 58.68497058749199, 57.95542113482952, 56.92788407206535, 56.371236741542816, 55.93270227313042, 59.04310517013073, 59.56173174083233, 58.45759838819504, 64.62411269545555, 65.70086851716042, 68.09253618121147, 64.73509714007378, 66.7692419886589, 66.73118323087692, 66.93605303764343, 64.22629684209824, 63.244539722800255, 62.69095502793789, 63.045912981033325, 66.14429712295532, 68.03563043475151, 67.34744936227798, 68.21583196520805, 72.66749829053879, 74.7686867415905, 70.08446529507637, 73.70739609003067, 77.3755444586277, 84.75204303860664, 69.68965128064156, 74.93190318346024, 29.19580366462469, 3.912346540018916, 7.81958662904799, 2.9658828768879175, 5.321104321628809, 2.0904478523880243, 1.4218392921611667, 0.4529271461069584, 1.4015075331553817, 1.5380232827737927, 15.62156405299902, 32.97297768294811, 72.13738113641739, 74.62639197707176, 19.606452025473118, 50.8905628323555, 69.19082164764404, 27.352684065699577, 0.3427869389997795, 0.3721186041366309, 0.07059348776238039, 0.2221622335491702, 0.032665570615790784, 0.04527585821051616, 0.08157509146258235, 0.04948979498294648, 0.02956600939796772, 0.04927833113470115, 0.06969749287236482, 0.025454091955907643, 0.07308179760002531, 0.07372506894171238, 0.07349443170824088, 0.0631793137290515, 0.09444409544812515, 0.07246554785524495, 0.02443663903250126, 0.03667947261419613, 0.005874333564861445, 0.03859945689328015, 0.09092168445931748, 0.016634702114970423, 0.008298876218759688, 0.02182391926908167, 0.011637976731435629, 0.06071995507227257, 0.15005149907665327, 0.12859657377703115, 0.12780327728250995, 0.17384331382345408, 0.20238540804712102, 0.06766230872017331, 0.22034852852812037, 0.1592001464450732, 0.14033283776370808, 0.07701125432504341, 0.17639164114370942, 0.28952338616363704, 0.21980414836434647, 0.14373084995895624, 0.16447669768240303, 0.34456399676855654, 0.10930961769190617, 0.1703859743429348, 0.16259891563095152, 0.20783575542736799, 0.09341276250779629, 0.21802668983582407, 0.21923671709373593, 0.2196727436967194, 0.147669279249385, 0.25039863714482635, 0.20213223178870976, 0.2266199138830416, 0.20203642052365467, 0.2203462427132763, 0.20654027728596702, 0.30696207541041076, 0.19972078618593514, 2.403642958961427, 73.56823235750198, 110.52887186408043, 71.32050856947899, 44.05800126492977, 103.90509769320488, 79.23183605074883, 14.12823848426342, 0.5083905137144029, 0.7822194357868284, 3.6623710161074996, 5.588645590469241, 9.529530499130487, 15.156603902578354, 1.7295960593037307, 0.5276381433941424, 1.1542891175486147, 0.48874966450966895, 3.753721439279616, 9.565708357840776, 12.76894312351942, 20.58965876698494, 37.90799327194691, 78.89451295137405, 94.16552111506462, 97.99855023622513, 89.9829563498497, 82.39775016903877, 77.5048515200615, 82.72992834448814, 81.78076967597008, 85.00989720225334, 85.91767609119415, 93.22276890277863, 88.69884565472603, 83.36144685745239, 90.06993368268013, 83.03063660860062, 79.56954672932625, 82.32036352157593, 78.7454241514206, 75.72317272424698, 66.97305545210838, 69.08185869455338, 63.754103779792786, 66.08272522687912, 62.201119512319565, 58.799652233719826, 58.90504337847233, 64.68858003616333, 68.29774037003517, 73.58343154191971, 77.27285876870155, 79.35875684022903, 72.17303842306137, 75.29106751084328, 29.47632361203432, 56.96224942803383, 75.68674027919769, 80.67320510745049, 76.17591843008995, 75.95853969454765, 73.01347732543945, 69.03443723917007, 69.37156274914742, 68.2649177312851, 63.50527413189411, 62.58405916392803, 61.175387352705, 59.39242422580719, 60.14191500842571, 65.74859395623207, 63.75828355550766, 63.824179619550705, 70.14513283967972, 71.44270241260529, 72.65647128224373, 71.7112948000431, 73.25048580765724, 74.3853785097599, 75.80955728888512, 71.76041096448898, 70.95977112650871, 70.17663314938545, 69.12047982215881, 72.46808499097824, 73.3795040845871, 72.53931596875191, 74.88962665200233, 80.23616015911102, 79.63915139436722, 77.247004956007, 79.67261239886284, 81.51447996497154, 86.84671863913536, 75.62908217310905, 77.2512075304985, 33.00884775817394, 4.452750217169523, 8.399438839405775, 6.39727639965713, 11.853294856846333, 9.600422345101833, 4.756909171119332, 0.9187479503452778, 3.3764617703855038, 2.0940115861594677, 13.942851182073355, 40.22991567850113, 94.3354631960392, 59.52839232981205, 27.866532392799854, 68.446623980999, 77.73805260658264, 43.016366958618164, 0.5574870260898024, 0.6186002749018371, 0.29591974918730557, 0.45879230950959027, 0.09944066405296326, 0.13077152660116553, 0.18930670281406492, 0.14810943219345063, 0.14520261785946786, 0.1664049012470059, 0.26064279838465154, 0.12531169457361102, 0.2006497175898403, 0.10942211243673228, 0.23586368974065408, 0.33638374821748585, 0.15630646812496707, 0.20814572082599625, 0.2993152232374996, 0.20123233320191503, 0.19993271387647837, 0.1992039693868719, 0.27928436058573425, 0.21117595431860536, 0.14715345692820847, 0.26904159458354115, 0.14392812765436247, 0.13082620804198086], [0.07367091442574747, 0.06160253564303275, 0.02950906997284619, 0.025914537072821986, 0.050960215885424986, 0.03522569066262804, 0.07385952383629046, 0.07223140026326291, 0.0950374425156042, 0.08463533740723506, 0.03327720049128402, 0.15349421824794263, 0.06749959284206852, 0.10157287659239955, 0.036122193923802115, 0.013088201940263389, 0.0272793429394369, 0.08046272341744043, 0.026047669089166448, 0.01813469203625573, 0.03435343336605001, 0.027753144859161694, 0.043871755624422804, 0.0717274374619592, 0.09791561737074517, 0.06644185428740457, 0.04568596159515437, 0.06219311078893952, 0.04348702997958753, 0.0710022404382471, 0.07063121855026111, 0.06954166412469931, 0.24844527477398515, 0.31791020825039595, 5.969460681080818, 71.21485903859138, 76.82147338986397, 55.09834684431553, 30.78470930457115, 94.46442067623138, 60.173654705286026, 7.6451455894857645, 0.169185669219587, 0.5835253070108593, 1.3780895085074008, 1.307904899585992, 1.3685840810649097, 2.894942108541727, 0.5284845479764044, 0.10577461987850256, 0.061757473813486286, 0.42316352133639157, 2.7351036854088306, 0.5782349815126508, 1.1546118627302349, 1.868862030096352, 14.117961935698986, 68.57283040881157, 95.69958999752998, 80.63417360186577, 75.47966659069061, 87.95825779438019, 92.50887840986252, 88.17188993096352, 83.25337305665016, 79.07463848590851, 78.1070128083229, 78.88524144887924, 82.51718536019325, 77.28377938270569, 73.5015307366848, 73.44644129276276, 77.2288191318512, 69.3326984345913, 70.89078202843666, 61.912745386362076, 60.20330831408501, 61.53677836060524, 61.48757480084896, 60.063076838850975, 58.47734592854977, 54.27474483847618, 55.82461707293987, 56.185574904084206, 67.03484773635864, 72.81472519040108, 73.44068080186844, 66.84466794133186, 66.58325716853142, 32.92503945529461, 68.36882695555687, 59.040597304701805, 69.68809336423874, 73.08198004961014, 67.33874022960663, 66.3061760365963, 61.36693127453327, 59.786725267767906, 57.64553256332874, 54.3367613106966, 51.01752921938896, 51.65076144039631, 55.78721567988396, 53.48148040473461, 55.8575689047575, 55.44460326433182, 57.83046863973141, 58.64115513861179, 59.31572534143925, 58.43799144029617, 58.10133330523968, 55.60337774455547, 53.27624201774597, 51.06841988861561, 50.82825377583504, 52.06474542617798, 60.281040742993355, 61.18890702724457, 61.71114340424538, 62.17135950922966, 70.52925422787666, 72.42844551801682, 66.93597704172134, 69.75173234939575, 66.84159770607948, 67.42213055491447, 70.61873182654381, 71.56812608242035, 83.46849471330643, 43.89823503792286, 0.8298346807714552, 32.134514674544334, 49.91394303739071, 11.713855639100075, 2.264283774420619, 2.183991470374167, 0.4339517361950129, 0.23426779021974653, 0.4051011905539781, 15.054653473198414, 24.94749292731285, 70.54727286100388, 43.90755973756313, 13.211930003017187, 51.26377500593662, 53.81729498505592, 50.95061480998993, 0.660590099869296, 0.13153967913240194, 0.04421216021000873, 0.0295946080586873, 0.009676757799752522, 0.039055773813743144, 0.0702351491781883, 0.01745035951898899, 0.10895595463807695, 0.038880148276803084, 0.033799319935496897, 0.08162238853401504, 0.08563062423490919, 0.037388186538009904, 0.045980668437550776, 0.17254565376788378, 0.03790199763898272, 0.029731153954344336, 0.04100592268514447, 0.03416155479499139, 0.06180429962114431, 0.029170149682613555, 0.050457781908335164, 0.06982503095059656, 0.021036385551269632, 0.014521121192956343, 0.06576264815521426, 0.015031753118819324, 0.052378445252543315, 0.020818450175283942, 0.06171788765641395, 0.03805116932198871, 0.06667511130217463, 0.023591818935528863, 0.030903951374057215, 0.007738569565844955, 0.03657300410850439, 0.08090143659501337, 0.04703469996456988, 0.07863521444960497, 0.06703896404360421, 0.08081372958258726, 0.03836418494756799, 0.06892626042827033, 0.04896978323813528, 0.041914248358807527, 0.056518241472076625, 0.021498899404832628, 0.052190908245393075, 0.009887658543448197, 0.04249012526997831, 0.14831122214673087, 0.04142656827752944, 0.08258631220087409, 0.09384577599121258, 0.05308132960635703, 0.02092441402055556, 0.03823275430477224, 0.03641346462245565, 0.28372617380227894, 0.13528857874916866, 0.30308589746709913, 0.4182754398789257, 8.526404276490211, 82.13204562664032, 87.69100293517113, 35.819427743554115, 51.20058439671993, 126.73745691776276, 62.802676633000374, 15.11935355141759, 0.2209102304186672, 0.3380530164577067, 0.8689700870309025, 1.0217731283046305, 0.1984023756813258, 2.30464497115463, 1.4317097375169396, 1.220189337618649, 0.2918229455826804, 1.0458321310579777, 3.918065708130598, 1.349152042530477, 2.368038631975651, 2.076946939341724, 20.551419518887997, 76.02415457367897, 95.13139888644218, 84.45999830961227, 81.5185609459877, 85.38690537214279, 89.13177162408829, 82.92419672012329, 86.53034001588821, 82.00306534767151, 80.24052992463112, 74.66689020395279, 79.28471401333809, 79.46601748466492, 76.28616571426392, 75.45947447419167, 80.91242507100105, 75.69592818617821, 77.11045548319817, 66.09132036566734, 64.1691555082798, 64.98738840222359, 64.10279586911201, 62.476399540901184, 60.649199187755585, 57.76776820421219, 59.71676342189312, 60.71660377085209, 71.70290485024452, 78.44612941145897, 78.9976242184639, 73.50434258580208, 71.1586220562458, 36.605301573872566, 69.39598023891449, 66.89436927437782, 75.92425033450127, 77.17698991298676, 72.76352673768997, 71.31195902824402, 66.08223125338554, 66.81323602795601, 63.16265791654587, 58.904997780919075, 57.566154822707176, 58.12674254179001, 59.78906974196434, 57.73358143866062, 58.927439376711845, 60.33243678510189, 61.37189760804176, 63.397135734558105, 66.45632117986679, 66.15674525499344, 65.47615617513657, 65.44843286275864, 63.463472574949265, 60.6209971010685, 61.33399844169617, 61.797698959708214, 67.11740970611572, 66.8500104546547, 69.35924381017685, 64.56203922629356, 69.05657485127449, 77.04704448580742, 71.25110149383545, 73.78618106245995, 71.05380088090897, 72.64963924884796, 73.14922884106636, 75.6144605576992, 86.02565109729767, 46.575096398591995, 0.9533053147606552, 35.807405188679695, 57.09427334368229, 12.185991704463959, 4.126596143469214, 0.46734873787499964, 0.6789432931691408, 0.31005507975351065, 0.9877262427471578, 26.22245941311121, 35.78123979270458, 70.92096760869026, 82.03240737318993, 16.560525968670845, 44.94588442146778, 63.726646453142166, 55.030307695269585, 0.5787376232910901, 0.3152542101452127, 0.050357302534393966, 0.07905008984380402, 0.020009240179206245, 0.0391349943674868, 0.06535166161484085, 0.05452322235214524, 0.05480113439261913, 0.04575392005790491, 0.08168080297764391, 0.030705259887326974, 0.05485953399329446, 0.024878324511519168, 0.03011445838637883, 0.04020262203994207, 0.03067919195018476, 0.035692850360646844, 0.0514177016884787, 0.022911930027476046, 0.03233233146602288, 0.01848718249675585, 0.04454871675989125, 0.034091262277797796, 0.017428275059501175, 0.04931673356622923, 0.035983935522381216, 0.04405404564749915, 0.018793305425788276, 0.08521906624082476, 0.19115413102554157, 0.13703554985113442, 0.12590216210810468, 0.12544835364678875, 0.1066718615766149, 0.14689386851387098, 0.20432898891158402, 0.1688231449224986, 0.2632565831299871, 0.12179928031400777, 0.1613515435019508, 0.23429939086781815, 0.19581294822273776, 0.14519671036396176, 0.12061291272402741, 0.20672032231232151, 0.16449266870040447, 0.18962395610287786, 0.1833279908169061, 0.2465016790665686, 0.09262570747523569, 0.27467983891256154, 0.23238653491716832, 0.18425151938572526, 0.2703275583917275, 0.18050492042675614, 0.1314013873343356, 0.13455164094921201, 0.17383414087817073, 0.46371963573619723, 0.2526116027729586, 0.5194492859300226, 0.7307988731190562, 15.225268118083477, 109.33506712317467, 98.76936927437782, 71.98298022150993, 51.79192006587982, 113.91825199127197, 84.60809156298637, 16.925228498876095, 0.278845276334323, 1.832749005407095, 2.9124608309939504, 1.1803734116256237, 5.055606393143535, 12.447803355753422, 1.378520072903484, 0.7465036085341126, 0.2451372702489607, 1.2057244637981057, 6.167333638295531, 1.317696855403483, 1.145777574274689, 2.0478960731998086, 17.796776331961155, 75.07241204380989, 98.20764541625977, 87.6584766805172, 86.64552703499794, 93.53622928261757, 97.05913424491882, 89.09865260124207, 91.21083766222, 88.63586783409119, 88.2360152900219, 80.76397463679314, 84.02968659996986, 79.52062055468559, 77.53604784607887, 78.59828844666481, 85.1931993663311, 78.81322771310806, 81.10264286398888, 69.63649973273277, 67.25317642092705, 69.50471520423889, 69.64909985661507, 68.15022468566895, 66.41737326979637, 59.79171819984913, 63.20190221071243, 61.84721030294895, 73.3877344429493, 83.16930636763573, 80.03358542919159, 77.33065366744995, 71.59347832202911, 45.48652321100235, 80.38824319839478, 73.94945070147514, 79.78725224733353, 80.72119653224945, 74.96024206280708, 73.52317437529564, 71.57385617494583, 69.7570064663887, 69.19843643903732, 63.96560803055763, 61.02406047284603, 61.632464826107025, 68.25965121388435, 63.45515102148056, 63.92114281654358, 64.30797725915909, 67.38815277814865, 70.14861345291138, 74.68860983848572, 73.65479931235313, 73.51886540651321, 74.62088987231255, 70.82689225673676, 69.60417106747627, 69.80097770690918, 71.54511451721191, 75.81624493002892, 75.62323808670044, 76.2928381562233, 71.81258216500282, 76.11311540007591, 80.67678451538086, 77.45690569281578, 81.0482069849968, 75.09958818554878, 77.00779259204865, 78.42836156487465, 80.86712390184402, 90.00392362475395, 48.0160740762949, 1.547781634144485, 37.43725933134556, 69.14886429905891, 18.212793208658695, 9.981694836169481, 5.004878165200353, 1.8905644468031824, 0.9118760784622282, 0.6146169011481106, 21.62543758749962, 42.09824502468109, 83.51363629102707, 61.4297267049551, 20.815535746514797, 73.90440791845322, 70.36593899130821, 75.91225817799568, 1.425473797135055, 0.7003118027932942, 0.19013673561858013, 0.14812146982876584, 0.12178008095361292, 0.20576614304445684, 0.16818923206301406, 0.19359229394467548, 0.14805785292992368, 0.27687923808116466, 0.1937463934882544, 0.2080429927445948, 0.14638242486398667, 0.18926503864349797, 0.0866567918274086, 0.22371584549546242, 0.160397304862272, 0.18158747639972717, 0.219286544888746, 0.08705845699296333, 0.17057350021786988, 0.10792485176352784, 0.1858175845700316, 0.20413926627952605, 0.10758334508864209, 0.10687127665732987, 0.12227492275997065, 0.10863004048587754, 0.1187776705774013], [0.030146630488161463, 0.03357755878823809, 0.05537107041163836, 0.012262239815754583, 0.0458823969529476, 0.01432068844223977, 0.03184964232787024, 0.05454819191072602, 0.05276342693832703, 0.06343412271235138, 0.14791365363635123, 0.04761776828672737, 0.03618278286012355, 0.05741675224271603, 0.05263311693852302, 0.07067668993840925, 0.06093290321587119, 0.03274705843068659, 0.0416674174630316, 0.010874295639951015, 0.09625362959923223, 0.04122845937672537, 0.0972822611220181, 0.022150751829030924, 0.06797666763304733, 0.08874069055309519, 0.05910550557018723, 0.1385228880099021, 0.05819931728183292, 0.1764341810485348, 0.10416399614769034, 0.17458982532843947, 0.18166770256357267, 0.48877748020458966, 0.941356677794829, 18.927764743566513, 74.09420773386955, 84.08162981271744, 54.82023976743221, 24.721735641360283, 86.71680361032486, 71.61345764994621, 15.87583215907216, 1.369303073734045, 0.47095489280764014, 0.47129417303949594, 0.6867779383901507, 1.264564306475222, 1.0313354339450598, 2.1404479444026947, 0.09403702002600767, 0.6553692393936217, 2.6024133805185556, 3.084032549522817, 0.9423403500113636, 0.44927364215254784, 0.45419108297210187, 6.9007284846156836, 74.10465717315674, 88.80637988448143, 71.64178133010864, 88.9894388616085, 86.79698690772057, 85.85380911827087, 85.90756863355637, 90.12052416801453, 88.43996554613113, 93.55833649635315, 86.1044816672802, 77.77127042412758, 72.6922957599163, 74.28488910198212, 73.21514770388603, 70.34776076674461, 64.38655704259872, 63.143541142344475, 62.58368298411369, 64.86977711319923, 65.11329084634781, 65.04627004265785, 64.5878778398037, 62.5973242521286, 57.93437786400318, 54.81870464980602, 63.03717344999313, 67.08389550447464, 70.55405169725418, 65.00579461455345, 75.21225214004517, 31.537739597260952, 37.11307592689991, 73.08247402310371, 71.43743589520454, 71.18706732988358, 66.19726628065109, 64.92939591407776, 61.30958095192909, 61.102792248129845, 53.87546606361866, 53.8010660558939, 56.35753467679024, 59.67566482722759, 61.49418644607067, 63.60426642000675, 60.242495611310005, 64.98253986239433, 61.926276460289955, 63.826581090688705, 60.429297387599945, 62.4401418864727, 57.92984090745449, 53.94922010600567, 50.53440034389496, 52.998647913336754, 52.398960292339325, 54.2219352722168, 53.4806102514267, 58.96308906376362, 62.26986542344093, 70.21207004785538, 68.26678723096848, 74.36409205198288, 70.85583910346031, 80.93843847513199, 76.4678643643856, 81.24470204114914, 84.4410753250122, 72.53345668315887, 20.272314995527267, 1.6012264788150787, 0.04330154501076322, 24.225026294589043, 38.41142825782299, 6.152237998321652, 1.3068314571864903, 1.41340576345101, 0.39852879010140896, 0.07766729802824557, 20.560197047889233, 21.516107954084873, 70.19907474517822, 36.25351645052433, 6.740969382226467, 54.14174057543278, 52.03561618924141, 67.73970991373062, 5.248531540855765, 0.2386297780321911, 0.23301057721255347, 0.0592456527374452, 0.0726210129505489, 0.050373848716844805, 0.08800779745797627, 0.0708483783819247, 0.03537104399583768, 0.03418832777242642, 0.06318646803265437, 0.05628983068163507, 0.06231497143744491, 0.034061171900248155, 0.051761004360741936, 0.0197400149772875, 0.019386511485208757, 0.08597557447501458, 0.04189341627352405, 0.06722872378304601, 0.05159933120012283, 0.05901678181544412, 0.05717248175642453, 0.08099899932858534, 0.028443078736017924, 0.05433039383206051, 0.01887807167804567, 0.06552925013238564, 0.056247851098305546, 0.06419017823645845, 0.09799827035749331, 0.04036478501802776, 0.07495491154259071, 0.05407002987340093, 0.016243475256487727, 0.01954916057002265, 0.10418846475658938, 0.05257206044916529, 0.04631279065506533, 0.1049004663946107, 0.05783994711237028, 0.01986878316529328, 0.07810182549292222, 0.023271717655006796, 0.025664223649073392, 0.01597375281562563, 0.08295957537484355, 0.05970363949018065, 0.015531601638940629, 0.07593811620608903, 0.12818536459235474, 0.07584900653455406, 0.13788006937829778, 0.07480421103537083, 0.20039795141201466, 0.13796397659461945, 0.03485823850496672, 0.17613470961805433, 0.07958844376844354, 0.09327258565463126, 0.07907391278422438, 0.241179485747125, 0.15044114144984633, 0.6483398540876806, 1.0150237404741347, 25.59395983815193, 85.90681627392769, 87.12223425507545, 34.65792886912823, 49.71194587647915, 117.55177661776543, 71.04252308607101, 24.076336473226547, 0.6227126636076719, 0.5275683815125376, 1.0870523191988468, 0.9746658685617149, 0.47794340061955154, 0.5624598311260343, 1.8902521510608494, 0.7709176547359675, 1.8012737506069243, 7.72919375449419, 8.478464148938656, 2.290097214281559, 2.0858159009367228, 0.5758695490658283, 10.987209230661392, 82.00360491871834, 86.37611389160156, 72.60066747665405, 88.91875505447388, 85.3593036532402, 94.69085812568665, 86.28702387213707, 90.31698882579803, 91.82166248559952, 93.51985976099968, 86.6653847694397, 81.44437372684479, 72.03239277005196, 74.49007049202919, 79.72251892089844, 75.70433333516121, 68.51557508111, 69.57599177956581, 68.22379633784294, 71.34370252490044, 70.66508933901787, 72.58609145879745, 68.38452771306038, 64.92348343133926, 62.91649952530861, 59.65456075966358, 67.36656993627548, 71.58356845378876, 76.43479093909264, 71.32505312561989, 77.41064697504044, 39.39446210861206, 49.99798312783241, 77.67205014824867, 75.80049857497215, 75.79156145453453, 69.69940915703773, 70.19421100616455, 69.2752531170845, 67.53703638911247, 61.25189244747162, 58.44591401517391, 60.62413953244686, 64.07480657100677, 67.08827286958694, 68.66112247109413, 65.80720961093903, 66.79699569940567, 68.36343884468079, 69.0634372830391, 67.11547940969467, 70.59669300913811, 67.88148030638695, 64.75530445575714, 60.591111704707146, 62.85963177680969, 62.795628011226654, 64.45289388298988, 65.10889828205109, 66.78840056061745, 65.3489238023758, 73.95062863826752, 74.319778829813, 78.32513630390167, 73.5352273285389, 84.45981591939926, 80.10046944022179, 82.58701801300049, 84.81324255466461, 74.62690114974976, 21.23599648475647, 1.8483293568715453, 0.08705905813258141, 31.259949803352356, 48.51783715188503, 5.322912549600005, 1.0422322992235422, 2.135035372339189, 0.3994077304378152, 0.24534470052458346, 38.44991259276867, 32.76540242135525, 63.84932667016983, 69.4316603243351, 10.642224792391062, 33.92229974269867, 56.1078804731369, 73.69534313678741, 6.111581604927778, 0.705678005469963, 0.021451097672979813, 0.08355485944775864, 0.13561847823439166, 0.07940845811390318, 0.059847311858902685, 0.07639996954821981, 0.05125796182255726, 0.10361299602664076, 0.01938020137458807, 0.025750867534952704, 0.049438197165727615, 0.05043568817200139, 0.08118025405565277, 0.034276858568773605, 0.014141062729322584, 0.04020730128104333, 0.03226256216294132, 0.02832356698490912, 0.03721912900800817, 0.06949406277271919, 0.03357318382768426, 0.02031149280810496, 0.009280908288928913, 0.03065706667257473, 0.07520130457123742, 0.020452593635127414, 0.033613983396207914, 0.010890743487834698, 0.28523377259261906, 0.15460087917745113, 0.1650194005924277, 0.16863293247297406, 0.09514758465229534, 0.14731840667081997, 0.1202788126829546, 0.13760838395683095, 0.17747268313542008, 0.1533641791320406, 0.2469999570166692, 0.18814760172972456, 0.16070623125415295, 0.19988692336482927, 0.09204597881762311, 0.1963076341780834, 0.161304535868112, 0.17852997640147805, 0.26610506465658545, 0.17907024506712332, 0.21955505391815677, 0.14273652050178498, 0.16622766153886914, 0.12490342429373413, 0.3165267559234053, 0.3047171380603686, 0.1512056723004207, 0.30454445513896644, 0.17871704214485362, 0.20753508171765134, 0.30558874597772956, 0.28255390701815486, 0.3443471115315333, 0.6758032366633415, 1.3761389069259167, 42.54082627594471, 106.84655785560608, 104.23469960689545, 71.10392019152641, 42.76050768792629, 105.80772399902344, 93.62965106964111, 31.49542696774006, 1.5729365218430758, 0.3643909766105935, 0.8358305809088051, 3.348453948274255, 2.3314140597358346, 6.225289078429341, 5.9053832944482565, 0.9557574894279242, 2.186712361872196, 7.112648813053966, 6.137628257274628, 1.9614315940998495, 1.5445139282383025, 0.6958416989073157, 9.28159000352025, 78.85669738054276, 95.51365077495575, 81.43698692321777, 91.94465428590775, 89.49553370475769, 99.11631345748901, 95.80425158143044, 98.06084409356117, 100.99766090512276, 98.43529880046844, 89.3566207587719, 86.45372852683067, 77.00847655534744, 79.70690935850143, 80.01806706190109, 78.73849332332611, 72.7004425227642, 74.53759834170341, 73.78624945878983, 75.32978743314743, 74.40778210759163, 74.76426377892494, 71.13619565963745, 70.90978100895882, 66.28727585077286, 63.33557903766632, 69.96398895978928, 72.30397179722786, 78.32708939909935, 75.21830141544342, 80.66441237926483, 43.057210966944695, 46.142615005373955, 83.3816009759903, 79.3185929954052, 79.34533596038818, 73.6980713903904, 73.69789659976959, 71.14416003227234, 69.89126086235046, 63.86320352554321, 61.97385750710964, 66.64522424340248, 69.75652009248734, 71.16626724600792, 74.55402866005898, 69.77219045162201, 74.9443893134594, 73.02789375185966, 74.26282748579979, 73.25143575668335, 77.7174425125122, 75.1664949953556, 72.93836295604706, 68.346126973629, 72.33347341418266, 70.8827492594719, 73.74850988388062, 74.71425086259842, 75.20523011684418, 74.47585925459862, 80.6765641272068, 79.55004617571831, 84.44615185260773, 81.43439546227455, 88.05652812123299, 86.29847645759583, 86.26563861966133, 91.167793571949, 76.89880684018135, 21.140574105083942, 2.069851295091212, 0.14269690465880558, 33.47983628511429, 58.49248431622982, 9.36607277020812, 3.452318524941802, 3.9100680872797966, 0.47255641780793667, 0.29218941810540855, 29.112018160521984, 37.02805928885937, 83.01909282803535, 51.246721521019936, 13.671142011880875, 79.17497590184212, 64.60113152861595, 90.20206019282341, 11.149396877735853, 1.3198752072639763, 0.3710006031906232, 0.24131556594511494, 0.2251372067257762, 0.1971441978821531, 0.15903341554803774, 0.19062736944761127, 0.15415269619552419, 0.17101430625189096, 0.16834101610584185, 0.18198424339061603, 0.2286403367179446, 0.2177373561426066, 0.1600800664164126, 0.21759516064776108, 0.15203905961243436, 0.13351800735108554, 0.20086106640519574, 0.15638843091437593, 0.12422313462593593, 0.11272223535343073, 0.12935666658449918, 0.24407311953837052, 0.1891892950516194, 0.15080434852279723, 0.1109000995347742, 0.11762010573875159, 0.23467331455321983, 0.11363610858097672], [0.031155949473031797, 0.045264570144354366, 0.057714739377843216, 0.05547067034058273, 0.041589002139517106, 0.04106386586499866, 0.040734723370405845, 0.04065383669512812, 0.1511807064525783, 0.04405528132338077, 0.1990181059227325, 0.11216844475711696, 0.013793700509268092, 0.08057579703745432, 0.030077076407906134, 0.049026468477677554, 0.04480592659092508, 0.06695361706078984, 0.05383621624787338, 0.003514854302011372, 0.07595376810058951, 0.08940687941503711, 0.08269370839116164, 0.008215269572247053, 0.014341833157232031, 0.09650085383327678, 0.059974382384098135, 0.03197411904693581, 0.09878737371764146, 0.09824831475270912, 0.06129991750640329, 0.08437341122771613, 0.12725417705951259, 0.18012810236541554, 0.24160580505849794, 1.0874042753130198, 48.410219326615334, 87.09185108542442, 75.08220791816711, 54.072751477360725, 36.34872034192085, 78.15182000398636, 83.63779082894325, 26.73589166253805, 9.523941949009895, 0.9812725859228522, 0.13936999021098018, 0.4504765151068568, 1.3963116682134569, 0.06565756004420109, 3.0485253548249602, 1.7008885997347534, 0.9197079332079738, 3.4943076968193054, 5.110512021929026, 0.3507343016099185, 0.8993628155440092, 0.10919348642346449, 8.863900266587734, 48.85617099702358, 74.34522986412048, 91.60758957266808, 94.33007508516312, 75.30134975910187, 70.76365604996681, 69.99995782971382, 82.63567060232162, 88.89638185501099, 88.64398419857025, 79.50780004262924, 68.84061723947525, 59.6871630102396, 66.94836437702179, 60.491477251052856, 61.71911917626858, 63.55573162436485, 65.44486105442047, 62.05881714820862, 66.50165274739265, 66.08032375574112, 74.07909214496613, 70.50817295908928, 70.72923749685287, 59.65358421206474, 62.16603219509125, 62.106466591358185, 76.3892237842083, 64.25445333123207, 83.9264765381813, 14.611410107463598, 7.091114418581128, 83.00885617733002, 76.24399557709694, 74.09256622195244, 62.079712226986885, 62.38604038953781, 58.52604031562805, 59.763949289917946, 56.63827881217003, 65.66247537732124, 66.4898581802845, 73.03344905376434, 76.12938612699509, 74.60928529500961, 78.09428349137306, 73.68455171585083, 72.00786128640175, 69.07946482300758, 65.44640377163887, 64.32300165295601, 56.26295015215874, 56.45871564745903, 52.16708533465862, 46.37283705174923, 45.18932595849037, 47.002919241786, 54.741846174001694, 59.61090110242367, 54.76417377591133, 37.459784522652626, 25.1846818998456, 24.6801620721817, 29.317549131810665, 49.84340362250805, 54.62708093225956, 53.209916576743126, 39.74501229822636, 7.582169668748975, 0.38156967668328434, 0.27242014766670763, 1.3570682052522898, 2.439003149047494, 2.7132318215444684, 1.5276055480353534, 0.9563091129530221, 0.9522414905950427, 1.7540659150108695, 26.677213311195374, 20.543363951146603, 75.59358447790146, 39.662853106856346, 9.938186220824718, 60.572040528059006, 56.26602418720722, 73.50785359740257, 18.66632167249918, 0.22336145513691008, 0.30986259633209556, 0.04182319426035974, 0.13211521465564147, 0.05174457321118098, 0.06802179763326421, 0.016930431265791412, 0.02918495738413185, 0.03548941655026283, 0.028704461292363703, 0.0970191994565539, 0.05190910735109355, 0.024674842461536173, 0.05709925033443142, 0.0009435027777726646, 0.021021444263169542, 0.05165374917851295, 0.052848031773464754, 0.05427910771686584, 0.051910235415562056, 0.036862115157418884, 0.05089692924229894, 0.07205158530268818, 0.07494979814509861, 0.05917337126447819, 0.03281522098404821, 0.05385075121012051, 0.06600153807085007, 0.025369988070451654, 0.07380533963441849, 0.02744252637057798, 0.029513341032725293, 0.026015589755843394, 0.09611865520128049, 0.08055903934291564, 0.04334648576332256, 0.07746612405753694, 0.05359591254091356, 0.17851894808700308, 0.06188356470374856, 0.07456628591171466, 0.054951756974332966, 0.031491348272538744, 0.0086661307796021, 0.07063260636641644, 0.02981829322379781, 0.038547398944501765, 0.01396629437294905, 0.03487401285383385, 0.061045390539220534, 0.03415465653233696, 0.08659286322654225, 0.12222116158227436, 0.015814293110452127, 0.10413183146738447, 0.04498188980505802, 0.06167672072479036, 0.05503029846295249, 0.1064190712349955, 0.11020042496966198, 0.06609000949538313, 0.011763680777221452, 0.17876315920148045, 0.14971621159929782, 0.2362418733537197, 1.5976435085758567, 58.88997718691826, 96.44683510065079, 76.54724210500717, 27.020564787089825, 59.84447456896305, 121.21362492442131, 83.20403650403023, 40.05682356655598, 9.807710722088814, 1.4970509125851095, 0.25931616488378495, 0.7656138518359512, 0.36741905787494034, 1.1210222588852048, 1.1341164750047028, 2.584897270426154, 0.9480273979716003, 4.355937112122774, 11.726796794682741, 1.673283912241459, 1.7477003065869212, 0.25741166551597416, 11.616496313363314, 60.69176830351353, 83.60016524791718, 93.40374559164047, 96.07771530747414, 81.04471117258072, 81.65314972400665, 82.1124766767025, 82.21963092684746, 84.4296683371067, 80.65397813916206, 76.30772575736046, 76.89917162060738, 69.8614552617073, 75.43374225497246, 69.76313173770905, 72.35187202692032, 72.16187462210655, 74.12772953510284, 70.4989318549633, 73.64398509263992, 71.74726366996765, 80.1688201725483, 75.57699456810951, 75.56700110435486, 61.88623420894146, 66.28943413496017, 70.19087478518486, 81.92243367433548, 70.72774797677994, 89.7430220246315, 18.215768449008465, 8.952431716024876, 86.61607101559639, 82.88744509220123, 80.20263075828552, 66.97482615709305, 67.66839534044266, 64.4481897354126, 64.95070517063141, 62.84686826169491, 68.16094771027565, 72.20443993806839, 75.95526427030563, 78.68894398212433, 79.59439739584923, 80.8490900695324, 77.58432805538177, 75.42703181505203, 73.6094981431961, 72.83466652035713, 70.18870890140533, 64.00463193655014, 64.5673817396164, 62.7490159124136, 58.59385147690773, 57.90948159992695, 58.36161933839321, 65.4700917005539, 68.03176984190941, 65.38225561380386, 47.558825612068176, 33.20004589855671, 37.25657902657986, 43.910253793001175, 59.36873249709606, 63.0301970243454, 60.61488702893257, 42.384419068694115, 8.58648095279932, 0.6079076486639678, 0.35931091639213264, 2.020421647466719, 1.9292689324356616, 1.3981285644695163, 0.617758323205635, 1.3240922684781253, 0.9499356080777943, 3.123777941800654, 53.065714314579964, 28.999230712652206, 64.4403013586998, 82.03905701637268, 11.19276775047183, 34.673876613378525, 56.49680480360985, 80.49807250499725, 18.439076766371727, 0.2902788034407422, 0.29827425722032785, 0.09445896066608839, 0.1156688881746959, 0.04524946001765784, 0.020019294424855616, 0.04652969444578048, 0.03655625754618086, 0.02434720838209614, 0.03979542416345794, 0.0143773616218823, 0.13327109481906518, 0.022719871485605836, 0.042299738415749744, 0.04804146410606336, 0.012434421787475003, 0.04327099821239244, 0.01375422196360887, 0.04496725094213616, 0.01247346524905879, 0.055191173814819194, 0.028447179101931397, 0.031595790715073235, 0.02636382956552552, 0.05686315460479818, 0.03311290383862797, 0.062410270620603114, 0.003650961866696889, 0.07922865057480522, 0.03048925966140814, 0.13108584098517895, 0.17938203614903614, 0.1272420206805691, 0.17989450396271423, 0.20974976912839338, 0.1588763325707987, 0.14280610426794738, 0.11947229111683555, 0.22484681918285787, 0.1131635089404881, 0.27636819519102573, 0.20487063797190785, 0.08517243710230105, 0.15815076447324827, 0.18463293876266107, 0.15389147505629808, 0.18633227882673964, 0.10326225703465752, 0.19749423925532028, 0.12754138821037486, 0.12830453866627067, 0.155568209302146, 0.22448687755968422, 0.10602784808725119, 0.1765808294294402, 0.22754989913664758, 0.10849744838196784, 0.17470347782364115, 0.17712132073938847, 0.33024983829818666, 0.1325091763283126, 0.12244425859535113, 0.30133178690448403, 0.19882783410139382, 0.27603010239545256, 1.4266219292767346, 82.87522494792938, 113.92784267663956, 99.82262715697289, 69.1696947813034, 59.84002500772476, 95.54924726486206, 102.51155287027359, 45.69322071969509, 11.416869275271893, 0.9538634691853076, 0.4510319384280592, 2.8803720278665423, 2.704883669503033, 4.756313553079963, 7.6537996251136065, 5.702961506322026, 3.5779575956985354, 6.405436461791396, 11.169630791991949, 0.4752840776927769, 1.0970483953133225, 0.22797004377935082, 9.559063464403152, 53.35485979914665, 84.12914246320724, 99.99224245548248, 104.73564952611923, 92.3273241519928, 92.79925882816315, 89.45004254579544, 89.54509824514389, 86.38447344303131, 84.74227756261826, 80.8562944829464, 83.7895242869854, 73.23706492781639, 80.55304035544395, 75.52591010928154, 77.5070022046566, 77.42803484201431, 80.96164762973785, 76.65645584464073, 79.67186003923416, 77.54701405763626, 87.80378848314285, 79.79866683483124, 81.53102427721024, 66.39868587255478, 72.19697713851929, 72.76746332645416, 87.35282108187675, 75.5025565624237, 95.20946189761162, 20.045216381549835, 8.784200493246317, 87.77255415916443, 86.53095558285713, 83.6931386590004, 71.79998204112053, 70.7364647090435, 68.41178745031357, 68.69391471147537, 68.13691779971123, 72.1453607082367, 77.2913333773613, 80.6263992190361, 87.20874801278114, 85.7649014890194, 89.25199717283249, 82.80581787228584, 82.27645307779312, 80.59042274951935, 81.9119842350483, 78.9138463139534, 73.46943005919456, 74.75504547357559, 72.90325284004211, 70.388562977314, 71.42216071486473, 71.05062425136566, 74.5766070485115, 76.65458634495735, 72.69475042819977, 48.88147383928299, 34.35385398566723, 37.990502044558525, 46.37756019830704, 63.16723667085171, 65.49966171383858, 60.88879153132439, 44.1166815161705, 7.8115548100322485, 0.7418938027694821, 0.32010634196922183, 2.607113253325224, 5.0187835190445185, 4.385648667812347, 3.356891395524144, 2.742415680550039, 1.1984021379612386, 3.211518321186304, 34.83625330030918, 36.64849765598774, 87.33180060982704, 60.453479290008545, 16.67072005569935, 87.28550389409065, 69.47823822498322, 94.98002260923386, 28.08824859559536, 0.6422426062636077, 0.4531179671175778, 0.209260827396065, 0.2865741803543642, 0.13059868040727451, 0.1587134163128212, 0.1784748348291032, 0.09869689849438146, 0.148248866898939, 0.14026591088622808, 0.25883973576128483, 0.28876627678982913, 0.15282521664630622, 0.13600954553112388, 0.1370042163762264, 0.11993148014880717, 0.18205045780632645, 0.13466901902575046, 0.15598314406815916, 0.14756070304429159, 0.14812847570283338, 0.1778577093500644, 0.2302145803696476, 0.10939191444776952, 0.17572393087903038, 0.1543067066813819, 0.12107905567972921, 0.12759682664182037, 0.1635446195723489, 0.15421059855725616], [0.07581293815746903, 0.048925573501037434, 0.09233432545443065, 0.1260289060883224, 0.06514213848276995, 0.08123932158923708, 0.013933879217802314, 0.05339599651051685, 0.015504577258980135, 0.06916492027812637, 0.16867798083694652, 0.056665190422791056, 0.014123770688456716, 0.06467783605330624, 0.12860905670095235, 0.04188166065432597, 0.03633580628957134, 0.004264198259988916, 0.06389579793903977, 0.04215677850879729, 0.0598448293749243, 0.11883406637934968, 0.10384132518083788, 0.040111831403919496, 0.09847316323430277, 0.08173285721568391, 0.0472405234904727, 0.05646713718306273, 0.01613144064322114, 0.3058032860280946, 0.05131675105076283, 0.10987309331540018, 0.0582328957534628, 0.18850662308977917, 0.09324575701612048, 0.05368100348277949, 0.2663646679138765, 60.20608216524124, 85.03176122903824, 87.36301213502884, 66.58308997750282, 20.108302496373653, 60.091924890875816, 71.28362774848938, 34.09919165074825, 25.298008918762207, 0.8384133735671639, 0.617414026055485, 0.3398874867707491, 0.33259276882745326, 1.0222796886228025, 0.8139205409679562, 2.4821448465809226, 8.306753262877464, 6.785462144762278, 8.206454794853926, 0.4208983381977305, 0.2656811202177778, 4.447251912206411, 1.5507834730669856, 8.227573111653328, 14.318855255842209, 30.960947647690773, 47.5518985837698, 52.00049087405205, 63.28841596841812, 77.23822742700577, 88.23456376791, 93.5943053662777, 91.1345985531807, 78.14858257770538, 57.16955870389938, 49.849403500556946, 51.355171501636505, 51.00016035139561, 50.32655529677868, 55.64883470535278, 60.330897867679596, 65.67072853446007, 64.35687303543091, 67.32766762375832, 64.27706971764565, 71.09045371413231, 65.66674634814262, 66.67022690176964, 55.34587696194649, 69.07614380121231, 54.998013228178024, 78.51785436272621, 12.953371927142143, 5.232836008071899, 83.72526213526726, 67.34931126236916, 72.43684306740761, 55.97567796707153, 61.3731325417757, 57.76139974594116, 65.3682267665863, 70.45917838811874, 77.56356596946716, 72.9116503894329, 78.79836291074753, 73.90041053295135, 80.13959974050522, 73.81811454892159, 76.23925343155861, 75.88462606072426, 73.00996631383896, 71.84705391526222, 62.93026998639107, 62.16751791536808, 57.81400792300701, 49.91946414113045, 49.8513375967741, 44.58513177931309, 41.39766901731491, 37.47774615883827, 25.609833486378193, 8.24548440054059, 1.504616781603545, 0.4661426291568205, 0.09862974897259846, 0.2845177485141903, 0.5785444274079055, 0.13542176457121968, 0.4587509570410475, 0.5967632622923702, 0.2121025405358523, 0.15901913662673905, 0.3203189227497205, 2.3969548428431153, 1.8662252090871334, 0.5559413996525109, 0.3456973750144243, 0.8007274707779288, 11.421914454549551, 31.144304908812046, 16.557421535253525, 89.03948977589607, 44.56255339086056, 9.781125448644161, 56.04491405189037, 61.15008071064949, 57.37329997122288, 11.916304025799036, 0.10234888104605488, 0.11202668712940067, 0.051189799269195646, 0.05252153874607757, 0.050151872346759774, 0.07503613960579969, 0.04772473774210084, 0.053015464000054635, 0.014049990077182883, 0.03930836377548985, 0.030669735133415088, 0.06011504905472975, 0.0289525167318061, 0.03206772613339126, 0.040299116080859676, 0.07722796144662425, 0.07353022549068555, 0.07981776740052737, 0.0284080048368196, 0.06056739548512269, 0.05243988023721613, 0.01218696748765069, 0.05655478482367471, 0.03145591443171725, 0.024497524827893358, 0.02983140882861335, 0.03826289663265925, 0.009114693184528733, 0.024697817498235963, 0.07907755672931671, 0.05267407606879715, 0.062053731744526885, 0.040540666595916264, 0.08262278875918128, 0.13520728389266878, 0.055905791523400694, 0.10318164495402016, 0.13169548561563715, 0.023871671692177188, 0.04541785332548898, 0.061221372307045385, 0.09986774035496637, 0.10844747957889922, 0.09107501216931269, 0.08954959441325627, 0.053061206272104755, 0.09431114711333066, 0.031441316386917606, 0.08637706894660369, 0.08545955177396536, 0.012187389584141783, 0.035829676417051814, 0.0691612837545108, 0.04984488296031486, 0.057506774755893275, 0.11282667779596522, 0.12011466445983388, 0.07853913601138629, 0.07421325368341058, 0.029785375263600145, 0.11556469806237146, 0.04727156752778683, 0.12260808027349412, 0.07596127121360041, 0.073709350253921, 0.03835174655250739, 0.09543656211462803, 1.2167125241830945, 74.544278383255, 91.18474826216698, 79.51039910316467, 45.63803628087044, 34.73342701792717, 108.61850157380104, 69.03588116168976, 53.65772254765034, 36.57013066112995, 0.738007501931861, 0.5324118747375906, 0.397061831317842, 0.5172053875867277, 0.352167270029895, 0.48624868621118367, 2.1213100338354707, 4.512860141694546, 3.5679194843396544, 4.90794014185667, 2.727559427730739, 0.8987965271808207, 2.8168769599869847, 4.08676240593195, 12.399909775704145, 25.615126602351665, 45.54955042898655, 65.44267237186432, 70.24469509720802, 77.78718397021294, 87.57706984877586, 92.86025315523148, 94.98487874865532, 91.83102518320084, 81.3112136721611, 67.08084806799889, 63.689317256212234, 62.10571803152561, 62.62940213084221, 64.28044393658638, 67.8345300257206, 71.42884075641632, 77.0675253868103, 70.86046725511551, 75.88120624423027, 71.03200525045395, 79.52929928898811, 72.56732806563377, 73.53062197566032, 61.00032314658165, 75.89170128107071, 61.14901676774025, 87.51963213086128, 15.666907969862223, 5.830135932192206, 92.3222704231739, 73.82021203637123, 79.73057448863983, 64.39671009778976, 65.94920799136162, 62.13864706456661, 68.47376212477684, 74.67452019453049, 81.5225887298584, 78.39331984519958, 83.39920163154602, 80.41649088263512, 84.12324517965317, 77.60926231741905, 81.05117082595825, 81.13260045647621, 77.29242011904716, 75.66887363791466, 71.84072345495224, 70.56542068719864, 69.93115112185478, 60.868956595659256, 59.557122588157654, 58.66356633603573, 55.65715245902538, 51.96465499699116, 33.24790433049202, 12.57157601416111, 3.1806466402485967, 0.6333935935981572, 0.15117803472094238, 0.5769182334188372, 1.4296704344451427, 0.2686698973411694, 0.27458015363663435, 0.9356152452528477, 0.5546204361598939, 0.6169964047148824, 1.4251371589489281, 2.0784119982272387, 0.9598008880857378, 0.5700166756287217, 0.46565150551032275, 0.7928931224159896, 17.174297533929348, 68.02170038223267, 14.097855314612389, 73.21785315871239, 85.83328261971474, 9.325928874313831, 36.670445278286934, 56.944812163710594, 65.35075530409813, 12.531078737229109, 0.16392096265917644, 0.19138774427119642, 0.027875606647285167, 0.07732047757599503, 0.019949476882175077, 0.027108185131510254, 0.07903546211309731, 0.06380907056154683, 0.026761116059788037, 0.037972887585056014, 0.02428649884677725, 0.08042131899856031, 0.057292694837087765, 0.042924708395730704, 0.09806890055187978, 0.023249232435773592, 0.0430233064253116, 0.05572840709646698, 0.06291119061643258, 0.11167877572006546, 0.07725273433607072, 0.04572232312057167, 0.0357135970989475, 0.03900527437508572, 0.015058264489198336, 0.018371719161223155, 0.01936311527970247, 0.05166866634681355, 0.03474639313935768, 0.019473448519420344, 0.025228725826309528, 0.18697558727581054, 0.1369173702551052, 0.2800579753238708, 0.2636754512786865, 0.13907167653087527, 0.21612618322251365, 0.21702729893149808, 0.19870137213729322, 0.1270201036822982, 0.10238237417070195, 0.2424439272726886, 0.17806190386181697, 0.12784179474692792, 0.13380478805629537, 0.21719460870372131, 0.14975517435232177, 0.1194614780251868, 0.22819881822215393, 0.19908828340703622, 0.1983081377693452, 0.1564107250305824, 0.21213048981735483, 0.23281384870642796, 0.26049804990179837, 0.18540967052103952, 0.19441842305241153, 0.12994131568120793, 0.1435705163748935, 0.20253870607120916, 0.36742748867254704, 0.1043032601592131, 0.16010439401725307, 0.1724670603289269, 0.22638210008153692, 0.19742486329050735, 0.1602772847400047, 2.6734092459082603, 101.993617862463, 107.44753360748291, 111.42028883099556, 80.92683389782906, 34.96888518333435, 80.66055178642273, 84.73907053470612, 56.40322342514992, 34.4303210824728, 2.04091917257756, 1.250044098123908, 0.7918796455487609, 2.117962413467467, 2.9294254956766963, 4.905930049717426, 12.424685396254063, 19.019520319998264, 19.030285142362118, 19.03607413172722, 2.205795175395906, 0.3077356010908261, 7.647032663226128, 5.311852768063545, 11.183768883347511, 18.29638872295618, 37.182874381542206, 58.59359309077263, 68.69677975773811, 80.9246452152729, 88.55452939867973, 94.83306929469109, 97.05400452017784, 97.89445102214813, 84.82071295380592, 81.91481128334999, 69.06795144081116, 71.45918592810631, 71.38367637991905, 74.78361994028091, 78.45879033207893, 80.47398179769516, 84.63891550898552, 75.61423256993294, 79.45370614528656, 74.33695390820503, 83.30112889409065, 78.17659467458725, 77.17689111828804, 64.16736200451851, 79.75276529788971, 65.17341122031212, 97.66626566648483, 16.541830971837044, 7.085291231051087, 95.48552468419075, 77.61262133717537, 83.21957767009735, 68.76223504543304, 70.77732011675835, 65.91613456606865, 72.28453204035759, 78.1416517496109, 84.32130575180054, 83.78916710615158, 89.86936524510384, 81.68952137231827, 88.43147680163383, 82.3230841755867, 86.44958674907684, 86.48099586367607, 85.3031274676323, 83.12345042824745, 78.21062564849854, 79.26604181528091, 80.55209040641785, 73.36860626935959, 73.60107019543648, 72.11549431085587, 67.28801295161247, 59.99691478908062, 35.36094054579735, 11.446620728820562, 2.608745265752077, 0.6714049726724625, 0.17070432601030916, 0.42421184945851564, 1.4735428802669048, 0.49413593485951424, 1.0492868581786752, 1.1179312434978783, 0.5884857627097517, 0.4444709076778963, 1.193730051163584, 4.294075006619096, 4.335428662598133, 1.7402268201112747, 1.4815685246139765, 1.0417779861018062, 16.223879233002663, 47.78101108968258, 27.722776606678963, 101.7932166159153, 64.41291242837906, 15.522358976304531, 81.41798794269562, 73.30889627337456, 83.69294866919518, 23.441314548254013, 0.2639568439917639, 0.3485619166167453, 0.14821174467215315, 0.21727832296164706, 0.12129903567256406, 0.19070447859121487, 0.13492044381564483, 0.1469811302376911, 0.11465014205896296, 0.24913760949857533, 0.13393381785135716, 0.2520333806751296, 0.17848285002401099, 0.16805177147034556, 0.1873939804499969, 0.13844187516951934, 0.12046049785567448, 0.2353445574408397, 0.16701717308023944, 0.24202462867833674, 0.13056828203843907, 0.0911391708359588, 0.11179746739799157, 0.20354845735710114, 0.18646739423274994, 0.1034774056461174, 0.09914161564665847, 0.222921094391495, 0.12466100917663425, 0.23609595227753744, 0.12347287527518347], [0.006864316819701344, 0.052358292232383974, 0.004269625214874395, 0.07004051352851093, 0.08219402778195217, 0.10649555697455071, 0.11019161567674018, 0.1004008250311017, 0.04504154734604526, 0.10018898639827967, 0.125711667642463, 0.14563724922481924, 0.07627937797224149, 0.10295658867107704, 0.12215077629662119, 0.06775959685910493, 0.02284001777297817, 0.0993426115019247, 0.05577847237873357, 0.046760179538978264, 0.04490404222451616, 0.04111310736334417, 0.020526691514533013, 0.006407256360034808, 0.040200629373430274, 0.10397028818260878, 0.10022718473919667, 0.18419726839056239, 0.08498519324348308, 0.03455435129581019, 0.1587282889522612, 0.18336839333642274, 0.05509700269612949, 0.18141200300306082, 0.05611852073343471, 0.16618141089566052, 0.11142496863612905, 1.7488928488455713, 74.784896671772, 84.47311520576477, 77.26229533553123, 62.89077490568161, 21.657838448882103, 58.399944081902504, 82.08064198493958, 27.490234784781933, 33.178330063819885, 8.593762312084436, 0.264505825471133, 0.17840278713265434, 0.37286811391822994, 0.19627178844530135, 0.3982289624400437, 0.5157288699410856, 7.664686515927315, 6.953096799552441, 4.284923672676086, 2.1211067447438836, 17.565760128200054, 40.34635663032532, 33.012879341840744, 7.323435852304101, 2.401811694726348, 1.3457666616886854, 2.481796215288341, 4.523121966049075, 4.76412070915103, 13.32366680726409, 21.414826288819313, 31.198645792901516, 34.95706781744957, 34.82742257416248, 24.56051219254732, 23.782085962593555, 33.18920128047466, 44.13978807628155, 49.38334330916405, 54.79161970317364, 62.50531978905201, 64.04871717095375, 72.22286134958267, 71.64210051298141, 70.59293121099472, 66.92043587565422, 74.6197347342968, 66.59166991710663, 74.11392867565155, 56.56304284930229, 68.8951975107193, 4.291038494557142, 4.360519191250205, 79.95372131466866, 64.56770092248917, 71.42360463738441, 58.27056862413883, 66.06472179293633, 67.53848791122437, 74.1860868036747, 72.18748524785042, 79.50187996029854, 75.12062385678291, 87.61413305997849, 62.31660671532154, 66.8109105527401, 73.81388157606125, 75.39309963583946, 81.51237487792969, 81.00339218974113, 84.31667000055313, 76.73870623111725, 63.982296735048294, 53.86310912668705, 50.213925540447235, 45.43638490140438, 32.84756921231747, 17.893640734255314, 5.21885703317821, 0.5160741170402616, 1.164184499066323, 1.8240703898482025, 0.502126015489921, 1.2793286517262459, 0.6928068492561579, 0.37511501053813845, 0.1469760391046293, 0.3262067958712578, 0.1520780668943189, 0.29221943055745214, 0.2962135209236294, 0.7758131576701999, 0.7232992036733776, 0.38582527020480484, 0.3584125911584124, 0.13189328281441703, 27.51664526760578, 31.584391593933105, 20.251057036221027, 110.78729599714279, 42.112441062927246, 17.23728485405445, 79.02138814330101, 51.2809044867754, 56.94888174533844, 10.41766919195652, 0.24099421600112692, 0.13728966121561825, 0.028364893478283193, 0.05984212795738131, 0.04667393455747515, 0.036956494077458046, 0.12061181434546597, 0.10750570902018808, 0.04446603408723604, 0.014472245202341583, 0.04797048510226887, 0.028903868951601908, 0.06341827043797821, 0.06146388019260485, 0.032130456165759824, 0.09582386672263965, 0.04018627623736393, 0.06537521738209762, 0.027444021798146423, 0.006800185519750812, 0.052938840963179246, 0.04947179419104941, 0.024915224094002042, 0.046189044951461256, 0.04271906669600867, 0.05964938107354101, 0.020220774531480856, 0.06699890291201882, 0.10499908297788352, 0.18059492809697986, 0.030285501161415596, 0.04301717257476412, 0.037215544434729964, 0.059083152082166635, 0.0699076616729144, 0.06770943509764038, 0.05050406223745085, 0.08219941577408463, 0.1229719330149237, 0.09245882072718814, 0.01151894644863205, 0.09146883283392526, 0.09584236104274169, 0.09787135568330996, 0.2150928316405043, 0.08380860715988092, 0.014570115927199367, 0.01901348394312663, 0.03700990273500793, 0.11209675329155289, 0.021969853332848288, 0.18026241625193506, 0.07825673397746868, 0.02938027766504092, 0.07656043671886437, 0.08130917995003983, 0.013591045953944558, 0.1169898961961735, 0.11374371257261373, 0.13151346647646278, 0.06277648339164443, 0.01774141870555468, 0.09702885479782708, 0.20840333512751386, 0.03291731081844773, 0.16335498599801213, 0.05892427681828849, 0.06649237227975391, 0.21630150818964466, 3.3299040561541915, 89.29498046636581, 89.76237818598747, 73.64868924021721, 29.961751364171505, 28.35180625319481, 104.61494520306587, 70.98998710513115, 41.5336599200964, 59.14584405720234, 8.807169310748577, 0.3148358466569334, 0.1313930455944501, 0.3381224221084267, 0.43915027286857367, 0.5058970162644982, 0.7285794359631836, 4.33565997518599, 5.363247860223055, 5.5294860899448395, 4.761923952028155, 27.113416604697704, 34.964754804968834, 30.6523073092103, 7.314425110816956, 4.089388540014625, 3.128314660862088, 5.770997805520892, 10.074387062340975, 11.16374870762229, 26.24213095754385, 37.162097096443176, 42.970309630036354, 55.083843022584915, 58.40318910777569, 46.71626262366772, 49.027625396847725, 55.35893686115742, 59.65743340551853, 62.17771656811237, 63.949367702007294, 70.48294231295586, 73.89997735619545, 79.49276804924011, 78.9900854229927, 78.2319501042366, 71.84434846043587, 79.19816225767136, 73.73317390680313, 82.91189298033714, 63.47044140100479, 79.95353132486343, 5.459874300286174, 5.740335350856185, 91.96551516652107, 75.40658131241798, 79.9775156378746, 65.04684001207352, 71.08603835105896, 72.50830963253975, 77.58482962846756, 78.49615752696991, 83.69579091668129, 81.312156021595, 94.91753876209259, 67.96192958950996, 71.27089843153954, 79.72071021795273, 80.81862330436707, 80.72238966822624, 80.47604888677597, 82.45451912283897, 77.97878488898277, 72.9365922510624, 63.61883103847504, 61.299652084708214, 59.10910002887249, 46.42227239906788, 24.74303539842367, 9.585612639784813, 1.8264829041436315, 0.814995348919183, 2.0076393708586693, 1.1313425051048398, 1.8783330218866467, 1.618403100874275, 0.9476039581932127, 0.23164076555985957, 0.557317400816828, 0.7125250599347055, 0.7788218837231398, 0.930225175106898, 0.33855447079986334, 1.0196706536225975, 0.4771016864106059, 0.39310253283474594, 0.26091154490131885, 42.2503736615181, 63.31863194704056, 11.697661858052015, 94.70041081309319, 88.05271312594414, 17.428576089441776, 55.67325219511986, 47.81509526073933, 65.23111492395401, 16.3851235806942, 0.4661276674596593, 0.17235591629287228, 0.01552109746626229, 0.04619214712874964, 0.003366957953403471, 0.05738058367569465, 0.016546475599170662, 0.06802360847359523, 0.03703197791764978, 0.0571960820525419, 0.01818391498090932, 0.020348911893961485, 0.10234678076812997, 0.020730169853777625, 0.013266877704154467, 0.025065158333745785, 0.02718941690545762, 0.007688148516535875, 0.07552240960649215, 0.048135527613339946, 0.04349344955699053, 0.04746878214064054, 0.04731397013529204, 0.07649670107639395, 0.07389589649392292, 0.050141111205448397, 0.035980102329631336, 0.1111518063407857, 0.03847593754471745, 0.072223325696541, 0.06844629868282937, 0.055762861302355304, 0.10199786745943129, 0.22888621024321765, 0.2561724866973236, 0.14125951303867623, 0.24612808192614466, 0.11040313518606126, 0.13421439420199022, 0.1936870810459368, 0.15848109440412372, 0.2917133452137932, 0.17121907963883132, 0.23592044919496402, 0.29296941531356424, 0.1742702120100148, 0.1840006883139722, 0.17592471151147038, 0.19324786320794374, 0.24497328529832885, 0.180371452588588, 0.2780506736598909, 0.2071022760355845, 0.12153586983913556, 0.12201628429465927, 0.19262144603999332, 0.10280983638949692, 0.17457484878832474, 0.23313206678722054, 0.29115248937159777, 0.13940948731033131, 0.1620506911422126, 0.1987574785016477, 0.23180788237368688, 0.14316660992335528, 0.3027995175216347, 0.14413169876206666, 0.29237154114525765, 0.4977032606257126, 6.120340609923005, 111.6012655198574, 102.2890368103981, 102.27804020047188, 77.23717868328094, 38.891635090112686, 76.90002277493477, 93.99428710341454, 44.2231822013855, 49.159656912088394, 12.693065945059061, 0.42897952487692237, 0.6090611242689192, 0.5411254602950066, 1.6650017816573381, 0.7211182988248765, 7.434945618733764, 21.614387780427933, 22.296724766492844, 17.50712737441063, 7.329103723168373, 30.485566556453705, 55.185115188360214, 45.36967948079109, 13.468525484204292, 3.0465772468596697, 1.5785444271750748, 2.6543900789693, 4.94491595774889, 4.36343933455646, 15.666446294635534, 26.95921517908573, 35.174993723630905, 51.891736909747124, 60.745094642043114, 57.231240794062614, 60.59686839580536, 65.9536537528038, 67.88922429084778, 70.86299031972885, 74.38317462801933, 79.00929719209671, 80.28181090950966, 86.57643914222717, 84.32406440377235, 84.19104874134064, 80.04363968968391, 85.8976511657238, 80.71868866682053, 89.27035018801689, 70.6189826130867, 88.45723941922188, 5.316166011616588, 6.545787155628204, 95.02436622977257, 79.62521374225616, 86.1090338230133, 69.31191354990005, 77.96581238508224, 76.61274299025536, 81.25996962189674, 80.47420218586922, 86.40412598848343, 85.5193130671978, 101.39243692159653, 70.92064082622528, 73.27950865030289, 84.79253366589546, 85.67278683185577, 88.21591436862946, 89.68484714627266, 95.28469786047935, 89.45419952273369, 82.8129006922245, 74.46420148015022, 72.8159411251545, 70.98190113902092, 53.98586913943291, 27.467409409582615, 9.043072052299976, 2.4062709929421544, 2.0244708051905036, 3.022920428775251, 2.114165942184627, 2.7052800357341766, 2.6552666444331408, 1.105880190152675, 0.48363312031142414, 0.7369389873929322, 0.6720081903040409, 0.5183500761631876, 0.902286758646369, 3.313658977858722, 2.8101881314069033, 0.9408400242682546, 0.4468349152011797, 0.24162729765521362, 39.52875070273876, 48.41432310640812, 28.940157182514668, 124.4082958996296, 60.601409152150154, 26.18891291320324, 100.83118423819542, 64.90398287773132, 81.93247273564339, 30.386281684041023, 0.5403816502075642, 0.26051137887407094, 0.1791060165851377, 0.18105228402419016, 0.14178005541907623, 0.12331112418905832, 0.17834966420195997, 0.17943867685971782, 0.08839933230774477, 0.15165870892815292, 0.10140580430743285, 0.09400003880728036, 0.27056860795710236, 0.11699134338414297, 0.11382059165043756, 0.2015820480301045, 0.09054724869201891, 0.19069009576924145, 0.14309226156910881, 0.14282614225521684, 0.2351221357821487, 0.20528063003439456, 0.18648933211807162, 0.24137851491104811, 0.22829379828181118, 0.1671696695848368, 0.22563202626770362, 0.15931866742903367, 0.15126951184356585, 0.22509229194838554, 0.1393353467574343, 0.16705180169083178], [0.08645082358270884, 0.048707237365306355, 0.06892218603752553, 0.05464908688736614, 0.04038405117171351, 0.010196461553277913, 0.22538689489010721, 0.09373295470140874, 0.043869473520317115, 0.029634928941959515, 0.05588216154137626, 0.03964974428527057, 0.05231224939052481, 0.11011101843905635, 0.07252462281030603, 0.08907423398341052, 0.11835311757749878, 0.033885869197547436, 0.1355173235060647, 0.040702499318285845, 0.0570491702092113, 0.04668010922614485, 0.05040697076765355, 0.028678404487436637, 0.06169376785692293, 0.02171232623368269, 0.07871383015299216, 0.0632547604618594, 0.14988843438914046, 0.07168026655563153, 0.1342312854831107, 0.18963355949381366, 0.08572417937102728, 0.04568827338516712, 0.09397559246281162, 0.07706865202635527, 0.16509456530911848, 0.18290818756213412, 3.619565600529313, 78.21002528071404, 90.2393513917923, 71.70310243964195, 69.98426467180252, 20.58884561061859, 52.52523511648178, 94.47946026921272, 42.50161997973919, 44.25638861954212, 28.698060773313046, 0.6530914991162717, 0.05900655502045993, 0.16358986089471728, 0.12064048351021484, 1.19100607233122, 0.24523545638658106, 1.6123425448313355, 8.65938289090991, 11.896064411848783, 15.526282265782356, 42.647661343216896, 43.71530145406723, 50.82164213061333, 9.86604044213891, 2.2167561622336507, 3.25319139752537, 3.2675935747101903, 6.527786571532488, 4.257499594241381, 0.9670243598520756, 1.039402757305652, 3.352312878705561, 5.165007272735238, 7.3195277620106936, 8.328816778957844, 14.256636444479227, 23.2450170814991, 33.197367042303085, 47.42083601653576, 59.87577348947525, 62.93942749500275, 62.769295424222946, 56.101641207933426, 64.82313841581345, 63.30086410045624, 63.866000175476074, 55.15641152858734, 56.77160985767841, 54.292121306061745, 63.75101074576378, 1.949247072916478, 6.007126634940505, 69.1806609928608, 61.736936420202255, 64.88053813576698, 60.654249116778374, 68.54451432824135, 69.61850389838219, 76.05738759040833, 80.53320541977882, 81.056437343359, 78.51748958230019, 83.28181073069572, 82.69297912716866, 77.66394898295403, 81.22460871934891, 80.57926654815674, 85.03279477357864, 86.5443080663681, 84.06364917755127, 64.36396345496178, 48.11684086918831, 38.02288770675659, 28.040310367941856, 15.168676804751158, 5.204485729336739, 0.7379725319333375, 0.33589318860322237, 0.7667952915653586, 0.5766154371667653, 0.18508460983866826, 0.07928595921839587, 0.36178951151669025, 0.1789224537787959, 0.43177127663511783, 0.31027419143356383, 0.2773601497756317, 0.18156077392632142, 0.23616828199010342, 1.044074131641537, 0.805383111583069, 1.0759728262200952, 0.15584379842039198, 2.374149179086089, 34.88336697220802, 25.964297465980053, 31.363587342202663, 111.52983695268631, 24.537455029785633, 11.771872825920582, 57.49007150530815, 41.46209456026554, 65.32147407531738, 22.543947100639343, 0.10547445082920603, 0.20664944720920175, 0.12046388947055675, 0.06201497308211401, 0.013382299293880351, 0.016577152273384854, 0.05038170435000211, 0.03211944640497677, 0.04941045568557456, 0.06896270730067044, 0.05060155817773193, 0.05903834862692747, 0.05396932043367997, 0.07854283932829276, 0.030689010563946795, 0.02175812973291613, 0.0093639499755227, 0.024729093456699047, 0.05862897254701238, 0.1190553599735722, 0.04766660902532749, 0.052312308762338944, 0.036142562166787684, 0.053904890883131884, 0.06870590194012038, 0.051912677081418224, 0.03877510469465051, 0.02395946405158611, 0.03150049153191503, 0.025584194154362194, 0.028150871075922623, 0.06339462561300024, 0.19918780541047454, 0.030657259630970657, 0.07056466274661943, 0.06561044108821079, 0.04659587917558383, 0.039351033556158654, 0.05319218420481775, 0.1713468923117034, 0.2020132655161433, 0.06572367055923678, 0.1219645343371667, 0.08195225833333097, 0.10509835265111178, 0.011743242957891198, 0.04098786252143327, 0.06624997200560756, 0.0621888657042291, 0.031936265804688446, 0.08116354831145145, 0.08567547221900895, 0.07318492644117214, 0.0432365031883819, 0.028172667953185737, 0.04837259926716797, 0.06445059785619378, 0.08482162389555015, 0.06787515667383559, 0.10771512825158425, 0.11336957366438583, 0.19476068671792746, 0.16457929217722267, 0.18124945781892166, 0.1507153650163673, 0.17600510094780475, 0.05033383953559678, 0.15109363768715411, 0.11331498870276846, 0.1273775368463248, 0.17255591024877504, 5.430148495361209, 92.05838218331337, 92.08282247185707, 65.866007655859, 39.00555297732353, 21.76210105419159, 108.71437042951584, 86.3252042233944, 33.67258474230766, 72.38772690296173, 34.4249177724123, 1.1879893904551864, 0.364904988091439, 0.27512922417372465, 1.031258963048458, 0.5899170390330255, 0.31270303297787905, 0.10112514632055536, 4.379492998123169, 8.201672751456499, 20.844699181616306, 50.909630209207535, 56.822599321603775, 53.08535546064377, 10.222827047109604, 1.4780824491754174, 2.3682796815410256, 0.22187787224538624, 3.568006167188287, 3.321461146697402, 3.1378184258937836, 5.492025800049305, 8.690757807344198, 10.946858245879412, 14.758164882659912, 22.926090694963932, 28.04877821356058, 38.83478634059429, 53.53104494512081, 64.30879801511765, 71.4385986328125, 65.7353326678276, 71.52259692549706, 63.36950361728668, 73.19122418761253, 70.05355775356293, 76.03458881378174, 65.56377947330475, 66.47743284702301, 57.41274565458298, 71.25969663262367, 2.124202628619969, 7.182702329009771, 84.18195202946663, 69.49800476431847, 75.98951563239098, 68.50737512111664, 77.18333557248116, 75.58808237314224, 81.57802015542984, 86.29182681441307, 88.0438520014286, 82.2002823650837, 88.13339799642563, 81.42067819833755, 79.5277489721775, 83.4227603673935, 79.65998187661171, 88.23796078562737, 90.71333795785904, 88.63247841596603, 70.1680988073349, 56.08379356563091, 44.804182425141335, 34.369406551122665, 21.293572895228863, 8.300972823053598, 2.0517678279429674, 1.743030238430947, 1.3629494584165514, 0.8529519871808589, 0.22296728566288948, 0.2884108177386224, 0.11276591074420139, 0.23934730124892667, 0.5517454748041928, 0.5921309546101838, 0.5429039429873228, 0.6996077718213201, 0.4806438978994265, 0.23767032951582223, 0.9503534669056535, 0.7545398804359138, 0.48072876990772784, 3.660112274810672, 55.602203607559204, 49.6882351487875, 10.584790874272585, 104.5182403922081, 69.03561517596245, 9.797772355377674, 38.817064091563225, 41.481614112854004, 72.4070754647255, 31.245882958173752, 0.30948451661970466, 0.28345721948426217, 0.1534669368993491, 0.03112003509158967, 0.03857257259369362, 0.07791411408106796, 0.03533926523232367, 0.14420389488805085, 0.0698057870613411, 0.04055086741573177, 0.04160250180575531, 0.08332318320753984, 0.06281240333919413, 0.06431435438571498, 0.0166296388124465, 0.028734434781654272, 0.018851278291549534, 0.07467615345376544, 0.030959577197791077, 0.016899541224120185, 0.03110111032583518, 0.05267224296403583, 0.022744288144167513, 0.009977044664992718, 0.026491569878999144, 0.027228311009821482, 0.06475308982771821, 0.06837461463874206, 0.01926724835357163, 0.08661969186505303, 0.09745571587700397, 0.10421789091196842, 0.060878971344209276, 0.2112439795746468, 0.14841510797850788, 0.14917687803972512, 0.10147642708034255, 0.14391859847819433, 0.08711749484064057, 0.3077138413209468, 0.28859074402134866, 0.10011143938754685, 0.15293777076294646, 0.12219068157719448, 0.17706003418425098, 0.17385321407346055, 0.1801193004939705, 0.16509760811459273, 0.10053969570435584, 0.25252126855775714, 0.2009071092470549, 0.1994760407251306, 0.19585738802561536, 0.1774833255331032, 0.1047406523139216, 0.13223257788922638, 0.19716396869625896, 0.14538873365381733, 0.18785705091431737, 0.14214312890544534, 0.2594498108373955, 0.22493293799925596, 0.21833313745446503, 0.29054167214781046, 0.3303558466723189, 0.2674314903561026, 0.13126677658874542, 0.26297631848137826, 0.16514476417796686, 0.19321785075590014, 0.38499985355883837, 8.759647160768509, 113.30218344926834, 108.59932020306587, 94.19724181294441, 87.50679641962051, 32.35462546348572, 76.41558676958084, 113.34863215684891, 55.03013290464878, 69.07955601811409, 40.80903120338917, 1.385273498017341, 0.5802040477283299, 0.40715364448260516, 2.1670697908848524, 2.224203525111079, 2.4460363341495395, 5.875168265774846, 17.798319049179554, 26.24589655548334, 27.114830128848553, 49.76837284862995, 57.58431404829025, 60.931151658296585, 14.22264726832509, 3.2556648273020983, 5.277337320148945, 4.650752367451787, 9.21751119196415, 5.635541249066591, 2.423886372707784, 2.9874239210039377, 4.8943335469812155, 7.938053822144866, 12.547830138355494, 22.921259254217148, 34.71093602478504, 51.015507727861404, 63.26177179813385, 72.86847710609436, 77.85440996289253, 70.33936321735382, 72.69924938678741, 65.16932263970375, 74.29450258612633, 73.23743730783463, 78.53852525353432, 70.91676503419876, 70.97293362021446, 65.36498934030533, 75.91485723853111, 2.099698930978775, 9.596638698130846, 87.49091327190399, 78.60168546438217, 80.98510757088661, 73.55743333697319, 80.17064407467842, 80.5824887752533, 82.27267608046532, 90.9212476015091, 90.1369620859623, 83.1134569644928, 88.79360496997833, 89.61152628064156, 87.69409596920013, 89.74011898040771, 85.62000006437302, 95.42688623070717, 97.87790670990944, 93.00963073968887, 76.36211603879929, 61.757808700203896, 51.8122223764658, 37.07879796624184, 20.122407339513302, 6.796359959989786, 2.175062424503267, 3.220468028448522, 3.0252539785578847, 1.435587191954255, 0.6638734799344093, 0.5503138422500342, 0.4429205018095672, 0.8300817268900573, 1.919003427028656, 0.9430605894885957, 0.8188653225079179, 0.9113357355818152, 1.380288521759212, 2.5812383042648435, 2.0274070976302028, 1.6010768618434668, 0.5727253959048539, 3.3605475118383765, 49.03041064739227, 39.15452778339386, 38.08767423033714, 130.0432187318802, 44.4692075997591, 16.735692769289017, 73.98730427026749, 57.32783541083336, 85.04042476415634, 46.707093715667725, 0.27683286869432777, 0.4738583229482174, 0.1848359903669916, 0.1633471340755932, 0.11152014165418223, 0.16047380544478074, 0.11614044880843721, 0.27445449319202453, 0.15380200173240155, 0.2714152500266209, 0.2453358838101849, 0.23799420276191086, 0.22359345050062984, 0.22352987813064829, 0.12229720203322358, 0.1588142741820775, 0.07339980045799166, 0.21584729896858335, 0.25483279139734805, 0.20559736381983384, 0.15755296451970935, 0.1180858924635686, 0.08803285978501663, 0.1402221983880736, 0.17712694621877745, 0.08619754342362285, 0.15072165842866525, 0.12264071992831305, 0.15720090450486168, 0.16245109465671703, 0.1575844464241527, 0.19428206083830446, 0.18673069338547066], [0.07808050359017216, 0.07016026647761464, 0.02966595442558173, 0.0716045155422762, 0.16175515309441835, 0.06413286217139103, 0.11993185122264549, 0.08394542208407074, 0.07040881173452362, 0.032559799728915095, 0.04610059208062012, 0.08143958271830343, 0.0441824891458964, 0.06342833396047354, 0.04519786962191574, 0.11357262526871637, 0.04330974574259017, 0.07948918893816881, 0.053862981803831644, 0.09706707540317439, 0.06573673977982253, 0.031490821347688325, 0.07025794795481488, 0.05892899687751196, 0.02860238259017933, 0.07613261084770784, 0.1273591018980369, 0.18781982478685677, 0.15524528600508347, 0.10571703664027154, 0.2734434208832681, 0.09643739278544672, 0.009699605743662687, 0.012052943966409657, 0.0689037362462841, 0.08076318932580762, 0.062750597280683, 0.20129078475292772, 0.14485483261523768, 2.492500953376293, 65.77670484781265, 91.84693112969398, 62.2951340675354, 74.78253319859505, 16.070462465286255, 28.03365882486105, 104.75313618779182, 50.65390393137932, 43.408338725566864, 44.45039860904217, 8.89659371227026, 0.10623295544064604, 0.2786051173461601, 0.14090289623709396, 0.3581603796919808, 1.7407036945223808, 3.5195029573515058, 13.040676042437553, 28.337942697107792, 29.884522408246994, 33.29832762479782, 36.328528225421906, 25.893186181783676, 15.121636278927326, 64.18791890144348, 67.2745768725872, 57.11785487830639, 37.96625554561615, 1.9629711052402854, 0.7675425452180207, 0.8376505051273853, 0.5524307442829013, 0.2239999544690363, 0.8594266616273671, 2.537638256326318, 5.6374648958444595, 12.67124941572547, 22.724693901836872, 42.85082124173641, 61.982787027955055, 72.59930714964867, 68.92270043492317, 65.52018821239471, 66.27171948552132, 63.609396144747734, 72.01610684394836, 71.87897220253944, 70.87882027029991, 20.892538614571095, 0.7519705651793629, 5.705685960128903, 63.93221542239189, 68.87437462806702, 69.80097010731697, 67.16677665710449, 70.53911089897156, 74.07868936657906, 76.10477864742279, 75.83066895604134, 80.28874933719635, 87.78672739863396, 81.05992555618286, 77.43555843830109, 79.11889091134071, 77.74208799004555, 81.57701700925827, 69.32959780097008, 63.261578008532524, 56.53050899505615, 35.82436367869377, 19.071737118065357, 9.750889521092176, 3.5855704871937633, 1.8571296846494079, 0.6597686314489692, 1.52211828622967, 1.5735574322752655, 0.4520183417480439, 0.10768009888124652, 0.0944350338249933, 0.02074867345072562, 0.04192547705315519, 0.21105569670908153, 0.30762944428715855, 0.252520763897337, 1.1164628597907722, 1.1764781456440687, 1.2489838362671435, 0.8829016238451004, 0.2572709246305749, 0.19999759242637083, 7.744723996147513, 43.6248929053545, 23.134596906602383, 41.0970139503479, 100.0452496111393, 14.137454889714718, 20.83955805748701, 75.50055027008057, 39.81752000749111, 69.94635790586472, 32.7135694026947, 0.6131174066103995, 0.4069302580319345, 0.10222939527011476, 0.039707687465124764, 0.18759477592539042, 0.019717839604709297, 0.02084316740365466, 0.06556518492288888, 0.03470237264991738, 0.054477624798892066, 0.06645878267590888, 0.026024760845757555, 0.06900081658386625, 0.03643624113465194, 0.09802148473681882, 0.03973062724980991, 0.04080912367498968, 0.035480447695590556, 0.07114256572094746, 0.0753516933764331, 0.03277015406638384, 0.016695055419404525, 0.043288397864671424, 0.03017687857209239, 0.061888377531431615, 0.04185660203802399, 0.02677821885299636, 0.0077335512560239295, 0.054014131310395896, 0.09119746653595939, 0.11076834605773911, 0.08317548097693361, 0.07179849068052135, 0.03744273810298182, 0.02008716754062334, 0.07259689315105788, 0.04986664644093253, 0.04332964643253945, 0.14194442628649995, 0.07406300588627346, 0.025129684363491833, 0.06408405854017474, 0.06493775101262145, 0.008419666319241514, 0.028736685344483703, 0.03983613467426039, 0.06107087589043658, 0.08208376690163277, 0.06321313339867629, 0.14186209242325276, 0.03504478474496864, 0.08412741153733805, 0.03719854554219637, 0.06084249478590209, 0.04756603317218833, 0.08686419241712429, 0.057337197722517885, 0.07867038482800126, 0.05708744276489597, 0.03856052382616326, 0.14464695705100894, 0.15393260488053784, 0.14219378790585324, 0.14577698078937829, 0.23053419368807226, 0.18189457710832357, 0.09757745036040433, 0.0769002884044312, 0.11590115813305601, 0.07501687345211394, 0.12286069249967113, 0.10633497848175466, 0.1675764555693604, 4.849829860031605, 86.32496103644371, 96.32040068507195, 61.544852927327156, 41.95308141410351, 12.904929276555777, 67.59627521038055, 111.22212946414948, 41.99093498289585, 64.63016957044601, 65.31997695565224, 12.662900313735008, 0.18616508779814467, 0.24864032602636144, 0.1335654454305768, 1.1399949970655143, 1.1041884496808052, 1.9382556877098978, 12.290795780718327, 22.827126905322075, 27.834823094308376, 32.932547852396965, 40.01627214252949, 24.84026648104191, 21.195733845233917, 49.536383897066116, 47.71762289106846, 57.41051137447357, 37.00662463903427, 2.8615331137552857, 1.3211805559694767, 0.7880514103453606, 1.2054350855760276, 0.5043638579081744, 1.8417128431610763, 6.396235730499029, 12.669209875166416, 20.044914297759533, 33.253174647688866, 53.456633538007736, 72.65972390770912, 78.00875768065453, 75.03941461443901, 76.05792716145515, 74.5374083518982, 74.12799552083015, 81.6689644753933, 78.53151082992554, 80.9257547557354, 29.466421343386173, 0.6474494549911469, 6.974452128633857, 73.66907134652138, 78.9863920211792, 78.32202047109604, 77.85619586706161, 79.60695192217827, 83.21320161223412, 85.31404048204422, 83.93982142210007, 86.93245723843575, 92.84273609519005, 86.20290398597717, 86.55060052871704, 89.84665006399155, 87.24401012063026, 91.7803131043911, 82.69892200827599, 73.5588164627552, 64.01136517524719, 42.49983407557011, 26.475759521126747, 15.850031543523073, 6.8689835630357265, 2.6926293270662427, 1.5915438858792186, 1.7896080203354359, 2.020179172977805, 0.42599971289746463, 0.11507255767355673, 0.07922673583379947, 0.1446402628789656, 0.03113545877567958, 0.23257912223925814, 0.22025589365512133, 0.44461411249358207, 1.2144497456029058, 0.20196400175336748, 0.44877316744532436, 1.313790308777243, 0.13755353924352676, 0.18912314000772312, 14.32812200859189, 66.6039052605629, 30.74519332498312, 15.665780380368233, 112.2471396625042, 47.3274902254343, 11.67427221313119, 42.08096355199814, 36.54360808432102, 74.41165789961815, 44.405823200941086, 0.3441466129152104, 0.4931582591962069, 0.1069336393265985, 0.060753837824449874, 0.10952593147521839, 0.044101847379351966, 0.08047298731980845, 0.11238617604249157, 0.06458518633735366, 0.07037133327685297, 0.09144708790699951, 0.05054929613834247, 0.03325998266518582, 0.04676391625253018, 0.08400021484703757, 0.06997370539465919, 0.011394261000532424, 0.03814464282186236, 0.10241977099212818, 0.04136797571845818, 0.04819252084416803, 0.08383982189116068, 0.052961710243835114, 0.0203078099002596, 0.05127449687279295, 0.02608126240374986, 0.02033690023381496, 0.055921525054145604, 0.041609173713368364, 0.08848695026244968, 0.1294028281699866, 0.026654024150047917, 0.09931371969287284, 0.05957584537100047, 0.13281308580189943, 0.20075605250895023, 0.2096098446054384, 0.2546247822465375, 0.3165719081880525, 0.07326683728024364, 0.1824629880138673, 0.21160856704227626, 0.18061891430988908, 0.14571946434443817, 0.18241943878820166, 0.20170236501144245, 0.13223600661149248, 0.17961576813831925, 0.2018371390295215, 0.32107199484016746, 0.0960845906229224, 0.20286180748371407, 0.0872046007134486, 0.16885584394913167, 0.10979893049807288, 0.1770505346939899, 0.18029406142886728, 0.19401591183850542, 0.1006859284825623, 0.18005316029302776, 0.2680344705004245, 0.2104556406266056, 0.17356309370370582, 0.16717599268304184, 0.34014097473118454, 0.14759163575945422, 0.16824082616949454, 0.2272218995494768, 0.23477715585613623, 0.136820609041024, 0.279469036613591, 0.26786327187437564, 0.46450230467598885, 6.6855731047689915, 99.21102717518806, 112.01726719737053, 83.80781650543213, 93.32369148731232, 25.197302922606468, 43.89821223914623, 125.96139416098595, 67.79428258538246, 61.78993597626686, 63.901725858449936, 13.854143992066383, 0.23731629538815469, 0.35433567711152136, 0.19303669250803068, 2.0089797489345074, 4.693473000079393, 7.382200174033642, 22.183105163276196, 33.27334016561508, 36.36833868920803, 40.91793715953827, 46.38971574604511, 33.67657832801342, 27.578182965517044, 74.73628208041191, 85.576591193676, 92.57023751735687, 56.40898771584034, 3.1576628610491753, 1.7759817140176892, 3.426992646418512, 1.7401663796044886, 0.21607844828395173, 0.9204857633449137, 4.231431093066931, 9.310992825776339, 17.91312988847494, 32.07310996949673, 56.5625336766243, 79.56512376666069, 90.21797373890877, 85.79838529229164, 87.18658000230789, 85.66203340888023, 85.50035208463669, 95.97895860671997, 86.87014818191528, 88.53429928421974, 26.413946337997913, 0.9409286663867533, 8.670497294515371, 78.30495938658714, 83.93602922558784, 85.84549516439438, 83.84434014558792, 85.90975731611252, 88.821791857481, 89.1796338558197, 86.84724301099777, 87.59565085172653, 92.90604829788208, 89.28786724805832, 85.89951306581497, 90.79460799694061, 88.48455235362053, 92.95538485050201, 84.89858597517014, 73.10481682419777, 64.01249751448631, 40.475162118673325, 23.47372490912676, 13.541366625577211, 6.56029287725687, 3.1645008316263556, 2.808806668035686, 2.634591478854418, 2.172556221485138, 0.4590156959602609, 0.1441435285960324, 0.1858470478327945, 0.20884230063529685, 0.18604379118187353, 0.5342468793969601, 0.3262045397423208, 0.7866978517267853, 4.89984942600131, 3.225302556529641, 3.130657710134983, 1.9666504953056574, 0.35144352761562914, 0.18728766037384048, 11.085968781262636, 60.83339050412178, 32.057868987321854, 47.09619663655758, 118.97584900259972, 32.890829890966415, 27.58540067821741, 94.597869515419, 51.47527165710926, 84.34649839997292, 54.37334954738617, 0.800822168821469, 0.7182077737525105, 0.18881123018218204, 0.18834658636478707, 0.3148651763331145, 0.10982975931256078, 0.14290437946328893, 0.19866784190526232, 0.11571889408514835, 0.2463935481500812, 0.1861158388783224, 0.09572076756739989, 0.21313976612873375, 0.08995374577352777, 0.2310927043436095, 0.09784776280866936, 0.1518833273439668, 0.11340634708176367, 0.18130088865291327, 0.18331722967559472, 0.10720513921114616, 0.11987260557361878, 0.12336936051724479, 0.16567376704188064, 0.188747895299457, 0.1847664066008292, 0.19084014318650588, 0.12531791377114132, 0.08835143409669399, 0.1384021999547258, 0.17333572934148833, 0.1328613847726956, 0.15844799461774528, 0.1577058617840521], [0.04389676971186418, 0.027905403876502533, 0.04497062029258814, 0.06140981102362275, 0.12210240311105736, 0.01963948550837813, 0.05342689582903404, 0.08616140083177015, 0.06468366191256791, 0.10823680611792952, 0.1181104352872353, 0.15327767439885065, 0.03458869417954702, 0.03860376506054308, 0.043683235271601006, 0.11426634780946188, 0.06882305737235583, 0.03092702474532416, 0.019146951781294774, 0.05727575160562992, 0.06151561530714389, 0.17422131932107732, 0.08656250196509063, 0.17385956685757264, 0.03243235812988132, 0.03563325590221211, 0.019991495428257622, 0.19730227533727884, 0.16420006955740973, 0.23061775951646268, 0.12255454174010083, 0.32339387806132436, 0.07122645067283884, 0.1649392189574428, 0.14351112971780822, 0.04672243390814401, 0.1526634136098437, 0.06624109591939487, 0.047307368731708266, 0.0643471276271157, 0.19845196598907933, 44.946230202913284, 91.04977190494537, 68.59063625335693, 69.9836491048336, 42.2212216258049, 23.346013762056828, 69.35640156269073, 56.751725524663925, 45.09854502975941, 55.1114409416914, 31.54357608407736, 5.332933086901903, 0.06547178563778289, 0.06731868692440912, 0.36037625453900546, 1.5594411897473037, 5.633045258000493, 14.688533619046211, 22.190172784030437, 27.16009709984064, 20.712217390537262, 11.536395661532879, 8.044050559401512, 37.51171633601189, 55.10967783629894, 53.471407145261765, 34.067106172442436, 1.3819395331665874, 9.735390152782202, 1.531410925090313, 0.22735082544386387, 0.2537405875045806, 0.24448311160085723, 0.4635972704272717, 0.48874740838073194, 0.038748086808482185, 0.4252783750416711, 2.9417688958346844, 7.777142431586981, 23.840224742889404, 32.525551691651344, 40.99763788282871, 53.04888501763344, 46.274331137537956, 33.97024177014828, 21.73498760908842, 7.064852127805352, 0.38364608713891357, 1.0317124449647963, 3.4219199186190963, 60.05320876836777, 67.12094351649284, 58.42188410460949, 62.88056865334511, 67.13253289461136, 68.91831547021866, 73.11754614114761, 81.1877278983593, 83.44276249408722, 77.67632111907005, 78.5114099085331, 76.46112352609634, 71.75769031047821, 60.712784975767136, 42.24674865603447, 29.32702012360096, 26.008308604359627, 12.031723782420158, 1.2646470707841218, 0.9405116981361061, 1.3726387009955943, 0.9225187136325985, 0.7701181538868695, 0.49745532392989844, 0.012577004126796965, 0.10101177584147081, 0.024099781912809703, 0.05116487795021385, 0.04832057100429665, 0.08026454772334546, 0.08121957303956151, 0.10929999203654006, 0.09498482424532995, 0.3083249554038048, 0.20581499120453373, 0.6638912914786488, 0.17643049999605864, 0.03234126321331132, 0.6606902007479221, 23.64902090281248, 49.94491897523403, 26.39415320008993, 64.67561513185501, 94.81308236718178, 7.784405741840601, 21.69109806418419, 69.98473584651947, 53.38773563504219, 73.50526973605156, 32.00736589729786, 0.28088659804780036, 0.11199276355910115, 0.025984894527937286, 0.11327247106237337, 0.033729673086781986, 0.14347599644679576, 0.10446072163176723, 0.033540781660121866, 0.0884909949672874, 0.18207086686743423, 0.2024174391408451, 0.1718601319589652, 0.10881352907745168, 0.10790035346872173, 0.06997426200541668, 0.1288981529069133, 0.06239984344574623, 0.08675887424033135, 0.08520302100805566, 0.055550480901729316, 0.10931225231615826, 0.10608093391056173, 0.03840144818241242, 0.04625229448720347, 0.009959410308510996, 0.035558310119085945, 0.10343851710786112, 0.05115951593325008, 0.03882911449181847, 0.03528283974446822, 0.0752095424104482, 0.015852020187594462, 0.03807918539678212, 0.11383932345779613, 0.06355619116220623, 0.0796492924564518, 0.04350544637418352, 0.06341559870634228, 0.11963612763793208, 0.07210472307633609, 0.02717319170187693, 0.030967087732278742, 0.1708465363481082, 0.06212801701622084, 0.07563229199149646, 0.040427392596029676, 0.08808104001218453, 0.089003351458814, 0.09161908805253915, 0.055997610033955425, 0.08196573573513888, 0.07929416737169959, 0.05669394493452273, 0.05387283752497751, 0.019154399233229924, 0.053112180685275234, 0.13052921538474038, 0.10747839056421071, 0.06956804005312733, 0.10088244918733835, 0.03027090868272353, 0.016435337129223626, 0.2212906107888557, 0.19597970880568027, 0.2819142350926995, 0.1906055206200108, 0.2649595448747277, 0.09100916140596382, 0.12514586909674108, 0.1536763264448382, 0.051934266157331876, 0.12444006439181976, 0.043490510652191006, 0.02496000157407252, 0.20159389270702377, 1.6406906861811876, 64.95401099324226, 95.15105903148651, 68.8279639184475, 36.318272575736046, 13.577100858092308, 52.59097158908844, 102.17236027121544, 45.58831214904785, 43.11193183064461, 73.42622637748718, 42.90602087974548, 5.965231508016586, 0.02077291013847571, 0.3575235279276967, 0.7358752225991338, 1.5481487894430757, 3.363373610191047, 19.59984987974167, 31.346873939037323, 28.800372183322906, 28.168652281165123, 23.854517675936222, 13.573902379721403, 50.17119683325291, 67.74871543049812, 55.55545851588249, 40.93241058290005, 4.671300714835525, 6.243230765685439, 3.091781046241522, 0.031057689120643772, 0.8037982403766364, 0.22224879765417427, 0.8242428058292717, 0.6393809441942722, 0.5922420986462384, 2.2757323225960135, 6.365673970431089, 13.620151598006487, 34.84579838812351, 44.60744798183441, 56.570042073726654, 67.36951857805252, 60.03310024738312, 45.07767274975777, 30.719457305967808, 11.732620932161808, 0.5531781760510057, 0.8636997104622424, 4.703719150274992, 67.98429518938065, 72.24073559045792, 70.89505299925804, 74.78422030806541, 77.45719447731972, 79.45949703454971, 81.3973094522953, 88.77512276172638, 90.59229925274849, 88.70519891381264, 86.03205755352974, 83.282221108675, 80.5733160674572, 72.08059698343277, 52.80995383858681, 42.485512644052505, 36.714952290058136, 21.185829676687717, 6.062853019684553, 1.8453849898651242, 1.0306375776417553, 0.6901373143773526, 1.9027689169161022, 0.8252888778224587, 0.20549266162561253, 0.08799118077149615, 0.02004523248615442, 0.057154892856488004, 0.13188409502618015, 0.08755633418331854, 0.04087003173481207, 0.11719586444087327, 0.13303515122970566, 0.15428476879606023, 0.47116085363086313, 1.0294382669962943, 0.33869449922349304, 0.20894211949780583, 1.5289196837693453, 35.99051356315613, 64.25582885742188, 26.85753833502531, 43.10170657932758, 112.33195871114731, 32.33147710561752, 10.124546270817518, 44.20743204653263, 50.85233688354492, 80.02172246575356, 43.840151354670525, 0.6372816755902022, 0.31986095826141536, 0.08008842865820043, 0.06464707403210923, 0.027358036568330135, 0.10446323751239106, 0.09779628744581714, 0.07168175085098483, 0.025006055548146833, 0.21685362153220922, 0.17125160055002198, 0.09883232560241595, 0.076267666881904, 0.06384352847817354, 0.10275942229782231, 0.11686308542266488, 0.033174049385706894, 0.04859674270846881, 0.0920192021294497, 0.049104022909887135, 0.044566498618223704, 0.06201201191288419, 0.018717177772487048, 0.08084472909104079, 0.04701566387666389, 0.01274697820917936, 0.0479233364603715, 0.024377291338169016, 0.04889304887910839, 0.07619506999617442, 0.047370254615088925, 0.08619694228400476, 0.026886372033914085, 0.09570554611855187, 0.05404696763434913, 0.13632182643050328, 0.134715462627355, 0.15162975032581016, 0.1902548855287023, 0.19272871606517583, 0.10782302168081515, 0.15164039272349328, 0.3038047713926062, 0.10797398936119862, 0.18522245634812862, 0.21524348761886358, 0.24490812473231927, 0.2584274875698611, 0.20890349813271314, 0.16182699298951775, 0.1941887877183035, 0.17552227451233193, 0.1248960176599212, 0.1748479442903772, 0.16025902790715918, 0.19788055680692196, 0.23983699997188523, 0.21368969755712897, 0.21134234382770956, 0.1271183937205933, 0.11155543077620678, 0.2491013630060479, 0.2922555583063513, 0.25604026566725224, 0.32762729621026665, 0.30473883845843375, 0.3818305267486721, 0.15112357592443004, 0.21443517005536705, 0.2328603813657537, 0.18105025053955615, 0.2350982979987748, 0.15265052992617711, 0.09167762123979628, 0.45203959685750306, 2.4888310628011823, 80.28360441327095, 113.86779069900513, 93.92110303044319, 90.21549627184868, 55.17298623919487, 40.24667277932167, 88.46816003322601, 69.3646091222763, 57.897611036896706, 77.52910941839218, 51.225222274661064, 6.687445929273963, 0.2100133799831383, 0.2799691550899297, 0.9412224381230772, 3.9992749504745007, 9.031925350427628, 26.424724459648132, 36.06866396963596, 35.08086137473583, 29.28997591137886, 21.60851139575243, 16.775890812277794, 48.28168362379074, 66.42295897006989, 79.48515325784683, 49.250639230012894, 2.9780645482242107, 15.679120514541864, 6.709137540310621, 0.549194267950952, 1.871057243552059, 0.3912524477345869, 1.038417185191065, 0.8212853770237416, 0.3568386740516871, 1.297730233054608, 3.655268484726548, 8.95081490278244, 28.789962641894817, 40.28638444840908, 57.33876742422581, 66.40926450490952, 58.10344599187374, 37.76095636188984, 25.203665681183338, 8.088719062507153, 0.526751484721899, 1.5949644148349762, 4.918288411572576, 71.09622940421104, 81.88740715384483, 75.19223481416702, 79.84592869877815, 82.2340777516365, 81.62736430764198, 80.22840857505798, 86.85700088739395, 90.13390704989433, 88.70068475604057, 85.36588490009308, 84.83091160655022, 79.8549722135067, 70.80576539039612, 49.33779135346413, 38.57885867357254, 33.21535147726536, 17.215662114322186, 5.026976354420185, 1.695468071848154, 1.2200449453666806, 0.9791007649619132, 2.0351726934313774, 0.8774925547186285, 0.1599052906385623, 0.15252819430315867, 0.1287414855323732, 0.24865469400538132, 0.26716954191215336, 0.2049212227575481, 0.1507159587345086, 0.24103939795168117, 0.3189539350569248, 0.25827873148955405, 1.62652219645679, 2.8160191560164094, 0.6581766356248409, 0.1818237020052038, 0.857104214373976, 32.00450465083122, 64.92807358503342, 36.22033663094044, 76.79299771785736, 110.58085307478905, 27.064057253301144, 31.799781136214733, 85.6112453341484, 65.91346710920334, 90.9484313428402, 53.4413393586874, 0.9357763803564012, 0.42611275683157146, 0.1305980421602726, 0.17580068379174918, 0.0826316128950566, 0.24552581424359232, 0.24204343470046297, 0.16034266795031726, 0.12580283306306228, 0.2634142152965069, 0.2230165939545259, 0.22354019398335367, 0.2543087163940072, 0.21230315789580345, 0.1377580751432106, 0.17922204395290464, 0.11204164882656187, 0.2265141875250265, 0.2380245566018857, 0.08866901393048465, 0.15528700954746455, 0.1453176507493481, 0.11442452916526236, 0.19207431992981583, 0.21317599777830765, 0.1745519757969305, 0.19352507020812482, 0.14632901991717517, 0.15853636956308037, 0.16777178883785382, 0.1861494581680745, 0.15074738126713783, 0.09489649382885545, 0.1282538499799557, 0.17705621954519302], [0.0700253366085235, 0.0898000321467407, 0.07129313264158554, 0.1338929106714204, 0.1125236514781136, 0.18018312519416213, 0.15236683655530214, 0.2117263013496995, 0.030067298612266313, 0.13746474869549274, 0.01269381724341656, 0.05540825572097674, 0.054625590491923504, 0.08374062643270008, 0.08447599087958224, 0.055234518949873745, 0.13810915552312508, 0.09471523910178803, 0.11242889406275935, 0.07280142905074172, 0.04570100121782161, 0.013393042809184408, 0.09346724356873892, 0.10300064997863956, 0.07636252077645622, 0.19125576072838157, 0.06080145773012191, 0.15970482170814648, 0.05480957632244099, 0.08703274157596752, 0.07112234219675884, 0.09938611619872972, 0.08783585668425076, 0.02888923008868005, 0.17235342267667875, 0.14253269706387073, 0.04083205603819806, 0.07086939600412734, 0.2001957458560355, 0.11949798426940106, 0.6198770657647401, 0.28529937844723463, 33.74874785542488, 92.24510416388512, 64.33442384004593, 97.16509535908699, 51.79256983101368, 18.69672004133463, 58.46478380262852, 87.47489333152771, 56.058654114603996, 50.7677648216486, 42.67214722931385, 18.69868453592062, 1.7796928086318076, 0.12754115072311834, 0.062094483073451556, 1.5471513429656625, 4.409108608961105, 6.93124464713037, 3.1008314481005073, 1.09272422734648, 1.26197011442855, 2.8491134801879525, 5.699524590745568, 31.287716813385487, 33.93363073468208, 4.383152201771736, 6.125298393890262, 10.754946693778038, 6.698711849749088, 0.3047234017867595, 0.2505722700152546, 0.13003700820263475, 0.07843525017960928, 0.41306244616862386, 0.7043721224181354, 0.2522897778544575, 0.6874426652211696, 0.21574264130322263, 0.18594141933135688, 0.20461198466364294, 0.8447842067107558, 1.4295911137014627, 0.48912982223555446, 0.16573940258240327, 0.2464917639736086, 0.22411304293200374, 0.23715836636256427, 5.808013994246721, 1.2490144721232355, 20.629649721086025, 84.5745013654232, 74.65457886457443, 73.26633855700493, 71.35574027895927, 83.0397181212902, 84.80118200182915, 78.26001539826393, 72.63548880815506, 70.35044342279434, 57.43525944650173, 50.23849122226238, 35.77134512364864, 16.54687140136957, 6.507970634847879, 2.14365117251873, 1.022188018541783, 0.44396710814908147, 0.26766146707814187, 0.36633822368457913, 0.2995437750359997, 0.0447295670164749, 0.06827826902735978, 0.17233344406122342, 0.06148220752947964, 0.013518794166884618, 0.14608612982556224, 0.13090368825942278, 0.03792990610236302, 0.10489145672181621, 0.012449523565010168, 0.21262355789076537, 0.20683347014710307, 0.15751201281091198, 0.5130326771177351, 0.05058561684563756, 0.15264539426425472, 8.855134136974812, 26.63999430835247, 49.86372113227844, 40.14038108289242, 63.48619535565376, 66.55055612325668, 22.859924845397472, 40.52553601562977, 64.90881621837616, 48.287493512034416, 69.98399868607521, 21.114019230008125, 0.04585055881761946, 0.2310322638368234, 0.20910945895593613, 0.06260496564209461, 0.033556251728441566, 0.07148335993406363, 0.0946999508596491, 0.0646607369708363, 0.07715681174886413, 0.04638478269043844, 0.1523848410579376, 0.21924470260273665, 0.16090051067294553, 0.1329653151333332, 0.10433730989461765, 0.038749474624637514, 0.06372309275320731, 0.07605893784784712, 0.0825004828220699, 0.10942203822196461, 0.06366780275129713, 0.0635846599470824, 0.031696329460828565, 0.05512283314601518, 0.007032792227619211, 0.0662644141993951, 0.07944396988023072, 0.011132680847367737, 0.05318014656950254, 0.11322407561237924, 0.07146137009840459, 0.06591921162907965, 0.05326367900124751, 0.042389297086629085, 0.04261422720446717, 0.042343703244114295, 0.08798631228273734, 0.10186736821196973, 0.006020636847097194, 0.10794791029184125, 0.10983944433974102, 0.15802599460585043, 0.08309857221320271, 0.11197136002010666, 0.019117839183309115, 0.02551057310483884, 0.10206101680523716, 0.012641451303352369, 0.06200876501679886, 0.14265656151110306, 0.06794828790589236, 0.19983918842626736, 0.07426949363434687, 0.10401535138953477, 0.07809214046574198, 0.059635825746227056, 0.05842402846610639, 0.07637406117282808, 0.12302886316319928, 0.07762475812342018, 0.08708274006494321, 0.2763930126093328, 0.0433154046186246, 0.09078262824914418, 0.10111602532560937, 0.11003212071955204, 0.21406145417131484, 0.1438695573597215, 0.14504203194519505, 0.09488983676419593, 0.15641247649909928, 0.09348401610623114, 0.13985067926114425, 0.0694133467914071, 0.24431514873867854, 0.10112580683198757, 0.3844195237616077, 0.9722611319739372, 50.585188418626785, 107.21021354198456, 62.388118878006935, 84.62214320898056, 22.550592944025993, 29.120930582284927, 97.33422428369522, 80.57673588395119, 50.65535165369511, 58.91357012093067, 63.17480966448784, 24.575838670134544, 3.413486983627081, 0.18700803397223353, 0.14293790969531983, 0.4417821957031265, 4.039353774860501, 5.8609565533697605, 5.447304574772716, 4.240155424922705, 1.3816606043837965, 2.862394005060196, 19.21368610113859, 55.9059327095747, 46.77973061800003, 19.94255919009447, 7.118387930095196, 15.357783157378435, 8.109950423240662, 1.8721406604163349, 0.31586936151143163, 0.3222303983056918, 0.03339783288538456, 0.8324162266217172, 3.0883652670308948, 1.4646046911366284, 0.20609749713912606, 0.15294430166250095, 0.4265890078386292, 0.5243038816843182, 2.0321081578731537, 3.197834542952478, 1.2584978132508695, 0.14936838182620704, 0.08426339525613002, 0.33434949174989015, 0.5268283712211996, 7.947256453335285, 1.658090427517891, 28.064180687069893, 95.97217217087746, 83.18471074104309, 78.48066955804825, 78.42124074697495, 90.57452380657196, 97.22638607025146, 94.5901407301426, 87.73178234696388, 83.517527282238, 73.91826197504997, 67.77361929416656, 49.18455317616463, 24.790036976337433, 11.13747026771307, 4.782831380143762, 1.4831422339193523, 0.5186184367630631, 0.775527044897899, 0.771825984120369, 0.43916725320741534, 0.31856991816312075, 0.11730657803127542, 0.1862223370699212, 0.1282934212940745, 0.03979601046012249, 0.049748054952942766, 0.15810209442861378, 0.07055126698105596, 0.27835329179652035, 0.04268669792509172, 0.14673531608423218, 0.3250873106298968, 0.2348218479892239, 0.7081525633111596, 0.06497704031062312, 0.19939416699344292, 18.074999302625656, 49.16871562600136, 63.58434408903122, 35.768369883298874, 58.9512374997139, 94.33121502399445, 40.1317023485899, 26.204851157963276, 45.670714527368546, 47.9414688795805, 81.78589180111885, 32.51297436654568, 0.27598150656558573, 0.20998393156332895, 0.151650411717128, 0.2376255631679669, 0.01007031685730908, 0.14262540615163743, 0.07264274303452112, 0.05263826002192218, 0.13422983087366447, 0.05712565594876651, 0.2228105886024423, 0.21704883605707437, 0.07507458285544999, 0.08978158977697603, 0.12015226908260956, 0.06394431213266216, 0.0871785958588589, 0.003796955534198787, 0.06471871354733594, 0.05394910062022973, 0.0811345674446784, 0.07868122760555707, 0.03787621171795763, 0.08088350630714558, 0.054911087281652726, 0.04853948230447713, 0.04073228541528806, 0.06486159181804396, 0.06724390070303343, 0.10813070126459934, 0.07498464939999394, 0.06869524469948374, 0.068884989595972, 0.05202864878810942, 0.01445865462301299, 0.01790613281627884, 0.12960616179043427, 0.20008175197290257, 0.1726898382185027, 0.21186543919611722, 0.21189660939853638, 0.2636548789450899, 0.21417936659418046, 0.25690463022328913, 0.13518427731469274, 0.179639769194182, 0.3416631789878011, 0.19364721287274733, 0.10822604497661814, 0.24021694989642128, 0.20826036779908463, 0.3906929277582094, 0.23454492300515994, 0.2571110660210252, 0.1743617485044524, 0.15298050362616777, 0.16668886179104447, 0.1677389265387319, 0.18369094555964693, 0.13237602019216865, 0.1880073655047454, 0.34861823078244925, 0.16033594409236684, 0.26581170852296054, 0.19427958206506446, 0.2553503355011344, 0.26132729602977633, 0.18764531618217006, 0.23084565822500736, 0.129567050607875, 0.24127528216922656, 0.2641295565990731, 0.24540800572140142, 0.15019074082374573, 0.33106905058957636, 0.18152654607547447, 0.9147756197489798, 0.9911502746399492, 55.983475148677826, 124.49552401900291, 85.23304402828217, 121.4419774711132, 66.09560653567314, 29.107433706521988, 77.64393165707588, 107.56047874689102, 71.11101061105728, 64.62766170501709, 66.18110194802284, 27.311570271849632, 2.8544657304883003, 0.23636398633243516, 0.22377806715667248, 4.022391960024834, 6.255972431972623, 7.763969963416457, 5.747535964474082, 5.8553072065114975, 3.770767324604094, 7.525131879374385, 13.5606724396348, 46.23838506639004, 43.96846666932106, 13.407576754689217, 11.71716146171093, 23.260793834924698, 13.942308761179447, 2.6797608425840735, 0.4363888007355854, 0.7924193353392184, 0.44504874385893345, 1.7289005778729916, 6.7529757879674435, 3.3555047074332833, 2.677461728453636, 0.7819868170190603, 0.5410231626592577, 0.5291657207999378, 1.4015686861239374, 2.060755295678973, 1.052047647535801, 0.31136458448600024, 0.29247781669255346, 0.4074903123546392, 1.4824398653581738, 11.350281648337841, 1.6629684157669544, 23.655970729887486, 98.42613369226456, 91.95923790335655, 86.60668551921844, 80.89879900217056, 91.12858727574348, 96.05469614267349, 97.104731798172, 88.23700323700905, 84.02384251356125, 72.53974914550781, 64.91347476840019, 47.79342882335186, 24.605064801871777, 11.009977608919144, 4.528010878711939, 1.150338042061776, 1.6036619106307626, 2.7507391339167953, 0.525201108539477, 0.37253248505294323, 0.16926549462368712, 0.22429142554756254, 0.27379190374631435, 0.24202084372518584, 0.18709041236434132, 0.1376351309590973, 0.3307472850428894, 0.19488588703097776, 0.3743250388652086, 0.1129988931643311, 0.7720049901399761, 0.5453322501853108, 0.36751776351593435, 1.0248269769363105, 0.162238588090986, 0.4464689770247787, 12.179460804909468, 38.62363167107105, 62.72049464285374, 49.902080073952675, 76.4534479379654, 80.12218907475471, 36.1700539290905, 54.81153443455696, 79.37560513615608, 62.43523634970188, 93.78925770521164, 39.78688985109329, 0.4286545829381794, 0.5022120452485979, 0.22659145994111896, 0.2861359273083508, 0.2127202894189395, 0.23254680912941694, 0.22928912221686915, 0.11280988299404271, 0.2926960081094876, 0.1187450680299662, 0.32760800037067384, 0.24293821246828884, 0.3082951210672036, 0.1468915826990269, 0.10438980942126364, 0.2437520367675461, 0.11532406409969553, 0.14841046213405207, 0.13361784105654806, 0.23752804496325552, 0.16694068734068424, 0.18024761782726273, 0.11100514311692677, 0.15642265876522288, 0.12925659539178014, 0.10629689146298915, 0.1955871720565483, 0.14719002996571362, 0.19477159628877416, 0.1568920523277484, 0.2146958716912195, 0.24191341042751446, 0.16370351338991895, 0.20901401876471937, 0.13545189576689154, 0.13326674583368003], [0.0238023959173006, 0.0585142587806331, 0.0386893458198756, 0.06701699647237547, 0.10575676380540244, 0.08273756931885146, 0.14212461974238977, 0.04245971947966609, 0.09025304651004262, 0.047766524367034435, 0.007264249998115702, 0.049064592603826895, 0.0689282568055205, 0.054463186315842904, 0.08629276097053662, 0.053091433946974576, 0.005447959983939654, 0.015656634968763683, 0.05076864159491379, 0.0405119529023068, 0.041973082115873694, 0.01257784831977915, 0.04273821039532777, 0.042975961114279926, 0.1560441782930866, 0.0940632846322842, 0.13001671788515523, 0.05397098284447566, 0.04536660802841652, 0.0574117575888522, 0.042413958653924055, 0.02485823271854315, 0.045950900894240476, 0.07792555057676509, 0.08398672260227613, 0.04734799760626629, 0.06937501486390829, 0.03216901073756162, 0.11598668323131278, 0.1450675618252717, 0.08196934999432415, 0.4173881281167269, 0.09561182770994492, 15.095846112817526, 60.74796348810196, 65.77996507287025, 63.48993055522442, 57.319050282239914, 24.602908417582512, 38.66999298334122, 77.57154554128647, 57.400943487882614, 45.63288755714893, 55.33109575510025, 40.47684922814369, 13.635174091905355, 0.7454854412935674, 0.3448372852290049, 0.16252311266725883, 0.13007717323489487, 2.1615750482305884, 2.5901136780157685, 0.8125371183268726, 2.8320590453222394, 0.5981509597040713, 5.879911361262202, 4.842832060530782, 3.2193257147446275, 3.3332730503752828, 6.179608404636383, 2.965095844119787, 0.07686249082325958, 0.20955001265974715, 0.09715096035506576, 0.2852856635581702, 0.26385668374132365, 0.057867721989168786, 0.06675152282696217, 0.3463806852232665, 0.6434282613918185, 1.1484514432959259, 1.8174467515200377, 1.1447895085439086, 0.09474432386923581, 1.198545580264181, 2.031159158796072, 1.2512017297558486, 0.2906980871921405, 0.9723242442123592, 0.3219192899996415, 0.4593515326268971, 0.6083483062684536, 14.81392689049244, 52.254469245672226, 78.1320458650589, 71.86140954494476, 53.57124678790569, 32.05409198999405, 25.59996161609888, 18.18096611648798, 11.226218305528164, 6.441286588087678, 2.38399516325444, 0.01477170178986853, 0.4527374234749004, 0.5998406815342605, 0.9833148575853556, 0.8553026954177767, 2.126525016501546, 1.1482272553257644, 0.09235482357325964, 0.2539195935241878, 0.04577281513775233, 0.02048087688308442, 0.04297728213714436, 0.03867145635013003, 0.0400192076631356, 0.02318995710083982, 0.012506553903222084, 0.06616518905502744, 0.024537112840334885, 0.2197625584085472, 0.6862036942038685, 0.17294457298703492, 0.09597887910786085, 0.19735266716452315, 0.9871023043524474, 19.004070349037647, 28.500988148152828, 42.439687103033066, 57.48335726559162, 79.08464714884758, 58.498696982860565, 41.8957082927227, 62.93841674923897, 59.92155343294144, 59.80974443256855, 68.2032698392868, 12.152492702007294, 0.03996601422841195, 0.16980476881144568, 0.08115234930301085, 0.022149696123960894, 0.09990308884880506, 0.12685862719081342, 0.1262906170450151, 0.10588504403131083, 0.07443004244123586, 0.06064492765290197, 0.058269290675525554, 0.033091756340581924, 0.10562006020336412, 0.07771979755489156, 0.07902855271822773, 0.03550930610799696, 0.08065221598371863, 0.047070163491298445, 0.11679182440275326, 0.09359393559861928, 0.07493429468013346, 0.02888693499699002, 0.044951762320124544, 0.1322246517520398, 0.0658429336908739, 0.08044108239118941, 0.06206043704878539, 0.037772648720419966, 0.03669861631351523, 0.020652066232287325, 0.025767233746591955, 0.09436720894882455, 0.1341042446438223, 0.017259432752325665, 0.04379026038805023, 0.02493418040103279, 0.01772900443029357, 0.04490631690714508, 0.07634659428731538, 0.08540044713299721, 0.13097223301883787, 0.03784692657063715, 0.017953155293071177, 0.13235320657258853, 0.062384911434492096, 0.12136760269640945, 0.05235471879132092, 0.019340930630278308, 0.04091768874786794, 0.03302628407254815, 0.031470612666453235, 0.011393003987905104, 0.05477364895341452, 0.0447754243214149, 0.03413537182495929, 0.10037104264483787, 0.059736742987297475, 0.11662270379019901, 0.02764796397968894, 0.06092774900025688, 0.043969863836537115, 0.09320190350990742, 0.0756319506035652, 0.15335352189140394, 0.031339764609583654, 0.017293606797466055, 0.01501230235589901, 0.026822476829693187, 0.06373510812409222, 0.0459152184339473, 0.029222027660580352, 0.08200879514333792, 0.06554971114383079, 0.05875778340850957, 0.09615228933398612, 0.15689879102865234, 0.15914117539068684, 0.018371168116573244, 0.39376343018375337, 0.2824530639918521, 30.982412695884705, 85.90868577361107, 72.64391675591469, 58.53825286030769, 25.59805601835251, 25.684241093695164, 75.2205128967762, 96.8999607861042, 57.744749039411545, 45.018407329916954, 66.03515937924385, 59.7660543769598, 21.324890814721584, 1.0099436505697668, 0.32351992442272604, 0.15217147360090166, 0.21644634573021904, 0.4565568716498092, 1.9007368572056293, 2.2066544042900205, 5.120098432525992, 3.2824821257963777, 16.62762276828289, 10.069159492850304, 7.991163097321987, 11.544566173106432, 18.770829364657402, 4.34826722368598, 1.9229237479157746, 0.2632948779501021, 0.0050391423701512394, 0.47769697790499777, 0.3982104087481275, 0.4005073558073491, 0.12635702441912144, 0.311777307651937, 0.41667860525194556, 0.7475686795078218, 1.8212787271477282, 1.5935726207681, 0.7142408459912986, 0.6594059884082526, 2.393085937947035, 1.4294819883070886, 1.131872576661408, 1.5440203109756112, 0.23404636303894222, 0.6488600105512887, 1.2753699766471982, 19.89040318876505, 64.1275705397129, 90.7110732793808, 83.92143040895462, 64.6014279127121, 41.094050109386444, 30.930490382015705, 23.561122119426727, 14.555261470377445, 9.383594579994678, 4.515383206307888, 0.6996508757583797, 0.4185435629915446, 0.6954849930480123, 1.3235285924747586, 0.9274447930511087, 0.514640643959865, 1.8558384664356709, 0.08347330483957194, 0.4277961852494627, 0.22453284618677571, 0.13748760684393346, 0.03164557027048431, 0.08892809026292525, 0.03873871348332614, 0.053410987893585116, 0.05287933556246571, 0.12230100925080478, 0.17262488545384258, 0.20311476109782234, 1.0430046077817678, 0.2677005040459335, 0.12865322933066636, 0.12919820321258157, 2.5394661957398057, 39.639442563056946, 53.75190429389477, 37.65904203057289, 47.26091019809246, 83.13178718090057, 86.7496794462204, 43.09633746743202, 42.43909813463688, 48.225116059184074, 61.704068183898926, 77.22443416714668, 20.739309936761856, 0.05461890374135692, 0.25161323603242636, 0.12539957970147952, 0.04263000897481106, 0.03967179720348213, 0.07086621961207129, 0.07263762963702902, 0.04145251376030501, 0.061798303067917004, 0.05589773179963231, 0.05187863476749044, 0.05876189861737657, 0.11907452222658321, 0.06282075250055641, 0.04644122673198581, 0.10316688363673165, 0.07320612217881717, 0.053422576529555954, 0.07590134278871119, 0.09792012962861918, 0.0962025327316951, 0.07948620550450869, 0.047525523041258566, 0.130040496296715, 0.08696338787558489, 0.057715908260433935, 0.0248473992178333, 0.030667812970932573, 0.01875071171525633, 0.03942852490581572, 0.025317002437077463, 0.05681471091520507, 0.15262991306371987, 0.0195538416664931, 0.04730482316517737, 0.050901526847155765, 0.06000159322866239, 0.13944876176537946, 0.15178572008153424, 0.14631457772338763, 0.2120538556482643, 0.17571992328157648, 0.14774169801967219, 0.27572395163588226, 0.14973601209931076, 0.1188893044309225, 0.15474504878511652, 0.09259028476662934, 0.1991471802466549, 0.1039819918514695, 0.14557596266968176, 0.23154470196459442, 0.1576119801029563, 0.08328133350005373, 0.22738561732694507, 0.15323788044042885, 0.18789252557326108, 0.15283317246939987, 0.08567070763092488, 0.11416102963266894, 0.14797541516600177, 0.2201776416040957, 0.2092542964965105, 0.28023080667480826, 0.23837985238060355, 0.21391544403741136, 0.11061475859605707, 0.18870443513151258, 0.20848507527261972, 0.1252608871436678, 0.1459684400469996, 0.15949748049024493, 0.19863549910951406, 0.21687713277060539, 0.18713367957388982, 0.2038821714813821, 0.19177330483216792, 0.21231307298876345, 0.641951150028035, 0.35611727682407945, 34.99666169285774, 99.86176505684853, 97.82082617282867, 83.56070056557655, 73.36255699396133, 31.963425055146217, 56.98097102344036, 102.16959401965141, 73.78570228815079, 55.276314094662666, 69.77747216820717, 60.75197987258434, 23.945196010172367, 1.382962865754962, 0.6494245177600533, 0.2101118629798293, 0.8288157416973263, 5.147476913407445, 8.93190711736679, 11.41906175762415, 10.641281493008137, 5.158038446679711, 11.050131004303694, 5.5133402813225985, 8.641755636781454, 12.53980116918683, 16.940074302256107, 11.05869384482503, 3.3981958916410804, 0.30737660941667855, 0.13755529071204364, 0.5770405987277627, 0.858081771293655, 0.3033971245167777, 0.2109766728244722, 1.0029818303883076, 1.444575609639287, 1.6087320260703564, 4.074967363849282, 3.3680891571566463, 2.670942940749228, 2.303991406224668, 3.312583160586655, 2.9431327851489186, 1.8134270422160625, 2.884923708625138, 1.1116504180245101, 1.5655969781801105, 1.3588256109505892, 17.42702577263117, 59.461234733462334, 90.46768113970757, 85.01825675368309, 64.8062065243721, 42.35649436712265, 33.39102745056152, 24.61697716265917, 16.81187678128481, 11.516688019037247, 6.272548567503691, 1.1683189147152007, 0.7520601572468877, 1.7974442685954273, 2.7346403477713466, 2.6318791368976235, 4.744243025779724, 3.0201665265485644, 0.20339178998256102, 0.4878790659131482, 0.2710730308899656, 0.3593993803951889, 0.09866150547168218, 0.21396626631030813, 0.22675073967548087, 0.18124458933016285, 0.1865009986795485, 0.6884326308500022, 0.21873168559977785, 0.5573181726504117, 1.240404371637851, 0.3368559025693685, 0.27340738219209015, 0.3384381317300722, 2.6284272596240044, 28.394850343465805, 46.46225765347481, 51.0349702835083, 69.7674711048603, 92.50974476337433, 72.07099109888077, 53.60775522887707, 78.61153453588486, 72.59631291031837, 77.17581957578659, 89.54720333218575, 23.520017825067043, 0.1827969544683583, 0.27904681395739317, 0.1718496676767245, 0.09628971281927079, 0.131619252206292, 0.22393587743863463, 0.1850060757715255, 0.14095349586568773, 0.15213648875942454, 0.1971357225556858, 0.18519548670155928, 0.13913890026742592, 0.15740388189442456, 0.15640664321836084, 0.10624742732034065, 0.21118370234034956, 0.22639262373559177, 0.1397129663382657, 0.27830502251163125, 0.12843304895795882, 0.1521810473059304, 0.10718907171394676, 0.11176283878739923, 0.2785411145305261, 0.1712778874207288, 0.2671281894436106, 0.15010163857368752, 0.11217467137612402, 0.10447005784953944, 0.1482750053401105, 0.06440320430556312, 0.11276536897639744, 0.20344175136415288, 0.14294374297605827, 0.1317791553447023, 0.17236311512533575, 0.09666778511018492], [0.14253189554437995, 0.04745389465824701, 0.05885507525817957, 0.06819864400313236, 0.012032097038172651, 0.034922207923955284, 0.07020886972895823, 0.07624381425557658, 0.02028852148214355, 0.02448956343869213, 0.039409618693753146, 0.05439396249130368, 0.056013491994235665, 0.07543935585999861, 0.029884824907639995, 0.04053053999086842, 0.039998345891945064, 0.020221769009367563, 0.04181402131507639, 0.0747404976573307, 0.03459695799392648, 0.047409718317794614, 0.07205351488664746, 0.04433332695043646, 0.012727242647088133, 0.07773894496494904, 0.08488101055263542, 0.07709153986070305, 0.05073491840448696, 0.020326853409642354, 0.042197214424959384, 0.08792552296654321, 0.07238610836793669, 0.10928379095275886, 0.08975100587122142, 0.0764337892178446, 0.05519716665730812, 0.08730624525924213, 0.046370544587261975, 0.07063030570861883, 0.035845595484715886, 0.07356364440056495, 0.2238836747710593, 0.39483586326241493, 5.331360446289182, 43.03787760436535, 66.15480735898018, 72.26375475525856, 61.019595712423325, 32.63809025287628, 24.193026311695576, 50.72442814707756, 78.41959923505783, 71.75822988152504, 57.252303063869476, 41.75853185355663, 42.21339784562588, 8.180808071047068, 0.3305625496432185, 0.39529403555206954, 0.06136530442745425, 0.35511202295310795, 3.740213639102876, 1.308127068914473, 1.3360720756463706, 0.8430530433543026, 5.063101965934038, 10.051444843411446, 14.044241141527891, 15.233444329351187, 3.437724933028221, 1.5913003426976502, 0.3856516373343766, 0.40771096770185977, 0.11658025294309482, 0.10374980352935381, 0.06472342618508264, 0.11746113770641387, 0.009719374702399364, 0.07854299517930485, 0.0749824452213943, 0.2224521164316684, 0.040611623335280456, 0.07641618547495455, 0.17140480951638892, 0.10651377670001239, 0.08600788758485578, 0.12779886892531067, 0.12749010580591857, 0.09761938912561163, 0.22772023687139153, 0.19270406191935763, 0.39884215453639627, 0.3805722895776853, 0.6374147871974856, 1.7993574659340084, 1.4047432970255613, 0.11552883006515913, 0.4034371767193079, 0.5622418771963567, 0.6425816193223, 0.726866974728182, 1.3116044760681689, 1.1000027367845178, 0.13439338537864387, 0.4837567324284464, 0.247116592945531, 0.14888433826854452, 0.7177775062154979, 0.06072620766644832, 0.007620899268658832, 0.09810723990085535, 0.0901659851660952, 0.10864648647839203, 0.0907363256555982, 0.05639066257572267, 0.03784573913435452, 0.09346855717012659, 0.14241141529055312, 0.18384405062533915, 0.17596673191292211, 1.347796821501106, 0.5591963999904692, 0.061597236708621494, 0.3769715077942237, 5.839045504108071, 27.04711776226759, 35.43512396514416, 60.60887195169926, 64.27765488624573, 71.84765428304672, 48.31614777445793, 32.77511470019817, 65.0715234875679, 58.31047408282757, 66.35854482650757, 46.86552241444588, 3.9314637891948223, 0.42467584018595517, 0.17137828515842557, 0.05941007926594466, 0.05223935564572457, 0.11199668209883384, 0.049784535221988335, 0.07765794696751982, 0.024358550253964495, 0.07927090104203671, 0.10136653727386147, 0.02475401106494246, 0.044280615911702625, 0.014325683096103603, 0.11872115603182465, 0.06337090657325462, 0.018605113473313395, 0.0107769407077285, 0.048072856952785514, 0.09836944067501463, 0.0196576625603484, 0.04585605442116503, 0.02425654762191698, 0.06347781294607557, 0.019477239038678817, 0.09449098433833569, 0.08914219244616106, 0.09630115673644468, 0.03944382056943141, 0.07715389510849491, 0.07297737000044435, 0.05821243474201765, 0.047466488904319704, 0.057364968888578005, 0.09050219290656969, 0.07531661205575801, 0.053043086736579426, 0.030797722210991196, 0.03860000979329925, 0.07358396440395154, 0.0931881440919824, 0.06199292387464084, 0.029478777360054664, 0.08084756409516558, 0.07992845872649923, 0.1527527830330655, 0.07050415544654243, 0.0137352702950011, 0.07001915451837704, 0.008732096575840842, 0.06224303877388593, 0.057208624348277226, 0.020478863807511516, 0.08090861316304654, 0.12053230806486681, 0.036998644354753196, 0.09372337357490323, 0.043160076820640825, 0.08868977180100046, 0.029786028353555594, 0.11783756242948584, 0.04822141636395827, 0.1277497981209308, 0.11488051211927086, 0.07071706277201883, 0.05123308132169768, 0.029546910227509215, 0.04951392220391426, 0.059708029293688014, 0.056831416659406386, 0.07011742229224183, 0.059173341578571126, 0.06895771264680661, 0.07959144204505719, 0.04585454043990467, 0.029570054102805443, 0.13583615014795214, 0.0438284438860137, 0.12807861407054588, 0.06159370779641904, 0.10654709913069382, 0.4292639752384275, 0.4187982977600768, 10.656830258667469, 67.48769983649254, 78.60137388110161, 65.18365547060966, 30.751149505376816, 21.92174568772316, 46.23168222606182, 83.91608789563179, 81.94428250193596, 62.89727255702019, 57.13542893528938, 63.44553753733635, 55.82989498972893, 9.236497823148966, 0.3139997727703303, 0.2217642791219987, 0.12552138097817078, 0.3846289578359574, 0.15870491130044684, 0.767798675224185, 2.3170520178973675, 1.810621249023825, 1.202791971154511, 5.756854014471173, 7.066401969641447, 11.783262714743614, 6.5710116270929575, 2.192891067825258, 0.4206413176143542, 0.13726237986702472, 0.20045699668116868, 0.20231300411978737, 0.028556553115777206, 0.04475473324418999, 0.0404382316628471, 0.02940345679235179, 0.053272072691470385, 0.1495594551670365, 0.08907365510822274, 0.03354766879056115, 0.1281394256511703, 0.04701713703980204, 0.04112597249331884, 0.11301110149361193, 0.1941330821136944, 0.08277947097667493, 0.2133466917439364, 0.11425992081058212, 0.5500422755721956, 0.42363570537418127, 1.3444368517957628, 2.4862510012462735, 1.498670931905508, 0.47271289222408086, 0.625849929638207, 0.7548749749548733, 0.8248485764488578, 0.8375528384931386, 1.395848449319601, 0.8824017131701112, 0.6870789534877986, 1.0303429747000337, 0.3487940307240933, 0.5419449100736529, 2.4584258068352938, 0.08188857464119792, 0.052805940867983736, 0.10731805698014796, 0.03784294123761356, 0.15621847909642383, 0.06529813050292432, 0.149665136996191, 0.06745764665538445, 0.08282346549094655, 0.11798032937804237, 0.1579478761414066, 1.0139293991960585, 1.050589713267982, 0.5096137512009591, 0.05726386239985004, 0.31077620980795473, 14.305820055305958, 49.0208275616169, 41.34378030896187, 38.71427580714226, 64.57683563232422, 84.15641739964485, 67.8825518488884, 32.768753841519356, 58.34016568958759, 58.138856291770935, 70.46751514077187, 63.126666247844696, 8.73612167313695, 0.3286789491539821, 0.30359901837073267, 0.09521078594843857, 0.02328863862203434, 0.016586555284447968, 0.11411768820835277, 0.07820041981176473, 0.06489711842732504, 0.03672914455819409, 0.10456734598847106, 0.05353012114937883, 0.10030009332695045, 0.0562261061713798, 0.12425345878000371, 0.023937021505844314, 0.06879052903968841, 0.10574267042102292, 0.04403912847919855, 0.1030385291960556, 0.01616808232938638, 0.05412930891907308, 0.08172309055225924, 0.06321746754110791, 0.04379722544399556, 0.09453978796955198, 0.10835523062269203, 0.09422236398677342, 0.030334087714436464, 0.12839678762247786, 0.10196504968916997, 0.10006466181948781, 0.05306608960381709, 0.030296011827886105, 0.028692301202681847, 0.08393036390771158, 0.06821514194598421, 0.04075388562341686, 0.05420786525064614, 0.18715195124968886, 0.1555290981195867, 0.23323500266997144, 0.15102101111551747, 0.2048418574850075, 0.11969888364546932, 0.14286868216004223, 0.15216804487863556, 0.07104888441972435, 0.15896427707048133, 0.11159595203935169, 0.09962714349967428, 0.10504727804800496, 0.16176065983017907, 0.22300264157820493, 0.16538428491912782, 0.19503234245348722, 0.2547174319624901, 0.24940929492004216, 0.2426580071914941, 0.09249313763575628, 0.17789946257835254, 0.11722025883500464, 0.25000464578624815, 0.10793624373036437, 0.1791395468171686, 0.13193886552471668, 0.13148465630365536, 0.17171395855257288, 0.19671968941111118, 0.1323615334695205, 0.18867378443246707, 0.20224993641022593, 0.1529499122989364, 0.2964500879170373, 0.1962233558879234, 0.20643333380576223, 0.2005366439698264, 0.20932846673531458, 0.16835174756124616, 0.16488970286445692, 0.13061635836493224, 0.4713441344210878, 0.558896572329104, 10.278268922120333, 75.43306589126587, 102.02762603759766, 94.21385452151299, 76.6502545773983, 46.28674887120724, 41.69475607573986, 71.12728133797646, 99.18445140123367, 86.73905521631241, 67.18550205230713, 63.66503655910492, 61.05770006775856, 13.842542264610529, 0.3355506429215893, 0.4484342731302604, 0.3049190912861377, 0.4208067274885252, 6.389852548018098, 5.51881056278944, 3.863688251003623, 4.738505333662033, 13.744129445403814, 20.856584943830967, 28.77214539796114, 32.722008749842644, 12.616888582706451, 5.607914831489325, 1.442045895382762, 0.40603160625323653, 0.4579950054176152, 0.4286556813167408, 0.2491693734191358, 0.3182869224110618, 0.10073110301163979, 0.1172466496063862, 0.27327560645062476, 0.2534690801985562, 0.13148578436812386, 0.1540766705875285, 0.27847034332808107, 0.23873345606261864, 0.20615867979358882, 0.3019743977347389, 0.33875526627525687, 0.1964671810856089, 0.6155092001426965, 1.0376737313345075, 0.5291930318344384, 0.9054880868643522, 1.0975148202851415, 2.680237954482436, 2.729442701674998, 0.8534067159052938, 0.6946211925242096, 0.8103428548201919, 1.155133859720081, 1.1026856303215027, 2.2490128688514233, 1.4450205420143902, 1.4875230425968766, 1.698530470021069, 0.6921827921178192, 0.886809357907623, 2.1381702041253448, 0.20450418029213324, 0.13330879592103884, 0.24814679782139137, 0.1588885037926957, 0.2546495996648446, 0.22186236135894433, 0.23693183320574462, 0.1979823794681579, 0.5438543076161295, 0.37510004884097725, 0.31796447408851236, 1.046803097706288, 2.038344810716808, 0.5125364474952221, 0.17158810514956713, 0.3589650755748153, 10.790606830269098, 43.49795691668987, 54.973360151052475, 71.54969707131386, 79.65837836265564, 83.65017056465149, 61.73187129199505, 43.72370280325413, 77.83973515033722, 70.63871875405312, 85.68868517875671, 69.76931780576706, 8.925647903233767, 0.5586561164818704, 0.423634221078828, 0.2060931036248803, 0.1149820898717735, 0.1398796823923476, 0.15113681583898142, 0.1281249983003363, 0.13606434571556747, 0.17028910922817886, 0.17942183010745794, 0.13271813542814925, 0.24797953257802874, 0.12393812023219652, 0.22343761433148757, 0.15473529696464539, 0.19663072074763477, 0.17241659428691491, 0.11453098282800056, 0.18272309593157843, 0.08005160329048522, 0.13074709509965032, 0.07983740462805144, 0.16383344860514626, 0.09801546591916122, 0.19107255415292457, 0.21386255859397352, 0.1991425344021991, 0.2323795438860543, 0.1275904441718012, 0.2070754548185505, 0.24692169012269005, 0.17366084939567372, 0.2003342454554513, 0.16363790753530338, 0.1894981472287327, 0.25707968801725656, 0.12731973838526756, 0.24617494113044813], [0.03192353426129557, 0.10285134470905177, 0.04037416947539896, 0.07973074316396378, 0.08706146269105375, 0.107576547015924, 0.01533548169390997, 0.04654373216908425, 0.02444185818603728, 0.09154076920822263, 0.052931185709894635, 0.04799626360181719, 0.031979870691429824, 0.06590018296265043, 0.06134684350399766, 0.006677841083728708, 0.0039847624975664075, 0.04374852200271562, 0.03036185331438901, 0.08088669754215516, 0.09549848691676743, 0.05286287472699769, 0.04505135853833053, 0.08202370489016175, 0.06519365837448277, 0.07013259179075249, 0.07385976874502376, 0.026897528368863277, 0.0801888263958972, 0.054009047598810866, 0.07099041802575812, 0.04748620034661144, 0.01528446739030187, 0.036879203107673675, 0.09196676197461784, 0.13330604997463524, 0.12634121667360887, 0.010839693004527362, 0.1406666261027567, 0.034916597287519835, 0.12013289160677232, 0.053154149136389606, 0.010064718280773377, 0.09442486640182324, 0.6185061112046242, 1.1358141526579857, 19.687666967511177, 57.32150495052338, 84.79512512683868, 62.86742515861988, 46.1970204859972, 20.361530408263206, 32.630745247006416, 70.1127053797245, 75.31356230378151, 59.11095052957535, 52.757763639092445, 58.12008149921894, 26.6381324082613, 2.0780918654054403, 0.5587931466288865, 0.19192636536899954, 0.11393970635253936, 0.5388579319696873, 0.6905786250717938, 1.2974241119809449, 0.7800356217194349, 0.635627992451191, 1.867982733529061, 3.944281213916838, 2.2347736079245806, 0.8878114947583526, 0.22880264441482723, 0.13730537990340963, 0.15195288142422214, 0.07140688161598518, 0.0718486301775556, 0.036355024203658104, 0.00827392428618623, 0.01444373096092022, 0.057733812573133036, 0.10015728184953332, 0.04162343037023675, 0.04757083486765623, 0.08220965741202235, 0.0429273652844131, 0.010160654783248901, 0.08151128902682103, 0.028169300458102953, 0.11818024911917746, 0.023607624825672247, 0.08354705205420032, 0.3222761146025732, 0.30568718444556, 0.8175501774530858, 0.2239735340117477, 0.48688482551369816, 0.5197949486318976, 0.3888642165111378, 0.17312694835709408, 0.25691870134323835, 0.11301299397018738, 0.07676548470044509, 0.07337628921959549, 0.1140349535853602, 0.10539475901168771, 0.1187291118549183, 0.1467434797086753, 1.3340465468354523, 0.09547849345835857, 0.11207278934307396, 0.09537501580780372, 0.07680865543079562, 0.07253813731949776, 0.08441342040896416, 0.03070978698815452, 0.06331377604510635, 0.19164010416716337, 0.16884196578757837, 1.0990276141092181, 1.6234434116631746, 0.11032286449335515, 0.2575591451022774, 1.6666080267168581, 6.06811098754406, 20.729310773313046, 41.55728705227375, 71.87540039420128, 67.36304372549057, 54.02787588536739, 45.89098870754242, 37.245240435004234, 49.79540079832077, 62.86982282996178, 60.27136646211147, 22.13754750788212, 0.48983486252836883, 0.6746160378679633, 0.08587236399762332, 0.05161107568710577, 0.10997854507877491, 0.056813638511812314, 0.008606977899034973, 0.021346594003262, 0.054831350935273804, 0.10771267916425131, 0.10009335324866697, 0.09543971624225378, 0.1621159110800363, 0.144446874037385, 0.039240145561052486, 0.04435773618752137, 0.06831220744061284, 0.0334694649791345, 0.06765408572391607, 0.030377340081031434, 0.05014262889744714, 0.06085664754209574, 0.02035217548836954, 0.06395096919732168, 0.02882873948692577, 0.011062532121286495, 0.0620061897643609, 0.06567293734406121, 0.032917132703005336, 0.09980922201066278, 0.062100553841446526, 0.09674143584561534, 0.05111439706524834, 0.018657008149602916, 0.01748890852468321, 0.03275873983511701, 0.048976332691381685, 0.008405434709857218, 0.08103937216219492, 0.1516976419952698, 0.04183470497082453, 0.10868346027564257, 0.06208433049323503, 0.0434548356133746, 0.09227511691278778, 0.100334143062355, 0.029675713667529635, 0.03114571896730922, 0.018650467973202467, 0.01436726748579531, 0.056870089974836446, 0.04725244980363641, 0.05489631854288746, 0.06415934200049378, 0.061449612403521314, 0.022177111059136223, 0.033750605362001806, 0.05766400987340603, 0.026177648833254352, 0.03511287308356259, 0.008377227532037068, 0.044572662154678255, 0.1427719506318681, 0.057949566034949385, 0.07145823081373237, 0.05370320111978799, 0.015867542206251528, 0.02353926745854551, 0.13504939939593896, 0.017696672766760457, 0.059008399257436395, 0.04086224660568405, 0.04255382751580328, 0.020410764336702414, 0.04864779875788372, 0.05090582759294193, 0.0886671659827698, 0.0348291388945654, 0.07421196234645322, 0.05802948791824747, 0.0361320236697793, 0.12442891733371653, 0.028553603078762535, 0.0972585346607957, 0.29707871668506414, 3.6158714862540364, 39.48917202651501, 81.03018075227737, 80.58842405676842, 51.97193540632725, 26.993149258196354, 23.28958299010992, 61.679114922881126, 99.1429652273655, 88.3043660223484, 51.11500918865204, 66.53558492660522, 71.6365148127079, 30.111565925180912, 1.361664414871484, 0.48794312810059637, 0.16060728812590241, 0.3346294001676142, 0.5617794301360846, 0.18732754338998348, 0.8920387085527182, 0.8891257492359728, 1.2796715833246708, 2.412307681515813, 3.626412358134985, 3.4051298070698977, 1.081422446295619, 1.7313117859885097, 0.7225714239757508, 0.114282964495942, 0.07604521553730592, 0.16868466016603634, 0.05523832245671656, 0.03013253339304356, 0.007621204476890853, 0.09051532892044634, 0.0682022879482247, 0.018238190095871687, 0.05322531367710326, 0.11419965099776164, 0.06407232518540695, 0.1287718690582551, 0.044109981317888014, 0.07844420790206641, 0.06335211539408192, 0.15997975773643702, 0.34807515679858625, 0.14460743026575074, 0.7975256675854325, 1.0789468791335821, 0.513819531770423, 0.5767136381473392, 0.4074186208890751, 0.053881505809840746, 0.008494601897837128, 0.10058145635412075, 0.05205957037105691, 0.06105342057708185, 0.07647231410373934, 0.23453684843843803, 0.23868610704084858, 0.10751704903668724, 0.37141353415790945, 1.4378506829962134, 0.3300767991458997, 0.09950591367669404, 0.18409697455354035, 0.09541132167214528, 0.055379571713274345, 0.07017427822574973, 0.14501133671728894, 0.07390935163130052, 0.15666326304199174, 0.15612664574291557, 2.345782988704741, 1.648847779724747, 0.27482672478072345, 0.017108665451814886, 2.8121649753302336, 22.42237262427807, 40.27690775692463, 41.63909286260605, 61.916750371456146, 83.64069387316704, 65.41026011109352, 52.606375962495804, 33.93544703722, 42.29070469737053, 61.642454490065575, 74.52747568488121, 38.76639001071453, 1.1159376567229629, 0.75538634438999, 0.11805758695118129, 0.08022458307095803, 0.08249714315752499, 0.06338540071737953, 0.06049605653970502, 0.0834859287715517, 0.16122442844789475, 0.0367256898607593, 0.23678466532146558, 0.06360786690493114, 0.10269265869283117, 0.10403689593658783, 0.06660985425696708, 0.022868881751492154, 0.054330998682416975, 0.04961830527463462, 0.09103539632633328, 0.07061649434035644, 0.07299281409359537, 0.06840574031230062, 0.008944084565882804, 0.049161056958837435, 0.03069098096602829, 0.012966917383891996, 0.0725678974413313, 0.03507194734993391, 0.06823699819506146, 0.06600225053261966, 0.025499058683635667, 0.006864872038931935, 0.021776078574475832, 0.06880751680000685, 0.08949034876422957, 0.013394424131547567, 0.028840209379268344, 0.042631218675523996, 0.037928165766061284, 0.08426352142123505, 0.09795212361495942, 0.21761588141089305, 0.10049435048131272, 0.157313265663106, 0.11921279176021926, 0.1948974942206405, 0.08163820370100439, 0.09936564776580781, 0.06511254163342528, 0.13382439559791237, 0.1678625980275683, 0.15180295275058597, 0.1391269516898319, 0.1469183890731074, 0.12047390104271472, 0.10689471368095838, 0.21629019785905257, 0.13862405758118257, 0.14799071825109422, 0.12418001584592275, 0.18543631362263113, 0.13087271101539955, 0.2450194617267698, 0.12872781517216936, 0.10054411890450865, 0.33684114867355675, 0.15518796251853928, 0.1297603058628738, 0.2210776589345187, 0.16087888448964804, 0.2512414794182405, 0.14517490606522188, 0.12887490884168074, 0.16303497191984206, 0.23262463073479012, 0.19552607845980674, 0.22711108205839992, 0.07979791495017707, 0.20175919868052006, 0.1624362962320447, 0.17884666565805674, 0.26693247025832534, 0.17678342090221122, 0.21087391505716369, 0.5961454391945153, 2.529039792716503, 38.580937162041664, 92.6877424120903, 108.54858532547951, 84.2650155723095, 61.47016793489456, 32.97563374042511, 52.07807511091232, 95.96439778804779, 94.79548931121826, 72.35242679715157, 70.05909785628319, 76.22106000781059, 37.56932884454727, 2.468150435015559, 0.8267585677094758, 0.3022265201434493, 1.1044363863766193, 2.9818705189973116, 3.429611655883491, 5.489681800827384, 2.4593869177624583, 5.020235041156411, 7.67023041844368, 12.769632786512375, 8.242498710751534, 1.8663510773330927, 1.7288713669404387, 0.903395467903465, 0.2129558619344607, 0.17286137823248282, 0.2731623250292614, 0.12617739499546587, 0.12902081507490948, 0.2000838448293507, 0.16811537352623418, 0.28001041850075126, 0.14025412558112293, 0.10557785426499322, 0.36925881227944046, 0.1537133744568564, 0.17217085434822366, 0.17471745988586918, 0.23506335768615827, 0.2121857352904044, 0.17221280053490773, 0.7034970412496477, 3.7439661752432585, 1.7023610207252204, 1.503130942583084, 0.9937920235097408, 1.6086668358184397, 1.2358684837818146, 1.1074850102886558, 0.7365067605860531, 0.48562041367404163, 0.36975700117181987, 0.23053653887473047, 0.20309052255470306, 0.2552033308893442, 0.27595903433393687, 0.1857973387814127, 0.34766549128107727, 2.435367456637323, 0.5235911824274808, 0.21787870558910072, 0.3113790415227413, 0.25641591113526374, 0.24710391706321388, 0.12755139236105606, 0.2968825522111729, 0.16508044966030866, 0.4724388913018629, 0.6456500734202564, 3.852916778996587, 3.9304478187114, 0.4831148637458682, 0.2045506238937378, 3.08737613260746, 20.525742396712303, 43.441602140665054, 65.21398544311523, 85.45885071158409, 84.13960710167885, 66.83481886982918, 59.4583734869957, 51.616388484835625, 60.71444168686867, 78.14200133085251, 87.49774530529976, 42.53119759261608, 1.0233987285755575, 0.860857522347942, 0.21001044107833877, 0.2064916369272396, 0.19512283994117752, 0.26646096899639815, 0.10994687021593563, 0.13215946150012314, 0.32075907569378614, 0.28485414921306074, 0.33442456740885973, 0.15452034131158143, 0.1510518993018195, 0.20346057222923264, 0.13741962611675262, 0.12160368729382753, 0.212746205215808, 0.16280493582598865, 0.22427465301007032, 0.12072007142705843, 0.1348458431311883, 0.16071691818069667, 0.14458098012255505, 0.20632572239264846, 0.07914624249679036, 0.15936098468955606, 0.11443577270256355, 0.15387207531603053, 0.1594264421146363, 0.15433223656145856, 0.1335894168005325, 0.13019201316637918, 0.13225185888586566, 0.1554752775700763, 0.2113719703629613, 0.16576744092162699, 0.152221197495237, 0.11407799072912894, 0.19426380400545895, 0.1688629388809204], [0.004957465771440184, 0.028275464683247264, 0.02529571022023447, 0.031936436498654075, 0.03805890250077937, 0.013470388512359932, 0.015849786323087756, 0.07437622189172544, 0.048494315196876414, 0.02965950516227167, 0.015480896254302934, 0.04917814861983061, 0.01228044840900111, 0.051717061796807684, 0.12788237538188696, 0.029345949624257628, 0.03730901051312685, 0.09390724808326922, 0.03731849144969601, 0.06559477435075678, 0.0561311372439377, 0.08834736712742597, 0.0663957669166848, 0.018351120852457825, 0.057428396539762616, 0.05885275975742843, 0.062104639364406466, 0.0405660220712889, 0.032459453941555694, 0.0679838664655108, 0.032513415499124676, 0.033986830967478454, 0.014689821564388694, 0.030839679529890418, 0.07118748049833812, 0.07708877164986916, 0.01582539563969476, 0.01887192855065223, 0.07588630687678233, 0.10484907266800292, 0.05551916969125159, 0.09421143957297318, 0.040863148315111175, 0.09610855457140133, 0.1807041425490752, 0.519534187624231, 0.4317087878007442, 5.817233249545097, 37.40683436393738, 69.03189897537231, 72.99740418791771, 59.74200166761875, 35.29111169278622, 20.731134675443172, 33.44159133732319, 66.29704892635345, 72.47766047716141, 64.36996713280678, 57.05724433064461, 43.47269967198372, 10.495561212301254, 0.14953981793951243, 0.20333448133897036, 0.06051583848602604, 0.3075942664872855, 0.809340124251321, 0.5792706040665507, 1.192103500943631, 0.9239352063741535, 2.583532906137407, 0.8375141874421388, 1.232264139689505, 0.07292293346836232, 0.12554496643133461, 0.057350497008883394, 0.06425216983188875, 0.04313591249228921, 0.18444093031575903, 0.06119648809544742, 0.05324218269379344, 0.04223618088872172, 0.012114547789678909, 0.03248024149797857, 0.0787682889495045, 0.032277542413794436, 0.0581945415615337, 0.16828300984343514, 0.02391532667388674, 0.02216437951574335, 0.11437548804678954, 0.165888010233175, 0.04973147537384648, 0.47907980682794005, 0.04291982877475675, 0.008514563814969733, 0.015650764580641408, 0.047398289243574254, 0.07696689615841024, 0.07563888226286508, 0.03574195085093379, 0.1160680151951965, 0.1274245444801636, 0.1124481156875845, 0.0436052652366925, 0.05350972693122458, 0.07429840028635226, 0.136094105837401, 0.0806161698710639, 0.29873245919588953, 0.30715883360244334, 0.1359321246854961, 0.02393403250607662, 0.19289114250568673, 0.0777280873444397, 0.03304749094240833, 0.13558432459831238, 0.133347625087481, 0.7760008319746703, 2.6944983517751098, 0.8672826213296503, 0.2115808700909838, 0.7258140156045556, 7.010319828987122, 17.62733392417431, 21.233811601996422, 48.11964891850948, 74.08546060323715, 55.01635104417801, 43.249989822506905, 42.93872952461243, 44.64858457446098, 62.83166907727718, 77.46692955493927, 53.20897422730923, 8.114890158176422, 0.24455995357129723, 0.10844337550224736, 0.08733639871934429, 0.1451910551986657, 0.08583768343669362, 0.09526445806841366, 0.062416400760412216, 0.014042681777937105, 0.04392237380670849, 0.042779770665219985, 0.04271869191143196, 0.09235189951141365, 0.03723679212271236, 0.045816416313755326, 0.05112677979923319, 0.05051424821431283, 0.10322464499040507, 0.003946698207073496, 0.02719750817050226, 0.04714228169177659, 0.06520959970657714, 0.04850378129049204, 0.02163236353226239, 0.09501611319137737, 0.047371527398354374, 0.04922611733491067, 0.04757496491947677, 0.05198027931328397, 0.07971561819431372, 0.0353970228752587, 0.11642426092294045, 0.07147787546273321, 0.02815896976244403, 0.05505298962816596, 0.007599870978083345, 0.017550766533531714, 0.00470462487101031, 0.016073046608653385, 0.047501043300144374, 0.026099719616468064, 0.0330113780364627, 0.05447465620818548, 0.04288164898753166, 0.06709469191264361, 0.04469334649911616, 0.04980316312867217, 0.022669403588224668, 0.04555331383016892, 0.08264459305792116, 0.026908814579655882, 0.06546506920130923, 0.09439815650694072, 0.08357864528079517, 0.014921721376595087, 0.026551476039458066, 0.04830127887544222, 0.06885452443384565, 0.03904196615621913, 0.08311572324601002, 0.02395630992396036, 0.03821391859673895, 0.07268730900250375, 0.13007288362132385, 0.05778879458375741, 0.09368880433612503, 0.05223500666033942, 0.04425132334290538, 0.013022139664826682, 0.049043730832636356, 0.06628351708059199, 0.0352860532439081, 0.010329589858883992, 0.05022888130042702, 0.0027720428670363617, 0.05858344549778849, 0.027120604972878937, 0.07751918019494042, 0.12518736999481916, 0.08856761429342441, 0.05440053791971877, 0.0496612236747751, 0.01762939336913405, 0.06534010637551546, 0.08069463714491576, 0.011494247773953248, 0.04882058929069899, 0.5632106470875442, 0.6523111159913242, 14.101746305823326, 65.0168140232563, 80.61261355876923, 71.82903528213501, 39.73197139799595, 28.243439868092537, 34.18217919766903, 58.701955676078796, 83.93949463963509, 67.37594023346901, 63.27477850019932, 63.77789810299873, 52.040996700525284, 8.534979466348886, 0.2973609702894464, 0.14134218828985468, 0.03456648169958498, 0.40656283556018025, 0.4384720983216539, 0.9782962175086141, 0.9258362324908376, 2.347441599704325, 2.870225147344172, 1.7475021234713495, 0.9969709091819823, 0.06770610285457224, 0.13004643347812817, 0.05935585795668885, 0.11562066341866739, 0.12417992678820156, 0.1322041981620714, 0.09213263940182514, 0.0946558004943654, 0.02313552799023455, 0.01571910710481461, 0.03122720678220503, 0.05654066917486489, 0.11851514325826429, 0.017140325471700635, 0.04679959129134659, 0.06799803406465799, 0.03888048966473434, 0.07493040582630783, 0.09328562518930994, 0.2196764395921491, 0.7186891604214907, 0.22607127379160374, 0.015409649149660254, 0.0615982757153688, 0.029351510165724903, 0.1292978142737411, 0.07068112056003883, 0.04771008032548707, 0.09658424896770157, 0.06326002228888683, 0.008869256598700304, 0.08881034853402525, 0.07417940432787873, 0.0719395729538519, 0.13733818283071741, 0.38065885368268937, 0.21575653430772945, 0.32575785589870065, 0.07534899938036688, 0.05186429276363924, 0.05684073803422507, 0.06561327609233558, 0.10356370999943465, 0.056295545218745247, 0.28458540269639343, 1.7389915301464498, 4.79379141703248, 0.8149415580555797, 0.2270966101787053, 0.8350995951332152, 11.422845404595137, 37.00250945985317, 32.28119060397148, 43.19642409682274, 83.64508643746376, 75.67445933818817, 45.66906541585922, 41.78852364420891, 43.40110391378403, 62.226391956210136, 77.74763569235802, 70.52535563707352, 17.880339547991753, 0.15109460247913375, 0.3750437346752733, 0.030239784864534158, 0.1514950059936382, 0.03229565823858138, 0.023741782861179672, 0.11145979762659408, 0.10856133245397359, 0.012417552770784823, 0.0659545452799648, 0.05238245284999721, 0.09920557393343188, 0.1097622758243233, 0.11717462417436764, 0.11237859129323624, 0.05928361730184406, 0.03527755194227211, 0.012390447682264494, 0.00949656898228568, 0.027241211391810793, 0.043523031563381664, 0.028996566907153465, 0.02689562661544187, 0.08378715167054906, 0.033514238748466596, 0.04558332628221251, 0.04588487201544922, 0.08951427560532466, 0.043330870976205915, 0.06159370779641904, 0.09520190244074911, 0.09892224421491846, 0.016875191358849406, 0.03172973723849282, 0.04826999364013318, 0.028782512963516638, 0.053331759918364696, 0.0428516736428719, 0.06146912717667874, 0.03810962458373979, 0.035876049514627084, 0.16682841524016112, 0.15819542692042887, 0.13481069501722232, 0.17586434521945193, 0.18210257141618058, 0.129901462350972, 0.18991851451573893, 0.1707871348480694, 0.19283806410385296, 0.12335817635175772, 0.17538120708195493, 0.2022039084113203, 0.13926984480349347, 0.11748645978514105, 0.2576684486120939, 0.19534891296643764, 0.17809109995141625, 0.21450699510751292, 0.14451868424657732, 0.189492417848669, 0.16908783931285143, 0.3719565487699583, 0.1891329512000084, 0.1605639763874933, 0.17378174525219947, 0.32492020865902305, 0.13351031870115548, 0.12916070991195738, 0.15430799801833928, 0.17986481805564836, 0.23495124885812402, 0.1798456854885444, 0.10527538455789909, 0.15621577767888084, 0.15730119834188372, 0.21516829321626574, 0.21634410746628419, 0.17962100770091638, 0.2128728007664904, 0.19963719067163765, 0.17909026821143925, 0.22159861691761762, 0.11332536392728798, 0.19169298961060122, 0.46515254478435963, 0.7834258710499853, 0.48130645765922964, 11.369482018053532, 68.5285247862339, 98.60953465104103, 96.3385409116745, 76.26451447606087, 54.07022841274738, 35.746616050601006, 50.938854441046715, 91.32134333252907, 86.0388895869255, 78.29793736338615, 70.4551050066948, 64.92124915122986, 15.262082442641258, 0.2937646413920447, 0.3869487630436197, 0.5773816897999495, 1.3376133679412305, 2.2241797763854265, 2.3035976523533463, 7.2152941301465034, 3.700152626261115, 8.851091153919697, 5.5811666417866945, 4.571206960827112, 0.11181295602000318, 0.19317063532071188, 0.1273259724257514, 0.23663357889745384, 0.2290018368512392, 0.28281926934141666, 0.19126616563880816, 0.22754651494324207, 0.19040025741560385, 0.09339933705632575, 0.15565763809718192, 0.12586772645590827, 0.22540669539012015, 0.1927114388672635, 0.21584145084489137, 0.1845876974402927, 0.10442379978485405, 0.24853456998243928, 0.23113833158276975, 0.27496577356942, 2.7597192395478487, 0.3565622091991827, 0.10231412627035752, 0.11729130463209003, 0.1370907062664628, 0.21204407414188609, 0.3217219084035605, 0.18317398033104837, 0.28193596517667174, 0.21778133581392467, 0.1494636439019814, 0.12018026289297268, 0.20858704636339098, 0.2903032349422574, 0.29936476901639253, 0.6853961187880486, 0.4295757960062474, 0.8269430359359831, 0.42747611179947853, 0.18991351244039834, 0.23715287446975708, 0.19632051786174998, 0.1435418101027608, 0.28072840184904635, 0.3853203129256144, 2.9232600890100002, 7.211019359529018, 1.2953766155987978, 0.23032133089145645, 1.2041777092963457, 13.07057473808527, 42.6763080060482, 47.61368706822395, 69.16247516870499, 91.03822812438011, 77.48840600252151, 56.487533301115036, 55.941662192344666, 60.766164511442184, 77.3595929145813, 94.43794369697571, 75.55213630199432, 17.047657929360867, 0.15536303515546024, 0.5160199699457735, 0.13983813696540892, 0.29459715296979994, 0.22890973632456735, 0.2169385677552782, 0.16129708470543846, 0.2853738603880629, 0.2154792085639201, 0.11554571392480284, 0.10675151628674939, 0.17397779098246247, 0.2175794419599697, 0.1649562586680986, 0.17179710877826437, 0.08617164989118464, 0.1724922636640258, 0.16839375311974436, 0.125811041216366, 0.11049283857573755, 0.13499977940227836, 0.16570833628065884, 0.11957775030168705, 0.16531235596630722, 0.19915446813683957, 0.08587197808083147, 0.12265488752746023, 0.13554944365750998, 0.21855438651982695, 0.23011826444417238, 0.21103834529640153, 0.18932962033431977, 0.1443350620684214, 0.14741138293175027, 0.16312349529471248, 0.11775787803344429, 0.10451547728735022, 0.16485155647387728, 0.14273880631662905, 0.1210620159690734, 0.1253401188296266], [0.05098404253658373, 0.059952281226287596, 0.03741772772627883, 0.05894713496672921, 0.047534725672448985, 0.050502744925324805, 0.04490450977755245, 0.056671613710932434, 0.03327788697788492, 0.013854545486537972, 0.059668072062777355, 0.02098739452776499, 0.03987166870501824, 0.05229732851148583, 0.03380521258804947, 0.050894869782496244, 0.026446389783814084, 0.055347117595374584, 0.005497304919117596, 0.07066009551635943, 0.06694433279335499, 0.05567234526097309, 0.022629754348599818, 0.05108250326884445, 0.020215013610140886, 0.07054669535136782, 0.018160977051593363, 0.027804017227026634, 0.03650195460068062, 0.041061954834731296, 0.05182822067581583, 0.05691045538696926, 0.06846725693321787, 0.01686553230683785, 0.017333751420665067, 0.04066066074301489, 0.06297183150309138, 0.024623675089969765, 0.03467274240392726, 0.05783875225461088, 0.027742235288314987, 0.016309697093674913, 0.03430397293413989, 0.05243495608738158, 0.21152270055608824, 0.1752497281995602, 0.08977695877547376, 0.5777827464044094, 1.4962260005995631, 16.43930297344923, 56.69803440570831, 83.33304718136787, 73.17148044705391, 45.32590202987194, 32.261298671364784, 42.50732347369194, 48.19125987589359, 68.7706857919693, 85.77698484063148, 63.659390062093735, 47.78873607516289, 24.414121247828007, 4.037753585726023, 0.19486326636979356, 0.04324091896705795, 0.31790628971066326, 0.3029670054093003, 0.698671240825206, 1.6183659341186285, 0.8290880208369344, 0.36764101940207183, 0.7946840138174593, 0.044463985759648494, 0.019379357181605883, 0.035363140123081394, 0.09591050504241139, 0.02171185682527721, 0.030498076375806704, 0.12576053064549342, 0.027530795559869148, 0.07815108183422126, 0.06696092721540481, 0.037885811398155056, 0.06548472127178684, 0.03980386238254141, 0.05590687876974698, 0.04521975926763844, 0.08265977739938535, 0.018882300064433366, 0.07846079490263946, 0.2032873104326427, 0.020948544952261727, 0.2947350440081209, 0.14608037075959146, 0.048243209530483, 0.07049011401250027, 0.02270299504743889, 0.003212419615010731, 0.0961320880742278, 0.03410953766433522, 0.10430852940771729, 0.06024080968927592, 0.10179345030337572, 0.01728522609482752, 0.011446613953012275, 0.112247446377296, 0.030533504650520626, 0.11266035508015193, 0.5139711080119014, 3.370863008312881, 0.9636599966324866, 0.18189095542766154, 0.12987210298888385, 0.18980515887960792, 0.2640796545892954, 2.230713525786996, 3.6576725682243705, 1.1441823723725975, 0.05571749381488189, 0.7767476700246334, 6.817036075517535, 24.08700630068779, 44.9368941038847, 44.55652691423893, 50.900145918130875, 61.44861929118633, 51.22697778046131, 42.96831093728542, 57.39647872745991, 57.36381568014622, 70.03603309392929, 60.53579807281494, 24.28928654640913, 1.0204981779679656, 0.49223603680729866, 0.1344443709240295, 0.11248034716118127, 0.06864306429633871, 0.01993405876419274, 0.08909111784305423, 0.02730393585807178, 0.04720553493825719, 0.042991382943000644, 0.013449667749227956, 0.03351082115841564, 0.0704156988649629, 0.0662844447651878, 0.03850090339255985, 0.06257608867599629, 0.0387463353399653, 0.050059493514709175, 0.053502631999435835, 0.03759747960430104, 0.0622081875189906, 0.06225928067578934, 0.07006338651990518, 0.010029114673670847, 0.07480612577637658, 0.10863248215173371, 0.02242260794446338, 0.0828287198964972, 0.012722854698949959, 0.07786770016537048, 0.08555869528208859, 0.03694935832754709, 0.02188136520999251, 0.024853957947925664, 0.04464751145860646, 0.08015593441086821, 0.03133953083306551, 0.12351950441370718, 0.02561228258855408, 0.014964883757784264, 0.09239104037988, 0.01512517281298642, 0.02847947551344987, 0.021062154773971997, 0.0899165344890207, 0.036374798728502356, 0.013071466510155005, 0.04576296683808323, 0.03695406354381703, 0.004819523710466456, 0.06258030407479964, 0.01907117108203238, 0.02715220191021217, 0.0688480751705356, 0.043893366964766756, 0.04822211398277432, 0.033716956386342645, 0.030772509599046316, 0.05133425831445493, 0.00810932242529816, 0.02978977619932266, 0.014788033677177737, 0.02046498379058903, 0.08706362976226956, 0.06460707227233797, 0.020276897594158072, 0.06197711612912826, 0.0629800173919648, 0.023404786588798743, 0.025664802524261177, 0.023879623804532457, 0.026577293501759414, 0.017042508552549407, 0.02754719516815385, 0.014157659006741596, 0.055346876397379674, 0.02195693439716706, 0.03857046860503033, 0.02491320359695237, 0.05852527596289292, 0.006589249987882795, 0.06787843696656637, 0.03509442329232115, 0.11224641479202546, 0.08242563722888008, 0.054225984786171466, 0.043083854543510824, 0.18233435897855088, 0.0697889032016974, 0.06756837508874014, 0.36507621640339494, 3.872380997054279, 34.86678086221218, 76.47284209728241, 85.4960735142231, 68.64605247974396, 39.65457335114479, 27.309062406420708, 50.62400333583355, 68.99095237255096, 83.71969163417816, 77.11547121405602, 64.10891354084015, 61.912091821432114, 23.632601983845234, 1.9896297622472048, 0.11927415253012441, 0.0257696587141254, 0.08370717041543685, 0.1085236165090464, 0.2250370167894289, 0.5478809040505439, 0.3922701993724331, 0.526120065478608, 0.5141719034872949, 0.2116305791423656, 0.061336267899605446, 0.05367013844079338, 0.022564738501387183, 0.07820012295269407, 0.015314301726903068, 0.1336592380539514, 0.08012941005290486, 0.038657199693261646, 0.06226274650543928, 0.028129079764767084, 0.018879943745560013, 0.07387847828795202, 0.060447171272244304, 0.06030416683643125, 0.021134287817403674, 0.03720765540492721, 0.06115813390351832, 0.27254423475824296, 0.09947118858690374, 0.24286281026434153, 0.04500206508964766, 0.13776801992207766, 0.020186721085337922, 0.023876141276559792, 0.038208541736821644, 0.027835051987494808, 0.07412329796352424, 0.09380347357364371, 0.09087308120797388, 0.07450721837813035, 0.052683334361063316, 0.06557613160111941, 0.16396146907936782, 0.11716522116330452, 0.06039264568244107, 0.4073413187870756, 4.227655995637178, 1.040018917992711, 0.09467623924138024, 0.16017081623431295, 0.20464086905121803, 0.5014592106454074, 3.27924279961735, 5.042529869824648, 1.0009377775713801, 0.10161703437916003, 0.5400521366391331, 14.68212716281414, 43.16093400120735, 58.796015828847885, 53.45675893127918, 58.34657974541187, 80.99215999245644, 65.30945912003517, 43.321034610271454, 53.985181376338005, 58.83617967367172, 72.40222692489624, 72.72967055439949, 37.48867057263851, 2.793901967816055, 0.469449995434843, 0.06015129554725718, 0.13590426446171477, 0.07263843857799657, 0.029568888930953108, 0.05317469549481757, 0.08068619150435552, 0.02620411010866519, 0.0684066308895126, 0.07946879472001456, 0.05308314044668805, 0.08426179963862523, 0.024610399923403747, 0.03713649457495194, 0.029720697093580384, 0.049105091602541506, 0.03177623279043473, 0.08377059435588308, 0.10761624449514784, 0.011223627334402408, 0.11432743398472667, 0.04055733523273375, 0.01790260761481477, 0.02472858137480216, 0.032178369219764136, 0.018429003685014322, 0.04779722701641731, 0.05157803898327984, 0.023708415901637636, 0.07269113848451525, 0.047565387503709644, 0.08193927074898966, 0.12818361312383786, 0.020059919588675257, 0.07307927429792471, 0.0406962021952495, 0.14953909063478932, 0.04277336964150891, 0.057183216922567226, 0.0678166160651017, 0.006538410088978708, 0.05821410828502849, 0.12546197947813198, 0.23086630477337167, 0.14796045346884057, 0.1024325136677362, 0.1480717014055699, 0.1772336967405863, 0.13865258573787287, 0.16781124140834436, 0.19363777275430039, 0.11964861056185327, 0.2592257416108623, 0.23818938760086894, 0.12035717605613172, 0.14629583107307553, 0.16771388647612184, 0.19263400317868218, 0.12325481744483113, 0.1216473181557376, 0.12306086457101628, 0.2903894428163767, 0.15524783899309114, 0.14046540018171072, 0.0845991873939056, 0.0847157342650462, 0.1729560169042088, 0.31863234762568027, 0.17267889896174893, 0.15644110855646431, 0.11386192927602679, 0.12490198452724144, 0.11652385714114644, 0.13868541835108772, 0.176910639856942, 0.09480470500420779, 0.1193053821043577, 0.14549892774084583, 0.18490342190489173, 0.11132071173051372, 0.18436297512380406, 0.09973782740416937, 0.13827468414092436, 0.13123118318617344, 0.11321961530484259, 0.14520782773615792, 0.4008634382626042, 0.22773714299546555, 0.15662461199099198, 0.9945078694727272, 2.269530580379069, 31.120696775615215, 83.16905558109283, 107.5272685289383, 98.32572028040886, 69.81826677918434, 43.00231151282787, 61.575319692492485, 70.57973831892014, 88.22584703564644, 101.10350042581558, 78.65995913743973, 74.23618331551552, 36.66539154946804, 7.2014756966382265, 0.25732539827004075, 0.15721270465292037, 0.6393041764385998, 1.068353047594428, 2.074000909924507, 6.047267206013203, 1.8388962442986667, 1.6796789690852165, 2.341938544996083, 0.32427744939923286, 0.15578694990836084, 0.182138817908708, 0.30717795132659376, 0.2535914455074817, 0.16868810373125598, 0.17409132473403588, 0.1809024444082752, 0.17687895015114918, 0.26720748050138354, 0.1432073093019426, 0.12393695506034419, 0.12128897215006873, 0.20866964739980176, 0.18389980075880885, 0.20146464026765898, 0.11683454242302105, 0.25022818066645414, 1.1762842372991145, 0.1916005922248587, 0.66770646488294, 0.3065827488899231, 0.24968881742097437, 0.19605494773713872, 0.15231853758450598, 0.14076687541091815, 0.18355508800596, 0.19242387148551643, 0.14115040248725563, 0.23392919276375324, 0.23932341893669218, 0.11687447738950141, 0.1843233295949176, 0.3433470526942983, 0.29542794276494533, 0.3645883878925815, 0.9444194321986288, 5.710828034207225, 2.3103881254792213, 0.7013475440908223, 0.3271403879625723, 0.5472596373874694, 0.4229080444201827, 4.420366454869509, 8.281646110117435, 2.289589704014361, 0.16800400684587657, 1.8979632435366511, 16.32142949849367, 50.65507046878338, 79.5878617465496, 70.2944116294384, 67.9926623404026, 80.22545993328094, 71.80751323699951, 55.473018139600754, 74.26019802689552, 76.5754745900631, 90.02584084868431, 82.38135784864426, 35.600099712610245, 2.166950097307563, 0.6781411205884069, 0.18998189392732456, 0.24812998075503856, 0.26369447994511575, 0.11591238682740368, 0.17066858417820185, 0.17354887415422127, 0.29940736829303205, 0.21196062705712393, 0.17882205604109913, 0.16971997101791203, 0.22920625400729477, 0.1607789914123714, 0.20060751907294616, 0.11987991572823375, 0.1308342529227957, 0.15075950796017423, 0.20299674477428198, 0.15426579950144514, 0.1981566654285416, 0.297247659182176, 0.14540843025315553, 0.141714375349693, 0.13020660378970206, 0.22453394456533715, 0.14171376678859815, 0.12150697060860693, 0.14657823310699314, 0.17364437371725217, 0.2217088852194138, 0.1453712783404626, 0.25731851113960147, 0.17962905258173123, 0.12251907450263388, 0.19920285616535693, 0.18191140901762992, 0.1787338888971135, 0.09012649548822083, 0.21720161457778886, 0.19898640137398615, 0.12407335438183509, 0.26238393620587885], [0.05431072320789099, 0.06909124727826566, 0.05218922728090547, 0.03259368990256917, 0.1049895686446689, 0.026491471544431988, 0.07489143565180711, 0.07959153110277839, 0.007961619267007336, 0.06100587859691586, 0.03993571976025123, 0.01756149056745926, 0.024358526134165004, 0.03145409245917108, 0.026276007520209532, 0.06829561301856302, 0.07677286164835095, 0.0507110731996363, 0.04925158042169642, 0.04047586226079147, 0.021482050797203556, 0.12600428162841126, 0.07125426636775956, 0.010519227143959142, 0.032522985493415035, 0.09737170476000756, 0.040516431763535365, 0.031287907040677965, 0.014612460090575041, 0.0699164709658362, 0.05055383808212355, 0.04858064181462396, 0.09978698726627044, 0.0637381435080897, 0.03302637313026935, 0.05869419990631286, 0.025301883033534978, 0.036979259457439184, 0.09035970055265352, 0.020714031852548942, 0.09863654704531655, 0.014261927972256672, 0.03972012586018536, 0.051437042056932114, 0.061355868019745685, 0.15416652982821688, 0.009357105518574826, 0.07915052468888462, 0.5238939786795527, 0.36498365574516356, 2.755005117505789, 28.367676101624966, 68.34772288799286, 79.85544338822365, 65.68698406219482, 53.07804085314274, 37.110799849033356, 28.937571421265602, 59.02968429028988, 78.64555031061172, 73.02340999245644, 75.65058141946793, 54.912031441926956, 20.388727448880672, 3.209133236669004, 0.501146261813119, 0.3215212613577023, 0.11168622688273899, 0.19130064581986517, 0.17829156888183206, 0.32271703938022256, 0.20849436696153134, 0.19932793773477897, 0.07193937999545597, 0.07290593086509034, 0.08852426544763148, 0.06642656604526564, 0.054471416733576916, 0.033660334229352884, 0.019466125377221033, 0.052515419738483615, 0.04390728223370388, 0.08315367667819373, 0.15689840511186048, 0.05333061330020428, 0.09896700314129703, 0.10082508859341033, 0.14148607588140294, 0.05864816077519208, 0.17681220138911158, 0.039758550556143746, 0.15720638155471534, 0.3455364180263132, 0.1374962305999361, 0.09408692203578539, 0.007646639733138727, 0.0830991956172511, 0.10446496671647765, 0.08135671450872906, 0.1514685558504425, 0.045655214416910894, 0.08617871513706632, 0.11437453067628667, 0.03757794256671332, 0.17958007083507255, 0.09813699260121211, 0.31963300018105656, 0.0952951904037036, 0.7337902626022696, 2.646613558754325, 1.8781487317755818, 0.23070877650752664, 0.5991070240270346, 2.5766120525076985, 3.5837047873064876, 1.5977744827978313, 0.09237900274456479, 0.9083518863189965, 9.014015961438417, 23.55567131191492, 35.843214467167854, 46.27097971737385, 58.94802667200565, 53.58250178396702, 59.5087093859911, 39.78364482522011, 41.55627250671387, 53.7494458258152, 70.59556066989899, 54.304649233818054, 30.980001725256443, 3.887828830629587, 0.042956082688760944, 0.3183205268578604, 0.03189530296367593, 0.14844958815956488, 0.11954436107771471, 0.08807532547507435, 0.026164039700233843, 0.059674981457646936, 0.07336814785958268, 0.011048285668948665, 0.024382944648095872, 0.025154544455290306, 0.026897728748735972, 0.02723203844652744, 0.041625044541433454, 0.03950520731450524, 0.08358094593859278, 0.0869976899411995, 0.022543342383869458, 0.025566226759110577, 0.043991619895678014, 0.11865177264553495, 0.09366073631099425, 0.03448682698945049, 0.054854888148838654, 0.0393542544770753, 0.04308440373279154, 0.06486931015388109, 0.024370461724174675, 0.04412100221088622, 0.13336307660210878, 0.027422267594374716, 0.009512295091553824, 0.017486505821580067, 0.018926825214293785, 0.032116455549839884, 0.0421031286532525, 0.1053033783682622, 0.06022025219863281, 0.014429866714635864, 0.04797187662916258, 0.07970782564370893, 0.016826749524625484, 0.022167459428601433, 0.02008138435485307, 0.06300444889348, 0.052453094176598825, 0.03257990079873707, 0.08201256525353529, 0.022749121380911674, 0.05764253954112064, 0.08321453278767876, 0.07450851713656448, 0.005949713504378451, 0.04440083270310424, 0.08534843000234105, 0.06450283020967618, 0.0702945061493665, 0.03238201083149761, 0.014438252055697376, 0.019779951799137052, 0.010132140541827539, 0.01782064853614429, 0.03149438365653623, 0.05079027519968804, 0.05625433746899944, 0.0845568923978135, 0.03953113053285051, 0.037032727486803196, 0.05646347468427848, 0.04402843042043969, 0.005722821333620232, 0.013350879544304917, 0.0778295389318373, 0.05666590288456064, 0.016687524475855753, 0.007694854748478974, 0.01787024812074378, 0.039885862279334106, 0.039654453212278895, 0.04946590153849684, 0.03843061829684302, 0.12370186494081281, 0.03552110254531726, 0.07326644394197501, 0.1022663245385047, 0.07385475924820639, 0.08529832761269063, 0.01075812169801793, 0.20910059771267697, 0.021865383059775922, 0.05602476521744393, 0.42819771682843566, 1.362735719885677, 12.449275776743889, 57.016939893364906, 85.43872699141502, 77.2969950735569, 56.761054024100304, 52.31317989528179, 39.13645215332508, 42.93063595890999, 86.71825513243675, 91.215640604496, 64.78687316179276, 72.69423365592957, 46.68395295739174, 12.187470775097609, 2.3286252468824387, 0.5754051427356899, 0.2938257943606004, 0.2020885786623694, 0.38847354997415096, 0.6823726091533899, 0.13278656144393608, 0.21666628861567006, 0.5206781043671072, 0.2738765679532662, 0.08270224308944307, 0.09828046459006146, 0.059516191540751606, 0.11351599940098822, 0.020398578271851875, 0.052184162123012356, 0.033611679027671926, 0.027920920329052024, 0.010668560244084802, 0.11701889190590009, 0.046665162371937186, 0.04444600723218173, 0.06026600189215969, 0.037981596688041463, 0.08220582050853409, 0.04076275057741441, 0.244774152233731, 0.23299831693293527, 0.2615657926071435, 0.038529635639861226, 0.062140555601217784, 0.023942830666783266, 0.09686154502560385, 0.02972337624669308, 0.08306602903758176, 0.10791339300340042, 0.05302108947944362, 0.07340417170780711, 0.04801485440111719, 0.0558231941977283, 0.04410965477291029, 0.00823282971396111, 0.2635791205102578, 0.033417451559216715, 0.6036679074168205, 5.543505437672138, 2.8596505522727966, 1.0692848288454115, 1.508243449497968, 3.822388742119074, 3.7157892622053623, 1.3252136833034456, 0.053114763359189965, 0.8572977664880455, 14.792999513447285, 40.616138353943825, 55.519599840044975, 59.814482778310776, 81.34092807769775, 71.96972653269768, 65.78580155968666, 44.46235276758671, 40.197822600603104, 54.547387808561325, 74.81685295701027, 68.51820454001427, 46.610795482993126, 9.781719166785479, 0.13167001510737464, 0.397494028438814, 0.029217977389635053, 0.07377952031674795, 0.070070065848995, 0.03174047240463551, 0.013657146264449693, 0.0521094575378811, 0.004816650671273237, 0.0384575137286447, 0.019778623354795855, 0.05518149620911572, 0.04615801575710066, 0.07154279854148626, 0.09865467771305703, 0.030540781408490147, 0.012362997495074524, 0.06096495286328718, 0.06051535237929784, 0.01452545533538796, 0.012665770555031486, 0.0396703203296056, 0.07771984950522892, 0.049654904287308455, 0.03382522460015025, 0.042515829554758966, 0.022108707307779696, 0.061246412369655445, 0.034499372995924205, 0.050404054127284326, 0.05963195173535496, 0.06806767720263451, 0.020232732385920826, 0.022372466592059936, 0.030710399259987753, 0.03901987613062374, 0.03430633667449001, 0.026903712314378936, 0.030778754771745298, 0.013179280158510664, 0.05872542576980777, 0.049611800350248814, 0.04743434277770575, 0.038884029709151946, 0.18196067278040573, 0.14843101962469518, 0.1473814743803814, 0.14584374439436942, 0.18415980477584526, 0.1968251189100556, 0.14137272024527192, 0.22877309209434316, 0.21851220284588635, 0.15457433997653425, 0.10250095452647656, 0.15212367929052562, 0.15351703186752275, 0.1361279477714561, 0.12496419134549797, 0.09527354937745258, 0.18139322666684166, 0.1895255027920939, 0.13287808309542015, 0.19078209239523858, 0.1920802125823684, 0.12366803784971125, 0.1647742246859707, 0.14209264802047983, 0.25069671333767474, 0.18374678475083783, 0.1370671801851131, 0.16868669365067035, 0.12448794033844024, 0.1552705783979036, 0.17074070608941838, 0.19123236823361367, 0.23262905393494293, 0.14539857453200966, 0.14103992638411, 0.0834126936388202, 0.1037835564056877, 0.19879083061823621, 0.16025929508032277, 0.1628906835685484, 0.1735127909341827, 0.18983992107678205, 0.17957043775822967, 0.1942170041729696, 0.20870740787358955, 0.30035488307476044, 0.09129061349085532, 0.12938725791173056, 0.603183611528948, 1.0221255593933165, 7.343723438680172, 52.869850024580956, 98.68341028690338, 103.97127494215965, 87.00627207756042, 74.71703991293907, 54.051271229982376, 45.17273224890232, 83.0740150809288, 105.39922311902046, 92.42237225174904, 99.20644462108612, 79.0708614885807, 32.39018015563488, 5.912871742621064, 0.8478903619106859, 0.7410782121587545, 0.7315289089456201, 1.0776320309378207, 2.627043896354735, 1.6417551040649414, 0.5022788979113102, 0.5713933298829943, 0.6732848030515015, 0.24964832584373653, 0.3175667126197368, 0.24147692369297147, 0.32547206967137754, 0.10848311008885503, 0.20557149255182594, 0.13488228258211166, 0.3141877142479643, 0.2536671148845926, 0.40774204884655774, 0.18276097514899448, 0.26157306565437466, 0.2181933613610454, 0.29163755709305406, 0.2383698185440153, 0.3995960875181481, 0.40497588634025306, 0.675499252974987, 0.8393951458856463, 0.2477031122543849, 0.15979058429365978, 0.12636873550945893, 0.22122632595710456, 0.2672422130126506, 0.33638175926171243, 0.27840349066536874, 0.2658016746863723, 0.21853333921171725, 0.2726541319862008, 0.25224990968126804, 0.3137592278653756, 0.193428932398092, 0.7326012826524675, 0.14536667702486739, 1.4271517633460462, 9.680086020380259, 4.408207107335329, 1.5157783264294267, 2.019935748539865, 5.286642070859671, 6.985105806961656, 1.7961980542168021, 0.21997890929924324, 1.6421710629947484, 18.13572384417057, 53.99986378848553, 65.89383736252785, 77.52771109342575, 79.45855468511581, 69.63744968175888, 75.57710096240044, 57.993096113204956, 56.73363849520683, 71.30529418587685, 91.32263526320457, 80.27450010180473, 47.51604750752449, 7.264732327312231, 0.25089848844800144, 0.7000220089685172, 0.17590405012015253, 0.20774340257048607, 0.18042896903352812, 0.1788776132161729, 0.26901517412625253, 0.1126542546262499, 0.1368737468146719, 0.06751760476618074, 0.1115632159053348, 0.09064855927135795, 0.07458843901986256, 0.12782180128851905, 0.13079392461804673, 0.1562759213265963, 0.1973527265363373, 0.21349751099478453, 0.15286927053239197, 0.14703978959005326, 0.11553061864105985, 0.18199920508777723, 0.22136077343020588, 0.17492711660452187, 0.1645714699407108, 0.09569616537191905, 0.12790085485903546, 0.17461718089180067, 0.10536067216889933, 0.1557200081879273, 0.248894318647217, 0.22004034428391606, 0.08323982518049888, 0.08288567973067984, 0.06497825001133606, 0.09279394493205473, 0.229187655786518, 0.13631752197397873, 0.19001912005478516, 0.09007243745145388, 0.12938482366735116, 0.13210437929956242, 0.0987285807786975, 0.1459730413625948], [0.022039108698663767, 0.0597896989347646, 0.0760933363926597, 0.06216267531272024, 0.05506948757101782, 0.01939552486874163, 0.0865700124995783, 0.024443817455903627, 0.01856510243669618, 0.10150359710678458, 0.05049394676461816, 0.024568065964558627, 0.05577555202762596, 0.07150950579671189, 0.04902354812656995, 0.04117005235457327, 0.04739261923532467, 0.01784114479960408, 0.029122826636012178, 0.014542201897711493, 0.05869775850442238, 0.03608907187299337, 0.0621642115584109, 0.019510997481120285, 0.08540513008483686, 0.11574511416256428, 0.059332291057216935, 0.06859587854705751, 0.02690756035008235, 0.05032072207541205, 0.037176897094468586, 0.0660513510229066, 0.0325880161835812, 0.022451701988757122, 0.03368404213688336, 0.06460819291532971, 0.03287166131485719, 0.023772773092787247, 0.039526829787064344, 0.04779540504387114, 0.009899550532281864, 0.03570140732335858, 0.04938714482705109, 0.08938058512285352, 0.06408475615899079, 0.06836879620095715, 0.04197035472316202, 0.21082552702864632, 0.20876308379229158, 0.2073257663869299, 0.33825814607553184, 0.39155393780674785, 7.729021813720465, 30.755523070693016, 63.48593316972256, 69.19671893119812, 67.18137547373772, 52.86984622478485, 29.27979625761509, 30.134514793753624, 55.83480812609196, 62.17837393283844, 74.49947878718376, 79.6392197906971, 52.59194813668728, 24.3116844445467, 5.548835126683116, 0.4192394303390756, 0.03512827635859139, 0.10117152312886901, 0.08019087472348474, 0.09212245713570155, 0.13461453054333106, 0.4300185019383207, 0.7048147986643016, 0.19428201630944386, 0.10076743114041165, 0.2578381629427895, 0.042687228560680524, 0.13730255974223837, 0.12369242482236587, 0.0989306230621878, 0.12329116041655652, 0.21077682729810476, 0.1819282557698898, 0.2314945773105137, 0.24595946597401053, 0.2052344536059536, 0.6482091173529625, 0.22511933580972254, 0.05861978846951388, 0.4429536609677598, 0.38397034630179405, 0.15830804040888324, 0.047657194882049225, 0.053696332543040626, 0.015232300902425777, 0.0448524889361579, 0.05587039478996303, 0.04234243788232561, 0.06559360917890444, 0.10917868057731539, 0.06175325470394455, 0.07609414533362724, 0.043443885224405676, 0.17650720837991685, 0.16899852926144376, 0.08066144830081612, 2.4397678580135107, 0.6598068668972701, 1.4542497717775404, 1.3675346248783171, 1.1210274836048484, 0.15453264612006024, 0.029180790224927478, 0.9383830998558551, 13.27985705807805, 32.55394756793976, 30.737848319113255, 53.53673703968525, 59.01641920208931, 50.33911742269993, 31.71987522393465, 54.54509273171425, 47.998226433992386, 51.06616660952568, 64.30096283555031, 64.20848339796066, 32.830519527196884, 7.497544409707189, 0.14623016584664583, 0.2860496303765103, 0.07554761294159107, 0.1147823482460808, 0.02440485099214129, 0.06929998373379931, 0.03466876078164205, 0.07529092632466927, 0.0511548404028872, 0.042740225326269865, 0.04361264960607514, 0.11621001031016931, 0.042388792426208965, 0.024399631838605274, 0.04423351179866586, 0.0717994332080707, 0.06403080202289857, 0.07811980773112737, 0.006913830129633425, 0.08004030038136989, 0.045870763788116165, 0.13260342908324674, 0.059686970853363164, 0.06585480805370025, 0.020842620069743134, 0.058372193161631, 0.016348978970199823, 0.11277815618086606, 0.02163501485483721, 0.05017590679926798, 0.055216674008988775, 0.01932852934260154, 0.03690191653731745, 0.10664652465493418, 0.048745361491455697, 0.077351113432087, 0.01567359118780587, 0.05231153692875523, 0.0468958626879612, 0.088367100834148, 0.09766522416612133, 0.03839473916741554, 0.05653541848005261, 0.09538733545923606, 0.08915976650314406, 0.0035907750816477346, 0.0712613835639786, 0.017184080643346533, 0.0073796367996692425, 0.08543769552488811, 0.02492650102794869, 0.01182160262032994, 0.11270771152339876, 0.02752500124188373, 0.03663955991214607, 0.06344553694361821, 0.12481252604629844, 0.04824377356271725, 0.07439034496201202, 0.061160345503594726, 0.07518344107666053, 0.04719741584267467, 0.04291819604986813, 0.04972959402948618, 0.040240059679490514, 0.02407675863651093, 0.04488545142521616, 0.08494508016156033, 0.06600852168048732, 0.07298571174032986, 0.02779297406959813, 0.11423842821386643, 0.050781985410139896, 0.038582836496061645, 0.08193973088054918, 0.10859625050215982, 0.029679710132768378, 0.05453190176922362, 0.06264525683945976, 0.07271539187058806, 0.07646327474503778, 0.10976093253702857, 0.02056023102340987, 0.022829156441730447, 0.019370395748410374, 0.0009310574830578844, 0.08783991623204201, 0.10261762014124542, 0.01968039825442247, 0.07379638191196136, 0.11804033201769926, 0.04272340454917867, 0.07102258270606399, 0.09054394613485783, 0.10958502869470976, 0.266737611964345, 0.4974093701457605, 1.982879899442196, 23.86898159980774, 60.94348579645157, 82.99120992422104, 74.74049225449562, 68.79824951291084, 48.49926754832268, 35.57710714638233, 55.09825944900513, 84.34265300631523, 81.31952002644539, 89.36504110693932, 76.31709605455399, 43.842518627643585, 21.042064391076565, 5.348093323409557, 0.833709582220763, 0.11561345716472715, 0.037234298506518826, 0.026424796997162048, 0.19632514886325225, 0.2032019040780142, 0.11954661720665172, 0.3293129807570949, 0.07571430673124269, 0.030969933868618682, 0.08749150758376345, 0.077672114566667, 0.07861841222620569, 0.06443746184231713, 0.1442323043011129, 0.08498498544213362, 0.0677572145650629, 0.06036598402715754, 0.10343437592382543, 0.0413636341545498, 0.07628615378052928, 0.41202207386959344, 0.13176413427572697, 0.04990333822206594, 0.6309134548064321, 0.28400406357832253, 0.5042696348391473, 0.064280000369763, 0.12109637740650214, 0.044792285916628316, 0.049319594545522705, 0.0633963399741333, 0.07055920053971931, 0.12111374366213568, 0.10228199127595872, 0.03975724808697123, 0.011199935197510058, 0.05870491651876364, 0.19741099997190759, 0.25770294363610446, 0.26069557992741466, 2.6314067747443914, 0.8476209919899702, 0.5172019440215081, 0.4225369408959523, 0.2545571280643344, 0.07082322699716315, 0.05542879465792794, 0.9799636749085039, 17.398310713469982, 49.71018277108669, 50.81131428480148, 69.20981302857399, 72.81593352556229, 72.52023339271545, 45.425969660282135, 50.40190525352955, 49.55782614648342, 50.58239556849003, 68.56226697564125, 76.32240056991577, 48.434454426169395, 15.004420168697834, 0.5833243927918375, 0.2197106822859496, 0.15733468404505402, 0.10379196493886411, 0.1280429316102527, 0.04773750639287755, 0.059952715382678434, 0.052622352086473256, 0.04317683822591789, 0.016706564274500124, 0.05576539573667105, 0.04186232399661094, 0.06129789886472281, 0.035558298986870795, 0.05831725567986723, 0.0699125746905338, 0.05508519883733243, 0.01501965889474377, 0.01101522855606163, 0.03566940220480319, 0.06593812897335738, 0.03852632566122338, 0.08054659352637827, 0.048301200949936174, 0.08145759464241564, 0.026249273505527526, 0.07011293972027488, 0.07146208256017417, 0.031498038733843714, 0.035088756994809955, 0.07335706759477034, 0.06187487415445503, 0.04730644475785084, 0.05075585067970678, 0.052460107472143136, 0.09713172388728708, 0.023938437152537517, 0.025363870918226894, 0.0027834070033350145, 0.040884744812501594, 0.040053958728094585, 0.1318103849189356, 0.021735650079790503, 0.025581960289855488, 0.02764186167041771, 0.06396135184331797, 0.10551153594860807, 0.14965072448831052, 0.19275102502433583, 0.1882092296727933, 0.1378631780971773, 0.05222187435720116, 0.21342141117202118, 0.11327038562740199, 0.1651976050925441, 0.211507263884414, 0.27288511802908033, 0.12787701707566157, 0.22934536216780543, 0.23376065102638677, 0.12286373530514538, 0.12217664756462909, 0.20065016287844628, 0.17184006428578869, 0.13824434514390305, 0.13385709462454543, 0.16742222243919969, 0.1878671144368127, 0.16270686843199655, 0.22711802856065333, 0.18289036117494106, 0.16568075807299465, 0.24317152885487303, 0.20635419117752463, 0.19689281762111932, 0.2507762418827042, 0.16238165932008997, 0.1723255030810833, 0.11153766376082785, 0.21942614286672324, 0.2487125073093921, 0.18534304050263017, 0.18419789179461077, 0.14658206258900464, 0.15930940542602912, 0.12804551428416744, 0.14234563132049516, 0.14601659058826044, 0.1853781589306891, 0.2462566367466934, 0.2827935613458976, 0.12243141944054514, 0.24144738621544093, 0.47055828908924013, 0.2395989338401705, 0.34001762978732586, 0.46130397473461926, 1.0219014901667833, 18.35967432707548, 60.57315766811371, 96.11930027604103, 98.11937615275383, 91.97629138827324, 79.69760745763779, 47.10359863936901, 47.96729229390621, 82.29348376393318, 87.28779897093773, 101.24967098236084, 104.50277522206306, 75.66658616065979, 37.016428112983704, 9.535149447619915, 1.199889164417982, 0.28204034082591534, 0.15202804614091292, 1.109352728817612, 0.5814545962493867, 0.4235921264626086, 0.554219854529947, 0.8840266603510827, 0.4365324805257842, 0.30305977386888117, 0.49044924206100404, 0.17916233075084165, 0.32594520365819335, 0.25254762964323163, 0.39519740792457014, 0.3028495976468548, 0.46311576501466334, 0.5200005532242358, 0.4606135102221742, 0.5189456348307431, 0.467208739137277, 1.3300347933545709, 0.3826369741000235, 0.1241805576137267, 1.5475426032207906, 0.7125832443125546, 0.5000583920627832, 0.1678024246939458, 0.2641538099851459, 0.12976322992471978, 0.12883330404292792, 0.13842274260241538, 0.17490045865997672, 0.19631677743745968, 0.16114763100631535, 0.1874272435088642, 0.20779818791197613, 0.24866269435733557, 0.28798001585528255, 0.5067659821361303, 0.6093480682466179, 4.50928975827992, 1.828346704132855, 3.0258308351039886, 2.354241097345948, 2.8416076954454184, 0.46712938870768994, 0.16048925695940852, 1.901837254408747, 22.036649622023106, 57.906065583229065, 66.66137337684631, 86.16497442126274, 81.05114802718163, 70.77206119894981, 50.5888020247221, 72.20526829361916, 67.52947479486465, 66.72923773527145, 84.37888786196709, 85.89134350419044, 50.50978906452656, 11.590237822383642, 0.2547620498808101, 0.42195675952825695, 0.3108728671213612, 0.25569062505383044, 0.3171739086974412, 0.14275183842983097, 0.15057864657137543, 0.13817857601679862, 0.12973082775715739, 0.15782800444867462, 0.15817057981621474, 0.3028111543972045, 0.1744337665149942, 0.11484895600005984, 0.2488714604987763, 0.21130415290826932, 0.21722050965763628, 0.18488810397684574, 0.11914320799405687, 0.1064326822233852, 0.11121072544483468, 0.14970963617088273, 0.18846939696231857, 0.10673249504179694, 0.17691142653347924, 0.10890947392908856, 0.24681939248694107, 0.26295631018001586, 0.16013540094718337, 0.13681609678315, 0.18974422855535522, 0.19798718858510256, 0.20003703015390784, 0.2705751091707498, 0.12878634093794972, 0.1868553296662867, 0.12020470181596465, 0.21770314313471317, 0.1978706565569155, 0.12518713250756264, 0.1589107682229951, 0.17867419053800404, 0.2631702565122396, 0.16433698096079752, 0.2282668137922883, 0.2836446859873831], [0.06330342308501713, 0.1098809675022494, 0.04048555842018686, 0.09547209614538588, 0.0663700292352587, 0.18171126663219184, 0.17443431570427492, 0.11640672397334129, 0.1225244699162431, 0.05812837538542226, 0.008805577544990228, 0.0946531213412527, 0.09681456707767211, 0.04641252788132988, 0.1109829825873021, 0.014169492551445728, 0.07749484517262317, 0.03554979768523481, 0.09767991126864217, 0.16519472555955872, 0.09449194170883857, 0.16152115393197164, 0.0775371327472385, 0.10552817489951849, 0.12925344868563116, 0.14194659335771576, 0.09666523954365402, 0.05945362107013352, 0.05055138528405223, 0.0858695586794056, 0.15194216481177136, 0.1025749986001756, 0.044863765870104544, 0.03318049122754019, 0.10693898278987035, 0.10215305796009488, 0.06299134256551042, 0.09562653707689606, 0.025159739489026833, 0.06860771580250002, 0.056606709185871296, 0.18374218343524262, 0.11212674347916618, 0.042274078659829684, 0.11293392555671744, 0.02896444118960062, 0.05753878358518705, 0.10241689888061956, 0.09453857826883905, 0.12076409562723711, 0.1319353625876829, 0.05960845905065071, 0.1620280704810284, 1.46876071812585, 15.91719388961792, 37.61648051440716, 62.1922317892313, 62.66307212412357, 52.78968192636967, 48.57611462473869, 30.40462899953127, 38.2372760027647, 42.23207384347916, 54.565816819667816, 74.84462946653366, 74.02287796139717, 54.249692782759666, 34.2889154702425, 16.32107801735401, 3.304747031070292, 0.25553023209795356, 0.31739664205815643, 0.1522370646125637, 0.15614380419719964, 0.581721116323024, 0.5871944257523865, 0.1251008949475363, 0.38827115145977587, 0.27240699680987746, 0.19326937064761296, 0.5640899436548352, 2.2797289956361055, 0.2960853965487331, 0.34554131620097905, 0.09273492934880778, 0.1333959389012307, 0.22611863765632734, 0.2360427551320754, 0.9004676062613726, 0.14120796346105635, 0.16935226653004065, 0.06294101753155701, 0.07011008987319656, 1.0554421716369689, 0.5992704746313393, 0.07741449284367263, 0.10081688786158338, 0.18225052597699687, 0.14262414450058714, 0.0820828540599905, 0.3525430045556277, 0.15901950770057738, 0.533542848424986, 0.4533461626851931, 0.3517091867979616, 0.14700698666274548, 1.4184057014063, 1.2563201738521457, 0.3504801605595276, 0.1277966276393272, 0.08709661080501974, 0.04063010281242896, 0.6203382066451013, 3.941544648259878, 17.413637191057205, 45.844885781407356, 64.91009294986725, 54.12433370947838, 63.815303295850754, 49.80410233139992, 46.81403137743473, 31.805801913142204, 50.59292480349541, 54.57942768931389, 64.57257986068726, 65.17978727817535, 38.59306611120701, 11.595575585961342, 0.4994505434297025, 0.21849918557563797, 0.036355128104332834, 0.05392168939579278, 0.1543352348380722, 0.17418864998035133, 0.13420675008092076, 0.03885811020154506, 0.09923866629833356, 0.09366937490995042, 0.13932115689385682, 0.1275448317755945, 0.0895175855839625, 0.16930990474065766, 0.08499784686136991, 0.1035632127604913, 0.12073024627170525, 0.04800690228876192, 0.05380676040658727, 0.028707103338092566, 0.1065146821201779, 0.11775341772590764, 0.034661409808904864, 0.06534052197821438, 0.11859342499519698, 0.09223441011272371, 0.04334496807132382, 0.08807398218777962, 0.16318151640007272, 0.07529725684435107, 0.12099421335733496, 0.030375519963854458, 0.1629482742282562, 0.09811829047976062, 0.06348767608869821, 0.16723502310924232, 0.08893101432477124, 0.05493538519658614, 0.06440845871111378, 0.11516473241499625, 0.020481991959968582, 0.07151070807594806, 0.08758193827816285, 0.09010239053168334, 0.13803813199047, 0.12448705718270503, 0.13476673018885776, 0.1599559941678308, 0.018162594933528453, 0.0504235577682266, 0.052107090086792596, 0.06783979333704337, 0.10399342092568986, 0.17983296507736668, 0.10328104821383022, 0.07578767545055598, 0.07328965089982376, 0.0336918903485639, 0.07802683889167383, 0.11189691518666223, 0.06526272263727151, 0.020838410237047356, 0.06760646210750565, 0.06504805642180145, 0.06808879872551188, 0.07887279818532988, 0.10375835307058878, 0.10905308692599647, 0.08172122034011409, 0.07950094455736689, 0.04716205992735922, 0.0551885391905671, 0.05378286696213763, 0.05239757781964727, 0.10510196691029705, 0.0719865360588301, 0.04573465390421916, 0.01984474129130831, 0.10541142022702843, 0.06692580136586912, 0.031452927287318744, 0.08963949076132849, 0.0407228712720098, 0.010994637668773066, 0.04287774158001412, 0.05054516608652193, 0.06146524574432988, 0.05881567834876478, 0.062477279134327546, 0.1240135298576206, 0.044790163374273106, 0.02527608783566393, 0.0788409897359088, 0.03839903249172494, 0.025088445072469767, 0.03242966042307671, 0.15393662732094526, 0.015548554147244431, 0.1266718137776479, 0.11240699328482151, 1.1138468189164996, 5.794838201254606, 34.78029750287533, 60.52808828651905, 76.77211403846741, 75.44110625982285, 57.44246006011963, 41.83288626372814, 41.829029470682144, 51.81125342845917, 68.16683739423752, 86.95644155144691, 86.96921646595001, 66.58270239830017, 43.59241224825382, 20.108716674149036, 6.033298205584288, 1.8651577038690448, 0.38022042252123356, 0.1029828903847374, 0.11161123286001384, 0.016842004370118957, 0.6763257086277008, 0.14608222612878308, 0.02407994801615132, 0.21324773377273232, 0.1371630805078894, 0.06711433656164445, 0.18321742565603927, 2.6780162611976266, 0.5473977362271398, 0.4103308677440509, 0.06856067848275416, 0.17910407215822488, 0.18841703102225438, 0.1962837963947095, 1.2725248793140054, 0.18114290025550872, 0.4401212395168841, 0.3106351423775777, 0.19223079434596002, 0.18827811582013965, 0.36298018356319517, 0.06953608317417093, 0.06799050868721679, 0.014551709737133933, 0.1856173382839188, 0.08100835781078786, 0.28049878135789186, 0.26255145377945155, 0.584752403665334, 0.7007118500769138, 0.23709084576694295, 0.13241441891295835, 1.040285259950906, 2.089868620969355, 0.27901769208256155, 0.08366412585019134, 0.03839690252789296, 0.045121109287720174, 0.6628979416564107, 4.614909365773201, 21.75289984792471, 54.871932193636894, 79.8679219186306, 61.6375907510519, 73.88382822275162, 77.51536175608635, 63.27788673341274, 35.739696621894836, 41.81978836655617, 58.89527030289173, 70.95793962478638, 79.83163386583328, 56.01909823715687, 21.31416779011488, 2.1417237259447575, 0.1534753231680952, 0.19161923497449607, 0.07351154563366435, 0.1791887215222232, 0.06367726513417438, 0.134418009838555, 0.15656077244784683, 0.13547787093557417, 0.13356160110561177, 0.026874920695263427, 0.1402338352636434, 0.06663102030870505, 0.1024562846578192, 0.10425047861644998, 0.07432712140143849, 0.11288602734566666, 0.016750245231378358, 0.04862293309997767, 0.03495661760098301, 0.0350869981048163, 0.07164891823776998, 0.033901109200087376, 0.05343922290194314, 0.04868698786594905, 0.11931084431125782, 0.08733905560802668, 0.057556888277758844, 0.029503390687750652, 0.0687151045713108, 0.06885099181090482, 0.0208850764829549, 0.13201092806411907, 0.016238144780800212, 0.10084928260766901, 0.07461203931597993, 0.09058155817911029, 0.058232157316524535, 0.05615899746771902, 0.06462750359787606, 0.09119128444581293, 0.05116046959301457, 0.1225519813306164, 0.06557101078215055, 0.06994819777901284, 0.0668646112899296, 0.09972694009775296, 0.07842907551093958, 0.17689164087641984, 0.14141246967483312, 0.1298124936874956, 0.17604542925255373, 0.27146853622980416, 0.3087719064205885, 0.34872023155912757, 0.19705641665495932, 0.1680579609819688, 0.11285617074463516, 0.22613293142057955, 0.254140961333178, 0.13840135390637442, 0.1509244873886928, 0.16230842418735847, 0.11115821107523516, 0.3671751287765801, 0.31779983604792506, 0.2048552458290942, 0.19415276387007907, 0.11298782774247229, 0.2365562174236402, 0.19319215760333464, 0.11899324963451363, 0.14866504847304896, 0.27459395758342, 0.2200867878855206, 0.12504652520874515, 0.18556230061221868, 0.136594818031881, 0.28837819292675704, 0.205013798258733, 0.19038354424992576, 0.12755112518789247, 0.0866206492355559, 0.18392368307104334, 0.19286389084300026, 0.1757859150529839, 0.10574664091109298, 0.23443156736902893, 0.1771336849196814, 0.3446190047543496, 0.24043186102062464, 0.11413535132305697, 0.14229479420464486, 0.23655906727071851, 0.14938168111257255, 0.12321209200308658, 0.39483194472268224, 0.2661849494324997, 0.2646889875177294, 0.2879014075733721, 1.0082291113212705, 3.317602453753352, 30.434031821787357, 64.4836950302124, 88.8561724126339, 92.97839641571045, 81.21754869818687, 72.70288199186325, 50.08171163499355, 57.69602045416832, 68.16021054983139, 80.44565051794052, 97.48459741473198, 94.6340511739254, 73.06697845458984, 50.590109154582024, 24.01291597634554, 7.862796960398555, 1.5382593451067805, 0.4508675081888214, 0.30665212485473603, 0.42892223107628524, 0.9353839920368046, 0.9933106368407607, 0.46683487482368946, 0.8069985592737794, 0.3311188635416329, 0.966213340871036, 1.6545487800613046, 4.7616346925497055, 2.412990932352841, 1.1432003625668585, 0.21454720466863364, 0.3250671538989991, 0.7657981419470161, 1.3493283768184483, 1.6063349484466016, 0.2595104888314381, 0.5107848008628935, 0.41990086203441024, 0.2321404981194064, 1.5185234416276217, 0.5344178108498454, 0.3344271203968674, 0.5379499588161707, 0.4561290383571759, 0.48272508778609335, 0.2778101881267503, 0.807280516019091, 1.21043692342937, 2.2307398868724704, 1.3168898737058043, 0.5459640850313008, 0.40044198743999004, 2.2087609162554145, 3.7276686122640967, 0.9717330196872354, 0.20571977365761995, 0.12081456909072585, 0.157886084925849, 0.6137830240186304, 4.322025356814265, 26.2281534075737, 58.65452662110329, 93.84511470794678, 84.18401151895523, 82.50851422548294, 69.9745523929596, 70.68584382534027, 52.372145131230354, 66.75708264112473, 76.67444407939911, 86.70652896165848, 97.56449192762375, 56.698429584503174, 20.205385386943817, 1.2926639174111187, 0.4244358593132347, 0.31934311729855835, 0.16303987009450793, 0.32931078399997205, 0.39366196375340223, 0.2129287735442631, 0.39056159730535, 0.1924202052759938, 0.21426115126814693, 0.14219708304153755, 0.19755138462642208, 0.18313598237000406, 0.1794815284665674, 0.2088648173958063, 0.2376897886279039, 0.16166854446055368, 0.0840496715682093, 0.19494683219818398, 0.17375559196807444, 0.11858284939080477, 0.27876945852767676, 0.1039140037028119, 0.17927533015608788, 0.11912014946574345, 0.17393574089510366, 0.15287192742107436, 0.15783339244080707, 0.2514397515915334, 0.15886206849245355, 0.14627420488977805, 0.10384691355284303, 0.15208295022603124, 0.21503202005987987, 0.16332037223037332, 0.2068455671542324, 0.12410804236424156, 0.16718004480935633, 0.13499611319275573, 0.2173193488852121, 0.34237751096952707, 0.10217650240520015, 0.19915996002964675, 0.10453835770022124, 0.17910003487486392, 0.19627336179837584, 0.16032922023441643, 0.310769560164772], [0.09724378076498397, 0.23444305581506342, 0.03620993062213529, 0.16155487712239847, 0.16549499850952998, 0.14335998392198235, 0.006932999804121209, 0.2249321958515793, 0.12079817504854873, 0.10545188953983597, 0.10361465101595968, 0.15505068004131317, 0.17563071713084355, 0.030041189857001882, 0.15979414660250768, 0.09668504746514373, 0.08600183165981434, 0.0922879041172564, 0.08720845988136716, 0.05650603685353417, 0.07476455066353083, 0.18585028359666467, 0.23482895776396617, 0.07918459668871947, 0.08283470902824774, 0.07972121398779564, 0.07983104442246258, 0.15486115036765113, 0.15369005617685616, 0.0646298190986272, 0.10293782717781141, 0.028154077153885737, 0.018215899690403603, 0.17573739343788475, 0.17160471441457048, 0.13526972819818184, 0.07595211311127059, 0.08504059456754476, 0.058292623798479326, 0.1578487252118066, 0.15691577136749402, 0.062452684360323474, 0.22773950302507728, 0.25888007890898734, 0.046208140411181375, 0.32205997151322663, 0.2072573552140966, 0.10860811002203263, 0.19561855006031692, 0.2388956895447336, 0.037397277847048827, 0.010646607515809592, 0.1878473287797533, 0.20215877098962665, 0.13216483464930207, 1.3464473001658916, 19.259342551231384, 53.225092962384224, 53.12930770218372, 53.08175325393677, 49.22731228172779, 55.01535549759865, 51.82888448238373, 31.383678764104843, 39.897349923849106, 75.45532509684563, 86.23017132282257, 82.52933710813522, 68.74632149934769, 44.66075912117958, 26.272759214043617, 16.74034181982279, 13.49336190149188, 12.097654044628143, 6.479473114013672, 5.400176178663969, 2.828463250771165, 1.649471540004015, 1.2855463055893779, 1.159135045018047, 2.123490641824901, 0.5481275939382613, 0.45377770671620965, 0.5140430072788149, 0.6361941620707512, 0.9663277503568679, 0.8574508270248771, 1.2759703444316983, 0.21483771095518023, 0.5095832340884954, 0.8846358745358884, 0.851369253359735, 0.7175534369889647, 0.3695266385329887, 0.8351979742292315, 0.9243340068496764, 0.8359991968609393, 1.2463878630660474, 1.9043583003804088, 1.468523705843836, 0.5955223320052028, 0.24278810567921028, 0.11817217455245554, 0.5009759240783751, 0.4505984944989905, 0.4424765787553042, 0.01720302210742375, 0.3026641794713214, 0.3011097660055384, 1.8479109043255448, 6.526879370212555, 15.548985097557306, 36.34565390646458, 57.719700783491135, 71.94459468126297, 55.98575122654438, 72.29023173451424, 74.83748584985733, 33.21555286645889, 42.783834636211395, 45.20792596042156, 57.89362885057926, 59.65078756213188, 67.44390338659286, 53.50574590265751, 17.97269929200411, 1.1789933731779456, 0.07350302577833645, 0.07646689642569982, 0.16416374885011464, 0.18758162506856024, 0.2962603949708864, 0.07653115157154389, 0.15661270794225857, 0.12870537262642756, 0.2632923249620944, 0.24173539888579398, 0.21754554065410048, 0.14305977034382522, 0.17847142094979063, 0.18503864121157676, 0.13183015573304147, 0.17427497659809887, 0.1197082272847183, 0.09216532358550467, 0.11595472635235637, 0.0224764062295435, 0.08846637792885303, 0.10521478077862412, 0.2079999481793493, 0.13156900880858302, 0.14366806426551193, 0.08515520443324931, 0.047961360396584496, 0.1197380616213195, 0.06458019168348983, 0.11418382098781876, 0.21044384047854692, 0.13716704357648268, 0.21686470921849832, 0.1603527314728126, 0.1453576673520729, 0.05717040374292992, 0.14968570932978764, 0.03522439561493229, 0.13964183890493587, 0.1173470621870365, 0.16834787355037406, 0.07743511712760665, 0.12693855649558827, 0.08702815510332584, 0.12358047926682048, 0.11563630047021434, 0.3000584396068007, 0.20823005848797038, 0.15429725171998143, 0.12992880307137966, 0.14923340000677854, 0.17330034374026582, 0.11164360534166917, 0.15109774918528274, 0.23719652759609744, 0.0825241202255711, 0.16164694796316326, 0.11387479069526307, 0.04147116022068076, 0.03404063296329696, 0.10100932675413787, 0.13878358964575455, 0.06797745430958457, 0.1382753372308798, 0.14011749619385228, 0.12875377549789846, 0.17031438677804545, 0.08100645791273564, 0.09688147169072181, 0.05173141493287403, 0.11703299271175638, 0.12805718084564433, 0.07141451831557788, 0.14872584521071985, 0.16964529611868784, 0.12372609606245533, 0.11355637965607457, 0.0841169324121438, 0.03938373629353009, 0.10767638814286329, 0.0737390287395101, 0.0292001064735814, 0.09499934065388516, 0.1726150742615573, 0.12997628567973152, 0.05772119606263004, 0.038313039840431884, 0.058345961951999925, 0.09507299138931558, 0.21676689415471628, 0.023135066003305838, 0.17656172654824331, 0.12194496390293352, 0.05092092658742331, 0.19038854632526636, 0.12270872291992418, 0.12446209133486263, 0.0807499123038724, 0.14020671718753874, 0.0760224464465864, 0.015167584697337588, 0.19846618553856388, 0.08309858705615625, 0.8579461660701782, 10.001402478665113, 39.457382932305336, 69.55508530139923, 64.86650168895721, 67.94175267219543, 51.53117425739765, 59.407410621643066, 53.65798853337765, 43.97365719079971, 70.31402617692947, 95.89605465531349, 97.90998458862305, 94.42895337939262, 68.76850470900536, 32.53293849527836, 13.191091921180487, 6.413281140848994, 3.7559286458417773, 1.7130541219376028, 3.2299627689644694, 2.9335637111216784, 1.0827477439306676, 0.41727760748472065, 0.6657142436597496, 0.6057483551558107, 3.8328944658860564, 1.0136205470189452, 0.36752948944922537, 0.20954339270247146, 0.15297575388103724, 0.5821254977490753, 0.34333191288169473, 0.22093308856710792, 0.11751550002372824, 0.23892665194580331, 0.2663142018718645, 0.41415156272705644, 0.3309180383803323, 0.463086316594854, 0.20713417354272678, 0.12588345998665318, 0.8345368097070605, 3.0412392457947135, 1.899774440098554, 1.4880386274307966, 0.4711191152455285, 0.277057412895374, 0.8022600947879255, 0.44455132680013776, 0.16354058228898793, 0.2011096413480118, 0.2687824663007632, 0.17981444107135758, 0.10707113702665083, 1.9089798023924232, 6.177469119429588, 16.253912821412086, 38.5292599350214, 70.00949531793594, 88.73214706778526, 74.28475230932236, 98.9831230044365, 95.82204982638359, 50.49028091132641, 38.99294525384903, 41.10685542225838, 55.97047604620457, 64.89132195711136, 76.3539008796215, 71.9772045314312, 29.676284082233906, 4.226848538964987, 0.1453053459408693, 0.2982614329084754, 0.051826721537509, 0.1312421669717878, 0.188999141973909, 0.04878114414168522, 0.1261372893350199, 0.10948903931421228, 0.25015871564392, 0.16646611358737573, 0.08411817922024056, 0.17482808441855013, 0.20763372798683122, 0.1850850402843207, 0.09210939533659257, 0.17613525880733505, 0.0802850977925118, 0.09766134273377247, 0.07000229292316362, 0.07620399061124772, 0.07447230775142089, 0.11072794353822246, 0.2122006969875656, 0.0860540046414826, 0.2108415128896013, 0.03365818571182899, 0.0823394961480517, 0.0573148850526195, 0.00674954368150793, 0.1200159068685025, 0.17943092883797362, 0.08382687883567996, 0.15840281266719103, 0.07857668868382461, 0.13421552226645872, 0.20461262291064486, 0.22239586163777858, 0.11914914517547004, 0.17475128697697073, 0.06313563091680408, 0.09422592629562132, 0.12425715467543341, 0.09735185230965726, 0.15637403324944898, 0.09782700493815355, 0.08549841804779135, 0.25860254536382854, 0.11654652233119123, 0.2114765834994614, 0.19427138875471428, 0.21486269164597616, 0.11039324235753156, 0.21358088386477903, 0.2648556441999972, 0.3348969592479989, 0.13914964656578377, 0.2222646350855939, 0.11820519270258956, 0.154752470261883, 0.11349046209943481, 0.19204441137844697, 0.3105636587133631, 0.20763170934515074, 0.14001990377437323, 0.19697832787642255, 0.17235698498552665, 0.17643703089561313, 0.16583904332946986, 0.15756282024085522, 0.19006698857992887, 0.2598530048271641, 0.2516269212355837, 0.153400870913174, 0.23325683665461838, 0.24095237371511757, 0.15388231695396826, 0.22006268292898312, 0.18909115344285965, 0.17694748006761074, 0.18362676462857053, 0.19875333731761202, 0.17489222082076594, 0.22936764144105837, 0.23412709386320785, 0.16475889191497117, 0.2249295389628969, 0.14751914277439937, 0.07901579519966617, 0.26301954116206616, 0.24213292286731303, 0.23249088088050485, 0.2398910728516057, 0.2943385887192562, 0.19906388159142807, 0.38856219209264964, 0.4440532863372937, 0.18286355480086058, 0.19092038419330493, 0.3493610315490514, 0.27419910533353686, 0.10744777697254904, 0.2505650563398376, 0.2384783947491087, 0.29460469319019467, 5.745846005156636, 32.11436055600643, 78.6692002415657, 81.58315747976303, 87.83490881323814, 77.63105794787407, 79.24135074019432, 76.5528430044651, 47.50243283808231, 63.35220314562321, 99.18771922588348, 107.9781599342823, 109.81248870491982, 98.59717011451721, 66.8834562599659, 41.04960009455681, 24.945380240678787, 18.150005377829075, 14.977294374257326, 8.351501561701298, 6.594336675480008, 5.303529789671302, 2.2228222992271185, 1.2984912609681487, 1.6675298335030675, 6.181062301620841, 0.9704252367373556, 0.4272166866576299, 0.41773500794079155, 0.5813777691219002, 1.0132389049977064, 0.9427540528122336, 1.9815728883258998, 0.6040396343450993, 0.625271707540378, 1.190449045971036, 1.1295252526178956, 1.030460768379271, 0.7745155866723508, 1.3823047885671258, 1.9357239548116922, 2.540367222391069, 3.9059293968603015, 2.01313981320709, 1.7675468791276217, 0.9764292114414275, 0.5456291092559695, 1.296450651716441, 0.9755753260105848, 0.3274016239447519, 0.4797857376979664, 0.22427435615099967, 0.3984255128307268, 1.208234941586852, 2.8262489195913076, 7.6022349670529366, 17.662062160670757, 45.98842687904835, 74.87169921398163, 96.03746026754379, 77.19056278467178, 98.23036819696426, 94.9111171066761, 51.01839177310467, 61.2080541998148, 66.69984251260757, 77.91598185896873, 83.31404820084572, 94.04213413596153, 78.92906829714775, 28.426476046442986, 2.585194604471326, 0.1891740513383411, 0.42568058939650655, 0.29160825710278004, 0.4545211012009531, 0.2534379396820441, 0.10592007340164855, 0.20216540578985587, 0.2007986666285433, 0.35980640386696905, 0.267154966131784, 0.23598981031682342, 0.1917195288115181, 0.2349553455132991, 0.31024174473714083, 0.20720254018669948, 0.3452029265463352, 0.18582191871246323, 0.14225120045011863, 0.19533801823854446, 0.30667064886074513, 0.180396462965291, 0.22077683679526672, 0.17946051084436476, 0.16678651358233765, 0.20481203799135983, 0.18982639914611354, 0.1465812759124674, 0.16065760573837906, 0.12998652731766924, 0.1529996213503182, 0.2634819585364312, 0.15589328482747078, 0.1742379434290342, 0.16631667473120615, 0.30247956281527877, 0.23394997289869934, 0.21523645205888897, 0.207860320515465, 0.22158415988087654, 0.163927745888941, 0.17068516375729814, 0.2849740505916998, 0.16629427671432495, 0.2903099439572543, 0.1812667795456946, 0.1712273174780421, 0.4250309430062771, 0.21625197725370526, 0.3409760689828545], [0.15312087343772873, 0.09512647055089474, 0.24621041578939185, 0.05488624388817698, 0.19126819912344217, 0.15383891615783796, 0.1486958030727692, 0.07114787949831225, 0.0116839509246347, 0.15521283930866048, 0.07950794300995767, 0.14251184271415696, 0.11930328924790956, 0.027274238818790764, 0.07908033236162737, 0.12075970953446813, 0.137723105144687, 0.13880382059141994, 0.09669807215686888, 0.14411393174668774, 0.07759586631436832, 0.04402583290357143, 0.06487218968686648, 0.019341902843734715, 0.10058482570457272, 0.016817652649478987, 0.14697192760650069, 0.062085287863737904, 0.08055023747147061, 0.12362246256088838, 0.1474197395145893, 0.08521209747414105, 0.14669149968540296, 0.02538502583774971, 0.04489223465498071, 0.21353325282689184, 0.0874982685490977, 0.10344203488784842, 0.10600246663670987, 0.09446683485293761, 0.08588400829466991, 0.08783627970842645, 0.09891053312458098, 0.1875469964579679, 0.30479138251394033, 0.12934295169543475, 0.33994092140346766, 0.4122349515091628, 0.07997178530786186, 0.16678593470714986, 0.22028510458767414, 0.135762395511847, 0.1118630806740839, 0.19647941167932004, 0.09024639686685987, 0.09784302048501559, 0.14793142065173015, 3.4108601370826364, 9.394117165356874, 42.5471643358469, 67.91168868541718, 64.40392971038818, 71.10334262251854, 63.956176936626434, 34.73083935678005, 40.850293189287186, 42.92479947209358, 49.54296134412289, 56.60953335464001, 57.284468337893486, 55.902121514081955, 37.3734113574028, 36.25999890267849, 30.336838737130165, 22.12160736322403, 16.21156219393015, 11.205613911151886, 9.5264963619411, 5.773782581090927, 3.0201605893671513, 2.585090585052967, 1.4069978822954, 5.422749342396855, 5.2409537974745035, 3.6883445223793387, 2.2330466005951166, 2.375685009174049, 2.3472254863008857, 2.611250043846667, 2.0684774313122034, 0.7535499148070812, 0.578710074769333, 0.15919738565571606, 0.7367530348710716, 1.6076221293769777, 1.0608642431907356, 1.0987763525918126, 0.9532920154742897, 1.7763662058860064, 2.7185137756168842, 3.329006116837263, 5.853860909119248, 7.526931557804346, 6.738617308437824, 4.384261267259717, 2.6717228488996625, 6.3478633761405945, 12.074924614280462, 22.61860739439726, 44.34572942554951, 60.710410103201866, 66.1811475455761, 77.94387236237526, 57.17486321926117, 73.55712175369263, 39.437711387872696, 36.887793615460396, 48.532074987888336, 44.18918542563915, 62.265974432229996, 63.20403389632702, 70.28555810451508, 59.09622251987457, 22.657053731381893, 3.9896671660244465, 0.0421030395955313, 0.08979846621514298, 0.12260697447345592, 0.29620042943861336, 0.17775155254639685, 0.06631329204537906, 0.08094943128526211, 0.08671836039866321, 0.05618164410407189, 0.27651327021885663, 0.0721191504271701, 0.16711421631043777, 0.12589577963808551, 0.311120210099034, 0.2762553293723613, 0.15827023540623486, 0.1899580264580436, 0.15737974725198, 0.1767284277593717, 0.15328818320995197, 0.048589276702841744, 0.13321853592060506, 0.22437702486058697, 0.10880582558456808, 0.2768793865107, 0.2756476291688159, 0.16030291852075607, 0.15492718666791916, 0.3275049012154341, 0.22398330067517236, 0.1579281350132078, 0.084421687934082, 0.17543861962622032, 0.05921604475588538, 0.0445175873755943, 0.1603355136467144, 0.1592645945493132, 0.1319040439557284, 0.19895245553925633, 0.09952105348929763, 0.19805444200756028, 0.1290770253399387, 0.12612369318958372, 0.22083879128331318, 0.11883504601428285, 0.0453395678778179, 0.20840844110352919, 0.025054833204194438, 0.06711236244882457, 0.0261875973228598, 0.10212641485850327, 0.11730338679626584, 0.006988711438680184, 0.07888367807026953, 0.018073615137836896, 0.3158150956733152, 0.14249990897951648, 0.09798216575291008, 0.072665564075578, 0.050647029565880075, 0.11868378889630549, 0.042542313094600104, 0.08655267592985183, 0.13364592392463237, 0.10232761109364219, 0.02297095303219976, 0.08881508343620226, 0.06454868009313941, 0.12515459675341845, 0.09453967664740048, 0.10330971737857908, 0.06847880475106649, 0.060316783346934244, 0.0395947845390765, 0.03133698526653461, 0.09086755220778286, 0.018949705627164803, 0.16033129824791104, 0.07380955503322184, 0.11502493405714631, 0.1891503026126884, 0.15924424486001953, 0.16463214793475345, 0.15910869900835678, 0.1227811342687346, 0.03958506240451243, 0.2233602528576739, 0.08813414809992537, 0.16046032804297283, 0.1445073145441711, 0.15386677638161927, 0.14076700899749994, 0.1256495201960206, 0.13228736323071644, 0.14113085431745276, 0.3689942217897624, 0.12036738800816238, 0.2686731331050396, 0.20462515036342666, 0.16464439337141812, 0.15569401817629114, 0.15344361861934885, 0.10876293687033467, 0.08024119233596139, 0.11172466271091253, 0.16241944947978482, 0.09370162864797749, 0.37117376108653843, 13.21993712335825, 29.435766488313675, 60.20230896770954, 74.00704801082611, 71.84167340397835, 72.03282594680786, 48.75994496047497, 33.752593249082565, 59.86077569425106, 68.94122824072838, 86.24654084444046, 96.67583361268044, 95.42320802807808, 72.73918524384499, 46.849776059389114, 34.56421069800854, 26.8380643799901, 15.811242274940014, 14.206137154251337, 8.170420378446579, 3.5526286298409104, 1.7616855748929083, 2.2137220250442624, 2.856837040744722, 3.1744847958907485, 2.595354071818292, 2.2328995959833264, 2.642810200341046, 2.004081574268639, 1.3986790599301457, 1.1252414574846625, 1.6916125849820673, 1.664333373773843, 1.1653785849921405, 1.3376326044090092, 0.8673882437869906, 0.8318447729106992, 1.151960080023855, 1.2123729195445776, 1.4495384995825589, 1.2817288166843355, 1.9660732825286686, 2.598662031814456, 2.1943449648097157, 3.4199974592775106, 5.283861570060253, 5.06999384611845, 3.4826012374833226, 3.1194958090782166, 7.69700045697391, 16.215308792889118, 32.89082229137421, 48.57308238744736, 76.52415454387665, 86.45771831274033, 101.15754872560501, 75.3730671107769, 84.60163190960884, 53.59544388949871, 47.54000522196293, 54.17572595179081, 38.87766323983669, 60.39851523935795, 70.9795680642128, 81.0906583070755, 77.9266668856144, 41.05339229106903, 9.960894752293825, 0.23947827547090128, 0.13027357519604266, 0.18144165922421962, 0.19391180336242542, 0.21586684713838622, 0.10631950470269658, 0.125639337929897, 0.07727449410595, 0.061957553116371855, 0.17971333087189123, 0.08930383963161148, 0.24515770899597555, 0.26003058592323214, 0.23126948392018676, 0.15072980721015483, 0.06144659186247736, 0.15928852139040828, 0.19773846521275118, 0.11854566779220477, 0.19558737985789776, 0.10749583103461191, 0.12006583856418729, 0.17508044431451708, 0.08248742102296092, 0.151833840936888, 0.21679125144146383, 0.14126222929917276, 0.15518952102866024, 0.18366551958024502, 0.25358251004945487, 0.16371805948438123, 0.16454567288747057, 0.08054145044297911, 0.1477313376381062, 0.08899947002646513, 0.1237990269146394, 0.14314946631202474, 0.06615579346544109, 0.15465591684915125, 0.07429484539898112, 0.12010469741653651, 0.0900307584379334, 0.08364955749129876, 0.1928950016736053, 0.054172806194401346, 0.10073277284391224, 0.1346181967528537, 0.018117505751433782, 0.06251388185773976, 0.09532142532407306, 0.10059152729809284, 0.3280118474503979, 0.2195470832521096, 0.25330082047730684, 0.14614085579523817, 0.2840589825063944, 0.15520271641435102, 0.21489294158527628, 0.1156834268476814, 0.16598184738541022, 0.13355403119930997, 0.2167578399530612, 0.22924796270672232, 0.2572088217129931, 0.16518163407454267, 0.25234054075554013, 0.24357151676667854, 0.3067781118443236, 0.20709255390102044, 0.1443264531553723, 0.15514095488470048, 0.1987297518644482, 0.10381569882156327, 0.17370016837958246, 0.13720002461923286, 0.21359544480219483, 0.12865343713201582, 0.2055106364423409, 0.21440036332933232, 0.18661738227820024, 0.19464062206679955, 0.15086777246324345, 0.17991359200095758, 0.2222909961710684, 0.22414667706470937, 0.14884506381349638, 0.3001459239749238, 0.20195334451273084, 0.15365490806289017, 0.24076983507256955, 0.21509425656404346, 0.19356741715455428, 0.23000902030617, 0.3021597268525511, 0.1378969755023718, 0.4132791532902047, 0.19403692946070805, 0.5035850778222084, 0.3946900164010003, 0.41277962853200734, 0.20072666346095502, 0.31664906186051667, 0.29970784904435277, 0.19761087518418208, 0.2642246405594051, 0.1548384258057922, 0.22487515438115224, 0.09808942093513906, 6.037154048681259, 23.076108545064926, 69.2458426952362, 98.73433515429497, 94.81451869010925, 97.66713961958885, 86.81268006563187, 51.47334136068821, 60.18756575882435, 57.62916684150696, 73.95203456282616, 80.010786652565, 94.8768961429596, 98.05119261145592, 75.57476788759232, 67.21572563052177, 55.539202988147736, 44.037664756178856, 33.38688567280769, 27.81404960900545, 27.360251359641552, 22.066603414714336, 13.5765147395432, 13.814957644790411, 15.744273718446493, 12.33379427343607, 9.328791070729494, 6.437289677560329, 6.642531864345074, 6.126667270436883, 6.863662423565984, 4.774604346603155, 3.446553759276867, 2.685710610821843, 1.6569677065126598, 1.1907531484030187, 1.8293972290121019, 2.439007186330855, 1.9751445832662284, 2.801930462010205, 2.8136340714991093, 5.814587166532874, 8.050300274044275, 10.857292301952839, 14.697543885558844, 17.691016606986523, 18.50711401551962, 16.531729213893414, 13.555157985538244, 21.75588458776474, 34.330226853489876, 44.34606000781059, 68.00242021679878, 89.67945903539658, 94.2184066772461, 105.08976012468338, 76.22774004936218, 88.71968373656273, 52.570395693182945, 49.36375916004181, 68.44983860850334, 61.696631982922554, 79.56794321537018, 89.30485233664513, 98.65886360406876, 90.12664183974266, 41.39403261244297, 7.357029849663377, 0.1483437727438286, 0.34182573901489377, 0.4215091554215178, 0.46001893118955195, 0.28591663751285523, 0.22237607598071918, 0.14201270387275144, 0.11918659394723363, 0.10655814228812233, 0.37305397738236934, 0.2896378847071901, 0.2740063547389582, 0.2181182411732152, 0.3380516805918887, 0.2908639720408246, 0.24177906685508788, 0.23059317958541214, 0.25233703781850636, 0.18724017776548862, 0.22461467538960278, 0.11203748537809588, 0.178502680209931, 0.27698551362846047, 0.18519971694331616, 0.2965699596097693, 0.22139655979117379, 0.21544024581089616, 0.1777902926551178, 0.31987461377866566, 0.3792981110746041, 0.20256465155398473, 0.20204667700454593, 0.20328454964328557, 0.3308649599784985, 0.1851413692929782, 0.24680109112523496, 0.2290180156705901, 0.21042344626039267, 0.24166345509001985, 0.1541808681213297, 0.26306136860512197, 0.22979554894845933, 0.17376853502355516, 0.2840519469464198, 0.1527177239768207, 0.11632717316388153, 0.23918206949019805, 0.20632278348784894, 0.21919621067354456, 0.2804734295932576, 0.18476615427061915], [0.025573668644938152, 0.05836044867464807, 0.05229645277722739, 0.020025493213324808, 0.11922327088541351, 0.03703158086864278, 0.0924517480598297, 0.10792977962410077, 0.03705822025949601, 0.01950593046785798, 0.02281041906826431, 0.01950190431671217, 0.05932289546763059, 0.12200367520563304, 0.13355965667869896, 0.036813274418818764, 0.10737414850154892, 0.09176699066301808, 0.09679078866611235, 0.15572083939332515, 0.12676094571361318, 0.038636942772427574, 0.1025058378581889, 0.04049614515679423, 0.0834460902842693, 0.07864799423259683, 0.08563728872104548, 0.04766982623550575, 0.0542767254228238, 0.08373223274247721, 0.0916646707628388, 0.0632539440994151, 0.061956358258612454, 0.09169726588879712, 0.10116908888448961, 0.12379049963783473, 0.03206492452591192, 0.08179366137483157, 0.08519227470969781, 0.058316780705354176, 0.08204725323594175, 0.02606557340186555, 0.1390579022699967, 0.16658205189742148, 0.051513494399841875, 0.17160741583211347, 0.13093183049932122, 0.03597472175897565, 0.25692802271805704, 0.17728009581333026, 0.14250845852075145, 0.15311790484702215, 0.30243461835198104, 0.2312533199437894, 0.12965520290890709, 0.13114564324496314, 0.03758719343750272, 0.3261275344993919, 0.16537919378606603, 2.7531422674655914, 28.321301490068436, 55.920216143131256, 75.00298216938972, 80.52106127142906, 82.63396829366684, 75.55602729320526, 63.42176981270313, 46.35507680475712, 48.28916162252426, 37.64248251914978, 40.108637586236, 33.467638939619064, 27.735006250441074, 25.494654066860676, 20.69285362958908, 18.498592972755432, 15.085217133164406, 13.488820195198059, 14.15030675008893, 12.717325743287802, 13.528588861227036, 10.390730537474155, 10.550422668457031, 9.153593871742487, 7.301206095144153, 5.021051047369838, 12.006183452904224, 14.074555914849043, 27.152981981635094, 37.22289763391018, 37.94442571699619, 34.54675443470478, 45.46496316790581, 50.924696400761604, 47.638366743922234, 48.13502289354801, 37.426768094301224, 34.10126633942127, 33.298141434788704, 34.7967392206192, 37.8443618863821, 30.35484217107296, 22.12079230695963, 15.508651211857796, 13.280908651649952, 15.493338983505964, 20.927700027823448, 35.64826212823391, 45.29132388532162, 57.07735285162926, 51.33993811905384, 50.470563769340515, 39.61890086531639, 44.91860568523407, 57.24236659705639, 54.81235519051552, 66.47465139627457, 57.7933332324028, 61.9914885610342, 71.00303560495377, 72.38535583019257, 38.14978189766407, 4.445262718945742, 0.29829435457941145, 0.22049545892514288, 0.07235372846480459, 0.16945484618190676, 0.0589785426564049, 0.04869649106694851, 0.04512549166975077, 0.1323574219713919, 0.10707458801334724, 0.011647762876236811, 0.23256518470589072, 0.14039847330423072, 0.17782538139726967, 0.166708484175615, 0.1304069985053502, 0.32671249529812485, 0.17893037991598248, 0.23996368458028883, 0.11180185349076055, 0.12997581070521846, 0.15425849676830694, 0.10078807026729919, 0.09822487030760385, 0.10577518391073681, 0.2555669832509011, 0.11531123236636631, 0.2576177450828254, 0.3233785304473713, 0.13199848966905847, 0.2412250536144711, 0.21930319868260995, 0.25031323079019785, 0.19009204348549247, 0.19674729730468243, 0.14022034301888198, 0.15862830681726336, 0.2016059006564319, 0.20424791669938713, 0.30769214092288166, 0.23179156996775419, 0.2707359177293256, 0.1776800540392287, 0.14940588996978477, 0.13862656604032964, 0.12358249048702419, 0.1163650672242511, 0.14976213569752872, 0.12902179470984265, 0.1406544548808597, 0.18051162944175303, 0.03792703770159278, 0.0642108841566369, 0.22655027074506506, 0.09316674797446467, 0.11946345955948345, 0.058653455998864956, 0.040849043798516504, 0.042454283247934654, 0.025235822613467462, 0.054442784676211886, 0.11224229587242007, 0.043645868136081845, 0.06691493632388301, 0.0518610050494317, 0.04219872840621974, 0.03985780909715686, 0.1311048399657011, 0.1294218419934623, 0.03967978271248285, 0.0842766574351117, 0.07287839718628675, 0.08684916392667219, 0.1309626444708556, 0.10992497685947455, 0.1181711207027547, 0.0727858736354392, 0.02373729286773596, 0.027493966481415555, 0.06369234557496384, 0.09617995659937151, 0.04781490868481342, 0.05663027608534321, 0.0633578299311921, 0.1619054379989393, 0.13759260589722544, 0.10899935543420725, 0.10885713025345467, 0.1169255816785153, 0.07001050107646734, 0.012589695779752219, 0.05017435942136217, 0.06468332794611342, 0.035824076912831515, 0.09617187461117283, 0.03840944482362829, 0.0732310583407525, 0.1356824958929792, 0.08941266816691495, 0.20425000955583528, 0.13163387251552194, 0.11696127156028524, 0.2415103797102347, 0.24570519133703783, 0.10936234728433192, 0.16270807071123272, 0.49678795505315065, 0.21675114578101784, 0.11462410009698942, 0.144404734892305, 0.11027004584320821, 0.04938643236528151, 0.7115534995682538, 11.830746866762638, 52.07083269953728, 77.40191504359245, 87.95692786574364, 81.81498304009438, 64.39218834042549, 54.24838185310364, 45.865663066506386, 45.528066381812096, 53.39387230575085, 60.755171701312065, 80.76744765043259, 68.19019854068756, 67.61335909366608, 51.76749497652054, 36.52451790869236, 32.00708091259003, 27.39778384566307, 29.986518435180187, 25.249018147587776, 28.54182455688715, 30.705599449574947, 24.793992564082146, 28.315180018544197, 22.838721983134747, 16.056414619088173, 17.928876243531704, 17.505590356886387, 31.553793735802174, 46.41069442033768, 50.97927287220955, 48.2225625962019, 52.19395749270916, 58.6836102604866, 49.06428582966328, 58.38111229240894, 51.975784599781036, 50.94818294048309, 46.339364647865295, 55.91581977903843, 54.724002331495285, 57.06657662987709, 56.64446108043194, 45.95868967473507, 37.505207285284996, 32.175993248820305, 36.86662495136261, 46.37966148555279, 68.46325948834419, 75.2295184135437, 83.75137433409691, 74.63567867875099, 70.37345498800278, 56.949588507413864, 50.24086229503155, 58.92577886581421, 43.03581431508064, 47.749149799346924, 58.73880609869957, 71.67102456092834, 81.25952884554863, 87.39135101437569, 57.856071665883064, 13.05825674906373, 0.9293716459069401, 0.10483440782991238, 0.04938386453432031, 0.0433092299499549, 0.09741017769556493, 0.09830317430896685, 0.023901737949927337, 0.2055055898381397, 0.14667892770376056, 0.04899393272353336, 0.2412128378637135, 0.218576947809197, 0.1844809766043909, 0.08732663205591962, 0.16572286753216758, 0.2842421445529908, 0.15819189429748803, 0.17618771380512044, 0.15965907572535798, 0.11047458916436881, 0.1283027426688932, 0.15286652458598837, 0.26672686566598713, 0.20049365877639502, 0.2708353061461821, 0.18353561405092478, 0.2226755622541532, 0.41828965942841023, 0.2515427320031449, 0.289510294678621, 0.22692373429890722, 0.12755324773024768, 0.23996977019123733, 0.1637652749195695, 0.1940745415049605, 0.23510554136009887, 0.17504565243143588, 0.1570290676318109, 0.22749563329853117, 0.21660187019733712, 0.27499231277033687, 0.1848685261211358, 0.18193679046817124, 0.08053595855017193, 0.09735537751112133, 0.13221553817857057, 0.15249741001753137, 0.10700969462050125, 0.11160081310663372, 0.056275655661011115, 0.025093309850490186, 0.08599875174695626, 0.10055160717456602, 0.17542618123115972, 0.23802897980203852, 0.14499938813969493, 0.11370376276317984, 0.21904089400777593, 0.19301111809909344, 0.2212685244739987, 0.17620643076952547, 0.13542336761020124, 0.21228702360531315, 0.098666722769849, 0.21309565287083387, 0.11881063677719794, 0.175115785386879, 0.21871371078304946, 0.07191551994765177, 0.16558836068725213, 0.19155673129716888, 0.1500178501009941, 0.25816948735155165, 0.13564745167968795, 0.1980201993137598, 0.12468508444726467, 0.2174909334280528, 0.1181528416054789, 0.20638372865505517, 0.13590690650744364, 0.10963983630063012, 0.12525119469501078, 0.1286919545964338, 0.17598099599126726, 0.1471463026246056, 0.17790603800676763, 0.18705753522226587, 0.13259698724141344, 0.22490173811092973, 0.2101720214704983, 0.21461270662257448, 0.28107578633353114, 0.1644722744822502, 0.16623888281174004, 0.14413466735277325, 0.207691541290842, 0.2984318003291264, 0.128168131923303, 0.15141737734666094, 0.19378471799427643, 0.15335145872086287, 0.37695114326197654, 0.29136020166333765, 0.1846493995981291, 0.2122737540048547, 0.5141828872729093, 0.31428508402314037, 0.16119251609779894, 0.19227000942919403, 0.11544445529580116, 0.4268132254946977, 0.28980753966607153, 6.1935014091432095, 45.34219175577164, 88.03531005978584, 108.67881193757057, 105.38000375032425, 105.30189514160156, 96.37273907661438, 78.4830330312252, 64.6531431376934, 67.84929603338242, 55.63550502061844, 74.79053556919098, 72.17060655355453, 68.34451586008072, 69.24881413578987, 68.17433059215546, 65.97366347908974, 59.784589782357216, 62.931896299123764, 61.95918269455433, 62.21500776708126, 56.650202572345734, 51.763983964920044, 47.12297759950161, 40.41303165256977, 35.68659067153931, 35.00136584043503, 54.071147963404655, 58.88104386627674, 69.63385507464409, 69.52128231525421, 64.79884251952171, 61.3924241065979, 74.0199065208435, 81.16717860102654, 80.08713215589523, 81.9762159883976, 67.18398213386536, 69.18050900101662, 65.5694791674614, 69.26980420947075, 76.49605125188828, 67.83415004611015, 58.47366392612457, 53.598293736577034, 59.49694141745567, 68.6729322373867, 63.60025003552437, 77.81505167484283, 81.11064523458481, 78.70921209454536, 68.64612087607384, 62.51812890172005, 54.265074357390404, 59.15648728609085, 77.44796857237816, 71.91548064351082, 86.34178653359413, 81.22122690081596, 85.79623460769653, 103.53559032082558, 99.9516986310482, 59.318081215023994, 10.908105075359344, 0.7235245790798217, 0.44664498476777226, 0.3489540674490854, 0.1960416039219126, 0.20542272162856534, 0.30279076017905027, 0.2923569059930742, 0.24500604369677603, 0.13728793943300843, 0.304193181800656, 0.2683142898604274, 0.3153668384766206, 0.3386525233509019, 0.28784850728698075, 0.24257951765321195, 0.3394137293798849, 0.3043778281426057, 0.22768329276004806, 0.266880490235053, 0.20915646658977494, 0.20923384290654212, 0.3381903434637934, 0.3423287073383108, 0.27863429859280586, 0.35918991663493216, 0.25593024969566613, 0.31696037796791643, 0.5649391387123615, 0.33678842650260776, 0.3806341253221035, 0.29973029159009457, 0.3941152972402051, 0.35723596054594964, 0.2615564415464178, 0.2552536188159138, 0.22180934232892469, 0.3473884623963386, 0.2726204978534952, 0.2564255887409672, 0.2677359787048772, 0.32123289245646447, 0.2820509683806449, 0.305770572158508, 0.1639107655500993, 0.17744372453307733, 0.1491037171217613, 0.18791621492709965, 0.16020516282878816, 0.18309817736735567, 0.19306979229440913, 0.4264405189314857, 0.20247076987288892, 0.33165466447826475], [0.16923775314353406, 0.033375794810126536, 0.0989258436311502, 0.023721153011138085, 0.041640366180217825, 0.1474754451191984, 0.12343301452347077, 0.09681376555818133, 0.05431539502751548, 0.07323530342546292, 0.028343792364466935, 0.09471925412071869, 0.07215819481643848, 0.1253809072659351, 0.0962931192771066, 0.06578087530215271, 0.0956771886558272, 0.10478950047399849, 0.058271758316550404, 0.03868520463583991, 0.021865114031243138, 0.0918060053663794, 0.02981503519549733, 0.025083424443437252, 0.07208195398561656, 0.07604169033584185, 0.07872686968767084, 0.09716333195683546, 0.08811434759991243, 0.0518677994114114, 0.11762339345295914, 0.06699800491333008, 0.07029899614281021, 0.12836285663070157, 0.10954541285173036, 0.09673424443462864, 0.03596471018681768, 0.2018187040812336, 0.07046791637549177, 0.1474580937065184, 0.08160428755218163, 0.17912256647832692, 0.1699379991623573, 0.20523017883533612, 0.11035267656552605, 0.0676332313742023, 0.0871230015764013, 0.3176025435095653, 0.16766592889325693, 0.19992771180113778, 0.21309026487870142, 0.15052829927299172, 0.031299187685362995, 0.29336566280107945, 0.1934211398474872, 0.2597800368675962, 0.17786971729947254, 0.21134379843715578, 0.4647810850292444, 0.897019172552973, 0.1619386120000854, 4.413554845377803, 25.90546142309904, 72.95264258980751, 88.50045830011368, 90.54431542754173, 85.45863032341003, 79.01413813233376, 71.13102793693542, 56.354840621352196, 49.60425965487957, 43.00535894930363, 35.21064721047878, 17.848941832780838, 14.419710393995047, 18.428201749920845, 20.462433993816376, 15.820628721266985, 12.850494347512722, 19.486133381724358, 14.279763903468847, 12.182214707136154, 2.5636255368590355, 4.960715984925628, 3.997998218983412, 5.729682147502899, 16.528461389243603, 16.742792688310146, 23.813348785042763, 27.414440251886845, 27.121557667851448, 17.83140007406473, 26.80904533714056, 65.10142788290977, 61.23396120965481, 40.71107245981693, 31.648231968283653, 21.507799699902534, 17.897142246365547, 27.558289133012295, 20.025957114994526, 14.131065532565117, 13.635468576103449, 19.249892458319664, 30.36104343831539, 32.22558058798313, 37.05264016985893, 30.452103652060032, 34.62306573987007, 45.98978340625763, 55.38396991789341, 54.31056931614876, 47.730971574783325, 64.4648252427578, 60.996553748846054, 65.84812581539154, 59.01681438088417, 63.18707540631294, 68.16722497344017, 32.832791805267334, 7.9774752818048, 0.4868764244019985, 0.06828009471064433, 0.3255307883955538, 0.050398532548570074, 0.02029750517976936, 0.06771053347620182, 0.1474884178605862, 0.0565867899422301, 0.19806124008027837, 0.056785522247082554, 0.10601385118206963, 0.07825134598533623, 0.06279416877077892, 0.09600126228178851, 0.14296428562374786, 0.21459439041791484, 0.10145252992515452, 0.12164050524006598, 0.21816377935465425, 0.1344317989423871, 0.22295786038739607, 0.1398182474076748, 0.11004202839103527, 0.13591147813713178, 0.11573624549782835, 0.1708226985647343, 0.12751219212077558, 0.1564852663432248, 0.08532526015187614, 0.08748669104534201, 0.11152019360451959, 0.1530228802585043, 0.10625857437844388, 0.1165561999368947, 0.25843606679700315, 0.12945130525622517, 0.10896485298871994, 0.11355432390701026, 0.1164320386305917, 0.2041665476281196, 0.16220100573264062, 0.1334469096036628, 0.1573687040945515, 0.15907273453194648, 0.10539469963987358, 0.10473678572452627, 0.14181658392772079, 0.12668589974055067, 0.13994119159178808, 0.13418479735264555, 0.09678793139755726, 0.05457688333990518, 0.07234329386847094, 0.11274253309238702, 0.04686832529841922, 0.1699773923610337, 0.04019428030005656, 0.0860259217733983, 0.10966161091346294, 0.030460082125500776, 0.14808811771217734, 0.0874675065279007, 0.07812054245732725, 0.012054228809574852, 0.04145756407524459, 0.02336021134397015, 0.10281094218953513, 0.09663607313996181, 0.0612889596959576, 0.1358737621922046, 0.04648160327633377, 0.06536007756949402, 0.037067014709464274, 0.0340439429419348, 0.11860340688144788, 0.010010060959757539, 0.0075517593995755306, 0.029149391812097747, 0.09205454320181161, 0.07615992188220844, 0.005165315824342542, 0.09738268112414517, 0.05632688982586842, 0.09126316144829616, 0.03509464593662415, 0.14801191398873925, 0.11396209694794379, 0.02790462091070367, 0.09263633502996527, 0.1648856804240495, 0.11559686274267733, 0.03246500149543863, 0.12717439618427306, 0.07134535757359117, 0.09741876434418373, 0.09304346240242012, 0.07382181531284004, 0.11157300483318977, 0.19678786309668794, 0.13946961611509323, 0.11050707296817563, 0.12206173341837712, 0.26896182855125517, 0.023586289935337845, 0.13005976245040074, 0.20256897085346282, 0.10291764076100662, 0.05087987839942798, 0.20500851416727528, 0.21149481064639986, 0.26711874932516366, 0.22527932800585404, 0.15938807307975367, 0.4720474826171994, 0.29596525768283755, 1.4565019821748137, 18.492232114076614, 53.80247198045254, 91.40941500663757, 102.52539172768593, 97.73777782917023, 83.84836032986641, 62.08253167569637, 54.40468266606331, 41.35892629623413, 47.16700203716755, 49.840424582362175, 47.16363541781902, 50.74962079524994, 52.165405824780464, 56.053790375590324, 52.51173824071884, 54.413596987724304, 52.25734569132328, 55.72338670492172, 48.22878286242485, 52.32583321630955, 36.57988853752613, 41.71644531190395, 36.016424372792244, 36.938634887337685, 44.692654609680176, 58.73832732439041, 57.955158948898315, 64.6299035847187, 60.77315993607044, 51.99829839169979, 71.90851181745529, 105.68638131022453, 95.84754645824432, 73.08302119374275, 42.94183395802975, 45.89411973953247, 36.743386164307594, 53.119713217020035, 49.42846968770027, 46.39286197721958, 51.28394432365894, 53.436103239655495, 69.3276447057724, 69.66316670179367, 66.24758318066597, 60.366999730467796, 52.63146981596947, 57.50218525528908, 49.02481734752655, 46.06226071715355, 41.84647813439369, 53.222178518772125, 63.36813569068909, 71.62131562829018, 80.35194754600525, 79.73224639892578, 85.95714077353477, 55.79661637544632, 20.480733811855316, 2.3654870688915253, 0.04213196109049022, 0.5227257194928825, 0.029566786797659006, 0.08985435735667124, 0.08979416175861843, 0.009867474909697194, 0.0738062227901537, 0.08438419463345781, 0.09102971889660694, 0.13214733480708674, 0.1732434655423276, 0.06888973191962577, 0.05736990045988932, 0.037301659540389664, 0.0705896805447992, 0.14161681261612102, 0.13014622265473008, 0.13365005026571453, 0.12810080428607762, 0.13446427532471716, 0.13104903046041727, 0.0940806583093945, 0.11557516976608895, 0.10439467791002244, 0.11798674895544536, 0.05333506989700254, 0.21830579673405737, 0.18517979769967496, 0.1871231262339279, 0.17170015460578725, 0.1347249621176161, 0.1095774291025009, 0.22418810374801978, 0.15669648157199845, 0.02740398107562214, 0.1904766244115308, 0.06029506810591556, 0.11889345303643495, 0.13052695925580338, 0.1594263975857757, 0.2145450227544643, 0.07414886495098472, 0.12079620835720561, 0.15776054322486743, 0.1073972144513391, 0.07523148029576987, 0.12108756069210358, 0.03569557404262014, 0.04520394781138748, 0.023910558375064284, 0.058120130124734715, 0.04795517830643803, 0.03412562371522654, 0.1115435193059966, 0.2642260951688513, 0.15971847722539678, 0.21269863354973495, 0.09553934214636683, 0.11880033576744609, 0.25070443167351186, 0.177624749194365, 0.21942951221717522, 0.13342756923520938, 0.14900097419740632, 0.16778253513621166, 0.24170621763914824, 0.20084534771740437, 0.18013294116826728, 0.2205174116534181, 0.12369156393106095, 0.20083525450900197, 0.11798733525210992, 0.10337807660107501, 0.31713656382635236, 0.11016441596439108, 0.13640199322253466, 0.24588393018348143, 0.20441890752408653, 0.17727570229908451, 0.22451438155258074, 0.22263232473051175, 0.1494595324038528, 0.15605629014316946, 0.1521862274967134, 0.20744333742186427, 0.20341752766398713, 0.136287895438727, 0.21791315608425066, 0.3234954335493967, 0.2725591667694971, 0.15810374199645594, 0.2798154711490497, 0.09844775209785439, 0.3154326224466786, 0.2074295186321251, 0.170663018070627, 0.19801715650828555, 0.2373655591509305, 0.20182133128400892, 0.276620703516528, 0.1815527438884601, 0.34831997647415847, 0.24656824971316382, 0.14035145082743838, 0.2632292720954865, 0.23072076961398125, 0.09138016102951951, 0.3443159710150212, 0.2540105808293447, 0.4034834273625165, 0.39780718507245183, 0.20953540719347075, 0.3974130452843383, 0.7092288555577397, 0.38701567507814616, 10.577376522123814, 47.08979018032551, 102.2200857102871, 120.6924220919609, 117.91776537895203, 112.56149679422379, 97.13353425264359, 95.58146953582764, 76.41519919037819, 78.6894303560257, 75.89724898338318, 76.17491528391838, 61.91350534558296, 61.09206162393093, 63.25759582221508, 71.21463105082512, 67.79059678316116, 62.47462883591652, 66.71339258551598, 47.852637246251106, 60.07876619696617, 38.78768786787987, 41.85886926949024, 34.46212537586689, 40.72226285934448, 49.98212657868862, 57.08665855228901, 51.713340282440186, 53.92408445477486, 55.42343460023403, 39.59886834025383, 47.294021621346474, 93.51381808519363, 85.58384880423546, 75.51200285553932, 67.86695748567581, 52.634486854076385, 42.46430218219757, 57.1944397687912, 46.92210137844086, 46.111445277929306, 50.641801580786705, 63.592589646577835, 75.05148276686668, 63.43389496207237, 66.00403904914856, 58.938090205192566, 53.59434574842453, 75.70932626724243, 81.10708102583885, 80.50004079937935, 69.75996270775795, 82.15935856103897, 85.96575111150742, 90.26506081223488, 97.52532362937927, 101.5690590441227, 98.16735237836838, 55.87361924350262, 17.389637678861618, 1.3096799980849028, 0.1814379039569758, 0.5086828605271876, 0.21751996624516323, 0.21071463532280177, 0.21914988581556827, 0.28810057032387704, 0.20973739010514691, 0.33149115450214595, 0.21084414009237662, 0.28744356182869524, 0.3399913280736655, 0.28371023247018456, 0.17776494089048356, 0.20888481085421517, 0.34998701827134937, 0.27842139126732945, 0.21540739835472777, 0.2964896592311561, 0.21504940115846694, 0.30567243054974824, 0.17809791286708787, 0.22847145359264687, 0.2590711077209562, 0.2024568323395215, 0.37611322884913534, 0.33359202614519745, 0.3409463237039745, 0.23221312469104305, 0.2813599695218727, 0.24732883233809844, 0.2048171588103287, 0.25204299890901893, 0.34507364442106336, 0.24315949121955782, 0.2454315169597976, 0.27790547988843173, 0.2368288824800402, 0.26542083418462425, 0.41332911467179656, 0.2960048883687705, 0.26901306642685086, 0.2360872394638136, 0.19842884066747501, 0.5527764663565904, 0.18498131772503257, 0.16323183401254937, 0.17554679507156834, 0.19700292265042663, 0.18111069104634225, 0.18696503393584862, 0.14583574404241517, 0.1833267736947164, 0.20934378466336057, 0.17599423590581864], [0.028496248050942086, 0.05374752217903733, 0.05624548364721704, 0.07236566219944507, 0.06975008887820877, 0.03279176169598941, 0.05227549823757727, 0.11816958445706405, 0.10866998287383467, 0.25371648254804313, 0.05605717109574471, 0.10387277739937417, 0.19796162901911885, 0.032007998088374734, 0.13250190328108147, 0.17911645118147135, 0.29529527644626796, 0.08121666382066905, 0.09316390554886311, 0.020119031651120167, 0.10201179014984518, 0.061977657896932214, 0.059523672389332205, 0.025838483634288423, 0.07020340010058135, 0.12645371141843498, 0.007649627805221826, 0.1301807028357871, 0.17004988534608856, 0.14339154004119337, 0.19027029251446947, 0.038953409384703264, 0.07887139552622102, 0.12998967402381822, 0.054294837536872365, 0.1905192682170309, 0.044896576218889095, 0.11092832341091707, 0.08083875480224378, 0.14944816270144656, 0.14189216424711049, 0.10407082692836411, 0.10350342534366064, 0.0776228285394609, 0.15801704430487007, 0.2294086673646234, 0.13550188683439046, 0.1870826494996436, 0.18403130932711065, 0.27529760263860226, 0.292444716906175, 0.21797494729980826, 0.17786168726161122, 0.39435854356270283, 0.18225307896500453, 0.3692419803701341, 0.08968603826360777, 0.306758934748359, 0.16817425552289933, 0.5719928664620966, 0.37659767316654325, 0.511960897129029, 0.13981352734845132, 4.15909199975431, 20.91436844319105, 47.63489753007889, 80.06184071302414, 87.6637127995491, 86.2991452217102, 77.75483250617981, 69.96436893939972, 63.96715074777603, 60.26437483727932, 50.75761556625366, 40.565578266978264, 44.20443020761013, 34.30877700448036, 33.971286714076996, 27.155943922698498, 24.88408003002405, 38.304346203804016, 29.97316975146532, 27.981721311807632, 29.169765561819077, 30.188857577741146, 30.444464161992073, 22.76142843067646, 42.74196848273277, 46.18117153644562, 52.923461347818375, 56.048793643713, 56.947548016905785, 52.461508736014366, 54.26691725850105, 60.93818888068199, 64.5155069231987, 111.03204846382141, 36.04077346622944, 45.96053257584572, 48.709795251488686, 41.87558077275753, 45.52254907786846, 45.278176590800285, 41.71264551579952, 34.11539398133755, 24.461341314017773, 39.94049660861492, 51.175517141819, 54.47453431785107, 62.75745525956154, 67.89347246289253, 70.48933357000351, 82.49333783984184, 79.5051933825016, 72.6211179792881, 67.31669381260872, 47.91887529194355, 26.139264777302742, 6.246928917244077, 0.5936803808435798, 0.12833063257858157, 0.10241332915029489, 0.0637766535510309, 0.1567009641439654, 0.15388939704280347, 0.04141530989727471, 0.06030344324244652, 0.08271162383607589, 0.1019651313254144, 0.12159367572166957, 0.08287394637591206, 0.07105960103217512, 0.07469560514437035, 0.2106276704580523, 0.1494128067861311, 0.09651286920416169, 0.14405715744942427, 0.05905759993765969, 0.06922300075530075, 0.2018937500542961, 0.21301698521710932, 0.3481892100535333, 0.17331224778899923, 0.23249110352480784, 0.03602234537538607, 0.15203193499473855, 0.19735130161279812, 0.18823152378899977, 0.1767559169093147, 0.15291112766135484, 0.06752586486982182, 0.064108965016203, 0.2564835356315598, 0.08702299717697315, 0.24133008235367015, 0.03832903312286362, 0.19754469045437872, 0.019701566161529627, 0.14720515493536368, 0.08510056752129458, 0.05189895848161541, 0.03560071643732954, 0.08047637893469073, 0.1324032570119016, 0.13051915186224505, 0.08158514756360091, 0.16920679074246436, 0.04639678321836982, 0.07452667749021202, 0.023772585700498894, 0.0046527510676241945, 0.05865678082045633, 0.13879801699658856, 0.20428437099326402, 0.14178523560985923, 0.1389304012991488, 0.07113544110325165, 0.10166724809096195, 0.07067337253829464, 0.057197377100237645, 0.11732633400242776, 0.08551625185646117, 0.06828806537669152, 0.09900321994791739, 0.09320395925897174, 0.16356716601876542, 0.04576751991407946, 0.11189961660420522, 0.0913472987303976, 0.09408842859556898, 0.03884508550981991, 0.1699171744985506, 0.1836687553441152, 0.11661207623546943, 0.08389310809434392, 0.008134879208228085, 0.09926499769790098, 0.06558384993695654, 0.06952605675905943, 0.0287110348654096, 0.05723343805584591, 0.061533226471510716, 0.017760601367626805, 0.0682662907638587, 0.08636525395559147, 0.06137849981314503, 0.21130675042513758, 0.04808274607057683, 0.11519284496898763, 0.0730872672284022, 0.073545973864384, 0.12533265282399952, 0.041592683191993274, 0.08188283041818067, 0.04349580958660226, 0.1222284123650752, 0.12281652729143389, 0.10518574054003693, 0.090479460923234, 0.07313990776310675, 0.058970564568880945, 0.25081821775529534, 0.10816394948051311, 0.08453301008557901, 0.12977658858289942, 0.06542376868310384, 0.13705799239687622, 0.17352364113321528, 0.1946391526143998, 0.33754200325347483, 0.2695835701888427, 0.22927750018425286, 0.2675428125075996, 0.2899767196504399, 0.28025161649566144, 0.2837236801860854, 0.3436128603061661, 0.3655205847462639, 1.519350134767592, 19.648114889860153, 52.05007441341877, 77.26070702075958, 97.8319899737835, 104.13165673613548, 97.00009301304817, 80.27688637375832, 69.1975548863411, 61.10020838677883, 53.202343583106995, 37.269844114780426, 36.48515582084656, 39.23427030444145, 41.34507603943348, 39.5175489038229, 31.388293616473675, 41.61318205296993, 39.274388551712036, 34.845209419727325, 20.52398309111595, 18.092601858079433, 19.6218279004097, 21.549810245633125, 27.824290059506893, 34.83203172683716, 37.47075833380222, 37.45430901646614, 50.68958021700382, 32.48967781662941, 30.547847114503384, 71.82196766138077, 70.44650986790657, 68.37603896856308, 118.74235153198242, 40.036927834153175, 45.002862364053726, 45.333391427993774, 35.53389586508274, 33.25012721121311, 34.145910143852234, 47.701576352119446, 46.26540541648865, 34.89297665655613, 44.46900241076946, 34.5604906976223, 39.934694319963455, 57.13402681052685, 67.66085654497147, 72.92235061526299, 83.52285459637642, 93.009562343359, 91.26363962888718, 84.96343329548836, 65.38807690143585, 44.187190532684326, 17.457766123116016, 2.3906877916306257, 0.18638709385413677, 0.1474113977747038, 0.03532705319230445, 0.11992815532721579, 0.13950158783700317, 0.08872501639416441, 0.155892260663677, 0.13874256372218952, 0.03728656054590829, 0.11897211326868273, 0.014912466795067303, 0.03823188970272895, 0.01917884928843705, 0.19362261809874326, 0.0695703258679714, 0.10035096755018458, 0.10460649427841417, 0.043314966751495376, 0.025099801787291653, 0.14994188386481255, 0.22702674439642578, 0.17604867985937744, 0.1533156872028485, 0.15463193063624203, 0.05591918728896417, 0.08820281902444549, 0.03475592231552582, 0.10387828413513489, 0.07408559686155058, 0.04881797322013881, 0.09845779335591942, 0.07262648257892579, 0.06332629607641138, 0.17038248624885455, 0.11479690176201984, 0.03283463927800767, 0.08428779707173817, 0.006603076199098723, 0.11972370848525316, 0.05978504937957041, 0.06532228740979917, 0.0454448712116573, 0.05244201762252487, 0.10534499800996855, 0.14770377427339554, 0.0781307098804973, 0.13784428301732987, 0.015351053807535209, 0.033535456750541925, 0.11415711851441301, 0.022831978458270896, 0.04406572705192957, 0.1352995476918295, 0.15889537608018145, 0.15529319905908778, 0.06044671856216155, 0.13772439648164436, 0.16160520957782865, 0.1899957424029708, 0.10686735811759718, 0.20046542747877538, 0.2793615439441055, 0.18667764466954395, 0.20408801356097683, 0.15311383787775412, 0.32178371446207166, 0.2093597111525014, 0.3037647844757885, 0.2857032255269587, 0.16639031062368304, 0.1782576972618699, 0.26783266570419073, 0.3298058855580166, 0.1152907639334444, 0.20041519892401993, 0.2918227080954239, 0.1875462246243842, 0.17467374738771468, 0.225886152475141, 0.08857294291374274, 0.2175822769640945, 0.21567445277469233, 0.1275117468321696, 0.1875212587765418, 0.19143007637467235, 0.13560387276811525, 0.17061054822988808, 0.1620912124053575, 0.17567561706528068, 0.22067829442676157, 0.11347980485879816, 0.3203500038944185, 0.11848766152979806, 0.18598891678266227, 0.1567439196514897, 0.1518060252419673, 0.13813447760185227, 0.1982232360751368, 0.22443532798206434, 0.19642930186819285, 0.13848830392817035, 0.33668799907900393, 0.24455382343148813, 0.2629106829408556, 0.2314733518869616, 0.32110922096762806, 0.3378504398278892, 0.23177723167464137, 0.2817444910760969, 0.4732266959035769, 0.3391047287732363, 0.28705538890790194, 0.311924223206006, 0.4293127788696438, 0.2937488188035786, 0.4233069933252409, 0.3652876691194251, 0.42195432528387755, 0.458217560662888, 9.397097155451775, 39.93254743516445, 75.0209704041481, 108.81821885704994, 120.10023146867752, 119.49469596147537, 106.48829787969589, 104.83674690127373, 92.15210035443306, 91.38740658760071, 79.7342374920845, 72.75391325354576, 82.74281725287437, 80.83161100745201, 80.91304823756218, 69.45059850811958, 71.13805755972862, 87.75188326835632, 75.81227034330368, 67.95828178524971, 66.2868882715702, 77.35035941004753, 73.66163894534111, 58.59146900475025, 82.33376160264015, 87.39000588655472, 92.15125679969788, 95.22028371691704, 89.81698125600815, 84.09336358308792, 97.96065106987953, 93.3289884030819, 92.68981710076332, 138.1424081325531, 57.835089191794395, 86.589495241642, 89.94603753089905, 83.85485798120499, 92.08135575056076, 92.57105827331543, 89.65973809361458, 69.08907070755959, 55.00138744711876, 81.89005181193352, 77.56577745079994, 80.00578612089157, 87.04948335886002, 90.78158229589462, 92.1215271949768, 105.04200428724289, 112.9368482530117, 116.21270567178726, 105.87561875581741, 77.69537329673767, 44.973413944244385, 14.421799331903458, 1.5855917427688837, 0.29698259371798486, 0.31569549115374684, 0.11965318219154142, 0.2935427689226344, 0.23952350195031613, 0.14538198010995984, 0.29568971309345216, 0.22562788508366793, 0.2763228351250291, 0.35259225347545, 0.21123378246556967, 0.1898122686543502, 0.07981865797773935, 0.2789906185353175, 0.2301623034873046, 0.2131710699177347, 0.18001715128775686, 0.19456076697679237, 0.20417699706740677, 0.3430521232075989, 0.3504437656374648, 0.35450090887025, 0.1807746317354031, 0.2842995570972562, 0.18868865707190707, 0.2648894564481452, 0.35775421711150557, 0.41578013158869, 0.29392639989964664, 0.20886520331259817, 0.3270788787631318, 0.2843033568933606, 0.42251651699189097, 0.2683198411250487, 0.37122957059182227, 0.165087143832352, 0.3680060966871679, 0.1615246568690054, 0.2101952803786844, 0.2152866657706909, 0.21158324496354908, 0.07521045525209047, 0.12140948208980262, 0.30578375270124525, 0.21748689614469185, 0.19850776065140963, 0.2748469705693424, 0.07105513330316171, 0.15719526418251917, 0.15545384434517473, 0.1031451164453756, 0.10535659035667777, 0.19464967626845464, 0.206315154209733, 0.28690734528936446, 0.1909849065123126], [0.11131452221889049, 0.07351046209805645, 0.07404871954349801, 0.052968252275604755, 0.03659003268694505, 0.10218197203357704, 0.0474542286247015, 0.11213666599360295, 0.08225978206610307, 0.07929391504148953, 0.09337091280031018, 0.20893456443445757, 0.24181777727790177, 0.20553523121634498, 0.23649111622944474, 0.01877765538665699, 0.11332671463605948, 0.07207237285911106, 0.1003648828191217, 0.090897134214174, 0.08981970648164861, 0.054004238481866196, 0.09111619394388981, 0.1688841197756119, 0.08575068146456033, 0.01747203765262384, 0.20236073905834928, 0.18833205511327833, 0.040663755498826504, 0.07508210081141442, 0.05646664365485776, 0.11878845398314297, 0.10637711762683466, 0.12352823949186131, 0.053573748300550506, 0.1374820852652192, 0.1687600029981695, 0.1598719385219738, 0.1469700870802626, 0.08871253347024322, 0.179082267859485, 0.08709472574992105, 0.06183994497405365, 0.15328349283663556, 0.12708944996120408, 0.14835650799795985, 0.10960909654386342, 0.22506781591800973, 0.08596536994446069, 0.12438874487997964, 0.05488813636475243, 0.11265158289461397, 0.12775364244589582, 0.16831645101774484, 0.1283806681749411, 0.021821204863954335, 0.17554250545799732, 0.2123884900356643, 0.08727235879632644, 0.12543109129182994, 0.13810486590955406, 0.2733058563899249, 0.25479592150077224, 0.3381244110642001, 0.120231671462534, 0.9860432893037796, 13.360341489315033, 25.990236774086952, 53.45024608075619, 77.64092981815338, 85.4598006606102, 85.60037791728973, 71.83430179953575, 71.58023223280907, 66.5816080570221, 64.00649383664131, 62.45276860892773, 54.13863614201546, 49.994871094822884, 50.48379085958004, 59.75791521370411, 53.007661029696465, 49.86580342054367, 49.905629083514214, 53.70303891599178, 51.62070885300636, 66.62231147289276, 66.22381925582886, 65.60328975319862, 67.86632671952248, 68.14213871955872, 66.37346282601357, 74.14465382695198, 70.7880887389183, 75.20614966750145, 70.68270519375801, 64.28462371230125, 57.60466955602169, 48.24399344623089, 46.00403644144535, 46.223375871777534, 42.505826354026794, 41.4339304715395, 41.421596333384514, 50.765910521149635, 56.12213350832462, 60.56135930120945, 65.31508281826973, 71.50356754660606, 78.06835368275642, 83.46300020813942, 84.86309587955475, 61.77586533129215, 31.861841306090355, 19.010395109653473, 3.0470310850068927, 1.9571067136712372, 0.07947750753373839, 0.27670293347910047, 0.2937109989579767, 0.023510828359576408, 0.12912833743030205, 0.09478432562900707, 0.13211862853495404, 0.07693450883380137, 0.015343047889473382, 0.07241054729092866, 0.03422119378228672, 0.024613567038613837, 0.056801727041602135, 0.10770168053568341, 0.03217680328816641, 0.05276746793242637, 0.04409784349263646, 0.07469955337001011, 0.0937705222168006, 0.06246302989893593, 0.008988212666736217, 0.031216846400639042, 0.048470514520886354, 0.08972652984084561, 0.029705228880629875, 0.041544016858097166, 0.055268119685933925, 0.048662448753020726, 0.12114110664697364, 0.08595497987698764, 0.05558496850426309, 0.1270121181732975, 0.041286257837782614, 0.024919534116634168, 0.07433244260028005, 0.07524894303060137, 0.09429656391148455, 0.03667842989671044, 0.056620490868226625, 0.04716871328128036, 0.12521619501058012, 0.0297891472291667, 0.029512721339415293, 0.060073336644563824, 0.016985424408630934, 0.02790204936900409, 0.04091759597940836, 0.01784030802809866, 0.01617208621610189, 0.12000635542790405, 0.05256480224488769, 0.08876227962900884, 0.19253333826782182, 0.0897826362052001, 0.03707444360770751, 0.1416987308766693, 0.09936475718859583, 0.05220502018346451, 0.03663064300781116, 0.027278671295789536, 0.032478170905960724, 0.026577705393719953, 0.0353157985227881, 0.06568633310962468, 0.03434598220337648, 0.0262192684749607, 0.08114305019262247, 0.025252485684177373, 0.05200068837439176, 0.052313904379843734, 0.15045215492136776, 0.10780160329886712, 0.10011676058638841, 0.12611392652615905, 0.06722526537487283, 0.11535930127138272, 0.0727328026550822, 0.06628342060139403, 0.04149612235778477, 0.11363581914338283, 0.03124776056210976, 0.02066829700197559, 0.021985412458889186, 0.048308329278370366, 0.16643298411509022, 0.19550218130461872, 0.06124599676695652, 0.013623263512272388, 0.0493910819204757, 0.04795705965079833, 0.07660359260626137, 0.09394741311552934, 0.060907291699550115, 0.05880694698134903, 0.06389140442479402, 0.209543407545425, 0.10666722315363586, 0.025223098491551355, 0.048965612368192524, 0.1236735816928558, 0.11660558244329877, 0.032240969376289286, 0.10154372503166087, 0.16818850475829095, 0.041883456651703455, 0.11386561032850295, 0.12475695402827114, 0.08172381785698235, 0.09774739475687966, 0.06422649894375354, 0.06654497570707463, 0.08949473485699855, 0.08023055735975504, 0.10400140643469058, 0.015314433458115673, 0.11559763457626104, 0.18885679804952815, 0.13019469974096864, 0.12215091730467975, 0.17358418554067612, 0.34640018886420876, 0.07278418153873645, 0.05941625022387598, 1.0653007426299155, 8.207064662128687, 35.009611397981644, 52.91059523820877, 78.17432999610901, 93.79469901323318, 98.22451651096344, 95.8910845220089, 86.20966762304306, 79.49954688549042, 74.27391529083252, 74.30540800094604, 61.42780780792236, 64.53650459647179, 57.128330916166306, 50.5755103379488, 56.983041912317276, 53.35304729640484, 53.49086210131645, 51.74296349287033, 54.528016448020935, 56.52355156838894, 67.83807143568993, 68.89924809336662, 69.13706213235855, 66.24651923775673, 66.09319746494293, 64.23836499452591, 60.05061350762844, 58.812522143125534, 64.07169073820114, 72.77545049786568, 84.41035777330399, 55.46897515654564, 57.39172138273716, 57.100744396448135, 59.61090110242367, 54.75528605282307, 50.33413589000702, 50.21254241466522, 43.29839162528515, 41.435549184679985, 60.22177152335644, 72.34517678618431, 75.95053732395172, 84.94026973843575, 92.35383912920952, 94.85584527254105, 82.51484468579292, 55.183203890919685, 38.67421455681324, 16.477707512676716, 5.714311972260475, 1.706208314280957, 0.606927479384467, 0.25949481467250735, 0.030780693632550538, 0.0651552522322163, 0.0920811269315891, 0.062402181210927665, 0.03485551482299343, 0.02677228538232157, 0.07278245975612663, 0.05633104585285764, 0.0485126870626118, 0.1174114657624159, 0.06323054418317042, 0.10519936637138017, 0.08153405069606379, 0.034904685817309655, 0.11198407300980762, 0.039125832554418594, 0.027981193852610886, 0.06355647317832336, 0.030810540956736077, 0.06008282500260975, 0.03010700165759772, 0.13072886795271188, 0.02957729004265275, 0.03155839760438539, 0.05118671935633756, 0.042176259885309264, 0.09379585171700455, 0.04064880122314207, 0.14226859639165923, 0.1868346385890618, 0.07639975432539359, 0.13619125296827406, 0.03809964640822727, 0.12338910906692035, 0.025467053565080278, 0.04333120865339879, 0.1251523703103885, 0.150679177895654, 0.14840232819551602, 0.08194833979359828, 0.027435049232735764, 0.03339616676385049, 0.1148168952204287, 0.008492052620567847, 0.06508826598292217, 0.046720634200028144, 0.05143427013535984, 0.021618297978420742, 0.10147535838768817, 0.1204446010524407, 0.06782549215131439, 0.06947697853320278, 0.09207138253259473, 0.05626663856673986, 0.02738801747909747, 0.05654746724758297, 0.14755163399968296, 0.1018957034102641, 0.16008405917091295, 0.15251283184625208, 0.19769432226894423, 0.10660526866558939, 0.12771800451446325, 0.21495764201972634, 0.14399955194676295, 0.11880807636771351, 0.14293477783212438, 0.22806969936937094, 0.232093223312404, 0.25442636164370924, 0.17771581071428955, 0.16026968514779583, 0.28454215032979846, 0.15715385234216228, 0.21037440514191985, 0.14919897919753566, 0.22573286929400638, 0.13332948699826375, 0.15284267195966095, 0.18381650210358202, 0.18885710975155234, 0.22506943379994482, 0.3022480721119791, 0.19100901146885008, 0.2947428810875863, 0.1644637991557829, 0.17663709906628355, 0.21809621423017234, 0.10824695127666928, 0.1606946685933508, 0.18579453346319497, 0.08536181834642775, 0.256611630320549, 0.24296038784086704, 0.21252057747915387, 0.17299448983976617, 0.21224786789389327, 0.15750865830341354, 0.14734441152540967, 0.18961450114147738, 0.34457121044397354, 0.2494463132461533, 0.14725591783644632, 0.22558264376129955, 0.205784696736373, 0.26048751140479, 0.26069077081047, 0.24165768118109554, 0.10146736545721069, 0.2199462102726102, 0.21075925324112177, 0.16847619088366628, 0.2031059592263773, 0.2668804011773318, 0.2498584723798558, 0.25364208966493607, 0.14866730460198596, 0.31954515958204865, 0.23147504398366436, 0.3305502893636003, 0.3672373801236972, 3.5018467297777534, 21.891668401658535, 43.52898225188255, 76.5415196120739, 107.33515843749046, 121.01617231965065, 124.4668735563755, 120.66726744174957, 116.00532799959183, 103.84194508194923, 101.16205528378487, 95.88692754507065, 93.11264321208, 85.94803646206856, 85.73260322213173, 91.0850340127945, 90.33464267849922, 83.62953767180443, 76.96730196475983, 81.55336707830429, 82.88191258907318, 102.53296092152596, 96.99582204222679, 94.43124085664749, 95.15446364879608, 92.75523439049721, 93.47765922546387, 99.13399010896683, 95.97910299897194, 101.14336788654327, 92.80220746994019, 90.99041149020195, 76.19040325284004, 79.5974600315094, 72.0171631872654, 76.16234555840492, 71.33866399526596, 68.45480114221573, 70.46837389469147, 71.09869167208672, 70.88527232408524, 89.1850371658802, 89.31765004992485, 94.9230408668518, 105.24984553456306, 113.76395747065544, 115.77037900686264, 91.24782487750053, 58.96777801215649, 34.05805125832558, 11.037002708762884, 3.1034131720662117, 0.8490979846101254, 0.43412427068687975, 0.4173340107081458, 0.1575047249207273, 0.24657196045154706, 0.19171054882463068, 0.24438691441901028, 0.18959036649903283, 0.20596367307007313, 0.20618950860807672, 0.1616996998200193, 0.1349746502819471, 0.18733983335550874, 0.17655443865805864, 0.11648158440948464, 0.203234039072413, 0.118718157755211, 0.16252804052783176, 0.24281832593260333, 0.14871181861963123, 0.16837053874041885, 0.13609912275569513, 0.15826857299543917, 0.21140973083674908, 0.16124908259371296, 0.17865685396827757, 0.21583514258963987, 0.15587222267640755, 0.18113127822289243, 0.20817718788748607, 0.11453795159468427, 0.32859855971764773, 0.3378026752034202, 0.2644910418894142, 0.25303216301836073, 0.21414000308141112, 0.26548347144853324, 0.20735738187795505, 0.2768622280564159, 0.1544927927898243, 0.2903708000667393, 0.22470308002084494, 0.15558136015897617, 0.10657441016519442, 0.07830089176422916, 0.20855385751929134, 0.10773863948998041, 0.20082289032870904, 0.18399175285594538, 0.16419616586063057, 0.09633117660996504, 0.20696808089269325, 0.27961808955296874, 0.24816581164486706, 0.15258254919899628, 0.19209717807825655, 0.21050046634627506, 0.15303619438782334, 0.22248888242756948], [0.009720904454297852, 0.11472757032606751, 0.0023575916566187516, 0.024385469805565663, 0.043646202102536336, 0.03451850556302816, 0.04018652856757399, 0.025418539371457882, 0.08801090705674142, 0.06245347103686072, 0.09693964864709415, 0.08233010797994211, 0.07986766198882833, 0.10693945034290664, 0.07164836162701249, 0.02668847650056705, 0.15779727953486145, 0.2525381598388776, 0.07104743723175488, 0.12167928245617077, 0.05414171391748823, 0.038953513285377994, 0.036289499985286966, 0.027359986561350524, 0.09121676237555221, 0.048053716964204796, 0.04287344454496633, 0.10663507331628352, 0.05550802263314836, 0.0829428993165493, 0.06907094953930937, 0.08691836177604273, 0.11418738329666667, 0.07387877514702268, 0.07584387829410844, 0.0918428307340946, 0.09939783471054398, 0.11173382823471911, 0.02206437140557682, 0.11270952236372977, 0.08583559058024548, 0.11956446585827507, 0.07166872615925968, 0.0399716026004171, 0.010796003698487766, 0.042631608303054236, 0.1418223578366451, 0.05410280682554003, 0.16133046650793403, 0.08596485044108704, 0.19524066330632195, 0.160265484591946, 0.14455227385042235, 0.02973006856336724, 0.09526735986582935, 0.21791527862660587, 0.07560940415714867, 0.04180570555035956, 0.09927512801368721, 0.2909110835753381, 0.11176685380632989, 0.13325399573659524, 0.0760545814409852, 0.20617493282770738, 0.31728727917652577, 0.23512698942795396, 0.6846454809419811, 0.15628849330823869, 0.6289036001544446, 5.030441768467426, 13.204963076859713, 28.084152415394783, 39.69082720577717, 56.659002900123596, 54.34727154672146, 74.1838601231575, 91.1805608868599, 79.02932971715927, 77.28767037391663, 88.55421781539917, 76.77387714385986, 89.08314183354378, 88.48712101578712, 79.76710572838783, 70.39263635873795, 55.191016271710396, 49.5043820142746, 58.87401044368744, 77.29659229516983, 102.01841533184052, 101.58499538898468, 93.38106080889702, 90.35315528512001, 88.35803434252739, 88.46236914396286, 87.65398532152176, 92.02317327260971, 95.03784030675888, 86.64601340889931, 86.54109343886375, 78.41249361634254, 79.58094611763954, 81.7448616027832, 80.91608807444572, 81.86702504754066, 77.05626279115677, 72.35584661364555, 77.77416586875916, 79.93070974946022, 55.43630450963974, 32.90866993367672, 15.422755870968103, 3.237765650264919, 0.34158569877035916, 0.2495775546412915, 0.18056139786494896, 0.3798129834467545, 0.1761606105719693, 0.1829501337488182, 0.11966953912633471, 0.1312545163091272, 0.062218455132097006, 0.08177183481166139, 0.07202399967354722, 0.07361203242908232, 0.12605817639268935, 0.09468174597714096, 0.04641122170141898, 0.051478824971127324, 0.052710333693539724, 0.053400486503960565, 0.060093834763392806, 0.18921276176115498, 0.10346990995458327, 0.05064871424110606, 0.02511208989744773, 0.051494031577021815, 0.1803186265169643, 0.04739860836707521, 0.11251970325247385, 0.08021911344258115, 0.08361927786609158, 0.055772041669115424, 0.07298001946764998, 0.05538831050216686, 0.08896896775695495, 0.12394634322845377, 0.0755759555613622, 0.14820016716839746, 0.14242959790863097, 0.07853728064219467, 0.11119713672087528, 0.061591039775521494, 0.09647364669945091, 0.05410597579611931, 0.06762587669072673, 0.01373099459669902, 0.05241239479801152, 0.04154060297878459, 0.014357354248204501, 0.026878829958150163, 0.03967137417930644, 0.07193172845290974, 0.013915762465330772, 0.12975536315934733, 0.029289197591424454, 0.11461532791145146, 0.08053014753386378, 0.10166572668822482, 0.011809605803136947, 0.03945852251490578, 0.060856603013235144, 0.02876229500543559, 0.0884874103940092, 0.03499124992231373, 0.061350198011496104, 0.015735809138277546, 0.06550058838911355, 0.07041140182991512, 0.02672521281056106, 0.026242423482472077, 0.028524061890493613, 0.04581559252983425, 0.08914103469578549, 0.12142505976953544, 0.02368790108448593, 0.08206330589018762, 0.10958496932289563, 0.16201327205635607, 0.11686835467116907, 0.04228017169225495, 0.06175948874442838, 0.10034945356892422, 0.11581366634345613, 0.1327667461009696, 0.0720038206782192, 0.013553716853493825, 0.06957935038371943, 0.09045553408213891, 0.027348268049536273, 0.03610504660173319, 0.060641595409833826, 0.039466467205784284, 0.042312789082643576, 0.03929258200514596, 0.034522702408139594, 0.08865491312462837, 0.11480121364002116, 0.03582044781069271, 0.06685251428280026, 0.06863260743557476, 0.07876843737903982, 0.11197282947250642, 0.11680594005156308, 0.0394155373214744, 0.027407213128753938, 0.029321076544874813, 0.10186531988438219, 0.06063333530619275, 0.15474144194740802, 0.07255804172018543, 0.13909984845668077, 0.17205696436576545, 0.1501846403698437, 0.17754712054738775, 0.1460480724927038, 0.25485912279691547, 0.12476789328502491, 0.15830655611352995, 0.13417342765023932, 0.11374642883311026, 0.15127858088817447, 0.10407479741843417, 0.06449562395573594, 0.17305494518950582, 0.16382243513362482, 0.11353911730111577, 0.06793467691750266, 0.2918853750452399, 0.17248245247174054, 0.29421690618619323, 0.10877426946535707, 0.6170832656789571, 0.7787953445222229, 6.252877498045564, 19.260904267430305, 34.02930960059166, 53.666785061359406, 62.63819485902786, 78.99543553590775, 74.85725238919258, 87.12995544075966, 103.25749844312668, 87.73564293980598, 88.74248251318932, 96.56008422374725, 91.61156415939331, 94.59707915782928, 90.88340163230896, 87.66041457653046, 82.40983352065086, 82.94903978705406, 85.01667603850365, 85.65984472632408, 95.8819118142128, 108.16710859537125, 104.30865123867989, 95.84784284234047, 97.45424464344978, 97.96958819031715, 94.08270835876465, 94.25412476062775, 91.06484949588776, 99.64002415537834, 92.7980200946331, 89.54786449670792, 79.61748495697975, 79.67071250081062, 80.69852694869041, 81.8559068441391, 88.97933900356293, 90.1764115691185, 83.95188197493553, 89.40341144800186, 88.46335709095001, 79.54692274332047, 60.2149622887373, 34.89153653383255, 14.047539364546537, 3.089314503595233, 0.6197654467541724, 0.5783321731723845, 0.5077703157439828, 0.3257490391843021, 0.05115933781780768, 0.13111396838212386, 0.20891071180813015, 0.08688780013471842, 0.0737801734067034, 0.18760273174848408, 0.06536721703014337, 0.17328211659332737, 0.06997838834649883, 0.09691794082755223, 0.02193944568716688, 0.08478488758555613, 0.030377625807886943, 0.10409176291432232, 0.17499295994639397, 0.14939371874788776, 0.10877085558604449, 0.09292928298236802, 0.06959128411835991, 0.06352062744554132, 0.033903550865943544, 0.116396118683042, 0.034931447662529536, 0.06286817573709413, 0.10649282587110065, 0.10457332027726807, 0.03439935375354253, 0.1609494478907436, 0.07505855246563442, 0.04644435488444287, 0.11128160054795444, 0.0964715241570957, 0.1755422679707408, 0.19314609991852194, 0.12258557093446143, 0.16107015078887343, 0.05218888589297421, 0.20388016768265516, 0.07235240744194016, 0.15386667248094454, 0.0671275171043817, 0.0812062514887657, 0.12053515791194513, 0.08709889661986381, 0.1925902461516671, 0.1280967818456702, 0.041222971194656566, 0.09224921595887281, 0.20097316039027646, 0.07878358461312018, 0.2351073522004299, 0.11128264697617851, 0.02807530003337888, 0.03275529626989737, 0.09595388357411139, 0.020727166011056397, 0.05115743420901708, 0.0721822478226386, 0.15081147314049304, 0.15811248449608684, 0.17507659998955205, 0.29685188666917384, 0.13123329088557512, 0.1237024660804309, 0.12108616545447148, 0.2353043033508584, 0.20792893948964775, 0.14426972338696942, 0.19329449976794422, 0.17743444768711925, 0.2703337330603972, 0.13580572209320962, 0.1594059291528538, 0.12537010159576312, 0.16714596538804471, 0.39412562793586403, 0.25105199427343905, 0.19774097367189825, 0.18635657674167305, 0.21055639459518716, 0.14773072907701135, 0.10229376173811033, 0.14351204998092726, 0.14578686619643122, 0.09384482604218647, 0.18860142503399402, 0.1751197929843329, 0.2484713983722031, 0.22468626295449212, 0.26413492974825203, 0.33706780057400465, 0.22559558681678027, 0.24526239634724334, 0.1451023091794923, 0.20551336754579097, 0.2008230981300585, 0.15944579732604325, 0.25090023991651833, 0.15025397180579603, 0.234574697969947, 0.2067734007141553, 0.3038944228319451, 0.12434689517249353, 0.19107032770989463, 0.3325913439039141, 0.18237278738524765, 0.43344473058823496, 0.2464912593131885, 0.41117231477983296, 0.24826843582559377, 0.43061293254140764, 0.18255298084113747, 0.18871041684178635, 0.30287732428405434, 0.1930518916924484, 0.23147238709498197, 0.19436589383985847, 0.32348216394893825, 0.38190598832443357, 0.3172629070468247, 0.31853782769758254, 0.3108058957150206, 0.5157377163413912, 0.34856310405302793, 0.7047281751874834, 0.19665289612021297, 2.115200199186802, 9.281313568353653, 20.297384150326252, 42.52814635634422, 60.08672297000885, 83.6943393945694, 90.55379211902618, 115.24325609207153, 133.3437368273735, 120.86038827896118, 121.14290311932564, 134.31166648864746, 125.73237285017967, 134.11161482334137, 138.11200976371765, 130.98875999450684, 123.00515279173851, 115.2475118637085, 108.63417953252792, 117.09985166788101, 130.0844693183899, 144.88955408334732, 138.84255856275558, 134.95060980319977, 124.48889717459679, 126.42679318785667, 121.95362001657486, 124.04280871152878, 130.95062524080276, 131.15742534399033, 125.87880179286003, 127.19081819057465, 117.2566768527031, 115.82253500819206, 116.03655472397804, 116.4439232647419, 117.57591292262077, 117.62211844325066, 109.41072106361389, 116.28038004040718, 109.24221530556679, 83.87051314115524, 57.618941590189934, 26.042531467974186, 8.200540412217379, 1.4880791190080345, 0.2891667396761477, 0.5740703456103802, 0.7094514998607337, 0.38680451922118664, 0.284348152927123, 0.34717062721028924, 0.31850069062784314, 0.21621985710226, 0.3341881191590801, 0.27507288032211363, 0.25658114289399236, 0.3056829096749425, 0.2977110561914742, 0.1901508215814829, 0.1268146772054024, 0.18726783018792048, 0.21415060095023364, 0.18015063396887854, 0.4444823367521167, 0.2821279439376667, 0.21356883138651028, 0.3282327699707821, 0.23269734636414796, 0.4727073706453666, 0.18088485550833866, 0.2145768905756995, 0.23503166798036546, 0.40315881196875125, 0.17117419454734772, 0.2941558719612658, 0.18935218162368983, 0.248336594668217, 0.2244734446867369, 0.2140469229198061, 0.37540323100984097, 0.30370844062417746, 0.2971446787705645, 0.4520314926048741, 0.23016448540147394, 0.4665799322538078, 0.19745520228752866, 0.384598589153029, 0.22894999041454867, 0.30677719158120453, 0.27713364630471915, 0.2719880692893639, 0.30335713759995997, 0.20947401673765853, 0.49032485811039805, 0.2862062829080969, 0.3546022862428799, 0.1936021793517284, 0.44761135010048747, 0.33899592992383987, 0.33084973110817373, 0.23031248449115083, 0.16940439498284832, 0.1898036597413011, 0.25523981486912817, 0.14277401380240917, 0.22218258323846385, 0.18191145354649052], [0.20749700954183936, 0.23833202838432044, 0.2657541772350669, 0.2329256755183451, 0.1843119302066043, 0.27777803828939795, 0.1631553631159477, 0.09477543469984084, 0.3208849439397454, 0.423579242778942, 0.3425688069546595, 0.4257944051641971, 0.37499522790312767, 0.35457800317090005, 0.30372767709195614, 0.32533690973650664, 0.243738025019411, 0.09202589630149305, 0.3009055566508323, 0.20661247341195121, 0.2852073224494234, 0.25391145958565176, 0.39950691105332226, 0.37004465761128813, 0.28052330191712826, 0.25759361044038087, 0.23816094850189984, 0.28775639191735536, 0.2259825574583374, 0.2624463359825313, 0.32940895529463887, 0.29428099805954844, 0.3238896623952314, 0.2830588642973453, 0.3289562452118844, 0.4496651398949325, 0.38960909529123455, 0.3201888391049579, 0.1868509955238551, 0.28589903376996517, 0.21924145199591294, 0.3074844880029559, 0.14385380898602307, 0.20224907551892102, 0.09243700158549473, 0.2188501917407848, 0.31114930228795856, 0.1331207505427301, 0.2633328759111464, 0.28603404527530074, 0.35135541984345764, 0.39992753067053854, 0.39499040809459984, 0.26998483459465206, 0.1823594732559286, 0.2696479589212686, 0.21375649084802717, 0.2543821296421811, 0.2980651200050488, 0.38013198820408434, 0.48961646331008524, 0.23773513385094702, 0.3583741479087621, 0.23292686295462772, 0.6459773308597505, 0.43925491569098085, 0.48349386372137815, 0.5260168178938329, 0.3504193638218567, 0.17050387192284688, 0.22347369755152613, 0.4956053278874606, 2.498071691952646, 3.725969628430903, 13.089188989251852, 17.864758484065533, 21.9082735106349, 28.45184538513422, 33.88685904443264, 35.77672943472862, 42.826582342386246, 42.257042303681374, 46.023521795868874, 47.42702968418598, 37.10561312735081, 13.37090777233243, 8.101118747144938, 4.5346092246472836, 11.689985319972038, 24.938895888626575, 31.898231953382492, 36.9776663929224, 36.98414124548435, 39.82101581990719, 47.402722388505936, 47.38105595111847, 34.63966324925423, 27.034586034715176, 25.197508111596107, 32.21939831972122, 47.00812116265297, 59.429506435990334, 54.549523293972015, 51.393237859010696, 44.49305132031441, 37.133112251758575, 28.595259189605713, 17.50459101051092, 10.244224648922682, 2.274046875536442, 0.6036229629535228, 0.3584649274125695, 0.9773882443550974, 0.45101374096702784, 0.35728378454223275, 0.4814197984524071, 0.6782739947084337, 0.3907456202432513, 0.32437087094876915, 0.5378269404172897, 0.627484138822183, 0.301190244499594, 0.45749928045552224, 0.3335592825897038, 0.4389871488092467, 0.35007696656975895, 0.3742383263306692, 0.14188799337716773, 0.18886126577854156, 0.2300783368991688, 0.34806731971912086, 0.2690480661112815, 0.20535759074846283, 0.25203272758517414, 0.2349432633491233, 0.29749687237199396, 0.2581091655883938, 0.304791679373011, 0.315501760924235, 0.2107559284195304, 0.18943821138236672, 0.15221837733406574, 0.1785780378850177, 0.11362549586920068, 0.3003994416212663, 0.16157280741026625, 0.22991297155385837, 0.25390623486600816, 0.24664935161126778, 0.1737361476989463, 0.16405474219936877, 0.11348551939590834, 0.1715604230412282, 0.130422227375675, 0.1016519227414392, 0.07973052794113755, 0.04537438573606778, 0.0729261914966628, 0.15894585696514696, 0.18253904330777004, 0.11027991640730761, 0.1058117940556258, 0.0644461672345642, 0.12063974878401496, 0.0872778803750407, 0.08588284312281758, 0.14305876102298498, 0.24865785555448383, 0.18159173632739112, 0.22894176741829142, 0.20929845428327098, 0.18189230613643304, 0.3847195889102295, 0.29583790514152497, 0.3524964867392555, 0.3825685183983296, 0.08883469839929603, 0.08698460587766021, 0.06037554659997113, 0.04617102189513389, 0.0739857112057507, 0.10789326595840976, 0.07384062133496627, 0.0501638172136154, 0.17632971634157002, 0.08034654762013815, 0.10570939994067885, 0.21116277377586812, 0.18867948412662372, 0.19911897863494232, 0.032346888692700304, 0.08976563360192813, 0.08041745240916498, 0.08922931316192262, 0.08197753588319756, 0.07126303855329752, 0.06371734853019007, 0.09958257011021487, 0.06700399404508062, 0.1320779143134132, 0.08237370915594511, 0.15448569785803556, 0.17886354209622368, 0.12165564505266957, 0.07929440485895611, 0.06744431026163511, 0.06632244272623211, 0.19306354341097176, 0.05191613920032978, 0.27668147056829184, 0.2541381411720067, 0.12245727586559951, 0.2227263548411429, 0.22236167831579223, 0.09457286549150012, 0.09947109210770577, 0.10271546489093453, 0.0938745416351594, 0.08723278748220764, 0.09934137953678146, 0.010656218328222167, 0.06105742075305898, 0.08923382541979663, 0.025550446844135877, 0.023906322567199823, 0.06352783369948156, 0.16194967000046745, 0.04749673513288144, 0.1882233304786496, 0.13262262102216482, 0.08211543434299529, 0.10248915437841788, 0.19660710560856387, 0.1623576137353666, 0.18428212555591017, 0.21726491977460682, 0.419987277709879, 0.15504364448133856, 0.0797274851356633, 0.11595207688515075, 0.18034106906270608, 0.15800260211108252, 0.11685220553772524, 0.06719786528265104, 0.1921980656334199, 0.36933344264980406, 1.2453563371673226, 3.092166488058865, 8.260116465389729, 13.056534491479397, 26.310802772641182, 38.45026217401028, 46.054737120866776, 50.019869953393936, 59.2794144898653, 60.550678074359894, 66.0533756017685, 72.72752746939659, 74.04018983244896, 78.4367287158966, 73.0390727519989, 46.11474730074406, 36.07386589050293, 28.02675649523735, 33.21432553231716, 48.86704221367836, 55.442885756492615, 62.202825620770454, 61.67256407439709, 62.945925146341324, 71.71385586261749, 72.2474992275238, 61.15108385682106, 53.47861535847187, 47.702191919088364, 55.95555804669857, 71.48208349943161, 84.977538138628, 78.84573116898537, 77.78653800487518, 68.85271579027176, 61.54759258031845, 51.63997381925583, 36.3063982129097, 22.41417456418276, 7.9184577986598015, 1.5538481273688376, 0.22263101855060086, 0.510379885090515, 0.35976178594864905, 0.31145215791184455, 0.1868210721295327, 0.21924534084973857, 0.1451020420063287, 0.05869914632057771, 0.13792692858260125, 0.4262111952994019, 0.08845472621032968, 0.0824992211710196, 0.06716204923577607, 0.1570015784818679, 0.06520310591440648, 0.14970255608204752, 0.052683000394608825, 0.017014355180435814, 0.04646347260859329, 0.10410536648123525, 0.02729887255554786, 0.03574327187379822, 0.120212858018931, 0.1363296783529222, 0.11374407622497529, 0.10140901780687273, 0.03553239432221744, 0.15904125262750313, 0.04886821661784779, 0.03645706208772026, 0.02446586480800761, 0.0893985822040122, 0.02950903472083155, 0.07520625469624065, 0.026462722598807886, 0.01851574590546079, 0.03256685384258162, 0.042701173515524715, 0.011736291817214806, 0.05850975765497424, 0.0668162529473193, 0.06954997617867775, 0.03245309002522845, 0.11270761504420079, 0.09277508695959114, 0.026758384956337977, 0.1101847508107312, 0.07256753378896974, 0.012882789378636517, 0.06865985167678446, 0.03490329429041594, 0.039665585427428596, 0.06766000064089894, 0.06574946761247702, 0.06530708080390468, 0.06567391697899438, 0.11406756355427206, 0.03739793464774266, 0.0726507137005683, 0.07911265289294533, 0.0697615031094756, 0.12129119859309867, 0.12161898295744322, 0.1539595893700607, 0.13181333866668865, 0.24923239659983665, 0.2744210371747613, 0.29684476205147803, 0.22409561730455607, 0.14532622997649014, 0.37087149918079376, 0.16923687740927562, 0.26445645780768245, 0.37404729751870036, 0.5131029733456671, 0.5597901181317866, 0.5776355043053627, 0.41577719268389046, 0.3249701700406149, 0.2445996881579049, 0.29600168229080737, 0.2617131534498185, 0.2732379053486511, 0.35882899537682533, 0.35188727255444974, 0.3206061042146757, 0.3057429939508438, 0.37548160180449486, 0.49022006685845554, 0.4031312634469941, 0.39170946227386594, 0.4483411187538877, 0.43135908781550825, 0.28476838662754744, 0.3052481892518699, 0.3935796150472015, 0.37120463442988694, 0.3686049801763147, 0.431956576067023, 0.40571171091869473, 0.42864879418630153, 0.39642494986765087, 0.36402441503014416, 0.18410224380204454, 0.35468603018671274, 0.20947707438608631, 0.259514941717498, 0.2856963383965194, 0.2755320322467014, 0.15081680176081136, 0.24156555096851662, 0.3875305474502966, 0.3297368064522743, 0.4422441084170714, 0.5336877750232816, 0.42558324930723757, 0.41628773091360927, 0.5986795469652861, 0.3534203418530524, 0.22126251307781786, 0.3594481840264052, 0.3792873054044321, 0.3186435392126441, 0.37153206998482347, 0.47196839936077595, 0.6686156254727393, 0.43097293353639543, 0.3662430209806189, 0.30896180716808885, 0.9015559509862214, 0.5694057990331203, 0.4284364508930594, 0.5173247249331325, 0.36674480186775327, 0.6410507170949131, 0.9715891617815942, 1.1003180011175573, 3.6626201402395964, 6.288355244323611, 16.532529070973396, 25.64050354063511, 34.46239896118641, 37.76657246053219, 50.1014743745327, 49.970749989151955, 59.69038903713226, 63.61882723867893, 64.14029225707054, 70.01457944512367, 69.01407793164253, 49.054269567131996, 43.24213944375515, 27.340315729379654, 24.71329439431429, 36.23620457947254, 46.172842383384705, 53.41221012175083, 55.737461149692535, 60.01707650721073, 71.9778048992157, 70.78787595033646, 57.91869230568409, 50.27405731379986, 43.86100083589554, 53.47860395908356, 74.01693508028984, 86.11050054430962, 78.32347199320793, 79.80087831616402, 70.1827584207058, 57.911852672696114, 46.90959244966507, 27.33575027436018, 14.729623664170504, 4.501575697213411, 0.8965622470714152, 0.4150440398370847, 0.9742264577653259, 0.7160668855067343, 0.5370450136251748, 0.5862354522105306, 0.6175948132295161, 0.38417927571572363, 0.2871114359004423, 0.5927941377740353, 0.9307661710772663, 0.30300978280138224, 0.39881885109934956, 0.5110796412918717, 0.525768999941647, 0.2704516751691699, 0.37829915061593056, 0.3523094655247405, 0.24135482555720955, 0.34950198023580015, 0.5579380143899471, 0.39492011186666787, 0.28540731640532613, 0.4236015072092414, 0.3301843215012923, 0.5519852181896567, 0.26276020507793874, 0.34011773066595197, 0.3670581663027406, 0.23270270467037335, 0.257563924533315, 0.2008702838793397, 0.19280934298876673, 0.15037684177514166, 0.3926422231597826, 0.1628918561618775, 0.21377393131842837, 0.2563349873526022, 0.2243201169767417, 0.13944111764431, 0.2255499447346665, 0.26147139142267406, 0.21378451434429735, 0.1501401115092449, 0.27018898457754403, 0.22256603610003367, 0.16499796736752614, 0.2601332397898659, 0.1789517982979305, 0.19536092091584578, 0.22086302982643247, 0.1957819116069004, 0.10517827453440987, 0.15379383810795844, 0.16147197922691703, 0.11839646642329171, 0.16021498886402696, 0.2516281383577734, 0.31020840746350586, 0.3352999751223251, 0.28398117574397475, 0.42198457522317767, 0.43087167490739375, 0.3227362164761871, 0.36321372259408236, 0.3379576950101182], [0.1970382043509744, 0.12208249128889292, 0.18818748474586755, 0.16229654982453212, 0.1924879039870575, 0.1588345051277429, 0.19670984853291884, 0.1812044539838098, 0.07086316938512027, 0.2242958635906689, 0.3092234587529674, 0.2250641051796265, 0.21133233967702836, 0.1430142915342003, 0.3184717468684539, 0.1690400598454289, 0.10903810296440497, 0.1891131210140884, 0.2696705795824528, 0.18609851715154946, 0.2670360740739852, 0.15817855048226193, 0.18762656953185797, 0.31783958547748625, 0.131522357405629, 0.20816982578253374, 0.14422143925912678, 0.3145869600120932, 0.1723003591177985, 0.14710600400576368, 0.2586209209403023, 0.23957632802193984, 0.16576687688939273, 0.21022235392592847, 0.2837071748217568, 0.17614360054722056, 0.21179662726353854, 0.22435452294303104, 0.17083650251151994, 0.1257555137271993, 0.2385083181434311, 0.19687056803377345, 0.14533642708556727, 0.21596767532173544, 0.285826392355375, 0.08447784624877386, 0.19976016454165801, 0.23445083352271467, 0.2091532456688583, 0.24592272966401652, 0.208211861026939, 0.18104624294210225, 0.27336510946042836, 0.22968799690715969, 0.3064308757893741, 0.2863508235896006, 0.1831495191436261, 0.2855645923409611, 0.33199768513441086, 0.12310666992561892, 0.09018028635182418, 0.15325659740483388, 0.29205102240666747, 0.15361475787358359, 0.17090970795834437, 0.28903763566631824, 0.2308307113707997, 0.2706068434054032, 0.28595665411558, 0.33015555585734546, 0.37844873790163547, 0.44045292015653104, 0.12333732200204395, 0.33345113683026284, 0.15671733592171222, 0.1101884689705912, 0.08199982999940403, 0.17328336340142414, 0.7607972540426999, 0.30132219835650176, 0.6680846039671451, 0.2612204564502463, 0.49133141816128045, 0.22845496307127178, 0.8356844668742269, 0.5318717693444341, 0.39362132374662906, 0.36728042468894273, 0.05798430596769322, 0.16207942710025236, 0.329214779776521, 0.12815499590942636, 0.3919323143782094, 0.04024030458822381, 0.11052097339415923, 0.12155574455391616, 0.03237354292650707, 0.05717661180824507, 0.13207469339249656, 0.09363628996652551, 0.20460665604332462, 0.28329555003438145, 0.414926097728312, 0.6983050948474556, 0.5056981206871569, 1.0397144593298435, 0.8347441954538226, 0.25463796278927475, 0.3593600168824196, 0.4531242308439687, 0.37730642419774085, 0.19397378753637895, 0.0753717462066561, 0.1648037027916871, 0.18182664091000333, 0.06833760373410769, 0.12443461702787317, 0.2417909709038213, 0.2976128848968074, 0.09171695506665856, 0.25885926908813417, 0.22472074313554913, 0.10599661109154113, 0.21276677754940465, 0.20497804158367217, 0.2070669794920832, 0.15924195904517546, 0.11042938494938426, 0.14278171729529276, 0.24328118859557435, 0.2694329438963905, 0.17061368009308353, 0.14324701420264319, 0.2747189055662602, 0.1701742989826016, 0.23758300842018798, 0.21006589435273781, 0.174634458089713, 0.22783319174777716, 0.17233878752449527, 0.28278334939386696, 0.16062110691564158, 0.2828780177515, 0.21656727127265185, 0.04982976541214157, 0.2356742342817597, 0.1449930650414899, 0.11646496772300452, 0.23635997873498127, 0.252330566290766, 0.21978731645504013, 0.22501251107314602, 0.13806308299535885, 0.16347885044524446, 0.12990909162908792, 0.04190936131635681, 0.11993404797976837, 0.1075358476373367, 0.16625568503513932, 0.2594268636312336, 0.2047484359354712, 0.14783875609282404, 0.14239793788874522, 0.10757794967503287, 0.07776129845296964, 0.1738355658017099, 0.3082457830896601, 0.2015206278883852, 0.22349061851855367, 0.12817537528462708, 0.32088684383779764, 0.10875351901631802, 0.1581989150145091, 0.14988203707616776, 0.18264202371938154, 0.15320724458433688, 0.36252913589123636, 0.3846246830653399, 0.4487763438373804, 0.28433244908228517, 0.35461938532534987, 0.369248689385131, 0.30286260007414967, 0.4144825605908409, 0.41455345053691417, 0.37347551726270467, 0.4173367121256888, 0.3133002243703231, 0.37745087582152337, 0.44524380995426327, 0.34329771471675485, 0.28497565363068134, 0.4002579941879958, 0.33186112996190786, 0.37693784397561103, 0.3793589671840891, 0.38463685428723693, 0.4144741891650483, 0.36658479482866824, 0.3828687022905797, 0.28375268331728876, 0.27670536772347987, 0.16644755989545956, 0.3515125176636502, 0.2770558692282066, 0.3952390869380906, 0.42554154060781, 0.43633996741846204, 0.45187486975919455, 0.5240228155162185, 0.47013784758746624, 0.2765748684760183, 0.37624821066856384, 0.4758142976788804, 0.4606739804148674, 0.3710924810729921, 0.3651764360256493, 0.3424938500393182, 0.3753666579723358, 0.33779160236008465, 0.43674247863236815, 0.27200656360946596, 0.40843643189873546, 0.32048560911789536, 0.4774616577196866, 0.4851600743131712, 0.3623029589653015, 0.32463543175254017, 0.34771257312968373, 0.44231250474695116, 0.6095519510563463, 0.35907521029002964, 0.37660925067029893, 0.37415541359223425, 0.49925117287784815, 0.339117671828717, 0.3231055982178077, 0.42606312199495733, 0.5669969657901675, 0.2689327363623306, 0.32960476353764534, 0.5114392563700676, 0.7249049143865705, 0.5417550390120596, 0.5811404006090015, 0.5158799118362367, 0.28015080315526575, 0.4778278333833441, 0.3409145004115999, 0.5942042183596641, 0.7232289668172598, 0.6683385965880007, 0.6970016460400075, 1.5547864395193756, 2.6993324048817158, 2.8061924083158374, 3.644897653721273, 2.0900374744087458, 3.170530158095062, 2.6726917969062924, 3.284344025887549, 1.3080549915321171, 0.7467897806782275, 0.3308175812708214, 0.14371076744282618, 0.35509409266524017, 0.6917535932734609, 0.45767184463329613, 0.9732009284198284, 0.943300926592201, 1.3210708368569613, 0.7957351324148476, 0.2830160572193563, 0.2684905647765845, 0.24363451026147231, 0.5372342909686267, 1.1478262580931187, 1.9462239788845181, 2.896034074947238, 2.74827235378325, 2.943854983896017, 2.635457357391715, 1.6445017629303038, 0.5017860524822026, 0.583874947624281, 0.3957448754226789, 0.5235300888307393, 0.5499592144042253, 0.3028256114339456, 0.3205657610669732, 0.32947479863651097, 0.5026778171304613, 0.29050854267552495, 0.5916106200311333, 0.6137754837982357, 0.3205295739462599, 0.30672307417262346, 0.5277671583462507, 0.48681108572054654, 0.422842824482359, 0.30089439474977553, 0.41011234978213906, 0.36533406819216907, 0.25815767236053944, 0.40374371339567006, 0.21842336776899174, 0.40827057673595846, 0.3353980870451778, 0.44829246355220675, 0.35758533398620784, 0.45836952282115817, 0.33506797975860536, 0.3769589209696278, 0.48337835585698485, 0.37728801893536, 0.5087337421718985, 0.3085515182465315, 0.4774074809392914, 0.5246483569499105, 0.374806098989211, 0.3416333446511999, 0.30114853580016643, 0.375020164065063, 0.29139134217984974, 0.2730391878867522, 0.3358930995455012, 0.2916302840458229, 0.43157739797607064, 0.3389540431089699, 0.38552294892724603, 0.1731520181056112, 0.19483666779706255, 0.17421217606170103, 0.2713254204718396, 0.4601675388403237, 0.33335596381220967, 0.3351846453733742, 0.2904191584093496, 0.28601958823855966, 0.24909575236961246, 0.1439822747488506, 0.34536676306743175, 0.43621427728794515, 0.4550889629172161, 0.3629622532753274, 0.2407234359998256, 0.42480613163206726, 0.18680906418012455, 0.24451506847981364, 0.352569276583381, 0.3261124837445095, 0.32855904777534306, 0.35502305428963155, 0.4678194969892502, 0.4390638571931049, 0.3346561174839735, 0.4896776162786409, 0.4029618756612763, 0.35287406179122627, 0.5774056760128587, 0.47226445691194385, 0.5341554468031973, 0.5055574094876647, 0.5117606953717768, 0.442650003824383, 0.44510796724352986, 0.518998772604391, 0.3181095788022503, 0.5996533040888608, 0.5100886069703847, 0.4926066059852019, 0.5491793062537909, 0.4730080591980368, 0.33571560750715435, 0.42895423248410225, 0.4995567596051842, 0.43348673614673316, 0.34232413570862263, 0.25152993737719953, 0.42932937329169363, 0.43948729697149247, 0.4389588284539059, 0.4710407741367817, 0.5053775722626597, 0.5216610641218722, 0.7276709878351539, 0.5596522567793727, 0.3839297953527421, 0.4985827056225389, 0.5768457998055965, 0.41447412979323417, 0.3489662683568895, 0.36022378772031516, 0.41827241191640496, 0.47141751798335463, 0.39215249475091696, 0.7505948608741164, 0.273946329834871, 0.3778524074004963, 0.43643745593726635, 0.4287686065072194, 0.5764623172581196, 0.40175555914174765, 0.4247725271852687, 0.47783955931663513, 0.3869152476545423, 0.5363197275437415, 0.45647556195035577, 0.39014050271362066, 0.489320702617988, 0.6779077299870551, 0.38909003720618784, 0.3276349848601967, 0.3814893466187641, 0.7233819086104631, 0.2937807608395815, 0.29724187043029815, 0.6367783213499933, 0.6732244219165295, 0.4329137387685478, 0.5495019920635968, 0.5761369003448635, 0.6218818144407123, 0.6350117130205035, 0.3485747112426907, 0.4827401682268828, 0.39402914873789996, 0.26257659774273634, 0.3628741158172488, 0.6261860334780067, 1.4579286868683994, 1.185757010243833, 1.3145983591675758, 0.8083823381457478, 1.412401192355901, 1.0077384626492858, 1.6391971288248897, 1.0316506982780993, 1.3918991549871862, 0.3352815698599443, 0.12724726024316624, 0.3349064290523529, 0.667023214045912, 0.28285596112255007, 0.7671441009733826, 0.4440481209894642, 0.7099036162253469, 0.43342994700651616, 0.20502708270214498, 0.1747274343506433, 0.3563527454389259, 0.34056444419547915, 0.5515569099225104, 0.8697206655051559, 1.4679253567010164, 1.2776211183518171, 1.4562274469062686, 1.3765453663654625, 1.0898042027838528, 0.5209775164257735, 0.7297657441813499, 0.6673302256967872, 0.6888522114604712, 0.4506918863626197, 0.2779813570668921, 0.28376331087201834, 0.3579159459332004, 0.45122744981199503, 0.28893987997435033, 0.7697853748686612, 0.6658200442325324, 0.2222004096256569, 0.40906969166826457, 0.6674789520911872, 0.5652555311098695, 0.4272111057071015, 0.2946001215605065, 0.3589946427382529, 0.36181055882479995, 0.26148314704187214, 0.44187920924741775, 0.4273525293683633, 0.6201595568563789, 0.4685818904545158, 0.4294329177355394, 0.38607878785114735, 0.6570923875551671, 0.37623612850438803, 0.4292123217601329, 0.5211519508156925, 0.43702541501261294, 0.4853571590501815, 0.4951743775745854, 0.45351151318755, 0.5691200424917042, 0.48832981672603637, 0.4596705373842269, 0.3985723096411675, 0.503710649209097, 0.3811151854461059, 0.31880580238066614, 0.4349362989887595, 0.39597277413122356, 0.6313922884874046, 0.3332560113631189, 0.45863723033107817, 0.361050273058936, 0.3136049205204472, 0.27369031857233495, 0.2687013050308451, 0.5091641878243536, 0.4886968235950917, 0.4104876983910799, 0.3517736349022016, 0.32078282441943884, 0.2565069874981418, 0.3464742552023381, 0.43773772835265845, 0.4661961825331673, 0.5221844860352576, 0.4617136996239424, 0.35340716131031513, 0.4651952924905345, 0.34853656485211104, 0.3208943543722853, 0.30830800475087017, 0.5329857626929879, 0.37552630878053606], [0.03188716160366312, 0.04563624141155742, 0.03284405713202432, 0.03790269525779877, 0.06783571894629858, 0.027421620070526842, 0.04594575410010293, 0.018901336152339354, 0.03084897678490961, 0.024412589737039525, 0.031776741161593236, 0.05607351318758447, 0.020745354195241816, 0.02044220542302355, 0.03287349441961851, 0.06091624942200724, 0.010954186909657437, 0.035169179827789776, 0.03388146455108654, 0.016766665248724166, 0.050569809100124985, 0.07684063457418233, 0.04255325606209226, 0.035709389121620916, 0.07813754506059922, 0.02636534354678588, 0.06861072892206721, 0.011404844954086002, 0.05322715420334134, 0.022463157038146164, 0.002595241257949965, 0.026599405791785102, 0.06526457058498636, 0.023210427389130928, 0.06018066604156047, 0.04362712148576975, 0.060811090806964785, 0.103856702480698, 0.03916090645361692, 0.050307530400459655, 0.09563047788105905, 0.017375265306327492, 0.08020752109587193, 0.0633268007368315, 0.12221990735270083, 0.03093611419899389, 0.030486890354950447, 0.02090689005854074, 0.018567345578048844, 0.058584532744134776, 0.03450803014857229, 0.06476507551269606, 0.02853131081792526, 0.025738254735188093, 0.0761774365673773, 0.06446814222726971, 0.0924803430098109, 0.030774851074966136, 0.02145351707440568, 0.04971404232492205, 0.04898677099845372, 0.05689812089258339, 0.10758983145933598, 0.03741406893823296, 0.058460924337850884, 0.02348281970625976, 0.09672207321273163, 0.029301951399247628, 0.07798964987159707, 0.05749961674155202, 0.08301594891236164, 0.11377210714272223, 0.05349054241378326, 0.07288795604836196, 0.03146194438159, 0.06848771052318625, 0.024368335471081082, 0.024033326299104374, 0.031521405253442936, 0.014576143094018335, 0.03505094085994642, 0.038476271511171944, 0.03265705447120126, 0.02655819433130091, 0.10511032349313609, 0.07966738601680845, 0.11208844865905121, 0.05926591336901765, 0.08084422443062067, 0.013394372181210201, 0.07412030710838735, 0.04375677839561831, 0.029541496260208078, 0.042593105681589805, 0.04999458156817127, 0.013862837131455308, 0.0691008432477247, 0.11109792641946115, 0.08286636904813349, 0.044038935520802625, 0.042021073095384054, 0.0662140001077205, 0.024125096570060123, 0.019944701161875855, 0.043804153392557055, 0.05112838283821475, 0.09870165566098876, 0.045573277602670714, 0.031730423725093715, 0.05512151954462752, 0.01052661986250314, 0.057495516375638545, 0.0991093619086314, 0.03489490060019307, 0.04922241030726582, 0.007372402251348831, 0.03709201395395212, 0.02233138686278835, 0.04080207698279992, 0.05593607485934626, 0.020962946327927057, 0.08774579706368968, 0.03611883570556529, 0.041861871286528185, 0.044029387790942565, 0.02922965508332709, 0.06311917750281282, 0.05962199953501113, 0.0035933855861003394, 0.06310100230621174, 0.049911204987438396, 0.02415739669231698, 0.03906230842403602, 0.057618193386588246, 0.05460292530187871, 0.025162969686789438, 0.06519385875435546, 0.03896125388564542, 0.0395940757880453, 0.07512720854720101, 0.06968131405301392, 0.04695324183558114, 0.03925736338715069, 0.042310870630899444, 0.0794064172077924, 0.06307936127996072, 0.032659280914231203, 0.01548797263239976, 0.05553638380661141, 0.008911118366086157, 0.012603361501533072, 0.034666745850699954, 0.11250517942244187, 0.055550651595694944, 0.05660679082211573, 0.0137566719786264, 0.03540194331435487, 0.05185125322896056, 0.009264613509003539, 0.031735737502458505, 0.021130894347152207, 0.02144160374882631, 0.03946809250919614, 0.04981784652045462, 0.054785860993433744, 0.047934735848684795, 0.017009867042361293, 0.03717686369782314, 0.031252287662937306, 0.042581973466440104, 0.08044142377912067, 0.03813077579252422, 0.014343316524900729, 0.021934347132628318, 0.02766217425232753, 0.023813132938812487, 0.06086680754378904, 0.05571811350819189, 0.10058144893264398, 0.06177376395498868, 0.0633915160142351, 0.02600048519525444, 0.027644394249364268, 0.03653351443063002, 0.05186660826439038, 0.03166460264765192, 0.02777600115223322, 0.03470739698968828, 0.021072236850159243, 0.06212268468516413, 0.02764808086794801, 0.021826598422194365, 0.108492676372407, 0.010313319198758109, 0.07432951111695729, 0.016726220055716112, 0.0202771573458449, 0.038147548330016434, 0.08241552917752415, 0.028670036772382446, 0.05716340529033914, 0.06633040597080253, 0.0862412410788238, 0.03088829391344916, 0.03242340782890096, 0.0096459549604333, 0.043087194208055735, 0.049087268926086836, 0.03923430114809889, 0.02035723693552427, 0.04463480960112065, 0.006805376378906658, 0.054306485544657335, 0.07258244353579357, 0.056045267047011293, 0.06867652773507871, 0.004643624506570632, 0.032579641047050245, 0.003493098010949325, 0.08610706820036285, 0.05723632129956968, 0.04757368100399617, 0.011964554178121034, 0.07984984302311204, 0.029420435275824275, 0.024754150217631832, 0.06575349747436121, 0.026887440726568457, 0.033176494762301445, 0.04403998937050346, 0.05858676660864148, 0.029834217857569456, 0.026511964097153395, 0.015810756776772905, 0.09641152151743881, 0.03634813336248044, 0.10466609615832567, 0.06901726257638074, 0.05211548377701547, 0.02418335701804608, 0.06097546538512688, 0.07888761145295575, 0.025813167121668812, 0.0699686365260277, 0.035528015650925227, 0.04999146083719097, 0.11567345980438404, 0.06347871836624108, 0.059648126843967475, 0.06043588691682089, 0.021954450057819486, 0.01929027905134717, 0.017833817946666386, 0.09890872970572673, 0.08915975166019052, 0.04219624221150298, 0.012422033487382578, 0.04936055367579684, 0.03369109625054989, 0.07376466994173825, 0.05116238433402032, 0.08332860830705613, 0.1221914756752085, 0.030195380313671194, 0.054952124337432906, 0.036051367060281336, 0.09374673638376407, 0.0625386844330933, 0.0343085742497351, 0.048814169713295996, 0.039050267077982426, 0.0377279120584717, 0.1304310589330271, 0.05144043367181439, 0.031219462471199222, 0.056897653339547105, 0.03254002149333246, 0.05821984137583058, 0.04905402813164983, 0.09946230507921427, 0.05937796653597616, 0.060587440893868916, 0.10091745629324578, 0.0458384655212285, 0.03021633114258293, 0.013039950281381607, 0.06853708560811356, 0.044984528140048496, 0.02178706792619778, 0.04369457899883855, 0.04395019692310598, 0.04762140481034294, 0.012001129998679971, 0.019290305026515853, 0.06097875681007281, 0.029101974141667597, 0.01862725544924615, 0.032456481640110724, 0.049178100380231626, 0.06772048567654565, 0.057726502418518066, 0.011819390092568938, 0.03427377865591552, 0.11872946808580309, 0.02740850075497292, 0.02036161004070891, 0.04572613775962964, 0.023047101094562095, 0.014879868886055192, 0.0257249962669448, 0.034869018199970014, 0.04445240454515442, 0.028764206035702955, 0.046742438498768024, 0.01439390780433314, 0.07392305167741142, 0.027516550035215914, 0.011986334357061423, 0.055457998169003986, 0.05132696300279349, 0.1060979142494034, 0.04650060225685593, 0.03225984961318318, 0.032235529433819465, 0.024543847830500454, 0.040852416859706864, 0.04154760143137537, 0.025404321677342523, 0.061463360689231195, 0.020015620793856215, 0.04404022314702161, 0.04909313931420911, 0.01058713272868772, 0.008251777671830496, 0.027147053260705434, 0.03865098791720811, 0.00988850088106119, 0.03770078285015188, 0.004910254510832601, 0.022769122260797303, 0.04327852358983364, 0.11171541555086151, 0.04650402726838365, 0.019732229848159477, 0.030059075616009068, 0.01539188027891214, 0.002675754540177877, 0.02666369062353624, 0.012165646512585226, 0.027712822120520286, 0.009897493855532957, 0.03543961844115984, 0.1465611340245232, 0.14759966579731554, 0.3548617707565427, 0.14280836039688438, 0.25121559330727905, 0.11701883995556273, 0.13144455064320937, 0.12994774268008769, 0.11615759984124452, 0.09467253592447378, 0.09785923641175032, 0.0823963966104202, 0.19498526060488075, 0.22833115799585357, 0.18516860611271113, 0.09581850841641426, 0.21349454240407795, 0.1524184603476897, 0.1431768070324324, 0.06299526852671988, 0.12423614447470754, 0.10078799605253153, 0.16312684980221093, 0.12169768029707484, 0.17154422937892377, 0.14205033075995743, 0.17589444672921672, 0.17885514098452404, 0.1386131183244288, 0.12338081927737221, 0.16748432535678148, 0.11542386069777422, 0.15837293380172923, 0.07252516457810998, 0.14383996051037684, 0.11351207343977876, 0.16445422545075417, 0.20785245375009254, 0.119864367734408, 0.19135652953991666, 0.205249504360836, 0.15123728779144585, 0.10818089271197096, 0.25989334797486663, 0.13880990620236844, 0.10144477448193356, 0.1351431623334065, 0.13635439187055454, 0.0985094097268302, 0.14716138306539506, 0.12051011784933507, 0.14334356761537492, 0.17243712209165096, 0.10811826286953874, 0.1438845635857433, 0.1786806620657444, 0.15248562471242622, 0.08244897777331062, 0.1707023222115822, 0.1744251576019451, 0.13485295290593058, 0.18774112744722515, 0.20526664797216654, 0.13069089967757463, 0.16832430294016376, 0.13992070831591263, 0.18407196417683735, 0.23518080997746438, 0.16921731439651921, 0.13411827123491094, 0.171466140600387, 0.19872501696227118, 0.15700641728471965, 0.11000246449839324, 0.1431148377014324, 0.15119731571758166, 0.1858557458035648, 0.12715605029370636, 0.1517581270309165, 0.1548591020400636, 0.11832432224764489, 0.11843093176139519, 0.1550315326312557, 0.1328547202865593, 0.27335721300914884, 0.24860960111254826, 0.2990457642590627, 0.16161525825737044, 0.17374604794895276, 0.12152593248174526, 0.20853059861110523, 0.14271676453063264, 0.15461679082363844, 0.16282610187772661, 0.14576755551388487, 0.10482963582035154, 0.1779915185761638, 0.29198363539762795, 0.16431360330898315, 0.15891888731857762, 0.14055319625185803, 0.15844843990635127, 0.0911701109725982, 0.21990341803757474, 0.17549444397445768, 0.1325293182162568, 0.2986003569094464, 0.11109411920187995, 0.09436337946681306, 0.14674043690320104, 0.1564712991239503, 0.27005147945601493, 0.287788690184243, 0.11440722228144296, 0.23698348668403924, 0.07421532427542843, 0.11719248766894452, 0.12114797893445939, 0.17866234586108476, 0.1592390943551436, 0.11595854099141434, 0.1476937552797608, 0.1512913903570734, 0.18930303660454229, 0.16521632205694914, 0.08816297311568633, 0.11356972347130068, 0.18115110840881243, 0.09300785415689461, 0.1478333681006916, 0.17178429930936545, 0.10853225510800257, 0.07304531362024136, 0.2063057734631002, 0.20512823743047193, 0.14862421550787985, 0.0981328143097926, 0.15256423299433663, 0.16095952625619248, 0.20273835863918066, 0.15939779521431774, 0.19643915758933872, 0.11044193466659635, 0.18402630725177005, 0.18636773864272982, 0.14741552411578596, 0.0711795840470586, 0.11429581107222475, 0.15077047690283507, 0.14853088301606476, 0.16739210608648136, 0.1333799827261828, 0.25125970656517893, 0.1422521355561912, 0.13434357242658734, 0.11325482279062271, 0.15264162415405735, 0.2182067497051321, 0.15603840438416228, 0.12584240437718108, 0.09989766374928877, 0.08163820370100439, 0.12580272916238755, 0.10005083560827188, 0.14431447489187121, 0.2633992239134386, 0.11868266083183698, 0.12658900493988767, 0.11113967964774929, 0.16432014905149117, 0.17751695966580883, 0.11763100046664476, 0.11277846046141349, 0.12107894435757771, 0.12418756348779425, 0.093766982172383], [0.01559357282530982, 0.04742509190691635, 0.02916915520472685, 0.021329012524802238, 0.053400326942210086, 0.02788721198157873, 0.05500964449311141, 0.014240407545003109, 0.054370358484447934, 0.062157083229976706, 0.08180169883416966, 0.03425332506594714, 0.04201226380246226, 0.05266828360618092, 0.0434924587898422, 0.027822986521641724, 0.02071104656351963, 0.010236608031846117, 0.016245013357547577, 0.03135268168989569, 0.029453605566232, 0.007610217908222694, 0.0376962854352314, 0.03678967783343978, 0.09829085465753451, 0.026723739647422917, 0.02876728780393023, 0.030937290503061377, 0.0782312783121597, 0.04795967572135851, 0.03858960859361105, 0.10690030205296353, 0.04761088115628809, 0.016731183168303687, 0.01873505796538666, 0.019059235492022708, 0.06480818687123246, 0.024047260121733416, 0.018790915710269473, 0.038867951079737395, 0.04831198064493947, 0.04210670209431555, 0.06442463010898791, 0.009034123777382774, 0.03675970991025679, 0.10855111308046617, 0.037630475490004756, 0.01544707936773193, 0.1617665821686387, 0.06485061545390636, 0.059337330239941366, 0.056612791086081415, 0.006161554920254275, 0.04774693908984773, 0.05261230711766984, 0.0588352599152131, 0.03306873491965234, 0.07327673010877334, 0.1085175754269585, 0.03556641808245331, 0.04894843907095492, 0.014162140651023947, 0.06891700584674254, 0.015312585510400822, 0.0667738243646454, 0.03432916142628528, 0.07005419131019153, 0.01134623105826904, 0.026503141816647258, 0.07897560790297575, 0.052961309484089725, 0.024462256114929914, 0.02824032213538885, 0.01672966176556656, 0.041003095102496445, 0.035671172227011994, 0.022955527492740657, 0.0563307898119092, 0.09371765903779306, 0.08858244982548058, 0.04850440840527881, 0.03152046643663198, 0.03742201362911146, 0.01761276369506959, 0.04518952417129185, 0.009170766152237775, 0.038983143531368114, 0.0690525071695447, 0.07650803367141634, 0.0363693216786487, 0.08239347254857421, 0.07779161518556066, 0.025572924641892314, 0.01482193219999317, 0.0765654759015888, 0.07315259106690064, 0.052465131811914034, 0.015349555596912978, 0.048705433946452104, 0.008491581356793176, 0.09383240991155617, 0.09072795422980562, 0.059752246452262625, 0.0529969474155223, 0.025571974692866206, 0.07968040328705683, 0.11044235769077204, 0.06373756463290192, 0.02533398277591914, 0.023433257229044102, 0.0461321110924473, 0.029728751251241192, 0.05099973895994481, 0.04377841571113095, 0.030584165506297722, 0.017175032007799018, 0.009630629610910546, 0.04167498365859501, 0.0900466478196904, 0.04209432678180747, 0.041852817084873095, 0.03478200509562157, 0.02603728829853935, 0.025204017874784768, 0.0508940385770984, 0.05026047452702187, 0.060495232755783945, 0.01838510564994067, 0.04770233601448126, 0.02554061709815869, 0.020532699199975468, 0.028025268147757743, 0.08412849507294595, 0.02387811167864129, 0.010404198892501881, 0.06110899259510916, 0.03857128867821302, 0.017184073221869767, 0.026682823190640192, 0.03510970782372169, 0.0352502000896493, 0.05164781570783816, 0.04398481069074478, 0.05417521075287368, 0.005302154868331854, 0.03139051637845114, 0.04071869669132866, 0.03767282243643422, 0.03673141553008463, 0.027199395080970135, 0.01364929248666158, 0.04500855146034155, 0.005503999091160949, 0.03277320429333486, 0.057322885404573753, 0.06244376374525018, 0.018664835952222347, 0.08089440103503875, 0.03636552188254427, 0.036281443972256966, 0.03562285470252391, 0.024278094024339225, 0.019547826559573878, 0.011977818212471902, 0.04094875133887399, 0.030753983737668023, 0.0568754334381083, 0.009972753196052508, 0.056629968094057404, 0.08278480701847002, 0.02756684167252388, 0.03344017612107564, 0.06755247828550637, 0.046768614047323354, 0.030876837008690927, 0.04004274487670045, 0.025440343670197763, 0.041257410557591356, 0.029565467630163766, 0.025428320877836086, 0.05628726285067387, 0.08402817155001685, 0.033568333892617375, 0.02478778249496827, 0.054934646759647876, 0.00822372912807623, 0.03639775706687942, 0.024151205325324554, 0.05695256855688058, 0.03694761799124535, 0.021629131479130592, 0.062415769934887066, 0.10389973962446675, 0.04166470862401184, 0.04369542504718993, 0.05216558616666589, 0.04935240118356887, 0.017324409636785276, 0.041115671483566985, 0.04540862100839149, 0.04535275584203191, 0.033054129453375936, 0.0201701489277184, 0.01470220986448112, 0.0690896887681447, 0.02931347509729676, 0.03962300099374261, 0.05924327786487993, 0.039416008585249074, 0.022580464610655326, 0.018104184200637974, 0.008050093474594178, 0.10375615631346591, 0.06905520858708769, 0.019213876803405583, 0.029084761881676968, 0.03434123245824594, 0.026487027935218066, 0.01140747679528431, 0.02804751773510361, 0.018071307058562525, 0.014936618135834578, 0.013294211930769961, 0.06412567818188109, 0.1061860888148658, 0.04342696425737813, 0.03381699418241624, 0.05435003848106135, 0.07434636529069394, 0.031284281649277546, 0.07279858662514016, 0.016122963461384643, 0.02970746274513658, 0.061750026361551136, 0.09285552834626287, 0.01647337405302096, 0.053345163105404936, 0.01942304370459169, 0.03409024553548079, 0.06040663516614586, 0.04329192677687388, 0.029620113818964455, 0.013863788008166011, 0.04613389966834802, 0.022719309308740776, 0.0540468637336744, 0.009157398217212176, 0.05137720268976409, 0.06657049816567451, 0.1180051096889656, 0.03227155699278228, 0.11172213198733516, 0.0597420048143249, 0.06355589430313557, 0.010952160846500192, 0.08166767438524403, 0.021280889814079273, 0.02045186447503511, 0.0279258834416396, 0.03789563001191709, 0.04482171578274574, 0.12787257903255522, 0.12977831036550924, 0.07899931209976785, 0.041999662134912796, 0.10035093044280075, 0.08967820118414238, 0.06704525003442541, 0.09996317312470637, 0.047339028751594014, 0.008271809165307786, 0.0641946608084254, 0.047133464977378026, 0.06665657987468876, 0.01678110744251171, 0.06736848503351212, 0.14217520452803, 0.03583092322514858, 0.08878197622834705, 0.07786821966874413, 0.023845906180213206, 0.03626536163210403, 0.0644311610085424, 0.08573203871492296, 0.056910793064162135, 0.03065085860725958, 0.05601904325885698, 0.05985697833239101, 0.05323414894519374, 0.04095472933840938, 0.04139387296163477, 0.017602546176931355, 0.04941053361108061, 0.03312898246804252, 0.09738471460877918, 0.07641129472176544, 0.051057645032415166, 0.05367502919398248, 0.03395202424144372, 0.015018965914350701, 0.019428259147389326, 0.02158801093173679, 0.04279323693481274, 0.06465779806603678, 0.03345152726978995, 0.04835498439206276, 0.058902064338326454, 0.025152811540465336, 0.04707345491624437, 0.04588440075167455, 0.021277414707583375, 0.04739885698654689, 0.012089014198863879, 0.04266823329089675, 0.00542632916221919, 0.0203394142590696, 0.05014172347728163, 0.0427227329055313, 0.05551245696551632, 0.0098244934270042, 0.017150988278444856, 0.03693666018079966, 0.031979607229004614, 0.06214317909325473, 0.062422768387477845, 0.058054557666764595, 0.03361090348334983, 0.018469736460247077, 0.037799421697854996, 0.05354409950086847, 0.01815325129427947, 0.04185664656688459, 0.020546915038721636, 0.051089639018755406, 0.053421522679855116, 0.031122487889660988, 0.00803575796453515, 0.05339549185009673, 0.06330709671601653, 0.04338305509008933, 0.04369456415588502, 0.04443845959031023, 0.07306981191504747, 0.009658765357016819, 0.027406279878050555, 0.03790321105043404, 0.04202624586469028, 0.017720664545777254, 0.002832734080584487, 0.03516527242027223, 0.05146073512150906, 0.06131655645731371, 0.10026539792306721, 0.20009243889944628, 0.10252215768559836, 0.15188487101113424, 0.1541508111404255, 0.2026675725937821, 0.2280228104791604, 0.13581660197814927, 0.18984947993885726, 0.13383059995248914, 0.18597597372718155, 0.11392585787689313, 0.1798478970886208, 0.17547452473081648, 0.13828071038005874, 0.11646021055639721, 0.1932145853061229, 0.0934108551882673, 0.1661742862779647, 0.16675550665240735, 0.09493544916040264, 0.09502501154202037, 0.12402429842040874, 0.192808793799486, 0.15025719272671267, 0.09084176257601939, 0.09771356024430133, 0.13611173926619813, 0.18675136961974204, 0.10963747627101839, 0.13259658648166806, 0.20806663756957278, 0.164083685958758, 0.06647134723607451, 0.1336712163174525, 0.11095775698777288, 0.13823379180394113, 0.17307352856732905, 0.14087021205341443, 0.1763832548749633, 0.1347669676761143, 0.08787982893409207, 0.1368585624732077, 0.12536965630715713, 0.1329286233521998, 0.17848743649665266, 0.08042447312618606, 0.1711216356488876, 0.25773322326131165, 0.08892845391528681, 0.17655264266068116, 0.1623952406225726, 0.1941839192295447, 0.12274385619093664, 0.1497644215123728, 0.12477883254177868, 0.09658097609644756, 0.3040509863058105, 0.3963464603293687, 0.10629572629113682, 0.1226820278679952, 0.124583380529657, 0.2574694936629385, 0.11341522316797636, 0.15080804441822693, 0.11863387204357423, 0.29552706400863826, 0.08475721289869398, 0.09480468273977749, 0.1293034991249442, 0.16475562646519393, 0.19928195426473394, 0.11203788613784127, 0.11257534206379205, 0.1576402856153436, 0.1608097756979987, 0.13814394740620628, 0.1720023126108572, 0.1327049994142726, 0.14302742754807696, 0.1636855979450047, 0.16666275303578004, 0.12403632121277042, 0.10978736041579396, 0.2030649481457658, 0.23538522713351995, 0.2053050318500027, 0.15733000851469114, 0.2384884879575111, 0.33043362374883145, 0.2986386517295614, 0.12986472604097798, 0.2453094781958498, 0.0877449064864777, 0.2897310984553769, 0.14724077802384272, 0.1392501185182482, 0.1368438234203495, 0.19931643444579095, 0.17975103197386488, 0.26037785166408867, 0.15479634603252634, 0.19060053338762373, 0.21016137907281518, 0.09395727625815198, 0.12299709182116203, 0.3366974095115438, 0.27543380158022046, 0.20052647654665634, 0.14639548666309565, 0.24525907152565196, 0.17635155032621697, 0.12321062997216359, 0.07933172004413791, 0.11786814633524045, 0.16474468720844015, 0.09041185869136825, 0.25980749633163214, 0.25947106594685465, 0.15179668902419508, 0.11360303105902858, 0.18590490566566586, 0.15090490953298286, 0.11740939517039806, 0.13804632530082017, 0.18228586704935879, 0.16236420400673524, 0.14328455203212798, 0.11402277494198643, 0.16054641717346385, 0.12968925264431164, 0.11672359134536237, 0.23987905005924404, 0.16785189625807106, 0.06510399951366708, 0.15489901474211365, 0.1709085056791082, 0.14981781161623076, 0.04957976925652474, 0.1211761953891255, 0.1892840227810666, 0.17900711798574775, 0.132216859201435, 0.22048563288990408, 0.22934580745641142, 0.12311047714320011, 0.12490266730310395, 0.18546939856605604, 0.16989047202514485, 0.13056035590125248, 0.09307417989475653, 0.12302383140195161, 0.23599542095325887, 0.09531016694381833, 0.13706404832191765, 0.2875864104134962, 0.0887278068694286, 0.15252814977429807, 0.11295246440568008, 0.10208984182099812, 0.11089565407019109, 0.09768691714270972, 0.16854516608873382, 0.13629570283228531, 0.11843162195873447, 0.1456623783451505, 0.1495724724372849, 0.1189721206901595, 0.09822834355873056, 0.19230110541684553, 0.26425494987051934, 0.18944446026580408, 0.1884223596425727, 0.17399448930518702, 0.1064774782571476, 0.17348015127936378], [0.03231368500564713, 0.05069037841167301, 0.043671561288647354, 0.036826095019932836, 0.04211061321257148, 0.07163534435676411, 0.012910514160466846, 0.030438680441875476, 0.03028792798431823, 0.02916743713285541, 0.007393583146040328, 0.012788656295015244, 0.04158438227022998, 0.048380781445303, 0.03283689911768306, 0.02231281832791865, 0.03900555268046446, 0.052671122321044095, 0.005224343931331532, 0.04868176685704384, 0.050974880723515525, 0.019284618319943547, 0.02159741023206152, 0.03971029982494656, 0.03187324262398761, 0.07996609303518198, 0.04522964467469137, 0.11676426845951937, 0.01859367697761627, 0.0418295767303789, 0.030423074931604788, 0.11973510787356645, 0.014827045597485267, 0.017798749613575637, 0.0446794831805164, 0.0892908000969328, 0.021222516188572627, 0.0447744075790979, 0.09573675342835486, 0.05604842859611381, 0.01907336412841687, 0.05195918376557529, 0.05384318872529548, 0.05258950091956649, 0.044128928348072805, 0.08771323904511519, 0.06637822996708564, 0.030177568769431673, 0.04050434959935956, 0.055118565796874464, 0.028810569856432267, 0.024500311592419166, 0.003134888374916045, 0.04479581482883077, 0.03378164939931594, 0.05538175733818207, 0.04080758000782225, 0.041021296274266206, 0.018733744363998994, 0.04677005381381605, 0.07360578354564495, 0.021518254616239574, 0.058630768544389866, 0.009025040817505214, 0.061793724016752094, 0.03275789749750402, 0.012424334145180183, 0.029904818366048858, 0.006178052399263834, 0.06271011312492192, 0.06332657809252851, 0.026518285339989234, 0.06008731870679185, 0.011963623710471438, 0.028749203520419542, 0.07514861950767227, 0.08189250060240738, 0.013531457061617402, 0.022725495109625626, 0.03041162359295413, 0.044825701115769334, 0.09335129783721641, 0.020611199870472774, 0.030793608857493382, 0.07119298723409884, 0.1426205228199251, 0.028718888643197715, 0.025508589715173002, 0.0411622560932301, 0.08028009571717121, 0.029217396659078076, 0.0887389390845783, 0.033015396766131744, 0.020738261118822265, 0.02573200770711992, 0.03073325369769009, 0.031105798843782395, 0.008053465608099941, 0.08896674873540178, 0.08683203515829518, 0.08028328695218079, 0.06362855056067929, 0.041177815219271, 0.08857223787344992, 0.05588572385022417, 0.03261218793340959, 0.05239891368546523, 0.04152366345806513, 0.08543545423890464, 0.034018067963188514, 0.06810843595303595, 0.016211754009418655, 0.012613813723874046, 0.031569626298733056, 0.01674848077527713, 0.03474939141597133, 0.025439247147005517, 0.023096702534530777, 0.03514423995511606, 0.02710254666453693, 0.013789777331112418, 0.038499337460962124, 0.04461050055397209, 0.006371585495799081, 0.04223951313178986, 0.07800006220350042, 0.051878872254746966, 0.04058570382767357, 0.105172136973124, 0.0727833503333386, 0.01648387358727632, 0.028856549615738913, 0.057211507592001, 0.09976566536352038, 0.023177809998742305, 0.10850725215277635, 0.016071475110948086, 0.0257373456042842, 0.011182345369888935, 0.021709875290980563, 0.021791932704218198, 0.04905281472019851, 0.007589679898956092, 0.06171720859128982, 0.03493093558063265, 0.01936799118993804, 0.04687567627115641, 0.04020395048428327, 0.055078953664633445, 0.020520292346191127, 0.08776292583206668, 0.03427577132242732, 0.06331597280222923, 0.05380208858696278, 0.014630132482125191, 0.06969954119995236, 0.04202109164907597, 0.05054992696386762, 0.0572263357025804, 0.014158417852740968, 0.037743957291240804, 0.038392902351915836, 0.02864914531528484, 0.03479148603219073, 0.023490454550483264, 0.09152506536338478, 0.060988163531874306, 0.027367369075363968, 0.07011834255536087, 0.06477553979493678, 0.04635829543985892, 0.04210519553453196, 0.028911967638123315, 0.01646793225518195, 0.012342385271040257, 0.02598729908640962, 0.026489308183954563, 0.01460544215660775, 0.041438702392042615, 0.015081216333783232, 0.011665429701679386, 0.027028741933463607, 0.017863824832602404, 0.026176914107054472, 0.07940042807604186, 0.03839944438368548, 0.0229242237037397, 0.0323849348933436, 0.052458411664702, 0.1058996791834943, 0.05848794593475759, 0.04645014363632072, 0.02969371260405751, 0.09891710855299607, 0.036062610597582534, 0.04210247556329705, 0.035288791768834926, 0.07951516410685144, 0.04098029632586986, 0.013226410246716114, 0.06898980311234482, 0.018575537033029832, 0.04720606557384599, 0.0610033256089082, 0.014298487094492884, 0.04189485975075513, 0.04246586075169034, 0.01915256983920699, 0.02177553495130269, 0.03083520809013862, 0.029618024673254695, 0.11116313893580809, 0.036519187269732356, 0.05938767753832508, 0.1703519542934373, 0.006269453915592749, 0.018298873656021897, 0.02506103384803282, 0.04547928459942341, 0.02570424767327495, 0.035178096732124686, 0.06360056417179294, 0.018389645738352556, 0.020230483678460587, 0.05822235354571603, 0.05695081337762531, 0.016425566755060572, 0.031050150755618233, 0.010350539760111133, 0.04796904162503779, 0.008357386213901918, 0.05701851951016579, 0.038385187726817094, 0.014168370980769396, 0.08272718667285517, 0.014488805300061358, 0.05313915775332134, 0.045370994121185504, 0.042528212288743816, 0.08065810863627121, 0.017556583115947433, 0.0590732666751137, 0.05297903568134643, 0.04306550123146735, 0.05577940377406776, 0.03458192208199762, 0.08861221736879088, 0.03619418966991361, 0.031038573251862545, 0.03680614237964619, 0.07887072759331204, 0.03592387722164858, 0.02984212729643332, 0.021234989835647866, 0.05687478776962962, 0.06551655198563822, 0.024096705710690003, 0.10819591378094628, 0.01599003553565126, 0.029819898118148558, 0.01779922458808869, 0.06099473524955101, 0.07251315662870184, 0.052667255731648766, 0.03410951539990492, 0.03000751861691242, 0.04289215779863298, 0.06655322838923894, 0.057764496668823995, 0.04001758235972375, 0.05383107316447422, 0.017437789392715786, 0.09041032986715436, 0.08595262726885267, 0.055820941779529676, 0.03857463947497308, 0.04036285543406848, 0.019036054509342648, 0.047067180057638325, 0.09865360902040266, 0.023850668912928086, 0.0536172158899717, 0.07164802023908123, 0.04263674396497663, 0.009637820094212657, 0.028604636863747146, 0.01303841589106014, 0.05956007102213334, 0.032571607298450544, 0.08120911617879756, 0.03568182946764864, 0.029458488897944335, 0.02206008735811338, 0.05103653464175295, 0.028881135112897027, 0.04911563381028827, 0.021676346914318856, 0.0393789976806147, 0.06385857923305593, 0.02270441997097805, 0.03112046924798051, 0.04581715475069359, 0.031511775887338445, 0.06882042274810374, 0.047487951815128326, 0.0837646794389002, 0.018594719695101958, 0.007899948650447186, 0.02260907625895925, 0.05914046443649568, 0.03862072313495446, 0.07519689621403813, 0.037207399363978766, 0.03463955355982762, 0.021208632460911758, 0.06529396705445834, 0.048663721536286175, 0.018111164099536836, 0.04326824484451208, 0.0709241813456174, 0.05368612430174835, 0.06540400529047474, 0.031124185552471317, 0.02710871020099148, 0.015466384484170703, 0.032399265764979646, 0.06738822616171092, 0.034437956564943306, 0.01457192120142281, 0.04237157088937238, 0.030501933688356075, 0.016254525835392997, 0.07474639030988328, 0.021474043023772538, 0.03708075928443577, 0.08646308386232704, 0.01933052386448253, 0.04907778056804091, 0.07305801918846555, 0.04280356391973328, 0.06166133229271509, 0.015704570287198294, 0.04603244808095042, 0.022510750968649518, 0.025716743584780488, 0.048417061334475875, 0.048634135819156654, 0.01692139747319743, 0.0359075611049775, 0.026865176296269055, 0.004690479536293424, 0.02316168127435958, 0.18732310534687713, 0.13077504438115284, 0.10630256147123873, 0.14952387660741806, 0.08257776265963912, 0.1367754567763768, 0.11264002023381181, 0.2057289911317639, 0.17574776866240427, 0.11736726344679482, 0.08781188531429507, 0.18754200922558084, 0.10497412455151789, 0.15418359922477975, 0.19095287541858852, 0.15925052342936397, 0.1196911875740625, 0.24584441824117675, 0.13391323067480698, 0.2171616128180176, 0.1794059036183171, 0.20803756022360176, 0.1292929012561217, 0.11219686901313253, 0.10620145869324915, 0.18648799625225365, 0.27669459173921496, 0.19695560331456363, 0.14757303753867745, 0.10994117052177899, 0.114319923450239, 0.1722239624359645, 0.11009354086127132, 0.09772241406608373, 0.08793841407168657, 0.2166269696317613, 0.09429063415154815, 0.11895774528966285, 0.2116169681539759, 0.12884170515462756, 0.11660138188744895, 0.2234875608701259, 0.09695998349343427, 0.10700717873987742, 0.12493818649090827, 0.12164664280135185, 0.11689226666931063, 0.21960615820717067, 0.10575027743470855, 0.12897500972030684, 0.08792783104581758, 0.06499332303064875, 0.07084562501404434, 0.08430282556219026, 0.11964079574681818, 0.16750137991039082, 0.13767354452284053, 0.13505609356798232, 0.1254465279635042, 0.11782430025050417, 0.23073513759300113, 0.1597090222639963, 0.09581746940966696, 0.2022672284510918, 0.15382583951577544, 0.17039842758094892, 0.2202978398418054, 0.12350165576208383, 0.11919562588445842, 0.11730393598554656, 0.1611120969755575, 0.14701990003231913, 0.13505968556273729, 0.11155129701364785, 0.15513112884946167, 0.11738394692656584, 0.19520685105817392, 0.12428955684299581, 0.12462946790037677, 0.1871665270300582, 0.1839206402655691, 0.20176648657070473, 0.1449062189203687, 0.09632541754399426, 0.20754973171278834, 0.27294434141367674, 0.15905622916761786, 0.14220653800293803, 0.19469303253572434, 0.12630073993932456, 0.15244094742229208, 0.1672068066545762, 0.1253014529356733, 0.12945581751409918, 0.14391270582564175, 0.15239429601933807, 0.06681010796455666, 0.15941718011163175, 0.2039953341591172, 0.2524392760824412, 0.18835644208593294, 0.1961273665074259, 0.2183558768592775, 0.360978611279279, 0.12815419438993558, 0.14872741856379434, 0.08787383980234154, 0.21614347526337951, 0.13082850869977847, 0.1277187466621399, 0.123101074132137, 0.15159559668973088, 0.09310581022873521, 0.16033665655413643, 0.16935271181864664, 0.23109690489945933, 0.09138508889009245, 0.16310462990077212, 0.08219562339945696, 0.09918612224282697, 0.11495483078761026, 0.10937817729427479, 0.1605912874219939, 0.10260297756758519, 0.0875850924057886, 0.14600149530451745, 0.1002399719436653, 0.17515985411591828, 0.2506773581262678, 0.18466448003891855, 0.10921191395027563, 0.1311766353319399, 0.06666957488050684, 0.2586331812199205, 0.12153429648606107, 0.1614566019270569, 0.0888977586873807, 0.08587267569964752, 0.10376885446021333, 0.14596468477975577, 0.17516267427708954, 0.13446852040942758, 0.2183849096763879, 0.23250665894011036, 0.15306602872442454, 0.13131005864124745, 0.12984124448848888, 0.09388879829202779, 0.14129921793937683, 0.11443914205301553, 0.13817364815622568, 0.12992176751140505, 0.08436788964900188, 0.15023328072857112, 0.09444437746424228, 0.09409496691660024, 0.13199040025938302, 0.1087285605899524, 0.10511093205423094, 0.17332260817056522, 0.10131325107067823, 0.1712598087033257, 0.09124878604779951, 0.12902270013000816, 0.15943552600219846, 0.15292524331016466, 0.2379441077937372, 0.08880535388016142, 0.17047556641045958, 0.15084230195498094, 0.2018600862356834, 0.1806853958987631, 0.15965759143000469, 0.08578418201068416, 0.09046249542734586, 0.12365073096589185], [0.03324943674670067, 0.07877210358856246, 0.017143776458397042, 0.021859701919311192, 0.07581010315334424, 0.02895353718486149, 0.05599979565886315, 0.059035884696641006, 0.04440047647221945, 0.07247386733070016, 0.04856206585827749, 0.00846431856189156, 0.11020293342880905, 0.0520716785104014, 0.030793987352808472, 0.012536399372038431, 0.02912521449616179, 0.07487124181352556, 0.03334893277497031, 0.017376831237925217, 0.029042548521829303, 0.03451009702985175, 0.07230675051687285, 0.029392896030913107, 0.061435682291630656, 0.047399539762409404, 0.040273730919579975, 0.05756483296863735, 0.02407617233984638, 0.07973603467689827, 0.02495346881914884, 0.021051939111202955, 0.04430183762451634, 0.06750527769327164, 0.03342888805491384, 0.014848688479105476, 0.04706270119640976, 0.04191235588223208, 0.06888125659315847, 0.0346320764219854, 0.05684665295120794, 0.02984140555781778, 0.031421141102327965, 0.04504629338043742, 0.03216121447621845, 0.022413110309571493, 0.020680651905422565, 0.011239366431254894, 0.054575109606957994, 0.04410901652590837, 0.05365520642953925, 0.0597377337544458, 0.08860274756443687, 0.03243195365939755, 0.07825516804587096, 0.08333286081324331, 0.011037533804483246, 0.050892428116640076, 0.014433434589591343, 0.03887437065714039, 0.06091378549172077, 0.07137770036933944, 0.07245525426696986, 0.040044340494205244, 0.0658679218031466, 0.03902062198903877, 0.05192175354750361, 0.027699372549250256, 0.004390110570966499, 0.01022231890601688, 0.050212980786454864, 0.030680453601235058, 0.06864900889922865, 0.0270435496349819, 0.05872406021808274, 0.030807889634161256, 0.011693809428834356, 0.04103722647414543, 0.02497790403140243, 0.0809498988382984, 0.03462888518697582, 0.07005247694905847, 0.03718071544426493, 0.050011869898298755, 0.06934927718248218, 0.12020849419059232, 0.020431010125321336, 0.0050663852198340464, 0.024220922678068746, 0.047502924644504674, 0.013154045282135485, 0.01664710340264719, 0.10768378735519946, 0.01824368013330968, 0.04002692599897273, 0.050202872735098936, 0.09129983096499927, 0.05990753343212418, 0.020730385076603852, 0.051268600509501994, 0.17139640840468928, 0.017106301711464766, 0.04411339890793897, 0.06476788825239055, 0.028757632462657057, 0.061247273260960355, 0.024282457852677908, 0.05089260252134409, 0.027946168193011545, 0.11981735267909244, 0.0625606371613685, 0.027544875956664328, 0.024230151284427848, 0.040646140623721294, 0.054233981427387334, 0.05109709018142894, 0.03299718817288522, 0.03422587673412636, 0.013761533973593032, 0.04032311713672243, 0.036439751493162476, 0.06163986567116808, 0.01363333538392908, 0.06100295824580826, 0.02981054705742281, 0.04816951426619198, 0.020708914744318463, 0.04118750395718962, 0.010968745064019458, 0.05029429419664666, 0.025061497690330725, 0.0313554239255609, 0.035453674718155526, 0.020045111887156963, 0.029312102124094963, 0.030515657854266465, 0.08228268474340439, 0.06897018072777428, 0.036919872800353914, 0.017023902910295874, 0.03591238506487571, 0.023281003777810838, 0.042033136705867946, 0.02148223818949191, 0.05105122545501217, 0.03132173042104114, 0.007530474604209303, 0.06878306303406134, 0.024228791298810393, 0.03305097903648857, 0.040307376184500754, 0.056155709753511474, 0.03053059543162817, 0.012492914156609913, 0.02618946753500495, 0.04609436546161305, 0.021499721333384514, 0.055257881758734584, 0.06036672988557257, 0.011524198998813517, 0.03078829136939021, 0.011528146296768682, 0.018369450044701807, 0.043097235466120765, 0.014069656062929425, 0.024535437441954855, 0.07713235798291862, 0.03367919220181648, 0.01588836130395066, 0.05782254374935292, 0.010906771094596479, 0.017747068304743152, 0.06409118315787055, 0.034650863890419714, 0.0838268268853426, 0.007291975243788329, 0.047043620579643175, 0.018130749376723543, 0.03574760972696822, 0.12538323760963976, 0.052225566541892476, 0.05900205018406268, 0.08033488848013803, 0.060220686355023645, 0.0692495251132641, 0.017064609710359946, 0.015851973803364672, 0.046604076196672395, 0.018503769497328904, 0.04213141932268627, 0.04437058276380412, 0.049492741309222765, 0.03986130832345225, 0.01298197277719737, 0.03983574133599177, 0.08045183611102402, 0.005559233431995381, 0.012451035690901335, 0.00991884822724387, 0.028537522593978792, 0.05983632065181155, 0.04197032503725495, 0.013675539466930786, 0.010474070240888977, 0.04352772935817484, 0.09237814927473664, 0.05600730248261243, 0.027531700980034657, 0.053113134345039725, 0.042685395455919206, 0.011913566777366214, 0.01956459538632771, 0.04051612377224956, 0.049923231490538456, 0.09781182059668936, 0.011682677213684656, 0.038555844585062005, 0.02463429522322258, 0.02146621893189149, 0.08099246842903085, 0.04845878487685695, 0.012563953459903132, 0.015680530268582515, 0.032084302001749165, 0.0521993130678311, 0.05511562689207494, 0.048062299902085215, 0.1070907742541749, 0.2078005182556808, 0.010804211851791479, 0.04518782836385071, 0.04476685622648802, 0.020231034723110497, 0.01913254483952187, 0.03346847050124779, 0.01661774960666662, 0.02756454843620304, 0.11253021206357516, 0.03090821315709036, 0.037778292753500864, 0.04937640595017001, 0.04778554561198689, 0.05741448869230226, 0.05893282635952346, 0.042482284479774535, 0.04348587965068873, 0.02430489668768132, 0.07656914211111143, 0.01328988984823809, 0.03766759029531386, 0.05377021705498919, 0.02698448395676678, 0.016685016016708687, 0.06556386390002444, 0.01982543988560792, 0.11275671553448774, 0.05434421633253805, 0.08654262725031003, 0.045573288734885864, 0.06289363882387988, 0.023429108623531647, 0.024926519581640605, 0.0763880654994864, 0.04054884506331291, 0.08369269853574224, 0.030506006223731674, 0.05088255013106391, 0.04521745489910245, 0.025080522646021564, 0.05123318522237241, 0.019606543428380974, 0.03970039586420171, 0.07180337401223369, 0.03437075138208456, 0.07100290094967932, 0.0533354335493641, 0.04466026155569125, 0.02418883035716135, 0.05044349185482133, 0.027175008108315524, 0.0385207224462647, 0.019920304912375286, 0.03987088202848099, 0.043493642515386455, 0.05147321804543026, 0.036709429405163974, 0.08818196467473172, 0.03512531518936157, 0.053326216075220145, 0.02093123064696556, 0.04127158557821531, 0.048859737580642104, 0.0423589061392704, 0.05676902801496908, 0.06142120670119766, 0.09648717605159618, 0.018330272068851627, 0.03329070757899899, 0.0516295700072078, 0.025770586398721207, 0.022624854318564758, 0.02369522422668524, 0.015409460829687305, 0.05611642416624818, 0.015796949119248893, 0.059567841308307834, 0.04095367548870854, 0.052040909067727625, 0.030373952176887542, 0.09709086123621091, 0.052418955383473076, 0.018883448537962977, 0.07472255252650939, 0.017871821473818272, 0.020374367559270468, 0.05669479098287411, 0.0487173194414936, 0.07617850526003167, 0.08837268920615315, 0.017129226653196383, 0.016213696580962278, 0.058328061350039206, 0.03112790556770051, 0.019072865034104325, 0.03491127608867828, 0.026059259580506478, 0.07018489093752578, 0.029523835000873078, 0.10106466870638542, 0.02291266846441431, 0.05781914100225549, 0.053901209830655716, 0.06010659228195436, 0.026662063464755192, 0.05501629784703255, 0.017629205976845697, 0.03913080865459051, 0.02476432691764785, 0.0912085096933879, 0.03868182786391117, 0.01746433787047863, 0.03345637349411845, 0.016813279544294346, 0.02607986160001019, 0.0020860112954323995, 0.06540668444358744, 0.09442612805287354, 0.06427980741136707, 0.03789954855164979, 0.009716519289213466, 0.011919078151549911, 0.07357118462095968, 0.1235472310509067, 0.11419281581765972, 0.1126354634470772, 0.1833304695901461, 0.1707776205148548, 0.1572415593545884, 0.2368994607240893, 0.12430618837242946, 0.2310432179365307, 0.0963944595423527, 0.18925448530353606, 0.13904714112868533, 0.2149804259533994, 0.2013897872529924, 0.18497414857847616, 0.13131268584402278, 0.17731518455548212, 0.1797380147036165, 0.16141465574037284, 0.0955170628731139, 0.11850246737594716, 0.1293934474233538, 0.17784868483431637, 0.12310062142205425, 0.1864145978470333, 0.16257522627711296, 0.12815796450013295, 0.14680090709589422, 0.11899935750989243, 0.15798318752786145, 0.16860894626006484, 0.1205587804724928, 0.1540666219079867, 0.1264319961774163, 0.1526781971915625, 0.1655149771249853, 0.11947071034228429, 0.13934196671471, 0.197284315363504, 0.14832388318609446, 0.0649842391430866, 0.13604767707874998, 0.10930816308245994, 0.09627150793676265, 0.1369894773233682, 0.16123275534482673, 0.13519903121050447, 0.13660160126164556, 0.1987541388371028, 0.23831117403460667, 0.1178082921251189, 0.183844213897828, 0.3151303011691198, 0.09367381295305677, 0.2021419836091809, 0.21184173499932513, 0.09359259231132455, 0.15530443517491221, 0.18039499351289123, 0.11418762820539996, 0.15428478363901377, 0.21972427843138576, 0.12952149758348241, 0.13579849357483909, 0.16257089213468134, 0.12908887001685798, 0.13612762122647837, 0.113054509711219, 0.09618478798074648, 0.12334482511505485, 0.08610214776126668, 0.3160269046202302, 0.10979901955579408, 0.08451795190921985, 0.10870044061448425, 0.1301880946266465, 0.0808764187968336, 0.12813434936106205, 0.13295195647515357, 0.21522753144381568, 0.22191407420905307, 0.15387998661026359, 0.18930224992800504, 0.15270016476279125, 0.1921598450280726, 0.14288487582234666, 0.13553893484640867, 0.1938391025760211, 0.18009457213338464, 0.1291701351874508, 0.0866096283425577, 0.1480574521701783, 0.20654606603784487, 0.18483790510799736, 0.10671212308807299, 0.21273062011459842, 0.22915032575838268, 0.12988697562832385, 0.13657176692504436, 0.10807040176587179, 0.20764937245985493, 0.17009346425766125, 0.116375049110502, 0.17444982659071684, 0.08324723181431182, 0.17805550654884428, 0.11678786133415997, 0.1814441231545061, 0.12262315329280682, 0.20515676558716223, 0.23437483760062605, 0.08911919328966178, 0.12531921995105222, 0.12432049697963521, 0.14283950091339648, 0.12160733866039664, 0.16540187381906435, 0.12464906059904024, 0.13654304580995813, 0.16456018929602578, 0.09636907809181139, 0.14006327488459647, 0.15639703982742503, 0.12863528419984505, 0.1153647931641899, 0.2261337180971168, 0.15424485609401017, 0.18922943039797246, 0.1806969882454723, 0.18329391139559448, 0.1335530070355162, 0.09133512750850059, 0.09218194769346155, 0.2446586888981983, 0.19205397024052218, 0.11136492146761157, 0.20474692195421085, 0.1579934885376133, 0.11847091125673614, 0.09968194368411787, 0.06660540879238397, 0.2198177741956897, 0.13816048245644197, 0.16037032037274912, 0.08704243402462453, 0.15750324062537402, 0.09758384025190026, 0.12861486029578373, 0.08854378393152729, 0.12340536210103892, 0.12631010584300384, 0.15973039611708373, 0.23210270795971155, 0.09690669729025103, 0.16463579930132255, 0.10705414926633239, 0.09693299900391139, 0.17581049498403445, 0.19203740550437942, 0.07271032300195657, 0.14589044032618403, 0.10416614837595262, 0.18885697616497055, 0.17945380182936788, 0.15301538456697017, 0.16711420146748424, 0.16256698843790218, 0.11594713418162428, 0.10825426885276102, 0.21837146196048707, 0.2370934878126718, 0.200663551222533, 0.13017583434702829, 0.19216509943362325, 0.15312792384065688, 0.12718389567453414], [0.06233246385818347, 0.05418873639428057, 0.03186881571309641, 0.09699910209747031, 0.03485857247142121, 0.05625848607451189, 0.03287506406195462, 0.033269563791691326, 0.013007690977246966, 0.0025748618827492464, 0.018024718738161027, 0.040865797782316804, 0.034192776947747916, 0.029465659899869934, 0.032885160981095396, 0.020539456454571337, 0.04744693331304006, 0.006536924402098521, 0.12855064967880026, 0.016836633076309226, 0.027176525800314266, 0.056674782681511715, 0.01198600966745289, 0.03722439825651236, 0.025437328695261385, 0.04368880880065262, 0.018007330218097195, 0.028846903551311698, 0.09504383982857689, 0.0950871293025557, 0.00591224664276524, 0.026628130617609713, 0.010732644695963245, 0.027566977114474867, 0.03199023849447258, 0.057378142009838484, 0.05659841568558477, 0.10407648209366016, 0.06758704752428457, 0.026021350677183364, 0.01413283509464236, 0.07789462528307922, 0.011227310242247768, 0.04966364307620097, 0.0685169140342623, 0.027385586945456453, 0.020640902475861367, 0.033173774791066535, 0.024275017822219525, 0.024952674721134827, 0.07182297413237393, 0.007738326512480853, 0.031961339263943955, 0.02401063327852171, 0.08783617580775172, 0.1381933002267033, 0.016315483990183566, 0.01285029444261454, 0.029654080062755384, 0.0368666051508626, 0.03231965187296737, 0.037596737456624396, 0.07121480637579225, 0.07381426024949178, 0.022191046737134457, 0.05073790925962385, 0.009075663638213882, 0.10624537157127634, 0.019797837558144238, 0.0404693944437895, 0.010866753564187093, 0.06302375957602635, 0.007315568582271226, 0.025358271414006595, 0.030728529927728232, 0.08564134084735997, 0.038511753591592424, 0.06895754937431775, 0.06198218499775976, 0.03063120282604359, 0.01270055223358213, 0.017046955872501712, 0.015510165630985284, 0.012425392633304, 0.09703019066364504, 0.022866688705107663, 0.10735138683230616, 0.02864145480998559, 0.017170185783470515, 0.05460197906359099, 0.08399782513151877, 0.054448543742182665, 0.051950478373328224, 0.013648669082613196, 0.05597881514404435, 0.03521576072671451, 0.024293475034937728, 0.11252508382312953, 0.029376631864579394, 0.062002928025322035, 0.026503073167987168, 0.07451241341186687, 0.029647274568560533, 0.03509910253342241, 0.0031031900880407193, 0.03748161921976134, 0.12192614303785376, 0.021069323920528404, 0.07880339995608665, 0.026432264858158305, 0.037283551137079485, 0.03180690575391054, 0.012584312426042743, 0.05415681662270799, 0.03718654501426499, 0.04271986450476106, 0.054027957521611825, 0.01954690073034726, 0.020235585943737533, 0.03816710763203446, 0.02795292359223822, 0.016705942725820933, 0.1206230281968601, 0.011773074511438608, 0.03171192940499168, 0.02862549121346092, 0.032482178503414616, 0.03414861916098744, 0.026239976250508334, 0.06321193111944012, 0.04615912155713886, 0.026505143760005012, 0.02444659679895267, 0.026595528070174623, 0.005429821430880111, 0.047137928995653056, 0.005542998951568734, 0.05370685248635709, 0.009962031945178751, 0.004698902912423364, 0.07938105060020462, 0.043645445111906156, 0.025888291020237375, 0.008846572854963597, 0.049512341429363005, 0.012954208104929421, 0.06461916185799055, 0.0646072207018733, 0.07550196343800053, 0.0399275598465465, 0.018292949462193064, 0.0478186973487027, 0.009442346745345276, 0.03119771383353509, 0.01716970895358827, 0.04038832223159261, 0.06180006195791066, 0.031568579870508984, 0.011788273695856333, 0.014992867363616824, 0.030194738355930895, 0.041977605505962856, 0.02240523241198389, 0.006721154213664704, 0.08427484659478068, 0.05744774804043118, 0.014447332232521148, 0.04317438171710819, 0.025920477964973543, 0.03862842662783805, 0.022205585410119966, 0.0265641055375454, 0.0029503002451747307, 0.018141484542866237, 0.04145842125581112, 0.0371744146104902, 0.03689549324917607, 0.05225332657573745, 0.053166450234130025, 0.01795621294149896, 0.01688637181359809, 0.0519310303934617, 0.0643669132841751, 0.026812916112248786, 0.03991604913608171, 0.034211241581942886, 0.015002441996330163, 0.07267990979016759, 0.09019879551487975, 0.061314003469306044, 0.04143911428400315, 0.053073036106070504, 0.005181899578019511, 0.022060636547394097, 0.06638185906922445, 0.03483189968392253, 0.024583600970800035, 0.054266687875497155, 0.06660765007836744, 0.013894390467612538, 0.0691070401808247, 0.015330976857512724, 0.05134314553288277, 0.1256846683099866, 0.03247720611398108, 0.06023150315741077, 0.03513641029712744, 0.07727729200269096, 0.0692320401140023, 0.0423143995431019, 0.020062433613929898, 0.028564516360347625, 0.04901407090073917, 0.013801986588077853, 0.04663795523811132, 0.02908906819357071, 0.01703859743429348, 0.04324134199123364, 0.03737935869139619, 0.07802633423125371, 0.037568862389889546, 0.05281732912408188, 0.017853805838967673, 0.018268549501954112, 0.04065910223289393, 0.03313131652248558, 0.0487768322636839, 0.024839384022925515, 0.045441331167239696, 0.05617903545498848, 0.05423104252258781, 0.06419090554118156, 0.014060060093470383, 0.011367970419087214, 0.04263446928234771, 0.0689022519509308, 0.031461443431908265, 0.03244452193030156, 0.01799632045731414, 0.026950601204589475, 0.010278357549395878, 0.013251350119389826, 0.01797349385014968, 0.08631898846942931, 0.008179820888472022, 0.04914718621876091, 0.04002123743703123, 0.04036354192066938, 0.024042957520578057, 0.04578039988700766, 0.017400036340404768, 0.08060970576480031, 0.019868499293806963, 0.04388030145491939, 0.046897625288693234, 0.017644961772020906, 0.026128674508072436, 0.025409466616110876, 0.03552961126843002, 0.06871684119687416, 0.037839586730115116, 0.035054755499004386, 0.04099952908291016, 0.05731212797400076, 0.034947674721479416, 0.0558788330090465, 0.1412398461252451, 0.041651301726233214, 0.05309763459081296, 0.042847673466894776, 0.008112565610645106, 0.03996142404503189, 0.05633142063743435, 0.03578187097446062, 0.009453480815864168, 0.028535364799608942, 0.017189902791869827, 0.06274540966842324, 0.02081764494505478, 0.013286744069773704, 0.08141275407979265, 0.04207047415548004, 0.014132004816929111, 0.057926203226088546, 0.04456840964849107, 0.09445499017601833, 0.05277918644424062, 0.014452654359047301, 0.05741263332311064, 0.024120671514538117, 0.05884753503778484, 0.061521496827481315, 0.07402189090498723, 0.03018331484781811, 0.02758023372734897, 0.050682270448305644, 0.05107741955725942, 0.04404467603308149, 0.046661844971822575, 0.005935094122833107, 0.025496461166767403, 0.06353872100589797, 0.03460501400695648, 0.007436136966134654, 0.02547717645938974, 0.06995327406912111, 0.029182760627008975, 0.0262821228170651, 0.04740798169223126, 0.0641720178828109, 0.04602523069479503, 0.0368924096255796, 0.08311825396958739, 0.057412674141232856, 0.03648383877589367, 0.04524232426774688, 0.06662602565484121, 0.02500994254660327, 0.009933445344358915, 0.010036768999270862, 0.017645306870690547, 0.022915644476597663, 0.05286722371238284, 0.04324428089603316, 0.050244848607690074, 0.0645081810944248, 0.02378724868322024, 0.0059856738062080694, 0.05224975313467439, 0.02447812137688743, 0.012029270383209223, 0.039067043326213025, 0.060794485252699815, 0.00443343808001373, 0.014953168956708396, 0.024493834498571232, 0.05413562088506296, 0.014637502936238889, 0.01579576353833545, 0.025566614531271625, 0.029896842133894097, 0.0632315906113945, 0.03467097238171846, 0.06150383371277712, 0.030057993935770355, 0.039823020924814045, 0.02450494259392144, 0.032259675208479166, 0.03399318746232893, 0.023316057267948054, 0.003711440408551425, 0.03626728379458655, 0.14523640042170882, 0.1748818307532929, 0.10791658423841, 0.11955714828218333, 0.11740573638235219, 0.17699710006127134, 0.10704880580306053, 0.12881599715910852, 0.11024549559806474, 0.17104056343669072, 0.07486751623218879, 0.2621168817859143, 0.1200602353492286, 0.18565967038739473, 0.1729552005417645, 0.12067508985637687, 0.12589570542331785, 0.08718102268176153, 0.20621238159947097, 0.15673317335313186, 0.1110177299415227, 0.1484717190032825, 0.1364821897004731, 0.09787986069568433, 0.13010699272854254, 0.11790455610025674, 0.16088654345367104, 0.2092716924380511, 0.10062419663881883, 0.18199619196821004, 0.12529314088169485, 0.12386847709422, 0.1186734953080304, 0.08737542084418237, 0.11496228937176056, 0.12703611922916025, 0.19693614420248196, 0.2207603759597987, 0.24121172464219853, 0.20510374655714259, 0.0963797650183551, 0.1580683860811405, 0.10246829260722734, 0.24368031561607495, 0.20675857260357589, 0.15064932871609926, 0.13304099935339764, 0.15150594525039196, 0.12920232955366373, 0.17311810195678845, 0.19474039640044793, 0.14744396321475506, 0.1276297334698029, 0.12586177443154156, 0.2077203811495565, 0.22146698960568756, 0.13221467728726566, 0.08521355950506404, 0.14368419855600223, 0.16540228942176327, 0.15371279558166862, 0.14822918514255434, 0.16000819683540612, 0.09844534753938206, 0.1347766155959107, 0.1484865916427225, 0.09831555333221331, 0.16841244039824232, 0.17624435451580212, 0.09892390662571415, 0.14805810526013374, 0.19496259541483596, 0.21186134254094213, 0.27285172138363123, 0.1061155550996773, 0.13509027688996866, 0.16643915878375992, 0.21584302419796586, 0.1725870359223336, 0.09588163549778983, 0.14592462364817038, 0.17316561425104737, 0.11085954858572222, 0.131651253614109, 0.18436091195326298, 0.1991292944876477, 0.16310275968862697, 0.206191438192036, 0.0800982175860554, 0.18347587116295472, 0.22942916548345238, 0.12145205910201184, 0.18555326125351712, 0.1542422140482813, 0.08837438872433268, 0.08125873617245816, 0.11208346142666414, 0.1978836886701174, 0.16349776036804542, 0.25109729496762156, 0.08471115521388128, 0.21169283048948273, 0.15072642301674932, 0.24393622297793627, 0.10597215732559562, 0.08749491404159926, 0.2333909278968349, 0.11460156107204966, 0.17972033674595878, 0.16848230618052185, 0.12702133564744145, 0.05378666304750368, 0.10216306211077608, 0.12486924097174779, 0.11088179817306809, 0.165310456068255, 0.22472957469290122, 0.11800948093878105, 0.06510573613923043, 0.12551988183986396, 0.10867987570236437, 0.1109125379298348, 0.2359556418377906, 0.15146474121138453, 0.1606090841232799, 0.197548876167275, 0.1606776734115556, 0.09686654710094444, 0.10227843638858758, 0.2461770488298498, 0.17582253261934966, 0.08113532443530858, 0.08951283583883196, 0.22754213627194986, 0.08671983727253973, 0.10307528034900315, 0.1693259202875197, 0.16455860109999776, 0.1298093915102072, 0.10114608972799033, 0.21021065767854452, 0.1441847177920863, 0.11650004162220284, 0.05947577788901981, 0.1753018714953214, 0.1836071867728606, 0.11701607174472883, 0.11172163474839181, 0.3888623759848997, 0.21319529361790046, 0.09677588634076528, 0.13775516592431813, 0.1855797559255734, 0.07428498967783526, 0.18458726699464023, 0.09311855290434323, 0.14622951275669038, 0.12710763257928193, 0.16394552774727345, 0.12581552378833294, 0.19266328832600266, 0.10160121179069392, 0.12881375587312505, 0.11793155543273315, 0.2093724612495862, 0.16575250891037285, 0.17790680984035134, 0.22446692863013595, 0.09632309462176636, 0.12732754577882588, 0.07844194435165264, 0.11132909799925983, 0.09541002291371115, 0.1103944743226748, 0.16845815669512376, 0.08285905147204176], [0.06042924098437652, 0.05575218179728836, 0.014365276674652705, 0.060513111093314365, 0.019443879500613548, 0.017582487780600786, 0.07890988330473192, 0.06136605399660766, 0.038534593186341226, 0.03279120508523192, 0.021406732084869873, 0.025089003538596444, 0.00975215722064604, 0.009355206548207207, 0.06102970895881299, 0.025556925793353003, 0.02768793605355313, 0.035015210160054266, 0.07791504918714054, 0.018059957765217405, 0.06127823937276844, 0.016642323971609585, 0.028444665076676756, 0.016810179222375154, 0.06824217096436769, 0.0881789144477807, 0.009676387653598795, 0.04834099119761959, 0.00809109249530593, 0.0324436499067815, 0.029381359345279634, 0.01717707662464818, 0.059036871753050946, 0.030747940800210927, 0.02058019850665005, 0.01475036226111115, 0.06353816439514048, 0.07359494076808915, 0.030260808052844368, 0.037320447008823976, 0.040614573372295126, 0.04821706737857312, 0.034914667703560553, 0.07702939983573742, 0.019551412988221273, 0.041632228530943394, 0.026551889786787797, 0.02212448165664682, 0.08470722925267182, 0.08010704172193073, 0.018518439901527017, 0.04762384276546072, 0.018228017106594052, 0.037884649937041104, 0.0267445476129069, 0.031720579136162996, 0.03265303574153222, 0.09216019534505904, 0.014673783753096359, 0.0435056504647946, 0.02312573720701039, 0.03152571713144425, 0.055738385271979496, 0.03553688802639954, 0.011789636464527575, 0.09462496425840072, 0.057137634212267585, 0.02329788763745455, 0.032681604716344737, 0.05844498300575651, 0.0485066682449542, 0.0490953546250239, 0.07280365549377166, 0.024370324426854495, 0.040817691769916564, 0.018441033898852766, 0.05051047439337708, 0.04848395852604881, 0.045151385202188976, 0.04067536639922764, 0.03772048687096685, 0.030597138247685507, 0.044263928721193224, 0.032636767864460126, 0.005296991839713883, 0.02059059599559987, 0.028577516932273284, 0.04676179371017497, 0.04493781736528035, 0.04414861752593424, 0.04779160153702833, 0.0311508806044003, 0.03288240390247665, 0.028644248995988164, 0.013174465475458419, 0.06680415594018996, 0.08344459114596248, 0.04297130413760897, 0.014046553005755413, 0.02617916095914552, 0.04933822245220654, 0.011883995903190225, 0.016067205906438176, 0.11111675470601767, 0.03690681100124493, 0.04445211510756053, 0.07373764834483154, 0.09289693276514299, 0.027198914540349506, 0.011675750192807755, 0.01918541358463699, 0.005958894798823167, 0.04306462920794729, 0.03120337270956952, 0.033594947308301926, 0.05670642414770555, 0.03152715689793695, 0.008733232989470707, 0.06510738370707259, 0.09646923092077486, 0.05582658210187219, 0.04761452510138042, 0.01828055188525468, 0.06195745663717389, 0.033553427856531925, 0.045788849238306284, 0.01624000200536102, 0.024791919968265574, 0.023533905441581737, 0.07353753564530052, 0.041660151837277226, 0.06512035644846037, 0.030177533517417032, 0.051155749533791095, 0.044742513782694004, 0.03584789614251349, 0.04171504107944202, 0.011931214121432276, 0.09470213277381845, 0.050464576270314865, 0.04830107107409276, 0.026361072486906778, 0.07678291032789275, 0.04111894806555938, 0.04199312381388154, 0.025684000029286835, 0.03144161695672665, 0.08470475790090859, 0.04566010145936161, 0.018971487661474384, 0.03175609832396731, 0.035400715059950016, 0.0775088940281421, 0.01935482920089271, 0.019326109941175673, 0.04432281813933514, 0.04998169788450468, 0.009541809376969468, 0.03864453494315967, 0.08092769377981313, 0.038271531520877033, 0.04722341698652599, 0.0318462432915112, 0.09542969724861905, 0.014320742247946328, 0.11804901514551602, 0.004445351869435399, 0.01839483891671989, 0.013149813185009407, 0.08291903926874511, 0.04482630225538742, 0.048930842749541625, 0.034966091116075404, 0.02583976754976902, 0.012755305106111336, 0.08323272282723337, 0.07345733174588531, 0.08624423193396069, 0.019727990329556633, 0.047307917920988984, 0.0475892772374209, 0.004227850649840548, 0.017709215062495787, 0.08027280040550977, 0.0126958006330824, 0.010703552507038694, 0.08365717192646116, 0.04674344410886988, 0.04560635883535724, 0.03924996046407614, 0.041773956472752616, 0.03634857865108643, 0.04353054580860771, 0.07717882384895347, 0.046107876260066405, 0.06996692216489464, 0.04571003686578479, 0.05611678781860974, 0.040179800998885185, 0.027330608645570464, 0.05475450525409542, 0.03449107207416091, 0.023462924582418054, 0.05618298368062824, 0.03152806973957922, 0.04059482482261956, 0.024377109511988238, 0.0326384339859942, 0.04934011863952037, 0.014220627454051282, 0.034749866390484385, 0.03969721576140728, 0.02737408551183762, 0.09759885389939882, 0.020367962824821007, 0.023836174768803176, 0.054911395272938535, 0.031337185646407306, 0.061790536492480896, 0.08761891949689016, 0.05614006156974938, 0.08735548675758764, 0.06132271999376826, 0.031013891275506467, 0.01611643998330692, 0.08418276833253913, 0.02302427077665925, 0.048805928163346834, 0.03314511304779444, 0.021559410415648017, 0.028416684253897984, 0.03727471215825062, 0.07366573423496448, 0.029784362232021522, 0.011408215232222574, 0.04344750319432933, 0.04881055545411073, 0.006900084626977332, 0.08219558629207313, 0.043772619537776336, 0.029510005078918766, 0.05649870814522728, 0.05461045810079668, 0.013150546055840096, 0.019621809406089596, 0.05113371888000984, 0.08413209448917769, 0.05537078468478285, 0.06158224161481485, 0.0077733280522807036, 0.04742359647934791, 0.07292677779332735, 0.03225195316190366, 0.02587937040516408, 0.027316066261846572, 0.03220277474611066, 0.05599522773991339, 0.015683545243518893, 0.04077079545822926, 0.07012738933553919, 0.0793480324500706, 0.04952897295879666, 0.024411422709817998, 0.048817450006026775, 0.02972204780235188, 0.06290417732088827, 0.03392053120478522, 0.08981555045465939, 0.05294772818160709, 0.03250170069804881, 0.03207875444786623, 0.08054170277318917, 0.029739245219388977, 0.049491869285702705, 0.06300358800217509, 0.023761557386023924, 0.03983368558692746, 0.034576582329464145, 0.026093513406522106, 0.096063565579243, 0.01115641658543609, 0.06126437976490706, 0.030576213393942453, 0.05843109742272645, 0.07596368319354951, 0.018400180524622556, 0.023868274511187337, 0.029641840192198288, 0.038976018913672306, 0.03215522905520629, 0.020120063236390706, 0.047304051331593655, 0.0728418464132119, 0.04973987648554612, 0.02835062383383047, 0.012351647274044808, 0.10186977277044207, 0.03907157413777895, 0.01580262469360605, 0.011946262093260884, 0.03995467792265117, 0.029871315964555833, 0.01832621252106037, 0.04006340997875668, 0.06790240833652206, 0.04273938298865687, 0.03459608225966804, 0.011296433876850642, 0.039662717026658356, 0.07537686702562496, 0.04798609617864713, 0.05363575473893434, 0.04814038868062198, 0.03552944057446439, 0.06527176941744983, 0.04219887312501669, 0.038920454317121767, 0.08670748051372357, 0.09152985963737592, 0.03650893449957948, 0.038865587339387275, 0.05969284495222382, 0.02366924163652584, 0.07475005651940592, 0.06179708965646569, 0.022478307982964907, 0.05131890327902511, 0.02847768693754915, 0.004439005115273176, 0.029839199523848947, 0.028415138731361367, 0.05135539096954744, 0.04234592597640585, 0.012865553926530993, 0.007365865785686765, 0.09412339117261581, 0.046283627962111495, 0.05713876227673609, 0.0379338283528341, 0.03427474344789516, 0.029384214758465532, 0.03133117796096485, 0.03566618499462493, 0.08395862489123829, 0.038585233633057214, 0.04540443158475682, 0.10874649829929695, 0.08309460172313266, 0.039430228134733625, 0.02659151861735154, 0.011072595643781824, 0.04299852611438837, 0.1489513393607922, 0.16241567936958745, 0.14862506155623123, 0.1843505070428364, 0.182307597133331, 0.14914345170836896, 0.0954155222279951, 0.2651982492534444, 0.09870096546364948, 0.211895540705882, 0.21076576929772273, 0.21226039534667507, 0.1187862126971595, 0.1799534008023329, 0.17501396272564307, 0.10693037387682125, 0.1283180309110321, 0.19127391366055235, 0.17228613956831396, 0.13039833022048697, 0.13124881661497056, 0.1350017832010053, 0.12101724962121807, 0.11594513038289733, 0.20170764910290018, 0.16784886829555035, 0.22744319314369932, 0.14863168151350692, 0.12836042238632217, 0.0895288068568334, 0.11527118607773446, 0.11664770674542524, 0.13882875675335526, 0.09388884282088839, 0.11916819610632956, 0.1700560748577118, 0.15627617365680635, 0.19550308672478423, 0.1293864267063327, 0.07380507988273166, 0.16345039650332183, 0.3094944910844788, 0.23771395295625553, 0.16270628955680877, 0.09966691519366577, 0.22160560794873163, 0.09830889626755379, 0.16276472626486793, 0.24777345301117748, 0.15865538036450744, 0.11064351681852713, 0.14626265707192943, 0.17050035414285958, 0.13692721113329753, 0.07922151111415587, 0.12129151029512286, 0.10220416224910878, 0.1694983508787118, 0.20625085453502834, 0.1360116235446185, 0.20152606040937826, 0.19213679392123595, 0.22180689324159175, 0.0983234794693999, 0.12604667310370132, 0.2159641426987946, 0.12992763047805056, 0.15286079520592466, 0.13665919192135334, 0.1985349677852355, 0.19467231177259237, 0.23062378575559705, 0.14213150687282905, 0.12788670952431858, 0.1766935913474299, 0.18359140871325508, 0.13835827965522185, 0.10324165501515381, 0.11644277008599602, 0.1368305686628446, 0.2530126000056043, 0.10556875553447753, 0.15888608439126983, 0.17763945856131613, 0.18702781962929294, 0.09004610605188645, 0.09262615276384167, 0.1760877316701226, 0.14293872605776414, 0.11554903132491745, 0.1262605600641109, 0.2134097446105443, 0.09535828037769534, 0.14584061253117397, 0.088455097284168, 0.20138257357757539, 0.14624932809965685, 0.2414765377761796, 0.1515996636589989, 0.10359073159634136, 0.15553515404462814, 0.13960634940303862, 0.08839113157591783, 0.3033947496442124, 0.11873319366713986, 0.18960083078127354, 0.12492508016293868, 0.15130088984733447, 0.16665775096043944, 0.10279503796482459, 0.22235468728467822, 0.08331680073752068, 0.17099135904572904, 0.09055295580765232, 0.1224242577154655, 0.12673560879193246, 0.15840094245504588, 0.18732870114035904, 0.17779891641112044, 0.12302628791076131, 0.21220819267909974, 0.11958986957324669, 0.10535886132856831, 0.24760007247095928, 0.086517935997108, 0.0919272648752667, 0.0734640184964519, 0.11886439795489423, 0.19895486009772867, 0.24387005309108645, 0.12450715454178862, 0.15483547205803916, 0.15220305940601975, 0.11198079271707684, 0.08707307730219327, 0.11918822667212225, 0.15631203423254192, 0.1823490089736879, 0.13751206803135574, 0.17487265780800954, 0.15848533948883414, 0.1764043467119336, 0.1740507292561233, 0.09738409862620756, 0.0975362463213969, 0.11549757822649553, 0.10379888175521046, 0.26594876835588366, 0.08891558507457376, 0.12588681449415162, 0.11007089793565683, 0.13034621661063284, 0.15438535949215293, 0.08435611918685026, 0.1622344765928574, 0.13661886361660436, 0.1800502956029959, 0.08708251742064022, 0.1557658877572976, 0.18807507905876264, 0.10098819038830698, 0.08160164550645277, 0.07913437555544078, 0.16878418216947466, 0.17422808770788833, 0.2094183853478171, 0.11164039184222929, 0.10077300466946326, 0.17082952632335946, 0.17242125497432426, 0.22991170990280807, 0.14684312045574188, 0.1349844317883253, 0.09149163161055185, 0.07599443037179299, 0.19409082422498614], [0.05238496501988266, 0.01608218801266048, 0.05852461174072232, 0.027311854573781602, 0.046690087401657365, 0.02394079161604168, 0.04714977738331072, 0.03381336879101582, 0.015809639844519552, 0.07942186872242019, 0.026852285191125702, 0.06848265649750829, 0.02838615600921912, 0.04895619822491426, 0.010987895257130731, 0.017874190780275967, 0.06568748343852349, 0.04641297688067425, 0.0479611154878512, 0.037923416020930745, 0.06639978935709223, 0.07871510664699599, 0.04013306424894836, 0.028120943970861845, 0.020233303839631844, 0.029261025665618945, 0.04398174562084023, 0.02076437358482508, 0.04561963214655407, 0.08695080847246572, 0.005986790274619125, 0.05102800736494828, 0.09047985426150262, 0.10226120371953584, 0.009541621056996519, 0.03803953244641889, 0.0075049911083624465, 0.010535249184613349, 0.06261141490540467, 0.029297424298420083, 0.022613317632931285, 0.14036310254596174, 0.01057949510141043, 0.016556346163270064, 0.041432861689827405, 0.035564232457545586, 0.04054775039548986, 0.04600889973517042, 0.020670749800046906, 0.04946740809828043, 0.023213577806018293, 0.014043265291547868, 0.0226334762191982, 0.06138359094620682, 0.03424749920668546, 0.059190496322116815, 0.06945090688532218, 0.03147573719616048, 0.03144670066831168, 0.01043614649461233, 0.03758523045689799, 0.016964254646154586, 0.04222921954351477, 0.11075181100750342, 0.02111480829626089, 0.06850273159216158, 0.03938833389838692, 0.08739778175367974, 0.028523514556582086, 0.0345616095000878, 0.07021030207397416, 0.04551517857180443, 0.02576900562416995, 0.033047735851141624, 0.018038003181573004, 0.04651077339076437, 0.03125792798527982, 0.051020348400925286, 0.023394411364279222, 0.018492132621759083, 0.04935512857628055, 0.03088084460614482, 0.06363552674883977, 0.0744619028409943, 0.022762823282391764, 0.013580963877757313, 0.06827313336543739, 0.03779302067414392, 0.08853020262904465, 0.03802374325459823, 0.1229424549092073, 0.03649088917882182, 0.10113853466464207, 0.009214114998030709, 0.05152216639544349, 0.06507256955956109, 0.030088796775089577, 0.05433975602500141, 0.07231170064187609, 0.12640458124224097, 0.04757647890073713, 0.04203250959108118, 0.04268702818080783, 0.044649548653978854, 0.08165913968696259, 0.05159697488124948, 0.027474535199871752, 0.031155615506577305, 0.07911359542049468, 0.06073083866795059, 0.02958958186354721, 0.049784717048169114, 0.09408536352566443, 0.07908481493359432, 0.05839600125909783, 0.05562076228670776, 0.031940121261868626, 0.025920557745848782, 0.0746266522037331, 0.03513379051582888, 0.04397050208353903, 0.03932851308491081, 0.011491342265799176, 0.02069946534902556, 0.04726966391899623, 0.033372592442901805, 0.015698492097726557, 0.02560177192208357, 0.024198726896429434, 0.06499553463072516, 0.03280939512478653, 0.05054834618931636, 0.026505598325456958, 0.04178948591288645, 0.13379555573919788, 0.04698948461737018, 0.08550302678486332, 0.03553085807652678, 0.016505432977282908, 0.034643312537809834, 0.013574507192970486, 0.05433299134892877, 0.03555167160811834, 0.052375654777279124, 0.033557350107003, 0.006523086130982847, 0.015277724978659535, 0.0532133539672941, 0.017813180675148033, 0.028878285265818704, 0.05992060265270993, 0.04358413629233837, 0.023687181201239582, 0.03759289684239775, 0.06158363314170856, 0.03827563188679051, 0.043187079863855615, 0.05810975118947681, 0.051136090041836724, 0.043516697332961485, 0.02067864810669562, 0.009472183865000261, 0.038909032664378174, 0.012888080891571008, 0.06311659482889809, 0.0436259154957952, 0.09805157882510684, 0.01990765314985765, 0.03022949498699745, 0.04043039087264333, 0.018019956005446147, 0.09766604052856565, 0.01248945574843674, 0.06668638452538289, 0.060380611757864244, 0.03787282752455212, 0.018175773620896507, 0.05860540935827885, 0.03948219331505243, 0.027014678234991152, 0.02614108321722597, 0.02835177230736008, 0.014537615425069816, 0.024961185299616773, 0.008783481025602669, 0.04551138248643838, 0.02964178453112254, 0.009106964644161053, 0.012056595332978759, 0.022982586197031196, 0.03867955689202063, 0.06845716372481547, 0.03609250059525948, 0.03497922712995205, 0.03177671889716294, 0.04809240512258839, 0.08207412640331313, 0.014947433082852513, 0.02289748597831931, 0.050854994187830016, 0.02929420708824182, 0.05488737195264548, 0.005946487945038825, 0.045016199292149395, 0.05856266536284238, 0.045533869561040774, 0.010965192959702108, 0.04790133920323569, 0.05386799130064901, 0.06945560468011536, 0.05108861856570002, 0.03200949351594318, 0.049056328789447434, 0.015430563798872754, 0.1107575700734742, 0.052210760695743375, 0.021422204008558765, 0.02221075446868781, 0.023439283468178473, 0.029621937646879815, 0.03741898566659074, 0.070094853581395, 0.036287822731537744, 0.009647163733461639, 0.02315781282959506, 0.03550405912392307, 0.03379001340363175, 0.03653138817753643, 0.04159194475505501, 0.018604504912218545, 0.05017724266508594, 0.02031678432103945, 0.07081081086653285, 0.02640635648276657, 0.03442239743890241, 0.025504493059997912, 0.047259971470339224, 0.014179040281305788, 0.027780520831584, 0.10350335112889297, 0.03639301845396403, 0.048510931883356534, 0.07421290487400256, 0.06330766074825078, 0.0710826892463956, 0.047611864501959644, 0.021973616021568887, 0.0409824337111786, 0.007637652788616833, 0.05201916414080188, 0.025929983021342196, 0.055199964554049075, 0.027401441075198818, 0.025262320996262133, 0.02820360808982514, 0.06616386061068624, 0.10068914198200218, 0.052086985306232236, 0.09150930214673281, 0.03242079917981755, 0.01885406134533696, 0.053652427086490206, 0.018529766930441838, 0.0020153402829237166, 0.041710988953127526, 0.022923815522517543, 0.05095468688523397, 0.0688914314378053, 0.03525159532728139, 0.03313453002192546, 0.037256915456964634, 0.03214158095943276, 0.02148284860595595, 0.07638693001354113, 0.018852426765079144, 0.05665033633704297, 0.01586806170962518, 0.05342432799807284, 0.06249750265851617, 0.03283886951976456, 0.03988182499597315, 0.010390945062681567, 0.08660585823236033, 0.08579484667279758, 0.0458538687962573, 0.04814088963030372, 0.021571546385530382, 0.026440524961799383, 0.07954314307426102, 0.045875676805735566, 0.01933645547978813, 0.033783827602746896, 0.06770838866941631, 0.008998181565402774, 0.041157914529321715, 0.021218196889094543, 0.09013433998916298, 0.04074475720699411, 0.021701500154449604, 0.025225003955711145, 0.022209680209925864, 0.01440397967598983, 0.050744124746415764, 0.03744470108358655, 0.06383405867381953, 0.053118893411010504, 0.0320334574644221, 0.07241615050588734, 0.05350882151105907, 0.05506038141902536, 0.1348312821937725, 0.01534765198812238, 0.03855512841255404, 0.06344716966850683, 0.03417733656533528, 0.10686473833629861, 0.023467713290301617, 0.0869467860320583, 0.04979597171768546, 0.0902874450548552, 0.032818438194226474, 0.03863992991682608, 0.01901779767649714, 0.014617009455832886, 0.06264534589718096, 0.026088758095283993, 0.07058292700094171, 0.007479895848518936, 0.04050277995702345, 0.03408519522054121, 0.04017505867523141, 0.011444877327448921, 0.04845206472964492, 0.02706672876229277, 0.024018182775762398, 0.00874740801009466, 0.03785515327763278, 0.012055451497872127, 0.029500672571884934, 0.07004849161603488, 0.014415080349863274, 0.07465413393219933, 0.009861059043032583, 0.04805246273463126, 0.11340517448843457, 0.05628673963656183, 0.05576716204814147, 0.050860166957136244, 0.049889537986018695, 0.032586995730525814, 0.040168371924664825, 0.06580883200513199, 0.1154903274436947, 0.15497944870730862, 0.09169668701360933, 0.07560829835711047, 0.106896346405847, 0.07549635280156508, 0.08794193185167387, 0.09072339744307101, 0.08212491899030283, 0.1809122259146534, 0.07952076732181013, 0.21858831751160324, 0.09604418810340576, 0.0992665413650684, 0.1521888843853958, 0.12126989153330214, 0.1514562510419637, 0.11665274592814967, 0.20573469082592055, 0.17194834363181144, 0.1621403722674586, 0.134767516865395, 0.173955942154862, 0.11981876275967807, 0.1349880386260338, 0.197430340340361, 0.11926121689612046, 0.094897302769823, 0.12275744491489604, 0.13761761627392843, 0.09554438132909127, 0.14525011531077325, 0.2429633415886201, 0.24148520606104285, 0.11965962403337471, 0.1403654328896664, 0.09241936073522083, 0.2059406813350506, 0.25174884125590324, 0.15984082769136876, 0.16321564035024494, 0.13802937464788556, 0.08354069927008823, 0.14060603716643527, 0.16174081480130553, 0.1194578043941874, 0.1568496460095048, 0.11655737995170057, 0.13516137463739142, 0.1638798922067508, 0.08157754054991528, 0.16313623054884374, 0.1423661591252312, 0.1525566927739419, 0.11702230578521267, 0.23642516898689792, 0.17237975407624617, 0.13408573548076674, 0.11534189048688859, 0.08530344843165949, 0.28417155146598816, 0.1631828077370301, 0.09669203849625774, 0.23218852991703898, 0.11436133529059589, 0.11287318076938391, 0.10353642122936435, 0.31280200579203665, 0.14205413055606186, 0.12587397533934563, 0.3044726449297741, 0.1461653021397069, 0.1510928213247098, 0.09665912424679846, 0.07979404836078174, 0.1731148365070112, 0.09805434703594074, 0.12813538836780936, 0.10711355818784796, 0.09357980510685593, 0.22523220162838697, 0.11087925260653719, 0.2273488068021834, 0.13593043258879334, 0.1758039343985729, 0.17549632902955636, 0.13740631198743358, 0.11043941878597252, 0.2171081633423455, 0.11095074369222857, 0.18493511161068454, 0.12651251920033246, 0.1654895511455834, 0.15439085138496011, 0.1282555123907514, 0.13696837064344436, 0.14872042753268033, 0.15789833036251366, 0.22318537317914888, 0.3165999613702297, 0.11934852314880118, 0.1596555727883242, 0.3097258333582431, 0.18461955041857436, 0.3022804297506809, 0.08875963758327998, 0.1486693974584341, 0.13293994852574542, 0.22336708061629906, 0.15800959314219654, 0.115811350842705, 0.10371997661422938, 0.1337146616424434, 0.10852352745132521, 0.10513633576920256, 0.13320663187187165, 0.28627732128370553, 0.13236533326562494, 0.14910934260115027, 0.13977416383568197, 0.16658365493640304, 0.07152070480515249, 0.13939387252321467, 0.1285636521060951, 0.09807730166357942, 0.15193232393357903, 0.11741951806470752, 0.09555198092130013, 0.10792114844662137, 0.14462870021816343, 0.13112189451931044, 0.2145520137855783, 0.18147327471524477, 0.20050709164934233, 0.3188562981085852, 0.13035130774369463, 0.22329749685013667, 0.1330971799325198, 0.12550003681099042, 0.29627028037793934, 0.06756897622835822, 0.14437160542001948, 0.14158215431962162, 0.20067499513970688, 0.08484058576868847, 0.16876760259037837, 0.13104672980261967, 0.11140214759507217, 0.10697687685023993, 0.17839968495536596, 0.13670737214852124, 0.11746055883122608, 0.07864853600040078, 0.14830412721494213, 0.15966122795362025, 0.19504412775859237, 0.11233372846618295, 0.13257620710646734, 0.10286680364515632, 0.12036090905894525, 0.09899005424813367, 0.08376067184144631, 0.12627761461772025, 0.126249561435543, 0.11484644011943601, 0.21329364302800968, 0.17503693961771205, 0.16975143807940185, 0.26776296319440007, 0.19059248850680888, 0.1293021929450333, 0.18394075246760622, 0.1800643964088522, 0.21016848884755746, 0.14080334454774857, 0.20123040361795574], [0.020221143749949988, 0.033584813281777315, 0.09643683617468923, 0.04247233970090747, 0.02641083534399513, 0.01658401157328626, 0.02595709553133929, 0.01470562467147829, 0.009910025946737733, 0.01205419170219102, 0.05259423953248188, 0.025360922736581415, 0.07782251079333946, 0.06516285924590193, 0.044561785980477, 0.05153202582732774, 0.005615202035187394, 0.04402296450280119, 0.034135052701458335, 0.06124497260316275, 0.04740979624330066, 0.029325416253414005, 0.052166235545882955, 0.05698318957001902, 0.0389707533759065, 0.09009861300000921, 0.07703075796598569, 0.03835638868622482, 0.09312556619988754, 0.012682888191193342, 0.01372094684484182, 0.005162465977264219, 0.059642308406182565, 0.027146277716383338, 0.034609886206453666, 0.021858727850485593, 0.04178512950602453, 0.06212208354554605, 0.03342444259033073, 0.028568926572916098, 0.046436402772087604, 0.011407191996113397, 0.01193680156575283, 0.03460750020167325, 0.01987263862247346, 0.03492948097118642, 0.08319302534800954, 0.02773944852378918, 0.048339785207645036, 0.05441516565042548, 0.08484457110171206, 0.06918082450283691, 0.01135025257099187, 0.04344535467680544, 0.03719102758623194, 0.01803078208467923, 0.01392683994708932, 0.013287867495819228, 0.02361189959628973, 0.03975135172368027, 0.061363074273685925, 0.07348782659391873, 0.07765300426399335, 0.030149446938594338, 0.015524105019721901, 0.04070803945069201, 0.02277504088851856, 0.008159662302205106, 0.03234793141018599, 0.04408729015267454, 0.056722235603956506, 0.05362298608815763, 0.022150341792439576, 0.03820810386969242, 0.03339635230076965, 0.013582839656010037, 0.015261988664860837, 0.02079520796542056, 0.0483368277491536, 0.02277286082971841, 0.027570693418965675, 0.06150580411485862, 0.051455736756906845, 0.034688791347434744, 0.01916529767186148, 0.06116280572314281, 0.01762620398949366, 0.030498833366436884, 0.07382044976111501, 0.03785737972066272, 0.061835291708121076, 0.0054292996082949685, 0.037259290329529904, 0.013709050217585173, 0.048225461068795994, 0.03415201819734648, 0.10053071571746841, 0.04586710871080868, 0.07463325731805526, 0.00512971268108231, 0.03919090777344536, 0.0066189099197799806, 0.03361059178132564, 0.0484643732488621, 0.03544706960383337, 0.006791651285311673, 0.07388834885205142, 0.05594503258180339, 0.03292380089988001, 0.0617240734572988, 0.024938687092799228, 0.046247730278992094, 0.040669930167496204, 0.03751672280486673, 0.05887418556085322, 0.04394844545458909, 0.0473846893873997, 0.06569633726030588, 0.0074760928055184195, 0.035237067786511034, 0.024518627797078807, 0.04423552301886957, 0.07241439161589369, 0.06569385848706588, 0.06353881748509593, 0.011261921226832783, 0.03494406417303253, 0.057658380683278665, 0.08295667357742786, 0.05239179648924619, 0.06379361904691905, 0.03068609021283919, 0.05820256417791825, 0.003727393104782095, 0.019893556054739747, 0.062229127215687186, 0.06675594602711499, 0.03441604465479031, 0.04746554637677036, 0.0367277047917014, 0.029884388895879965, 0.05437580213765614, 0.044204449295648374, 0.024957409623311833, 0.009792943801585352, 0.009924486694217194, 0.06572560014319606, 0.028381155789247714, 0.027156708601978607, 0.06186835809785407, 0.022249746907618828, 0.050233913061674684, 0.05914381894399412, 0.017959958931896836, 0.043359388000681065, 0.016966410585155245, 0.08281249654828571, 0.09218865670845844, 0.08050435790210031, 0.05391806400439236, 0.07869878681958653, 0.08241046773036942, 0.05662504023348447, 0.047715112086734734, 0.017319045764452312, 0.08189877917175181, 0.03740203130291775, 0.01641198730794713, 0.022431378274632152, 0.08956580291851424, 0.03402141504921019, 0.05073722648376133, 0.05745791917433962, 0.13370594882871956, 0.035083580514765345, 0.04772343898366671, 0.06928350063390099, 0.009454825030843494, 0.044895106766489334, 0.06560822948813438, 0.08502185533870943, 0.05339250470569823, 0.014245120182749815, 0.015856760655879043, 0.026341861994296778, 0.04273939041013364, 0.06471814209362492, 0.05633491244225297, 0.07124530122382566, 0.07771404591039754, 0.010761773064587032, 0.01776305045495974, 0.026909781227004714, 0.04690698748163413, 0.04031226322695147, 0.08999956597108394, 0.036404440106707625, 0.05462039174744859, 0.02300155920238467, 0.03156451661197934, 0.023409859168168623, 0.060450247474364005, 0.0442915551684564, 0.010866517932299757, 0.05804851658467669, 0.07810104623786174, 0.02693100665055681, 0.006383399095284403, 0.03453658428043127, 0.0259068317245692, 0.05813840180053376, 0.03272597772593144, 0.01034223419992486, 0.03468656119366642, 0.037984606096870266, 0.02222590170276817, 0.048069413387565874, 0.03796590768615715, 0.022314269226626493, 0.024271835864055902, 0.009547772533551324, 0.04441751247213688, 0.0422127253114013, 0.04804139731277246, 0.024395848740823567, 0.052183137959218584, 0.03603006000048481, 0.02828514414431993, 0.048529697087360546, 0.05036198919697199, 0.03190538875060156, 0.010238885497528827, 0.05123934504808858, 0.026642856682883576, 0.07657281574211083, 0.06256659660721198, 0.02524833893403411, 0.04793315507413354, 0.025558361849107314, 0.04057515048771165, 0.017964973994821776, 0.07185993308667094, 0.014305415043054381, 0.016063163056969643, 0.029148978064768016, 0.06660766492132097, 0.036421654222067446, 0.04676514450693503, 0.05829161447763909, 0.008615648966951994, 0.019228612145525403, 0.048050343903014436, 0.0263912778973463, 0.0033256523329328047, 0.02307693172042491, 0.008629245112388162, 0.017589564158697613, 0.07406204109429382, 0.12039219058351591, 0.07225779103464447, 0.03961051064834464, 0.03396205065655522, 0.07264905871124938, 0.025712758251756895, 0.05794884986244142, 0.07925066267489456, 0.117062114586588, 0.07479600288206711, 0.04980582743883133, 0.015586954723403323, 0.026464947186468635, 0.048823049510247074, 0.13756783300777897, 0.05645298813760746, 0.027697285258909687, 0.03941801238397602, 0.04745565354824066, 0.01438124583728495, 0.05402973125455901, 0.009190538821712835, 0.06104929794673808, 0.019944554587709717, 0.025062735221581534, 0.12172155518783256, 0.08449695655144751, 0.013718272330152104, 0.05694927713193465, 0.008402069070143625, 0.04670185786380898, 0.09840707498369738, 0.0636675652640406, 0.06019465552526526, 0.03996681574790273, 0.04596451930410694, 0.034046826185658574, 0.015800166329427157, 0.017213629253092222, 0.026734630664577708, 0.011076633854827378, 0.017962940510187764, 0.04703769453044515, 0.07135244508390315, 0.030964304678491317, 0.07428831449942663, 0.013193598970246967, 0.03869641477649566, 0.048608019642415456, 0.012060060234944103, 0.017241402274521533, 0.057881585307768546, 0.00921211398235755, 0.06186511120176874, 0.024934395623859018, 0.05359230941394344, 0.039922917712829076, 0.03996726845798548, 0.05593996371317189, 0.010610499248286942, 0.04925040411762893, 0.06043961249815766, 0.055297048602369614, 0.06501676005427726, 0.07748847754555754, 0.04701083249528892, 0.020357359389890917, 0.03473745768133085, 0.010343691592424875, 0.03186148329405114, 0.0043710809768526815, 0.035583784338086843, 0.03784462591283955, 0.099790846434189, 0.032556460064370185, 0.029794232796120923, 0.025025672366609797, 0.043025443810620345, 0.03773641336010769, 0.04303869485738687, 0.04439379343239125, 0.05306264603859745, 0.009223831566487206, 0.0685565076128114, 0.008388680726056919, 0.05083534211735241, 0.051155174369341694, 0.03499811478832271, 0.013276879071781877, 0.041836946256808005, 0.010864435280382168, 0.09482558161835186, 0.06045750196790323, 0.024055293870333117, 0.1275308200274594, 0.15421424992382526, 0.11621807745541446, 0.12780556309735402, 0.20122152753174305, 0.09784442314412445, 0.06472289183875546, 0.045615164417540655, 0.0693015348224435, 0.09867136119282804, 0.14392884011613205, 0.10972920572385192, 0.1676423434400931, 0.17262577603105456, 0.09664236655225977, 0.06881357272504829, 0.07759502768749371, 0.15710322302766144, 0.10196917603025213, 0.15194278821581975, 0.200998185609933, 0.1708801111089997, 0.11502399895107374, 0.15292809315724298, 0.1138973816705402, 0.1734138181200251, 0.12610925099579617, 0.18914068437879905, 0.18114557198714465, 0.16653979400871322, 0.16526003455510363, 0.12316188571276143, 0.11233846336835995, 0.0847018115746323, 0.14137778169242665, 0.16074304177891463, 0.16144291672389954, 0.11385605146642774, 0.1278121830546297, 0.13624980841996148, 0.09431020458578132, 0.21397998119937256, 0.1152160445053596, 0.13986586360260844, 0.16960728331469, 0.09819241618970409, 0.12928228854434565, 0.16300423216307536, 0.13518371328245848, 0.2411325226421468, 0.215165933186654, 0.12883729679742828, 0.17335055745206773, 0.20761063235113397, 0.13552364660426974, 0.10096567362779751, 0.26065176352858543, 0.07875741648604162, 0.23464561760192737, 0.23778917704476044, 0.19778050045715645, 0.15002444037236273, 0.14975609461544082, 0.13783782633254305, 0.0924988224869594, 0.13030507194343954, 0.08187913452275097, 0.13263192755402997, 0.1404224446741864, 0.11844777851365507, 0.19848410098347813, 0.13427492376649752, 0.211450252099894, 0.17512914404505864, 0.16948242438957095, 0.13042246486293152, 0.13098905008519068, 0.11307841428788379, 0.08020995534025133, 0.19807053176918998, 0.12223644982441328, 0.10392844589659944, 0.2883343765279278, 0.1403867918998003, 0.14738226105691865, 0.14158905629301444, 0.10875741529162042, 0.10905604067374952, 0.12054217862896621, 0.18609283230034634, 0.26570480957161635, 0.16751055285567418, 0.20225161366397515, 0.136403729848098, 0.19581637694500387, 0.1383425312815234, 0.15587133209919557, 0.18555682356236503, 0.15692611690610647, 0.11134296131785959, 0.15017091063782573, 0.08343992303707637, 0.14164455409627408, 0.20143263885984197, 0.16512721980689093, 0.08610633347416297, 0.17691872926661745, 0.21442007477162406, 0.19217599416151643, 0.18441686988808215, 0.16245326172793284, 0.14543295081239194, 0.19235780549934134, 0.25759004813153297, 0.24161239532986656, 0.13022889790590852, 0.14471786184003577, 0.12210670014610514, 0.15762750583235174, 0.08745955812628381, 0.10988101203111, 0.11933114947169088, 0.22328149614622816, 0.15131304622627795, 0.16067509073764086, 0.13171093713026494, 0.09427627359400503, 0.16958478139713407, 0.1677240093704313, 0.16005110781406984, 0.15691578621044755, 0.24078255548374727, 0.14807357161771506, 0.19194119347957894, 0.1449016176047735, 0.13665730686625466, 0.22780399565817788, 0.1705427307751961, 0.10599209141219035, 0.1659438048955053, 0.1281252209446393, 0.24363082920899615, 0.2062130198464729, 0.10225922960671596, 0.09320522091002204, 0.10757325930171646, 0.17572206066688523, 0.08848182944348082, 0.10086276000947692, 0.2294068268383853, 0.050466643151594326, 0.13062088546575978, 0.15320341510232538, 0.11905260660569184, 0.17516858177259564, 0.22932997002499178, 0.255298771080561, 0.18206645851023495, 0.17863927991129458, 0.18225444451672956, 0.1556022887234576, 0.1427551484084688, 0.1308968011289835, 0.1104325836058706, 0.11406163379433565, 0.2627720794407651, 0.09765343143953942, 0.1257398395682685, 0.13149399252142757, 0.1332555097178556, 0.06953548203455284, 0.15054882707772776, 0.12530468869954348, 0.2148227789439261, 0.16121348919114098, 0.11011219103238545], [0.04005905728263315, 0.047095582049223594, 0.05003252015740145, 0.041706224365043454, 0.038759849849157035, 0.013741177790507209, 0.046929047821322456, 0.02688869681151118, 0.04880782435066067, 0.023463646321033593, 0.015005531186034204, 0.009366740450786892, 0.019115152608719654, 0.02514705432986375, 0.00595502542637405, 0.004384064850455616, 0.053369913730421104, 0.008033188278204761, 0.05109726087539457, 0.05751892371335998, 0.04790709826920647, 0.051647645013872534, 0.04057633792399429, 0.06871008765301667, 0.03848678774375003, 0.06687358385534026, 0.06499792434624396, 0.04065844914293848, 0.05782763117167633, 0.0760879780864343, 0.03199971943104174, 0.1253129413817078, 0.04201734751404729, 0.02506898596038809, 0.03434722158999648, 0.027242211435805075, 0.10391766991233453, 0.05628383041766938, 0.02643872154294513, 0.029976929145050235, 0.02569544580182992, 0.1056493676151149, 0.06438564509153366, 0.051737155445152894, 0.03911726817023009, 0.033997447389992885, 0.025817942841968033, 0.02090598278300604, 0.04202515490760561, 0.06036428079823963, 0.00819820203105337, 0.01348836240140372, 0.008596085026510991, 0.07558671670267358, 0.05769878320279531, 0.031289009129977785, 0.027152873553859536, 0.0728278791939374, 0.018588693455967586, 0.022236260228964966, 0.017505185678601265, 0.06342848239000887, 0.07778823841363192, 0.021029678391641937, 0.03490164672257379, 0.0602805405651452, 0.03487399430014193, 0.008709443445695797, 0.026629598214640282, 0.0235810986123397, 0.0584968628390925, 0.04061655119585339, 0.011898209886567201, 0.02764276523521403, 0.02143787260138197, 0.019411492176004685, 0.04502554293139838, 0.019287599898234475, 0.045154309264034964, 0.004088710948053631, 0.02450238218443701, 0.04236474684148561, 0.06581666166312061, 0.05876551287656184, 0.03461233158304822, 0.007959977265272755, 0.011269326005276525, 0.027028649165004026, 0.045390401282929815, 0.036463986325543374, 0.04179423936875537, 0.06464515929110348, 0.054385268231271766, 0.00871270518473466, 0.05538822144444566, 0.004580126815199037, 0.03148414572933689, 0.03910177212674171, 0.0537252429057844, 0.06054097873857245, 0.03870369524520356, 0.04585977258102503, 0.023001574045338202, 0.09234717203071341, 0.04330782358010765, 0.050322358511039056, 0.04063114924065303, 0.029400731255009305, 0.03303179451904725, 0.01581642121891491, 0.05895379574212711, 0.027443474464234896, 0.02164186673326185, 0.05294687100104056, 0.005560893059737282, 0.07154595266911201, 0.031113576551433653, 0.020680607376561966, 0.030958955649111886, 0.05608186977042351, 0.02325841094716452, 0.0340942939510569, 0.013020115457038628, 0.03718073770869523, 0.03519576355756726, 0.04922908963635564, 0.03185171663062647, 0.037322268981370144, 0.0393876511225244, 0.028057952331437264, 0.04977903590770438, 0.05518112884601578, 0.03310097010398749, 0.04870748227403965, 0.034295735094929114, 0.027673582917486783, 0.04538860528555233, 0.03049631563044386, 0.0481682711688336, 0.05610838299617171, 0.04890452248218935, 0.012658558734983671, 0.08416103082709014, 0.019496685163176153, 0.05955037857347634, 0.020737971681228373, 0.03517968121741433, 0.04701455436588731, 0.0011055285744987486, 0.0732609372062143, 0.052477366116363555, 0.03505635482724756, 0.012262892905710032, 0.013159406371414661, 0.028358236413623672, 0.044078020728193223, 0.07901049626525491, 0.043371930296416394, 0.06821198781835847, 0.03533281596901361, 0.03054376669751946, 0.028616869312827475, 0.05131224621436559, 0.04089696427399758, 0.029381351923802868, 0.02194317312387284, 0.04026554131996818, 0.05753108380304184, 0.04436836374225095, 0.1185963193711359, 0.08730536210350692, 0.029084841662552208, 0.02145757847756613, 0.030952285596868023, 0.06952499548788182, 0.057790134160313755, 0.08595072737080045, 0.0213449334478355, 0.03539802106388379, 0.08570345118641853, 0.007180454103945522, 0.06571722129592672, 0.007934745171951363, 0.04312708093493711, 0.015354092902271077, 0.026314009191992227, 0.11002529296092689, 0.015158298574533546, 0.08620004446129315, 0.04406953426951077, 0.02496255827281857, 0.03667609584226739, 0.050756934215314686, 0.09299166791606694, 0.03567626336007379, 0.05756774960900657, 0.1046837073226925, 0.037580061398330145, 0.005779155908385292, 0.04937708130455576, 0.02131922730768565, 0.04538505039818119, 0.038314832127070986, 0.026488484400033485, 0.05401081762101967, 0.06130103443865664, 0.055296017017099075, 0.05396984735853039, 0.04750671701913234, 0.007630265636180411, 0.06811265877331607, 0.02450217438308755, 0.09035803072038107, 0.04130117500608321, 0.11834389268187806, 0.05650562496157363, 0.037698504456784576, 0.026740456523839384, 0.022072240026318468, 0.04353914730018005, 0.013612184175144648, 0.02621587314934004, 0.03990849407273345, 0.020309576211730018, 0.025775838948902674, 0.03072698997129919, 0.053770591839565895, 0.07348688406636938, 0.02400697263510665, 0.022832720605947543, 0.014557115355273709, 0.015258022813213756, 0.0733016365848016, 0.01078648379916558, 0.037037339934613556, 0.05213344375079032, 0.034155398680013604, 0.0161685647253762, 0.033737417397787794, 0.013103197034070035, 0.02954378393042134, 0.0534265284659341, 0.025633461627876386, 0.03203433319868054, 0.0366794355068123, 0.050998622027691454, 0.03858178635709919, 0.04525942335021682, 0.012241167460160796, 0.06739016316714697, 0.04076082470419351, 0.07319018826819956, 0.058263119717594236, 0.033462837600382045, 0.027070237265434116, 0.01713402092718752, 0.03640516741143074, 0.0839595303114038, 0.07225387991638854, 0.031954073638189584, 0.003216815912310267, 0.01870953736215597, 0.044168095191707835, 0.040537961467634887, 0.05358895119570661, 0.024382397314184345, 0.05421986206783913, 0.058903466997435316, 0.006076611944081378, 0.024147865660779644, 0.02434980960970279, 0.027735670992115047, 0.02933551873866236, 0.028218107800057624, 0.05597982817562297, 0.08499740899424069, 0.008788403320068028, 0.0653661038086284, 0.021813134007970802, 0.039878114257589914, 0.025752661676960997, 0.06223792537639383, 0.023042338361847214, 0.04824305739020929, 0.057042843400267884, 0.08168128537363373, 0.06796695291996002, 0.030763249451410957, 0.03203242587915156, 0.027926128350372892, 0.011421909712225897, 0.02558406242314959, 0.035811144989565946, 0.024320338925463147, 0.01434019579392043, 0.10663777473382652, 0.0709280776209198, 0.07142154645407572, 0.074656464275904, 0.035516100469976664, 0.003016437431142549, 0.0786513858474791, 0.009764127134985756, 0.02491268409357872, 0.05873557092854753, 0.034230025339638814, 0.0216524349161773, 0.03225234650017228, 0.05905992285988759, 0.016966688890533987, 0.0374607797130011, 0.09013467395561747, 0.0245346303563565, 0.03661548093077727, 0.002894853928410157, 0.05419625806098338, 0.05674569489201531, 0.02015375859627966, 0.03724883346876595, 0.0804328742378857, 0.05878647483768873, 0.0278186097057187, 0.04229100333759561, 0.0917883645161055, 0.10060858927317895, 0.05589537548075896, 0.05364928409107961, 0.0486009061569348, 0.028832702555519063, 0.044325300623313524, 0.018252283480251208, 0.029134658325347118, 0.033439404287491925, 0.0060918899816897465, 0.05087190402264241, 0.05478752340422943, 0.06386666864273138, 0.028615318224183284, 0.04732952183985617, 0.02376449072471587, 0.008608716379967518, 0.103077128296718, 0.023821901413612068, 0.04136390874919016, 0.03055493230931461, 0.07531024442869239, 0.017324923574051354, 0.09058898707735352, 0.0638398177397903, 0.002454746904732019, 0.11038377255317755, 0.029675758196390234, 0.19284288806375116, 0.12476737378165126, 0.10617167630698532, 0.18952243030071259, 0.18532598594902083, 0.12112810421967879, 0.1623247514362447, 0.20641531446017325, 0.08445337763987482, 0.09151728023425676, 0.17137607355834916, 0.06642140069743618, 0.14022969407960773, 0.1504689423018135, 0.1525656579178758, 0.131758508796338, 0.11313734081340954, 0.15972365741617978, 0.10409832349978387, 0.08609877098933794, 0.3029707458335906, 0.12726945045869797, 0.17733755288645625, 0.16446840047137812, 0.16323984920745715, 0.11837928570457734, 0.17272937984671444, 0.11279814221779816, 0.16841578006278723, 0.1191716842004098, 0.17798840155592188, 0.1853495417162776, 0.15649475099053234, 0.05828053421282675, 0.17104451166233048, 0.19350791175384074, 0.20760110317496583, 0.12051309386151843, 0.18426076654577628, 0.18034334003459662, 0.11970821244176477, 0.1919888987322338, 0.16412552824476734, 0.13214405451435596, 0.12511708860984072, 0.12323699847911485, 0.23396079341182485, 0.08521271345671266, 0.07886335806688294, 0.2594206889625639, 0.12406329085933976, 0.18093126942403615, 0.07808537950040773, 0.0696173780306708, 0.1278247105074115, 0.1362600500578992, 0.11516383441630751, 0.12561710318550467, 0.201362565276213, 0.14072706660954282, 0.1596872476511635, 0.14843658573227003, 0.14453717856667936, 0.10045897230156697, 0.10967882131808437, 0.12225021666381508, 0.08762922792811878, 0.11789697877247818, 0.0834834499983117, 0.10310653960914351, 0.12178195858723484, 0.07568322558654472, 0.09063257341040298, 0.14291012368630618, 0.22716751496773213, 0.11104412071290426, 0.17882558866403997, 0.07581019221106544, 0.09983117473893799, 0.08465804712614045, 0.10938208099105395, 0.16649640805553645, 0.12728479807265103, 0.24261782731628045, 0.1430129408254288, 0.13685218000318855, 0.11158033725223504, 0.08259451293270104, 0.19218547880882397, 0.1648500276496634, 0.130027879786212, 0.16578415408730507, 0.16982071014354005, 0.14752175513422117, 0.20220763399265707, 0.17567239614436403, 0.22877089533722028, 0.1557929316186346, 0.18386215902864933, 0.19019018509425223, 0.06585466704564169, 0.1481971688917838, 0.10155653450055979, 0.17733130400301889, 0.1320645259693265, 0.11569006164791062, 0.09742457536049187, 0.11674903216771781, 0.12352909296168946, 0.19932735885959119, 0.15166859433520585, 0.19472126383334398, 0.14210795110557228, 0.16778194141807035, 0.17973344307392836, 0.11704603966791183, 0.13195312960306183, 0.19536991574568674, 0.1306735334219411, 0.18015795154497027, 0.2164484534296207, 0.17818271066062152, 0.1551086120889522, 0.1185282644291874, 0.08344930378370918, 0.19872397795552388, 0.1228977701975964, 0.11272518910118379, 0.17654289084021002, 0.1323543643229641, 0.14730179740581661, 0.1880791163421236, 0.11756857100408524, 0.23461060307454318, 0.18008767015999183, 0.15623047220287845, 0.09667223057476804, 0.08664355191285722, 0.09399295129696839, 0.1762684594723396, 0.09573828967404552, 0.07130931146093644, 0.2339689718792215, 0.18198868143372238, 0.14284390927059576, 0.17000589083181694, 0.10345680362661369, 0.15158210444496945, 0.14779832388740033, 0.1474251868785359, 0.09836472803726792, 0.10440163183375262, 0.07771042422973551, 0.08733392736758105, 0.1358323503518477, 0.08599147869972512, 0.2901621675118804, 0.1727687136735767, 0.11441521521192044, 0.1654770236928016, 0.08706855762284249, 0.1081781838729512, 0.1886603664024733, 0.11119001210317947, 0.07432300990330987, 0.21639807644532993, 0.11775884282542393, 0.1090705199749209, 0.1527168185566552, 0.18828430533176288, 0.1142442540731281, 0.1287684848648496, 0.1795771616161801, 0.07518467304180376, 0.19129681633785367, 0.17609666712814942], [0.02844073169399053, 0.027065131289418787, 0.03659991067252122, 0.014174789630487794, 0.030182273985701613, 0.050075375474989414, 0.04905120425974019, 0.07828555157175288, 0.04653296360629611, 0.045807670103386045, 0.05486310001288075, 0.04318201099522412, 0.023704352643107995, 0.050864964941865765, 0.03437985011260025, 0.03349956648889929, 0.029706538771279156, 0.05674636653566267, 0.018859404808608815, 0.13401717587839812, 0.04030024785606656, 0.049365314553142525, 0.032764858842710964, 0.07026804858469404, 0.032970689790090546, 0.05818465244374238, 0.034411354281473905, 0.05247421198873781, 0.041077172572840936, 0.028303788749326486, 0.07146695847040974, 0.06642328575253487, 0.01426789947799989, 0.019196553221263457, 0.05030883658037055, 0.03434018974076025, 0.051575370962382294, 0.03659195113868918, 0.0038872888217156287, 0.03274825699918438, 0.02290672571689356, 0.04544762457953766, 0.04742744080431294, 0.02407082331046695, 0.028132959341746755, 0.03462781649432145, 0.059095074684591964, 0.03246284555643797, 0.004194183584331768, 0.06534286716487259, 0.02328749014850473, 0.05664514872478321, 0.024699620917090215, 0.10282129514962435, 0.03659362097096164, 0.061528751321020536, 0.05684477902832441, 0.017772353276086506, 0.03149325188132934, 0.0349439825367881, 0.05260572426777799, 0.06168363011965994, 0.044646142196143046, 0.015282111999113113, 0.03719584412465338, 0.08708110734005459, 0.05894506066397298, 0.052357008316903375, 0.07864250233978964, 0.021103720609971788, 0.008703471939952578, 0.03775120807404164, 0.054007667204132304, 0.03078630983509356, 0.04140226294111926, 0.020516102922556456, 0.026569411893433426, 0.007784777535562171, 0.05881048331502825, 0.04681274956965353, 0.030245614434534218, 0.012593874998856336, 0.06654934695689008, 0.03803381048783194, 0.0035979066569780116, 0.04123082311707549, 0.018405273513053544, 0.03816902979451697, 0.03131985278741922, 0.06475519752711989, 0.06588778167497367, 0.00935059131734306, 0.03094590312684886, 0.07286348743946292, 0.04763127537444234, 0.043520300459931605, 0.0469886608334491, 0.012596975320775528, 0.050851480118581094, 0.017927436165336985, 0.024543667859688867, 0.022038349852664396, 0.01763668125931872, 0.03790229820879176, 0.04929345610435121, 0.02202429728640709, 0.06949816684937105, 0.017269349700654857, 0.04065195535076782, 0.03405477458727546, 0.030937164337956347, 0.01742263473715866, 0.05184123794606421, 0.022672522463835776, 0.04322956781834364, 0.06399203222827055, 0.10178023265325464, 0.01814091494452441, 0.05049056628195103, 0.012887783104815753, 0.046083615452516824, 0.03143157569866162, 0.05510564129508566, 0.016535966788069345, 0.03156398226565216, 0.036249757977202535, 0.038107179207145236, 0.02154517416784074, 0.04084764113940764, 0.025745294005901087, 0.03450993375736289, 0.03551716174115427, 0.02026260939601343, 0.06968177418457344, 0.104540049796924, 0.0414967568940483, 0.07430291996570304, 0.07101249691913836, 0.044034300808561966, 0.04585214701364748, 0.03413097088923678, 0.06632309581618756, 0.009269672173104482, 0.02883118486352032, 0.021097634999023285, 0.021914034550718497, 0.012896323369204765, 0.0419474520458607, 0.031005228556750808, 0.08174518428859301, 0.028546190878842026, 0.0575207568181213, 0.023714393901173025, 0.05010887973185163, 0.04879900392552372, 0.020694242484751157, 0.10477455361979082, 0.03795672731939703, 0.03422362060518935, 0.020573274268826935, 0.01829724835261004, 0.031037391381687485, 0.049377192626707256, 0.057818651184788905, 0.030066797662584577, 0.0494318480923539, 0.04130809182242956, 0.03645785618573427, 0.05946579600276891, 0.023131034286052454, 0.0324027501483215, 0.046934543424868025, 0.066361153149046, 0.014913094837538665, 0.05691626269253902, 0.04918635306239594, 0.036059111371287145, 0.013071205830783583, 0.048548814811510965, 0.07554303389042616, 0.016427405425929464, 0.031210712550091557, 0.029517356051655952, 0.04131796980800573, 0.07548591820523143, 0.02737341943429783, 0.03358276124345139, 0.03979462264396716, 0.014848362861812348, 0.034140778370783664, 0.058118857341469266, 0.031191071611829102, 0.02746692447544774, 0.05620897740300279, 0.0747840320400428, 0.11600263198488392, 0.03118474480288569, 0.021815082145622, 0.06171629574964754, 0.0510569511243375, 0.0909181592578534, 0.011182427933817962, 0.015930153494991828, 0.020417167215782683, 0.034421417803969234, 0.056681988935451955, 0.02608024009532528, 0.040980511548696086, 0.02424418900773162, 0.035193414660170674, 0.05368895559513476, 0.054644366828142665, 0.00982451754680369, 0.026872466041822918, 0.024540868107578717, 0.0517803781258408, 0.02228812521934742, 0.0013602763306153065, 0.06551964674144983, 0.038792129562352784, 0.09467157113249414, 0.023294013626582455, 0.01442641943867784, 0.033108076167991385, 0.02252987240353832, 0.026804598492162768, 0.045328947744565085, 0.11783371810452081, 0.029752956397715025, 0.017188457459269557, 0.03909228376869578, 0.0394974036316853, 0.017144138255389407, 0.06187766462971922, 0.023919393643154763, 0.03730303993506823, 0.03915918838174548, 0.025088519287237432, 0.015169292564678472, 0.029505353668355383, 0.02768411213764921, 0.10186285595409572, 0.03396664826141205, 0.04831391393963713, 0.07873605005443096, 0.06961871389648877, 0.05581846671702806, 0.07181163411587477, 0.022877481387695298, 0.04182275268249214, 0.011572679795790464, 0.020460658925003372, 0.0651739766180981, 0.03347792546264827, 0.05122527392813936, 0.01792684615793405, 0.041002289872267283, 0.015004609067545971, 0.07772988334181719, 0.050452215800760314, 0.047565973800374195, 0.032662872908986174, 0.03043533521122299, 0.014851946507405955, 0.04620628875272814, 0.06201884709298611, 0.0371323199942708, 0.03105043277173536, 0.009031397312355693, 0.028301126294536516, 0.04938206111546606, 0.02241022521047853, 0.04909823044727091, 0.07130389378289692, 0.10199791940976866, 0.03797248311457224, 0.047251169598894194, 0.020932269653712865, 0.021057527483208105, 0.005708812368538929, 0.06535134991281666, 0.016501770478498656, 0.041479672654531896, 0.03460180421825498, 0.007822714269423159, 0.033847515005618334, 0.01539692410005955, 0.00801487207354512, 0.08176662493497133, 0.01823439401050564, 0.05249566376733128, 0.03793477459112182, 0.06041364846169017, 0.050593528139870614, 0.08960006045526825, 0.02301250588061521, 0.01798926263290923, 0.04763598430145066, 0.08765529215452261, 0.050121255044359714, 0.04199769544356968, 0.027837285852001514, 0.02224899177235784, 0.061885713221272454, 0.012690715066128178, 0.014607681587222032, 0.13186840602429584, 0.028388705286488403, 0.02781312337901909, 0.0678004595101811, 0.027599358872976154, 0.03396030289877672, 0.10631855475367047, 0.08502979631884955, 0.027198304123885464, 0.02781398612569319, 0.049064856066252105, 0.03745012989384122, 0.03684559866087511, 0.014082933084864635, 0.03025056084879907, 0.03487057299935259, 0.039679838373558596, 0.029485321247193497, 0.01778805897629354, 0.0607306160236476, 0.020201949955662712, 0.026479547086637467, 0.01603654964128509, 0.017828986565291416, 0.1299560398911126, 0.05526267603272572, 0.017619955106056295, 0.012887791453977115, 0.05608905375993345, 0.03396869287826121, 0.08360732928849757, 0.0712627342727501, 0.020938566776749212, 0.03340754388773348, 0.04076975274074357, 0.03749450290342793, 0.044104760308982804, 0.006738763522662339, 0.027592545957304537, 0.034003024629782885, 0.012684346511377953, 0.06413545226678252, 0.04250615194905549, 0.0402262297575362, 0.00954287343120086, 0.06054972494894173, 0.11157526096212678, 0.1438948794384487, 0.19215211184928194, 0.11127359277452342, 0.1205338814179413, 0.21086582564748824, 0.1543236870202236, 0.1584145682863891, 0.2053212997270748, 0.12878708308562636, 0.10636103528668173, 0.09198362356983125, 0.29115397366695106, 0.11821077365311794, 0.12714537821011618, 0.14283311844337732, 0.20789621077710763, 0.13231599528808147, 0.30951061053201556, 0.32890747126657516, 0.16831343789817765, 0.1315311444341205, 0.21953615883830935, 0.14740207639988512, 0.10203227342572063, 0.17714177432935685, 0.25336221093311906, 0.09110869825235568, 0.17379544529831037, 0.15778641449287534, 0.15413725952384993, 0.22850870940601453, 0.12325681382208131, 0.13234655692940578, 0.21196597052039579, 0.13615484320325777, 0.10296840366208926, 0.1144179908442311, 0.16655103012453765, 0.15250771102728322, 0.1442795345792547, 0.08998748380690813, 0.12950880685821176, 0.12427450608811341, 0.11005151303834282, 0.24480809806846082, 0.1682399949640967, 0.16047628421802074, 0.12867188692325726, 0.15561906126094982, 0.21335544908652082, 0.22180315281730145, 0.1296771111083217, 0.16277098999125883, 0.18549553700722754, 0.17006377835059538, 0.12920134991873056, 0.07935152054415084, 0.11385952471755445, 0.14428124151891097, 0.13812733814120293, 0.1927945445640944, 0.0828549919242505, 0.09606813720893115, 0.10009142366470769, 0.2280303358566016, 0.28136157256085426, 0.1736281652119942, 0.11637064817477949, 0.2506599621847272, 0.12001523893559352, 0.18140787666197866, 0.14861667528748512, 0.1661718520335853, 0.07939630915643647, 0.12504639162216336, 0.1406027123448439, 0.10354917132644914, 0.14026220014784485, 0.09473187063122168, 0.21826153504662216, 0.06255786895053461, 0.14028823468834162, 0.09366544152726419, 0.09736582695040852, 0.09821977175306529, 0.1775349790113978, 0.11557506586541422, 0.11031801826902665, 0.18887455022195354, 0.18393729405943304, 0.25426466250792146, 0.126390851510223, 0.12897241220343858, 0.10524976562010124, 0.0721622617857065, 0.19294889643788338, 0.11253534030402079, 0.1966415115748532, 0.13214877457357943, 0.1744127192068845, 0.08219971263315529, 0.1551190169993788, 0.1529029937228188, 0.15327059431001544, 0.1548699670820497, 0.08798617869615555, 0.13742243143497035, 0.14525713602779433, 0.16018079069908708, 0.08494688358041458, 0.09920951473759487, 0.26476539904251695, 0.15748609701404348, 0.17604174820007756, 0.13342241873033345, 0.22683158924337476, 0.10268376776366495, 0.2722846018150449, 0.13497454638127238, 0.14365719922352582, 0.09658748473157175, 0.23120258672861382, 0.148559158842545, 0.11807962131570093, 0.10416468634502962, 0.2507925097597763, 0.20755559467943385, 0.09221044616424479, 0.1681422392721288, 0.31931206583976746, 0.22468644106993452, 0.13630135799758136, 0.13713281572563574, 0.20160668733296916, 0.12874213862232864, 0.19547497417079285, 0.22923815151443705, 0.17899123602546751, 0.1634406446828507, 0.14350545970955864, 0.13173591782106087, 0.09684837932582013, 0.12920638167997822, 0.11847274436149746, 0.11805627334979363, 0.13363094738451764, 0.1135590736521408, 0.11047973224776797, 0.18742541782557964, 0.12134272590628825, 0.20156662620138377, 0.11579206242458895, 0.07138222747016698, 0.18792400747770444, 0.10652637836756185, 0.352872577495873, 0.15689208201365545, 0.19889241579221562, 0.09997258355724625, 0.11381851363694295, 0.1525925236637704, 0.09914808717439882, 0.13466248812619597, 0.10742613594629802, 0.13835845777066424, 0.09763512265635654, 0.12814724788768217, 0.09537071135127917, 0.12622276990441605, 0.11257554244366474, 0.16908095218241215, 0.15724939643405378, 0.11367723840521649, 0.12840677693020552, 0.1865617954172194], [0.047847934256424196, 0.032410179046564735, 0.06135318515589461, 0.047722158778924495, 0.01208826370202587, 0.012881091715826187, 0.009212260556523688, 0.04220736700517591, 0.02331765845156042, 0.037112400750629604, 0.09227393689798191, 0.11160687645315193, 0.020332560525275767, 0.057307200113427825, 0.03435406419157516, 0.010541997162363259, 0.04311621218221262, 0.004193376034891116, 0.02108722266711993, 0.019348443020135164, 0.06931973228347488, 0.06808847218053415, 0.010221510892733932, 0.026791757481987588, 0.01524342384072952, 0.011009821082552662, 0.02120080651366152, 0.026454952312633395, 0.03911662250175141, 0.017407869709131774, 0.04237141503836028, 0.016812782305350993, 0.028794654499506578, 0.030626111692981794, 0.047229090705513954, 0.01843499281676486, 0.06938185746548697, 0.0071147271864901995, 0.04348795766418334, 0.07266091080964543, 0.03569903245079331, 0.06332716438919306, 0.0256682943290798, 0.03879825228068512, 0.047048611522768624, 0.08186749764718115, 0.03778627826250158, 0.016181355640583206, 0.01873085740953684, 0.03706142262672074, 0.026722214533947408, 0.06676257340586744, 0.05183062152354978, 0.06089116483053658, 0.057619948565843515, 0.08658654012833722, 0.04022490502393339, 0.018805838444677647, 0.008549060694349464, 0.05660866845573764, 0.046242579774116166, 0.03807976798270829, 0.03466506859695073, 0.033200536636286415, 0.029201718789408915, 0.04424004640895873, 0.051005958157475106, 0.028511853561212774, 0.00955701783823315, 0.035118891901220195, 0.0562680894654477, 0.0049008561381924665, 0.03104253817582503, 0.024947060373960994, 0.09786319205886684, 0.0735269600409083, 0.027410973962105345, 0.04414271374116652, 0.026034089642053004, 0.018642983413883485, 0.02344678658118937, 0.056088129786076024, 0.050361388057353906, 0.06885623879497871, 0.010596465235721553, 0.032556092701270245, 0.030144454140099697, 0.05648459991789423, 0.061434075541910715, 0.036069679554202594, 0.033052270373445936, 0.062027786261751316, 0.04378163292130921, 0.0809956225566566, 0.0646781106479466, 0.02404369781288551, 0.03347544297866989, 0.031653351688873954, 0.051760521964752115, 0.03167122260492761, 0.03500099803204648, 0.10448823304614052, 0.03958531473472249, 0.055734667112119496, 0.02799138725094963, 0.0125592686526943, 0.05540952108276542, 0.03458805222180672, 0.03912887164915446, 0.06652173906331882, 0.036807307551498525, 0.029402855652733706, 0.05663537835062016, 0.007450080529451952, 0.017770195481716655, 0.024535296433896292, 0.021141462530067656, 0.02358180921874009, 0.09414144762558863, 0.015753034385852516, 0.06468945808592252, 0.04248483004630543, 0.03445742680924013, 0.037040356764919125, 0.04635298166249413, 0.06970352653297596, 0.017334044568997342, 0.021766072568425443, 0.040252327380585484, 0.03636300600192044, 0.062164404516806826, 0.02227884095191257, 0.00871809874297469, 0.02506598953914363, 0.013150555332686054, 0.044812665291829035, 0.07578379401820712, 0.048727516550570726, 0.0899227982154116, 0.05058746850409079, 0.09326782848802395, 0.019515814019541722, 0.018020043207798153, 0.027548258294700645, 0.07125722753698938, 0.04528860830760095, 0.04713834459835198, 0.05921826006670017, 0.09251399198547006, 0.012297586454224074, 0.03498680074699223, 0.029560328257502988, 0.0036905194974679034, 0.03750957221200224, 0.035835713788401335, 0.04384771003969945, 0.017792573089536745, 0.08157208576449193, 0.02078606470604427, 0.09682669377070852, 0.06059765655663796, 0.02284699210576946, 0.022116566651675384, 0.030314350296976045, 0.03203925363777671, 0.026078444097947795, 0.05891671062272508, 0.028565672255354002, 0.026242315871058963, 0.0295492813893361, 0.04385155807540286, 0.04312670986109879, 0.059891183918807656, 0.010363769470131956, 0.01406994735589251, 0.012356410006759688, 0.04458679264644161, 0.02853779533324996, 0.01943231312907301, 0.04010737109638285, 0.02076558885164559, 0.05582266727287788, 0.05387085227994248, 0.04637048150470946, 0.05145526920387056, 0.025114403542829677, 0.07200604712124914, 0.06504654244054109, 0.06727837346261367, 0.06833050138084218, 0.03827174674370326, 0.02258868389617419, 0.061622265639016405, 0.02739878233114723, 0.029649846110260114, 0.04346445384726394, 0.04900966254353989, 0.015156401459535118, 0.010913127589446958, 0.04579184751491994, 0.09669368606409989, 0.0316629031294724, 0.11721232527634129, 0.033257181057706475, 0.018814766481227707, 0.044480097785708494, 0.021835426268808078, 0.021860314191144425, 0.030569895861844998, 0.06966295331949368, 0.069895534979878, 0.05356295747333206, 0.0721353515109513, 0.01168426540971268, 0.07799773185979575, 0.035753135016420856, 0.02240820656879805, 0.05527771565539297, 0.05542910635995213, 0.01212464841955807, 0.029030789191892836, 0.07835994445485994, 0.022469684226962272, 0.0270788944180822, 0.06119843623309862, 0.03451839795161504, 0.07567823835415766, 0.06400325350114144, 0.018740093437372707, 0.026580356716294773, 0.03538043958542403, 0.026651040716387797, 0.03964825998991728, 0.023375191594823264, 0.009012402042571921, 0.017724857680150308, 0.046336646992131136, 0.06851789366919547, 0.08125517386361025, 0.04157630399276968, 0.04821278889721725, 0.017116342969529796, 0.06439108503400348, 0.02690061941393651, 0.02135377799277194, 0.04899185099930037, 0.01387076419632649, 0.05575149531068746, 0.07510511481086724, 0.05463058885652572, 0.015748926598462276, 0.05481795145897195, 0.0428684721555328, 0.05874662892892957, 0.030200508554116823, 0.03275727780419402, 0.05890370077395346, 0.07945440447656438, 0.0784732258762233, 0.004999961147404974, 0.007658289596292889, 0.03759745733987074, 0.01627803336305078, 0.027919179992750287, 0.016104066526168026, 0.06921857755514793, 0.02771423962258268, 0.020600299576472025, 0.06496383008197881, 0.013140011269570095, 0.006680065671389457, 0.01728233357425779, 0.019731639840756543, 0.09300638470449485, 0.03472223623248283, 0.07821570805390365, 0.06166156235849485, 0.022672832310490776, 0.048129249043995515, 0.0700454339676071, 0.07498821170884185, 0.04499046161072329, 0.018672908663575072, 0.04462110955500975, 0.031754087103763595, 0.04704434788436629, 0.07268709377967753, 0.054703783171135, 0.040842802336555906, 0.021039740058768075, 0.01664736872044159, 0.04424484068294987, 0.0452706483338261, 0.017597527403268032, 0.04842749593080953, 0.03808989087701775, 0.020565813829307444, 0.03230859758332372, 0.03316617148811929, 0.055168337930808775, 0.03995265557023231, 0.03471170144621283, 0.07844722844311036, 0.027894345876120497, 0.06512876498163678, 0.024772535070951562, 0.05070512488600798, 0.04166964761679992, 0.019396537900320254, 0.038465462130261585, 0.06945667337276973, 0.04664071602746844, 0.029463663522619754, 0.04074401505931746, 0.033914994783117436, 0.01853526810009498, 0.05032713423133828, 0.013496722694981145, 0.030275680692284368, 0.02587783230410423, 0.02545484709116863, 0.03760492334549781, 0.036291989890742116, 0.026168273652729113, 0.1071725737710949, 0.05424435294116847, 0.015361598798335763, 0.01748712737025926, 0.030948387466196436, 0.03183521497703623, 0.04861399022047408, 0.034671614339458756, 0.02188626709539676, 0.00836458968478837, 0.051154521279386245, 0.04741228243801743, 0.03346874509588815, 0.02209465474152239, 0.021026557660661638, 0.05341351861716248, 0.007425984385918127, 0.008915010930650169, 0.020165835194347892, 0.03693824095535092, 0.07139739696867764, 0.052192444491083734, 0.041258820638176985, 0.0603834987123264, 0.0431046420999337, 0.042104549866053276, 0.09619322619982995, 0.037741615815320984, 0.13878421304980293, 0.2628508658381179, 0.09328281987109222, 0.1735783225740306, 0.10418603793368675, 0.131111103692092, 0.10738436787505634, 0.137122574087698, 0.10630429067532532, 0.1143313451029826, 0.14210774330422282, 0.2404117042897269, 0.17042697058059275, 0.15278554143151268, 0.11717388202669099, 0.196703837136738, 0.16956588631728664, 0.18748395843431354, 0.08793989094556309, 0.10344876616727561, 0.11426829965785146, 0.0977854298253078, 0.1160082351998426, 0.18863658799091354, 0.23019336978904903, 0.10784369791508652, 0.20035147812450305, 0.12491537287132815, 0.1338377987849526, 0.13592633593361825, 0.07753942598355934, 0.1599880401045084, 0.13272129697725177, 0.1462276277015917, 0.10064209724077955, 0.1169143158767838, 0.15979678864823654, 0.08043832160183229, 0.1908985650516115, 0.16939845780143514, 0.07674100867006928, 0.1190142153063789, 0.13674648333108053, 0.16310829611029476, 0.10739873585407622, 0.2765160606941208, 0.1450995632330887, 0.09348150764708407, 0.1255338787450455, 0.1159500285575632, 0.23156937095336616, 0.14583592215785757, 0.1497270617983304, 0.16631786216748878, 0.14996165467891842, 0.16513165784999728, 0.12143077430664562, 0.1361908225226216, 0.11223054767469876, 0.15412824985105544, 0.10092937518493272, 0.13142485404387116, 0.19423665624344721, 0.1111454535566736, 0.14161492756102234, 0.12225906306412071, 0.1835944812046364, 0.13777382351690903, 0.11027888482203707, 0.1012600984540768, 0.16507255320902914, 0.22085537086240947, 0.16005606536054984, 0.17227816890226677, 0.17657676246017218, 0.22082936600781977, 0.07302136451471597, 0.19751503423321992, 0.10231745851342566, 0.10259430928272195, 0.18078300316119567, 0.17636219272390008, 0.10977815036312677, 0.0679481914266944, 0.10050562370452099, 0.10307619319064543, 0.12318968656472862, 0.09744332201080397, 0.09661481803050265, 0.16017805959563702, 0.15444179240148515, 0.11426094497437589, 0.14950021693948656, 0.21501092822290957, 0.12114828321500681, 0.14393357501830906, 0.12435412369086407, 0.2061881430563517, 0.16794082039268687, 0.13663712044944987, 0.16945496492553502, 0.2686278917826712, 0.13713470078073442, 0.17256174352951348, 0.18334409542148933, 0.10946758382488042, 0.12841124465921894, 0.08771479013375938, 0.14428311173105612, 0.1670543398358859, 0.11258570244535804, 0.1698322282754816, 0.14623396564275026, 0.08656567835714668, 0.076546751515707, 0.11851336210384034, 0.1523792155785486, 0.10235291090793908, 0.14992548240115866, 0.18300298950634897, 0.22238340839976445, 0.24691691069165245, 0.13610814727144316, 0.19370732683455572, 0.0970824749674648, 0.14076628169277683, 0.14803677593590692, 0.17232109472388402, 0.1819618750596419, 0.1294367591617629, 0.18832075962563977, 0.10962011743686162, 0.12718600337393582, 0.20250107918400317, 0.1570792219717987, 0.12862054514698684, 0.16346065298421308, 0.14233580528525636, 0.20152901415713131, 0.11319537676172331, 0.15962274017510936, 0.088694521546131, 0.08046004426432773, 0.119735916814534, 0.14414283097721636, 0.14382927358383313, 0.13716821616981179, 0.22444448608439416, 0.1718837470980361, 0.1614221217459999, 0.1433240936603397, 0.16830472508445382, 0.11813223216449842, 0.0753037357935682, 0.09312933631008491, 0.1402558622066863, 0.1918213811586611, 0.17957109084818512, 0.14676210761535913, 0.12418249461916275, 0.1305622557993047, 0.1017432811204344, 0.1168438044260256, 0.16130889969645068, 0.12741948303300887, 0.12613804632565007, 0.11504440059070475, 0.18525576393585652, 0.1389450512942858, 0.11433688894612715, 0.1517757010878995, 0.18201539875008166, 0.11410998471546918, 0.08928497423767112, 0.13932264118921012, 0.16677524778060615], [0.004380379159556469, 0.04885881360678468, 0.058651010622270405, 0.016233291134994943, 0.0032715344605094288, 0.018480119106243365, 0.03453932651609648, 0.028205129492562264, 0.028322351718088612, 0.06747392195393331, 0.04469160987355281, 0.03305780308437534, 0.04670145339332521, 0.021033758348494302, 0.08301382637000643, 0.03558276759576984, 0.08200474301702343, 0.03692786944156978, 0.04178097347903531, 0.009874584684439469, 0.1395818288438022, 0.016103856869449373, 0.02806919401336927, 0.027942711640207563, 0.027550714803510346, 0.02894352190196514, 0.0489515412482433, 0.03400829387828708, 0.0033633295470281155, 0.17256379185710102, 0.03963409239077009, 0.011665556794469012, 0.11929557091207244, 0.049030772934202105, 0.02454985551594291, 0.012916949508507969, 0.020468547954806127, 0.022867989318910986, 0.053376158903120086, 0.0673343388189096, 0.029431574912450742, 0.01670869238296291, 0.03355265231220983, 0.0714347195753362, 0.0790829595644027, 0.027751272791647352, 0.009285912219638703, 0.04439136289875023, 0.01987042516702786, 0.082352706376696, 0.048841974276001565, 0.012910752575407969, 0.04670309725042898, 0.0382597870338941, 0.00962135554800625, 0.03574332753487397, 0.012640165532502579, 0.030391411200980656, 0.02633523276017513, 0.033640607944107614, 0.11037667762138881, 0.04768327024066821, 0.061861192662036046, 0.03314022600534372, 0.06699971927446313, 0.021792860388814006, 0.06159127355203964, 0.09832191353780217, 0.03725274458702188, 0.054598361093667336, 0.03920605500752572, 0.056302324737771414, 0.04698013355664443, 0.13451019942294806, 0.023047839531500358, 0.015704269717389252, 0.04654161704820581, 0.051980019561597146, 0.019650257781904656, 0.032083923506434076, 0.051287848109495826, 0.061925340196467005, 0.020882751705357805, 0.054228968219831586, 0.05587223160546273, 0.0910287986334879, 0.038666046093567275, 0.027595262217801064, 0.0322225084528327, 0.0382653197448235, 0.014087073341215728, 0.015414571444125613, 0.03814428659097757, 0.0824768008897081, 0.01826177554903552, 0.04034281744679902, 0.027272069892205764, 0.032810474949656054, 0.05402470691478811, 0.07800296400091611, 0.020288515916035976, 0.0703959354723338, 0.025163457648886833, 0.02343870644835988, 0.03613915199821349, 0.043751019329647534, 0.012284039476071484, 0.01894944958621636, 0.07873012029449455, 0.022299570991890505, 0.047141268660197966, 0.03383296891115606, 0.04484037337533664, 0.0544318268657662, 0.0805593807308469, 0.07584243852761574, 0.02912314947025152, 0.03184179040545132, 0.02966348492918769, 0.05669739592121914, 0.05719757748011034, 0.046037427891860716, 0.027375616191420704, 0.01863500347099034, 0.03222504288714845, 0.06640314386459067, 0.019494831649353728, 0.02894613611715613, 0.08709899309906177, 0.01647663208132144, 0.06335957397823222, 0.08675192773807794, 0.021373305753513705, 0.04249119396263268, 0.008147876997099956, 0.028492427845776547, 0.031162728992057964, 0.04827309210668318, 0.011027631699107587, 0.014852137610432692, 0.0794881276669912, 0.06153107053251006, 0.055067613648134284, 0.03169322728354018, 0.052697965802508406, 0.033718897102517076, 0.03875572721881326, 0.026664061697374564, 0.07038438765448518, 0.05178890540264547, 0.009362179953313898, 0.046495169735862873, 0.1143311669875402, 0.034800762878148817, 0.0867768342141062, 0.04955996133503504, 0.012617744323506486, 0.045372589738690294, 0.029306352334970143, 0.020126440140302293, 0.032873490708880126, 0.02943624302133685, 0.11418210662668571, 0.041621819909778424, 0.05440464199637063, 0.06938104110304266, 0.025635949677962344, 0.008928961451601936, 0.051683564961422235, 0.009714835541672073, 0.013134097280271817, 0.039563681129948236, 0.021158710042072926, 0.017140716954600066, 0.02321943706192542, 0.00895304228833993, 0.02989289947436191, 0.029618412445415743, 0.05527502165932674, 0.042331309377914295, 0.026765188595163636, 0.015147806461754953, 0.03205751047062222, 0.04378867961349897, 0.05048151950177271, 0.015042560644360492, 0.02918902249803068, 0.033368002259521745, 0.009969679776986595, 0.013339301112864632, 0.0546276499517262, 0.02456187088682782, 0.071520148194395, 0.047407540114363655, 0.019718665243999567, 0.04316300830396358, 0.09576454685884528, 0.0044248449376027565, 0.04194147404632531, 0.016449326612928417, 0.019352606468601152, 0.03704147369717248, 0.02097016928019002, 0.036737144910148345, 0.05709583274438046, 0.1312362594762817, 0.022200618586794008, 0.05774133052909747, 0.02202278144977754, 0.04404686907946598, 0.00808514974778518, 0.010915938473772258, 0.035986930088256486, 0.08587743286625482, 0.0433096937922528, 0.0447414747759467, 0.012775665927620139, 0.04908851202344522, 0.02882067419704981, 0.07178755142376758, 0.03624587654485367, 0.009259437028958928, 0.013508195370377507, 0.03737873528734781, 0.005673902205671766, 0.04071170566021465, 0.07218418482807465, 0.030548182476195507, 0.026921258540824056, 0.012101231804990675, 0.04547031203401275, 0.09470107150264084, 0.03686061972985044, 0.04266706440830603, 0.030607888256781735, 0.021393638744484633, 0.048575049731880426, 0.05132266967848409, 0.08107239031232893, 0.05443288442620542, 0.060695081992889754, 0.04639893173589371, 0.09372197091579437, 0.057283926362288184, 0.03134575003059581, 0.026458802203706, 0.004132813073738362, 0.029947560506116133, 0.049612446018727496, 0.04787863690580707, 0.061850899073760957, 0.007490613852496608, 0.014937505002308171, 0.02828977143508382, 0.019490618105919566, 0.013263615037431009, 0.06189504943904467, 0.01629434947972186, 0.06350098279654048, 0.018381229783699382, 0.06885570444865152, 0.08181916899047792, 0.030043594415474217, 0.05435367129393853, 0.06728094129357487, 0.029097862643538974, 0.044450790373957716, 0.06715455354424194, 0.04082959952938836, 0.04286187075194903, 0.01492536161094904, 0.0444749398593558, 0.07961528724990785, 0.009842552663030801, 0.03156031234539114, 0.03150809854560066, 0.041392707789782435, 0.041372899868292734, 0.05971469006908592, 0.020794983465748373, 0.026459837499714922, 0.024805438188195694, 0.037213147297734395, 0.02218306493887212, 0.05075389512057882, 0.024283029306388926, 0.011987089492322411, 0.03156194135954138, 0.032516558494535275, 0.010210477012151387, 0.07953711683512665, 0.04117286509426776, 0.06950293143745512, 0.002876225325962878, 0.038631951829302125, 0.03805735512287356, 0.018301302334293723, 0.011846778124890989, 0.03186769878084306, 0.0665535029838793, 0.030536352642229758, 0.04862035784753971, 0.05292853995342739, 0.03099936744547449, 0.05365835313568823, 0.006994532195676584, 0.015322436593123712, 0.10181450503296219, 0.03990510987932794, 0.013383250170591054, 0.06473790548625402, 0.0023207435606309446, 0.014160970840748632, 0.03430470766033977, 0.011367396182322409, 0.03577284274797421, 0.03129733231617138, 0.01692353300313698, 0.04667339650040958, 0.003917041058230097, 0.04012969489849638, 0.03177953534759581, 0.028657513030339032, 0.05284032456984278, 0.046184191305655986, 0.03288933927251492, 0.0506418233999284, 0.020463877990550827, 0.07478068495402113, 0.06496324378531426, 0.027983375766780227, 0.022653148698736914, 0.03246542080887593, 0.09278579615056515, 0.054240375029621646, 0.06661170220468193, 0.0054079535857454175, 0.025079821316467132, 0.05255519885395188, 0.06271412814385258, 0.029069503325445112, 0.01140898613812169, 0.05417432759713847, 0.01310662853938993, 0.012936065377289196, 0.02226775326562347, 0.04930525625240989, 0.04552488957415335, 0.03795369193539955, 0.03861369128571823, 0.03626846009865403, 0.07037042785668746, 0.07718279433902353, 0.11906059211469255, 0.15998674876755103, 0.1115781998669263, 0.10261801347951405, 0.10931546581559815, 0.1579826680244878, 0.09983972428017296, 0.12474692019168288, 0.24223312764661387, 0.11920396020286717, 0.08619176209322177, 0.11279867656412534, 0.10361715947510675, 0.21622411702992395, 0.07517629419453442, 0.26156323961913586, 0.16448144742753357, 0.15334587777033448, 0.1387939797132276, 0.24389872967731208, 0.10964964749291539, 0.09508016053587198, 0.07531500159529969, 0.07961553215864114, 0.11720884460373782, 0.09413000370841473, 0.16004990553483367, 0.2221389301121235, 0.296754160663113, 0.10900556721026078, 0.11907026972039603, 0.1478577550733462, 0.11537579179275781, 0.16414734738646075, 0.09682825970230624, 0.12645942595554516, 0.264852408436127, 0.15547787508694455, 0.11222058805287816, 0.13050945941358805, 0.16059536923421547, 0.14719794125994667, 0.2071794297080487, 0.20466127811232582, 0.17578984843567014, 0.13411237858235836, 0.13378363684751093, 0.06419294644729234, 0.16691799246473238, 0.1903565597604029, 0.14532707602484152, 0.148616393271368, 0.13779993227217346, 0.12381195512716658, 0.18268677522428334, 0.1302808037144132, 0.2342428985866718, 0.08448654421954416, 0.15504311013501137, 0.197278912528418, 0.138087262166664, 0.11449137440649793, 0.27877512853592634, 0.18869857216486707, 0.13426291581708938, 0.17069583584088832, 0.139786112413276, 0.19087135791778564, 0.16970662720268592, 0.08579771136282943, 0.1027414994314313, 0.11000106926076114, 0.20463714346988127, 0.1810992174432613, 0.10874945946852677, 0.10425227461382747, 0.12207619787659496, 0.05640681541990489, 0.16447331348899752, 0.16539363597985357, 0.11092079061199911, 0.138315309304744, 0.07342380893533118, 0.2223757197498344, 0.34074849681928754, 0.1243284008523915, 0.13255242869490758, 0.10358041574363597, 0.10656537822796963, 0.11351336477673613, 0.18087615753756836, 0.19153387314872816, 0.10247497935779393, 0.12922659778269008, 0.1750509365228936, 0.17396723764250055, 0.1549499706015922, 0.20397682499606162, 0.13475859625032172, 0.09242658183211461, 0.26028496446087956, 0.08617229555966333, 0.09540013008518144, 0.08263204334070906, 0.16782988415798172, 0.19889360322849825, 0.15462027891771868, 0.1643392667756416, 0.1337510417215526, 0.16299851762596518, 0.0835257227299735, 0.15705870901001617, 0.07698644432821311, 0.14153122814605013, 0.14367219060659409, 0.1438987979781814, 0.12059507891535759, 0.10256482375552878, 0.1847882554284297, 0.14385812828550115, 0.1724083416047506, 0.08256407745648175, 0.12435158554580994, 0.10342453504563309, 0.1458013677620329, 0.1337231369689107, 0.08454228693153709, 0.24933395208790898, 0.10948576644295827, 0.13075931085040793, 0.27034916973207146, 0.20201535837259144, 0.23441512137651443, 0.17332716495729983, 0.08827887431834824, 0.11594347539357841, 0.1647025183774531, 0.05063540753326379, 0.07617250870680436, 0.23954258998855948, 0.1853479683632031, 0.11893803384737112, 0.11373468063538894, 0.1924492380931042, 0.14435272518312559, 0.12392222342896275, 0.19263434456661344, 0.12653012294322252, 0.08237797650508583, 0.10675922720110975, 0.14151380251860246, 0.13794702594168484, 0.21673655515769497, 0.14108172414125875, 0.14813882124144584, 0.14616347645642236, 0.19925125903682783, 0.17978478485019878, 0.16063854738604277, 0.1534860100946389, 0.08854691579472274, 0.23861992231104523, 0.11703643627697602, 0.15670419990783557, 0.1302233466412872, 0.18808496446581557, 0.12843125296058133, 0.14885383599903435, 0.08340248168678954, 0.13528417039196938, 0.12637053150683641, 0.1056842040270567, 0.18358809873461723, 0.1527565679862164, 0.13813618454150856], [0.05399926609243266, 0.017173043052025605, 0.028889198547403794, 0.03605316305765882, 0.01337141940894071, 0.028697524066956248, 0.07177169172791764, 0.06720019562635571, 0.04266679723514244, 0.028722265415126458, 0.026979967988154385, 0.03129735458060168, 0.015508337164646946, 0.07539439655374736, 0.008573324284952832, 0.029856192850274965, 0.0607560234493576, 0.028858076584583614, 0.032823718574945815, 0.035447741247480735, 0.032542251647100784, 0.10998002195265144, 0.04379107675049454, 0.06580662782653235, 0.034371397050563246, 0.04166747683484573, 0.06643282977165654, 0.08061090804403648, 0.04889385782007594, 0.014864178028801689, 0.04476432550291065, 0.01220386526256334, 0.03343722608406097, 0.07665553552214988, 0.02038939048361499, 0.051484554351191036, 0.07029521118965931, 0.04276830448361579, 0.054662063339492306, 0.048180568555835634, 0.03668389952508733, 0.07256788259837776, 0.007249044319905806, 0.01017331025650492, 0.025773955749173183, 0.02964592942589661, 0.06252394538023509, 0.05147678777575493, 0.04153282898187172, 0.011795670125138713, 0.03322520191431977, 0.046958114035078324, 0.05312308654538356, 0.05573795482632704, 0.02782130741252331, 0.015426728750753682, 0.05277687465422787, 0.01971995287021855, 0.09138594978139736, 0.0860965668107383, 0.01831310619309079, 0.01121840168707422, 0.048888989331317134, 0.04110455411137082, 0.06093012387282215, 0.012032945869577816, 0.026761019580590073, 0.011006845070369309, 0.09819413797231391, 0.017806653486331925, 0.02265305407490814, 0.01767968129570363, 0.0509899574535666, 0.04164328653132543, 0.015599571233906318, 0.007005433417361928, 0.032166847377084196, 0.012570426843012683, 0.035022301381104626, 0.05254334675555583, 0.045908472311566584, 0.023293763151741587, 0.10252015388687141, 0.03536406409693882, 0.0751016712456476, 0.02803608866088325, 0.09261609666282311, 0.02638306232256582, 0.03066263278014958, 0.039303135345107876, 0.022495299454021733, 0.027758657161029987, 0.047215479717124254, 0.018106653697032016, 0.13797121995594352, 0.010817719867191045, 0.008300971858261619, 0.016067825599748176, 0.05604701109405141, 0.02399739150860114, 0.06319043110124767, 0.021789758211525623, 0.02692619753361214, 0.03602249751565978, 0.03330335006467067, 0.02976823536300799, 0.04213325613818597, 0.032004910754039884, 0.04766155871038791, 0.028250381947145797, 0.020124293478147592, 0.04706794075900689, 0.06842200818937272, 0.042181057870038785, 0.056540127407060936, 0.020859019678027835, 0.03626690901000984, 0.030075287832005415, 0.027232652573729865, 0.008196304916054942, 0.052089085584157147, 0.06519934322568588, 0.04603539069648832, 0.030991302155598532, 0.03646992350695655, 0.033906675307662226, 0.05609038962575141, 0.03140861364954617, 0.04329679526563268, 0.0067334636605664855, 0.04661769460653886, 0.02949946472654119, 0.04072468953381758, 0.05709958801162429, 0.021423400721687358, 0.07686891782213934, 0.06687644112389535, 0.11984172480879351, 0.015115089809114579, 0.026181372559221927, 0.010203510100836866, 0.021276808001857717, 0.017281250038649887, 0.031888204321148805, 0.038023394445190206, 0.08295108520542271, 0.04054960576468147, 0.0324318534694612, 0.023113992720027454, 0.025523336189507972, 0.07101919109118171, 0.04216395507683046, 0.08490793567034416, 0.04242528753820807, 0.010284895870427135, 0.0045814803070243215, 0.05541326150705572, 0.08326682451297529, 0.01073949564670329, 0.015826638737053145, 0.011469676192064071, 0.029616223109769635, 0.037588978302665055, 0.008724812396394555, 0.01588591592735611, 0.07945490171550773, 0.025267788769269828, 0.04351840427261777, 0.0399109839781886, 0.026932437140203547, 0.03659445959783625, 0.028384037177602295, 0.06643161264946684, 0.01852865741966525, 0.05873669528227765, 0.1044520978757646, 0.01843037665821612, 0.01586102429428138, 0.05627208964142483, 0.01615875167772174, 0.031597775960108265, 0.052812252833973616, 0.017959587858058512, 0.022296320385066792, 0.02393456314166542, 0.04104528248717543, 0.057035514691961, 0.026953105952998158, 0.0268610722196172, 0.06014800783304963, 0.04022557295684237, 0.005061017636762699, 0.008098262569546932, 0.04548803452053107, 0.058539684760035016, 0.013738009747612523, 0.035078611836070195, 0.031062366506375838, 0.03433992627833504, 0.03168470000673551, 0.034885820423369296, 0.07028843538137153, 0.037732851051259786, 0.05074100030469708, 0.058539970486890525, 0.029652931589225773, 0.032715157212805934, 0.0351886723365169, 0.059460189077071846, 0.06966287168324925, 0.040837165724951774, 0.027251280480413698, 0.010026481904787943, 0.03240304329665378, 0.03683074828586541, 0.03734814024937805, 0.018053541898552794, 0.037178032580413856, 0.05974588253593538, 0.031535301968688145, 0.036778215362573974, 0.08660426261485554, 0.029388086913968436, 0.026155575505981687, 0.03291308799816761, 0.012100911753805121, 0.03306073456769809, 0.06297957952483557, 0.033916920656338334, 0.058283361795474775, 0.024147017757059075, 0.02330852446903009, 0.017577218532096595, 0.01650914186029695, 0.06082594489271287, 0.09691664949059486, 0.01680097102507716, 0.02956580345198745, 0.05853122056578286, 0.04156399918429088, 0.05709716861019842, 0.018055467771773692, 0.05403301525802817, 0.07266977205290459, 0.03252009853895288, 0.016375430968764704, 0.05109859674121253, 0.03310520405648276, 0.07122755647287704, 0.050084073445759714, 0.007270353235071525, 0.037785398817504756, 0.021292623168847058, 0.015225816387101077, 0.030273289121396374, 0.017279454041272402, 0.06072597760066856, 0.007035755252218223, 0.016220463112404104, 0.02189206326875137, 0.02079690748360008, 0.031073530262801796, 0.03630159699241631, 0.04086394612386357, 0.07087342586601153, 0.030481988469546195, 0.020495625212788582, 0.046270785096567124, 0.006935498058737721, 0.033399272651877254, 0.07907970153610222, 0.029267649333633017, 0.06479951116489246, 0.03093254261330003, 0.07125894189812243, 0.020427700146683492, 0.03694212980917655, 0.06512218213174492, 0.051048909954261035, 0.03398239292437211, 0.041461894506937824, 0.04346528876340017, 0.04351896459411364, 0.030678935909236316, 0.08025135975913145, 0.00899930684681749, 0.0330834628402954, 0.016348635726899374, 0.03105074261839036, 0.012173985469416948, 0.04788582089531701, 0.08395730386837386, 0.02480077379004797, 0.053902927902527153, 0.09251639654394239, 0.04080357983184513, 0.062174902195692994, 0.04404847582918592, 0.051659341261256486, 0.057144532474922016, 0.031371829099953175, 0.025325626193080097, 0.02374803359998623, 0.0202206539324834, 0.034823001333279535, 0.004206560288366745, 0.006327401270027622, 0.056772178431856446, 0.00801250183940283, 0.0751424374175258, 0.05348866849089973, 0.06818150781327859, 0.053960859950166196, 0.029535859648603946, 0.03311586129711941, 0.030866990564391017, 0.02804569205181906, 0.06557237633387558, 0.03872246787068434, 0.027086211994173937, 0.05664641037583351, 0.09173645128612407, 0.025578654021956027, 0.08485501311952248, 0.034372725494904444, 0.060411321828723885, 0.034602368250489235, 0.06892346995300613, 0.010432819817651762, 0.057672210605232976, 0.018604838878673036, 0.01793381121387938, 0.023797957874194253, 0.04924141670926474, 0.01148615372585482, 0.02385186748142587, 0.08202619850635529, 0.02778658232273301, 0.06113875271694269, 0.0401822537969565, 0.0005659211160491395, 0.10397309350082651, 0.018216740172647405, 0.029079108571750112, 0.14574091241229326, 0.01921094532008283, 0.06233126900042407, 0.026400966635264922, 0.03948001511162147, 0.02641386330651585, 0.04381325954454951, 0.03369332640431821, 0.16991788696032017, 0.193485498894006, 0.20316877460572869, 0.1099270697159227, 0.12258427959750406, 0.10965324690914713, 0.1666631389525719, 0.19870552816428244, 0.14633929124101996, 0.15625653642928228, 0.10778999610920437, 0.09727028285851702, 0.08725923762540333, 0.1701129085267894, 0.10092995406012051, 0.1339311758056283, 0.08374332042876631, 0.19394169707084075, 0.16879700648132712, 0.07339103569393046, 0.07565628562588245, 0.16450000111944973, 0.12578378955367953, 0.14294494525529444, 0.21717317547881976, 0.13037204334978014, 0.20174491975922137, 0.15325261949328706, 0.12459993042284623, 0.11802587498095818, 0.24454321071971208, 0.09861490601906553, 0.13660877040820196, 0.3038727818056941, 0.12403405766235664, 0.14317208697320893, 0.15352767426520586, 0.09105605029617436, 0.13635470357257873, 0.12659305706620216, 0.13876647572033107, 0.15822342073079199, 0.16231850255280733, 0.0634804624132812, 0.06788866376155056, 0.2449462265940383, 0.1498635724419728, 0.18079345260048285, 0.09200962100294419, 0.0813808491511736, 0.15372269583167508, 0.13298498204676434, 0.14023986150277779, 0.16250620654318482, 0.07861240825150162, 0.11451909362222068, 0.13081353215966374, 0.08525396202458069, 0.22410241537727416, 0.13246187183540314, 0.12453900009859353, 0.09220795996952802, 0.24064604484010488, 0.11976238922215998, 0.1911301151267253, 0.08468198881018907, 0.15112298220628873, 0.1652312243822962, 0.17292750359047204, 0.07975072920089588, 0.2796684665372595, 0.16057227359851822, 0.09405462376889773, 0.14955473510781303, 0.09494452562648803, 0.12203583246446215, 0.07554206167696975, 0.15699334064265713, 0.15937836578814313, 0.09510499279713258, 0.17123945901403204, 0.10869576508412138, 0.1221352357242722, 0.11928855761652812, 0.18609338148962706, 0.1012895542953629, 0.21374608593760058, 0.12628139957087114, 0.14474993746262044, 0.10997726858477108, 0.14516225986881182, 0.19628485024441034, 0.13428895035758615, 0.1345014717662707, 0.24930325686000288, 0.09519490398815833, 0.17153640714241192, 0.07946552184876055, 0.2400383001076989, 0.11936683193198405, 0.2198092543403618, 0.15711655199993402, 0.20442972803721204, 0.14462708233622834, 0.16191968723433092, 0.10200462842476554, 0.08701802478753962, 0.17109974229242653, 0.2500603365479037, 0.07539789949078113, 0.09022330865263939, 0.14770025649340823, 0.14079896587645635, 0.1093852796475403, 0.2778077538823709, 0.12381182896206155, 0.1574899413390085, 0.18127663526684046, 0.2358563573216088, 0.187223895045463, 0.11571787734283134, 0.13930042128777131, 0.10416293487651274, 0.2096090727718547, 0.1081025590247009, 0.17609457427170128, 0.16304298711474985, 0.23535894026281312, 0.23319673753576353, 0.09306505147833377, 0.15217390784528106, 0.11679948336677626, 0.0917958008358255, 0.11154895924846642, 0.12783508573193103, 0.16877526155440137, 0.1570775150321424, 0.1340400191838853, 0.09672202126239426, 0.1478158385725692, 0.07582026315503754, 0.2588218648452312, 0.15300684986868873, 0.07749566153506748, 0.10320966102881357, 0.16367504460504279, 0.09515423429547809, 0.1859090171637945, 0.06515036890050396, 0.13843863940564916, 0.2529832109576091, 0.1626067527104169, 0.16901194729143754, 0.1368033021572046, 0.10007926728576422, 0.09057245202711783, 0.11998710411717184, 0.21277749416185543, 0.09888442436931655, 0.05978355395200197, 0.12457710196031258, 0.08194690744858235, 0.1508048383402638, 0.08547707388061099, 0.09319577337009832, 0.259229660150595, 0.12482736899983138, 0.13830531999701634, 0.2040739869698882, 0.17367649386869743, 0.20682395581388846, 0.10430390582769178, 0.2563896687934175, 0.14048478507902473, 0.18910941027570516, 0.22015053837094456], [0.03649566860985942, 0.027543102223717142, 0.01945725300174672, 0.03377359338628594, 0.044854897205368616, 0.003727419079950778, 0.03956796703278087, 0.0330336647311924, 0.08482677440042607, 0.07957859546877444, 0.03951001272071153, 0.041770112147787586, 0.08285803472972475, 0.02507632951164851, 0.05461146000016015, 0.041309323787572794, 0.05043687189754564, 0.010452971910126507, 0.027965003901044838, 0.0427754736301722, 0.06699480625684373, 0.013646278439409798, 0.050641567358979955, 0.087072164460551, 0.04380730009870604, 0.04080198792507872, 0.030910727182345, 0.08249136924860068, 0.11149769910844043, 0.04150167362240609, 0.044092793177696876, 0.025599996333767194, 0.01585713729582494, 0.020857218114542775, 0.01802615664928453, 0.002412177545920713, 0.017114482034230605, 0.06639077968429774, 0.050209229229949415, 0.03202595064067282, 0.04216908331727609, 0.032907640634221025, 0.038919522921787575, 0.047495031903963536, 0.03739882893569302, 0.03750243646209128, 0.04009203090390656, 0.02323638957022922, 0.01075214184311335, 0.025870859826682135, 0.019721546632354148, 0.028947668652108405, 0.05940444636507891, 0.019857355946442112, 0.04018718536826782, 0.0210140172202955, 0.04928773414576426, 0.02935986118245637, 0.03936805100238416, 0.06320829459582455, 0.03593120592995547, 0.011655235375656048, 0.020846557163167745, 0.014493690487142885, 0.058306887876824476, 0.14201604353729635, 0.05323138815583661, 0.041002646103152074, 0.0459593057166785, 0.019717123432201333, 0.04254779756593052, 0.07346687576500699, 0.006953984957362991, 0.08445710322121158, 0.04231350525515154, 0.015957290124788415, 0.029614814884553198, 0.020018227587570436, 0.0066923500708071515, 0.005482529222717858, 0.04099360674445052, 0.05066987287136726, 0.06081931380322203, 0.06681201528408565, 0.07420934256515466, 0.06838015848188661, 0.08791092492174357, 0.009914381425915053, 0.02816674004861852, 0.005175412743483321, 0.009871674537862418, 0.029561486007878557, 0.041027318802662194, 0.017326528468402103, 0.03747970818949398, 0.03302446581074037, 0.0553193835366983, 0.055319543098448776, 0.022379491019819397, 0.0333294810843654, 0.025586240626580548, 0.025622960238251835, 0.031000957496871706, 0.0758475370821543, 0.022569196953554638, 0.04652334166166838, 0.059868874959647655, 0.07252953582792543, 0.010587296928861178, 0.057167483391822316, 0.02588637071312405, 0.05073122993053403, 0.06623454275541008, 0.0670454504142981, 0.014758181714569218, 0.008366061920241918, 0.049886417255038396, 0.07642767392098904, 0.04571623750962317, 0.005405120900832117, 0.08043421752518043, 0.05385930446209386, 0.03257921431213617, 0.030475214516627602, 0.034103403813787736, 0.027109021903015673, 0.005094818288853276, 0.002482672994119639, 0.042699347832240164, 0.01354795685983845, 0.04371727387479041, 0.057210976956412196, 0.03821424885245506, 0.009296665011788718, 0.008921689332055394, 0.011977091835433384, 0.04275186962331645, 0.024161430264939554, 0.05373155487177428, 0.07012522968580015, 0.06542761300806887, 0.039032570566632785, 0.02730290056206286, 0.05694751082046423, 0.02269688902742928, 0.026843820996873546, 0.03386144511750899, 0.02127558345819125, 0.03220862658054102, 0.026950693973049056, 0.029242471973702777, 0.041883122685248964, 0.08183817539247684, 0.046849842110532336, 0.06300357315922156, 0.03376695116457995, 0.05031812826928217, 0.0404164756037062, 0.06882033369038254, 0.14629857701947913, 0.03388490069482941, 0.09453318285522982, 0.00831524243039894, 0.07465593735105358, 0.08312345642480068, 0.06820096692536026, 0.00907598740013782, 0.020017231254314538, 0.04321832057030406, 0.08229053666582331, 0.00808826398497331, 0.031967755130608566, 0.07664414355531335, 0.03097602319030557, 0.02356561555643566, 0.07150350182200782, 0.04769317420141306, 0.0390444523509359, 0.01835480932641076, 0.020255763083696365, 0.017974707261600997, 0.009482205641688779, 0.04359732796729077, 0.038312776378006674, 0.08254559797933325, 0.03924064651073422, 0.04680267862568144, 0.06382585052051581, 0.014009869573783362, 0.015049590638227528, 0.10212061868514866, 0.045110277642379515, 0.03396219908609055, 0.04063972475705668, 0.04002713751106057, 0.0023288158081413712, 0.04816554006538354, 0.005260103389446158, 0.04906857793685049, 0.015123027078516316, 0.038253883249126375, 0.017330907139694318, 0.02276238355989335, 0.028964181437913794, 0.06535265609272756, 0.026571875823719893, 0.02372414015553659, 0.046068594383541495, 0.04112589456781279, 0.061552436964120716, 0.0796656716556754, 0.0899278670840431, 0.005461134496727027, 0.04162137091043405, 0.0395835632662056, 0.01990703160117846, 0.07189372307038866, 0.05074536042229738, 0.041299330769106746, 0.04327224873122759, 0.018906590557890013, 0.06590805714949965, 0.07010277229710482, 0.057580358698032796, 0.06308745811111294, 0.019859203894156963, 0.033973531681112945, 0.07627814600709826, 0.03708169067976996, 0.023758766910759732, 0.04375400276330765, 0.056172868207795545, 0.06647931790212169, 0.04383517887617927, 0.009209205691149691, 0.09713449951959774, 0.024107025274133775, 0.00999038755253423, 0.049456925262347795, 0.010841566927410895, 0.021923370768490713, 0.013083591347822221, 0.053329095608205535, 0.024840534351824317, 0.022683077659166884, 0.09789094096049666, 0.00291926478894311, 0.10388444396085106, 0.018537854484748095, 0.042679324687924236, 0.032934035116340965, 0.02232793402072275, 0.05633533175569028, 0.027807750229840167, 0.04289383134164382, 0.011127085981570417, 0.017631508490012493, 0.04708434222266078, 0.019344370484759565, 0.03531296351866331, 0.028082407952751964, 0.04874732447206043, 0.03660785165266134, 0.023471576168958563, 0.050425398294464685, 0.03847314706945326, 0.004348793818280683, 0.02343129239307018, 0.09669506645877846, 0.015424916055053473, 0.018241984325868543, 0.1449997295276262, 0.02267507359647425, 0.05645802360959351, 0.033696083482936956, 0.06519418529933318, 0.023413824092131108, 0.02712398174480768, 0.011477324023871915, 0.05420062560006045, 0.03504535248794127, 0.06565399031387642, 0.046964852735982276, 0.05326957536453847, 0.07442989401170053, 0.03361425056937151, 0.013413927772489842, 0.04977853866876103, 0.048870561804505996, 0.039850803223089315, 0.046025111951166764, 0.00743064692869666, 0.07026351406238973, 0.04811963823158294, 0.035744262640946545, 0.03790449496591464, 0.01644790911086602, 0.06678518664557487, 0.017860613188531715, 0.0355563731136499, 0.03404688926821109, 0.023641754341952037, 0.04510408813075628, 0.029304882882570382, 0.054326556928572245, 0.022554955139639787, 0.06782703581848182, 0.08331695658853278, 0.041400418704142794, 0.015345617575803772, 0.011800995034718653, 0.01886465550342109, 0.05503883687197231, 0.02139972806617152, 0.009609545195417013, 0.011680649295158219, 0.10021839028922841, 0.030094683861534577, 0.024037346884142607, 0.020752168966282625, 0.017810828067013063, 0.03686549935082439, 0.0662956215091981, 0.040547364478698, 0.020681304995378014, 0.06197952439833898, 0.03536598997015972, 0.025934402510756627, 0.02631168255902594, 0.022141456429380924, 0.019254501967225224, 0.011647017945506377, 0.054422757821157575, 0.011810878586402396, 0.007514943772548577, 0.04084097294253297, 0.028613987924472895, 0.04140666758758016, 0.033223569189431146, 0.06433057031244971, 0.04055283410707489, 0.015248459312715568, 0.039253032955457456, 0.03352368999912869, 0.008020903878787067, 0.04910370378638618, 0.011116953810414998, 0.047295524054788984, 0.04353515454567969, 0.0048277935547957895, 0.04387562221381813, 0.024623942263133358, 0.08883170012268238, 0.07563328646938317, 0.14111454191152006, 0.05484641282237135, 0.14007534220581874, 0.08095635552308522, 0.14225094811990857, 0.15260534797562286, 0.17553895799210295, 0.164913852349855, 0.20104498544242233, 0.10700465543777682, 0.11273583892034367, 0.1407362989266403, 0.1647586395847611, 0.10890771503909491, 0.17908418260049075, 0.1381990741356276, 0.13185948540922254, 0.11352096436894499, 0.23331545147811994, 0.11248633629293181, 0.1540570185170509, 0.22667361568892375, 0.12762439000653103, 0.1640070221037604, 0.1206056990486104, 0.1321930214180611, 0.16613098938250914, 0.22499800950754434, 0.128389188030269, 0.16924450668739155, 0.2134445810224861, 0.14994376891991124, 0.18705085589317605, 0.19571256532799453, 0.1926736338646151, 0.12770994479069486, 0.09756027706316672, 0.07563727922388352, 0.09275179836549796, 0.17967502120882273, 0.1352702922304161, 0.13749323232332245, 0.11756062260246836, 0.12851063307607546, 0.1384335185866803, 0.12327280710451305, 0.1359403328387998, 0.06538303961860947, 0.18924863717984408, 0.12280819297302514, 0.16308371617924422, 0.1456452495767735, 0.15265783265931532, 0.20001489931019023, 0.10826639554579742, 0.16547263017855585, 0.11601196820265613, 0.17913190269609913, 0.08884764887625352, 0.0977460588910617, 0.16639354638755322, 0.08977324061561376, 0.14896861655870453, 0.23326753842411563, 0.17011657473631203, 0.1516766392160207, 0.111321624572156, 0.21392877300968394, 0.09116079701925628, 0.17405601334758103, 0.12461256177630275, 0.14328274119179696, 0.07894322057836689, 0.13020605460042134, 0.14526653161738068, 0.11327743603033014, 0.08663138811243698, 0.07052676868624985, 0.22651568666333333, 0.18817075673723593, 0.1437282227561809, 0.14074075181270018, 0.1811329703195952, 0.1658744437736459, 0.20964343420928344, 0.11753636921639554, 0.1281261263648048, 0.13234628975624219, 0.10408078655018471, 0.12890812737168744, 0.1500252418918535, 0.12989825627300888, 0.12325711810262874, 0.31423441017977893, 0.16007383237592876, 0.11003436200553551, 0.13944371516117826, 0.18635184183949605, 0.11211027522222139, 0.07818676429451443, 0.07625564408954233, 0.1754684984916821, 0.11602778336964548, 0.2208037322270684, 0.2431726866052486, 0.18284209189005196, 0.16844209661940113, 0.10792338231112808, 0.09024854909512214, 0.14256699912948534, 0.18911338818725199, 0.18205897766165435, 0.1511867030058056, 0.10144743879209273, 0.25844399293418974, 0.15629894274752587, 0.16872013482498005, 0.17304176464676857, 0.1568276042235084, 0.4057284240843728, 0.11265437336987816, 0.07932144129881635, 0.13236273574875668, 0.15532499266555533, 0.16493123344844207, 0.12430101560312323, 0.1200367983256001, 0.0990312805515714, 0.24639930721605197, 0.21551763697061688, 0.13153423176845536, 0.05972270155325532, 0.16703433153452352, 0.16594140033703297, 0.10194613234489225, 0.08422539729508571, 0.10902835114393383, 0.12827880098484457, 0.269066322944127, 0.2250457147601992, 0.0762582193419803, 0.19733442517463118, 0.08985873602796346, 0.10178589524002746, 0.1917814090847969, 0.10882047557970509, 0.1424324032268487, 0.08919471423723735, 0.11514844969497062, 0.12196285708341748, 0.17826777562731877, 0.1252381774247624, 0.1006873237201944, 0.1386742267641239, 0.2097988547757268, 0.0961554137757048, 0.13805104536004364, 0.16791159461718053, 0.1707190353772603, 0.13853387179551646, 0.14911860460415483, 0.17448589496780187, 0.1765936240553856, 0.16073860373580828, 0.08448212101939134, 0.10555367509368807, 0.08574757186579518, 0.11597149146837182, 0.1020235383475665, 0.15847539470996708, 0.17589404596947134, 0.13768933742539957, 0.15891983726760373, 0.12658507155720145], [0.06629965137108229, 0.044413319337763824, 0.021610811563732568, 0.05255465708614793, 0.09010384514112957, 0.03220297883672174, 0.01703587931842776, 0.03751230702619068, 0.0272539355137269, 0.010915016355284024, 0.04418205870024394, 0.03570973050955217, 0.008574368857807713, 0.01994104422919918, 0.024285222352773417, 0.035380721601541154, 0.03873917361488566, 0.060794221790274605, 0.03346809571667109, 0.03233801260648761, 0.06901594897499308, 0.04700706609582994, 0.01853689525887603, 0.05385081058193464, 0.05469104791700374, 0.054849667139933445, 0.017247487885470036, 0.05620912212179974, 0.04437647912709508, 0.0115805948007619, 0.009543455089442432, 0.03687644231831655, 0.018002098076976836, 0.05016418457671534, 0.0794686314475257, 0.08562708419049159, 0.06140790370409377, 0.09960460447473451, 0.05354178400011733, 0.036722695294884034, 0.09704967946163379, 0.016610320708423387, 0.02190116199926706, 0.012046771153109148, 0.05914748144277837, 0.06648277631029487, 0.03000410844833823, 0.01607479622180108, 0.009691022805782268, 0.05440916909719817, 0.02541178768296959, 0.044629614567384124, 0.021940885453659575, 0.023606773211213294, 0.035400908018345945, 0.05994422892399598, 0.022616657297476195, 0.06848778473795392, 0.05868733875104226, 0.035783733765129, 0.027702804982254747, 0.01935193853569217, 0.06258437846554443, 0.04295153703424148, 0.020415506660356186, 0.012775234554283088, 0.011604404753597919, 0.042021830086014234, 0.01570003390952479, 0.028459367022151127, 0.1157469250028953, 0.03636999703303445, 0.018809434150171, 0.033596965949982405, 0.07344460391323082, 0.017264690868614707, 0.037172511001699604, 0.011600409216043772, 0.06144908918940928, 0.08369537768885493, 0.06297893385635689, 0.006043345174475689, 0.019666312291519716, 0.11970743318670429, 0.01283483086808701, 0.027438759971118998, 0.05529901900445111, 0.018807452615874354, 0.015149083883443382, 0.02877511189581128, 0.027741381818486843, 0.02146458806237206, 0.09744527385919355, 0.05056103691458702, 0.022251865739235654, 0.08783748198766261, 0.14337282307678834, 0.03431376928347163, 0.04874577709415462, 0.024001619894988835, 0.019195130153093487, 0.02069064121315023, 0.013678575778612867, 0.022526701577589847, 0.029598942201118916, 0.018575162248453125, 0.01468423412006814, 0.022495095363410655, 0.019387335269129835, 0.02140462995157577, 0.027762223180616274, 0.04162004988756962, 0.0533551969419932, 0.045690136175835505, 0.07751994460704736, 0.017569826741237193, 0.032408561164629646, 0.015209888970275642, 0.05252346833003685, 0.07080613533616997, 0.033307468984276056, 0.0545302467799047, 0.05229846770816948, 0.04879709660599474, 0.050464910236769356, 0.031273242202587426, 0.019862513872794807, 0.03951810213038698, 0.03502970801491756, 0.048432509138365276, 0.015541768134426093, 0.0551860604173271, 0.04252228252880741, 0.030339310578710865, 0.06266936921747401, 0.04556577077892143, 0.07192065560957417, 0.06569672317709774, 0.034092238201992586, 0.02324299839528976, 0.04172533095697872, 0.018851827480830252, 0.05525264590687584, 0.038265508992481045, 0.028981364011997357, 0.03377246161107905, 0.05585349979810417, 0.02458787759678671, 0.025752533656486776, 0.004088999457962927, 0.019799761575995944, 0.06071645584597718, 0.025667702466307674, 0.052166406239848584, 0.04003693386039231, 0.042807048303075135, 0.02960692399938125, 0.018125161004718393, 0.004477520724321948, 0.026266615641361568, 0.03218404664949048, 0.03281109835370444, 0.031290949846152216, 0.029971194198878948, 0.11134204847621731, 0.02987798045069212, 0.027573242696234956, 0.04976956610335037, 0.021883127810724545, 0.03161479711707216, 0.03183735978382174, 0.03270616609370336, 0.01079738594853552, 0.0067034275525656994, 0.022319608979159966, 0.06300501292571425, 0.049506808718433604, 0.026595208946673665, 0.03058897091250401, 0.04995793802663684, 0.04253161132510286, 0.0446688816009555, 0.016870736617420334, 0.04511675288085826, 0.03244561288738623, 0.007520888839280815, 0.02456239966704743, 0.03442959627136588, 0.04202570409688633, 0.0059809723006765125, 0.04546165117062628, 0.008308584438054822, 0.054882006224943325, 0.029484655169653706, 0.03148655028780922, 0.03502418643620331, 0.10801356809679419, 0.02782490868412424, 0.027035369312216062, 0.07987800010596402, 0.09208140152622946, 0.02566979717812501, 0.06444951432058588, 0.07824042157153599, 0.056237360840896145, 0.04116516902286094, 0.02939471429272089, 0.10360076543292962, 0.033695348756737076, 0.04199494949716609, 0.02789228270557942, 0.06069347153243143, 0.04586563925840892, 0.0184542830902501, 0.04770249557623174, 0.0428375097544631, 0.06417937998776324, 0.08497110728058033, 0.05662433148245327, 0.04056801844853908, 0.06298003965639509, 0.014269429229898378, 0.03219101170543581, 0.11574425327125937, 0.07054325178614818, 0.021943007996014785, 0.02856575018086005, 0.03926282930478919, 0.012103529679734493, 0.03954349100240506, 0.06037857827323023, 0.05961557624686975, 0.03577607109036762, 0.042384350672364235, 0.08692843272001483, 0.018559291420388035, 0.025802899508562405, 0.04044697787321638, 0.11900440411409363, 0.017002673776005395, 0.003682717901938304, 0.018952551763504744, 0.09478076332015917, 0.059010544064221904, 0.0520964217139408, 0.02113582220772514, 0.05207336689636577, 0.027717621960619, 0.028256829355086666, 0.06490316693088971, 0.10955090474453755, 0.04495621149544604, 0.019927865541831125, 0.056440802072756924, 0.0372959635569714, 0.04265287825546693, 0.02731094544287771, 0.059909166157012805, 0.00740400892937032, 0.12147416768129915, 0.017169647726404946, 0.0605162466672482, 0.04105837768292986, 0.02921208659245167, 0.0019565807406252134, 0.022792726267653052, 0.004058732356497785, 0.04123487524338998, 0.13087121187709272, 0.03806734071986284, 0.05299420146911871, 0.01607432495802641, 0.140407616563607, 0.08363696324522607, 0.032023824387579225, 0.028981683135498315, 0.03300047217635438, 0.10577003340586089, 0.07978546171216294, 0.02049642487691017, 0.05887063067348208, 0.04226252713124268, 0.037832139278179966, 0.0503183212276781, 0.03463169421593193, 0.02116289018886164, 0.061047594717820175, 0.007376642697636271, 0.027375182035029866, 0.0764007488032803, 0.033847756203613244, 0.02108555840095505, 0.023756035807309672, 0.047895042080199346, 0.028813415992772207, 0.05021818324166816, 0.02636599849211052, 0.07456476450897753, 0.027212399363634177, 0.013677848473889753, 0.04877013067016378, 0.0893639684363734, 0.0005762386501828587, 0.046733866693102755, 0.025723500839376356, 0.06902948574861512, 0.08575043655582704, 0.005890822694709641, 0.0210831575532211, 0.06431852525565773, 0.017562980428920127, 0.02060934821201954, 0.08197804054361768, 0.05129502838826738, 0.029033807877567597, 0.007382469484582543, 0.010394165983598214, 0.03213751027942635, 0.011522332497406751, 0.09330547021818347, 0.03315361434943043, 0.08117937089991756, 0.0591998399613658, 0.01678492579230806, 0.04607459464750718, 0.045929382322356105, 0.031031296493893024, 0.04929222042846959, 0.0264135423276457, 0.0831375498091802, 0.0072135172467824304, 0.05973582643491682, 0.020915558343403973, 0.023291187899303623, 0.04968252331309486, 0.06945363798877224, 0.012722106057481142, 0.10431966162286699, 0.049932708716369234, 0.07161736211855896, 0.04822760216484312, 0.07265743013704196, 0.056556157796876505, 0.031839029616094194, 0.04930046197841875, 0.05966215714579448, 0.009763989837665576, 0.0238923182405415, 0.05109450008603744, 0.07418674416840076, 0.012671073200181127, 0.034288966708118096, 0.12827601050958037, 0.1121210957353469, 0.08953167896834202, 0.1435567272710614, 0.20576755312504247, 0.18049245234578848, 0.15006960747996345, 0.07740074826870114, 0.14441945910220966, 0.14517544041154906, 0.08503554796334356, 0.0984894682187587, 0.1322189372149296, 0.10551728017162532, 0.14373217098182067, 0.12295324573642574, 0.158217795251403, 0.13991169864311814, 0.07917995084426366, 0.16734916542191058, 0.17650284455157816, 0.14825020276475698, 0.12357551429886371, 0.18408704461762682, 0.14189513283781707, 0.11931379805901088, 0.2060692955274135, 0.17713965178700164, 0.17500912392279133, 0.20863666635705158, 0.12628298776689917, 0.1881794843939133, 0.1418349743471481, 0.129365379398223, 0.15946084808092564, 0.18116654508048669, 0.09960295690689236, 0.17484491632785648, 0.14079402317292988, 0.15199168090475723, 0.11541040556039661, 0.20955456944648176, 0.15943272068398073, 0.12267261001397856, 0.18173465912695974, 0.15145628072787076, 0.12708272610325366, 0.19696605275385082, 0.20250024797860533, 0.1450313301756978, 0.16699152445653453, 0.17592545365914702, 0.09855457683443092, 0.1628617398091592, 0.1423853065352887, 0.17701155709801242, 0.1301262143533677, 0.12278647773200646, 0.17023834632709622, 0.22059131471905857, 0.0899563729763031, 0.16255517344688997, 0.23446284147212282, 0.13288191257743165, 0.10045282731880434, 0.160518096818123, 0.16083468217402697, 0.10644650843460113, 0.08224472388974391, 0.1543306780513376, 0.2707507903687656, 0.1624437325517647, 0.10437280681799166, 0.12896743981400505, 0.1921849444624968, 0.11244747744058259, 0.08092251358903013, 0.24981450755149126, 0.1600810608942993, 0.2215549786342308, 0.1521411642897874, 0.10425524320453405, 0.16310252220137045, 0.27267218101769686, 0.07939561153762043, 0.16119692445499822, 0.1130347463185899, 0.1256703893886879, 0.11413573723984882, 0.1611347621656023, 0.0825684264418669, 0.10497592797037214, 0.39251997659448534, 0.09238954124157317, 0.13045998784946278, 0.1672791808960028, 0.28680430550593883, 0.13801877677906305, 0.15323681174777448, 0.13004634442040697, 0.11332725640386343, 0.1385201420634985, 0.17166283942060545, 0.11040011464501731, 0.173132766794879, 0.1684228898375295, 0.11556474259123206, 0.1665940450038761, 0.07552219438366592, 0.16445385437691584, 0.12554502580314875, 0.1432650038623251, 0.13273863354697824, 0.19145554688293487, 0.14067309763049707, 0.14533258276060224, 0.10292740000295453, 0.08045693466556258, 0.10085894537041895, 0.26198828243650496, 0.09615058239432983, 0.21696252428228036, 0.07368414691882208, 0.12623131944565102, 0.14630758669227362, 0.10232241605990566, 0.12182341495645232, 0.13413323293207213, 0.09027840569615364, 0.13905813975725323, 0.15522796427831054, 0.15342451573815197, 0.10803630008012988, 0.18366385716944933, 0.14989613788202405, 0.12460186000680551, 0.1534443607670255, 0.207823138916865, 0.14198295859387144, 0.04914140117762145, 0.14140472165308893, 0.11480388537165709, 0.29828132246620953, 0.17015546327456832, 0.08467568055493757, 0.18140155356377363, 0.13720015820581466, 0.13615006377222016, 0.1538815748062916, 0.11418028094340116, 0.1245751723763533, 0.12049824348650873, 0.09807142385398038, 0.13862626918125898, 0.09950812527677044, 0.15520727320108563, 0.11076744805905037, 0.08424260027823038, 0.1550940511515364, 0.14975603524362668, 0.13299087469931692, 0.2611156948842108, 0.18651032005436718, 0.1893649614066817, 0.19186666700989008, 0.18701701395912096, 0.23317055456573144, 0.1845420998870395, 0.12361919711111113, 0.22739026317140087, 0.09251160969142802, 0.08982402578112669, 0.10567978082690388, 0.14372359175467864, 0.15220834349747747, 0.1388594668242149], [0.020804277010029182, 0.02248095002869377, 0.024820796934363898, 0.007004584122114466, 0.012497293755586725, 0.027478327574499417, 0.036953462404198945, 0.02134920079697622, 0.03790578259213362, 0.014704306431667646, 0.006369985239871312, 0.02347223668039078, 0.02442228033032734, 0.03045056222617859, 0.06813684536609799, 0.08977781966677867, 0.021402503698482178, 0.038553744307137094, 0.01085054042050615, 0.009308929929829901, 0.009008822107716696, 0.010159177909372374, 0.04369822665466927, 0.027552469982765615, 0.042598029831424356, 0.06222062962478958, 0.03293174559075851, 0.03525274194544181, 0.020782752872037236, 0.0720853975508362, 0.061457404954126105, 0.04276422638213262, 0.08018783191801049, 0.024404696996498387, 0.09388593360199593, 0.018203314721176866, 0.0369960542593617, 0.10187630366999656, 0.029781464145344216, 0.06920026135048829, 0.028479523753048852, 0.047766398201929405, 0.047623030113754794, 0.06885527400299907, 0.0063781841163290665, 0.0749651828664355, 0.06463085068389773, 0.02227426004537847, 0.023745927755953744, 0.017393431226082612, 0.044200675474712625, 0.021291320699674543, 0.0178856922138948, 0.046790177148068324, 0.09356275055324659, 0.041469330826657824, 0.07054778630845249, 0.017936590556928422, 0.019521133363014087, 0.09454571030801162, 0.026121683476958424, 0.03123858019534964, 0.002872191057576856, 0.010876287378778215, 0.017876279925985727, 0.057582525769248605, 0.04575261758873239, 0.030944873396947514, 0.0028869505194961675, 0.051639429439092055, 0.047738159482833, 0.06973246287088841, 0.05315485046594404, 0.015120298758120043, 0.06727089261403307, 0.12146005203248933, 0.025705182779347524, 0.042020568434963934, 0.021105934065417387, 0.07543559317127801, 0.028924578582518734, 0.03502625702822115, 0.025421240789000876, 0.05408413810073398, 0.05285160892526619, 0.029948284100100864, 0.023058196202327963, 0.049576411038287915, 0.022606478742090985, 0.01307467908191029, 0.1390067979809828, 0.03616956892074086, 0.034743576688924804, 0.022533978335559368, 0.042617192084435374, 0.034626146662048995, 0.023236448942043353, 0.01417027551724459, 0.05820844198751729, 0.026980366892530583, 0.020627699668693822, 0.054531582645722665, 0.042681870254455134, 0.020149454139755107, 0.050559125884319656, 0.04087097055162303, 0.02956600012112176, 0.03367549259564839, 0.03501103929011151, 0.0043221242776780855, 0.005457439065139624, 0.023275884814211167, 0.06514930762932636, 0.03903120130416937, 0.025415097661607433, 0.01722049040836282, 0.04650741146178916, 0.06497037582448684, 0.05884565369342454, 0.005818257350256317, 0.05618581868475303, 0.033453119176556356, 0.0663997077208478, 0.027417380551923998, 0.028624875230889302, 0.07123079223674722, 0.06767991988454014, 0.05836972180986777, 0.01510555970526184, 0.019327213885844685, 0.025119678357441444, 0.03727425944816787, 0.02284559501276817, 0.02785358712571906, 0.05892975015740376, 0.0993088363611605, 0.08459979595500045, 0.021808534547744785, 0.05992658807372209, 0.08903675552573986, 0.10325457580620423, 0.028509356234280858, 0.05058438116975594, 0.028687443846138194, 0.008747636220505228, 0.038464052049675956, 0.06351703545078635, 0.10664036482921802, 0.04187262871710118, 0.09130996870226227, 0.057772330037551, 0.03480716761259828, 0.022211483628780115, 0.04266020696377382, 0.056076886248774827, 0.0655058427946642, 0.03283931109763216, 0.020138815452810377, 0.05812192983285058, 0.06239422538783401, 0.040804347954690456, 0.02424526697723195, 0.029542641022999305, 0.04965373169397935, 0.020492380172072444, 0.11390027604647912, 0.02977354914037278, 0.008429249301116215, 0.03151231023366563, 0.013325970285222866, 0.017240047855011653, 0.014521062748826807, 0.07177419276558794, 0.02064184871414909, 0.10303089991793968, 0.024649665101605933, 0.02084706738969544, 0.0034281798025403987, 0.04402297563501634, 0.02053644333500415, 0.0395960461901268, 0.02744248184171738, 0.062338742427527905, 0.03444406815106049, 0.02303311717696488, 0.007132438076951075, 0.026039575968752615, 0.029130867806088645, 0.02350802118598949, 0.0218470631443779, 0.033848754392238334, 0.021806883269164246, 0.019305906826048158, 0.03283097677922342, 0.024714161445444915, 0.039487273315899074, 0.03445251379162073, 0.09107967285672203, 0.05052931381214876, 0.05448949545098003, 0.07601518082083203, 0.012139332739025122, 0.047840657498454675, 0.11350365006364882, 0.07871896581491455, 0.09830682567553595, 0.05875909329915885, 0.03288143539975863, 0.07411747210426256, 0.05125914183736313, 0.04551469988655299, 0.05985323790810071, 0.061518617294495925, 0.042229323444189504, 0.0502811396290781, 0.050914254679810256, 0.01235901216205093, 0.024368508020415902, 0.07543597908806987, 0.03581208009563852, 0.052571663400158286, 0.05760143569204956, 0.016940483656071592, 0.022504863882204518, 0.03173092096403707, 0.03220909784431569, 0.11452489721705206, 0.04019597981823608, 0.019612582655099686, 0.05835574716911651, 0.06188987666973844, 0.02650606031238567, 0.053141031676204875, 0.013515781975002028, 0.04085698106791824, 0.014265496774896747, 0.021850493722013198, 0.05245116088190116, 0.004002086543550831, 0.02996410483319778, 0.018160151412303094, 0.059446407394716516, 0.06348680035443977, 0.08404677719227038, 0.028886339423479512, 0.032551398617215455, 0.08234498061938211, 0.10254443695885129, 0.06729386950610206, 0.023336670419666916, 0.024685273347131442, 0.07261072678375058, 0.037247000364004634, 0.010662316926755011, 0.04344194079749286, 0.05009971420804504, 0.015547931670880644, 0.0397707774391165, 0.018418181316519622, 0.08814387765596621, 0.05983893672237173, 0.0955928435723763, 0.02382329108513659, 0.10244818782666698, 0.05519642079889309, 0.04210153674648609, 0.10639147076290101, 0.05384950069128536, 0.006130307720013661, 0.08458340191282332, 0.038207717952900566, 0.01576205890160054, 0.04376909804705065, 0.05485719251737464, 0.036913620206178166, 0.014658439849881688, 0.027974494114459958, 0.04419227807375137, 0.05675726497429423, 0.03269369430199731, 0.024126519638230093, 0.04648790039937012, 0.06262469192733988, 0.04018556006485596, 0.019383079052204266, 0.02460125851939665, 0.001749656632910046, 0.06334637117106467, 0.04792434207047336, 0.019349491303728428, 0.016069762605184224, 0.022477892380265985, 0.028807918533857446, 0.03975286199420225, 0.012693690150626935, 0.062157094362191856, 0.010870488422369817, 0.026743003945739474, 0.04737476687296294, 0.036345064581837505, 0.02729015046497807, 0.03843340506136883, 0.02511017330107279, 0.0118280741480703, 0.027450164925539866, 0.020995706581743434, 0.02412877762253629, 0.013984193119540578, 0.015544643956673099, 0.04125639381527435, 0.025169463478960097, 0.06788116807001643, 0.048940813503577374, 0.036496670509222895, 0.05026063408877235, 0.02383196679147659, 0.04953956711688079, 0.06260587848373689, 0.05001747682399582, 0.022101098438724875, 0.08300509871332906, 0.013312587507243734, 0.0681598371011205, 0.029692603093280923, 0.0337116982700536, 0.046113475764286704, 0.021065134496893734, 0.03630816128861625, 0.008053845958784223, 0.06611196222365834, 0.004262353095327853, 0.025472213346802164, 0.01820842626329977, 0.01843696321884636, 0.0008760500190874154, 0.014477994063781807, 0.024356808062293567, 0.052009727733093314, 0.10562979718088172, 0.06592785022803582, 0.06587374024093151, 0.0399901933997171, 0.09120388611336239, 0.022177550781634636, 0.05662849493091926, 0.04231185026583262, 0.029237824273877777, 0.027584233903326094, 0.023305205213546287, 0.004239163299644133, 0.004417795462359209, 0.017010156479955185, 0.17153400258393958, 0.0964034692151472, 0.15061947953654453, 0.11884931751410477, 0.1709913887316361, 0.14335421001305804, 0.1603388978401199, 0.1478658741689287, 0.17821209970861673, 0.08851886261254549, 0.16289578954456374, 0.16944635601248592, 0.11055569848394953, 0.12369926000246778, 0.22652813990134746, 0.13132654916262254, 0.12624353519640863, 0.07779427949571982, 0.09310544657637365, 0.1071343754301779, 0.11950141299166717, 0.14519878837745637, 0.12613607221283019, 0.1675621618051082, 0.15791440528118983, 0.1345559602486901, 0.1277218191535212, 0.3522199625149369, 0.16659137327224016, 0.30157764558680356, 0.15931866742903367, 0.11785519585828297, 0.13544739835197106, 0.1577891455963254, 0.2651262906147167, 0.11581017082789913, 0.19684497878188267, 0.16582105366978794, 0.18478570244042203, 0.17304206150583923, 0.16568642808124423, 0.08754043738008477, 0.11051836103433743, 0.26480105181690305, 0.15510092343902215, 0.16695322963641956, 0.2007810035138391, 0.1115398011461366, 0.1252434466732666, 0.15674972324632108, 0.2064399389200844, 0.15261403110343963, 0.13295698823640123, 0.19198098743800074, 0.18234736140584573, 0.15255504520609975, 0.14168813300784677, 0.09220050138537772, 0.1432336852303706, 0.16673134232405573, 0.10742031008703634, 0.16715184319764376, 0.044660484199994244, 0.18550760432844982, 0.12292148181586526, 0.11797661863965914, 0.2182322647422552, 0.1105492863280233, 0.10467475702171214, 0.12310939360759221, 0.1453100808430463, 0.11099474562797695, 0.09139350484474562, 0.1631008301046677, 0.12847775593400002, 0.21439504955196753, 0.14376632461789995, 0.13115169917000458, 0.1079226475849282, 0.15761235117679462, 0.0943454640218988, 0.12365841219434515, 0.06875972991110757, 0.13970223488286138, 0.15426051540998742, 0.1521549979224801, 0.0993781752185896, 0.19660827820189297, 0.10243757511489093, 0.08745714614633471, 0.3449194855056703, 0.12448466004570946, 0.07216425816295668, 0.17510080884676427, 0.11332021342241205, 0.09698445210233331, 0.1257092779269442, 0.10307585922419094, 0.18763779080472887, 0.1722583090304397, 0.2517005125992, 0.14233017980586737, 0.2663492312422022, 0.07932599808555096, 0.09390071718371473, 0.14809276355663314, 0.23164786049164832, 0.15979902993422002, 0.06115606702223886, 0.0926463540236, 0.12805819016648456, 0.131183210760355, 0.1564022051752545, 0.12579903326695785, 0.22960739966947585, 0.23222814576001838, 0.14307749283034354, 0.11491028708405793, 0.0789182324660942, 0.16301125288009644, 0.12895354680949822, 0.19451389292953536, 0.12175728217698634, 0.0834055244922638, 0.17952298483578488, 0.10665719673852436, 0.1068972740904428, 0.09660525174695067, 0.1400197108159773, 0.0845442981517408, 0.13057444186415523, 0.12115552657633089, 0.16890988714294508, 0.09978842703276314, 0.1522567612119019, 0.24789166229311377, 0.13182436698116362, 0.08214803689043038, 0.18208645196864381, 0.11944963334826753, 0.16783404018497095, 0.15120700816623867, 0.21480461116880178, 0.17132011562353, 0.09060765951289795, 0.09678002752480097, 0.1570932040340267, 0.16706459631677717, 0.1299328255117871, 0.19360832433449104, 0.19709098589373752, 0.16110805969219655, 0.10858897745492868, 0.1220398252189625, 0.08547132965759374, 0.1408598813577555, 0.15706844598753378, 0.1280408981256187, 0.15498832479352131, 0.13313784962520003, 0.14126889378530905, 0.14799024327658117, 0.15656437928555533, 0.14260891563026235, 0.20258826669305563, 0.27488499821629375, 0.16322196344844997, 0.14489861932815984, 0.10779708361951634, 0.08303548223921098, 0.11079500400228426, 0.09487450399319641, 0.18662116723135114, 0.16223201266257092, 0.20714858605060726, 0.08406673354329541], [0.04562277885270305, 0.036851454206043854, 0.05331773703801446, 0.041726284616743214, 0.058758250961545855, 0.028804345092794392, 0.023389043781207874, 0.09735453146276996, 0.034337495744694024, 0.02163243589166086, 0.04840781417442486, 0.007161013545555761, 0.04172428081801627, 0.03987470037827734, 0.0248399851625436, 0.07717242653598078, 0.04711210596724413, 0.07334622481721453, 0.06332929435302503, 0.0995108118513599, 0.0015760976293677231, 0.060190447547938675, 0.0495776986645069, 0.022167613424244337, 0.10245779121760279, 0.013812068664265098, 0.021917094054515474, 0.03706014613271691, 0.012516489405243192, 0.04343443397374358, 0.04358207683253568, 0.02418808449874632, 0.025492644672340248, 0.04124161023355555, 0.05061718780780211, 0.03456667465798091, 0.05699610665033106, 0.013867722318536835, 0.01838090509409085, 0.026786850030475762, 0.024209328475990333, 0.007298732962226495, 0.04600385313096922, 0.02260661232867278, 0.03190283205185551, 0.03515110111038666, 0.0058292128414905164, 0.02842991303623421, 0.09309832938015461, 0.06394229349098168, 0.033983227840508334, 0.04193001899693627, 0.04317304214055184, 0.01827171476179501, 0.06707086155074649, 0.0621684603538597, 0.04854781291214749, 0.02199411414039787, 0.08367481277673505, 0.05052206302934792, 0.04468116043426562, 0.017886729365272913, 0.02832606802257942, 0.017773251274775248, 0.07018892079940997, 0.04079121565155219, 0.09468459582421929, 0.014633385872002691, 0.056596048234496266, 0.018668093980522826, 0.06453400041209534, 0.0335090362932533, 0.057483857235638425, 0.06501321258838288, 0.03709563192387577, 0.03370407641341444, 0.013934339349361835, 0.02984519422170706, 0.031143102896749042, 0.022067609024816193, 0.04015716178400908, 0.043017306161345914, 0.029932621073385235, 0.051010834067710675, 0.05555048832320608, 0.046102677515591495, 0.014033105289854575, 0.02153106965124607, 0.06681685408693738, 0.03327825434098486, 0.07563825143733993, 0.05993279984977562, 0.027023678630939685, 0.04644261454814114, 0.020294195201131515, 0.026598915974318516, 0.05213814525632188, 0.018356447617406957, 0.030705142999067903, 0.05104216012114193, 0.02713900281378301, 0.014811039327469189, 0.0320495026971912, 0.024999539491545875, 0.02275096376251895, 0.009008210763568059, 0.010762710953713395, 0.037532931310124695, 0.038711962770321406, 0.018162531850975938, 0.022710206867486704, 0.047475201718043536, 0.023675286429352127, 0.05309762716933619, 0.012459508234314853, 0.009431459438928869, 0.06663536187261343, 0.06419880199246109, 0.06606669121538289, 0.03738916617294308, 0.050173572744824924, 0.027232953143538907, 0.0744546446367167, 0.0522172173805302, 0.02194082237110706, 0.021689681452699006, 0.006097233444961603, 0.008728706816327758, 0.046649451105622575, 0.06570737299625762, 0.09233717530150898, 0.01871382883109618, 0.014087636445765384, 0.04295659105991945, 0.033960321452468634, 0.037462620239239186, 0.047294926625909284, 0.07153980768634938, 0.025286168056481984, 0.02785971541015897, 0.011156229193147738, 0.023859077446104493, 0.023765748665027786, 0.05251644761301577, 0.006704401621391298, 0.006548108567585587, 0.07679220201680437, 0.024569867528043687, 0.0464948988519609, 0.09120893271756358, 0.03206985609722324, 0.05404827752499841, 0.014536997587129008, 0.020400817702466156, 0.07476478072931059, 0.036351294911582954, 0.040939749087556265, 0.11674829002004117, 0.03168217299389653, 0.04072059287864249, 0.007618714571435703, 0.047138077425188385, 0.04285915078071412, 0.0546146809210768, 0.06220917828613892, 0.018404987786198035, 0.026100359718839172, 0.013594634237961145, 0.09199955005897209, 0.03812384413322434, 0.09938636852893978, 0.05176501195819583, 0.07329321320867166, 0.034157098198193125, 0.051992528460687026, 0.057478406160953455, 0.08918037594412453, 0.03275267648859881, 0.05140737470355816, 0.0872143376909662, 0.06280910078203306, 0.09057162082171999, 0.012475167550292099, 0.033284102464676835, 0.02881187232560478, 0.04762336779094767, 0.0639911564940121, 0.040685745334485546, 0.03899408278812189, 0.08532189822290093, 0.03715423932590056, 0.05130282464961056, 0.05723392416257411, 0.04187021673715208, 0.06094673684856389, 0.09733916900586337, 0.01240226916706888, 0.014875229535391554, 0.02857472274627071, 0.037310071784304455, 0.06068655842682347, 0.03284595331933815, 0.04048852701089345, 0.007305638646357693, 0.0681264404556714, 0.03539402830938343, 0.017334200420009438, 0.05345373188902158, 0.0691815147001762, 0.06144629871414509, 0.04615994905179832, 0.05416593761765398, 0.013190935587772401, 0.03457316473941319, 0.02870384902053047, 0.01096559093639371, 0.03447610295552295, 0.022475918267446104, 0.07802722480846569, 0.04446614912012592, 0.06088250025641173, 0.018302254138689023, 0.06188743129314389, 0.031019739399198443, 0.03600785865273792, 0.01949872606928693, 0.01742441403621342, 0.03185658140864689, 0.07230666888062842, 0.008819113390927669, 0.035073494727839716, 0.06038525389158167, 0.012427830588421784, 0.06366073750541545, 0.09733597777085379, 0.03609400715504307, 0.026882041602220852, 0.04980894816981163, 0.03705386014189571, 0.019526593714545015, 0.02672229802556103, 0.07718317283433862, 0.0209978829298052, 0.008529142378392862, 0.029235837173473556, 0.02248164950287901, 0.05297980380419176, 0.07430196259520017, 0.04095940486877225, 0.10394861004897393, 0.050465173699194565, 0.04105083004105836, 0.011114510289189639, 0.02644686846906552, 0.05261638521915302, 0.02321513446077006, 0.007726346393610584, 0.044074027973692864, 0.03361754570505582, 0.023860767687438056, 0.02957693566713715, 0.037125566450413316, 0.05125685973325744, 0.016105153772514313, 0.07038255454972386, 0.03836629264696967, 0.11423794581787661, 0.0473264827451203, 0.05108137149363756, 0.02092154376441613, 0.024698056840861682, 0.09993533516535535, 0.09235033357981592, 0.0549858104204759, 0.04022929853817914, 0.05029413463489618, 0.03154141355480533, 0.027855613188876305, 0.05999726279696915, 0.05626417092571501, 0.07045417922199704, 0.015749891390441917, 0.01320444082011818, 0.03539121928042732, 0.07328515348490328, 0.042244760115863755, 0.025591008925403003, 0.07673746862565167, 0.013104926238156622, 0.03031993495824281, 0.03447516413871199, 0.032667292398400605, 0.050238814947078936, 0.033950888755498454, 0.06622553308261558, 0.02128991618519649, 0.00836990160678397, 0.042130599249503575, 0.031047636730363593, 0.06594670820049942, 0.04404077975777909, 0.018292125678271987, 0.07170725104515441, 0.07453125654137693, 0.045254540018504485, 0.010005725889641326, 0.06022372544975951, 0.04097593620826956, 0.018445911664457526, 0.057865577182383277, 0.03306941769551486, 0.026355254049121868, 0.021661092068825383, 0.07462038105586544, 0.03679739988001529, 0.06485650068498217, 0.011221186596230837, 0.05859963544935454, 0.017961326338991057, 0.033052337166736834, 0.004287436759113916, 0.043414919200586155, 0.04705802566604689, 0.020210831607982982, 0.07814538214006461, 0.0352799453685293, 0.05700116067600902, 0.008034510228753788, 0.037084377254359424, 0.04975923911842983, 0.03731503675226122, 0.025998546334449202, 0.014820926589891315, 0.0463720882544294, 0.07129858000553213, 0.08532526015187614, 0.051687617087736726, 0.06661614024778828, 0.022809563743066974, 0.017204448886332102, 0.03157312923576683, 0.0028161069576526643, 0.030719937713001855, 0.03402720751182642, 0.017743069984135218, 0.03896854548656847, 0.03999954817118123, 0.014359670676640235, 0.028184380898892414, 0.018177035271946806, 0.0022610108771914383, 0.05416384847194422, 0.17168229853268713, 0.13555722136516124, 0.20575633185217157, 0.17022308777086437, 0.14326199074275792, 0.15361686557298526, 0.19726878963410854, 0.16199267003685236, 0.09310837063821964, 0.1404676859965548, 0.17435808229492977, 0.12918913416797295, 0.09680803617811762, 0.18304918077774346, 0.1300092221936211, 0.25757128663826734, 0.2402223230456002, 0.26752624777145684, 0.19321759842569008, 0.15020360966445878, 0.12873020488768816, 0.17739325849106535, 0.13530641997931525, 0.19210198719520122, 0.15509241842664778, 0.14383077272213995, 0.09058446739800274, 0.11591250557103194, 0.13881229591788724, 0.12525523197837174, 0.11915184659301303, 0.19433092384133488, 0.12780470220604911, 0.1073971253936179, 0.10914297585259192, 0.12850687780883163, 0.09903099853545427, 0.0959817883267533, 0.10974449396599084, 0.08044183938181959, 0.08873301674611866, 0.14358470623847097, 0.2496421808609739, 0.13391516025876626, 0.1319587996113114, 0.1261253110715188, 0.21050457784440368, 0.11146949007525109, 0.09832825147896074, 0.14269766164943576, 0.11510484109749086, 0.14770326961297542, 0.15855002508033067, 0.11474891449324787, 0.17046758090145886, 0.1882585824932903, 0.11530377378221601, 0.12497774296207353, 0.21373234136262909, 0.1744813084951602, 0.11043746693758294, 0.14084465248743072, 0.13132974039763212, 0.11738401371985674, 0.1291052417946048, 0.09176428924547508, 0.1821551303146407, 0.099363258050289, 0.1413027208764106, 0.14396790676983073, 0.1625154388602823, 0.10889310215134174, 0.2494928310625255, 0.2656557090813294, 0.11302662722300738, 0.1263378027942963, 0.07252343537402339, 0.13300571765284985, 0.18298584589501843, 0.10737198143033311, 0.07727561474894173, 0.09683750686235726, 0.17437746719224378, 0.12992789765121415, 0.18636153428815305, 0.1486593933077529, 0.1328678266145289, 0.10158513687201776, 0.1398008069372736, 0.0953147756808903, 0.25792211468797177, 0.1559491388616152, 0.13931933121057227, 0.14035431551747024, 0.07441122899763286, 0.14880434959195554, 0.10685875662602484, 0.1620192389236763, 0.1146090122347232, 0.15453733649337664, 0.09383420590893365, 0.1498271181480959, 0.15934542927425355, 0.10587357784970663, 0.15391865250421688, 0.1288078335346654, 0.1603078909101896, 0.12868361285654828, 0.2586291736224666, 0.14959089254261926, 0.15946926403557882, 0.20699773711385205, 0.15046679007355124, 0.14403967245016247, 0.07472641911590472, 0.08968993453891017, 0.19425633799983189, 0.1688109737006016, 0.19535513216396794, 0.07413398489006795, 0.1815412554424256, 0.1379178001661785, 0.09622631856473163, 0.18673588841920719, 0.11725525109795853, 0.039102020746213384, 0.18016470508882776, 0.0876285599952098, 0.1421746108098887, 0.20008348859846592, 0.14890256541548297, 0.12919029191834852, 0.0936117026139982, 0.2241071651224047, 0.14148662507068366, 0.09146363780018874, 0.13577665959019214, 0.17556460661580786, 0.09899832919472829, 0.1784739294089377, 0.12616173567948863, 0.13459334964863956, 0.09884830404189415, 0.15855471545364708, 0.08104720182018355, 0.08563175972085446, 0.19901849183952436, 0.16081301146186888, 0.2280764825991355, 0.14244046295061707, 0.1445492755738087, 0.10360427579144016, 0.1971401457558386, 0.14430932438699529, 0.13492121564922854, 0.09152768514468335, 0.14422273059608415, 0.18419428495690227, 0.1301551581127569, 0.19507765799062327, 0.08963356100139208, 0.2166804191074334, 0.09789982446818613, 0.11237582308240235, 0.12696787132881582, 0.12250071376911364, 0.1058276166440919, 0.11649256077362224, 0.13444873475236818, 0.17453581182053313, 0.1496195691288449, 0.10142522631213069, 0.1475828338880092, 0.20732165488880128, 0.11397926282370463, 0.12660300184506923], [0.04869622389378492, 0.01731096377625363, 0.013807931190967793, 0.024246959073934704, 0.031001705210655928, 0.08278021312435158, 0.035915550324716605, 0.051647233121911995, 0.01678244887443725, 0.06047243768989574, 0.023513995474786498, 0.04276619678421412, 0.052604277079808526, 0.01805607262213016, 0.06901352215209045, 0.07952731306431815, 0.05799097416456789, 0.008864094961609226, 0.02675027513760142, 0.07258384619490243, 0.10832198982825503, 0.05239860198344104, 0.03591796601540409, 0.048675106081645936, 0.035703173634829, 0.017902533400047105, 0.030975924855738413, 0.048904025243246, 0.010829727816599188, 0.02496020752005279, 0.04118189332075417, 0.018956730054924265, 0.0471183325862512, 0.01221565056766849, 0.020740955114888493, 0.05544222382013686, 0.0644250308687333, 0.03906483172613662, 0.06710224697599187, 0.01209817879498587, 0.031920072142384015, 0.018712953096837737, 0.03626744706707541, 0.03311702275823336, 0.0853602598363068, 0.013993862376082689, 0.06207184385857545, 0.0430649149348028, 0.008639141651656246, 0.061441452489816584, 0.029967665286676493, 0.006459467840613797, 0.0358276206679875, 0.03743704583030194, 0.03509690948703792, 0.004970600393789937, 0.03363524592714384, 0.037468817172339186, 0.028779661261069123, 0.020480685780057684, 0.04493783591897227, 0.040742241326370277, 0.019280404776509386, 0.03395883344637696, 0.052871936350129545, 0.060062653428758495, 0.05725953196815681, 0.030171831967891194, 0.002191368203057209, 0.017835079597716685, 0.05003519188903738, 0.05649630729749333, 0.0684608744631987, 0.0033743151880116784, 0.05686072778189555, 0.031635439954698086, 0.1003540845704265, 0.03496222081594169, 0.02550199016695842, 0.035314403285156004, 0.08872140213497914, 0.053665288505726494, 0.03416070874664001, 0.02328959042642964, 0.07479763560695574, 0.0458025455736788, 0.022415258827095386, 0.03274290982517414, 0.027711280308722053, 0.0273651927273022, 0.02914743439760059, 0.038453617453342304, 0.023345399931713473, 0.07130272861104459, 0.055729857995174825, 0.0820568714698311, 0.061757807779940777, 0.04276850486348849, 0.13044198334682733, 0.019827692303806543, 0.01372065462419414, 0.017160537863674108, 0.03330445215397049, 0.10621114372042939, 0.018771877766994294, 0.041565327628632076, 0.01338173062322312, 0.09118649759329855, 0.021751337226305623, 0.03939175890991464, 0.058786756853805855, 0.02874227000575047, 0.01621003779291641, 0.060705182622768916, 0.06990468566073105, 0.009367148632009048, 0.03638459136709571, 0.036982955352868885, 0.03105656291154446, 0.027941349799220916, 0.040968967441585846, 0.03659589936432894, 0.046999188198242337, 0.03073490868700901, 0.0912045911536552, 0.027987032699456904, 0.03405196555831935, 0.0025082228194150957, 0.03848003419989254, 0.06340039952192456, 0.04832747297768947, 0.0670692659332417, 0.049436601548222825, 0.06887977971928194, 0.031485808140132576, 0.05854898758116178, 0.04079014695889782, 0.018171754891227465, 0.03281835284724366, 0.03885128244291991, 0.0422728800913319, 0.03788249770877883, 0.031728575777378865, 0.03177942031470593, 0.02805831598379882, 0.03770219293073751, 0.07311939480132423, 0.017388315973221324, 0.04184510245977435, 0.013913399652665248, 0.0386836572579341, 0.04083680207259022, 0.04570260054606479, 0.02214550484495703, 0.05000074139388744, 0.0621064687584294, 0.08809036880847998, 0.04017165963887237, 0.01774925578502007, 0.021527793069253676, 0.02244808401883347, 0.017523524147691205, 0.04104188716155477, 0.02250729998195311, 0.02499345016985899, 0.07206512207631022, 0.040092687704600394, 0.057616104240878485, 0.0240869019398815, 0.029530306528613437, 0.04052284391946159, 0.024791667638055515, 0.018763170519378036, 0.12780741846654564, 0.016466138113173656, 0.0325137197796721, 0.02794764506688807, 0.05674583590007387, 0.03206564440915827, 0.02392284462985117, 0.039550678702653386, 0.08908146992325783, 0.00960107821811107, 0.05449519514513668, 0.04932595475111157, 0.060990111669525504, 0.007401401207971503, 0.029374854420893826, 0.006883057440063567, 0.029340505971049424, 0.04505146243900526, 0.03577755167498253, 0.04079169062606525, 0.09155302206636406, 0.02603162942250492, 0.02155071430024691, 0.02433452693367144, 0.06026294795447029, 0.03538695935276337, 0.06056679063476622, 0.03633305292169098, 0.005392692246459774, 0.03872943663736805, 0.03744491630641278, 0.03924296943296213, 0.06272885235375725, 0.0691453053150326, 0.05370933868107386, 0.03175144134729635, 0.016025146542233415, 0.01701944631349761, 0.0717719885869883, 0.07708788849413395, 0.0424954613117734, 0.055997161034611054, 0.04820785361516755, 0.045726386379101314, 0.05226003187999595, 0.0336864244309254, 0.009070236683328403, 0.029884557734476402, 0.03454828794929199, 0.03258772303524893, 0.10272108294884674, 0.050004351942334324, 0.02782500145258382, 0.09791046686586924, 0.06210616076714359, 0.00738565051506157, 0.00255082140029117, 0.03754672041395679, 0.005768032506239251, 0.008265348769782577, 0.0055891786269057775, 0.029304986783245113, 0.028439386551326606, 0.06935966724995524, 0.10888447097386234, 0.018954702136397827, 0.09023522012284957, 0.03686937336169649, 0.042921198037220165, 0.030913671653252095, 0.03540720514138229, 0.02834107981470879, 0.08470503249554895, 0.09229542207322083, 0.08051029508351348, 0.012015307802357711, 0.06314263679087162, 0.04067880996444728, 0.0182609387775301, 0.16099819215014577, 0.0260977640573401, 0.030962781420385, 0.03915368906746153, 0.050250047352164984, 0.03148581556160934, 0.0210288453308749, 0.01928302641317714, 0.0100099366500217, 0.03485542947601061, 0.01765069115208462, 0.07475244623492472, 0.07800294915796258, 0.03281999670434743, 0.028279271900828462, 0.07094630476785824, 0.12940766697283834, 0.0556688460346777, 0.04523705872998107, 0.046323919159476645, 0.026156866842939053, 0.01704086098470725, 0.050547489008749835, 0.046577681714552455, 0.030537332277162932, 0.04532629085588269, 0.015000337079982273, 0.05227998823102098, 0.05247175919066649, 0.061800804105587304, 0.09460278146434575, 0.08093302982160822, 0.018155125217163004, 0.03544272061844822, 0.031807425257284194, 0.09056996583240107, 0.06198054114065599, 0.027798799928859808, 0.019336913755978458, 0.040970147456391715, 0.026213008459308185, 0.06865660849143751, 0.07080551935359836, 0.014880738126521464, 0.10472545312950388, 0.04304709596908651, 0.0616391309449682, 0.031191669040708803, 0.02981810026540188, 0.029338455788092688, 0.05253412185993511, 0.04713591035397258, 0.024765662783465814, 0.043452490426716395, 0.03400813802727498, 0.05518617916095536, 0.023266954922291916, 0.04610203184711281, 0.0916060856252443, 0.06868270982522517, 0.01743741646350827, 0.03483421889541205, 0.031095753874978982, 0.018633135114214383, 0.0225080551172141, 0.015259516385413008, 0.06310190772637725, 0.025146633161057252, 0.052035424596397206, 0.025642987093306147, 0.025907961644406896, 0.04393031107611023, 0.036784093172173016, 0.015844652516534552, 0.07644365236046724, 0.039479907500208355, 0.021806629083584994, 0.05886402926989831, 0.02986504667205736, 0.0511499051208375, 0.05637892179947812, 0.04335152494604699, 0.014149326543702045, 0.03780085033213254, 0.013302350507728988, 0.038521590759046376, 0.07256690296344459, 0.012735483269352699, 0.03043734086531913, 0.08121911290800199, 0.028817293714382686, 0.02451972246490186, 0.029642344852618407, 0.01598888706212165, 0.02586082227935549, 0.020520999241853133, 0.036926403699908406, 0.044777353905374184, 0.05798949729069136, 0.0475639143405715, 0.12104548091883771, 0.11877459808601998, 0.1247881242306903, 0.09321735502453521, 0.13873747258912772, 0.23881142609752715, 0.11871161943417974, 0.19275886210380122, 0.13779779488686472, 0.1937845695647411, 0.10328175325412303, 0.19345570908626541, 0.14754183765035123, 0.1513821995467879, 0.1344294982845895, 0.16407944087404758, 0.2011427262914367, 0.14725827786605805, 0.13618552358821034, 0.1635891484329477, 0.1776162293390371, 0.1521060013328679, 0.17828586918767542, 0.1415499154245481, 0.12720733269816265, 0.13070194283500314, 0.16594566026469693, 0.09656004011048935, 0.09677181195002049, 0.1662082617986016, 0.15660013596061617, 0.11225829657632858, 0.12244037716300227, 0.09330649438197725, 0.08318001549923792, 0.1424751806189306, 0.2898142783669755, 0.12145263797719963, 0.12657796178245917, 0.1174339083081577, 0.07973207902978174, 0.11981457704678178, 0.06935019002412446, 0.0935511953139212, 0.22516966826515272, 0.17428642051527277, 0.11160720299812965, 0.1909657591022551, 0.15685261460021138, 0.12946834496688098, 0.23955649783601984, 0.09743325848830864, 0.11156597669469193, 0.15301329171052203, 0.16056454041972756, 0.09370773652335629, 0.14325145224574953, 0.10808749342686497, 0.1316317796590738, 0.2517608640482649, 0.12832240958232433, 0.23943917913129553, 0.10697609759517945, 0.1374557093367912, 0.134515349927824, 0.11300155747449026, 0.14002842362970114, 0.1499253636575304, 0.12159166450146586, 0.16725823748856783, 0.18766486435197294, 0.20811305148527026, 0.11444893840234727, 0.165194621658884, 0.24328492901986465, 0.14072486985241994, 0.30369086656719446, 0.0826913260971196, 0.14615679712733254, 0.12717494537355378, 0.20184591121505946, 0.11967910540988669, 0.13273003947688267, 0.07114480700693093, 0.14580702292732894, 0.2158341629547067, 0.13470890204189345, 0.11447276134276763, 0.2665524312760681, 0.12742050719680265, 0.12420334154739976, 0.11222089233342558, 0.22649297694442794, 0.14085808536037803, 0.13934812654042616, 0.08237684844061732, 0.08745861559873447, 0.12665532325627282, 0.16608643083600327, 0.09374166751513258, 0.134468253236264, 0.1722769666230306, 0.1301530800992623, 0.2742955251596868, 0.11425927514210343, 0.091191091487417, 0.26235522993374616, 0.27323986461851746, 0.1877749100094661, 0.18274870002642274, 0.17263221787288785, 0.21136491996003315, 0.17943002341780812, 0.16789682587841526, 0.13192439364502206, 0.19339068210683763, 0.08779143914580345, 0.16051695391070098, 0.1886048389133066, 0.1148655652650632, 0.15694192465161905, 0.15308391448343173, 0.16373962629586458, 0.07828751826309599, 0.11762444730265997, 0.10590123769361526, 0.1719896961003542, 0.10198733638389967, 0.12579135945998132, 0.10600812180200592, 0.11430847953306511, 0.1262921013403684, 0.1613321586046368, 0.11509227653732523, 0.10572895553195849, 0.1492891352972947, 0.08882939946488477, 0.11456604188424535, 0.10999622303643264, 0.13506982330000028, 0.09059985211933963, 0.23717457486782223, 0.12198722921311855, 0.1253248009015806, 0.10756521442090161, 0.15107423794688657, 0.1391933739068918, 0.1372359594097361, 0.16851871594553813, 0.1465890833060257, 0.12962925742613152, 0.07339094663620926, 0.16149250703165308, 0.14834674133453518, 0.1640651619527489, 0.22758062405046076, 0.21106896630953997, 0.16829368192702532, 0.09749075266881846, 0.1385129729169421, 0.07968675607116893, 0.08743664802750573, 0.14880483940942213, 0.10075093319755979, 0.1023891351360362, 0.1359093704377301, 0.1859803672414273, 0.13988263614010066, 0.08128390240017325, 0.12312147577176802, 0.12504254729719833, 0.09020036144647747, 0.1271499795257114, 0.18358884088229388, 0.11444191026384942, 0.150917140126694], [0.0320557664235821, 0.0160130217045662, 0.040661209932295606, 0.06840081245172769, 0.06763223689631559, 0.02015004229178885, 0.027872565697180107, 0.07995214065886103, 0.06228597572771832, 0.0072064195319399005, 0.07177244871854782, 0.015512859627051512, 0.03786432993365452, 0.037369425044744276, 0.018078630200761836, 0.07658998161787167, 0.04627442162018269, 0.011178937984368531, 0.03421915658691432, 0.05011458684748504, 0.03820117221039254, 0.026224819739582017, 0.1575431681703776, 0.05172050165128894, 0.09151422258582897, 0.03339180664625019, 0.07019693599431776, 0.016422574044554494, 0.04166973667452112, 0.016042557326727547, 0.025429786619497463, 0.00902574771316722, 0.059493949374882504, 0.004990496445316239, 0.06349396950099617, 0.05730517405027058, 0.03145846741972491, 0.024019077063712757, 0.07789230978232808, 0.05860832599864807, 0.039012521447148174, 0.015398662580992095, 0.07886243038228713, 0.038962166727287695, 0.03945121978176758, 0.01986212610063376, 0.018291697087988723, 0.008960682698671008, 0.06995649499003775, 0.02221989958343329, 0.0025204884332197253, 0.040493273045285605, 0.023144908736867364, 0.053796125430380926, 0.01472170793931582, 0.06109423869929742, 0.07901958015281707, 0.025086112873395905, 0.052731540563399903, 0.10444055005791597, 0.03795135045947973, 0.037343238363973796, 0.06744510435964912, 0.04941154293192085, 0.04386788532428909, 0.04588333948049694, 0.0293605625120108, 0.07507360322051682, 0.0740662490716204, 0.02613378790556453, 0.014670894943265012, 0.036360386220621876, 0.06714027462294325, 0.03131372264761012, 0.03484049746475648, 0.006314899792414508, 0.06352684664307162, 0.017429102554160636, 0.0681177647493314, 0.03276829498645384, 0.03015606132976245, 0.008688789475854719, 0.05319196527125314, 0.028044810751453042, 0.04804151976713911, 0.052436948753893375, 0.11237240920308977, 0.00583792101679137, 0.025397557001269888, 0.026054715781356208, 0.022225012980925385, 0.03378375338797923, 0.07165839546360075, 0.024142783804563805, 0.04413553346239496, 0.016656302323099226, 0.07017988144070841, 0.05040293719503097, 0.04231031402014196, 0.011395559758966556, 0.03895837806339841, 0.06156176204967778, 0.10171764733968303, 0.06566682204720564, 0.028524291956273373, 0.03043870827241335, 0.04385158776130993, 0.0497503927181242, 0.0413531661615707, 0.04108903209271375, 0.031171634764177725, 0.020123172835155856, 0.02403390888503054, 0.04849461205594707, 0.009298044478782685, 0.04129317465412896, 0.017182785595650785, 0.05148300697328523, 0.02992571909999242, 0.05236573597358074, 0.05591605542576872, 0.020582590077538043, 0.0031279149698093534, 0.011584986459638458, 0.04438485426362604, 0.05500742176081985, 0.01404176893629483, 0.027854041691171005, 0.03565285231161397, 0.02585536192782456, 0.028881511752842925, 0.015176986780716106, 0.04931377981847618, 0.065599947120063, 0.0508629871183075, 0.023022955319902394, 0.03558700154826511, 0.025918004757841118, 0.02438978353893617, 0.10737680539023131, 0.02188013695558766, 0.012580253805936081, 0.04747704595502, 0.026278684817953035, 0.03170506824972108, 0.08836156441248022, 0.013777406657027313, 0.007134812485674047, 0.008059361043706303, 0.04664220403356012, 0.05609460873529315, 0.020343796641100198, 0.04365891880297568, 0.051960404598503374, 0.007369540344370762, 0.01145131360317464, 0.033690836498863064, 0.08471614986774512, 0.033541275188326836, 0.04807396275282372, 0.05919183589867316, 0.02007214461627882, 0.04079875587194692, 0.034810562938218936, 0.0726320561079774, 0.03820643403741997, 0.029162538958189543, 0.031859616792644374, 0.016568957107665483, 0.05941560826613568, 0.028053618189005647, 0.07355870169703849, 0.051210590536356904, 0.03762090920645278, 0.06160196047858335, 0.007016562849457841, 0.040596234903205186, 0.006448183485190384, 0.0434726286039222, 0.04124139129999094, 0.0010820954935297777, 0.026628863488440402, 0.015064794461068232, 0.03650291568192188, 0.06660531973466277, 0.0755861378274858, 0.015892372612142935, 0.025607030038372613, 0.07388100159005262, 0.029438083547574934, 0.0033153907497762702, 0.007892754456406692, 0.0447432002692949, 0.07842767285183072, 0.03511616450850852, 0.07580104895168915, 0.04050632371217944, 0.04177849470579531, 0.14679195679491386, 0.09027423482621089, 0.015619158366462216, 0.04633930017007515, 0.046468905129586346, 0.04156732029514387, 0.036613068950828165, 0.040258479784824885, 0.04868116942816414, 0.056354286207351834, 0.03414522754610516, 0.024094301152217668, 0.0649915196117945, 0.04872688943578396, 0.03806131448072847, 0.009517112557659857, 0.11111725194496103, 0.04013507175841369, 0.03278451462392695, 0.023627898444829043, 0.027689980670402292, 0.06342675318592228, 0.0046033347007323755, 0.025008710581460036, 0.03685120558657218, 0.01752753360051429, 0.07587447704281658, 0.011277129688096466, 0.05275044677546248, 0.024782754444458988, 0.0317911128513515, 0.040770858540781774, 0.05331134714651853, 0.037079178509884514, 0.03495175653370097, 0.005962259047009866, 0.06458186893723905, 0.03131280609522946, 0.05570484761847183, 0.0056148866224248195, 0.04968487221049145, 0.009112160605582176, 0.033264639641856775, 0.05479274070239626, 0.04952485774992965, 0.05439338732685428, 0.05107264754769858, 0.04647501671570353, 0.01629682825296186, 0.029349270735110622, 0.04895882542768959, 0.033617508597671986, 0.004143098312852089, 0.005397981904025073, 0.026683309297368396, 0.0546121798834065, 0.06256835549720563, 0.03529037625412457, 0.020991242563468404, 0.010222015553154051, 0.028554439850267954, 0.04475711924897041, 0.044955907214898616, 0.017260067288589198, 0.04431116642081179, 0.055291267271968536, 0.031969061310519464, 0.014441961866396014, 0.018009521409112494, 0.06778611379559152, 0.025535770873830188, 0.05266124804620631, 0.05754360383434687, 0.06027790223015472, 0.011851780200231588, 0.10631067314534448, 0.028705643162538763, 0.009875178402580786, 0.03875279944622889, 0.07643735894816928, 0.027197777199035045, 0.03674283347208984, 0.034441581956343725, 0.036236629384802654, 0.0054739374718337785, 0.06110630230978131, 0.029996378980285954, 0.03289442298409995, 0.03625877136073541, 0.18003098492044955, 0.029158382931200322, 0.034238816078868695, 0.02574677644588519, 0.07335334943491034, 0.014731055289303185, 0.02704523802094627, 0.05150965749635361, 0.028446474061638582, 0.01286777202039957, 0.03185269997629803, 0.04300035179767292, 0.01482209176174365, 0.020850967375736218, 0.027937895101786125, 0.07514321667258628, 0.040800076894811355, 0.075314801215427, 0.008087340011115884, 0.04440719661943149, 0.03464587665803265, 0.03747970447875559, 0.038548270968021825, 0.033545705809956416, 0.027845503282151185, 0.016266483689832967, 0.046234475521487184, 0.0314216197875794, 0.03379897112608887, 0.014385455669980729, 0.05938279049587436, 0.057517287277732976, 0.10685563960578293, 0.021917914127698168, 0.024434477527393028, 0.03876935676089488, 0.0525836119777523, 0.05155539605766535, 0.03648534904641565, 0.08015178580535576, 0.008632911321910797, 0.026322846315451898, 0.01408785630701459, 0.08904140879167244, 0.050365310307824984, 0.025192115681420546, 0.03801822167588398, 0.03049956438189838, 0.05601772965746932, 0.03637898444139864, 0.042025321890832856, 0.03947716897528153, 0.014528859010169981, 0.04175799658696633, 0.03643843789177481, 0.0447370256006252, 0.0427364997449331, 0.026883900682150852, 0.01968343734915834, 0.02998054897034308, 0.05246705397439655, 0.12529783125501126, 0.018678194610401988, 0.04331518939579837, 0.061635015736101195, 0.1749034272506833, 0.0641708898183424, 0.17831833072705194, 0.15064359933603555, 0.12081956374458969, 0.05831016074807849, 0.08530150400474668, 0.26708553079515696, 0.18364373012445867, 0.11670638094074093, 0.15961291413987055, 0.173246567719616, 0.09314861730672419, 0.09918612966430373, 0.14267174585256726, 0.1308014351525344, 0.13882414059480652, 0.09301358353695832, 0.2048209437634796, 0.12320443303906359, 0.2190393948694691, 0.1284272305201739, 0.17668012878857553, 0.1700008739135228, 0.14197932207025588, 0.1260338636348024, 0.15473627659957856, 0.06245543772820383, 0.13660317461472005, 0.10031029043602757, 0.15845528250792995, 0.17385469836881384, 0.14987571397796273, 0.11711188300978392, 0.19652772549306974, 0.0895335417590104, 0.1013009982125368, 0.10396708952612244, 0.23521558701759204, 0.10443143648444675, 0.15808725147508085, 0.09500253188889474, 0.17912862240336835, 0.220176201837603, 0.08943343345890753, 0.10670572577510029, 0.10773677669931203, 0.18059001507936046, 0.24082994903437793, 0.07119378875358962, 0.08239935777965002, 0.15246080729411915, 0.12015622472972609, 0.15684651414630935, 0.14280469418736175, 0.09717524342704564, 0.1921288380981423, 0.10696661294787191, 0.11491729295812547, 0.22573907364858314, 0.15433011401910335, 0.1406630637939088, 0.0945751290419139, 0.07765842194203287, 0.15505161514738575, 0.1345048559596762, 0.14984859590185806, 0.1803994909278117, 0.10787279010401107, 0.1341262270580046, 0.1316920865792781, 0.09603303362382576, 0.18486236629541963, 0.15950442699249834, 0.08349991083377972, 0.1235685900610406, 0.12969044008059427, 0.12211104171001352, 0.18563565448857844, 0.21189911785768345, 0.1452161546330899, 0.1328028441639617, 0.1984778669429943, 0.13350540568353608, 0.15465965727344155, 0.16684306523529813, 0.13188072567572817, 0.1955731157795526, 0.10427874702145346, 0.09165388735709712, 0.12208525949972682, 0.12727142457151785, 0.13074108370346949, 0.10381346495705657, 0.1376426118076779, 0.13189524208428338, 0.0818969015381299, 0.1887475242256187, 0.1794055473874323, 0.10991147719323635, 0.12940869113663211, 0.1040626855683513, 0.2324020754895173, 0.11883788101840764, 0.11674922512611374, 0.13857204787200317, 0.1773005345603451, 0.16275016532745212, 0.15192030114121735, 0.10731070971814916, 0.10231555861537345, 0.16765470762038603, 0.17736964335199445, 0.14096982311457396, 0.15892757044639438, 0.15499176835874096, 0.11797070372267626, 0.1954927560291253, 0.15359549171989784, 0.08977880672318861, 0.1533504790859297, 0.09800509811611846, 0.10214047113549896, 0.10817732298164628, 0.0934745091944933, 0.147203047235962, 0.12341517329332419, 0.09153136619715951, 0.2525331429205835, 0.14811522094532847, 0.1838796737138182, 0.10362147135310806, 0.14192596165230498, 0.12088177056284621, 0.09622881960240193, 0.0833360297838226, 0.1874377077911049, 0.15574679971905425, 0.0870556516747456, 0.16249743435764685, 0.08727698237635195, 0.12746797496220097, 0.116955527337268, 0.31623464659787714, 0.11962914402829483, 0.2776228403672576, 0.1097301185654942, 0.15731688734376803, 0.10694958065869287, 0.1464495446998626, 0.1822026722948067, 0.13708368554944173, 0.10360067637520842, 0.26050241373013705, 0.1771411212394014, 0.12516170652816072, 0.12528086575912312, 0.21716302289860323, 0.09523695407551713, 0.2057192986831069, 0.1915312311029993, 0.15269165975041687, 0.14220870507415384, 0.10529937819228508, 0.16466152213979512, 0.1485729479463771, 0.2109943507821299, 0.166118981433101, 0.09990230217226781, 0.13834956684149802, 0.15351352893048897, 0.11297904813545756, 0.20297853247029707, 0.10685248547815718, 0.14330009260447696, 0.0995148194488138], [0.07669646496651694, 0.020282133446016815, 0.025571789155947044, 0.030480415116471704, 0.0851507812330965, 0.030279914644779637, 0.07436474828864448, 0.030452907412836794, 0.013664844191225711, 0.03590431049815379, 0.05599369149422273, 0.08676337165525183, 0.002901966718127369, 0.08322988782310858, 0.046037724750931375, 0.012510041069617728, 0.03680736321257427, 0.024283944003400393, 0.029467635868059006, 0.018850961023417767, 0.02287602492287988, 0.009540998580632731, 0.034448168516973965, 0.10095889039803296, 0.026211093718302436, 0.026821959181688726, 0.019450556974334177, 0.03850439148664009, 0.009645227655710187, 0.05310765729518607, 0.12044535804307088, 0.0649643866927363, 0.013812213383062044, 0.04882350222032983, 0.042534969543339685, 0.06103494109993335, 0.022728649237251375, 0.01692282981821336, 0.019365568077773787, 0.02302381064509973, 0.03863349549646955, 0.0106379299541004, 0.04617518534359988, 0.0667331027216278, 0.054802971208118834, 0.02818073880916927, 0.029252785971038975, 0.03242602389946114, 0.09005395055282861, 0.04771298583364114, 0.007775259491609177, 0.027396986333769746, 0.017859856197901536, 0.08322538298671134, 0.11962305841734633, 0.04791628605744336, 0.04989211694919504, 0.02649984111485537, 0.03533883107593283, 0.04727240986539982, 0.08204328274587169, 0.028958390830666758, 0.03866600527544506, 0.05075833687442355, 0.01996516773942858, 0.03146388138702605, 0.04958716104738414, 0.03081546696193982, 0.04574514787236694, 0.014780082492507063, 0.037752061543869786, 0.030213607460609637, 0.047951111337170005, 0.005777426704298705, 0.042267480966984294, 0.11148803634569049, 0.04147865591221489, 0.029470311310433317, 0.06295005689025857, 0.009584109011484543, 0.04088062960363459, 0.011388199509383412, 0.04270509576599579, 0.05138685432029888, 0.053836899023735896, 0.046819143171887845, 0.04364810200058855, 0.051798835338559, 0.0291744114656467, 0.023668338071729522, 0.008220888557843864, 0.0299258341328823, 0.0039007833856885554, 0.06505683602881618, 0.011805980411736527, 0.05811656781588681, 0.01385104904329637, 0.03799245059781242, 0.04383087441965472, 0.05315715112374164, 0.0618430768372491, 0.0859587277227547, 0.05366670600778889, 0.028565388383867685, 0.030507603696605656, 0.024076094414340332, 0.019780738475674298, 0.02781606042844942, 0.006077066045691026, 0.013958354320493527, 0.059563881950452924, 0.036426541264518164, 0.06558916371432133, 0.04086183471372351, 0.04719261414720677, 0.008976509925560094, 0.010413971122034127, 0.029835728128091432, 0.015364873524958966, 0.08180339835234918, 0.038881447035237215, 0.05360714865673799, 0.0286686304025352, 0.0337558523460757, 0.03597003138565924, 0.055751287509338, 0.025077902864723, 0.048245762518490665, 0.01428876310455962, 0.053405970975290984, 0.056850374821806327, 0.031488171880482696, 0.060700855901814066, 0.036765847471542656, 0.019260606131865643, 0.037490413669729605, 0.022547329572262242, 0.07162149588111788, 0.014846354424662422, 0.0766320910770446, 0.07545125248725526, 0.03950735954276752, 0.04571837118419353, 0.014932565081835492, 0.04824345814995468, 0.042189032246824354, 0.06482207245426252, 0.06775553731131367, 0.017287981318077073, 0.031350529461633414, 0.04832149497815408, 0.02236911950603826, 0.02344842672755476, 0.05130694727995433, 0.04459467796550598, 0.0236391512589762, 0.016242198762483895, 0.018083572904288303, 0.012091994849470211, 0.056314729736186564, 0.050246125101693906, 0.04143748155911453, 0.0501600767893251, 0.01720479212963255, 0.04001022767624818, 0.007274113604580634, 0.034731813648249954, 0.09642655742936768, 0.04286738490918651, 0.034845781556214206, 0.029691996387555264, 0.01971561501704855, 0.04586708644637838, 0.040318508399650455, 0.05329475272446871, 0.03671720711281523, 0.05265694730042014, 0.04453336172446143, 0.039264243096113205, 0.024347154576389585, 0.04955864031217061, 0.012514826066762907, 0.1007134176325053, 0.027330437951604836, 0.04053039527207147, 0.026119312315131538, 0.04271425015758723, 0.01723493816825794, 0.03102679536823416, 0.027929250936722383, 0.013743432991759619, 0.013995457065902883, 0.0439890557754552, 0.050339743320364505, 0.023535731124866288, 0.03512899253109936, 0.03272670503065456, 0.08153719740221277, 0.025359857754665427, 0.08427001521340571, 0.03251213529438246, 0.02207407684181817, 0.01823288188461447, 0.08805717996438034, 0.018938866560347378, 0.04435940973053221, 0.053167081059655175, 0.03907389706000686, 0.03265475752414204, 0.032518154112040065, 0.1342091546393931, 0.028870067835669033, 0.03883900360960979, 0.035446913752821274, 0.04088749075890519, 0.040778157563181594, 0.021472547596204095, 0.01676704931014683, 0.021155910289962776, 0.04903299195575528, 0.0450768624432385, 0.034614635951584205, 0.023012615347397514, 0.10319726716261357, 0.06265501608140767, 0.054573573361267336, 0.0331768138858024, 0.07320554330362938, 0.07244540596730076, 0.09457668755203485, 0.053567952127195895, 0.03367684330441989, 0.032781130430521443, 0.04190887149889022, 0.006528382282340317, 0.030654816109745298, 0.0319075484003406, 0.01089980140022817, 0.014040052719792584, 0.044086169509682804, 0.028122869844082743, 0.027084462381026242, 0.050245698366779834, 0.01960561017767759, 0.03765604618820362, 0.06415707102860324, 0.004860876642851508, 0.020012110435345676, 0.04144162274315022, 0.032775979925645515, 0.057129210836137645, 0.043919564777752385, 0.01072596629455802, 0.0442853804997867, 0.04767208607518114, 0.02645723998284666, 0.0335028838890139, 0.027535187218745705, 0.028794261161237955, 0.055764709250070155, 0.0892138913332019, 0.050234900118084624, 0.01743242552038282, 0.04044950859679375, 0.05759940962889232, 0.020536623305815738, 0.04976572177838534, 0.041700328001752496, 0.012433754782250617, 0.06450260756537318, 0.09310771012678742, 0.032245477923424914, 0.03489340888336301, 0.03802960622124374, 0.009220432530128164, 0.037449799638125114, 0.06551080776262097, 0.012908508506370708, 0.10677035199478269, 0.057218687870772555, 0.013776288797089364, 0.015951256464177277, 0.08360317326150835, 0.08540305207134224, 0.027651813870761544, 0.05963019655609969, 0.0065512608398421435, 0.0356406068749493, 0.07554018404334784, 0.036297715560067445, 0.05997519132506568, 0.01751326024532318, 0.05851619578606915, 0.04536015876510646, 0.047757310603628866, 0.029870423531974666, 0.09554588788887486, 0.04309691263188142, 0.01816084717574995, 0.024437229039904196, 0.01959865439857822, 0.06587440817384049, 0.005050610870966921, 0.05271481626550667, 0.049663349927868694, 0.04503304233367089, 0.049315794749418274, 0.023807945326552726, 0.042355065525043756, 0.03895954323525075, 0.010211075368715683, 0.055111600740929134, 0.04707921398221515, 0.03388852608622983, 0.03222929539333563, 0.045479796681320295, 0.017759820257197134, 0.05180238280445337, 0.054654827399645, 0.03694185150379781, 0.05219532031333074, 0.0807177995739039, 0.04834954073885456, 0.02111163190420484, 0.019678437129186932, 0.042987434717360884, 0.0380892600514926, 0.02799942099954933, 0.08299795925267972, 0.04808673511433881, 0.08302233880385756, 0.017222798487637192, 0.07139842855394818, 0.03272224101237953, 0.03159541593049653, 0.0918084396107588, 0.04606202266586479, 0.08794037334155291, 0.044281740265432745, 0.019198831614630762, 0.024130571764544584, 0.018653555307537317, 0.014348190579767106, 0.03461544860329013, 0.03772779702558182, 0.056589424566482194, 0.02381545586104039, 0.05621486634481698, 0.020842390003963374, 0.04073796284501441, 0.002690880205591384, 0.02815662828652421, 0.22670376172754914, 0.10664418688975275, 0.18849617365049198, 0.10791099586640485, 0.1218678176519461, 0.2088779682526365, 0.2174936793744564, 0.11463912858744152, 0.14400835381820798, 0.06045277819794137, 0.1262181092170067, 0.21374837175244465, 0.07990407175384462, 0.17151792766526341, 0.0945786022930406, 0.1859186650835909, 0.16611221304628998, 0.11608173750573769, 0.1605343201663345, 0.11644153812085278, 0.1267166098114103, 0.16815064038382843, 0.13008316978812218, 0.37624218442942947, 0.103642288595438, 0.19649373512947932, 0.08960753388237208, 0.131032228237018, 0.16423861670773476, 0.1445735734887421, 0.15720224037067965, 0.1311330118915066, 0.08037155799684115, 0.14549958083080128, 0.2186356220045127, 0.13331201684195548, 0.11093244233052246, 0.07922645381768234, 0.15364929742645472, 0.0947408728825394, 0.11792237506597303, 0.09790656316909008, 0.1749343451228924, 0.24933068663813174, 0.1115671121806372, 0.13261270592920482, 0.08396002755034715, 0.24197086750064045, 0.24327649822225794, 0.23170024127466604, 0.1835905626649037, 0.13487420801538974, 0.12856587854912505, 0.19067584653384984, 0.18751606374280527, 0.1289850435568951, 0.11535046229255386, 0.09882367216050625, 0.042735497845569625, 0.14784114580834284, 0.14243090408854187, 0.14209906017640606, 0.16559962648898363, 0.20521587022813037, 0.28366519894916564, 0.16283683333313093, 0.14864802360534668, 0.16611679951893166, 0.1292744217789732, 0.12437772398698144, 0.07796725185471587, 0.05109334233566187, 0.11956262533203699, 0.07296870913705789, 0.1782790117431432, 0.23093625961337239, 0.136706140183378, 0.14439336518989876, 0.18803420156473294, 0.1082794128160458, 0.1204276058706455, 0.08378731494303793, 0.10086563212098554, 0.14667726529296488, 0.2094414661405608, 0.19843082962324843, 0.15191859420156106, 0.10880014815484174, 0.14665332360891625, 0.2373442446696572, 0.2801796578569338, 0.08716368611203507, 0.1304038814851083, 0.1969485083827749, 0.17504574148915708, 0.14773265866097063, 0.11367989529389888, 0.08971652569016442, 0.13399268500506878, 0.1414300437318161, 0.14265218283981085, 0.11013743147486821, 0.2023837753222324, 0.18605060409754515, 0.10254567634547129, 0.06998940181802027, 0.15239138680044562, 0.09215470345225185, 0.13404009339865297, 0.24193613498937339, 0.10250565232126974, 0.1491416260250844, 0.17254687089007348, 0.11575470271054655, 0.10046244555269368, 0.1585155152133666, 0.12401279513142072, 0.14206873602233827, 0.1638483806164004, 0.17610726499697194, 0.17105794453527778, 0.16079298831755295, 0.15806797047844157, 0.08131174778100103, 0.1565372760524042, 0.13246209447970614, 0.10331818528356962, 0.12181219368358143, 0.1687458428204991, 0.1405992836225778, 0.10895803265157156, 0.06841943293693475, 0.12753231916576624, 0.18485310429241508, 0.10536508794757538, 0.1434854810941033, 0.12978616228792816, 0.14265106961829588, 0.15560236293822527, 0.19591687858337536, 0.128031799395103, 0.18814742361428216, 0.2203620653017424, 0.13497819774784148, 0.24159106600563973, 0.15444349934114143, 0.09591733280103654, 0.11070705950260162, 0.18117424857337028, 0.16439905419247225, 0.09351147557026707, 0.12082203509635292, 0.16748828842537478, 0.13369866093853489, 0.22474931582110003, 0.0930143627920188, 0.11072093766415492, 0.20927654608385637, 0.08195668153348379, 0.1642334513599053, 0.1148156558338087, 0.18339610513066873, 0.10289723169989884, 0.13644809543620795, 0.11698994814651087, 0.10226046899333596, 0.11568202418857254, 0.14844494231510907, 0.11092795233707875, 0.11170825382578187, 0.12944694142788649, 0.140666076913476, 0.1541890762746334, 0.1696154024102725, 0.09155842490145005, 0.12889732170151547], [0.04360689054010436, 0.08841603805194609, 0.023844909846957307, 0.026313114904041868, 0.029381487365753856, 0.03826119711447973, 0.043908317529712804, 0.07729724093223922, 0.06286252057179809, 0.01915869997901609, 0.028067340499546845, 0.07708483826718293, 0.016202872357098386, 0.04745024329167791, 0.09000850885058753, 0.05071669125754852, 0.029678934588446282, 0.04606604139553383, 0.0517172139370814, 0.05976372747682035, 0.03207912181096617, 0.0474530337669421, 0.026151616148126777, 0.04927112488076091, 0.023311995864787605, 0.10531174237257801, 0.025847984979918692, 0.033504034217912704, 0.038588758834521286, 0.0338191055925563, 0.056362987888860516, 0.036364824263728224, 0.029256507841637358, 0.014413860444619786, 0.018997702172782738, 0.058450723518035375, 0.049612765142228454, 0.014642135793110356, 0.004945238424625131, 0.06856432242784649, 0.025789895225898363, 0.05093567306175828, 0.06096999946748838, 0.03060404949792428, 0.024915918002079707, 0.025223957527487073, 0.013345249426492956, 0.08296180181787349, 0.024769510819169227, 0.021843257782165892, 0.02852880978025496, 0.03966755211877171, 0.024223638938565273, 0.04077096986293327, 0.014534882466250565, 0.019868810995831154, 0.031557199035887606, 0.01663919767452171, 0.042489906336413696, 0.010729971108958125, 0.04689489789598156, 0.05015287795686163, 0.020958064851583913, 0.020039914998051245, 0.02503986037481809, 0.03052503860089928, 0.04835086176171899, 0.0559589515614789, 0.019634283053164836, 0.11297455072053708, 0.013469586065184558, 0.009728257282404229, 0.034407060957164504, 0.022581657613045536, 0.02038189664745005, 0.01129515738284681, 0.017208642020705156, 0.0327201889740536, 0.04843936658289749, 0.03402868809644133, 0.028191535202495288, 0.05321793672919739, 0.041731416567927226, 0.0069793511011084775, 0.02293705543706892, 0.03243639541324228, 0.011045362534787273, 0.011318236320221331, 0.009949424711521715, 0.03117669992207084, 0.04893012657703366, 0.0332203260040842, 0.053247422256390564, 0.050970450101885945, 0.07051122811390087, 0.03408220065466594, 0.04105212508875411, 0.010543901698838454, 0.0330677701276727, 0.010103264503413811, 0.04495430788665544, 0.030381963661056943, 0.051496269152266905, 0.06825074277003296, 0.0389688497671159, 0.04184808218269609, 0.022049790059099905, 0.028924901416758075, 0.06139651915873401, 0.012474020004447084, 0.034669306260184385, 0.02339550974284066, 0.03672527425806038, 0.05609901709249243, 0.012633216247195378, 0.006532118068207637, 0.027517340422491543, 0.0027485302371133002, 0.060733079953934066, 0.061325503047555685, 0.04362652405689005, 0.07938503593322821, 0.03555704104655888, 0.03673541570606176, 0.02377746903221123, 0.08447494445135817, 0.03320556097605731, 0.03271408480941318, 0.03604727782658301, 0.05047656195529271, 0.0161741419651662, 0.018018573755398393, 0.047221758286468685, 0.05910370215133298, 0.029513801164284814, 0.04098556186363567, 0.07835172888007946, 0.016725303503335454, 0.06580080196727067, 0.05595714443188626, 0.014442774518101942, 0.06739749558619224, 0.048484860235475935, 0.03210333437891677, 0.10158982724533416, 0.015918718854663894, 0.04632002659491263, 0.029625854331243318, 0.026099582319147885, 0.07541093902545981, 0.01669280114583671, 0.022321382712107152, 0.024281650767079554, 0.035444987879600376, 0.043994640436721966, 0.040912964977906086, 0.01979790991754271, 0.05163079084013589, 0.04605899470334407, 0.026095879002241418, 0.04785794582858216, 0.05060268253146205, 0.025594040598662104, 0.04237835782987531, 0.045294590017874725, 0.010088348262797808, 0.0077681432230747305, 0.0169052260753233, 0.04642158579372335, 0.08635943551780656, 0.015491835511056706, 0.06663404827122577, 0.020527405831671786, 0.07041137956548482, 0.06987126675085165, 0.036910384442307986, 0.03323656419524923, 0.005708793814847013, 0.02714302154345205, 0.0219204745371826, 0.010258109905407764, 0.059001159606850706, 0.02952295555587625, 0.06348437353153713, 0.030951619519328233, 0.03672361926874146, 0.04201396332064178, 0.0724623491987586, 0.02477970421750797, 0.07947772275656462, 0.026950896208290942, 0.03400047164177522, 0.011964963287027786, 0.023801358765922487, 0.00366247907095385, 0.02740058389463229, 0.07018896532827057, 0.01557718434924027, 0.03940870585211087, 0.0524720226530917, 0.03835760580841452, 0.011043504382541869, 0.025387636342202313, 0.038879851417732425, 0.019968991655332502, 0.01732360069581773, 0.027242265241511632, 0.017069919776986353, 0.014265154459280893, 0.018620756090967916, 0.08322986555867828, 0.026451540288690012, 0.039630882602068596, 0.027141869359184057, 0.04657365927414503, 0.03356527624418959, 0.06470104301115498, 0.02092593913403107, 0.042321256987634115, 0.027167677544639446, 0.027409651083871722, 0.010121435989276506, 0.04808621932170354, 0.06583926748135127, 0.01997596784349298, 0.04992522415705025, 0.051635629642987624, 0.06178885552799329, 0.02752717016846873, 0.020030825544381514, 0.04203557095024735, 0.043145571544300765, 0.06808395992266014, 0.03358567046234384, 0.061328453084570356, 0.07043645673547871, 0.023348555914708413, 0.04272698912245687, 0.019908181930077262, 0.022283757680270355, 0.019081555583397858, 0.020078885172551963, 0.0553675637638662, 0.014902224229444982, 0.029297815781319514, 0.03170266740198713, 0.020949474492226727, 0.010827433652593754, 0.021646610912284814, 0.03759487466595601, 0.03199038692400791, 0.11639313524938188, 0.018968884578498546, 0.07266165295732208, 0.008595710241934285, 0.025978810772357974, 0.010533699951338349, 0.03248996734328102, 0.05390829734096769, 0.031185817206278443, 0.02095374740747502, 0.02664889776497148, 0.017659600634942763, 0.034066266744048335, 0.07452321908203885, 0.0080693874588178, 0.015589058712066617, 0.0716703588841483, 0.03500890190480277, 0.044339865271467716, 0.048406433779746294, 0.018582310985948425, 0.028476646075432654, 0.022865030005050357, 0.017279849234910216, 0.025026115799846593, 0.05787063120806124, 0.06671794806607068, 0.05444804650323931, 0.05914626432058867, 0.019586049020290375, 0.02284063746628817, 0.07182939370977692, 0.010144476891582599, 0.01919032660225639, 0.02227704866527347, 0.010276801822328707, 0.11752737438655458, 0.02472378339007264, 0.08371707808692008, 0.04265438110451214, 0.0575057283276692, 0.021736859780503437, 0.01970410430658376, 0.06859699176857248, 0.0699164041725453, 0.00986204238870414, 0.02939393318229122, 0.0177669764161692, 0.06315042191999964, 0.05146966315805912, 0.05093284176837187, 0.0841529859462753, 0.03338442598760594, 0.03609881256124936, 0.0012289884352867375, 0.011220780270377873, 0.0011213401467102813, 0.05783281507319771, 0.01099369606890832, 0.01975487462914316, 0.04646395500458311, 0.04880503016465809, 0.021167684462852776, 0.043700527312466875, 0.05958904075669125, 0.0454460660694167, 0.023043145447445568, 0.024015355193114374, 0.04122577651287429, 0.07841164246201515, 0.06316229628282599, 0.022663100899080746, 0.021888176270294935, 0.013380525560933165, 0.0714743354183156, 0.029416329343803227, 0.04961610109603498, 0.04142060883168597, 0.014539046842401149, 0.03348713922605384, 0.0232315915854997, 0.07199929357739165, 0.03159681487886701, 0.017687227082205936, 0.019845605893351603, 0.0350219748361269, 0.013261339427117491, 0.04165439648204483, 0.03771232695726212, 0.006552656541316537, 0.04207584359392058, 0.02907031597715104, 0.009406038097949931, 0.046708529771422036, 0.017121827440860216, 0.011116682926513022, 0.0551625343359774, 0.06377425641403534, 0.018226011452497914, 0.09253394833649509, 0.01529949959149235, 0.15617739380104467, 0.1617998897563666, 0.11748525750590488, 0.09017921765916981, 0.14169015164952725, 0.10076328995637596, 0.23424831626471132, 0.15810389042599127, 0.17362996120937169, 0.10463250655448064, 0.1584351999917999, 0.13733315106946975, 0.1586191784008406, 0.2077493694378063, 0.16381499881390482, 0.1649102009832859, 0.1442445645807311, 0.21297549916198477, 0.11610389803536236, 0.16534127003978938, 0.12728136935038492, 0.20082959934370592, 0.10055387072497979, 0.18674307240871713, 0.08801757896435447, 0.16041657101595774, 0.17992794513702393, 0.14720377454068512, 0.3056399244815111, 0.08280114911030978, 0.18839947180822492, 0.12457984790671617, 0.19835551647702232, 0.1046139899699483, 0.148174726346042, 0.21976249903673306, 0.17760862974682823, 0.15024712920421734, 0.15763976611196995, 0.23635591176571324, 0.1162760540319141, 0.1754833266022615, 0.1038568805961404, 0.12223305078805424, 0.14971941767726094, 0.07935899397125468, 0.11594269613851793, 0.2242765825940296, 0.11369599247700535, 0.17132879875134677, 0.07498078281059861, 0.1285733000258915, 0.12296627784962766, 0.13802009780192748, 0.14881709968904033, 0.09349842119263485, 0.15088881977135316, 0.14157771627651528, 0.10109056223882362, 0.11211886929231696, 0.18815517163602635, 0.15779733890667558, 0.09400989452842623, 0.14416447200346738, 0.13577936100773513, 0.1393843730329536, 0.17033096635714173, 0.1477905610227026, 0.13581010076450184, 0.1542514463653788, 0.13717130350414664, 0.15233559213811532, 0.2274312000372447, 0.08907952549634501, 0.09547715017106384, 0.19793424376985058, 0.1484366154181771, 0.14538533461745828, 0.1396410819143057, 0.0872787635307759, 0.17097253818064928, 0.13654359499923885, 0.09599980025086552, 0.16016109409974888, 0.1286082254955545, 0.15861956431763247, 0.13141792238457128, 0.0932509075209964, 0.12291792692849413, 0.11142504285089672, 0.08666261768667027, 0.12863437877967954, 0.2043536282144487, 0.13631452369736508, 0.14711688389070332, 0.12155658318079077, 0.11986430094111711, 0.07717085318290628, 0.1062095703673549, 0.06153107424324844, 0.07095470587955788, 0.1528743765084073, 0.20026950049214065, 0.24534290452720597, 0.08829133497783914, 0.16845950740389526, 0.18446524307364598, 0.1495301997056231, 0.16644128132611513, 0.1402655101264827, 0.11642081735772081, 0.20249819965101779, 0.1377192756626755, 0.20634829852497205, 0.145529430010356, 0.08756614537560381, 0.10165967818466015, 0.07915753798442893, 0.10542320553213358, 0.21732215420342982, 0.13705306453630328, 0.11935371076106094, 0.07868714994401671, 0.141364423034247, 0.09643400117056444, 0.16860817442648113, 0.16021197574445978, 0.22604875703109428, 0.1214921053906437, 0.08268551508081146, 0.12163776671513915, 0.19039322185562924, 0.13275810750201344, 0.12259679220733233, 0.11938532625208609, 0.11106338686659001, 0.18688654439756647, 0.18122377950930968, 0.119293233146891, 0.1480474480194971, 0.1708861521910876, 0.139088686555624, 0.12688675458775833, 0.16758746904088184, 0.13906242937082425, 0.1713854691479355, 0.09097495581954718, 0.25572826678398997, 0.12247479797224514, 0.20826131774811074, 0.2166439054417424, 0.16666239680489525, 0.14147017907816917, 0.08876538180629723, 0.2698469435563311, 0.17812534264521673, 0.1021065327222459, 0.14745834603672847, 0.09335144626675174, 0.07472788114682771, 0.1252446637954563, 0.11838229882414453, 0.13803784997435287, 0.12469318869989365, 0.10481847391929477, 0.11785840193624608, 0.18312584463274106, 0.11476969462819397, 0.1391953628626652, 0.19064627937041223, 0.09440227542654611, 0.12466233019949868, 0.1280789851443842, 0.2584185224259272, 0.2235205567558296, 0.07053732202621177], [0.07653516659047455, 0.025238438684027642, 0.03348501297296025, 0.08152047681505792, 0.04006063063570764, 0.011417336227168562, 0.0406416246551089, 0.009463688129471848, 0.03241960432205815, 0.05792538315290585, 0.023563339018437546, 0.007374977503786795, 0.027275253705738578, 0.031354548191302456, 0.025633819714130368, 0.032637743788654916, 0.07800764695275575, 0.01970747922314331, 0.03773628719500266, 0.045850532842450775, 0.030725283031642903, 0.08656368940137327, 0.028622966055991128, 0.011702576975949341, 0.01198122467030771, 0.040258535445900634, 0.014542063672706718, 0.01858392330177594, 0.08298471933812834, 0.06438919255742803, 0.04072659314260818, 0.0436939036444528, 0.0462140441959491, 0.02847544750693487, 0.06405825406545773, 0.019814534025499597, 0.013317211087269243, 0.018377057058387436, 0.020650938167818822, 0.035613255022326484, 0.05517448291357141, 0.005677896351699019, 0.1155954526620917, 0.03803568069997709, 0.01741033178404905, 0.09341591663542204, 0.007164397275118972, 0.06733578600687906, 0.1446480702725239, 0.004139542497796356, 0.024484232963004615, 0.029029560937487986, 0.05809056296129711, 0.03407243399124127, 0.043677598659996875, 0.0672300744918175, 0.02477465575793758, 0.05207259506278206, 0.018835617120203096, 0.05970423691906035, 0.019537746338755824, 0.030811938049737364, 0.03237446318962611, 0.010929202508123126, 0.05466823058668524, 0.02655836502526654, 0.02279201380588347, 0.019539605418685824, 0.05379316797188949, 0.021932165218458977, 0.030090583495621104, 0.022891040425747633, 0.05188487994018942, 0.02290812280989485, 0.020236296550137922, 0.04280750472389627, 0.0341505079268245, 0.03806923319643829, 0.012204236336401664, 0.06182994453411084, 0.08320478096720763, 0.03358146990649402, 0.026294948984286748, 0.0377175776520744, 0.02145801263395697, 0.05237745448539499, 0.08679206308443099, 0.036497772598522715, 0.02209786638559308, 0.04474055822356604, 0.048779615317471325, 0.04649621245334856, 0.01935944535944145, 0.045188704098109156, 0.04208937294606585, 0.048775470422697254, 0.036723708326462656, 0.028664415003731847, 0.014649534077761928, 0.004710112125394517, 0.02311737320269458, 0.03172812306729611, 0.0025630100162743474, 0.031700667313998565, 0.030444649164564908, 0.05333660985343158, 0.03843387261440512, 0.01777550183760468, 0.028966313257114962, 0.0718922536179889, 0.008276538501377217, 0.048481531703146175, 0.03811793663771823, 0.009635000860725995, 0.021646844688802958, 0.035064692856394686, 0.08636769562144764, 0.050921872825711034, 0.06192969289259054, 0.01561885408591479, 0.016773300048953388, 0.044097049394622445, 0.019600919804361183, 0.010718503999669338, 0.040788933547446504, 0.042862397676799446, 0.018373426100879442, 0.050583958145580254, 0.04590935917804018, 0.05606700084172189, 0.04418600321514532, 0.01790140348020941, 0.029118971178831998, 0.023386598404613324, 0.017610348004382104, 0.03640273687778972, 0.05212187737924978, 0.049045886771637015, 0.0437951362982858, 0.04988826149201486, 0.01680769673839677, 0.03148968215100467, 0.057361332364962436, 0.04575312224915251, 0.03201156039722264, 0.06507993908599019, 0.02517025757697411, 0.027622979578154627, 0.06842074653832242, 0.04386847904243041, 0.0462690855783876, 0.05745557398768142, 0.046637654668302275, 0.03848281725367997, 0.02878095445339568, 0.07737447624094784, 0.03835346833511721, 0.06367096430039965, 0.02114524191711098, 0.02003954392421292, 0.04769028353621252, 0.01724671234114794, 0.06337106242426671, 0.05341647607565392, 0.0216217600973323, 0.08228854028857313, 0.03600522402848583, 0.003764280627365224, 0.032055072515504435, 0.01819031785998959, 0.032931326277321205, 0.054142704684636556, 0.02804114825266879, 0.06261740403715521, 0.02820622601575451, 0.057190330408047885, 0.03122037902357988, 0.0055691638317512115, 0.05972143990220502, 0.0593175148969749, 0.012702395542874001, 0.035109425807604566, 0.052432714801398106, 0.010528324946790235, 0.06515062123071402, 0.011259332059125882, 0.041835970332613215, 0.024108101388264913, 0.031086384260561317, 0.03691072211950086, 0.03843662598228548, 0.011800511711044237, 0.029962527769384906, 0.011759291901398683, 0.07366445031948388, 0.04935657576425001, 0.062037549214437604, 0.0350956738111563, 0.057382090235478245, 0.037509817120735534, 0.05246558823273517, 0.042172920220764354, 0.020897318208881188, 0.021534594852710143, 0.03803820029133931, 0.04411026704474352, 0.07478135288693011, 0.010933007870335132, 0.00622122823187965, 0.07052033426589333, 0.01073350002116058, 0.030609851237386465, 0.025103317711909767, 0.02372623115661554, 0.0080704719221103, 0.03991388948634267, 0.025165711922454648, 0.009769839816726744, 0.051305047381902114, 0.03782112580665853, 0.03670707308629062, 0.0745809062209446, 0.06513819025713019, 0.05210522729612421, 0.03638467300334014, 0.013854757926310413, 0.026881748453888576, 0.00831938083138084, 0.058445020113140345, 0.026489204283279832, 0.06236016080947593, 0.05501090985490009, 0.021253383965813555, 0.010736989970610011, 0.10283477997290902, 0.0496352856134763, 0.029963971246615984, 0.047002375722513534, 0.03326982354337815, 0.04006106479209848, 0.03528700319293421, 0.02352988114580512, 0.07665098615689203, 0.03374737701960839, 0.062204179921536706, 0.021877788058191072, 0.006018664125804207, 0.008163659695128445, 0.0588192592113046, 0.010189803560933797, 0.028510228257800918, 0.036901282001053914, 0.021523121249629185, 0.008903349935280858, 0.0306367782104644, 0.019858485866279807, 0.03518748861097265, 0.08445590836345218, 0.03888931008987129, 0.013285474997246638, 0.021953355389996432, 0.010306916319677839, 0.06276706553762779, 0.032822902212501504, 0.04736268841952551, 0.04660145641537383, 0.03284122212789953, 0.02591261305497028, 0.04091903203516267, 0.06584777249372564, 0.04079002821526956, 0.032093916524900123, 0.05488698974659201, 0.03536818301654421, 0.010970343464578036, 0.017551545788592193, 0.037825871841050684, 0.014369612672453513, 0.033316567714791745, 0.037018107177573256, 0.04559759036055766, 0.06288736767601222, 0.02359187088586623, 0.046418869533226825, 0.013415138400887372, 0.04747820370539557, 0.004391300790302921, 0.049090000029536895, 0.03689735975058284, 0.0162100396482856, 0.0235892214186606, 0.05565385094087105, 0.041541204118402675, 0.04124871258682106, 0.059936696125078015, 0.02276594030263368, 0.06300136898062192, 0.042814254557015374, 0.028093031796743162, 0.01645617106987629, 0.021089682886668015, 0.05150861106812954, 0.016019658360164613, 0.061383880383800715, 0.01546695408251253, 0.06764940277207643, 0.021151603978069033, 0.11405067969462834, 0.018303152137377765, 0.0220589759919676, 0.07429578792653047, 0.011395671081118053, 0.010723629457061179, 0.05575906150625087, 0.09327122010290623, 0.04746563914522994, 0.021009742449678015, 0.04942870138620492, 0.037225244304863736, 0.06139236684248317, 0.036581338426913135, 0.02856374081602553, 0.04329080242314376, 0.046458129145321436, 0.05494409801030997, 0.05354935390641913, 0.10378441729699261, 0.06794618762796745, 0.02004192807362415, 0.01229013343618135, 0.05540312376979273, 0.03200071761966683, 0.033896207314683124, 0.07475821272237226, 0.041727672432898544, 0.01949621204403229, 0.03917994996299967, 0.050558105431264266, 0.019493310246616602, 0.04348087757534813, 0.03288173225882929, 0.10812030377564952, 0.020598436785803642, 0.014178676628944231, 0.06224772543646395, 0.021561026442213915, 0.017996149763348512, 0.03842692240141332, 0.004386972213978879, 0.027177806005056482, 0.09769182273885235, 0.00434424630839203, 0.15423302626004443, 0.0676826064591296, 0.13510820717783645, 0.22657596389763057, 0.13596949924249202, 0.11841358034871519, 0.16420630359789357, 0.08673786403960548, 0.08799108429229818, 0.11878060948220082, 0.17793821753002703, 0.1848799700383097, 0.21388108259998262, 0.12086172515409999, 0.09574842741130851, 0.11265979104791768, 0.12014423904474825, 0.17943192331586033, 0.1380342134507373, 0.14209631423000246, 0.13494398473994806, 0.12409689530613832, 0.23078588565113023, 0.12805008591385558, 0.17468851612647995, 0.12432040050043724, 0.1187736184510868, 0.1501741909305565, 0.19729118765098974, 0.13002384250285104, 0.20883076766040176, 0.09491475066170096, 0.07064130433718674, 0.18995177757460624, 0.12941507360665128, 0.107560657634167, 0.1241088958340697, 0.166285504528787, 0.1456986099947244, 0.16601295821601525, 0.19704636797541752, 0.14083916059462354, 0.33652757643722, 0.12748964567435905, 0.19825079943984747, 0.2504652820061892, 0.11816612604889087, 0.14892162376781926, 0.18390254670521244, 0.10896938008954749, 0.1111022086115554, 0.09731314188684337, 0.1432159182149917, 0.06911459524417296, 0.12728625268209726, 0.15039373305626214, 0.08916139180655591, 0.16195237141801044, 0.21658854122506455, 0.1379185274709016, 0.10283574476488866, 0.12602948496351019, 0.09986238204874098, 0.07340734809986316, 0.15889500500634313, 0.11057182535296306, 0.12335491832345724, 0.119087272323668, 0.20592383458279073, 0.09389703613123856, 0.2102301167906262, 0.07914056506706402, 0.18730410636635497, 0.11464791561593302, 0.19709364278241992, 0.14320868969662115, 0.12794320180546492, 0.1536338310688734, 0.08168066939106211, 0.18401706009171903, 0.16494637326104566, 0.14738745609065518, 0.1017064334882889, 0.1790565747069195, 0.1854242166155018, 0.08552743602194823, 0.1905504977912642, 0.1822791135055013, 0.08488268780638464, 0.12595765991136432, 0.10267527759424411, 0.17081772617530078, 0.11977450107224286, 0.1356662725447677, 0.14303241478046402, 0.12246072685229592, 0.1281935430597514, 0.15132769622141495, 0.18490244226995856, 0.14399318431969732, 0.11910938090295531, 0.07664281511097215, 0.10434253461426124, 0.12133010939578526, 0.13670265208929777, 0.10648875148035586, 0.11259662685915828, 0.09273370480514131, 0.1448861215612851, 0.30052759568206966, 0.09645974627346732, 0.14577426452888176, 0.11455741812824272, 0.17888205125927925, 0.13803765701595694, 0.10949525851174258, 0.15182017057668418, 0.13056421506917104, 0.13028138258960098, 0.11289948990452103, 0.09154050203505903, 0.11125414850539528, 0.22373423591488972, 0.07887316183769144, 0.1696222450118512, 0.14300879964139313, 0.09419091176823713, 0.13193090970162302, 0.13406127429334447, 0.12295201377128251, 0.1212778696208261, 0.2482167081325315, 0.19164690223988146, 0.07546661494416185, 0.19161274860380217, 0.21248302480671555, 0.1592778938356787, 0.2217408420983702, 0.23839487344957888, 0.12185126775875688, 0.09769935553777032, 0.12316289503360167, 0.22968176286667585, 0.08901108463760465, 0.15375355433207005, 0.1406396712991409, 0.08526443372829817, 0.10648874405887909, 0.2676942106336355, 0.09816197329200804, 0.15234810474794358, 0.11471080521005206, 0.12137355472077616, 0.14067378040635958, 0.16907860699575394, 0.15829727926757187, 0.11247757152887061, 0.14581848168745637, 0.17164306860649958, 0.13517780578695238, 0.20406463590916246, 0.10576669374131598, 0.148586647992488, 0.15195540472632274, 0.09614828915800899, 0.41745174501556903, 0.11448598641436547, 0.06073322467273101, 0.11879067300469615, 0.1424684122321196, 0.10882181886699982, 0.21281139546772465, 0.12433449388481677, 0.09281226855819114, 0.15507537871599197, 0.10842852512723766]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.02737526738201268, 0.03556289288098924, 0.04328606381022837, 0.04030996627989225, 0.012191226487630047, 0.034272350021637976, 0.03019178275280865, 0.044204130172147416, 0.043429506113170646, 0.059759233772638254, 0.014026010358065832, 0.02133616497303592, 0.018853324763767887, 0.035857447583111934, 0.012523170589702204, 0.0258200969255995, 0.04992392168787774, 0.05436859959445428, 0.03383227871381678, 0.016137875063577667, 0.07087824240443297, 0.004106586038687965, 0.013618424709420651, 0.04466442500415724, 0.012567263438540976, 0.03129710225039162, 0.04685045809310395, 0.013091913606331218, 0.03408819349715486, 0.038446103208116256, 0.0427079715882428, 0.04661988023144659, 0.15963802841724828, 0.023007743147900328, 0.03870006985380314, 0.040026599453995004, 0.01945479463756783, 0.01243771135705174, 0.005623745082630194, 0.03967696255131159, 0.05032534565543756, 0.07323802710743621, 0.03236158692743629, 0.00935833748371806, 0.054769177513662726, 0.026130234873562586, 0.005575742043220089, 0.05117651111504529, 0.0906418873637449, 0.007085086272127228, 0.052818768890574574, 0.041456410035607405, 0.05172584882529918, 0.046868043282302096, 0.03002570680109784, 0.039782165695214644, 0.05739467334933579, 0.02155496124032652, 0.03700304529047571, 0.01659236444538692, 0.026262168321409263, 0.04404277613502927, 0.06740951837855391, 0.04870515193033498, 0.10643360248650424, 0.017068177585315425, 0.028789292482542805, 0.07218615151941776, 0.036577746432158165, 0.006979000436331262, 0.039269853732548654, 0.03253225491789635, 0.054453204429592006, 0.03440374355704989, 0.04714287169917952, 0.02552623798692366, 0.004889206275038305, 0.030247827889979817, 0.04074539916473441, 0.0047947893199307146, 0.010803319419210311, 0.0983310048468411, 0.009943147997546475, 0.04705798113718629, 0.01679028780927183, 0.04154831018240657, 0.023158449221227784, 0.03670329926535487, 0.06832402243162505, 0.0345416234631557, 0.042726076280814596, 0.05354280074243434, 0.020921482537232805, 0.023681943494011648, 0.06833333638496697, 0.07317890020203777, 0.044098771177232265, 0.0681115010229405, 0.0709400929918047, 0.021754979316028766, 0.024135304811352398, 0.03989122800703626, 0.026572076203592587, 0.022062126408854965, 0.02674420251423726, 0.002414325831523456, 0.051067649183096364, 0.05173647638002876, 0.05419675901066512, 0.016935320163611323, 0.03351518498675432, 0.024760122651059646, 0.05777354344900232, 0.009835016153374454, 0.058416250758455135, 0.026205126850982197, 0.10410859482362866, 0.029860573376936372, 0.023442070232704282, 0.004270910985724186, 0.10947476781439036, 0.021847115094715264, 0.07146817559259944, 0.031243463527061976, 0.05264766303298529, 0.05467614930239506, 0.04690772220783401, 0.06062209919036832, 0.059743285019067116, 0.010242726111755474, 0.019466817429929506, 0.028320403580437414, 0.050810673128580675, 0.025197245777235366, 0.03901443247741554, 0.020795352684217505, 0.030568424554076046, 0.041426905954722315, 0.03575053378881421, 0.068684431607835, 0.032769460158306174, 0.028350000429782085, 0.032174947918974794, 0.03536304364388343, 0.04666047570935916, 0.030754390063520987, 0.024229427690443117, 0.028487238378147595, 0.018271883600391448, 0.06799307651817799, 0.04103516330360435, 0.015123399080039235, 0.046530618419637904, 0.018101970745192375, 0.0534548562427517, 0.011302155835437588, 0.023319257779803593, 0.04829931218409911, 0.03404799135751091, 0.03215793789422605, 0.06067678434192203, 0.01769378395692911, 0.06829205070971511, 0.03835198032902554, 0.06402680184692144, 0.029946940812806133, 0.08089056413155049, 0.01867689956270624, 0.051003149128519, 0.06783671342418529, 0.04228131459967699, 0.03340053801366594, 0.022581511038879398, 0.00618132202362176, 0.04753078486828599, 0.058079757291125134, 0.045116738037904724, 0.06097584388044197, 0.01013910095934989, 0.03064002696191892, 0.017840614164015278, 0.03796666096604895, 0.06277001186390407, 0.03559011114703026, 0.03061737290408928, 0.07675994085730053, 0.0342659044690663, 0.038522748509421945, 0.03007948282174766, 0.03065364722715458, 0.021745580015704036, 0.005804006723337807, 0.035952720791101456, 0.014979925235820701, 0.030619616045441944, 0.01648348210437689, 0.06449999520555139, 0.046325340372277424, 0.018743191903922707, 0.07070915147778578, 0.020663287505158223, 0.005839146488142433, 0.04225412601954304, 0.03242671780753881, 0.025233759442926385, 0.03487656584184151, 0.026006570806202944, 0.04006960691185668, 0.03585807098716032, 0.017914353957166895, 0.014180226789903827, 0.015258358635037439, 0.015366042407549685, 0.02238498105725739, 0.010378097558714217, 0.013879616162739694, 0.02407345422398066, 0.011694017230183817, 0.03967006799939554, 0.011725558506441303, 0.026764672802528366, 0.10241717347525991, 0.01449459034120082, 0.041931310333893634, 0.04371280243503861, 0.010301376187271671, 0.05341600852261763, 0.08289178760605864, 0.04022862689453177, 0.04614495024725329, 0.07103769283276051, 0.045507924078265205, 0.022826581189292483, 0.028304569859756157, 0.020319706527516246, 0.0055529646033392055, 0.032047510030679405, 0.024258358462247998, 0.04370998598460574, 0.06893262805533595, 0.08906528368243016, 0.037908855083514936, 0.044369610550347716, 0.05348820093786344, 0.042925984889734536, 0.026551346163614653, 0.14150378352496773, 0.05239233825705014, 0.09054924506926909, 0.04252643484505825, 0.021404232902568765, 0.04349012844613753, 0.00284625601125299, 0.03548505272192415, 0.021953529794700444, 0.011716831777448533, 0.023916929712868296, 0.03523825522279367, 0.019714958216354717, 0.02568557709309971, 0.0723905093036592, 0.038447079132311046, 0.006304468906819238, 0.01785539774573408, 0.11200290129636414, 0.016595941597188357, 0.043560020203585736, 0.03180708758009132, 0.02126324896380538, 0.04627644768333994, 0.08979459962574765, 0.04831343154364731, 0.04650891431083437, 0.05190298463276122, 0.04483341574086808, 0.044448504559113644, 0.01303763014220749, 0.007622339498993824, 0.028432851941033732, 0.013952050703665009, 0.04015407816041261, 0.04387987472000532, 0.009595492629159708, 0.043254418633296154, 0.05567904685449321, 0.007423986153298756, 0.0631918634462636, 0.008982843228295678, 0.021599939100269694, 0.02076804721582448, 0.0062350321786652785, 0.038339434322551824, 0.08506315585691482, 0.0711313370265998, 0.023998948163352907, 0.043493828052305616, 0.013491326353687327, 0.014432298175961478, 0.022122670816315804, 0.07417866960167885, 0.019279684893263038, 0.00729862349544419, 0.09014511597342789, 0.058740246458910406, 0.08647089867736213, 0.03209882212104276, 0.030955122456362005, 0.06429892513551749, 0.04605140624335036, 0.08335398233612068, 0.02805270349199418, 0.015695829642936587, 0.03747663940885104, 0.09566269451170228, 0.035950242017861456, 0.029508878869819455, 0.02460807143506827, 0.0763147413090337, 0.020504488311416935, 0.01638926645682659, 0.04618325619958341, 0.022183207802299876, 0.06847492331871763, 0.015462199698959012, 0.022904213547008112, 0.04191740990791004, 0.019394231676415075, 0.015257135019055568, 0.033674290316412225, 0.05872905116120819, 0.05107205011881888, 0.06770235500880517, 0.006897032544657122, 0.005839196583110606, 0.030267366782936733, 0.06318986706901342, 0.02236158114101272, 0.043319671967765316, 0.01418320280208718, 0.034589562492328696, 0.030674139779875986, 0.018937695822387468, 0.037221307211439125, 0.0806507836387027, 0.048807995044626296, 0.09514493518508971, 0.042967456101905555, 0.023675935808569193, 0.029422719235299155, 0.07098839938407764, 0.011683791362884222, 0.03417738480493426, 0.11829828028567135, 0.10532245898502879, 0.1609495814773254, 0.1897525999811478, 0.10299571469658986, 0.10907695439527743, 0.20506491739070043, 0.12966496957233176, 0.17375722469296306, 0.1791599261923693, 0.13048134685959667, 0.08567546479753219, 0.30361766112037003, 0.16406879847636446, 0.09230229436070658, 0.1165463516372256, 0.09489189251326025, 0.08363508561160415, 0.07790898584062234, 0.09268087131204084, 0.1536511379526928, 0.09349757514428347, 0.09190059950924478, 0.24779641506029293, 0.11279494356131181, 0.11525747118867002, 0.19049453985644504, 0.11454766630777158, 0.1491875946521759, 0.09081548312678933, 0.09117109802900814, 0.1545392512343824, 0.2367799452622421, 0.10435275398776866, 0.10415725002530962, 0.19811719801509753, 0.06976381118874997, 0.14115659199887887, 0.11421326198615134, 0.11855645119794644, 0.16958086285740137, 0.12649812153540552, 0.09530861585517414, 0.18777955585392192, 0.1227998586546164, 0.18650019716005772, 0.09341263634269126, 0.11554650060134009, 0.16177354351384565, 0.0895661220420152, 0.18513909832108766, 0.1638208469375968, 0.1316131665953435, 0.16547374340007082, 0.16145048663020134, 0.16388140618801117, 0.11907113061170094, 0.15526937611866742, 0.15661627025110647, 0.11882900493219495, 0.22595244110561907, 0.15128595783608034, 0.19141483266139403, 0.14094950311118737, 0.16699590312782675, 0.10586715827230364, 0.159110821550712, 0.10233193039312027, 0.18400396860670298, 0.12355306433164515, 0.17598190141143277, 0.16937485750531778, 0.17638429388171062, 0.1926522154826671, 0.1308567845262587, 0.08685817359946668, 0.1951009762706235, 0.1332552870735526, 0.18482419021893293, 0.10112985895830207, 0.09962133248336613, 0.12802685669157654, 0.11660357864457183, 0.1283825680729933, 0.1748243291513063, 0.120288460602751, 0.09574574825819582, 0.16513731301529333, 0.2606107376050204, 0.06656674289843068, 0.13378139556152746, 0.15914263000013307, 0.06573987164301798, 0.1485045367735438, 0.20447575603611767, 0.14593839790904894, 0.25518071022816, 0.14641095302067697, 0.12780345539795235, 0.090581313270377, 0.17113074922235683, 0.14314406347693875, 0.19711528380867094, 0.08949283495894633, 0.10488192754564807, 0.0912519772828091, 0.08497468443238176, 0.0854171157698147, 0.14308678451925516, 0.1049638977565337, 0.11419329821364954, 0.10839957394637167, 0.14015650347573683, 0.1378149978700094, 0.11449815021478571, 0.180455285590142, 0.3637658804655075, 0.17638180026551709, 0.09167929107206874, 0.1362074466305785, 0.21207245386904106, 0.1532842795131728, 0.20805133448448032, 0.14309724880149588, 0.1607746721128933, 0.2418993689934723, 0.16643188573652878, 0.19451844971626997, 0.1731981203192845, 0.08248167679994367, 0.10625448514474556, 0.17089425644371659, 0.15050560439703986, 0.23367462126770988, 0.10261282586725429, 0.11954977133427747, 0.2432394798961468, 0.14499307988444343, 0.19394724833546206, 0.13103745295666158, 0.14073013910092413, 0.15172202896792442, 0.09667329184594564, 0.22202520340215415, 0.14911045582266524, 0.19706305145518854, 0.130866150429938, 0.1753165214904584, 0.1370248183957301, 0.16828211926622316, 0.09664215875091031, 0.16343322320608422, 0.09841591396252625, 0.1174649375025183, 0.25447089050430804, 0.1592819459619932, 0.08248486803495325, 0.10954265948385, 0.1150874377344735, 0.14702625281643122, 0.143985376926139, 0.10234328525257297, 0.18092248239554465, 0.09155488485703245, 0.23456081980839372, 0.10398156140581705, 0.14899349334882572, 0.09752350364578888, 0.22732541430741549, 0.19765053555602208, 0.06371323703206144, 0.13633046502945945, 0.14505712722893804, 0.09374463610583916, 0.1040899520739913, 0.14785238192416728], [0.007010305616859114, 0.008707550969120348, 0.02077689361613011, 0.0275694262018078, 0.044456055911723524, 0.02762370688287774, 0.043456115818116814, 0.02397555195784662, 0.04144457649090327, 0.03296298629720695, 0.009086945210583508, 0.03949646852561273, 0.06716805321048014, 0.02372465780354105, 0.06093705553212203, 0.1251132888137363, 0.017398464842699468, 0.02279034953971859, 0.04729459265945479, 0.012880043432232924, 0.014075596027396386, 0.058245011314284056, 0.06646196648944169, 0.046246249694377184, 0.07436457017320208, 0.06166083876451012, 0.024767636896285694, 0.05465830065077171, 0.03415900551772211, 0.024775351521384437, 0.023299329259316437, 0.0773524418764282, 0.043480020394781604, 0.051024214990320615, 0.006440365887101507, 0.062471905985148624, 0.04430709574080538, 0.04817877255845815, 0.09628246945794672, 0.02631628387462115, 0.04746641840029042, 0.052341263653943315, 0.03493730691843666, 0.02279667078255443, 0.09245126566383988, 0.022410392193705775, 0.006909726516823866, 0.008341973662027158, 0.10816444671945646, 0.04366808061604388, 0.009557323974149767, 0.031099531406653114, 0.028365847138047684, 0.03754254583327565, 0.06745910868630745, 0.06112225848482922, 0.0953101521008648, 0.03895160225511063, 0.020297421688155737, 0.017974590373341925, 0.02382330592809012, 0.027415276563260704, 0.027939475876337383, 0.005731893161282642, 0.010703148036554921, 0.050533592293504626, 0.07730365308816545, 0.06975149153731763, 0.029304829076863825, 0.017341343591397163, 0.05571096662606578, 0.07630985797732137, 0.04857632993662264, 0.021046660585852806, 0.035948854201706126, 0.008168689601006918, 0.03340045266668312, 0.06195370136993006, 0.04270314020686783, 0.011597066768445075, 0.04406767890031915, 0.038711031374987215, 0.017213894570886623, 0.06977526252740063, 0.046473012916976586, 0.04573259444441646, 0.026853047747863457, 0.03311284817755222, 0.0487773628992727, 0.0488215615041554, 0.0043153317710675765, 0.009121984785451787, 0.01881423027953133, 0.052706329806824215, 0.007783501041558338, 0.01538739863462979, 0.05765324873209465, 0.021340771854738705, 0.050064977986039594, 0.022401517962862272, 0.05834349802171346, 0.017797161417547613, 0.015078538108355133, 0.009599143068044214, 0.09411476741661318, 0.02612516786030028, 0.0056895420402724994, 0.019832109937851783, 0.011767406358558219, 0.04872270372288767, 0.053909299240331165, 0.03523339415551163, 0.01933578198077157, 0.06456383474869654, 0.05421244801254943, 0.029111785333952866, 0.03646591219876427, 0.05708286371373106, 0.038238461420405656, 0.10100015380885452, 0.016057802895375062, 0.03054583357879892, 0.02133101075742161, 0.056131326491595246, 0.03605249512474984, 0.06787462974898517, 0.047670115673099644, 0.04882995519437827, 0.034901553954114206, 0.01420620474164025, 0.015380786098830868, 0.0298416003715829, 0.03151639204588719, 0.010439317320560804, 0.018719793843047228, 0.0720906890637707, 0.05917307440540753, 0.051017732330365106, 0.03985995390394237, 0.03774239135964308, 0.028932315472047776, 0.09685905140941031, 0.02700535686017247, 0.04578562089591287, 0.03437119295995217, 0.021823691058671102, 0.026719900888565462, 0.01722873010294279, 0.057416919225943275, 0.006368521817421424, 0.026305663741368335, 0.04145428007177543, 0.06540225382195786, 0.08763492020079866, 0.08930715703172609, 0.029372468416113406, 0.048048815078800544, 0.034811123259714805, 0.010006592347053811, 0.03163742148899473, 0.05788760412542615, 0.03295822170912288, 0.014026032622496132, 0.03811076378042344, 0.0369209155178396, 0.019438331946730614, 0.08235413872171193, 0.01901566585729597, 0.06734576789312996, 0.06043074383342173, 0.01648607405513758, 0.012352250269032083, 0.047102584212552756, 0.05625610378046986, 0.035182846477255225, 0.06974251155043021, 0.015163500102062244, 0.0482927404664224, 0.023401005346386228, 0.042785151235875674, 0.03422205838433001, 0.026832950388779864, 0.0358128816151293, 0.035332593324710615, 0.051368864660616964, 0.03077868983382359, 0.015472035938728368, 0.02116513147484511, 0.04082535073393956, 0.012913517075503478, 0.028767903786501847, 0.04795061038748827, 0.03807242443144787, 0.02488518010068219, 0.007866027863201452, 0.029635884457093198, 0.03135579128866084, 0.053762376264785416, 0.10486807164852507, 0.016892667081265245, 0.06418389224563725, 0.07683130577788688, 0.026687051577027887, 0.045897239906480536, 0.01282959687159746, 0.03375493208295666, 0.033469654226792045, 0.07299440971110016, 0.10747605279902928, 0.023097871417121496, 0.02862152072339086, 0.030871693925291765, 0.0015681284708080057, 0.0361408329627011, 0.05380277878430206, 0.023642591113457456, 0.042194553825538605, 0.011573441424843622, 0.05965598989860155, 0.050825111611629836, 0.0544409441499738, 0.03970332363678608, 0.04150074593781028, 0.016969093449006323, 0.011039872497349279, 0.06635086698224768, 0.02539211891416926, 0.03651041137345601, 0.06944320339243859, 0.024938570204540156, 0.02773024589259876, 0.025982538209063932, 0.1080826175166294, 0.02846709463483421, 0.05144186601683032, 0.008433841339865467, 0.07761092449072748, 0.04425503037055023, 0.05213809330598451, 0.06551243306603283, 0.047580846439814195, 0.02540939240134321, 0.10836268178536557, 0.030267726724559907, 0.07280918449396268, 0.059289153723511845, 0.055670185611234047, 0.015544084562861826, 0.06783103599445894, 0.03334819062729366, 0.021287042218318675, 0.03926659941498656, 0.022637585861957632, 0.10213224071776494, 0.027074857134721242, 0.056165776986745186, 0.021675068564945832, 0.028331821522442624, 0.023653146308788564, 0.07723931630607694, 0.033885420198203065, 0.021499192553164903, 0.06534955391543917, 0.05312553563271649, 0.010442943639645819, 0.006942336949578021, 0.007242419260364841, 0.01726640337437857, 0.013623629947687732, 0.06347417642246, 0.013731043763982598, 0.054139788044267334, 0.045107041878509335, 0.05691009544534609, 0.022867128427606076, 0.035059494111919776, 0.04843968941713683, 0.10486314378795214, 0.047994100241339765, 0.08718373894225806, 0.029308740195119753, 0.03392488390090875, 0.029048630422039423, 0.05818450772494543, 0.02982903581141727, 0.019385398263693787, 0.017053590672730934, 0.011803959914686857, 0.006390760272552143, 0.043534438373171724, 0.0699584987887647, 0.04897257742413785, 0.023449452746717725, 0.04175291658611968, 0.04269591539923567, 0.05689365316356998, 0.01913134070491651, 0.037983066140441224, 0.018422869834466837, 0.01922475297760684, 0.03286016915808432, 0.05233905205386691, 0.06600478867767379, 0.03373706487764139, 0.025448403393966146, 0.029304586023499724, 0.047424134536413476, 0.054921874398132786, 0.02761585496045882, 0.018589576611702796, 0.022148961397761013, 0.07727200791123323, 0.08308333592140116, 0.06146744250145275, 0.007400274071187596, 0.03593725443352014, 0.04825841613637749, 0.07503985776565969, 0.02614941568026552, 0.018947122953250073, 0.045156925334595144, 0.01566470025863964, 0.048312908329535276, 0.025027416413649917, 0.017115033078880515, 0.047231328280759044, 0.03820182530034799, 0.026984960786649026, 0.04854937884374522, 0.06973959491006099, 0.04821916394575965, 0.05630551226204261, 0.035014475433854386, 0.05190519994357601, 0.052939913366572, 0.01525331666925922, 0.041521477833157405, 0.03072081530262949, 0.032720871749916114, 0.012699550334218657, 0.04087680012162309, 0.035318592708790675, 0.009991800416173646, 0.024948745049186982, 0.06241666793357581, 0.10986646593664773, 0.022737024373782333, 0.04390186084492598, 0.08093729717074893, 0.02800370133627439, 0.02376255000854144, 0.0852710907929577, 0.16317274421453476, 0.199091341055464, 0.0982750098046381, 0.1490065996767953, 0.1347206873469986, 0.14735950680915266, 0.21186040743486956, 0.12493352580349892, 0.11790574353653938, 0.1689059240743518, 0.17553183337440714, 0.16824458143673837, 0.18518542317906395, 0.11122721596620977, 0.20042794902110472, 0.20030501967994496, 0.17833767109550536, 0.12696365593001246, 0.14506545412587002, 0.09935649708495475, 0.07848073641071096, 0.14588901540264487, 0.1585793844424188, 0.07920562173239887, 0.17509335768409073, 0.2694978076033294, 0.09113990556215867, 0.16828471678309143, 0.20343988115200773, 0.16251941677182913, 0.2025839770794846, 0.16168610367458314, 0.20796183147467673, 0.19693547626957297, 0.118114353826968, 0.17355752759613097, 0.12938945466885343, 0.1523730854387395, 0.29066638264339417, 0.11713187646819279, 0.14563229167833924, 0.1580617661238648, 0.12897839391371235, 0.09912052380968817, 0.20666026772232726, 0.14445704146055505, 0.1690345085808076, 0.09172304067760706, 0.2163684944389388, 0.17789640492992476, 0.12302707458729856, 0.16341420938260853, 0.09018040509545244, 0.14516249735606834, 0.10759218406747095, 0.13123961398378015, 0.27408125228248537, 0.11706672332365997, 0.10673053577193059, 0.07157243991969153, 0.1699409232242033, 0.09661851392593235, 0.1629791475716047, 0.06643983564572409, 0.1549868256552145, 0.10667386537534185, 0.21267304429784417, 0.17909938178490847, 0.26465291914064437, 0.1257496210746467, 0.17797626001993194, 0.1555103959981352, 0.1809204340679571, 0.1565633699647151, 0.11580845646676607, 0.18127874296624213, 0.16166664456250146, 0.2907333243638277, 0.2073089047917165, 0.10833928929059766, 0.11242260807193816, 0.14370759105077013, 0.163701732235495, 0.18425971269607544, 0.12807981634978205, 0.16805095510790125, 0.15429857274284586, 0.17167974554467946, 0.1061897847102955, 0.11568909685593098, 0.18695250648306683, 0.092059901508037, 0.07766578404698521, 0.1606166985584423, 0.10946543901809491, 0.16099443688290194, 0.12978705286514014, 0.11656933595077135, 0.13850857940269634, 0.20596524642314762, 0.13843639811966568, 0.227291171613615, 0.1547586004016921, 0.11081330536399037, 0.22261858015554026, 0.14818983647273853, 0.1628104574047029, 0.14713807962834835, 0.1172294985735789, 0.13308028865139931, 0.20477368379943073, 0.14022820978425443, 0.07172247249400243, 0.17689417902147397, 0.12143662985181436, 0.15961891069309786, 0.08268954494269565, 0.1402171517838724, 0.08546312150429003, 0.16845463891513646, 0.11226301663555205, 0.11984244469203986, 0.09045203114510514, 0.13471571495756507, 0.14436532685067505, 0.19118779484415427, 0.1485342820524238, 0.11608794186031446, 0.17068197252228856, 0.13859642000170425, 0.11648584433714859, 0.14385560498340055, 0.08744504913920537, 0.1648691008449532, 0.12850105937104672, 0.21277339750668034, 0.1509487407747656, 0.167464955302421, 0.08202348224585876, 0.10683923072065227, 0.14436212077271193, 0.19675906776683405, 0.07344437384745106, 0.15615867683663964, 0.1138046057894826, 0.08913752433727495, 0.11898072218173184, 0.09517461367067881, 0.12871349172201008, 0.13522332912543789, 0.1512245525373146, 0.12713825359242037, 0.22850345500046387, 0.203560791851487, 0.2786233148071915, 0.18113556783646345, 0.12012633844278753, 0.19860055879689753, 0.10462544873007573, 0.13607060944195837, 0.1820075765135698, 0.08206491635064594, 0.1438800513278693, 0.1237135982955806, 0.17031383758876473, 0.1221405272372067, 0.17159000504761934, 0.08497164904838428, 0.1543209856026806, 0.14757587254280224, 0.13540718879085034, 0.12520837277406827, 0.16350435063941404, 0.1863212653552182, 0.09199852589517832, 0.18977217783685774], [0.028549727212521248, 0.03592797016608529, 0.028743776565534063, 0.029126819390512537, 0.022890114596521016, 0.06192180386278778, 0.014115195172053063, 0.031361168148578145, 0.036744224998983555, 0.025766855251276866, 0.026119184294657316, 0.07547212910139933, 0.02547387204685947, 0.014447292342083529, 0.03676872329378966, 0.012574522570503177, 0.028031372312398162, 0.04103843246411998, 0.048743008883320726, 0.061455282411770895, 0.03602137316192966, 0.044687327681458555, 0.05931492109084502, 0.08392244519200176, 0.04649658723792527, 0.040842501766746864, 0.03254987721447833, 0.07843734303605743, 0.01809356592275435, 0.01668463937676279, 0.02451640506478725, 0.02573501526057953, 0.048755985335446894, 0.056819330784492195, 0.061792829728801735, 0.027174481183465105, 0.04866451563430019, 0.057215923370677046, 0.013033694904152071, 0.06340818465105258, 0.013367633528105216, 0.045698032627115026, 0.012045661642332561, 0.03918008726031985, 0.026912480789178517, 0.03676025167806074, 0.09743319169501774, 0.051421423559077084, 0.03119110500847455, 0.09835876116994768, 0.03317846516438294, 0.01941329930559732, 0.09064140496775508, 0.013955324502603617, 0.02136967479600571, 0.12157492164988071, 0.02464791548845824, 0.04885343303612899, 0.03440087886701804, 0.02765051140158903, 0.07747552706860006, 0.03025196165253874, 0.03833165661490057, 0.017540454391564708, 0.003964274119425681, 0.07299865479581058, 0.07259396166773513, 0.03351164123159833, 0.02120427234331146, 0.03602867218432948, 0.06615747814066708, 0.009032357465912355, 0.046773630965617485, 0.0371956400340423, 0.062310295907082036, 0.019595262783695944, 0.01609275619557593, 0.04003870017186273, 0.005708840662919101, 0.06891633049235679, 0.04216313500364777, 0.05601349941571243, 0.02677589964150684, 0.026910920423688367, 0.05650582163070794, 0.04248672994435765, 0.026362239514128305, 0.05850678535352927, 0.08463374178973027, 0.027854316285811365, 0.029640910652233288, 0.03092072391154943, 0.04039279738208279, 0.024727701929805335, 0.03142346773529425, 0.024837985074555036, 0.02158748400688637, 0.07167049989220686, 0.04742781187815126, 0.08637997816549614, 0.06522402705741115, 0.054254086207947694, 0.048926734962151386, 0.06477455273852684, 0.07601722914841957, 0.027007267890439834, 0.08416673052124679, 0.04568154581647832, 0.04425596176588442, 0.013422345582512207, 0.03840528879663907, 0.02540201174269896, 0.03471811731287744, 0.03293957153800875, 0.027500703326950315, 0.0676428570295684, 0.01349010181002086, 0.05206371526583098, 0.027411230003053788, 0.051778411434497684, 0.019345301880093757, 0.08333398145623505, 0.09914233552990481, 0.04955140066158492, 0.025292114514741115, 0.06442308644182049, 0.031201313249766827, 0.02366196487855632, 0.043331720735295676, 0.005798892398161115, 0.052304724013083614, 0.04841469017264899, 0.04477258931729011, 0.09093306900467724, 0.05204024113481864, 0.026507531620154623, 0.04121432517422363, 0.01973580328922253, 0.024325064550794195, 0.027887735195690766, 0.05901088545215316, 0.08787012164248154, 0.03841311474388931, 0.033759451762307435, 0.04425914929015562, 0.01574087429617066, 0.02951617047074251, 0.08490895983413793, 0.04970364483597223, 0.048222570403595455, 0.0036792534638152574, 0.12042484508128837, 0.017072858681785874, 0.014731790943187661, 0.0366247021156596, 0.03440713517193217, 0.021066102999611758, 0.02860621392756002, 0.04564228991512209, 0.02532063896069303, 0.04150708387896884, 0.05249877707683481, 0.023092750598152634, 0.07033856003545225, 0.03783105574257206, 0.03683326787722763, 0.019734304150915705, 0.01882630131149199, 0.04174721318122465, 0.0639464495179709, 0.028501059023255948, 0.0567485744250007, 0.02122686888469616, 0.04666071690735407, 0.08629705058410764, 0.055153958819573745, 0.03563795369700529, 0.04455935544683598, 0.05136880528880283, 0.08393503943807445, 0.02166119040339254, 0.0219973610364832, 0.005929786839260487, 0.04245465432177298, 0.05185082649404649, 0.01920010254252702, 0.02515146268706303, 0.02469901977747213, 0.007348457320404123, 0.009898330627038376, 0.023612595359736588, 0.007483016579499235, 0.03464522727881558, 0.048422215550090186, 0.013299542406457476, 0.062360376032302156, 0.06810646184021607, 0.05058913833636325, 0.01798496003175387, 0.044182670972077176, 0.03543558115779888, 0.036974899339838885, 0.012223330868437188, 0.032992928245221265, 0.02110154426191002, 0.03364162468642462, 0.0005308473907916778, 0.05841390186105855, 0.008556437642255332, 0.04945594191667624, 0.027052733712480403, 0.05239148849796038, 0.049556866579223424, 0.06684562715236098, 0.058003386584459804, 0.04351095682068262, 0.0333963411685545, 0.030085813341429457, 0.017887245157908183, 0.030413302702072542, 0.03262615886342246, 0.0408133910241304, 0.046609620039816946, 0.06635505269514397, 0.052725748100783676, 0.030443016439676285, 0.03244694133172743, 0.0844057317590341, 0.05081922638055403, 0.001652282799113891, 0.058912357926601544, 0.022847743530292064, 0.009449152239540126, 0.08674273994984105, 0.06592730846023187, 0.039742379158269614, 0.0080522132338956, 0.06510977342259139, 0.04244310279318597, 0.010236028228973737, 0.026395322602184024, 0.01414816786564188, 0.051159237627871335, 0.04598647945385892, 0.04903780107269995, 0.02935856427939143, 0.10299159577698447, 0.06501441486761905, 0.03342153337143827, 0.021344790584407747, 0.004595698464981979, 0.032010755166993476, 0.05056323738244828, 0.043573790753725916, 0.021802200317324605, 0.052936729553039186, 0.010509266594453948, 0.010468571854289621, 0.03320203577459324, 0.05441457193228416, 0.0344420309556881, 0.004431219522302854, 0.04262104012013879, 0.012696424964815378, 0.05355694978788961, 0.05790771632746328, 0.0543140851368662, 0.018250134962727316, 0.05817560195282567, 0.04369788155599963, 0.04627917136531323, 0.018784913590934593, 0.04011623976111878, 0.007609447930008173, 0.03274605653132312, 0.03341428629937582, 0.03179870131134521, 0.02332982225198066, 0.015540089952992275, 0.05031959772168193, 0.0066557102400111035, 0.031021127215353772, 0.02789343117910903, 0.014495177565549966, 0.04951976290612947, 0.01237145055711153, 0.03884468103933614, 0.03529179375618696, 0.08097271987935528, 0.03714144098921679, 0.06742953410139307, 0.04078458085132297, 0.0017626082694732759, 0.028597868476936128, 0.027443069993751124, 0.07109674552339129, 0.08275365908048116, 0.04613993332895916, 0.08094067394267768, 0.011561770224943757, 0.051379217620706186, 0.021409042019513436, 0.07474296158761717, 0.02040839503024472, 0.05457706516608596, 0.04687379863753449, 0.04189879313344136, 0.029055231825623196, 0.04100829755770974, 0.015016920369816944, 0.049056744392146356, 0.04351493473222945, 0.01277690067581716, 0.05052965148934163, 0.02071703569527017, 0.023830046484363265, 0.010453317008796148, 0.07160147273680195, 0.030667714636365417, 0.031012113831820898, 0.014424774653889472, 0.04394495364977047, 0.06436408570152707, 0.030139034606690984, 0.01971154062630376, 0.03805944426858332, 0.0110962822145666, 0.08790178908384405, 0.04765791105455719, 0.004943704498145962, 0.047659454721724615, 0.05074439563031774, 0.04152635745413136, 0.0332235135283554, 0.02474898486980237, 0.042128591740038246, 0.05714001650630962, 0.01137021541580907, 0.0346000304853078, 0.0652219564653933, 0.0047244870620488655, 0.04141699828323908, 0.011036140422220342, 0.022100937021605205, 0.0033882132947837817, 0.08341834880411625, 0.01671895257459255, 0.03743295659660362, 0.025265985350415576, 0.03396169442567043, 0.05617201102722902, 0.028423662297427654, 0.13141548814019188, 0.09314892900874838, 0.13657644245540723, 0.1899247188703157, 0.08631175252958201, 0.13367336854571477, 0.13630720612127334, 0.11758694658055902, 0.19780295784585178, 0.172277367382776, 0.07532401868957095, 0.24025796097703278, 0.09142302005784586, 0.0891543785110116, 0.23824294097721577, 0.142016785684973, 0.11839168699225411, 0.1782924891449511, 0.19836485269479454, 0.13412220461759716, 0.22445615264587104, 0.16009315790142864, 0.10440441488754004, 0.1352777730789967, 0.11544634035089985, 0.10432894589030184, 0.16728434624383226, 0.12530241772765294, 0.11789103416958824, 0.10079958097776398, 0.13085675484035164, 0.20188543800031766, 0.14926793955964968, 0.22653713473118842, 0.13872555369744077, 0.13713231106521562, 0.1420489206793718, 0.16345523530617356, 0.1382018200820312, 0.17393495421856642, 0.12339457869529724, 0.12900577916298062, 0.20463870198000222, 0.13800135115161538, 0.09068525847396813, 0.09686387536930852, 0.26414579479023814, 0.1071343976946082, 0.23213582258904353, 0.20145718910498545, 0.13307688961504027, 0.22521471662912518, 0.216958754172083, 0.08600891174864955, 0.11100120231276378, 0.30273590062279254, 0.07460306675056927, 0.17340293823508546, 0.09873851071461104, 0.14098693703999743, 0.09003123341244645, 0.19022931111976504, 0.07291370115126483, 0.2363807737128809, 0.07755964950774796, 0.10676180245354772, 0.13958316470962018, 0.16266631748294458, 0.07118984052794985, 0.1632880888064392, 0.16761204897193238, 0.12746614927891642, 0.10633259618771262, 0.07317352705285884, 0.21781370829558, 0.13164369855076075, 0.11512913159094751, 0.15549013536656275, 0.06994188210228458, 0.18048981030005962, 0.1285497294156812, 0.1500338953337632, 0.08634684869321063, 0.09521106054307893, 0.12374367754091509, 0.21069054520921782, 0.13424164586467668, 0.08823642347124405, 0.32167197670787573, 0.14378244406543672, 0.06354911107337102, 0.12703053827863187, 0.17407887149602175, 0.1569550161366351, 0.16196417156606913, 0.1812578144017607, 0.11820049490779638, 0.18100739893270656, 0.09670990199083462, 0.21499378461157903, 0.143851523171179, 0.09269115747883916, 0.10501235257834196, 0.13097009563352913, 0.2068452406092547, 0.11410958395572379, 0.1462562894448638, 0.1377592032076791, 0.11522276836331002, 0.13171138241887093, 0.21791085542645305, 0.19541156507330015, 0.19054816744755954, 0.12244066660059616, 0.14504807302728295, 0.14872323285089806, 0.15589972666930407, 0.09765478214831091, 0.11592196795390919, 0.13822197681292892, 0.15286947833374143, 0.2566600183490664, 0.22083815303631127, 0.11159883157233708, 0.2029179732198827, 0.15964677091687918, 0.16512491914909333, 0.07766815149807371, 0.21415281255031005, 0.1104602286068257, 0.14235296373954043, 0.1460003523970954, 0.15898505720542744, 0.16373707330785692, 0.13810499949613586, 0.16390414559282362, 0.1028305348881986, 0.16469165333546698, 0.09301681187935174, 0.12255739158717915, 0.12894446292193606, 0.20937116991262883, 0.09930393818649463, 0.15177409804891795, 0.1404735934920609, 0.1186746233724989, 0.1842156142811291, 0.23518937436165288, 0.0930641831655521, 0.1434167433762923, 0.11407327066990547, 0.2060321139288135, 0.16171437950106338, 0.1217684663424734, 0.18590964056784287, 0.18525208288338035, 0.1357102522160858, 0.06467716812039725, 0.11804802808910608, 0.1736082014394924, 0.22705003299051896, 0.12398643404594623, 0.16568099556025118, 0.1491135431570001, 0.09930232030455954, 0.14741421793587506, 0.1152053130499553, 0.16538032185053453, 0.15190164354862645, 0.19131171866320074, 0.1408011477906257, 0.1752905611647293, 0.12376272847177461, 0.1481853539007716, 0.1442754379240796, 0.1414141766144894], [0.01576555998326512, 0.04108229710254818, 0.03055245353607461, 0.013227003964857431, 0.024401839727943297, 0.015984565907274373, 0.03350625695020426, 0.02420009801426204, 0.03468683578830678, 0.0339745818200754, 0.0841317159938626, 0.018733783326752018, 0.011714525553543353, 0.0353821057069581, 0.04024721769383177, 0.029321065412659664, 0.03419848777411971, 0.0970068501192145, 0.013720226033910876, 0.05387361678003799, 0.048265752266161144, 0.03085101026954362, 0.05992328551656101, 0.04528846729954239, 0.04421364821610041, 0.06190399974002503, 0.09426834003534168, 0.024909893618314527, 0.04571493132971227, 0.05187707625736948, 0.03692582482472062, 0.04537415567028802, 0.013974078574392479, 0.03384768198884558, 0.01889038390800124, 0.07352282627834938, 0.0020808976660191547, 0.10550104940193705, 0.002737850732046354, 0.04397777513077017, 0.020584764570230618, 0.03621270625444595, 0.09022618076414801, 0.05548063367314171, 0.04845057301281486, 0.011096203361375956, 0.06520170325529762, 0.09364484692923725, 0.036603098196792416, 0.030225595000956673, 0.010063721019832883, 0.02191190273151733, 0.02894931436458137, 0.069689351512352, 0.01893105174531229, 0.07731572040938772, 0.026658029892132618, 0.03357808571308851, 0.07110755861504003, 0.06963606530916877, 0.07679909656872042, 0.06145798754005227, 0.034036796059808694, 0.059199802853981964, 0.01146085020081955, 0.06955105229280889, 0.08370811294298619, 0.02937696026492631, 0.023403905288432725, 0.11113113752799109, 0.017167732985399198, 0.033718507474986836, 0.02528109176637372, 0.0654909924196545, 0.051581512234406546, 0.04436323179106694, 0.0748212359030731, 0.03299525116744917, 0.007818468257028144, 0.01271775985514978, 0.0876706323469989, 0.03675128653412685, 0.035095299026579596, 0.038133926209411584, 0.07203650486189872, 0.11698824120685458, 0.052302898329799064, 0.042294023878639564, 0.06824824915383942, 0.020820574573008344, 0.022653289706795476, 0.035757769728661515, 0.05500556268088985, 0.02522299088013824, 0.04727731917228084, 0.01925890290294774, 0.020986607851227745, 0.027937043487327173, 0.025469495230936445, 0.05169892741832882, 0.02634719989146106, 0.03079143622017, 0.016914170810196083, 0.021789036472910084, 0.03748183444258757, 0.017514217615826055, 0.08978866986581124, 0.0738393967912998, 0.020551559027808253, 0.047596969598089345, 0.061902136949356645, 0.016240224649664015, 0.0009617172270282026, 0.065787317143986, 0.03663383424282074, 0.05475587822729722, 0.04691827554779593, 0.014396809601748828, 0.032215676983469166, 0.023564865987282246, 0.03116016487183515, 0.02413566104223719, 0.050719511418719776, 0.018091743950208183, 0.04902518085145857, 0.019623514490376692, 0.08025746763451025, 0.040318794126505964, 0.04976201104000211, 0.061987112858332694, 0.04096187622053549, 0.050859892362495884, 0.022664980388071854, 0.07295596646144986, 0.10747668362455443, 0.021317305145203136, 0.052371112833498046, 0.05060726900410373, 0.06695046293316409, 0.07954337314004079, 0.037157571568968706, 0.038716872077202424, 0.058559845201671124, 0.05499906517798081, 0.04465196434466634, 0.004107987770112231, 0.046858128189342096, 0.06069829178159125, 0.04149244872678537, 0.02840618100890424, 0.014868228299746988, 0.07003223116043955, 0.04824702788027935, 0.09012768292450346, 0.07249287373269908, 0.02989466393046314, 0.05610676140349824, 0.03192736745404545, 0.0723149735131301, 0.026399929483886808, 0.03258609402109869, 0.061888410928077064, 0.015527966970694251, 0.06728523090714589, 0.06063877524866257, 0.010723732430051314, 0.031151726652751677, 0.047260364808607846, 0.04257357977621723, 0.019614556767919566, 0.08357920931302942, 0.06095543481933419, 0.03576734343369026, 0.04759969328006264, 0.04887103306828067, 0.015240683460433502, 0.02875583275454119, 0.046309528916026466, 0.030789564152655657, 0.012528357274277369, 0.036074592571821995, 0.03281703553511761, 0.009311565481766593, 0.02094454106554622, 0.012289943260839209, 0.02865970051061595, 0.0763445311167743, 0.030279064885689877, 0.09346164035378024, 0.012533354711194988, 0.020026190832140855, 0.021538120054174215, 0.015338186822191346, 0.04265104143996723, 0.03514432530209888, 0.04112039154279046, 0.018739681545412168, 0.1533575591747649, 0.025302946160081774, 0.03806014559813775, 0.05962862691376358, 0.045555365868494846, 0.0143473064963473, 0.06598746695090085, 0.021989028573443647, 0.04298777610529214, 0.06849376644822769, 0.004137525711485068, 0.011341462759446586, 0.015278103473974625, 0.06222313808393665, 0.023522049632447306, 0.0076478188202599995, 0.06555527725140564, 0.04878968626144342, 0.03930962171580177, 0.03599357602070086, 0.05418582717538811, 0.0708895453135483, 0.07633169196196832, 0.054492233975906856, 0.006025731227055076, 0.03817822871496901, 0.04676243566791527, 0.033817346702562645, 0.05768828923464753, 0.06742621670127846, 0.05023099271056708, 0.05144978844327852, 0.10174786017159931, 0.007948620550450869, 0.009442493319511414, 0.05258773089735769, 0.058826647291425616, 0.015228983502311166, 0.06260237554670312, 0.026683522664825432, 0.0291253889008658, 0.04096647382539231, 0.01636544166103704, 0.04814791405806318, 0.02597595906991046, 0.057847932621371, 0.0077631661952182185, 0.020579986994562205, 0.08624512993264943, 0.03376855420356151, 0.02612789710838115, 0.07484315152396448, 0.023656762423343025, 0.0442219491378637, 0.017108203464886174, 0.05587908162851818, 0.05519066173292231, 0.0373357129865326, 0.023533653111371677, 0.0681757710117381, 0.029199733544373885, 0.028413554246071726, 0.013289001126395306, 0.08562076851376332, 0.04794172687979881, 0.1327954969019629, 0.02236634201835841, 0.05878280120668933, 0.023753718451189343, 0.031882660478004254, 0.05200887055252679, 0.0411770619393792, 0.031086781309568323, 0.014924089755368186, 0.009903577611112269, 0.04293418562156148, 0.04657875782868359, 0.03517743622069247, 0.03874338901368901, 0.017763376999937464, 0.05610233078186866, 0.053149822415434755, 0.06484794372227043, 0.04229684403981082, 0.05703786730009597, 0.029131053343007807, 0.07792362841428258, 0.03436792751017492, 0.03605235040595289, 0.07531817798735574, 0.014261178403103258, 0.04249637415341567, 0.06491077394457534, 0.03782022038649302, 0.03155984108161647, 0.04482776057557203, 0.04463309895072598, 0.004749438530780026, 0.0520567168132402, 0.052394776212167926, 0.015233841786539415, 0.08219773109885864, 0.062266286549856886, 0.03135599537927192, 0.020201376646582503, 0.027675044948409777, 0.017220739027834497, 0.0426316602533916, 0.028415845627023373, 0.006335707294056192, 0.01808004770282423, 0.02426671504508704, 0.07016196599579416, 0.13202418282162398, 0.024405392759945244, 0.06559289671713486, 0.04025536647532135, 0.11260205938015133, 0.02471966261509806, 0.03155915459501557, 0.09639658208470792, 0.04774844193889294, 0.008070404201134806, 0.056342905372730456, 0.0216464587720111, 0.03844591024972033, 0.057343635853612795, 0.025448954438616056, 0.06670530186966062, 0.04955648437316995, 0.04319106519687921, 0.009867512944765622, 0.05999928143864963, 0.03058728438190883, 0.026770984768518247, 0.028286530105106067, 0.017379178279952612, 0.020099759931326844, 0.04152858760789968, 0.06291361743933521, 0.0719776822370477, 0.04253978608176112, 0.02793107290926855, 0.06034699617885053, 0.016655999897920992, 0.01563279718538979, 0.05134199891472235, 0.017573281438671984, 0.00897549503861228, 0.06640529609285295, 0.04601090353389736, 0.037604333338094875, 0.05860883065906819, 0.035297983267810196, 0.011902836249646498, 0.09774208097951487, 0.22963601688388735, 0.1568009314360097, 0.10860138616408221, 0.17168687016237527, 0.13871476287022233, 0.11816064157756045, 0.17309738119365647, 0.0692754186457023, 0.09509035764494911, 0.17595439741853625, 0.11776134386309423, 0.2932096633594483, 0.10897652697167359, 0.10576881628367119, 0.2007426938507706, 0.07383389747701585, 0.19166558951837942, 0.11537735772435553, 0.07501237603719346, 0.12675217352807522, 0.26966392993927, 0.1191306953842286, 0.24587416352005675, 0.15004726883489639, 0.16181437647901475, 0.14797485113376752, 0.10564240626990795, 0.10037830827059224, 0.11434124535298906, 0.19385125895496458, 0.13031716895056888, 0.09073122710105963, 0.13523046858608723, 0.10870288970181718, 0.16600592265604064, 0.08148661261657253, 0.20195935590891168, 0.07716536871157587, 0.1333065694780089, 0.12621065805433318, 0.12450159585569054, 0.18381083209533244, 0.15780035202624276, 0.21897353668464348, 0.07840642516384833, 0.09709512858535163, 0.18951668607769534, 0.1159722261945717, 0.2213339225272648, 0.23380212223855779, 0.13173058920074254, 0.1508144268882461, 0.21028470917372033, 0.07267809894983657, 0.1803003845270723, 0.20375091524329036, 0.1439929023035802, 0.10927834358881228, 0.10785160920931958, 0.20778034668182954, 0.11809404866653495, 0.20549344830214977, 0.1521169554325752, 0.16262736957287416, 0.10568299432634376, 0.24959509901236743, 0.10626003640936688, 0.19404815073357895, 0.2288208864047192, 0.09492376033449546, 0.15163401025347412, 0.11548451642738655, 0.10790790853207, 0.1433157964493148, 0.15124368510441855, 0.15394393005408347, 0.16130033531226218, 0.22494258591905236, 0.09814424338401295, 0.16294986242428422, 0.16326324170222506, 0.1043030597793404, 0.17290561023401096, 0.13029462250415236, 0.17516798805445433, 0.24814795557176694, 0.11647310908301733, 0.1672039568074979, 0.1159597210062202, 0.08707514789421111, 0.14996064535807818, 0.15759833942865953, 0.11537893849890679, 0.15828878909815103, 0.11954387868172489, 0.09499193402007222, 0.1456410638638772, 0.07128813056624494, 0.18325888202525675, 0.0731070974143222, 0.1508335891412571, 0.16403246292611584, 0.19003069755854085, 0.16620517446426675, 0.1304463917040266, 0.22002501151291654, 0.1034130911284592, 0.182885151298251, 0.09508676565019414, 0.15336358541389927, 0.13341752055566758, 0.11112874039099552, 0.15810109995072708, 0.12732358271023259, 0.15484988456591964, 0.21419933036668226, 0.18030265549896285, 0.09383854005136527, 0.10805825280840509, 0.11110089501016773, 0.11816883488791063, 0.1778323427424766, 0.28986326011363417, 0.14089526695897803, 0.11748307559173554, 0.2041050384286791, 0.16037529276218265, 0.11889562752912752, 0.12029188932501711, 0.15201330708805472, 0.13717192690819502, 0.13117593771312386, 0.16038005735026672, 0.3027326351730153, 0.07886035979026929, 0.1522416213992983, 0.11767966308980249, 0.22568508982658386, 0.19242813141318038, 0.13275458972202614, 0.21590497868601233, 0.15757346263853833, 0.10747145890491083, 0.12910856661619619, 0.15088516840478405, 0.14922550355549902, 0.17328124085906893, 0.07982191600603983, 0.21527189703192562, 0.11924534977879375, 0.08377890640986152, 0.18589709827210754, 0.14890471764374524, 0.12751450762152672, 0.19565596914617345, 0.09067481645615771, 0.09740779540152289, 0.10052661906229332, 0.1825049045146443, 0.15517316409386694, 0.17040981212630868, 0.16550265747355297, 0.08946539033786394, 0.1817126470268704, 0.10650079653714783, 0.11930461027077399, 0.15139529103180394, 0.10716676275478676, 0.09141147223999724, 0.12428540823748335, 0.22458558320067823, 0.10128884183359332, 0.16648212913423777, 0.15247397299390286, 0.09730557940201834], [0.04166956969129387, 0.02291276123287389, 0.050494414317654446, 0.030964636789576616, 0.06731943649356253, 0.04556224557745736, 0.05483291686687153, 0.028530366435006727, 0.04485457066039089, 0.04712754634965677, 0.0646914989920333, 0.016886978519323748, 0.04317033330153208, 0.003346038665767992, 0.0587412001186749, 0.038037703052395955, 0.03032441010873299, 0.03236535703763366, 0.01396425161146908, 0.025819898401095998, 0.020417222876858432, 0.03463919732894283, 0.05020704360504169, 0.042173654946964234, 0.03895169502357021, 0.027086059853900224, 0.04237790883053094, 0.029395833080343436, 0.030965573751018383, 0.04080596954736393, 0.04402920967550017, 0.07691766950301826, 0.04032246404676698, 0.03946560631447937, 0.025497333190287463, 0.0179522647158592, 0.003749543197955063, 0.04019066233013291, 0.02397059441136662, 0.03601463817176409, 0.03938239300623536, 0.02849309763405472, 0.0340844011225272, 0.04490974562941119, 0.05205553308769595, 0.05964704330835957, 0.032484449475305155, 0.03539766854373738, 0.013839471539540682, 0.017159764174721204, 0.07615932816406712, 0.013005702021473553, 0.0512554533634102, 0.020148326075286604, 0.00539783440217434, 0.03415977364056744, 0.05514603268238716, 0.014083498044783482, 0.03178047787514515, 0.047778814332559705, 0.012201308563817292, 0.03611931068007834, 0.08751125613343902, 0.06843142604338937, 0.03277652169344947, 0.013259574971016264, 0.007527330681114108, 0.037991686185705476, 0.05119569934322499, 0.019769878999795765, 0.058846098982030526, 0.052349353063618764, 0.023728221967758145, 0.03734880076081026, 0.006134705408840091, 0.018229134038847405, 0.07472925412002951, 0.06630138057516888, 0.02271540004585404, 0.0326624461740721, 0.07233718599309213, 0.013537799641198944, 0.026005218242062256, 0.04499967166339047, 0.029581555536424275, 0.0523083568259608, 0.044752829635399394, 0.006954132923056022, 0.03694015569635667, 0.006578778748007608, 0.0403478009684477, 0.035569256797316484, 0.05036286493123043, 0.014176509557728423, 0.0400012365571456, 0.02408441203442635, 0.04602284469001461, 0.007297406373254489, 0.06501806623418815, 0.04323957196902484, 0.061705349071417004, 0.009361512020404916, 0.01474522103308118, 0.03965145122492686, 0.022541511134477332, 0.0421011359867407, 0.014519770484184846, 0.023590753953612875, 0.008673106040077982, 0.041205033485312015, 0.010972279542329488, 0.034382584926788695, 0.06282788453972898, 0.02168117087421706, 0.0752615743840579, 0.05384830212278757, 0.07317486291867681, 0.018505765874579083, 0.0245510744935018, 0.024219913357228506, 0.04643026150006335, 0.006562271528309793, 0.04328110255300999, 0.09460245491936803, 0.023298269843508024, 0.03982578171417117, 0.019505705968185794, 0.05930228602665011, 0.0289240331039764, 0.027292041086184327, 0.017016281053656712, 0.04173194720351603, 0.03632718995504547, 0.02414033286186168, 0.08346282571437769, 0.003079468497162452, 0.033554667243151926, 0.0232502491780906, 0.014623948536609532, 0.05028080937336199, 0.04761087002407294, 0.0613052053085994, 0.02060479328065412, 0.0130694756990124, 0.02823370032274397, 0.01340689685093821, 0.037402187153929844, 0.02294964411703404, 0.04413892136653885, 0.022635993955191225, 0.04687080407165922, 0.02331353025510907, 0.061213832086650655, 0.03595976006181445, 0.07073255139403045, 0.03887127590132877, 0.016408148549089674, 0.0022569000748262624, 0.006640766632699524, 0.015909653520793654, 0.08917742961784825, 0.08838474910589866, 0.052524128841469064, 0.07438586239004508, 0.06463336656452157, 0.04438047188159544, 0.014799344007769832, 0.04830350531847216, 0.032076761781354435, 0.04972444352461025, 0.056070032514980994, 0.13522377441404387, 0.0445418222079752, 0.004255315679984051, 0.038311147363856435, 0.03600483440095559, 0.03256647534726653, 0.026454581238795072, 0.023958400925039314, 0.036393022164702415, 0.09906545645208098, 0.03667773969937116, 0.024043515986704733, 0.018799849312927108, 0.07416234977426939, 0.032265757108689286, 0.04747046681586653, 0.06751390144927427, 0.06587127631064504, 0.008152216705639148, 0.08372930868063122, 0.028847543653682806, 0.07440169982146472, 0.021016755745222326, 0.028640441778406966, 0.02356720931857126, 0.011860075555887306, 0.018323318145121448, 0.03826016923994757, 0.019865849826601334, 0.04571288300212473, 0.01439385214325739, 0.06658876241999678, 0.017758354515535757, 0.010346098006266402, 0.05930581122811418, 0.0646829123434145, 0.03197355501470156, 0.02679768167581642, 0.049425781035097316, 0.015185395313892514, 0.019632926778285764, 0.028515161684481427, 0.04030519055959303, 0.043377073379815556, 0.013554781835409813, 0.007719091900071362, 0.019790386395470705, 0.07134333151043393, 0.0492808210401563, 0.01878700830275193, 0.05573794369411189, 0.03130593009700533, 0.059488925035111606, 0.014804250531597063, 0.019723915938811842, 0.033339793226332404, 0.05921246760408394, 0.02533351151214447, 0.04002962370577734, 0.0305652258975897, 0.005458689583974774, 0.03131261684757192, 0.014094919697527075, 0.036310109426267445, 0.02494384130841354, 0.04717610507213976, 0.02524198058381444, 0.06836425425717607, 0.026160590568906628, 0.020769448019564152, 0.04045192799821962, 0.022252106937230565, 0.0379307744151447, 0.05187525057408493, 0.01829733926570043, 0.046370039926841855, 0.0944669684395194, 0.017704802994558122, 0.04782754745974671, 0.024035482238105033, 0.01619290531380102, 0.06452843430452049, 0.04687733126047533, 0.014715283723489847, 0.019979750941274688, 0.0847070362942759, 0.018221343343611807, 0.00346968348367227, 0.021305607042449992, 0.049359551776433364, 0.03470057294180151, 0.02636165878357133, 0.056047909092740156, 0.03634814820543397, 0.009057830757228658, 0.05545641739445273, 0.031561752111883834, 0.022444959577114787, 0.030529656614817213, 0.05678093577444088, 0.040340323830605485, 0.015956084134813864, 0.012270474871911574, 0.08466373939882033, 0.06495391498901881, 0.07550638663815334, 0.030560941850126255, 0.030882041319273412, 0.03454652163782157, 0.009998928744607838, 0.06351824515149929, 0.023387160581478383, 0.028448615157685708, 0.062293471419252455, 0.018537811811256688, 0.04638139849703293, 0.02408580170595087, 0.02980595687404275, 0.0483530288329348, 0.013423976452031638, 0.0776374340057373, 0.041463133893557824, 0.03839445344056003, 0.022816545497335028, 0.02244001687358832, 0.02824660812621005, 0.029925555827503558, 0.04152312540099956, 0.016310070022882428, 0.06812573541537859, 0.011214565711270552, 0.03339793307532091, 0.017997541290242225, 0.0295238739636261, 0.05573640373768285, 0.04759101757372264, 0.05205082044994924, 0.05324813842889853, 0.051607517088996246, 0.09088387945666909, 0.007261421487783082, 0.057963314320659265, 0.0544769976841053, 0.038908954738872126, 0.008137169661495136, 0.03261291152739432, 0.10433517993078567, 0.07927451530122198, 0.04667000859626569, 0.13001302198972553, 0.04614083874912467, 0.06887989104143344, 0.01657216504099779, 0.060166153343743645, 0.018592547057778575, 0.012713918313238537, 0.03815138894424308, 0.05995684543449897, 0.02371535312704509, 0.0565543877746677, 0.042001966503448784, 0.02461634823703207, 0.04014601472590584, 0.021934274773229845, 0.0230773324801703, 0.12623507471289486, 0.02452007869578665, 0.022873061898280866, 0.01823187070840504, 0.05939805647358298, 0.0418099246599013, 0.025188694380631205, 0.031117955222725868, 0.006580196250070003, 0.03169634801452048, 0.06871552759548649, 0.03759491919481661, 0.0242362257631612, 0.043531443807296455, 0.03533534298185259, 0.03157194179948419, 0.1792219400522299, 0.10834682208951563, 0.15867567068198696, 0.1389900254434906, 0.18241335317725316, 0.09011308487970382, 0.1549707804224454, 0.13763541297521442, 0.1448464166605845, 0.15303840598789975, 0.2131747658131644, 0.19471878506010398, 0.12375093574519269, 0.07415649422910064, 0.179431552242022, 0.16204769286559895, 0.1816359386430122, 0.10885162351769395, 0.13512113539036363, 0.08507834019837901, 0.11621172467130236, 0.12345148657914251, 0.12387397640850395, 0.14694630866870284, 0.16599574038991705, 0.10485510632861406, 0.16540062701096758, 0.10378166392911226, 0.12447126428014599, 0.2572380326455459, 0.22542526392498985, 0.1284514245344326, 0.1244064376805909, 0.1323540080920793, 0.09119244961766526, 0.11943090154090896, 0.2355631347745657, 0.10250865801936015, 0.08163536127540283, 0.15351392969023436, 0.17994639492826536, 0.07426934520481154, 0.12285280346986838, 0.19013949640793726, 0.1272152885212563, 0.10032271398813464, 0.0906505185412243, 0.20131491939537227, 0.1517419482115656, 0.07897203817265108, 0.14097307372139767, 0.13165894226403907, 0.1436786472913809, 0.15835927828447893, 0.06827935998444445, 0.16219505370827392, 0.21092163515277207, 0.1522010110784322, 0.14018121699336916, 0.20518207282293588, 0.1600070984568447, 0.12702299805823714, 0.1478563153068535, 0.17962535668630153, 0.10605053554172628, 0.0954739292501472, 0.20246257656253874, 0.13453948457026854, 0.1296410575741902, 0.10958832383039407, 0.13937194948084652, 0.1738773041870445, 0.16556042624870315, 0.08378364873351529, 0.09755874081747606, 0.07849408022593707, 0.16766463755629957, 0.2004745410522446, 0.11784427144448273, 0.13426077843178064, 0.14188395609380677, 0.14699824416311458, 0.0868266323232092, 0.08901761553715914, 0.1215058054367546, 0.1649545962573029, 0.11589630448725075, 0.1492656537448056, 0.09151236721663736, 0.12169149820692837, 0.11310481990221888, 0.0767922168597579, 0.23259604320628569, 0.10629663171130233, 0.1925418878090568, 0.10931334327324294, 0.07555504926131107, 0.09872609458398074, 0.13306255132192746, 0.2300588332582265, 0.2751481340965256, 0.11494021789985709, 0.102937077608658, 0.13794926722766832, 0.14798797230469063, 0.21688314416678622, 0.13077026495011523, 0.19417452363995835, 0.19190600083675236, 0.08174493937985972, 0.1330873093684204, 0.06563052360434085, 0.1999805824016221, 0.1357780399848707, 0.19871323165716603, 0.1403122505871579, 0.2043607083032839, 0.0814022972190287, 0.08058065810473636, 0.10330737219192088, 0.16173655487364158, 0.1831689040409401, 0.14285324548836797, 0.16629117453703657, 0.15828378702281043, 0.11321666155708954, 0.08326735885930248, 0.14913417486241087, 0.1407569900038652, 0.1381565787596628, 0.12022907394566573, 0.1299211589503102, 0.21085139829665422, 0.1266986201517284, 0.16605206939857453, 0.12003751820884645, 0.13707049016375095, 0.14898151508532465, 0.12296123866690323, 0.12847073521697894, 0.212622043909505, 0.24629883526358753, 0.17198414483573288, 0.1578584176604636, 0.1780324851279147, 0.14005380508024246, 0.18617377092596143, 0.19488015765091404, 0.12548715312732384, 0.07740103770629503, 0.077878298034193, 0.09886262007057667, 0.12572539737448096, 0.10459121345775202, 0.1428204425610602, 0.13721826660912484, 0.07983712261193432, 0.13104141602525488, 0.1507301040692255, 0.13159879861632362, 0.2242594983545132, 0.16996113932691514, 0.08953239885158837, 0.18278773699421436, 0.15199800400296226, 0.27346642746124417, 0.10901287736487575, 0.14768916880711913, 0.08186128587112762, 0.107495986885624, 0.1282256335252896, 0.20196438767015934, 0.09087972342967987, 0.11491083627333865, 0.2447667604428716, 0.14116336038568988], [0.02879186773498077, 0.02319247112609446, 0.04457000526599586, 0.013585479846369708, 0.043566295062191784, 0.01504330464740633, 0.023939854654599912, 0.014169139103614725, 0.031095395788725, 0.03311352353193797, 0.01811914404242998, 0.043810042334371246, 0.01413387966749724, 0.04348993919847999, 0.02582403401902411, 0.03433302801568061, 0.006382104511430953, 0.05447898292914033, 0.02199641108745709, 0.0022289895241556223, 0.014143345761112869, 0.0604125352401752, 0.012778681830241112, 0.08866070929798298, 0.015453181677003158, 0.049088129817391746, 0.07017216310487129, 0.041008661210071295, 0.05633504602883477, 0.05818213656311855, 0.05060663817857858, 0.049630806752247736, 0.03641237366537098, 0.0594463220477337, 0.057961971033364534, 0.034072359776473604, 0.04034280631458387, 0.018195394150097854, 0.04184576297120657, 0.03711910976562649, 0.04107130960619543, 0.02040626135567436, 0.007075458761391928, 0.01076883367204573, 0.07822568994015455, 0.05595849514065776, 0.07754081379971467, 0.07752404868369922, 0.039276440293178894, 0.012327697240834823, 0.030898787881596945, 0.035239112403360195, 0.020126519921177533, 0.014678321058454458, 0.036530879806377925, 0.03772586373088416, 0.03584055259125307, 0.010877489658014383, 0.06061372405383736, 0.03194292658008635, 0.03417767053178977, 0.023082353109202813, 0.024475774334860034, 0.030948639796406496, 0.03625149460276589, 0.03365762167959474, 0.009882662961899769, 0.024571503963670693, 0.0714397439151071, 0.024245161221188027, 0.015017032619653037, 0.0375736974820029, 0.035366331358090974, 0.046153295697877184, 0.03359084694238845, 0.08697848315932788, 0.0026136312135349726, 0.017120370976044796, 0.03172028227709234, 0.07933488901471719, 0.03456783240835648, 0.10944007241050713, 0.034851425589295104, 0.01869894320407184, 0.08391952113015577, 0.03587348910514265, 0.01461507430576603, 0.017228956457984168, 0.02551654924900504, 0.06710830290103331, 0.042211422842228785, 0.07062250573653728, 0.05320303069311194, 0.08483654106385075, 0.04282260000763927, 0.09643121069530025, 0.02488135618477827, 0.09223809858667664, 0.01726193935610354, 0.05819281977892388, 0.01036638461300754, 0.050664392110775225, 0.027293671955703758, 0.03868863335810602, 0.03518901372444816, 0.025818081994657405, 0.020308746861701366, 0.06112240691436455, 0.029800810079905204, 0.055444468816858716, 0.018216736461909022, 0.07806165303918533, 0.11687398757203482, 0.024049738894973416, 0.03856846480630338, 0.03201487037586048, 0.03064619049837347, 0.0608376893796958, 0.055623934968025424, 0.027920144784729928, 0.05366603065340314, 0.0036778276125915, 0.03272047841164749, 0.05046874714025762, 0.04252139195159543, 0.029452394010149874, 0.0683434889651835, 0.04988296626834199, 0.04477938367926981, 0.060473472985904664, 0.006538485695273266, 0.016083045193227008, 0.01464319706428796, 0.015983649354893714, 0.050487055923440494, 0.020174308665446006, 0.05066134188382421, 0.049583687796257436, 0.0382770939177135, 0.01940508187544765, 0.018279807882208843, 0.073962407768704, 0.014609581485274248, 0.07370980296400376, 0.03484949600533582, 0.04156690098170657, 0.00677541819641192, 0.03106210675468901, 0.009865041593002388, 0.027459100383566692, 0.01882795630081091, 0.051995853282278404, 0.016316274377459195, 0.04660014281398617, 0.010681257463147631, 0.062085989193292335, 0.046560731061617844, 0.08375128367333673, 0.026834020936803427, 0.08736044430406764, 0.037685605930164456, 0.014617070683016209, 0.04531737395154778, 0.05033070767240133, 0.04028793191537261, 0.04438002659298945, 0.08885244315024465, 0.009643059656809783, 0.016787881395430304, 0.04940720507875085, 0.023539942812931258, 0.05693462342605926, 0.07262933242600411, 0.007550799709861167, 0.11328980763209984, 0.08789639367023483, 0.08802106705843471, 0.05421462992671877, 0.03149213865981437, 0.03227370551030617, 0.035320611350471154, 0.019514886334945913, 0.08121596620185301, 0.05826484892168082, 0.059324405738152564, 0.07379713890259154, 0.05133641425345559, 0.01920250153489178, 0.04014201454992872, 0.01875797548564151, 0.038079267033026554, 0.08814877583063208, 0.02646815326443175, 0.0154260385534144, 0.06254812455154024, 0.024723677634028718, 0.045484880392905325, 0.0854569765215274, 0.024931696061685216, 0.031030621139507275, 0.012305414256843505, 0.020128488467889838, 0.035982696135761216, 0.04313123325118795, 0.03971417012508027, 0.0212138905772008, 0.04749277577502653, 0.040229825463029556, 0.010130019854841521, 0.04512792962486856, 0.09603233600500971, 0.03768408081668895, 0.016937262735154945, 0.027072677075921092, 0.05739423548220657, 0.030873521463945508, 0.025765033278730698, 0.05636634610709734, 0.044244707096368074, 0.028580953076016158, 0.053781664682901464, 0.04083480569534004, 0.016544271420571022, 0.06656092446064577, 0.02784918062388897, 0.03516614444379229, 0.03235995791328605, 0.019244369796069805, 0.06342359163681976, 0.05885969883820508, 0.014976257170928875, 0.03718218860740308, 0.04376733544631861, 0.015167456676863367, 0.03691001336846966, 0.01631185117730638, 0.011471333036752185, 0.05126384705363307, 0.039696406820439734, 0.029544867466029245, 0.054890028841327876, 0.0831040863704402, 0.021345727545849513, 0.007597574958708719, 0.030239107654779218, 0.041612457716837525, 0.025071859927265905, 0.03674238076200709, 0.0439798271690961, 0.07260923506692052, 0.025515222660033032, 0.051241920300526544, 0.019970485227531753, 0.04426732404681388, 0.03164710651617497, 0.04309086041757837, 0.023896032689663116, 0.01920469458127627, 0.010539751237956807, 0.051644995546666905, 0.07609221574966796, 0.09898110394715331, 0.015609989131917246, 0.00400807567530137, 0.05266984582704026, 0.03751929434656631, 0.04248329751135316, 0.020441626547835767, 0.06624101428315043, 0.04992958056391217, 0.021665309322997928, 0.02267672673042398, 0.0213303929194808, 0.023212355117721017, 0.03553921837010421, 0.04617338563548401, 0.02429888343613129, 0.07392334111500531, 0.029761470686935354, 0.02082606832118472, 0.025802174059208483, 0.02563322599598905, 0.04405106221383903, 0.038214738669921644, 0.04850073848501779, 0.074605426780181, 0.01853594530984992, 0.01949226196302334, 0.03732143035449553, 0.03600949508836493, 0.022954631349421106, 0.04707416366727557, 0.018993820740433875, 0.03260224315454252, 0.03193230273609515, 0.028955051166121848, 0.008177916351996828, 0.03400764449907001, 0.02616998244775459, 0.062295297102537006, 0.0666178397659678, 0.026489918600418605, 0.04456262831808999, 0.04719040996860713, 0.014881565621180926, 0.048217108196695335, 0.022577494164579548, 0.05409753015555907, 0.03407780714042019, 0.03569278727809433, 0.04212317035126034, 0.05439496810140554, 0.04696863397839479, 0.029860899921914097, 0.02740458592597861, 0.010245503599435324, 0.051131180734955706, 0.012413981185090961, 0.07099373542587273, 0.07700269736233167, 0.00845147755171638, 0.015187257176876301, 0.10178458906011656, 0.011327980719215702, 0.025941261810658034, 0.025375034674652852, 0.017327524801658, 0.040522305862396024, 0.02837672331224894, 0.0186597559513757, 0.01618807207705686, 0.11254173761699349, 0.0444563045311952, 0.0670654587156605, 0.04028845141874626, 0.11965828074607998, 0.03747964510694146, 0.0617359812167706, 0.07312669753446244, 0.020495786629908253, 0.01605092689715093, 0.03348826357978396, 0.06619421445066109, 0.00913491114260978, 0.07837460187147371, 0.1449993732967414, 0.046228876017266884, 0.026865471299970523, 0.04244565207045525, 0.035766456567216665, 0.039170658274088055, 0.03012798959389329, 0.22153513360535726, 0.15199899848084897, 0.14311995852040127, 0.12419002741808072, 0.20805185398785397, 0.15223393274936825, 0.11369974774424918, 0.11280963066383265, 0.14160100487060845, 0.13926227489719167, 0.104077758587664, 0.07649267863598652, 0.10217218310572207, 0.15213365375529975, 0.20286201528506353, 0.1555290535907261, 0.07775691978167742, 0.1275060322950594, 0.11604321261984296, 0.08868557866662741, 0.08305392460897565, 0.15649853594368324, 0.0759805299458094, 0.16606618504738435, 0.11347642808686942, 0.11273854033788666, 0.23284426191821694, 0.11199287488125265, 0.12691872630966827, 0.19099548953818157, 0.1640014856820926, 0.1167756381619256, 0.13035267329541966, 0.14124682231340557, 0.1878288493026048, 0.16681192471878603, 0.10567573612206616, 0.11194428647286259, 0.22288146370556206, 0.13744211319135502, 0.11322771955747157, 0.0833866887842305, 0.09101664225454442, 0.07197629442089237, 0.14126377296634018, 0.17915864969836548, 0.11042202284443192, 0.29293394065462053, 0.11107679005363025, 0.1170964611810632, 0.06931855969014578, 0.16322272043908015, 0.18983481510076672, 0.11364488818799146, 0.10199824595474638, 0.15791453886777163, 0.1723651189240627, 0.0837908846733626, 0.14601141039747745, 0.14180332917021587, 0.1274613698478788, 0.14122791239060462, 0.09254928852897137, 0.10730646463343874, 0.12581258488353342, 0.17446458048652858, 0.13543656299589202, 0.10372004340752028, 0.19059422513237223, 0.12647642113734037, 0.08499130111886188, 0.12971237796591595, 0.14717932819621637, 0.09340214979602024, 0.1466747123049572, 0.23054666176903993, 0.20944594871252775, 0.09819177794270217, 0.1241077900340315, 0.1443656682386063, 0.12095667552785017, 0.17501308699138463, 0.11165450749103911, 0.1902032914222218, 0.18311892781639472, 0.21028021175879985, 0.0906966652837582, 0.09510404284810647, 0.16015576547943056, 0.10783590536448173, 0.1262350450269878, 0.30226285569369793, 0.17597311438294128, 0.24897982890252024, 0.1448793977033347, 0.1598442712565884, 0.08044288581004366, 0.1724818884395063, 0.14176659286022186, 0.1575456914724782, 0.06846971344202757, 0.14451184164499864, 0.16836396331200376, 0.11823496766737662, 0.15630842739483342, 0.16688511532265693, 0.10882528469664976, 0.14058908651350066, 0.1192363772133831, 0.20805413980269805, 0.11421366274589673, 0.2238387451507151, 0.18643563031218946, 0.16880183044122532, 0.12356830804492347, 0.13734357082284987, 0.1695289570488967, 0.15526284521911293, 0.12857083609560505, 0.11327702042763121, 0.18915058462880552, 0.11733000763342716, 0.11133438951219432, 0.11446137679740787, 0.10764295439003035, 0.13681134703801945, 0.13802610919810832, 0.20937906636390835, 0.08091444644378498, 0.2589913713745773, 0.14964232337661088, 0.19186620687833056, 0.08725694438908249, 0.10579001202131622, 0.16214509232668206, 0.12378287778119557, 0.12245881953276694, 0.09175950981443748, 0.121447287092451, 0.1489476879942231, 0.12770210771122947, 0.11291525312117301, 0.13908513908972964, 0.16828913998324424, 0.22002980578690767, 0.1050642880727537, 0.1880911094485782, 0.17662010388448834, 0.07497837083064951, 0.13153696287190542, 0.1847531073144637, 0.15089011110831052, 0.11680458934279159, 0.203095227770973, 0.10528700659051538, 0.20461459702346474, 0.1669534671236761, 0.22099205962149426, 0.09832432551775128, 0.20409932389156893, 0.16920069028856233, 0.14202637423295528, 0.16406027862103656, 0.10228019527858123, 0.13213568308856338, 0.09556961435009725, 0.17207035270985216, 0.11144111034809612, 0.17206756223458797, 0.4414231743430719, 0.21319781692000106, 0.08646490954561159, 0.2046839433023706, 0.07786280199070461, 0.22821361664682627, 0.20480998966377228], [0.015786894873599522, 0.005816536495331093, 0.04255378669768106, 0.008982756025943672, 0.04131122739636339, 0.009663078162702732, 0.05048662918852642, 0.020775524353666697, 0.015877442456257995, 0.018917550223704893, 0.026811686002474744, 0.01570843131048605, 0.07593585265567526, 0.07233988741063513, 0.029486159874068107, 0.02181556268624263, 0.06414595365640707, 0.07410283695207909, 0.016866365367604885, 0.06722795937093906, 0.016095952996693086, 0.036139511939836666, 0.056953618695843033, 0.046676762140123174, 0.04795646593265701, 0.020201471270411275, 0.02395810963207623, 0.06226837940630503, 0.06640504376264289, 0.03221182523702737, 0.06606116221519187, 0.06882383662741631, 0.043424203468021005, 0.04402052283694502, 0.0276825202308828, 0.04107569569896441, 0.10288250748999417, 0.025816427005338483, 0.04667459877964575, 0.09510007235803641, 0.03300209005828947, 0.024072400374279823, 0.04468980274396017, 0.02245909006887814, 0.03723845453350805, 0.033827284059952945, 0.010118895061168587, 0.03145950642647222, 0.020099062312510796, 0.011193457175977528, 0.018361264155828394, 0.10265306511428207, 0.02895791214541532, 0.024491459626005962, 0.039442540364689194, 0.047649699190515094, 0.09643757090088911, 0.04283516827854328, 0.04721193967270665, 0.03383226016012486, 0.03152049612253904, 0.01665762520133285, 0.08007895143236965, 0.0177722660737345, 0.021039441344328225, 0.03139874679618515, 0.014063123308005743, 0.0491320501168957, 0.01151414382547955, 0.010172680358664365, 0.018529720546212047, 0.039347293131868355, 0.0685554908704944, 0.06204723795235623, 0.007221882178782835, 0.008530489376425976, 0.017844423236965667, 0.06331964643322863, 0.03176531208737288, 0.016257553797913715, 0.040142767829820514, 0.02091118338285014, 0.03672545608424116, 0.030074460337345954, 0.013426831865217537, 0.06582648769835941, 0.04449739724805113, 0.02520280446333345, 0.011190912537131226, 0.06016742241627071, 0.035156990052200854, 0.031476672302233055, 0.05062920317868702, 0.04480267969483975, 0.07840587597456761, 0.028417133253242355, 0.04531404541921802, 0.03238636352762114, 0.006652656302321702, 0.05051320549682714, 0.08484221849357709, 0.051509913537302054, 0.015523409256275045, 0.01760720129823312, 0.023126813321141526, 0.05456189937831368, 0.0266642750648316, 0.06846559452242218, 0.04721597695606761, 0.05654393091390375, 0.05676707987731788, 0.03821655693172943, 0.07646595389815047, 0.022114915373094846, 0.023369671871478204, 0.030664846235595178, 0.00609907536272658, 0.030871167000441346, 0.0608904968976276, 0.06354243916575797, 0.06187617662362754, 0.009396350287715904, 0.06988507069763727, 0.06029328695149161, 0.08467643012409098, 0.016647199881845154, 0.03915726993000135, 0.02478584363416303, 0.0250850070733577, 0.03750216928892769, 0.017350661255477462, 0.060328869221848436, 0.01876167138107121, 0.046412832161877304, 0.03332483895064797, 0.05585171122220345, 0.04687291548179928, 0.04288800548238214, 0.029194091366662178, 0.03514254785841331, 0.04695448122220114, 0.03021570031705778, 0.019525677162164357, 0.059810026359627955, 0.05148087329871487, 0.03342328855069354, 0.04511166174779646, 0.02949628462374676, 0.04677127464674413, 0.03616342022723984, 0.04524408686847892, 0.028581363112607505, 0.04767391917994246, 0.02858708321582526, 0.06553961051395163, 0.030896333228156436, 0.03271618508733809, 0.025500075425952673, 0.05083618074422702, 0.028398874565027654, 0.10440187674248591, 0.014729278773302212, 0.04428740656294394, 0.04046812166052405, 0.01152732993432437, 0.04559904868074227, 0.06415802097762935, 0.08419269826845266, 0.07223354507004842, 0.03917904454283416, 0.011943457702727756, 0.0312159484019503, 0.01874962075817166, 0.05018447860493325, 0.04184831595921423, 0.051521561545087025, 0.02963839848234784, 0.0602348613756476, 0.009137552260654047, 0.07108354271622375, 0.06625540452660061, 0.021312757635314483, 0.03344842880323995, 0.03487323730951175, 0.008825021814118372, 0.037812045629834756, 0.02696251824090723, 0.011955217960348818, 0.00834089754789602, 0.028046697661920916, 0.061810503975721076, 0.03603823475714307, 0.013538212460844079, 0.023990719600988086, 0.06808229751186445, 0.0127842173242243, 0.023961753577168565, 0.009933919391187374, 0.019465451878204476, 0.05629197177768219, 0.005314756535881315, 0.03180208550475072, 0.007327185976464534, 0.03309237974463031, 0.016281502903439105, 0.08654742152430117, 0.00953795577515848, 0.04650122566090431, 0.01907469628349645, 0.0319590274739312, 0.03945290074625518, 0.06742657293216325, 0.12743631494231522, 0.03511672854074277, 0.021519061701837927, 0.03890413077897392, 0.02072723837045487, 0.0044425938631320605, 0.012683881741395453, 0.012266528501641005, 0.03842919337330386, 0.025086170389840845, 0.01049963444529567, 0.025010231984197162, 0.03807216839049943, 0.043094437569379807, 0.0195900491962675, 0.06777469214284793, 0.019220812173443846, 0.012277667210582877, 0.05663415380695369, 0.03647202749561984, 0.08904006550437771, 0.05610771506326273, 0.02878309926018119, 0.010090087671414949, 0.045080773561494425, 0.03328002065245528, 0.049944152633543126, 0.022878824674990028, 0.011518518786033383, 0.04435229624505155, 0.04055701239849441, 0.10101328982273117, 0.04681648999394383, 0.01650685975619126, 0.013696316818823107, 0.03952302999095991, 0.038139804019010626, 0.026919434712908696, 0.05120170702866744, 0.027998758632747922, 0.014448175497818738, 0.05195735808229074, 0.015207413907774026, 0.06078920116124209, 0.036468717516982, 0.06398699304554611, 0.02138427284080535, 0.04699467222962994, 0.008804367844277294, 0.040048689479590394, 0.0515417516726302, 0.029075119527988136, 0.018432669894536957, 0.032493032413185574, 0.037387269985629246, 0.010826025427377317, 0.06874938437249511, 0.025864950475806836, 0.08355465906788595, 0.02988495478348341, 0.08615876620751806, 0.012918262182211038, 0.010187524239881895, 0.03964354735217057, 0.02993912414240185, 0.07754997932352126, 0.016715345736884046, 0.0767623602587264, 0.025085057168325875, 0.039192737167468295, 0.06269059464102611, 0.014936193256289698, 0.04253460589097813, 0.07719748144154437, 0.064898676937446, 0.01772278152202489, 0.03791947150602937, 0.04344135450082831, 0.02660251353518106, 0.04392750946863089, 0.025292999525845516, 0.018245312858198304, 0.11772466692491435, 0.05052214837633073, 0.06469402971561067, 0.05010314293031115, 0.07385430653812364, 0.08658427657792345, 0.07570021334686317, 0.024917970040405635, 0.018020469942712225, 0.025515658671793062, 0.018211337337561417, 0.027567891811486334, 0.028688258353213314, 0.13374207657761872, 0.053226237650960684, 0.024293710666825064, 0.020536975825962145, 0.06265990683459677, 0.02849298260116484, 0.07725861214566976, 0.03999680222477764, 0.026323827805754263, 0.07768870898871683, 0.020710888857138343, 0.04262341128196567, 0.039414565108017996, 0.10959463950712234, 0.03892852888384368, 0.05407257172919344, 0.16161552543053403, 0.0422461219568504, 0.04260377034370322, 0.028244205423106905, 0.01845384707849007, 0.02921345399954589, 0.022753529738110956, 0.011485275208542589, 0.05904841957089957, 0.002774424001472653, 0.03431799210375175, 0.04607426810252946, 0.03198918093403336, 0.08018416570848785, 0.0505636307207169, 0.0671956833684817, 0.029694523400394246, 0.02661271435499657, 0.0513904129184084, 0.022353577078320086, 0.028966637946723495, 0.07154127713874914, 0.04646178422262892, 0.0028491046987255686, 0.025595730839995667, 0.028643248951993883, 0.031108596740523353, 0.04490823164815083, 0.023925959794723894, 0.25780340074561536, 0.1276925191632472, 0.16576525900745764, 0.1660264504607767, 0.16755818389356136, 0.13177026441553608, 0.23938776314025745, 0.12322923561441712, 0.08423179460805841, 0.19894975412171334, 0.14756024291273206, 0.13252924400148913, 0.21447968407301232, 0.16371905396226794, 0.11528731294674799, 0.20353946252726018, 0.13994738110341132, 0.15915110532660037, 0.12656625069212168, 0.1519857585662976, 0.16609235317446291, 0.19461565621895716, 0.10170627021580003, 0.062279563571792096, 0.11226867922232486, 0.19562894012778997, 0.12442039747838862, 0.11262403437285684, 0.1749448836199008, 0.21384137769928202, 0.08007391224964522, 0.18364150368142873, 0.15002547937911004, 0.14685910631669685, 0.09853655748884194, 0.16525273182196543, 0.27207632549107075, 0.11231869255425408, 0.10586429358227178, 0.1592854637419805, 0.10325646828277968, 0.1293563994113356, 0.1501454846584238, 0.29746911604888737, 0.17742194992024451, 0.09716853441204876, 0.13386408565565944, 0.1373114952002652, 0.13689433399122208, 0.08861018388415687, 0.12512212037108839, 0.250032966141589, 0.12823255034163594, 0.12239352538017556, 0.10249690982163884, 0.1320243757800199, 0.21158189425477758, 0.204704174248036, 0.12239065326866694, 0.11326096777338535, 0.0832204773905687, 0.0770538164942991, 0.19712917681317776, 0.14085697213886306, 0.11947822087677196, 0.10262609546771273, 0.06523512216517702, 0.19145875296089798, 0.1445677995798178, 0.09619137083063833, 0.13201575202401727, 0.18936791515443474, 0.15733046864625067, 0.11245706598856486, 0.16503379825735465, 0.06199730996740982, 0.10758156393421814, 0.19022046471945941, 0.15565842477371916, 0.13195707782870159, 0.13607868400868028, 0.08852736762491986, 0.08389513415750116, 0.1885077214683406, 0.13045773172052577, 0.14932989404769614, 0.17140289477538317, 0.10387989459559321, 0.13616167096188292, 0.14977801765780896, 0.10168099266593345, 0.08810173851088621, 0.18857806222513318, 0.12573209154652432, 0.24755260470556095, 0.08725010920898058, 0.2720749599393457, 0.09573734714649618, 0.12089477299014106, 0.08498168288497254, 0.1679098283057101, 0.1513608850655146, 0.06151385641715024, 0.25023094145581126, 0.07388869766145945, 0.10621033477946185, 0.1268955267732963, 0.17436284688301384, 0.13733013794990256, 0.19105711748125032, 0.16153699136339128, 0.12079689113306813, 0.16768541769124568, 0.09709705816931091, 0.11794508478487842, 0.1370128698181361, 0.11674604131258093, 0.1115730642050039, 0.23356595600489527, 0.17302340391324833, 0.1844579997123219, 0.08599678505561315, 0.25666577741503716, 0.24268172623123974, 0.1742297798045911, 0.12055201950715855, 0.15421013842569664, 0.18957774998852983, 0.11233472294406965, 0.16372659418266267, 0.07942693759105168, 0.34854814235586673, 0.16127919894643128, 0.16778278746642172, 0.228900118090678, 0.16478693025419489, 0.21240732574369758, 0.17598411301150918, 0.1310835254844278, 0.09693733314634301, 0.15388090687338263, 0.13232138328021392, 0.08563703639083542, 0.20239279983798042, 0.16040800663176924, 0.20215494150761515, 0.1374631901853718, 0.20220512553351, 0.14803598925936967, 0.08429197536315769, 0.21703518053982407, 0.15075664327014238, 0.08837572459015064, 0.14563043630914763, 0.21714058035286143, 0.10513160828850232, 0.09783801098819822, 0.10114738848642446, 0.12476222327677533, 0.09993910527555272, 0.21210353501373902, 0.09704366806545295, 0.13903155602747574, 0.12943088135216385, 0.09956020920071751, 0.21392957452917472, 0.14307385630672798, 0.12894167244667187, 0.1127968063519802, 0.12738187098875642, 0.07252480092574842, 0.11221062843105756, 0.08476268994854763, 0.10819924602401443, 0.1757789685507305, 0.1447580268722959], [0.017275932550546713, 0.07373827917035669, 0.036766890189028345, 0.038392338319681585, 0.03437918589042965, 0.04242292750859633, 0.030721444272785448, 0.028348647865641396, 0.01804660652851453, 0.036955150790163316, 0.06777892238460481, 0.041454287493252195, 0.09778200852451846, 0.06063447079213802, 0.043559363402891904, 0.03273869813710917, 0.03717519386555068, 0.014720230137754697, 0.038299514199025, 0.0769943259365391, 0.07670725579373538, 0.04876656093983911, 0.053013697688584216, 0.02793365372781409, 0.042238448149873875, 0.06185829457535874, 0.076480841380544, 0.05087390039989259, 0.03996194354840554, 0.07371120562311262, 0.007140534908103291, 0.014433358519454487, 0.032430525025120005, 0.017669712397037074, 0.011480579269118607, 0.013994542368891416, 0.021385285872383974, 0.010908388048846973, 0.023943348314787727, 0.05459876556415111, 0.05204303532082122, 0.007471071248801309, 0.04361826766398735, 0.06389273286913522, 0.05205958150327206, 0.011030613277398515, 0.09263807165552862, 0.025153099122690037, 0.04492999141803011, 0.03679171502881218, 0.10271214749081992, 0.07623763958690688, 0.07967992831254378, 0.024853776121744886, 0.05039303323428612, 0.06884990085382015, 0.023738467316434253, 0.03378186833288055, 0.08372241412871517, 0.029227196719148196, 0.03703464964928571, 0.09197082894388586, 0.02157254271878628, 0.0568061836384004, 0.026198215600743424, 0.01105470524635166, 0.07811689109075814, 0.053348870133049786, 0.037208764915703796, 0.00970795119428658, 0.045252725467435084, 0.02159421899705194, 0.037818747223354876, 0.017199309513671324, 0.03938411478884518, 0.03325661331473384, 0.01669060809945222, 0.07260628874064423, 0.05177248538529966, 0.05959253256150987, 0.019867167138727382, 0.03062364034121856, 0.10966506190015934, 0.04555708394036628, 0.041845161831588484, 0.009954671695595607, 0.028312969116086606, 0.03284704427642282, 0.03873915506119374, 0.01776787070411956, 0.032799023611005396, 0.010143205036001746, 0.00877093409144436, 0.02817760694597382, 0.051004544366151094, 0.013848137041350128, 0.02222561412054347, 0.028896729490952566, 0.10144254803890362, 0.0532015797944041, 0.025116670803981833, 0.05870083470654208, 0.02171852502215188, 0.04607659102475736, 0.02242257454781793, 0.005731416795242694, 0.05147596399183385, 0.013136727266100934, 0.009642244222050067, 0.04885339592874516, 0.042714357769000344, 0.03966773394495249, 0.07634867230081, 0.06703707156702876, 0.028244288914720528, 0.05789715185528621, 0.05810707945784088, 0.032396523529314436, 0.029361634915403556, 0.04508520789386239, 0.0671895532286726, 0.022220615755941253, 0.052283999539213255, 0.008564187519368716, 0.008575624942750437, 0.04821519716642797, 0.03173756689648144, 0.01707175102637848, 0.07670865845284425, 0.022855916431581136, 0.05926340490987059, 0.0667356260237284, 0.030196428597264457, 0.03145427428535186, 0.059489233026397415, 0.03640010596427601, 0.06372884439770132, 0.019149590116285253, 0.035016356778214686, 0.022092161125328857, 0.030472989928966854, 0.02206269600719679, 0.033122421882580966, 0.070162797201192, 0.016344433315680362, 0.07700569563894533, 0.03149524825857952, 0.02385817944741575, 0.03669992620416451, 0.05382167757488787, 0.054158070852281526, 0.08169830281985924, 0.016220301695284434, 0.030863675019645598, 0.04806661178008653, 0.04766679456224665, 0.021372109040385112, 0.056029340557870455, 0.053180647519184276, 0.020042072792421095, 0.007696156289966893, 0.02306996666447958, 0.01688867803750327, 0.02465360776113812, 0.03650802907941397, 0.017924437888723332, 0.03524244464642834, 0.05366960038372781, 0.036836603831034154, 0.007880775265221018, 0.02289396263222443, 0.029097567639837507, 0.029178663971833885, 0.027003458817489445, 0.045792029341100715, 0.05617731367237866, 0.02650118069141172, 0.04321465065004304, 0.033235009395866655, 0.03738971907296218, 0.029812352331646252, 0.054890626270207576, 0.02787202764011454, 0.026936934555124026, 0.019923562940675765, 0.02650237369380193, 0.03759395440283697, 0.06473818008089438, 0.050420648549334146, 0.014789171018492198, 0.08822509829769842, 0.09082035161554813, 0.02015619469602825, 0.0457832905522082, 0.023821786380722187, 0.05051896456279792, 0.039853352500358596, 0.01564347854582593, 0.026072432701766957, 0.011278148285782663, 0.04532941158686299, 0.07327216590056196, 0.03345030272612348, 0.0212709023617208, 0.030695266868860926, 0.03680237969092559, 0.0637827614264097, 0.02555968658271013, 0.03910165709385183, 0.034190847363788635, 0.020524309220490977, 0.03459078332525678, 0.024043955709203146, 0.007537464707638719, 0.027435208794486243, 0.01057233523169998, 0.03180105391948018, 0.046472300455207005, 0.050250841450178996, 0.0645964001887478, 0.03628221951657906, 0.010992447405442363, 0.018031841500487644, 0.025653349330241326, 0.05761590386100579, 0.04791726569237653, 0.05978325709293131, 0.13446764467516914, 0.06627627371926792, 0.11391292966436595, 0.039619060189579614, 0.06669516413239762, 0.05199000515858643, 0.01058578294760082, 0.02921748200606089, 0.01836306015320588, 0.04359463397122454, 0.06427806336432695, 0.06124809704488143, 0.02386364165431587, 0.019440499017946422, 0.03704582639329601, 0.04529346937488299, 0.04888854775344953, 0.02106816988089122, 0.014597519730159547, 0.02319105919013964, 0.02206265889981296, 0.10444005281897262, 0.042133790484513156, 0.03379015812242869, 0.06977305092732422, 0.051550275238696486, 0.040652348689036444, 0.08481130804284476, 0.0801377443713136, 0.034693151465035044, 0.017708855120872613, 0.004268135353413527, 0.026164477567363065, 0.03912212552677374, 0.025425975691177882, 0.009584981962689199, 0.039362347597489133, 0.04035070276586339, 0.01149515041106497, 0.0091247483578627, 0.01763368483807426, 0.0856242046575062, 0.05743485322454944, 0.01307889726376743, 0.05499766251887195, 0.09766109782503918, 0.008271834212791873, 0.02652556766406633, 0.031968315452104434, 0.03367901408637408, 0.051773617160506546, 0.06372905962052755, 0.025750396271178033, 0.02835195784427924, 0.05906047204916831, 0.06223655611393042, 0.07618588220793754, 0.04610723801306449, 0.02459153638483258, 0.019454067332844716, 0.016480548765684944, 0.06152010158984922, 0.0297281074381317, 0.016802696518425364, 0.01959365232323762, 0.03729264244611841, 0.0227878911755397, 0.0363160948472796, 0.08828799531329423, 0.026947608494083397, 0.03920907183783129, 0.0274699431611225, 0.019810086705547292, 0.05043203680543229, 0.03254410330555402, 0.050659950356930494, 0.043364575612940826, 0.04218411551846657, 0.01749024810123956, 0.02991510453284718, 0.03994996899564285, 0.033291193685727194, 0.0580488245759625, 0.10245180208585225, 0.00979042328253854, 0.008538615893485257, 0.02695635470445268, 0.025825624070421327, 0.0032436689025416854, 0.056103644383256324, 0.05164898459042888, 0.05145225608430337, 0.05447359122626949, 0.017942961894732434, 0.014199126508174231, 0.03268442116677761, 0.049489665107103065, 0.021736067537858617, 0.009511706939520082, 0.08482624747557566, 0.027727867309295107, 0.04275096049241256, 0.03856873940094374, 0.044041184228262864, 0.0391114682861371, 0.019767055127886124, 0.02330450759473024, 0.06075068740756251, 0.07134100858820602, 0.03710487166245002, 0.059591367389657535, 0.03864634578349069, 0.02127980627847137, 0.05811287192045711, 0.057653252442833036, 0.06812550534959882, 0.036953748131054454, 0.053215855004964396, 0.009167086027446203, 0.013334176583157387, 0.014422352469409816, 0.0206697553221602, 0.05704091010557022, 0.05639668510411866, 0.08816815330646932, 0.19851972407195717, 0.19554806087398902, 0.24634919740492478, 0.11260209648753516, 0.12192539346870035, 0.1704086543759331, 0.08942036423832178, 0.14260238473070785, 0.13552318647271022, 0.10175304778385907, 0.15803506365045905, 0.20290617307182401, 0.29819713323377073, 0.08848516910802573, 0.14334934152429923, 0.14237179944757372, 0.14763518498511985, 0.11808831186499447, 0.12043009948683903, 0.1525328104617074, 0.13819436891935766, 0.07800830746418796, 0.12958789011463523, 0.07611962326336652, 0.11954306231928058, 0.13980781281134114, 0.17382278601871803, 0.1052104911650531, 0.07448008545907214, 0.1440505968639627, 0.16815460345242172, 0.16981054272037, 0.12270113074919209, 0.12635522842174396, 0.11515300648170523, 0.11199393615243025, 0.1217484803055413, 0.08466267812764272, 0.11903369668289088, 0.15443986281752586, 0.22158886509714648, 0.0878106607706286, 0.17286698886891827, 0.1578842443996109, 0.19750412466237321, 0.08889211094356142, 0.0904485207865946, 0.09550620525260456, 0.09584751896909438, 0.2099796271068044, 0.23130856541683897, 0.272396873915568, 0.24795826262561604, 0.16948430944466963, 0.08369872477487661, 0.12573464453453198, 0.12939871667185798, 0.13291110866703093, 0.1699157347320579, 0.15823732857825235, 0.1470391365000978, 0.16006693040253595, 0.15417074522702023, 0.13437791902106255, 0.17217557440744713, 0.09422965929843485, 0.19215815293136984, 0.15639092453056946, 0.12981198902707547, 0.11252211523242295, 0.1435542039689608, 0.08582490365370177, 0.1733166116173379, 0.10854130930965766, 0.17061077087419108, 0.2093266707379371, 0.112174099922413, 0.12332125450484455, 0.21674077055649832, 0.24068217258900404, 0.18441275838995352, 0.12858137459261343, 0.16196308803046122, 0.1498246393748559, 0.10318986052880064, 0.1267739778268151, 0.07645281788427383, 0.1566674784407951, 0.16306786390487105, 0.12339413340669125, 0.11303501349175349, 0.1108702429337427, 0.17122287943493575, 0.1653494336642325, 0.14682556124171242, 0.14282192685641348, 0.28440414054784924, 0.08453790826024488, 0.24084946751827374, 0.12870461563579738, 0.16261794429738075, 0.13159323250874877, 0.14143604028504342, 0.09819150334806181, 0.14611544465878978, 0.1194306269462686, 0.13682436430826783, 0.18942206224892288, 0.14307862089481205, 0.11011343784048222, 0.08507345686666667, 0.15867065376369283, 0.2358201108290814, 0.12462375336326659, 0.13170197198633105, 0.1248836683225818, 0.17396276991348714, 0.12612452439498156, 0.10350819735322148, 0.21313151344656944, 0.222709508088883, 0.12607539421878755, 0.10184208324062638, 0.17115690250648186, 0.1292643285705708, 0.11789179858169518, 0.09342166085843928, 0.12311799509916455, 0.27863753435667604, 0.12100091495085508, 0.1572043777559884, 0.15080843033501878, 0.10064565212815069, 0.17690682521788403, 0.227164754178375, 0.1334761205362156, 0.14561348565621302, 0.15097615570994094, 0.12018522786092944, 0.09235112025635317, 0.12290818252949975, 0.12751538335578516, 0.19948901346651837, 0.15800191933522, 0.18501591664971784, 0.14458991558058187, 0.0846422542235814, 0.17935573443537578, 0.07559750752989203, 0.14629664743551984, 0.20259453041944653, 0.1722484829952009, 0.11921617595362477, 0.24559676356147975, 0.16581001051235944, 0.0867957144510001, 0.1047408526937943, 0.146208836522419, 0.18716302409302443, 0.12582883791765198, 0.13195584586355835, 0.10306357668014243, 0.11807026283349842, 0.12089094350812957, 0.13510338321793824, 0.08466813291306607, 0.16648034797981381, 0.06882446745294146, 0.163040345069021, 0.11534986115293577, 0.13089573243632913, 0.08276330700027756, 0.13093960820697248, 0.12721165199764073, 0.17790026409784332, 0.19397613272303715], [0.0903715452295728, 0.07625136931892484, 0.022449225070886314, 0.046890671364963055, 0.03839825694740284, 0.04419119453814346, 0.024519086073269136, 0.05210026603890583, 0.05722263238567393, 0.0628273279289715, 0.09140477806795388, 0.032662438752595335, 0.07573702387162484, 0.06873443009681068, 0.036967808118788525, 0.05529397240024991, 0.05464047055284027, 0.04473696622881107, 0.015126187699934235, 0.030663925972476136, 0.050372438636259176, 0.047256898978957906, 0.04850207064009737, 0.09910745458910242, 0.0633020352688618, 0.031399633662658744, 0.03568345106032211, 0.07425732241244987, 0.06514459499157965, 0.03904342447640374, 0.02859593332686927, 0.029314354542293586, 0.015769923811603803, 0.06417913507902995, 0.028499691616161726, 0.07108963574864902, 0.04099681282241363, 0.014092931669438258, 0.02009613082918804, 0.04474644716538023, 0.02607540871395031, 0.054111972349346615, 0.046917377549107186, 0.06140464567579329, 0.028260042854526546, 0.05297436386172194, 0.031767490290803835, 0.052199606216163374, 0.05201913445489481, 0.025158906428259797, 0.05080653936602175, 0.03231396331102587, 0.05473272321978584, 0.007130973726816592, 0.0948834468727, 0.07570532674435526, 0.03957433837058488, 0.037218082579784095, 0.030751115336897783, 0.052505333951557986, 0.013394658835750306, 0.04616341488144826, 0.03655058011645451, 0.03259616867580917, 0.026013654605776537, 0.04104654784896411, 0.06526462995680049, 0.03118582462775521, 0.007588071757709258, 0.021224764896032866, 0.06600599837838672, 0.03157214217935689, 0.03202983578376006, 0.020187472509860527, 0.010671671698219143, 0.11594604322453961, 0.01354958587398869, 0.08837015106109902, 0.01888065064122202, 0.06317777006188408, 0.0350138742942363, 0.028825073277403135, 0.04726758590550162, 0.018355100619373843, 0.04405298437632155, 0.043662818789016455, 0.028696991575998254, 0.02832615893566981, 0.014444773678405909, 0.06798908376367763, 0.021483562923094723, 0.06673751107882708, 0.03879212214087602, 0.0038023523393349024, 0.038374311552615836, 0.03579381955205463, 0.03292987908935174, 0.021532023311010562, 0.15453543659532443, 0.04763073731737677, 0.01570781532791443, 0.05470902644447051, 0.020730574324261397, 0.033184895874001086, 0.07159768778365105, 0.07311141671380028, 0.035711556192836724, 0.0598103046650067, 0.03699106331623625, 0.009383799642819213, 0.017739255345077254, 0.03252926035202108, 0.016214034258155152, 0.007656035322725074, 0.0398582432535477, 0.017998123876168393, 0.0897468053153716, 0.04020175743789878, 0.0650327088078484, 0.12118765414925292, 0.05473879769851919, 0.11632208203081973, 0.011139124544570222, 0.07719975241343491, 0.026605354105413426, 0.06179836615046952, 0.03595723304897547, 0.1791267967200838, 0.03302973876998294, 0.01618077491002623, 0.04135590839723591, 0.06067472859285772, 0.02963776765682269, 0.024614203430246562, 0.11126447177957743, 0.04344856075476855, 0.01895573743240675, 0.058144457725575194, 0.03296186565421522, 0.04472253887797706, 0.0404010277998168, 0.04848081553063821, 0.020057056754012592, 0.053363590632216074, 0.035948772565461695, 0.047013415169203654, 0.03347227771882899, 0.03194286720827222, 0.06726605381118134, 0.040842386733856983, 0.06570392943103798, 0.08828713442198932, 0.023583696129207965, 0.008233422504417831, 0.020759744438691996, 0.014625665680796374, 0.0278123905081884, 0.029397050202533137, 0.07546930894022807, 0.016642414884699974, 0.019401276513235644, 0.027612658159341663, 0.004833178300032159, 0.025564861207385547, 0.042870312681770884, 0.06288278120337054, 0.03546591273334343, 0.02048398833721876, 0.034450428356649354, 0.05522730527445674, 0.055401479912688956, 0.020193908785586245, 0.030775368722970597, 0.11140347603941336, 0.047004431471577846, 0.020263325568521395, 0.014255043624871178, 0.08774478032137267, 0.027623428577499, 0.08504116602125578, 0.10174768205615692, 0.035443666856735945, 0.01042617852363037, 0.026193165285803843, 0.057404217368457466, 0.0590305968944449, 0.07743650494376197, 0.01927833418449154, 0.0181410281220451, 0.11327719854307361, 0.06466573162470013, 0.02358953312068479, 0.04701923731772695, 0.02826236577675445, 0.023705855492153205, 0.10508428895263933, 0.0425015246582916, 0.08532445121090859, 0.0901001195597928, 0.07480177679099143, 0.056947985794977285, 0.01940289253980154, 0.05345576166291721, 0.061087496287655085, 0.03073640040383907, 0.019542427435226273, 0.06415530471713282, 0.02376394153543515, 0.012151302653364837, 0.020568864056258462, 0.0053706360813521314, 0.03539224715495948, 0.057536267704563215, 0.02521394595532911, 0.023312904995691497, 0.024948138343461324, 0.03531265181663912, 0.019137910567224026, 0.06327638664515689, 0.01598565315362066, 0.04436076786078047, 0.05663403877406381, 0.04844150025746785, 0.01125353588577127, 0.04398596844112035, 0.03931045292119961, 0.02131510653271107, 0.029744462517555803, 0.0213366121170111, 0.01888475842861226, 0.07526318484451622, 0.03181288375344593, 0.01687151030637324, 0.030751837075513322, 0.038446893595391884, 0.07052054206724279, 0.022508897454827093, 0.015530947621300584, 0.03728800773387775, 0.07137868742574938, 0.03866925217153039, 0.04671283793868497, 0.04240404727170244, 0.03997387357230764, 0.05290918474202044, 0.04943479070789181, 0.027632378878479358, 0.0711806230538059, 0.03282502475485671, 0.035292187094455585, 0.0774865405401215, 0.02680719600903103, 0.06618289669859223, 0.058240131693310104, 0.04752656204800587, 0.025334049569210038, 0.015224324670271017, 0.021828316494065803, 0.09197956402204, 0.03743306420801673, 0.021635500961565413, 0.08120960599626414, 0.024733036116231233, 0.042744574311655015, 0.028265926230233163, 0.027438192228146363, 0.07067139842547476, 0.1130111757083796, 0.06078984311898239, 0.057985463718068786, 0.032991265834425576, 0.03139071675832383, 0.036550216464092955, 0.06387060202541761, 0.00858367353430367, 0.047637709794798866, 0.03484686880256049, 0.04015519138192758, 0.015026164746814175, 0.045404401898849756, 0.022705225201207213, 0.04589523981849197, 0.010206024126091506, 0.008046248221944552, 0.020845592371188104, 0.039079129201127216, 0.005632661986965104, 0.039671737831668, 0.023808197656762786, 0.016246924387814943, 0.025999076970038004, 0.06595960672711954, 0.043762578279711306, 0.03934592386940494, 0.03180879823048599, 0.1421158030279912, 0.033383576228516176, 0.0871167378500104, 0.05375805696530733, 0.057398339558858424, 0.04477038513869047, 0.008038455671339761, 0.03602157725254074, 0.06601893401239067, 0.010481082608748693, 0.021177009548409842, 0.05471164251503069, 0.04918641614494845, 0.010147080902243033, 0.010850165635929443, 0.020088492274226155, 0.030584135820390657, 0.041898937852238305, 0.02646367996931076, 0.05390906175307464, 0.030705671779287513, 0.04243049741489813, 0.05867085565114394, 0.03847028609015979, 0.021814729625475593, 0.0394305435474962, 0.028425762575352564, 0.012014490512228804, 0.024389421741943806, 0.06619895677431487, 0.027377209953556303, 0.05035681642766576, 0.08460158453090116, 0.03365912452863995, 0.007296390558622079, 0.06530047568958253, 0.06383161700796336, 0.024580764111306053, 0.02016629347053822, 0.03162702400004491, 0.04563443799270317, 0.024855219598975964, 0.017227852513315156, 0.030470258825516794, 0.022734386038791854, 0.027120560444018338, 0.04674805655668024, 0.03194976176018827, 0.029752269911114126, 0.029750384856015444, 0.024227023131970782, 0.035038469068240374, 0.045199925370980054, 0.012971771957381861, 0.07509269125876017, 0.060021582976332866, 0.02110140510922065, 0.11865469670738094, 0.17567615141160786, 0.20265133440261707, 0.20099509827559814, 0.21815571963088587, 0.14427414658712223, 0.15187333803623915, 0.08709971298230812, 0.15003597334725782, 0.20017040893435478, 0.178494575957302, 0.09807460024603643, 0.14351253979839385, 0.18978713953401893, 0.0870249119179789, 0.13529366988223046, 0.1438270026119426, 0.13562797772465274, 0.18896245019277558, 0.2710890315938741, 0.24338097777217627, 0.10841659881407395, 0.1494055485818535, 0.1634037896292284, 0.15944241313263774, 0.12575972912600264, 0.20150752156041563, 0.18817847507307306, 0.1227862254017964, 0.11329007480526343, 0.12024583164020441, 0.14820994867477566, 0.12309887737501413, 0.11179409804753959, 0.15894152282271534, 0.21101587306475267, 0.16016219247831032, 0.178594172175508, 0.12482996651669964, 0.07730945668299682, 0.1694753739866428, 0.12878374342108145, 0.13891766604501754, 0.10631046534399502, 0.16498827491886914, 0.16164730419404805, 0.12763282080413774, 0.12360725595499389, 0.18790711619658396, 0.08861984664690681, 0.07956211236887611, 0.1470653639989905, 0.161128097679466, 0.17481874820077792, 0.19507209188304842, 0.15885239088675007, 0.07763501460431144, 0.13460123125696555, 0.15016264311270788, 0.1472462253877893, 0.15001553460024297, 0.1349299878347665, 0.10775340822874568, 0.09990225022193044, 0.1360781051334925, 0.1471548670087941, 0.1288212664076127, 0.14085774397244677, 0.13516207225620747, 0.0979948193707969, 0.11381063945009373, 0.13515632803319022, 0.12242781260283664, 0.29371278011240065, 0.14719050494022667, 0.2094505648710765, 0.10476381474290974, 0.2481136386631988, 0.09774237041710876, 0.10214315028861165, 0.1324262042180635, 0.12142980209318921, 0.13484474475262687, 0.09655393223511055, 0.14616288273828104, 0.137185211351607, 0.12899855064461008, 0.11973739368841052, 0.10106739980983548, 0.1299721741816029, 0.2448304367135279, 0.2313655475154519, 0.14067821844946593, 0.1685010379878804, 0.15397312614368275, 0.06337702929158695, 0.09612855545128696, 0.1434172480367124, 0.35642045899294317, 0.1356495890649967, 0.19432517961831763, 0.12485232000472024, 0.0950771028874442, 0.06888520481879823, 0.1123877419740893, 0.14440454193390906, 0.08187989893485792, 0.2539213153067976, 0.15487051627133042, 0.16438112390460446, 0.1152869344514329, 0.11271797542576678, 0.08639723309897818, 0.14607832243200392, 0.10731474700151011, 0.1331622217549011, 0.14792759116971865, 0.12870492733782157, 0.31339109293185174, 0.25068852002732456, 0.0888245458190795, 0.20324493380030617, 0.07888697320595384, 0.14630071440478787, 0.1373486767988652, 0.07797286249115132, 0.12502681376645342, 0.22072064137319103, 0.17264547263039276, 0.11985007397015579, 0.11656068250886165, 0.2218459895811975, 0.06761401717085391, 0.12988381407922134, 0.204052034241613, 0.10668077477021143, 0.11012428061803803, 0.21411724883364514, 0.12096986349206418, 0.1565345746348612, 0.13799548818496987, 0.1455187430838123, 0.09520858176983893, 0.09401708593941294, 0.2065080383908935, 0.1586008770391345, 0.11484465896501206, 0.19082019425695762, 0.1255581618170254, 0.12280187729629688, 0.10445897758472711, 0.1684408646542579, 0.13169931509764865, 0.17400198499672115, 0.20638948772102594, 0.08887798787327483, 0.12904306466225535, 0.11421604503993876, 0.18160982988774776, 0.21699520846595988, 0.1041269110282883, 0.13640371500514448, 0.0743217185663525, 0.09724887931952253, 0.08353232784429565, 0.15787222160724923, 0.1409921023878269, 0.14458764460869133, 0.08997560944408178, 0.15068784618051723, 0.15188564284471795, 0.13359703123569489, 0.08096173609374091, 0.1991181177436374, 0.13242969231214374, 0.12760479730786756], [0.04273793580068741, 0.024763230394455604, 0.021893195043958258, 0.06445282429922372, 0.05823388280987274, 0.007117896620911779, 0.042075320379808545, 0.10646943337633274, 0.018261647528561298, 0.010734437910286942, 0.06799082781071775, 0.00986774579359917, 0.04386781853099819, 0.03901212810887955, 0.06666771951131523, 0.0667343866371084, 0.0554747261776356, 0.03222738436306827, 0.034830645454348996, 0.020239055484125856, 0.01132474124460714, 0.04532499580818694, 0.03236463344364893, 0.0387822998163756, 0.040291048935614526, 0.02476390389347216, 0.06105428888986353, 0.018165175752073992, 0.06337231665384024, 0.04691447946242988, 0.09386264500790276, 0.06662621119176038, 0.003492119535621896, 0.022965693060541525, 0.03479748629615642, 0.013557326474256115, 0.024980995076475665, 0.02944130446849158, 0.00800504325525253, 0.09709909165394492, 0.008308973137900466, 0.010968060432787752, 0.07048865940305404, 0.014555619927705266, 0.02864947557100095, 0.006155870069051161, 0.03251048401580192, 0.013292102375999093, 0.06720939825754613, 0.013663801473740023, 0.06298091539065354, 0.01884712040919112, 0.08627200310002081, 0.053517931373789907, 0.04769581624714192, 0.021367663575802, 0.02060480255750008, 0.07100610702764243, 0.022960852402320597, 0.012436481247277698, 0.06263848845264874, 0.0315109446819406, 0.038028385388315655, 0.05192470729525667, 0.011123791773570701, 0.021882866203668527, 0.030372165456356015, 0.007452719792127027, 0.02243825983896386, 0.006473887306128745, 0.10257682428346016, 0.016160939157998655, 0.05524798893020488, 0.039405314237228595, 0.03411581623367965, 0.02143754234566586, 0.05264479463221505, 0.11844341468531638, 0.051798022686853074, 0.023470663327316288, 0.01616688932699617, 0.03585914339055307, 0.022039980722183827, 0.0497653321508551, 0.022977372609602753, 0.055272045647143386, 0.01550438801132259, 0.07104755597538315, 0.04659615005948581, 0.09310728710261174, 0.059125717962160707, 0.03670472047815565, 0.04584444352076389, 0.0271371233247919, 0.026192489931418095, 0.06443324644351378, 0.040985513624036685, 0.036425405778572895, 0.062045423401286826, 0.09238269863999449, 0.0037792532248204225, 0.03721494700585026, 0.04769675506395288, 0.017886720088426955, 0.05424896538897883, 0.026056237184093334, 0.03850911154586356, 0.09742126538185403, 0.03752430384338368, 0.016345284930139314, 0.037218253273749724, 0.015947727551974822, 0.06020129774697125, 0.07640106050530449, 0.016679197578923777, 0.030884785410307813, 0.018333287043788005, 0.01598525239387527, 0.03743598084838595, 0.057464717247057706, 0.006062453157937853, 0.04482238000491634, 0.016009284991014283, 0.01576310532982461, 0.04725257967947982, 0.0330585415213136, 0.024899013733374886, 0.04071436997037381, 0.01446372720238287, 0.02647252636961639, 0.020235508018231485, 0.036091071960981935, 0.0725592662638519, 0.026791686977958307, 0.06096929813793395, 0.06643966495175846, 0.06032103956385981, 0.03462353801296558, 0.027712681112461723, 0.018060449438053183, 0.02505794465832878, 0.006419014762286679, 0.014535165410052286, 0.02598093888082076, 0.057545251402189024, 0.034848787254304625, 0.02622654337756103, 0.00855187900015153, 0.016772298149589915, 0.03579635398637038, 0.042437885495019145, 0.020299507123127114, 0.025920090192812495, 0.03353275533299893, 0.038662546867271885, 0.053413696732604876, 0.05901156451727729, 0.039127027412177995, 0.06845849959063344, 0.03220762468117755, 0.07626005986821838, 0.061433626542566344, 0.027286282020213548, 0.040963594292406924, 0.06360945510095917, 0.02598011324153049, 0.025639608466008212, 0.012633066889975453, 0.013776897358184215, 0.044805147335864604, 0.04562707959848922, 0.002637052466525347, 0.027684060187311843, 0.03529911504301708, 0.05908336730499286, 0.03888247490976937, 0.036751353327417746, 0.0024316313238159637, 0.0701322355598677, 0.024446327770419884, 0.007985638876562007, 0.01782967861799989, 0.025111162212851923, 0.022095268868724816, 0.04424677768838592, 0.03684684917971026, 0.010007731543737464, 0.026883280988840852, 0.0278002619597828, 0.054701597546227276, 0.0395780750841368, 0.023715770585113205, 0.010782273038785206, 0.07248050213092938, 0.07440389657858759, 0.026207100963802077, 0.025899697830027435, 0.036451295600272715, 0.038340881510521285, 0.03486444285954349, 0.0031198095575746265, 0.0604603629471967, 0.036634517018683255, 0.03138584455882665, 0.012366873361315811, 0.03537820201017894, 0.04081806284375489, 0.028125834724050947, 0.0008279635460439749, 0.020281608376535587, 0.02625063163577579, 0.028050094842910767, 0.03362701179867145, 0.05204218556173146, 0.027335896447766572, 0.0385863431438338, 0.014922526606824249, 0.04928872862365097, 0.017264492344111204, 0.04581239016260952, 0.051471563056111336, 0.002873769512916624, 0.02108392567606643, 0.05842883387231268, 0.08171182475052774, 0.020650370424846187, 0.02581910986918956, 0.0528091358137317, 0.0032878570709726773, 0.035760812534135766, 0.10433264178573154, 0.01066741640897817, 0.08287969802040607, 0.06446314757340588, 0.019245544244768098, 0.029385426314547658, 0.05029018640925642, 0.05946008146565873, 0.053297008853405714, 0.05869088250619825, 0.012962958026037086, 0.015439341550518293, 0.024768748262431473, 0.029685061017517, 0.018240399840578903, 0.024059572351688985, 0.05302947203745134, 0.026300227509636898, 0.04750941843667533, 0.03216884004359599, 0.03913080123311374, 0.013042703649261966, 0.041533686162438244, 0.026705078344093636, 0.052181074788677506, 0.051569129500421695, 0.016364205985155422, 0.022514890297316015, 0.048556113833910786, 0.03740664746146649, 0.04021054075565189, 0.026153579128731508, 0.06886233182740398, 0.022837175347376615, 0.10433103874674998, 0.05058512331743259, 0.017510323195892852, 0.04855143459280953, 0.00774587647356384, 0.06707228647428565, 0.02480786501109833, 0.016815094095363747, 0.0553130084881559, 0.04098709439858794, 0.018864601697714534, 0.061302355461521074, 0.025077296158997342, 0.08447183485259302, 0.05287514242809266, 0.096960087394109, 0.01880028718005633, 0.05840490703121759, 0.0066237756254849955, 0.033151625393657014, 0.02950360405520769, 0.030132366409816314, 0.029555749206338078, 0.032413277513114735, 0.06386397464666516, 0.008823332500469405, 0.09640577729442157, 0.12575667147757486, 0.011192220572411316, 0.049040699159377255, 0.01829798122344073, 0.035614702210295945, 0.028662034565059002, 0.02715286798775196, 0.014257450038712705, 0.03457106446148828, 0.015560801439278293, 0.0628410502395127, 0.004525276999629568, 0.0707631946715992, 0.0038618619146291167, 0.011131779137940612, 0.022271016860031523, 0.03736202583240811, 0.06701290723867714, 0.014108484301686985, 0.041055078836507164, 0.005619468920485815, 0.06816845343564637, 0.023589950578752905, 0.045596436320920475, 0.02198849237174727, 0.06212930464243982, 0.005009085389247048, 0.014048055854800623, 0.07752430101390928, 0.019904638174921274, 0.036303452361607924, 0.07462202120223083, 0.04050630144774914, 0.025175638147629797, 0.04187064347206615, 0.011587686949496856, 0.03370720827660989, 0.1212526588642504, 0.012199920747661963, 0.047443185467273, 0.05676292013959028, 0.06623094333917834, 0.02578362593339989, 0.03199867300281767, 0.0269673050934216, 0.024933000386226922, 0.0356269958865596, 0.07452347883372568, 0.0424308573565213, 0.10043004338513128, 0.007338256036746316, 0.028356885704852175, 0.04218440124532208, 0.013619289311463945, 0.011881129357789177, 0.034792339502018876, 0.03305864542198833, 0.01809792418498546, 0.05496515273989644, 0.020938017587468494, 0.03882413468090817, 0.12138413032516837, 0.082339295768179, 0.21055013086879626, 0.2068062184844166, 0.17030369985150173, 0.15228462143568322, 0.09137478045886382, 0.2731613750802353, 0.1691371327615343, 0.1750721619464457, 0.0831127843412105, 0.10262682277243584, 0.14323830138891935, 0.09953401880920865, 0.12102612570743077, 0.14609763311455026, 0.11680493073072284, 0.1468620600644499, 0.2611299144336954, 0.07457027866621502, 0.1509316120063886, 0.14841558295302093, 0.21389047818956897, 0.24304718943312764, 0.18610887753311545, 0.14875061810016632, 0.12546229118015617, 0.1396334229502827, 0.17872759548481554, 0.13564298395067453, 0.17747023404808715, 0.20360296068247408, 0.07019370023044758, 0.1266497719916515, 0.09844779662671499, 0.10214556969003752, 0.15959357377141714, 0.08690642061992548, 0.14799776865402237, 0.1837355486350134, 0.0974034761020448, 0.13646819279529154, 0.13267676811665297, 0.13587172870757058, 0.138272947515361, 0.08722499493160285, 0.10554802734986879, 0.16174041404156014, 0.21716470015235245, 0.12809740524971858, 0.11703438794938847, 0.11032680529751815, 0.1997535742702894, 0.15450490463990718, 0.12698130420176312, 0.11628769832896069, 0.16473008174216375, 0.12463248101994395, 0.07578041724627838, 0.12581601360579953, 0.1923737023025751, 0.1305677625350654, 0.15669667453039438, 0.2353085929644294, 0.0830245652468875, 0.13344238250283524, 0.21621482534101233, 0.16902440052945167, 0.1192074260325171, 0.07791521988110617, 0.17572882905369624, 0.057556532046874054, 0.1710333942901343, 0.19978691154392436, 0.16237790405284613, 0.10205205166130327, 0.12142776118707843, 0.1289593504043296, 0.1188865584845189, 0.12786389590473846, 0.11883440034580417, 0.1289951367652975, 0.15964230318786576, 0.142193001229316, 0.15141455718548968, 0.2598057745490223, 0.1476947942865081, 0.19999754789751023, 0.11426202850998379, 0.1758868619799614, 0.19491477141855285, 0.19121954392176121, 0.19868062168825418, 0.161451228777878, 0.12095508733182214, 0.15621043421560898, 0.09561170896631666, 0.1251226695603691, 0.09470709774177521, 0.13502812944352627, 0.12706190143944696, 0.18300116382306442, 0.18630385457072407, 0.15797048195963725, 0.13649639440700412, 0.11012192800990306, 0.11555830074939877, 0.14637736341683194, 0.09801570340641774, 0.08154950221069157, 0.1620643021306023, 0.12969557574251667, 0.26552966271992773, 0.201939451508224, 0.16857437702128664, 0.22249409230425954, 0.11232163888053037, 0.11811456162831746, 0.17268173396587372, 0.13311249786056578, 0.07537571669672616, 0.07533172218245454, 0.1653940961114131, 0.2105477114673704, 0.11638664145721123, 0.15567988768452778, 0.12526375183369964, 0.1491122369770892, 0.08400723556405865, 0.10087382543133572, 0.21231276128673926, 0.16626846481813118, 0.21109492663526908, 0.18580005504190922, 0.1727342780213803, 0.11802695109508932, 0.14513695263303816, 0.09337328025139868, 0.13325556908966973, 0.06136680727649946, 0.13907463027862832, 0.13147693796781823, 0.09541413441183977, 0.1208376424619928, 0.10562506970018148, 0.0921506661688909, 0.17191131046274677, 0.12738507706671953, 0.12520371208665892, 0.2080927463248372, 0.10906149545917287, 0.11551143412361853, 0.18322432762943208, 0.11119943737867288, 0.17917039047461003, 0.24408355413470417, 0.2536216063890606, 0.13406293670414016, 0.1244436638080515, 0.1017061663151253, 0.17559362458996475, 0.10587823853711598, 0.11884504274348728, 0.07659769253223203, 0.16974271042272449, 0.14020211587194353, 0.18136306578526273, 0.11293204050161876, 0.09392791689606383, 0.17770800332073122, 0.11172256985446438, 0.15442236297531053, 0.11272015733993612, 0.166493498836644, 0.0994822836946696, 0.1386983910924755], [0.013774100389127852, 0.019030427174584474, 0.023497436304751318, 0.06856830033939332, 0.011157031640323112, 0.021797218651045114, 0.0538752086868044, 0.03976212770794518, 0.029783185927954037, 0.03844965809548739, 0.0642292968404945, 0.017312780182692222, 0.01198043706608587, 0.03782014988246374, 0.01729116698697908, 0.010021278521890054, 0.043972101411782205, 0.01735771722451318, 0.04465876612812281, 0.04448444306035526, 0.030816737889836077, 0.03567616317013744, 0.0255594713598839, 0.0346514205011772, 0.04953526266035624, 0.0682986706669908, 0.024491752774338238, 0.07717938045971096, 0.0419380898529198, 0.03027025373739889, 0.015812960955372546, 0.0632439176843036, 0.025253886487917043, 0.0014403360910364427, 0.02683575941773597, 0.048165476982831024, 0.013130062779964646, 0.030342351528815925, 0.03238184013753198, 0.04198240720143076, 0.04255407242453657, 0.02625347962748492, 0.025144271276076324, 0.028556126380863134, 0.0329952660104027, 0.0592828566004755, 0.016360120462195482, 0.04069579401402734, 0.02860560351109598, 0.09286604457884096, 0.01853101002780022, 0.028748607946909033, 0.029312886945263017, 0.03341599694977049, 0.05694649778888561, 0.02775024862785358, 0.008114960892271483, 0.021455778769450262, 0.05810792550619226, 0.039535115865874104, 0.011566542234504595, 0.015846778769628145, 0.011120377894258127, 0.0655966074555181, 0.02421072556899162, 0.06359050807077438, 0.022379145921149757, 0.08341338383615948, 0.052484824700513855, 0.0151398506386613, 0.014388721119757975, 0.007445132723660208, 0.03069530397624476, 0.049066544452216476, 0.02987961874168832, 0.05772316646471154, 0.016168043366633356, 0.07414863488520496, 0.028903646307298914, 0.045940848503960297, 0.04003888199804351, 0.024896841096051503, 0.04081876417330932, 0.042093669981113635, 0.025326049217255786, 0.025182669996866025, 0.08143309634760953, 0.030060185126785655, 0.08540754206478596, 0.03389879741007462, 0.0780380675860215, 0.04160216783930082, 0.023229060861922335, 0.006676074772258289, 0.03483652697468642, 0.04803628762601875, 0.018144660934922285, 0.04501485971559305, 0.0847649312345311, 0.020955452491762117, 0.10545209734118544, 0.019609215160016902, 0.04584981666994281, 0.022469951400125865, 0.026100613904418424, 0.03475981859082822, 0.03709133488882799, 0.016412061522714794, 0.042720361743704416, 0.02059711576293921, 0.01366601307381643, 0.05067622565547936, 0.04229084006510675, 0.03130472781776916, 0.021793468949908856, 0.033191070542670786, 0.04738854484457988, 0.036053808726137504, 0.07901497883722186, 0.030919651508156676, 0.04409661523823161, 0.10721966304117814, 0.003338407764204021, 0.019510067941155285, 0.06912704848218709, 0.04918090569844935, 0.04710640627308749, 0.02329239017853979, 0.09070425745449029, 0.02025913057877915, 0.0617921506636776, 0.020660099980887026, 0.016819255688460544, 0.05809250367747154, 0.007396634300675942, 0.03760739098652266, 0.024295469556818716, 0.029280291819304693, 0.05766782080172561, 0.0538552449143026, 0.03576286086172331, 0.03533150978910271, 0.07059607785777189, 0.017813045233197045, 0.021598336061288137, 0.05242051018285565, 0.01830159733799519, 0.03981404093792662, 0.05062136609922163, 0.01736473979690345, 0.04614182580553461, 0.04709347434982192, 0.020527576525637414, 0.020362270552141126, 0.07589740940602496, 0.059407088410807773, 0.05067134974524379, 0.03044528370082844, 0.015363705570052844, 0.02110615485435119, 0.04326091242546681, 0.022565925937669817, 0.016140099651238415, 0.02058570895314915, 0.01622603664145572, 0.06905334579641931, 0.03429765725741163, 0.07604567566886544, 0.05676129483617842, 0.05133518228831235, 0.03472209151368588, 0.050536345661384985, 0.049006374829332344, 0.053313799944589846, 0.04502133866481017, 0.06739423013641499, 0.0659000345331151, 0.03795860495301895, 0.059359661463531666, 0.0247556400790927, 0.04288241339963861, 0.024972929786599707, 0.058608377948985435, 0.047662701617809944, 0.01852591332863085, 0.04902465392660815, 0.06926482819835655, 0.029627377589349635, 0.06194378998770844, 0.049855157994898036, 0.04444304977369029, 0.0012577227698784554, 0.03256339914514683, 0.010197332649113378, 0.023489753220928833, 0.009951430365617853, 0.02294298705237452, 0.013338138724066084, 0.04245882519171573, 0.060756776729249395, 0.0102589652306051, 0.033128822906292044, 0.07101310548023321, 0.06820372029324062, 0.030132720785331912, 0.009506544374744408, 0.04589484276948497, 0.02379036755883135, 0.01899756858620094, 0.024137930158758536, 0.041372395207872614, 0.03798473968345206, 0.02144626258086646, 0.04772329797560815, 0.05464797366585117, 0.04235805638018064, 0.038540879177162424, 0.040846438860171475, 0.027376122707210016, 0.03714573431352619, 0.05752650846261531, 0.07444789109285921, 0.052002822048962116, 0.07716118299867958, 0.069478878431255, 0.035496949349180795, 0.037412491874420084, 0.017821225555962883, 0.02092505783366505, 0.044915831240359694, 0.019673320020956453, 0.058323044431745075, 0.041321936587337404, 0.028332073852652684, 0.03152979152218904, 0.05476459475175943, 0.0807464390527457, 0.04054530872963369, 0.015483298957406078, 0.074596973718144, 0.04376038152258843, 0.018468539747118484, 0.029488334366760682, 0.019356452648935374, 0.039820850142859854, 0.05017977338866331, 0.04346332207205705, 0.01200277478346834, 0.06088375077524688, 0.03193216172803659, 0.0321809890010627, 0.024635666341055185, 0.04506905876041856, 0.047912152294884436, 0.03484083885268774, 0.07271326932823285, 0.03359717004059348, 0.03328329723444767, 0.04408468150359113, 0.04634161938156467, 0.06596018560230732, 0.06190541353134904, 0.05664013180648908, 0.023126264131860808, 0.04210273160424549, 0.02831352572684409, 0.019967331099906005, 0.024565702224208508, 0.04494133885600604, 0.028256072364456486, 0.005407231383287581, 0.03694719125633128, 0.06208727681951132, 0.05030593107221648, 0.017287469236180186, 0.02358707661187509, 0.0753258889017161, 0.0025576512462066603, 0.025819519905780908, 0.021973346993036103, 0.02315877947694389, 0.023593575970153324, 0.047385312791448087, 0.020925313874613494, 0.07380125782219693, 0.05865046885446645, 0.012945823691552505, 0.044205172889633104, 0.047071747976588085, 0.015450375431100838, 0.009701606759335846, 0.03521050632116385, 0.07147623531636782, 0.009391051353304647, 0.006907917068019742, 0.08005967043573037, 0.034616884659044445, 0.11740392554202117, 0.014238002986530773, 0.001145536596141028, 0.03500358812743798, 0.02136057421012083, 0.024570125424361322, 0.0507879819633672, 0.05677919172740076, 0.009187447776639601, 0.034551750068203546, 0.060382700903574005, 0.038827407552162185, 0.04485517922148574, 0.04542823968222365, 0.0179643264709739, 0.06112502669566311, 0.0074798935293074464, 0.02865893424313981, 0.010874774325202452, 0.09543222797219642, 0.015560018473479431, 0.025970604474423453, 0.027553904183150735, 0.022144261747598648, 0.026819821796379983, 0.04612540207745042, 0.03794971031311434, 0.01316013274845318, 0.03649841084552463, 0.02500225389667321, 0.0713320063368883, 0.02929906073404709, 0.04933660457027145, 0.027619728971330915, 0.01796714848751435, 0.03332090927870013, 0.02934480300609721, 0.030097986418695655, 0.03868896732456051, 0.03961692280427087, 0.025638472980062943, 0.05713270264095627, 0.08560960661270656, 0.01612417501746677, 0.04595281192450784, 0.051470587131916545, 0.0504812560393475, 0.026178361295023933, 0.13482669572113082, 0.0691640519653447, 0.053546504059340805, 0.05426100302429404, 0.02047005636995891, 0.035054970721830614, 0.09974698550649919, 0.1520262353005819, 0.12237894217832945, 0.18799541692715138, 0.12794863432645798, 0.09334075191873126, 0.09656649679527618, 0.13096438109641895, 0.277458528871648, 0.08236965702963062, 0.1194012378982734, 0.17713300214381889, 0.16031562408898026, 0.13381966069573537, 0.15678080439101905, 0.10515598783968017, 0.09266909342841245, 0.09043685422511771, 0.07559530335129239, 0.08992388917249627, 0.09351487460662611, 0.13090722088236362, 0.15383360238047317, 0.07574713934445754, 0.09461970985285006, 0.11855682227178477, 0.13254463614430279, 0.21015933074522763, 0.1994246247340925, 0.1993061334360391, 0.12657276674872264, 0.11733872786862776, 0.12116866259020753, 0.12953494529938325, 0.1185108462232165, 0.21862042282009497, 0.181110572302714, 0.10960988322040066, 0.14044591138372198, 0.09443467017263174, 0.13245545967947692, 0.13922124897362664, 0.15314757591113448, 0.15080899436725304, 0.14026861230377108, 0.13999061862705275, 0.16187633096706122, 0.09882392449071631, 0.14610790443839505, 0.07823330437531695, 0.1993826191755943, 0.18378429289441556, 0.09770251708687283, 0.0988242139283102, 0.1259052791283466, 0.11066617458709516, 0.08049582320381887, 0.13634361588628963, 0.09369533523567952, 0.2304620569339022, 0.21408826054539531, 0.17961789068067446, 0.1381001458503306, 0.11186915886355564, 0.18328457517782226, 0.06977295444812626, 0.19290015217848122, 0.20903190452372655, 0.23728306201519445, 0.1175142235297244, 0.13956124166725203, 0.1290667985449545, 0.07028076899587177, 0.1235211148741655, 0.10729350673500448, 0.12821086478652433, 0.08422147133387625, 0.14380368433194235, 0.1222075877012685, 0.13768725941190496, 0.24173197016352788, 0.18826014100341126, 0.09123533833189867, 0.1542244470329024, 0.18175919452914968, 0.17745752847986296, 0.08915758458897471, 0.23808884143363684, 0.16076076426543295, 0.1408265737700276, 0.08906096438295208, 0.17298145772656426, 0.10304450348485261, 0.07538331628893502, 0.16915564192458987, 0.06287476600846276, 0.14568453887477517, 0.11499376385472715, 0.16843592195073143, 0.1440249927691184, 0.12575073429616168, 0.1880010572494939, 0.12100479638320394, 0.1398292460362427, 0.14389685355126858, 0.08995269192382693, 0.0885310560988728, 0.1051115406153258, 0.10981403320329264, 0.1829299028031528, 0.13247957947896793, 0.09532996744383126, 0.13696186942979693, 0.15378221607534215, 0.13361175544559956, 0.0554276072216453, 0.16708798881154507, 0.1580914223450236, 0.12513435096479952, 0.1702602396835573, 0.1764291344443336, 0.10238799965009093, 0.19771547347772866, 0.05224015716521535, 0.11130075537948869, 0.20845972350798547, 0.10742345679318532, 0.1697015212266706, 0.10979876722558402, 0.14903745817719027, 0.08910940436180681, 0.09483966015977785, 0.1322361995698884, 0.1755249610869214, 0.10703652325901203, 0.1716511431732215, 0.10729522109613754, 0.14291848026914522, 0.09606081221136265, 0.13127881422406062, 0.13957277464214712, 0.13259139144793153, 0.11076698792749085, 0.08268359291832894, 0.11975235538557172, 0.12367118455586024, 0.25300770183093846, 0.10853649277123623, 0.10234973451588303, 0.14623892318923026, 0.1405774793238379, 0.2045322334743105, 0.1763638699776493, 0.06469189975177869, 0.1142657244054135, 0.1411910870228894, 0.14570610568625852, 0.1658794458489865, 0.12661210057558492, 0.09581392936524935, 0.10113690936123021, 0.17841668013716117, 0.09707574368803762, 0.09596989912097342, 0.11603479666518979, 0.17406396917067468, 0.19619784085080028, 0.1720009619020857, 0.15215550258290023, 0.12615551648195833, 0.20031177322380245, 0.1581371683278121, 0.12100631778594106, 0.1738885254599154, 0.14281573734479025, 0.1116899227781687, 0.18512504204409197], [0.06086377215979155, 0.006555636264238274, 0.026035516420961358, 0.04201367759378627, 0.07383852847851813, 0.06534495259984396, 0.01547459170978982, 0.06868920361739583, 0.04722714256786276, 0.055518691006000154, 0.06924275672645308, 0.014212846963346237, 0.058098006702493876, 0.014547544433298754, 0.021813421590195503, 0.03598159033572301, 0.04998693744710181, 0.030635232687927783, 0.06487611564807594, 0.03051306961424416, 0.06405563428415917, 0.06472102904808708, 0.0359714340447681, 0.04240165384544525, 0.03972876445914153, 0.05714622086088639, 0.020777051322511397, 0.05844676044944208, 0.08528759615728632, 0.044117098514107056, 0.0047443900712096365, 0.1000525128620211, 0.08174877628334798, 0.020013006578665227, 0.04366092260170262, 0.03018329072801862, 0.01537412625111756, 0.04103315208340064, 0.02778895719529828, 0.09123687457758933, 0.014710797440784518, 0.026131346239708364, 0.02033172746450873, 0.03237501237890683, 0.06584235481568612, 0.023663213542022277, 0.07750444856355898, 0.059878088723053224, 0.03203419219062198, 0.08775401263847016, 0.03537132601195481, 0.03123048707493581, 0.021739416479249485, 0.03745257527043577, 0.028354809546726756, 0.03962111222790554, 0.05920121293456759, 0.06249817801290192, 0.017492871593276504, 0.03526715074258391, 0.10848283549421467, 0.05407735487096943, 0.06108082438004203, 0.040792306608636864, 0.008035394312173594, 0.12301150432904251, 0.03602022283303086, 0.033758108475012705, 0.008273130188172217, 0.017137045178969856, 0.10399658989626914, 0.06983501283684745, 0.027187624618818518, 0.005615547597699333, 0.007746082883386407, 0.03790693292103242, 0.012420095554261934, 0.011267367663094774, 0.04105589890968986, 0.026876742667809594, 0.03571150795323774, 0.016453521602670662, 0.04320748150348663, 0.012178177676105406, 0.027367101902200375, 0.03617317575844936, 0.04333393233537208, 0.01698034811852267, 0.06346561945974827, 0.07270834146765992, 0.003555832449819718, 0.043587984328041784, 0.022269322907959577, 0.018232976508443244, 0.008080274765234208, 0.045320847202674486, 0.03864514350425452, 0.04790461949596647, 0.02753174921963364, 0.10129931353731081, 0.05633938759274315, 0.07868358021369204, 0.027000039372069295, 0.04541132984741125, 0.08275732529000379, 0.058880055948975496, 0.03757404258067254, 0.08094660370261408, 0.03758639933948871, 0.10373986617196351, 0.05107214288727846, 0.04325234433053993, 0.01701733304798836, 0.012938563631905708, 0.009349268439109437, 0.04568069976812694, 0.025329492782475427, 0.07534507341915742, 0.03798612749960739, 0.010867687742575072, 0.04564489114272874, 0.009963201755454065, 0.024062958400463685, 0.0868870283011347, 0.10849105106899515, 0.03531585418386385, 0.015728255930298474, 0.04385864929645322, 0.0714841614535544, 0.05847502143296879, 0.009811923300730996, 0.03281315410276875, 0.055828849363024347, 0.05110994046845008, 0.043178407868254, 0.03888487575750332, 0.14609367004595697, 0.013397711845755111, 0.013399686886259587, 0.026142630595131777, 0.04413155926158652, 0.04015054182673339, 0.011414890850574011, 0.04027384224173147, 0.06261232774704695, 0.058121221081819385, 0.05587397565250285, 0.022185591951711103, 0.03723626890860032, 0.036989601285313256, 0.04905282214167528, 0.06773212997359224, 0.02287651845108485, 0.05657289693772327, 0.04866967356065288, 0.0352706054400187, 0.08608468502643518, 0.007823525065759895, 0.023066469293553382, 0.02402695125056198, 0.06414161209249869, 0.015427974631165853, 0.022518851510540117, 0.011718791974999476, 0.04311578915803693, 0.05471175754792057, 0.027469772467156872, 0.051626048516482115, 0.02551447494624881, 0.038937460631132126, 0.020411102013895288, 0.06326178860035725, 0.06625599824474193, 0.04466580168809742, 0.03476817517366726, 0.07015165014308877, 0.06473601300967857, 0.038853033911436796, 0.04694481103797443, 0.10380605090176687, 0.020572161047311965, 0.03908224622136913, 0.0348248233058257, 0.021111299793119542, 0.027002813149010763, 0.00752386670683336, 0.02544290036894381, 0.04464380443096161, 0.04982215839845594, 0.053300819781725295, 0.03732241741090547, 0.052831667417194694, 0.06091130300774239, 0.034899464808404446, 0.04553898295853287, 0.022730966593371704, 0.059032934659626335, 0.01759389830112923, 0.051813388854498044, 0.09576906653819606, 0.01283761948798201, 0.03314026311272755, 0.012991057592444122, 0.09294643401517533, 0.017943559323612135, 0.06395444244844839, 0.050376590952510014, 0.05217347148573026, 0.06957270816201344, 0.023573254111397546, 0.030164291747496463, 0.09891111199976876, 0.026230923904222436, 0.030116705238469876, 0.0565012945298804, 0.08335595644894056, 0.08709703382919542, 0.023448131723853294, 0.027885299095942173, 0.0765963492449373, 0.10080592634039931, 0.04963771614711732, 0.1038852974306792, 0.027468950538604986, 0.02078064702800475, 0.037769527989439666, 0.034568812043289654, 0.050447729518054985, 0.04692850234278012, 0.010218856787105324, 0.03833083283097949, 0.05231467992416583, 0.06955905264476314, 0.036561326414812356, 0.013887185141356895, 0.0313658028608188, 0.07378147216513753, 0.058389926780364476, 0.018512092683522496, 0.02703411693801172, 0.0627440441166982, 0.05835713498527184, 0.05880382996110711, 0.010092031170643168, 0.007735219696769491, 0.012257763737579808, 0.010902385001827497, 0.008185931546904612, 0.03885090023686644, 0.021461046162585262, 0.022739857522537932, 0.031906494550639763, 0.08883905480615795, 0.010661355845513754, 0.035517833384801634, 0.012968172541150125, 0.04643865890102461, 0.04318719860748388, 0.0652232626453042, 0.03824165265541524, 0.056146633287426084, 0.04325979178247508, 0.0404847309255274, 0.032370863773394376, 0.02083541938191047, 0.054040904287830926, 0.04242257869918831, 0.08435918425675482, 0.014183728799253004, 0.0781248469138518, 0.06388513327692635, 0.018767265319183934, 0.13083306548651308, 0.04860370034293737, 0.025223042830475606, 0.1924272408359684, 0.0556136488012271, 0.09337569965282455, 0.03647717800049577, 0.050599049718584865, 0.028524202898552176, 0.07444157541613095, 0.059394316049292684, 0.027578873741731513, 0.08299709836137481, 0.07918122733826749, 0.03593344350520056, 0.03669328027172014, 0.020801033824682236, 0.02902699310652679, 0.043098255919176154, 0.007776348129482358, 0.021524082330870442, 0.034179177091573365, 0.02637139205035055, 0.04722588091681246, 0.021905689100094605, 0.011858747111546108, 0.027924170935875736, 0.08449701592326164, 0.032281524036079645, 0.03323414479382336, 0.04650012357160449, 0.05168969139049295, 0.05187727292650379, 0.0442215075599961, 0.0692296281340532, 0.0202854341478087, 0.06298622174654156, 0.036553934623952955, 0.023625605208508205, 0.037368668054114096, 0.021632601019518916, 0.03657539753476158, 0.02970370933326194, 0.029766196312266402, 0.07656835543457419, 0.10868906349060126, 0.06173368798044976, 0.01216709741129307, 0.014006651435920503, 0.03811329079326242, 0.024137570217135362, 0.04838684108108282, 0.047575818389304914, 0.016714896737539675, 0.01476936680774088, 0.028391200758051127, 0.034806236217264086, 0.04596409999066964, 0.019070835260208696, 0.03569905100448523, 0.0027874969327967847, 0.01714137746603228, 0.030035389972908888, 0.03861998840875458, 0.06830804399214685, 0.07949620223371312, 0.062258033867692575, 0.0035644715126181836, 0.08691738956258632, 0.018698145395319443, 0.01492973935455666, 0.011908548931387486, 0.049654629692668095, 0.02608499169582501, 0.05266471387585625, 0.01453943832530058, 0.010309119570592884, 0.01884808334580157, 0.04477575457713101, 0.05032958331867121, 0.13417937967460603, 0.1025393680902198, 0.1376377878477797, 0.2711566264042631, 0.10600458917906508, 0.09145544448983856, 0.1728096802253276, 0.1483041123719886, 0.09312788912211545, 0.16546939441468567, 0.14121112501015887, 0.102871612762101, 0.15914533141767606, 0.12449808549718, 0.08476179937133566, 0.14577889553038403, 0.2084080403437838, 0.08760729746427387, 0.12918756081489846, 0.2109864098019898, 0.26694758038502187, 0.15896046243142337, 0.09835450124228373, 0.18049856764264405, 0.1329594966955483, 0.17446631711209193, 0.15742207935545594, 0.17821532062953338, 0.11626523351878859, 0.12646937073441222, 0.11010983842425048, 0.22688521683448926, 0.32855759316589683, 0.11629155007540248, 0.1022514518990647, 0.17551409604493529, 0.08793364206212573, 0.12954992183949798, 0.14053067949134856, 0.23851082660257816, 0.1500620524166152, 0.08541836999938823, 0.11496746956254356, 0.163696552044712, 0.1938462271937169, 0.12635295744985342, 0.19896277139196172, 0.20177031605271623, 0.09540639381157234, 0.1421708258567378, 0.12618774053407833, 0.1416867526131682, 0.13236637227237225, 0.09568619832862169, 0.08271621030871756, 0.16507078689755872, 0.12931092060171068, 0.12006361954263411, 0.12341018606093712, 0.1291436405153945, 0.24958696507383138, 0.23368327470961958, 0.12848787882830948, 0.17506822856375948, 0.30346623330842704, 0.20113094098633155, 0.12850232102209702, 0.1159131141321268, 0.10655788995791227, 0.08306911637191661, 0.17592141637578607, 0.22961225331528112, 0.10429831745568663, 0.11513151388498954, 0.1562502430169843, 0.25993256305810064, 0.16975063655991107, 0.1653997364337556, 0.07675344706512988, 0.0930443975084927, 0.0992976373527199, 0.15834207530133426, 0.13803661800920963, 0.08878374253981747, 0.11744256917154416, 0.12965846835868433, 0.1411672937683761, 0.12340440473053604, 0.14033206593012437, 0.17189216305268928, 0.19645002263132483, 0.2632143994560465, 0.21021071705035865, 0.17013937351293862, 0.17045202548615634, 0.08362379754544236, 0.1930625637760386, 0.11847594301798381, 0.1036896301957313, 0.33270985004492104, 0.20433121535461396, 0.18526464002206922, 0.12899543362436816, 0.1366768847219646, 0.22242143604671583, 0.16166845540283248, 0.17145871912362054, 0.1586074524675496, 0.16952457837760448, 0.22987731877947226, 0.12727422988973558, 0.16503790975548327, 0.14845647529000416, 0.12365060480078682, 0.10379654399002902, 0.08525428856955841, 0.09438215580303222, 0.14518995682010427, 0.13608570472570136, 0.19206802651751786, 0.12858303700340912, 0.06820164970122278, 0.1014300280075986, 0.16779532976215705, 0.25109399983193725, 0.10724053965532221, 0.1946081456844695, 0.09749789955094457, 0.22074826410971582, 0.16977279708953574, 0.15564718865789473, 0.17139842704636976, 0.18127221206668764, 0.11684692886774428, 0.1031129146576859, 0.14730822440469638, 0.18241393205244094, 0.09956738576875068, 0.09010732581373304, 0.16605937213171273, 0.17545234935823828, 0.1640873373253271, 0.12675953563302755, 0.13343144324608147, 0.18747193564195186, 0.13398217619396746, 0.15153104468481615, 0.1536121455137618, 0.1525050392956473, 0.0988417879852932, 0.16125295660458505, 0.15276011545211077, 0.10510561085538939, 0.15164699783781543, 0.08364617329789326, 0.08272264472907409, 0.19571534096030518, 0.11451290411059745, 0.2070814068429172, 0.1656503151752986, 0.17950373352505267, 0.1838520064484328, 0.12592907238285989, 0.15876227931585163, 0.2166658581700176, 0.12230937325512059, 0.14067496784264222, 0.1240106948534958, 0.1337177786626853, 0.09099808856262825, 0.09577878867276013, 0.1707028565579094, 0.17504370800452307, 0.13347885163966566, 0.1982668595155701, 0.19797096523689106], [0.07761928849504329, 0.029326060066523496, 0.027137210527143907, 0.02796086271700915, 0.023261631868081167, 0.032363460850319825, 0.057234131963923573, 0.01283949619391933, 0.03845920211460907, 0.050048557968693785, 0.02387278862443054, 0.040881015520426445, 0.07793070850311778, 0.06380163424182683, 0.0809957116143778, 0.0663440021162387, 0.029760392717435025, 0.04350396207883023, 0.004573334308588528, 0.03195932433300186, 0.010635250800987706, 0.055777815578039736, 0.04315984304412268, 0.06809661354054697, 0.013126068170095095, 0.0564962924545398, 0.015183361829258502, 0.004401248352223774, 0.04435995520907454, 0.027845082113344688, 0.021953637406113558, 0.03242251725168899, 0.040341333151445724, 0.05293350121064577, 0.05345104531443212, 0.03844010294415057, 0.025499318435322493, 0.040443526886519976, 0.02477536636433797, 0.04252782637195196, 0.043737731175497174, 0.04021769134851638, 0.01360162248602137, 0.013558609462052118, 0.020561923120112624, 0.06829440331785008, 0.041674037420307286, 0.04855861858231947, 0.026752301200758666, 0.009330570956080919, 0.09340361924842, 0.017425219266442582, 0.0075702926824305905, 0.06605686518014409, 0.011964396471739747, 0.052029008729732595, 0.02008285195188364, 0.011493104866531212, 0.07225093359011225, 0.07087424222845584, 0.04517642155406065, 0.06975113530643284, 0.03660009620944038, 0.02295256817888003, 0.057385418767808005, 0.0836964463815093, 0.029196176801633555, 0.1143495351425372, 0.030965683217800688, 0.09569477013428695, 0.02394766575889662, 0.03200814280717168, 0.04140593286138028, 0.035462131490930915, 0.038309562878566794, 0.07891473695053719, 0.10859731177333742, 0.037716943115810864, 0.07706626973231323, 0.08018490043468773, 0.0442692239448661, 0.06064299064746592, 0.03331286439788528, 0.07538291552918963, 0.08366191425011493, 0.029329457247513346, 0.028701156879833434, 0.05033805864513852, 0.06200017836818006, 0.02700258122786181, 0.0359498783654999, 0.0493961062602466, 0.017124400837928988, 0.051612392999231815, 0.03772730349737685, 0.02661552523932187, 0.029876742919441313, 0.010949072584480746, 0.04515905529842712, 0.04389329274999909, 0.07598879004945047, 0.020471861644182354, 0.016510833956999704, 0.029730476744589396, 0.08820055547403172, 0.026444842405908275, 0.07777221544529311, 0.049875125478138216, 0.036913657313562, 0.031041397123772185, 0.0016173923495443887, 0.03472080017672852, 0.028822878375649452, 0.11737366818124428, 0.026245015433232766, 0.05598956886387896, 0.06849767756648362, 0.04505596727540251, 0.04430374123330694, 0.06487057180493139, 0.00726781137927901, 0.045564431202365085, 0.02808517059747828, 0.032982311822706833, 0.04103352315723896, 0.0170738049200736, 0.04578706808388233, 0.03977530082920566, 0.0011402849736441567, 0.0313758292759303, 0.024486156980856322, 0.005595866768999258, 0.08564091782318428, 0.04931737552396953, 0.04493315296713263, 0.0006015458279762242, 0.04166351747699082, 0.04733696558105294, 0.045036567535134964, 0.04527924982539844, 0.024201012711273506, 0.020225626321916934, 0.02566352231951896, 0.04615161473338958, 0.07582326143165119, 0.06583487396710552, 0.021737870956712868, 0.012831590465793852, 0.054670932004228234, 0.04015876853372902, 0.05863751837750897, 0.04791018560354132, 0.05595102171355393, 0.0865849074034486, 0.02828229800797999, 0.05664032847562339, 0.03452742246736307, 0.026674744913179893, 0.052393110090633854, 0.032565239671384916, 0.02747984526649816, 0.03652856430562679, 0.038649544439977035, 0.047434977313969284, 0.05725342038203962, 0.04779894879902713, 0.0399679957627086, 0.0348725842195563, 0.05510409020644147, 0.04508833975705784, 0.05844145780429244, 0.04588940653775353, 0.0039414609636878595, 0.016139774961629882, 0.05882923738681711, 0.013793801626889035, 0.012986948877369286, 0.004837127453356516, 0.03603016761189792, 0.020727154878841247, 0.02968007007439155, 0.05081294038973283, 0.037513550123549066, 0.034958324540639296, 0.04038800310809165, 0.07072905587847345, 0.02749068989942316, 0.018413006691844203, 0.08316599632962607, 0.0496016663237242, 0.004862302494075266, 0.036145419435342774, 0.02842613735992927, 0.035769302703556605, 0.014172331266308902, 0.05849146000400651, 0.03010697753779823, 0.028380905314406846, 0.008380758299608715, 0.012409960600052727, 0.05836242278746795, 0.02233453171356814, 0.011689621860568877, 0.028113631960877683, 0.0620450523274485, 0.014862122279737378, 0.08705139916855842, 0.04294023041438777, 0.016657515734550543, 0.04317767314205412, 0.07779212726745754, 0.057434808695688844, 0.0161028327056556, 0.03744145047676284, 0.023418069176841527, 0.043692000035662204, 0.06651082207099535, 0.014726715580763994, 0.02724535999732325, 0.062205912836361676, 0.022205229179235175, 0.05447922412713524, 0.0676021353865508, 0.013024128620600095, 0.0400057970546186, 0.010114072028954979, 0.08724376384634525, 0.034285419242223725, 0.020109641627641395, 0.03269147528044414, 0.04451218082976993, 0.05878607407794334, 0.04866563256655354, 0.026015350413217675, 0.06622936998610385, 0.06975866810535081, 0.037888323568040505, 0.03371133832843043, 0.04257631087966729, 0.03471506337518804, 0.0693955946189817, 0.0403390584688168, 0.043414596366346814, 0.07207706323242746, 0.07419137516990304, 0.01953967963345349, 0.08436135874944739, 0.03491050796583295, 0.06056618207367137, 0.07123062896425836, 0.06255421758396551, 0.015555245536233997, 0.04460912387003191, 0.017068005035980605, 0.049686946513247676, 0.040674739284440875, 0.03189164417563006, 0.062333680980373174, 0.04825430834898725, 0.008818889818940079, 0.08025190894841217, 0.015625529704266228, 0.09131928265560418, 0.04408935332321562, 0.06624179353821091, 0.043769762269221246, 0.03413510836253408, 0.027538936919881962, 0.04237858789565507, 0.02576259161287453, 0.07075178044033237, 0.04303388202970382, 0.05346482328604907, 0.04262034621206112, 0.06915066362125799, 0.02512455241230782, 0.0045824293283658335, 0.02344242275285069, 0.05067093043180648, 0.05553286973736249, 0.0745435019780416, 0.05924347824475262, 0.018039884525933303, 0.055300239837379195, 0.021047404588898644, 0.03247502419981174, 0.019205811513529625, 0.024481349719280843, 0.02367096156376647, 0.05953285646683071, 0.04419603705173358, 0.042076066238223575, 0.01959195466042729, 0.0775146679370664, 0.011355352053215029, 0.02923134532466065, 0.028474124628701247, 0.020846618390351068, 0.009614417394914199, 0.07597506773890927, 0.004492403104450204, 0.028724293333652895, 0.025754884409252554, 0.046764001599512994, 0.0243181143378024, 0.015939890472509433, 0.027970762967015617, 0.0048927129228104604, 0.017140512863988988, 0.03791917835769709, 0.02882695091102505, 0.021612768978229724, 0.017898978512675967, 0.06112706760177389, 0.01042839383444516, 0.028103566583013162, 0.06089624483138323, 0.040678594741621055, 0.05005938590329606, 0.03985681833000854, 0.011405960030970164, 0.03906270176230464, 0.07039913412882015, 0.007685807040616055, 0.05525837899767794, 0.049773840873967856, 0.04716195231594611, 0.03940930328099057, 0.04769456201756839, 0.03066806344577344, 0.02726620321482187, 0.017140765194199048, 0.048836705027497374, 0.007963392072269926, 0.006671242927041021, 0.02796090910123894, 0.015544303496426437, 0.06423323764465749, 0.07207761242170818, 0.013994894889037823, 0.06313391655567102, 0.07280654986971058, 0.03475938443443738, 0.06072300900996197, 0.13114027009578422, 0.05284199440211523, 0.07908038431196474, 0.03736877566552721, 0.02871011645765975, 0.008444122868240811, 0.019997640411020257, 0.033917128457687795, 0.11321222351398319, 0.11110091727459803, 0.12477727403165773, 0.08126535612973385, 0.1529982261126861, 0.09661429110565223, 0.19505129690514877, 0.10747948152129538, 0.19719475298188627, 0.06852138918475248, 0.18875779554946348, 0.0889174552867189, 0.12018768436973915, 0.1601863419637084, 0.23370046284981072, 0.153869136411231, 0.09768521020305343, 0.11633176705799997, 0.10149863956030458, 0.20692959311418235, 0.22363273979863152, 0.11684970450005494, 0.08751233224757016, 0.17661758058238775, 0.0963750301161781, 0.09686950827017426, 0.06459910902776755, 0.09248502596165054, 0.15982951736077666, 0.07686225333600305, 0.14989060146035627, 0.12055164843332022, 0.14024738688021898, 0.1989062494249083, 0.22724928479874507, 0.1661668499582447, 0.0752751185791567, 0.11391113366698846, 0.09558663921779953, 0.11255929683102295, 0.1443845930043608, 0.05739271407946944, 0.13028349028900266, 0.22408162039937451, 0.15376018913229927, 0.17768394289305434, 0.091110308712814, 0.1657258064369671, 0.12264592238352634, 0.10649470350472257, 0.16370005498174578, 0.14653236838057637, 0.07408031277009286, 0.1535740733379498, 0.12139847603975795, 0.1873343117767945, 0.11410992534365505, 0.11530068644788116, 0.18271147389896214, 0.14559735136572272, 0.15318006713641807, 0.21182468044571579, 0.05281911027850583, 0.10847689089132473, 0.19514301151502877, 0.1655039339675568, 0.1284593655145727, 0.12340158456936479, 0.23945670865941793, 0.20018896262627095, 0.09386067089508288, 0.20351817773189396, 0.12772530724760145, 0.16091818863060325, 0.12001661933027208, 0.1167147301021032, 0.35408153606113046, 0.13682504708413035, 0.17291214113356546, 0.1761815242934972, 0.0802073949307669, 0.16199293721001595, 0.1908086909679696, 0.13102816126774997, 0.21766536781797186, 0.12698455480858684, 0.1390853914199397, 0.09728551915031858, 0.2927227254258469, 0.18161720683565363, 0.09260783655918203, 0.18925838900031522, 0.1760763768106699, 0.16193360992474481, 0.20456429425394163, 0.1633340574335307, 0.13301392580615357, 0.12232727385708131, 0.1692117631318979, 0.13111260283039883, 0.11408060308895074, 0.11921077311853878, 0.14101366919931024, 0.12491672358009964, 0.14214020484359935, 0.12601152498973534, 0.0997810203989502, 0.1573341348557733, 0.1510486486949958, 0.1655856889556162, 0.08456264404230751, 0.21907629445195198, 0.11557994919712655, 0.3528684808406979, 0.15063503495184705, 0.14878163987305015, 0.17073177063139156, 0.21818148699821904, 0.13334790710359812, 0.15018475911347196, 0.11570437025511637, 0.08970560869784094, 0.09957464397302829, 0.13836256926879287, 0.1223657839000225, 0.11420463080867194, 0.10635148384608328, 0.14575081266229972, 0.08491190616041422, 0.1371367639512755, 0.14687875838717446, 0.0987625117704738, 0.1652253168867901, 0.07513569129514508, 0.1893630318227224, 0.13016539975069463, 0.08557412453228608, 0.1770972751546651, 0.10257510250085033, 0.17065849096979946, 0.15448514866875485, 0.1533808626118116, 0.08312935649883002, 0.15472734114155173, 0.15087880077771842, 0.2003392030019313, 0.2645366988144815, 0.055975623909034766, 0.13691538129933178, 0.15801817236933857, 0.15061854443047196, 0.14392317010788247, 0.21328849252313375, 0.2689991140505299, 0.08875295825419016, 0.13163192808860913, 0.10742331578512676, 0.09275464079109952, 0.1106928547960706, 0.11051529596443288, 0.15042552666272968, 0.12226958671817556, 0.12675471167312935, 0.1284944245708175, 0.14424492081161588, 0.18554931302787736, 0.14070211560465395, 0.19928380963392556, 0.18790968402754515, 0.26617464842274785, 0.1617296677432023, 0.12938045983901247, 0.06251405255170539, 0.09937896189512685, 0.16303555079502985, 0.15287373826140538], [0.028882714032079093, 0.08222692718845792, 0.024557905962865334, 0.01699918011581758, 0.06427005559089594, 0.005946876644884469, 0.026511756295803934, 0.01213514146002126, 0.019295346064609475, 0.03333226042741444, 0.03911220301233698, 0.022764443019696046, 0.03789000453252811, 0.03164512127113994, 0.05445016904559452, 0.034566804533824325, 0.015649406450393144, 0.09068860555998981, 0.05197752223466523, 0.06242219693376683, 0.003541172018231009, 0.04773001070134342, 0.008316903913510032, 0.024995483654493, 0.013511491433746414, 0.030763650211156346, 0.06104461499489844, 0.03253592483815737, 0.01966553674719762, 0.061372599739115685, 0.02456355927279219, 0.015737276735308114, 0.0641252106288448, 0.027886091338586994, 0.1002805600001011, 0.04690816378570162, 0.049750303660403006, 0.04366507491795346, 0.02077060391457053, 0.023377794677799102, 0.032376819508499466, 0.03053453994652955, 0.025612425451981835, 0.0606538408464985, 0.02133545436663553, 0.043872364185517654, 0.0406576030945871, 0.017244148220925126, 0.015210691417451017, 0.08165677223587409, 0.05017399576900061, 0.05425162969913799, 0.00811661031548283, 0.0210927405350958, 0.05995067818730604, 0.02602376636787085, 0.0333516564569436, 0.04317917970183771, 0.03303985795355402, 0.010690243943827227, 0.03338411057484336, 0.040223580290330574, 0.02252022077300353, 0.04094847674423363, 0.030815505924692843, 0.045186466522864066, 0.02230835430964362, 0.09751849414897151, 0.0370932570513105, 0.012062804325978504, 0.02556574807385914, 0.004360374105090159, 0.04075831253430806, 0.04290369077352807, 0.013609081070171669, 0.04419376979058143, 0.020677885549957864, 0.11424610202084295, 0.007039640859147767, 0.02553669299231842, 0.020167306502116844, 0.015405655467475299, 0.08953575335908681, 0.12946930975886062, 0.05305396291078068, 0.005704711538783158, 0.04547492448182311, 0.033917748150997795, 0.0620421319763409, 0.003445015886427427, 0.05792270399979316, 0.057114030205411837, 0.03302934543171432, 0.02475341178069357, 0.04252404141880106, 0.06099385580455419, 0.02994038393808296, 0.007346992506427341, 0.019121037839795463, 0.024007544088817667, 0.041449560012551956, 0.037169460774748586, 0.07243467451189645, 0.02402205307589611, 0.022420539207814727, 0.08730678702704608, 0.005696717680621077, 0.04654393625969533, 0.009223574597854167, 0.047371575637953356, 0.03805067950452212, 0.06510819264804013, 0.022495382945635356, 0.017454220542276744, 0.05983722978271544, 0.01883199543954106, 0.022745026581105776, 0.034617641649674624, 0.06581355206435546, 0.08606373419752344, 0.009429246911167866, 0.12331822654232383, 0.0277661788277328, 0.013339110009837896, 0.018857260001823306, 0.06490030224085785, 0.025610816846892703, 0.01732320735754911, 0.025550161117280368, 0.030448159523075446, 0.004014464639112703, 0.02760843348369235, 0.05362750205677003, 0.047856814053375274, 0.04818461326067336, 0.03215131422621198, 0.016032091189117637, 0.01744611628964776, 0.017092022790166084, 0.07576766714919358, 0.041937577771022916, 0.019726537575479597, 0.03129585544229485, 0.04408602479088586, 0.01955644660483813, 0.028194411024742294, 0.026077329021063633, 0.06565929666976444, 0.021269553508318495, 0.06768204242689535, 0.03097668926784536, 0.022107881668489426, 0.023951979492267128, 0.07010293556959368, 0.01994098856812343, 0.029153796458558645, 0.02086174707073951, 0.00681563842590549, 0.0725543977750931, 0.014217151419870788, 0.03913177344657015, 0.01551683475554455, 0.038325274144881405, 0.05645145931339357, 0.015159689173742663, 0.06644186170888133, 0.011369388848834205, 0.06677934594335966, 0.0073636504748719744, 0.05908648803597316, 0.030004893269506283, 0.08947875641752034, 0.03536143689416349, 0.03261593577917665, 0.03379261834197678, 0.010385076529928483, 0.03171780721459072, 0.010706684370234143, 0.041243892337661237, 0.0761337685980834, 0.031970794225344434, 0.06608661045902409, 0.051709673716686666, 0.05404500836448278, 0.0348293838032987, 0.022559970202564728, 0.09565314307110384, 0.03181075750035234, 0.06061706371838227, 0.03746424183191266, 0.12760654877638444, 0.049544888315722346, 0.047758423825143836, 0.008828878198983148, 0.05521907856746111, 0.06426896463381127, 0.01447713688321528, 0.06039790008799173, 0.05201025094720535, 0.04017694001959171, 0.035746006687986664, 0.006887478321004892, 0.028209652882651426, 0.04957289696903899, 0.046680676969117485, 0.07714675564784557, 0.008253433588834014, 0.030728277597518172, 0.06124903586169239, 0.022547249791387003, 0.08582811715314165, 0.039956963737495244, 0.01577790560986614, 0.024025259153859224, 0.053253711957950145, 0.030583924308302812, 0.06564554467331618, 0.050623689021449536, 0.017244528571609408, 0.03885100784827955, 0.04687785076384898, 0.06285923285759054, 0.02832373953424394, 0.008872995167621411, 0.03716476297995541, 0.059726805629907176, 0.03036762536794413, 0.04757548442285042, 0.019471602427074686, 0.05390982987591997, 0.056772085663396865, 0.023259472218342125, 0.08301529582240619, 0.06413745606550947, 0.017839955507952254, 0.058192919968860224, 0.03370672216988169, 0.059782852622447535, 0.059922146319877356, 0.02324296499864431, 0.04101481732504908, 0.08138746168697253, 0.04422617195814382, 0.03561423465725966, 0.036615536591853015, 0.05892606539418921, 0.0728800002252683, 0.025782804004848003, 0.01789746824215399, 0.03172964818077162, 0.04029261486721225, 0.027313042010064237, 0.007718002798355883, 0.03206143643183168, 0.04017730738269165, 0.022578959906240925, 0.02811309946991969, 0.017886974274006207, 0.012915249990328448, 0.043749642645707354, 0.05086084231152199, 0.025562961309333332, 0.1025790284620598, 0.04026735587103758, 0.03757597216463182, 0.05947508027020376, 0.0867049943190068, 0.04795160857611336, 0.05032298562582582, 0.05361836250813212, 0.047743157847435214, 0.040301891713170335, 0.04914650344289839, 0.017219546025444288, 0.017332001807517372, 0.0348392321029678, 0.04293553633033298, 0.023494875895266887, 0.03208782720321324, 0.015003545940999174, 0.1574928208719939, 0.05962290124443825, 0.018029121529252734, 0.03392909187823534, 0.025947531103156507, 0.06938879654626362, 0.0359423307236284, 0.01942999762832187, 0.025565731375536416, 0.04560077788482886, 0.015372443431260763, 0.09437920205527917, 0.0514078311243793, 0.07621272568940185, 0.006228774946066551, 0.05380211827286985, 0.02498808073141845, 0.1111306031816639, 0.08331618475494906, 0.030218229185265955, 0.016144311339303385, 0.050406028240104206, 0.00926210783291026, 0.008676547749928432, 0.05844266379426699, 0.0211773509363411, 0.02101729936839547, 0.08452153648249805, 0.07177015548222698, 0.06218853915925138, 0.027478912015794776, 0.026708210207289085, 0.07908126004622318, 0.01952265105501283, 0.04444597754627466, 0.00855468524605385, 0.03427910356549546, 0.04215045541059226, 0.026938207338389475, 0.03472469645203091, 0.012767986554536037, 0.04037642931507435, 0.03465107540250756, 0.01004844854833209, 0.006345603369481978, 0.045998305577086285, 0.05680641370418016, 0.04175710229901597, 0.07273600873304531, 0.01913852469442645, 0.03212269701180048, 0.09668478029198013, 0.058772674601641484, 0.012152850031270646, 0.014639165347034577, 0.024189021460188087, 0.05635189278109465, 0.02074055992125068, 0.008213069104385795, 0.033401625260012224, 0.05089152640721295, 0.08555810156394728, 0.05392927414504811, 0.016695728918421082, 0.030411460320465267, 0.02555742859840393, 0.04691491361882072, 0.061419317935360596, 0.062132087696227245, 0.015205699546640972, 0.07419468514854088, 0.02700232704228256, 0.09572259325068444, 0.09068362574907951, 0.1269052637508139, 0.12908606469864026, 0.19534417806426063, 0.07463586967787705, 0.16210087516810745, 0.10923838635790162, 0.22182679764227942, 0.15580908075207844, 0.1488564335159026, 0.07402828821795993, 0.11221388645935804, 0.14014350104844198, 0.26876830612309277, 0.1275809743674472, 0.1377370723639615, 0.15574372722767293, 0.15663645666791126, 0.1787488505942747, 0.1535735686775297, 0.18036756373476237, 0.08829671554849483, 0.1510324698756449, 0.12308468008995987, 0.0801016240438912, 0.24226273933891207, 0.1576473657041788, 0.1116002861817833, 0.1722663687542081, 0.11789188021793962, 0.0887666063499637, 0.14454860764089972, 0.10902780937612988, 0.20937225344823673, 0.15704725024988875, 0.08594710569013841, 0.1563077000901103, 0.14388156530912966, 0.14153682393953204, 0.11079456613515504, 0.12754946277709678, 0.07063208686304279, 0.1378359115915373, 0.20221697021042928, 0.11362439749063924, 0.13093527406454086, 0.11249592484091409, 0.06345933346892707, 0.1379253700724803, 0.10352422032156028, 0.31594841508194804, 0.09922613884555176, 0.07020354853011668, 0.12116837315261364, 0.08493763642036356, 0.16566817124839872, 0.1966108163469471, 0.16736709570977837, 0.22131844132672995, 0.2022647051489912, 0.13891437090933323, 0.10584037416265346, 0.10456379110109992, 0.09553344949381426, 0.11353133959346451, 0.08217737398808822, 0.16490390757098794, 0.10295410247636028, 0.12708372058114037, 0.2189182466827333, 0.09234180630301125, 0.14293296699179336, 0.1310916742659174, 0.10704653483116999, 0.12021543327136897, 0.15777151216752827, 0.1626596529968083, 0.1432825333904475, 0.11335976247210056, 0.0932720661512576, 0.07169362521381117, 0.19273063080618158, 0.2146987957530655, 0.10199791198829189, 0.1397269038716331, 0.21220440772594884, 0.1021995757764671, 0.19050760165555403, 0.11982560536125675, 0.34876434481702745, 0.14229244901798666, 0.2389120019506663, 0.15747061581350863, 0.14568786369636655, 0.20341298572020605, 0.15365294879302382, 0.11382352313376032, 0.09514625620795414, 0.18198363482952118, 0.15001540101366118, 0.1346025225939229, 0.1817784903687425, 0.16710955562302843, 0.2745634998427704, 0.18273179390234873, 0.10835135661181994, 0.1637955248588696, 0.08568684934289195, 0.1786116571747698, 0.189207358926069, 0.11129630249342881, 0.16337928391294554, 0.1760551959159784, 0.08835669592372142, 0.2099278845707886, 0.1367821212625131, 0.14221600780729204, 0.1800969915348105, 0.21387772809248418, 0.13676270667929202, 0.282145191449672, 0.1308264455292374, 0.10907051255344413, 0.07111301340046339, 0.19587013812270015, 0.17051092232577503, 0.1394128566607833, 0.1433746042312123, 0.16131023556226864, 0.1294961606618017, 0.1525807086727582, 0.18611312261782587, 0.1592428793082945, 0.11188798715011217, 0.10031137397163548, 0.17234408645890653, 0.085994914843468, 0.12668692390434444, 0.09103606425924227, 0.09435029540327378, 0.13010519673116505, 0.12567482743179426, 0.12226407256093808, 0.1524639391573146, 0.14385182003024966, 0.12088844247045927, 0.13322439888725057, 0.12206951854750514, 0.18532910296926275, 0.10775557529996149, 0.2614188176812604, 0.15620374004356563, 0.17600122693693265, 0.15741103619802743, 0.1120638613065239, 0.08023414935451001, 0.0811813969630748, 0.1008297863882035, 0.054835080227348953, 0.11373812420060858, 0.11740888308850117, 0.11116730238427408, 0.1294182351557538, 0.14314176281914115, 0.19462137075606734, 0.14445214328588918, 0.14207350061042234, 0.08524775024852715, 0.13696728710783646, 0.1011917540745344, 0.16449302493128926, 0.11891255591763183, 0.09989672122173943, 0.11561817722395062, 0.07064165314659476], [0.005085284010419855, 0.07400473245070316, 0.03194951314071659, 0.06089260830776766, 0.024335239395441022, 0.07396314249490388, 0.02813685376167996, 0.023259709705598652, 0.11063432160881348, 0.03526365151628852, 0.07208280745544471, 0.0006906630949288228, 0.019930149501306005, 0.05545088468352333, 0.04068852838827297, 0.03920146853488404, 0.033713731754687615, 0.07061010444886051, 0.03681598696857691, 0.01271053133677924, 0.03903857454133686, 0.06578417043783702, 0.014458932928391732, 0.04067115471116267, 0.04671831498853862, 0.06441958350478671, 0.04704834434960503, 0.002864165426217369, 0.030059096025070176, 0.03636406356235966, 0.04744810961710755, 0.020774997428816278, 0.05999099535983987, 0.06153914138849359, 0.013618107441288885, 0.034520843328209594, 0.046318709282786585, 0.08074773038970307, 0.02262848156533437, 0.04587974748574197, 0.02678306136658648, 0.03042218249902362, 0.0922680516669061, 0.09894214861560613, 0.06043303706974257, 0.0327579902659636, 0.061476351984310895, 0.10336315943277441, 0.04500998380535748, 0.032421021824120544, 0.027998981277050916, 0.09391390514792874, 0.03725657406903338, 0.10142827653908171, 0.0059341172709537204, 0.039005281796562485, 0.04948531241097953, 0.08484632999170572, 0.06499696697574109, 0.09658896902692504, 0.05008540931157768, 0.030772793470532633, 0.005304445785441203, 0.09176124644000083, 0.015485672902286751, 0.013251423406472895, 0.011405890454625478, 0.026797414502652828, 0.08539342641597614, 0.03451254982792307, 0.14069733617361635, 0.01884505538328085, 0.03680861002067104, 0.020280031312722713, 0.0335091476154048, 0.013334235954971518, 0.026548386849754024, 0.06632998294662684, 0.08308159187436104, 0.09298269535065629, 0.050084385147783905, 0.034470559112378396, 0.05959629525023047, 0.0338828672101954, 0.03536337389959954, 0.049262675529462285, 0.023768774772179313, 0.07894873473560438, 0.016596856294199824, 0.042453043861314654, 0.03683025475766044, 0.00967844711340149, 0.0708547756948974, 0.054779010970378295, 0.020082642295164987, 0.07838941513909958, 0.03272112036938779, 0.016446972149424255, 0.08911627664929256, 0.007876687886891887, 0.08028781405300833, 0.04578737236442976, 0.08252801650087349, 0.013492600064637372, 0.007742344778307597, 0.04626201662176754, 0.03382015202078037, 0.06663113163085654, 0.08713341390830465, 0.03390604077139869, 0.016193153933272697, 0.03946773627831135, 0.008859202353050932, 0.050279955903533846, 0.028996349828958046, 0.005026556009397609, 0.014490780340565834, 0.0377045418281341, 0.014925002597010462, 0.033133401957456954, 0.022954341911827214, 0.026900266893790103, 0.08529431259375997, 0.03617983282310888, 0.04531144048087299, 0.043851123919012025, 0.03335266577778384, 0.05533549927349668, 0.038485522381961346, 0.030506544280797243, 0.07175474107498303, 0.05494866221852135, 0.0437454495113343, 0.06543051480548456, 0.051036378790740855, 0.04734544832899701, 0.029245485093269963, 0.02705711423914181, 0.01861703236500034, 0.04993057133106049, 0.05371963226934895, 0.057635040138848126, 0.04377082354039885, 0.03890436084475368, 0.09871416084934026, 0.017431876331102103, 0.05162622663192451, 0.043050691674579866, 0.07711926649790257, 0.03134412472718395, 0.005458121841002139, 0.05720867258787621, 0.06925621186383069, 0.02246657277282793, 0.022855964671180118, 0.041219561026082374, 0.04844293631322216, 0.014422574186028214, 0.02656181972270133, 0.07105845812475309, 0.059342562381061725, 0.02126528986991616, 0.10957078688079491, 0.0488264299929142, 0.08321827321196906, 0.08633896708488464, 0.05434521081042476, 0.03064958396862494, 0.053292993834475055, 0.017993227556871716, 0.015190064350463217, 0.0681066102697514, 0.038154045832925476, 0.040159525524359196, 0.08132460920023732, 0.020141257118666545, 0.06296901134192012, 0.06484994752099738, 0.039487206522608176, 0.07128787823603489, 0.05400624970206991, 0.03791102957620751, 0.08505483638145961, 0.04804660347872414, 0.0858634062751662, 0.07471640754374675, 0.0812633078021463, 0.06807027471950278, 0.01827859818149591, 0.06159528114949353, 0.07430973288137466, 0.04507832447416149, 0.018947364151244983, 0.06435356204747222, 0.02649442158144666, 0.039731799843139015, 0.06423452898161486, 0.0251730035233777, 0.004524456926446874, 0.02487965666659875, 0.01531893551145913, 0.034501484406064264, 0.01992316589166876, 0.014162287225190084, 0.06308351730694994, 0.04855695988226216, 0.0439096905029146, 0.0475763972644927, 0.012188668861199403, 0.05105850592372008, 0.04161660632234998, 0.0818386281025596, 0.01993542246054858, 0.07806593523127958, 0.048215683273156174, 0.015395194895972963, 0.05993877784931101, 0.06741521807271056, 0.049178189437952824, 0.05570296256337315, 0.05883098143385723, 0.05624286386591848, 0.039061477218638174, 0.035077695283689536, 0.02292383407620946, 0.08279095942270942, 0.016632568440400064, 0.02606914313219022, 0.07813770833308809, 0.09376523812534288, 0.08316076418850571, 0.06716639079968445, 0.042402666877023876, 0.10718872290453874, 0.040105827429215424, 0.037117209867574275, 0.03083871844864916, 0.040036596183199435, 0.052943568443879485, 0.06544192903675139, 0.04187497390375938, 0.03475365134363528, 0.04926159199385438, 0.044341609318507835, 0.03285910788690671, 0.033529638312757015, 0.07212849406641908, 0.05985698204312939, 0.01748640377627453, 0.01701247012533713, 0.09690148741356097, 0.013868116584490053, 0.035139879837515764, 0.07344442579778843, 0.08930946511100046, 0.04777258771355264, 0.02075451415294083, 0.03664919298898894, 0.012845242272305768, 0.04811064340174198, 0.009257296860596398, 0.043402974333730526, 0.08784748613834381, 0.00564331505302107, 0.017692375731712673, 0.04983857841580175, 0.06350464900606312, 0.026261756429448724, 0.03958090266678482, 0.042990522051695734, 0.037800612844876014, 0.01640967180719599, 0.04710618362878449, 0.07829199341358617, 0.013898660599807044, 0.04610507836332545, 0.02353521718760021, 0.03180856445396785, 0.039837214499129914, 0.08533123444067314, 0.020024214863951784, 0.045859253077651374, 0.012642477322515333, 0.0267873287157272, 0.012879556397820124, 0.016496304560860153, 0.0671035679988563, 0.015728656690043863, 0.047055554314283654, 0.09183028101688251, 0.058539536330499686, 0.022478120590676554, 0.02433016496070195, 0.042475939117139205, 0.05665399512508884, 0.06339578336337581, 0.01469802693463862, 0.020250462293915916, 0.14538662595441565, 0.0376741100626532, 0.03285940474597737, 0.07937463844427839, 0.040214043692685664, 0.0064268643654941116, 0.1122696662787348, 0.037372375081758946, 0.02729199841269292, 0.04975741343514528, 0.019077718679909594, 0.02690278648515232, 0.05520042097487021, 0.02627464011311531, 0.026936188696708996, 0.012752184375131037, 0.02774143376882421, 0.04131242967559956, 0.03793142379436176, 0.043054179768660106, 0.06404255764209665, 0.07072215390508063, 0.028240093924978282, 0.046362581342691556, 0.006042697650627815, 0.08381461855606176, 0.025239969363610726, 0.022798785903432872, 0.011419953225413337, 0.04750388572574593, 0.005866407891517156, 0.05369967591832392, 0.008264390471595107, 0.049386350729037076, 0.0705943041248247, 0.04102320359379519, 0.029397553007584065, 0.05793989956146106, 0.08563226438127458, 0.020792079812963493, 0.013873045372747583, 0.02807633161864942, 0.08209034975152463, 0.1234529263456352, 0.004540658010228071, 0.043365035744500346, 0.051913586212322116, 0.061750749955535866, 0.0142769713056623, 0.0656053054262884, 0.015713327629782725, 0.04081283070263453, 0.0743401757790707, 0.04348230992036406, 0.15596010780427605, 0.1055957400240004, 0.15833993791602552, 0.14868835191009566, 0.11562468585907482, 0.24923975870478898, 0.1643919147318229, 0.15772772545460612, 0.20016910275444388, 0.17229264078196138, 0.17581048014108092, 0.11962598990066908, 0.15293739968910813, 0.13670177635503933, 0.31436502817086875, 0.12245512363733724, 0.12691087438724935, 0.17150609783129767, 0.06557939705089666, 0.14276432135375217, 0.18135689111659303, 0.18886454607127234, 0.047203271387843415, 0.20056932815350592, 0.11721788396243937, 0.1471499985200353, 0.23253293096786365, 0.10217773437034339, 0.15212406520731747, 0.11631638975813985, 0.13315107469679788, 0.11861760416650213, 0.0875293422723189, 0.21618291299091652, 0.096374651620863, 0.12114047582144849, 0.18452903808793053, 0.17307085683569312, 0.0716108015330974, 0.11451458878582343, 0.1537302360520698, 0.16728703281842172, 0.17131627129856497, 0.17523930844618008, 0.18767017812933773, 0.0999968963151332, 0.18163380125770345, 0.1673010890954174, 0.08983328778413124, 0.13388517749262974, 0.06153842892672401, 0.15482184622669592, 0.1760755604482256, 0.20726391579955816, 0.14925409108400345, 0.18467222806066275, 0.20144460228038952, 0.14300574199296534, 0.1550532627152279, 0.20239844016032293, 0.14285737182945013, 0.09025122824823484, 0.13695510104298592, 0.2530973235843703, 0.1155486231436953, 0.10034089660621248, 0.0964007455331739, 0.09796110360184684, 0.13495109451469034, 0.1465167387505062, 0.23398525459924713, 0.10850571590708569, 0.10804718738654628, 0.13819662504829466, 0.24855867493897676, 0.15134843182750046, 0.11687785416143015, 0.19103235943475738, 0.19973959220806137, 0.19391110574360937, 0.0841454828332644, 0.15935335541144013, 0.08552662708098069, 0.23024325695587322, 0.19596035359427333, 0.11383125631255098, 0.17544069763971493, 0.1169328844116535, 0.1525244687218219, 0.12362701934762299, 0.1520110954879783, 0.14300520764663815, 0.11373302564607002, 0.1301277134916745, 0.1710050442488864, 0.31430892180651426, 0.15904156432952732, 0.09592996415449306, 0.1884201035136357, 0.2135244064265862, 0.20342065952718258, 0.10167682179599069, 0.15543506800895557, 0.2046754234470427, 0.09278903191443533, 0.08458545024041086, 0.17576154292328283, 0.15688084589783102, 0.1785938159446232, 0.11150730249937624, 0.19668235938297585, 0.17020132800098509, 0.12906722899060696, 0.1605642880895175, 0.13221009081462398, 0.1904168666806072, 0.08403315136092715, 0.14482205937383696, 0.16754443931858987, 0.12459348858101293, 0.17848513583885506, 0.17097044532420114, 0.2684328256873414, 0.08495783025864512, 0.18982188688823953, 0.16723805107176304, 0.18232428061310202, 0.19839042710373178, 0.29573234205599874, 0.1216629626287613, 0.17723096563713625, 0.25766191771253943, 0.15026128938188776, 0.23927501606522128, 0.14628530741902068, 0.11898993223439902, 0.10488397587323561, 0.25374186399858445, 0.10008421741076745, 0.06941268627997488, 0.12828861217712983, 0.11077803108491935, 0.14278554677730426, 0.12966943730134517, 0.15548525203485042, 0.11577448836760595, 0.10552380364970304, 0.15145393554121256, 0.18728745257249102, 0.13031952898018062, 0.11504940266604535, 0.2170937359915115, 0.1815067752613686, 0.12618744367500767, 0.1977562322281301, 0.10620482804370113, 0.15828825475182384, 0.11293794799712487, 0.16789989836979657, 0.22533498908160254, 0.12823859142372385, 0.1197470490296837, 0.16129549650941044, 0.18996578932274133, 0.19585851609008387, 0.14535682130372152, 0.21446636994369328, 0.1925171446055174, 0.20047108264407143, 0.07442446891218424, 0.07763091052765958, 0.1254438710748218, 0.07507366259233095, 0.14869583275867626, 0.2193271106807515, 0.1446780827245675], [0.02260699082398787, 0.027648323921312112, 0.05463129760755692, 0.01911613409902202, 0.032874522294150665, 0.0015572694587717706, 0.05695443876902573, 0.0611391275015194, 0.011924211958103115, 0.04835437212022953, 0.041393535284441896, 0.022348582424456254, 0.05344439938198775, 0.020330421284597833, 0.008705221553100273, 0.0019318969088999438, 0.03139414548058994, 0.02346468718315009, 0.10407656372990459, 0.008409145448240452, 0.04251833801390603, 0.018852671673812438, 0.009168274391413433, 0.023654240976611618, 0.01023768321829266, 0.07839403129764833, 0.05185147587326355, 0.006676808106931276, 0.033678238542051986, 0.061238196794874966, 0.030608682354795747, 0.02160673902835697, 0.06824133975896984, 0.020037985414091963, 0.025459554162807763, 0.03145173242955934, 0.02312871321919374, 0.04314922291086987, 0.014166679811751237, 0.08029239310417324, 0.03085222553636413, 0.06455930764786899, 0.026503514745854773, 0.0284839617961552, 0.027484880738484208, 0.049497331492602825, 0.05040076641307678, 0.07806266236002557, 0.060351601205184124, 0.04979959710908588, 0.018841250021068845, 0.08203107441659085, 0.04051014577271417, 0.011986208191956393, 0.08065354442805983, 0.012156530156062217, 0.03548049593518954, 0.025353386226925068, 0.04628194328688551, 0.0030217456423997646, 0.025584639442968182, 0.016963369635050185, 0.03273661270213779, 0.05593099114776123, 0.041438542830292135, 0.026065410129376687, 0.02922969033534173, 0.04368570662336424, 0.057668971130624413, 0.04193874294287525, 0.04648841619200539, 0.018197308891103603, 0.011640293159871362, 0.04073682735906914, 0.037444923727889545, 0.011841976429423084, 0.03771038624108769, 0.009486954459134722, 0.05088663565402385, 0.03851863330055494, 0.05491392970725428, 0.025069986004382372, 0.022570274923054967, 0.02559837288572453, 0.054882373588043265, 0.020714107922685798, 0.08048399336985312, 0.027676532954501454, 0.08994549309136346, 0.07702101356699131, 0.02412030971754575, 0.06609582051169127, 0.04446485036169179, 0.01222707500346587, 0.0457175362680573, 0.03761665298952721, 0.08373790275072679, 0.054378945133066736, 0.045747674885205925, 0.007500356859964086, 0.06688319466775283, 0.009950219737220323, 0.03212056704796851, 0.09835040458710864, 0.039435207945643924, 0.04361715444247238, 0.00883153137692716, 0.008101343410089612, 0.02278480755194323, 0.09016120573505759, 0.02954917748866137, 0.02618138925754465, 0.01976617939362768, 0.04532133702014107, 0.05476814963913057, 0.09504289730102755, 0.014594950971513754, 0.01438149167370284, 0.037480257378774695, 0.028149140016466845, 0.03335985718877055, 0.13282323838211596, 0.031167270935839042, 0.03135650375043042, 0.05094694257422816, 0.05049492639955133, 0.07210353564005345, 0.0230196342090494, 0.03142448818834964, 0.035945904164691456, 0.08915646394598298, 0.04038270046294201, 0.05469852876558434, 0.053656683303415775, 0.024827003144309856, 0.021774644374090713, 0.05373731393774506, 0.018296970047231298, 0.03288271931523923, 0.0420895176648628, 0.0415711423556786, 0.09262545514502563, 0.07046940809232183, 0.02275567083415808, 0.0279723604398896, 0.06668429166893475, 0.03883838020556141, 0.054305773082887754, 0.04369617461634334, 0.038696548363077454, 0.05114178602525499, 0.029781792545691133, 0.020273251793696545, 0.03676639295008499, 0.04301992594264448, 0.08897026651538908, 0.05526111381186638, 0.032769141034805216, 0.07666857505682856, 0.009972269872378092, 0.03863000369165093, 0.01938094908837229, 0.026442647504154593, 0.03204612592526246, 0.020389499950397294, 0.029052693680569064, 0.07891544941230677, 0.02004739028052427, 0.015997870759747457, 0.030703736629220657, 0.0724873595754616, 0.07588656662846915, 0.01356481474431348, 0.05115947511512786, 0.035727026261156425, 0.070089896034915, 0.026480975720915012, 0.03499860831652768, 0.03682513764942996, 0.04158607065619435, 0.01974351420358289, 0.018575314388726838, 0.04361703198810574, 0.051415768393781036, 0.027676158169924747, 0.053597433943650685, 0.04463431607291568, 0.12774498900398612, 0.02580502947239438, 0.016354674953618087, 0.04453049332369119, 0.021218233996478375, 0.02392322498053545, 0.040146853352780454, 0.04740041920740623, 0.04141817458730657, 0.03356215551320929, 0.05472224409459159, 0.07232538584503345, 0.03478253944194876, 0.008774798825470498, 0.05103639734443277, 0.016138563405547757, 0.010781716428027721, 0.05507567337190267, 0.0404048572818283, 0.03739344836503733, 0.019228831079090014, 0.06480103998910636, 0.01587632181326626, 0.018334574670006987, 0.03405720512091648, 0.05035909482103307, 0.014411768515856238, 0.07143886075937189, 0.010677289756131358, 0.008966547520685708, 0.04656090175558347, 0.08248840065789409, 0.01846932827902492, 0.01082755425159121, 0.02728936007770244, 0.05715412102290429, 0.042932341384585015, 0.04495130218856502, 0.010922544515779009, 0.03631986124673858, 0.054647706492687576, 0.05376692563004326, 0.05149520417035092, 0.025931346717698034, 0.021461220567289274, 0.041391386766918004, 0.020090145408175886, 0.026049706284538843, 0.025051619704754557, 0.01321441342952312, 0.03849421664199326, 0.07048973551718518, 0.059827322111232206, 0.039204960339702666, 0.014392851171578513, 0.03492578507575672, 0.09151648613624275, 0.0315203291393118, 0.1055701804580167, 0.020139281150477473, 0.023791399144101888, 0.015134412551560672, 0.03527791930537205, 0.04561189896776341, 0.005078663589301868, 0.10357789986301214, 0.006429920622395002, 0.04216047811496537, 0.03723587928107008, 0.011845774370158324, 0.007904046233306872, 0.02456428101140773, 0.013872348681616131, 0.006684266691081575, 0.01533244723759708, 0.05524905391212087, 0.008876864540070528, 0.060022718462278135, 0.03954635569243692, 0.03865990111080464, 0.08648227580124512, 0.03219306374376174, 0.07148647695430554, 0.05710508361516986, 0.06363746375427581, 0.038501530507346615, 0.04301274195313454, 0.060943326679989696, 0.020201128027110826, 0.07043923978926614, 0.02591219003079459, 0.03131625708192587, 0.00628698437139974, 0.018089289296767674, 0.03545430183294229, 0.09411323859239928, 0.024615927068225574, 0.04464702906261664, 0.05339902076229919, 0.021247266813588794, 0.024347071084775962, 0.0394764453812968, 0.032691805536160246, 0.023994215116545092, 0.05168798816157505, 0.029491458808479365, 0.05442172252514865, 0.04158223746344447, 0.024046434482443146, 0.017154116430901922, 0.037261565012158826, 0.046847741832607426, 0.022224992571864277, 0.08774220506893471, 0.017895683376991656, 0.029488659056369215, 0.026506698559387587, 0.05113853170769289, 0.0942748412489891, 0.13167002995032817, 0.020592219443642534, 0.06579994107596576, 0.03323842698591761, 0.03272491645475384, 0.014777100914216135, 0.04888484443654306, 0.04592142649926245, 0.03086754346441012, 0.04418360607814975, 0.002123892368217639, 0.06052625823940616, 0.03765553039556835, 0.04390899288409855, 0.05293892631016206, 0.11825006295111962, 0.009317652948084287, 0.04991752066416666, 0.03377715198439546, 0.07299701464944519, 0.00827617484901566, 0.02686838237423217, 0.02400552730250638, 0.0177083931339439, 0.02024979065026855, 0.01879775089037139, 0.080318650288973, 0.00757073982640577, 0.0030116528978396673, 0.03541553574905265, 0.05289496148179751, 0.023979474208317697, 0.022125207106000744, 0.017865509507828392, 0.03453203862591181, 0.08682210522238165, 0.036832681580563076, 0.025405791129742283, 0.08702914215973578, 0.06465193509939127, 0.013558262508013286, 0.05278435550280847, 0.02755060348135885, 0.08157283533364534, 0.04869561904342845, 0.08386572284507565, 0.12241685108165257, 0.13778465887298808, 0.09646891921875067, 0.06466142716817558, 0.1515853253658861, 0.0995890935882926, 0.17801553447498009, 0.1504472122178413, 0.12875542306574062, 0.110661031503696, 0.09445987350773066, 0.1903498952742666, 0.09022236612509005, 0.17492782906629145, 0.09087394209927879, 0.07762703651678748, 0.17199092806549743, 0.16250210988800973, 0.17083912971429527, 0.11006269720382988, 0.14012965257279575, 0.1631214321241714, 0.14845778146991506, 0.09886639018077403, 0.03876389826473314, 0.1655212853802368, 0.17027671536197886, 0.15355326351709664, 0.11247924136114307, 0.13447715900838375, 0.11277526180492714, 0.148266663600225, 0.13900826743338257, 0.14295956556452438, 0.09910173263051547, 0.16002385615138337, 0.1340704769245349, 0.11477247026050463, 0.18341510411119089, 0.12651746190385893, 0.11220823129406199, 0.16708414448658004, 0.1361491286661476, 0.07569643581518903, 0.15697098715463653, 0.07773490768158808, 0.13465620955685154, 0.12432633768185042, 0.11025957413949072, 0.2495926053961739, 0.11114952052594163, 0.12089738534996286, 0.16795146279037, 0.08247767662396654, 0.1666714361635968, 0.24372601707000285, 0.07479678955860436, 0.1640862092608586, 0.1022357183683198, 0.08003984024981037, 0.18907503399532288, 0.15810559736564755, 0.16700066771591082, 0.15210463578114286, 0.15559443680103868, 0.0907732178166043, 0.10178242198890075, 0.16989039781037718, 0.194911016151309, 0.16724020330002531, 0.13114303088514134, 0.07708071934757754, 0.12739931145915762, 0.1647958211833611, 0.11322459511575289, 0.0846537871984765, 0.11275912751443684, 0.07920495379948989, 0.16833056666655466, 0.17960975674213842, 0.1672776520717889, 0.10572619474260136, 0.09828263908275403, 0.07433407532516867, 0.14068773278268054, 0.06433226983062923, 0.16222230537096038, 0.14120921026915312, 0.27555515756830573, 0.14759421843336895, 0.17507735698018223, 0.22499180515296757, 0.23280840134248137, 0.0904336481471546, 0.14524448983138427, 0.09190541604766622, 0.09253628610167652, 0.19303676672279835, 0.16135161771671847, 0.09267971356166527, 0.16856116679264233, 0.10088167735375464, 0.15608658461133018, 0.17311336705461144, 0.20008256833534688, 0.07860222598537803, 0.14151101204333827, 0.16212097252719104, 0.1332766906125471, 0.1456656734808348, 0.1832972065312788, 0.14826503087533638, 0.17819744971347973, 0.11554007360246032, 0.14213935879524797, 0.28216356702614576, 0.12085753201972693, 0.13805946131469682, 0.09677053545601666, 0.13084234233247116, 0.07955098015372641, 0.20082536910194904, 0.2103726685163565, 0.17328511486994103, 0.15738666406832635, 0.24595045630121604, 0.08952173418947496, 0.08815123233944178, 0.14185257809003815, 0.17171967308968306, 0.17797027830965817, 0.14965419773943722, 0.1694624309311621, 0.14123776811175048, 0.0816438217589166, 0.05012960420572199, 0.1448831826564856, 0.08713525443454273, 0.1424235716694966, 0.18103470996720716, 0.11780568718677387, 0.28333200432825834, 0.1860837929416448, 0.09646735328715295, 0.22427138756029308, 0.16206124448217452, 0.0843351089861244, 0.22150454227812588, 0.10597783475532196, 0.1657732148305513, 0.18355091713601723, 0.1906316145323217, 0.12609279016032815, 0.11600911093410105, 0.16603418363956735, 0.17116307717515156, 0.14045230869669467, 0.12915881001390517, 0.16795734059996903, 0.10217109957011417, 0.17574474069988355, 0.16597798821749166, 0.14591798884794116, 0.14811517641646788, 0.09712995757581666, 0.08851918173604645, 0.14999077655375004, 0.14053593389689922, 0.15226927382173017, 0.1334125778521411, 0.14251773536670953, 0.16640837449813262, 0.1751917664660141, 0.170790103438776, 0.13438801222946495, 0.17981510900426656], [0.02141546159691643, 0.025600742192182224, 0.039374136613332666, 0.04220938564685639, 0.03636937362898607, 0.037820799261680804, 0.02598424700408941, 0.033002728305291384, 0.014729769518453395, 0.02243324663140811, 0.024442036301479675, 0.019301658030599356, 0.05354647437343374, 0.04251972583006136, 0.04270011224434711, 0.006286464404183789, 0.05082454015791882, 0.08171404377208091, 0.041959207665058784, 0.025012964943016414, 0.0361722146772081, 0.1143921418406535, 0.026320809120079502, 0.012646975665120408, 0.026213728342554532, 0.037581601354759187, 0.045947182734380476, 0.05039041345298756, 0.04469885694561526, 0.007835392007109476, 0.08810027647996321, 0.051380928271100856, 0.04167016340943519, 0.00935433174163336, 0.03017315670149401, 0.03816916709183715, 0.061163050631876104, 0.03276364543125965, 0.06231675259186886, 0.034065910513163544, 0.035987134178867564, 0.0395105062489165, 0.03655913707916625, 0.08965045970398933, 0.029873694547859486, 0.018036452092928812, 0.06067252441425808, 0.03652471255918499, 0.01760450359142851, 0.024282784397655632, 0.031872389154159464, 0.03701400681165978, 0.007031910463410895, 0.061179934491519816, 0.05138095795700792, 0.036983114914619364, 0.015384651760541601, 0.025210140593117103, 0.03417427149543073, 0.06365885987179354, 0.03680550413264427, 0.01506192884335178, 0.05567211519519333, 0.053076479671290144, 0.029355675469560083, 0.011037241583835566, 0.04648040470783599, 0.008533560012438102, 0.011098100476374384, 0.09114426196902059, 0.030927525695005897, 0.04441290002432652, 0.03268521155405324, 0.02410815519397147, 0.050735152181005105, 0.04392433307657484, 0.025668056841823272, 0.012996386212762445, 0.0547931525943568, 0.09044529244420119, 0.01635219803574728, 0.03890977110131644, 0.043694593841792084, 0.026498317856749054, 0.015689183710492216, 0.10171861955313943, 0.049381793942302465, 0.031263108176062815, 0.027710044632840436, 0.041012023139046505, 0.05836316864588298, 0.01005609730782453, 0.014656131770607317, 0.01889796865725657, 0.025686217195470817, 0.05949925944150891, 0.04003301160992123, 0.03354700456839055, 0.06606761147850193, 0.03937585839594249, 0.051567982882261276, 0.0318766973214224, 0.008750394226808567, 0.08990647838800214, 0.018409082586003933, 0.07911208886071108, 0.012470320398279, 0.021266681396809872, 0.02208652822446311, 0.039634864224353805, 0.011640207812888548, 0.07794064586050808, 0.04611218442732934, 0.002475473465892719, 0.040859396758605726, 0.0327039656258421, 0.0472255840577418, 0.07061184849590063, 0.04050820505653974, 0.024983050825539976, 0.06896091872476973, 0.09827697649598122, 0.01344798492937116, 0.04797458175744396, 0.06635083729634061, 0.030734663778275717, 0.05568328080698848, 0.03741573877050541, 0.03632175001257565, 0.06600772758247331, 0.04644284832465928, 0.031072309429873712, 0.03462649547145702, 0.051327437977306545, 0.03361115581355989, 0.003589283132896526, 0.011598939763644012, 0.0449594954989152, 0.04158825257036369, 0.016873287750058807, 0.026307635998819023, 0.009951883075700607, 0.05453420242702123, 0.02054895037872484, 0.06606227543670684, 0.051998435956193134, 0.04066442714247387, 0.03909835824742913, 0.025456811927142553, 0.04215446300804615, 0.04649420123314485, 0.028814319557568524, 0.030872315473970957, 0.019561051631171722, 0.06942829364561476, 0.03556262941856403, 0.031118710357986856, 0.030744029681955, 0.0729532798868604, 0.1302816200768575, 0.04059125509229489, 0.05469652867759578, 0.013157813536963658, 0.05811024471768178, 0.026708588702604175, 0.03543664613971487, 0.014046543728909455, 0.05492660930030979, 0.035057701825280674, 0.009364006564283045, 0.03177520491590258, 0.022900372932781465, 0.017635311996855307, 0.05841441765369382, 0.05470956450153608, 0.04313265446398873, 0.048526620885240845, 0.0363354389264714, 0.024821756160235964, 0.05869836706551723, 0.04381645820103586, 0.06775002315407619, 0.04345167406427208, 0.015093465481186286, 0.043537570236367173, 0.05389863457821775, 0.04018869934952818, 0.012608754132088507, 0.033985328118433245, 0.049043051767512225, 0.009864311505225487, 0.017451845669711474, 0.08356933874893002, 0.06937255835509859, 0.06183222292747814, 0.08573028724640608, 0.00764130740208202, 0.02652053033671109, 0.016382488793169614, 0.04088953537575435, 0.026994298859790433, 0.0582700773520628, 0.04037835147755686, 0.044635674203163944, 0.045702288844040595, 0.038843360016471706, 0.06606426439248025, 0.015147704416449415, 0.13494540966348723, 0.035509606677806005, 0.05099026544485241, 0.07611308494233526, 0.112235275155399, 0.02987040497828275, 0.00691968057253689, 0.03644895041361451, 0.0447563919442473, 0.06653156509855762, 0.02413508773315698, 0.06939060738659464, 0.04289176817110274, 0.033711861542542465, 0.057964668740169145, 0.048875174252316356, 0.012765068058797624, 0.03595199348637834, 0.03043099735805299, 0.01856890037743142, 0.041838059478322975, 0.05770919182396028, 0.027694162672560196, 0.023856487350712996, 0.04136979769100435, 0.046599370980402455, 0.01374882840536884, 0.027763542348111514, 0.0715747702633962, 0.028094710905861575, 0.004519658014032757, 0.04102157829038333, 0.023125959851313382, 0.011886908832821064, 0.012690189068962354, 0.06855973595520481, 0.027522620803210884, 0.009597570642654318, 0.044871766222058795, 0.03317363007226959, 0.07524368120357394, 0.024129024386638775, 0.04202742587949615, 0.09185287199215963, 0.05941647286817897, 0.008097373847704148, 0.04233169158396777, 0.08371869596885517, 0.02141386597941164, 0.03104826384515036, 0.03294467009254731, 0.06767858401872218, 0.015483432543987874, 0.01678182918112725, 0.11472227881313302, 0.07526694753323682, 0.03903929813532159, 0.02580087344540516, 0.04007667215773836, 0.04051860254548956, 0.029016285770921968, 0.012152014187449822, 0.03164748501149006, 0.04904173445538618, 0.05131763420649804, 0.03106504380411934, 0.02886835532990517, 0.049782193746068515, 0.034577476617414504, 0.05241238366579637, 0.046675845587742515, 0.0612058985279873, 0.07085079778335057, 0.055467293568653986, 0.06878651402075775, 0.015722634161647875, 0.03245871179387905, 0.011987895650236169, 0.0072616844863659935, 0.04856337945966516, 0.027731503832910676, 0.025779176758078393, 0.022279649892880116, 0.04839915702177677, 0.04670983966207132, 0.004890745303782751, 0.038628441470791586, 0.017231271958735306, 0.03907480990164913, 0.008335514194186544, 0.017748984901118092, 0.022174815967446193, 0.010314446335542016, 0.03388015837117564, 0.037463492262759246, 0.03922940668417141, 0.02346601748286048, 0.05060896852228325, 0.049941466058953665, 0.013851408057234949, 0.009984469852497568, 0.014917568132659653, 0.02082717041048454, 0.03541883088473696, 0.06965929453144781, 0.08177809853805229, 0.07843672705348581, 0.02143213765521068, 0.05080649112642277, 0.035648020930239, 0.04110663583560381, 0.04525004631432239, 0.03944121563108638, 0.033926089890883304, 0.021189742947171908, 0.07576921823783778, 0.03363257048476953, 0.034104791629943065, 0.03255120936955791, 0.027557748508115765, 0.032114344139699824, 0.03461204956693109, 0.005745114058299805, 0.03138433057756629, 0.028417409703251906, 0.0481596177269239, 0.05583057114563417, 0.06406775355571881, 0.037059968017274514, 0.08009520446648821, 0.0401248004345689, 0.024041382312134374, 0.03954906453145668, 0.05137467938766349, 0.043518385718925856, 0.01323897109614336, 0.04578449283144437, 0.01648482353630243, 0.08056514721829444, 0.0341178422968369, 0.015409290135721676, 0.042447674422874115, 0.04081672326719854, 0.022122364680399187, 0.1444364245980978, 0.1893262955127284, 0.1973624635138549, 0.13315511198015884, 0.1703982791514136, 0.13707135105505586, 0.12629168573766947, 0.10369290306698531, 0.06600393520784564, 0.10639354135491885, 0.11360974007402547, 0.0970355563913472, 0.1079869175737258, 0.11110206760349683, 0.11673179207718931, 0.12381510183331557, 0.14186421496560797, 0.19393163354834542, 0.14750719419680536, 0.13212017220212147, 0.15079453733051196, 0.16790380206657574, 0.12866603879956529, 0.05865233535587322, 0.11037200209102593, 0.1199031004216522, 0.1529638795182109, 0.28967635764274746, 0.10789884690893814, 0.1186608565330971, 0.18659456865862012, 0.10999856822309084, 0.25203254946973175, 0.15326839755289257, 0.09182700072415173, 0.16896868008188903, 0.2509707142598927, 0.16231896268436685, 0.2129592906567268, 0.101983766653575, 0.1833861306658946, 0.10071634911582805, 0.19482940959278494, 0.19800201669568196, 0.12696275050984696, 0.10468567401403561, 0.21599513478577137, 0.10926325572654605, 0.09219250845490023, 0.10146768458071165, 0.08850919242831878, 0.09550141097861342, 0.13897855184040964, 0.1647779205814004, 0.16387888288591057, 0.1396208064397797, 0.13097646326059476, 0.1434653837350197, 0.1231368382286746, 0.18056549452012405, 0.11674401524942368, 0.1172838089405559, 0.11257295976975001, 0.06508774647954851, 0.1621945935767144, 0.10428228706587106, 0.126629259029869, 0.08775178619544022, 0.18348201614571735, 0.13620667479699478, 0.08942260552430525, 0.19193068466847762, 0.2171270435792394, 0.13107457518344745, 0.2153927632025443, 0.114175137860002, 0.20233791059581563, 0.16222255770117044, 0.15778874483658, 0.13830328651238233, 0.15769906371133402, 0.10855694636120461, 0.1098551630275324, 0.1168721322028432, 0.15182300558080897, 0.16140131192514673, 0.2659911004593596, 0.1885453483555466, 0.14081112225539982, 0.12226434715557843, 0.1478338282322511, 0.13350173947401345, 0.07332113280426711, 0.051741174174821936, 0.07821860985131934, 0.25821627234108746, 0.1922493480378762, 0.06928611299372278, 0.1866549052647315, 0.09780488151591271, 0.10659647421562113, 0.16586915968218818, 0.1252171746455133, 0.11757859741919674, 0.12365104266791604, 0.21821047528646886, 0.0989285673131235, 0.1097659494553227, 0.1564216346014291, 0.15363651764346287, 0.11654713831376284, 0.1632930018240586, 0.09101849762373604, 0.1078111473179888, 0.13886760076275095, 0.1374425139511004, 0.06964044398046099, 0.0929188409645576, 0.1215712480188813, 0.08174306916771457, 0.16262218938209116, 0.13534112280467525, 0.19656692573335022, 0.12211329783895053, 0.1439404027769342, 0.11623273487202823, 0.15411199681693688, 0.07441845009452663, 0.18963345559313893, 0.20883361750748008, 0.10674790202756412, 0.1115447364281863, 0.181942994822748, 0.13947262923466042, 0.11435660038841888, 0.15027889312477782, 0.10296877473592758, 0.17670095345238224, 0.132293923816178, 0.17928626941284165, 0.14921633061021566, 0.09116299377637915, 0.12523215118562803, 0.1523333805380389, 0.11746003190637566, 0.15000812796643004, 0.07061984142637812, 0.14173085102811456, 0.16741900151828304, 0.2189266329514794, 0.1492487921495922, 0.11956338232266717, 0.16900795453693718, 0.11843498388770968, 0.17453848355216905, 0.16632865299470723, 0.11198762789717875, 0.1318695637746714, 0.17919356032507494, 0.200913239386864, 0.1553951998357661, 0.14584527321858332, 0.19683113030623645, 0.11966843332629651, 0.11808616705820896, 0.1526130217825994, 0.08569979981984943, 0.08915843063732609, 0.1532895932905376, 0.11713380605215207, 0.17271943506784737, 0.1320725560071878, 0.08527297584805638, 0.16690598451532423, 0.13372233544941992, 0.10519080198719166], [0.011802862463810015, 0.036914492229698226, 0.07760188513202593, 0.056103495953720994, 0.027480071621539537, 0.011156473174196435, 0.01561638644488994, 0.06521824572701007, 0.013295904955157312, 0.027507794548000675, 0.06789966981159523, 0.025783013661566656, 0.027159033379575703, 0.019765255419770256, 0.053643576975446194, 0.04553486403892748, 0.051787387710646726, 0.057338229307788424, 0.05620512194582261, 0.07304313170607202, 0.05128661243361421, 0.03400049019546714, 0.038369617468561046, 0.0264566110126907, 0.009699916518002283, 0.026907003739324864, 0.026741224646684714, 0.03527886925439816, 0.04601525994075928, 0.025767896113393363, 0.059429397369967774, 0.029905584633524995, 0.05150924189365469, 0.008938360751926666, 0.007685623822908383, 0.05345158337149769, 0.04580489818181377, 0.0021227009892754722, 0.01743593402352417, 0.05213643089518882, 0.02914734162914101, 0.03542270860634744, 0.023882763089204673, 0.01920046805025777, 0.0410501361329807, 0.010287401546520414, 0.017161576870421413, 0.04587821866152808, 0.009048378578881966, 0.02711761226237286, 0.044349732124828734, 0.006999059760346427, 0.06988977591390721, 0.045311529538594186, 0.007630632535438053, 0.04013735015178099, 0.028733867038681637, 0.0476716964476509, 0.011675189871311886, 0.024666389399499167, 0.08682244661031291, 0.0207666705318843, 0.047444228184758686, 0.03727953982888721, 0.028557850018842146, 0.03410109202377498, 0.01981045035790885, 0.0757496478036046, 0.011548533093446167, 0.028791871445719153, 0.01624952747079078, 0.07777965176501311, 0.020367903453006875, 0.057509264661348425, 0.05058358707174193, 0.04568428063066676, 0.05005547478504013, 0.0030944016680223285, 0.024304084035975393, 0.07027497282251716, 0.06510658960905857, 0.061125516513129696, 0.08548001278541051, 0.014936704410501989, 0.024708355995244347, 0.03131591198325623, 0.014326807449833723, 0.032540496467845514, 0.05713529644708615, 0.05385986478358973, 0.03218584635760635, 0.044829189209849574, 0.03536534801241942, 0.05530208036361728, 0.03276273258961737, 0.03421744593651965, 0.018988037554663606, 0.027162146689079236, 0.03493920681648888, 0.02118138079822529, 0.05618413029878866, 0.03673898914712481, 0.05063504017016385, 0.049011837036232464, 0.05171417855308391, 0.02926545999798691, 0.08653519093059003, 0.012046298033965286, 0.029660072905244306, 0.07382160751149058, 0.007621053728144034, 0.03692124577355571, 0.03426102855883073, 0.06053919387341011, 0.035836493043461815, 0.04592203134961892, 0.028217985345690977, 0.010057201252493542, 0.09108544676564634, 0.009556127261021174, 0.08457943142275326, 0.045403080875985324, 0.06433900111005642, 0.026113573658221867, 0.00972991691014613, 0.022904768302396405, 0.05507966241566464, 0.04762213211506605, 0.010867032797250431, 0.03978951666795183, 0.03540086720022373, 0.007660972460143967, 0.03716656268807128, 0.02920644070400158, 0.07094692817190662, 0.05935557965131011, 0.01644056184886722, 0.045012124901404604, 0.028082292919862084, 0.013316928143467521, 0.0343545206123963, 0.046686083514941856, 0.03652731378679164, 0.00345150434441166, 0.06027621013345197, 0.03174367106112186, 0.02670652738743229, 0.08644982168334536, 0.06501579526229762, 0.012437564782885602, 0.04268697994120885, 0.022190391791809816, 0.01900504757941235, 0.058541395410429686, 0.0755153146747034, 0.021625339104502928, 0.10081711792736314, 0.05928879007115029, 0.0789514287316706, 0.01910815972223645, 0.01711212571535725, 0.05777503887657076, 0.03768203991057817, 0.04187821708910633, 0.04942860119626857, 0.03666825134132523, 0.04368723173683975, 0.04729740910988767, 0.04812224316992797, 0.013217285541031742, 0.0444630988931749, 0.03105065356066916, 0.033331796585116535, 0.03876563860103488, 0.03551255300408229, 0.049802435823949054, 0.014586210327252047, 0.034068200038746, 0.04371463925053831, 0.08753438145504333, 0.07457272033207119, 0.018064961695927195, 0.03935056971386075, 0.016370616285712458, 0.051143700766260736, 0.03032472923223395, 0.019672763410198968, 0.02560691315011354, 0.0696411267563235, 0.05133985781867523, 0.02824324805260403, 0.025574564788257703, 0.04543175746221095, 0.022396139247575775, 0.07410156787955202, 0.07003692895523272, 0.030521244370902423, 0.01587545164511539, 0.03573774658434559, 0.00527462814716273, 0.014287241701822495, 0.040253488841699436, 0.09052631270606071, 0.06536602217238396, 0.020827209373237565, 0.04353083895693999, 0.0660091896133963, 0.079503356537316, 0.03999360356829129, 0.028766649556928314, 0.030026643762539607, 0.061050106887705624, 0.05854592251125723, 0.08410060516325757, 0.12907764874398708, 0.009196137398248538, 0.05456225189846009, 0.06172538334794808, 0.037514592841034755, 0.04151605273364112, 0.019639511483546812, 0.014506971219816478, 0.03150750111672096, 0.05441319524834398, 0.06851062062196434, 0.023717952499282546, 0.045067266473779455, 0.04818749650439713, 0.030654112924821675, 0.0806310202460736, 0.018189121146860998, 0.04529025587544311, 0.04847572068683803, 0.03189413408108521, 0.033048344412236474, 0.0710478528344538, 0.0456879023113288, 0.08722013386432081, 0.03779438622586895, 0.05465502406877931, 0.04910207477223594, 0.02317082638910506, 0.023546744596387725, 0.05325016820279416, 0.03353037674969528, 0.01864497608039528, 0.019190684688510373, 0.013161454699002206, 0.02406839277682593, 0.05212941759964451, 0.03616593239712529, 0.055121723635238595, 0.03968509648984764, 0.06447074716561474, 0.027420026308391243, 0.060220563900657, 0.04529983700194862, 0.0331273274787236, 0.06739215212292038, 0.13287735579069704, 0.04775016743224114, 0.04119472505408339, 0.002785089591270662, 0.014780854326090775, 0.10764087637653574, 0.017598996855667792, 0.09076224887394346, 0.018252977388328873, 0.06349235161906108, 0.015510917983192485, 0.019506316384649836, 0.013260485029604752, 0.038838480395497754, 0.013590006947197253, 0.036266330134822056, 0.02300317893968895, 0.04109179288207088, 0.0765594348195009, 0.014871555904392153, 0.039758272250765, 0.024415560183115304, 0.030961399170337245, 0.040588349584140815, 0.04996245770598762, 0.027461488243716303, 0.06563653500052169, 0.026698122564994264, 0.005323767136360402, 0.04785008648468647, 0.014506312563753454, 0.01279673086173716, 0.016002765223674942, 0.0281152220122749, 0.04604180656315293, 0.04162797973549459, 0.048798091083881445, 0.08553692066925578, 0.013938542688265443, 0.052427493792492896, 0.038788262972957455, 0.07515368837630376, 0.06276875763433054, 0.06727851447067223, 0.007862836628191872, 0.07440012646839023, 0.05040979835030157, 0.09661259900894947, 0.03307808226963971, 0.04680907593865413, 0.05100219546875451, 0.023812294311937876, 0.015913599891064223, 0.050266218750039116, 0.022948890837142244, 0.011421542349125957, 0.011078785155405058, 0.028752699035976548, 0.023070855386322364, 0.02244302257167874, 0.05301151206367649, 0.008686011060490273, 0.024194834331865422, 0.04939150494465139, 0.037652472747140564, 0.06921933454577811, 0.06397186065441929, 0.058968831654055975, 0.07824943866580725, 0.03594135479943361, 0.048791883018566296, 0.03800119309744332, 0.024469232303090394, 0.06506993493530899, 0.04929857692332007, 0.027380275023460854, 0.09385520868818276, 0.05209581315284595, 0.02281060460518347, 0.04705650055257138, 0.028075852933397982, 0.021472801781783346, 0.05925010933424346, 0.05327058468537871, 0.04028090748761315, 0.04352519863459747, 0.008981912760646082, 0.0548550996609265, 0.05041086704295594, 0.037266522558638826, 0.010571966940915445, 0.0961135195393581, 0.06086791334382724, 0.13962024240754545, 0.10288976569427177, 0.17835433973232284, 0.11724831201718189, 0.16412223310908303, 0.10305433694156818, 0.12348333955742419, 0.24618550931336358, 0.15587781846988946, 0.12627136573428288, 0.1100955372385215, 0.1911040212144144, 0.10551424478762783, 0.1438776616123505, 0.1673464640043676, 0.19202609517378733, 0.1397080087917857, 0.14120394102064893, 0.24895143433241174, 0.12703585205599666, 0.09292601011111401, 0.11681340605719015, 0.0866544243763201, 0.07700214075157419, 0.12592175480676815, 0.15443107578903437, 0.23866002797149122, 0.28498598432634026, 0.15130304207559675, 0.14377039158716798, 0.20636554603697732, 0.2647984097711742, 0.2183544370927848, 0.1612748351180926, 0.13371491397265345, 0.1333574956515804, 0.12055587867507711, 0.18684492475586012, 0.21087087225168943, 0.18144171859603375, 0.11513143967022188, 0.241365393740125, 0.16177378100110218, 0.1886509411269799, 0.15538849082076922, 0.08226786405430175, 0.08832625302602537, 0.16406695795012638, 0.11442931601777673, 0.16119021544000134, 0.09746656607603654, 0.16600314702372998, 0.1635422743856907, 0.15543533518211916, 0.14923963404726237, 0.1404746770276688, 0.11573852389119565, 0.22932397347176448, 0.10796736940392293, 0.1251031065476127, 0.3448734129779041, 0.16823919344460592, 0.14670699572889134, 0.1317400293191895, 0.23483341065002605, 0.0743280490860343, 0.12359077285509557, 0.20333758351625875, 0.1017795350344386, 0.08339247753610834, 0.06058171893528197, 0.1303566957358271, 0.1318957912735641, 0.1355226372834295, 0.1380085202981718, 0.16493798699229956, 0.12299242371227592, 0.17365984007483348, 0.07302801415789872, 0.15898740239208564, 0.11835719938972034, 0.18865224730689079, 0.16868436330696568, 0.17165728815598413, 0.06613142875721678, 0.11067487997934222, 0.07957918176543899, 0.1432791937259026, 0.17733912623953074, 0.17569957359228283, 0.20189174625556916, 0.17399564705556259, 0.17358770332066342, 0.17588917748071253, 0.09945556637831032, 0.06369695431203581, 0.15117364120669663, 0.07149140481487848, 0.10560999668086879, 0.14066236617509276, 0.3278291306924075, 0.18418684863718227, 0.15215315739624202, 0.12445675529306754, 0.15479549998417497, 0.14050998841412365, 0.12462014652555808, 0.10356311628129333, 0.14220572164049372, 0.15933327289531007, 0.15574495919281617, 0.08045985872740857, 0.10976907389704138, 0.16847880324348807, 0.14381621178472415, 0.09993613668484613, 0.1518143224529922, 0.14385081070940942, 0.19872388889780268, 0.2134246172499843, 0.1908062567235902, 0.12656347505981103, 0.17277343373280019, 0.14191548252711073, 0.22228998685022816, 0.08728437416721135, 0.16258934192592278, 0.21572067373199388, 0.2056658492074348, 0.17630115849897265, 0.17761219205567613, 0.11033362563466653, 0.19921697181416675, 0.1026732663740404, 0.16423405992100015, 0.20819102152017877, 0.09486101174843498, 0.10043586924439296, 0.15161046932917088, 0.08279981324449182, 0.07365978963207453, 0.14612196071539074, 0.1542223838623613, 0.10541570984059945, 0.14127404429018497, 0.0878987240139395, 0.12993055453989655, 0.12659344298299402, 0.10464698585565202, 0.11584034655243158, 0.11256492231041193, 0.14284867385867983, 0.09339529977296479, 0.121543959248811, 0.12888010387541726, 0.13076576753519475, 0.24319967109477147, 0.22386664990335703, 0.10630657649016939, 0.18640122434590012, 0.11680016614263877, 0.18032704247161746, 0.21734532405389473, 0.15661135723348707, 0.21871758479392156, 0.27610675140749663, 0.20449088100576773, 0.1303102818201296, 0.10502837554668076, 0.07631411048350856, 0.1620007149176672, 0.12476784875616431, 0.13178381603211164, 0.1231603643100243, 0.15426995552843437, 0.33772421535104513], [0.02182089872803772, 0.030060073804634158, 0.022474129691545386, 0.08049656535149552, 0.05525433058210183, 0.028145959913672414, 0.02001676370127825, 0.036849250027444214, 0.02145343358279206, 0.01837795876781456, 0.019155994850734714, 0.04569317155983299, 0.04862462148594204, 0.02670640493306564, 0.13133354019373655, 0.08654792618472129, 0.01866126993263606, 0.040409510547760874, 0.04506045355810784, 0.04178813520411495, 0.08027025483897887, 0.07765594316879287, 0.055551512486999854, 0.0683332621701993, 0.060805387402069755, 0.05262048929580487, 0.021454992092913017, 0.029158386641938705, 0.07737226464087144, 0.06361514737363905, 0.07094125816365704, 0.007336847347687581, 0.00611920658229792, 0.028643145051319152, 0.06755989234079607, 0.05840669560711831, 0.09591561843990348, 0.03345294106111396, 0.06256394714000635, 0.012504097394412383, 0.016537310075364076, 0.0076677153356286, 0.0299739271576982, 0.03335081411933061, 0.08355871861567721, 0.04002022811619099, 0.03491582174319774, 0.04978584140189923, 0.02696370011108229, 0.019019525025214534, 0.082620413886616, 0.04010962351458147, 0.040659339720150456, 0.04703431775851641, 0.0568823613866698, 0.06861111483885907, 0.07586038365843706, 0.037013917753938586, 0.03195023673470132, 0.062373148393817246, 0.031397845086758025, 0.05338673079677392, 0.03192002390278503, 0.008227609632740496, 0.05620816475129686, 0.011546635050763143, 0.02187783258705167, 0.06163275960716419, 0.05364482007280458, 0.023693315051787067, 0.07615586975589395, 0.05120619331137277, 0.02753863635007292, 0.042808436119230464, 0.0596521047555143, 0.023278139087778982, 0.051566995825851336, 0.017080549187085126, 0.023611693650309462, 0.026890143999480642, 0.01561234730615979, 0.012165524985903176, 0.1434907058137469, 0.04181821073871106, 0.09124106029048562, 0.04975644493242726, 0.092664722178597, 0.03740373453183565, 0.06146579864434898, 0.05589412867266219, 0.022960600072110537, 0.0100071257656964, 0.07660124741960317, 0.04712690810265485, 0.010871893864532467, 0.025405071246495936, 0.14238637522794306, 0.006561144855368184, 0.038135692520882, 0.03313265980978031, 0.025099582853727043, 0.031155522738117725, 0.0421662928420119, 0.09717485008877702, 0.025410787638975307, 0.08578015957027674, 0.01673904807830695, 0.033517819611006416, 0.0713580779847689, 0.06433342015952803, 0.05314443071256392, 0.026078319788211957, 0.06704222949338146, 0.009352181368740276, 0.07769244941300713, 0.10146172513486817, 0.03212704228644725, 0.029327299453143496, 0.02388507858995581, 0.046079221938271075, 0.021562516303674784, 0.048026806689449586, 0.053977636198396794, 0.02198131951445248, 0.06154621034511365, 0.006947894707991509, 0.04739935422549024, 0.019981982950412203, 0.02882816617784556, 0.028613435024453793, 0.07037149654934183, 0.0803781631111633, 0.03462559005129151, 0.029491037639672868, 0.09846646164078265, 0.03925504417566117, 0.009321612305939198, 0.04449631742318161, 0.030486118521366734, 0.03948818615754135, 0.038140238175401464, 0.011684290457196767, 0.04316741666116286, 0.0182540998866898, 0.012109130111639388, 0.010186902691202704, 0.03142588342598174, 0.0125102683523437, 0.047875174786895514, 0.12027440432575531, 0.01562351291795494, 0.055710083470330574, 0.030304926876851823, 0.010980971019307617, 0.05106309981783852, 0.032669748907210305, 0.03055338307603961, 0.039371231105178595, 0.024333315377589315, 0.010671488944353769, 0.008273998500953894, 0.0700442391098477, 0.02067509136395529, 0.07641359537956305, 0.010979893977491884, 0.030897487267793622, 0.06754435918992385, 0.04531250546278898, 0.0616515470755985, 0.03838719152554404, 0.07738640997558832, 0.015227660624077544, 0.04176383728918154, 0.05147574505826924, 0.04509134916588664, 0.05152421843376942, 0.031269397877622396, 0.016708731345715933, 0.04035925601783674, 0.09225117522873916, 0.04292997393349651, 0.01141111517426907, 0.037800523787154816, 0.021898998638789635, 0.035611006314866245, 0.0415496757341316, 0.03615022113081068, 0.03609027786296792, 0.02018771741859382, 0.011659453557513189, 0.04326542097260244, 0.02403894621238578, 0.02861513083189493, 0.05696083237126004, 0.054677106672897935, 0.051846599963027984, 0.019834243612422142, 0.021421298588393256, 0.06568265205714852, 0.06770818086806685, 0.016314092463289853, 0.01997009188926313, 0.04572172569169197, 0.10403662134194747, 0.009004055664263433, 0.029332097437873017, 0.02728146362642292, 0.07958166796015576, 0.05949775288172532, 0.05585648694250267, 0.08325074959429912, 0.017426221165806055, 0.027572324288485106, 0.04842981885303743, 0.03462251755991019, 0.011311414127703756, 0.057119158445857465, 0.0727547331189271, 0.020907118268951308, 0.08593061516876332, 0.0202968984740437, 0.036173216576571576, 0.048949006813927554, 0.035124836504110135, 0.04155273338255938, 0.024611212575109676, 0.043377014008001424, 0.04699236043961719, 0.04906894901068881, 0.039811465685488656, 0.024137481159414165, 0.02142491655831691, 0.05539099336601794, 0.03862979960103985, 0.0500355184340151, 0.055698632131679915, 0.051499827750376426, 0.03216653196432162, 0.06146305640868377, 0.0724699413694907, 0.05840363424795214, 0.05040953117713798, 0.07675870147068053, 0.04051183786941692, 0.04864815127803013, 0.031952696954249404, 0.05525577777007129, 0.08156820433214307, 0.023969108260644134, 0.03048716866032919, 0.027907630319532473, 0.030757863314647693, 0.05727056399337016, 0.03483897235128097, 0.10055925129563548, 0.05080049086245708, 0.03395651052414905, 0.033975965925492346, 0.08656790480017662, 0.0032708426397221046, 0.05753277218900621, 0.07178815998486243, 0.049169639896717854, 0.05633527980535291, 0.07283971644937992, 0.02986223578773206, 0.03694670886034146, 0.02163434877729742, 0.07211115007521585, 0.010089981915371027, 0.016884236283658538, 0.04072470066603273, 0.040937763842521235, 0.02911926061642589, 0.015420536456076661, 0.04724961851025, 0.01173354216007283, 0.029502787692763377, 0.03248484652431216, 0.019950003807025496, 0.011833451007987605, 0.03298429335700348, 0.047913677408359945, 0.044017350155627355, 0.06709259905619547, 0.08911796874599531, 0.07350344138103537, 0.004428875263329246, 0.026866554835578427, 0.020125720257055946, 0.039776395497028716, 0.08660127175971866, 0.012383933481032727, 0.03830894689599518, 0.029399170889519155, 0.04410795525473077, 0.02409731056104647, 0.013921128193032928, 0.028642582874454092, 0.018132419208995998, 0.060524150540004484, 0.041810644543147646, 0.051064977451460436, 0.02297553393873386, 0.03684337963932194, 0.025255791952076834, 0.05043451186793391, 0.03189877621480264, 0.0343531476391945, 0.039605118945473805, 0.07680052891373634, 0.05909567953494843, 0.029296669163159095, 0.019725758320419118, 0.03247504275350366, 0.03691294485179242, 0.13138776150299236, 0.07460194610757753, 0.044005494346492924, 0.06885030161356553, 0.028966741847398225, 0.03476003010291606, 0.05449578515253961, 0.029943365516373888, 0.04108802277187351, 0.04804670737939887, 0.03014698115293868, 0.008801606127235573, 0.027904825001314748, 0.0100888148881495, 0.042646662768675014, 0.040679696830920875, 0.06502353586256504, 0.018326689350942615, 0.04348698173998855, 0.011955296813539462, 0.025820989358180668, 0.02402173024165677, 0.016096350045700092, 0.006607588456972735, 0.002185777279919421, 0.04990155706764199, 0.019704213773366064, 0.015860183812037576, 0.024303111822518986, 0.01537038582682726, 0.03127084506559186, 0.01168680819318979, 0.05912483851716388, 0.06848922450444661, 0.01955643547262298, 0.09943066732375883, 0.12563657714053988, 0.054363760791602544, 0.17687767365714535, 0.20517384982667863, 0.1134660305979196, 0.1215960357512813, 0.15022753650555387, 0.1779677698505111, 0.164088420860935, 0.12432227813405916, 0.1668077241629362, 0.17937835509655997, 0.1301008032169193, 0.16700253792805597, 0.21463666314957663, 0.1435977383516729, 0.1480920214089565, 0.13542232860345393, 0.14367106254212558, 0.16050500533310696, 0.18208496767329052, 0.2151610646978952, 0.15968947409419343, 0.15094059199327603, 0.0716802294482477, 0.08906467512133531, 0.1357081890455447, 0.2459107810864225, 0.19185793935321271, 0.13524678099201992, 0.13331394642591476, 0.11622712423559278, 0.110975613060873, 0.12283288422622718, 0.247803658421617, 0.11071452550822869, 0.20798982528503984, 0.14220592944184318, 0.15225858689518645, 0.15011098963441327, 0.06637975136982277, 0.26252212410327047, 0.13802340778056532, 0.18104843969922513, 0.14460625767242163, 0.1639792212517932, 0.243876391032245, 0.1196218709810637, 0.07851122383726761, 0.10087248956551775, 0.19399808545131236, 0.17646159598371014, 0.16525298415217549, 0.12022317387163639, 0.09128306584898382, 0.2717350563034415, 0.16345030744560063, 0.1504029505304061, 0.2062251465395093, 0.17732435750076547, 0.13233155070338398, 0.11349228036124259, 0.14705109992064536, 0.23046538175549358, 0.1091113306756597, 0.11167222255608067, 0.13634938979521394, 0.2211254384019412, 0.18433214630931616, 0.13856208825018257, 0.1475501645472832, 0.17834414262324572, 0.1415605578222312, 0.09787949704332277, 0.09572648210451007, 0.11325507512083277, 0.18200925376731902, 0.15574865508824587, 0.18481470557162538, 0.14054920349735767, 0.1835797421517782, 0.08289351681014523, 0.2512180572375655, 0.11811867312644608, 0.2486329639214091, 0.1359737294842489, 0.15922080783639103, 0.2282628952525556, 0.14162746985675767, 0.16634655359666795, 0.12381990352878347, 0.13374140864470974, 0.16068600030848756, 0.11881826605531387, 0.12474156188545749, 0.1439294041483663, 0.17187368357554078, 0.15455955639481544, 0.14311612903838977, 0.09180584209389053, 0.16926493059145287, 0.10710370988817886, 0.10712283503380604, 0.12979128310689703, 0.15260672837030143, 0.1711264150799252, 0.12491620407672599, 0.1688712212489918, 0.13156666362192482, 0.14198850985849276, 0.15886203880654648, 0.16766877874033526, 0.16420207335613668, 0.07852979237213731, 0.09243818902177736, 0.3367641137447208, 0.17514207225758582, 0.1349497734918259, 0.15205267060082406, 0.17119733471190557, 0.10033251775894314, 0.14162816747557372, 0.12982036045286804, 0.13864964683307335, 0.15443692391272634, 0.09883361693937331, 0.19549974706023932, 0.09753081380040385, 0.07984517491422594, 0.0881790257699322, 0.13446905475575477, 0.14529449574183673, 0.10081036438350566, 0.1277840556576848, 0.22921133029740304, 0.10430508584249765, 0.11276117584202439, 0.09321161080151796, 0.16282579017570242, 0.14073677390115336, 0.1889800836215727, 0.23054305493133143, 0.09860830832622014, 0.10232902859570459, 0.11176077561685815, 0.09202243789331988, 0.13911610149079934, 0.09140454058069736, 0.12034754297928885, 0.24497580860042945, 0.11246102163568139, 0.1301093676011078, 0.10336159350117669, 0.14063725189771503, 0.14090915996348485, 0.15417939866892993, 0.13483211339917034, 0.18711760465521365, 0.15117478411411867, 0.13209582975832745, 0.11616397488978691, 0.10013146995333955, 0.05507548041350674, 0.18545195809565485, 0.10609975477564149, 0.1108579381252639, 0.12058714535669424, 0.1307481192634441, 0.14209675951860845, 0.10032687743660063, 0.22149677941342816, 0.08362337452126667, 0.13798916508676484, 0.1802242550184019, 0.11209870513994247, 0.19632773153716698], [0.010587050164758693, 0.042262501156073995, 0.04084675427293405, 0.07387761739664711, 0.037455046622199006, 0.04394578114442993, 0.04830068144656252, 0.01654165163927246, 0.035967292860732414, 0.03914455322956201, 0.01323808794040815, 0.04157082694291603, 0.08063974790275097, 0.010873200044443365, 0.060614477333729155, 0.05648932739859447, 0.043772582430392504, 0.08024821305298246, 0.022101627218944486, 0.015549679428659147, 0.030099064388195984, 0.027194346621399745, 0.023646526351512875, 0.04131520530791022, 0.08062817039899528, 0.05831963426317088, 0.022045131227059755, 0.040517578381695785, 0.05757652179454453, 0.019988541680504568, 0.10733374598203227, 0.04685613923356868, 0.009198608750011772, 0.005643488530040486, 0.039493114018114284, 0.02170943556848215, 0.06035655133018736, 0.009616566840122687, 0.07675816712435335, 0.05437868167064153, 0.012340618031885242, 0.015320606271416182, 0.06761174619896337, 0.04764225544931833, 0.06762753910152242, 0.09098740905756131, 0.05853974413184915, 0.027402021805755794, 0.025808246682572644, 0.002749660388872144, 0.016395904967794195, 0.04178804985713214, 0.03726022543560248, 0.04147990272031166, 0.04677749384427443, 0.019221958791604266, 0.031142832012847066, 0.039926992103573866, 0.02703038579056738, 0.060683022093144245, 0.029710646558669396, 0.0040535888092563255, 0.030801483044342604, 0.03954298263124656, 0.02829346361977514, 0.050602938572410494, 0.08884742623195052, 0.01844396352680633, 0.01811138488847064, 0.05471610653330572, 0.03782679581490811, 0.04210321028949693, 0.010910678502114024, 0.06877467676531523, 0.015880848914093804, 0.05487679263751488, 0.03210834758647252, 0.030721030525455717, 0.04592519660945982, 0.1484388715471141, 0.09187484698486514, 0.04578086744004395, 0.034047802109853365, 0.022410664932976943, 0.03475483877991792, 0.04316445178119466, 0.046360952328541316, 0.06623418652452528, 0.082490723580122, 0.03661091672256589, 0.07115936052286997, 0.11720865906681865, 0.013028599132667296, 0.10220384312560782, 0.08013604485313408, 0.03855843096971512, 0.040873705365811475, 0.099543191754492, 0.05583715028478764, 0.03057540816371329, 0.016837041257531382, 0.0327355254557915, 0.0044320006327325245, 0.002692738357836788, 0.020554570292006247, 0.06289603596087545, 0.06689244924928062, 0.04170505919319112, 0.027376634789106902, 0.04482317410293035, 0.034607737688929774, 0.02387231550528668, 0.02482031639374327, 0.011087708553532138, 0.055893868920975365, 0.05111663464049343, 0.03197714329871815, 0.03655450607766397, 0.04437862764461897, 0.078695053816773, 0.04772050007886719, 0.061675076867686585, 0.06409626686945558, 0.05396829998062458, 0.03257082433265168, 0.031460296813747846, 0.041731000965228304, 0.035800205732812174, 0.07661280265892856, 0.02939033933216706, 0.010687633439374622, 0.03217432080418803, 0.06953666204935871, 0.015898808887868654, 0.021091493726999033, 0.052795142619288526, 0.05723898189899046, 0.0360812310827896, 0.046377773105632514, 0.0521602055960102, 0.04849768454732839, 0.04835508458199911, 0.01960628738743253, 0.01322077177974279, 0.045667782687814906, 0.04304299189243466, 0.020938349698553793, 0.039899588300613686, 0.08592637750552967, 0.014300905568234157, 0.04113959461392369, 0.01711687546048779, 0.017057618679245934, 0.023268942022696137, 0.03937095279979985, 0.06210165593074635, 0.02720773125474807, 0.05551729576836806, 0.044501133961603045, 0.09177243802696466, 0.05056967922428157, 0.018424689951643813, 0.08358936189324595, 0.042749108833959326, 0.04432476627698634, 0.02737966089625843, 0.051786949843517505, 0.01635665277717635, 0.022121180954854935, 0.05299750773701817, 0.02983020654937718, 0.016046557502704673, 0.026139335459447466, 0.0428821276727831, 0.020469019218580797, 0.019990513937955257, 0.03980503497587051, 0.03599342016968876, 0.03297995921457186, 0.05184154593735002, 0.03061943978536874, 0.012046604169881903, 0.05969702695438173, 0.006707642023684457, 0.07231294002849609, 0.022857248586660717, 0.0342887440638151, 0.03874910355079919, 0.10323672715458088, 0.06448250278481282, 0.033752026574802585, 0.12010089762043208, 0.03721555556694511, 0.03155590769893024, 0.04334704608481843, 0.03415836355998181, 0.03676009953778703, 0.08528776685125194, 0.01049370282999007, 0.054730674892198294, 0.011483184207463637, 0.07732369849691167, 0.02089836463710526, 0.03235208001569845, 0.04558896289381664, 0.03534655312250834, 0.013971496828162344, 0.024952704407041892, 0.044611439370783046, 0.013478789624059573, 0.05722174551920034, 0.10319579771021381, 0.019623436564870644, 0.0419717536715325, 0.005680736921931384, 0.06813133863033727, 0.0384233415388735, 0.013907707379985368, 0.038058026766520925, 0.026746551411633845, 0.016157632890099194, 0.053042259241919965, 0.04433900066942442, 0.027926731345360167, 0.06134197872597724, 0.014387002120201942, 0.034118491676053964, 0.010833852302312152, 0.04878225736320019, 0.09552518196869642, 0.024305956103489734, 0.033091997538576834, 0.01823354610678507, 0.045729117482551374, 0.0325973115832312, 0.04138007643632591, 0.0649396657536272, 0.016368397264159285, 0.020507759327301756, 0.02038740709394915, 0.036702924480778165, 0.010555972730799112, 0.027674549564835615, 0.07595654373290017, 0.03149635034787934, 0.027592384540184867, 0.015360183151642559, 0.03899826107954141, 0.0732631265418604, 0.03902835145709105, 0.05392877690610476, 0.032624670857330784, 0.051481407645042054, 0.051281855267006904, 0.03998628228146117, 0.09630577289499342, 0.02244425082608359, 0.086095305159688, 0.08200219002901576, 0.04107662338356022, 0.05372697953134775, 0.041297334391856566, 0.008627852657809854, 0.02662331964529585, 0.08491321976180188, 0.00979022661340423, 0.025529631457175128, 0.004076177465321962, 0.06669157955911942, 0.03426980445510708, 0.11206729002879001, 0.010740548568719532, 0.02747388953139307, 0.024210861010942608, 0.06579542881809175, 0.022129350145405624, 0.02941521797765745, 0.0157157897047, 0.07263314706506208, 0.01703714096947806, 0.03903408083715476, 0.03865542967105284, 0.060883479891344905, 0.01975441635295283, 0.01932522121933289, 0.013463531995512312, 0.030522368724632543, 0.06112255905463826, 0.06757259790902026, 0.01727496590319788, 0.03152644814690575, 0.019492410392558668, 0.048073075886350125, 0.04205667763017118, 0.05548954686673824, 0.03836801442957949, 0.055948802692000754, 0.052875138717354275, 0.07242665931698866, 0.013952832741779275, 0.02893563843826996, 0.027897589061467443, 0.0511568775982596, 0.017396197581547312, 0.046710871247341856, 0.04062720101501327, 0.08845975797157735, 0.042238162423018366, 0.01211314420288545, 0.01723071349260863, 0.02186601202993188, 0.054249956156127155, 0.029937689942016732, 0.007760533890177612, 0.05512126721441746, 0.044622501081903465, 0.06445836814236827, 0.042610813325154595, 0.008469265903841006, 0.036709626074298285, 0.05133839207701385, 0.018894586319220252, 0.04368483459984418, 0.034498949971748516, 0.008529923488822533, 0.04503729855059646, 0.06270231315284036, 0.01851056014857022, 0.019368202702025883, 0.016786382257123478, 0.04440059150510933, 0.044080306543037295, 0.010978698192047887, 0.06721909070620313, 0.03666232900286559, 0.026522888510953635, 0.06617568302317522, 0.026218769380648155, 0.04041334002977237, 0.07196522899903357, 0.004806471188203432, 0.04496556626691017, 0.06481515563791618, 0.029650191208929755, 0.029921143759565894, 0.023139730401453562, 0.011872798750118818, 0.00968591219134396, 0.028263453023100737, 0.0751103914808482, 0.041726607450982556, 0.033879097099998035, 0.09001113605336286, 0.1028774979931768, 0.09957246948033571, 0.09432210863451473, 0.1622899150243029, 0.13563799671828747, 0.24516939040040597, 0.09653508168412372, 0.16048190969740972, 0.16130401636473835, 0.15803144196979702, 0.06791931446059607, 0.26316921750549227, 0.22539439058164135, 0.1973356126109138, 0.18950024008518085, 0.1407872251002118, 0.11196953433682211, 0.12339501656242646, 0.11846152308862656, 0.11084748126449995, 0.17845317895989865, 0.1136394334025681, 0.18101482040947303, 0.30803908011876047, 0.1748908552690409, 0.07903240446466953, 0.17433566943509504, 0.1329372322652489, 0.10282326184096746, 0.17423625133233145, 0.12215570415719412, 0.1607244584010914, 0.11489099124446511, 0.16853192617418244, 0.2230933023383841, 0.1832250549341552, 0.1328190229833126, 0.19379427685635164, 0.16401165310526267, 0.14120864623691887, 0.14222158875782043, 0.1671498839277774, 0.10493310604942963, 0.17229421413503587, 0.20670433645136654, 0.09843118736171164, 0.17569849005667493, 0.11432717423303984, 0.09148591707344167, 0.11190146455192007, 0.12767708249157295, 0.15143082506256178, 0.17487700679339468, 0.18531080160755664, 0.13600803154986352, 0.11420508351875469, 0.13052725611487404, 0.12994818796869367, 0.14801773242652416, 0.15256702346960083, 0.07744086135062389, 0.10876416141400114, 0.15435806330060586, 0.2056378999259323, 0.09357507020467892, 0.19320738647365943, 0.2089446279569529, 0.10464321574545465, 0.15925885032629594, 0.1618167365086265, 0.1402083647553809, 0.17937065160367638, 0.14240580465411767, 0.16514323535375297, 0.16588662983849645, 0.10634381746058352, 0.16038997244322672, 0.1096826211141888, 0.2839511336060241, 0.19340168073540553, 0.1557908090762794, 0.17149622726719826, 0.14851180982077494, 0.24014303198782727, 0.12416539553669281, 0.1682601368520409, 0.12920305685838684, 0.17522640991955996, 0.15672202629502863, 0.17596999736269936, 0.20684647257439792, 0.17064437532098964, 0.29111980518791825, 0.22041392658138648, 0.12052778838551603, 0.1381762308301404, 0.21244734234642237, 0.09017354765092023, 0.1152408099733293, 0.17371039517456666, 0.14443212014157325, 0.1151482122077141, 0.18630582868354395, 0.1336889833328314, 0.18962398578878492, 0.1291609028703533, 0.1203269038524013, 0.08463516671326943, 0.13115417794324458, 0.11434824380557984, 0.22676559747196734, 0.13619462231872603, 0.11257308593485504, 0.1061427325475961, 0.11036578289349563, 0.13095744943711907, 0.180376187490765, 0.2173888435936533, 0.1423912585596554, 0.17052716051694006, 0.1194008594029583, 0.19565579103073105, 0.12202809928567149, 0.16051600396167487, 0.10405324544990435, 0.2103293122490868, 0.12398821520037018, 0.18089098564814776, 0.1770894232322462, 0.14704335189890116, 0.08647385984659195, 0.1605689339339733, 0.13315373158548027, 0.10771017070510425, 0.15231271914672107, 0.17238834814634174, 0.13567927497206256, 0.14272791158873588, 0.13388306979322806, 0.12955446378327906, 0.12011798928142525, 0.14209235116140917, 0.1310055109206587, 0.10286679622367956, 0.14581441471818835, 0.1926244146306999, 0.16226459294557571, 0.18064221774693578, 0.13099427480483428, 0.1313520790426992, 0.17141144431661814, 0.1202476944308728, 0.11688509752275422, 0.08931584758101963, 0.1186173444148153, 0.10004089082940482, 0.09227788512362167, 0.14325390133308247, 0.2526960294926539, 0.13668492960277945, 0.12946374365128577, 0.12837545829825103, 0.1789455791004002, 0.1262288703583181, 0.11611131951212883, 0.12794946553185582, 0.09329316540970467, 0.2251207162044011, 0.12332229351159185, 0.12366814175038598, 0.3253757389029488, 0.08327954492415302, 0.18249491520691663, 0.14921453461283818, 0.14180328464135528], [0.01314616089075571, 0.04650684742955491, 0.0379666943626944, 0.04342229243775364, 0.0708286595181562, 0.0067715901059273165, 0.0213595852983417, 0.004020354044769192, 0.032923029066296294, 0.019914299082302023, 0.04371158160211053, 0.052767519882763736, 0.021158951240067836, 0.04503094947722275, 0.06321226508589461, 0.008957883874245454, 0.036241794732632115, 0.06800966351875104, 0.02758030608674744, 0.02855428585462505, 0.018623142095748335, 0.06788990314817056, 0.019101153848168906, 0.031334176237578504, 0.03262424041167833, 0.026311289220757317, 0.007400000404231832, 0.02039531282207463, 0.01571240180055611, 0.02132947265636176, 0.031670220705564134, 0.08479482494294643, 0.016110476826725062, 0.02032628752203891, 0.02781523664452834, 0.035477634955896065, 0.01214175863424316, 0.05852123867953196, 0.051205773997935466, 0.03623294833232649, 0.014679210707981838, 0.03914213753887452, 0.030183845483406913, 0.06851512545836158, 0.037364571398939006, 0.004812797533304547, 0.009486197468504542, 0.016241855519183446, 0.032931107343756594, 0.07519256949308328, 0.03126728275674395, 0.025096386052609887, 0.03885678917868063, 0.003427045244279725, 0.01356167638732586, 0.03809522691881284, 0.034621222512214445, 0.051007791262236424, 0.032212430087383837, 0.01790691207133932, 0.03512193099595606, 0.016482773353345692, 0.11433515974204056, 0.03983138121839147, 0.03668117584311403, 0.025537572437315248, 0.08399563579587266, 0.013981374813738512, 0.05576210802246351, 0.04627850343240425, 0.013415678313322132, 0.012987741120014107, 0.04430275788763538, 0.022948337937123142, 0.010128055946552195, 0.04393936527776532, 0.023104272440832574, 0.0660252571105957, 0.02872856810427038, 0.057852953250403516, 0.007014758966761292, 0.009295992440456757, 0.030094014073256403, 0.0449354387819767, 0.050741601444315165, 0.004232108722135308, 0.06814825959736481, 0.03364024800248444, 0.02831573918228969, 0.05581901590630878, 0.04645054439606611, 0.04283357266103849, 0.13628299726406112, 0.022417681939259637, 0.026944855126203038, 0.013020510650676442, 0.027360075619071722, 0.02065820008283481, 0.025252383638871834, 0.0217076098851976, 0.04418484546476975, 0.026055597081722226, 0.015068393877299968, 0.023315396756515838, 0.04419920973305125, 0.041849937551887706, 0.043236458659521304, 0.03907393416739069, 0.040868829455575906, 0.1203107918263413, 0.042060770574607886, 0.019124594582535792, 0.029944270936539397, 0.005045959460403537, 0.03107425756752491, 0.03888933606503997, 0.028537145954032894, 0.0012922804125992116, 0.04481882140680682, 0.011345693928888068, 0.021606262198474724, 0.032321681646863, 0.04917936945275869, 0.011360069329384714, 0.05189551491639577, 0.033045821110135876, 0.0655669734987896, 0.0017477190476711257, 0.05865150786121376, 0.022429500641010236, 0.04526679287664592, 0.05634404456941411, 0.05565803294302896, 0.08204973200918175, 0.01991239176277304, 0.07204800815088674, 0.039617375514353625, 0.037929497921140864, 0.023759700161463115, 0.039773857351974584, 0.028406746896507684, 0.017885495544760488, 0.05661136245180387, 0.0645921922114212, 0.059455198133946396, 0.07940250608953647, 0.01616721030586632, 0.03448049275903031, 0.031664127673138864, 0.017727919039316475, 0.04697140961070545, 0.016181771243282128, 0.01892487893201178, 0.08788198858383112, 0.007438861111950246, 0.02420143016934162, 0.04373708179628011, 0.038635807286482304, 0.05670866543368902, 0.05032626220781822, 0.047339051016024314, 0.05274778988678008, 0.027242968426435255, 0.033947274496313184, 0.03229183246730827, 0.025282154892920516, 0.04105262603843585, 0.02809326928399969, 0.021610325457004365, 0.023598359111929312, 0.00601070041739149, 0.07907866252935492, 0.044625955779338256, 0.018819375218299683, 0.03904204408172518, 0.07939964139950462, 0.04342661915870849, 0.07993176870513707, 0.03400470930500887, 0.010042343456007075, 0.02948117264168104, 0.015265030542650493, 0.015200267025647918, 0.013702149171876954, 0.04150252709223423, 0.08071454896708019, 0.061140767647884786, 0.07364282413618639, 0.03467070149781648, 0.09858197692665271, 0.04656219680327922, 0.04748942126752809, 0.02577302435383899, 0.07135633393772878, 0.025171253910230007, 0.02175776236981619, 0.08074475437751971, 0.09244745844625868, 0.029101096552039962, 0.02833545433531981, 0.027093256830994505, 0.039471220661653206, 0.01473219634135603, 0.021330858617147896, 0.03431569886743091, 0.017778266337700188, 0.0595697300741449, 0.07109411832061596, 0.02390866033238126, 0.03537257282005157, 0.07111653860192746, 0.02432822424452752, 0.03261192447098438, 0.019230070465710014, 0.04524801282968838, 0.03496476638247259, 0.024612520610389765, 0.043554049625527114, 0.01056955774402013, 0.04133642702072393, 0.05673734201991465, 0.03314806308480911, 0.04213413929392118, 0.024756027851253748, 0.04809389683941845, 0.01671405439992668, 0.060603482415899634, 0.029838804330211133, 0.03957299508329015, 0.0075812055001733825, 0.04961016762536019, 0.04337417529313825, 0.04804888187209144, 0.03578474308596924, 0.038847731266287155, 0.03188683134794701, 0.13104721962008625, 0.025897818341036327, 0.10766656952910125, 0.010976559879054548, 0.07090319340932183, 0.02342591182241449, 0.03563410937204026, 0.053711891669081524, 0.03810599919233937, 0.030745449039386585, 0.03756905905902386, 0.0851285390672274, 0.01273489882805734, 0.010771796696644742, 0.017391779947502073, 0.03516127966577187, 0.10228801009361632, 0.023633477539988235, 0.012171798916824628, 0.058858229385805316, 0.028973042681172956, 0.09337155846878886, 0.0601139321224764, 0.02528038115997333, 0.060981309798080474, 0.07411399143165909, 0.059536927146837115, 0.04220819449983537, 0.04601152322720736, 0.026920648124360014, 0.019533673803380225, 0.036391163084772415, 0.08510353611200117, 0.01492035304181627, 0.05626356978609692, 0.02999093347170856, 0.01652139657380758, 0.01555374639792717, 0.11379233808838762, 0.04583998321322724, 0.07504077060730197, 0.01524877101473976, 0.022765339163015597, 0.061506991551141255, 0.03516026663419325, 0.05024321588280145, 0.012345845534582622, 0.03844309008854907, 0.027307555683364626, 0.07846391192288138, 0.014799176096857991, 0.024239153535745572, 0.04648402267775964, 0.01396641404426191, 0.05009995540603995, 0.014984738991188351, 0.05054999375715852, 0.04913203898468055, 0.017990739506785758, 0.04049054565257393, 0.035195526070310734, 0.019222153605369385, 0.04942483108607121, 0.02069435937301023, 0.0168385645156377, 0.006896699969729525, 0.041900693031493574, 0.020225453772582114, 0.03276522991654929, 0.07069550338201225, 0.04215313085296657, 0.07015387658611871, 0.050395883081364445, 0.0884530192706734, 0.05001179568353109, 0.03872627508826554, 0.030263847147580236, 0.06586150964722037, 0.04371825350972358, 0.026883101018029265, 0.029115165816619992, 0.021955127267574426, 0.04939522681524977, 0.1241160427161958, 0.04292375473596621, 0.07476727434550412, 0.0009236188441263948, 0.025645669957157224, 0.013792606769129634, 0.03763356653507799, 0.06605586328078061, 0.012122131611249642, 0.0314465411065612, 0.09162847622064874, 0.027375135650800075, 0.07732252590358257, 0.010981111099681584, 0.025215652894985396, 0.09594307048246264, 0.014118395683908602, 0.057417412754148245, 0.03455458507232834, 0.03457405160588678, 0.021097041280881967, 0.051560854553827085, 0.04183160279353615, 0.012494005113694584, 0.04334011442551855, 0.06808271311456338, 0.0674061341851484, 0.02307911363459425, 0.06567375370650552, 0.05532398856303189, 0.022948883415665478, 0.02847243995347526, 0.07561041347798891, 0.1141005297540687, 0.08796032969257794, 0.11703360127285123, 0.20163407258223742, 0.1285289492807351, 0.05802139108709525, 0.11962553719058633, 0.2093743611476384, 0.15033764153486118, 0.18630453734658659, 0.1187749023665674, 0.14797954150708392, 0.1438787451479584, 0.1565596295404248, 0.08758748954278417, 0.11061495897592977, 0.08699650250491686, 0.33234984904993325, 0.161009561852552, 0.14175105228787288, 0.13565451692556962, 0.13939891912741587, 0.10879374342039227, 0.09774202160770074, 0.11660053583909757, 0.12085160225979052, 0.08690246497280896, 0.1607915633940138, 0.15534926089458168, 0.04132743590162136, 0.14764659921638668, 0.2649594855029136, 0.24030174768995494, 0.1194988600036595, 0.14894906838890165, 0.1159339165315032, 0.11027350425138138, 0.24176345206797123, 0.16785838262876496, 0.14354102342622355, 0.0986184089560993, 0.10868406883673742, 0.11076326234615408, 0.16976363898720592, 0.13501500827260315, 0.13589599693659693, 0.16625547723378986, 0.08244749347795732, 0.16093225975055248, 0.11314463612507097, 0.17646321386564523, 0.09615492395823821, 0.1551552486489527, 0.18058275687508285, 0.17244694812688977, 0.12131842799135484, 0.11858871235745028, 0.11964117424213327, 0.1793614638154395, 0.15090156986843795, 0.1443324497085996, 0.09247514797607437, 0.1731096563162282, 0.16532927693333477, 0.2080636689788662, 0.07630793581483886, 0.23277994740055874, 0.11727259508916177, 0.20289355656132102, 0.1740087236976251, 0.15152541920542717, 0.32981680997181684, 0.12094556557713076, 0.13451732404064387, 0.1320446067256853, 0.14273984532337636, 0.18790756148518994, 0.08853400242514908, 0.10311903737601824, 0.14065050665521994, 0.1376396432169713, 0.14886158402077854, 0.19914541393518448, 0.1925625788862817, 0.2883158822078258, 0.11717301371390931, 0.20994444930693135, 0.14508966298308223, 0.15114809648366645, 0.08718126759049483, 0.09542361905914731, 0.11314925970509648, 0.1819069858174771, 0.14107293711276725, 0.2101398419472389, 0.1445347591652535, 0.1161322629195638, 0.13677299284609035, 0.16318769106874242, 0.12545253935968503, 0.16190894093597308, 0.0698347159777768, 0.07449710290529765, 0.13648368883877993, 0.11524307352374308, 0.14171759627060965, 0.09338367031887174, 0.17008816532325, 0.16027465753722936, 0.2940200886223465, 0.2036413297173567, 0.22648016747552902, 0.22682879876811057, 0.11072308989241719, 0.20297330775065348, 0.1046416127064731, 0.11597667908063158, 0.1058610800828319, 0.1267419764189981, 0.1296086554066278, 0.06654407770838588, 0.15038093843031675, 0.1334836013847962, 0.12830523628508672, 0.11590489113586955, 0.10063136578537524, 0.13425424753222615, 0.1065268978709355, 0.22399838111596182, 0.1229003825574182, 0.21482687559910119, 0.1374850538559258, 0.13259674975415692, 0.17635132768191397, 0.11368839288479649, 0.11098524613771588, 0.08923155444790609, 0.15762759489007294, 0.11652405009954236, 0.09560593505739234, 0.09964211261831224, 0.07751715413178317, 0.1797043508850038, 0.16300224320730194, 0.13004281179746613, 0.1534758129855618, 0.11886019739904441, 0.12979410326806828, 0.10298544337274507, 0.09785580026800744, 0.08259557420387864, 0.10518526556552388, 0.12213155467179604, 0.2211458029341884, 0.13551831798395142, 0.1750838730367832, 0.08936077720136382, 0.21943601343082264, 0.18105390190612525, 0.06629346928093582, 0.07516151803429238, 0.17614881042391062, 0.11084449783083983, 0.07902654149802402, 0.12324801937211305, 0.12011411527055316, 0.17357965843984857, 0.10780945522128604, 0.16641348047414795, 0.11953866880503483, 0.0859624013537541, 0.149875832721591, 0.12457704258849844, 0.10463185346452519, 0.15598768601194024, 0.1640219838009216], [0.054769912239862606, 0.04674693220295012, 0.03617446338466834, 0.04102821309061255, 0.055365630469168536, 0.0317012795858318, 0.02626949702971615, 0.03416615982132498, 0.09430151403648779, 0.04944673186400905, 0.03624773562478367, 0.01146678367149434, 0.008689494516147533, 0.026301657999283634, 0.03142541216220707, 0.03143351641483605, 0.017627883098612074, 0.02557028259616345, 0.0200034291628981, 0.03684612558572553, 0.0757090820115991, 0.052258799914852716, 0.06938099657418206, 0.04854519313084893, 0.03169947616697755, 0.06896364240674302, 0.046479840675601736, 0.012782825797330588, 0.04220661001454573, 0.05934578330197837, 0.03856659459415823, 0.03278436619439162, 0.028340131721051876, 0.006905295431351988, 0.017252389770874288, 0.03480714534816798, 0.02795355256239418, 0.07332010864047334, 0.03416947722143959, 0.028001079699606635, 0.044494992689578794, 0.056889575062086806, 0.022256101547100116, 0.037124520022189245, 0.0437967949983431, 0.006667093857686268, 0.024042625409492757, 0.021612828350043856, 0.09652665088651702, 0.031530815685982816, 0.05281679848849308, 0.020839452954533044, 0.08345801659743302, 0.03587833161873277, 0.06412921080482192, 0.07989226418430917, 0.09091101979720406, 0.01439647934603272, 0.07690101570915431, 0.045557981939055026, 0.01647209941438632, 0.026640758260327857, 0.05725633702240884, 0.05480683779751416, 0.04378180361527484, 0.07618795279995538, 0.03559258620953187, 0.10341666828026064, 0.10936858874629252, 0.009818909693422029, 0.07951171312015504, 0.0407247303519398, 0.0035688643311004853, 0.08102116727968678, 0.0882160737819504, 0.04689277906436473, 0.042573127066134475, 0.032063918915810063, 0.01603461820195662, 0.07466167415259406, 0.01733439708914375, 0.06327128809061833, 0.03980512032285333, 0.006369770480887382, 0.05465617068693973, 0.05801032195449807, 0.006368693902913947, 0.06419480923796073, 0.03848823864245787, 0.04096806573215872, 0.0295180759349023, 0.04295769685995765, 0.08213778783101588, 0.12996317935176194, 0.15682383411331102, 0.057560250206734054, 0.06959643462323584, 0.05526037537492812, 0.06447178617236204, 0.03682255126477685, 0.069429302966455, 0.01762639880325878, 0.04398873294121586, 0.0805531615333166, 0.06999130171607248, 0.03069999806029955, 0.01668586763116764, 0.0781953361001797, 0.03713273930770811, 0.021763458353234455, 0.036189406528137624, 0.07511796138714999, 0.06742831697920337, 0.1358398757292889, 0.031211688474286348, 0.045886163352406584, 0.04205839570204262, 0.07141781345126219, 0.03435811260715127, 0.05975434301944915, 0.028253938689886127, 0.028621286946872715, 0.026816862482519355, 0.009543815031065606, 0.07228849368402734, 0.06010871482430957, 0.0708681417745538, 0.030285395405371673, 0.014228211275622016, 0.11782450805185363, 0.014006931596668437, 0.01173175172880292, 0.05594624228251632, 0.030584056039515417, 0.01658435481658671, 0.07946325829834677, 0.036221022019162774, 0.01804106454073917, 0.035773031995631754, 0.029062449211778585, 0.028210348646098282, 0.04394625982968137, 0.03582483761420008, 0.05950529310212005, 0.05545512605749536, 0.01797444565454498, 0.0370901363203302, 0.03459761108388193, 0.03805020453000907, 0.07993170191184618, 0.06116551456216257, 0.09957868867786601, 0.04390143782075029, 0.007998467826837441, 0.01740661362418905, 0.03303491525002755, 0.030848924834572244, 0.07223231310490519, 0.09748794735060073, 0.08021680536330678, 0.049833364828373305, 0.030390689462365117, 0.079839230311336, 0.04165310143434908, 0.01899056827824097, 0.024030550666793715, 0.03307725848571863, 0.044785031423089094, 0.06253156723687425, 0.04742470970086288, 0.008347481325472472, 0.038191249695955776, 0.0021314049899956444, 0.008520658702764194, 0.017942099148058333, 0.030912007387087215, 0.03091158807364991, 0.06799340306315571, 0.019718459298019297, 0.03721760389453266, 0.018415778613416478, 0.08528623060556129, 0.03588652121834457, 0.03988829652371351, 0.03550143934262451, 0.025765146456251387, 0.01876564372651046, 0.020620866343961097, 0.0244302342980518, 0.05235023993009236, 0.046610295394202694, 0.03672348197142128, 0.06647565911407582, 0.051827341230819, 0.010626628900354262, 0.036923958323313855, 0.10861542759812437, 0.05145910610735882, 0.05421686379122548, 0.06133431976195425, 0.024136137872119434, 0.08463518155622296, 0.007934012301120674, 0.04686937914812006, 0.015827835450181738, 0.03910561645170674, 0.03868284089548979, 0.021033671146142296, 0.019994037284050137, 0.047945879196049646, 0.029829134145984426, 0.05110071928356774, 0.061862636139267124, 0.022691246849717572, 0.052407132970984094, 0.013085479185974691, 0.056671283455216326, 0.007240509157782071, 0.04360384773463011, 0.02946023851109203, 0.04168598970863968, 0.04687408436439, 0.016273845794785302, 0.06288335265708156, 0.044278367204242386, 0.07429400677210651, 0.0993174898030702, 0.022555500618182123, 0.055693745089229196, 0.01870866348326672, 0.042977601260645315, 0.01187976751680253, 0.034089288164977916, 0.03860571319819428, 0.06630247895373031, 0.013316874337760964, 0.07634239373146556, 0.06873938022181392, 0.019657384254969656, 0.054852661705808714, 0.0950088030367624, 0.03699763503391296, 0.051522203502827324, 0.0401935641275486, 0.023837818625906948, 0.05992630605760496, 0.009232519332726952, 0.04048655660881195, 0.04041798587422818, 0.1324626139830798, 0.043483452827786095, 0.08648381204693578, 0.09740096022142097, 0.07379028887953609, 0.04355143726570532, 0.039733176527079195, 0.07581741330795921, 0.05951476290647406, 0.031085707050806377, 0.03616131252783816, 0.04934132462949492, 0.027010483245248906, 0.003914197704943945, 0.04621678643161431, 0.04355396798928268, 0.10234000495984219, 0.04318413724831771, 0.10604076145682484, 0.061800336552551016, 0.0558181253290968, 0.02996258899656823, 0.04360653430921957, 0.032278113867505454, 0.03754653858777601, 0.03861545388645027, 0.059129699584445916, 0.030502930021611974, 0.021036741782154422, 0.027890714918612503, 0.04583449503115844, 0.09299031720729545, 0.014039715970284306, 0.026982294621120673, 0.011588674005906796, 0.039928665646584705, 0.08629057163489051, 0.037109740151208825, 0.07080612049321644, 0.03502211955492385, 0.09075764013687149, 0.029142163293727208, 0.04418579912453424, 0.07190625794464722, 0.08108318856102414, 0.0602522127883276, 0.04127249099838082, 0.040073135824059136, 0.02838219665136421, 0.06608969779335894, 0.0314273306139512, 0.10593322425847873, 0.07785683512338437, 0.0188491835797322, 0.10231821550405584, 0.042459964388399385, 0.048407387439510785, 0.016857505979714915, 0.020136459133937024, 0.05709150602342561, 0.08409421527176164, 0.05129991171997972, 0.021563570153375622, 0.14592650870326906, 0.04083115803950932, 0.05579480333835818, 0.004890857553618844, 0.06666201239568181, 0.015654581075068563, 0.06844929695944302, 0.03167894094076473, 0.04153964560828172, 0.030204020767996553, 0.0384965321427444, 0.03478760459984187, 0.02151096115994733, 0.002026433999162691, 0.03988199940067716, 0.0544175516552059, 0.04128506298002321, 0.08615487735369243, 0.05936400673817843, 0.028789144053007476, 0.02749170107563259, 0.052581244526663795, 0.04553376566036604, 0.05411046578956302, 0.03409468357858714, 0.02127775238477625, 0.03225081025448162, 0.020466286259761546, 0.04161796074185986, 0.05871801542525645, 0.044919905631104484, 0.07252051873365417, 0.029261415293149184, 0.029568519712483976, 0.03437206869421061, 0.029468168359017, 0.015889008827798534, 0.02985076960612787, 0.0648131815250963, 0.06377542900736444, 0.09201216656947508, 0.13755349471466616, 0.13013813324505463, 0.07674834108911455, 0.08003338356502354, 0.12013201587251388, 0.1946591163869016, 0.1442824289551936, 0.2181102111353539, 0.08667719346703961, 0.11363354075001553, 0.1295603861217387, 0.20796941622393206, 0.07713695187703706, 0.1508145159459673, 0.15033673611469567, 0.0901226511632558, 0.11586799155338667, 0.12276921537704766, 0.11961095398874022, 0.16347058292012662, 0.1854646488209255, 0.162018867849838, 0.12424077547620982, 0.11858595156809315, 0.13815732090733945, 0.0945528200827539, 0.14916427637217566, 0.0726026447955519, 0.12028233788441867, 0.10484377373359166, 0.060515370932989754, 0.17587240494322032, 0.2287444451940246, 0.1755107712233439, 0.12447964312741533, 0.10762987032649107, 0.2357307859347202, 0.16379846376366913, 0.0927480282553006, 0.12638988671824336, 0.15033795323688537, 0.1467969291843474, 0.1244920889439527, 0.17583369452040642, 0.2965396799845621, 0.08739211916690692, 0.1418963202740997, 0.15814660844625905, 0.1813348344876431, 0.15789295721333474, 0.30227378010749817, 0.210896817734465, 0.19768771715462208, 0.1534394922782667, 0.17203956842422485, 0.3014082578010857, 0.1519146459759213, 0.16604139731498435, 0.10156440868740901, 0.284648752422072, 0.1194384194968734, 0.12960032850969583, 0.32050781417638063, 0.2269604112370871, 0.12855672044679523, 0.11143693947815336, 0.20470307586947456, 0.21512907813303173, 0.1550793120986782, 0.20811953785596415, 0.1627554791048169, 0.16152182186488062, 0.15001412451965734, 0.18103451700881124, 0.174805493443273, 0.2204749608063139, 0.1472057931823656, 0.11754725652281195, 0.21238310204353184, 0.19037475722143427, 0.12341000052401796, 0.18316492612939328, 0.1376066918601282, 0.28609291242901236, 0.25349817238748074, 0.13423512980807573, 0.15249044867232442, 0.10755062379757874, 0.25061635358724743, 0.1604183076415211, 0.1841816387604922, 0.21092121955007315, 0.17080855323001742, 0.24538161495001987, 0.17366298678098246, 0.17366942862281576, 0.15058781951665878, 0.21435013477457687, 0.25227624108083546, 0.11542766049387865, 0.10152088914765045, 0.0983743833785411, 0.14143402164336294, 0.24326649407157674, 0.1386579143581912, 0.1579296193085611, 0.2537452185060829, 0.15173651569057256, 0.20033120264997706, 0.1573805042426102, 0.17233952967217192, 0.2488091349368915, 0.22243780782446265, 0.09847182736848481, 0.12784225487848744, 0.16601120674749836, 0.1762788643827662, 0.1468823800678365, 0.20635445835068822, 0.12688001588685438, 0.12330801459029317, 0.16591131367022172, 0.12748269917210564, 0.26741759735159576, 0.17555369704496115, 0.1465029051178135, 0.29044833965599537, 0.1054213872703258, 0.20336664601927623, 0.12130344402976334, 0.06824531767051667, 0.21763908094726503, 0.18308928643818945, 0.19321186904562637, 0.149923152057454, 0.18052672472549602, 0.12376667669741437, 0.136017709155567, 0.10533121632761322, 0.1401861448539421, 0.09414533647941425, 0.20345650525996462, 0.21704735176172107, 0.13683905883226544, 0.1914361322997138, 0.11915247741853818, 0.09096354900975712, 0.10343822767026722, 0.09308563865488395, 0.10940672771539539, 0.14294213993707672, 0.2624970691977069, 0.1400721212849021, 0.12809318985091522, 0.10543833050178364, 0.08012366582988761, 0.1893212489085272, 0.31006707285996526, 0.19349674985278398, 0.17590712261153385, 0.31116462021600455, 0.12055552986566909, 0.1114690225222148, 0.12126975794672035, 0.20232760958606377, 0.2140462104580365, 0.12942250992637128, 0.14935413259081542, 0.13355884031625465, 0.09511223615845665, 0.13666241284227, 0.06847801807452925, 0.0705807154008653, 0.12764062819769606, 0.13051060232101008], [0.05188030831050128, 0.036821950125158764, 0.029395738456514664, 0.061378210375551134, 0.05205692090385128, 0.08840799317113124, 0.048858843292691745, 0.021530822887143586, 0.05399640511313919, 0.01756700101395836, 0.05323650155332871, 0.01574696918396512, 0.033485398889752105, 0.014889636477164458, 0.032319265956175514, 0.06200582611199934, 0.009168214091914706, 0.02762419855571352, 0.09684119533631019, 0.008335362053912831, 0.028571731891133823, 0.03198267972038593, 0.048217716757790186, 0.03035889400052838, 0.02443531800963683, 0.03631048050010577, 0.010104028915520757, 0.08186289633158594, 0.07982207927852869, 0.010063087411253946, 0.02946918881207239, 0.033448655158281326, 0.045789665600750595, 0.06486595564638264, 0.07138265791581944, 0.06238074056454934, 0.01283892102946993, 0.03937244080589153, 0.031081105735211167, 0.04293641206459142, 0.03540697507560253, 0.042416185096953996, 0.03320714917208534, 0.0845767225837335, 0.009424238342035096, 0.04243341776600573, 0.05996801846777089, 0.06691940405289643, 0.009634359830670292, 0.026211117838101927, 0.06059334467863664, 0.04628264832717832, 0.08051166063523851, 0.09863182698609307, 0.07728333308477886, 0.01305498155488749, 0.059106711560161784, 0.06851437588920817, 0.11895162999280728, 0.040380499995080754, 0.04416558673256077, 0.06725421655573882, 0.043333898938726634, 0.06380689606885426, 0.06338004241115414, 0.07147697746404447, 0.03820755839115009, 0.011651336317299865, 0.04680774378357455, 0.07958377565955743, 0.048599915389786474, 0.06965648179175332, 0.024328599029104225, 0.12745522486511618, 0.1132033474277705, 0.15883435669820756, 0.05326242848241236, 0.02543544178479351, 0.06445692095439881, 0.05920855648582801, 0.024131915051839314, 0.025091612187679857, 0.044245375029277056, 0.03435984181123786, 0.08888843731256202, 0.06105144646426197, 0.023515598513768055, 0.0953660580853466, 0.09719885114463978, 0.04085124426637776, 0.016182114486582577, 0.169217447983101, 0.13921261037467048, 0.05585895458352752, 0.040006954804994166, 0.0992740667425096, 0.0696770021750126, 0.02691250861971639, 0.030098741553956643, 0.06445597842684947, 0.09096282912651077, 0.02787022793199867, 0.00691002012899844, 0.02119268370734062, 0.04462465331016574, 0.03469995324849151, 0.0475770614866633, 0.0476291157247033, 0.03492446776363067, 0.07551204180344939, 0.010973133012157632, 0.04353089832875412, 0.06875126200611703, 0.035521425379556604, 0.018522237842262257, 0.016136815647769254, 0.02073673971608514, 0.022736627324775327, 0.02887223490688484, 0.0322918473102618, 0.043368134211050346, 0.040349767659790814, 0.016924371630011592, 0.057776270841713995, 0.03059422531805467, 0.01410214264979004, 0.038086888889665715, 0.03635001841757912, 0.03384980453120079, 0.025875427745631896, 0.027688399895851035, 0.035976762665086426, 0.010953572782455012, 0.03337072594149504, 0.027653671095322352, 0.012742154249281157, 0.051857435319107026, 0.0076453836481960025, 0.04819033892999869, 0.027544952026801184, 0.03591749475162942, 0.042652332776924595, 0.02657946984982118, 0.0182500718801748, 0.03217434677935671, 0.01665154330112273, 0.041407673197682016, 0.034614164687809534, 0.01951988655491732, 0.07432996382704005, 0.052555595902958885, 0.014560570980393095, 0.031499541582888924, 0.037156283942749724, 0.002523617513361387, 0.03268752705480438, 0.031522344070253894, 0.026584156512399204, 0.04522621224168688, 0.01155630059656687, 0.028385068762872834, 0.03907081343641039, 0.0771046090812888, 0.056624702556291595, 0.004550401481537847, 0.09600373363355175, 0.040941055267467164, 0.00901469064046978, 0.012075111917511094, 0.04419484961545095, 0.041177366219926625, 0.0703167260508053, 0.017667851461737882, 0.024640907759021502, 0.01389330785968923, 0.009278953657485545, 0.017271227334276773, 0.03194369470293168, 0.011312832557450747, 0.01406042374583194, 0.010329239194106776, 0.04411319852806628, 0.024907524311856832, 0.03075010230531916, 0.02528788612835342, 0.030991491403256077, 0.022794646574766375, 0.070724461984355, 0.05513796924788039, 0.004891237904303125, 0.04311654614866711, 0.03253934613894671, 0.018958166110678576, 0.04049335839226842, 0.01596540922037093, 0.043932418775511906, 0.02179355429689167, 0.01131078237449401, 0.03516382523230277, 0.01322109925240511, 0.018922697017842438, 0.03092507104156539, 0.02553407506638905, 0.0710963447636459, 0.03199104372470174, 0.015612456772942096, 0.08925788584747352, 0.0604895998549182, 0.03176605052431114, 0.032313803749275394, 0.04525510776147712, 0.03588139297789894, 0.018130856988136657, 0.05654105138091836, 0.0723325030412525, 0.04448786065040622, 0.06359005536069162, 0.016745183784223627, 0.047330456945928745, 0.05411230260506272, 0.03738667626748793, 0.11279548532911576, 0.01275736271054484, 0.014809653366683051, 0.039952006191015244, 0.06914453348144889, 0.09214660662109964, 0.05357555543014314, 0.0390271009382559, 0.03327054713736288, 0.041826285305432975, 0.01881211701402208, 0.06143032027466688, 0.03867186824209057, 0.038307841095956974, 0.018407141869829502, 0.09566599706886336, 0.06392584007699043, 0.08847325763781555, 0.014050408462935593, 0.04496936977375299, 0.022375221815309487, 0.030565305678464938, 0.02202764622779796, 0.016292336404148955, 0.06163519385154359, 0.07039370902930386, 0.06028270763636101, 0.0656967083341442, 0.05492282063642051, 0.06554910258273594, 0.07908834013505839, 0.08930831478210166, 0.027315147854096722, 0.03482324995275121, 0.06965050750295632, 0.027984591033600736, 0.04790402206708677, 0.06700138168525882, 0.0900454084330704, 0.06729809974785894, 0.07592600435600616, 0.00906263709111954, 0.05141412082593888, 0.11009845387889072, 0.004243625926392269, 0.04569789904053323, 0.11659383424557745, 0.05836380318214651, 0.05563174607232213, 0.06624381217989139, 0.06872935380670242, 0.02024525798333343, 0.01834619299188489, 0.06265291580348276, 0.038879012790857814, 0.06546076474478468, 0.0506354928802466, 0.044269483696552925, 0.048868461526581086, 0.05433763719338458, 0.023483879122068174, 0.03284961210738402, 0.06343516914057545, 0.03650142396509182, 0.05108626966830343, 0.024003465987334494, 0.033854572830023244, 0.06021939501806628, 0.046933968260418624, 0.024372886691708118, 0.023957606827025302, 0.0403520720283268, 0.11610221336013637, 0.05072907399153337, 0.042861477413680404, 0.03834465162071865, 0.01469540622565546, 0.02740745618211804, 0.04822020295250695, 0.04735543392598629, 0.023202254487841856, 0.0512875215645181, 0.05017962866986636, 0.041427948672208004, 0.038735347843612544, 0.06085056935262401, 0.034481535476516, 0.030823463603155687, 0.049604928062763065, 0.03113240483799018, 0.01470089069698588, 0.03966545555158518, 0.009473939971940126, 0.08548759753466584, 0.05347861610061955, 0.030194773607945535, 0.08578576278523542, 0.06492408807389438, 0.05242536382866092, 0.04653133830288425, 0.021513766478165053, 0.03189289098372683, 0.05058857801486738, 0.01688755368377315, 0.0402914756705286, 0.02915564997238107, 0.03141230954497587, 0.0359127635601908, 0.04722234087239485, 0.06402674989658408, 0.06373715645167977, 0.05970832615275867, 0.016067833021224942, 0.05803113919682801, 0.020590705462382175, 0.04892691307759378, 0.10653023753548041, 0.07888404914410785, 0.011320756839268142, 0.027550646154850256, 0.017249654956685845, 0.05277275944536086, 0.05730062097427435, 0.03238015175156761, 0.030992697393230628, 0.004561321720757405, 0.0439047997497255, 0.033551338710822165, 0.053456466703210026, 0.06103967971284874, 0.021006733040849213, 0.12902327900519595, 0.18764822540106252, 0.07060537696816027, 0.1371839497005567, 0.09324191269115545, 0.2277361782034859, 0.15900444210274145, 0.12684264132985845, 0.11764420327381231, 0.08481119672069326, 0.10038308770162985, 0.15661696786992252, 0.16091290453914553, 0.057932455820264295, 0.11087016871897504, 0.16302239993819967, 0.1362787076504901, 0.08436673189862631, 0.10853869694983587, 0.14928000688087195, 0.15882285340921953, 0.1916203333530575, 0.18154533725464717, 0.1480230165179819, 0.08076907455688342, 0.1225419549155049, 0.10048691416159272, 0.27684652421157807, 0.25516895460896194, 0.14145312452455983, 0.17536951083457097, 0.2025931203388609, 0.18816761003108695, 0.26663519558496773, 0.23374591197352856, 0.10181069781538099, 0.14326344535220414, 0.16222300298977643, 0.18133170262444764, 0.12739377503748983, 0.25794437911827117, 0.0585191495338222, 0.12241626478498802, 0.14152961026411504, 0.09187754840240814, 0.14070950739551336, 0.2076584118185565, 0.08925730697228573, 0.12196574403787963, 0.10148888773983344, 0.23987818916793913, 0.21233723731711507, 0.1444820815231651, 0.1697733165929094, 0.14509561500744894, 0.13478488312102854, 0.21091508941026405, 0.18446956237312406, 0.37160497857257724, 0.12506058148574084, 0.16072453261585906, 0.12407675341819413, 0.20403000729857013, 0.2182727711624466, 0.1440312119666487, 0.14697149716084823, 0.1477717253146693, 0.10923545487457886, 0.15190676436759531, 0.1975546352332458, 0.22685698553686962, 0.13211430923547596, 0.13423977565253153, 0.2420290667214431, 0.16711087664589286, 0.20823586208280176, 0.18264328537043184, 0.07424610856105573, 0.1740209394483827, 0.2520292840199545, 0.13454809348331764, 0.18513157294364646, 0.21006970899179578, 0.19926026870962232, 0.17421713360818103, 0.20045251410920173, 0.12071461664163508, 0.13367452629609033, 0.26316069765016437, 0.13042954495176673, 0.12374782614642754, 0.2609245473286137, 0.3105747315566987, 0.16622429218841717, 0.16720435756724328, 0.17357005504891276, 0.225793769932352, 0.10816345224156976, 0.15548053197562695, 0.07292884096386842, 0.2537950611440465, 0.17983814526814967, 0.12146126915467903, 0.0933055073255673, 0.10169210261665285, 0.10221915363217704, 0.08293406033772044, 0.18086579715600237, 0.09398179681738839, 0.19115181552479044, 0.10603088347124867, 0.153916678391397, 0.14908805780578405, 0.22887062514200807, 0.19668655993882567, 0.10142017970792949, 0.15271687792846933, 0.1869452334358357, 0.10059615829959512, 0.0795824769011233, 0.14924655086360872, 0.08748767810175195, 0.08642931614303961, 0.19709365762537345, 0.13720388378715143, 0.08083113294560462, 0.11611445879680105, 0.16461316379718482, 0.12176317482953891, 0.10708220244850963, 0.1484299509320408, 0.10401492094388232, 0.12415358796715736, 0.11483436537673697, 0.08144344188622199, 0.11479563268949278, 0.10611124322167598, 0.113131351681659, 0.12530418403912336, 0.11054705246351659, 0.08255906053818762, 0.19382722821319476, 0.118627459887648, 0.15214664133964106, 0.16014651831937954, 0.07111514336429536, 0.12260716001037508, 0.10653250850737095, 0.08720497178728692, 0.19008897099411115, 0.13999064831295982, 0.12773603870300576, 0.1869731827173382, 0.12665784655837342, 0.18267844832735136, 0.13359795149881393, 0.17647013068199158, 0.12000593240372837, 0.15237964602420107, 0.062445708172162995, 0.11906177212949842, 0.17176023888168857, 0.16817516094306484, 0.12826496735215187, 0.07907884064479731, 0.19979492673883215, 0.15742659161332995, 0.17318259458988905, 0.11543439177330583, 0.17731830157572404, 0.06759869924280792, 0.14189390087267384, 0.08522795716999099, 0.11656925431452692, 0.18278413015650585, 0.08373291551833972], [0.03241548540245276, 0.012172063306934433, 0.10596858017379418, 0.012983867109142011, 0.0529696141165914, 0.025289253535447642, 0.05604427999060135, 0.06220910407137126, 0.05815581629576627, 0.05962544310023077, 0.05167664072359912, 0.12646465067518875, 0.02052542429737514, 0.016283994664263446, 0.047218982654158026, 0.03765944151382428, 0.018754450284177437, 0.02419252439722186, 0.019312285585328937, 0.10755914365290664, 0.018699683496379294, 0.04949340182065498, 0.00743908375625324, 0.04034548175695818, 0.03629865066614002, 0.018064861505990848, 0.010453115701238858, 0.021946061933704186, 0.005799383607154596, 0.04372752664494328, 0.029128288842912298, 0.019470489205559716, 0.03320239200547803, 0.016425101057393476, 0.03784945729421452, 0.06401175851351582, 0.07722644746536389, 0.050303971802350134, 0.03248770379286725, 0.04203082120511681, 0.013797287865600083, 0.05581440345849842, 0.05940328861470334, 0.016983966088446323, 0.044689060596283525, 0.03332915082864929, 0.054327132093021646, 0.08741828729398549, 0.08957159167039208, 0.028787596675101668, 0.04625651359674521, 0.04073888681887183, 0.062351893284358084, 0.06963754960452206, 0.03281946977949701, 0.043361581047065556, 0.027293850071146153, 0.030378304873011075, 0.04338062084570993, 0.04488861668505706, 0.07513494914746843, 0.028044732825946994, 0.05036959621065762, 0.1118507758656051, 0.07454725724528544, 0.03899251685652416, 0.016066159478214104, 0.010057904437417164, 0.07615585491294041, 0.07168118681875058, 0.04782346935826354, 0.036983871905249543, 0.04614378136466257, 0.10370253614382818, 0.11502082998049445, 0.14564873767085373, 0.03338913120387588, 0.03422585075895768, 0.034023404004983604, 0.08390739443711936, 0.05132829144713469, 0.025186111706716474, 0.07021952696959488, 0.07432352940668352, 0.03798877325607464, 0.04930877774313558, 0.043305682484060526, 0.13275356555823237, 0.1028119663533289, 0.12332832717220299, 0.1367565171676688, 0.13624681014334783, 0.20042584132170305, 0.21560222696280107, 0.1454784593079239, 0.17627429275307804, 0.030854127289785538, 0.038675022369716316, 0.10274178144754842, 0.1494253787677735, 0.05371427767386194, 0.04205981320410501, 0.019754993372771423, 0.050643608265090734, 0.018576357106212527, 0.046776384333497845, 0.11063013589591719, 0.07305654231458902, 0.020973466271243524, 0.07943074480863288, 0.03204857501259539, 0.014986725163907977, 0.04470326530281454, 0.010943699435301824, 0.043419245921541005, 0.015809129617991857, 0.027637887469609268, 0.018914950851467438, 0.1176420807314571, 0.059968289351672865, 0.08834194202790968, 0.03653264240710996, 0.008387512771150796, 0.041151947662001476, 0.05249966023257002, 0.031749600821058266, 0.07492493619793095, 0.03418058346142061, 0.047604943974874914, 0.0568415284215007, 0.060231644165469334, 0.05745647940784693, 0.07237398909637704, 0.05120890215039253, 0.025209522755176295, 0.025191171298502013, 0.023251406928466167, 0.04975841904524714, 0.05058442198787816, 0.027676037570927292, 0.02349729900743114, 0.046344346774276346, 0.04913423203106504, 0.043547600362217054, 0.04356979799922556, 0.03128916498098988, 0.038730906089767814, 0.041565476058167405, 0.02815280808135867, 0.024979067347885575, 0.011995342174486723, 0.017071899455913808, 0.06708145199809223, 0.07553369025117718, 0.016130542644532397, 0.05574207745667081, 0.0430729041545419, 0.0466294168290915, 0.01819542383600492, 0.014299084523372585, 0.03919124916137662, 0.0687191121687647, 0.04013398822280578, 0.09926664526574314, 0.04868827549216803, 0.06684898908133619, 0.03893870372849051, 0.046013946339371614, 0.03229884576285258, 0.04817990804440342, 0.04295368926250376, 0.055521032481919974, 0.029959288294776343, 0.05329683073796332, 0.02467690563207725, 0.11949216583161615, 0.01618791251530638, 0.06950084600248374, 0.058567500454955734, 0.04704815881268587, 0.03499564714729786, 0.015206298830889864, 0.05605813959846273, 0.026703152470872737, 0.06492914952104911, 0.06247098572202958, 0.028694548054772895, 0.08962559775682166, 0.048509440166526474, 0.019914681288355496, 0.023107990600692574, 0.06370887320372276, 0.031194804614642635, 0.02627218360430561, 0.07513182470574975, 0.06458721240051091, 0.02467905043886276, 0.03614777946495451, 0.022271890738920774, 0.016952710539044347, 0.029716784119955264, 0.025343443303427193, 0.050012775318464264, 0.022967685727053322, 0.008480951019009808, 0.04552776168566197, 0.030908979424566496, 0.07061849813908339, 0.06884211572469212, 0.028378864408296067, 0.09359142713947222, 0.026592399917717557, 0.03897478323779069, 0.04022878274554387, 0.04229694794048555, 0.02785355187370442, 0.011405674304114655, 0.03867694453219883, 0.014801231845922302, 0.0152188838001166, 0.043172641380806454, 0.07213777833385393, 0.0342578039271757, 0.07271813781699166, 0.038209128033486195, 0.028889200402772985, 0.11849826682009734, 0.05013061352656223, 0.09272966010030359, 0.032272562602884136, 0.06932181029696949, 0.05182816501474008, 0.0314744718343718, 0.022562150261364877, 0.03691750163852703, 0.019787733217526693, 0.06097759534895886, 0.021066642912046518, 0.12208885891595855, 0.04862537105509546, 0.06386869470588863, 0.04893035293207504, 0.059843122435268015, 0.010307640841347165, 0.031334784798673354, 0.0907754962099716, 0.1362587438779883, 0.05926368692598771, 0.025098241421801504, 0.014369050495588453, 0.07543082858319394, 0.19758056587306783, 0.11537004756974056, 0.11629751694272272, 0.09634728863602504, 0.18134512065444142, 0.08042730070883408, 0.06431819128920324, 0.10690096256439574, 0.05752548429882154, 0.04961759281286504, 0.036429502433747984, 0.035201114442315884, 0.03580639524443541, 0.06467650018748827, 0.016053811996243894, 0.07918086368590593, 0.06960350729059428, 0.1452165999216959, 0.1200652151601389, 0.11507028670166619, 0.09548061600071378, 0.07262417449965142, 0.045082380311214365, 0.14092293422436342, 0.11296675816993229, 0.019536334402801003, 0.06514229433378205, 0.05694555526133627, 0.033462102874182165, 0.033805056737037376, 0.022898166898812633, 0.08334382233442739, 0.09148842553258874, 0.06378054240485653, 0.09023985854582861, 0.06742302546626888, 0.015279235249181511, 0.09898534161038697, 0.0514244515215978, 0.03228211404348258, 0.0406768358516274, 0.015218410680972738, 0.019550544675439596, 0.05150830307684373, 0.11818070182926022, 0.0486827502027154, 0.03613265449530445, 0.05396352426032536, 0.07435711158905178, 0.0023412525797539274, 0.03731401629920583, 0.02058277004834963, 0.030765004630666226, 0.05297778516251128, 0.045463948117685504, 0.02778723541268846, 0.03724393900483847, 0.0048299527406925336, 0.024619166542834137, 0.034503447386668995, 0.04722834855783731, 0.011579777510632994, 0.07238591540954076, 0.06891204087878577, 0.04647981470043305, 0.026914623740594834, 0.016271574822894763, 0.038133436391945, 0.0544800070929341, 0.025392434326931834, 0.03728157331352122, 0.012121714153181529, 0.01758556954882806, 0.03210301525541581, 0.046381743595702574, 0.028809018767788075, 0.06150450535642449, 0.043595053284661844, 0.00850483518661349, 0.04589590404066257, 0.04937617588439025, 0.05703375209122896, 0.04354004158813041, 0.0369557074009208, 0.02384282441198593, 0.010694312768464442, 0.06753240319085307, 0.0670653251290787, 0.06099049387557898, 0.022718893706041854, 0.005291308380037663, 0.04506076897087041, 0.05659202208335046, 0.06023800808179658, 0.028330250024737325, 0.030543638677045237, 0.08144523788359948, 0.016243979916907847, 0.027535443259694148, 0.02254144063044805, 0.10139712860109285, 0.18535164941567928, 0.09247184541891329, 0.17771312413970008, 0.13084675068967044, 0.15932749898638576, 0.12583628908032551, 0.22890776221174747, 0.09281093269237317, 0.14145291672321036, 0.182998952222988, 0.2121677901595831, 0.21275626873830333, 0.22449682233855128, 0.09546651519485749, 0.197484873351641, 0.16002952615963295, 0.09384283708641306, 0.11085056117735803, 0.11632108013145626, 0.2389405746362172, 0.15484118659514934, 0.15743471070891246, 0.13341983605641872, 0.15957767696818337, 0.1302085185307078, 0.11503065601573326, 0.24132074613589793, 0.13193212682381272, 0.10321559821022674, 0.09564369553118013, 0.09935972542734817, 0.24683993513463065, 0.21423189580673352, 0.2336186039610766, 0.12254764718818478, 0.12150012800702825, 0.21975169336656108, 0.1661151964799501, 0.12539959454443306, 0.16348171513527632, 0.16306710691424087, 0.2295445100753568, 0.1325414449092932, 0.09238478407496586, 0.1832115775323473, 0.11997586800134741, 0.12585369986481965, 0.1823579444317147, 0.13202660222304985, 0.10050523036625236, 0.21822120674187317, 0.16536932322196662, 0.18330939259612933, 0.22962199029279873, 0.14043642673641443, 0.34827286493964493, 0.17280957632465288, 0.1714553200872615, 0.1572865483467467, 0.1529482944170013, 0.18409446609439328, 0.09908925712807104, 0.22748304647393525, 0.20248913060640916, 0.10721017839387059, 0.11188656964804977, 0.17956631141714752, 0.11796858860179782, 0.2219436562154442, 0.17830987024353817, 0.18349454359849915, 0.12841378280427307, 0.15144139324547723, 0.17787783639505506, 0.2928715408779681, 0.24216492427513003, 0.29516222421079874, 0.202727701398544, 0.23025079717626795, 0.2674479957204312, 0.231146109290421, 0.24813717958750203, 0.21444616868393496, 0.19316450518090278, 0.16010578925488517, 0.11488637508591637, 0.13495306862751022, 0.3365346713690087, 0.17893300711875781, 0.2106726446072571, 0.32494576822500676, 0.31144877371843904, 0.4154711903538555, 0.333717567846179, 0.3197209595236927, 0.3583149245241657, 0.1377613257500343, 0.2261671592714265, 0.206229065079242, 0.391578339622356, 0.18152923265006393, 0.15654888324206695, 0.16683982947142795, 0.18129312578821555, 0.11467466261819936, 0.16665285278577358, 0.2077673442545347, 0.2212790332851, 0.23831013502785936, 0.21431011817185208, 0.18181169405579567, 0.1380740964668803, 0.28661232674494386, 0.22593272966332734, 0.1348079342278652, 0.19781452050665393, 0.12501753692049533, 0.12659129075473174, 0.14893661515088752, 0.2840740035753697, 0.1794825674733147, 0.10562017894699238, 0.11978653870755807, 0.1869052168331109, 0.1287130019045435, 0.1900477966410108, 0.08431164227658883, 0.12034309009322897, 0.1418136153370142, 0.09954405264579691, 0.14556091191479936, 0.145219583355356, 0.09706574695883319, 0.21599584724754095, 0.14687540387967601, 0.10223505785688758, 0.1043750109965913, 0.13722928008064628, 0.14190102549036965, 0.09305430517997593, 0.1648435858078301, 0.10166079882765189, 0.17041107377735898, 0.13467501557897776, 0.12382071246975102, 0.1233589778712485, 0.11560533064766787, 0.12233224624651484, 0.12942158966325223, 0.18354794854531065, 0.1815079478546977, 0.1363232365110889, 0.1363961599417962, 0.11732308339560404, 0.1252594028483145, 0.18038009118754417, 0.11830560528323986, 0.13255425437819213, 0.13804969465127215, 0.1020657665503677, 0.12047453928971663, 0.20680837071267888, 0.20022307173348963, 0.23815464024664834, 0.2776663302211091, 0.15006555535364896, 0.11986637153313495, 0.16737150406697765, 0.16480247082654387, 0.2715919108595699, 0.08376536221476272, 0.16365117713576183, 0.07482329907361418, 0.1002065307693556, 0.17882137326523662, 0.22000454307999462], [0.03994398357463069, 0.05866510029591154, 0.02714998474402819, 0.056041597126750275, 0.05957618304819334, 0.051069036999251693, 0.12809501553419977, 0.014089952874201117, 0.052182061845087446, 0.06304095513769425, 0.07687118137255311, 0.022161830238474067, 0.052971269105910324, 0.04395670926896855, 0.022731378485332243, 0.06613788544200361, 0.02110388202709146, 0.01167830503618461, 0.03195694574969821, 0.016726385183574166, 0.023706770189164672, 0.02857292303815484, 0.05126823685714044, 0.002716409157983435, 0.07205011585028842, 0.04695691546658054, 0.016486480380990542, 0.07528380912845023, 0.04083532890945207, 0.023053902878018562, 0.030733823296031915, 0.02464522149239201, 0.029062057728879154, 0.03802865627221763, 0.07380119102890603, 0.0755450822180137, 0.009343747788079781, 0.020488051595748402, 0.09265264743589796, 0.02973658647533739, 0.03704730697791092, 0.06653627031482756, 0.04004200643976219, 0.04275679006241262, 0.07330894673941657, 0.011763663151214132, 0.023514830390922725, 0.02266399889776949, 0.016313719534082338, 0.04423741178470664, 0.06012543170072604, 0.042366149500594474, 0.031291591803892516, 0.10365287904278375, 0.05264685409201775, 0.030276344914454967, 0.08177566429367289, 0.04258497545379214, 0.08235867324401625, 0.024295065086334944, 0.21811334299854934, 0.028899540375277866, 0.10789680600282736, 0.0397225304186577, 0.1048487238585949, 0.060496702208183706, 0.019323074557178188, 0.011343517580826301, 0.08945519322878681, 0.030532157652487513, 0.1427460348349996, 0.02506379649275914, 0.08057328857830726, 0.14666255592601374, 0.23340283194556832, 0.2269193110987544, 0.07682649666094221, 0.016629597994324286, 0.03304147954622749, 0.05745401547756046, 0.059638211751007475, 0.05365723991417326, 0.013611488411697792, 0.04946640990965534, 0.05326827660610434, 0.017634170944802463, 0.10547444340772927, 0.05274250950606074, 0.08147206652211025, 0.04567056203086395, 0.0634394735971, 0.11316269999952056, 0.15270831354428083, 0.09310686407843605, 0.1593413919908926, 0.18657433771295473, 0.0833009484631475, 0.021989659398968797, 0.0674149212136399, 0.08501164338667877, 0.07510538198403083, 0.06134414208645467, 0.05842105245392304, 0.038857219624333084, 0.04341799911344424, 0.12435765631380491, 0.06277284686802886, 0.041137683583656326, 0.0786219745350536, 0.03976788677391596, 0.03190147392160725, 0.041120595633401535, 0.04238347122736741, 0.01792487018974498, 0.011431400853325613, 0.049630988578428514, 0.03494793447316624, 0.08394349992158823, 0.020536975825962145, 0.03562724821676966, 0.10549699727562256, 0.021646553395839874, 0.03484368498902768, 0.06418810022296384, 0.08182916571968235, 0.051947713873232715, 0.020826853142352775, 0.05824908570502885, 0.005670337577612372, 0.008920205964386696, 0.008929710093070753, 0.04297976833186112, 0.009390639461344108, 0.07219020364573225, 0.04879415770119522, 0.025356837213621475, 0.04318936567869969, 0.03746928101463709, 0.06490234314696863, 0.019028937313123606, 0.04710844346845988, 0.04487857913773041, 0.043051893953816034, 0.05531772483664099, 0.026509130948397797, 0.06194518522534054, 0.08247651887359098, 0.052408097762963735, 0.025060846455744468, 0.025254825304728, 0.04918868711683899, 0.07769308023853227, 0.05480148320202716, 0.004163674821029417, 0.01706923885649303, 0.023622152366442606, 0.019112068985123187, 0.04628396935004275, 0.04482314812776167, 0.10015713341999799, 0.034439080918673426, 0.022900107614987064, 0.04401606252940837, 0.022347723388520535, 0.009926216825988377, 0.02783155276119942, 0.032325199426850304, 0.022311886932584457, 0.041572396585252136, 0.0472126150270924, 0.011850816335936543, 0.0053285827470972436, 0.0551687535335077, 0.020477602156461217, 0.017827539377321955, 0.02762353433354292, 0.031249912790372036, 0.07191876313299872, 0.026671164050640073, 0.02171616128180176, 0.07739900422166102, 0.03843914186290931, 0.058736791761475615, 0.08703417392098345, 0.0014010056270308269, 0.09556788514601067, 0.03384842784726061, 0.043424455798231065, 0.04702003512647934, 0.05074221742688678, 0.05245439664577134, 0.040379134443355724, 0.05085438191599678, 0.013305539887369378, 0.04088554633199237, 0.016001368130673654, 0.006312039276963333, 0.024463256158924196, 0.03085461154114455, 0.027814013956231065, 0.01437606471881736, 0.0413134167320095, 0.11522232307470404, 0.017284162968280725, 0.023333364151767455, 0.0294024586037267, 0.08363866276340559, 0.03976135216362309, 0.010290505579177989, 0.0616062426706776, 0.018472111332812347, 0.04776224588567857, 0.02401841284154216, 0.024911773107305635, 0.05873779366083909, 0.011036479027097812, 0.03706035393406637, 0.02598361246782588, 0.014812877070653485, 0.05163756664842367, 0.013793254292977508, 0.028126007273385767, 0.02795733009406831, 0.034783099763444625, 0.040366581015405245, 0.021636610472342, 0.022385717638826463, 0.010318523509340594, 0.07524376283981837, 0.05496849611517973, 0.07752406352665275, 0.07917218797956593, 0.04497038651606999, 0.01686007195530692, 0.041807178713497706, 0.04605097208695952, 0.08299398876260966, 0.025380649021826684, 0.09974849948775955, 0.09262190767913125, 0.06663106483756565, 0.027804664750874508, 0.015731187413621228, 0.047872963186819106, 0.09644463614677079, 0.04777013491548132, 0.07596121926326305, 0.07699472669628449, 0.051943491052952595, 0.11834874632768333, 0.163024581852369, 0.3354156611021608, 0.14810358406975865, 0.03635475703049451, 0.01990933782508364, 0.0816721495357342, 0.06308146155788563, 0.05789453207398765, 0.02866211249056505, 0.009533900865790201, 0.0672465872776229, 0.044482736120698974, 0.07221781153930351, 0.08068858121987432, 0.009240542876796098, 0.019461809788481332, 0.02315769779670518, 0.186567020136863, 0.1495687320129946, 0.21769440063508227, 0.05419344161055051, 0.1304245280334726, 0.058975588908651844, 0.03609757317462936, 0.09951133877621032, 0.15639135497622192, 0.261278462712653, 0.13030719448579475, 0.09861408965662122, 0.030739400535821915, 0.03485732937406283, 0.07663725642487407, 0.08725967549253255, 0.033631245751166716, 0.0861882814206183, 0.06017686995619442, 0.09628624698962085, 0.04131418485485483, 0.028396200978022534, 0.058037447452079505, 0.02246042036858853, 0.015474693755095359, 0.12143677085987292, 0.07220282757771201, 0.05845039697305765, 0.027281389411655255, 0.16065043659182265, 0.021097349272167776, 0.05412650731159374, 0.02168441962567158, 0.047588375527993776, 0.02558269687142456, 0.01725450303638354, 0.042663832355174236, 0.03271612571552396, 0.03789964503084775, 0.00794016377767548, 0.054113430669531226, 0.03662755938421469, 0.023247965218615718, 0.011135292279504938, 0.029731428548984695, 0.01177817770440015, 0.09816742065595463, 0.08941556996433064, 0.015470359612663742, 0.047196569794323295, 0.029843112497474067, 0.05762713997683022, 0.04713057802291587, 0.07904035286628641, 0.017585884961590637, 0.05327294100425206, 0.042468892424949445, 0.020979616820113733, 0.07020173768978566, 0.055173180444398895, 0.04776650581334252, 0.02222720973804826, 0.04022097906272393, 0.015521753339271527, 0.05704849856556393, 0.029384667468548287, 0.0531773672264535, 0.10418267600471154, 0.03466113892500289, 0.03820019257545937, 0.04137592412007507, 0.04811045415408444, 0.03408880947972648, 0.012310017427807907, 0.010626874736772152, 0.04031259348266758, 0.03972923201217782, 0.03315552166895941, 0.01634817188460147, 0.02554868238803465, 0.02692449987080181, 0.05316786773619242, 0.015827865136088803, 0.02286378319695359, 0.036728732666233554, 0.1764754147734493, 0.2001868252409622, 0.15125104720937088, 0.11754353836295195, 0.2577751991339028, 0.11841717976494692, 0.25777027127332985, 0.10444106213981286, 0.14058619213756174, 0.15042169718071818, 0.1288308104267344, 0.07493345605325885, 0.10141556354938075, 0.1840744577930309, 0.1661440808675252, 0.16838674724567682, 0.15072655660333112, 0.07794948483933695, 0.0981521992071066, 0.14700712024932727, 0.10889254554058425, 0.12573385785799474, 0.1707788821659051, 0.14151448529446498, 0.16381238645408303, 0.1692508446285501, 0.314118160167709, 0.16453244781587273, 0.1281127825495787, 0.20014983660075814, 0.180616628495045, 0.11594787632930093, 0.11995424923952669, 0.13939831056632102, 0.1198025765188504, 0.2144039998529479, 0.06931181356776506, 0.12686496513197199, 0.17407119768904522, 0.10846480872714892, 0.14909323799656704, 0.14203471597284079, 0.11030511974240653, 0.13064089376712218, 0.33070064848288894, 0.1408767281100154, 0.1546347507974133, 0.20490271359449252, 0.08485490179737099, 0.1289923908188939, 0.19895828881999478, 0.22438909218180925, 0.14311396196717396, 0.28518499864730984, 0.1924152477295138, 0.1952251821057871, 0.11454550665803254, 0.26068566483445466, 0.16504822560818866, 0.15753873012727126, 0.36103091784752905, 0.07580015837447718, 0.3268820611992851, 0.17469699145294726, 0.2811175840906799, 0.11725182237569243, 0.15872573596425354, 0.2101174439303577, 0.2818709530401975, 0.16951982863247395, 0.28300350008066744, 0.14777319476706907, 0.15806823765160516, 0.26127457385882735, 0.3059919102815911, 0.446359584457241, 0.1532922947080806, 0.1261912879999727, 0.12404498949763365, 0.188317034044303, 0.17361394566250965, 0.2749699295964092, 0.08658056583954021, 0.16211588139412925, 0.22789728362113237, 0.26110150502063334, 0.2225232290220447, 0.1280874604708515, 0.10358013372751884, 0.20266876003006473, 0.15770131984027103, 0.2942810277454555, 0.2009739915956743, 0.24581235746154562, 0.22408439603168517, 0.2763486321782693, 0.21770375169580802, 0.10742751634097658, 0.13893929222831503, 0.16538704570848495, 0.35983650537673384, 0.19706955266883597, 0.22089776233769953, 0.2316604324732907, 0.08650063653476536, 0.14917144551873207, 0.21770404855487868, 0.13564129185397178, 0.2536402194527909, 0.2814510161988437, 0.16527167143067345, 0.18190753500675783, 0.13750697689829394, 0.17598151549464092, 0.22666856908472255, 0.11470316851045936, 0.14898224239004776, 0.2036616051918827, 0.2245584799675271, 0.1365926954895258, 0.31039925816003233, 0.06410071233403869, 0.24680986331077293, 0.11225677517359145, 0.1546082115964964, 0.1535274664638564, 0.18952974787680432, 0.13783202273771167, 0.059974096657242626, 0.08338895975612104, 0.08413066214416176, 0.29198894917499274, 0.13818489911500365, 0.17757931491360068, 0.11603489314438775, 0.07179158870712854, 0.09733706130646169, 0.14868533879052848, 0.165426958410535, 0.09162677670246921, 0.13207123498432338, 0.10428498106193729, 0.15868806454818696, 0.11951427441090345, 0.29907547985203564, 0.19302694068755955, 0.18346154771279544, 0.19903367618098855, 0.15118477342184633, 0.10948797804303467, 0.16418262908700854, 0.17019176913890988, 0.12109504154068418, 0.04634553421055898, 0.12210221015266143, 0.0881304893118795, 0.10683254397008568, 0.14939916611183435, 0.1422453671693802, 0.1390469481702894, 0.1572675196803175, 0.1694840274285525, 0.11590842375881039, 0.16746826528105885, 0.14631534955697134, 0.1453681761631742, 0.13678615854587406, 0.07712137419730425, 0.11499636879307218, 0.10329619544791058, 0.14048416167497635, 0.11425494099967182, 0.12747282860800624, 0.10512236854992807, 0.11283169471425936, 0.16595846973359585], [0.047787801740923896, 0.039390133606502786, 0.025149265929940157, 0.034120617929147556, 0.058143919668509625, 0.022150623808556702, 0.026028892752947286, 0.032138593815034255, 0.011745018546207575, 0.03300590469734743, 0.03968575329054147, 0.05388991063227877, 0.02981086803629296, 0.051557537153712474, 0.022930838094907813, 0.09348153733299114, 0.03688681383209769, 0.031275227447622456, 0.015008931150077842, 0.032503867769264616, 0.09608550346456468, 0.05912180684390478, 0.008825027380225947, 0.032909718647715636, 0.04844780109124258, 0.043400595750426874, 0.013902188584324904, 0.017541806955705397, 0.05142356094438583, 0.02675910112884594, 0.047680064162705094, 0.05953655607299879, 0.08919221319956705, 0.049178326735273004, 0.10781564473290928, 0.015882305378909223, 0.0349401975836372, 0.04299359454307705, 0.028310406851232983, 0.012984420009161113, 0.07390501006739214, 0.02009756317420397, 0.1028194694663398, 0.0408193875773577, 0.021424627120723017, 0.026883974896918517, 0.035282156968605705, 0.020780064442078583, 0.07654976463527419, 0.06371233161189593, 0.06399684134521522, 0.039534841271233745, 0.01074047157089808, 0.010094227927766042, 0.010142706869373797, 0.09195203776471317, 0.03783814325288404, 0.010051227891381131, 0.05033845569414552, 0.060119791378383525, 0.13481599395163357, 0.033557305578142405, 0.09175286017125472, 0.07215131510747597, 0.1311370194889605, 0.07533681331551634, 0.04190874533378519, 0.013314975367393345, 0.057188218997907825, 0.10646152950357646, 0.10373934666858986, 0.03876141578075476, 0.17480641370639205, 0.5588043679017574, 0.7625250925775617, 0.8335479721426964, 0.3872474923264235, 0.03632627340266481, 0.44205949176102877, 0.36819270229898393, 0.03162293476634659, 0.5375189788173884, 0.48228900181129575, 1.1787092196755111, 1.2834232882596552, 0.7973441679496318, 0.6930644041858613, 0.4194294201442972, 0.2107081192662008, 0.34473846084438264, 0.5880229000467807, 0.2266453398624435, 0.5349017505068332, 0.4661337530706078, 0.5756344366818666, 0.5588791763875633, 0.6997069821227342, 0.0909106338804122, 0.07540846025221981, 0.014196223783073947, 0.11759100612835027, 0.06726175677613355, 0.07469472198863514, 0.059902635257458314, 0.0492602821032051, 0.1223845305503346, 0.08359964806004427, 0.0805466083693318, 0.07785421534208581, 0.09083622615435161, 0.027652804637909867, 0.09779233179870062, 0.04273708975233603, 0.03809701549471356, 0.028181132147437893, 0.023607832627021708, 0.07373984510195442, 0.00986431521596387, 0.06465903745265678, 0.037338774345698766, 0.03980217770731542, 0.05585702871030662, 0.05632579886878375, 0.0866269574908074, 0.04195149303996004, 0.06178417257615365, 0.06068383845558856, 0.015567139380436856, 0.040451534659950994, 0.039763782697264105, 0.043006715714000165, 0.026421062138979323, 0.03983411232184153, 0.03263811486249324, 0.02356871402298566, 0.030761640846321825, 0.05776765079644974, 0.03337149406434037, 0.026387415018689353, 0.01916062770760618, 0.05457230799947865, 0.01932619714352768, 0.054860409727552906, 0.025578110398782883, 0.028991824583499692, 0.016158773942152038, 0.03907249069015961, 0.12423924665199593, 0.07027346626273356, 0.00696306142344838, 0.01722728291497333, 0.040596175531391054, 0.05656911569531076, 0.031247916413121857, 0.07696424669120461, 0.0636614128598012, 0.018094990846293513, 0.04396169650135562, 0.044515179106383584, 0.0650833010149654, 0.033226459854631685, 0.006827113420513342, 0.060919158640899695, 0.046390408169827424, 0.0671867850178387, 0.10874824976781383, 0.05893643319723196, 0.025033171768882312, 0.012070737884641858, 0.08473380556097254, 0.04546000360278413, 0.02003491848881822, 0.010034386705228826, 0.071520593483001, 0.06888504154630937, 0.011311901162116555, 0.053047573019284755, 0.011002998890035087, 0.024213979886553716, 0.01919297606946202, 0.023177524271886796, 0.022170917836774606, 0.04276518746337388, 0.03253785071137827, 0.050677542967605405, 0.04899995154119097, 0.022316384347504936, 0.04566356728901155, 0.04392982125864364, 0.04934118362143636, 0.08710683760000393, 0.039129803044488654, 0.033837945011327974, 0.02058599653537385, 0.03018282317498233, 0.0665856602427084, 0.014143049829726806, 0.07870915462262928, 0.04878285479207989, 0.026318289528717287, 0.04531242011580616, 0.024137380969477817, 0.01925157048390247, 0.009144185205514077, 0.08664427921758033, 0.007646024214409408, 0.018359598034294322, 0.044274326210143045, 0.09856426186161116, 0.0313461730547715, 0.05385687392845284, 0.0823790451977402, 0.04427737272635568, 0.043598370684776455, 0.04309550626203418, 0.03885711572365835, 0.062167892610887066, 0.005254206098470604, 0.06798589252866805, 0.05938806716585532, 0.019514682244334836, 0.04837822474655695, 0.0551171631377656, 0.041050373620237224, 0.031911144105833955, 0.06053318618796766, 0.007544919117208337, 0.04311147356929723, 0.038091364040155895, 0.020908524638798553, 0.065216182556469, 0.04809149228094611, 0.03820674573944416, 0.09019373406772502, 0.1436646652291529, 0.06864837065222673, 0.18824742059223354, 0.07833169831428677, 0.1255364911048673, 0.09145393793005496, 0.09299957178882323, 0.06889089709147811, 0.036456768939387985, 0.009988394886022434, 0.03533988492563367, 0.0690945127280429, 0.16219008131884038, 0.11112317428342067, 0.1479204517090693, 0.5386399780400097, 0.5998408596497029, 0.8741141797509044, 0.6362687924411148, 0.10585863841697574, 0.07135667532566004, 0.30494732258375734, 0.1369620772311464, 0.260597497690469, 0.10252464388031512, 0.5955709575209767, 0.6947725906502455, 0.3689866221975535, 0.38287787523586303, 0.35662502457853407, 0.5089873785618693, 0.5366425914689898, 0.15926763735478744, 0.17833464313298464, 0.6005105737131089, 0.4345504712546244, 0.5012243357487023, 0.5726327165029943, 0.7830143056344241, 0.03217874400434084, 0.1377748922095634, 0.04495839340961538, 0.20502012135693803, 0.06576491170562804, 0.0664233673887793, 0.043186241236981004, 0.06249558791751042, 0.09737642481923103, 0.10422514169476926, 0.049357763200532645, 0.13856618490535766, 0.08007745229406282, 0.04024462017696351, 0.07791504176566377, 0.021223883595666848, 0.040703864870010875, 0.0076160349544807104, 0.04001625762612093, 0.05195322431973182, 0.008488225921610137, 0.09508350020041689, 0.009283909348596353, 0.030242102220654488, 0.034711374901235104, 0.018638510118762497, 0.10386959358584136, 0.02835400060575921, 0.06540133355883881, 0.04638621503545437, 0.03791432471189182, 0.04559091474220622, 0.019168420258210972, 0.025730857378221117, 0.07064298159093596, 0.019472481872071512, 0.036998952346039005, 0.03899144445313141, 0.011624176495388383, 0.07309908964089118, 0.01756574863975402, 0.03365814118296839, 0.04365269218396861, 0.07640468218596652, 0.06768339313566685, 0.09196564875310287, 0.030153656771290116, 0.03531171671056654, 0.04724238628114108, 0.0580086113041034, 0.0414292993809795, 0.020755484511028044, 0.0255420976827736, 0.03338227375934366, 0.04222630290314555, 0.026704020783654414, 0.051726231031352654, 0.03164003755955491, 0.054141005166457035, 0.032156219822354615, 0.022746904214727692, 0.010513330780668184, 0.07510096620535478, 0.05195392564928625, 0.0320340326288715, 0.04160515498369932, 0.04407554566569161, 0.016330343642039225, 0.04425842940690927, 0.03630077691923361, 0.056586314967717044, 0.04761565687658731, 0.0751436545397155, 0.04436857896507718, 0.008785497811913956, 0.09007566579384729, 0.05810093447507825, 0.09956130015780218, 0.010809216710185865, 0.1333537997561507, 0.10993628719006665, 0.15634603943908587, 0.09082293428946286, 0.103548317856621, 0.07731644029263407, 0.1552333967993036, 0.10186734594753943, 0.18505354353692383, 0.16806259198347107, 0.08970283306553029, 0.15398427320178598, 0.22487515438115224, 0.21639383136061952, 0.1777115953154862, 0.12273821586859412, 0.15847521659452468, 0.11617127020144835, 0.13380414980929345, 0.1327292824862525, 0.14568740356480703, 0.15452638239366934, 0.09216074453433976, 0.10200062082731165, 0.1638396826456301, 0.19773460604483262, 0.11125630073365755, 0.1549006623099558, 0.1728153057047166, 0.16425709618488327, 0.11200026667211205, 0.1942441816208884, 0.16636584943626076, 0.11480052344268188, 0.26035995106212795, 0.17223169561475515, 0.1806664711330086, 0.25631987722590566, 0.1472985467989929, 0.12299481342779472, 0.1529707814916037, 0.07025017024716362, 0.23708099004579708, 0.138766223390121, 0.14599147631088272, 0.09285782900406048, 0.13766633084742352, 0.22463325876742601, 0.15451404789928347, 0.31080325366929173, 0.09644511112128384, 0.17493148043286055, 0.12113244578358717, 0.13039246725384146, 0.26448002841789275, 0.19849839474773034, 0.19633938325569034, 0.15710654784925282, 0.2644295326899737, 0.23718901706160977, 0.3234848059946671, 0.13638851582072675, 0.2795024332590401, 0.46260504866950214, 0.30072940047830343, 0.22894132212968543, 0.1233404538652394, 0.22620304953306913, 0.1664006116334349, 0.24822942854370922, 0.19766227633226663, 0.3085741982795298, 0.4406285716686398, 0.863071734784171, 0.8287865901365876, 1.2324829841963947, 0.5621953890658915, 0.16045623138779774, 0.9757431107573211, 0.7726573082618415, 0.6836852012202144, 1.0714697116054595, 1.022695410065353, 2.5504126958549023, 2.195704341866076, 2.069596233777702, 1.949572549201548, 1.096520817372948, 1.0999430087395012, 1.482481425628066, 1.2407862511463463, 0.28343373793177307, 0.6161362258717418, 0.4679114045575261, 0.936583005823195, 0.9502018906641752, 1.0456309793516994, 0.2784055983647704, 0.2860897360369563, 0.1579658658010885, 0.19546200142940506, 0.22793765645474195, 0.3840800654143095, 0.10279221780365333, 0.16368635493563488, 0.18067635654006153, 0.21667258202796802, 0.24285880266688764, 0.2748737472575158, 0.24706001160666347, 0.10881443449761719, 0.27795627247542143, 0.23899365303805098, 0.16457179648568854, 0.1335687405662611, 0.13973634399008006, 0.17794301180401817, 0.09025699473568238, 0.16065811039879918, 0.10014908853918314, 0.14175347168929875, 0.1669597753789276, 0.19271258177468553, 0.17973194393562153, 0.11046564628486522, 0.14944929076591507, 0.08208016006392427, 0.16521246288903058, 0.12375960403005593, 0.10227321909042075, 0.0872467398585286, 0.1044219295727089, 0.15472790517378598, 0.20461547275772318, 0.15659737517125905, 0.14101271925028414, 0.16958311898633838, 0.053414212525240146, 0.14011884690262377, 0.15347754961112514, 0.15719107846962288, 0.1709040379500948, 0.3163175593363121, 0.11933723508263938, 0.09539971448248252, 0.20773670839844272, 0.12536349648144096, 0.22347727470332757, 0.21527045726543292, 0.07453066282323562, 0.14803647907683626, 0.12095601501641795, 0.13724738848395646, 0.10612791185849346, 0.1705077607766725, 0.12659376952797174, 0.15377040108432993, 0.12592739512911066, 0.10571559687377885, 0.3515185142168775, 0.15573373791994527, 0.07610469125211239, 0.14671480312244967, 0.1927396553219296, 0.20581009302986786, 0.21739580493886024, 0.14855222718324512, 0.22420227876864374, 0.1349068179843016, 0.18915478518465534, 0.10365624097175896, 0.1215096349187661, 0.22650844330200925, 0.1589559650165029, 0.16499528079293668, 0.0934442740981467], [0.017445396406401414, 0.05858067357621621, 0.013071824596408987, 0.01588858023751527, 0.04580709493893664, 0.04880373882770073, 0.033012012572726235, 0.057834488616208546, 0.03806339249422308, 0.06623292487347499, 0.04344784829299897, 0.012677483500738163, 0.016405935093644075, 0.06509848535642959, 0.047535608828184195, 0.0459710130962776, 0.013201769088482251, 0.0452360790950479, 0.010899658536800416, 0.027907400253752712, 0.012189575209049508, 0.041330200401716866, 0.012449691475922009, 0.013346641881071264, 0.01951050024217693, 0.037544349252129905, 0.02089356665237574, 0.0472298773820512, 0.06432777241570875, 0.010633619003783679, 0.0218924992805114, 0.019473886386549566, 0.053172268671914935, 0.02296947430295404, 0.10059192063636146, 0.056878672912716866, 0.03393443905224558, 0.04556706582661718, 0.022908427090442274, 0.012367110848572338, 0.05488549060828518, 0.045936566311866045, 0.03996524239482824, 0.04316988059144933, 0.041474611207377166, 0.01581846398039488, 0.053433066786965355, 0.045443052949849516, 0.10336318169720471, 0.059757226263172925, 0.014873177497065626, 0.0303582038031891, 0.05433548125438392, 0.0754025304922834, 0.047185623116092756, 0.03647455450845882, 0.09932595028658397, 0.010609974178805714, 0.06480570809799246, 0.09982542309444398, 0.16827698360430077, 0.026255258926539682, 0.14961639273678884, 0.07218929822556674, 0.12484342907555401, 0.044094500117353164, 0.07613987647346221, 0.0707764494291041, 0.2805116947274655, 0.37137333943974227, 0.09352212538942695, 0.8388117584399879, 4.876387109979987, 17.827087305486202, 26.491388082504272, 31.012999154627323, 50.92266730964184, 56.282629296183586, 96.76820665597916, 94.86820220947266, 80.34805655479431, 93.54752227663994, 92.80358299612999, 107.32427582144737, 107.27126866579056, 95.85586041212082, 94.92591351270676, 96.6014564037323, 98.8363216817379, 97.27067649364471, 101.6273783147335, 64.52796265482903, 43.84106710553169, 46.64872124791145, 38.48612844944, 30.81569854170084, 15.343473125249147, 2.25704088807106, 1.055563883855939, 0.32985557976644486, 0.6228741549421102, 0.38003396533895284, 0.20536364667350426, 0.18794049799907953, 0.07252054099808447, 0.08010601013666019, 0.07139454712159932, 0.08993803450721316, 0.16388640826335177, 0.17295517085585743, 0.10981540617649443, 0.028976989051443525, 0.0152308128963341, 0.014906189153407468, 0.0557158536685165, 0.04080237013113219, 0.022334240420605056, 0.03250113295507617, 0.015638548829883803, 0.11281195358606055, 0.04565950031974353, 0.013689387942577014, 0.04788955760886893, 0.016999727449729107, 0.04940735350828618, 0.024634143082948867, 0.07347141770878807, 0.062206417496781796, 0.015837208775337785, 0.06098022626247257, 0.10872068640310317, 0.06892324730870314, 0.08009662939002737, 0.02928761125076562, 0.04221956791297998, 0.028950357082067057, 0.05423776266979985, 0.07802784821251407, 0.012104687430110062, 0.013910213983763242, 0.023171473912952933, 0.0104309523885604, 0.028016987635055557, 0.016492725553689525, 0.006759360903743072, 0.052991548291174695, 0.005753747554990696, 0.02442309483740246, 0.05133143444254529, 0.0018244529428557144, 0.02647686607815558, 0.032450618673465215, 0.04746302678540815, 0.043666191850206815, 0.0709228751657065, 0.03559242293704301, 0.06282634087256156, 0.013499358246917836, 0.02746753303654259, 0.04286555922590196, 0.0421835997258313, 0.007058114306346397, 0.033971650336752646, 0.009070281212189002, 0.017560820779181086, 0.012631293157028267, 0.022252941853366792, 0.04672204428061377, 0.06003657807013951, 0.04897728264040779, 0.06263577219215222, 0.015682799385103863, 0.030311756490846165, 0.08399455968174152, 0.07680205031647347, 0.05984954572340939, 0.02000907505134819, 0.11135157023090869, 0.06388266192516312, 0.02362757375522051, 0.038603401408181526, 0.017818739361246116, 0.04153282527113333, 0.015292557727661915, 0.07013279959210195, 0.018453642987878993, 0.030183884446159936, 0.04609000163327437, 0.012177690641692607, 0.09251702736946754, 0.03735127582331188, 0.0869802717352286, 0.016862970041984227, 0.06493263761512935, 0.060725469229510054, 0.011545698089321377, 0.08107178917271085, 0.11499000858748332, 0.025771916698431596, 0.049156307213706896, 0.07365305835264735, 0.05618939954729285, 0.05779597115179058, 0.061874102320871316, 0.10081371146952733, 0.028200049491715617, 0.03959771231166087, 0.02373946179432096, 0.047869070622255094, 0.02475253975717351, 0.017376829382556025, 0.07382315860013478, 0.03256323587265797, 0.07186738424934447, 0.04326189948187675, 0.00990587455817149, 0.02781941493594786, 0.06869698874652386, 0.02071047139907023, 0.034749005499179475, 0.03637596018961631, 0.05428260694316123, 0.05486723377543967, 0.04630601855751593, 0.016813014226499945, 0.07121609771274962, 0.042138792559853755, 0.05731579789426178, 0.05534497649932746, 0.048569435384706594, 0.05230028968071565, 0.10771727305836976, 0.06463413097662851, 0.0732086603238713, 0.13134066481143236, 0.18801477213855833, 0.1685190573334694, 0.045357524140854366, 0.10611753663397394, 0.137306448596064, 0.09803370048757643, 0.07911979235359468, 0.06477966613601893, 0.09884639672236517, 0.4065066995099187, 0.3689910750836134, 0.3402040572836995, 0.392937152646482, 3.9068460976704955, 17.576146870851517, 25.45729637145996, 33.05289499461651, 55.66409848630428, 65.41634738445282, 105.38396313786507, 104.42484140396118, 91.99406683444977, 104.45198714733124, 106.98981776833534, 120.49711257219315, 123.1280229985714, 115.2281405031681, 112.38685816526413, 112.51643881201744, 110.195781737566, 110.12612387537956, 113.84468033909798, 71.67717263102531, 50.1247139275074, 54.19084534049034, 41.5668473392725, 34.06088970601559, 16.378553733229637, 2.790796346962452, 0.6497647776268423, 0.2793115231906995, 0.6412518094293773, 0.7531379337888211, 0.2661376597825438, 0.10481294491910376, 0.11533058757777326, 0.0997278158320114, 0.11560130820726044, 0.021356609286158346, 0.0504848851414863, 0.27184643782675266, 0.05967894823697861, 0.12996576202567667, 0.025962069776142016, 0.02899962641095044, 0.0395302473771153, 0.046624481547041796, 0.07118422247003764, 0.07616248971316963, 0.1067945831164252, 0.0771085721498821, 0.058574502618284896, 0.04099633784790058, 0.055528205339214765, 0.04190241852484178, 0.055675380644970573, 0.033319792346446775, 0.0008809494693196029, 0.026485740308999084, 0.026001960213761777, 0.012800556633010274, 0.0423898685403401, 0.0066319629058853025, 0.045719228364760056, 0.032406735481345095, 0.12339694614638574, 0.003918477577826707, 0.062039797921897843, 0.04966641870851163, 0.04017198247311171, 0.027016437124984805, 0.027397452031436842, 0.01780330825567944, 0.02587692317320034, 0.026405421376693994, 0.04312035707698669, 0.007565367141069146, 0.015070423651195597, 0.026935132991638966, 0.08570641235564835, 0.006569950901393895, 0.10884895920753479, 0.03975691040977836, 0.019288531293568667, 0.056875310983741656, 0.06768226507119834, 0.05689540834282525, 0.03310110369056929, 0.02772385600110283, 0.050010422710329294, 0.006701126894768095, 0.022182090870046522, 0.03887432241754141, 0.04441596880496945, 0.010194901187787764, 0.021519577494473197, 0.03963512397604063, 0.1207283315306995, 0.01090856801965856, 0.08743178696022369, 0.0275582717222278, 0.02836034596839454, 0.020196962723275647, 0.029516020185837988, 0.041064570905291475, 0.02470602936227806, 0.06620024068979546, 0.055487075514975004, 0.1832906311028637, 0.09959184695617296, 0.11178711443790235, 0.1570849068230018, 0.10579997164313681, 0.14977874496253207, 0.22225801512831822, 0.11020455131074414, 0.1347512935171835, 0.13148459693184122, 0.1702276148716919, 0.13268414506455883, 0.30445973156020045, 0.19693908310728148, 0.2623902296181768, 0.08094940902083181, 0.2255207931739278, 0.22008496220223606, 0.06919197156094015, 0.22658203466562554, 0.1673980729538016, 0.13879279227694497, 0.12824769015423954, 0.17066294385585934, 0.18793472409015521, 0.13986054982524365, 0.15735199092887342, 0.2317947760457173, 0.12390194053296, 0.17823670932557434, 0.3209914272883907, 0.0983567870571278, 0.2673509524902329, 0.2024272206472233, 0.15865327266510576, 0.10952906333841383, 0.17783881427021697, 0.20731614815304056, 0.08710131602128968, 0.15245674032485113, 0.22666675824439153, 0.11563062304048799, 0.14014816173585132, 0.19888594426447526, 0.23850454803323373, 0.1563832804095, 0.1264056350919418, 0.2455927262781188, 0.13859046797733754, 0.14752939925529063, 0.12829336192226037, 0.18782203638693318, 0.19224428659072146, 0.15618390985764563, 0.1676232405588962, 0.1934650304610841, 0.09952417793101631, 0.2079340603086166, 0.33812254085205495, 0.3973084321478382, 0.161748458922375, 0.268211814109236, 0.2445669297594577, 0.2839203493203968, 0.17402889527147636, 0.17005131026962772, 0.31917640124447644, 0.7610587868839502, 0.5478808446787298, 0.5011536832898855, 1.6725708567537367, 7.571098962798715, 26.015106439590454, 38.44711974263191, 46.957488879561424, 72.40521356463432, 86.93058013916016, 131.48501336574554, 133.1500080227852, 115.76513528823853, 128.72476547956467, 136.02104276418686, 148.843135535717, 150.70090144872665, 141.4460876584053, 135.3607141971588, 138.40372771024704, 139.4041684269905, 138.45984309911728, 139.2939591407776, 92.60573521256447, 65.8456939458847, 70.93539163470268, 57.658531665802, 46.29757449030876, 23.973215706646442, 4.763047741726041, 1.9341476331464946, 0.32280419720336795, 0.6420841428916901, 0.9950062958523631, 0.5091992171946913, 0.2710780478082597, 0.25520330120343715, 0.21742249256931245, 0.25525513279717416, 0.19286506343632936, 0.3055207652505487, 0.47046189894899726, 0.23186717997305095, 0.20151402277406305, 0.1943577895872295, 0.14717800717335194, 0.23213712876895443, 0.16062974551459774, 0.18190784670878202, 0.11041860896511935, 0.12635162158403546, 0.2872684149770066, 0.18471663817763329, 0.12324548864853568, 0.14627110271248966, 0.12355428145383485, 0.0958903186256066, 0.15681222692364827, 0.2269080007681623, 0.09913109941408038, 0.11483907801448368, 0.1854743412695825, 0.18142122047720477, 0.13660795404575765, 0.17636284581385553, 0.10526977392146364, 0.17270833253860474, 0.11040612604119815, 0.08703537620021962, 0.17250449425773695, 0.12196708732517436, 0.12902069633128121, 0.0759876322990749, 0.12246434853295796, 0.09017954420414753, 0.2030306906090118, 0.10365482346969657, 0.11239793166168965, 0.20757785910973325, 0.057883730114554055, 0.2073204971384257, 0.126159880310297, 0.13537166960304603, 0.11033034534193575, 0.1325871908920817, 0.16547665261896327, 0.144642251834739, 0.1936994749121368, 0.13728718244237825, 0.13386089442064986, 0.1413671689806506, 0.07393192776362412, 0.15044100786326453, 0.07457398198312148, 0.21812361432239413, 0.11113924178062007, 0.11185631228727289, 0.0787779146048706, 0.3302362421527505, 0.150581837806385, 0.19268923380877823, 0.12361475906800479, 0.15941602236125618, 0.17900388222187757, 0.2378447787486948, 0.12605179392267019, 0.12680203100899234, 0.24237619887571782], [0.09402657800819725, 0.015174048803601181, 0.046012180027901195, 0.03510548129270319, 0.03130453857011162, 0.014048816556169186, 0.07235146491439082, 0.02692653150006663, 0.02430809534416767, 0.05673475934599992, 0.043464494665386155, 0.030655602786282543, 0.031863587282714434, 0.05431505363958422, 0.04081619634234812, 0.0903628917876631, 0.011695474622683832, 0.0017803563832785585, 0.05035140617110301, 0.013210840916144662, 0.07258026162162423, 0.02074589781841496, 0.09150017373031005, 0.04944025662553031, 0.020561657802318223, 0.015195301130006555, 0.047415080334758386, 0.02039930557657499, 0.05920876799791586, 0.02354777061555069, 0.061103997941245325, 0.02759827348199906, 0.056637393281562254, 0.060755054946639575, 0.05225859953498002, 0.011359819782228442, 0.05353042914066464, 0.05102431518025696, 0.07525780427386053, 0.0163727314065909, 0.0494257624814054, 0.03580609838536475, 0.02939796118880622, 0.05404667077527847, 0.03508619287458714, 0.08062010325375013, 0.02371227692492539, 0.04141722463828046, 0.04425528270076029, 0.008424857642239658, 0.02141556549759116, 0.030740378315385897, 0.05518252408364788, 0.02860746630176436, 0.07233003168948926, 0.010778971409308724, 0.058554605639074, 0.07970263803144917, 0.09657688686274923, 0.10199967829976231, 0.19350742193637416, 0.050643953363760374, 0.503035532310605, 0.3249544068239629, 0.23297174804611132, 0.23934094846481457, 0.5545158230233938, 3.1351471692323685, 7.151083750650287, 29.40847635269165, 51.12190581858158, 69.42123368382454, 101.2042710185051, 119.5673480629921, 118.25914666056633, 116.07012212276459, 113.12337264418602, 122.99986347556114, 106.43798857927322, 110.37890151143074, 116.68370559811592, 112.67548307776451, 110.32452642917633, 104.24353793263435, 105.70500791072845, 99.07583802938461, 111.01146876811981, 92.66343891620636, 102.52941951155663, 103.64350453019142, 101.81918442249298, 120.92895939946175, 120.06366983056068, 116.73742711544037, 129.30742621421814, 127.15611845254898, 121.25514149665833, 110.99887624382973, 86.45661637187004, 59.80424612760544, 50.24593502283096, 11.855264101177454, 1.865928943734616, 0.19906030443962663, 0.018102464273397345, 0.39281734032556415, 0.5831645044963807, 0.5949765269178897, 0.23871950368629768, 0.059738683703471906, 0.029505715465347748, 0.2069822113844566, 0.11428516867454164, 0.013907633165217703, 0.07961394396261312, 0.003188434329786105, 0.0478652411402436, 0.05552056492888369, 0.09101080897380598, 0.012096216742065735, 0.03500846403767355, 0.04879405751125887, 0.020027187165396754, 0.12940302112838253, 0.04730256703624036, 0.039171656462713145, 0.021514822183235083, 0.028651548018387984, 0.027295735126244836, 0.03487082532956265, 0.01741525778925279, 0.02091803340590559, 0.006574483104486717, 0.050480985155445524, 0.06532579776830971, 0.04646175824746024, 0.012243673136254074, 0.03680690308101475, 0.05252323826425709, 0.03051848729228368, 0.06300040418864228, 0.03521492952131666, 0.032286882342305034, 0.06927184149390087, 0.054287401217152365, 0.03766824709600769, 0.044951350428164005, 0.01097622312954627, 0.043624661266221665, 0.035812373243970796, 0.017795510138967074, 0.030188034907041583, 0.03604033503506798, 0.0932401092723012, 0.01628384066862054, 0.02869948704756098, 0.06281704918364994, 0.06654090131632984, 0.13515855447622016, 0.10590384263196029, 0.05286120860546362, 0.018747594695014413, 0.01998302566789789, 0.014504907121590804, 0.09286447122576647, 0.021631109302688856, 0.10271927952999249, 0.015996872571122367, 0.028643549521802925, 0.03639424670836888, 0.018605172845127527, 0.05415826752141584, 0.06280395027715713, 0.03519974517985247, 0.03983296570368111, 0.05285888197249733, 0.009369512372359168, 0.02651186761795543, 0.057660996753838845, 0.011614420964178862, 0.036807181386393495, 0.040102628772729076, 0.010610306289891014, 0.04198231443297118, 0.05519373793504201, 0.012357424893707503, 0.04398797966132406, 0.030374564448720776, 0.03389101599168498, 0.04553790313366335, 0.021168873754504602, 0.043604293023236096, 0.026674778309825342, 0.0154715860116994, 0.037311793566914275, 0.009788123552425532, 0.03354653701535426, 0.014402333035832271, 0.07016112736891955, 0.02239416142401751, 0.017547052084410097, 0.023200248833745718, 0.01453642613341799, 0.031523527795798145, 0.06869560093036853, 0.013204476999817416, 0.033889527985593304, 0.014483215072687017, 0.013551990432461025, 0.09745325936819427, 0.06744481492205523, 0.04233199215377681, 0.02035728331975406, 0.08620499458629638, 0.039977265187189914, 0.033105849724961445, 0.05160238142707385, 0.012728038600471336, 0.025759580348676536, 0.025038914136530366, 0.04244879506586585, 0.030241378626669757, 0.06755836351658218, 0.014421825544559397, 0.02109275166731095, 0.01982530258828774, 0.04034341487567872, 0.08631483244244009, 0.08464294442092068, 0.04911470241495408, 0.06160302546049934, 0.02985998708027182, 0.05254121308098547, 0.029484375008905772, 0.07401867740554735, 0.12161522026872262, 0.10754404094768688, 0.05219906073762104, 0.35358198161702603, 0.7491852552630007, 0.3661325597204268, 0.17649034678470343, 0.20127282477915287, 2.8281150944530964, 6.809211820363998, 32.235615849494934, 61.008937284350395, 85.02940535545349, 115.41502967476845, 138.69056671857834, 136.70596361160278, 132.9667666554451, 128.0746203660965, 140.56693643331528, 123.6722981929779, 128.09447050094604, 131.2592750787735, 132.34905660152435, 130.10533779859543, 120.7553619146347, 122.03119665384293, 121.8179140985012, 128.01503956317902, 122.5847053527832, 128.60564947128296, 128.45624148845673, 129.54871326684952, 149.68991249799728, 148.02896082401276, 142.87134557962418, 157.4885380268097, 151.4123448729515, 143.50499957799911, 130.03219932317734, 111.4517967402935, 77.25224867463112, 62.4086719751358, 15.141140632331371, 2.128886114805937, 0.08921827000449412, 0.003517430018291634, 0.43395197368226945, 0.7415852474514395, 0.36043524043634534, 0.26880182151217014, 0.08793728600721806, 0.057461581673123874, 0.28834467753767967, 0.08640195315820165, 0.021515636690310203, 0.059077311379951425, 0.05639985036395956, 0.022217470905161463, 0.05359150789445266, 0.016943355767580215, 0.05732905265176669, 0.023948383786773775, 0.058110274403588846, 0.060935144501854666, 0.05648641446896363, 0.048492834612261504, 0.029379709922068287, 0.030644323996966705, 0.012315991716604913, 0.04932164287311025, 0.029702178653678857, 0.06346729671349749, 0.035629667618195526, 0.032658972922945395, 0.012215588412800571, 0.03069638380111428, 0.024427642347291112, 0.013542990036512492, 0.02101339938235469, 0.020217308701830916, 0.04692283604526892, 0.06517915680888109, 0.015882858278928325, 0.024164790338545572, 0.05126334239321295, 0.02655478601809591, 0.017095822586270515, 0.047376703878398985, 0.02462987573380815, 0.015748468322271947, 0.046339823384187184, 0.018106343850377016, 0.04621338739525527, 0.014872271149215521, 0.09709258301882073, 0.06771268570446409, 0.06309306132607162, 0.05603685109235812, 0.0135953522658383, 0.018133404410036746, 0.08160226148902439, 0.025289247969340067, 0.05554289986321237, 0.02246770640340401, 0.012910934401588747, 0.027506371479830705, 0.01536959358418244, 0.048692858254071325, 0.05016080409404822, 0.03341159601404797, 0.036522916561807506, 0.05213141026615631, 0.0625472488172818, 0.10182684694882482, 0.0327499565173639, 0.029607068718178198, 0.0033078658361773705, 0.1319091796176508, 0.1230029844737146, 0.13966336118755862, 0.13751554128248245, 0.08106791516183876, 0.12151780596468598, 0.15974414069205523, 0.12825892627006397, 0.2066281030420214, 0.0970417087955866, 0.1522812817711383, 0.1123120503325481, 0.13713752094190568, 0.1252199651207775, 0.14192999893566594, 0.1332654693396762, 0.12991853174753487, 0.15580623090500012, 0.08625431772088632, 0.09503413253696635, 0.16437876387499273, 0.0855621017399244, 0.1817556025343947, 0.10847822675714269, 0.0918183769681491, 0.10588065051706508, 0.13497211213689297, 0.19604374130722135, 0.14981307671405375, 0.08871179132256657, 0.11240552383242175, 0.07877055992139503, 0.13540977146476507, 0.19713156652869657, 0.13793872873065993, 0.12025482647004537, 0.16761109902290627, 0.21263909846311435, 0.1785579850547947, 0.09362596669234335, 0.2405506046488881, 0.13373214664170519, 0.15514199389144778, 0.14970838936278597, 0.12374425641610287, 0.1314075620030053, 0.1398747693747282, 0.12306362536037341, 0.13227919960627332, 0.04526107833953574, 0.10308867611456662, 0.14528152300044894, 0.11001042774296366, 0.18136974511435255, 0.23299794585909694, 0.14600134687498212, 0.2138332586036995, 0.279430712107569, 0.19142525241477415, 0.17379684053594247, 0.23741673765471205, 0.24998428125400096, 0.8602940244600177, 0.9773270320147276, 0.41690867103170604, 0.8693932299502194, 1.3071692828088999, 5.137772709131241, 11.618121676146984, 43.602249920368195, 78.0892525613308, 106.3661040365696, 138.3814913034439, 158.8487434387207, 155.37256836891174, 151.81550323963165, 144.87896025180817, 151.96387767791748, 131.6316854953766, 136.65141373872757, 143.8765588402748, 143.5946747660637, 137.0272895693779, 130.1916691660881, 129.95913684368134, 126.92192181944847, 139.5821052789688, 123.2681442797184, 131.1868965625763, 134.54474598169327, 136.19966357946396, 156.30479514598846, 163.2930913567543, 160.17333716154099, 173.28410804271698, 168.51699024438858, 165.07565170526505, 157.59833693504333, 134.19777899980545, 100.16418322920799, 76.27956166863441, 20.397045202553272, 3.999118208885193, 0.5081463768146932, 0.09643472105381079, 0.557532386155799, 0.8007779961917549, 0.9253699262626469, 0.6068871659226716, 0.22781039297115058, 0.18532974121626467, 0.5116671253927052, 0.42846794764045626, 0.17113769572461024, 0.20597036724211648, 0.11084425292210653, 0.10516719426959753, 0.11080883021350019, 0.1873187712044455, 0.17791578982723877, 0.1309620655956678, 0.1600525772664696, 0.09925970618496649, 0.1371733666746877, 0.14883381285471842, 0.17063067527487874, 0.10525768433581106, 0.1295247778762132, 0.1127234598970972, 0.0878514714713674, 0.13274694560095668, 0.12930202967254445, 0.11980259136180393, 0.12079905078280717, 0.2003642133786343, 0.17219645844306797, 0.13487885385984555, 0.10789346633828245, 0.1309482764918357, 0.1384502911241725, 0.16171291004866362, 0.11295961870928295, 0.13127571204677224, 0.1348630164284259, 0.15191510610748082, 0.10726615859312005, 0.22702854039380327, 0.11902254962478764, 0.0723619588825386, 0.14169024070724845, 0.09140797672444023, 0.1054806329193525, 0.309506306075491, 0.18460883380612358, 0.15228107396978885, 0.14688016846776009, 0.15025011263787746, 0.160196524229832, 0.18556847528088838, 0.2834423171589151, 0.12381620763335377, 0.12746842025080696, 0.08557255117921159, 0.06885070237331092, 0.1575595696340315, 0.10072290227981284, 0.1322132078348659, 0.08164813363691792, 0.11731471939128824, 0.14039217989193276, 0.1726377839804627, 0.17467370285885409, 0.17307694244664162, 0.18013801745837554, 0.09753897742484696, 0.18074531690217555], [0.0035176074379705824, 0.013132300355209736, 0.021683803643099964, 0.022211238720046822, 0.03664915588160511, 0.03190345174516551, 0.019284043155494146, 0.039904130244394764, 0.0446769821428461, 0.03183569366228767, 0.046663050961797126, 0.035177773897885345, 0.014233502788556507, 0.05769327646703459, 0.009666551413829438, 0.048662411645636894, 0.07425841336953454, 0.08568456352804787, 0.03950903679651674, 0.025225816607417073, 0.03225625761842821, 0.013436831377475755, 0.02286269038449973, 0.04000598630227614, 0.050195113581139594, 0.032051239322754554, 0.011289337089692708, 0.0271684623658075, 0.029041904708719812, 0.07186837130575441, 0.018041582188743632, 0.036554851176333614, 0.015558351424260763, 0.03914146218448877, 0.04630608906154521, 0.03774620599870104, 0.0641088536940515, 0.06434248178265989, 0.01965388688404346, 0.05882121477043256, 0.06824971118476242, 0.016285508645523805, 0.05915044261200819, 0.044466178806032985, 0.057550164419808425, 0.08303465103381313, 0.08666675887070596, 0.09760942950379103, 0.0382300417550141, 0.042067230970133096, 0.03371301187144127, 0.03741627682757098, 0.05133035832841415, 0.037115384184289724, 0.06148320571810473, 0.022211299947230145, 0.03966708085499704, 0.09278955141780898, 0.10542367308516987, 0.24365787307033315, 0.17334617878077552, 0.4296431830152869, 9.155481420457363, 19.9581915512681, 35.21747924387455, 59.271252527832985, 77.60783359408379, 86.99101209640503, 96.72517776489258, 111.25802993774414, 104.01013165712357, 105.07456853985786, 84.22047436237335, 82.22776249051094, 89.54818367958069, 89.24825817346573, 76.09976291656494, 62.97500878572464, 85.34278213977814, 91.9375866651535, 71.88924685120583, 89.33923289179802, 78.24334189295769, 72.86715477705002, 91.37528523802757, 75.99206149578094, 83.30418393015862, 101.60048335790634, 107.97015756368637, 100.99009171128273, 78.03892806172371, 83.43073233962059, 85.92519208788872, 90.10680690407753, 86.17515787482262, 82.89940685033798, 99.32212561368942, 102.20652043819427, 116.59403800964355, 123.48399549722672, 122.71364763379097, 113.80224421620369, 94.667147397995, 68.9048869907856, 48.987271562218666, 37.35964469611645, 23.945076316595078, 14.456906598061323, 3.327135667204857, 0.5314883461687714, 0.2795000880723819, 0.0742361340962816, 0.1878917685826309, 0.04049645685881842, 0.03312138287583366, 0.056628717575222254, 0.05567913220147602, 0.07990898477146402, 0.026512717377045192, 0.04132685702643357, 0.0253267765219789, 0.05777289035904687, 0.005898045646972605, 0.02818156444845954, 0.06566904106875882, 0.011967555237788474, 0.02149400308553595, 0.04179052863037214, 0.059635410143528134, 0.05924002354731783, 0.02415698480035644, 0.11309246314340271, 0.029241932061268017, 0.026707967153924983, 0.036926299799233675, 0.022681474620185327, 0.030249894771259278, 0.006077304924474447, 0.12943471083417535, 0.022848752851132303, 0.03373441912117414, 0.01902749754663091, 0.03762640852073673, 0.025900571708916686, 0.03445213529630564, 0.029345456096052658, 0.037143674853723496, 0.014772082140552811, 0.09668128477642313, 0.0330008877790533, 0.011596809799812036, 0.05338837465387769, 0.02053570675343508, 0.0286897445039358, 0.011952186287089717, 0.020553906069835648, 0.05143870075698942, 0.04242676812282298, 0.07025010345387273, 0.005534719830393442, 0.026969525970343966, 0.10306087526259944, 0.06334318735753186, 0.02084722695144592, 0.06841372582130134, 0.0550082529662177, 0.06508367951028049, 0.025936215206456836, 0.003823490792456141, 0.06339042505715042, 0.02450899100949755, 0.045452897538780235, 0.02848880616511451, 0.06671795548754744, 0.12380196581943892, 0.02675516403542133, 0.0448919266636949, 0.05112490587634966, 0.0318294447788503, 0.01606177338544512, 0.03417067950067576, 0.023603535591973923, 0.054438628649222665, 0.03675755768199451, 0.02916908655606676, 0.035494080948410556, 0.0696301726566162, 0.0206117917332449, 0.01722272798360791, 0.019994447320641484, 0.022251567024795804, 0.10508063016459346, 0.040213138272520155, 0.015198878281807993, 0.06599102183827199, 0.05581032906775363, 0.04591670644003898, 0.03531594695232343, 0.053568801886285655, 0.03524267842294648, 0.07069738843711093, 0.05919742055993993, 0.025423797487746924, 0.041015867464011535, 0.04927927366225049, 0.045175794439273886, 0.026775229853228666, 0.029163737526687328, 0.042676062948885374, 0.035326040160725825, 0.004226235087116947, 0.05854712850123178, 0.02193080152210314, 0.056593729023006745, 0.060481495602289215, 0.08040918488404714, 0.03847607113129925, 0.0414740731503116, 0.038204997981665656, 0.038230253267101943, 0.05444625421660021, 0.011727905548468698, 0.12527426064480096, 0.042294632439734414, 0.05057047703303397, 0.04374718613689765, 0.011271719431533711, 0.050591761828400195, 0.07608701329445466, 0.052032578460057266, 0.019358393365109805, 0.07317262163269334, 0.014213821959856432, 0.1277434008079581, 0.06606699549593031, 0.3659683669684455, 0.13387036422500387, 0.5580052232835442, 9.3835917301476, 21.876188032329082, 37.597261145710945, 70.55087506771088, 91.2708668410778, 103.10392588376999, 109.72605094313622, 130.16572415828705, 118.04723963141441, 121.25430554151535, 99.6923853456974, 108.33845660090446, 119.52821776270866, 122.90685206651688, 127.81223684549332, 101.8682549893856, 136.63878321647644, 134.0985131263733, 115.0037169456482, 128.58174115419388, 125.62873721122742, 122.38785311579704, 123.05986985564232, 116.89020171761513, 134.50427055358887, 126.23650699853897, 132.28596478700638, 130.93603402376175, 110.5111800134182, 115.7326090335846, 124.91822853684425, 121.1379861831665, 112.59301990270615, 110.27256801724434, 128.92106294631958, 128.47098469734192, 137.84002035856247, 140.73105722665787, 140.5133593082428, 134.53991264104843, 113.96903246641159, 85.79399272799492, 63.37106913328171, 45.92503108084202, 31.083574667572975, 17.016450203955173, 3.3329538675025105, 0.704590966925025, 0.13363635021960363, 0.11106120495242067, 0.11146870339871384, 0.08922178036300465, 0.06709304434480146, 0.1510609535034746, 0.06206686404766515, 0.03795896118390374, 0.07085493896738626, 0.018500273981771898, 0.059941620274912566, 0.04863152345933486, 0.04856414016103372, 0.03360370836162474, 0.04745167192595545, 0.00363720221685071, 0.07822536339517683, 0.04372817602416035, 0.050275870380573906, 0.02144799549569143, 0.014141363299131626, 0.017205302356160246, 0.02497741050319746, 0.01786378401448019, 0.03840686957119033, 0.02138340823876206, 0.03979367269494105, 0.018329754420847166, 0.04726819446659647, 0.0743193733796943, 0.05207594214880373, 0.10136563185369596, 0.046915618659113534, 0.022573816822841763, 0.010771096294774907, 0.0720955352880992, 0.01331824731096276, 0.046541683841496706, 0.10095802950672805, 0.02121686287864577, 0.02350679293158464, 0.010329790238756686, 0.026689574879128486, 0.05612642831692938, 0.024819704121910036, 0.03811795519141015, 0.014218316591723124, 0.010311317255400354, 0.04818604560568929, 0.004169009471297613, 0.020068304002052173, 0.10052842248114757, 0.025832449973677285, 0.014260770221881103, 0.07494227276765741, 0.05070160339528229, 0.029071885619487148, 0.03279629621829372, 0.05423650472948793, 0.039644445350859314, 0.04721033292298671, 0.015941281999403145, 0.028543856824398972, 0.036320117287687026, 0.01253732705663424, 0.005539359644899378, 0.22647382953437045, 0.11300681188004091, 0.19862304587149993, 0.11359516429365613, 0.17191579303471372, 0.11706488279742189, 0.13855693774530664, 0.17437665082979947, 0.32055361953098327, 0.12033586157485843, 0.16368470736779273, 0.16027542937081307, 0.0898385644541122, 0.14107140828855336, 0.09298795717768371, 0.23346784408204257, 0.17803828872274607, 0.11522158834850416, 0.19749940460314974, 0.1753624901175499, 0.11441493319580331, 0.12383266104734503, 0.13097398448735476, 0.11696190980728716, 0.18994839338120073, 0.12045666837366298, 0.10459125056513585, 0.09432336286408827, 0.12464477098546922, 0.31809945590794086, 0.2213588883751072, 0.11380599360563792, 0.15801276953425258, 0.18641007074620575, 0.12334648752585053, 0.11461707937996835, 0.14744350308319554, 0.21483723598066717, 0.15116659080376849, 0.23646481451578438, 0.19158591254381463, 0.09835493168793619, 0.21894395467825234, 0.10488438405445777, 0.2737432188587263, 0.12087182578397915, 0.2146065913257189, 0.18702358938753605, 0.19829351746011525, 0.23358163016382605, 0.16423595981905237, 0.2887969423318282, 0.1447300033760257, 0.20266902720322832, 0.18666415242478251, 0.19381573976716027, 0.11274500444415025, 0.25888025702442974, 0.2363404305651784, 0.6746765377465636, 0.13111625419696793, 1.2771060084924102, 15.666971616446972, 29.602144360542297, 48.892918825149536, 84.14019227027893, 109.50364127755165, 122.3472560942173, 129.1568174958229, 145.3943645954132, 134.7613799571991, 131.3535252213478, 108.43019127845764, 102.61374458670616, 112.44875684380531, 112.0451121032238, 101.19788736104965, 86.50535255670547, 116.0764829814434, 120.85107877850533, 98.17271769046783, 120.16235053539276, 108.31551343202591, 104.73026901483536, 126.08267605304718, 107.05402672290802, 111.59659177064896, 127.48930737376213, 135.68144738674164, 130.80006211996078, 107.41060718894005, 111.04861557483673, 114.68294575810432, 116.06933936476707, 113.9199011027813, 112.09146201610565, 128.89435797929764, 127.84745335578918, 144.66956108808517, 155.70667684078217, 157.80294835567474, 157.40834712982178, 132.56640493869781, 102.04746097326279, 77.32610151171684, 57.866182923316956, 40.29665909707546, 26.18581037968397, 6.092350836843252, 0.8803945896215737, 0.5628810147754848, 0.22835529263829812, 0.3637057665036991, 0.12148179695941508, 0.35258732561487705, 0.29277886147610843, 0.11600656536757015, 0.23531610349891707, 0.15432503772899508, 0.10855273096240126, 0.11597520220675506, 0.12612851714948192, 0.1352945456164889, 0.15419802657561377, 0.14790924527915195, 0.08206594793591648, 0.13893149967771024, 0.14341684727696702, 0.10695769233279862, 0.16166280023753643, 0.12073835052433424, 0.14019390771863982, 0.10127114903298207, 0.13162092946004122, 0.10622598667396232, 0.07578319287858903, 0.12520553776994348, 0.0678733829408884, 0.2503172680735588, 0.17422164586605504, 0.08356616977835074, 0.13049872795818374, 0.16358741180738434, 0.15417871589306742, 0.19362739752978086, 0.14436833997024223, 0.11250814059167169, 0.09175867860903963, 0.249818901065737, 0.09372302476549521, 0.18124824069673195, 0.1574180569150485, 0.09380529925692827, 0.10778486044728197, 0.1898167363833636, 0.12116941958083771, 0.1258494399371557, 0.134326295228675, 0.2595504460623488, 0.10513425033423118, 0.09497254912275821, 0.2581883379025385, 0.10689006783650257, 0.14554856257745996, 0.2403711384977214, 0.11662867065751925, 0.10959058738080785, 0.11397760783438571, 0.17200174857862294, 0.08966245281044394, 0.1621724182041362, 0.08488086954457685, 0.12635000370210037, 0.19628341047791764, 0.2213437930913642, 0.11157481567352079], [0.03881403405102901, 0.07707578406552784, 0.033090012293541804, 0.06075103621697053, 0.042860813191509806, 0.028617273783311248, 0.009599297063687118, 0.07515988530940376, 0.1535009272629395, 0.03695755534863565, 0.016253067515208386, 0.026364809200458694, 0.12258967501111329, 0.031698978928034194, 0.05080250579339918, 0.0479712086962536, 0.029841676441719756, 0.030248087641666643, 0.03967980126617476, 0.05121754446008708, 0.027365022033336572, 0.036623351406888105, 0.01384779565341887, 0.06430106252082624, 0.03790680304518901, 0.08091079507721588, 0.046392118820222095, 0.03921609997632913, 0.019292646502435673, 0.033818782758316956, 0.006923568962520221, 0.0448412231344264, 0.02452969321893761, 0.03480863706499804, 0.03880311705870554, 0.05883005003852304, 0.04686111904447898, 0.06197755770699587, 0.06180116404721048, 0.022657557055936195, 0.012460136276786216, 0.047015574818942696, 0.03382469767529983, 0.021994145681674127, 0.05257899952994194, 0.0311521422554506, 0.07823118183296174, 0.031143815358518623, 0.05519821308553219, 0.016149831062648445, 0.00591076605815033, 0.03988441880210303, 0.04536343905783724, 0.01632761996006593, 0.03853405884001404, 0.03373607039975468, 0.12763087637722492, 0.3058634593617171, 0.735951930982992, 15.366666130721569, 48.861266523599625, 67.97886148095131, 95.63497826457024, 91.66087031364441, 98.72580081224442, 93.16687390208244, 91.41759976744652, 78.59008088707924, 87.05389112234116, 65.65410822629929, 77.2563448548317, 47.45384484529495, 61.366110518574715, 58.38593803346157, 39.19096402823925, 42.28994093835354, 25.342694520950317, 30.015140399336815, 25.05656037479639, 33.252015709877014, 29.91556104272604, 30.19348192960024, 38.81457142531872, 25.191759020090103, 30.28830014169216, 39.4033270329237, 22.246740348637104, 56.33535526692867, 42.8066486120224, 42.29471728205681, 37.133043855428696, 50.14069586992264, 70.73134258389473, 56.78739421069622, 52.52391278743744, 40.69846473634243, 56.93756215274334, 63.04698072373867, 77.786895185709, 94.01871979236603, 94.59150105714798, 78.3013267815113, 99.66685071587563, 108.99613291025162, 107.46680617332458, 108.53131145238876, 109.72688689827919, 108.12189102172852, 86.98588237166405, 37.87442587316036, 2.9339185170829296, 0.4063967725960538, 0.7566513202618808, 0.2012556217960082, 0.004495914854487637, 0.050198464377899654, 0.044576461950782686, 0.026008904860646, 0.08264701245934702, 0.10278816567733884, 0.10183739286730997, 0.08940806685131975, 0.021261712718114723, 0.0831761934387032, 0.0403737390297465, 0.011226689621253172, 0.02845377122866921, 0.0617520041851094, 0.021744040059274994, 0.06936346704605967, 0.03389997000340372, 0.11245100264204666, 0.017463950098317582, 0.03509643080178648, 0.03131532939733006, 0.04176900634774938, 0.037896587382419966, 0.0771779555361718, 0.026115553337149322, 0.05089584199595265, 0.058129941317019984, 0.03908317390596494, 0.07185352093074471, 0.04121513040445279, 0.04056384015711956, 0.0672635824594181, 0.05398362533014733, 0.01470563116527046, 0.03337675589136779, 0.08001441427040845, 0.06852862512459978, 0.022761732325307094, 0.02269184242322808, 0.036729066632688046, 0.02732486442255322, 0.025716856762301177, 0.062466673844028264, 0.01272843379410915, 0.0415205501485616, 0.0481836967082927, 0.1027452175912913, 0.03394886269234121, 0.047883371807984076, 0.04421290235768538, 0.057433925539953634, 0.02648958092322573, 0.024946268131316174, 0.0855459229205735, 0.05164908478036523, 0.02180419112846721, 0.07268655201187357, 0.0335420358896954, 0.09298489952925593, 0.03932093575713225, 0.017893069161800668, 0.05154405975190457, 0.09053673245944083, 0.05915307723626029, 0.029833444168616552, 0.03762536580325104, 0.010813450662681134, 0.011528410686878487, 0.0773325894260779, 0.0870249787112698, 0.0030563202153643942, 0.019920429222111125, 0.06985692845773883, 0.021785516837553587, 0.0744828833558131, 0.03733964265848044, 0.0469602439989103, 0.010428903133288259, 0.01708629341010237, 0.019411952307564206, 0.02392990059888689, 0.05121469832374714, 0.04202201191219501, 0.06935422730748542, 0.029858140987926163, 0.03640941249614116, 0.03290449021733366, 0.06117410863225814, 0.004834133351323544, 0.0415038184291916, 0.04463758523343131, 0.01446547774321516, 0.04972474409441929, 0.01313037633735803, 0.028369151550577953, 0.017772080536815338, 0.06923247055965476, 0.09101331001147628, 0.02505832500901306, 0.05798807607789058, 0.07307543739443645, 0.027641818996926304, 0.06160338169138413, 0.05716569852665998, 0.07564494560938329, 0.038774228960392065, 0.025367140078742523, 0.03203485641279258, 0.07753385987598449, 0.03567268249753397, 0.05542837534449063, 0.06298749824054539, 0.001788836348168843, 0.0496823377761757, 0.022422060610551853, 0.09990417980588973, 0.07709505764069036, 0.04012052566395141, 0.02206901910540182, 0.26633023226168007, 0.21289715805323794, 19.190837927162647, 53.522499203681946, 81.49485781788826, 108.50997179746628, 110.49304738640785, 112.93113335967064, 107.16517835855484, 104.17434364557266, 101.61008164286613, 112.4717304110527, 93.68077352643013, 110.50721302628517, 95.09540721774101, 97.0447026193142, 90.26971936225891, 72.15246632695198, 60.208221450448036, 41.508585065603256, 39.74003076553345, 42.02528513967991, 54.740827828645706, 38.43718707561493, 46.9645868986845, 55.700451135635376, 42.67029672861099, 56.06857918202877, 53.119344636797905, 49.693942442536354, 73.75848054885864, 73.25581312179565, 69.89611700177193, 58.602773398160934, 64.05156701803207, 90.98298668861389, 87.34793454408646, 80.25458917021751, 79.816814661026, 94.13330644369125, 99.64534386992455, 121.10940411686897, 126.92175462841988, 131.85879170894623, 103.72628688812256, 129.8957258462906, 133.91856998205185, 134.04229134321213, 134.837786257267, 126.74846112728119, 129.49428498744965, 104.77496981620789, 47.768513560295105, 4.587401691824198, 0.2829792763805017, 0.5386552365962416, 0.18790368747431785, 0.034980655764229596, 0.014761169786652317, 0.02076498214591993, 0.060551372516783886, 0.06080580300476868, 0.0853055264451541, 0.08961102939792909, 0.05297914700349793, 0.03225571956136264, 0.07573731330921873, 0.03502921077597421, 0.018065371732518543, 0.012522848683147458, 0.06261633534450084, 0.03431757650105283, 0.14011675404617563, 0.055249298820854165, 0.04146309678617399, 0.07545160129666328, 0.011451976897660643, 0.01026255258693709, 0.029332051053643227, 0.06168689928017557, 0.027305755975248758, 0.08525436278432608, 0.08913606230635196, 0.02392455528024584, 0.030423655662161764, 0.06442418482038192, 0.03776354256842751, 0.03782001258514356, 0.022373976862581912, 0.02099385306792101, 0.0036333358593765297, 0.05513103758858051, 0.016441945954284165, 0.022880017677380238, 0.021234652158454992, 0.010703785355872242, 0.05652211548294872, 0.11680160590913147, 0.04352168456534855, 0.04531934806436766, 0.008060370364546543, 0.0377545366063714, 0.02286262173583964, 0.0316684358404018, 0.017588810878805816, 0.029744649909844156, 0.020426852242962923, 0.02907504345785128, 0.017500821850262582, 0.0578646420763107, 0.07638220253284089, 0.04321528889704496, 0.06464975318522193, 0.053488575722440146, 0.029071206554363016, 0.0025979642441598116, 0.017491151666035876, 0.0456443679286167, 0.02167505557736149, 0.18763887434033677, 0.0960624375147745, 0.18524198967497796, 0.11691785592120141, 0.11517471430124715, 0.09738027656567283, 0.24790306168142706, 0.17835965350968763, 0.2251007524318993, 0.11212888086447492, 0.11508023890201002, 0.1241161095094867, 0.22370891383616254, 0.13238764222478494, 0.137970982468687, 0.11235030062380247, 0.16970361408311874, 0.10861015092814341, 0.15393782960018143, 0.11293357674730942, 0.10362956818426028, 0.13698918046429753, 0.12533366214483976, 0.1100236750789918, 0.15516617306275293, 0.19264390342868865, 0.09659171497332864, 0.15687012928538024, 0.19936302647693083, 0.14504216553177685, 0.09568927824147977, 0.12866991281043738, 0.1210336213989649, 0.0802743218082469, 0.18676015664823353, 0.146712695423048, 0.14781312231207266, 0.1997396070510149, 0.14882320014294237, 0.18026591918896884, 0.0957997098157648, 0.16882087395060807, 0.1301613773102872, 0.2514982328284532, 0.18938406428787857, 0.2661076176445931, 0.2168441071989946, 0.1848759624408558, 0.12889172590803355, 0.13194309576647356, 0.11220279135159217, 0.2012668875977397, 0.09607395564671606, 0.2243013703264296, 0.1934228913160041, 0.12865496595622972, 0.2529610355850309, 0.6444335449486971, 1.717062194366008, 28.207463398575783, 75.80391839146614, 101.75254359841347, 126.63727149367332, 120.17548263072968, 129.86148208379745, 119.18149396777153, 114.50865671038628, 100.41173994541168, 110.3320424258709, 83.48675653338432, 101.33154138922691, 68.66036251187325, 87.60146453976631, 80.18350258469582, 54.52663332223892, 55.359997004270554, 32.212995663285255, 44.333516880869865, 33.62446032464504, 43.1770109385252, 44.10631567239761, 45.29909446835518, 49.32932160794735, 36.76229014992714, 44.40497204661369, 51.3334746658802, 35.46442039310932, 78.09255078434944, 60.58013029396534, 65.62053322792053, 53.2406797260046, 70.6915283203125, 94.29909154772758, 79.74936068058014, 76.4929886162281, 64.23174574971199, 82.45515748858452, 94.85161229968071, 111.4962999522686, 125.52545115351677, 121.19006618857384, 102.69141241908073, 130.55363774299622, 141.09788954257965, 143.80858808755875, 148.14334988594055, 145.1137724518776, 144.97328639030457, 124.65991079807281, 63.99555802345276, 7.355806790292263, 0.44662464992143214, 0.8787919068709016, 0.516322588082403, 0.19990914326626807, 0.1555384194944054, 0.06080062281398568, 0.10094816636410542, 0.19248610798968002, 0.26851843984331936, 0.1677027394180186, 0.24045259662671015, 0.16367074014851823, 0.21715150476666167, 0.1804157142760232, 0.10575527208857238, 0.13895032054279, 0.2602321532322094, 0.14333964907564223, 0.17221055924892426, 0.13432923413347453, 0.22285306913545355, 0.10784170153783634, 0.119202757923631, 0.11844807537272573, 0.1717683728202246, 0.059459498879732564, 0.2702838310506195, 0.18619505572132766, 0.20815152442082763, 0.12972843804163858, 0.10742244005086832, 0.1331377011956647, 0.14847306971205398, 0.11827724039903842, 0.1393323633237742, 0.18343098607147112, 0.09209372859913856, 0.0998726904799696, 0.26446340430993587, 0.19415659335209057, 0.11959023322560824, 0.20519526820862666, 0.1546788788982667, 0.15162293741013855, 0.19020948093384504, 0.1400468882638961, 0.13645572471432388, 0.18010977131780237, 0.10413324896944687, 0.10940666092210449, 0.15977683971868828, 0.13657283561769873, 0.10902003908995539, 0.21141611330676824, 0.09709240490337834, 0.18706869712332264, 0.2225564030231908, 0.13723728043260053, 0.20324604702182114, 0.17708710773149505, 0.1235238162917085, 0.1164622069336474, 0.3190004825592041, 0.12160328653408214, 0.1595505588920787], [0.039194332784973085, 0.06971496302867308, 0.04718888856587, 0.019574542020563968, 0.07161493529565632, 0.04026183429232333, 0.06400736499927007, 0.05642689051455818, 0.039078509507817216, 0.009237449976353673, 0.04116208539926447, 0.034366840263828635, 0.052842179939034395, 0.011366144735802663, 0.06688250447041355, 0.05251612848951481, 0.03538114462571684, 0.04176803042355459, 0.037969651821185835, 0.04441954966750927, 0.04083182226167992, 0.05733338308345992, 0.059153993788640946, 0.0036100734723731875, 0.06127760112576652, 0.039149829899542965, 0.05745632355683483, 0.003520858276715444, 0.031047616321302485, 0.03333996392029803, 0.015822471577848773, 0.04336476114985999, 0.029382038410403766, 0.03744361754797865, 0.061905532274977304, 0.06209532170032617, 0.0397733230056474, 0.06017289946612436, 0.08068125622230582, 0.034231966055813245, 0.03885272963088937, 0.06418559176381677, 0.041200729028787464, 0.033833640554803424, 0.061815379885956645, 0.039799554215278476, 0.10512877328437753, 0.023151517561927903, 0.017587619731784798, 0.06421397891244851, 0.015699924442742486, 0.11044388651498593, 0.04756804810313042, 0.07522975109168328, 0.08383668260648847, 0.13708896964089945, 4.628083733841777, 21.95319090038538, 58.092369586229324, 84.61553156375885, 86.44431263208389, 83.25407221913338, 83.42956200242043, 72.1755538880825, 85.37188097834587, 73.10229375958443, 62.953927516937256, 41.71654410660267, 24.445026889443398, 49.63616654276848, 35.381698831915855, 50.83120621740818, 32.39925026893616, 65.98567843437195, 73.81455034017563, 83.136787712574, 125.946696549654, 98.51256385445595, 116.69737726449966, 116.68296083807945, 96.94508716464043, 81.73401698470116, 116.25366747379303, 114.06265184283257, 75.02656370401382, 108.13623145222664, 135.9413382411003, 69.56486597657204, 64.68618616461754, 72.39808514714241, 62.015423476696014, 80.91750159859657, 90.58125704526901, 59.33744117617607, 46.914896965026855, 53.2009756565094, 51.594642251729965, 40.23059204220772, 45.72661332786083, 58.68983052670956, 46.32540039718151, 47.42646351456642, 42.33042396605015, 49.227513670921326, 51.564243882894516, 69.44693550467491, 92.47898161411285, 87.66467794775963, 102.06164941191673, 102.43117198348045, 90.6139124929905, 54.79241386055946, 15.257058162242174, 5.216614678502083, 1.5977469342760742, 0.18800125020788983, 0.10195122347795404, 0.07248088062624447, 0.11380476906197146, 0.04532068764092401, 0.10261559407808818, 0.03505110784317367, 0.02170532778109191, 0.12980024825083092, 0.020147567229287233, 0.07616412243805826, 0.08963250715169124, 0.038111275862320326, 0.014980122832639609, 0.04622088679752778, 0.051220531604485586, 0.042568202916299924, 0.09430453457753174, 0.010698055048123933, 0.05463192472234368, 0.03573983573005535, 0.052122927518212236, 0.014473559731413843, 0.09998529654694721, 0.03703857189975679, 0.03559148040949367, 0.01843873324105516, 0.027735403818951454, 0.04249866738973651, 0.036295214522397146, 0.058975945139536634, 0.024423547547485214, 0.017264687157876324, 0.036006827067467384, 0.05527201596123632, 0.041289289511041716, 0.07492370423278771, 0.06340642576105893, 0.06744695972884074, 0.019949842389905825, 0.022212355652300175, 0.10010844853240997, 0.03376738903170917, 0.015027607296360657, 0.0008739565828363993, 0.051108010884490795, 0.03819183228188194, 0.04437304669409059, 0.05083734962681774, 0.018528098953538574, 0.015947914944263175, 0.04395648662466556, 0.015262087927112589, 0.04739084921311587, 0.02611375919514103, 0.05465929141792003, 0.08200903263059445, 0.04170556385361124, 0.040564422743045725, 0.0451896243612282, 0.022216660108824726, 0.015259529372997349, 0.04926854591758456, 0.03959488843975123, 0.026400294991617557, 0.021749099651060533, 0.013049251247139182, 0.010234043911623303, 0.023159564298111945, 0.03532821836415678, 0.027523390781425405, 0.0656559198978357, 0.0434182959725149, 0.027404259381000884, 0.04594970974721946, 0.031126762660278473, 0.05267169377475511, 0.07026910243439488, 0.013095088143018074, 0.055221768852788955, 0.04054803983308375, 0.01718485804303782, 0.06067257265385706, 0.05275402021652553, 0.01949741617863765, 0.04946915214532055, 0.05768565461039543, 0.07776309445034713, 0.02796880555251846, 0.02918257137935143, 0.006161647688713856, 0.004774306044055265, 0.05854052709764801, 0.03981322457548231, 0.02124571386957541, 0.027009440527763218, 0.052942169495509006, 0.02261277400975814, 0.06005893155816011, 0.05244808839051984, 0.04858612628595438, 0.0766598474001512, 0.017810442150221206, 0.09153974504442886, 0.021239971501927357, 0.04984429295291193, 0.05053514338214882, 0.07673001746297814, 0.009468370153626893, 0.046579737463616766, 0.03321376170788426, 0.04948547197273001, 0.05712930731533561, 0.051002696418436244, 0.07726778509095311, 0.08830822625895962, 0.21965907333651558, 3.742081713862717, 23.136409409344196, 69.33614864945412, 98.46255093812943, 101.67058199644089, 98.20980370044708, 98.95659282803535, 97.14093625545502, 109.50654432177544, 114.69176888465881, 102.90179952979088, 73.9860351383686, 56.55406393110752, 63.79710227251053, 44.970104321837425, 37.4701389670372, 31.14453099668026, 45.82507744431496, 34.571179524064064, 42.383852899074554, 42.43583790957928, 62.19512723386288, 45.35076789557934, 56.82538837194443, 55.869063287973404, 44.63783875107765, 50.268824994564056, 49.44390065968037, 38.585713505744934, 55.66965378820896, 49.14841331541538, 41.48833215236664, 27.559345476329327, 38.375751972198486, 26.39963250607252, 49.99292939901352, 55.90647608041763, 32.7995739877224, 29.548949114978313, 31.772403605282307, 30.2835750952363, 39.88485999405384, 50.90820528566837, 73.15245106816292, 61.831083968281746, 77.18110889196396, 85.30092358589172, 89.43563371896744, 91.15907683968544, 103.83392751216888, 119.78039503097534, 103.07182520627975, 121.78664177656174, 122.21696868538857, 110.96774071455002, 71.60197466611862, 20.06587017327547, 5.857000015676022, 1.722369915805757, 0.11928652413189411, 0.1801493574748747, 0.07940364899695851, 0.11604338331380859, 0.08613060170318931, 0.03596681046474259, 0.07748461095616221, 0.011530401498021092, 0.04688697175879497, 0.029457709642883856, 0.027761492165154777, 0.05051509055192582, 0.030791228418820538, 0.017391371766279917, 0.04402706486871466, 0.04771464824443683, 0.02901075862610014, 0.05280343611957505, 0.06819997986895032, 0.06916009631822817, 0.06642986118094996, 0.07467570816515945, 0.019633114170574117, 0.03740346735867206, 0.06410727291950025, 0.02460447016346734, 0.01455759311284055, 0.008687736553838477, 0.0368031737889396, 0.05584591875958722, 0.029973622877150774, 0.03329501945700031, 0.01908686008391669, 0.0758638940169476, 0.03426676907110959, 0.029069071024423465, 0.020867786297458224, 0.004233490044498467, 0.03290514330728911, 0.04461635238840245, 0.03213480144040659, 0.05601118391496129, 0.030601142134401016, 0.045195910352049395, 0.06561595524544828, 0.03476312856946606, 0.028570698450494092, 0.07878115779021755, 0.011990021903329762, 0.005702784737877664, 0.022744252892152872, 0.028789995667466428, 0.04349362396169454, 0.018683714333747048, 0.04335114273999352, 0.04768664330185857, 0.03634086773672607, 0.02738825867709238, 0.06219690687430557, 0.05444302216346841, 0.0518045239005005, 0.12075264428858645, 0.11183566573890857, 0.13040174409979954, 0.11689432983985171, 0.10939135041553527, 0.1607512796181254, 0.1766414480516687, 0.1489705016138032, 0.17368207481922582, 0.13431618717731908, 0.12691020645434037, 0.10730544046964496, 0.08665707384352572, 0.15665852813981473, 0.1852105968282558, 0.16177860496100038, 0.12734786578221247, 0.09240785002475604, 0.22008505125995725, 0.15465884091099724, 0.1434365290333517, 0.1667022649780847, 0.13020375394262373, 0.16480842285091057, 0.11567724475753494, 0.10894002072745934, 0.19637610472273082, 0.13132317981217057, 0.0940618003369309, 0.11940463693463244, 0.1030485110823065, 0.16903844196349382, 0.1052626344608143, 0.11107294572866522, 0.12831777858082205, 0.1691603026119992, 0.2237154744216241, 0.1927102217450738, 0.15079961362062022, 0.14572427346138284, 0.23303408845094964, 0.21423036698251963, 0.16351607657270506, 0.18781304155709222, 0.1596603522193618, 0.1587385157472454, 0.27260886097792536, 0.10014678788138554, 0.11767634568968788, 0.2075589937157929, 0.13938593154307455, 0.1905605019419454, 0.19753970322199166, 0.33836510439869016, 0.24285521067213267, 0.41009863489307463, 8.038484808057547, 34.96427983045578, 92.8342093527317, 117.33275637030602, 109.32530924677849, 104.32971730828285, 105.94779208302498, 94.01521638035774, 107.56206706166267, 92.5050938129425, 85.3954929113388, 59.1803690046072, 41.641558930277824, 69.98291194438934, 48.033169358968735, 67.81585022807121, 43.49218122661114, 93.38521778583527, 108.30146178603172, 121.85281902551651, 187.380713224411, 150.53368002176285, 174.82475817203522, 176.3104784488678, 146.29306197166443, 124.55790907144547, 165.54933428764343, 164.91004139184952, 116.79812505841255, 155.81796526908875, 188.61710608005524, 98.12053889036179, 95.87184995412827, 106.69031023979187, 91.15807369351387, 113.52780774235725, 132.89183467626572, 87.8277575969696, 69.6992951631546, 76.10524222254753, 69.88261252641678, 56.71666480600834, 59.67827148735523, 76.690813601017, 62.28431984782219, 71.51227667927742, 59.867923110723495, 69.96596485376358, 70.89417904615402, 92.40419402718544, 118.72476607561111, 114.23070922493935, 132.61625826358795, 134.0412425994873, 127.5267505645752, 92.0253923535347, 30.167168341577053, 8.849518038332462, 2.5640893494710326, 0.23505293793277815, 0.23191812098957598, 0.34189659927506, 0.2635965758236125, 0.2034264779649675, 0.21849599434062839, 0.2219201301340945, 0.15789625234901905, 0.23095561482477933, 0.1497463131090626, 0.15623507351847365, 0.13207810727180913, 0.1674933498725295, 0.12365876100375317, 0.15256224403856322, 0.18428004754241556, 0.1071491590118967, 0.1637462165672332, 0.13585549051640555, 0.30718290887307376, 0.13028712681261823, 0.112228632933693, 0.09427697121282108, 0.18384681141469628, 0.19880454550730065, 0.12590047001140192, 0.10719576588599011, 0.08890676836017519, 0.09686055054771714, 0.1101885580283124, 0.15994775632862002, 0.10981203682604246, 0.14373721758602187, 0.1304462581174448, 0.1427092688390985, 0.1385612867306918, 0.16789609857369214, 0.12836667126975954, 0.25059310952201486, 0.21554025763180107, 0.1129319440224208, 0.12519507348770276, 0.12129519134759903, 0.12250412764842622, 0.1957198977470398, 0.12621487345313653, 0.14163506944896653, 0.13699891744181514, 0.08627854142105207, 0.11071730856201611, 0.11969198909355327, 0.09503754641627893, 0.14034915016964078, 0.17383568454533815, 0.10685459317755885, 0.1538012595847249, 0.1709633058635518, 0.11057134295697324, 0.1304453081684187, 0.10259386399411596, 0.12811086780857295], [0.048097540784510784, 0.062068270417512394, 0.06908499839482829, 0.06240014772629365, 0.02619977225549519, 0.061224092278280295, 0.08050603515584953, 0.054482671403093264, 0.028875760108348913, 0.03026977134140907, 0.0550218639546074, 0.020310431536927354, 0.042607544164638966, 0.0036326336021375027, 0.07739509310340509, 0.026235777550027706, 0.029768105487164576, 0.030153263433021493, 0.026499753912503365, 0.008250338833022397, 0.043953028216492385, 0.005994202010697336, 0.02494953358109342, 0.014822546327195596, 0.005401530761446338, 0.035158459504600614, 0.05739530417486094, 0.03358634210599121, 0.05131277684995439, 0.04699283541413024, 0.007279767842192086, 0.0546008472883841, 0.05536265445698518, 0.01931339138536714, 0.008598102740506874, 0.03301839133200701, 0.0014282822212408064, 0.017631426853768062, 0.039370770973619074, 0.04765566234709695, 0.003593233445826627, 0.05236699762463104, 0.02687693191546714, 0.05071149251307361, 0.02461107898852788, 0.06292446763836779, 0.04064581778948195, 0.11359854106558487, 0.011307910262985388, 0.07361888987361453, 0.06335403755656444, 0.0891134119592607, 0.3190446848748252, 3.553259395994246, 15.624053869396448, 49.41917918622494, 75.60369193553925, 83.50273087620735, 84.56696256995201, 71.50747373700142, 84.14012387394905, 84.70539674162865, 59.64269019663334, 56.660614013671875, 41.981967464089394, 26.707150004804134, 18.166424296796322, 43.6400692909956, 62.90882773697376, 67.11216598749161, 93.016766756773, 139.82286036014557, 100.37928208708763, 89.2851085960865, 98.52755784988403, 64.65495944023132, 60.13199754059315, 42.808077335357666, 56.02712720632553, 47.586195543408394, 40.509728863835335, 54.82365198433399, 55.930840373039246, 53.07295672595501, 57.515799924731255, 57.579651698470116, 87.41149753332138, 76.50780782103539, 85.88785529136658, 78.38007375597954, 88.21906819939613, 81.34614899754524, 83.28972950577736, 98.23327884078026, 97.55760669708252, 122.84164756536484, 114.91971865296364, 101.55993193387985, 121.5769462287426, 83.43779236078262, 77.24586501717567, 47.97701217234135, 50.39610296487808, 39.7956445813179, 45.41747711598873, 34.80825260281563, 48.66127945482731, 76.90667241811752, 57.389977276325226, 92.25154101848602, 83.34025919437408, 95.22825568914413, 94.54313725233078, 89.27256926894188, 85.12389108538628, 33.75608906149864, 6.439682124182582, 0.2507746982155368, 0.4739741573575884, 0.32627082837279886, 0.3726158133940771, 0.08304776478325948, 0.05658059671986848, 0.029943547342554666, 0.0865018684999086, 0.08996064774692059, 0.024601249242550693, 0.03816436910710763, 0.04231849619827699, 0.05033234410802834, 0.039498301630374044, 0.01120538812756422, 0.05373372936446685, 0.044400469050742686, 0.02731577867962187, 0.008670363804412773, 0.0345968429610366, 0.02113789836585056, 0.06457842537201941, 0.06439005344873294, 0.10789004503749311, 0.02676912939932663, 0.022579696487809997, 0.014369360342243453, 0.02100546953442972, 0.06297658866969869, 0.048203979604295455, 0.041946836063289084, 0.014727739744557766, 0.025770649481273722, 0.02686192383407615, 0.012442323804862099, 0.026477559986233246, 0.03008953521202784, 0.028155041945865378, 0.05740522297855932, 0.03452107710472774, 0.05490444505994674, 0.026561285376374144, 0.012489051277952967, 0.038673092785757035, 0.04548158154648263, 0.012122540720156394, 0.05426325915323105, 0.00849979136546608, 0.035032145970035344, 0.03624901954026427, 0.056720985085121356, 0.043736309962696396, 0.07287348416866735, 0.03409023440326564, 0.02981754736538278, 0.025508511789666954, 0.027407704801589716, 0.05440541011921596, 0.065505753736943, 0.03540850761055481, 0.016122969027492218, 0.04838291883061174, 0.03184740475262515, 0.008116490644169971, 0.06362338521284983, 0.0354843105742475, 0.01101571095205145, 0.04052659176522866, 0.08221103780670092, 0.020454955520108342, 0.048777125412016176, 0.06455791983171366, 0.04283004003809765, 0.021042411790404003, 0.03220980659534689, 0.05647238787787501, 0.018512617753003724, 0.01233464281540364, 0.0545289405999938, 0.027284296775178518, 0.01999223943130346, 0.0464278161234688, 0.009779091615200741, 0.03442553672357462, 0.058371150444145314, 0.03462255837803241, 0.037289655301719904, 0.04201700241537765, 0.03158494793751743, 0.006702987366224988, 0.027178438685950823, 0.07681126036914065, 0.046560571499867365, 0.042929758710670285, 0.025487865241302643, 0.03401578214834444, 0.028507807001005858, 0.07218771745101549, 0.014212560308806133, 0.034033126139547676, 0.06258725799852982, 0.03560737350198906, 0.03687442367663607, 0.15421717398567125, 0.03371842212800402, 0.05625288285955321, 0.13843727385392413, 0.04012207304185722, 0.030482674956147093, 0.09090654464671388, 0.05591041139268782, 0.08040139233344235, 2.9684377647936344, 16.70165229588747, 54.93223875761032, 90.95646411180496, 101.19323641061783, 101.37189522385597, 96.42753213644028, 114.0691114962101, 103.8444073498249, 91.4452774822712, 81.45445838570595, 73.30094709992409, 46.165090799331665, 25.853858292102814, 26.953464187681675, 32.68633246421814, 49.77874629199505, 65.61481073498726, 105.08870378136635, 76.01280078291893, 85.64610466361046, 91.77820041775703, 76.06983572244644, 69.21370401978493, 53.594110161066055, 65.39797157049179, 57.52075865864754, 49.45287197828293, 56.70334652066231, 57.90518023073673, 61.17270469665527, 57.66717620193958, 64.94505107402802, 82.72180438041687, 75.63284397125244, 81.16220846772194, 75.52812159061432, 75.56029066443443, 83.63678768277168, 90.6564550101757, 90.55082067847252, 86.42014592885971, 90.3491958975792, 99.6637424826622, 75.38109987974167, 84.58454802632332, 63.39672535657883, 51.47130087018013, 35.51159866154194, 25.913526490330696, 34.37118485569954, 49.25977014005184, 60.090389773249626, 81.63004696369171, 123.76613795757294, 95.22141605615616, 113.8721452653408, 105.84352567791939, 108.08314070105553, 117.26220935583115, 107.38934352993965, 100.99852725863457, 40.493959710001945, 8.12354039400816, 0.14941887755412608, 0.31494375492911786, 0.5153924692422152, 0.22924434102606028, 0.027623003697954118, 0.023045470225042664, 0.055498734654975124, 0.045021179103059694, 0.06638544364250265, 0.033506594627397135, 0.030447484168689698, 0.05304278987750877, 0.029351543562370352, 0.045260094993864186, 0.035595513982116245, 0.03784465559874661, 0.05587273626588285, 0.061341752370935865, 0.04047791058837902, 0.05658435940858908, 0.045996769331395626, 0.01376495805743616, 0.10768769105197862, 0.04506906247115694, 0.05064202006906271, 0.038828498509246856, 0.0376672934362432, 0.055053980395314284, 0.0846585221006535, 0.08206896105548367, 0.04959034857165534, 0.047938409479684196, 0.005325244937921525, 0.024151583820639644, 0.07142009926610626, 0.02890796746214619, 0.019229289355280343, 0.038049673894420266, 0.02915830129495589, 0.042138621865888126, 0.07222725165775046, 0.030327525273605715, 0.04041526961373165, 0.05355093839170877, 0.04182991811831016, 0.02827444979629945, 0.009069965799426427, 0.03259766410337761, 0.08894177546608262, 0.053832364501431584, 0.06779421062674373, 0.04968363282387145, 0.04196210575173609, 0.039317421687883325, 0.04638454149244353, 0.04046988797199447, 0.03541224061336834, 0.0853462035593111, 0.03657693749119062, 0.12001877898001112, 0.1642135321162641, 0.198763920343481, 0.1788019883679226, 0.09317471864051186, 0.21378844772698358, 0.1400705479318276, 0.15060451783938333, 0.1746312965406105, 0.18621015100507066, 0.17841028282418847, 0.08177603536751121, 0.08595321356551722, 0.17963427730137482, 0.22046534257242456, 0.1216150941036176, 0.23378291545668617, 0.10691790579585359, 0.08357334634638391, 0.10104024462634698, 0.1554742979351431, 0.08147737287799828, 0.09436112333787605, 0.15691811655415222, 0.13307841843925416, 0.22217259393073618, 0.1620342006208375, 0.15471702528884634, 0.16476914839586243, 0.10235962734441273, 0.08860886286129244, 0.09161401176243089, 0.1346642544376664, 0.1671696695848368, 0.13873036281438544, 0.10105250490596518, 0.09585688487277366, 0.12925983115565032, 0.2080635353922844, 0.16850105283083394, 0.07064612829708494, 0.10189795953920111, 0.10061368782771751, 0.1682033625547774, 0.17287932336330414, 0.11503219226142392, 0.13885168911656365, 0.21958448749501258, 0.1478290042723529, 0.21206740726483986, 0.14533859415678307, 0.3294199093943462, 0.408904934884049, 8.301066868007183, 28.98932084441185, 78.39360103011131, 106.45351454615593, 113.83049950003624, 105.42083635926247, 91.87125742435455, 105.80935791134834, 110.09987488389015, 80.81986203789711, 72.21163675189018, 58.861554712057114, 36.36290118098259, 26.63915265351534, 61.467717066407204, 86.95415407419205, 99.38825726509094, 129.99900430440903, 200.31649589538574, 149.34353828430176, 142.2054997086525, 154.56085592508316, 102.0830650627613, 95.7756695151329, 67.64915317296982, 90.01044407486916, 79.56842198967934, 67.84931123256683, 83.92206877470016, 86.78058698773384, 86.26031890511513, 91.78997978568077, 92.75132060050964, 140.95085263252258, 112.3906047642231, 138.76653224229813, 124.23517718911171, 141.09668880701065, 116.94415882229805, 133.9402288198471, 145.3002816438675, 150.8116579055786, 191.72204107046127, 168.9522948861122, 153.32017689943314, 177.62000977993011, 120.80085307359695, 118.22749435901642, 72.27327704429626, 67.43865966796875, 53.70024986565113, 60.817564353346825, 49.33282122015953, 68.22166085243225, 100.40855571627617, 78.69299456477165, 121.38648524880409, 107.642273157835, 116.89363673329353, 128.54226887226105, 125.00579863786697, 120.11004254221916, 53.27872708439827, 10.872633028775454, 0.661889452021569, 0.5197438888717443, 0.6639913329854608, 0.49242225650232285, 0.1659068459412083, 0.213006921694614, 0.18393465201370418, 0.2183517802041024, 0.16153311735251918, 0.15468411846086383, 0.12400925508700311, 0.19219641806557775, 0.08706135879037902, 0.17244409827981144, 0.12687119917245582, 0.090270004584454, 0.16168975504115224, 0.11224930174648762, 0.1838233447051607, 0.10416761040687561, 0.12402244305121712, 0.1355488647823222, 0.3189737652428448, 0.14950048411265016, 0.07826476401533, 0.09937128808815032, 0.126197729841806, 0.1471929540275596, 0.17674900009296834, 0.14141612104140222, 0.16017234505852684, 0.19211962062399834, 0.11593819130212069, 0.07863557810196653, 0.23734186979709193, 0.1004631060641259, 0.14674515696242452, 0.09222051710821688, 0.21983905899105594, 0.14689826202811673, 0.19774337823037058, 0.1956082638935186, 0.19587555580073968, 0.188694252865389, 0.09688806196209043, 0.12058435488143004, 0.12120766987209208, 0.19323420769069344, 0.18873257737141103, 0.1406543212942779, 0.20483483676798642, 0.16167133493581787, 0.24651472602272406, 0.12912140577100217, 0.06934418604942039, 0.10587344426312484, 0.11458633220172487, 0.21628118818625808, 0.09042036370374262], [0.047626199084334075, 0.016233376481977757, 0.04120223558857106, 0.07856766416807659, 0.10998737663612701, 0.023504033997596707, 0.00755662417759595, 0.07082244774210267, 0.05521898208826315, 0.02625238867040025, 0.013288998343341518, 0.007644968509339378, 0.061249889331520535, 0.026255730190314353, 0.04816497603314929, 0.03409706587262917, 0.0466548019903712, 0.02800370133627439, 0.03714194564963691, 0.04089301233761944, 0.04208526144793723, 0.023548167664557695, 0.03864464255457278, 0.05970295300357975, 0.07689242163905874, 0.024148477932612877, 0.09134596286457963, 0.03786450804909691, 0.04649362977943383, 0.08784094781731255, 0.023791302664903924, 0.03978430308052339, 0.04236878783558495, 0.06402850136510096, 0.03448937626671977, 0.048801579177961685, 0.06734924114425667, 0.029793193789373618, 0.025119941819866654, 0.034502608759794384, 0.03873271321936045, 0.01610409250133671, 0.008926209939090768, 0.03194571705535054, 0.00447169532890257, 0.03878408097079955, 0.07015194700215943, 0.0469589378189994, 0.05664203541527968, 0.09114426196902059, 0.5757277691736817, 8.85908117517829, 36.20537303388119, 68.44424530863762, 90.45053645968437, 80.28601348400116, 81.33184656500816, 72.9325720667839, 71.8844287097454, 44.7067366540432, 31.519211791455746, 32.39353537559509, 36.5982111543417, 55.65351225435734, 43.73293250799179, 83.92001688480377, 93.7378616631031, 121.23364984989166, 107.80074745416641, 64.8294384777546, 41.23852215707302, 20.53700879216194, 14.706051629036665, 6.946929255500436, 1.7209837026894093, 0.7497308822348714, 0.9344487078487873, 0.3897637885529548, 0.967630724189803, 1.1965673114173114, 0.32126136124134064, 1.017378664109856, 0.9506960422731936, 0.8902374270837754, 0.765335694886744, 0.5263710301369429, 0.680761436233297, 0.9412305126897991, 1.5723861451260746, 0.8116444037295878, 0.628964634379372, 1.0987916705198586, 0.6023131613619626, 1.232784593012184, 3.890593657270074, 4.695921968668699, 5.326301017776132, 15.430563502013683, 24.72272928804159, 40.481078401207924, 70.16324266791344, 86.24179869890213, 129.42850291728973, 127.98103898763657, 107.47997626662254, 70.62237963080406, 47.11657494306564, 27.041666954755783, 32.803525775671005, 53.44273388385773, 66.69657468795776, 87.63945490121841, 86.71113431453705, 79.08229887485504, 83.02337139844894, 100.93571662902832, 91.60670042037964, 55.60548663139343, 29.235838316380978, 11.108957547694445, 2.981538511812687, 0.17692260327748954, 0.21442463155835867, 0.03505746433802415, 0.07542101739090867, 0.07543931133113801, 0.039909547922434285, 0.05911571752221789, 0.014112381504673976, 0.09093471657251939, 0.020228578214300796, 0.046636289116577245, 0.02936564622359583, 0.024088491991278715, 0.09696073306258768, 0.020087742705072742, 0.004443307716428535, 0.0301907752873376, 0.07584159990074113, 0.043512084885151125, 0.01632139705179725, 0.030715798384335358, 0.014724585616932018, 0.05638050257402938, 0.039308345221797936, 0.12950425007147714, 0.024844762738212012, 0.029532289918279275, 0.04190762098005507, 0.02291684675583383, 0.04252625301887747, 0.020096605803701095, 0.04695199502748437, 0.017859101062640548, 0.044982643084949814, 0.0013525970734917792, 0.041824344589258544, 0.0545215042802738, 0.07656804373255, 0.019639891834231094, 0.04828495904803276, 0.0545322394464165, 0.0451311950746458, 0.024512976342521142, 0.03372407729330007, 0.04153369358391501, 0.03237724995415192, 0.0459846463490976, 0.01079085041055805, 0.04988784588931594, 0.08423622522968799, 0.0532001622923417, 0.02439665582642192, 0.06894079167977907, 0.010466050407558214, 0.07184969144873321, 0.018489601898181718, 0.04672694245527964, 0.06562018548720516, 0.1264179844292812, 0.048638128573657013, 0.024531745257263537, 0.0300987953596632, 0.030096956688794307, 0.04465003847144544, 0.07566990403574891, 0.02620032144477591, 0.03725591355760116, 0.07954209664603695, 0.058847004402196035, 0.10134684067452326, 0.020694685917987954, 0.07707045544520952, 0.030946903170843143, 0.04925379944324959, 0.026895298215094954, 0.026832954099518247, 0.048496196541236714, 0.03725259244674817, 0.016968763193290215, 0.029838496338925324, 0.052022477830178104, 0.07723379472736269, 0.08293122533359565, 0.036229285833542235, 0.03639359732915182, 0.017604750355530996, 0.056026691090664826, 0.06371521114488132, 0.017197556189785246, 0.024226282839663327, 0.022227078006835654, 0.008229052182286978, 0.048322456059395336, 0.05584597813140135, 0.08695513519342057, 0.04214688939100597, 0.05240243146545254, 0.027809549937956035, 0.028198333275213372, 0.04525338226812892, 0.03648665522632655, 0.0267141381118563, 0.04085900713107549, 0.13069716340396553, 0.00788483388532768, 0.08501838208758272, 7.404738189652562, 35.922835394740105, 76.17687597870827, 100.57032823562622, 92.2306877374649, 92.02850818634033, 90.6700810790062, 109.74909290671349, 71.84348970651627, 63.7528270483017, 61.08780585229397, 43.633902221918106, 56.50637648999691, 25.01141119748354, 28.461567163467407, 41.45299404859543, 98.01874995231628, 101.58037483692169, 64.7196015715599, 51.802453100681305, 26.30995161831379, 19.52922686934471, 8.301185611635447, 1.858781527262181, 0.47722461575176567, 0.43786139984149486, 0.35706140741240233, 0.8490578492637724, 1.0283527127467096, 0.2727757254615426, 0.9761442267335951, 0.6629376020282507, 0.8002063049934804, 0.37903028482105583, 0.37493208597879857, 0.32160726143047214, 0.5275670753326267, 0.48481770674698055, 0.38658012344967574, 0.1720974559430033, 0.5293628352228552, 0.1377591586788185, 1.218183757737279, 4.772273171693087, 5.251210397109389, 6.339506199583411, 17.197141908109188, 28.128205351531506, 46.01852506399155, 77.03251406550407, 78.95791634917259, 100.12949109077454, 87.1408000588417, 64.84586119651794, 26.7499528080225, 32.237838730216026, 32.30237826704979, 46.9478639960289, 100.06456777453423, 100.12633726000786, 120.3228311240673, 107.24913865327835, 97.21048012375832, 93.23016330599785, 120.95314130187035, 106.85704529285431, 68.88659477233887, 36.240015774965286, 16.985031589865685, 3.831955916248262, 0.09068303945241496, 0.2642534062033519, 0.0866266903176438, 0.06019176114932634, 0.06671449707937427, 0.06293306912994012, 0.031063485293998383, 0.007136285184969893, 0.07880605684476905, 0.08167229796526954, 0.04893957782769576, 0.010786184157041134, 0.0046808218758087605, 0.08880307548679411, 0.008095568573480705, 0.039496420286013745, 0.01669856021180749, 0.04892834542260971, 0.07007457068539225, 0.05560502133448608, 0.06644984721788205, 0.03390690908418037, 0.012499616677814629, 0.04840815185161773, 0.029266647434269544, 0.07083468575729057, 0.05279404424072709, 0.06742983096046373, 0.06589952245121822, 0.05611399363260716, 0.030375434616871644, 0.043906391656491905, 0.040113241484505124, 0.045946974933031015, 0.019819361696136184, 0.05159882282896433, 0.03792426949075889, 0.03273904323577881, 0.05952215469733346, 0.04860850203840528, 0.05990609366563149, 0.008941751439124346, 0.03175940459186677, 0.04829315977985971, 0.034567780458019115, 0.048314581872546114, 0.04322250257246196, 0.024807766676531173, 0.058232869778294116, 0.08293688792036846, 0.023575615996378474, 0.045667997910641134, 0.0690175594354514, 0.10838990376214497, 0.08917716244468465, 0.18861508055124432, 0.16924180526984856, 0.19175647292286158, 0.1994447220931761, 0.2734245406463742, 0.06702973914798349, 0.0975402539188508, 0.15429704391863197, 0.13217145460657775, 0.17217089887708426, 0.06376695368089713, 0.10214388501481153, 0.21611220116028562, 0.22110655816504732, 0.15328886598581448, 0.11080485230195336, 0.23097694414900616, 0.15826032031327486, 0.20415180857526138, 0.12353105965303257, 0.08867645025020465, 0.1637472555739805, 0.1624736559460871, 0.17203983559738845, 0.18314966757316142, 0.1106036412238609, 0.18577114096842706, 0.15834698831895366, 0.17837265593698248, 0.23528000543592498, 0.06502355070551857, 0.1602523188921623, 0.14769074216019362, 0.1656104766880162, 0.12815112189855427, 0.1622201976715587, 0.1439591048983857, 0.16446697554783896, 0.20355274697067216, 0.21392899565398693, 0.15800540742930025, 0.09424681033124216, 0.1435021942597814, 0.1787126634735614, 0.12699524173513055, 0.12164560379460454, 0.28833749354816973, 0.17184168216772377, 0.19485961500322446, 0.20290477783419192, 1.2454044283367693, 15.047108978033066, 54.60117392241955, 99.22127902507782, 120.4482851922512, 102.30422079563141, 98.4395469725132, 94.53214824199677, 94.80894818902016, 61.84258595108986, 40.742382779717445, 43.908479288220406, 55.852165594697, 77.9072879254818, 61.64362482726574, 122.32232183218002, 135.11538416147232, 170.47057181596756, 164.3767324090004, 97.06495553255081, 66.82199835777283, 30.457398667931557, 26.10932808369398, 11.542817316949368, 2.563061504624784, 1.8709092889912426, 1.123615619726479, 0.6130720465444028, 0.9583374322392046, 1.465152099262923, 0.6958067289087921, 1.5299256797879934, 1.1089744116179645, 1.1479235091246665, 0.9574185346718878, 0.7099795527756214, 1.1025626119226217, 1.0737930494360626, 1.4252652833238244, 0.8955429517664015, 0.9171577356755733, 1.4395222370512784, 0.9585299750324339, 2.0878119813278317, 6.902180006727576, 8.072343841195107, 10.335455853492022, 28.279773518443108, 39.893018156290054, 67.3243921995163, 110.08412852883339, 135.85740834474564, 201.23499780893326, 179.64095413684845, 151.02312415838242, 101.02532342076302, 67.57664546370506, 41.17715544998646, 48.91496904194355, 68.06976780295372, 85.8229547739029, 114.07581433653831, 109.26705837249756, 99.12981793284416, 104.03179049491882, 130.3684964776039, 125.03739014267921, 83.94500434398651, 47.1955993026495, 23.69193959981203, 6.24178446829319, 0.23969185072928667, 0.46823631681036204, 0.1515328703681007, 0.19786109769484028, 0.187994348234497, 0.12009837431833148, 0.17402953351847827, 0.1271239746711217, 0.2511325618252158, 0.09131444385275245, 0.08607781273894943, 0.12481660785852, 0.08880045570549555, 0.4521681071491912, 0.07929846440674737, 0.10616289669997059, 0.1132245060580317, 0.22750094707589597, 0.17432419583201408, 0.11312929593259469, 0.14685417845612392, 0.06097950637922622, 0.12297742490773089, 0.21078214107546955, 0.20740925800055265, 0.12085874914191663, 0.13011785777052864, 0.13463143666740507, 0.16616033390164375, 0.13580711733084172, 0.08467448569717817, 0.15842139604501426, 0.16118239320348948, 0.08388029120396823, 0.05669344769557938, 0.11543617292772979, 0.12915063154650852, 0.1266874879365787, 0.11050848304876126, 0.11937729621422477, 0.1315227136365138, 0.13302648294484243, 0.09366381622385234, 0.11743926661438309, 0.12575505359563977, 0.10610481622279622, 0.12703674263320863, 0.12956418591784313, 0.12046483199810609, 0.2229323601932265, 0.09576749318512157, 0.11178604574524797, 0.16955304716248065, 0.14270932821091264, 0.1056320607312955], [0.012595221069204854, 0.020261948884581216, 0.0712414643203374, 0.024561843056289945, 0.07759884974802844, 0.033507433254271746, 0.011250864154135343, 0.029463398204825353, 0.08149580782628618, 0.017848538445832673, 0.0862019592022989, 0.024593100461061113, 0.05377515233703889, 0.044742736426997, 0.10931798911769874, 0.021189770777709782, 0.03431713492318522, 0.06598529245820828, 0.04432561974681448, 0.015746815188322216, 0.09015169140184298, 0.014069619883230189, 0.034034365526167676, 0.01587395992828533, 0.05171165525098331, 0.047923707534209825, 0.009809570692596026, 0.04571286444843281, 0.007663206788492971, 0.026842455445148516, 0.0626859487965703, 0.1726814519497566, 0.04318669394706376, 0.041163157802657224, 0.04074218566529453, 0.008481078111799434, 0.04187341168290004, 0.019717570576176513, 0.04377932855277322, 0.02288166153448401, 0.031935219376464374, 0.01427491741196718, 0.059580086744972505, 0.09317486707004718, 0.10458209246280603, 0.051542208093451336, 0.09146046882960945, 0.2784993464592844, 0.018893855303758755, 6.047888472676277, 48.16371515393257, 58.72747890651226, 76.71216085553169, 62.40797281265259, 66.35036766529083, 74.8927652835846, 65.25928661227226, 53.08990001678467, 30.091708190739155, 52.93633125722408, 59.46584768593311, 40.00912852585316, 52.574982047080994, 56.968952268362045, 84.16180551052094, 77.45877519249916, 49.187904596328735, 16.011354736983776, 4.191024536266923, 1.6599980439059436, 0.6974371382966638, 0.25716824107803404, 0.5397092644125223, 0.29592227248940617, 0.22021097887773067, 0.18275358335813507, 0.2780559577513486, 0.19875948230037466, 0.5864040681626648, 0.5914104182738811, 0.23172982328105718, 0.5336273345164955, 0.4830563231371343, 0.4390077805146575, 0.4929443128639832, 0.43774981051683426, 0.7840037962887436, 0.7204950728919357, 0.8183411881327629, 0.6145252310670912, 0.3890030278125778, 0.5578285921365023, 0.31507796491496265, 0.27256833971478045, 0.19143398007145151, 0.10489166452316567, 0.3543287899810821, 0.8078032254707068, 0.7260494248475879, 0.3795724979136139, 0.3415128792403266, 2.4384787771850824, 6.350450562313199, 25.572515688836575, 54.37899984419346, 95.64593687653542, 89.49440136551857, 104.08586919307709, 58.48529510200024, 31.204144097864628, 34.91807051002979, 34.70314264297485, 70.28235867619514, 73.5179078578949, 91.65478304028511, 71.32382959127426, 78.32328960299492, 83.86960119009018, 92.4733579158783, 85.2698564529419, 75.02708807587624, 30.1327782869339, 2.833425309509039, 0.3980992053402588, 0.02102007500070613, 0.050190397232654504, 0.036096463663852774, 0.06680280523141846, 0.05260857040411793, 0.04069448412337806, 0.012996800887776772, 0.04962993843946606, 0.024931764710345306, 0.04330393472628202, 0.012637328673008597, 0.03695196326589212, 0.025682246705400757, 0.02536411953769857, 0.027964922264800407, 0.016619725574855693, 0.023337412567343563, 0.04440830984094646, 0.1260079033090733, 0.04599797903210856, 0.05295203263813164, 0.032409169725724496, 0.05210312330746092, 0.037610448634950444, 0.05138936649018433, 0.014091818447923288, 0.03543699494912289, 0.044840184127679095, 0.039645640208618715, 0.017736939844326116, 0.023088941525202245, 0.07670640974538401, 0.06508871869300492, 0.009537542955513345, 0.08180042234016582, 0.025380823426530696, 0.03121005203865934, 0.015178415414993651, 0.023394372401526198, 0.01123947775340639, 0.034526227609603666, 0.02942746341432212, 0.1624620784423314, 0.045912765635875985, 0.06166190003568772, 0.03944187985325698, 0.033006698795361444, 0.04438642761670053, 0.056134573387680575, 0.057898109225789085, 0.08032630183151923, 0.0052424439854803495, 0.06152832087536808, 0.018100354718626477, 0.030704270975547843, 0.05532009599846788, 0.06316095299553126, 0.043796969403047115, 0.021059056307421997, 0.02483547661540797, 0.022849233391752932, 0.01594140074303141, 0.0562779822939774, 0.03126674098894, 0.022730550990672782, 0.04634017219359521, 0.10938675652141683, 0.05399237896199338, 0.03405357230803929, 0.02898367209127173, 0.03678451990708709, 0.03613405344367493, 0.033147907233797014, 0.002221709055447718, 0.02328399092220934, 0.0051384593552938895, 0.07186103146523237, 0.05378762783948332, 0.02016656806517858, 0.03963748771639075, 0.010164464783883886, 0.09585327061358839, 0.009146819829766173, 0.052170940762152895, 0.03843743492325302, 0.0536551285040332, 0.03154538033413701, 0.016629722304060124, 0.0635286649048794, 0.06185786784044467, 0.03680566369439475, 0.05072635402029846, 0.025330199678137433, 0.018100241541105788, 0.09481415996560827, 0.015398272953461856, 0.1267000599182211, 0.009020676061481936, 0.1698218085221015, 0.23304158414248377, 0.028922224119014572, 5.16206338070333, 50.58606617152691, 69.02891993522644, 95.2537751197815, 69.78592291474342, 87.55989477038383, 105.17786979675293, 110.7007822394371, 92.5989031791687, 57.518030405044556, 47.65967980027199, 27.15645119547844, 25.460847280919552, 34.703564420342445, 41.33922055363655, 74.68231737613678, 80.5358424782753, 58.61503913998604, 22.437909990549088, 5.30209394171834, 1.730286197271198, 0.8798323385417461, 0.5987679515965283, 0.5334845453035086, 0.3916534152813256, 0.23183511919341981, 0.056065156604745425, 0.16290787170873955, 0.155552668729797, 0.5525783426128328, 0.7613005489110947, 0.4101505852304399, 0.7849146786611527, 0.3466854407452047, 0.4482615308370441, 0.10108060261700302, 0.30867287423461676, 0.7213403494097292, 0.4458480072207749, 0.33118527091573924, 0.4075825761537999, 0.10588295859633945, 0.33843661774881184, 0.16882461437489837, 0.15728706785012037, 0.23379421094432473, 0.05311879693181254, 0.1442070267512463, 0.8226352545898408, 0.8700009598396719, 0.5786051647737622, 0.25331699929665774, 2.704972014762461, 7.8735285345464945, 31.796667203307152, 62.00987957417965, 94.53999102115631, 78.47374632954597, 57.760305404663086, 36.47150695323944, 16.25397551804781, 41.8581473082304, 63.54915037751198, 110.27418673038483, 110.3842668235302, 122.2781454026699, 92.61705100536346, 89.90930870175362, 103.25476258993149, 108.93659010529518, 103.29400688409805, 91.32426917552948, 40.236660316586494, 4.06358364969492, 0.4747223312733695, 0.03775667770241853, 0.04575412785925437, 0.015633728580723982, 0.025459810203756206, 0.03027356186066754, 0.07596829193062149, 0.03552464630047325, 0.09384461081936024, 0.015114477537281346, 0.05071886946097948, 0.029582874703919515, 0.029287891411513556, 0.031061594672792125, 0.04351535033492837, 0.034649327644729055, 0.027180357137694955, 0.02908176917117089, 0.037089290271978825, 0.023726177350908983, 0.061190870037535205, 0.06308872718364, 0.0103402777131123, 0.021231956307019573, 0.018620960181578994, 0.07110587393981405, 0.017702179502521176, 0.025982643965107854, 0.04817381872271653, 0.03068489721044898, 0.07568187487777323, 0.024141557405528147, 0.032975714129861444, 0.04767588587128557, 0.05077608162537217, 0.04793046478880569, 0.015112624951143516, 0.07469277014024556, 0.030219409200071823, 0.023004351533018053, 0.04124439328734297, 0.0628335916553624, 0.01599372029886581, 0.1219866874453146, 0.045898501557530835, 0.039256450545508415, 0.03261497098719701, 0.024849772235029377, 0.008240645456680795, 0.01191409648527042, 0.03551626003172714, 0.037646620912710205, 0.03564920465578325, 0.08284156647277996, 0.12138626028900035, 0.20700285793282092, 0.11367321596480906, 0.2479743375442922, 0.09769309923285618, 0.15660435135941952, 0.09816502351895906, 0.2093602900276892, 0.12630384211661294, 0.2029455068986863, 0.10743250357336365, 0.15899100922979414, 0.1316464296542108, 0.20584632467944175, 0.17666573112364858, 0.14629587560193613, 0.15639378922060132, 0.0827533844858408, 0.13303825340699404, 0.14545209822244942, 0.0569170642120298, 0.09323132966528647, 0.06273918304941617, 0.18913357460405678, 0.21056626515928656, 0.11615999697824009, 0.10436329990625381, 0.05122118840517942, 0.16274412424536422, 0.1444683369481936, 0.26948863465804607, 0.12098667313694023, 0.10560985567281023, 0.13493347592884675, 0.06681404876871966, 0.14253738743718714, 0.17654407827649266, 0.14682582841487601, 0.1353732726420276, 0.13718013506149873, 0.06789311664761044, 0.21481424424564466, 0.14736680954229087, 0.21754255722044036, 0.23100033664377406, 0.2602506772382185, 0.37912940606474876, 0.14921123947715387, 12.650331538170576, 72.41760849952698, 89.50356647372246, 107.59778514504433, 84.35500994324684, 87.7529776096344, 97.43601322174072, 87.99944758415222, 70.0718803703785, 37.510925978422165, 74.22791495919228, 81.82030275464058, 66.58002734184265, 84.20631632208824, 90.0333720445633, 129.0907770395279, 121.2265594303608, 75.60246080160141, 25.695769675076008, 6.657729148864746, 3.322972753085196, 1.3537457585334778, 0.8872042992152274, 0.5473079660441726, 0.45874665258452296, 0.34395404043607414, 0.22319007839541882, 0.3980780392885208, 0.39724062953609973, 1.080228597857058, 1.474714286159724, 0.733040040358901, 1.2510244455188513, 0.8711197029333562, 0.9554732765536755, 0.7342488504946232, 0.7902655634097755, 1.6041409224271774, 0.9438765363302082, 1.0151509149000049, 1.0125301242806017, 0.7066642900463194, 0.736813594121486, 0.4848329653032124, 0.4056539718294516, 0.36285137641243637, 0.21673241397365928, 0.3137576545123011, 1.1592105659656227, 0.9460322675295174, 0.9087983029894531, 0.7785913429688662, 5.657088467851281, 9.947812054306269, 43.8354168087244, 89.59980770945549, 156.8373441696167, 133.3155271410942, 151.92914754152298, 88.34539622068405, 46.56840495765209, 46.972916051745415, 44.26132455468178, 86.6502995789051, 95.10112971067429, 120.24938866496086, 89.79763269424438, 97.12718099355698, 110.79315528273582, 122.19278678297997, 117.12141931056976, 109.88735988736153, 52.934454157948494, 7.821223866194487, 0.7586486474610865, 0.20323905599070713, 0.15730888699181378, 0.11040056735510007, 0.33653856022283435, 0.06723583355778828, 0.18472152150934562, 0.09113724125199951, 0.1870833768043667, 0.14655665145255625, 0.08883591552148573, 0.07748107833322138, 0.18196518503827974, 0.08150521825882606, 0.13252851669676602, 0.1109766965964809, 0.17105208156863227, 0.17954990995349362, 0.12063522168318741, 0.3019980574026704, 0.14047812059288844, 0.17921190621564165, 0.09557890603900887, 0.13381894823396578, 0.12046503237797879, 0.2526420901995152, 0.06993695424171165, 0.15729147620731965, 0.10529010876780376, 0.15104624413652346, 0.12149308502557687, 0.10521754898945801, 0.13033973023993894, 0.11802643901319243, 0.1233042222156655, 0.26384623430203646, 0.13751338905422017, 0.08427224907791242, 0.08697751836734824, 0.10410425325972028, 0.1117877897922881, 0.21831683989148587, 0.1299206691328436, 0.2760914037935436, 0.11224290443351492, 0.11550449504284188, 0.07654085886315443, 0.10127972083864734, 0.09466115137911402, 0.1346845892840065, 0.1335868489695713, 0.18967470416100696, 0.09206706323311664], [0.02078661389532499, 0.020787367175216787, 0.023139140394050628, 0.0820246251532808, 0.06422189762815833, 0.0603123007749673, 0.10549992133746855, 0.0858321544365026, 0.009022604717756622, 0.04905627683911007, 0.06296327454037964, 0.03767777998291422, 0.03943844742025249, 0.05484882109158207, 0.014636177274951478, 0.061018261330900714, 0.03697193445987068, 0.09483086570980959, 0.029737785043835174, 0.052623250085162, 0.08580344816436991, 0.04993826740246732, 0.01008548171739676, 0.01919103535328759, 0.07594978276756592, 0.039997648273129016, 0.015753218067402486, 0.04253536288160831, 0.08763907622778788, 0.02856017108570086, 0.022259591496549547, 0.04071716786711477, 0.017454459884902462, 0.04985366998880636, 0.06212316337041557, 0.022368941390595865, 0.06003019188938197, 0.014394464415090624, 0.04226068289426621, 0.03858778662106488, 0.04024152171041351, 0.03528731860569678, 0.06031779637851287, 0.07125061500119045, 0.039090877398848534, 0.09012923401314765, 0.061840820708312094, 7.253206120803952, 29.49824083596468, 58.560379073023796, 67.24723353981972, 65.23485392332077, 38.15808825194836, 87.78652220964432, 77.9933001101017, 33.92628952860832, 18.720341473817825, 27.39887248724699, 61.55425742268562, 51.402566358447075, 78.37653234601021, 78.67139652371407, 61.02413646876812, 66.777213960886, 22.574991434812546, 3.796581239439547, 0.2991681295679882, 0.14512633992126212, 0.07280270554474555, 0.07513381366152316, 0.14767434069653973, 0.039140983499237336, 0.17273948789807037, 0.2338721216074191, 0.34579554630909115, 0.31284125056117773, 0.29740232275798917, 0.1426708255894482, 0.46135571727063507, 0.2909829234704375, 0.14896434178808704, 0.34939683275297284, 0.13698431197553873, 0.14646239869762212, 0.4785289254505187, 0.22204660694114864, 0.29987652436830103, 0.4144760890631005, 0.6926624570041895, 0.20330774917965755, 0.23614941659616306, 0.3295073937624693, 0.1020532613620162, 0.07545649947132915, 0.3047906106803566, 0.3755925677251071, 0.32628047629259527, 0.4894997976953164, 0.3137719928054139, 0.442657662788406, 0.051875677308999, 0.07341659525991417, 0.32482304668519646, 0.4155329370405525, 0.0478744474821724, 2.5441420823335648, 18.314768336713314, 56.85333587229252, 90.14200821518898, 118.70859414339066, 74.23628211021423, 69.4492381811142, 38.112809881567955, 33.16813141107559, 21.553224362432957, 48.21193836629391, 78.41029733419418, 64.5083937048912, 82.11083516478539, 70.61626195907593, 78.10539409518242, 75.98418071866035, 61.60600304603577, 12.849322110414505, 0.25944357679691166, 0.14160660066409037, 0.02254082093713805, 0.039898942632135004, 0.0801824513473548, 0.03301422417280264, 0.03384801224456169, 0.036159950686851516, 0.13092053501168266, 0.04862530797254294, 0.0704231351846829, 0.04179094423307106, 0.044093950928072445, 0.13370249042054638, 0.06897480430779979, 0.012476615665946156, 0.027702561928890646, 0.059924417291767895, 0.045057017414364964, 0.02144708822015673, 0.037182815722189844, 0.033626403237576596, 0.0357055633503478, 0.06245979413506575, 0.018627350073074922, 0.01991602828638861, 0.005244358726486098, 0.031763048536959104, 0.045786693299305625, 0.05092840001452714, 0.041297801944892853, 0.06697287579299882, 0.006079953927837778, 0.043125938027515076, 0.019237794367654715, 0.08950776697020046, 0.0843314130906947, 0.02987115269206697, 0.031428681322722696, 0.02857666346244514, 0.006367591349771828, 0.05694144747394603, 0.050710305076790974, 0.008947363930928987, 0.07029486980172805, 0.017339174664812163, 0.030923629419703502, 0.017819563145167194, 0.0485642329294933, 0.018726530688581988, 0.03074273648962844, 0.030458325090876315, 0.06988608743995428, 0.008779957679507788, 0.10288541670888662, 0.07013872193056159, 0.0366781515913317, 0.06180843338370323, 0.04710184206487611, 0.025173832873406354, 0.04860845008806791, 0.009412401086592581, 0.058874582609860227, 0.05803902451589238, 0.04928158916300163, 0.055616673053009436, 0.03229655994800851, 0.028937718307133764, 0.037075612490298226, 0.021267696283757687, 0.04888239534921013, 0.05275700365018565, 0.03280166936747264, 0.007700217229285045, 0.0351831173611572, 0.022981183537922334, 0.026220146064588334, 0.028747945580107626, 0.06455983457271941, 0.017475889399065636, 0.05791834388219286, 0.024649919287185185, 0.07223550433991477, 0.03240260171878617, 0.026834831733140163, 0.05871181849215645, 0.04389184556202963, 0.005197420205149683, 0.0594420955167152, 0.015994254645192996, 0.0752736565482337, 0.033075024621211924, 0.045059395997668616, 0.029046544987068046, 0.1522681606002152, 0.05178494975552894, 0.06315250735497102, 0.012188872951810481, 0.11065866405260749, 5.303585361689329, 31.009769327938557, 68.00124228000641, 82.83002257347107, 78.29256445169449, 49.23061430454254, 107.46119767427444, 107.62119948863983, 69.13352072238922, 36.694877967238426, 33.95445741713047, 24.278067648410797, 43.838015869259834, 60.978075340390205, 63.90044912695885, 60.23363068699837, 68.57381075620651, 28.926973789930344, 4.694845201447606, 0.11401953175663948, 0.3918593761045486, 0.14624564704718068, 0.040395970063400455, 0.06470541426097043, 0.11736757514881901, 0.09044211605214514, 0.19532727194018662, 0.3497199044795707, 0.46801079297438264, 0.6295668426901102, 0.39533995965030044, 0.8259315777104348, 0.8201443694997579, 0.9007253986783326, 1.0518835438415408, 0.6849854439496994, 0.7960663083940744, 1.4067289279773831, 1.5872478601522744, 0.9418239339720458, 1.4241957594640553, 1.491335069295019, 0.7793743384536356, 0.7396494888234884, 0.8503598137758672, 0.5954223498702049, 0.2130120128276758, 0.4711142764426768, 0.13377922849031165, 0.1842797506833449, 0.3911919775418937, 0.2509181998902932, 0.2788415062241256, 0.08511104664648883, 0.10640002772561274, 0.26724740804638714, 0.6582083401735872, 0.14717684942297637, 2.920777159743011, 20.791773721575737, 65.70416674017906, 80.45778706669807, 78.88249799609184, 38.101463690400124, 32.18948632478714, 29.87281333655119, 38.25748711824417, 48.70623104274273, 84.12229523062706, 126.14144369959831, 88.71509358286858, 97.68806129693985, 89.32165503501892, 90.89942917227745, 95.08731365203857, 78.9767025411129, 18.373535983264446, 0.18033153988653794, 0.14746248722076416, 0.05653060565236956, 0.07309953492949717, 0.044081853920943104, 0.08136347547406331, 0.03930277169274632, 0.05082306328404229, 0.030387828483071644, 0.03800697813858278, 0.05366244979086332, 0.04176462767645717, 0.04005033704743255, 0.02750232491962379, 0.006416856040232233, 0.03664921525341924, 0.0074055335790035315, 0.04364052467280999, 0.028899354838358704, 0.012257684884389164, 0.047908575143083, 0.06128950146376155, 0.030856841694912873, 0.054083444192656316, 0.06558526001754217, 0.019422244040470105, 0.027300887486489955, 0.009212305085384287, 0.012829427105316427, 0.04993076428945642, 0.05622054377454333, 0.033769767615012825, 0.04985342136933468, 0.06253109968383797, 0.009234152057615574, 0.05628162994980812, 0.018830269946192857, 0.015234966140269535, 0.046152149079716764, 0.03605048761528451, 0.044431026981328614, 0.03992374520748854, 0.038182310527190566, 0.07294150942470878, 0.09009133995277807, 0.07407139957649633, 0.061356213118415326, 0.04761393880471587, 0.030906704741937574, 0.034557590770418756, 0.003460464849922573, 0.07257072502397932, 0.1454998183180578, 0.06097791076172143, 0.15691050211898983, 0.19623947533546016, 0.1487118928343989, 0.16518414253368974, 0.25336054852232337, 0.09120675080339424, 0.09250233284546994, 0.13394431181950495, 0.21005957125453278, 0.11712319334037602, 0.1845240211696364, 0.1631597417872399, 0.10532434404012747, 0.08685937587870285, 0.09610480672563426, 0.15955927170580253, 0.08595936596975662, 0.1506568244076334, 0.12545412755571306, 0.15351032285252586, 0.16877215937711298, 0.18536723451688886, 0.1649228620226495, 0.11019091063644737, 0.0955095820245333, 0.12947193696163595, 0.13092065375531092, 0.14867977268295363, 0.12260442148544826, 0.09425097377970815, 0.2280658550444059, 0.12141003870056011, 0.12939738080604002, 0.08779996642260812, 0.21012081328080967, 0.11844935928820632, 0.20070653641596437, 0.05317820956406649, 0.08187439962057397, 0.18384915660135448, 0.20639269379898906, 0.18731911259237677, 0.20882448909105733, 0.16785928804893047, 0.2353679499356076, 11.857239045202732, 52.39359878003597, 90.75803875923157, 95.72862803936005, 91.66870549321175, 61.62933759391308, 116.31793722510338, 99.52672183513641, 43.54551896452904, 25.684603974223137, 40.72306081652641, 90.54093360900879, 74.96227875351906, 114.52186480164528, 126.0706914961338, 89.77402076125145, 110.35841301083565, 36.97635166347027, 6.392914233729243, 0.6072657799813896, 0.5993120942730457, 0.12179282362922095, 0.14434720360441133, 0.21527921460801736, 0.20043400494614616, 0.6798437261022627, 0.43206350470427424, 0.6070905143860728, 0.702705318108201, 0.4903276782715693, 0.4315686406334862, 0.6443278631195426, 0.6646905548404902, 0.5018554581329226, 0.6371737376321107, 0.28588454704731703, 0.3833091224078089, 0.4920377646340057, 0.5182439787313342, 0.4954509611707181, 0.5791880178730935, 0.8148093963973224, 0.3526041575241834, 0.46416771481744945, 0.5915980925783515, 0.6487661437131464, 0.23335830308496952, 0.5912472645286471, 0.9526212327182293, 0.7273976993747056, 1.4390162704512477, 0.6434511195402592, 0.8029118191916496, 0.2661736391019076, 0.17621066101128235, 0.22424729744670913, 0.9074345917906612, 0.47461279027629644, 3.9967024885118008, 34.38596986234188, 95.60951203107834, 137.35419362783432, 173.70196402072906, 107.78617143630981, 98.28739553689957, 50.06599947810173, 47.37367294728756, 32.51730613410473, 65.27299627661705, 101.9148100912571, 82.71101295948029, 101.94232821464539, 91.58830940723419, 99.24293026328087, 108.61471697688103, 101.11745327711105, 27.525620386004448, 0.23892599885584787, 0.439192337798886, 0.12491583300288767, 0.19470717787044123, 0.21666763932444155, 0.25354094977956265, 0.14825619931798428, 0.0805853187921457, 0.2172275897464715, 0.21559517655987293, 0.24739142507314682, 0.18376756488578394, 0.14323871699161828, 0.18690261931624264, 0.15515000908635557, 0.05959525253274478, 0.11357541574398056, 0.19288858951767907, 0.22844887746032327, 0.05782587228168268, 0.15483872266486287, 0.17888850794406608, 0.13811535987770185, 0.11942828918108717, 0.15361193771241233, 0.10064816058729775, 0.21856412349734455, 0.16620541195152327, 0.1559485896723345, 0.15415768342791125, 0.18171564530348405, 0.1346844111685641, 0.14293421379989013, 0.17878825863590464, 0.11641542194411159, 0.12443472835002467, 0.17040426086168736, 0.07251326052937657, 0.19670210051117465, 0.1115349326573778, 0.136419270420447, 0.10607533069560304, 0.1237208564998582, 0.15585522749461234, 0.18815224757418036, 0.08458219221211039, 0.1360139242024161, 0.1349119981750846, 0.11214402809855528, 0.10761242985608988, 0.14058141270652413, 0.19336148601723835], [0.03821513942966703, 0.007484142324756249, 0.038874723177286796, 0.022043305543775205, 0.029333175407373346, 0.037774092197651044, 0.02714459304115735, 0.019187140933354385, 0.032479766523465514, 0.03940244954719674, 0.07962241928908043, 0.03680581212393008, 0.0592665441945428, 0.0885446225584019, 0.02095682360959472, 0.055446476326324046, 0.04670546841225587, 0.023840583126002457, 0.020669029872806277, 0.0354038395016687, 0.02062364754237933, 0.013636702879011864, 0.022466626578534488, 0.031762451108079404, 0.044670514325844124, 0.06226518074981868, 0.02717374089115765, 0.05028377425333019, 0.04681362159317359, 0.038412213034462184, 0.02077909593936056, 0.07740940171061084, 0.019386808344279416, 0.08411202681600116, 0.03836788084299769, 0.04699432342022192, 0.044206608945387416, 0.030070534376136493, 0.02091251553792972, 0.03762598549656104, 0.026010602523456328, 0.05882521494640969, 0.022330817264446523, 0.023821005270292517, 0.0056636257795616984, 0.42531607614364475, 12.991358488798141, 42.82030887901783, 63.70771586894989, 74.60616946220398, 77.98585250973701, 66.46294802427292, 65.03932401537895, 39.35978136956692, 34.64320465922356, 46.664045825600624, 64.65084046125412, 69.59597870707512, 79.24231588840485, 56.36311657726765, 45.94414785504341, 38.249070569872856, 17.89575532078743, 2.37039094325155, 0.10474639653693885, 0.07253450821735896, 0.12438927180483006, 0.08924402995035052, 0.07336359849432483, 0.05304693477228284, 0.2257193176774308, 0.1033673896745313, 0.062247647510957904, 0.04000259839813225, 0.061500623924075626, 0.10590460704406723, 0.06322196495602839, 0.11177887659869157, 0.25311261182650924, 0.16624087176751345, 0.14068862335989252, 0.0896317650040146, 0.27838285895995796, 0.32189373043365777, 0.3827829397050664, 0.4346822766819969, 0.5947797687258571, 0.4850926873041317, 0.38846467388793826, 0.3481079003540799, 0.12069787379004993, 0.25096433178987354, 0.14912782207829878, 0.25467797939199954, 0.10486277271411382, 0.09310949128121138, 0.06080643383029383, 0.15937823220156133, 0.2741178550058976, 0.15915457857772708, 0.185155707586091, 0.15276430116500705, 0.17230530182132497, 0.10028238568338566, 0.03406456351513043, 0.058186437308904715, 0.14940183784347028, 0.8811560331378132, 13.847571294754744, 36.3510762155056, 81.93197876214981, 107.74429008364677, 106.73898562788963, 76.09580352902412, 54.41992364823818, 24.293529018759727, 19.869031235575676, 39.352789744734764, 48.81084702908993, 61.46544858813286, 76.39352515339851, 73.26720491051674, 73.14447149634361, 73.58221560716629, 26.012228094041348, 1.6688153520226479, 0.39311764296144247, 0.24861050653271377, 0.08820435527013615, 0.05017370262066834, 0.028685185861831997, 0.10602657901472412, 0.03580173084628768, 0.024622020100650843, 0.03295320850156713, 0.04470429688808508, 0.007541929653598345, 0.044378894817782566, 0.023269674893526826, 0.029721355749643408, 0.020480756284086965, 0.022680292750010267, 0.06210020132130012, 0.0961094006197527, 0.02511680624593282, 0.027767735482484568, 0.023626749971299432, 0.02133336522092577, 0.07061005249852315, 0.07437796593876556, 0.016151287527463865, 0.05962653776805382, 0.03918286289263051, 0.028353572015475947, 0.013202309928601608, 0.03648287398391403, 0.07218761355034076, 0.07636152629856952, 0.058566606167005375, 0.03761616688279901, 0.02481103212630842, 0.03544073166267481, 0.009918767518684035, 0.025430992609472014, 0.006061194753783639, 0.047172884151223116, 0.04260083514964208, 0.06369457943947054, 0.021978148688504007, 0.04189569466689136, 0.019572258061089087, 0.030752516140637454, 0.047605864237993956, 0.018538264521339443, 0.025742883881321177, 0.07984072944964282, 0.021258846172713675, 0.01762794618116459, 0.038594057768932544, 0.05314132482453715, 0.026767138588184025, 0.0772633841552306, 0.062458161410177127, 0.018274943104188424, 0.1141801176709123, 0.041999283639597706, 0.060166383409523405, 0.01655654654314276, 0.036103350794292055, 0.04242955859808717, 0.05844154686201364, 0.04592624303768389, 0.026174622726102825, 0.052611160499509424, 0.04981268117262516, 0.03567631902114954, 0.0314302732294891, 0.03333012675284408, 0.08426898362813517, 0.07567961132735945, 0.05097749308333732, 0.0579464193288004, 0.048400581945315935, 0.016114599457068834, 0.04814927960978821, 0.052712586111738347, 0.0037725386437159614, 0.0026972670821123756, 0.01794307321688393, 0.0773919463972561, 0.04308260031393729, 0.019559869760996662, 0.01618771955691045, 0.04978082077286672, 0.02024464942223858, 0.0718836669693701, 0.0644832820398733, 0.029492006142390892, 0.03426609000598546, 0.024284879109472968, 0.1110140563105233, 0.2151301913545467, 13.529401067644358, 59.01877127587795, 77.84076869487762, 93.05743217468262, 92.72331610321999, 103.8769944012165, 89.32274177670479, 75.83313122391701, 51.20599910616875, 23.821856528520584, 41.36800400912762, 35.30458576977253, 54.92343083024025, 48.67905110120773, 50.96451826393604, 46.91339984536171, 24.2662787809968, 3.884948347695172, 0.16871289146365598, 0.058663311720010825, 0.10197782947216183, 0.16235284914728254, 0.29848081176169217, 0.5442073324229568, 0.9163786587305367, 1.0437040077522397, 0.286315378616564, 0.22645497898338363, 0.5348366789985448, 0.5224790296051651, 0.28803383640479296, 0.6949448876548558, 0.9504811163060367, 1.6683722008019686, 1.7016414343379438, 1.0934220836497843, 2.361933309584856, 1.575374803505838, 2.0655845990404487, 3.1637261481955647, 3.592862533405423, 2.3917541094124317, 1.2236786191351712, 2.0873909164220095, 1.7592662922106683, 1.1178271053358912, 0.8517304121050984, 2.183196838013828, 0.4936147097032517, 0.41436758707277477, 0.31025183794554323, 0.7646134961396456, 0.9848980663809925, 0.780814461177215, 0.7579067966435105, 0.6376249634195119, 0.1707773978705518, 0.2652143983868882, 0.11620871155173518, 0.02509929341613315, 0.16699793661246076, 0.5556057707872242, 16.34350061416626, 40.67497439682484, 81.22399315237999, 94.5641653239727, 67.96764448285103, 51.134076565504074, 29.27507121115923, 23.177310414612293, 33.51297810673714, 68.17950591444969, 89.12683188915253, 92.21637770533562, 99.59200233221054, 87.0320574939251, 90.70741027593613, 88.91030430793762, 38.28415408730507, 1.8800073070451617, 0.17378796444972977, 0.44697271718177944, 0.10830249360878952, 0.09185277551296167, 0.03079314872593386, 0.027020995767088607, 0.061661135623580776, 0.042766757105709985, 0.060874644623254426, 0.0947991240536794, 0.02079857174976496, 0.007130660169423209, 0.051389923100941814, 0.04664753265387844, 0.06953912597964518, 0.05703942209947854, 0.01537959031338687, 0.03913856780854985, 0.05368058416934218, 0.036018638347741216, 0.019626076755230315, 0.014774090577702736, 0.020429609321581665, 0.021256653126329184, 0.04385631895274855, 0.024669784725119825, 0.031082701352715958, 0.01186285211588256, 0.01726130853057839, 0.05147886949998792, 0.03101818645518506, 0.015596513585478533, 0.03833947885141242, 0.03010329277458368, 0.04955419113684911, 0.06241834518732503, 0.003891006517733331, 0.017071461588784587, 0.02290713946422329, 0.02043691391008906, 0.050768374421750195, 0.05198478414968122, 0.043001056837965734, 0.020294588539400138, 0.05538496341614518, 0.030789181946602184, 0.03679794535855763, 0.026438046188559383, 0.009619719112379244, 0.01697375970252324, 0.129593871824909, 0.1195127381652128, 0.14795503579080105, 0.12527342943940312, 0.2476612848113291, 0.10520240917685442, 0.13372349319979548, 0.1287570854765363, 0.1429302358883433, 0.24170221004169434, 0.16482431965414435, 0.07977924251463264, 0.19355071883182973, 0.21927345340372995, 0.10683555708965287, 0.13010530063183978, 0.1022641574672889, 0.18634342588484287, 0.19460335141047835, 0.1230590240447782, 0.1346783700864762, 0.09491804579738528, 0.20912489562761039, 0.17618381010834128, 0.17782266513677314, 0.2348119328962639, 0.13437227869872004, 0.09822325984714553, 0.13532878831028938, 0.14845790021354333, 0.14983606844907627, 0.17298674181802198, 0.11121816176455468, 0.2097253079409711, 0.24954905617050827, 0.11532061311299913, 0.12454291863832623, 0.2459395764162764, 0.08362651380593888, 0.20199949125526473, 0.18924851843621582, 0.21125788742210716, 0.1276675978442654, 0.11367326049366966, 0.3552944725379348, 1.0919633181765676, 30.281821489334106, 83.09319645166397, 94.06830713152885, 103.3762800693512, 103.34690764546394, 95.7724016904831, 90.96707314252853, 52.93356500566006, 48.32097351551056, 71.08090862631798, 98.27500820159912, 105.83000600337982, 116.71307802200317, 89.8776564002037, 68.2969956099987, 61.168460324406624, 29.992791898548603, 4.811972491443157, 0.6558906426653266, 0.2905652130721137, 0.21256501728203148, 0.48802699078805745, 0.4100108833517879, 0.5247582541778684, 0.603553201071918, 0.7186604244634509, 0.15657870273571461, 0.1878878500428982, 0.31565461365971714, 0.16956783074419945, 0.18903412681538612, 0.3399758617160842, 0.5684000405017287, 0.7060889771673828, 0.7661903521511704, 0.5616161576472223, 1.340353258419782, 0.8634460740722716, 0.5096365499775857, 0.8291358151473105, 1.6652738233096898, 0.8443431335035712, 0.6801364291459322, 1.0323321679607034, 0.5765284574590623, 0.5715914536267519, 0.2812636981252581, 0.9874853712972254, 0.3049893875140697, 0.2710525179281831, 0.13632887683343142, 0.39693290542345494, 0.4063961491920054, 0.3811872628284618, 0.4171459504868835, 0.5238534277305007, 0.5870659451466054, 1.0039999382570386, 0.19360459875315428, 0.0759728264529258, 0.3216428845189512, 1.888135545887053, 23.579995706677437, 54.409911185503006, 126.27338021993637, 157.6685419678688, 149.05584812164307, 108.57377797365189, 77.2613225877285, 32.59889155626297, 23.259241618216038, 53.4888482093811, 70.65187364816666, 83.47925573587418, 103.04075807332993, 93.77216622233391, 97.63088956475258, 109.10343915224075, 51.834173798561096, 4.306774400174618, 0.42384513944853097, 0.7285333040636033, 0.1813606166979298, 0.24535608506994322, 0.1310463884146884, 0.19482111238176003, 0.14095751830609515, 0.1754140545381233, 0.15354935982031748, 0.22144484391901642, 0.1418482736335136, 0.25245064578484744, 0.09936696878867224, 0.14345315314130858, 0.14515538758132607, 0.14533546229358763, 0.17322428844636306, 0.1682405441533774, 0.10697863574023359, 0.12023099610814825, 0.09531925083138049, 0.12620216788491234, 0.07685615288210101, 0.11911623092601076, 0.09287047520047054, 0.2044607201241888, 0.16096150036901236, 0.12813439388992265, 0.10291559243341908, 0.1212281160405837, 0.11901464575203136, 0.14067222189623863, 0.16626628290396184, 0.107293966866564, 0.19924199703382328, 0.1507165376096964, 0.08655447934870608, 0.12285076998523436, 0.1305435091489926, 0.14847090264083818, 0.10797074617585167, 0.11271306240814738, 0.09555086769978516, 0.12462485174182802, 0.16355414874851704, 0.1390247727977112, 0.10865890260902233, 0.12683654087595642, 0.08259890644694678, 0.09442965325433761], [0.04370486887637526, 0.02797760742396349, 0.012306294629524928, 0.021088866524223704, 0.03683417700813152, 0.02543463655456435, 0.043490187817951664, 0.005810297816424281, 0.02768929047306301, 0.06177532246510964, 0.03308515493699815, 0.04496816007304005, 0.013456932447297731, 0.06626736794714816, 0.036722101576742716, 0.010343990306864725, 0.029083060508128256, 0.04035815021779854, 0.00665154354464903, 0.004968523307979922, 0.04750686915940605, 0.06067901449569035, 0.02237651129689766, 0.035671149962581694, 0.057093509822152555, 0.03568061234545894, 0.018573269771877676, 0.03206174442311749, 0.044041080327588134, 0.0815854815300554, 0.026862693812290672, 0.0796174468996469, 0.03017027902387781, 0.07857466262066737, 0.06425022540497594, 0.014884195607010042, 0.0672846520319581, 0.04860336637648288, 0.03332586682518013, 0.03169316420098767, 0.06992536189500242, 0.10205113881966099, 0.04590815689880401, 0.04318746206990909, 5.763058606535196, 25.781124494969845, 64.89921033382416, 53.2725790143013, 57.865685150027275, 59.73249837756157, 56.570471450686455, 35.059707909822464, 21.953094005584717, 28.56297992169857, 53.40878650546074, 77.12678700685501, 65.55827736854553, 72.7963949739933, 49.21586349606514, 35.45374296605587, 11.675690487027168, 1.8341385433450341, 0.45430391910485923, 0.2527859481051564, 0.07817225530743599, 0.05909226936637424, 0.179035616456531, 0.031012663021101616, 0.07299881806829944, 0.19994369766209275, 0.6617203610949218, 0.3185846720589325, 0.35205772903282195, 0.5686197755858302, 0.5857270513661206, 0.5891786317806691, 1.630076786968857, 0.4301381955156103, 1.8695354252122343, 0.8439235528931022, 2.2227586526423693, 2.291807122528553, 4.921449841931462, 3.254474066197872, 8.084165956825018, 6.610790267586708, 4.343201145529747, 7.799070104956627, 4.935723775997758, 3.11847603879869, 1.9945868337526917, 1.6948497737757862, 1.2643353687599301, 1.4328236714936793, 0.45066080521792173, 0.29984452296048403, 0.4467680922243744, 0.2782578219193965, 0.46613874030299485, 0.28193822130560875, 0.17261740460526198, 0.030396023648791015, 0.03403318922210019, 0.13710399070987478, 0.017357388824166264, 0.15372082561952993, 0.16001567768398672, 0.1038656676246319, 0.2766077307751402, 0.4099716088967398, 6.391628477722406, 26.37380339205265, 53.6198727786541, 67.92550474405289, 88.22064891457558, 103.25037762522697, 86.21580049395561, 40.05434989929199, 24.785049743950367, 26.417438350617886, 47.22114913165569, 57.34632521867752, 59.90418076515198, 70.91038137674332, 75.89107811450958, 60.58364510536194, 24.263531528413296, 5.431941049173474, 0.48612649901770055, 0.060830542497569695, 0.0730834154819604, 0.06547752986080013, 0.05667176214046776, 0.06972258488531224, 0.010118016543856356, 0.06167760016978718, 0.04645049244572874, 0.016234348695434164, 0.02875673075322993, 0.022515693672175985, 0.02434828635159647, 0.024212187599914614, 0.02935902255558176, 0.015361762070824625, 0.06895969418110326, 0.0008660695823436981, 0.04429829015862197, 0.05079464644950349, 0.06062175038096029, 0.08779247073107399, 0.03349525461089797, 0.04611157586623449, 0.08736929812585004, 0.04821227310458198, 0.04835009734961204, 0.00920856837183237, 0.03862063407723326, 0.02312613054527901, 0.06288906719419174, 0.04702184596681036, 0.035279206931591034, 0.024240329839813057, 0.01573987610754557, 0.03827520144113805, 0.025705826592457015, 0.03986045114288572, 0.03176249192620162, 0.04329875453549903, 0.05604600919468794, 0.04746209167933557, 0.048929109834716655, 0.006408783792721806, 0.014682240525871748, 0.07368724909611046, 0.05574881986831315, 0.0723184912931174, 0.014664941063529113, 0.042813876061700284, 0.03767383546801284, 0.02769915918179322, 0.07907181250629947, 0.02365774391364539, 0.06804154618293978, 0.024106314667733386, 0.02642838157044025, 0.04769145241880324, 0.011280816306680208, 0.042984083920600824, 0.02429622098134132, 0.09037804644322023, 0.05172636090719607, 0.05067578407761175, 0.009473683930991683, 0.021799701135023497, 0.03899814604665153, 0.05670941871358082, 0.014540783467964502, 0.009712300179671729, 0.031265323486877605, 0.08525850396836177, 0.08743278885958716, 0.020599416420736816, 0.011699192782543832, 0.011565807508304715, 0.05796906596515328, 0.06770449239411391, 0.02682104634004645, 0.023555004700028803, 0.033830935426522046, 0.03255772542615887, 0.023489536142733414, 0.02705369293835247, 0.03365529133589007, 0.04610819167282898, 0.09735886560520157, 0.07751078650471754, 0.009725438976602163, 0.08323658199515194, 0.15241121698636562, 0.0637509158696048, 4.774317936971784, 33.35185155272484, 77.21041291952133, 62.05538973212242, 75.36621987819672, 94.7959452867508, 105.3827016055584, 67.97438532114029, 50.52989758551121, 21.341381929814816, 21.09376821666956, 48.86807195842266, 49.14233364164829, 64.54364061355591, 55.73239602148533, 44.80850659310818, 17.187572121620178, 2.563902447000146, 0.179401584318839, 0.40320797183085233, 0.10220782845863141, 0.2929323969874531, 0.5372306099161506, 0.3450356761459261, 0.6299742520786822, 1.2139164679683745, 1.800872515887022, 1.9997462444007397, 2.8108079731464386, 3.804461066611111, 3.9636228885501623, 4.276449177414179, 6.415324006229639, 5.146190207451582, 5.205079447478056, 4.299650257453322, 5.344256004318595, 6.7148595582693815, 6.70544033870101, 10.739472024142742, 13.973388243466616, 13.584047835320234, 13.715431485325098, 9.92917975410819, 8.460596557706594, 7.193863755092025, 6.862764721736312, 9.342742022126913, 7.227114820852876, 3.7898736493662, 3.782006883993745, 3.3293704222887754, 3.8225597329437733, 2.0325137861073017, 2.526350012049079, 1.5724581037648022, 1.531794467009604, 1.0246728477068245, 0.39889532199595124, 0.9021922980900854, 0.4632751486497, 0.3698381030699238, 0.12216093629831448, 0.024037756920733955, 0.3441989194834605, 0.29138350510038435, 6.6669598035514355, 30.32391183078289, 60.74008271098137, 68.77993449568748, 67.17452064156532, 55.976973697543144, 34.602573439478874, 32.289356365799904, 31.442830190062523, 50.5483303964138, 80.82008242607117, 93.26435387134552, 81.27910539507866, 83.53481635451317, 91.1093071103096, 76.2196084856987, 30.82298845052719, 5.782187730073929, 0.39775766897946596, 0.31150191149208695, 0.1106014073593542, 0.055747955266269855, 0.019528107695805375, 0.04428662359714508, 0.06985352199990302, 0.023587024661537725, 0.060339070041663945, 0.0363185513560893, 0.021454463312693406, 0.032410086278105155, 0.0612678678589873, 0.037432644894579425, 0.006672760619039764, 0.032618496188661084, 0.03773101794649847, 0.030278819976956584, 0.024845935331541114, 0.033848309103632346, 0.00491142339342332, 0.04329207520640921, 0.04262034250132274, 0.02198860554926796, 0.0965272965549957, 0.024072251944744494, 0.04218008565658238, 0.01413929085174459, 0.07046057653496973, 0.043453098987811245, 0.01850283439125633, 0.03225253945856821, 0.0042728721109597245, 0.04567718198813964, 0.09625618258723989, 0.0068745964927074965, 0.02977077165269293, 0.037937405504635535, 0.0884752614365425, 0.03632570937043056, 0.02717307666898705, 0.05105745578475762, 0.01218268065713346, 0.06237544905161485, 0.05693011487892363, 0.03770893905311823, 0.05501819403434638, 0.0073004065052373335, 0.08245487784733996, 0.17102903046179563, 0.09614865281037055, 0.10359652776969597, 0.1489570687408559, 0.15735224325908348, 0.12399810060742311, 0.10659476727596484, 0.14064630609937012, 0.13311735150637105, 0.14579595008399338, 0.13363626116188243, 0.11276769189862534, 0.17780194437364116, 0.22098055633250624, 0.1448656085995026, 0.10413566837087274, 0.10776245500892401, 0.13630328758154064, 0.09476656603510492, 0.09702271723654121, 0.09074149842490442, 0.14216658077202737, 0.2923508203821257, 0.14586483623133972, 0.20710414624772966, 0.1016639158478938, 0.12778111675288528, 0.1376695666112937, 0.26943116274196655, 0.16975851816823706, 0.20837684045545757, 0.1041470974450931, 0.18011851381743327, 0.11664235586067662, 0.14897309913067147, 0.09015001414809376, 0.17887753900140524, 0.1743042765883729, 0.15299880498787388, 0.18472420808393508, 0.14008509402628988, 0.266142706386745, 0.16053619037847966, 10.006849486380816, 59.61090490221977, 103.52653160691261, 79.73634257912636, 84.36957076191902, 83.44046741724014, 81.0504412651062, 57.03385278582573, 36.07119843363762, 45.003580525517464, 78.97583618760109, 113.6270660161972, 97.15887129306793, 107.83957377076149, 72.81666308641434, 58.822762593626976, 24.125013761222363, 5.10939915664494, 1.2366975517943501, 0.5087003752123564, 0.23485332989366725, 0.23215039836941287, 0.286108081927523, 0.19280579552287236, 0.22078658861573786, 0.5706637690309435, 1.4298471249639988, 1.1296086106449366, 1.8505576997995377, 2.7543190168216825, 3.5678757866844535, 3.5013477690517902, 4.689732575789094, 3.76844541169703, 5.0998469442129135, 4.5989003498107195, 6.153602125123143, 8.361064698547125, 9.941247906535864, 12.283812705427408, 22.306104563176632, 15.224726647138596, 12.720397878438234, 16.585910506546497, 11.949374601244926, 8.38446194306016, 6.892458703368902, 5.982979405671358, 4.919302007183433, 3.1609069369733334, 2.090661353431642, 1.7411444708704948, 2.200350067578256, 0.9662668942473829, 1.0266496916301548, 0.7337064889725298, 0.7345242763403803, 0.27002327784430236, 0.17558461491717026, 0.3034457500325516, 0.2106237519183196, 0.39765721186995506, 0.3388674493180588, 0.20459221384953707, 0.4437806212808937, 0.6435496173799038, 11.104248650372028, 40.02685837447643, 78.8309195637703, 100.1166021823883, 126.68062716722488, 138.92671644687653, 120.31215369701385, 53.328192830085754, 33.43584984540939, 37.71785147488117, 60.77288255095482, 80.03051519393921, 85.12679412961006, 91.13457575440407, 105.76015055179596, 96.08143910765648, 45.44383630156517, 12.78020191937685, 0.5951309530064464, 0.533457649871707, 0.14310498198028654, 0.13471026759361848, 0.18492709641577676, 0.2063332180841826, 0.17877540463814512, 0.09904776365146972, 0.22164636669913307, 0.08887438103556633, 0.14541114651365206, 0.2456469921162352, 0.18380640889517963, 0.09756406201631762, 0.15071846719365567, 0.11766098323278129, 0.16817263764096424, 0.13497426436515525, 0.0790112755203154, 0.21075206925161183, 0.12257370399311185, 0.13172776903957129, 0.10545617173193023, 0.20209720241837204, 0.24539700709283352, 0.16189075831789523, 0.20110863202717155, 0.09838815763941966, 0.12010492748231627, 0.09421494993148372, 0.11033428614609875, 0.13260176667245105, 0.11351872308296151, 0.1887394199729897, 0.17742295924108475, 0.09069993073353544, 0.1062577505945228, 0.16944047820288688, 0.15362350037321448, 0.13215739832958207, 0.2270185510860756, 0.1618017748114653, 0.11910566274309531, 0.15486621181480587, 0.1636959137977101, 0.10287608791259117, 0.15120352007215843, 0.1520260126562789], [0.04589991905959323, 0.0693298848636914, 0.026352884742664173, 0.05500731414940674, 0.043597795520327054, 0.05159207670658361, 0.1157727740064729, 0.012157489381934283, 0.03624593220592942, 0.027140364654769655, 0.025291348247264978, 0.052209910936653614, 0.04366992856375873, 0.03450464595516678, 0.028178211796330288, 0.03495089193165768, 0.03641392846475355, 0.017212471502716653, 0.026621978213370312, 0.015324067462643143, 0.06025936709193047, 0.06044629553798586, 0.020652895582315978, 0.034934360592160374, 0.058332811095169745, 0.0034601236939124647, 0.05908583494601771, 0.05594317721261177, 0.05071945946838241, 0.13229718926595524, 0.05166478491446469, 0.04723275691503659, 0.04515986795013305, 0.031167367415037006, 0.05319926429365296, 0.02996939634613227, 0.07628827632288449, 0.018786076907417737, 0.11547972957487218, 0.022451462646131404, 0.024646553647471592, 0.011193488717253786, 0.575277196476236, 12.979961950331926, 47.33268454670906, 66.99949443340302, 72.37793862819672, 85.78860461711884, 75.36347642540932, 38.66351053118706, 23.609064146876335, 34.56862226128578, 35.55978387594223, 57.75845490396023, 76.11716598272324, 54.01958853006363, 63.09569410979748, 29.090914092957973, 8.58090665191412, 0.5839383567217737, 0.7443249004427344, 0.12364891270408407, 0.02643310905114049, 0.07608201864059083, 0.10751948328106664, 0.04404719191370532, 0.1625983219128102, 0.7363085180986673, 0.9512622118927538, 1.7622874863445759, 1.5702848578803241, 1.774835481774062, 4.06038754619658, 4.821654371917248, 3.8086653035134077, 5.312559530138969, 3.942414801567793, 2.5096252094954252, 3.058703108690679, 7.259248746559024, 8.322756104171276, 3.0315640149638057, 4.094442268833518, 4.399924976751208, 11.927580870687962, 21.268612034618855, 13.043818473815918, 10.010886769741774, 2.638838463462889, 5.5932666175067425, 9.573014415800571, 4.330544024705887, 6.848091334104538, 6.450349576771259, 2.3847313737496734, 2.3367131128907204, 3.5474575823172927, 3.4683596016839147, 4.411749467253685, 3.436343944631517, 1.8785385671071708, 1.538847244810313, 0.5071995151229203, 0.4484958713874221, 0.24081225623376667, 0.11646247410681099, 0.030868185422150418, 0.09951168758561835, 0.26845731656067073, 0.1281797984847799, 0.03693921687954571, 0.5718281690496951, 5.515125235542655, 32.51802809536457, 48.68386924266815, 77.6398278772831, 87.51147776842117, 75.48562467098236, 62.10171304643154, 40.230554044246674, 17.96590145677328, 23.881112448871136, 54.63715419173241, 61.715532168745995, 59.94106538593769, 65.08726984262466, 79.7093640267849, 69.88993093371391, 34.45403181016445, 6.233315672725439, 0.5573030328378081, 0.025977660443459172, 0.08303993512527086, 0.052968114978284575, 0.03554772709321696, 0.04094435782462824, 0.02622675117891049, 0.06141855723399203, 0.028056573792127892, 0.06352672047796659, 0.015283344891940942, 0.033200020843651146, 0.046534258653991856, 0.08794128618319519, 0.04346434994658921, 0.04044757901283447, 0.051460913236951455, 0.03359311420354061, 0.03800712656811811, 0.0587728044774849, 0.03654820524388924, 0.009534422224533046, 0.015254571826517349, 0.008101895382424118, 0.009718002656882163, 0.03881472053762991, 0.03734502322913613, 0.046396215475397184, 0.03231972237699665, 0.01635117943806108, 0.031529806365142576, 0.10239177718176506, 0.0182869881609804, 0.04792681342223659, 0.0448816367861582, 0.06967537687160075, 0.03162205532134976, 0.023117363925848622, 0.05577384879870806, 0.03872023029543925, 0.14751448208699003, 0.010295675565430429, 0.03639256574388128, 0.06155817747639958, 0.0018304417267245299, 0.015488664685108233, 0.008893218691810034, 0.037443695473484695, 0.026165841263718903, 0.06556477674166672, 0.013354643160710111, 0.05436729341454338, 0.06880932764033787, 0.016469752372358926, 0.06516363107948564, 0.018296908820047975, 0.0437577765842434, 0.10575285268714651, 0.015344861512858188, 0.012972246931894915, 0.03131007128104102, 0.1036908918467816, 0.03877418072079308, 0.0211887484692852, 0.05381025963288266, 0.0667977066768799, 0.028565683387569152, 0.05744610047258902, 0.013505429014912806, 0.06967084234929644, 0.006773002969566733, 0.028314974770182744, 0.05091255887236912, 0.041502738604322076, 0.02943974224763224, 0.014723765543749323, 0.06703470411594026, 0.05042379525548313, 0.022195521887624636, 0.04510339422267862, 0.03572832130885217, 0.006560717656611814, 0.09595628813258372, 0.016940305540629197, 0.10677214799216017, 0.11349123393301852, 0.04607311035215389, 0.03372814797330648, 0.29194842791184783, 15.922691244632006, 64.70632508397102, 94.26867797970772, 105.6278644502163, 125.222949385643, 109.88083183765411, 63.147709518671036, 40.9638424962759, 22.100660987198353, 21.256699673831463, 41.83012381196022, 67.61259913444519, 54.54192370176315, 58.935430347919464, 35.74035778641701, 11.816415935754776, 0.5631652870215476, 0.8411381242331117, 0.2584285562625155, 0.06507161218905821, 0.085086221806705, 0.23672363109653816, 0.7969605666585267, 0.8418996271211654, 2.1916114864870906, 1.998047735542059, 3.3568113623186946, 4.087197007611394, 4.789710436016321, 4.249349981546402, 5.249127158895135, 5.999671434983611, 5.69532866589725, 6.879716562107205, 5.4597394075244665, 6.032822756096721, 9.559086263179779, 9.121665135025978, 8.07852515950799, 13.988682422786951, 8.147805891931057, 14.865728560835123, 17.190750651061535, 16.171846725046635, 12.816455774009228, 9.190663732588291, 13.003801871091127, 13.90032671391964, 8.127212896943092, 13.581616915762424, 14.921838250011206, 9.53004252165556, 6.919385958462954, 5.435613552108407, 4.808790637180209, 7.000102177262306, 3.9943651389330626, 4.397675497457385, 3.2115727057680488, 1.4340924471616745, 1.124474136158824, 0.9233196987770498, 0.7275615655817091, 0.3629998356336728, 0.49791281344369054, 0.054906541627133265, 0.05354780281777494, 0.016057786197052337, 0.2945859613828361, 5.5106433760374784, 37.752129435539246, 48.72458405792713, 76.65517911314964, 70.26690870523453, 42.064179852604866, 39.38642553985119, 15.564342923462391, 23.108049631118774, 43.079344779253006, 83.79734426736832, 92.97539457678795, 81.75407230854034, 81.77582994103432, 95.03583401441574, 85.4762613773346, 39.7504536062479, 6.7613220401108265, 0.2827564539620653, 0.025374995711899828, 0.10809147875988856, 0.012686782611126546, 0.043298669188516214, 0.057394543473492377, 0.034497606684453785, 0.08650204661535099, 0.03041933636268368, 0.016464841210108716, 0.031060639157658443, 0.00875712828928954, 0.029616187857754994, 0.05791934207081795, 0.03941304741601925, 0.04771799533045851, 0.045198021762189455, 0.04782843061548192, 0.050417123347870074, 0.013723718766414095, 0.010437028722662944, 0.047919358548824675, 0.011124422599095851, 0.02070433198241517, 0.046827588812448084, 0.09665300894994289, 0.02328118003788404, 0.044034289676346816, 0.036429376268642955, 0.06463220139266923, 0.061981880717212334, 0.10191493987804279, 0.06151015681098215, 0.06760905962437391, 0.04626608730177395, 0.0329494532343233, 0.008812185442366172, 0.019244080358475912, 0.012389532985253027, 0.027253230473434087, 0.04101558544789441, 0.02303710065461928, 0.0824671529699117, 0.010513017223274801, 0.02722718294535298, 0.07787011214531958, 0.09326096362201497, 0.16571979504078627, 0.11909798893611878, 0.20299230673117563, 0.17737140966346487, 0.12564966862555593, 0.2374436627724208, 0.09918688665493391, 0.1381138013675809, 0.13368795916903764, 0.15866626024944708, 0.1996851185685955, 0.14247866871301085, 0.09560972001054324, 0.1404168488807045, 0.16602889954810962, 0.15662861958844587, 0.15799846092704684, 0.16587220248766243, 0.13174633757444099, 0.1960669260006398, 0.10418629768537357, 0.0786625848559197, 0.1505746686598286, 0.20255826908396557, 0.07924596488010138, 0.16467802750412375, 0.15315504191676155, 0.11394913904950954, 0.15583728236379102, 0.15127378661418334, 0.1320683109224774, 0.12235406538820826, 0.12668512790696695, 0.17678728007012978, 0.20826428633881733, 0.21067157591460273, 0.11438621950219385, 0.2594305149978027, 0.24886163446353748, 0.16480616672197357, 0.22412858350435272, 1.2639591889455914, 32.275285720825195, 94.40342634916306, 104.4071951508522, 103.47577393054962, 119.07649040222168, 103.63538816571236, 57.54912793636322, 39.68345560133457, 51.2223344296217, 51.44028313457966, 82.84750923514366, 103.44701707363129, 73.39965060353279, 105.05423203110695, 49.11134630441666, 17.290711887180805, 1.4771310752257705, 1.5676783164963126, 0.4482501611346379, 0.24534762458642945, 0.17619794060010463, 0.341582017717883, 0.5799295124597847, 0.5468153581023216, 2.0756374346092343, 4.55490393564105, 7.719488125294447, 9.827591255307198, 8.83443284779787, 12.558587361127138, 14.908041190356016, 11.922891922295094, 14.03731506317854, 13.50444970652461, 8.876367397606373, 12.201242186129093, 21.44950322806835, 20.832074359059334, 15.7362618483603, 24.031873159110546, 23.038634955883026, 31.96798861026764, 47.127655148506165, 37.09954485297203, 30.47963697463274, 21.07887301594019, 25.526684448122978, 30.24525985121727, 16.04978397488594, 17.760818861424923, 24.82597164809704, 13.255525063723326, 10.796984788030386, 11.71499652788043, 8.88470035046339, 11.911617927253246, 8.164291307330132, 7.45419348590076, 6.443705158308148, 3.2004780136048794, 1.554431989789009, 0.6719271477777511, 0.29450625472236425, 0.23929744376800954, 0.4122166946763173, 0.5404643551446497, 0.2783487201668322, 0.12193539761938155, 0.8461356279440224, 10.886111855506897, 58.38543266057968, 76.10793247818947, 112.02391684055328, 119.18518736958504, 111.38845413923264, 89.63210597634315, 59.30887810885906, 28.607568629086018, 31.96895755827427, 72.34617993235588, 83.94299805164337, 83.55342015624046, 88.51441875100136, 108.98884490132332, 104.54923152923584, 59.425588846206665, 14.843708742409945, 0.8514916780404747, 0.32423692813608795, 0.28475749189965427, 0.24008858803426847, 0.2787783049279824, 0.12935620645293966, 0.10154049668926746, 0.22470921016065404, 0.09408874029759318, 0.11215055899810977, 0.11884832303621806, 0.12645040143979713, 0.12300596790737472, 0.21649485250236467, 0.11994723594398238, 0.12213374400744215, 0.11775203733122908, 0.10138411875232123, 0.09936337679391727, 0.12694473116425797, 0.10114882083144039, 0.17704902071272954, 0.13084053149214014, 0.11984657845459878, 0.17632471426622942, 0.19175034278305247, 0.1303959998767823, 0.07734841943602078, 0.11272852134425193, 0.13146717130439356, 0.2483991874032654, 0.1410812046378851, 0.17925489140907302, 0.129033446428366, 0.0984211906325072, 0.1535866898484528, 0.10800841759191826, 0.11461386588052846, 0.11563177336938679, 0.1460304984357208, 0.167732440168038, 0.196505312633235, 0.1799982858938165, 0.10234610541374423, 0.10832434985786676, 0.11978031951002777], [0.02899825900385622, 0.009810140290937852, 0.01961994290468283, 0.06115968499216251, 0.04445446400495712, 0.03075603577599395, 0.04213257707306184, 0.026367239734099712, 0.020257371688785497, 0.022875470167491585, 0.02008107450819807, 0.05118001405207906, 0.06233480162336491, 0.03317141847219318, 0.019582666682254057, 0.03293703339295462, 0.04399919351271819, 0.018023525735770818, 0.062115942273521796, 0.0504445605474757, 0.013454869276756654, 0.0689148016681429, 0.05203608139709104, 0.010670685569493799, 0.056275599999935366, 0.04178909628535621, 0.07861083489842713, 0.02044011627731379, 0.03889656458341051, 0.0424396221205825, 0.02724597041378729, 0.07908290019258857, 0.024879951670300215, 0.054877371512702666, 0.07183366105891764, 0.05913709137530532, 0.039644248681725, 0.03787355111853685, 0.0939834963355679, 0.07222760046715848, 0.08530506631359458, 1.6248318809084594, 30.397637374699116, 61.35016657412052, 61.67218029499054, 55.083542838692665, 40.47720640897751, 29.36556715518236, 25.709925815463066, 36.064575389027596, 64.36680570244789, 67.71580919623375, 75.5344520509243, 46.387401670217514, 34.37616638839245, 39.39169965684414, 7.3799145966768265, 0.22436141007347032, 0.39504327869508415, 0.15413243556395173, 0.4273009055759758, 0.11532191187143326, 0.17456546804169193, 0.21832623548107222, 0.024570758105255663, 1.1659671971574426, 1.495852789375931, 2.086650193668902, 3.8447469798848033, 4.980458775535226, 5.8449427876621485, 8.652019836008549, 5.774308377876878, 5.997098498046398, 5.75812267139554, 5.473519843071699, 9.828946832567453, 8.79071144387126, 5.083153489977121, 4.1341411136090755, 5.38538689725101, 10.21857887506485, 11.531074047088623, 13.11508459970355, 11.907103769481182, 12.580978609621525, 15.673605110496283, 8.25307734310627, 10.211368761956692, 8.422118872404099, 6.3231599517166615, 17.404086403548717, 15.714833848178387, 4.6582745388150215, 6.6044132597744465, 9.123213551938534, 8.608893100172281, 5.925591085106134, 10.023569539189339, 5.166713381186128, 6.31626189686358, 6.961127668619156, 7.267332337796688, 2.2547078132629395, 0.675111673772335, 1.06286816066131, 0.30834775418043137, 0.20103938964894041, 0.19130511354887858, 0.21215352608123794, 0.06452584420912899, 0.09222692926414311, 0.2928056678501889, 0.10651166157913394, 8.174475710839033, 30.225157029926777, 47.27686934173107, 54.30369548499584, 52.25437045097351, 114.61324989795685, 99.17800694704056, 58.23533311486244, 17.84179251641035, 19.935977943241596, 50.91525010764599, 53.092031702399254, 65.23184448480606, 66.94205671548843, 70.58741390705109, 63.9582060277462, 21.55634969472885, 1.2840533419512212, 0.27707483852282166, 0.059940321516478434, 0.11046014697058126, 0.10880494985030964, 0.03025551839527907, 0.045685980148846284, 0.035664760071085766, 0.04624059081834275, 0.05215000477619469, 0.026991274608008098, 0.031658331499784254, 0.0556118119857274, 0.08654923236463219, 0.15117525908863172, 0.05161322791536804, 0.03887970669893548, 0.034422256430843845, 0.17287884838879108, 0.043624605605145916, 0.031242910627042875, 0.04465150421310682, 0.030444166768575087, 0.009110359969781712, 0.031212282192427665, 0.03152927201881539, 0.044267212724662386, 0.04751774533360731, 0.0561819966242183, 0.05849357883562334, 0.04563790382235311, 0.016066265234258026, 0.019663273196783848, 0.11968302394961938, 0.010738595792645356, 0.05748773866798729, 0.006399787571353954, 0.02902373507822631, 0.04477729453356005, 0.01204347972816322, 0.029890272271586582, 0.05995689738483634, 0.03244529005314689, 0.06731867208145559, 0.03318218332424294, 0.03948393736209255, 0.09872253227513283, 0.03369427635334432, 0.036713908266392536, 0.01898745867947582, 0.04998834752768744, 0.029140966580598615, 0.07341844320762902, 0.01983267953619361, 0.08742984995478764, 0.08689483569469303, 0.042724436134449206, 0.04815900916582905, 0.008426856802543625, 0.01384165623676381, 0.041263065722887404, 0.035537355579435825, 0.026150914818572346, 0.05711741068807896, 0.09424632051377557, 0.06322295201243833, 0.09842321669566445, 0.061322508481680416, 0.06725881787133403, 0.07693372215726413, 0.050285533143323846, 0.027361923566786572, 0.023298431260627694, 0.01646469463594258, 0.07847217202652246, 0.014926010990166105, 0.0416487376060104, 0.062426404911093414, 0.059707995897042565, 0.02553706963226432, 0.026505837668082677, 0.043709778183256276, 0.07660250907065347, 0.02744460438407259, 0.05666342411132064, 0.11213091434910893, 1.937762307934463, 37.277698293328285, 84.32154893875122, 83.95856201648712, 76.19210556149483, 49.60116662085056, 58.114203214645386, 59.95545141398907, 20.708294101059437, 28.83488193154335, 44.03030075132847, 47.46860325336456, 41.183394715189934, 46.43962226808071, 48.16229023039341, 11.973918434232473, 0.1785775480675511, 0.42620175518095493, 0.0668246614804957, 0.429828007472679, 0.18866845581214875, 0.6287536269519478, 1.119599116500467, 1.2462435895577073, 2.325987475924194, 2.027503279969096, 2.817924991250038, 2.2535275015980005, 1.057701031677425, 0.4818543407600373, 2.6369141042232513, 2.1866323286667466, 2.5353108812123537, 3.410168099217117, 0.6582900357898325, 2.602052637375891, 5.668344413861632, 3.759843623265624, 6.8822296522557735, 13.42564383521676, 11.571146696805954, 20.72342298924923, 17.92540892958641, 14.369207303971052, 13.278331439942122, 11.816866211593151, 9.387084692716599, 8.893609922379255, 6.2263397220522165, 8.5948889516294, 14.451663829386234, 18.3833147585392, 9.75900873541832, 6.00565136410296, 4.1207007598131895, 1.4377774181775749, 5.007422128692269, 5.1298468094319105, 4.494505701586604, 2.8999381279572845, 4.733695741742849, 3.9609635062515736, 3.2460152450948954, 3.7431860296055675, 2.6944140437990427, 0.6231416249647737, 0.22487070149509236, 0.5007836781442165, 0.2912616147659719, 0.052228869099053554, 0.2851388370618224, 0.1593858763226308, 0.24429907382000238, 10.611383747309446, 35.683733224868774, 53.76572795212269, 50.29689408838749, 38.767963126301765, 69.17076632380486, 42.58340299129486, 32.39076532423496, 31.845787167549133, 45.908950343728065, 81.19017496705055, 77.91534349322319, 79.8076343536377, 80.8186537027359, 89.3394684791565, 78.08328688144684, 26.721961610019207, 0.9149689937476069, 0.18951158010168, 0.12113130287616514, 0.0842035336245317, 0.09432256876607426, 0.09349953441414982, 0.025032648554770276, 0.06734052833053283, 0.03751108990400098, 0.04578440006298479, 0.05960481510555837, 0.055215779721038416, 0.04046012501930818, 0.02579518117272528, 0.07872275818954222, 0.05335713765816763, 0.028664437268162146, 0.021312217722879723, 0.037761483108624816, 0.055414823727915064, 0.02873181500035571, 0.03509423404466361, 0.01734459790895926, 0.03694793711474631, 0.031471265756408684, 0.041578708551242016, 0.031768466214998625, 0.05270824454782996, 0.03499159873172175, 0.028989280872337986, 0.05829058289236855, 0.05126998832565732, 0.012667944120039465, 0.022690582627546974, 0.027194289104954805, 0.03742143846466206, 0.045664799254154786, 0.026152990976697765, 0.11561946113943122, 0.015611213675583713, 0.05872886933502741, 0.06839222580310889, 0.04365647713711951, 0.00852162256705924, 0.08955617726314813, 0.12983634631382301, 0.20353072002762929, 0.06479404895799235, 0.18109780736267567, 0.13534153840737417, 0.22967352502746508, 0.15767752658575773, 0.16974380880128592, 0.10906260868068784, 0.2453850585152395, 0.1283776105265133, 0.14187574794050306, 0.16855459136422724, 0.07469533797120675, 0.1272424214403145, 0.12863908399594948, 0.17566674097906798, 0.07389600781607442, 0.17567367263836786, 0.17059295932995155, 0.15766296564834192, 0.14810854161623865, 0.1809936692006886, 0.12494137772591785, 0.4317412938689813, 0.10733711533248425, 0.1466953885392286, 0.13354632770642638, 0.12860037357313558, 0.17045036307536066, 0.06987592001678422, 0.21472382097272202, 0.1819901805720292, 0.17317679099505767, 0.14995994773926213, 0.1882290153298527, 0.12682321190368384, 0.2132133871782571, 0.21104505431139842, 0.39716798812150955, 0.20910981518682092, 5.385405421257019, 68.93500417470932, 110.14810189604759, 93.72298926115036, 86.81609228253365, 67.00858354568481, 43.56971986591816, 41.24482221901417, 59.28779684007168, 105.63228741288185, 103.3540740609169, 109.09264013171196, 73.14272359013557, 55.74086956679821, 67.6773552596569, 13.376689162105322, 0.8626807120162994, 1.000525380950421, 0.2329268481116742, 0.6483527971431613, 0.36174412176478654, 0.42213834822177887, 0.617533897748217, 0.647457588929683, 3.6450555827468634, 7.181852124631405, 8.536485135555267, 8.700946010649204, 11.12816171720624, 11.438706703484058, 18.697396405041218, 15.7846038043499, 17.919334955513477, 20.055371336638927, 17.885845452547073, 27.092135846614838, 24.159597605466843, 16.684950292110443, 17.28811852633953, 16.221671551465988, 23.528673760592937, 23.76264240592718, 29.914552196860313, 25.417048931121826, 31.8466592207551, 41.20236709713936, 24.702983647584915, 28.13440091907978, 24.20254100114107, 22.18144655227661, 43.705478981137276, 35.21845579147339, 21.48195158690214, 25.571580938994884, 26.538993827998638, 25.21785791963339, 23.795993216335773, 29.286626391112804, 23.67507990449667, 19.646433480083942, 31.343752406537533, 25.128131434321404, 18.228539563715458, 13.015752229839563, 6.188986776396632, 1.6512722871266305, 0.6845555920153856, 0.32005596498493105, 0.3544750821311027, 0.1935420505469665, 0.2770930953556672, 0.6400736351497471, 0.5378564482089132, 15.677949227392673, 51.588828563690186, 71.12977400422096, 82.05619409680367, 79.20081451535225, 144.67968374490738, 114.48583513498306, 82.85087585449219, 26.436036452651024, 30.869007781147957, 71.70796617865562, 75.23574247956276, 87.0213420689106, 89.57868844270706, 98.18587258458138, 101.25072732567787, 45.66071346402168, 3.23221652302891, 0.41902892757207155, 0.3217123495414853, 0.23896147351479158, 0.18946374126244336, 0.1805780516588129, 0.1273561778361909, 0.1515241723973304, 0.11163150091306306, 0.19316315447213128, 0.19571076933061704, 0.10139178513782099, 0.18665690906345844, 0.1955568479024805, 0.251365655567497, 0.19211993232602254, 0.11273349373368546, 0.14532857516314834, 0.21980238205287606, 0.11860408223583363, 0.08867812008247711, 0.14163214538712054, 0.18521034449804574, 0.11390146348276176, 0.14187503547873348, 0.13706746220123023, 0.14048055483726785, 0.11666317310300656, 0.19106203049886972, 0.1375998492585495, 0.1897403397015296, 0.20378066052217036, 0.11762381647713482, 0.2292320955893956, 0.09375118926982395, 0.08984574844362214, 0.1369126353529282, 0.18272196786710992, 0.2913460711715743, 0.057969225526903756, 0.10888694232562557, 0.15753138286527246, 0.11658170755254105, 0.17024055792717263, 0.17892441304866225], [0.07556776225101203, 0.014023053827258991, 0.052573889843188226, 0.0595634440833237, 0.0744702891097404, 0.07405543597997166, 0.03880064199620392, 0.006307918501988752, 0.08116987140965648, 0.03401996043976396, 0.07579544573673047, 0.061238263588165864, 0.024614594913145993, 0.018706581759033725, 0.06644752429565415, 0.04027026137919165, 0.007468902322216309, 0.03917526701116003, 0.0199241306836484, 0.04050541087053716, 0.01984873404580867, 0.05648808801197447, 0.07663847354706377, 0.03872536224662326, 0.0455656668782467, 0.02737264017923735, 0.045572579983854666, 0.045460909022949636, 0.0782794808037579, 0.03884894467773847, 0.05216131881752517, 0.07306246465304866, 0.007039395022729877, 0.06689438625471666, 0.06853405764559284, 0.0199033041644725, 0.04065582936163992, 0.06272044382058084, 0.1933414480299689, 1.0851112171076238, 9.558275956660509, 39.97402220964432, 64.02192860841751, 50.4080381244421, 78.85265439748764, 73.79539176821709, 129.21790301799774, 118.24330911040306, 36.392163410782814, 54.29158553481102, 52.66581617295742, 34.256848990917206, 41.50583401322365, 36.44475258886814, 15.174796376377344, 1.2568590324372053, 0.26801947911735624, 0.05489782510267105, 0.15988157159881666, 0.1203826317214407, 0.24023749254411086, 0.061491269152611494, 0.5716470256447792, 0.5500605620909482, 0.6482990062795579, 0.676691320259124, 2.4988895980641246, 2.34699749853462, 2.4248987808823586, 4.6794436778873205, 11.004360560327768, 14.98038550838828, 21.65095891803503, 18.665899895131588, 13.934488780796528, 5.407956261187792, 4.456596560776234, 3.6655977554619312, 6.756882928311825, 5.1806011609733105, 8.412379994988441, 5.5022975988686085, 17.476482018828392, 5.228303326293826, 8.148998077958822, 9.251943044364452, 9.731027986854315, 6.997977141290903, 3.204315332695842, 8.28948698937893, 8.482035007327795, 4.654219206422567, 13.235316798090935, 15.003748554736376, 7.214094344526529, 4.701639711856842, 5.059617077931762, 6.088033793494105, 11.067468523979187, 6.4695285726338625, 8.907834459096193, 9.90289656445384, 8.392267674207687, 13.635710813105106, 13.769376240670681, 12.501354832202196, 2.1445555239915848, 1.5995767735876143, 0.5141572386492044, 0.3965432778932154, 0.39345861529000103, 0.504663388710469, 0.05764868823462166, 0.17314109369181097, 0.19889440474798903, 0.5105688655748963, 15.710023306310177, 44.74668011069298, 63.476034700870514, 50.379828438162804, 111.39860719442368, 129.432515501976, 71.52543157339096, 36.94082736968994, 28.915868885815144, 29.537616223096848, 51.498815193772316, 58.529988303780556, 57.23167397081852, 65.26477351784706, 74.42321687936783, 48.522024527192116, 8.280762657523155, 0.06558654393302277, 0.0795504087000154, 0.014201711037458153, 0.07174966478487477, 0.06205380595929455, 0.029173682305554394, 0.1023768525919877, 0.03656019835034385, 0.027345549933670554, 0.06047248221875634, 0.013179267170926323, 0.0323260640288936, 0.09653534885728732, 0.0524000046425499, 0.01376873837216408, 0.09109576261835173, 0.021403878527053166, 0.08302545582409948, 0.03247309090511408, 0.024616446571599226, 0.13152489555068314, 0.04530840138613712, 0.0020015572090414935, 0.06371893672621809, 0.03595852438593283, 0.05316869523085188, 0.06566820986336097, 0.03087751607381506, 0.019128537242067978, 0.07224531553220004, 0.03596026843297295, 0.050615540239959955, 0.04218965936161112, 0.06506430945592001, 0.028540142375277355, 0.013016443681408418, 0.016238873940892518, 0.014274295863287989, 0.07440602654241957, 0.07033932444755919, 0.02376296375587117, 0.03466545822448097, 0.06934209319297224, 0.04792237166839186, 0.0052813450474786805, 0.057007750947377644, 0.029874872707296163, 0.02213146712165326, 0.06745265200152062, 0.007976200613484252, 0.052964133355999365, 0.0327479415864218, 0.03251227630244102, 0.06988721550442278, 0.02955756375740748, 0.06145138242573012, 0.0373467338795308, 0.06771404383471236, 0.0027620032324193744, 0.05509696558874566, 0.04174157656962052, 0.03068524045374943, 0.060681207542074844, 0.08825021257507615, 0.09929417152306996, 0.05949835031060502, 0.052890849983668886, 0.03901703741576057, 0.02408313739579171, 0.05918825503613334, 0.015136729907681001, 0.0817639086744748, 0.03668761026347056, 0.005294032989695552, 0.04049120245326776, 0.060355226596584544, 0.020401711990416516, 0.11830224335426465, 0.02913315547630191, 0.014049338842596626, 0.027156771684531122, 0.1516484227613546, 1.6924639767967165, 14.629956912249327, 59.24688063561916, 86.76250755786896, 77.71919801831245, 109.48097929358482, 91.44141688942909, 110.55238500237465, 91.43776908516884, 27.370598204433918, 35.16441509127617, 45.13856068253517, 39.97660607099533, 49.164699241518974, 48.63055430352688, 20.42772475630045, 1.4291683863848448, 0.7092214340809733, 0.05816543081891723, 0.12088335875887424, 0.39407222298905253, 1.1477472935803235, 1.2601855164393783, 1.9810159807093441, 2.699991906993091, 0.9790656762197614, 0.8355083700735122, 0.46377407968975604, 0.5600400140974671, 2.4374901177361608, 7.617095019668341, 14.640378803014755, 24.19427264481783, 30.76937522739172, 27.914012745022774, 19.168160744011402, 8.35822245106101, 3.0808017728850245, 2.4916875595226884, 1.6963134077377617, 0.45743420894723386, 3.137739817611873, 7.360905641689897, 8.73788857832551, 12.574683297425508, 8.87685377150774, 3.2080350955948234, 2.4710240308195353, 3.6491645872592926, 3.98236395791173, 2.2480101976543665, 1.6474639414809644, 1.4173041167668998, 3.3667561411857605, 2.8734134137630463, 3.2656103186309338, 4.795991024002433, 4.484892692416906, 11.503951102495193, 14.65098973363638, 15.663619246333838, 14.993212670087814, 15.840451307594776, 15.447026118636131, 21.11177735030651, 24.280015043914318, 20.033665001392365, 5.981259047985077, 0.4032088624080643, 0.6798345828428864, 0.5469163495581597, 1.1076270276680589, 0.9614794480148703, 0.23678763391217217, 0.0884676247369498, 0.4235724447062239, 0.6362300226464868, 19.406444057822227, 53.31164091825485, 62.43208631873131, 56.344208791852, 107.80466124415398, 88.34009170532227, 35.73884166777134, 30.742316879332066, 44.203962832689285, 57.388639748096466, 79.75549355149269, 89.94112819433212, 72.99839973449707, 83.21817174553871, 86.19592756032944, 60.15137270092964, 8.064957987517118, 0.07873898153775372, 0.0651627553452272, 0.06894236503285356, 0.033337581626255997, 0.052998502214904875, 0.015277087659342214, 0.0018188207377534127, 0.023819704656489193, 0.00955382660322357, 0.030793566184001975, 0.06704113853629678, 0.03150943070068024, 0.05399322501034476, 0.014983927267167019, 0.006827288289059652, 0.036392665933817625, 0.041972451290348545, 0.025999653989856597, 0.0220146901847329, 0.0032757950839368277, 0.01010424321066239, 0.04974172072252259, 0.030919475248083472, 0.0293193974357564, 0.010413897834951058, 0.05759056693932507, 0.07969853395479731, 0.026592039976094384, 0.03728537310962565, 0.029274989174155053, 0.03947359182348009, 0.01940305210155202, 0.03888587023539003, 0.014901218619343126, 0.03742871522263158, 0.032853267184691504, 0.041154953360091895, 0.10237738693831488, 0.02410123466688674, 0.014603532054024981, 0.05815812437504064, 0.07441309920977801, 0.09225839632563293, 0.2361556951655075, 0.09093475367990322, 0.15384424477815628, 0.16790264431620017, 0.18012099259067327, 0.22670497884973884, 0.17146300873719156, 0.17665179359028116, 0.14435023156693205, 0.1497294960427098, 0.14442593062995002, 0.1319006597623229, 0.1479889519396238, 0.11324219143716618, 0.14262338750995696, 0.13074752554530278, 0.1498872766387649, 0.12254883462446742, 0.08504109922796488, 0.15844909299630672, 0.17772568127838895, 0.21157128154300153, 0.17098842014092952, 0.13337207143194973, 0.15271187585312873, 0.1752507226774469, 0.15793583850609139, 0.13981087045976892, 0.15590315539157018, 0.11607913998886943, 0.20904866221826524, 0.14012350759003311, 0.1948634147993289, 0.1179580129974056, 0.25303397385869175, 0.11889298548339866, 0.3279862878844142, 0.2463398315012455, 0.4503151128301397, 3.7576340418308973, 29.274083264172077, 92.36975267529488, 106.66691109538078, 76.94094657897949, 116.89774051308632, 105.47539383172989, 154.85438257455826, 145.0555595755577, 61.051487401127815, 83.42630177736282, 82.78473660349846, 56.07184320688248, 68.10848012566566, 61.65359169244766, 28.20655334740877, 2.012061383575201, 0.9266579977702349, 0.11150217425893061, 0.3352751873899251, 0.3631015692371875, 0.7290589227341115, 0.9451491117943078, 1.3977475161664188, 3.543275906704366, 7.124830009415746, 7.082951031625271, 8.122758585959673, 11.762414183467627, 7.773954402655363, 11.819629613310099, 15.1535127684474, 21.853892728686333, 28.674538135528564, 25.120235458016396, 19.4285873696208, 15.474846325814724, 20.22364530712366, 19.134266562759876, 20.40620271116495, 19.000528939068317, 20.370857007801533, 16.09281286597252, 33.4175880253315, 22.277828380465508, 26.350330151617527, 29.640433005988598, 28.784183152019978, 25.776997916400433, 19.54590417444706, 24.262906461954117, 31.890062391757965, 18.32491759210825, 36.23538762331009, 34.05468463897705, 28.40512689203024, 24.49336599558592, 20.80440804362297, 17.971960231661797, 22.271642312407494, 18.390950448811054, 19.001171104609966, 19.09221611917019, 13.248485941439867, 16.59349299967289, 21.122369281947613, 21.505605317652225, 7.819397589191794, 5.4495512042194605, 0.744358564261347, 0.8556896809022874, 0.9596966905519366, 0.6771196878980845, 0.27535421366337687, 0.4148488846840337, 0.5410836625378579, 1.5105802053585649, 27.72220093756914, 72.50756487250328, 97.28919669985771, 64.27477464079857, 127.94887751340866, 150.78071236610413, 97.54116117954254, 55.05860857665539, 39.29637797176838, 41.381542682647705, 72.98251658678055, 83.2958547770977, 81.14501059055328, 88.00958544015884, 102.60565102100372, 84.72463130950928, 16.556754671037197, 0.2537728857714683, 0.16013954213121906, 0.1662718935403973, 0.15175241249380633, 0.18496962147764862, 0.14246100559830666, 0.13714011845877394, 0.1151962588483002, 0.1554112450685352, 0.17380135279381648, 0.27200867130886763, 0.17480561218690127, 0.1860682523692958, 0.150673775060568, 0.10941057204036042, 0.19403499987674877, 0.11999194292002358, 0.10744792540208437, 0.1615954132284969, 0.09729554556543007, 0.16502505575772375, 0.16760075348429382, 0.16179709928110242, 0.17834421683801338, 0.1642681987141259, 0.13968184066470712, 0.1846365159144625, 0.138523526256904, 0.13391615473665297, 0.17426252336008474, 0.050246640894329175, 0.11001241669873707, 0.11438971501775086, 0.20826728461543098, 0.14418798324186355, 0.09392924534040503, 0.09642764838645235, 0.2396424682228826, 0.17424318299163133, 0.13916612224420533, 0.14781720412429422, 0.20730739081045613, 0.16587117832386866], [0.04658072823076509, 0.04040948086185381, 0.04596823004249018, 0.05126175790792331, 0.03400000037800055, 0.03855948481941596, 0.021949201218376402, 0.023184272249636706, 0.023060389248712454, 0.01236335001522093, 0.09730784295243211, 0.08641137843369506, 0.038273565005511045, 0.030044110208109487, 0.046408828275161795, 0.0061565282612718875, 0.04130394692765549, 0.03943718947994057, 0.05351530417101458, 0.08820120856398717, 0.05493125143402722, 0.06946186840650626, 0.03500273836834822, 0.04077825404237956, 0.06337944869301282, 0.0497388189251069, 0.029309248566278256, 0.07520268496591598, 0.008845220290822908, 0.041034443420358, 0.06561104222782888, 0.0591866705508437, 0.04517832516285125, 0.08186897452105768, 0.06141879472124856, 0.032486468116985634, 0.0625930170645006, 0.6097214575856924, 11.307753380388021, 40.74272096157074, 74.69418033957481, 70.35153776407242, 70.36323353648186, 63.31843055784702, 33.89656372368336, 22.327989488840103, 44.30740088224411, 94.41394418478012, 74.64903116226196, 41.1329448223114, 36.17403231561184, 32.23590463399887, 20.56091520935297, 3.077043299563229, 0.7155827677343041, 0.20555672381306067, 0.03090557667746907, 0.1699578738771379, 0.11461462287115864, 0.17635480093304068, 0.2628377149812877, 0.29899746528826654, 1.1783713940531015, 1.849990461487323, 3.74879642855376, 2.510570646263659, 2.112451996654272, 20.06309252232313, 60.4224843531847, 89.26196023821831, 120.68972423672676, 126.6917833685875, 131.66293501853943, 132.8986895084381, 127.61077165603638, 103.95517140626907, 65.68376183509827, 30.730723701417446, 5.059742946177721, 0.8857622765935957, 8.550749570131302, 6.165529685094953, 11.630475763231516, 18.614720441401005, 14.663326721638441, 11.599918752908707, 4.556109420955181, 6.986449034884572, 9.50912369415164, 4.1102836187928915, 1.4065243327058852, 8.012566398829222, 9.164257999509573, 3.6392414197325706, 4.730758024379611, 27.27588638663292, 70.04848882555962, 93.33656519651413, 116.07530504465103, 120.01884743571281, 118.9664863049984, 113.26549261808395, 122.35419452190399, 136.95754051208496, 134.3580999970436, 125.77958151698112, 107.585838586092, 52.48680777847767, 5.570340547710657, 3.7118994584307075, 6.045867456123233, 10.576187185943127, 0.8593079179991037, 0.03472693031653762, 0.06080656741687562, 0.044263758027227595, 0.16949415032286197, 2.732001864351332, 22.303121723234653, 38.44992399215698, 31.964226812124252, 61.12103886902332, 100.92370927333832, 102.3218822479248, 46.963131576776505, 37.05503784120083, 30.62996830791235, 24.17528886348009, 39.73922900855541, 60.79789660871029, 62.59553074836731, 63.76102700829506, 66.93425953388214, 15.66158065572381, 0.9382116340566427, 0.03508990732370876, 0.035513703332981095, 0.01926055603689747, 0.010915221373579698, 0.036066892789676785, 0.016591804123891052, 0.019709347579919267, 0.045427961376844905, 0.07057877839542925, 0.020079664427612443, 0.03344276250572875, 0.030894223673385568, 0.02130957567715086, 0.050678485495154746, 0.00969834780335077, 0.017143002769444138, 0.02281388675328344, 0.06231905324966647, 0.019444929639576003, 0.0057921026746043935, 0.022376529850589577, 0.028260009457881097, 0.07187291324953549, 0.013898628130846191, 0.06869032426038757, 0.016415562604379375, 0.01558139603730524, 0.019765463221119717, 0.04220726310450118, 0.05832911148900166, 0.05135314968356397, 0.06443085672799498, 0.05901607306441292, 0.028608872671611607, 0.05508455687959213, 0.04177507711574435, 0.017421335978724528, 0.04664251573558431, 0.009758600917848526, 0.08216099478886463, 0.06844059898867272, 0.05680304435372818, 0.062066411337582394, 0.0657749010133557, 0.06012841513438616, 0.08555647626053542, 0.055038180071278475, 0.01424701358700986, 0.020566580096783582, 0.01080414969692356, 0.05951781313342508, 0.06734794238582253, 0.06517194313346408, 0.043980606424156576, 0.01261621178855421, 0.022012083391018678, 0.010527256254135864, 0.07102411895175464, 0.057488057791488245, 0.07978349502081983, 0.046723918203497306, 0.07292609501746483, 0.07573359514935873, 0.05435920771560632, 0.02886743506678613, 0.020174744677206036, 0.10048594194813631, 0.04953489900799468, 0.04090954738785513, 0.03929960272216704, 0.02074703515972942, 0.06857057131128386, 0.05559110235481057, 0.025739241791598033, 0.027895030507352203, 0.00827931320600328, 0.0744880190177355, 0.12546710029710084, 0.05182976805372164, 17.453930228948593, 57.59870767593384, 101.96589455008507, 95.40816843509674, 105.20124614238739, 101.5637469291687, 76.97550192475319, 52.46617488563061, 83.98715168237686, 100.06586730480194, 49.04891185462475, 46.76184497773647, 41.36091738939285, 42.88284972310066, 27.22544029355049, 3.384371045976877, 0.7572968699969351, 0.24410143989371136, 0.031790637876838446, 0.10120060047484003, 0.6410420488100499, 0.655098978895694, 0.9666129131801426, 1.9383847620338202, 0.7054778037127107, 0.6152745627332479, 1.8564334907568991, 1.2006891402415931, 4.285969091579318, 25.724796317517757, 71.8956533074379, 105.08530676364899, 132.6110601425171, 136.83982282876968, 142.15263694524765, 142.8438350558281, 136.82871222496033, 118.59488144516945, 80.19701465964317, 40.79783320426941, 10.17205037176609, 2.323969784192741, 0.4547650006134063, 2.105487445369363, 6.781227272003889, 5.0226531364023685, 3.2720861211419106, 1.6631595930084586, 4.074420193210244, 6.078021805733442, 12.172174695879221, 4.65432845056057, 1.6533310641534626, 1.64208343019709, 1.8529269914142787, 2.3634974006563425, 7.593361018225551, 36.837609708309174, 84.56509307026863, 111.9751350581646, 129.41154062747955, 135.38492649793625, 132.27865397930145, 125.61015620827675, 130.42335033416748, 142.91378170251846, 144.63182151317596, 135.62701910734177, 125.78529641032219, 69.77468311786652, 11.990929171442986, 2.4703949270769954, 5.3966019954532385, 10.498920232057571, 2.4198809126392007, 0.05967451390461065, 0.16412006603786722, 0.04116388510738034, 0.7165328355040401, 3.005021014250815, 25.933118239045143, 48.836176469922066, 36.79126359522343, 65.26209086179733, 77.24547743797302, 62.34016165137291, 31.672328375279903, 27.837788835167885, 51.91559582948685, 48.922519236803055, 71.0091532766819, 81.62295654416084, 78.0291397869587, 78.627258092165, 80.58418348431587, 18.13869908452034, 0.5650252872146666, 0.0666862286743708, 0.014925019295333186, 0.05179559586395044, 0.04742653538414743, 0.057668318040668964, 0.03650100094091613, 0.05365440119931009, 0.03110502515482949, 0.006206156604093849, 0.08581343005062081, 0.025569434692442883, 0.018612013591337018, 0.04042275788378902, 0.01895872086606687, 0.04017895495053381, 0.007041721655696165, 0.04755813301017042, 0.006925120051164413, 0.042343061286373995, 0.022021855620550923, 0.056371570826740935, 0.028110429593652952, 0.03297876435681246, 0.04046637761348393, 0.05622795782983303, 0.04902419379504863, 0.04941526109178085, 0.03193405791535042, 0.03586744802305475, 0.060666646604659036, 0.05373650128603913, 0.061864621384302154, 0.04426363928359933, 0.019664712963276543, 0.1164359794347547, 0.020024444929731544, 0.11126228986540809, 0.055359418693115, 0.039903970682644285, 0.03708094482135493, 0.08438639139058068, 0.1305271967430599, 0.21660759957740083, 0.3260231588501483, 0.14583813375793397, 0.19641923834569752, 0.14332033839309588, 0.10403339299955405, 0.1328400702914223, 0.10261798379360698, 0.2129451304790564, 0.1180189433216583, 0.21385199041105807, 0.10646131428075023, 0.10964743589283898, 0.09400536000612192, 0.060154197344672866, 0.15437608264619485, 0.11613346519879997, 0.1363159337779507, 0.2390959655167535, 0.1835859613493085, 0.2170588105218485, 0.19409440137678757, 0.2189612021902576, 0.12614695209776983, 0.21539512323215604, 0.10147272376343608, 0.12479496683226898, 0.18126738810678944, 0.1378654787549749, 0.21300469525158405, 0.24967127304989845, 0.10514671099372208, 0.269265070091933, 0.09560403515934013, 0.22220412036404014, 0.2789901732467115, 1.4494720031507313, 32.40262068808079, 85.5051702260971, 125.72951540350914, 103.46824273467064, 102.19863206148148, 94.40940722823143, 49.25019845366478, 35.91883420944214, 56.839664205908775, 129.3297842144966, 136.07849568128586, 59.14696879684925, 62.92968861758709, 54.594113901257515, 38.108006939291954, 4.279152257367969, 1.377612752839923, 0.3691336861811578, 0.15501772868447006, 0.3761528298491612, 0.4085819225292653, 0.35410050535574555, 0.5561476573348045, 3.828533962368965, 6.431969963014126, 8.321735858917236, 13.746267780661583, 10.171193517744541, 6.69295753352344, 26.251429058611393, 72.58678302168846, 100.86592197418213, 134.40935164690018, 142.06115305423737, 148.5796120762825, 150.343097448349, 142.3673102259636, 118.19876790046692, 72.39253744482994, 35.80670602619648, 9.517007321119308, 12.32212794944644, 25.316949002444744, 21.81676112115383, 30.203220807015896, 37.936153560876846, 36.76348328590393, 26.359111480414867, 13.57095468789339, 14.049922786653042, 16.805400028824806, 7.0607825461775064, 11.206176280975342, 23.01994375884533, 29.021938294172287, 17.23659709095955, 9.770583864301443, 30.83946816623211, 74.61867839097977, 105.49946933984756, 129.1344290971756, 131.3489654660225, 127.05676138401031, 120.86148262023926, 133.69494438171387, 149.24887776374817, 145.7522749900818, 132.7377301454544, 119.1675791144371, 61.01567432284355, 10.145785231143236, 6.14361816085875, 7.893374394625425, 13.396859429776669, 1.5726710110902786, 0.13055746152531356, 0.3507451369659975, 0.17727447033394128, 0.8256267034448683, 4.920709831640124, 37.93895781040192, 67.95056819915771, 48.06913822889328, 80.5006867647171, 128.2588192820549, 136.4602991938591, 67.33818545937538, 54.03111331164837, 42.5855802744627, 35.5655899643898, 59.34648849070072, 86.99514627456665, 86.5232951939106, 85.59351548552513, 100.30612081289291, 30.449415296316147, 1.4262217632494867, 0.19979381351731718, 0.09080754214664921, 0.1468259174725972, 0.14497010299237445, 0.12241898846696131, 0.13123375101713464, 0.17877105565275997, 0.12322146532824263, 0.16072718950454146, 0.1017643506929744, 0.17109203879954293, 0.10963843364152126, 0.09833500502281822, 0.1016403229732532, 0.07757704544928856, 0.06528862359118648, 0.13267774775158614, 0.15113732049940154, 0.1218044085544534, 0.14571802457794547, 0.19151877786498517, 0.09601390847819857, 0.21437327493913472, 0.14072748221224174, 0.11941127173486166, 0.1202701592410449, 0.1089330816466827, 0.08249108723248355, 0.10718281540903263, 0.22865017759613693, 0.1274211602867581, 0.19617879734141752, 0.1533119022496976, 0.09910652690450661, 0.21740704105468467, 0.14605883363401517, 0.20120637287618592, 0.15273988450644538, 0.10923130626906641, 0.2550817374140024, 0.1581631731824018], [0.031230761669576168, 0.028121732502768282, 0.07837627912522294, 0.03769923176150769, 0.07492371907574125, 0.08798470182227902, 0.09111248320550658, 0.018452116019034293, 0.015197213087958517, 0.03957009699661285, 0.018960630040965043, 0.015788887540111318, 0.0368863240146311, 0.015750885868328623, 0.004047845050081378, 0.03731988668732811, 0.10975465396768413, 0.02401920508418698, 0.034604731990839355, 0.017498151973995846, 0.06685278887744062, 0.046093541677691974, 0.04817197077500168, 0.0272489779672469, 0.03231395217881072, 0.010875904245040147, 0.09228901733877137, 0.0068649040440504905, 0.013052677186351502, 0.034427833670633845, 0.04190730927803088, 0.11042348487535492, 0.06443792197387666, 0.10719561003497802, 0.24904801743105054, 0.7010013470426202, 5.774124087765813, 37.74716690182686, 69.5381610095501, 84.30072605609894, 59.25807863473892, 45.06794147193432, 27.231635861098766, 45.387295335531235, 33.526509180665016, 37.77752727270126, 27.03188057988882, 38.21769565343857, 34.75413590669632, 36.389150172472, 29.83594201505184, 7.45304262265563, 0.44819236267358065, 0.334365195594728, 0.13202312897192314, 0.2747416152851656, 0.14805098064243793, 0.11954083587625064, 0.4314459190936759, 0.5424305121414363, 2.4658966809511185, 3.442949652671814, 6.152617027983069, 2.866065320558846, 6.230172291398048, 36.85707986354828, 85.63015311956406, 117.14293375611305, 117.56698340177536, 119.77565288543701, 108.7922890484333, 104.51014682650566, 99.76241558790207, 98.5663765668869, 99.66260254383087, 108.36555674672127, 126.23454630374908, 133.0797877907753, 107.93247118592262, 48.159379586577415, 7.070537572726607, 3.29183841124177, 4.511767700314522, 6.093205790966749, 3.7634831154718995, 3.9381074951961637, 28.7245624512434, 62.11440056562424, 71.05831503868103, 47.131017968058586, 5.905826445668936, 0.45387311722151935, 4.04196803458035, 22.734592370688915, 71.39748483896255, 130.35104781389236, 125.33677607774734, 124.62410911917686, 113.81175130605698, 117.31608286499977, 111.19510531425476, 114.95567992329597, 111.04853197932243, 110.9477461874485, 109.92440789937973, 120.00895276665688, 123.58569324016571, 141.09240263700485, 125.6264877319336, 46.57215155661106, 0.5938259605318308, 1.7508986662141979, 0.32521798799280077, 0.30258177139330655, 0.2594388270517811, 0.09041100522154011, 0.29404918081127107, 0.15029950998723507, 0.015687242994317785, 9.129129834473133, 37.407989501953125, 38.67514170706272, 43.784514740109444, 48.29316280782223, 67.40908965468407, 75.84869518876076, 29.834365099668503, 37.99135699868202, 19.527135081589222, 36.75831936299801, 54.21557441353798, 64.15803730487823, 68.03119987249374, 61.41897328197956, 21.134874410927296, 2.0291749527677894, 0.19253837002906948, 0.07617864626809023, 0.0312722736998694, 0.015185968622972723, 0.0572987730265595, 0.04308952084102202, 0.06609005402424373, 0.09521108280750923, 0.0700814652373083, 0.04074227101227734, 0.010624687256495235, 0.036021710839122534, 0.05257233133306727, 0.05495063633134123, 0.10239112409180962, 0.017020656014210545, 0.03340620802191552, 0.03290197804744821, 0.0938806940393988, 0.05423592585430015, 0.05655923028825782, 0.015498056563956197, 0.015448501508217305, 0.05867975029104855, 0.1030472716956865, 0.08610939854406752, 0.03776588033360895, 0.07163821646827273, 0.02046686327958014, 0.043416021289885975, 0.013896814507461386, 0.06821718285209499, 0.01860544187366031, 0.016881468072824646, 0.060560782949323766, 0.035917557834181935, 0.09238914048182778, 0.07505729081458412, 0.03172264601744246, 0.02377055036049569, 0.03442630113568157, 0.016379418157157488, 0.03426657982345205, 0.03114161860139575, 0.012310956244618865, 0.05438566156954039, 0.03062339914322365, 0.01625879875064129, 0.0314792735298397, 0.038916687917662784, 0.0152775997412391, 0.06359329854603857, 0.07292878901353106, 0.04173446308413986, 0.019241536647314206, 0.017256414066650905, 0.06802966439863667, 0.06595138373086229, 0.047336687275674194, 0.02742392443906283, 0.0495700619649142, 0.01751604886521818, 0.03017645369254751, 0.07243981017381884, 0.05030251348216552, 0.061890477809356526, 0.04426997351401951, 0.027856201340910047, 0.06881975481519476, 0.020905071796732955, 0.040511381448595785, 0.1111194487020839, 0.08066480280831456, 0.07324594582314603, 0.189160039590206, 0.26291899499483407, 9.877034202218056, 53.75568129122257, 94.2186650633812, 107.35437780618668, 88.56263816356659, 81.58220753073692, 60.11818528175354, 78.21773886680603, 36.95830263197422, 23.139587938785553, 20.59619251638651, 36.70862562954426, 41.106004267930984, 45.95378413796425, 40.08494585752487, 9.796386379748583, 0.3678157803369686, 0.3774404263822362, 0.12420610233675689, 0.14980414125602692, 0.3918162127956748, 0.44848954828921705, 0.9663252567406744, 0.8332578814588487, 0.7007712812628597, 0.9029000694863498, 1.3196567189879715, 3.062624023295939, 10.627930909395218, 45.68869896233082, 96.25388905405998, 128.1322404742241, 123.47981572151184, 122.56411045789719, 112.35962122678757, 108.6909256875515, 103.07482704520226, 103.04809927940369, 105.64825415611267, 110.70059224963188, 127.95862019062042, 139.084210395813, 119.9444930255413, 62.508739605546, 12.195100765675306, 1.3272470491938293, 3.0773539328947663, 1.650410802103579, 1.7879460845142603, 7.50600703060627, 43.21849711239338, 76.33942365646362, 98.07599008083344, 67.36985296010971, 11.709564719349146, 0.9972656308673322, 8.387658521533012, 32.848355770111084, 84.30320352315903, 132.59578496217728, 128.80533635616302, 122.67169028520584, 115.5779193341732, 115.80583110451698, 114.0617398917675, 113.86860385537148, 111.81647837162018, 111.4707501232624, 112.51774594187737, 120.35075962543488, 125.07851153612137, 141.2389075756073, 139.3316227197647, 59.425759837031364, 2.076859544031322, 3.5056785866618156, 0.34406064252834767, 0.16309124155668542, 0.30224848771467805, 0.279917917214334, 0.11943731369683519, 0.14473746938165277, 0.06074145137972664, 10.974121782928705, 48.63576382398605, 43.324807807803154, 44.02239717543125, 43.70934337377548, 47.75484949350357, 49.82310131192207, 22.44754057377577, 32.66090802848339, 29.212904646992683, 67.03167110681534, 80.80810546875, 84.03757497668266, 83.93905386328697, 79.7003585100174, 26.796283721923828, 1.3157309358939528, 0.0827209377894178, 0.014296267145255115, 0.0844318479357753, 0.017401769255229738, 0.020001961565867532, 0.059010521799791604, 0.07090524915838614, 0.031782006699359044, 0.1258228116785176, 0.061734463524771854, 0.02915115255746059, 0.015858873921388295, 0.05513552387128584, 0.037731485499534756, 0.06389742324245162, 0.03261650352214929, 0.036583679902832955, 0.00943097889830824, 0.05882011268113274, 0.11531867610756308, 0.058263702303520404, 0.008309800632559927, 0.0508674808224896, 0.02866375263693044, 0.055808065517339855, 0.044350318421493284, 0.02800305937853409, 0.04796059227373917, 0.023983374194358476, 0.04700859863078222, 0.05549352848902345, 0.053905510576441884, 0.021759133487648796, 0.028569677997438703, 0.01514341201982461, 0.031831526503083296, 0.04116820440685842, 0.010220966341876192, 0.07031706743873656, 0.04703302642155904, 0.13842845713952556, 0.1449603511719033, 0.15947031788527966, 0.1885988868889399, 0.1677456800825894, 0.17290299787418917, 0.21750438114395365, 0.08169946799171157, 0.2043435350060463, 0.13987853948492557, 0.10783747871755622, 0.12602936621988192, 0.15219520748360083, 0.11522909146151505, 0.1269333466188982, 0.07691078979405575, 0.1898176418035291, 0.21253648912534118, 0.11242447086260654, 0.13979495881358162, 0.11213564182980917, 0.13724216376431286, 0.14974138524848968, 0.11641773744486272, 0.13231059245299548, 0.15443103126017377, 0.1812259911093861, 0.13363816105993465, 0.20872864814009517, 0.12277963513042778, 0.16209020308451727, 0.25424248713534325, 0.19069581030635163, 0.18921429058536887, 0.28653205605223775, 1.567231840454042, 24.958214052021503, 85.45115992426872, 122.39685103297234, 121.90920040011406, 88.25547784566879, 75.09290054440498, 41.79106950759888, 63.57444941997528, 55.28604917228222, 58.96699905395508, 51.001007705926895, 64.61827620863914, 58.68599273264408, 60.60560792684555, 52.361178919672966, 12.021134700626135, 1.3687693211250007, 0.5164874636102468, 0.5747952160891145, 0.3041089331964031, 0.27990126342047006, 0.18239772354718298, 0.9842257993295789, 5.237489333376288, 10.2757971547544, 14.699933007359505, 16.42481815069914, 7.147040767595172, 9.774012230336666, 45.625686943531036, 97.13365584611893, 130.60270071029663, 127.37887009978294, 130.79101860523224, 118.59194800257683, 116.56913414597511, 109.92302477359772, 109.24409240484238, 112.88808926939964, 120.97556009888649, 140.88900715112686, 146.40653908252716, 122.81441062688828, 59.56694506108761, 12.606586385518312, 10.458026826381683, 16.71126388013363, 20.096393935382366, 10.919615607708693, 8.46492262557149, 47.501490488648415, 86.84011459350586, 110.72837635874748, 83.06094378232956, 12.26212726905942, 1.703766470309347, 8.674169797450304, 29.918496385216713, 87.72380277514458, 137.20750629901886, 142.5773325562477, 137.7360275387764, 127.12084874510765, 123.53859856724739, 122.02496498823166, 118.950534760952, 114.65106546878815, 118.12459588050842, 117.7259136736393, 131.92192912101746, 137.14977979660034, 154.51931655406952, 140.56234627962112, 50.8112458884716, 3.0504549387842417, 5.617448044940829, 2.2579423896968365, 0.568896863842383, 0.4103519150521606, 0.3155641310149804, 0.2866697986610234, 0.2763398748356849, 0.8653503656387329, 15.241935923695564, 68.93400862812996, 61.161274909973145, 65.03159523010254, 72.08641067147255, 108.53198781609535, 113.04885104298592, 43.32915857434273, 54.11727748811245, 30.014920011162758, 52.94926576316357, 75.12643754482269, 89.19089645147324, 89.74278643727303, 98.04117634892464, 46.85523636639118, 3.5300844395533204, 0.36744426121003926, 0.12646595685509965, 0.2054783233324997, 0.15329260641010478, 0.20671803649747744, 0.11799063780927099, 0.18111705867340788, 0.22305298887658864, 0.305790402344428, 0.13200205197790638, 0.11953796376474202, 0.14130229043075815, 0.14062891015782952, 0.11809572592028417, 0.15933245653286576, 0.11126531040645204, 0.0945626015891321, 0.13929755659773946, 0.15994584158761427, 0.17731041996739805, 0.16361257061362267, 0.06573024598765187, 0.13715227483771741, 0.0759293365990743, 0.12346615141723305, 0.18322781572351232, 0.09217271537636407, 0.16309634753270075, 0.13867327681509778, 0.1865110473590903, 0.11643436155281961, 0.1070249754411634, 0.15774206374771893, 0.14023992087459192, 0.13000607548747212, 0.10921758395852521, 0.20468885631999, 0.24094379448797554, 0.15189757657935843, 0.0999048922676593], [0.022907291604497004, 0.04623373337381054, 0.033273512017331086, 0.03112161957687931, 0.07517628677305765, 0.006895248143337085, 0.0504515775537584, 0.055121723635238595, 0.055000664506223984, 0.0992158823646605, 0.03432788493228145, 0.09546955057885498, 0.02532529593736399, 0.02450039508403279, 0.09909297528793104, 0.0656151314615272, 0.05212974785536062, 0.050683739900705405, 0.047196339728543535, 0.018174829237977974, 0.06919450228451751, 0.002770676387626736, 0.04837827669689432, 0.05989485754980706, 0.12530690029961988, 0.06483980236225761, 0.11447806769865565, 0.046919741289457306, 0.11265468507190235, 0.06963761639781296, 0.04004144240752794, 0.181097733147908, 0.016939101406023838, 0.08390553164645098, 3.3808486349880695, 19.52142968773842, 52.220476269721985, 70.7086805999279, 77.77904480695724, 54.06570665538311, 63.752697855234146, 40.128168538212776, 38.71358424425125, 50.29673829674721, 73.87059733271599, 77.68246158957481, 60.422719940543175, 36.74341656267643, 31.62472452968359, 19.85425192862749, 1.493267621845007, 0.5113729974254966, 0.1531350039294921, 0.27986145461909473, 0.19228299701353535, 0.14334987587062642, 0.022454332902270835, 0.6568900484126061, 1.0497691947966814, 5.0072910357266665, 5.388862285763025, 5.051090810447931, 32.00673133134842, 79.18993189930916, 108.00909787416458, 123.09266209602356, 110.7467369735241, 108.787402510643, 106.55119970440865, 98.71226593852043, 101.24391809105873, 99.25667032599449, 100.6464533507824, 104.35185492038727, 101.02620497345924, 97.18435272574425, 95.82489967346191, 95.38976222276688, 114.2122270166874, 116.24829456210136, 88.16942766308784, 17.637160196900368, 2.326222825795412, 2.1957060042768717, 18.0448954179883, 71.18321433663368, 102.56053224205971, 103.82920816540718, 108.17202553153038, 118.06477949023247, 87.52646416425705, 51.01425379514694, 53.46195325255394, 87.01346889138222, 97.38356083631516, 110.53936690092087, 102.35419571399689, 106.51558801531792, 104.76416319608688, 109.10637259483337, 112.509545981884, 109.31122720241547, 116.53650909662247, 117.70287930965424, 113.20171684026718, 109.98767450451851, 108.24406206607819, 104.5080341398716, 108.67195710539818, 139.04285341501236, 93.99806410074234, 11.05134503915906, 1.0172462649643421, 1.2232746533118188, 0.6422797136474401, 0.17597314406884834, 0.18077003041980788, 0.1586869067978114, 0.10384119159425609, 0.18871754145948216, 1.2952984822914004, 23.516529612243176, 37.11439445614815, 42.31856860220432, 42.151662558317184, 38.53888861835003, 68.91293495893478, 122.43476539850235, 118.54759678244591, 39.97053399682045, 30.255623795092106, 37.06359498202801, 56.69760882854462, 68.32427814602852, 74.30200338363647, 43.784146159887314, 5.178179740905762, 0.5841475236229599, 0.22981629939749837, 0.18919759226264432, 0.14292379404651, 0.04114703835512046, 0.04479007802729029, 0.06438211246859282, 0.006427995213016402, 0.0733213999774307, 0.08553367748390883, 0.3701397415716201, 0.18752689909888431, 0.11733857201761566, 0.1333494804566726, 0.026721168105723336, 0.027916484141314868, 0.05502395681105554, 0.06843023118562996, 0.05748920812038705, 0.0417238095542416, 0.0374712699704105, 0.07231564886751585, 0.13929420209024101, 0.07550092443125322, 0.027224815494264476, 0.08244629119872116, 0.04297790925193112, 0.0893091682519298, 0.012090965119568864, 0.09094642766285688, 0.0849757605465129, 0.023617662372998893, 0.04396982672915328, 0.03992434263636824, 0.027043822374253068, 0.07832844028598629, 0.05132533027790487, 0.023148830987338442, 0.06036544968083035, 0.030014440999366343, 0.016200631071114913, 0.059474108056747355, 0.020303950732341036, 0.0626203948922921, 0.04842652000661474, 0.09231068805092946, 0.03087486475124024, 0.08440144956693985, 0.06055403682694305, 0.08021372545044869, 0.05151996963832062, 0.058744250345625915, 0.052429809293244034, 0.08498002047417685, 0.049846549081848934, 0.02542588106734911, 0.10964270841213875, 0.04673552168242168, 0.039007771702017635, 0.04410994421050418, 0.026407543919049203, 0.0499365678842878, 0.019060818121943157, 0.07747763476800174, 0.07032207693555392, 0.16490242327563465, 0.0883092058938928, 0.10810822161147371, 0.05904696496145334, 0.11293197370832786, 0.10623742316965945, 0.10015766776632518, 0.15838097868254408, 1.4862299244850874, 22.895948812365532, 78.6689342558384, 94.54215690493584, 101.67883515357971, 89.36326280236244, 105.28970539569855, 69.20174226164818, 31.807129941880703, 27.303083427250385, 37.85946987569332, 48.107139989733696, 56.24351039528847, 45.49174793064594, 44.22391556203365, 25.58056365698576, 1.8249955214560032, 0.6924338755197823, 0.17804620001697913, 0.08543032599845901, 0.9851063427049667, 0.22116803767858073, 0.19769945793086663, 0.764402785571292, 0.7288945221807808, 0.652402073610574, 2.407046388834715, 8.286350257694721, 37.45801381766796, 87.28950887918472, 118.35424035787582, 131.82544469833374, 118.14696907997131, 113.57770666480064, 113.54394927620888, 105.4189744591713, 106.16260215640068, 102.7684722840786, 106.46434396505356, 107.64525219798088, 106.92107185721397, 104.11343291401863, 100.44610530138016, 99.59979951381683, 115.77685385942459, 121.71393647789955, 99.72469881176949, 25.96706561744213, 3.9725956320762634, 5.275618862360716, 27.384000085294247, 88.76012116670609, 116.07823848724365, 113.04860785603523, 111.9347508251667, 128.57178568840027, 106.85589015483856, 67.73872956633568, 62.94083721935749, 95.42632386088371, 103.61027911305428, 115.0735267996788, 108.29356580972672, 114.86131578683853, 112.93086737394333, 115.85804790258408, 117.43852749466896, 115.23987427353859, 120.72725102305412, 125.61556711792946, 120.02328559756279, 115.80209970474243, 116.15387722849846, 111.37798190116882, 106.74283102154732, 139.54365134239197, 108.47233101725578, 18.945884071290493, 1.4978697686456144, 0.38746767269913107, 0.3958099172450602, 0.0594570126850158, 0.03763780419831164, 0.06449695240007713, 0.1343344440101646, 0.27726794534828514, 1.1026782682165504, 29.77376975119114, 48.49826440215111, 44.591260850429535, 40.94582386314869, 44.867065250873566, 39.58842270076275, 86.62201389670372, 63.289696499705315, 27.119104899466038, 54.76001299917698, 59.402334094047546, 76.40832915902138, 81.51225328445435, 92.52689704298973, 57.00026258826256, 5.4430820513516665, 0.4871093697147444, 0.13309526519151405, 0.20207870809827, 0.1499158047954552, 0.032471951708430424, 0.04935698765621055, 0.08924995228881016, 0.04120517820410896, 0.12456846336135641, 0.0663602477288805, 0.4506332566961646, 0.11286815642961301, 0.16378369502490386, 0.21174859546590596, 0.05715615821827669, 0.06731978530297056, 0.007996658841875615, 0.08886735289706849, 0.025367568669025786, 0.00822558356958325, 0.0350134104519384, 0.06773814136977307, 0.25863427959848195, 0.13327841239515692, 0.15131254156585783, 0.008318785257870331, 0.05398793349741027, 0.20498338504694402, 0.08728870830964297, 0.10504823541850783, 0.014702265525556868, 0.03457805549260229, 0.0264449036330916, 0.023865944167482667, 0.04797910514753312, 0.08168334112269804, 0.0926811459066812, 0.05658421097905375, 0.03413793594518211, 0.14139354490907863, 0.14989352552220225, 0.09213108089170419, 0.1012710080249235, 0.16473254567245021, 0.1099618838634342, 0.24941555864643306, 0.13704395096283406, 0.24910403473768383, 0.22472084703622386, 0.17941510624950752, 0.20896515576168895, 0.1027687659370713, 0.14930123230442405, 0.2198425619280897, 0.08619641535915434, 0.1336248914594762, 0.20816797041334212, 0.18141044449293986, 0.14153786294627935, 0.14923837239621207, 0.07822611296433024, 0.15524298534728587, 0.19630563037935644, 0.1861934526823461, 0.14062264643143862, 0.33317725465167314, 0.15646064188331366, 0.5122023622971028, 0.18062863644445315, 0.17683296668110415, 0.32635860959999263, 0.23398531397106126, 0.18889313359977677, 6.311055226251483, 51.200158819556236, 119.40524876117706, 110.02504169940948, 112.03647136688232, 81.71978294849396, 90.58042868971825, 53.088414296507835, 59.65379700064659, 75.10863170027733, 116.11107632517815, 124.12396475672722, 97.68908724188805, 62.971360981464386, 56.73545099794865, 33.30449469387531, 2.852863878943026, 0.9099000063724816, 0.2393587600090541, 0.5322361341677606, 0.7029645354487002, 0.1728341414127499, 0.2209475010749884, 2.6051459088921547, 10.595305860042572, 13.141105603426695, 14.836260192096233, 9.549188744276762, 36.16308510303497, 91.82054534554482, 124.86251592636108, 137.55416929721832, 122.28175520896912, 119.55675423145294, 114.04119819402695, 107.50719040632248, 110.30860528349876, 106.03464022278786, 110.0244489312172, 111.36830762028694, 107.77769029140472, 105.62246114015579, 101.26453578472137, 102.79791310429573, 121.64929434657097, 124.30906802415848, 103.12435358762741, 25.819166153669357, 5.909663289785385, 6.3352428283542395, 25.877236537635326, 103.95833283662796, 121.98248326778412, 114.07136097550392, 112.37746506929398, 128.6095556616783, 130.07060766220093, 78.66697356104851, 69.23028632998466, 103.22911396622658, 108.94746512174606, 122.40332588553429, 110.12575149536133, 115.72598978877068, 116.25625133514404, 119.50413465499878, 118.49165618419647, 118.12908723950386, 121.88397735357285, 128.27818304300308, 124.53474551439285, 115.63141286373138, 118.43100383877754, 112.20796376466751, 116.65217489004135, 153.51123064756393, 108.93218994140625, 13.037207778543234, 5.542535064741969, 4.354161182418466, 1.3199816015549004, 0.3967031661886722, 0.39370527549181134, 0.45709736295975745, 0.18705346825299785, 0.3990129375597462, 1.9094924186356366, 39.95824545621872, 63.67318332195282, 68.14034521579742, 65.79699575901031, 63.31811137497425, 99.0605628490448, 149.90788400173187, 142.4045330286026, 51.76268443465233, 45.5418748408556, 53.07513400912285, 79.89385932683945, 90.10387346148491, 103.85895296931267, 77.28598326444626, 12.222318705171347, 0.8751476649194956, 0.41397089429665357, 0.24073639389825985, 0.2981610648566857, 0.18246733699925244, 0.15929082204820588, 0.2804814151022583, 0.10601423709886149, 0.2931105421157554, 0.17064605257473886, 0.6241781974676996, 0.3554637712659314, 0.22696453757816926, 0.32900748308748007, 0.11160228998051025, 0.14030776801519096, 0.15886405744822696, 0.1541935736895539, 0.1367447170196101, 0.27931009826716036, 0.16606150951702148, 0.22305052494630218, 0.4134576249634847, 0.37433249002788216, 0.23571600235300139, 0.1487008051481098, 0.2360364023479633, 0.4011777229607105, 0.3259288764093071, 0.24111150501994416, 0.18072238453896716, 0.11618719669058919, 0.15056332864332944, 0.15949765860568732, 0.24929156061261892, 0.2905506966635585, 0.22858988551888615, 0.13766860181931406, 0.13851864292519167], [0.04706334315415006, 0.11948010593187064, 0.013266343357827282, 0.024277108823298477, 0.04849638949963264, 0.007935196026664926, 0.04514430882409215, 0.05792038107756525, 0.06317963285255246, 0.11088321567513049, 0.10136946875718422, 0.06890818171086721, 0.06813623680500314, 0.043944066783296876, 0.0631866832554806, 0.05927697136939969, 0.049675046175252646, 0.07933131186291575, 0.0159528891890659, 0.03600402545998804, 0.04689638219133485, 0.0063921128366928315, 0.11509554198710248, 0.12656236183829606, 0.005005176126360311, 0.22620779927819967, 0.21831048710737377, 0.23462130484404042, 0.12666479306062683, 0.10069321637274697, 0.16624582931399345, 0.29984363238327205, 0.1565386712900363, 5.069941123947501, 45.97667030990124, 69.01698857545853, 76.32846504449844, 66.13920539617538, 61.860456392169, 59.13581259548664, 28.711969926953316, 51.41644321382046, 64.57095354795456, 72.06834644079208, 55.505270808935165, 32.87298984825611, 34.362699910998344, 31.5474271774292, 4.860057011246681, 0.33275167748797685, 0.09866891210549511, 0.1341688708635047, 0.10266165176290087, 0.10371851458330639, 0.13454074622131884, 0.7051217509433627, 0.9010089584626257, 3.420670498162508, 2.5160043546929955, 6.6019082441926, 47.93896101415157, 96.73856064677238, 121.4453136920929, 112.69972577691078, 99.83060672879219, 98.42556372284889, 111.06481030583382, 110.87144628167152, 109.52882632613182, 96.955187022686, 85.76183885335922, 82.77092814445496, 87.35458418726921, 89.12583634257317, 91.16841673851013, 99.48978021740913, 108.74633431434631, 112.466501891613, 110.69464176893234, 99.93284404277802, 97.85984247922897, 84.84945461153984, 23.641715794801712, 59.12939094007015, 72.43422120809555, 91.12892165780067, 92.19014391303062, 79.23698097467422, 81.19319200515747, 90.24613782763481, 98.65523859858513, 66.08464032411575, 69.62842896580696, 97.42238715291023, 110.04815205931664, 107.55001410841942, 106.84047058224678, 107.29782164096832, 101.775813549757, 100.9213761985302, 107.16618150472641, 115.1800274848938, 111.05404928326607, 113.01304176449776, 108.79712238907814, 107.32899516820908, 93.15583169460297, 103.73238176107407, 104.42757725715637, 95.03916263580322, 119.0051682293415, 131.291421353817, 70.21630302071571, 24.499145485460758, 7.27013991214335, 1.2988921394571662, 0.13791132863843814, 0.10164792256546207, 0.07282295133336447, 0.16228295367909595, 0.22719969449099153, 0.22201426414540038, 9.27967680618167, 27.532938793301582, 39.883028492331505, 44.10037279129028, 50.912058278918266, 63.7401357293129, 162.71260410547256, 153.1267672777176, 43.433352783322334, 34.66857209801674, 50.92322587966919, 63.534038588404655, 63.71336616575718, 74.40008372068405, 54.95140492916107, 7.915413212031126, 0.3526690509170294, 0.10573438805295154, 0.06143606449768413, 0.052886797857354395, 0.03329419567307923, 0.0017857824104794418, 0.13497457606717944, 0.1246221800101921, 0.18704904505284503, 0.07281948550371453, 0.08436511401669122, 0.057254596686107107, 0.021453016124723945, 0.0457392923271982, 0.01640627462620614, 0.018496051161491778, 0.010318870463379426, 0.04061143408762291, 0.05173977522645146, 0.08630259442725219, 0.03697843196277972, 0.12870433361968026, 0.10317858730559237, 0.10284335920005105, 0.04906057387415785, 0.03937738722015638, 0.18098969128914177, 0.07394976157229394, 0.08975542164989747, 0.021391907685028855, 0.041218002515961416, 0.08963630694779567, 0.01957011696504196, 0.05100854083138984, 0.033504575985716656, 0.04832472332054749, 0.08215168083552271, 0.06951327697606757, 0.04592756406054832, 0.10833731517777778, 0.01229795938343159, 0.04037955375679303, 0.1607846317347139, 0.05388408106227871, 0.055151042179204524, 0.06680819322355092, 0.06332205099170096, 0.19477818656014279, 0.09073694905964658, 0.06977811237447895, 0.014092582860030234, 0.027751137349696364, 0.0408925781812286, 0.014996636546129594, 0.05927433674514759, 0.07380243041552603, 0.02715453039854765, 0.047583852137904614, 0.05513228439667728, 0.06372773117618635, 0.0654066696006339, 0.08542073745047674, 0.030862925450492185, 0.21765805024188012, 0.20735279540531337, 0.12011690574581735, 0.09735349245602265, 0.12307823082664981, 0.15338433586293831, 0.2134405288961716, 0.11048786618630402, 3.0411679996177554, 59.61288459599018, 93.01441088318825, 96.32616877555847, 96.45831808447838, 100.51108941435814, 92.15251833200455, 46.17670297622681, 30.46910773962736, 45.26227444410324, 43.72861213982105, 45.85024729371071, 35.078334510326385, 41.108747720718384, 39.34645928442478, 7.415469288825989, 0.27327379561029375, 0.27638063358608633, 0.1295936937094666, 0.1517967929248698, 0.3341019112849608, 0.0549183083785465, 0.7557821762748063, 0.5005708895623684, 2.1835053339600563, 1.423707485664636, 8.39856868609786, 56.017722710967064, 109.32331055402756, 131.02730512619019, 118.60001876950264, 106.92991018295288, 105.3318603336811, 118.66480529308319, 117.17910781502724, 113.95447924733162, 100.86271494626999, 87.98790380358696, 86.53780281543732, 89.74544629454613, 90.65231323242188, 96.25743806362152, 101.09925225377083, 107.18648001551628, 118.7017697095871, 118.6278560757637, 105.75148701667786, 98.77411141991615, 93.15932750701904, 33.869687765836716, 74.40619379281998, 88.26642125844955, 102.44421288371086, 100.81156209111214, 85.12433186173439, 90.10801523923874, 93.06197673082352, 108.55532616376877, 77.95450419187546, 74.3249237537384, 105.15121042728424, 115.54116010665894, 114.16600629687309, 108.81356030702591, 110.07407426834106, 105.08184894919395, 103.01411390304565, 110.11279419064522, 117.82368242740631, 113.10246616601944, 116.93138390779495, 112.15438663959503, 108.59012469649315, 95.87228313088417, 105.51834672689438, 111.01852118968964, 97.4027270078659, 118.71657371520996, 137.9154235124588, 83.85352045297623, 34.447199776768684, 12.364020701497793, 3.703609728254378, 0.06671387367532589, 0.048166085543925874, 0.0552820238226559, 0.2819799893768504, 0.18848708976292983, 0.26397869281936437, 10.86821861565113, 37.41344980895519, 46.805158853530884, 44.56468127667904, 50.947301387786865, 61.50728814303875, 154.03637766838074, 117.80886322259903, 41.77312307059765, 45.5366463214159, 68.70913669466972, 84.73390281200409, 74.76708322763443, 86.88673049211502, 67.60638266801834, 10.554272811859846, 0.4466654977295548, 0.08530091028660536, 0.10877002438064665, 0.062497153849108145, 0.022875978538650088, 0.047117100621107966, 0.17547171941259876, 0.11816146536148153, 0.31491225818172097, 0.13248066301457584, 0.09762376779690385, 0.1382377400295809, 0.09763815804035403, 0.05436640654806979, 0.05452397192129865, 0.032506161005585454, 0.13540499203372747, 0.035636977772810496, 0.04911498443107121, 0.01950994734215783, 0.09452595433685929, 0.1999852727749385, 0.17593818891327828, 0.16861017822520807, 0.12205590755911544, 0.06563539951457642, 0.19415610353462398, 0.09865741623798385, 0.08671911738929339, 0.03373651939909905, 0.07590584762510844, 0.026618686788424384, 0.026216518817818724, 0.061328946612775326, 0.020730856340378523, 0.01886570935312193, 0.04064860084326938, 0.04387913999380544, 0.21841081063030288, 0.2514345565577969, 0.12082972374628298, 0.13162147864932194, 0.21913630451308563, 0.09369251507450826, 0.129073106800206, 0.1870646746829152, 0.1310553980874829, 0.3085321036633104, 0.23224597214721143, 0.2004376711556688, 0.12446117849322036, 0.16613539773970842, 0.19895083765732124, 0.19447478174697608, 0.11189911936526187, 0.17628808185691014, 0.07964443881064653, 0.16733963624574244, 0.2192085303249769, 0.10824600132764317, 0.21699511940823868, 0.29657052364200354, 0.11361264187144116, 0.3257430426310748, 0.3979623533086851, 0.39629103674087673, 0.25824316777288914, 0.19130064581986517, 0.3019729728111997, 0.37489183188881725, 0.35120814805850387, 10.749871116131544, 100.2486602962017, 122.33288526535034, 113.38830962777138, 101.7307023704052, 94.13709864020348, 79.68305423855782, 40.95712445676327, 77.4295699596405, 98.36615011096, 109.99878510832787, 87.56283581256866, 50.47953128814697, 51.564825251698494, 49.565820917487144, 9.649981185793877, 0.7393230625893921, 0.3282108320854604, 0.3979008737951517, 0.5382538237608969, 0.2831052930559963, 0.23395528667606413, 1.953046869020909, 8.237177096307278, 13.156795911490917, 9.179821014404297, 8.738453797996044, 57.88847632706165, 111.1331382393837, 136.68918371200562, 121.33687511086464, 109.38361331820488, 108.50513085722923, 123.28033402562141, 122.54310518503189, 119.96383398771286, 106.1086830496788, 94.47414055466652, 91.0496199131012, 95.21026745438576, 95.64252465963364, 101.12110868096352, 106.55414834618568, 116.80394634604454, 119.9991112947464, 123.4131520986557, 107.49735653400421, 102.81125798821449, 98.40869262814522, 41.388762295246124, 76.979461312294, 116.11505091190338, 104.70117017626762, 108.05949836969376, 94.67210993170738, 96.51096045970917, 103.87448653578758, 111.18032410740852, 99.54335734248161, 78.04021999239922, 108.30102860927582, 121.44561767578125, 120.96809729933739, 117.09796696901321, 121.90672293305397, 112.02400043606758, 110.54207235574722, 116.25103041529655, 121.7926150560379, 115.30735865235329, 119.84191372990608, 120.1905906200409, 119.68374341726303, 102.43120238184929, 114.12482410669327, 112.5856103003025, 98.13991785049438, 127.69742220640182, 146.7830228805542, 81.4489258825779, 29.297835789620876, 11.070490311831236, 4.26734771579504, 0.14999947452452034, 0.10920073720626533, 0.308437286876142, 0.33197681594174355, 0.274694474064745, 0.5982215527910739, 16.701439507305622, 49.00940917432308, 65.67901208996773, 67.35427379608154, 78.60471770167351, 87.32797801494598, 167.36712634563446, 160.00968754291534, 58.88356313109398, 52.49888353049755, 68.78731369972229, 91.3141617178917, 86.31496757268906, 96.33718058466911, 89.15984451770782, 20.15382405370474, 0.7833831233438104, 0.21168766514165327, 0.3105113818310201, 0.25983264029491693, 0.1402024572598748, 0.17475303844548762, 0.30816954968031496, 0.2502599742729217, 0.4091560479719192, 0.24963072210084647, 0.2357183475396596, 0.23703503626165912, 0.1893494208343327, 0.19693592155817896, 0.21558585518505424, 0.08078409562585875, 0.1453447836684063, 0.1588050863938406, 0.11274261472863145, 0.17791534453863278, 0.2185709067271091, 0.27379478327929974, 0.3612852073274553, 0.27056329417973757, 0.19095671974355355, 0.12496561626903713, 0.37421074812300503, 0.15801955276401713, 0.32558279810473323, 0.24405507050687447, 0.1910227263579145, 0.21513813233468682, 0.1744438597233966, 0.1423842675285414, 0.2952523506246507, 0.1141400788037572, 0.11131357969134115, 0.10344370472012088], [0.09595624360372312, 0.09656382506364025, 0.04285315422748681, 0.03403329312277492, 0.11976074165431783, 0.06030653057678137, 0.013969996762170922, 0.11300634432700463, 0.08875154817360453, 0.09736776395584457, 0.04694888171798084, 0.013562651383836055, 0.03764922956179362, 0.05479913059389219, 0.03572394263755996, 0.03561672456271481, 0.02279355005157413, 0.04810544094652869, 0.06289997676503845, 0.04652830662962515, 0.05376343382522464, 0.01876720409200061, 0.027474592716316693, 0.0714309568866156, 0.12412218027748168, 0.09320663099060766, 0.18086907744873315, 0.01714678215648746, 0.1834270972176455, 0.031105646703508683, 0.06352375930873677, 0.2930989349260926, 2.2521443758159876, 56.15871034562588, 81.94922983646393, 83.48012208938599, 77.20109581947327, 77.1899776160717, 44.32558290660381, 38.14605049788952, 71.4707601070404, 72.41932600736618, 58.86164590716362, 43.99269796907902, 30.0253314524889, 36.560589373111725, 16.077047511935234, 0.8703064278233796, 0.39431653800420463, 0.07571064794319682, 0.3486313816392794, 0.2322013393859379, 0.04899683452094905, 0.2527404989814386, 1.2550094816833735, 2.776976488530636, 1.7944639222696424, 9.92936784401536, 46.83371812105179, 107.04327329993248, 115.89675262570381, 105.434500426054, 98.42311665415764, 101.5292675793171, 109.91968855261803, 108.73582407832146, 101.17336347699165, 99.19950619339943, 86.39450490474701, 88.73150110244751, 89.08125713467598, 96.97034060955048, 97.1721325814724, 104.24991399049759, 101.2615567445755, 103.03193494677544, 101.85836032032967, 107.03372821211815, 108.0382727086544, 111.42053201794624, 100.63339725136757, 100.4844680428505, 52.11200729012489, 60.73634371161461, 66.73175320029259, 100.40749177336693, 100.49300998449326, 86.21513932943344, 93.25763583183289, 93.96901085972786, 115.0671735405922, 55.57204842567444, 95.9916803240776, 114.51807260513306, 102.89687499403954, 100.64545780420303, 95.6006433069706, 103.09384122490883, 99.99084413051605, 97.0779812335968, 97.97676220536232, 114.6463081240654, 111.21007651090622, 112.84534156322479, 121.83829620480537, 109.39353078603745, 99.2991292476654, 79.93817254900932, 86.6797935962677, 109.67419132590294, 109.19132083654404, 97.82838776707649, 102.36257046461105, 110.92485621571541, 98.55697587132454, 68.49896237254143, 24.070247299969196, 0.3506288572680205, 0.2643985999748111, 0.07233164957142435, 0.2172290740418248, 0.10268582351272926, 0.24952854320872575, 1.8732672999612987, 15.392982568591833, 33.888192772865295, 49.18459877371788, 49.760169088840485, 22.093401476740837, 41.92734159529209, 50.013402700424194, 31.79992362856865, 27.850660644471645, 45.82767650485039, 62.2485713660717, 72.26802572607994, 68.47159624099731, 78.91786649823189, 20.043525472283363, 0.5662108829710633, 0.06305508562945761, 0.04048458249599207, 0.044606882584048435, 0.025913616809702944, 0.20682386675616726, 0.06205650366609916, 0.21852654113899916, 0.02803920939186355, 0.06561128713656217, 0.07913515481050126, 0.11854278083774261, 0.03209341557521839, 0.02042408403212903, 0.03469952651357744, 0.034832077799364924, 0.0723298238881398, 0.018043109157588333, 0.04099876467080321, 0.22273784328717738, 0.16782525315647945, 0.0937111875100527, 0.04832430771784857, 0.04951716538926121, 0.018672858568606898, 0.05162762929103337, 0.05501114734215662, 0.024508328642696142, 0.0142896750185173, 0.051614619442261755, 0.04142552556004375, 0.03747876937268302, 0.08103559463052079, 0.07030384236713871, 0.07171470220782794, 0.045062012068228796, 0.032939749653451145, 0.08689636451890692, 0.06508498569019139, 0.09602832098607905, 0.01914216121804202, 0.04730126827780623, 0.05696465072105639, 0.0431678062886931, 0.041404010698897764, 0.06972841074457392, 0.07477997991372831, 0.09416826142114587, 0.048739966077846475, 0.008943765442381846, 0.024732891397434287, 0.08229920495068654, 0.032105887366924435, 0.0668049203522969, 0.028585413383552805, 0.047783552945475094, 0.01885164194391109, 0.07796139630954713, 0.026114191496162675, 0.05871599307283759, 0.021416962590592448, 0.15631963382475078, 0.10806977094034664, 0.19960600562626496, 0.1500589502393268, 0.19810513069387525, 0.1544275728520006, 0.012384672845655587, 0.20090262667508796, 2.2984418040141463, 68.85706275701523, 101.01023063063622, 99.71361100673676, 100.42921140789986, 101.68337970972061, 77.63634726405144, 56.24505691230297, 34.95370879769325, 45.71456037461758, 50.43317757546902, 45.05435720086098, 38.48181568086147, 47.933409512043, 22.67488617449999, 1.5447447658516467, 0.6004153413232416, 0.029788106367050204, 0.28082407952751964, 0.41449683951213956, 0.16493400908075273, 0.489625814370811, 0.828034111764282, 2.196184303611517, 2.0207047322764993, 12.647960465401411, 55.07221944630146, 119.7647550702095, 127.19113737344742, 113.05455073714256, 104.79077696800232, 107.89610713720322, 114.97633561491966, 115.68881258368492, 104.9475109577179, 103.17007273435593, 90.46992301940918, 92.9728715121746, 94.46792408823967, 101.60210967063904, 103.79820182919502, 108.0356052517891, 104.83670890331268, 109.41797107458115, 107.64058604836464, 112.08384722471237, 110.30988201498985, 112.61037737131119, 100.64642295241356, 102.05670967698097, 60.317511186003685, 67.74468764662743, 77.66457974910736, 108.88814270496368, 109.1388912498951, 94.10637348890305, 101.65304213762283, 104.7248201072216, 120.51776066422462, 62.29912385344505, 100.26161760091782, 118.73160570859909, 106.30041316151619, 105.08748024702072, 100.51073983311653, 110.51985874772072, 107.75518029928207, 101.38035356998444, 103.45304355025291, 120.30626401305199, 116.35895982384682, 118.11644911766052, 126.5773107111454, 116.20619282126427, 107.0515188574791, 85.44916123151779, 87.62845069169998, 115.76748356223106, 114.55230876803398, 99.9121655523777, 105.14669626951218, 118.3965776860714, 113.15544292330742, 80.8466050028801, 33.95555175840855, 1.6265332396142185, 0.2786235819803551, 0.16888241283595562, 0.11871852882904932, 0.09232158277882263, 0.33951727382373065, 1.2809683824889362, 19.972891062498093, 42.685469314455986, 49.69789803028107, 43.1846409291029, 36.22000224888325, 62.475157007575035, 37.79526472091675, 36.65143869817257, 54.4493492692709, 71.00574865937233, 87.88360700011253, 88.70224267244339, 79.96995404362679, 93.09068039059639, 24.863046258687973, 0.5486655619461089, 0.053611089460900985, 0.057270901670563035, 0.09683186654001474, 0.11964567165705375, 0.12884868134278804, 0.2615337318275124, 0.17539207212394103, 0.11560469240066595, 0.058935494380421005, 0.18973640631884336, 0.20049965532962233, 0.022236267650441732, 0.0557574176491471, 0.021162355842534453, 0.01956746378709795, 0.062109422506182455, 0.04592018711264245, 0.02672460239409702, 0.31982192129362375, 0.17805617448175326, 0.1532391124055721, 0.07966744538862258, 0.08161215431755409, 0.13209707656642422, 0.07171644625486806, 0.07744489863398485, 0.007535489667134243, 0.03784239204833284, 0.09334072223282419, 0.04940301936585456, 0.011355961541994475, 0.04344401881098747, 0.12137007404817268, 0.01238670169186662, 0.08257466048235074, 0.052185008171363734, 0.23959323414601386, 0.3001125867012888, 0.19518932153005153, 0.1616813984583132, 0.19008059956831858, 0.21805478754686192, 0.14569182676495984, 0.22133340302389115, 0.17973258218262345, 0.2737866196548566, 0.15200855734292418, 0.09233154240064323, 0.08434017043327913, 0.22071209183195606, 0.22664327669190243, 0.09226048918208107, 0.18065725365886465, 0.10562253155512735, 0.16817945055663586, 0.11224297864828259, 0.17732376378262416, 0.13261144427815452, 0.1765027258079499, 0.16870842373464257, 0.19879137980751693, 0.15690469852415845, 0.304233287461102, 0.25128407869488, 0.34788979799486697, 0.1965162667329423, 0.16539431875571609, 0.44172457535751164, 11.753398217260838, 106.87399998307228, 119.47727009654045, 116.74032256007195, 113.74417573213577, 102.82357692718506, 62.077474147081375, 55.01040056347847, 102.50184819102287, 107.09734439849854, 85.35070091485977, 64.87900301814079, 50.693733394145966, 63.244205340743065, 31.683058999478817, 1.8955626036040485, 0.8703454351052642, 0.16741811094107106, 0.8955939521547407, 0.43798732745926827, 0.180966135521885, 1.074040629900992, 5.231168372556567, 7.63433706946671, 6.9146699365228415, 12.489780653268099, 55.3471764922142, 124.78829830884933, 134.63758260011673, 117.70468041300774, 105.14149814844131, 110.96877425909042, 119.27620768547058, 122.00319215655327, 109.83850210905075, 109.42664220929146, 96.44272372126579, 97.89473220705986, 99.49371680617332, 103.44722986221313, 105.59241995215416, 110.87787553668022, 106.9893465936184, 111.95241987705231, 108.97705793380737, 115.43744087219238, 115.53723111748695, 115.9120962023735, 104.13864076137543, 102.03463286161423, 65.27640849351883, 84.46119144558907, 88.18550080060959, 116.74649342894554, 120.44852837920189, 97.82313644886017, 106.13433167338371, 112.27401942014694, 133.05692821741104, 68.60138207674026, 103.67937460541725, 126.27224788069725, 112.76303797960281, 110.08166626095772, 106.78691625595093, 115.64191550016403, 109.07541185617447, 108.10818135738373, 107.19823658466339, 122.99497693777084, 118.1801488995552, 121.83331847190857, 127.83147901296616, 117.05279499292374, 107.16226011514664, 89.47905018925667, 93.99127006530762, 123.59132453799248, 120.1841613650322, 102.39749819040298, 106.84646666049957, 123.80758613348007, 113.33052232861519, 77.7917817234993, 28.560772240161896, 1.210975544527173, 0.341423821519129, 0.28730011952575296, 0.20540047204121947, 0.12711576651781797, 0.593099546385929, 3.531444054096937, 27.868031412363052, 57.500235959887505, 68.98972883820534, 71.66175305843353, 34.95313122868538, 58.572245836257935, 70.49099788069725, 46.01583480834961, 42.687414810061455, 63.17026510834694, 84.18747693300247, 93.15345302224159, 88.71397644281387, 110.43462172150612, 36.062576696276665, 1.0769420117139816, 0.1800779628683813, 0.09506106507615186, 0.1472364884102717, 0.24700674024643376, 0.3361094504361972, 0.338529534637928, 0.3068614104995504, 0.24998030334245414, 0.12684624816756696, 0.2978744177380577, 0.2841717592673376, 0.30601500591728836, 0.10508384366403334, 0.13911736314184964, 0.21845804090844467, 0.19937994744395837, 0.14758264092961326, 0.15372606518212706, 0.44375672412570566, 0.3636426542652771, 0.20996036095311865, 0.16694629797711968, 0.1700441411230713, 0.24336040543857962, 0.20666359254391864, 0.18441327789332718, 0.16680751636158675, 0.13649523665662855, 0.1701268757460639, 0.13588712085038424, 0.10120532795554027, 0.18032745807431638, 0.21776275243610144, 0.13223001005826518, 0.14643609698396176, 0.08976231620181352], [0.06827192366472445, 0.06739477932569571, 0.032700180672691204, 0.021180688745516818, 0.027712256232916843, 0.04428307984198909, 0.11648703177343123, 0.04204918193863705, 0.11015793701517396, 0.03223271298338659, 0.0656745106971357, 0.06269233126658946, 0.09659745919634588, 0.046528117381967604, 0.0285700546373846, 0.10039276530733332, 0.04218191133986693, 0.062112717641866766, 0.011524449473654386, 0.03172062737576198, 0.05762290231359657, 0.05168317162315361, 0.06891398530569859, 0.016045260599639732, 0.060827399502159096, 0.133734536357224, 0.08035737555474043, 0.20036688511027023, 0.1491144485771656, 0.03755276520678308, 0.24032790097407997, 10.026901010423899, 79.20190885663033, 96.37980669736862, 85.85523024201393, 84.1983975470066, 73.05942445993423, 57.8156304359436, 36.30856029689312, 65.60157224535942, 67.4754948914051, 50.96510723233223, 55.39080575108528, 42.281106412410736, 29.269992783665657, 4.714208012446761, 0.585338284727186, 0.1662641455186531, 0.19307800044771284, 0.2111955321743153, 0.2927982166875154, 0.14142000989522785, 0.10407694964669645, 4.326958917081356, 1.734660950023681, 23.446049094200134, 72.67381355166435, 114.00931790471077, 121.21966660022736, 102.32331097126007, 96.93235024809837, 97.2516319155693, 98.48933950066566, 94.64062482118607, 90.0918585062027, 84.6545022726059, 87.63702303171158, 85.00256359577179, 86.06070801615715, 91.25101670622826, 93.39635878801346, 97.65184164047241, 105.26314482092857, 98.2537293434143, 100.51596075296402, 108.53136464953423, 108.45782339572906, 104.87935021519661, 100.94432696700096, 97.03820496797562, 97.18787893652916, 94.17006567120552, 89.34713646769524, 48.52328225970268, 87.16142535209656, 95.48398196697235, 79.66109901666641, 86.5911215543747, 79.85871881246567, 91.69999301433563, 72.44701132178307, 71.75323694944382, 101.32128193974495, 97.76147335767746, 101.37359753251076, 96.02395579218864, 97.16074079275131, 102.62702107429504, 98.63247022032738, 95.5535638332367, 96.06452241539955, 101.51850655674934, 113.67536142468452, 105.39172232151031, 110.18503591418266, 116.77357077598572, 106.01792871952057, 100.14053329825401, 78.42817917466164, 90.88732302188873, 105.65738126635551, 114.08827006816864, 100.63794940710068, 93.3171634376049, 99.97002884745598, 114.57894533872604, 119.93690103292465, 79.57202419638634, 6.90012289211154, 0.5442361277528107, 0.14598699373891577, 0.037286512306309305, 0.027332649551681243, 0.1557007568771951, 0.25827053817920387, 7.2696188651025295, 22.879358902573586, 56.09332725405693, 53.776143193244934, 35.21343246102333, 48.76150667667389, 57.841830030083656, 33.354044035077095, 27.96728778630495, 33.429952561855316, 53.49943824112415, 62.82855324447155, 57.976012229919434, 77.7091133594513, 39.86303396522999, 1.3312096428126097, 0.08876243548002094, 0.018720545267569833, 0.06196096699568443, 0.0331819272832945, 0.12439239624654874, 0.06936603487702087, 0.04695079645898659, 0.12557396956253797, 0.01902270883874735, 0.03675918669614475, 0.05831349299114663, 0.03657660352473613, 0.03959615380153991, 0.0492131854116451, 0.03433743637287989, 0.07024875274510123, 0.06322801345959306, 0.12390432282700203, 0.04728987260023132, 0.05476739264850039, 0.02474209773936309, 0.014608541550842347, 0.04997493691917043, 0.02922434501670068, 0.053886162786511704, 0.1068345551902894, 0.05178260827960912, 0.030114749679341912, 0.0921836843190249, 0.02032100899668876, 0.014649289169028634, 0.051048932218691334, 0.025527106299705338, 0.07037449482595548, 0.12166858068667352, 0.06433899368857965, 0.019364946529094595, 0.03271588451752905, 0.03799786827585194, 0.0705905859649647, 0.024369936654693447, 0.08916721024434082, 0.04057403726619668, 0.055255451225093566, 0.019351213086338248, 0.050744952241075225, 0.030173420163919218, 0.08871401776559651, 0.016426030597358476, 0.06847178403404541, 0.03929043719836045, 0.057231608661822975, 0.09818034144700505, 0.044839015245088376, 0.03613858425524086, 0.02861216966266511, 0.0797409625374712, 0.09034397444338538, 0.05552684349822812, 0.0429372358485125, 0.2140210516517982, 0.18933794723125175, 0.2518443111330271, 0.16769937006756663, 0.06452406305470504, 0.23851424048189074, 7.584357876330614, 93.99773731827736, 109.8410327732563, 110.13588175177574, 116.2869992852211, 105.79733535647392, 83.95757406949997, 41.29448175430298, 25.96552100032568, 54.68178279697895, 53.5341227799654, 61.087330877780914, 54.253747165203094, 35.79271897673607, 6.899189092218876, 0.49751490354537964, 0.33812619221862406, 0.14894770283717662, 0.2201486236299388, 0.7446671789512038, 0.12630790908588096, 0.47582513303495944, 3.0198817793279886, 4.013113332912326, 28.77475205808878, 82.07912966609001, 125.23731261491776, 129.60321754217148, 107.50971347093582, 102.03830346465111, 104.30674374103546, 104.56704497337341, 99.85751688480377, 93.2649390399456, 90.14659836888313, 93.41924875974655, 88.22716936469078, 88.80853816866875, 93.39439049363136, 95.56155100464821, 101.93125560879707, 106.0360537469387, 104.15573984384537, 104.37848389148712, 110.84607884287834, 111.5769012272358, 107.34414115548134, 104.16835516691208, 98.92243266105652, 96.9022786617279, 95.86466073989868, 92.96258926391602, 56.800191923975945, 95.0720688700676, 104.5890761911869, 87.14519262313843, 93.15640166401863, 90.57441741228104, 100.59267103672028, 80.62294140458107, 79.43417519330978, 106.5763695538044, 102.80597627162933, 106.85807883739471, 100.7461827993393, 102.21785143017769, 104.81967061758041, 103.77471908926964, 99.30131793022156, 98.42099636793137, 104.25933748483658, 117.32307448983192, 107.9385432600975, 111.8507069349289, 121.25336319208145, 109.61078032851219, 104.30633336305618, 84.95225429534912, 92.91120082139969, 108.44526126980782, 121.98810696601868, 110.87392374873161, 99.52486753463745, 104.25179108977318, 119.0550747513771, 125.98389655351639, 92.99287363886833, 13.80815600976348, 0.41570241388399154, 0.12332731042988598, 0.02715677910600789, 0.08210747109842487, 0.014250824515329441, 0.0644707323226612, 7.769238855689764, 29.974089302122593, 60.637913793325424, 44.15704295039177, 33.54103960096836, 34.61236171424389, 35.11667065322399, 21.730097271502018, 47.068169340491295, 61.43964037299156, 80.64931198954582, 83.0473481118679, 68.14273908734322, 90.79660668969154, 49.36489149928093, 1.0917169251479208, 0.3628657740773633, 0.10360601241700351, 0.009599869445082732, 0.02832247602782445, 0.16934131243033335, 0.1041888803592883, 0.15450529055669904, 0.27797016547992826, 0.11935563292354345, 0.10118818434420973, 0.025377737947565038, 0.05703585979063064, 0.04650372669857461, 0.08956854886491783, 0.03281522098404821, 0.06901972650666721, 0.08301123627461493, 0.0888496007246431, 0.08410926602664404, 0.024540111116948538, 0.015623700310243294, 0.0032673624309609295, 0.07119591871742159, 0.017613377822272014, 0.047312886599684134, 0.07993736449861899, 0.040812815859680995, 0.006278063292484148, 0.1256364435539581, 0.10245154975564219, 0.03591476364817936, 0.04433538641023915, 0.05845983338076621, 0.04196389432763681, 0.04153072128247004, 0.2673970250179991, 0.22793013107730076, 0.1866319729015231, 0.13954384572571144, 0.19924321415601298, 0.19240941444877535, 0.26795639656484127, 0.15528346208157018, 0.2197060067555867, 0.15080313140060753, 0.13390150474151596, 0.1709273413871415, 0.24415769468760118, 0.16351972793927416, 0.11934493115404621, 0.2057910940493457, 0.18936133972601965, 0.15147713507758453, 0.1686181192053482, 0.10517188464291394, 0.15771953214425594, 0.23353165393928066, 0.16044596006395295, 0.154162522230763, 0.1729812053963542, 0.4505390929989517, 0.3576698200777173, 0.49356338276993483, 0.38758935523219407, 0.1350080914562568, 0.35894527507480234, 23.069721087813377, 133.19510400295258, 127.95737385749817, 116.37618809938431, 122.30516955256462, 97.64139980077744, 84.32388961315155, 54.696142226457596, 99.26059931516647, 105.78515321016312, 70.43840870261192, 82.12485641241074, 65.78022345900536, 49.236310198903084, 9.420768935233355, 1.2309688841924071, 0.46559385547880083, 0.41559064644388855, 0.39687730371952057, 0.6628489005379379, 0.4825829219771549, 2.6614797860383987, 9.423202704638243, 6.267609782516956, 25.055038556456566, 84.00936529040337, 130.93954503536224, 136.43401980400085, 108.07962208986282, 101.10397160053253, 105.90489238500595, 108.70665684342384, 106.66114300489426, 99.25052225589752, 96.3389740884304, 98.67517232894897, 92.98689275979996, 93.52100729942322, 98.37941139936447, 101.16651624441147, 105.1715013384819, 111.35281205177307, 105.60080230236053, 109.23805832862854, 116.93766117095947, 115.806705057621, 111.60763397812843, 108.11692088842392, 102.53563597798347, 102.27167934179306, 101.52516379952431, 94.44298982620239, 63.0532655864954, 107.89107620716095, 113.43323081731796, 99.14852812886238, 103.59458595514297, 102.20541089773178, 111.54315143823624, 91.81206420063972, 81.16050615906715, 112.62408703565598, 109.8529489338398, 112.8876256942749, 106.37626469135284, 111.77455142140388, 111.50348156690598, 109.93953868746758, 105.74685126543045, 104.56870928406715, 109.69107761979103, 121.7919234931469, 112.30513975024223, 115.67827194929123, 125.35795614123344, 114.85132992267609, 110.76539397239685, 88.93996551632881, 98.70267525315285, 115.0857849419117, 129.18786942958832, 113.38254153728485, 100.9129710495472, 108.9414918422699, 127.0287948846817, 134.59113389253616, 90.10115280747414, 10.336327906697989, 0.35436613485217094, 0.35688041243702173, 0.15875652024988085, 0.31207645253743976, 0.28692328662145883, 0.867041393648833, 14.484771452844143, 42.49444976449013, 83.34373980760574, 81.7985451221466, 61.14863678812981, 73.52155566215515, 75.98033532500267, 45.587320402264595, 38.47704313695431, 45.84076300263405, 69.30847093462944, 83.65476071834564, 75.0011658668518, 105.82074210047722, 65.68886876106262, 2.538357130251825, 0.6422904599457979, 0.3020177688449621, 0.1731049214140512, 0.10758693708339706, 0.274010777939111, 0.18706666363868862, 0.23212635278468952, 0.2907065179897472, 0.19578223815187812, 0.23245825606863946, 0.1838927503558807, 0.12244012483279221, 0.16408340394264087, 0.17953509668586776, 0.13221720058936626, 0.14119530242169276, 0.19232823833590373, 0.22663011099211872, 0.19500007387250662, 0.1835983552155085, 0.0957785957143642, 0.10795671958476305, 0.21218583919107914, 0.12400748877553269, 0.25159174343571067, 0.2400766988284886, 0.19554559694370255, 0.12593468301929533, 0.24886684434022754, 0.128054776287172, 0.07719176690443419, 0.12477363750804216, 0.09243360254913568, 0.16936957341386005, 0.13250248215626925], [0.08346458460437134, 0.031806909464648925, 0.014458538662438514, 0.08053419966017827, 0.01736611833621282, 0.10317743697669357, 0.06982772494666278, 0.013655876264238032, 0.07153808590373956, 0.021659995545633137, 0.028006172688037623, 0.02259109587612329, 0.014604267707909457, 0.02013189863646403, 0.09199106731102802, 0.07608562547829933, 0.040592353470856324, 0.08706106193130836, 0.04222625466354657, 0.008297790827782592, 0.05653434978739824, 0.008995780717668822, 0.04182554315775633, 0.07808218826539814, 0.095084450149443, 0.045408350124489516, 0.04377620411105454, 0.2684483217308298, 0.20566488441545516, 0.06942015970707871, 8.837548680603504, 96.36492669582367, 88.29246506094933, 94.4250775873661, 60.54038442671299, 79.66853901743889, 40.77829845249653, 24.77815691381693, 74.00117352604866, 82.12069943547249, 56.921591609716415, 36.25898815691471, 33.06516073644161, 21.48237146437168, 0.4890931898262352, 0.28002998151350766, 0.22723475354723632, 0.1087580832245294, 0.1196030352730304, 0.04981705242244061, 0.31252090993802994, 1.194490841589868, 0.8576199773233384, 24.71710179001093, 99.78506237268448, 126.19309812784195, 116.17527768015862, 103.32604676485062, 96.5066210925579, 99.09881919622421, 96.26939222216606, 90.7279671728611, 89.00429606437683, 88.75759050250053, 89.62034940719604, 87.3282440006733, 83.9450803399086, 81.92632466554642, 84.07599091529846, 89.13781329989433, 94.48319166898727, 99.23647820949554, 103.52518647909164, 109.03329491615295, 105.4988081753254, 96.24373599886894, 98.49722787737846, 96.87550529837608, 95.78420385718346, 100.45928299427032, 101.65014669299126, 91.96215614676476, 101.87492743134499, 69.48126286268234, 54.03771735727787, 101.36182576417923, 77.92314827442169, 89.59847778081894, 81.54040217399597, 97.70949974656105, 72.41421148180962, 94.68743830919266, 103.2643760740757, 101.336420327425, 93.47375303506851, 93.23292195796967, 91.10607728362083, 99.30672883987427, 98.7436218559742, 99.69867020845413, 93.08055013418198, 97.44939610362053, 105.5924579501152, 117.8228996694088, 104.43087548017502, 105.58160573244095, 109.68058258295059, 97.65678137540817, 85.85187122225761, 85.50538301467896, 96.73416048288345, 100.05420953035355, 110.52013993263245, 105.95566526055336, 101.79747998714447, 91.01482138037682, 93.59625846147537, 110.54691329598427, 117.48091042041779, 17.37587671726942, 0.24685578740900382, 0.10543854572460987, 0.09409566453541629, 0.2036973915528506, 0.08046210001339205, 0.09355075002531521, 1.1754875862970948, 13.331810720264912, 31.7107842117548, 50.43326877057552, 50.0078359991312, 56.59347541630268, 88.42896893620491, 42.533215284347534, 28.63025911152363, 28.71413391083479, 56.09975650906563, 65.92697158455849, 62.31488920748234, 79.76693853735924, 48.37767407298088, 2.7019355027005076, 0.23003573762252927, 0.002788091346701549, 0.12098302177037112, 0.046155774471117184, 0.05290858360240236, 0.2302110180607997, 0.027636818776954897, 0.061874525345047005, 0.03976869942562189, 0.06292245641816407, 0.017167742262245156, 0.06165110920846928, 0.06347877773805521, 0.012875128559244331, 0.039016332375467755, 0.05427357871667482, 0.07648239989066496, 0.0356373525573872, 0.052847827682853676, 0.033937073676497675, 0.030859986545692664, 0.05326643607986625, 0.02986568862979766, 0.06145281848148443, 0.03135031794954557, 0.011789009349740809, 0.016859982897585724, 0.01446299247618299, 0.0734377687331289, 0.04399745317641646, 0.006883706355438335, 0.046692681207787246, 0.06723978920490481, 0.05009536151192151, 0.0766110660333652, 0.06951637173187919, 0.041303230755147524, 0.05940866547462065, 0.03482585118035786, 0.0190743753046263, 0.04629461916920263, 0.043405174801591784, 0.08553128034691326, 0.05245842279691715, 0.01550480175865232, 0.07709704659646377, 0.040572868383605964, 0.03222732870199252, 0.061601574561791494, 0.04668324480007868, 0.057977485630544834, 0.02914465505455155, 0.033931392536032945, 0.053502105074585415, 0.0445120546646649, 0.035002296790480614, 0.061466481420211494, 0.05566609266679734, 0.19229093799367547, 0.03995699713414069, 0.13328522531082854, 0.18863455450627953, 0.35204434068873525, 0.08378460610401817, 9.450016915798187, 103.36383193731308, 102.39243686199188, 114.51367244124413, 87.80170619487762, 94.7707450389862, 73.6090649664402, 39.403976798057556, 23.49915884435177, 60.163877829909325, 60.4047355055809, 43.9275086671114, 43.37130591273308, 27.05740001052618, 1.1435118271037936, 0.29117252735886723, 0.5151861521881074, 0.13336564443306997, 0.22331291867885739, 0.3539694123901427, 0.3643300908152014, 0.6961558351758868, 0.9585742664057761, 30.192096903920174, 108.90010446310043, 132.17972248792648, 121.30140781402588, 107.10505798459053, 99.54556122422218, 105.21577656269073, 102.46760442852974, 92.34391406178474, 93.25926974415779, 93.15891712903976, 93.66360604763031, 93.1924769282341, 89.94827181100845, 86.39065191149712, 87.63242527842522, 94.49159681797028, 99.10993739962578, 104.31016355752945, 108.63832890987396, 109.15572434663773, 106.17378115653992, 100.9566231071949, 100.59802874922752, 97.13095039129257, 97.80110523104668, 104.69176188111305, 106.2471704185009, 93.86586919426918, 105.0517849624157, 74.08705651760101, 62.434939965605736, 106.92620918154716, 85.48323020339012, 97.80998155474663, 88.50205421447754, 104.19113874435425, 82.24938333034515, 96.45269438624382, 107.37450912594795, 104.80395466089249, 95.73703318834305, 96.78266867995262, 98.54953587055206, 104.97148767113686, 103.63314628601074, 106.23094528913498, 99.54407170414925, 100.04340291023254, 109.34497699141502, 121.08362630009651, 108.87604415416718, 107.88925990462303, 114.42501559853554, 101.95250406861305, 88.57226684689522, 91.70968249440193, 103.59397038817406, 102.11294665932655, 112.85112485289574, 113.80908384919167, 110.36965280771255, 97.07078441977501, 96.88102260231972, 113.96571904420853, 128.14035683870316, 27.320509292185307, 0.1539192462223582, 0.18221064296085387, 0.05554422830755357, 0.2238379287882708, 0.06092512921895832, 0.19409768166951835, 0.7398324133828282, 16.382727809250355, 41.62375308573246, 48.21854621171951, 47.27233998477459, 53.31808157265186, 45.409265756607056, 24.211462922394276, 35.148778930306435, 52.07804091274738, 77.57420539855957, 88.28426510095596, 74.17457342147827, 90.58783829212189, 65.33415779471397, 5.070380475372076, 0.31371653953101486, 0.03902193559042644, 0.1931125548435375, 0.11784001151681878, 0.0071837905215943465, 0.12472118251025677, 0.07279741403181106, 0.01242965534402174, 0.06682282095425762, 0.06603695335797966, 0.04540378591627814, 0.09699294227175415, 0.07009952911175787, 0.03928547965188045, 0.020658882858697325, 0.049277845027972944, 0.09027675070683472, 0.07141825873986818, 0.03298992996860761, 0.06156892006401904, 0.026260004960931838, 0.0497472942515742, 0.06166900981043, 0.05940761533565819, 0.0445028928515967, 0.07954532498843037, 0.02656815395312151, 0.06968766683712602, 0.0733314041281119, 0.017018657781591173, 0.02562156500061974, 0.07419921224936843, 0.05394884829001967, 0.07151535392040387, 0.16704562702216208, 0.16344698262400925, 0.11322657665004954, 0.1490688361809589, 0.07544957523350604, 0.13248291914351285, 0.160018275200855, 0.16214518138440326, 0.1833275009994395, 0.14332884340547025, 0.11699360693455674, 0.16639654466416687, 0.16661062458297238, 0.1658621834940277, 0.28145054122433066, 0.2062133909203112, 0.2801269356859848, 0.23070513998391107, 0.11950378044275567, 0.1528298031189479, 0.15861986117670313, 0.13075656490400434, 0.11267806272371672, 0.23093643772881478, 0.32044951105490327, 0.14675827813334763, 0.2488126972457394, 0.4851479030912742, 0.43143570714164525, 0.23458556301193312, 23.18058393895626, 143.85822862386703, 114.84797850251198, 127.18346938490868, 84.81193542480469, 103.05318340659142, 60.1287867128849, 41.17716304957867, 115.02168238162994, 125.99460437893867, 79.40893694758415, 58.31466905772686, 53.82448419928551, 35.436613485217094, 2.3090748209506273, 0.6277215667068958, 0.8728517568670213, 0.36484962387476116, 0.30536055041011423, 0.3472523228265345, 0.9184408199507743, 3.7149402452632785, 3.6699948320165277, 27.370157428085804, 108.99892956018448, 138.03523868322372, 128.22448432445526, 110.88832497596741, 103.0294194817543, 108.67946550250053, 108.31071808934212, 98.70879292488098, 95.65416723489761, 96.47350206971169, 97.86667451262474, 98.36713045835495, 94.3418088555336, 91.28891587257385, 91.58062621951103, 99.32920083403587, 102.4587433040142, 106.19356289505959, 110.58623358607292, 115.62097862362862, 110.13809323310852, 103.5868951678276, 100.6868527829647, 100.4097792506218, 100.84785774350166, 110.00291928648949, 111.851656883955, 99.72103580832481, 110.48625335097313, 79.22436565160751, 71.89487054944038, 115.50805628299713, 97.62683898210526, 106.44861280918121, 99.48382213711739, 116.7805927991867, 91.36803522706032, 97.97670140862465, 114.18970182538033, 110.73406085371971, 104.15706217288971, 100.874904692173, 103.30627262592316, 109.44157540798187, 109.25149440765381, 110.33465668559074, 103.77061530947685, 104.04587253928185, 113.01475927233696, 124.96420606970787, 108.3365947008133, 110.09795218706131, 115.9758035838604, 104.8066221177578, 92.49466717243195, 98.2130715250969, 107.93075367808342, 105.48010557889938, 118.04008841514587, 119.8848894238472, 113.08537468314171, 99.90136653184891, 101.3497044146061, 122.40264192223549, 132.56771206855774, 21.622851826250553, 0.2819843828910962, 0.37683171685785055, 0.23276283347513527, 0.52058115019463, 0.19175060995621607, 0.47930307453498244, 2.2442006645724177, 25.693244710564613, 54.4180541485548, 74.72526267170906, 74.08302873373032, 88.33556234836578, 132.5522544980049, 58.40550698339939, 40.66105954349041, 37.86877177655697, 69.97243210673332, 89.15431201457977, 78.79984483122826, 101.34838208556175, 80.27014553546906, 10.112728904932737, 0.7159693969879299, 0.22859840537421405, 0.34179949667304754, 0.19881031941622496, 0.17029127629939467, 0.42071511677931994, 0.15785212424816564, 0.17681502155028284, 0.18726181879173964, 0.20920599752571434, 0.2148322932771407, 0.2227618740289472, 0.15576465579215437, 0.12610886507900432, 0.11958895673160441, 0.12675431091338396, 0.1828129106434062, 0.1699837451451458, 0.20245392312062904, 0.17337584984488785, 0.11800125052104704, 0.1639988287934102, 0.16430986288469285, 0.2336117168306373, 0.15967800049111247, 0.1267582888249308, 0.1415434290538542, 0.16660321794915944, 0.14337737986352295, 0.1623532350640744, 0.12231490225531161, 0.22914999921340495, 0.193704298872035, 0.197162855474744], [0.052966267030569725, 0.015714980763732456, 0.023570623197883833, 0.02186106561566703, 0.06546679840539582, 0.08455062124994583, 0.05549256740778219, 0.006082404870539904, 0.019058959042013157, 0.049544049688847736, 0.009710442027426325, 0.019469717371976003, 0.021390488327597268, 0.04253612358297687, 0.03501054576190654, 0.13015756267122924, 0.03131630532152485, 0.03368286583281588, 0.060044096026103944, 0.10757652475149371, 0.06462919569457881, 0.07345232224906795, 0.048427803922095336, 0.016291479223582428, 0.07301078891032375, 0.14278559130616486, 0.12167991328169592, 0.1407235933584161, 0.27316472958773375, 3.7948043597862124, 87.65526965260506, 91.56434789299965, 105.6395374238491, 81.7610715329647, 76.62399798631668, 42.568219006061554, 44.517453610897064, 67.89624631404877, 70.5508142709732, 63.267684280872345, 37.36775726079941, 32.15059921145439, 15.342389233410358, 0.18649805977474898, 0.12646753020817414, 0.12422990301274695, 0.1298928979667835, 0.16645533760311082, 0.047970288433134556, 0.34628723398782313, 1.6653413884341717, 3.135578683577478, 71.20794340968132, 128.51389199495316, 111.52979135513306, 94.63060855865479, 93.79039764404297, 97.6221576333046, 94.39790144562721, 87.55807846784592, 88.22518587112427, 90.45874401926994, 98.60673040151596, 100.0834147632122, 94.06445413827896, 88.53275656700134, 87.93495744466782, 86.45647957921028, 83.56081455945969, 89.24483835697174, 95.03432169556618, 97.02346175909042, 97.17560559511185, 88.57035174965858, 91.60717159509659, 97.76463478803635, 97.27757692337036, 98.63083630800247, 93.17014172673225, 96.01108208298683, 94.30800586938858, 97.73450240492821, 97.99393728375435, 90.8623431622982, 47.62464188039303, 84.99895378947258, 80.36145463585854, 76.89081206917763, 83.17679956555367, 68.61799478530884, 73.26995596289635, 98.94123405218124, 96.37289866805077, 91.15527704358101, 91.3770179450512, 91.08311891555786, 88.54145050048828, 96.48967400193214, 98.39475497603416, 97.7965758740902, 94.07454639673233, 95.17481535673141, 97.29514718055725, 106.20394393801689, 108.32119032740593, 96.95738330483437, 100.77138304710388, 107.3144343495369, 94.54596430063248, 79.62582930922508, 82.12300971150398, 95.2256566286087, 92.47253715991974, 92.25961938500404, 91.24591737985611, 93.34122374653816, 94.9813449382782, 94.32737722992897, 87.46720254421234, 125.36982670426369, 20.982542484998703, 0.4069649608572945, 0.28309751534834504, 0.06102155275584664, 0.15034660667879507, 0.036134357724222355, 0.07843116836738773, 0.48604222072754055, 7.480266261845827, 27.728248313069344, 43.31357941031456, 39.949787110090256, 41.99240170419216, 80.37438914179802, 60.90401351451874, 33.486915305256844, 26.408949606120586, 34.45751242339611, 70.21119609475136, 61.07419118285179, 73.92935737967491, 62.135056257247925, 7.900130432099104, 0.5818488250952214, 0.09401712304679677, 0.19958053511800244, 0.1036806650517974, 0.0691228405048605, 0.06004674178257119, 0.08176706280210055, 0.02144731828593649, 0.03646038690931164, 0.014941684221412288, 0.03135776540148072, 0.017528082789795008, 0.01208411602419801, 0.02918384601798607, 0.03470374191238079, 0.033790584857342765, 0.02434498008369701, 0.07392814281047322, 0.07256505501572974, 0.04211272462271154, 0.03819646328338422, 0.06317578110611066, 0.042740993449115194, 0.04764478617289569, 0.01629086324101081, 0.028946312377229333, 0.08687962166732177, 0.02910270144639071, 0.09413744002813473, 0.06591027617105283, 0.033234471338801086, 0.04892956625553779, 0.03519719590258319, 0.033154508637380786, 0.02452828128298279, 0.03271437424700707, 0.048365786351496354, 0.06626284084632061, 0.021206689889368135, 0.03859025426208973, 0.07263299121404998, 0.039130355944507755, 0.055889096911414526, 0.046449026704067364, 0.036295659811003134, 0.020521930637187324, 0.02871946937375469, 0.032027520283008926, 0.04037584672914818, 0.05072909625596367, 0.10046668321592733, 0.011407839519961271, 0.04446893588465173, 0.09436844091396779, 0.12706176785286516, 0.03175041718350258, 0.03858073992887512, 0.028149414611107204, 0.20793570787645876, 0.14749156456673518, 0.32517295447178185, 0.322772225481458, 4.848854737356305, 102.47875303030014, 108.33184495568275, 124.82620507478714, 100.04777267575264, 93.99599701166153, 82.69251555204391, 33.10453802347183, 26.94462776184082, 66.11394435167313, 72.78830140829086, 46.81986786425114, 40.91036416590214, 20.59675108641386, 0.19514768704539165, 0.21757202048320323, 0.2700015180744231, 0.1961969948024489, 0.592428051168099, 0.3125443321187049, 0.3174746863078326, 1.144347544759512, 4.8628968838602304, 81.36896297335625, 134.12550687789917, 113.96666139364243, 98.33159476518631, 99.3625858426094, 103.05215746164322, 101.82259663939476, 90.67169979214668, 91.05626955628395, 95.10297641158104, 104.77383747696877, 106.9469104707241, 99.69233974814415, 93.63398283720016, 92.45761156082153, 91.69100269675255, 89.07122567296028, 91.4223875105381, 99.58026096224785, 102.07146808505058, 101.46496742963791, 94.84676375985146, 92.4734491109848, 97.40170866250992, 98.8954009115696, 103.92725810408592, 98.28898385167122, 99.62401181459427, 97.42936357855797, 99.27654325962067, 101.74863740801811, 95.42890012264252, 55.909470319747925, 90.78364178538322, 86.25706627964973, 81.34698495268822, 90.66977709531784, 78.68047803640366, 79.88731607794762, 104.43792790174484, 102.85415768623352, 95.53335651755333, 96.6574577987194, 94.89429920911789, 93.33281099796295, 102.13534265756607, 102.56998613476753, 101.19847252964973, 99.60153222084045, 96.19316071271896, 101.6667366027832, 109.18130457401276, 109.95856806635857, 99.84595030546188, 101.65136262774467, 113.79462942481041, 101.10353082418442, 84.48723524808884, 84.93395447731018, 99.84582111239433, 97.28873312473297, 96.4681063592434, 92.81822741031647, 96.1816093325615, 100.46645700931549, 101.70238628983498, 88.9593368768692, 130.68631142377853, 31.712788604199886, 0.39872866531368345, 0.2746518747881055, 0.08475094917230308, 0.09527356422040612, 0.12452497350750491, 0.08070147232501768, 0.24483683402650058, 7.812501909211278, 34.715218394994736, 43.22437919676304, 38.24553295969963, 50.35299427807331, 53.58976699411869, 37.03925348818302, 30.553533509373665, 45.352496802806854, 60.43473869562149, 91.05208218097687, 76.60064443945885, 82.65711665153503, 82.17651844024658, 13.44081737101078, 0.3643814771203324, 0.11768640921218321, 0.18158933176891878, 0.07432511018123478, 0.08327115865540691, 0.06711685986374505, 0.11271692899754271, 0.04807546931260731, 0.0192959601918119, 0.039162958491942845, 0.007384581358564901, 0.015903677376627456, 0.03430495999054983, 0.019616024364950135, 0.04087331944901962, 0.11862104031024501, 0.032358892931370065, 0.012762823989760363, 0.04215785833366681, 0.026967633493768517, 0.05391970415075775, 0.0277633902078378, 0.0883971578150522, 0.06578670116141438, 0.012594598592841066, 0.028030787871102802, 0.005823393939863308, 0.04468994004128035, 0.04974347961251624, 0.043881796882487833, 0.03013231817021733, 0.0488747883355245, 0.029395716192084365, 0.17347730143228546, 0.1227690743689891, 0.1861126921721734, 0.14159664104226977, 0.19245884148404002, 0.1188208487292286, 0.1445868579321541, 0.20351439277874306, 0.13096631068037823, 0.19525230018189177, 0.10335265062167309, 0.12047285461449064, 0.07841548678698018, 0.09700181093649007, 0.1353281203773804, 0.27391052863094956, 0.18641565169673413, 0.18889302969910204, 0.18048811820335686, 0.3203385748201981, 0.17274218931561336, 0.20541581965517253, 0.15464981639524922, 0.15295908524421975, 0.193211022997275, 0.4220167547464371, 0.38842388545162976, 0.7608442171476781, 0.6423324358183891, 14.680837132036686, 137.6629802584648, 113.3586560189724, 137.39264756441116, 108.73917549848557, 98.39471697807312, 62.51372113823891, 70.34105032682419, 100.15529930591583, 106.80710837244987, 84.88470152020454, 60.45439504086971, 54.72482308745384, 30.391401909291744, 0.6099134660325944, 0.4378854751121253, 0.494463014183566, 0.2887156029464677, 0.5305494403000921, 0.4276269755791873, 1.315680113621056, 5.881578521803021, 4.928356921300292, 82.36979886889458, 143.86319875717163, 124.34142708778381, 102.97727108001709, 101.71836823225021, 107.13124617934227, 108.09533804655075, 94.18858587741852, 92.79680415987968, 97.78674200177193, 108.76969546079636, 110.42373910546303, 105.5982032418251, 101.32360741496086, 97.0842432975769, 97.62016654014587, 93.5184234380722, 96.24730780720711, 104.36170399188995, 108.54510471224785, 107.1265572309494, 101.01187974214554, 100.0070920586586, 101.91040232777596, 103.44890177249908, 107.81181246042252, 105.33692166209221, 108.356414437294, 103.55093389749527, 106.46114453673363, 109.41134423017502, 99.4790343940258, 62.738980650901794, 101.73064917325974, 96.69129878282547, 96.28802642226219, 102.13121607899666, 86.39787152409554, 83.95878240466118, 111.8831267952919, 108.5017642378807, 100.56678682565689, 100.62769755721092, 102.80327081680298, 98.18200439214706, 109.19819846749306, 107.78722777962685, 110.15744939446449, 103.60828042030334, 101.03060513734818, 103.67308214306831, 113.867167532444, 113.79454582929611, 100.73174357414246, 106.60460203886032, 118.58645349740982, 104.18382793664932, 87.89111539721489, 93.30827191472054, 107.3530250787735, 103.87599125504494, 102.00286656618118, 99.27256107330322, 102.53927618265152, 106.85157358646393, 107.01605916023254, 98.44828650355339, 137.88862735033035, 26.693877317011356, 0.5189283576328307, 0.6380587932653725, 0.16471863782498986, 0.37265580031089485, 0.22736033977707848, 0.33233749971259385, 0.6865789834409952, 14.468580521643162, 48.0790138989687, 65.66688314080238, 60.96029229462147, 63.091901913285255, 121.41075074672699, 82.14687243103981, 44.36430662870407, 34.724847078323364, 43.809452801942825, 89.83902767300606, 79.28662911057472, 95.72146162390709, 99.39511969685555, 21.003245674073696, 0.977706239791587, 0.22365605807863176, 0.4167552839498967, 0.1913057072670199, 0.25995812262408435, 0.14178554731188342, 0.19202775758458301, 0.2355869725579396, 0.1193426750251092, 0.1569140050560236, 0.09859187717665918, 0.10024789065937512, 0.11411761399358511, 0.10621954483212903, 0.1416668778983876, 0.14384600159246475, 0.12223702869960107, 0.20344526914414018, 0.17406871891580522, 0.10729269037256017, 0.20123046298976988, 0.12250724466866814, 0.1548793478286825, 0.15558352723019198, 0.08691092545632273, 0.10757227224530652, 0.38529297220520675, 0.1522417104570195, 0.2378675775253214, 0.24187299306504428, 0.15556991624180228, 0.1554895268054679, 0.11151274986332282], [0.04284858630853705, 0.05489736497111153, 0.0685394011088647, 0.02562071709689917, 0.09289039444411173, 0.10120344290044159, 0.05206733323575463, 0.03526579632307403, 0.03316949630971067, 0.0272657319510472, 0.03929934297048021, 0.055493903273600154, 0.04839334600546863, 0.026409805614093784, 0.05785974761238322, 0.07064734541927464, 0.0553465164557565, 0.07749929805868305, 0.06134370050858706, 0.022115405190561432, 0.03464937959506642, 0.01549328640976455, 0.05943442170973867, 0.05045267222158145, 0.07151081197662279, 0.1310515240766108, 0.14125878573395312, 0.05192174241528846, 1.2710611266084015, 81.15210101008415, 115.21300211548805, 103.48474904894829, 76.7967215180397, 67.73769602179527, 59.556507021188736, 27.965205498039722, 62.34767384827137, 92.7086640894413, 54.03385676443577, 42.316991686820984, 36.60077601671219, 9.653258509933949, 0.7462749083060771, 0.13688943581655622, 0.018225117164547555, 0.08784832476521842, 0.1530555941280909, 0.0864212415763177, 0.30174750834703445, 1.4404194639064372, 10.752112995833158, 103.81050556898117, 118.03740575909615, 92.75281012058258, 91.81077226996422, 94.28290441632271, 86.33441492915154, 82.39784136414528, 86.64439469575882, 86.94704845547676, 90.14283657073975, 97.45875120162964, 103.32034707069397, 101.29669725894928, 96.89860805869102, 93.32791686058044, 91.92628607153893, 83.21036696434021, 80.79716205596924, 81.28580823540688, 93.17398712038994, 100.77789589762688, 93.33960503339767, 96.68397277593613, 86.02360680699348, 93.69090378284454, 91.21421948075294, 94.88601565361023, 94.30395528674126, 96.25917077064514, 96.86052650213242, 103.35491001605988, 88.8770180940628, 104.86206874251366, 63.903610557317734, 49.85006466507912, 89.63916599750519, 65.68162634968758, 82.86732137203217, 66.32870122790337, 92.6717072725296, 99.37368124723434, 96.0693709552288, 89.40316826105118, 90.14602839946747, 88.89306843280792, 85.39812996983528, 86.22740507125854, 96.53411641716957, 92.32885167002678, 92.6940880715847, 87.8690841794014, 92.28371769189835, 98.4248873591423, 104.56253081560135, 102.42506191134453, 97.40731716156006, 99.59210872650146, 100.13072982430458, 87.05759212374687, 83.14113467931747, 74.97070670127869, 78.99690225720406, 77.74665534496307, 81.9260586798191, 73.49051132798195, 77.72803634405136, 85.11309966444969, 96.12844258546829, 87.36501082777977, 122.10050493478775, 20.194922648370266, 0.714223925024271, 0.39672118553426117, 0.10822320255101658, 0.04426333871379029, 0.032679244686733, 0.17798054963350296, 0.35393497673794627, 4.800078654661775, 21.27716727554798, 48.48096013069153, 32.95046389102936, 37.01120339334011, 67.32850357890129, 79.90579068660736, 44.918438494205475, 26.35385826230049, 28.289309106767178, 62.20232404768467, 73.6245909333229, 70.18243163824081, 79.35668215155602, 14.935430120676756, 0.733547491254285, 0.03221997030777857, 0.044990621172473766, 0.036400952012627386, 0.047564240885549225, 0.027239766059210524, 0.006507488506031223, 0.03348967737110797, 0.037345932360040024, 0.07869825247325934, 0.020314485518611036, 0.028959155242773704, 0.031557358597638085, 0.10087478280183859, 0.014473379760602256, 0.05494328164786566, 0.03385745236300863, 0.06160930402984377, 0.015282178792404011, 0.05656595043546986, 0.08032607176573947, 0.021236631837382447, 0.05179596322705038, 0.08541910472558811, 0.05662322939315345, 0.0503237203520257, 0.04423729675181676, 0.04286905474145897, 0.014097039456828497, 0.03348205180373043, 0.07565373263787478, 0.0362753064109711, 0.026500898675294593, 0.03218152705812827, 0.03949739992094692, 0.021019126907049213, 0.02018769515416352, 0.06885750044602901, 0.017590367533557583, 0.0496954626578372, 0.01844762417022139, 0.03829714303719811, 0.06192931810801383, 0.03867889266985003, 0.06731191111612134, 0.008027490439417306, 0.04124103506910615, 0.01676348885666812, 0.07451755649526604, 0.02255745803267928, 0.02278677795402473, 0.0678226571471896, 0.0856425728125032, 0.03719822270795703, 0.03092436229053419, 0.03549393622961361, 0.10372018441557884, 0.1556508697103709, 0.15470728831132874, 0.16180753387743607, 2.2108227806165814, 95.48993244767189, 121.96030005812645, 115.21076023578644, 96.41712829470634, 105.9219154715538, 84.78439450263977, 33.392357379198074, 39.46939408779144, 75.23756638169289, 65.10053873062134, 51.99066840112209, 45.621028393507004, 12.93049430474639, 0.8101018646266311, 0.11868321744259447, 0.15399510855786502, 0.10576742846751586, 0.6863837095443159, 0.826989880297333, 0.635545109398663, 0.7417226338293403, 14.024334009736776, 115.10651662945747, 120.59145390987396, 95.90036362409592, 95.86884811520576, 100.20678654313087, 90.73068782687187, 86.79603695869446, 86.46600186824799, 93.31313565373421, 96.4851826429367, 102.98085808753967, 106.68626725673676, 105.04807636141777, 102.11498335003853, 103.31520214676857, 96.32280215620995, 88.1916792690754, 83.82188335061073, 87.88985386490822, 96.2061408162117, 105.29521510004997, 97.74008810520172, 100.76789483428001, 89.59790021181107, 97.41300165653229, 94.76037159562111, 98.21029767394066, 97.5270563364029, 100.00664368271828, 100.92917338013649, 106.69404923915863, 92.3094955086708, 107.16773942112923, 70.36606818437576, 57.05151043832302, 99.38011810183525, 75.69277435541153, 90.36598339676857, 72.74385899305344, 96.8764628469944, 104.986702054739, 100.73427423834801, 92.39372178912163, 93.99981200695038, 92.96468675136566, 89.37169834971428, 91.80562734603882, 101.79486572742462, 98.71246352791786, 99.41471144556999, 93.24938267469406, 97.58411407470703, 103.01384031772614, 109.25794646143913, 104.47249084711075, 99.92148265242577, 103.73125702142715, 102.073193192482, 91.68175399303436, 87.75914087891579, 77.5493623316288, 80.40313079953194, 81.88185945153236, 87.58369669318199, 78.45986947417259, 79.91843640804291, 88.51697221398354, 102.63671815395355, 90.55267497897148, 127.35235512256622, 30.54207142442465, 0.4500220238696784, 0.2237187250284478, 0.10228064056718722, 0.016708161747374106, 0.03392181512026582, 0.06785381250665523, 0.14987526868935674, 4.766864161938429, 30.665940977633, 54.45754922926426, 35.310353860259056, 43.55712354183197, 43.1610631942749, 33.354815393686295, 34.65862423181534, 35.0418184697628, 54.29009601473808, 81.8844585120678, 92.57074669003487, 80.07266253232956, 99.46953490376472, 28.088636174798012, 0.883581965463236, 0.020101932568650227, 0.1355670325574465, 0.04829603560210671, 0.03409370765439235, 0.013203589205659227, 0.09473280573729426, 0.03804867199505679, 0.006645308112638304, 0.0877067081455607, 0.01799898291210411, 0.066542103595566, 0.03333834603836294, 0.03371263337612618, 0.021839220498804934, 0.0339902077394072, 0.01543323367513949, 0.03858068426779937, 0.03661474991531577, 0.008554830892535392, 0.07007605498074554, 0.02160902298783185, 0.05767160575487651, 0.04451609565876424, 0.05851546105986927, 0.07298131080460735, 0.037389967692433856, 0.08991370690637268, 0.022123277522041462, 0.019742807307920884, 0.036767739948118106, 0.0336864021664951, 0.06680216698441654, 0.1216682986705564, 0.17343611223623157, 0.11569466296350583, 0.17087927990360186, 0.19483945827232674, 0.13539819396100938, 0.12897392618469894, 0.1785508159082383, 0.14389949559699744, 0.16043681680457667, 0.11781970635638572, 0.14712071337271482, 0.09749366188771091, 0.18822603189619258, 0.14329301251564175, 0.16377851483412087, 0.14260415104217827, 0.1351956618600525, 0.1738422451307997, 0.16676277969963849, 0.1668660421273671, 0.1126368809491396, 0.16039018024457619, 0.31271223560906947, 0.2834590006386861, 0.30829271650873125, 0.4379257885739207, 10.829033218324184, 130.90103030204773, 134.94804114103317, 131.8946009874344, 101.10753580927849, 90.55384531617165, 80.45334130525589, 42.236701995134354, 97.00257048010826, 141.06198906898499, 71.31051510572433, 69.93268623948097, 57.96033427119255, 19.63681049644947, 1.648757653310895, 0.2664722199551761, 0.2894674282288179, 0.2548804075922817, 0.4489077930338681, 0.7378140091896057, 1.7104598111473024, 5.138464272022247, 12.991238795220852, 120.79312428832054, 126.31553515791893, 99.96882051229477, 98.28599721193314, 107.11777210235596, 96.18030980229378, 89.22168999910355, 91.8166771531105, 96.17940545082092, 102.47736230492592, 107.55600258708, 109.54342514276505, 109.4677484035492, 106.25541597604752, 104.8853386938572, 100.23408427834511, 95.17622888088226, 89.44362848997116, 91.67748302221298, 101.60425275564194, 111.52086183428764, 101.38269424438477, 105.82624420523643, 94.26711246371269, 104.17156979441643, 102.40753725171089, 104.45520177483559, 101.46352350711823, 102.76102468371391, 104.44030657410622, 107.82410100102425, 98.2207091152668, 112.28434726595879, 75.14443337917328, 64.20893177390099, 105.73987483978271, 79.70535144209862, 95.52030801773071, 78.52628231048584, 102.92510747909546, 110.16153797507286, 105.3993371129036, 99.92448449134827, 99.71096634864807, 98.22481289505959, 92.8136296570301, 95.64939469099045, 105.07782876491547, 103.79189416766167, 104.14782866835594, 97.29644671082497, 101.56942382454872, 108.23559612035751, 111.97100847959518, 106.48404210805893, 101.1226437985897, 107.15720638632774, 109.22458425164223, 97.55305454134941, 90.65672099590302, 82.17688322067261, 86.92594438791275, 89.35983538627625, 94.16623547673225, 82.07932725548744, 84.93914499878883, 94.37147006392479, 105.91249957680702, 96.09778583049774, 134.04710948467255, 26.226380802690983, 1.0710172983817756, 0.6249574525281787, 0.20035827619722113, 0.25715467461850494, 0.22845053987111896, 0.4766850743908435, 0.4707105184206739, 7.833177074790001, 41.1682715266943, 78.5401363670826, 53.62996123731136, 55.784084647893906, 95.11639729142189, 107.13829100131989, 56.85251131653786, 35.647733956575394, 36.971563920378685, 81.03373736143112, 96.32532522082329, 89.2127376794815, 113.0813317000866, 39.3430432677269, 1.4375738915987313, 0.12804164027329534, 0.30658399569801986, 0.13004150561755523, 0.1397721897228621, 0.13956409151433036, 0.11338752621668391, 0.11906114872545004, 0.06183908408274874, 0.22764673456549644, 0.08901644294383004, 0.12632103025680408, 0.12712542928056791, 0.10752265225164592, 0.14608817815314978, 0.19971070782048628, 0.10421363840578124, 0.20754426950588822, 0.2015072395442985, 0.2833850827300921, 0.17269828385906294, 0.18135454592993483, 0.16895846812985837, 0.11632800436927937, 0.1744726550532505, 0.24754427780862898, 0.09482020104769617, 0.19817895954474807, 0.14742656727321446, 0.11967444472247735, 0.10149722947971895, 0.11812964949058369], [0.046006647316971794, 0.04717437957879156, 0.04788836646184791, 0.02382503513217671, 0.028483520218287595, 0.07452293706592172, 0.024375912798859645, 0.012068058731529163, 0.017930393623828422, 0.012837849553761771, 0.07346260841586627, 0.10811691216076724, 0.041286064879386686, 0.04036373116832692, 0.08066972324741073, 0.039088665798772126, 0.04703101149061695, 0.03820637095486745, 0.02016313563217409, 0.03920075607311446, 0.0426055440766504, 0.019825814670184627, 0.018068486897391267, 0.03596364891564008, 0.12884733063401654, 0.2652370190480724, 0.32949489599559456, 1.5411203540861607, 79.67315956950188, 115.90470939874649, 105.86688682436943, 84.79052737355232, 88.16983044147491, 53.77900443971157, 42.31535017490387, 92.81660869717598, 58.49420182406902, 48.837023824453354, 42.01450891792774, 31.58378552645445, 6.117192953824997, 1.138579691760242, 0.07248505891766399, 0.07471155389794149, 0.1751681958558038, 0.04910081312118564, 0.06332438133540563, 1.7975735804066062, 1.668126757722348, 11.660043876618147, 103.22077721357346, 98.44077050685883, 93.00886318087578, 97.30189561843872, 87.23446503281593, 82.65248090028763, 84.51862156391144, 88.46800044178963, 91.0110291838646, 92.57173463702202, 93.88657808303833, 97.12559267878532, 98.69254499673843, 93.51497322320938, 95.02717047929764, 95.897346585989, 88.45536231994629, 78.18336591124535, 78.09869885444641, 85.2966146171093, 95.11916354298592, 96.27720460295677, 96.47537916898727, 93.15124154090881, 91.84116303920746, 85.16102269291878, 85.02017185091972, 86.69181615114212, 90.85941731929779, 91.05696871876717, 92.85365670919418, 89.8479799926281, 93.5004960000515, 92.39195108413696, 99.26054611802101, 43.91065277159214, 75.13713017106056, 96.9835714995861, 69.69308629631996, 74.27370250225067, 97.13069200515747, 96.93952426314354, 87.51418322324753, 82.13598221540451, 86.75056859850883, 84.45220872759819, 83.57868880033493, 85.79913005232811, 88.72932761907578, 91.17152497172356, 91.18642777204514, 88.90316069126129, 88.19076731801033, 89.64674279093742, 95.96042320132256, 101.06944665312767, 97.88260325789452, 94.88062754273415, 96.5483732521534, 80.29379546642303, 81.4132609963417, 77.91425675153732, 70.92775404453278, 77.98825398087502, 75.44566601514816, 80.45045346021652, 82.83259123563766, 82.35032871365547, 89.55851152539253, 98.24723929166794, 88.2051533460617, 107.71003112196922, 23.010689355432987, 0.660874075256288, 0.36039068188983947, 0.10466558407642879, 0.09194756261422299, 0.13967842678539455, 0.06645614063018002, 0.323889009305276, 1.5819909609854221, 15.77089224010706, 33.286111280322075, 35.830215364694595, 68.84422704577446, 110.08374094963074, 113.77599522471428, 72.58755818009377, 26.508952639997005, 26.817247197031975, 45.77468454837799, 69.48408231139183, 68.65484520792961, 83.37094634771347, 22.10398580878973, 0.9544571279548109, 0.013203603120928165, 0.04288726704544388, 0.05020856129704043, 0.02314883840881521, 0.07380950308288448, 0.0289280388460611, 0.05369701160816476, 0.03074290718359407, 0.040112862989190035, 0.004092642475370667, 0.10957200400298461, 0.03069313504965976, 0.023571038800582755, 0.053551944001810625, 0.054991966535453685, 0.02775340646621771, 0.010607409130898304, 0.021736768867413048, 0.045596102354465984, 0.03327951599203516, 0.023283241353055928, 0.03011241562489886, 0.08215772933908738, 0.023752158085699193, 0.018360368012508843, 0.05609804116829764, 0.052698366562253796, 0.028702887939289212, 0.045080005438649096, 0.04773084190674126, 0.08012463062186725, 0.06617820632527582, 0.05730566757847555, 0.04346046851424035, 0.04076629062183201, 0.04154446585744154, 0.02416026509308722, 0.05417185624537524, 0.01496668161053094, 0.058710694138426334, 0.04434598798980005, 0.06537687237141654, 0.02899547038396122, 0.023399628662446048, 0.06824248266639188, 0.04430214190506376, 0.02387531378190033, 0.05844746920047328, 0.017305590627074707, 0.031671152100898325, 0.019968820961366873, 0.018674773309612647, 0.015497808872169117, 0.03021675416675862, 0.2183103238348849, 0.256625137408264, 0.3632411820581183, 2.7597470255568624, 90.26637554168701, 128.15570801496506, 120.43358758091927, 104.97139647603035, 108.88873547315598, 75.17569050192833, 62.458460703492165, 39.0091285854578, 52.77165949344635, 60.69440916180611, 49.515982791781425, 43.43312479555607, 9.149268753826618, 0.8806716185063124, 0.0957402860512957, 0.018727591959759593, 0.06404272833606228, 0.5701943160966039, 0.7860241597518325, 2.097658202983439, 0.9514582576230168, 14.296287316828966, 115.58532893657684, 103.28373983502388, 98.37869703769684, 102.8846624493599, 94.42203015089035, 84.898471981287, 89.87472295761108, 92.61846452951431, 94.70924153923988, 95.05395144224167, 97.85766139626503, 99.2732298374176, 104.47857052087784, 97.61172339320183, 100.91120794415474, 96.87050476670265, 92.21092119812965, 82.62157335877419, 83.6721333861351, 89.4832755625248, 99.44832444190979, 101.31807491183281, 100.68704277276993, 96.04186043143272, 96.38489082455635, 91.98828354477882, 92.77282744646072, 94.79790598154068, 95.47255977988243, 92.45815113186836, 94.53298419713974, 92.4411128461361, 96.75217911601067, 96.45671457052231, 104.29985091090202, 49.84925150871277, 77.06827014684677, 105.07455334067345, 74.79675963521004, 77.94705659151077, 103.15001741051674, 98.85880127549171, 89.32664796710014, 87.64749526977539, 91.15695655345917, 88.45038458704948, 87.86298930644989, 89.28541257977486, 90.75480133295059, 95.35838350653648, 93.29081565141678, 91.8309035897255, 91.43077746033669, 93.27160388231277, 99.3903623521328, 103.22051122784615, 98.83616209030151, 99.3366788327694, 102.31685891747475, 82.50318691134453, 84.44915369153023, 82.85147622227669, 76.14713117480278, 81.29154592752457, 78.8885472714901, 86.50667488574982, 90.16805961728096, 88.42389240860939, 91.59935921430588, 104.15229722857475, 93.57168897986412, 115.45705541968346, 34.393417462706566, 1.0236948751844466, 0.2495290181832388, 0.04563988164591137, 0.055102375845308416, 0.07332856912398711, 0.02207532736065332, 0.3949952172115445, 0.7835410523694009, 19.061245881021023, 40.005978494882584, 38.595019206404686, 68.75525861978531, 93.34338963031769, 71.19764596223831, 41.24750107526779, 25.76107867062092, 55.849786922335625, 69.17279541492462, 84.63039636611938, 79.30403217673302, 97.39615336060524, 39.60409685969353, 0.6293604068923742, 0.06734492926625535, 0.05936156136158388, 0.05398206310928799, 0.013499294236680726, 0.08060637352173217, 0.04973739029082935, 0.08544434516807087, 0.025968962472688872, 0.042939054110320285, 0.058353283238830045, 0.08985633889096789, 0.08363753469893709, 0.03365745840710588, 0.04668953450163826, 0.052940299283363856, 0.00945194457017351, 0.045169103977968916, 0.004954442911184742, 0.02405805280432105, 0.02211245515354676, 0.05704214949219022, 0.05349498416762799, 0.036557767816702835, 0.024402401904808357, 0.03091613372816937, 0.046193750167731196, 0.018070494406856596, 0.11573418974876404, 0.050436838500900194, 0.02717537176067708, 0.13947034341981634, 0.18122860346920788, 0.21205312834354118, 0.1186646860151086, 0.1466130101471208, 0.1201447808125522, 0.13561411440605298, 0.10845988086657599, 0.1251045463141054, 0.10028389966464601, 0.15040568163385615, 0.3187652811175212, 0.1829693850595504, 0.11119010116090067, 0.18779950478347018, 0.14717863057740033, 0.1762769793276675, 0.2444554294925183, 0.05354887151042931, 0.2474431527662091, 0.10204496415099129, 0.1446011516964063, 0.06434756549424492, 0.1031726946530398, 0.32080829492770135, 0.36080070363823324, 0.6581366190221161, 13.76299163326621, 126.03875800967216, 142.8441086411476, 133.88163596391678, 107.31951087713242, 110.77322155237198, 66.9160509109497, 59.4123275578022, 139.18447941541672, 85.89135870337486, 69.49242666363716, 68.75319913029671, 55.11128894984722, 12.751223724335432, 1.6271740989759564, 0.4815870785387233, 0.26595060888212174, 0.23632224794710055, 0.2681551733985543, 0.18949384277220815, 4.742154562845826, 5.6778282299637794, 13.002875670790672, 124.46063429117203, 108.52106720209122, 102.73672118782997, 108.9348953962326, 100.6776724755764, 86.90734058618546, 91.33942276239395, 98.33594173192978, 100.19100978970528, 98.82915526628494, 100.81550627946854, 104.06223446130753, 110.33930003643036, 104.61141139268875, 108.10699582099915, 102.00611159205437, 97.5702752172947, 87.95723184943199, 87.89364606142044, 96.25712648034096, 106.91655769944191, 107.27007552981377, 108.16807374358177, 100.13321489095688, 101.30096063017845, 96.8238128721714, 99.56441581249237, 102.09606796503067, 102.04692900180817, 98.61677706241608, 97.11094826459885, 98.55144336819649, 101.39874458312988, 101.92481875419617, 110.08505567908287, 57.28344239294529, 85.6314754486084, 104.36499461531639, 83.77247840166092, 82.84598171710968, 106.90894290804863, 105.57662799954414, 97.1037058532238, 92.07276061177254, 96.282197535038, 93.53286266326904, 92.43212252855301, 93.40379878878593, 95.8847464621067, 99.21019122004509, 99.39034715294838, 98.1143756210804, 95.33809259533882, 98.334930986166, 104.81044471263885, 109.45998921990395, 103.57552617788315, 103.06323766708374, 108.77802461385727, 85.69575279951096, 90.3498874604702, 86.78443998098373, 82.3582398891449, 84.28082272410393, 83.06690946221352, 90.42442426085472, 93.58249559998512, 89.82486203312874, 97.93586120009422, 107.93225079774857, 97.69729480147362, 119.18803721666336, 29.608581215143204, 1.5669057704508305, 0.7135061791632324, 0.20119862485444173, 0.21441168850287795, 0.18572371773188934, 0.17137300106696784, 0.573404609458521, 2.321930956095457, 26.54049664735794, 56.22695468366146, 55.92431232333183, 100.55278837680817, 148.18621158599854, 151.48992151021957, 102.48387515544891, 35.786422714591026, 39.22701269388199, 61.40386149287224, 91.84563159942627, 84.91839811205864, 114.29905995726585, 48.44833888113499, 1.1898316978476942, 0.0927355008025188, 0.1941166361211799, 0.20678197994129732, 0.08537714369595051, 0.20501087419688702, 0.06249496451346204, 0.1742943169665523, 0.15973287489032373, 0.10669972180039622, 0.08063260102062486, 0.15831439319299534, 0.1639472198439762, 0.20452816650504246, 0.12421515653841197, 0.09687963116448373, 0.09769456868525594, 0.12730030895909294, 0.19194125285139307, 0.11518740502651781, 0.13514308811863884, 0.1373288466129452, 0.14904844196280465, 0.16526197898201644, 0.18332840641960502, 0.11375215821317397, 0.18805012805387378, 0.1587684836704284, 0.24988147895783186, 0.13513352925656363, 0.14702659420436248], [0.04919668746879324, 0.04804521566256881, 0.027982130814052653, 0.008008837485249387, 0.024557295546401292, 0.07655162742594257, 0.10806721053086221, 0.044043651869287714, 0.06482089986093342, 0.028979365779377986, 0.046999199330457486, 0.11538541002664715, 0.02425560694973683, 0.055336159784928896, 0.04578703468723688, 0.02085917367367074, 0.044979911981499754, 0.04880707107076887, 0.08201378237572499, 0.10777237752336077, 0.036463162541622296, 0.021218588371993974, 0.0634472216188442, 0.002507462118046533, 0.12545538920676336, 0.1571049596532248, 11.95632727816701, 90.99796548485756, 115.16625702381134, 105.94649255275726, 94.71068546175957, 97.89882078766823, 48.01669344305992, 59.02630627155304, 51.9086118042469, 61.33864179253578, 39.556211829185486, 35.40830880403519, 26.60173036158085, 2.16920955106616, 0.21028387796832249, 0.15280440682545304, 0.1368567516328767, 0.2890954341273755, 0.21701517223846167, 2.6110880775377154, 31.12061507999897, 1.4924368914216757, 2.816667021252215, 84.35755580663681, 94.13607269525528, 100.22647708654404, 94.16063457727432, 90.18571346998215, 93.34055498242378, 102.03068107366562, 95.88093906641006, 95.93829318881035, 92.85999476909637, 87.87487506866455, 90.93742713332176, 94.73754242062569, 94.70389902591705, 97.24035412073135, 93.73131081461906, 85.33381462097168, 77.94432833790779, 76.8524569272995, 77.45676130056381, 86.48430168628693, 94.57463756203651, 95.34683212637901, 96.19386747479439, 98.85335996747017, 91.93633273243904, 97.56047934293747, 93.16542997956276, 87.62869387865067, 88.83311524987221, 90.74722453951836, 82.9769378900528, 89.22759488224983, 89.63785886764526, 92.73128807544708, 96.37147754430771, 75.4948353767395, 26.556697078049183, 63.293427899479866, 50.726430639624596, 84.40578281879425, 103.1941406428814, 89.67418491840363, 88.59610676765442, 92.58456274867058, 88.52660089731216, 83.07677373290062, 84.95814397931099, 83.42567101120949, 85.31201899051666, 86.60246014595032, 88.16748216748238, 87.89233893156052, 89.01637181639671, 86.98862582445145, 91.25442132353783, 100.28117135167122, 99.04588803648949, 99.03666973114014, 90.86408346891403, 76.33402034640312, 76.39963522553444, 70.54511457681656, 75.59736907482147, 79.42988142371178, 80.50263985991478, 84.08334732055664, 86.51328653097153, 90.9711617231369, 95.14600530266762, 88.87990593910217, 97.36004009842873, 87.13947013020515, 98.4069599211216, 29.673709720373154, 0.47035865136422217, 0.12980994069948792, 0.14588361256755888, 0.14685051224660128, 0.047154694111668505, 0.06174316891701892, 0.11065412953030318, 0.41163945221342146, 13.291880562901497, 33.35927255451679, 76.22270911931992, 85.24446621537209, 106.2688672542572, 133.39669078588486, 82.72116601467133, 23.273407258093357, 28.30890465527773, 48.42162251472473, 61.6387914866209, 65.00618979334831, 79.9417595565319, 30.529448501765728, 0.9968949132598937, 0.06383661908330396, 0.037086488664499484, 0.012611141064553522, 0.03640560527855996, 0.021210771701589692, 0.008844355688779615, 0.07903155841631815, 0.056196783916675486, 0.03437432482314762, 0.05174023906874936, 0.07152668651542626, 0.04890722018899396, 0.06925819339812733, 0.06181499767990317, 0.023300910033867694, 0.022533904120791703, 0.030404126046050806, 0.09084911725949496, 0.029133815987734124, 0.0613076840818394, 0.0516577011148911, 0.0691169552737847, 0.016440875406260602, 0.031587252306053415, 0.043664332770276815, 0.04211666542687453, 0.025269044854212552, 0.06610658165300265, 0.030648938300146256, 0.014889105841575656, 0.057605257752584293, 0.026743267408164684, 0.045711677012150176, 0.01667976346652722, 0.017236082931049168, 0.016300288516504224, 0.043381214563851245, 0.07241677390993573, 0.021937009587418288, 0.02216651690105209, 0.03812007402302697, 0.05674981752235908, 0.030014376061444636, 0.05291481393214781, 0.028963159129489213, 0.06297198735410348, 0.09113083651755005, 0.06643628817982972, 0.010053145415440667, 0.09793042321689427, 0.04304194917494897, 0.023717718722764403, 0.019107259868178517, 0.1644122792640701, 0.1290411499212496, 13.4997883066535, 104.30115804076195, 126.94393783807755, 123.75663846731186, 122.65934094786644, 119.6563620865345, 76.85814142227173, 71.42961591482162, 32.277516201138496, 53.32312770187855, 48.47944401204586, 44.53829929232597, 36.0664676874876, 2.6300723338499665, 0.46239742543548346, 0.030806626127741765, 0.1642554486170411, 0.14208224311005324, 0.6285975384525955, 6.2336809281259775, 27.04353265464306, 1.2200208404101431, 4.054112182930112, 94.98553991317749, 104.81277018785477, 107.08217561244965, 100.6888134777546, 92.88065046072006, 99.53132718801498, 106.23637899756432, 101.3805815577507, 101.30959376692772, 95.4980032145977, 94.59907785058022, 96.61994621157646, 99.96616825461388, 98.67217049002647, 99.82936799526215, 96.31793841719627, 90.83008289337158, 81.61180794239044, 82.91413486003876, 83.89468744397163, 92.4629844725132, 100.03646448254585, 98.8445596396923, 99.75093260407448, 100.44095277786255, 97.05001473426819, 101.10084056854248, 98.29786777496338, 93.84274363517761, 95.47583520412445, 94.92203012108803, 84.52401727437973, 91.85924246907234, 91.70145213603973, 94.99191597104073, 96.13054767251015, 82.65311166644096, 28.96829467266798, 64.07990589737892, 53.782241865992546, 87.30606839060783, 106.87939569354057, 93.60200375318527, 92.88186639547348, 96.84259906411171, 93.4774312376976, 88.82908746600151, 89.31828081607819, 86.44479140639305, 87.80050545930862, 90.00032901763916, 92.5971020758152, 92.05157294869423, 93.60989972949028, 90.14263898134232, 93.78206089138985, 100.81330999732018, 104.4318862259388, 102.594054043293, 93.06892275810242, 81.2048801779747, 78.75654235482216, 73.09727802872658, 78.7852992117405, 83.17814469337463, 87.30096906423569, 88.73340100049973, 91.5920940041542, 96.64199262857437, 99.04414013028145, 94.23371985554695, 101.72172725200653, 91.6253650188446, 103.92083644866943, 42.31653571128845, 1.844867030158639, 0.144726084836293, 0.1648156958981417, 0.29760682897176594, 0.02411404228041647, 0.0780654899426736, 0.08159749690094031, 0.3276516980258748, 15.51368784159422, 43.0427223443985, 81.19348838925362, 85.93965411186218, 83.06497156620026, 101.7305351793766, 45.20177409052849, 20.969252698123455, 48.104882910847664, 74.24711152911186, 83.6773619055748, 74.90490183234215, 91.90509080886841, 50.307035744190216, 0.6710830586962402, 0.020571096065395977, 0.018646024363988545, 0.06177476956509054, 0.01752520511217881, 0.028605625775526278, 0.07787509195622988, 0.03985247305536177, 0.07252935029100627, 0.0399579916120274, 0.14705163426697254, 0.037164755558478646, 0.0435445130278822, 0.031074064609128982, 0.03046451460249955, 0.021994177222950384, 0.07111027487553656, 0.03913716514944099, 0.1020223880186677, 0.017635161711950786, 0.08781882439507172, 0.020826478357776068, 0.08082033469690941, 0.05551868729526177, 0.019040666957153007, 0.045561332735815085, 0.004546682393993251, 0.022399271110771224, 0.03152821445837617, 0.03559683129424229, 0.11459310058853589, 0.15101795346708968, 0.10088615250424482, 0.10164030813029967, 0.14757421013200656, 0.12271383631741628, 0.17216810840182006, 0.11520715357619338, 0.17679881304502487, 0.1417358679464087, 0.11717033456079662, 0.21827801072504371, 0.1376683940179646, 0.21293591300491244, 0.23358623147942126, 0.15807022660737857, 0.25640979583840817, 0.15114376234123483, 0.2670210233191028, 0.15161526360316202, 0.23982626851648092, 0.1400251581799239, 0.17277607577852905, 0.13984722085297108, 0.20273519709007815, 0.30462526017799973, 30.364014878869057, 141.35285586118698, 141.18108987808228, 133.31935733556747, 120.92198297381401, 126.02373361587524, 61.221053302288055, 78.10624524950981, 74.09920066595078, 89.5122604072094, 65.40688589215279, 61.319213435053825, 48.42632666230202, 4.434345429763198, 0.7407118880655617, 0.2888813987374306, 0.5075830570422113, 0.5003672442398965, 0.4860125051345676, 3.085344904102385, 51.2973690032959, 11.331826988607645, 3.286651214584708, 107.94352099299431, 107.80283734202385, 112.07102671265602, 104.57414299249649, 97.70281970500946, 99.38412308692932, 113.50899875164032, 106.78528234362602, 108.43056365847588, 97.53319680690765, 95.833380818367, 105.05604073405266, 103.40786397457123, 103.04242238402367, 104.63281184434891, 101.03183627128601, 96.26208901405334, 85.42017638683319, 86.54699832201004, 87.07884058356285, 98.13104152679443, 102.37558096647263, 105.27533456683159, 104.27609458565712, 107.05917924642563, 100.31421437859535, 105.5225721001625, 103.98243114352226, 99.80697959661484, 101.12067550420761, 98.94027650356293, 88.8776944577694, 93.30471530556679, 95.70351138710976, 100.48025026917458, 99.30496573448181, 84.17546197772026, 37.508919686079025, 78.26883092522621, 62.345010191202164, 92.06014528870583, 114.05150324106216, 98.36387783288956, 96.08811154961586, 104.3591657280922, 97.43504047393799, 91.83009803295135, 90.72367340326309, 92.60727792978287, 91.96949735283852, 96.63758486509323, 98.02144780755043, 97.1165719628334, 98.10539290308952, 94.15978342294693, 99.84041780233383, 106.81131854653358, 108.1036975979805, 105.99367082118988, 99.6663947403431, 86.91506177186966, 83.14070910215378, 77.91453033685684, 84.6843458712101, 88.66679817438126, 90.6549122929573, 95.08619651198387, 94.79330822825432, 103.06572273373604, 102.48355597257614, 97.95411542057991, 104.61160898208618, 94.02116686105728, 108.12224060297012, 36.696059703826904, 2.295961012132466, 0.670449323952198, 0.3687646012986079, 0.358648119145073, 0.13398634706391022, 0.18275244045071304, 0.47268795606214553, 0.9076673886738718, 23.60453099012375, 57.279923781752586, 86.74715638160706, 98.07196229696274, 124.00720462203026, 171.83368027210236, 121.19251325726509, 32.14945547282696, 40.257418602705, 62.06219896674156, 87.36548960208893, 80.27639999985695, 108.66267800331116, 59.815873503685, 1.4724274026229978, 0.140179569425527, 0.16242667799815536, 0.08505479185259901, 0.12604732619365677, 0.11405467987060547, 0.12007592435111292, 0.17635757656535134, 0.13896787975681946, 0.13735992775764316, 0.30324887309689075, 0.1267948024906218, 0.16391193814342842, 0.16519766446435824, 0.13264417299069464, 0.09202464207191952, 0.1522183624911122, 0.16410526761319488, 0.25117106444668025, 0.06982922408496961, 0.23261931695742533, 0.1656912817270495, 0.22457523766206577, 0.09445212548598647, 0.12426425702869892, 0.15890304988715798, 0.1301802130183205, 0.11768185984692536, 0.1482527854386717, 0.11592117385589518], [0.028729352925438434, 0.010560330065345624, 0.04078707075677812, 0.02116183819452999, 0.02079828416754026, 0.0077879158925497904, 0.04600314066919964, 0.02680032186617609, 0.05952799168881029, 0.05225412438448984, 0.03166699978464749, 0.050821014956454746, 0.0427184395812219, 0.028325498424237594, 0.04598626052029431, 0.10157736658584327, 0.07080678100464866, 0.04280258057406172, 0.032585563385509886, 0.02949130481283646, 0.005295019582263194, 0.02850973844033433, 0.0841873325407505, 0.06318784100585617, 0.11883562488947064, 30.206283442676067, 102.4393567442894, 106.85290351510048, 97.85981208086014, 109.88574877381325, 71.00669100880623, 33.47537152469158, 54.075760915875435, 43.29788625240326, 109.05297785997391, 44.432174786925316, 25.192693769931793, 30.064003877341747, 1.1140515329316258, 0.4917018982814625, 0.10019790701335296, 0.5338247457984835, 0.03071687820920488, 0.09393257016199641, 0.080018941371236, 16.717848926782608, 16.132915914058685, 2.62837833724916, 47.898409590125084, 94.54326644539833, 107.1497891843319, 99.70323756337166, 95.67663922905922, 105.6198088824749, 105.39198830723763, 98.40136662125587, 104.03792336583138, 102.02289149165154, 97.5382049381733, 94.69571426510811, 91.00890889763832, 90.99201500415802, 92.63276696205139, 91.4066107571125, 84.71221357584, 74.50999662280083, 72.68751561641693, 76.2678050994873, 83.38327288627625, 92.3049433529377, 99.99552547931671, 92.75920897722244, 94.34887647628784, 91.1611059308052, 92.8764858841896, 92.43799701333046, 91.92160472273827, 96.40049278736115, 90.16092360019684, 90.01282274723053, 92.078125923872, 90.46116068959236, 85.25363132357597, 90.25898113846779, 87.98636868596077, 89.84784319996834, 43.61163541674614, 16.634034924209118, 44.0435316413641, 89.79564920067787, 94.91757676005363, 85.76695337891579, 84.79654625058174, 84.92933392524719, 88.21819424629211, 86.58882647752762, 83.4797041118145, 85.37400126457214, 82.9342433810234, 83.47729504108429, 82.26189985871315, 82.62935534119606, 83.82714986801147, 83.86714652180672, 83.10866922140121, 88.21928098797798, 96.66755765676498, 93.74610722064972, 79.02049139142036, 74.57485154271126, 70.28081595897675, 73.01717072725296, 73.45450446009636, 78.75389009714127, 82.46916353702545, 85.77766120433807, 93.12557771801949, 89.6168839931488, 90.9759570658207, 96.27145931124687, 86.83836668729782, 98.5246168076992, 82.36208528280258, 94.52698811888695, 35.305927097797394, 0.1383962034014985, 0.04710909655841533, 0.20485052576987073, 0.012906154970551142, 0.06168893276480958, 0.07864673258154653, 0.1063125062501058, 0.11834723234642297, 11.225986517965794, 47.3941158503294, 84.6757735311985, 91.25669360160828, 115.71158856153488, 117.5093100965023, 88.98254603147507, 26.683663465082645, 22.898618169128895, 46.35385327041149, 68.75168681144714, 68.42445597052574, 72.23097771406174, 34.28948923945427, 1.166399186477065, 0.08952748583396897, 0.043135715823154896, 0.05076967318018433, 0.036376357238623314, 0.13448839512420818, 0.024404066170973238, 0.03264400009356905, 0.11967526850639842, 0.031188748689601198, 0.04545527612208389, 0.0276168550044531, 0.040845808034646325, 0.07433713297359645, 0.059131937159691006, 0.017871736126835458, 0.030571094430342782, 0.05373615618736949, 0.050188779350719415, 0.018118769257853273, 0.0621021976985503, 0.08066647264058702, 0.014186961780069396, 0.025236104629584588, 0.07604320431710221, 0.023313823403441347, 0.0962532139965333, 0.04118763012229465, 0.08308697244501673, 0.030326144878927153, 0.0508895671373466, 0.023276317115232814, 0.06916705766343512, 0.030028144756215625, 0.027494823661982082, 0.014881865263305372, 0.0065422265834058635, 0.01585464367963141, 0.025988176676037256, 0.021363722771639004, 0.113107580691576, 0.04702321151853539, 0.009688722147984663, 0.04628437753126491, 0.05700844856619369, 0.04894655030511785, 0.0040852998517948436, 0.020490966380748432, 0.02475830253388267, 0.026125217955268454, 0.03808979810855817, 0.011409779308451107, 0.032320345781045035, 0.07592402282170951, 37.029719799757004, 123.56427758932114, 119.81961652636528, 115.1998320221901, 118.63107830286026, 88.19431632757187, 66.42455488443375, 61.78367771208286, 26.618690751492977, 53.92518639564514, 43.8615670055151, 32.955836802721024, 39.74954545497894, 1.4875440602190793, 0.4933645762503147, 0.08894936763681471, 0.457148096174933, 0.03847344392852392, 0.3678038762882352, 0.25113897398114204, 9.700828157365322, 7.454143138602376, 2.3397619742900133, 53.51861581206322, 103.97805377840996, 112.80580088496208, 104.30422827601433, 102.00975179672241, 112.65557214617729, 108.54825854301453, 104.3228928744793, 107.51881778240204, 110.26925459504128, 103.19522738456726, 100.12046277523041, 94.98027339577675, 92.62318387627602, 97.87555083632469, 97.03852415084839, 88.94256457686424, 77.43339255452156, 75.87175235152245, 80.42862743139267, 87.60653346776962, 96.96841031312943, 102.04740777611732, 97.16954872012138, 98.56875523924828, 94.63382318615913, 97.21212923526764, 97.45446503162384, 95.86164370179176, 98.53968679904938, 95.20543411374092, 93.84380757808685, 94.71452325582504, 92.94865161180496, 89.77350398898125, 95.56425645947456, 90.06119415163994, 92.51371175050735, 51.154709458351135, 21.007577441632748, 48.98623041808605, 93.33020433783531, 100.12262865900993, 90.71203082799911, 89.06871020793915, 89.80530068278313, 92.03793928027153, 90.77206760644913, 87.54126816987991, 89.1982452571392, 86.39577403664589, 87.49725133180618, 86.06682568788528, 87.10784822702408, 85.9397529065609, 89.24352362751961, 87.516128718853, 91.4603778719902, 99.65614289045334, 98.36754083633423, 84.35227409005165, 77.12517589330673, 73.35476741194725, 76.3534677028656, 78.72530043125153, 85.4086022078991, 84.00501072406769, 89.03270334005356, 98.10209468007088, 94.93959277868271, 95.09064987301826, 98.73048216104507, 91.03928446769714, 103.01229760050774, 88.06510806083679, 99.049581438303, 49.51219439506531, 1.6252223099581897, 0.09623098667361774, 0.07299489952856675, 0.07689236968872137, 0.053761615563416854, 0.12244240322615951, 0.05101984745124355, 0.1379713832284324, 12.617346458137035, 49.14438173174858, 86.36528447270393, 88.28174203634262, 111.71233355998993, 102.04344838857651, 30.067716278135777, 16.70306771993637, 36.65761336684227, 60.85859075188637, 87.4644286930561, 82.65340805053711, 84.02249738574028, 56.95933498442173, 1.8332193489186466, 0.04371524781163316, 0.012805134756490588, 0.08939375082263723, 0.0224410614464432, 0.07522296786191873, 0.019441658623691183, 0.043892988469451666, 0.023067135371093173, 0.04418726486619562, 0.037276756775099784, 0.058072161409654655, 0.0476908846758306, 0.03347480102092959, 0.05419878136308398, 0.0848851517366711, 0.07114043575711548, 0.008505634850735078, 0.012522326396720018, 0.03898367045621853, 0.059332060991437174, 0.10103369146236219, 0.04236873959598597, 0.014989457195042633, 0.036409534950507805, 0.03717514933669008, 0.09219940300681628, 0.07535476586781442, 0.04233525389281567, 0.14800536824623123, 0.17210588674061, 0.25620481465011835, 0.1161559448519256, 0.12949078751262277, 0.0955395054188557, 0.11835017125122249, 0.13169385289074853, 0.1495258358772844, 0.1307269828976132, 0.12765683670295402, 0.22446116956416517, 0.16322148847393692, 0.10300310648744926, 0.17578238243004307, 0.14201976911863312, 0.14204397797584534, 0.13569138682214543, 0.10456247007823549, 0.08019425149541348, 0.11012750896043144, 0.12369396848953329, 0.10868177560041659, 0.1732654034276493, 0.147682118404191, 58.412000834941864, 151.7480644583702, 131.14011347293854, 125.33530175685883, 134.53878790140152, 92.2597485780716, 46.59204348921776, 68.43143999576569, 62.67614722251892, 157.4440348148346, 74.15584802627563, 45.085173547267914, 54.240208491683006, 2.299354230053723, 0.7885213382542133, 0.27965861081611365, 0.7133312104269862, 0.1608503414900042, 0.3754410211695358, 0.14571107807569206, 25.279158130288124, 29.173614755272865, 3.713329369202256, 61.78256817162037, 104.7408476471901, 116.08355820178986, 109.16559621691704, 104.16599929332733, 117.93603479862213, 115.37198558449745, 107.6686817407608, 112.43598952889442, 113.62574368715286, 108.05269673466682, 103.67522522807121, 97.60313585400581, 98.8966852426529, 102.78389185667038, 102.16775491833687, 94.200828820467, 83.53454276919365, 81.47620841860771, 85.54526567459106, 91.70281246304512, 101.52419105172157, 108.88503447175026, 101.07150614261627, 101.5708677470684, 100.00671207904816, 104.69109311699867, 103.66323307156563, 102.19438388943672, 106.1332069337368, 100.73462381958961, 99.9210874736309, 99.22232776880264, 96.24783977866173, 92.35386952757835, 97.91366279125214, 95.744199603796, 96.20012953877449, 52.471232414245605, 30.997573882341385, 58.48781816661358, 97.14813306927681, 107.31290683150291, 96.42115607857704, 96.2465326488018, 94.57513153553009, 95.8384345471859, 95.37838563323021, 91.55908897519112, 93.85880157351494, 92.28595957159996, 93.4464780986309, 90.76191455125809, 91.90814584493637, 92.69381448626518, 91.76518991589546, 91.47451311349869, 99.05762940645218, 104.21780571341515, 104.37637880444527, 88.27866420149803, 81.97726473212242, 79.76224198937416, 83.52828830480576, 84.1326230764389, 89.3478812277317, 90.1185254752636, 95.4703938961029, 103.98987874388695, 99.73802089691162, 100.26053085923195, 102.02305108308792, 94.46656376123428, 107.5897827744484, 87.8852105140686, 102.62253731489182, 45.178378745913506, 1.6660597873851657, 0.5112368578556925, 0.35238059295807034, 0.2831146738026291, 0.42264612566214055, 0.23859373934101313, 0.27388357382733375, 0.2571085427189246, 20.369802564382553, 65.74420899152756, 99.18236911296844, 92.41857245564461, 118.9797855913639, 145.97117364406586, 123.19313630461693, 37.664798721671104, 34.57779876887798, 61.6572280973196, 92.48903587460518, 89.47104021906853, 97.72502571344376, 66.12503215670586, 2.609103871509433, 0.16770650952821597, 0.13765414478257298, 0.1615031494293362, 0.09638470772188157, 0.21100803598528728, 0.0971498026046902, 0.15801064699189737, 0.3099098859820515, 0.13017752644373104, 0.21734766924055293, 0.14332298043882474, 0.12993807991733775, 0.156105880450923, 0.21286146074999124, 0.17535106104332954, 0.12816595000913367, 0.1825887375161983, 0.13721182476729155, 0.12388908653520048, 0.17655638308497146, 0.1171997310302686, 0.11476210245746188, 0.16636246524285525, 0.1938967377645895, 0.22317150986054912, 0.2042926533613354, 0.24077603942714632, 0.15675503702368587], [0.05637466558255255, 0.02808824494422879, 0.034357841723249294, 0.032821262066136114, 0.03794212927459739, 0.055074177944334224, 0.04509628444793634, 0.02335629651497584, 0.035739869126700796, 0.05569332206505351, 0.04443522011570167, 0.010662416189006763, 0.03416340274270624, 0.042788424107129686, 0.01262323436094448, 0.04663389940105844, 0.039739740823279135, 0.01864006120740669, 0.03276881448982749, 0.01519705723694642, 0.04173917943262495, 0.0278616561263334, 0.03972736551077105, 0.6114297034218907, 53.985686749219894, 111.3913343846798, 98.51459294557571, 113.08975204825401, 88.65447923541069, 72.88685292005539, 82.55996346473694, 55.154519230127335, 56.94685645401478, 120.91011241078377, 48.445542231202126, 29.75932102650404, 36.190458834171295, 1.6829518997110426, 0.529083312721923, 0.22516349359648302, 0.08313916026963852, 0.12723753810860217, 0.21032739750808105, 0.3968998946947977, 1.2773464643396437, 3.9133499236777425, 2.1256285021081567, 18.08086808770895, 98.96602392196655, 99.19472604990005, 105.43474361300468, 104.07905235886574, 109.98865485191345, 101.95410758256912, 99.94580894708633, 99.09362867474556, 98.69360134005547, 99.36908349394798, 103.49818512797356, 94.60097774863243, 92.25509762763977, 91.35257765650749, 90.31879752874374, 85.13544246554375, 82.96085715293884, 72.56360426545143, 71.61553233861923, 71.56595259904861, 85.48397496342659, 90.27530506253242, 99.28174138069153, 95.36243408918381, 95.71951612830162, 87.2256951034069, 91.19930148124695, 92.80138671398163, 96.45425230264664, 90.8514529466629, 89.68331202864647, 91.00782215595245, 95.42256966233253, 91.41340479254723, 97.48446822166443, 89.6457852423191, 93.97220268845558, 86.91393703222275, 97.62873888015747, 35.90122975409031, 37.11793586611748, 102.32944384217262, 85.505930185318, 82.43536055088043, 78.5973384976387, 89.4063600897789, 82.13833048939705, 86.14469110965729, 82.12976574897766, 83.59679102897644, 80.73760405182838, 80.36565721035004, 80.27924984693527, 79.5249979197979, 79.4806618988514, 85.54892107844353, 79.79740530252457, 82.49464496970177, 83.3751717209816, 77.41337522864342, 73.06389302015305, 74.14095282554626, 71.1294624209404, 68.99653807282448, 75.79697996377945, 78.82390514016151, 83.73033866286278, 83.42329993844032, 93.17254319787025, 90.69919511675835, 92.35589861869812, 91.35453075170517, 97.54182234406471, 85.53763568401337, 92.57880985736847, 93.5737256705761, 104.08149182796478, 26.704235561192036, 0.5126569129060954, 0.22728217678377405, 0.11876114294864237, 0.07889170068665408, 0.08646071641123854, 0.03587249091651756, 0.028487574199971277, 0.05839744473632891, 11.797958426177502, 44.01869237422943, 76.72190353274345, 91.83730244636536, 114.09396216273308, 89.5458734035492, 84.39421623945236, 38.39527152478695, 24.562881365418434, 38.61519992351532, 58.45923990011215, 79.54445287585258, 95.05661889910698, 23.008379079401493, 1.0449451161548495, 0.29441399092320353, 0.1787637232337147, 0.09926478989655152, 0.03004188933118712, 0.10220760581432842, 0.015620125013811048, 0.02553088568674866, 0.03962729431805201, 0.03559358439815696, 0.0639167265035212, 0.023575304294354282, 0.04405995685374364, 0.015528727672062814, 0.06112612136348616, 0.05170393691514619, 0.07295732459169813, 0.03986644769611303, 0.09494677433394827, 0.03992495119746309, 0.03324173696455546, 0.04167794482782483, 0.1190006711112801, 0.07069722516462207, 0.035110561293549836, 0.028000228085147683, 0.03198094680556096, 0.014496977273665834, 0.07716163570876233, 0.02826019870553864, 0.05428836971987039, 0.02357020759518491, 0.03387377590115648, 0.07855184157961048, 0.06318421190371737, 0.05099473688460421, 0.027920413813262712, 0.07183090769103728, 0.08071730975643732, 0.09051667220774107, 0.07172147801611573, 0.07258009834913537, 0.023461638811568264, 0.033082794907386415, 0.05592882036580704, 0.01803201961593004, 0.06408817003830336, 0.02698128158954205, 0.06934413409908302, 0.05441480941954069, 0.08258922141976655, 1.0299107478931546, 69.53059181571007, 133.32543700933456, 110.88992089033127, 135.4340958595276, 103.72522294521332, 110.14569282531738, 102.90828198194504, 36.26388229429722, 43.20519022643566, 63.12119834125042, 51.76644243299961, 37.29931153357029, 50.148033276200294, 2.039891565218568, 0.6636129564139992, 0.17435085377655923, 0.36648457520641387, 0.11629575805272907, 0.6654240342322737, 1.2179712066426873, 1.4046306093223393, 1.8378467881120741, 1.2802504585124552, 23.551369942724705, 105.28961420059204, 103.99750113487244, 109.57456067204475, 109.16191041469574, 115.95610544085503, 103.2058972120285, 101.90202757716179, 102.99446135759354, 102.27861016988754, 100.84418714046478, 105.5967365205288, 99.51535284519196, 99.50918197631836, 94.45136457681656, 95.08919075131416, 88.8349087536335, 86.56749442219734, 78.3879317343235, 74.28397715091705, 76.09883576631546, 88.32332700490952, 94.75448191165924, 102.50089064240456, 99.56730365753174, 98.95982265472412, 93.20581421256065, 96.67757391929626, 98.63142147660255, 100.68416252732277, 93.33243101835251, 96.10717132687569, 94.8270732164383, 97.54357784986496, 94.88112911581993, 100.14665096998215, 93.2334615290165, 97.6056057214737, 90.52758112549782, 99.90588828921318, 43.867669478058815, 40.8001434803009, 104.63877752423286, 90.32594114542007, 87.05279678106308, 83.02319660782814, 94.3181437253952, 86.47446781396866, 89.50623393058777, 87.21845269203186, 87.23968595266342, 84.843420535326, 84.40993219614029, 85.27148276567459, 83.3453357219696, 84.93359729647636, 89.70813989639282, 85.49115657806396, 84.49744150042534, 86.36355936527252, 82.3233425617218, 75.44368252158165, 77.63154432177544, 74.8821410536766, 73.40836733579636, 80.8665083348751, 84.11676272749901, 89.17989984154701, 88.63139167428017, 94.15055751800537, 93.1448882818222, 96.79703190922737, 93.36045071482658, 99.58067893981934, 89.12468880414963, 97.80298233032227, 96.86661377549171, 109.92337435483932, 37.120823711156845, 0.7257062557619065, 0.24262449180241674, 0.16917845554417, 0.14063986425753683, 0.06494018525700085, 0.12800963886547834, 0.012140445960540092, 0.2686637523584068, 13.835287503898144, 48.94160181283951, 85.64178049564362, 98.56155082583427, 117.18650981783867, 91.43719151616096, 40.26584655046463, 24.66478619724512, 47.52564579248428, 58.406023755669594, 75.76972782611847, 88.48626986145973, 107.24951103329659, 41.253086775541306, 0.9760165179613978, 0.19220245914766565, 0.10040982728241943, 0.0697666165069677, 0.07259184654685669, 0.12462249171221629, 0.05959736765362322, 0.08920680382288992, 0.03340641953400336, 0.07973676198162138, 0.044812090127379633, 0.010154443934879964, 0.08149475397658534, 0.024665951532369945, 0.059138994984095916, 0.02397790456598159, 0.035367169984965585, 0.04854155660723336, 0.015279886483767768, 0.050533291723695584, 0.04024594491056632, 0.030198504755389877, 0.0750530902587343, 0.03249028646678198, 0.07733111997367814, 0.03430968747125007, 0.11984042605035938, 0.05681117458152585, 0.18540357006713748, 0.13397577888099477, 0.16788894427008927, 0.12262970645679161, 0.16469920839881524, 0.13495691295247525, 0.18154950812458992, 0.12845457124058157, 0.14237792958738282, 0.17569966265000403, 0.1569475798169151, 0.1832548892707564, 0.1291757309809327, 0.14953778445487842, 0.09940727482899092, 0.14373522863024846, 0.15779637411469594, 0.11175060077221133, 0.3052787954220548, 0.12585889489855617, 0.15511502424487844, 0.13803114095935598, 0.11799978849012405, 1.6750415554270148, 92.17366799712181, 156.24088257551193, 122.53349170088768, 143.9514908194542, 113.07205259799957, 97.56159648299217, 99.74411576986313, 71.65998995304108, 78.30674529075623, 173.03581416606903, 72.61514469981194, 48.9409938454628, 64.63270023465157, 4.215057771652937, 0.6727070559281856, 0.8318285644054413, 0.4241659847320989, 0.3532469761557877, 0.5249556654598564, 0.904968346003443, 3.460811306722462, 12.280520182102919, 4.375241976231337, 27.045639641582966, 106.56807839870453, 103.68408635258675, 113.58979761600494, 111.2843169271946, 118.09754133224487, 106.89154744148254, 102.37097561359406, 102.56804063916206, 103.48824486136436, 102.88767948746681, 110.19661769270897, 105.29428035020828, 104.3054062128067, 100.24426013231277, 99.92431730031967, 92.94986754655838, 91.30851522088051, 80.62012195587158, 78.75366970896721, 81.1712671816349, 97.07228913903236, 98.87429684400558, 107.88167551159859, 103.05502250790596, 104.05362412333488, 98.64261567592621, 100.64831525087357, 104.51936513185501, 103.54370668530464, 98.14183294773102, 101.2496329843998, 99.52742859721184, 104.44134771823883, 102.08631008863449, 105.3958261013031, 97.7249725162983, 98.43906819820404, 92.43124857544899, 101.40386670827866, 48.274483010172844, 48.05904597043991, 109.53344687819481, 97.29257091879845, 91.41421034932137, 88.66965562105179, 98.56763809919357, 92.42637723684311, 94.30546000599861, 89.65205490589142, 90.45057445764542, 89.47835102677345, 89.73673716187477, 88.7196533381939, 87.70455300807953, 89.83090370893478, 96.11293941736221, 90.48910439014435, 90.6579977273941, 91.51837795972824, 86.17398753762245, 80.40323719382286, 83.82688388228416, 80.97183108329773, 76.42006292939186, 84.59428310394287, 89.12425562739372, 93.59737560153008, 93.44306588172913, 99.98655796051025, 99.5898212492466, 101.11683011054993, 99.96921569108963, 103.28068479895592, 91.87665313482285, 102.7934293448925, 99.38061207532883, 113.63862499594688, 33.54389704763889, 2.1658954164013267, 1.0544770234264433, 0.201766605314333, 0.211355836072471, 0.1719994776067324, 0.3729436348658055, 0.11633936665020883, 0.44049213523976505, 24.008101634681225, 60.76939053833485, 92.39862352609634, 100.18893510103226, 126.57350331544876, 113.68156269192696, 115.32780915498734, 56.77783012390137, 37.608512341976166, 51.717086881399155, 79.75287929177284, 98.36985111236572, 119.83244463801384, 54.51207250356674, 1.5201419172808528, 0.2580445393687114, 0.2755213750060648, 0.17993290268350393, 0.20375257765408605, 0.2452394788269885, 0.1280372912879102, 0.24110641388688236, 0.09534682161756791, 0.15271968324668705, 0.14142333471681923, 0.13907819258747622, 0.18190183531260118, 0.09955502158845775, 0.1108753785956651, 0.17396763840224594, 0.1332212521811016, 0.14608365105232224, 0.23151960253017023, 0.10749250621302053, 0.13987736689159647, 0.19992705871118233, 0.3227841592160985, 0.10402258732938208, 0.1969119205023162, 0.1597204661811702, 0.15100563381565735, 0.1239354930294212], [0.0746739492751658, 0.0123022285879415, 0.030381308715732303, 0.027554475636861753, 0.025315494021924678, 0.07391718871076591, 0.0442331704107346, 0.10338042920920998, 0.03681182352011092, 0.028787928786186967, 0.02805834938044427, 0.05748318559199106, 0.020901064199279062, 0.06309383315965533, 0.056596070498926565, 0.037018804796389304, 0.03770851602894254, 0.017801686663005967, 0.006965395941733732, 0.05045797486673109, 0.05251619528280571, 0.05005624290788546, 0.4405924736056477, 72.90755420923233, 114.19673904776573, 97.13848918676376, 102.94707030057907, 72.63925820589066, 71.0833328962326, 40.48336587846279, 22.29738213121891, 73.14006373286247, 108.0863781273365, 60.74780389666557, 34.871192425489426, 34.45685125887394, 2.4303645500913262, 0.408845889614895, 0.27188856212887913, 0.293906272854656, 0.12906847579870373, 0.5725552956573665, 0.16082292655482888, 0.7609834440518171, 0.4849575273692608, 2.3188835196197033, 15.242543891072273, 95.28349712491035, 102.52198711037636, 99.74384218454361, 102.60013371706009, 105.98199024796486, 103.91696825623512, 108.26247587800026, 102.69050806760788, 99.98058468103409, 98.85284319519997, 97.55943059921265, 98.30233633518219, 97.38393321633339, 97.56783574819565, 96.11817553639412, 93.80639478564262, 87.19457477331161, 79.55079853534698, 72.54215061664581, 69.91093620657921, 70.82667946815491, 76.51234477758408, 93.99532824754715, 98.23179692029953, 89.309541285038, 86.41126200556755, 83.41053262352943, 92.53203436732292, 91.27198398113251, 92.22650796175003, 90.3311924636364, 86.86479806900024, 85.11836618185043, 87.12593525648117, 85.84848180413246, 88.60776454210281, 88.32015037536621, 96.1689256131649, 89.74588707089424, 91.350267380476, 75.76862588524818, 39.67813968658447, 91.23432040214539, 84.15561184287071, 81.12346574664116, 77.5435258448124, 83.27163487672806, 82.6820433139801, 84.35486555099487, 81.99124038219452, 84.79761779308319, 80.06316304206848, 80.88591769337654, 76.45090207457542, 79.97610971331596, 78.10575127601624, 79.17040094733238, 77.2591795027256, 72.81495317816734, 70.16345545649529, 77.27671176195145, 71.54729560017586, 68.6917032301426, 68.45540151000023, 70.45221716165543, 71.78945660591125, 75.8224005997181, 79.65101435780525, 86.23410791158676, 87.76752322912216, 89.41269814968109, 88.9740040898323, 92.94048964977264, 85.76367035508156, 95.47018110752106, 88.18288654088974, 96.03229254484177, 92.94649332761765, 93.94150793552399, 13.305540829896927, 0.953156054019928, 0.28539226565044373, 0.07941058807773516, 0.14753107650903985, 0.051002766922465526, 0.0904832904052455, 0.04334370270953514, 0.13424455508356914, 13.923966195434332, 40.434105321764946, 80.79909235239029, 97.01386347413063, 83.28774601221085, 64.26546514034271, 40.539777651429176, 29.26678765565157, 30.256628841161728, 47.81737893819809, 67.12097391486168, 74.20307949185371, 80.08992120623589, 16.846876703202724, 0.4884357360424474, 0.1707066415110603, 0.029502130892069545, 0.04628182825399563, 0.009492883291386534, 0.03467696522420738, 0.07982542636455037, 0.015117485090740956, 0.025391347080585547, 0.034224667033413425, 0.04993209273379762, 0.06279589055338874, 0.098049730877392, 0.08442296442808583, 0.05607044440694153, 0.03927215810108464, 0.06369828275637701, 0.07390006736386567, 0.038761593896197155, 0.036765064505743794, 0.04828007942705881, 0.015391474880743772, 0.036659842808148824, 0.04901105035969522, 0.05130598248797469, 0.08817591617116705, 0.022626032478001434, 0.032820423439261504, 0.04317190294386819, 0.059423820130177774, 0.03462406122707762, 0.00491740788675088, 0.03884849196765572, 0.034108877152903005, 0.03908914077328518, 0.09349087355076335, 0.04450976884982083, 0.02986380543006817, 0.043979548863717355, 0.02995934395585209, 0.03244607672968414, 0.029098217019054573, 0.0421320315945195, 0.041978729859692976, 0.0044354622878017835, 0.058677219567471184, 0.03557716067007277, 0.030729817553947214, 0.08244286989793181, 0.7230119034647942, 96.31296828389168, 135.73795795440674, 106.42865628004074, 127.02770054340363, 84.14814904332161, 87.03555330634117, 59.587547555565834, 48.75040367245674, 61.22965984046459, 65.73083370923996, 67.8597454726696, 37.315601259469986, 49.20929744839668, 2.7696654433384538, 0.15461074974155053, 0.2862448152154684, 0.367166074574925, 0.22369680198607966, 1.3083937671035528, 0.720719201490283, 1.6012891754508018, 1.0778101463802159, 0.9894396539311856, 19.529348462820053, 103.73296692967415, 105.32125890254974, 104.51716884970665, 105.5599544942379, 109.08414378762245, 107.28443115949631, 114.25041496753693, 107.67248913645744, 101.19030296802521, 99.67502787709236, 100.26590377092361, 102.36610427498817, 102.15764746069908, 102.29516968131065, 100.83003669977188, 97.81000435352325, 92.1255549788475, 84.03740778565407, 73.58238279819489, 72.61300921440125, 75.83676382899284, 79.1031065583229, 96.75691366195679, 100.56845873594284, 93.17628979682922, 90.23839384317398, 88.470379114151, 95.06628558039665, 96.26324415206909, 96.5326800942421, 94.76427778601646, 90.5213114619255, 88.79412934184074, 88.77896815538406, 90.94849973917007, 93.80659237504005, 95.32347097992897, 98.13576087355614, 91.99456080794334, 92.55531951785088, 81.07523873448372, 44.51446697115898, 94.52727690339088, 87.3411177098751, 85.72609037160873, 81.9180791079998, 87.07297369837761, 87.50555008649826, 86.98619395494461, 86.49633184075356, 87.46009692549706, 84.07983630895615, 83.57122600078583, 78.8075964152813, 82.64372617006302, 81.54433116316795, 83.17371413111687, 80.65781593322754, 75.71424320340157, 74.99034404754639, 79.48715955018997, 74.06460732221603, 72.51451089978218, 69.7552889585495, 74.64502617716789, 75.23281663656235, 81.31825849413872, 82.81923115253448, 89.57570940256119, 90.52188903093338, 93.14495667815208, 90.57363465428352, 97.43379414081573, 88.06746393442154, 100.18996864557266, 90.47203570604324, 99.28743347525597, 95.6023608148098, 100.44627249240875, 19.811080545186996, 0.09260500155505724, 0.22931331623112783, 0.2860497194342315, 0.5534264096058905, 0.2222167665604502, 0.04663083433115389, 0.035386829476919957, 0.1376996235921979, 17.265279851853848, 46.1682940274477, 88.53491485118866, 107.9171884059906, 88.30574154853821, 67.99474462866783, 25.04375696182251, 27.683519013226032, 48.4544413536787, 58.66326995193958, 80.25652706623077, 77.96494603157043, 98.28636959195137, 32.536168321967125, 0.7422701013274491, 0.2575188019545749, 0.07737845415249467, 0.044076369449612685, 0.02350336977542611, 0.06358320533763617, 0.051838740619132295, 0.0019520861087585217, 0.03233105497201905, 0.06232725398149341, 0.056216784796561114, 0.0984460451581981, 0.13568631053203717, 0.06802167146815918, 0.07286143911187537, 0.02593499066279037, 0.018827926614903845, 0.09578503013472073, 0.04858342857914977, 0.054505544394487515, 0.020364944139146246, 0.08952142990892753, 0.022093292900535744, 0.02383419508987572, 0.05333030901965685, 0.01945186872035265, 0.026008674794866238, 0.13173961371649057, 0.10340126129449345, 0.1507072607637383, 0.16952591424342245, 0.14265212346799672, 0.16178175166714936, 0.13266410707728937, 0.1798413513461128, 0.14037738146726042, 0.12716741999611259, 0.160436519945506, 0.17537390434881672, 0.1319780360790901, 0.1865972700761631, 0.1371231084340252, 0.11213900375878438, 0.07917891183751635, 0.14302362775197253, 0.20569578744471073, 0.12021009722957388, 0.12035481602651998, 0.33016015717294067, 1.8921330501325428, 125.06218001246452, 149.64694440364838, 122.56018906831741, 137.45850563049316, 97.66891032457352, 93.94329383969307, 61.38577826321125, 30.51974192261696, 94.70674127340317, 156.63867563009262, 83.68832811713219, 58.19580763578415, 67.02259719371796, 5.516473688185215, 0.7252699916716665, 0.9011173120234162, 0.6385469483211637, 0.6571618525777012, 2.6099167903885245, 0.9527640813030303, 3.5261599626392126, 7.337246211245656, 7.08381881006062, 21.45192939788103, 103.93396094441414, 105.36462217569351, 106.19784906506538, 107.6060003042221, 113.56822237372398, 110.68710297346115, 119.29530546069145, 113.32806766033173, 104.40583482384682, 103.73593837022781, 101.53251260519028, 107.11117565631866, 102.58724480867386, 103.78693163394928, 104.18309077620506, 102.09965497255325, 96.53740704059601, 90.04449024796486, 78.05215135216713, 75.173349827528, 79.40873175859451, 84.16455656290054, 104.78849709033966, 106.7519961297512, 98.66034552454948, 97.8347410261631, 92.24717885255814, 101.71798825263977, 103.16914558410645, 101.39008864760399, 101.2325718998909, 95.44875785708427, 95.02092361450195, 95.24012625217438, 97.30283036828041, 99.92491006851196, 100.44767081737518, 105.31600758433342, 101.05996996164322, 95.39556071162224, 84.10681486129761, 50.16403041779995, 98.14294248819351, 92.01653122901917, 88.14520016312599, 86.3206672668457, 90.98798722028732, 91.1798845231533, 92.6842238008976, 92.82954320311546, 93.30469250679016, 88.1904785335064, 89.7112937271595, 83.74230802059174, 87.98102617263794, 88.08501899242401, 88.84153559803963, 86.51519402861595, 81.4365841448307, 78.77188593149185, 84.36738967895508, 77.86612093448639, 77.0226725935936, 76.91773742437363, 81.04646667838097, 80.57531476020813, 86.33519008755684, 87.24890425801277, 94.63468953967094, 96.39902606606483, 97.50135451555252, 98.0025552213192, 101.13962888717651, 94.44707080721855, 105.53660094738007, 95.89496031403542, 105.14640748500824, 101.55240833759308, 102.3219658434391, 16.878350414335728, 1.670656946953386, 1.3988595502451062, 0.18918846384622157, 0.6795732281170785, 0.4396551114041358, 0.22821618447778746, 0.17089649772970006, 0.38341441832017154, 29.1738598421216, 57.990797236561775, 98.55753064155579, 109.70268979668617, 96.52981504797935, 79.82762888073921, 57.806541323661804, 42.01669380068779, 44.01277229189873, 61.342160403728485, 90.74532464146614, 88.97910341620445, 112.3084607720375, 37.83962734043598, 1.1189120658673346, 0.4284667008323595, 0.27700483915396035, 0.10436427954118699, 0.14100366504862905, 0.1646767955389805, 0.15171834791544825, 0.06200122108566575, 0.1347786045516841, 0.11499466185341589, 0.1180649119487498, 0.2733166323741898, 0.25238219008315355, 0.2769102598540485, 0.2188969767303206, 0.14188713248586282, 0.16321705043083057, 0.1985891000367701, 0.17916509154019877, 0.17343943705782294, 0.16363234142772853, 0.24267970758955926, 0.09089610262890346, 0.21224872878519818, 0.1620124705368653, 0.1508309322525747, 0.14379651518538594], [0.036492963481578045, 0.05658756919729058, 0.09477154584601521, 0.038410699053201824, 0.07847065062378533, 0.01674422270298237, 0.07211452684714459, 0.05220282342634164, 0.013935759634478018, 0.021907019399804994, 0.01838862899603555, 0.029318946581042837, 0.04065669396368321, 0.03133540078124497, 0.04313054676458705, 0.04426749474077951, 0.046557944297092035, 0.06154218419396784, 0.0927315822627861, 0.054858918010722846, 0.08712504990398884, 0.028009386187477503, 61.846655532717705, 120.58332994580269, 93.4558179974556, 109.49250027537346, 80.26131480932236, 124.46957901120186, 148.8925176858902, 96.59630388021469, 58.52763622999191, 48.31718131899834, 83.31920072436333, 45.93495614826679, 35.04282921552658, 1.6522497846744955, 0.14683175075333565, 0.03798981226282194, 0.10552958498010412, 0.26736828905995935, 0.29175306495744735, 0.05687730365025345, 0.8858284761663526, 2.9593840381130576, 1.3987478124909103, 20.157431960105896, 99.25207257270813, 101.42249330878258, 99.77712079882622, 103.76577436923981, 102.40515857934952, 104.762202501297, 104.71911281347275, 99.13365572690964, 100.38090839982033, 100.48454403877258, 98.93590673804283, 98.94850686192513, 96.31460979580879, 96.82962656021118, 95.4856538772583, 96.46852433681488, 99.10125866532326, 91.36761724948883, 79.2908088862896, 72.016821205616, 68.36822658777237, 69.11721959710121, 73.75944569706917, 79.06002447009087, 86.58977642655373, 84.3308812379837, 81.22393995523453, 84.75619241595268, 91.97954401373863, 91.95007279515266, 91.70801058411598, 89.6167927980423, 83.10434505343437, 85.44575661420822, 83.80721613764763, 83.20339813828468, 84.64186415076256, 85.32273441553116, 83.48281234502792, 88.0387830734253, 87.67601653933525, 91.91181644797325, 59.8496612906456, 80.5042813718319, 92.60038509964943, 74.57404598593712, 82.29359775781631, 84.40149664878845, 82.44813546538353, 74.69460591673851, 79.26709815859795, 81.03829711675644, 81.62621676921844, 79.86910745501518, 76.53039380908012, 73.76323029398918, 78.34795787930489, 79.12603452801704, 80.53034797310829, 71.37305974960327, 73.1864820420742, 67.90701493620872, 68.20594489574432, 66.94765761494637, 69.29732993245125, 65.7041971385479, 71.19135349988937, 76.556695997715, 79.80159267783165, 82.67978623509407, 84.42638531327248, 88.0471122264862, 89.45879727602005, 87.48913496732712, 93.20161163806915, 87.370186150074, 90.89699730277061, 86.09651729464531, 88.03889706730843, 96.36395394802094, 80.66400960087776, 4.078163942322135, 0.9303705766797066, 0.3510466864099726, 0.08863606257364154, 0.12901931593660265, 0.09482344423304312, 0.020676772328442894, 0.12064396418281831, 0.6951488298363984, 16.148358285427094, 30.636680647730827, 59.843878000974655, 89.26806271076202, 59.77910287678242, 47.609530091285706, 58.72413128614426, 29.186323173344135, 42.591716945171356, 64.47810173034668, 82.38547682762146, 82.31860801577568, 75.72011008858681, 1.2983044772408903, 0.13791760720778257, 0.06933102034963667, 0.06343142129480839, 0.08309324359288439, 0.050446594032109715, 0.011976182704529492, 0.046519200477632694, 0.015400817592308158, 0.034013626209343784, 0.04505184835579712, 0.029142124330974184, 0.0733658397803083, 0.05575336923357099, 0.04151886918407399, 0.017054830059350934, 0.012077669543941738, 0.04900088293652516, 0.03204735789040569, 0.04995673574740067, 0.05207388639973942, 0.03299749245343264, 0.04047733542392962, 0.10143301886273548, 0.045953079097671434, 0.009174609549518209, 0.003266329686084646, 0.051278048049425706, 0.03357186651555821, 0.027129494046675973, 0.019665006111608818, 0.033823142875917256, 0.04050455740070902, 0.05640427356411237, 0.031186748601612635, 0.038526822900166735, 0.03314979971037246, 0.027446834537840914, 0.03596190857933834, 0.06291637080721557, 0.015431200190505479, 0.10088725088280626, 0.04960957019648049, 0.049786108575062826, 0.052310152823338285, 0.06929995404789224, 0.045728360491921194, 0.04175255664449651, 0.16065358329797164, 78.06332275271416, 141.53032153844833, 105.0955282151699, 127.0519508421421, 92.01631844043732, 119.39672201871872, 134.73134636878967, 111.0003125667572, 29.98669322580099, 36.98292911052704, 86.09280109405518, 49.28056262433529, 47.900073900818825, 0.5118925601709634, 0.3520898788701743, 0.1747628051089123, 0.2515505690826103, 0.15814282349310815, 0.5425843445118517, 0.18613053340232, 1.962398523464799, 1.5817338810302317, 0.3762738296063617, 26.644656658172607, 106.87874212861061, 105.48734039068222, 105.19065991044044, 108.33945214748383, 105.30949473381042, 108.74806702136993, 108.65421205759048, 102.7202832698822, 104.67805221676826, 102.70449131727219, 103.45498904585838, 103.6140789091587, 98.57909068465233, 98.87966215610504, 98.6905463039875, 97.59644821286201, 100.43247163295746, 95.94463884830475, 82.09278613328934, 75.40705248713493, 73.04870143532753, 72.89893627166748, 75.598334223032, 81.37479946017265, 89.59779381752014, 87.87292197346687, 85.35130128264427, 90.33314555883408, 96.23509526252747, 95.35884708166122, 95.43190956115723, 94.3166010081768, 88.08074042201042, 91.03953525424004, 88.45676824450493, 89.64833110570908, 89.77916568517685, 91.39952793717384, 89.06563997268677, 94.02685895562172, 94.55259874463081, 93.22973772883415, 63.31076256930828, 83.27762335538864, 97.59904727339745, 77.50115811824799, 86.17460310459137, 88.52143317461014, 85.80249667167664, 79.61067572236061, 79.9524673819542, 84.5070093870163, 85.25732472538948, 82.14312583208084, 80.75309962034225, 77.54949912428856, 84.30856883525848, 82.71324723958969, 85.8014327287674, 74.43874284625053, 77.18866288661957, 70.09001299738884, 69.90958347916603, 70.94073414802551, 74.11656573414803, 66.99161365628242, 74.06742677092552, 79.8304483294487, 85.28561040759087, 87.04116940498352, 88.41205224394798, 92.13254660367966, 94.93700131773949, 89.64307978749275, 97.51901596784592, 88.6592061817646, 93.37870493531227, 89.71637025475502, 92.68507495522499, 97.61382848024368, 90.81848591566086, 8.58498003333807, 0.3800467005930841, 0.5309908103663474, 0.1892675322596915, 0.38726191967725754, 0.23726539890049025, 0.07967283338075504, 0.07364075354416855, 0.21579750085948035, 20.756864994764328, 33.76725286245346, 64.71700251102448, 97.81998261809349, 68.92232805490494, 36.48100644350052, 31.875227987766266, 38.816129341721535, 51.39213211834431, 71.52153298258781, 94.27943900227547, 89.05659645795822, 96.1863286793232, 6.4829599019140005, 0.3080522606614977, 0.19728642306290567, 0.0331063469639048, 0.054472355550387874, 0.0484577792667551, 0.05970429629087448, 0.03592441527871415, 0.028636319148063194, 0.03605178637371864, 0.10543755124672316, 0.03297428920632228, 0.09464337694225833, 0.030400558171095327, 0.013115082529111532, 0.013422937445284333, 0.029820040981576312, 0.040445693957735784, 0.02869253497919999, 0.057987196632893756, 0.039845270512159914, 0.026674275504774414, 0.04741037882922683, 0.09467963085626252, 0.04990860747057013, 0.06587622643564828, 0.03572537869331427, 0.15002236235886812, 0.18994492013007402, 0.1483151110005565, 0.183182604087051, 0.16102238616440445, 0.121587560424814, 0.16433655051514506, 0.20190730167087168, 0.13598266494227573, 0.1274590691900812, 0.24565426516346633, 0.10944540845230222, 0.19144999561831355, 0.16856222064234316, 0.17370028712321073, 0.14795729191973805, 0.23231570434290916, 0.13417983980616555, 0.1716477144509554, 0.13880640326533467, 0.1605813278001733, 0.3671973041491583, 99.40439119935036, 159.2740622162819, 119.84534114599228, 141.84385031461716, 99.91830602288246, 139.4887974858284, 157.33811169862747, 115.38949504494667, 79.69053223729134, 69.94503557682037, 112.3501293361187, 72.4858908355236, 61.734261363744736, 6.589124780148268, 0.4595979256555438, 0.3715004544937983, 0.6445291929412633, 0.9068644442595541, 1.7285941005684435, 0.21141874050954357, 4.798996662721038, 10.848806407302618, 6.070567080751061, 25.936110578477383, 108.19420874118805, 107.02581703662872, 105.86863473057747, 109.50525999069214, 109.28892239928246, 112.38652378320694, 111.2405888736248, 107.72354319691658, 108.50113347172737, 109.12976413965225, 107.83780306577682, 107.87629500031471, 100.63854977488518, 102.84820720553398, 102.65403762459755, 103.35566997528076, 104.4369475543499, 99.95489045977592, 86.9915896654129, 80.43064132332802, 76.86935842037201, 76.27487272024155, 81.28156006336212, 86.8359500169754, 95.56324571371078, 94.15858268737793, 90.65436512231827, 95.09768709540367, 101.52182757854462, 97.14878663420677, 99.34263691306114, 96.85112580657005, 91.03438273072243, 94.45651710033417, 93.09970870614052, 93.74522566795349, 96.06767624616623, 96.51859045028687, 91.17969453334808, 99.65500295162201, 99.77227225899696, 98.1283588707447, 67.20737367868423, 87.94567286968231, 102.30928972363472, 83.40256065130234, 90.91883093118668, 93.26300114393234, 89.15093019604683, 83.97849574685097, 84.43733632564545, 87.40239322185516, 90.44143214821815, 87.55652815103531, 83.57915997505188, 83.3519321680069, 87.01346129179001, 85.17350882291794, 89.47686150670052, 77.93497323989868, 81.5917906165123, 74.60440635681152, 74.86654669046402, 76.44672229886055, 78.53142723441124, 71.4181861281395, 77.93878823518753, 85.0246100127697, 91.35010778903961, 93.78323122859001, 91.76952168345451, 95.47391250729561, 98.25350895524025, 95.70133790373802, 102.99184709787369, 93.98237094283104, 98.80461618304253, 94.38437417149544, 96.18470996618271, 105.0739985704422, 89.93674322962761, 6.160500179976225, 3.504857593216002, 1.0237796581350267, 0.19510271289618686, 0.6924184982199222, 0.2618238818831742, 0.12107783855753951, 0.29184803017415106, 1.3323740428313613, 31.47278968244791, 47.566542997956276, 78.34978178143501, 104.523985683918, 77.74571299552917, 62.50446103513241, 80.551877617836, 40.8702003210783, 57.32406981289387, 82.69149720668793, 107.65900745987892, 98.88581022620201, 116.21177852153778, 8.420660700649023, 0.5793300352524966, 0.3661061392631382, 0.1659573713550344, 0.2490657102316618, 0.14454603980993852, 0.15183323237579316, 0.11088340863352641, 0.1401185945724137, 0.12218520452734083, 0.16542547411518171, 0.07736863553873263, 0.13755101594142616, 0.17690591979771852, 0.16716319805709645, 0.05399610454333015, 0.14798022428294644, 0.19222251197788864, 0.12692246673395857, 0.2440010421560146, 0.15553374396404251, 0.16073012840934098, 0.10108587928698398, 0.26368726626969874, 0.12178192890132777, 0.1610036988859065, 0.22213196876691654], [0.05395065913035069, 0.01374097369989613, 0.04912773823889438, 0.011632553487288533, 0.07121263930457644, 0.05897608985833358, 0.03529700363287702, 0.10238673057756387, 0.022006448634783737, 0.07233642158098519, 0.024495133257005364, 0.015136532310862094, 0.01776088338374393, 0.04936617173370905, 0.039885532023618, 0.10107991984114051, 0.022496761484944727, 0.10215893576969393, 0.07825644453987479, 0.13160377100575715, 0.3165678115328774, 20.689642801880836, 118.02292093634605, 96.55667960643768, 103.1179091334343, 71.05902940034866, 69.85007107257843, 50.49145504832268, 111.7105932533741, 80.81192046403885, 121.10438838601112, 87.39284813404083, 61.93658910691738, 37.34477989375591, 0.4899446410126984, 0.5808820738457143, 0.08272025501355529, 0.2019836092949845, 0.01842574194597546, 0.18632733612321317, 0.13067020860034972, 1.1737050069496036, 0.16875986941158772, 2.087491136044264, 25.578910745680332, 126.4071786403656, 105.92339739203453, 103.9786921441555, 103.36720615625381, 99.60814386606216, 102.92279720306396, 99.44271594285965, 97.44788378477097, 96.82328850030899, 91.64644628763199, 91.72961622476578, 87.33411088585854, 94.25474032759666, 92.79536783695221, 94.93197798728943, 92.86722958087921, 93.5671216249466, 96.10389590263367, 92.81035423278809, 81.55683249235153, 69.3875902891159, 67.6417587697506, 68.70665162801743, 74.64342266321182, 72.85527661442757, 77.59364515542984, 73.60695227980614, 78.69199141860008, 86.86311855912209, 90.3694336116314, 90.01387149095535, 88.93850639462471, 90.0486472249031, 83.2531450688839, 82.31205716729164, 78.11496958136559, 79.83690798282623, 80.23653253912926, 83.86573299765587, 82.97544077038765, 84.03518110513687, 80.46395033597946, 91.49966016411781, 72.15898677706718, 75.45828893780708, 87.74832665920258, 71.4351636171341, 80.16907095909119, 81.58808201551437, 80.95241412520409, 76.46250665187836, 73.10537159442902, 79.94239792227745, 79.64573264122009, 77.3177495598793, 76.26210540533066, 71.74759805202484, 74.587831646204, 76.59809857606888, 74.34804931282997, 71.87744468450546, 69.86032292246819, 66.58979281783104, 67.40819290280342, 63.50686624646187, 65.20330801606178, 69.55215945839882, 67.08465546369553, 72.0393767952919, 76.06081500649452, 80.32894358038902, 86.08955606818199, 83.37869793176651, 85.66390290856361, 88.96519616246223, 87.7272529900074, 88.22121128439903, 87.55157321691513, 84.18637499213219, 86.63469761610031, 87.53073513507843, 97.47971847653389, 63.5254130512476, 0.7646476349327713, 0.8182730292901397, 1.197164235636592, 0.2528621518285945, 0.3048586507793516, 0.08118570884107612, 0.10597952685202472, 0.0561862231552368, 1.1591036967001855, 17.00355939567089, 22.940917499363422, 64.8496761918068, 85.4414476454258, 55.40250152349472, 56.45839266479015, 52.70164065063, 28.67454383522272, 40.703013092279434, 63.106360137462616, 70.94703420996666, 78.84894579648972, 39.86890845000744, 1.1052665230818093, 0.023542946655652486, 0.05811921728309244, 0.06994562994805165, 0.03769370276131667, 0.05772238349891268, 0.03929950995370746, 0.058900620861095376, 0.037480383543879725, 0.03362658877449576, 0.026749377138912678, 0.0206926839746302, 0.020024712102895137, 0.05244844462140463, 0.06325191803625785, 0.04004717920906842, 0.028582557970366906, 0.06140125035017263, 0.10581352325971238, 0.006961473227420356, 0.06529319522087462, 0.030817151637165807, 0.06487028978881426, 0.086731110495748, 0.021264748102112208, 0.1072670565918088, 0.01667973934672773, 0.02972901100292802, 0.09444984709261917, 0.019523113041941542, 0.03570454289729241, 0.011574768013815628, 0.06504157005110756, 0.03058798571146326, 0.029939688174636103, 0.00142522167379866, 0.03220548358513042, 0.01043197469698498, 0.06277952619711868, 0.02748598653852241, 0.04651629496947862, 0.18283901939867064, 0.06227270612725988, 0.0483168417122215, 0.10038507665740326, 0.16825354658067226, 0.4114228341495618, 29.85003925859928, 141.1096841096878, 104.35915052890778, 121.83502838015556, 85.063117146492, 92.22671315073967, 87.88312062621117, 150.0268480181694, 62.143529802560806, 85.9631596505642, 84.69878509640694, 67.55029767751694, 48.39648686349392, 0.11497776315081865, 1.223040847107768, 0.020783478321391158, 0.13834643497830257, 0.03256503558077384, 0.9386111469939351, 0.17153272608993575, 1.7769593303091824, 0.5711852910462767, 2.245997730642557, 32.043190374970436, 133.8332113623619, 107.40116089582443, 109.38692674040794, 104.93801906704903, 104.91952165961266, 103.85278970003128, 103.44947934150696, 100.77562361955643, 103.0653503537178, 94.16659265756607, 97.00045019388199, 90.37427455186844, 99.04192864894867, 95.60059770941734, 98.54838073253632, 96.10261157155037, 95.15453964471817, 98.24230715632439, 97.49633118510246, 85.73218524456024, 72.64430433511734, 72.31287091970444, 72.57882624864578, 78.1296443939209, 78.64513233304024, 79.41513821482658, 80.89376047253609, 81.78669735789299, 91.02293774485588, 94.9678860604763, 92.99445435404778, 91.38692021369934, 93.71668919920921, 85.77054038643837, 87.14400708675385, 80.78292801976204, 83.36460828781128, 83.78298103809357, 87.7388347685337, 87.35046520829201, 89.2076763510704, 84.58306610584259, 97.43206903338432, 75.58791518211365, 78.18734809756279, 91.68192118406296, 75.83092734217644, 83.17594081163406, 84.58212375640869, 85.06662055850029, 80.15805155038834, 76.92482024431229, 82.69466623663902, 82.81362265348434, 82.33895972371101, 79.68974187970161, 75.72317272424698, 79.82404947280884, 78.98723557591438, 77.7368138730526, 76.74384355545044, 72.07761034369469, 69.89067569375038, 70.89760646224022, 67.44544610381126, 68.17143514752388, 72.84075379371643, 70.62235683202744, 76.40671044588089, 80.76620131731033, 83.9560541510582, 88.30869019031525, 88.3248621225357, 89.04839649796486, 94.40255999565125, 92.74614527821541, 93.07690232992172, 90.67469403147697, 88.20564731955528, 89.07250240445137, 91.55279651284218, 98.76905769109726, 74.97765272855759, 2.9855453968048096, 0.19050286675337702, 2.4298850633203983, 0.39663613541051745, 0.5409789900295436, 0.08466755403787829, 0.06960211947443895, 0.10422480772831477, 0.6277812947519124, 21.409329883754253, 26.76437683403492, 69.7696901857853, 93.14079970121384, 66.9352474808693, 33.543623462319374, 16.86830185353756, 39.5745762437582, 57.42009066045284, 70.92472180724144, 80.38796201348305, 89.68246087431908, 62.89183124899864, 2.1261832723394036, 0.07025648592389189, 0.03228181347367354, 0.09104550437768921, 0.016986468981485814, 0.02218113535491284, 0.01795816293451935, 0.02542147456551902, 0.021456871581904124, 0.03132105135591701, 0.0314248963695718, 0.018628767575137317, 0.06109990499680862, 0.04087233610334806, 0.0527688334841514, 0.01068395331458305, 0.03928501952032093, 0.08730814515729435, 0.057738699615583755, 0.019724995763681363, 0.04391960188513622, 0.05276679999951739, 0.08627750983578153, 0.019741452888411004, 0.040393457893515006, 0.11510077412822284, 0.14105433889199048, 0.0873075588606298, 0.28544365195557475, 0.12235183894517832, 0.1683611876796931, 0.121947205188917, 0.11553480435395613, 0.17369849112583324, 0.1758833887288347, 0.17376513598719612, 0.13569391012424603, 0.13226509880041704, 0.11364252073690295, 0.2222145994892344, 0.16425869922386482, 0.2008178734104149, 0.17041849525412545, 0.20119457272812724, 0.1919274340616539, 0.23734894988592714, 0.5889781925361603, 39.44669030606747, 165.8705386519432, 116.5433107316494, 137.79094219207764, 95.59202536940575, 104.49285015463829, 64.89756122231483, 120.32580256462097, 90.73387205600739, 172.4261748790741, 123.42726454138756, 85.75182259082794, 61.54924549162388, 1.0471510165371, 1.918596492614597, 0.12306633419939317, 0.43472057150211185, 0.15223636699374765, 2.8783930465579033, 0.2537206979468465, 3.108025174587965, 6.028195079416037, 7.8718362003564835, 29.178907871246338, 136.48040771484375, 108.72348234057426, 110.65997242927551, 105.98617002367973, 106.00104242563248, 107.08757892251015, 106.52068734169006, 105.30676648020744, 106.82973995804787, 101.24779388308525, 100.60505837202072, 91.86928153038025, 103.1930311024189, 101.52964755892754, 104.15162086486816, 99.84532713890076, 97.14833065867424, 103.32195818424225, 106.3793957233429, 89.93499532341957, 76.92760169506073, 75.6219157576561, 76.85115739703178, 82.26345017552376, 82.56013825535774, 84.96901139616966, 88.01856815814972, 85.78783705830574, 97.04528778791428, 99.18159395456314, 96.75952792167664, 96.7272524535656, 99.71393778920174, 88.68155658245087, 91.96827381849289, 85.48877790570259, 86.87594667077065, 89.45594742894173, 93.22084620594978, 93.0401811003685, 96.02793037891388, 89.09245133399963, 101.10511913895607, 81.28374114632607, 84.43123385310173, 95.62776625156403, 78.31321254372597, 88.62681671977043, 91.41777455806732, 88.41202944517136, 84.00019258260727, 80.74451208114624, 87.02377393841743, 86.4611305296421, 86.52868330478668, 83.52413132786751, 80.31190529465675, 83.97053137421608, 85.96644267439842, 82.8119583427906, 82.15320289134979, 76.79564237594604, 76.41232654452324, 75.15855342149734, 70.47718182206154, 73.06184872984886, 78.74006643891335, 75.7688918709755, 81.82213425636292, 84.33788046240807, 90.88301405310631, 94.52897161245346, 90.52376613020897, 94.23305869102478, 98.23106735944748, 96.82358488440514, 96.5045540034771, 94.10254329442978, 93.0712178349495, 94.96190518140793, 98.04471775889397, 105.6668047606945, 74.93688851594925, 2.3835992719978094, 5.065538585186005, 4.838279904797673, 0.3746467153541744, 0.9655532450415194, 0.21412257745396346, 0.28231944772414863, 0.21443650592118502, 3.0625328281894326, 35.84793761372566, 39.56117816269398, 81.75613179802895, 100.9534464776516, 79.82374548912048, 77.00804337859154, 67.78423592448235, 41.96537755429745, 57.75629661977291, 81.51403918862343, 92.94951796531677, 103.67398649454117, 74.48360323905945, 2.189905853010714, 0.17851114069344476, 0.12883665855042636, 0.13499369379132986, 0.1463352984865196, 0.111990893346956, 0.16082160553196445, 0.12585401156684384, 0.10245803612633608, 0.13837675913237035, 0.15710507839685306, 0.08441802914603613, 0.1986105035757646, 0.16433453187346458, 0.15547229413641617, 0.15603887935867533, 0.0898920584586449, 0.1531419949606061, 0.1335803625988774, 0.07175971346441656, 0.16446850437205285, 0.15425437042722479, 0.20973798382328823, 0.09326782106654719, 0.1333992785657756, 0.18168153619626537], [0.065384293848183, 0.08589612756622955, 0.017238548716704827, 0.031985347741283476, 0.028305328705755528, 0.042303987211198546, 0.018922541166830342, 0.11369427069439553, 0.04703222861280665, 0.03864909915137105, 0.0275607504954678, 0.039629368620808236, 0.01705038645013701, 0.08222565811593086, 0.04760367490234785, 0.11629995118710212, 0.04957609562552534, 0.04353217111201957, 0.06791745909140445, 0.09090403618756682, 0.6574494496453553, 56.547756269574165, 110.19651889801025, 97.46787071228027, 77.1420393884182, 58.61534312367439, 28.240960501134396, 6.154530700296164, 20.830455645918846, 122.33302965760231, 73.3590079843998, 56.02672062814236, 37.32016861438751, 0.22629911312833428, 0.049036027339752764, 0.2695291262352839, 0.19122579280519858, 0.14012704021297395, 0.29869983438402414, 0.1658140477957204, 0.38283637433778495, 0.6577089638449252, 2.2045690286904573, 16.610157005488873, 133.03422063589096, 99.85620975494385, 106.73894003033638, 101.65823265910149, 108.87099042534828, 105.98930105566978, 101.08678132295609, 108.02899360656738, 101.5348456799984, 90.72403058409691, 86.0965932905674, 85.39046958088875, 84.6767158806324, 83.5684521496296, 87.11848005652428, 88.75203520059586, 93.6042608320713, 95.41459769010544, 90.85368722677231, 95.82370653748512, 82.82552361488342, 68.03725674748421, 68.00838589668274, 68.47569242119789, 73.0671988427639, 73.97048637270927, 71.58389523625374, 70.64751148223877, 81.56035870313644, 86.78142294287682, 92.64539748430252, 90.11369213461876, 90.57450860738754, 83.08298259973526, 79.66161578893661, 78.34339812397957, 78.87078702449799, 76.83041051030159, 77.32582792639732, 79.68603327870369, 79.57209259271622, 81.76482573151588, 83.18299323320389, 89.16606858372688, 73.08036893606186, 71.349326223135, 93.91246989369392, 73.43380317091942, 75.46875357627869, 84.46676194667816, 80.95793142914772, 76.11743196845055, 74.00717720389366, 72.16695874929428, 74.71731349825859, 72.58828774094582, 71.18740171194077, 70.39944559335709, 71.12142965197563, 73.14065650105476, 74.89657267928123, 71.40358731150627, 68.53918701410294, 64.71961677074432, 62.4760727584362, 65.53936198353767, 66.12739562988281, 64.80291590094566, 66.98115661740303, 66.29356071352959, 75.74177652597427, 77.7312433719635, 80.1956695318222, 83.32724869251251, 84.8253259062767, 84.54604849219322, 89.36160609126091, 86.60239934921265, 88.93544375896454, 86.79086163640022, 80.16465559601784, 85.67895010113716, 86.60521879792213, 100.34919530153275, 44.614276215434074, 0.5377352703362703, 8.608559668064117, 2.702010073699057, 0.18660904053831473, 0.20180736406473443, 0.03661872040538583, 0.05290512890496757, 0.14595237997127697, 0.599850834114477, 8.518081773072481, 35.46249769628048, 52.077364549040794, 47.760598585009575, 72.45551526546478, 105.55130615830421, 28.958052322268486, 20.829718485474586, 46.14255040884018, 59.05725181102753, 71.42621889710426, 80.80270975828171, 22.586791701614857, 0.8386858901940286, 0.2889478061115369, 0.0853389898838941, 0.05718264546885621, 0.02258777847600868, 0.03380864131031558, 0.08494117646478117, 0.1220389865920879, 0.03174119599862024, 0.05385521151765715, 0.06217021553311497, 0.014050876943656476, 0.10507872284506448, 0.015773090926813893, 0.08242001917096786, 0.08167266903910786, 0.06165737664559856, 0.0026679336951929145, 0.04002368281362578, 0.0819363615300972, 0.11533685130416416, 0.024538790094084106, 0.1419863131013699, 0.03514738295052666, 0.06096130149671808, 0.08342720262589864, 0.060434064944274724, 0.08251759674749337, 0.05187776645470876, 0.057981148129329085, 0.022771203985030297, 0.004258779190422501, 0.026132136626983993, 0.0733337047859095, 0.05060015922936145, 0.01015156996800215, 0.031107622671697754, 0.048717575482442044, 0.05949298829364125, 0.034422601529513486, 0.10629525873810053, 0.06163531630591024, 0.038480587099911645, 0.09658593364292756, 0.26460666849743575, 0.8156147156842053, 78.13098952174187, 122.62841820716858, 112.25693553686142, 85.78263893723488, 76.71507149934769, 48.12096364796162, 17.042032331228256, 22.748606018722057, 71.50821849703789, 77.30312034487724, 63.791584968566895, 47.86647230386734, 0.43626952276099473, 0.14965912560001016, 0.1136719246278517, 0.35768727539107203, 0.1256470859516412, 0.29421061277389526, 0.047270691793528385, 0.36745156394317746, 1.063220591749996, 1.9399338914081454, 22.656850442290306, 138.4745255112648, 100.70826843380928, 114.80225175619125, 105.93390002846718, 112.24416822195053, 108.5493528842926, 103.80971521139145, 109.27167892456055, 106.44792884588242, 94.17035445570946, 87.94631123542786, 88.42229649424553, 88.74371364712715, 85.37785425782204, 90.51494300365448, 91.41949966549873, 98.32496032118797, 98.31191182136536, 97.62924805283546, 98.76967325806618, 87.71411329507828, 71.49180337786674, 72.71849155426025, 71.41411274671555, 75.21284490823746, 78.74796241521835, 75.11129155755043, 73.65329459309578, 85.53546220064163, 90.5977937579155, 96.33975684642792, 94.26975712180138, 94.46714892983437, 89.14099752902985, 82.84750163555145, 81.9708126783371, 80.35064801573753, 81.21541321277618, 82.00808107852936, 82.08856076002121, 83.06774541735649, 85.54309219121933, 88.06051790714264, 93.01276937127113, 76.58773273229599, 74.64335426688194, 100.18630564212799, 77.78858229517937, 80.00707805156708, 87.04411044716835, 84.23062741756439, 79.83538046479225, 76.83503106236458, 75.47646716237068, 79.45495247840881, 76.39178484678268, 77.0148754119873, 75.72023928165436, 75.39104014635086, 76.22875839471817, 78.71691048145294, 75.63910603523254, 72.66183659434319, 67.49360471963882, 66.18918791413307, 68.48434075713158, 69.25305470824242, 69.09183695912361, 69.2136812210083, 70.91608867049217, 79.1653624176979, 80.42991176247597, 84.34361055493355, 87.70874038338661, 90.41571512818336, 88.76696079969406, 94.15863588452339, 90.34655123949051, 93.42131584882736, 91.59790009260178, 83.16685169935226, 88.3370366692543, 89.21262368559837, 102.63655856251717, 57.145893573760986, 1.5377665590494871, 2.2171121556311846, 1.445816361811012, 0.520520769059658, 0.23550293175503612, 0.05369951635657344, 0.023677819008298684, 0.23644122906262055, 0.21997828589519486, 10.603181887418032, 43.350046053528786, 53.24656940996647, 53.51407125592232, 74.94611442089081, 74.99500259757042, 40.32055601477623, 35.56939356029034, 58.712082132697105, 66.49014696478844, 80.49224361777306, 94.1136234998703, 39.42984580993652, 0.8164938341360539, 0.32392902590800077, 0.14030646183528006, 0.11569017297006212, 0.10969103706884198, 0.026955671928590164, 0.0983854265359696, 0.07371389961917885, 0.03261815108999144, 0.032704956392990425, 0.03547597996657714, 0.0829117588000372, 0.026448580974829383, 0.01472150199333555, 0.027582354414334986, 0.05778442333394196, 0.036893203723593615, 0.052542203848133795, 0.058477518759900704, 0.05935432913247496, 0.02459898383676773, 0.06447899984777905, 0.04312905133701861, 0.013462789847835666, 0.08506633224897087, 0.17583789507625625, 0.24503792636096478, 0.11420580340200104, 0.13740366994170472, 0.13070033979602158, 0.1312659602263011, 0.06335811936878599, 0.14785371778998524, 0.13100322510581464, 0.14381241198861971, 0.09942074480932206, 0.1951025050948374, 0.16041962866438553, 0.1975630215019919, 0.10016404281486757, 0.1710212675970979, 0.1559027101029642, 0.16783855244284496, 0.23226247751154006, 0.33256136113777757, 1.7994455737061799, 105.40138140320778, 141.49939119815826, 131.14576756954193, 105.08062541484833, 86.7214697599411, 42.41534560918808, 17.213843911886215, 32.97934994101524, 168.30325931310654, 96.00782185792923, 73.29422146081924, 64.04988750815392, 1.1443360266275704, 0.3200150281190872, 0.4627324308967218, 0.6089714134577662, 0.24989068158902228, 0.7705122046172619, 0.2708218287443742, 1.5355788264423609, 4.3808989226818085, 10.411506872624159, 20.022594295442104, 144.532890021801, 103.6984495818615, 118.44139248132706, 109.99009117484093, 116.18886575102806, 111.8628890812397, 109.94923576712608, 115.10813534259796, 111.48011282086372, 96.86516225337982, 91.05670273303986, 93.22370365262032, 94.52778607606888, 89.47825223207474, 94.17533218860626, 96.10793128609657, 103.46628203988075, 103.23529243469238, 101.97065189480782, 101.97932302951813, 92.84651309251785, 75.51159247756004, 75.6489247083664, 74.40240919589996, 80.82394301891327, 83.87574166059494, 78.90658870339394, 76.53291687369347, 90.26169419288635, 95.12090384960175, 99.1825819015503, 98.39037761092186, 100.83509802818298, 92.19245418906212, 88.71140018105507, 87.9600740969181, 87.44085475802422, 85.93817979097366, 88.36069419980049, 87.57868096232414, 87.36099824309349, 90.8379028737545, 92.20332160592079, 96.45497426390648, 81.82113111019135, 78.9498683810234, 104.99642953276634, 81.23802959918976, 84.20275211334229, 94.89014223217964, 88.4516005218029, 84.2109140753746, 81.37485265731812, 79.83982622623444, 82.48171806335449, 79.86271619796753, 80.02898007631302, 79.63084504008293, 78.62209796905518, 79.32943761348724, 84.96954336762428, 81.06019154191017, 76.7444971203804, 71.76559388637543, 70.25669485330582, 73.50053519010544, 73.49368795752525, 72.36932829022408, 74.75743934512138, 75.08482977747917, 85.39254426956177, 84.89737764000893, 88.3204011619091, 92.36018478870392, 94.57054138183594, 90.9414929151535, 99.56620171666145, 93.94805118441582, 100.12117713689804, 94.7160355746746, 89.86018493771553, 93.72987449169159, 96.7348824441433, 108.24342370033264, 54.68718610703945, 2.0618826476857066, 20.52948709577322, 6.521636601537466, 0.5356319050770253, 0.6720869767013937, 0.20987658732337877, 0.14445000590058044, 0.3878689667908475, 1.3226283970288932, 19.915833324193954, 59.536816477775574, 66.81445196270943, 63.66912133991718, 105.47607019543648, 148.10726702213287, 39.483080953359604, 32.67836429178715, 62.80972145497799, 81.13837614655495, 91.95464015007019, 108.80354404449463, 44.7431842982769, 1.0212061274796724, 0.4263112071203068, 0.2350637732888572, 0.3454347437946126, 0.15929996530758217, 0.15789215569384396, 0.20914480002829805, 0.2570409479085356, 0.06312887737294659, 0.1179865411540959, 0.1614108114154078, 0.1917167383362539, 0.20288518513552845, 0.09016732103191316, 0.18250821449328214, 0.1584097888553515, 0.12049381286487915, 0.1477536465972662, 0.2337883776635863, 0.11488065312732942, 0.23038951941998675, 0.12097942977561615, 0.3062499104999006, 0.09679047696408816, 0.17461523646488786], [0.005559062738029752, 0.013191434682084946, 0.055435470276279375, 0.010929383406619309, 0.033771511662052944, 0.029551053266914096, 0.1149511719995644, 0.034604513057274744, 0.1251986061106436, 0.017820676366682164, 0.06284741044510156, 0.04594153127982281, 0.08564822055632249, 0.052566728118108585, 0.09492946745012887, 0.09976053712307476, 0.050148658847319894, 0.06284541406785138, 0.09826618566876277, 0.054227239015745, 12.707396876066923, 91.24687492847443, 92.42438614368439, 84.91258442401886, 73.15865993499756, 38.37080463767052, 36.770509108901024, 99.32340234518051, 120.34211128950119, 103.59473034739494, 100.54993852972984, 54.56354074180126, 2.264857543632388, 0.08078805869445205, 0.16429684561444446, 0.11416359746363014, 0.13448563433485106, 0.09416895903996192, 0.10405697103124112, 0.5908427643589675, 0.993933625286445, 1.9924739096313715, 4.08760073594749, 116.38922899961472, 98.06886166334152, 111.25265702605247, 105.48969626426697, 106.17914646863937, 101.3042664527893, 102.75497540831566, 98.70782017707825, 101.63752377033234, 95.89933767914772, 97.89749845862389, 95.11917114257812, 86.58422872424126, 78.97949159145355, 81.04012861847878, 77.84373253583908, 84.72545966506004, 88.74087899923325, 91.44422113895416, 93.3050648868084, 88.73922228813171, 73.8568876683712, 65.32153487205505, 67.30302974581718, 68.85767832398415, 70.86207076907158, 72.61763736605644, 68.92105132341385, 67.89094939827919, 75.13169646263123, 82.39020377397537, 87.72805094718933, 78.27617973089218, 75.63104286789894, 69.44412365555763, 67.37252801656723, 64.53276559710503, 62.981460839509964, 68.12421128153801, 69.71028417348862, 75.74388161301613, 78.10410976409912, 83.50968450307846, 80.70557937026024, 89.59334045648575, 72.60186821222305, 61.690054535865784, 93.94225269556046, 71.57984465360641, 71.91720575094223, 75.37381187081337, 83.10054525732994, 78.68309989571571, 73.51561278104782, 65.60665637254715, 73.44367504119873, 72.19345092773438, 72.4258540570736, 66.82439222931862, 69.06620353460312, 66.15271747112274, 71.99748024344444, 65.79373553395271, 66.30784794688225, 63.00192654132843, 63.9720144867897, 62.783590257167816, 64.49965417385101, 64.11904379725456, 64.70028340816498, 63.23676533997059, 69.93612885475159, 75.88154822587967, 79.13012310862541, 79.56434100866318, 81.15002632141113, 84.5124126970768, 87.14326992630959, 84.34833750128746, 89.72162917256355, 84.70310926437378, 82.46728643774986, 76.04705214500427, 87.78709217905998, 83.77874046564102, 99.19977217912674, 29.003011509776115, 0.9464048256631941, 1.6535045485943556, 0.18952948070364073, 0.11439427180448547, 0.23179501353297383, 0.04341036983532831, 0.10610459357849322, 0.1380745120695792, 0.20363134040962905, 3.9564619353041053, 30.5193904414773, 67.3473733663559, 78.70155930519104, 41.26301944255829, 43.67273613810539, 25.901175253093243, 22.50414803624153, 56.09504856169224, 68.66644218564034, 74.07184973359108, 67.30622917413712, 6.678040958940983, 0.6065103330183774, 0.1104564659181051, 0.15013156196800992, 0.06102367158746347, 0.1285604905569926, 0.04422900696226861, 0.02970001158246305, 0.006074699986129417, 0.038076814234955236, 0.0949530083744321, 0.029079448104312178, 0.06233935841009952, 0.04604892004863359, 0.049220970540773124, 0.028782533372577745, 0.061147858868935145, 0.056218792306026444, 0.06427308355341665, 0.06222085597983096, 0.07220180341391824, 0.031220238015521318, 0.08635841877548955, 0.03753221142687835, 0.03965733645600267, 0.17095437040552497, 0.06819275877205655, 0.05965964497590903, 0.02730073163547786, 0.03403999471629504, 0.03617350972490385, 0.01212209914228879, 0.027223314500588458, 0.0508191447443096, 0.008810770723357564, 0.031515690716332756, 0.059398138109827414, 0.10359472435084172, 0.04220691800583154, 0.07725043367827311, 0.06340806590742432, 0.07136211526812986, 0.09815165743930265, 0.13509734213585034, 0.11496162143885158, 20.070872604846954, 118.77832800149918, 106.09031483530998, 99.2487895488739, 85.97449064254761, 54.880747720599174, 42.506624311208725, 57.14604936540127, 102.46481537818909, 111.3392923772335, 91.54771238565445, 64.92907673120499, 2.1564752468839288, 0.07758978812489659, 0.029391326388577, 0.1695987189305015, 0.13269563351059332, 0.1343555803759955, 0.12577803048770875, 0.942090394673869, 1.6434808052144945, 1.981736517045647, 6.931147277355194, 124.70813021063805, 98.83260548114777, 116.59751862287521, 107.11041569709778, 108.55825200676918, 105.71084439754486, 107.88546770811081, 101.79631724953651, 105.69297015666962, 99.26325917243958, 101.64201512932777, 99.19721871614456, 91.52395606040955, 82.75379866361618, 84.7481520473957, 81.53255179524422, 87.55774408578873, 92.38926842808723, 95.49599692225456, 98.28494846820831, 92.8096778690815, 75.995192527771, 69.00632634758949, 68.96306946873665, 71.92713841795921, 75.33215090632439, 75.96208870410919, 71.86571091413498, 71.95994585752487, 79.40067619085312, 85.52002742886543, 88.87096881866455, 81.7388579249382, 78.10920909047127, 73.278748691082, 70.73176056146622, 66.50045201182365, 66.37282446026802, 71.68430864810944, 72.85143122076988, 79.53304588794708, 81.67092517018318, 86.70410469174385, 83.93574804067612, 95.16638740897179, 77.67256692051888, 66.79185837507248, 95.42497873306274, 76.4693994820118, 75.21505638957024, 80.12367099523544, 87.76269748806953, 81.08090043067932, 77.6301383972168, 67.62943223118782, 77.44378119707108, 75.85429608821869, 74.6939143538475, 71.14199414849281, 71.55089780688286, 71.01443499326706, 73.26757729053497, 70.28788357973099, 69.21266287565231, 66.53363943099976, 66.98331490159035, 65.56637853384018, 67.88222506642342, 67.03851833939552, 70.6324490904808, 65.29840171337128, 73.05713698267937, 78.1926754117012, 84.1947877407074, 84.2818334698677, 83.33832129836082, 88.27763825654984, 88.98501589894295, 88.81039246916771, 93.05553987622261, 87.5664684176445, 88.56430247426033, 78.17982450127602, 90.44536113739014, 89.3872319161892, 103.37507173418999, 40.05224481225014, 2.5184989208355546, 0.2342036389745772, 0.40056132478639483, 0.37989548058249056, 0.1551087011466734, 0.07671636194572784, 0.056136892599170096, 0.017319151520496234, 0.33158413076307625, 3.472568350844085, 35.586439445614815, 67.86196455359459, 87.07016944885254, 53.13656531274319, 42.87119194865227, 37.185944616794586, 36.98021985590458, 60.41097857058048, 78.97336632013321, 83.93982902169228, 90.7651899755001, 13.665608558803797, 0.7722395088057965, 0.18383909307885915, 0.20798388810362667, 0.03880505777487997, 0.05639508948661387, 0.0613814498501597, 0.061742189282085747, 0.04058531420014333, 0.03063623829802964, 0.0699624841217883, 0.012613714461622294, 0.04579635235131718, 0.10250987514154986, 0.10366630449425429, 0.049323850762448274, 0.041910173968062736, 0.07457150320988148, 0.1099219340540003, 0.03317775270261336, 0.0689248503476847, 0.09668260579928756, 0.09208624032908119, 0.06516404668218456, 0.008692781302670483, 0.25974696676712483, 0.19405108963837847, 0.15251219359925017, 0.1091050224204082, 0.11779407999711111, 0.20502591010881588, 0.1782218218431808, 0.16861025243997574, 0.20371968566905707, 0.12959250627318397, 0.12420164202922024, 0.15074904367793351, 0.2485005944618024, 0.20404967421200126, 0.21697666961699724, 0.11071473330957815, 0.14619660592870787, 0.27841355418786407, 0.3048271540319547, 0.28498494531959295, 30.36193449050188, 145.76633423566818, 123.12221691012383, 116.44376367330551, 106.46973967552185, 63.3431102335453, 59.153850227594376, 138.3448764681816, 154.46472108364105, 119.66900780797005, 124.62409391999245, 88.84094282984734, 4.915548283606768, 0.4073543509002775, 0.1993538238457404, 0.40456889255438, 0.5778959090821445, 0.48957190476357937, 0.36756003624759614, 2.34513892326504, 3.647617595270276, 6.578110596165061, 5.861317059025168, 133.2516297698021, 100.64891561865807, 123.19438263773918, 111.52079343795776, 112.84681588411331, 108.19755256175995, 109.89811331033707, 104.24315795302391, 111.65859684348106, 101.8071998655796, 104.78120908141136, 102.83414036035538, 96.19566857814789, 86.95594757795334, 90.640929043293, 87.49807968735695, 93.02991405129433, 97.64087542891502, 100.11369913816452, 101.16145491600037, 98.08225974440575, 81.24334931373596, 70.65750494599342, 73.66389602422714, 75.94099223613739, 77.74198919534683, 79.94931355118752, 76.29415288567543, 75.14883354306221, 83.03163215517998, 90.6816628575325, 95.91256096959114, 86.20613381266594, 85.47724932432175, 78.3196721971035, 75.61838954687119, 71.76826894283295, 72.83829152584076, 78.1447371840477, 80.56231945753098, 84.3000040948391, 87.63930290937424, 91.26782700419426, 87.89177656173706, 100.05790293216705, 83.05117830634117, 71.77616491913795, 99.31169897317886, 81.00605204701424, 81.39102458953857, 84.6044285595417, 90.85618749260902, 84.90049347281456, 82.41039589047432, 71.69284299015999, 82.09150180220604, 80.96224039793015, 81.58811241388321, 75.68490117788315, 76.48334473371506, 74.83727306127548, 79.52430635690689, 76.13678053021431, 75.29155388474464, 71.37852385640144, 70.50344601273537, 69.54954519867897, 72.33829155564308, 73.02151009440422, 75.99097475409508, 68.91583800315857, 78.07365819811821, 82.90040999650955, 89.24798458814621, 89.79672074317932, 88.75527262687683, 94.18502926826477, 94.3669331073761, 91.45173713564873, 97.46479287743568, 92.49032020568848, 92.60197341442108, 85.42100474238396, 96.11553847789764, 94.18759033083916, 109.6950826048851, 35.453241392970085, 3.9709529327228665, 5.779119869694114, 0.5932760587893426, 0.7115660270210356, 0.7034060836303979, 0.48204251972492784, 0.36486336844973266, 0.2813351817894727, 0.37110346485860646, 6.081239283084869, 52.49473035335541, 85.698883831501, 97.26184576749802, 58.46600353717804, 59.732350185513496, 35.87012842297554, 33.6499759554863, 74.1413252055645, 92.16235220432281, 97.01834723353386, 102.95312717556953, 14.38625793904066, 0.93321323976852, 0.291919662267901, 0.3365680086426437, 0.17739115079166368, 0.31044717121403664, 0.17420861375285313, 0.11035791612812318, 0.16494316718308255, 0.15934498398564756, 0.23142811056459323, 0.17416779563063756, 0.14150321949273348, 0.21475739573361352, 0.20115617400733754, 0.13491674792021513, 0.18981545988935977, 0.12663730391068384, 0.2371937668067403, 0.16342826565960422, 0.1847828080644831, 0.1455041821463965, 0.21011481672758237, 0.15953866968629882, 0.07289104338269681], [0.06341964341118, 0.021150672582734842, 0.03875398317177314, 0.03440114975092001, 0.08893429461750202, 0.02364746145758545, 0.003565506576705957, 0.050442026113159955, 0.02694384766073199, 0.0196461759696831, 0.03872813416819554, 0.02683104121388169, 0.03882971563143656, 0.1155358507821802, 0.04500177194131538, 0.06496826812508516, 0.1418347962317057, 0.10516428505070508, 0.11516016820678487, 0.4163518821587786, 58.07060815393925, 105.02536877989769, 87.23128840327263, 73.04965898394585, 51.89827635884285, 31.270555034279823, 67.05570861697197, 84.59485307335854, 41.48456655442715, 87.49227359890938, 70.79730704426765, 6.578324809670448, 0.19550742086721584, 0.03720411907124799, 0.01909361733851256, 0.16032417363021523, 0.05268417669867631, 0.11073572866735049, 0.1299546446534805, 0.09036271367222071, 1.1711846734397113, 0.12940419372171164, 75.12723550200462, 106.62810757756233, 96.3909325003624, 104.68173801898956, 93.81419196724892, 103.6808717250824, 99.17929887771606, 102.95546784996986, 97.0375058054924, 104.98588129878044, 105.35871729254723, 101.59021630883217, 92.93973729014397, 87.2885437309742, 80.0762115418911, 80.86557358503342, 74.10569831728935, 79.13650676608086, 84.3986240029335, 89.15490478277206, 87.24665477871895, 79.26608741283417, 67.19792738556862, 65.91915920376778, 68.59725549817085, 70.25686204433441, 69.40253108739853, 72.13563323020935, 67.4257479608059, 69.07565742731094, 67.68577560782433, 69.31879118084908, 66.2972617149353, 64.78583201766014, 60.34860871732235, 61.52437582612038, 57.68256537616253, 63.90530526638031, 64.58309009671211, 70.04867121577263, 68.82288739085197, 73.5348853468895, 76.65187329053879, 82.27336004376411, 79.42793592810631, 87.6102040708065, 72.78581634163857, 58.00450310111046, 90.7042184472084, 75.75370028614998, 71.61180093884468, 77.82139733433723, 81.04799419641495, 80.5659444630146, 78.40060025453568, 66.5024583041668, 64.1296224296093, 68.0320206284523, 66.47167235612869, 65.204007178545, 64.49729830026627, 65.50321832299232, 68.47259938716888, 66.23047649860382, 63.77611219882965, 63.33908624947071, 64.44470152258873, 62.46479116380215, 61.57727278769016, 62.571747824549675, 63.32375407218933, 64.39723446965218, 62.314414232969284, 69.72992911934853, 73.55780571699142, 77.07425102591515, 78.64316403865814, 82.1086160838604, 84.99223574995995, 86.30472332239151, 86.50913715362549, 90.31793117523193, 79.51818108558655, 75.8148542046547, 76.91950052976608, 88.53689834475517, 85.92729717493057, 85.96683785319328, 13.854944799095392, 0.6310390261933208, 0.7315970084164292, 0.2150099485879764, 0.0951164960861206, 0.04727497769636102, 0.08485264566843398, 0.1354637256008573, 0.04684027953771874, 0.12678521394263953, 0.6112673808820546, 29.096737280488014, 43.884631767868996, 45.299117267131805, 73.86291414499283, 35.031703412532806, 27.948860675096512, 39.469242095947266, 59.57269795238972, 69.95015770196915, 78.34230378270149, 41.59798286855221, 1.9229357410222292, 0.017499526802566834, 0.058245697800884955, 0.059307043193257414, 0.04506489902269095, 0.011565797303774161, 0.05975357489660382, 0.04503011085034814, 0.028788123599952087, 0.03995953898993321, 0.0400757556053577, 0.058378887333674356, 0.034109623011318035, 0.02957788747153245, 0.13360234501305968, 0.033285490280832164, 0.034990938220289536, 0.0773279213171918, 0.13356317445868626, 0.009220038264174946, 0.04985681669495534, 0.034552725992398337, 0.039290808272198774, 0.05357244583137799, 0.07833227718947455, 0.0711236112692859, 0.00959304446951137, 0.034765265954774804, 0.04895376769127324, 0.034373771923128515, 0.008513856919307727, 0.048797482522786595, 0.03317738533951342, 0.046757826930843294, 0.015764624877192546, 0.049758990498958156, 0.06898369523696601, 0.09349109619506635, 0.09297810145653784, 0.06496047557448037, 0.10810908250277862, 0.11035820556571707, 0.08716797572560608, 0.7455297920387238, 78.54344978928566, 121.45165175199509, 101.06987982988358, 85.68347945809364, 73.0749124288559, 43.360605686903, 61.796859204769135, 92.60797709226608, 47.782550007104874, 86.82442143559456, 80.94465494155884, 8.424004521220922, 0.2958097035298124, 0.11894823095644824, 0.135207150306087, 0.10217840972472914, 0.271998014068231, 0.07872259491705336, 0.16520345321623608, 0.11758871289202943, 1.7460878868587315, 0.7773634151089936, 81.94571122527122, 110.0059363245964, 102.63986438512802, 106.10720112919807, 98.13336700201035, 110.03121256828308, 104.49675634503365, 107.51817181706429, 101.77843540906906, 106.95836305618286, 109.27312284708023, 104.25545409321785, 96.21366441249847, 90.71263879537582, 83.82626831531525, 81.84323832392693, 77.48162716627121, 82.62186974287033, 88.54116171598434, 92.51333177089691, 92.11761340498924, 81.39958173036575, 69.40806359052658, 70.15707939863205, 70.19215151667595, 73.30539286136627, 72.24790200591087, 75.28317153453827, 71.68849602341652, 73.4663750231266, 70.46033352613449, 72.98612639307976, 69.28205475211143, 67.713453322649, 64.56039011478424, 65.49574792385101, 62.94900678098202, 68.05356547236443, 69.9276477098465, 72.64382556080818, 73.84971365332603, 77.8217925131321, 81.37052088975906, 86.19221895933151, 85.59437423944473, 92.11333483457565, 75.44896423816681, 60.320125445723534, 95.5412144958973, 79.89711955189705, 73.53928551077843, 82.31232315301895, 84.46797028183937, 83.50126415491104, 80.84291160106659, 70.61472684144974, 66.79747447371483, 71.34134665131569, 69.29288417100906, 68.7856949865818, 69.1110411286354, 68.78732889890671, 71.62017568945885, 68.99002522230148, 68.69046449661255, 67.21735194325447, 66.48144543170929, 67.04028904438019, 65.26375517249107, 66.34993448853493, 67.11563140153885, 68.48216727375984, 66.13215297460556, 72.98057869076729, 74.88872990012169, 80.64176559448242, 82.91977375745773, 86.84804856777191, 86.69541835784912, 89.4067856669426, 89.03597876429558, 92.01833993196487, 82.33265206217766, 78.85892406105995, 80.03781840205193, 91.58482879400253, 89.2565569281578, 93.21406736969948, 20.1580361276865, 0.5324575316626579, 0.2957460569450632, 0.18230085843242705, 0.03451204887824133, 0.024555236086598597, 0.07572166883619502, 0.11188153046532534, 0.09093778164242394, 0.1985116643481888, 0.1228038217232097, 30.289350785315037, 43.52913424372673, 40.924647599458694, 43.211281299591064, 33.22925113141537, 38.48865531384945, 57.25578747689724, 66.58730015158653, 77.72105231881142, 89.42129328846931, 63.72129254043102, 2.4638911010697484, 0.038200144335860386, 0.04550911522528622, 0.08254488551756367, 0.03230156944482587, 0.03208367859770078, 0.09213184530381113, 0.013369231928663794, 0.035868294071406126, 0.03560077580914367, 0.05392491402744781, 0.02573916943219956, 0.05098950845422223, 0.04298994317650795, 0.07314344780752435, 0.013867016350559425, 0.029951289798191283, 0.0844887261337135, 0.12440533930202946, 0.014543371707986807, 0.05092527928354684, 0.03105875224719057, 0.018666713585844263, 0.010336021496186731, 0.1688369785551913, 0.10144426982151344, 0.12909102224512026, 0.12326381969614886, 0.13201610825490206, 0.14433491363888606, 0.0663081934908405, 0.1688841197756119, 0.10614530780003406, 0.11016777047188953, 0.09904224207275547, 0.10182172612985596, 0.20020520081743598, 0.20592721877619624, 0.11315141935483553, 0.1834813630557619, 0.1623394014313817, 0.23885398084530607, 0.19285753805888817, 1.2190744536928833, 102.76000633835793, 143.8243344426155, 120.85576012730598, 105.83711162209511, 77.38262727856636, 46.67576439678669, 93.19340407848358, 108.17749723792076, 59.053151831030846, 106.8015530705452, 101.06245502829552, 10.420401245355606, 0.6397258350625634, 0.3080584650160745, 0.5953880329616368, 0.2815467829350382, 0.6283162941690534, 0.38035549339838326, 0.4758777661481872, 0.8426825038623065, 2.7916947612538934, 1.297960476949811, 82.18513637781143, 111.48634448647499, 105.12730970978737, 113.7982240319252, 101.89885094761848, 113.9451165497303, 108.6230157315731, 110.4009099304676, 104.96802225708961, 109.425388276577, 110.90784832835197, 108.0158843100071, 99.88500460982323, 94.70433980226517, 88.85817110538483, 87.23399385809898, 79.85646933317184, 87.3266252875328, 93.093431442976, 98.3241319656372, 96.64311736822128, 88.62091183662415, 74.0429712831974, 73.73128160834312, 75.18536478281021, 77.47265204787254, 75.70360377430916, 79.09874439239502, 74.47734877467155, 77.73074179887772, 75.21860539913177, 78.80695804953575, 73.37212488055229, 73.07434245944023, 69.49415177106857, 70.9863393008709, 66.75552472472191, 71.94945842027664, 72.2870323061943, 76.94031581282616, 76.63920477032661, 81.72160685062408, 85.65358266234398, 90.96124425530434, 91.0582834482193, 97.96497523784637, 78.10312181711197, 68.71352925896645, 98.1332378089428, 83.5960690677166, 79.626954048872, 87.56641522049904, 89.62581351399422, 89.40461978316307, 85.34888461232185, 74.5461630821228, 72.10042431950569, 74.82791796326637, 73.42437967658043, 73.4301021695137, 70.9715884923935, 72.32840448617935, 75.72646334767342, 73.10692951083183, 72.84859657287598, 71.63003996014595, 71.78980618715286, 72.28978335857391, 68.07891011238098, 69.47490960359573, 69.92257878184319, 73.14419031143188, 69.59097057580948, 76.14748075604439, 79.74244505167007, 86.56076118350029, 87.31596305966377, 90.93907624483109, 90.26992455124855, 93.95450323820114, 92.60228499770164, 96.38428285717964, 88.07389318943024, 83.54391306638718, 85.05074501037598, 97.3664465546608, 95.9874777495861, 98.09964761137962, 20.217147655785084, 2.1396658988669515, 3.992687053978443, 0.6642430694773793, 0.29496513947378844, 0.4019432928180322, 0.3067950624972582, 0.535971571225673, 0.22617651033215225, 0.2607551298569888, 1.0907342028804123, 44.89729642868042, 62.970639020204544, 63.170930072665215, 98.32391157746315, 46.63936994969845, 40.73313407599926, 58.600569516420364, 81.94150105118752, 91.61847218871117, 105.52621230483055, 74.07012462615967, 2.903099083341658, 0.09199244770570658, 0.14328234043205157, 0.1848155664629303, 0.12984866596525535, 0.11301804799586535, 0.17161850351840258, 0.08761972101638094, 0.18127898045349866, 0.21615551289869472, 0.14752931019756943, 0.26407819997984916, 0.1326557801803574, 0.09084074583370239, 0.20545056700939313, 0.1352416750160046, 0.13788894546451047, 0.2999806625302881, 0.20635626919101924, 0.07706790245720185, 0.15939758741296828, 0.13958778086816892, 0.1647541718557477, 0.13141884264769033], [0.0949766680423636, 0.01891900297778193, 0.016966907824098598, 0.0956236946512945, 0.01482527650296106, 0.11222806147998199, 0.027264277341600973, 0.056995242048287764, 0.022668652163702063, 0.00891284849785734, 0.0012815234458685154, 0.008937428428907879, 0.03739301049790811, 0.06776389389415272, 0.010613097692839801, 0.038772347616031766, 0.051601628147182055, 0.05692745056876447, 0.24992764054331928, 5.697055198252201, 79.35776889324188, 86.89446687698364, 73.06185632944107, 57.34387055039406, 33.704468831419945, 36.1166287958622, 67.02454268932343, 45.18012285232544, 137.93267458677292, 107.60463237762451, 13.988563679158688, 0.21245486772386357, 0.05242122264462523, 0.24269086949061602, 0.048844167322386056, 0.03164921792631503, 0.08913448895327747, 0.10160121179069392, 0.06565067291376181, 0.5353438330348581, 1.2929225410334766, 41.30577094852924, 121.3742347061634, 101.16951048374176, 100.44059559702873, 93.5739916563034, 96.90480172634125, 91.64965331554413, 99.21643048524857, 94.77017506957054, 101.01095259189606, 93.67082566022873, 91.48862555623055, 95.17492935061455, 95.7754035294056, 85.9812542796135, 79.84549552202225, 75.61451375484467, 74.82760637998581, 72.50206276774406, 80.20337551832199, 81.16342440247536, 77.24505946040154, 67.04048663377762, 62.03767128288746, 67.71385610103607, 68.0366487801075, 64.75949943065643, 66.89113184809685, 66.39392092823982, 67.82402738928795, 70.57265549898148, 63.675254210829735, 64.05060946941376, 60.894210040569305, 60.773110538721085, 62.24873475730419, 66.07994377613068, 67.3687282204628, 69.27241086959839, 69.45591822266579, 73.22504237294197, 73.28533753752708, 74.98582229018211, 78.91871765255928, 78.92688721418381, 76.21722981333733, 89.79618117213249, 68.0080895125866, 46.89261496067047, 89.01227563619614, 74.76481094956398, 68.125921189785, 66.76712170243263, 79.42406013607979, 78.20706903934479, 76.30556747317314, 70.1046422123909, 67.47110232710838, 63.924912214279175, 62.70512066781521, 61.84172339737415, 63.520515114068985, 63.771681636571884, 67.87831887602806, 64.27012369036674, 64.278574436903, 63.08874808251858, 62.310907021164894, 60.95960833132267, 62.154127433896065, 60.98393842577934, 63.338687270879745, 61.36583313345909, 64.09689858555794, 62.8494331240654, 69.20592203736305, 71.15006491541862, 75.06018429994583, 77.88290083408356, 81.98174849152565, 84.5454253256321, 85.9727655351162, 83.20953860878944, 82.68986329436302, 71.51589408516884, 76.50479078292847, 80.92094421386719, 89.3160693347454, 78.84813264012337, 72.49735862016678, 8.078658152371645, 1.0319936298765242, 0.29343177331611514, 0.18868978513637558, 0.11545807370566763, 0.03859365329844877, 0.09949792074621655, 0.10853805870283395, 0.4315434966702014, 0.2001796560944058, 1.5708023426122963, 17.603896781802177, 28.330092318356037, 77.07271590828896, 56.114735305309296, 26.382727213203907, 16.572575122117996, 66.17233201861382, 65.30568212270737, 66.8707649409771, 70.53834334015846, 16.049548387527466, 0.8186952816322446, 0.06758937044651248, 0.08307091236929409, 0.03576090901333373, 0.05275358234939631, 0.08030533615965396, 0.02154690337192733, 0.052211150323273614, 0.15756595210405067, 0.027600676185102202, 0.1369851134950295, 0.03627621925261337, 0.008543381409253925, 0.021912249685556162, 0.017907207075040787, 0.02858943582396023, 0.03234331525163725, 0.06177846917125862, 0.04827344833756797, 0.045380163355730474, 0.0380204740940826, 0.03517383309372235, 0.04381204242235981, 0.03816306663793512, 0.03665315605758224, 0.060803884553024545, 0.011026753181795357, 0.06332717181066982, 0.0344059106282657, 0.041876261529978365, 0.032932164904195815, 0.05144385497260373, 0.024867555948731024, 0.03524487518006936, 0.03209671442164108, 0.08094081495073624, 0.03273316171544138, 0.015035559408715926, 0.04447767096280586, 0.03967852477217093, 0.12067238101735711, 0.37365992611739784, 7.551835896447301, 104.93541240692139, 103.94739702343941, 89.95399430394173, 72.57805868983269, 49.16852183640003, 48.10048654675484, 60.96789948642254, 46.35681711137295, 109.29469808936119, 116.94903776049614, 19.395781829953194, 0.14779302495298907, 0.03977048058004584, 0.1025988809124101, 0.045710426493315026, 0.27697553916368634, 0.11101130294264294, 0.025984918647736777, 0.03677527645777445, 0.7992725644726306, 1.8215421005152166, 48.14488336443901, 126.26362234354019, 105.88919922709465, 104.38243567943573, 96.96262702345848, 100.20160362124443, 94.79596808552742, 101.0898819565773, 99.13683995604515, 103.05879190564156, 96.36582344770432, 94.25138130784035, 97.96360731124878, 98.82243722677231, 89.81559053063393, 84.2200031876564, 80.57906895875931, 78.03611621260643, 76.32167100906372, 83.79662230610847, 86.96838051080704, 80.54154977202415, 71.23854696750641, 67.38044679164886, 69.76580679416656, 71.26463636755943, 67.05669656395912, 69.85376447439194, 69.53032582998276, 73.10164019465446, 72.56480500102043, 68.66264998912811, 66.89046308398247, 64.63308781385422, 64.03231725096703, 66.37314364314079, 69.51935961842537, 70.38135096430779, 75.19670337438583, 71.06684938073158, 78.1442280113697, 76.80284678936005, 77.98108756542206, 81.45778700709343, 82.68361642956734, 82.21355885267258, 93.79061803221703, 71.10249146819115, 50.17066106200218, 92.0706707239151, 77.88888171315193, 71.08324930071831, 70.72638005018234, 82.33653545379639, 80.94844713807106, 80.39657235145569, 74.91003915667534, 70.46247661113739, 66.5104378759861, 65.42086154222488, 65.39323702454567, 66.06686487793922, 68.18215817213058, 69.80801492929459, 66.33581444621086, 66.27109631896019, 66.07357531785965, 66.79740607738495, 64.16588768362999, 65.32522827386856, 64.95002880692482, 66.83186262845993, 64.57443416118622, 67.65346974134445, 66.32785007357597, 72.38373711705208, 74.09847110509872, 78.16872149705887, 80.13043463230133, 84.86657649278641, 87.73692727088928, 88.42478916049004, 87.06881672143936, 85.65726086497307, 75.35237342119217, 79.67939883470535, 84.88192766904831, 92.92154386639595, 85.08651629090309, 84.89309147000313, 13.616177961230278, 0.7698774605523795, 0.32319976191502064, 0.22856481577036902, 0.12089400857803412, 0.21945002517895773, 0.07574538045446388, 0.4668802348896861, 0.43036573799327016, 0.12997508340049535, 1.2506886385381222, 22.104479782283306, 26.005802638828754, 56.7307810485363, 47.68766529858112, 33.93333055078983, 34.187293723225594, 73.7446340918541, 73.75358641147614, 78.06877166032791, 88.24849382042885, 34.54433016479015, 0.7634178071748465, 0.03127693438727874, 0.1422862891922705, 0.07130666199373081, 0.030287966947071254, 0.15281904197763652, 0.06941738407476805, 0.023192140870378353, 0.06062856700737029, 0.029109096903994214, 0.020664196636062115, 0.0468023112625815, 0.016429884199169464, 0.019283414185338188, 0.0634976802393794, 0.06635091893258505, 0.044120987367932685, 0.036754841421497986, 0.009977025183616206, 0.04149595908529591, 0.047471116195083596, 0.048885041105677374, 0.020946624645148404, 0.25540362170431763, 0.22997961641522124, 0.13303114363225177, 0.1139355577470269, 0.11845224624266848, 0.3038410178851336, 0.1707345462637022, 0.10374403704190627, 0.16725293855415657, 0.1667080685729161, 0.09434595383936539, 0.16145237168530002, 0.33997031045146286, 0.18669829121790826, 0.08832758889184333, 0.11647286417428404, 0.14696532249217853, 0.24917958537116647, 0.6182254012674093, 11.787952613085508, 131.41356199979782, 121.77866220474243, 104.74776327610016, 83.78971427679062, 52.33963407576084, 56.076463758945465, 88.80770221352577, 63.95720288157463, 164.49803709983826, 133.68532329797745, 26.7927423119545, 0.7029160286765546, 0.15621785569237545, 1.0375061840750277, 0.24224133579991758, 0.35113048972561955, 0.2845053101191297, 0.40792449843138456, 0.43393511208705604, 2.145246611908078, 3.6809135461226106, 45.94800464808941, 135.01260727643967, 110.98884478211403, 107.7641174197197, 102.4065189063549, 107.44115754961967, 98.82116049528122, 107.64598175883293, 101.97657957673073, 107.47559890151024, 99.7364629805088, 97.18474790453911, 102.58812636137009, 103.5988949239254, 93.99042651057243, 88.9123485982418, 83.97883772850037, 84.6851134300232, 81.13328441977501, 87.72173568606377, 90.23911580443382, 85.33285707235336, 76.13915920257568, 71.07617408037186, 74.82655003666878, 76.03213414549828, 71.56742691993713, 72.03468784689903, 73.61936241388321, 76.14465370774269, 77.22176671028137, 72.72516399621964, 70.8944222331047, 70.26691630482674, 67.55495622754097, 71.19563207030296, 74.72103729844093, 75.54452911019325, 80.2435165643692, 76.45185962319374, 81.67309865355492, 81.87663853168488, 81.87020927667618, 87.85000160336494, 85.7341231405735, 87.23081722855568, 96.05291023850441, 78.8118901848793, 57.03001879155636, 95.65737426280975, 84.44862172007561, 74.53220263123512, 76.33436992764473, 87.5556617975235, 85.97439184784889, 85.34312412142754, 78.0613848567009, 73.59108433127403, 71.01150915026665, 67.93042168021202, 67.44903311133385, 69.33180168271065, 71.30205675959587, 74.58142518997192, 70.2101169526577, 68.94669994711876, 69.97808620333672, 71.28514766693115, 68.50896343588829, 68.27721387147903, 69.34733524918556, 71.03055372834206, 69.65245887637138, 71.9078278541565, 69.14792954921722, 78.00535306334496, 78.16152468323708, 82.28456944227219, 84.4250325858593, 88.77661988139153, 91.82784855365753, 90.03176853060722, 92.3364132642746, 90.44530034065247, 80.25868535041809, 84.3664625287056, 90.92861160635948, 98.27300950884819, 87.06692442297935, 85.5843123793602, 10.199573244899511, 2.7698509208858013, 1.1285168817266822, 0.6316943722777069, 0.48143657098989934, 0.6335378671064973, 0.5189598246943206, 0.5313523847144097, 0.971442632144317, 0.25431031943298876, 3.0460155894979835, 31.611592434346676, 44.73886393010616, 103.12179252505302, 77.62597382068634, 36.651381701231, 29.1481751203537, 87.29959353804588, 88.61858636140823, 91.59961000084877, 102.43574693799019, 41.11857779324055, 1.2383718369528651, 0.24349825194803998, 0.25555172469466925, 0.19384817162062973, 0.16510185319930315, 0.2974925085436553, 0.17608330846996978, 0.16677024570526555, 0.33325595199130476, 0.18230645422590896, 0.2809837303357199, 0.12629358563572168, 0.13611622183816507, 0.12114079494494945, 0.18387676449492574, 0.21214790060184896, 0.10842078452697024, 0.08714938492630608, 0.11598749959375709, 0.10419558195280842, 0.15590720751788467, 0.22290993249043822, 0.20617168222088367], [0.07522946907556616, 0.1012911499128677, 0.04197027679765597, 0.03720531392900739, 0.012821117834391771, 0.02441499429551186, 0.02876569218642544, 0.05756138198194094, 0.014331591519294307, 0.06850224919617176, 0.019071018941758666, 0.09010603447677568, 0.05962369163171388, 0.06420735895517282, 0.029875943255319726, 0.07445284121786244, 0.05483575187099632, 0.024513429052603897, 0.0609097741835285, 18.352431915700436, 76.31963431835175, 84.50740456581116, 71.44850850105286, 39.07551862299442, 38.65202374756336, 60.4074789583683, 72.96486273407936, 75.35523846745491, 92.19156503677368, 39.70679014921188, 1.011240805964917, 0.15532947523752227, 0.015730458253528923, 0.30435989785473794, 0.11656475689960644, 0.2844967308919877, 0.1145418181840796, 0.2606617973651737, 0.23444339720299467, 2.436839402653277, 12.914212178438902, 127.35895156860352, 97.38417640328407, 101.99861839413643, 95.22952482104301, 91.87849223613739, 85.3565526008606, 90.33776611089706, 88.1064422428608, 93.92503201961517, 94.38612967729568, 95.6139349937439, 96.71501711010933, 97.33097165822983, 94.81207922101021, 89.50102061033249, 80.08780851960182, 76.28605172038078, 72.39110112190247, 71.47614821791649, 71.8303956091404, 77.03832015395164, 68.22897925972939, 65.95264300704002, 63.79410803318024, 67.22673743963242, 65.43175935745239, 65.50801366567612, 69.47306290268898, 66.10927060246468, 66.8128028512001, 66.434715539217, 64.46670234203339, 65.08802220225334, 66.15202590823174, 70.64218416810036, 68.37641134858131, 70.252735465765, 69.36896368861198, 70.55477365851402, 71.49203136563301, 75.2121913433075, 75.69297954440117, 74.61829081177711, 74.23877477645874, 79.22320291399956, 78.74930754303932, 86.26699134707451, 68.0385410785675, 45.102059841156006, 90.64413607120514, 79.24035519361496, 70.73859259486198, 65.59754446148872, 76.7820543050766, 75.52212551236153, 79.45673078298569, 74.73909392952919, 77.86362826824188, 71.95874512195587, 69.12332966923714, 62.8939401358366, 62.58105732500553, 63.5827861726284, 66.91867277026176, 65.03188401460648, 64.76913571357727, 61.212135180830956, 64.266057908535, 62.138084694743156, 60.46648979187012, 61.99454739689827, 62.96534590423107, 59.61098089814186, 61.88157945871353, 61.72596260905266, 62.85496562719345, 65.98953142762184, 75.75322911143303, 76.77675738930702, 84.50356677174568, 80.90634539723396, 84.4463874399662, 83.59136492013931, 79.06462222337723, 69.95327353477478, 72.50168278813362, 80.57067140936852, 87.41465136408806, 84.30765688419342, 85.20047977566719, 62.5718542188406, 2.242159224115312, 0.17099646502174437, 0.11649063118966296, 0.2671835833461955, 0.18619596114149317, 0.13940751319751143, 0.0712240683787968, 0.14153305382933468, 0.2184085248154588, 0.24990050762426108, 5.4580385237932205, 26.65849171578884, 47.471821680665016, 53.69223989546299, 41.37876123189926, 23.700202256441116, 31.952147260308266, 51.71870939433575, 64.81564521789551, 72.52496793866158, 58.38243082165718, 3.1889097718521953, 0.16032919054850936, 0.20209110196447, 0.020987847237847745, 0.07480463405954652, 0.06126910353486892, 0.042543930976535194, 0.02480569608451333, 0.02714548732910771, 0.08300766654429026, 0.026992823841283098, 0.05807791305414867, 0.016290327039314434, 0.02293589397595497, 0.06819946778705344, 0.09587720487616025, 0.03328048449475318, 0.061520509771071374, 0.023963356616150122, 0.028594959258043673, 0.022599938565690536, 0.06458602496422827, 0.013227470590209123, 0.05461850298161153, 0.07085277931764722, 0.01491541775976657, 0.04519833346421365, 0.015407799346576212, 0.06541989467223175, 0.07584497667266987, 0.08416826676693745, 0.011810725518444087, 0.026226025729556568, 0.0384971073071938, 0.05917392787523568, 0.03127148331259377, 0.07384358250419609, 0.041520720842527226, 0.05640411029162351, 0.04483082564547658, 0.09121051349211484, 0.05541974045627285, 24.94186542928219, 103.24953407049179, 97.2440855205059, 84.70324605703354, 48.65768484771252, 46.029483675956726, 50.61203017830849, 56.49322919547558, 67.80993774533272, 110.35766825079918, 47.19756379723549, 1.0864292713813484, 0.2845971880014986, 0.21557432221015915, 0.6142276001628488, 0.14770665380638093, 0.09935873094946146, 0.055890414223540574, 0.3209262964082882, 0.5792038107756525, 2.4272639164701104, 15.80385072156787, 133.09105038642883, 99.62710484862328, 107.01616555452347, 101.7905567586422, 96.15106657147408, 88.54853332042694, 94.27727311849594, 90.9492065012455, 98.81691232323647, 97.04351708292961, 99.90632146596909, 98.91672536730766, 98.88084009289742, 97.20734909176826, 93.39479327201843, 84.38292324542999, 81.02701172232628, 77.92963072657585, 75.80140292644501, 75.47085106372833, 79.82326671481133, 73.7567326426506, 69.06353607773781, 68.23061317205429, 71.5627683699131, 68.37014928460121, 68.68633031845093, 72.93980687856674, 70.399369597435, 69.84372541308403, 68.64525452256203, 66.9750389456749, 69.9180494248867, 69.16837245225906, 74.39167097210884, 73.68743196129799, 72.71277666091919, 73.98788943886757, 73.52853208780289, 77.00866654515266, 79.86636400222778, 79.74561408162117, 77.92050361633301, 79.1205932199955, 83.60711887478828, 83.849728256464, 87.73584052920341, 73.03316786885262, 47.875394225120544, 92.72145420312881, 83.4291972219944, 75.98793491721153, 69.9836415052414, 80.96204280853271, 79.991065710783, 81.62586718797684, 82.21866577863693, 80.83535760641098, 76.56257808208466, 72.58376598358154, 66.57936617732048, 64.75443810224533, 67.49371111392975, 70.71449428796768, 67.09750637412071, 68.3416660130024, 63.82213532924652, 67.76454538106918, 65.26711419224739, 64.22780156135559, 65.22460967302322, 63.38257871568203, 62.916229739785194, 64.99393165111542, 66.44481539726257, 66.15367501974106, 67.84668177366257, 77.97224164009094, 80.34512311220169, 87.50914469361305, 84.84019830822945, 88.87780845165253, 85.36940351128578, 81.53738513588905, 75.10962724685669, 76.2445655465126, 83.08043673634529, 92.2464644908905, 88.27028185129166, 85.32787933945656, 73.28114256262779, 5.134598454460502, 0.34453570609912276, 0.11007974433596246, 0.3006729675689712, 0.17231597390491515, 0.1379005823400803, 0.06476393260527402, 0.31806686078198254, 0.2039810997666791, 0.344356432906352, 4.954863823950291, 32.012172639369965, 39.67867165803909, 30.156135633587837, 38.75471703708172, 29.627762585878372, 55.95145046710968, 60.68607620894909, 74.08113643527031, 77.8633850812912, 82.07314878702164, 7.524170055985451, 0.3367143007926643, 0.2468140935525298, 0.08410510999965481, 0.06415835494408384, 0.030045794883335475, 0.058773019700311124, 0.05815988697577268, 0.03428105170314666, 0.054783107625553384, 0.011609331686486257, 0.05694004110409878, 0.03442474262556061, 0.015614430885761976, 0.02126728810253553, 0.06562932874658145, 0.01125612319810898, 0.05220949533395469, 0.06789547667722218, 0.034554778030724265, 0.04240310845489148, 0.07690832586376928, 0.013836117959726835, 0.1392229410703294, 0.19600416999310255, 0.07072210195474327, 0.11271546696661972, 0.12012055711238645, 0.14201677084201947, 0.23143594764405861, 0.13167831231839955, 0.09445104937185533, 0.15447127050720155, 0.12652854959014803, 0.19003629335202277, 0.1325702402391471, 0.15066360763739794, 0.10680428298655897, 0.19585223752073944, 0.15610812173690647, 0.2007767732720822, 0.19882226799381897, 35.83506390452385, 129.8195931315422, 116.0808527469635, 102.06057026982307, 64.49697151780128, 56.21625445783138, 84.15426671504974, 102.05063000321388, 101.93207636475563, 112.0071293413639, 60.33302575349808, 2.28912684135139, 0.40972601738758385, 0.8064846368506551, 0.7234089227858931, 0.2711731317685917, 0.42613374476786703, 0.40641220926772803, 0.7712121983058751, 1.748581265565008, 4.680207436904311, 18.061443530023098, 142.7316802740097, 102.33874574303627, 111.53535425662994, 108.65589916706085, 103.59916850924492, 92.76741653680801, 97.95806720852852, 94.66008737683296, 104.01056483387947, 103.0572035908699, 103.31864476203918, 104.64865699410439, 101.87798246741295, 103.68874490261078, 99.08974528312683, 89.36668261885643, 85.36696404218674, 81.52029365301132, 80.59416174888611, 80.14124125242233, 84.75107789039612, 77.36709371209145, 72.99987405538559, 71.08502760529518, 75.5267384648323, 72.69380807876587, 73.0654813349247, 74.77231934666634, 73.52959603071213, 73.11000734567642, 72.851871997118, 71.5535044670105, 73.33790391683578, 73.25136736035347, 78.08058902621269, 77.4382334947586, 78.69348853826523, 78.29853013157845, 77.23204135894775, 80.03515854477882, 84.78652998805046, 83.85732024908066, 82.58061915636063, 83.67352411150932, 88.24729308485985, 87.86990493535995, 94.09018635749817, 76.56859695911407, 54.611083790659904, 100.1649659872055, 88.89311403036118, 78.40960577130318, 73.15017119050026, 84.63312461972237, 84.68370750546455, 87.38296866416931, 84.79434236884117, 84.72219184041023, 79.62329864501953, 76.97845816612244, 71.46207377314568, 67.30954259634018, 72.13655278086662, 73.90472710132599, 69.49158310890198, 71.23530194163322, 69.33353438973427, 72.37567394971848, 68.89033377170563, 68.28256398439407, 69.59299206733704, 69.05772998929024, 68.35115790367126, 70.67015066742897, 69.26733434200287, 70.4634265601635, 71.23256608843803, 84.50284481048584, 85.09350031614304, 91.30476862192154, 87.57124856114388, 91.9892942905426, 87.78730496764183, 88.2750391960144, 78.18037167191505, 80.75494632124901, 87.91577607393265, 98.90555396676064, 93.62370818853378, 92.52776339650154, 74.83184695243835, 4.141162661835551, 0.7126820983830839, 0.4369842109736055, 0.6853154324926436, 0.7411009515635669, 0.4957805044250563, 0.4355727945221588, 0.49195764237083495, 0.5604539543855935, 0.4986620263662189, 9.104102477431297, 45.84041342139244, 67.04684749245644, 72.01910108327866, 54.94232341647148, 34.57838013768196, 53.32661971449852, 72.07721516489983, 88.71702387928963, 94.64231193065643, 92.5328779220581, 8.631099108606577, 0.5986224312800914, 0.6891650415491313, 0.1785881756222807, 0.13857140962500125, 0.27167886088136584, 0.19787323923083022, 0.17882386688143015, 0.1367486800882034, 0.2227188739925623, 0.06729294182150625, 0.11789817363023758, 0.0801402676734142, 0.2436838037101552, 0.14993156801210716, 0.1871092926012352, 0.1750715682283044, 0.11371214903192595, 0.13942726916866377, 0.15419336588820443, 0.11860040860483423, 0.1267034441116266, 0.0810873371665366], [0.04701457291957922, 0.05411268852185458, 0.035104984053759836, 0.018337122091907077, 0.04520300899457652, 0.017561644563102163, 0.0424433625448728, 0.052190622518537566, 0.12504754937253892, 0.01271325594643713, 0.04707942178356461, 0.08641886670375243, 0.07380216324236244, 0.0544533157517435, 0.07024765436653979, 0.06022764398949221, 0.03450983356742654, 0.1465014653513208, 0.435003656311892, 22.93350599706173, 86.65002599358559, 71.23055219650269, 57.16280646622181, 36.07094384729862, 39.5335840433836, 76.07476785779, 105.98484769463539, 62.355680018663406, 55.82629278302193, 9.081421494483948, 0.5614530039019883, 0.36397145537193865, 0.2949076675577089, 0.21125932718859985, 0.08684525280841626, 0.18122458102880046, 0.06517815490951762, 0.2952521725092083, 1.0333781805820763, 3.585563600063324, 70.2956959605217, 96.28230392932892, 107.56279662251472, 94.73036840558052, 91.78310215473175, 86.38350829482079, 84.49347451329231, 84.03386637568474, 83.12411159276962, 84.07074719667435, 93.25914815068245, 94.40493866801262, 97.7020825445652, 92.57706955075264, 92.96711102128029, 87.62423291802406, 79.89814549684525, 75.67427694797516, 69.16841045022011, 71.37041509151459, 70.70526838302612, 67.56662920117378, 65.6073023378849, 64.59029451012611, 63.83863404393196, 64.70710784196854, 61.15411229431629, 69.16983157396317, 70.15517190098763, 65.62835320830345, 66.9968193769455, 62.07739815115929, 67.14549019932747, 68.06430369615555, 69.87279385328293, 68.25357154011726, 69.29647117853165, 67.76246309280396, 69.53200533986092, 69.58217024803162, 71.99383243918419, 70.5187439918518, 73.96255239844322, 76.49234265089035, 75.94093143939972, 79.01173666119576, 79.244504570961, 84.336968511343, 74.79309663176537, 43.73981013894081, 82.299153059721, 76.2546806037426, 72.22913861274719, 61.64116635918617, 70.35053461790085, 72.52137333154678, 74.73508134484291, 75.13206884264946, 80.53710401058197, 76.11785754561424, 76.28841519355774, 69.32731792330742, 67.15015634894371, 61.50196462869644, 61.07869394123554, 61.12775690853596, 64.03224885463715, 62.73295037448406, 59.44578096270561, 57.742073982954025, 62.34346367418766, 61.15152083337307, 61.35334700345993, 60.573043674230576, 59.44519579410553, 60.695359110832214, 61.36329106986523, 62.535740956664085, 71.60385176539421, 79.55187007784843, 78.4042176604271, 85.11741623282433, 84.59266439080238, 79.9167948961258, 75.7614366710186, 72.84693986177444, 66.42865866422653, 77.21910685300827, 83.36138606071472, 84.60455775260925, 80.38025602698326, 87.90442988276482, 42.910918816924095, 0.4444198776036501, 0.19496318913297728, 0.1652177469804883, 0.054482560080941767, 0.08168495158315636, 0.12329970253631473, 0.07192793607828207, 0.06218348142283503, 0.09346627877675928, 0.19467838254058734, 9.453598223626614, 36.97840355336666, 74.58644092082977, 50.15071973204613, 32.590782791376114, 16.1060893535614, 32.890031933784485, 50.831441804766655, 57.24295936524868, 76.09549954533577, 22.0902818441391, 0.7037000334821641, 0.1708393672015518, 0.1283771058660932, 0.09113557141972706, 0.04524866591964383, 0.03973638631578069, 0.02780151062324876, 0.0529107209877111, 0.06573008271516301, 0.03936696746677626, 0.014167280951369321, 0.06908760333317332, 0.004264487697582808, 0.04342426655057352, 0.012191001987957861, 0.023633306846022606, 0.015917581513349432, 0.01991437515243888, 0.029269851656863466, 0.0271126231746166, 0.05642991105560213, 0.04722585865238216, 0.05966445038211532, 0.022380661757779308, 0.012467596716305707, 0.050334945335634984, 0.06519765855045989, 0.046542566997231916, 0.06346339301671833, 0.037422429231810383, 0.0502425850572763, 0.04955929711286444, 0.02355333857849473, 0.07795860583428293, 0.01816465624870034, 0.10021244568633847, 0.03928975813323632, 0.02385435553151183, 0.05964290954580065, 0.16600224160356447, 0.5426655057817698, 38.17340523004532, 110.13805523514748, 86.75676226615906, 75.03762871026993, 42.58258983492851, 50.06418317556381, 58.365567326545715, 87.52062767744064, 68.64142432808876, 63.85302007198334, 10.967918615788221, 0.6214108772110194, 0.33456492237746716, 0.3953851416008547, 0.23979423742275685, 0.4449578159255907, 0.15587333589792252, 0.10167172324145213, 0.17665033898083493, 1.0771510004997253, 5.200294079259038, 84.89762082695961, 102.35572323203087, 109.74414557218552, 99.21315506100655, 93.85375544428825, 89.87992867827415, 89.0010130405426, 88.03225502371788, 85.88199600577354, 87.2376112639904, 94.48956772685051, 99.34472680091858, 100.1169441640377, 98.58966931700706, 98.26048538088799, 92.323037981987, 83.5753145813942, 79.35953199863434, 74.00833234190941, 74.74119901657104, 73.14116567373276, 70.37130430340767, 68.89222607016563, 67.6815578341484, 66.70994997024536, 67.83748626708984, 65.35998120903969, 73.73679891228676, 73.85721445083618, 71.04540333151817, 70.31652644276619, 64.59784090518951, 71.58967852592468, 71.2278163433075, 72.55332961678505, 73.2226637005806, 72.41864204406738, 72.73944362998009, 75.9696426987648, 73.76897558569908, 74.28800493478775, 72.31079623103142, 78.99874895811081, 79.53390464186668, 79.47091922163963, 84.36229795217514, 82.52315863966942, 88.45421478152275, 75.97275853157043, 46.58550024032593, 85.00521585345268, 80.5810372531414, 75.4653337597847, 64.02923941612244, 73.08114409446716, 74.63684901595116, 78.07428136467934, 79.27131593227386, 83.95971715450287, 80.3597143292427, 80.58021649718285, 72.8815484046936, 67.54278168082237, 64.38279524445534, 63.684480115771294, 64.25331339240074, 68.83377000689507, 65.32515227794647, 62.750258445739746, 63.50440017879009, 63.90421852469444, 63.628854900598526, 64.83857318758965, 64.35013219714165, 63.058079928159714, 64.44997563958168, 65.85691094398499, 64.51590970158577, 72.71550491452217, 82.90236309170723, 82.56814062595367, 87.99773767590523, 86.55950725078583, 83.54105561971664, 81.2540191411972, 76.51900202035904, 70.22569611668587, 79.60261255502701, 86.2151849269867, 88.18453565239906, 84.3534292280674, 89.57291275262833, 54.76334162056446, 1.2517832173034549, 0.060655009729089215, 0.19454274763120338, 0.08855521300574765, 0.054726385278627276, 0.3799594833981246, 0.1114851790771354, 0.09670584244304337, 0.13804013578919694, 0.3122290677856654, 9.972444232553244, 41.06045611202717, 44.98305402696133, 26.05611953884363, 33.2851043343544, 29.254039339721203, 45.16373053193092, 62.717808187007904, 65.58403238654137, 87.4944318830967, 37.92205631732941, 0.5947515671141446, 0.11117238609585911, 0.12536791968159378, 0.026012242669821717, 0.026476838247617707, 0.022897675225976855, 0.03493444593914319, 0.027690767346939538, 0.019114555179839954, 0.06207847865880467, 0.029946059512440115, 0.05277737931464799, 0.030557529826182872, 0.04876558501564432, 0.0741009073681198, 0.05281781523081008, 0.08080667917965911, 0.01847073650424136, 0.013913874627178302, 0.034784465315169655, 0.015308809834095882, 0.02116470659530023, 0.14021645416505635, 0.14821495075011626, 0.13280927116284147, 0.1375518026179634, 0.23789882194250822, 0.1831632637185976, 0.19738971517654136, 0.15769073681440204, 0.20623431948479265, 0.12291563369217329, 0.10071276454254985, 0.1625551882898435, 0.11741525813704357, 0.22244144434807822, 0.20776591933099553, 0.09087654703762382, 0.11099266761448234, 0.2778709848644212, 0.7708479522261769, 56.32433965802193, 137.1051549911499, 101.41498491168022, 91.95189669728279, 54.98483553528786, 56.435711681842804, 100.79054161906242, 129.86283481121063, 81.79324820637703, 85.36605209112167, 15.657887253910303, 0.8066549152135849, 1.1430900497362018, 0.6593950046226382, 0.6235489749815315, 0.7040601235348731, 0.5541356059256941, 0.21153896843316033, 0.7793056452646852, 1.6805911576375365, 4.844933347776532, 89.51259478926659, 104.6145348250866, 113.3373011648655, 106.17869049310684, 98.98517489433289, 95.9693755209446, 92.30758041143417, 92.12335869669914, 91.90238535404205, 93.21852073073387, 101.0739304125309, 103.32794666290283, 104.3060901761055, 101.94931223988533, 101.59565761685371, 95.92644542455673, 89.14152190089226, 85.67644983530045, 77.77259275317192, 80.6740714609623, 76.7135363817215, 74.59860786795616, 73.05139169096947, 71.28322497010231, 69.99790593981743, 72.4893182516098, 70.19901394844055, 75.37776365876198, 79.08910810947418, 74.17387425899506, 72.26956084370613, 68.90947714447975, 73.12179431319237, 75.54424032568932, 79.29962441325188, 78.97986397147179, 79.11654263734818, 77.84843668341637, 79.68404978513718, 80.77355772256851, 79.16318893432617, 78.04012879729271, 84.49365690350533, 84.53733935952187, 85.34250855445862, 88.209348320961, 86.12040281295776, 93.06411981582642, 78.67962688207626, 52.300138995051384, 86.91460579633713, 84.58720028400421, 80.35326987504959, 68.93988311290741, 76.1800754070282, 81.45735383033752, 82.51211643218994, 83.99538964033127, 88.68822902441025, 84.16636526584625, 83.50187972187996, 75.6773167848587, 70.69920390844345, 67.35745042562485, 67.55596697330475, 66.9777899980545, 72.31892019510269, 70.89443743228912, 67.28987485170364, 64.8824380338192, 68.09210300445557, 69.12977412343025, 68.0995962023735, 69.12304848432541, 66.81749939918518, 69.60703611373901, 68.9228068292141, 66.87499031424522, 76.55475050210953, 87.08340793848038, 87.48656630516052, 92.26767495274544, 90.00722944736481, 89.63783606886864, 84.91914287209511, 82.07906126976013, 72.49681904911995, 84.73730742931366, 91.81552201509476, 92.79703214764595, 88.27794224023819, 95.72497263550758, 52.060736641287804, 1.3970504910685122, 0.25703646533656865, 0.4538358317222446, 0.23176866729045287, 0.4055096983211115, 0.5555671791080385, 0.2543677913490683, 0.28182586014736444, 0.45948802842758596, 0.45503876404836774, 15.351178161799908, 59.066485315561295, 98.64554151892662, 69.96265903115273, 45.88593117892742, 27.439872287213802, 50.48320189118385, 74.23029363155365, 78.50270077586174, 105.03314316272736, 43.51417064666748, 0.8549962774850428, 0.34260158019606024, 0.2073501978884451, 0.12139002297772095, 0.17012905766023323, 0.18976474151713774, 0.16179426427697763, 0.13281310064485297, 0.14158819540170953, 0.1565783761907369, 0.08245627308497205, 0.09449747070902959, 0.10260428374749608, 0.12885004689451307, 0.17697388568194583, 0.1592605424229987, 0.1727746063261293, 0.06496167043223977, 0.09586301501258276, 0.22102944902144372, 0.1184739095333498, 0.17448461847379804], [0.023208486672956496, 0.029199217751738615, 0.12268039514310658, 0.04723542122519575, 0.07581654499517754, 0.06233956621144898, 0.04044154906296171, 0.06177135197503958, 0.0942192469665315, 0.006122498471086146, 0.10167796470341273, 0.03413991376874037, 0.057517457971698605, 0.08747536587179638, 0.03592300519812852, 0.016493634684593417, 0.15229461074341089, 0.0632014445727691, 2.5931520899757743, 42.522959634661674, 79.63332250714302, 71.35728299617767, 74.41320821642876, 68.5254317522049, 46.33867308497429, 72.75638312101364, 67.49567180871964, 92.24494457244873, 23.114473186433315, 0.30419525981415063, 0.08557035442208871, 0.1745179112185724, 0.053833225392736495, 0.1853913691593334, 0.12339987020823173, 0.10979637751006521, 0.1916745991911739, 0.3345941036241129, 0.38903185282833874, 61.2102010846138, 125.97474664449692, 104.70683187246323, 99.85323071479797, 89.08296704292297, 88.92652183771133, 78.74391943216324, 74.58651691675186, 81.44366696476936, 77.41139933466911, 73.75374600291252, 78.02809104323387, 84.73885014653206, 92.28223577141762, 92.57821708917618, 89.74407836794853, 80.50887912511826, 73.06412100791931, 67.9784283041954, 66.3276144862175, 65.50081685185432, 65.59676170349121, 66.10718071460724, 67.84539744257927, 66.95924699306488, 62.08894953131676, 58.14584031701088, 66.61677896976471, 69.07946482300758, 65.08610710501671, 66.81524991989136, 64.44584146142006, 64.33538138866425, 68.94418448209763, 69.7518539428711, 69.22219276428223, 69.33541908860207, 66.69296488165855, 65.8668664097786, 68.0943600833416, 68.08542296290398, 66.09621450304985, 68.85168984532356, 72.37076461315155, 76.66592493653297, 75.57298198342323, 79.51803669333458, 78.99789020419121, 84.54553171992302, 67.92565673589706, 39.9287324398756, 83.92760127782822, 76.87945067882538, 72.57233619689941, 61.25329837203026, 62.63423167169094, 61.46455943584442, 64.93537679314613, 68.85906904935837, 73.03138956427574, 71.79314240813255, 74.40257638692856, 72.9491999745369, 71.2078370153904, 63.99900063872337, 61.83024421334267, 60.79512655735016, 64.8004612326622, 63.03142435848713, 59.82943497598171, 59.92221459746361, 59.93311621248722, 59.37371402978897, 58.68562035262585, 58.961618542671204, 60.32050542533398, 61.393054872751236, 60.912749245762825, 62.75376185774803, 71.08533918857574, 77.9664659500122, 84.0859767794609, 80.82492336630821, 77.63675764203072, 78.04455935955048, 77.82284125685692, 70.32602593302727, 67.47889950871468, 69.41040426492691, 82.93133273720741, 81.90243914723396, 85.56734248995781, 77.40088909864426, 81.53839588165283, 18.802339173853397, 0.3739300975576043, 0.20411240053363144, 0.20191841904306784, 0.1785174192627892, 0.19159979070536792, 0.04892527293122839, 0.08278011664515361, 0.09093020431464538, 0.07298010852537118, 0.27011097001377493, 15.114787146449089, 29.02670133858919, 76.8508306145668, 43.45346890389919, 29.87841233611107, 25.270618088543415, 52.754351422190666, 63.30089069902897, 63.03669847548008, 61.489242911338806, 2.956479568965733, 0.22076175635447726, 0.11547117261216044, 0.07327561688725837, 0.090205779124517, 0.03469371178653091, 0.03353330081154127, 0.10665098496247083, 0.02025164973019855, 0.026319020544178784, 0.02330826100660488, 0.06070027702662628, 0.049364776496076956, 0.06761386131984182, 0.051458215530146845, 0.009441281763429288, 0.06380461767548695, 0.11126685407361947, 0.07587590938783251, 0.02835638661053963, 0.0192336587497266, 0.07836124321329407, 0.03540093399351463, 0.07084935059538111, 0.025683859021228272, 0.02942146315035643, 0.020799460471607745, 0.029136051707610022, 0.06060060659365263, 0.020947541197529063, 0.027383009837649297, 0.028073695139028132, 0.06186105536471587, 0.018706535374803934, 0.049706546633387916, 0.03356801476911642, 0.07491638665669598, 0.030143556141410954, 0.1274199431645684, 0.08055107609834522, 4.2317991983145475, 65.91276034712791, 96.9376015663147, 84.75168585777283, 82.9668228328228, 74.13464516401291, 45.94356268644333, 64.52330410480499, 75.8717143535614, 94.84467387199402, 29.511513523757458, 0.2441280087805353, 0.22098628571256995, 0.10050902274088003, 0.1416147346026264, 0.10639871412422508, 0.10479948236024939, 0.04575436905724928, 0.17301029758527875, 0.06865435978397727, 0.5690742074511945, 70.09036257863045, 126.77147269248962, 108.76831993460655, 103.57978954911232, 92.49049499630928, 93.54540199041367, 79.90454435348511, 79.88874480128288, 83.71202364563942, 79.86438810825348, 78.22887226939201, 80.69750860333443, 88.38224664330482, 96.24862253665924, 94.1528069972992, 94.81144085526466, 83.97221848368645, 76.80135726928711, 71.48835316300392, 69.51350793242455, 66.96499228477478, 69.12417322397232, 69.79872062802315, 70.60913354158401, 69.45169284939766, 64.27657574415207, 63.75862553715706, 70.00329405069351, 73.08758094906807, 68.07736739516258, 70.45009687542915, 65.50218477845192, 68.50916862487793, 72.86217704415321, 73.32296311855316, 73.43514069914818, 74.46157962083817, 71.8479734659195, 70.40581405162811, 70.94976246356964, 70.21489709615707, 69.52100872993469, 71.83375462889671, 75.15596956014633, 79.17737737298012, 76.41973614692688, 84.81460288167, 82.02698886394501, 87.9147045314312, 72.18987911939621, 43.133932650089264, 87.05181643366814, 81.81137323379517, 76.36057332158089, 65.33270627260208, 65.92137068510056, 64.8038962483406, 67.83505439758301, 70.29810503125191, 75.82744672894478, 74.58582535386086, 75.90642929077148, 76.54322952032089, 75.91567039489746, 67.44801476597786, 65.74075877666473, 63.14008332788944, 65.3214892745018, 65.66993817687035, 62.374055832624435, 61.76932208240032, 65.04803314805031, 63.060207813978195, 62.63331212103367, 63.135265186429024, 64.75575283169746, 65.41293516755104, 62.97884277999401, 65.26295721530914, 76.07056528329849, 82.98642978072166, 87.0296560227871, 81.4950630068779, 81.6085097193718, 81.68390527367592, 80.14185681939125, 74.9084584414959, 71.62110283970833, 72.35140845179558, 84.69872429966927, 84.82242286205292, 87.03147232532501, 82.14013919234276, 84.90116983652115, 27.024337984621525, 0.32025913533288985, 0.06405355627066456, 0.6090741266962141, 0.08689712893101387, 0.11916792893316597, 0.258139445213601, 0.13464809046126902, 0.2306942007271573, 0.06306266295723617, 0.05838647950440645, 18.61344750970602, 30.700289234519005, 46.60859540104866, 32.99144469201565, 33.95992912352085, 36.999158039689064, 56.51231177151203, 76.86454027891159, 72.01414614915848, 82.95818209648132, 7.70257618278265, 0.3323787631234154, 0.19585933245252818, 0.08690300674061291, 0.06832364393630996, 0.028385198638716247, 0.05028784122259822, 0.03853318681649398, 0.07179477994213812, 0.07615082315169275, 0.048229238600470126, 0.03894995468726847, 0.01307720423938008, 0.05328432554961182, 0.011317190819681855, 0.035729942901525646, 0.010039007502200548, 0.1338402775581926, 0.03691581696330104, 0.03040266215975862, 0.0626588381419424, 0.10935010926914401, 0.08520906951162033, 0.17064015992218629, 0.20167928421869874, 0.20476785051869228, 0.17746616707881913, 0.20378074957989156, 0.1397129663382657, 0.1439558988204226, 0.15580002655042335, 0.12160339785623364, 0.21599813306238502, 0.15077159012435004, 0.13665356644196436, 0.20705317554529756, 0.10019458961323835, 0.13799177744658664, 0.17902924882946536, 0.20176814898150042, 6.571526974439621, 92.01154589653015, 116.38920620083809, 100.4601189494133, 97.5490115582943, 88.09236779808998, 65.8134488761425, 101.28750175237656, 86.14853650331497, 114.96277794241905, 39.78902153670788, 0.5627556215040386, 0.5278216616716236, 0.3214414953254163, 0.3013907728018239, 0.7088884175755084, 0.4070662788581103, 0.4683800262864679, 0.4085712059168145, 0.4702379781519994, 0.889746006578207, 73.34029018878937, 127.29482620954514, 112.489133477211, 107.56459772586823, 96.63874000310898, 100.5056557059288, 84.5576910674572, 83.21685701608658, 89.16627377271652, 84.49057146906853, 81.52152478694916, 85.08655428886414, 94.6109864115715, 99.76968079805374, 97.68684536218643, 97.43484288454056, 88.6031211912632, 83.4413793683052, 75.852160602808, 73.03588092327118, 69.06169697642326, 73.23829606175423, 73.61324474215508, 72.58875891566277, 73.147541731596, 69.3160705268383, 67.54215851426125, 74.81609299778938, 75.6870898604393, 71.27716809511185, 73.35985913872719, 71.58100739121437, 71.84598997235298, 78.07220667600632, 80.74503645300865, 78.95956546068192, 79.81464877724648, 75.01948848366737, 75.59926137328148, 76.73509642481804, 76.76491722464561, 73.84041175246239, 76.47201374173164, 81.2369504570961, 83.88803780078888, 80.9458176791668, 88.08584734797478, 87.57499516010284, 93.51937338709831, 76.10042408108711, 48.60628500580788, 90.10200396180153, 85.80763399600983, 78.08083981275558, 69.21784579753876, 70.93251898884773, 69.46491613984108, 71.4548009634018, 75.3228110074997, 80.4936571419239, 78.35822492837906, 80.4574678838253, 80.98064661026001, 78.33379983901978, 71.27196997404099, 68.70899990200996, 65.79596981406212, 70.23491442203522, 70.53432315587997, 67.33969777822495, 67.05035850405693, 66.5983347594738, 68.64162191748619, 65.93662306666374, 67.84305676817894, 69.81580451130867, 68.55206072330475, 66.24303862452507, 68.22241321206093, 78.43951016664505, 85.3260326385498, 91.92439377307892, 85.06521463394165, 85.35066291689873, 84.72158387303352, 84.12222683429718, 80.64330071210861, 74.04621630907059, 75.38021072745323, 91.72814190387726, 92.405706346035, 92.38125085830688, 88.39187532663345, 89.69798684120178, 24.832106418907642, 0.5766173370648175, 0.387249510968104, 0.5117283971048892, 0.31182050064671785, 0.4069046984659508, 0.4756759316660464, 0.47128695936407894, 0.3842477314174175, 0.17071554728318006, 0.6636138469912112, 27.241025157272816, 46.544044464826584, 103.45427468419075, 60.04988394677639, 41.575119495391846, 38.97513560950756, 71.40698432922363, 87.75569066405296, 85.65489739179611, 94.5723956823349, 7.405847730115056, 0.27632164768874645, 0.471321691875346, 0.20082191069377586, 0.1898722193436697, 0.18276191025506705, 0.1934451557463035, 0.22231297858525068, 0.10361042819567956, 0.19956787407863885, 0.09777965591638349, 0.13711987267015502, 0.19326810899656266, 0.21931762603344396, 0.19787307595834136, 0.08658763108542189, 0.20528643362922594, 0.27051167038735, 0.1622579136164859, 0.16202588856685907, 0.10573016523267142, 0.11065422600950114], [0.046947030059527606, 0.051886386499973014, 0.023017589592200238, 0.014699276525789173, 0.01593701836100081, 0.09744732960825786, 0.02529800716729369, 0.048977111946442164, 0.033825825739768334, 0.06946301131392829, 0.0944173707102891, 0.08928680734243244, 0.20580338401487097, 0.043918807787122205, 0.04328408969740849, 0.027428817047621123, 0.05966191594779957, 0.21090187918161973, 15.055195894092321, 59.597837403416634, 68.4769843518734, 75.82742393016815, 74.36552837491035, 39.926486760377884, 43.60867157578468, 74.80098500847816, 84.63775277137756, 60.40198065340519, 2.7636950137093663, 0.03522189086652361, 0.10106277622980997, 0.04974484516424127, 0.15124101337278262, 0.04384924628539011, 0.2484019481926225, 0.19499431480653584, 0.23191675543785095, 0.32585083215963095, 40.51117658615112, 120.16735106706619, 95.37352949380875, 101.30337730050087, 93.29488143324852, 92.35290437936783, 80.28036698698997, 78.07421296834946, 73.51365968585014, 74.3742299079895, 72.9242505133152, 71.0618032515049, 66.62686362862587, 70.64759507775307, 74.90686252713203, 78.56225118041039, 73.61628457903862, 66.24285623431206, 66.1768613755703, 63.97272124886513, 65.33644527196884, 65.88946759700775, 65.2885602414608, 64.04332906007767, 66.72013342380524, 62.159306555986404, 58.1581212580204, 62.552615851163864, 67.18643680214882, 69.17424693703651, 65.20016178488731, 65.20843014121056, 61.06886766850948, 67.34041213989258, 69.01337116956711, 67.71218419075012, 65.58383479714394, 63.748461082577705, 61.70358940958977, 62.73344434797764, 60.28061896562576, 62.739881202578545, 62.56929315626621, 67.69413515925407, 67.60363921523094, 71.94824248552322, 76.13768488168716, 76.64491206407547, 74.8210859298706, 80.43874248862267, 67.96631455421448, 43.27379934489727, 78.42466056346893, 79.14115771651268, 68.13798174262047, 60.6928588449955, 58.86299483478069, 54.53204803168774, 55.66050007939339, 57.65745632350445, 62.4277051538229, 64.30907160043716, 69.26558643579483, 69.58885788917542, 72.01186627149582, 64.8091247677803, 60.34271523356438, 61.95421636104584, 62.787507846951485, 63.20849105715752, 61.00433953106403, 56.827109679579735, 59.45304997265339, 57.99706690013409, 57.8261748701334, 58.923597782850266, 59.31376464664936, 60.16888976097107, 61.06382913887501, 64.20384764671326, 71.86869755387306, 78.96130576729774, 77.71553501486778, 78.9874179661274, 74.95411679148674, 80.70320069789886, 74.95011940598488, 71.6250242292881, 66.54871702194214, 66.52420833706856, 75.29498130083084, 81.34032011032104, 80.61243116855621, 83.11004474759102, 81.00518569350243, 67.86724627017975, 4.247426809743047, 0.4438717570155859, 0.21141994278877974, 0.269699078053236, 0.1770112750818953, 0.04724763326521497, 0.05248623849183787, 0.146072726638522, 0.05628032005915884, 0.18322815711144358, 3.6323732882738113, 23.276568688452244, 43.277139365673065, 64.4509331882, 35.6471411883831, 36.46759696304798, 44.51753720641136, 55.79596661031246, 65.03990158438683, 73.19499358534813, 25.623296163976192, 0.5970361351501197, 0.06910866548423655, 0.050209459295729175, 0.012804296129615977, 0.03295605463790707, 0.08630583761259913, 0.07259437727043405, 0.02197753270593239, 0.006151474699436221, 0.024909648709581234, 0.011873652219946962, 0.04838989130803384, 0.054823673417558894, 0.03317914051876869, 0.034930894762510434, 0.027529413309821393, 0.017781409333110787, 0.05936481567914598, 0.015570653449685778, 0.019827072610496543, 0.03100462370639434, 0.011175362687936286, 0.030326181986310985, 0.059354566619731486, 0.008195409700419987, 0.03705551884195302, 0.050428819595254026, 0.024017628020374104, 0.01681164310866734, 0.0986134514096193, 0.053218849570839666, 0.08416868979111314, 0.0410071323858574, 0.17605328117497265, 0.08075680685578845, 0.027441294405434746, 0.01437826704204781, 0.13471350335748866, 0.07036193768726662, 22.80801773071289, 83.87920707464218, 83.88008862733841, 89.97599512338638, 82.99706161022186, 62.59748764336109, 54.84028749167919, 70.42421266436577, 96.16164520382881, 68.7835443019867, 3.249199711717665, 0.19981869030743837, 0.22281100420514122, 0.21989673870848492, 0.05711398938728962, 0.12755973410094157, 0.30017293815035373, 0.11140510134282522, 0.04250368059729226, 0.6313135020900518, 49.29586820304394, 124.16938751935959, 100.69853335618973, 105.72470605373383, 98.3534587919712, 98.58834698796272, 82.43852958083153, 81.86715424060822, 75.87629690766335, 78.74979391694069, 76.8354794383049, 75.45240685343742, 69.99576285481453, 74.55193877220154, 77.58348450064659, 82.87838637828827, 78.01369741559029, 68.7765146791935, 68.51259604096413, 67.77977496385574, 67.85590767860413, 68.17310705780983, 67.1458549797535, 67.95258969068527, 68.94052907824516, 65.78738987445831, 60.95416322350502, 66.01226180791855, 70.74996158480644, 71.96420162916183, 69.80366796255112, 68.22230681777, 65.17904251813889, 70.80176040530205, 72.30842515826225, 72.04363256692886, 67.87979319691658, 66.73590257763863, 64.56673577427864, 67.98602029681206, 64.01245951652527, 65.05066260695457, 66.48496404290199, 72.4666790664196, 72.666305154562, 75.08325666189194, 79.54594239592552, 78.22213903069496, 78.5013784468174, 84.80460181832314, 69.60543259978294, 47.55992375314236, 83.0129523575306, 81.5214791893959, 72.25126102566719, 63.13008986413479, 59.80739615857601, 58.53397808969021, 58.502838760614395, 61.22755095362663, 64.94811370968819, 66.06469139456749, 73.54678630828857, 71.28117308020592, 74.47692319750786, 66.96769773960114, 63.57297129929066, 64.04294908046722, 64.95325103402138, 66.37096256017685, 62.8406897932291, 59.17361296713352, 60.856907442212105, 61.159876585006714, 59.73283275961876, 62.33402118086815, 62.402706295251846, 62.459969222545624, 63.92912998795509, 66.71425133943558, 75.00942662358284, 82.3201659321785, 81.20653688907623, 83.52065831422806, 78.90693068504333, 81.42102777957916, 77.56089091300964, 76.76883101463318, 70.24505227804184, 70.04940837621689, 79.18062999844551, 85.9677954018116, 85.26635304093361, 86.90139770507812, 81.64759442210197, 75.94875901937485, 8.114833161234856, 0.508497798582539, 0.3602296655299142, 0.5789855006150901, 0.3228252741973847, 0.05389904647017829, 0.10514272566069849, 0.20880345662590116, 0.02353744177526096, 0.3125454008113593, 3.373045278713107, 29.559026174247265, 41.30635991692543, 34.52556677162647, 32.12875798344612, 45.08535973727703, 53.02333898842335, 68.28377991914749, 72.1156994998455, 84.02935221791267, 40.42754307389259, 0.3312483831541613, 0.021287849303917028, 0.018922370472864714, 0.007350199975917349, 0.025355475372634828, 0.06729680098942481, 0.04717493247881066, 0.007533971047450905, 0.027307483323966153, 0.014874806511215866, 0.0370518266572617, 0.04316370963351801, 0.05072433537861798, 0.009138966979662655, 0.0032284481494571082, 0.019806157033599447, 0.06767320344806649, 0.0064358457439084304, 0.0496016663237242, 0.06795143461204134, 0.004924020422549802, 0.11669449915643781, 0.1571966297342442, 0.13434312713798136, 0.06166972227219958, 0.09528956492431462, 0.1629334015888162, 0.11975351313594729, 0.15377345873275772, 0.200333429093007, 0.15647839405573905, 0.15852375305257738, 0.17712856410071254, 0.4109245561994612, 0.1414326115627773, 0.06890598495374434, 0.11726485448889434, 0.5725893750786781, 0.3132285625906661, 31.9910229742527, 109.82735350728035, 102.77886092662811, 109.95146244764328, 105.67771777510643, 57.545385137200356, 65.80407097935677, 98.08849141001701, 102.76064470410347, 84.11707431077957, 6.217648163437843, 0.2348812494892627, 0.40392942843027413, 0.1925080904038623, 0.2303267188835889, 0.559020540677011, 0.6072558055166155, 0.5223346373531967, 0.464214826351963, 1.0568363405764103, 49.48259398341179, 124.71051648259163, 102.7932621538639, 109.45616662502289, 104.21158164739609, 105.38053572177887, 84.9965751171112, 86.73105284571648, 81.22298240661621, 83.08795273303986, 82.53664791584015, 79.0769411623478, 74.48496356606483, 78.09164643287659, 80.9370781481266, 88.79780754446983, 82.33764499425888, 72.08638027310371, 72.25312292575836, 72.06060245633125, 71.99831619858742, 71.96675509214401, 71.0819573700428, 71.70913651585579, 71.90514519810677, 68.41277539730072, 64.3069589138031, 69.3447969853878, 76.64001792669296, 76.3902497291565, 72.34690949320793, 71.86055079102516, 69.67632919549942, 75.05766123533249, 75.90870156884193, 77.3554739356041, 74.23518016934395, 71.87536239624023, 71.09025612473488, 72.19014510512352, 66.44580334424973, 70.44821217656136, 70.69484174251556, 79.33453693985939, 76.24066695570946, 79.11655783653259, 83.37272465229034, 84.15790691971779, 82.38871425390244, 88.7212036550045, 73.71168985962868, 51.71756185591221, 85.32195165753365, 87.01768666505814, 76.10218718647957, 66.96873128414154, 63.56598727405071, 59.85910378396511, 61.55011564493179, 66.16135060787201, 70.81469491124153, 70.98919674754143, 76.64077788591385, 75.00217661261559, 77.56219044327736, 69.64009433984756, 68.32173228263855, 69.81215670704842, 68.89132931828499, 69.45474788546562, 68.47584441304207, 63.508226573467255, 64.57811236381531, 64.72366735339165, 62.69253574311733, 65.56797444820404, 66.67615458369255, 66.49357438087463, 67.86441922187805, 71.69172585010529, 77.94733017683029, 87.84554824233055, 84.842219799757, 86.36084631085396, 81.45045340061188, 85.79017773270607, 82.36593827605247, 80.60869976878166, 74.1637971997261, 74.68715071678162, 82.1258519589901, 90.4955792427063, 89.51974600553513, 90.62099531292915, 88.64612728357315, 77.63808757066727, 6.463983720168471, 1.0679157148115337, 0.5300650256685913, 0.543507932452485, 1.375086719635874, 0.23441531433491036, 0.39022243581712246, 0.5837139906361699, 0.3224777412833646, 0.3741666051791981, 7.254278613254428, 42.31619752943516, 60.518170818686485, 86.99365675449371, 47.85242445766926, 49.50345106422901, 63.73386986553669, 80.5295804142952, 85.72927460074425, 101.87484383583069, 46.16742767393589, 0.6380012619774789, 0.19685257837409154, 0.1353713875869289, 0.127850848948583, 0.10753960290458053, 0.23224652133649215, 0.13504320988431573, 0.14233715599402785, 0.06358786602504551, 0.1586080461856909, 0.14427284040721133, 0.21406960295280442, 0.21576030441792682, 0.12181433106889017, 0.14482057507848367, 0.15378329961095005, 0.1338546900660731, 0.12832570471800864, 0.12770200381055474, 0.1382339105475694, 0.12184867024188861], [0.014547110276907915, 0.02331529656657949, 0.08124424202833325, 0.028992574152653106, 0.040737510134931654, 0.02797871879010927, 0.1108143146848306, 0.03874954141792841, 0.024490036557835992, 0.0511356076458469, 0.05202133492275607, 0.04157834489888046, 0.015442123676621122, 0.01832878220739076, 0.011310070840409026, 0.013129910639690934, 0.1534595005796291, 2.603892688639462, 36.13050565123558, 72.86063432693481, 73.33575323224068, 56.936323419213295, 44.20406922698021, 19.27343789488077, 44.58544336259365, 53.876028433442116, 67.96848803758621, 37.458891570568085, 0.45760644658003, 0.22406691103242338, 0.1380001488723792, 0.4344747425056994, 0.23356430843705311, 0.19537991989636794, 0.2791136072482914, 0.42858191183768213, 0.6382430240046233, 25.94717748463154, 116.53872057795525, 98.01492735743523, 107.73181915283203, 96.3844196498394, 94.38379660248756, 86.33700639009476, 80.47224149107933, 69.49951708316803, 70.75413376092911, 69.86056610941887, 66.49292081594467, 67.66565948724747, 64.05928060412407, 65.4314249753952, 63.0861946195364, 62.828351855278015, 61.68084762990475, 66.33206784725189, 66.07385650277138, 66.61579862236977, 66.24018877744675, 64.30363789200783, 63.27866569161415, 64.32699903845787, 64.28215384483337, 58.36130015552044, 60.6799129396677, 65.96987128257751, 64.64118897914886, 68.54829892516136, 64.48991909623146, 60.35594992339611, 60.96018970012665, 66.5232203900814, 66.19186297059059, 67.41935670375824, 60.01162759959698, 57.13061459362507, 55.57416491210461, 59.269322231411934, 58.796456605196, 61.19380496442318, 62.154366821050644, 68.961481153965, 66.86058148741722, 72.73477748036385, 71.94125846028328, 75.56607395410538, 73.80004271864891, 79.97200593352318, 66.15274786949158, 46.36704996228218, 83.30621302127838, 74.92634788155556, 69.71941888332367, 59.12582293152809, 62.4105566740036, 59.450929686427116, 61.97398290038109, 62.421853467822075, 62.352788373827934, 61.63705877959728, 63.751565515995026, 66.55814051628113, 69.33024376630783, 66.02907210588455, 58.4574805945158, 60.927842035889626, 59.946556091308594, 61.685699969530106, 58.27059522271156, 55.905928909778595, 55.17886072397232, 57.20529958605766, 58.77644307911396, 59.55637402832508, 59.785497933626175, 58.676614835858345, 58.0979210883379, 63.17318715155125, 72.36090794205666, 77.29687348008156, 78.8920658826828, 81.74977853894234, 81.34621739387512, 77.90674835443497, 74.57862854003906, 69.85672071576118, 67.2191758453846, 64.30501341819763, 65.0649194419384, 78.27049523591995, 77.73080259561539, 81.99218273162842, 79.23470869660378, 84.12470430135727, 41.483373418450356, 0.4498221486574039, 0.14603492163587362, 0.29568805068265647, 0.15603095322148874, 0.09610222405171953, 0.12876541237346828, 0.20703995047369972, 0.3640029818052426, 0.07714835868682712, 0.13759530731476843, 10.74215468019247, 26.84445943683386, 63.926857709884644, 54.14229914546013, 19.1149066016078, 26.78779687732458, 47.378437891602516, 63.16543556749821, 60.85117734968662, 65.63382491469383, 5.9511494636535645, 0.18615747336298227, 0.040876610873965546, 0.08518713904777542, 0.07864889223128557, 0.03423838563321624, 0.022001958641340025, 0.05173484365514014, 0.021598645907943137, 0.029451290065480862, 0.006778960560041014, 0.06690405643894337, 0.020568498548527714, 0.05712859485356603, 0.01077741660992615, 0.005089627893539728, 0.0741011745412834, 0.030740239162696525, 0.024596820476290304, 0.039329047431237996, 0.03288141684606671, 0.019306890171719715, 0.06223266726010479, 0.020455725498322863, 0.01587322334671626, 0.03969566838350147, 0.10993329633492976, 0.05911282685701735, 0.005296280305628898, 0.050062350783264264, 0.02085001557134092, 0.02904282126110047, 0.01347159728538827, 0.06228596830624156, 0.07424211580655538, 0.04773415559611749, 0.03405679693969432, 0.183510247443337, 3.4480019565671682, 55.87524175643921, 93.29851403832436, 89.41559359431267, 73.16378965973854, 58.305541947484016, 29.74133089184761, 42.804817110300064, 63.294731229543686, 76.51786968111992, 42.5583129376173, 0.3264853684231639, 0.11914372007595375, 0.6938314880244434, 0.1837567740585655, 0.7528372155502439, 0.15819029125850648, 0.8179499872494489, 0.26884355989750475, 0.6338231486734003, 33.89480821788311, 122.39029258489609, 102.38083228468895, 110.86400628089905, 100.88234469294548, 96.98461264371872, 91.92704603075981, 84.84249338507652, 73.19459080696106, 75.71036741137505, 74.57680463790894, 71.25527366995811, 70.20421966910362, 68.87600094079971, 68.29017877578735, 66.51709511876106, 64.05811786651611, 66.89351812005043, 68.73074993491173, 70.25081276893616, 68.96049320697784, 67.10355564951897, 66.31932333111763, 66.25752344727516, 69.36963245272636, 67.07330167293549, 62.25866362452507, 65.2860751748085, 70.03531113266945, 68.80233809351921, 70.58653995394707, 68.95750656723976, 63.747226148843765, 64.92589250206947, 71.32115453481674, 68.76491770148277, 71.4780481159687, 63.7647508084774, 61.59442126750946, 59.59035940468311, 64.48513135313988, 62.378136813640594, 66.02828174829483, 65.4849261045456, 72.49338403344154, 70.00590831041336, 77.12981164455414, 75.41076108813286, 78.14256370067596, 76.2510783970356, 84.19458255171776, 67.97449171543121, 48.74772101640701, 87.23796084523201, 79.05792698264122, 71.88140407204628, 61.427663415670395, 66.51444286108017, 64.29183572530746, 66.20142325758934, 64.40889984369278, 67.57475316524506, 65.96883773803711, 67.35387861728668, 70.84961503744125, 71.61845818161964, 68.65968614816666, 62.61595465242863, 62.222728952765465, 63.93883466720581, 63.54242853820324, 60.7839285582304, 59.46914590895176, 57.73006282746792, 59.779828637838364, 61.873048916459084, 63.63531455397606, 62.19481565058231, 62.06190638244152, 60.65225802361965, 66.00037604570389, 77.33428627252579, 79.97889116406441, 82.25451305508614, 84.5472264289856, 84.31425333023071, 81.29657685756683, 78.17473277449608, 73.28602150082588, 69.68963608145714, 68.40205997228622, 68.41655999422073, 79.48286578059196, 81.20279788970947, 86.58873528242111, 82.27054819464684, 87.20280513167381, 50.61382368206978, 1.1725173331797123, 0.14927041833288968, 0.3846369433449581, 0.37667402531951666, 0.3339569253148511, 0.15929974266327918, 0.2692322671646252, 1.0588934551924467, 0.052428213675739244, 0.12291227918467484, 10.110603868961334, 32.226458340883255, 48.57254281640053, 26.41250241547823, 23.663042150437832, 47.46528223156929, 56.71463191509247, 72.7667261660099, 70.18414154648781, 86.61192163825035, 14.337609149515629, 0.28866014967206866, 0.026357450806244742, 0.04338673243182711, 0.035291534004500136, 0.09654530847910792, 0.029935329912404995, 0.024674755259184167, 0.01935219086590223, 0.060029716914868914, 0.016870139188540634, 0.03023897406819742, 0.049870201328303665, 0.05604800557193812, 0.024774223456915934, 0.009425577918591443, 0.02000128064537421, 0.02397584139544051, 0.05266085841867607, 0.06730929875629954, 0.04387589680845849, 0.12262489733984694, 0.11868519897689112, 0.1706829818431288, 0.10131921793799847, 0.19342557789059356, 0.2408650377765298, 0.3145247383508831, 0.13366152386879548, 0.16939255030592903, 0.13405449106357992, 0.10693271906347945, 0.18104823189787567, 0.24982546165119857, 0.17995487025473267, 0.1016158469428774, 0.12874840234871954, 0.3298061230452731, 4.193283040076494, 75.88537082076073, 115.61809837818146, 105.88897123932838, 89.30348441004753, 71.2072366476059, 30.83469182252884, 60.19116036593914, 77.8934034705162, 91.90831303596497, 56.952016577124596, 0.659509829711169, 0.3615558537421748, 0.5021453707013279, 0.9341552329715341, 0.7944384519942105, 0.40218033478595316, 1.3248109049163759, 0.6460067199077457, 1.0346838855184615, 32.12815381586552, 122.79753193259239, 103.78024399280548, 114.76331904530525, 103.9606811106205, 102.87987470626831, 94.2076912522316, 90.30472308397293, 76.32176220417023, 82.61611685156822, 80.02730056643486, 76.28207713365555, 74.4977080821991, 72.54053190350533, 72.4834817647934, 70.99719151854515, 68.33571553230286, 69.62790459394455, 71.55249372124672, 74.5663931965828, 74.4419726729393, 71.21937319636345, 69.71603706479073, 68.98548066616058, 71.86346143484116, 69.97320726513863, 66.6207155585289, 67.96862483024597, 73.83194580674171, 71.96353286504745, 75.82395851612091, 72.68660366535187, 66.48401409387589, 67.80962616205215, 74.35824036598206, 74.86174374818802, 76.99010834097862, 68.35091471672058, 64.97660458087921, 63.664732575416565, 68.48809495568275, 67.28251844644547, 69.30750578641891, 69.07317236065865, 75.88897302746773, 74.48084458708763, 81.33861780166626, 78.7251864373684, 80.94515651464462, 81.64975270628929, 86.82974874973297, 72.66251295804977, 53.17419469356537, 88.28844487667084, 83.73127341270447, 76.30492150783539, 65.41852846741676, 68.68654310703278, 66.934654712677, 68.21328610181808, 68.76636922359467, 68.1525045633316, 70.3606952726841, 71.27465263009071, 74.85457733273506, 76.76488682627678, 71.82775855064392, 64.29514914751053, 66.49052694439888, 67.42793664336205, 66.81055337190628, 65.01057475805283, 64.09258961677551, 61.165572479367256, 62.97245912253857, 65.55890813469887, 66.56687244772911, 67.29598492383957, 64.28531527519226, 63.46450611948967, 70.71098327636719, 80.65494328737259, 84.83392104506493, 85.58510273694992, 87.2580161690712, 90.31771078705788, 86.26581341028214, 81.06446251273155, 76.82746946811676, 74.93142440915108, 72.69101902842522, 72.65937432646751, 84.39662531018257, 85.87426722049713, 91.32116094231606, 85.32845690846443, 95.38665398955345, 48.33861976861954, 2.0276355603709817, 2.95409947168082, 0.8764555072411895, 0.5236484168563038, 0.7701600703876466, 0.47970237967092544, 1.2512923311442137, 0.9009409777354449, 0.1245204167207703, 0.23460278083803132, 16.86325952410698, 44.434017688035965, 87.5146771967411, 74.32976469397545, 28.63138385117054, 46.10211297869682, 66.03861719369888, 87.91681721806526, 82.32414811849594, 97.17404767870903, 14.626643490046263, 0.2605324855539948, 0.14545796118909493, 0.11962915887124836, 0.2398156261187978, 0.21073559357319027, 0.09319674558355473, 0.08841774499160238, 0.19596893282141536, 0.1549590248032473, 0.11652491099084727, 0.2481355468626134, 0.1521266033523716, 0.1426132646156475, 0.10353769030189142, 0.124047965509817, 0.09550643531838432, 0.13085148559184745, 0.13092335517285392, 0.11879594225320034, 0.0936936134530697], [0.013232187866378808, 0.06327821974991821, 0.01845527014666004, 0.05443181573355105, 0.030652663881483022, 0.0310529690614203, 0.09928847925039008, 0.010359641273680609, 0.04576218387228437, 0.03416269028093666, 0.05283372687699739, 0.031551035499433056, 0.05436696686956566, 0.023885620357759763, 0.04579074171488173, 0.060614659159909934, 0.15011241455795243, 7.640679879114032, 61.96134477853775, 68.34149122238159, 61.80602811276913, 45.224914848804474, 47.000878751277924, 46.6644524037838, 91.35240286588669, 68.30804541707039, 49.12078879773617, 5.445686336606741, 0.26273132069036365, 0.12792215449735522, 1.1946594575420022, 0.4278549930313602, 0.15058152610436082, 0.14084250025916845, 0.24377605266636238, 0.22308579180389643, 8.365295771509409, 104.88764137029648, 96.11669361591339, 108.51988166570663, 95.19028052687645, 97.77645975351334, 86.98444604873657, 85.47280356287956, 70.93451008200645, 75.26165708899498, 69.3324476480484, 70.66610768437386, 66.93796813488007, 66.446213722229, 64.05954658985138, 65.03890603780746, 64.82110932469368, 65.83869472146034, 63.66351284086704, 65.687136054039, 65.09033247828484, 65.15039205551147, 61.370552480220795, 64.73328843712807, 64.13780719041824, 66.22366726398468, 56.292755752801895, 60.013880878686905, 64.10739362239838, 63.544001653790474, 65.80826595425606, 66.11313879489899, 60.804512053728104, 62.90932551026344, 67.28229805827141, 68.75661134719849, 70.32623872160912, 66.70686453580856, 59.43749740719795, 58.44648778438568, 55.76854348182678, 59.41882140934467, 57.750467732548714, 60.57433940470219, 61.412072852253914, 65.01242905855179, 64.57444936037064, 68.42165172100067, 68.23402538895607, 72.22506523132324, 70.27004733681679, 81.25936925411224, 61.33606553077698, 51.461356803774834, 82.76516005396843, 71.17288649082184, 64.6767246723175, 61.96029223501682, 71.32649704813957, 67.4175252020359, 72.32631459832191, 70.07210835814476, 71.05858862400055, 70.252735465765, 68.648491948843, 68.3467349410057, 67.68104866147041, 60.36101505160332, 57.577953189611435, 58.126294165849686, 61.31630279123783, 58.98204244673252, 59.35838185250759, 57.68921121954918, 54.90831904113293, 53.63567613065243, 56.818852722644806, 56.454182490706444, 58.8557980209589, 57.199668288230896, 60.0606981664896, 58.64824555814266, 67.06904590129852, 73.43399316072464, 78.19688558578491, 78.483716994524, 78.67363080382347, 75.84895357489586, 73.37637305259705, 67.28080093860626, 64.96594235301018, 61.129368022084236, 62.97687068581581, 66.29526302218437, 78.96002143621445, 75.86252644658089, 83.85192453861237, 78.4120224416256, 88.90347227454185, 11.40845462679863, 1.8446010444313288, 0.27011120750103146, 0.38786065473686904, 0.11635760864010081, 0.2509480935987085, 0.2719877427443862, 0.5767005169764161, 0.05533704665140249, 0.06395722550223581, 1.308800345286727, 21.64936300367117, 29.043219052255154, 66.13617315888405, 34.664863497018814, 17.88514818996191, 35.71809098124504, 52.14778617024422, 60.14836706221104, 76.41535118222237, 42.01319418847561, 1.94248141720891, 0.04036890764837153, 0.05960703041637316, 0.03391300211660564, 0.007849308203731198, 0.06915229634614661, 0.060047610095352866, 0.05546774256799836, 0.034161755174864084, 0.0743242196040228, 0.06052027652913239, 0.0626971700694412, 0.019972965856140945, 0.07903228572104126, 0.062360338924918324, 0.0338176880904939, 0.07118549896404147, 0.06159282464068383, 0.05832568647747394, 0.12142414692789316, 0.06849045646958984, 0.046318364184116945, 0.030956938862800598, 0.053225102165015414, 0.1037516663200222, 0.0378061047376832, 0.035586162921390496, 0.05410002748249099, 0.13725494354730472, 0.019076868920819834, 0.046303892304422334, 0.024511254559911322, 0.004800627702934435, 0.025217623297066893, 0.06494333196314983, 0.08144314502715133, 0.07328660067287274, 11.484987270087004, 88.784059882164, 83.28480497002602, 78.60832750797272, 57.184936478734016, 62.839903235435486, 49.6356725692749, 68.6556887626648, 70.73044583201408, 56.90646842122078, 5.740337250754237, 0.3811256942572072, 0.4760109371272847, 1.5803988464176655, 1.3530366215854883, 0.6540350359864533, 0.6654774688649923, 0.17315559525741264, 0.6616999371908605, 12.226329389959574, 112.22958460450172, 99.94453981518745, 113.69369924068451, 100.2862174808979, 101.49221956729889, 91.33224874734879, 87.77711391448975, 73.44709485769272, 78.80912393331528, 74.04009103775024, 74.78642418980598, 70.19901394844055, 69.8446449637413, 67.38264307379723, 69.26956102252007, 67.76454538106918, 69.3947871029377, 67.6060938835144, 69.33438554406166, 68.69542703032494, 69.11668002605438, 66.85881078243256, 68.92498031258583, 66.73343271017075, 69.08404737710953, 60.31265124678612, 64.34003993868828, 66.36876627802849, 68.38450491428375, 67.50332459807396, 68.42632547020912, 64.01201874017715, 67.19132333993912, 70.0572207570076, 74.30153980851173, 73.85216072201729, 68.91765430569649, 62.31547437608242, 61.16425774991512, 58.034985065460205, 62.958574667572975, 61.967257261276245, 64.37436729669571, 64.55052584409714, 69.89367753267288, 68.43266353011131, 70.63456937670708, 70.74616938829422, 76.4111790060997, 75.11140555143356, 84.1612659394741, 64.81380611658096, 54.46158081293106, 84.06962245702744, 73.12436297535896, 67.96002969145775, 64.8360425233841, 73.72006461024284, 72.36802875995636, 75.51259562373161, 72.70467549562454, 74.53133627772331, 74.26740244030952, 73.89302372932434, 72.15836361050606, 71.07101395726204, 64.23610031604767, 60.00334024429321, 61.07664965093136, 63.51942837238312, 61.90319649875164, 61.51939049363136, 59.61558625102043, 57.27657236158848, 56.75810918211937, 60.21027334034443, 59.322154596447945, 61.276302337646484, 60.87342895567417, 63.68544526398182, 62.80006617307663, 70.75608685612679, 75.69110244512558, 81.6038815677166, 82.29912266135216, 82.29883387684822, 79.73828807473183, 77.02412411570549, 70.96648156642914, 67.38714203238487, 62.6246751844883, 65.74197471141815, 67.96011328697205, 84.50045093894005, 78.42393100261688, 88.46940636634827, 79.08133372664452, 95.03463327884674, 15.785757042467594, 1.1165048950351775, 0.6837728340178728, 0.5438009917270392, 0.2531334513332695, 0.35149307339452207, 0.5452921742107719, 0.9335134830325842, 0.4280664160614833, 0.24071423336863518, 1.594265727326274, 24.3539609760046, 34.65570978820324, 42.85824604332447, 29.019044749438763, 29.394544400274754, 41.12125284969807, 62.287762463092804, 68.31863924860954, 84.61230173707008, 57.316531017422676, 2.2942045563831925, 0.022368421887222212, 0.06092721094319131, 0.06758718111086637, 0.08982273444416933, 0.032986846345011145, 0.017793892257031985, 0.058110916361329146, 0.054582534794462845, 0.030078245290496852, 0.007511698731832439, 0.025624312802392524, 0.021582942063105293, 0.06260018621105701, 0.09533919976092875, 0.0321146818168927, 0.029188200569478795, 0.1707583840470761, 0.06615394551772624, 0.0790541864989791, 0.1141574524808675, 0.09727465410833247, 0.1909887805231847, 0.19241934438468888, 0.23430474917404354, 0.10679112470825203, 0.17323659325484186, 0.20813301525777206, 0.19103933562291786, 0.15183099108980969, 0.23988206317881122, 0.08769185034907423, 0.19565107097150758, 0.11424102573073469, 0.1718188388622366, 0.15348416956840083, 0.17683675163425505, 16.878709495067596, 112.04663962125778, 101.54200449585915, 95.20656645298004, 73.65336298942566, 69.37827318906784, 62.3096264898777, 120.55766612291336, 86.5407058596611, 76.11815392971039, 8.656161613762379, 0.2864316286286339, 0.5267692962661386, 3.980203536339104, 2.5928317196667194, 0.42007479176390916, 0.7632485975045711, 1.6301325964741409, 1.4867924130521715, 11.008044462651014, 114.18654039502144, 100.3661347925663, 116.59308806061745, 104.58603635430336, 105.55142015218735, 95.33103257417679, 93.44631850719452, 77.81866908073425, 85.88372111320496, 78.28463047742844, 80.12027397751808, 74.4291065633297, 74.78221401572227, 72.59105399250984, 73.77440929412842, 73.00868958234787, 73.0461023747921, 70.80728530883789, 73.17759051918983, 70.38778781890869, 72.53863200545311, 70.76921135187149, 71.01851597428322, 69.56662908196449, 73.57739746570587, 63.477296233177185, 68.6043231189251, 72.60622277855873, 70.51071882247925, 72.29821130633354, 73.55861887335777, 69.0349768102169, 71.54563128948212, 73.23952719569206, 77.17526480555534, 80.45694351196289, 74.49121803045273, 66.19486480951309, 65.79155445098877, 63.06293986737728, 68.89123052358627, 65.04263743758202, 67.7208249270916, 69.87742960453033, 74.16546151041985, 73.2202622294426, 74.45875257253647, 75.82148864865303, 80.05233362317085, 78.50538343191147, 89.5875571668148, 69.01137247681618, 59.85946476459503, 86.9195607304573, 78.90094220638275, 72.47286513447762, 68.33651348948479, 76.71024575829506, 74.48215931653976, 79.68414098024368, 76.04506865143776, 79.46327403187752, 79.2292369902134, 75.34347429871559, 77.03953608870506, 74.20719087123871, 69.02375981211662, 63.82470399141312, 63.57690788805485, 67.01677590608597, 67.182986587286, 66.46811574697495, 61.76509290933609, 63.27284440398216, 60.50115533173084, 63.71984861791134, 60.685240253806114, 63.17423589527607, 63.6798519641161, 69.42215323448181, 66.09707325696945, 75.9143328666687, 79.86829429864883, 87.88821995258331, 86.45552203059196, 86.06157436966896, 83.37896391749382, 80.50122633576393, 73.63424241542816, 73.40586706995964, 67.09422335028648, 70.45049965381622, 72.2694544494152, 88.12021270394325, 81.84777528047562, 95.18770426511765, 82.07092970609665, 102.098917812109, 12.424547653645277, 3.825540435500443, 2.1935358457267284, 0.9649756166618317, 0.34129059116821736, 0.708230281015858, 1.1632946343161166, 1.6281606210395694, 0.4975176346488297, 0.2771041385130957, 2.4086781637743115, 37.867593839764595, 42.506160736083984, 99.22140061855316, 47.72935666143894, 25.047552958130836, 52.556879818439484, 74.79279264807701, 82.03405648469925, 103.01076248288155, 67.8840109705925, 2.7821537107229233, 0.2178109623491764, 0.17318796773906797, 0.11476533822133206, 0.15400895703351125, 0.26141504757106304, 0.123917829914717, 0.14542637538397685, 0.1254627067828551, 0.13289804686792195, 0.06307065588771366, 0.1543910295004025, 0.10889864599448629, 0.23419164586812258, 0.1966428622836247, 0.08022644586162642, 0.121969514148077, 0.2229122628341429, 0.10851634346181527, 0.3353713994147256], [0.006888668540341314, 0.03634824097389355, 0.03795745833485853, 0.1071853238681797, 0.04686782805947587, 0.016373421603930183, 0.009163319627987221, 0.02043492866505403, 0.01110809627789422, 0.11347021631081589, 0.02497630655852845, 0.16015500848880038, 0.012908617973153014, 0.06227457633940503, 0.02644875909027178, 0.04345749621279538, 0.6119416072033346, 45.376028940081596, 76.99788272380829, 74.1049687564373, 64.18384552001953, 46.62619985640049, 24.792142063379288, 46.477597430348396, 95.36900013685226, 81.06925785541534, 28.22172213345766, 0.16293139779008925, 0.04807062308827881, 1.1222507804632187, 0.8189673826564103, 0.428408783627674, 0.5842013144865632, 0.41012063215021044, 0.5036205821670592, 0.45892079011537135, 71.70250967144966, 102.32578843832016, 101.29381701350212, 99.54688355326653, 98.88530865311623, 96.34733363986015, 83.82360845804214, 71.54579848051071, 74.19608026742935, 71.49830862879753, 69.01986122131348, 67.72150129079819, 68.20662125945091, 64.2411920428276, 63.33241380751133, 64.55360367894173, 67.51951172947884, 64.45750683546066, 66.37249007821083, 66.4967206120491, 64.90680232644081, 66.82705968618393, 64.35650825500488, 62.50631533563137, 62.737301141023636, 57.69643843173981, 59.93418775498867, 61.97014130651951, 61.687151491642, 67.51648709177971, 63.781492710113525, 62.54442349076271, 61.99916414916515, 68.60347956418991, 71.99782982468605, 73.4342211484909, 70.32405003905296, 65.61019018292427, 58.09385150671005, 57.73915193974972, 56.574586629867554, 57.39296771585941, 59.20680418610573, 60.27394652366638, 63.04955318570137, 66.42539083957672, 64.28598403930664, 67.5748747587204, 64.5781959593296, 71.19568526744843, 70.42479023337364, 80.74956580996513, 59.3688502907753, 55.894248336553574, 84.16236028075218, 65.47265276312828, 64.3461500108242, 66.08513429760933, 77.17877581715584, 74.56581562757492, 72.71319463849068, 73.01347732543945, 76.78564131259918, 73.31765860319138, 73.64298194646835, 67.44954988360405, 66.11242443323135, 58.03276598453522, 57.84094847738743, 60.119784995913506, 60.113583728671074, 56.86807528138161, 57.895243763923645, 55.82913503050804, 52.6789216697216, 52.85373508930206, 56.48239977657795, 57.84756772220135, 56.49480231106281, 59.340822994709015, 59.81576710939407, 57.24397771060467, 61.330172047019005, 61.13170489668846, 65.85727572441101, 70.72777837514877, 78.57327818870544, 71.64181172847748, 70.91849774122238, 64.75858747959137, 64.42420542240143, 58.31851825118065, 62.01450772583485, 61.212606355547905, 68.70336100459099, 76.44317328929901, 79.31429162621498, 78.40325251221657, 85.8232207596302, 68.47258418798447, 0.26580805715639144, 0.4469304741360247, 0.21387235494330525, 0.25842074886895716, 0.08124353698804043, 0.3687095339410007, 1.0185587382875383, 0.674038587603718, 0.09739594330312684, 0.23078512866050005, 7.640921166166663, 27.38825585693121, 33.753801584243774, 56.00269831717014, 27.04463079571724, 29.47381764650345, 40.60152433812618, 62.178206741809845, 54.53839749097824, 55.094562247395515, 8.53852467611432, 0.5068947002291679, 0.02224904928880278, 0.018927906894532498, 0.02720390177273657, 0.09427331242477521, 0.0801055648480542, 0.030989652732387185, 0.027202593737456482, 0.03612987886299379, 0.024908006707846653, 0.07196370017481968, 0.029971544863656163, 0.0499970751843648, 0.041900377618731, 0.07431143239955418, 0.07119615620467812, 0.03595708833017852, 0.06084482141886838, 0.048950821364996955, 0.07818743964890018, 0.07333106274018064, 0.016288855731545482, 0.06067502545192838, 0.03867968305712566, 0.05082907839096151, 0.01633551270060707, 0.07167857445892878, 0.07023710102657788, 0.06360154380672611, 0.04964294457749929, 0.05481314234202728, 0.035611329149105586, 0.07422796305036172, 0.023575961095048115, 0.09675602646893822, 1.179757488425821, 60.854593366384506, 96.98123082518578, 88.58223751187325, 78.76104891300201, 59.40105356276035, 39.104153886437416, 52.977931424975395, 73.07977616786957, 89.02280867099762, 32.85623274743557, 0.17004112800350413, 0.05762955566751771, 2.594617148861289, 1.6216458706185222, 1.3358875480480492, 0.8292017772328109, 0.9194949071388692, 0.27603140857536346, 0.8272270706947893, 85.08614391088486, 104.23640951514244, 108.89358401298523, 101.66812732815742, 105.72482004761696, 99.2177452147007, 90.44251129031181, 73.95706549286842, 78.51448014378548, 75.6059718132019, 73.37416157126427, 71.74019604921341, 70.91914370656013, 66.2805426120758, 67.8485132753849, 67.5869657099247, 69.64789152145386, 68.17897394299507, 69.49776157736778, 69.00267854332924, 68.1559319794178, 68.98339077830315, 66.17133647203445, 66.39144346117973, 66.88335746526718, 60.874135717749596, 62.600276693701744, 64.90321531891823, 65.34207656979561, 69.35347571969032, 67.99912959337234, 64.06849130988121, 66.06906116008759, 71.78557321429253, 75.20042717456818, 75.07908448576927, 75.39050057530403, 69.32157263159752, 61.43330991268158, 60.9270478785038, 61.68618254363537, 61.318955048918724, 63.08617182075977, 64.89253789186478, 68.10159489512444, 69.12320047616959, 68.99748802185059, 70.63162073493004, 65.92336177825928, 72.84999489784241, 74.81227040290833, 85.4934972524643, 63.49037893116474, 59.294807463884354, 89.90467295050621, 70.86788445711136, 66.74195185303688, 71.78482085466385, 79.60343331098557, 76.16276353597641, 76.39316037297249, 75.99508613348007, 80.45761227607727, 79.63357329368591, 78.14699426293373, 71.06064811348915, 69.46820676326752, 61.29514552652836, 61.52261272072792, 63.8716846704483, 62.68068037927151, 59.921268448233604, 59.88474480807781, 58.34086485207081, 55.753830671310425, 54.98434916138649, 59.228060245513916, 60.147166326642036, 61.16516590118408, 61.827208176255226, 62.451336085796356, 61.09218701720238, 63.05796593427658, 63.55475887656212, 68.52016523480415, 71.26201450824738, 78.50328594446182, 75.54820731282234, 72.89034113287926, 68.92826333642006, 66.13561078906059, 61.77239611744881, 64.08850863575935, 63.09589169919491, 69.0082186460495, 79.4504003226757, 81.64689525961876, 83.12001541256905, 86.37684345245361, 77.42443263530731, 0.7406029407866299, 0.5265933775808662, 0.2330766135128215, 0.5609762482345104, 0.5192512215580791, 0.12533042638096958, 1.0738154919818044, 1.6102233272977173, 0.42007087322417647, 0.5858986359089613, 7.742820773273706, 34.05025787651539, 34.268312975764275, 40.56765295565128, 31.088417507708073, 42.32207581400871, 50.23688390851021, 72.74924710392952, 68.52334186434746, 75.33856496214867, 19.957253001630306, 0.8356559684034437, 0.08002842601854354, 0.015342575698014116, 0.04471958141948562, 0.051336399410502054, 0.017923833038366865, 0.033122844906756654, 0.010340074550185818, 0.0475956522859633, 0.05442064270027913, 0.038839886765345, 0.04620776933734305, 0.056033975270111114, 0.021253317172522657, 0.02225065418315353, 0.01654673720622668, 0.04443174686457496, 0.01436670067050727, 0.05095515814900864, 0.09958708978956565, 0.13688057457329705, 0.10447457752889022, 0.33259867632295936, 0.16721823572879657, 0.17726801364915445, 0.16065552772488445, 0.15154673368670046, 0.16796943760709837, 0.1832211363944225, 0.11271419789409265, 0.260569533566013, 0.18789359426591545, 0.15834336663829163, 0.19811099366052076, 0.22410011471947655, 1.3857693714089692, 77.05861106514931, 117.32378125190735, 106.07883185148239, 94.70235630869865, 73.18571448326111, 37.988795936107635, 64.69832271337509, 112.47663214802742, 102.96584889292717, 45.01684181392193, 0.3772866236977279, 0.09844379645073786, 3.898605052381754, 5.324137033894658, 3.6206618417054415, 2.5752275018021464, 1.2392413965426385, 1.0881449980661273, 0.6165855517610908, 85.28129383921623, 104.22030597925186, 113.25758144259453, 105.86624085903168, 107.84792572259903, 102.5265620648861, 94.36353608965874, 77.55303293466568, 84.95147153735161, 78.31957340240479, 76.5301126241684, 74.13007780909538, 77.50086933374405, 70.41491076350212, 72.77114912867546, 72.65694245696068, 75.56224375963211, 72.63291254639626, 75.59174537658691, 73.67935359477997, 72.97140598297119, 72.27054879069328, 70.34710720181465, 68.72186601161957, 71.11518278717995, 64.59075048565865, 66.1857832968235, 66.89178541302681, 69.53734025359154, 72.50114321708679, 72.46283367276192, 68.60368475317955, 70.25056958198547, 74.34367194771767, 81.64277628064156, 79.16728511452675, 79.52515751123428, 72.9252840578556, 64.49069425463676, 63.96032631397247, 63.86954918503761, 66.77941024303436, 66.8522447347641, 69.20025274157524, 74.10646587610245, 74.64322507381439, 72.68535733222961, 73.98188576102257, 71.23947411775589, 76.69203713536263, 79.49796617031097, 87.15047433972359, 70.63988149166107, 63.038408383727074, 91.161098331213, 73.40221166610718, 70.0637412071228, 73.78676623106003, 84.2594526708126, 80.35727486014366, 78.56842204928398, 79.24204990267754, 83.93767073750496, 83.93799751996994, 81.935915350914, 76.2491101026535, 72.94944316148758, 64.6816112101078, 65.30515015125275, 67.00800597667694, 67.10059940814972, 63.107294887304306, 64.8261858522892, 61.689214780926704, 59.66020725667477, 58.07484492659569, 62.82155022025108, 65.50063446164131, 63.51494841277599, 66.31221771240234, 67.25382998585701, 64.52863901853561, 67.01649472117424, 67.23290830850601, 72.80961826443672, 76.19267553091049, 84.71580818295479, 79.95690554380417, 78.15960958600044, 71.99354365468025, 71.74914836883545, 63.99915263056755, 69.0197928249836, 67.11455225944519, 73.34678784012794, 84.3786446750164, 85.96784099936485, 86.8899755179882, 91.84829905629158, 78.83146673440933, 0.42339088569860905, 1.1987945856526494, 1.1384690226987004, 0.5425469996407628, 0.5788436019793153, 1.627044549677521, 4.377221670001745, 1.811267570592463, 0.45258709404151887, 0.8601927955169231, 14.254310019314289, 45.87520055472851, 49.55752596259117, 78.87742146849632, 35.39749078452587, 45.427846759557724, 61.37154042720795, 84.85926568508148, 81.97660356760025, 95.21218255162239, 23.168044611811638, 0.9205741679761559, 0.12332512851571664, 0.17310696974163875, 0.25930687319487333, 0.11897133401362225, 0.13336226023966447, 0.15883303567534313, 0.18221767852082849, 0.08701537532033399, 0.15814110171049833, 0.19425286474870518, 0.1329271835857071, 0.17922302358783782, 0.12011415979941376, 0.13011327129788697, 0.0894160004099831, 0.1506926552974619, 0.1498276079655625, 0.20830759807722643], [0.027403318708820734, 0.058995088838855736, 0.025009545497596264, 0.053661870915675536, 0.06932325006346218, 0.054277211529552005, 0.0187778965846519, 0.0353981509397272, 0.05288767730235122, 0.041321376265841536, 0.06444856437155977, 0.08146814056090079, 0.07422942508128472, 0.06528141733724624, 0.08024401991860941, 0.25973625015467405, 8.361885454505682, 61.59658335149288, 65.02857059240341, 72.51676797866821, 51.7534015327692, 37.53317378461361, 23.214932195842266, 65.75929418206215, 91.19715839624405, 67.19209089875221, 5.343394400551915, 0.028785116046492476, 0.29094183817505836, 1.3883407646790147, 1.0018697963096201, 0.3690753533737734, 1.074319202452898, 2.4354569893330336, 1.2827482307329774, 26.104646734893322, 114.50849711894989, 93.44413742423058, 105.26575148105621, 95.59761106967926, 98.64947810769081, 81.4894089102745, 77.5535649061203, 70.01973196864128, 75.79101428389549, 74.22068774700165, 77.68559262156487, 67.96844244003296, 62.83088631927967, 67.69795015454292, 62.51192003488541, 61.76633924245834, 62.2616882622242, 62.54950761795044, 62.815918922424316, 61.64409980177879, 64.89437699317932, 60.96076346933842, 64.52747628092766, 63.35586994886398, 60.3938452899456, 56.077698692679405, 58.34849864244461, 59.64305877685547, 63.42921361327171, 63.04318852722645, 62.44386188685894, 59.47590574622154, 63.254255801439285, 72.95298457145691, 77.7223290503025, 73.8209567964077, 70.06848335266113, 68.2250502705574, 57.85591967403889, 54.46994796395302, 55.81739366054535, 56.14735275506973, 55.12948237359524, 58.31866264343262, 59.06122639775276, 63.217724561691284, 65.01306742429733, 68.70270743966103, 61.18750490248203, 69.01464030146599, 68.67021158337593, 81.22934326529503, 57.499464601278305, 59.54492524266243, 82.38638877868652, 61.68926417827606, 64.3345758318901, 68.97152781486511, 73.98455321788788, 68.51267203688622, 73.93052771687508, 74.08842444419861, 74.67695206403732, 74.5205220580101, 75.24192854762077, 72.46646627783775, 61.83405160903931, 56.79332189261913, 58.4139159321785, 59.4455149769783, 59.25817742943764, 57.195594906806946, 55.76344795525074, 53.08266140520573, 53.495957627892494, 53.26140381395817, 53.471965715289116, 53.22844058275223, 56.69754423201084, 56.13932378590107, 58.001060485839844, 60.381412357091904, 57.69941367208958, 59.01470169425011, 56.02512091398239, 59.52964246273041, 61.40984617173672, 66.17544785141945, 60.77126003801823, 63.458627834916115, 56.66177675127983, 58.257451727986336, 57.21402771770954, 61.25932864844799, 58.238346353173256, 69.6440689265728, 69.58717077970505, 84.91715177893639, 75.4836867749691, 95.70452213287354, 22.21646547317505, 0.9207353624515235, 0.13268208189401776, 0.417142121004872, 0.13473098835675046, 0.5282091221306473, 0.13897251075832173, 0.3217679512454197, 0.14737537392647937, 0.125585250207223, 0.2442774476367049, 20.444263368844986, 23.613813892006874, 57.23482400178909, 43.777363523840904, 18.198241889476776, 46.230280101299286, 45.14856934547424, 59.06710468232632, 47.26738505065441, 36.97119913995266, 7.375452686101198, 0.14239588956115767, 0.0952110457001254, 0.10070900185382925, 0.08012314632651396, 0.02709336444240762, 0.05038835028244648, 0.03686555501190014, 0.0664418913947884, 0.05061424890300259, 0.13291530922288075, 0.1335274919983931, 0.03185474830388557, 0.05688343750080094, 0.036906310051563196, 0.14074659993639216, 0.05932380830927286, 0.04306516726501286, 0.02992378951603314, 0.06485684949439019, 0.03630623541539535, 0.05139817207236774, 0.03172430100676138, 0.04659245787479449, 0.054059391186456196, 0.038640282436972484, 0.09527020971290767, 0.05010482018406037, 0.01313314269282273, 0.03440733555180486, 0.01548404203276732, 0.054010272142477334, 0.022289655898930505, 0.0995382787368726, 0.165627739042975, 11.59011147916317, 86.67375192046165, 82.15042144060135, 86.72314167022705, 64.03826773166656, 53.45178119838238, 32.60644935071468, 52.82726190984249, 86.4964610338211, 74.408960044384, 4.81731690466404, 0.2634018362732604, 0.8954793051816523, 2.7369370870292187, 1.4053950808010995, 0.4643860546639189, 4.676466537639499, 3.9379365043714643, 1.3158476608805358, 36.30486689507961, 118.86674925684929, 98.09905484318733, 111.41544789075851, 99.58151489496231, 101.10404759645462, 85.2587078511715, 80.38522616028786, 73.71387854218483, 79.65343102812767, 77.39524260163307, 78.61658066511154, 71.87663152813911, 68.14110517501831, 70.34924268722534, 65.20464554429054, 65.2772368490696, 65.19185543060303, 65.16125187277794, 66.85326308012009, 65.24609372019768, 66.79629653692245, 63.95459622144699, 66.96394354104996, 65.77692523598671, 63.56545150279999, 59.666689708828926, 62.376457303762436, 61.82424433529377, 66.56800478696823, 67.21714675426483, 64.94442030787468, 64.0387237071991, 67.33285814523697, 77.77931079268456, 80.63198491930962, 77.60325863957405, 73.57659190893173, 72.88903400301933, 63.286223486065865, 58.596230149269104, 60.51875978708267, 57.61690869927406, 57.67630331218243, 61.7517214268446, 61.13904230296612, 66.86144024133682, 67.14480623602867, 70.84093630313873, 64.5804150402546, 70.70665150880814, 73.08337077498436, 84.94004935026169, 60.00562012195587, 60.831163823604584, 85.2733826637268, 66.621483117342, 65.84121778607368, 73.10043945908546, 77.19114035367966, 71.16717159748077, 76.19820043444633, 77.37802952528, 77.36543700098991, 78.0023056268692, 79.61256042122841, 73.53779599070549, 63.29347349703312, 59.74399276077747, 60.7620607316494, 60.62389634549618, 60.65557524561882, 59.79191578924656, 59.56903874874115, 56.29373989999294, 56.164805218577385, 57.15261921286583, 55.80160930752754, 56.03028103709221, 59.10067968070507, 58.996185287833214, 59.546764343976974, 62.90858455002308, 59.220958426594734, 61.87418885529041, 59.82903599739075, 63.10404226183891, 63.935863226652145, 67.22683623433113, 62.95555762946606, 64.14020866155624, 60.255513712763786, 63.04565839469433, 60.962245389819145, 64.78252619504929, 62.977338060736656, 71.34702354669571, 73.94977748394012, 88.5388970375061, 76.61756113171577, 99.05318364501, 29.841294027864933, 0.9549795999191701, 0.21450690604979172, 0.8278165734373033, 0.5747953942045569, 1.1026932299137115, 1.369967325590551, 2.549908747896552, 1.189523320645094, 0.2126959915040061, 0.1195969496620819, 21.188588328659534, 32.39293120801449, 38.930753991007805, 32.41605296730995, 31.196046732366085, 55.180228650569916, 56.684966906905174, 72.67322078347206, 62.69574657082558, 57.39574156701565, 11.226325649768114, 0.11754465900594369, 0.08453543690848164, 0.04350776187493466, 0.043275042917230166, 0.018998342275153846, 0.041212629366782494, 0.03518769641232211, 0.0699882885965053, 0.03847512860374991, 0.02775459946860792, 0.13520243024686351, 0.15878341568168253, 0.090639341797214, 0.08518489776179194, 0.07500441279262304, 0.07506401467253454, 0.05187620423384942, 0.05355919849534985, 0.19368470617337152, 0.1323640122427605, 0.15555491001578048, 0.11865543885505758, 0.14743710577022284, 0.16030597616918385, 0.16234118258580565, 0.2616172085981816, 0.15043104824144393, 0.1651401331764646, 0.18685764516703784, 0.1237045440939255, 0.13815300160786137, 0.14909665187587962, 0.2040620829211548, 0.35524664854165167, 13.554917648434639, 110.76540157198906, 100.25386601686478, 106.68380498886108, 78.46483960747719, 59.41304191946983, 32.98126123845577, 89.50705468654633, 113.62639725208282, 90.83920240402222, 9.173294864594936, 0.26540438819210976, 1.313650191295892, 6.040672184899449, 3.167273970320821, 2.3308011051267385, 8.462787140160799, 10.41928505524993, 1.9615866732783616, 31.120102107524872, 121.29463657736778, 97.99997135996819, 116.61385014653206, 100.9398128092289, 107.3422260582447, 89.21083018183708, 85.53093284368515, 77.81059071421623, 85.49697026610374, 83.06937173008919, 85.57717636227608, 75.46958193182945, 70.54002285003662, 74.28802773356438, 68.45463395118713, 67.79404699802399, 70.1544651389122, 69.51483026146889, 70.59551507234573, 68.2925346493721, 71.19556367397308, 66.62799596786499, 69.54064607620239, 70.02640441060066, 68.03851827979088, 64.35580149292946, 66.04061588644981, 65.73898807168007, 70.41842937469482, 69.64394733309746, 69.96977224946022, 66.71558886766434, 71.50833249092102, 80.57153016328812, 85.26220366358757, 81.81382790207863, 76.67742311954498, 75.96620008349419, 65.12043446302414, 61.553641855716705, 65.94358429312706, 62.68733002245426, 61.962078139185905, 65.90212851762772, 66.41359627246857, 72.71723762154579, 71.92621886730194, 76.86899363994598, 69.54341992735863, 74.52461823821068, 76.62253126502037, 90.50285965204239, 64.78409931063652, 67.48716026544571, 90.52812829613686, 69.32477965950966, 69.92599099874496, 76.43954828381538, 78.86147752404213, 72.94994473457336, 80.54050862789154, 80.71346014738083, 81.16906329989433, 82.30581790208817, 84.17451202869415, 78.56283634901047, 67.78488948941231, 61.24143160879612, 63.39491665363312, 64.23261970281601, 66.86251938343048, 62.68376961350441, 63.64079765975475, 59.23838809132576, 59.53836679458618, 60.22578410804272, 60.38756042718887, 58.38565304875374, 62.89102949202061, 62.706446796655655, 63.69954250752926, 67.24563002586365, 64.3339754641056, 65.09895041584969, 61.382601633667946, 66.48559480905533, 68.43337789177895, 72.78197094798088, 69.09499078989029, 68.85906144976616, 63.256664872169495, 66.15913912653923, 63.97549510002136, 68.83406639099121, 66.67635977268219, 77.18351036310196, 79.39041674137115, 93.63792702555656, 80.07581636309624, 104.70258370041847, 27.399271465837955, 1.3275670632719994, 0.46870476042386144, 3.372737020254135, 0.5096199852414429, 1.5044114738702774, 3.515187813900411, 4.94446330703795, 0.795662283198908, 0.16776669770479202, 0.3757998941000551, 34.881577268242836, 36.99623599648476, 80.54566875100136, 59.89952601492405, 29.560116715729237, 64.03664141893387, 69.94229212403297, 84.91992563009262, 83.69543373584747, 76.09148696064949, 11.246529165655375, 0.25167343905195594, 0.11390901112463325, 0.24952453561127186, 0.26098442380316556, 0.18391434685327113, 0.13997820991789922, 0.12624188762856647, 0.17636983684496954, 0.12665045476751402, 0.21578408282948658, 0.27606142102740705, 0.22505902888951823, 0.16564615914830938, 0.2018224445055239, 0.18723505694651976, 0.17222764348844066, 0.142250235658139, 0.23068213340593502], [0.08710471505764872, 0.08146418491378427, 0.03086245975282509, 0.03827991778962314, 0.045238680322654545, 0.04867347335675731, 0.016678781976224855, 0.009187809573631966, 0.015790447905601468, 0.05764033165178262, 0.09895887662423775, 0.04562222595268395, 0.07850913098081946, 0.026461870984348934, 0.08915263446397148, 0.051026957225985825, 32.22214937210083, 70.63318625092506, 70.45857042074203, 66.60889059305191, 48.46648670732975, 26.82493608444929, 39.96424913406372, 95.2855110168457, 68.55722844600677, 31.479405127465725, 0.23070009337970987, 0.13787595788016915, 0.6577189383096993, 0.5599377758335322, 1.7727048648521304, 1.2619139486923814, 1.3891507149673998, 2.8812645049765706, 4.545939741656184, 95.03264978528023, 99.19222578406334, 101.32043838500977, 96.475660353899, 94.77042585611343, 87.46595621109009, 77.32591912150383, 69.7394286096096, 72.08612188696861, 69.84836876392365, 67.79018640518188, 67.85276144742966, 64.06828612089157, 65.75340449810028, 65.96170172095299, 66.53879955410957, 64.79973167181015, 61.51840254664421, 62.667928263545036, 61.81673973798752, 62.04465910792351, 62.09925837814808, 64.58982333540916, 63.241359293460846, 59.97462138533592, 54.82261463999748, 58.63478668034077, 60.39525121450424, 61.30907937884331, 62.70396552979946, 61.76703080534935, 59.28640991449356, 60.33065088093281, 60.86457923054695, 75.9367136657238, 75.2592708170414, 77.87467807531357, 69.77828532457352, 67.41560250520706, 58.769725039601326, 58.52146156132221, 54.39377345144749, 56.89098045229912, 53.61248977482319, 57.32270568609238, 58.153219521045685, 64.22191187739372, 64.07976910471916, 67.51885056495667, 59.84226308763027, 67.39122301340103, 69.36645582318306, 77.6279953122139, 53.78210887312889, 62.377863228321075, 79.45398733019829, 63.45824025571346, 64.68759968876839, 72.79378071427345, 72.8258889913559, 71.06654539704323, 72.77003958821297, 67.82645925879478, 72.69496321678162, 70.54126918315887, 67.67601013183594, 64.21998158097267, 55.78343868255615, 55.59229373931885, 58.17584350705147, 58.18412706255913, 56.50528594851494, 54.837255254387856, 55.63986338675022, 52.38171301782131, 52.08547331392765, 52.278803139925, 50.307104140520096, 51.533948108553886, 54.70708943903446, 56.25340886414051, 57.19937950372696, 57.809904143214226, 57.63173550367355, 58.82153145968914, 60.03400839865208, 58.69619898498058, 56.172393411397934, 56.482566967606544, 56.531667932868004, 56.297703087329865, 57.69898049533367, 58.54406274855137, 57.73160554468632, 60.380059629678726, 61.83754742145538, 61.46424785256386, 65.87899535894394, 75.74721023440361, 80.18131390213966, 83.1047174334526, 75.19222721457481, 2.0485959481447935, 0.3456899832235649, 0.3816608717897907, 0.5988204956520349, 0.2590376220177859, 1.4130183029919863, 1.7929831892251968, 0.933538181707263, 0.4730405058944598, 0.36003489629365504, 6.418440314009786, 26.709454581141472, 38.97744208574295, 73.06772321462631, 19.976521767675877, 25.69282103329897, 45.29052212834358, 59.938504323363304, 47.54280187189579, 44.105563312768936, 28.613843992352486, 11.486107259988785, 0.44191747438162565, 0.006680316146230325, 0.0951747917861212, 0.06764490535715595, 0.034228073491249233, 0.04712285226560198, 0.02052306055702502, 0.06617510414798744, 0.031020591013657395, 0.05707607306248974, 0.0699818912835326, 0.01747471123962896, 0.014450877843046328, 0.05627938866382465, 0.09495509380940348, 0.03406117561098654, 0.023568695469293743, 0.07064900783007033, 0.02632322852150537, 0.05419423570856452, 0.041853908041957766, 0.07226126428577118, 0.029207769148342777, 0.03963546536397189, 0.06775636851671152, 0.04459976538782939, 0.07944345037685707, 0.10279485242790543, 0.08463390506221913, 0.022657096924376674, 0.07565395528217778, 0.0722406548447907, 0.10546643563429825, 47.61659771203995, 91.73665344715118, 85.88583379983902, 81.6147793829441, 63.12722481787205, 38.76768574118614, 44.64695826172829, 70.79301327466965, 74.09003555774689, 35.39189748466015, 0.2939510392025113, 0.18795741896610707, 1.6083147609606385, 3.0236143665388227, 3.5451442189514637, 2.23909183871001, 1.5194801590405405, 2.3216823069378734, 8.335018046200275, 108.40551540255547, 100.87829411029816, 106.58277601003647, 98.98968145251274, 103.15704703330994, 91.32013499736786, 81.32163271307945, 72.0455476641655, 77.53970324993134, 75.62631592154503, 74.39469560980797, 70.934639275074, 69.24211129546165, 70.97835972905159, 70.60908794403076, 68.28540623188019, 70.14670595526695, 64.77292031049728, 66.47851198911667, 64.91390034556389, 64.39769804477692, 65.64226046204567, 67.39772066473961, 66.44764244556427, 62.73954302072525, 56.906103640794754, 62.01589845120907, 62.304553762078285, 64.0764556825161, 65.63643157482147, 64.49862062931061, 62.512330412864685, 61.42254889011383, 63.17765951156616, 79.1560985147953, 79.8989586532116, 81.20086759328842, 71.29056617617607, 70.4264697432518, 62.1844308078289, 62.716873437166214, 57.357527017593384, 60.14085866510868, 56.761373206973076, 61.073628813028336, 62.40495577454567, 67.64691889286041, 67.16667786240578, 71.60362377762794, 63.336285799741745, 70.9042789041996, 72.47365549206734, 80.85142314434052, 57.53606043756008, 66.47896036505699, 83.67236897349358, 67.33394488692284, 69.7382202744484, 77.40453690290451, 75.00495806336403, 73.75378400087357, 76.5424619615078, 71.70094415545464, 73.34188610315323, 72.58797615766525, 70.28339982032776, 65.7770012319088, 58.509123623371124, 57.816960364580154, 60.228200778365135, 59.02152992784977, 58.463298082351685, 57.26718306541443, 55.645456686615944, 56.24950647354126, 55.0236314535141, 54.9406249076128, 54.19886291027069, 55.370716229081154, 57.75343157351017, 58.47786270081997, 59.56689566373825, 60.533434599637985, 59.516776353120804, 62.50568836927414, 63.927845656871796, 60.62226623296738, 58.96837458014488, 59.27745379507542, 58.834758549928665, 58.783966675400734, 60.75881950557232, 60.52843026816845, 62.09877960383892, 64.52592596411705, 65.53960517048836, 64.11391407251358, 69.21191811561584, 78.07578608393669, 84.8375840485096, 84.75889787077904, 82.28354349732399, 3.8696565432474017, 0.3085763059789315, 0.12157458026194945, 1.4766317582689226, 0.44791655091103166, 2.200617715716362, 2.1908719511702657, 2.541293897666037, 1.2728304066695273, 0.5591990717221051, 5.153330499306321, 34.24808666110039, 41.429864689707756, 44.531140476465225, 27.377544231712818, 42.00849764049053, 59.565501138567924, 71.86406180262566, 64.30714130401611, 58.0081433057785, 43.81622023880482, 16.619044728577137, 0.3234262653859332, 0.04882826309767552, 0.07761829401715659, 0.035993516648886725, 0.06787436257582158, 0.011587545013753697, 0.021858892978343647, 0.02491639112122357, 0.04359809980087448, 0.06009479955537245, 0.03571692563127726, 0.028191666933707893, 0.05956696557404939, 0.07950630286359228, 0.05483445682330057, 0.07720576380961575, 0.03582558718335349, 0.16101840825285763, 0.24550328264012933, 0.14588108926545829, 0.12622407608432695, 0.18717268685577437, 0.17361897742375731, 0.20079459965927526, 0.17844897840404883, 0.08081559237325564, 0.1880050648469478, 0.17825907765654847, 0.14427058427827433, 0.1838659291388467, 0.11997893307125196, 0.18303133954759687, 0.2118044495000504, 56.46981485188007, 111.73351362347603, 102.44112744927406, 95.4402007162571, 72.8300079703331, 39.46983866393566, 55.96528932452202, 120.94328463077545, 88.66339355707169, 50.786053240299225, 0.5210979818366468, 0.2975997934117913, 1.9488223269581795, 4.46911308914423, 9.002286940813065, 4.8729174211621284, 6.986113702878356, 7.682509459555149, 6.890759719535708, 110.87512448430061, 104.87257897853851, 110.92003047466278, 104.15754094719887, 104.49340492486954, 94.8383130133152, 86.06706887483597, 76.165841370821, 80.97384497523308, 79.32530343532562, 78.97129163146019, 75.37224635481834, 70.34956187009811, 74.88464891910553, 73.12180191278458, 72.35786810517311, 74.36089262366295, 68.37032407522202, 70.55207580327988, 67.28336200118065, 67.10199013352394, 68.91288176178932, 70.77250957489014, 68.80304485559464, 66.908238530159, 60.498560070991516, 65.93402400612831, 67.01049864292145, 66.35498821735382, 68.3706584572792, 69.9669300019741, 65.53220316767693, 68.24201256036758, 67.20085322856903, 82.16131925582886, 83.97490113973618, 84.78105828166008, 75.39370760321617, 73.73449623584747, 65.49260169267654, 65.1242646574974, 60.162764489650726, 64.65446546673775, 60.990132093429565, 65.76889246702194, 67.20770806074142, 71.26672625541687, 71.88539385795593, 76.25164076685905, 67.38243788480759, 74.96405705809593, 77.3679068684578, 84.40424010157585, 64.09445911645889, 70.64105182886124, 86.74287781119347, 69.9126461148262, 73.7891449034214, 81.97406530380249, 78.71838480234146, 77.4570880830288, 80.74384331703186, 77.3162068426609, 81.06892347335815, 78.31534042954445, 74.78403031826019, 70.84550365805626, 62.466580867767334, 61.927750781178474, 63.789920657873154, 63.12572009861469, 61.6253288090229, 62.3187991976738, 60.97736097872257, 59.35754969716072, 58.316998332738876, 58.58037360012531, 59.78604890406132, 59.81140114367008, 62.4419391900301, 60.57797580957413, 63.17708194255829, 64.36043724417686, 62.61153928935528, 66.148142516613, 68.35757195949554, 65.82089647650719, 62.64676719903946, 63.04584838449955, 61.91578522324562, 63.77459987998009, 64.88833531737328, 64.30122882127762, 65.67930847406387, 67.97910466790199, 67.37488389015198, 68.34936439990997, 72.19797268509865, 82.28042766451836, 87.95119017362595, 89.56824660301208, 82.43925914168358, 2.8764655999839306, 0.5923819192685187, 3.385460637509823, 3.0425060028210282, 0.4905387747567147, 3.6759609868749976, 7.566809467971325, 2.4874277506023645, 1.331637476105243, 0.8213792438618839, 9.750709980726242, 43.126979023218155, 57.56592683494091, 95.97423166036606, 28.770709075033665, 43.446002304553986, 65.39439976215363, 85.49791261553764, 78.66433650255203, 81.62069946527481, 56.552669405937195, 16.6837552562356, 0.3219696372980252, 0.07266612810781226, 0.2582145208725706, 0.18761159299174324, 0.1637967419810593, 0.13818423118209466, 0.10399031132692471, 0.2616191381821409, 0.16175466327695176, 0.27598592976573855, 0.11326815918437205, 0.0876582162163686, 0.09623274556361139, 0.1394173689186573, 0.15792098070960492, 0.15413130749948323, 0.12911972851725295], [0.1194605948694516, 0.0737329431285616, 0.16187128436286002, 0.06369061637087725, 0.051556127073126845, 0.056673038634471595, 0.05497682301211171, 0.052047232165932655, 0.04335794452344999, 0.0386656861519441, 0.04022496068500914, 0.15360301709733903, 0.012713381183857564, 0.11790081567596644, 0.029920294000476133, 3.4824898559600115, 76.49925827980042, 67.15128108859062, 70.86476102471352, 49.92704853415489, 34.27409626543522, 24.037422761321068, 54.437231719493866, 89.46371421217918, 60.18269822001457, 7.176748523488641, 0.01888645794679178, 0.7898309617303312, 1.792262177914381, 1.6419380879960954, 1.0212799860164523, 0.3924458211986348, 1.9228204409591854, 0.23217246984131634, 53.91740061342716, 105.03855407238007, 93.47205832600594, 99.24345463514328, 88.6821037530899, 93.0712254345417, 73.38596373796463, 72.40903615951538, 66.9684424996376, 69.24495354294777, 68.96949872374535, 66.84859693050385, 66.27697840332985, 67.09075793623924, 65.55781379342079, 67.22022458910942, 66.99611261487007, 66.71251103281975, 62.63909921050072, 64.19588327407837, 62.29926824569702, 63.63447479903698, 59.92669075727463, 63.621977269649506, 62.295267060399055, 55.616361647844315, 54.5369877666235, 59.0816693007946, 58.72730031609535, 61.084826812148094, 58.01871053874493, 59.56517055630684, 57.77390867471695, 58.18128861486912, 65.24548575282097, 74.61876958608627, 77.63101994991302, 76.10183000564575, 70.63302665948868, 64.34858188033104, 60.72926469147205, 59.5292054861784, 56.636337116360664, 55.722805336117744, 56.2298159301281, 62.43824198842049, 62.71610587835312, 68.10350239276886, 64.77406784892082, 70.38476318120956, 58.86185109615326, 64.58816662430763, 70.54824560880661, 72.4181404709816, 54.56058830022812, 66.24749958515167, 75.60891285538673, 63.14499646425247, 63.03748123347759, 73.5822232067585, 74.06453132629395, 71.61964371800423, 66.50084719061852, 63.45272675156593, 58.47123205661774, 57.495486214756966, 57.287219390273094, 54.076798260211945, 56.995414048433304, 56.7502436041832, 57.10694566369057, 54.698517099022865, 55.87611570954323, 54.42370064556599, 52.37382844090462, 52.199596390128136, 52.893492355942726, 50.664387568831444, 52.07485668361187, 50.57726204395294, 52.270983159542084, 55.03671035170555, 56.231704428792, 56.84391997754574, 56.78848475217819, 57.59860888123512, 58.6177521944046, 55.74886053800583, 57.50414974987507, 56.338452100753784, 56.39599621295929, 54.132769256830215, 57.578982934355736, 58.078306540846825, 63.05427633225918, 61.57854951918125, 64.7264564037323, 63.30703876912594, 67.81136646866798, 70.7182864844799, 80.82262828946114, 75.91712191700935, 86.83531165122986, 38.86885531246662, 0.08954425837146118, 0.09608980792108923, 2.3307303339242935, 0.383892361423932, 0.8064833306707442, 2.130128648132086, 3.344373917207122, 0.7882710266858339, 0.08809829494566657, 0.03282866127847228, 20.621280670166016, 28.740981370210648, 59.60643634200096, 43.06372381746769, 12.494670040905476, 32.56194233894348, 53.503298833966255, 51.900921016931534, 42.10514545440674, 45.276641473174095, 34.01764802634716, 9.548165649175644, 0.3137207846157253, 0.02585743808594998, 0.0832848587015178, 0.07208979848655872, 0.018436649661452975, 0.08761200268054381, 0.013609878878924064, 0.009939123701769859, 0.03893181659805123, 0.05810736147395801, 0.048843499389477074, 0.10387158996309154, 0.007131756228773156, 0.020490513670665678, 0.04550200916128233, 0.03715491468028631, 0.05525404485524632, 0.08100892926449887, 0.058183383371215314, 0.05660526570864022, 0.010319274006178603, 0.034900485261459835, 0.03001578057592269, 0.03290501714218408, 0.026344593097746838, 0.059436429219204, 0.0910697206563782, 0.03236132346501108, 0.011883164697792381, 0.16055772750405595, 0.13339221331989393, 5.4932008869946, 94.94732156395912, 82.77471274137497, 85.90699106454849, 60.808946415781975, 43.60167995095253, 30.988083891570568, 47.39930637180805, 73.81593346595764, 70.07868960499763, 8.304735571146011, 0.17485174408648163, 1.2566032586619258, 5.8739380817860365, 4.13440614938736, 1.7660361039452255, 2.200047983787954, 2.884701658040285, 0.9849177778232843, 71.60905748605728, 108.00545766949654, 98.95595446228981, 103.90542447566986, 94.2082916200161, 93.19874659180641, 75.890401750803, 75.69656655192375, 72.10059151053429, 72.22505003213882, 73.77012312412262, 71.236821860075, 70.12147530913353, 69.96370777487755, 69.68168690800667, 70.94602346420288, 69.11022797226906, 70.65558984875679, 68.25504586100578, 67.69035056233406, 64.64134097099304, 67.17455863952637, 65.4964166879654, 66.2894569337368, 64.68147441744804, 60.50057776272297, 59.044336304068565, 63.00294488668442, 63.947095423936844, 63.044343665242195, 60.731529369950294, 61.15127384662628, 61.67690344154835, 59.33592885732651, 69.45407912135124, 77.81903386116028, 80.41418060660362, 79.07750353217125, 72.99787536263466, 67.39898979663849, 61.90117880702019, 62.26065471768379, 60.1572547852993, 59.4299054145813, 59.05898071825504, 65.0728990137577, 65.51733076572418, 72.49460756778717, 69.77670460939407, 73.11149686574936, 63.54427143931389, 67.42396205663681, 75.52425339818001, 76.11500009894371, 56.44645370543003, 67.955272346735, 79.13940981030464, 65.46471878886223, 67.77129381895065, 77.2172449529171, 76.35571718215942, 74.0718649327755, 68.7615966796875, 65.06330072879791, 61.33027844130993, 59.14291821420193, 59.606508538126945, 59.029836282134056, 59.0700913220644, 59.3462111055851, 59.71189208328724, 57.66057975590229, 59.250243455171585, 57.234250232577324, 55.72050265967846, 55.95888286828995, 56.457442715764046, 53.65066632628441, 55.94090983271599, 55.578827261924744, 55.285505801439285, 57.84655697643757, 58.13262462615967, 59.98076185584068, 59.59888614714146, 61.378706842660904, 60.0492911785841, 58.68568494915962, 59.0105827152729, 59.221129417419434, 60.00824198126793, 58.5825926810503, 60.17417147755623, 61.301377192139626, 65.75826063752174, 65.04316180944443, 69.16835725307465, 66.30538567900658, 74.0638093650341, 73.72581750154495, 83.63763883709908, 78.7398536503315, 90.77569261193275, 49.604160860180855, 0.19809520075796172, 0.09736128500662744, 0.027120014965476003, 0.5705222859978676, 2.125836778432131, 2.2238263953477144, 5.66897090524435, 2.8822766756638885, 0.08559305671951734, 0.11182780639501289, 19.01070859283209, 41.15149922668934, 49.34099458158016, 24.331601075828075, 23.081673346459866, 45.33196270465851, 59.054618552327156, 66.99909925460815, 60.04171058535576, 62.182853892445564, 41.86761260032654, 12.781808283179998, 0.39291545224841684, 0.014248555398808094, 0.02714308833674295, 0.05058769114839379, 0.00688125077431323, 0.050971952950931154, 0.053375643110484816, 0.05427835072623566, 0.004168631903667119, 0.09341273282188922, 0.05014590176870115, 0.07768873867462389, 0.06266427066293545, 0.01880186053313082, 0.006545007317981799, 0.07693154766457155, 0.30987304577138275, 0.16726594098145142, 0.3176323481602594, 0.08888609212590382, 0.18158155406126752, 0.1055102000827901, 0.16358065826352686, 0.2096407624776475, 0.18646366865141317, 0.18396267550997436, 0.11137890352983959, 0.21767203230410814, 0.25552883686032146, 0.4603178385877982, 0.2512305846903473, 6.365985553711653, 113.3822375535965, 97.5571583211422, 100.7175475358963, 74.78893205523491, 51.37886323034763, 33.83093744516373, 72.05750182271004, 105.80315664410591, 89.84070718288422, 13.1397595256567, 0.25435475923586637, 1.8327347561717033, 8.327330108731985, 10.449566580355167, 4.013386918231845, 4.471073783934116, 14.097357541322708, 0.9577819495461881, 68.49270030856133, 113.17700296640396, 103.24669942259789, 107.48981013894081, 98.76024976372719, 99.02855336666107, 78.82218763232231, 80.54785743355751, 77.26589754223824, 77.26872459053993, 77.18512147665024, 74.62228819727898, 73.87273281812668, 74.25961285829544, 75.82178503274918, 76.32430046796799, 73.61538022756577, 74.01834860444069, 71.26335203647614, 72.2096836566925, 70.52201941609383, 70.61880022287369, 67.78357475996017, 70.38040101528168, 69.34123277664185, 64.33137640357018, 62.05308325588703, 66.41012325882912, 66.0896484553814, 66.24338060617447, 65.1799164712429, 66.33161187171936, 63.92299711704254, 63.4580996632576, 72.63897702097893, 82.3040471971035, 84.44691181182861, 81.81284755468369, 75.53604036569595, 71.73394918441772, 67.34380915760994, 66.1158138513565, 64.18087407946587, 60.46987161040306, 62.804667726159096, 67.60635986924171, 69.7291311621666, 77.06633225083351, 70.54186955094337, 79.30395618081093, 66.82362467050552, 73.39573681354523, 78.07224467396736, 78.7828977406025, 62.775245904922485, 70.45448184013367, 82.93047398328781, 69.84564051032066, 69.52176868915558, 80.28841495513916, 78.8589696586132, 77.98470497131348, 75.72595417499542, 69.90522131323814, 66.61160364747047, 65.88394269347191, 65.08161574602127, 62.47763067483902, 63.424319475889206, 63.15242886543274, 62.85666033625603, 60.36293014883995, 62.608894631266594, 60.94486892223358, 59.876309260725975, 58.64699922502041, 60.027799531817436, 56.70352131128311, 60.27168944478035, 58.40060144662857, 58.186422139406204, 60.510719418525696, 59.95199739933014, 61.932261139154434, 62.856550142169, 64.13581609725952, 64.71587777137756, 61.85317598283291, 62.998244538903236, 62.263736352324486, 61.78990937769413, 60.599463656544685, 63.46300520002842, 65.03126084804535, 69.06296610832214, 67.47421056032181, 72.4214842915535, 69.07331675291061, 76.6734105348587, 76.82545557618141, 87.44070276618004, 83.49165067076683, 95.64033597707748, 46.21378518640995, 0.19367691362276673, 1.7348775384016335, 5.342610217630863, 1.056627945508808, 4.289855808019638, 5.440671555697918, 11.40501581132412, 2.7606615889817476, 0.1257772438111715, 0.2968018362298608, 31.755914390087128, 45.678302720189095, 83.24690580368042, 55.833478197455406, 19.82874769717455, 48.37553858757019, 71.99432641267776, 82.94652432203293, 76.5748742222786, 79.7877462208271, 51.50058589875698, 12.915469910949469, 0.6668842246290296, 0.14164103631628677, 0.25347457209136337, 0.1606354006798938, 0.13486637093592435, 0.1554299917188473, 0.13942010002210736, 0.16534532216610387, 0.19329953152919188, 0.2097743342164904, 0.1432387318345718, 0.30964247533120215, 0.1896109091467224, 0.09884804429020733, 0.13044461054960266, 0.17487057979451492], [0.030727615230716765, 0.053851645498070866, 0.07055002759443596, 0.04859018212300725, 0.05837774442625232, 0.0478582909272518, 0.04918791528325528, 0.0181599065035698, 0.027421725826570764, 0.027791278262156993, 0.021853735051990952, 0.09626620900235139, 0.06599863627343439, 0.008544541014998686, 0.07671112238313071, 23.853862211108208, 76.03718027472496, 69.83210563659668, 67.66329601407051, 61.51598207652569, 37.262339517474174, 38.93399901688099, 87.46072769165039, 60.92222973704338, 34.790971130132675, 1.1096776113845408, 0.0017035395762832195, 0.1932451469474472, 2.049909015186131, 4.414500994607806, 1.0576996067538857, 1.3036363036371768, 2.6045049307867885, 19.472017139196396, 105.42319223284721, 92.10029393434525, 98.18483144044876, 91.50981321930885, 84.27506223320961, 73.36609080433846, 71.85349836945534, 71.48161992430687, 67.83416524529457, 66.14112809300423, 65.38130566477776, 65.00565782189369, 65.0201578438282, 63.65625903010368, 62.9549952596426, 63.98297309875488, 64.58527877926826, 63.52968402206898, 66.16920858621597, 63.55337955057621, 62.384182289242744, 62.62299567461014, 61.78271636366844, 65.30801519751549, 59.7675096988678, 55.10431632399559, 57.46459387242794, 57.06016257405281, 58.941331431269646, 58.603430762887, 57.18410052359104, 57.43419550359249, 60.264241844415665, 64.23211053013802, 71.94418430328369, 76.1390832066536, 77.93419808149338, 75.91644555330276, 73.61022010445595, 66.36710956692696, 61.14792622625828, 57.12553046643734, 57.430467903614044, 54.04466338455677, 61.237525418400764, 70.1814740896225, 69.56229731440544, 70.8257295191288, 68.42722982168198, 65.48823952674866, 60.32180495560169, 64.91929605603218, 72.8682491183281, 68.04510712623596, 55.36631986498833, 68.07756498456001, 72.36247345805168, 59.53905075788498, 63.87635841965675, 72.09913238883018, 72.69994854927063, 71.13977506756783, 65.38407951593399, 56.92575618624687, 53.9721442759037, 53.38150016963482, 53.05962324142456, 52.558741718530655, 54.811827018857, 54.35537651181221, 55.89190386235714, 52.7861101180315, 53.78106392920017, 53.63186113536358, 53.1187404692173, 52.22122102975845, 51.651848182082176, 51.528673991560936, 50.50788156688213, 52.93554849922657, 50.07430203258991, 55.726673528552055, 55.87443619966507, 56.88581272959709, 57.678651586174965, 58.10754977166653, 57.00270965695381, 55.01338340342045, 57.776408940553665, 56.32707171142101, 56.26010410487652, 56.07291094958782, 58.560641258955, 62.27073557674885, 68.89295563101768, 69.92858245968819, 71.60892069339752, 73.28374922275543, 73.12254667282104, 76.24440595507622, 76.8377897143364, 79.46521192789078, 77.9326705634594, 80.3814871609211, 21.86682913452387, 0.3855957981431857, 0.4451321315718815, 1.3355087558738887, 1.6423635464161634, 0.6758357130456716, 2.361882012337446, 1.5339151094667614, 0.0797248505114112, 0.16579037328483537, 2.355691669508815, 37.86177635192871, 40.242861583828926, 84.91342797875404, 27.582421638071537, 21.52768023312092, 43.858648762106895, 40.127868354320526, 51.397223845124245, 48.76164726912975, 39.202956184744835, 33.75350520014763, 8.986047562211752, 0.6743097386788577, 0.10134286276297644, 0.054931203194428235, 0.05490237817866728, 0.13586870074504986, 0.01900555223983247, 0.03770618939597625, 0.040026566057349555, 0.026697504727053456, 0.09480348788201809, 0.08073991557466798, 0.052361357302288525, 0.01801493352104444, 0.040565799426985905, 0.099292835657252, 0.014693332850583829, 0.04285822309611831, 0.030802334658801556, 0.0487998722383054, 0.06302667621639557, 0.08901327397325076, 0.045338621639530174, 0.07232950476463884, 0.018849153893825132, 0.0923944913665764, 0.028423281946743373, 0.09330773376859725, 0.04985761821444612, 0.07537609519204125, 0.09610292909201235, 35.15559196472168, 94.02560502290726, 84.21085327863693, 81.30359128117561, 74.7158619761467, 46.0662505030632, 36.07518821954727, 48.1581674516201, 54.20313388109207, 43.64208698272705, 0.645140188280493, 0.04109921806957573, 4.0298994071781635, 4.281252594664693, 6.9187157694250345, 2.267713565379381, 0.6967785267625004, 1.2757615931332111, 30.734128318727016, 114.7141344845295, 92.62903556227684, 103.17361414432526, 92.7639739215374, 89.5973302423954, 76.77722096443176, 76.06547355651855, 73.44492137432098, 73.5264042019844, 69.73445847630501, 70.74834287166595, 67.31312960386276, 68.40446144342422, 68.3595934510231, 67.94860750436783, 66.64431989192963, 69.21834737062454, 67.12035834789276, 71.00218445062637, 67.96306192874908, 66.52017295360565, 64.80532497167587, 64.09265041351318, 65.67479431629181, 63.954102247953415, 58.17757621407509, 62.44883581995964, 60.96601478755474, 62.04110249876976, 60.83040006458759, 61.058460026979446, 59.624405577778816, 63.67254875600338, 68.19104209542274, 75.5794720351696, 78.25490087270737, 78.24192836880684, 77.78024554252625, 75.71688026189804, 68.901626765728, 65.83691641688347, 61.707480400800705, 61.7940853536129, 56.18573449552059, 65.87513476610184, 74.68427807092667, 75.4835955798626, 73.71868908405304, 72.54998579621315, 68.33152815699577, 63.923840671777725, 69.30266484618187, 77.35738903284073, 72.46543273329735, 59.247746989130974, 70.98450779914856, 73.27450051903725, 66.11024335026741, 69.53232452273369, 75.90819999575615, 75.87324187159538, 73.6606813967228, 68.19196924567223, 60.33919282257557, 56.44551895558834, 56.201180666685104, 55.79527124762535, 55.677880346775055, 58.01652565598488, 56.76927298307419, 57.57319204509258, 56.7185153067112, 56.732414960861206, 56.87263883650303, 53.87418553233147, 55.8020044863224, 54.95497673749924, 54.59061048924923, 54.47318159043789, 56.18145972490311, 53.09100575745106, 57.90551461279392, 58.5201658308506, 60.108868181705475, 59.80217903852463, 60.27046211063862, 59.25969734787941, 58.414839282631874, 60.45176558196545, 57.4365171790123, 58.128444850444794, 58.7227937579155, 60.25639906525612, 66.55586823821068, 73.01282376050949, 72.6782289147377, 75.6219157576561, 76.49868071079254, 75.89818373322487, 79.33104872703552, 80.67454263567924, 84.93682712316513, 81.48926451802254, 85.29581665992737, 32.200680524110794, 0.12334610160905868, 0.8108036988414824, 0.0933962497219909, 2.1827952470630407, 2.253125673159957, 3.4258166095241904, 2.339684790931642, 0.7435796654317528, 0.1913922416861169, 1.7947587626986206, 40.052867978811264, 47.07269869744778, 55.27498036623001, 28.44722293317318, 33.97602126002312, 58.04092414677143, 53.37516210973263, 65.67037895321846, 64.05276775360107, 52.21521355211735, 45.32860368490219, 12.893854770809412, 0.7758223009295762, 0.07032958004856482, 0.06998673008638434, 0.051140706200385466, 0.023362191022897605, 0.05534130286832806, 0.03248826411436312, 0.013900591111450922, 0.06864279712317511, 0.04392379130877089, 0.022144347094581462, 0.06417023672838695, 0.006113286099207471, 0.05034534653532319, 0.023633876444364432, 0.11672913518850692, 0.20616411231458187, 0.23576651292387396, 0.230873444234021, 0.2130177867366001, 0.19596928905230016, 0.12101958738639951, 0.13277108024340123, 0.13109453895594925, 0.12026490483549424, 0.14226550905732438, 0.19121691671898589, 0.11561632185475901, 0.28119476744905114, 0.18885516532463953, 43.21513049304485, 117.35530436038971, 101.43345952033997, 95.79089149832726, 86.60016506910324, 51.958126947283745, 54.83631670475006, 109.4271893799305, 83.70405927300453, 56.195306181907654, 2.4450935097411275, 0.13365870370762423, 4.029161771759391, 8.18779494613409, 12.13475240394473, 3.7938228249549866, 11.648673936724663, 4.033501613885164, 29.069099463522434, 122.01503992080688, 98.21734249591827, 109.88482922315598, 98.71770724654198, 92.197834700346, 81.29342302680016, 80.26398226618767, 79.37833338975906, 76.9653108716011, 74.0913274884224, 76.64683476090431, 70.73854699730873, 75.81935316324234, 74.82079714536667, 71.15202561020851, 71.76112532615662, 72.6409301161766, 72.87411600351334, 75.77804177999496, 71.725262850523, 69.45694416761398, 68.42129454016685, 68.37225437164307, 71.79072573781013, 68.0237902700901, 62.217542231082916, 65.70422753691673, 62.906240075826645, 65.64469993114471, 63.32838222384453, 64.37363013625145, 63.94312083721161, 65.61566188931465, 70.56627184152603, 78.14272329211235, 81.54816895723343, 84.02657076716423, 81.59541562199593, 81.13196209073067, 74.2574393749237, 69.35878783464432, 63.71696837246418, 65.62361106276512, 59.49798256158829, 69.73380491137505, 77.92209953069687, 77.58282333612442, 78.97545620799065, 76.98790445923805, 74.2601752281189, 67.82828316092491, 72.2740750014782, 84.23614472150803, 75.26063874363899, 61.26035079360008, 73.49987402558327, 78.66684436798096, 70.15456393361092, 70.48041924834251, 79.83284220099449, 78.4140819311142, 81.38603165745735, 71.56172722578049, 65.57813510298729, 58.210957422852516, 59.661388993263245, 60.08271798491478, 59.76397208869457, 60.70854440331459, 61.05865761637688, 61.579898446798325, 59.338182136416435, 61.3464617729187, 61.721482649445534, 57.927530631423, 58.548827692866325, 58.788974806666374, 57.93767228722572, 57.913045808672905, 60.462036430835724, 57.28452913463116, 62.57278896868229, 61.83776780962944, 64.28754195570946, 62.63244956731796, 63.56519311666489, 63.241005912423134, 61.397797018289566, 64.42664489150047, 61.32046736776829, 61.70166291296482, 60.690738558769226, 64.87633556127548, 69.64993581175804, 74.19811695814133, 74.55901399254799, 80.3846637904644, 79.22536879777908, 78.8790325820446, 83.57393145561218, 83.25792521238327, 85.80394059419632, 84.5162732899189, 87.31434434652328, 29.825029000639915, 0.3049833612749353, 4.335545981302857, 6.12110341899097, 4.608548507094383, 3.250445332378149, 7.1877893060445786, 4.686734061688185, 0.5859577702358365, 0.30168012133799493, 4.4768831972032785, 57.908740639686584, 54.80356626212597, 116.1720934510231, 37.18199662864208, 31.936400905251503, 65.87483838200569, 62.66307972371578, 79.11722660064697, 81.12335175275803, 68.37695091962814, 54.95597988367081, 13.633208647370338, 0.7145334896631539, 0.22248491935897619, 0.17334295785985887, 0.1598242184263654, 0.19671994174132124, 0.17815783387050033, 0.08855732070514932, 0.18270580389071256, 0.12709826667560264, 0.2036217667046003, 0.16943235910730436, 0.1084607640223112, 0.1892727569793351, 0.1301745281671174, 0.14634010760346428], [0.09941874843207188, 0.07772050259518437, 0.09060903248609975, 0.02731095657509286, 0.017664086917648092, 0.021226533062872477, 0.06229289996554144, 0.021303451103449333, 0.03235667390981689, 0.08930676369345747, 0.03409913646464702, 0.07704344869125634, 0.13732621941016987, 0.06668661459116265, 2.6890625059604645, 70.93895584344864, 73.16336408257484, 67.16681465506554, 55.444052293896675, 38.658019825816154, 22.182176113128662, 60.20972616970539, 82.71089896559715, 44.355460703372955, 18.426888920366764, 0.44727539469022304, 1.1141997249796987, 2.8622923605144024, 4.018946494907141, 1.9926617620512843, 1.1949642724357545, 0.7067113718949258, 0.7860446430277079, 68.07346120476723, 96.7716720700264, 93.35509300231934, 90.777957290411, 81.77406683564186, 75.40229514241219, 74.21136304736137, 72.90619388222694, 67.70165875554085, 67.47370138764381, 66.23833447694778, 65.60010552406311, 63.957309275865555, 64.00970086455345, 63.95271152257919, 61.930650025606155, 62.41928480565548, 60.98670847713947, 62.806708216667175, 64.30220916867256, 62.256585136055946, 61.31416730582714, 63.02495710551739, 59.07357573509216, 58.097670301795006, 54.163623601198196, 55.463286861777306, 58.91918241977692, 57.440708354115486, 55.64844712615013, 57.22847454249859, 58.288123682141304, 58.13064493238926, 66.99818730354309, 73.97371619939804, 75.8995820581913, 74.19164210557938, 74.36498880386353, 73.84897649288177, 72.6170901954174, 66.43450275063515, 64.63738918304443, 59.01644580066204, 56.85642130672932, 56.28452159464359, 62.65643008053303, 70.52667036652565, 72.4966898560524, 72.36285343766212, 67.27488845586777, 63.2647280395031, 58.3343406021595, 68.7921242415905, 72.7109907567501, 65.72224617004395, 64.3181911110878, 69.50877338647842, 70.2127768099308, 59.50071081519127, 63.017186522483826, 70.98671928048134, 69.98245596885681, 67.43537664413452, 62.74289444088936, 58.9970288425684, 55.30486196279526, 53.32747846841812, 53.052407428622246, 53.31009820103645, 52.74942308664322, 54.83946293592453, 50.75978524982929, 51.21985696256161, 52.13646657764912, 53.705672174692154, 54.02202419936657, 54.97274458408356, 52.91016586124897, 55.4033412784338, 51.36170335114002, 52.67356775701046, 51.61310166120529, 52.85667613148689, 55.17694182693958, 56.59781098365784, 56.31694905459881, 57.176455333828926, 53.082205429673195, 57.237920835614204, 55.98844148218632, 57.40999460220337, 55.78036844730377, 59.28178936243057, 59.89558182656765, 70.57887956500053, 72.32946842908859, 78.12645256519318, 74.63048055768013, 78.25943022966385, 74.35858234763145, 78.16573485732079, 77.95372143387794, 81.92968368530273, 77.61428564786911, 76.25132918357849, 76.05320021510124, 30.73386613279581, 0.11025890620658174, 1.4559010206721723, 1.7468909500166774, 0.09087345970328897, 3.5597188118845224, 2.9394709691405296, 0.6130722246598452, 0.10863787014386617, 0.23166901170043275, 16.660656295716763, 29.254905693233013, 43.885566517710686, 53.646049574017525, 18.473523817956448, 19.215610697865486, 29.03517298400402, 45.125177800655365, 48.91178101301193, 46.482654958963394, 46.567755192518234, 40.61455003917217, 10.022977720946074, 0.07299351171241142, 0.07974212028784677, 0.05605366444797255, 0.08103467436740175, 0.028681157855316997, 0.05532926523301285, 0.07159003624110483, 0.07050091226119548, 0.052701153326779604, 0.02220131991634844, 0.06032987483195029, 0.020502352781477384, 0.03992279525846243, 0.04052326694363728, 0.04270001947588753, 0.0554699912754586, 0.030625959552708082, 0.09020178637001663, 0.04419255637913011, 0.07322095028939657, 0.044254473759792745, 0.05442349625809584, 0.056478629339835607, 0.04688594017352443, 0.024815000761009287, 0.0929610023740679, 0.08205712380004115, 0.07242288178531453, 3.81460462231189, 88.36373403668404, 86.15118876099586, 79.28656831383705, 68.09994578361511, 55.06836265325546, 32.32750251889229, 53.326357528567314, 72.30281665921211, 51.284863874316216, 20.760436803102493, 0.6349930702708662, 0.5685329146217555, 6.953252591192722, 8.110415898263454, 3.128643105737865, 2.2475406853482127, 1.2692056386731565, 2.8849609941244125, 83.76222655177116, 101.06358736753464, 98.68829682469368, 95.14071598649025, 84.27855804562569, 79.44947317242622, 77.5978173315525, 75.64786836504936, 71.95278704166412, 71.14219173789024, 70.03661826252937, 71.00797533988953, 65.81047743558884, 68.48926529288292, 67.96605616807938, 65.85604459047318, 65.88644295930862, 65.11588990688324, 65.83434015512466, 66.43827974796295, 65.88588818907738, 65.50591617822647, 64.62529823184013, 65.20733579993248, 62.51833029091358, 57.35260248184204, 58.62662471830845, 61.3968812674284, 60.7916459441185, 60.208392441272736, 60.561431497335434, 60.79934433102608, 59.22354228794575, 69.27523791790009, 75.58456376194954, 80.32843440771103, 77.27556422352791, 78.04521292448044, 76.95420026779175, 76.63595974445343, 70.57191073894501, 68.39118495583534, 61.443569362163544, 60.8998679369688, 59.34351325035095, 67.107705026865, 74.11462783813477, 74.91320058703423, 74.51298326253891, 70.30283197760582, 67.73479297757149, 62.22689352929592, 71.21103644371033, 74.81400310993195, 71.2538069486618, 68.31179961562157, 75.57225242257118, 72.854965031147, 63.45590718090534, 69.65125814080238, 75.41704595088959, 72.81803861260414, 71.6058200597763, 65.57673677802086, 64.26400601863861, 58.707700967788696, 57.23127119243145, 56.144738495349884, 56.415834948420525, 55.698760226368904, 58.10256823897362, 54.08566318452358, 53.70235875248909, 55.9842275083065, 57.60310024023056, 57.276199981570244, 56.22047983109951, 56.0649161785841, 58.91199320554733, 54.91137407720089, 55.75284272432327, 55.76479308307171, 56.25615231692791, 57.92908854782581, 58.91138143837452, 58.08958813548088, 60.55483125150204, 55.992606058716774, 60.47329142689705, 58.57613302767277, 60.021153688430786, 57.88054995238781, 61.243871077895164, 63.018394857645035, 75.88318973779678, 76.29862144589424, 81.75278037786484, 78.3787514269352, 81.62107944488525, 77.78928145766258, 81.26034200191498, 82.54052370786667, 86.24797716736794, 79.31930735707283, 78.9358851313591, 81.56456127762794, 45.187057480216026, 0.30466587049886584, 0.4727463482413441, 0.578190452652052, 1.6888496582396328, 6.356655629351735, 3.057207176461816, 1.6768161789514124, 0.4735478380462155, 0.16504898259881884, 15.98632737994194, 37.51580111682415, 46.408840119838715, 37.02738672494888, 26.423803009092808, 35.698902010917664, 37.024609073996544, 56.512786746025085, 61.20015822350979, 64.02189821004868, 65.0451073050499, 56.977528408169746, 13.124314304441214, 0.09513403303571977, 0.07930628664325923, 0.06009606491716113, 0.04550836565613281, 0.05597003182629123, 0.09757149091456085, 0.11570265589398332, 0.042921854837914, 0.04180309690127615, 0.0394665525527671, 0.0223703718802426, 0.0685504442662932, 0.027626165247056633, 0.06548024612129666, 0.16046408331021667, 0.19476179993944243, 0.09292214352171868, 0.14069610420847312, 0.08436258329311386, 0.189075538655743, 0.2102316010859795, 0.13157614826923236, 0.09677383059170097, 0.10821932854014449, 0.09926502738380805, 0.19406817387789488, 0.20142186287557706, 0.15512951096752658, 3.8683885987848043, 102.06219658255577, 101.02950319647789, 95.04928529262543, 81.90763726830482, 61.232612282037735, 34.28948163986206, 82.88852423429489, 113.34669426083565, 68.58106076717377, 31.314889155328274, 1.0161750786937773, 3.975823321379721, 8.744384329766035, 13.676422778517008, 7.0098253805190325, 6.671153353527188, 6.13385695964098, 2.064672647975385, 90.22406861186028, 105.79915165901184, 106.29574701189995, 98.10463294386864, 89.9424809217453, 83.92374828457832, 81.04865536093712, 80.23148640990257, 76.86324074864388, 73.83736431598663, 76.76009148359299, 73.63670468330383, 69.77534428238869, 72.32445269823074, 71.89759120345116, 69.90625485777855, 70.34896910190582, 68.17032560706139, 70.0681945681572, 72.7440033853054, 70.12816295027733, 68.0666595697403, 69.92157563567162, 66.05841413140297, 66.35716930031776, 60.941604897379875, 62.750304043293, 65.38474068045616, 64.75583642721176, 63.73561017215252, 64.71977636218071, 63.921363204717636, 63.41553434729576, 74.05785128474236, 77.77084484696388, 84.78241100907326, 80.36360532045364, 81.18560001254082, 80.68085789680481, 79.53471019864082, 73.82727205753326, 71.9644296169281, 64.49768587946892, 65.04400536417961, 64.32234808802605, 69.20342177152634, 79.70980480313301, 79.69584435224533, 77.95634329319, 72.62596651911736, 71.36818841099739, 65.93716263771057, 75.08907794952393, 79.47617813944817, 72.31494560837746, 64.63544368743896, 74.29659247398376, 75.26417255401611, 66.43897131085396, 72.40581393241882, 78.5802698135376, 77.07125678658485, 75.7652060687542, 68.95993083715439, 69.42992001771927, 61.916096806526184, 60.50500072538853, 59.73127484321594, 60.88238127529621, 58.7685889005661, 60.75845092535019, 56.95086143910885, 58.10404255986214, 58.38730975985527, 60.73323167860508, 60.894312635064125, 61.461037024855614, 60.62667779624462, 62.609213814139366, 58.44914764165878, 58.992370292544365, 58.002948984503746, 59.632369950413704, 62.73345194756985, 61.661894246935844, 60.62533266842365, 64.1974563896656, 58.970133885741234, 65.48426494002342, 61.1706680059433, 62.742214277386665, 61.842274367809296, 64.68063846230507, 65.09683012962341, 78.85625660419464, 78.61708983778954, 85.56753247976303, 80.46259000897408, 84.76728782057762, 82.0161746442318, 83.43166708946228, 86.76141321659088, 88.68151098489761, 82.80697301030159, 80.93169003725052, 81.19185447692871, 38.03003892302513, 0.1706817201920785, 3.6029075318947434, 6.570437857881188, 5.0065163522958755, 12.029295712709427, 12.158456481993198, 1.5226456266827881, 0.3917380201164633, 0.2249069925164804, 27.42131218314171, 46.55969962477684, 60.79051360487938, 71.97192281484604, 26.007288359105587, 29.972470588982105, 45.08450098335743, 72.06960797309875, 76.86091527342796, 77.33259156346321, 80.13746425509453, 65.64249604940414, 14.173691645264626, 0.3659089357824996, 0.22202190826646984, 0.2224722583196126, 0.1821331775863655, 0.17030272021656856, 0.12519483600044623, 0.21101729798829183, 0.16860228177392855, 0.22240678605157882, 0.09759200387634337, 0.15104683785466477, 0.09722583563416265, 0.0740106993180234, 0.11970287639996968], [0.034158935013692826, 0.03560934019333217, 0.07283516708412208, 0.05009114982385654, 0.0457510887645185, 0.05713422775443178, 0.026004554019891657, 0.01981199959118385, 0.07962420044350438, 0.12454918236471713, 0.049551667834748514, 0.1229435607092455, 0.16911669401451945, 0.2748812874779105, 13.324299473315477, 76.24958887696266, 65.39367780089378, 62.73554943501949, 32.593347653746605, 23.904684484004974, 32.1106481552124, 71.91573902964592, 49.1691830009222, 36.49585224688053, 3.1919574458152056, 0.1653726035146974, 0.952779755461961, 2.889568959362805, 2.920970474369824, 2.5172243267297745, 0.9125960210803896, 1.000530724413693, 16.902368925511837, 101.42639189958572, 89.5690369606018, 94.41346541047096, 83.91763061285019, 78.46863940358162, 73.4545348584652, 70.60975670814514, 68.46290990710258, 66.65616005659103, 65.71953311562538, 62.333170026540756, 62.79761150479317, 63.80401790142059, 62.54799149930477, 63.790239840745926, 62.887427285313606, 60.92054262757301, 60.23876041173935, 61.36906675994396, 61.79867170751095, 58.84055323898792, 59.77909907698631, 61.370054706931114, 60.87093248963356, 57.1219776570797, 57.36876301467419, 58.72060127556324, 55.9833687543869, 55.70464231073856, 56.95488542318344, 59.04549144208431, 56.304922699928284, 64.52361568808556, 75.21632552146912, 77.07056522369385, 72.5841611623764, 73.43607544898987, 73.32845762372017, 73.92152220010757, 72.04814672470093, 68.12014549970627, 64.30463343858719, 59.964384734630585, 58.826946169137955, 54.038792699575424, 59.88561496138573, 69.4789145886898, 72.20672741532326, 70.33389911055565, 71.7998756468296, 66.23597100377083, 60.658656880259514, 69.3150369822979, 74.17318269610405, 59.63558077812195, 71.96800142526627, 68.17005202174187, 73.95746067166328, 59.15568172931671, 58.224290907382965, 70.77849805355072, 66.03770524263382, 67.54342764616013, 66.15416899323463, 62.0191814750433, 61.23303025960922, 58.0266635119915, 53.81230965256691, 52.4793715775013, 52.177933752536774, 51.94424629211426, 51.017172038555145, 52.82542280852795, 52.06827163696289, 53.94081875681877, 52.551168724894524, 58.935217559337616, 57.81446769833565, 55.5441465228796, 55.782549530267715, 51.83910973370075, 51.40707291662693, 51.79212525486946, 54.71387207508087, 54.161522313952446, 55.23625664412975, 53.30621100962162, 54.95872713625431, 54.20639410614967, 57.05110386013985, 56.864944249391556, 54.88242343068123, 56.53952211141586, 63.893389105796814, 72.13106587529182, 75.5249297618866, 75.21483600139618, 76.65618225932121, 75.65042942762375, 78.86731401085854, 74.8993693292141, 76.0878923535347, 83.26886862516403, 75.57725295424461, 73.2399907708168, 73.95676910877228, 86.88163876533508, 59.15621370077133, 1.0134881478734314, 0.6103800691198558, 2.775601437315345, 1.6187106468714774, 2.0269710710272193, 2.0097518200054765, 0.40497555979527533, 0.052698240397148766, 0.47393966233357787, 30.167231038212776, 32.95193821191788, 65.4791884124279, 29.710138365626335, 17.014573104679585, 27.236102521419525, 37.8079978376627, 42.47255153954029, 55.40388844907284, 54.8444976657629, 58.1036663800478, 39.665467366576195, 2.5475500244647264, 0.001896529629448196, 0.06858156993985176, 0.07342766810324974, 0.036176530265947804, 0.011596730946621392, 0.02982258654810721, 0.05876200993952807, 0.011757351185224252, 0.005282021793391323, 0.04240377267706208, 0.034410010994179174, 0.02720013722864678, 0.02894629567890661, 0.013844234272255562, 0.04064427412231453, 0.041741168388398364, 0.0704618233430665, 0.04927283553115558, 0.04046103415021207, 0.022276514318946283, 0.04537792949122377, 0.1091734335932415, 0.05505914203240536, 0.03227159410016611, 0.04926357352815103, 0.029639407803188078, 0.5725585017353296, 19.01900924742222, 95.72997316718102, 75.8719651401043, 75.38852468132973, 42.11105793714523, 33.148478865623474, 38.06788869202137, 59.175623059272766, 53.659212067723274, 45.4093911498785, 2.939839311875403, 0.5413184186909348, 3.607306033372879, 6.45077277906239, 4.788451278582215, 3.615005607716739, 1.8406010465696454, 0.8068837935570627, 26.422414183616638, 107.53683641552925, 90.17999857664108, 99.05371561646461, 83.207266330719, 80.24296179413795, 75.73835670948029, 74.21594560146332, 71.86175912618637, 71.38477072119713, 70.53081214427948, 69.44110661745071, 68.40149000287056, 68.29230666160583, 66.27126350998878, 66.96787253022194, 65.9607669711113, 66.06637850403786, 64.96642872691154, 65.88665574789047, 63.63064840435982, 65.45797035098076, 64.34920504689217, 65.75800985097885, 64.10462737083435, 60.38512855768204, 59.61087070405483, 59.26579222083092, 58.32159988582134, 60.0119049847126, 59.43836756050587, 62.276032492518425, 60.47538511455059, 66.87915489077568, 76.97063058614731, 78.93549755215645, 76.75085037946701, 75.57199403643608, 74.38534811139107, 76.9332405924797, 73.23239877820015, 70.09147211909294, 68.11603412032127, 64.12149846553802, 62.57748171687126, 55.88770128786564, 65.74849516153336, 73.84832292795181, 75.26378497481346, 73.96362394094467, 76.4068852365017, 68.03468808531761, 64.37972500920296, 74.44230705499649, 76.09414681792259, 68.61490935087204, 77.6877661049366, 75.07710859179497, 74.49973717331886, 63.781621903181076, 62.823343724012375, 73.32206636667252, 70.51004245877266, 72.30515733361244, 70.11600360274315, 66.17347955703735, 64.83386904001236, 61.89759939908981, 57.679818123579025, 55.941240414977074, 55.38693755865097, 55.47738790512085, 54.52488161623478, 54.17755365371704, 56.23065948486328, 56.96291819214821, 55.600524097681046, 62.18884997069836, 61.08239494264126, 58.44414331018925, 59.477950036525726, 53.93119767308235, 55.309345722198486, 54.88131009042263, 57.61182837188244, 57.70238511264324, 57.27417089045048, 57.26489558815956, 59.44659411907196, 58.05635131895542, 59.75714385509491, 58.29671502113342, 58.33629369735718, 59.67410311102867, 66.21460095047951, 77.63602808117867, 78.54197546839714, 78.6252973973751, 80.28767019510269, 80.61556220054626, 80.99040448665619, 79.60810706019402, 80.77227339148521, 85.12575298547745, 79.26212042570114, 78.44368994235992, 79.15618970990181, 86.7753204703331, 75.09624436497688, 3.5152550227940083, 0.6449134473223239, 1.6843904787674546, 0.838800537167117, 3.372285794466734, 2.9679547157138586, 0.9677026234567165, 0.12883095885626972, 0.6460405618418008, 31.40872322022915, 44.75957281887531, 46.64445027709007, 28.877983018755913, 29.925298020243645, 38.11541274189949, 50.84247261285782, 55.65767303109169, 65.92129468917847, 66.41277551651001, 73.05805653333664, 51.15112245082855, 3.1013349210843444, 0.0591167120001046, 0.027669521514326334, 0.03853988469927572, 0.008813890526653267, 0.03718540581758134, 0.029890214755141642, 0.08841191171086393, 0.06751928201992996, 0.09336214061477222, 0.03374313935637474, 0.01619679416762665, 0.03980952125857584, 0.01595677804289153, 0.10954395824228413, 0.12936166865983978, 0.13534278521547094, 0.07603841746458784, 0.18786960805300623, 0.18195478012785316, 0.11529592185979709, 0.1456718481495045, 0.29564527329057455, 0.17562562599778175, 0.15227347437758, 0.31497697345912457, 0.42159877717494965, 0.6270175951067358, 21.079501882195473, 113.59742760658264, 86.73755809664726, 90.54240792989731, 54.92454037070274, 40.965415611863136, 47.40065149962902, 94.77113261818886, 66.35426625609398, 61.41281001269817, 4.556947750970721, 0.5130061379168183, 5.685843424871564, 10.232947804033756, 10.89514397084713, 10.468892343342304, 7.822134867310524, 1.8460429483093321, 27.45561484247446, 113.2284826040268, 96.79535999894142, 103.34115475416183, 89.27107214927673, 85.25426968932152, 78.21953997015953, 77.90136784315109, 76.37034639716148, 75.85483565926552, 73.83414968848228, 71.31858587265015, 71.03352516889572, 72.20662862062454, 71.72967821359634, 72.86972343921661, 71.1177210509777, 69.54155042767525, 69.29224580526352, 71.0288742184639, 68.7094634771347, 67.6543664932251, 66.60192936658859, 67.02368393540382, 67.817552536726, 65.1977527141571, 64.66627523303032, 65.32420992851257, 62.29999020695686, 62.158561795949936, 62.79229179024696, 65.29274001717567, 63.39265197515488, 72.24274188280106, 79.86576363444328, 83.93966943025589, 79.61897447705269, 78.02836462855339, 79.43491995334625, 80.39440646767616, 78.82224082946777, 74.78800490498543, 72.9982477426529, 66.77788272500038, 66.72740623354912, 59.03164878487587, 69.68910411000252, 76.66267231106758, 77.7140074968338, 77.25560009479523, 79.94340106844902, 73.0672900378704, 69.96575966477394, 78.53822886943817, 81.5208712220192, 62.87384681403637, 66.8098846077919, 72.1653400361538, 80.00042840838432, 67.30606958270073, 64.6582804620266, 79.20363396406174, 72.68398940563202, 76.42371073365211, 73.99941802024841, 71.50947242975235, 67.44917750358582, 66.18707522749901, 58.89874331653118, 59.31075520813465, 58.35910007357597, 59.37677666544914, 56.801863834261894, 58.61408919095993, 60.32293349504471, 59.97754342854023, 58.403785675764084, 66.42028391361237, 64.95128273963928, 61.850626319646835, 64.16411697864532, 57.119207605719566, 58.65793503820896, 57.47731938958168, 62.205622270703316, 60.99526181817055, 59.569464325904846, 57.962310165166855, 60.36071486771107, 59.977969005703926, 62.83221624791622, 61.12941361963749, 59.92285296320915, 64.47463631629944, 72.23277881741524, 80.75104013085365, 82.98610299825668, 83.10129001736641, 80.84753975272179, 83.02949666976929, 85.28000190854073, 82.0359867811203, 83.91691625118256, 86.43940329551697, 82.05750122666359, 78.49953174591064, 81.08292952179909, 90.18676221370697, 68.12061667442322, 1.7261004843749106, 5.669225491583347, 9.73511466756463, 5.310030290856957, 7.935478510335088, 6.952165374532342, 1.0929859383031726, 0.12497339397668839, 1.4930839254520833, 48.41578222811222, 50.2578853815794, 91.33968114852905, 41.98985584080219, 25.645353980362415, 39.401009157299995, 57.521708607673645, 66.14834010601044, 76.34104236960411, 78.04685443639755, 89.12383005023003, 58.86673763394356, 3.5763353202492, 0.1394098880700767, 0.12342540008830838, 0.11674919544020668, 0.11260123559623025, 0.09679720082203858, 0.14724312321050093, 0.1476947942865081, 0.12339731722022407, 0.16458852449432015, 0.1690579456044361, 0.11854508891701698, 0.18371043435763568, 0.16490018198965117], [0.2125666945357807, 0.16367828036891297, 0.051842458778992295, 0.04875657534284983, 0.06986636115470901, 0.07598300129757263, 0.07238986363518052, 0.02811417743942002, 0.11897972770384513, 0.05605052145256195, 0.08370655443286523, 0.004937221374348155, 0.20231717498973012, 0.04327043046941981, 40.376504212617874, 83.37754279375076, 69.05016839504242, 59.961101710796356, 47.1502411365509, 49.92719292640686, 50.03919571638107, 84.84177142381668, 60.07543757557869, 23.172224387526512, 0.05878479758393951, 0.19588496623327956, 0.03292961191618815, 5.133594833314419, 2.4525959696620703, 1.3116976898163557, 1.8486314406618476, 0.584530649939552, 56.31775841116905, 101.24241337180138, 93.36916744709015, 90.13889238238335, 77.30228438973427, 80.7592324912548, 70.9786257147789, 73.34601268172264, 65.88407948613167, 66.9223053753376, 61.968321204185486, 61.56860925257206, 62.97494038939476, 65.05058661103249, 62.263230979442596, 63.799389749765396, 62.37071581184864, 61.16006277501583, 62.1340911090374, 62.37224332988262, 60.605113953351974, 60.31322881579399, 59.27239626646042, 60.5609717220068, 56.67814627289772, 50.126313641667366, 54.9942172318697, 57.30356611311436, 55.58938689529896, 54.435191228985786, 56.79711028933525, 55.51116429269314, 60.13729825615883, 73.41104999184608, 74.63039696216583, 73.45627516508102, 70.37894949316978, 71.35810375213623, 71.90015226602554, 69.09184455871582, 66.38509020209312, 62.23130129277706, 59.88937295973301, 56.14691577851772, 56.96126528084278, 52.12133198976517, 58.50538082420826, 69.12241011857986, 75.50200179219246, 69.95323553681374, 70.08271738886833, 61.04796878993511, 62.83200345933437, 68.54737937450409, 72.7616648375988, 48.08194734156132, 67.0469006896019, 63.49174685776234, 69.38014268875122, 62.433404847979546, 59.67805489897728, 66.55583024024963, 68.13682660460472, 67.19728901982307, 66.7285917699337, 65.8500637114048, 64.75353375077248, 65.54663479328156, 62.405483946204185, 52.7836212515831, 49.640597105026245, 53.330465108156204, 50.72385437786579, 51.71801023185253, 48.81745107471943, 53.78861032426357, 53.93974721431732, 59.22822743654251, 62.05420799553394, 58.37034747004509, 55.82799889147282, 52.51286298036575, 49.05419737100601, 49.185871705412865, 50.12149550020695, 55.6433629989624, 52.36488752067089, 52.83744916319847, 52.38883763551712, 53.818256333470345, 54.07532013952732, 56.57440423965454, 54.40200001001358, 59.3998072296381, 64.20866578817368, 72.28408366441727, 70.79899415373802, 70.29648631811142, 74.86973091959953, 76.5757329761982, 75.07664501667023, 70.23020267486572, 76.11208185553551, 74.6643215417862, 78.46299290657043, 79.38876003026962, 79.79056566953659, 75.57614341378212, 84.50703978538513, 68.40108722448349, 1.6613689390942454, 0.9038560150656849, 3.0104718217626214, 0.6772025709506124, 2.2212589206174016, 1.1249538604170084, 0.0951888257986866, 0.059561161979218014, 9.961014445871115, 31.419326551258564, 38.24058182537556, 53.5058256983757, 27.33612645417452, 17.346897572278976, 18.722038082778454, 28.140963166952133, 35.72636313736439, 53.871525675058365, 57.11644895374775, 62.051798924803734, 16.51521909981966, 0.3102117619710043, 0.10602998547255993, 0.007111124523362378, 0.040430053195450455, 0.060396597618819214, 0.009206818758684676, 0.0713320286013186, 0.043367651815060526, 0.020078154157090466, 0.048221171455224976, 0.0587062523845816, 0.05516778503078967, 0.040257767323055305, 0.006698284933008836, 0.04088058878551237, 0.0257835795491701, 0.028190460943733342, 0.08987354187411256, 0.02945290609204676, 0.04586590272083413, 0.062373044493142515, 0.11031775851733983, 0.01530747582364711, 0.05526347384147812, 0.004067996214871528, 0.07700612608459778, 0.07045280624879524, 52.380128502845764, 97.51469939947128, 77.33079805970192, 71.58020183444023, 59.125895127654076, 52.28294111788273, 52.1530868858099, 73.67916360497475, 70.04215076565742, 27.020830772817135, 0.0871290649229195, 1.6667678556405008, 3.706693025305867, 5.877688955515623, 4.108223654329777, 0.990676962537691, 1.8882152228616178, 1.0896405740641057, 63.99359732866287, 105.58643907308578, 94.75194364786148, 93.66384163498878, 79.23622101545334, 83.51550579071045, 74.95996847748756, 80.26604935526848, 70.50408437848091, 71.1585308611393, 66.69731944799423, 67.83169537782669, 67.87364512681961, 68.59793946146965, 67.86713227629662, 69.36273202300072, 65.32281160354614, 64.51307505369186, 64.49015468358994, 65.06438747048378, 64.7881954908371, 63.523250967264175, 63.18149350583553, 64.74993154406548, 60.45485481619835, 56.77982121706009, 58.11340145766735, 59.35783468186855, 59.684723541140556, 57.92363964021206, 58.13027635216713, 57.30217158794403, 63.503818809986115, 76.65020138025284, 75.09678393602371, 77.00197890400887, 74.02416229248047, 76.97458997368813, 76.24946728348732, 73.65308940410614, 71.01942792534828, 67.64207795262337, 64.5065926015377, 59.75588612258434, 58.699064031243324, 56.35733708739281, 62.23142668604851, 73.16768825054169, 76.10309913754463, 73.63313287496567, 76.15490555763245, 66.8480421602726, 64.80522617697716, 74.83272090554237, 72.09411665797234, 62.415215224027634, 80.9592917561531, 73.06113436818123, 71.58561274409294, 65.92156067490578, 64.27501022815704, 71.73459514975548, 69.57834765315056, 69.46009799838066, 70.71466147899628, 69.76975858211517, 69.71845373511314, 68.15410807728767, 67.36223816871643, 56.86411589384079, 52.29613021016121, 55.10430872440338, 53.46590884029865, 54.53684717416763, 52.77155689895153, 55.9689599275589, 58.63008253276348, 62.42026515305042, 64.51423019170761, 62.96233646571636, 59.671998023986816, 56.208563670516014, 53.44006262719631, 53.77660296857357, 54.111938774585724, 57.042200937867165, 56.198866590857506, 56.65956526994705, 56.56168632209301, 56.72489896416664, 56.996743977069855, 59.332041665911674, 57.17612475156784, 59.80860449373722, 65.02522677183151, 76.9615338742733, 72.95904144644737, 76.63989633321762, 76.67622998356819, 78.39688405394554, 79.73982319235802, 72.91282072663307, 77.69329100847244, 77.18023493885994, 79.86719235777855, 80.46841889619827, 80.55096566677094, 77.45394945144653, 81.41927227377892, 81.77861899137497, 3.994693346321583, 0.8949351031333208, 0.7634179852902889, 2.8601200645789504, 3.345949170179665, 2.9461536230519414, 0.5759504134766757, 0.09148147160885856, 8.250015657395124, 42.180613204836845, 39.27044056355953, 34.88928325474262, 26.14057570695877, 27.897360138595104, 35.8789287507534, 44.50440131127834, 42.38250397145748, 64.17737066745758, 67.1807599067688, 77.34644562005997, 24.10723641514778, 0.4474919236963615, 0.07138841698179021, 0.06851635742350481, 0.0762766988191288, 0.04632345160644036, 0.07167207324528135, 0.0397250537207583, 0.03566315703210421, 0.026288993249181658, 0.12894253333797678, 0.026388745318399742, 0.040363872176385485, 0.02288903848238988, 0.30445928627159446, 0.23007242940366268, 0.21114718867465854, 0.14574572152923793, 0.15227066905936226, 0.16702401568181813, 0.13579460472101346, 0.20404813054483384, 0.2205558549030684, 0.145148144220002, 0.2298013525432907, 0.12501859077019617, 0.29345065355300903, 0.28661015967372805, 60.15664301812649, 115.44806510210037, 91.5052230656147, 85.79430431127548, 69.22948077321053, 65.89498490095139, 70.58151662349701, 104.11707311868668, 86.29869684576988, 38.48815754055977, 0.3977296454831958, 1.0269077215343714, 3.880801582708955, 15.32294187694788, 8.950976394116879, 7.400750778615475, 7.339543662965298, 1.005062812473625, 66.40485674142838, 113.20423990488052, 101.38621285557747, 101.09395533800125, 85.23671463131905, 89.42146047949791, 78.23149412870407, 81.81012690067291, 74.9423298239708, 74.42907616496086, 68.38734716176987, 70.08255019783974, 70.84032073616982, 72.29150086641312, 70.024633705616, 70.76052501797676, 69.41970616579056, 67.68604919314384, 69.38293933868408, 69.04935523867607, 69.26876306533813, 66.47752404212952, 65.01711040735245, 66.31075859069824, 63.320816829800606, 59.18240949511528, 61.94165423512459, 63.88705104589462, 62.58020617067814, 61.277202889323235, 62.61375457048416, 61.5659835934639, 64.37828108668327, 79.76489424705505, 78.88524144887924, 82.1844220161438, 75.97898259758949, 79.34514597058296, 80.294449031353, 76.97330564260483, 75.60641258955002, 69.64248061180115, 67.11699172854424, 62.44347430765629, 65.19931063055992, 58.40867981314659, 64.55622553825378, 77.41212889552116, 80.7724329829216, 76.70854344964027, 78.03713455796242, 68.2177546620369, 70.14001831412315, 78.53521943092346, 78.08375045657158, 55.29744476079941, 65.27358904480934, 64.9163170158863, 74.700518399477, 71.25160306692123, 66.86098426580429, 74.34899926185608, 72.27851316332817, 72.10879147052765, 74.09541606903076, 73.96606341004372, 71.0790391266346, 71.59999877214432, 69.9246534705162, 57.127198576927185, 55.49917213618755, 57.21023552119732, 57.70880676805973, 57.66081914305687, 57.133202254772186, 60.6827399879694, 61.02661773562431, 66.68686240911484, 68.82803991436958, 66.70430347323418, 63.18962886929512, 58.24239693582058, 54.62609678506851, 57.8898024559021, 57.82644845545292, 61.40907861292362, 57.23972573876381, 58.93851198256016, 59.04916204512119, 59.98766988515854, 61.723010167479515, 61.38165168464184, 60.4195661097765, 63.41896176338196, 70.15055134892464, 79.14424315094948, 77.56860449910164, 77.48921915888786, 78.68284910917282, 81.82874590158463, 81.1564327776432, 73.58965560793877, 78.70840653777122, 80.06845235824585, 85.08359044790268, 82.75731727480888, 84.82139691710472, 80.86102142930031, 89.03028666973114, 78.55114057660103, 2.427219031378627, 5.366727048531175, 11.9087272323668, 5.637419773265719, 7.614640351384878, 4.1349960677325726, 0.44617315696086735, 0.17704401863738894, 16.96444809436798, 51.963298469781876, 55.214039236307144, 72.89419412612915, 37.2235170006752, 25.98486576229334, 30.690331868827343, 43.87582004070282, 54.758295491337776, 76.89673215150833, 75.4282933473587, 88.52945074439049, 28.2413936778903, 0.43317657778970897, 0.16281082847854123, 0.13957520888652653, 0.13389587926212698, 0.20980312954634428, 0.10787422987050377, 0.13947403931524605, 0.22376304608769715, 0.14056115207495168, 0.1815452630398795, 0.15158247551880777, 0.1672027396853082, 0.11112757521914318], [0.015644749473722186, 0.09027832405990921, 0.06409534660633653, 0.032194837476708926, 0.020635874425352085, 0.11330332956276834, 0.056971797603182495, 0.057226788412663154, 0.035035337205044925, 0.0903355584887322, 0.060841374142910354, 0.04735469177830964, 0.025663552005426027, 0.52845100290142, 60.581866800785065, 68.96025002002716, 64.14589315652847, 40.448612943291664, 35.088666155934334, 56.61413110792637, 57.90802627801895, 77.0416259765625, 49.583820551633835, 6.905623571947217, 0.12489108979934826, 0.2241587740718387, 3.116683247499168, 3.9572185697034, 2.9012167593464255, 0.22910919593414292, 0.826389096910134, 2.21041192766279, 79.60677713155746, 100.55436909198761, 97.07702368497849, 89.88367527723312, 87.41033479571342, 85.89750677347183, 84.56371754407883, 80.05521386861801, 81.85460731387138, 75.79748913645744, 68.26238706707954, 63.84463772177696, 63.55962261557579, 64.63029116392136, 62.91024126112461, 61.103597804903984, 60.001181960105896, 60.07261052727699, 60.99068306386471, 63.03120017051697, 62.86204844713211, 59.72259610891342, 59.156783670187, 61.75924502313137, 54.55387406051159, 50.917571783065796, 56.689830645918846, 56.3311754912138, 55.36468215286732, 53.67378048598766, 54.166777431964874, 60.97422614693642, 69.24327403306961, 74.3220891058445, 74.42562595009804, 73.60813781619072, 72.89244621992111, 67.63621866703033, 68.05992633104324, 66.65537729859352, 61.87029406428337, 58.00115168094635, 57.13476397097111, 53.95023465156555, 53.55852127075195, 50.81625021994114, 56.16328909993172, 68.72744411230087, 74.9667777121067, 70.10362386703491, 71.37623637914658, 62.33696222305298, 63.98535177111626, 64.5828165113926, 73.63998010754585, 39.24622446298599, 48.97042326629162, 53.171306848526, 65.4279899597168, 64.17477160692215, 59.358214661478996, 64.66245263814926, 63.59407916665077, 68.40883880853653, 68.99593770503998, 67.42389366030693, 67.71492764353752, 66.85887157917023, 65.47042608261108, 61.733892783522606, 48.714066222310066, 52.29877486824989, 52.64269441366196, 51.189036816358566, 48.676623031497, 49.37196671962738, 52.216832265257835, 56.99542924761772, 59.04095448553562, 61.84085324406624, 58.67746978998184, 53.06178152561188, 48.95328238606453, 49.84178110957146, 50.59731736779213, 54.59202021360397, 51.72568581998348, 53.199136555194855, 52.348366007208824, 51.99561573565006, 51.82435132563114, 56.91601350903511, 53.86890381574631, 56.53787299990654, 61.996044516563416, 72.35133245587349, 66.85963913798332, 71.40774428844452, 76.14485129714012, 76.62458315491676, 74.28227484226227, 74.980578571558, 69.11528930068016, 79.81813699007034, 77.06682622432709, 78.27480420470238, 74.82400417327881, 84.37039151787758, 73.63428801298141, 84.83726486563683, 57.21048250794411, 0.44134839554317296, 0.4979171772720292, 2.2078378032892942, 1.4817645703442395, 1.5520024951547384, 0.8310617180541158, 0.14987054863013327, 1.1224017036147416, 20.44968757778406, 27.82441545277834, 63.646554350852966, 62.152687311172485, 26.00736815482378, 13.694370165467262, 13.141359239816666, 23.093542009592056, 42.54196621477604, 60.49351014196873, 66.2901408970356, 43.74634578824043, 1.7536094645038247, 0.0845482612203341, 0.02553071128204465, 0.04200033006782178, 0.06063196975446772, 0.0819312481326051, 0.043160191853530705, 0.017138548028015066, 0.05151877106982283, 0.08090893970802426, 0.06259854606469162, 0.0250484896969283, 0.01344068776234053, 0.01629169815714704, 0.018835153277905192, 0.06592823614482768, 0.05840130019350909, 0.055314826749963686, 0.10077528306283057, 0.06284767761826515, 0.013450364440359408, 0.03208692178304773, 0.14755253941984847, 0.047073020759853534, 0.05750247401010711, 0.05127676784468349, 0.6468468310777098, 78.27460661530495, 82.15512558817863, 71.81034788489342, 52.96835973858833, 52.71316163241863, 59.24487814307213, 49.723485857248306, 78.93446400761604, 59.27958548069, 8.68612015619874, 0.5612787476275116, 1.9332885229960084, 7.316649416461587, 5.861447202041745, 0.8104671200271696, 3.1040926231071353, 3.3008539024740458, 4.616924682632089, 91.64025261998177, 101.38652443885803, 100.23052006959915, 92.28720590472221, 92.99123212695122, 87.51003384590149, 90.17166182398796, 86.86447128653526, 85.55014461278915, 81.684999614954, 74.7001688182354, 70.41768461465836, 65.41515424847603, 67.12332218885422, 65.89488610625267, 65.33969029784203, 64.43346172571182, 63.1050606071949, 64.13983628153801, 64.82639104127884, 65.54537326097488, 62.08711802959442, 63.61644096672535, 64.1279125213623, 58.614127188920975, 54.612345322966576, 60.24829789996147, 58.36619049310684, 59.60177779197693, 57.262326925992966, 59.88037124276161, 64.58502039313316, 73.90256881713867, 78.12237918376923, 79.31118339300156, 75.96699044108391, 75.17825156450272, 71.52261212468147, 71.02298453450203, 69.2899963259697, 64.60256025195122, 61.68264493346214, 59.967310577631, 57.92069859802723, 57.082847356796265, 55.58057136833668, 60.10258711874485, 70.86573377251625, 76.29036068916321, 75.47978818416595, 77.1077348291874, 67.7547039091587, 68.44298377633095, 71.81989297270775, 76.2535710632801, 55.10978423058987, 62.56931975483894, 63.05144548416138, 70.35067901015282, 65.09188279509544, 66.03840440511703, 67.93140962719917, 63.470050022006035, 69.68181610107422, 72.8145731985569, 70.01881241798401, 69.5824970304966, 69.43313464522362, 69.15697306394577, 64.77063283324242, 52.65117175877094, 55.611292719841, 56.91069759428501, 56.06205873191357, 52.04547666013241, 53.710570111870766, 54.68957617878914, 59.71570327877998, 62.70254820585251, 64.56228241324425, 60.125203505158424, 56.550636515021324, 51.67625427246094, 52.44403347373009, 52.4695985019207, 55.26011936366558, 55.2675973623991, 55.976795107126236, 56.436802223324776, 55.23856692016125, 54.32065777480602, 58.58471296727657, 57.15846709907055, 57.29334846138954, 65.47354191541672, 73.97639125585556, 70.44605389237404, 74.71000269055367, 78.40360209345818, 78.45869153738022, 78.33751603960991, 78.37614476680756, 72.58764937520027, 81.92128613591194, 81.1908133327961, 79.21966910362244, 77.08473846316338, 84.42210674285889, 78.4333848953247, 83.75459656119347, 71.44234523177147, 0.6219405925367028, 0.7588151260279119, 1.3618663977831602, 2.247727825306356, 3.1495514838024974, 2.232401822693646, 0.42530755628831685, 0.6582007999531925, 22.470681332051754, 37.87758730351925, 45.00161603093147, 29.340832382440567, 20.266740694642067, 20.298588685691357, 21.1747969686985, 29.924304373562336, 50.639058127999306, 69.81578171253204, 74.06662881374359, 58.804325982928276, 1.999776167795062, 0.02300080221175449, 0.11076421229518019, 0.045808612630935386, 0.02863414465537062, 0.022831423702882603, 0.051315582168172114, 0.026864185529120732, 0.06590181568753906, 0.04199473427433986, 0.08923587374738418, 0.09796062862733379, 0.05370167600631248, 0.19054009288083762, 0.22001509641995654, 0.1146177547343541, 0.2341645723208785, 0.1879031234420836, 0.2880092861596495, 0.24925949983298779, 0.19273800775408745, 0.1352423577918671, 0.213331418344751, 0.09477262938162312, 0.10275434600771405, 0.1494976639514789, 0.8221560053061694, 91.5378025174141, 95.20774438977242, 86.97401940822601, 62.98546202480793, 55.082942470908165, 67.58764207363129, 76.41287371516228, 95.11287108063698, 71.40454486012459, 12.62027895078063, 0.4935127682983875, 1.6247310675680637, 8.10629976913333, 9.413380231708288, 7.696611452847719, 4.360340600833297, 4.355049384757876, 5.973630482330918, 98.38780894875526, 108.68765786290169, 109.07579183578491, 96.89019531011581, 98.33292469382286, 95.01857534050941, 93.99157404899597, 88.76988664269447, 89.45785492658615, 83.71611222624779, 74.58031564950943, 70.55139183998108, 70.0893822312355, 70.14783069491386, 70.11590480804443, 69.35538321733475, 67.1942263841629, 65.70238083600998, 66.65843233466148, 69.2571584880352, 70.80887362360954, 65.0151877105236, 65.644601136446, 70.26725068688393, 61.402383372187614, 57.265404760837555, 62.70907625555992, 62.37724766135216, 63.44056360423565, 60.47891892492771, 60.38970351219177, 66.4228829741478, 76.18714302778244, 81.91684797406197, 82.07418233156204, 80.79676687717438, 79.10094827413559, 74.41721320152283, 73.97026598453522, 73.37201088666916, 68.88063669204712, 65.94013407826424, 63.9773266017437, 61.297045424580574, 59.5488466322422, 56.95865102112293, 63.253613635897636, 76.70776069164276, 81.83725744485855, 76.62793457508087, 79.42008554935455, 71.34180262684822, 73.04192259907722, 74.61591213941574, 82.82160982489586, 46.673085540533066, 53.91671285033226, 57.93487183749676, 74.48668107390404, 71.50941163301468, 68.03141266107559, 73.20806488394737, 66.88762083649635, 74.1590778529644, 76.01343914866447, 74.69224244356155, 74.21139344573021, 73.26015248894691, 71.4819923043251, 68.23771879076958, 53.00710625946522, 58.66228200495243, 57.96193778514862, 59.2636339366436, 55.26883989572525, 57.905989587306976, 58.348073065280914, 65.63401490449905, 67.24885985255241, 68.09720233082771, 65.5497658252716, 60.71362853050232, 53.823264464735985, 55.37998013198376, 54.664155542850494, 60.326763689517975, 59.03382606804371, 59.12083379924297, 57.90329173207283, 56.411187797784805, 57.10274688899517, 62.04895667731762, 61.224663108587265, 61.80877536535263, 68.69833767414093, 79.07980620861053, 73.08784693479538, 78.75838905572891, 81.04444518685341, 84.03369918465614, 79.92664396762848, 80.57250291109085, 73.76355707645416, 86.84892252087593, 83.42489585280418, 81.30288451910019, 79.895189255476, 89.58799794316292, 80.21756395697594, 90.58848425745964, 66.89944580197334, 0.44158828735817224, 3.008778062649071, 9.38213450834155, 4.978117626160383, 7.014859160408378, 2.05168423242867, 0.37729929958004504, 2.1683199238032103, 33.92030484974384, 48.42734880745411, 87.27427169680595, 80.64262434840202, 35.644724518060684, 20.34307859838009, 22.81040970236063, 38.69331993162632, 61.055826768279076, 81.9397759437561, 83.97692263126373, 69.80111449956894, 2.7643022686243057, 0.26049754524137825, 0.18059347348753363, 0.24121838912833482, 0.09264803869882599, 0.14722951222211123, 0.2684776217211038, 0.13192231563152745, 0.21814173756865785, 0.20682894304627553, 0.25194853835273534, 0.17986671795370057, 0.1289905354497023], [0.0764722102030646, 0.06988673310843296, 0.02318060604011407, 0.0371291992632905, 0.02250467092380859, 0.15961061348207295, 0.1347478202660568, 0.04319162922911346, 0.057994918679469265, 0.224184823455289, 0.013391922166192671, 0.05529494461370632, 0.20137706684181467, 4.493870185688138, 78.72009471058846, 72.1326693892479, 71.84854343533516, 35.959245041012764, 34.533105567097664, 68.82705196738243, 84.43194061517715, 70.74484705924988, 33.99799168109894, 0.3155440039699897, 0.09835939199547283, 2.441855608485639, 1.9058412895537913, 0.6801667087711394, 1.873301260638982, 7.095497008413076, 1.4740399410948157, 26.16348657757044, 113.58292758464813, 99.98475685715675, 99.42057073116302, 86.67057529091835, 96.81769520044327, 91.87324091792107, 89.98350352048874, 85.39543971419334, 91.66913866996765, 86.18630647659302, 83.91589030623436, 79.02910932898521, 73.7267978489399, 65.1211716234684, 64.05558720231056, 61.391063779592514, 59.56018142402172, 60.1304966211319, 60.698566138744354, 63.04207518696785, 61.885656639933586, 60.60026541352272, 61.495869755744934, 56.80776111781597, 51.42835557460785, 51.01859696209431, 55.48605144023895, 53.65834191441536, 55.108154118061066, 54.13596488535404, 60.81381015479565, 67.50311180949211, 69.12017583847046, 71.65527060627937, 75.62799543142319, 72.28335410356522, 72.42175027728081, 67.11869403719902, 64.82315361499786, 62.44314752519131, 55.24140156805515, 52.80024155974388, 51.85594283044338, 49.75985370576382, 55.45454353094101, 51.66543625295162, 53.008869364857674, 66.89411848783493, 75.2423845231533, 68.41573923826218, 70.1607272028923, 61.29189670085907, 66.48508563637733, 62.01630882918835, 67.43928283452988, 28.242828100919724, 25.147119015455246, 43.518874794244766, 61.27548538148403, 61.04514554142952, 63.272992596030235, 67.19880893826485, 68.07408437132835, 66.55336037278175, 66.22974693775177, 65.31057626008987, 68.50421369075775, 66.36162266135216, 66.86146304011345, 57.00129993259907, 49.451032876968384, 50.90456888079643, 50.19752562046051, 50.94868451356888, 48.61429877579212, 47.35066518187523, 50.21777853369713, 53.352161943912506, 57.13257908821106, 58.406377136707306, 57.01372906565666, 53.099570497870445, 52.23618842661381, 46.93732716143131, 49.99664939939976, 50.43610721826553, 51.30021505057812, 50.99073305726051, 51.215122416615486, 52.8803488612175, 52.33560249209404, 54.16051536798477, 57.16395020484924, 53.576015532016754, 59.73960779607296, 62.96966627240181, 65.60049310326576, 68.01745221018791, 72.61350318789482, 70.67501440644264, 70.25879234075546, 70.8942398428917, 76.87344700098038, 76.74583464860916, 76.00150778889656, 74.38360020518303, 73.18883791565895, 67.40307077765465, 82.67128989100456, 71.40196859836578, 86.77592843770981, 22.444208152592182, 0.8418547420296818, 2.3364544892683625, 3.2114860229194164, 2.9119502333924174, 2.6970598893240094, 0.3826115926494822, 0.3886232856893912, 10.196739546954632, 24.091265872120857, 38.15822884440422, 70.87464049458504, 69.56816419959068, 73.78327801823616, 31.454981938004494, 19.64188702404499, 28.426339253783226, 49.74137529730797, 53.552323803305626, 62.4128707498312, 9.64161403477192, 0.1608077422133647, 0.053744241886306554, 0.019208164121664595, 0.05452517048979644, 0.027826279801956844, 0.0055511245409434196, 0.0964863077388145, 0.13623229373479262, 0.012401373951433925, 0.045806534617440775, 0.061271830927580595, 0.07662524105398916, 0.05548168010136578, 0.005893241632293211, 0.02672385653568199, 0.0540866354276659, 0.061219962226459756, 0.07333189394557849, 0.049159257250721566, 0.05568081316596363, 0.03760975472687278, 0.19605615001637489, 0.0611192973155994, 0.09381532567203976, 0.20255182724213228, 7.527746614068747, 94.75679978728294, 80.22064939141273, 81.48149013519287, 46.18309423327446, 42.78119757771492, 64.60364699363708, 70.14946460723877, 77.15184286236763, 40.08436068892479, 0.26495518104638904, 0.28395552712026983, 4.915162604302168, 4.948491090908647, 4.949024012312293, 4.720026450231671, 9.86348032951355, 1.7284309468232095, 29.928812831640244, 114.79837596416473, 99.88645613193512, 101.21519163250923, 88.97268176078796, 100.33091068267822, 96.72825559973717, 95.26828274130821, 89.79168221354485, 92.67964884638786, 88.15596118569374, 91.12918004393578, 84.27892282605171, 77.71661415696144, 68.74023422598839, 67.48022183775902, 64.0594781935215, 61.89522072672844, 63.59970286488533, 63.90886947512627, 65.03385230898857, 64.47909727692604, 63.33085589110851, 65.43150097131729, 60.601865127682686, 54.98626805841923, 54.54462915658951, 57.82641425728798, 58.54558266699314, 57.20685750246048, 55.9565269947052, 65.47851964831352, 70.94153970479965, 73.70680332183838, 75.24360805749893, 80.10144218802452, 73.1870748102665, 76.01476147770882, 68.6900769174099, 67.80346289277077, 66.28963932394981, 58.51293481886387, 54.971730038523674, 55.39401277899742, 54.39935155212879, 56.797387674450874, 53.88027660548687, 56.83989979326725, 69.3285870552063, 80.0433737039566, 70.54517537355423, 73.38715687394142, 65.47293394804001, 70.54581373929977, 67.98020660877228, 70.60284107923508, 40.72867691516876, 37.120462730526924, 51.050435453653336, 64.85102131962776, 64.89231750369072, 65.79962521791458, 69.99280661344528, 69.24698263406754, 68.82345736026764, 69.90045636892319, 69.05856594443321, 72.42751836776733, 69.27189409732819, 69.06140819191933, 59.034164249897, 53.52716535329819, 55.047836154699326, 54.07978110015392, 54.27787967026234, 52.35047109425068, 51.56240478157997, 52.40420401096344, 55.327584743499756, 60.62321998178959, 61.61547973752022, 60.788913890719414, 57.223147228360176, 54.02548961341381, 49.126610085368156, 53.57041843235493, 54.223880767822266, 55.24588152766228, 55.29658980667591, 55.09796306490898, 55.29978923499584, 54.6101376414299, 56.85637570917606, 59.939199686050415, 55.943170711398125, 64.01603892445564, 65.05105778574944, 69.8213142156601, 70.19306346774101, 75.35151466727257, 73.86780828237534, 73.85781481862068, 74.2918199300766, 78.91940161585808, 78.68925556540489, 79.79739770293236, 75.789904743433, 75.87644889950752, 70.43656200170517, 82.48246282339096, 75.02961114048958, 89.29963141679764, 30.991838090121746, 0.9611227421555668, 0.9926310076843947, 3.29513568431139, 4.369825841858983, 3.6951839178800583, 1.1314681358635426, 0.6568453414365649, 9.411005359143019, 38.028712794184685, 37.338411435484886, 54.719621166586876, 49.230264723300934, 50.706227123737335, 30.098344534635544, 31.11341066658497, 36.36160545051098, 59.24689203500748, 58.93150515854359, 75.85982859134674, 13.230345714837313, 0.29543497832491994, 0.08483147219521925, 0.06397226883564144, 0.05441795612568967, 0.018083758441207465, 0.0590564236335922, 0.04820530433789827, 0.017560937667440157, 0.07976781344041228, 0.09647745391703211, 0.05631844418530818, 0.015100163363968022, 0.1353142422158271, 0.11969348081038333, 0.08532888183253817, 0.20697294938145205, 0.19583107146900147, 0.32194541359785944, 0.19359821628313512, 0.19736412592465058, 0.17393605259712785, 0.37738046084996313, 0.12450492809875868, 0.2300752347218804, 0.4265951825072989, 7.2355555929243565, 110.65389275550842, 92.61240765452385, 95.95566585659981, 57.53808952867985, 49.577569887042046, 75.35173505544662, 103.43997985124588, 93.16367447376251, 55.45819893479347, 0.8837490971200168, 0.3490454109851271, 7.597490446642041, 6.112478831782937, 5.141089931130409, 10.18053911626339, 14.556354861706495, 2.7431271923705935, 30.56796133518219, 115.24692669510841, 107.57720544934273, 107.1201203763485, 93.15918311476707, 104.90949019789696, 101.96468621492386, 98.84724229574203, 90.51938116550446, 96.71091333031654, 91.7419807612896, 89.76072147488594, 86.959428191185, 80.64605176448822, 73.37176010012627, 69.9823647737503, 68.30838739871979, 65.43220773339272, 66.74681559205055, 67.5265109539032, 68.93861398100853, 69.20712277293205, 66.89294815063477, 68.60266640782356, 64.83965992927551, 57.57229529321194, 57.68976218998432, 61.788131073117256, 61.30222834646702, 59.82321470975876, 59.578363448381424, 66.31497636437416, 73.7168499827385, 75.36384120583534, 79.63817104697227, 83.6864586174488, 77.41761580109596, 79.98459085822105, 72.60121464729309, 73.27054113149643, 69.83250841498375, 62.32134126126766, 58.18168379366398, 58.59934218227863, 57.41475194692612, 61.31015472114086, 58.88415589928627, 59.25872080028057, 73.58982279896736, 85.3912827372551, 73.52774173021317, 76.17568284273148, 68.88252899050713, 74.48126256465912, 69.94082540273666, 79.14175808429718, 37.21489906311035, 36.241524294018745, 52.127350866794586, 72.71487414836884, 68.04623946547508, 68.9756315946579, 71.69836029410362, 73.1528690457344, 72.98313215374947, 73.22475358843803, 72.29121968150139, 77.35782220959663, 74.20299589633942, 73.27810272574425, 62.30537451803684, 55.58336801826954, 56.912441700696945, 55.467333644628525, 57.975267469882965, 55.054079219698906, 53.207241520285606, 56.77816070616245, 58.69352772831917, 64.69716757535934, 64.73341763019562, 62.86968603730202, 59.282040148973465, 56.6822462528944, 51.41016595065594, 56.804299503564835, 55.887784883379936, 57.65188202261925, 57.80647672712803, 56.996546387672424, 58.35467331111431, 59.15038861334324, 61.87706910073757, 64.13456976413727, 60.20976036787033, 67.62743353843689, 69.09753665328026, 72.3210708796978, 74.06787514686584, 80.15317261219025, 78.06213721632957, 76.10713452100754, 76.01907804608345, 83.01411509513855, 81.93707048892975, 84.38590228557587, 80.54713547229767, 79.3536727130413, 75.02249032258987, 90.10460302233696, 78.15222278237343, 93.371272534132, 27.158717773854733, 1.1599242151714861, 10.001829005777836, 8.248260151594877, 9.021368566900492, 6.490141041576862, 1.0753388539887965, 0.5515842803288251, 17.068554908037186, 48.514014557003975, 54.605741277337074, 99.33490052819252, 87.98967450857162, 89.45169165730476, 45.224512070417404, 33.24849709868431, 45.12235075235367, 70.1686079800129, 68.74369964003563, 88.61697524785995, 15.770487561821938, 0.46117611753288656, 0.24207717273384333, 0.1753810586524196, 0.2172360650729388, 0.1353392525925301, 0.1239093545882497, 0.2914862777106464, 0.3351896326057613, 0.22924549877643585, 0.15496009349590167, 0.11924842969165184, 0.25694583426229656], [0.07247513640322722, 0.12426925168256275, 0.03300510688859504, 0.0344543134997366, 0.024357425900234375, 0.054414416081272066, 0.06086720088205766, 0.13139166519977152, 0.014168798643368063, 0.19699844007845968, 0.08860168629325926, 0.23229749203892425, 0.4213014431297779, 24.00553487241268, 79.15614411234856, 63.66977110505104, 58.65358047187328, 41.05261713266373, 39.048790857195854, 45.40731646120548, 76.94766461849213, 50.589330196380615, 11.230757161974907, 0.15966248960467055, 0.46003291325178, 2.1892323391512036, 5.198789834976196, 2.7447197819128633, 2.8046128805726767, 0.4259381740121171, 1.8263235501945019, 46.87279902398586, 89.25128281116486, 101.46433666348457, 97.74545341730118, 92.76515945792198, 94.41816955804825, 94.1437178850174, 97.49504685401917, 90.90268179774284, 90.73159217834473, 87.57203131914139, 87.5875648856163, 85.8461943268776, 86.40665665268898, 77.541473954916, 67.09165468811989, 60.234212055802345, 61.162107065320015, 59.67629939317703, 60.87492607533932, 60.612154975533485, 60.2329733222723, 60.7497151941061, 60.6693647056818, 54.37389671802521, 51.33734665811062, 53.58322374522686, 57.488600984215736, 55.33886633813381, 54.569061845541, 57.41778418421745, 63.13450522720814, 67.4393056333065, 67.35924392938614, 71.31153345108032, 71.59670054912567, 68.19164246320724, 68.62510800361633, 61.964494809508324, 58.06746192276478, 54.07418020069599, 52.099300771951675, 48.88468846678734, 49.31183874607086, 50.018369033932686, 54.45472218096256, 52.18468599021435, 55.842799097299576, 70.56865811347961, 73.04019749164581, 68.93941193819046, 68.65790784358978, 66.80629000067711, 65.51860749721527, 64.41255524754524, 55.82175962626934, 21.432962715625763, 10.579399913549423, 35.53202636539936, 57.03870132565498, 57.028145492076874, 63.76797303557396, 66.04383051395416, 67.55428746342659, 65.47660455107689, 61.45970709621906, 59.93011437356472, 61.927382200956345, 59.971220567822456, 61.79673381149769, 51.28731094300747, 50.37311799824238, 50.43555624783039, 52.09393925964832, 50.20378388464451, 49.660261049866676, 48.21478061378002, 50.0947867333889, 50.90924642980099, 51.56177021563053, 56.082140654325485, 55.525584518909454, 53.04565519094467, 51.27154938876629, 47.206333726644516, 48.411807641386986, 48.65740746259689, 51.1671993881464, 52.40286648273468, 52.4251788854599, 52.321338057518005, 52.34039403498173, 53.43880869448185, 53.37723679840565, 52.1953634172678, 57.44765058159828, 58.329723849892616, 61.8439918756485, 62.75864079594612, 66.08014896512032, 65.28723791241646, 66.22091621160507, 70.93891024589539, 68.37638854980469, 67.15607643127441, 67.40164965391159, 66.46316841244698, 64.4908994436264, 66.13295093178749, 70.92402264475822, 75.75242355465889, 81.38585686683655, 59.45716895163059, 0.6147883669473231, 0.24439721542876214, 1.3359215087257326, 1.73179863486439, 1.506059872917831, 0.6162427389062941, 0.11813879274995998, 0.17399324249709025, 30.137818716466427, 28.658088818192482, 30.20355138927698, 86.04030311107635, 129.96276944875717, 62.04958364367485, 21.087656244635582, 21.98076982051134, 42.00868763029575, 57.219237238168716, 67.91279822587967, 32.476279735565186, 0.41150292672682554, 0.2059018224827014, 0.014228997952159261, 0.013168431814847281, 0.08534017732017674, 0.054866217033122666, 0.028278162390051875, 0.11237292870646343, 0.011030427740479354, 0.05238152887613978, 0.07733645601547323, 0.030085325379332062, 0.06936833553481847, 0.07129029763746075, 0.03553106958861463, 0.01865246806119103, 0.046126845554681495, 0.1331165203009732, 0.05328029568772763, 0.13460897927870974, 0.034222533358843066, 0.2557731221895665, 0.0308071493418538, 0.3228768683038652, 0.6264657934661955, 33.12830574810505, 93.0812568962574, 71.13596767187119, 71.46806985139847, 59.44856621325016, 42.1451611071825, 41.88237100839615, 78.12595099210739, 59.293857514858246, 12.532844692468643, 0.43094066495541483, 1.1787510174326599, 4.958906807005405, 3.3453837130218744, 3.8414340326562524, 3.352094627916813, 0.30239267216529697, 4.2230824660509825, 58.31709712743759, 88.95440474152565, 102.11587250232697, 98.51542890071869, 94.7661092877388, 97.17478483915329, 95.73024675250053, 99.60444286465645, 93.97872313857079, 92.10861548781395, 89.22954797744751, 89.37486737966537, 85.4615181684494, 89.0329161286354, 79.27172631025314, 70.41080698370934, 62.54044130444527, 64.6135188639164, 61.59434527158737, 65.20672023296356, 64.31423172354698, 61.82476870715618, 64.4983622431755, 63.74711595475674, 58.62835742533207, 54.726506397128105, 57.239687740802765, 59.35567259788513, 56.828173622488976, 57.85847693681717, 60.539206489920616, 66.6271524131298, 71.25090390443802, 69.67189863324165, 76.78740441799164, 74.97741714119911, 69.27748739719391, 70.68754613399506, 64.98415857553482, 60.68842068314552, 57.71583639085293, 55.97030885517597, 52.823766097426414, 52.43363343179226, 54.136918634176254, 56.91982090473175, 55.377559661865234, 60.05347855389118, 74.50676679611206, 76.70726671814919, 70.38490757346153, 71.38002097606659, 71.84715270996094, 69.50171336531639, 68.0006343126297, 62.482179030776024, 27.23514687269926, 14.609238523989916, 43.24129208922386, 63.73098962008953, 61.36518716812134, 66.90057054162025, 71.82485550642014, 69.7576068341732, 68.25950682163239, 65.29786974191666, 62.97288849949837, 62.39261783659458, 61.696297600865364, 63.393799513578415, 54.05272655189037, 53.79787042737007, 53.71650539338589, 55.604004710912704, 54.9500598013401, 52.03144021332264, 50.99688112735748, 52.009834572672844, 53.0531369894743, 55.48623003065586, 59.46885712444782, 58.59812244772911, 55.92120788991451, 53.86211737990379, 50.67185416817665, 51.88633359968662, 51.21430546045303, 53.17125365138054, 54.79803375899792, 54.6952910721302, 54.72863808274269, 54.43824626505375, 55.77540971338749, 55.59848740696907, 55.55756360292435, 58.40087503194809, 60.688945055007935, 64.00297522544861, 65.76630860567093, 68.27728986740112, 66.85476779937744, 67.6385061442852, 72.59406343102455, 71.4414256811142, 69.27642345428467, 69.94954213500023, 67.0278713107109, 67.88357019424438, 69.51342433691025, 75.0558753311634, 79.44052845239639, 84.37373533844948, 67.62386173009872, 1.272441758774221, 0.6307614035904408, 2.3365357099100947, 5.188624430447817, 2.8792107151821256, 2.491886098869145, 0.06734236143529415, 0.2725177846150473, 35.066973119974136, 39.53844778239727, 34.01158355176449, 79.39016595482826, 108.6384429037571, 53.53020519018173, 28.558368869125843, 33.43279480934143, 48.75924579799175, 63.279148265719414, 78.61880734562874, 40.436780378222466, 0.3237653971882537, 0.020268752523406874, 0.07375828005024232, 0.05738905158068519, 0.11511719043483026, 0.11347671752446331, 0.060949649778194726, 0.13140352471964434, 0.0822785212949384, 0.08160069555742666, 0.09667384103522636, 0.08773495428613387, 0.14487197622656822, 0.16562846634769812, 0.13484698603861034, 0.20751263917190954, 0.17829372111009434, 0.14311563922092319, 0.13702475902391598, 0.15719774295575917, 0.21008440351579338, 0.2898120816098526, 0.1443831532378681, 0.5235537781845778, 0.9164189721923321, 39.00381647050381, 109.4055001437664, 81.17155596613884, 81.99725165963173, 63.368587866425514, 53.10801364481449, 55.65398722887039, 93.37007939815521, 73.3230847120285, 18.27377423644066, 0.4345219727838412, 1.5796020766720176, 5.642326259985566, 13.868770357221365, 13.025774192065, 6.676549538969994, 1.3992398860864341, 4.395426493138075, 70.51226913928986, 101.75246760249138, 103.92016008496284, 106.66488960385323, 97.50555709004402, 99.20316159725189, 100.13611033558846, 103.57555657625198, 98.65605175495148, 97.58265495300293, 92.49320805072784, 92.35933363437653, 89.50761705636978, 92.57406771183014, 83.30531626939774, 74.03904229402542, 66.85338467359543, 68.4375424683094, 63.959186375141144, 68.45517352223396, 67.07154616713524, 65.3744812309742, 65.92112749814987, 68.24865460395813, 62.36218146979809, 58.92985984683037, 59.70300056040287, 63.39632637798786, 61.32460914552212, 59.871000945568085, 63.813228607177734, 69.46975708007812, 74.96939957141876, 72.68719643354416, 80.8389750123024, 78.58565032482147, 73.30135747790337, 75.64947947859764, 68.56467604637146, 64.12020653486252, 61.765799671411514, 60.17275035381317, 55.65525256097317, 53.69782939553261, 54.96414564549923, 60.93037270009518, 58.943003341555595, 62.52831995487213, 80.00459298491478, 81.48215129971504, 71.59293115139008, 74.46274235844612, 72.0325979590416, 74.78450909256935, 72.36616685986519, 70.25704443454742, 27.375123761594296, 14.923693500459194, 45.41997358202934, 73.05422633886337, 65.58605387806892, 69.91492599248886, 76.2856337428093, 75.0942000746727, 73.64115044474602, 68.9085727930069, 68.13539788126945, 68.82336616516113, 66.24575927853584, 68.53536441922188, 56.04408569633961, 56.46671801805496, 56.49988263845444, 57.35667586326599, 57.213165163993835, 56.03099159896374, 54.23442140221596, 54.981601908802986, 56.65460653603077, 59.41504441201687, 63.39672155678272, 62.85034127533436, 59.24970768392086, 56.79472401738167, 53.481750190258026, 53.34307283163071, 54.01665508747101, 56.680878326296806, 58.24343428015709, 57.03560829162598, 58.07223826646805, 57.49368891119957, 59.078678861260414, 59.93161529302597, 58.72515723109245, 64.78790670633316, 64.54532772302628, 69.35685753822327, 68.8252280652523, 72.90413439273834, 69.66641172766685, 72.12899878621101, 76.98809444904327, 75.77514633536339, 73.03458139300346, 74.95332643389702, 72.62558653950691, 72.41696253418922, 72.30019479990005, 78.1973035633564, 83.49447771906853, 87.86938056349754, 67.97462850809097, 0.90063770650886, 3.925554631277919, 11.752920392900705, 8.127113152295351, 7.1003711968660355, 3.063978413119912, 0.2752361528109759, 0.6381679186597466, 45.68134255707264, 47.32238329946995, 45.18912076950073, 96.50726705789566, 138.26594710350037, 76.33682459592819, 33.11064049601555, 35.71645326912403, 61.97658196091652, 72.78180375695229, 86.70600458979607, 45.83627924323082, 0.5583169253077358, 0.40292913210578263, 0.13600071397377178, 0.18990417622262612, 0.12676747661316767, 0.24258993740659207, 0.12126682646339759, 0.3427648526849225, 0.15757160726934671, 0.2514560194686055, 0.1971686739125289, 0.19449087150860578], [0.05789051705505699, 0.0297544889326673, 0.011037909516744548, 0.021351677714847028, 0.027293473431200255, 0.016562669261475094, 0.020641401570173912, 0.027846969023812562, 0.03318024260806851, 0.10425441199913621, 0.03719164727954194, 0.05839701057993807, 0.046976419107522815, 42.586040049791336, 78.56075406074524, 64.79662343859673, 47.46213600039482, 23.920140154659748, 28.49159885197878, 43.306261003017426, 67.47152790427208, 35.42109131813049, 2.5702082086354494, 0.0974258963833563, 0.7681124552618712, 3.307582391425967, 3.801347608678043, 6.485138610005379, 1.9817976700142026, 0.722193819237873, 30.779997557401657, 89.42174926400185, 83.51386427879333, 103.76173138618469, 91.20638430118561, 96.21702343225479, 93.99073049426079, 96.107437312603, 90.47137454152107, 88.83518233895302, 86.61084249615669, 87.0724493265152, 86.54318332672119, 87.09213227033615, 84.65497344732285, 80.76929435133934, 74.43458586931229, 60.90822748839855, 61.422750279307365, 62.7956660091877, 59.81576710939407, 60.7880475372076, 58.819270581007004, 61.875872164964676, 58.07896390557289, 51.76185987889767, 53.55205401778221, 52.67397053539753, 53.415626138448715, 54.44341018795967, 56.07450306415558, 59.390155747532845, 62.94640772044659, 66.14431232213974, 65.99252566695213, 66.4456133544445, 63.72726961970329, 63.96595001220703, 59.6784158796072, 56.239528208971024, 54.126233607530594, 51.896798238158226, 49.76135082542896, 51.30168557167053, 49.23603281378746, 51.10224947333336, 50.099696069955826, 54.51931491494179, 53.4800098836422, 68.38554605841637, 68.3037668466568, 71.94953441619873, 64.86809760332108, 67.01809823513031, 61.54925689101219, 58.01596328616142, 51.07308603823185, 26.003266274929047, 14.396081361919641, 35.06798006594181, 52.13805869221687, 52.80831232666969, 65.33594369888306, 66.1074922978878, 63.17686155438423, 59.719168692827225, 52.472311556339264, 51.97440907359123, 50.834538638591766, 51.62567138671875, 50.58258555829525, 48.787425085902214, 49.667085483670235, 51.67560450732708, 49.00078363716602, 49.29039649665356, 49.48861666023731, 46.85272090137005, 47.93255835771561, 49.090215638279915, 49.988612830638885, 51.796400025486946, 52.62151055037975, 53.635767325758934, 52.82408528029919, 49.643811732530594, 48.55011261999607, 48.17945770919323, 50.85725761950016, 51.046635657548904, 51.641163155436516, 52.73102447390556, 49.187733605504036, 51.467318683862686, 52.46826857328415, 52.951587438583374, 52.189811915159225, 54.11017566919327, 55.097476691007614, 55.38875386118889, 55.68506196141243, 58.25289577245712, 56.7535038292408, 57.57593549787998, 58.48224766552448, 58.59487742185593, 60.888001173734665, 65.26581466197968, 63.47243249416351, 69.18114736676216, 71.6913078725338, 77.19969749450684, 75.73003515601158, 80.061726719141, 13.556939139962196, 0.5443181795999408, 1.4047798700630665, 5.1804781425744295, 1.8845645687542856, 1.7865694896318018, 0.0882146785443183, 0.21846722869668156, 8.75532679259777, 47.70622730255127, 37.77974255383015, 85.93224450945854, 101.16307362914085, 85.40120780467987, 24.65425506234169, 20.004414170980453, 36.690872982144356, 58.00155445933342, 59.63533379137516, 48.66862826049328, 0.32094571099150926, 0.042466265222174115, 0.03671554099128116, 0.029393395125225652, 0.06579817476449534, 0.05321749886206817, 0.04502740572206676, 0.03345804332639091, 0.03847364059765823, 0.03427763040235732, 0.03635133944044355, 0.020736277729156427, 0.05991951911710203, 0.04144381207879633, 0.030464729825325776, 0.038243901362875476, 0.018536819188739173, 0.10728809647844173, 0.014433817723329412, 0.08006732939975336, 0.07608497980982065, 0.0962768068711739, 0.1189351172070019, 0.049283800763078034, 0.057638476282591, 54.722972586750984, 89.87633407115936, 71.345724016428, 59.89667996764183, 31.746099516749382, 29.63884089142084, 42.50069282948971, 71.47077530622482, 42.84332424402237, 2.2217008844017982, 0.13765172538114712, 3.572418442927301, 4.563435902819037, 3.0428643710911274, 2.1074486151337624, 0.9956934652291238, 0.5522512039169669, 38.41987520456314, 100.44097557663918, 89.25194397568703, 102.42413476109505, 91.45810559391975, 96.45650938153267, 97.05339655280113, 99.09805923700333, 92.33854115009308, 93.16253453493118, 89.75051522254944, 88.21225136518478, 89.14440214633942, 90.71409031748772, 86.91094279289246, 85.48332139849663, 78.09804528951645, 63.860125690698624, 63.63562993705273, 65.53447544574738, 62.395091503858566, 64.01895716786385, 62.01974384486675, 62.428902089595795, 61.39219991862774, 55.43548375368118, 56.079028621315956, 57.10540674626827, 56.21697261929512, 57.473044618964195, 58.70164409279823, 63.796456307172775, 66.08315840363503, 70.51983073353767, 68.65805223584175, 68.72802168130875, 66.2885069847107, 65.78410685062408, 64.90680992603302, 59.525857865810394, 56.557001173496246, 54.27096024155617, 53.39667655527592, 53.36264558136463, 52.38485164940357, 53.147223740816116, 54.69986982643604, 56.68485291302204, 54.704672768712044, 70.0130595266819, 71.10257506370544, 74.7604563832283, 66.89272776246071, 65.20948648452759, 63.05331878364086, 61.76941707730293, 56.388712003827095, 30.357627421617508, 18.452862426638603, 41.77052401006222, 57.750486731529236, 56.04682914912701, 68.37884321808815, 70.31249865889549, 64.96083542704582, 61.976870745420456, 55.778312757611275, 54.40962240099907, 55.562928915023804, 53.106345534324646, 53.43544587492943, 51.509036645293236, 51.772791892290115, 53.91469895839691, 51.34634077548981, 52.49886453151703, 52.908824533224106, 49.513315334916115, 50.552190989255905, 52.37376384437084, 52.10168704390526, 54.54904071986675, 55.73822110891342, 56.56874634325504, 55.51219403743744, 52.182368114590645, 52.764804661273956, 52.50058963894844, 53.71210902929306, 54.23222132027149, 55.001615434885025, 55.237844958901405, 55.57294897735119, 56.218880116939545, 55.524186193943024, 55.31854882836342, 55.25595098733902, 56.05928488075733, 58.17135214805603, 59.24362041056156, 58.75881962478161, 59.82935518026352, 59.64587822556496, 59.578690230846405, 60.72029337286949, 61.66817910969257, 62.89236322045326, 68.26958388090134, 67.75091171264648, 73.41510817408562, 75.05004644393921, 80.51717787981033, 76.731638610363, 86.85166597366333, 20.83449672907591, 0.7775036513339728, 0.43755723803769797, 1.8464051163755357, 3.998599061742425, 2.27979501709342, 0.4657857748679817, 0.3318943188060075, 6.182012250646949, 56.32816605269909, 44.38687361776829, 82.43115797638893, 100.6858192384243, 74.26670327782631, 29.902850724756718, 32.46842935681343, 44.45573352277279, 65.53052365779877, 67.4002893269062, 58.43850441277027, 0.42566197633277625, 0.0143799953184498, 0.01967227359273238, 0.0233812920487253, 0.057478038797853515, 0.029864905663998798, 0.015580344042973593, 0.07805107001331635, 0.006882230409246404, 0.09143999297521077, 0.04258154302078765, 0.06702478902298026, 0.14958643965655938, 0.12726812943583354, 0.10772994894068688, 0.10299569985363632, 0.14107324881479144, 0.16568071354413405, 0.08568321281927638, 0.19579504762077704, 0.20640364789869636, 0.17180049297166988, 0.20684829825768247, 0.15804898634087294, 0.21985871106153354, 62.95328535139561, 104.95138674974442, 82.36599147319794, 68.56092184782028, 38.66222620010376, 41.982233449816704, 60.07388345897198, 84.29965451359749, 57.71753869950771, 3.6016148887574673, 0.14921028952812776, 3.19994461722672, 7.9174793511629105, 11.608246006071568, 17.06194706261158, 4.484137482941151, 0.6716953602153808, 39.05406877398491, 103.08225184679031, 91.85810253024101, 103.33843410015106, 94.60728541016579, 99.86403733491898, 102.10607662796974, 101.95455595850945, 98.4183669090271, 96.95191159844398, 94.3721616268158, 92.41232559084892, 90.9345392882824, 93.58380272984505, 90.99166542291641, 88.81568938493729, 81.32999986410141, 66.15582570433617, 68.85996580123901, 70.50563469529152, 66.12302586436272, 67.45531037449837, 65.0383360683918, 68.48020657896996, 63.024713918566704, 58.5094428062439, 59.658345356583595, 60.878706872463226, 61.14634171128273, 61.93373166024685, 62.89079010486603, 66.06167435646057, 68.30559834837914, 75.27548834681511, 70.64970016479492, 71.48253947496414, 70.14798268675804, 71.5679968893528, 69.11675602197647, 62.65138775110245, 61.66349396109581, 58.33947792649269, 56.330863907933235, 56.99719995260239, 56.77661418914795, 56.31378762423992, 57.66684181988239, 59.913482666015625, 58.440993279218674, 76.16291552782059, 73.44621330499649, 78.06460708379745, 67.25011378526688, 68.67281064391136, 67.66941368579865, 65.71158394217491, 63.96750032901764, 30.654019117355347, 15.461376048624516, 44.950501173734665, 65.62326148152351, 60.01594036817551, 70.12343600392342, 75.39225608110428, 69.68774378299713, 64.93642553687096, 59.996413215994835, 58.319320008158684, 58.79429452121258, 58.40447723865509, 57.66391597688198, 54.78711694478989, 54.48364622890949, 58.188994601368904, 54.882944002747536, 56.25764183700085, 56.77703596651554, 54.539438635110855, 54.97949682176113, 56.80279478430748, 56.35078623890877, 59.10450987517834, 57.479063495993614, 59.8110743612051, 58.771731331944466, 56.49169407784939, 56.487772688269615, 55.90097397565842, 58.18581037223339, 56.67943060398102, 59.218180775642395, 58.152030184865, 57.652368396520615, 58.73405635356903, 58.6390196532011, 58.62595975399017, 59.541722014546394, 59.08583767712116, 61.42617389559746, 62.103867530822754, 62.65324205160141, 63.58605019748211, 61.99466519057751, 63.34884412586689, 64.72372815012932, 64.95071277022362, 67.0321498811245, 73.28795939683914, 69.88313689827919, 76.42968401312828, 79.22001108527184, 85.15170559287071, 81.61585852503777, 91.51055797934532, 18.50571569055319, 1.2950520892627537, 6.706097228452563, 11.655079443007708, 4.991744169965386, 4.524064315482974, 0.37404521950520575, 0.4857976088533178, 12.772320192307234, 65.60316815972328, 56.76733888685703, 93.19588154554367, 101.76896631717682, 100.48220336437225, 37.30945698916912, 33.12724560499191, 55.90649127960205, 77.39056125283241, 78.26183170080185, 70.0459885597229, 0.47493319027125835, 0.09040715347509831, 0.12559721362777054, 0.12257253139978275, 0.1664350918144919, 0.27661850675940514, 0.06646546942647547, 0.17409867199603468, 0.1198050775565207, 0.21664797241101041, 0.24002547579584643, 0.1721231936244294], [0.04637558748072479, 0.026956215551763307, 0.021838259417563677, 0.08325276081450284, 0.033560563606442884, 0.057753939618123695, 0.031147114204941317, 0.021827822965860832, 0.02961336027510697, 0.08104811466182582, 0.0615337385534076, 0.10023820563219488, 0.2281565306475386, 68.22516426444054, 66.80249780416489, 66.99252560734749, 39.87271964550018, 42.95691154897213, 29.08905789256096, 49.59186851978302, 56.434142366051674, 18.777686096727848, 0.055710888700559735, 0.21205997094511986, 1.100978571921587, 5.488409819081426, 1.6868146299384534, 1.6829584306105971, 0.1251000934280455, 14.103034436702728, 101.7575441300869, 106.57999455928802, 105.61950489878654, 98.94361272454262, 96.04940682649612, 81.53786391019821, 87.39237695932388, 87.24030151963234, 88.02020967006683, 90.41407361626625, 88.8667206466198, 82.87872835993767, 84.61610913276672, 80.57354405522346, 81.4979736506939, 78.87864500284195, 76.9576808810234, 64.14879620075226, 59.91899996995926, 63.18777836859226, 60.81609383225441, 60.765651538968086, 59.05058316886425, 59.8067007958889, 56.19952015578747, 51.091252863407135, 57.41916351020336, 55.28101064264774, 53.89803685247898, 52.927705720067024, 56.04065828025341, 58.51859651505947, 62.72397145628929, 62.97969773411751, 60.78806273639202, 59.379558116197586, 57.15313978493214, 55.50688952207565, 53.94277945160866, 51.230823174118996, 50.025356858968735, 50.595136284828186, 51.49808943271637, 48.65916296839714, 51.41490049660206, 55.85578300058842, 56.061207577586174, 55.67562706768513, 52.66634814441204, 55.329032465815544, 61.8458803743124, 65.92430412769318, 69.25386786460876, 59.53755743801594, 51.03789612650871, 52.945139184594154, 49.199034199118614, 36.26085385680199, 30.04450522363186, 42.069830149412155, 51.42886094748974, 57.354954555630684, 65.07997423410416, 64.28252622485161, 60.592627823352814, 54.222843423485756, 55.125663578510284, 55.38520485162735, 52.3100982606411, 49.77187246084213, 48.25971320271492, 48.51991184055805, 49.029289707541466, 48.042490258812904, 50.00764220952988, 50.20936958491802, 48.552552089095116, 47.974686697125435, 45.668278858065605, 46.006673499941826, 47.7872047573328, 47.62689895927906, 51.03457510471344, 50.84450550377369, 49.607523679733276, 50.58464124798775, 49.36249002814293, 47.894036024808884, 49.577816873788834, 52.93967127799988, 51.2382023781538, 51.41225963830948, 50.87938763201237, 51.114997789263725, 50.84077410399914, 52.000779658555984, 52.40123637020588, 51.03324517607689, 50.32418802380562, 53.315569907426834, 53.37365739047527, 53.597985953092575, 53.07877041399479, 57.09039755165577, 59.17120769619942, 63.963715732097626, 67.22375839948654, 69.08855393528938, 68.40722769498825, 75.06918981671333, 74.36008706688881, 75.81487700343132, 74.53718036413193, 79.80957984924316, 63.35289090871811, 3.121648393571377, 0.6402594095561653, 2.6444761734455824, 2.1272716764360666, 0.912661092588678, 0.46368944516871125, 0.23324705514824018, 0.49826512578874826, 41.251019686460495, 41.18250176310539, 46.33932285010815, 77.19839036464691, 55.627647042274475, 31.443808637559414, 19.598611146211624, 27.95591499656439, 56.807574927806854, 56.19003586471081, 64.08875182271004, 3.0552258202806115, 0.2165498011163436, 0.148209651815705, 0.03990368866652716, 0.01651523489272222, 0.023333835415542126, 0.040457709328620695, 0.05651880921504926, 0.039263426733668894, 0.019527202275639866, 0.07873535243561491, 0.03202544969099108, 0.07723912334768102, 0.01368531633488601, 0.013054892497166293, 0.051533153891796246, 0.04227846104186028, 0.06639537357841618, 0.02406765805062605, 0.025526045028527733, 0.06415277399355546, 0.04409349821798969, 0.05947033794654999, 0.05476967475260608, 0.3448966867290437, 77.81744554638863, 77.67192095518112, 73.46565306186676, 51.282462403178215, 43.39008070528507, 31.746074818074703, 47.79199630022049, 60.48406004905701, 24.41995583474636, 0.12956501712324098, 0.3810105723096058, 4.38372359611094, 1.9046836579218507, 2.0531317172572017, 1.4685009070672095, 0.43562711973208934, 21.36091858148575, 105.42261466383934, 105.11916294693947, 107.87689536809921, 102.03670755028725, 96.38686671853065, 83.58696475625038, 88.6137530207634, 90.11202782392502, 91.74246713519096, 92.00244158506393, 91.03809133172035, 85.96449717879295, 87.04306930303574, 85.51610603928566, 84.92993429303169, 82.33119294047356, 80.20524501800537, 66.64342314004898, 62.56579354405403, 64.92576330900192, 64.75439250469208, 63.178408071398735, 61.61804459989071, 61.95070534944534, 59.387822672724724, 55.35622760653496, 60.480963215231895, 59.155153557658195, 56.71522468328476, 56.7041102796793, 59.91950914263725, 60.02927765250206, 66.35489702224731, 66.17421671748161, 63.133927658200264, 63.660917580127716, 61.58054061233997, 57.42042124271393, 59.2855017632246, 54.727038368582726, 51.903288289904594, 52.2569315135479, 54.028134271502495, 51.57078333199024, 55.51470190286636, 60.74936181306839, 61.575517281889915, 60.153151005506516, 55.403466671705246, 57.677089869976044, 65.46981811523438, 69.64233621954918, 71.95779517292976, 61.612234711647034, 53.20266656577587, 56.073298528790474, 54.69250962138176, 41.29307962954044, 34.57336060702801, 48.806788846850395, 57.43865266442299, 62.67208144068718, 66.94419980049133, 66.9993044435978, 65.01524090766907, 57.132035717368126, 58.74628409743309, 57.222459465265274, 56.51844464242458, 53.340473771095276, 51.07130013406277, 51.81618936359882, 52.25108742713928, 53.525938019156456, 54.73338782787323, 51.742632910609245, 52.29825809597969, 51.58718325197697, 49.58543926477432, 50.00213250517845, 49.93858851492405, 49.64945822954178, 52.72258512675762, 53.087813928723335, 53.52625720202923, 53.070809841156006, 52.97961853444576, 50.07887318730354, 51.61383882164955, 54.8851402848959, 52.96482592821121, 53.58594819903374, 54.23833519220352, 53.050811514258385, 52.481951639056206, 53.99103306233883, 55.37603594362736, 53.970449566841125, 54.033518582582474, 56.5466733276844, 55.780216455459595, 55.06887562572956, 56.30118370056152, 62.45833531022072, 61.524220034480095, 68.81664052605629, 69.72486019134521, 70.60348704457283, 73.6857296526432, 75.84365665912628, 76.63481220602989, 76.05475813150406, 79.38249796628952, 82.26259142160416, 78.98728877305984, 4.858754631131887, 2.689055143855512, 0.8226728963200003, 3.2412020908668637, 2.8717785514891148, 1.9182186503894627, 0.17909697722643614, 0.21473202912602574, 41.00939825177193, 51.88291758298874, 47.47190907597542, 77.76745542883873, 61.813616305589676, 26.830856166779995, 24.82720658183098, 39.79122541844845, 62.51107268035412, 64.5130142569542, 74.50299739837646, 4.922948386520147, 0.18067951808916405, 0.160018275200855, 0.03948661651520524, 0.053806968207936734, 0.056430452823406085, 0.07527346358983777, 0.02878196562960511, 0.08444339575362392, 0.046314497594721615, 0.005080688724774518, 0.05641088981064968, 0.16586283658398315, 0.14469049143372104, 0.10210393520537764, 0.14839627227047458, 0.16125205118441954, 0.15693273686338216, 0.24664132157340646, 0.14835661189863458, 0.15474430663743988, 0.2077997018932365, 0.17704830825095996, 0.1306417101295665, 0.3683138207998127, 87.9265370965004, 90.24753615260124, 85.67544668912888, 56.634828597307205, 59.08279784023762, 41.30240052938461, 66.43405437469482, 79.07715395092964, 31.06208872050047, 0.40218036447186023, 0.654725352069363, 5.201502414420247, 12.51528013497591, 9.547005761414766, 8.878275845199823, 1.9307523965835571, 19.8199150711298, 107.36559480428696, 105.21390706300735, 113.6911153793335, 106.55812293291092, 100.60068100690842, 84.60358500480652, 95.54420873522758, 95.6028699874878, 94.90949839353561, 96.95260316133499, 93.70928719639778, 88.49323868751526, 92.09059685468674, 87.26885318756104, 88.400409668684, 85.73048293590546, 86.62698403000832, 72.14458554983139, 66.78533032536507, 71.00060373544693, 69.24218729138374, 67.08570420742035, 64.87782508134842, 64.69359576702118, 63.30450050532818, 59.0556824952364, 65.49329325556755, 63.75655084848404, 60.720612555742264, 59.68379259109497, 62.75918796658516, 64.18671056628227, 71.0561415553093, 70.15220806002617, 69.02354702353477, 68.25292557477951, 66.32302433252335, 61.76333740353584, 64.58775624632835, 57.95861296355724, 55.99327102303505, 56.337046176195145, 57.67153836786747, 55.65775282680988, 58.1133596599102, 64.69770714640617, 62.979720532894135, 62.31438383460045, 58.813259303569794, 59.49176609516144, 69.03756827116013, 73.19470480084419, 77.18818411231041, 64.12193164229393, 57.71897882223129, 61.1453727632761, 59.93477292358875, 42.36008517444134, 34.176232516765594, 53.32546457648277, 63.58203001320362, 67.01356127858162, 73.19285809993744, 72.32877686619759, 68.81531819701195, 60.5585702508688, 62.32853427529335, 63.19425322115421, 59.49230566620827, 56.66691027581692, 53.11726614832878, 55.74001461267471, 56.175490245223045, 56.3611900806427, 58.26804555952549, 55.366703644394875, 55.09020388126373, 55.295324474573135, 52.6041454821825, 53.06784600019455, 54.053824692964554, 53.426413759589195, 57.949421256780624, 57.57072597742081, 57.214571088552475, 57.01083742082119, 57.27612018585205, 53.984846994280815, 55.28246596455574, 59.69754405319691, 55.418171882629395, 56.80584982037544, 59.94389623403549, 56.984113454818726, 55.25487184524536, 57.08669275045395, 59.58642281591892, 55.99094934761524, 58.29405136406422, 58.60343836247921, 60.00490576028824, 58.99025000631809, 60.56005597114563, 63.85989770293236, 64.79340121150017, 69.95535582304001, 73.28422799706459, 73.5829071700573, 75.3618349134922, 80.37976205348969, 80.39293214678764, 81.6099688410759, 83.18436875939369, 88.53483125567436, 78.62032726407051, 3.3673132862895727, 5.13498698361218, 7.985315211117268, 7.284641359001398, 5.146652357652783, 2.1478026872500777, 0.27613952464889735, 1.4635230554267764, 53.742503598332405, 57.15570844709873, 60.358491986989975, 82.82405689358711, 75.38306817412376, 42.504857406020164, 28.258025385439396, 42.31678269803524, 72.97828361392021, 72.15449541807175, 85.21938756108284, 5.713380072265863, 0.4714260675245896, 0.33194662537425756, 0.144587718823459, 0.17910582362674177, 0.13116529531544074, 0.21375200827606022, 0.19075544929364696, 0.16897155961487442, 0.08089693175861612, 0.15850543684791774, 0.08834158579702489], [0.159152738051489, 0.05089882171887439, 0.003648487499958719, 0.009114992826653179, 0.06002939036989119, 0.05350762665329967, 0.03171701682731509, 0.04037768725538626, 0.14327399869216606, 0.024117836510413326, 0.2356221800437197, 0.041411584315937944, 1.513059928547591, 60.81605963408947, 69.68756899237633, 63.49194064736366, 47.95564591884613, 29.962239637970924, 33.8176229596138, 47.94400334358215, 36.9288732111454, 6.459830068051815, 0.06699882869725116, 0.1316940161632374, 3.3798877615481615, 2.829755418933928, 0.836008518235758, 0.40875519916880876, 10.270005315542221, 109.7901839017868, 96.3120487332344, 93.29191759228706, 89.36114251613617, 93.08661460876465, 92.2207322716713, 96.65187209844589, 82.98364832997322, 83.86211559176445, 86.91575333476067, 90.54374545812607, 80.06432577967644, 78.50624218583107, 75.49952432513237, 78.9467753469944, 74.80337888002396, 76.39339596033096, 72.95084908604622, 68.31539422273636, 59.585233479738235, 59.26476247608662, 58.491545766592026, 61.86493635177612, 60.25410778820515, 60.7166151702404, 51.8799689412117, 50.91546289622784, 53.29415425658226, 52.609738782048225, 53.926493525505066, 54.0578942745924, 56.682918816804886, 59.83600862324238, 57.61982314288616, 57.018121629953384, 53.47536273300648, 52.940199449658394, 50.85536532104015, 52.40999110043049, 50.59938445687294, 49.998009726405144, 52.82960258424282, 52.37773083150387, 50.516716092824936, 51.92787677049637, 54.71413426101208, 60.590089559555054, 65.58830335736275, 63.40835653245449, 59.49099853634834, 56.347138434648514, 56.757007241249084, 66.40748620033264, 67.44726240634918, 61.843155920505524, 49.77353677153587, 52.47489921748638, 53.38634870946407, 45.65445140004158, 42.28866420686245, 49.41794045269489, 53.339554220438, 57.65412390232086, 60.982749089598656, 62.26187825202942, 59.547398909926414, 52.68456056714058, 53.90281319618225, 57.205257788300514, 58.87131258845329, 58.23559530079365, 53.67268614470959, 48.15271854400635, 51.56340412795544, 51.098799258470535, 53.3233442902565, 51.95742778480053, 50.64481481909752, 51.142310723662376, 51.437140703201294, 46.80926263332367, 46.5791317820549, 45.90022601187229, 47.16400399804115, 48.35130728781223, 48.96327205002308, 48.19988161325455, 48.41814950108528, 47.9898364841938, 46.428116485476494, 49.99622002243996, 53.150609359145164, 53.71059291064739, 51.383119001984596, 49.93235304951668, 50.893929451704025, 53.273449167609215, 52.342613115906715, 52.529525086283684, 52.96500451862812, 53.354175835847855, 53.283362835645676, 56.418373212218285, 61.16663262248039, 63.09748761355877, 67.30318933725357, 67.63270005583763, 68.9242659509182, 72.77259305119514, 70.3931151330471, 71.14989012479782, 70.44949650764465, 68.06348294019699, 77.18062251806259, 73.28403800725937, 85.29240444302559, 39.405158534646034, 1.194245635997504, 0.3938201302662492, 4.483328126370907, 1.9643959100358188, 1.3024711911566556, 0.047083956305868924, 0.12901073670946062, 15.341937057673931, 70.64844623208046, 30.999494679272175, 45.987412333488464, 40.302294194698334, 50.186415016651154, 31.291773095726967, 18.376091346144676, 53.92689250409603, 57.796019688248634, 68.52162435650826, 10.93455070629716, 0.3940051031531766, 0.1722994091687724, 0.056493557640351355, 0.05629194580251351, 0.04004759481176734, 0.05923085431277286, 0.13864789536455646, 0.14512230263790116, 0.037881610842305236, 0.034963222715305164, 0.034192212915513664, 0.08101117055048235, 0.05462424349389039, 0.0516637644614093, 0.0481713473709533, 0.0340471527306363, 0.037442983011715114, 0.06349317540298216, 0.017485370335634798, 0.04661162383854389, 0.07037565999780782, 0.08417686083703302, 0.08504080236889422, 1.8693697778508067, 73.43632623553276, 78.29914569854736, 72.2036799788475, 54.915778040885925, 40.822414085268974, 37.928519770503044, 46.56066857278347, 50.93896083533764, 6.511682560667396, 0.10175027957302518, 0.8045242389198393, 4.378300812095404, 3.3923617796972394, 0.49967603757977486, 0.29090915399137884, 15.60238553211093, 116.23845309019089, 96.25781044363976, 97.43756353855133, 90.60237631201744, 96.83551624417305, 94.56977382302284, 101.12857908010483, 86.85098201036453, 86.93397715687752, 88.6994232237339, 93.35193917155266, 81.89425438642502, 82.34635412693024, 77.51827999949455, 81.82802394032478, 76.89011290669441, 79.36688080430031, 77.28283703327179, 70.26429444551468, 61.49328209459782, 63.44587191939354, 61.23374842107296, 64.0785151720047, 62.5626815110445, 64.6057216823101, 53.91536012291908, 54.897649213671684, 56.44357345998287, 56.10756129026413, 56.40281304717064, 56.65304861962795, 59.59347523748875, 61.33467860519886, 61.66986241936684, 61.548797115683556, 57.09487371146679, 56.060428619384766, 54.750190526247025, 54.932139962911606, 56.31927452981472, 53.49393233656883, 55.31128741800785, 55.88410668075085, 53.70908439159393, 56.004826202988625, 58.59071284532547, 62.57377311587334, 68.01602348685265, 68.83776739239693, 61.61577992141247, 58.81244234740734, 59.478899985551834, 68.81483182311058, 69.29476886987686, 64.0908645093441, 52.48010873794556, 53.887963593006134, 58.68529736995697, 48.176151886582375, 45.98491586744785, 54.04666967689991, 56.28210112452507, 59.894308894872665, 64.67460438609123, 65.88428467512131, 64.04928714036942, 57.14563898742199, 56.893678307533264, 61.01135775446892, 62.94374406337738, 62.228405848145485, 57.517559230327606, 51.85644820332527, 54.343220964074135, 54.74132560193539, 56.39417991042137, 56.06040962040424, 54.3340140581131, 54.07851196825504, 51.78729571402073, 49.69360426068306, 50.002710074186325, 48.66185702383518, 48.85212041437626, 52.12236933410168, 51.985037103295326, 51.377544701099396, 51.58277928829193, 51.40769608318806, 49.07052889466286, 51.470567509531975, 56.52129828929901, 54.28302459418774, 53.61079506576061, 52.92239360511303, 54.28052432835102, 55.25106444954872, 55.11131934821606, 55.77462315559387, 55.81145077943802, 56.29666194319725, 56.92614756524563, 59.38635975122452, 65.45668601989746, 66.83354213833809, 70.85150733590126, 72.38857045769691, 72.85684213042259, 74.218590259552, 73.95268812775612, 73.06004762649536, 71.95194348692894, 71.7346939444542, 79.64447110891342, 76.16825044155121, 85.11297807097435, 55.76263099908829, 0.6139147700741887, 1.7937853024341166, 1.558785606175661, 2.6988631300628185, 2.4065063428133726, 0.7560802227817476, 0.17263785819523036, 13.34269618615508, 79.19655114412308, 41.469378769397736, 50.789492055773735, 47.60180130600929, 34.70272086560726, 30.49094706773758, 24.468427933752537, 61.39728784561157, 63.447008058428764, 78.3324547111988, 16.12542651593685, 0.5210046493448317, 0.3056866500992328, 0.07502072519855574, 0.10053424834040925, 0.08480792384943925, 0.04983964710845612, 0.043640647127176635, 0.004973703498762916, 0.08916119884815998, 0.0648205733159557, 0.050799529781215824, 0.2216858192696236, 0.1844349189195782, 0.13120829535182565, 0.10576014799880795, 0.17310330353211612, 0.11326169507810846, 0.1644601477892138, 0.14520052500301972, 0.19963201048085466, 0.146970487840008, 0.40468478633556515, 0.21815426502143964, 2.616720087826252, 86.02995246648788, 91.68552339076996, 79.65198710560799, 64.595857411623, 43.18063594400883, 47.1487782150507, 65.54091230034828, 59.59908373653889, 11.071686297655106, 0.20136281760642305, 0.6274942320305854, 8.92622072249651, 11.443068869411945, 6.405997406691313, 2.081585065461695, 13.897120635956526, 117.47527912259102, 104.21680256724358, 101.65553480386734, 96.33667141199112, 100.47318264842033, 100.66476836800575, 106.41572177410126, 90.91205969452858, 92.46672347187996, 93.45726191997528, 97.29682669043541, 87.08086967468262, 87.1592366695404, 82.60894283652306, 86.38244435191154, 80.18476411700249, 84.23302888870239, 81.11927077174187, 74.40684735774994, 68.51417675614357, 64.52719509601593, 65.60528844594955, 67.7239179611206, 66.59071996808052, 67.50965505838394, 55.72923459112644, 58.40090163052082, 59.84449736773968, 59.41346749663353, 60.080818086862564, 61.002128049731255, 61.57530449330807, 65.32758414745331, 65.03596499562263, 65.18895998597145, 58.99349123239517, 60.75098432600498, 57.656768560409546, 58.41233901679516, 58.89085114002228, 55.92026934027672, 59.15555253624916, 60.52796669304371, 56.686296835541725, 59.72265310585499, 59.827352687716484, 68.20766240358353, 72.2484339773655, 71.46949097514153, 65.93688905239105, 60.628079921007156, 62.05311365425587, 75.61409577727318, 74.49463784694672, 68.95451232790947, 57.7053527534008, 58.89816954731941, 61.04817397892475, 51.342917159199715, 48.041008338332176, 57.28138670325279, 59.18840557336807, 63.93562763929367, 68.8133879005909, 69.35302734375, 66.56066358089447, 60.25581009685993, 59.93042595684528, 64.7635044157505, 65.95887467265129, 63.549769744277, 59.84712302684784, 54.46795307099819, 57.710379883646965, 56.45256757736206, 59.551403895020485, 59.65307503938675, 57.16266207396984, 58.367110043764114, 56.82799123227596, 52.72157058119774, 54.469172805547714, 53.540111258625984, 53.26338350772858, 55.48730157315731, 56.722406297922134, 55.61698101460934, 55.20436115562916, 54.556210935115814, 51.911024674773216, 57.21615940332413, 60.8639370650053, 58.88422429561615, 55.78118920326233, 55.981647446751595, 58.02545517683029, 60.739615336060524, 59.47161577641964, 57.86693908274174, 59.81013581156731, 59.53759543597698, 61.18390269577503, 62.46620088815689, 68.76002356410027, 69.00729149580002, 75.73704957962036, 74.99630972743034, 75.84493339061737, 78.36534574627876, 78.93678948283195, 77.27865725755692, 76.87935188412666, 75.53499922156334, 84.77563217282295, 78.50036010146141, 95.76497688889503, 52.21264488995075, 1.2888853764161468, 6.482270713895559, 12.308478131890297, 5.871967887505889, 5.188156580552459, 0.8174025791231543, 0.2777864394010976, 20.844404697418213, 87.58285313844681, 48.01021859049797, 62.024710178375244, 58.4977850317955, 68.2770998775959, 40.81923745572567, 31.273874156177044, 72.11832895874977, 72.97246992588043, 91.8626394867897, 18.49961131811142, 0.6989226210862398, 0.5708979908376932, 0.21766213205410168, 0.1971709745703265, 0.22438772663008422, 0.1685461902525276, 0.2507838711608201, 0.20192653813865036, 0.23913457203889266, 0.1926644757622853, 0.11634582333499566], [0.04868585238000378, 0.06975316136959009, 0.050061983420164324, 0.05260731988528278, 0.026789892835950013, 0.06623247216339223, 0.10457912387209944, 0.0547117946553044, 0.08912380944821052, 0.06603727248148061, 0.08927670671255328, 0.02362313200137578, 2.432287009432912, 63.147941306233406, 65.17319843173027, 57.325962111353874, 38.14945891499519, 29.047987796366215, 54.591480642557144, 52.59424701333046, 27.10338894277811, 1.2527794763445854, 0.0276363308148575, 2.111423914320767, 4.207471003755927, 0.8470146276522428, 0.5063305492512882, 5.367907835170627, 103.0737555027008, 98.03467109799385, 94.69136729836464, 91.67490676045418, 89.84990268945694, 91.49345129728317, 89.56012263894081, 89.9870753288269, 91.85725897550583, 85.8098454773426, 84.72595363855362, 85.364098995924, 78.51720079779625, 73.9068853855133, 69.56725984811783, 72.09499821066856, 71.32520511746407, 71.37707993388176, 69.48390752077103, 63.428898230195045, 58.105551078915596, 57.02323995530605, 58.23758639395237, 59.959798380732536, 59.96960185468197, 59.44909818470478, 49.00368668138981, 54.91814911365509, 53.56039837002754, 56.24056175351143, 52.04511947929859, 52.55095213651657, 56.77364654839039, 61.784699857234955, 58.26825834810734, 56.2040951102972, 52.53668010234833, 53.91679644584656, 51.7804940789938, 51.79466351866722, 51.50699235498905, 49.89362172782421, 50.57910114526749, 52.52315662801266, 50.103674456477165, 52.54189722239971, 55.089998692274094, 63.834872245788574, 65.67962005734444, 66.91263109445572, 62.74093754589558, 59.47245553135872, 57.52570599317551, 63.418410792946815, 62.02140435576439, 60.76365664601326, 50.331586226820946, 52.455007284879684, 54.34626840054989, 50.415348932147026, 51.67191490530968, 52.178602516651154, 51.198030933737755, 52.98327013850212, 58.90709526836872, 61.92937329411507, 61.868865340948105, 55.378220826387405, 54.82982665300369, 55.85965119302273, 60.50833694636822, 61.20953232049942, 60.32791122794151, 56.25085540115833, 57.937364503741264, 56.61283537745476, 51.570255160331726, 49.08428035676479, 50.988247990608215, 51.83994188904762, 51.78366310894489, 48.34838144481182, 43.84189926087856, 46.73981375992298, 45.390623956918716, 45.89751675724983, 46.20856046676636, 47.3799654096365, 48.149690106511116, 46.77742414176464, 47.02202841639519, 47.468382865190506, 50.780110359191895, 52.36136510968208, 50.419935286045074, 50.76933793723583, 51.71273611485958, 50.49609459936619, 51.582285314798355, 52.32572682201862, 52.021712735295296, 54.8627632856369, 57.13534153997898, 63.65422613918781, 62.76216320693493, 69.25135999917984, 63.96461248397827, 72.14412197470665, 64.33814004063606, 68.2036118209362, 64.21368151903152, 71.17712706327438, 65.30431419610977, 72.23911687731743, 68.60520467162132, 80.97816154360771, 68.00213903188705, 91.38852372765541, 13.91131192445755, 3.4823136404156685, 1.9771954044699669, 1.6526983981020749, 1.7407042882405221, 0.27694238000549376, 0.08697460914845578, 2.60755592957139, 58.131841868162155, 58.48867692053318, 27.187208645045757, 46.14530146121979, 38.964781165122986, 32.06940516829491, 24.66529157012701, 47.83135078847408, 53.2004588842392, 70.86558938026428, 26.141772642731667, 0.5326826102100313, 0.2142972790170461, 0.05221227096626535, 0.06132117261586245, 0.0709437443583738, 0.03885928279487416, 0.01594025412487099, 0.017801022440835368, 0.014950292206776794, 0.06906168753630482, 0.024803178348520305, 0.03062940126255853, 0.0633108668262139, 0.052234171744203195, 0.05650775492540561, 0.03404870381928049, 0.06565354502527043, 0.07430738769471645, 0.007495001336792484, 0.07055445821606554, 0.027493437701195944, 0.2720356557983905, 0.2567848179023713, 3.8367609959095716, 77.14365810155869, 68.87008085846901, 64.7791139781475, 45.15495680272579, 34.59575280547142, 39.931126311421394, 62.165473625063896, 32.968581318855286, 0.5526551103685051, 0.10860720460186712, 3.7245620414614677, 4.062312617897987, 0.9528610354755074, 0.5928072589449584, 8.747176229953766, 110.00780582427979, 96.01786091923714, 99.16369691491127, 91.98468893766403, 91.12009093165398, 92.23670661449432, 92.87942692637444, 92.85370990633965, 93.22295889258385, 88.8444310426712, 87.77247816324234, 87.2461000084877, 83.57422024011612, 75.74724823236465, 71.45760521292686, 74.71589237451553, 74.98439356684685, 74.58019405603409, 72.05591350793839, 67.72280842065811, 61.01726643741131, 61.56653456389904, 61.94122485816479, 63.08964483439922, 62.63876862823963, 62.2049231082201, 51.6789635270834, 58.13846491277218, 55.59254452586174, 59.36399035155773, 55.58194309473038, 55.95123007893562, 61.210204884409904, 63.25408101081848, 63.56594927608967, 61.25210143625736, 55.26038534939289, 57.97398693859577, 54.974234104156494, 55.301145762205124, 56.51328831911087, 52.731773033738136, 52.69639313220978, 55.16134366393089, 53.269778564572334, 56.053892970085144, 56.43893010914326, 68.04278165102005, 70.70579275488853, 71.5599413216114, 65.92916786670685, 63.331209272146225, 61.76356539130211, 65.90421840548515, 63.91038939356804, 64.79889571666718, 51.697749719023705, 54.32027779519558, 56.874265149235725, 53.51244494318962, 54.79366399347782, 55.41804648935795, 54.954262375831604, 54.76977847516537, 63.39232139289379, 63.24599124491215, 66.47687047719955, 57.73011602461338, 57.76062458753586, 59.93570387363434, 62.732874378561974, 64.32313084602356, 62.82847344875336, 59.71603386104107, 60.12528330087662, 60.42413346469402, 56.47805280983448, 55.32687798142433, 52.96672582626343, 54.6599567681551, 54.11297991871834, 51.91331595182419, 47.999810948967934, 48.979432582855225, 47.823325619101524, 49.63700249791145, 49.02420558035374, 51.08557976782322, 50.35304367542267, 51.66643559932709, 50.0053471326828, 50.53815454244614, 52.952609583735466, 53.57407383620739, 53.980446830391884, 54.28926765918732, 53.445047959685326, 53.773452937603, 54.95283745229244, 56.403512209653854, 55.253838300704956, 57.17186518013477, 60.93675635755062, 67.43056610226631, 66.00434303283691, 72.0811365544796, 65.82060769200325, 76.70559480786324, 65.80720201134682, 69.39031854271889, 68.10093373060226, 72.8978419303894, 67.55049526691437, 73.00533816218376, 71.0975593328476, 82.83187687397003, 70.31651884317398, 97.91813895106316, 19.816884733736515, 5.272278841584921, 0.8077886793762445, 0.8344792190473527, 2.963834311813116, 1.8163473042659461, 0.06011778015817981, 1.7217528051696718, 63.002857491374016, 71.3253191113472, 35.12363187968731, 52.93551430106163, 38.13637241721153, 32.90855593979359, 34.4077654927969, 56.06736704707146, 61.31629139184952, 78.80988389253616, 34.11676570773125, 0.5663059372454882, 0.13408931263256818, 0.09371863867272623, 0.05561073587159626, 0.05420311921625398, 0.018765014756354503, 0.04552604732452892, 0.05487810994964093, 0.04234772197378334, 0.10446473665069789, 0.03439287109358702, 0.10801908967550844, 0.18774684198433533, 0.22789101989474148, 0.2184100091108121, 0.10589374200208113, 0.20555528404656798, 0.1957906541065313, 0.11648919884464704, 0.211950741650071, 0.24215073441155255, 0.4709518054733053, 0.38568254036363214, 4.247729368507862, 90.29722988605499, 80.37142530083656, 75.22186562418938, 52.25259594619274, 40.57386942207813, 71.52907937765121, 76.45231559872627, 45.05106657743454, 2.2330000530928373, 0.14735733973793685, 6.533297225832939, 11.377471089363098, 6.750162038952112, 5.213219560682774, 7.548613669350743, 108.42847377061844, 102.88410007953644, 101.58541336655617, 94.49823126196861, 98.1338381767273, 98.13820034265518, 98.80704805254936, 96.4075756072998, 97.82061338424683, 93.41690048575401, 92.2161041200161, 91.57864272594452, 87.04886019229889, 79.30211707949638, 76.60330429673195, 78.56007769703865, 79.80560526251793, 76.82199776172638, 76.11376896500587, 71.94923803210258, 64.79063495993614, 64.5473264157772, 65.45342579483986, 66.77994221448898, 65.29634222388268, 66.52508229017258, 55.1799550652504, 61.79961025714874, 60.775641202926636, 63.07754248380661, 57.11806006729603, 58.912912756204605, 65.29308199882507, 67.4345862865448, 67.05244079232216, 64.51792359352112, 59.301118925213814, 60.97828812897205, 58.71300168335438, 59.862424805760384, 59.48649197816849, 54.62569400668144, 57.87146843969822, 58.72215159237385, 55.90393401682377, 60.45357808470726, 59.5874335616827, 71.43281534314156, 72.586220651865, 74.93421345949173, 68.1632199883461, 65.84489598870277, 64.1068084537983, 69.63226675987244, 68.34054127335548, 70.71615099906921, 57.42291770875454, 58.52547414600849, 59.13932740688324, 54.65567819774151, 54.66491550207138, 57.70117677748203, 57.31738217175007, 59.14112091064453, 67.25237846374512, 65.35418272018433, 69.92660656571388, 61.531029269099236, 61.91286697983742, 64.24811527132988, 66.63558796048164, 67.63835415244102, 68.4367673099041, 63.169387355446815, 65.6213691830635, 63.18777456879616, 58.89486752450466, 58.73867690563202, 57.44124412536621, 58.03363613784313, 57.84379072487354, 54.61019463837147, 50.9477611631155, 53.27237382531166, 50.04079923033714, 53.213055208325386, 52.36696980893612, 54.84772369265556, 55.00348873436451, 53.36417309939861, 53.92994374036789, 53.726597651839256, 57.310090363025665, 56.02394677698612, 57.027940303087234, 57.45716147124767, 57.17814244329929, 56.975392922759056, 58.26309062540531, 59.37993809580803, 58.04763078689575, 61.24879941344261, 64.68918800354004, 72.0555031299591, 69.54566940665245, 75.949237793684, 68.19241002202034, 81.15235179662704, 67.88842633366585, 75.48027455806732, 69.40867155790329, 77.7713692188263, 69.73100066184998, 79.12149757146835, 74.3074294924736, 88.38894948363304, 74.57568749785423, 103.63308548927307, 17.10857056081295, 7.024908671155572, 9.125216994434595, 6.0528267826884985, 6.851080348715186, 2.079216130077839, 0.11100807460024953, 4.244233081117272, 73.91328424215317, 75.68955972790718, 45.73476389050484, 62.29576863348484, 57.27881044149399, 43.41730244457722, 39.3987862765789, 64.06833931803703, 70.97265243530273, 89.96711120009422, 38.817425072193146, 0.6513901404105127, 0.30564571323338896, 0.2561421477003023, 0.19901466235751286, 0.16243691963609308, 0.16222466540057212, 0.14926072588423267, 0.1405890568275936, 0.11668856197502464, 0.16320419643307105, 0.14683909801533446], [0.07960963950608857, 0.03531156457029283, 0.024863967664714437, 0.06472667679190636, 0.09586369036696851, 0.02828573229635367, 0.06714002971420996, 0.022593518988287542, 0.07784947301843204, 0.006709701019644854, 0.0891668391705025, 0.22400078567443416, 7.174301454797387, 68.38626801967621, 58.38701717555523, 61.51353120803833, 32.36420474946499, 48.12757529318333, 68.18835183978081, 40.13600751757622, 15.741386823356152, 0.18354766652919352, 0.36577914899680763, 3.6112031992524862, 1.7679103533737361, 0.30161712784320116, 0.21592418546788394, 81.61815360188484, 98.8063032925129, 90.0062794983387, 93.68922427296638, 81.38680681586266, 80.06612688302994, 75.00549763441086, 84.27783608436584, 86.99442431330681, 87.35410541296005, 88.5645304620266, 83.43148469924927, 87.39613115787506, 81.83988690376282, 74.1125075519085, 64.41853612661362, 64.2751470208168, 68.10788735747337, 68.75470384955406, 68.65011066198349, 64.81593400239944, 58.12363050878048, 57.44527570903301, 59.484542682766914, 58.62328849732876, 60.12798875570297, 54.67682026326656, 48.53122003376484, 52.653926610946655, 54.526789113879204, 54.69627521932125, 52.05122195184231, 53.307005167007446, 59.42296698689461, 61.37982398271561, 56.670174300670624, 56.33659400045872, 54.84966158866882, 53.71500447392464, 52.17162609100342, 50.48717647790909, 52.021344155073166, 50.74929021298885, 51.47347815334797, 48.487499579787254, 51.00074551999569, 51.18665814399719, 52.09135539829731, 61.606816202402115, 64.23385083675385, 65.85913002490997, 65.15148639678955, 62.02395021915436, 61.36330246925354, 61.35654263198376, 60.49395851790905, 56.56363181769848, 45.61480052769184, 51.57807894051075, 52.06608295440674, 55.194367691874504, 60.46060390770435, 59.44548837840557, 55.391881093382835, 49.85998213291168, 54.31913785636425, 58.76043453812599, 62.81768962740898, 55.90249389410019, 51.72348953783512, 54.184313490986824, 60.67321389913559, 59.77990843355656, 60.94415836036205, 58.234280571341515, 55.6120640784502, 57.05846406519413, 52.68391840159893, 50.65501727163792, 49.02259446680546, 52.19670094549656, 52.02521234750748, 52.207879945635796, 47.66238525509834, 45.11818237602711, 44.79791276156902, 44.211045652627945, 46.07244037091732, 46.79497539997101, 46.24314621090889, 45.67179746925831, 46.20449848473072, 47.01067462563515, 48.276610895991325, 53.04869882762432, 52.47383527457714, 51.82717077434063, 49.42321456968784, 50.09580507874489, 51.1050271242857, 51.24574117362499, 53.68545725941658, 59.869526624679565, 63.63006703555584, 66.28582432866096, 65.83818554878235, 67.69375517964363, 68.68105620145798, 69.86525505781174, 67.13355123996735, 65.56865081191063, 66.80244460701942, 66.94989189505577, 67.12345898151398, 66.51468604803085, 66.08027055859566, 74.17581975460052, 75.04905089735985, 79.66355368494987, 50.37349797785282, 2.4625063128769398, 1.7293648654595017, 2.521573193371296, 1.9023059355095029, 0.6710849585942924, 0.028286802844377235, 0.03399106863071211, 30.87238200008869, 81.07678905129433, 40.92104159295559, 43.49219262599945, 37.92638048529625, 31.850582510232925, 18.15109971910715, 32.128005623817444, 59.010738506913185, 60.35932034254074, 43.73515158891678, 0.25285487878136337, 0.05687281365680974, 0.07881276585976593, 0.07749014737783, 0.014445026008615969, 0.09935896843671799, 0.010369656556576956, 0.057382353697903454, 0.06582951566088013, 0.05372404062654823, 0.050469441048335284, 0.08805297940853052, 0.04956735312589444, 0.04547675387584604, 0.018099078224622644, 0.11735094361938536, 0.030673744586238172, 0.04621381413016934, 0.010926875875156838, 0.04500914517848287, 0.11007993729435839, 0.20748565468238667, 0.23449519911082461, 9.02337295934558, 82.52436697483063, 64.78058829903603, 70.13521537184715, 39.7610854357481, 37.27208599448204, 54.547798186540604, 57.59025312960148, 16.212842725217342, 0.1928425021469593, 2.1474303072318435, 5.303512690588832, 1.963628944940865, 0.45782238186802715, 0.8872275135945529, 91.5971477329731, 99.051473736763, 96.52074113488197, 94.29679647088051, 85.1303431391716, 81.60452753305435, 77.58531600236893, 85.95869868993759, 91.31547644734383, 87.75062173604965, 92.44612097740173, 86.30843192338943, 89.88808304071426, 85.84782063961029, 76.7157630622387, 66.92279174923897, 67.70620331168175, 69.81696724891663, 73.77026751637459, 72.7018104493618, 67.83072263002396, 62.483201175928116, 60.79514555633068, 62.1161712706089, 60.309588611125946, 63.102199360728264, 55.89717797935009, 52.811006382107735, 56.842639446258545, 56.15000881254673, 57.280976325273514, 54.222953617572784, 58.76065492630005, 61.59581959247589, 65.16467168927193, 62.74631805717945, 59.283875450491905, 57.515526339411736, 56.2767244130373, 54.97888885438442, 53.69292385876179, 55.022358521819115, 54.28829491138458, 54.9275042116642, 54.996041133999825, 54.40291576087475, 53.21468532085419, 57.084990441799164, 63.65102291107178, 69.10713493824005, 66.74399614334106, 68.55070039629936, 65.52162453532219, 62.554177567362785, 65.66901862621307, 64.19780597090721, 60.870164930820465, 48.063457533717155, 52.830472737550735, 54.30732049047947, 58.95441792905331, 61.68928697705269, 62.215414345264435, 57.70371504127979, 53.63491617143154, 56.50031961500645, 61.555408760905266, 67.14678213000298, 58.9466093480587, 54.04564753174782, 56.263565719127655, 61.47777892649174, 62.90736101567745, 65.15974715352058, 61.966991275548935, 59.51160103082657, 60.754297748208046, 55.25428667664528, 53.46511468291283, 51.569901779294014, 56.100482270121574, 55.11717863380909, 55.52424319088459, 51.22384674847126, 49.06360186636448, 47.15566344559193, 48.28743651509285, 49.16324011981487, 51.60472311079502, 48.906328305602074, 48.95656540989876, 49.539537727832794, 50.4364188015461, 51.694869473576546, 55.10199084877968, 53.690795972943306, 52.980682477355, 52.71035358309746, 53.66272307932377, 54.57532770931721, 55.04136510193348, 55.929434448480606, 62.210808992385864, 65.87213292717934, 68.99977549910545, 69.01030853390694, 68.73046115040779, 70.66736921668053, 71.85246482491493, 67.61618614196777, 67.9297985136509, 69.79596957564354, 70.00438079237938, 69.53677788376808, 68.85198622941971, 70.51852360367775, 76.91341325640678, 79.97002243995667, 79.11514431238174, 63.340134993195534, 4.016184993088245, 2.0949254371225834, 0.7236706931143999, 1.9564253627322614, 3.1940299971029162, 0.40700257290154696, 0.03931050858227536, 29.87143211066723, 90.24624422192574, 49.154367595911026, 51.75237938761711, 39.729429334402084, 25.623845234513283, 25.543034970760345, 39.13403928279877, 64.22016397118568, 69.09135818481445, 51.400860249996185, 0.15971310407621786, 0.061845470263506286, 0.06065730667614844, 0.05859358323505148, 0.028253343116375618, 0.10876114087295718, 0.0265332321941969, 0.045011631373199634, 0.025873626182146836, 0.07753265017527156, 0.03767524554859847, 0.173161621496547, 0.21971350244712085, 0.09445167277590372, 0.11854001262690872, 0.21497183188330382, 0.167491999163758, 0.15022940671769902, 0.0844227937341202, 0.15214488987112418, 0.19613634649431333, 0.1897156855557114, 0.47471609723288566, 10.43224710971117, 97.1445232629776, 73.31911012530327, 80.56779116392136, 46.15221709012985, 63.07892180979252, 90.21335318684578, 66.42351374030113, 27.36142359673977, 0.3374580218223855, 2.7130898041650653, 11.534016039222479, 9.860121309757233, 5.372047713026404, 0.7849915057886392, 90.4155783355236, 102.28036567568779, 97.87037551403046, 100.03207951784134, 90.31167671084404, 83.47313046455383, 82.38306015729904, 90.18632143735886, 93.87393996119499, 91.77224233746529, 94.46684494614601, 90.5568927526474, 96.17216303944588, 88.49291950464249, 81.11579775810242, 71.54693841934204, 72.14449435472488, 75.2911739051342, 78.17924693226814, 77.05606520175934, 72.31346368789673, 66.28796741366386, 64.78881865739822, 65.42063355445862, 63.29167619347572, 66.03526577353477, 60.21603003144264, 56.32513761520386, 59.188648760318756, 59.81926292181015, 60.99781908094883, 57.37388513982296, 61.490990817546844, 66.13080024719238, 69.8833192884922, 65.61095774173737, 64.37363013625145, 62.718503549695015, 58.56974937021732, 58.640486374497414, 57.16589190065861, 58.67708221077919, 59.29880864918232, 58.0051376670599, 57.12138868868351, 58.177899196743965, 56.936239823699, 58.92222225666046, 68.0226731300354, 71.61848098039627, 71.34750992059708, 70.26081383228302, 68.71842339634895, 66.50758802890778, 69.55022916197777, 67.576934248209, 65.32246962189674, 50.529149025678635, 54.45005603134632, 55.133183375000954, 59.69240292906761, 63.55944022536278, 64.87659394741058, 59.124804586172104, 54.064030945301056, 59.87449295818806, 66.28824859857559, 69.51409310102463, 62.51941703259945, 56.976396068930626, 61.084750816226006, 67.07744345068932, 67.23906397819519, 69.01160806417465, 65.1737380027771, 61.76258124411106, 64.53098729252815, 57.93637655675411, 58.93509216606617, 56.30786754190922, 59.745615273714066, 59.00759607553482, 58.330297619104385, 53.36223900318146, 53.03789600729942, 48.80211889743805, 51.71734146773815, 53.78307402133942, 54.75336715579033, 51.15893103182316, 53.78481052815914, 52.84154534339905, 54.1049737483263, 54.52122241258621, 59.0243835747242, 56.90186306834221, 57.64133378863335, 55.14529712498188, 56.6375682502985, 56.83917783200741, 57.56526567041874, 59.54501263797283, 64.48606610298157, 70.37948906421661, 70.57089999318123, 71.36264830827713, 71.96293249726295, 74.5095406472683, 77.36471503973007, 72.83025875687599, 70.52712634205818, 74.51324164867401, 73.43564987182617, 74.14351388812065, 71.49580836296082, 74.58403944969177, 80.41636928915977, 81.71003267168999, 86.14287480711937, 69.99903067946434, 5.304981786757708, 4.642697749659419, 7.978154495358467, 7.164471857249737, 4.156660605221987, 0.41836227115709335, 0.18031824060017243, 39.720982387661934, 99.63685512542725, 57.070019245147705, 62.73425370454788, 54.21531602740288, 44.414646327495575, 26.984025947749615, 47.834413424134254, 74.36029225587845, 78.86124953627586, 61.42877675592899, 0.2900338947074488, 0.14377192041138187, 0.18299323768587783, 0.16534247231902555, 0.1941499437089078, 0.19601127976784483, 0.10979023252730258, 0.16425308858742937, 0.12863608571933582, 0.18967317533679307, 0.14047236152691767], [0.027812062107841484, 0.05743063040426932, 0.044406228116713464, 0.017674306291155517, 0.0534562292159535, 0.045126367404009216, 0.023065736422722694, 0.020488172194745857, 0.04889949814241845, 0.033874232321977615, 0.13977067574160174, 0.07857164950110018, 7.7640435844659805, 64.67876136302948, 57.25983425974846, 56.308627501130104, 36.5670832246542, 58.47216300666332, 56.9394164532423, 28.26794095337391, 4.814291317015886, 0.34346098720561713, 1.7768623167648911, 3.3995970664545894, 0.19341106148203835, 0.8490271540358663, 45.71917712688446, 106.29494905471802, 86.81149452924728, 97.06104174256325, 83.59420716762543, 91.2529394030571, 82.40786522626877, 80.93087688088417, 71.36878877878189, 82.10177645087242, 84.90835905075073, 86.77306339144707, 83.42190161347389, 83.96528005599976, 83.86809647083282, 80.52123606204987, 65.98864987492561, 62.79004231095314, 64.91950124502182, 66.90959125757217, 65.30247509479523, 60.10086961090565, 56.24030336737633, 58.412130028009415, 57.39082083106041, 58.22310917079449, 57.13306926190853, 49.38710890710354, 53.360342904925346, 54.67902794480324, 54.64456759393215, 56.45301215350628, 51.16958566009998, 53.271948248147964, 58.041965290904045, 60.04608415067196, 57.64533877372742, 58.243791460990906, 57.16882914304733, 54.181235656142235, 54.2035024613142, 53.362922966480255, 51.849015802145004, 53.31865914165974, 52.75844380259514, 54.959741681814194, 49.668347015976906, 50.93229599297047, 49.894172698259354, 59.378627166152, 66.5673816204071, 66.79598495364189, 65.16791671514511, 64.79666143655777, 62.11537331342697, 60.35728745162487, 61.274869814515114, 51.36223152279854, 49.1335105150938, 54.40791629254818, 56.11570805311203, 61.444086134433746, 60.129105895757675, 63.89367789030075, 61.71952195465565, 51.932265534996986, 54.464415460824966, 54.445291087031364, 61.189393401145935, 62.22959518432617, 54.28175926208496, 50.221513733267784, 50.19066318869591, 56.157532408833504, 58.730245158076286, 59.404347985982895, 59.007660672068596, 54.172891303896904, 52.54736892879009, 46.701872795820236, 47.44619965553284, 50.57597391307354, 53.2389622181654, 53.10489401221275, 51.41666740179062, 45.60274377465248, 45.17796836793423, 45.763893127441406, 45.16363173723221, 47.17468522489071, 46.30509428679943, 44.42870557308197, 45.57722054421902, 46.061553955078125, 49.363223388791084, 52.74628445506096, 51.80840738117695, 51.54548428952694, 48.672200068831444, 51.224219128489494, 51.70470714569092, 54.17095720767975, 57.055827006697655, 63.578670993447304, 67.23809123039246, 65.24978712201118, 66.17178484797478, 64.63722199201584, 64.23318207263947, 61.70809596776962, 62.28259094059467, 62.83201865851879, 66.51676833629608, 65.62254711985588, 67.88771957159042, 67.65837147831917, 73.934745490551, 71.10385939478874, 83.53205770254135, 70.44174492359161, 60.572253316640854, 38.744020611047745, 1.9940306385979056, 0.8033211878500879, 2.2786246798932552, 2.086819284595549, 0.26296120835468173, 0.1239055473706685, 7.801876254379749, 71.19108751416206, 59.19423446059227, 42.82876342535019, 44.59064908325672, 43.558989241719246, 30.56393925100565, 29.925805293023586, 52.0504429936409, 60.75850032269955, 39.26797829568386, 0.30101684911642224, 0.0802815800125245, 0.04490681043535005, 0.06987455446505919, 0.03215023811208084, 0.024211974232457578, 0.06678060017293319, 0.07900978380348533, 0.030342594582180027, 0.10081756321596913, 0.07786577800288796, 0.026248607427987736, 0.06351781470584683, 0.025467843952355906, 0.016063816146925092, 0.03734292295121122, 0.030379004347196314, 0.04271968638931867, 0.014656040857516928, 0.08907672017812729, 0.04330817610025406, 0.14526715502142906, 0.13953312911326066, 9.749486446380615, 77.3784551024437, 65.04009917378426, 66.2198294699192, 43.693198040127754, 43.07405926287174, 59.4604329764843, 39.44595694541931, 3.7386386236175895, 0.30877395474817604, 3.6782498890534043, 3.305416270159185, 0.745311303762719, 0.41946198558434844, 54.59271937608719, 107.95264050364494, 90.9709869325161, 99.69123780727386, 87.34371677041054, 92.85652935504913, 85.89714959263802, 82.42371037602425, 73.32867041230202, 82.16207921504974, 87.38360702991486, 91.23628109693527, 87.23476901650429, 87.11851045489311, 87.11418628692627, 82.26017475128174, 68.90414983034134, 66.83915823698044, 68.9883229136467, 70.01663133502007, 67.03436896204948, 65.10107070207596, 58.81744287908077, 61.57065734267235, 60.00390261411667, 60.188428312540054, 59.22080643475056, 52.904587760567665, 56.474610194563866, 56.72656707465649, 56.96303978562355, 57.913646176457405, 54.86728124320507, 55.71717403829098, 63.436889201402664, 63.18625085055828, 62.011418491601944, 64.88081932067871, 59.35208939015865, 58.56952138245106, 56.61122806370258, 56.74319498240948, 53.922864720225334, 56.267544105648994, 55.780911818146706, 56.67443007230759, 53.19928854703903, 54.41076993942261, 54.12372574210167, 62.50155799090862, 70.93374252319336, 67.30466365814209, 69.47251573204994, 68.86601507663727, 65.89914947748184, 65.72304412722588, 63.76494079828262, 54.773962050676346, 51.692638993263245, 56.24092273414135, 61.36842079460621, 64.67276528477669, 64.01312068104744, 64.9109061062336, 66.5833331644535, 55.81926316022873, 57.36437425017357, 58.46763364970684, 63.46241243183613, 63.610315695405006, 57.03396677970886, 52.663445100188255, 52.335632890462875, 57.22730040550232, 60.83749808371067, 61.63675479590893, 61.50416471064091, 57.7828685939312, 53.92098382115364, 50.598951280117035, 51.15326173603535, 53.98049622774124, 56.49831712245941, 56.823997646570206, 55.82686275243759, 49.43270266056061, 47.684177085757256, 48.81420984864235, 48.47561001777649, 49.60798725485802, 50.09202428162098, 48.21207515895367, 47.534153535962105, 48.94680753350258, 50.93261897563934, 53.32495920360088, 52.52412177622318, 53.79448100924492, 51.825426667928696, 54.36497859656811, 54.00688961148262, 56.940054818987846, 60.690385177731514, 68.23015719652176, 68.26994106173515, 68.0106733739376, 67.8064951300621, 68.85362014174461, 64.97962161898613, 64.81188341975212, 65.30671566724777, 66.82862520217896, 68.08260351419449, 67.90968999266624, 69.96042475104332, 70.78037515282631, 75.56363448500633, 76.40643686056137, 84.22410696744919, 73.46087291836739, 67.51821979880333, 58.46102960407734, 5.87649866938591, 0.5113619542680681, 0.8803032163996249, 3.0152294039726257, 1.5846889349631965, 0.1750711229396984, 6.940737487748265, 79.02461796998978, 67.31534108519554, 53.9725736528635, 45.34478321671486, 36.35715588927269, 32.40420140326023, 39.52165648341179, 59.51173782348633, 68.56276094913483, 49.914471209049225, 0.491873839055188, 0.09487795497989282, 0.04996355237381067, 0.02142739533155691, 0.05384531497838907, 0.04172996566921938, 0.04122890095459297, 0.08540163456927985, 0.09612647001631558, 0.0705161114456132, 0.038224779927986674, 0.19998105737613514, 0.1463849630090408, 0.10898866108618677, 0.104890796210384, 0.17219954577740282, 0.11840912004117854, 0.10710154281696305, 0.14432444935664535, 0.14409202354727313, 0.14657553168945014, 0.2556956419721246, 0.24297744239447638, 12.183723226189613, 92.86983624100685, 72.94370546936989, 74.34638500213623, 46.71088211238384, 81.3614621758461, 75.44632717967033, 49.32633116841316, 7.312997337430716, 0.42885404254775494, 6.141087021678686, 7.225134652107954, 6.122692208737135, 1.2372866389341652, 54.33063983917236, 111.01244911551476, 94.22257125377655, 102.7689890563488, 90.41421040892601, 96.06906697154045, 89.6592365205288, 88.56317013502121, 79.25550118088722, 86.81822776794434, 90.64452365040779, 93.86127144098282, 90.42519181966782, 91.27440065145493, 89.03421565890312, 86.62315383553505, 72.1895295381546, 70.44188931584358, 74.26294907927513, 74.81369152665138, 72.13397651910782, 66.85377985239029, 63.12031298875809, 65.3509072959423, 62.87149094045162, 62.54430949687958, 62.21637189388275, 57.12681479752064, 61.25688157975674, 61.30463361740112, 61.12952381372452, 63.771347254514694, 58.28352592885494, 59.3927776068449, 68.0279016494751, 67.22348481416702, 65.1426936686039, 66.9016420841217, 64.5059086382389, 62.5601052492857, 60.57630009949207, 59.096370711922646, 58.37403327226639, 61.73278324306011, 59.30564068257809, 59.41669352352619, 57.52576299011707, 57.8977782279253, 57.17507600784302, 66.41001686453819, 76.62606507539749, 72.61942327022552, 71.35827854275703, 71.15743651986122, 69.50192615389824, 69.39088091254234, 68.93619731068611, 58.450374975800514, 52.223778292536736, 57.07919955253601, 61.46602615714073, 66.7634890973568, 67.52103924751282, 68.15270975232124, 68.77864256501198, 57.59664438664913, 59.88322488963604, 63.50498914718628, 68.46516698598862, 67.62244060635567, 58.89989845454693, 56.32563918828964, 54.80784483253956, 63.15086714923382, 65.67347958683968, 66.20502546429634, 65.80638885498047, 61.87731608748436, 59.29675295948982, 55.58280564844608, 55.66477105021477, 57.4144821614027, 60.88667504489422, 62.222120985388756, 59.77509409189224, 51.09268918633461, 51.98014676570892, 51.705235317349434, 51.487005427479744, 55.11917732656002, 53.14171023666859, 52.23627582192421, 50.00516854226589, 52.98657976090908, 55.532161965966225, 58.4377596527338, 55.942509546875954, 58.938226997852325, 54.60731819272041, 58.084849789738655, 57.44980126619339, 60.06187230348587, 62.79245898127556, 72.46775820851326, 72.33835995197296, 70.55019110441208, 72.59012684226036, 71.88654139637947, 69.22047525644302, 68.6707891523838, 68.41521486639977, 71.1490161716938, 72.03591898083687, 72.70281359553337, 72.68418699502945, 73.81344839930534, 79.61095690727234, 79.35910642147064, 88.467977643013, 75.11481016874313, 70.35763263702393, 56.763345301151276, 5.555914621800184, 1.8452851264737546, 8.877525385469198, 9.198220577090979, 1.956828972324729, 0.2739242138341069, 11.396795902401209, 88.5108545422554, 73.56379419565201, 61.46948017179966, 60.41329264640808, 60.853058248758316, 43.39865684509277, 45.443729907274246, 68.48601266741753, 77.38670825958252, 63.870476335287094, 1.064290115609765, 0.17711940599838272, 0.12233559333253652, 0.13991459301905707, 0.16056531225331128, 0.0723881863814313, 0.14123852510238066, 0.17362501850584522, 0.1385849018697627, 0.12983297696337104, 0.11790419986937195], [0.013710913008253556, 0.1209900870162528, 0.017739349968906026, 0.029704505286645144, 0.04904374567558989, 0.00815527064332855, 0.05952708626864478, 0.0655654224101454, 0.05673302643117495, 0.024810410577629227, 0.04594079655362293, 0.11772680431022309, 6.023398786783218, 61.06274239718914, 56.886527091264725, 45.058213993906975, 32.49751299619675, 66.62301823496819, 44.0578530728817, 32.87911131978035, 0.13411453081062064, 0.12346500108833425, 2.3726382851600647, 2.0560452109202743, 1.7913650698028505, 9.98696705326438, 94.96489182114601, 85.02153977751732, 93.20106446743011, 87.01009467244148, 92.48910427093506, 88.21124821901321, 91.55658110976219, 79.60721790790558, 73.87992203235626, 69.943857640028, 81.88255101442337, 85.31219378113747, 87.31623664498329, 84.4822347164154, 86.52479991316795, 79.53810721635818, 70.91603547334671, 62.75728426873684, 64.5967997610569, 63.44546154141426, 65.3205469250679, 58.75753529369831, 57.65307515859604, 56.352344155311584, 58.26783277094364, 57.895167768001556, 54.55999933183193, 47.11442805826664, 53.756156265735626, 55.418076887726784, 53.71508426964283, 51.682520136237144, 51.42292946577072, 52.883913069963455, 58.87729726731777, 59.347229450941086, 57.313741967082024, 58.109974041581154, 53.617725893855095, 53.49882647395134, 51.408885419368744, 50.22660166025162, 50.041194409132004, 54.254237338900566, 53.58036629855633, 54.51620668172836, 50.72836473584175, 49.34408001601696, 51.85609482228756, 54.51337583363056, 65.83556368947029, 66.87763497233391, 67.10964292287827, 64.72050592303276, 62.98550382256508, 59.954505264759064, 55.14307044446468, 47.06324480473995, 50.84696017205715, 60.45430384576321, 61.20309926569462, 60.684031918644905, 66.10377609729767, 66.32842004299164, 63.61598499119282, 56.27331219613552, 56.37296564877033, 51.659067794680595, 58.18052865564823, 60.548063814640045, 57.07452580332756, 51.158817037940025, 48.75272914767265, 49.04711455106735, 54.37590681016445, 53.90052951872349, 55.4174879193306, 51.6464638710022, 46.61659777164459, 45.40888197720051, 47.028157487511635, 48.88463146984577, 51.98873050510883, 54.48214530944824, 52.84428119659424, 48.709639459848404, 43.012540563941, 45.7677461206913, 45.359598621726036, 46.2917760014534, 44.78617899119854, 44.723113775253296, 46.13903559744358, 46.74903206527233, 47.39494800567627, 50.08188262581825, 49.12923954427242, 49.940754398703575, 50.82428298890591, 50.474363565444946, 50.24748533964157, 56.37075796723366, 59.937124997377396, 63.899187594652176, 64.5739857852459, 63.986506909132004, 62.5656795501709, 60.94853192567825, 61.58858098089695, 61.06463089585304, 62.02522315084934, 64.94544625282288, 66.65633484721184, 68.40855002403259, 69.89050090312958, 71.50816529989243, 71.62703052163124, 77.86651611328125, 77.07227513194084, 77.8268614411354, 72.94796124100685, 80.91253146529198, 36.71967923641205, 0.48815918213222176, 1.0462447651661932, 2.92536280117929, 1.4282775716856122, 0.10271297869621776, 0.8422415493987501, 46.59298583865166, 75.06121024489403, 46.89697712659836, 43.45547139644623, 32.54278376698494, 29.195370487868786, 37.219910994172096, 51.41415573656559, 59.95818346738815, 45.8321450650692, 1.4451512787491083, 0.1077366950630676, 0.03985244708019309, 0.029733564078924246, 0.027900863788090646, 0.028265907676541246, 0.06240349481231533, 0.0266422536878963, 0.05358690657885745, 0.028044903519912623, 0.049438609057688154, 0.03421741625061259, 0.04402154329000041, 0.030553331125702243, 0.030970568404882215, 0.041611069900682196, 0.015848018156248145, 0.10620542176184244, 0.10986058812704869, 0.06423249549698085, 0.010928798037639353, 0.039912980355438776, 0.13724585965974256, 8.722715992480516, 76.05326101183891, 63.77836927771568, 60.57831399142742, 28.068985529243946, 47.08272635936737, 53.91138933598995, 33.6866819858551, 0.23319326428463683, 0.864389076596126, 4.75568326190114, 1.8457743502222002, 1.0020420933142304, 12.644334509968758, 100.77575281262398, 88.87558937072754, 98.20254608988762, 90.26306971907616, 94.49965238571167, 90.55030390620232, 94.67514976859093, 82.66666933894157, 76.61470368504524, 73.22527796030045, 84.51479136943817, 88.01912292838097, 90.40005996823311, 86.72935053706169, 88.6425706744194, 83.28675046563148, 73.1341740489006, 66.11154288053513, 68.1782291829586, 66.35786846280098, 69.444100856781, 63.07777427136898, 61.68174438178539, 60.757683366537094, 60.81472970545292, 62.13229380548, 56.364427506923676, 52.05235809087753, 57.24042110145092, 58.735055699944496, 56.04858845472336, 56.983383893966675, 53.719951808452606, 56.27194046974182, 62.18934394419193, 61.78735211491585, 60.15573486685753, 59.25913877785206, 55.12602835893631, 55.96042938530445, 55.210121646523476, 54.544515162706375, 54.844148084521294, 58.02423544228077, 59.54928360879421, 58.252075016498566, 53.27102109789848, 53.4350810945034, 55.16238860785961, 57.32914634048939, 68.5272404551506, 68.34216758608818, 70.52318215370178, 69.16687533259392, 66.58627420663834, 63.27100150287151, 59.12521876394749, 48.9431407302618, 52.9901097714901, 63.29238295555115, 64.8706966638565, 64.76174131035805, 68.34085285663605, 69.21245008707047, 66.85253351926804, 58.31475265324116, 59.0375080704689, 54.65994156897068, 61.92205488681793, 61.83641508221626, 57.746713533997536, 56.285182759165764, 51.97670415043831, 52.310653030872345, 56.69460318982601, 56.91251389682293, 55.272882878780365, 53.83996456861496, 50.45982554554939, 48.40712249279022, 48.355331271886826, 52.87687584757805, 54.06958244740963, 58.42891372740269, 55.79953081905842, 51.38587385416031, 46.40161670744419, 49.56365503370762, 48.074655532836914, 48.582186698913574, 48.24795663356781, 48.59379127621651, 48.882602378726006, 49.13074046373367, 50.21253481507301, 53.175589218735695, 52.710342183709145, 53.64666134119034, 54.044203609228134, 53.332490399479866, 54.34496887028217, 58.29588666558266, 63.22173714637756, 67.10759103298187, 67.06149190664291, 65.74665606021881, 65.18450662493706, 64.68063846230507, 64.58884298801422, 63.63972991704941, 64.69570845365524, 66.28941133618355, 69.66272592544556, 70.98057121038437, 73.33246260881424, 73.87853890657425, 76.29555881023407, 79.62217390537262, 78.34585279226303, 76.76277413964272, 74.52312111854553, 81.00174307823181, 56.2537432461977, 2.4554774025455117, 1.0006691794842482, 2.654166603460908, 2.4784227088093758, 0.05293060312396847, 0.4883923946181312, 50.10007984936237, 82.36970007419586, 55.165135860443115, 50.51595613360405, 30.82810677587986, 32.88255013525486, 44.298889338970184, 60.99973797798157, 65.41113406419754, 55.64306281507015, 2.2053159261122346, 0.19299090199638158, 0.10606027251924388, 0.030440584050666075, 0.05799506339826621, 0.13706075318623334, 0.11563695356016979, 0.009996064054575982, 0.02070586080662906, 0.1305595543817617, 0.08680375933181494, 0.09549744048854336, 0.11305239459034055, 0.09397850910318084, 0.1639018300920725, 0.12758373515680432, 0.08855529464199208, 0.1950954250060022, 0.19447239203145728, 0.18053309235256165, 0.06081568841182161, 0.25106980581767857, 0.3550909459590912, 11.996711511164904, 88.90556216239929, 72.38257437944412, 65.59533298015594, 44.81056608259678, 86.57909139990807, 64.28094550967216, 47.851014733314514, 0.4643066448625177, 0.6780813925433904, 8.993041086941957, 11.31431182846427, 4.133022548630834, 11.719478387385607, 103.84657323360443, 90.33851847052574, 100.25708824396133, 93.38098481297493, 97.86127120256424, 93.25897336006165, 96.65395438671112, 84.88725498318672, 79.24532532691956, 77.31182187795639, 88.63698497414589, 91.92579969763756, 93.71817111968994, 92.70693898200989, 91.60104632377625, 86.02707982063293, 76.41636952757835, 68.69421109557152, 72.53824442625046, 70.82279607653618, 73.95355448126793, 68.9466467499733, 65.57073310017586, 65.24763643741608, 63.36084008216858, 64.28628042340279, 60.01509681344032, 54.3890655040741, 62.01739177107811, 62.42696039378643, 58.31903502345085, 60.1166957616806, 55.90866856276989, 61.05952017009258, 65.59327349066734, 68.1781379878521, 62.4457161873579, 63.516004756093025, 58.60336236655712, 61.914459094405174, 59.899788200855255, 57.53582485020161, 56.5753997862339, 61.90763846039772, 63.60048182308674, 61.382438242435455, 55.99087335169315, 55.57557463645935, 59.011167883872986, 61.012220308184624, 71.85790613293648, 71.78921341896057, 73.55320036411285, 72.26086691021919, 70.57145476341248, 67.54416480660439, 62.454558312892914, 52.10377313196659, 53.39772529900074, 65.85914522409439, 66.81284084916115, 67.42289811372757, 71.47464349865913, 72.43063420057297, 69.39433872699738, 60.33496364951134, 62.370461225509644, 58.68315048515797, 65.8532403409481, 65.96451357007027, 63.48112262785435, 59.51724752783775, 56.44766204059124, 56.59946769475937, 61.193295791745186, 61.47802211344242, 60.16470618546009, 57.70755283534527, 54.382571652531624, 51.00774474442005, 52.81524695456028, 57.01869919896126, 59.22386147081852, 62.571105659008026, 59.663182497024536, 56.11681379377842, 49.00623254477978, 54.40651796758175, 51.1973811686039, 52.36716739833355, 51.583930626511574, 51.37786768376827, 53.01478564739227, 51.86648726463318, 53.47626708447933, 55.97235694527626, 54.30773466825485, 56.13679692149162, 57.66116492450237, 58.58815938234329, 56.31765201687813, 62.62116797268391, 66.94784000515938, 70.16564413905144, 69.91190895438194, 69.39013615250587, 70.43459370732307, 68.82538765668869, 68.10088813304901, 66.2530092895031, 69.43804398179054, 70.39069086313248, 72.39709720015526, 74.22151610255241, 75.75394347310066, 77.0455701649189, 79.16442006826401, 83.8082192838192, 83.17795470356941, 80.16749024391174, 79.57115784287453, 82.88812145590782, 58.32350738346577, 2.536821300163865, 4.804798951372504, 12.399688437581062, 3.9934370387345552, 0.28471314115449786, 1.4703559200279415, 60.61681732535362, 90.09787738323212, 63.0634718388319, 62.32426330447197, 43.66330124437809, 39.92031209170818, 50.80448605120182, 70.22163793444633, 73.7386304140091, 68.17753002047539, 3.3443724922835827, 0.33292483538389206, 0.13708059821510687, 0.22909788560355082, 0.12994587246794254, 0.2512785868020728, 0.28190820885356516, 0.17192395665915683, 0.1693902793340385, 0.2197659871308133, 0.12480133445933461], [0.13340926787350327, 0.019146495360473637, 0.036016549202031456, 0.0689927494386211, 0.037146279792068526, 0.10126406894414686, 0.06274930594372563, 0.06230866318219341, 0.10675655546947382, 0.06239587295567617, 0.12273955173441209, 0.04290532349841669, 8.142777811735868, 59.43554811179638, 51.39296807348728, 30.98006822168827, 49.94007043540478, 64.36412304639816, 54.58727426826954, 20.885706581175327, 0.6514949316624552, 0.9997237427160144, 4.746943730860949, 0.544657667633146, 0.9074265172239393, 52.03256115317345, 92.1794892847538, 88.45777899026871, 94.53562885522842, 92.34493240714073, 91.46565958857536, 101.22184127569199, 91.79032936692238, 84.23214733600616, 78.06089088320732, 70.15552148222923, 70.62098890542984, 79.5579345524311, 85.68879917263985, 79.8614090681076, 82.41392210125923, 81.45713344216347, 72.09441304206848, 68.5784313082695, 63.35402324795723, 65.84374845027924, 60.01556418836117, 57.56414093077183, 56.723728626966476, 56.97439357638359, 56.81064136326313, 59.80502128601074, 51.35051675140858, 51.846941113471985, 53.937554731965065, 54.847784489393234, 52.605125829577446, 55.09889781475067, 52.45292879641056, 51.94684535264969, 57.45576694607735, 58.40196557343006, 59.436007887125015, 57.26931095123291, 52.239247262477875, 51.45772039890289, 51.867718398571014, 52.385376021265984, 52.91188716888428, 56.48211099207401, 53.20111624896526, 53.14059689640999, 52.55823254585266, 51.396144703030586, 50.42272813618183, 55.01383937895298, 64.46640595793724, 65.54183945059776, 66.06451660394669, 67.44167670607567, 61.1692088842392, 58.83557170629501, 50.16057640314102, 48.84569115936756, 57.27824427187443, 55.091096833348274, 59.75194193422794, 60.44601269066334, 59.089390486478806, 60.619777366518974, 54.98738519847393, 53.58198881149292, 47.9739723354578, 50.09808875620365, 55.61813995242119, 58.66741552948952, 59.06892478466034, 56.02256365120411, 52.95430049300194, 49.94154095649719, 49.7696153819561, 47.294450998306274, 47.91176587343216, 49.291981011629105, 47.64695808291435, 43.560436964035034, 44.56686995923519, 47.45815761387348, 49.614040330052376, 51.84982895851135, 52.24520154297352, 51.149059161543846, 46.94748781621456, 43.43416973948479, 44.94054190814495, 45.41923642158508, 45.72740748524666, 46.38139799237251, 46.280555203557014, 45.69495342671871, 46.381561383605, 48.505370020866394, 49.82460603117943, 50.3176561743021, 49.47948195040226, 50.33613458275795, 51.762331053614616, 57.61880859732628, 61.61669947206974, 63.15360300242901, 61.1203321069479, 60.49948342144489, 60.59674680233002, 59.09820981323719, 61.29682503640652, 63.18924129009247, 65.62475860118866, 69.87040758132935, 71.55998691916466, 73.5191085934639, 72.43593871593475, 73.11027333140373, 77.43037551641464, 76.35456964373589, 72.517269551754, 71.97190761566162, 73.61310794949532, 75.62239453196526, 82.34401345252991, 26.38326868414879, 0.41410928999539465, 2.697930517606437, 1.1671186541207135, 0.10233348148176447, 0.20271545596187934, 19.877476282417774, 75.76725795865059, 55.892644822597504, 46.781235337257385, 56.639270558953285, 35.69961257278919, 28.566500432789326, 49.05412517488003, 56.220981404185295, 50.78232184052467, 0.9699956816621125, 0.054978815678623505, 0.03031609063327778, 0.00558011282919324, 0.03871963286655955, 0.02884196084778523, 0.030301648439490236, 0.028554695891216397, 0.0487909961520927, 0.02162895707442658, 0.0745857301808428, 0.1367836946155876, 0.012739022386085708, 0.048515132439206354, 0.07815906734322198, 0.043926095677306876, 0.04282487469026819, 0.008217893064283999, 0.11147681507281959, 0.044122412291471846, 0.03573867797967978, 0.2013649995205924, 0.23244341311510652, 14.791647735983133, 74.15517926216125, 60.1533067971468, 40.16203232109547, 44.56743232905865, 61.460421457886696, 64.23080340027809, 19.930396042764187, 0.7157428935170174, 2.84847772680223, 5.817405665293336, 1.6340949526056647, 1.1260498641058803, 60.988570377230644, 97.73520156741142, 93.85571613907814, 97.54739284515381, 93.81176009774208, 94.06668841838837, 104.88840132951736, 93.68960425257683, 86.29325553774834, 80.27554124593735, 71.4166510105133, 72.64021575450897, 82.04136729240417, 87.44758799672127, 84.35526072978973, 84.39152598381042, 84.13491055369377, 75.17559170722961, 72.42865070700645, 67.48309448361397, 69.23885866999626, 64.72322657704353, 59.76653695106506, 59.16892781853676, 61.146877482533455, 60.644928216934204, 61.82422533631325, 55.5332563072443, 55.28250776231289, 58.70518170297146, 56.76131621003151, 54.51983168721199, 57.40312077105045, 55.71757681667805, 55.81335447728634, 59.34461899101734, 62.03981816768646, 62.57713973522186, 60.52721433341503, 54.51303765177727, 55.1604925096035, 55.0522705167532, 54.6518974006176, 56.48982837796211, 58.39614048600197, 56.425421833992004, 55.45785315334797, 54.95912991464138, 54.39213193953037, 53.75371299684048, 58.19841429591179, 68.68652790784836, 69.22889560461044, 68.83344322443008, 69.88049983978271, 64.57267105579376, 62.48763553798199, 53.47239889204502, 53.24552446603775, 56.91217191517353, 60.11256158351898, 64.01307508349419, 64.6697710454464, 61.79453752934933, 62.0083786547184, 56.24351419508457, 55.96996307373047, 51.86912052333355, 52.88199417293072, 59.62581530213356, 63.62995684146881, 64.07098397612572, 58.12160901725292, 55.57701475918293, 52.048474699258804, 52.455341666936874, 51.69552683830261, 51.237674206495285, 52.44446285068989, 50.68186283111572, 48.20800557732582, 48.25422629714012, 52.19400689005852, 52.57829166948795, 55.245930925011635, 55.385911613702774, 54.76419277489185, 50.076851695775986, 45.67197225987911, 47.67129197716713, 48.5073459148407, 49.31296728551388, 47.021101266145706, 48.43438982963562, 48.576612398028374, 49.097366854548454, 51.604837104678154, 51.38028435409069, 51.47686757147312, 52.02431559562683, 53.0151504278183, 54.04578432440758, 60.654526501894, 63.58729273080826, 64.77435663342476, 65.32794132828712, 63.52515086531639, 61.32774777710438, 61.924938932061195, 64.0084621310234, 65.3475634753704, 68.29582527279854, 72.46464997529984, 74.81459587812424, 76.33575305342674, 76.10815286636353, 76.29397049546242, 78.37356090545654, 77.41719022393227, 73.81926968693733, 75.26238664984703, 77.94077172875404, 78.02592515945435, 82.84601971507072, 45.68840637803078, 0.061201701682875864, 0.25789159757550806, 2.3803696827962995, 0.6462542410008609, 0.22965454088989645, 19.229058176279068, 85.11629149317741, 63.25674466788769, 56.74145467579365, 44.60963286459446, 25.44818826019764, 40.25487273931503, 58.51112611591816, 62.81881436705589, 58.96929793059826, 2.222235705703497, 0.06750598273356445, 0.07393949024844915, 0.03712757024914026, 0.06287364536547102, 0.04658731850213371, 0.017701170181680936, 0.046209561623982154, 0.025195648304361384, 0.05486405367264524, 0.028686675723292865, 0.25541300245095044, 0.09982078467146493, 0.10223456803942099, 0.1986311055952683, 0.11929982341825962, 0.20331036153947935, 0.1698050062987022, 0.2670735673746094, 0.19046624918701127, 0.18268499406985939, 0.4737085575470701, 0.6928492407314479, 21.00924175232649, 87.47801676392555, 68.7749795615673, 44.303863272070885, 62.33590587973595, 86.5970416367054, 74.27959978580475, 27.90436316281557, 0.8506373770069331, 2.984707304276526, 10.104659087955952, 4.28436272777617, 2.0314830914139748, 61.31870426237583, 102.79318615794182, 99.7198198735714, 99.28441643714905, 98.01247268915176, 96.03236854076385, 102.87349104881287, 97.38872855901718, 89.69029605388641, 83.93113508820534, 75.97268253564835, 78.03275719285011, 88.48319962620735, 91.96756705641747, 88.01481395959854, 87.50467613339424, 88.16954925656319, 80.06041958928108, 76.41005426645279, 71.9310674071312, 72.52956569194794, 68.61589729785919, 63.84390816092491, 62.47397907078266, 64.23687547445297, 61.46766006946564, 64.73828136920929, 57.4755334854126, 59.235640838742256, 62.15778283774853, 61.28894425928593, 58.3939404040575, 61.22886948287487, 59.90264564752579, 57.15523347258568, 63.25780101120472, 65.72899460792542, 64.78551283478737, 63.65532048046589, 60.85091896355152, 59.06371906399727, 56.281462758779526, 58.30189034342766, 58.267209604382515, 62.81922094523907, 60.25837115943432, 58.201944306492805, 59.432200491428375, 57.18656659126282, 57.785266265273094, 63.09623368084431, 71.43968537449837, 73.54377686977386, 73.44693526625633, 72.38310635089874, 67.34520748257637, 67.85167470574379, 56.92310772836208, 54.99946475028992, 61.361539363861084, 58.03847707808018, 63.00614811480045, 66.06294348835945, 64.56450909376144, 66.29561260342598, 57.360392063856125, 56.836886554956436, 53.91893193125725, 56.764150857925415, 63.459494188427925, 68.06694075465202, 65.50704091787338, 61.244847625494, 58.98424252867699, 55.36367900669575, 55.593243688344955, 54.827204793691635, 53.43915447592735, 57.52626836299896, 55.18744446337223, 50.42474962770939, 50.923495665192604, 56.74148887395859, 55.5319681763649, 59.555743262171745, 57.73169293999672, 58.34477484226227, 53.111463859677315, 49.932744428515434, 51.05857461690903, 52.277663201093674, 53.04651014506817, 52.69659452140331, 51.40543520450592, 51.812347769737244, 52.465323731303215, 54.94176484644413, 53.8074991106987, 54.49130281805992, 54.04853917658329, 56.56524293124676, 56.52302339673042, 63.58021751046181, 68.47788870334625, 70.73951214551926, 68.8642367720604, 67.5312303006649, 64.85546708106995, 67.14626535773277, 68.51545348763466, 68.70846793055534, 70.96770510077477, 74.57750380039215, 77.73722425103188, 81.80303648114204, 79.27854314446449, 81.63636982440948, 81.8661966919899, 82.224380671978, 75.29410734772682, 78.55882376432419, 80.3885167837143, 82.90871635079384, 89.15605992078781, 44.419080689549446, 0.6130007409956306, 11.234034486114979, 5.9152983874082565, 0.8015893714036793, 0.4012728959787637, 26.289717704057693, 91.30892559885979, 70.7482972741127, 65.62983512878418, 76.36849209666252, 47.65369512140751, 39.23369653522968, 66.00902438163757, 71.6859121620655, 74.59536284208298, 4.243066068738699, 0.3395640884991735, 0.15277880273060873, 0.07957789784995839, 0.1659469961305149, 0.11282415449386463, 0.15380430239019915, 0.1523729518521577, 0.1206680023460649, 0.09881064004730433, 0.19447994709480554], [0.07113610161468387, 0.06483239572844468, 0.08080048966803588, 0.08682779749506153, 0.09787750066607259, 0.06793594599002972, 0.16860845644259825, 0.08486889128107578, 0.033729257484083064, 0.09621061471989378, 0.11370905427611433, 0.3312008857028559, 15.495745204389095, 54.67568792402744, 53.57290729880333, 35.5637014657259, 41.91244259476662, 51.78145542740822, 60.84545485675335, 6.663415543735027, 0.20558397547574714, 2.0308741740882397, 2.2189491195604205, 2.41425056476146, 5.614072401076555, 92.97669410705566, 77.7248977124691, 96.67209461331367, 85.62620893120766, 95.68509757518768, 93.84044095873833, 93.24505850672722, 83.66515696048737, 86.11652702093124, 79.36217665672302, 76.3642667233944, 61.046239882707596, 70.36134883761406, 79.16073426604271, 84.64337646961212, 75.40931716561317, 79.30796876549721, 70.33271357417107, 68.74622270464897, 64.01298388838768, 66.15117475390434, 57.91383616626263, 59.923662319779396, 56.49759516119957, 58.870020657777786, 58.69680695235729, 55.207761973142624, 48.00553344190121, 53.468192517757416, 53.69695924222469, 53.69246408343315, 53.70689570903778, 52.37431101500988, 51.68160438537598, 54.13809277117252, 55.77913351356983, 56.484573259949684, 54.04009982943535, 52.09510959684849, 49.4853450357914, 52.99655042588711, 52.78049021959305, 56.39141745865345, 56.079078018665314, 57.73824758827686, 56.89358331263065, 56.62645384669304, 54.27693732082844, 53.521803840994835, 48.8163985311985, 51.101147532463074, 60.689511224627495, 64.38046216964722, 67.09641963243484, 64.7444674372673, 58.086324110627174, 56.43324561417103, 50.502668246626854, 53.054584711790085, 52.899184450507164, 65.16681477427483, 63.64745490252972, 61.96968533098698, 62.85366989672184, 61.555389761924744, 63.328929394483566, 61.49268552660942, 49.6228064596653, 46.394176706671715, 55.7073325663805, 55.51218643784523, 60.7354773581028, 59.348874762654305, 57.65495605766773, 53.204235881567, 55.6978140771389, 51.92758038640022, 45.910922437906265, 45.84253370761871, 46.11507788300514, 45.590417236089706, 44.67701844871044, 44.51475575566292, 47.84325934946537, 52.59243831038475, 51.741698160767555, 52.720787823200226, 49.50965233147144, 46.320095881819725, 42.96383857727051, 45.3975547850132, 45.00686354935169, 46.30269281566143, 45.254458263516426, 46.7455742508173, 45.30693344771862, 48.026181533932686, 49.47605453431606, 51.06564983725548, 50.17794907093048, 51.535285636782646, 53.42071786522865, 58.80761660635471, 60.7592298835516, 59.97945472598076, 57.349775433540344, 57.48100519180298, 55.45008637011051, 58.8515118509531, 61.35577507317066, 67.44635805487633, 67.48315528035164, 73.2574850320816, 72.61745497584343, 74.56752553582191, 71.9447010755539, 75.17771199345589, 72.855474203825, 75.69254636764526, 70.06320923566818, 75.68409562110901, 72.32192203402519, 81.63951605558395, 71.72830268740654, 83.88662427663803, 11.834281627088785, 1.1820886633358896, 3.620586320757866, 0.2758349769283086, 0.2869326079962775, 3.8057793583720922, 61.767197996377945, 70.2553953230381, 41.99888415634632, 62.69332230091095, 49.76665534079075, 23.289491795003414, 52.45792552828789, 50.212097838521004, 44.3239451944828, 4.619510918855667, 0.20269000029657036, 0.06589837212231942, 0.11426990269683301, 0.08038222265895456, 0.0432315233774716, 0.09587749431375414, 0.09419532012543641, 0.10813948829309084, 0.027198823627259117, 0.05843949111294933, 0.07388498692307621, 0.05707203577912878, 0.05076751724118367, 0.21288739138981327, 0.048635560742695816, 0.07963240117533132, 0.10239876079140231, 0.07443064358085394, 0.07445650000590831, 0.14801163197262213, 0.22290490072919056, 0.40757254231721163, 24.757231436669827, 67.15241342782974, 62.68015220761299, 40.69036737084389, 43.88985648751259, 57.98831596970558, 71.6286264359951, 6.331629222258925, 0.18565431208116934, 2.52445581369102, 3.458606475032866, 0.9428295737598091, 7.875206144526601, 99.88382667303085, 83.06589871644974, 101.63098812103271, 89.25747647881508, 98.39713364839554, 94.67483058571815, 97.07663610577583, 84.8086068034172, 91.48916512727737, 83.65357518196106, 79.4438798725605, 64.29004982113838, 73.99694815278053, 80.44876635074615, 89.06383126974106, 79.46540951728821, 82.01727658510208, 73.6382246017456, 74.14530739188194, 66.66788622736931, 68.97896021604538, 61.88324376940727, 62.9942661523819, 61.52429983019829, 61.46131061017513, 60.454079657793045, 58.62241834402084, 51.647972390055656, 57.0893108099699, 56.797741055488586, 57.01619513332844, 56.56075917184353, 56.26093626022339, 54.699159264564514, 57.39099942147732, 58.297360986471176, 60.693953186273575, 56.57750487327576, 55.87916314601898, 52.94507838785648, 56.22965253889561, 55.24226412177086, 58.32333639264107, 59.12727065384388, 61.98725938796997, 63.32197196781635, 59.405788108706474, 58.31785708665848, 56.229257360100746, 51.48756019771099, 53.59132491052151, 62.52329282462597, 68.77681866288185, 67.23182156682014, 68.52541655302048, 58.848377019166946, 58.03031511604786, 54.80043902993202, 56.14926025271416, 55.69102384150028, 66.09185233712196, 68.05133119225502, 64.67134416103363, 66.60985574126244, 66.22920736670494, 66.19317770004272, 63.84396135807037, 53.22760082781315, 48.92562747001648, 59.41933058202267, 61.52834661304951, 64.13857474923134, 62.462765872478485, 61.19405575096607, 59.881112203001976, 59.136777743697166, 55.40690168738365, 47.12249122560024, 47.446112260222435, 47.56606042385101, 48.49475719034672, 47.21347354352474, 48.64680603146553, 51.055606976151466, 56.507615223526955, 55.180057659745216, 54.686923921108246, 51.82256922125816, 49.235257655382156, 46.46726578474045, 48.38767133653164, 48.702514842152596, 49.54619117081165, 47.460536286234856, 49.60899040102959, 46.45182341337204, 51.66414812207222, 51.32272124290466, 53.61820466816425, 52.26469449698925, 53.30198563635349, 55.66123344004154, 60.39098784327507, 62.64990583062172, 64.88420113921165, 59.238281697034836, 58.58328424394131, 56.435198709368706, 63.05770754814148, 63.47583711147308, 69.82395887374878, 68.85683476924896, 75.49370303750038, 72.89270460605621, 76.35873422026634, 72.74058356881142, 76.48939400911331, 73.84716778993607, 79.22273173928261, 69.5843893289566, 79.82308432459831, 73.16775664687157, 83.83616298437119, 73.09774920344353, 90.9915666282177, 20.483553260564804, 1.3632258935831487, 1.3718704297207296, 0.5648488935548812, 0.23814580868929625, 2.713423236273229, 66.49779975414276, 77.5412991642952, 52.981241047382355, 60.00704884529114, 30.8702028170228, 27.93522510677576, 61.370715871453285, 57.02855966985226, 54.93308611214161, 6.150380847975612, 0.08846374330460094, 0.03632275933341589, 0.0648961313709151, 0.11174827784998342, 0.047935619004420005, 0.013307939807418734, 0.10132407900528051, 0.024297174641105812, 0.0053687185572925955, 0.050189009416499175, 0.19720787415280938, 0.10939507599687204, 0.16798260330688208, 0.5588671832811087, 0.27632610057480633, 0.25004979805089533, 0.3884538385318592, 0.1446768656023778, 0.28481576533522457, 0.2599915786413476, 0.3832101495936513, 0.7277493586298078, 30.752376839518547, 81.29756480455399, 69.1249331831932, 46.69143095612526, 52.933587804436684, 70.74296995997429, 79.15573373436928, 8.71305026113987, 0.31526097853202373, 5.364164561033249, 7.792806141078472, 5.67369737662375, 6.976734381169081, 104.83422383666039, 88.15476804971695, 104.70614790916443, 92.81269490718842, 101.53400212526321, 95.99780559539795, 100.28883174061775, 89.07025292515755, 91.70246288180351, 87.97838911414146, 82.37821161746979, 66.49539068341255, 77.3844587802887, 84.75339576601982, 92.1186925470829, 81.96674689650536, 86.0954837501049, 76.30413115024567, 77.48725086450577, 70.6277297437191, 75.40655851364136, 63.81227865815163, 66.99600622057915, 64.25759956240654, 63.43698799610138, 63.74515525996685, 62.11993306875229, 55.11386901140213, 61.77466079592705, 61.55487298965454, 59.99115809798241, 59.8700737953186, 58.21826443076134, 59.689404889941216, 60.909500420093536, 63.1523110717535, 65.2458581328392, 60.71880765259266, 59.02368441224098, 54.44625623524189, 60.249168053269386, 59.08108413219452, 63.23800027370453, 63.07090424001217, 66.0857118666172, 65.47517582774162, 63.427526503801346, 59.4825591892004, 60.6979163736105, 54.226392433047295, 57.77354769408703, 68.34569379687309, 70.84466010332108, 71.69864907860756, 73.31381320953369, 61.182850152254105, 64.3212765455246, 57.368478029966354, 57.186239808797836, 56.50304786860943, 67.87614539265633, 70.36565020680428, 68.29002678394318, 70.83035007119179, 68.92028376460075, 67.87536263465881, 65.48548087477684, 54.53551724553108, 51.62711910903454, 61.71755366027355, 64.5674729347229, 68.29163029789925, 65.31747668981552, 66.0197702050209, 61.865760907530785, 62.7228657156229, 58.75828765332699, 50.73007844388485, 51.1669410020113, 51.01358123123646, 51.93430982530117, 50.84193304181099, 51.72454208135605, 55.177861377596855, 62.4225602298975, 58.46310429275036, 60.181748270988464, 56.026770025491714, 52.49164491891861, 49.15360763669014, 51.7440540343523, 50.90002812445164, 52.684488371014595, 49.8124884814024, 53.615590408444405, 50.963173136115074, 54.6859397739172, 52.612379640340805, 58.039563819766045, 55.80047316849232, 57.139091938734055, 58.69680695235729, 63.63979831337929, 64.67821419239044, 67.29805961251259, 64.15776371955872, 62.24495775997639, 61.69522225856781, 64.9302850663662, 67.11630776524544, 75.65214693546295, 72.61769816279411, 79.6491676568985, 77.07603693008423, 81.384017765522, 77.44513392448425, 81.95025578141212, 77.1417886018753, 82.56366446614265, 71.1501333117485, 86.3874600827694, 76.16444304585457, 90.31212508678436, 76.32604077458382, 96.11916348338127, 18.008240684866905, 4.966725837439299, 9.719004482030869, 0.9699219418689609, 0.24723906215513125, 5.4149246122688055, 75.12443885207176, 85.86838513612747, 57.070061042904854, 84.32893574237823, 70.20355090498924, 28.107352070510387, 69.38885942101479, 64.67047020792961, 71.5088340640068, 9.615989159792662, 0.4338285990525037, 0.22066397097660229, 0.16517063544597477, 0.2792690129717812, 0.17571432748809457, 0.28117538255173713, 0.24169134499970824, 0.18432776763802394, 0.14849517086986452, 0.13202998641645536], [0.077520909399027, 0.03136258936137892, 0.0586207124433713, 0.03369406855199486, 0.12460249825380743, 0.05144811490026768, 0.1024315191898495, 0.041449270574958064, 0.09058978117536753, 0.06203763456142042, 0.12364195878035389, 0.1168093242449686, 28.065955191850662, 65.29545307159424, 44.661842063069344, 31.644947044551373, 70.0418771803379, 58.10545228421688, 63.2117360830307, 1.0830910317599773, 0.06105549859057646, 2.519975616596639, 1.5726458374410868, 1.797001592349261, 35.999781265854836, 92.95526325702667, 79.41553339362144, 95.57969123125076, 88.20217430591583, 91.76984086632729, 88.46768125891685, 90.81365257501602, 86.63719788193703, 88.75578179955482, 80.21953985095024, 83.64458486437798, 65.81025704741478, 60.69190129637718, 66.85178115963936, 76.12537354230881, 78.3646085858345, 76.44331008195877, 74.63907569646835, 67.65354573726654, 63.75861033797264, 59.54157382249832, 57.106584683060646, 57.41057217121124, 56.38864740729332, 59.89846207201481, 60.05233861505985, 53.96134525537491, 49.73639376461506, 53.48568677902222, 50.33528342843056, 52.25725069642067, 52.34565295279026, 54.035011902451515, 51.77164055407047, 53.75988006591797, 51.56425528228283, 54.42462779581547, 49.04644198715687, 53.59437234699726, 51.44202724099159, 51.63971163332462, 54.57177110016346, 53.44044640660286, 55.17553210258484, 58.30547735095024, 57.38762900233269, 58.152258172631264, 57.33619876205921, 58.08363385498524, 52.064091861248016, 50.8668977022171, 52.26878307759762, 60.732000544667244, 62.97549895942211, 65.66229298710823, 55.177834779024124, 48.41535285115242, 56.22579574584961, 51.88076309859753, 56.35978415608406, 64.82713580131531, 62.17212326824665, 58.619135320186615, 60.53891010582447, 61.216216161847115, 62.08836056292057, 64.71578657627106, 56.37584209442139, 46.43612265586853, 53.29550698399544, 62.76747152209282, 60.0935398042202, 62.45345637202263, 58.181357011199, 58.52159075438976, 56.31967730820179, 60.059638023376465, 50.027731731534004, 44.90676552057266, 45.917036309838295, 44.128491282463074, 43.85630428791046, 46.5696968883276, 48.13227564096451, 49.69434902071953, 50.658102706074715, 51.79525628685951, 51.21085524559021, 47.508026137948036, 45.614716932177544, 46.7304814606905, 47.22967207431793, 46.370055601000786, 46.57656691968441, 46.06287248432636, 43.274593502283096, 45.09153060615063, 48.560999035835266, 51.5403887629509, 49.65733140707016, 50.782975405454636, 54.42159555852413, 57.8404089063406, 57.90812507271767, 58.05458441376686, 53.69185991585255, 52.718789130449295, 56.921033039689064, 60.79109117388725, 62.73404851555824, 66.29104524850845, 69.55402135848999, 70.32651990652084, 70.1877361536026, 74.2946469783783, 72.32061490416527, 74.35979068279266, 73.70454624295235, 72.97531217336655, 67.97000795602798, 73.37018698453903, 75.10290920734406, 73.52367594838142, 76.9236347079277, 79.71264705061913, 63.540597036480904, 1.1476851906627417, 1.3106327969580889, 1.3666429789736867, 0.12127535374020226, 0.029183335791458376, 35.67300260066986, 75.4960361123085, 53.32693889737129, 47.573591619729996, 44.19276483356953, 32.885658368468285, 36.434276551008224, 48.54073092341423, 33.009022548794746, 2.945677936077118, 0.06763519806554541, 0.10611525824060664, 0.03088100602326449, 0.026748406780825462, 0.06256370223127306, 0.14958281797589734, 0.04935946642945055, 0.05540815182030201, 0.0730250752530992, 0.04196768299152609, 0.048038328532129526, 0.06563747010659426, 0.05898048708331771, 0.010192168228968512, 0.025626299902796745, 0.0231966234423453, 0.15758689551148564, 0.026918391995423008, 0.08573606857680716, 0.11545851899427362, 0.12957396742422134, 0.0634099286980927, 39.57411266863346, 72.13845267891884, 52.580240964889526, 37.39747926592827, 66.75044059753418, 66.45433008670807, 68.33209052681923, 1.0035309009253979, 0.06370248331222683, 1.8197550089098513, 0.9337951429188251, 0.7624483841937035, 41.09643638134003, 97.53922328352928, 85.0035211443901, 98.81748229265213, 89.77665022015572, 93.06781321763992, 90.86292073130608, 92.61298522353172, 89.44839343428612, 90.76120018959045, 82.39182248711586, 85.39291664958, 69.41972136497498, 63.80914002656937, 67.71856024861336, 78.70630905032158, 82.04513669013977, 81.30422964692116, 76.57864362001419, 70.55913582444191, 65.33652886748314, 62.21678987145424, 59.74179647862911, 62.18687407672405, 59.83936384320259, 60.82623168826103, 61.37963019311428, 56.237882897257805, 53.06139014661312, 57.00190410017967, 53.396786749362946, 56.925706788897514, 56.47663548588753, 55.59897378087044, 55.95152646303177, 57.83235713839531, 55.52525773644447, 57.20175437629223, 52.668316438794136, 53.88377621769905, 54.414797723293304, 57.17944957315922, 57.00744420289993, 57.90350452065468, 59.225563779473305, 62.08800718188286, 60.767889618873596, 63.11359494924545, 61.04518733918667, 61.80494897067547, 54.91487368941307, 53.61097365617752, 53.59351359307766, 63.32906998693943, 66.76705330610275, 69.0125048160553, 58.55505935847759, 52.192186787724495, 61.484610959887505, 52.5935972481966, 57.75941625237465, 67.40171805024147, 66.12158954143524, 62.624682784080505, 64.12373274564743, 64.01146396994591, 65.84540516138077, 66.06477499008179, 58.85734833776951, 48.93457978963852, 55.853689312934875, 65.55486515164375, 63.87865349650383, 65.0500850379467, 61.94338694214821, 62.40313187241554, 60.26534378528595, 62.9120347648859, 54.71730709075928, 47.093928158283234, 49.74490910768509, 49.109586998820305, 45.78919216990471, 48.93152475357056, 51.020147278904915, 52.650882974267006, 53.266734927892685, 55.22487245500088, 55.29507368803024, 50.98069779574871, 48.278617188334465, 48.390669375658035, 49.47568215429783, 49.606467336416245, 48.911594823002815, 48.380326330661774, 46.96588642895222, 47.80079662799835, 50.24702936410904, 54.69171546399593, 53.040992841124535, 54.156016409397125, 57.41698622703552, 59.34131316840649, 60.37518069148064, 59.58932586014271, 56.461215913295746, 55.125055611133575, 60.074559822678566, 63.47718603909016, 65.34457683563232, 68.390554189682, 72.26988762617111, 74.61447581648827, 73.14198642969131, 74.9828052520752, 76.13675773143768, 75.97061544656754, 76.08615964651108, 74.84443947672844, 71.23620629310608, 75.16961842775345, 77.29974612593651, 75.2183698117733, 80.4815585911274, 78.53124484419823, 73.55317756533623, 1.8493708572350442, 1.3907118374481797, 1.9773945375345647, 0.22168298426549882, 0.07876351693994366, 33.23017068207264, 84.44382637739182, 59.86601181328297, 57.15189725160599, 36.11000955104828, 29.285589046776295, 45.58397278189659, 52.657904997467995, 45.646574422717094, 4.736212156713009, 0.06538620858918875, 0.1344144920585677, 0.03760017360036727, 0.04800317299668677, 0.04647711328289006, 0.07732392114121467, 0.053521315567195415, 0.0017052300495379313, 0.05467341448820662, 0.02645118034706684, 0.20385615178383887, 0.09793148448807187, 0.2858580672182143, 0.14114937832346186, 0.15233813028316945, 0.3913643636042252, 0.35513220936991274, 0.1705650842632167, 0.19686737679876387, 0.3121772065060213, 0.3170607757056132, 0.38161803502589464, 45.63633397221565, 85.72783827781677, 59.53424781560898, 42.29853607714176, 86.9619208574295, 79.4106012582779, 76.92705452442169, 1.4403068949468434, 0.20557024574372917, 7.093469817191362, 9.19660471379757, 3.6862135492265224, 39.988073855638504, 105.7396012544632, 91.08800545334816, 104.77383747696877, 94.14414346218109, 97.20980376005173, 91.68321311473846, 96.26329734921455, 91.80875837802887, 94.4018304347992, 86.96883648633957, 89.83206644654274, 72.72291451692581, 68.18484842777252, 71.63114190101624, 84.20076861977577, 86.31910935044289, 84.84294936060905, 82.47750028967857, 73.91043439507484, 70.04177078604698, 67.79676005244255, 64.77435663342476, 64.6728640794754, 63.8397815823555, 64.90689352154732, 65.4649543762207, 61.136321648955345, 56.11181706190109, 59.02180731296539, 56.838961243629456, 59.42428931593895, 57.85655803978443, 58.38678538799286, 58.981616869568825, 61.4542505890131, 59.811473339796066, 60.077877044677734, 56.426930353045464, 59.51542742550373, 57.24337354302406, 58.8556270301342, 61.51277504861355, 59.19595576822758, 61.365939527750015, 65.51264941692352, 64.32397440075874, 65.31293213367462, 65.1149931550026, 65.93534633517265, 58.08290809392929, 57.146277353167534, 57.62249439954758, 68.18874701857567, 72.45125189423561, 73.53711202740669, 62.73223601281643, 58.54559026658535, 62.766095995903015, 55.445458218455315, 59.588201120495796, 70.15417635440826, 68.34273755550385, 65.16249060630798, 67.27510884404182, 68.34345951676369, 68.5726860165596, 68.83468195796013, 60.600842982530594, 51.075517907738686, 60.53288362920284, 69.33639943599701, 66.09773442149162, 68.35348337888718, 66.77782952785492, 65.6278820335865, 65.6541234254837, 65.10957464575768, 56.78061917424202, 51.45855635404587, 53.87842230498791, 51.39591671526432, 48.670083582401276, 53.98562975227833, 55.17534211277962, 59.10007931292057, 58.02072063088417, 59.485504031181335, 58.580126613378525, 53.45584698021412, 51.938557997345924, 54.57129992544651, 53.62168528139591, 51.158782839775085, 54.48407560586929, 50.947301387786865, 50.88261365890503, 50.73034442961216, 53.093532621860504, 58.18840563297272, 56.05990044772625, 58.259887397289276, 59.57316152751446, 63.83445426821709, 63.867307305336, 63.895448595285416, 58.15504342317581, 56.20290957391262, 65.45257464051247, 67.00957909226418, 69.97462838888168, 71.53578221797943, 76.24410957098007, 80.44269427657127, 78.05739507079124, 82.16780930757523, 79.33007597923279, 78.90846580266953, 80.06915912032127, 79.3135316669941, 73.90835970640182, 78.44938203692436, 80.16825780272484, 79.24565970897675, 83.0861060321331, 83.78459975123405, 74.38775718212128, 1.590227137785405, 9.32835504412651, 4.567391965538263, 0.2277893159771338, 0.25810147693846375, 44.09831330180168, 87.42182537913322, 66.68218106031418, 65.76983481645584, 61.93667650222778, 41.99381522834301, 50.76117977499962, 63.28670226037502, 60.85085056722164, 7.818326046690345, 0.20867751416517422, 0.21670468733645976, 0.08575105253839865, 0.12925433926284313, 0.23582879395689815, 0.17134960857219994, 0.10735569128883071, 0.16419695253716782, 0.22434796235756949, 0.0965323431591969], [0.01049582537234528, 0.01599587623786647, 0.06614282072405331, 0.06730669381795451, 0.044514744949992746, 0.11668027960695326, 0.05578052070632111, 0.06368069385644048, 0.03181090592988767, 0.05969521611405071, 0.023591340250277426, 0.14564910874469206, 45.04139989614487, 59.70304995775223, 42.244882956147194, 46.38937756419182, 53.624234944581985, 62.24194452166557, 46.80876486003399, 0.03550891276972834, 0.48115675162989646, 3.4190928703173995, 1.0608252952806652, 0.8557695359922945, 76.09474718570709, 81.90920278429985, 87.42165058851242, 88.19959804415703, 83.20997938513756, 91.84763789176941, 94.41291064023972, 80.38298428058624, 87.12598085403442, 84.64614272117615, 86.04062229394913, 78.25336575508118, 72.77159750461578, 61.765560284256935, 59.74490851163864, 63.82119297981262, 67.29251950979233, 65.95035552978516, 64.40785869956017, 61.953923776745796, 59.908808916807175, 58.994266390800476, 59.544362872838974, 57.863610461354256, 57.042056545615196, 57.70797461271286, 57.20341108739376, 49.30164769291878, 53.244164139032364, 53.77369612455368, 52.21574932336807, 52.57641837000847, 55.343114510178566, 51.84642434120178, 52.98567920923233, 51.64854235947132, 53.21372017264366, 50.087107345461845, 49.74204406142235, 51.20360143482685, 51.77832819521427, 55.411852821707726, 56.64193421602249, 55.5727855861187, 57.20757186412811, 58.12413588166237, 59.21359822154045, 58.43054763972759, 58.856770768761635, 56.93516828119755, 57.96990595757961, 52.96219266951084, 50.72351239621639, 54.405982196331024, 63.08749035000801, 62.0882997661829, 57.90874443948269, 49.50949653983116, 53.2119532674551, 47.74642534554005, 59.29711773991585, 65.00743612647057, 59.523843973875046, 59.694910794496536, 60.331239849328995, 58.632829785346985, 59.62571270763874, 52.46781639754772, 49.45956341922283, 45.193505734205246, 42.29941762983799, 50.07931396365166, 64.04763042926788, 60.494889467954636, 61.14968553185463, 59.13205459713936, 58.85054290294647, 56.71687759459019, 57.2293446958065, 49.83643859624863, 43.23803186416626, 43.36650677025318, 44.34248819947243, 40.88442675769329, 46.353496089577675, 46.348256170749664, 49.50704947113991, 50.3173103928566, 51.42322205007076, 49.46762278676033, 48.891159519553185, 44.33070883154869, 46.52667559683323, 45.04633583128452, 47.03444615006447, 45.54972901940346, 44.58146497607231, 43.33871126174927, 47.42218494415283, 48.38737115263939, 50.61299152672291, 49.36937905848026, 54.75218541920185, 54.32216629385948, 54.2574405670166, 50.2595154941082, 50.07674530148506, 51.348457261919975, 56.986625120043755, 59.80518087744713, 65.94504341483116, 66.02897331118584, 74.47459772229195, 68.18199098110199, 70.24044692516327, 68.60217243432999, 72.06643894314766, 68.12132343649864, 70.92698648571968, 66.9775240123272, 69.84424218535423, 70.50726100802422, 78.41679498553276, 66.99198603630066, 78.1968779861927, 70.17711952328682, 90.66330224275589, 22.453377060592175, 1.476719866041094, 0.9584932238794863, 0.2158578226226382, 0.26734828075859696, 11.677158158272505, 70.50121933221817, 60.881191939115524, 41.88311956822872, 38.066581562161446, 35.357311740517616, 21.587874703109264, 50.613177716732025, 38.350977301597595, 0.5963464721571654, 0.1318632555194199, 0.14204758481355384, 0.05146201903698966, 0.04694810988439713, 0.00449025505076861, 0.04480081690417137, 0.004779956107086036, 0.05490906863997225, 0.04103366045455914, 0.023464930236514192, 0.02180422452511266, 0.01872413355158642, 0.047467019539908506, 0.01468938648031326, 0.02645743479661178, 0.1477257566875778, 0.05174286998226307, 0.04285319875634741, 0.10751543115475215, 0.05558132455917075, 0.03322384007333312, 0.26574726041872054, 57.326323091983795, 64.36095401644707, 55.11088617146015, 47.17048265039921, 50.99395528435707, 74.06881749629974, 48.824283108115196, 0.03911760213668458, 0.5031670408789068, 4.0715503972023726, 2.0796160586178303, 1.6407453082501888, 81.5122988820076, 88.2306119799614, 94.44544449448586, 90.53678423166275, 88.43817964196205, 92.4135947227478, 97.1422129869461, 83.14032152295113, 89.10739213228226, 85.24094760417938, 87.34447672963142, 80.12969747185707, 74.84804168343544, 65.51260381937027, 62.52139292657375, 64.59369152784348, 69.53984051942825, 68.19723576307297, 67.24110826849937, 63.154587149620056, 64.63694080710411, 61.59007050096989, 63.467135578393936, 62.13755652308464, 61.73982806503773, 61.04586370289326, 60.443052649497986, 50.99606417119503, 56.4845884591341, 56.12819418311119, 54.40175302326679, 55.646813213825226, 59.03926357626915, 54.39867898821831, 55.428598523139954, 56.173130571842194, 56.63415223360062, 53.91071677207947, 52.46760740876198, 54.67198692262173, 54.968359619379044, 57.900730669498444, 58.48936468362808, 59.92688074707985, 60.42256414890289, 61.75711713731289, 62.495455518364906, 61.023137122392654, 61.69684857130051, 59.4699514657259, 61.33028604090214, 57.452609315514565, 52.96375818550587, 54.79761578142643, 65.57251140475273, 66.49232804775238, 61.71618573367596, 53.340420573949814, 56.21725760400295, 48.973960876464844, 61.81214578449726, 68.37735369801521, 60.474378168582916, 64.25031155347824, 61.230134814977646, 59.9552196264267, 58.51838752627373, 53.39329093694687, 49.62956249713898, 45.569525957107544, 44.82424154877663, 53.33030551671982, 63.090203404426575, 63.188287541270256, 63.82162615656853, 61.60439193248749, 61.88241921365261, 60.07252313196659, 59.49081614613533, 53.23169320821762, 47.67964392900467, 45.617103204131126, 49.07350793480873, 45.33826656639576, 48.06819207966328, 48.11024822294712, 52.511210069060326, 54.337844252586365, 55.437782630324364, 52.33242966234684, 52.72709548473358, 46.321365013718605, 47.09139369428158, 48.88155363500118, 48.470434695482254, 47.54912853240967, 47.45561175048351, 47.68123224377632, 49.20263260602951, 51.103704795241356, 52.32051730155945, 51.84014707803726, 56.4726684987545, 58.30257810652256, 57.98105075955391, 53.85964371263981, 53.662206307053566, 52.95697934925556, 58.79587523639202, 61.960706412792206, 69.62433278560638, 67.72748976945877, 73.98133099079132, 69.99905347824097, 74.36210095882416, 71.06118768453598, 75.96953630447388, 70.07326349616051, 75.60353994369507, 69.68678623437881, 74.11202117800713, 74.10399600863457, 78.71227473020554, 69.62429478764534, 79.67672377824783, 74.70341384410858, 92.39878311753273, 30.6996850669384, 1.3545685331337154, 1.1033851490356028, 0.523859424283728, 0.30693105363752693, 10.138807855546474, 77.73277848958969, 66.17612421512604, 53.5023944824934, 39.92318473756313, 29.865175746381283, 30.234058052301407, 56.784266978502274, 52.3789581656456, 2.2919966373592615, 0.25448220083490014, 0.08234105465817265, 0.10669083829270676, 0.10560325797996484, 0.042640213505364954, 0.07889560438343324, 0.03058900430914946, 0.05959996888122987, 0.06451986992033198, 0.03890792315360159, 0.12454576848540455, 0.2608906163368374, 0.1560693816281855, 0.10976264689816162, 0.15080418525030836, 0.1953566906740889, 0.14324707357445732, 0.1483724344871007, 0.15844545647269115, 0.1957781266537495, 0.08867891418049112, 0.48620896646752954, 67.039954662323, 73.95619913935661, 58.04652884602547, 61.7517252266407, 70.70428043603897, 81.85751035809517, 57.351337149739265, 0.1511309083434753, 0.8085112937260419, 8.019872456789017, 8.586410656571388, 1.1102190823294222, 87.0582988858223, 92.70654380321503, 96.93725198507309, 92.73624300956726, 93.35741847753525, 93.3913354575634, 99.57665875554085, 90.26614755392075, 92.21201553940773, 90.34009158611298, 91.02348491549492, 83.30689698457718, 77.47285723686218, 69.02861595153809, 67.520682066679, 68.45524951815605, 73.48719790577888, 73.29056605696678, 71.3490678369999, 67.44499772787094, 67.90858805179596, 64.7245717048645, 67.34464511275291, 63.99935021996498, 63.835069835186005, 62.902193292975426, 65.587148219347, 55.067481100559235, 60.283708199858665, 59.79138381779194, 58.558053597807884, 58.25724273920059, 61.67129874229431, 57.32286527752876, 58.53802867233753, 58.4380978345871, 60.75305141508579, 57.16774620115757, 55.7077581435442, 58.01507793366909, 58.38211163878441, 64.02399569749832, 63.39845046401024, 63.704246655106544, 64.22485291957855, 64.77179557085037, 65.97679451107979, 63.78789156675339, 65.11991769075394, 63.833929896354675, 62.51996420323849, 59.80462230741978, 57.15944364666939, 58.55155594646931, 69.33085933327675, 70.77900722622871, 65.788833796978, 57.38288685679436, 59.24839295446873, 48.8991466909647, 63.723542019724846, 70.70367246866226, 62.96218067407608, 65.67328959703445, 63.52732814848423, 61.29858434200287, 60.04797264933586, 55.768931061029434, 50.2578017860651, 47.98149213194847, 48.95906947553158, 58.630986884236336, 67.71230578422546, 69.00501161813736, 67.85625725984573, 65.1219391822815, 65.03683894872665, 62.9782348126173, 64.17979493737221, 55.92007175087929, 50.45556217432022, 48.33480857312679, 52.00134962797165, 47.795070335268974, 51.69282518327236, 51.72024831175804, 56.75569251179695, 56.21731840074062, 57.48723305761814, 55.425247102975845, 56.98763206601143, 48.0727594345808, 51.423833817243576, 51.9392229616642, 51.551997140049934, 50.49793750047684, 50.95523156225681, 49.37099017202854, 54.302642941474915, 52.537896037101746, 56.2542562186718, 54.90541219711304, 59.823742881417274, 62.21505716443062, 61.210360676050186, 56.498089134693146, 55.8937581628561, 55.246136114001274, 63.11876267194748, 66.6558788716793, 70.449108928442, 71.69990301132202, 79.56528335809708, 72.5180371105671, 77.03563749790192, 73.12883913516998, 79.43475276231766, 75.0727616250515, 77.46202781796455, 73.14611300826073, 77.5950738787651, 77.00460076332092, 84.95211750268936, 72.02453479170799, 82.86630302667618, 77.384542375803, 96.43614247441292, 28.530683554708958, 2.341019231826067, 5.027187243103981, 0.8577688818331808, 0.5091196589637548, 16.50787979364395, 86.05109453201294, 76.36826410889626, 60.06719581782818, 56.481928601861, 49.87676963210106, 33.84700298309326, 66.64219960570335, 68.00892546772957, 5.729635125026107, 0.6013968167826533, 0.41044112120289356, 0.26746099814772606, 0.1807741864467971, 0.2299721207236871, 0.5188166198786348, 0.0814801559317857, 0.1861888068378903, 0.14475246076472104, 0.12053705038852058], [0.05606553138932213, 0.05682263334165327, 0.019388025466469117, 0.15583109285216779, 0.07557794451713562, 0.13134444976458326, 0.03374114297912456, 0.07938105802168138, 0.11951595166465268, 0.1320011614006944, 0.1803887594724074, 1.605631629936397, 54.782287403941154, 57.72472031414509, 25.589871257543564, 48.87135498225689, 48.99997428059578, 77.02712595462799, 31.20367482304573, 0.2385426647379063, 0.43841376551426947, 0.8442901144735515, 3.4379099356010556, 9.760944731533527, 98.43675792217255, 73.29951077699661, 101.71533599495888, 86.68139711022377, 99.97336506843567, 88.34105685353279, 82.96709641814232, 85.62136799097061, 88.90772804617882, 80.76241672039032, 84.9688670039177, 77.76354923844337, 70.27250960469246, 62.58889630436897, 63.16706568002701, 58.601591661572456, 62.788837775588036, 58.43584455549717, 59.84406419098377, 57.422777116298676, 59.17857550084591, 58.217903450131416, 59.70968820154667, 58.11896815896034, 60.01502841711044, 59.0047462284565, 54.59637098014355, 48.28814707696438, 53.43794994056225, 53.46377715468407, 52.064228653907776, 53.20205479860306, 55.41344873607159, 54.09087270498276, 52.698954194784164, 51.48417457938194, 50.88612087070942, 51.31305456161499, 53.141315057873726, 49.16137062013149, 54.22527529299259, 55.756076350808144, 59.36796873807907, 58.20355162024498, 58.83726641535759, 57.3307840526104, 56.8004959076643, 56.892599165439606, 61.45694464445114, 57.87524163722992, 70.96080467104912, 56.423776522278786, 54.0470876544714, 50.79936392605305, 60.75455233454704, 63.196673691272736, 58.110601007938385, 48.154010474681854, 49.31061901152134, 50.04943996667862, 56.5277199447155, 54.047703221440315, 57.563597559928894, 62.51231141388416, 63.98179516196251, 62.041965052485466, 58.94432567059994, 54.58616092801094, 46.724587976932526, 42.960817739367485, 45.89884668588638, 45.26079252362251, 51.89824216067791, 61.41235403716564, 59.27768558263779, 59.28637191653252, 57.90419228374958, 59.240022003650665, 56.49227924644947, 53.450021892786026, 45.71325324475765, 44.85735297203064, 44.140605032444, 41.999796107411385, 43.64551059901714, 43.53791557252407, 47.728072330355644, 47.83670090138912, 49.83466029167175, 49.62183751165867, 47.62102447450161, 45.440891459584236, 44.188425466418266, 46.62395037710667, 46.696697473526, 45.752402544021606, 44.78924922645092, 44.23042841255665, 42.4223942309618, 48.45033377408981, 50.000506192445755, 48.62403005361557, 50.57040721178055, 52.324347496032715, 51.85885347425938, 51.193315386772156, 50.98673567175865, 51.32140651345253, 53.43247443437576, 58.984694704413414, 60.78123450279236, 63.616866543889046, 65.17475634813309, 67.93358311057091, 70.39451345801353, 70.94203367829323, 71.52474761009216, 69.97329086065292, 74.20000925660133, 70.14664515852928, 70.1921971142292, 70.07653132081032, 78.7281958758831, 69.1038291156292, 68.48095133900642, 73.58395591378212, 80.159822255373, 69.38896581530571, 1.0785843548364937, 0.615390456514433, 0.7685637404210865, 0.2719884552061558, 1.0976044717244804, 52.51156724989414, 65.15141040086746, 48.11227731406689, 37.26473718881607, 37.29113057255745, 32.052758261561394, 40.33725991845131, 43.424795642495155, 3.1453624460846186, 0.09632150642573833, 0.08726357176783495, 0.010629926819092361, 0.09462756919674575, 0.026048696963698603, 0.11617348922300152, 0.0498919277015375, 0.07611100692884065, 0.044314435581327416, 0.03567860483599361, 0.0342924399592448, 0.02612535154185025, 0.027408825444581453, 0.05974187493848149, 0.06921935681020841, 0.15807536226930097, 0.050763992039719597, 0.0979888450819999, 0.093732279347023, 0.16027664649300277, 0.1764632435515523, 3.404858596622944, 67.03641325235367, 63.91366481781006, 36.90187945961952, 43.295249193906784, 45.17112113535404, 89.44853022694588, 30.220234394073486, 0.19826012081466615, 0.7801354257389903, 4.177887216210365, 3.3645296981558204, 11.482419557869434, 105.50889283418655, 78.21881040930748, 105.28166502714157, 87.29919075965881, 102.13566944003105, 90.23373529314995, 87.87828728556633, 86.05344280600548, 91.85144528746605, 83.95466342568398, 87.67971754074097, 77.57270067930222, 74.52819004654884, 65.10215744376183, 64.87015709280968, 60.932796970009804, 63.95973354578018, 59.67486687004566, 61.1785563826561, 59.53052781522274, 63.081251084804535, 59.65977028012276, 60.997146517038345, 59.758811965584755, 61.415796652436256, 60.07768325507641, 58.034479692578316, 51.245760172605515, 56.65255844593048, 55.013964772224426, 56.835788413882256, 54.37100127339363, 60.443884804844856, 54.993168488144875, 57.11687073111534, 53.028670102357864, 54.20476399362087, 52.18836039304733, 54.156514182686806, 51.895673498511314, 56.90254703164101, 57.81146965920925, 63.0781314522028, 60.324472412467, 64.65715572237968, 59.04191203415394, 60.398177057504654, 59.91487719118595, 64.13722962141037, 61.39533095061779, 70.64343810081482, 61.717135682702065, 55.609852597117424, 55.48917107284069, 63.327033296227455, 66.53486296534538, 62.9463355243206, 50.723136216402054, 51.47476628422737, 49.1937068849802, 56.5862900018692, 53.02259422838688, 57.78299778699875, 65.66705793142319, 65.72103023529053, 64.96507599949837, 60.88167831301689, 55.569798946380615, 47.37068250775337, 44.542604461312294, 47.37418591976166, 47.48807720839977, 54.40083347260952, 63.47824238240719, 61.22819311916828, 62.95394651591778, 60.35687707364559, 61.49217255413532, 60.27851767838001, 55.61938248574734, 48.87593373656273, 47.387029230594635, 47.426243126392365, 46.775216460227966, 47.299991101026535, 45.328170508146286, 50.90534023940563, 51.097674518823624, 51.70399658381939, 52.20577485859394, 50.91852933168411, 48.75188559293747, 47.774935215711594, 48.48176948726177, 48.57605382800102, 49.25468601286411, 46.69785641133785, 46.570130065083504, 45.671409890055656, 51.49555876851082, 51.92485973238945, 53.781588301062584, 51.48766279220581, 55.20023837685585, 52.022715881466866, 54.28826071321964, 52.80779555439949, 54.545981884002686, 55.74539512395859, 61.06469929218292, 61.454983949661255, 66.21281504631042, 68.51469352841377, 71.88414752483368, 73.41101199388504, 73.26504662632942, 73.27541247010231, 73.6921589076519, 74.94597762823105, 73.602035343647, 71.6332545876503, 74.34431031346321, 79.15442660450935, 74.14001807570457, 71.80798441171646, 77.5358958542347, 79.93310362100601, 76.39379113912582, 2.476581232622266, 1.4459171751514077, 1.5367794432677329, 0.2868477063020691, 0.8234507264569402, 56.449003368616104, 73.2976108789444, 56.43872112035751, 44.274802431464195, 32.424716502428055, 37.65239238739014, 46.857683435082436, 59.16655674576759, 5.74503474868834, 0.21301729691913351, 0.09427311204490252, 0.04247717108228244, 0.0920437449531164, 0.03884405021381099, 0.06803247713833116, 0.053843841815250926, 0.18084236013237387, 0.06956082637771033, 0.007640187222932582, 0.23121665784856305, 0.14305932505521923, 0.16547159117180854, 0.26662943651899695, 0.1317028477205895, 0.26063695026095957, 0.16940878849709406, 0.27558567468076944, 0.29482493293471634, 0.45284559892024845, 0.5011976778041571, 3.704663459211588, 76.73106104135513, 74.35837715864182, 38.574051931500435, 65.10995462536812, 69.65122774243355, 94.40962001681328, 37.012134343385696, 0.3840306680649519, 0.9817377640865743, 8.146497812122107, 6.938098529353738, 11.312182992696762, 108.70227947831154, 82.56845980882645, 107.64137640595436, 91.10014960169792, 104.46560561656952, 91.96464121341705, 94.15811911225319, 88.66018652915955, 96.87666043639183, 84.670370221138, 91.21610417962074, 82.63125523924828, 78.0319744348526, 70.3816245496273, 69.478230625391, 65.93147054314613, 69.33539628982544, 64.1895680129528, 67.67791002988815, 62.5926923006773, 65.83433255553246, 61.726293191313744, 64.98494893312454, 64.20517757534981, 64.79138731956482, 63.05252082645893, 61.494026854634285, 54.529874548316, 60.85505314171314, 58.94305653870106, 60.91687582433224, 56.62033997476101, 62.57176302373409, 59.31747704744339, 58.90260010957718, 58.368705958127975, 56.2997891753912, 58.477592915296555, 57.679191157221794, 53.784951120615005, 59.6073292940855, 62.088459357619286, 66.13503322005272, 63.25537674129009, 66.49906888604164, 63.81813794374466, 62.13714614510536, 63.43204066157341, 68.77435639500618, 65.30278667807579, 72.95784071087837, 63.88183772563934, 60.041072219610214, 57.01038524508476, 67.31284841895103, 70.85956290364265, 66.19188576936722, 55.20987465977669, 52.59683847427368, 52.14601546525955, 61.07341222465038, 57.243358343839645, 58.878251016139984, 67.03294783830643, 71.54340460896492, 68.8952887058258, 64.00781616568565, 59.94299568235874, 50.34160628914833, 45.484478920698166, 51.77169755101204, 51.66379474103451, 57.730093225836754, 63.804603070020676, 64.58384245634079, 65.43546795845032, 63.465334475040436, 66.83747872710228, 66.20089888572693, 59.971399158239365, 52.129623144865036, 51.895529106259346, 51.35312721133232, 50.2845561504364, 49.82075683772564, 49.33222085237503, 54.84521582722664, 55.15523739159107, 54.650624468922615, 56.43967106938362, 54.8625048995018, 52.13823728263378, 50.82717463374138, 53.000407218933105, 53.35033044219017, 51.00440092384815, 48.679704666137695, 51.233498230576515, 48.80032919347286, 54.07377742230892, 56.448790580034256, 55.3750441968441, 55.61714440584183, 59.1714508831501, 55.94854362308979, 55.83222046494484, 55.0906066596508, 56.84302322566509, 59.3999820202589, 64.96736347675323, 66.24379098415375, 69.06254053115845, 72.2338655591011, 74.31084170937538, 76.763184517622, 76.37571170926094, 76.0006034374237, 76.37253507971764, 78.95204186439514, 75.3513702750206, 73.82614731788635, 75.44422969222069, 83.64412888884544, 75.52480816841125, 75.27516916394234, 79.70568582415581, 85.50017729401588, 78.03078889846802, 1.944230510853231, 3.3862089598551393, 3.928508497774601, 0.26704554387833923, 2.065120073966682, 66.29336312413216, 79.17015016078949, 65.0959637761116, 55.733824744820595, 52.09753766655922, 46.15982048213482, 55.243582651019096, 72.25802466273308, 8.771864455193281, 0.33273653767537326, 0.3167374071199447, 0.15580931823933497, 0.3256826614961028, 0.12281790026463568, 0.22272923437412828, 0.19580710009904578, 0.25416690681595355, 0.1284979423508048, 0.11582646839087829], [0.06406372369383462, 0.10799266921821982, 0.055004694368108176, 0.04583243928209413, 0.01933490810188232, 0.10249158120132051, 0.05635723253362812, 0.09578721947036684, 0.11970412320806645, 0.297198083717376, 0.37181467982009053, 5.293018603697419, 61.803866028785706, 50.52395090460777, 27.921378649771214, 51.473508551716805, 41.44299678504467, 80.12315422296524, 13.037257175892591, 0.10949352188617922, 1.1555291572585702, 17.174966298043728, 4.1151217091828585, 26.594421453773975, 100.08814930915833, 78.57925906777382, 103.72447058558464, 81.98031216859818, 96.93320140242577, 78.89517411589622, 90.19016683101654, 81.53350174427032, 87.45311290025711, 79.66497480869293, 82.13181003928185, 68.0251581966877, 67.19108775258064, 62.00853444635868, 60.53682401776314, 57.58995674550533, 61.88300438225269, 56.760043278336525, 59.94093619287014, 55.524847358465195, 61.10304683446884, 56.78808577358723, 58.7456077337265, 57.07375064492226, 58.484436348080635, 57.76150994002819, 50.24861007928848, 49.8527929186821, 53.45045506954193, 52.09035225212574, 55.42738638818264, 53.40344399213791, 58.69062468409538, 54.96841661632061, 56.41792483627796, 50.388594567775726, 52.30258226394653, 49.750840589404106, 50.24907745420933, 49.587164372205734, 55.27525395154953, 60.05379393696785, 61.49972654879093, 62.35617399215698, 58.3429129421711, 57.936600744724274, 58.785125613212585, 60.63083857297897, 63.23578119277954, 64.3947722017765, 66.61835208535194, 60.067279413342476, 54.98462274670601, 52.110886350274086, 61.610350012779236, 60.520443096756935, 52.958586663007736, 42.36938327550888, 50.17163001000881, 45.808251947164536, 46.10810525715351, 49.94011603295803, 61.21129922568798, 55.42015537619591, 56.7277792096138, 55.12488082051277, 61.327333599328995, 56.585959419608116, 50.26988133788109, 49.20517086982727, 43.062158301472664, 48.00695836544037, 47.735850512981415, 54.95781518518925, 61.43212057650089, 57.73244149982929, 59.208198711276054, 54.89685885608196, 54.597723707556725, 52.67369695007801, 50.650043338537216, 43.95782344043255, 45.481921657919884, 43.95058862864971, 42.524031177163124, 42.92905904352665, 43.8962971419096, 43.99996317923069, 46.81401997804642, 45.92524006962776, 45.65230451524258, 45.01996524631977, 44.25759695470333, 43.88050898909569, 45.61602786183357, 44.54861953854561, 44.60684761404991, 44.99226853251457, 44.25389975309372, 46.0244907438755, 51.233859211206436, 50.15468671917915, 49.78804439306259, 50.6610057502985, 51.870161667466164, 52.155020982027054, 50.61046086251736, 53.77214580774307, 50.639202520251274, 54.31550905108452, 55.218181014060974, 55.55789798498154, 56.01808749139309, 63.73685270547867, 66.36453330516815, 67.61114001274109, 69.7185905277729, 71.18002250790596, 71.86322584748268, 75.7088702917099, 67.55123242735863, 76.72784641385078, 71.8015855550766, 68.8047243654728, 62.165986597537994, 77.44828775525093, 70.73642671108246, 89.21636268496513, 21.70704010874033, 0.5408858356531709, 1.4853628585115075, 0.10223214121651836, 0.08131395195960067, 28.254472576081753, 75.08585572242737, 49.98191379010677, 44.04711104929447, 34.78703834116459, 28.50266195833683, 34.02107164263725, 55.728303641080856, 4.587163729593158, 0.2015508629847318, 0.08613308789790608, 0.042026824739878066, 0.056322051023016684, 0.05294194685120601, 0.04721367258753162, 0.01270968157768948, 0.09952919484931044, 0.07599519478389993, 0.07971255312440917, 0.11536552789038979, 0.008313109683513176, 0.02594269044493558, 0.10814565554028377, 0.059342068852856755, 0.0964308470429387, 0.08961655097664334, 0.1879366091452539, 0.1583247832604684, 0.3809921076754108, 0.5873733724001795, 9.398706369102001, 71.81365370750427, 58.882453590631485, 34.60511930286884, 40.14472045004368, 47.136360481381416, 89.48676377534866, 12.600390817970037, 0.10221033691777848, 2.149472697637975, 26.23270746320486, 7.666964968666434, 30.91974835842848, 105.55398881435394, 81.35178789496422, 107.46427550911903, 82.29149267077446, 98.37750390172005, 81.49235755205154, 94.338548630476, 82.71345242857933, 89.67298418283463, 80.35144597291946, 85.02617552876472, 70.58738350868225, 70.84523007273674, 62.74561129510403, 65.68247750401497, 60.35402722656727, 64.15968641638756, 58.36523674428463, 64.00333240628242, 59.05159771442413, 62.08045318722725, 58.08132737874985, 62.83797673881054, 58.22015292942524, 61.00776694715023, 60.04387266933918, 52.82368630170822, 52.01943665742874, 56.86958760023117, 54.444854110479355, 58.12040828168392, 55.70091471076012, 61.75588980317116, 57.268782779574394, 58.04124712944031, 53.74034531414509, 54.44346338510513, 52.24755361676216, 53.47917012870312, 51.42495855689049, 58.0932055413723, 63.60536836087704, 64.29433599114418, 64.75845068693161, 62.61354558169842, 62.75696128606796, 61.66481249034405, 63.49864348769188, 67.09442093968391, 67.36177459359169, 72.24833518266678, 62.50622034072876, 58.96953731775284, 55.22484205663204, 62.787371054291725, 66.21745839715004, 52.52674363553524, 44.9267752468586, 49.974644780159, 46.475564539432526, 46.82731546461582, 52.67785772681236, 62.80047655105591, 56.91536754369736, 58.27719546854496, 55.53683951497078, 59.61087450385094, 59.440149664878845, 56.491143107414246, 48.25385391712189, 45.678466111421585, 49.6811181306839, 51.859590634703636, 54.61232252418995, 64.21600699424744, 61.39299027621746, 62.60776989161968, 57.52923980355263, 58.71594652533531, 55.58323122560978, 51.256806179881096, 45.32745614647865, 48.35378855466843, 47.62100927531719, 45.89732676744461, 45.230489149689674, 46.81794136762619, 47.19927370548248, 48.69422748684883, 49.40041959285736, 49.666743502020836, 48.227749317884445, 48.60784292221069, 47.012053951621056, 48.109917640686035, 48.98255601525307, 48.068404868245125, 47.04393044114113, 48.100296556949615, 50.17019368708134, 54.093604758381844, 51.5345598757267, 51.78852304816246, 54.79085594415665, 53.74638319015503, 54.179768934845924, 52.777796164155006, 55.97286991775036, 53.17888364195824, 56.49446412920952, 58.25967080891132, 58.65032784640789, 59.327557906508446, 63.4096522629261, 67.18459010124207, 69.6291509270668, 70.12793496251106, 72.77801156044006, 72.99613505601883, 74.86539155244827, 69.74895089864731, 79.272630661726, 72.68917232751846, 71.2502883374691, 63.60970392823219, 81.62272095680237, 72.66108423471451, 91.36610493063927, 30.018586814403534, 0.5197440076153725, 0.34957242489326745, 0.0361115069972584, 0.05722224275814369, 27.24189531058073, 84.17981654405594, 56.357207894325256, 53.82951132953167, 27.97144666314125, 33.211422488093376, 44.37593400478363, 66.57045185565948, 8.299243915826082, 0.360815012245439, 0.11186982679646462, 0.07446775096468627, 0.10555245797149837, 0.021337675243557896, 0.047327336214948446, 0.008574558105465258, 0.04382939754577819, 0.028730746307701338, 0.06275697232922539, 0.19196391804143786, 0.20247782027581707, 0.1258880613022484, 0.2818066533654928, 0.20782649342436343, 0.23287436342798173, 0.2040481157018803, 0.35289050778374076, 0.41649562132079154, 0.8188219217117876, 0.9825125662609935, 10.690848883241415, 85.21881759166718, 66.4942279458046, 38.09617817401886, 67.57725343108177, 59.222664535045624, 97.92927235364914, 16.5291016548872, 0.26660536124836653, 2.989775282330811, 31.939782723784447, 9.552150685340166, 33.54980193078518, 114.24546003341675, 84.77943196892738, 110.69886714220047, 83.92532140016556, 104.07602772116661, 86.10983178019524, 98.71207594871521, 87.1182444691658, 94.00002479553223, 83.26314613223076, 89.69968155026436, 72.68396660685539, 75.491141974926, 66.69003903865814, 68.3052259683609, 64.71913799643517, 68.04011419415474, 61.7128799110651, 66.91950872540474, 61.66443631052971, 66.68775156140327, 63.000798001885414, 66.17512866854668, 63.075008019804955, 65.61822295188904, 61.8470811098814, 57.74168260395527, 55.31197898089886, 59.476293325424194, 57.18651719391346, 61.72547243535519, 57.813890129327774, 65.49783021211624, 59.28140938282013, 61.61999389529228, 55.81362426280975, 59.08713720738888, 56.25347726047039, 56.46194167435169, 54.674848169088364, 61.99709326028824, 64.42061841487885, 68.95115330815315, 67.06133991479874, 66.15728482604027, 65.93731462955475, 65.99627986550331, 67.65142545104027, 71.01658567786217, 68.52180674672127, 73.57163697481155, 67.73953512310982, 62.69925378262997, 57.87696294486523, 67.03567609190941, 71.64197131991386, 56.96412652730942, 50.22682584822178, 50.30826687812805, 48.09651955962181, 47.95762941241264, 51.88490107655525, 65.41645377874374, 58.970187082886696, 60.336513966321945, 59.232885986566544, 60.2858816832304, 62.21763342618942, 57.00366720557213, 49.505160972476006, 47.67638370394707, 54.79908250272274, 55.80941028892994, 60.399370193481445, 68.02757486701012, 64.98625606298447, 65.55690944194794, 61.49200156331062, 61.49898558855057, 58.95153388381004, 54.94008153676987, 48.88996638357639, 51.25908225774765, 49.46111373603344, 49.21362541615963, 49.74634923040867, 52.1225593239069, 49.20556224882603, 54.061234295368195, 53.78253445029259, 54.0753049403429, 52.35539563000202, 50.10226473212242, 48.7652912735939, 51.015766113996506, 52.60763369500637, 49.91396203637123, 51.37616157531738, 51.208510771393776, 53.52736674249172, 57.33779467642307, 53.968709260225296, 54.47275221347809, 57.26318567991257, 58.12002830207348, 57.73616909980774, 55.843999832868576, 59.43896792829037, 55.448494255542755, 59.24966588616371, 60.55312134325504, 62.433480843901634, 60.98226651549339, 68.47499325871468, 72.2222837805748, 72.475426197052, 75.88445886969566, 74.96723368763924, 76.18608668446541, 77.74477824568748, 73.00864398479462, 83.35933417081833, 76.25863239169121, 74.20237272977829, 66.10207378864288, 85.57255581021309, 75.46769723296165, 96.6611436009407, 29.3661143258214, 0.7387444842606783, 6.072085574269295, 0.2071017713751644, 0.26282777020242065, 36.693684831261635, 88.57200846076012, 62.4703274667263, 62.91453503072262, 49.1907012462616, 40.97865790128708, 47.93256975710392, 79.73103046417236, 9.60685919970274, 0.48166773514822125, 0.33331989543512464, 0.18217745411675423, 0.14957403094740584, 0.2643703093053773, 0.12175795010989532, 0.08318391919601709, 0.15730787767097354, 0.18043992313323542, 0.19995272217784077], [0.030509277239616495, 0.05184107467357535, 0.03579530384740792, 0.056252393042086624, 0.03607398029998876, 0.03185334564477671, 0.11193103171535768, 0.11344703903887421, 0.09438914683414623, 0.17279663326917216, 0.4473421286093071, 14.663374219089746, 66.84576228260994, 43.9557221531868, 38.75887781381607, 49.8250126093626, 50.97632423043251, 83.18871572613716, 5.029811002314091, 0.28440446709282696, 1.8022615788504481, 1.4145519956946373, 2.8250952064990997, 40.30992418527603, 84.31806072592735, 91.35786697268486, 93.89669314026833, 86.54024988412857, 87.58188039064407, 86.90035656094551, 89.16321113705635, 83.22385624051094, 85.48976585268974, 78.12489464879036, 70.22614449262619, 61.00677900016308, 65.88682293891907, 58.824666291475296, 61.14979572594166, 58.50208640098572, 58.923734575510025, 56.339816227555275, 57.781861647963524, 55.90007342398167, 59.10466946661472, 56.68995223939419, 57.06242725253105, 55.19714914262295, 58.73458452522755, 55.871852338314056, 48.90098959207535, 49.91907276213169, 52.45099849998951, 53.51443983614445, 52.12715707719326, 54.04980830848217, 58.405639976263046, 53.707629069685936, 54.955360516905785, 51.004283130168915, 51.33201174438, 49.203004986047745, 50.40892347693443, 49.30250644683838, 57.58074603974819, 64.26114857196808, 61.509058848023415, 64.06979084014893, 60.73717586696148, 58.215938955545425, 59.320619478821754, 63.19239892065525, 63.71082790195942, 64.0339207649231, 59.70696374773979, 61.91600561141968, 54.88684259355068, 55.75012966990471, 58.80103535950184, 62.15173356235027, 45.30665226280689, 43.42463605105877, 50.43235681951046, 48.657795041799545, 60.107135474681854, 63.77350553870201, 61.82796433568001, 58.513926565647125, 56.718367114663124, 60.78922547399998, 63.39897483587265, 61.757276728749275, 66.66722506284714, 49.660766422748566, 43.587278723716736, 40.30410669744015, 50.46964421868324, 50.92687368392944, 54.37763951718807, 55.14741361141205, 54.58471320569515, 54.21916522085667, 53.42242017388344, 52.73600600659847, 49.044165909290314, 44.2239535599947, 44.544663950800896, 44.19803515076637, 42.77782715857029, 42.157932221889496, 43.68731215596199, 45.71669206023216, 45.719807893037796, 44.59138244390488, 44.13268245756626, 47.62980580329895, 44.774547815322876, 45.940986424684525, 44.672014117240906, 46.59531891345978, 46.42729572951794, 45.800910741090775, 41.71585634350777, 45.701549872756004, 49.81595389544964, 50.83212576806545, 47.68351972103119, 51.631386280059814, 51.3592828810215, 50.95852978527546, 51.851348876953125, 50.84178104996681, 52.740835547447205, 52.45218403637409, 53.12557250261307, 54.7281327098608, 55.147839188575745, 56.34812258183956, 58.82872447371483, 66.19994893670082, 67.82370820641518, 69.59128215909004, 74.33665752410889, 72.8262309730053, 72.4719987809658, 75.05103439092636, 70.96849545836449, 66.24380618333817, 61.64508394896984, 72.25394368171692, 74.26865637302399, 79.01753515005112, 65.61143651604652, 0.5178376380354166, 0.4341688589192927, 0.5975289212074131, 0.4299905674997717, 9.798054490238428, 68.85579362511635, 62.11989887058735, 45.737317353487015, 43.17622818052769, 29.525901451706886, 35.632394179701805, 61.41554206609726, 8.408735040575266, 0.2619498985586688, 0.09218862702255137, 0.04613569937646389, 0.06370153336320072, 0.010598140634101583, 0.06970903326873668, 0.01688710653979797, 0.021074819524073973, 0.02442008728394285, 0.045680736875510775, 0.017226184536411893, 0.07026511710137129, 0.041368205784237944, 0.05718154709029477, 0.05495777208125219, 0.09894428600091487, 0.1040203237789683, 0.04452427412616089, 0.06854476683656685, 0.2040782172116451, 0.73933927109465, 22.94083770364523, 75.76567724347115, 57.870366498827934, 46.212975829839706, 44.99350726604462, 63.227398842573166, 89.13696974515915, 4.466111725196242, 0.1252978015691042, 2.0081984158605337, 1.1068936670199037, 3.0565597862005234, 48.08795101940632, 89.97874617576599, 93.26530382037163, 94.9090576171875, 89.00771588087082, 88.44217702746391, 87.93809607625008, 93.06382343173027, 85.59292271733284, 87.62177065014839, 80.37698060274124, 72.5911907851696, 62.81930074095726, 65.16256660223007, 61.34591080248356, 63.75047117471695, 61.9328349083662, 62.71235167980194, 59.318715780973434, 59.64500807225704, 60.05895406007767, 61.984261348843575, 59.48287457227707, 58.85995879769325, 56.54978536069393, 60.783461183309555, 58.82645979523659, 52.33538970351219, 53.39833326637745, 53.668430373072624, 54.60934728384018, 55.48919767141342, 56.98869600892067, 62.13198222219944, 56.39185443520546, 57.43031211197376, 53.87243002653122, 52.49726861715317, 51.76783315837383, 52.971790954470634, 52.86716356873512, 62.48042732477188, 67.21594601869583, 65.50451785326004, 65.67670181393623, 62.788598388433456, 63.27642381191254, 61.556145921349525, 66.64231359958649, 63.992381393909454, 69.96514409780502, 64.63816434144974, 63.056237027049065, 59.19020667672157, 59.71788816154003, 61.79463632404804, 64.17205095291138, 49.68254305422306, 45.03869444131851, 50.00315845012665, 50.86482681334019, 63.74662958085537, 68.11941593885422, 64.35498833656311, 61.066739782691, 58.92331659793854, 62.032009586691856, 66.58760413527489, 65.8033338189125, 66.13042786717415, 50.73562614619732, 44.94989700615406, 43.84625002741814, 55.2361274510622, 55.909968093037605, 55.81615872681141, 57.21916504204273, 55.86732678115368, 56.70043207705021, 53.725575506687164, 56.483706906437874, 52.783119678497314, 48.82174864411354, 48.764109537005424, 47.756046429276466, 46.82842880487442, 46.002573519945145, 46.4667072147131, 48.696837946772575, 48.42874713242054, 47.556595131754875, 47.355806306004524, 49.13688853383064, 48.183424696326256, 47.15560644865036, 47.814202308654785, 48.962394297122955, 49.54112224280834, 47.45574854314327, 46.09076678752899, 46.981792375445366, 50.85110194981098, 52.159584537148476, 51.700390577316284, 54.04103457927704, 54.331635385751724, 53.845500871539116, 54.94799271225929, 53.6876155436039, 55.20320601761341, 53.474872559309006, 55.356824174523354, 56.7890889197588, 59.12304908037186, 59.5666828751564, 62.21879996359348, 68.62239494919777, 72.21798241138458, 72.4695061147213, 75.545175075531, 75.0309106707573, 76.53132855892181, 75.01544550061226, 74.21937301754951, 66.79043725132942, 64.57825675606728, 71.28215342760086, 78.47173243761063, 78.67898091673851, 74.16150972247124, 1.146389578934759, 0.9243459405843168, 1.512702510226518, 0.6021693034563214, 8.999248053878546, 75.65761104226112, 67.47785836458206, 54.16730560362339, 38.98458570241928, 32.07418151199818, 43.25363002717495, 68.68275091052055, 13.227269779890776, 0.3498973074601963, 0.13606948137748986, 0.026519914354139473, 0.04570675657305401, 0.035359470202820376, 0.20698819309473038, 0.07267388355103321, 0.09635698108468205, 0.01609703838767018, 0.028564605418068822, 0.18295170710189268, 0.12344140821369365, 0.10821051924722269, 0.17052428098395467, 0.1395392740960233, 0.220892567303963, 0.25023851136211306, 0.213175255630631, 0.23492355190683156, 0.40174392226617783, 0.8995770290493965, 24.468296840786934, 91.32594868540764, 59.02471035718918, 48.16135548055172, 69.72558215260506, 72.25604116916656, 98.96287009119987, 6.286311903968453, 0.29244548873975873, 4.138678070157766, 3.759923418983817, 5.0909064989537, 47.451884150505066, 92.52421438694, 97.20399007201195, 98.13724279403687, 92.71247148513794, 94.52904000878334, 89.77530509233475, 98.12757611274719, 86.41986474394798, 94.509197473526, 85.19354894757271, 76.0220418870449, 65.611162930727, 71.8848542869091, 62.83331818878651, 67.9263710975647, 66.4648175239563, 67.27633997797966, 60.689401030540466, 62.30523392558098, 64.18889164924622, 64.52173858880997, 61.09722934663296, 60.9154736995697, 57.95312985777855, 64.59377512335777, 61.051331609487534, 54.90090183913708, 56.03857979178429, 57.25319981575012, 58.30056421458721, 58.10292162001133, 58.27838100492954, 64.27896961569786, 57.523072734475136, 59.759336337447166, 57.04707607626915, 57.30439826846123, 54.73083056509495, 56.09466478228569, 54.979610815644264, 65.25620117783546, 70.14196380972862, 69.15644109249115, 67.05773010849953, 67.02549263834953, 64.80952754616737, 64.21501904726028, 70.32104060053825, 67.91358098387718, 69.10509824752808, 67.57663786411285, 65.88657215237617, 61.960535421967506, 61.985625475645065, 66.04674875736237, 68.5581935942173, 53.99257577955723, 48.70373077690601, 50.647581070661545, 52.31026545166969, 64.6405278146267, 71.60920187830925, 67.8330709040165, 64.20977532863617, 61.39866717159748, 66.31376042962074, 70.20511642098427, 68.2854138314724, 69.84089076519012, 53.302946984767914, 47.13899753987789, 46.839212626218796, 59.59551192820072, 60.02596043050289, 58.047136813402176, 59.561488553881645, 58.635797426104546, 59.707849100232124, 57.94410914182663, 59.455542638897896, 56.257125064730644, 50.23626834154129, 51.63834370672703, 50.44736601412296, 49.827227890491486, 48.61359961330891, 50.601926520466805, 52.18190833926201, 53.42327892780304, 51.38788014650345, 51.22660540044308, 54.74417544901371, 51.68447703123093, 51.1421587318182, 50.757702961564064, 52.54055969417095, 51.651050224900246, 52.19689093530178, 47.47937947511673, 51.50201842188835, 54.29644927382469, 55.95751114189625, 52.81012862920761, 56.617702916264534, 57.1123755723238, 56.07327193021774, 57.914957106113434, 56.475047171115875, 59.229295179247856, 55.973766669631004, 58.95813412964344, 61.84282913804054, 62.61304780840874, 61.304059848189354, 65.8667904138565, 73.5642957687378, 74.24167782068253, 74.75746214389801, 78.32085013389587, 79.10879105329514, 78.65121960639954, 79.99197766184807, 78.09261158108711, 71.76654383540154, 68.62873300909996, 76.53874576091766, 83.08099910616875, 84.63711440563202, 74.46588099002838, 0.7273572077974677, 4.40417124889791, 1.7546728136949241, 0.6313309574034065, 13.186374474316835, 84.06259283423424, 73.93625780940056, 62.101990431547165, 61.59856304526329, 40.4902321100235, 50.244118720293045, 81.18234738707542, 15.495564714074135, 0.5357708351220936, 0.29227621969766915, 0.08994766758405603, 0.1789555832510814, 0.07669489903491922, 0.2694832911947742, 0.09303051192546263, 0.20721998065710068, 0.1384644364588894, 0.2204554423224181], [0.07263157371198758, 0.051743148287641816, 0.02645164233399555, 0.04860669119807426, 0.06335192985716276, 0.011494961163407424, 0.10103225169586949, 0.04109497298486531, 0.04998593925847672, 0.034485821379348636, 0.04327287955675274, 29.003558680415154, 66.77844509482384, 26.297974660992622, 37.68413968384266, 43.959191367030144, 58.442847579717636, 71.80419981479645, 0.7910326472483575, 0.0672076764749363, 1.033089158590883, 1.0351967392489314, 3.315820349380374, 88.72479066252708, 87.21886307001114, 92.16869786381721, 83.14162865281105, 89.32876065373421, 89.91089701652527, 85.05500838160515, 84.87143263220787, 81.31761252880096, 76.61306977272034, 71.96003705263138, 61.904640421271324, 63.08866448700428, 59.126461297273636, 61.00102610886097, 58.348331451416016, 58.03660377860069, 55.581924095749855, 58.049021512269974, 57.70456239581108, 58.332911878824234, 58.3430003374815, 56.37041978538036, 55.752056166529655, 57.946780398488045, 56.6883335262537, 49.65962268412113, 51.258941665291786, 51.760366559028625, 50.92056602239609, 51.37286715209484, 51.91232420504093, 59.09164376556873, 59.18494775891304, 52.25863762199879, 54.635565876960754, 51.03262200951576, 51.55958913266659, 47.390304654836655, 49.555531069636345, 50.313928574323654, 56.89435087144375, 64.72947344183922, 60.218879878520966, 61.15737631917, 59.80187505483627, 60.26646472513676, 60.49751132726669, 62.926504388451576, 61.654872223734856, 63.320018872618675, 56.57269053161144, 64.192303866148, 55.64118571579456, 58.675543293356895, 58.54656681418419, 57.097297981381416, 42.40882895886898, 46.59855633974075, 52.490577176213264, 55.278122797608376, 62.39754997193813, 57.610110864043236, 59.7924629598856, 61.406251564621925, 59.889076575636864, 60.23321270942688, 59.34019982814789, 59.914983585476875, 60.09339161217213, 49.93582226336002, 43.576988875865936, 40.18806092441082, 45.66212318837643, 58.36243249475956, 55.87704285979271, 56.153709813952446, 52.97643430531025, 54.82301361858845, 49.93495211005211, 50.763543248176575, 50.44026419520378, 45.26578165590763, 44.55673210322857, 46.181657910346985, 43.965187445282936, 44.61566314101219, 41.8367962539196, 43.49053971469402, 42.96440854668617, 43.629133477807045, 43.33103187382221, 43.83786387741566, 42.2205376625061, 46.18250526487827, 45.92897906899452, 46.23888283967972, 47.677162662148476, 46.535445526242256, 45.28642974793911, 44.00243304669857, 45.256437957286835, 49.55073572695255, 50.11527143418789, 50.33524543046951, 51.34966939687729, 52.88030706346035, 52.52613186836243, 50.385695323348045, 52.88389787077904, 51.3719742000103, 54.927371218800545, 58.37045766413212, 64.07338544726372, 66.22094660997391, 69.29894864559174, 66.84285923838615, 72.17692941427231, 70.76710626482964, 74.1034184396267, 72.00587019324303, 76.009601354599, 69.67271938920021, 66.55650660395622, 59.08233046531677, 65.60487806797028, 63.48415486514568, 77.55153581500053, 70.70213735103607, 88.62861022353172, 12.656785491853952, 0.25837476539891213, 1.6958742938004434, 0.07562866288935766, 0.8795287110842764, 49.66558836400509, 70.53019657731056, 53.410112634301186, 36.259934306144714, 31.815645284950733, 29.335657060146332, 60.82939311861992, 16.601147688925266, 0.2273270025034435, 0.1725805495516397, 0.041475642792647704, 0.014699613275297452, 0.036845142240053974, 0.08292888014693744, 0.06723832717398182, 0.03249302870244719, 0.04566516290651634, 0.0485895735619124, 0.03519547411997337, 0.05822400111355819, 0.07470007287338376, 0.013479350873240037, 0.03650502709206194, 0.04050875053508207, 0.04788096724951174, 0.07226910136523657, 0.010470873439771822, 0.02504171945474809, 0.040337477694265544, 41.10489472746849, 77.21178844571114, 36.83247238397598, 32.82721370458603, 40.82361102104187, 72.08125054836273, 72.4852904677391, 0.8102257736027241, 0.02989083073771326, 1.8104945495724678, 0.3369618218857795, 6.050830464810133, 92.36699402332306, 90.10692849755287, 94.25166249275208, 86.9282166659832, 93.15482094883919, 91.90978735685349, 89.0525534749031, 85.76586663722992, 83.45856964588165, 80.80473884940147, 73.59156310558319, 65.23347079753876, 64.76709142327309, 60.18235243856907, 62.53759145736694, 61.94071188569069, 59.75305147469044, 57.96495862305164, 59.1888577491045, 60.516308918595314, 61.395102962851524, 58.684974387288094, 58.33717904984951, 59.23858568072319, 60.1569090038538, 59.40407820045948, 54.27519701421261, 52.58409395813942, 54.830943793058395, 55.021587163209915, 55.59805043041706, 55.1622062176466, 60.97554847598076, 58.59549678862095, 53.86013388633728, 56.822565123438835, 55.123022720217705, 54.479531049728394, 51.22500188648701, 52.74293303489685, 51.48892432451248, 59.39405053853989, 65.866190046072, 64.85618904232979, 63.514933213591576, 62.183454260230064, 62.726547718048096, 63.2641276717186, 67.2029735147953, 63.47354203462601, 68.17858636379242, 60.345124304294586, 67.19823136925697, 58.6871212720871, 61.707704588770866, 63.04341271519661, 59.648389890789986, 46.05768196284771, 48.292414247989655, 52.08098195493221, 58.24446402490139, 64.71172839403152, 60.771609619259834, 63.06255228817463, 63.142169415950775, 61.69045731425285, 61.73244126141071, 62.33228087425232, 60.66746860742569, 63.12174551188946, 53.019991368055344, 44.4377338886261, 42.19472944736481, 49.540430679917336, 61.03957884013653, 57.96860262751579, 58.294359147548676, 55.66135123372078, 57.69108071923256, 52.90115274488926, 54.052487164735794, 52.00112164020538, 47.958925142884254, 46.385516971349716, 48.09452846646309, 47.56823390722275, 46.2145983427763, 45.8917448669672, 47.20420204102993, 45.42443074285984, 47.22459554672241, 46.02833613753319, 47.09435373544693, 45.23319460451603, 48.201089948415756, 48.913266733288765, 49.11536268889904, 49.33157108724117, 48.90074260532856, 48.772488087415695, 45.84634110331535, 47.92599231004715, 54.12463389337063, 52.296118810772896, 51.80357024073601, 55.185183584690094, 55.17192229628563, 55.3109036386013, 53.3551599830389, 54.46065366268158, 53.77957060933113, 58.83313983678818, 60.96902422606945, 68.46546337008476, 70.09730860590935, 70.71555063128471, 69.42736655473709, 73.83199140429497, 71.67442917823792, 75.48148289322853, 74.2018635571003, 78.05798023939133, 72.20178008079529, 68.60756814479828, 61.00853070616722, 69.20874908566475, 65.35533785820007, 82.07367315888405, 70.80510422587395, 92.70949244499207, 17.020232900977135, 0.14076625200686976, 2.7220566105097532, 0.22365789860486984, 0.4743979830527678, 52.0561008900404, 78.62041845917702, 62.32358694076538, 40.10661989450455, 27.242824360728264, 38.70563507080078, 68.55059400200844, 24.959435686469078, 0.28087015205528587, 0.14390423049917445, 0.03580867363780271, 0.03169839263136964, 0.03485239409201313, 0.07658669390366413, 0.031146216206252575, 0.01804775500204414, 0.045125436008675024, 0.04712232534075156, 0.23363919113762677, 0.13748999655945227, 0.13565086555900052, 0.0973778497427702, 0.05988756223814562, 0.08985711814602837, 0.2167690166970715, 0.20105778006836772, 0.14822045748587698, 0.19362540857400745, 0.1631502274540253, 46.16176597774029, 92.41088926792145, 36.604081839323044, 47.70928613841534, 61.874781623482704, 76.90288782119751, 81.7961436510086, 1.4378718193620443, 0.12917399435536936, 5.228864746168256, 7.383380485698581, 6.138285147026181, 94.5128832757473, 94.65852186083794, 99.13183942437172, 89.37918394804001, 96.11353978514671, 93.24462532997131, 91.62357151508331, 90.56456834077835, 88.1242024898529, 84.92130875587463, 80.61132162809372, 70.4559713602066, 69.76873263716698, 63.57443042099476, 67.34972923994064, 65.73662459850311, 65.86849272251129, 60.776746943593025, 62.38271936774254, 63.21978025138378, 66.7219877243042, 61.029611974954605, 60.97483031451702, 61.07419118285179, 63.02204646170139, 61.2310391664505, 56.47407442331314, 56.403314620256424, 57.84190982580185, 58.28432388603687, 60.752435848116875, 58.45806956291199, 63.58335614204407, 60.042238757014275, 53.61954599618912, 60.04264913499355, 57.65108786523342, 57.008990719914436, 53.057430759072304, 55.45323260128498, 53.608739376068115, 62.382031604647636, 71.30950435996056, 67.39821463823318, 66.39757633209229, 64.20075461268425, 66.53433859348297, 65.6866192817688, 73.02258923649788, 66.21599927544594, 69.92852926254272, 64.21385630965233, 70.52809908986092, 63.55873726308346, 67.24504485726357, 66.20918244123459, 62.9639095813036, 49.8175498098135, 48.962470293045044, 53.1337458640337, 61.601663678884506, 68.14956352114677, 64.53387513756752, 65.30901834368706, 67.2289489209652, 64.45863157510757, 66.45803108811378, 64.96588915586472, 65.500877648592, 66.36573404073715, 53.54429863393307, 46.0369236767292, 46.64302155375481, 54.725913628935814, 66.3740099966526, 63.13561476767063, 63.240758925676346, 58.74630689620972, 61.75452567636967, 56.61165364086628, 56.97140693664551, 57.68027029931545, 52.347081676125526, 50.857956781983376, 52.19151422381401, 49.76494923233986, 49.05412897467613, 47.36600115895271, 50.83385847508907, 49.03426744043827, 50.44607788324356, 49.29974399507046, 53.38169015944004, 48.07891510426998, 52.28671431541443, 51.36078380048275, 51.12563721835613, 53.08312498033047, 53.15126672387123, 51.34617358446121, 50.837023705244064, 50.86028605699539, 54.55412104725838, 53.98256331682205, 55.15319690108299, 56.9488475471735, 58.98105829954147, 58.80185231566429, 53.81026916205883, 58.07926028966904, 57.19249427318573, 61.0063686221838, 62.8129018843174, 70.17081186175346, 71.81372210383415, 75.28206959366798, 70.71678936481476, 78.83971229195595, 77.3246119916439, 80.16394883394241, 77.5635127723217, 82.98904404044151, 76.15317285060883, 74.22285363078117, 63.627156391739845, 72.53653451800346, 68.79116669297218, 83.67726311087608, 75.40151998400688, 96.26680836081505, 16.43914718180895, 1.0225110012106597, 6.0539192240685225, 0.45551240269560367, 1.4959047990851104, 62.51730814576149, 84.56499427556992, 69.79532361030579, 51.95540249347687, 44.31320317089558, 44.18050289154053, 80.72326362133026, 27.69415844231844, 0.33555233501829207, 0.36417147901374847, 0.1524045821861364, 0.141887889476493, 0.15602329425746575, 0.12160866710473783, 0.17887468915432692, 0.16728859132854268, 0.10961277017486282, 0.1642781138070859], [0.020012112290714867, 0.09221201951731928, 0.060741065462934785, 0.06270514073548838, 0.1837880036327988, 0.021969370936858468, 0.09173798011033796, 0.05619092837150674, 0.11783862370066345, 0.11980316281551495, 1.4774515642784536, 46.61899924278259, 58.49943794310093, 41.2480216473341, 59.31188374757767, 41.34360171854496, 76.39365434646606, 52.982973754405975, 0.036168808219372295, 0.12544271332444623, 0.20581573335221037, 1.3751776772551239, 21.544057354331017, 105.43890818953514, 78.88920083642006, 94.29145395755768, 81.39026463031769, 92.72779986262321, 81.26800999045372, 87.23085522651672, 81.83777421712875, 79.37581792473793, 71.70782938599586, 64.2001162469387, 58.90142597258091, 63.279543444514275, 57.07068420946598, 58.528897762298584, 56.268049478530884, 58.77846837043762, 56.49974584579468, 56.75435118377209, 56.03675588965416, 57.926630079746246, 56.364530101418495, 57.26473979651928, 54.776447117328644, 57.781895846128464, 53.63708205521107, 49.45779651403427, 50.80714590847492, 51.0421746969223, 52.61565886437893, 50.35190373659134, 54.94864247739315, 59.70891684293747, 54.58409383893013, 54.34258259832859, 53.18369418382645, 50.73842279613018, 48.739585652947426, 47.56172105669975, 49.65061716735363, 50.51803462207317, 55.30770421028137, 65.98621800541878, 59.6747262775898, 61.148317605257034, 65.35093769431114, 60.41853256523609, 61.641949117183685, 60.303953513503075, 63.32961715757847, 59.94993411004543, 58.664299696683884, 59.65435937047005, 56.17444150149822, 60.104091838002205, 59.75420281291008, 58.27770084142685, 42.32794649899006, 49.63654272258282, 56.39190003275871, 61.7683607339859, 62.0066649466753, 63.30587983131409, 62.506250739097595, 59.288017228245735, 57.10263289511204, 60.86457923054695, 62.39440754055977, 60.17158381640911, 63.69660906493664, 55.35414531826973, 42.58844152092934, 40.067216008901596, 49.71286162734032, 58.058900982141495, 55.256642550230026, 56.54576137661934, 52.88410685956478, 51.02899320423603, 49.63202476501465, 49.80707377195358, 46.56973108649254, 44.93039645254612, 45.17355680465698, 46.80119946599007, 45.59185355901718, 45.220602080225945, 46.43233805894852, 45.054577589035034, 44.012760892510414, 44.15058709681034, 42.735033854842186, 42.89839468896389, 45.11471316218376, 45.20948767662048, 46.81526631116867, 46.55604802072048, 47.01714187860489, 46.47291228175163, 45.37825562059879, 43.455064818263054, 42.07559444010258, 51.58483497798443, 50.6042367964983, 49.88803222775459, 50.748211070895195, 50.35879276692867, 51.604631915688515, 48.79747174680233, 52.85874702036381, 56.47198833525181, 61.73248305916786, 67.15732276439667, 67.61490941047668, 67.85161390900612, 70.08368253707886, 71.3480418920517, 72.95173063874245, 70.61811625957489, 73.09448137879372, 68.93818840384483, 71.52961134910583, 61.87952756881714, 62.34068222343922, 59.26299937069416, 67.19137653708458, 63.52684557437897, 75.60455828905106, 69.7920785844326, 87.70078361034393, 47.174046859145164, 0.23774803237756714, 0.9705510456115007, 0.08390142014832236, 0.10293925210135058, 25.909339115023613, 76.94058179855347, 56.381192207336426, 44.219534397125244, 36.13456763327122, 27.46609278023243, 52.77798615396023, 26.668473780155182, 0.3142301650950685, 0.01257465708476957, 0.07243910513352603, 0.035337539738975465, 0.03924334792827722, 0.03247684617235791, 0.09655149056925438, 0.08367254180484451, 0.07344149431446567, 0.07945667544845492, 0.0456964889599476, 0.02968354703625664, 0.1198755890072789, 0.09158250017208047, 0.07352223256020807, 0.09839884456596337, 0.1019935926888138, 0.13582185638369992, 0.1284804128226824, 0.21837849752046168, 2.616140143945813, 59.71239745616913, 63.13302330672741, 51.01702764630318, 41.27405405044556, 45.433052480220795, 88.58590811491013, 51.67577549815178, 0.02558784923166968, 0.2852346928557381, 0.7901407044846565, 0.9635548491496593, 25.490124709904194, 109.56609472632408, 80.06751000881195, 98.44723775982857, 83.16438183188438, 94.84730333089828, 83.45669254660606, 90.23656234145164, 83.35489600896835, 80.82648888230324, 72.78168216347694, 66.53645128011703, 61.55663229525089, 65.72840943932533, 60.79680226743221, 62.5946643948555, 58.31594958901405, 60.28604507446289, 59.047881513834, 60.01449264585972, 58.944606855511665, 58.834218978881836, 58.500805869698524, 58.870457634329796, 57.41024158895016, 59.19875241816044, 56.09181493520737, 55.176318660378456, 51.61516115069389, 53.88251468539238, 56.80185243487358, 54.146566316485405, 59.08296503126621, 60.68163804709911, 56.40531711280346, 55.27380242943764, 54.02163662016392, 54.35008339583874, 51.6612146794796, 50.89308589696884, 52.196301966905594, 52.1125278621912, 57.05714553594589, 68.651402592659, 64.75848868489265, 63.44902195036411, 67.57865935564041, 64.88920167088509, 64.2565356194973, 63.85681986808777, 67.79068797826767, 66.74714237451553, 61.05498321354389, 63.87556046247482, 59.549663588404655, 63.99706274271011, 62.09587275981903, 62.14690022170544, 45.55420137941837, 50.90699315071106, 58.73830832540989, 62.59971432387829, 66.24502211809158, 65.88156402111053, 64.42369624972343, 61.83146774768829, 60.48117220401764, 62.64911167323589, 62.7665101736784, 63.54837901890278, 67.45011985301971, 56.32147841155529, 45.1536800712347, 43.00793141126633, 52.830936312675476, 61.80295787751675, 60.274087116122246, 58.498396798968315, 55.68419560790062, 54.63749997317791, 53.45201678574085, 54.713720083236694, 49.29777570068836, 49.196093156933784, 48.43910537660122, 49.218337163329124, 48.61489534378052, 49.00365248322487, 50.68037711083889, 48.24034944176674, 48.7546556442976, 46.239042431116104, 46.12598329782486, 45.185134783387184, 48.48963126540184, 47.61095121502876, 50.115431025624275, 48.94383989274502, 50.60753881931305, 48.62938016653061, 47.533450573682785, 46.77818410098553, 43.90722535550594, 51.49566896259785, 53.19644629955292, 52.45552025735378, 52.84362003207207, 51.62645034492016, 54.049443528056145, 52.03651674091816, 55.58095134794712, 58.617060631513596, 63.9212492108345, 69.57245036959648, 70.59062093496323, 70.3980852663517, 72.48943224549294, 71.62324592471123, 74.71830144524574, 73.40802535414696, 73.22925254702568, 72.15434342622757, 74.57602947950363, 64.49016228318214, 63.68258781731129, 62.73515805602074, 71.34474366903305, 66.79584056138992, 78.3412778377533, 70.82139015197754, 87.57723703980446, 57.126127034425735, 0.15332252980442718, 1.5265682036988437, 0.060797008554800414, 0.13287793466588482, 24.738726429641247, 84.95190471410751, 64.37568202614784, 48.19573983550072, 29.298922531306744, 35.62166355550289, 59.7537924349308, 34.920593574643135, 0.29513770365156233, 0.09870727371890098, 0.12172523624030873, 0.07332549663260579, 0.038663637824356556, 0.028915791554027237, 0.08389308582991362, 0.09747531599714421, 0.1334704802138731, 0.08703905725269578, 0.2675282664131373, 0.15634256618795916, 0.3113415482221171, 0.14802214078372344, 0.2920354373054579, 0.1955069904215634, 0.18275935726705939, 0.3232686629053205, 0.4086786095285788, 0.4433881735894829, 2.8471822338178754, 70.72654724121094, 76.02800756692886, 51.94211460649967, 76.06346726417542, 64.88182246685028, 92.91921839118004, 63.917092233896255, 0.13151837949408218, 0.3431925078621134, 5.018149903044105, 4.094221880659461, 26.814762130379677, 112.47391149401665, 84.58621233701706, 102.05256029963493, 87.89831221103668, 99.38488304615021, 86.5444752573967, 93.83070588111877, 86.8057644367218, 84.61932376027107, 78.11846539378166, 71.3702555000782, 64.66851711273193, 70.19076839089394, 63.465497866272926, 66.84887051582336, 60.31262084841728, 66.98662832379341, 62.88754887878895, 61.64664186537266, 63.85795220732689, 62.64132209122181, 62.21682406961918, 62.40225411951542, 58.6691140383482, 63.519853949546814, 58.4785732626915, 56.456105187535286, 55.30151054263115, 56.72031261026859, 59.203414767980576, 58.115282356739044, 61.56132884323597, 62.06479802727699, 57.59376414120197, 57.92374603450298, 57.80342549085617, 57.16615788638592, 54.61775243282318, 54.0947674959898, 57.75867149233818, 55.243461057543755, 59.46661904454231, 72.85810366272926, 68.94482284784317, 66.36416092514992, 69.88455042243004, 68.67572888731956, 66.44005045294762, 67.44382739067078, 67.65084028244019, 70.84153667092323, 64.7507295012474, 69.6814589202404, 63.26134242117405, 67.11123123764992, 66.51085585355759, 65.80463334918022, 49.97511975467205, 52.72449642419815, 59.81324024498463, 65.43045982718468, 69.01939004659653, 68.69356513023376, 67.93780848383904, 64.14251133799553, 62.089188918471336, 65.18015965819359, 67.12488010525703, 65.03478705883026, 70.47530472278595, 58.763394579291344, 44.240965247154236, 45.195082649588585, 55.28986416757107, 65.78352928161621, 61.322591453790665, 63.812157064676285, 59.516476169228554, 58.382332026958466, 56.26357711851597, 56.90515749156475, 52.637161910533905, 51.65617235004902, 50.08291997015476, 53.12467195093632, 51.190476939082146, 52.450215741992, 52.9006739705801, 50.93582600355148, 51.433435901999474, 49.39028173685074, 49.5303688198328, 48.62516239285469, 50.88645525276661, 51.93977013230324, 53.159219697117805, 52.30488494038582, 53.08578483760357, 51.49621993303299, 50.516320914030075, 48.738814294338226, 45.92764154076576, 56.50177113711834, 55.649514868855476, 54.22410875558853, 55.22579200565815, 55.17527751624584, 57.48094819486141, 53.81764076650143, 58.60859088599682, 61.07103735208511, 65.9179812669754, 72.84057140350342, 72.39238545298576, 72.9191891849041, 76.07729092240334, 74.99279111623764, 76.39256000518799, 77.55747869610786, 77.36477583646774, 72.47117042541504, 78.7283706665039, 68.47186982631683, 68.81961196660995, 67.19578430056572, 75.563695281744, 69.9171830713749, 82.07881808280945, 76.07797488570213, 93.01967740058899, 56.54302552342415, 0.23341939668171108, 6.072401907294989, 0.333845098502934, 0.2360390592366457, 33.333430141210556, 93.47387462854385, 68.95871490240097, 63.074647039175034, 54.66960825026035, 38.12331631779671, 70.15305161476135, 42.27400079369545, 0.44115131080616266, 0.2828861813759431, 0.20284439669921994, 0.19751297106267884, 0.17586513189598918, 0.14921515801688656, 0.1377590250922367, 0.19040070270420983, 0.1484178242390044, 0.17338855541311204], [0.09301924612373114, 0.07077370348270051, 0.044512930398923345, 0.0416685900563607, 0.013941943579993676, 0.09051753309904598, 0.04022690511192195, 0.10328685923013836, 0.11526129324920475, 0.3899137914413586, 7.5871469266712666, 58.64755779504776, 46.99001133441925, 36.63867898285389, 53.45096804201603, 40.54037801921368, 88.46375226974487, 28.88749960809946, 0.47799425257835537, 0.4872827947838232, 2.0315901981666684, 0.18791106442222372, 62.47844763100147, 99.64853569865227, 84.81419250369072, 90.82854777574539, 81.8561652302742, 85.03356993198395, 84.42545056343079, 85.82572102546692, 78.41264560818672, 76.00251093506813, 63.35146978497505, 63.35211955010891, 61.291771307587624, 62.04182825982571, 60.679760947823524, 59.9047165364027, 57.60207809507847, 57.53222644329071, 54.897406026721, 57.85572208464146, 56.95178858935833, 56.79900258779526, 56.805903017520905, 56.85291409492493, 55.70601023733616, 58.30761283636093, 51.641334146261215, 51.06067210435867, 49.46658544242382, 51.78367830812931, 52.40315146744251, 52.922184616327286, 58.21081683039665, 56.62949748337269, 52.75169536471367, 52.02016241848469, 52.099327370524406, 52.83439412713051, 49.270466566085815, 47.859488278627396, 45.9219266474247, 50.325050577521324, 51.68237954378128, 67.34792813658714, 58.375496193766594, 63.74461188912392, 58.31772789359093, 64.51494455337524, 61.303923055529594, 62.05000542104244, 62.307023629546165, 58.2362412661314, 62.157900631427765, 60.89522458612919, 60.98223231732845, 61.792075261473656, 62.89459750056267, 54.364256635308266, 42.17425994575024, 53.28968569636345, 56.580624505877495, 54.96919557452202, 60.650331526994705, 59.557544365525246, 57.482734099030495, 58.91684174537659, 61.32491692900658, 58.6053154617548, 58.18411946296692, 57.87398770451546, 63.18028137087822, 51.432854533195496, 46.888271793723106, 46.08876429498196, 42.21824638545513, 55.094064474105835, 57.7047485858202, 58.79902146756649, 51.03002294898033, 50.467295944690704, 50.97731597721577, 45.967338010668755, 43.799409940838814, 42.27758400142193, 42.598077803850174, 46.39777131378651, 48.985500857234, 51.51983566582203, 49.040575101971626, 49.726537093520164, 45.17328321933746, 44.33572456240654, 42.51568302512169, 41.95397436618805, 43.626827001571655, 45.2877102792263, 47.26597532629967, 46.34609788656235, 46.59899331629276, 45.27859456837177, 46.228779181838036, 46.1629743129015, 43.59055034816265, 43.34161050617695, 49.23407591879368, 49.91363525390625, 51.356474831700325, 51.49445682764053, 50.64024746417999, 51.71537697315216, 56.676006987690926, 63.809747993946075, 66.75392121076584, 67.85683482885361, 69.16083365678787, 69.34177234768867, 72.09085643291473, 70.28767079114914, 69.77285921573639, 71.18939280509949, 71.43906220793724, 70.59830412268639, 63.96623879671097, 58.12773048877716, 59.403979405760765, 62.44652934372425, 64.23785582184792, 66.08503550291061, 72.337197214365, 75.3138130903244, 75.07090732455254, 78.61824497580528, 4.6587243396788836, 1.3907026941888034, 0.3436273173429072, 0.30558951781131327, 4.7483795788139105, 67.764902561903, 64.01178315281868, 47.593844532966614, 40.38705624639988, 21.137705259025097, 46.889016553759575, 32.7082534879446, 0.3899541049031541, 0.07131741571356542, 0.033175541102536954, 0.024913873385230545, 0.00727519018255407, 0.014381396122189471, 0.04967114618921187, 0.05380141323257703, 0.027093063872598577, 0.04905711917672306, 0.06885542985401116, 0.056054347223835066, 0.11533643570146523, 0.0790533924009651, 0.12902445159852505, 0.0437238047743449, 0.08620213731774129, 0.17991506145335734, 0.20449229108635336, 0.5599275045096874, 11.776392683386803, 71.15735292434692, 54.53263700008392, 36.81286543607712, 40.88488653302193, 50.1615871489048, 94.14782166481018, 29.41741917282343, 0.5376058991532773, 0.8902497764211148, 1.4873357838951051, 0.9512668428942561, 69.00868982076645, 101.39490678906441, 87.52193480730057, 93.0974668264389, 82.74042338132858, 90.77490985393524, 84.64937254786491, 87.1611213684082, 79.17260482907295, 77.70481199026108, 63.83475825190544, 66.41664370894432, 63.077949061989784, 66.45185261964798, 63.54063503444195, 64.24707412719727, 59.09695588052273, 60.04898339509964, 57.92849197983742, 60.61080604791641, 59.113933369517326, 60.09656444191933, 57.869956120848656, 59.178769290447235, 58.657836243510246, 59.864826276898384, 53.64449545741081, 52.62268088757992, 52.95908823609352, 54.67958651483059, 55.20600646734238, 55.53351849317551, 59.70866985619068, 59.05786357820034, 51.880873292684555, 53.195621743798256, 52.300868555903435, 53.621559888124466, 52.99992844462395, 49.49198707938194, 49.761077240109444, 51.655036211013794, 53.15822035074234, 68.79279300570488, 64.87215578556061, 67.94607684016228, 60.51945134997368, 66.83996379375458, 63.471816927194595, 65.43001145124435, 67.64976114034653, 62.72452622652054, 65.75047105550766, 63.507747799158096, 64.58052143454552, 65.00548303127289, 65.55349722504616, 56.55543565750122, 44.53294537961483, 53.01966838538647, 58.10955986380577, 56.39815829694271, 62.31593415141106, 60.92859819531441, 59.54307474195957, 61.2551374733448, 62.95743852853775, 62.53646291792393, 59.23887826502323, 60.46393632888794, 61.91279858350754, 52.10015192627907, 46.42916142940521, 46.75719402730465, 45.46663887798786, 60.807411298155785, 61.315763220191, 60.32631151378155, 54.3350438028574, 53.95069822669029, 53.5362658649683, 49.91794802248478, 46.5763883292675, 45.338699743151665, 45.181764364242554, 50.14701493084431, 53.831909000873566, 56.96671038866043, 54.22424174845219, 52.178131341934204, 47.17300571501255, 48.890961930155754, 47.24827207624912, 45.737309753894806, 47.100000232458115, 47.86449261009693, 49.580320939421654, 49.784085005521774, 48.94885182380676, 47.40135446190834, 49.418388828635216, 48.73372636735439, 46.84287942945957, 46.83014631271362, 51.8762831389904, 52.23683059215546, 53.63190293312073, 53.877897933125496, 54.03480291366577, 53.41452419757843, 60.38043200969696, 67.23470941185951, 68.4210741519928, 71.05664312839508, 73.59926149249077, 72.14285284280777, 73.96756052970886, 72.29901686310768, 70.34068554639816, 73.89708951115608, 72.34678789973259, 71.75235539674759, 63.95873799920082, 60.027043372392654, 62.971737161278725, 65.00783890485764, 65.3461879491806, 70.00150054693222, 73.60570594668388, 78.69184702634811, 75.05506977438927, 85.14259368181229, 7.199837984517217, 1.2110421597026289, 1.312746077310294, 0.26572567876428366, 3.7509314389899373, 70.78902348876, 71.78982138633728, 54.48932312428951, 36.032307520508766, 29.29315634071827, 57.20801644027233, 41.431905180215836, 0.4881221044342965, 0.0844128563767299, 0.029186109568399843, 0.02216499920905335, 0.0659077157615684, 0.04115239666134585, 0.04850873512623366, 0.021675280077033676, 0.0430784813943319, 0.06281899361056276, 0.19420980534050614, 0.12312801409279928, 0.21465005149366334, 0.16043280920712277, 0.22223852633032948, 0.1671302318572998, 0.17793409118894488, 0.36442805430851877, 0.4571810772176832, 0.7625877892132849, 13.685567937791348, 86.87365159392357, 61.06423571705818, 45.78006885945797, 73.66468638181686, 56.15047998726368, 99.68683004379272, 34.99128118157387, 0.6738161214161664, 0.833812354831025, 5.24629726074636, 0.8325572940520942, 69.35665234923363, 106.43167331814766, 91.36314868927002, 97.61553078889847, 86.24505132436752, 93.65350618958473, 88.59662353992462, 92.7556523680687, 84.09373596310616, 82.61888310313225, 66.57221496105194, 69.86475348472595, 66.616862565279, 71.33485659956932, 67.18964383006096, 67.66366079449654, 64.33934077620506, 63.52375254034996, 61.608678102493286, 65.26970565319061, 64.07733723521233, 63.37420396506786, 62.219856306910515, 63.73811423778534, 61.28150425851345, 62.43973150849342, 56.59700162708759, 57.70843058824539, 57.84535624086857, 57.44138091802597, 58.574939891695976, 57.39814683794975, 63.386226519942284, 59.695955738425255, 53.483000323176384, 53.76632831990719, 55.240520015358925, 56.45690314471722, 55.292854607105255, 52.7865356951952, 50.79222410917282, 54.363553673028946, 57.48231612145901, 70.84462210536003, 69.20754075050354, 68.9439032971859, 63.291866183280945, 68.04038017988205, 67.28175848722458, 67.2863258421421, 69.99425053596497, 68.18445324897766, 66.92121103405952, 68.94258096814156, 66.83146744966507, 68.79300579428673, 68.56566399335861, 62.639722377061844, 47.48725265264511, 56.11162327229977, 59.10547882318497, 58.20580489933491, 65.93816578388214, 65.28089985251427, 62.070220336318016, 64.33334469795227, 67.21072509884834, 66.97116315364838, 64.14086982607841, 64.36688929796219, 66.10116183757782, 54.7752919793129, 48.55358563363552, 47.19743840396404, 50.64465902745724, 63.3924125880003, 64.66331899166107, 63.70922438800335, 58.74030701816082, 57.55325071513653, 56.56466916203499, 52.198068872094154, 50.96390649676323, 50.12289762496948, 48.44736233353615, 51.98452793061733, 53.713074177503586, 58.970692455768585, 55.95843069255352, 54.78316515684128, 48.64801436662674, 50.087749511003494, 48.99744361639023, 47.74756908416748, 48.974880427122116, 50.91451294720173, 52.03747048974037, 51.782720759510994, 51.040677577257156, 52.199201211333275, 53.280995562672615, 51.42987169325352, 49.81681264936924, 48.87971073389053, 54.276986718177795, 56.10747769474983, 57.23059482872486, 57.5778353959322, 56.59836955368519, 56.33716017007828, 62.09929257631302, 70.2957035601139, 70.74756771326065, 74.04496997594833, 75.69893762469292, 74.90069165825844, 75.67471772432327, 75.28026849031448, 73.52299958467484, 77.50552788376808, 75.51802933216095, 77.15603023767471, 69.5374846458435, 63.99776950478554, 65.48100471496582, 69.05845955014229, 69.27641585469246, 74.58199515938759, 78.4658807516098, 82.40854158997536, 81.00064873695374, 88.94224539399147, 6.646596221253276, 3.649831688962877, 2.291281088255346, 0.38733705470804125, 7.198431584984064, 84.77123200893402, 74.47262182831764, 67.8101809322834, 54.771362990140915, 29.11291491240263, 63.626761212944984, 51.4918577671051, 0.7487394323106855, 0.17213845218066126, 0.09032092333654873, 0.13314598356373608, 0.19168175349477679, 0.11354254602338187, 0.22262940066866577, 0.13589849055279046, 0.13340012461412698, 0.12385000503854826], [0.022113080412964337, 0.06442285637604073, 0.1365739043103531, 0.027548920661502052, 0.06227891048183665, 0.028790706273866817, 0.07901336095528677, 0.02228569097496802, 0.11007754757883959, 0.44544012285768986, 12.460945900529623, 71.90098062157631, 38.163240775465965, 35.22176541388035, 47.094323337078094, 50.385265946388245, 87.12061554193497, 13.52531248703599, 0.36811928905081004, 0.640830744523555, 3.5585187887772918, 13.602740932255983, 95.35821631550789, 85.93724504113197, 88.5569840669632, 83.516326546669, 83.85920494794846, 79.59361463785172, 82.18369245529175, 79.93311122059822, 77.83957555890083, 66.26644536852837, 63.42110864818096, 60.2964261174202, 61.542519852519035, 61.47962182760239, 62.580099776387215, 60.068350955843925, 58.6138080060482, 57.00994826853275, 56.06268189847469, 55.26289701461792, 55.62500238418579, 54.55481640994549, 57.46711313724518, 56.4815828204155, 55.553163439035416, 56.1790506541729, 50.44229708611965, 48.07376258075237, 48.99058498442173, 50.198334977030754, 50.169042348861694, 52.24575251340866, 59.176204428076744, 52.074423506855965, 51.890159994363785, 54.68390688300133, 53.515724167227745, 51.572269052267075, 49.27976466715336, 47.074488401412964, 48.167970925569534, 50.608093589544296, 49.44645792245865, 61.870563849806786, 58.50699193775654, 60.275200456380844, 63.68069551885128, 60.395228415727615, 61.9091621786356, 66.10110104084015, 54.679582715034485, 61.54337100684643, 62.40315467119217, 61.39878496527672, 61.13704361021519, 63.27106989920139, 62.55258925259113, 48.87574754655361, 41.930518224835396, 50.029730424284935, 55.45587345957756, 58.968591168522835, 59.62306424975395, 57.28816173970699, 57.04245172441006, 56.2741519510746, 60.200709253549576, 57.72483430802822, 58.907365053892136, 59.02762100100517, 59.46123093366623, 55.94543159008026, 49.80275720357895, 43.79878677427769, 40.0498091429472, 52.005145624279976, 57.45377965271473, 58.909766525030136, 54.96758446097374, 52.861095294356346, 48.7476222217083, 46.96797251701355, 47.21226900815964, 44.74101081490517, 51.74865558743477, 54.011008590459824, 56.213435009121895, 57.60182350873947, 54.037010595202446, 51.40555679798126, 46.20034910738468, 44.50991481542587, 43.5747279971838, 45.17937049269676, 41.84387147426605, 45.87544374167919, 47.14841343462467, 49.424339309334755, 47.9472179710865, 48.1236083060503, 46.746326610445976, 47.4016622453928, 46.98440283536911, 41.89695082604885, 47.79231168329716, 50.62287859618664, 50.66434197127819, 53.44464898109436, 48.699410408735275, 54.52993534505367, 60.94858132302761, 67.02000573277473, 67.0887440443039, 68.11375424265862, 68.27380925416946, 69.42904606461525, 68.27117219567299, 71.98202267289162, 71.00950285792351, 69.53715786337852, 65.78468441963196, 59.75324906408787, 54.941768646240234, 60.23676551878452, 59.692106544971466, 62.79920741915703, 61.99488177895546, 69.51804488897324, 65.07691159844398, 77.67866939306259, 69.04737174510956, 94.56630080938339, 19.93446372449398, 0.7939730957150459, 0.14096393046202138, 0.15785334137035534, 0.055968681117519736, 35.300937965512276, 77.81514286994934, 50.54778702557087, 43.61199639737606, 23.40966034680605, 45.58908350765705, 37.190504372119904, 0.810164917493239, 0.044963273030589335, 0.042879266693489626, 0.0298427952293423, 0.051254841091576964, 0.011420867922424804, 0.08007938929949887, 0.004638778282242129, 0.028306670137681067, 0.04108164401259273, 0.05892253277124837, 0.07649829669389874, 0.027432388633314986, 0.022983721682976466, 0.1643252104986459, 0.06911749704158865, 0.05981575945043005, 0.0880240579135716, 0.14707156835356727, 0.6238773604854941, 17.296086698770523, 80.84522187709808, 50.58705031871796, 37.0282568782568, 42.66188018023968, 61.26188971102238, 92.7835200726986, 15.204291343688965, 0.6348754547070712, 1.5930762724019587, 2.558169267140329, 17.024410776793957, 99.75774943828583, 88.08541417121887, 89.67918545007706, 84.99572396278381, 86.96567505598068, 80.8975450694561, 83.80799889564514, 81.33957535028458, 78.83061558008194, 68.8245441019535, 63.32193776965141, 62.281245812773705, 63.00696887075901, 65.10048553347588, 64.88100171089172, 63.6422073841095, 60.62165446579456, 60.44303745031357, 58.59088383615017, 59.54922281205654, 59.43257287144661, 58.419505432248116, 58.408083245158195, 58.32450293004513, 58.624512031674385, 58.196328207850456, 53.58978599309921, 51.401897594332695, 53.182227462530136, 51.87228575348854, 53.62243764102459, 55.74730262160301, 60.511217191815376, 53.78529690206051, 51.69493027031422, 55.324788093566895, 54.3647164106369, 55.25961019098759, 50.3071953356266, 49.48034830391407, 51.33452720940113, 50.357713624835014, 50.99502682685852, 64.60110113024712, 63.7122718244791, 64.01407063007355, 62.637579292058945, 65.24438381195068, 63.52491907775402, 70.14534562826157, 58.70038256049156, 65.3875981271267, 64.47242483496666, 64.25840511918068, 63.529022857546806, 66.58348515629768, 64.53918725252151, 51.39053240418434, 45.56002266705036, 49.76328872144222, 56.80410571396351, 62.26184405386448, 62.02346384525299, 59.517076537013054, 61.392264515161514, 60.236149951815605, 61.336430311203, 60.45818343758583, 61.305613964796066, 62.00058527290821, 62.15333327651024, 55.78445702791214, 49.621586725115776, 45.3374420106411, 44.314548298716545, 57.14130721986294, 62.6217645406723, 60.31333141028881, 59.250878021121025, 55.61388798058033, 50.733718648552895, 51.4831068366766, 50.24427831172943, 49.63006407022476, 54.0079877525568, 58.68171416223049, 58.477182537317276, 60.141607224941254, 57.92598031461239, 54.168544337153435, 50.15064373612404, 47.644043639302254, 46.596576645970345, 48.24098400771618, 45.75956515967846, 49.14690859615803, 48.961733132600784, 52.35650137066841, 51.472634598612785, 52.13968500494957, 49.09065641462803, 49.70347233116627, 47.50638462603092, 47.43063189089298, 49.65759739279747, 55.16681157052517, 51.42542213201523, 55.038378462195396, 52.53197595477104, 55.175896883010864, 64.37499046325684, 70.35779222846031, 68.61112475395203, 70.78610524535179, 69.07763332128525, 71.50365874171257, 70.12699261307716, 74.63545829057693, 71.1071728169918, 72.50188797712326, 67.26017564535141, 62.0923313498497, 57.78682038187981, 62.645794451236725, 61.93847380578518, 66.80801510810852, 63.33880886435509, 73.32566097378731, 66.725073158741, 80.43283000588417, 70.14278456568718, 98.79401475191116, 23.66808257997036, 0.9552803181577474, 1.006199901457876, 0.026689767837524414, 0.1748396916082129, 35.15580855309963, 82.0382210612297, 61.06745034456253, 42.699376568198204, 31.367149651050568, 56.40281304717064, 48.29702340066433, 1.4298657677136362, 0.04044719309604261, 0.05082513016532175, 0.06404652813216671, 0.020857784002146218, 0.07233705240651034, 0.10867122226045467, 0.03406523144803941, 0.04734878799354192, 0.01748029033478815, 0.24597745563369244, 0.164217094425112, 0.33433411445003003, 0.16059342480730265, 0.34303938795346767, 0.18764427717542276, 0.21751276741269976, 0.10894730861764401, 0.20644200209062546, 0.726644805399701, 20.531369894742966, 96.43420457839966, 49.98855583369732, 48.21427144110203, 65.85370391607285, 67.65323415398598, 103.00392284989357, 18.21915216743946, 0.5641258042305708, 1.5315595921128988, 8.125451691448689, 16.451331228017807, 101.03867590427399, 93.70434746146202, 94.29757922887802, 90.6032806634903, 90.52769511938095, 87.32122957706451, 88.38758155703545, 86.56886234879494, 82.08330944180489, 74.08469304442406, 66.98487281799316, 66.37176051735878, 67.6070286333561, 67.98437878489494, 69.88693669438362, 68.69139164686203, 64.64370444417, 64.74721848964691, 61.64811238646507, 61.713822260499, 59.71028856933117, 59.80752915143967, 61.527134478092194, 61.58138416707516, 60.559786185622215, 63.72163072228432, 56.71956405043602, 55.45632183551788, 57.0867345482111, 55.2663966268301, 55.53883820772171, 58.21889519691467, 62.2736082226038, 53.341655507683754, 53.024486526846886, 56.95773907005787, 57.69744157791138, 56.21201768517494, 54.07614089548588, 53.19919355213642, 54.154017716646194, 54.74165618419647, 54.119177386164665, 68.86957168579102, 67.11335152387619, 68.13352838158607, 63.23696672916412, 69.04609501361847, 67.6902973651886, 70.413269251585, 64.45843398571014, 68.77713024616241, 68.51504310965538, 68.72107565402985, 67.67240792512894, 69.59920853376389, 68.89860972762108, 56.57794564962387, 47.0549650490284, 51.219940558075905, 58.27230133116245, 64.66031715273857, 66.47397503256798, 63.41478578746319, 65.04962906241417, 62.84027561545372, 66.21020078659058, 61.71764485538006, 63.08043032884598, 63.20066347718239, 66.49298921227455, 57.144673839211464, 49.49845813214779, 46.99789211153984, 50.81957124173641, 59.48597140610218, 62.11453355848789, 66.51204138994217, 60.13873837888241, 59.13109704852104, 53.8522607088089, 53.964001312851906, 54.42509897053242, 51.39619030058384, 58.41150686144829, 61.34618058800697, 61.402383372187614, 63.93769472837448, 59.13154162466526, 58.352378234267235, 51.98652662336826, 48.43450002372265, 48.56250375509262, 49.83179524540901, 48.66697154939175, 52.86695457994938, 52.134209498763084, 55.59805043041706, 51.420041620731354, 55.01631684601307, 51.58521115779877, 51.36429101228714, 51.38439953327179, 50.07379285991192, 55.176033675670624, 55.93665786087513, 56.590082198381424, 58.64609107375145, 54.441620483994484, 58.22497107088566, 66.51963338255882, 72.33111754059792, 71.59609258174896, 73.15190389752388, 72.01754316687584, 74.52828884124756, 73.09432938694954, 76.8212454020977, 75.631954818964, 76.54370069503784, 71.45485416054726, 64.79691982269287, 60.37821672856808, 67.05725893378258, 65.8740708231926, 70.64443364739418, 67.48472839593887, 76.93116590380669, 70.52137345075607, 82.66850084066391, 73.71585443615913, 105.41800171136856, 22.700147219002247, 1.4882890577428043, 2.089032190851867, 0.3379425551975146, 0.34110900247469544, 46.059574261307716, 89.91443082690239, 68.21783065795898, 60.71893684566021, 31.520471423864365, 61.79029695689678, 57.43097327649593, 1.452276490163058, 0.2218496854766272, 0.17229231423698366, 0.22399263689294457, 0.1978953107027337, 0.1966813945909962, 0.18558974523330107, 0.06468326857429929, 0.15738157293526456, 0.1140872304677032], [0.049238058491027914, 0.052376860767253675, 0.06232856758288108, 0.04305215370550286, 0.07696863278397359, 0.023606339054822456, 0.0408770635840483, 0.13848442991729826, 0.13277673540869728, 0.22326378850266337, 21.15093234926462, 62.02245689928532, 31.66072379797697, 33.751529306173325, 41.36405602097511, 57.7177856862545, 80.97076714038849, 3.9395046327263117, 0.20494268566835672, 0.7527945272158831, 0.9538343176245689, 46.28218151628971, 93.88604611158371, 85.56091323494911, 87.45403245091438, 80.58726131916046, 78.00918325781822, 77.85245686769485, 78.28424289822578, 75.40895998477936, 67.8384818136692, 60.98878316581249, 59.05061736702919, 60.31355939805508, 62.49911092221737, 63.100751638412476, 60.620446130633354, 60.42494662106037, 58.96004922688007, 56.510609462857246, 57.21983000636101, 56.077090725302696, 55.17254926264286, 56.09920933842659, 55.610521361231804, 57.42372706532478, 56.124690771102905, 54.71419885754585, 50.53275503218174, 46.72400660812855, 48.90975572168827, 52.520660161972046, 51.528385207057, 52.49707482755184, 56.88721865415573, 52.022947669029236, 51.525037586688995, 49.68182489275932, 53.67343470454216, 51.154751256108284, 51.3867212086916, 49.05081555247307, 47.39893399178982, 46.99231021106243, 50.1211117208004, 54.45385582745075, 65.05038142204285, 56.61981180310249, 64.10632207989693, 57.743487507104874, 63.12230788171291, 61.479971408843994, 56.32329471409321, 62.401349768042564, 59.675573632121086, 61.736594438552856, 59.13547821342945, 63.51935237646103, 56.74672119319439, 48.19322057068348, 43.66880714893341, 47.24365532398224, 54.5525973290205, 61.01103097200394, 59.616589397192, 62.766722962260246, 61.540752947330475, 58.836533054709435, 56.3659930229187, 55.07896788418293, 56.36501647531986, 60.95096379518509, 60.751071721315384, 54.01535175740719, 48.66781510412693, 48.76678839325905, 42.56698027253151, 41.34110905230045, 56.40907131135464, 59.82541099190712, 57.478223741054535, 53.14601920545101, 50.84127947688103, 49.44548897445202, 52.53487519919872, 57.32954151928425, 53.516563922166824, 58.09997297823429, 58.34086865186691, 59.44974794983864, 55.31951777637005, 51.26894652843475, 50.031710118055344, 47.385862693190575, 44.25476610660553, 43.85292246937752, 42.84068338572979, 46.325438395142555, 46.91801659762859, 50.21856129169464, 49.901574701070786, 48.989517241716385, 48.00652898848057, 46.2577336281538, 47.858226746320724, 44.83943693339825, 41.77052780985832, 53.11054050922394, 49.75297227501869, 52.14345060288906, 48.839193508028984, 54.018984362483025, 59.58285100758076, 66.3379955291748, 65.12812525033951, 68.0060376226902, 65.82240879535675, 68.38279500603676, 67.06528410315514, 69.63722929358482, 62.55697421729565, 62.29954943060875, 55.52559971809387, 55.561207607388496, 55.49023501574993, 60.73451980948448, 57.54717104136944, 65.63184902071953, 59.19000908732414, 66.59965708851814, 64.7616121172905, 78.43362808227539, 68.87870639562607, 88.28578501939774, 46.32917359471321, 0.22739936190191656, 0.5763756344094872, 0.18586582416901365, 0.4494804341811687, 10.384188238531351, 76.4236119389534, 54.42632630467415, 50.822196900844574, 42.984528467059135, 42.355502620339394, 54.35346141457558, 3.1512172194197774, 0.16786374093499035, 0.09026697662193328, 0.14798889256780967, 0.12814849469577894, 0.014102211298450129, 0.058063945834874175, 0.08738852717215195, 0.06454821996157989, 0.01702790494164219, 0.0794472724373918, 0.04997783500584774, 0.03911014355253428, 0.01139980577136157, 0.09409873702679761, 0.11683739969157614, 0.10552872408879921, 0.0868229586922098, 0.07628711115103215, 0.2207327977521345, 29.41446863114834, 70.690927952528, 41.246167346835136, 33.83130602538586, 46.468291729688644, 67.56462290883064, 85.64449355006218, 4.169293502345681, 0.3608152497326955, 0.43310604407452047, 0.4431866656523198, 54.74303551018238, 97.24945843219757, 86.92502483725548, 89.23586323857307, 81.04425519704819, 79.66252014040947, 78.9604926109314, 81.8423567712307, 75.77305644750595, 69.95415508747101, 63.806753754615784, 61.010833382606506, 64.3129549920559, 66.67081207036972, 64.82196807861328, 62.86634221673012, 62.744486555457115, 62.07619361579418, 59.48769271373749, 60.34040495753288, 60.6784538179636, 59.03248094022274, 59.45686876773834, 58.588041588664055, 58.182614743709564, 58.28335873782635, 57.76807218790054, 50.43737635016441, 50.49960181117058, 49.757494032382965, 54.525709971785545, 53.919194117188454, 55.64148969948292, 59.42366614937782, 51.07745200395584, 52.133077159523964, 50.663240030407906, 52.180506214499474, 54.83346305787563, 52.64353796839714, 51.045237332582474, 50.90386971831322, 49.72953513264656, 52.05156393349171, 58.640281185507774, 66.70686453580856, 61.41228944063187, 64.88424673676491, 59.254351034760475, 66.3840414583683, 65.2724415063858, 61.27636693418026, 64.5899373292923, 64.90779787302017, 63.70208457112312, 63.72608408331871, 65.41638538241386, 59.459513425827026, 54.98217187821865, 46.590018197894096, 48.7640031427145, 56.369340643286705, 64.86068800091743, 61.37840285897255, 63.282442688941956, 62.02219471335411, 61.09568662941456, 57.347107976675034, 55.82311615347862, 56.79896838963032, 62.9096294939518, 62.475799173116684, 55.755776166915894, 49.027625396847725, 49.38932418823242, 45.009789392352104, 49.59526553750038, 62.2613500803709, 60.668201968073845, 60.115985199809074, 54.67115856707096, 53.36674936115742, 51.51855893433094, 56.688002943992615, 59.71251145005226, 56.39307036995888, 59.80726696550846, 61.25741735100746, 62.65011861920357, 58.677644580602646, 54.81556981801987, 50.49626559019089, 49.61463689804077, 47.130622789263725, 45.96010319888592, 45.7675751298666, 49.53834839165211, 48.934009820222855, 52.66771227121353, 52.11675703525543, 52.85217337310314, 50.488407611846924, 49.37391981482506, 50.31500771641731, 46.70598417520523, 44.24429006874561, 53.19508597254753, 51.62570558488369, 53.53241667151451, 51.79204545915127, 57.025839015841484, 63.33186663687229, 66.81602507829666, 66.16429924964905, 70.44457197189331, 68.14655408263206, 70.83776727318764, 68.66175323724747, 70.71119606494904, 63.84162828326225, 65.42826354503632, 55.91403767466545, 58.78872022032738, 58.685757145285606, 63.08778293430805, 60.105558559298515, 68.24786424636841, 61.58171094954014, 69.61041033267975, 68.11439260840416, 82.11008280515671, 71.51093915104866, 90.48569217324257, 53.127027824521065, 0.08057612358243205, 1.6291105700656772, 0.2273656683973968, 0.5069245642516762, 10.870431996881962, 81.51686623692513, 64.90889981389046, 48.05884838104248, 33.39106924831867, 50.60457497835159, 65.43769463896751, 5.19524272531271, 0.3615758620435372, 0.20177810860332102, 0.027127351095259655, 0.12549414415843785, 0.053554938567685895, 0.060059005772927776, 0.04310352145694196, 0.08861609880113974, 0.06262869210331701, 0.1833334975526668, 0.14993477409007028, 0.2635380649007857, 0.18259224045323208, 0.1412820743280463, 0.15911387919913977, 0.14928279735613614, 0.2226318052271381, 0.25646714901085943, 0.4034143185708672, 35.038554444909096, 83.41138377785683, 44.56631138920784, 45.81305108964443, 60.55809527635574, 73.64811167120934, 95.81118240952492, 5.245617097243667, 0.2797420875867829, 4.223989667370915, 2.260052701458335, 52.742507457733154, 98.50273758172989, 91.9773705303669, 92.3144656419754, 86.6756746172905, 83.06435599923134, 85.79481348395348, 86.76866322755814, 81.65280014276505, 74.53508287668228, 67.89940014481544, 65.2837572991848, 67.29672208428383, 69.07894045114517, 70.80068126320839, 67.03671723604202, 66.58878967165947, 67.3153866827488, 62.12146818637848, 65.22942021489143, 62.51441270112991, 62.38283336162567, 63.78132551908493, 61.223120391368866, 62.64188826084137, 60.84256321191788, 59.72627051174641, 54.08434085547924, 53.00667308270931, 53.52398872375488, 57.98748001456261, 56.3426660746336, 58.24501119554043, 61.57805174589157, 51.25855028629303, 53.20656135678291, 52.3533171415329, 55.28677873313427, 53.89237515628338, 56.02372258901596, 54.79385018348694, 54.052718952298164, 51.45124174654484, 55.734193325042725, 62.23727457225323, 70.05985021591187, 68.60280320048332, 68.82714316248894, 60.581156238913536, 67.21268579363823, 68.14886435866356, 65.79926803708076, 66.29359871149063, 68.15004989504814, 65.05503237247467, 67.15620562434196, 66.88265070319176, 64.56795170903206, 55.4830040037632, 50.90512365102768, 49.30411376059055, 57.099448665976524, 68.54906648397446, 64.93418365716934, 66.0245655477047, 67.69639983773232, 65.82816168665886, 61.62233076989651, 56.83586820960045, 60.53916849195957, 65.75275093317032, 65.61712861061096, 55.80181449651718, 52.67691157758236, 50.02830170094967, 48.09760630130768, 48.71324926614761, 63.03527355194092, 64.8641686141491, 64.01279389858246, 57.59900785982609, 55.72706110775471, 54.01154436171055, 59.5023675262928, 63.67281474173069, 59.05961148440838, 63.56474854052067, 63.82316127419472, 63.945955485105515, 61.11997112631798, 58.65861900150776, 51.269531697034836, 53.167244866490364, 48.46879318356514, 48.852219209074974, 48.63842748105526, 50.64786225557327, 51.10838994383812, 55.80297343432903, 53.933070972561836, 54.904963821172714, 54.59149204194546, 51.158790439367294, 53.874656707048416, 48.595565780997276, 47.31153108179569, 57.08720952272415, 55.012771636247635, 56.27287141978741, 53.726278468966484, 59.24229048192501, 65.06758689880371, 71.12442389130592, 69.72400903701782, 74.33237135410309, 71.0413983464241, 73.37318122386932, 71.5549635887146, 76.57396227121353, 67.22025498747826, 68.53890582919121, 59.71356779336929, 61.34104706346989, 62.730826288461685, 68.26657444238663, 63.84026795625687, 71.86458617448807, 65.08945852518082, 74.71275374293327, 72.06168159842491, 86.64469107985497, 75.11218070983887, 94.99764606356621, 54.6429792791605, 0.2722174226073548, 4.2982590571045876, 0.7095336110796779, 0.8343148184940219, 15.760361105203629, 90.49757033586502, 67.21368134021759, 68.44457969069481, 55.02273850142956, 56.58315896987915, 78.04539531469345, 5.17056162469089, 0.6069775891955942, 0.4344094928819686, 0.16479898273246363, 0.34881593892350793, 0.16419082239735872, 0.21487946418346837, 0.13322309270733967, 0.1473577256547287, 0.18268719082698226], [0.08942131418734789, 0.008224026914831484, 0.11937878050957806, 0.07409886646200903, 0.057808045894489624, 0.03230923583032563, 0.004416191959535354, 0.01714271889795782, 0.11747842232580297, 0.13605208543594927, 35.0148057192564, 61.7796765267849, 33.82265008985996, 48.39783579111099, 45.378540605306625, 67.98549592494965, 71.62336751818657, 0.7548967050388455, 0.18605997000122443, 0.6227214506361634, 1.5559848002158105, 77.11620077490807, 89.52420696616173, 84.95011880993843, 82.85494923591614, 75.52978590130806, 74.3309274315834, 74.70716804265976, 70.55462926626205, 66.29709452390671, 64.4128592312336, 63.69275227189064, 60.38620010018349, 61.20156794786453, 59.5855450630188, 62.5764025747776, 60.48866920173168, 59.197103306651115, 56.93668819963932, 57.10650488734245, 54.349961802363396, 55.075696259737015, 56.24077074229717, 56.02901950478554, 55.84846079349518, 56.44109599292278, 54.9876169860363, 54.335845559835434, 47.70509876310825, 48.08575853705406, 47.22183309495449, 48.9495699852705, 52.20795974135399, 54.017620235681534, 56.36888846755028, 51.415557861328125, 50.592161044478416, 48.96810919046402, 49.723896235227585, 49.951317831873894, 51.24870881438255, 50.113637521862984, 49.02728721499443, 47.96305172145367, 49.431783109903336, 51.61476597189903, 62.75405824184418, 62.11036138236523, 57.61674150824547, 56.0795833915472, 63.88237729668617, 61.04697324335575, 60.12434855103493, 61.02178819477558, 60.081684440374374, 63.278532698750496, 59.24806237220764, 61.79743677377701, 54.796316251158714, 51.75272136926651, 43.0464119464159, 46.68035455048084, 61.71336628496647, 57.86199934780598, 60.582801550626755, 62.00330212712288, 53.50356861948967, 50.62057971954346, 52.259158194065094, 51.66973762214184, 54.8899432271719, 62.271590530872345, 62.21141695976257, 53.9392152428627, 50.14641836285591, 44.801875948905945, 44.39413122832775, 39.72710385918617, 47.844661474227905, 59.00761507451534, 57.88806214928627, 54.596146792173386, 51.0153329372406, 55.455501079559326, 59.41277593374252, 58.219582960009575, 58.61178271472454, 57.20363907516003, 61.18762269616127, 59.106626361608505, 53.35243932902813, 56.01937182247639, 51.15996837615967, 43.15964587032795, 46.481857001781464, 43.044880628585815, 44.10893373191357, 47.5724820792675, 47.450827807188034, 49.598518162965775, 48.51353958249092, 50.705360770225525, 47.961934581398964, 47.39362187683582, 46.85553655028343, 47.76143454015255, 41.72370292246342, 49.01822850108147, 50.31468093395233, 51.09007492661476, 48.8945147395134, 50.311948880553246, 56.91233530640602, 63.866266161203384, 63.00965532660484, 62.60951019823551, 61.32791496813297, 62.782929092645645, 59.17819172143936, 57.9344766587019, 56.23285196721554, 56.053277403116226, 55.27336165308952, 54.12573583424091, 55.60739412903786, 58.3829627931118, 60.79092778265476, 60.832227766513824, 60.11819668114185, 64.91308718919754, 66.05617985129356, 74.81470987200737, 72.39844992756844, 80.17240718007088, 71.53418630361557, 1.2487045512534678, 0.5110618891194463, 0.1072262013622094, 0.2269419317599386, 2.7268122928217053, 68.22932124137878, 64.5781959593296, 50.936547964811325, 51.090576499700546, 30.293226577341557, 57.837027087807655, 7.686976119875908, 0.19950566726038232, 0.06985456100665033, 0.020224893451086245, 0.04595661172061227, 0.09009364061057568, 0.06436178504372947, 0.022481382329715416, 0.11009272449882701, 0.019342129198776092, 0.059717324693338014, 0.030284016866062302, 0.07548620764282532, 0.0213282907861867, 0.05363078977097757, 0.023110393303795718, 0.014442224401136627, 0.05595088812697213, 0.0958542428270448, 0.07768908006255515, 46.43861152231693, 70.58003470301628, 42.907977774739265, 42.19619616866112, 52.51263119280338, 77.0755885541439, 74.8533234000206, 0.6603613996412605, 0.04024027490231674, 0.9255473886150867, 2.19051880761981, 83.91742542386055, 91.69658079743385, 88.02363708615303, 84.80859160423279, 78.26478034257889, 75.78500300645828, 76.27861931920052, 72.36365139484406, 68.0040693283081, 68.30330327153206, 66.50959432125092, 62.50168718397617, 62.08798058331013, 62.4183614552021, 64.18019011616707, 64.61357966065407, 61.38289801776409, 60.99083885550499, 60.39768308401108, 58.76196205615997, 59.79267194867134, 59.67817649245262, 58.22505086660385, 58.03758792579174, 58.48838813602924, 58.051441982388496, 57.602572068572044, 51.828603297472, 51.63989782333374, 51.00369036197662, 52.194466665387154, 52.232559621334076, 56.00327208638191, 58.5605538636446, 52.178629115223885, 50.22560231387615, 48.52559253573418, 51.25460609793663, 49.682246670126915, 52.3465421050787, 53.15495252609253, 51.71996332705021, 50.0149492174387, 51.438060253858566, 55.16891285777092, 63.70564877986908, 64.69240263104439, 63.13848741352558, 59.627620205283165, 64.90312412381172, 64.12367954850197, 63.18631924688816, 64.76415798068047, 63.1544541567564, 67.33037307858467, 62.650236412882805, 65.74439898133278, 58.53890262544155, 56.58326916396618, 45.426611825823784, 47.97866888344288, 62.32940062880516, 61.95927008986473, 61.504274904727936, 64.71980676054955, 57.1658881008625, 53.07988375425339, 53.98589573800564, 54.456557482481, 56.042333990335464, 64.00011777877808, 64.36872079968452, 57.307593896985054, 51.4910826086998, 46.54258914291859, 44.66063752770424, 45.93438997864723, 51.787789687514305, 61.1107262223959, 60.674076452851295, 57.10248090326786, 54.79642264544964, 57.588835805654526, 61.67843095958233, 61.11812062561512, 62.13236600160599, 63.106702119112015, 64.47787374258041, 59.74019296467304, 58.24274271726608, 59.32694613933563, 53.249628245830536, 47.737583220005035, 49.51798528432846, 45.87563373148441, 46.80166684091091, 49.67621639370918, 50.048106238245964, 52.29932963848114, 49.60097283124924, 53.3412679284811, 51.78638756275177, 50.01835763454437, 47.62150704860687, 50.36007709801197, 44.20126497745514, 50.80439865589142, 52.03799106180668, 52.237677946686745, 51.59253716468811, 52.36226946115494, 59.46267105638981, 65.73388874530792, 65.75425565242767, 66.38117641210556, 66.06234312057495, 65.7668025791645, 62.576885148882866, 61.75121605396271, 59.749327674508095, 58.476855754852295, 55.7901681214571, 56.88677787780762, 57.60125353932381, 61.89232528209686, 60.87563283741474, 63.11065390706062, 63.027768954634666, 67.73355424404144, 68.09090986847878, 75.45742258429527, 76.02586448192596, 80.93100607395172, 77.02048391103745, 2.5383447809144855, 0.9821251058019698, 0.17210275487741455, 0.2598559734178707, 2.9954690393060446, 73.296068161726, 72.25449085235596, 55.122095569968224, 34.770501628518105, 35.67664660513401, 67.65018671751022, 11.93613801151514, 0.25537360925227404, 0.07254519514390267, 0.010868343615584308, 0.07569506284198724, 0.07905731094069779, 0.08236363079049625, 0.013075973201921443, 0.09398423848324455, 0.02239006291347323, 0.08985869149910286, 0.08349009964149445, 0.16310088947648183, 0.2207079654908739, 0.18003487377427518, 0.15377715462818742, 0.1088794540555682, 0.13609781657578424, 0.2364897061488591, 0.17040944105247036, 53.86261135339737, 81.12743273377419, 44.91868168115616, 61.676686853170395, 64.68947678804398, 83.84918868541718, 84.73162293434143, 1.187358268070966, 0.28207388590089977, 2.2888620430603623, 2.7260416466742754, 85.13979703187943, 94.74335610866547, 92.17312082648277, 91.02311253547668, 80.77836826443672, 81.05409666895866, 82.03464925289154, 74.91612643003464, 71.60098671913147, 71.17613151669502, 69.50517117977142, 66.36957183480263, 68.53554680943489, 66.13523840904236, 68.0823603272438, 68.09287056326866, 64.55118700861931, 65.1163762807846, 64.73080337047577, 61.78994357585907, 62.485416457057, 63.96636039018631, 62.236989587545395, 62.08464436233044, 62.14906610548496, 61.613264456391335, 59.760122895240784, 55.52446737885475, 54.79075334966183, 54.78153124451637, 54.226787611842155, 56.78024299442768, 61.16325080394745, 60.61967097222805, 51.45773559808731, 52.34295889735222, 47.98415198922157, 53.27880308032036, 50.73379464447498, 55.05396902561188, 54.855357483029366, 54.97427590191364, 51.680882424116135, 55.16975261271, 58.42676304280758, 67.0788037776947, 68.75689253211021, 67.85326302051544, 64.16387379169464, 69.72123518586159, 69.68692302703857, 66.69475838541985, 67.96989396214485, 66.69602751731873, 71.50381833314896, 66.71120390295982, 67.98886254429817, 61.67856775224209, 59.33596305549145, 46.98687270283699, 49.80183005332947, 64.80725526809692, 64.61967453360558, 64.28353697061539, 67.9450660943985, 59.24180410802364, 54.54692043364048, 56.88968472182751, 55.60321055352688, 58.207723796367645, 67.64768645167351, 67.7364344894886, 60.90248979628086, 51.04488015174866, 48.58527593314648, 49.19977895915508, 45.82710273563862, 57.017213478684425, 64.57786157727242, 63.506151884794235, 61.00069172680378, 57.91007436811924, 60.539419278502464, 65.55792778730392, 64.95342582464218, 65.7664605975151, 64.52300012111664, 65.24455100297928, 63.586449176073074, 61.647899597883224, 60.986685678362846, 56.219780668616295, 48.536885529756546, 52.229968160390854, 48.761126697063446, 49.70140524208546, 52.527081817388535, 53.16186435520649, 54.78617459535599, 51.26949369907379, 54.63908828794956, 54.808160215616226, 53.05770054459572, 49.51059848070145, 53.89444224536419, 47.28663481771946, 54.718549624085426, 55.391041338443756, 54.99827541410923, 55.08593671023846, 55.29808692634106, 61.689298376441, 68.48132371902466, 67.28394716978073, 68.08036923408508, 68.27292770147324, 68.32137510180473, 65.97383826971054, 65.68292587995529, 63.03008683025837, 61.88579723238945, 60.03225289285183, 60.203194320201874, 61.85133308172226, 64.74132120609283, 65.56959316134453, 65.88154882192612, 67.61400505900383, 72.0273694396019, 73.52445870637894, 81.79427415132523, 79.27198469638824, 86.77440851926804, 78.95103871822357, 2.6043066289275885, 2.225933619774878, 0.2427331273793243, 0.2906270488165319, 4.3693271186202765, 82.36168250441551, 76.4536227285862, 71.50597661733627, 69.09330368041992, 43.47985468804836, 81.83391362428665, 13.649535421282053, 0.4137956287013367, 0.2567406155867502, 0.07362231859588064, 0.1658720095292665, 0.22951143997488543, 0.28227848117239773, 0.07862578917411156, 0.23320936888922006, 0.1664796206750907], [0.041171031989506446, 0.07627493992913514, 0.06372065850882791, 0.05273494702123571, 0.07059127616230398, 0.058924774057231843, 0.018879897361330222, 0.038926191118662246, 0.06256664113607258, 0.7233406451996416, 50.21753914654255, 47.6427099108696, 32.885890156030655, 46.150632575154305, 48.94140802323818, 72.33277425169945, 59.22741048038006, 0.07077017828123644, 0.17696199647616595, 2.1599760465323925, 6.485512414947152, 89.29469928145409, 88.45790058374405, 86.59277826547623, 84.49696272611618, 77.34182506799698, 69.47965934872627, 68.42691823840141, 66.3627777993679, 62.492959052324295, 63.89373108744621, 59.52124111354351, 59.69193555414677, 59.293401539325714, 59.2800148576498, 60.116121992468834, 60.522605180740356, 59.36063513159752, 58.71988691389561, 58.319380804896355, 56.26691713929176, 54.95838135480881, 52.83274881541729, 54.788804054260254, 54.53539565205574, 54.17748145759106, 54.78590101003647, 53.263725489377975, 49.12255950272083, 45.45272022485733, 49.05485473573208, 49.28351126611233, 53.224716782569885, 55.53294472396374, 56.82027764618397, 51.63688838481903, 51.088456213474274, 49.29836466908455, 50.17771728336811, 49.03972014784813, 51.80758282542229, 49.84523892402649, 45.668845027685165, 47.389525696635246, 47.07924194633961, 51.240315064787865, 56.892093792557716, 59.136853739619255, 62.01746016740799, 56.46351478993893, 53.14082108438015, 57.99311511218548, 63.83190840482712, 62.25537680089474, 58.00708696246147, 60.11391431093216, 58.34479384124279, 60.73858939111233, 58.043800592422485, 43.092009499669075, 46.53943531215191, 54.30479742586613, 62.036964520812035, 58.88440288603306, 60.5937297642231, 53.865453600883484, 54.31661859154701, 54.513052850961685, 53.539579287171364, 57.326228097081184, 55.8793531358242, 51.953677386045456, 57.317480966448784, 53.815273493528366, 51.392713487148285, 46.948099583387375, 44.87186439335346, 39.64667737483978, 38.93274128437042, 58.254860267043114, 56.802661791443825, 57.430065125226974, 54.945275858044624, 58.880447298288345, 58.64216968417168, 61.33686348795891, 56.04186661541462, 57.86202594637871, 56.319468319416046, 50.81575624644756, 61.079237312078476, 56.92978397011757, 51.546517834067345, 45.1609642803669, 44.44587305188179, 43.62817592918873, 47.476012855768204, 47.78778612613678, 49.010321125388145, 48.29973265528679, 47.48745784163475, 52.29641139507294, 50.86729668080807, 47.52433866262436, 47.211417853832245, 47.44707740843296, 43.20379190146923, 43.93765412271023, 52.13572941720486, 49.29055988788605, 49.51662115752697, 49.563172459602356, 52.18462139368057, 58.20561870932579, 60.761080384254456, 55.32514527440071, 57.19945929944515, 57.63251446187496, 55.69563299417496, 56.14150106906891, 53.588938638567924, 52.98141963779926, 53.34252566099167, 52.960395365953445, 54.08255115151405, 56.34269267320633, 56.841541305184364, 55.68480737507343, 61.41364596784115, 60.26271052658558, 69.44146379828453, 71.06513187289238, 79.683897793293, 74.02282476425171, 91.78238019347191, 10.829740930348635, 0.9170545474626124, 0.3635313321137801, 0.09383595737745054, 1.4547945675440133, 59.27404537796974, 67.74563759565353, 48.665280640125275, 44.3386048078537, 20.005196928977966, 59.62421178817749, 18.360183499753475, 0.3446002135751769, 0.06764092002413236, 0.053583629996865056, 0.016468672547489405, 0.03527986002154648, 0.06687237415462732, 0.020212289928167593, 0.03927039921109099, 0.003026334434252931, 0.059919630439253524, 0.047807034497964196, 0.05170465308765415, 0.030219644831959158, 0.032585722947260365, 0.017422018754587043, 0.003268343225499848, 0.09346672406536527, 0.09522909473162144, 1.1018440942279994, 62.939879670739174, 55.10662280023098, 44.01770822703838, 45.90286307036877, 57.87712633609772, 80.16533195972443, 63.02675440907478, 0.10718470046413131, 0.2783192420611158, 2.1591954259201884, 7.197675900533795, 96.358353048563, 89.02790039777756, 90.79299688339233, 84.90745469927788, 80.93426629900932, 70.87348535656929, 69.19560939073563, 67.43834808468819, 66.88614651560783, 66.10029548406601, 66.24468013644218, 62.87796579301357, 62.62928433716297, 63.46085451543331, 64.67670187354088, 62.79433608055115, 62.61346958577633, 61.826307624578476, 60.74644736945629, 58.86762298643589, 59.24324043095112, 56.8935377150774, 58.81868161261082, 57.80535198748112, 59.068852588534355, 57.2801897674799, 54.88543286919594, 51.599657982587814, 49.94705066084862, 52.172249257564545, 51.61008842289448, 53.47413919866085, 59.09648850560188, 57.22286604344845, 50.711364448070526, 52.63585478067398, 48.01732420921326, 50.44035919010639, 50.79245209693909, 55.331236347556114, 52.34404943883419, 48.04108053445816, 49.76974077522755, 51.38618163764477, 53.01432967185974, 58.21930557489395, 61.17010183632374, 65.1584704220295, 61.04578010737896, 54.35726121068001, 59.885937944054604, 65.30385822057724, 63.589614406228065, 62.72024765610695, 63.94337922334671, 62.73060590028763, 66.70056447386742, 59.0853551030159, 47.02296696603298, 50.532895624637604, 54.91842269897461, 62.515830025076866, 61.060766503214836, 63.08586783707142, 54.86427940428257, 55.63791409134865, 57.54501275718212, 56.2739809602499, 56.82557836174965, 57.37952783703804, 53.45104403793812, 55.87698206305504, 56.155389323830605, 52.49131813645363, 48.61876733601093, 44.380603954195976, 43.053703755140305, 44.240965247154236, 59.862622395157814, 60.45480541884899, 60.05417391657829, 59.033856466412544, 59.55793954432011, 60.37710338830948, 62.667745873332024, 58.59153360128403, 59.81478676199913, 55.33291585743427, 55.6246680021286, 62.901600524783134, 58.46298269927502, 53.45496542751789, 45.858846232295036, 49.03188116848469, 43.843179792165756, 48.297980949282646, 50.08342534303665, 51.375348418951035, 50.248526483774185, 50.68068869411945, 54.38343420624733, 52.08606228232384, 50.031592324376106, 50.22472456097603, 47.33817905187607, 45.47991916537285, 45.419897586107254, 53.24874669313431, 52.45786093175411, 51.61608450114727, 53.559174835681915, 54.94047291576862, 59.15830358862877, 64.03269723057747, 58.00223082304001, 61.28707095980644, 58.99566851556301, 58.142200112342834, 58.04214008152485, 55.89414954185486, 55.329594835639, 54.72241401672363, 55.583751797676086, 56.25851199030876, 59.20082330703735, 58.74553173780441, 58.35188806056976, 62.90556751191616, 64.15652498602867, 72.07609802484512, 74.26801800727844, 81.96878358721733, 75.36525472998619, 96.2369267642498, 14.49509359896183, 1.0522852535359561, 0.10885304101975635, 0.21338494203519076, 1.3782366318628192, 63.7759830057621, 75.03576681017876, 56.93787753582001, 44.02001090347767, 27.32340093702078, 69.91535156965256, 23.16219102591276, 0.28509365511126816, 0.03343427233630791, 0.07561038379208185, 0.023747170853312127, 0.11861136270454153, 0.016848793165991083, 0.0439928407286061, 0.03890379310178105, 0.01841044628235977, 0.14578668808098882, 0.13992391439387575, 0.12935147155076265, 0.0780515227233991, 0.07630859632627107, 0.22322969423839822, 0.12257290247362107, 0.21406899439170957, 0.1736021158285439, 1.3687310856766999, 70.6032058596611, 63.35308849811554, 44.545066729187965, 61.79840952157974, 68.90281990170479, 84.9661311507225, 71.17921695113182, 0.15854558703722432, 0.6760528357699513, 4.5019205287098885, 8.649609815329313, 97.15477511286736, 92.3376215994358, 92.06636175513268, 91.21424227952957, 86.01691156625748, 74.93714690208435, 71.8069052696228, 71.40179380774498, 69.18188452720642, 71.66355416178703, 70.05734235048294, 65.35586223006248, 64.92453217506409, 66.778923869133, 70.21854490041733, 67.55665853619576, 66.23906403779984, 67.42570996284485, 64.59761291742325, 64.21898603439331, 61.18983417749405, 59.139015823602676, 60.980321019887924, 60.60368902981281, 59.571512416005135, 59.35767129063606, 58.04266445338726, 57.0533799380064, 51.3483052700758, 54.69509348273277, 55.8590242266655, 58.73387396335602, 61.73522651195526, 58.47940921783447, 50.631709322333336, 52.60820746421814, 49.54041168093681, 52.272005304694176, 51.84039406478405, 56.123858615756035, 54.84610877931118, 50.28874732553959, 52.61450372636318, 54.15825068950653, 55.35791091620922, 63.03215391933918, 64.86273989081383, 69.73923102021217, 61.842977330088615, 60.37932246923447, 63.380876407027245, 68.2694698870182, 66.97781279683113, 66.35837003588676, 65.64990565180779, 66.29367470741272, 69.12673428654671, 63.83380830287933, 53.70123401284218, 51.61723203957081, 59.46117013692856, 65.64324080944061, 61.50566183030605, 66.89839705824852, 59.31340366601944, 55.66088005900383, 58.901292979717255, 57.9672385007143, 59.22162339091301, 59.83104228973389, 54.26381282508373, 59.40798059105873, 57.44735799729824, 55.289039611816406, 50.106478706002235, 49.92717392742634, 43.12715761363506, 48.27723786234856, 61.83331444859505, 62.5023939460516, 63.387343659996986, 60.53142070770264, 64.24868524074554, 63.57934735715389, 66.52774974703789, 62.414299473166466, 62.46956370770931, 58.538777232170105, 57.81392052769661, 64.90684032440186, 61.40852004289627, 57.438812255859375, 48.578345105051994, 49.867186546325684, 49.41034846007824, 52.172488644719124, 53.4683521091938, 54.003891572356224, 51.476168408989906, 51.67202889919281, 55.46467758715153, 57.03979566693306, 53.88860955834389, 53.0013457685709, 50.69675423204899, 48.763037994503975, 49.70314174890518, 57.1014017611742, 55.39666883647442, 55.2208598703146, 56.430532559752464, 57.67411842942238, 61.403998285532, 67.56591483950615, 60.531435906887054, 63.89449864625931, 62.164812460541725, 62.46907353401184, 61.94679155945778, 60.00440798699856, 60.378798097372055, 58.627453073859215, 59.81121115386486, 58.7423475086689, 63.52160945534706, 64.10756081342697, 62.031158432364464, 67.08396390080452, 67.15104550123215, 76.22995913028717, 76.78036719560623, 87.3735223710537, 78.91319274902344, 100.78795775771141, 14.253773298114538, 1.02799778804183, 1.1079970328137279, 0.26811652234755456, 3.0930126551538706, 73.4292434155941, 80.98772943019867, 66.75318405032158, 65.63449367880821, 30.194359682500362, 82.37295269966125, 26.327580772340298, 0.5662856914568692, 0.27214757166802883, 0.1224108471069485, 0.14001856790855527, 0.13870490714907646, 0.1511241844855249, 0.13811455835821107, 0.1135847668047063, 0.12352598336292431], [0.06019527150783688, 0.043598530246526934, 0.05187637121707667, 0.060881346216774546, 0.051723648357437924, 0.04664541011152323, 0.10416599252494052, 0.10208227933617309, 0.357473180629313, 2.6566333835944533, 59.29540403187275, 52.539928928017616, 36.28212511539459, 44.438691437244415, 50.59886768460274, 82.89884448051453, 46.30936525762081, 0.2206854338874109, 0.27819058333989233, 2.2283241664990783, 12.662964910268784, 91.38947367668152, 87.32158675789833, 86.41372427344322, 86.4858216047287, 83.24227005243301, 76.11889109015465, 65.85299715399742, 65.1529911160469, 63.20000231266022, 61.35830573737621, 61.06653839349747, 62.47222736477852, 59.60837423801422, 59.20150727033615, 58.76909427344799, 59.084287360310555, 55.83693981170654, 55.18076442182064, 53.944595754146576, 54.92379941046238, 55.83399496972561, 54.58380505442619, 55.68644508719444, 55.49550153315067, 55.454779118299484, 54.782861173152924, 51.12420089542866, 48.554489985108376, 48.53400148451328, 49.86799590289593, 48.85478027164936, 52.10193783044815, 53.828264996409416, 56.02952867746353, 51.08505539596081, 50.24906225502491, 49.70485545694828, 50.10509558022022, 47.52124562859535, 50.24891026318073, 49.883609265089035, 48.31463925540447, 45.84630690515041, 47.779327780008316, 48.16867008805275, 53.28335523605347, 58.895350098609924, 61.86581030488014, 64.16252106428146, 53.335104659199715, 50.891117602586746, 60.41450098156929, 59.77819852530956, 60.198049396276474, 57.294929176568985, 58.99457797408104, 58.75405088067055, 61.278076842427254, 47.256130054593086, 46.20162583887577, 50.649811550974846, 57.31751896440983, 59.2551413923502, 58.281006664037704, 50.55331192910671, 58.78407306969166, 57.170356661081314, 60.577485635876656, 59.326022788882256, 57.29599691927433, 52.28047505021095, 54.28895607590675, 53.00221212208271, 50.24728775024414, 48.97094003856182, 42.638047859072685, 39.73227918148041, 37.13998608291149, 53.59269663691521, 59.062544927001, 60.69163151085377, 53.9230053126812, 58.76103110611439, 57.720662131905556, 54.564160108566284, 50.04577316343784, 50.6291938573122, 50.28323382139206, 58.9541557431221, 60.706971287727356, 55.95330476760864, 46.38719268143177, 46.56565010547638, 45.88395148515701, 45.14907471835613, 47.829819470644, 47.479512467980385, 48.9079812169075, 48.14623609185219, 47.33450844883919, 48.113785833120346, 52.325118854641914, 48.22782151401043, 47.20368146896362, 45.25890402495861, 45.34868560731411, 41.725792810320854, 48.52739743888378, 51.33526436984539, 50.079234167933464, 51.042030304670334, 51.30434162914753, 51.08825482428074, 57.17584356665611, 56.23075067996979, 57.20964655280113, 54.896406680345535, 53.90286259353161, 53.33837628364563, 52.794978842139244, 50.878460481762886, 54.58066642284393, 52.988426461815834, 56.27965025603771, 57.66628324985504, 61.017289236187935, 60.615001022815704, 64.72723916172981, 64.02576640248299, 71.4191360771656, 67.65154704451561, 82.71957769989967, 72.51560524106026, 89.06733468174934, 29.988872408866882, 0.4353168129455298, 0.1441678561968729, 0.11531948504853062, 0.28823659115005285, 48.847933039069176, 72.7962201833725, 52.53474220633507, 39.161280021071434, 18.952062539756298, 52.42595784366131, 27.068104036152363, 0.08881884612492286, 0.045534192395280115, 0.06750582688255236, 0.03545434636180289, 0.048554610984865576, 0.043520233666640706, 0.10147745124413632, 0.05220130202360451, 0.08870792473317124, 0.01764378546795342, 0.04471992651815526, 0.06413837632862851, 0.09901332799927332, 0.07333963454584591, 0.11562606625375338, 0.14233144145691767, 0.14266111829783767, 0.34568265080451965, 3.9443524600937963, 68.90333667397499, 60.31461574137211, 36.90283700823784, 42.275429517030716, 61.99890956282616, 90.051299482584, 48.13331678509712, 0.27385807363316417, 0.19005287293111905, 3.0105827283114195, 15.114224776625633, 95.6202806532383, 87.89051502943039, 89.41006109118462, 88.30371245741844, 86.18966549634933, 78.92420455813408, 68.962172716856, 70.04489421844482, 66.10102504491806, 65.4914465546608, 64.38083454966545, 67.08021730184555, 63.2504940032959, 61.65983855724335, 61.512292474508286, 63.83181720972061, 57.851219326257706, 58.023855462670326, 56.320178881287575, 56.12393841147423, 58.77572871744633, 57.595329657197, 59.31990511715412, 59.44374807178974, 58.07037636637688, 56.83815188705921, 53.12700502574444, 51.522164940834045, 52.026736065745354, 52.250969633460045, 51.953848376870155, 53.81474532186985, 57.06691101193428, 58.811716586351395, 51.97629377245903, 51.38270862400532, 49.356809332966805, 51.23829357326031, 49.71077933907509, 52.50821962952614, 54.45275008678436, 52.80635163187981, 50.38070239126682, 49.50263790786266, 49.610498920083046, 57.11619816720486, 60.253420025110245, 63.803934305906296, 65.7347323000431, 60.18173307180405, 53.61803747713566, 61.32679022848606, 61.33997552096844, 64.09135088324547, 59.70942981541157, 61.22814752161503, 61.8355867266655, 63.51022906601429, 51.78560860455036, 52.54335634410381, 53.468200117349625, 59.60309252142906, 61.69753633439541, 59.56075519323349, 53.84662181138992, 62.67915666103363, 60.15867590904236, 61.58563993871212, 59.93757717311382, 58.853065967559814, 53.38351026177406, 53.860703855752945, 55.37415884435177, 51.02166719734669, 49.148227125406265, 42.60617896914482, 43.52400451898575, 45.06403908133507, 55.89114010334015, 60.4836268723011, 62.567469254136086, 57.37347476184368, 59.96567666530609, 59.99137468636036, 53.952218145132065, 53.45765948295593, 51.658140644431114, 51.552487313747406, 62.90122054517269, 62.78457820415497, 58.05106580257416, 48.23475234210491, 47.342978194355965, 49.37812998890877, 45.66884882748127, 50.200804844498634, 48.77509854733944, 51.3255824893713, 48.15059445798397, 48.524638786911964, 50.21765314042568, 54.18684795498848, 51.022856533527374, 49.427348747849464, 47.30140082538128, 48.30945633351803, 44.69501428306103, 50.61926878988743, 53.004727587103844, 51.09968461096287, 53.70808504521847, 52.66523100435734, 53.720620572566986, 60.24262100458145, 58.760909512639046, 59.936498031020164, 57.58394926786423, 57.64088921248913, 55.55702403187752, 55.89637242257595, 52.97403663396835, 57.98701263964176, 55.09841524064541, 60.108887180686, 59.535532146692276, 62.47016407549381, 63.36189262568951, 68.80938291549683, 66.18617847561836, 73.94449576735497, 70.22155433893204, 82.32941463589668, 73.43591585755348, 92.11414039134979, 34.73228707909584, 0.5344951723236591, 0.02747160557191819, 0.023640789549972396, 0.14955727325286716, 52.90837615728378, 78.22039112448692, 60.98325826227665, 38.701094314455986, 23.479732386767864, 64.02913302183151, 36.136524528265, 0.13448967161821201, 0.020720965367218014, 0.02741278109169798, 0.010115636105183512, 0.010160417295992374, 0.020499332240433432, 0.2026757362182252, 0.03787368470511865, 0.0395222136285156, 0.16009749204386026, 0.17703068966511637, 0.22539906611200422, 0.22219767852220684, 0.14648638491053134, 0.2106697650742717, 0.2711830468615517, 0.31928502197843045, 0.6290932337287813, 4.983071610331535, 82.23478451371193, 66.89358651638031, 47.347644343972206, 56.99064910411835, 69.7766362130642, 96.80629581212997, 54.8841143399477, 0.39804903615731746, 0.8110185654368252, 3.7185348523780704, 22.56680477410555, 99.73561182618141, 94.04603272676468, 91.89337223768234, 91.23805180191994, 90.43502569198608, 83.25020402669907, 71.41329199075699, 73.72944250702858, 68.6514101922512, 69.16509702801704, 67.26231873035431, 72.11648225784302, 68.51507350802422, 66.3727180659771, 65.58804497122765, 68.71504157781601, 62.80341759324074, 60.28838574886322, 60.720741748809814, 60.72693161666393, 62.58944347500801, 61.454786360263824, 62.009104415774345, 61.502371206879616, 61.24162159860134, 59.85282652080059, 57.8073924779892, 56.5117722004652, 54.23950932919979, 56.72848977148533, 54.42573353648186, 56.771792247891426, 59.816454872488976, 60.127228796482086, 51.75240978598595, 51.629319190979004, 51.340302899479866, 51.321531906723976, 49.498746916651726, 55.715980902314186, 56.27567566931248, 54.75436270236969, 52.67579823732376, 52.241614535450935, 52.667225897312164, 59.67466928064823, 62.71573729813099, 68.10446754097939, 69.8980700969696, 62.71626926958561, 59.60498861968517, 65.44680655002594, 66.59489214420319, 66.6710552573204, 65.37689790129662, 65.34556478261948, 68.0490817129612, 67.20064043998718, 56.60853400826454, 53.527378141880035, 55.179130509495735, 61.38589985668659, 65.46073660254478, 63.84209185838699, 52.87909112870693, 65.70913687348366, 62.62903735041618, 68.27365726232529, 63.734937608242035, 60.8625615388155, 54.120875895023346, 56.013349145650864, 56.351538598537445, 50.97995683550835, 51.28372773528099, 47.60931730270386, 44.21060487627983, 47.61995293200016, 61.66198544204235, 61.404055282473564, 65.73933005332947, 59.36690479516983, 64.46511402726173, 61.3865078240633, 56.37677304446697, 55.62770403921604, 56.12583830952644, 56.62399157881737, 62.58177928626537, 65.99273845553398, 62.97845520079136, 51.205372139811516, 50.8393681794405, 52.89273239672184, 49.54682193696499, 52.96714760363102, 51.43751688301563, 52.618330121040344, 49.5762437582016, 49.342909678816795, 49.72106918692589, 58.29329900443554, 54.71075624227524, 51.41789473593235, 50.31214267015457, 51.444208323955536, 47.94086471199989, 53.61453786492348, 55.521830320358276, 54.218743443489075, 56.84368439018726, 55.72967156767845, 56.44755184650421, 64.88461911678314, 62.1210578083992, 65.47047927975655, 61.68899439275265, 61.34996138513088, 59.117489978671074, 59.63224455714226, 56.85608312487602, 61.55288189649582, 59.63578216731548, 61.4764603972435, 63.1350751966238, 65.11158853769302, 67.38987028598785, 74.15691196918488, 68.80603909492493, 79.61708217859268, 74.20738846063614, 88.88274058699608, 78.32955166697502, 97.07076162099838, 35.794508680701256, 0.764070600271225, 1.206547119654715, 0.18384121562121436, 0.7771145284641534, 62.30622947216034, 85.59571176767349, 68.48779857158661, 52.606060579419136, 26.735939159989357, 73.169154971838, 42.38629996776581, 0.18357819848461077, 0.14646276977146044, 0.12541325006168336, 0.1357511742389761, 0.1538922023610212, 0.13834051263984293, 0.27177171839866787, 0.19225145573727787, 0.19470403116429225], [0.06933842698344961, 0.08978154524811544, 0.014294657612481387, 0.03358152927830815, 0.11383363860659301, 0.06979542667977512, 0.1277470076456666, 0.11201105749933049, 0.23391941125737503, 4.183677155524492, 62.08690144121647, 39.03676450252533, 40.902506187558174, 41.390153020620346, 50.66691443324089, 86.26699894666672, 31.655831560492516, 1.1692482023499906, 0.9448344411794096, 1.9830117048695683, 9.653037171810865, 95.77699184417725, 83.32448244094849, 90.32348647713661, 88.95046055316925, 83.86855244636536, 81.68333530426025, 71.95219427347183, 65.2639451622963, 63.62456873059273, 61.64540693163872, 62.74773918092251, 62.023794427514076, 60.2839931845665, 59.66446302831173, 58.96482557058334, 56.75278186798096, 54.04508516192436, 54.839158952236176, 54.492807537317276, 55.672032460570335, 55.11180952191353, 54.35216948390007, 56.104589849710464, 57.189659625291824, 54.10430118441582, 54.889992624521255, 51.600851118564606, 49.80830490589142, 46.00234553217888, 47.56974622607231, 49.38800945878029, 50.97907908260822, 52.34784163534641, 56.19999133050442, 52.37127497792244, 51.009857431054115, 47.36660912632942, 51.66761353611946, 51.89521372318268, 49.02422457933426, 51.1022874712944, 47.9455878585577, 47.014257833361626, 47.39186257123947, 46.05395816266537, 49.27937708795071, 56.764983013272285, 57.06728719174862, 60.51852039992809, 60.816868990659714, 54.93142560124397, 59.35954459011555, 56.138161048293114, 58.60539145767689, 55.33474735915661, 58.38342256844044, 58.50794568657875, 60.12404456734657, 47.79190890491009, 41.0827761143446, 59.25500839948654, 49.48925502598286, 56.84202767908573, 54.60528530180454, 54.23405662178993, 63.471824526786804, 59.478265419602394, 53.587471917271614, 57.2907418012619, 54.837950617074966, 46.87313720583916, 50.187805742025375, 50.325787737965584, 52.750593423843384, 45.47725930809975, 46.02854512631893, 37.933983877301216, 32.93974466621876, 50.47489553689957, 59.718423932790756, 54.367676451802254, 55.386914759874344, 59.25890699028969, 58.74829798936844, 54.877867475152016, 55.61967507004738, 48.22280578315258, 56.47973991930485, 60.7184124737978, 56.869918182492256, 51.404762640595436, 45.56082062423229, 46.69124476611614, 45.52451737225056, 46.04812167584896, 47.06995524466038, 50.82726962864399, 44.971312656998634, 46.7154760658741, 45.979208573699, 45.30638247728348, 53.37863132357597, 48.78984935581684, 47.50234164297581, 46.034294217824936, 45.86221285164356, 40.61527580022812, 44.93944376707077, 52.161564230918884, 49.45026531815529, 49.259207770228386, 49.12346005439758, 50.201192423701286, 53.64949218928814, 52.825027629733086, 53.85395161807537, 53.220753595232964, 52.21621669828892, 51.54086373746395, 54.114477038383484, 50.49900144338608, 57.56895147264004, 57.12234243750572, 62.076676189899445, 61.82218864560127, 64.86121237277985, 60.55773429572582, 64.92618888616562, 62.525549903512, 67.5559213757515, 65.04796475172043, 79.66101542115211, 69.46303904056549, 88.56831505894661, 49.025421515107155, 0.16445357236079872, 0.13118093978846446, 0.05143811817106325, 0.30077538394834846, 34.66743215918541, 73.3248782157898, 52.62771561741829, 52.54160463809967, 21.759148612618446, 43.36970999836922, 45.0374823063612, 0.513338620075956, 0.026067853650602046, 0.0761428895930294, 0.02048762300546514, 0.034553297446109354, 0.14524722093483433, 0.0923088623676449, 0.05165511473023798, 0.09649516898207366, 0.021100540507177357, 0.04291201395972166, 0.0571843078796519, 0.050520805089036, 0.11610002402449027, 0.048375541882705875, 0.04815975502424408, 0.14502417587209493, 0.37209262896794826, 6.611007805913687, 73.15146312117577, 45.31429745256901, 43.870215341448784, 43.02154988050461, 61.559455543756485, 91.84949979186058, 32.355651408433914, 1.2881663837470114, 1.6117867059074342, 3.5054743476212025, 11.83915201574564, 100.25461077690125, 84.34844389557838, 92.70236402750015, 87.1602626144886, 86.76910400390625, 84.61805462837219, 75.2447783946991, 67.98804938793182, 69.018934071064, 64.8401615023613, 68.10797855257988, 64.39928635954857, 65.0870418548584, 63.65516848862171, 62.23850950598717, 58.78965497016907, 57.59101688861847, 58.10994364321232, 57.23043143749237, 57.38174691796303, 55.950914695858955, 59.69204194843769, 60.33316634595394, 59.18593190610409, 59.25756186246872, 57.65644557774067, 53.67476463317871, 51.42883814871311, 50.073789060115814, 51.863063648343086, 52.28104501962662, 51.88583582639694, 55.81019684672356, 57.352309897542, 51.20523914694786, 51.678636744618416, 48.23862433433533, 52.94602453708649, 53.68885047733784, 51.1748293787241, 52.34198994934559, 51.62732429802418, 49.27141651511192, 50.556366965174675, 49.5229934155941, 50.82201451063156, 57.36618295311928, 60.42818404734135, 62.086897641420364, 64.24141243100166, 62.730431109666824, 63.2982612401247, 57.71309293806553, 62.039092406630516, 55.24368144571781, 60.90591341257095, 61.228873282670975, 61.546703428030014, 51.59066766500473, 45.96289984881878, 58.05239573121071, 52.06626154482365, 59.614792093634605, 54.84325133264065, 54.162457063794136, 63.151919692754745, 62.08226189017296, 58.38722236454487, 58.182314559817314, 53.895399793982506, 48.55196692049503, 49.43298004567623, 51.62710390985012, 54.453437849879265, 45.40060982108116, 46.35996334254742, 40.86997613310814, 40.23885279893875, 55.33752880990505, 63.15637305378914, 56.13333910703659, 57.78591603040695, 60.4743629693985, 60.31755678355694, 57.09323599934578, 59.260062128305435, 51.87590315937996, 61.871661990880966, 61.622338369488716, 61.67328983545303, 50.444375574588776, 47.50009596347809, 48.446381986141205, 47.065855264663696, 49.49978806078434, 51.12410590052605, 51.42058119177818, 48.0038121342659, 47.64650210738182, 45.959681421518326, 46.99583262205124, 55.0705361366272, 51.28692336380482, 49.88146997988224, 48.26453514397144, 47.781109884381294, 44.861559346318245, 47.84992419183254, 54.13502633571625, 49.55637842416763, 51.07040338218212, 50.631348341703415, 51.66271559894085, 55.59481680393219, 54.26732383668423, 57.7264454215765, 55.0011670589447, 54.16308782994747, 53.42833265662193, 55.08950851857662, 52.184818983078, 57.40972861647606, 58.81855621933937, 63.58679495751858, 64.35203209519386, 67.95640468597412, 64.92947190999985, 67.72507309913635, 64.48783680796623, 69.98436346650124, 68.7142588198185, 81.28859728574753, 70.46148106455803, 89.73555162549019, 53.755270913243294, 0.16002281714463606, 0.2811797760659829, 0.09850890506641008, 0.2244674926623702, 38.31338971853256, 79.71662923693657, 62.25048266351223, 53.70898939669132, 27.38346241414547, 56.87358878552914, 55.584728345274925, 1.1542673874646425, 0.06933521348400973, 0.10207736631855369, 0.03756817590328865, 0.051331809227121994, 0.10956958460155874, 0.036526311887428164, 0.09526257301331498, 0.12153885327279568, 0.1872126737725921, 0.37354887113906443, 0.09431157755898312, 0.19702095683896914, 0.22127823176560923, 0.2976274013053626, 0.12582784343976527, 0.3880593425128609, 0.47608865483198315, 7.759787812829018, 85.49644589424133, 52.74245046079159, 51.39402821660042, 60.066515654325485, 67.99046605825424, 99.51297417283058, 38.31271715462208, 1.2339286878705025, 1.603724251035601, 3.610712313093245, 23.49700815975666, 103.04448947310448, 90.06285846233368, 98.29510912299156, 90.63867196440697, 88.69523584842682, 89.4228284060955, 78.77023681998253, 72.95030951499939, 72.64292880892754, 68.55988830327988, 73.35470661520958, 69.03451323509216, 67.8698681294918, 67.22507312893867, 66.73288553953171, 63.261201828718185, 60.48767365515232, 61.62644974887371, 60.69622166454792, 62.61577986180782, 59.4936203956604, 62.034023478627205, 64.86973911523819, 62.901171147823334, 60.45445203781128, 59.80025254189968, 56.30756735801697, 55.54409712553024, 53.309155851602554, 53.67806665599346, 54.686931520700455, 57.432071417570114, 58.19812551140785, 60.07350727915764, 52.24823758006096, 52.97400243580341, 48.06796409189701, 54.53708656132221, 55.062944144010544, 51.4045612514019, 55.578682869672775, 53.70061844587326, 53.794682398438454, 53.196776881814, 50.56897468864918, 54.425311759114265, 61.19820132851601, 63.57864059507847, 66.30449652671814, 67.77693271636963, 65.45836552977562, 66.67556181550026, 62.47232235968113, 64.56960842013359, 61.2793155759573, 64.59901124238968, 68.29648643732071, 66.10310733318329, 57.61994853615761, 46.962584406137466, 53.73946376144886, 54.510119408369064, 59.74105551838875, 57.773467898368835, 53.50891873240471, 65.57362094521523, 64.10309985280037, 61.12858526408672, 58.93173314630985, 59.17057693004608, 49.29855465888977, 48.970719650387764, 52.30883672833443, 54.7560004144907, 45.90797379612923, 47.80314490199089, 46.58605121076107, 45.26095971465111, 55.40905997157097, 65.84017664194107, 64.27476704120636, 60.16442120075226, 63.307935521006584, 62.47645653784275, 58.062313199043274, 62.84729763865471, 55.12564457952976, 64.45898115634918, 66.26419588923454, 62.44458384811878, 54.8837685585022, 50.40051072835922, 51.182527765631676, 49.84604828059673, 52.283100709319115, 52.17413015663624, 54.744977205991745, 48.68169955909252, 47.98042058944702, 46.651981472969055, 48.99377681314945, 58.02588455379009, 54.75819669663906, 52.203677371144295, 52.484961077570915, 49.54231157898903, 47.09146209061146, 50.92253051698208, 58.22138786315918, 52.44235776364803, 52.151403576135635, 52.5186462700367, 55.294929295778275, 57.62384332716465, 57.26059801876545, 59.20410633087158, 59.20509807765484, 57.60335482656956, 57.667221799492836, 58.31775829195976, 55.30722163617611, 62.07808971405029, 62.53382205963135, 67.26071521639824, 67.06809595227242, 72.3897635936737, 69.27519232034683, 70.91682583093643, 69.75806280970573, 75.31857803463936, 72.86067232489586, 85.29482871294022, 75.90519055724144, 92.31031626462936, 56.48288615047932, 0.33785492239985615, 0.5647827533539385, 0.1534433662891388, 0.6006803177297115, 45.877393037080765, 87.7197977900505, 68.20705443620682, 72.20236524939537, 31.145819127559662, 61.031755059957504, 66.82492420077324, 1.009201977867633, 0.21248531062155962, 0.21578869898803532, 0.08573910396080464, 0.13862192019587383, 0.21315975958714262, 0.1949587362469174, 0.20223184284986928, 0.22383834439096972], [0.07763235771562904, 0.027761659148382023, 0.06318704690784216, 0.1592208375222981, 0.09409446225618012, 0.05396501597715542, 0.005609116424238891, 0.19701757264556363, 0.5807284195907414, 9.552413821220398, 68.99807319045067, 38.84640231728554, 33.310661762952805, 35.2451341599226, 61.763732582330704, 91.29456996917725, 18.38045161217451, 0.9308063064236194, 0.8937628660351038, 2.7747151348739862, 9.849232044070959, 89.98195320367813, 86.92082226276398, 81.32977947592735, 84.44360598921776, 85.69805547595024, 85.53219437599182, 74.50942665338516, 65.60861706733704, 63.82041022181511, 66.33823111653328, 62.96521671116352, 63.31862814724445, 60.616270154714584, 59.79193478822708, 55.94750627875328, 54.32416118681431, 54.05619956552982, 55.26583805680275, 54.40693214535713, 54.117205291986465, 53.80268096923828, 53.79594773054123, 55.07999762892723, 56.01556442677975, 56.749514043331146, 54.182333797216415, 51.13094933331013, 46.95925958454609, 46.492629423737526, 48.192787393927574, 49.695564955472946, 49.69135478138924, 51.03298678994179, 53.22016082704067, 48.91401529312134, 53.996029794216156, 54.01548095047474, 52.069217786192894, 49.646942764520645, 49.21395979821682, 49.74739797413349, 53.775193244218826, 47.76262387633324, 47.19643525779247, 48.27515557408333, 43.66455137729645, 50.52550882101059, 52.05803498625755, 56.78724981844425, 57.290753200650215, 59.10594999790192, 57.73680366575718, 59.63846102356911, 58.91940660774708, 54.71565417945385, 56.01297676563263, 58.8871805369854, 59.22601595520973, 52.767358124256134, 50.36995656788349, 61.5935093164444, 53.67304712533951, 55.89607983827591, 53.36137644946575, 48.23534891009331, 49.05585788190365, 45.883499309420586, 53.19463759660721, 51.316899955272675, 44.43292334675789, 43.6902341991663, 44.588825181126595, 46.72157473862171, 62.767167538404465, 46.13284192979336, 54.24190700054169, 40.30043609440327, 44.713534489274025, 50.447480008006096, 44.51455816626549, 53.03981110453606, 56.23321294784546, 56.93001575767994, 57.91969545185566, 58.9911999553442, 54.85845051705837, 55.99367380142212, 57.58616454899311, 56.260803267359734, 55.36400578916073, 45.59722267091274, 46.510507464408875, 48.029164373874664, 43.765565156936646, 46.55073210597038, 47.452321127057076, 46.096113100647926, 46.12235069274902, 44.51649986207485, 45.519980415701866, 42.27238968014717, 49.644738882780075, 49.912293925881386, 46.830165311694145, 47.454688400030136, 45.61076134443283, 43.86943258345127, 40.62594182789326, 50.85671804845333, 49.428781270980835, 47.88379557430744, 52.24025800824165, 49.650449976325035, 52.15775303542614, 52.25928358733654, 52.2257199883461, 50.14828406274319, 52.642599418759346, 50.274851471185684, 51.99945352971554, 58.24449822306633, 64.76865693926811, 65.10435372591019, 62.68241308629513, 66.13460004329681, 65.6102965772152, 59.48652617633343, 66.32326751947403, 59.28319908678532, 62.35316835343838, 63.88153374195099, 78.5044714808464, 74.8592434823513, 82.9083363711834, 60.89275851845741, 0.10631935627316125, 0.15003327192971483, 0.059549951838562265, 0.45054790971335024, 23.17338142544031, 75.48389196395874, 53.48253294825554, 55.24818800389767, 27.697146981954575, 26.95519309490919, 52.61022515594959, 1.2924852082505822, 0.12196008145110682, 0.12361012806650251, 0.09139121902990155, 0.04589550328091718, 0.08088560658507049, 0.0678894727025181, 0.0965930508391466, 0.07644013458047993, 0.05347218910173979, 0.13162245828425512, 0.08592124926508404, 0.06599302563699894, 0.040254405394080095, 0.09512958014965989, 0.08058652849285863, 0.23188537743408233, 0.69143500411883, 14.85694533213973, 74.87578779459, 50.06293684244156, 35.542149022221565, 41.12385950982571, 73.73595535755157, 96.16587057709694, 20.154268629848957, 1.2562958314083517, 1.4395172498188913, 5.340285217389464, 13.905456438660622, 93.38977754116058, 87.36425086855888, 88.41222703456879, 83.92719849944115, 86.77767634391785, 88.13708379864693, 76.00597634911537, 67.01070383191109, 68.57756495475769, 69.2622958123684, 65.92238143086433, 65.87963372468948, 63.820098638534546, 62.05459177494049, 58.792835399508476, 55.35536505281925, 57.36934058368206, 59.5634226500988, 56.853856444358826, 57.25906290113926, 57.43144065141678, 56.9031397998333, 56.437744572758675, 59.96114730834961, 58.19719836115837, 56.17169424891472, 54.396995678544044, 49.83719855546951, 48.876222521066666, 50.66372640430927, 54.32091236114502, 52.656027898192406, 54.78012152016163, 53.82035382091999, 49.01291638612747, 53.65852430462837, 54.37779150903225, 53.012900948524475, 51.591401025652885, 48.56409586966038, 50.248655676841736, 54.59707774221897, 50.36186680197716, 49.945306554436684, 51.413019597530365, 46.74494728446007, 54.57162670791149, 55.48792093992233, 58.92605245113373, 59.92504544556141, 60.27034051716328, 62.28408046066761, 63.616231977939606, 63.819437474012375, 60.63099816441536, 59.55589905381203, 61.18003070354462, 62.94263072311878, 57.73592971265316, 53.7004778534174, 59.774881303310394, 53.81549388170242, 58.464054241776466, 54.354232773184776, 48.8882564753294, 47.24617458879948, 46.569324508309364, 55.35042151808739, 49.63188037276268, 44.84854504466057, 44.262179508805275, 45.049254074692726, 47.473656982183456, 62.23173446953297, 48.96900214254856, 55.260552540421486, 42.95196421444416, 50.41555032134056, 53.456975519657135, 45.432554706931114, 55.97668871283531, 59.65529032051563, 58.077200800180435, 56.41240753233433, 61.1114177852869, 58.67773577570915, 59.41818684339523, 59.13859024643898, 61.276860907673836, 57.20637112855911, 47.965768575668335, 49.29063208401203, 47.870515286922455, 47.4902468919754, 49.22087162733078, 49.877202808856964, 46.85575693845749, 46.83654136955738, 44.14844021201134, 46.77119627594948, 43.44890534877777, 51.886979565024376, 52.65266127884388, 47.93183259665966, 49.15883995592594, 47.783135175704956, 44.66856010258198, 45.424495339393616, 52.810896188020706, 51.07455275952816, 50.16713485121727, 54.004149958491325, 51.633175984025, 54.95246887207031, 54.69373315572739, 54.64784301817417, 53.00456799566746, 55.736655592918396, 53.21155808866024, 54.83503237366676, 60.56438773870468, 68.11081320047379, 67.7712482213974, 65.36570370197296, 68.44552963972092, 68.40038806200027, 62.400202229619026, 68.50656196475029, 62.06996574997902, 64.42854478955269, 65.39629206061363, 80.54110139608383, 77.58042186498642, 84.55820024013519, 64.3440829217434, 0.3092892427230254, 0.199105768406298, 0.0650733636575751, 0.3783447778550908, 26.432223357260227, 83.40428575873375, 64.41595986485481, 59.856474325060844, 31.57533098012209, 35.28073064982891, 64.66980144381523, 3.3703146502375603, 0.27750068285968155, 0.2397894431487657, 0.09042221165145747, 0.030463121220236644, 0.06486912461696193, 0.07901361328549683, 0.022086155295255594, 0.02898738097428577, 0.1377938169753179, 0.1976791676133871, 0.17984331061597914, 0.28343516285531223, 0.21363709412980825, 0.20733634941279888, 0.20836079522268847, 0.49700202012900263, 0.9432420891243964, 15.971768461167812, 88.83816137909889, 52.999746054410934, 41.786745339632034, 51.35994404554367, 79.3028162419796, 106.89309015870094, 22.926107794046402, 1.0832240246236324, 1.663514873944223, 8.536143153905869, 27.259391471743584, 99.12433862686157, 89.68763619661331, 92.27642968297005, 89.66235995292664, 92.72861301898956, 92.48231783509254, 81.76729559898376, 70.92766284942627, 71.94579541683197, 72.68638327717781, 68.92216086387634, 70.68151205778122, 69.38657194375992, 66.84716060757637, 62.10475668311119, 59.84501414000988, 62.58182868361473, 60.50271324813366, 61.16943687200546, 60.64362868666649, 60.191555544734, 58.74189913272858, 58.35058093070984, 60.96748150885105, 62.668502032756805, 59.73468706011772, 57.87271097302437, 52.276310473680496, 52.433698028326035, 52.99675941467285, 56.185187324881554, 54.269379526376724, 56.46224185824394, 55.73824390769005, 50.54896876215935, 53.92963595688343, 56.33134268224239, 53.69775339961052, 52.34914876520634, 51.39186233282089, 51.75010710954666, 58.096982538700104, 53.1237979978323, 54.02512103319168, 54.3769745528698, 49.22585316002369, 56.122262701392174, 56.708404049277306, 61.63576304912567, 62.133813723921776, 64.75262179970741, 65.90785101056099, 66.64574861526489, 65.63697874546051, 60.89669890701771, 63.99165943264961, 64.63577046990395, 68.32221865653992, 59.85417924821377, 58.827941715717316, 61.833854019641876, 50.53380377590656, 60.47603867948055, 55.9567815810442, 50.527518913149834, 50.52599899470806, 47.46541142463684, 60.26639632880688, 53.131530582904816, 45.42478032410145, 45.51003634929657, 45.07226184010506, 47.86085620522499, 65.09361550211906, 48.96498955786228, 55.81813462078571, 52.07125447690487, 50.89990273118019, 58.337312042713165, 50.05050390958786, 57.33699671924114, 61.7511210590601, 61.6164068877697, 60.981624349951744, 62.974138632416725, 62.3206041008234, 61.22016794979572, 63.065713718533516, 62.97095060348511, 60.3781521320343, 51.97321593761444, 50.849209651350975, 53.28585550189018, 49.720860198140144, 51.054003462195396, 52.65908673405647, 49.49035316705704, 48.71646009385586, 45.60367852449417, 47.16317184269428, 44.82057474553585, 51.41564145684242, 56.58732354640961, 50.912168473005295, 51.40839144587517, 51.40912100672722, 49.533982425928116, 47.658254876732826, 55.17385259270668, 52.98756770789623, 51.02743908762932, 56.79728887975216, 54.46243576705456, 57.91456572711468, 58.38658779859543, 56.38017766177654, 55.478782430291176, 59.69584934413433, 55.07562406361103, 56.59832775592804, 63.3105231821537, 71.39587372541428, 69.77285921573639, 69.42567944526672, 71.38607785105705, 72.26853489875793, 67.29795321822166, 71.80924594402313, 65.90959131717682, 67.40304797887802, 68.92728298902512, 85.2652359008789, 82.57182642817497, 89.3907505273819, 68.7469370663166, 0.512471969705075, 0.5149445089045912, 0.16053525527240708, 0.8417742932215333, 32.867461144924164, 91.40646636486053, 69.80837970972061, 74.90307793021202, 40.04174217581749, 38.42520251870155, 80.8041612803936, 4.180702390149236, 0.42412504786625504, 0.4247869842220098, 0.26603165140841156, 0.11912968606338836, 0.13867767032934353, 0.18130902259144932, 0.1359402883099392, 0.19056925928452983], [0.02406320516456617, 0.07677781919483095, 0.010901421137532452, 0.06665932582109235, 0.050899827328976244, 0.10557472240179777, 0.036877700258628465, 0.028402195675880648, 0.32696028356440365, 21.501254551112652, 68.56971457600594, 24.712067060172558, 47.67384923994541, 54.808509796857834, 61.53465427458286, 90.05771353840828, 11.86285324394703, 0.8633383142296225, 0.8505512285046279, 7.12039184756577, 6.2234134040772915, 83.73808264732361, 84.83558535575867, 90.36312595009804, 83.27153608202934, 82.37542256712914, 82.0811815559864, 71.85917526483536, 66.40447676181793, 64.19112592935562, 64.76153612136841, 64.74078923463821, 60.624150931835175, 57.57633447647095, 57.29377403855324, 53.5853136330843, 51.977635100483894, 54.90959957242012, 57.1981255710125, 53.47831517457962, 54.34155285358429, 55.41780710220337, 54.12365734577179, 55.95794811844826, 54.72707636654377, 53.242982402443886, 57.37942524254322, 49.750574603676796, 45.69099023938179, 46.64939381182194, 48.64471614360809, 52.68308624625206, 50.3655906021595, 50.68515345454216, 52.76493385434151, 49.900134578347206, 53.13519358634949, 54.03810493648052, 50.937543511390686, 53.22702705860138, 49.15085278451443, 48.36921572685242, 50.794465988874435, 52.08244487643242, 47.57000081241131, 44.69785273075104, 46.240843534469604, 48.508664444088936, 50.082726180553436, 52.627772614359856, 53.29009607434273, 57.62619160115719, 57.19741880893707, 59.96049374341965, 56.180840358138084, 56.61062389612198, 54.82394456863403, 57.934955433011055, 55.626514703035355, 65.24844199419022, 53.35038743913174, 47.67350725829601, 58.66647318005562, 52.92558163404465, 50.27963921427727, 46.58373333513737, 46.077889278531075, 44.00980465114117, 46.69220611453056, 43.86307932436466, 44.225633069872856, 47.21980020403862, 40.783207789063454, 44.496710523962975, 57.33457624912262, 55.932846665382385, 51.72545403242111, 38.48476052284241, 54.15133886039257, 38.12267415225506, 47.968641221523285, 55.39352260529995, 56.09979070723057, 57.11259216070175, 56.68615624308586, 56.21915750205517, 56.11487589776516, 54.76360000669956, 57.921800538897514, 54.44263122975826, 49.531778544187546, 44.545005932450294, 45.51339536905289, 46.23622678220272, 46.35307431221008, 48.455737084150314, 43.41495417058468, 42.98009030520916, 43.457553684711456, 43.718975856900215, 45.29907166957855, 47.09015876054764, 50.25578789412975, 50.29234953224659, 48.48923608660698, 47.314183339476585, 45.28878182172775, 43.193247467279434, 42.50067003071308, 46.66969612240791, 49.006950706243515, 48.52943032979965, 50.21945424377918, 49.13732931017876, 52.51390032470226, 51.04124754667282, 51.96214333176613, 50.69466434419155, 54.968659803271294, 51.60677880048752, 59.18660067021847, 60.14546021819115, 67.0835155248642, 66.43238246440887, 66.9988864660263, 66.35830163955688, 66.6069146990776, 59.731818214058876, 60.849182456731796, 56.60151578485966, 56.913349851965904, 63.9001527428627, 74.49032887816429, 71.62149801850319, 84.01887997984886, 64.0592198073864, 0.31839483068324625, 0.14199413533788174, 0.07862417129217647, 0.11786709248553962, 18.028427101671696, 75.87036162614822, 57.56113909184933, 50.14758490025997, 39.22656811773777, 30.825342424213886, 56.20586581528187, 5.169133376330137, 0.15355304087279364, 0.15672091307351366, 0.0488920952193439, 0.13774511724477634, 0.06071794756280724, 0.056279076961800456, 0.04886814611381851, 0.07083987336955033, 0.043286138024996035, 0.1238435780396685, 0.031565206809318624, 0.051985537429573014, 0.08945252149715088, 0.14730161929037422, 0.036241000634618104, 0.11202926238183863, 0.3054134506965056, 29.818143770098686, 75.75759887695312, 35.81227272748947, 47.58255533874035, 57.3667149245739, 72.33506172895432, 95.2400578558445, 12.023248337209225, 0.8934048539958894, 0.23097296623745933, 8.771634567528963, 11.33394442498684, 89.67919304966927, 85.93305766582489, 90.29434204101562, 86.30837872624397, 84.89062920212746, 83.66670727729797, 75.03708153963089, 67.5133104622364, 65.815249979496, 65.67326679825783, 67.22588628530502, 63.088789880275726, 60.42963556945324, 58.735329285264015, 56.66157156229019, 52.85043306648731, 57.53765635192394, 58.51915128529072, 55.74176251888275, 55.860779732465744, 59.33079533278942, 58.26266884803772, 59.66204255819321, 55.81684648990631, 56.32828764617443, 57.23832741379738, 53.67384888231754, 48.62558037042618, 49.464951530098915, 51.391581147909164, 53.63127216696739, 52.87809558212757, 55.1595501601696, 56.54957637190819, 49.578075259923935, 54.45142775774002, 52.983110547065735, 51.40654854476452, 55.302509889006615, 50.872346609830856, 49.99386414885521, 53.2628059387207, 54.11013387143612, 50.47986567020416, 48.430783823132515, 48.47765050828457, 51.111885756254196, 54.01543915271759, 52.529243901371956, 55.55005140602589, 60.121388509869576, 60.24551644921303, 62.23934926092625, 61.28261759877205, 58.557506427168846, 59.002986922860146, 59.79625515639782, 60.213347375392914, 67.97658920288086, 57.75716297328472, 52.093331292271614, 59.13372650742531, 53.41963492333889, 50.87034031748772, 48.20545971393585, 48.25084827840328, 44.32662405073643, 50.77761009335518, 46.50386542081833, 42.83905327320099, 46.753812208771706, 41.21841363608837, 48.98509427905083, 57.20846101641655, 57.44996465742588, 50.30842266976833, 44.49061185121536, 56.77318677306175, 44.589923322200775, 50.02078950405121, 56.92060366272926, 59.7199210524559, 59.605007618665695, 58.32736037671566, 57.84033291041851, 58.339645117521286, 55.71446478366852, 59.167381301522255, 55.17324082553387, 50.828842744231224, 46.49102970957756, 46.111057698726654, 49.063890650868416, 48.85259918868542, 50.80393508076668, 44.690690115094185, 44.625785797834396, 44.490630850195885, 43.55206601321697, 46.22866898775101, 47.42930196225643, 50.993856489658356, 52.39402435719967, 50.19991189241409, 48.63412231206894, 47.23528817296028, 44.74441163241863, 44.264649376273155, 49.8136892169714, 52.26059831678867, 51.45306184887886, 52.14815855026245, 52.5728427618742, 53.77398490905762, 52.93635405600071, 54.37442488968372, 53.42947259545326, 55.647155195474625, 52.5868184119463, 64.33476582169533, 63.778430074453354, 68.58191192150116, 70.41105017066002, 68.4453396499157, 68.36862176656723, 68.48656743764877, 62.43750102818012, 64.51343223452568, 58.544229939579964, 59.54484164714813, 67.47636124491692, 75.59437483549118, 74.39351007342339, 88.0933329463005, 66.24531090259552, 0.3943048417568207, 0.15351335081504658, 0.08389516384340823, 0.22480466519482434, 20.61904639005661, 83.41784343123436, 64.76203009486198, 57.80843362212181, 38.50081466138363, 42.79358111321926, 68.52144196629524, 10.774660035967827, 0.27700308768544346, 0.18573697248939425, 0.07414164385409094, 0.08882807844202034, 0.04758452378155198, 0.1288894994650036, 0.03517339522659313, 0.1024365212651901, 0.07817431847797707, 0.3790667391149327, 0.14880215283483267, 0.18182647763751447, 0.20542034675600007, 0.2510558534413576, 0.15685218415455893, 0.2976187033345923, 0.4855224204948172, 32.951421439647675, 87.51813501119614, 36.78070776164532, 60.938158482313156, 73.60853299498558, 76.74344077706337, 104.62972640991211, 14.471157733350992, 1.3553668465465307, 3.8268896006047726, 10.111431274563074, 18.48636142909527, 99.44175839424133, 88.45283165574074, 97.47765138745308, 91.69494688510895, 88.62302452325821, 88.13373997807503, 80.3331309556961, 72.17365399003029, 70.57596132159233, 71.42184913158417, 73.67995396256447, 66.47567734122276, 65.71233630180359, 63.61612558364868, 60.35173214972019, 55.64343899488449, 61.56037129461765, 62.64304339885712, 59.01216723024845, 59.77079652249813, 62.183256670832634, 60.63158333301544, 61.73814855515957, 59.029277712106705, 58.0361820012331, 60.83082564175129, 54.97902564704418, 51.94366492331028, 54.10703703761101, 55.096439346671104, 58.50192300975323, 54.86229971051216, 57.21093848347664, 57.47212886810303, 50.547509640455246, 55.668259263038635, 53.849616050720215, 52.978676185011864, 55.087426230311394, 53.789529874920845, 51.34880304336548, 55.76757833361626, 57.82589368522167, 51.918088495731354, 49.96120110154152, 51.49956755340099, 54.38585847616196, 57.05133564770222, 55.90947411954403, 59.38038647174835, 63.93721595406532, 64.9157926440239, 66.1933296918869, 64.15934443473816, 62.16800428926945, 63.01717512309551, 62.614795714616776, 62.52115733921528, 69.71451714634895, 61.30514279007912, 57.26734645664692, 57.75662340223789, 55.039921179413795, 51.48892432451248, 47.750711515545845, 48.81478361785412, 44.540788158774376, 55.44054888188839, 48.48924748599529, 44.26928512752056, 47.08979777991772, 41.78685553371906, 49.87307243049145, 62.16953940689564, 58.74623849987984, 53.9253193885088, 49.16084244847298, 61.062275022268295, 52.835214883089066, 51.071075946092606, 59.65356141328812, 62.524394765496254, 64.02258217334747, 62.272456884384155, 63.15340541303158, 59.85158018767834, 59.32513363659382, 61.97729632258415, 60.55227778851986, 52.97487258911133, 48.81390206515789, 48.50521042943001, 50.563312992453575, 50.26146098971367, 53.609347343444824, 45.297745540738106, 45.59211954474449, 45.85282355546951, 45.23664101958275, 47.94851370155811, 47.54362642765045, 53.52575562894344, 55.406920686364174, 54.46557059884071, 50.99153481423855, 50.015462189912796, 46.81201368570328, 47.84941501915455, 52.98489265143871, 53.34136672317982, 52.13770531117916, 54.686570540070534, 53.45650054514408, 56.605904549360275, 56.49205885827541, 56.82821162045002, 57.09155648946762, 60.07425203919411, 54.847640097141266, 66.53297826647758, 66.01511925458908, 72.6946060359478, 73.00115838646889, 71.44316598773003, 72.0045630633831, 72.21004083752632, 64.25717398524284, 68.26253145933151, 62.72124320268631, 62.333082631230354, 71.06144607067108, 78.69009152054787, 78.34142982959747, 92.54422411322594, 72.23674580454826, 0.8835525764152408, 0.2696426154579967, 0.32631891954224557, 0.3389520838391036, 25.030771158635616, 89.44624274969101, 70.43027713894844, 70.00111296772957, 53.92338529229164, 43.10329869389534, 81.97435408830643, 11.781285870820284, 0.38613400363828987, 0.3985419706441462, 0.2613689156714827, 0.2917336206883192, 0.1100014329131227, 0.16912150313146412, 0.16765188745921478, 0.1624582489603199], [0.14129721414064988, 0.09887666150461882, 0.06109784182626754, 0.08097670521237887, 0.03490006594802253, 0.04559787608741317, 0.10804071585880592, 0.05574166927544866, 0.24099178175674751, 28.924429826438427, 64.50147807598114, 32.51063369214535, 39.51358951628208, 51.896976828575134, 69.42449390888214, 86.05602666735649, 4.878045246005058, 0.05857632088009268, 1.1174738430418074, 3.6206953274086118, 24.27461363375187, 82.06813305616379, 84.38736900687218, 86.42496407032013, 79.7861959040165, 83.87569606304169, 78.31139624118805, 70.4048565030098, 61.34508244693279, 62.80121751129627, 62.26601243019104, 61.44851669669151, 56.75610288977623, 55.77407978475094, 56.577375680208206, 55.37640072405338, 53.89447644352913, 55.62556095421314, 55.74632987380028, 56.26692473888397, 55.246934071183205, 52.23504848778248, 53.84987823665142, 56.88009403645992, 54.4357156008482, 52.3489473760128, 53.14170263707638, 49.79669272899628, 44.7704516351223, 43.56011398136616, 49.486690163612366, 49.26257058978081, 52.46233709156513, 52.0017372071743, 53.962876573204994, 49.63986374437809, 51.56087726354599, 55.58769218623638, 52.95326694846153, 50.26067443192005, 53.9350126683712, 48.51301521062851, 47.831206396222115, 47.405629232525826, 50.023350566625595, 47.33648054301739, 46.22251711785793, 46.894735246896744, 48.2622666656971, 49.08478192985058, 48.91364671289921, 51.02309212088585, 53.28133374452591, 54.029471799731255, 55.50989896059036, 54.61883917450905, 55.17033398151398, 55.360897555947304, 56.857508048415184, 58.04512292146683, 61.103529408574104, 49.01922404766083, 55.82217380404472, 53.65679159760475, 46.10341630876064, 43.43397215008736, 44.208309799432755, 47.12694078683853, 40.150522738695145, 45.62603272497654, 44.080325067043304, 46.03504657745361, 40.87607480585575, 46.524323523044586, 43.6964962631464, 43.75640004873276, 38.71574632823467, 47.34322138130665, 41.89899891614914, 40.26439122855663, 47.27773189544678, 51.11714467406273, 57.22630485892296, 56.61239840090275, 55.848920568823814, 52.269098460674286, 53.2113528996706, 53.86399067938328, 52.163331136107445, 49.17854569852352, 47.65667036175728, 44.523833468556404, 44.094019532203674, 45.36673083901405, 49.58554945886135, 43.17482225596905, 46.34332783520222, 47.572364285588264, 43.136334121227264, 42.93614946305752, 47.019205167889595, 44.02875043451786, 51.31358653306961, 51.23641647398472, 47.6738378405571, 46.15201950073242, 43.962949365377426, 42.442894130945206, 43.04428406059742, 45.96347741782665, 52.73321695625782, 48.40971775352955, 51.979960575699806, 49.06778544187546, 54.790871143341064, 51.84822924435139, 53.37011978030205, 51.288500279188156, 51.803380250930786, 54.03375796973705, 60.720175579190254, 63.91874134540558, 66.50396302342415, 63.600914999842644, 64.13370341062546, 64.772509932518, 63.138430416584015, 58.94678793847561, 58.24535697698593, 57.287082597613335, 64.09168526530266, 70.51276311278343, 78.52454200387001, 73.22440400719643, 82.80926808714867, 53.67230236530304, 0.32170534366741776, 0.5066663562320173, 0.24760868138400838, 0.09209116076817736, 13.194788172841072, 74.058056473732, 62.19019129872322, 48.544241935014725, 48.25939022004604, 22.41704910993576, 61.41588784754276, 16.7127837985754, 0.41150568751618266, 0.17973899433854967, 0.1301928740576841, 0.07331818647799082, 0.12934773112647235, 0.04456886978005059, 0.012160270580352517, 0.07784997767885216, 0.1224503070989158, 0.054967705727904104, 0.03149951189698186, 0.09000594101962633, 0.03961058486311231, 0.02884488676500041, 0.07033429268631153, 0.057720591212273575, 0.1141313585685566, 37.385145127773285, 70.26780545711517, 40.43763153254986, 39.093210473656654, 59.41606655716896, 75.33632308244705, 91.58639430999756, 5.219340082257986, 0.06546304313815199, 0.08125682143145241, 10.097302682697773, 37.8357857465744, 82.83449113368988, 85.50272315740585, 87.32364624738693, 83.12963649630547, 83.87528568506241, 81.008081138134, 72.4753426015377, 63.775960206985474, 65.83756998181343, 62.506721913814545, 63.33420731127262, 59.385945573449135, 56.70249156653881, 57.226593643426895, 57.68277816474438, 57.25486412644386, 56.532500088214874, 57.925026565790176, 57.05698974430561, 55.67916087806225, 55.04101552069187, 57.69711099565029, 58.355482667684555, 56.575772166252136, 54.97033551335335, 55.68517975509167, 51.09030671417713, 48.535160422325134, 47.20419064164162, 51.89765699207783, 50.287037417292595, 53.48835423588753, 52.975898534059525, 56.14512227475643, 50.46570762991905, 51.944329887628555, 57.31022335588932, 53.83446626365185, 49.47716407477856, 52.07340516149998, 50.22646106779575, 48.34612436592579, 48.65089841187, 51.83773800730705, 49.15007382631302, 49.02343802154064, 48.15108083188534, 51.04790098965168, 52.10529685020447, 49.675559028983116, 52.21801780164242, 56.91947132349014, 57.151114493608475, 56.49140529334545, 58.04328761994839, 58.364134803414345, 57.69536308944225, 58.80475156009197, 62.023106664419174, 63.12706522643566, 52.84592270851135, 59.3164587020874, 54.30996134877205, 48.361813724040985, 44.63498890399933, 46.21680982410908, 47.599350437521935, 44.569275230169296, 48.17295245826244, 43.652905002236366, 47.013801857829094, 42.46274806559086, 47.47222825884819, 48.13460111618042, 47.82738000154495, 41.205159947276115, 50.7237745821476, 43.63803640007973, 46.00109159946442, 48.39622087776661, 54.83349725604057, 60.64660392701626, 57.097837552428246, 58.228406086564064, 56.2778377532959, 57.69529849290848, 53.849855437874794, 52.07399033010006, 49.09042462706566, 48.60635720193386, 47.70639829337597, 47.64539256691933, 47.04955413937569, 49.05097134411335, 45.198563262820244, 48.59819523990154, 47.467326521873474, 44.721122682094574, 44.74647492170334, 47.160857766866684, 44.11450043320656, 50.90456508100033, 55.32389894127846, 50.26923157274723, 48.6791916936636, 47.12851770222187, 45.13214662671089, 45.19502945244312, 48.338593170046806, 53.31321783363819, 51.30247972905636, 54.243259727954865, 50.14574579894543, 55.32533906400204, 52.87678845226765, 53.9793448895216, 53.45588497817516, 54.32427518069744, 57.42248833179474, 62.01256982982159, 65.12512341141701, 68.45771938562393, 66.06901556253433, 65.8727864921093, 67.01128900051117, 65.526784658432, 63.66258189082146, 63.120267391204834, 58.100679740309715, 67.27056428790092, 72.34829261898994, 79.99913647770882, 74.98956128954887, 87.18028753995895, 55.7288584113121, 0.3848893626127392, 0.42268447985406965, 0.17153501190477982, 0.06213522327016108, 13.350372724235058, 80.05950763821602, 69.80270281434059, 58.65346647799015, 46.0590460896492, 26.96964181959629, 71.52059063315392, 22.655085436999798, 0.5495034763589501, 0.1245959525112994, 0.1274077719426714, 0.054469980677822605, 0.03642373965703882, 0.07515955876442604, 0.00592061250245024, 0.10045937306131236, 0.3195089427754283, 0.3725469717755914, 0.21300981607055292, 0.1906595638138242, 0.1132900599623099, 0.12435718133929186, 0.1161952712573111, 0.2401442639529705, 0.4356096050469205, 41.64443537592888, 82.26534247398376, 42.906294465065, 49.57196518778801, 70.84586843848228, 81.1059182882309, 102.9937469959259, 6.359958127140999, 0.2968648000387475, 2.605173932388425, 15.141695402562618, 44.4120092689991, 87.95735344290733, 86.72694906592369, 89.69683930277824, 89.92343634366989, 89.04274240136147, 86.05439275503159, 75.16813650727272, 68.65345448255539, 69.66939836740494, 69.03663352131844, 67.34817892313004, 64.15436670184135, 61.499240174889565, 63.51625174283981, 60.65177544951439, 60.82033060491085, 59.26625959575176, 61.57723858952522, 60.72683282196522, 60.93351513147354, 56.93800672888756, 59.41770426928997, 61.479226648807526, 59.602142572402954, 56.37190170586109, 58.490755409002304, 54.42586652934551, 49.606357142329216, 49.04737673699856, 54.990588426589966, 55.93420699238777, 58.244597017765045, 55.38590021431446, 57.54861496388912, 49.42779712378979, 53.24876569211483, 58.64500433206558, 54.56405371427536, 49.121841341257095, 52.84002922475338, 51.75493285059929, 49.14861470460892, 51.52673229575157, 55.707765743136406, 52.10119687020779, 51.71773284673691, 52.602192386984825, 53.91618847846985, 52.54871405661106, 52.12411344051361, 56.70092225074768, 60.5003497749567, 61.31212301552296, 62.37116798758507, 62.178069949150085, 61.3679002225399, 63.85833218693733, 62.52809576690197, 65.37863060832024, 66.22717067599297, 57.50752776861191, 60.95952853560448, 54.881674870848656, 49.06962454319, 45.28936319053173, 46.69085718691349, 47.946233823895454, 44.65092524886131, 48.72415088117123, 47.003238424658775, 47.8329961001873, 41.257125958800316, 49.29577700793743, 48.545640259981155, 52.87680745124817, 48.91589619219303, 56.064167618751526, 50.02493508160114, 46.645628213882446, 53.93026292324066, 58.05330388247967, 62.90180191397667, 60.814596712589264, 61.48521512746811, 57.828614339232445, 61.884953677654266, 55.29788553714752, 56.25552535057068, 51.28350354731083, 51.570855528116226, 49.810592383146286, 49.47200395166874, 50.57685546576977, 53.1986615806818, 46.74512967467308, 51.293291822075844, 49.087077006697655, 45.046457424759865, 44.03402455151081, 47.409307435154915, 45.141847506165504, 54.19925808906555, 59.9786339700222, 53.50562050938606, 50.98350204527378, 49.3069826066494, 49.06248092651367, 48.24506118893623, 51.965981125831604, 55.980207324028015, 53.69377501308918, 57.0588668435812, 52.13473007082939, 58.09676215052605, 55.86681380867958, 57.307046726346016, 55.66941820085049, 56.83262698352337, 59.6670088917017, 65.96585869789124, 69.59348604083061, 72.01340138912201, 68.69979679584503, 70.43179705739021, 71.10513612627983, 68.27852860093117, 67.09823593497276, 66.1554305255413, 62.09564857184887, 70.52656397223473, 77.89028003811836, 84.25458893179893, 79.43817257881165, 90.5767884850502, 61.58415801823139, 0.6381142465397716, 0.5661104258615524, 0.600910383509472, 0.22960368893109262, 18.806712739169598, 88.27363327145576, 74.88109990954399, 68.32262143492699, 64.41953927278519, 30.48172116279602, 81.53582721948624, 26.103430800139904, 0.8460405736695975, 0.40921619161963463, 0.33712233358528465, 0.18949158664327115, 0.15909513254882768, 0.22885395650519058, 0.20578895666403696, 0.16283333039609715], [0.163029539398849, 0.060025609127478674, 0.05627648686640896, 0.09672071508248337, 0.035209433917771094, 0.12853122025262564, 0.14951026561902836, 0.14143402164336294, 0.31282471551094204, 38.5447783023119, 54.39732626080513, 38.32419253885746, 48.84221434593201, 50.20619295537472, 71.55852019786835, 78.53241518139839, 3.448570976033807, 0.03434367412410211, 0.5801866517867893, 7.891597989946604, 59.02871534228325, 79.0746308863163, 85.50579339265823, 85.6593507528305, 81.95514231920242, 79.4663518667221, 77.28874191641808, 69.51263397932053, 62.483372166752815, 62.353415340185165, 58.96215811371803, 59.064786806702614, 55.15372507274151, 56.861049458384514, 54.295514523983, 54.26664747297764, 53.585621416568756, 52.94787123799324, 52.54185162484646, 53.6442256718874, 53.69393080472946, 54.24786888062954, 53.33438269793987, 52.40021042525768, 53.60192634165287, 51.69509746134281, 52.23164767026901, 50.54672688245773, 45.50895340740681, 45.17821155488491, 48.092689365148544, 48.4504933655262, 50.28135672211647, 50.34499570727348, 53.48911799490452, 49.127689227461815, 47.72703118622303, 50.53294502198696, 56.586738377809525, 52.32823848724365, 48.726833537220955, 47.31147788465023, 47.8776741027832, 46.81064955890179, 49.462789446115494, 47.06377677619457, 43.91582429409027, 46.05643182992935, 46.77611321210861, 44.164011776447296, 47.31319539248943, 48.04527550935745, 51.238084584474564, 50.12371078133583, 53.54856200516224, 52.246288284659386, 49.162050783634186, 52.81040981411934, 54.39219273626804, 56.65468633174896, 62.451480478048325, 54.114477038383484, 50.358013808727264, 50.792433097958565, 42.241394743323326, 43.73403824865818, 43.021796867251396, 49.6172359585762, 44.75445069372654, 44.388663321733475, 44.45278488099575, 44.57597807049751, 48.86987306177616, 43.27438451349735, 49.70680095255375, 45.93447357416153, 31.07985846698284, 41.54844872653484, 45.63701033592224, 49.132860749959946, 52.19701632857323, 53.993035554885864, 54.00118611752987, 53.39498944580555, 55.65701946616173, 52.736583575606346, 50.47291964292526, 49.82627794146538, 48.31881523132324, 47.2876987606287, 44.194151759147644, 45.396984815597534, 45.761902034282684, 45.81308528780937, 43.416109308600426, 42.628837153315544, 41.29495672881603, 43.576833084225655, 47.94724836945534, 47.20736347138882, 44.76896211504936, 44.30424325168133, 49.03667651116848, 51.14086680114269, 48.5357303917408, 45.24526655673981, 44.20598812401295, 43.58829326927662, 42.45125748217106, 43.9708149433136, 52.23997302353382, 48.571364879608154, 50.53220026195049, 49.505639746785164, 51.28406971693039, 49.33040075004101, 52.74788796901703, 52.06088483333588, 52.40676127374172, 55.26075392961502, 60.25159232318401, 60.77627956867218, 62.390425354242325, 62.7304957062006, 64.76098135113716, 62.48482748866081, 61.97422228753567, 58.80385480821133, 60.20878002047539, 59.12253610789776, 70.05269899964333, 71.98636204004288, 75.50725311040878, 74.07054260373116, 79.67188283801079, 46.06338545680046, 0.15380954195279628, 0.18368434044532478, 0.12032009093672968, 0.11875723925186321, 3.7848707428202033, 56.284308806061745, 68.2535107433796, 53.12004379928112, 44.40985478460789, 31.50720063596964, 56.1461216211319, 26.67915690690279, 0.2681617339840159, 0.2025760806282051, 0.14068961783777922, 0.06096964323660359, 0.07176525730756111, 0.018870212334149983, 0.04191313142655417, 0.14225679624360055, 0.05084486758278217, 0.06621564025408588, 0.04877158527961001, 0.09160458648693748, 0.004122765785723459, 0.10421515980851837, 0.1930005053873174, 0.13637866009958088, 0.2808497578371316, 46.512015983462334, 61.32823795080185, 44.367293268442154, 43.05954024195671, 57.55826264619827, 78.34806427359581, 86.48490965366364, 3.0519340094178915, 0.08446499225101434, 0.08624541194876656, 10.829064566642046, 66.54839783906937, 80.35592213273048, 88.45089375972748, 84.86490458250046, 87.99999475479126, 82.1496918797493, 81.09737634658813, 70.87657079100609, 65.60012832283974, 63.10774326324463, 61.22010715305805, 59.41428825259209, 59.157254844903946, 59.38849903643131, 56.951587200164795, 56.60391725599766, 56.97565130889416, 55.64613305032253, 57.74055406451225, 55.134273916482925, 57.29599691927433, 56.580392718315125, 56.55950523912907, 55.478892624378204, 56.44894637167454, 53.506137281656265, 54.12273019552231, 52.10422530770302, 49.04027871787548, 48.51741537451744, 51.088216826319695, 50.92415302991867, 52.950120717287064, 52.73160204291344, 56.98634013533592, 50.83193577826023, 47.713967487215996, 51.140946596860886, 58.369743302464485, 55.3939937800169, 49.28533896803856, 47.42052063345909, 48.197126761078835, 49.00107242166996, 50.561618283391, 49.71074514091015, 46.10102243721485, 48.314494863152504, 48.757250905036926, 47.82574988901615, 51.957553178071976, 52.81973071396351, 52.51250199973583, 53.5414981842041, 56.267749294638634, 55.82102246582508, 51.10461674630642, 55.72636194527149, 57.818753868341446, 59.881059005856514, 62.89012894034386, 59.47151318192482, 53.7407822906971, 50.64562037587166, 42.179404869675636, 44.318655878305435, 41.49402804672718, 49.1640380769968, 46.909193471074104, 46.82462900876999, 45.89003495872021, 44.29698184132576, 48.60259920358658, 43.075047209858894, 51.20391681790352, 48.22115287184715, 37.9694701731205, 45.44082686305046, 49.83825869858265, 55.033016949892044, 56.93650960922241, 57.91092172265053, 57.21383012831211, 56.7772563546896, 57.110707461833954, 56.95926658809185, 51.43284313380718, 51.73298142850399, 51.736424043774605, 49.19950157403946, 46.99063070118427, 47.18994140625, 48.22450049221516, 47.17279672622681, 44.67825338244438, 44.777865037322044, 40.55170141160488, 44.20739784836769, 48.648284152150154, 49.08168509602547, 46.81394398212433, 46.69664807617664, 51.18650995194912, 54.33388106524944, 49.257782846689224, 48.259511813521385, 46.14159666001797, 46.56025059521198, 44.47836510837078, 47.40047670900822, 54.19212967157364, 51.547186598181725, 51.47812530398369, 54.14588235318661, 54.201233983039856, 51.56280755996704, 54.31440711021423, 55.24345725774765, 54.475940242409706, 57.98643887042999, 61.10602967441082, 62.28008687496185, 65.56998074054718, 66.59962669014931, 65.60284897685051, 64.69837591052055, 64.6300707757473, 62.72036924958229, 61.62893481552601, 62.50836722552776, 72.67705857753754, 74.24230098724365, 79.34485718607903, 76.37493655085564, 81.23448058962822, 48.620595037937164, 0.3255729126976803, 0.2670408831909299, 0.11818550352472812, 0.18254566326504573, 3.383062966167927, 59.85708229243755, 74.0694710612297, 64.13122594356537, 42.89513446390629, 30.136112608015537, 67.29559734463692, 33.40559586882591, 0.14982502529164776, 0.1651506419875659, 0.03899554481904488, 0.03800706719630398, 0.03841785706754308, 0.1277539986767806, 0.022992072699707933, 0.12263299417099915, 0.2040306307026185, 0.14491537702269852, 0.21042231819592416, 0.2540110854897648, 0.08275100219179876, 0.25174046983011067, 0.3731010592309758, 0.4262851132079959, 0.3988462808774784, 55.03707133233547, 69.88405644893646, 52.696750313043594, 65.22233739495277, 68.7937581539154, 84.76256087422371, 96.38560518622398, 3.8480271538719535, 0.1395510000293143, 1.2920958478935063, 21.056009642779827, 80.46205043792725, 82.38155543804169, 91.21379390358925, 89.47811543941498, 91.71674251556396, 84.49513122439384, 84.04639050364494, 74.24973338842392, 69.76093545556068, 68.42864334583282, 65.98693236708641, 64.45220232009888, 62.60513663291931, 61.9270858168602, 61.639650240540504, 60.21927885711193, 60.75166828930378, 57.18019813299179, 60.428526028990746, 59.10426668822765, 60.606470480561256, 59.79721650481224, 61.61583311855793, 57.994175255298615, 58.7466336786747, 55.835020914673805, 57.291893139481544, 53.67670252919197, 52.10897505283356, 52.412020191550255, 56.292850747704506, 54.39359486103058, 55.794743075966835, 54.79771837592125, 59.588045328855515, 50.373912155628204, 46.83375991880894, 53.1702771037817, 60.47263406217098, 55.491637140512466, 49.244586154818535, 48.33319365978241, 49.51657555997372, 49.702244997024536, 51.36037342250347, 50.64185477793217, 49.76706571877003, 52.410040497779846, 52.509872540831566, 50.197829604148865, 54.79608066380024, 55.027290657162666, 55.56286431849003, 59.14594665169716, 61.0443589836359, 57.65041530132294, 53.531158939003944, 59.05250586569309, 60.026264414191246, 62.93470814824104, 67.33961418271065, 63.49307298660278, 56.45595319569111, 51.84257514774799, 46.85691587626934, 45.073177590966225, 42.54921242594719, 50.93919262290001, 48.639297634363174, 46.1387088149786, 48.581989109516144, 46.14259220659733, 48.345949575304985, 44.25287760794163, 54.82207126915455, 48.502687364816666, 42.39802993834019, 51.69529505074024, 54.49023127555847, 56.44240692257881, 59.91185635328293, 61.18245877325535, 60.16268089413643, 58.80291245877743, 63.490751311182976, 57.78961703181267, 54.759196043014526, 55.3463177382946, 54.41205807030201, 51.518330946564674, 49.050674960017204, 50.41491575539112, 49.30907629430294, 48.65250572562218, 46.6210625320673, 45.525030344724655, 41.81884601712227, 45.010047778487206, 49.26490366458893, 49.837156757712364, 48.382549211382866, 45.20450994372368, 52.79966399073601, 58.68691608309746, 51.33207634091377, 50.650009140372276, 47.98641286790371, 50.30632138252258, 48.61135393381119, 50.7467595487833, 58.34565259516239, 52.73426949977875, 54.699322655797005, 55.08849777281284, 57.09744617342949, 54.10936251282692, 57.14665353298187, 58.20405699312687, 57.331441417336464, 60.756467431783676, 63.9453399181366, 65.7492247223854, 69.20349016785622, 68.44590201973915, 70.51893398165703, 69.34905275702477, 68.64722281694412, 65.82046329975128, 66.14920645952225, 65.57124987244606, 75.41203781962395, 76.81732401251793, 82.21879497170448, 81.4518441259861, 84.05694633722305, 53.326125741004944, 0.5341645900625736, 0.8273743721656501, 0.4267102153971791, 0.7784478412941098, 7.172516975551844, 71.07248827815056, 80.64481303095818, 72.80987665057182, 60.919170901179314, 42.532212138175964, 79.06687170267105, 37.11586117744446, 0.3570801392197609, 0.5497885204385966, 0.3163037257036194, 0.18198912672232836, 0.26689800492022187, 0.3481155593181029, 0.11608592321863398, 0.23611799406353384], [0.07350555650191382, 0.08632140787085518, 0.014744248819624772, 0.0341618182574166, 0.11303667590254918, 0.025114754207606893, 0.12935032864334062, 0.021146863509784453, 0.04777544498210773, 40.85152432322502, 52.69840322434902, 33.404725715518, 50.678074434399605, 52.768080085515976, 73.61168682575226, 69.65371280908585, 2.153652235865593, 0.10163402213947847, 0.41385636606719345, 1.034012152813375, 27.02364642173052, 95.09254217147827, 75.28703212738037, 90.06559431552887, 78.53706613183022, 81.88124388456345, 70.83246275782585, 67.66904890537262, 60.42857922613621, 60.87516166269779, 57.380990758538246, 59.5313485711813, 56.993939727544785, 57.96523600816727, 56.15400619804859, 57.81364694237709, 57.8282305598259, 57.41151072084904, 55.64825713634491, 54.813278540968895, 52.94533297419548, 52.497720792889595, 54.06784974038601, 53.920497447252274, 53.732460737228394, 53.48186798393726, 49.902878031134605, 50.85028499364853, 47.300960049033165, 45.24452559649944, 46.0557022690773, 48.51659841835499, 48.33943672478199, 52.81779281795025, 51.42950691282749, 53.884859159588814, 47.25552208721638, 47.92642928659916, 54.18964460492134, 53.254567980766296, 48.71159255504608, 50.57896815240383, 48.80475975573063, 51.13644003868103, 53.29426445066929, 56.08931086957455, 51.85582123696804, 48.62964615225792, 52.68239848315716, 47.927633821964264, 48.53957198560238, 48.13822612166405, 47.72402174770832, 47.69206926226616, 45.96893772482872, 48.88946481049061, 48.81448723375797, 50.04348188638687, 53.0852110683918, 53.83537821471691, 56.52653820812702, 57.996671721339226, 49.44323189556599, 47.01675429940224, 45.72442464530468, 48.1459055095911, 44.26004022359848, 38.77136394381523, 40.77163740992546, 43.09018939733505, 46.892223581671715, 43.63356024026871, 53.138776794075966, 47.35958710312843, 43.71646799147129, 51.79173767566681, 41.592818945646286, 45.57744473218918, 43.81017096340656, 52.52028778195381, 51.63218803703785, 53.539913669228554, 51.44903406500816, 52.92080149054527, 50.588961616158485, 50.869542360305786, 47.208450213074684, 45.812230333685875, 44.925084337592125, 45.19990459084511, 43.474189192056656, 45.735945627093315, 47.108944952487946, 46.550758704543114, 43.66329364478588, 44.74818862974644, 43.45111683011055, 42.9362216591835, 50.85176311433315, 47.90148742496967, 46.51156760752201, 46.14253520965576, 48.37228216230869, 49.16705131530762, 47.1766497194767, 46.31970830261707, 44.161815494298935, 43.761020600795746, 41.725321635603905, 44.40524943172932, 50.47412037849426, 50.19626788794994, 50.18123209476471, 50.54519556462765, 49.07145984470844, 51.30670130252838, 50.55933840572834, 51.49576395750046, 50.262521132826805, 51.534453481435776, 56.78273186087608, 57.785737439990044, 60.91664023697376, 63.978344947099686, 60.516369715332985, 62.14654304087162, 59.30546589195728, 58.75338591635227, 60.11297196149826, 61.62348970770836, 69.63045805692673, 71.84983536601067, 78.28874185681343, 72.94137239456177, 79.92739632725716, 47.40375213325024, 0.5451819801237434, 0.4573697014711797, 0.209719845734071, 0.06464412028435618, 1.006814162246883, 38.817957043647766, 76.4842338860035, 49.44635532796383, 51.077300012111664, 33.04278373718262, 47.37121447920799, 40.562124252319336, 0.29369461233727634, 0.13319443096406758, 0.09356902912259102, 0.04966378037352115, 0.10558842244790867, 0.0714350312773604, 0.03551682035322301, 0.02096559022902511, 0.047915157992974855, 0.03416630454012193, 0.027223112265346572, 0.041624539881013334, 0.07039169038762338, 0.04879293315752875, 0.10260295530315489, 0.05136289037181996, 0.11102219024905935, 50.06510652601719, 61.293469816446304, 33.27317297458649, 44.78265278041363, 62.50675991177559, 80.96240758895874, 74.20827761292458, 1.8859175336547196, 0.11042781159630977, 0.10057765655801632, 1.0386020690202713, 28.153168112039566, 97.03129693865776, 76.1636146903038, 88.63787412643433, 78.81779506802559, 84.75953623652458, 74.95934531092644, 71.34253978729248, 64.42725285887718, 64.39692288637161, 60.26705749332905, 61.98803834617138, 59.97440479695797, 61.07267126441002, 58.766757398843765, 60.49763672053814, 60.63941851258278, 60.628463700413704, 58.073359206318855, 56.65244825184345, 55.26722498238087, 55.419714599847794, 55.856968536973, 56.08042314648628, 55.36395639181137, 55.023293271660805, 55.42382597923279, 52.29788191616535, 49.51508603990078, 47.94357776641846, 50.78742116689682, 50.70908457040787, 51.74905076622963, 53.95585834980011, 53.1332328915596, 55.63855245709419, 48.19963462650776, 49.98293213546276, 53.57271730899811, 53.49093049764633, 48.90010803937912, 52.17857591807842, 51.432254165410995, 52.73295857012272, 56.75692364573479, 57.81836248934269, 55.26153288781643, 52.440309673547745, 56.09209232032299, 51.18753969669342, 50.426341742277145, 49.29225839674473, 51.43728889524937, 50.3787948936224, 49.63414125144482, 51.91906124353409, 52.302798852324486, 53.230488672852516, 55.60235179960728, 56.786687448620796, 60.57032682001591, 58.82482968270779, 54.6784807741642, 50.565509274601936, 46.9513788074255, 49.84342262148857, 43.81925627589226, 42.75793142616749, 43.56482572853565, 42.984125688672066, 48.306196108460426, 44.42334786057472, 50.01180298626423, 45.88412247598171, 46.11732356250286, 52.83253602683544, 44.07186672091484, 51.14337846636772, 50.53771376609802, 55.63656896352768, 54.464328065514565, 56.08483470976353, 54.239323139190674, 54.73887853324413, 53.11101168394089, 53.092221692204475, 48.48751097917557, 48.097108528018, 46.3690410554409, 46.14807531237602, 46.393010169267654, 47.63084314763546, 48.141740933060646, 47.12782993912697, 45.0361979752779, 46.88992090523243, 44.82408195734024, 45.403501465916634, 49.957028925418854, 49.36873309314251, 49.72842559218407, 46.92862942814827, 50.930460691452026, 53.53865973651409, 49.16547439992428, 47.96454504132271, 48.311572819948196, 46.61596700549126, 44.06495489180088, 47.11513862013817, 51.50071129202843, 53.18301022052765, 51.47038511931896, 54.16588447988033, 51.495152190327644, 53.66417080163956, 51.29169590771198, 52.422097250819206, 52.75281250476837, 53.92210856080055, 58.80992688238621, 61.55203074216843, 64.10971149802208, 65.77095195651054, 64.29277047514915, 65.03124564886093, 62.28620454668999, 63.599645867943764, 61.89179711043835, 65.26734977960587, 70.90896025300026, 74.1667078435421, 80.57217612862587, 75.56719109416008, 79.05344322323799, 52.64863349497318, 0.49120198760647327, 0.253012451576069, 0.04373656971438322, 0.07266444343258627, 0.8229157864116132, 43.16807001829147, 82.39024937152863, 58.42717722058296, 52.596146911382675, 33.87658439576626, 58.058505803346634, 47.271272242069244, 0.27338868007063866, 0.14415320620173588, 0.0600364259298658, 0.025753624613571446, 0.07443770140525885, 0.04082985185959842, 0.020525233194348402, 0.01723804776702309, 0.19426735147135332, 0.26540694118011743, 0.1470551817328669, 0.1813496625982225, 0.19992126995930448, 0.06676038407022133, 0.20040354720549658, 0.14636272826464847, 0.21559441956924275, 59.790274277329445, 71.03390514850616, 45.011529698967934, 68.43161478638649, 70.10409504175186, 86.4096736907959, 81.66688218712807, 3.56101477984339, 0.27681419625878334, 0.7081771432422101, 2.8527969075366855, 33.3490777015686, 99.76886004209518, 79.97092679142952, 94.68168541789055, 86.04581281542778, 88.4418198466301, 77.54649728536606, 74.45540115237236, 68.50527763366699, 66.36347696185112, 62.59126357734203, 65.15519499778748, 66.36882707476616, 65.27967631816864, 64.36860680580139, 63.56482453644276, 64.68198359012604, 64.48254749178886, 61.08607694506645, 60.481134206056595, 60.922172740101814, 59.24972288310528, 58.19354675710201, 59.89776290953159, 58.20549711585045, 57.33545020222664, 56.178226098418236, 56.77570603787899, 53.684321120381355, 51.04898773133755, 53.45745049417019, 54.35822635889053, 53.54506239295006, 57.12614983320236, 56.021530106663704, 57.69891209900379, 48.752748146653175, 48.99984508752823, 54.98429216444492, 54.981936290860176, 49.491903483867645, 51.82177886366844, 51.275318786501884, 54.91154506802559, 56.100071892142296, 59.311572164297104, 58.17297086119652, 54.79537770152092, 58.16337637603283, 51.75626277923584, 53.21749337017536, 52.60066866874695, 53.047646284103394, 52.50939376652241, 53.061093762516975, 55.365195125341415, 55.98260119557381, 57.30897702276707, 59.26942102611065, 59.38830524682999, 62.36811675131321, 61.80477038025856, 53.40331859886646, 50.35669907927513, 46.283583641052246, 51.227179169654846, 44.54685643315315, 43.10819283127785, 46.01113826036453, 42.63879641890526, 49.94964972138405, 44.58489619195461, 52.790221497416496, 43.81625823676586, 48.36916632950306, 52.98915222287178, 47.76001341640949, 52.39051714539528, 51.45723782479763, 57.64277771115303, 57.475419491529465, 59.39070291817188, 56.21808975934982, 59.8978541046381, 54.52282972633839, 56.31034880876541, 52.66653813421726, 50.5907741189003, 49.589402452111244, 51.79679520428181, 48.25177922844887, 49.443710669875145, 51.69252119958401, 47.67598092556, 44.70829077064991, 47.58567877113819, 45.08471757173538, 44.436795338988304, 51.76183708012104, 49.13216918706894, 49.459848403930664, 48.20492014288902, 52.39422954618931, 55.753591284155846, 52.80072033405304, 51.35074853897095, 51.52106299996376, 48.183166310191154, 46.09058439731598, 49.64693896472454, 54.00400556623936, 55.72669632732868, 55.23754097521305, 57.37948223948479, 54.64145556092262, 56.447297260165215, 54.69197005033493, 54.918008521199226, 56.00648291409016, 56.614625081419945, 62.33920030295849, 64.2597122490406, 66.23942881822586, 69.17006716132164, 67.40317717194557, 69.30322721600533, 63.968997448682785, 68.24148818850517, 65.44039249420166, 68.36922973394394, 73.5981747508049, 77.87714794278145, 82.48740255832672, 78.22412252426147, 81.61240071058273, 55.85918001830578, 0.9993919730186462, 2.3593708220869303, 0.40056678699329495, 0.5709894234314561, 3.3544735377654433, 50.870484709739685, 89.55921828746796, 65.10947585105896, 70.62716737389565, 46.43553748726845, 65.58492913842201, 55.72131961584091, 0.42378357087727636, 0.28909130778629333, 0.2429412552737631, 0.12531847780337557, 0.1420392727595754, 0.14850478910375386, 0.1362335405428894, 0.11982642172370106], [0.04164523466897663, 0.03938368805393111, 0.11048520187614486, 0.04122417718463112, 0.11426345343352295, 0.05085966971819289, 0.14774524548556656, 0.02902715452364646, 0.2888140414142981, 55.47385409474373, 35.79860106110573, 44.78578381240368, 54.0472586452961, 49.54610377550125, 80.15702560544014, 51.04633927345276, 0.2407545765163377, 0.03712757024914026, 0.726026447955519, 1.0217328742146492, 23.428051359951496, 95.25743052363396, 75.5381378531456, 87.9298885166645, 80.09367540478706, 84.41014498472214, 68.99105876684189, 67.0732256770134, 60.25083236396313, 62.076015025377274, 56.120856776833534, 60.337380319833755, 57.981605529785156, 61.51154011487961, 58.83952349424362, 60.669908076524734, 57.86862999200821, 58.54891888797283, 56.91329665482044, 57.263166680932045, 51.23373381793499, 52.94978253543377, 51.86121314764023, 50.15316300094128, 51.893830597400665, 53.09904992580414, 54.19664762914181, 53.08339096605778, 46.91445238888264, 46.04688674211502, 45.6240264326334, 47.59262099862099, 49.66715767979622, 51.555770337581635, 49.41387087106705, 54.35861013829708, 48.95079731941223, 49.23727534711361, 51.75967499613762, 56.81914910674095, 49.750316217541695, 53.37498351931572, 53.648990616202354, 56.10433146357536, 61.451803520321846, 62.81853698194027, 61.35536849498749, 63.06611269712448, 60.07675990462303, 57.596253007650375, 53.30949403345585, 50.15081472694874, 50.40760114789009, 46.17945782840252, 48.8273723423481, 48.66482466459274, 46.91664107143879, 48.04628625512123, 51.739520877599716, 55.79338654875755, 55.505715385079384, 56.65551468729973, 43.66110496222973, 42.63680152595043, 46.47686406970024, 46.86605058610439, 46.4282950758934, 38.765124678611755, 39.065316170454025, 41.52031883597374, 40.31893730163574, 39.34704825282097, 40.45412264764309, 57.33496382832527, 44.7579351067543, 46.8767736107111, 45.47304153442383, 52.59350225329399, 54.98463414609432, 49.99542586505413, 53.19048061966896, 50.477475598454475, 50.43932184576988, 48.933709636330605, 47.139909490942955, 46.46940506994724, 44.91798631846905, 44.01182994246483, 41.902631521224976, 44.24887642264366, 44.25149068236351, 47.24961720407009, 45.67040294408798, 46.67482204735279, 41.48933529853821, 41.652270555496216, 44.2434237152338, 46.38723827898502, 45.78716687858105, 49.46516431868076, 46.48820646107197, 52.347902432084084, 49.949296340346336, 50.23357428610325, 45.513976737856865, 45.358036905527115, 44.72356975078583, 43.86821284890175, 42.56344646215439, 46.55398093163967, 49.02850694954395, 49.59603689610958, 48.10994043946266, 47.72864229977131, 49.633240699768066, 50.8970794826746, 50.97496010363102, 51.29129692912102, 50.64261853694916, 50.158725902438164, 49.01424631476402, 57.442756444215775, 58.87610413134098, 60.769903510808945, 57.78142087161541, 61.04550652205944, 57.902421578764915, 58.97090524435043, 53.4399676322937, 62.12503619492054, 65.1476638019085, 72.30695083737373, 71.50741294026375, 77.49944061040878, 74.44195747375488, 67.19589829444885, 0.9420762641821057, 0.26536098739597946, 0.02328462174773449, 0.20791501679923385, 0.5632419954054058, 30.574593879282475, 77.71738171577454, 53.81795234978199, 41.0844936221838, 17.839178256690502, 44.94534105062485, 38.14472056925297, 0.20048447098815814, 0.042748210835270584, 0.13354983064346015, 0.07694146275753155, 0.030262850814324338, 0.08628778858110309, 0.08075708145042881, 0.0806586652470287, 0.058916376656270586, 0.05345637022401206, 0.07291120011359453, 0.03363482661370654, 0.11627567553659901, 0.019134429894620553, 0.07825237014913, 0.029140632614144124, 0.7758185011334717, 62.145004123449326, 45.43218992650509, 41.00721336901188, 49.19012367725372, 59.83545005321503, 85.5823364853859, 57.94969104230404, 0.3290440561249852, 0.001962804576578492, 0.27142801496665925, 1.5377800958231091, 28.620761521160603, 97.47416317462921, 76.06746464967728, 93.08970764279366, 80.69015979766846, 85.1178190112114, 72.25515961647034, 69.41856622695923, 62.39911928772926, 62.952992767095566, 58.80585730075836, 63.327926248312, 60.451267808675766, 63.86907801032066, 61.43412686884403, 65.19136145710945, 62.07025073468685, 60.58969438076019, 59.89883065223694, 57.3817241191864, 53.15786696970463, 54.79051016271114, 54.42373104393482, 53.22465218603611, 54.52428124845028, 54.89896774291992, 54.993092492222786, 53.760864213109016, 48.41744273900986, 49.137815684080124, 47.56473809480667, 50.65614581108093, 52.37559534609318, 53.1193408370018, 52.985990792512894, 56.11728876829147, 48.934602588415146, 50.125910863280296, 52.80787535011768, 59.54947739839554, 50.49110546708107, 55.20674742758274, 56.26413568854332, 59.64861787855625, 63.1583147495985, 65.70544347167015, 63.15302163362503, 66.69544994831085, 60.90589061379433, 61.17908835411072, 56.33662819862366, 54.588007628917694, 54.25916947424412, 47.29663968086243, 50.412879064679146, 49.95581679046154, 51.30934976041317, 51.215540394186974, 53.79689387977123, 58.00064630806446, 59.8566947132349, 59.84944090247154, 49.13534961640835, 44.62121844291687, 47.39503540098667, 46.55451290309429, 48.15659433603287, 40.241607651114464, 40.337685495615005, 41.49158477783203, 41.73505291342735, 41.6609188914299, 42.97016903758049, 54.35306243598461, 44.6436258405447, 47.7190288156271, 48.35134528577328, 53.17067228257656, 55.655104368925095, 53.41448999941349, 55.7740493863821, 52.43951931595802, 50.60093477368355, 51.40206478536129, 49.23221781849861, 47.654531076550484, 46.03925675153732, 48.33178013563156, 43.815798461437225, 47.34908826649189, 47.24579460918903, 48.94195519387722, 47.57863014936447, 46.89327612519264, 44.48330104351044, 43.36537063121796, 44.58494558930397, 46.40170410275459, 46.81135252118111, 49.9820201843977, 46.43717519938946, 52.46310465037823, 51.60370476543903, 54.26063619554043, 47.07312427461147, 47.40582302212715, 46.3770966231823, 45.66159501671791, 44.99921835958958, 47.401590049266815, 50.33932261168957, 51.815581396222115, 49.960794523358345, 51.34239658713341, 51.99578672647476, 54.752086624503136, 53.50643366575241, 53.82671847939491, 52.2589948028326, 53.52694496512413, 51.93658970296383, 60.05842208862305, 59.945150166749954, 63.51344369351864, 62.144574746489525, 64.32100296020508, 60.47543831169605, 62.45967663824558, 58.421006351709366, 64.94511187076569, 68.26932549476624, 75.22768691182137, 73.65505769848824, 79.5196022093296, 76.71026855707169, 74.60460394620895, 2.278115269728005, 0.32084124628454447, 0.14648135314928368, 0.12151212853495963, 0.8884247462265193, 34.51851814985275, 84.99726668000221, 61.963921040296555, 49.32866044342518, 23.41776341199875, 53.96146684885025, 47.44074694812298, 0.3237785183591768, 0.04939120808558073, 0.051569070128607564, 0.054164586908882484, 0.026022282072517555, 0.05784209934063256, 0.0685217157297302, 0.11006024811649695, 0.1929595388355665, 0.11336952913552523, 0.26780909509398043, 0.12385862137307413, 0.2382749126991257, 0.09058986281161197, 0.43290052853990346, 0.21203478245297447, 1.1612571123987436, 76.31423100829124, 50.790495201945305, 60.96875064074993, 72.55445435643196, 65.82003772258759, 92.85356551408768, 63.259966894984245, 0.9473568527027965, 0.15484697534702718, 0.7583708467427641, 1.750030294060707, 30.659935399889946, 100.89219376444817, 79.09019485116005, 93.44771683216095, 83.86214599013329, 90.88385000824928, 73.82488578557968, 74.11167919635773, 66.07957139611244, 68.39401960372925, 62.77269244194031, 67.78182685375214, 62.759613543748856, 66.75360202789307, 65.05014583468437, 69.20854389667511, 64.27924320101738, 63.47038820385933, 64.92661446332932, 59.69369865953922, 56.23589940369129, 57.57795698940754, 57.11371690034866, 55.40331847965717, 57.31769755482674, 57.13286027312279, 58.61831076443195, 57.111076042056084, 52.391379699110985, 52.381116449832916, 49.71858412027359, 53.48857842385769, 55.47395668923855, 57.11981937289238, 54.719757959246635, 57.35602229833603, 49.58114929497242, 49.51300375163555, 53.7150614708662, 60.246663987636566, 50.51692508161068, 56.53534233570099, 57.11643375456333, 58.29799175262451, 65.80467894673347, 66.70596778392792, 65.62566295266151, 68.52163195610046, 63.96582841873169, 62.50102981925011, 57.253587394952774, 55.45502610504627, 58.181938380002975, 50.603188052773476, 55.31839303672314, 53.91361601650715, 56.605133190751076, 53.56976106762886, 56.738829016685486, 60.63696764409542, 62.32394032180309, 60.515461564064026, 47.31156907975674, 44.94562603533268, 46.49861790239811, 49.07537743449211, 50.83303011953831, 40.90710774064064, 42.36833073198795, 42.51034811139107, 43.0229140073061, 46.01384751498699, 45.939322113990784, 51.11912816762924, 43.631930127739906, 50.579883903265, 50.84360495209694, 57.41925850510597, 59.22188177704811, 55.46598091721535, 60.50612546503544, 55.1005507260561, 52.93097734451294, 51.26565970480442, 54.06157247722149, 52.66784526407719, 47.88999304175377, 50.037113428115845, 47.60964788496494, 52.099745348095894, 50.08936822414398, 52.39724658429623, 47.839258164167404, 48.94607037305832, 44.300090074539185, 43.650074154138565, 45.09454004466534, 47.284529730677605, 50.0877533107996, 50.850881561636925, 47.82208688557148, 54.47286620736122, 52.27452836930752, 56.49860970675945, 49.4940921664238, 49.37647707760334, 50.64272493124008, 48.3201489597559, 47.63313442468643, 51.32109872996807, 53.48323971033096, 54.33523379266262, 52.516533583402634, 52.1054108440876, 54.27770487964153, 57.868196815252304, 56.13439165055752, 55.340173467993736, 57.41307243704796, 55.206356048583984, 54.88861329853535, 63.49149987101555, 62.57263317704201, 66.85424342751503, 64.84381690621376, 69.12820860743523, 63.221155777573586, 65.59613853693008, 60.131480768322945, 69.60967317223549, 71.20240330696106, 79.54799428582191, 78.50251838564873, 83.03409442305565, 78.51850792765617, 79.81649547815323, 2.1574584441259503, 2.0723370742052794, 0.39957978995516896, 0.7010318641550839, 3.0599869647994637, 39.93081092834473, 91.9110032916069, 68.36570352315903, 61.159910783171654, 27.27983247488737, 63.73671971261501, 58.23843374848366, 0.44863643415737897, 0.0805726577527821, 0.20093661703867838, 0.12102423323085532, 0.10706204571761191, 0.16362134279916063, 0.2419961302075535, 0.26330413995310664], [0.029932331635791343, 0.03806060201895889, 0.09681525727501139, 0.061497707283706404, 0.04107242653844878, 0.09568950088578276, 0.07291965317563154, 0.09747274074470624, 0.8318785554729402, 43.114914670586586, 48.76887448132038, 28.456555232405663, 38.89654062688351, 57.745357006788254, 73.09078797698021, 66.30835711956024, 0.6647275434806943, 0.11869724403368309, 0.7517408556304872, 0.09115484499488957, 27.18252919614315, 91.6818755865097, 76.23125106096268, 86.05633065104485, 76.1078716814518, 77.60613888502121, 61.88716135919094, 62.96397037804127, 57.49765209853649, 60.00755421817303, 58.5017292201519, 62.25600376725197, 64.88569065928459, 65.64395517110825, 61.749525144696236, 65.32754614949226, 58.60383354127407, 61.774983778595924, 57.44898431003094, 55.94836503267288, 53.47263067960739, 53.877707943320274, 51.56800948083401, 52.02117316424847, 52.015648260712624, 52.64438532292843, 51.58056780695915, 53.1104227155447, 47.39211715757847, 47.22298823297024, 45.39844013750553, 48.365484327077866, 48.638252690434456, 50.603188052773476, 49.4708526134491, 52.74072155356407, 48.891159519553185, 49.40938711166382, 56.32394827902317, 56.29157781600952, 54.423039481043816, 53.388298004865646, 59.0844963490963, 64.42165195941925, 63.39057348668575, 60.493696331977844, 62.2326236218214, 61.752876564860344, 63.55675756931305, 63.002830892801285, 55.616791024804115, 55.203654393553734, 50.70430442690849, 48.42498533427715, 48.0327133834362, 48.43206815421581, 47.44689121842384, 49.32707592844963, 53.83619137108326, 52.686023488640785, 54.83453080058098, 52.95988619327545, 37.98403099179268, 45.163996517658234, 52.95285277068615, 49.07981559634209, 40.18882468342781, 41.650769636034966, 37.9307996481657, 40.723737180233, 38.84795643389225, 40.0676453858614, 34.973691925406456, 50.05481667816639, 51.384635120630264, 40.92267170548439, 47.776968106627464, 46.181699708104134, 53.63911114633083, 49.662848711013794, 47.74519041180611, 46.07449606060982, 49.217429012060165, 46.043949499726295, 46.10976576805115, 44.274563044309616, 42.342708706855774, 41.452709063887596, 41.2492261826992, 45.166492983698845, 49.072652980685234, 53.740360513329506, 50.623467564582825, 43.26254054903984, 39.42091628909111, 37.93865382671356, 40.52587039768696, 42.186119109392166, 45.14613747596741, 50.89578755199909, 50.102732107043266, 53.07561658322811, 50.01508601009846, 49.392542615532875, 48.20303924381733, 46.15541271865368, 43.96420329809189, 41.92273624241352, 40.472563058137894, 45.80074355006218, 50.71128845214844, 49.64329116046429, 47.11115263402462, 50.060892552137375, 48.79108428955078, 51.188368052244186, 49.34984050691128, 52.53430522978306, 48.540195152163506, 52.0598740875721, 49.566113501787186, 54.45696406066418, 56.07976198196411, 57.870032116770744, 55.81018544733524, 59.57975797355175, 55.989691615104675, 61.24403826892376, 56.12655647099018, 61.00253842771053, 60.899294167757034, 69.2056256532669, 66.67466506361961, 76.26100346446037, 66.43859893083572, 91.60265743732452, 17.887217178940773, 0.897047552280128, 0.08277769724372774, 0.07854885814595036, 0.16617155517451465, 22.702039517462254, 77.92439460754395, 51.43901400268078, 54.06335458159447, 26.991467848420143, 36.783834993839264, 41.12051568925381, 0.6819859205279499, 0.031168502900982276, 0.049251383752562106, 0.05237980709352996, 0.034572381773614325, 0.048669139214325696, 0.1393914531217888, 0.061773114575771615, 0.02384242365224054, 0.01355918462650152, 0.1470479235285893, 0.04079752390680369, 0.03236188007576857, 0.0558331538195489, 0.03335400906507857, 0.13030026282649487, 1.1924331332556903, 54.517855793237686, 58.65228474140167, 43.829656317830086, 47.7832605689764, 64.21183481812477, 79.25013586878777, 72.6692233979702, 1.1628981493413448, 0.08079390681814402, 0.4030723072355613, 0.9175746445544064, 31.156439557671547, 95.60528665781021, 76.535774320364, 90.0054283440113, 78.25914144515991, 80.87198004126549, 65.87834179401398, 65.08135735988617, 59.99062232673168, 65.30195072293282, 59.34508256614208, 63.635044768452644, 65.62377065420151, 66.44006565213203, 64.86876636743546, 69.27295044064522, 62.75332868099213, 64.81464207172394, 60.85789158940315, 58.50148603320122, 56.50046020746231, 56.434237360954285, 53.28736402094364, 53.70034486055374, 52.840561196208, 53.77602159976959, 53.250297009944916, 55.23048475384712, 51.02632574737072, 48.850934877991676, 48.435157388448715, 51.1025420576334, 51.42643287777901, 53.311086148023605, 53.23581598699093, 53.22474718093872, 47.99945376813412, 50.03840535879135, 58.32168348133564, 55.75337469577789, 54.81788769364357, 54.28827591240406, 60.621342882514, 66.32883802056313, 65.05583792924881, 64.466033577919, 64.52189058065414, 63.98086041212082, 65.54051712155342, 65.75094982981682, 58.01142632961273, 56.38723388314247, 55.58309443295002, 50.52282236516476, 50.387108847498894, 53.4358486533165, 52.59318687021732, 52.72521838545799, 57.582326754927635, 57.69379377365112, 57.12295040488243, 55.74960149824619, 44.60482232272625, 46.305861845612526, 54.16146531701088, 51.60232163965702, 43.35531637072563, 43.245015889406204, 39.607714265584946, 40.777496695518494, 39.74863350391388, 41.52892917394638, 38.63359473645687, 51.00719757378101, 48.66533763706684, 43.17381910979748, 51.35731838643551, 50.19877575337887, 54.33938317000866, 53.37706960737705, 49.717223793268204, 48.382059037685394, 50.97754776477814, 49.938216134905815, 47.425061389803886, 47.825126722455025, 45.52684284746647, 44.984391555190086, 44.41909968852997, 47.53348097205162, 52.997739762067795, 56.72458358108997, 52.97377444803715, 45.82908622920513, 40.61458803713322, 38.80930110812187, 41.012054309248924, 42.81487137079239, 46.232149600982666, 51.806062906980515, 51.01249448955059, 54.57710221409798, 53.41553874313831, 50.5961774289608, 49.36684459447861, 48.364446982741356, 47.29980491101742, 44.08521540462971, 44.19406816363335, 48.16280700266361, 52.36287742853165, 52.567720636725426, 50.38889095187187, 51.978056877851486, 51.0711595416069, 53.667830005288124, 51.946336179971695, 55.261187106370926, 50.80379068851471, 54.637727960944176, 51.54712960124016, 56.61596640944481, 57.867193669080734, 60.86510360240936, 57.32653968036175, 62.31025345623493, 59.82990235090256, 64.54908952116966, 59.51702333986759, 63.97331401705742, 62.85069465637207, 71.86840116977692, 70.87817430496216, 81.86934292316437, 69.62490275502205, 98.0125030875206, 22.871025949716568, 0.6769714958500117, 0.02253245322208386, 0.23916648438898847, 0.6837959296535701, 25.132624693214893, 87.47090354561806, 57.562621012330055, 64.24110844731331, 32.94211193919182, 46.30482070147991, 51.589170545339584, 0.939151905477047, 0.03794216267124284, 0.07540800754213706, 0.05017684190534055, 0.06911268050316721, 0.01314968423685059, 0.07701422291575, 0.09176726525765844, 0.11774196638725698, 0.09276350945583545, 0.2099896757863462, 0.134505212190561, 0.1863178366329521, 0.14910560217685997, 0.150118529854808, 0.5071432306431234, 2.2100742207840085, 67.00156912207603, 65.53524300456047, 39.76212278008461, 55.69779887795448, 71.29546031355858, 86.3185241818428, 80.56580007076263, 1.6317762457765639, 0.20084055344341323, 0.9392397757619619, 1.1437919433228672, 33.60265709459782, 95.39751380681992, 81.35320141911507, 91.13192349672318, 80.24579644203186, 83.81359219551086, 68.40592816472054, 69.08302143216133, 63.749525025486946, 67.66793176531792, 63.31378720700741, 65.6144231557846, 69.98350471258163, 71.95145711302757, 69.09178376197815, 71.88727095723152, 66.28533035516739, 68.15689712762833, 63.23914781212807, 63.571443781256676, 58.28200601041317, 59.802433624863625, 56.24681621789932, 56.42300896346569, 56.89211659133434, 57.139916494488716, 56.431037932634354, 57.61200316250324, 54.05684173107147, 52.1722948551178, 50.03178611397743, 53.55074688792229, 54.23078499734402, 56.048447862267494, 54.99989792704582, 54.81863245368004, 49.01332676410675, 49.216528460383415, 59.18391801416874, 58.010461181402206, 56.04941301047802, 57.064969316124916, 62.16346733272076, 67.66571268439293, 66.36595442891121, 65.91419667005539, 67.94983103871346, 66.74081191420555, 67.6611377298832, 69.62645307183266, 59.74493511021137, 61.679551899433136, 56.22165396809578, 54.01504397392273, 53.7230334430933, 55.83750978112221, 54.28892947733402, 55.30697464942932, 59.713560193777084, 59.252276346087456, 59.492545053362846, 57.516974061727524, 42.42045633494854, 47.640460431575775, 56.23485825955868, 53.469408452510834, 42.089904472231865, 43.02639462053776, 39.53371703624725, 42.481842041015625, 38.694387674331665, 42.93631285429001, 40.238503217697144, 56.654937118291855, 47.08468705415726, 44.18280176818371, 52.46146313846111, 51.61283567547798, 57.324214205145836, 56.14157326519489, 54.41611245274544, 50.645274594426155, 53.95845741033554, 52.714947536587715, 51.75115965306759, 52.1825847029686, 48.46989132463932, 47.256308645009995, 46.79067403078079, 50.71941241621971, 56.48103564977646, 57.33673453330994, 54.191681295633316, 45.02208173274994, 41.53996378183365, 38.085618540644646, 40.77671393752098, 42.09603354334831, 47.933740094304085, 52.52459675073624, 53.40165048837662, 56.70427747070789, 56.05011597275734, 53.19450840353966, 52.95300096273422, 52.119914665818214, 50.988445580005646, 46.97360001504421, 46.459331810474396, 51.133597791194916, 57.80067823827267, 53.45224857330322, 51.480686366558075, 54.062872007489204, 53.12955468893051, 55.53065724670887, 54.15418490767479, 59.54901002347469, 53.60187694430351, 57.77676232159138, 53.98078881204128, 59.35860604047775, 61.37113004922867, 63.88929292559624, 61.40167661011219, 66.62880912423134, 62.55544289946556, 68.13102051615715, 63.3172982186079, 66.31039381027222, 67.72071093320847, 76.69559374451637, 74.51741382479668, 83.36537584662437, 73.82273510098457, 100.32144919037819, 22.79218018054962, 1.3838465558364987, 0.18656295316759497, 0.7735281146597117, 2.928958358243108, 29.636298827826977, 95.78985035419464, 64.77519258856773, 77.97876209020615, 38.621249198913574, 53.63344565033913, 63.67821045219898, 1.1375009058974683, 0.12207178209791891, 0.1557157631032169, 0.09849852984189056, 0.18141699023544788, 0.13171104103093967, 0.21761185897048563, 0.21086101653054357], [0.10513976449146867, 0.04049260140163824, 0.047663473451393656, 0.03236560936784372, 0.11117669797386043, 0.07384822092717513, 0.018700232685660012, 0.10305222182068974, 0.8828886807896197, 50.38167893886566, 44.1981453448534, 19.96944274753332, 34.36908356845379, 58.65279771387577, 71.0497123003006, 61.582771092653275, 0.7642966881394386, 0.03347245954500977, 0.2054772843257524, 0.26990839338395745, 35.4296750575304, 91.34755432605743, 78.25366213917732, 89.93158310651779, 77.2517167031765, 70.80682933330536, 57.31669060885906, 62.050058618187904, 57.12111510336399, 64.07052800059319, 60.91082654893398, 64.56234320998192, 64.63200867176056, 66.64829447865486, 61.117011085152626, 63.40362198650837, 57.54515714943409, 60.59645801782608, 55.659785717725754, 55.65145656466484, 55.60799449682236, 54.36372846364975, 49.31985251605511, 52.69823223352432, 53.55630598962307, 54.53066110610962, 52.888989597558975, 52.62066699564457, 48.89638043940067, 45.49030780792236, 43.9811921864748, 46.853309869766235, 49.34126436710358, 48.870674818754196, 48.19119147956371, 53.116532787680626, 47.993518486618996, 56.02723740041256, 57.043033093214035, 53.90334136784077, 60.011076629161835, 58.22489507496357, 60.15239104628563, 63.20089906454086, 61.239121332764626, 57.84398451447487, 60.30888944864273, 56.63613572716713, 61.13155670464039, 60.340629145503044, 60.92311508953571, 55.844402611255646, 52.6045748591423, 52.75551036000252, 51.16289421916008, 50.56116610765457, 52.42077872157097, 51.82133808732033, 54.99639831483364, 57.151551470160484, 53.335575833916664, 46.17457889020443, 34.385278299450874, 50.7799431681633, 58.13224844634533, 41.30563035607338, 43.774122297763824, 38.36749121546745, 39.034127444028854, 40.10173715651035, 42.398884892463684, 41.90260112285614, 38.43737706542015, 32.94050082564354, 52.384768053889275, 52.91671670973301, 43.15237686038017, 53.81680481135845, 51.36959172785282, 50.16257509589195, 45.80673962831497, 47.88158789277077, 44.80211913585663, 45.84711626172066, 45.54377093911171, 45.59638291597366, 44.10579510033131, 47.017259672284126, 44.59021970629692, 53.51173058152199, 57.78331696987152, 61.665032878518105, 57.98749901354313, 54.35216948390007, 48.19336496293545, 40.564233139157295, 40.7314545661211, 41.95468112826347, 44.762198477983475, 54.989832267165184, 53.58593299984932, 54.66152988374233, 48.888176679611206, 45.7613130658865, 46.76683411002159, 44.168924912810326, 42.21915453672409, 41.00570484995842, 42.00799986720085, 47.333759889006615, 48.44254419207573, 48.00151325762272, 47.620849683880806, 49.62226688861847, 48.71476538479328, 49.995995834469795, 48.594372645020485, 52.021678537130356, 51.552753299474716, 49.61339436471462, 48.193524554371834, 51.32090874016285, 51.40298053622246, 56.404275968670845, 54.481993317604065, 58.512786626815796, 54.60405416786671, 62.44715251028538, 58.90233792364597, 62.8548364341259, 59.94497537612915, 66.07552841305733, 66.6857148706913, 76.79331690073013, 67.15226143598557, 82.51941964030266, 48.35480310022831, 0.1482011319603771, 0.0657896845950745, 0.2103206588071771, 0.4257949988823384, 19.16628934442997, 75.84340587258339, 53.65539327263832, 44.253109395504, 30.995352901518345, 42.56276249885559, 43.71144086122513, 2.111006649211049, 0.12262336109415628, 0.11201256405911408, 0.12689684779616073, 0.04382149738376029, 0.07379575108643621, 0.06529928083182313, 0.024135497769748326, 0.019498154615575913, 0.02867910767236026, 0.036991675588069484, 0.04827597535040695, 0.05597606177616399, 0.08173250840627588, 0.0823787112312857, 0.19827766518574208, 1.3647125638090074, 64.17488560080528, 51.163688376545906, 22.62828167527914, 41.831259950995445, 65.24109318852425, 79.96529549360275, 67.89161056280136, 0.7940068782772869, 0.047979364899219945, 0.1355393504491076, 0.3476152627263218, 42.15067461133003, 94.10652548074722, 80.22374242544174, 90.12594267725945, 80.22964730858803, 73.36093068122864, 60.402337834239006, 64.22209426760674, 60.735842138528824, 67.11307793855667, 64.2612473666668, 66.83975100517273, 66.8151967227459, 69.0258876979351, 63.83768409490585, 66.3412557542324, 61.90869100391865, 62.104228511452675, 59.46679763495922, 59.53873157501221, 58.875507563352585, 57.220282182097435, 53.19509357213974, 55.48122949898243, 57.341982051730156, 55.37819802761078, 54.370465502142906, 54.822892025113106, 50.52846126258373, 47.49588578939438, 47.22445495426655, 49.56598810851574, 51.814312264323235, 50.36994896829128, 50.310147777199745, 54.77944515645504, 47.71186240017414, 56.19909457862377, 57.370518520474434, 55.05821339786053, 61.5701899677515, 59.084553346037865, 62.060348466038704, 63.77090647816658, 63.427002131938934, 59.872775450348854, 61.029611974954605, 59.009134992957115, 64.27253276109695, 64.29024741053581, 64.9106477200985, 58.570281341671944, 54.29249748587608, 55.6980686634779, 51.9470239430666, 54.225826263427734, 54.62700113654137, 55.27092598378658, 58.33062440156937, 59.71529670059681, 54.929430708289146, 49.07555602490902, 39.292437583208084, 49.29096646606922, 56.80048070847988, 45.68721704185009, 43.82009983062744, 38.47407549619675, 39.616734981536865, 39.273461401462555, 42.01089531183243, 41.29679583013058, 41.11707307398319, 35.235919654369354, 49.88414503633976, 54.341024681925774, 47.89441600441933, 57.064007967710495, 55.72409726679325, 52.98372231423855, 47.72386975586414, 48.651817962527275, 47.52484403550625, 47.400613501667976, 47.63361319899559, 47.04195074737072, 46.75964489579201, 49.606957510113716, 48.840576633811, 57.13761381804943, 59.98143441975117, 61.944044306874275, 60.3489924967289, 56.9123201072216, 51.769885048270226, 41.34979158639908, 40.41419439017773, 42.77093432843685, 44.409809187054634, 54.610380828380585, 54.38688062131405, 55.83783656358719, 51.38874650001526, 49.265321642160416, 48.021849766373634, 46.291137635707855, 45.976712107658386, 43.74465487897396, 43.562967628240585, 49.48814548552036, 50.978170931339264, 51.19049213826656, 49.10571500658989, 52.11371339857578, 53.336898162961006, 51.42827957868576, 51.40332251787186, 54.189709201455116, 51.77206613123417, 54.22697760164738, 51.00115589797497, 53.75375099480152, 55.87844878435135, 59.31001044809818, 56.81143172085285, 61.4935252815485, 59.816549867391586, 66.10351771116257, 60.92137098312378, 65.64104452729225, 63.719681426882744, 69.78151515126228, 70.01384988427162, 79.59801480174065, 72.91234955191612, 83.8756200671196, 56.40860393643379, 0.06323451467324048, 0.09397946647368371, 0.23116491531254724, 0.5574443971272558, 23.650567419826984, 83.29515561461449, 62.450709119439125, 48.417123556137085, 30.16813538968563, 48.24462041258812, 58.73755596578121, 3.045422821305692, 0.12447408444131725, 0.16074697516160086, 0.031256658912752755, 0.08298779182950966, 0.12473062262870371, 0.06296915977145545, 0.05487167181854602, 0.2029349238728173, 0.19758363836444914, 0.1440023275790736, 0.10640713007887825, 0.21721314755268395, 0.28038885444402695, 0.15059032797580585, 0.6584405433386564, 2.2370121628046036, 75.2323530614376, 57.638932317495346, 27.867355048656464, 49.38411846756935, 76.27781376242638, 85.92412814497948, 75.8674205839634, 1.057874159887433, 0.17481830291217193, 0.20225211832439527, 0.41552643582690507, 42.16773949563503, 94.3288591504097, 82.74936810135841, 95.63019812107086, 83.59405517578125, 77.54891395568848, 64.28808152675629, 68.44621360301971, 64.32415679097176, 71.8189886212349, 68.24591875076294, 70.37856951355934, 71.21214598417282, 72.36886471509933, 68.25802490115166, 69.57112804055214, 64.26285088062286, 64.71835523843765, 64.75753113627434, 61.38963885605335, 61.31379872560501, 60.49417890608311, 53.58617998659611, 60.398769825696945, 59.429533034563065, 59.41578157246113, 55.305070951581, 57.24504925310612, 53.83360370993614, 50.03361761569977, 49.4629680365324, 51.11950434744358, 54.35369700193405, 53.29079143702984, 52.15825840830803, 56.940970569849014, 49.14603464305401, 55.853894501924515, 58.198703080415726, 54.44114550948143, 65.83544209599495, 59.41353589296341, 63.20922061800957, 68.79903987050056, 66.21710121631622, 62.75028504431248, 65.6362795829773, 61.09025292098522, 67.7274289727211, 64.20831620693207, 68.76384615898132, 60.421519204974174, 56.71519048511982, 58.18482242524624, 56.973230838775635, 55.50853103399277, 59.77274961769581, 57.96219237148762, 61.61644868552685, 61.12752892076969, 58.66617299616337, 49.111251309514046, 38.74070718884468, 51.142618507146835, 59.152178317308426, 48.058544397354126, 44.956846833229065, 40.447875782847404, 40.48999272286892, 41.73498831689358, 43.290001675486565, 42.85799525678158, 38.94914500415325, 41.25344015657902, 55.593939051032066, 51.513888984918594, 48.868451938033104, 59.47085201740265, 58.090792670845985, 54.98977907001972, 50.838824808597565, 50.98829358816147, 49.920619279146194, 50.99013268947601, 49.9984847009182, 49.57174099981785, 51.196530014276505, 51.72070048749447, 50.202039778232574, 58.48489612340927, 62.35374212265015, 64.34603601694107, 62.60545201599598, 59.50829140841961, 51.79706498980522, 42.75770723819733, 41.07936009764671, 42.084888741374016, 47.69195906817913, 57.746960520744324, 55.70132128894329, 56.50888055562973, 52.668153047561646, 51.19810312986374, 51.31437689065933, 49.43307504057884, 47.89625130593777, 45.588452741503716, 47.923803627491, 51.90548077225685, 53.56057696044445, 53.10839742422104, 51.65293112397194, 54.39216233789921, 54.431896805763245, 53.90948183834553, 54.760206788778305, 56.929084807634354, 55.06438426673412, 55.6950668245554, 53.56666803359985, 56.09809219837189, 58.09051148593426, 63.09572450816631, 61.96573734283447, 66.27832353115082, 62.318377420306206, 68.9518828690052, 62.49540992081165, 67.52138882875443, 66.67724892497063, 73.41615691781044, 72.31213375926018, 83.69531974196434, 73.82476419210434, 88.25473308563232, 59.12632070481777, 0.35623714851681143, 0.11644477388472296, 0.7137306046206504, 1.348693217150867, 26.067545525729656, 92.66644835472107, 68.65837901830673, 63.54407384991646, 42.956204786896706, 59.06969614326954, 70.34218266606331, 3.2985913613811135, 0.3030701639363542, 0.2226713320123963, 0.27817761059850454, 0.1925515802577138, 0.22899414820130914, 0.1943959211348556, 0.21582941320957616], [0.03324840516143013, 0.032207517069764435, 0.058283558464609087, 0.06758886578609236, 0.12014903331873938, 0.11961816766415723, 0.19490386184770614, 0.18132701225113124, 1.6388410166837275, 49.37208071351051, 44.49233315885067, 44.98855613172054, 37.60231867432594, 60.34680001437664, 72.5985623896122, 67.10962012410164, 0.8887552691157907, 0.14721743005793542, 0.23250321537489071, 0.09097385744098574, 43.00294227898121, 87.41044119000435, 76.03734746575356, 84.15590062737465, 73.35876479744911, 65.7918356359005, 60.36929860711098, 60.420584455132484, 58.82419891655445, 63.30388493835926, 64.10181552171707, 66.5033246576786, 65.03925561904907, 63.902675807476044, 62.58739918470383, 59.6668417006731, 56.82131119072437, 54.16735880076885, 55.09043946862221, 55.074400529265404, 52.553072422742844, 54.62174981832504, 49.70268577337265, 52.3208174854517, 49.74685080349445, 53.58648397028446, 50.85888773202896, 53.95230934023857, 46.83510884642601, 46.50721304118633, 44.34325575828552, 46.49341218173504, 46.78620167076588, 48.895396292209625, 47.928929552435875, 51.320528760552406, 52.392151057720184, 58.23076955974102, 56.77815690636635, 59.52750697731972, 56.80288977921009, 62.68565811216831, 58.796289414167404, 59.42275419831276, 60.49559623003006, 62.77541309595108, 56.70309193432331, 55.39107173681259, 59.258963987231255, 64.65020209550858, 59.8063588142395, 60.653367564082146, 55.18464781343937, 55.291783064603806, 53.34322102367878, 53.138423413038254, 53.07690851390362, 55.24369664490223, 54.84255596995354, 53.909265249967575, 46.50559812784195, 32.48696856200695, 36.63923755288124, 62.67711617052555, 41.90456561744213, 40.63664585351944, 43.56538809835911, 43.985311165452, 40.174336060881615, 41.36231191456318, 39.128343388438225, 44.133431017398834, 39.453256353735924, 31.52169305831194, 30.35461988300085, 53.3928045630455, 52.17713199555874, 50.808631628751755, 56.166803911328316, 51.57840572297573, 48.82331036031246, 44.903980270028114, 47.68302574753761, 49.75168414413929, 48.03501985967159, 47.474796921014786, 49.32354971766472, 51.90857760608196, 54.62413229048252, 57.77049645781517, 58.42485934495926, 56.782294884324074, 57.60112054646015, 56.94253608584404, 57.3620829731226, 49.535851925611496, 41.75393030047417, 41.22711896896362, 47.1962034702301, 51.246086955070496, 49.0996353328228, 51.76099732518196, 48.547714948654175, 47.7995502948761, 45.77756479382515, 44.246923327445984, 43.233764693140984, 40.66124193370342, 41.57404415309429, 46.31741322577, 47.129695639014244, 46.98081582784653, 49.2062272131443, 49.537136256694794, 45.94797804951668, 49.22314390540123, 48.455968871712685, 50.0170961022377, 50.06082035601139, 49.07307095825672, 49.164752438664436, 51.502003222703934, 51.82785473763943, 51.01569391787052, 54.75118987262249, 55.45712739229202, 57.22974747419357, 62.951062470674515, 64.51537013053894, 63.82960572838783, 68.41861188411713, 68.18250015377998, 71.01968631148338, 69.63768526911736, 73.60704347491264, 69.91533637046814, 76.08913868665695, 4.081705352291465, 0.3558050107676536, 0.5996578757185489, 1.0346352006308734, 21.815505288541317, 74.21393930912018, 51.845140010118484, 47.34674759209156, 40.43947443366051, 37.15188704431057, 55.52726402878761, 2.229666681960225, 0.0457213657500688, 0.07020478049525991, 0.08450099383480847, 0.0489740060584154, 0.06076739315176383, 0.06319965599686839, 0.04828203498618677, 0.1109247536805924, 0.10500706848688424, 0.11525140784215182, 0.0702262953564059, 0.07555262243840843, 0.06380386068485677, 0.144858127750922, 0.3779339249012992, 2.80286212451756, 61.464529037475586, 50.75418435037136, 40.69907650351524, 40.90765491127968, 69.1193474829197, 77.68537223339081, 76.00157618522644, 1.091147311963141, 0.12135521625168622, 0.2641319314716384, 0.0640865892637521, 46.32723189890385, 89.99540448188782, 77.48501658439636, 85.46856299042702, 76.58324137330055, 69.54208999872208, 63.863461911678314, 62.2415379434824, 61.37644596397877, 65.44961839914322, 66.40326082706451, 68.87250512838364, 68.99726763367653, 67.0133788883686, 63.21217305958271, 62.75361366569996, 59.60879601538181, 57.699755653738976, 56.40829615294933, 58.38614322245121, 55.383092164993286, 56.25819280743599, 53.06292146444321, 54.321584925055504, 53.039628714323044, 54.99443382024765, 52.07407012581825, 55.066470354795456, 49.511172249913216, 48.71597371995449, 47.16749221086502, 48.534655049443245, 50.77671334147453, 51.30106620490551, 49.013227969408035, 51.23952470719814, 54.57089714705944, 59.837395548820496, 57.32399761676788, 58.157900869846344, 60.23667812347412, 62.91088342666626, 58.62654872238636, 63.39919522404671, 63.67917940020561, 63.55948202311993, 59.96082812547684, 58.363355845212936, 61.15248218178749, 64.40765351057053, 61.88724875450134, 63.38309548795223, 59.831581860780716, 59.08964887261391, 58.48225526511669, 55.56201696395874, 57.11651735007763, 56.62509351968765, 55.283697098493576, 56.8582908064127, 46.03198394179344, 37.40463808178902, 39.71384257078171, 58.276769891381264, 45.84638670086861, 44.145411774516106, 43.09527352452278, 42.567903622984886, 40.62284879386425, 41.30648531019688, 40.59200584888458, 44.25778314471245, 39.50576573610306, 37.15874947607517, 33.627180978655815, 49.368592500686646, 52.301495522260666, 52.85658113658428, 56.999308839440346, 52.89405472576618, 51.857721135020256, 47.78596982359886, 50.25478854775429, 51.01825878024101, 52.80491150915623, 50.192076712846756, 51.34073607623577, 55.8665706217289, 56.415998339653015, 59.327326118946075, 59.676474183797836, 59.342760890722275, 59.74491611123085, 59.767920076847076, 59.22791585326195, 52.33476273715496, 42.85445384681225, 43.07345509529114, 47.314817905426025, 53.847583159804344, 48.77802059054375, 54.084910824894905, 49.66442942619324, 48.66239279508591, 46.80799350142479, 45.844585597515106, 45.15480861067772, 44.09694157540798, 44.23729844391346, 47.63940408825874, 49.22695130109787, 50.30352093279362, 52.027705013751984, 51.75524443387985, 49.280585423111916, 51.97520703077316, 51.02379508316517, 51.64849296212196, 52.8822373598814, 53.44782941043377, 51.67875453829765, 52.303004041314125, 57.01402924954891, 52.7699039876461, 56.454277485609055, 58.859301432967186, 60.31581647694111, 66.36774033308029, 68.22639539837837, 67.86346927285194, 72.40460559725761, 70.5937747657299, 74.91919666528702, 72.48671159148216, 78.35664421319962, 72.94523298740387, 83.95267993211746, 6.362063214182854, 0.6394342007115483, 0.21965445717796683, 1.291272360831499, 26.509501710534096, 81.58445701003075, 59.92381051182747, 56.36986881494522, 33.213462978601456, 40.45812003314495, 72.72397845983505, 3.312179669737816, 0.11331877365591936, 0.0946035236120224, 0.0554339377413271, 0.08390270406380296, 0.10843322292203084, 0.07119869434973225, 0.062498957267962396, 0.20573803049046546, 0.15875797485932708, 0.2230942968162708, 0.2715427806833759, 0.2801594417542219, 0.15091841662069783, 0.3484757384285331, 0.542947759386152, 3.391331322491169, 73.94305944442749, 59.75771762430668, 61.07186570763588, 51.581016182899475, 78.75765189528465, 85.8276817202568, 82.61442974209785, 1.2143188901245594, 0.3589931287569925, 0.27657881670165807, 0.24165391107089818, 47.68479645252228, 92.92477369308472, 78.74588772654533, 89.25168558955193, 79.08315762877464, 71.76713660359383, 66.2865462899208, 68.35042834281921, 65.50478383898735, 68.7774646282196, 71.20928853750229, 71.78903862833977, 73.25341165065765, 71.25493168830872, 67.32407301664352, 65.09353950619698, 62.873603627085686, 60.37590265274048, 59.684001579880714, 63.005695939064026, 60.367976278066635, 60.198813155293465, 55.33668905496597, 57.796209678053856, 55.86369797587395, 57.34372615814209, 54.75576102733612, 59.92679715156555, 50.66062577068806, 53.23615036904812, 50.023548156023026, 52.89425611495972, 52.325677424669266, 53.39113265275955, 52.04837590456009, 54.607002809643745, 54.55017305910587, 61.32514491677284, 58.09095226228237, 60.803159326314926, 61.23494915664196, 67.82401978969574, 61.497473269701004, 63.84697079658508, 65.75734108686447, 67.34186366200447, 62.00133763253689, 60.553877502679825, 64.1471166908741, 67.40565463900566, 65.15516459941864, 65.74705883860588, 62.041835859417915, 60.944382548332214, 60.705702155828476, 58.173628225922585, 60.62534786760807, 58.32864850759506, 60.16235411167145, 59.404872357845306, 48.794192522764206, 36.790233850479126, 37.50142268836498, 61.247283294796944, 52.811040580272675, 45.803722590208054, 44.60561268031597, 44.65307213366032, 43.99316154420376, 41.179442927241325, 41.21231496334076, 45.17796076834202, 40.69411776959896, 39.39241401851177, 42.68355421721935, 54.86856557428837, 53.7027957290411, 56.79195776581764, 59.09683048725128, 57.2505247592926, 53.980044052004814, 51.13126091659069, 50.8668977022171, 53.23532961308956, 55.2657088637352, 51.9910179823637, 53.54769565165043, 57.02771231532097, 61.524056643247604, 61.0715389251709, 61.608925089240074, 63.036421090364456, 61.97361432015896, 62.929308637976646, 62.34817922115326, 53.245254680514336, 43.08804251253605, 43.51546637713909, 46.664543598890305, 55.11414259672165, 51.320543959736824, 53.37937988340855, 50.63551291823387, 51.18655554950237, 51.302304938435555, 50.10733745992184, 49.79521460831165, 46.003113090991974, 46.23848766088486, 50.784191340208054, 51.003477573394775, 51.573769971728325, 54.04675707221031, 53.852720484137535, 51.18508502840996, 54.44820553064346, 53.92608314752579, 54.25524428486824, 55.94144180417061, 54.687600284814835, 55.77822916209698, 56.67333573102951, 58.57531987130642, 54.96588975191116, 60.21448731422424, 62.97767624258995, 63.77713054418564, 69.29505005478859, 70.22324904799461, 69.74426195025444, 74.61117759346962, 73.48719790577888, 77.81157866120338, 75.94090864062309, 79.95803788304329, 76.7620749771595, 85.70348158478737, 5.840708389878273, 0.5564819206483662, 1.398899091873318, 2.1820317255333066, 31.095570623874664, 85.53045406937599, 67.71719992160797, 69.85010147094727, 56.357720866799355, 50.26983194053173, 83.09758141636848, 4.925192166119814, 0.308497222722508, 0.16441766725620255, 0.1537729986011982, 0.2536683913785964, 0.16764783533290029, 0.14754580071894452, 0.1611638840404339], [0.06546322867507115, 0.021082419116282836, 0.05449355870950967, 0.15331147180404514, 0.07787718481267802, 0.10525444857194088, 0.12309020909015089, 0.2724145370302722, 2.083829320035875, 47.638229951262474, 49.741835072636604, 37.620113119482994, 31.53849955648184, 60.50309702754021, 71.19050994515419, 58.86578008532524, 0.6951314338948578, 0.12172065718914382, 0.1705864878022112, 0.09375318564707413, 46.61395311355591, 88.9493890106678, 79.07947182655334, 83.60538616776466, 68.49308028817177, 62.47074544429779, 59.4128443300724, 61.60472631454468, 58.27177315950394, 62.53693029284477, 63.600607216358185, 63.69751341640949, 60.452852323651314, 58.47734972834587, 59.29331794381142, 55.9575529396534, 54.456610679626465, 55.024418011307716, 55.20775817334652, 56.141858249902725, 53.826798275113106, 51.98426194489002, 50.60253068804741, 50.04124000668526, 51.2749882042408, 53.48453924059868, 52.88784205913544, 51.07047937810421, 49.32522922754288, 46.11252062022686, 44.08393107354641, 44.79764297604561, 46.90641961991787, 47.77013227343559, 46.95283032953739, 48.489232286810875, 55.849247351288795, 59.41428065299988, 57.911278903484344, 59.614035934209824, 57.25677542388439, 59.872441068291664, 57.20648132264614, 59.22513820230961, 62.27353982627392, 62.64110550284386, 60.49009792506695, 55.660420283675194, 51.57574966549873, 54.16876092553139, 58.684803396463394, 58.61714042723179, 59.106018394231796, 56.916522681713104, 57.864989787340164, 54.41478252410889, 57.57683604955673, 53.36752071976662, 52.82198019325733, 44.3174247443676, 39.75267268717289, 34.91546764969826, 46.76007427275181, 42.43344023823738, 32.38345071673393, 47.06958666443825, 39.602516144514084, 41.7065354436636, 38.27177815139294, 39.84875813126564, 39.54418547451496, 42.03116722404957, 37.16466195881367, 37.125128880143166, 28.960803374648094, 33.5535903275013, 49.81205150485039, 48.088342398405075, 55.143036246299744, 56.34817957878113, 51.34656496345997, 51.67198330163956, 52.879231721162796, 55.11622868478298, 51.37785628437996, 52.38094925880432, 53.44777621328831, 54.53470788896084, 54.96876999735832, 58.73929247260094, 55.631462037563324, 56.09899275004864, 54.73328523337841, 55.688170194625854, 54.24557000398636, 53.18783216178417, 47.62023411691189, 42.78459079563618, 45.25058627128601, 54.20064501464367, 41.596189364790916, 47.50948525965214, 47.489125952124596, 49.19200077652931, 44.113143905997276, 44.18839506804943, 42.22574718296528, 41.018829345703125, 41.485155522823334, 45.52227929234505, 47.32700765132904, 47.288728505373, 47.54642687737942, 49.16966937482357, 47.68260397017002, 49.46490213274956, 51.372175589203835, 49.59689944982529, 51.09998099505901, 48.900609612464905, 48.844038248062134, 48.72088685631752, 52.113132029771805, 48.75860743224621, 54.21749331057072, 56.773076578974724, 59.02203530073166, 63.4171948581934, 71.75173223018646, 72.0890249311924, 75.87644889950752, 71.17314487695694, 74.98681023716927, 74.29349184036255, 78.52185934782028, 70.60009762644768, 82.13869526982307, 26.433087810873985, 0.7830081309657544, 0.6680071237497032, 0.8902284025680274, 25.15022534877062, 74.04114738106728, 52.6409313082695, 40.156841799616814, 34.49064664542675, 41.13972365856171, 56.070779263973236, 4.600677704438567, 0.26303043588995934, 0.08765760765527375, 0.10871064514503814, 0.03179200713930186, 0.06462625678977929, 0.098066859645769, 0.06718717093463056, 0.11490990858874284, 0.05485736321134027, 0.10240350311505608, 0.12207263556774706, 0.16135115758515894, 0.10473590256879106, 0.10034971332061104, 0.36716019676532596, 3.061244934797287, 58.586909249424934, 58.77026081085205, 39.43654105067253, 35.56811682879925, 68.32213506102562, 77.87897944450378, 66.06625691056252, 0.40760166419204324, 0.02599613620986929, 0.11798179140896536, 0.05066353864094708, 51.52154937386513, 92.66869783401489, 82.95758172869682, 86.86949461698532, 72.84490317106247, 65.31650394201279, 62.582869827747345, 65.02720266580582, 62.14088514447212, 67.27159023284912, 64.93651673197746, 67.74173900485039, 64.48213711380959, 64.2543925344944, 60.53980305790901, 58.22453789412975, 59.88922476768494, 59.384402856230736, 54.954083785414696, 58.48274163901806, 56.177162155508995, 53.062233701348305, 52.33626365661621, 53.610282093286514, 53.2875844091177, 57.39818103611469, 55.747177228331566, 53.189139291644096, 53.767791241407394, 49.32191580533981, 47.73520074784756, 47.49218478798866, 49.23165164887905, 48.988255709409714, 48.72478924691677, 51.64061978459358, 57.37476669251919, 58.774045407772064, 57.012239545583725, 60.93769110739231, 59.91399563848972, 63.43832552433014, 59.188048392534256, 61.99338085949421, 64.88091051578522, 64.54958349466324, 62.55145691335201, 57.49971158802509, 53.14586341381073, 55.037124529480934, 62.31748826801777, 60.8798012137413, 62.088862136006355, 59.327823892235756, 59.09084960818291, 58.27964633703232, 58.04700382053852, 54.940001741051674, 52.88328990340233, 44.24846224486828, 42.32220880687237, 37.97522306442261, 45.583205223083496, 43.97665522992611, 38.49122777581215, 45.446275770664215, 41.03253521025181, 43.58326233923435, 39.57804545760155, 41.69746533036232, 39.37778480350971, 42.71589048206806, 37.35678344964981, 37.495627999305725, 35.834193751215935, 33.53934869170189, 48.162278831005096, 51.03699557483196, 57.70686127245426, 58.899750262498856, 54.76470194756985, 54.29559051990509, 54.67648588120937, 59.062902107834816, 55.061762407422066, 53.94140772521496, 56.10414907336235, 58.11768002808094, 57.42419824004173, 60.43417252600193, 57.956488877534866, 58.515450283885, 56.96904346346855, 58.2461853325367, 56.48161321878433, 56.141850650310516, 48.382420018315315, 43.65016154944897, 46.994388699531555, 53.745744824409485, 43.40770035982132, 47.204205840826035, 51.12694054841995, 48.99378061294556, 48.30407962203026, 45.44068247079849, 44.322695061564445, 44.97105427086353, 44.16740879416466, 48.14454138278961, 48.61006200313568, 48.94820585846901, 50.38611330091953, 51.48566409945488, 50.46190783381462, 51.45624227821827, 54.355946481227875, 51.704490557312965, 54.43895682692528, 53.94154451787472, 52.94772304594517, 51.97317034006119, 53.719017058610916, 51.542581245303154, 55.11618688702583, 58.01905632019043, 63.43553267419338, 65.27748003602028, 74.3212379515171, 76.51913121342659, 80.4300257563591, 75.8948703110218, 78.8166019320488, 75.24136617779732, 81.25914126634598, 75.05650609731674, 85.17899572849274, 32.67738774418831, 1.2606520601548254, 0.5197884771041572, 0.874734140234068, 29.988213144242764, 79.0263506770134, 60.86467802524567, 49.02780018746853, 37.11499102413654, 46.19168937206268, 69.47448402643204, 6.8201409839093685, 0.27780588367022574, 0.15254501136951149, 0.1515674396068789, 0.04747022932861, 0.034069699177052826, 0.037795933603774756, 0.04167964063526597, 0.3370256465859711, 0.1254679315024987, 0.16371856414480135, 0.2067233799607493, 0.20479281636653468, 0.12480988400056958, 0.31882414827123284, 0.5635360640008003, 4.716197680681944, 70.43026193976402, 65.68000003695488, 49.248591139912605, 45.30258268117905, 78.85366514325142, 84.09711018204689, 75.70392295718193, 0.5836232111323625, 0.26069296756759286, 0.24087443336611614, 0.18325906014069915, 52.86492168903351, 95.90885236859322, 84.9476109445095, 91.88695818185806, 75.20978227257729, 70.1933142542839, 64.15147125720978, 69.38983976840973, 65.48016875982285, 71.9206939637661, 68.62552598118782, 72.55828455090523, 67.73096278309822, 67.03024998307228, 64.90269854664803, 62.97368265688419, 62.042736411094666, 61.36604592204094, 58.10185007750988, 64.6855553984642, 61.088128834962845, 56.390615701675415, 55.12163579463959, 55.80233506858349, 55.954687893390656, 60.54096579551697, 58.25647138059139, 56.93712517619133, 54.84568700194359, 52.81351424753666, 51.23694844543934, 50.9703965485096, 52.340914607048035, 52.65809878706932, 48.87233152985573, 53.00750143826008, 62.09546618163586, 61.248544827103615, 57.900312691926956, 62.95376792550087, 60.88403798639774, 65.28433486819267, 60.806750133633614, 63.04543800652027, 68.94470125436783, 66.77709996700287, 64.31916385889053, 57.66166269779205, 55.05229711532593, 62.307057827711105, 65.92910706996918, 64.37486127018929, 65.41575461626053, 62.81443700194359, 64.87928420305252, 61.77873037755489, 62.38073207437992, 59.77100171148777, 54.65248256921768, 46.93659000098705, 43.97159770131111, 36.87202446162701, 50.09724900126457, 52.879873886704445, 42.226514741778374, 46.99260659515858, 41.405158415436745, 44.091815650463104, 40.81302098929882, 42.08109274506569, 40.934698060154915, 44.63979944586754, 37.33977936208248, 40.652848184108734, 38.51303480565548, 42.041042894124985, 53.64429406821728, 53.32930617034435, 60.16182214021683, 61.04449577629566, 60.13757564127445, 55.911469012498856, 58.609024062752724, 61.372148394584656, 57.45831660926342, 55.25055527687073, 58.69934901595116, 61.62739209830761, 58.174050003290176, 63.216850608587265, 59.894077107310295, 60.43609142303467, 58.726711347699165, 60.524052903056145, 59.54701513051987, 58.245531767606735, 48.96818898618221, 44.39546875655651, 46.848370134830475, 57.0624690502882, 43.416109308600426, 49.1868444532156, 52.026162296533585, 54.67284947633743, 50.02794452011585, 47.48781122267246, 48.76351296901703, 46.9299403578043, 45.67443832755089, 51.83646507561207, 51.60340078175068, 51.88522405922413, 54.41437594592571, 54.148306623101234, 52.82000049948692, 53.046559542417526, 56.73450484871864, 54.11082163453102, 55.63612438738346, 54.99478720128536, 53.613549917936325, 54.498233646154404, 56.06902755796909, 53.7156618386507, 58.4653689712286, 62.75220774114132, 66.31979450583458, 69.18111696839333, 78.09220880270004, 79.5949749648571, 81.63614943623543, 78.90121579170227, 80.48611834645271, 79.74550768733025, 84.41579148173332, 77.62400552630424, 88.49770724773407, 32.99315460026264, 1.4017142658121884, 1.7939834855496883, 1.5980125637724996, 33.54575514793396, 87.11283355951309, 69.16804566979408, 58.647561594843864, 48.695397824048996, 57.07251191139221, 83.82246851921082, 8.471724260598421, 0.3925009479280561, 0.34481733629945666, 0.2334151219110936, 0.1416946787503548, 0.1606167876161635, 0.14650149503722787, 0.271786205121316], [0.04613282726495527, 0.038160391195560805, 0.0357453573087696, 0.02960909292596625, 0.10767396131996065, 0.10510350315598771, 0.15416652982821688, 0.030427284764300566, 1.0812839912250638, 45.08675426244736, 49.0550447255373, 34.860317409038544, 46.79245613515377, 54.17089641094208, 82.13150605559349, 35.85374370217323, 0.19288780284114182, 0.3663514042273164, 0.1456863497151062, 0.09329797452664934, 49.94717225432396, 91.61524996161461, 75.6466980278492, 76.38532519340515, 65.38730934262276, 65.06203919649124, 62.03837424516678, 62.30203069746494, 59.36421073973179, 59.641975834965706, 58.79424512386322, 61.749027371406555, 59.40905973315239, 55.27533374726772, 56.36537365615368, 57.55903780460358, 54.68537740409374, 58.56885641813278, 56.21761478483677, 58.28947260975838, 56.21856853365898, 57.614055052399635, 54.61841739714146, 54.80741925537586, 51.77306927740574, 51.13816134631634, 51.355711072683334, 50.83154059946537, 50.221540331840515, 44.53877806663513, 42.89587542414665, 45.02360165119171, 45.14085955917835, 44.245012030005455, 48.632085621356964, 46.11016474664211, 51.65980875492096, 62.69089423120022, 65.44663935899734, 64.45485457777977, 62.52458095550537, 58.866863027215004, 53.43938246369362, 58.258454874157906, 62.06847243010998, 60.936186388134956, 62.54717834293842, 45.12124501168728, 36.87819913029671, 49.57366369664669, 52.42805913090706, 54.8655941337347, 52.38784208893776, 55.00817768275738, 56.08629763126373, 53.21951866149902, 51.97745271027088, 52.453206181526184, 43.644363060593605, 39.54666294157505, 44.78879325091839, 35.49267187714577, 30.762590691447258, 30.106250010430813, 40.91057315468788, 41.08564496040344, 40.63596189022064, 41.012559682130814, 40.74619397521019, 39.87769737839699, 40.109234154224396, 40.48286430537701, 44.652589559555054, 37.700197622179985, 35.225888192653656, 27.02000241726637, 36.039356142282486, 49.30249884724617, 49.93123970925808, 56.55322037637234, 53.107983246445656, 55.97735367715359, 51.65939077734947, 54.08565178513527, 54.43855784833431, 58.22057470679283, 54.552027359604836, 56.84996925294399, 55.401794761419296, 58.13477151095867, 56.269337609410286, 56.42887204885483, 56.48247957229614, 57.36408546566963, 52.700618505477905, 54.304485842585564, 49.79321211576462, 45.60582920908928, 52.06204757094383, 46.84875771403313, 42.31559716165066, 47.19845674932003, 45.804657340049744, 46.95479102432728, 46.02169789373875, 43.99557821452618, 42.43207611143589, 43.32498259842396, 43.76868098974228, 47.51333445310593, 46.04800768196583, 47.53681719303131, 46.74876227974892, 49.02965448796749, 47.68663175404072, 53.45054246485233, 53.02111990749836, 54.1474212706089, 52.036186158657074, 54.01963032782078, 51.96502737700939, 50.15405595302582, 51.78779348731041, 50.86674951016903, 49.47622932493687, 52.126465514302254, 57.71790727972984, 63.818973898887634, 67.7263194322586, 72.8690242767334, 74.55561697483063, 76.6581429541111, 76.05357259511948, 76.30818173289299, 73.74893546104431, 73.3441735804081, 74.32082757353783, 53.020644932985306, 0.15559807332465425, 0.08238379494287074, 0.32960598065983504, 28.41697085648775, 74.35393899679184, 52.623775228857994, 41.654972210526466, 31.607511453330517, 27.68994066864252, 67.71071746945381, 7.662922460585833, 0.39142783207353204, 0.045539962593466043, 0.11242371387197636, 0.06031693548720796, 0.17415146838175133, 0.049427892445237376, 0.07481142471078783, 0.020270784152671695, 0.027443923463579267, 0.12432146177161485, 0.006802931466154405, 0.10564036536379717, 0.0693101882643532, 0.03742874490853865, 0.13396694732364267, 1.9347113091498613, 56.884083822369576, 53.81364718079567, 34.08487781882286, 55.91369949281216, 62.070292532444, 89.14789035916328, 37.89783261716366, 0.3687537956284359, 0.5146425438579172, 0.10058501124149188, 0.6983885122463107, 54.254218339920044, 94.31363716721535, 78.65534618496895, 81.65520921349525, 68.40085923671722, 68.88813748955727, 62.80478551983833, 64.24602538347244, 62.97186255455017, 63.10615874826908, 62.553079426288605, 63.8787978887558, 61.0203442722559, 58.32033455371857, 58.72883923351765, 59.93391416966915, 59.36314679682255, 60.3666577488184, 58.0740849673748, 61.13974906504154, 59.56362783908844, 59.800195544958115, 58.15576158463955, 57.22248986363411, 54.63203586637974, 54.29149433970451, 55.785585567355156, 52.18606151640415, 50.55792108178139, 48.73708538711071, 44.859116077423096, 47.943019196391106, 47.99348048865795, 47.57575750350952, 50.85178591310978, 48.57205644249916, 53.286782652139664, 63.65727357566357, 67.0038489997387, 67.12616443634033, 63.88407960534096, 61.540160179138184, 56.1667051166296, 60.23052245378494, 63.943971991539, 65.02322047948837, 63.88705864548683, 47.59380653500557, 37.874410673975945, 51.77784562110901, 53.4892737865448, 56.15399859845638, 55.37219434976578, 55.83020277321339, 58.545852452516556, 53.634023219347, 53.833546712994576, 54.466455951333046, 43.61969478428364, 43.27902026474476, 43.10402065515518, 34.507954716682434, 34.990772008895874, 37.88782775402069, 44.199897050857544, 42.68931470811367, 41.14470899105072, 41.1680131405592, 41.58909894526005, 40.965799391269684, 40.52464306354523, 40.23365467786789, 45.68783640861511, 39.34856437146664, 37.75419272482395, 29.47234522551298, 32.92371712625027, 48.66265878081322, 53.681756258010864, 59.56163674592972, 54.868759363889694, 57.83304490149021, 55.22996038198471, 58.36545713245869, 55.952715799212456, 61.6992462426424, 58.26524131000042, 59.55116830766201, 58.4805491566658, 60.9614360332489, 58.683131486177444, 58.91793228685856, 58.089633733034134, 58.15969057381153, 55.09654954075813, 56.07204079627991, 51.58668167889118, 47.22301483154297, 52.94592574238777, 47.77490481734276, 43.24967063963413, 48.719914108514786, 48.542296439409256, 48.517981544137, 47.84704014658928, 47.93986916542053, 43.765838742256165, 46.3598607480526, 44.9031975120306, 50.514854192733765, 46.07793107628822, 48.7918746471405, 49.8040035367012, 51.41450151801109, 50.55614277720451, 55.29206804931164, 56.09266608953476, 57.99864761531353, 56.75748981535435, 55.27817979454994, 53.89694631099701, 53.20626117289066, 52.58260443806648, 55.695519000291824, 52.41547420620918, 56.693782433867455, 59.75228391587734, 67.92357444763184, 71.88894286751747, 77.10247591137886, 76.05397537350655, 77.3820649087429, 78.4441839158535, 79.29877325892448, 75.94584837555885, 80.08276239037514, 74.45678427815437, 62.066652327775955, 0.20113606180530041, 0.3522264934144914, 0.6081573665142059, 33.942206874489784, 81.62534281611443, 59.92952160537243, 47.289879843592644, 37.19715781509876, 36.77860647439957, 78.14408361911774, 10.894637648016214, 0.4775702487677336, 0.1311493242974393, 0.20119948574574664, 0.07261511287651956, 0.17381658166414127, 0.032993547938531265, 0.06974704607273452, 0.10644580339430831, 0.13504772214218974, 0.2322492079110816, 0.10936461083474569, 0.1981889340095222, 0.18603819538839161, 0.2654881024500355, 0.24908108753152192, 2.851829621940851, 70.0003682076931, 63.558022901415825, 45.308213979005814, 64.57813516259193, 71.47930204868317, 95.30143976211548, 45.99053576588631, 0.8033845375757664, 0.6769027432892472, 0.3104244318092242, 1.2145379721187055, 55.61172589659691, 98.22295859456062, 80.247802734375, 86.20615661144257, 71.28187224268913, 73.9369797706604, 66.9566023349762, 68.24139699339867, 64.57169830799103, 67.4304673075676, 64.08064305782318, 68.67287904024124, 66.04382291436195, 62.14416056871414, 62.43402421474457, 63.88693705201149, 61.092528998851776, 64.51308265328407, 60.39884962141514, 64.77328509092331, 61.74911096692085, 63.72907072305679, 60.33488765358925, 59.94883596897125, 57.46785789728165, 56.20376452803612, 57.34464570879936, 54.82621684670448, 53.46885748207569, 50.111357644200325, 47.348457500338554, 51.58543914556503, 50.900009125471115, 49.898702055215836, 53.703323900699615, 50.7771161198616, 57.09770455956459, 66.972895860672, 70.4130944609642, 69.90142151713371, 66.34177252650261, 63.23649175465107, 57.03640624880791, 64.21616658568382, 66.49532988667488, 65.52355483174324, 67.3238754272461, 49.042794182896614, 38.78722429275513, 52.336062267422676, 57.740949243307114, 59.07055489718914, 57.568366304039955, 60.453315898776054, 64.33256193995476, 57.86967873573303, 55.858499854803085, 56.75520993769169, 45.317527279257774, 45.5818372964859, 46.85489058494568, 40.68669676780701, 41.546434834599495, 39.73622336983681, 44.10578370094299, 43.24479550123215, 41.76387436687946, 41.847561076283455, 44.25567805767059, 41.941613629460335, 42.57110685110092, 41.642098501324654, 48.30896236002445, 38.853268548846245, 40.038033574819565, 34.98923309147358, 40.742587968707085, 54.08932238817215, 58.60501907765865, 60.412996262311935, 58.41428451240063, 60.028304904699326, 56.065881326794624, 60.145133435726166, 58.966653272509575, 65.41861966252327, 60.44221289455891, 63.59501771628857, 61.783423125743866, 63.40574607253075, 62.195932790637016, 61.47020973265171, 58.696027994155884, 62.385607212781906, 56.86153583228588, 57.883889973163605, 53.03023561835289, 47.27113924920559, 53.60404662787914, 49.109845384955406, 43.56107532978058, 50.113732516765594, 50.927337259054184, 52.321467250585556, 51.357014402747154, 50.0932402163744, 46.515910774469376, 48.52773942053318, 47.4952208250761, 54.35259886085987, 47.93927639722824, 50.464278906583786, 51.89151652157307, 54.80988912284374, 51.96192294359207, 59.670462906360626, 58.951518684625626, 61.367987617850304, 59.18433599174023, 57.84780330955982, 56.579123586416245, 57.0171070843935, 54.687034115195274, 57.78370454907417, 54.83635850250721, 59.96261402964592, 63.536352664232254, 70.26805624365807, 73.77014592289925, 78.78065586090088, 79.10806149244308, 81.51724621653557, 80.54936215281487, 83.00368085503578, 78.8934338092804, 82.14722961187363, 75.20168870687485, 62.18833699822426, 0.24286417581606656, 1.307010285090655, 1.12686907639727, 38.26005578041077, 86.7254139482975, 67.23106160759926, 61.2824884057045, 45.98133645951748, 40.27560442686081, 92.25036308169365, 11.537812035530806, 0.5928951292298734, 0.32338491291739047, 0.21390161040471867, 0.2175992721458897, 0.31776044284924865, 0.19656100339489058, 0.12018369161523879], [0.07832820279872976, 0.09630631466279738, 0.1266242569545284, 0.0221358179624076, 0.004397550601424882, 0.24275027099065483, 0.05532334289455321, 0.10234631321509369, 1.5862483950331807, 48.850083723664284, 44.480736181139946, 52.14498572051525, 55.66451646387577, 49.07518744468689, 86.02107614278793, 17.266360893845558, 0.262494427151978, 0.04323990964621771, 0.31011786544695497, 0.5139449250418693, 49.83834609389305, 87.43634060025215, 73.1201907992363, 77.0669174194336, 68.07526990771294, 70.41655227541924, 64.00521710515022, 59.51516143977642, 58.61868694424629, 58.355877846479416, 55.85492804646492, 57.605190128088, 53.99481765925884, 56.20310336351395, 56.979173719882965, 58.19332256913185, 59.161259829998016, 62.04909726977348, 63.173966109752655, 66.28166735172272, 65.728470236063, 64.02994617819786, 59.726312309503555, 61.62973277270794, 56.55732035636902, 56.57158099114895, 51.66743494570255, 52.15560235083103, 49.461425319314, 48.0448043346405, 42.08510912954807, 44.17345426976681, 44.88163746893406, 46.244711726903915, 48.56371209025383, 49.17125388979912, 53.05472530424595, 55.7375181466341, 57.48056061565876, 56.6705808788538, 48.251707032322884, 54.099676832556725, 54.45860557258129, 55.66880643367767, 58.89389097690582, 61.90919637680054, 56.1148265004158, 41.23901233077049, 47.88289122283459, 52.49279625713825, 52.57444627583027, 53.09302344918251, 50.045765563845634, 52.57612958550453, 50.52906543016434, 47.44395397603512, 47.42572635412216, 44.07890774309635, 41.034651696681976, 42.82199218869209, 32.739210426807404, 27.9170373827219, 32.364869713783264, 44.18105386197567, 45.58868832886219, 47.41800896823406, 46.72994948923588, 41.75663195550442, 41.23242348432541, 40.80924779176712, 39.18635107576847, 42.60141782462597, 44.807347655296326, 45.34902758896351, 37.5829891115427, 33.10817062854767, 27.782361209392548, 36.97248347103596, 42.8418955206871, 50.48611253499985, 56.69790141284466, 54.88431952893734, 57.45113879442215, 53.80539022386074, 56.54003128409386, 55.13354815542698, 55.563897863030434, 55.7466034591198, 59.35834005475044, 59.726707488298416, 53.22880536317825, 56.637142673134804, 57.215403243899345, 57.48790182173252, 57.21004173159599, 53.99123825132847, 53.83002810180187, 54.803494065999985, 57.555435597896576, 54.71429765224457, 40.2459242194891, 45.80456614494324, 44.970746487379074, 43.58457326889038, 44.32749040424824, 44.6075239777565, 40.91249965131283, 44.46049466729164, 45.52463136613369, 48.993693217635155, 48.17151613533497, 48.59048545360565, 48.0578376352787, 53.79408583045006, 51.77865877747536, 53.72618347406387, 56.95444844663143, 57.57546432316303, 55.51248662173748, 55.343361496925354, 54.00306321680546, 53.74132566154003, 50.27042470872402, 53.14812049269676, 52.04000495374203, 54.446054846048355, 55.95373414456844, 65.50622016191483, 66.45445927977562, 74.99775364995003, 71.01005002856255, 75.07928967475891, 70.54362505674362, 80.4336279630661, 74.18246179819107, 83.82020384073257, 66.44776403903961, 81.10939890146255, 4.665027726441622, 0.36221752292476594, 0.3780433174688369, 27.853183709084988, 77.05510005354881, 51.31997399032116, 43.82367543876171, 31.1033184081316, 33.9217259734869, 68.51028576493263, 13.168069906532764, 0.40444934740662575, 0.19775851804297417, 0.15726127079688013, 0.15299555438105017, 0.10802897508256137, 0.07409512603771873, 0.016710601557861082, 0.048428512673126534, 0.08629322110209614, 0.05811535440443549, 0.04149707230681088, 0.07584111008327454, 0.2119281655177474, 0.12930992612382397, 0.20799283840460703, 2.3875712463632226, 59.8398008197546, 53.27994301915169, 51.56593479216099, 65.2097600698471, 56.224549412727356, 93.68906468153, 17.65179131180048, 0.47199885710142553, 0.0991799401526805, 1.0271891439333558, 1.1295085097663105, 54.50267940759659, 90.95456421375275, 77.19368621706963, 81.48754701018333, 70.86321070790291, 73.88190552592278, 67.03516691923141, 64.76294204592705, 61.330027654767036, 61.81694872677326, 58.523984625935555, 60.30026011168957, 55.703194588422775, 58.21090802550316, 59.19956937432289, 62.04074911773205, 61.71043664216995, 66.11050173640251, 65.81331968307495, 69.04668778181076, 66.78436517715454, 66.46580547094345, 65.55982768535614, 64.054074883461, 60.025344863533974, 58.30504797399044, 53.27569104731083, 54.61096219718456, 52.19721391797066, 48.53540740907192, 46.90664380788803, 47.06698380410671, 47.39054024219513, 48.16911466419697, 49.3158171325922, 50.347423776984215, 54.05015408992767, 58.581224754452705, 59.33740697801113, 57.04853139817715, 49.50354985892773, 55.59687249362469, 57.84161724150181, 59.161731004714966, 60.23724429309368, 62.00463205575943, 56.67208559811115, 42.681943103671074, 50.68734593689442, 53.33705015480518, 54.36273671686649, 57.15730056166649, 54.328694343566895, 54.256524816155434, 51.78966298699379, 49.96151268482208, 49.03460182249546, 44.21600438654423, 41.46957255899906, 41.21874801814556, 33.02679419517517, 31.469151377677917, 39.54625256359577, 46.73907659947872, 48.15629415214062, 47.67397083342075, 47.491945400834084, 43.045412600040436, 42.388097271323204, 41.04304164648056, 40.145617201924324, 41.65634773671627, 44.81442667543888, 45.1629363745451, 39.719542264938354, 36.065654531121254, 29.363864846527576, 38.29412095248699, 43.86382408440113, 51.82038813829422, 58.60942304134369, 57.04998292028904, 59.64034952223301, 56.09536774456501, 58.14724624156952, 56.707374304533005, 58.312864154577255, 58.1915632635355, 62.77163989841938, 60.831388011574745, 57.101310566067696, 57.67257571220398, 59.99608263373375, 60.30673876404762, 57.82177850604057, 54.85688500106335, 54.80871878564358, 56.591336131095886, 60.11037290096283, 56.36063911020756, 41.16745077073574, 47.387868985533714, 46.84558868408203, 46.3873028755188, 45.34108981490135, 46.13642893731594, 42.19933100044727, 45.85259556770325, 46.11438252031803, 50.74399709701538, 50.151464492082596, 51.271332800388336, 49.832802191376686, 55.07280081510544, 53.552468195557594, 57.72801473736763, 57.99497701227665, 60.43138347566128, 58.238388150930405, 57.500897124409676, 54.338144436478615, 57.45552755892277, 52.259321585297585, 55.552331283688545, 53.4078099578619, 57.333998680114746, 57.82332502305508, 68.07932808995247, 69.50048983097076, 77.35068619251251, 73.32414865493774, 76.98553338646889, 72.11705982685089, 82.59493678808212, 74.24224019050598, 86.96402594447136, 68.70557248592377, 92.18697488307953, 6.431299299001694, 0.6801840453408659, 0.6755160551983863, 32.230269536376, 87.56241783499718, 57.06494651734829, 52.786284908652306, 34.65323232114315, 45.7767516374588, 77.33269035816193, 18.35770223289728, 0.5398197553586215, 0.2536061400314793, 0.15687728358898312, 0.14740731596248224, 0.05902827026147861, 0.09409492980921641, 0.061696536067756824, 0.27515983034390956, 0.15738639689516276, 0.33253048779442906, 0.11630899796728045, 0.22947182413190603, 0.3623699303716421, 0.29492927889805287, 0.3397649433463812, 3.4508337546139956, 70.27526065707207, 62.299047857522964, 63.274371922016144, 72.11696863174438, 62.22136102616787, 102.44345292448997, 21.201389841735363, 0.909496396780014, 0.41655710083432496, 1.9398861564695835, 3.2691322546452284, 53.977498188614845, 97.79548153281212, 78.2110284268856, 85.40840461850166, 73.00118118524551, 77.04401984810829, 69.71740499138832, 67.87632778286934, 66.62418857216835, 66.3237614929676, 59.59236189723015, 64.25535008311272, 59.33585286140442, 59.502568915486336, 63.75981107354164, 64.69373255968094, 65.13412892818451, 68.06017711758614, 69.18785780668259, 72.39019677042961, 71.22470051050186, 68.22818130254745, 66.44395664334297, 69.16863083839417, 61.121924221515656, 61.48318983614445, 56.11578784883022, 56.045138239860535, 53.7076822668314, 52.27945290505886, 48.16564165055752, 50.73161356151104, 50.63852235674858, 52.55515091121197, 52.98617698252201, 54.717561677098274, 56.804626286029816, 57.568639889359474, 59.88116540014744, 57.702122926712036, 51.056256741285324, 58.13980244100094, 61.562430784106255, 61.79028935730457, 65.1774314045906, 66.21076315641403, 58.370085284113884, 43.79034362733364, 49.918544590473175, 55.518372505903244, 56.62296563386917, 59.04902145266533, 55.84352865815163, 56.997842118144035, 56.48740030825138, 52.32646778225899, 49.569328129291534, 47.05732852220535, 44.23217251896858, 45.72203457355499, 37.972699999809265, 36.3899215310812, 40.241968631744385, 46.2019108235836, 49.86469767987728, 48.121339827775955, 48.37251394987106, 43.93000513315201, 44.637052193284035, 43.15719500184059, 39.35957998037338, 41.636516600847244, 46.74013674259186, 45.625052377581596, 40.00594809651375, 38.56892600655556, 32.61313319206238, 40.27730293571949, 46.21044136583805, 56.31812699139118, 60.139232352375984, 60.56702099740505, 61.74253731966019, 60.000991970300674, 61.03337377309799, 59.319821521639824, 62.553235217928886, 60.11347733438015, 63.94888132810593, 64.92746561765671, 59.13201279938221, 58.676478043198586, 59.17206645011902, 62.084522768855095, 62.54920743405819, 58.14729183912277, 55.82499325275421, 58.084986582398415, 63.36598500609398, 58.87000545859337, 40.40437191724777, 49.57321532070637, 48.88069488108158, 46.90847910940647, 48.3698008954525, 48.7965901941061, 45.699448585510254, 48.266062662005424, 49.881747364997864, 53.74119646847248, 52.26918585598469, 53.922161757946014, 52.80708119273186, 60.984481796622276, 55.29235303401947, 59.17126089334488, 61.10223367810249, 64.079799503088, 61.96489758789539, 59.398275911808014, 58.36237549781799, 59.43201810121536, 54.67251129448414, 58.18946957588196, 56.283845230937004, 59.69509318470955, 60.88813416659832, 74.0943293273449, 70.78149989247322, 81.72825649380684, 75.35083070397377, 78.99279847741127, 75.92718377709389, 85.95675319433212, 76.91881656646729, 89.08226788043976, 70.59467911720276, 90.70883139967918, 5.433855671435595, 0.949725431855768, 1.5446929936297238, 37.05554321408272, 95.01814976334572, 65.53087323904037, 65.13350576162338, 44.38443794846535, 50.14567740261555, 91.64982810616493, 19.817055724561214, 0.6956359755713493, 0.5034047656226903, 0.2456640763557516, 0.3155059466371313, 0.25143710954580456, 0.3450314310612157, 0.20291230321163312], [0.07312844900297932, 0.055360108890454285, 0.06435767354560085, 0.07759006271953695, 0.060899246818735264, 0.04484138640691526, 0.011524110868776916, 0.1114119884732645, 0.8012800442520529, 52.138617262244225, 47.554091066122055, 40.510671213269234, 40.42515680193901, 57.5493673235178, 85.53274914622307, 12.577219661325216, 0.4078590706922114, 0.4225424031028524, 1.5325307962484658, 1.8138984544202685, 46.25416561961174, 90.6090259552002, 71.86949551105499, 80.27254700660706, 72.82017409801483, 76.77906766533852, 70.0615981221199, 66.21362060308456, 57.68578000366688, 58.18090483546257, 56.0555724799633, 57.38627627491951, 55.88840425014496, 59.11215126514435, 57.95354403555393, 61.49711228907108, 62.846849262714386, 67.32155755162239, 63.443056270480156, 66.70529901981354, 66.79739087820053, 65.70786014199257, 64.49707791209221, 64.41623345017433, 63.542363941669464, 55.75987994670868, 51.030342131853104, 50.987552627921104, 51.79231524467468, 48.57806012034416, 43.73013585805893, 43.695428520441055, 44.838551580905914, 46.42813928425312, 48.22915904223919, 46.607854440808296, 53.46377335488796, 61.50914624333382, 61.091609448194504, 49.26108106970787, 48.74680146574974, 54.31844249367714, 50.31290262937546, 49.083862379193306, 49.75614130496979, 51.013030260801315, 47.33787126839161, 50.93006171286106, 50.01122161746025, 55.93843996524811, 55.726605132222176, 57.31884889304638, 55.04883550107479, 54.431733414530754, 54.07837517559528, 54.596728160977364, 52.091078013181686, 47.50412754714489, 41.33324347436428, 33.18746857345104, 30.39966456592083, 39.86239179968834, 43.3754400908947, 50.54539315402508, 51.25380054116249, 55.41927382349968, 51.11342467367649, 46.60907417535782, 42.62697145342827, 40.97757115960121, 43.56783136725426, 50.81395514309406, 50.28812035918236, 49.865678027272224, 44.000027775764465, 38.0653428286314, 31.87803603708744, 33.21125149726868, 41.019558906555176, 41.40592597424984, 48.7400758266449, 53.15346300601959, 53.63103657960892, 52.992955818772316, 54.889160469174385, 52.479413375258446, 50.02329356968403, 54.47526007890701, 53.51057544350624, 48.630903884768486, 45.561329796910286, 54.283803552389145, 58.748123198747635, 59.297596514225006, 55.497424229979515, 51.987111791968346, 50.57719364762306, 57.575414925813675, 58.8720041513443, 54.34449389576912, 45.87433040142059, 46.131485402584076, 44.87077385187149, 45.93469776213169, 43.35934415459633, 43.63928273320198, 38.84563475847244, 45.69732069969177, 44.43046487867832, 46.01237699389458, 46.332411020994186, 47.94714197516441, 48.5652282088995, 51.06568783521652, 49.10874344408512, 56.30635902285576, 55.6118892878294, 58.53979177772999, 57.3392727971077, 58.5933119058609, 57.533491775393486, 58.52987810969353, 55.00594720244408, 56.724165603518486, 54.541676715016365, 54.78033430874348, 53.45058046281338, 58.115574941039085, 65.71279987692833, 73.47351863980293, 70.58264896273613, 78.12298715114594, 75.5330841243267, 81.46229356527328, 68.1189675629139, 80.03021121025085, 67.2342686355114, 91.96246773004532, 19.49766956269741, 0.4927146923728287, 0.3965144231915474, 30.4261377453804, 74.92630988359451, 47.60821916162968, 44.85409274697304, 40.100897401571274, 28.364621065557003, 66.83370932936668, 17.09632381796837, 0.5039660667534918, 0.3011851978953928, 0.16966665512882173, 0.12839882110711187, 0.1730854029301554, 0.11192467150976881, 0.11123926844447851, 0.10991309507517144, 0.06185144455230329, 0.07026070132269524, 0.08236313355155289, 0.09644046527682804, 0.20006622624350712, 0.1401021782658063, 0.26978982787113637, 2.155813369899988, 60.59254042804241, 55.762817189097404, 40.02883426845074, 46.146517395973206, 64.35452476143837, 94.25475552678108, 13.718693610280752, 0.45087659207638353, 0.45878788630943745, 1.9300192734226584, 3.1278475234284997, 50.42315751314163, 92.68973350524902, 75.10977163910866, 82.62766823172569, 78.58672186732292, 78.52348566055298, 74.48895335197449, 70.1837007701397, 61.37545421719551, 60.16029842197895, 58.009268045425415, 60.093509405851364, 58.36329884827137, 60.981077179312706, 60.67664511501789, 64.66183707118034, 67.35093757510185, 70.28080835938454, 68.34303393959999, 67.93869003653526, 68.46958994865417, 67.6888458430767, 66.65147110819817, 65.62079161405563, 64.28099110722542, 58.18465143442154, 53.85784260928631, 52.295123264193535, 52.887146696448326, 49.647071957588196, 45.76700136065483, 45.92042952775955, 46.832369193434715, 49.25522938370705, 52.1304515004158, 48.67933988571167, 56.94148734211922, 63.802201598882675, 61.71447202563286, 51.144366413354874, 50.51400303840637, 55.29244422912598, 51.68989174067974, 51.06664918363094, 50.987108051776886, 54.08125162124634, 48.13782714307308, 51.48937650024891, 52.42626942694187, 59.03656952083111, 58.977364897727966, 60.42163699865341, 57.38953270018101, 57.739911898970604, 56.99402712285519, 58.00368994474411, 55.41765131056309, 48.33657927811146, 41.435290798544884, 32.433558627963066, 35.7491809129715, 41.79149888455868, 46.19456581771374, 52.78136037290096, 52.37043522298336, 56.11802972853184, 51.55588813126087, 48.641269728541374, 42.01891668140888, 42.55219526588917, 45.515812039375305, 51.22854709625244, 51.62454664707184, 51.419638842344284, 46.0143680870533, 39.32156682014465, 32.518161088228226, 34.754090309143066, 40.220119804143906, 42.416310757398605, 49.77007515728474, 53.07253114879131, 55.67610964179039, 55.37053383886814, 55.10623522102833, 52.7169044315815, 51.99565753340721, 56.937961131334305, 52.58131630718708, 47.99994394183159, 44.55798603594303, 54.35258746147156, 59.45815309882164, 61.597290113568306, 56.00701868534088, 53.28662306070328, 52.758869379758835, 59.777480363845825, 61.52437582612038, 54.624478071928024, 46.82912416756153, 48.471000865101814, 45.775949880480766, 48.51293541491032, 45.756688714027405, 45.99562369287014, 42.08113454282284, 48.554463386535645, 47.12246082723141, 48.22246000170708, 48.72538201510906, 50.15915147960186, 51.1145494133234, 52.56836660206318, 51.48251786828041, 60.0523766130209, 57.124599516391754, 60.5277881026268, 60.354050025343895, 61.47797651588917, 59.446974098682404, 61.473686546087265, 59.215368926525116, 58.47894564270973, 56.212808042764664, 58.35124209523201, 55.66517002880573, 62.112819850444794, 66.82663410902023, 75.88317453861237, 72.13029071688652, 80.93444868922234, 76.36396273970604, 83.27915847301483, 69.2465190589428, 84.22355979681015, 69.11276623606682, 97.20934018492699, 24.361066594719887, 0.6054048892110586, 0.15397832117741928, 35.06199158728123, 84.67844858765602, 54.09955903887749, 54.62749131023884, 47.44824394583702, 30.611503198742867, 74.63518470525742, 22.98035178333521, 0.7145342614967376, 0.3472908848198131, 0.23263226001290604, 0.20306726364651695, 0.07968136065755971, 0.11409434766392224, 0.08837521250825375, 0.17672505840891972, 0.1857250981265679, 0.29143812716938555, 0.1689957536291331, 0.22919809038285166, 0.38285679824184626, 0.3046779823489487, 0.34891942399553955, 3.9817194174975157, 73.98950055241585, 63.27425792813301, 50.13857178390026, 56.74855649471283, 70.76560154557228, 103.6698979139328, 15.472165569663048, 0.9519875573460013, 0.7177342241629958, 2.8814221965149045, 3.509386475197971, 53.16694848239422, 98.50135445594788, 77.47322201728821, 89.13921162486076, 78.4404981136322, 82.93742761015892, 77.23447322845459, 73.35684210062027, 62.21866697072983, 62.04058572649956, 59.900722950696945, 63.014895245432854, 62.74354800581932, 64.54733401536942, 63.60995091497898, 66.70356631278992, 68.77881735563278, 73.673205524683, 70.05980461835861, 70.32875418663025, 71.43304333090782, 69.83757734298706, 66.92776948213577, 68.74219492077827, 68.11640650033951, 59.870529770851135, 55.80220207571983, 52.89588622748852, 56.5527606010437, 53.64831045269966, 50.414687767624855, 47.89237551391125, 48.769547045230865, 51.10137552022934, 54.09771613776684, 49.50696587562561, 59.53535735607147, 64.20780703425407, 64.28031474351883, 56.63982532918453, 53.121575117111206, 56.95567958056927, 54.758861660957336, 53.86937119066715, 54.052479565143585, 56.693877428770065, 50.10192655026913, 53.926759511232376, 53.817389979958534, 64.82926368713379, 61.99958212673664, 64.56881046295166, 61.38923987746239, 61.4681426435709, 58.90868738293648, 60.30752532184124, 57.562328428030014, 53.00738364458084, 43.803639113903046, 35.36688722670078, 36.95908918976784, 45.891653671860695, 47.65920862555504, 57.16011241078377, 55.21166056394577, 58.703627586364746, 54.97739553451538, 49.82706069946289, 45.38755752146244, 41.88184283673763, 45.77793337404728, 54.065015092492104, 51.20779640972614, 52.11926490068436, 46.538489162921906, 40.48423983156681, 33.70828002691269, 37.97270379960537, 43.81796054542065, 45.28758868575096, 52.611102908849716, 57.70441800355911, 59.25387226045132, 57.90742211043835, 60.10836660861969, 57.13765561580658, 53.75214748084545, 58.24891738593578, 57.50358358025551, 51.678952127695084, 46.036866679787636, 56.27806194126606, 60.08750952780247, 61.76651023328304, 57.87620298564434, 56.946818456053734, 55.57997100055218, 62.53862500190735, 63.46519388258457, 56.936228424310684, 48.261388912796974, 49.16657634079456, 49.91040922701359, 48.893868774175644, 49.213929399847984, 48.79651419818401, 44.544207975268364, 52.493696808815, 50.152433440089226, 51.25817030668259, 50.80088384449482, 52.8441596031189, 54.38813455402851, 54.713290706276894, 53.255586326122284, 61.48125194013119, 61.77575133740902, 63.467409163713455, 63.50528933107853, 64.92003321647644, 61.682568937540054, 63.749806210398674, 60.30480086803436, 61.45991988480091, 58.22400592267513, 61.64451017975807, 58.480070382356644, 65.47296434640884, 70.05025953054428, 79.53990831971169, 75.35864308476448, 84.83718886971474, 77.18411833047867, 85.79909205436707, 71.33184716105461, 85.81008866429329, 70.25370821356773, 100.92188537120819, 21.935229264199734, 0.8761493861675262, 0.7497583120130002, 37.62547843158245, 93.25445920228958, 61.74971513450146, 65.6303671002388, 55.692338570952415, 41.145913526415825, 89.29744273424149, 26.733989864587784, 0.7479157671332359, 0.692411195486784, 0.3035167884081602, 0.29309857869520783, 0.30281364801339805, 0.24321169388713315, 0.2493615896673873], [0.030685778510815, 0.07049942796584219, 0.04304010122723412, 0.060480853644548915, 0.08079439663561061, 0.09759978158399463, 0.03823421633569524, 0.21505490789422765, 2.4735150346532464, 56.63995452225208, 39.50736925005913, 32.62406900525093, 52.07364834845066, 56.805671229958534, 87.40213483572006, 17.89015632122755, 0.41022203920874745, 0.49079077842179686, 0.6080800050403923, 2.58277983404696, 46.37181110680103, 89.90018159151077, 74.52366068959236, 78.94067287445068, 76.93461611866951, 80.33760711550713, 74.06465291976929, 72.88078844547272, 60.645794570446014, 58.102693632245064, 55.09941078722477, 58.39343503117561, 55.01697041094303, 56.88810020685196, 59.22089383006096, 62.40948133170605, 63.67126822471619, 63.47615249454975, 66.02129772305489, 66.89225658774376, 67.08429828286171, 65.16176864504814, 64.94435951113701, 65.53605616092682, 58.82455609738827, 60.55116444826126, 52.22784407436848, 50.08386231958866, 50.67384146153927, 47.875899598002434, 44.468557834625244, 42.33999565243721, 44.542004093527794, 45.115488320589066, 44.55033324658871, 48.27208533883095, 55.368831530213356, 55.93099616467953, 51.36938273906708, 55.7081039249897, 55.89729577302933, 49.23993140459061, 47.772096768021584, 46.96272499859333, 49.440914019942284, 48.114933371543884, 50.68213641643524, 52.16619238257408, 53.96483726799488, 55.4749446362257, 54.7960464656353, 55.534734427928925, 54.15388472378254, 55.84887497127056, 56.24460093677044, 55.235367491841316, 56.232137605547905, 52.18388423323631, 40.94812273979187, 41.48029938340187, 38.56088563799858, 45.78425623476505, 49.65233847498894, 52.9515228420496, 53.50468955934048, 51.206417083740234, 53.26067045331001, 52.17470772564411, 45.99071055650711, 44.542760252952576, 50.586123168468475, 50.46634219586849, 54.54917371273041, 52.908987924456596, 51.24770186841488, 43.82535494863987, 36.996243596076965, 35.965043529868126, 43.58763970434666, 41.980063766241074, 39.1346700489521, 49.8945564776659, 48.054315224289894, 49.71356838941574, 49.858424216508865, 52.792501375079155, 49.58408273756504, 50.17971597611904, 47.8058959543705, 46.091754734516144, 39.84742060303688, 47.704851776361465, 52.600752264261246, 53.9848317950964, 51.83009281754494, 46.505088955163956, 45.990543365478516, 51.85716636478901, 58.06158363819122, 61.30421943962574, 54.487541019916534, 49.92855705320835, 45.83219826221466, 45.61070814728737, 43.43831531703472, 43.35962153971195, 41.44452050328255, 46.083265990018845, 47.49407708644867, 48.012426272034645, 47.82771818339825, 49.46103014051914, 46.60097301006317, 51.38508349657059, 53.67281533777714, 54.753595143556595, 55.13571783900261, 57.865377366542816, 55.43614871799946, 59.22731168568134, 58.655913546681404, 60.3272994607687, 57.7110106498003, 61.08450762927532, 58.934959173202515, 57.271408438682556, 50.941065922379494, 55.5584679543972, 57.52448245882988, 69.60871562361717, 69.24520432949066, 79.20092850923538, 71.30932196974754, 78.46520438790321, 70.69748640060425, 81.0990558564663, 70.1367124915123, 89.04429271817207, 39.170464128255844, 0.17077008029446006, 0.193237844214309, 37.25115291774273, 75.77761620283127, 50.10145157575607, 48.92228364944458, 30.828532353043556, 39.47229713201523, 61.45762100815773, 19.24006048589945, 0.3220947930822149, 0.19111291214358062, 0.15430977917276323, 0.04774002969497815, 0.14674508274765685, 0.006063725941203302, 0.07344462617766112, 0.11222984263440594, 0.07388974408968352, 0.027992827017442323, 0.12728499103104696, 0.08741844314499758, 0.16172920761164278, 0.12457656761398539, 0.2754027204355225, 4.11101745441556, 67.17649653553963, 44.08485062420368, 41.92920729517937, 61.14344246685505, 62.25589357316494, 96.3280762732029, 18.528455570340157, 0.46409637958277017, 0.5499712668824941, 0.7138494669925421, 1.858048285357654, 51.08111500740051, 91.17297649383545, 79.2090068757534, 83.52593243122101, 81.09112188220024, 82.82074347138405, 76.44270211458206, 76.56721383333206, 62.72112540900707, 60.882514268159866, 57.25075654685497, 61.63071691989899, 57.025592029094696, 58.84429603815079, 61.8320719152689, 65.53281873464584, 66.66902616620064, 67.97011435031891, 66.26002371311188, 70.2159534394741, 68.97461324930191, 66.36301338672638, 65.78122660517693, 67.21966981887817, 60.42961277067661, 63.26006568968296, 53.85063819587231, 52.23548926413059, 52.01836131513119, 52.87341423332691, 47.288276329636574, 46.011860221624374, 46.31541833281517, 45.18457241356373, 47.47207246720791, 51.7666932195425, 57.047380059957504, 57.35696844756603, 56.3789389282465, 58.698532059788704, 59.44006226956844, 51.6021354496479, 50.78847371041775, 47.633514404296875, 50.3754548728466, 51.907000690698624, 53.396520763635635, 54.914748296141624, 57.38462336361408, 57.297133058309555, 55.869048088788986, 58.38310718536377, 58.02441023290157, 59.8457171022892, 58.14474977552891, 56.98569416999817, 57.36333690583706, 52.62161314487457, 42.66218416392803, 44.781030267477036, 39.95301693677902, 47.39776365458965, 51.910029128193855, 55.24528495967388, 55.348901599645615, 53.064274191856384, 56.54930658638477, 53.683257177472115, 48.842822313308716, 46.060490012168884, 51.62603996694088, 53.95114280283451, 55.38886025547981, 53.370271772146225, 51.90567836165428, 46.314084604382515, 37.769673094153404, 37.68910601735115, 44.066452011466026, 43.65804612636566, 42.25090563297272, 51.359115689992905, 49.610806703567505, 50.117642506957054, 50.30003271996975, 54.53474208712578, 52.94065922498703, 52.520223185420036, 47.97410532832146, 48.10440793633461, 40.207101702690125, 47.69386276602745, 53.96607980132103, 55.589975863695145, 52.92414151132107, 48.026797100901604, 47.55996935069561, 53.87228563427925, 60.56745037436485, 61.66399173438549, 56.21693842113018, 50.79552233219147, 48.39906692504883, 48.50735351443291, 45.288766622543335, 45.581206530332565, 43.31663444638252, 49.85235974192619, 50.3209125995636, 50.79845957458019, 48.30745384097099, 52.64490209519863, 51.52080461382866, 52.48230881989002, 54.65520702302456, 55.679525658488274, 57.360855638980865, 60.8686488121748, 60.90196542441845, 62.50650152564049, 60.01707270741463, 63.32704469561577, 62.621407359838486, 65.26539668440819, 60.923932045698166, 61.865365728735924, 54.37201201915741, 59.602579548954964, 59.391288086771965, 72.41143763065338, 71.35751098394394, 82.15539157390594, 73.98478120565414, 82.33952209353447, 76.94883495569229, 83.8614772260189, 72.48638480901718, 92.38296076655388, 46.45443007349968, 0.17158976756036282, 0.1426041658851318, 42.50490680336952, 82.17050716280937, 56.74082010984421, 55.9217094630003, 33.11695195734501, 50.5864879488945, 71.68940797448158, 23.65205504000187, 0.4355923872208223, 0.27112358598969877, 0.14040856651263312, 0.056493179145036265, 0.1596917153801769, 0.08304343806230463, 0.16832114139106125, 0.16975103731965646, 0.20025686913868412, 0.21277731604641303, 0.23020623862976208, 0.23474953311961144, 0.3476565261371434, 0.21832467697095126, 0.5236127937678248, 6.2512982077896595, 78.48785877227783, 54.6424625068903, 43.154367953538895, 73.52825090289116, 71.84261575341225, 102.95371994376183, 19.914554692804813, 0.7763041032012552, 1.255499655380845, 1.4750474807806313, 3.56520714238286, 52.22433306276798, 95.78634694218636, 79.12803322076797, 86.75884455442429, 79.94289949536324, 85.05725026130676, 78.75281095504761, 80.21887108683586, 66.71840831637383, 64.20535996556282, 59.72924195230007, 67.12670400738716, 60.32507658004761, 60.02770833671093, 63.646827936172485, 69.1071729362011, 68.32519769668579, 70.79902455210686, 69.51591700315475, 72.89040192961693, 71.38996884226799, 68.760996311903, 67.46470347046852, 69.44017186760902, 61.241933181881905, 65.06871163845062, 55.27787581086159, 54.328728541731834, 53.99482145905495, 54.587734043598175, 49.09955553710461, 48.4555546939373, 48.79378594458103, 48.46126578748226, 49.36500549316406, 55.83837993443012, 59.22347009181976, 60.01445844769478, 61.0344947129488, 58.58900673687458, 61.46950677037239, 56.383559480309486, 52.237240970134735, 50.340401753783226, 54.287618547677994, 55.31230956315994, 56.818225756287575, 59.273824989795685, 60.40471650660038, 62.39917628467083, 60.995147824287415, 61.993342861533165, 61.371255442500114, 64.41445514559746, 61.376898139715195, 61.18333652615547, 60.072595328092575, 56.4333102107048, 45.62224432826042, 43.81712459027767, 38.763228580355644, 50.540939792990685, 54.682128578424454, 58.91292795538902, 60.44828496873379, 55.169148445129395, 59.92423228919506, 54.92954470217228, 49.600079879164696, 46.84406116604805, 52.214130610227585, 54.97765012085438, 59.76797327399254, 56.309657245874405, 54.44282501935959, 48.64177890121937, 38.55607129633427, 37.57896512746811, 43.740353509783745, 43.88921432197094, 44.37923602759838, 51.752751767635345, 50.7954653352499, 53.16733606159687, 51.25088609755039, 58.420740365982056, 54.83675368130207, 54.53376553952694, 51.169733852148056, 49.16278034448624, 42.28927977383137, 47.83603593707085, 56.79359927773476, 56.915245950222015, 55.830347165465355, 48.68085600435734, 51.0084743052721, 55.66443666815758, 62.35811568796635, 63.44284728169441, 58.36220070719719, 54.560842886567116, 50.31360179185867, 50.86623653769493, 49.84829396009445, 49.05432276427746, 47.172633334994316, 52.67975002527237, 52.73054949939251, 53.65331098437309, 51.707036420702934, 55.27920953929424, 53.19044642150402, 55.28266355395317, 58.89518290758133, 58.464730605483055, 60.43741375207901, 63.58195401728153, 62.4300192296505, 63.96544083952904, 62.29235261678696, 65.73211044073105, 65.57438850402832, 68.74792501330376, 62.554538547992706, 63.23531001806259, 57.163764014840126, 62.14930549263954, 62.3537877202034, 76.35593757033348, 73.38265791535378, 85.8195349574089, 76.02054476737976, 84.7572411596775, 79.71195548772812, 86.85500219464302, 76.18176251649857, 95.85486486554146, 46.935579255223274, 0.4385469958651811, 0.27638226631097496, 45.303825214505196, 92.44937360286713, 64.24275755882263, 69.60469543933868, 41.18959218263626, 56.73457704484463, 86.24330341815948, 27.815991304814816, 0.5797220079693943, 0.48068290518131107, 0.26595616014674306, 0.23227490106364712, 0.3810326586244628, 0.3076031425734982, 0.1971586697618477], [0.14730380120454356, 0.02035280631389469, 0.06521554430946708, 0.1111392788880039, 0.07149759432650171, 0.09550063172355294, 0.018346682809351478, 0.266203117207624, 2.20580514986068, 59.63388226926327, 43.303817734122276, 19.164509139955044, 38.19233201444149, 53.900107741355896, 84.15383353829384, 16.458583138883114, 0.2155325244530104, 0.7674807391595095, 0.06865906500024721, 0.6815832608845085, 51.05009727180004, 81.52818962931633, 74.29992109537125, 85.3466123342514, 79.35736611485481, 79.01102229952812, 73.81811454892159, 68.728758841753, 57.96354129910469, 56.166176944971085, 56.03994011878967, 57.024767473340034, 58.76429133117199, 56.87161289155483, 58.39160732924938, 62.37095519900322, 63.43461312353611, 64.32052418589592, 61.90298371016979, 64.2001922428608, 58.72970938682556, 63.86307433247566, 60.13172775506973, 63.725726902484894, 61.104232370853424, 60.53943067789078, 55.49495056271553, 50.4455953091383, 50.71366332471371, 49.92812007665634, 45.08038580417633, 44.70132574439049, 41.81183539330959, 45.89405134320259, 42.48927064239979, 50.057556331157684, 48.69809947907925, 53.306617587804794, 55.75511120259762, 53.49977262318134, 48.433021903038025, 49.623669013381004, 48.95281121134758, 47.708195596933365, 47.08402208983898, 51.33253991603851, 49.6526500582695, 50.43057471513748, 51.636626198887825, 52.72284351289272, 53.888221979141235, 57.46012531220913, 52.94777624309063, 53.029741644859314, 55.441172048449516, 57.29343965649605, 55.85033789277077, 48.33664767444134, 45.23314520716667, 43.68515007197857, 43.42050567269325, 51.03725016117096, 52.22694352269173, 50.54142616689205, 48.86844053864479, 50.356771275401115, 50.2399617433548, 53.937588930130005, 50.1440054923296, 50.424267053604126, 52.62070119380951, 53.89458283782005, 49.993465170264244, 49.92676354944706, 49.623866602778435, 53.59549708664417, 42.98625737428665, 41.55771262943745, 44.253603368997574, 42.756753489375114, 38.62364687025547, 44.42062720656395, 49.18284706771374, 51.747014075517654, 52.359548807144165, 53.47344383597374, 51.36739544570446, 51.32533550262451, 53.30295458436012, 49.86633159220219, 49.89274777472019, 47.81347654759884, 48.56606796383858, 49.38948757946491, 46.38985633850098, 44.81037229299545, 46.462348848581314, 45.12252174317837, 51.497116684913635, 57.277092933654785, 55.673635974526405, 52.43130795657635, 43.34884911775589, 46.20364733040333, 42.58706219494343, 41.396274492144585, 41.3839365541935, 46.686985194683075, 46.0172825306654, 48.45009058713913, 46.99459008872509, 51.48761339485645, 51.94610059261322, 51.13316461443901, 53.757493793964386, 54.47243683040142, 54.393659457564354, 57.19928450882435, 57.234147638082504, 58.606683388352394, 57.327497228980064, 60.37133529782295, 60.05904145538807, 60.72074934840202, 58.37501361966133, 58.22436310350895, 54.07188132405281, 53.731457591056824, 54.70751881599426, 56.73127502202988, 61.49852201342583, 71.75074428319931, 70.2650012075901, 76.54132202267647, 71.3270366191864, 74.62870225310326, 72.1241046488285, 83.65821093320847, 55.977266281843185, 0.441201954963617, 0.06230150145711377, 42.31655091047287, 70.07183477282524, 53.99865925312042, 47.90399149060249, 43.21046054363251, 26.040637269616127, 63.756642043590546, 22.143085710704327, 0.30966640217229724, 0.1790140793309547, 0.11610790563281626, 0.025878444575937465, 0.07660800838493742, 0.06659010570729151, 0.034417035421938635, 0.0674259643710684, 0.046485588609357364, 0.1431068521924317, 0.09781732733245008, 0.09336127230199054, 0.11662976903608069, 0.14155249809846282, 0.5686742789112031, 4.295099526643753, 69.30708780884743, 52.04708017408848, 25.053963214159012, 46.87781095504761, 63.11175964772701, 92.4497839808464, 18.82396761327982, 0.2081435389118269, 1.504807008896023, 0.1513061294099316, 1.0341008543036878, 55.127799063920975, 85.94435065984726, 78.61164093017578, 88.08477580547333, 82.84944713115692, 81.96371465921402, 76.57895520329475, 73.07087704539299, 60.185814052820206, 58.73009696602821, 59.14909668266773, 60.80024488270283, 60.62536306679249, 59.38570238649845, 60.83687871694565, 65.02527996897697, 65.47585219144821, 66.48450806736946, 63.723849803209305, 65.45062154531479, 61.89408838748932, 65.23421555757523, 62.07001134753227, 64.13586929440498, 62.424623519182205, 62.13559202849865, 58.60670618712902, 52.81425520777702, 53.27441431581974, 53.883248046040535, 47.26098619401455, 46.71164587140083, 45.21872118115425, 47.78329856693745, 43.55941101908684, 51.053581684827805, 50.983635038137436, 55.28970457613468, 58.19874107837677, 56.03828340768814, 50.061466321349144, 53.36242899298668, 50.686452984809875, 48.88699874281883, 50.17567299306393, 54.27680052816868, 54.02847245335579, 52.7046462893486, 53.51253993809223, 57.180844098329544, 58.80325064063072, 60.856212079524994, 56.52908407151699, 56.889038756489754, 60.51288150250912, 59.42389413714409, 57.093163803219795, 51.68830722570419, 45.41569121181965, 43.73821422457695, 45.36491833627224, 53.03335525095463, 52.95810408890247, 54.66958165168762, 52.360947132110596, 52.45087690651417, 52.018916085362434, 55.564714819192886, 51.29933349788189, 52.64945425093174, 54.019440338015556, 56.31293646991253, 52.100277319550514, 52.3374529927969, 51.24981075525284, 54.97010372579098, 46.17795690894127, 41.6914464533329, 45.06101444363594, 42.12830141186714, 40.16506835818291, 47.23665609955788, 50.10375425219536, 52.73633658885956, 53.27191784977913, 54.9064951390028, 54.82904389500618, 54.63519349694252, 53.67936238646507, 53.353746458888054, 52.4503905326128, 50.10045602917671, 50.19447438418865, 50.048056840896606, 49.2082829028368, 47.299158945679665, 48.0619528144598, 49.62500274181366, 52.279696092009544, 59.97561313211918, 57.01824702322483, 54.33462202548981, 46.341028958559036, 46.96661219000816, 45.29637761414051, 44.093548357486725, 41.84284172952175, 48.69216039776802, 47.48847998678684, 50.688630267977715, 49.83496807515621, 53.74370813369751, 53.78758817911148, 53.25397901237011, 54.63953286409378, 57.90936380624771, 58.100645542144775, 60.03989428281784, 58.88613559305668, 60.51383525133133, 62.05358102917671, 63.10433104634285, 62.26182125508785, 64.13969948887825, 62.22212478518486, 60.63870035111904, 58.14696125686169, 58.40115621685982, 56.80064409971237, 59.58702318370342, 64.465342015028, 71.90883859992027, 74.0050721168518, 79.76915001869202, 73.40569987893105, 79.17062133550644, 75.67069754004478, 87.22588509321213, 63.70412886142731, 0.8796104067005217, 0.03473219585430343, 48.2355161011219, 79.72257971763611, 62.556115463376045, 58.929373472929, 39.11876030266285, 31.716818287968636, 76.54351070523262, 26.38741046190262, 0.33553200017195195, 0.15120212483452633, 0.09641869808547199, 0.12240009338711388, 0.086390056530945, 0.10677602200303227, 0.055456313493778, 0.17394979717209935, 0.14190089190378785, 0.24946302641183138, 0.2526678575668484, 0.19434345129411668, 0.2849071385571733, 0.32112602319102734, 0.7370827265549451, 6.401613391935825, 81.97907343506813, 58.013436421751976, 25.817596837878227, 52.36183248460293, 69.6677416563034, 98.18714171648026, 20.504539534449577, 0.46533048211131245, 2.6754077011719346, 0.3190851170802489, 1.7660831264220178, 58.08386564254761, 86.97371542453766, 79.33659642934799, 89.71816375851631, 81.28611221909523, 87.49120205640793, 79.23722416162491, 75.54561585187912, 62.934822142124176, 60.286143869161606, 59.88420143723488, 63.70844542980194, 63.79501238465309, 64.03312280774117, 64.99526157975197, 67.80404046177864, 68.46547096967697, 71.02882102131844, 66.69006943702698, 68.46181556582451, 63.87492969632149, 69.60898920893669, 64.72457930445671, 69.45306837558746, 66.23555302619934, 65.31525760889053, 61.07294484972954, 56.687573567032814, 53.894404247403145, 55.50511121749878, 49.55509029328823, 49.92283836007118, 48.22628639638424, 51.6728800535202, 45.79247899353504, 53.61109524965286, 53.788336738944054, 59.651140943169594, 58.780125081539154, 57.90101185441017, 53.178024888038635, 53.57593193650246, 53.93932543694973, 50.423389300704, 54.03227224946022, 57.8327751159668, 57.20136299729347, 56.50990270078182, 58.16638581454754, 62.438986748456955, 60.81487409770489, 65.80705001950264, 61.041642129421234, 60.660948157310486, 64.10083517432213, 62.51786671578884, 61.25106409192085, 53.997675105929375, 48.467630445957184, 45.12650392949581, 45.51979802548885, 58.10341939330101, 57.59149566292763, 59.40355762839317, 56.243894174695015, 55.78180857002735, 55.5535814166069, 58.35693798959255, 52.533959448337555, 53.88731002807617, 55.783818662166595, 60.9435959905386, 55.39432056248188, 56.44455000758171, 54.519235119223595, 57.644548416137695, 47.309141010046005, 43.282542675733566, 46.16750746965408, 43.05682338774204, 41.999796107411385, 49.901145324110985, 51.81347630918026, 56.25232592225075, 57.59556144475937, 58.731529489159584, 58.48762817680836, 57.36561678349972, 58.78162980079651, 55.20807355642319, 54.08128581941128, 51.70315682888031, 50.72526790201664, 52.80985504388809, 51.733277812600136, 49.16992776095867, 49.96003456413746, 51.51937589049339, 55.27406081557274, 61.2811166793108, 59.53883416950703, 56.23649597167969, 48.149758502840996, 49.707458317279816, 48.16206984221935, 47.05797828733921, 45.014318749308586, 52.26220183074474, 50.44123314321041, 52.150666415691376, 52.10270918905735, 56.79582215845585, 56.269687190651894, 55.45234724879265, 58.8587960600853, 60.73167376220226, 58.04437056183815, 62.80762016773224, 60.15180207788944, 61.950895339250565, 63.00288788974285, 64.32663425803185, 66.0907655954361, 67.40967482328415, 66.23616099357605, 62.94222414493561, 60.91033637523651, 59.79376249015331, 60.69068156182766, 62.328230291604996, 68.7345877289772, 77.47711300849915, 77.9337041079998, 82.90974989533424, 77.49237298965454, 81.91082149744034, 79.99770775437355, 89.17596325278282, 64.4729720056057, 1.7274187761358917, 0.23597864841576666, 53.84554646909237, 87.88916230201721, 70.62057852745056, 70.11901304125786, 57.023688331246376, 35.865211486816406, 88.1355182826519, 29.90959346294403, 0.5287579551804811, 0.2826397289754823, 0.1822009653551504, 0.16269677522359416, 0.17940936202649027, 0.20433976489584893, 0.11781117907958105], [0.05492984135344159, 0.05220931350777391, 0.030670464293507393, 0.02092777594953077, 0.037930863472865894, 0.05121867623529397, 0.07743015958112665, 0.3703503037104383, 4.434172539040446, 64.78009432554245, 46.78015239536762, 43.51111561059952, 41.43511600792408, 49.110890328884125, 83.41627791523933, 23.688316494226456, 0.252719065756537, 0.7071425300091505, 0.2362148294923827, 2.8697052877396345, 67.35248789191246, 79.69860300421715, 78.87583315372467, 79.80141788721085, 75.91292694211006, 77.06810295581818, 77.00780779123306, 61.84235796332359, 52.033169120550156, 56.34861275553703, 60.843779146671295, 63.527521938085556, 60.73126718401909, 64.516791254282, 61.00922606885433, 61.991773545742035, 59.63441424071789, 61.347844898700714, 60.620917305350304, 61.03851869702339, 62.701104283332825, 64.3458080291748, 60.81537567079067, 61.911141872406006, 59.134144484996796, 60.63913352787495, 58.21493960916996, 50.04825823009014, 51.64028540253639, 48.51886309683323, 44.84835885465145, 43.67338590323925, 43.392569571733475, 43.65200065076351, 43.04320111870766, 44.71047565340996, 48.64813216030598, 50.844425708055496, 50.67264072597027, 45.88348031044006, 48.53976957499981, 49.0469815582037, 45.07823891937733, 47.10864096879959, 48.75206798315048, 49.85034964978695, 53.04614916443825, 53.672891333699226, 50.91656103730202, 54.52056884765625, 51.40594817698002, 54.67069499194622, 54.87121023237705, 53.48714590072632, 55.84755264222622, 56.76858901977539, 52.22405567765236, 48.985641449689865, 39.59787659347057, 43.627187982201576, 50.551624819636345, 48.84414084255695, 50.29564395546913, 47.27940760552883, 50.735512152314186, 49.1899298876524, 52.26754814386368, 52.10406191647053, 55.36147512495518, 51.81537240743637, 52.5313413888216, 52.54538543522358, 49.29807968437672, 48.47602799534798, 49.8027990013361, 49.000707641243935, 53.23103204369545, 41.86711102724075, 43.22320505976677, 40.563864558935165, 45.15443243086338, 47.10588611662388, 51.355901062488556, 52.41594918072224, 51.70230187475681, 52.36918888986111, 50.817523151636124, 51.32252745330334, 51.0287120193243, 49.61769953370094, 47.550918236374855, 47.63764478266239, 46.34153813123703, 46.765302792191505, 44.51599068939686, 45.10076031088829, 46.03487178683281, 48.679104298353195, 51.465620175004005, 52.72502839565277, 55.18758125603199, 51.08585715293884, 44.35858033597469, 43.8178351521492, 42.18432180583477, 41.39280907809734, 42.28894539177418, 45.97309470176697, 48.64974707365036, 50.823500230908394, 56.27194806933403, 58.69997978210449, 57.841647639870644, 57.51469038426876, 55.082649886608124, 52.9095882922411, 55.09778067469597, 56.706431955099106, 56.77104368805885, 57.12737716734409, 59.0294449031353, 57.60078236460686, 57.383160442113876, 62.055271938443184, 60.041835978627205, 60.01386947929859, 55.27346804738045, 55.986948162317276, 54.94103528559208, 57.62054890394211, 55.53191877901554, 58.19884367287159, 60.990911051630974, 66.24192908406258, 66.59391939640045, 74.60182249546051, 71.21792927384377, 79.73045289516449, 62.17655763030052, 1.3106099981814623, 0.13930390938185155, 37.07500956952572, 71.22937425971031, 50.10716646909714, 40.53025156259537, 39.07245598733425, 39.94986690580845, 62.35530003905296, 22.320146709680557, 0.28003992629237473, 0.26867690321523696, 0.14701400737976655, 0.07793522818246856, 0.10342383742681704, 0.03550529851054307, 0.02259465447423281, 0.045228052767924964, 0.15345164865721017, 0.10474947644979693, 0.03603645360271912, 0.037786842294735834, 0.12514870410086587, 0.08223612239817157, 0.43980348156765103, 6.202926328405738, 77.3788046836853, 51.83706544339657, 48.656791895627975, 52.05553092062473, 57.28442274034023, 90.16527816653252, 26.99541963636875, 0.24308932857820764, 1.0273794899694622, 0.4424005828332156, 4.566356996074319, 74.27258536219597, 80.83968937397003, 82.70629361271858, 81.98758497834206, 77.26335167884827, 78.32556948065758, 77.4986806511879, 65.194401293993, 55.942159965634346, 60.96140943467617, 64.95633646845818, 66.13173499703407, 62.47240595519543, 66.73860803246498, 64.18849647045135, 65.3351229429245, 62.85211578011513, 64.97595101594925, 62.413733303546906, 63.96722674369812, 64.73420798778534, 63.827660232782364, 65.88313713669777, 64.20384004712105, 62.182546108961105, 63.331612050533295, 59.238897264003754, 53.745072260499, 52.47176818549633, 49.62081536650658, 48.80095615983009, 45.43431781232357, 46.86841405928135, 45.313856676220894, 47.14990295469761, 46.85892216861248, 51.49796783924103, 51.9562042504549, 51.034176126122475, 47.3556125164032, 51.97049908339977, 50.977255180478096, 47.754252925515175, 49.07979279756546, 51.11296109855175, 53.236568346619606, 56.79112561047077, 56.139217391610146, 56.54602736234665, 56.10400088131428, 56.159865483641624, 58.846454322338104, 56.69478937983513, 56.365309059619904, 57.109730914235115, 59.19001288712025, 55.094372257590294, 52.61717118322849, 42.82035827636719, 47.99572616815567, 50.534559935331345, 52.42199085652828, 52.94213354587555, 49.98883701860905, 53.810839131474495, 50.57402841746807, 52.74525851011276, 55.11280506849289, 58.54222744703293, 55.498332381248474, 54.282363429665565, 54.37760151922703, 53.37309122085571, 50.94288222491741, 53.13231714069843, 52.29625940322876, 53.67459364235401, 42.77817294001579, 44.571889489889145, 40.244567692279816, 45.536425933241844, 49.287539049983025, 52.91134759783745, 55.88503383100033, 54.71721209585667, 55.93677945435047, 53.59300822019577, 53.546749502420425, 52.761844620108604, 52.16884844005108, 51.08983933925629, 51.82375855743885, 48.50008450448513, 47.9844331741333, 44.1278301179409, 47.59480968117714, 46.989654153585434, 50.991781800985336, 51.24845802783966, 54.31306578218937, 57.09697499871254, 51.92671403288841, 46.162423342466354, 47.69471772015095, 43.99462826550007, 44.73561130464077, 44.073276445269585, 49.04779091477394, 50.56580185890198, 53.40942867100239, 59.53413002192974, 60.975613072514534, 59.66079242527485, 59.607450887560844, 57.720730528235435, 56.058000549674034, 57.157718539237976, 59.07228000462055, 59.30804215371609, 59.656646847724915, 61.136097460985184, 59.55241844058037, 59.38366949558258, 62.49859035015106, 61.704634353518486, 62.444466054439545, 60.3509683907032, 60.79943172633648, 58.183173313736916, 61.70723341405392, 57.7629766613245, 60.94690561294556, 62.98681475222111, 68.30508157610893, 70.57432740926743, 76.66310548782349, 75.62730386853218, 84.87400129437447, 70.28555810451508, 2.3476629378274083, 0.23728156287688762, 42.449410781264305, 80.52488386631012, 58.89646343886852, 49.88302789628506, 37.36379027366638, 39.861514046788216, 74.85738918185234, 26.29330851137638, 0.20741497253766283, 0.21755161142209545, 0.10441772159538232, 0.11151393729960546, 0.03208054302376695, 0.011581707094592275, 0.031573652449878864, 0.14669050520751625, 0.20283494173781946, 0.18654246989171952, 0.1255586664774455, 0.3162068309029564, 0.17648846172960475, 0.3326303214998916, 0.6553231074940413, 8.215990383177996, 86.66883498430252, 61.802228316664696, 55.600326508283615, 58.99027280509472, 63.981696367263794, 97.526113986969, 28.82613480091095, 0.37555430259089917, 2.8761658910661936, 0.6443659798242152, 5.802889969199896, 74.79660004377365, 83.68048533797264, 84.18231680989265, 83.55167984962463, 81.61602571606636, 82.57709294557571, 83.19443821907043, 69.23457249999046, 57.37847149372101, 61.332634314894676, 65.72422966361046, 71.17155656218529, 64.79500472545624, 68.79455611109734, 67.22172170877457, 68.2034370303154, 63.53331662714481, 67.49385550618172, 63.791387379169464, 65.98451569676399, 66.65550649166107, 66.44250512123108, 67.72367477416992, 68.82671758532524, 64.47079092264175, 64.98374059796333, 64.12462949752808, 56.02434575557709, 54.67909254133701, 52.680004611611366, 50.29101960361004, 48.463652059435844, 48.6233726888895, 50.75152449309826, 48.86118672788143, 48.821744844317436, 55.13984061777592, 55.895946845412254, 53.68664279580116, 51.49645932018757, 55.750684440135956, 54.42592352628708, 50.64169138669968, 51.97471305727959, 52.53457881510258, 54.39862959086895, 59.54226538538933, 61.16409435868263, 58.45418997108936, 61.37648016214371, 60.05888566374779, 65.03699094057083, 60.19823178648949, 60.02111189067364, 61.146938279271126, 64.30154040455818, 56.57467022538185, 52.812568098306656, 41.82627461850643, 47.85697661340237, 55.52496895194054, 56.60038724541664, 56.69803440570831, 53.786125257611275, 55.73583483695984, 52.88319870829582, 55.93279726803303, 56.4674361795187, 61.80485397577286, 57.33839124441147, 56.7161176353693, 59.270154386758804, 56.27126790583134, 52.153368070721626, 58.01357701420784, 56.65438994765282, 58.20178471505642, 44.25929166376591, 45.05092978477478, 40.76336905360222, 49.48808088898659, 52.03229136765003, 56.326285153627396, 57.29454919695854, 57.01009266078472, 58.4417000412941, 56.019216030836105, 58.790844306349754, 54.80190195143223, 55.29785513877869, 52.76387371122837, 52.848403975367546, 50.757987946271896, 51.75292655825615, 47.268562987446785, 50.025983825325966, 50.17554759979248, 53.382936492562294, 53.891797587275505, 57.282443046569824, 61.06552764773369, 55.1723250746727, 48.97473603487015, 49.44034785032272, 46.55925504863262, 47.0580542832613, 48.101436495780945, 50.14712892472744, 53.15230406820774, 56.90306380391121, 61.665291264653206, 63.31908792257309, 62.088672146201134, 61.23179912567139, 59.72512297332287, 57.016673907637596, 60.1017701625824, 62.00394429266453, 64.25554007291794, 61.472622603178024, 63.455284014344215, 63.72129254043102, 62.85354070365429, 65.84001705050468, 64.88428473472595, 66.4645591378212, 63.17241959273815, 62.61834852397442, 61.79506570100784, 64.69392254948616, 62.04660840332508, 64.63871151208878, 67.04601153731346, 71.91991120576859, 74.33239415287971, 78.3438540995121, 80.97845032811165, 89.41769868135452, 72.4868331849575, 3.7536981655284762, 0.2278853053576313, 48.38655039668083, 88.76731798052788, 66.7970260977745, 59.789168536663055, 55.265944451093674, 55.03205940127373, 87.57146894931793, 35.75097441673279, 0.4300018184585497, 0.30015554220881313, 0.281508369371295, 0.20219562604324892, 0.1962154742795974, 0.24348183564143255, 0.10494673188077286], [0.047732786333654076, 0.024610514956293628, 0.0389676103804959, 0.02659886402398115, 0.03611601554439403, 0.1385424955515191, 0.04727997977170162, 0.3532760980306193, 2.7976433420553803, 65.06842285394669, 41.13480672240257, 28.281709514558315, 53.1098223477602, 52.98432648181915, 76.30944326519966, 40.26283711194992, 0.4005958791822195, 1.2339348625391722, 0.859047097619623, 13.503757193684578, 89.84562411904335, 74.55743327736855, 79.95999857783318, 72.09732368588448, 76.89809247851372, 73.73602375388145, 65.7362674176693, 53.62505570054054, 61.17564953863621, 67.45127499103546, 68.80375921726227, 68.35159868001938, 67.71781548857689, 66.44790843129158, 64.6503084897995, 64.73534032702446, 65.49083098769188, 65.03930121660233, 63.92615094780922, 62.86756955087185, 61.31853707134724, 65.36156952381134, 66.52619943022728, 61.4892353117466, 64.75598841905594, 62.07522466778755, 57.60894052684307, 50.299804732203484, 49.19894680380821, 48.388963267207146, 46.75815537571907, 43.38252291083336, 42.994742318987846, 40.151259899139404, 41.74823060631752, 40.51048122346401, 41.365936920046806, 45.68298786878586, 44.19406436383724, 46.65858931839466, 45.676957592368126, 44.21183981001377, 44.882336631417274, 46.8961525708437, 44.708552956581116, 51.312518790364265, 51.44550405442715, 51.096827164292336, 52.6834624260664, 50.1487210392952, 53.94507832825184, 54.42022763192654, 52.77545928955078, 52.57009170949459, 53.2122078537941, 53.95890958607197, 50.795374140143394, 46.7169351875782, 48.164600506424904, 50.11881664395332, 48.772522285580635, 48.37284453213215, 48.343814089894295, 50.532143265008926, 48.60096149146557, 49.62038978934288, 50.88811956346035, 53.62345218658447, 53.618121072649956, 55.41955500841141, 53.81960906088352, 51.36259250342846, 51.66873827576637, 46.043314933776855, 48.08159776031971, 50.034575164318085, 51.52456261217594, 46.855411157011986, 40.56676760315895, 41.604712307453156, 41.65676951408386, 49.203202575445175, 47.76092156767845, 50.209741964936256, 53.31404238939285, 51.17327146232128, 50.073686465620995, 51.48131713271141, 50.58096684515476, 48.9028362929821, 48.11020642518997, 49.153030067682266, 44.74288411438465, 44.020900055766106, 42.17801794409752, 45.93302585184574, 44.62691433727741, 46.92022047936916, 49.39432851970196, 50.34006357192993, 48.803889602422714, 44.593901708722115, 40.53101912140846, 43.663305044174194, 42.24841296672821, 38.81519839167595, 43.46519507467747, 46.56779319047928, 46.00283570587635, 53.66254448890686, 60.64676731824875, 63.2828226685524, 58.99793319404125, 62.220422476530075, 60.59914827346802, 61.31188742816448, 57.68268696963787, 58.60431991517544, 56.94756701588631, 58.79669979214668, 57.31830172240734, 61.99332386255264, 60.0302542001009, 59.35065686702728, 56.534969955682755, 59.74532648921013, 57.81353294849396, 59.465239718556404, 54.60761457681656, 57.30384349822998, 54.57482233643532, 56.26980498433113, 55.27333125472069, 58.721505627036095, 59.367448166012764, 71.94735333323479, 69.9526047706604, 79.72026944160461, 63.959171175956726, 2.7114832028746605, 0.48039756424259394, 33.13805602490902, 69.68683943152428, 50.92531576752663, 39.24404717981815, 35.58080814778805, 36.727016642689705, 63.64957898855209, 19.335988238453865, 0.33542189514264464, 0.2026883081998676, 0.07878609307226725, 0.07291595728020184, 0.08175580442184582, 0.05577086907578632, 0.0927528076863382, 0.04873957273957785, 0.13501629960956052, 0.020186277652101126, 0.039545053223264404, 0.06590917037101462, 0.12611518817720935, 0.013631594119942747, 0.23778139933710918, 4.423773922026157, 74.22006458044052, 45.46755462884903, 27.51319695264101, 54.94941383600235, 61.46034546196461, 82.1424874663353, 43.76587674021721, 0.3053116280352697, 2.3112143436446786, 0.9044920059386641, 16.485679484903812, 92.8928630053997, 77.320067435503, 83.0864480137825, 74.40702974796295, 80.60091778635979, 76.32129102945328, 69.99844551086426, 56.52299679815769, 65.87945133447647, 70.04602655768394, 71.71122640371323, 69.6182531118393, 72.55532070994377, 69.11071434617043, 67.69541949033737, 66.86328694224358, 67.49149203300476, 67.77709230780602, 66.75413399934769, 65.37176817655563, 65.00416830182076, 67.5718729197979, 67.60072097182274, 64.08231496810913, 64.51837196946144, 64.64443400502205, 60.312795639038086, 52.75771804153919, 52.448285445570946, 50.84101729094982, 49.8943816870451, 44.73886013031006, 43.959244564175606, 40.2329783141613, 44.15635518729687, 44.80377584695816, 43.79687547683716, 47.43451528251171, 46.651723086833954, 50.15139229595661, 48.2784765958786, 47.99923337996006, 46.72831937670708, 48.88488985598087, 49.531683549284935, 52.63760268688202, 52.81524695456028, 54.248841628432274, 55.39050556719303, 53.00450339913368, 56.14682838320732, 57.90938280522823, 55.9609841555357, 54.9890761077404, 56.85979172587395, 54.116167947649956, 52.10925243794918, 49.55305740237236, 50.83586856722832, 54.85200226306915, 51.74758784472942, 51.51725560426712, 49.15979750454426, 52.96997085213661, 52.16379091143608, 53.03225331008434, 52.47728168964386, 56.343897208571434, 54.78883445262909, 57.01703488826752, 56.75193831324577, 52.730408906936646, 52.543417140841484, 50.476936027407646, 51.30952075123787, 52.864781096577644, 53.22980470955372, 48.97414706647396, 41.67334042489529, 42.297107353806496, 43.03058199584484, 50.694436356425285, 50.503861382603645, 53.988620191812515, 54.483528435230255, 54.6554160118103, 53.273278176784515, 55.37336468696594, 54.40840266644955, 50.39020948112011, 51.55267350375652, 49.47341367602348, 46.98986694216728, 46.169369369745255, 43.43436352908611, 47.055983394384384, 47.67708286643028, 49.36548426747322, 50.808855816721916, 49.52749237418175, 49.796502739191055, 45.08371062576771, 41.605947241187096, 46.609663143754005, 45.42855352163315, 42.17543788254261, 45.72996474802494, 48.926094844937325, 50.81557385623455, 58.310162499547005, 63.75842794775963, 64.00086253881454, 62.13722974061966, 67.52807646989822, 63.139973133802414, 63.01192760467529, 59.60877321660519, 60.87369114160538, 58.80210690200329, 60.696293860673904, 61.22261881828308, 64.08885821700096, 63.05220544338226, 60.93126565217972, 59.67091128230095, 61.782100796699524, 60.54456040263176, 62.958779856562614, 60.21470010280609, 59.400772377848625, 59.17670600116253, 60.422377958893776, 60.75185067951679, 63.08244042098522, 61.84336110949516, 75.0355464220047, 75.7361376285553, 82.93058797717094, 73.74622240662575, 3.583129830658436, 0.47009711852297187, 38.12174700200558, 79.29127246141434, 57.585738971829414, 47.09062233567238, 38.315570801496506, 38.25659416615963, 73.73694330453873, 24.562324695289135, 0.24617243267130107, 0.20292624074500054, 0.0551458248810377, 0.08655579295009375, 0.04823864532227162, 0.03516520562698133, 0.06099055695813149, 0.13077995739877224, 0.17375833791447803, 0.1194430653413292, 0.18966959818499163, 0.1054197248595301, 0.24145856295945123, 0.16193349118111655, 0.45754778722766787, 6.957555860280991, 88.89106974005699, 54.991728365421295, 36.552666798233986, 65.6834426522255, 70.01809805631638, 89.61262822151184, 48.01383599638939, 0.48738301440607756, 3.5001273220404983, 1.2447966984473169, 16.232328079640865, 95.84041804075241, 78.75311493873596, 84.50974524021149, 77.05184742808342, 82.42183327674866, 80.09891912341118, 72.16893464326859, 59.31087680160999, 67.839165776968, 72.56413623690605, 74.03495371341705, 69.90070715546608, 74.22986045479774, 72.97294110059738, 68.52214112877846, 70.38314446806908, 72.1296751499176, 70.8056589961052, 67.74845704436302, 69.80461031198502, 67.1793007850647, 69.64013233780861, 73.16124379634857, 65.82895204424858, 68.05456101894379, 68.6768764257431, 62.54061609506607, 55.372578129172325, 55.69750629365444, 51.935438364744186, 53.08461830019951, 48.53032328188419, 47.08927720785141, 43.937806114554405, 47.59721115231514, 48.12942959368229, 47.283063009381294, 50.00321164727211, 49.00943577289581, 53.31835515797138, 50.188945680856705, 48.08108098804951, 50.4326494038105, 53.34877252578735, 50.46049050986767, 57.33412027359009, 57.579264119267464, 58.812719732522964, 61.11420303583145, 56.15543112158775, 59.90144871175289, 62.20625303685665, 59.1638208925724, 58.07023197412491, 60.79572692513466, 57.850816547870636, 56.64628878235817, 52.474249452352524, 53.586863949894905, 57.254746332764626, 56.19257412850857, 54.48386661708355, 54.93547238409519, 56.81468814611435, 56.37551911175251, 57.57082857191563, 56.39023572206497, 58.47500145435333, 57.867212668061256, 60.51051802933216, 59.70043569803238, 55.62114559113979, 57.261194586753845, 51.349699795246124, 52.682523876428604, 57.65053689479828, 58.98373335599899, 49.429757818579674, 42.151430770754814, 43.267123103141785, 43.02076332271099, 51.56343832612038, 54.19296942651272, 56.25353045761585, 56.63002945482731, 57.37553805112839, 56.48197419941425, 58.72740291059017, 57.997040301561356, 54.99374985694885, 54.408786445856094, 53.3261751383543, 49.98168580234051, 49.49342340230942, 44.800933599472046, 50.005255937576294, 49.65784437954426, 53.112269416451454, 54.52620394527912, 53.68438571691513, 53.89463223516941, 48.72150242328644, 45.98455488681793, 48.756331354379654, 49.09090720117092, 44.724914878606796, 48.58098976314068, 51.89444996416569, 52.260754108428955, 58.90103459358215, 66.17860928177834, 65.89320659637451, 63.156471848487854, 67.8684090077877, 65.74341103434563, 65.37445083260536, 62.591255977749825, 63.63335765898228, 60.50250805914402, 63.12929190695286, 65.08818939328194, 67.77501001954079, 66.11892968416214, 65.90750142931938, 63.106926307082176, 65.58710262179375, 63.69041159749031, 65.32129168510437, 61.303991451859474, 61.93935915827751, 61.24615095555782, 64.39564615488052, 63.21715459227562, 65.3896576166153, 68.385568857193, 78.52608472108841, 78.37769508361816, 86.23375833034515, 77.08687394857407, 4.531643958762288, 0.4769808944547549, 45.35409651696682, 88.53810667991638, 65.59322029352188, 60.184655115008354, 54.43320393562317, 54.19340640306473, 86.85574695467949, 30.91376557946205, 0.4717735410667956, 0.35720324667636305, 0.17966299841646105, 0.23942115978570655, 0.1507207826944068, 0.1648292623576708, 0.20420234883204103], [0.1286932607763447, 0.02763142707408406, 0.030643761820101645, 0.07133630337193608, 0.03170071926433593, 0.0786551262717694, 0.07698471512412652, 0.3245408524526283, 3.0781115172430873, 59.894821867346764, 43.92643712460995, 54.33956556022167, 44.90381307899952, 50.0201815366745, 72.9935359954834, 54.3937012553215, 0.0305115778974141, 1.8321770173497498, 0.4491253610467538, 33.504949137568474, 89.51497346162796, 72.02765822410583, 78.35634782910347, 75.10635942220688, 76.09201893210411, 63.891785591840744, 53.8394819945097, 65.22505804896355, 73.46608623862267, 72.28096023201942, 68.22360634803772, 67.2796382009983, 67.52673134207726, 68.58969390392303, 67.06433415412903, 67.55313232541084, 66.45419329404831, 64.41762417554855, 65.88304594159126, 67.35232070088387, 67.34010055661201, 63.86724650859833, 63.52737374603748, 60.7992797344923, 61.859886422753334, 63.39056968688965, 60.23870721459389, 50.08736953139305, 47.201367393136024, 49.122183322906494, 48.55507135391235, 44.180989265441895, 41.7821703851223, 41.54548488557339, 41.02064944803715, 41.897649988532066, 43.08776132762432, 43.971609100699425, 46.77008293569088, 44.26493816077709, 44.884198531508446, 43.47958870232105, 42.7935279160738, 44.31354135274887, 48.36169213056564, 49.44299250841141, 51.02672852575779, 51.58633589744568, 53.06474916636944, 56.375120133161545, 52.48583883047104, 50.21824970841408, 53.27510587871075, 51.32569648325443, 49.77591164410114, 49.76082645356655, 48.41063730418682, 46.80842287838459, 45.315494388341904, 44.92689684033394, 45.147490203380585, 47.80288651585579, 49.33096691966057, 48.583611622452736, 48.84986713528633, 51.189884170889854, 51.68456442654133, 54.971619844436646, 51.9446262717247, 52.35096886754036, 51.29284344613552, 51.89576469361782, 49.6141467243433, 48.687961623072624, 44.82285462319851, 48.96427519619465, 48.10979604721069, 49.63797144591808, 45.332817658782005, 40.073740258812904, 44.71494421362877, 47.213389948010445, 53.51638153195381, 48.627670258283615, 51.763470992445946, 52.50039204955101, 52.46460556983948, 50.305705815553665, 49.8801476508379, 50.38671366870403, 47.75672659277916, 49.20530006289482, 45.23709699511528, 44.72160905599594, 43.379312083125114, 41.53021350502968, 41.8304467946291, 42.374695390462875, 46.7792784422636, 43.79267290234566, 43.32210995256901, 43.715065866708755, 42.354989647865295, 42.26376034319401, 40.621773451566696, 39.9575424939394, 43.447385430336, 46.10254995524883, 50.32042242586613, 58.2607651501894, 60.596617609262466, 64.65571179986, 61.10634885728359, 64.28755715489388, 62.423415184020996, 61.09483167529106, 59.938796907663345, 61.0988100618124, 61.6448787599802, 61.21636055409908, 63.952635526657104, 63.93331736326218, 62.0166090130806, 66.19567796587944, 65.65407022833824, 64.94429111480713, 62.417875081300735, 64.930969029665, 63.91855135560036, 65.5473567545414, 60.68406991660595, 63.79878178238869, 61.70294724404812, 64.36308190226555, 60.0651591271162, 72.27773040533066, 70.95166996121407, 77.64887899160385, 56.975324526429176, 2.664487324655056, 0.15407474100356922, 32.114706337451935, 71.22831031680107, 48.70375357568264, 41.82887367904186, 30.871992520987988, 29.340573996305466, 69.8780831694603, 18.79044011235237, 0.2584283781470731, 0.1753037713933736, 0.12587827979587018, 0.05860502344148699, 0.04828574201383162, 0.04981270343705546, 0.051475336877047084, 0.08793681103270501, 0.034414682813803665, 0.03183138549502473, 0.024066741498245392, 0.10080453110276721, 0.064459711429663, 0.04272572376066819, 0.38577985076699406, 4.686369281262159, 72.49431878328323, 46.01667836308479, 54.771123602986336, 53.98518517613411, 56.38105161488056, 76.51059687137604, 59.547930881381035, 0.047900055287755094, 2.1012905705720186, 0.41883490048348904, 39.18821677565575, 92.14283645153046, 75.53455844521523, 81.32367700338364, 78.71474459767342, 77.41016820073128, 66.15058958530426, 58.971995785832405, 70.27527585625648, 76.32013589143753, 74.46113884449005, 71.60531848669052, 70.99253296852112, 69.96836632490158, 69.4900631904602, 69.60444465279579, 68.75470384955406, 68.58551412820816, 68.33453759551048, 67.0818056166172, 70.17857104539871, 69.01414632797241, 67.60202810168266, 64.90160420536995, 64.47109490633011, 65.1595039665699, 66.10921740531921, 62.301304936409, 52.62285187840462, 48.76101650297642, 50.344087556004524, 50.41434958577156, 45.88001489639282, 41.53575740754604, 43.5845884680748, 44.7490169852972, 44.5360954105854, 44.766872227191925, 46.647444516420364, 48.07917349040508, 46.133233308792114, 47.13044799864292, 45.597146674990654, 45.98959341645241, 46.46961785852909, 49.60889160633087, 52.759340554475784, 54.6660440415144, 56.461747884750366, 55.65524496138096, 59.40295726060867, 53.80755990743637, 55.367740988731384, 55.740026012063026, 54.11180958151817, 51.319506615400314, 50.92644050717354, 51.55900776386261, 49.667051285505295, 47.967911660671234, 48.56483303010464, 49.17563505470753, 50.33730112016201, 52.88553178310394, 50.706356316804886, 51.773829236626625, 54.14964035153389, 55.234071761369705, 57.30624496936798, 54.41371098160744, 52.33783297240734, 55.415633618831635, 55.86915448307991, 53.65188606083393, 53.39874364435673, 49.39354956150055, 51.792007461190224, 50.076832696795464, 51.044021397829056, 47.51592971384525, 41.841249614953995, 47.320160418748856, 48.6056200414896, 53.61595518887043, 51.94331154227257, 55.33492594957352, 54.96073342859745, 54.825308695435524, 53.3115953207016, 53.91866974532604, 54.14808623492718, 49.698882177472115, 52.6814029365778, 48.60069550573826, 47.42416463792324, 47.55852922797203, 43.37238885462284, 44.36749465763569, 45.40636271238327, 48.48426595330238, 47.2844423353672, 43.68359595537186, 45.668415650725365, 44.96632732450962, 44.8129827529192, 42.71794617176056, 41.51472553610802, 47.08365350961685, 48.61934870481491, 52.03085884451866, 59.51555281877518, 63.93451049923897, 65.19195422530174, 63.6188842356205, 65.11909693479538, 65.90229570865631, 65.11793419718742, 63.97208288311958, 65.44919282197952, 64.186482578516, 64.54906672239304, 66.35010167956352, 64.79657024145126, 64.53541785478592, 70.39266675710678, 67.59502127766609, 68.16110730171204, 65.37501320242882, 69.40178632736206, 66.0836523771286, 67.96421706676483, 66.31834298372269, 68.52147236466408, 67.07192614674568, 68.76722037792206, 65.16042351722717, 75.3787288069725, 74.61929395794868, 82.25984796881676, 64.07879635691643, 2.639944441616535, 0.11825228197267279, 37.10193872451782, 78.91323074698448, 55.72498261928558, 53.10806684195995, 28.987018167972565, 34.47814151644707, 80.70613414049149, 23.355564549565315, 0.25562023976817727, 0.21032631397247314, 0.10985619461280294, 0.0675093149766326, 0.023812016006559134, 0.019510676502250135, 0.0339825487753842, 0.1781265894533135, 0.09914474750985391, 0.09140164620475844, 0.11170893660164438, 0.4692026524571702, 0.12162256010924466, 0.2679286402417347, 0.6437464943155646, 6.304081175476313, 82.61525809764862, 57.40239500999451, 66.9913400709629, 63.382977694272995, 66.09508216381073, 84.8862062394619, 65.51036953926086, 0.1350897128577344, 3.895757580175996, 0.4661143384873867, 40.626849979162216, 95.08025363087654, 77.05188542604446, 84.18105527758598, 81.72302037477493, 82.46944472193718, 68.56469884514809, 60.10821841657162, 72.11870893836021, 78.57937306165695, 79.1677638888359, 72.6753106713295, 72.55426436662674, 72.22340852022171, 71.11105620861053, 72.93114334344864, 70.34876391291618, 71.48119434714317, 68.61998587846756, 70.75744718313217, 71.24129042029381, 71.22315779328346, 68.7665668129921, 67.46560022234917, 65.5796018242836, 64.55450043082237, 66.98286652565002, 66.69158175587654, 53.71223442256451, 49.965707659721375, 51.77537955343723, 54.96365927159786, 49.7431156039238, 45.76676957309246, 46.5924196690321, 47.97684118151665, 46.62082314491272, 48.036539778113365, 48.38698357343674, 51.628943011164665, 49.389711767435074, 50.185096487402916, 48.46311628818512, 49.6098605543375, 48.75206038355827, 53.88243108987808, 55.450363755226135, 56.95574417710304, 58.93842078745365, 60.142097398638725, 64.39357906579971, 59.41996514797211, 58.015374317765236, 58.898610323667526, 58.39006081223488, 53.38849939405918, 56.53644807636738, 55.84219492971897, 50.7705994695425, 52.79019109904766, 52.27088436484337, 53.64322632551193, 53.670755848288536, 56.476958468556404, 54.0577232837677, 54.948600679636, 57.68603838980198, 57.4447513371706, 60.85641346871853, 58.33345144987106, 54.21232558786869, 55.681250765919685, 58.269918859004974, 55.08581891655922, 55.5874489992857, 50.069647282361984, 54.92507614195347, 53.60870897769928, 54.03348058462143, 50.17245456576347, 45.49026980996132, 48.44751812517643, 52.122916504740715, 58.54788154363632, 55.597393065690994, 60.01092083752155, 57.258998304605484, 57.37584203481674, 57.8922875225544, 56.205185651779175, 58.697179332375526, 53.33268418908119, 56.81077815592289, 51.501893028616905, 51.246789917349815, 50.22063598036766, 45.79118326306343, 47.180282324552536, 47.11870662868023, 51.740258038043976, 48.473067954182625, 47.542729675769806, 49.45952542126179, 46.81105233728886, 48.40166978538036, 44.78118225932121, 44.823116809129715, 49.123273864388466, 50.14012970030308, 55.30423119664192, 61.03562705218792, 65.47269836068153, 67.89386004209518, 66.62499412894249, 67.30526402592659, 68.23155552148819, 66.84254005551338, 65.14739781618118, 63.135789558291435, 67.88633644580841, 66.4200559258461, 68.68876978754997, 68.07985246181488, 66.7649482190609, 72.60570600628853, 70.10009765625, 70.78052714467049, 70.59457272291183, 71.64391681551933, 71.02578118443489, 69.91807222366333, 69.35989737510681, 70.28834715485573, 68.6845064163208, 69.05670404434204, 69.56833899021149, 78.11461240053177, 80.05133047699928, 83.89566779136658, 71.1287784576416, 3.64715235773474, 0.24645431520184502, 44.38780836760998, 88.1880770623684, 62.25544899702072, 64.68896001577377, 44.536946564912796, 45.193152353167534, 92.58559629321098, 27.203903049230576, 0.4448674223385751, 0.3156666364520788, 0.19283932575490326, 0.17932024493347853, 0.16224957187660038, 0.12965492089278996, 0.21440974407596514], [0.08502324315486476, 0.03477847247268073, 0.025246244222216774, 0.10428078050608747, 0.012284553413337562, 0.022769547140342183, 0.005267122714940342, 0.4515946941683069, 3.3336451929062605, 66.07716992497444, 43.00993010401726, 30.576651468873024, 31.65242314338684, 55.59429243206978, 64.72128108143806, 69.93629604578018, 0.48679351166356355, 0.8518926159013063, 0.15411305066663772, 49.7769033908844, 88.51390957832336, 73.99730533361435, 74.55408945679665, 66.53521254658699, 64.56203162670135, 55.22493325173855, 62.93370500206947, 72.4274879693985, 70.71258679032326, 72.27124035358429, 73.06366503238678, 70.11123865842819, 73.30955743789673, 68.02292391657829, 68.70134711265564, 71.27546578645706, 65.34762427210808, 65.91262355446815, 66.41198515892029, 62.8540650755167, 60.40681779384613, 61.252215430140495, 58.729017823934555, 62.251653000712395, 64.31766673922539, 62.31684610247612, 57.69596345722675, 49.75521795451641, 49.66324768960476, 49.71146710216999, 49.11508150398731, 43.719044253230095, 42.52086974680424, 40.63579089939594, 42.07573503255844, 42.140643149614334, 41.8425415456295, 42.59153835475445, 45.063564106822014, 44.419586062431335, 43.271101489663124, 38.933816626667976, 42.26439110934734, 41.91056549549103, 46.40567488968372, 50.07546477019787, 51.17308147251606, 51.214788034558296, 50.67134119570255, 50.341404899954796, 51.008554100990295, 50.15971764922142, 47.99872800707817, 48.80621127784252, 49.28239032626152, 52.979603335261345, 54.9892470985651, 53.097511008381844, 52.21307046711445, 49.31297488510609, 49.01049591600895, 51.92113973200321, 49.564019814133644, 48.175551518797874, 49.07212860882282, 51.84656873345375, 50.74715472757816, 53.69236908853054, 50.24095728993416, 51.170573607087135, 52.67912305891514, 50.29255472123623, 49.64188143610954, 49.22155559062958, 49.88413363695145, 48.9683523774147, 48.137709349393845, 44.578835517168045, 45.53720869123936, 42.77707099914551, 39.09946493804455, 42.85512641072273, 44.76229727268219, 47.381755113601685, 45.87589591741562, 51.26283645629883, 53.17665696144104, 52.95851446688175, 54.33135040104389, 50.299626141786575, 49.793337509036064, 47.03743278980255, 47.223303616046906, 42.29088328778744, 40.1765513420105, 40.330747067928314, 39.72454659640789, 43.20077106356621, 42.37207353115082, 45.031227841973305, 41.22569404542446, 41.121895015239716, 39.50086019933224, 42.77096472680569, 41.27410724759102, 42.51038230955601, 43.18972505629063, 46.691924929618835, 46.51899240911007, 61.631537675857544, 58.47654417157173, 60.837733671069145, 60.18482230603695, 68.69611859321594, 67.24926263093948, 61.8108956515789, 62.05139994621277, 63.29218156635761, 65.02319008111954, 64.25309300422668, 63.293709084391594, 66.58533185720444, 66.02358520030975, 66.98058664798737, 63.2000745087862, 68.12130823731422, 66.88752964138985, 68.80002021789551, 68.16961884498596, 71.32379919290543, 66.23844087123871, 73.60970333218575, 69.29115906357765, 73.89036387205124, 66.44093960523605, 71.2466861307621, 66.82906597852707, 76.18870854377747, 45.70168286561966, 2.121233087964356, 0.193850323848892, 38.08227851986885, 68.25424030423164, 49.34053100645542, 37.76016220450401, 47.19513192772865, 39.90535229444504, 62.644149139523506, 17.81179502606392, 0.33420260588172823, 0.24245664768386632, 0.1244769491313491, 0.08002201386261731, 0.04102446524484549, 0.012684990324487444, 0.08010048113646917, 0.060080453840782866, 0.04895085847238079, 0.019941077625844628, 0.029080891581543256, 0.009331046858278569, 0.04960580750775989, 0.043386895704315975, 0.4022488201735541, 4.146894179284573, 72.3523736000061, 48.06887224316597, 30.068056359887123, 40.996190160512924, 66.94517254829407, 70.78121110796928, 77.84842908382416, 0.7266722351778299, 1.536653337534517, 0.1902137853903696, 56.01306416094303, 91.85825452208519, 77.64804303646088, 76.72911554574966, 68.13635542988777, 67.89636790752411, 58.731829673051834, 66.5320435166359, 76.46609365940094, 72.15830281376839, 74.55957636237144, 75.2367152273655, 73.95211815834045, 76.84078395366669, 69.81245309114456, 69.65005740523338, 72.94093921780586, 66.8071411550045, 68.06825548410416, 66.3646624982357, 64.03437674045563, 62.28339269757271, 63.80944401025772, 62.25772127509117, 63.264272063970566, 64.63441774249077, 64.14290651679039, 60.660055205225945, 50.42276233434677, 50.562636628746986, 52.11172230541706, 51.64620168507099, 47.38942310214043, 43.44763621687889, 42.27427437901497, 44.39055562019348, 43.26342970132828, 44.861088171601295, 46.500388607382774, 45.84882237017155, 46.96845889091492, 45.74365921318531, 42.58744977414608, 44.66909967362881, 44.08177278935909, 50.13906955718994, 52.95226760208607, 54.153177961707115, 54.55140419304371, 53.8189022988081, 53.54747526347637, 53.93806390464306, 53.88929732143879, 51.69820949435234, 51.80767402052879, 53.82149375975132, 57.45450921356678, 58.17345343530178, 57.41741940379143, 54.71370868384838, 51.804485991597176, 50.949197486042976, 54.75402072072029, 51.89349241554737, 51.79152488708496, 53.04231896996498, 54.26255129277706, 53.38387884199619, 55.622870698571205, 52.443448305130005, 52.7246256172657, 57.04434782266617, 55.205147713422775, 54.294883757829666, 53.91655705869198, 51.67695723474026, 50.21392174065113, 50.3261449187994, 47.42478780448437, 48.116726875305176, 45.69454684853554, 42.343696653842926, 44.87920939922333, 48.51616904139519, 50.69422736763954, 47.37873427569866, 54.171975553035736, 56.10658474266529, 56.62990406155586, 55.72204537689686, 54.62221719324589, 51.89929470419884, 50.08682236075401, 50.015606582164764, 44.36219394207001, 44.14613373577595, 42.398235127329826, 41.083931252360344, 45.42616344988346, 45.393975377082825, 45.853469520807266, 43.632735684514046, 43.53513792157173, 42.31003426015377, 44.9672544747591, 43.16788762807846, 44.897900596261024, 46.48426987230778, 49.97153654694557, 49.92467366158962, 62.93766438961029, 60.44117175042629, 62.76267237961292, 62.34371446073055, 65.44729292392731, 67.63752579689026, 64.07032281160355, 65.2805806696415, 63.81941467523575, 66.44823521375656, 68.16055253148079, 65.14337003231049, 68.99298906326294, 69.77871850132942, 69.73981618881226, 66.80021032691002, 71.21010929346085, 69.28821042180061, 71.49963855743408, 70.70502519607544, 74.06575486063957, 70.97231045365334, 76.60205036401749, 73.97963628172874, 75.56612715125084, 69.46909591555595, 75.77538952231407, 71.03607103228569, 83.96692156791687, 51.49073302745819, 2.07983217202127, 0.1928235773812048, 44.43557560443878, 78.57507929205894, 57.04989552497864, 46.9386038929224, 52.13736712932587, 47.897725626826286, 70.24975642561913, 21.839041225612164, 0.45313506620004773, 0.18123777641449124, 0.05525327302166261, 0.06568017328390852, 0.08238562804763205, 0.029565950026153587, 0.05543416780710686, 0.1583203749032691, 0.14785809646127746, 0.12450826034182683, 0.15225757757434621, 0.1933290096349083, 0.2475370344473049, 0.27971637959126383, 0.7294829562306404, 6.6769627667963505, 86.34192332625389, 55.550537779927254, 42.539082169532776, 44.15847547352314, 74.63095933198929, 74.18621599674225, 85.3895728290081, 0.7586646778509021, 2.8466360131278634, 0.6087293545715511, 58.35384115576744, 93.8088646531105, 79.97518256306648, 80.21726757287979, 70.36612898111343, 68.79353776574135, 61.41967624425888, 68.43409225344658, 78.4086862206459, 73.20238798856735, 76.89047768712044, 76.5051631629467, 74.43008691072464, 79.4600822031498, 74.43668335676193, 67.71152302622795, 73.92662152647972, 68.87375146150589, 70.10675489902496, 72.25363969802856, 68.30527916550636, 65.23874491453171, 66.84190928936005, 65.25801748037338, 64.47807893157005, 68.12635436654091, 66.97977349162102, 62.952924370765686, 54.12920504808426, 54.43324953317642, 54.30512420833111, 53.53311203420162, 49.31963972747326, 46.29716031253338, 45.498310178518295, 47.34101749956608, 45.32929144799709, 46.7995161563158, 49.54346291720867, 50.025991424918175, 49.01194743812084, 48.55751842260361, 45.481743067502975, 48.54078032076359, 47.08406388759613, 53.65385815501213, 56.5194857865572, 56.63561515510082, 57.42422103881836, 57.19258926808834, 58.69063228368759, 58.61639566719532, 56.453642919659615, 54.22506630420685, 55.09045086801052, 56.29686713218689, 58.2450757920742, 59.892215207219124, 60.00039540231228, 57.00489453971386, 54.66644302010536, 54.403162747621536, 60.59426933526993, 56.43970526754856, 54.27348330616951, 56.1465547978878, 56.495395079255104, 57.3404735326767, 57.92670227587223, 55.60251519083977, 54.43411588668823, 59.63026866316795, 58.23051117360592, 57.39428624510765, 57.335609793663025, 54.094429314136505, 55.345565378665924, 54.634083956480026, 49.686593636870384, 51.82030454277992, 48.4664449095726, 46.204304695129395, 48.221498653292656, 51.626397147774696, 53.42906601727009, 50.92460140585899, 58.45884472131729, 58.756972923874855, 58.25898304581642, 61.75880044698715, 56.29531681537628, 55.99127233028412, 52.920546904206276, 53.58224339783192, 45.7220383733511, 46.82337127625942, 45.08063659071922, 44.67126935720444, 48.26172709465027, 49.073914512991905, 49.19913299381733, 45.071737468242645, 45.22762790322304, 44.902547746896744, 47.77234375476837, 46.4360124617815, 46.38446442782879, 48.215361982584, 51.03262960910797, 50.564145147800446, 63.92269313335419, 62.233706563711166, 63.94531711935997, 66.2780499458313, 70.21275401115417, 68.0987374484539, 66.79733768105507, 67.81544744968414, 67.83612594008446, 68.16354677081108, 69.86171364784241, 68.97599637508392, 71.68683931231499, 73.8029457628727, 71.87073424458504, 70.22087037563324, 74.07944172620773, 72.78619632124901, 73.42004030942917, 74.92653027176857, 77.09941327571869, 74.15177464485168, 80.49138486385345, 77.87085548043251, 78.1965360045433, 74.46110844612122, 78.97427067160606, 77.29507997632027, 85.89804634451866, 62.33773358166218, 3.24038655962795, 0.2769599243765697, 51.89937449991703, 87.50605925917625, 65.44503584504128, 55.81411063671112, 68.72194200754166, 56.4913634955883, 81.64710804820061, 27.3220482096076, 0.5386252538301051, 0.2727464254712686, 0.176097602234222, 0.2078715863171965, 0.1865081678261049, 0.18764211010420695, 0.09750781464390457], [0.019171821149939205, 0.00707044323462469, 0.046326501833391376, 0.08102509324089624, 0.032114266214193776, 0.0582117816520622, 0.05595290676865261, 0.058312635810580105, 0.7815371942706406, 49.01272639632225, 52.225526198744774, 55.11771060526371, 33.23166020214558, 47.21516825258732, 60.56559607386589, 77.4194473028183, 2.745890119113028, 0.41682795505039394, 0.403901434619911, 61.20835058391094, 83.11003714799881, 70.98497897386551, 73.71747314929962, 64.32130694389343, 61.25102989375591, 58.896208852529526, 70.08107587695122, 72.16652557253838, 75.83116292953491, 72.5548343360424, 63.96042510867119, 59.55646902322769, 53.82307067513466, 72.9478320479393, 76.1985120177269, 57.363435700535774, 58.031854033470154, 58.0167992413044, 64.63691800832748, 59.137017130851746, 63.50211650133133, 61.171754747629166, 65.23321241140366, 64.68653574585915, 65.6184433400631, 64.02524963021278, 52.58472092449665, 48.518749102950096, 50.976183637976646, 47.87974499166012, 50.79785540699959, 46.872483640909195, 43.232685551047325, 41.89343981444836, 41.4010014384985, 44.055474400520325, 41.483947187662125, 43.575221970677376, 44.14499759674072, 43.30183804035187, 41.44368454813957, 37.82950468361378, 40.312242060899734, 38.98273520171642, 44.803984835743904, 48.33289347589016, 48.06918382644653, 49.06110160052776, 49.06107120215893, 48.399921879172325, 48.983703553676605, 47.11868762969971, 48.28735671937466, 51.75098866224289, 56.17702156305313, 55.19260838627815, 52.62328125536442, 54.11661632359028, 51.96862958371639, 49.412255957722664, 48.82858447730541, 49.58021454513073, 48.02677050232887, 48.64290364086628, 49.908167347311974, 51.23187951743603, 51.489296704530716, 53.955056592822075, 45.473337918519974, 47.944630309939384, 55.09501442313194, 51.99113957583904, 49.13896702229977, 50.57675667107105, 50.01708850264549, 47.630417570471764, 47.883301600813866, 45.66422827541828, 46.74444571137428, 48.710532411932945, 48.05545516312122, 52.068568021059036, 52.12977513670921, 49.097993820905685, 46.61415830254555, 41.56915381550789, 45.67709058523178, 49.902646243572235, 49.525079503655434, 47.622589990496635, 50.90147964656353, 48.298193737864494, 42.553977370262146, 40.50956927239895, 37.44316041469574, 39.29113805294037, 36.31850056350231, 39.11169648170471, 42.746695429086685, 42.35861845314503, 41.72495685517788, 41.154428869485855, 41.96029722690582, 40.72539769113064, 40.71828067302704, 41.89432896673679, 43.47327344119549, 45.023871436715126, 49.83241841197014, 56.40812136232853, 62.032180577516556, 60.911882892251015, 56.763755679130554, 60.59143088757992, 80.03749161958694, 65.39139792323112, 61.18165701627731, 64.62472826242447, 64.22297582030296, 66.8889507651329, 64.14401605725288, 65.90644508600235, 66.49184167385101, 67.97445371747017, 69.1316132247448, 69.68356400728226, 66.57675951719284, 73.48641514778137, 69.52961146831512, 72.76815488934517, 71.28736674785614, 73.77548843622208, 71.5630267560482, 73.68698358535767, 68.00544485449791, 73.03035601973534, 67.11925640702248, 77.59866088628769, 32.35432907938957, 1.517389677464962, 0.23138485819799826, 42.214921563863754, 69.62487995624542, 45.03453366458416, 45.29344417154789, 32.12511397898197, 33.15769337117672, 65.57905465364456, 12.821776438504457, 0.2546172123402357, 0.07287961430847645, 0.029266845958773047, 0.044803347627748735, 0.019763982636504807, 0.018569620260677766, 0.0729621114442125, 0.1037587686732877, 0.03143257759802509, 0.05676310196577106, 0.015811445118742995, 0.06336569669656456, 0.045929805346531793, 0.023492844266002066, 0.1366164887440391, 1.3007936999201775, 60.54188534617424, 56.83860406279564, 50.032971650362015, 42.42778994143009, 55.70798233151436, 65.861387103796, 84.10910993814468, 3.4480931516736746, 0.3089653101051226, 0.9245260746683925, 67.46416389942169, 88.15475285053253, 75.57769373059273, 76.27710700035095, 68.188686221838, 65.36952629685402, 62.81812280416489, 73.47063839435577, 74.40550222992897, 79.58147048950195, 72.5083476305008, 66.55550345778465, 61.37860044836998, 56.44918955862522, 66.84377878904343, 74.91810232400894, 61.582702696323395, 59.02175411581993, 61.55898816883564, 63.830859661102295, 64.26927253603935, 65.68256869912148, 65.32747015357018, 67.92862817645073, 66.12336784601212, 65.11240169405937, 66.5908719599247, 53.137944638729095, 49.45141285657883, 52.29467108845711, 49.76304933428764, 51.61931052803993, 49.378855749964714, 47.20294050872326, 43.73813442885876, 44.083155915141106, 46.154398173093796, 43.60969752073288, 44.60181288421154, 47.709989100694656, 46.18324622511864, 44.66124549508095, 39.925776198506355, 44.01784121990204, 40.96313953399658, 46.551264077425, 49.19170059263706, 50.3942296653986, 51.15600898861885, 53.59544388949871, 51.65955416858196, 51.14109478890896, 49.25083301961422, 51.47108048200607, 55.173746198415756, 57.54254288971424, 56.20195962488651, 54.51930731534958, 55.25843985378742, 52.57261857390404, 53.098464757204056, 49.73366931080818, 52.955326437950134, 50.95897816121578, 53.22137676179409, 53.01939100027084, 54.692213237285614, 53.54660890996456, 56.69289708137512, 47.924753576517105, 49.15114916861057, 57.02942982316017, 54.01719845831394, 54.906704127788544, 51.84411406517029, 52.11673803627491, 49.21575330197811, 52.36820474267006, 49.52013596892357, 50.45390926301479, 52.400366216897964, 51.44712656736374, 54.555378779768944, 53.292649537324905, 51.84390127658844, 49.99688878655434, 46.49004936218262, 48.39810557663441, 52.236211225390434, 52.38699473440647, 50.62863148748875, 51.40448525547981, 50.87501026690006, 45.26664040982723, 43.101356998085976, 40.33209219574928, 42.13968180119991, 39.68028277158737, 42.07272179424763, 44.66901607811451, 44.920315593481064, 43.671820387244225, 42.83044293522835, 43.256970047950745, 44.348172694444656, 42.3614265024662, 44.1854502260685, 45.799402222037315, 47.528879418969154, 49.77237023413181, 59.78315345942974, 64.68557059764862, 64.12672698497772, 59.60380308330059, 62.80106171965599, 75.89496910572052, 64.0851192176342, 64.72879707813263, 66.76022127270699, 66.46351799368858, 67.640900015831, 69.04415711760521, 66.27421215176582, 69.93901669979095, 71.45776480436325, 72.61986404657364, 73.60754504799843, 69.17695999145508, 74.56469088792801, 73.45215618610382, 75.1357014477253, 74.32537972927094, 76.56813338398933, 74.9197818338871, 79.11194488406181, 71.94977760314941, 77.20326170325279, 72.95416250824928, 85.48718959093094, 37.16359421610832, 1.4667269960045815, 0.44691966846585274, 49.66192916035652, 77.85436436533928, 53.878042325377464, 54.8114812374115, 37.20172896981239, 38.561489805579185, 75.95541626214981, 16.32077593356371, 0.397736948216334, 0.11141411101561971, 0.10123906598892063, 0.06459056690800935, 0.010512100670894142, 0.052566646481864154, 0.08347880415385589, 0.1815230876673013, 0.14749469642993063, 0.12101399159291759, 0.1445310632698238, 0.22063447802793235, 0.1375769911101088, 0.1694919535657391, 0.23636753379832953, 1.9251959072425961, 72.49241888523102, 66.75385281443596, 66.67952120304108, 48.20894032716751, 65.65125077962875, 71.04034200310707, 91.61718785762787, 3.4584592329338193, 1.1504430114291608, 1.8791994941420853, 69.7377111017704, 89.35547322034836, 76.85099020600319, 79.26202163100243, 69.6144001185894, 67.60464996099472, 63.26574258506298, 74.79136392474174, 77.52315133810043, 81.09572723507881, 75.38852468132973, 71.90795704722404, 65.1927749812603, 59.04597781598568, 64.1322822868824, 74.30114462971687, 65.9444734454155, 62.89147026836872, 63.80718693137169, 66.87367558479309, 66.25007584691048, 67.47433975338936, 66.72983810305595, 70.73036223649979, 68.53206619620323, 68.40012207627296, 68.33844378590584, 56.23078487813473, 51.50031991302967, 54.806066527962685, 51.53813548386097, 54.62004370987415, 51.3963308930397, 50.341036319732666, 45.93722842633724, 46.76691010594368, 49.394780695438385, 46.46479591727257, 47.604126781225204, 48.73358957469463, 49.42625820636749, 47.72173807024956, 43.83021108806133, 47.097659558057785, 45.017001405358315, 50.97507409751415, 53.30666318535805, 52.82965578138828, 54.93218936026096, 56.86404749751091, 53.899978548288345, 54.55967254936695, 52.30757899582386, 54.192665442824364, 60.53886450827122, 61.43928699195385, 61.32283844053745, 55.7349418848753, 58.580050617456436, 55.85837446153164, 56.34660266339779, 53.29420745372772, 57.80506320297718, 53.30966502428055, 55.229056030511856, 55.14003820717335, 57.85107113420963, 55.57622440159321, 59.59160573780537, 48.202940449118614, 50.42829863727093, 58.9619567245245, 58.941278234124184, 55.802658051252365, 54.52168218791485, 54.236040115356445, 52.033803686499596, 53.41297388076782, 51.958168745040894, 53.82841698825359, 54.83150236308575, 51.100471168756485, 57.11956098675728, 57.70442180335522, 55.37767365574837, 53.57323408126831, 48.70696060359478, 52.726198732852936, 56.239057034254074, 54.4704495370388, 52.59732864797115, 55.29594384133816, 54.382632449269295, 47.41107054054737, 47.07433640956879, 43.11693236231804, 44.692635610699654, 42.575218230485916, 43.538451343774796, 47.03084014356136, 48.83894272148609, 47.74067245423794, 46.784005388617516, 47.17840522527695, 47.0668888092041, 43.128643333911896, 47.36774906516075, 47.40388512611389, 48.977692276239395, 53.84790614247322, 63.29098463058472, 67.04930976033211, 66.09394982457161, 59.99385595321655, 66.89922541379929, 75.88203459978104, 63.920162469148636, 68.70184108614922, 67.90481865406036, 71.11340448260307, 70.62193125486374, 70.89968875050545, 68.06463047862053, 74.42665949463844, 73.01541522145271, 74.25407275557518, 74.8269148170948, 72.09646493196487, 77.32574433088303, 75.27377843856812, 77.99497202038765, 76.80534705519676, 80.74392691254616, 79.20731216669083, 82.7126544713974, 75.93513295054436, 79.02999088168144, 77.8009544312954, 91.21801167726517, 46.2763412296772, 2.183288033120334, 0.7094817794859409, 56.30774974822998, 87.89982452988625, 61.2844642996788, 65.28608277440071, 45.49905113875866, 46.20154604315758, 92.1946656703949, 21.052827313542366, 0.5149424308910966, 0.2941753756022081, 0.28172973718028516, 0.12509857944678515, 0.12897224893094972, 0.15436944784596562, 0.12407577378326096], [0.05143524605955463, 0.03119275628705509, 0.0382907271705335, 0.03148396761389449, 0.06093975323892664, 0.07323361875023693, 0.06021076755132526, 0.02861528111679945, 0.2852933225221932, 52.2527289390564, 49.40472476184368, 38.66373471915722, 32.03669652342796, 47.852139472961426, 54.457435235381126, 84.68244597315788, 9.064196068793535, 0.12062360707204789, 0.800902855116874, 65.41820928454399, 83.61931622028351, 72.91832283139229, 71.56583100557327, 64.41424995660782, 68.92438754439354, 67.19981208443642, 72.98961460590363, 67.16638907790184, 69.53360125422478, 58.87009285390377, 62.440050691366196, 57.482426315546036, 77.27021411061287, 83.06126296520233, 49.00150939822197, 58.50534662604332, 61.11080601811409, 67.53374576568604, 66.4140522480011, 66.69648349285126, 66.27920508384705, 64.8506261408329, 64.47749376296997, 64.28159907460213, 59.10881124436855, 51.704798340797424, 47.47171148657799, 48.36532473564148, 45.46139135956764, 47.8731257468462, 47.209609150886536, 47.371301874518394, 42.818838357925415, 38.77575270831585, 40.25906391441822, 41.49135299026966, 38.91824506223202, 41.672945246100426, 43.246953785419464, 44.36301849782467, 41.419650837779045, 39.3632809817791, 38.199479430913925, 38.58665205538273, 39.629563093185425, 43.1785536557436, 44.43997956812382, 46.466646417975426, 49.0654219686985, 44.281919449567795, 44.97784070670605, 49.94551174342632, 50.9705675393343, 52.73854047060013, 51.187501698732376, 52.07183204591274, 51.752219796180725, 54.71652053296566, 47.7045363932848, 46.46630443632603, 48.660736083984375, 48.48088413476944, 47.755229473114014, 51.056659519672394, 49.455421641469, 51.81258715689182, 52.048801481723785, 52.07237921655178, 48.023875057697296, 45.88895581662655, 54.934119656682014, 52.958069890737534, 52.618596106767654, 50.52129864692688, 52.443919479846954, 50.717786103487015, 46.9754733145237, 46.65632463991642, 48.05528037250042, 52.063704282045364, 53.34740459918976, 52.67796412110329, 51.6182541847229, 52.55600966513157, 50.915246307849884, 49.481408447027206, 43.218424916267395, 46.900533735752106, 48.33591051399708, 50.71934401988983, 48.62978294491768, 45.20054295659065, 43.0831141769886, 37.521474212408066, 35.02614811062813, 36.767533868551254, 34.18921262025833, 39.64177183806896, 43.689246252179146, 40.76267749071121, 40.67377746105194, 41.124011501669884, 41.63140207529068, 41.112118139863014, 40.03019459545612, 43.118026703596115, 45.343134105205536, 46.798212826251984, 44.485725313425064, 50.28848893940449, 62.20147669315338, 62.13725633919239, 63.59491892158985, 56.587631329894066, 58.6038563400507, 80.84850490093231, 59.82405826449394, 65.56640893220901, 68.03386732935905, 67.21815750002861, 64.7291998565197, 68.36125776171684, 68.23798477649689, 65.1034189760685, 62.414565458893776, 65.5581633746624, 70.09128972887993, 68.88872265815735, 68.7195785343647, 71.16748318076134, 73.67227837443352, 74.5633153617382, 72.67268121242523, 74.53091830015182, 70.73776423931122, 71.26475796103477, 69.8455873131752, 70.90803310275078, 22.360994517803192, 1.1102881911210716, 1.251688222400844, 52.30173110961914, 67.5349996984005, 48.88451747596264, 42.74927169084549, 33.52253459393978, 48.99203270673752, 64.07107517123222, 12.106030695140362, 0.6169300270266831, 0.16441956715425476, 0.10974801174597815, 0.05292276604450308, 0.1342054587439634, 0.024368567392230034, 0.05262457110802643, 0.027206714512431063, 0.05148761942109559, 0.15455805725650862, 0.00931786260480294, 0.017314357246505097, 0.009116414039453957, 0.052355538864503615, 0.06872744648717344, 0.45397672103717923, 62.59519636631012, 55.76534405350685, 41.32753998041153, 41.99308566749096, 53.66740062832832, 58.63163664937019, 93.96260440349579, 10.683561824262142, 0.2752883406355977, 1.4418708672747016, 70.02385094761848, 85.50126403570175, 74.731555134058, 74.23624411225319, 68.62211376428604, 70.84681838750839, 71.12364113330841, 73.28194051980972, 70.5795331299305, 71.73211008310318, 65.31863942742348, 65.40408924221992, 61.6819191724062, 69.15123537182808, 75.93892514705658, 58.200203999876976, 59.9056550860405, 63.91120254993439, 69.32425528764725, 69.40097317099571, 66.86764150857925, 70.58299094438553, 65.85957080125809, 66.4944939315319, 66.56075477600098, 62.00300574302673, 53.619219213724136, 49.22362267971039, 49.253272488713264, 49.353834092617035, 47.91799373924732, 49.16470684111118, 50.518885776400566, 44.118269830942154, 41.7498455196619, 43.05530346930027, 45.56045204401016, 40.84744334220886, 44.61217872798443, 44.27791826426983, 45.723672285676, 43.190743401646614, 41.944820657372475, 38.237614184617996, 40.78203745186329, 41.31536543369293, 44.6690084785223, 49.206485599279404, 48.86014938354492, 49.78339344263077, 46.557765528559685, 47.2912173718214, 51.57956086099148, 53.55283297598362, 55.41545122861862, 52.62745343148708, 55.40396444499493, 54.90814425051212, 55.67116230726242, 50.92430122196674, 50.99184639751911, 53.57476159930229, 50.202837735414505, 51.4592669159174, 53.531227335333824, 52.65284366905689, 54.900153279304504, 54.19646143913269, 54.47146788239479, 49.27866272628307, 47.35460177063942, 56.65592506527901, 56.791410595178604, 56.32126182317734, 54.589983522892, 54.52847242355347, 52.59629510343075, 50.097594782710075, 50.12827813625336, 49.56039100885391, 54.14935916662216, 54.94046911597252, 54.97040390968323, 53.63136716187, 55.72169579565525, 53.018448650836945, 52.59756803512573, 45.14453016221523, 48.193216770887375, 50.96309334039688, 53.04820865392685, 51.0775052011013, 47.83041223883629, 45.69577418267727, 41.15842245519161, 38.06019030511379, 39.994677901268005, 37.96903319656849, 41.817728877067566, 47.05317534506321, 43.575290367007256, 41.89573109149933, 43.38719666004181, 43.79669688642025, 43.78232605755329, 42.32141084969044, 46.788926124572754, 48.52186493575573, 49.378376975655556, 47.52637155354023, 52.09667131304741, 62.795415222644806, 63.70381347835064, 64.3261630833149, 60.95319427549839, 60.826440677046776, 76.16526380181313, 60.927405059337616, 67.00912311673164, 68.83133813738823, 67.52678453922272, 67.36534640192986, 73.17288637161255, 70.3328275680542, 67.62035071849823, 64.4848121702671, 68.68567675352097, 70.60745403170586, 69.31674689054489, 71.17269650101662, 70.96822947263718, 74.04478758573532, 77.20545038580894, 75.23824274539948, 77.99906820058823, 73.74936103820801, 76.94983810186386, 74.96466502547264, 78.68998512625694, 23.324197232723236, 0.720603842055425, 1.3066939520649612, 60.96205919981003, 75.81139639019966, 57.4489539116621, 51.0391690582037, 36.3936073333025, 50.956151112914085, 73.67179200053215, 15.882021076977253, 0.476190002518706, 0.14373125071870163, 0.056098401109920815, 0.028339567688817624, 0.11525957146659493, 0.0395087139622774, 0.09060271680937149, 0.12429524169419892, 0.21295362064847723, 0.21279658220009878, 0.08036305298446678, 0.16425397916464135, 0.18324582022614777, 0.17647688422584906, 0.19507494173012674, 1.0118719283491373, 76.61551684141159, 64.06686499714851, 49.54079166054726, 43.338870853185654, 66.12443938851357, 64.14778545498848, 100.24716317653656, 11.220391318202019, 0.2399153559235856, 2.3321063350886106, 74.48636189103127, 89.38210979104042, 78.7293890118599, 75.51796853542328, 73.64811167120934, 72.80087873339653, 74.84607338905334, 75.3718663752079, 74.86299768090248, 72.82976478338242, 69.77704659104347, 64.78938862681389, 61.909306570887566, 68.54696899652481, 80.66604629158974, 64.43796068429947, 62.09203116595745, 63.65583725273609, 71.22983023524284, 72.38755971193314, 70.56005537509918, 73.99538263678551, 67.88262024521828, 70.12095853686333, 69.15720105171204, 64.87844064831734, 55.17200209200382, 52.54415050148964, 52.927340939641, 51.84512861073017, 50.76987370848656, 51.50294937193394, 53.663646429777145, 44.54602807760239, 44.43603157997131, 46.575696766376495, 47.11849004030228, 44.929663091897964, 47.64569655060768, 49.87942188978195, 50.52887164056301, 47.54799619317055, 46.317857801914215, 41.48809276521206, 44.34515945613384, 44.23151895403862, 47.478946298360825, 51.03975422680378, 52.427755147218704, 54.8393527418375, 49.75731924176216, 50.29515378177166, 55.32158486545086, 56.66918255388737, 60.115643218159676, 55.80737739801407, 56.98273412883282, 60.62904126942158, 60.87824709713459, 53.21896389126778, 53.80243398249149, 57.00460575520992, 54.013478457927704, 57.09073193371296, 55.53457863628864, 54.717432484030724, 58.925037905573845, 59.54646795988083, 58.09201620519161, 52.35084347426891, 48.95052373409271, 59.76944379508495, 59.51202280819416, 59.994551315903664, 57.795924693346024, 58.33531714975834, 56.85454800724983, 52.67063811421394, 54.04928393661976, 53.05156007409096, 58.35850350558758, 58.71844679117203, 59.27643544971943, 57.23567135632038, 57.94689439237118, 57.70979851484299, 55.570433512330055, 48.94277974963188, 52.94907197356224, 54.537732526659966, 57.82805196940899, 53.484159260988235, 49.66914117336273, 48.5882967710495, 43.62449012696743, 41.524627804756165, 42.92014852166176, 39.04937982559204, 45.60317315161228, 49.99015174806118, 47.02319875359535, 44.27554339170456, 45.91544419527054, 49.21490214765072, 45.492462292313576, 46.022435054183006, 49.08849433064461, 50.72560988366604, 51.555128172039986, 51.03812411427498, 54.309649765491486, 68.39422479271889, 65.71533814072609, 67.06752598285675, 61.03513687849045, 71.56298875808716, 73.39867025613785, 56.374785751104355, 72.54759952425957, 68.832166492939, 69.88832741975784, 69.57540661096573, 75.28221398591995, 71.1698466539383, 69.37108397483826, 68.47706034779549, 72.99627184867859, 72.79793009161949, 71.92311063408852, 73.11160326004028, 74.19213607907295, 77.06121012568474, 81.96442142128944, 77.30280876159668, 80.49954682588577, 77.03467234969139, 82.50679671764374, 78.7702064216137, 83.46448212862015, 30.256976522505283, 1.0783541109412909, 1.4551298995502293, 69.52874511480331, 83.06880936026573, 66.42047390341759, 61.010267212986946, 52.16027230024338, 69.16682973504066, 87.89234653115273, 22.408522367477417, 0.8807176910340786, 0.3503441991051659, 0.2599064988316968, 0.21680915204342455, 0.1900126930559054, 0.13866615219740197, 0.19110795459710062], [0.030752543971175328, 0.10679775208700448, 0.050328796642133966, 0.012267316105862847, 0.040348402108065784, 0.020615988578356337, 0.06561058951774612, 0.04098040393728297, 0.08413431351073086, 39.610552713274956, 60.95412902534008, 39.28661249577999, 33.59771355986595, 54.650385081768036, 53.595208302140236, 82.73534685373306, 20.506321638822556, 0.12684528337558731, 1.0294033563695848, 59.702198803424835, 82.21615791320801, 69.46906551718712, 74.09970223903656, 70.47322243452072, 74.18075948953629, 71.97863325476646, 69.52282503247261, 72.61867091059685, 72.1031753718853, 67.40652099251747, 67.30746790766716, 63.97245526313782, 51.8550156801939, 40.015599578619, 57.76443958282471, 67.76746362447739, 71.16463333368301, 65.19681796431541, 63.345667496323586, 59.9031700193882, 60.95893956720829, 58.78924839198589, 59.035117998719215, 53.44032861292362, 49.32539261877537, 47.194208577275276, 48.45674403011799, 46.734680235385895, 47.857462987303734, 44.9311488121748, 47.39958755671978, 45.53198017179966, 44.47191685438156, 41.07492953538895, 42.789142951369286, 40.96484564244747, 40.15004016458988, 39.80555444955826, 40.025615841150284, 41.406093165278435, 39.735877588391304, 39.878825917840004, 37.32105776667595, 39.656507447361946, 37.60904051363468, 40.75725518167019, 42.50473201274872, 43.14734973013401, 43.68497148156166, 43.4479857981205, 49.03448402881622, 49.79858882725239, 46.521819457411766, 47.28037275373936, 47.17440024018288, 45.54325796663761, 46.497979536652565, 48.86045716702938, 44.842514768242836, 47.377468943595886, 50.48533737659454, 50.92170596122742, 47.82173730432987, 49.8449881374836, 49.80778433382511, 46.74762234091759, 46.72844097018242, 52.76128225028515, 47.50968284904957, 44.27224516868591, 50.09407237172127, 49.454498291015625, 47.7237481623888, 49.54084865748882, 51.01040460169315, 49.51543942093849, 48.3333570510149, 46.01778030395508, 49.71229165792465, 46.58679597079754, 50.9888331592083, 47.910724729299545, 52.97058641910553, 53.96901324391365, 52.768680453300476, 49.87661004066467, 46.37482434511185, 41.545325294137, 43.74364033341408, 49.629003927111626, 45.33908732235432, 40.6735722720623, 43.85816238820553, 40.95850758254528, 36.288748160004616, 35.289052203297615, 34.15561482310295, 37.213667929172516, 39.187631607055664, 40.539785251021385, 39.24701862037182, 39.59464676678181, 41.27958655357361, 42.571555227041245, 41.09894424676895, 44.86228130757809, 44.71087463200092, 47.33101263642311, 44.89148274064064, 46.24823793768883, 55.36413498222828, 59.69604313373566, 61.252610608935356, 68.84390786290169, 49.63273532688618, 51.07798017561436, 72.7382504940033, 61.699155047535896, 60.869530364871025, 63.31473335623741, 64.95821356773376, 64.773710668087, 64.65344712138176, 69.46522772312164, 69.15163055062294, 66.54944658279419, 67.64327868819237, 67.29114398360252, 70.39770528674126, 67.53002196550369, 65.96000701189041, 68.8206835091114, 67.95420840382576, 68.30309808254242, 66.9421099126339, 70.42232796549797, 73.39755311608315, 58.909063562750816, 9.794035255908966, 0.5168176302686334, 1.1818208964541554, 53.530824556946754, 67.07619711756706, 45.48289820551872, 42.58552707731724, 42.68038898706436, 41.14054061472416, 61.43005728721619, 9.946207590401173, 0.3848383028525859, 0.0596547393797664, 0.11650138490949757, 0.05126694552018307, 0.0656983262160793, 0.057153308371198364, 0.06094304837461095, 0.036114839240326546, 0.0694538235256914, 0.02115195649821544, 0.09629018037230708, 0.04104696345166303, 0.005519511832972057, 0.049812432553153485, 0.040642366802785546, 0.03427597912377678, 47.38473795354366, 69.38857063651085, 39.90529529750347, 33.5720307379961, 59.13112744688988, 59.147941544651985, 92.2101004421711, 22.313071489334106, 0.06967516907025129, 1.3924616435542703, 61.53291396796703, 86.28265410661697, 72.51636520028114, 79.6732659637928, 74.51388001441956, 77.55101144313812, 74.21110466122627, 72.25062265992165, 77.01510339975357, 72.72730708122253, 65.77646926045418, 66.5220956504345, 66.39377653598785, 49.970176219940186, 45.9956768900156, 57.8250615298748, 69.25662651658058, 73.34408238530159, 67.2502201795578, 66.02004379034042, 62.29985721409321, 63.96110147237778, 60.99195599555969, 62.42917187511921, 55.79249359667301, 52.113766595721245, 50.07827281951904, 51.251798048615456, 48.82028952240944, 47.98420898616314, 46.8057744204998, 49.46456015110016, 46.972205489873886, 44.73162151873112, 44.31366294622421, 46.29122883081436, 44.13147792220116, 43.849833235144615, 42.65325464308262, 42.541601434350014, 43.133651465177536, 43.854282796382904, 40.9106757491827, 40.340428948402405, 41.029993146657944, 40.293661057949066, 43.71294938027859, 44.27151560783386, 44.80542875826359, 47.03215107321739, 47.34403073787689, 51.28378473222256, 52.91917897760868, 50.729310885071754, 50.688124895095825, 50.064597353339195, 48.31848084926605, 47.832080349326134, 50.08237659931183, 46.85763403773308, 50.65975941717625, 52.35693074762821, 53.4122671186924, 50.01839183270931, 49.220601841807365, 52.88384847342968, 49.277712777256966, 49.14180926978588, 53.50809417665005, 49.00546498596668, 45.614177361130714, 51.51800036430359, 53.22261169552803, 49.60535779595375, 53.123657405376434, 51.26314043998718, 50.73385924100876, 50.47285884618759, 49.62806157767773, 51.01690225303173, 50.61680652201176, 52.32472367584705, 50.84584303200245, 54.67245809733868, 56.98409825563431, 55.467569231987, 51.45886793732643, 50.53421415388584, 46.2726554274559, 46.70872002840042, 50.0708632171154, 49.32737611234188, 44.253185391426086, 45.3838337212801, 43.568610325455666, 37.57557190954685, 38.86227026581764, 37.79397279024124, 39.35274414718151, 42.27427437901497, 43.067793399095535, 42.5313875824213, 41.93638511002064, 43.58678475022316, 44.05870042741299, 43.6521602421999, 47.692038863897324, 47.59692616760731, 50.09752258658409, 47.34450191259384, 48.44709634780884, 56.83369852602482, 62.37358085811138, 61.785908192396164, 67.12345898151398, 54.846678748726845, 55.33228509128094, 70.64594596624374, 61.73828914761543, 63.46767894923687, 66.25050902366638, 67.43762612342834, 65.7839472591877, 65.85645496845245, 71.64472237229347, 72.22018629312515, 70.43105229735374, 69.47285011410713, 69.45308357477188, 71.90995573997498, 70.27654498815536, 66.63738146424294, 70.52681475877762, 71.15533903241158, 70.3967933356762, 69.67515125870705, 72.8742603957653, 78.49483519792557, 62.62215591967106, 8.646892961114645, 0.4048955859616399, 1.56714444514364, 61.40690132975578, 76.50814220309258, 53.01179140806198, 51.260142400860786, 47.39731527864933, 42.86377094686031, 73.02890449762344, 13.61948948353529, 0.3706908307503909, 0.056283815574715845, 0.22275120194535702, 0.046128875328577124, 0.046949508832767606, 0.05565140185353812, 0.017573635814187583, 0.08548462894395925, 0.15132797823753208, 0.13735105167143047, 0.16220957011682913, 0.12681013526162133, 0.1566312913200818, 0.13261077634524554, 0.12181692116428167, 0.2144059888087213, 59.65611107647419, 74.24744591116905, 52.2002537548542, 45.443695709109306, 72.58044496178627, 65.7843804359436, 97.78000116348267, 23.30732613801956, 0.08305325667606667, 2.8373794723302126, 66.39498487114906, 88.98247763514519, 75.44146344065666, 81.22664541006088, 76.40532732009888, 79.64670538902283, 78.91347393393517, 75.25693774223328, 78.29399317502975, 75.16694337129593, 65.03660336136818, 66.27010837197304, 67.34887808561325, 59.28352206945419, 58.63778471946716, 57.509891241788864, 71.00690379738808, 76.27575427293777, 70.84352016448975, 67.78105169534683, 66.04974299669266, 64.86106798052788, 62.83261902630329, 64.54750880599022, 56.81036397814751, 53.407942950725555, 52.39796854555607, 54.616247713565826, 52.506277933716774, 50.80202378332615, 49.07122805714607, 53.0145500600338, 50.97611904144287, 49.20640580356121, 46.20418690145016, 49.17391374707222, 45.907742008566856, 46.666481494903564, 46.11735016107559, 44.432037994265556, 44.47236143052578, 45.64483791589737, 43.641532212495804, 41.444843485951424, 44.7996910661459, 43.36435228586197, 46.485451608896255, 46.69691786170006, 50.53236745297909, 50.28620906174183, 49.492101073265076, 54.406274780631065, 54.748476818203926, 54.171238392591476, 53.38341906666756, 53.49843129515648, 50.839022397994995, 51.070414781570435, 55.66221758723259, 48.885680213570595, 53.316367864608765, 55.50241336226463, 57.72788554430008, 52.25018687546253, 53.49987141788006, 56.69449299573898, 51.97105385363102, 53.038910552859306, 58.15436325967312, 51.98147289454937, 46.87189847230911, 54.79978546500206, 55.98279878497124, 53.162692710757256, 57.316599413752556, 56.12090237438679, 55.8102348446846, 53.341948091983795, 53.043721094727516, 55.25926060974598, 51.187843680381775, 56.09310306608677, 51.183040738105774, 56.59517392516136, 59.463096633553505, 60.47884672880173, 54.352910444140434, 50.88843494653702, 49.279453083872795, 49.52161028981209, 56.3892287760973, 50.53007237613201, 46.14967882633209, 47.25027076900005, 46.193672865629196, 39.24532391130924, 40.400480926036835, 40.153934955596924, 41.982252448797226, 43.96551802754402, 45.77225647866726, 44.226377829909325, 44.56193022429943, 45.98617359995842, 47.447073608636856, 46.311287954449654, 51.70313023030758, 49.49556648731232, 51.944630071520805, 49.52658802270889, 52.49156512320042, 60.32993271946907, 64.57736760377884, 66.82151198387146, 72.37488359212875, 56.93655900657177, 68.02031725645065, 64.50106009840965, 56.934693306684494, 67.24931582808495, 69.85152259469032, 68.39535713195801, 68.31818327307701, 67.76119396090508, 74.89271968603134, 71.60977184772491, 71.77589893341064, 72.49886333942413, 71.83127716183662, 73.53615447878838, 72.58820414543152, 71.21909201145172, 74.04905095696449, 74.74781826138496, 73.20475906133652, 71.59613817930222, 75.95127448439598, 81.15169823169708, 72.50304311513901, 13.514975141733885, 0.43202191474847496, 1.8137339944951236, 72.05296486616135, 82.43452459573746, 62.76580721139908, 62.75321468710899, 61.99514776468277, 64.0262071788311, 86.32716491818428, 20.96170250326395, 0.8330928278155625, 0.29346246854402125, 0.3732121438952163, 0.2042709826491773, 0.22531431284733117, 0.16235961753409356, 0.25915292208082974], [0.05478855498949997, 0.09139519694144838, 0.03393931867321953, 0.03467588911007624, 0.09324532657046802, 0.21603013447020203, 0.14970757300034165, 0.03424784059461672, 0.0766855182882864, 39.451877027750015, 60.46074450016022, 49.59850296378136, 44.483445435762405, 49.091553166508675, 41.0318436473608, 83.49501729011536, 26.980277448892593, 0.08166581159457564, 0.19300728861708194, 44.21133063733578, 85.73689699172974, 69.66331869363785, 74.93773207068443, 70.53243845701218, 76.14111229777336, 69.67104747891426, 73.7639370560646, 71.49882540106773, 71.23347043991089, 63.55625219643116, 60.81946425139904, 56.01737692952156, 37.97592222690582, 54.60919909179211, 68.51904809474945, 64.44481551647186, 66.81071296334267, 60.99637135863304, 65.98887786269188, 58.92542168498039, 56.422419995069504, 53.074788227677345, 51.70304283499718, 47.68256977200508, 47.06004157662392, 46.13526239991188, 46.62263944745064, 46.02419055998325, 48.025151789188385, 45.72167359292507, 46.830267906188965, 45.64234144985676, 45.17516791820526, 45.05224451422691, 42.91569136083126, 40.00712223351002, 40.37162147462368, 38.748557567596436, 39.23380672931671, 41.31826467812061, 39.690781608223915, 40.3273044526577, 40.84968142211437, 39.3856617808342, 39.81060057878494, 39.02801737189293, 42.32748292386532, 42.753470465540886, 43.75611126422882, 41.84269733726978, 47.05018110573292, 45.91631054878235, 43.74390631914139, 45.53687050938606, 45.290035754442215, 43.61168101429939, 44.99604552984238, 45.13435050845146, 45.74547551572323, 44.78946961462498, 46.539587303996086, 49.25689749419689, 48.08652609586716, 48.90019163489342, 47.45278850197792, 45.28497062623501, 48.271028995513916, 48.20973828434944, 39.21546891331673, 39.842784851789474, 50.64538858830929, 47.723064199090004, 45.61823174357414, 47.66762137413025, 49.71862591803074, 48.95283780992031, 46.43682561814785, 45.2554652094841, 46.23193681240082, 45.84662228822708, 45.92414192855358, 45.62304988503456, 48.5966981202364, 47.07972452044487, 48.66293616592884, 47.169019728899, 47.01557256281376, 48.85871686041355, 41.49441562592983, 41.70772098004818, 42.847720608115196, 42.21599690616131, 45.47140382230282, 40.94572886824608, 36.87829792499542, 36.12191051244736, 34.95714761316776, 37.44320221245289, 40.196040496230125, 41.55865877866745, 39.85542677342892, 40.1929322630167, 43.17128084599972, 41.98287941515446, 42.62861296534538, 44.16052356362343, 44.90271493792534, 45.79719454050064, 47.844532281160355, 44.96206775307655, 48.7785791605711, 58.38756054639816, 61.615639328956604, 61.40633136034012, 66.20737373828888, 48.9334512501955, 48.099206015467644, 69.8896649479866, 63.812020272016525, 62.17953287065029, 60.99183440208435, 65.99491953849792, 66.9630315899849, 64.8993319272995, 66.12334504723549, 71.10649645328522, 68.6306557059288, 65.76742574572563, 69.45229321718216, 67.77421966195107, 67.97617882490158, 68.06934982538223, 67.6613201200962, 68.41278299689293, 70.11821508407593, 67.84646898508072, 59.22774486243725, 31.30071211606264, 1.2635205499827862, 0.20294126181397587, 1.6289818519726396, 64.71355229616165, 60.933165550231934, 42.11881332099438, 40.56983783841133, 31.02004397660494, 41.90866939723492, 59.347898215055466, 6.62897371686995, 0.37051865248940885, 0.051596292105386965, 0.016857069967954885, 0.02381786413025111, 0.03019573097844841, 0.06930805087904446, 0.06408948363969103, 0.045651807959075086, 0.03995371313067153, 0.036305942267063074, 0.018809309840435162, 0.08361135915038176, 0.12307938857702538, 0.10435149233671837, 0.09534964177873917, 0.11074496098444797, 48.676471039652824, 64.75544884800911, 49.39401313662529, 53.1372606754303, 57.770200073719025, 46.43193908035755, 89.73717793822289, 29.9766693636775, 0.1390712906140834, 0.4362188489176333, 45.51814891397953, 88.79655361175537, 70.84543526172638, 78.81172299385071, 72.29649379849434, 79.15375024080276, 71.05878621339798, 76.46648123860359, 73.82490858435631, 73.47715884447098, 63.820964992046356, 64.12661299109459, 57.2868812084198, 43.214378133416176, 57.34276860952377, 70.22730723023415, 65.91800406575203, 69.83536586165428, 61.75890304148197, 69.09132018685341, 61.57650142908096, 57.04642631113529, 55.6700299680233, 51.698087900877, 49.92854565382004, 51.21967077255249, 48.509899377822876, 48.63612100481987, 49.33598645031452, 49.41950596868992, 48.32912787795067, 48.51015776395798, 48.42180870473385, 48.00186283886433, 47.43917003273964, 44.48750741779804, 42.78740644454956, 43.85655127465725, 41.06126166880131, 42.501771971583366, 43.34636025130749, 43.00742603838444, 39.96323458850384, 43.96857686340809, 42.947868034243584, 42.989099621772766, 41.40883281826973, 44.713526889681816, 45.986412987113, 45.648265331983566, 44.042251110076904, 48.981773257255554, 48.515515476465225, 45.44251777231693, 47.43556782603264, 46.82244032621384, 45.816261917352676, 47.534795701503754, 47.74378828704357, 47.77266673743725, 46.66928954422474, 48.593472093343735, 51.95968106389046, 50.013136714696884, 49.835215061903, 50.66927410662174, 48.46834860742092, 51.62676192820072, 48.73577065765858, 40.48670209944248, 39.01586562395096, 50.583011135458946, 50.06895191967487, 46.97364181280136, 50.04498280584812, 50.06732560694218, 49.54315513372421, 49.70197521150112, 47.1638710051775, 47.985671907663345, 46.80463068187237, 47.051936611533165, 48.63170564174652, 49.50228072702885, 50.47198869287968, 52.222319170832634, 51.363352462649345, 51.06377273797989, 52.55770057439804, 44.59288716316223, 44.23671707510948, 46.40607386827469, 46.409801468253136, 46.89897961914539, 43.57758544385433, 39.02177810668945, 40.51974892616272, 37.82696641981602, 39.71084073185921, 43.987028673291206, 44.415539279580116, 40.66251866519451, 41.107170805335045, 45.08046180009842, 44.301967173814774, 45.75132340192795, 47.04600133001804, 46.96635380387306, 47.60608367621899, 48.89432854950428, 48.841758370399475, 51.559535935521126, 59.787633419036865, 63.079484179615974, 64.3877425789833, 67.30635076761246, 53.79021383821964, 53.388408198952675, 68.05513858795166, 63.615031242370605, 62.474659234285355, 65.41146084666252, 68.20690244436264, 68.94894942641258, 66.43409237265587, 69.06948655843735, 72.75190696120262, 69.71727579832077, 68.58055919408798, 70.1285733282566, 70.44112175703049, 70.67882180213928, 70.46980261802673, 71.85682699084282, 70.86421385407448, 72.1298499405384, 69.61879268288612, 65.32102569937706, 29.973646625876427, 0.5518387479241937, 0.17644921696046367, 2.0910000102594495, 74.81889724731445, 67.77940258383751, 50.33685274422169, 48.10612164437771, 48.430088460445404, 51.702613458037376, 69.72988352179527, 10.331379622220993, 0.4360350634669885, 0.0653598846110981, 0.1383550142054446, 0.08821450042887591, 0.06412623479263857, 0.04141815232287627, 0.03670085017802194, 0.10888101998716593, 0.16572331282077357, 0.15384795551653951, 0.16825641127070412, 0.22108377423137426, 0.26461762259714305, 0.30875611351802945, 0.2315914721111767, 0.20832649315707386, 61.472409814596176, 76.29131063818932, 63.38218733668327, 59.108632653951645, 68.57921406626701, 52.87802718579769, 98.51281464099884, 32.877599000930786, 0.3061629307921976, 0.8631881035398692, 52.244950756430626, 89.87359061837196, 74.99054923653603, 81.00707039237022, 74.26081359386444, 81.64811119437218, 72.46104016900063, 78.9073334634304, 75.34592896699905, 73.56817916035652, 65.9811718761921, 67.62745633721352, 59.722109735012054, 46.53344303369522, 57.346671000123024, 71.29357561469078, 68.11034962534904, 70.85598349571228, 65.82243159413338, 73.49554985761642, 65.89981824159622, 60.567898750305176, 57.22648724913597, 54.53187704086304, 52.19606637954712, 54.45448659360409, 51.14810161292553, 51.00584104657173, 51.861733719706535, 51.0722690820694, 49.96317699551582, 51.18530921638012, 50.64285032451153, 51.1478166282177, 49.65163171291351, 47.46665395796299, 45.49605309963226, 46.56291425228119, 44.46691632270813, 43.95048223435879, 45.41537202894688, 45.2780169993639, 43.06860655546188, 47.29302227497101, 45.616339445114136, 45.82291916012764, 44.971639439463615, 48.705448284745216, 48.8668180257082, 49.6491314470768, 47.01581194996834, 51.87273412942886, 52.92471148073673, 47.671090587973595, 52.08416238427162, 49.556036442518234, 49.20067951083183, 51.7122383415699, 49.9198517203331, 50.49254558980465, 49.19641613960266, 51.856664791703224, 55.62197394669056, 52.54587560892105, 53.8440265506506, 52.509572356939316, 50.27945302426815, 55.65401762723923, 54.25559386610985, 42.029559910297394, 40.96210978925228, 53.57962913811207, 55.0511571764946, 49.48060289025307, 51.94713793694973, 54.16412137448788, 54.50585603713989, 51.15007370710373, 48.12406808137894, 52.82812066376209, 50.487336069345474, 50.45544818043709, 52.777359187603, 53.50943170487881, 51.3007128238678, 55.03351092338562, 53.77336174249649, 54.538538083434105, 57.364602237939835, 47.47949346899986, 47.88914568722248, 50.065995678305626, 49.13125343620777, 50.729945451021194, 46.51300773024559, 42.032766938209534, 43.748732060194016, 39.93694379925728, 43.53887692093849, 44.87914100289345, 47.10897535085678, 44.38013657927513, 43.88813138008118, 49.21259567141533, 46.6878629475832, 47.70878456532955, 49.96280841529369, 47.49880403280258, 51.85513727366924, 52.807772755622864, 51.17609851062298, 54.132039695978165, 62.56681568920612, 64.27551940083504, 67.38936111330986, 69.21715423464775, 56.69169634580612, 65.30764281749725, 70.46581283211708, 60.658273100852966, 65.5709382891655, 66.00118920207024, 70.72674483060837, 70.832249969244, 68.47773671150208, 73.97131472826004, 76.9029638171196, 70.10243833065033, 71.78084626793861, 72.87405520677567, 73.90166446566582, 71.7221850156784, 76.09958052635193, 71.89347982406616, 76.18408039212227, 73.82268190383911, 78.06141525506973, 72.93587028980255, 40.8077734708786, 1.6458186297677457, 0.215753402444534, 2.623242912814021, 83.41788902878761, 75.37300631403923, 60.55802308022976, 59.08831514418125, 46.116134226322174, 62.311009615659714, 84.1776430606842, 16.016797944903374, 0.7133623212575912, 0.18648303870577365, 0.16674541344400495, 0.14030036138137802, 0.29485746868886054, 0.2752347872592509, 0.25836354412604123], [0.05508030437340494, 0.03203437401680276, 0.09591123976861127, 0.039034878645907156, 0.02463981494656764, 0.025963776715798303, 0.1689487459952943, 0.11764159833546728, 0.31168605317361653, 28.505950681865215, 58.95141988992691, 37.37530365586281, 21.952645629644394, 48.51833872497082, 47.70330145955086, 74.12823110818863, 35.213804841041565, 0.07404317570035346, 0.08419669844442979, 25.387781001627445, 78.8616219162941, 67.64966994524002, 77.45913997292519, 73.14741253852844, 77.18999281525612, 73.33866387605667, 72.23783254623413, 69.30933728814125, 71.91483467817307, 70.14987498521805, 70.65164566040039, 59.51825827360153, 61.66581183671951, 62.20061033964157, 64.3201594054699, 65.50536900758743, 66.1046652495861, 60.26405565440655, 55.62982812523842, 51.255742236971855, 50.321562364697456, 47.38672524690628, 45.914034470915794, 47.17063844203949, 47.91968084871769, 45.46145595610142, 46.82758145034313, 46.51089884340763, 47.85873971879482, 45.840649008750916, 45.698171854019165, 45.1915792375803, 46.135608181357384, 45.89384615421295, 44.313176572322845, 42.16356731951237, 42.27856434881687, 38.587814792990685, 40.59191845357418, 38.85775990784168, 41.43936797976494, 39.630053266882896, 41.734437346458435, 40.50326161086559, 44.99139457941055, 43.266161754727364, 43.29211436212063, 42.16930501163006, 42.6010150462389, 43.56184668838978, 44.18921202421188, 43.51688750088215, 44.197153598070145, 45.54087929427624, 43.26463043689728, 45.88886082172394, 45.61874471604824, 44.35867913067341, 42.209107875823975, 42.85793825984001, 45.30891694128513, 47.60787717998028, 47.28348858654499, 48.51460352540016, 49.20067951083183, 47.79504753649235, 52.16925121843815, 43.844885900616646, 40.56060813367367, 38.04724059998989, 42.94854059815407, 50.19122935831547, 46.10833324491978, 46.927082911133766, 49.497812166810036, 49.2788565158844, 47.5860283523798, 44.68213677406311, 42.76527263224125, 43.251817524433136, 45.248446986079216, 40.527728497982025, 44.659562185406685, 44.57003898918629, 45.18820881843567, 43.74167963862419, 43.401453495025635, 45.808449536561966, 42.92836368083954, 40.19334264099598, 42.87871174514294, 41.77577532827854, 41.803149059414864, 40.979615449905396, 38.8182458281517, 36.55401572585106, 37.894348204135895, 38.98197524249554, 42.16948740184307, 38.90504837036133, 39.699939116835594, 40.14403648674488, 43.164616003632545, 40.2876041829586, 44.06579464673996, 42.75703087449074, 45.266625210642815, 47.34963543713093, 46.66664108633995, 47.64649070799351, 47.04955033957958, 48.78179758787155, 58.07812035083771, 61.869104728102684, 62.70452789962292, 64.86919954419136, 52.63151541352272, 42.7621416002512, 63.501231148839, 68.35628002882004, 69.17013555765152, 59.36488330364227, 62.06503361463547, 65.06293594837189, 67.56160587072372, 61.56385950744152, 65.0904768705368, 64.9506975710392, 67.55536660552025, 65.31921699643135, 68.97321492433548, 68.86696502566338, 75.03930822014809, 66.50763362646103, 74.08349990844727, 57.27661035954952, 58.77195551991463, 12.504426017403603, 0.056253417205880396, 0.21381037076935172, 4.478917513042688, 72.04684719443321, 53.152334466576576, 45.97447782754898, 39.357284903526306, 20.44825315475464, 28.594438433647156, 60.184012949466705, 6.11175924539566, 0.13939087424660102, 0.03626183271990158, 0.0780456820211839, 0.07257321864017285, 0.07657867870875634, 0.0666242816078011, 0.04994431961677037, 0.03938546920835506, 0.06641023137490265, 0.022255754593061283, 0.038010425414540805, 0.0605123726563761, 0.05902695294935256, 0.13906375039368868, 0.10473741655005142, 0.322801970760338, 35.430970788002014, 68.49701687693596, 39.5309241861105, 34.244670644402504, 59.7483017295599, 50.49275077879429, 81.6494183242321, 39.792346358299255, 0.12369883697829209, 0.06829896752606146, 25.807956755161285, 84.57961589097977, 72.90353402495384, 81.43594577908516, 75.62107980251312, 80.43043613433838, 73.48316252231598, 73.66122856736183, 70.20956978201866, 74.18580561876297, 71.38632863759995, 73.0612787604332, 61.55799642205238, 62.44887001812458, 64.9480377137661, 67.8503979742527, 67.48710706830025, 65.69260776042938, 62.537105083465576, 58.229709416627884, 53.79715986549854, 51.5204094350338, 48.54266881942749, 48.691271245479584, 48.046768829226494, 51.78299814462662, 48.00713695585728, 47.918347120285034, 49.02780398726463, 50.20518980920315, 48.43266852200031, 49.21161152422428, 47.23625712096691, 49.07400570809841, 47.23994292318821, 46.612562388181686, 44.7327196598053, 44.79878291487694, 40.57710684835911, 42.50500179827213, 43.32003906369209, 43.46198424696922, 41.96305587887764, 42.785301357507706, 43.64589437842369, 46.80058769881725, 47.25302182137966, 44.99699167907238, 45.99619746208191, 45.60077168047428, 46.29233077168465, 45.579310432076454, 45.588315948843956, 47.94286720454693, 49.62098255753517, 46.09905034303665, 47.59153425693512, 46.902684420347214, 46.96240581572056, 45.36761999130249, 46.511176228523254, 46.49943485856056, 46.905583664774895, 49.18685965240002, 50.52178502082825, 50.13719625771046, 49.238403886556625, 52.5975376367569, 44.55628752708435, 40.32203033566475, 38.165710642933846, 43.78348499536514, 50.61818204820156, 46.8036313354969, 48.91678914427757, 51.373976692557335, 50.96921481192112, 48.45504932105541, 46.8864630907774, 45.96642605960369, 44.38927888870239, 48.86939808726311, 45.214188024401665, 43.673252910375595, 46.56255707144737, 45.560642033815384, 48.870116248726845, 45.75263053178787, 49.477240070700645, 44.73482094705105, 42.735212445259094, 44.42267149686813, 42.50930316746235, 44.52681250870228, 44.227114990353584, 41.675130128860474, 38.31742890179157, 39.67679835855961, 41.3270878046751, 44.1914577037096, 42.33351320028305, 42.350091710686684, 41.23761400580406, 45.328983664512634, 42.76502184569836, 46.356908306479454, 46.68655961751938, 47.218139693140984, 48.78661572933197, 48.74072939157486, 49.31817300617695, 49.115134701132774, 51.80758282542229, 60.31405337154865, 63.76271411776543, 63.52456569671631, 65.870810598135, 55.01024857163429, 47.95744702219963, 63.57071042060852, 69.7350512444973, 70.08734554052353, 62.94624052941799, 64.99523118138313, 68.20670485496521, 70.2007694542408, 67.31965005397797, 71.06251001358032, 67.31227084994316, 71.03883728384972, 68.19188565015793, 71.89877673983574, 71.77278310060501, 76.0795783996582, 71.13820195198059, 76.72304347157478, 63.677423894405365, 65.3941261768341, 14.747604299336672, 0.1164485514163971, 0.2434059139341116, 6.427823910489678, 81.17113038897514, 58.59917879104614, 54.44721758365631, 45.700083151459694, 29.440540932118893, 36.742048636078835, 74.2022967338562, 8.857681900262833, 0.23404723877320066, 0.06033448356902227, 0.0346204581001075, 0.03852080408250913, 0.07466776718501933, 0.0694938846572768, 0.016265222038782667, 0.1710806245682761, 0.22621878306381404, 0.23536670312751085, 0.2923837420530617, 0.10897182917688042, 0.1456068063271232, 0.2184578331070952, 0.21218058478552848, 0.5200413416605443, 48.944352865219116, 78.23697343468666, 47.85233326256275, 29.590334594249725, 67.59241461753845, 61.62056006491184, 88.27497079968452, 42.5011146068573, 0.22257134987739846, 0.5085274844896048, 30.745389014482498, 87.01472282409668, 75.5484277009964, 85.27649089694023, 79.16024789214134, 83.40770557522774, 76.14204704761505, 75.93403100967407, 73.18702921271324, 77.61354088783264, 76.08150869607925, 73.20034369826317, 61.539278626441956, 65.21752685308456, 69.50333967804909, 69.5496515929699, 68.30347806215286, 70.21238163113594, 65.41817128658295, 60.804265066981316, 55.896786600351334, 53.65277901291847, 50.656233206391335, 49.74859870970249, 50.519486144185066, 54.06499609351158, 50.20592696964741, 51.19166627526283, 51.87965355813503, 53.604324012994766, 52.20339618623257, 50.66409878432751, 50.321003794670105, 51.539305821061134, 48.939283937215805, 49.95580539107323, 46.16536818444729, 46.954171657562256, 43.75255845487118, 45.414847657084465, 43.667082041502, 46.1164116114378, 45.232598036527634, 48.625337183475494, 46.138978600502014, 49.914437010884285, 50.724990516901016, 47.06220366060734, 47.703727036714554, 48.98236222565174, 49.292683973908424, 46.37743100523949, 49.61038492619991, 51.05526499450207, 51.60045213997364, 48.413076773285866, 50.74609458446503, 50.407202169299126, 49.537599831819534, 49.52806234359741, 50.492541790008545, 49.88079361617565, 51.85843929648399, 52.25840203464031, 53.99962440133095, 54.71430145204067, 53.354871198534966, 56.96796052157879, 44.8411088436842, 42.4953693151474, 40.44395059347153, 46.20915323495865, 55.97494840621948, 49.75687086582184, 51.89041078090668, 55.08182913064957, 53.807673901319504, 52.81390182673931, 50.62061011791229, 48.16842310130596, 49.09624211490154, 50.007315427064896, 47.39199936389923, 47.65629418194294, 50.13745464384556, 49.06263291835785, 50.03833696246147, 48.05958554148674, 51.78155802190304, 48.09411808848381, 44.898774549365044, 48.092054799199104, 44.60307441651821, 46.6635100543499, 46.56590849161148, 43.588126078248024, 40.25162011384964, 42.27572210133076, 43.71494047343731, 48.002436608076096, 45.222634971141815, 44.91107828915119, 44.693836346268654, 48.86182889342308, 45.57244420051575, 50.014706030488014, 48.41211162507534, 49.84635226428509, 51.07920750975609, 51.82425253093243, 51.403938084840775, 49.68804135918617, 54.15339075028896, 62.3637355864048, 64.96247693896294, 67.96484023332596, 69.23155546188354, 54.76350121200085, 53.67127642035484, 67.66752898693085, 65.56812644004822, 68.52461099624634, 66.20575502514839, 70.43894827365875, 71.3538707792759, 70.90991020202637, 68.74395042657852, 73.18722680211067, 71.95361539721489, 73.57455521821976, 72.29249641299248, 75.11396661400795, 75.37886559963226, 81.3224458694458, 76.3201054930687, 81.07134014368057, 67.3410353064537, 72.41193160414696, 19.693642146885395, 0.37367105833254755, 0.21614846249576658, 6.043314943090081, 91.365185379982, 67.18481048941612, 66.44665449857712, 57.08893083035946, 31.087706945836544, 44.39576134085655, 92.70870208740234, 13.091517314314842, 0.3169942199019715, 0.1980925735551864, 0.2671443088911474, 0.20217726530972868, 0.11464032344520092, 0.1705787843093276, 0.13364586455281824], [0.049035385382012464, 0.03495397184451576, 0.07668064237805083, 0.06902217559400015, 0.033823335834313184, 0.11072550929384306, 0.055714020563755184, 0.03279891599959228, 0.42190789652522653, 28.258048184216022, 61.018155589699745, 44.96444642543793, 32.35278636217117, 37.715203016996384, 52.58524909615517, 65.42148470878601, 54.27341490983963, 0.23899363819509745, 0.07952959887916222, 8.705812599509954, 56.747610345482826, 67.23239153623581, 66.73997595906258, 68.54097291827202, 72.04397454857826, 68.71118098497391, 68.32444533705711, 70.88294684886932, 71.29598468542099, 70.53158730268478, 69.52949747443199, 65.76684057712555, 64.66002076864243, 66.18546411395073, 65.0889265537262, 62.653306648135185, 61.865255534648895, 53.03402781486511, 49.06622752547264, 50.33429928123951, 48.88985998928547, 46.18777938187122, 46.99398972094059, 47.34260581433773, 47.289161682128906, 44.50337156653404, 44.0751763433218, 43.695838898420334, 45.56677110493183, 46.16012826561928, 48.17050538957119, 45.72832703590393, 46.58518485724926, 48.09789888560772, 43.264577239751816, 43.63402381539345, 41.863554418087006, 40.257000625133514, 39.42577622830868, 40.983096063137054, 42.93559469282627, 41.04379780590534, 41.99405461549759, 42.17689320445061, 41.32814034819603, 42.24338583648205, 45.53152799606323, 44.66527707874775, 42.79866524040699, 43.6429837346077, 46.87991224229336, 44.66715797781944, 44.50819730758667, 45.83033636212349, 48.13236303627491, 48.84657271206379, 48.47668915987015, 49.5721285790205, 45.98594941198826, 44.00127410888672, 45.14884293079376, 45.373171493411064, 47.528769224882126, 48.40207636356354, 48.836879432201385, 49.371902123093605, 48.87120679020882, 44.03934806585312, 37.91547507047653, 37.302222177386284, 46.497181579470634, 46.97069697082043, 49.328725039958954, 48.03999379277229, 46.07861503958702, 44.115792363882065, 45.44718772172928, 40.914665535092354, 41.6645172983408, 42.37148076295853, 44.392026141285896, 45.143572613596916, 44.87811505794525, 45.601717829704285, 42.7460228651762, 41.843787878751755, 42.34531156718731, 41.168347522616386, 42.314069643616676, 42.076715379953384, 41.04939490556717, 43.03955711424351, 40.84080509841442, 40.441085547208786, 41.86244487762451, 40.347169786691666, 39.94272708892822, 39.88847739994526, 41.757692098617554, 38.1971425563097, 42.17158108949661, 39.66078221797943, 43.22278328239918, 43.410535007715225, 43.490729704499245, 44.1327166557312, 45.79300336539745, 45.12756787240505, 47.00378559529781, 44.6415663510561, 47.41111233830452, 47.07049861550331, 52.2594203799963, 57.51868776977062, 61.538541465997696, 57.51548834145069, 67.36251175403595, 60.51952354609966, 46.70944198966026, 52.645369470119476, 69.6523904800415, 77.02345535159111, 73.37842494249344, 62.006300166249275, 63.31084616482258, 66.18409618735313, 66.8693134188652, 61.61757342517376, 65.24335786700249, 65.91157481074333, 66.73449665307999, 64.01065841317177, 69.0854001045227, 65.85008651018143, 70.49278378486633, 63.25020141899586, 60.62412053346634, 9.37903767451644, 0.06271824706345797, 0.18932907114503905, 8.2419771887362, 74.59549963474274, 53.345782086253166, 49.75328765809536, 31.165467873215675, 40.61239555478096, 37.3831882327795, 50.86737647652626, 5.2854418102651834, 0.33436863915994763, 0.13765420415438712, 0.0560631268308498, 0.03702396643348038, 0.13956063310615718, 0.044100455852458254, 0.05664111515216064, 0.0555597354832571, 0.019202388357371092, 0.05816619894176256, 0.03565683393389918, 0.03907766345946584, 0.02243619666842278, 0.1080959168029949, 0.10896961015532725, 0.40153039153665304, 35.556709840893745, 73.58258798718452, 42.337229400873184, 35.13603061437607, 51.253435760736465, 55.07420673966408, 74.4523537158966, 58.75338971614838, 0.5561755027156323, 0.09814832519623451, 8.215228524059057, 60.37681080400944, 69.13267716765404, 67.69591346383095, 69.102803170681, 70.80633535981178, 68.05476620793343, 72.17711940407753, 73.16026344895363, 72.03939199447632, 70.85407599806786, 72.16638877987862, 68.03370013833046, 66.27073913812637, 68.46880719065666, 68.55638489127159, 65.43157696723938, 65.04453733563423, 55.072257444262505, 52.74179309606552, 51.27349868416786, 52.28221155703068, 50.556195974349976, 49.90118332207203, 49.19662892818451, 47.87654936313629, 47.056952342391014, 45.69049246609211, 48.13596524298191, 49.29527163505554, 48.440344110131264, 49.71072234213352, 48.901912942528725, 49.75201092660427, 50.264622420072556, 46.05279542505741, 47.67070680856705, 45.39122812449932, 43.814658522605896, 43.19549314677715, 43.41438800096512, 43.849240466952324, 44.76229727268219, 44.80339206755161, 44.68879021704197, 42.25609615445137, 44.766598641872406, 45.77262885868549, 47.44801215827465, 43.9112189412117, 46.16811543703079, 48.25127385556698, 47.06099912524223, 47.09273122251034, 49.97346684336662, 50.580419674515724, 50.991857796907425, 50.282964035868645, 51.238384768366814, 48.857314735651016, 47.46540382504463, 47.48664848506451, 47.70575612783432, 50.53727678954601, 49.387903064489365, 50.49590080976486, 50.14691233634949, 48.84031444787979, 44.441632479429245, 39.463572800159454, 37.75061331689358, 45.961721912026405, 49.465449303388596, 52.759872525930405, 50.52116945385933, 49.09482479095459, 47.88803614675999, 47.24177822470665, 44.799029901623726, 45.294504314661026, 44.62430387735367, 46.39606520533562, 48.10132250189781, 43.7576349824667, 45.93374781310558, 45.690796449780464, 45.65537095069885, 44.102759063243866, 43.95687349140644, 45.34905418753624, 43.91848035156727, 43.40493030846119, 45.048456117510796, 43.48767466843128, 44.42121997475624, 45.082825273275375, 42.76486225426197, 43.37205067276955, 42.15147636830807, 45.023107677698135, 43.07826943695545, 44.02058087289333, 42.333509400486946, 45.75163498520851, 46.22829660773277, 46.84483252465725, 46.67162261903286, 46.815004125237465, 47.10009902715683, 49.235367849469185, 46.96613721549511, 49.69204634428024, 49.23578582704067, 54.1741718351841, 58.63307297229767, 63.98827761411667, 60.3107475489378, 67.51076459884644, 63.16917076706886, 51.506027206778526, 55.75891859829426, 71.90212815999985, 80.21352857351303, 74.81058329343796, 64.87278655171394, 65.02909496426582, 67.36322611570358, 70.52983179688454, 67.369244992733, 69.8171116411686, 67.36708670854568, 70.54220393300056, 66.87008857727051, 73.55903685092926, 67.77314811944962, 75.77542752027512, 68.1558483839035, 71.87171459197998, 11.89221616834402, 0.22090125043177977, 0.12410039082169533, 9.107901323586702, 83.15184250473976, 62.165447026491165, 60.23930378258228, 38.54463391005993, 43.06446097791195, 43.5730142891407, 63.62373657524586, 8.000219911336899, 0.4220925725530833, 0.1310430487501435, 0.07031216926407069, 0.04320109532272909, 0.020258323493180797, 0.060093144566053525, 0.07126984404749237, 0.20302432298194617, 0.08159887729561888, 0.17263275221921504, 0.15248057810822502, 0.11613301991019398, 0.26511824573390186, 0.1701733490335755, 0.24974712054245174, 0.6297068414278328, 47.19793617725372, 81.43225237727165, 54.66694459319115, 39.3200659006834, 55.38549363613129, 64.85761776566505, 81.87948077917099, 64.07807439565659, 0.5739694135263562, 0.1907574085635133, 11.481597851961851, 67.96154201030731, 69.47721987962723, 71.17562994360924, 71.69370174407959, 75.13181805610657, 68.90675649046898, 73.42087626457214, 76.06495678424835, 74.98757019639015, 73.28086897730827, 74.13061738014221, 68.7269501388073, 69.7792960703373, 70.44829577207565, 72.1391898393631, 70.59096291661263, 69.32714313268661, 57.03586287796497, 54.77967694401741, 54.13976848125458, 55.74682004749775, 52.92205922305584, 51.85524366796017, 52.31350667774677, 52.05450497567654, 49.48182262480259, 48.661294654011726, 49.264865666627884, 53.28224189579487, 50.70636011660099, 53.67786146700382, 52.19884783029556, 50.656035616993904, 54.828834906220436, 47.57193110883236, 49.16361629962921, 47.75492548942566, 47.8284515440464, 45.466498285532, 46.20862886309624, 47.41299323737621, 45.7691216468811, 47.13309645652771, 46.70521281659603, 45.266290828585625, 46.992921978235245, 49.87634785473347, 51.59273475408554, 48.52207392454147, 49.742435440421104, 50.96097685396671, 50.11893443763256, 50.80555759370327, 51.001011505723, 54.4549273699522, 54.36226174235344, 52.524638548493385, 53.84330838918686, 49.36129689216614, 50.0308171659708, 49.424605295062065, 50.70176236331463, 53.9972685277462, 53.98968793451786, 54.0290804207325, 54.81033369898796, 53.46765674650669, 48.80501814186573, 40.09545989334583, 38.21883179247379, 49.74353738129139, 51.36823520064354, 57.062507048249245, 51.7690072953701, 51.8066480755806, 48.88238199055195, 50.7005350291729, 46.89182460308075, 48.159276992082596, 48.616882637143135, 50.157175585627556, 52.09128700196743, 48.3908973634243, 50.89722387492657, 48.00325356423855, 46.772890985012054, 48.503834903240204, 45.98669417202473, 47.7334376424551, 48.387857526540756, 45.666211768984795, 49.87742319703102, 43.46559785306454, 44.74244713783264, 46.883708238601685, 46.28369003534317, 45.18200755119324, 45.58874152600765, 47.19996526837349, 43.97830054163933, 47.60835975408554, 45.5032043159008, 47.282557636499405, 49.73487004637718, 46.93512327969074, 48.37427705526352, 48.759899362921715, 50.29996432363987, 51.657935455441475, 47.543227449059486, 51.23980209231377, 50.71592800319195, 55.95982141792774, 62.314570024609566, 67.4465024471283, 63.30701217055321, 71.79873570799828, 62.591787949204445, 55.87301887571812, 61.83229610323906, 70.60264348983765, 74.09908667206764, 70.37528648972511, 66.22451841831207, 70.55588319897652, 72.46677026152611, 71.04298666119576, 68.31523463129997, 72.80927628278732, 72.16786310076714, 74.2362593114376, 70.68805530667305, 76.15419879555702, 72.71936550736427, 79.39567565917969, 73.93064931035042, 78.65245074033737, 16.55721064656973, 0.36355665419250727, 0.3612318023806438, 10.647263322025537, 93.72715383768082, 68.78228276968002, 70.77804207801819, 47.19644285738468, 59.38498042523861, 55.800693556666374, 79.80913147330284, 12.543450873345137, 0.80121835693717, 0.3541945503093302, 0.19422730518272147, 0.18009305815212429, 0.25368958711624146, 0.19577367376768962, 0.2003421270637773], [0.04152278772380669, 0.08855691252392717, 0.05113240527862217, 0.02128428142896155, 0.05903399964154232, 0.09389275393914431, 0.18651386752026156, 0.09955201589036733, 0.4745122737949714, 21.470559798181057, 61.18380770087242, 58.32530848681927, 49.729033559560776, 35.41165642440319, 51.7813566327095, 54.067572355270386, 66.46439954638481, 1.4569795690476894, 0.18170323659433052, 1.4991469751112163, 32.872032299637794, 62.825874388217926, 63.29435884952545, 69.27225887775421, 68.4728653728962, 71.81382089853287, 69.39706698060036, 70.39180040359497, 69.48703855276108, 69.38409447669983, 65.9726831316948, 64.39151957631111, 69.93573367595673, 65.61669543385506, 66.4269107580185, 61.40937499701977, 53.540840819478035, 48.874626606702805, 49.01084929704666, 48.68256591260433, 46.13919898867607, 46.33950524032116, 47.22944028675556, 47.444919124245644, 44.5235712826252, 43.41939993202686, 42.674696892499924, 44.214389473199844, 43.0285757035017, 46.72863855957985, 46.7952261865139, 50.39103403687477, 50.97988843917847, 51.28130346536636, 47.99031525850296, 43.79612311720848, 42.0622381567955, 40.279373824596405, 40.83550438284874, 41.63413792848587, 40.933770909905434, 44.011423364281654, 41.42842076718807, 41.88883826136589, 41.964963376522064, 41.3658457249403, 41.674522161483765, 41.61716043949127, 41.84332050383091, 43.40353958308697, 44.15266938507557, 43.42006489634514, 45.098089054226875, 46.94183371961117, 51.17214672267437, 48.42866733670235, 49.73735511302948, 48.313347324728966, 48.410135731101036, 48.96006882190704, 46.99400492012501, 44.20499637722969, 43.26255954802036, 43.18510830402374, 45.58290123939514, 47.36005827784538, 49.42827209830284, 45.31082063913345, 36.592344269156456, 33.940474167466164, 42.649120464921, 49.744141548871994, 50.88596887886524, 47.559767961502075, 47.29596711695194, 44.24709431827068, 44.54574689269066, 42.36688680946827, 42.98629157245159, 46.164498031139374, 47.785707637667656, 49.240683764219284, 47.71577998995781, 47.90143042802811, 46.97122134268284, 43.81099931895733, 42.57968299090862, 38.983415365219116, 38.4251569211483, 39.450984075665474, 42.64808312058449, 42.1306686848402, 41.24195337295532, 40.76253689825535, 41.322167068719864, 41.237735599279404, 39.07295376062393, 42.41989016532898, 40.61014607548714, 40.09943448007107, 40.45350708067417, 42.06740587949753, 44.04599770903587, 43.31813916563988, 45.0127874314785, 43.25795419514179, 44.2426523566246, 43.08314837515354, 45.16105927526951, 45.926220417022705, 45.13898245990276, 46.036764085292816, 46.97503633797169, 48.65162797272205, 55.07905147969723, 59.968689903616905, 57.38656885921955, 63.638312593102455, 69.3650270998478, 55.9651031345129, 54.08543899655342, 54.17622372508049, 72.83905148506165, 80.69212049245834, 76.84681043028831, 62.18750484287739, 64.1514028608799, 65.10267421603203, 68.06282177567482, 65.0630347430706, 69.45475548505783, 63.452506363391876, 67.8968694806099, 65.0934711098671, 72.56233513355255, 59.00941617786884, 63.96228700876236, 10.764923058450222, 0.08100104765617289, 0.5130683002062142, 11.417989265173674, 74.45393443107605, 54.210364893078804, 50.79407840967178, 37.73678965866566, 39.96398314833641, 32.517055347561836, 48.366487473249435, 5.157172093167901, 0.2683851798065007, 0.20644948293920606, 0.05388933546782937, 0.06690947411698289, 0.09552827672450803, 0.04907732414721977, 0.0360769822873408, 0.0408782361773774, 0.10511896209209226, 0.017223930262844078, 0.059474108056747355, 0.022290411034191493, 0.15251921431627125, 0.14217487798305228, 0.14505487110000104, 0.46928470430430025, 27.848141379654408, 69.2135900259018, 60.075426176190376, 42.500442042946815, 40.874851271510124, 60.08768431842327, 62.49941110610962, 72.87770301103592, 1.8457210343331099, 0.13380771211814135, 0.8015349868219346, 33.085109665989876, 65.88281035423279, 68.12452286481857, 71.03369235992432, 69.49322462081909, 73.77940222620964, 70.80543100833893, 72.75872379541397, 68.71183454990387, 70.64583197236061, 70.26003867387772, 68.71952533721924, 71.18362471461296, 67.84690976142883, 67.42019265890121, 62.592608705163, 55.74237048625946, 52.22750969231129, 51.29525251686573, 51.45484775304794, 50.82101136445999, 48.48200887441635, 49.19045805931091, 48.54342117905617, 49.09000664949417, 47.75146387517452, 45.66032588481903, 46.264691054821014, 45.05065239965916, 49.43438217043877, 48.42997066676617, 51.437235698103905, 54.080134481191635, 53.13624992966652, 52.16110445559025, 47.795704901218414, 43.98172415792942, 43.86000148952007, 43.34492392838001, 45.54905265569687, 44.073234647512436, 44.58305709064007, 41.8483742326498, 42.70150065422058, 45.90445898473263, 44.42647509276867, 44.1434320807457, 44.14450362324715, 44.63908888399601, 47.25839853286743, 45.56068763136864, 46.4239177107811, 47.647440657019615, 48.355502262711525, 53.94488073885441, 51.13177768886089, 51.67072556912899, 51.145517751574516, 49.96921107172966, 49.64777871966362, 48.597819060087204, 45.57199202477932, 44.679636508226395, 45.57541564106941, 47.117775678634644, 47.340998500585556, 48.857561722397804, 45.26896968483925, 37.43595600128174, 34.369433149695396, 41.95500411093235, 49.62099775671959, 53.28394800424576, 48.67845833301544, 49.99432772397995, 47.67908155918121, 45.08920133113861, 46.42939321696758, 46.16045504808426, 47.23225973546505, 49.88248452544212, 50.769144147634506, 48.164167329669, 49.78618249297142, 48.99442657828331, 46.017229333519936, 45.635479018092155, 41.74527056515217, 43.19693326950073, 41.247744262218475, 44.98952127993107, 44.87059906125069, 43.71253900229931, 42.45552845299244, 44.47975963354111, 42.52442255616188, 41.26550830900669, 44.87862803041935, 41.23363561928272, 42.86949723958969, 41.76547408103943, 45.50815925002098, 46.66927054524422, 45.486998185515404, 47.57105715572834, 45.27838937938213, 46.93318918347359, 43.39445807039738, 46.862372383475304, 49.48819488286972, 49.795978367328644, 48.53205218911171, 49.94724825024605, 51.28640279173851, 57.66575887799263, 64.04374703764915, 61.425991505384445, 64.67847257852554, 71.08415365219116, 61.86570391058922, 56.50359503924847, 59.909667670726776, 75.50045147538185, 81.32600247859955, 76.9591324031353, 65.40635392069817, 67.08718612790108, 67.17358589172363, 70.64266294240952, 69.7426888346672, 75.4644826054573, 67.61391386389732, 72.11823776364326, 66.8967479467392, 76.56645387411118, 63.942877650260925, 74.83990252017975, 15.032301172614098, 0.051150999788660556, 0.297634347807616, 12.857221886515617, 82.57264718413353, 58.92541028559208, 55.85295595228672, 47.311652675271034, 47.00848214328289, 41.43700830638409, 65.87929174304008, 8.645412940531969, 0.21611732197925448, 0.05768762501247693, 0.0945276538550388, 0.032507482028449886, 0.041305928461952135, 0.0661765736003872, 0.05624890865874477, 0.12115683275624178, 0.27932298195082694, 0.17007695889333263, 0.29797211405821145, 0.16303143929690123, 0.28627539169974625, 0.4132688225945458, 0.3273239062400535, 0.7179766986519098, 38.60188543796539, 79.68652725219727, 75.11997029185295, 60.75501590967178, 51.97570480406284, 68.265350908041, 66.22026264667511, 81.52865320444107, 2.1699096634984016, 0.16603035415755585, 2.023789929226041, 40.2609334141016, 66.13890141248703, 71.63826271891594, 73.32302391529083, 72.25850343704224, 77.32178494334221, 73.48909020423889, 76.52993023395538, 74.30697351694107, 73.36343854665756, 71.44427552819252, 70.44299885630608, 74.65788468718529, 71.56513184309006, 71.57001838088036, 66.38186037540436, 59.73952800035477, 52.95586600899696, 54.271317422389984, 54.86406661570072, 53.45135182142258, 51.04450777173042, 52.342879101634026, 52.75839060544968, 50.03002680838108, 49.295609816908836, 48.65437902510166, 48.71386483311653, 47.68019109964371, 53.47800739109516, 53.89999754726887, 55.22538922727108, 57.03690022230148, 56.661575362086296, 54.47737656533718, 49.11722458899021, 46.62089914083481, 45.32163105905056, 47.42037244141102, 48.19133207201958, 46.54441684484482, 50.67848101258278, 45.7962141931057, 46.62354379892349, 47.71251976490021, 45.33231608569622, 45.695804581046104, 45.27856796979904, 46.932493820786476, 50.11729292571545, 48.75700771808624, 48.42644065618515, 49.443915858864784, 51.48639366030693, 54.81583580374718, 53.52944143116474, 55.65746784210205, 53.18702280521393, 53.970510363578796, 54.59224060177803, 50.631390139460564, 49.14011836051941, 47.15128228068352, 46.59922890365124, 50.592107847332954, 51.292691454291344, 53.37668962776661, 48.984870091080666, 39.048087894916534, 36.68899968266487, 43.59085813164711, 53.41130957007408, 55.99158391356468, 52.121818363666534, 52.297619730234146, 49.7897657006979, 49.67044070363045, 48.650324642658234, 49.54142242670059, 50.66483214497566, 52.99272783100605, 54.807506650686264, 51.34452827274799, 53.2690642029047, 52.18869857490063, 49.10980738699436, 49.919384345412254, 45.61492592096329, 45.035969987511635, 43.23697172105312, 49.32612597942352, 48.661309853196144, 44.35964807868004, 43.910314589738846, 45.47077305614948, 46.43699660897255, 43.79985071718693, 49.1183303296566, 45.938638150691986, 45.57795390486717, 43.36432948708534, 48.64394098520279, 48.2843092828989, 49.193247109651566, 50.891030207276344, 46.167176887393, 48.584094196558, 45.62264710664749, 50.687927305698395, 52.05202750861645, 51.02277293801308, 50.19572451710701, 51.68484941124916, 53.395061641931534, 59.936129450798035, 66.51613757014275, 63.1816340982914, 71.75351053476334, 71.05970576405525, 62.174733728170395, 61.705979481339455, 64.11206737160683, 77.1522456407547, 75.38907185196877, 73.2568010687828, 67.09421575069427, 71.55601993203163, 72.44568139314651, 75.88280975818634, 73.20995718240738, 77.07148477435112, 71.21277675032616, 74.22071814537048, 72.38292396068573, 82.23428294062614, 71.05793505907059, 81.12968221306801, 19.404025487601757, 0.34558845742139965, 0.4744100949028507, 15.603611916303635, 93.08856770396233, 66.30785554647446, 71.44084051251411, 57.04148657619953, 54.79689382016659, 48.56896720826626, 83.28974470496178, 12.49375144019723, 0.3858354821568355, 0.3783829539315775, 0.25172414258122444, 0.2262369211530313, 0.1980317768175155, 0.15018786129076034, 0.2579194132704288], [0.09536195400869474, 0.09393849250045605, 0.042362683670944534, 0.03696765597851481, 0.02555532646510983, 0.025896603074215818, 0.018857914947147947, 0.027718521814676933, 0.3489611326949671, 18.27971711754799, 63.094801157712936, 40.74614837765694, 45.313514694571495, 40.211182683706284, 47.93808326125145, 54.27170880138874, 75.09166181087494, 7.910541398450732, 0.10114901378983632, 0.22227944835321978, 15.127893593162298, 56.09791740775108, 62.66672372817993, 70.25927111506462, 66.27147629857063, 66.89223378896713, 62.569304555654526, 63.62453833222389, 63.370483964681625, 61.10959768295288, 60.31535670161247, 60.53142450749874, 57.209555357694626, 58.55353184044361, 55.249369740486145, 50.95907315611839, 49.373703226447105, 47.53560125827789, 47.32181333005428, 49.76388908922672, 45.59582054615021, 46.219724267721176, 44.932699128985405, 45.38590081036091, 46.0021897405386, 44.88303579390049, 40.725523084402084, 43.42350371181965, 44.22592185437679, 46.626401245594025, 48.9471685141325, 53.142857775092125, 52.54594400525093, 54.398257210850716, 51.40232317149639, 45.262741819024086, 44.00769956409931, 45.06697632372379, 44.0800666809082, 43.477267026901245, 42.27732561528683, 44.09169025719166, 39.080956131219864, 40.52015170454979, 42.38045208156109, 41.65458843111992, 41.79401434957981, 42.31927536427975, 40.73503777384758, 43.57662029564381, 44.48151133954525, 42.062386348843575, 41.84017427265644, 43.66739362478256, 46.346721053123474, 45.37919797003269, 44.682448357343674, 45.50772987306118, 46.657787561416626, 44.532177820801735, 46.61888524889946, 45.60096547007561, 43.32928776741028, 41.62105143070221, 44.21540781855583, 49.349323734641075, 48.80434177815914, 45.120967626571655, 39.48311135172844, 37.32958070933819, 42.17633083462715, 46.68792374432087, 48.40898059308529, 45.47445885837078, 46.51799686253071, 45.56291811168194, 43.149591609835625, 43.78929488360882, 45.323675349354744, 46.21857292950153, 48.993632420897484, 47.92964391410351, 48.93335625529289, 47.62694455683231, 47.755153477191925, 42.54691354930401, 43.206668347120285, 40.51757924258709, 38.97543579339981, 35.82135044038296, 39.555379673838615, 40.25436356663704, 41.31818488240242, 40.134658589959145, 39.800960496068, 38.06848905980587, 41.43752507865429, 39.85975854098797, 39.78268347680569, 40.7197891920805, 44.294447377324104, 43.37627224624157, 45.039674788713455, 42.915771156549454, 43.986333310604095, 44.069271460175514, 45.219264551997185, 44.330214858055115, 43.43980483710766, 44.08539779484272, 44.07893434166908, 46.02453634142876, 47.49883823096752, 46.36785551905632, 49.11674581468105, 54.56315316259861, 62.07128047943115, 59.408181980252266, 62.829457595944405, 64.4703121483326, 66.4294946193695, 54.704657569527626, 46.249514669179916, 51.45697183907032, 73.65444213151932, 83.92357349395752, 80.05561664700508, 63.92629534006119, 65.97896039485931, 65.11132255196571, 68.49367305636406, 65.56111201643944, 71.91560223698616, 65.16180664300919, 71.84492602944374, 58.70171248912811, 64.00371998548508, 15.181951392441988, 0.14018651592778042, 0.300217229523696, 14.41723957657814, 72.54767552018166, 52.520538568496704, 54.27490822970867, 34.09753113985062, 39.615902826189995, 33.641244024038315, 45.67872069776058, 3.323570271022618, 0.12230008898768574, 0.012480067580327159, 0.09175314960884862, 0.021807510383951012, 0.0745683119748719, 0.015453826417797245, 0.04698395561717916, 0.08343345150933601, 0.04893097262538504, 0.03939253445423674, 0.06244428324862383, 0.049156778477481566, 0.029280670314619783, 0.029528616287279874, 0.095596316823503, 0.3528905374696478, 26.722056604921818, 71.79949566721916, 47.07681007683277, 44.11163918673992, 45.87167054414749, 55.8900685608387, 58.63498046994209, 83.5868127644062, 8.729742765426636, 0.18036223511444405, 0.13950550637673587, 14.619106594473124, 59.60238195955753, 63.95339548587799, 71.81895062327385, 69.30465593934059, 68.56266215443611, 64.24822926521301, 65.13922065496445, 65.40452241897583, 63.842874616384506, 62.285045608878136, 63.83210599422455, 60.55644616484642, 61.9264892488718, 57.191092148423195, 54.6163085103035, 51.42365522682667, 51.09982520341873, 50.426812916994095, 52.18686327338219, 48.45470353960991, 49.036106541752815, 47.89715185761452, 47.18800351023674, 46.796328127384186, 47.04511597752571, 44.86970230937004, 45.53894899785519, 49.32302534580231, 48.73051553964615, 52.80247963964939, 57.04387664794922, 55.139160454273224, 56.04858085513115, 53.99402730166912, 49.300435557961464, 46.65906809270382, 46.42252318561077, 47.079530730843544, 45.35597361624241, 44.87994655966759, 44.81628097593784, 41.419992819428444, 41.997421234846115, 43.34385618567467, 43.62791754305363, 44.27194118499756, 41.899637281894684, 42.6030745357275, 45.94673931598663, 45.283579900860786, 43.522382006049156, 45.09251095354557, 49.0347234159708, 47.32665807008743, 47.61142618954182, 45.89966744184494, 47.57742941379547, 47.67271310091019, 46.84917189180851, 48.93475078046322, 47.2499667853117, 47.64909356832504, 44.83280248939991, 47.99012526869774, 52.18435540795326, 50.64295671880245, 48.220461308956146, 40.28892271220684, 37.50240683555603, 41.84628814458847, 48.7447951734066, 50.56754596531391, 47.81352214515209, 45.53258053958416, 46.04828506708145, 44.118570014834404, 45.07952705025673, 48.10487911105156, 47.74185039103031, 51.03616341948509, 50.443140640854836, 49.88978773355484, 49.88857559859753, 47.99862541258335, 46.00721687078476, 44.59291756153107, 43.227601423859596, 40.62408372759819, 38.98157626390457, 43.03230330348015, 42.31642931699753, 43.58409069478512, 41.73481732606888, 41.859507635235786, 41.27001106739044, 42.84509874880314, 42.35973559319973, 41.43111862242222, 43.24099190533161, 44.91010174155235, 46.564171984791756, 48.07785116136074, 46.21269464492798, 46.684610322117805, 48.97352010011673, 46.74053192138672, 47.056678757071495, 46.13989815115929, 47.90062487125397, 46.67474985122681, 48.25910143554211, 50.44900372624397, 49.229493364691734, 52.06071384251118, 55.92851109802723, 62.06005968153477, 61.33014164865017, 65.89488610625267, 67.76574611663818, 69.18708264827728, 61.83548793196678, 51.574070155620575, 56.64523623883724, 77.0251576602459, 82.41829186677933, 78.61567631363869, 67.22674503922462, 67.01553717255592, 67.97982662916183, 72.58911609649658, 70.05099669098854, 74.02011170983315, 69.35031428933144, 76.45589500665665, 64.93116661906242, 73.42450886964798, 21.493164785206318, 0.2990680583752692, 0.36545533512253314, 16.490731313824654, 82.15428203344345, 59.57720071077347, 60.08105367422104, 41.660493314266205, 47.732472494244576, 44.64190453290939, 59.431976303458214, 5.377815803512931, 0.3375184623291716, 0.07600683908094652, 0.027539424881979357, 0.051358767741476186, 0.03787277928495314, 0.058234602693119086, 0.05364398144592997, 0.1418817593366839, 0.29717682860791683, 0.12567288300488144, 0.15413636894663796, 0.14010593353305012, 0.12605330790393054, 0.07343716017203405, 0.22844675491796806, 0.43768865754827857, 34.8343838006258, 85.48005357384682, 52.93633125722408, 57.381959706544876, 58.91451247036457, 64.31509047746658, 64.75038751959801, 92.04081952571869, 9.61725639179349, 0.33634209888987243, 0.3471437911503017, 20.21873027086258, 65.85013210773468, 66.20868846774101, 77.96936139464378, 70.88280245661736, 74.2720077931881, 66.95132821798325, 68.60413312911987, 67.67417103052139, 66.06197834014893, 67.44611486792564, 68.00532326102257, 62.54263378679752, 65.08916974067688, 60.409017875790596, 56.442083939909935, 54.41035956144333, 53.386299312114716, 53.41780722141266, 56.52613542973995, 50.85004560649395, 51.288739666342735, 51.469188183546066, 50.93535102903843, 51.827132776379585, 49.36250522732735, 45.44151462614536, 48.9128677546978, 50.90853966772556, 51.3681136071682, 54.93511140346527, 58.626552522182465, 59.141269102692604, 57.99254894256592, 57.27898523211479, 49.810934364795685, 48.49523976445198, 49.83038172125816, 48.87387424707413, 48.69532562792301, 47.62251019477844, 48.29267643392086, 43.85703384876251, 43.9961101859808, 46.99447989463806, 47.133932411670685, 46.6731159389019, 44.91364695131779, 44.67351123690605, 48.94679233431816, 48.680434226989746, 46.0672764480114, 46.94698244333267, 51.39790400862694, 51.48860514163971, 49.88171696662903, 48.55227090418339, 50.48849880695343, 51.3849239051342, 50.54668888449669, 53.481731191277504, 50.14972798526287, 49.541126042604446, 46.55283339321613, 51.47823929786682, 56.24385617673397, 55.3203309327364, 51.767510175704956, 41.31442308425903, 39.0321933478117, 44.44955125451088, 50.41512854397297, 52.26298838853836, 51.660507917404175, 50.07608413696289, 50.725134909152985, 47.71161161363125, 47.85511091351509, 51.610601395368576, 51.14131137728691, 55.393511205911636, 54.15092468261719, 53.41651529073715, 54.06580924987793, 51.37825906276703, 48.56242395937443, 48.717486038804054, 45.760325118899345, 43.75706881284714, 41.75770349800587, 46.154561564326286, 45.56308530271053, 46.53920352458954, 44.36769224703312, 45.292479023337364, 44.454855769872665, 45.71403220295906, 45.520295798778534, 44.75589841604233, 47.31126509606838, 48.26975606381893, 47.75014154613018, 52.178853303194046, 48.41316036880016, 49.66852180659771, 50.54577313363552, 49.03957195580006, 47.46703393757343, 46.48255996406078, 50.636014491319656, 48.32050234079361, 51.8272315710783, 52.88357488811016, 52.56115458905697, 54.262726083397865, 59.57998976111412, 65.65568134188652, 63.673985078930855, 69.05091315507889, 70.37358418107033, 69.02489975094795, 63.90149027109146, 56.55565604567528, 65.68997830152512, 80.51786944270134, 77.43564963340759, 73.6653171479702, 69.33813974261284, 72.73480027914047, 71.60405695438385, 75.92542067170143, 73.461404889822, 79.46796298027039, 73.89422446489334, 84.98563930392265, 69.61591243743896, 82.48624742031097, 25.895688347518444, 0.572893536882475, 0.4406695085344836, 18.46176914870739, 93.24220106005669, 69.21713903546333, 76.0384114086628, 49.59800139069557, 59.36394475400448, 51.645202338695526, 77.95930713415146, 10.94856720417738, 0.483944941079244, 0.2423491550143808, 0.20961870584869757, 0.15420644253026694, 0.14703382272273302, 0.14127931353868917, 0.13668583502294496], [0.035847417457262054, 0.04557063555694185, 0.020613263041013852, 0.07485488487873226, 0.06796566158300266, 0.04428940294019412, 0.1371758899767883, 0.07394696367555298, 0.40754362824372947, 14.041400793939829, 71.36132597923279, 38.37267033755779, 40.76268129050732, 48.81496220827103, 46.950523853302, 40.98608270287514, 76.09555274248123, 18.14542282372713, 0.19525872718077153, 0.3548561007482931, 4.264105064794421, 39.12145435810089, 61.49972654879093, 66.24646604061127, 67.48496398329735, 66.43003419041634, 61.28576762974262, 61.253055185079575, 60.000486597418785, 56.31009802222252, 55.98923943936825, 53.99328254163265, 52.63761408627033, 50.34349098801613, 46.031763553619385, 48.4593240916729, 46.73018887639046, 47.27304294705391, 46.43912449479103, 45.285825580358505, 44.79204587638378, 44.98314142227173, 44.35882732272148, 43.36184822022915, 44.71038445830345, 43.93396072089672, 42.877655401825905, 45.712706074118614, 43.91037158668041, 51.01613089442253, 55.813616663217545, 54.45949472486973, 58.22524465620518, 55.14584809541702, 56.00345827639103, 50.90947061777115, 46.657418981194496, 48.11351224780083, 52.63477563858032, 46.93946644663811, 43.44515115022659, 42.979793921113014, 40.54530255496502, 38.09462025761604, 40.01048505306244, 42.640525326132774, 41.788649037480354, 43.013916090130806, 41.90847560763359, 40.92573434114456, 40.42878940701485, 41.01233169436455, 42.46839836239815, 44.76306103169918, 43.211239501833916, 42.38713592290878, 42.6124220341444, 40.46506226062775, 42.668267637491226, 42.36124411225319, 42.68562510609627, 44.36416983604431, 45.426509231328964, 44.17669929563999, 42.80338458716869, 45.35824589431286, 50.29519937932491, 48.83489593863487, 42.155074775218964, 35.59210114181042, 42.69180737435818, 49.532986879348755, 48.032964169979095, 45.752280950546265, 45.757847651839256, 45.56538037955761, 44.138636738061905, 43.84608283638954, 42.5649131834507, 42.85530500113964, 44.691263884305954, 43.7650103867054, 47.847541719675064, 46.53910472989082, 46.99457488954067, 43.30462709069252, 40.64649112522602, 41.174845173954964, 40.03659725189209, 39.885737746953964, 40.083988308906555, 39.89549182355404, 41.38766795396805, 40.75233444571495, 38.60619820654392, 39.2411745339632, 39.69691067934036, 40.841356068849564, 41.90648451447487, 44.005180299282074, 43.86228136718273, 44.72513906657696, 45.751885771751404, 45.83571307361126, 48.11236850917339, 48.90352785587311, 49.24848474562168, 48.3818044513464, 47.393272295594215, 46.65773816406727, 45.372202545404434, 43.67336690425873, 46.50451518595219, 46.137264892458916, 48.12096744775772, 47.04744145274162, 52.875234335660934, 57.69404076039791, 62.08462156355381, 58.524558395147324, 61.42127215862274, 65.94406306743622, 68.5711432993412, 54.45575572550297, 44.139434695243835, 53.61750550568104, 82.10931524634361, 82.37810522317886, 69.50176656246185, 65.00080168247223, 68.58445778489113, 64.19707641005516, 69.97664228081703, 67.15458691120148, 70.63363462686539, 59.89428609609604, 62.604676857590675, 15.91764036566019, 0.24122095695929602, 0.15184896590653807, 13.094045128673315, 71.06573984026909, 51.443813145160675, 49.987643882632256, 28.80227778106928, 47.36834943294525, 42.29361154139042, 41.39258489012718, 2.651638314127922, 0.29087364964652807, 0.09391389030497521, 0.012517770537670003, 0.06933697979548015, 0.02532696020352887, 0.06708897737553343, 0.05586683619185351, 0.017186008371936623, 0.03306605576653965, 0.04169925559835974, 0.05120553651067894, 0.029567319288617, 0.07070037187077105, 0.10133394956937991, 0.05136258609127253, 0.3844225814100355, 20.02051390707493, 80.49402192234993, 44.66056153178215, 42.696564719080925, 56.361733451485634, 52.23491169512272, 47.38863654434681, 86.14884048700333, 19.65266514569521, 0.15205614385195076, 0.25046525232028216, 4.513900335878134, 44.8417966067791, 63.62140350043774, 70.08387252688408, 70.94904810190201, 70.80251276493073, 65.57165265083313, 62.82750070095062, 61.85168646275997, 59.62157852947712, 58.95449012517929, 55.56425504386425, 54.63210806250572, 52.809402868151665, 48.510165363550186, 50.96078686416149, 51.074795946478844, 50.365130826830864, 48.79775673151016, 48.34266275167465, 47.97403693199158, 47.04254351556301, 45.960992351174355, 48.849175572395325, 47.755985632538795, 45.87951712310314, 46.088840290904045, 49.514284282922745, 45.9179862588644, 52.82265655696392, 58.48362699151039, 59.696480110287666, 58.669573813676834, 58.85110147297382, 56.50838278234005, 52.16070547699928, 46.928967610001564, 51.51807256042957, 57.21275858581066, 49.186962246894836, 46.468223333358765, 47.1817946434021, 42.66261734068394, 42.94643171131611, 43.589885383844376, 45.995893478393555, 43.83505962789059, 44.94524985551834, 42.82552219927311, 43.45538020133972, 43.17461706697941, 42.79494144022465, 44.75531704723835, 45.16166724264622, 45.34070983529091, 43.928090035915375, 44.79743778705597, 43.91892492771149, 45.48874609172344, 43.94949048757553, 44.3597012758255, 47.527439296245575, 48.29723618924618, 48.32028955221176, 46.00231893360615, 49.4168347120285, 52.19477824866772, 50.81002235412598, 43.056447207927704, 34.892699271440506, 43.834406062960625, 51.4248863607645, 49.20078970491886, 48.238400146365166, 48.32553327083588, 46.631306782364845, 46.51667833328247, 45.974120646715164, 44.9275504052639, 46.75185151398182, 47.84593440592289, 46.354054659605026, 49.52151529490948, 49.25833381712437, 47.50146009027958, 46.40660963952541, 42.27800577878952, 43.43318559229374, 43.425927981734276, 41.4859838783741, 42.135190442204475, 42.05369621515274, 43.66659566760063, 43.67744408547878, 41.15577779710293, 39.86170783638954, 42.396475821733475, 41.537911891937256, 42.96731919050217, 46.898261457681656, 46.46658182144165, 48.37718389928341, 47.37333856523037, 49.9397436529398, 50.255506709218025, 51.15462966263294, 52.95252978801727, 51.5366155654192, 50.52715413272381, 48.79193924367428, 48.19279119372368, 46.86746411025524, 48.54719057679176, 47.30228237807751, 49.72301848232746, 48.25156643986702, 54.86165754497051, 59.30594466626644, 64.1622930765152, 61.76330700516701, 64.19130071997643, 67.56735876202583, 69.80587184429169, 58.45419757068157, 50.83219416439533, 61.773509457707405, 79.41439345479012, 81.10233888030052, 71.45170792937279, 67.97642201185226, 72.80254304409027, 67.9579246044159, 74.41224306821823, 70.66381260752678, 76.35248735547066, 65.82914963364601, 71.3958129286766, 19.890965558588505, 0.41082982847001404, 0.05780159292044118, 15.766657367348671, 81.84453785419464, 56.82374686002731, 61.22854270040989, 36.44521616399288, 49.54500563442707, 54.01881717145443, 59.23737354576588, 9.079550094902515, 0.33268696221057326, 0.06772634864319116, 0.029815014786436222, 0.11984850803855807, 0.007626126771356212, 0.055561980479978956, 0.015429722388944356, 0.0871325604384765, 0.29261149233207107, 0.137876343796961, 0.12308958568610251, 0.20524920750176534, 0.14234223228413612, 0.16105958260595798, 0.20377920591272414, 0.6645547121297568, 28.47611278295517, 92.47990876436234, 49.46565069258213, 55.438496991992, 63.09135094285011, 62.763462737202644, 52.37908735871315, 92.75838062167168, 20.29287189245224, 0.34365652827546, 0.28197354753501713, 5.793770933523774, 51.38431213796139, 68.09790909290314, 74.31344076991081, 73.94971668720245, 73.88927713036537, 67.5712801516056, 67.16182172298431, 65.8067612349987, 62.23012335598469, 60.91860473155975, 59.152847081422806, 58.15420746803284, 56.317496225237846, 51.6523839533329, 53.4716921299696, 52.873064652085304, 54.08410146832466, 51.98020376265049, 51.39152035117149, 48.73744636774063, 51.45031079649925, 49.97868776321411, 50.60621649026871, 51.91388592123985, 49.77968104183674, 49.890384301543236, 49.9815072119236, 47.39733427762985, 57.45474100112915, 60.51871418952942, 61.576984003186226, 61.20227850973606, 60.8160824328661, 61.32131092250347, 57.268285006284714, 52.222011387348175, 53.378760516643524, 60.77213019132614, 52.12378665804863, 47.57624387741089, 49.04405951499939, 45.30764780938625, 44.813598319888115, 44.70653146505356, 49.30660642683506, 46.143257170915604, 48.72902601957321, 46.71466290950775, 45.226476565003395, 44.82234165072441, 46.38797543942928, 49.20325197279453, 50.719192028045654, 48.325514271855354, 45.835640877485275, 47.95349143445492, 45.84850698709488, 47.61943615972996, 46.68920427560806, 48.84628392755985, 51.66175805032253, 51.84418246150017, 51.01419299840927, 48.804748356342316, 53.15399117767811, 52.90105774998665, 55.12268453836441, 44.52892139554024, 36.441051587462425, 44.69621881842613, 54.469309598207474, 52.49753460288048, 53.028901889920235, 52.96805575489998, 49.23712335526943, 47.96853482723236, 49.12042401731014, 47.762072905898094, 48.76385115087032, 51.68293811380863, 50.33040829002857, 53.30024532973766, 52.41817966103554, 51.82587884366512, 47.7953515201807, 45.415147840976715, 46.43082574009895, 47.157787531614304, 43.663871213793755, 45.007148534059525, 44.29655246436596, 45.98056510090828, 46.90914787352085, 42.36003577709198, 44.75147545337677, 44.54728201031685, 45.59047043323517, 46.19198955595493, 49.88319508731365, 49.087977558374405, 49.45060350000858, 52.21120096743107, 51.52556195855141, 51.179902106523514, 53.34365040063858, 57.03542970120907, 52.71564669907093, 52.31264032423496, 52.80450113117695, 50.38230210542679, 48.83433356881142, 50.950876995921135, 51.91803149878979, 54.45145435631275, 51.06855668127537, 58.084978982806206, 64.15948882699013, 66.42156824469566, 65.42560368776321, 68.06896224617958, 71.46949097514153, 71.75692275166512, 59.936068654060364, 56.30012735724449, 72.27762401103973, 86.47275790572166, 78.27526777982712, 71.37759670615196, 72.59783282876015, 76.99906066060066, 73.27426493167877, 79.30440455675125, 74.54528912901878, 80.42413607239723, 72.3654904961586, 79.32964280247688, 27.036126852035522, 0.5472426570486277, 0.13530803786125034, 17.314532808959484, 93.05462032556534, 65.69788947701454, 71.33043363690376, 40.78864149749279, 64.57751959562302, 67.7737408876419, 77.85453155636787, 13.786393627524376, 0.509908472886309, 0.32309120055288076, 0.2355060784611851, 0.3086266532773152, 0.08565953088691458, 0.12590538302902132, 0.11967936516157351], [0.05824452149681747, 0.09922998317051679, 0.14299340749857947, 0.06606102120713331, 0.04925381057546474, 0.09136083550401963, 0.2154872682876885, 0.19447678554570302, 0.5176773341372609, 14.44370610639453, 63.26683692634106, 54.974595084786415, 37.390092462301254, 34.18812967836857, 49.38959777355194, 39.78628188371658, 81.81882083415985, 30.571599639952183, 0.29958480095956475, 0.059326702685211785, 0.5284517153631896, 24.745936542749405, 59.66814883053303, 63.30397993326187, 67.23269551992416, 61.67571410536766, 58.88407230377197, 59.239163249731064, 63.04061986505985, 56.884684190154076, 54.72902566194534, 52.395350486040115, 49.611407071352005, 48.215665966272354, 48.837419003248215, 46.88947632908821, 46.9515535980463, 45.06975017488003, 48.73862810432911, 48.20635266602039, 48.96402820944786, 46.61358833312988, 48.47405590116978, 46.58708095550537, 46.5215040743351, 44.87979456782341, 43.70014026761055, 45.39182849228382, 47.72978983819485, 55.13515166938305, 58.435779958963394, 57.74677433073521, 57.54714824259281, 59.15892295539379, 55.11197671294212, 51.38821832835674, 46.78166851401329, 48.83894272148609, 54.37198542058468, 50.61620615422726, 45.133290365338326, 43.968941643834114, 42.6954285800457, 40.72960786521435, 42.58313700556755, 40.55871583521366, 42.41933919489384, 41.56069926917553, 40.77159181237221, 39.390400126576424, 38.96203011274338, 38.24460580945015, 39.33216445147991, 40.33391609787941, 42.648208513855934, 42.88058504462242, 41.65152199566364, 39.602269157767296, 42.20345377922058, 41.800261214375496, 40.45117400586605, 41.742755100131035, 42.499378100037575, 45.57912804186344, 45.912962928414345, 47.70029962062836, 49.44892778992653, 47.396745309233665, 46.46961405873299, 38.93165834248066, 44.62512083351612, 48.397759795188904, 49.04792010784149, 47.943448573350906, 45.08761301636696, 46.424138098955154, 44.423256665468216, 41.2081503868103, 39.28444281220436, 42.16631077229977, 42.99577586352825, 42.07545004785061, 42.298840060830116, 42.44077384471893, 44.87121842801571, 41.60874009132385, 41.888534277677536, 38.50711092352867, 38.7823111563921, 41.11878298223019, 40.35308226943016, 39.57441285252571, 40.39945498108864, 40.01991614699364, 40.17885401844978, 39.47760924696922, 43.94193649291992, 43.016762137413025, 46.5811912715435, 50.699915662407875, 48.40542398393154, 46.11609622836113, 46.61556422710419, 47.36208736896515, 53.83706532418728, 51.48123353719711, 55.26758976280689, 55.580920949578285, 54.38428156077862, 46.5140450745821, 46.91202811896801, 42.94562615454197, 46.230485290288925, 44.62191000580788, 49.46818895637989, 45.02492398023605, 47.01427683234215, 51.96456000208855, 54.51230809092522, 60.71175903081894, 59.96797934174538, 55.94962276518345, 60.13111598789692, 66.88906475901604, 63.71783472597599, 49.86909784376621, 47.0454503595829, 62.54019811749458, 73.76700729131699, 59.11899469792843, 66.06390103697777, 61.33392624557018, 67.82559290528297, 60.65214402973652, 69.26810190081596, 58.02642032504082, 60.49096427857876, 11.771044470369816, 0.3177035943372175, 0.12706274748779833, 15.248936098068953, 72.78294369578362, 56.21897131204605, 46.45566500723362, 31.762866117060184, 40.733069479465485, 36.732590943574905, 44.94369573891163, 4.365668864920735, 0.19668961758725345, 0.03072131068620365, 0.03992843929154333, 0.0969088717829436, 0.08137701966916211, 0.04682540689827874, 0.073357364453841, 0.06209583378222305, 0.04057787416968495, 0.061818856847821735, 0.041417265456402674, 0.040002869282034226, 0.043261546961730346, 0.16484014224261045, 0.1703583070775494, 0.6191936961840838, 19.89950180053711, 72.78517037630081, 53.68637681007385, 41.26430757343769, 47.601493522524834, 54.82655882835388, 46.84789136052132, 87.74220898747444, 35.10413132607937, 0.11796061051427387, 0.05410027239122428, 0.7078872306738049, 26.844921112060547, 64.26375523209572, 66.86666116118431, 69.43959429860115, 65.6538650393486, 62.93209008872509, 61.56087666749954, 64.4542770087719, 58.574005141854286, 57.41995006799698, 55.64914628863335, 52.61519528925419, 50.33415488898754, 51.42836697399616, 50.42275853455067, 49.618885070085526, 47.245684415102005, 51.393921822309494, 50.92065341770649, 50.99741689860821, 48.9709210395813, 51.07854254543781, 48.166154623031616, 47.60473474860191, 46.30175046622753, 45.97365327179432, 47.47665122151375, 50.22319704294205, 58.440077528357506, 61.63682319223881, 59.5321199297905, 60.78781954944134, 59.16247956454754, 58.62967595458031, 53.418240398168564, 50.51850959658623, 49.2732822149992, 56.502599492669106, 54.18832987546921, 47.92617850005627, 45.644997507333755, 45.225541815161705, 44.540434777736664, 44.852436035871506, 44.49959076941013, 43.662670478224754, 42.94408343732357, 43.936837166547775, 42.68301084637642, 40.9578388184309, 40.863721668720245, 41.01517014205456, 43.48818764090538, 45.532876923680305, 46.01809948682785, 44.02983717620373, 43.26660633087158, 46.300853714346886, 44.79708440601826, 44.8522574454546, 46.06356784701347, 44.14560556411743, 47.3392353951931, 47.40056790411472, 50.533925369381905, 49.558643102645874, 47.96514540910721, 46.90752536058426, 40.7854762673378, 46.090614795684814, 50.07115200161934, 49.888678193092346, 49.68783617019653, 46.99420250952244, 46.58413231372833, 44.87265855073929, 45.38433529436588, 43.579739928245544, 44.51483555138111, 44.14370186626911, 42.781657353043556, 44.599552005529404, 45.725955963134766, 45.84241971373558, 42.600737661123276, 42.27763719856739, 40.017024502158165, 41.26327782869339, 42.81691186130047, 43.80550481379032, 41.501148864626884, 43.74901324510574, 42.74898290634155, 43.527602925896645, 41.11237272620201, 47.821216732263565, 43.98930475115776, 47.86329947412014, 52.032439559698105, 49.3358800560236, 48.36570471525192, 47.93112963438034, 51.42495855689049, 55.95843829214573, 56.14187344908714, 57.06607885658741, 58.4359547495842, 57.773973271250725, 48.97191658616066, 49.07389551401138, 44.72366474568844, 48.3598530292511, 47.93747529387474, 52.940758019685745, 48.71882736682892, 50.355384349823, 53.09733621776104, 57.077238857746124, 62.48876787722111, 61.83994509279728, 59.75865997374058, 64.33411225676537, 67.37651780247688, 64.1961644589901, 53.57690468430519, 53.7503045797348, 59.827284291386604, 73.49679619073868, 62.96357899904251, 69.86842408776283, 65.23109972476959, 69.93689641356468, 65.83972826600075, 73.21312621235847, 63.747423738241196, 71.2613533437252, 16.754976734519005, 0.6621722993440926, 0.06318706917227246, 18.323154486715794, 82.39721059799194, 62.22698472440243, 58.21636073291302, 39.126071110367775, 32.416869923472404, 45.47017268836498, 60.42247295379639, 9.018993694335222, 0.07410415797494352, 0.03190807532519102, 0.09074317567865364, 0.13244532194221392, 0.05712596022931393, 0.028446683718357235, 0.03255732466641348, 0.1657864250591956, 0.23125952429836616, 0.1892011397285387, 0.13764425937552005, 0.08966798923211172, 0.318648912361823, 0.28045069018844515, 0.4887085792142898, 0.9551876387558877, 28.68703566491604, 82.65137135982513, 67.27700874209404, 49.09099079668522, 47.94731676578522, 66.66140377521515, 50.24724595248699, 97.71864205598831, 36.49411953985691, 0.4398483963450417, 0.1413305662572384, 1.5526929893530905, 33.36521543562412, 69.65992167592049, 74.56371054053307, 73.9461524784565, 69.97278928756714, 64.56525385379791, 64.66945186257362, 67.67470300197601, 61.20390482246876, 61.98867671191692, 59.76199999451637, 56.820627227425575, 52.76618018746376, 54.23698626458645, 52.95605219900608, 52.25308611989021, 49.23092968761921, 53.693877607584, 52.89344295859337, 54.38600666821003, 51.52870438992977, 54.31528866291046, 51.02059185504913, 51.557210460305214, 48.145282343029976, 48.70752677321434, 52.246288284659386, 52.78473079204559, 58.597962856292725, 62.71190330386162, 61.738650128245354, 61.42116956412792, 63.09445537626743, 61.168289333581924, 56.94309085607529, 51.30201995372772, 54.16558809578419, 58.5481171309948, 56.594892740249634, 50.77208139002323, 49.85180877149105, 47.26896956562996, 47.12724857032299, 48.0597223341465, 46.626606434583664, 45.770709961652756, 45.82150563597679, 45.17550230026245, 45.346622318029404, 42.38450266420841, 42.33459234237671, 42.59008303284645, 46.06316886842251, 47.205938547849655, 47.564639300107956, 47.68778309226036, 46.02074794471264, 50.242583602666855, 48.115001767873764, 47.50060893595219, 49.27998125553131, 48.20641726255417, 51.80324345827103, 50.98485477268696, 55.902714282274246, 52.97321207821369, 49.55889008939266, 49.03396725654602, 38.93756702542305, 48.17759580910206, 50.13412982225418, 52.257520481944084, 53.170144110918045, 51.396828666329384, 49.6761441975832, 47.61559076607227, 47.212911173701286, 45.62094859778881, 48.646973222494125, 48.20463515818119, 46.5022087097168, 49.23145405948162, 46.410135850310326, 48.82832229137421, 46.9760736823082, 45.60393691062927, 42.27461636066437, 44.446150436997414, 44.8534619808197, 46.62701681256294, 43.862927332520485, 44.57644544541836, 45.002630576491356, 45.66968858242035, 43.250179812312126, 49.82011467218399, 47.446807622909546, 50.72994165122509, 54.04114097356796, 53.005415350198746, 51.62569798529148, 50.954718589782715, 53.77200901508331, 56.2714084982872, 56.48317873477936, 58.85982200503349, 61.69291578233242, 59.377867206931114, 51.07109874486923, 52.56454400718212, 47.0213520526886, 50.901969820261, 50.764341205358505, 54.853632375597954, 50.838019251823425, 53.79595533013344, 56.02386698126793, 61.50882326066494, 67.01992973685265, 64.49207738041878, 63.293203711509705, 67.93472304940224, 71.06632500886917, 65.39400458335876, 54.18038830161095, 61.442421823740005, 73.80505084991455, 73.79103720188141, 64.05269175767899, 72.75636792182922, 69.60794806480408, 76.53809979557991, 72.27029800415039, 78.10218706727028, 69.84222829341888, 79.97329026460648, 22.804461121559143, 1.0700954915955663, 0.22055754699977115, 21.33365124464035, 93.54615435004234, 69.77317839860916, 66.41827002167702, 49.06168296933174, 60.04889219999313, 56.54836043715477, 78.85558024048805, 13.76829044893384, 0.23348316201008856, 0.20638907211832702, 0.19074155628914014, 0.20171462529106066, 0.2388014961616136, 0.11432076949859038, 0.2006697704200633], [0.05485652829520404, 0.038715599293936975, 0.037763824584544636, 0.0037534538523686933, 0.05653089137922507, 0.15778763161506504, 0.11000166297890246, 0.15032768191304058, 0.49685673729982227, 10.908078476786613, 58.03445689380169, 52.87591449916363, 40.652137622237206, 21.654112748801708, 51.1145456135273, 41.17424100637436, 72.27701604366302, 48.7535385042429, 0.39625259349122643, 0.07608457905007526, 0.06740439013810828, 7.817103462293744, 40.58505222201347, 60.223895609378815, 61.79109871387482, 64.2774572968483, 65.15859201550484, 62.4691229313612, 56.51939459145069, 55.71142494678497, 52.959358021616936, 50.522430986166, 47.113652899861336, 47.3302298784256, 46.36049151420593, 47.643701657652855, 49.04774151742458, 49.63277332484722, 49.98113103210926, 54.81813468039036, 54.97280918061733, 52.17406556010246, 49.379277527332306, 45.16844227910042, 46.20387151837349, 44.76572848856449, 45.19711934030056, 47.05553121864796, 52.90260806679726, 60.44341742992401, 57.47566267848015, 54.01318967342377, 59.049086049199104, 60.37971384823322, 57.918061539530754, 51.13822214305401, 49.53413061797619, 48.09235118329525, 53.64559359848499, 54.9512605369091, 50.55183380842209, 45.903068259358406, 48.436297327280045, 45.70261761546135, 42.05397740006447, 43.93608100712299, 42.53786623477936, 42.000894248485565, 40.322490110993385, 42.01952084898949, 39.065179377794266, 37.27854184806347, 38.32087531685829, 39.856376722455025, 43.52212741971016, 44.26689885556698, 40.48572175204754, 41.71503558754921, 41.45599968731403, 42.21903294324875, 41.03988401591778, 42.4632952362299, 43.09680104255676, 44.26119536161423, 45.56305110454559, 48.139734640717506, 50.0355327129364, 48.51327359676361, 46.365020871162415, 43.30055370926857, 48.34544040262699, 49.88227553665638, 50.54016463458538, 49.25672650337219, 45.351083278656006, 43.470013216137886, 44.725583642721176, 41.23870834708214, 41.13451413810253, 43.49018253386021, 43.13134118914604, 40.38166053593159, 41.59380689263344, 44.68822784721851, 44.70741681754589, 40.09844273328781, 39.46822755038738, 39.18205350637436, 39.875911474227905, 40.6932058185339, 40.35941272974014, 40.02896726131439, 40.59718497097492, 42.70386792719364, 41.7890328168869, 41.326533034443855, 44.548847526311874, 44.783910512924194, 52.28457883000374, 55.265663266181946, 52.250259071588516, 45.43917395174503, 47.30005569756031, 47.8439699113369, 55.587711185216904, 57.12704658508301, 59.18346203863621, 59.16026808321476, 60.430266335606575, 56.32291853427887, 51.90122500061989, 45.491500943899155, 44.88149307668209, 45.285696387290955, 46.225382164120674, 45.767176151275635, 45.97891978919506, 48.30555774271488, 51.39370523393154, 51.01074278354645, 57.36545339226723, 61.023239716887474, 62.15656690299511, 58.96037220954895, 62.12171137332916, 60.43639540672302, 60.62326177954674, 46.79956555366516, 59.397504553198814, 67.59765833616257, 71.06433391571045, 63.65281641483307, 64.83091279864311, 59.37820918858051, 63.28841216862202, 54.76857014000416, 56.09812259674072, 11.555149555206299, 0.11966596939601004, 0.0989742019737605, 25.04320979118347, 77.33716651797295, 47.853906378149986, 37.91987903416157, 34.00513529777527, 57.63618506491184, 37.42236413061619, 48.13791073858738, 11.356859095394611, 0.07054633912048303, 0.032376808376284316, 0.027652572716760915, 0.03210128976206761, 0.14269996230723336, 0.15054314222652465, 0.013568363137892447, 0.03286816951003857, 0.03829459004919045, 0.020618176058633253, 0.09886994506814517, 0.04493848900892772, 0.17848656076239422, 0.1440889510558918, 0.14038737077498809, 0.47587191802449524, 14.443708956241608, 68.41871827840805, 56.77872307598591, 48.13314199447632, 34.70134913921356, 57.82684363424778, 48.208214566111565, 79.15387943387032, 55.04675321280956, 0.5064373591449112, 0.08920051041059196, 0.0749005121178925, 7.4345827382057905, 49.423370361328125, 64.55574676394463, 65.80467894673347, 66.77912905812263, 66.56969949603081, 63.463875353336334, 61.09995000064373, 58.11786621809006, 55.84139697253704, 51.376351565122604, 49.46240186691284, 49.79745268821716, 48.93154375255108, 50.149370804429054, 50.51495298743248, 51.56559661030769, 53.419140949845314, 56.18145972490311, 57.66931168735027, 53.79186674952507, 53.021287098526955, 48.84505279362202, 49.85807083547115, 48.12723711133003, 46.37625306844711, 49.55629102885723, 56.11826151609421, 61.78378030657768, 59.67762552201748, 55.497800409793854, 59.49590787291527, 61.35411836206913, 60.301578640937805, 54.25951525568962, 52.796985134482384, 50.901715233922005, 57.71356411278248, 56.5536193549633, 51.46503120660782, 48.32245923578739, 51.03495888411999, 48.554660975933075, 43.61025229096413, 46.302594020962715, 43.16375344991684, 44.571562707424164, 42.034362852573395, 42.78701886534691, 40.79776480793953, 40.04996493458748, 41.83282546699047, 41.375702396035194, 46.559232249855995, 45.822117403149605, 43.62808473408222, 43.07074584066868, 43.68519946932793, 44.561109468340874, 42.107311338186264, 43.22969131171703, 44.2243867367506, 46.502079516649246, 48.29610385000706, 50.56971184909344, 53.13804343342781, 50.51250971853733, 45.821190252900124, 43.538253754377365, 46.90597504377365, 51.016108095645905, 51.90186716616154, 52.179769054055214, 47.471255511045456, 47.112649753689766, 46.36494867503643, 42.91400425136089, 42.50498279929161, 45.29907166957855, 43.4777420014143, 41.615028753876686, 44.89140294492245, 46.09968490898609, 46.96725815534592, 41.38075612485409, 42.19696752727032, 40.147110521793365, 42.258965000510216, 41.094870865345, 42.744936123490334, 42.25734628736973, 45.009344816207886, 46.07158161699772, 43.70050124824047, 45.49490936100483, 47.958256378769875, 47.60238267481327, 53.65484610199928, 58.00130367279053, 55.101671665906906, 47.200185656547546, 49.3917066603899, 51.216304153203964, 59.20013554394245, 59.67130646109581, 60.99592678248882, 59.935468286275864, 60.2658985555172, 56.493346989154816, 52.10962861776352, 49.42375414073467, 47.58008927106857, 47.63492792844772, 49.331563487648964, 49.24760699272156, 49.06432382762432, 51.31191082298756, 53.90686757862568, 52.67882287502289, 59.0744648873806, 63.14609840512276, 64.40995618700981, 62.2399078309536, 65.07603764533997, 61.081612184643745, 63.90523687005043, 53.53543370962143, 61.91558763384819, 70.3525561094284, 75.19332155585289, 67.88362339138985, 71.90016746520996, 66.6533862054348, 71.99122577905655, 61.15456447005272, 66.06345266103745, 14.041294399648905, 0.1273324736393988, 0.08494782610796392, 28.16424071788788, 85.07089152932167, 55.14819636940956, 48.91160622239113, 32.153973430395126, 46.65755197405815, 45.862668827176094, 66.57588556408882, 17.887331172823906, 0.11047020307159983, 0.057197892892872915, 0.02549264838307863, 0.0823988308547996, 0.1067649491596967, 0.04086553060915321, 0.07412654114887118, 0.15633900387911126, 0.20458531187614426, 0.1492361311102286, 0.2631138532888144, 0.13297773868544027, 0.2572611579671502, 0.296927229501307, 0.30206149618607014, 0.6903407815843821, 20.282051973044872, 81.08998194336891, 67.37621381878853, 52.24659226834774, 30.76140135526657, 68.00520166754723, 53.19743424654007, 86.38195797801018, 58.135622665286064, 0.5898999993223697, 0.24773147713858634, 0.18990275129908696, 10.745755936950445, 57.72772595286369, 68.22756573557854, 70.36255717277527, 71.14072501659393, 71.30624413490295, 67.76983469724655, 63.66285927593708, 60.6854872405529, 58.299355879426, 54.36950035393238, 51.86654806137085, 53.432288244366646, 51.122338995337486, 53.514550030231476, 54.358982518315315, 53.493514358997345, 55.56390926241875, 59.52454313635826, 59.74570646882057, 56.1510119587183, 56.79052524268627, 51.45299345254898, 53.0372766405344, 50.349232479929924, 49.563582837581635, 51.5869514644146, 58.73090632259846, 64.88657221198082, 62.60972298681736, 58.590511456131935, 61.40320412814617, 64.68884602189064, 63.92446383833885, 57.52837724983692, 55.59617333114147, 53.6715804040432, 59.4316191226244, 58.72324213385582, 54.84691433608532, 51.46163418889046, 53.57816241681576, 53.10164898633957, 46.512103378772736, 49.529282078146935, 47.15501748025417, 46.514820232987404, 45.28360649943352, 46.94834277033806, 41.265949085354805, 42.86978982388973, 43.902665600180626, 44.90632854402065, 49.91536036133766, 48.99060018360615, 46.976981833577156, 47.558396235108376, 46.34753040969372, 47.210851684212685, 44.9363849312067, 46.26387409865856, 48.98617722094059, 50.767084658145905, 51.97029009461403, 55.56377246975899, 56.970863565802574, 52.42452532052994, 47.382826656103134, 42.96929508447647, 50.04077263176441, 55.01378618180752, 56.130261272192, 56.087627559900284, 50.55830866098404, 51.77400782704353, 49.91365805268288, 45.407396256923676, 44.776261523365974, 50.19684545695782, 46.8137463927269, 44.72438670694828, 47.82799556851387, 48.447822108864784, 50.004872158169746, 42.972969487309456, 45.19212260842323, 43.01809586584568, 45.94933457672596, 45.01500651240349, 45.19606299698353, 43.581214249134064, 45.16650818288326, 48.23321722447872, 45.88401988148689, 47.734471186995506, 50.08094787597656, 51.90440163016319, 57.79904052615166, 61.9013611972332, 59.928438663482666, 50.90978220105171, 51.79486110806465, 51.34456627070904, 59.228075444698334, 62.61369377374649, 64.34819430112839, 62.96104833483696, 62.342639118433, 59.757037460803986, 55.54484188556671, 51.76339119672775, 50.3492096811533, 51.169338673353195, 53.72190110385418, 51.923081427812576, 52.68675684928894, 56.10716991126537, 55.382525995373726, 55.2174324542284, 63.04262615740299, 66.68162629008293, 67.39957496523857, 64.9631305038929, 68.81301552057266, 63.50983768701553, 63.495371863245964, 57.71612897515297, 69.48747932910919, 74.18947622179985, 78.50951761007309, 70.24733975529671, 75.10115370154381, 71.69190064072609, 76.74331918358803, 68.21172818541527, 75.80622106790543, 18.3395829051733, 0.42728309403173625, 0.28636070899665356, 30.080253705382347, 96.88620552420616, 60.515366569161415, 58.3986559510231, 44.49391387403011, 75.50703272223473, 61.16242244839668, 81.71426564455032, 21.691945418715477, 0.2888973103836179, 0.1885461647179909, 0.18166123103583232, 0.16329644538927823, 0.27976384735666215, 0.14835015521384776, 0.1488092032377608], [0.0036609465360015747, 0.07233366821310483, 0.04396474301756825, 0.052583274300559424, 0.022605517660849728, 0.04050528099469375, 0.09936172180459835, 0.1382155646570027, 0.46547258854843676, 13.362481724470854, 65.18180876970291, 43.384988978505135, 34.47396174073219, 26.041104644536972, 36.45353391766548, 44.55551616847515, 59.4955088943243, 66.07629597187042, 5.005774442106485, 0.20207508641760796, 0.5526492919307202, 1.3182540005072951, 12.87723446264863, 62.277294024825096, 58.45856353640556, 63.92314910888672, 59.93089713156223, 59.05233107507229, 60.64426705241203, 59.54805247485638, 55.62789782881737, 49.35285374522209, 49.93013396859169, 50.0234417617321, 48.300200030207634, 51.169380471110344, 53.43686319887638, 57.248032093048096, 56.452244594693184, 56.292584761977196, 56.90317779779434, 52.2228891402483, 51.25940524041653, 46.966897174715996, 44.55190256237984, 45.22144943475723, 45.89248202741146, 49.4958932697773, 58.867653384804726, 58.09756010770798, 56.85618191957474, 52.465426325798035, 56.778909265995026, 58.28283056616783, 57.01106160879135, 53.426584750413895, 50.65610781311989, 49.284195229411125, 52.808794900774956, 53.07065024971962, 50.70615492761135, 46.622259467840195, 48.9284773170948, 50.239068791270256, 46.10854983329773, 43.387219458818436, 40.95006823539734, 41.774791181087494, 41.47842228412628, 39.744351133704185, 39.840075597167015, 37.905436009168625, 40.16656167805195, 39.48171302676201, 39.75832298398018, 44.362448528409004, 41.51915989816189, 43.83485823869705, 41.219264790415764, 40.90084947645664, 39.30835872888565, 42.039678767323494, 43.05722996592522, 44.97124046087265, 45.76961562037468, 47.26718746125698, 49.562750682234764, 50.099737867712975, 46.359431371092796, 40.58189459145069, 47.23208874464035, 51.583888828754425, 50.47926530241966, 46.51714950799942, 44.32149812579155, 45.57646058499813, 43.246619403362274, 42.29644238948822, 39.38162259757519, 40.95241270959377, 41.78699232637882, 38.3655571192503, 43.57932575047016, 43.79386603832245, 41.24924898147583, 41.20421759784222, 38.07613044977188, 39.42951902747154, 39.456885159015656, 39.20585162937641, 42.02005662024021, 41.04542411863804, 41.319625005126, 42.48433090746403, 42.9455691576004, 48.82573463022709, 47.67910435795784, 45.50594016909599, 52.76600159704685, 56.510978043079376, 51.822459027171135, 45.62678508460522, 50.814281925559044, 51.50023631751537, 57.80995354056358, 58.97964857518673, 57.02664837241173, 55.011760890483856, 60.88842675089836, 55.68199932575226, 53.673525899648666, 50.087817907333374, 46.119033470749855, 43.87938044965267, 46.29980117082596, 43.58963079750538, 48.59783045947552, 47.53170646727085, 49.0182550996542, 49.94217172265053, 52.99830973148346, 54.064536318182945, 58.756767734885216, 60.632658675312996, 65.37393406033516, 60.71999318897724, 63.09238828718662, 62.373626455664635, 57.547399029135704, 65.09146481752396, 69.3286782503128, 66.5636046230793, 68.9114074409008, 63.91045778989792, 66.58613741397858, 59.7596251219511, 51.88683897256851, 7.220210591331124, 0.12700144608970731, 0.06760272168321535, 42.42850810289383, 73.0260394513607, 52.69219055771828, 34.10367541015148, 88.11194434762001, 50.93509644269943, 32.71630145609379, 62.51382373273373, 20.15546176582575, 0.052705665584653616, 0.0072339481084782165, 0.031344150702352636, 0.045340655124164186, 0.07352668544626795, 0.06442290832637809, 0.0617587985470891, 0.007419070816467865, 0.06701231352053583, 0.02458533945173258, 0.03806049069680739, 0.04313694778829813, 0.11325350176775828, 0.016374445767723955, 0.1283663001959212, 0.3093752427957952, 16.77756082266569, 74.11333590745926, 52.951880022883415, 35.28974376618862, 21.010875664651394, 45.65529875457287, 50.55977538228035, 67.89180055260658, 71.30040004849434, 6.567395171150565, 0.2835173928178847, 0.4824941314291209, 1.3626322941854596, 18.9570801705122, 68.72179761528969, 60.318385139107704, 65.78181937336922, 62.11998626589775, 62.367976158857346, 63.812423050403595, 62.29716315865517, 59.27791357040405, 51.9326189160347, 53.42352591454983, 51.78470425307751, 51.817819476127625, 54.2897692322731, 55.75043745338917, 57.47042655944824, 57.86728486418724, 58.343323320150375, 59.02212269604206, 55.61109513044357, 53.86412367224693, 49.59852576255798, 48.87063302099705, 47.21820808947086, 47.98941470682621, 51.69711135327816, 60.76855458319187, 59.432002902030945, 58.99612829089165, 52.3661794513464, 60.35310007631779, 61.044172793626785, 60.59046573936939, 57.03753098845482, 54.14087042212486, 51.90222814679146, 56.56400419771671, 57.026739567518234, 53.25444258749485, 50.31732939183712, 52.18698866665363, 52.81991310417652, 48.613402023911476, 46.016541570425034, 43.82470518350601, 42.51402631402016, 43.76180335879326, 41.38011775910854, 41.08862780034542, 41.38680540025234, 42.53082901239395, 42.88741707801819, 43.61160881817341, 46.79507039487362, 44.36872199177742, 44.529913142323494, 43.53377379477024, 44.62561100721359, 42.54567101597786, 44.61965672671795, 44.7850276529789, 47.43654057383537, 47.228209152817726, 50.20618535578251, 51.59944899380207, 50.14367111027241, 46.10598877072334, 42.38348051905632, 47.86287769675255, 53.37031736969948, 53.27287159860134, 48.4859074652195, 47.98054598271847, 46.7255075275898, 45.40519617497921, 44.91464629769325, 41.48176230490208, 43.92556697130203, 42.918301820755005, 41.73251464962959, 44.46799546480179, 46.46948866546154, 44.74110201001167, 42.266382202506065, 39.470021054148674, 40.147254914045334, 41.18641175329685, 41.8314765393734, 43.083425760269165, 42.49328702688217, 45.33525712788105, 44.51245307922363, 45.50389587879181, 52.02464997768402, 50.61915099620819, 48.53891842067242, 55.20113132894039, 56.72453038394451, 55.5148158967495, 48.73022295534611, 52.843798622488976, 53.76993052661419, 59.83484208583832, 60.226338878273964, 59.593517035245895, 59.45196323096752, 62.704584896564484, 61.85406893491745, 59.351337030529976, 53.65096651017666, 49.260723888874054, 47.4173554033041, 49.61323097348213, 47.38626167178154, 51.417187973856926, 51.97495624423027, 52.58500970900059, 51.39514535665512, 56.00708328187466, 58.77148054540157, 63.49645860493183, 63.7741819024086, 68.36607590317726, 65.39184629917145, 65.28040587902069, 64.94874447584152, 62.248350977897644, 68.13754856586456, 73.35583135485649, 71.02770388126373, 73.77451568841934, 69.5436555147171, 72.81257450580597, 66.84176489710808, 58.97476203739643, 6.757923122495413, 0.1307306342641823, 0.06663569583906792, 46.84183828532696, 80.65081670880318, 61.65812484920025, 40.45818082988262, 91.76186129450798, 63.84298861026764, 44.37561862170696, 74.12192344665527, 27.109890393912792, 0.1343081274535507, 0.023242766474140808, 0.03646226825367194, 0.05693564016837627, 0.06366607354721054, 0.05852507929375861, 0.07574986302643083, 0.07872650603530928, 0.1893627646495588, 0.15284572960808873, 0.15098252333700657, 0.16637459193589166, 0.17454740416724235, 0.2603191329399124, 0.33542058896273375, 0.6984122609719634, 20.344919599592686, 88.5615362226963, 57.2620153427124, 45.088912546634674, 36.41579434275627, 56.033142283558846, 57.25397877395153, 71.92057237029076, 78.12986478209496, 7.571931118145585, 0.6561895203776658, 0.49459487898275256, 2.1615895349532366, 26.160439141094685, 77.0420591533184, 67.33867183327675, 71.46720349788666, 67.60495394468307, 65.01366019248962, 65.95135867595673, 64.34390813112259, 64.26613390445709, 53.32575336098671, 56.8310234695673, 53.034947365522385, 54.21442307531834, 56.93731136620045, 56.12412840127945, 61.06280319392681, 60.48243373632431, 60.92412583529949, 62.910571843385696, 58.61273646354675, 58.38466890156269, 52.5270514190197, 50.62835030257702, 49.131196439266205, 52.05701284110546, 53.86119782924652, 64.21721532940865, 61.79559767246246, 60.48672370612621, 52.40942873060703, 62.52416677772999, 62.14782737195492, 63.46013255417347, 62.153663858771324, 58.06536443531513, 56.41409084200859, 59.41204257309437, 61.19255103170872, 57.79644526541233, 52.703498750925064, 54.25818532705307, 58.71683567762375, 51.15200400352478, 47.68377810716629, 45.5896382778883, 45.4448888450861, 45.92045992612839, 43.3624941855669, 43.14872905611992, 42.618737295269966, 45.96346601843834, 43.96758511662483, 45.21941654384136, 49.534624591469765, 48.89330640435219, 47.9446417093277, 46.66776202619076, 47.027496322989464, 44.1671010106802, 47.98835836350918, 47.766951844096184, 51.30695968866348, 50.32225392758846, 54.772134348750114, 55.608138889074326, 50.36717891693115, 46.355073004961014, 40.9795356541872, 47.74028867483139, 54.64618630707264, 57.650704085826874, 52.50362187623978, 49.85051304101944, 48.91358971595764, 47.51677706837654, 48.35404314100742, 45.09843483567238, 46.07266075909138, 45.69941058754921, 42.63464704155922, 48.77287566661835, 48.72962258756161, 47.028047293424606, 45.95198303461075, 41.005906239151955, 44.00210626423359, 43.1090933829546, 45.014843121171, 46.072033792734146, 44.153634533286095, 46.92035347223282, 47.47979365289211, 47.406100407242775, 53.99343453347683, 54.281402081251144, 49.846804440021515, 58.06407630443573, 59.859004989266396, 57.403816133737564, 51.87839202582836, 55.8422177284956, 55.876936465501785, 62.38462306559086, 61.267152428627014, 61.72560542821884, 61.407083719968796, 64.44232285022736, 61.950082182884216, 61.714734211564064, 56.70518182218075, 51.86155132949352, 49.457431733608246, 52.24298246204853, 50.288067162036896, 55.05195893347263, 53.50445777177811, 56.148496493697166, 55.96981108188629, 58.496930077672005, 60.37995703518391, 67.10363924503326, 66.06492698192596, 69.56120297312737, 67.73699685931206, 69.74138170480728, 67.2041742503643, 63.192942291498184, 72.76094287633896, 76.57598376274109, 72.27522253990173, 77.85950168967247, 73.22270929813385, 77.46770471334457, 72.83349618315697, 68.61918032169342, 11.281120609492064, 0.5558687879238278, 0.1484043468371965, 50.12138530611992, 89.53997611999512, 67.32586652040482, 52.15851679444313, 100.67623615264893, 65.05645349621773, 51.441001296043396, 89.47364687919617, 33.64536300301552, 0.27947883296292275, 0.0996719098475296, 0.14499971468467265, 0.18891679326770827, 0.1799831460812129, 0.1733990790671669, 0.22334774024784565], [0.013726252273045247, 0.039415689461748116, 0.024461415632686112, 0.11290771290077828, 0.1931348638026975, 0.13223689718870446, 0.14057574269827455, 0.15174702450167388, 0.24383149109780788, 9.7872250713408, 61.17050841450691, 48.03833708167076, 47.61545777320862, 56.135375797748566, 59.96289901435375, 40.40767773985863, 56.802551597356796, 61.639737635850906, 22.52083294093609, 0.3134865628089756, 0.6097037647850811, 0.136403952492401, 2.3441676003858447, 32.21271447837353, 69.7399377822876, 61.34511284530163, 76.15759581327438, 64.45021882653236, 66.32363229990005, 58.715125769376755, 58.33598591387272, 53.58675755560398, 55.78909657895565, 53.49608302116394, 55.68790040910244, 58.672096878290176, 59.997287169098854, 60.46678237617016, 59.773330986499786, 57.91586525738239, 58.579328656196594, 51.201367154717445, 45.8174816519022, 44.79917049407959, 42.66945697367191, 46.316288486123085, 46.25618331134319, 54.152569994330406, 56.68619804084301, 58.654534220695496, 58.84537898004055, 55.80734319984913, 58.63638639450073, 57.961546406149864, 55.81618532538414, 51.153242737054825, 48.36969070136547, 48.78474622964859, 57.578690350055695, 49.55946385860443, 50.10294869542122, 48.27089600265026, 45.3808356821537, 45.021306574344635, 46.67664594948292, 40.922409519553185, 41.42357222735882, 40.08262798190117, 42.94803522527218, 41.71343207359314, 40.47683782875538, 37.76150353252888, 41.33607432246208, 40.68158224225044, 40.22056818008423, 39.5702862739563, 41.88899785280228, 42.64561705291271, 42.786167711019516, 41.708393543958664, 43.15952807664871, 44.73355561494827, 43.63946512341499, 45.8735666424036, 47.469667196273804, 48.7085223197937, 49.9655594676733, 47.54716023802757, 40.90933822095394, 40.80101363360882, 46.32494442164898, 52.39001177251339, 51.79415054619312, 47.02508345246315, 46.44896596670151, 44.94382493197918, 44.32628966867924, 39.94662947952747, 39.62401919066906, 43.77390570938587, 41.36972911655903, 41.30744285881519, 43.164726197719574, 42.717873975634575, 42.52338521182537, 38.67743298411369, 36.96719415485859, 38.265576884150505, 40.92164196074009, 40.342298448085785, 40.5606347322464, 39.62801657617092, 41.62213057279587, 43.45705971121788, 47.82886192202568, 49.89508464932442, 49.04179863631725, 49.93368677794933, 51.814475655555725, 55.47989957034588, 53.50761920213699, 48.690663278102875, 47.54001282155514, 53.8107555359602, 58.37287053465843, 59.715866670012474, 55.711975917220116, 57.23489239811897, 53.77214580774307, 74.27819386124611, 81.57281443476677, 55.60126505792141, 49.71921108663082, 44.893622025847435, 44.71331030130386, 45.1577078551054, 46.51252135634422, 46.79518438875675, 48.51079612970352, 46.15421198308468, 49.470704421401024, 53.66610109806061, 57.884250953793526, 61.09402231872082, 62.66385868191719, 63.51782105863094, 62.60131783783436, 63.87069672346115, 60.94184808433056, 65.59268072247505, 66.65529370307922, 68.3069434762001, 64.75771352648735, 67.60484755039215, 64.93385687470436, 63.27371835708618, 39.350285679101944, 1.7815221729688346, 0.20634203479858115, 1.065764317754656, 55.41053429245949, 66.09486177563667, 47.55015827715397, 40.15485070645809, 48.344748839735985, 25.418760739266872, 44.12406072020531, 57.09450513124466, 28.140809275209904, 0.27490806416608393, 0.13550020958064124, 0.034635980118764564, 0.08967299130745232, 0.11352900182828307, 0.050676730315899476, 0.0909714306180831, 0.03427470634051133, 0.05630716354062315, 0.023467652063118294, 0.04235439388139639, 0.1011932383698877, 0.056935981556307524, 0.15053016948513687, 0.14224174548871815, 0.38694558665156364, 14.607442170381546, 69.30833414196968, 52.394218146800995, 42.48449809849262, 49.794059470295906, 68.73100832104683, 48.24804022908211, 64.34637039899826, 64.72658559679985, 26.7365338280797, 0.32342015008907765, 1.0810090997256339, 0.16257243580184877, 2.485858672298491, 41.16993583738804, 72.08080977201462, 63.80716413259506, 79.27617967128754, 67.98180252313614, 67.62755513191223, 61.80062860250473, 61.85512527823448, 57.156825587153435, 58.924445137381554, 56.553227975964546, 59.53726105391979, 58.242985904216766, 62.679365649819374, 63.45912180840969, 62.336855828762054, 60.80429166555405, 59.59664806723595, 53.625230491161346, 50.17060026526451, 46.769642159342766, 46.041608825325966, 50.36400988698006, 49.32154342532158, 57.04250492155552, 58.59303832054138, 58.546392023563385, 59.67972680926323, 59.08311702311039, 61.66538245975971, 60.52267737686634, 59.96252663433552, 53.3746225386858, 53.740976080298424, 51.24176278710365, 60.04478842020035, 55.4841173440218, 54.077562019228935, 50.31913809478283, 49.15943652391434, 47.64608033001423, 48.65465261042118, 43.109648153185844, 43.965761214494705, 41.46204136312008, 44.85167607665062, 41.836978644132614, 43.19882556796074, 39.77151207625866, 43.10681350529194, 42.7337571233511, 42.926680371165276, 42.23830170929432, 43.91366980969906, 44.441590681672096, 44.29723262786865, 44.31297518312931, 44.54912111163139, 44.59347613155842, 45.613105818629265, 48.13614763319492, 49.408741146326065, 51.28412291407585, 52.936426252126694, 48.35008755326271, 40.62054231762886, 40.51879517734051, 46.323002725839615, 53.13482880592346, 52.82115563750267, 48.6233688890934, 50.465160459280014, 46.140669509768486, 45.749339908361435, 42.224432453513145, 42.33369179069996, 44.234558790922165, 44.291479736566544, 46.03682868182659, 44.956675842404366, 45.19980199635029, 44.546172469854355, 41.39281287789345, 39.119125083088875, 38.954491317272186, 42.95290656387806, 41.87714248895645, 41.53634637594223, 40.648843199014664, 44.74728047847748, 46.58081129193306, 50.83201177418232, 50.83519600331783, 52.17531569302082, 50.822250097990036, 55.58964528143406, 58.5386860370636, 57.552141174674034, 49.70818027853966, 50.87440609931946, 54.42193754017353, 60.94502851366997, 60.65122827887535, 58.8854706287384, 58.719826117157936, 55.52277646958828, 76.04025050997734, 76.26277416944504, 59.2861021310091, 52.874565571546555, 48.62510919570923, 48.220829889178276, 48.73832032084465, 48.50481525063515, 49.76128242909908, 51.98853671550751, 47.0361864566803, 50.23314870893955, 55.756935104727745, 60.774816647171974, 63.903002589941025, 66.17604061961174, 67.31553867459297, 67.31211885809898, 67.4633963406086, 66.14065691828728, 68.48548829555511, 70.80030888319016, 71.6448287665844, 69.26831468939781, 70.89129880070686, 70.66201150417328, 70.40026634931564, 44.43296514451504, 1.4602388441562653, 0.13028951652813703, 1.6124719753861427, 63.5572325438261, 71.5288133919239, 55.665462613105774, 49.04052950441837, 62.99105152487755, 42.390327751636505, 55.077873542904854, 70.592832416296, 34.40058007836342, 0.08001883747056127, 0.19876718579325825, 0.014618560544477077, 0.04540845031442586, 0.09645001671742648, 0.017467466022935696, 0.07127827484509908, 0.10101169420522638, 0.25457508803810924, 0.1489525119541213, 0.18905272503616288, 0.3189479385036975, 0.16811963345389813, 0.33912850718479604, 0.26800243940670043, 0.507954724598676, 21.320414654910564, 80.530446767807, 65.4012393951416, 65.28001829981804, 67.95106217265129, 80.97753077745438, 53.9242098480463, 69.07712414860725, 76.18006020784378, 29.45746712386608, 0.5191979056689888, 0.7058299973141402, 0.2447992516681552, 4.88890316337347, 51.16217605769634, 81.27371728420258, 72.88035526871681, 80.02556785941124, 70.19501656293869, 72.46621549129486, 65.9963558614254, 63.08397553861141, 60.86853101849556, 62.50218875706196, 59.50416103005409, 61.1793315410614, 62.101458460092545, 63.851971328258514, 65.5726557970047, 66.1810639500618, 63.39925602078438, 63.14395911991596, 55.87756723165512, 51.608652099967, 50.340614542365074, 48.05119939148426, 51.7797227203846, 51.34262457489967, 60.88278405368328, 60.04133440554142, 62.33753599226475, 59.25897918641567, 57.03460514545441, 64.88580465316772, 60.92096820473671, 63.32944996654987, 55.900476202368736, 55.66430747509003, 55.15273332595825, 63.93568843603134, 59.413805678486824, 60.05146846175194, 54.21958699822426, 52.042284831404686, 50.78803673386574, 53.898546025156975, 45.44803507626057, 46.72397620975971, 44.0629979968071, 48.6749929189682, 45.18750585615635, 46.27499230206013, 42.146947011351585, 47.219530418515205, 46.15761660039425, 45.80086134374142, 45.59439942240715, 47.971643060445786, 47.35792279243469, 49.28114779293537, 45.863269194960594, 47.4367343634367, 48.65833841264248, 48.580841571092606, 49.92166042327881, 52.860209941864014, 55.24949513375759, 53.59115771949291, 49.95164841413498, 41.01582370698452, 40.85201449692249, 48.993127048015594, 55.023722648620605, 55.888392850756645, 52.674232721328735, 52.95189902186394, 49.70397390425205, 49.56730663776398, 44.641022980213165, 44.26850996911526, 47.663680985569954, 47.58008927106857, 48.68355765938759, 48.588585555553436, 47.670923396945, 47.53367476165295, 44.18744131922722, 41.88099928200245, 41.37981377542019, 47.09468051791191, 44.11043465137482, 43.42514142394066, 44.45056959986687, 47.18414291739464, 49.19931538403034, 54.933177307248116, 55.26046134531498, 54.79622885584831, 56.76457263529301, 60.47863394021988, 63.26059766113758, 61.97479225695133, 53.229903504252434, 53.651916459202766, 57.045947536826134, 63.328644409775734, 62.44808726012707, 61.86146333813667, 59.486343786120415, 56.57980374991894, 77.24702015519142, 73.27988862991333, 62.35762171447277, 57.33408987522125, 49.945694133639336, 51.21815085411072, 50.95720365643501, 52.7607236802578, 54.16939169168472, 55.6830670684576, 51.8350325524807, 53.560280576348305, 60.22030480206013, 64.1580905020237, 67.08248198032379, 70.21566465497017, 69.08725440502167, 67.25693821907043, 71.13774597644806, 69.87015679478645, 71.30257353186607, 74.60542470216751, 76.61530405282974, 75.41548043489456, 76.44964054226875, 75.78677371144295, 77.25655764341354, 52.789355143904686, 2.999674938619137, 0.32244283065665513, 1.7724971822462976, 68.59379768371582, 79.4473984837532, 62.4300192296505, 58.880679085850716, 68.50140944123268, 39.69439521431923, 59.45263959467411, 83.23830306529999, 39.62710842490196, 0.25289507349953055, 0.29930717835668474, 0.1592083100695163, 0.13243788562249392, 0.17484813724877313, 0.1298600059817545, 0.22514062060508877], [0.08366917245439254, 0.041645620585768484, 0.14417558937566355, 0.036448356695473194, 0.12597556051332504, 0.05334965680958703, 0.14400445012142882, 0.2216838748427108, 0.36002498120069504, 9.859041217714548, 62.27560691535473, 45.13620860874653, 33.1927464902401, 56.32820025086403, 52.43190832436085, 29.57785416394472, 62.874485179781914, 62.9580844938755, 43.24407733976841, 0.11912110683624633, 0.09824945023865439, 0.12429894501110539, 0.4380279377801344, 6.7256049066782, 60.66858194768429, 47.37802751362324, 77.579715102911, 61.11146338284016, 65.05418121814728, 62.045506462454796, 62.90307864546776, 60.42636014521122, 56.94775700569153, 59.41762447357178, 62.02529914677143, 60.15852391719818, 60.29140658676624, 57.270044311881065, 59.86025512218475, 57.62623719871044, 52.92602241039276, 48.8547270745039, 44.80249531567097, 44.23479437828064, 43.462679609656334, 45.527397617697716, 51.326882019639015, 60.13596452772617, 58.70661802589893, 60.12091353535652, 57.63962768018246, 53.64307053387165, 58.55350524187088, 53.86523701250553, 54.01386223733425, 52.92594261467457, 51.98995403945446, 48.16757574677467, 54.78757292032242, 46.890954449772835, 51.106140464544296, 48.177120834589005, 44.90583077073097, 46.116392612457275, 45.17603427171707, 44.30701330304146, 41.13794155418873, 40.58012768626213, 40.97731277346611, 39.78914313018322, 40.671337991952896, 37.537038177251816, 39.06192295253277, 38.947279304265976, 39.12246510386467, 39.08303081989288, 42.71522931754589, 42.07663178443909, 46.67990617454052, 42.261966839432716, 46.85231052339077, 42.90871113538742, 44.76821355521679, 45.572049021720886, 48.4354043751955, 52.348734587430954, 53.417966812849045, 46.629239693284035, 40.8725979924202, 39.19614315032959, 46.93623661994934, 51.42966270446777, 55.39397478103638, 47.34114669263363, 47.11511202156544, 47.345482259988785, 45.40778763592243, 44.23242710530758, 42.13141344487667, 42.455361261963844, 43.05842310190201, 39.40236568450928, 43.44886355102062, 37.80362047255039, 39.25226613879204, 38.18307191133499, 38.97749148309231, 38.64180989563465, 39.12449039518833, 39.08815674483776, 38.62280711531639, 40.59520147740841, 41.231777518987656, 45.08057199418545, 44.68647614121437, 43.25681045651436, 47.549424916505814, 49.23874966800213, 51.76835373044014, 52.50859200954437, 54.687805473804474, 46.63887217640877, 52.28074483573437, 51.825126484036446, 60.32948434352875, 57.928780764341354, 59.352982342243195, 58.11429060995579, 57.006646245718, 53.15433315932751, 74.03717279434204, 66.9623476266861, 51.572690829634666, 49.56439979374409, 43.69105875492096, 44.57166530191898, 43.344737738370895, 46.02423615753651, 43.913289830088615, 46.41600653529167, 46.46427534520626, 47.11060546338558, 50.808240249753, 64.15540024638176, 63.80242958664894, 63.91760900616646, 61.70088395476341, 64.55502480268478, 63.75988706946373, 63.856500685214996, 60.61571158468723, 63.37551489472389, 60.86235634982586, 66.53461217880249, 61.84650354087353, 68.28273877501488, 28.47382340580225, 0.8873849676456302, 0.13418975489912555, 3.2521464535966516, 69.66811403632164, 64.91206884384155, 58.685703948140144, 33.1002214550972, 34.423576444387436, 31.025025509297848, 41.699965596199036, 65.03838926553726, 34.4809153676033, 0.3011409065220505, 0.019473038482828997, 0.022596491289732512, 0.10074957506731153, 0.027842458621307742, 0.07145469819079153, 0.05219271537498571, 0.07995801846846007, 0.025492943386780098, 0.03704708804434631, 0.13893336988985538, 0.042161754608969204, 0.04829375720873941, 0.09852872783085331, 0.1719312445493415, 0.4732446855632588, 13.078825045377016, 70.8325919508934, 51.58029042184353, 39.40649226307869, 65.84943294525146, 63.02803494036198, 35.78002005815506, 69.54916521906853, 62.23472870886326, 47.33851343393326, 0.13070474815322086, 0.8377652708441019, 0.0559556749794865, 0.3455393569311127, 10.501919221132994, 70.40475010871887, 50.7242913544178, 84.6575117111206, 66.19279772043228, 68.40859562158585, 63.489960953593254, 66.42205461859703, 63.25346164405346, 60.35960912704468, 61.584211215376854, 65.0638934969902, 63.11118587851524, 64.23430681228638, 59.9804312735796, 63.92909958958626, 59.45165924727917, 55.3704996407032, 51.502432599663734, 47.557024508714676, 45.689546316862106, 46.224147230386734, 47.51293167471886, 54.69960764050484, 61.816059574484825, 61.72890365123749, 60.14852285385132, 60.859943479299545, 57.65924982726574, 61.59996896982193, 57.541516944766045, 56.56166732311249, 54.74613234400749, 56.40776418149471, 52.13165983557701, 58.0891739577055, 53.16597953438759, 56.21669143438339, 52.559881657361984, 48.2998276501894, 52.14024357497692, 46.961828246712685, 46.496752202510834, 43.369124829769135, 41.71557895839214, 43.47078837454319, 42.14375138282776, 43.89594376087189, 39.30704779922962, 41.01497255265713, 41.009637638926506, 43.82286228239536, 42.15868078172207, 45.0550601631403, 43.69665205478668, 46.57763846218586, 44.94741193950176, 48.86311322450638, 45.112425684928894, 45.23895889520645, 46.287831813097, 50.8972504734993, 53.729462698102, 55.69853983819485, 45.65444000065327, 39.02946509420872, 38.20296384394169, 44.66097950935364, 53.61049488186836, 59.31933514773846, 48.35765674710274, 48.25166903436184, 47.42889158427715, 47.510469406843185, 44.995262771844864, 44.55815702676773, 45.8654198795557, 44.02993217110634, 44.00463692843914, 43.7213659286499, 41.89328022301197, 41.86925791203976, 39.993442967534065, 40.776314958930016, 41.215020418167114, 43.120264783501625, 43.47170412540436, 41.014258190989494, 42.79454626142979, 43.059544041752815, 47.400020733475685, 48.52514795958996, 46.90255142748356, 49.59473356604576, 52.312127351760864, 55.02058781683445, 56.01560242474079, 57.24234759807587, 51.122278198599815, 54.954091385006905, 51.1219248175621, 60.57371623814106, 60.7270722091198, 60.95618091523647, 60.954964980483055, 55.6808327883482, 55.20567208528519, 74.63347479701042, 68.98376315832138, 56.96843929588795, 51.89679443836212, 46.044850051403046, 48.21023605763912, 48.42561990022659, 47.83724807202816, 47.39950016140938, 50.241914838552475, 49.679510816931725, 49.74514089524746, 55.02344146370888, 66.62949308753014, 66.36588603258133, 68.32506090402603, 65.41510865092278, 67.74335011839867, 66.22554436326027, 67.0902867615223, 62.40466319024563, 66.23836487531662, 63.2394327968359, 72.31591835618019, 65.01493692398071, 74.93242755532265, 29.468953907489777, 0.42130286805331707, 0.36087479966226965, 4.813784044235945, 74.23015683889389, 73.99310275912285, 61.83766521513462, 46.08928486704826, 42.447917461395264, 28.55143614113331, 47.7023933082819, 71.97588980197906, 45.401479974389076, 0.44639538566116244, 0.059960426297038794, 0.04176116555754561, 0.0389507896034047, 0.04820474030566402, 0.06747789986548014, 0.040014973710640334, 0.15165956981945783, 0.3120882378425449, 0.25334710080642253, 0.21736882044933736, 0.29826009704265743, 0.1909905023057945, 0.26716007210779935, 0.31315443688072264, 0.9387491864617914, 16.645383015275, 84.03309881687164, 61.40076465904713, 46.260739266872406, 61.628984212875366, 68.52727085351944, 40.951086580753326, 74.16218608617783, 71.89189150929451, 53.590766340494156, 0.2535276801791042, 1.6847651149146259, 0.140293370350264, 0.8459435601253062, 14.963091686367989, 79.45736154913902, 54.327520206570625, 69.05260026454926, 67.49346032738686, 72.74505972862244, 67.909135222435, 71.44945845007896, 66.845982670784, 63.733797669410706, 65.39192989468575, 68.3090029656887, 64.33893039822578, 66.06644690036774, 62.844842970371246, 65.46929374337196, 62.48085670173168, 59.83853168785572, 54.37186762690544, 49.020242393016815, 48.780000284314156, 49.093122482299805, 50.5563897639513, 57.398173436522484, 65.33244788646698, 65.60968860983849, 59.97600071132183, 59.134110286831856, 61.69045351445675, 63.26454184949398, 57.67702527344227, 58.83724741637707, 57.41879113018513, 58.69016870856285, 55.00158503651619, 64.50553625822067, 57.53392495214939, 59.54160042107105, 56.438979506492615, 52.15784803032875, 56.27680420875549, 52.472664937376976, 50.793892219662666, 46.590770557522774, 43.934040516614914, 46.452495977282524, 44.96997892856598, 45.430487617850304, 41.328881308436394, 43.61656375229359, 42.70281158387661, 44.418461322784424, 45.262639224529266, 50.65185584127903, 48.788618221879005, 51.61674566566944, 47.82677583396435, 52.4303238093853, 49.23155665397644, 49.93663161993027, 49.2386394739151, 55.18706448376179, 56.41383245587349, 57.91119910776615, 46.34154953062534, 39.632333144545555, 37.69519329071045, 46.33314438164234, 56.483767703175545, 61.07686243951321, 51.89990647137165, 51.512380465865135, 52.760343700647354, 50.86239494383335, 49.26480486989021, 47.99818083643913, 48.31781968474388, 48.25895704329014, 47.11380109190941, 48.16156066954136, 43.52371193468571, 43.649181202054024, 44.166128262877464, 43.70150439441204, 43.70819203555584, 44.802244529128075, 45.62545895576477, 42.21977010369301, 45.5185516923666, 44.91006754338741, 49.56527754664421, 52.91972614824772, 50.6010639667511, 53.393013551831245, 56.703867092728615, 58.695378229022026, 61.67284905910492, 60.11658936738968, 53.27865868806839, 57.113032937049866, 56.03479899466038, 63.89067605137825, 65.40305569767952, 64.18037250638008, 65.18862560391426, 58.745626732707024, 59.32130344212055, 76.31137356162071, 62.5041950494051, 63.0246227234602, 54.627970084548, 50.52785709500313, 49.74062293767929, 51.7042625695467, 50.41641287505627, 51.43833763897419, 52.43317745625973, 51.82321898639202, 51.021382212638855, 58.633129969239235, 71.34327694773674, 71.11961334943771, 69.1070893406868, 72.30157032608986, 70.11400490999222, 72.2491255402565, 69.2990094423294, 67.5193901360035, 70.51493659615517, 66.39070630073547, 74.06533688306808, 71.25626921653748, 82.53910258412361, 38.30915294587612, 1.5157938818447292, 0.3393549512838945, 4.891327433288097, 82.21123337745667, 78.74197393655777, 73.2790070772171, 51.36085219681263, 50.206344947218895, 42.40765482187271, 58.797079771757126, 83.8279478251934, 50.65006233751774, 0.777983731823042, 0.1006796202273108, 0.2070805459516123, 0.1561722284532152, 0.17421772732632235, 0.12516688671894372, 0.14137445687083527], [0.0568190413468983, 0.03624027332989499, 0.053577362559735775, 0.021133367554284632, 0.025400304803042673, 0.11200525390449911, 0.07709283861913718, 0.1561784476507455, 0.15367999265436083, 13.538074102252722, 65.78135579824448, 48.6167648434639, 33.72498773038387, 29.655884876847267, 43.6471863090992, 32.31285810470581, 64.67224851250648, 63.7710964679718, 68.54055494070053, 1.8069818755611777, 0.9391013206914067, 2.852077796123922, 0.7231161603704095, 1.6888931184075773, 20.900104008615017, 40.28887711465359, 27.23534446209669, 56.249073296785355, 66.35039806365967, 65.25981858372688, 61.47226922214031, 63.67600657045841, 62.86733016371727, 60.05842208862305, 63.297816663980484, 62.814957574009895, 56.38406105339527, 58.201172947883606, 60.97130410373211, 60.20520821213722, 52.655693516135216, 43.42348471283913, 43.13409984111786, 42.59982571005821, 42.558084949851036, 48.620648235082626, 54.91587683558464, 55.16661398112774, 61.36027783155441, 65.79282358288765, 50.887857377529144, 54.986378252506256, 57.09678500890732, 56.41003265976906, 52.12106600403786, 54.401430040597916, 50.95136716961861, 49.6264960616827, 51.20900094509125, 46.84857912361622, 49.92035709321499, 48.499522134661674, 43.58509384095669, 44.215077236294746, 42.64089770615101, 41.90738886594772, 41.811922788619995, 37.82855473458767, 40.448666140437126, 37.277192920446396, 36.734855622053146, 39.209928810596466, 39.198377430438995, 39.22765865921974, 39.267484322190285, 40.39206437766552, 40.04084922373295, 39.21972468495369, 41.013916209340096, 43.93214821815491, 43.326411321759224, 45.13434290885925, 43.455330803990364, 40.82359202206135, 47.156947776675224, 52.93860353529453, 53.64968977868557, 49.04370233416557, 38.46367545425892, 39.73811946809292, 44.98393937945366, 52.765876203775406, 55.85440367460251, 52.90352761745453, 48.06468106806278, 46.410067453980446, 42.993173003196716, 44.255826249718666, 45.742789059877396, 43.20216178894043, 40.819070264697075, 39.42954562604427, 40.240555107593536, 39.31834079325199, 39.12631809711456, 37.85195767879486, 38.008045703172684, 39.691013395786285, 38.83540950715542, 40.26977553963661, 39.64829608798027, 38.8587212562561, 43.37868131697178, 48.14714804291725, 40.690811946988106, 42.69256733357906, 46.02081634104252, 48.99531953036785, 49.959198608994484, 49.58794713020325, 54.65168461203575, 49.124087020754814, 50.10899417102337, 53.47894214093685, 53.92627313733101, 56.418475806713104, 59.026363268494606, 61.42069838941097, 57.24854126572609, 44.51640106737614, 38.278663381934166, 70.65306678414345, 56.660211235284805, 53.606630489230156, 44.71945837140083, 44.53545704483986, 41.07276365160942, 46.095752120018005, 45.31467363238335, 45.80438755452633, 46.801438853144646, 50.72893090546131, 49.69808802008629, 58.011813908815384, 59.64750073850155, 67.22785457968712, 61.46602235734463, 64.39100280404091, 60.32280050218105, 66.47654369473457, 57.82612927258015, 64.52255174517632, 59.825251400470734, 70.29399365186691, 62.11763799190521, 66.28165975213051, 13.07737447321415, 0.48474527313373983, 0.45855678152292967, 10.704175718128681, 76.12255409359932, 61.52742326259613, 53.30118387937546, 38.362494483590126, 49.52392056584358, 48.39850835502148, 53.80848325788975, 53.67026947438717, 51.352599039673805, 0.8922362979501486, 0.04963489969668444, 0.008811530497041531, 0.059543617608142085, 0.06123125029262155, 0.04475075904338155, 0.14467331813648343, 0.03935359767638147, 0.0754834913823288, 0.023927726106194314, 0.12630105164134875, 0.02462618169374764, 0.1056197336583864, 0.06731758112437092, 0.33825318852905184, 0.24216483521740884, 15.95201712101698, 76.31597891449928, 51.678233966231346, 33.92468221485615, 40.27794510126114, 48.58396880328655, 35.74660085141659, 68.41168865561485, 68.65495160222054, 74.18641358613968, 2.3502622358500957, 1.110943655949086, 2.1962728863582015, 0.46273115440271795, 1.3726059277541935, 27.925982102751732, 44.81551721692085, 33.819085881114006, 61.98012717068195, 66.41134679317474, 68.21232855319977, 65.07525488734245, 67.72636502981186, 64.3652705848217, 64.01413142681122, 65.35037532448769, 67.37879768013954, 57.81248800456524, 60.76708406209946, 61.842452958226204, 61.53559662401676, 54.16632145643234, 47.13020481169224, 45.79971380531788, 43.96885044872761, 45.7605417072773, 53.00449579954147, 56.5129729360342, 58.52483578026295, 60.61853863298893, 68.41852828860283, 55.14290325343609, 58.639870807528496, 59.28942695260048, 59.14903588593006, 56.377297416329384, 59.28389064967632, 52.018334716558456, 52.01379016041756, 54.9605168402195, 52.7376589179039, 53.12030978500843, 50.1670778542757, 46.194315031170845, 49.0706542879343, 46.390859484672546, 44.8887050896883, 44.5776803791523, 38.32877889275551, 42.89424531161785, 41.80582031607628, 39.30678181350231, 40.92486038804054, 40.70166036486626, 41.20745502412319, 40.75489550828934, 41.827691942453384, 42.148413732647896, 41.396935656666756, 45.3463601320982, 45.97876399755478, 45.99497012794018, 44.92340862751007, 44.13898631930351, 43.20183880627155, 49.041293263435364, 57.01703488826752, 55.714487582445145, 49.668852388858795, 38.02477240562439, 39.715932458639145, 43.2769113779068, 54.574271366000175, 56.46327540278435, 54.33360368013382, 49.34392422437668, 47.83241093158722, 44.63970825076103, 44.880603924393654, 45.61653323471546, 44.88912686705589, 44.801799952983856, 40.92003084719181, 44.43015709519386, 41.7539568990469, 40.686077401041985, 40.61562538146973, 40.130543410778046, 43.225412741303444, 40.091344714164734, 40.72328120470047, 43.342644050717354, 40.22250607609749, 45.69235056638718, 51.12080007791519, 44.355263113975525, 47.468314468860626, 48.34002949297428, 52.790639474987984, 54.367292672395706, 53.33803050220013, 56.54667712748051, 52.389039024710655, 53.137317672371864, 54.5503706485033, 54.741238206624985, 61.7835409194231, 59.47391465306282, 63.50109055638313, 58.23660984635353, 48.91859404742718, 45.09438805282116, 70.358726978302, 60.99199399352074, 57.56905406713486, 47.492469772696495, 47.34736315906048, 44.938752204179764, 50.12388177216053, 47.45162196457386, 49.80107009410858, 48.233623802661896, 52.12319768965244, 51.206778064370155, 59.467530995607376, 64.10462737083435, 69.85839262604713, 65.35851448774338, 68.86186569929123, 63.40818174183369, 68.5686506330967, 61.135113313794136, 67.10403442382812, 64.0711359679699, 74.01112139225006, 65.90601190924644, 73.24053794145584, 12.624719962477684, 0.19217100692912936, 0.5257074313703924, 12.930073477327824, 82.30192691087723, 69.26251620054245, 57.66137771308422, 48.296958804130554, 50.12850612401962, 46.2676814943552, 67.51514956355095, 61.307954639196396, 58.87356586754322, 1.5583882899954915, 0.03171722091792617, 0.07352544605964795, 0.023391646864183713, 0.04962929277098738, 0.06521942574181594, 0.0762717635370791, 0.1747686680755578, 0.13476889726007357, 0.3117650473723188, 0.15737918321974576, 0.1759028181550093, 0.271320195752196, 0.2066314872354269, 0.3931568283587694, 0.5287073703948408, 18.842727206647396, 86.08856052160263, 62.464437782764435, 44.74320329725742, 41.17381922900677, 62.08978168666363, 42.60405108332634, 81.0074807703495, 71.83525174856186, 84.45163875818253, 2.2145092952996492, 5.268774479627609, 5.2085914090275764, 0.5243458575569093, 2.464981167577207, 36.44417122006416, 48.64972807466984, 38.073056414723396, 65.24777323007584, 70.867580473423, 74.01695787906647, 66.34842216968536, 72.3927654325962, 66.4315465092659, 68.09648796916008, 70.41946291923523, 69.49102833867073, 60.81582024693489, 61.88792511820793, 64.53593462705612, 67.56897747516632, 56.11940525472164, 48.52074019610882, 47.49331712722778, 46.492576226592064, 49.41059544682503, 56.849448680877686, 58.4979560226202, 60.44858135282993, 60.92779643833637, 64.42008644342422, 58.4688875824213, 59.36479590833187, 60.31054615974426, 61.597898080945015, 57.95764021575451, 60.56000657379627, 55.256957933306694, 54.37787130475044, 60.46305097639561, 58.8194377720356, 59.49658043682575, 56.07274375855923, 49.11187447607517, 52.92565383017063, 50.41354022920132, 48.75169940292835, 46.63971573114395, 43.03328365087509, 44.94254820048809, 44.75308656692505, 40.22710382938385, 43.89248214662075, 44.02443766593933, 43.680525720119476, 44.595934599637985, 46.109951958060265, 47.198555544018745, 47.50331059098244, 47.35584430396557, 49.15669307112694, 48.654622212052345, 48.89303661882877, 45.908425971865654, 46.06961712241173, 51.919281631708145, 59.43758100271225, 57.46980719268322, 48.61529432237148, 37.92995609343052, 38.95702198147774, 44.781106263399124, 55.25132283568382, 60.088888853788376, 56.14777833223343, 53.24987143278122, 51.8990895152092, 50.06281524896622, 47.2888159006834, 50.14179401099682, 48.16458910703659, 48.15824344754219, 44.16764058172703, 47.724584117531776, 43.81317660212517, 42.48753413558006, 42.707774117589, 42.75168836116791, 47.48597212135792, 42.20041774213314, 43.537345603108406, 45.46310506761074, 41.56538061797619, 49.728311598300934, 55.12800805270672, 48.1025118380785, 50.7976920157671, 54.03770975768566, 57.803060710430145, 59.143404588103294, 58.158501237630844, 59.6839901804924, 54.868124797940254, 54.70237389206886, 58.343965485692024, 58.61767239868641, 63.26188579201698, 64.45591852068901, 64.51945871114731, 60.999692380428314, 48.2006149739027, 50.01013107597828, 66.20114207267761, 60.27067109942436, 61.18084765970707, 51.46829143166542, 50.03680944442749, 45.88365130126476, 51.41458511352539, 50.655051469802856, 51.409417390823364, 51.02833203971386, 54.898686558008194, 53.311557322740555, 63.05638521909714, 68.06326255202293, 74.63742658495903, 68.31575900316238, 71.62817806005478, 68.11822280287743, 75.26003837585449, 64.35099095106125, 72.55129292607307, 67.32599571347237, 77.65583261847496, 73.29072564840317, 81.25258281826973, 17.219074331223965, 0.9910837188363075, 0.5924598150886595, 13.099693525582552, 91.98600366711617, 74.92922812700272, 72.97360986471176, 52.72495999932289, 68.82869347929955, 63.711097687482834, 72.08330243825912, 73.90277400612831, 67.24477887153625, 2.1423742035403848, 0.13146861107088625, 0.2113368667778559, 0.11358279269188643, 0.14005500735947862, 0.12847539590438828, 0.18933361308882013], [0.07149475932237692, 0.027244931407039985, 0.042313776139053516, 0.0208949693114846, 0.07609797481563874, 0.030211575831344817, 0.08069017683737911, 0.16607725789071992, 0.049260378582403064, 14.433968178927898, 64.4052292406559, 46.32459104061127, 51.5955314040184, 15.442890990525484, 39.64340195059776, 28.507242612540722, 66.10154181718826, 61.2921778857708, 73.74073550105095, 9.685134049504995, 0.48251790984068066, 0.4272097995271906, 0.12515217735199258, 0.12349116921541281, 0.6509849871508777, 25.526825040578842, 36.1601934581995, 55.26060953736305, 55.96762239933014, 65.93149334192276, 60.18611043691635, 62.41607777774334, 60.28498113155365, 59.63361628353596, 55.76168105006218, 57.23850980401039, 59.74878050386906, 63.04198779165745, 56.59667484462261, 54.94262360036373, 43.60354945063591, 44.538318291306496, 43.15936088562012, 45.21126218140125, 52.28543758392334, 55.55945210158825, 54.448197931051254, 60.65143346786499, 73.7586173415184, 48.099696189165115, 49.21147093176842, 59.81540992856026, 58.788933008909225, 56.192855313420296, 49.31250371038914, 53.52718435227871, 53.42413768172264, 53.18351939320564, 49.22806464135647, 44.11939837038517, 47.83103160560131, 48.63586261868477, 43.099092319607735, 43.46233382821083, 40.26266232132912, 42.83088371157646, 43.51789064705372, 46.35718189179897, 40.72089493274689, 40.507327392697334, 41.101452112197876, 40.134187415242195, 37.61414363980293, 40.017229691147804, 38.20557050406933, 39.8053340613842, 38.67141030728817, 38.32527928054333, 40.42113281786442, 45.62984772026539, 43.1978490203619, 43.168430998921394, 43.45869742333889, 42.372920885682106, 43.587476313114166, 45.94804264605045, 51.945169642567635, 50.26265412569046, 38.36961530148983, 41.42387621104717, 41.52465060353279, 56.514200270175934, 54.449132680892944, 53.91848735511303, 46.60276271402836, 42.1907814592123, 40.193775817751884, 44.355160519480705, 43.60753923654556, 42.09498479962349, 38.78604635596275, 37.800937816500664, 35.53812503814697, 38.432338535785675, 38.237492591142654, 37.61382445693016, 37.841971814632416, 39.79904539883137, 39.89246718585491, 39.063522666692734, 38.52778181433678, 40.993488505482674, 46.410401836037636, 43.40200826525688, 38.88478025794029, 43.63843157887459, 43.2953479886055, 52.389468401670456, 48.025185987353325, 50.07535457611084, 52.33638904988766, 51.51953548192978, 50.94821333885193, 53.908262103796005, 49.73255977034569, 59.08138811588287, 53.450097888708115, 62.11759999394417, 54.94081489741802, 56.72165393829346, 34.12857547402382, 54.250323548913, 66.15746721625328, 54.46617476642132, 53.06290626525879, 45.528754144907, 44.714195653796196, 46.736112758517265, 44.17676769196987, 45.59597633779049, 45.28185859322548, 46.60520978271961, 46.04514643549919, 51.319833397865295, 55.68852737545967, 61.787143126130104, 58.62817503511906, 66.01612240076065, 62.09865801036358, 63.24126049876213, 57.33613796532154, 62.492316886782646, 61.234310790896416, 71.6353976726532, 61.572222858667374, 51.7158367484808, 3.845667955465615, 0.2756933751516044, 0.36608467635232955, 26.83260977268219, 74.16410118341446, 61.19866490364075, 47.59089209139347, 40.12646622955799, 66.06738165020943, 21.03435080498457, 35.12402705848217, 57.5173844397068, 47.93352350592613, 3.4678974514827132, 0.1201879812288098, 0.16674694226821885, 0.005449940126709407, 0.08249704667832702, 0.04124693885387387, 0.031906772856018506, 0.04254433915775735, 0.06703328661387786, 0.03454911173321307, 0.05049221756053157, 0.052195936295902357, 0.04008399715530686, 0.03045782599656377, 0.09330472807050683, 0.08844709693221375, 19.775166772305965, 76.42349794507027, 50.3072789311409, 48.652813509106636, 25.154270231723785, 46.95302031934261, 34.052260369062424, 72.90491715073586, 65.27866557240486, 80.97008317708969, 11.221748795360327, 0.45602460333611816, 2.021851558238268, 0.08357808124856092, 0.11202751833479851, 0.9929193172138184, 33.98184634745121, 39.44055363535881, 53.754852935671806, 58.303946033120155, 68.24921697378159, 62.3372358083725, 65.04355698823929, 62.672241032123566, 60.52146524190903, 59.288678392767906, 58.31862084567547, 62.08834156394005, 64.7840005159378, 60.57072579860687, 57.64157697558403, 47.1102786809206, 46.159337908029556, 45.38644038140774, 49.37852896749973, 53.78071054816246, 59.12277549505234, 57.665994465351105, 60.9309084713459, 71.2253388762474, 53.504936546087265, 52.23636321723461, 61.12195461988449, 59.038351625204086, 59.7936636954546, 52.95030690729618, 56.75836756825447, 55.55146113038063, 55.3963116556406, 52.613519579172134, 50.28058536350727, 52.00046047568321, 52.81072899699211, 43.92680950462818, 46.59753039479256, 44.87390108406544, 45.755214393138885, 48.014440163969994, 49.81589689850807, 41.61580391228199, 42.49777838587761, 42.37949073314667, 41.20373122394085, 40.16596131026745, 40.255499705672264, 40.24796091020107, 43.38424041867256, 42.89881266653538, 42.39391855895519, 43.76347906887531, 46.88128396868706, 43.99837106466293, 45.54125167429447, 45.70471130311489, 43.9449193328619, 44.64992970228195, 47.829534485936165, 53.43611843883991, 49.159759506583214, 39.39888507127762, 40.04643492400646, 40.146004781126976, 57.38646246492863, 55.407505854964256, 55.636428371071815, 47.335800379514694, 44.059289395809174, 42.81211271882057, 45.50443924963474, 45.485858246684074, 44.60987985134125, 41.351110115647316, 40.88947668671608, 40.258501544594765, 40.658251494169235, 40.60449577867985, 39.13006089627743, 39.96250502765179, 42.79781028628349, 41.73753038048744, 41.365336552262306, 39.6638410538435, 42.621378153562546, 49.27836634218693, 46.33032113313675, 43.959708139300346, 45.46376243233681, 46.52183085680008, 53.946309462189674, 52.943699061870575, 55.09423166513443, 55.89549086987972, 52.83527188003063, 53.2268712669611, 56.43959127366543, 53.24123829603195, 59.15680646896362, 57.309360802173615, 63.84042754769325, 56.36674538254738, 56.57272852957249, 38.18532519042492, 57.585499584674835, 68.15210938453674, 57.51010403037071, 55.45592285692692, 49.164022877812386, 46.46646022796631, 48.567215502262115, 48.92931327223778, 49.574568048119545, 47.698867097496986, 49.38718110322952, 47.954809963703156, 54.95444096624851, 58.34455445408821, 64.39186915755272, 62.153063490986824, 69.16020289063454, 65.22146344184875, 65.79925283789635, 59.43425998091698, 65.99590748548508, 65.08984610438347, 73.68511408567429, 67.29750484228134, 58.08676868677139, 3.2262235321104527, 0.13582999032223597, 0.40978325181640685, 30.782756209373474, 83.80233719944954, 67.0144048333168, 55.70942245423794, 41.83831997215748, 68.9541931450367, 18.508620634675026, 36.68103151023388, 71.47111728787422, 55.87270349264145, 5.910079842433333, 0.10255398097797297, 0.13976325426483527, 0.1131882298795972, 0.06589174474356696, 0.06303756352281198, 0.03760853760468308, 0.17876369354780763, 0.19147509505273774, 0.13677907845703885, 0.1081815680663567, 0.24121501977788284, 0.12870984035544097, 0.2552749926690012, 0.25788821338210255, 0.1780461851740256, 24.536598175764084, 88.39403361082077, 61.490819826722145, 67.97300219535828, 26.061072573065758, 56.7177477478981, 44.47279840707779, 80.08188843727112, 68.51965606212616, 90.0136511027813, 12.848414909094572, 2.950231754221022, 5.672467667609453, 0.25454281945712864, 0.5318081227596849, 1.8249933840706944, 41.7400686442852, 49.75403241813183, 57.75280460715294, 61.32307782769203, 72.02261969447136, 66.09239190816879, 69.68147411942482, 66.83700755238533, 64.86098438501358, 63.05962264537811, 62.3712819814682, 64.71638694405556, 65.47874003648758, 64.32845816016197, 60.49436889588833, 49.54190120100975, 48.68516497313976, 48.158840015530586, 50.3058236092329, 56.1996341496706, 61.8680027872324, 60.166613683104515, 64.61799502372742, 66.40688583254814, 58.73613864183426, 58.424091786146164, 63.93581762909889, 63.126305267214775, 61.96731045842171, 54.89118956029415, 58.76595564186573, 59.884627014398575, 59.751892536878586, 59.41727489233017, 54.198505729436874, 57.96831764280796, 57.08859644830227, 47.43060529232025, 52.34570614993572, 47.882511243224144, 47.3669321089983, 52.76079207658768, 53.227950409054756, 44.45161834359169, 44.5703961700201, 46.75530172884464, 45.58505192399025, 41.65762446820736, 44.35165710747242, 42.15383984148502, 47.331195026636124, 47.26730905473232, 45.02990551292896, 47.21758492290974, 51.6294901818037, 46.69983230531216, 46.71000435948372, 48.37977156043053, 47.668955102562904, 46.79849021136761, 49.56574872136116, 55.07720857858658, 51.00492909550667, 40.532136261463165, 42.74772137403488, 41.13930948078632, 59.61434371769428, 56.408649533987045, 58.29581826925278, 51.951351910829544, 48.40408645570278, 43.24130728840828, 49.90984305739403, 48.56319911777973, 46.981636583805084, 43.45035307109356, 44.36026744544506, 43.825985714793205, 43.4693406522274, 43.618338257074356, 42.368383929133415, 43.42345431447029, 44.269133135676384, 45.47637775540352, 42.40975230932236, 42.70874686539173, 45.645263493061066, 52.21889175474644, 49.7325673699379, 47.98925131559372, 48.32730017602444, 50.100699216127396, 60.364039689302444, 58.12765829265118, 57.33016848564148, 59.226525127887726, 55.36196909844875, 55.19317835569382, 57.905408218503, 56.623208820819855, 63.245113492012024, 61.79444633424282, 65.55478915572166, 59.27908770740032, 58.01372140645981, 39.55953285098076, 57.289449870586395, 64.73360762000084, 61.60549007356167, 58.38706657290459, 51.994536593556404, 49.95565339922905, 53.69604729115963, 49.373608231544495, 52.19718351960182, 51.19426913559437, 54.064802303910255, 51.16263583302498, 58.841275200247765, 60.994418263435364, 68.65607634186745, 64.95353981852531, 73.43620464205742, 67.77890861034393, 71.18120804429054, 62.18317687511444, 70.24340316653252, 68.77880215644836, 83.34091275930405, 73.17632898688316, 68.4810121357441, 5.145748956128955, 0.4334760789060965, 0.5289862398058176, 33.54212634265423, 89.19778168201447, 73.49323198199272, 65.4199267923832, 54.23559933900833, 87.6365214586258, 30.187261663377285, 50.90928442776203, 79.95831146836281, 70.21336197853088, 6.791829178109765, 0.33590696286410093, 0.2631565119372681, 0.23131509631639346, 0.14075880084419623, 0.19349801150383428, 0.16179849451873451], [0.08321994304424152, 0.0619217333587585, 0.009092684795177775, 0.07928866805741563, 0.05725152790546417, 0.03824836909188889, 0.045649154781131074, 0.31918596010655165, 0.10226126309134997, 18.603727631270885, 64.62399870157242, 49.58296939730644, 45.93861535191536, 24.53801739960909, 38.339855298399925, 25.54486647248268, 54.776241928339005, 62.93333642184734, 67.49121844768524, 34.59769830107689, 0.4229552746983245, 1.0025303671136498, 0.04210169630823657, 0.3711287275655195, 0.035527154759620316, 0.4420477361418307, 45.046362429857254, 53.1904274225235, 55.04458352923393, 56.52542866766453, 57.228873521089554, 59.61273640394211, 58.57703737914562, 58.88611279428005, 55.680015832185745, 62.472626343369484, 61.38029135763645, 62.02078118920326, 55.40008865296841, 49.4352675229311, 42.546499371528625, 46.75038479268551, 44.2098943144083, 53.59005957841873, 53.698547556996346, 60.61304412782192, 56.22380085289478, 69.72691208124161, 49.742237851023674, 35.14441676437855, 57.52349831163883, 56.251945942640305, 60.36131523549557, 55.210585221648216, 52.2524743527174, 54.65538561344147, 53.72034318745136, 52.86064311861992, 51.295529901981354, 45.04335679113865, 49.31333586573601, 47.14570418000221, 44.8478002846241, 41.977441906929016, 40.77973857522011, 41.021660193800926, 42.03990675508976, 46.00836060941219, 44.086431339383125, 37.922945469617844, 39.196549728512764, 37.75945924222469, 39.33680780231953, 38.88280816376209, 38.9542481303215, 37.670904994010925, 37.083657905459404, 36.44067160785198, 38.586150482296944, 41.57497130334377, 43.81333239376545, 41.15770049393177, 42.77154229581356, 44.27941918373108, 45.95992460846901, 39.08883310854435, 52.30446316301823, 49.684860929846764, 38.35025534033775, 40.46935983002186, 43.68179865181446, 56.192589327692986, 51.39776721596718, 47.05358952283859, 45.39876691997051, 40.93817487359047, 42.52793736755848, 43.70925597846508, 42.14739918708801, 43.01034428179264, 38.89813274145126, 36.530825570225716, 38.42123933136463, 37.43038170039654, 37.52819985151291, 36.65165148675442, 36.21974766254425, 39.49752777814865, 39.856110736727715, 38.164517506957054, 43.31804797053337, 45.04046514630318, 43.36979739367962, 38.58747661113739, 40.43131627142429, 43.81861411035061, 42.82066985964775, 48.08949373662472, 45.702408626675606, 48.45339260995388, 50.82684025168419, 52.599593326449394, 51.13169029355049, 53.4279602766037, 50.10476879775524, 57.30657175183296, 55.604031309485435, 59.45890165865421, 59.27457734942436, 59.05127853155136, 42.16516703367233, 42.05275006592274, 65.67913368344307, 57.664330154657364, 56.8027263879776, 50.7820862531662, 44.72613461315632, 45.16296677291393, 45.681072771549225, 44.1515826433897, 45.80946408212185, 45.91010928153992, 44.84203599393368, 47.76818297803402, 47.68631637096405, 56.63563035428524, 58.28866325318813, 58.28479506075382, 60.79764202237129, 61.665789037942886, 58.13105911016464, 62.80504010617733, 65.82044050097466, 66.97001561522484, 63.7922765314579, 31.237694397568703, 0.5616691173054278, 0.3922064934158698, 0.23552957485662773, 44.4084108620882, 66.81363120675087, 62.421724274754524, 43.84360156953335, 45.990448370575905, 46.98862060904503, 40.20600736141205, 51.77889436483383, 50.01871861517429, 59.1547279804945, 7.324473196640611, 0.07910304950200953, 0.1546054211212322, 0.030175795036484487, 0.10992483585141599, 0.010033219678007299, 0.08149181507178582, 0.062093458909657784, 0.05879082382307388, 0.0604684634890873, 0.06841345122666098, 0.05293787988193799, 0.07243152780574746, 0.06008383061271161, 0.27256982401013374, 0.07961019611684605, 23.688669875264168, 73.45209538936615, 54.229899644851685, 56.21757298707962, 32.79729790985584, 49.286809489130974, 32.939262092113495, 59.49302762746811, 66.89326733350754, 74.74310651421547, 36.65744237601757, 0.6303890829440206, 2.646286776289344, 0.14660394110251218, 0.3884432406630367, 0.08702016959432513, 1.79290980566293, 50.47391898930073, 54.38508331775665, 53.91714982688427, 59.54012610018253, 60.15732318162918, 62.32614800333977, 61.60816892981529, 62.37116038799286, 57.224629148840904, 64.44290041923523, 64.63663682341576, 64.63723719120026, 59.254848808050156, 52.55895830690861, 44.33089502155781, 48.602861389517784, 46.23642057180405, 54.93065804243088, 58.599995747208595, 62.271978110075, 59.576281160116196, 67.00553610920906, 54.75622080266476, 37.9122718423605, 60.29598534107208, 57.24935442209244, 59.840678572654724, 57.4107051640749, 55.19537843763828, 55.97918897867203, 54.81273517012596, 56.473983228206635, 56.3234619051218, 49.33693639934063, 52.54268757998943, 50.65927304327488, 46.65573947131634, 47.05177702009678, 43.86776827275753, 45.689029544591904, 44.828991293907166, 48.84908817708492, 46.48807346820831, 40.72417415678501, 42.88428224623203, 40.744791850447655, 43.15015397965908, 39.94590371847153, 40.818108916282654, 42.45805911719799, 40.578562170267105, 40.54987370967865, 41.486607044935226, 43.466889783740044, 46.92940838634968, 43.83700132369995, 45.17145551741123, 45.2331718057394, 47.38240107893944, 41.63423292338848, 53.79862658679485, 50.723052620887756, 37.95514114201069, 40.60633487999439, 41.69496886432171, 58.07183548808098, 52.91222535073757, 49.00849722325802, 47.82447695732117, 42.48494267463684, 44.64430220425129, 46.53104156255722, 44.29229289293289, 44.42342385649681, 43.101201206445694, 40.253349021077156, 40.51077000796795, 41.180780455470085, 40.29217153787613, 39.39965263009071, 40.64393766224384, 41.52621991932392, 41.52729906141758, 40.902908965945244, 45.00482305884361, 49.98990476131439, 46.72999508678913, 43.87289799749851, 44.29248668253422, 45.85249677300453, 45.10791152715683, 51.72314755618572, 49.46019418537617, 52.84496136009693, 54.635790064930916, 56.85412622988224, 52.99864411354065, 56.649818792939186, 50.54697386920452, 58.499692529439926, 57.29299508035183, 61.47801831364632, 61.924182772636414, 60.149020627141, 44.18746031820774, 44.75116766989231, 68.23763519525528, 62.034528851509094, 58.72484564781189, 53.49011354148388, 46.25074960291386, 48.37145760655403, 50.65347075462341, 47.32830338180065, 48.70122291147709, 47.6692058891058, 48.979535177350044, 49.472573921084404, 50.141653418540955, 58.68418022990227, 61.80262729525566, 61.812354773283005, 63.756505250930786, 64.03657302260399, 62.81637869775295, 66.12195432186127, 69.74427714943886, 69.0125124156475, 71.38516589999199, 34.63975064456463, 0.36517177533823997, 0.29990502283908427, 0.0774515705415979, 50.23381747305393, 74.34880927205086, 70.82373842597008, 54.02879923582077, 49.290806874632835, 60.500395372509956, 38.193544149398804, 63.4259457886219, 62.153793051838875, 69.66012686491013, 9.773744344711304, 0.10318027940229513, 0.04356849553005304, 0.024428161850664765, 0.13388756720814854, 0.008132516395562561, 0.058426933974260464, 0.26909381209407, 0.11922773861442693, 0.1522133604157716, 0.17238784348592162, 0.17797596316086128, 0.197685208695475, 0.2337893276126124, 0.5152848875150084, 0.2022992743877694, 33.12077835202217, 82.8213818371296, 64.90180179476738, 59.0577457845211, 31.455703899264336, 58.47954221069813, 37.07206092774868, 69.17073592543602, 73.84150609374046, 81.37195721268654, 41.00735776126385, 2.0320756221190095, 3.966302932240069, 0.13369045278523117, 0.47697745088953525, 0.3359804057981819, 2.9648462450131774, 57.539974227547646, 58.164409920573235, 59.113982766866684, 63.69986169040203, 64.72251981496811, 64.33466702699661, 66.10515922307968, 64.4181789457798, 59.63321350514889, 66.74429252743721, 66.57734468579292, 67.58058965206146, 61.92474514245987, 55.65726265311241, 46.15853615105152, 50.377419367432594, 49.67163763940334, 57.95665606856346, 61.54293783009052, 64.15356874465942, 63.67414087057114, 61.45490035414696, 57.19950869679451, 43.517320677638054, 61.37487284839153, 59.446837306022644, 62.585305497050285, 59.77311819791794, 59.40522953867912, 59.24054637551308, 58.710607811808586, 59.47937496006489, 60.244159922003746, 56.14568464457989, 58.68524417281151, 56.32763788104057, 52.01601304113865, 51.72028250992298, 48.78349989652634, 50.413787215948105, 51.39629289507866, 53.565364703536034, 49.80400733649731, 43.16726826131344, 44.949334636330605, 41.71524077653885, 44.97149884700775, 43.96077588200569, 44.38015937805176, 43.36744152009487, 44.303289502859116, 42.10555583238602, 45.248393788933754, 47.8479178994894, 51.76169268786907, 47.357428818941116, 48.668624460697174, 48.83530251681805, 50.56090012192726, 41.33263170719147, 56.610346511006355, 50.83409406244755, 38.52204792201519, 42.93629765510559, 43.70981454849243, 59.78597290813923, 54.52717289328575, 52.49824896454811, 51.11144877970219, 46.866343170404434, 46.75724342465401, 49.22201916575432, 46.234893053770065, 47.5251442193985, 44.33041624724865, 44.62960459291935, 45.288234651088715, 43.64389568567276, 43.53988766670227, 42.59501516819, 42.580363154411316, 45.731477066874504, 43.9974819123745, 42.82056346535683, 50.03907412290573, 55.1488271355629, 51.14445760846138, 48.18110302090645, 46.39138005673885, 49.736724346876144, 52.29446969926357, 56.59466855227947, 53.463750556111336, 54.63904649019241, 58.257759511470795, 60.529068633913994, 55.2232651412487, 59.03099901974201, 53.971984684467316, 59.64142486453056, 61.10911510884762, 64.87752869725227, 65.60701355338097, 63.96269738674164, 46.340162605047226, 50.005145743489265, 62.48286299407482, 65.67163288593292, 60.882966443896294, 57.749251797795296, 48.66854086518288, 52.18959912657738, 50.81232503056526, 49.61519546806812, 52.647083178162575, 51.87155619263649, 51.80745743215084, 53.31477954983711, 54.59238499403, 64.93865981698036, 63.68509568274021, 66.33282780647278, 67.39158019423485, 67.73151755332947, 65.39477974176407, 69.82070624828339, 75.10725617408752, 74.77899938821793, 76.65636464953423, 42.59302407503128, 0.6559002608992159, 0.7376181415747851, 0.4361042910022661, 55.31392827630043, 81.21432647109032, 77.98381581902504, 65.01023277640343, 63.312309086322784, 71.05377808213234, 57.012539729475975, 72.78933495283127, 68.15609157085419, 79.95055228471756, 12.122777346521616, 0.4048220836557448, 0.2506841561989859, 0.12864758900832385, 0.3668456745799631, 0.27972748212050647, 0.10341963687096722], [0.06402617844287306, 0.09269904650864191, 0.03922576273907907, 0.022429960772569757, 0.05392039805883542, 0.04655993696360383, 0.05098607231047936, 0.14657554653240368, 0.26248231530189514, 22.687643989920616, 63.864852637052536, 43.81172128021717, 45.03357231616974, 30.68097297102213, 33.06691624224186, 26.952468641102314, 56.60368926823139, 68.68589714169502, 58.57202544808388, 60.406624004244804, 1.3204638194292784, 1.3572405022569, 0.11746589487302117, 0.02206789289630251, 0.2557424863334745, 0.4896433587418869, 3.3389839064329863, 54.04558673501015, 57.725016698241234, 63.41833479702473, 62.40379683673382, 60.37488430738449, 62.391352504491806, 64.99870419502258, 60.98762422800064, 60.83614535629749, 60.799705311656, 57.85074055194855, 47.693558782339096, 44.861722737550735, 44.61702346801758, 44.7192607820034, 53.12213748693466, 55.29547266662121, 61.28273919224739, 53.725043535232544, 58.77289406955242, 52.99718499183655, 29.56405520439148, 54.89918053150177, 56.91369943320751, 58.308148607611656, 56.031702160835266, 57.629387229681015, 52.51808010041714, 54.1416721791029, 55.5590683221817, 53.225754126906395, 51.352428048849106, 45.00663936138153, 47.99485221505165, 44.96980793774128, 42.653509229421616, 42.95799069106579, 40.61670072376728, 40.808883011341095, 44.50594022870064, 43.4674521535635, 44.59845766425133, 41.220533922314644, 39.798794612288475, 39.561261758208275, 37.39033564925194, 40.49618639051914, 38.370040878653526, 38.47263157367706, 37.480569407343864, 37.47216425836086, 40.525498017668724, 41.19389735162258, 43.184682726860046, 41.05956695973873, 44.594338685274124, 44.87787187099457, 47.61843681335449, 45.39399817585945, 55.512748807668686, 52.7113339304924, 38.057500049471855, 38.91190320253372, 42.832369431853294, 57.24161423742771, 51.28535404801369, 43.66304285824299, 46.85289569199085, 45.18189735710621, 43.362942561507225, 41.15468345582485, 41.3235729932785, 40.2647940069437, 39.59705963730812, 36.783785596489906, 36.32350489497185, 38.43015365302563, 38.31091605126858, 39.09217692911625, 36.467163786292076, 37.50538967549801, 40.1648023724556, 41.45032659173012, 46.76852881908417, 40.09755738079548, 42.5048042088747, 37.85101532936096, 40.65945602953434, 40.35429060459137, 44.03326839208603, 46.95116601884365, 49.09667909145355, 49.12984371185303, 53.06449458003044, 52.23555006086826, 51.888780668377876, 54.0898771584034, 51.00748635828495, 53.44920873641968, 56.17003753781319, 56.92190699279308, 59.04318116605282, 58.044530153274536, 53.980876207351685, 37.461456432938576, 58.251413851976395, 59.98187519609928, 56.95541739463806, 55.87636649608612, 49.08829674124718, 45.15010446310043, 45.3209812939167, 44.978783056139946, 46.57124720513821, 45.7901307195425, 45.65347105264664, 43.776489570736885, 47.24949561059475, 47.14420326054096, 56.746253818273544, 54.76827755570412, 61.09436810016632, 52.87968389689922, 58.46591234207153, 60.64105622470379, 67.41709202528, 62.76697754859924, 65.25009110569954, 8.775145579129457, 0.027003275135939475, 0.6163560203276575, 1.0384702635928988, 61.27217195928097, 61.99615851044655, 57.116384357213974, 33.3856925368309, 33.791480362415314, 44.28975082933903, 32.25997254252434, 27.167630195617676, 52.0205993950367, 57.54484176635742, 7.749825697392225, 0.17946615116670728, 0.32174259948078543, 0.0264876847359119, 0.10871646358282305, 0.06979938974836841, 0.08041812776355073, 0.052330751132103615, 0.10613859878503717, 0.042957392579410225, 0.06911889970069751, 0.11775804130593315, 0.0158555973393959, 0.018369231111137196, 0.14693685370730236, 0.11165423289639875, 33.30539144575596, 72.76614099740982, 53.05421993136406, 58.03590461611748, 29.2283983156085, 41.16636402904987, 29.513913094997406, 62.85856023430824, 74.77035105228424, 64.08062025904655, 67.64564216136932, 1.39334580861032, 1.3665851508267224, 0.38377640827093273, 0.05869381770025939, 0.017098878379329108, 0.8754983148537576, 7.3371098935604095, 59.67295937240124, 57.77384027838707, 67.31991603970528, 65.2329920232296, 65.00167563557625, 64.92161393165588, 64.94933724403381, 61.40924960374832, 62.683575823903084, 63.47236409783363, 61.571820080280304, 50.78579105436802, 46.38245813548565, 46.37228228151798, 48.879041969776154, 55.39584428071976, 58.83070796728134, 63.42596098780632, 57.59386673569679, 56.80708095431328, 55.765131264925, 34.51723001897335, 56.308429911732674, 60.6589874625206, 59.906209856271744, 60.44816717505455, 59.16521541774273, 52.687763795256615, 56.880310624837875, 56.13944537937641, 58.642606660723686, 55.166936963796616, 52.36322320997715, 52.42682419717312, 50.16935773193836, 46.56379960477352, 45.47748729586601, 43.202389776706696, 45.117468014359474, 47.0830949395895, 47.449026703834534, 50.01947097480297, 44.733548015356064, 43.81488271057606, 41.99036121368408, 40.57020261883736, 39.222654327750206, 40.04099361598492, 43.61516162753105, 41.01841136813164, 40.32193534076214, 42.98962019383907, 41.82780213654041, 44.11467522382736, 44.616567492485046, 45.62046982347965, 46.45942680537701, 49.14794594049454, 46.324701234698296, 56.10450245440006, 52.63871982693672, 38.68522636592388, 37.23696827888489, 43.0907441675663, 56.389209777116776, 52.264861688017845, 46.61278657615185, 48.634050115942955, 45.20124211907387, 46.300982907414436, 43.72886672616005, 44.77009065449238, 43.36102366447449, 43.308711871504784, 38.4008876234293, 40.90999558568001, 39.65446315705776, 41.8959628790617, 41.46287351846695, 37.76926651597023, 41.7651093006134, 41.83612748980522, 42.548334673047066, 50.90048789978027, 47.05225579440594, 47.36593276262283, 40.62245361506939, 42.690226659178734, 45.757726058363914, 48.13289500772953, 53.00486817955971, 53.54871019721031, 52.221205830574036, 56.38234734535217, 55.05723685026169, 55.2427276968956, 55.94518460333347, 51.8259434401989, 56.94802299141884, 59.321007058024406, 59.277290403842926, 60.88619627058506, 57.842916771769524, 54.57517571747303, 42.3425567150116, 59.87173430621624, 63.68562005460262, 59.26310196518898, 57.640904411673546, 52.97564774751663, 47.2910425812006, 48.62054564058781, 48.52591171860695, 48.856182396411896, 48.62787164747715, 50.09457774460316, 46.95874661207199, 48.56740929186344, 52.83190906047821, 58.82952623069286, 59.58454951643944, 63.78881871700287, 56.49177007377148, 64.5116539299488, 64.49650034308434, 70.6694895029068, 67.4790970981121, 69.03978735208511, 9.161053821444511, 0.16982281784294173, 1.207896403502673, 1.9645273592323065, 68.60858649015427, 68.19722056388855, 64.6636837720871, 39.70134884119034, 36.352949514985085, 61.8990433216095, 34.24378529191017, 44.25107650458813, 62.93344281613827, 69.32874664664268, 12.846314571797848, 0.31494132068473846, 0.21275335951941088, 0.13413599372142926, 0.09798466679058038, 0.016317981317115482, 0.06027228417224251, 0.20754147903062403, 0.1946278422838077, 0.0852672613109462, 0.11250711642787792, 0.25875032180920243, 0.25110643822699785, 0.14393820601981133, 0.26044981030281633, 0.333781570661813, 41.762856021523476, 80.89824423193932, 60.40324218571186, 56.579184383153915, 39.68807615339756, 52.92919524013996, 38.39692443609238, 73.6872723698616, 79.90406557917595, 71.42177313566208, 73.439100086689, 1.550680878572166, 4.360248455777764, 0.3565711446572095, 0.12201218763948418, 0.5682535702362657, 1.0403538937680423, 9.813154879957438, 66.83762311935425, 61.28210462629795, 71.32925570011139, 66.97399020195007, 70.668805539608, 66.57413005828857, 69.408078789711, 66.0050193965435, 66.8395534157753, 64.41535949707031, 65.4850172996521, 52.41561479866505, 50.234934613108635, 48.76860089600086, 51.69854387640953, 56.869796589016914, 62.2167556732893, 67.68162623047829, 63.34355480968952, 55.64098812639713, 53.48096363246441, 40.256871432065964, 59.544552862644196, 62.503549084067345, 61.806016713380814, 62.13266618549824, 63.99482846260071, 55.40881298482418, 58.945344015955925, 60.17803966999054, 60.66848695278168, 59.64853808283806, 58.55425380170345, 56.20079308748245, 54.763577207922935, 51.959035098552704, 51.75424508750439, 48.73075492680073, 48.41655358672142, 51.03855349123478, 52.68238328397274, 53.54898378252983, 47.450246438384056, 47.204604819417, 45.49021281301975, 43.02306979894638, 44.38597686588764, 42.939542680978775, 44.25022155046463, 42.77750037610531, 42.934534549713135, 46.606516912579536, 45.706026032567024, 47.16903492808342, 46.55471809208393, 50.03312364220619, 49.55443672835827, 51.31567262113094, 46.941643729805946, 59.113994166255, 54.24278475344181, 37.92979270219803, 37.84371592104435, 42.84202851355076, 58.6043731123209, 57.55023367702961, 49.897679910063744, 51.976084783673286, 49.84668664634228, 50.11139564216137, 46.27724938094616, 47.541973516345024, 47.146262750029564, 47.13395521044731, 43.078683614730835, 42.864466309547424, 43.715236857533455, 45.91938458383083, 44.396380707621574, 40.42112521827221, 42.26858988404274, 43.724025785923004, 46.954950615763664, 55.075757056474686, 49.45110127329826, 51.85812771320343, 43.779027834534645, 47.02741652727127, 48.70863251388073, 52.58186727762222, 56.86834506690502, 57.63212688267231, 58.47438968718052, 58.989163264632225, 58.83322723209858, 57.87879824638367, 58.47730413079262, 53.821558356285095, 61.076911836862564, 61.247575879096985, 63.970866948366165, 60.78665301203728, 61.00965924561024, 54.245927184820175, 45.5570550262928, 58.979542180895805, 64.81002911925316, 64.98262345790863, 60.76905995607376, 56.56520493328571, 49.725670740008354, 52.44479343295097, 52.14701861143112, 52.53654710948467, 50.949615463614464, 52.77257524430752, 49.64592441916466, 53.65415833890438, 54.96177837252617, 63.90291139483452, 61.6953856498003, 68.56610476970673, 60.127836763858795, 65.93311205506325, 66.92042827606201, 76.08045235276222, 71.65878161787987, 80.23403227329254, 13.8176498003304, 0.2932417538249865, 1.4373563532717526, 2.335612359456718, 74.76359501481056, 73.45309853553772, 70.087581127882, 50.86751326918602, 46.03000424802303, 69.48944762349129, 44.04967211186886, 39.925073236227036, 69.95798528194427, 83.21771577000618, 18.49287047982216, 0.5025582422968, 0.4793359962059185, 0.23309446958592162, 0.2049676069873385, 0.1873526131385006, 0.2685674512758851], [0.05984317809634376, 0.006445111457651365, 0.09155316307442263, 0.10113225609529763, 0.04662871178879868, 0.01690368797426345, 0.079654339060653, 0.04118079123145435, 1.11352882348001, 48.30211512744427, 61.695628836750984, 48.831031545996666, 45.16552783548832, 54.488107189536095, 49.268494471907616, 37.63362519443035, 43.04780647158623, 72.68979549407959, 58.320152163505554, 72.17952087521553, 7.221726235002279, 0.20435963961062953, 0.8378078998066485, 0.051163334283046424, 0.34298999060411006, 0.09219000741722994, 0.4725108202546835, 29.77221943438053, 66.09610810875893, 68.79072591662407, 63.79562795162201, 61.5195918828249, 63.05155947804451, 61.2622506916523, 59.45913724601269, 60.374861508607864, 60.46965502202511, 50.447111427783966, 42.30150371789932, 43.772116005420685, 46.12801618874073, 52.2167144715786, 59.29503545165062, 55.55955469608307, 57.75981903076172, 48.27733285725117, 62.440179884433746, 42.30831295251846, 44.520094469189644, 58.63271579146385, 59.35526221990585, 59.47845160961151, 54.259082078933716, 54.80227433145046, 52.1495720744133, 56.172583401203156, 53.92338149249554, 53.04347410798073, 50.571991726756096, 48.31083185970783, 45.81407703459263, 46.536353677511215, 42.37357825040817, 44.51949030160904, 40.57412400841713, 42.25559838116169, 44.73330482840538, 40.79385481774807, 46.557989716529846, 40.97213365137577, 39.46338661015034, 38.37974175810814, 38.83335381746292, 39.96970944106579, 40.18217884004116, 40.57380102574825, 40.925821736454964, 40.84062650799751, 39.864755272865295, 40.12047775089741, 43.14036190509796, 43.46218943595886, 44.38140571117401, 45.28475783765316, 47.80440263450146, 52.805166095495224, 59.42955203354359, 46.9162230938673, 35.936290472745895, 38.055904135107994, 44.86478537321091, 60.48664391040802, 54.41657982766628, 47.03185088932514, 46.337434351444244, 45.450212359428406, 42.66116961836815, 39.64400991797447, 43.613493517041206, 43.9574358612299, 41.23679704964161, 37.80652351677418, 38.36306445300579, 39.087696969509125, 39.27973486483097, 36.36825889348984, 37.5288800150156, 38.390115201473236, 39.81997847557068, 44.085933566093445, 43.81112091243267, 42.00480803847313, 42.37020403146744, 40.55576719343662, 43.64150181412697, 42.24683225154877, 43.17308574914932, 47.46524043381214, 51.02029547095299, 49.12991590797901, 53.29937517642975, 51.907901242375374, 51.503591537475586, 54.07380782067776, 53.87845650315285, 51.562040001153946, 55.95301978290081, 56.93159267306328, 59.07009892165661, 55.378931388258934, 53.104818016290665, 40.851740911602974, 47.720852717757225, 59.6313402056694, 59.47687469422817, 59.28774744272232, 54.289575442671776, 45.08428059518337, 48.76908726990223, 44.87767428159714, 47.915945649147034, 47.351330146193504, 50.77208898961544, 47.335302606225014, 48.27279970049858, 46.5101882815361, 53.76880198717117, 50.648686811327934, 56.180505976080894, 54.918377101421356, 61.62591017782688, 62.314877808094025, 66.5189266204834, 70.9394346177578, 41.961649954319, 1.0434308974072337, 0.1892457576468587, 1.359751217532903, 5.989973405376077, 68.56824785470963, 59.90930289030075, 63.702407553792, 38.283352330327034, 40.63056617975235, 42.31749705970287, 40.06256125867367, 46.11277140676975, 49.45108987390995, 66.36509567499161, 14.027409944683313, 0.24306598061230034, 0.12242563811014406, 0.07876163188484497, 0.04517455876339227, 0.0686446376494132, 0.05532642280741129, 0.06399580233846791, 0.06327067210804671, 0.0947176585032139, 0.06507892234367318, 0.12604438728885725, 0.04329962655901909, 0.06382697858498432, 0.06833067207480781, 1.0823023365810513, 60.782397240400314, 64.87524881958961, 64.76389199495316, 38.9846882969141, 31.897023618221283, 54.79387678205967, 40.38127675652504, 53.488608822226524, 76.24100133776665, 65.12067764997482, 80.83097264170647, 9.1506471298635, 0.9293452254496515, 0.8573639660608023, 0.06894096979522146, 0.5792350403498858, 0.13602728286059573, 0.4457728425040841, 35.57386592030525, 69.51264917850494, 67.35856756567955, 65.78678950667381, 62.4391121417284, 64.80711087584496, 63.288693353533745, 61.91904164850712, 60.53237825632095, 62.42460831999779, 51.369397938251495, 44.95872773230076, 45.95147006213665, 48.50546881556511, 55.951891243457794, 61.59215658903122, 58.29884670674801, 60.314912125468254, 48.98049272596836, 63.48873361945152, 44.76478613913059, 45.69403387606144, 63.302251026034355, 59.334640726447105, 61.379694789648056, 56.12445518374443, 56.97497494518757, 52.806469425559044, 59.39352996647358, 54.27540980279446, 56.3791137188673, 54.37867686152458, 53.74348774552345, 50.48413664102554, 50.4947342723608, 46.98941096663475, 47.45384484529495, 45.771576315164566, 45.53637273609638, 48.943862691521645, 43.021777868270874, 48.198156505823135, 46.037379652261734, 42.5613147765398, 42.427303567528725, 40.88262565433979, 41.48374579846859, 41.57485730946064, 41.25036992132664, 42.48639799654484, 41.99894495308399, 43.451652601361275, 43.49365934729576, 44.91294398903847, 45.349787548184395, 46.562173292040825, 48.74448738992214, 49.26703155040741, 52.589432671666145, 60.861991569399834, 48.1003687530756, 36.814396753907204, 38.84801723062992, 43.38342726230621, 58.179810494184494, 57.11785867810249, 48.02306570112705, 48.06722693145275, 45.47789007425308, 46.46477311849594, 42.669202387332916, 45.73472589254379, 45.621191784739494, 44.99733746051788, 40.275171250104904, 41.39993369579315, 40.9678702801466, 40.80980636179447, 39.693680852651596, 38.74058559536934, 39.865690022706985, 41.318352073431015, 45.872745886445045, 48.544849902391434, 45.60642197728157, 46.10009528696537, 43.52145105600357, 47.887021601200104, 45.72977475821972, 47.40237280726433, 51.79461792111397, 54.231769144535065, 55.39143271744251, 57.23829701542854, 54.9300766736269, 55.31265914440155, 53.97992625832558, 56.188044771552086, 54.0871375054121, 59.56647768616676, 61.34230859577656, 60.36003850400448, 56.60808563232422, 56.08928047120571, 46.08046554028988, 49.30762477219105, 61.14587813615799, 63.347878977656364, 61.638871282339096, 57.79529392719269, 49.098354801535606, 50.13329766690731, 49.04416210949421, 50.837445482611656, 51.80775761604309, 55.12915179133415, 51.287770718336105, 50.430681109428406, 49.86894205212593, 56.235952600836754, 54.496356546878815, 58.88544023036957, 59.007641673088074, 65.10632202029228, 65.62937915325165, 70.52557602524757, 72.80706480145454, 46.44189454615116, 0.7872482878156006, 0.26829377689864486, 2.1126752346754074, 7.5410629995167255, 75.84816321730614, 66.27088353037834, 71.66656360030174, 42.311497181653976, 43.767639845609665, 54.78139065206051, 45.276075303554535, 45.318663418293, 57.249445617198944, 76.78310304880142, 20.48183385282755, 0.27149201778229326, 0.18589114624774083, 0.08883155911462381, 0.09364624958834611, 0.033346175696351565, 0.04163943107414525, 0.13161016831872985, 0.1841990792308934, 0.22242061968427151, 0.16503424354596063, 0.24516554607544094, 0.09935032983776182, 0.20660571986809373, 0.1902651716955006, 1.5620366879738867, 69.64023113250732, 75.32558485865593, 67.56207704544067, 59.965558871626854, 76.49532169103622, 68.02189037203789, 53.017806485295296, 59.341955333948135, 83.99682596325874, 69.46240827441216, 89.28488820791245, 9.093336705118418, 4.003753960132599, 2.4155258713290095, 0.2260452095651999, 1.2390403635799885, 0.46399004466366023, 0.9161208069417626, 38.60439330339432, 75.30783221125603, 73.65251183509827, 69.38648074865341, 66.66767343878746, 69.47946935892105, 66.5283653140068, 64.84706953167915, 64.24106284976006, 67.51972451806068, 54.50662359595299, 47.320589795708656, 47.20354847609997, 50.36603517830372, 57.77164779603481, 66.34156733751297, 60.141538828611374, 64.10195231437683, 51.011229157447815, 58.08141477406025, 54.02551621198654, 49.573257118463516, 63.470042422413826, 63.96930143237114, 64.21536862850189, 58.205930292606354, 59.616574198007584, 56.45435728132725, 61.47514946758747, 56.62672363221645, 59.689112305641174, 60.0761329382658, 59.02423918247223, 55.2143470197916, 56.253952234983444, 50.681486651301384, 50.75701519846916, 51.95826753973961, 49.665405973792076, 54.90980476140976, 47.34541766345501, 53.25194992125034, 50.56476071476936, 46.28186993300915, 46.5854736417532, 43.502410277724266, 44.11551117897034, 45.85476145148277, 44.79572407901287, 45.5242133885622, 46.37857474386692, 46.4039421826601, 45.542627200484276, 47.618319019675255, 47.888659313321114, 47.95251488685608, 51.38899728655815, 52.307977974414825, 55.7753337174654, 65.31065225601196, 47.52689212560654, 36.989331766963005, 40.46634279191494, 44.05612416565418, 61.69427990913391, 58.96132595837116, 49.72872577607632, 50.74061147868633, 50.678142830729485, 47.95009061694145, 44.694204926490784, 48.47766570746899, 49.35395188629627, 47.972824797034264, 43.72390799224377, 43.00723984837532, 43.419985100626945, 44.37876485288143, 41.04293905198574, 41.27836301922798, 43.4226905554533, 45.527276024222374, 51.69318996369839, 53.2007172703743, 49.49555888772011, 50.743107944726944, 47.78177484869957, 52.03201778233051, 50.4213298112154, 51.20502255856991, 55.33093996345997, 57.396459728479385, 57.60110914707184, 63.22053261101246, 58.75295273959637, 57.0847624540329, 56.1029901355505, 58.599121794104576, 56.909059882164, 60.924464017152786, 63.55079188942909, 61.70264706015587, 61.32636085152626, 56.34097896516323, 47.91164807975292, 50.948175340890884, 61.3421756029129, 66.8474493920803, 64.89062279462814, 61.894308775663376, 50.643678680062294, 55.932022109627724, 52.096188738942146, 55.564688220620155, 55.20240806043148, 57.1515666693449, 54.148641005158424, 55.16551584005356, 53.182098269462585, 61.282374411821365, 58.95537167787552, 63.78415256738663, 63.058311715722084, 69.49464574456215, 70.3396824002266, 76.0363519191742, 76.83975040912628, 56.42840087413788, 1.3437882740981877, 0.46240125491749495, 2.2803747234866023, 8.28549150377512, 85.61568349599838, 72.55472794175148, 80.5418461561203, 53.99964340031147, 57.17132940888405, 62.09847941994667, 56.58575423061848, 60.53059235215187, 68.94575759768486, 88.85590642690659, 28.40763285756111, 0.6231234571896493, 0.4121260339161381, 0.201996463292744, 0.20973290753317997, 0.11165712727233768, 0.16149746457813308], [0.06373700060066767, 0.15415245870826766, 0.13701266201678663, 0.07880238321376964, 0.09011578629724681, 0.014236292336136103, 0.09312011883594096, 0.14704559318488464, 4.448310155421495, 60.46272039413452, 57.149366587400436, 41.93030543625355, 67.16906413435936, 117.95378744602203, 75.96639007329941, 34.92548771202564, 32.00667813420296, 74.99839961528778, 54.21180121600628, 71.75380691885948, 30.157554857432842, 0.28641254059039056, 0.88431027950719, 0.13037683762377128, 0.09090892694075592, 0.09327635576482862, 0.6393833190668374, 10.171666592359543, 66.40292644500732, 65.33525213599205, 66.69155895709991, 62.07499288022518, 58.44670817255974, 60.427952259778976, 56.19073502719402, 53.508048579096794, 48.49841259419918, 44.71518360078335, 42.504857406020164, 44.77799043059349, 51.25152446329594, 58.04751679301262, 56.77097909152508, 58.38743135333061, 50.49211621284485, 58.21899399161339, 55.39921469986439, 36.48195639252663, 54.16976027190685, 57.421773970127106, 59.87643465399742, 54.13136713206768, 58.11160795390606, 54.377761110663414, 53.473269045352936, 56.1965487152338, 55.154253244400024, 53.96673336625099, 53.720259591937065, 47.86171115934849, 49.31365504860878, 45.438524186611176, 44.993849247694016, 44.65669333934784, 46.293383315205574, 42.99265243113041, 42.732510790228844, 39.145913645625114, 42.53256931900978, 45.01518130302429, 43.51499520242214, 39.4389995187521, 38.681920543313026, 37.93213337659836, 39.62964668869972, 37.885069102048874, 41.39343984425068, 41.50610379874706, 39.769030809402466, 40.810794308781624, 44.937980845570564, 43.806287571787834, 46.54595196247101, 46.29293493926525, 52.07006514072418, 55.77772758901119, 63.29819664359093, 47.974310517311096, 34.53051030635834, 36.59083195030689, 42.20084331929684, 58.32418754696846, 59.93124671280384, 53.159390687942505, 49.38951417803764, 46.042448580265045, 43.03618289530277, 44.126253202557564, 42.115347906947136, 42.45100289583206, 39.853169694542885, 39.29658316075802, 37.591721042990685, 38.95605303347111, 42.283359691500664, 38.953522369265556, 42.14336760342121, 39.98106323182583, 42.72024504840374, 43.31440016627312, 42.99213565886021, 40.10877437889576, 43.90991561114788, 41.47240720689297, 42.695090398192406, 46.119736433029175, 45.15072762966156, 46.55579723417759, 50.436794981360435, 50.08052609860897, 53.1639314442873, 54.6343157440424, 52.41997316479683, 53.307510539889336, 53.00807520747185, 50.67356787621975, 58.22722055017948, 56.53151594102383, 58.89049395918846, 55.17780818045139, 54.925057142972946, 46.51967637240887, 47.8221020847559, 52.473272904753685, 61.012683883309364, 57.941696271300316, 55.574385300278664, 48.835952281951904, 44.47423852980137, 45.934503972530365, 50.77929340302944, 49.63834762573242, 53.82459059357643, 52.602990344166756, 50.77709712088108, 48.047730177640915, 50.65754033625126, 50.545982122421265, 56.4675235748291, 53.14720094203949, 60.900768488645554, 63.15073035657406, 69.45778772234917, 74.15862947702408, 9.056853912770748, 0.5360911460593343, 0.4337825858965516, 2.4044102802872658, 13.685651533305645, 68.53592678904533, 57.11454525589943, 62.777981758117676, 31.551859639585018, 22.4642900750041, 49.04665857553482, 30.440890453755856, 44.13491673767567, 49.01762813329697, 64.7214786708355, 28.399328403174877, 0.4482872091466561, 0.2262920478824526, 0.11711196464602835, 0.06907771050464362, 0.04396465767058544, 0.0307436530420091, 0.08932850119890645, 0.1563520063064061, 0.01676583033258794, 0.016590019258728717, 0.13638688309583813, 0.06437011936213821, 0.26210465119220316, 0.07364606732153334, 6.115693459287286, 69.45676937699318, 63.59360419213772, 56.8995413929224, 54.67057719826698, 106.09625771641731, 77.131407558918, 41.97225138545036, 40.75820133090019, 79.60071265697479, 61.956728026270866, 77.0212970674038, 35.05327105522156, 0.2882665739161894, 1.4876301493495703, 0.08643805122119375, 0.21467819373356178, 0.12887030752608553, 0.71905572200194, 13.03955890238285, 71.58001944422722, 66.24969586730003, 68.92175808548927, 62.69622914493084, 61.79793834686279, 60.80830045044422, 59.117953553795815, 54.35954108834267, 52.83633202314377, 45.836583226919174, 46.92052826285362, 46.45904302597046, 53.8056144118309, 60.00858776271343, 61.51028998196125, 61.5911952406168, 55.81629551947117, 57.16326244175434, 55.88284134864807, 39.67125065624714, 54.920474588871, 58.76016475260258, 62.22557120025158, 58.03697615861893, 60.009815096855164, 57.95307286083698, 55.46387583017349, 58.02645832300186, 56.24016657471657, 57.1772038936615, 58.55004362761974, 52.76005491614342, 52.82939739525318, 50.479250103235245, 47.49482184648514, 50.2869538217783, 50.5418935418129, 45.89529387652874, 45.307871997356415, 43.09732161462307, 46.728224381804466, 49.94459219276905, 47.054733261466026, 40.32088279724121, 40.45066483318806, 41.23657666146755, 42.78483398258686, 39.374330788850784, 42.04356975853443, 43.368619456887245, 42.85609915852547, 41.77325986325741, 45.511430874466896, 45.722577944397926, 48.50542701780796, 47.02713914215565, 53.59608605504036, 57.80940257012844, 63.09240348637104, 48.78257654607296, 33.26892860233784, 35.16028471291065, 41.91368892788887, 59.87053357064724, 61.53358653187752, 53.513881266117096, 50.798615366220474, 47.85688541829586, 45.73282599449158, 45.5394733697176, 43.505564108490944, 44.384358152747154, 42.27214269340038, 41.072372272610664, 40.8397601544857, 39.606323540210724, 43.06781239807606, 41.47995360195637, 44.49796825647354, 42.47751027345657, 45.519250854849815, 46.48488163948059, 46.84694521129131, 45.84468439221382, 47.071273773908615, 43.6648553609848, 47.99769826233387, 49.90339860320091, 47.88732938468456, 51.24804005026817, 54.23075079917908, 54.60719659924507, 57.20368467271328, 57.137222439050674, 56.214232966303825, 57.33375549316406, 57.3559994995594, 54.41407196223736, 59.25054743885994, 58.38973022997379, 61.38232424855232, 57.19299204647541, 55.84178455173969, 49.57776367664337, 49.109218418598175, 55.1645202934742, 64.532909989357, 60.96084326505661, 61.447068974375725, 50.686247795820236, 47.08827406167984, 47.10647128522396, 53.86141821742058, 52.78897516429424, 57.73731663823128, 56.493920758366585, 55.51755554974079, 51.954946517944336, 53.612212389707565, 53.572971895337105, 59.49460834264755, 56.48045428097248, 63.78905430436134, 65.55684864521027, 71.64561152458191, 75.23437455296516, 10.777455735951662, 0.5943678470794111, 0.5793293821625412, 2.6769525557756424, 18.081504553556442, 75.90177074074745, 65.7822373509407, 68.1522461771965, 40.28403237462044, 24.29235488176346, 61.733566001057625, 35.46910174190998, 45.90185612440109, 62.031527012586594, 73.43469992280006, 37.25346699357033, 0.9524498856626451, 0.16462560219224542, 0.06217923633812461, 0.08757623116252944, 0.05591930603259243, 0.09857717523118481, 0.10764873572043143, 0.2590567397419363, 0.23903497582068667, 0.12545715551823378, 0.24077111156657338, 0.3187306079780683, 0.5456855124793947, 0.3001890575978905, 6.693356512114406, 79.84222769737244, 72.94635772705078, 56.15185171365738, 89.97804701328278, 123.00666511058807, 82.80537709593773, 52.07112528383732, 44.526508525013924, 89.75355505943298, 63.82229492068291, 83.40756118297577, 36.97802357375622, 1.7290729936212301, 4.488583244383335, 0.3266161942156032, 0.47152385290246457, 0.3958206041716039, 1.1185905081219971, 14.534745421260595, 79.48766872286797, 67.21383333206177, 71.23204171657562, 66.06731325387955, 64.84092146158218, 64.91349756717682, 62.30330742895603, 57.95565292239189, 55.6168632209301, 47.549117133021355, 48.60550984740257, 49.93114851415157, 57.68371291458607, 62.72599294781685, 65.15266433358192, 63.700009882450104, 60.269808545708656, 53.238472044467926, 58.5814793407917, 45.05248010158539, 57.8264332562685, 63.40931408107281, 63.82902055978775, 60.49157224595547, 62.63635575771332, 60.777320712804794, 57.49961659312248, 62.22537741065025, 59.18677546083927, 60.263671875, 64.19673442840576, 58.44008132815361, 59.2945908755064, 55.204649940133095, 53.44660967588425, 54.45890195667744, 55.415094047784805, 50.484121441841125, 48.50304834544659, 46.06679767370224, 49.38108243048191, 53.969754204154015, 51.96933634579182, 44.46068465709686, 43.19434940814972, 43.21335218846798, 44.47831951081753, 42.691222205758095, 43.415653333067894, 44.1194211691618, 45.112193897366524, 44.724097922444344, 49.760872051119804, 48.65032844245434, 52.029293328523636, 48.80527272820473, 53.51043485105038, 60.67749626934528, 66.54670313000679, 48.414250910282135, 34.99704547226429, 36.79993852972984, 41.670843958854675, 63.412597104907036, 63.26543100178242, 55.7077619433403, 56.168646812438965, 51.86713322997093, 47.19161331653595, 49.46307063102722, 48.31388309597969, 46.364051923155785, 45.52985608577728, 45.74115514755249, 41.753071546554565, 43.052803203463554, 46.733582094311714, 43.38947653770447, 45.66787227988243, 45.35316936671734, 50.09594567120075, 50.10105259716511, 48.599620163440704, 48.768388107419014, 50.57024762034416, 47.32147514820099, 53.392774164676666, 54.99999292194843, 53.32890719175339, 52.87368021905422, 58.123831897974014, 58.375180810689926, 63.01042288541794, 61.43656253814697, 54.661875665187836, 60.18767215311527, 59.90615665912628, 57.25283123552799, 63.07775907218456, 62.94507019221783, 64.02926981449127, 59.780026227235794, 58.18576477468014, 51.869124323129654, 51.51545450091362, 54.962074756622314, 65.97876280546188, 62.24470317363739, 63.232741355895996, 54.07536193728447, 50.20709730684757, 50.92753104865551, 57.8887727111578, 54.405313432216644, 60.99347971379757, 60.62076911330223, 56.72772601246834, 54.80103559792042, 56.983676478266716, 58.054424822330475, 64.6999642252922, 60.41362702846527, 68.70789036154747, 70.32319128513336, 77.69267544150352, 80.40641382336617, 17.691689170897007, 0.7182841852772981, 0.8110962237697095, 4.988779854029417, 19.33483500033617, 84.67565193772316, 71.66646480560303, 75.75504541397095, 50.65323516726494, 34.62502643465996, 64.04905915260315, 46.79006606340408, 57.769668102264404, 67.37980842590332, 83.56478154659271, 47.15185604989529, 1.4143963227979839, 0.32834222191013396, 0.2476088298135437, 0.21362266677897424, 0.11642034980468452, 0.3139085479779169], [0.035187815155950375, 0.042447696687304415, 0.09607069761841558, 0.03221003295038827, 0.10922859743004665, 0.018548055304563604, 0.38541483285371214, 0.04686980217229575, 8.225879352539778, 66.65667682886124, 64.32793378829956, 44.96958754956722, 59.845789298415184, 88.2691191136837, 75.22097647190094, 39.25078421831131, 21.439842246472836, 59.110426157712936, 63.19526016712189, 58.79687078297138, 61.37059047818184, 2.352799787186086, 0.4175164899788797, 0.46458595956210047, 0.045186039787949994, 0.2581036736955866, 0.28001834463793784, 4.421745305880904, 56.25688947737217, 63.11111368238926, 63.05632822215557, 60.71173243224621, 51.8957456946373, 51.009960025548935, 46.45735211670399, 47.00912430882454, 45.43253190815449, 46.95887200534344, 42.727160677313805, 49.277051612734795, 57.00096935033798, 55.26348978281021, 55.590139254927635, 52.76237279176712, 52.213332653045654, 61.068586483597755, 39.20066490769386, 45.76217941939831, 55.395395904779434, 57.081646621227264, 58.11614491045475, 57.070756405591965, 56.24984845519066, 55.186084136366844, 55.554679557681084, 56.94999888539314, 55.57823829352856, 53.950048461556435, 55.07782034575939, 50.45822203159332, 50.12207306921482, 46.779441833496094, 45.5278991907835, 42.91207015514374, 44.499222189188, 42.752911895513535, 46.031155586242676, 44.335994347929955, 38.69507543742657, 35.298175513744354, 39.3266661465168, 44.012719094753265, 41.05655372142792, 41.80463097989559, 41.247649267315865, 40.84113948047161, 40.409589037299156, 41.65870741009712, 42.586613819003105, 39.774175733327866, 43.536125868558884, 45.73613561689854, 45.459499061107635, 47.15250201523304, 54.327664598822594, 56.03697627782822, 58.3239671587944, 49.74488250911236, 32.199840769171715, 34.96597073972225, 42.16023489832878, 58.06009791791439, 59.657471403479576, 56.50837138295174, 52.55957767367363, 45.85592418909073, 43.91029179096222, 43.57861518859863, 41.49726927280426, 40.62459670007229, 39.52498510479927, 39.95792627334595, 40.948350727558136, 37.50176087021828, 37.03389957547188, 39.74428653717041, 40.27318015694618, 41.30115419626236, 43.800739869475365, 42.32676476240158, 41.551587358117104, 41.30926676094532, 46.54715269804001, 39.905340895056725, 43.66973049938679, 43.10852341353893, 46.24734878540039, 51.33674629032612, 48.14019061625004, 48.145419135689735, 51.61723963916302, 53.18311661481857, 52.00699992477894, 52.681091353297234, 53.25389921665192, 51.18584878742695, 53.19028303027153, 56.856231316924095, 57.39774405956268, 56.82708688080311, 54.419361278414726, 49.72576193511486, 44.736147075891495, 51.72782510519028, 54.59347553551197, 59.77765515446663, 59.59920912981033, 52.485603243112564, 42.85328730940819, 45.4785930365324, 47.2293870896101, 52.14764937758446, 57.14197978377342, 53.718887865543365, 57.57224589586258, 53.72542351484299, 52.16572880744934, 50.691373720765114, 54.02374930679798, 59.388407841324806, 67.36947298049927, 66.270252764225, 78.2378701865673, 38.493367061018944, 0.8412499807309359, 0.0710999738657847, 0.2882283681537956, 0.8657480380497873, 27.51474916934967, 69.60669413208961, 57.20703609287739, 62.009833976626396, 30.174080170691013, 27.289198972284794, 41.87102101743221, 50.10612912476063, 31.321776285767555, 42.50353887677193, 64.31803151965141, 27.42593463510275, 0.41833252587821335, 0.17425508704036474, 0.03627433419751469, 0.04332321201218292, 0.11281355662504211, 0.018817451200447977, 0.09026956671732478, 0.018426714159431867, 0.06589058699319139, 0.03305752848973498, 0.13469438563333824, 0.0575801805825904, 0.4541743698064238, 0.08953170123277232, 10.109183695167303, 75.62902897596359, 73.55978921055794, 48.612113893032074, 60.72408936917782, 93.64630937576294, 79.82845723628998, 44.7832265496254, 28.90109147876501, 69.30056735873222, 68.25061529874802, 63.87085631489754, 66.5275065600872, 3.223095112480223, 0.7923964178189635, 0.4509996995329857, 0.03413019534491468, 0.788792489329353, 0.2538512565661222, 5.598658053204417, 64.38643544912338, 66.64821088314056, 66.92374929785728, 63.37196208536625, 54.61166515946388, 53.01803447306156, 49.71828393638134, 50.04740707576275, 47.4427380412817, 50.182470828294754, 46.35011427104473, 51.62505961954594, 58.86307083070278, 58.87861579656601, 59.91957753896713, 55.91028727591038, 53.592301458120346, 61.57038375735283, 44.359062910079956, 46.6026297211647, 59.04338635504246, 58.108089342713356, 60.33807188272476, 58.70585046708584, 56.89538821578026, 54.49788026511669, 56.49777375161648, 58.08168835937977, 58.15748669207096, 56.16758666932583, 58.374519646167755, 57.264675199985504, 54.74245794117451, 51.23539812862873, 50.89448042213917, 47.29141116142273, 48.00186283886433, 45.66634476184845, 49.981594607234, 46.644005700945854, 41.41092270612717, 40.73730245232582, 44.096291810274124, 45.5971846729517, 41.957169994711876, 43.42421807348728, 42.64409713447094, 43.90483908355236, 41.73105552792549, 45.367323607206345, 43.092480674386024, 42.19692572951317, 44.90830823779106, 48.283625319600105, 46.582403406500816, 48.42878893017769, 56.42315335571766, 57.02175423502922, 60.40186665952206, 50.46064630150795, 31.173082664608955, 35.460563600063324, 40.69450154900551, 57.755228877067566, 61.0606487095356, 58.69919702410698, 53.49838189780712, 48.8069674372673, 46.28020942211151, 47.6884176582098, 45.30642807483673, 43.6838885396719, 42.70269758999348, 42.05869674682617, 42.5735767185688, 38.47880244255066, 39.21455696225166, 43.50972108542919, 40.58543600142002, 43.620215356349945, 45.6829384714365, 47.56686978042126, 43.491124883294106, 46.03437781333923, 49.74528148770332, 43.8115768879652, 46.78585588932037, 46.96953423321247, 50.47924630343914, 53.491052091121674, 52.43612229824066, 54.75895665585995, 53.7472989410162, 54.69148747622967, 56.12989269196987, 55.30344843864441, 57.26917415857315, 54.030474945902824, 55.971357598900795, 59.551293700933456, 61.074160784482956, 60.31273864209652, 56.043071150779724, 52.120370641350746, 47.88914568722248, 53.13042864203453, 57.73561432957649, 61.725787818431854, 63.72755840420723, 55.57851567864418, 46.60819262266159, 48.75392608344555, 49.78602670133114, 56.00106060504913, 61.03617422282696, 57.70845338702202, 60.09832754731178, 57.05454267561436, 56.82292990386486, 54.08826984465122, 57.831855565309525, 62.88128301501274, 70.27041211724281, 67.19155892729759, 82.21843779087067, 40.77862523496151, 0.9734834195114672, 0.05320651878719218, 1.4328267588280141, 0.5416691873688251, 31.245012804865837, 79.31937575340271, 62.2263615578413, 69.37683686614037, 36.96142606437206, 32.92217060923576, 55.117106437683105, 49.29136924445629, 31.073535606265068, 53.83762389421463, 72.73286238312721, 36.44404202699661, 0.8246267633512616, 0.07428806959069334, 0.015180187292571645, 0.08404922627960332, 0.06195637681230437, 0.04374041032860987, 0.12335855484707281, 0.2280217714724131, 0.21410451357951388, 0.09852132861851715, 0.3427462396211922, 0.2523407188709825, 0.6013088871259242, 0.3042967856163159, 12.276117168366909, 90.45584097504616, 79.98142182826996, 60.35042881965637, 71.77225112915039, 93.6136919260025, 83.70460644364357, 54.886116832494736, 35.32026372849941, 71.58460959792137, 73.497753739357, 70.2204068005085, 73.24852511286736, 3.4662585519254208, 1.2919577490538359, 0.7610071927774698, 0.18071570520987734, 1.3437183341011405, 0.5516592669300735, 6.766781397163868, 71.51169911026955, 70.82785740494728, 70.02757474780083, 66.54389128088951, 58.61771799623966, 55.4720301926136, 52.35688894987106, 53.65387335419655, 49.60326410830021, 52.32463628053665, 48.33484277129173, 54.77763645350933, 61.61144435405731, 60.59725597500801, 61.783157140016556, 59.091172590851784, 54.289104267954826, 60.081916227936745, 48.62605154514313, 48.80240388214588, 59.93443854153156, 61.63958564400673, 62.72914297878742, 60.76671168208122, 61.041436940431595, 60.307787507772446, 61.72972060739994, 63.14829848706722, 61.424585580825806, 60.29269091784954, 62.50852681696415, 60.86935557425022, 58.89672942459583, 55.46981491148472, 54.67403121292591, 51.496155336499214, 51.699155643582344, 49.49816554784775, 55.0277504324913, 53.09201270341873, 47.17891439795494, 49.43374000489712, 50.82747861742973, 50.43336756527424, 47.29298047721386, 46.446803882718086, 47.22856253385544, 46.35009907186031, 44.57614526152611, 47.8833319991827, 47.048102617263794, 44.017932415008545, 48.007410541176796, 51.93662770092487, 48.78428265452385, 50.63398540019989, 59.3691922724247, 59.977608025074005, 62.62321226298809, 52.23161347210407, 30.92113148421049, 36.02309301495552, 42.84833997488022, 60.70131339132786, 63.19316267967224, 61.05786345899105, 55.87207652628422, 50.39334811270237, 49.10965919494629, 50.886690840125084, 45.21681748330593, 45.33456176519394, 43.934675082564354, 43.794565200805664, 45.0425436347723, 41.527105271816254, 41.8006943911314, 45.69098263978958, 44.32866834104061, 48.109986037015915, 49.28536556661129, 48.72167721390724, 47.50049114227295, 49.64331775903702, 53.6792977899313, 46.10940478742123, 51.08923897147179, 51.35856091976166, 56.19478940963745, 58.57476510107517, 56.71952225267887, 58.504700660705566, 57.28471912443638, 56.97935231029987, 58.428267762064934, 58.73721398413181, 59.3542742729187, 56.88857138156891, 58.8727793097496, 62.98796609044075, 64.73402559757233, 63.239197209477425, 58.42017039656639, 51.769850850105286, 52.732012420892715, 54.133198633790016, 59.923764914274216, 66.56114995479584, 67.57742822170258, 59.529589265584946, 47.97993801534176, 53.291019424796104, 53.60949173569679, 57.99001827836037, 63.66865396499634, 58.702058270573616, 64.12484228610992, 60.6027352809906, 60.348304733633995, 56.58310577273369, 59.422340020537376, 66.33984223008156, 74.38401058316231, 70.19740283489227, 86.4818774163723, 47.70797520875931, 2.1001413697376847, 0.14392446144483984, 1.548279644921422, 2.349319886416197, 34.424552991986275, 86.6085322201252, 68.95202726125717, 74.3273252248764, 45.11881694197655, 39.00292731821537, 58.62094022333622, 70.47764539718628, 40.44110454618931, 62.38005191087723, 80.8952347934246, 49.16293613612652, 0.9021130960900337, 0.27018191933166236, 0.12603114737430587, 0.14723435102496296, 0.19194328633602709, 0.17062040395103395], [0.03734209545655176, 0.03764289904211182, 0.21009200310800225, 0.02731312550167786, 0.03992256519268267, 0.0790148823580239, 0.3342257608892396, 0.1379342016298324, 7.16622831299901, 69.89991679787636, 60.48011586070061, 60.3454776853323, 62.126765102148056, 111.8143580853939, 55.12617275118828, 35.842169523239136, 21.55955482274294, 31.83549351990223, 70.21866649389267, 52.50438183546066, 68.73933747410774, 14.461843483150005, 0.6491102033760399, 0.14894078602083027, 0.06722918391460553, 0.2298183922539465, 0.2678756805835292, 1.0139734530821443, 49.855156391859055, 65.57329416275024, 64.60506051778793, 57.625142857432365, 53.107690662145615, 51.85824930667877, 48.176322877407074, 45.38332834839821, 44.065832644701004, 45.606220588088036, 44.53263759613037, 53.322268947958946, 55.97394905984402, 56.73115722835064, 56.104221269488335, 52.958704456686974, 55.619371086359024, 51.269478499889374, 42.36548088490963, 54.10382620990276, 56.38873480260372, 58.59463423490524, 56.67109005153179, 56.72866076231003, 53.725343719124794, 52.922218814492226, 54.69944424927235, 56.92649334669113, 53.0410498380661, 56.74979142844677, 50.5633319914341, 51.97132743895054, 51.681551188230515, 47.380049005150795, 45.12584276497364, 42.95605659484863, 43.99052828550339, 40.33751830458641, 45.19297756254673, 44.68139201402664, 36.79781824350357, 25.747082121670246, 34.22733597457409, 41.198058128356934, 41.343727111816406, 40.263673067092896, 41.87670551240444, 42.098112031817436, 43.16031463444233, 43.483080714941025, 41.83363102376461, 42.15208053588867, 44.70191091299057, 45.68586431443691, 49.862926974892616, 50.19279107451439, 52.02136695384979, 55.94231195747852, 62.70127907395363, 46.24689660966396, 32.84863315522671, 36.27470791339874, 39.324184879660606, 55.81139378249645, 59.90832634270191, 54.69246782362461, 51.334633603692055, 46.87363877892494, 46.95145480334759, 44.07840996980667, 45.19778050482273, 40.02395153045654, 38.83860893547535, 40.74395589530468, 40.9865652769804, 38.60736094415188, 38.395130932331085, 39.84531171619892, 40.51187574863434, 41.87128320336342, 44.45857957005501, 42.76007451117039, 41.56883843243122, 45.596306920051575, 42.6782763004303, 44.33052644133568, 45.249115750193596, 41.899534687399864, 45.962383076548576, 51.2419755756855, 50.116141587495804, 47.104966565966606, 52.45924025774002, 51.02824464440346, 53.129189908504486, 54.55239214003086, 53.96193042397499, 51.677230820059776, 55.578451082110405, 55.29233783483505, 57.04856179654598, 58.41483548283577, 58.48162069916725, 52.599722519516945, 45.65898455679417, 51.46202176809311, 54.63466912508011, 57.7389657497406, 57.41702802479267, 51.82866409420967, 45.000666081905365, 42.648964673280716, 46.29429146647453, 52.036315351724625, 57.73669347167015, 60.51788203418255, 57.93189659714699, 58.07771757245064, 59.18839417397976, 55.5349700152874, 62.35708974301815, 59.45784151554108, 64.1701890528202, 64.79293003678322, 63.27140808105469, 4.671981353312731, 0.6057000264991075, 0.12254437431693077, 0.24163681198842824, 0.24035819544224069, 36.140259727835655, 67.59346336126328, 61.768930703401566, 61.90716728568077, 34.786768555641174, 20.72446223348379, 46.33039332926273, 45.962588265538216, 30.476131662726402, 42.8328900039196, 60.691475719213486, 37.485714331269264, 0.6534591293893754, 0.11223317487747408, 0.10173199305427261, 0.04561569505312946, 0.09949394283466972, 0.045433011691784486, 0.020484507840592414, 0.02937482473498676, 0.3013274824479595, 0.0770574455964379, 0.062481694913003594, 0.042696342134149745, 0.27490482840221375, 0.033961642475333065, 10.280860383063555, 80.6106148660183, 64.34595242142677, 66.19955375790596, 73.13731268048286, 115.86954608559608, 60.64405806362629, 42.16941520571709, 23.49420391023159, 40.96942059695721, 77.55057826638222, 57.56918705999851, 75.4657593369484, 18.528713956475258, 0.8477441291324794, 2.0192724466323853, 0.07968960591824725, 0.4586370225297287, 0.33556489215698093, 1.6337605705484748, 56.1530714482069, 70.48399865627289, 65.51600843667984, 60.408622696995735, 56.30646541714668, 53.194667994976044, 50.97063973546028, 48.60179744660854, 46.72702744603157, 48.906278908252716, 46.72421179711819, 54.963834062218666, 59.91077721118927, 59.03530418872833, 57.9801882058382, 56.41509398818016, 55.1287642121315, 55.45783035457134, 44.75267618894577, 56.922587156295776, 59.83432911336422, 61.12875245511532, 58.893499597907066, 59.82462823390961, 55.16741193830967, 54.27382908761501, 57.099414467811584, 58.769500851631165, 55.408140420913696, 59.583527371287346, 52.033032327890396, 53.928275629878044, 56.00631572306156, 51.00797653198242, 50.42539179325104, 48.11896875500679, 48.769212663173676, 43.91762539744377, 47.86655969917774, 49.71940487623215, 41.25489927828312, 32.64861188828945, 39.676821157336235, 45.34711629152298, 44.993180483579636, 44.54942129552364, 43.966437578201294, 45.35134166479111, 45.86115650832653, 44.76561449468136, 44.24649015069008, 42.17922627925873, 45.43462559580803, 47.850980535149574, 51.05071663856506, 50.867878049612045, 54.16361600160599, 57.9337964951992, 60.977706760168076, 47.3419788479805, 32.47951336205006, 35.84824159741402, 38.66563081741333, 56.32177099585533, 61.79970525205135, 55.93162313103676, 51.884783282876015, 48.9550568908453, 49.49820354580879, 47.23387844860554, 45.62168575823307, 42.51956641674042, 41.498439610004425, 42.21682146191597, 42.72065542638302, 42.36856631934643, 41.94186441600323, 40.81976182758808, 42.224732637405396, 45.249020755290985, 45.82238718867302, 46.10317312180996, 44.67857636511326, 48.005514442920685, 45.77270485460758, 46.12710803747177, 47.97327697277069, 45.47125943005085, 49.9947153031826, 54.07860316336155, 52.67380714416504, 50.22786319255829, 57.279604598879814, 54.43672634661198, 56.41113840043545, 55.98833128809929, 56.51988856494427, 52.402672693133354, 55.35142086446285, 57.29994110763073, 59.35167521238327, 61.49177357554436, 61.02980576455593, 55.46835198998451, 48.67282323539257, 53.38255271315575, 56.33530206978321, 61.871430203318596, 59.53127257525921, 56.486203372478485, 47.837191075086594, 46.05688400566578, 50.094285160303116, 56.31765581667423, 60.05680337548256, 64.13309544324875, 63.10628034174442, 63.1776937097311, 63.19101579487324, 58.33406321704388, 65.95350936055183, 62.27718763053417, 68.6818465590477, 67.02500626444817, 71.24920159578323, 5.153487240895629, 0.7897729554679245, 0.23856828367570415, 1.2056513177230954, 0.014242656252463348, 41.39913193881512, 74.78513985872269, 67.68299415707588, 68.81256714463234, 43.16542536020279, 32.77107171714306, 49.40337583422661, 55.63574440777302, 27.994387932121754, 50.06810836493969, 66.92851424217224, 49.150841385126114, 1.169375970494002, 0.23516889108577743, 0.03078044315770967, 0.0610169143328676, 0.09516115111182444, 0.026572380484140012, 0.1311929922667332, 0.1528977690031752, 0.5368313344661146, 0.198394805775024, 0.13905744213843718, 0.33783945604227483, 0.43796239129733294, 0.4163280443754047, 13.324925489723682, 89.75252911448479, 77.66422256827354, 68.85073229670525, 73.38469460606575, 112.98545524477959, 66.19124740362167, 52.106923162937164, 34.55894038081169, 48.65482360124588, 82.98039570450783, 62.58124731481075, 82.2000315785408, 19.708964824676514, 1.4902499900199473, 2.5897562596946955, 0.2331673781736754, 0.7824710535351187, 0.7234560046344995, 2.685281471349299, 58.57095010578632, 75.74499875307083, 64.8405110836029, 64.95826676487923, 57.8694773465395, 57.49310374259949, 52.734919264912605, 52.894358709454536, 48.93365643918514, 51.8585304915905, 49.228851199150085, 58.874006643891335, 61.895380318164825, 60.19289307296276, 60.24088069796562, 58.96987549960613, 53.91869634389877, 57.11775988340378, 49.31333966553211, 60.053558349609375, 62.539213970303535, 62.53846921026707, 62.30461075901985, 61.677245423197746, 58.732901215553284, 57.56318338215351, 62.18903996050358, 59.73573200404644, 58.13055753707886, 63.42707812786102, 53.31028439104557, 59.09546636044979, 60.60731403529644, 55.3875645250082, 54.06714677810669, 53.69675025343895, 52.04477749764919, 47.60938189923763, 54.205710142850876, 56.08932986855507, 46.82440102100372, 37.59760692715645, 45.70327877998352, 49.13382589817047, 49.45752292871475, 47.491269037127495, 46.02819174528122, 49.69512037932873, 48.78817364573479, 47.34673619270325, 46.524262726306915, 46.32271774113178, 48.611505925655365, 51.856767386198044, 53.19524176418781, 53.891831785440445, 57.61581435799599, 59.34806540608406, 65.46335846185684, 49.08722139894962, 31.596414148807526, 36.46711438894272, 38.167785331606865, 58.584971353411674, 62.90419578552246, 57.16799698770046, 54.46592777967453, 51.04988068342209, 51.145901530981064, 49.0228034555912, 47.20808543264866, 44.58581194281578, 43.95604133605957, 45.40192075073719, 47.95249208807945, 45.558403953909874, 43.71128506958485, 44.75514605641365, 46.132332757115364, 49.08269204199314, 50.81756494939327, 50.26549257338047, 50.38066819310188, 52.300302386283875, 47.070168033242226, 52.124193236231804, 53.25299106538296, 50.167594626545906, 53.971315920352936, 59.3936363607645, 58.320908322930336, 55.16985520720482, 61.08931057155132, 57.49492384493351, 58.9765365421772, 58.14153514802456, 60.22995248436928, 57.158265709877014, 59.88094501197338, 60.19125156104565, 61.06034092605114, 64.60564568638802, 63.42932380735874, 56.52956284582615, 52.31152318418026, 56.98224015533924, 58.06464247405529, 63.272263035178185, 63.64741310477257, 59.39391754567623, 50.460110530257225, 48.6869128793478, 51.977524906396866, 58.34684193134308, 64.33618694543839, 66.34629428386688, 64.90758508443832, 65.42776197195053, 66.66174575686455, 61.170398220419884, 68.3213447034359, 64.98361900448799, 72.5024351477623, 72.4888850748539, 76.30404755473137, 9.119817484170198, 1.5483103995211422, 0.28797407867386937, 0.9895493136718869, 0.8223525853827596, 44.66907687485218, 79.24534812569618, 73.65092352032661, 74.2933702468872, 50.28987966477871, 31.86332892626524, 65.29411554336548, 67.7926030755043, 40.7421699911356, 61.724872067570686, 77.57700964808464, 61.64059638977051, 1.6442082286812365, 0.3790634439792484, 0.26149166689720005, 0.18711619457462803, 0.34415738889947534, 0.30962029995862395], [0.13983840413857251, 0.05352026542823296, 0.11762518945033662, 0.023985416955838446, 0.026045323902508244, 0.04458722680283245, 0.09430508376681246, 0.08799772651400417, 5.623674960806966, 64.54301744699478, 61.76263824105263, 43.875284269452095, 22.236093319952488, 35.07179506123066, 37.77479901909828, 41.36780641973019, 22.018497996032238, 23.746576867997646, 63.74912604689598, 59.66202735900879, 63.11310477554798, 43.15992325544357, 0.23101810365915298, 1.075371508486569, 0.05738081374147441, 0.05476187478052452, 0.16266116697806865, 0.22747516486560926, 34.9557226896286, 65.49444079399109, 65.55106535553932, 63.11522886157036, 63.421549424529076, 58.435035198926926, 57.550530061125755, 54.37342554330826, 47.74744749069214, 44.90325070917606, 46.71790033578873, 52.470442056655884, 57.490546479821205, 57.631857097148895, 57.276260778307915, 51.65542759001255, 52.90423817932606, 45.97907938063145, 50.37183366715908, 58.88412170112133, 58.23987007141113, 57.15666979551315, 56.62235386669636, 54.91589203476906, 53.07032726705074, 53.871833458542824, 52.38288335502148, 58.779593110084534, 54.90733489394188, 55.66120684146881, 50.721464306116104, 50.556606352329254, 49.810292199254036, 48.08734305202961, 45.49783520400524, 43.334995061159134, 42.92730733752251, 43.266378343105316, 44.17894497513771, 44.58406403660774, 45.57117126882076, 42.23412573337555, 34.41254563629627, 36.220386028289795, 44.65891622006893, 44.060946106910706, 40.95726504921913, 43.2504115998745, 44.57839474081993, 43.9631849527359, 42.1280088275671, 42.49712102115154, 42.48727574944496, 44.48637507855892, 48.47413569688797, 49.8069179803133, 53.841400891542435, 58.43266412615776, 61.99023462831974, 43.783845975995064, 33.86881001293659, 37.28553727269173, 39.2680998891592, 56.41594134271145, 57.94378615915775, 54.44532908499241, 52.042121440172195, 50.48534117639065, 47.89258070290089, 45.71287326514721, 43.19409482181072, 42.53974333405495, 42.69086882472038, 40.10307468473911, 43.7679248303175, 41.418415904045105, 41.40899620950222, 38.41586261987686, 44.43043828010559, 39.04124066233635, 35.51223702728748, 39.05541770160198, 42.9247272759676, 44.17654350399971, 42.39980824291706, 44.37108926475048, 45.57722054421902, 42.32084468007088, 46.574959605932236, 48.16670939326286, 46.95195637643337, 47.854506745934486, 53.36958020925522, 53.20743151009083, 54.01034362614155, 54.55975994467735, 52.726438120007515, 51.875196397304535, 52.1428844332695, 54.45716165006161, 55.598191022872925, 57.615229189395905, 56.84437595307827, 54.2089057713747, 45.254036486148834, 51.07416898012161, 56.36912025511265, 57.49661095440388, 56.18103414773941, 51.79983504116535, 46.55217602849007, 43.52283038198948, 43.24780873954296, 51.10765278339386, 59.06790643930435, 60.223561227321625, 64.01418462395668, 59.782435297966, 60.565341487526894, 61.20612770318985, 64.79226887226105, 66.13756388425827, 66.97791919112206, 66.55347436666489, 33.64796206355095, 2.420072089880705, 0.18211493559647352, 0.08025976829230785, 1.6447252384386957, 0.7590137247461826, 46.95671372115612, 65.07428213953972, 62.27665185928345, 59.169455990195274, 20.327005460858345, 27.032667137682438, 53.93602341413498, 40.52150823175907, 30.796270184218884, 48.01021859049797, 61.133775785565376, 42.661124020814896, 0.994444222887978, 0.17337348981527612, 0.07142999951611273, 0.02167334307159763, 0.031096204729692545, 0.055914834592840634, 0.10515470392419957, 0.03436411658185534, 0.17983640864258632, 0.025041979206434917, 0.0693112495355308, 0.12683272623689845, 0.05067613659775816, 0.07841611761250533, 7.267179396003485, 74.90146681666374, 71.14843860268593, 40.72631724178791, 33.7595658749342, 55.20363539457321, 46.892128586769104, 57.71071046590805, 24.878849610686302, 27.422653511166573, 70.28544411063194, 66.37376680970192, 70.19930273294449, 48.73206585645676, 0.41418139706365764, 0.7173154153861105, 0.02371235485043144, 0.16335644060745835, 0.24737711646594107, 0.08007400872884318, 42.495528906583786, 72.65372782945633, 68.26296463608742, 65.6601195037365, 64.39344227313995, 60.54478079080582, 63.07212397456169, 56.763250306248665, 50.53413435816765, 47.53607243299484, 49.61975522339344, 56.87298841774464, 58.835385516285896, 59.46813516318798, 59.56911474466324, 54.7587438672781, 52.5167615711689, 51.30716107785702, 52.78212413191795, 61.82843931019306, 58.85786511003971, 59.390345737338066, 60.88318683207035, 57.964255660772324, 53.49151186645031, 55.02447880804539, 56.953893676400185, 60.75415715575218, 55.92251881957054, 58.866350054740906, 52.989596799016, 53.13723787665367, 52.90171131491661, 52.4232941865921, 48.884137496352196, 48.17429378628731, 46.295906379818916, 48.645643293857574, 46.17818109691143, 48.98176945745945, 47.628677263855934, 45.81891417503357, 39.49574187397957, 42.55806215107441, 46.93203404545784, 47.89367504417896, 44.468979611992836, 44.14408564567566, 46.31756141781807, 45.084702372550964, 44.55104760825634, 43.175171837210655, 45.02328246831894, 46.60310469567776, 50.16820639371872, 51.690632700920105, 55.89209385216236, 57.99676291644573, 61.959805861115456, 43.66347223520279, 35.21842159330845, 37.692050859332085, 38.3998616784811, 56.768361032009125, 60.88324382901192, 56.16813383996487, 55.55807277560234, 49.64429430663586, 50.73897376656532, 46.720548793673515, 43.75141851603985, 43.337825909256935, 45.05891315639019, 39.855278581380844, 46.79304130375385, 42.45070271193981, 42.074332907795906, 41.10177889466286, 45.58986246585846, 41.29035137593746, 40.17014868557453, 43.05110089480877, 46.02313041687012, 47.67236731946468, 48.46637651324272, 46.1568908393383, 48.36040019989014, 47.4337325245142, 51.98376037180424, 49.805987030267715, 50.35276249051094, 52.12763965129852, 55.419775396585464, 56.68918468058109, 56.37360401451588, 58.08453820645809, 56.38298571109772, 53.833090737462044, 51.985474079847336, 57.2346606105566, 59.11543428897858, 58.999008536338806, 60.60425139963627, 56.8691848218441, 49.064567014575005, 52.35238239169121, 56.87279462814331, 58.74583192169666, 57.97796532511711, 55.68044140934944, 48.75389188528061, 47.6724661141634, 45.82521803677082, 53.62435653805733, 61.18795707821846, 65.92479810118675, 67.30166181921959, 61.50919184088707, 64.2111736536026, 63.53007160127163, 66.04795709252357, 70.98337545990944, 73.3051572740078, 72.20770016312599, 41.451078951358795, 4.155395273119211, 0.1426181776332669, 0.08905732785933651, 2.2383967135101557, 0.7679996488150209, 57.22937889397144, 69.40440058708191, 71.45418539643288, 62.230146154761314, 29.73563689738512, 25.09369198232889, 56.27202786505222, 52.85383768379688, 33.29534098505974, 57.82222308218479, 67.7715066075325, 55.95637120306492, 1.9758962304331362, 0.24071237799944356, 0.060648066937574185, 0.008243643733294448, 0.14302153489552438, 0.059947735571768135, 0.20736904843943194, 0.14228030748199672, 0.2517428150167689, 0.22768715192796662, 0.20490682509262115, 0.15747729514259845, 0.3669229766819626, 0.27193071611691266, 8.58517287299037, 85.83217307925224, 79.76549461483955, 57.45479039847851, 34.11490000784397, 49.334470331668854, 54.95495393872261, 53.25308606028557, 32.31395244598389, 39.02044057846069, 75.91177180409431, 72.3936165869236, 77.22631126642227, 53.92387166619301, 1.3008395349606872, 4.580790046602488, 0.24111339007504284, 0.4729008337017149, 0.6337640143465251, 0.4263763380004093, 45.73114648461342, 76.7462146282196, 70.43194904923439, 68.53434607386589, 69.68657344579697, 62.55244106054306, 66.14128768444061, 59.236058816313744, 53.43378536403179, 50.74875824153423, 52.816375494003296, 59.94928054511547, 61.21428206562996, 60.21370455622673, 61.56270056962967, 56.113998144865036, 51.74454040825367, 52.69606254994869, 55.22700794041157, 64.92976069450378, 61.59667454659939, 62.121164202690125, 62.39637203514576, 59.2186975479126, 58.04189309477806, 57.286269441246986, 58.41141186654568, 65.0130446255207, 59.38131362199783, 61.01832278072834, 57.56187245249748, 58.31183820962906, 57.85989046096802, 56.48863524198532, 55.747443214058876, 52.7357742190361, 50.23275353014469, 53.165736347436905, 50.98048500716686, 52.5074178725481, 54.334131851792336, 50.65669298171997, 45.52698723971844, 47.4721522629261, 51.77632190287113, 53.36882404983044, 48.719123750925064, 47.63536490499973, 50.22663585841656, 47.430856078863144, 46.85248151421547, 47.688626646995544, 48.501281440258026, 48.95019695162773, 52.10577942430973, 53.133305087685585, 58.19702737033367, 63.02472911775112, 64.3152728676796, 43.355802744627, 34.70663845539093, 37.65242658555508, 37.90458865463734, 59.3927776068449, 62.558353543281555, 58.49328227341175, 57.45245732367039, 52.754651606082916, 51.745178773999214, 50.64802184700966, 45.72402186691761, 47.04256631433964, 47.573701813817024, 43.3062420040369, 47.2969588637352, 46.43984645605087, 46.85235232114792, 46.9381745159626, 50.90382032096386, 48.00870627164841, 45.29289320111275, 47.847902700304985, 51.07737600803375, 51.068613678216934, 51.97519563138485, 49.68419596552849, 52.89374314248562, 51.91420890390873, 54.595006853342056, 54.57688942551613, 55.0449825078249, 57.54406280815601, 60.44711083173752, 59.06581275165081, 59.01429891586304, 59.55880589783192, 60.317347794771194, 56.83283977210522, 55.914436653256416, 60.553337931632996, 62.659557312726974, 62.99820654094219, 63.164740204811096, 58.04379299283028, 53.274991884827614, 56.50666907429695, 59.67737093567848, 61.7829367518425, 59.96994003653526, 59.37534034252167, 51.87171198427677, 49.6027397364378, 47.46707573533058, 56.70586198568344, 64.11824584007263, 68.91094386577606, 70.2003438770771, 65.96455156803131, 67.5187061727047, 70.4172970354557, 71.25822231173515, 74.44406256079674, 74.17539417743683, 76.10374510288239, 46.96793831884861, 6.20536532253027, 0.6220038828905672, 0.18649025238119066, 3.9544948283582926, 2.154894294217229, 59.223918467760086, 79.92361932992935, 76.2629109621048, 73.63235011696815, 36.40521191060543, 40.55079326033592, 76.0133783519268, 61.06085769832134, 37.46727392077446, 68.10866251587868, 78.55044901371002, 70.32547116279602, 3.079248368740082, 0.28079347335733473, 0.12712504336377606, 0.07902487908722833, 0.23700820020167157, 0.08656570062157698], [0.027866391028510407, 0.058032616070704535, 0.07246565917739645, 0.04567898540699389, 0.051399700896581635, 0.03349846811033785, 0.07033915375359356, 0.11027926331735216, 2.066642129793763, 59.73147623240948, 59.539141952991486, 73.40633064508438, 26.53509333729744, 14.96682308614254, 34.68819424510002, 38.072798028588295, 9.82397859916091, 25.92469409108162, 57.05360792577267, 67.15201064944267, 55.77785298228264, 61.094732880592346, 3.043770147487521, 2.3234207136556506, 0.27130060305353254, 0.06537850509630516, 0.602159685222432, 0.2584334841230884, 14.942222256213427, 68.57656940817833, 63.77826288342476, 63.185327500104904, 63.47495935857296, 64.47836771607399, 63.518379628658295, 58.940628468990326, 55.51487669348717, 43.2266628742218, 46.39583721756935, 51.45909212529659, 53.42883042991161, 57.73695185780525, 58.6530826985836, 58.47780950367451, 50.29761224985123, 48.35742495954037, 59.080267176032066, 56.774980276823044, 58.88737052679062, 55.26553027331829, 56.42262898385525, 52.69512020051479, 51.605498269200325, 52.70800530910492, 51.86986528337002, 55.61396397650242, 55.05212612450123, 53.21696139872074, 55.106250420212746, 49.48431149125099, 47.71298334002495, 53.97576168179512, 46.777864918112755, 44.30065244436264, 42.7179803699255, 44.80756804347038, 44.534484297037125, 43.63804779946804, 44.45555493235588, 37.71047607064247, 31.979767978191376, 37.50490330159664, 42.58587285876274, 42.323500737547874, 43.863820284605026, 44.79535169899464, 45.74183911085129, 45.423260405659676, 43.14455687999725, 41.46937496960163, 42.36673481762409, 45.08757121860981, 50.665048733353615, 51.3268706202507, 52.602465972304344, 60.85545971989632, 61.13860532641411, 45.80343760550022, 37.39651791751385, 41.16408795118332, 42.17925287783146, 55.33217869699001, 59.128596782684326, 56.815619096159935, 55.923894345760345, 51.97747930884361, 51.00326098501682, 44.54193949699402, 42.37127557396889, 42.19852164387703, 41.28908984363079, 42.05792538821697, 37.55791425704956, 32.392783015966415, 34.58882957696915, 37.35774479806423, 44.79755938053131, 36.55930504202843, 38.415805622935295, 41.61606229841709, 44.90011967718601, 41.1119319498539, 44.504317715764046, 48.488555923104286, 45.34069463610649, 44.55458141863346, 48.031368255615234, 50.01830443739891, 49.5873049646616, 49.76746089756489, 51.1061442643404, 51.90324269235134, 54.52451303601265, 54.377445727586746, 49.69524957239628, 51.370743066072464, 49.59038659930229, 51.985147297382355, 52.02313385903835, 54.96469661593437, 55.91650754213333, 57.82575309276581, 50.36055587232113, 54.55601714551449, 54.380987137556076, 56.5511304885149, 52.26377494633198, 53.944740146398544, 42.527272403240204, 45.01748777925968, 41.45256847143173, 49.573393911123276, 55.86948126554489, 61.37402169406414, 61.07000760734081, 62.97115959227085, 63.53453256189823, 61.29712142050266, 66.26757770776749, 64.65443506836891, 60.39222277700901, 52.46270567178726, 15.149953309446573, 2.33619277831167, 0.04560605084407143, 0.4837354179471731, 1.3155189785175025, 2.154780300334096, 59.32627357542515, 58.850698694586754, 63.76281291246414, 35.97097501158714, 11.034172810614109, 32.33803175389767, 39.73932020366192, 52.00743690133095, 26.84116881340742, 43.55743892490864, 59.91634391248226, 55.341742783784866, 1.9643645617179573, 0.10362480359617621, 0.14320572110591456, 0.032447932098875754, 0.05551110996748321, 0.03710055236297194, 0.10281958820996806, 0.03191161165887024, 0.07410697813611478, 0.11606755506363697, 0.026946942416543607, 0.046613531158072874, 0.16223622806137428, 0.02215808053733781, 2.5829743361100554, 70.00599190592766, 66.3597759604454, 68.78074005246162, 31.841140016913414, 23.20991836488247, 39.02398958802223, 50.99801726639271, 15.024802275002003, 29.522567130625248, 63.228238597512245, 71.40080586075783, 61.701659113168716, 66.26905962824821, 4.62043521925807, 1.1375260795466602, 0.3463838913012296, 0.0507274078699993, 0.9907725511584431, 0.3758843505056575, 18.47049918025732, 73.96237760782242, 67.38282546401024, 65.65329506993294, 63.98447781801224, 67.21989020705223, 66.7671824991703, 62.6307662576437, 55.972033962607384, 46.20959021151066, 48.44186782836914, 54.113397896289825, 55.04494071006775, 58.82329076528549, 60.55182561278343, 58.12674634158611, 51.89630426466465, 52.21069559454918, 57.93472744524479, 60.32230272889137, 60.077379271388054, 58.56618516147137, 59.3155163526535, 55.50039567053318, 53.29473562538624, 54.22911688685417, 55.76994560658932, 59.27279144525528, 56.21649384498596, 56.97945490479469, 59.33018356561661, 56.12993448972702, 50.42308911681175, 57.64816962182522, 52.898378893733025, 47.18594782054424, 47.0280434936285, 48.85574921965599, 48.54852430522442, 46.66259430348873, 48.06294456124306, 43.1581449508667, 36.58710055053234, 42.28677950799465, 46.73249155282974, 43.76198194921017, 47.258083149790764, 45.84544435143471, 46.263258531689644, 48.21775205433369, 47.10765302181244, 43.338399678468704, 47.19190210103989, 48.85433949530125, 51.63905046880245, 52.2733960300684, 53.816618621349335, 60.2078490704298, 60.60468837618828, 44.75138805806637, 36.42615258693695, 40.85173711180687, 42.28473141789436, 56.34724862873554, 62.0919019728899, 57.62358874082565, 57.696119248867035, 54.371871426701546, 51.14177495241165, 47.2738903015852, 42.9697472602129, 43.9690138399601, 44.78833727538586, 44.30502600967884, 40.43410152196884, 36.54594875872135, 38.08816060423851, 43.25900673866272, 47.48324766755104, 40.541183575987816, 43.22800040245056, 45.035472214221954, 49.53730344772339, 43.09532672166824, 48.38765233755112, 49.90242585539818, 48.8860259950161, 48.51079612970352, 51.20932012796402, 53.93476568162441, 52.03900560736656, 53.011924400925636, 53.808137476444244, 54.76512752473354, 56.503063067793846, 56.90992623567581, 52.497059628367424, 55.143553018569946, 52.06308491528034, 54.77498039603233, 55.508519634604454, 58.454018980264664, 59.53680507838726, 59.87896151840687, 54.47359956800938, 56.185403913259506, 56.285817325115204, 59.95369590818882, 56.3428408652544, 56.68263763189316, 45.08831597864628, 47.782037034630775, 45.383643731474876, 51.40752889215946, 57.936798334121704, 66.22166857123375, 62.45444051921368, 65.4110124707222, 66.78705543279648, 63.7683530151844, 71.9255805015564, 66.80382773280144, 62.76801869273186, 57.02698275446892, 17.024289183318615, 2.462389231659472, 0.03617922055127565, 0.5690539022907615, 3.2790428353473544, 2.7675556065514684, 66.05437114834785, 64.91866528987885, 70.79759582877159, 40.14999456703663, 15.400686655193567, 22.806564308702946, 41.88439629971981, 62.08019480109215, 21.34480744600296, 50.75013376772404, 67.41375580430031, 65.28374969959259, 2.820401983335614, 0.04860505476244725, 0.153182516223751, 0.08576035164878704, 0.10143543084268458, 0.012001158756902441, 0.22126533323898911, 0.14256239781389013, 0.28643646743148565, 0.19821713562123477, 0.16726493166061118, 0.16149841452715918, 0.33468921727035195, 0.29248529754113406, 2.9949380178004503, 78.1326462328434, 76.26089707016945, 92.77433216571808, 37.971206679940224, 26.24116960912943, 50.56434653699398, 49.702621176838875, 17.40830797702074, 39.926574155688286, 67.83481121063232, 78.31166222691536, 68.29163789749146, 72.94967114925385, 4.836551947519183, 5.657192012295127, 1.3650854188017547, 0.33889416663441807, 1.9978843443095684, 0.43139987625181675, 20.34441612660885, 79.0769411623478, 71.03081211447716, 68.27381685376167, 67.6096884906292, 70.7862800359726, 70.04965156316757, 66.33925706148148, 61.093805730342865, 49.405344128608704, 52.36627444624901, 59.55811433494091, 59.23374094069004, 59.818966537714005, 63.15027818083763, 57.93172940611839, 52.47282072901726, 54.48556512594223, 61.73729360103607, 63.24919067323208, 61.52694448828697, 59.40766140818596, 62.68569990992546, 58.26484993100166, 55.00226899981499, 56.64927922189236, 58.70644323527813, 61.98243364691734, 57.316914796829224, 60.0286278873682, 62.88507141172886, 59.06990893185139, 54.83133137226105, 62.481905445456505, 56.74623481929302, 52.590770199894905, 50.35433940589428, 52.71641045808792, 54.409611001610756, 49.47082221508026, 51.516856625676155, 48.19162465631962, 42.508296221494675, 48.22485387325287, 51.640065014362335, 48.698707446455956, 51.64606109261513, 50.77117323875427, 51.16791754961014, 50.61988815665245, 49.767107516527176, 47.95660346746445, 51.118136420845985, 49.65637385845184, 56.19624853134155, 55.95020793378353, 56.71856090426445, 64.62360352277756, 63.763854056596756, 47.49245837330818, 35.47513201832771, 42.15224012732506, 44.08582717180252, 57.39203676581383, 63.89249995350838, 60.14783889055252, 59.89041030406952, 56.65706880390644, 55.71909673511982, 48.52944552898407, 46.95620834827423, 46.0277433693409, 47.51097097992897, 48.03255759179592, 46.13661892712116, 43.66578631103039, 43.52975741028786, 45.907517820596695, 51.517954766750336, 45.799539014697075, 47.82250866293907, 50.33298075199127, 53.718431890010834, 47.27659575641155, 50.99665313959122, 52.32405871152878, 52.67309658229351, 52.47493341565132, 58.011677116155624, 58.29174488782883, 59.16111543774605, 56.170508712530136, 56.34993128478527, 59.400145411491394, 61.61647528409958, 58.989668637514114, 54.69303399324417, 56.94508194923401, 52.81756483018398, 58.323590978980064, 58.98286700248718, 60.42157620191574, 63.06102097034454, 65.52838817238808, 58.4868910163641, 58.5819923132658, 59.68181669712067, 62.27080017328262, 58.99820677936077, 61.060481518507004, 48.603051379323006, 51.77229031920433, 47.99188457429409, 54.823895171284676, 62.480773106217384, 69.83690097928047, 65.0892761349678, 69.19843643903732, 71.05984255671501, 68.06596040725708, 70.55547282099724, 69.95566740632057, 71.78466886281967, 62.42895908653736, 21.24892719089985, 4.6628219448029995, 0.21247676108032465, 0.626444835215807, 5.691526019945741, 2.791933910921216, 73.70971396565437, 73.86397048830986, 76.1761312186718, 50.225305929780006, 25.190715976059437, 43.957675248384476, 56.76591016352177, 74.57918331027031, 33.730144053697586, 63.83391469717026, 76.60388186573982, 78.39303106069565, 4.31775058619678, 0.4353089164942503, 0.20286110986489803, 0.1344774558674544, 0.1327897229930386, 0.1872178094345145], [0.06085322253056802, 0.031671371034462936, 0.02050214126938954, 0.04117239383049309, 0.03038764109078329, 0.022432806908909697, 0.05182582353882026, 0.17063125415006652, 0.5111045180819929, 47.49516382813454, 67.85815715789795, 47.937308102846146, 31.71972133219242, 29.01795420795679, 35.66864423453808, 57.27421648800373, 7.501514721661806, 30.99617175757885, 57.382164895534515, 66.44082561135292, 54.85014796257019, 63.99880304932594, 15.497873090207577, 0.6371079536620528, 0.17229789518751204, 0.2382160455454141, 0.17795534629840404, 0.3545883932383731, 2.7086476050317287, 51.3953847438097, 64.02198940515518, 67.53674000501633, 62.2563723474741, 65.30043840408325, 62.516745775938034, 62.12571255862713, 58.69085267186165, 48.65014985203743, 47.064559534192085, 48.98513987660408, 54.839527532458305, 55.23853652179241, 62.1673659235239, 54.918643087148666, 47.45467320084572, 52.28779345750809, 57.60319523513317, 58.465038388967514, 58.253017365932465, 54.773027300834656, 55.09778447449207, 52.332099080085754, 51.76526449620724, 51.10351100564003, 52.78009504079819, 56.58698156476021, 56.81051217019558, 51.86738021671772, 54.648052006959915, 51.960828602313995, 53.350824415683746, 52.70307317376137, 52.49313063919544, 46.95818804204464, 45.34776605665684, 43.85078698396683, 46.47781401872635, 43.67869421839714, 41.948935836553574, 49.801906049251556, 38.61368380486965, 34.14722487330437, 41.74213573336601, 42.750742211937904, 41.279138177633286, 42.29537844657898, 45.086039900779724, 41.58730924129486, 48.334056213498116, 46.665109768509865, 45.46088598668575, 48.4232260286808, 49.380922839045525, 49.341674745082855, 52.8541948646307, 51.56767129898071, 58.275261372327805, 48.01876053214073, 39.51983258128166, 43.68185564875603, 40.23645132780075, 60.64905099570751, 53.37789796292782, 53.514857813715935, 51.614313796162605, 54.988084360957146, 49.806123822927475, 45.521298944950104, 42.991337701678276, 43.059004470705986, 43.10247413814068, 45.982841178774834, 32.1292519569397, 28.182854019105434, 33.211772069334984, 31.377264708280563, 37.363535687327385, 41.4032357186079, 40.634001195430756, 44.40005511045456, 42.69154518842697, 42.15549275279045, 46.68556027114391, 49.171079099178314, 41.49744786322117, 41.547726765275, 46.58017672598362, 49.69495318830013, 48.728729635477066, 51.15338712930679, 52.596481293439865, 53.162521719932556, 55.280258283019066, 51.70258305966854, 49.505529552698135, 52.19904541969299, 52.50221215188503, 50.66317543387413, 54.802688509225845, 54.99037563800812, 55.03853805363178, 55.0671923160553, 54.87340651452541, 57.111691609025, 53.88910353183746, 57.90591359138489, 54.19842593371868, 52.18201473355293, 46.57263033092022, 43.43852810561657, 44.592256397008896, 44.165227711200714, 49.83682997524738, 60.20171619951725, 57.76994928717613, 63.381313383579254, 59.229500368237495, 62.06939958035946, 57.97278620302677, 71.01068839430809, 62.19605818390846, 45.64112551510334, 7.500577121973038, 0.6066198740154505, 0.057131734138238244, 1.4039865438826382, 1.8948564352467656, 11.47804219275713, 67.01119780540466, 52.32734553515911, 62.86277040839195, 33.58438767492771, 16.860331781208515, 23.313861787319183, 45.12976795434952, 43.40261623263359, 51.7757785320282, 55.3204221278429, 52.34883338212967, 52.669832557439804, 0.5247521388810128, 0.19813923980109394, 0.06351812640787102, 0.03206203386071138, 0.03696868756378535, 0.08865808951668441, 0.11082859360612929, 0.05701301277440507, 0.011765653962356737, 0.015269734831235837, 0.04975720563379582, 0.08097749931039289, 0.037781302162329666, 0.24768534523900598, 0.5116265150718391, 53.36243659257889, 73.83155062794685, 50.92777423560619, 33.41989450156689, 32.27959468960762, 48.433854058384895, 53.1878549605608, 12.662630528211594, 34.60896849632263, 64.73534032702446, 74.3689937889576, 61.808061003685, 70.42245715856552, 17.639479972422123, 0.5500241671688855, 0.3013064054539427, 0.11072478941059671, 0.6572713342029601, 0.40121405851095915, 4.300835793837905, 57.66788676381111, 66.43434315919876, 70.67233934998512, 65.3142848610878, 68.70887070894241, 65.14774739742279, 65.60940742492676, 59.81941871345043, 50.89609153568745, 48.58302265405655, 52.40295767784119, 56.398591473698616, 58.35462011396885, 64.31717276573181, 54.44736957550049, 48.717615231871605, 55.385398641228676, 59.6080968528986, 59.601268619298935, 59.6471131592989, 56.056499630212784, 57.0942809432745, 54.23588812351227, 53.49460870027542, 54.40652556717396, 54.405442625284195, 57.60541811585426, 59.50472339987755, 55.43116718530655, 58.64155411720276, 54.703996405005455, 54.64310847222805, 55.18316209316254, 54.87293154001236, 49.395449459552765, 49.543071538209915, 47.71509602665901, 50.33295415341854, 46.242576241493225, 44.55445982515812, 52.07975082099438, 42.55960486829281, 39.29474785923958, 45.772210881114006, 45.052502900362015, 45.92617101967335, 47.62444049119949, 47.48347565531731, 46.387933641672134, 50.21694637835026, 50.25463655591011, 47.4597155302763, 50.03483735024929, 51.07466295361519, 51.08198896050453, 55.01017637550831, 52.527503594756126, 58.28924082219601, 47.610464841127396, 38.880083709955215, 45.18407464027405, 39.04632478952408, 60.76858498156071, 55.81449821591377, 54.852245450019836, 55.62855899333954, 57.602659463882446, 53.31180810928345, 46.537280827760696, 44.845387414097786, 45.4608403891325, 44.6355664730072, 47.44478613138199, 35.843773037195206, 34.38870191574097, 38.697484508156776, 35.54330416023731, 40.45006066560745, 44.914699494838715, 45.57711035013199, 46.70807026326656, 44.54099714756012, 46.40662103891373, 48.43112200498581, 50.77909201383591, 47.21473507583141, 47.27691113948822, 52.878543958067894, 53.99027310311794, 52.95317195355892, 55.92837430536747, 55.179457291960716, 55.44232338666916, 56.463966965675354, 54.45602171123028, 53.31674784421921, 53.66032540798187, 53.38222973048687, 52.40764282643795, 57.74842344224453, 56.75092376768589, 58.380386531353, 56.844372153282166, 56.626073867082596, 59.89033430814743, 56.16357408463955, 58.97548779845238, 57.34490409493446, 55.78060783445835, 50.94462253153324, 46.66666768491268, 47.68210619688034, 45.38748152554035, 53.2877553999424, 65.04421055316925, 61.0938361287117, 65.96165612339973, 62.31753766536713, 63.61207500100136, 63.43921087682247, 82.68211171030998, 66.69075340032578, 49.932075664401054, 10.286114551126957, 1.1506813298910856, 0.04409140536154155, 1.481942804530263, 1.4643157878890634, 15.582798533141613, 76.37247428297997, 58.81955936551094, 68.30733105540276, 39.14525248110294, 20.229324102401733, 21.395312435925007, 47.64121279120445, 55.51416993141174, 42.3588502407074, 59.70136284828186, 59.98605117201805, 62.15984232723713, 1.0424761986359954, 0.06435150629840791, 0.052042356255697086, 0.0597085413755849, 0.031784715538378805, 0.07583965547382832, 0.19576405553380027, 0.2157781011192128, 0.19695710245287046, 0.22865973645821214, 0.22906457801582292, 0.1293593383161351, 0.16766367276431993, 0.32193324237596244, 0.8190944383386523, 63.75981867313385, 85.2202919125557, 63.508226573467255, 43.61280955374241, 41.162070259451866, 58.496390506625175, 65.80404058098793, 15.854828786104918, 42.3437612503767, 69.87152472138405, 80.51614433526993, 66.1953815817833, 78.13225105404854, 20.034109577536583, 1.0429954645223916, 1.2082692584954202, 0.23267428041435778, 1.1763247288763523, 0.6538340623956174, 5.618849219754338, 60.2250849455595, 70.45823603868484, 71.92212268710136, 67.40936324000359, 70.02907186746597, 67.17378348112106, 68.24122980237007, 63.34472894668579, 54.08529460430145, 51.426877453923225, 55.97937136888504, 61.023273915052414, 60.177811682224274, 67.8862376511097, 56.04248218238354, 50.71856506168842, 58.42520132660866, 61.469502970576286, 63.97632345557213, 63.808653652668, 59.97320406138897, 60.958437994122505, 57.24761791527271, 55.43277829885483, 55.579188242554665, 56.02157570421696, 62.124774008989334, 62.66217537224293, 58.04476574063301, 61.41039714217186, 59.82620894908905, 58.65646071732044, 60.78875809907913, 60.75467772781849, 54.98059116303921, 55.620632618665695, 54.451199769973755, 55.00703014433384, 49.21103395521641, 48.418985456228256, 57.0311663299799, 50.28948828577995, 45.14538511633873, 49.49785016477108, 48.96802939474583, 48.98111589252949, 51.39745183289051, 53.45629155635834, 48.56174759566784, 54.81129124760628, 53.87986622750759, 52.93953828513622, 53.52455109357834, 55.28889141976833, 54.35542210936546, 55.54941684007645, 52.6727470010519, 60.9271314740181, 47.53680199384689, 39.0247343480587, 44.94469128549099, 39.18427638709545, 62.08061657845974, 57.12070852518082, 57.875443026423454, 58.37526060640812, 60.61014488339424, 55.46862557530403, 49.271530508995056, 48.566307350993156, 46.14160045981407, 46.891513019800186, 51.65530979633331, 41.54245264828205, 36.91201351583004, 45.20067594945431, 43.924582824110985, 47.48085759580135, 51.36183634400368, 49.01565983891487, 51.35436974465847, 49.32288475334644, 49.6666257083416, 52.87040859460831, 55.28598077595234, 50.41470296680927, 50.88341161608696, 57.25666143000126, 57.83961854875088, 58.275595754384995, 61.04991428554058, 57.86894917488098, 58.69106166064739, 60.952787697315216, 55.92010974884033, 54.08595956861973, 55.352401211857796, 56.57957576215267, 53.702731132507324, 60.62102369964123, 59.38269294798374, 62.23238803446293, 60.84323197603226, 60.467473939061165, 63.0855942517519, 59.38355550169945, 63.71781572699547, 61.34850226342678, 59.31734025478363, 51.65407486259937, 50.27569502592087, 51.78193800151348, 49.143690168857574, 55.21011024713516, 69.72337827086449, 62.163474932312965, 70.9917502105236, 64.35392439365387, 65.55177971720695, 64.0654818713665, 74.52542379498482, 65.69563239812851, 60.04910498857498, 13.3808071911335, 2.8244694275781512, 0.13978755217976868, 2.511055120266974, 6.320054568350315, 14.541294369846582, 85.72159141302109, 62.34168156981468, 74.4062165915966, 46.141748651862144, 28.766989074647427, 32.555342093110085, 60.58169960975647, 65.7788023352623, 65.60989379882812, 77.52059027552605, 68.75727251172066, 75.23990705609322, 2.5505502009764314, 0.2547309984220192, 0.1958614549948834, 0.1080067477596458, 0.24497629841789603, 0.1469514740165323], [0.03923470190784428, 0.011783774425566662, 0.043094953362015076, 0.24028651881963015, 0.03149894044327084, 0.15634887444321066, 0.14529566833516583, 0.42730345856398344, 0.4987530433572829, 33.13434362411499, 68.11796441674232, 54.75610300898552, 44.20358665287495, 31.849681958556175, 37.73160673677921, 76.42697855830193, 9.87153209745884, 22.534232921898365, 63.73289331793785, 63.621255308389664, 62.66397647559643, 55.34325510263443, 36.142471209168434, 0.12368072857498191, 0.12237442249897867, 0.06342439315631054, 0.47988099977374077, 0.2137551995110698, 0.8276042598299682, 29.17319107800722, 59.11439694464207, 61.18923380970955, 63.63795921206474, 63.521879240870476, 64.48002442717552, 60.97450353205204, 58.105722069740295, 44.86965671181679, 46.03927955031395, 46.764102056622505, 51.45126074552536, 54.46159601211548, 56.06798641383648, 57.81463868916035, 47.46353432536125, 53.7610200047493, 63.42175081372261, 58.25847007334232, 59.53920654952526, 57.45742745697498, 56.509382128715515, 53.74373473227024, 54.144294038414955, 49.502451717853546, 52.736461982131004, 54.02034088969231, 57.98667065799236, 53.26548859477043, 55.76859287917614, 50.91098673641682, 51.44123688340187, 48.88220340013504, 49.882613718509674, 48.407339081168175, 44.01477858424187, 41.87792144715786, 45.82997918128967, 45.39358779788017, 33.328687995672226, 36.107604280114174, 39.944254606962204, 37.35755480825901, 42.7825541049242, 42.59051240980625, 43.32959175109863, 45.971179604530334, 47.40584962069988, 48.259519413113594, 47.47585326433182, 48.10053214430809, 49.909231290221214, 49.74477231502533, 49.538990557193756, 51.463252902030945, 52.56424002349377, 45.425711274147034, 52.207689955830574, 52.67341956496239, 39.44492720067501, 36.14293098449707, 43.304596692323685, 60.526412576437, 46.2266056984663, 52.41236977279186, 56.04155123233795, 49.68750938773155, 52.53574535250664, 47.34917186200619, 46.236728355288506, 42.43752881884575, 42.845851108431816, 42.12135538458824, 45.05358964204788, 42.15711146593094, 30.049108676612377, 21.467455364763737, 21.343097537755966, 35.122332349419594, 44.606053456664085, 44.230914786458015, 43.06042939424515, 45.06171740591526, 43.95421363413334, 45.29872588813305, 43.979113698005676, 48.205881491303444, 48.430210053920746, 52.37773843109608, 51.291654109954834, 51.8358039110899, 52.32521004974842, 53.239972963929176, 56.32931359112263, 50.636466667056084, 48.19919764995575, 49.441309198737144, 51.40000529587269, 55.07151648402214, 53.569491282105446, 56.79507739841938, 56.680661737918854, 53.55921283364296, 57.19089835882187, 57.76616849005222, 57.894704192876816, 57.34121449291706, 55.173077434301376, 52.840154618024826, 48.66073228418827, 43.38750824332237, 45.89249722659588, 44.82068873941898, 46.81740939617157, 55.58087915182114, 60.10764844715595, 58.733923360705376, 62.34729766845703, 63.94866853952408, 57.18051351606846, 40.60430958867073, 50.54178714752197, 29.657750576734543, 8.79863116890192, 0.3518418234307319, 0.09197507402859628, 0.7752944261301309, 2.3561538197100163, 32.76006370782852, 72.52458035945892, 56.12097077071667, 63.14883425831795, 44.51903432607651, 38.93852077424526, 21.404040567576885, 30.678104124963284, 44.375276640057564, 40.14279015362263, 54.43462125957012, 55.85658855736256, 51.789856776595116, 1.343609089963138, 0.12662887311307713, 0.047083110257517546, 0.1336636018822901, 0.10187782507273369, 0.11929790867725387, 0.06797362482757308, 0.0194288844068069, 0.006040322778062546, 0.17286041344050318, 0.01458769926102832, 0.13575206481618807, 0.10113774798810482, 0.42561073845718056, 0.5122537189163268, 36.69564172625542, 77.6792773604393, 60.39854943752289, 44.62662935256958, 27.67274659126997, 55.295465067029, 73.94132673740387, 10.881155021488667, 28.676667921245098, 70.58151662349701, 72.81907215714455, 66.39937743544579, 62.855603992938995, 40.379730239510536, 0.07224766814033501, 0.16869283863343298, 0.03120771056273952, 0.8704711846075952, 0.22010324872098863, 0.8674045710358769, 33.0022057145834, 63.27900767326355, 63.06096017360687, 65.56976035237312, 64.32210490107536, 67.236328125, 61.91720254719257, 60.29946215450764, 48.542262241244316, 46.27709358930588, 48.82653258740902, 53.824723586440086, 55.76844088733196, 59.87903751432896, 56.94252088665962, 46.3232497125864, 56.24974586069584, 63.74210022389889, 59.88677389919758, 60.57952232658863, 57.68825747072697, 57.97217443585396, 56.73968017101288, 56.32153540849686, 52.384604662656784, 54.61316607892513, 56.2660051882267, 60.35237431526184, 56.52119189500809, 58.341780602931976, 55.69625236093998, 54.83436360955238, 51.32005758583546, 52.00400948524475, 50.893355682492256, 48.31126503646374, 47.8506575524807, 49.51065927743912, 49.813233241438866, 37.00204208493233, 40.93769229948521, 44.2861258238554, 42.5247835367918, 47.18285858631134, 47.2564872354269, 47.27683134377003, 46.96785092353821, 51.283028572797775, 52.70610921084881, 50.30776150524616, 50.590299144387245, 53.86294573545456, 53.051411882042885, 51.02577097713947, 51.839592307806015, 53.26662853360176, 45.76485827565193, 52.75449201464653, 53.79356145858765, 38.13998602330685, 35.485665053129196, 40.694995522499084, 58.48345220088959, 46.80515505373478, 53.5528139770031, 57.4604444950819, 53.33454228937626, 54.86239850521088, 48.132959604263306, 46.304858699440956, 45.978254824876785, 45.43654829263687, 44.45904694497585, 47.128445506095886, 44.40462626516819, 34.86817918717861, 27.968378327786922, 25.307939685881138, 39.33041654527187, 48.88953700661659, 46.109678372740746, 46.16210035979748, 47.910500541329384, 49.18198451399803, 47.976392805576324, 48.43721307814121, 52.02861316502094, 51.973246335983276, 55.00290736556053, 53.87865029275417, 56.35151579976082, 55.14518693089485, 55.99272385239601, 58.22805270552635, 54.2879681289196, 51.55985891819, 51.99612870812416, 55.593509674072266, 56.62730120122433, 56.465186700224876, 60.411461144685745, 58.42696823179722, 58.050609827041626, 59.28662650287151, 60.0441462546587, 57.538568302989006, 59.98123683035374, 58.335203155875206, 57.738376781344414, 51.83294266462326, 45.796043202281, 47.60100334882736, 48.73799353837967, 48.865408301353455, 58.02749186754227, 60.74043609201908, 63.20694074034691, 64.53338876366615, 69.49358940124512, 60.272559598088264, 48.249624744057655, 55.83845213055611, 33.56896050274372, 10.83756661042571, 0.30735728389117867, 0.09700292415800504, 1.742827424313873, 0.9105387283489108, 38.35517607629299, 81.01372003555298, 63.30591782927513, 73.74893546104431, 53.50262627005577, 45.45419454574585, 26.403346806764603, 37.09302820265293, 53.72864954173565, 42.37921714782715, 64.68671053647995, 62.65162333846092, 61.22534327208996, 1.8025023909285665, 0.12588565674377605, 0.03550584027834702, 0.053660609264625236, 0.034300247352803126, 0.04282784699171316, 0.19827900105156004, 0.22510795126436278, 0.09785910282516852, 0.3012734540970996, 0.12890835001599044, 0.2384323815931566, 0.1908969768555835, 0.6791772181168199, 0.6162947486154735, 47.56937764585018, 84.86200153827667, 72.74401858448982, 58.39954890310764, 42.57834546267986, 56.845519691705704, 76.87679842114449, 19.2009149864316, 33.40736657381058, 77.52218618988991, 75.76136067509651, 72.65957951545715, 69.37867596745491, 46.60360626876354, 0.2800859691342339, 0.5785297625698149, 0.15498626162298024, 1.551865702494979, 0.3845036536222324, 1.039501908235252, 36.51076264679432, 65.28609797358513, 62.77361199259758, 68.52172315120697, 64.86681327223778, 69.06950935721397, 64.57454055547714, 64.14314210414886, 49.41567197442055, 48.83819416165352, 50.14543801546097, 56.887169256806374, 58.73177267611027, 62.02375262975693, 58.60129527747631, 48.319339603185654, 57.989535704255104, 68.64163711667061, 62.87209890782833, 64.43051308393478, 60.806400552392006, 59.98454265296459, 58.18669572472572, 58.7842820584774, 53.464461117982864, 59.25688549876213, 58.89999344944954, 63.269956558942795, 58.55552673339844, 60.06025739014149, 59.33260403573513, 57.82536171376705, 56.47627450525761, 57.80107341706753, 57.12187886238098, 52.138822451233864, 51.016032099723816, 53.09495374560356, 54.49576757848263, 44.12939563393593, 47.627503126859665, 49.43738020956516, 46.985280588269234, 51.33482739329338, 53.03763762116432, 51.09271578490734, 51.04573130607605, 54.74514439702034, 56.276420429348946, 52.06698350608349, 54.00508850812912, 57.28268623352051, 57.82965548336506, 52.783051282167435, 56.20773911476135, 55.125294998288155, 47.381276339292526, 53.941369727253914, 55.24465799331665, 39.18566331267357, 34.26989749073982, 40.69399997591972, 61.5217349678278, 47.87872664630413, 55.76629780232906, 61.300605833530426, 55.24355985224247, 58.42482514679432, 53.478877544403076, 51.93769544363022, 48.075092509388924, 48.81388686597347, 49.17365916073322, 53.956857696175575, 51.11431002616882, 40.36049947142601, 35.50169259309769, 32.9051361232996, 45.56424804031849, 52.074594497680664, 50.73648490011692, 51.545773074030876, 52.42636442184448, 54.232893884181976, 53.11969421803951, 52.615860253572464, 55.46202152967453, 56.9590499997139, 59.43740241229534, 58.250805884599686, 58.73144969344139, 58.16133588552475, 57.42009446024895, 60.34754857420921, 57.88333520293236, 54.17550556361675, 54.7305341809988, 57.47767277061939, 61.2750294059515, 59.90881271660328, 62.68090836703777, 60.45425824820995, 60.12017257511616, 61.40910901129246, 63.23671214282513, 61.08921177685261, 61.3925115019083, 61.0240338742733, 60.366672948002815, 54.63956706225872, 48.86529050767422, 50.98816819489002, 52.55228966474533, 52.09562636911869, 60.25081716477871, 64.193504601717, 64.03766736388206, 66.41992673277855, 70.79612910747528, 61.47060491144657, 51.439276188611984, 54.632864221930504, 33.190428614616394, 14.554696250706911, 1.444211422931403, 0.22551981353899464, 2.0544355222955346, 5.725082019343972, 42.459031865000725, 88.02889600396156, 69.22134920954704, 75.47822266817093, 57.392849922180176, 50.54463319480419, 33.54577034711838, 46.51422366499901, 66.00385665893555, 48.66031810641289, 75.96639767289162, 70.12662023305893, 75.22333234548569, 2.9897615080699325, 0.3266208549030125, 0.20398694789037108, 0.2712422702461481, 0.20407147851074114, 0.22828238405054435], [0.0891767542634625, 0.11153561543324031, 0.19124645419651642, 0.19662689126562327, 0.10689907008782029, 0.1895984707516618, 0.22461087559349835, 0.5614033690653741, 0.5737101368140429, 16.866472251713276, 72.99409076571465, 45.46763062477112, 38.230941742658615, 35.7538128644228, 35.903053656220436, 34.76075515151024, 15.687099136412144, 19.887378551065922, 64.27181839942932, 54.37030591070652, 67.10737824440002, 52.21535414457321, 53.21228384971619, 3.96385348867625, 0.20856941293459386, 0.22719617671100423, 0.5394402507226914, 0.19897960330126807, 0.6396383803803474, 16.28013141453266, 52.4028816819191, 63.35049703717232, 68.40493261814117, 63.173707723617554, 59.39830631017685, 59.343087673187256, 49.01691757142544, 47.04798482358456, 47.446522638201714, 50.11595539748669, 53.14056269824505, 54.56677436828613, 57.26915895938873, 57.262558713555336, 42.06440784037113, 53.55353593826294, 60.53502291440964, 60.71076728403568, 58.217344880104065, 57.224963530898094, 58.86183209717274, 58.47544603049755, 56.03330187499523, 50.28939329087734, 49.93347018957138, 55.42674042284489, 54.893370643258095, 56.57405085861683, 55.52679665386677, 52.288374826312065, 52.12944075465202, 50.706287920475006, 48.709358274936676, 53.81669461727142, 47.71209038794041, 43.47000941634178, 43.38057741522789, 50.97461812198162, 35.61676561832428, 25.30145153403282, 36.437407582998276, 44.77913036942482, 48.78411166369915, 42.27796398103237, 44.9153720587492, 43.499503433704376, 48.296711817383766, 47.53789633512497, 47.770322263240814, 46.430510357022285, 48.457169607281685, 49.66987453401089, 52.73181103169918, 51.663483157753944, 56.567633002996445, 46.44737005233765, 46.854974180459976, 53.18599306046963, 39.46693941950798, 36.109663769602776, 45.28671473264694, 57.49287195503712, 42.86459170281887, 50.88238187134266, 53.45262475311756, 50.46182423830032, 49.370659589767456, 49.42321836948395, 47.432588785886765, 45.9743220359087, 45.245779529213905, 44.33705449104309, 43.95954094827175, 40.89339807629585, 30.728413425385952, 18.721112832427025, 23.71000573039055, 40.68676516413689, 41.83014661073685, 39.34502676129341, 41.569871976971626, 45.487017184495926, 45.28654754161835, 44.24469284713268, 47.32168793678284, 49.767183512449265, 52.07653619349003, 47.92030781507492, 50.05523465573788, 54.31227542459965, 51.44941784441471, 53.599923849105835, 53.628281727433205, 48.53216998279095, 50.39916940033436, 52.55875691771507, 55.072831213474274, 55.45841932296753, 54.62220959365368, 55.19593320786953, 55.867683961987495, 55.94344809651375, 61.47761173546314, 60.32040283083916, 48.35403174161911, 57.21023552119732, 57.86728486418724, 55.555435717105865, 54.15423810482025, 47.39863760769367, 45.15551917254925, 43.75011518597603, 44.0285300463438, 47.23789483308792, 56.912270709872246, 60.118386670947075, 63.64251896739006, 62.874545976519585, 68.19101169705391, 58.72492924332619, 42.824256867170334, 24.997933320701122, 2.584865209646523, 0.5743265943601727, 0.05132077720190864, 2.201945981942117, 1.0488362261094153, 42.59144335985184, 64.40269097685814, 55.55939890444279, 64.68088924884796, 51.12246058881283, 61.564163491129875, 21.3602327182889, 35.4004318267107, 38.55473756790161, 37.175362184643745, 55.60120806097984, 47.15132027864456, 45.23635223507881, 0.9509622061159462, 0.3176422929391265, 0.01728147268295288, 0.1100883235631045, 0.11757700180169195, 0.10023133334470913, 0.08418368859565817, 0.016963610833045095, 0.056407958327326924, 0.22418681241106242, 0.03598429917474277, 0.12439609956345521, 0.1147056175977923, 0.5984079802874476, 0.4161396872950718, 18.921799063682556, 83.7589131295681, 51.487940177321434, 40.481697767972946, 37.84032270312309, 45.17429396510124, 34.87314932048321, 14.331133347004652, 22.902058884501457, 68.2358568906784, 61.66741155087948, 73.46000656485558, 57.25889950990677, 62.11139872670174, 4.884300660341978, 0.4016864800360054, 0.5766011879313737, 1.10201294766739, 0.2561350230826065, 0.5507535499054939, 19.47430081665516, 57.976912781596184, 69.71112012863159, 69.9723257124424, 65.18749326467514, 61.705884486436844, 60.004989355802536, 50.416188687086105, 47.05090306699276, 50.5744805932045, 49.11355398595333, 54.569065645337105, 55.54189704358578, 61.01336024701595, 55.27559973299503, 41.38082452118397, 55.520732179284096, 61.30978234112263, 61.08880899846554, 60.21923325955868, 56.68997123837471, 59.04327996075153, 61.528396010398865, 57.67680108547211, 52.5159902125597, 52.75471240282059, 56.86172962188721, 55.529357716441154, 56.34621128439903, 57.32517555356026, 55.33299945294857, 54.223512187600136, 54.15543124079704, 53.35270531475544, 56.9143757969141, 52.23813012242317, 49.21531252563, 46.689762845635414, 52.39522509276867, 40.416747853159904, 29.479638934135437, 40.18546186387539, 46.948057785630226, 52.88736328482628, 44.776048734784126, 49.44723688066006, 46.16325169801712, 51.61529414355755, 48.50062407553196, 49.90481212735176, 49.79282073676586, 52.788427993655205, 51.061967834830284, 54.55767385661602, 55.135379657149315, 57.708168402314186, 45.147216618061066, 49.500384628772736, 56.1614727973938, 38.468972370028496, 36.93150267004967, 46.770208328962326, 59.574719443917274, 44.301632791757584, 51.69672377407551, 53.162058144807816, 50.742131397128105, 51.27204716205597, 50.62575124204159, 50.25154732167721, 47.47834973037243, 49.8333265632391, 46.646673157811165, 46.270641535520554, 43.63043300807476, 34.61600951850414, 23.81223924458027, 28.78202296793461, 45.022807493805885, 47.23108559846878, 43.29966075718403, 46.08051493763924, 49.139574989676476, 49.90649163722992, 48.425414711236954, 49.78637248277664, 51.93933315575123, 56.838858649134636, 51.00380815565586, 52.73840367794037, 54.735834896564484, 54.52713869512081, 53.56357499957085, 54.1228061914444, 50.943889170885086, 51.880998685956, 54.90836463868618, 56.971327140927315, 58.16124089062214, 55.849745124578476, 57.45988592505455, 58.445427641272545, 58.21199856698513, 60.712948366999626, 62.479325383901596, 49.61760073900223, 57.42550536990166, 61.27346009016037, 58.43598514795303, 57.193090841174126, 51.25648319721222, 47.27995477616787, 46.46685540676117, 46.4185182005167, 50.47786697745323, 59.295837208628654, 63.15046817064285, 63.7277027964592, 65.06252557039261, 71.33761525154114, 64.57773998379707, 47.90773808956146, 28.671958073973656, 3.4320292761549354, 0.6998509587720037, 0.0960242837027181, 1.466617751866579, 1.446792553178966, 51.49819202721119, 70.16367584466934, 62.85071365535259, 74.657983481884, 58.190153539180756, 71.44917726516724, 26.585877612233162, 46.52322918176651, 50.019638165831566, 29.884480610489845, 60.42901620268822, 55.58308303356171, 52.8043719381094, 1.2163705425336957, 0.19224275776650757, 0.0791882406338118, 0.12844919809140265, 0.09097783535253257, 0.11296698823571205, 0.20911374856950715, 0.1588753826217726, 0.27692228264641017, 0.38166562153492123, 0.2125236054416746, 0.3673174133291468, 0.2405409567290917, 0.7920407212805003, 0.5955176416318864, 23.605425842106342, 95.08165955543518, 60.6975743919611, 51.930137649178505, 48.10787335038185, 58.84290151298046, 40.39549559354782, 24.002624228596687, 28.915931582450867, 78.63703116774559, 66.0103391110897, 77.68403470516205, 62.958411276340485, 65.79096168279648, 5.368821211159229, 0.4365925648016855, 0.9493452741298825, 2.519482593052089, 0.6448218959849328, 0.8640017348807305, 23.05249471217394, 60.25281585752964, 66.7596285045147, 74.36837822198868, 67.37467870116234, 63.78792196512222, 64.22250464558601, 54.92585889995098, 50.98373383283615, 54.03543367981911, 52.32763811945915, 57.23679229617119, 58.11423361301422, 63.86039927601814, 55.902414098381996, 45.01722179353237, 58.27785283327103, 64.13128674030304, 63.470308408141136, 63.957909643650055, 58.233140632510185, 62.50369727611542, 65.5258347094059, 58.45813415944576, 55.70132128894329, 56.26824326813221, 58.930004239082336, 61.52626432478428, 59.55205366015434, 60.821808725595474, 58.35612863302231, 59.344930574297905, 59.60398927330971, 57.36724689602852, 62.75906637310982, 56.06549754738808, 53.983243480324745, 52.403763234615326, 56.7255487293005, 46.263687908649445, 39.22448582947254, 48.5684048384428, 52.15465620160103, 56.80834248661995, 47.96060465276241, 53.09600628912449, 50.6912749260664, 54.538230299949646, 55.59844180941582, 56.574107855558395, 53.404614329338074, 56.631294786930084, 54.56858307123184, 58.26838754117489, 58.114871978759766, 60.69331482052803, 49.06436562538147, 51.78208239376545, 56.84095613658428, 39.16300892829895, 36.49810552597046, 46.761134415864944, 61.247207298874855, 46.460095569491386, 54.42012123763561, 55.07514148950577, 52.92644418776035, 55.3372286260128, 54.555010199546814, 53.94602827727795, 52.82210938632488, 52.92952962219715, 51.729151234030724, 53.02607484161854, 49.626233875751495, 40.48795223236084, 30.050109922885895, 35.242987275123596, 49.89853486418724, 50.053482949733734, 47.506540417671204, 50.65645359456539, 52.71513752639294, 54.47045333683491, 53.03466618061066, 55.17679363489151, 58.04853513836861, 60.17490863800049, 52.91192516684532, 57.97695077955723, 60.053619146347046, 58.31623077392578, 57.322523295879364, 56.863416731357574, 52.673100382089615, 55.39582908153534, 58.502299189567566, 57.88387097418308, 59.48622599244118, 58.2563915848732, 61.21257595717907, 62.0537406206131, 60.795422941446304, 64.03566107153893, 64.64857578277588, 52.63202078640461, 61.662984788417816, 63.65185126662254, 63.39341193437576, 60.463161170482635, 54.05564099550247, 51.031227484345436, 48.84519338607788, 48.26143071055412, 53.430015966296196, 63.19790482521057, 66.03389784693718, 68.53549361228943, 69.0071927011013, 74.1831761598587, 64.82212767004967, 52.41864703595638, 30.815117172896862, 6.379130948334932, 1.1656912369653583, 0.32591596303973347, 4.036159096285701, 2.893872228451073, 53.312868252396584, 79.58510309457779, 68.76161947846413, 76.20668917894363, 66.83693915605545, 76.74684539437294, 34.257586151361465, 50.70955574512482, 60.15018716454506, 44.506836980581284, 76.36357516050339, 64.40893024206161, 67.94210225343704, 1.8086353805847466, 0.3963177837431431, 0.17313316755462438, 0.23290724057005718, 0.20625492150429636, 0.2801411255495623], [0.03590390602767002, 0.15436112094903365, 0.08175095077604055, 0.1307606467162259, 0.15738877176772803, 0.058825968226301484, 0.15004878281615674, 0.4403615469345823, 0.49498219101224095, 7.173114493489265, 66.9176772236824, 55.680357813835144, 47.69092932343483, 27.603358514606953, 45.29872968792915, 27.6100005581975, 18.934756368398666, 46.46729998290539, 63.81417855620384, 59.04083289206028, 64.11784306168556, 55.40533237159252, 57.88597226142883, 7.156190676614642, 0.3877875383477658, 0.4260742838960141, 0.1545968567370437, 0.6665086979046464, 0.24166133254766464, 11.662021670490503, 62.81794801354408, 57.01472461223602, 66.92257136106491, 60.59183366596699, 60.24303138256073, 54.13291744887829, 46.250198632478714, 46.54778726398945, 47.11513862013817, 50.021173283457756, 52.4554518610239, 54.82824593782425, 55.715954303741455, 72.17902690172195, 56.802369207143784, 39.9375631660223, 52.75042623281479, 55.87500236928463, 53.74406151473522, 57.95257888734341, 57.14041046798229, 58.6508522182703, 56.80397652089596, 51.42425559461117, 50.37079632282257, 51.4424642175436, 59.22706849873066, 57.21110187470913, 55.10154627263546, 51.08542397618294, 52.00332932174206, 51.00579544901848, 53.12207289040089, 53.91323983669281, 48.89113292098045, 45.771276131272316, 43.53246666491032, 43.262654542922974, 46.44401103258133, 43.730698227882385, 35.570145919919014, 37.15821370482445, 46.027629375457764, 49.220472648739815, 47.53049813210964, 47.00378559529781, 47.40263119339943, 48.167172968387604, 46.432155668735504, 44.192301258444786, 46.906845197081566, 51.87855161726475, 57.03936628997326, 57.4527271091938, 59.17801693081856, 58.362668082118034, 53.17857585847378, 56.01807229220867, 40.92462860047817, 35.85277855396271, 48.92879270017147, 50.57810179889202, 47.53031574189663, 55.771332532167435, 58.478991240262985, 54.61115598678589, 49.79661673307419, 47.759553641080856, 45.81656210124493, 42.301727905869484, 45.15803083777428, 45.733707547187805, 42.699703350663185, 44.061424881219864, 34.84809346497059, 30.899791829288006, 40.96852004528046, 43.2397835701704, 41.65349029004574, 39.200752303004265, 43.95259492099285, 42.82150961458683, 43.219720646739006, 43.64045687019825, 48.70383717119694, 50.79180233180523, 53.064505979418755, 53.4985376894474, 53.54931056499481, 53.32954175770283, 51.61299906671047, 53.72986547648907, 55.26902228593826, 47.42536537349224, 48.41092228889465, 53.54914717376232, 57.159192860126495, 52.0991487801075, 57.957541421055794, 57.4526397138834, 56.12240709364414, 57.29903295636177, 73.41030523180962, 57.88256384432316, 38.670042380690575, 36.069454327225685, 60.41102796792984, 56.10576018691063, 57.73547753691673, 54.751984030008316, 53.05153347551823, 45.397079810500145, 44.63329799473286, 42.642850801348686, 50.24269379675388, 55.35780072212219, 59.2049764841795, 59.52056095004082, 63.52682277560234, 64.40347373485565, 72.96416357159615, 30.44751349836588, 1.219412754289806, 0.43857555370777845, 0.3910102997906506, 0.8265491633210331, 6.03942490182817, 60.45476742088795, 62.0720062404871, 56.56174711883068, 52.1164720505476, 63.82313847541809, 58.021590784192085, 11.534474864602089, 29.192718230187893, 35.48649340867996, 48.542372435331345, 56.35636433959007, 50.62064431607723, 38.242234736680984, 0.9042804641649127, 0.15329489222494885, 0.07288548469659872, 0.1008846311015077, 0.06629018156672828, 0.16757278935983777, 0.03604986792197451, 0.062307045300258324, 0.09413783336640336, 0.12333873208262958, 0.069291508407332, 0.10976562291034497, 0.21805354073876515, 0.4360247327713296, 0.4649117623921484, 7.893959088250995, 76.57301232218742, 66.28270849585533, 50.73687627911568, 32.611320689320564, 53.612915351986885, 26.319361813366413, 21.076581738889217, 49.667712450027466, 68.91214460134506, 62.862553820014, 71.53274238109589, 61.30674630403519, 65.91345191001892, 8.275903668254614, 0.29157310898881406, 0.7053955737501383, 0.11925058934139088, 1.010333129670471, 0.09272359675378539, 12.402635179460049, 67.72961005568504, 61.77055701613426, 67.2034902870655, 63.06189872324467, 64.3135629594326, 56.71657741069794, 49.80740815401077, 47.107573226094246, 48.46246272325516, 51.002079248428345, 55.0509861856699, 57.997579872608185, 61.21658094227314, 68.35845351219177, 48.90716426074505, 41.87544398009777, 54.09925505518913, 58.41604381799698, 57.06145070493221, 60.73206514120102, 59.5343504101038, 59.6146135032177, 56.94491095840931, 52.707674726843834, 52.52661444246769, 53.667727410793304, 61.23486176133156, 58.58712203800678, 55.42390577495098, 56.865320429205894, 55.40926516056061, 54.59260158240795, 57.057001143693924, 56.045807003974915, 53.71826849877834, 50.79569332301617, 46.97269186377525, 46.107413694262505, 50.418221578001976, 47.86104619503021, 39.37780000269413, 40.80929338932037, 47.83035144209862, 51.34837746620178, 49.79472443461418, 50.88521271944046, 50.19413240253925, 52.76413209736347, 50.463024973869324, 47.14680232107639, 51.52704007923603, 53.76105800271034, 58.159891963005066, 58.620199263095856, 60.38236230611801, 60.29115580022335, 54.55548137426376, 55.55825136601925, 40.891984552145004, 36.429990381002426, 48.589459508657455, 55.125484988093376, 50.70737466216087, 55.38068689405918, 58.23724061250687, 56.54526360332966, 53.10091942548752, 50.418768748641014, 52.04544246196747, 46.16766706109047, 49.63569536805153, 47.18293458223343, 45.02801701426506, 47.90830805897713, 38.63158084452152, 33.867012709379196, 44.25277881324291, 48.01809176802635, 46.108641028404236, 43.706216141581535, 47.375375255942345, 47.36108802258968, 46.458765640854836, 46.64090886712074, 51.528852581977844, 53.18057835102081, 57.3481111228466, 55.3033572435379, 55.945974960923195, 54.37268078327179, 54.373653531074524, 54.1608839482069, 54.06344197690487, 50.349593460559845, 52.43995629251003, 56.58540464937687, 58.349771574139595, 55.229971781373024, 60.23860462009907, 59.971098974347115, 58.639699816703796, 59.228094443678856, 66.25303208827972, 60.082653388381004, 41.72042369842529, 37.84542962908745, 62.64914207160473, 60.20716890692711, 59.71642903983593, 55.865282490849495, 55.48385135829449, 46.581468656659126, 48.503587916493416, 45.60256138443947, 51.091914027929306, 56.461516097187996, 63.25630769133568, 61.82229124009609, 65.94913959503174, 66.1540549993515, 75.97964376211166, 31.53163142502308, 2.50116971321404, 0.35776606178842485, 0.5460667982697487, 1.4575539319775999, 7.095029158517718, 68.97937819361687, 65.95990061759949, 65.6192184984684, 55.36871753633022, 71.36661529541016, 65.15076443552971, 16.947833485901356, 35.77452175319195, 48.747405633330345, 38.498941361904144, 60.830153077840805, 59.634627029299736, 45.54622940719128, 1.0383168468251824, 0.1665455085458234, 0.01093865654183901, 0.2009717799955979, 0.04530967788014095, 0.1315323615563102, 0.15418756229337305, 0.19961645506555215, 0.14731880743056536, 0.2858316170750186, 0.1757847869885154, 0.34591791161801666, 0.25920944404788315, 0.837733328808099, 0.6652504310477525, 10.827594045549631, 91.13258466124535, 75.29042154550552, 63.03811199963093, 37.577152624726295, 67.74702072143555, 36.04473665356636, 30.63224818557501, 54.70007121562958, 78.16890388727188, 68.86407718062401, 76.97691544890404, 64.50326398015022, 74.32316064834595, 8.974853362888098, 0.41963175928685814, 1.259605810046196, 0.1885285461321473, 1.9056029710918665, 0.5675535171758384, 15.177067704498768, 67.95627549290657, 63.951571583747864, 71.5487015247345, 65.86359098553658, 67.15470850467682, 59.60615515708923, 50.76205372810364, 52.39899069070816, 50.54288528859615, 53.14156964421272, 55.06998896598816, 61.47367134690285, 63.10192957520485, 74.41425696015358, 47.858165949583054, 41.38210125267506, 55.412517786026, 61.351310312747955, 58.410116136074066, 64.06466871500015, 61.71782724559307, 63.63675467669964, 60.39109043776989, 54.937421679496765, 56.79319649934769, 56.953183114528656, 66.08324199914932, 59.76010389626026, 60.080973878502846, 59.610623717308044, 60.07743626832962, 58.479435816407204, 62.300795763731, 61.49546317756176, 55.76458789408207, 53.22905234992504, 54.51433718204498, 51.04111075401306, 57.425691559910774, 53.534597754478455, 46.01262018084526, 45.06334751844406, 52.64741376042366, 55.60759171843529, 55.40380485355854, 55.03425948321819, 55.16585782170296, 57.365065813064575, 55.014272555708885, 52.70552024245262, 55.850987657904625, 59.076277390122414, 63.06924752891064, 61.888331696391106, 62.73395732045174, 62.40269869565964, 57.2344858199358, 57.08557941019535, 39.93983544409275, 35.34609854221344, 51.16253323853016, 55.777780786156654, 55.14370501041412, 58.58609229326248, 60.59863530099392, 59.778156727552414, 57.364294454455376, 52.13574841618538, 56.22907496988773, 48.874448016285896, 52.44637414813042, 52.233665362000465, 50.262331143021584, 54.27479803562164, 44.77403104305267, 41.73830173909664, 49.46977727115154, 52.27226749062538, 52.049914821982384, 47.77814604341984, 51.569191217422485, 50.38675546646118, 51.746618896722794, 50.98836958408356, 55.87425380945206, 58.43471221625805, 61.01570852100849, 57.829944267868996, 61.25623561441898, 60.492480397224426, 57.10878476500511, 56.622144877910614, 58.49761784076691, 51.15383170545101, 54.1478506475687, 58.60638700425625, 60.24692617356777, 57.172381952404976, 62.247401028871536, 60.5661204457283, 60.766335502266884, 62.694124057888985, 68.45320522785187, 62.51258119940758, 40.95117777585983, 38.957979530096054, 68.85555803775787, 63.58659736812115, 65.9729491174221, 60.32877378165722, 61.226525008678436, 50.830199271440506, 50.71244738996029, 47.71746329963207, 54.714689031243324, 60.86524419486523, 66.48228138685226, 63.25755402445793, 70.88213369250298, 70.17262056469917, 76.69180914759636, 35.01905769109726, 5.652272226288915, 0.810366366058588, 1.2309703091159463, 4.4700616132467985, 8.23287382721901, 75.18530398607254, 72.32854887843132, 68.08578774333, 65.39573729038239, 76.49043515324593, 70.62645301222801, 21.94409418851137, 42.91933536529541, 58.7836778908968, 55.525010749697685, 76.1781907081604, 68.34716811776161, 61.077709794044495, 1.6125155542977154, 0.304149009170942, 0.20491092174779624, 0.30470075143966824, 0.154774111288134, 0.26805314293596894], [0.027794898087449837, 0.041788895905483514, 0.029406913345155772, 0.06252430161111988, 0.1534942479338497, 0.0830496424168814, 0.061400393169606104, 0.035444872846710496, 0.1255149391363375, 1.7835777439177036, 61.7017313092947, 58.61636906862259, 51.4717872440815, 34.91238981485367, 38.694646060466766, 34.2114794254303, 13.271154575049877, 49.79942858219147, 68.80145654082298, 50.927287861704826, 60.61206378042698, 54.088855013251305, 58.251372054219246, 13.265380784869194, 0.19732829503482208, 0.2202726958785206, 0.13015235279453918, 0.9188712656032294, 0.06806243764003739, 7.80997646972537, 57.95083858072758, 56.96166805922985, 67.91497930884361, 55.389779806137085, 58.20413298904896, 46.15568250417709, 48.86469013988972, 48.837384805083275, 56.776344403624535, 55.358275696635246, 61.9392641633749, 53.076684325933456, 61.543059423565865, 49.63957495987415, 58.763516172766685, 49.89310875535011, 42.3562777787447, 55.892397835850716, 60.227342024445534, 62.25290693342686, 59.42410692572594, 58.66450108587742, 54.50937084853649, 52.706527188420296, 50.57049460709095, 51.304938197135925, 57.721965461969376, 55.47478884458542, 57.533301785588264, 52.6312380284071, 47.798296362161636, 51.150970458984375, 49.921812415122986, 51.50118626654148, 52.00734570622444, 48.782169967889786, 46.75499014556408, 42.556523233652115, 42.71622106432915, 45.707485154271126, 43.84350657463074, 42.24029280245304, 41.54207266867161, 41.79419293999672, 45.80070935189724, 51.30005545914173, 44.48705144226551, 36.81308962404728, 42.93232686817646, 47.08922021090984, 46.50312826037407, 47.29962632060051, 48.31127643585205, 53.38333547115326, 55.8337327837944, 57.1241245418787, 58.60355235636234, 59.71421755850315, 44.33748006820679, 37.98639066517353, 51.1615376919508, 57.95197851955891, 56.836825758218765, 61.68091982603073, 60.61557859182358, 58.31943780183792, 53.17792609333992, 48.41913364827633, 47.77156099677086, 49.51030969619751, 48.63140545785427, 48.343643099069595, 47.57785499095917, 47.666709423065186, 45.059312134981155, 44.070798978209496, 39.8520677536726, 40.87212681770325, 40.10253131389618, 40.028241500258446, 45.368558540940285, 40.38319565355778, 44.99239392578602, 48.59108582139015, 52.06638693809509, 49.84762899577618, 54.34694856405258, 48.65382805466652, 52.513311356306076, 50.3082250803709, 52.663813680410385, 54.38564568758011, 51.44883647561073, 46.41475260257721, 50.66262066364288, 54.71795305609703, 55.123288705945015, 52.24221110343933, 55.30409440398216, 56.42583981156349, 58.58818978071213, 53.77108946442604, 80.80297574400902, 53.700227066874504, 48.38596522808075, 29.211318232119083, 43.47811818122864, 60.417841002345085, 58.30306448042393, 54.57147091627121, 53.47771480679512, 48.147056847810745, 47.63412997126579, 46.21392197906971, 47.288131937384605, 45.967896580696106, 54.0430598706007, 58.46698388457298, 63.09686064720154, 58.81800904870033, 64.45566013455391, 26.922037973999977, 0.1561817279434763, 0.27917980682104826, 0.501826306572184, 0.5738523323088884, 13.10139013454318, 62.54044510424137, 57.43710234761238, 50.464947670698166, 50.04425324499607, 67.8121492266655, 25.167210437357426, 15.529177710413933, 39.11648042500019, 31.58895704895258, 21.763974353671074, 37.89813660085201, 60.41929252445698, 25.880143381655216, 0.5055368668399751, 0.17980486736632884, 0.10056624232674949, 0.06627793613006361, 0.008657824291731231, 0.03113307277089916, 0.06569241872057319, 0.033330568330711685, 0.02711292188905645, 0.037544761144090444, 0.22508783906232566, 0.11115183602669276, 0.11102148520876653, 0.40001762739848346, 0.07763248388073407, 2.442062459886074, 68.48535910248756, 70.23036986589432, 52.12783344089985, 43.559487015008926, 51.63037173449993, 31.934865787625313, 17.06760685890913, 53.252234905958176, 78.40108662843704, 55.50750508904457, 71.29197210073471, 59.09578934311867, 68.12164261937141, 16.806771755218506, 0.07831078459275886, 0.23476790869608521, 0.31564858742058277, 2.1163235139101744, 0.0277290194935631, 9.198551159352064, 64.22237545251846, 60.680524706840515, 68.65675270557404, 58.12417007982731, 59.98604737222195, 48.877997025847435, 51.2820216268301, 50.79019881784916, 58.56240056455135, 56.50630049407482, 63.02204266190529, 51.90491460263729, 65.363340228796, 51.34503744542599, 52.36213266849518, 48.994817957282066, 45.426345840096474, 58.86707201600075, 60.86326450109482, 62.955204248428345, 60.87212182581425, 61.26032039523125, 55.74462376534939, 55.12934558093548, 52.49312683939934, 54.08795066177845, 57.1098031103611, 57.779410779476166, 59.486309587955475, 56.11125089228153, 52.724526822566986, 53.267171904444695, 56.2407061457634, 53.93503546714783, 53.96422550082207, 52.95551262795925, 51.4896272867918, 48.07817414402962, 46.68222025036812, 48.22612300515175, 46.72804579138756, 47.22525671124458, 44.84511762857437, 46.36667378246784, 48.80092576146126, 51.74989052116871, 48.07492911815643, 41.591428220272064, 47.7648239582777, 50.134331211447716, 48.9161241799593, 52.33701601624489, 52.148591727018356, 55.76326556503773, 56.59210368990898, 58.685893937945366, 60.17859064042568, 60.28612107038498, 45.623920038342476, 38.9278319478035, 52.929309234023094, 58.083941638469696, 56.97473555803299, 62.450811713933945, 61.2030004709959, 60.59143468737602, 56.00764565169811, 51.26387380063534, 51.2816758453846, 52.323070764541626, 51.368128806352615, 51.34681575000286, 51.654033064842224, 49.49172109365463, 50.3999749571085, 48.73746156692505, 45.24825319647789, 43.815798461437225, 43.52917984127998, 44.295279532670975, 49.01968762278557, 44.78098846971989, 47.35409639775753, 50.972144454717636, 56.854722797870636, 53.50783959031105, 57.51613810658455, 50.284772738814354, 54.721034690737724, 53.75451475381851, 56.06079339981079, 54.804531410336494, 54.09951724112034, 48.336833864450455, 54.77276511490345, 58.170326203107834, 58.16308379173279, 54.476487413048744, 59.14933606982231, 58.16915586590767, 62.666659131646156, 55.410017520189285, 72.97688528895378, 56.93677179515362, 52.789697125554085, 35.214405208826065, 44.6459399163723, 61.78034529089928, 60.94900690019131, 59.09468740224838, 55.98304197192192, 49.478277415037155, 51.56455546617508, 48.12049627304077, 50.27802050113678, 48.72345171868801, 55.39420276880264, 59.39941585063934, 66.90462872385979, 61.99400782585144, 66.77219063043594, 28.90207562595606, 0.8197294792626053, 0.20676131854997948, 0.4170148278353736, 0.19697819428984076, 15.968050360679626, 70.75725719332695, 65.94084843993187, 54.54780578613281, 52.64289580285549, 74.07302767038345, 28.89411885291338, 20.59281449764967, 41.76638223230839, 42.98892483115196, 21.89062725752592, 43.154231160879135, 68.21602955460548, 31.92091293632984, 0.9731114550959319, 0.23783060372807086, 0.12990594492293894, 0.10666245114407502, 0.11304996776743792, 0.05542833452636842, 0.1523986746906303, 0.09477764629991725, 0.10510968524613418, 0.3536154970061034, 0.29926134331617504, 0.23558989661978558, 0.18776975950459018, 0.5082165542989969, 0.39468974922783673, 3.095074757002294, 81.22360557317734, 79.43197891116142, 68.69485706090927, 43.40915948152542, 62.36333280801773, 41.44528426229954, 25.358777157962322, 59.242799654603004, 84.6695950627327, 59.48587641119957, 73.69525194168091, 63.03124576807022, 72.42017716169357, 17.64653619378805, 0.2553418156458065, 0.625093235867098, 0.9711821679957211, 4.576165694743395, 0.12450013382476754, 11.749560423195362, 64.92957070469856, 63.727964982390404, 72.44545340538025, 60.41836157441139, 63.361375853419304, 51.2854490429163, 52.14184328913689, 53.75478073954582, 60.55491104722023, 59.004461243748665, 65.74979469180107, 57.819722816348076, 66.96606382727623, 59.94466759264469, 58.84964235126972, 48.532922342419624, 48.29209886491299, 59.08731199800968, 63.90120908617973, 66.46271243691444, 65.05435600876808, 63.365551829338074, 59.10267077386379, 59.496154859662056, 55.60361333191395, 57.31596104800701, 61.40808306634426, 60.254457369446754, 63.848034739494324, 60.96993237733841, 55.9454657882452, 57.120210751891136, 60.44920451939106, 56.438208147883415, 57.41642385721207, 55.99903151392937, 55.719324722886086, 52.804721519351006, 52.834587916731834, 53.9653692394495, 54.074799567461014, 49.581411480903625, 50.932850763201714, 51.70215368270874, 53.27982522547245, 56.093304455280304, 53.28541472554207, 48.3868657797575, 53.862307369709015, 57.27814547717571, 56.771055087447166, 59.26030911505222, 56.36852368712425, 60.98971411585808, 57.69035495817661, 61.78001470863819, 63.30238401889801, 63.55245240032673, 46.28306686878204, 38.29048454761505, 53.96833688020706, 60.68625099956989, 59.561651945114136, 65.93522474169731, 67.75193765759468, 61.49350248277187, 59.33498650789261, 54.350071996450424, 58.09402249753475, 58.85852627456188, 57.387207224965096, 56.62355840206146, 55.79435549676418, 55.9103898704052, 54.986017271876335, 55.16554243862629, 49.24924850463867, 47.43474327027798, 48.11608850955963, 48.71286928653717, 53.170607686042786, 48.07647563517094, 53.53252686560154, 56.409816071391106, 59.85361307859421, 59.19106163084507, 63.292732536792755, 56.89759969711304, 59.73413988947868, 56.5836301445961, 58.96239370107651, 58.69016490876675, 56.6423711925745, 51.60563126206398, 58.02796684205532, 61.42546333372593, 61.37872964143753, 59.139031022787094, 61.916731372475624, 60.79845517873764, 66.38319790363312, 56.770906895399094, 74.22732219099998, 57.76935651898384, 50.56245803833008, 31.876288130879402, 47.917815148830414, 65.89607924222946, 64.12952363491058, 61.659048199653625, 60.20444445312023, 51.85742475092411, 53.47492955625057, 51.82257302105427, 54.19179908931255, 51.46548718214035, 59.390858709812164, 62.65190452337265, 70.25963589549065, 63.80485385656357, 70.41756302118301, 30.662317872047424, 1.784078604541719, 0.4783421120373532, 0.8237097063101828, 1.4578886702656746, 16.915704309940338, 78.52502837777138, 69.33049455285072, 63.42150762677193, 62.224237471818924, 77.5464440882206, 38.20605307817459, 25.06853923201561, 58.36355343461037, 53.593202009797096, 28.747173137962818, 54.2391749471426, 78.36407661437988, 44.078653156757355, 1.5478133386932313, 0.46124926360789686, 0.19096393341897056, 0.27536579116713256, 0.2202570514054969, 0.1426814086153172], [0.02685512947209645, 0.05676970708009321, 0.06357810678309761, 0.06894350051879883, 0.1399420079542324, 0.06217866117367521, 0.11084647936513647, 0.15481406851904467, 0.09550272458000109, 0.9280889772344381, 54.583155289292336, 59.827242493629456, 44.55137439072132, 24.24282643944025, 33.3396428078413, 43.63249249756336, 16.193421967327595, 23.031964413821697, 72.86840870976448, 49.42641779780388, 49.7823902964592, 55.46411521732807, 53.77591520547867, 16.200341396033764, 0.10675576879293658, 0.15984495403245091, 0.006383774343703408, 0.5390267260372639, 0.28361369390040636, 4.767043702304363, 53.8312554359436, 64.87293854355812, 66.86635717749596, 57.89596572518349, 50.26857800781727, 48.99871654808521, 59.838193506002426, 57.428598403930664, 58.66621099412441, 55.19262358546257, 57.930076494812965, 56.98892019689083, 63.87379735708237, 45.213648453354836, 21.411467269062996, 48.77097576856613, 57.77819864451885, 60.145448818802834, 59.359422996640205, 60.87532125413418, 57.95371502637863, 56.7828306555748, 54.96338568627834, 54.00244764983654, 48.80671665072441, 48.17199870944023, 52.24671006202698, 55.69019168615341, 52.26932264864445, 53.54665830731392, 44.831271171569824, 50.25863394141197, 56.166382133960724, 55.87442860007286, 54.96297150850296, 54.12114568054676, 54.106056690216064, 48.25181342661381, 46.30864329636097, 45.318986400961876, 42.43435978889465, 42.1677090972662, 41.518643125891685, 43.541358187794685, 41.32026717066765, 41.68239153921604, 34.8585657030344, 33.3539604395628, 48.82275179028511, 47.25736118853092, 45.04088692367077, 45.44645816087723, 41.99104517698288, 47.38654285669327, 50.30785270035267, 48.21601174771786, 50.710137113928795, 49.55100551247597, 48.180080875754356, 45.66257916390896, 52.141489908099174, 52.722235545516014, 55.43594732880592, 58.13442572951317, 59.21000361442566, 54.292113706469536, 53.44043880701065, 48.12685713171959, 43.15705820918083, 36.45205199718475, 35.86767755448818, 40.96110284328461, 41.290104389190674, 41.97094805538654, 44.93786305189133, 40.119668394327164, 38.69153402745724, 37.37887166440487, 41.66001453995705, 41.33124478161335, 41.25699296593666, 43.6603108048439, 46.68560966849327, 53.62387776374817, 49.185769110918045, 53.43054413795471, 45.96431717276573, 45.579842403531075, 55.456348434090614, 50.294728204607964, 55.346253141760826, 50.23128680884838, 50.54060161113739, 44.38372738659382, 50.83266533911228, 53.63276548683643, 54.828979298472404, 53.9041431248188, 54.69848670065403, 57.44963027536869, 56.2724344432354, 56.19264252483845, 71.81458845734596, 48.12482424080372, 57.48098239302635, 44.18362632393837, 30.385519824922085, 50.24480268359184, 61.74103260040283, 56.949447914958, 56.91779561340809, 53.864572048187256, 53.13360147178173, 47.144290655851364, 50.61222396790981, 45.5112636834383, 50.66365420818329, 53.535361513495445, 61.85328237712383, 55.8673457801342, 67.62965261936188, 25.611959472298622, 0.17099245742429048, 0.06570981466211379, 0.35272162465844303, 0.3128600417403504, 29.572859331965446, 66.67724892497063, 53.93309377133846, 43.427360504865646, 71.65660813450813, 45.650271624326706, 12.94539425522089, 33.61212618649006, 33.17575000226498, 33.405470475554466, 30.489252358675003, 47.82070755958557, 56.266738548874855, 17.54401959478855, 1.1523201107047498, 0.40785102581139654, 0.09959818489733152, 0.09611466244678013, 0.11876075703185052, 0.09116208093473688, 0.08622403809567913, 0.09927141727530397, 0.04810643171367701, 0.1147887455590535, 0.04222137504257262, 0.04869161515671294, 0.01726246813632315, 0.1858922594692558, 0.051546887334552594, 1.1206660280004144, 61.559558138251305, 71.20566353201866, 46.18457995355129, 25.71449887007475, 51.21077544987202, 42.961410507559776, 22.011770457029343, 26.246122643351555, 77.6773926615715, 52.422678619623184, 57.90183261036873, 62.67387114465237, 62.810584008693695, 20.062494054436684, 0.04266310505045112, 0.46715340460650623, 0.024679618181835394, 1.235198532231152, 0.31218109535984695, 5.888393456116319, 57.02952861785889, 67.74949818849564, 69.12757024168968, 60.956678688526154, 53.995326831936836, 52.08747960627079, 62.28583976626396, 61.07707902789116, 63.02075073122978, 59.70679275691509, 59.411833584308624, 59.630295261740685, 63.889984488487244, 47.92686626315117, 23.356482200324535, 48.3067736774683, 58.229101449251175, 60.158881098032, 60.11646777391434, 63.01779069006443, 57.377525344491005, 58.64722341299057, 56.718230322003365, 54.00513790547848, 50.13536475598812, 49.93262283504009, 54.29598569869995, 55.94705410301685, 54.63246904313564, 57.28846572339535, 47.71750129759312, 54.93637293577194, 59.74423594772816, 58.610243797302246, 57.04258091747761, 57.31772415339947, 57.14551739394665, 50.04951596260071, 49.7994589805603, 50.59554286301136, 45.67265622317791, 44.3121088296175, 45.631405636668205, 46.72141134738922, 43.88605669140816, 44.6957628428936, 38.90361204743385, 38.13525527715683, 53.674707636237144, 50.35277009010315, 50.20509101450443, 48.396053686738014, 46.73633314669132, 49.65236507356167, 52.559554874897, 52.3897609859705, 52.95744672417641, 52.33104273676872, 49.29382771253586, 45.22050328552723, 50.96057787537575, 53.440511003136635, 58.84566016495228, 58.91151823103428, 62.58014537394047, 59.955808594822884, 56.38800524175167, 52.40599751472473, 49.429142251610756, 41.16153068840504, 42.86308318376541, 46.3826709240675, 45.91465003788471, 45.42552128434181, 47.370291128754616, 41.25751353800297, 40.99381148815155, 42.81090438365936, 44.768509939312935, 43.1908193975687, 45.32278999686241, 47.02764831483364, 52.077854722738266, 56.73126742243767, 52.84125655889511, 56.095192953944206, 49.12000983953476, 48.13231363892555, 57.60349161922932, 53.41662548482418, 55.27049280703068, 50.529639199376106, 53.83907541632652, 46.94919012486935, 52.223288118839264, 53.870317339897156, 57.89284609258175, 55.797915905714035, 58.618242368102074, 57.802665531635284, 58.92312280833721, 55.11181712150574, 63.659861236810684, 49.45391312241554, 57.216003611683846, 55.53071044385433, 35.2501080930233, 50.36914721131325, 64.06450912356377, 59.31519716978073, 61.80576592683792, 55.68418800830841, 56.60011366009712, 49.14875529706478, 52.43591710925102, 46.87648102641106, 53.28625068068504, 55.59447102248669, 64.489865899086, 58.65930296480656, 72.9752741754055, 27.83518597483635, 0.8049863297492266, 0.03011695200257236, 0.8974884473718703, 0.4136974277207628, 34.698864072561264, 72.32324436306953, 57.609339505434036, 44.60079073905945, 79.98187780380249, 45.88253416121006, 17.881659977138042, 40.08743852376938, 44.71281252801418, 36.831290647387505, 23.012446761131287, 55.17246946692467, 65.03564581274986, 21.407279893755913, 1.225581367034465, 0.3899555595126003, 0.15852451004320756, 0.17790208978112787, 0.13556105084717274, 0.07432100610458292, 0.3544901328859851, 0.1853370587923564, 0.12773893307894468, 0.24435374041786417, 0.20930480706738308, 0.26171119417995214, 0.11753270300687291, 0.3328102774685249, 0.3338132455246523, 1.6728841024450958, 74.4405135512352, 78.3385343849659, 65.1491229236126, 29.18661955744028, 54.07245509326458, 52.53782384097576, 27.636468037962914, 34.17972072958946, 84.08264815807343, 58.53100284934044, 61.297577396035194, 66.69836819171906, 70.9037621319294, 24.593331031501293, 0.12652540288399905, 0.5058087897486985, 0.24756869446719065, 2.1092684799805284, 0.9569379198364913, 6.890503233298659, 57.6503849029541, 70.59300720691681, 73.24319779872894, 61.37693993747234, 57.04337887465954, 53.90725135803223, 66.75340443849564, 62.59876437485218, 63.083451166749, 61.34952060878277, 63.962522596120834, 61.61010682582855, 67.75284960865974, 48.58530253171921, 29.36151087284088, 52.296023815870285, 58.58938671648502, 62.11332902312279, 62.778091952204704, 66.53994709253311, 60.276332795619965, 62.49277666211128, 59.50259551405907, 58.25192302465439, 51.065801829099655, 52.265093475580215, 56.48516222834587, 61.029672771692276, 56.17454409599304, 61.28657318651676, 52.23081171512604, 58.293397799134254, 64.30684491991997, 65.70975244045258, 61.44050292670727, 60.65639220178127, 63.91250967979431, 56.246440038084984, 56.04775629937649, 55.41214540600777, 50.72612665593624, 50.17348051071167, 50.72387717664242, 52.302703857421875, 49.94869217276573, 50.23358188569546, 44.74270552396774, 43.547000885009766, 57.71699532866478, 55.00464767217636, 54.494008272886276, 53.455679789185524, 50.33499464392662, 53.717721328139305, 55.857865288853645, 53.89148600399494, 55.91805785894394, 54.41792115569115, 52.71379619836807, 48.12528781592846, 55.3343103826046, 54.988452941179276, 58.4170887619257, 62.15651750564575, 63.928392827510834, 61.98963426053524, 61.54908210039139, 56.53632268309593, 56.533377841115, 49.632355347275734, 48.38522046804428, 54.569897800683975, 53.61233778297901, 53.48032906651497, 52.98149183392525, 47.967938259243965, 47.14145600795746, 46.24592386186123, 52.01629802584648, 48.694341480731964, 49.22684110701084, 51.628437638282776, 56.28652408719063, 61.708019971847534, 56.182778254151344, 59.30007018148899, 50.94963826239109, 49.79624815285206, 62.104870676994324, 56.579423770308495, 60.37227004766464, 53.13961274921894, 56.335169076919556, 48.95431213080883, 56.157395616173744, 57.89438880980015, 63.65171827375889, 58.60568784177303, 64.39008325338364, 59.28983353078365, 63.132023960351944, 54.43908601999283, 73.0329854786396, 49.82190817594528, 59.54741790890694, 48.277853429317474, 33.78591366112232, 55.93443118035793, 66.07385650277138, 65.12021407485008, 62.28207416832447, 59.1484659165144, 58.651524782180786, 53.29486861824989, 55.0975526869297, 49.57021728157997, 58.50341632962227, 58.39337423443794, 68.09853985905647, 60.79983450472355, 74.67524975538254, 32.29387052357197, 1.6972132469527423, 0.2740922657540068, 1.1623111995868385, 0.7745602342765778, 35.32988101243973, 77.99593716859818, 66.87888890504837, 51.068845465779305, 81.69091209769249, 58.1659222394228, 24.658100455999374, 46.98240414261818, 55.25179021060467, 48.83325442671776, 39.49395976960659, 67.36679792404175, 77.82974168658257, 28.14686994999647, 1.3034334895201027, 0.8322629879694432, 0.2041895393631421, 0.38705524639226496, 0.19841960835037753, 0.2677363052498549], [0.03125897070276551, 0.050136658319388516, 0.17129345767898485, 0.030627096894022543, 0.09588562825229019, 0.1002038293518126, 0.03621530006057583, 0.06194014604261611, 0.46401168568991125, 0.6014963833149523, 41.70898251235485, 64.86912354826927, 48.75624395906925, 47.87213779985905, 37.10627809166908, 33.70112881064415, 16.89945638179779, 37.46719792485237, 66.17198243737221, 60.40216684341431, 47.08707332611084, 50.65100088715553, 59.20974142849445, 22.99357697367668, 0.1141065708361566, 0.0913397065596655, 0.13881844090064988, 0.4685417847940698, 0.4811943043023348, 2.713032807223499, 50.71790389716625, 67.63929650187492, 65.35156086087227, 56.53311565518379, 47.60048657655716, 57.66820214688778, 61.69911704957485, 60.806039571762085, 59.16112683713436, 62.0079530775547, 59.05213728547096, 59.486909955739975, 53.4349101036787, 49.78799119591713, 48.59520100057125, 51.42106756567955, 62.50123120844364, 58.36656667292118, 57.111136838793755, 58.12444366514683, 58.61858814954758, 55.58570109307766, 52.980709075927734, 52.08610028028488, 51.58004343509674, 46.87905728816986, 51.143097281455994, 55.65877877175808, 55.249430537223816, 55.70114269852638, 54.87458825111389, 50.61112202703953, 54.947411343455315, 51.165899857878685, 52.326893359422684, 53.3292605727911, 50.67880779504776, 47.42839001119137, 46.24964386224747, 46.13725729286671, 44.34211201965809, 42.23200544714928, 42.269254848361015, 41.430541053414345, 44.13260646164417, 42.61717177927494, 37.662328854203224, 42.78695806860924, 45.47602817416191, 44.635121896862984, 44.34414491057396, 43.46666179597378, 48.79711456596851, 46.366829574108124, 49.46334421634674, 50.78699178993702, 55.953460559248924, 59.33491051197052, 58.8630024343729, 56.47396042943001, 57.62327715754509, 51.73519290983677, 50.372901409864426, 47.949775233864784, 51.528681591153145, 49.869048446416855, 46.07018329203129, 48.35560105741024, 44.1454041749239, 27.33260214328766, 23.11025731265545, 35.78899137675762, 43.515838757157326, 37.95634187757969, 40.36542780697346, 36.6349133849144, 39.568207785487175, 39.5232068002224, 41.2608839571476, 40.35727344453335, 42.25524120032787, 45.39111413061619, 54.010366424918175, 51.38908468186855, 49.97226610779762, 49.80577804148197, 54.0292552113533, 51.27817623317242, 53.831513822078705, 54.123011380434036, 53.35058882832527, 51.68467842042446, 47.736089900135994, 44.427972212433815, 47.24226079881191, 50.80754488706589, 54.88924786448479, 56.50470457971096, 56.37900732457638, 52.98885963857174, 55.920052751898766, 55.49512915313244, 39.326738342642784, 45.373893454670906, 57.11163081228733, 58.180464059114456, 45.21262250840664, 37.28612624108791, 60.789430662989616, 58.45597967505455, 61.14603012800217, 55.19994959235191, 59.64167945086956, 51.31046690046787, 52.90908291935921, 47.21874386072159, 51.48206189274788, 50.556074380874634, 66.29767209291458, 57.20800504088402, 63.33802230656147, 18.98621890693903, 0.27304862800519913, 0.18482073181075975, 0.41713668848387897, 0.30782459944020957, 43.76741945743561, 60.132673904299736, 58.2234625518322, 64.64219212532043, 67.15737596154213, 19.356106258928776, 32.10813269019127, 57.14394807815552, 26.570900715887547, 43.8450150936842, 37.11569018661976, 45.184184834361076, 54.62221719324589, 6.454701293259859, 0.6707063445355743, 0.3952823096187785, 0.16097252868348733, 0.19890170748112723, 0.04135515511734411, 0.0514468940673396, 0.04503245232626796, 0.07184836300439201, 0.16798926779301837, 0.05164852074813098, 0.06456859191530384, 0.06938102626008913, 0.0928385034785606, 0.07985637392266653, 0.4041892691748217, 0.2937497984385118, 48.13557006418705, 75.28597578406334, 57.32483357191086, 38.15367288887501, 47.08470605313778, 38.99586729705334, 22.17130109667778, 42.72203095257282, 74.18560042977333, 64.69152867794037, 47.52001069486141, 58.45436856150627, 64.70041260123253, 23.58343642205, 0.40750206797383726, 0.5387071869336069, 0.2583383407909423, 1.8316585826687515, 0.5133159994147718, 3.8714308105409145, 54.777982234954834, 70.67668631672859, 67.17354029417038, 59.58647981286049, 49.24391359090805, 59.96599204838276, 64.54007640480995, 64.49701711535454, 61.50637999176979, 61.149305552244186, 59.49017398059368, 60.85796378552914, 53.594041764736176, 49.15405601263046, 51.11748285591602, 55.27777701616287, 63.247419968247414, 59.748822301626205, 58.26870672404766, 57.843072563409805, 61.40802226960659, 57.62150265276432, 54.64736804366112, 52.745680287480354, 54.10270147025585, 48.669061437249184, 53.247663751244545, 56.16645812988281, 57.71599978208542, 57.39236354827881, 56.80839568376541, 57.52532601356506, 58.828249499201775, 54.661119505763054, 54.07329864799976, 55.95675118267536, 54.381199926137924, 52.295792028307915, 49.923279136419296, 47.73966170847416, 48.92237864434719, 45.14176771044731, 46.70251876115799, 44.93579216301441, 47.80861660838127, 46.647265926003456, 42.007977068424225, 46.42902463674545, 51.24694190919399, 47.67399363219738, 46.54507800936699, 45.95961682498455, 52.295894622802734, 45.26894308626652, 50.488324016332626, 53.23019988834858, 56.28142096102238, 58.28221119940281, 58.67753438651562, 56.53161093592644, 59.780011028051376, 53.394077494740486, 54.19138491153717, 50.92163376510143, 55.77692203223705, 52.6062847673893, 52.567420452833176, 51.00400194525719, 49.48068268597126, 30.71562521159649, 28.916254565119743, 39.78334844112396, 44.49569217860699, 42.078071907162666, 45.02524696290493, 38.89999844133854, 42.01057232916355, 42.27514073252678, 43.466350212693214, 44.776896089315414, 47.05116905272007, 49.76628676056862, 53.26493762433529, 53.87307219207287, 53.13216134905815, 53.91626447439194, 54.56267438828945, 53.03093098104, 55.85106745362282, 55.476456955075264, 54.250813722610474, 55.1805554330349, 48.86291183531284, 47.52431586384773, 51.05496481060982, 52.956466376781464, 57.22621366381645, 57.21042551100254, 58.959365263581276, 56.91552713513374, 59.60987515747547, 54.04407441616058, 39.473786652088165, 47.08127483725548, 54.24270495772362, 64.83371704816818, 54.95670184493065, 38.093309327960014, 60.29799543321133, 60.23556478321552, 64.8137529194355, 57.507877349853516, 61.983148008584976, 53.27623821794987, 56.87635503709316, 49.84572149813175, 54.43063907325268, 53.21972005069256, 70.55272936820984, 62.62581132352352, 68.82617801427841, 20.37911206483841, 0.5502253188751638, 0.16615987377008423, 0.514171487884596, 0.3353334014536813, 48.849004581570625, 66.0695019364357, 63.780702352523804, 64.30027887225151, 74.9356497824192, 23.21488279849291, 37.37086169421673, 55.0983202457428, 33.69218409061432, 51.40854723751545, 31.316914446651936, 52.63686552643776, 62.30641186237335, 7.828056374564767, 0.5920779949519783, 0.5053508549463004, 0.20270482840714976, 0.17881815234431997, 0.06764627090888098, 0.061879230561316945, 0.1192311079648789, 0.24229156435467303, 0.2797146874945611, 0.14870172541122884, 0.3084267780650407, 0.2480243137688376, 0.20260995224816725, 0.3090394358150661, 0.7086763414554298, 0.7507624675054103, 60.60840457677841, 83.51346909999847, 70.60353264212608, 58.52982111275196, 63.056031838059425, 46.20959401130676, 25.301839113235474, 49.045685827732086, 79.87850055098534, 74.59123626351357, 59.20170105993748, 65.71657687425613, 70.87667718529701, 31.960506811738014, 0.6031725089997053, 0.8691687451209873, 0.5282435577828437, 3.038739454932511, 1.2121059838682413, 5.5722827184945345, 56.77464969456196, 73.54407325387001, 72.43310406804085, 61.87706150114536, 53.042193576693535, 63.29348869621754, 67.22202569246292, 66.48001670837402, 64.36215475201607, 67.633186429739, 61.41302280128002, 63.95381346344948, 55.44463746249676, 49.999012872576714, 51.67751580476761, 55.72311691939831, 68.42542871832848, 63.1518778949976, 59.75479558110237, 60.53483672440052, 64.8408530652523, 61.52334988117218, 58.39704483747482, 56.76437124609947, 55.13346455991268, 51.06732174754143, 56.13200917840004, 60.700222849845886, 62.068837210536, 62.56589613854885, 61.03908106684685, 61.05901099741459, 64.08951938152313, 57.89786942303181, 57.114077880978584, 58.669368624687195, 56.700557470321655, 55.50653234124184, 56.427428126335144, 53.66003282368183, 54.21475365757942, 52.63512521982193, 53.000536412000656, 48.855479434132576, 51.24910019338131, 51.98222525417805, 47.84564942121506, 52.83353537321091, 54.58407863974571, 53.15027877688408, 49.65826615691185, 50.52181161940098, 57.20362767577171, 49.887682646512985, 56.13745428621769, 56.560386791825294, 60.27014672756195, 65.00793769955635, 63.05555686354637, 60.499365627765656, 64.29344683885574, 54.36751686036587, 56.66472539305687, 54.25038054585457, 58.361296355724335, 56.037952825427055, 56.36931024491787, 55.074788108468056, 58.42090755701065, 39.08512070775032, 39.824029058218, 48.959324061870575, 50.83358868956566, 45.149317905306816, 51.01492255926132, 46.13355249166489, 47.526436150074005, 49.28497798740864, 48.646817430853844, 49.08413976430893, 49.47247512638569, 52.522913441061974, 57.31240063905716, 59.41140800714493, 58.43671090900898, 58.37331511080265, 59.3667908012867, 56.599859073758125, 59.098574593663216, 59.550427347421646, 57.82539211213589, 58.50183941423893, 52.55069375038147, 49.51423868536949, 51.92261405289173, 57.05098606646061, 59.49386738240719, 58.98870728909969, 60.71090787649155, 59.99787613749504, 62.069764360785484, 55.55835396051407, 52.716927230358124, 48.73499549925327, 59.22530919313431, 63.919174522161484, 48.27056922018528, 42.58518509566784, 65.25133743882179, 64.61213573813438, 68.98219004273415, 59.773083999753, 67.02901124954224, 54.72762353718281, 60.24412952363491, 52.29722075164318, 57.975738644599915, 52.66259014606476, 72.5746388733387, 62.47799165546894, 71.3576477766037, 22.24582079797983, 1.8160208780318499, 0.3441970789572224, 1.078654294833541, 0.6692687748000026, 52.48491927981377, 72.8010231256485, 70.64072504639626, 70.51840960979462, 81.3939580321312, 28.93846057355404, 47.9908662289381, 66.05572387576103, 46.777557134628296, 67.68141344189644, 52.52916790544987, 63.29006128013134, 75.22271677851677, 12.687591388821602, 0.9682503878138959, 0.8206674351822585, 0.36218115768861026, 0.41530658199917525, 0.12996384728467092, 0.1933679130161181], [0.05089944141218439, 0.04095936405065004, 0.07905928505351767, 0.04275553954357747, 0.010911099670920521, 0.07985854099388234, 0.0642403622623533, 0.12019074201816693, 0.3100226627429947, 0.35145368019584566, 24.297900684177876, 76.41959935426712, 43.019042015075684, 44.467588886618614, 47.369664162397385, 41.77864037454128, 11.848764549940825, 27.22248785197735, 73.25743943452835, 59.4084669649601, 59.353138133883476, 45.08371062576771, 61.09144225716591, 35.00461466610432, 1.7000670125707984, 0.17133261339040473, 0.18774243362713605, 1.0460989479906857, 0.1572161927470006, 1.7862758366391063, 48.43166537582874, 69.79228377342224, 61.714494824409485, 57.45159097015858, 49.79329191148281, 60.31241185963154, 62.41522662341595, 64.40264537930489, 57.918019741773605, 54.58628252148628, 50.20183078944683, 50.448612347245216, 47.647854834795, 47.8604344278574, 56.77452050149441, 62.65926472842693, 58.55056419968605, 59.360262751579285, 56.34339943528175, 56.94853596389294, 54.59198221564293, 53.53617087006569, 50.75260743498802, 52.270280197262764, 52.00558640062809, 48.30925114452839, 51.35896369814873, 56.220673620700836, 54.9078668653965, 54.92322564125061, 56.764956414699554, 54.52932357788086, 54.00825373828411, 51.07099235057831, 53.215274289250374, 53.98807302117348, 55.3009519726038, 52.00138382613659, 51.05504460632801, 49.5629520714283, 49.062895104289055, 47.623076364398, 43.835933580994606, 43.47475156188011, 46.41653850674629, 44.31277759373188, 45.22483505308628, 45.12365408241749, 43.62586185336113, 44.77891378104687, 43.70336249470711, 47.0599427819252, 42.50957675278187, 52.46500074863434, 56.46065354347229, 57.714529260993004, 56.429290026426315, 58.119192346930504, 51.951541900634766, 48.15472863614559, 59.59934212267399, 59.36755836009979, 56.02090314030647, 52.462948858737946, 46.688983887434006, 46.91037900745869, 44.03842851519585, 44.743317291140556, 43.322957307100296, 40.357752218842506, 41.57635822892189, 42.25901439785957, 40.189033672213554, 38.96447338163853, 37.16839715838432, 37.94238522648811, 38.09079386293888, 40.562439635396004, 41.116294115781784, 45.917944461107254, 46.86097025871277, 49.670094922184944, 52.79353491961956, 49.059019312262535, 50.104445815086365, 47.99261033535004, 51.25172205269337, 48.91382910311222, 54.19572427868843, 51.864013597369194, 53.169938921928406, 51.10252305865288, 47.25241005420685, 43.65192845463753, 50.003808215260506, 49.742291048169136, 56.72253929078579, 52.77357459068298, 58.70121471583843, 53.84414054453373, 56.96508027613163, 45.47206498682499, 29.329358898103237, 50.44975608587265, 57.34372615814209, 60.73816381394863, 61.29782058298588, 43.78602705895901, 44.05314892530441, 55.07838651537895, 64.05468285083771, 60.979618057608604, 59.19736169278622, 57.03102573752403, 55.74818417429924, 49.97380502521992, 53.52392412722111, 55.93744061887264, 61.43609896302223, 59.70836207270622, 60.29165357351303, 14.390901289880276, 0.14595190499676391, 0.07518678074120544, 0.4447930888272822, 1.7359836352989078, 53.99697594344616, 57.27657616138458, 64.00080934166908, 55.5622411519289, 66.04367852210999, 20.89990071952343, 28.335039652884007, 71.74835041165352, 30.376267321407795, 26.074672043323517, 25.561855360865593, 51.522525921463966, 41.9838597625494, 2.0128367794677615, 0.16089629527414218, 0.2008318406296894, 0.00899751641554758, 0.11201781846466474, 0.04659439488023054, 0.037534237490035594, 0.03601285701734014, 0.031331812497228384, 0.06245626151212491, 0.04180894873570651, 0.10711637092754245, 0.023259023218997754, 0.09021146397572011, 0.14523265999741852, 0.5643076600972563, 0.35736684571020305, 28.339238427579403, 86.43390119075775, 48.28321874141693, 37.3950169980526, 57.6725073158741, 41.02424405515194, 13.809363394975662, 37.79776878654957, 79.4731231033802, 67.22467795014381, 62.21936233341694, 53.00369784235954, 69.88141179084778, 39.26148444414139, 1.1668200138956308, 0.9868506866041571, 0.2944631507853046, 1.9255576003342867, 0.36848763178568333, 2.799245906062424, 51.36567793786526, 73.58326435089111, 65.17592668533325, 60.7560608536005, 51.564593464136124, 63.559763208031654, 64.97001573443413, 65.9630012512207, 62.72452622652054, 57.58381627500057, 54.56404611468315, 53.359457552433014, 47.28112131357193, 47.218356281518936, 58.27377185225487, 65.1099394261837, 61.482065096497536, 61.06620021164417, 57.941464483737946, 60.31281843781471, 56.56026899814606, 56.26201540231705, 56.112497225403786, 55.355471447110176, 52.40558333694935, 51.079462096095085, 53.63127216696739, 56.37741141021252, 57.48296208679676, 57.37771913409233, 59.41945217549801, 56.8811921775341, 56.97598189115524, 56.52563765645027, 57.99533039331436, 55.16276478767395, 56.82044483721256, 57.87000931799412, 54.12711516022682, 51.72276757657528, 51.36610731482506, 49.30059514939785, 47.12475210428238, 48.659105971455574, 51.92166030406952, 48.5611130297184, 48.45380298793316, 45.963086038827896, 48.115955516695976, 49.12097118794918, 47.99299791455269, 47.41732120513916, 47.16684244573116, 52.07300618290901, 57.74331271648407, 57.85749278962612, 55.546320006251335, 59.137119725346565, 54.41201627254486, 50.14239437878132, 59.76274475455284, 60.29424503445625, 58.472755774855614, 53.06375361979008, 51.98717258870602, 50.76522275805473, 50.800716653466225, 48.38701397180557, 46.26624897122383, 45.49795299768448, 46.34952910244465, 46.58577002584934, 45.753576681017876, 43.216247633099556, 43.0415216088295, 41.18363030254841, 42.97912135720253, 43.86820524930954, 45.347188487648964, 47.84330114722252, 50.09944528341293, 54.73254047334194, 56.0801799595356, 52.581559494137764, 51.528673991560936, 49.34979110956192, 55.62205754220486, 49.9817655980587, 56.05732798576355, 54.77327808737755, 56.02590747177601, 53.368102088570595, 49.80724096298218, 45.4237125813961, 51.22530207037926, 51.51576988399029, 58.3033836632967, 55.30572831630707, 60.6303483992815, 57.198570147156715, 60.03861755132675, 48.415793627500534, 30.3898211941123, 51.66749954223633, 58.84719908237457, 59.87739220261574, 71.71354427933693, 52.33940228819847, 44.74701829254627, 56.145760640501976, 65.12294232845306, 63.987228870391846, 62.20940686762333, 58.84256333112717, 59.30591806769371, 53.20547841489315, 56.639707535505295, 59.50840160250664, 66.83902144432068, 64.0874370932579, 65.79240560531616, 16.238468550145626, 0.17290848976699635, 0.1585947023704648, 0.5965916183777153, 1.5157750016078353, 62.42768995463848, 60.0089905411005, 74.28723737597466, 59.77918267250061, 76.87803715467453, 23.60895585268736, 35.73312297463417, 72.92429611086845, 37.45665729045868, 35.66648595035076, 27.677399441599846, 62.94731207191944, 48.33968751132488, 2.6858699647709727, 0.12694526551058516, 0.2812515269033611, 0.009094683027797146, 0.010463565140526043, 0.07365578945609741, 0.0525898534397129, 0.14185257809003815, 0.11865307882544585, 0.1485854308702983, 0.2009055358939804, 0.12683422537520528, 0.133454212336801, 0.46419164165854454, 0.12441219674656168, 0.7324214454274625, 0.5405019968748093, 37.19617746770382, 98.20220410823822, 63.08711796998978, 52.80683420598507, 68.63736614584923, 60.74656516313553, 17.972475104033947, 42.23882608115673, 84.13025960326195, 74.76113274693489, 68.49268510937691, 60.842612609267235, 74.4691564142704, 48.542501628398895, 3.0864637065678835, 3.4599782014265656, 0.6331056402996182, 2.837976277805865, 0.6219998456072062, 3.614378641359508, 53.592670038342476, 73.65498930215836, 68.39081257581711, 62.39491291344166, 55.99040977656841, 65.9966142475605, 66.70002490282059, 69.67278018593788, 64.16575089097023, 58.442589193582535, 54.11532059311867, 53.607477843761444, 48.10438893735409, 47.67430521547794, 60.39671033620834, 66.6500423848629, 62.39479511976242, 64.76662784814835, 61.49319089949131, 63.28035280108452, 57.90408968925476, 59.948376193642616, 56.229040771722794, 56.53989069163799, 54.00991424918175, 53.812701031565666, 56.5538739413023, 61.428959146142006, 60.974963307380676, 60.62516927719116, 61.816667541861534, 61.500912085175514, 60.32903976738453, 59.354012086987495, 62.05317445099354, 61.43475763499737, 63.35827901959419, 59.3463858962059, 59.71407696604729, 56.523369178175926, 57.99088083207607, 55.914554446935654, 53.07981535792351, 51.88002213835716, 55.94241075217724, 52.46849276125431, 53.58688674867153, 51.2910233438015, 53.01396109163761, 52.65078417956829, 50.61580337584019, 50.763064473867416, 49.819141924381256, 56.00448802113533, 62.741408720612526, 59.84046958386898, 57.08303354680538, 61.053030118346214, 57.17099882662296, 50.254666954278946, 62.07858368754387, 61.91724814474583, 60.89041404426098, 58.250771686434746, 56.79599314928055, 56.304519921541214, 54.731712117791176, 53.02977964282036, 50.217869728803635, 51.01462997496128, 51.95186108350754, 49.894370287656784, 51.31041370332241, 46.73413686454296, 47.73782640695572, 46.3967377692461, 48.92691180109978, 48.20862114429474, 48.631101474165916, 52.454270124435425, 54.73577030003071, 57.03372739255428, 61.240637451410294, 56.13385207951069, 57.89381504058838, 55.909572914242744, 59.594561979174614, 53.57591673731804, 58.106459230184555, 57.06218406558037, 59.732433781027794, 56.98824003338814, 52.08178751170635, 49.131496623158455, 53.08562144637108, 55.069977566599846, 61.7751357704401, 58.35786513984203, 63.76864939928055, 61.24963536858559, 60.41560672223568, 53.67674432694912, 40.26626832783222, 53.59221026301384, 62.45049633085728, 64.80245232582092, 67.79572650790215, 49.1163544356823, 52.755704149603844, 58.970221281051636, 66.76386147737503, 64.67086538672447, 66.49238124489784, 61.36259950697422, 62.39849612116814, 55.13933904469013, 59.71478372812271, 60.56758716702461, 69.42302718758583, 67.08288475871086, 68.80470156669617, 22.185865715146065, 0.5443375348113477, 0.18423749279463664, 1.5011779661290348, 2.816328126937151, 67.32218071818352, 67.68175542354584, 78.5491494834423, 64.4065211713314, 81.86639428138733, 29.687793664634228, 45.119132325053215, 76.55516847968102, 52.65208750963211, 39.07244838774204, 37.08471044898033, 70.0660590827465, 62.619872242212296, 4.768881378695369, 0.3706374851753935, 0.48477240605279803, 0.1674352990812622, 0.22583620593650267, 0.10784372760099359, 0.21580282947979867], [0.03399523950065486, 0.01729466806864366, 0.06238332323846407, 0.02908580645453185, 0.03173760400386527, 0.08811788022285327, 0.05851565772900358, 0.12099196464987472, 0.43874986935406923, 0.3360465756850317, 9.730421919375658, 60.321223586797714, 50.218462496995926, 40.40474809706211, 35.40933474898338, 42.37089939415455, 24.85089261084795, 8.605207297950983, 55.814179033041, 62.73028291761875, 61.04455277323723, 52.2709945589304, 51.94614998996258, 48.869405686855316, 2.9406593553721905, 0.22333775094011799, 0.14827411476289853, 1.3537816191092134, 0.11146166783873923, 1.2822854868136346, 42.41738609969616, 73.55337515473366, 65.26809453964233, 55.49145095050335, 53.314695954322815, 59.57974277436733, 60.50435855984688, 60.80272614955902, 60.15710659325123, 59.16445545852184, 50.34708559513092, 43.182520642876625, 52.43909373879433, 37.259254083037376, 40.327342450618744, 65.76786652207375, 57.042303532361984, 57.73200832307339, 53.61626297235489, 53.33215981721878, 54.496056362986565, 53.550967276096344, 52.61389575898647, 50.504393354058266, 49.98131722211838, 49.7051290422678, 49.59511734545231, 54.30802725255489, 54.96956795454025, 54.35916870832443, 56.82353027164936, 55.555196329951286, 53.94878692924976, 53.89301732182503, 52.485021874308586, 52.41542860865593, 51.75478845834732, 54.20997351408005, 53.79571594297886, 53.53081315755844, 50.762532502412796, 48.65158997476101, 47.81385652720928, 44.843320325016975, 45.57503946125507, 44.355244114995, 43.041346818208694, 43.33087608218193, 42.990600541234016, 42.81598471105099, 44.71862241625786, 49.04776431620121, 52.42838591337204, 58.660287111997604, 59.01737295091152, 58.548637703061104, 56.764055863022804, 57.05564461648464, 50.60489796102047, 45.8016213029623, 55.8174392580986, 55.27729444205761, 56.82832941412926, 59.82716269791126, 52.386029586195946, 46.57521799206734, 44.73464995622635, 47.30075865983963, 42.84948751330376, 40.21714836359024, 39.40832756459713, 36.50455757975578, 39.8648426681757, 40.604871958494186, 40.621085688471794, 38.795059472322464, 38.605316653847694, 43.09183090925217, 46.030403226614, 48.13860610127449, 49.11762356758118, 54.20382544398308, 52.895145267248154, 52.03474223613739, 51.40358090400696, 49.56343084573746, 51.35869771242142, 49.48240019381046, 52.57037669420242, 53.404401540756226, 50.41033700108528, 48.62336128950119, 46.404759138822556, 44.79958467185497, 50.009329319000244, 49.08155970275402, 53.753857389092445, 53.330423310399055, 54.26259309053421, 53.546791300177574, 58.72462525963783, 45.097515285015106, 34.447131380438805, 54.75741773843765, 56.281831339001656, 55.87278708815575, 61.24362029135227, 71.85994282364845, 50.260712429881096, 40.997254103422165, 46.53386481106281, 54.611171185970306, 58.97471264004707, 59.65575009584427, 59.2349910736084, 52.50916197896004, 54.2403756827116, 57.25864112377167, 64.00872811675072, 60.55730491876602, 53.94526071846485, 8.988983854651451, 1.5959686296992004, 0.1249605548218824, 0.11564701708266512, 4.3797186110168695, 64.73265767097473, 52.42674060165882, 63.14162224531174, 58.75190019607544, 69.05839875340462, 9.243234861642122, 35.93748740851879, 35.27747802436352, 29.957410097122192, 35.058172792196274, 34.028534442186356, 61.32985286414623, 35.50643093883991, 0.8221095171757042, 0.0321169824746903, 0.08662595559144393, 0.02104954754031496, 0.03514904165058397, 0.09792922835913487, 0.0650921103078872, 0.020532005291897804, 0.08050698510487564, 0.11448442048276775, 0.05579546013905201, 0.05972330640361179, 0.021357377409003675, 0.045526744943344966, 0.09508488801657222, 0.5826929735485464, 0.3042921546148136, 12.682741899043322, 70.23132741451263, 61.49992033839226, 36.76355168223381, 44.59829807281494, 44.480538591742516, 20.121457390487194, 14.194389134645462, 61.92971907556057, 72.88723289966583, 65.88772729039192, 58.703866973519325, 58.05514678359032, 57.264694198966026, 2.752392045222223, 0.5189813766628504, 0.2543873543618247, 1.194565650075674, 0.26302417216356844, 1.7406407603994012, 44.29810658097267, 75.01383438706398, 67.10261330008507, 59.19630154967308, 55.21416462957859, 62.5894358754158, 62.08951570093632, 63.44494476914406, 60.617961063981056, 57.49049328267574, 46.83658316731453, 43.458735421299934, 53.76537077128887, 37.22224786877632, 39.76827085018158, 67.14497342705727, 57.69937567412853, 60.08575402200222, 54.75654378533363, 55.30666686594486, 55.74795238673687, 56.92131422460079, 55.38254879415035, 52.945842146873474, 50.650582909584045, 49.8678857088089, 51.27285651862621, 57.16421239078045, 55.86350418627262, 57.005620300769806, 59.615768641233444, 57.30162061750889, 56.50869816541672, 56.49909608066082, 55.49410700798035, 54.98279124498367, 52.43643008172512, 55.792368203401566, 57.11026668548584, 58.010932356119156, 56.72013022005558, 54.338915795087814, 49.20139767229557, 49.34817999601364, 49.4651073217392, 49.120598807930946, 47.33985856175423, 47.81971201300621, 44.49722349643707, 46.902137249708176, 49.38729889690876, 50.38599170744419, 53.72068136930466, 59.409424513578415, 61.51008479297161, 60.109468549489975, 58.036117404699326, 56.606983691453934, 53.3831150829792, 47.877092733979225, 56.34065218269825, 57.718397453427315, 60.825437530875206, 60.30623719096184, 55.53177058696747, 51.19700878858566, 47.51585751771927, 51.074617356061935, 46.66142016649246, 43.67872841656208, 47.815574035048485, 41.42024740576744, 44.61743384599686, 44.54685643315315, 42.08277225494385, 41.817660480737686, 43.19375663995743, 46.6584525257349, 48.57050992548466, 49.56311546266079, 54.22711819410324, 56.313335448503494, 55.264865309000015, 57.54248969256878, 54.9574314057827, 51.644377782940865, 54.012262523174286, 54.53894466161728, 55.257052928209305, 54.05861243605614, 54.02431167662144, 52.67354495823383, 49.168643429875374, 47.534043341875076, 49.57137241959572, 50.02783052623272, 56.28081299364567, 52.979766726493835, 57.314642518758774, 55.44781029224396, 61.980009377002716, 49.398846477270126, 39.81637626886368, 55.224921852350235, 57.18960642814636, 56.26214079558849, 62.44174160063267, 77.01978474855423, 59.51124764978886, 44.27545979619026, 46.74895606935024, 53.37149530649185, 59.08263064920902, 60.64112462103367, 62.124663814902306, 54.007759764790535, 56.46694600582123, 58.62824723124504, 66.95033267140388, 64.88354757428169, 56.36744074523449, 11.671843193471432, 2.3323274357244372, 0.15877072495641187, 0.1669483314617537, 5.17022249288857, 69.42259401082993, 56.63778863847256, 69.430892765522, 60.857249423861504, 76.76853463053703, 10.656549073755741, 51.40434846282005, 42.170802131295204, 38.438178822398186, 39.23737093806267, 36.14949703216553, 70.33731132745743, 38.19702096283436, 1.2459356873296201, 0.08528462014510296, 0.08122423372697085, 0.09766877905349247, 0.07621893746545538, 0.055008364288369194, 0.015449074817297515, 0.17523213929962367, 0.1865718440967612, 0.325358699192293, 0.2669502224307507, 0.15281031432095915, 0.19969148619566113, 0.18122686684364453, 0.1619849368580617, 0.743525696452707, 0.5990591109730303, 18.180779926478863, 83.52642640471458, 72.00046688318253, 53.11492547392845, 51.00197285413742, 55.861577689647675, 33.83524261415005, 20.964795537292957, 64.53777372837067, 80.18473371863365, 69.93104472756386, 67.79010280966759, 61.63264341652393, 63.70141580700874, 4.0533949714154005, 1.462914019357413, 0.6243240146432072, 2.2686155419796705, 0.3838115563848987, 2.519482593052089, 47.99937777221203, 77.04679369926453, 71.39579772949219, 61.46321810781956, 58.525565341115, 65.61538070440292, 64.36978474259377, 67.80201897025108, 62.19375170767307, 57.621533051133156, 50.184427723288536, 44.742295145988464, 54.452210515737534, 41.09225660562515, 43.25061298906803, 69.13124844431877, 60.35093039274216, 62.43332505226135, 56.46113991737366, 59.802638813853264, 57.19877913594246, 58.898051753640175, 59.387917667627335, 54.37884025275707, 51.86369061470032, 54.07116696238518, 54.012167528271675, 61.020032688975334, 59.56965811550617, 59.971235767006874, 61.33731186389923, 63.598258942365646, 59.99523147940636, 62.271848917007446, 59.047106355428696, 60.0762203335762, 55.35144366323948, 58.623801469802856, 59.25484120845795, 60.07665731012821, 62.715638503432274, 60.25495134294033, 55.6610244512558, 56.228322610259056, 54.84765909612179, 54.13008660078049, 52.81259469687939, 50.81349536776543, 47.73966930806637, 50.74692294001579, 52.69282132387161, 54.312625005841255, 58.16351316869259, 63.4158269315958, 63.335848823189735, 63.45578558743, 61.389863044023514, 61.34194761514664, 57.44905270636082, 47.22203068435192, 59.61107589304447, 61.1206778883934, 65.56403025984764, 64.53207403421402, 59.82017867267132, 57.182937785983086, 52.40523375570774, 57.43820808827877, 52.061587795615196, 48.388609886169434, 53.745083659887314, 48.55420880019665, 47.798930928111076, 47.65824347734451, 47.03289583325386, 45.71829557418823, 46.78856514394283, 53.02268162369728, 55.285608395934105, 53.41021902859211, 56.782401278615, 60.89089661836624, 60.42284153401852, 59.81503754854202, 60.40750555694103, 56.35577917098999, 62.3940085619688, 57.280695140361786, 57.85359799861908, 58.030919283628464, 56.95014327764511, 55.626643896102905, 52.10452549159527, 51.48435316979885, 52.82013729214668, 54.74405385553837, 57.994072660803795, 57.29477718472481, 59.90614905953407, 58.88730973005295, 64.24878403544426, 50.854825749993324, 40.77246196568012, 59.56097178161144, 62.05476276576519, 59.43609528243542, 64.63038995862007, 70.56057214736938, 56.256243512034416, 47.98038259148598, 50.63775099813938, 61.17915295064449, 63.00737164914608, 63.66573192179203, 65.66318973898888, 59.42978762090206, 57.76381641626358, 62.04677939414978, 70.57365864515305, 66.77051872015, 61.62844464182854, 17.500050254166126, 2.402060581371188, 0.4810299928067252, 0.5333817133214325, 5.893293768167496, 77.05863386392593, 62.336855828762054, 75.55681765079498, 65.38096368312836, 83.827605843544, 17.069267369806767, 50.47035478055477, 41.89278244972229, 46.34892113506794, 48.950713723897934, 53.44924293458462, 77.69143670797348, 54.5575712621212, 1.6233994765207171, 0.35748018650338054, 0.20154005731455982, 0.25699009594973177, 0.2197127157705836, 0.2137929599848576, 0.28278640704229474], [0.12208367872517556, 0.06668363115750253, 0.13463157025398687, 0.17557820276124403, 0.12002238581771962, 0.10496049872017466, 0.044057767518097535, 0.2150944940513, 0.39957943372428417, 0.2985583810368553, 4.759080754593015, 57.38703243434429, 51.67577549815178, 38.681361973285675, 52.08458796143532, 33.33398871123791, 58.19684498012066, 19.57526709884405, 30.9649146348238, 63.23790527880192, 53.909196853637695, 65.3483234345913, 49.84607107937336, 53.943155631423, 7.16654559597373, 0.5683730263262987, 0.1066296779026743, 1.2234178581275046, 0.5013955640606582, 0.8430763764772564, 37.09678240120411, 71.5075421333313, 67.7814468741417, 59.02754880487919, 51.91249519586563, 58.514963909983635, 63.31993527710438, 57.42402344942093, 70.33073768019676, 61.031489074230194, 21.095977798104286, 31.06705315411091, 64.45246830582619, 28.280698768794537, 27.47079122811556, 65.66006630659103, 56.13063745200634, 63.24064873158932, 58.10781195759773, 60.424950420856476, 54.34768192470074, 55.597864240407944, 54.66426193714142, 56.509750708937645, 48.43758545815945, 48.54429893195629, 48.16120348870754, 54.701218754053116, 52.19069726765156, 53.37854012846947, 52.728702798485756, 58.65164257586002, 56.062176525592804, 56.01647637784481, 53.75154711306095, 52.753192484378815, 50.28042957186699, 57.970886304974556, 57.00935550034046, 53.809038028120995, 51.49252273142338, 50.11609598994255, 47.63290263712406, 45.8792245388031, 46.808882653713226, 46.567842587828636, 45.90591810643673, 47.07077980041504, 45.68601630628109, 46.43280543386936, 47.771078422665596, 51.4758226275444, 57.2957157343626, 58.76143388450146, 61.48850955069065, 61.054721027612686, 56.907494366168976, 55.628916174173355, 54.82903249561787, 45.97168117761612, 51.48324742913246, 54.30879481136799, 52.80374117195606, 56.758131980895996, 59.08101573586464, 53.679905757308006, 50.271446853876114, 45.76184123754501, 41.20050899684429, 38.8525465875864, 39.89062048494816, 40.303016155958176, 40.761719942092896, 40.942020267248154, 41.084592416882515, 40.35956472158432, 41.686347126960754, 47.68834546208382, 48.632146418094635, 51.597017124295235, 53.12221348285675, 51.97027489542961, 53.93587902188301, 52.570505887269974, 49.14856530725956, 50.51622211933136, 47.945204079151154, 50.36934860050678, 50.16650028526783, 51.36304467916489, 50.61277873814106, 52.89340116083622, 46.209749802947044, 47.04838380217552, 51.20448298752308, 50.98388962447643, 52.47870661318302, 53.59334260225296, 54.133772403001785, 56.455580815672874, 59.42667178809643, 57.24993959069252, 53.94382059574127, 55.415094047784805, 60.67705549299717, 55.56560017168522, 55.98186403512955, 68.18560838699341, 67.93004170060158, 59.4974809885025, 48.324750512838364, 45.84228292107582, 50.25381579995155, 62.75713607668877, 60.452776327729225, 57.29688227176666, 52.043329775333405, 63.58843646943569, 59.57777447998524, 64.6786017715931, 40.912024676799774, 4.654199257493019, 2.57732926402241, 0.32415935886092484, 0.49391812935937196, 13.512951750308275, 63.74694876372814, 54.16953228414059, 60.7795549929142, 58.6035143584013, 45.90987369418144, 12.607744373381138, 32.092230543494225, 15.020197872072458, 30.973374880850315, 21.563238725066185, 41.737150400877, 54.08790126442909, 18.051915541291237, 0.5775196105241776, 0.20400392822921276, 0.09692799692857079, 0.08093506330624223, 0.03760929830605164, 0.10840295071830042, 0.07646179044968449, 0.1554945734096691, 0.04564663890050724, 0.16436800273368135, 0.07656194327864796, 0.1686125827836804, 0.1643242160207592, 0.028336723407846875, 0.29470900946762413, 0.6730381131637841, 0.2626185736153275, 6.888153534382582, 68.20785239338875, 62.26528286933899, 38.447438925504684, 51.881044283509254, 36.78484573960304, 49.86933723092079, 23.58329962939024, 38.063674718141556, 73.58406990766525, 60.11383071541786, 73.25337365269661, 54.62415888905525, 63.084518909454346, 8.086840063333511, 0.5922112846747041, 0.1290659821825102, 1.3264878024347126, 0.5868134368211031, 0.7893559872172773, 40.63107915222645, 72.60282576084137, 71.01128876209259, 59.75282348692417, 52.376518696546555, 61.73802696168423, 65.59015765786171, 57.83477380871773, 72.80858471989632, 62.19192400574684, 20.99800195544958, 32.761017456650734, 61.45969569683075, 32.04732835292816, 31.174684278666973, 66.45914822816849, 58.29742178320885, 65.22220820188522, 59.35276195406914, 62.164812460541725, 56.824100241065025, 56.766259744763374, 55.05593352019787, 56.00747846066952, 50.84827110171318, 49.06170576810837, 49.45034511387348, 56.88093759119511, 55.27083098888397, 55.356550589203835, 55.092734545469284, 61.18388369679451, 59.14685860276222, 59.12431441247463, 56.45331233739853, 54.94083009660244, 52.845177948474884, 58.427724391222, 58.692608177661896, 56.322143375873566, 55.98876066505909, 53.55040870606899, 50.81136368215084, 49.9046715348959, 48.716346099972725, 51.910158321261406, 49.30960826575756, 50.61739929020405, 50.06836675107479, 48.27649690210819, 48.19379433989525, 52.449535578489304, 57.41829335689545, 57.570243403315544, 61.33149437606335, 61.55434861779213, 57.775800973176956, 57.472573444247246, 56.018581464886665, 44.47182185947895, 53.03639508783817, 56.50138355791569, 54.231624752283096, 56.80218681693077, 60.481536984443665, 54.779878333210945, 52.05182611942291, 47.96658933162689, 44.35341261327267, 40.135053768754005, 47.89647549390793, 46.25988811254501, 41.01902313530445, 44.11347448825836, 44.7736244648695, 44.3679316341877, 44.4060055911541, 50.418023988604546, 48.811572790145874, 55.0293805450201, 58.392792865633965, 55.46895235776901, 55.6071737408638, 56.21263325214386, 51.947597712278366, 54.24965478479862, 52.40372523665428, 52.467603608965874, 51.16801634430885, 53.82963292300701, 50.37798173725605, 53.24798293411732, 46.62251025438309, 48.828759267926216, 52.55822494626045, 53.34885612130165, 53.06324064731598, 55.98599061369896, 58.33117537200451, 58.10139410197735, 57.37453490495682, 59.62732382118702, 55.954060927033424, 58.282078206539154, 62.95532964169979, 57.87459947168827, 57.20768965780735, 64.16499093174934, 65.89424014091492, 62.39250384271145, 51.81302033364773, 48.86127032339573, 50.346496626734734, 63.05702358484268, 62.792781963944435, 60.853290036320686, 55.057328045368195, 65.67572146654129, 61.92748859524727, 67.57138654589653, 44.15883645415306, 6.1840009689331055, 1.7770625185221434, 0.20275245944503695, 0.5866817501373589, 15.64483780413866, 70.01119762659073, 58.18534679710865, 66.11969724297523, 63.47031220793724, 52.5206183642149, 16.107994951307774, 44.75518025457859, 19.06868778169155, 40.89597813785076, 22.14120101183653, 44.28363315761089, 66.03740125894547, 20.23284651339054, 0.8383369026705623, 0.1697387918829918, 0.08790955194854178, 0.17276730359299108, 0.08600907502113841, 0.016467815366922878, 0.034441099560353905, 0.3999323397874832, 0.1922258219565265, 0.4151128517696634, 0.20559488504659384, 0.2754214819287881, 0.23145291313994676, 0.2629391517257318, 0.39141669985838234, 0.9514581388793886, 0.533521237084642, 8.975942004472017, 83.62776696681976, 70.66277906298637, 55.991055741906166, 63.47340144217014, 52.307711988687515, 67.5018198788166, 34.68254394829273, 38.55092257261276, 80.08102208375931, 65.26145249605179, 78.83489415049553, 58.918399661779404, 71.61240890622139, 9.848268795758486, 0.8102239924483001, 0.48909989884123206, 2.0588701218366623, 1.6236759116873145, 1.2416123505681753, 44.90684151649475, 73.18259865045547, 73.99663656949997, 61.530941873788834, 54.92242768406868, 63.282476887106895, 69.8406171798706, 60.453369095921516, 73.75728741288185, 65.73227763175964, 22.69314419478178, 31.84293732047081, 64.84963819384575, 28.56040745973587, 29.028477743268013, 72.25028827786446, 60.35120777785778, 68.9080560207367, 61.72099247574806, 66.36292219161987, 58.09756390750408, 59.42254140973091, 59.654537960886955, 61.24719209969044, 53.43337498605251, 52.494555562734604, 52.984782457351685, 60.70222534239292, 55.77775798738003, 59.98944818973541, 55.63740871846676, 65.52486956119537, 60.75999364256859, 62.59488098323345, 61.57384917140007, 61.100124791264534, 55.1948768645525, 65.45372977852821, 63.639821112155914, 61.17662228643894, 59.82551358640194, 60.49870826303959, 54.366631507873535, 53.66533733904362, 51.67479895055294, 58.24698328971863, 53.97421136498451, 57.90793128311634, 54.03553247451782, 55.832558646798134, 50.91713860630989, 57.26879417896271, 60.751322507858276, 58.555541932582855, 63.916970640420914, 62.89493948221207, 60.25365561246872, 61.0749701410532, 57.35433518886566, 45.889415591955185, 53.67405787110329, 60.597198978066444, 56.15506254136562, 61.80837258696556, 65.88250637054443, 62.813198268413544, 55.69227397441864, 53.053015395998955, 50.18654800951481, 43.70433144271374, 54.906723126769066, 50.151445493102074, 43.88167552649975, 51.461778581142426, 48.73513609170914, 50.3513527661562, 49.15986210107803, 56.302813813090324, 51.47572383284569, 56.301700472831726, 62.629561722278595, 60.149883180856705, 60.65402492880821, 61.09037831425667, 54.70110096037388, 58.93085539340973, 54.25214745104313, 55.69862723350525, 52.11102694272995, 56.190229654312134, 52.639905363321304, 55.670626536011696, 52.012794613838196, 53.972995430231094, 53.65704618394375, 55.29074192047119, 55.032048001885414, 58.80716063082218, 58.8895858079195, 61.62227377295494, 62.09106981754303, 61.89717762172222, 57.7323617041111, 60.04546098411083, 66.66765823960304, 61.90499000251293, 60.486852899193764, 68.74236971139908, 65.2932719886303, 58.74475657939911, 48.07597406208515, 48.063252344727516, 52.72897258400917, 66.43293723464012, 64.21583220362663, 62.74560749530792, 57.29282408952713, 69.1120594739914, 64.70760181546211, 70.85969969630241, 51.33986212313175, 11.718898918479681, 2.4387578247115016, 0.8349698083475232, 1.310457056388259, 15.89688302949071, 76.70627117156982, 64.77422744035721, 69.52679201960564, 68.94477725028992, 57.909777984023094, 20.55254425853491, 43.30631040036678, 26.22779432684183, 49.4657950848341, 31.397340930998325, 57.494559064507484, 73.10768947005272, 33.24525207281113, 1.454285157378763, 0.5252875539008528, 0.23590919823618606, 0.24260249454528093, 0.2542415965581313, 0.2612409397261217, 0.20143010071478784], [0.044698022029479034, 0.019242362286604475, 0.03634732813225128, 0.043351458152756095, 0.0757188635179773, 0.04412060145114083, 0.050678058760240674, 0.04945683991536498, 0.18866674887249246, 0.08530722596333362, 1.6760843619704247, 50.036771446466446, 63.32034945487976, 33.96996058523655, 42.87059538066387, 47.105445340275764, 77.16704204678535, 12.528166193515062, 20.93436487019062, 58.87323148548603, 59.4752711802721, 56.869728192687035, 51.174920573830605, 59.030014872550964, 20.692988522350788, 0.4423860664246604, 0.2716909133596346, 1.5039616730064154, 0.4168880986981094, 0.738162521738559, 32.6387894153595, 71.37986898422241, 67.59146466851234, 57.66426935791969, 56.920717656612396, 56.85976892709732, 64.3479435145855, 60.56222565472126, 64.50691178441048, 48.2022412866354, 52.29614920914173, 56.60972334444523, 49.283070489764214, 48.21292631328106, 27.42043063044548, 55.07177487015724, 57.27337293326855, 61.98072373867035, 60.338315069675446, 57.00974687933922, 59.62393440306187, 59.776321426033974, 57.68614858388901, 55.18190436065197, 51.72918163239956, 50.76557993888855, 48.595934361219406, 52.851816192269325, 52.920349314808846, 51.85497768223286, 54.2574405670166, 56.58689796924591, 53.24533447623253, 54.61986131966114, 55.24145096540451, 53.80280636250973, 52.07246281206608, 54.18467067182064, 53.827964812517166, 53.71375814080238, 54.70110476016998, 56.493723168969154, 49.756232500076294, 45.63593879342079, 48.68122458457947, 49.51402969658375, 47.28069953620434, 48.887808099389076, 45.93091696500778, 48.30448240041733, 48.95483270287514, 56.14951103925705, 58.31921361386776, 59.7200046479702, 59.78062279522419, 60.43214723467827, 55.93179412186146, 55.67539148032665, 57.69030936062336, 47.64918856322765, 52.7442629635334, 54.64869797229767, 54.96278911828995, 60.77635936439037, 59.663695469498634, 61.14999331533909, 53.30392353236675, 49.98291313648224, 45.59027664363384, 41.63071811199188, 41.931992545723915, 40.863448083400726, 43.15716840326786, 45.772750452160835, 45.2181626111269, 42.77734458446503, 44.39153976738453, 51.9678658246994, 53.326118141412735, 52.311663776636124, 49.15206491947174, 50.54769963026047, 54.38494272530079, 51.95346459746361, 48.63041751086712, 50.25853894650936, 50.85011400282383, 53.21456752717495, 50.60445338487625, 51.23238869011402, 49.68084454536438, 50.113363936543465, 46.7961685359478, 45.73772393167019, 50.22204950451851, 49.83367994427681, 52.0230882614851, 54.11461383104324, 56.603795662522316, 54.49453264474869, 56.00927956402302, 57.03309282660484, 53.354981392621994, 56.3533017039299, 56.834595277905464, 53.97443175315857, 53.46527047455311, 57.31742016971111, 57.35739402472973, 62.17184208333492, 65.7953542470932, 61.37888923287392, 60.90728893876076, 60.97466692328453, 55.024828389286995, 57.227638587355614, 57.09173887968063, 61.71463541686535, 57.75330238044262, 64.7029584646225, 29.16608165949583, 0.8489921840373427, 0.30821930326055735, 0.04123465630982537, 0.09691029670648277, 31.78259275853634, 64.22894150018692, 48.4047894179821, 63.524691089987755, 52.268068715929985, 54.5456513017416, 13.410874977707863, 14.8686458542943, 40.08050389587879, 29.852389432489872, 41.676752641797066, 44.781965017318726, 54.38432715833187, 7.541251089423895, 0.7832317252177745, 0.05929740269493777, 0.16245501319644973, 0.0633850073791109, 0.07194861231255345, 0.018567404949862976, 0.0345008572912775, 0.03614100736740511, 0.04780609939189162, 0.12092105243937112, 0.07747134877718054, 0.09499937776126899, 0.12390117612085305, 0.042293255755794235, 0.01729887047986267, 0.220676914032083, 0.06642147491220385, 1.780616040341556, 55.97267992794514, 75.33053979277611, 39.65512812137604, 54.95473355054855, 58.084747195243835, 81.87033846974373, 21.40411466360092, 21.15182340145111, 71.19352698326111, 63.282142505049706, 66.01515725255013, 55.896452218294144, 70.55787429213524, 22.28346347808838, 0.24913472996558994, 0.10793322318932042, 1.7515649367123842, 0.7287437771447003, 0.5348124552983791, 35.90441778302193, 74.44036915898323, 70.85903093218803, 61.73841834068298, 57.814988270401955, 59.308433532714844, 64.9460618197918, 62.69638493657112, 63.45460005104542, 53.25061619281769, 53.715141266584396, 58.666788563132286, 49.055854082107544, 55.52429638803005, 33.84685859084129, 53.44106577336788, 60.69472074508667, 62.87474736571312, 62.468096986413, 59.313339069485664, 61.68769486248493, 61.219252198934555, 59.52497251331806, 55.70303499698639, 54.24444906413555, 51.875120401382446, 51.546278446912766, 54.63202826678753, 53.58285516500473, 55.70764794945717, 56.38278812170029, 58.29529769718647, 55.32242842018604, 57.84322835505009, 56.610380709171295, 56.1124250292778, 58.46257232129574, 58.96188832819462, 56.99923284351826, 57.29298748075962, 56.07313893735409, 57.131442949175835, 53.937049359083176, 49.85644072294235, 52.397064194083214, 51.93496339023113, 49.35258775949478, 53.415591940283775, 50.33279076218605, 51.83337204158306, 53.12564469873905, 57.067822962999344, 57.73676946759224, 60.13984031975269, 60.82413800060749, 60.723238214850426, 56.310299411416054, 58.05957354605198, 58.26167330145836, 45.757281482219696, 52.990390956401825, 58.14515635371208, 56.707347705960274, 61.353084817528725, 63.05431433022022, 62.30763919651508, 57.15300679206848, 52.77808494865894, 48.41667897999287, 45.10388374328613, 45.02622731029987, 45.889107808470726, 47.40941382944584, 47.87287496030331, 48.12289774417877, 46.726328283548355, 48.85707154870033, 52.2493851184845, 54.03674840927124, 56.21399737894535, 51.8804857134819, 51.32690481841564, 56.05002857744694, 56.91173493862152, 50.901981219649315, 53.004754185676575, 55.033111944794655, 55.92141307890415, 53.39938580989838, 52.724371030926704, 51.10161870718002, 51.41814172267914, 49.183994606137276, 48.513714373111725, 50.56683540344238, 52.14350380003452, 50.62668599188328, 56.11264541745186, 57.146775126457214, 58.51745277643204, 57.27042429149151, 60.2873408049345, 57.27037489414215, 58.23918230831623, 57.95997329056263, 55.612124875187874, 54.67677466571331, 60.05617640912533, 57.42054283618927, 63.21658842265606, 64.60650444030762, 62.66742669045925, 62.958616465330124, 63.55906404554844, 57.840507701039314, 58.71278889477253, 59.879086911678314, 64.75258380174637, 61.41351297497749, 68.2680031657219, 32.03907139599323, 0.8734831167384982, 0.39184367225971073, 0.22826071333838627, 0.12316449065110646, 37.47499890625477, 69.99037474393845, 53.79678748548031, 67.55879402160645, 60.17072506248951, 59.539217948913574, 17.720155343413353, 18.30408900976181, 40.298061221838, 37.32797719538212, 37.9845629632473, 51.68594375252724, 63.68452191352844, 9.677370116114616, 0.5324525444302708, 0.12916461360873654, 0.15225361450575292, 0.11770893339416943, 0.05887024104595184, 0.017618489364394918, 0.027280124049866572, 0.20504658634308726, 0.1588404571521096, 0.33673243888188154, 0.15040174825116992, 0.20984552102163434, 0.1970688402070664, 0.2124553278554231, 0.1751714909914881, 0.6008011987432837, 0.29789582127705216, 2.5384447630494833, 69.59293887019157, 82.9295240342617, 49.93111051619053, 58.77499535679817, 70.90357214212418, 83.14023792743683, 24.901042319834232, 29.542460963129997, 76.49279862642288, 70.48088282346725, 73.70695531368256, 62.47060105204582, 79.89427730441093, 26.268735229969025, 0.41580791759770364, 0.5321577633731067, 3.082352802157402, 1.4052111469209194, 1.1389681021682918, 38.988963067531586, 75.17217949032784, 74.67196673154831, 61.424410790205, 59.70699794590473, 59.81203190982342, 68.84539738297462, 64.84254777431488, 68.292276263237, 56.77534505724907, 48.302164524793625, 54.94843728840351, 53.27732115983963, 48.50591339170933, 28.039081133902073, 58.58394540846348, 61.895011737942696, 67.20285952091217, 65.6704169511795, 62.10496187210083, 61.373896300792694, 64.27731290459633, 61.34264677762985, 57.76807218790054, 55.85621237754822, 55.31086944043636, 52.359651401638985, 56.52547426521778, 56.145692244172096, 55.22637337446213, 58.77804659307003, 64.25275102257729, 56.95835083723068, 60.80014608800411, 60.262433141469955, 59.3096798658371, 60.58380089700222, 65.24443700909615, 57.48971052467823, 59.665530771017075, 59.594881162047386, 61.47383853793144, 57.929552122950554, 53.554527685046196, 55.964479967951775, 59.640353322029114, 53.165804743766785, 58.2450719922781, 57.078063413500786, 57.080145701766014, 53.483729884028435, 60.372794419527054, 59.87788997590542, 62.27806158363819, 63.62950086593628, 63.961709439754486, 58.266514241695404, 61.76280163228512, 63.577755242586136, 49.287941828370094, 56.01752892136574, 61.52536377310753, 58.037728518247604, 63.20132464170456, 66.2754736840725, 66.06469139456749, 58.62329609692097, 59.034593626856804, 54.27001789212227, 48.714203014969826, 51.83504395186901, 50.86790084838867, 51.87554217875004, 54.07070338726044, 52.24831357598305, 50.504264160990715, 53.37032496929169, 56.4481446146965, 56.295920982956886, 57.36300632357597, 56.94980129599571, 53.42782348394394, 58.36147494614124, 59.77417454123497, 55.05000203847885, 56.121027767658234, 57.01750606298447, 59.22494441270828, 55.55241107940674, 54.94907185435295, 54.493510499596596, 53.59485872089863, 51.99190333485603, 51.79761216044426, 52.399902641773224, 55.0140293687582, 55.9146798402071, 59.03489001095295, 60.859951078891754, 62.316739708185196, 60.533727183938026, 61.78561180830002, 58.82799491286278, 59.80428032577038, 59.74640563130379, 59.13616217672825, 56.6578059643507, 61.14576034247875, 61.689283177256584, 65.21662250161171, 66.07251137495041, 63.93223062157631, 63.58465567231178, 65.91373309493065, 60.750353559851646, 63.84340658783913, 61.746591702103615, 67.92407602071762, 63.016551956534386, 72.36124992370605, 41.01722963154316, 2.5209875497967005, 0.6379315000958741, 0.6204227521084249, 0.4819922021124512, 38.08186814188957, 75.84567055106163, 59.83106888830662, 71.30252033472061, 64.13132473826408, 65.33937871456146, 21.79873488843441, 20.876385681331158, 59.642549604177475, 44.73609387874603, 57.83273711800575, 59.77898508310318, 78.41381594538689, 17.79878832399845, 1.1569091957062483, 0.38200332841370255, 0.3190220345277339, 0.14779637946048751, 0.23357970057986677, 0.09176996667520143, 0.19929722766391933], [0.03833946029772051, 0.10193862923188135, 0.06449690787121654, 0.07822675121133216, 0.0824470110819675, 0.030875746051606257, 0.09893381429719739, 0.09088711522053927, 0.23263280920218676, 0.2920107386307791, 0.8510556514374912, 28.100624531507492, 68.96892115473747, 36.836496368050575, 29.76638674736023, 29.146472811698914, 36.96101188659668, 30.67919086664915, 14.673177693039179, 59.471285194158554, 58.31164062023163, 62.02876456081867, 48.75535100698471, 56.65779456496239, 48.63199822604656, 0.5777918302919716, 0.08856768850819208, 0.7558322860859334, 0.26550719048827887, 0.12210762783070095, 23.942912332713604, 69.7472333908081, 63.36057789623737, 66.52634382247925, 57.36527860164642, 61.50144025683403, 58.0970623344183, 62.06219516694546, 55.58754779398441, 54.4343438744545, 65.21368145942688, 71.74277991056442, 57.14643694460392, 53.046266958117485, 38.972661942243576, 35.930320993065834, 56.13629914820194, 59.86807510256767, 60.60536853969097, 61.04595489799976, 57.883889973163605, 59.28315728902817, 61.67594589293003, 56.57849662005901, 53.95115800201893, 49.857189282774925, 49.11882810294628, 51.23518154025078, 50.95561534166336, 50.95091499388218, 52.19637796282768, 54.920554384589195, 54.0473498404026, 53.55471387505531, 53.54423403739929, 57.42398925125599, 54.01181034743786, 54.51528713107109, 54.12960022687912, 55.67382596433163, 56.101785600185394, 58.70601385831833, 52.44730889797211, 51.748138815164566, 50.39165340363979, 51.812940537929535, 47.50548407435417, 43.808586448431015, 47.94094830751419, 50.395787581801414, 53.7499625980854, 57.53510668873787, 59.671895429492, 61.55889317393303, 59.58224304020405, 58.50292235612869, 51.12566001713276, 56.066645085811615, 58.16581204533577, 48.23620766401291, 57.77627594769001, 59.23740394413471, 54.393556863069534, 57.19638526439667, 57.5446517765522, 59.08596687018871, 56.51144161820412, 49.728045612573624, 45.79746052622795, 46.5273367613554, 43.626302629709244, 46.87681540846825, 46.69420100748539, 45.94192497432232, 45.91681972146034, 48.35788853466511, 51.571839675307274, 54.639460667967796, 52.12971813976765, 54.95459295809269, 51.40074245631695, 53.49636800587177, 51.71773664653301, 54.22480031847954, 52.47159719467163, 50.00496335327625, 53.88083137571812, 50.65309837460518, 48.965008556842804, 48.9560866355896, 51.40826225280762, 48.56140561401844, 45.434861183166504, 47.687657698988914, 50.287098214030266, 51.06708616018295, 50.20273134112358, 53.67424786090851, 52.650290206074715, 54.8544455319643, 58.3737026900053, 57.15647600591183, 58.248301818966866, 58.9090521633625, 58.41324716806412, 52.59065240621567, 54.62420828640461, 55.16075849533081, 58.478022292256355, 57.48843379318714, 57.45329327881336, 56.3926599919796, 62.4771860986948, 59.12622570991516, 55.75050964951515, 56.59363880753517, 58.253218755126, 64.132449477911, 56.74507588148117, 63.20113465189934, 10.348327662795782, 0.9566176088992506, 0.12891632068203762, 0.41419131215661764, 1.1748078977689147, 51.508664265275, 56.78247727453709, 55.02482458949089, 59.440354853868484, 57.93827265501022, 66.14877328276634, 10.224914085119963, 41.83193251490593, 32.715518698096275, 25.843133367598057, 25.263991244137287, 44.938512817025185, 42.4944269657135, 1.62382529117167, 0.388777325861156, 0.07390837941784412, 0.04473165245144628, 0.029176760363043286, 0.046558575122617185, 0.012933523521496681, 0.05118851535371505, 0.05962080096651334, 0.03826213964202907, 0.057028787123272195, 0.06744422862539068, 0.05909083331061993, 0.1052367409283761, 0.19833844708045945, 0.10040503300842829, 0.14908480719896033, 0.1923867641016841, 0.6812048843130469, 33.51945295929909, 81.10947489738464, 40.589357390999794, 36.52526646852493, 42.59342685341835, 42.771777883172035, 34.67208310961723, 14.39060965552926, 66.22225373983383, 66.5121477842331, 67.3454050719738, 54.82198007404804, 65.33058598637581, 53.11054430902004, 0.5769501754548401, 0.06308345793513581, 0.7147464563604444, 0.840522616636008, 0.2602456900058314, 27.460679970681667, 72.86120429635048, 66.94589450955391, 68.78922879695892, 61.144381016492844, 67.23043084144592, 59.95589219033718, 65.33700004220009, 52.58740358054638, 58.2106876373291, 66.29855364561081, 67.8060619533062, 53.75715561211109, 55.257721692323685, 50.859963074326515, 35.02151615917683, 56.75774060189724, 60.70578955113888, 62.66150280833244, 62.27160952985287, 59.2904756963253, 60.94536669552326, 63.72598148882389, 57.93530121445656, 56.01301856338978, 52.03730329871178, 50.61837203800678, 54.09178465604782, 53.765021190047264, 52.465992495417595, 54.699896425008774, 56.71813152730465, 58.653443679213524, 55.869097486138344, 56.28895215690136, 58.6375567317009, 56.66611231863499, 56.90257363021374, 59.249772280454636, 57.676652893424034, 58.204695358872414, 58.717500641942024, 56.092764884233475, 53.180038779973984, 53.57161156833172, 55.330164805054665, 51.27995453774929, 47.861160188913345, 49.04701575636864, 53.730154260993004, 56.66187174618244, 63.45533721148968, 58.98616902530193, 62.612686827778816, 60.32454460859299, 60.771343633532524, 52.855528593063354, 60.05113787949085, 59.62640807032585, 50.533249005675316, 58.669995591044426, 59.04131166636944, 55.372407138347626, 58.267346397042274, 60.36076806485653, 63.10425125062466, 59.263861924409866, 52.44366489350796, 51.69778011739254, 50.16938053071499, 47.65727832913399, 51.54079534113407, 50.570730194449425, 51.6392632573843, 49.9744737893343, 51.84244215488434, 52.39479951560497, 55.630158707499504, 52.79774509370327, 54.57595847547054, 52.56741665303707, 56.435567289590836, 55.389282032847404, 55.65921954810619, 54.24411468207836, 52.97431781888008, 55.706128031015396, 52.90861934423447, 51.61513075232506, 51.181053444743156, 52.70967721939087, 51.10840514302254, 46.7735293507576, 48.402167558670044, 50.900548696517944, 53.636462688446045, 52.116494849324226, 56.34357042610645, 56.10992856323719, 57.16704323887825, 59.666089341044426, 60.035790503025055, 57.54169173538685, 60.391481816768646, 60.753431394696236, 56.16141960024834, 55.98792091012001, 56.35636813938618, 62.21313066780567, 62.215414345264435, 58.36982689797878, 59.035049602389336, 62.654317393898964, 62.101082280278206, 58.395631313323975, 57.48643510043621, 59.93085153400898, 66.86514124274254, 60.02093330025673, 66.70902281999588, 12.583736311644316, 1.1692172102630138, 0.4607008758466691, 0.18474103999324143, 2.0468449546024203, 59.23944443464279, 63.56855973601341, 64.73650306463242, 66.10247656702995, 62.881081625819206, 73.58704894781113, 15.869626142084599, 39.11344438791275, 39.36818651854992, 33.459552973508835, 28.886260874569416, 52.04571984708309, 51.753051951527596, 2.1599097875878215, 0.23402329708915204, 0.06869733013445511, 0.02695321356441127, 0.04639037848392036, 0.08167820546077564, 0.039552363377879374, 0.012053202790411888, 0.13934514310676605, 0.2272863031248562, 0.19473879336146638, 0.326028413255699, 0.11708936624927446, 0.16005355690140277, 0.22486169182229787, 0.31849344726651907, 0.2845165313920006, 0.6229461135808378, 0.7817791344132274, 44.96692769229412, 93.06172594428062, 52.78929054737091, 41.180385276675224, 46.12729422748089, 51.13132171332836, 42.05814577639103, 21.085839942097664, 76.0866916179657, 70.35688787698746, 74.25495430827141, 59.70073588192463, 72.10264340043068, 57.938299253582954, 0.8672593475785106, 0.211561796895694, 1.2727006198838353, 1.251522812526673, 0.9205684682819992, 31.84989094734192, 69.99981343746185, 70.45179918408394, 70.37138789892197, 63.03352564573288, 69.48877885937691, 64.33660492300987, 66.29311993718147, 57.72561326622963, 58.51915888488293, 70.26074543595314, 68.61409619450569, 52.467554211616516, 54.973291754722595, 41.191511079669, 39.07004691660404, 59.522909224033356, 63.08844029903412, 65.41500985622406, 66.15227669477463, 62.15585254132748, 64.18078288435936, 67.62918144464493, 59.0694035589695, 58.46628092229366, 53.24268601834774, 54.17566895484924, 56.319133937358856, 57.52302713692188, 54.10762220621109, 57.7367352694273, 61.06105528771877, 59.47901397943497, 60.10313428938389, 59.76412408053875, 64.18792650103569, 60.42246535420418, 60.612394362688065, 62.87750601768494, 62.50272072851658, 60.57698406279087, 64.17059943079948, 59.78052020072937, 58.33222411572933, 58.140418007969856, 60.622608214616776, 56.81706301867962, 50.966235771775246, 54.515530318021774, 56.951887384057045, 58.70606705546379, 65.31203538179398, 62.45355136692524, 66.30048394203186, 61.71246573328972, 63.433074206113815, 56.42528884112835, 63.23174200952053, 64.06486630439758, 51.05450123548508, 63.07737909257412, 63.227243050932884, 58.282902762293816, 63.42254117131233, 60.54182454943657, 67.36433565616608, 61.89139433205128, 57.05533683300018, 54.60009478032589, 53.60792241990566, 51.9362211227417, 57.75351136922836, 54.674806371331215, 55.51999121904373, 54.19136591255665, 54.391379579901695, 56.731685400009155, 59.021792113780975, 55.61841733753681, 59.95074726641178, 57.09312200546265, 60.26875980198383, 58.519542664289474, 62.3457245528698, 58.46555896103382, 57.60833255946636, 62.055135145783424, 54.8996365070343, 53.016981929540634, 54.15624439716339, 55.555504113435745, 52.422773614525795, 51.09403431415558, 52.32903264462948, 53.212926015257835, 56.54443144798279, 53.53254206478596, 58.16374875605106, 58.154344260692596, 59.94754023849964, 61.79830312728882, 61.31528064608574, 62.74724140763283, 63.65098871290684, 63.77777650952339, 57.11727350950241, 59.93698060512543, 59.33012276887894, 64.06244203448296, 61.39903575181961, 60.43867528438568, 61.45139694213867, 67.81676217913628, 64.4601134955883, 59.76962998509407, 59.73448187112808, 62.98001691699028, 71.73679143190384, 63.598471730947495, 73.43808174133301, 22.540681175887585, 1.0915684956125915, 1.2205258570611477, 0.6191118818242103, 1.69655148871243, 63.88064458966255, 68.96702125668526, 70.68661898374557, 68.68000745773315, 69.91501718759537, 76.6794066131115, 19.235236644744873, 53.820562809705734, 52.99772836267948, 38.65933455526829, 39.27185408771038, 57.96986036002636, 69.58431333303452, 5.737288389354944, 0.6438621506094933, 0.12538251030491665, 0.1280940804281272, 0.21897090948186815, 0.21281751076458022, 0.12085051130270585, 0.10720458260038868], [0.04549629462417215, 0.027292614395264536, 0.0503794927499257, 0.04980630983482115, 0.06605169241083786, 0.06975879427045584, 0.18425165297230706, 0.060144556846353225, 0.2786137262592092, 0.2412625914439559, 0.47342384001240134, 15.263663157820702, 61.526150330901146, 42.8265405446291, 41.521359980106354, 30.52627757191658, 57.74229057133198, 65.25550961494446, 12.14379496872425, 42.30086535215378, 58.84194016456604, 61.44637741148472, 55.8555968105793, 45.126044154167175, 63.35928976535797, 5.2640442084521055, 0.19296348706120625, 0.6355128111317754, 1.1986885475926101, 0.148195001820568, 14.545402899384499, 74.9140365421772, 65.7155205309391, 62.9016537219286, 60.958669781684875, 63.91217529773712, 61.804029420018196, 63.42135563492775, 57.09427334368229, 57.38475635647774, 53.69652606546879, 46.372130289673805, 66.75052419304848, 41.50544263422489, 55.04102312028408, 46.61994159221649, 39.23599921166897, 51.9363959133625, 50.8354277908802, 57.52315632998943, 55.75022466480732, 58.923460990190506, 57.64904737472534, 58.548493310809135, 55.606474578380585, 53.1978028267622, 48.04845593869686, 51.69003613293171, 53.14137205481529, 49.59645487368107, 52.204577922821045, 53.620305955410004, 57.34754495322704, 54.82256904244423, 54.65906761586666, 54.53931324183941, 54.22303721308708, 56.99575982987881, 54.71170239150524, 56.189921870827675, 56.03142857551575, 56.09512075781822, 55.23404896259308, 56.67970798909664, 52.691160812973976, 50.827429220080376, 47.39953435957432, 42.58960425853729, 46.42922222614288, 50.46777851879597, 55.752056166529655, 56.39121226966381, 60.673989057540894, 59.873094633221626, 61.11222334206104, 58.16298119723797, 52.7386886626482, 59.64823789894581, 58.31203579902649, 56.26568980515003, 58.43213975429535, 58.09422008693218, 55.0670251250267, 56.89404308795929, 58.34938399493694, 59.025436118245125, 55.23341439664364, 54.223041012883186, 48.74542973935604, 44.8572313785553, 43.62107031047344, 43.635889515280724, 44.32413898408413, 50.01007027924061, 52.25750148296356, 51.16024196147919, 54.08921219408512, 53.839592188596725, 54.98475193977356, 55.82281216979027, 55.46878516674042, 54.97167304158211, 52.70665258169174, 55.50158500671387, 51.79415434598923, 51.47682957351208, 52.064373046159744, 52.94194735586643, 45.94964995980263, 51.73841893672943, 50.10750465095043, 46.08246423304081, 43.18951986730099, 48.22583042085171, 53.1948047876358, 53.628806099295616, 52.239608243107796, 52.72149458527565, 55.31831704080105, 55.15070803463459, 56.428860649466515, 54.83805701136589, 52.77748838067055, 57.58291192352772, 57.210566103458405, 54.14410784840584, 52.865339666604996, 53.55250999331474, 58.423054441809654, 61.167886555194855, 59.38926659524441, 55.964753553271294, 60.69013439118862, 60.57082079350948, 58.16639721393585, 58.04780177772045, 57.95628368854523, 60.4548966139555, 61.093205362558365, 55.52226349711418, 0.8574753475841135, 0.9862213453743607, 0.272988632787019, 0.23198026843601838, 9.737115260213614, 63.92893999814987, 53.26595596969128, 61.54884271323681, 50.35066120326519, 69.72906276583672, 33.90699416399002, 15.707428995519876, 43.57183255255222, 28.427940867841244, 28.079868145287037, 30.718338266015053, 53.855163753032684, 31.817182302474976, 0.7566337462048978, 0.08236506313551217, 0.08761252960539423, 0.07555945761851035, 0.040140738055924885, 0.05216121491685044, 0.057773079606704414, 0.10775275513879023, 0.05525499851501081, 0.04938511876389384, 0.05639362374495249, 0.11628527892753482, 0.06709397945087403, 0.07774762809276581, 0.15429573773872107, 0.05261467085801996, 0.2104010185576044, 0.2835676510585472, 0.5765402724500746, 18.53949397802353, 74.31600943207741, 46.93819351494312, 42.9135824739933, 48.492405116558075, 63.18968586623669, 65.32139047980309, 14.911812487989664, 45.32928004860878, 69.12041902542114, 66.64392471313477, 60.22060878574848, 50.800074487924576, 72.11666464805603, 5.86524604819715, 0.19884249893948436, 1.698435831349343, 1.2416242249310017, 0.12962070788489655, 16.47884365171194, 79.15051281452179, 66.49102851748466, 67.82430097460747, 61.600272953510284, 66.55473589897156, 62.416674345731735, 67.09112271666527, 57.45022304356098, 61.28192603588104, 54.79283183813095, 51.497158482670784, 67.25309282541275, 42.84848436713219, 62.735644429922104, 50.40762394666672, 41.61396101117134, 53.792600110173225, 53.2743801176548, 59.13125284016132, 57.4484371393919, 60.588812828063965, 59.503313675522804, 61.140927001833916, 55.41679635643959, 55.105186477303505, 49.351303428411484, 54.57552529871464, 56.39173284173012, 52.41787187755108, 52.70708575844765, 56.709946766495705, 58.7238235026598, 58.32260683178902, 56.89543381333351, 57.33675353229046, 57.825665697455406, 58.87523017823696, 58.45469534397125, 59.50032703578472, 58.61725442111492, 61.18554800748825, 59.747347980737686, 59.23469468951225, 57.94195465743542, 52.988494858145714, 51.02781526744366, 45.43213672935963, 51.71217754483223, 52.41758309304714, 59.16146881878376, 60.179297402501106, 62.430634796619415, 58.37804585695267, 63.11096549034119, 59.47983093559742, 56.023069024086, 61.15315854549408, 57.85531170666218, 54.264173805713654, 59.098240211606026, 60.59301160275936, 57.034407556056976, 57.36102283000946, 60.55575080215931, 61.06475628912449, 59.83211003243923, 54.71522860229015, 54.324278980493546, 49.304945915937424, 47.26647689938545, 47.51599431037903, 50.38238950073719, 50.73427341878414, 53.193889036774635, 56.01000152528286, 57.114309668540955, 54.13763679563999, 57.61984594166279, 57.11665414273739, 56.989402770996094, 54.68583717942238, 54.88485909998417, 56.13724909722805, 52.00283154845238, 56.086856201291084, 53.87136608362198, 54.34907644987106, 49.02883753180504, 50.96159242093563, 50.47953128814697, 48.961801528930664, 47.55609355866909, 48.75750929117203, 53.609905913472176, 54.82602685689926, 52.459981217980385, 54.694641306996346, 58.04739899933338, 57.421781569719315, 58.25220800936222, 56.69830799102783, 54.08441685140133, 59.26998719573021, 57.87999518215656, 56.818028166890144, 53.21234844624996, 57.644582614302635, 59.24004480242729, 61.54329501092434, 61.05234235525131, 58.62274892628193, 59.47675310075283, 63.934738487005234, 61.34495325386524, 59.03414525091648, 61.444530710577965, 62.39654302597046, 62.61780135333538, 59.382411763072014, 2.009608377702534, 0.8628776483237743, 0.7943825237452984, 0.17418676492525265, 13.182052206248045, 75.12208297848701, 57.789271250367165, 67.68698394298553, 55.8398200571537, 76.77139967679977, 42.64447711408138, 19.35912899672985, 43.904010728001595, 37.24364832043648, 35.283736288547516, 29.015957415103912, 64.3048158288002, 34.91287238895893, 1.2684448482468724, 0.0739076075842604, 0.07442991627613083, 0.020935331012879033, 0.03961544221965596, 0.02378510016569635, 0.03475446399534121, 0.023926232533995062, 0.1902766601415351, 0.17542101588333026, 0.21256644220557064, 0.23378952057100832, 0.1524441535002552, 0.2125770549173467, 0.3765180258778855, 0.18217246688436717, 0.2938714512856677, 0.6145459518302232, 1.0426502767950296, 27.7360150963068, 84.33908119797707, 61.68270952999592, 53.732555732131004, 50.033989995718, 77.36694931983948, 76.67777270078659, 20.27628008276224, 51.28473088145256, 74.78941082954407, 72.72981494665146, 67.86141738295555, 56.654260754585266, 78.57491210103035, 6.5174634754657745, 0.23956335528055206, 3.325484893284738, 1.8629677151329815, 0.42968011228367686, 20.16087457537651, 76.55089750885963, 67.97570005059242, 72.52929970622063, 64.00047495961189, 68.91231179237366, 64.9475209414959, 66.43258765339851, 62.09041245281696, 62.66124062240124, 53.95691469311714, 61.20697505772114, 65.85521623492241, 48.263900578022, 56.690696999430656, 44.99326407909393, 46.78464375436306, 55.202575251460075, 55.366027280688286, 62.023938819766045, 60.19910953938961, 62.449200600385666, 62.29172945022583, 61.47835649549961, 60.234341248869896, 57.839591950178146, 52.015469670295715, 58.19414712488651, 56.468135342001915, 54.831312373280525, 57.010499238967896, 59.953399524092674, 61.42485536634922, 60.706473514437675, 62.25544899702072, 60.847054570913315, 62.79697693884373, 64.01423782110214, 62.447296902537346, 61.92112013697624, 64.24132883548737, 63.19852039217949, 61.95909909904003, 62.77520410716534, 58.473743721842766, 57.08503603935242, 53.91065217554569, 49.965597465634346, 54.910074546933174, 55.720791444182396, 61.39146275818348, 63.4777408093214, 66.27836912870407, 63.60380284488201, 64.62635457515717, 61.995273157954216, 59.68993306159973, 63.26012268662453, 62.716162875294685, 57.76926152408123, 60.22009581327438, 62.034718841314316, 62.154754400253296, 62.6882191747427, 61.178168803453445, 64.21573340892792, 63.41775722801685, 63.2060781866312, 56.14879667758942, 52.0253149420023, 51.54072314500809, 48.26391197741032, 52.23960064351559, 56.62148371338844, 57.17770166695118, 59.30654123425484, 59.96464692056179, 57.790711373090744, 60.64566917717457, 62.10564203560352, 59.72774863243103, 60.48673890531063, 57.93188899755478, 60.60386002063751, 55.9044735878706, 58.35308499634266, 57.9759856313467, 56.64455987513065, 51.629509180784225, 54.03084732592106, 52.795940190553665, 50.51125958561897, 49.43268746137619, 53.53818096220493, 56.93048693239689, 58.366844058036804, 54.125264659523964, 57.932143583893776, 60.017027109861374, 60.423612892627716, 60.204524248838425, 58.305625542998314, 54.267646819353104, 62.35363572835922, 59.14723478257656, 59.17612083256245, 55.79165764153004, 57.57195331156254, 64.56879526376724, 65.46294808387756, 61.091894432902336, 60.34898489713669, 61.81624196469784, 66.01003512740135, 65.35339996218681, 61.727949902415276, 61.1455437541008, 67.54442319273949, 67.40656659007072, 69.68449875712395, 4.816263411194086, 1.1509175109677017, 2.062762062996626, 0.2813374379184097, 13.085108008235693, 78.13561007380486, 62.4605467915535, 74.19965207576752, 61.167244389653206, 82.0687410235405, 46.51021108031273, 24.98030796647072, 53.91994267702103, 46.7279963940382, 41.36776082217693, 42.46498994529247, 71.31335735321045, 53.29243674874306, 1.9718506350181997, 0.17430810607038438, 0.19074353040196002, 0.18874335335567594, 0.2628735755570233, 0.13314867013832554, 0.16053433500928804, 0.15754368767375126], [0.07264254265464842, 0.047032087604748085, 0.08080956613412127, 0.07755503334919922, 0.0358922468876699, 0.07019436074187979, 0.09914569003740326, 0.08329890755703673, 0.3110317757818848, 0.27685062086675316, 0.4903265798930079, 6.393879381939769, 52.63661853969097, 54.613922238349915, 34.20774422585964, 21.13735757768154, 39.86917443573475, 48.7397338449955, 14.035858791321516, 37.500506937503815, 64.58730027079582, 61.3077874481678, 64.48912113904953, 49.34757202863693, 67.48956173658371, 18.623355478048325, 0.23933576827403158, 0.6139358470682055, 1.1737947771325707, 0.050560673262225464, 6.246981164440513, 43.304494097828865, 69.51316595077515, 67.88112312555313, 57.910841926932335, 65.67313000559807, 62.537739649415016, 63.43925267457962, 49.643667340278625, 70.55345892906189, 59.908079355955124, 57.33652174472809, 44.46489103138447, 62.862428426742554, 51.37027569115162, 61.27148039638996, 53.152676448225975, 53.11902165412903, 56.8476589769125, 59.78050880134106, 60.89458242058754, 62.16602839529514, 57.84569442272186, 57.085978388786316, 54.60474193096161, 53.99620458483696, 47.8655793517828, 48.67062695324421, 53.30921284854412, 51.626704931259155, 48.74240130186081, 55.86895689368248, 56.00738726556301, 56.72025181353092, 53.898785412311554, 55.332190096378326, 55.057886615395546, 56.652930825948715, 52.282629534602165, 54.81833986938, 57.24622339010239, 57.113462314009666, 55.27913734316826, 54.623345732688904, 56.32915019989014, 50.98848357796669, 49.68527510762215, 46.2078233063221, 50.66784918308258, 52.506939098238945, 56.75403580069542, 57.07758843898773, 57.469066232442856, 57.94025234878063, 59.26973260939121, 56.82074502110481, 52.929575219750404, 56.9771446287632, 58.77520814538002, 47.687684297561646, 56.01327694952488, 58.009336441755295, 52.59963892400265, 57.018224224448204, 57.366437539458275, 58.812788128852844, 55.03483325242996, 53.04918900132179, 50.86031265556812, 48.532648757100105, 47.911925464868546, 45.80520451068878, 45.92498928308487, 48.512977212667465, 54.02855984866619, 53.55881005525589, 55.41331194341183, 53.288070783019066, 51.86258487403393, 55.241781547665596, 55.26191286742687, 53.47640007734299, 55.0112821161747, 53.755324110388756, 50.71826107800007, 53.98461900651455, 52.38126844167709, 51.20003342628479, 49.383092522621155, 48.793231174349785, 49.336092844605446, 45.10648660361767, 45.75290031731129, 47.27085426449776, 50.59927426278591, 53.829617723822594, 55.4890912771225, 56.676907539367676, 54.998640194535255, 57.167202830314636, 56.08666241168976, 61.709847673773766, 58.77546653151512, 56.16633653640747, 60.449835285544395, 55.841769352555275, 49.992283433675766, 51.78877003490925, 58.52869637310505, 57.98677325248718, 61.14519037306309, 56.77359335124493, 61.14123858511448, 58.03002253174782, 59.93809014558792, 60.54034262895584, 63.3050362765789, 60.48876039683819, 66.03598773479462, 34.88771393895149, 0.14861177711281925, 0.7302766980137676, 0.27071457356214523, 0.27416651020757854, 34.02408488094807, 52.82560519874096, 50.056158006191254, 60.69069296121597, 57.492545172572136, 64.7798815369606, 38.76877248287201, 21.250219121575356, 43.368114084005356, 24.81279395520687, 24.88749224692583, 32.92244419455528, 51.92750819027424, 14.647102542221546, 0.48395684512797743, 0.09149359830189496, 0.24785207613604143, 0.025272545935877133, 0.10839192982530221, 0.11469733522972092, 0.04879592772340402, 0.05338577713700943, 0.10594611536362208, 0.03973706909164321, 0.019689311448018998, 0.05849244706041645, 0.031805829639779404, 0.09821581610594876, 0.1496127265272662, 0.098686552955769, 0.29840630013495684, 0.3574387152912095, 0.6363490631338209, 7.974663432687521, 63.42117704451084, 61.7598719894886, 38.65579314529896, 31.138276532292366, 51.70020438730717, 50.74734851717949, 16.86746209859848, 41.66652359068394, 72.09098562598228, 67.55761608481407, 69.1089740395546, 51.88747353851795, 76.38500601053238, 20.429052785038948, 0.19615041761426255, 0.7561087212525308, 1.1681440053507686, 0.07653768989257514, 7.899398496374488, 48.201363533735275, 71.03052332997322, 68.1353522837162, 60.45522339642048, 66.48663595318794, 64.49238136410713, 62.61636883020401, 54.600698947906494, 71.17565274238586, 60.469172447919846, 59.30932268500328, 46.950466856360435, 65.68237870931625, 50.981833934783936, 62.5241781771183, 56.606504917144775, 54.238141402602196, 58.291315510869026, 62.4244449287653, 62.41284415125847, 64.75075230002403, 59.717264994978905, 59.08416956663132, 55.02835839986801, 55.03156162798405, 50.69063276052475, 51.71934016048908, 54.945731833577156, 54.56471487879753, 51.56691133975983, 57.4543534219265, 56.84856332838535, 58.68110239505768, 53.94746080040932, 59.62573930621147, 57.433059364557266, 60.30201181769371, 56.83109946548939, 58.01511973142624, 59.18103776872158, 58.97375889122486, 56.953954473137856, 57.53474570810795, 58.264371156692505, 54.6076525747776, 49.766404554247856, 51.456272676587105, 52.350372299551964, 55.57332135736942, 58.645049929618835, 58.46071042120457, 61.79079852998257, 61.620818451046944, 60.66832356154919, 58.43858040869236, 55.86234524846077, 61.775739938020706, 61.16455793380737, 50.628099516034126, 57.92897455394268, 61.25177085399628, 55.67476451396942, 59.1078194975853, 59.41140800714493, 60.06649665534496, 58.56677792966366, 56.0922709107399, 57.42315709590912, 52.724405229091644, 48.91832046210766, 51.492906510829926, 49.893959909677505, 51.96507677435875, 56.83442048728466, 56.32964797317982, 58.10755357146263, 54.63230945169926, 54.224644526839256, 57.959600910544395, 56.46290302276611, 55.77308803796768, 56.27558447420597, 56.88603311777115, 51.98243044316769, 56.44791662693024, 53.24704818427563, 51.81340791285038, 51.76519989967346, 50.46410031616688, 51.14325687289238, 47.865704745054245, 47.82995246350765, 49.76672373712063, 52.44459584355354, 54.22604665160179, 56.14508427679539, 57.512121722102165, 57.299447134137154, 57.837593257427216, 58.692839965224266, 60.613389909267426, 48.489266484975815, 58.89821134507656, 61.99215352535248, 59.61327977478504, 53.92324090003967, 53.92435424029827, 59.43394459784031, 60.73442101478577, 62.07781992852688, 60.092677250504494, 61.658926606178284, 61.32406957447529, 60.65895326435566, 62.768600061535835, 65.28777748346329, 64.55098941922188, 66.51951938867569, 39.2114183306694, 0.12621803500223905, 1.1884104553610086, 0.40313645848073065, 0.14648493030108511, 43.14587160944939, 63.4350311011076, 53.47045719623566, 66.72457918524742, 61.015678122639656, 73.56177270412445, 38.294003158807755, 24.627077020704746, 49.87156771123409, 31.553801335394382, 26.559985801577568, 33.05283799767494, 63.274459317326546, 17.921227253973484, 0.8014138683211058, 0.11899054821697064, 0.13217826752224937, 0.035610787381301634, 0.10209067302639596, 0.06508799880975857, 0.05467075388878584, 0.03809455156442709, 0.2003793531912379, 0.2963664330309257, 0.12222503559314646, 0.18746705231023952, 0.17995381640503183, 0.27376518642995507, 0.2967272652313113, 0.27312218968290836, 0.6311399582773447, 0.6407291593495756, 0.7387998781632632, 13.607577122747898, 79.15588572621346, 74.50604483485222, 47.88225285708904, 30.794793963432312, 62.36177109181881, 58.009275645017624, 23.00637848675251, 45.516222417354584, 81.08510300517082, 69.68089655041695, 75.06219819188118, 56.56962409615517, 84.03262004256248, 22.09567565470934, 0.22298273717751727, 2.106767976656556, 1.9845913513563573, 0.2828661137027666, 11.864398811012506, 48.42020899057388, 67.19855815172195, 68.5166922211647, 62.72263012826443, 68.99144634604454, 63.404811322689056, 68.26427176594734, 59.80682238936424, 68.9920923113823, 62.30240307748318, 58.15073825418949, 53.78145910799503, 67.91483491659164, 55.54485708475113, 55.21320328116417, 51.66066370904446, 56.770735904574394, 59.95236597955227, 63.15120533108711, 62.798432260751724, 67.25652784109116, 61.6790085285902, 61.37822046875954, 58.01037758588791, 57.0459209382534, 52.53773644566536, 55.42823754251003, 58.89839753508568, 57.55007028579712, 55.55939510464668, 61.94221280515194, 60.28363600373268, 61.45713083446026, 57.87288956344128, 61.38955906033516, 62.29910485446453, 66.65035396814346, 58.71454440057278, 63.324529230594635, 60.842681005597115, 65.20702421665192, 60.43289199471474, 59.27214168012142, 63.55447769165039, 60.065710097551346, 55.02365045249462, 53.92147779464722, 57.86566615104675, 58.147147446870804, 63.91267687082291, 62.8025246411562, 63.75952988862991, 63.3999589830637, 64.4460466504097, 62.21582852303982, 58.41843768954277, 63.83465185761452, 62.219556123018265, 52.58737698197365, 60.1659981161356, 65.18118560314178, 58.40206056833267, 62.954474687576294, 62.03618176281452, 64.52418565750122, 60.96648596227169, 59.99224103987217, 58.98643121123314, 57.30777248740196, 52.28006847202778, 54.65388089418411, 54.77575175464153, 56.64260298013687, 59.55786354839802, 59.42712016403675, 59.51581500470638, 57.22933329641819, 55.6485041230917, 63.110501915216446, 57.39485241472721, 57.240580692887306, 62.4449410289526, 60.55719092488289, 54.60650123655796, 60.183651968836784, 57.29200713336468, 52.361220717430115, 55.25278575718403, 53.3574740588665, 53.14256899058819, 49.36180606484413, 52.07758113741875, 50.87151825428009, 53.67305092513561, 58.908068016171455, 57.47309781610966, 60.5553974211216, 60.845321863889694, 59.43506173789501, 60.208153054118156, 63.556153401732445, 57.728542909026146, 60.81069812178612, 66.0672676563263, 61.51061676442623, 56.14305518567562, 57.66970306634903, 63.245869651436806, 63.28754961490631, 65.82115486264229, 60.56672461330891, 63.77051889896393, 62.84640468657017, 62.55711480975151, 63.6357781291008, 69.34845998883247, 67.82557010650635, 71.20035901665688, 46.93772614002228, 0.2377891176729463, 1.855742046609521, 1.701258011162281, 0.5455709248781204, 43.345482498407364, 68.4228752553463, 60.38862816989422, 68.95635142922401, 67.29785442352295, 76.0025717318058, 49.07591700553894, 29.432361871004105, 55.4524802416563, 39.01437610387802, 37.17641852796078, 49.657027423381805, 70.44879734516144, 35.233449786901474, 1.3661430682986975, 0.2453104726737365, 0.46349921787623316, 0.25025911338161677, 0.2260323555674404, 0.2616265893448144, 0.21682782447896898, 0.1003787164518144], [0.04313958983402699, 0.06490069557912648, 0.1432484688120894, 0.03770074574276805, 0.11272781630395912, 0.042958620833815075, 0.10144141255295835, 0.07731191319180652, 0.10913356542005204, 0.03998306878202129, 0.024493812234140933, 1.622863111551851, 41.669282242655754, 52.674962282180786, 37.40246839821339, 37.4914064258337, 33.00660967826843, 43.60575333237648, 12.176582459360361, 50.755867660045624, 56.092498898506165, 52.91972994804382, 60.862223356962204, 52.59183034300804, 61.41050733625889, 38.84426683187485, 0.30166777200065553, 0.5188547365833074, 1.2811013753525913, 0.10105262364959344, 2.6733232755213976, 41.11339867115021, 52.107352539896965, 65.3966872394085, 66.36193424463272, 64.76576909422874, 57.42479860782623, 56.217800974845886, 68.01160052418709, 70.05541205406189, 55.8807210624218, 65.42742758989334, 56.13505661487579, 63.50763380527496, 53.98593753576279, 45.681680738925934, 59.560914784669876, 65.59299990534782, 62.276264280080795, 59.71929408609867, 61.61421820521355, 59.56618890166283, 58.91633257269859, 54.77088801562786, 52.82764568924904, 52.732586190104485, 50.1280577480793, 47.37635560333729, 51.91592641174793, 52.79809087514877, 46.67049787938595, 48.85246239602566, 55.11949650943279, 59.742621034383774, 58.89478012919426, 54.233365058898926, 55.88403828442097, 55.008527263998985, 57.466432973742485, 55.33426098525524, 53.738027438521385, 57.497990280389786, 56.09325125813484, 55.17790697515011, 52.77141630649567, 50.369265004992485, 47.44449354708195, 46.447438448667526, 53.859468922019005, 53.58146823942661, 57.1011433750391, 55.78852280974388, 58.18429805338383, 55.97560957074165, 61.91567122936249, 53.08420032262802, 55.97603514790535, 54.288203716278076, 57.24490866065025, 42.53088980913162, 50.56272782385349, 59.179069474339485, 54.612584710121155, 56.326832324266434, 57.42661491036415, 58.071850687265396, 56.88185714185238, 56.74516707658768, 53.5304369777441, 52.88335070014, 47.02410310506821, 46.19762845337391, 45.958275496959686, 47.6375687867403, 52.509579956531525, 53.38119238615036, 53.02661441266537, 54.03392136096954, 53.14144425094128, 54.84265096485615, 53.523133769631386, 52.87178032100201, 54.98323202133179, 52.46843956410885, 53.81545588374138, 49.94158275425434, 52.5988257676363, 49.50481899082661, 47.6743508130312, 49.784548580646515, 50.185833647847176, 44.46381948888302, 44.509299248456955, 50.84165185689926, 54.882172644138336, 54.51874114573002, 58.47467467188835, 54.89003822207451, 58.5909940302372, 56.68402835726738, 59.95181500911713, 42.20289520919323, 17.204657904803753, 30.646601915359497, 56.41690269112587, 57.55001708865166, 55.941396206617355, 51.46915778517723, 54.70221810042858, 58.78288373351097, 59.66444782912731, 61.99459679424763, 60.63113495707512, 60.98134696483612, 59.44675371050835, 62.13189482688904, 65.24522736668587, 58.542010858654976, 66.55642300844193, 17.339332178235054, 0.8541984984185547, 1.8772404617629945, 0.16744942957302555, 4.899006821215153, 40.051298663020134, 57.85363979637623, 61.062970384955406, 51.858424097299576, 49.910295233130455, 68.30223932862282, 32.25609675049782, 19.16030276566744, 25.984064005315304, 32.75977872312069, 54.12353575229645, 36.27648621797562, 51.8140272796154, 10.086997635662556, 0.929235506337136, 0.1787450656411238, 0.17383544705808163, 0.07773104109219275, 0.05949022750428412, 0.04723870522866491, 0.044101409512222745, 0.055852201039670035, 0.12991455383598804, 0.01792540082533378, 0.12695878744125366, 0.16953207406913862, 0.03380484522494953, 0.06467734623583965, 0.045765438189846464, 0.08690072092576884, 0.08403576372074895, 0.291121051996015, 0.06271029124036431, 2.402705359272659, 51.31140165030956, 65.4769541323185, 36.33081950247288, 40.59610202908516, 49.01163965463638, 52.15927295386791, 16.12360641360283, 55.50080604851246, 64.36464741826057, 57.74422846734524, 69.68590468168259, 58.41703936457634, 69.44535478949547, 42.52889111638069, 0.3234029025770724, 1.4990405808202922, 1.8804366840049624, 0.06367178066284396, 3.730117818340659, 41.582278311252594, 58.02090302109718, 67.51016423106194, 65.03771290183067, 65.14992848038673, 58.96089278161526, 59.61602322757244, 71.58230692148209, 68.74085739254951, 58.718093410134315, 66.15581810474396, 55.338619351387024, 60.913057029247284, 59.85267072916031, 45.44474445283413, 58.953635171055794, 67.92264729738235, 61.96219973266125, 61.77304968237877, 63.289293721318245, 60.49510605633259, 60.66097855567932, 57.023103162646294, 54.992036148905754, 52.81750403344631, 51.29953108727932, 48.496512696146965, 53.925121799111366, 55.24959392845631, 48.47732752561569, 49.75742183625698, 58.75345051288605, 61.41183726489544, 59.31476779282093, 57.8939176350832, 57.48675808310509, 57.40124747157097, 58.736169040203094, 59.19986955821514, 57.29444660246372, 59.80998381972313, 56.05773836374283, 57.311933264136314, 54.399397149682045, 53.38217653334141, 50.25549530982971, 51.582593098282814, 55.77075116336346, 58.43171417713165, 59.014587700366974, 59.409929886460304, 61.40586778521538, 60.94674602150917, 62.836574614048004, 55.852427780628204, 56.43946588039398, 55.729553773999214, 58.08988071978092, 47.92737923562527, 50.396722331643105, 58.45701701939106, 55.679122880101204, 55.90245969593525, 59.824841022491455, 63.182515650987625, 58.57866369187832, 61.15814387798309, 58.03720034658909, 53.640064895153046, 50.00012621283531, 49.60395187139511, 49.463374614715576, 51.152000203728676, 58.258033096790314, 55.59104360640049, 54.5182129740715, 55.927469953894615, 54.88175846636295, 56.074601858854294, 56.19540497660637, 57.25276663899422, 57.39129200577736, 55.47300674021244, 56.46952226758003, 52.57809028029442, 54.34099808335304, 51.70544050633907, 49.87258605659008, 51.370066702365875, 51.51327341794968, 46.204726472496986, 45.0656083971262, 52.850813046097755, 56.624040976166725, 55.8321026712656, 59.28621232509613, 57.59075090289116, 58.92990164458752, 55.98762072622776, 61.697703525424004, 45.702887400984764, 19.602872617542744, 32.88011446595192, 60.69143392145634, 59.03070643544197, 56.223158687353134, 54.10610228776932, 57.235675156116486, 60.33936761319637, 61.87405586242676, 61.93158857524395, 61.56009390950203, 62.6449128985405, 61.40236057341099, 64.72229182720184, 64.51548412442207, 61.318407878279686, 69.82806265354156, 19.066271111369133, 0.9488995699211955, 2.685179589316249, 0.08586755488067865, 7.07645907998085, 46.16396605968475, 62.348714992403984, 64.31966543197632, 59.7845745831728, 54.971156269311905, 78.70835334062576, 33.77278916537762, 28.413380049169064, 29.490363858640194, 38.95314998924732, 49.244981333613396, 41.88535764813423, 64.16248306632042, 13.94960816949606, 1.0227873176336288, 0.06291707584750839, 0.1696664176415652, 0.05272707283438649, 0.09008627108414657, 0.012820871997973882, 0.021890495481784455, 0.05128900957060978, 0.21196559944655746, 0.19264764385297894, 0.2548512857174501, 0.17814604856539518, 0.32666152459569275, 0.12973902106750757, 0.19374027819139883, 0.22703866328811273, 0.24962594266980886, 0.6108071305789053, 0.2598524111090228, 4.031928973272443, 65.05799621343613, 77.12299481034279, 55.928062722086906, 50.199159532785416, 58.175687715411186, 56.246424838900566, 21.20334103703499, 60.60443378984928, 72.24889755249023, 62.96381838619709, 75.5289651453495, 62.74861313402653, 78.1022934615612, 46.412681713700294, 0.36220170033629984, 2.8634104505181313, 2.769035864621401, 0.14640382840298116, 7.526246644556522, 48.25645297765732, 60.47563970088959, 66.93656221032143, 66.22506558895111, 66.8240274488926, 63.40278223156929, 62.122501730918884, 69.31499138474464, 71.5303561091423, 61.82938165962696, 69.31612372398376, 57.420786023139954, 59.589907228946686, 58.7704735994339, 49.31845039129257, 58.132708221673965, 66.20305716991425, 64.94488388299942, 64.75193783640862, 65.20970687270164, 63.65855410695076, 64.32519033551216, 59.69788983464241, 56.54900260269642, 55.04750557243824, 55.167271345853806, 51.235873103141785, 58.851086273789406, 57.95577071607113, 50.01778766512871, 49.5410880446434, 61.99483998119831, 66.45572081208229, 64.10803958773613, 60.926614701747894, 61.03533446788788, 57.39136420190334, 62.39976145327091, 62.80608505010605, 57.621232867240906, 60.59093691408634, 58.28676335513592, 59.34986650943756, 57.82330982387066, 55.951727852225304, 53.08240681886673, 56.61733813583851, 60.88942229747772, 58.58642287552357, 62.80728958547115, 63.188766315579414, 64.55061703920364, 61.43354170024395, 67.78206244111061, 58.109005093574524, 62.207525968551636, 55.14664985239506, 61.149852722883224, 48.020367845892906, 52.93081395328045, 62.055906504392624, 60.36248937249184, 60.23899979889393, 63.23931500315666, 69.42802771925926, 63.39234799146652, 65.11060819029808, 60.33235318958759, 57.82372400164604, 54.554960802197456, 51.98108151555061, 53.318263962864876, 53.255251944065094, 60.50177089869976, 57.25498951971531, 57.45730206370354, 57.349501848220825, 58.2918930798769, 59.35268975794315, 58.5898806899786, 60.01576937735081, 60.88642045855522, 58.426664248108864, 62.606690749526024, 56.1003340780735, 56.81817255914211, 52.47725889086723, 53.17831747233868, 54.49566878378391, 53.4517128020525, 49.743609577417374, 48.65782544016838, 54.79101933538914, 59.30836133658886, 56.930509731173515, 61.36969372630119, 58.84219475090504, 62.34518118202686, 60.26108801364899, 64.31310698390007, 49.719944447278976, 23.051597960293293, 31.636042222380638, 63.82868617773056, 61.31700575351715, 58.62650692462921, 57.80057184398174, 60.52949421107769, 61.44641540944576, 65.97079083323479, 65.01986905932426, 63.57535757124424, 64.51597809791565, 65.15314310789108, 65.87546914815903, 69.07603740692139, 62.82883062958717, 71.93596914410591, 23.69646515697241, 0.6791888549923897, 4.115490289404988, 0.22418271575588733, 6.336843017488718, 51.230127811431885, 68.21305811405182, 68.96074399352074, 63.41927334666252, 60.45680031180382, 81.38344779610634, 43.01729790866375, 26.618723049759865, 37.16110534965992, 48.806127682328224, 68.17293226718903, 50.26203855872154, 77.74208799004555, 22.38793697208166, 1.496645521838218, 0.32637799449730664, 0.3548991453135386, 0.2211279171751812, 0.1708952063927427, 0.15838967665331438, 0.21520231326576322, 0.16956072096945718], [0.020727837654703762, 0.04594308978994377, 0.03221169907192234, 0.14191174210282043, 0.01668934644840192, 0.014391070017154561, 0.10018006578320637, 0.12446052540326491, 0.028299979676376097, 0.12749472196446732, 0.06448244341299869, 1.2572533800266683, 31.069621816277504, 55.88830165565014, 48.0346816778183, 42.27057337760925, 20.62601901590824, 31.28518994897604, 7.879460491240025, 36.393953114748, 62.40727365016937, 57.19673104584217, 49.60747428238392, 57.29165755212307, 55.946506932377815, 54.028768837451935, 1.4779464877210557, 0.5677842360455543, 2.151300637051463, 0.10149742243811488, 0.5942570592742413, 29.786295779049397, 61.45767040550709, 51.672994047403336, 63.76889258623123, 60.8369205147028, 64.34697076678276, 69.07717734575272, 67.78448671102524, 60.20591877400875, 62.08561331033707, 57.111976593732834, 55.05733944475651, 50.69106213748455, 62.393066212534904, 48.26931528747082, 54.48170453310013, 57.50107191503048, 56.36621721088886, 58.30194354057312, 57.72379316389561, 59.0171829611063, 56.92520521581173, 54.12616901099682, 54.188018292188644, 51.079025119543076, 52.58245624601841, 49.20446030795574, 49.88947235047817, 50.321611762046814, 48.0304791033268, 46.29959598183632, 55.17315723001957, 57.77949437499046, 57.65626318752766, 57.43130385875702, 54.72752094268799, 54.541737511754036, 54.4467806071043, 55.10109789669514, 57.50525549054146, 52.957735508680344, 55.22951200604439, 56.18689723312855, 53.225951716303825, 49.65250946581364, 48.709890246391296, 50.71107566356659, 52.4425895512104, 58.47704954445362, 56.955299600958824, 55.85710912942886, 56.84617705643177, 58.471513241529465, 58.54629322886467, 51.00556746125221, 58.40270273387432, 57.825665697455406, 57.25603066384792, 44.500844702124596, 48.39248567819595, 57.22761198878288, 52.88393586874008, 55.519702434539795, 57.44138091802597, 57.587437480688095, 54.40568581223488, 58.693782314658165, 53.72117154300213, 52.99063414335251, 47.52566859126091, 45.73288679122925, 43.275965228676796, 46.50821998715401, 52.62244910001755, 54.8441556841135, 55.10831370949745, 55.64243584871292, 55.273259058594704, 53.718021512031555, 54.613914638757706, 55.890862718224525, 51.98032535612583, 54.33047264814377, 52.36473932862282, 51.25212863087654, 52.52432696521282, 48.25233779847622, 45.98742373287678, 48.116624280810356, 49.46607626974583, 44.956007078289986, 44.99570734798908, 51.861209347844124, 56.07852324843407, 59.23400692641735, 55.967474207282066, 56.690472811460495, 52.15649530291557, 50.4706359654665, 50.09971886873245, 42.58793234825134, 36.70654334127903, 42.40641608834267, 59.630629643797874, 59.48605500161648, 56.62416636943817, 56.89489804208279, 51.751893013715744, 55.52846476435661, 58.22180584073067, 58.47249738872051, 62.077405750751495, 59.713096618652344, 61.46218456327915, 61.73769637942314, 63.99466887116432, 65.19224300980568, 58.47375512123108, 2.682581478729844, 0.35268220177385956, 2.41283917799592, 0.35191188217140734, 18.268551416695118, 62.10307717323303, 53.199292346835136, 58.60919885337353, 49.315699338912964, 54.62906062602997, 59.80751775205135, 22.875257022678852, 24.547959566116333, 31.592578254640102, 69.5807035267353, 59.59565632045269, 32.553335800766945, 51.235143542289734, 4.160265186801553, 0.47725272830575705, 0.06366239249473438, 0.1066002443258185, 0.04443437035661191, 0.05198071346967481, 0.12429424721631221, 0.07129240533686243, 0.1531713394797407, 0.06173441157443449, 0.027350325653969776, 0.0492094895162154, 0.14455457450821996, 0.010589929697744083, 0.027893314290849958, 0.09334409900475293, 0.12464462255593389, 0.04674919575336389, 0.18341905233683065, 0.09543996857246384, 1.6160810692235827, 37.22535230219364, 73.14152285456657, 45.61549209058285, 41.10239826142788, 31.390362605452538, 40.73030322790146, 10.5999169126153, 40.021295472979546, 69.16130483150482, 60.59240363538265, 63.55859287083149, 61.39318786561489, 62.041775062680244, 61.39297507703304, 1.7776328441686928, 0.5040947254747152, 3.287106240168214, 0.15384198864921927, 1.4492315473034978, 36.071829199790955, 64.8664028942585, 56.097233444452286, 67.17208117246628, 62.605037838220596, 65.3903491795063, 70.19729644060135, 67.20481261610985, 60.84763213992119, 64.13873434066772, 60.51358826458454, 59.539073556661606, 51.39365203678608, 61.2359257042408, 51.6955192387104, 55.327482149004936, 60.12274503707886, 57.418635338544846, 59.23988901078701, 59.28333967924118, 60.10142058134079, 57.714548259973526, 55.87293528020382, 56.72655947506428, 53.173651322722435, 52.24762201309204, 53.14573422074318, 54.281789660453796, 52.88416005671024, 49.62298884987831, 47.37331576645374, 57.52674713730812, 59.94366064667702, 61.40216678380966, 59.97867576777935, 54.582049548625946, 56.57536178827286, 55.2679393440485, 60.44942870736122, 57.99091883003712, 56.08683340251446, 57.264196425676346, 55.486610010266304, 54.06298600137234, 52.31640212237835, 50.1910013705492, 55.217014476656914, 56.068677976727486, 58.5699849575758, 59.84823256731033, 60.08939802646637, 59.33324620127678, 60.74344553053379, 63.873348981142044, 53.63845378160477, 58.5840480029583, 58.53110544383526, 59.65407058596611, 47.163251638412476, 48.43187436461449, 61.52377925813198, 57.42201715707779, 58.43797244131565, 59.68454495072365, 63.241796270012856, 59.81935031712055, 62.250110283493996, 57.10494317114353, 57.86122038960457, 50.4907862842083, 49.49110932648182, 46.67283855378628, 47.68459126353264, 55.64302481710911, 56.760119274258614, 56.44681468605995, 54.67404641211033, 58.6113191395998, 55.612090677022934, 55.849220752716064, 56.972554475069046, 56.30366876721382, 55.948520824313164, 54.44364197552204, 57.42390565574169, 53.09249147772789, 50.044891610741615, 48.88509884476662, 51.72052189707756, 50.37805013358593, 46.6679710149765, 46.16918697953224, 54.1564229875803, 56.76944777369499, 60.1869235932827, 55.26755936443806, 58.29736478626728, 52.638670429587364, 52.84688025712967, 49.808969870209694, 53.137507662177086, 42.782299518585205, 44.65396128594875, 60.57867877185345, 58.60294818878174, 59.77061793208122, 58.2004813849926, 54.158562272787094, 56.9868341088295, 60.36601558327675, 61.278977394104004, 63.50917652249336, 61.55147597193718, 63.54064643383026, 63.37125152349472, 66.86060428619385, 63.91521513462067, 58.87302249670029, 3.339273165911436, 0.47901675396133214, 3.1320265866816044, 0.7663022086489946, 21.67334731668234, 62.43794560432434, 55.070053562521935, 66.96670219302177, 55.4347237944603, 63.384983986616135, 64.08169940114021, 30.643753968179226, 28.803260028362274, 36.649238616228104, 81.29919871687889, 60.67599155008793, 37.81362533569336, 61.80052600800991, 6.618733266368508, 0.6504245765972883, 0.12012907696771435, 0.12573526793858036, 0.04023781839350704, 0.06346695532556623, 0.08217958558816463, 0.018940538247989025, 0.06175975220685359, 0.12735674186842516, 0.1258553029038012, 0.21789031277876347, 0.27254275046288967, 0.1125609666632954, 0.12888661993201822, 0.14702982996823266, 0.26056834612973034, 0.21039239480160177, 0.44661479420028627, 0.4670013237046078, 1.9408944086171687, 51.18141442537308, 83.99921223521233, 69.29202541708946, 53.7201151996851, 38.66604119539261, 42.61633202433586, 13.985321503132582, 46.2435831874609, 78.77280548214912, 66.02046936750412, 67.014739215374, 65.93235969543457, 67.37794652581215, 65.30148714780807, 2.0334430737420917, 0.9951266425196081, 5.344409896060824, 0.12849758611992002, 2.9634856805205345, 42.68691323697567, 63.405882865190506, 62.737437933683395, 72.67345637083054, 64.5867682993412, 67.31142729520798, 67.18995541334152, 66.08163088560104, 64.8802037537098, 65.9658282995224, 62.396444231271744, 61.18939720094204, 52.92437709867954, 61.05073884129524, 52.908436954021454, 59.75886516273022, 63.17951001226902, 59.47025924921036, 61.2511894851923, 61.19882829487324, 63.285915702581406, 60.21313078701496, 58.26735019683838, 58.56215737760067, 55.15332609415054, 57.24680095911026, 55.73610082268715, 54.80791702866554, 55.843897238373756, 53.15439395606518, 51.706557646393776, 59.20433811843395, 64.41122531890869, 64.98075395822525, 62.73295037448406, 56.53405800461769, 59.927553310990334, 59.86784711480141, 65.24903476238251, 61.67417898774147, 57.18451090157032, 59.90523710846901, 58.11799921095371, 57.254685536026955, 56.93475030362606, 53.23560319840908, 58.5855071246624, 58.255377039313316, 61.322412863373756, 62.2281626611948, 62.83749416470528, 62.68882714211941, 64.27208438515663, 65.9066578745842, 55.0812553614378, 62.83310540020466, 63.0627004802227, 61.527256071567535, 47.65812188386917, 51.21682472527027, 64.05050307512283, 59.17811572551727, 63.344242572784424, 65.34529119729996, 65.45746117830276, 64.1617839038372, 65.99941089749336, 57.86383084952831, 60.6350639462471, 53.96007992327213, 51.96788102388382, 50.393644496798515, 50.750148966908455, 56.131705194711685, 59.188861548900604, 58.5775313526392, 56.970616579055786, 61.059299781918526, 58.84118400514126, 59.86085169017315, 60.454243049025536, 59.11185868084431, 58.13525028526783, 55.69173060357571, 60.79229570925236, 57.03959047794342, 51.29373639822006, 52.667628675699234, 56.261525228619576, 53.084314316511154, 49.2323812097311, 49.161613807082176, 57.428625002503395, 60.52156023681164, 64.80304509401321, 56.70718811452389, 59.617056772112846, 57.38130234181881, 52.919114381074905, 52.96513371169567, 50.475632697343826, 36.81471973657608, 44.04394581913948, 63.77010852098465, 62.56702847778797, 61.617269441485405, 62.78464660048485, 54.692513421177864, 60.09073555469513, 63.079905956983566, 62.35300876200199, 66.25393643975258, 63.30564044415951, 64.55605834722519, 66.10130622982979, 69.89979520440102, 69.17900428175926, 65.4800471663475, 5.850711353123188, 0.5167554679792374, 6.371846739202738, 0.6735693721566349, 23.975077606737614, 67.62825429439545, 61.22304819524288, 71.25303938984871, 59.75097298622131, 66.34156733751297, 70.60096397995949, 34.101619720458984, 31.890142187476158, 48.1242086738348, 80.83084344863892, 75.4960361123085, 46.91086918115616, 79.1330261528492, 13.943158015608788, 1.195392224472016, 0.2913657232420519, 0.23406034510117024, 0.1287675349158235, 0.15977997158188373, 0.13746237382292747, 0.12901688169222325, 0.22887999104568735], [0.09167087511741556, 0.0356845160422381, 0.06223781034350395, 0.0993958605977241, 0.005531606984732207, 0.023811019673303235, 0.02126568135281559, 0.06683292900561355, 0.027344561021891423, 0.3599723184015602, 0.42021579982247204, 0.30127211823128164, 13.867577221244574, 52.74715080857277, 37.974045127630234, 39.98227156698704, 28.852345794439316, 39.2807874083519, 10.84969935938716, 18.215624056756496, 62.94542357325554, 59.89475727081299, 50.988745763897896, 58.10236304998398, 54.463359117507935, 61.94138064980507, 19.983319602906704, 1.8715959833934903, 1.3633144763298333, 0.11328157721436583, 0.9536523430142552, 15.835980847477913, 69.64392453432083, 62.74871952831745, 62.21395142376423, 61.04651726782322, 68.85766312479973, 61.113101094961166, 61.60288341343403, 60.04643373191357, 58.82575683295727, 60.362040996551514, 61.223652362823486, 51.92537650465965, 57.10696466267109, 49.928439259529114, 46.44654929637909, 61.74488939344883, 61.34155623614788, 62.027636021375656, 56.11651360988617, 55.39984926581383, 57.150787711143494, 55.9147634357214, 55.67642122507095, 54.29180212318897, 55.806541442871094, 52.15059041976929, 50.3498100489378, 49.09039042890072, 49.104871451854706, 46.7289387434721, 50.73581613600254, 56.76554538309574, 57.03596167266369, 54.768532142043114, 57.277168929576874, 56.92905820906162, 55.36350041627884, 54.499768763780594, 55.20297423005104, 55.05763962864876, 55.76236501336098, 52.706527188420296, 48.22445869445801, 47.70909234881401, 50.96728831529617, 53.86147141456604, 56.210801750421524, 59.491120129823685, 56.644339486956596, 57.204855009913445, 60.66701263189316, 56.28846198320389, 59.65340942144394, 48.72247137129307, 53.193520456552505, 55.66820986568928, 54.10160332918167, 45.786821097135544, 50.750741735100746, 57.55132421851158, 53.56493912637234, 53.20324793457985, 57.37817890942097, 57.38379120826721, 57.47871771454811, 56.34741961956024, 55.19362673163414, 56.483775302767754, 50.09601406753063, 45.39533190429211, 46.019342020154, 45.23839272558689, 48.93030881881714, 52.876290678977966, 55.015876069664955, 54.629110023379326, 53.20091485977173, 54.36319649219513, 53.63958232104778, 54.44165088236332, 50.97195826470852, 54.39323388040066, 55.08449658751488, 51.918844655156136, 50.1293458789587, 46.77472248673439, 46.98142759501934, 50.43828450143337, 47.15234622359276, 46.45382210612297, 47.86462560296059, 56.06137476861477, 52.97867998480797, 55.506813526153564, 54.93004247546196, 54.12059850990772, 50.86810223758221, 52.17699520289898, 52.17550188302994, 61.054987013339996, 53.21902088820934, 51.820198148489, 49.86104227602482, 54.48784880340099, 60.73695167899132, 59.175725653767586, 56.012706980109215, 55.366525053977966, 55.98733954131603, 61.16222105920315, 62.34781064093113, 61.777453646063805, 62.2421383112669, 64.37052950263023, 60.98516196012497, 60.547995418310165, 30.567655451595783, 0.11079438059823588, 0.09378161732456647, 0.4925992141943425, 1.244191937148571, 34.570176377892494, 62.44103483855724, 60.67557357251644, 59.79784347116947, 62.42310740053654, 60.07668390870094, 61.22553326189518, 19.757816903293133, 30.520135201513767, 39.93741877377033, 43.5481446236372, 34.31022472679615, 39.91313047707081, 45.8986034989357, 1.1343236826360226, 0.23147608299041167, 0.0908700680884067, 0.1820871199015528, 0.06782825294067152, 0.08296342712128535, 0.005805960427096579, 0.0563207633967977, 0.06708155589876696, 0.05275668823742308, 0.009075131147255888, 0.07104354837792926, 0.03190760406141635, 0.0326606093585724, 0.03490779912681319, 0.04588086812873371, 0.06837951281340793, 0.01959226450708229, 0.2866855915635824, 0.3322138875955716, 0.3664193255826831, 15.586019810289145, 69.58278581500053, 44.323500618338585, 38.58741581439972, 41.59253016114235, 43.3532302826643, 15.649617947638035, 20.47241985797882, 70.67788705229759, 64.11550238728523, 54.05330792069435, 66.2124502658844, 59.935855865478516, 70.7320949435234, 22.980230189859867, 2.2161624440923333, 2.367329732514918, 0.3974150639260188, 1.4457898819819093, 21.281018368899822, 71.6509160399437, 64.36246633529663, 65.80466374754906, 65.16923904418945, 71.00998163223267, 63.587513118982315, 63.77785250544548, 62.39832513034344, 63.91431838274002, 63.51491801440716, 62.43603050708771, 51.23812638223171, 56.83523364365101, 54.39544156193733, 50.385995507240295, 63.740914687514305, 62.448212653398514, 62.11241327226162, 58.85248839855194, 57.86868318915367, 59.74248804152012, 59.99610923230648, 57.199907675385475, 56.015416234731674, 59.83147166669369, 55.34126780927181, 52.136044800281525, 51.60546027123928, 51.30393125116825, 47.104734778404236, 51.56620837748051, 58.82311977446079, 59.892538189888, 56.23791329562664, 60.559056624770164, 58.29542689025402, 58.46123859286308, 57.920318618416786, 57.38502234220505, 59.217341020703316, 55.981586650013924, 53.38793322443962, 51.655568182468414, 50.553064942359924, 51.977490708231926, 55.47803767025471, 57.65149064362049, 59.35594238340855, 58.23842614889145, 59.01733115315437, 61.21262155473232, 58.71914595365524, 61.63708157837391, 52.127666249871254, 56.204277500510216, 58.39638367295265, 58.10030736029148, 49.34468798339367, 52.21965171396732, 60.37504389882088, 56.717485561966896, 57.36195757985115, 61.70619606971741, 62.04017534852028, 60.15938267111778, 59.382540956139565, 56.4043215662241, 57.16472156345844, 52.25846283137798, 48.58412079513073, 47.86543495953083, 48.06204400956631, 51.1624838411808, 56.08723998069763, 55.472546964883804, 56.98548138141632, 56.13519720733166, 57.09907628595829, 54.06245782971382, 56.837931498885155, 54.95926670730114, 57.56064131855965, 55.951317474246025, 53.330731093883514, 53.23325492441654, 48.80415938794613, 49.210053607821465, 52.30687603354454, 50.12490391731262, 48.533454313874245, 49.28217373788357, 55.48767015337944, 54.76192429661751, 55.841203182935715, 56.79823882877827, 55.982680991292, 53.47858875989914, 52.90775679051876, 55.59413284063339, 59.416746720671654, 51.05596795678139, 50.07123939692974, 50.53394816815853, 55.43074920773506, 63.912091702222824, 61.312936171889305, 56.744513511657715, 57.228333950042725, 56.81414857506752, 60.86233735084534, 62.58399456739426, 63.671405017375946, 63.82185414433479, 67.22897171974182, 62.35020451247692, 61.919604018330574, 34.465697184205055, 0.3065805521328002, 0.17495695094112307, 0.8484004845377058, 1.9506149995140731, 37.671984136104584, 66.96408793330193, 67.42950975894928, 65.79498186707497, 66.17647379636765, 67.02189043164253, 67.02747613191605, 26.26324262470007, 26.840646341443062, 44.5764796435833, 51.03708676993847, 36.90651521086693, 46.79334908723831, 53.53846214711666, 2.180176475085318, 0.17001188738504425, 0.05840270656335633, 0.02477112127962755, 0.11918350661289878, 0.046064393827691674, 0.035644929885165766, 0.023358999787888024, 0.09639601805247366, 0.13832696102326736, 0.12140076185460202, 0.23270936915650964, 0.08826820223475806, 0.2253788203233853, 0.15519766981014982, 0.18448416783940047, 0.2501135633792728, 0.10986414301441982, 0.5494901770725846, 0.7149732566904277, 0.61058116145432, 24.601187109947205, 81.00924387574196, 62.45353236794472, 50.45274272561073, 49.28384184837341, 55.9991455078125, 18.169950507581234, 25.22808127105236, 77.61833623051643, 71.37429848313332, 62.846815064549446, 70.9485313296318, 63.97161930799484, 77.94943526387215, 29.064845591783524, 3.297104691155255, 4.038777155801654, 0.5773474916350096, 3.0567932361736894, 27.465872392058372, 74.39081981778145, 63.82556274533272, 67.27312535047531, 66.57485961914062, 73.91600489616394, 66.33358016610146, 67.47484132647514, 64.51959550380707, 64.92949470877647, 66.2857711315155, 61.357226595282555, 53.352940902113914, 60.39143241941929, 51.48773118853569, 51.86883553862572, 67.922343313694, 62.859909161925316, 64.51307505369186, 58.89118552207947, 61.111349388957024, 62.18370124697685, 62.76029370725155, 59.64829109609127, 57.41351701319218, 61.57196447253227, 56.611212864518166, 54.43505443632603, 54.382358863949776, 55.03372751176357, 48.795032277703285, 55.859898179769516, 62.656874656677246, 62.45466470718384, 58.96105997264385, 65.4909297823906, 61.93139098584652, 60.7889898866415, 60.77230118215084, 61.76505111157894, 62.42980644106865, 60.47060877084732, 55.82221180200577, 53.84702458977699, 54.31724175810814, 54.3122336268425, 58.95951345562935, 61.47096589207649, 63.06930832564831, 61.55892737209797, 64.69162747263908, 64.46382969617844, 60.79502776265144, 65.31431525945663, 54.08440925180912, 58.29584486782551, 61.04568511247635, 58.065273240208626, 51.46383807063103, 55.29653660953045, 64.64779302477837, 60.128068551421165, 61.170322224497795, 64.83265310525894, 65.16166225075722, 63.84858191013336, 62.371544167399406, 58.260263577103615, 60.253556817770004, 55.027761831879616, 53.21516029536724, 50.62976762652397, 50.691563710570335, 53.14367093145847, 59.05524931848049, 59.17086951434612, 62.142036482691765, 59.1869730502367, 59.22217816114426, 56.520477533340454, 58.87013465166092, 57.381461933255196, 59.16495323181152, 58.88544023036957, 58.215175196528435, 55.171044543385506, 52.044857293367386, 52.99951046705246, 55.659485533833504, 53.4433950483799, 50.980443209409714, 51.48076996207237, 58.4964969009161, 57.874010503292084, 58.939340338110924, 59.636340737342834, 58.88100206851959, 54.50559005141258, 55.705337673425674, 53.47750201821327, 55.71257248520851, 53.60717386007309, 51.70842334628105, 54.273745492100716, 57.01106160879135, 65.5147697031498, 64.82423275709152, 59.36955705285072, 59.035554975271225, 60.49727573990822, 63.73100861907005, 64.87571239471436, 65.25697633624077, 67.51603111624718, 66.69601991772652, 67.99414426088333, 64.79429796338081, 42.24208250641823, 0.9995012171566486, 0.2830423292471096, 2.6069883350282907, 3.8158082077279687, 46.47988870739937, 69.9421401321888, 71.4256489276886, 71.6452619433403, 70.0472804903984, 68.7293592095375, 73.77035111188889, 30.606878846883774, 39.208940863609314, 55.28077505528927, 49.108146876096725, 45.37676990032196, 55.147197023034096, 74.02527943253517, 5.280212815850973, 0.38990411383565515, 0.14066131232539192, 0.23176685645012185, 0.20640949602238834, 0.1826591821736656, 0.11958445189520717, 0.20004525315016508, 0.2797333005582914], [0.05065490746346768, 0.028756391220667865, 0.15083320322446525, 0.039138872089097276, 0.02894753877626499, 0.019684142389451154, 0.04522973744315095, 0.01500583082815865, 0.07064450299367309, 0.1570292012183927, 0.08949447510531172, 0.06753668538294733, 4.03673904016614, 43.025209084153175, 43.00372123718262, 38.35924185812473, 21.596036665141582, 44.10511493682861, 16.85800440609455, 9.034390468150377, 56.90484590828419, 56.56301625072956, 51.63014754652977, 52.98519283533096, 60.432230830192566, 64.08867582678795, 47.75833770632744, 0.7379949744790792, 0.5987751355860382, 0.216105610888917, 5.416638795286417, 14.249935504049063, 47.9825484752655, 66.44788563251495, 64.8919603228569, 60.11472746729851, 64.23240691423416, 60.992670357227325, 64.90677952766418, 57.82002680003643, 66.22278571128845, 56.95932358503342, 56.003815457224846, 50.64318090677261, 58.43511499464512, 50.73337286710739, 48.44175763428211, 60.27553103864193, 60.69362260401249, 62.018801495432854, 58.551495149731636, 58.423852398991585, 56.58315137028694, 57.55329631268978, 55.404082238674164, 56.73855923116207, 57.94902607798576, 58.96479897201061, 53.54095481336117, 52.53767564892769, 48.643807992339134, 48.760492131114006, 47.28723518550396, 53.780448362231255, 56.27862051129341, 57.191821709275246, 55.188143625855446, 55.704095140099525, 55.82621678709984, 54.79041136801243, 55.7057898491621, 57.256384044885635, 52.590238228440285, 49.759268537163734, 48.05122219026089, 47.98263967037201, 53.93556743860245, 55.58325782418251, 57.13469557464123, 55.16987040638924, 57.845208048820496, 56.096940860152245, 55.278335586190224, 55.01879811286926, 54.53804790973663, 49.230952486395836, 55.155214592814445, 53.532420471310616, 55.35502687096596, 48.89685161411762, 52.83717177808285, 57.18515306711197, 53.26581157743931, 52.17889130115509, 57.3216949403286, 56.43001198768616, 56.41591094434261, 53.779547810554504, 54.91697497665882, 55.463723838329315, 53.15143771469593, 46.60437382757664, 45.18070422112942, 42.97781802713871, 47.17649392783642, 54.728839471936226, 54.035878255963326, 53.441438153386116, 54.425216764211655, 53.08296158909798, 55.34243814647198, 52.1036097407341, 54.98159810900688, 55.16713075339794, 52.95515924692154, 50.67848101258278, 47.2073520720005, 45.06017088890076, 46.62275344133377, 49.84992027282715, 46.60771764814854, 45.74004180729389, 49.21298325061798, 53.97030517458916, 54.11705709993839, 53.43869850039482, 53.79983112215996, 56.859711930155754, 55.33505134284496, 55.20548589527607, 60.108226016163826, 54.31927464902401, 50.34661442041397, 51.16550847887993, 51.58075399696827, 44.87331971526146, 53.57171796262264, 61.39009863138199, 58.28766770660877, 60.3586819767952, 54.69966843724251, 56.28031522035599, 50.5132544785738, 57.73623749613762, 57.75399014353752, 63.48058685660362, 56.601230800151825, 51.16358958184719, 7.702264124527574, 0.10574024359812029, 1.223016504663974, 2.039863779209554, 0.9757092094514519, 49.99715477228165, 63.56952868402004, 58.46861019730568, 57.48855158686638, 60.48441343009472, 62.06783406436443, 55.372236147522926, 16.297946758568287, 39.76681552827358, 29.51766349375248, 20.850537568330765, 32.724976390600204, 45.50213277339935, 25.328424386680126, 0.6470793904736638, 0.11559863647562452, 0.1023856618849095, 0.01131579743741895, 0.03352456944412552, 0.06778420647606254, 0.0769122815108858, 0.043367547914385796, 0.09547093839501031, 0.04412285386933945, 0.012046054980601184, 0.024870930865290575, 0.07647844424354844, 0.11266961708315648, 0.045167690186644904, 0.07164105889387429, 0.004642331778086373, 0.016984784306259826, 0.14235143491532654, 0.281269071274437, 0.07293447386473417, 5.199581617489457, 54.008318334817886, 52.76183322072029, 37.864618599414825, 35.472380965948105, 47.46714033186436, 19.617638625204563, 11.16404129192233, 62.899396643042564, 66.3341349363327, 54.259697645902634, 62.14114733040333, 64.94859248399734, 69.07809689640999, 52.97781743109226, 1.2327971798367798, 0.8310139237437397, 0.18318874906981364, 10.766396429389715, 19.910766296088696, 52.02229030430317, 67.30668514966965, 66.73818245530128, 62.62620270252228, 66.79197236895561, 62.92525425553322, 65.45426174998283, 59.60772067308426, 67.4783219397068, 58.181938380002975, 57.18970522284508, 53.08439031243324, 59.39747795462608, 55.168350487947464, 53.58645357191563, 61.931584775447845, 63.572044149041176, 62.08185151219368, 60.34418575465679, 58.524816781282425, 59.83157806098461, 59.84750300645828, 57.119044214487076, 59.37857776880264, 61.191099509596825, 58.53440746665001, 56.16488881409168, 53.26830804347992, 50.234634429216385, 50.08091367781162, 48.17614048719406, 55.74728362262249, 58.53574499487877, 58.30964952707291, 57.875648215413094, 58.638643473386765, 59.35745470225811, 57.67381824553013, 58.49060341715813, 56.5856858342886, 56.142553612589836, 53.33542764186859, 50.42933218181133, 51.57831832766533, 53.05227443575859, 57.33548820018768, 57.96075984835625, 58.749255537986755, 58.86800676584244, 58.376491740345955, 60.41212610900402, 59.89106386899948, 58.418209701776505, 53.82180534303188, 58.942763954401016, 57.5755213201046, 58.181132823228836, 51.16056114435196, 54.67585511505604, 61.16474412381649, 55.64153149724007, 56.33146807551384, 59.10517863929272, 58.5200784355402, 59.81596849858761, 58.07896390557289, 58.45526911318302, 58.162464424967766, 54.8426965624094, 48.086138516664505, 47.71876662969589, 46.76792085170746, 49.50278989970684, 57.17727608978748, 55.41942201554775, 55.64522869884968, 55.477076321840286, 55.17872013151646, 58.558878153562546, 56.31920613348484, 56.386747509241104, 57.74922139942646, 55.882955342531204, 52.19016149640083, 48.80772739648819, 46.58070109784603, 47.93407827615738, 49.9017608910799, 49.52501870691776, 48.64992566406727, 50.81205144524574, 55.04248604178429, 56.760636046528816, 56.71976923942566, 57.21195302903652, 57.7021761238575, 57.84185662865639, 57.04442381858826, 59.906244054436684, 53.980876207351685, 52.97209873795509, 55.3686111420393, 51.50872506201267, 48.24478380382061, 52.448456436395645, 62.91822463274002, 60.361235439777374, 60.796255096793175, 58.7676465511322, 58.666385784745216, 54.279156401753426, 58.993134051561356, 59.73645776510239, 64.68029648065567, 58.22866067290306, 52.71580249071121, 9.148165863007307, 0.30473207007162273, 3.3770412392914295, 4.074532287195325, 1.4392013917677104, 54.9161846190691, 66.41575455665588, 64.33604255318642, 63.311564326286316, 69.1208977997303, 67.9122206568718, 60.79182833433151, 19.434919729828835, 40.6089149415493, 36.432407051324844, 28.34096923470497, 39.85963694751263, 54.20347586274147, 25.829342007637024, 0.9899272746406496, 0.11119293616502546, 0.179914913023822, 0.031340525310952216, 0.1296421411097981, 0.049432285959483124, 0.11745361232897267, 0.023282627225853503, 0.09509855095529929, 0.1701210721512325, 0.08553168110665865, 0.5018780787941068, 0.1780892297392711, 0.17503541079349816, 0.21409526641946286, 0.19154602952767164, 0.13845971639966592, 0.20328506914665923, 0.21396313444711268, 0.6714915961492807, 0.2088742723572068, 8.335151989012957, 72.17984765768051, 70.2589063346386, 49.69022624194622, 39.879228696227074, 62.30659045279026, 25.191819816827774, 14.196013547480106, 70.39166361093521, 73.00396263599396, 58.6993034183979, 68.57175886631012, 70.24496868252754, 77.39265874028206, 59.436137080192566, 3.598664584569633, 1.6647778311744332, 0.4154106607893482, 12.222673036158085, 23.752502650022507, 57.25031957030296, 69.5444230735302, 68.79423692822456, 63.654039949178696, 69.20909106731415, 65.0898765027523, 67.8890722990036, 60.871126279234886, 69.21308845281601, 60.35512916743755, 59.59368422627449, 53.65808352828026, 62.456652000546455, 54.00760017335415, 51.49533458054066, 66.21839314699173, 66.05700820684433, 64.88476350903511, 63.66987369954586, 61.44084490835667, 60.48243373632431, 61.038967072963715, 59.205386862158775, 61.06986701488495, 63.226574286818504, 63.17170903086662, 57.409287840127945, 58.68334427475929, 53.654667511582375, 51.609332263469696, 51.3249821215868, 58.167453557252884, 59.94884356856346, 62.00162261724472, 61.948794052004814, 63.32221135497093, 62.82634176313877, 63.48010428249836, 64.92192551493645, 61.8788094073534, 61.54971286654472, 55.970156863331795, 54.29787799715996, 53.743765130639076, 58.69713753461838, 58.974328860640526, 63.93397852778435, 61.65910519659519, 63.788567930459976, 61.899917274713516, 63.87671560049057, 61.772240325808525, 60.97511909902096, 55.797117948532104, 63.37599366903305, 57.833717465400696, 60.55563300848007, 53.9340665191412, 57.4482661485672, 65.10455131530762, 59.570167288184166, 61.7745354026556, 64.68653574585915, 61.207168847322464, 61.8436498939991, 60.93571901321411, 63.31229388713837, 61.48961529135704, 58.20891693234444, 52.464525774121284, 52.0642514526844, 49.86270658671856, 52.937687784433365, 61.43443085253239, 58.12916301190853, 56.95977956056595, 57.37121768295765, 57.343756556510925, 61.45760960876942, 59.373562037944794, 59.80125188827515, 60.613519102334976, 57.97248601913452, 55.84518536925316, 52.16289035975933, 48.69158662855625, 50.454072654247284, 52.055808305740356, 51.321307718753815, 50.36272935569286, 53.99121545255184, 58.144738376140594, 58.88056129217148, 56.61821588873863, 56.608845591545105, 58.359392657876015, 61.419319063425064, 59.177834540605545, 58.80116455256939, 56.28253810107708, 53.58305275440216, 56.88597612082958, 53.295358791947365, 53.21295641362667, 59.59260128438473, 62.64565385878086, 62.03737869858742, 63.34184870123863, 60.6532421708107, 59.18403960764408, 55.184009447693825, 60.94228506088257, 59.05924290418625, 64.9925409257412, 60.680885687470436, 56.17975361645222, 14.637319017201662, 0.3210171649698168, 3.8604232762008905, 5.001556193456054, 3.02261620759964, 64.16925430297852, 70.09317442774773, 70.29960215091705, 66.3415065407753, 70.74797049164772, 71.30150958895683, 68.46579775214195, 24.532678686082363, 50.94821713864803, 43.45344990491867, 35.066756531596184, 48.2976845651865, 64.91462990641594, 47.7836025506258, 1.5202908217906952, 0.3764040913665667, 0.17782033479306847, 0.14153280149912462, 0.15854405821301043, 0.20827198983170092, 0.23163424950325862, 0.13637477124575526, 0.20268738793674856], [0.05403670002124272, 0.06742397541529499, 0.0021339215663829236, 0.08385009321500547, 0.11754183884477243, 0.04156683418841567, 0.03251833222748246, 0.09833494565100409, 0.07257468067109585, 0.01991570916288765, 0.18304827535757795, 0.09036661736899987, 1.1230165581218898, 25.150067657232285, 43.93007732927799, 37.62120746076107, 29.700739569962025, 33.257855996489525, 43.59981805086136, 7.0451577845960855, 41.438995599746704, 50.724500343203545, 54.17707867920399, 56.334705501794815, 63.4261167794466, 54.68714810907841, 62.50286892056465, 3.2655592588707805, 0.4942239832598716, 0.3587769262958318, 17.834722995758057, 35.014912113547325, 33.272511810064316, 68.33623990416527, 58.44075009226799, 58.84832002222538, 61.601146906614304, 62.71812357008457, 63.84697839617729, 63.21452513337135, 59.47657831013203, 61.110236048698425, 57.60593868792057, 55.90514995157719, 56.940765380859375, 49.55564506351948, 47.71027788519859, 64.2070622742176, 62.568650990724564, 61.705303117632866, 58.26904870569706, 62.29618281126022, 57.999183386564255, 61.29761539399624, 58.110224828124046, 60.13001784682274, 58.5550631582737, 60.69287784397602, 55.053159669041634, 52.00359910726547, 49.08347859978676, 47.84537963569164, 46.06794901192188, 45.85725411772728, 56.06502637267113, 56.59242287278175, 56.72869116067886, 56.012562587857246, 57.41195149719715, 55.092890337109566, 56.26470185816288, 53.94325062632561, 49.75121296942234, 47.38173991441727, 46.486127972602844, 50.03640666604042, 53.78610625863075, 56.38538338243961, 57.25037656724453, 55.63544422388077, 56.52893967926502, 57.293154671788216, 56.05045035481453, 56.60446062684059, 48.87913316488266, 48.438622802495956, 52.71181270480156, 52.656635865569115, 53.76420043408871, 48.15462224185467, 53.11484567821026, 55.36871373653412, 54.40619118511677, 48.864747136831284, 53.88173192739487, 55.99660724401474, 53.0952463299036, 55.03730691969395, 54.98382858932018, 56.04950040578842, 52.41420887410641, 50.463256761431694, 44.69957023859024, 46.163563281297684, 44.61161255836487, 52.194595858454704, 53.34813416004181, 57.048675790429115, 54.565619230270386, 56.148230507969856, 53.118683472275734, 53.04109163582325, 54.133601412177086, 54.37084548175335, 51.90704628825188, 47.29026362299919, 46.214913725852966, 44.03361797332764, 47.40852847695351, 48.04240666329861, 46.34352162480354, 47.0824109762907, 50.92327147722244, 54.02122624218464, 55.428993701934814, 54.94364574551582, 56.33105769753456, 56.03397063910961, 56.21291823685169, 58.44972521066666, 59.01022933423519, 57.02901944518089, 62.69658252596855, 54.78042930364609, 56.93570785224438, 59.430057406425476, 50.752995014190674, 56.4360536634922, 63.75619366765022, 56.57983414828777, 62.47628174722195, 61.63509048521519, 61.369317546486855, 55.44623717665672, 60.13440661132336, 50.91518551111221, 51.635767444968224, 23.910944648087025, 11.179315522313118, 6.622410994023085, 5.819359235465527, 3.3239846862852573, 3.532530083321035, 56.16716109216213, 59.769933968782425, 58.705231100320816, 61.09711155295372, 58.82017493247986, 62.91433744132519, 46.233965903520584, 21.834179386496544, 45.223030149936676, 30.26173386722803, 35.81824980676174, 35.87992049753666, 48.03076408803463, 9.16950836777687, 0.6698390410747379, 0.042535084576229565, 0.2082035638159141, 0.022554294628207572, 0.033557572751306, 0.054388307326007634, 0.0629203264543321, 0.061306856587179936, 0.02324663491890533, 0.05010450848203618, 0.05241741171630565, 0.01903323434817139, 0.14313125400803983, 0.0628622533986345, 0.03153444849886, 0.030564880798920058, 0.18774707947159186, 0.12475897266995162, 0.029862605006201193, 0.3120635391678661, 0.1132306584622711, 1.7030257475562394, 32.55765236914158, 59.23271119594574, 36.257266849279404, 36.74609921872616, 41.618767753243446, 45.89456431567669, 7.348282719030976, 42.57068507373333, 60.75295642018318, 57.50870570540428, 62.630454674363136, 68.24178457260132, 58.836001083254814, 70.17559960484505, 4.995075166225433, 1.1100845457985997, 0.5023440881632268, 21.013602018356323, 43.9700473845005, 39.40827056765556, 69.92474466562271, 58.42878833413124, 61.89413778483868, 63.915359526872635, 66.22509598731995, 63.27401474118233, 65.24930834770203, 61.69671177864075, 63.69030520319939, 57.02444449067116, 58.61931771039963, 56.48237697780132, 51.26745320856571, 52.37437181174755, 66.23451948165894, 63.38414043188095, 62.96663783490658, 60.917867571115494, 61.73043116927147, 59.32058148086071, 64.2134839296341, 58.065942004323006, 59.17987123131752, 59.74394716322422, 61.34555362164974, 55.93006141483784, 55.43732665479183, 52.85500802099705, 50.846363604068756, 48.87263551354408, 48.912400379776955, 58.57362896203995, 59.476483315229416, 59.95409108698368, 57.1249794960022, 61.87181398272514, 57.28078253567219, 58.535999581217766, 56.58250540494919, 54.47446212172508, 52.470734640955925, 51.65223956108093, 51.91209241747856, 58.4615957736969, 56.36766113340855, 59.0683738142252, 60.02962723374367, 59.454820677638054, 58.454987928271294, 59.51696254312992, 58.78210477530956, 53.996466770768166, 52.79411628842354, 57.566865384578705, 56.93900607526302, 57.21677877008915, 50.88137112557888, 56.85433901846409, 58.901251181960106, 57.624037116765976, 55.44163942337036, 57.725582867860794, 59.55659441649914, 58.69157463312149, 57.0978869497776, 57.644590213894844, 57.58194677531719, 58.62970635294914, 50.0821790099144, 47.231765761971474, 45.93545392155647, 49.310907796025276, 52.619652450084686, 57.240759283304214, 57.96404667198658, 58.751630410552025, 56.150578781962395, 56.28318786621094, 55.10311558842659, 55.67221865057945, 56.45331993699074, 53.86844024062157, 49.233198165893555, 46.62404157221317, 45.818712785840034, 48.759359791874886, 49.989813566207886, 49.26263518631458, 46.78787358105183, 51.08592174947262, 54.5342481136322, 55.82572661340237, 56.86529003083706, 57.77561858296394, 58.42906191945076, 58.67104433476925, 60.923829451203346, 58.565387204289436, 58.68980772793293, 60.76076500117779, 58.07072974741459, 57.012950107455254, 58.86440455913544, 56.97715222835541, 55.94106562435627, 66.86362132430077, 59.21221889555454, 63.20966139435768, 62.16021470725536, 63.91499474644661, 56.59791737794876, 61.25725395977497, 53.599452674388885, 56.40975907444954, 28.191857635974884, 17.681133337318897, 10.554892178624868, 9.40103279426694, 4.145572325214744, 4.78024466894567, 64.67315286397934, 67.39012867212296, 66.18619367480278, 66.62142992019653, 63.32593895494938, 68.1920376420021, 52.813818231225014, 25.6098410859704, 50.37295460700989, 35.35750553011894, 37.691872268915176, 41.51494972407818, 59.64479148387909, 10.505932755768299, 0.9372456546407193, 0.02740395695582265, 0.2893205126747489, 0.12129997077863663, 0.011977106678386917, 0.016095448336272966, 0.04976671996701043, 0.05805970446090214, 0.08992548479000106, 0.27260250819381326, 0.13223737216321751, 0.1845850850804709, 0.1997074275277555, 0.25737289572134614, 0.0992816366488114, 0.10279199515935034, 0.29852988256607205, 0.28067674837075174, 0.13031409645918757, 0.4963244393002242, 0.2848114015068859, 2.427349886856973, 47.02458567917347, 74.06919747591019, 52.17039115726948, 40.75108431279659, 57.97348536550999, 55.141219943761826, 10.463122352957726, 49.22661691904068, 71.72142505645752, 61.913326755166054, 72.16151744127274, 72.70038172602654, 65.3654833137989, 75.44828027486801, 6.2386957090348005, 1.1807418731041253, 0.9180763363838196, 25.86674340069294, 50.788728296756744, 46.36128567159176, 71.38634383678436, 61.84225536882877, 64.06501829624176, 66.60644352436066, 69.31984752416611, 68.87182876467705, 69.57231357693672, 61.23480476438999, 65.93713223934174, 56.732688546180725, 58.03616680204868, 58.258994445204735, 51.59632556140423, 51.592882946133614, 68.0712953209877, 65.15949636697769, 66.68064594268799, 62.3275501281023, 64.2688013613224, 59.682021886110306, 66.54699951410294, 62.9330438375473, 63.28367002308369, 61.84478223323822, 64.85229805111885, 57.32354924082756, 59.28540296852589, 55.774178579449654, 54.32980388402939, 50.10071441531181, 51.32812835276127, 59.63829003274441, 62.35290236771107, 63.42727571725845, 62.5154272466898, 63.75730320811272, 63.66323925554752, 63.117155358195305, 60.052049830555916, 58.931185975670815, 56.69061340391636, 55.61112932860851, 56.16407185792923, 61.17476038634777, 61.10195629298687, 61.5807344019413, 62.33853913843632, 61.682226955890656, 61.16287462413311, 62.81450539827347, 59.22586776316166, 56.44266150891781, 54.972786381840706, 60.446423068642616, 57.97421492636204, 59.355041831731796, 53.12496453523636, 58.555405139923096, 59.95013169944286, 61.80416241288185, 56.4329644292593, 60.47821596264839, 63.769272565841675, 60.88037118315697, 61.275135800242424, 60.46128787100315, 59.366479218006134, 61.272247955203056, 54.627856090664864, 51.974352076649666, 50.251862704753876, 52.059159725904465, 54.75958742201328, 57.927735820412636, 58.375461995601654, 59.99148488044739, 59.77216824889183, 59.53412622213364, 56.80404111742973, 59.384007677435875, 59.227931052446365, 56.14469289779663, 51.196229830384254, 48.51064793765545, 49.39201444387436, 51.22188985347748, 53.80712293088436, 49.80334237217903, 49.65182550251484, 55.4324097186327, 57.48315207660198, 59.31341886520386, 59.04741793870926, 59.72014144062996, 62.00502723455429, 58.71596932411194, 61.231472343206406, 61.30236133933067, 62.309656888246536, 63.78499612212181, 61.161111518740654, 58.858381882309914, 58.755095824599266, 61.50815449655056, 62.50847361981869, 65.97096562385559, 62.24624589085579, 64.74973395466805, 65.2949059009552, 62.66391567885876, 58.3173631131649, 60.20271174609661, 57.96920299530029, 57.22090154886246, 32.951147854328156, 17.43914522230625, 7.967966767027974, 14.835576228797436, 5.78341506421566, 5.897448370233178, 69.17727157473564, 69.3692372739315, 70.57600691914558, 70.35013183951378, 67.58856162428856, 73.85064840316772, 57.55230836570263, 30.059499219059944, 60.224488377571106, 46.462143659591675, 47.504792511463165, 51.441438272595406, 72.1731524169445, 22.727226465940475, 1.2772295018658042, 0.10083265107823536, 0.4590544063830748, 0.20484058099100366, 0.13021579157793894, 0.21161226293770596, 0.20015831192722544, 0.2009642100892961, 0.157234167563729], [0.10242057251161896, 0.03207967471098527, 0.08254941261839122, 0.020251490168448072, 0.012036644548061304, 0.012842923060816247, 0.01636627101106569, 0.02809185920341406, 0.10239575509331189, 0.03593884262954816, 0.14120064588496462, 0.40286821662448347, 0.4412804445018992, 15.110478177666664, 51.34003311395645, 45.600319504737854, 40.77718511223793, 22.403394542634487, 41.396840661764145, 9.518302101641893, 25.41606478393078, 62.73711495101452, 55.64176328480244, 60.13717666268349, 64.11489441990852, 57.09000237286091, 58.777887001633644, 14.61999099701643, 1.7256407090462744, 0.10205758066149428, 8.878614027053118, 65.268664509058, 36.981819570064545, 42.31077142059803, 65.69163501262665, 59.150187224149704, 55.66500283777714, 59.259169176220894, 61.75651676952839, 61.22200705111027, 59.58210624754429, 55.76204963028431, 53.36658976972103, 52.56319887936115, 58.02864320576191, 44.622954949736595, 52.96451814472675, 57.21705615520477, 60.907406732439995, 60.866589322686195, 55.82619398832321, 62.17255264520645, 61.55403323471546, 60.66382460296154, 59.79704171419144, 56.01764291524887, 53.62676940858364, 56.19581535458565, 56.014618277549744, 51.634885892271996, 52.00663894414902, 49.25217054784298, 46.257342249155045, 44.76855933666229, 51.128452867269516, 56.974465772509575, 57.457355260849, 57.41385139524937, 55.257584899663925, 54.75126586854458, 57.42352567613125, 52.31296710669994, 49.11638103425503, 48.94020348787308, 48.34293633699417, 52.809627056121826, 56.86432108283043, 57.531424686312675, 54.62343692779541, 56.36552184820175, 55.09445205330849, 57.8668212890625, 55.75255773961544, 51.300899013876915, 46.934766098856926, 48.28414589166641, 53.95651191473007, 54.362463131546974, 55.44550381600857, 50.70564955472946, 54.44588005542755, 54.920930564403534, 52.52485893666744, 46.67411528527737, 52.1157006919384, 57.7875005453825, 54.12020333111286, 53.08716036379337, 55.320783108472824, 52.13582061231136, 54.29089397192001, 52.792562171816826, 46.72711484134197, 43.07980075478554, 43.2681642472744, 50.03248147666454, 52.01943665742874, 54.509845823049545, 56.69667407870293, 54.20184575021267, 55.68792700767517, 53.82137216627598, 55.64605325460434, 50.736154317855835, 51.29202648997307, 47.69591845571995, 43.619915172457695, 42.61863850057125, 48.0700121819973, 47.8455126285553, 49.58316698670387, 46.28543794155121, 48.46633851528168, 47.44782976806164, 50.363656505942345, 52.64715537428856, 53.65997962653637, 54.81159523129463, 62.120024263858795, 57.97779053449631, 59.258800595998764, 55.46454839408398, 52.46758081018925, 55.58562129735947, 55.15045344829559, 58.3211363106966, 62.215209156274796, 51.04826956987381, 59.66371826827526, 59.807768538594246, 62.11134172976017, 58.02909538149834, 64.41102772951126, 57.712720558047295, 52.413015738129616, 49.177325963974, 40.959772914648056, 26.947008334100246, 48.3607117831707, 25.011698082089424, 1.8840112234465778, 2.0546418987214565, 14.163611736148596, 61.11132279038429, 57.499669790267944, 57.5197821110487, 56.43165349960327, 52.194398269057274, 72.50866681337357, 27.878948226571083, 24.790242165327072, 34.20854218304157, 26.18051916360855, 32.96069674193859, 39.698867574334145, 44.658722430467606, 4.08167970366776, 0.6661990145221353, 0.12591051869094372, 0.13143001939170063, 0.07896738490671851, 0.016957931547949556, 0.10342443856643513, 0.058485218542045914, 0.030350082852237392, 0.06416318632545881, 0.05678131798049435, 0.00686138069795561, 0.02281120203406317, 0.027063582056143787, 0.09354879817692563, 0.10255435947328806, 0.039810396992834285, 0.021364798885770142, 0.1544914420810528, 0.03371534221514594, 0.09114788364968263, 0.34394525340758264, 0.4528116382425651, 18.39314293116331, 67.64589294791222, 47.37889006733894, 43.89744848012924, 36.344202384352684, 46.23794808983803, 13.013933077454567, 26.87292940914631, 68.84668931365013, 56.160739436745644, 67.47684761881828, 69.09741505980492, 61.36474259197712, 67.63321682810783, 19.509942904114723, 1.4538179012015462, 0.3317758423509076, 9.126105196774006, 76.18848815560341, 42.83447451889515, 51.383119001984596, 64.75783511996269, 60.655708238482475, 57.66421616077423, 62.82819226384163, 62.98328474164009, 62.65738382935524, 61.1613243073225, 56.87896549701691, 53.99626538157463, 55.91710031032562, 56.78982987999916, 50.327915623784065, 55.64074493944645, 57.64967814087868, 63.969992995262146, 60.80824725329876, 57.97631621360779, 64.60684642195702, 64.21856045722961, 62.24185712635517, 60.92054642736912, 58.78761067986488, 57.262456119060516, 59.015351459383965, 57.95151874423027, 53.20566460490227, 56.477311849594116, 50.96930980682373, 50.511905550956726, 46.86615698039532, 53.882374092936516, 58.04902531206608, 60.07815442979336, 56.657767966389656, 58.67752678692341, 59.37232330441475, 60.976840406656265, 54.64039921760559, 53.03886115550995, 50.73313727974892, 51.58169634640217, 58.186182752251625, 59.766650944948196, 59.119788855314255, 57.205147594213486, 57.54120156168938, 59.126495495438576, 61.877217292785645, 59.98290874063969, 55.341621190309525, 51.52647390961647, 49.92475725710392, 56.89196079969406, 57.54185512661934, 59.381803795695305, 51.24927878379822, 58.370754048228264, 60.10487459599972, 56.42974600195885, 51.625899374485016, 56.60209335386753, 57.44404077529907, 57.66340300440788, 58.182306960225105, 59.12970632314682, 56.89797207713127, 58.613158240914345, 55.745607912540436, 50.280760154128075, 46.7327955365181, 46.91706284880638, 52.242024913430214, 55.67182347178459, 57.9446829110384, 58.47227320075035, 54.770333245396614, 58.63313376903534, 57.10292547941208, 58.965957909822464, 53.31497333943844, 52.907452806830406, 47.308403849601746, 45.67594684660435, 44.6534027159214, 49.71667282283306, 49.21363681554794, 51.90333768725395, 47.502759620547295, 50.53050555288792, 50.4196161031723, 51.45653486251831, 54.03421014547348, 57.7751512080431, 57.82443456351757, 61.023395508527756, 58.373018726706505, 60.22540032863617, 56.53330184519291, 56.482388377189636, 56.36388413608074, 56.72855816781521, 53.97741459310055, 64.28098350763321, 53.014033287763596, 60.517904832959175, 60.75584426522255, 61.30339868366718, 61.20289787650108, 62.54694275557995, 58.22437070310116, 53.30338396131992, 55.11565491557121, 42.87690684199333, 34.111153408885, 55.07810913026333, 23.73852699995041, 2.646447792649269, 2.1242686500772834, 18.543512262403965, 68.33877816796303, 61.918730065226555, 63.375499695539474, 64.04853478074074, 59.25254613161087, 77.48587533831596, 35.83389736711979, 33.13534677028656, 38.859450817108154, 32.39733137190342, 34.06660079956055, 43.85799899697304, 52.546255588531494, 4.17130739428103, 0.8913056447636336, 0.10401646461104974, 0.15612577000865713, 0.04536097512755077, 0.15801866218680516, 0.10593674203846604, 0.01786043507308932, 0.05522411403944716, 0.11802807173808105, 0.16409998352173716, 0.07428792858263478, 0.2128778918995522, 0.07738604632322676, 0.11675591187668033, 0.1637471665162593, 0.20346132921986282, 0.10895441097090952, 0.23527148558059707, 0.24116486543789506, 0.24405487754847854, 0.7884734845720232, 0.9669198060873896, 28.58889453113079, 79.22241255640984, 67.16073498129845, 51.49937756359577, 43.97017277777195, 56.024360954761505, 15.271410942077637, 32.49253526329994, 75.85652276873589, 65.770822763443, 72.60839626193047, 74.57482114434242, 65.54062351584435, 72.43432760238647, 24.39875867217779, 2.221618238836527, 0.2092529903165996, 16.923554688692093, 87.67527177929878, 48.15477803349495, 56.968085914850235, 68.9000840485096, 65.42163670063019, 59.31145817041397, 66.1753262579441, 64.10412579774857, 63.922313153743744, 61.77500277757645, 57.957499623298645, 55.947107300162315, 54.54710282385349, 59.62097816169262, 50.459004789590836, 52.7443465590477, 60.14539562165737, 65.9712316095829, 63.64771708846092, 61.01977050304413, 68.00608322024345, 65.80746039748192, 64.24774289131165, 60.08829228579998, 61.07339322566986, 57.11599677801132, 59.10935081541538, 60.19912853837013, 55.66589958965778, 59.88530717790127, 55.01071594655514, 52.393446788191795, 50.48176936805248, 54.818328469991684, 60.720209777355194, 63.32590475678444, 60.14926761388779, 63.09469096362591, 62.140527963638306, 63.52911785244942, 58.91377530992031, 55.88514782488346, 54.478581100702286, 54.63264383375645, 62.06696391105652, 64.80701208114624, 62.66239196062088, 60.31511351466179, 63.157003819942474, 61.30490340292454, 63.956511318683624, 62.23640441894531, 55.5432915687561, 55.65111078321934, 51.468595415353775, 61.13889791071415, 60.184852704405785, 65.02334967255592, 54.32606488466263, 61.81745409965515, 63.78852993249893, 59.59332324564457, 53.71626600623131, 60.89449882507324, 62.49302364885807, 62.560884207487106, 59.767285510897636, 63.28326724469662, 59.42282259464264, 62.69826963543892, 59.50743645429611, 53.40928427875042, 49.64602321386337, 51.2225928157568, 56.16645812988281, 58.16998042166233, 59.78398181498051, 61.37260816991329, 57.37268440425396, 60.57520195841789, 60.1852098852396, 62.597670033574104, 56.0519664734602, 54.49303172528744, 49.47747565805912, 49.24550570547581, 46.85759983956814, 51.54436334967613, 51.62472143769264, 55.613515600562096, 50.15531748533249, 51.78048647940159, 52.565592750906944, 52.532663717865944, 57.33768068253994, 56.90584525465965, 58.46762605011463, 63.456826731562614, 61.46873161196709, 64.13393899798393, 59.26658637821674, 56.200451105833054, 57.76481196284294, 60.79452618956566, 57.24766731262207, 62.92866267263889, 55.166002213954926, 62.09561437368393, 64.07865956425667, 63.279433250427246, 62.68757700920105, 65.10486289858818, 57.27535642683506, 58.522046729922295, 58.872000351548195, 48.4965430945158, 40.01814164221287, 59.164311066269875, 29.20767992734909, 7.047045808285475, 2.8096780087798834, 19.314534589648247, 72.86691918969154, 64.64898616075516, 69.53506037592888, 67.26936355233192, 64.46450605988503, 81.77946254611015, 40.17144441604614, 32.74508871138096, 47.16442197561264, 41.0118605196476, 45.09835883975029, 55.44443607330322, 71.55883178114891, 11.00692542269826, 1.2916573276743293, 0.32600644568447024, 0.28798758576158434, 0.13911059475503862, 0.1992936950409785, 0.22817444609245285, 0.23982024227734655, 0.18501413549529389, 0.1588044926756993], [0.018547663821664173, 0.08878478154656477, 0.04519778427493293, 0.049487909927847795, 0.04411711706779897, 0.10944687790470198, 0.04132421126996633, 0.0074498328376648715, 0.06676393895759247, 0.04869667660386767, 0.09406318815308623, 0.35520449455361813, 0.15338990197051316, 6.645729867741466, 49.53116677701473, 37.438224479556084, 36.99716694653034, 22.56285298615694, 42.67381154000759, 14.469265434890985, 14.507997706532478, 70.6271293759346, 60.35813860595226, 66.17759853601456, 62.235446870326996, 58.22208322584629, 56.58988080918789, 31.33679687976837, 0.34673454123549163, 0.5386464495677501, 1.0835693310946226, 13.9478849619627, 40.649470165371895, 34.57840293645859, 50.72057135403156, 55.46608351171017, 58.96362483501434, 55.77798217535019, 57.91269242763519, 55.49538753926754, 55.8099764585495, 58.17444518208504, 60.049184784293175, 59.23295058310032, 49.37082298099995, 53.9883504062891, 55.56716948747635, 48.79216343164444, 60.0311129540205, 53.95003326237202, 54.81492005288601, 60.257413610816, 56.63365826010704, 62.15495578944683, 60.73799282312393, 57.94077292084694, 55.714719370007515, 51.05680391192436, 51.743411868810654, 49.932163059711456, 52.365267500281334, 50.6078390032053, 47.78878927230835, 46.05029135942459, 46.20955601334572, 51.91623419523239, 55.926398411393166, 58.68010304868221, 57.28723458945751, 56.606440320611, 53.646710738539696, 51.77455119788647, 50.75486831367016, 48.16259041428566, 49.35662314295769, 54.58856999874115, 56.201180666685104, 55.666598752141, 56.25928334891796, 57.0496029406786, 57.692688032984734, 56.18098855018616, 51.90673090517521, 47.291639149188995, 46.72100476920605, 48.89136090874672, 54.43157762289047, 58.370119482278824, 55.31242735683918, 50.80942578613758, 55.26626743376255, 56.63761764764786, 50.2957047522068, 43.38328666985035, 47.70587392151356, 54.519090726971626, 54.77312229573727, 54.61516477167606, 55.42621225118637, 55.93927212059498, 55.760149732232094, 53.195602744817734, 51.29570469260216, 48.32310900092125, 43.83222118020058, 46.84418275952339, 51.795370280742645, 52.76834227144718, 55.436787083745, 55.806974619627, 53.88139374554157, 54.66580845415592, 54.17930155992508, 52.20175467431545, 46.66863217949867, 43.27705956995487, 45.26456572115421, 44.82963725924492, 49.51898843050003, 48.96598130464554, 46.82273671030998, 47.77367368340492, 48.74722704291344, 49.37235809862614, 51.67952589690685, 53.23638595640659, 53.68601202964783, 55.53834803402424, 55.683333054184914, 56.6020667552948, 55.567997843027115, 59.61430571973324, 57.223455011844635, 57.720061764121056, 58.20175051689148, 57.131537944078445, 58.222550600767136, 56.48179940879345, 50.62671259045601, 57.1171785145998, 60.468382090330124, 61.531268656253815, 57.16981329023838, 55.34961976110935, 46.54104642570019, 42.50930696725845, 31.104977019131184, 22.11428325623274, 22.122652307152748, 2.0632014144212008, 1.4419885422103107, 2.0481796329841018, 51.099441424012184, 57.82459035515785, 55.85912302136421, 61.10811196267605, 57.256159856915474, 58.41672018170357, 48.958191722631454, 8.943689335137606, 37.528857216238976, 23.321746364235878, 35.42665421962738, 26.633825339376926, 42.67396353185177, 34.80441860854626, 0.7387738139368594, 0.14923326642019674, 0.09900147590087727, 0.1829138575703837, 0.04024765556096099, 0.05444333757623099, 0.0446998440020252, 0.035227267726440914, 0.0337235392362345, 0.053098376738489605, 0.052675059414468706, 0.0731092867499683, 0.03639257687609643, 0.06407868539099582, 0.1481988758314401, 0.07598470081575215, 0.04418896809511352, 0.058106508004129864, 0.01798874498490477, 0.09582461629179306, 0.065414039127063, 0.18819569289917126, 0.2117112951236777, 7.429696200415492, 58.202373683452606, 47.37668998539448, 33.91777418553829, 31.927687972784042, 47.133966609835625, 17.184986360371113, 17.724751196801662, 72.0735901594162, 65.92803552746773, 71.15936681628227, 67.92561873793602, 62.104418501257896, 60.795449540019035, 35.842606499791145, 0.2091005234979093, 0.5823487357702106, 2.752463766373694, 19.19440783560276, 46.05575926601887, 41.66500747203827, 55.560341253876686, 58.96066099405289, 60.172161385416985, 57.27387070655823, 60.45552738010883, 57.35817678272724, 55.72401367127895, 58.1450005620718, 59.2875574529171, 57.78178185224533, 49.83876787126064, 59.92423988878727, 55.668798834085464, 51.407642886042595, 59.730891063809395, 57.0039863884449, 57.94926926493645, 60.87378233671188, 59.30953927338123, 61.84840723872185, 60.71621999144554, 60.293234288692474, 56.854688599705696, 52.92707875370979, 52.33363039791584, 53.11652138829231, 54.73544731736183, 51.832748875021935, 50.518634989857674, 47.749415785074234, 47.19523452222347, 54.5207816362381, 57.92968891561031, 60.03963589668274, 57.84405671060085, 59.42993961274624, 55.35568803548813, 55.274657383561134, 52.89736054837704, 51.30776904523373, 51.38296701014042, 58.77208851277828, 60.60863256454468, 58.261171728372574, 60.63646227121353, 59.09336507320404, 60.107530653476715, 58.99793319404125, 54.57518711686134, 50.38217671215534, 50.46125426888466, 53.47104236483574, 58.548493310809135, 60.20327031612396, 56.710873916745186, 52.644845098257065, 58.673381209373474, 59.74333539605141, 54.43003110587597, 46.9124460965395, 51.27987094223499, 59.191521406173706, 58.449767008423805, 57.34623022377491, 58.921667486429214, 57.925566136837006, 59.71372738480568, 56.071979999542236, 52.73217961192131, 47.82212108373642, 46.743503361940384, 49.57969777286053, 54.522563740611076, 57.39560477435589, 55.884695649147034, 58.30270729959011, 55.96341222524643, 54.851120710372925, 56.39484487473965, 53.086183816194534, 48.619379103183746, 45.11413559317589, 48.20235148072243, 45.94046965241432, 51.06560803949833, 49.650518372654915, 49.26861606538296, 50.38966991007328, 51.08896918594837, 51.39944672584534, 54.50150907039642, 54.58778344094753, 56.90409354865551, 57.33545400202274, 58.00236001610756, 58.66303436458111, 55.93737222254276, 60.55289715528488, 58.82052831351757, 59.43629287183285, 58.96166794002056, 57.58182518184185, 56.362018436193466, 58.49904656410217, 51.71323008835316, 58.820524513721466, 60.41355483233929, 62.847396433353424, 57.31956325471401, 56.255624145269394, 50.560816526412964, 48.30777682363987, 34.90874581038952, 30.42311880737543, 19.140471629798412, 2.8648189874365926, 1.8949031014926732, 7.349722366780043, 60.81191785633564, 65.840283036232, 62.10957482457161, 70.29983773827553, 64.02711153030396, 66.00825682282448, 49.92395170032978, 14.417208228260279, 39.84466195106506, 27.689915969967842, 45.35058930516243, 30.102862492203712, 50.38161814212799, 41.9269198179245, 1.3013639068230987, 0.3204299777280539, 0.09379752897075377, 0.12487574218539521, 0.05311270018864889, 0.10572024271823466, 0.020468744623940438, 0.043204705871175975, 0.0287172540629399, 0.07367323734797537, 0.136374207213521, 0.1036896524601616, 0.13007307657971978, 0.1461891399230808, 0.21207975660217926, 0.21668475324986503, 0.15597498044371605, 0.1431197952479124, 0.20831061119679362, 0.25288970035035163, 0.18072838109219447, 0.7108440657611936, 0.4671722848434001, 12.191766444593668, 74.68989416956902, 64.13062557578087, 50.63345342874527, 36.83314494788647, 62.399138286709785, 19.789459705352783, 21.385054886341095, 79.86008673906326, 73.76939356327057, 79.5512393116951, 73.47127676010132, 68.52336466312408, 67.20080763101578, 45.33379040658474, 0.6952998123597354, 1.2577771581709385, 2.911301893182099, 36.535909697413445, 55.19904524087906, 45.58367259800434, 59.351147040724754, 62.281572595238686, 63.292227163910866, 57.04375125467777, 62.38239258527756, 57.880238369107246, 58.14987950026989, 59.081543907523155, 61.5909406542778, 59.31361265480518, 56.61894924938679, 56.45682714879513, 56.67955219745636, 52.3934505879879, 59.94385823607445, 58.87568615376949, 58.05287070572376, 64.36780124902725, 62.14083954691887, 62.72816643118858, 64.63038995862007, 63.79230692982674, 57.678248807787895, 53.23400728404522, 55.46941593289375, 53.97713340818882, 59.09214533865452, 55.12375608086586, 52.23438732326031, 50.26618413627148, 50.40430672466755, 55.764850080013275, 60.38622289896011, 63.194264620542526, 62.52526491880417, 61.88031792640686, 58.827307149767876, 57.37212963402271, 55.28872422873974, 53.191916942596436, 53.49312297999859, 63.119625225663185, 63.62520329654217, 60.74995078146458, 63.074844628572464, 64.28061872720718, 63.76790463924408, 62.08774879574776, 55.91333091259003, 52.40595571696758, 53.46451811492443, 57.02994279563427, 62.03680492937565, 63.6703334748745, 60.37948966026306, 55.790335312485695, 61.66861608624458, 62.707449942827225, 59.021860510110855, 50.44824756681919, 54.90876741707325, 62.60342292487621, 61.746230721473694, 59.87313263118267, 60.46910025179386, 59.385269209742546, 63.49337697029114, 58.91553081572056, 55.24829439818859, 53.51567856967449, 50.274870470166206, 52.7458930760622, 56.30491890013218, 61.089637354016304, 57.72340178489685, 60.663433223962784, 56.82971253991127, 60.27881786227226, 59.828819409012794, 56.38087682425976, 51.25854268670082, 47.21201442182064, 51.789153814315796, 49.2904306948185, 54.61604252457619, 53.31728361546993, 52.41920180618763, 52.36149810254574, 52.153090685606, 53.67992475628853, 58.223785534501076, 60.017688274383545, 59.903063625097275, 57.78428211808205, 61.292561665177345, 62.0168673992157, 59.84841875731945, 62.76100046932697, 59.75300967693329, 62.4715244024992, 60.35252630710602, 60.408493503928185, 58.631450459361076, 58.36929872632027, 51.95895530283451, 59.77733597159386, 61.02239616215229, 64.03620064258575, 58.540004566311836, 58.69870685040951, 53.24438072741032, 50.87240360677242, 45.720689445734024, 45.29339097440243, 26.443170569837093, 5.534599665552378, 2.3920276947319508, 8.914334010332823, 67.13560312986374, 68.98313999176025, 65.9850324690342, 72.54851907491684, 65.90035021305084, 69.41491082310677, 57.304474264383316, 16.947746090590954, 45.45643262565136, 38.08373004198074, 49.06922936439514, 40.11689454317093, 61.86955310404301, 58.29319640994072, 3.087067399173975, 0.8863152062986046, 0.12100630294298753, 0.2943308703834191, 0.16176258941413835, 0.23464030382456258, 0.08866172604029998, 0.23103336221538484, 0.20949916070094332, 0.146273507270962], [0.055823305519879796, 0.015219478445942514, 0.05076615168945864, 0.025240243958251085, 0.03723213143530302, 0.020245176347089, 0.08995779789984226, 0.10529907391173765, 0.02536353509640321, 0.07433223479893059, 0.015468627625523368, 0.1350295395241119, 0.33698788611218333, 0.6811165390536189, 28.39222088456154, 46.524570509791374, 45.905538126826286, 27.5042275339365, 32.08714261651039, 42.80290201306343, 11.814314648509026, 50.27613580226898, 69.14220705628395, 55.14631167054176, 59.28495839238167, 58.463495671749115, 55.957989916205406, 61.023026928305626, 6.219862494617701, 1.7338525434024632, 0.666636050445959, 0.7307240052614361, 11.179235726594925, 41.87796704471111, 46.186837032437325, 53.447198644280434, 52.8860941529274, 58.92485551536083, 59.711443707346916, 55.49659967422485, 57.37599402666092, 54.22763876616955, 53.310527577996254, 48.94464924931526, 55.64626984298229, 63.36831048130989, 52.83242583274841, 57.21448369324207, 51.39882355928421, 46.45637936890125, 56.82914637029171, 56.61858826875687, 63.35556976497173, 61.21008709073067, 60.22167652845383, 58.77454698085785, 52.773027420043945, 50.982039123773575, 52.721688374876976, 51.864477172493935, 52.84281447529793, 51.229888424277306, 47.44683042168617, 44.85327959060669, 45.73849909007549, 45.373460277915, 52.71403178572655, 56.89858764410019, 58.85359413921833, 54.355319514870644, 53.18745598196983, 49.77234743535519, 48.22671577334404, 49.933413192629814, 55.28777427971363, 57.11399428546429, 55.11292286217213, 55.729451179504395, 57.17841982841492, 56.103579103946686, 55.62960393726826, 50.65672717988491, 47.429655343294144, 43.93261939287186, 50.60587830841541, 52.32175223529339, 54.96022425591946, 55.40264971554279, 52.579408809542656, 50.510815009474754, 55.43909355998039, 54.37727473676205, 48.305534943938255, 45.681114569306374, 44.694729298353195, 45.25579199194908, 53.44329245388508, 54.72978562116623, 52.920615300536156, 53.9453861117363, 55.065767392516136, 54.3831492215395, 54.26772281527519, 50.97566306591034, 43.96445408463478, 46.98300451040268, 49.839961007237434, 52.77498811483383, 54.81874644756317, 55.034783855080605, 55.11252388358116, 55.6661731749773, 51.40965677797794, 49.76245276629925, 43.138469606637955, 44.26917113363743, 44.965928345918655, 47.68170341849327, 48.607500940561295, 47.17237114906311, 46.947457417845726, 48.74140575528145, 47.655028849840164, 47.7775114774704, 47.53446891903877, 50.43217442929745, 52.92034171521664, 54.343958124518394, 58.16314838826656, 57.17233635485172, 58.37748348712921, 54.67245049774647, 56.53375782072544, 54.80994991958141, 52.475769370794296, 53.759705275297165, 54.245421811938286, 55.952928587794304, 53.475951701402664, 54.08839523792267, 54.01752524077892, 54.02607858181, 52.896543592214584, 50.657133758068085, 48.085503950715065, 43.19521576166153, 22.343068979680538, 2.9344426514580846, 1.4011649577878416, 0.4613034403882921, 0.21070794115075842, 36.78271785378456, 56.982243955135345, 58.85252259671688, 55.19306816160679, 57.63077415525913, 38.687559440732, 67.5338825583458, 29.1843206807971, 19.313626438379288, 41.688372418284416, 24.513877294957638, 33.88821557164192, 20.909407809376717, 55.35511426627636, 18.190680295228958, 0.6468713516369462, 0.11095052846940234, 0.13214798789704219, 0.048463894563610666, 0.01625772078114096, 0.08300141023937613, 0.08651026961160824, 0.07347204853431322, 0.06384657870512456, 0.09872320020804182, 0.021795604479848407, 0.05918254792049993, 0.041313743276987225, 0.04413703631144017, 0.0586141184612643, 0.06733295100275427, 0.10798243500175886, 0.043462394387461245, 0.08594227430876344, 0.049717482179403305, 0.03532121249008924, 0.1737170448177494, 0.30880019709002227, 1.1967377085238695, 35.045245885849, 62.26665839552879, 42.87116155028343, 37.47267723083496, 45.148614943027496, 40.68261198699474, 13.216418512165546, 54.88794073462486, 74.76267546415329, 60.768805369734764, 65.51174506545067, 63.84637042880058, 59.294036105275154, 69.99837711453438, 7.091716211289167, 0.42009925295133144, 2.203490836545825, 1.098835130687803, 13.192537743598223, 43.21703799068928, 50.857063829898834, 56.45389370620251, 56.12636648118496, 58.87394204735756, 60.616030767560005, 54.119006395339966, 56.212260872125626, 54.74729888141155, 54.91159826517105, 52.4931800365448, 60.246132016181946, 62.226038575172424, 51.88517086207867, 57.12284781038761, 50.89320749044418, 49.61522966623306, 57.0344303548336, 59.160442873835564, 66.00245833396912, 62.73312136530876, 63.63805800676346, 60.11864885687828, 55.09260535240173, 53.751885294914246, 54.67283807694912, 53.311865106225014, 55.73764733970165, 53.213036209344864, 51.08536697924137, 47.46256157755852, 47.1566703915596, 49.711771085858345, 53.78573767840862, 59.603126719594, 60.243935734033585, 56.061792746186256, 56.784548163414, 53.98146517574787, 51.161499693989754, 54.96509559452534, 57.73700885474682, 58.648876324296, 58.06740492582321, 60.077269077301025, 58.31260196864605, 57.90247857570648, 58.23340281844139, 54.323883801698685, 49.99850369989872, 48.612972646951675, 52.964597940444946, 55.98029471933842, 59.05471354722977, 58.49206253886223, 58.00276659429073, 54.76016119122505, 60.02624161541462, 57.200378850102425, 51.74620471894741, 49.336332231760025, 46.44425041973591, 49.027727991342545, 56.8172188103199, 59.73518863320351, 56.181775107979774, 59.67511385679245, 58.37791666388512, 57.050286903977394, 56.4167582988739, 52.615807056427, 47.966961711645126, 49.441909566521645, 52.664543241262436, 55.646794214844704, 56.51062086224556, 57.51179873943329, 58.57679419219494, 58.837160021066666, 55.04211366176605, 51.67521692812443, 44.61228132247925, 46.09035260975361, 46.39773331582546, 49.993218183517456, 51.21312752366066, 50.99187299609184, 49.97989609837532, 50.55023409426212, 50.452263951301575, 50.35983771085739, 50.98199352622032, 53.34642045199871, 54.56452488899231, 57.2463221848011, 59.43833716213703, 57.49495044350624, 57.81764052808285, 58.06306175887585, 56.277894750237465, 55.099638774991035, 52.4102608859539, 54.732525274157524, 53.6991973221302, 56.71018995344639, 54.52846102416515, 54.43103425204754, 54.15207602083683, 55.76413951814175, 53.16694088280201, 55.121377408504486, 53.30810710787773, 46.130163073539734, 25.86230143904686, 2.4946870235726237, 1.5162813244387507, 1.3068248075433075, 0.7737938035279512, 46.382070556283, 63.21626543998718, 65.8530655503273, 63.32992114126682, 62.73022972047329, 42.799064218997955, 75.55599689483643, 36.73631854355335, 23.238304741680622, 39.28416542708874, 30.436078011989594, 42.556660026311874, 22.196014970541, 64.04136076569557, 21.566462852060795, 0.9427810076158494, 0.056977801577886567, 0.12182713311631233, 0.060212411408429034, 0.0056732356642896775, 0.019900487714039627, 0.05465325775730889, 0.11553262243978679, 0.007797601847414626, 0.09507166294497438, 0.118224436591845, 0.10342234570998698, 0.17653549904935062, 0.14174539712257683, 0.2184194343863055, 0.25350345647893846, 0.21333325887098908, 0.13466848467942327, 0.23148264357587323, 0.3137925057671964, 0.11419168775319122, 0.29768466542009264, 0.43310815177392215, 2.1016028663143516, 49.06052403151989, 76.77584543824196, 62.75479160249233, 38.56173299252987, 55.55041618645191, 53.13764825463295, 19.345071651041508, 59.517669305205345, 82.3249688744545, 64.76003900170326, 71.84411287307739, 67.90980398654938, 66.37132734060287, 77.87641078233719, 11.175314337015152, 5.865899613127112, 3.0475376453250647, 0.9954621526412666, 17.519573606550694, 54.23569813370705, 55.579427629709244, 59.46264065802097, 60.01005068421364, 62.411624416708946, 61.48943290114403, 56.09865836799145, 57.40953102707863, 54.46083225309849, 55.513960942626, 58.305823132395744, 61.68582536280155, 61.42687305808067, 50.16794040799141, 55.59262812137604, 52.293477952480316, 47.87493444979191, 58.73423494398594, 61.04923792183399, 69.48719054460526, 64.94663938879967, 66.08191967010498, 63.24849531054497, 55.721236020326614, 56.070357486605644, 55.83071194589138, 56.45745411515236, 57.56095290184021, 54.7398778796196, 52.027157843112946, 48.18462923169136, 52.05924712121487, 52.2287218272686, 56.25263750553131, 63.410427421331406, 62.70844928920269, 57.87081107497215, 60.854042395949364, 56.72909393906593, 53.960665091872215, 57.91362337768078, 59.56979110836983, 62.63930059969425, 61.498005241155624, 62.179475873708725, 62.318977788090706, 62.23616883158684, 61.07022799551487, 55.172321274876595, 53.36927242577076, 51.21397107839584, 57.612827718257904, 58.69738832116127, 63.25317285954952, 62.77493432164192, 63.83391469717026, 56.46129950881004, 63.116710782051086, 62.400973588228226, 54.298664554953575, 53.018338456749916, 51.16501070559025, 50.6122125685215, 59.373847022652626, 61.52264691889286, 60.483368486166, 62.70657978951931, 61.529889330267906, 59.68939729034901, 60.68432070314884, 56.99013993144035, 50.83849422633648, 52.55928888916969, 55.21970093250275, 57.63189509510994, 59.4282791018486, 58.80024120211601, 61.124230697751045, 60.9257597476244, 57.0443744212389, 54.07199911773205, 47.368395030498505, 47.49159961938858, 49.85421024262905, 53.58511984348297, 53.11244420707226, 52.43771441280842, 50.51022224128246, 51.867555007338524, 53.74821849167347, 53.028198927640915, 51.817922070622444, 54.35224927961826, 56.003059297800064, 59.37387362122536, 60.102746710181236, 60.869967341423035, 60.698189958930016, 60.058163702487946, 58.75736050307751, 56.623208820819855, 53.03838238120079, 55.67519769072533, 55.48856310546398, 56.76466383039951, 53.46657760441303, 54.89870175719261, 54.51592169702053, 57.78339296579361, 52.143849581480026, 59.48685295879841, 55.05419321358204, 55.3813024610281, 36.42664276063442, 7.082758666947484, 1.349967811256647, 1.7335429787635803, 1.016643166076392, 50.00103056430817, 69.86554384231567, 70.11538803577423, 65.8429428935051, 68.1482107937336, 51.065209060907364, 80.21397694945335, 38.38821530342102, 28.724841736257076, 53.727771788835526, 38.02725747227669, 49.047004356980324, 32.70026631653309, 76.94697305560112, 37.42470860481262, 1.05519934091717, 0.15778813627548516, 0.22247706743655726, 0.27671008778270334, 0.11353105015587062, 0.21632542018778622, 0.17313244024990126, 0.16777545504737645, 0.17240371060324833, 0.19207440898753703], [0.03243465878767893, 0.09781042535905726, 0.031173538372968324, 0.04193340319034178, 0.15960178192472085, 0.0327016649680445, 0.03314219640742522, 0.0529813214961905, 0.02106956140778493, 0.06465833983384073, 0.03772822747123428, 0.1025282136106398, 0.2993414062075317, 0.5454924353398383, 14.709526542574167, 47.71608777344227, 34.6079121530056, 26.09750121831894, 25.593832544982433, 49.25772584974766, 17.174820005893707, 31.7824749648571, 66.6409532725811, 58.438120633363724, 61.44624441862106, 58.38382534682751, 54.126096814870834, 55.43889597058296, 44.844889640808105, 0.41335868183523417, 0.9711088438052684, 0.1887532536056824, 0.8098582620732486, 26.52297768741846, 42.147684171795845, 59.93437394499779, 56.55195124447346, 50.40097810328007, 57.438253685832024, 59.01376314461231, 54.91947524249554, 57.27143883705139, 55.83389237523079, 64.99253332614899, 62.898256704211235, 57.08880923688412, 55.47942079603672, 57.69870311021805, 53.998602256178856, 52.709236443042755, 55.39877392351627, 57.55397267639637, 59.63084623217583, 57.552262768149376, 62.10789531469345, 58.278871178627014, 54.474378526210785, 51.345094442367554, 54.670166820287704, 53.36445048451424, 50.97758576273918, 51.69910244643688, 50.33372551202774, 47.51756742596626, 44.413035213947296, 43.0387819558382, 45.78238673508167, 48.35757315158844, 49.69065181910992, 53.22734624147415, 49.806526601314545, 48.07803355157375, 53.31050857901573, 53.434055149555206, 55.36082535982132, 56.21104873716831, 55.87681867182255, 57.66129031777382, 57.06927068531513, 53.900141939520836, 52.26858548820019, 47.950443997979164, 46.219971254467964, 49.67274717986584, 50.807499289512634, 52.14962147176266, 53.90098549425602, 53.98880638182163, 53.84842671453953, 54.309813156723976, 55.72701171040535, 52.59017363190651, 48.62023025751114, 43.85945811867714, 45.42852312326431, 42.18553774058819, 47.042855098843575, 51.86038859188557, 52.84992389380932, 54.18864145874977, 54.343684539198875, 51.390946581959724, 55.49884535372257, 54.66384015977383, 50.2001778781414, 44.887405559420586, 47.07226172089577, 49.721829146146774, 49.97703105211258, 54.35482934117317, 53.959240168333054, 53.09249147772789, 49.27432715892792, 45.890658125281334, 42.94209994375706, 44.806241914629936, 45.82570441067219, 46.66619271039963, 48.828390687704086, 52.50939376652241, 48.504803851246834, 48.056690096855164, 49.79074984788895, 49.58805352449417, 52.652083709836006, 55.597522258758545, 55.31351409852505, 54.646053314208984, 56.331369280815125, 56.58380873501301, 58.20718802511692, 60.39652794599533, 57.361721992492676, 50.16755282878876, 49.869185239076614, 50.421709790825844, 56.77114248275757, 53.700219467282295, 50.34480191767216, 52.80746877193451, 54.79454554617405, 56.7095135897398, 51.31036810576916, 51.036687791347504, 45.023502856492996, 29.848703630268574, 6.795210046693683, 0.2860202413285151, 0.351332591380924, 2.0177302043884993, 13.322802353650331, 59.465042129158974, 51.77860178053379, 60.87540104985237, 53.611216843128204, 46.691734939813614, 51.50915823876858, 69.40030440688133, 24.59309544414282, 41.28306336700916, 39.059244096279144, 26.92696250975132, 29.785524420440197, 27.55698960274458, 46.13781586289406, 8.435455206781626, 0.637838642578572, 0.0360675087722484, 0.1494293418363668, 0.04371371527668089, 0.05876141251064837, 0.028416788154572714, 0.05674573942087591, 0.01830110566515941, 0.07229595226817764, 0.04856965060753282, 0.06179062183946371, 0.051737066387431696, 0.04368588844954502, 0.04261954840330873, 0.050919382920255885, 0.08238463356974535, 0.036758511341759004, 0.03692870435770601, 0.02145379166904604, 0.00812332767964108, 0.07578972377814353, 0.05488202106789686, 0.23441684315912426, 0.5725459149107337, 18.255580812692642, 66.09640449285507, 36.45750850439072, 30.815096274018288, 41.99974291026592, 53.47948171198368, 20.163838416337967, 37.13031180202961, 70.78857511281967, 62.19910942018032, 65.86630403995514, 65.76475828886032, 59.07076768577099, 60.66845275461674, 53.29932577908039, 0.9650378383230418, 4.2371307872235775, 1.0289263632148504, 1.1996945436112583, 30.217040665447712, 49.89320755004883, 62.18617111444473, 58.85132186114788, 53.59069414436817, 59.108864441514015, 59.96055833995342, 53.317431807518005, 58.80896553397179, 57.462720572948456, 66.31765142083168, 64.22104552388191, 56.16458863019943, 57.74705171585083, 57.29347005486488, 55.3814772516489, 53.80968779325485, 55.034639462828636, 60.776910334825516, 62.18090459704399, 60.43239042162895, 63.78184989094734, 60.69197729229927, 56.28856837749481, 54.065315276384354, 55.90213291347027, 55.48035554587841, 54.63648922741413, 55.0448153167963, 52.941536977887154, 49.38621215522289, 46.98230914771557, 45.602549985051155, 49.00604635477066, 51.51216767728329, 53.53585548698902, 56.24397397041321, 54.418168142437935, 51.24664552509785, 54.640137031674385, 54.77295130491257, 56.30857430398464, 59.46557030081749, 59.56788741052151, 59.934928715229034, 57.905472815036774, 58.85858327150345, 57.96592757105827, 53.178264275193214, 48.08178015053272, 52.457401156425476, 54.858005940914154, 56.014409288764, 58.34396928548813, 60.224484577775, 55.77658765017986, 56.96627341210842, 59.131572023034096, 55.298839285969734, 51.39894135296345, 46.59495793282986, 46.984399035573006, 48.44070889055729, 52.748921513557434, 55.65456859767437, 58.0185167491436, 58.84380206465721, 58.47478486597538, 56.03482939302921, 57.97010734677315, 55.534495040774345, 52.86933705210686, 48.29599365592003, 51.592008993029594, 53.49720016121864, 55.24480998516083, 59.04362954199314, 56.241390109062195, 55.321546867489815, 53.13650071620941, 48.0264513194561, 44.34653118252754, 48.4211665391922, 46.88545994460583, 48.263345807790756, 50.0954706966877, 53.88794459402561, 50.821554735302925, 51.447191163897514, 51.408311650156975, 50.664740949869156, 52.00196139514446, 57.52495363354683, 55.44496424496174, 57.37607382237911, 55.7162506878376, 58.84753726422787, 58.66631738841534, 59.49367739260197, 59.34775002300739, 52.064570635557175, 49.526246041059494, 50.53239785134792, 55.33822417259216, 53.99362072348595, 51.327413991093636, 52.16188341379166, 53.89322251081467, 54.21665355563164, 52.440568059682846, 57.209125980734825, 49.405226334929466, 32.91640631854534, 9.145397711545229, 0.5603574751876295, 1.0741534363478422, 1.8377438373863697, 19.96276270598173, 67.99864321947098, 56.7667081207037, 68.36925253272057, 58.1414819508791, 51.15705393254757, 54.938930198550224, 72.06926599144936, 27.261735945940018, 41.72451987862587, 42.74644084274769, 36.8972285091877, 31.316013894975185, 28.852929063141346, 58.81419025361538, 9.474709890782833, 0.7230160001199692, 0.08272513834526762, 0.12790392735041678, 0.060517953606904484, 0.05988486453134101, 0.06357550184475258, 0.03930215199943632, 0.042346022455603816, 0.029718119985773228, 0.07250245485920459, 0.14038118126336485, 0.14944730181014165, 0.1461791357723996, 0.1407536948681809, 0.31470407091546804, 0.285925097996369, 0.10652605924406089, 0.272436534287408, 0.07506744339480065, 0.17162555392133072, 0.16096535953693092, 0.17254978010896593, 0.6616018549539149, 0.9807543293572962, 26.64135843515396, 80.05098849534988, 55.111858919262886, 34.84667994081974, 49.26903024315834, 64.79633465409279, 23.006011806428432, 40.156363025307655, 78.71064841747284, 66.72754302620888, 75.25031849741936, 67.24400371313095, 67.19035819172859, 63.12427617609501, 63.66196632385254, 1.8177155870944262, 7.658593067899346, 0.4401004296960309, 1.3596634659916162, 39.33164767920971, 54.83663968741894, 64.83584493398666, 57.235279977321625, 56.117212772369385, 60.30938722193241, 61.92299723625183, 55.92077851295471, 60.103928446769714, 59.1178547590971, 63.54388765990734, 59.1789934784174, 55.498024597764015, 57.97671899199486, 61.60600304603577, 56.57772146165371, 53.16797822713852, 57.06929728388786, 61.198284924030304, 62.81194433569908, 62.81618490815163, 67.58325710892677, 61.6069719940424, 58.21245834231377, 55.726544335484505, 57.72134229540825, 56.66374884545803, 55.22976279258728, 58.27275350689888, 54.63492751121521, 51.678712740540504, 49.46383059024811, 47.66392797231674, 52.212853878736496, 52.98296995460987, 56.38569876551628, 59.812886863946915, 58.214833214879036, 52.687224224209785, 57.69719839096069, 57.423506677150726, 59.66448202729225, 62.44659014046192, 63.14722694456577, 63.14586281776428, 61.74268551170826, 60.431440472602844, 59.97672267258167, 56.246835216879845, 51.600626930594444, 56.14034593105316, 58.173415437340736, 58.04255425930023, 59.522179663181305, 64.53357875347137, 60.31129091978073, 61.248734816908836, 63.33716355264187, 58.56240816414356, 54.45585072040558, 49.05887871980667, 51.97785168886185, 50.76936833560467, 53.6254470795393, 59.264830872416496, 61.08343608677387, 60.04886940121651, 59.980507269501686, 57.89990231394768, 61.158360466361046, 59.18830297887325, 56.84753358364105, 51.56665675342083, 54.0267663449049, 57.53582864999771, 58.228596076369286, 59.464297369122505, 59.34631370007992, 56.61773331463337, 52.72850900888443, 50.96802547574043, 47.9329839348793, 50.493537336587906, 48.46392184495926, 49.42495867609978, 52.001038044691086, 56.24408796429634, 51.688387021422386, 52.54245959222317, 54.7776098549366, 52.55255565047264, 57.62006253004074, 60.114210695028305, 57.70130217075348, 59.077865704894066, 61.098221093416214, 61.23417019844055, 62.79791168868542, 62.518907859921455, 64.10453617572784, 53.166644498705864, 50.8706708997488, 53.82737584412098, 58.637161552906036, 50.54619491100311, 51.66463069617748, 52.99955606460571, 55.81409923732281, 53.077953457832336, 57.44718700647354, 59.80268061161041, 54.59142744541168, 41.63955643773079, 12.946883775293827, 0.5379944283049554, 1.752891659270972, 4.549690615385771, 19.88143377006054, 76.29135623574257, 59.469605684280396, 72.88644254207611, 63.21466572582722, 59.6969398856163, 59.827318489551544, 80.07156819105148, 33.853721022605896, 50.93718633055687, 52.02785320580006, 45.303019657731056, 43.07953476905823, 40.33730551600456, 70.99939540028572, 20.364589244127274, 1.180336601100862, 0.16958540480118245, 0.357756206067279, 0.12066849958500825, 0.25686591980047524, 0.11121232848381624, 0.1465152099262923, 0.11755310464650393, 0.09997026805649512, 0.16623578063445166], [0.02533608305384405, 0.08018443288165145, 0.026094955028383993, 0.03191920754034072, 0.07897343341028318, 0.01934256149979774, 0.02116120551363565, 0.052477859644568525, 0.04819920759473462, 0.09230245763319544, 0.01237332726304885, 0.06809405313106254, 0.2892461494775489, 0.07529175010859035, 5.096635641530156, 45.90703904628754, 44.51867334544659, 44.32818576693535, 18.95465400069952, 39.61664378643036, 16.689608842134476, 19.355923868715763, 66.85882598161697, 61.61788880825043, 63.169231563806534, 56.40454575419426, 59.25897158682346, 53.71894486248493, 62.98898063600063, 29.32138692587614, 1.213804967701435, 2.2599047468975186, 0.4193439841037616, 12.949315644800663, 38.03773730993271, 49.79245975613594, 64.2561024427414, 61.136553436517715, 56.110498532652855, 52.99626164138317, 57.22063556313515, 56.897288113832474, 59.185475930571556, 58.62497940659523, 58.71997810900211, 62.612401843070984, 60.46498127281666, 60.14484465122223, 64.4872896373272, 57.10531935095787, 57.48962692916393, 53.20353291928768, 64.04753923416138, 62.12884359061718, 59.54714052379131, 59.22945477068424, 56.515754386782646, 54.79648344218731, 55.24035282433033, 51.77501857280731, 55.80014258623123, 51.45107455551624, 51.2088717520237, 49.64893005788326, 47.091587483882904, 45.13276979327202, 44.29125554859638, 43.82300667464733, 45.052632093429565, 45.862790420651436, 44.93441663682461, 47.51323565840721, 50.37973344326019, 54.64921474456787, 56.07731111347675, 55.04381217062473, 56.095337346196175, 56.21461674571037, 53.009063154459, 53.163832649588585, 47.42682829499245, 44.662735015153885, 45.29416233301163, 49.59446758031845, 49.89688575267792, 51.822759211063385, 53.35309289395809, 52.4696858972311, 52.67050512135029, 56.72812879085541, 54.34524245560169, 54.36654791235924, 48.75053286552429, 45.77311523258686, 45.09936958551407, 43.12784917652607, 43.70327889919281, 47.30938419699669, 54.109563902020454, 54.40646477043629, 55.47689773142338, 54.90757428109646, 53.26654873788357, 55.949523970484734, 52.213701233267784, 46.97849415242672, 45.99475733935833, 47.64885038137436, 47.55513980984688, 54.314201921224594, 52.24487476050854, 48.93421120941639, 45.44272296130657, 43.524627685546875, 42.88499280810356, 46.390703693032265, 44.79570887982845, 49.2379517108202, 51.24790705740452, 50.49338914453983, 49.972877874970436, 49.39509607851505, 49.67952221632004, 51.01581931114197, 51.43353849649429, 52.88777366280556, 52.214457392692566, 54.47921946644783, 56.26652956008911, 56.61155864596367, 58.79373975098133, 54.061792865395546, 51.832106709480286, 53.54495979845524, 54.656696543097496, 52.55361199378967, 54.05366510152817, 55.78975394368172, 51.904994398355484, 46.597082018852234, 57.80557617545128, 55.00466667115688, 45.32806411385536, 47.557495683431625, 39.992044642567635, 15.068282391875982, 0.9855505032464862, 0.259913801564835, 4.815208967775106, 0.40488587867002934, 51.67428597807884, 56.68391436338425, 57.86380425095558, 55.455535277724266, 51.889122650027275, 57.67719626426697, 68.68075981736183, 49.243385419249535, 20.98482236266136, 53.856459483504295, 18.82390681654215, 30.861774869263172, 27.208669893443584, 38.636847361922264, 46.84394717216492, 1.339858928695321, 0.11127470599603839, 0.0696647196309641, 0.15765414893394336, 0.040684769410290755, 0.03842780184641015, 0.09409722304553725, 0.0632088586280588, 0.05466870927193668, 0.0593546074378537, 0.06144520033558365, 0.028892643967992626, 0.05227569490671158, 0.043572239665081725, 0.03445387934334576, 0.03882850593072362, 0.005740649112340179, 0.08036879720748402, 0.01209215441122069, 0.019225615724280942, 0.03711797056894284, 0.053124255427974276, 0.04406549327541143, 0.2382756251608953, 0.07054809058899991, 6.153200771659613, 59.57730710506439, 50.52332393825054, 37.43473246693611, 29.0393128618598, 43.929127380251884, 20.472043678164482, 20.827822387218475, 73.13407525420189, 66.24999985098839, 69.93798315525055, 62.303318828344345, 66.75002261996269, 60.15113711357117, 68.10230925679207, 37.532809004187584, 1.3628079160116613, 4.288525879383087, 0.4731033806456253, 15.441898293793201, 41.41889087855816, 54.29258108139038, 65.2931959927082, 61.37752890586853, 57.56865508854389, 56.75190791487694, 58.529456332325935, 58.19112628698349, 59.53536115586758, 60.431611463427544, 60.45468382537365, 63.842221051454544, 62.91226275265217, 61.740116849541664, 64.12048012018204, 57.87625998258591, 56.25679448246956, 54.24023889005184, 64.23691347241402, 62.588786110281944, 60.96830986440182, 62.609160616993904, 59.554208144545555, 56.178457885980606, 57.47290402650833, 54.245102629065514, 56.433868780732155, 54.29519534111023, 52.24941551685333, 50.570635199546814, 47.80570976436138, 47.22663223743439, 47.56446070969105, 46.48413307964802, 49.42569583654404, 49.921014457941055, 49.40301105380058, 49.58040073513985, 54.06533807516098, 56.75604969263077, 60.19840657711029, 57.31647402048111, 59.21067997813225, 58.83071556687355, 58.87081101536751, 55.03082446753979, 50.58514662086964, 46.23268537223339, 48.78965936601162, 54.10964749753475, 51.69335335493088, 56.62603206932545, 57.16936871409416, 56.17374613881111, 55.57626999914646, 61.70242287218571, 59.15988430380821, 56.34770840406418, 52.04557925462723, 47.57233768701553, 48.96012581884861, 45.5224084854126, 46.75907492637634, 51.46459802985191, 57.85157270729542, 58.67802836000919, 57.70271189510822, 56.33355036377907, 58.732764422893524, 59.39802512526512, 55.921595469117165, 50.34293241798878, 49.63989794254303, 50.13284169137478, 52.07276299595833, 55.885881185531616, 55.75030066072941, 49.79821264743805, 47.7510990947485, 46.12835817039013, 45.20592346787453, 47.517176046967506, 46.944721564650536, 50.0706884264946, 53.62585745751858, 52.54453808069229, 51.93336747586727, 51.90828122198582, 51.919752806425095, 52.02874235808849, 51.72661677002907, 54.1616553068161, 54.04334105551243, 56.48641996085644, 57.325525134801865, 56.79666191339493, 58.091332241892815, 55.654040426015854, 53.02730977535248, 54.26733523607254, 55.086354687809944, 53.794716596603394, 53.402136862277985, 54.87301513552666, 55.12886680662632, 46.61733113229275, 56.30018815398216, 59.05265785753727, 54.60333600640297, 51.77868537604809, 42.995513677597046, 18.437967225909233, 1.0809094738215208, 0.30681581294629723, 6.801715772598982, 1.8239422654733062, 57.1016563475132, 61.210660859942436, 62.989934384822845, 58.41900385916233, 57.483995631337166, 62.34045423567295, 71.88642740249634, 51.95179268717766, 25.044917799532413, 59.96490530669689, 22.81704604625702, 41.69094108045101, 29.849993661046028, 42.448783814907074, 59.947920218110085, 3.0746183171868324, 0.2317508409032598, 0.0626277421542909, 0.270537348696962, 0.06473313347669318, 0.047272539741243236, 0.08870761303114705, 0.09772556077223271, 0.0466008441435406, 0.07145779294660315, 0.051226119976490736, 0.12632650730665773, 0.18444918299792334, 0.08597768217441626, 0.12529024650575593, 0.23401921527693048, 0.21546313364524394, 0.19194276683265343, 0.17047964822268113, 0.19888846756657586, 0.13861072860891, 0.24414862564299256, 0.16922901064390317, 0.5230778537224978, 0.1996467198478058, 9.701894000172615, 73.51226136088371, 67.45389685034752, 54.3099195510149, 33.13921116292477, 56.28018602728844, 22.518838047981262, 25.915386490523815, 81.29410699009895, 71.41955405473709, 76.03827461600304, 66.87830373644829, 71.73473954200745, 67.04000025987625, 72.88235396146774, 43.33543583750725, 4.171652225777507, 6.961063547059894, 0.7729086291510612, 19.173254370689392, 52.583132609725, 56.600554436445236, 66.65678322315216, 59.40646827220917, 56.798649206757545, 57.197266817092896, 61.030204743146896, 57.6949755102396, 59.760981649160385, 59.723481461405754, 62.9469358921051, 68.11796441674232, 65.17814576625824, 63.541129007935524, 64.37664717435837, 58.08639630675316, 59.24992427229881, 54.83688287436962, 69.21381801366806, 64.9772809445858, 64.8596240580082, 64.94545385241508, 62.00552120804787, 59.04785491526127, 59.99958224594593, 57.19342142343521, 59.447240084409714, 59.14127670228481, 55.72820104658604, 54.02754530310631, 50.561367496848106, 49.50879357755184, 50.25684043765068, 49.738156870007515, 52.01141528785229, 50.675794556736946, 53.023183196783066, 54.184203296899796, 57.25706420838833, 60.997043922543526, 62.83593624830246, 61.69620640575886, 63.20019610226154, 60.91454654932022, 60.75730338692665, 57.64687769114971, 52.787698432803154, 47.79651805758476, 51.25494807958603, 56.50234870612621, 56.38566456735134, 59.85568016767502, 60.0175666809082, 57.59442150592804, 59.63745407760143, 65.6337109208107, 62.52299264073372, 62.271898314356804, 54.82660062611103, 51.74941934645176, 52.03436225652695, 48.10310460627079, 49.45684276521206, 53.8956543803215, 60.18710598349571, 61.318776458501816, 62.160438895225525, 58.5434889793396, 61.21634155511856, 62.892709001898766, 58.86898331344128, 53.3569572865963, 51.536269783973694, 50.91792516410351, 52.01695539057255, 59.30350139737129, 58.49537216126919, 52.728949785232544, 49.50958393514156, 49.41828243434429, 48.58612708747387, 48.429309502243996, 48.26890870928764, 55.11276327073574, 55.703460574150085, 54.285167679190636, 53.19815240800381, 53.15002419054508, 53.538731932640076, 56.358184441924095, 54.45922113955021, 57.24224120378494, 58.06824088096619, 59.746618419885635, 61.23003602027893, 58.00350375473499, 60.55948980152607, 57.96343110501766, 55.28915360569954, 57.120123356580734, 55.063202530145645, 54.52789485454559, 54.758230894804, 56.69110357761383, 52.60846585035324, 47.09558866918087, 57.211459055542946, 63.10341149568558, 61.087186485528946, 53.74229080975056, 50.096386447548866, 22.13226769119501, 1.9956351025030017, 0.5889001186005771, 9.102289974689484, 3.713431963697076, 64.26412761211395, 66.77849069237709, 68.24695229530334, 62.04020954668522, 64.54640686511993, 65.74654966592789, 78.21935757994652, 59.35173600912094, 30.070777013897896, 63.34656424820423, 29.04993139207363, 48.96435119211674, 41.62801645696163, 53.77389371395111, 72.04946905374527, 7.1462874580174685, 0.5530938680749387, 0.32700828567612916, 0.3653688303893432, 0.18007993698120117, 0.12263049313332886, 0.16144386667292565, 0.1853094805846922, 0.12992684380151331, 0.20119788270676509, 0.14753640512935817], [0.017696329523460008, 0.08914629652281292, 0.057677119912113994, 0.0617265744949691, 0.03479137842077762, 0.016452323034172878, 0.043556071977945976, 0.03924112519598566, 0.05335779074812308, 0.029444462306855712, 0.05213758864556439, 0.013510712178685935, 0.08968137757619843, 0.06332676362944767, 1.696907125879079, 33.98881137371063, 56.6568598151207, 51.489999666810036, 35.747790187597275, 25.443624705076218, 48.3181806653738, 11.884204298257828, 41.013042256236076, 70.0573043525219, 58.84633652865887, 63.05016115307808, 52.08098195493221, 58.66607800126076, 49.16112743318081, 57.184077724814415, 7.884593540802598, 2.9662730684503913, 0.21469017199706286, 1.8356452812440693, 22.03679781407118, 41.234452575445175, 60.065151527523994, 61.4187490940094, 63.05525287985802, 56.20620399713516, 60.24518966674805, 56.1703035235405, 58.838976323604584, 61.9671356678009, 64.27281394600868, 59.59319785237312, 61.625948175787926, 57.77285613119602, 60.01240275800228, 60.1680614054203, 62.35782690346241, 56.501964926719666, 59.058235958218575, 62.5289811193943, 59.667563661932945, 57.249130234122276, 56.15856595337391, 55.35524345934391, 53.765682354569435, 54.92166392505169, 54.80059862136841, 55.12114182114601, 51.6044457256794, 51.2872539460659, 46.554832085967064, 44.85425993800163, 43.4219191968441, 43.70268613100052, 44.35828015208244, 43.52927103638649, 46.12711563706398, 47.5043935328722, 53.43807153403759, 57.32078678905964, 53.323811665177345, 56.172378212213516, 55.910819247365, 52.93423756957054, 49.70227159559727, 44.67454858124256, 44.066357016563416, 42.8492671251297, 46.05851411819458, 48.66215340793133, 49.93089012801647, 50.185807049274445, 53.529958203434944, 48.611000552773476, 54.44475531578064, 55.87977111339569, 53.777077943086624, 55.40125139057636, 50.92790722846985, 48.87843020260334, 46.004245430231094, 42.755305767059326, 42.16974578797817, 45.513383969664574, 49.141581282019615, 54.71156179904938, 55.0786828994751, 54.000752940773964, 53.579857125878334, 54.19502131640911, 55.10514847934246, 50.150297954678535, 45.90291626751423, 46.21701121330261, 45.01788295805454, 44.169437885284424, 43.85915033519268, 45.63605658710003, 41.102652847766876, 43.05673599243164, 43.58531042933464, 46.89139522612095, 46.437000408768654, 49.88235533237457, 51.215437799692154, 51.89578749239445, 51.13489352166653, 51.76185987889767, 48.80655325949192, 51.03386074304581, 50.61601996421814, 51.44352436065674, 53.311283737421036, 57.26491458714008, 56.617102548480034, 57.833595871925354, 54.496649131178856, 54.46319952607155, 54.116981104016304, 55.589633882045746, 56.689838245511055, 51.789624989032745, 51.33090980350971, 55.63129484653473, 57.01647251844406, 54.82193447649479, 50.95525436103344, 41.21594376862049, 46.8495062738657, 42.27398939430714, 20.77439535409212, 5.283853970468044, 1.8863266054540873, 1.0991436266340315, 1.5744700958020985, 8.570863790810108, 55.93352682888508, 48.532587960362434, 60.23967616260052, 50.638355165719986, 63.7193888425827, 54.35760699212551, 63.925170600414276, 18.470255993306637, 26.444078721106052, 35.79709254205227, 14.839269630610943, 46.76639333367348, 40.74521742761135, 41.091272458434105, 33.49581062793732, 0.679058771347627, 0.09292632923461497, 0.0907137717877049, 0.09243867141776718, 0.10401348117738962, 0.05617265298496932, 0.023992816168174613, 0.04162975717918016, 0.027137761571793817, 0.05429663353424985, 0.011091664200648665, 0.023434980867023114, 0.0212631116664852, 0.060613709210883826, 0.07716705338680185, 0.05143326452525798, 0.0384878341719741, 0.037997204053681344, 0.04152181551035028, 0.010861687478609383, 0.09108971411478706, 0.06527784760692157, 0.07842165403417312, 0.05810091221064795, 0.030825873727735598, 1.866554960142821, 38.85840967297554, 68.22388753294945, 46.02524310350418, 45.44285975396633, 36.199137568473816, 49.342050924897194, 15.2122538164258, 43.45306992530823, 78.88124406337738, 63.96150425076485, 69.9646045267582, 58.31846505403519, 62.4465711414814, 55.3989677131176, 63.12532491981983, 13.192595690488815, 4.8246039636433125, 1.075789367314428, 2.48015517834574, 27.11498212069273, 45.76412491500378, 62.41246797144413, 63.605341762304306, 65.04894509911537, 59.28405024111271, 60.602970868349075, 58.35178166627884, 62.59752184152603, 63.877087980508804, 65.18062323331833, 60.9785845130682, 63.75449135899544, 58.67812715470791, 62.43185833096504, 62.96976886689663, 61.793086007237434, 58.988665491342545, 60.2348580211401, 63.94413158297539, 61.25567324459553, 59.78611350059509, 59.66084562242031, 57.06626124680042, 58.80924291908741, 59.062670320272446, 56.216068267822266, 57.31635242700577, 54.216478765010834, 52.673932537436485, 48.90363045036793, 45.91267794370651, 46.045021042227745, 46.24202527105808, 46.246718019247055, 47.54973649978638, 48.94567899405956, 50.182702615857124, 54.71881181001663, 59.645319655537605, 57.36416906118393, 60.762554705142975, 58.432694524526596, 57.11789287626743, 53.04663173854351, 48.86490672826767, 46.257547438144684, 45.294853895902634, 49.114902913570404, 53.966683968901634, 52.768011689186096, 52.975503355264664, 57.71744750440121, 56.99398152530193, 55.36099635064602, 59.12698946893215, 57.77860902249813, 57.1796927601099, 53.74283418059349, 51.88196763396263, 49.93633523583412, 46.072341576218605, 45.565684363245964, 50.168913155794144, 52.43791580200195, 58.1769834458828, 56.88468798995018, 57.3142359405756, 58.573009595274925, 57.499396204948425, 57.16471016407013, 52.64371655881405, 50.06911151111126, 49.170129150152206, 49.197062104940414, 47.74939298629761, 46.4896921813488, 47.33260855078697, 43.70893679559231, 42.98246517777443, 47.03187748789787, 50.818545296788216, 48.71117077767849, 51.07496693730354, 53.01913641393185, 53.756798431277275, 53.51467542350292, 52.77282603085041, 51.326186656951904, 52.62521535158157, 51.67413778603077, 56.16488881409168, 56.901312097907066, 58.25346194207668, 56.90664321184158, 61.18174061179161, 56.644476279616356, 56.30847170948982, 55.75883500277996, 54.676634073257446, 57.427355870604515, 55.087411031126976, 54.19326201081276, 56.197536662220955, 57.29038842022419, 56.89647115767002, 54.43924941122532, 48.26802335679531, 50.87858967483044, 46.77447929978371, 22.44315180927515, 6.2583572790026665, 3.5195953398942947, 1.2021973030641675, 1.5805337391793728, 9.910024981945753, 64.59620699286461, 54.23323206603527, 66.80978581309319, 54.72643420100212, 70.25972709059715, 59.51139584183693, 69.47422564029694, 21.72351412475109, 34.7244518995285, 39.707785695791245, 19.793922565877438, 60.70042423903942, 47.4631467461586, 47.85549469292164, 38.96574631333351, 0.7737024896778166, 0.0936936579819303, 0.1203230075770989, 0.08400387363508344, 0.06368608184857294, 0.03333522159664426, 0.1139767246786505, 0.060017497453372926, 0.03922751791833434, 0.07738637286820449, 0.019302472537674475, 0.11028320412151515, 0.12737283163005486, 0.13160345930373296, 0.2577804832253605, 0.20569363521644846, 0.14636446489021182, 0.17043697473127395, 0.11040214070817456, 0.1633112586569041, 0.1707392663229257, 0.2446559874806553, 0.1268386040464975, 0.1848502247594297, 0.17947461165022105, 2.556018107570708, 56.01782910525799, 82.10178405046463, 65.77158272266388, 50.74681654572487, 47.927250042557716, 58.81737448275089, 16.319117322564125, 47.25001618266106, 86.59608408808708, 67.52980157732964, 76.92162081599236, 61.57766416668892, 73.06250989437103, 57.350831776857376, 77.10565254092216, 12.489658109843731, 8.718745205551386, 0.45219918829388916, 2.9455461306497455, 35.96356920897961, 49.74458992481232, 66.97373181581497, 66.05847492814064, 63.75119313597679, 57.778020054101944, 62.29287698864937, 59.3610455095768, 64.92923632264137, 67.02964201569557, 68.05514618754387, 62.808703109622, 66.79780885577202, 61.77797421813011, 64.59065169095993, 64.6431040763855, 63.63091818988323, 60.07324129343033, 62.19157822430134, 65.44013410806656, 63.66881735622883, 61.91201962530613, 62.68700323998928, 58.57197605073452, 59.95957799255848, 60.53534209728241, 58.82165685296059, 59.677921906113625, 54.89228010177612, 55.49468457698822, 51.74395143985748, 47.95757241547108, 48.553312048316, 48.48230145871639, 50.49476467072964, 49.74242024123669, 53.558977246284485, 53.72408598661423, 60.22982709109783, 65.0443397462368, 60.53938128054142, 62.874314188957214, 60.133540257811546, 58.71094599366188, 54.132313281297684, 50.389194935560226, 48.42555530369282, 48.107405975461006, 50.47513112425804, 55.61082534492016, 56.24563068151474, 56.093160063028336, 60.98170794546604, 55.534039065241814, 60.28809696435928, 62.536546513438225, 60.28826795518398, 61.14482939243317, 58.752865344285965, 55.0331499427557, 52.41001009941101, 48.27260211110115, 47.746938318014145, 51.232658475637436, 55.458757504820824, 61.71179696917534, 59.407118037343025, 60.773007944226265, 62.11572669446468, 59.899290427565575, 59.21385280787945, 56.55869208276272, 51.16579346358776, 50.24698756635189, 52.09353268146515, 47.654762864112854, 48.64850454032421, 48.92350718379021, 45.99604547023773, 45.61552248895168, 49.060630425810814, 50.802114978432655, 50.48311069607735, 52.63714671134949, 55.26760496199131, 56.00499339401722, 56.23241499066353, 55.79635038971901, 54.70473736524582, 56.38363167643547, 54.21766810119152, 58.59420485794544, 58.358013331890106, 60.44151373207569, 59.718302339315414, 61.899719685316086, 57.35637187957764, 58.31980638206005, 58.05885538458824, 56.81100234389305, 58.609434440732, 56.430122181773186, 55.23782216012478, 56.89153902232647, 57.673711851239204, 56.57424084842205, 60.1613699644804, 54.481453746557236, 52.86500908434391, 50.188835486769676, 28.786341436207294, 10.37220748141408, 3.7327292282134295, 1.8233990133740008, 4.602936208248138, 11.341516468673944, 68.42355161905289, 57.93729230761528, 72.08030819892883, 58.65279771387577, 76.95445865392685, 62.92462728917599, 78.45460295677185, 23.20598177611828, 37.01783403754234, 42.769213020801544, 26.857473738491535, 67.62839868664742, 49.65774558484554, 59.17089991271496, 58.967759013175964, 1.9890865101478994, 0.2899115887703374, 0.1990828212001361, 0.2262356149731204, 0.23435531911673024, 0.14719320635776967, 0.12842138239648193, 0.22010299639077857, 0.14004132215632126, 0.1868207158986479, 0.09316559764556587], [0.05349214545276482, 0.05556626638281159, 0.03134144928480964, 0.023156799798016436, 0.17911890026880428, 0.052307147125247866, 0.07480818152544089, 0.04910420102532953, 0.024468545816489495, 0.12086399612599052, 0.026312584268453065, 0.02223492250777781, 0.011506928294693353, 0.28860813996288925, 0.39915928908158094, 11.483552847057581, 51.330123245716095, 34.43820185959339, 37.66829453408718, 19.696978367865086, 38.98467689752579, 35.67326098680496, 13.35286634042859, 58.53079006075859, 61.921256929636, 63.8168004155159, 56.899381801486015, 62.25792646408081, 50.74141323566437, 52.48662918806076, 28.156316243112087, 1.1997045180760324, 2.838375731371343, 0.9248650283552706, 9.443779550492764, 35.75350508093834, 51.222703009843826, 61.67616248130798, 58.429924473166466, 62.630659863352776, 62.58239105343819, 70.82603350281715, 68.17331224679947, 69.22135680913925, 58.817195892333984, 61.28311537206173, 53.53691183030605, 59.6044946461916, 56.7820592969656, 59.17416773736477, 60.39620116353035, 62.73480847477913, 59.67631459236145, 62.220456674695015, 60.26943996548653, 57.75812432169914, 57.7771271020174, 57.61523678898811, 56.55185244977474, 54.2243367433548, 55.787059888243675, 56.691700145602226, 54.62538242340088, 51.738259345293045, 47.4516561627388, 45.287436693906784, 46.028024554252625, 41.60277061164379, 41.21276333928108, 41.302495524287224, 45.555816292762756, 46.48166321218014, 50.86940556764603, 53.70964676141739, 54.29859235882759, 54.005514085292816, 54.15043070912361, 49.15346324443817, 43.4667681902647, 41.854917481541634, 42.78799541294575, 42.13284596800804, 45.2555488049984, 47.23282590508461, 49.88118879497051, 54.64442700147629, 55.102108642458916, 29.824829511344433, 42.29722514748573, 52.40184433758259, 48.73904228210449, 55.24816520512104, 49.51977878808975, 47.826335057616234, 44.79193948209286, 42.79384329915047, 42.29134686291218, 40.393664091825485, 42.49427877366543, 48.51542428135872, 52.68247447907925, 53.373136818408966, 54.060462936758995, 53.41066740453243, 55.79353854060173, 51.79169587790966, 48.98493088781834, 44.89254288375378, 41.39463298022747, 42.48271979391575, 41.13847732543945, 40.53314320743084, 41.89470894634724, 42.2345133125782, 45.258109867572784, 46.72905273735523, 48.65290850400925, 50.20829804241657, 50.60935892164707, 52.036452144384384, 50.47456115484238, 50.04296511411667, 50.87863527238369, 49.7911412268877, 51.10591247677803, 53.12767378985882, 55.1964195817709, 54.005160704255104, 54.186414778232574, 56.05053395032883, 53.869424387812614, 53.64091604948044, 55.35944223403931, 54.81674015522003, 53.35766404867172, 53.27569864690304, 55.300967171788216, 53.626617416739464, 54.67700645327568, 53.48277613520622, 42.304885536432266, 48.9689489454031, 39.9130354821682, 29.432071186602116, 6.323016034439206, 3.84944424033165, 2.5531300250440836, 1.4543835958465934, 2.0618038019165397, 18.459375277161598, 62.5712576508522, 52.27743901312351, 56.111174896359444, 53.616825342178345, 61.16522669792175, 56.69723644852638, 53.8682122528553, 20.731360763311386, 49.65898051857948, 30.212095230817795, 28.874667696654797, 39.124099016189575, 33.97450514137745, 48.87434922158718, 14.96326932683587, 0.47793235746212304, 0.04237354871293064, 0.16271641245111823, 0.02681171568838181, 0.03259137811255641, 0.04569355376588646, 0.07428395809256472, 0.025711498456075788, 0.050548431536299177, 0.044977307043154724, 0.03462563829089049, 0.026344468788011, 0.01710709766484797, 0.060263526829658076, 0.014246947721403558, 0.12303814000915736, 0.05260671503492631, 0.07929021172458306, 0.036419071548152715, 0.08165454579284415, 0.03194317891029641, 0.10292020859196782, 0.05495155659446027, 0.10652471595676616, 0.25117542827501893, 0.25371369207277894, 14.212066736072302, 64.09275680780411, 36.22263930737972, 41.32463313639164, 31.595625691115856, 44.33634772896767, 41.63811631500721, 15.76872255653143, 64.48030561208725, 67.22077175974846, 70.46867787837982, 60.291493982076645, 70.06277605891228, 56.45190641283989, 58.055652156472206, 33.471883311867714, 1.8810705374926329, 5.212372206151485, 1.2023654440417886, 12.04005578532815, 40.342967212200165, 55.96592389047146, 63.25414180755615, 60.936433374881744, 65.60103267431259, 63.93617480993271, 69.54314634203911, 69.26956102252007, 68.54067653417587, 60.211075097322464, 63.60689967870712, 54.876932725310326, 63.46930146217346, 60.67814603447914, 61.429171934723854, 62.82466605305672, 63.46134088933468, 60.15419974923134, 63.904005736112595, 61.386409029364586, 60.643077716231346, 59.20289799571037, 60.386405289173126, 58.7118199467659, 56.81399278342724, 59.06561516225338, 58.83360721170902, 55.91264694929123, 52.644005343317986, 50.01224756240845, 48.09101365506649, 46.10803686082363, 43.75689782202244, 43.46713677048683, 45.27779661118984, 49.161150231957436, 50.23875720798969, 56.352480947971344, 56.496329829096794, 57.30075046420097, 57.07200273871422, 56.632993295788765, 53.47556032240391, 48.10940466821194, 44.57977406680584, 45.91510981321335, 43.99827606976032, 48.81480261683464, 51.370777264237404, 54.96422164142132, 57.74081625044346, 57.7188990265131, 37.66912288963795, 48.31321433186531, 55.92599183320999, 52.1036933362484, 56.81613586843014, 54.102644473314285, 51.87267333269119, 48.53369750082493, 46.639358550310135, 46.49969324469566, 43.48457023501396, 46.32052145898342, 54.739908277988434, 56.789662688970566, 56.589937806129456, 57.40328796207905, 57.64648251235485, 57.32859916985035, 53.43514569103718, 50.675133392214775, 48.646011874079704, 44.9621095508337, 45.889757573604584, 43.19535635411739, 44.14465181529522, 43.448540568351746, 44.83252890408039, 47.5759132951498, 47.83387765288353, 50.68928763270378, 53.53666104376316, 52.70298957824707, 53.5821446031332, 51.24620854854584, 52.39471971988678, 52.64042593538761, 53.03614430129528, 52.44184099137783, 56.25859558582306, 56.49454012513161, 57.239695340394974, 56.2704661488533, 56.485397815704346, 55.11008821427822, 54.79322321712971, 55.432029739022255, 57.49133303761482, 55.93669965863228, 56.137743070721626, 55.5495498329401, 55.544374510645866, 56.18124693632126, 54.67829078435898, 44.556154534220695, 56.94067798554897, 44.495863169431686, 34.76290203630924, 7.277424121275544, 6.344310091808438, 3.154403823427856, 1.9986136676743627, 1.7271653772331774, 18.970008976757526, 70.1927898824215, 56.897546499967575, 63.779296427965164, 56.75644487142563, 66.07719272375107, 61.829849034547806, 61.595857590436935, 25.038657635450363, 55.214529410004616, 33.46668139100075, 33.389218747615814, 43.83708871901035, 34.81826886534691, 61.07143633067608, 17.202385626733303, 0.6035023787990212, 0.05699795830878429, 0.11516908882185817, 0.020715848258987535, 0.03671548161946703, 0.16131036914885044, 0.06829434394603595, 0.014463029583566822, 0.08507511927746236, 0.016010240506147966, 0.02071134342259029, 0.14596517459722236, 0.11520537242176943, 0.15266292379237711, 0.11186143310624175, 0.3987615869846195, 0.23880998633103445, 0.15484891977394, 0.10007321136072278, 0.12749479617923498, 0.21259798348182812, 0.2839808788849041, 0.1433885862934403, 0.2732931211357936, 0.6305590050760657, 0.58896453701891, 23.89330979436636, 74.39487800002098, 52.9723609238863, 50.32382324337959, 35.337381809949875, 54.7066068649292, 46.00618712604046, 16.468194723129272, 70.28255626559258, 71.53195962309837, 76.26367092132568, 66.67882964015007, 75.58055117726326, 63.732935115695, 64.9934832751751, 38.809175714850426, 3.8283807830885053, 5.338685028254986, 2.0060971286147833, 16.952611729502678, 49.077360928058624, 56.555044278502464, 66.17714256048203, 62.19307914376259, 66.97223469614983, 66.10424727201462, 72.88923919200897, 71.47224202752113, 73.49757134914398, 62.463639825582504, 67.66435235738754, 58.44618380069733, 66.37911692261696, 62.795552015304565, 63.956838101148605, 66.86886504292488, 67.1918173134327, 60.65939024090767, 66.28442600369453, 64.24765929579735, 63.07587817311287, 60.515932738780975, 63.19766543805599, 60.95152236521244, 56.742317229509354, 60.495026260614395, 61.54880851507187, 58.94198499619961, 56.518600434064865, 50.349000692367554, 50.6349391490221, 48.82812850177288, 46.97075016796589, 44.65118743479252, 50.10100319981575, 51.6505828499794, 53.738962188363075, 57.01509699225426, 59.14123110473156, 60.43935924768448, 60.354152619838715, 59.24902372062206, 54.9698643386364, 47.79178351163864, 46.61309815943241, 47.57244028151035, 47.75176785886288, 51.12861625850201, 52.682542875409126, 57.91478231549263, 62.056829854846, 61.6449623554945, 36.35065443813801, 49.71863351762295, 57.42796763777733, 55.30322805047035, 62.45255582034588, 58.47026690840721, 52.691673785448074, 52.233365178108215, 51.58453859388828, 48.80042038857937, 46.26816026866436, 47.924529388546944, 54.950549975037575, 59.75960612297058, 59.27279144525528, 59.56137455999851, 60.801065638661385, 60.59785634279251, 57.96887241303921, 53.921485394239426, 50.76100878417492, 46.69828578829765, 48.740262016654015, 45.3600849956274, 46.197883039712906, 45.67077152431011, 46.38625793159008, 49.72061701118946, 50.227680802345276, 52.998039945960045, 56.128007993102074, 54.83882836997509, 56.6613207757473, 53.95249553024769, 54.35784637928009, 55.432595908641815, 53.966573774814606, 54.917218163609505, 58.05179536342621, 57.46840886771679, 56.556579396128654, 56.70952878892422, 59.1977758705616, 55.54850108921528, 55.429818257689476, 56.26085266470909, 58.66719514131546, 56.72010362148285, 56.31830558180809, 57.81188003718853, 56.159291714429855, 57.412692457437515, 58.70923988521099, 49.200474321842194, 56.79005786776543, 49.27423596382141, 41.95261023938656, 11.649277154356241, 9.388249330222607, 4.483728054910898, 4.336637947708368, 3.290391876362264, 23.192266412079334, 76.7234842479229, 59.67252999544144, 68.47294136881828, 62.11352661252022, 72.90326803922653, 66.59194350242615, 66.44523337483406, 26.230250895023346, 63.63103598356247, 37.11151801049709, 47.487256452441216, 51.84186838567257, 44.78368252515793, 68.36976930499077, 30.506355240941048, 0.7239098427817225, 0.22026202379493043, 0.3230838681338355, 0.10553183368756436, 0.10360331099946052, 0.20239952369593084, 0.19989118329249322, 0.1410005777142942, 0.19649964262498543, 0.13055514602456242, 0.17170570587040856], [0.04521890950854868, 0.03593476823880337, 0.06339225074043497, 0.06879211723571643, 0.03847969652269967, 0.033785282212193124, 0.07725180665147491, 0.1339618710335344, 0.0651107456360478, 0.11147311917738989, 0.06310338460025378, 0.07820258688298054, 0.05593621215666644, 0.22818259487394243, 0.10140509926714003, 3.788301721215248, 47.683276534080505, 42.14228846132755, 35.206034258008, 23.8590432330966, 24.24491822719574, 67.63459235429764, 15.828278660774231, 26.83454766869545, 65.94209477305412, 64.07506495714188, 62.39231005311012, 56.34267747402191, 57.5397652387619, 51.4603840559721, 43.18830393254757, 0.2189952222397551, 5.574167892336845, 0.34536688181106, 2.316030110232532, 25.095358192920685, 49.20021213591099, 59.28105220198631, 58.07042956352234, 60.30012331902981, 57.73463778197765, 62.826679944992065, 59.452772587537766, 62.086426466703415, 58.658710196614265, 55.549492835998535, 55.91172739863396, 58.77474457025528, 55.731894448399544, 58.8900151848793, 58.82419891655445, 59.80311758816242, 61.04292266070843, 61.17845758795738, 60.81721097230911, 59.89145144820213, 57.00910471379757, 60.83155520260334, 57.26626731455326, 57.310166358947754, 56.29726991057396, 56.01543143391609, 54.48422759771347, 50.41903853416443, 46.07299894094467, 46.26751430332661, 42.980059906840324, 42.161644622683525, 42.34297089278698, 42.43652947247028, 42.97214113175869, 46.27270482480526, 47.61905238032341, 54.292060509324074, 52.79275216162205, 52.44658313691616, 50.96623957157135, 42.131922617554665, 41.95003017783165, 42.42082491517067, 42.31419123709202, 41.343442127108574, 45.97546197474003, 46.40347480773926, 50.77665634453297, 52.17112071812153, 61.90560556948185, 16.82479988783598, 23.3353154361248, 41.52943454682827, 43.636911660432816, 59.26853187382221, 48.576072826981544, 50.715806409716606, 45.410534888505936, 43.434108942747116, 40.65012753009796, 41.369485929608345, 36.671311631798744, 42.79495283961296, 47.69746497273445, 52.649511247873306, 53.94206888973713, 55.172914043068886, 50.47033578157425, 50.332467779517174, 49.55915987491608, 44.26239989697933, 41.40198938548565, 40.57352364063263, 39.87802796065807, 40.85413098335266, 40.53532049059868, 41.748842373490334, 44.94493827223778, 47.174913212656975, 48.84788744151592, 52.2750299423933, 51.24212756752968, 51.22070051729679, 50.95801681280136, 52.33423836529255, 49.4790031760931, 49.06072922050953, 53.37151810526848, 55.26252083480358, 54.44449692964554, 55.775413513183594, 53.74486707150936, 54.59136664867401, 55.69222457706928, 56.78069517016411, 56.59667104482651, 60.31979486346245, 57.22549170255661, 56.7230598628521, 53.96941602230072, 55.7623840123415, 51.534134298563, 54.86249350011349, 43.20057347416878, 41.24165698885918, 42.963990569114685, 29.568322375416756, 1.5291208354756236, 5.540263261646032, 1.0244133928790689, 1.0445570619776845, 0.14209156448487192, 25.719125121831894, 56.720639392733574, 54.35047097504139, 52.85242035984993, 59.400635585188866, 55.924794897437096, 59.63889800012112, 41.36591412127018, 41.828524097800255, 60.42802445590496, 28.309014849364758, 39.06319588422775, 29.272854030132294, 37.213348746299744, 43.54027904570103, 3.0477756075561047, 0.3606415871763602, 0.08837200643029064, 0.1707289949990809, 0.025841034766926896, 0.061872105943621136, 0.024543185463699047, 0.11870027941768058, 0.03225779386411887, 0.07078166672727093, 0.004283306243451079, 0.043867774002137594, 0.01998251915210858, 0.0704965484328568, 0.03351973806275055, 0.03020545311301248, 0.02494442760507809, 0.04425323808391113, 0.08559103807783686, 0.05960105612757616, 0.04171054366452154, 0.09998852488934062, 0.05486029098392464, 0.10804796664160676, 0.08334035650477745, 0.28877583565190434, 0.1378891384229064, 4.470397895202041, 58.340021297335625, 48.718413189053535, 34.43461485207081, 38.96237209439278, 31.195051185786724, 69.82143580913544, 17.960496246814728, 30.15373606234789, 70.89680850505829, 68.71175095438957, 67.07072541117668, 60.497332736849785, 63.57028864324093, 55.48642762005329, 49.28281590342522, 1.7778025288134813, 6.724737603217363, 1.079004113562405, 2.8884672559797764, 29.698465391993523, 53.35158057510853, 63.878425508737564, 60.223834812641144, 61.941916421055794, 58.185050413012505, 64.70010101795197, 64.39971193671227, 63.66581931710243, 61.475692838430405, 57.3373045027256, 57.99662232398987, 59.79481503367424, 57.31746196746826, 61.30236513912678, 61.18004210293293, 62.04076811671257, 62.75576815009117, 64.61025103926659, 62.89055071771145, 61.08176417648792, 58.828808069229126, 63.25329065322876, 57.74932399392128, 59.405240938067436, 59.31849539279938, 58.979705572128296, 57.724047750234604, 54.93998274207115, 48.83883252739906, 46.75133474171162, 46.89407028257847, 44.233848229050636, 45.123600885272026, 44.4398807734251, 45.36839134991169, 48.65761265158653, 50.995501801371574, 56.285680532455444, 56.67764849960804, 56.207750514149666, 52.89592422544956, 44.30192157626152, 42.92028151452541, 44.90191698074341, 45.23902729153633, 44.611034989356995, 48.40204976499081, 51.227118372917175, 55.035342425107956, 55.448536053299904, 64.59866166114807, 19.761170223355293, 28.53069305419922, 45.31244695186615, 44.63937386870384, 62.275834903120995, 52.69662491977215, 54.49532300233841, 47.87912182509899, 47.6059240847826, 43.843453377485275, 44.97778370976448, 40.8402731269598, 46.794922202825546, 52.59176954627037, 56.88738964498043, 56.651722490787506, 57.97424152493477, 53.64237517118454, 52.91152998805046, 52.71585948765278, 47.94631361961365, 43.62627983093262, 44.02794487774372, 42.69076243042946, 44.28899846971035, 41.7188885807991, 44.21600818634033, 46.048623248934746, 50.1021583378315, 50.55009350180626, 54.86704185605049, 53.99173602461815, 53.08736175298691, 52.342723309993744, 55.37141539156437, 52.96473853290081, 52.001148238778114, 54.52356308698654, 59.04413491487503, 56.84045076370239, 57.400240525603294, 56.28842778503895, 56.19404464960098, 56.99553944170475, 59.46932829916477, 59.14694979786873, 59.70820628106594, 58.2658226788044, 59.217109233140945, 57.944637313485146, 58.22127006947994, 53.98197054862976, 55.72598956525326, 50.84918685257435, 46.960954293608665, 45.741048753261566, 31.006474904716015, 2.4657665379345417, 6.567990314215422, 2.0334813091903925, 0.6181029765866697, 0.6237936462275684, 33.46502847969532, 63.05852070450783, 59.3819709867239, 60.739805325865746, 63.75014439225197, 63.98013085126877, 65.14059618115425, 49.399188458919525, 43.436989188194275, 65.28184220194817, 28.227393329143524, 49.387439489364624, 31.7186326906085, 39.46896091103554, 51.22904106974602, 2.2211750876158476, 0.1786423969315365, 0.18763454019790515, 0.13313492556335405, 0.05932435749855358, 0.014934937171346974, 0.00733613256670651, 0.08395132957957685, 0.05138877277204301, 0.097027014271589, 0.047149265301413834, 0.042582845489960164, 0.1465722662396729, 0.18184434855356812, 0.1726517511997372, 0.21264301700284705, 0.13188437704229727, 0.20484392065554857, 0.2721389033831656, 0.3299648535903543, 0.1630350758205168, 0.21202544623520225, 0.3049143118551001, 0.15611416281899437, 0.16377342370105907, 0.6846432841848582, 0.5442648043390363, 7.57450120523572, 74.49486583471298, 60.44397599995136, 45.67141368985176, 40.61781786382198, 39.04721014201641, 79.35104325413704, 20.009215213358402, 34.08854462206364, 78.8260406255722, 73.74635919928551, 72.15849280357361, 65.07909268140793, 69.42813411355019, 55.20412556827068, 58.531899601221085, 1.5784018160775304, 12.757109608501196, 1.043935320340097, 4.225093508139253, 37.33420506119728, 56.0940758138895, 65.68454459309578, 59.99845750629902, 64.43942740559578, 57.102955877780914, 67.26470500230789, 67.0761439204216, 68.82874667644501, 65.20131692290306, 59.537983015179634, 61.96862518787384, 62.24983669817448, 61.516597643494606, 64.64457079768181, 62.82826445996761, 63.13199736177921, 64.09295439720154, 64.96592715382576, 64.37486127018929, 61.76738038659096, 60.98211072385311, 66.61220401525497, 61.17100618779659, 61.31478287279606, 60.95535255968571, 61.88218742609024, 59.338182136416435, 57.06202067434788, 51.81500002741814, 48.74802120029926, 50.03087796270847, 47.76780679821968, 48.08584213256836, 47.07570433616638, 47.041756957769394, 51.779308542609215, 52.62739263474941, 58.57008375227451, 57.81383693218231, 57.32863336801529, 56.964115127921104, 46.16478681564331, 46.82093560695648, 46.99404291808605, 47.698794901371, 47.84475266933441, 50.61236076056957, 51.944964453577995, 58.80511254072189, 57.91683800518513, 69.61416453123093, 17.955391220748425, 24.70786638557911, 47.25165009498596, 46.63819961249828, 68.89291763305664, 56.66995011270046, 57.81501106917858, 50.42243555188179, 50.279130041599274, 46.29539720714092, 46.51613116264343, 41.100198179483414, 47.83392325043678, 52.40684486925602, 58.97959917783737, 58.87079581618309, 60.962477177381516, 53.48652273416519, 55.618162751197815, 56.60829462110996, 50.739292949438095, 45.50867982208729, 47.91999243199825, 45.71180932223797, 45.15683390200138, 42.95233279466629, 46.53980389237404, 47.55007468163967, 53.0171225219965, 52.37575113773346, 58.957693353295326, 54.595124647021294, 54.62852865457535, 53.536182269454, 57.98549272119999, 55.47508142888546, 54.70831297338009, 58.06777350604534, 64.47567746043205, 58.85057710111141, 60.98916694521904, 57.60729141533375, 59.02101315557957, 58.495755940675735, 60.61702251434326, 59.53839339315891, 62.550206780433655, 59.09169316291809, 62.2220715880394, 56.79120920598507, 59.63224455714226, 55.33078037202358, 58.862550258636475, 52.88199417293072, 52.379915714263916, 46.67878903448582, 36.98287591338158, 4.488050797954202, 12.512489184737206, 3.4907152270898223, 6.598069500178099, 1.1696286569349468, 35.98674036562443, 67.22754299640656, 62.87456877529621, 61.177541837096214, 68.32070633769035, 66.6369178891182, 71.61838218569756, 51.455440521240234, 52.60712452232838, 72.10103988647461, 39.9475072324276, 60.959783121943474, 40.421360805630684, 53.66499915719032, 64.77314069867134, 9.083544630557299, 0.6594009418040514, 0.34916807315312326, 0.3266280092066154, 0.11655310518108308, 0.2508862578542903, 0.09534402372082695, 0.35459070873912424, 0.2468615910038352, 0.292135092895478, 0.1727209342061542, 0.17014517710777], [0.029813252185704187, 0.05149690739926882, 0.09727193784783594, 0.0342975978855975, 0.044097724749008194, 0.03305050035123713, 0.07184844464063644, 0.09058664931217209, 0.03777972138777841, 0.07610883985762484, 0.09047460727742873, 0.031628152064513415, 0.03696734427649062, 0.1557215370121412, 0.17716654721880332, 0.4692474188050255, 24.065622948110104, 54.760548770427704, 29.586700089275837, 23.318907916545868, 24.779129661619663, 60.17537601292133, 30.355123355984688, 20.621898137032986, 61.77314467728138, 69.77421194314957, 65.08209452033043, 59.356291964650154, 52.232772409915924, 54.46237117052078, 52.517726719379425, 6.419084854424, 6.047538416460156, 1.4988136617466807, 0.5502702633384615, 14.368664883077145, 48.72917041182518, 61.44714497029781, 57.59811870753765, 58.62216755747795, 62.8240542858839, 68.71901616454124, 62.012911811470985, 63.564961329102516, 55.51355816423893, 54.39273990690708, 52.79861144721508, 54.25909347832203, 51.940986067056656, 55.27578592300415, 57.500209361314774, 58.5485465079546, 60.85442237555981, 63.176580369472504, 61.19036614894867, 61.015727519989014, 58.87506678700447, 61.25748574733734, 54.5602273195982, 58.659523352980614, 58.961466550827026, 56.676744148135185, 54.98309522867203, 49.083303809165955, 48.25238719582558, 45.05488157272339, 43.728904724121094, 40.96745990216732, 41.6719800978899, 40.626181215047836, 42.64100030064583, 46.26120664179325, 47.87156783044338, 51.74763344228268, 51.5830946713686, 50.545381754636765, 44.63152728974819, 42.78275929391384, 40.33539041876793, 41.708591133356094, 43.858785554766655, 41.985227689146996, 45.321471467614174, 44.44440633058548, 51.42593510448933, 48.31405408680439, 66.32696092128754, 21.515338495373726, 13.233883325010538, 27.833552062511444, 45.19309915602207, 59.48451988399029, 48.56095723807812, 49.133605509996414, 45.07981203496456, 42.92269438505173, 39.56494756042957, 41.596402153372765, 39.40330043435097, 40.727050602436066, 39.73933160305023, 50.20931638777256, 52.68986888229847, 52.617060989141464, 52.41684973239899, 49.87058736383915, 47.796734645962715, 45.899507850408554, 41.013847813010216, 40.1724361628294, 39.165877774357796, 41.065384447574615, 41.29831574857235, 43.563875779509544, 43.25720563530922, 45.69458864629269, 47.0036032050848, 50.26956595480442, 51.625545993447304, 51.10690802335739, 50.896904692053795, 50.43971702456474, 51.78157702088356, 51.296225264668465, 54.592107608914375, 55.43636530637741, 56.111999452114105, 55.34054584801197, 56.63317568600178, 58.851120471954346, 58.10334339737892, 55.16913324594498, 53.12407158315182, 53.50311264395714, 57.09295481443405, 59.08538930118084, 59.635569378733635, 56.22847080230713, 53.95846500992775, 45.9834111481905, 45.76319016516209, 52.109685614705086, 51.7437082529068, 18.37217565625906, 1.3799934438429773, 0.10844654447282664, 0.5741616594605148, 1.6444925009272993, 2.8767356229946017, 53.25353443622589, 55.73746494948864, 58.47594380378723, 50.9177465736866, 60.88797837495804, 49.34099838137627, 57.070456221699715, 24.746681302785873, 51.409614980220795, 41.23259827494621, 29.41169288009405, 38.02087381482124, 18.426315151154995, 42.69305370748043, 24.46345590054989, 0.5032812722492963, 0.038932651514187455, 0.05277932003082242, 0.01173105225461768, 0.035504741899785586, 0.02828049829986412, 0.020834402639593463, 0.05583518730418291, 0.05330045612936374, 0.06896556456922553, 0.11943212608457543, 0.007823384057701332, 0.04131431101995986, 0.09811062409426086, 0.07781250664265826, 0.042251138875144534, 0.052429798161028884, 0.04058734397403896, 0.08497012764564715, 0.07724902359768748, 0.08902827277779579, 0.03895199559337925, 0.06128186476416886, 0.06471338492701761, 0.03808679241046775, 0.0619298561650794, 0.13651384972035885, 0.6904386857058853, 30.00137183815241, 61.6019182652235, 30.3993396833539, 31.798760890960693, 31.669252440333366, 67.19697743654251, 36.673686504364014, 22.53393653780222, 68.39373841881752, 73.47078278660774, 71.99176535010338, 64.85047414898872, 59.935985058546066, 56.09426200389862, 58.59323590993881, 6.89172581769526, 3.2658093329519033, 2.0435410318896174, 0.3344499785453081, 16.83866534382105, 52.42612883448601, 64.18135285377502, 59.33773756027222, 60.017627477645874, 63.903861343860626, 67.87537023425102, 66.07492044568062, 64.4854125380516, 60.30790530145168, 56.43791936337948, 54.64155055582523, 56.11052893102169, 55.25486044585705, 56.9479887932539, 59.939192086458206, 60.53182728588581, 61.55885897576809, 63.81460413336754, 62.408200800418854, 64.10974949598312, 62.48999521136284, 62.06125281751156, 56.541555002331734, 59.66008186340332, 60.12749098241329, 58.765093088150024, 55.23342579603195, 51.9787522405386, 49.17326018214226, 46.24884590506554, 45.14312043786049, 44.446013644337654, 45.74325643479824, 43.41789901256561, 46.034275218844414, 47.72096671164036, 51.16806574165821, 54.246664345264435, 55.661279037594795, 53.60638730227947, 48.42447616159916, 45.511799454689026, 43.05375695228577, 45.327535942196846, 46.19733206927776, 45.09094163775444, 48.395616710186005, 48.13692659139633, 55.34045085310936, 49.93749037384987, 68.9298440515995, 23.440852873027325, 15.826469007879496, 32.42817051708698, 47.927265241742134, 62.39842012524605, 50.94988904893398, 52.65958830714226, 48.837445601820946, 47.13338524103165, 42.5907251983881, 43.70425544679165, 41.9101133197546, 44.57318142056465, 42.72053003311157, 52.48895846307278, 55.01136191189289, 55.1773864030838, 56.74128748476505, 53.591298311948776, 51.11140698194504, 47.666416838765144, 42.38913841545582, 42.675365656614304, 42.10548743605614, 42.98180781304836, 42.37399622797966, 46.03339746594429, 44.998788982629776, 48.42019759118557, 46.96086309850216, 51.98062554001808, 52.60848484933376, 53.13916437327862, 53.75758498907089, 52.22292713820934, 53.61553341150284, 54.58766184747219, 56.43394477665424, 57.73586131632328, 58.82753513753414, 58.249700143933296, 58.29890750348568, 60.095044523477554, 60.272525399923325, 57.752664014697075, 54.3546811491251, 55.41324734687805, 58.89085873961449, 59.16335351765156, 58.4020871669054, 56.2478269636631, 57.49364711344242, 49.14239063858986, 48.97344030439854, 56.15952730178833, 54.13159132003784, 20.439735911786556, 1.6651683789677918, 0.37087455682922155, 0.48846847959794104, 0.6386043014936149, 4.608879564329982, 60.51489919424057, 60.67095302045345, 63.48421946167946, 55.9750510007143, 65.966687053442, 55.992674455046654, 63.6520716547966, 27.947150766849518, 54.1203211247921, 46.73104003071785, 29.782750569283962, 52.62204252183437, 17.846494764089584, 49.66828241944313, 27.55670841783285, 0.6489568459801376, 0.011539500228536781, 0.07120167778339237, 0.044253327141632326, 0.08029801858356223, 0.05520875900401734, 0.117521927022608, 0.03965204865380656, 0.09079754541744478, 0.11424737109337002, 0.06539760797750205, 0.03373899446160067, 0.21428234700579196, 0.24150910321623087, 0.26974791137035936, 0.18870685453293845, 0.18011637643212453, 0.11819411985925399, 0.18241403595311567, 0.21181846124818549, 0.174027158645913, 0.29018256173003465, 0.26124797528609633, 0.15798292035469785, 0.13705079356441274, 0.35004410427063704, 0.23549683130113408, 1.3738386053591967, 45.582920238375664, 79.41468223929405, 43.43579985201359, 38.207333609461784, 41.1295972019434, 75.94432085752487, 38.21766525506973, 24.50729414820671, 74.46129083633423, 79.42463010549545, 76.84198468923569, 69.00647833943367, 63.36809389293194, 61.020522862672806, 64.87807586789131, 9.350683595985174, 14.806824121624231, 4.656086806207895, 1.0594482254236937, 20.96852693706751, 57.72355377674103, 64.73675385117531, 59.27998445928097, 61.917392536997795, 67.02159404754639, 70.82751542329788, 68.74772742390633, 67.87828847765923, 64.11039546132088, 59.70126025378704, 58.764184936881065, 58.92145849764347, 57.96764887869358, 61.18744030594826, 62.390151768922806, 62.954064309597015, 64.71876561641693, 66.99747294187546, 64.31917145848274, 65.02188295125961, 63.042116984725, 64.74457383155823, 57.63545170426369, 63.22344705462456, 64.43376570940018, 62.63559199869633, 59.91966873407364, 53.62565606832504, 52.40963391959667, 48.05901937186718, 49.55087251961231, 47.27595739066601, 47.206041142344475, 44.90606635808945, 46.912453696131706, 51.757037937641144, 53.47122475504875, 57.25760757923126, 55.12300752103329, 55.15471301972866, 50.75443133711815, 48.33591811358929, 44.68213677406311, 47.94683799147606, 49.32131163775921, 48.89218166470528, 51.986074447631836, 51.04486495256424, 58.87896157801151, 51.950151175260544, 75.52331864833832, 21.094271689653397, 12.088527884334326, 32.23911926150322, 49.49075594544411, 66.5842755138874, 52.687319219112396, 55.50695791840553, 50.72122871875763, 50.21538086235523, 45.6173387914896, 47.41747699677944, 45.81451781094074, 46.83053009212017, 43.7092749774456, 56.126533672213554, 57.478892505168915, 58.964973762631416, 58.45903471112251, 56.81077815592289, 51.775596141815186, 51.777800023555756, 44.62584279477596, 46.74698397517204, 45.00124745070934, 47.14827664196491, 45.43076880276203, 47.39811323583126, 44.562534391880035, 49.734425470232964, 49.64377373456955, 55.57392172515392, 54.257615357637405, 56.07290714979172, 54.36209835112095, 53.05369935929775, 53.780345767736435, 55.126700922846794, 59.86207902431488, 61.83836817741394, 61.75602659583092, 60.774904042482376, 58.813175708055496, 64.02810707688332, 63.83417308330536, 60.75735278427601, 56.01572401821613, 56.72596290707588, 59.36827652156353, 63.33833388984203, 60.51061302423477, 58.95745016634464, 59.351910799741745, 51.62450484931469, 48.527082055807114, 54.907726272940636, 58.205546513199806, 27.28443782776594, 3.11073609162122, 0.8222190581727773, 3.886349997483194, 5.236182678490877, 4.475295357406139, 67.26219713687897, 62.29882746934891, 70.44366002082825, 60.5562561750412, 71.16749837994576, 60.740534886717796, 70.06556510925293, 31.239155419170856, 62.90249727666378, 52.52506032586098, 43.83086085319519, 54.56299737095833, 32.29387812316418, 60.15985004603863, 46.699437126517296, 0.8148757147137076, 0.13021423306781799, 0.20285533595597371, 0.12946490140166134, 0.11723751376848668, 0.16196994547499344, 0.25381937390193343, 0.2887840289622545, 0.17552168079419062, 0.23849500401411206, 0.17001806205371395, 0.11105164609034546], [0.03914901724783704, 0.022978075794526376, 0.08195689675631002, 0.009603565340512432, 0.01727301219943911, 0.027463532860565465, 0.07997514723683707, 0.01802993232558947, 0.03252864065871108, 0.040339462939300574, 0.038724467958672903, 0.08850022728438489, 0.02212069299275754, 0.02443983768898761, 0.18335927976295352, 0.06521541072288528, 5.6679672840982676, 47.070441618561745, 39.33885209262371, 34.80632230639458, 21.78592387586832, 37.31581784784794, 46.116761192679405, 36.19825221598148, 57.73972570896149, 67.47014477849007, 63.96916463971138, 57.5973891466856, 53.910310193896294, 53.513254299759865, 52.825897783041, 9.78474285453558, 0.8338052895851433, 2.989673875272274, 0.30567522102501243, 10.762090310454369, 45.548345893621445, 62.345868945121765, 61.1859317868948, 60.3288459777832, 58.43645632266998, 65.35843089222908, 65.04552528262138, 61.09508626163006, 58.42843495309353, 52.237951532006264, 51.55501797795296, 52.44828924536705, 49.41669411957264, 51.242682337760925, 55.59912197291851, 56.94643087685108, 61.48380160331726, 61.765016913414, 63.41846399009228, 61.99065640568733, 62.33237586915493, 58.56501862406731, 55.81719987094402, 58.814847618341446, 58.5313106328249, 56.66199333965778, 53.84866990149021, 48.50947380065918, 46.5986817330122, 47.717877477407455, 42.64214023947716, 41.05380266904831, 42.09718868136406, 42.55199007689953, 44.78058569133282, 46.445112973451614, 50.688751861453056, 51.288173496723175, 54.686794728040695, 46.238639652729034, 41.01985529065132, 41.61285527050495, 39.50299948453903, 40.916637629270554, 44.17072981595993, 41.05424724519253, 46.29869543015957, 44.77801322937012, 51.77541375160217, 49.65935669839382, 63.49815711379051, 29.504573196172714, 10.100320670753717, 23.13946444541216, 55.27780741453171, 55.72866462171078, 49.611904844641685, 46.26483924686909, 44.03733417391777, 42.97440581023693, 39.76486623287201, 42.639978155493736, 39.03242513537407, 39.7226694971323, 37.9891949146986, 44.21549141407013, 47.048129215836525, 50.91425456106663, 50.57642988860607, 47.353028655052185, 47.0405600219965, 43.6988939344883, 42.85179018974304, 40.47985106706619, 41.26513972878456, 39.84403118491173, 40.50383538007736, 42.9889590293169, 44.18810248374939, 45.592191740870476, 45.501243621110916, 48.76256301999092, 52.46912732720375, 51.24319911003113, 52.113056033849716, 51.05922818183899, 53.21230284869671, 51.41432672739029, 53.53728801012039, 55.06018929183483, 57.31748476624489, 54.45218771696091, 55.59252932667732, 54.70167472958565, 54.79025557637215, 52.45096430182457, 55.48208445310593, 54.278692826628685, 55.8222422003746, 57.041368782520294, 56.612652987241745, 52.514124512672424, 57.48512417078018, 54.82898309826851, 56.47211752831936, 45.25445446372032, 33.25913652777672, 13.5687755048275, 0.625058562727645, 0.11378584429621696, 1.0300829261541367, 0.30223447596654296, 5.760272406041622, 48.65691348910332, 51.166173443198204, 56.06682367622852, 45.39970926940441, 48.24298270046711, 56.508720964193344, 52.16043569147587, 38.69486644864082, 66.80331096053123, 37.14659012854099, 32.02301725745201, 24.823969155550003, 27.904304265975952, 42.097492665052414, 6.573282955214381, 0.06099820107920095, 0.03036977388546802, 0.1347730978159234, 0.005502449394043651, 0.03536015297868289, 0.07769295407342725, 0.061231035069795325, 0.05707383177650627, 0.17005595611408353, 0.03144796231936198, 0.020503903870121576, 0.06227621648577042, 0.0639267529186327, 0.05903146891796496, 0.011142694274894893, 0.02289019994350383, 0.016704603149264585, 0.01672562262683641, 0.03173885081196204, 0.03539146047842223, 0.03316988222650252, 0.04860326247580815, 0.03430353506701067, 0.02907328642322682, 0.02360431113629602, 0.03073885691264877, 0.16169063077541068, 0.01716417624265887, 7.360113384202123, 62.350603491067886, 36.97822876274586, 38.22708114981651, 32.387569695711136, 42.455748841166496, 52.08650305867195, 38.92042234539986, 63.45889762043953, 71.46385967731476, 69.39030334353447, 61.516194865107536, 59.9922676384449, 58.527252450585365, 59.199519976973534, 10.892231427133083, 1.9480057270266116, 2.6996487379074097, 0.6718729413114488, 13.801019992679358, 51.11198455095291, 64.62405949831009, 64.14675191044807, 59.40266087651253, 61.41725957393646, 68.46425503492355, 66.50336265563965, 64.49533760547638, 60.77789828181267, 53.939963802695274, 53.77643197774887, 53.84082332253456, 52.556572034955025, 53.24143968522549, 57.88144290447235, 57.76526793837547, 63.41338746249676, 64.61737185716629, 65.04377737641335, 59.59924712777138, 63.52170065045357, 61.26841776072979, 58.73364217579365, 61.82142108678818, 61.33930295705795, 59.881959557533264, 57.22272165119648, 51.75557121634483, 48.31164501607418, 49.164269864559174, 45.4339150339365, 43.53711001574993, 46.024380549788475, 45.334816351532936, 46.804782673716545, 48.797939121723175, 54.73737381398678, 53.9763468503952, 55.82600399851799, 49.74694959819317, 45.369288101792336, 44.07806418836117, 42.177474573254585, 43.90616901218891, 45.095687583088875, 43.4582794457674, 47.786942571401596, 47.711273431777954, 53.36224280297756, 52.104172110557556, 66.2964029610157, 37.36728988587856, 16.162560023367405, 27.143150009214878, 57.76719443500042, 60.39909280836582, 52.61179447174072, 49.95590038597584, 48.054178431630135, 46.615674421191216, 43.31409998238087, 45.24366304278374, 42.22196638584137, 42.9261863976717, 42.28471241891384, 46.84938848018646, 50.05455829203129, 52.98787169158459, 52.51329615712166, 50.14144442975521, 51.09597980976105, 46.383389085531235, 43.888712748885155, 42.24294126033783, 44.44540947675705, 41.74685128033161, 42.21464417874813, 45.880995243787766, 45.09297452867031, 47.16294765472412, 48.11367943882942, 51.54565908014774, 54.52392026782036, 53.70018906891346, 54.22784775495529, 53.97544249892235, 55.930240005254745, 53.8887083530426, 55.57131886482239, 57.49984838068485, 59.60231356322765, 56.096598878502846, 57.538902685046196, 56.67711652815342, 58.021256402134895, 54.49683532118797, 58.58660526573658, 54.07828018069267, 57.54411980509758, 58.8772364705801, 57.91386656463146, 54.726916775107384, 59.03479881584644, 55.96346162259579, 61.6037991642952, 53.69058698415756, 39.10598158836365, 17.166789136826992, 0.83643130492419, 0.40234271669760346, 0.9593949629925191, 0.5135987279936671, 6.2896794732660055, 57.203380689024925, 55.60533083975315, 61.05712629854679, 51.99493557214737, 55.895038694143295, 61.900852024555206, 58.693242743611336, 41.10668443143368, 73.13823983073235, 41.17800660431385, 38.029210567474365, 33.73159557580948, 30.452468432486057, 51.71937435865402, 7.211458710953593, 0.21763584518339485, 0.1174191024620086, 0.08000610221643001, 0.019998326897621155, 0.029918852378614247, 0.07288212276762351, 0.0924368308915291, 0.08653372147819027, 0.22825240128440782, 0.060673118132399395, 0.03554763432475738, 0.048984355307766236, 0.17191418999573216, 0.11555952529306524, 0.17937581695150584, 0.1808404750772752, 0.1316288110683672, 0.13520263804821298, 0.2708874939708039, 0.193617319164332, 0.12513273308286443, 0.10880711692152545, 0.11090340209193528, 0.21336313773645088, 0.2422717193257995, 0.1257253676885739, 0.6021744688041508, 0.1732633402571082, 12.898037396371365, 73.08088570833206, 56.66281409561634, 49.64391812682152, 36.91152334213257, 50.04888519644737, 57.13661067187786, 41.78159661591053, 68.42075496912003, 76.44201055169106, 75.24219453334808, 64.56887885928154, 63.74362774193287, 59.93891090154648, 62.258272245526314, 13.53561943396926, 5.979991815984249, 8.955565597862005, 1.3809043262153864, 16.5579155087471, 55.05083039402962, 66.11693859100342, 62.84444019198418, 59.73893143236637, 61.80056020617485, 71.32940769195557, 69.67268139123917, 67.97875508666039, 66.05921968817711, 55.79652898013592, 56.658847108483315, 55.74256807565689, 56.605706959962845, 55.806233659386635, 62.063479498028755, 62.57797949016094, 66.93013295531273, 65.3222568333149, 65.78270852565765, 61.71968154609203, 64.87623676657677, 64.19820874929428, 58.042968437075615, 63.749164044857025, 64.05610397458076, 60.565231293439865, 58.49857538938522, 52.24180832505226, 49.53390643000603, 49.73354771733284, 48.280650079250336, 47.147094905376434, 48.14240209758282, 48.33911374211311, 50.49897484481335, 51.1653146892786, 58.232471868395805, 55.54633900523186, 60.074670016765594, 50.757102593779564, 46.435689479112625, 46.96821950376034, 45.95754973590374, 45.31860642135143, 48.66385571658611, 46.50956131517887, 53.15500572323799, 50.31651243567467, 58.68453361093998, 53.50297965109348, 72.52197369933128, 31.30623321980238, 9.766344241797924, 25.849374532699585, 60.594516322016716, 64.76452276110649, 56.19051843881607, 52.9997194558382, 50.312815234065056, 49.925817400217056, 46.62485472857952, 48.92010636627674, 44.3202555924654, 45.25367170572281, 43.099795281887054, 50.22261567413807, 49.67413030564785, 56.15529052913189, 56.19674250483513, 52.21520975232124, 53.59641283750534, 48.50588299334049, 46.802707985043526, 44.58932675421238, 47.78372414410114, 46.107919067144394, 45.166116803884506, 46.12450897693634, 46.78805597126484, 48.35100710391998, 50.71683615446091, 53.34085375070572, 57.931440621614456, 55.60525104403496, 56.2696073949337, 53.600482419133186, 58.74701365828514, 55.95356695353985, 58.72840225696564, 60.62359236180782, 65.51521807909012, 57.184377908706665, 60.181201100349426, 61.71184256672859, 60.74433088302612, 56.278289929032326, 58.30159395933151, 56.808536276221275, 58.39474976062775, 61.30048044025898, 58.96930553019047, 55.482232645154, 59.706177189946175, 53.9420460909605, 60.71667216718197, 57.79305584728718, 47.882237657904625, 19.634939096868038, 1.692062623333186, 1.1105219973251224, 5.365128284320235, 1.5789581299759448, 6.828229799866676, 58.67099493741989, 61.23162053525448, 63.21289502084255, 56.72390341758728, 61.27962715923786, 69.68861013650894, 62.440153285861015, 45.701413080096245, 79.37641829252243, 51.32642604410648, 48.482244461774826, 39.51290175318718, 46.798539608716965, 64.33869481086731, 19.697593934834003, 0.5892260698601604, 0.22906324215000495, 0.36569635500200093, 0.12544480618089437, 0.17174983397126198, 0.24205744644859806, 0.20573865389451385, 0.21294087055139244, 0.2784646733198315, 0.13201043824665248, 0.10471683679497801, 0.12377936742268503], [0.04520492744632065, 0.02676952088222606, 0.060787887559854425, 0.011423104569985298, 0.018791168040479533, 0.03992809419287369, 0.17171142040751874, 0.020608904778782744, 0.07865299630793743, 0.03149571210087743, 0.02627226338518085, 0.02989123335282784, 0.1452629396226257, 0.06552540580742061, 0.35168549744412303, 0.07662187912501395, 1.762327621690929, 44.1129083186388, 49.350790455937386, 32.51675136387348, 22.012023143470287, 26.596699431538582, 50.22829256951809, 36.56501993536949, 55.380002930760384, 61.169345676898956, 62.492324486374855, 59.6788414567709, 54.44437153637409, 53.47054839134216, 51.225017085671425, 6.5486351028084755, 1.3102152943611145, 2.1226677484810352, 0.8082275558263063, 13.431785255670547, 46.41696788370609, 60.15207186341286, 64.99750345945358, 65.34825503826141, 67.88273423910141, 64.82119292020798, 61.28642879426479, 62.63290174305439, 58.531325832009315, 53.53144392371178, 51.01715303957462, 50.90641938149929, 50.21246261894703, 47.16450937092304, 52.83809892833233, 56.00974313914776, 57.174019664525986, 61.40671133995056, 59.45278398692608, 64.17551636695862, 60.58804526925087, 57.74563059210777, 65.59608533978462, 58.89930188655853, 57.844375893473625, 57.8897150605917, 53.96642558276653, 46.71488709747791, 47.54285126924515, 46.14092409610748, 43.81995923817158, 41.410637721419334, 41.974405869841576, 44.00713339447975, 45.031322836875916, 47.0502495020628, 50.29083341360092, 53.451701402664185, 53.34704361855984, 44.84527722001076, 43.10887299478054, 39.57587197422981, 40.53694300353527, 39.70633417367935, 41.71837940812111, 42.99459792673588, 46.38419084250927, 44.26136635243893, 48.26547369360924, 50.79489916563034, 62.90185131132603, 39.62080456316471, 7.382460935041308, 25.633329525589943, 58.795286267995834, 55.45138210058212, 50.07590174674988, 46.03059321641922, 47.15846389532089, 42.27688863873482, 40.1900178194046, 41.35854251682758, 40.05886025726795, 40.0275157392025, 40.86588375270367, 40.54131276905537, 44.56645578145981, 48.988719284534454, 48.752208575606346, 47.05449387431145, 44.89722043275833, 43.59364718198776, 40.58980196714401, 40.222889855504036, 39.26589220762253, 39.9432210624218, 39.90921288728714, 40.939508602023125, 42.48552784323692, 45.335990488529205, 45.41373811662197, 49.31262530386448, 51.67161092162132, 51.296115070581436, 55.19347473978996, 50.27619659900665, 55.112827867269516, 54.46382649242878, 53.933188766241074, 54.50319617986679, 55.508211851119995, 55.720859840512276, 53.3486395329237, 56.07718572020531, 52.866737991571426, 49.62792858481407, 51.18185140192509, 51.39916554093361, 53.83404828608036, 54.653565511107445, 56.971935108304024, 57.574009001255035, 58.797558546066284, 54.057822078466415, 41.917800307273865, 40.405857637524605, 44.49523240327835, 18.178045973181725, 0.4075211856979877, 0.28084138641133904, 0.34049877896904945, 0.2414765823050402, 4.250831427052617, 49.03031945228577, 53.477676808834076, 51.26668184995651, 53.61590199172497, 56.94011941552162, 59.22087863087654, 50.780505537986755, 57.354715168476105, 53.7388975918293, 29.140782617032528, 31.686627008020878, 25.65372683107853, 31.377773880958557, 28.6256043612957, 0.11035374525818042, 0.2777807100210339, 0.043031306777265854, 0.1000739386654459, 0.08498106690240093, 0.008659761297167279, 0.11163965711602941, 0.028980801835132297, 0.03524222571286373, 0.03801805469265673, 0.04132906862650998, 0.031159181526163593, 0.03129796314169653, 0.026366473466623574, 0.03282831246906426, 0.026791043164848816, 0.09125104959821329, 0.02294921923748916, 0.018257480369356927, 0.02302539327502018, 0.03619067560066469, 0.013790209632134065, 0.1096107144257985, 0.04181648153462447, 0.03377016466401983, 0.03391387785086408, 0.030255971105361823, 0.27085831272415817, 0.04246127056831028, 2.075577825307846, 53.02500329911709, 54.537827521562576, 30.819834619760513, 35.90698264539242, 31.277010887861252, 53.26209917664528, 39.52710919082165, 62.52722941339016, 66.82452142238617, 69.14906188845634, 65.35636380314827, 59.59259748458862, 57.09918648004532, 56.60859480500221, 7.427978692576289, 0.9126814571209252, 2.061012494377792, 0.8316545456182212, 16.405623480677605, 50.220639780163765, 63.82813900709152, 66.53320625424385, 67.00549811124802, 71.16483852267265, 67.1817098557949, 64.4793252646923, 63.432534635066986, 60.30022971332073, 54.67250369489193, 52.579211220145226, 51.67692303657532, 50.68177543580532, 50.429411977529526, 54.841431230306625, 57.85868212580681, 59.33629363775253, 63.61128084361553, 60.55135443806648, 66.49370357394218, 59.3124271184206, 57.829378098249435, 65.21493539214134, 61.224594712257385, 60.24856388568878, 61.34398050606251, 54.8547039180994, 49.44592975080013, 49.80672039091587, 48.99868614971638, 45.30860535800457, 46.168829798698425, 46.12776920199394, 45.689382925629616, 47.937403097748756, 50.74102185666561, 53.78713980317116, 56.523505970835686, 55.95406852662563, 45.805052518844604, 44.69083070755005, 43.281091153621674, 45.14872893691063, 43.357942029833794, 44.472863003611565, 45.635323226451874, 46.790480241179466, 47.687247321009636, 51.47034712135792, 54.2232272028923, 65.24878397583961, 51.135911867022514, 14.862725771963596, 31.826299913227558, 64.55541238188744, 56.81605227291584, 56.308251321315765, 48.458970710635185, 50.200204476714134, 45.5290163308382, 42.47939497232437, 44.73793298006058, 43.34389418363571, 42.10644118487835, 43.304269909858704, 42.059703692793846, 49.55132469534874, 52.80105471611023, 53.402668833732605, 47.2432791441679, 46.06675207614899, 45.9060662984848, 42.603678703308105, 42.24530093371868, 42.48743154108524, 45.304946154356, 41.45053178071976, 43.6149450391531, 43.81631523370743, 47.32977770268917, 47.87556141614914, 49.08160150051117, 54.89562012255192, 54.24187280237675, 56.990356519818306, 52.57372431457043, 55.995744690299034, 56.34586550295353, 58.51820133626461, 56.62168130278587, 59.350976049900055, 56.73132821917534, 56.937721744179726, 60.29084041714668, 56.43206387758255, 52.3289680480957, 53.63560393452644, 52.850421667099, 53.656176030635834, 56.716326624155045, 56.38606354594231, 56.724670976400375, 60.70128299295902, 58.61264906823635, 48.4226218611002, 45.48271581530571, 47.34796352684498, 19.782610572874546, 0.4232769215013832, 0.56849978514947, 1.0921778879128397, 0.31451618880964816, 4.552575135603547, 54.12890486419201, 61.25395953655243, 56.711413487792015, 59.06118839979172, 61.87176078557968, 62.44182139635086, 57.802365347743034, 59.21841636300087, 62.54294157028198, 30.57915933430195, 39.92747850716114, 27.346750684082508, 37.15743474662304, 36.82813301682472, 0.8318583690561354, 0.21021448716055602, 0.06584508591913618, 0.12150518945418298, 0.06238765738089569, 0.13692243170225993, 0.07340069103520364, 0.03387883734831121, 0.06259531030082144, 0.07772750104777515, 0.012149837839388056, 0.07645421312190592, 0.016029417602112517, 0.1718059997074306, 0.10504396806936711, 0.14925275521818548, 0.14224878104869276, 0.11432689963839948, 0.09801916181459092, 0.2954828320071101, 0.07992969811311923, 0.2377803306444548, 0.20848106767516583, 0.10566211771219969, 0.14689097413793206, 0.37526810076087713, 0.23353552795015275, 0.7219578756485134, 0.2762918727239594, 4.057823633775115, 69.12199214100838, 70.65348476171494, 47.33200438320637, 40.897395461797714, 40.928610786795616, 61.48940250277519, 43.57077240943909, 65.19915863871574, 73.78900051116943, 73.27988103032112, 68.44503566622734, 63.867330104112625, 59.66412104666233, 58.728881031274796, 8.748220223933458, 4.2725942842662334, 5.499167516827583, 1.7221022676676512, 18.896722309291363, 53.714016526937485, 63.76855820417404, 66.2848287820816, 70.33266797661781, 74.53986302018166, 72.51397132873535, 66.71982944011688, 66.26538902521133, 63.47245529294014, 60.31570628285408, 54.51899953186512, 55.77100954949856, 56.88665248453617, 52.882472947239876, 59.12369504570961, 64.43673714995384, 63.44193533062935, 67.235818952322, 60.986803472042084, 65.8882288634777, 64.20998811721802, 58.220441713929176, 67.25174009799957, 61.32478393614292, 63.375191912055016, 63.30403313040733, 56.93054012954235, 48.1327810138464, 51.14647530019283, 50.60213930904865, 49.185966700315475, 47.43250899016857, 49.68769557774067, 47.64171816408634, 49.843597412109375, 53.13215374946594, 56.11402094364166, 57.99028426408768, 57.98534832894802, 48.112866282463074, 47.1194551885128, 44.86165814101696, 48.7269589304924, 46.45767129957676, 46.770345121622086, 48.3453606069088, 51.040582582354546, 50.78242063522339, 55.05873017013073, 58.50042589008808, 71.81109264492989, 47.27264016866684, 8.028138913214207, 27.72912986576557, 66.78045898675919, 61.812286376953125, 57.172545343637466, 52.034343257546425, 50.608032792806625, 47.97253601253033, 46.3580634444952, 48.00117887556553, 46.23686894774437, 45.47984316945076, 44.17802542448044, 44.850798323750496, 50.944660529494286, 54.5682030916214, 54.4960867613554, 51.26046918332577, 49.85534258186817, 48.32281641662121, 44.92468535900116, 44.08960796892643, 45.25300294160843, 46.490208953619, 43.00896115601063, 46.10949218273163, 45.65838798880577, 50.15762396156788, 49.51258957386017, 53.081529065966606, 56.94411680102348, 55.52291326224804, 59.87088315188885, 52.75540016591549, 57.7814094722271, 58.20591889321804, 61.389897242188454, 58.80051478743553, 63.06817218661308, 58.76922346651554, 58.48798155784607, 62.38056108355522, 59.641022086143494, 55.12793965637684, 55.611277520656586, 53.375443294644356, 54.789997190237045, 56.83963380753994, 59.85749267041683, 57.20637492835522, 58.39503474533558, 59.13606718182564, 53.25666546821594, 49.20900106430054, 52.49906212091446, 25.72526939213276, 1.106430091895163, 1.175841917283833, 2.629834609106183, 1.3936045509763062, 7.13923123665154, 57.265446558594704, 64.27687972784042, 61.15981958806515, 62.24566072225571, 65.45053794980049, 69.79560479521751, 62.222694754600525, 66.1893779039383, 65.40725827217102, 42.423530369997025, 46.53725802898407, 38.92236404120922, 49.588589295744896, 53.74073289334774, 3.844210971146822, 0.6818386784289032, 0.2993153122952208, 0.41420226625632495, 0.2017521928064525, 0.23091924958862364, 0.181665817508474, 0.12409875067532994, 0.12562078423798084, 0.1706919024582021, 0.1493376717553474, 0.2689080673735589, 0.12544195633381605], [0.010834151944436599, 0.02435025860904716, 0.007344760033447528, 0.020570600681821816, 0.03733173507498577, 0.03948985970055219, 0.08495503236190416, 0.03643823380116373, 0.050350931196589954, 0.03595559661334846, 0.03435168560827151, 0.08151986825396307, 0.06256549822865054, 0.055798655084799975, 0.07078683207510039, 0.2757997397566214, 0.17036636680131778, 12.895094454288483, 54.45877656340599, 32.19374589622021, 28.909299038350582, 24.519654884934425, 58.807172030210495, 41.812454760074615, 36.2287911772728, 61.96180075407028, 57.30683773756027, 59.15606930851936, 57.017650455236435, 59.90277864038944, 49.906263649463654, 4.042112426832318, 0.3452063404256478, 1.2614462175406516, 1.2268170132301748, 15.873705223202705, 50.72972886264324, 67.97566965222359, 67.99141600728035, 63.35188776254654, 60.46241261065006, 62.80260443687439, 63.2881423830986, 58.58982749283314, 55.3775330632925, 51.01109616458416, 53.19097079336643, 47.446385845541954, 47.56034553050995, 46.07085585594177, 48.86079154908657, 50.65476268529892, 55.35033792257309, 59.40144494175911, 59.61451470851898, 59.33452673256397, 63.83348912000656, 63.3377905189991, 57.7031222730875, 59.28813502192497, 58.02988573908806, 60.92491239309311, 51.00350797176361, 47.79374800622463, 45.189310759305954, 44.62119184434414, 43.84643241763115, 44.14761945605278, 41.40431486070156, 43.613269329071045, 45.324610099196434, 47.269961312413216, 50.46380393207073, 53.13729487359524, 50.3537580370903, 42.34586253762245, 39.667876437306404, 40.59822991490364, 40.57253569364548, 40.93084126710892, 41.32838733494282, 44.34471867978573, 46.32501281797886, 46.953981667757034, 48.41045491397381, 51.55301548540592, 62.15920016169548, 45.06463944911957, 7.94886234216392, 32.787927612662315, 62.65609189867973, 54.28845450282097, 52.73155264556408, 45.37923976778984, 43.97225506603718, 39.69195954501629, 40.248314291238785, 42.54864625632763, 39.32763509452343, 38.29485051333904, 39.41862881183624, 40.46540044248104, 42.51214541494846, 49.05269645154476, 54.13329362869263, 52.28758826851845, 45.34501500427723, 42.94421263039112, 41.89966008067131, 41.796419620513916, 39.69041682779789, 40.70923335850239, 37.412138879299164, 40.91571807861328, 39.91677448153496, 44.79033976793289, 43.71097728610039, 45.02870097756386, 53.085739240050316, 52.34957054257393, 52.555173709988594, 52.3090723156929, 55.54494448006153, 54.25924926996231, 54.730518981814384, 55.22019490599632, 55.163368955254555, 56.12281747162342, 53.18004257977009, 53.057457357645035, 50.27559243142605, 48.47638517618179, 49.9090451002121, 48.6990912258625, 52.788093611598015, 55.346184745430946, 53.52206602692604, 49.69524957239628, 49.758994951844215, 46.014835461974144, 54.87237296998501, 48.63335095345974, 45.19962340593338, 16.703563593328, 0.2583123359363526, 0.3670750872697681, 0.24793599819531664, 0.383513777051121, 1.969531096983701, 34.013312458992004, 61.059565767645836, 53.72104614973068, 58.55061739683151, 52.679343447089195, 55.79590201377869, 49.001273810863495, 56.51720590889454, 42.00372889637947, 24.68999594449997, 33.91684703528881, 22.908830121159554, 47.522157579660416, 14.174147620797157, 0.25062119239009917, 0.055068693473003805, 0.038553870472242124, 0.06517382818856277, 0.025205105121131055, 0.034790398785844445, 0.01904574324726127, 0.05071522551588714, 0.060626711638178676, 0.05475960380863398, 0.035783648418146186, 0.05049295228673145, 0.032695523696020246, 0.06350598487188108, 0.023118699791666586, 0.015918293975119013, 0.03917575682862662, 0.0207902856709552, 0.016838625742821023, 0.02868778523406945, 0.04168328829109669, 0.020266273750166874, 0.059789116348838434, 0.06760949749150313, 0.031978898477973416, 0.09979518799809739, 0.10880762158194557, 0.038711294837412424, 0.06393902804120444, 0.04279006796423346, 16.533735506236553, 66.58093929290771, 29.378904439508915, 39.02237467467785, 32.17266082763672, 59.654830545187, 44.525136798620224, 39.35035787522793, 68.74891296029091, 63.14234800636768, 65.30003562569618, 60.544830188155174, 63.97014498710632, 54.08186338841915, 4.333738703280687, 0.6528967595659196, 2.020060191862285, 2.1407963382080197, 18.787041194736958, 55.160264521837234, 72.17475593090057, 71.6634401679039, 67.85621926188469, 63.40261124074459, 64.27747249603271, 65.97164958715439, 61.92183069884777, 57.65623278915882, 53.2459956407547, 54.2269130051136, 50.484892800450325, 49.13127243518829, 48.93691286444664, 51.46977715194225, 53.307081162929535, 58.740269020199776, 61.297132819890976, 62.56415583193302, 59.87777218222618, 63.73124040663242, 62.42091491818428, 61.09445549547672, 62.35625758767128, 61.44923485815525, 60.64613655209541, 52.71899811923504, 50.573097467422485, 48.17284606397152, 46.50031641125679, 45.9654077142477, 45.18086761236191, 44.37091067433357, 44.67603050172329, 48.046719431877136, 49.73277635872364, 52.91244573891163, 56.873140409588814, 55.06699092686176, 46.456630155444145, 43.39510403573513, 43.531573712825775, 43.87947544455528, 44.534792080521584, 45.623361468315125, 47.99972355365753, 48.13444532454014, 51.245315596461296, 51.243624687194824, 55.16178824007511, 64.06001016497612, 59.51004311442375, 18.64179588854313, 42.392607629299164, 66.80325016379356, 56.2402767688036, 56.64683595299721, 51.568427458405495, 46.861867010593414, 43.13134878873825, 45.53182817995548, 43.57580713927746, 42.26159065961838, 40.83618074655533, 43.800739869475365, 43.67764927446842, 47.4847561866045, 52.734258100390434, 55.71340084075928, 52.73178443312645, 48.56479123234749, 46.066398695111275, 44.61302608251572, 42.75247111916542, 41.264885142445564, 42.40850977599621, 40.43279819190502, 43.70246194303036, 42.38459385931492, 46.237404718995094, 46.48654595017433, 47.00337901711464, 55.290323942899704, 53.2893893122673, 57.309353202581406, 54.33128200471401, 58.83648745715618, 55.24454779922962, 56.05346739292145, 57.511247768998146, 57.633152827620506, 56.28758043050766, 56.08260042965412, 54.9278461933136, 52.205717861652374, 50.64707189798355, 50.84584303200245, 49.59670566022396, 55.10951824486256, 59.14150469005108, 55.038488656282425, 52.9551250487566, 54.15568582713604, 49.28818501532078, 58.17066818475723, 53.16141977906227, 49.81291405856609, 18.611051738262177, 0.24532521172659472, 0.5232125683687627, 0.19772470579482615, 0.23524304648162797, 2.321638371795416, 36.88020542263985, 66.31453558802605, 57.409846410155296, 62.444021478295326, 56.710976511240005, 62.74245746433735, 54.3924967199564, 63.768869787454605, 47.14163839817047, 29.184719659388065, 44.8590324819088, 22.80283860862255, 59.61089730262756, 17.22657322883606, 0.16548192186746746, 0.10786755796289071, 0.03936653331038542, 0.04595458936819341, 0.11672868989990093, 0.04936152959999163, 0.07168677519075572, 0.03760205865546595, 0.013945129248895682, 0.11330068009556271, 0.09385230689076707, 0.039776636695023626, 0.03807678083830979, 0.18804289953550324, 0.11777953390264884, 0.06597903615329415, 0.09418358677066863, 0.10814538094564341, 0.12457475677365437, 0.2176125714322552, 0.19015892583411187, 0.11733630846720189, 0.20874613313935697, 0.1918160673812963, 0.21926530462224036, 0.2149631635984406, 0.2927481959341094, 0.10398658574558794, 0.5747011711355299, 0.3709304553922266, 24.654739536345005, 80.14681175351143, 44.55588474869728, 46.35091982781887, 38.911306634545326, 70.20001709461212, 50.141121447086334, 43.99858385324478, 74.60897371172905, 68.4175631403923, 69.11819234490395, 65.20045816898346, 66.5718349814415, 59.73587639629841, 7.071821428835392, 2.1408039378002286, 3.208556855097413, 2.950758975930512, 21.461920961737633, 57.329872101545334, 72.78848379850388, 72.0159700512886, 68.89966607093811, 67.02351674437523, 70.20123302936554, 68.23157832026482, 65.96816137433052, 61.20146155357361, 55.442182794213295, 58.25247399508953, 53.247165977954865, 53.143131360411644, 51.48103214800358, 52.72961474955082, 56.48465685546398, 60.41451618075371, 65.69784387946129, 63.73869560658932, 64.12689417600632, 65.34843742847443, 64.79780897498131, 62.20340698957443, 64.72644120454788, 61.728155091404915, 62.720373049378395, 54.62077707052231, 52.68215909600258, 50.42717769742012, 48.386010825634, 50.61426065862179, 50.660279989242554, 48.175517320632935, 47.653527930378914, 50.52619278430939, 51.290821954607964, 56.52603283524513, 60.64610615372658, 57.222151681780815, 47.407498732209206, 46.12432658672333, 46.66564553976059, 47.04953894019127, 45.62734745442867, 48.6921413987875, 51.378821432590485, 52.16971859335899, 53.826832473278046, 52.30608947575092, 58.36406260728836, 68.92084613442421, 56.97247467935085, 10.440178234130144, 34.538448080420494, 70.81678479909897, 59.64973121881485, 58.452073484659195, 51.29677623510361, 49.90988485515118, 45.08234269917011, 47.97030933201313, 46.33527226746082, 43.74591641128063, 41.50524504482746, 47.045708745718, 44.71421845257282, 48.34320992231369, 53.81573706865311, 58.37948217988014, 55.63946820795536, 52.05311805009842, 48.66368852555752, 48.35832171142101, 45.075639858841896, 45.32331816852093, 44.95788037776947, 41.76950566470623, 45.15278711915016, 43.93629379570484, 48.36650267243385, 48.942449167370796, 47.9611062258482, 59.01747174561024, 55.06674773991108, 57.56774313747883, 54.520709440112114, 59.880048260092735, 56.82531237602234, 58.32096911966801, 60.90896464884281, 61.791387498378754, 59.2046383023262, 59.91263151168823, 57.70364664494991, 54.35150071978569, 51.85285359621048, 53.31036038696766, 51.347222328186035, 54.73231628537178, 60.245402455329895, 59.51637737452984, 56.272092461586, 56.089523658156395, 54.232711493968964, 60.90548023581505, 53.18559788167477, 56.29900261759758, 24.536189697682858, 0.32488491211552173, 1.4381140563637018, 0.728539953706786, 0.6567355629522353, 4.01563829742372, 41.73842333257198, 71.23368322849274, 63.096275478601456, 67.04942375421524, 61.950655952095985, 69.3548284471035, 59.53916475176811, 67.55117163062096, 53.828675374388695, 39.20153886079788, 50.89218154549599, 41.412780806422234, 70.91244846582413, 33.88874374330044, 0.5347824131604284, 0.22132984071504325, 0.196518151788041, 0.1503083563875407, 0.1676741222036071, 0.14006983547005802, 0.15791388577781618, 0.20138693740591407, 0.17451090534450486, 0.24381200229981914, 0.166838270961307, 0.15653343172743917, 0.10739089135313407], [0.05157537838385906, 0.06414598334231414, 0.08254090760601684, 0.012488064221543027, 0.02436302169371629, 0.003255255451222183, 0.08011285273823887, 0.056653724241186865, 0.0015132977887333254, 0.06263635848881677, 0.03225931155611761, 0.05482836008013692, 0.03386954194866121, 0.0484744664572645, 0.0095956494078564, 0.22044567565899342, 0.26238482678309083, 1.9474956043995917, 45.58176890015602, 40.71405149996281, 37.31095410883427, 24.794868417084217, 32.423910945653915, 72.26324558258057, 39.895849004387856, 54.64085519313812, 65.82577541470528, 64.3326835334301, 60.66580809652805, 58.806674256920815, 49.38311152160168, 5.917567815631628, 0.3400791093008593, 0.9551624651066959, 2.2997890692204237, 27.495647594332695, 57.46354892849922, 70.79472318291664, 66.65163829922676, 64.96575996279716, 64.65868324041367, 61.95909149944782, 60.17942659556866, 59.22450363636017, 53.19963812828064, 52.879471108317375, 49.91484358906746, 48.05660270154476, 47.01002486050129, 43.82195793092251, 42.14755117893219, 48.42367820441723, 50.18123209476471, 57.355247139930725, 60.850185602903366, 61.44611142575741, 63.30865368247032, 61.72561302781105, 61.784004494547844, 58.93758483231068, 60.43535426259041, 58.68340507149696, 48.31179320812225, 44.28176745772362, 42.93712981045246, 43.125333711504936, 44.02717351913452, 42.06483341753483, 41.74851939082146, 45.73843449354172, 48.11960332095623, 47.96581797301769, 50.11268377304077, 51.36309787631035, 44.898732751607895, 41.005777046084404, 41.710985004901886, 38.25627878308296, 38.39207209646702, 39.55052353441715, 43.52837808430195, 44.590257704257965, 48.61609987914562, 45.81849619746208, 52.24659986793995, 50.26121400296688, 62.671640664339066, 45.74381500482559, 8.017407339066267, 43.25604669749737, 61.10157631337643, 54.76676903665066, 52.736366987228394, 47.55711950361729, 44.9173479527235, 43.72207649052143, 39.67522904276848, 42.967360988259315, 39.432900846004486, 37.579535096883774, 38.404991403222084, 40.946078449487686, 39.68689061701298, 43.313214629888535, 53.43083292245865, 49.89839047193527, 45.44786788523197, 43.40355098247528, 43.32584895193577, 41.592450365424156, 42.50816322863102, 39.76243436336517, 38.03717494010925, 40.36091364920139, 43.15957747399807, 40.99195338785648, 42.793223932385445, 44.036976993083954, 44.98478293418884, 54.350767359137535, 55.85183881223202, 53.41658368706703, 56.09244950115681, 54.801848754286766, 51.5061791986227, 54.53403912484646, 54.3070925027132, 54.985451102256775, 53.5428699105978, 51.73270784318447, 48.58653366565704, 48.707169592380524, 45.407601445913315, 48.3969846367836, 53.744107112288475, 54.10517893731594, 59.45593781769276, 59.98323932290077, 55.51355056464672, 55.594186037778854, 54.11583736538887, 44.92323763668537, 48.21605734527111, 21.316111385822296, 0.2748010167852044, 0.12455823656637222, 0.08358786275493912, 0.31779375043697655, 0.9289451187942177, 26.84614274650812, 55.5104461312294, 53.39219279587269, 53.836153373122215, 58.21358308196068, 53.431646078825, 46.941119357943535, 62.49745421111584, 30.020756497979164, 29.047799706459045, 24.47685208171606, 29.928497448563576, 42.866001427173615, 3.971156934276223, 0.2756822429364547, 0.09532947762636468, 0.06196895250468515, 0.027048280826420523, 0.07882437304942869, 0.007266724132932723, 0.00683207375004713, 0.1046450859575998, 0.024046675680438057, 0.0033447781743234373, 0.03917534493666608, 0.02915381501225056, 0.009701822909846669, 0.01565260510687949, 0.01844578921009088, 0.06766431251890026, 0.01635457476368174, 0.07565929132397287, 0.015125076333788456, 0.0657824709196575, 0.1301162547315471, 0.04264820643584244, 0.10056058716145344, 0.08468777014059015, 0.051131844957126305, 0.058009089989354834, 0.0253487756344839, 0.0192500583580113, 0.08777242532232776, 0.24107693578116596, 2.5771292997524142, 58.85646678507328, 41.284051313996315, 39.91414502263069, 39.75683346390724, 37.01791003346443, 78.24648812413216, 41.81726910173893, 60.90567022562027, 70.83874002099037, 68.76036554574966, 62.825950384140015, 64.49479043483734, 53.636736273765564, 6.374989645555615, 0.19272205157903954, 0.9979013842530549, 2.5038070091977715, 31.61851566284895, 62.40055941045284, 75.05785122513771, 66.90105691552162, 66.65902510285378, 67.43409991264343, 64.31573644280434, 63.837729692459106, 60.181413888931274, 55.332661271095276, 53.54579195380211, 52.52605967223644, 51.59456625580788, 48.94901901483536, 46.910960376262665, 46.42358332872391, 50.88620446622372, 52.65977829694748, 60.672043561935425, 62.2114397585392, 63.50102975964546, 64.51736122369766, 62.844755575060844, 61.83925352990627, 60.006326884031296, 62.22708731889725, 59.95765149593353, 50.849509835243225, 46.38153098523617, 45.65182574093342, 45.05689166486263, 46.406035870313644, 44.53263379633427, 44.63335119187832, 47.029855996370316, 50.13777382671833, 50.69658704102039, 51.56308874487877, 53.3902321010828, 49.88962434232235, 43.93328055739403, 44.12535645067692, 44.07253548502922, 42.46151693165302, 43.719310238957405, 46.006114929914474, 48.706554025411606, 50.88541030883789, 49.5129581540823, 54.24855284392834, 54.92729142308235, 62.950161918997765, 58.83809097111225, 20.97935825586319, 54.53214302659035, 63.241830468177795, 57.58575037121773, 54.699090868234634, 53.69646526873112, 48.75493302941322, 46.28231830894947, 43.331446051597595, 44.12189483642578, 42.23734796047211, 40.22178031504154, 43.505864292383194, 43.95442642271519, 43.09390939772129, 45.69054186344147, 56.36103808879852, 53.4363654255867, 48.68850119411945, 46.302233040332794, 46.61139205098152, 44.35585968196392, 44.36736926436424, 40.048289224505424, 41.61097437143326, 41.98411054909229, 45.20502291619778, 44.34762552380562, 43.78411576151848, 45.29348596930504, 49.50199954211712, 55.47753609716892, 57.88870811462402, 55.83608105778694, 57.64683209359646, 56.385865956544876, 53.40121351182461, 57.35063038766384, 57.7292762696743, 57.002652660012245, 55.433762446045876, 53.51244494318962, 50.784012749791145, 50.10486379265785, 47.262259125709534, 49.64350774884224, 55.57275138795376, 56.19802683591843, 61.03091910481453, 60.90734213590622, 57.479698061943054, 56.915724724531174, 56.46256864070892, 49.80093710124493, 54.01436761021614, 25.29312428086996, 0.14794237475143746, 0.32436208392027766, 0.5141938116867095, 0.4636407009093091, 1.1035011615604162, 29.272890128195286, 63.45233157277107, 59.11094292998314, 61.55669689178467, 62.082961052656174, 60.36071866750717, 49.228387624025345, 74.23544615507126, 33.094130381941795, 35.57947441935539, 28.781057819724083, 30.875988006591797, 51.29036217927933, 2.1948567498475313, 0.18047627352643758, 0.09969262318918481, 0.020107751006435137, 0.023959668142197188, 0.01365932910630363, 0.03163201123243198, 0.07720078399870545, 0.12860111572081223, 0.0798117188969627, 0.03495327051496133, 0.07566966654849239, 0.03612099535530433, 0.06146311206975952, 0.12063150352332741, 0.1790939344209619, 0.1797454510233365, 0.21401027566753328, 0.10687921763746999, 0.06248889374546707, 0.23613479628693312, 0.25006214738823473, 0.227938354073558, 0.2768299891613424, 0.13545379566494375, 0.18506166263250634, 0.14515595161356032, 0.18430257914587855, 0.11427276738686487, 0.47117320296820253, 0.4357321484712884, 4.4883932545781136, 75.21750345826149, 61.22898727655411, 53.2578282058239, 43.11262719333172, 45.211383774876595, 82.43289068341255, 48.37388187646866, 65.11083617806435, 78.94954159855843, 73.66354644298553, 68.74893575906754, 68.17474097013474, 59.975738525390625, 8.268732503056526, 1.6583020286634564, 1.4322722260840237, 4.426474152132869, 32.05022379755974, 63.39547902345657, 76.92624136805534, 69.23530966043472, 69.88251373171806, 73.38026404380798, 68.8870507478714, 66.60768985748291, 63.693793416023254, 58.71265210211277, 57.813719138503075, 55.10253421962261, 55.46243570744991, 52.8618248552084, 49.6980120241642, 46.621146127581596, 56.032215133309364, 55.17782337963581, 62.599626928567886, 63.389760330319405, 63.685802444815636, 67.78037533164024, 64.12744894623756, 65.19957661628723, 61.77994251251221, 63.75562369823456, 61.31324015557766, 51.493119299411774, 47.31989063322544, 47.30178080499172, 46.374478563666344, 52.41417087614536, 48.72828125953674, 48.732107654213905, 50.6512288749218, 54.620723873376846, 52.96266384422779, 55.236309841275215, 58.158493638038635, 50.58834984898567, 46.862828359007835, 45.47931119799614, 44.326312467455864, 43.94061416387558, 47.75961063802242, 47.58163578808308, 50.88469974696636, 53.03540714085102, 51.80227071046829, 57.494019493460655, 56.54549919068813, 66.42474487423897, 57.28218466043472, 11.875784900039434, 47.5854279845953, 70.36525502800941, 61.25406593084335, 58.79052892327309, 53.78183528780937, 51.84305012226105, 50.57810939848423, 46.95758767426014, 47.35979989171028, 45.30437998473644, 42.0797324180603, 44.10929471254349, 46.253261268138885, 45.27660347521305, 47.648307010531425, 60.03966249525547, 55.75987234711647, 49.87386278808117, 48.38756114244461, 48.420098796486855, 46.538454964756966, 48.3207531273365, 43.99030029773712, 43.00735764205456, 43.433447778224945, 45.88426686823368, 46.48100584745407, 45.93351222574711, 48.004450500011444, 49.48159463703632, 58.40103082358837, 61.569608598947525, 55.35535365343094, 58.998845145106316, 61.88331976532936, 56.062256321311, 60.844740495085716, 60.50278924405575, 61.08351968228817, 57.76473216712475, 57.334538251161575, 52.25015267729759, 55.07456012070179, 48.23755279183388, 50.41050039231777, 56.979405507445335, 57.812081426382065, 65.31984016299248, 64.4104577600956, 59.715087711811066, 56.48402988910675, 59.86250080168247, 49.99264061450958, 55.33157832920551, 32.018818482756615, 0.3638240648433566, 0.9425340802408755, 0.38323238433804363, 0.7897715305443853, 2.273942856118083, 34.31889206171036, 67.88849472999573, 63.38726006448269, 64.02420848608017, 67.10303127765656, 62.85361289978027, 55.779581889510155, 74.32416379451752, 41.228673085570335, 43.44857096672058, 39.79252114892006, 46.64983078837395, 66.4064222574234, 10.594187770038843, 0.7204020372591913, 0.1858296073623933, 0.22610711952438578, 0.16969956195680425, 0.13732804509345442, 0.09851625232840888, 0.24077277397736907, 0.2572873409371823, 0.1931232269271277, 0.11955796464462765, 0.20513844938250259, 0.11632450885372236, 0.11517343038576655], [0.05230357368418481, 0.09976959874620661, 0.03043911088752793, 0.0946331798331812, 0.03153796998958569, 0.019437474766164087, 0.06752314118784852, 0.019932849063479807, 0.022111473663244396, 0.02782692918117391, 0.03742730143130757, 0.0924034119816497, 0.04737941642815713, 0.06631885073147714, 0.057040353494812734, 0.04682148093706928, 0.4657843499444425, 0.13894150382839143, 19.841017238795757, 59.057198613882065, 27.314803898334503, 30.79235829412937, 22.21324324607849, 51.63169406354427, 68.74660268425941, 61.25571124255657, 62.21663407981396, 62.95081928372383, 62.50038005411625, 58.618303164839745, 46.194615215063095, 3.8599148159846663, 0.37444505898747593, 0.6114569550845772, 5.090380702167749, 48.57926085591316, 70.55291175842285, 68.21083143353462, 64.55971375107765, 60.737479850649834, 60.140759870409966, 59.880443438887596, 59.15633909404278, 57.39239014685154, 54.24232117831707, 49.794401451945305, 51.555325761437416, 49.17652800679207, 47.51423120498657, 45.064818039536476, 43.78308981657028, 43.46223123371601, 44.16352920234203, 49.45763312280178, 53.81920248270035, 57.42019325494766, 63.154366761446, 62.52861253917217, 62.419752180576324, 58.44865746796131, 57.37422712147236, 52.79260776937008, 45.340440049767494, 46.59705922007561, 43.79124037921429, 41.42631947994232, 44.02602598071098, 43.59598785638809, 44.20128397643566, 46.68206825852394, 48.90605852007866, 47.393572479486465, 48.270462825894356, 45.707063376903534, 40.84992080926895, 39.762248173356056, 40.302089005708694, 38.5554139316082, 41.554676592350006, 38.66681255400181, 44.22779515385628, 47.821961492300034, 49.464377760887146, 48.62693689763546, 53.3561897277832, 50.991086438298225, 61.470718905329704, 47.098286524415016, 12.279076259583235, 53.78639504313469, 60.09807676076889, 57.16696724295616, 53.56225647032261, 47.480652406811714, 45.588513538241386, 41.99047140777111, 41.443532556295395, 42.51773491501808, 38.90567533671856, 38.42723920941353, 38.6254707723856, 39.80066791176796, 38.687973618507385, 38.937023654580116, 45.964936539530754, 51.409588381648064, 45.09065665304661, 46.53381921350956, 44.16236266493797, 42.661127820611, 41.16050474345684, 40.430700704455376, 40.076149329543114, 40.33062927424908, 40.000499188899994, 42.7184971421957, 42.40195132791996, 44.54268425703049, 42.75008864700794, 50.09921729564667, 56.72770321369171, 55.0511571764946, 56.049451008439064, 55.11450357735157, 54.36635032296181, 55.759275779128075, 52.37500637769699, 52.26300358772278, 49.923047348856926, 47.99941956996918, 46.17098428308964, 45.480910912156105, 48.43136139214039, 50.46914264559746, 55.827440321445465, 56.07908941805363, 60.7558860629797, 57.875640615820885, 55.1119577139616, 56.10708251595497, 56.04028970003128, 49.26085688173771, 47.90613077580929, 28.88286765664816, 0.4155497392639518, 0.054246226864052005, 0.09767317998921499, 0.49911782378330827, 1.4569199597463012, 20.477749072015285, 54.71074104309082, 51.51541270315647, 57.707602232694626, 52.02653467655182, 53.74924823641777, 60.41666306555271, 45.74115514755249, 22.34273459762335, 29.99509457498789, 22.389777973294258, 41.053696274757385, 28.2167823985219, 0.35924228257499635, 0.06039435633283574, 0.05451414588605985, 0.07081871473928913, 0.055898481368785724, 0.057296012237202376, 0.009444216957490426, 0.051092384965159, 0.07728143318672664, 0.009357432063552551, 0.046892842146917246, 0.03214757380192168, 0.06171416578581557, 0.09148308949079365, 0.02591251100966474, 0.05591908338828944, 0.02780630675260909, 0.06474286303273402, 0.02692085221497109, 0.048584263495285995, 0.040986868043546565, 0.0567757518729195, 0.048744177765911445, 0.05795298362500034, 0.02731162265263265, 0.022065968878450803, 0.050787135915015824, 0.04170458050793968, 0.07697216540691443, 0.09388384074554779, 0.40470565552823246, 0.1396951696369797, 24.90398906171322, 64.7801399230957, 26.77577242255211, 49.227418676018715, 27.71353930234909, 57.78003014624119, 74.41965267062187, 66.86409249901772, 69.64865148067474, 65.73486909270287, 65.80023318529129, 62.57557801902294, 49.63814623653889, 4.777754852548242, 0.5764772195834666, 0.6655208696611226, 6.331254467368126, 54.12196643650532, 73.68788033723831, 71.61191493272781, 66.8542206287384, 63.776689767837524, 63.57574515044689, 62.09977515041828, 60.68829149007797, 60.01373268663883, 56.417335867881775, 52.26887047290802, 53.91801618039608, 53.51361908018589, 50.54171495139599, 48.913840502500534, 47.592507004737854, 47.070734202861786, 48.10584045946598, 52.40696646273136, 56.92378789186478, 59.69679169356823, 62.061583399772644, 65.29146328568459, 63.847753554582596, 60.13268530368805, 59.89935502409935, 54.39441941678524, 48.14104937016964, 46.99774771928787, 44.65429186820984, 44.54391539096832, 45.28575338423252, 45.59819921851158, 46.564411371946335, 47.010724022984505, 48.69244158267975, 50.415956899523735, 52.1998243778944, 51.14932894706726, 44.98822174966335, 44.00449253618717, 45.0657793879509, 41.82767294347286, 44.5394392311573, 42.606919929385185, 47.60287664830685, 50.71285396814346, 54.668228924274445, 52.02931232750416, 57.525557801127434, 56.023418605327606, 62.02975630760193, 53.68282400071621, 27.394046746194363, 63.7726391851902, 59.93486791849136, 60.91614246368408, 56.11726976931095, 53.047543689608574, 49.74367417395115, 47.71135702729225, 44.55428123474121, 43.32148678600788, 42.41813465952873, 42.62486256659031, 42.35673375427723, 43.76528017222881, 42.99361377954483, 41.90684549510479, 50.0784932076931, 55.03455966711044, 48.014364168047905, 49.733790904283524, 46.171409860253334, 45.31117022037506, 43.87907266616821, 42.37428121268749, 41.84320271015167, 43.533511608839035, 42.539389953017235, 46.08608543872833, 43.53712521493435, 46.02951027452946, 45.6876540184021, 53.408972695469856, 57.66140051186085, 57.27440647780895, 57.14066885411739, 57.33822025358677, 56.23721033334732, 58.095276430249214, 57.79159292578697, 54.675003960728645, 52.577349320054054, 50.03869794309139, 48.50176781415939, 48.458814918994904, 49.59620788693428, 52.02115796506405, 56.1738221347332, 59.3107970058918, 61.816523149609566, 57.61581055819988, 57.68092006444931, 56.431201323866844, 56.7464742064476, 51.5816393494606, 54.29318904876709, 33.83080445230007, 0.3138664533616975, 0.17721193697070703, 0.7482536521274596, 0.7514494587667286, 1.4287580084055662, 22.665878757834435, 62.71464675664902, 57.63368099927902, 63.50257247686386, 57.941798865795135, 60.42579397559166, 69.24362361431122, 53.2279884070158, 24.421563148498535, 39.79788266122341, 22.684725746512413, 50.46145185828209, 31.816239953041077, 0.4775563854491338, 0.07883980229962617, 0.05825141604873352, 0.03039245948457392, 0.03755033467314206, 0.007732496942480793, 0.045860826430725865, 0.029596339118143078, 0.031464519634027965, 0.033909565972862765, 0.0019553174661268713, 0.07550501366495155, 0.03569076121493708, 0.024898694609873928, 0.1755854461225681, 0.14859837392577901, 0.24293530324939638, 0.19054286851314828, 0.12165515523520298, 0.11181633279193193, 0.18548250489402562, 0.1306579780066386, 0.2646557689877227, 0.18890039180405438, 0.12588776444317773, 0.205279249639716, 0.16973594203591347, 0.1826276260544546, 0.19683153106598184, 0.2409391783294268, 0.5596275581046939, 0.517293851589784, 36.1348070204258, 81.89136654138565, 40.08912943303585, 49.441309198737144, 31.981637477874756, 61.101747304201126, 80.82502216100693, 72.9520346224308, 73.64643976092339, 71.46503761410713, 71.17978692054749, 66.96763694286346, 54.31381814181805, 6.892204117029905, 1.12326544476673, 0.9323639259673655, 7.687817299738526, 54.536900371313095, 77.18742415308952, 73.16874459385872, 70.34266903996468, 65.61166450381279, 67.91013076901436, 66.96872368454933, 64.25274342298508, 65.2365030348301, 60.05176484584808, 55.63110865652561, 58.61802197992802, 56.788306161761284, 53.285232335329056, 52.13737852871418, 48.817318081855774, 48.667579516768456, 48.6526995152235, 54.25633482635021, 56.87908709049225, 62.161768823862076, 66.81210368871689, 67.26733446121216, 68.08517217636108, 61.82680919766426, 61.840344071388245, 56.632400527596474, 48.78774806857109, 48.89764957129955, 47.0408184081316, 47.491003051400185, 48.39148633182049, 50.31068354845047, 49.984634444117546, 50.25574989616871, 53.16167816519737, 53.87314818799496, 54.28962104022503, 52.71123133599758, 46.59176230430603, 46.55207723379135, 46.09839677810669, 44.61608871817589, 48.16977582871914, 45.07055193185806, 50.47471694648266, 55.33151373267174, 53.81759516894817, 53.91555391252041, 61.89739041030407, 54.869428128004074, 66.13626435399055, 55.48495709896088, 17.82010518014431, 58.635292053222656, 64.77381706237793, 62.94038504362106, 60.022506415843964, 53.54258872568607, 52.080400586128235, 49.58752915263176, 47.329549714922905, 47.533321380615234, 45.92453330755234, 43.523932322859764, 44.84672874212265, 45.938311368227005, 43.425517603755, 42.472699731588364, 52.48804651200771, 57.88981765508652, 50.9691996127367, 51.014975756406784, 48.774091601371765, 48.11955012381077, 46.52592323720455, 46.28473877906799, 44.45837818086147, 43.289332911372185, 42.80551627278328, 48.15268814563751, 45.06734110414982, 49.669015780091286, 48.15004348754883, 55.82158103585243, 61.539791598916054, 57.35495075583458, 59.16361950337887, 59.620503187179565, 58.37089084088802, 60.222782269120216, 57.553034126758575, 57.59200483560562, 54.57864873111248, 53.427314311265945, 51.53540343046188, 50.332802161574364, 51.52759484946728, 53.21533888578415, 58.40940937399864, 61.14707887172699, 62.37922355532646, 59.59941811859608, 58.40279772877693, 59.27303463220596, 61.00393295288086, 54.01111878454685, 55.80621846020222, 40.73195993900299, 0.7653147366363555, 0.5409671156667173, 0.675699810963124, 0.6555976427625865, 1.9322087871842086, 27.806429117918015, 66.86729192733765, 61.766692623496056, 66.35400027036667, 61.94073848426342, 66.1490772664547, 73.11283439397812, 55.7193361222744, 34.528921991586685, 45.90903013944626, 40.49410790205002, 59.463894590735435, 48.84447142481804, 0.5694833386223763, 0.28569779300596565, 0.13732773339143023, 0.13968814891995862, 0.20915683766361326, 0.16433270619018003, 0.08831820072373375, 0.1059109895140864, 0.10880040790652856, 0.16498290176969022, 0.06700280660879798, 0.25548638601321727, 0.1345831822254695, 0.10293471757904626], [0.039089456186047755, 0.04031024087453261, 0.05170555850781966, 0.06072259711800143, 0.03147529932903126, 0.10073777491925284, 0.021954795156489126, 0.018775829703372438, 0.02822885595378466, 0.04325736124883406, 0.07693560721236281, 0.03152013618091587, 0.035678333952091634, 0.025088146358029917, 0.08017905231099576, 0.09538008467643522, 0.2647097973385826, 0.4530569032067433, 3.795418026857078, 51.07076816260815, 40.89252412319183, 27.351908907294273, 22.410908639431, 36.4431756734848, 64.823267608881, 67.78107449412346, 62.59419322013855, 64.94582623243332, 59.07203681766987, 62.05295026302338, 42.420118153095245, 4.294899562373757, 0.7035889488179237, 0.07946011901367456, 21.31204180419445, 65.32564625144005, 70.71355953812599, 65.54824590682983, 62.32848487794399, 62.9907551407814, 61.77646189928055, 57.71558940410614, 58.68276670575142, 56.96614421904087, 55.062070190906525, 51.29036597907543, 51.52432702481747, 49.29923102259636, 47.48258650302887, 47.26991951465607, 42.58847191929817, 45.35718955099583, 44.59151543676853, 44.68944378197193, 45.48670940101147, 49.414349645376205, 52.65010021626949, 55.55595628917217, 54.047205448150635, 49.22198876738548, 50.421899780631065, 45.739536434412, 46.618307679891586, 44.78146344423294, 43.107634261250496, 41.564905643463135, 42.85709090530872, 42.37105518579483, 43.469025269150734, 47.412294074893, 46.17091588675976, 47.39615634083748, 47.79128573834896, 40.430940091609955, 41.365670934319496, 40.30250698328018, 41.443403363227844, 37.61735446751118, 40.78649841248989, 40.160349011421204, 48.67024317383766, 46.49811252951622, 51.80255949497223, 49.78405840694904, 54.242651760578156, 52.66073204576969, 63.12478914856911, 37.494666650891304, 17.03880250453949, 59.401612132787704, 57.63575568795204, 55.92623881995678, 56.11108370125294, 49.911959543824196, 46.17773652076721, 46.95408046245575, 40.70508398115635, 42.452044039964676, 38.10543067753315, 37.19402298331261, 37.63651303946972, 39.60232235491276, 37.420775815844536, 39.19317550957203, 41.37290954589844, 46.97612687945366, 44.58929255604744, 44.82086353003979, 44.231727942824364, 45.6169094145298, 44.44946385920048, 41.824116334319115, 39.6442075073719, 38.05794082581997, 40.57031661272049, 43.328546807169914, 42.464606165885925, 41.60365216434002, 43.4280938655138, 42.993815168738365, 48.795701041817665, 53.00363704562187, 54.748355224728584, 56.57092742621899, 55.95984421670437, 53.492879793047905, 52.765986397862434, 50.243989527225494, 49.38841983675957, 46.81286484003067, 45.27601830661297, 43.00521835684776, 45.536152347922325, 51.63816511631012, 56.83830767869949, 60.22589050233364, 57.59517766535282, 55.1422268897295, 55.88052347302437, 53.98138917982578, 53.61857324838638, 50.970077365636826, 48.34549359977245, 35.795211642980576, 0.7338648929726332, 0.08638834959128872, 1.2602393073029816, 0.3983803011942655, 2.57579343393445, 29.778405502438545, 57.82519072294235, 55.149298310279846, 55.12781426310539, 54.77502219378948, 62.77383618056774, 47.55522720515728, 40.782060250639915, 24.09272689372301, 28.571278676390648, 25.477184504270554, 43.91698703169823, 7.887210650369525, 0.10627933967043646, 0.03534767747623846, 0.12158139317762107, 0.055528216471429914, 0.014240216441976372, 0.04736531191156246, 0.05640779505483806, 0.005313500450938591, 0.07390061655314639, 0.02819598808855517, 0.13696148351300508, 0.06437885444029234, 0.03570107706764247, 0.09539341364870779, 0.04421553327119909, 0.010587080778350355, 0.029219762254797388, 0.0434009000309743, 0.056611826294101775, 0.08804077107924968, 0.07451282159308903, 0.02340439139516093, 0.0566058668482583, 0.0525456993636908, 0.04947971290675923, 0.0038658901530652656, 0.07502813183236867, 0.060598524869419634, 0.012809326963179046, 0.04442900091817137, 0.14904312818543985, 0.34606515371706337, 3.849569158628583, 62.76791229844093, 38.85625138878822, 32.65246868133545, 33.36925081908703, 38.36502894759178, 73.85996550321579, 69.77127850055695, 68.28943401575089, 69.37906354665756, 63.74966561794281, 65.58230727910995, 45.15455402433872, 5.429512979462743, 0.8892021013889462, 0.140894124051556, 25.057377330958843, 69.61352616548538, 73.00334706902504, 68.52626010775566, 65.209501683712, 64.52590316534042, 65.53894400596619, 61.88814550638199, 61.75294876098633, 59.763329923152924, 56.98439463973045, 55.077402368187904, 53.14718194305897, 52.71300584077835, 49.541612416505814, 49.45724934339523, 45.59750385582447, 49.12136256694794, 48.12061406672001, 46.845470890402794, 46.15231208503246, 52.8967297822237, 55.25229558348656, 55.585431307554245, 55.634285286068916, 54.32951509952545, 53.55695195496082, 47.6825849711895, 48.640346378088, 47.28587485849857, 45.546313002705574, 44.0599999576807, 45.03343552350998, 44.53929103910923, 46.66438400745392, 50.57241350412369, 47.85076014697552, 49.382047578692436, 48.70107091963291, 45.84276929497719, 44.7873455286026, 43.42611037194729, 44.853370785713196, 42.12537556886673, 45.08234269917011, 45.33343322575092, 49.55297000706196, 50.930905267596245, 54.8922573029995, 53.02854850888252, 57.571900114417076, 56.661085188388824, 65.29822692275047, 44.205976724624634, 32.779704853892326, 66.39797911047935, 60.1880369335413, 61.2688547372818, 57.81680457293987, 56.95968836545944, 50.45952916145325, 49.4766853004694, 44.257144778966904, 43.95962834358215, 41.43737308681011, 41.250677704811096, 42.4132215231657, 44.91466909646988, 41.274567022919655, 43.58564481139183, 45.32206043601036, 51.00296080112457, 46.56895972788334, 47.889723256230354, 49.10671815276146, 46.953149512410164, 45.64247064292431, 43.36458407342434, 40.745631605386734, 41.73556588590145, 43.311003148555756, 45.46715185046196, 44.408034682273865, 44.96044144034386, 45.73015473783016, 47.08034008741379, 52.71912731230259, 55.52636727690697, 55.557236820459366, 58.11865657567978, 57.55100503563881, 55.68068839609623, 55.391322523355484, 53.84225204586983, 50.98176933825016, 48.23626846075058, 48.6324580013752, 46.5690129250288, 47.39078722894192, 54.0963976085186, 58.378456234931946, 61.91857047379017, 58.401076421141624, 57.16596029698849, 55.54671138525009, 56.820661425590515, 54.731480330228806, 53.425771594047546, 53.525706231594086, 43.12978707253933, 0.7802143902517855, 0.21530484838876873, 5.165450423955917, 1.5753587731160223, 2.7609513234347105, 35.313336700201035, 63.13924357295036, 61.17902375757694, 60.62059052288532, 62.839808240532875, 66.08558267354965, 56.2714046984911, 44.41382937133312, 29.3438608199358, 38.24411563575268, 25.979546047747135, 55.57318836450577, 6.339232139289379, 0.05229481634160038, 0.07178932515671477, 0.09792781827854924, 0.05589594322373159, 0.014143096213956596, 0.039944974341779016, 0.030029914778424427, 0.06142279860796407, 0.08789065686869435, 0.05715969455195591, 0.07324306629016064, 0.02548245684010908, 0.028655451715167146, 0.04964986881532241, 0.19148095801938325, 0.15556899597868323, 0.14514055947074667, 0.15922398422844708, 0.24170771677745506, 0.20026552258059382, 0.2322037291014567, 0.11616825708188117, 0.157107527484186, 0.16535474744159728, 0.0996210282028187, 0.08263343857834116, 0.19620544044300914, 0.09323250968009233, 0.13520565116778016, 0.20368032215628773, 0.5407300440128893, 0.5637134669814259, 7.3699030838906765, 78.20629388093948, 57.70572513341904, 44.14483420550823, 33.37035275995731, 44.589999318122864, 77.66517251729965, 79.15964752435684, 73.77779871225357, 74.05235677957535, 71.59497544169426, 68.74151855707169, 51.2857074290514, 7.0113505236804485, 1.5699885925278068, 0.5280433560255915, 26.077595986425877, 74.25660341978073, 78.58226090669632, 70.86777806282043, 65.3768827021122, 68.39855656027794, 70.38706585764885, 66.47721245884895, 65.97998633980751, 63.77390071749687, 61.236085295677185, 56.07988737523556, 56.591936498880386, 55.11858455836773, 53.98028343915939, 51.301028206944466, 48.3825758099556, 51.58536694943905, 49.751851335167885, 49.42022792994976, 48.01879473030567, 54.293949007987976, 56.71109810471535, 56.893112137913704, 57.44712620973587, 53.577474653720856, 56.19390405714512, 48.379984349012375, 49.67899024486542, 48.98555785417557, 48.532983139157295, 47.01782204210758, 49.67352993786335, 46.78850434720516, 49.88265171647072, 52.622601091861725, 51.18181720376015, 53.40828113257885, 52.83877909183502, 48.26056815683842, 47.94994242489338, 45.62672048807144, 47.80227854847908, 43.823420852422714, 47.074104622006416, 49.16855603456497, 54.83649529516697, 51.01588010787964, 57.713115736842155, 55.482434034347534, 61.89419098198414, 57.20899298787117, 70.85348322987556, 45.380254313349724, 22.164472863078117, 68.24775025248528, 63.605322763323784, 64.23255130648613, 62.73334175348282, 56.39237880706787, 51.874991208314896, 52.16617338359356, 46.84099093079567, 48.25348533689976, 43.988700583577156, 42.80552767217159, 44.51277606189251, 46.63907736539841, 41.68635852634907, 46.51242636144161, 46.44495718181133, 53.23421627283096, 50.236674919724464, 48.569658771157265, 49.1676364839077, 49.91558454930782, 48.430491238832474, 47.38409198820591, 44.519049525260925, 42.58714959025383, 44.48219150304794, 47.92297147214413, 47.98808477818966, 48.30244570970535, 48.23033697903156, 48.194512501358986, 53.704327046871185, 55.69773808121681, 58.53739410638809, 60.2154790610075, 60.59693679213524, 59.49017398059368, 58.27192895114422, 57.208867594599724, 53.95813062787056, 51.088038235902786, 50.68110667169094, 49.25073802471161, 47.464849054813385, 56.02409116923809, 59.803531765937805, 65.14048978686333, 58.64369340240955, 58.03426690399647, 56.56575970351696, 55.80465294420719, 56.39273218810558, 56.94641947746277, 54.4661595672369, 48.07815134525299, 1.4101895922794938, 0.6796107511036098, 8.52713668718934, 1.827571545727551, 3.5868785670027137, 38.56252335011959, 71.99827820062637, 63.3344466984272, 67.0231519639492, 65.29150888323784, 70.48198476433754, 59.32257257401943, 52.1740959584713, 35.22809587419033, 47.0687735080719, 41.652851924300194, 67.01833382248878, 18.138824477791786, 0.43900356511585414, 0.17422733071725816, 0.2924932533642277, 0.18205030937679112, 0.12114354831282981, 0.11989906313829124, 0.09161508045508526, 0.12191587171400897, 0.18099055218044668, 0.10178747601457871, 0.23308344127144665, 0.12642004759982228, 0.11122145690023899, 0.22715417115250602], [0.05596517446974758, 0.07833292285795324, 0.033930702338693663, 0.05811406677821651, 0.025021379042300396, 0.012420289440342458, 0.11120443945401348, 0.04445966646017041, 0.0622006398771191, 0.045906947198091075, 0.03992562284111045, 0.03180884647008497, 0.059324120011297055, 0.04018416853796225, 0.03981466063123662, 0.048141138249775395, 0.07224337852676399, 0.3235290083102882, 0.02119115673849592, 26.318161077797413, 52.67637960612774, 35.60542322695255, 26.160287149250507, 32.712851241230965, 69.51411589980125, 65.60106307268143, 61.92716181278229, 63.955910950899124, 58.09942960739136, 61.60027675330639, 44.29006241261959, 3.9762484235689044, 0.9352536115329713, 3.381892153993249, 44.90910239517689, 70.90584442019463, 69.25219595432281, 65.66688314080238, 64.41007018089294, 62.10064150393009, 61.357595175504684, 58.86915810406208, 60.319004505872726, 57.71196819841862, 53.63834358751774, 51.34579740464687, 51.72861546278, 50.04528298974037, 48.25898364186287, 48.16601023077965, 47.27433107793331, 43.826430290937424, 44.7993490844965, 43.87263581156731, 43.765264973044395, 45.6887711584568, 47.4357920140028, 49.06960554420948, 47.74759188294411, 45.04761256277561, 45.75309790670872, 46.75311304628849, 45.57983860373497, 44.455524533987045, 41.611152961850166, 42.55944147706032, 44.431874603033066, 43.049083203077316, 44.70162972807884, 47.64448821544647, 44.510507583618164, 46.27156488597393, 42.96744838356972, 39.58233542740345, 41.488244757056236, 37.83717267215252, 40.389332324266434, 39.394199922680855, 41.64079897105694, 40.80729089677334, 49.19323951005936, 49.50379304587841, 53.42763729393482, 51.995463743805885, 56.213184222579, 50.463017374277115, 59.43540371954441, 42.507722452282906, 27.978899963200092, 62.311241403222084, 56.116080433130264, 58.568199053406715, 53.4901325404644, 54.81606759130955, 48.66891324520111, 51.641102358698845, 46.17854967713356, 41.29319742321968, 40.066478848457336, 39.95202139019966, 38.17657046020031, 38.99839796125889, 38.466202318668365, 39.82352368533611, 40.35470858216286, 41.16637922823429, 43.66924412548542, 44.217383712530136, 44.57602746784687, 45.33265046775341, 42.972266525030136, 40.17381928861141, 39.68320481479168, 39.369486048817635, 38.67690861225128, 42.40750662982464, 41.488723531365395, 42.46158912777901, 40.34121930599213, 42.12159477174282, 41.08950935304165, 44.95623506605625, 46.200960874557495, 50.49253039062023, 46.80068649351597, 48.71726565063, 46.69972971081734, 45.931372940540314, 45.702313631772995, 45.946431532502174, 44.816539362072945, 46.13688871264458, 52.08607368171215, 57.48931534588337, 57.40692436695099, 62.25748188793659, 59.1969209164381, 54.777013286948204, 55.67022755742073, 60.19725523889065, 60.90309016406536, 59.178803488612175, 46.001760363578796, 48.520086631178856, 4.678479004651308, 0.47182489768601954, 1.9353404128924012, 0.5932277301326394, 4.39511775970459, 32.003759890794754, 57.23856680095196, 49.026751443743706, 47.542676478624344, 58.21599215269089, 46.47116057574749, 36.48763328790665, 27.800393141806126, 26.187440492212772, 26.702003180980682, 29.461168125271797, 30.36197628825903, 0.30733487103134394, 0.10023172668297775, 0.04659409059968311, 0.028040088836860377, 0.006731258090439951, 0.07903909863671288, 0.07595115574076772, 0.04378855344839394, 0.03443052766670007, 0.01923108906339621, 0.12816529691917822, 0.0713853222259786, 0.016779734469309915, 0.007130523335945327, 0.05687819793820381, 0.01590616171597503, 0.0026530603599894675, 0.02897270500398008, 0.010703817824833095, 0.008937004477047594, 0.020257889336789958, 0.07801408137311228, 0.09865347543382086, 0.024904602105380036, 0.05885659295017831, 0.03239121346268803, 0.009017552547447849, 0.03404506358492654, 0.05569876571826171, 0.019635613352875225, 0.05506665998836979, 0.11061271026846953, 0.3175574803026393, 0.282115000882186, 31.880524903535843, 58.43720868229866, 31.658953092992306, 38.52013662457466, 38.15365768969059, 79.3114721775055, 72.23135769367218, 67.64419823884964, 70.78745037317276, 65.01361459493637, 65.70172727108002, 47.31090411543846, 5.13258408755064, 1.083096731454134, 3.598018381744623, 51.44997641444206, 73.33627000451088, 70.51655530929565, 66.22422203421593, 66.93365916609764, 64.9506975710392, 64.90543439984322, 62.40185134112835, 62.27196291089058, 62.08518013358116, 58.440609499812126, 55.29671899974346, 53.11964102089405, 54.2313701659441, 49.955725595355034, 50.6622064858675, 50.143849700689316, 46.57850481569767, 48.07885430753231, 47.433257550001144, 44.57349680364132, 44.98048156499863, 49.09194454550743, 51.38633742928505, 51.51486553251743, 48.41628760099411, 48.12336131930351, 48.94080385565758, 47.22819395363331, 47.92130336165428, 44.777994230389595, 44.6127524971962, 46.83077707886696, 47.340242341160774, 48.177857995033264, 50.39859943091869, 45.331119149923325, 48.67254585027695, 45.61581887304783, 44.42425221204758, 45.27811199426651, 43.027754947543144, 44.41683121025562, 43.39870244264603, 44.99177075922489, 45.33888593316078, 49.29994538426399, 53.36243279278278, 58.40689770877361, 56.26415088772774, 59.99803572893143, 56.758815944194794, 62.63347931206226, 43.136592507362366, 43.351554572582245, 65.408785790205, 58.76197725534439, 63.4358936548233, 56.651053726673126, 58.505772203207016, 53.712903186678886, 54.326783046126366, 47.64241732656956, 43.88370081782341, 41.75359971821308, 42.28756986558437, 42.877279222011566, 41.82616822421551, 42.34798662364483, 42.445903569459915, 42.95016311109066, 46.088745296001434, 47.049322351813316, 48.19911785423756, 47.213158160448074, 46.34493134915829, 46.38096481561661, 43.00724744796753, 40.77696852385998, 42.1251779794693, 41.38052433729172, 43.590922728180885, 44.43851664662361, 45.35704515874386, 42.996763810515404, 44.297038838267326, 45.00315494835377, 46.254040226340294, 47.61456482112408, 53.14340874552727, 50.57760402560234, 50.82835637032986, 50.10012544691563, 48.222045823931694, 47.41871193051338, 48.99397820234299, 47.404223307967186, 49.667454063892365, 53.37819054722786, 57.68752031028271, 58.39438498020172, 64.11272093653679, 60.662677064538, 54.9197868257761, 55.67737117409706, 62.955409437417984, 62.52116493880749, 61.96056582033634, 52.87137374281883, 57.452096343040466, 6.460652723908424, 0.4524796607438475, 3.125042086467147, 1.2076434795744717, 6.7864044941961765, 38.18434864282608, 64.18833687901497, 56.56487435102463, 55.3429701179266, 66.16681471467018, 53.5204017162323, 49.17530067265034, 30.19313234835863, 35.45502729713917, 29.67618528753519, 36.80579021573067, 36.29831984639168, 0.9960070671513677, 0.030882813152857125, 0.07660065370146185, 0.03501124338072259, 0.011943109821004327, 0.014235017697501462, 0.03657527508039493, 0.044251764920772985, 0.057857335632434115, 0.018829307009582408, 0.042425168794579804, 0.02796933062199969, 0.08364910478121601, 0.05432244171970524, 0.017923640079970937, 0.12856705114245415, 0.17625481879804283, 0.2290068834554404, 0.21789918886497617, 0.08655260171508417, 0.23170024127466604, 0.19389028107980266, 0.2120288452715613, 0.15974086039932445, 0.11493655169033445, 0.19082507758866996, 0.06965798835153691, 0.1994968208600767, 0.17374339106027037, 0.2068531370605342, 0.12545722973300144, 0.28106943354941905, 0.32250629912596196, 0.28214471647515893, 46.4739154279232, 75.08662328124046, 51.294956132769585, 43.36632817983627, 42.03468583524227, 82.79253378510475, 78.54196786880493, 72.67106249928474, 75.34143760800362, 70.39180800318718, 69.69344347715378, 54.79662403464317, 7.879236778244376, 1.3189053093083203, 4.449763102456927, 54.773566871881485, 76.93466171622276, 72.81344085931778, 72.93474555015564, 70.09100094437599, 67.18897506594658, 68.20004001259804, 65.61152771115303, 66.2916912138462, 67.44021758437157, 63.390687480568886, 55.71156933903694, 55.60335114598274, 57.44693621993065, 53.183238208293915, 53.671724796295166, 54.15864206850529, 48.15434105694294, 52.14246265590191, 50.50606906414032, 46.794329434633255, 46.89749389886856, 53.10957156121731, 53.44282507896423, 52.10848867893219, 48.129357397556305, 51.65082983672619, 50.16942612826824, 48.80810737609863, 49.490094780921936, 46.95777766406536, 48.24397824704647, 49.52940747141838, 49.33132790029049, 50.300731882452965, 53.194162622094154, 48.709331676363945, 51.00280500948429, 47.18109168112278, 47.11049526929855, 46.98296271264553, 43.338753059506416, 47.60528951883316, 45.93473196029663, 46.94694824516773, 47.49293714761734, 54.479223266243935, 54.98100534081459, 59.37800019979477, 59.71692681312561, 64.17829781770706, 57.066253647208214, 67.1746726334095, 43.58615018427372, 30.805439092218876, 69.11383017897606, 59.342297315597534, 67.15420693159103, 58.64715501666069, 59.65286985039711, 54.42213512957096, 59.3278618901968, 50.78820392489433, 46.28403961658478, 45.62952473759651, 44.739475697278976, 45.19936881959438, 43.15670482814312, 44.06434692442417, 44.93264973163605, 46.4240887016058, 48.13002236187458, 47.4093796312809, 49.062936902046204, 47.830803617835045, 48.857964500784874, 48.687448650598526, 44.327410608530045, 41.8732400983572, 42.679955810308456, 42.924814671278, 46.24526269733906, 45.110180005431175, 48.913661912083626, 44.83563333749771, 46.44733965396881, 45.524559170007706, 48.14269468188286, 49.598012790083885, 58.34868863224983, 52.605528607964516, 55.29647581279278, 51.45466536283493, 51.90620273351669, 50.99920280277729, 51.496318727731705, 50.50341680645943, 52.75877818465233, 55.602693781256676, 61.826186031103134, 58.746021911501884, 67.26027444005013, 62.54195362329483, 57.342460826039314, 57.00796477496624, 64.59178403019905, 63.14556643366814, 65.85148483514786, 55.407555252313614, 60.62267281115055, 8.056265953928232, 0.7947927829809487, 9.063139725476503, 4.879118213430047, 8.410885725170374, 41.302727311849594, 70.74227839708328, 59.83503207564354, 62.569209560751915, 66.02000579237938, 63.89553219079971, 57.97061271965504, 38.46651390194893, 40.19721083343029, 44.4981886446476, 46.47537834942341, 58.311739414930344, 2.264306335709989, 0.19885792076820508, 0.11927626765100285, 0.1943334174575284, 0.09064124911674298, 0.10637391154887155, 0.1285141211701557, 0.1609104999806732, 0.20821760524995625, 0.05559571480262093, 0.1477029430679977, 0.18588641134556383, 0.18143451976357028, 0.20534147130092606, 0.1745660469168797], [0.023340728112088982, 0.041124840718111955, 0.03132601632387377, 0.0439307600754546, 0.027494873756950255, 0.10654713623807766, 0.05471509721246548, 0.0657355523435399, 0.03620405281253625, 0.053064902167534456, 0.014976221918914234, 0.018383346759947017, 0.04268012249667663, 0.02752238517132355, 0.06816659806645475, 0.09339659853139892, 0.03474184006336145, 0.2894263429334387, 0.12704257591394708, 8.080669194459915, 51.199034079909325, 47.44746118783951, 31.578063033521175, 25.477108508348465, 44.934321641922, 72.35865846276283, 63.495474457740784, 68.27030584216118, 55.95156446099281, 63.19714106619358, 48.28622058033943, 5.174691053107381, 0.18392221361864358, 10.383433979004622, 60.82327924668789, 72.96520471572876, 67.628383487463, 63.270762115716934, 62.35396631062031, 64.58473920822144, 59.38779607415199, 60.258762538433075, 60.292470529675484, 59.20605182647705, 54.40550722181797, 51.583588644862175, 49.37220610678196, 49.61600482463837, 48.561948984861374, 45.63770569860935, 45.370804220438, 44.054847434163094, 44.77695308625698, 45.1508454233408, 45.38471147418022, 46.24172508716583, 47.05339193344116, 48.27576734125614, 46.335454657673836, 46.92750468850136, 46.36873707175255, 46.52003735303879, 44.73668284714222, 43.50823536515236, 43.84449452161789, 43.29141519963741, 43.12390498816967, 44.99181255698204, 44.65708091855049, 47.7610469609499, 44.99289929866791, 43.26160579919815, 41.46470122039318, 39.37335804104805, 40.981063172221184, 38.24183575809002, 40.73461599647999, 38.9306665956974, 41.75252057611942, 43.4129972755909, 49.963530376553535, 52.777571976184845, 54.71754267811775, 54.13007900118828, 57.031284123659134, 55.20262844860554, 64.89923313260078, 45.914490446448326, 29.73747029900551, 63.22621710598469, 57.984519973397255, 57.46701434254646, 55.932082906365395, 56.99321776628494, 52.125420570373535, 54.47480030357838, 49.08437915146351, 44.295245334506035, 41.67653605341911, 40.878924652934074, 38.80838915705681, 39.518384858965874, 38.72907221317291, 39.38910819590092, 39.755883514881134, 40.53101912140846, 40.84369674324989, 40.853295028209686, 43.56781616806984, 44.997793436050415, 40.85340142250061, 41.33979432284832, 40.2258612960577, 40.25984287261963, 39.53227311372757, 41.766568422317505, 40.05770891904831, 40.15303060412407, 41.52087360620499, 40.86637392640114, 41.349806785583496, 43.315247520804405, 41.38416834175587, 41.353260800242424, 40.59525087475777, 44.330488443374634, 41.81531980633736, 43.729470893740654, 42.49214328825474, 43.8950964063406, 41.436989307403564, 46.298315450549126, 52.15893097221851, 59.24868553876877, 61.08330689370632, 60.01855842769146, 58.76058652997017, 62.562263533473015, 61.94679155945778, 64.59968760609627, 57.3318175971508, 64.36062723398209, 49.011316671967506, 56.47288128733635, 20.42992863804102, 0.6325359083712101, 4.876450281590223, 3.122373204678297, 4.066961668431759, 43.6363834887743, 60.352712497115135, 52.91813403367996, 43.72292384505272, 45.688448175787926, 41.40016168355942, 32.07063250243664, 20.060136280953884, 30.91962106525898, 30.184301622211933, 33.454639837145805, 6.845741160213947, 0.1877854039776139, 0.06924855289980769, 0.052790459667448886, 0.03390227066120133, 0.05908972379984334, 0.0168192872297368, 0.06275645282585174, 0.04876304687059019, 0.05298915857565589, 0.019036293851968367, 0.039191189789562486, 0.08490823252941482, 0.05337117167073302, 0.011224779518670402, 0.051777183180092834, 0.05751529832195956, 0.03124305534583982, 0.027585827665461693, 0.028933471367054153, 0.016538375057280064, 0.00774575912146247, 0.05898264302231837, 0.07185691254562698, 0.13870927097741514, 0.020852535162703134, 0.03993420206825249, 0.08334100217325613, 0.05521566839888692, 0.01850703494710615, 0.07673694912227802, 0.050298108835704625, 0.0565636609098874, 0.23604961257660761, 0.2028148146928288, 8.550477884709835, 64.21800568699837, 45.12150339782238, 38.519813641905785, 34.63301740586758, 52.42832511663437, 81.96765884757042, 66.35166719555855, 74.60597947239876, 63.11008393764496, 69.5341408252716, 52.12189055979252, 6.927647665143013, 0.1124630773847457, 11.953753866255283, 65.02434521913528, 77.41699263453484, 69.81922432780266, 66.07249617576599, 64.0218298137188, 67.86391764879227, 65.13066351413727, 62.65008442103863, 62.59170435369015, 60.86159639060497, 56.377350613474846, 55.869230479002, 51.78266376256943, 52.63219937682152, 50.91344140470028, 48.58329623937607, 47.11017608642578, 49.43270266056061, 47.16096416115761, 48.71790021657944, 46.01285196840763, 47.089307606220245, 47.890513613820076, 48.43431383371353, 47.79033198952675, 48.73369596898556, 46.71364076435566, 48.426649644970894, 45.98154924809933, 46.438330337405205, 44.39191974699497, 44.26530674099922, 46.60016365349293, 47.60879673063755, 47.835887745022774, 51.57024376094341, 46.6973814368248, 46.25579573214054, 46.12808458507061, 44.50017213821411, 43.90125207602978, 44.19164389371872, 44.16467674076557, 44.96018685400486, 46.237226128578186, 46.040305495262146, 51.188717633485794, 55.53200237452984, 59.42922905087471, 60.383300855755806, 61.10818795859814, 59.35978017747402, 63.448904156684875, 49.644780680537224, 44.85883109271526, 63.91144573688507, 61.15385390818119, 61.93678289651871, 57.51166574656963, 58.71246971189976, 56.70432686805725, 54.03286501765251, 52.92006433010101, 47.0491361618042, 43.90260860323906, 42.32331074774265, 43.013794496655464, 42.78933294117451, 42.88457103073597, 44.22523409128189, 42.62367323040962, 43.56603026390076, 45.06523981690407, 45.47492243349552, 45.53502380847931, 47.39860340952873, 44.59501124918461, 44.105844497680664, 41.93608872592449, 42.869964614510536, 40.830766037106514, 45.00282436609268, 43.32065463066101, 43.6337274312973, 43.1403923034668, 45.38048230111599, 41.742010340094566, 43.956474512815475, 43.690283596515656, 44.63944226503372, 43.87604422867298, 47.42820382118225, 44.660489335656166, 45.902372896671295, 43.86622555553913, 46.266165375709534, 43.74310836195946, 47.460999861359596, 53.19483898580074, 61.05344049632549, 61.37543521821499, 58.31145443022251, 57.794818952679634, 65.89538767933846, 64.68253836035728, 65.98928824067116, 59.656073078513145, 65.36652445793152, 55.26037015020847, 65.55759340524673, 24.86522164195776, 0.6106450455263257, 4.040734050795436, 5.7038976810872555, 6.940408805385232, 48.418632075190544, 67.10231691598892, 57.223162427544594, 51.09732873737812, 48.128681033849716, 53.12047317624092, 37.129517644643784, 25.264544114470482, 40.07764644920826, 31.640704572200775, 46.238263472914696, 7.5708068534731865, 0.29493702691979706, 0.07008718719589524, 0.039956885811989196, 0.02180520230467664, 0.040553591097705066, 0.029850936589355115, 0.03899607545463368, 0.03962971371947788, 0.06988651046412997, 0.018337329893256538, 0.04780234783538617, 0.029165245941840112, 0.023665812914259732, 0.03968622084357776, 0.08566097807488404, 0.1538178836926818, 0.08415454445639625, 0.13797050749417394, 0.1291725694318302, 0.07920107236714102, 0.21849445067346096, 0.18552169029135257, 0.17296875215834007, 0.17625406180741265, 0.10105136199854314, 0.09522438209387474, 0.157506832620129, 0.27025515446439385, 0.2306893322383985, 0.15128104481846094, 0.15464367141248658, 0.2734611136838794, 0.5177566548809409, 0.37355982523877174, 16.90115299075842, 80.12965947389603, 60.56297041475773, 48.09833586215973, 39.68413956463337, 54.78483326733112, 85.62407344579697, 75.30327245593071, 80.57536795735359, 67.92441800236702, 74.1781984269619, 59.56731364130974, 8.780771177262068, 0.2409636543598026, 13.64009577780962, 68.26215907931328, 80.43030694127083, 72.28180378675461, 69.94704186916351, 68.37489902973175, 70.98283588886261, 66.25520557165146, 66.14169046282768, 68.11756923794746, 66.30045354366302, 59.33615684509277, 58.52335385978222, 55.349057391285896, 55.531185418367386, 54.006258845329285, 51.96313887834549, 49.47469040751457, 52.66465723514557, 49.793029725551605, 52.19638556241989, 47.266761884093285, 50.84421671926975, 50.45427784323692, 50.64899079501629, 51.80654928088188, 49.18189711868763, 49.46799136698246, 51.88074789941311, 48.16095270216465, 47.795758098363876, 47.93287754058838, 48.929507061839104, 51.236446872353554, 52.465597316622734, 48.25450748205185, 54.155138656497, 49.80309538543224, 49.20618921518326, 48.774718567728996, 47.18635059893131, 46.58076949417591, 46.340204402804375, 47.6268457621336, 46.351755782961845, 51.10379219055176, 48.82140666246414, 56.049451008439064, 58.432702124118805, 62.315417379140854, 59.84805017709732, 64.74267393350601, 60.32345026731491, 70.76386123895645, 49.083999171853065, 34.656101167201996, 67.4582590162754, 64.56673577427864, 64.50123488903046, 59.55285541713238, 61.72036170959473, 57.9141553491354, 59.98270355165005, 57.79200330376625, 51.39609910547733, 46.76441363990307, 45.99694602191448, 44.97054509818554, 46.17882326245308, 45.205912068486214, 45.95626540482044, 45.39910890161991, 46.75590589642525, 45.80647364258766, 46.80398851633072, 45.882974937558174, 48.874318823218346, 47.07092799246311, 47.7384115755558, 43.03782820701599, 45.0813015550375, 42.91451722383499, 48.102439641952515, 45.98216861486435, 44.868847355246544, 46.71392194926739, 47.83518098294735, 43.52349154651165, 46.27525828778744, 45.665979981422424, 48.012084290385246, 47.06387557089329, 48.84845741093159, 45.59285670518875, 48.27677048742771, 46.00002385675907, 50.22395320236683, 46.64808668196201, 49.89025890827179, 54.40832667052746, 63.80143404006958, 62.536212131381035, 60.64991354942322, 61.026807725429535, 66.07359811663628, 66.58901005983353, 69.86574903130531, 62.018957287073135, 70.27882486581802, 60.1738902926445, 66.72836378216743, 28.65287359803915, 0.7219170278403908, 12.76998521760106, 10.191656369715929, 6.549492906779051, 54.58778344094753, 71.58787742257118, 61.34481266140938, 56.89493604004383, 56.63168616592884, 58.461120799183846, 41.84817664325237, 29.3715176358819, 47.18254320323467, 45.778092965483665, 58.87728586792946, 21.894953325390816, 0.35270185384433717, 0.12706096633337438, 0.2153132643434219, 0.16882465890375897, 0.2883206616388634, 0.18929261685116217, 0.14599107555113733, 0.1508143378305249, 0.17713556997478008, 0.14109205483691767, 0.1852425982360728, 0.3165681677637622, 0.14329445228213444, 0.20332401705672964, 0.18378712789854035], [0.014956907525629504, 0.03934278829547111, 0.012507641149568371, 0.07734776634606533, 0.04694183873652946, 0.07936139852972701, 0.0387463576043956, 0.018316097048227675, 0.039034841538523324, 0.008471616656606784, 0.04291789548005909, 0.013037509543210035, 0.03557875628757756, 0.03731140022864565, 0.05377452522225212, 0.07158795080613345, 0.025255426444346085, 0.14825744612608105, 0.2337255622842349, 0.13477967324433848, 26.725869700312614, 57.94569365680218, 31.69624049216509, 36.868103072047234, 26.778282187879086, 55.61164990067482, 69.54757690429688, 63.224731385707855, 56.93163067102432, 57.683496326208115, 55.958924666047096, 7.824630858376622, 0.062024825092521496, 14.165405239909887, 65.5715462565422, 74.80694308876991, 71.0966169834137, 61.06694497168064, 62.51158945262432, 60.77265456318855, 59.34650368988514, 58.768771290779114, 55.88112384080887, 57.71360971033573, 52.88171298801899, 51.655997559428215, 48.600923493504524, 47.446917816996574, 45.83018057048321, 44.18869145214558, 46.86210639774799, 44.38689261674881, 43.67037646472454, 44.432216584682465, 44.51058357954025, 44.60909329354763, 46.29728190600872, 47.02927082777023, 43.72342921793461, 43.91828276216984, 45.73787212371826, 47.2678904235363, 44.14777144789696, 41.890377178788185, 41.865070536732674, 41.68514259159565, 43.70226055383682, 44.64995630085468, 44.91802431643009, 44.713329300284386, 43.33233140408993, 41.2161223590374, 42.06056624650955, 43.47594849765301, 41.88491307199001, 40.4182905703783, 40.48469960689545, 42.00010389089584, 45.49011401832104, 44.40392330288887, 47.37209603190422, 53.64609137177467, 59.063339084386826, 56.1434655636549, 59.36976604163647, 56.194690614938736, 63.74829389154911, 42.61321619153023, 27.840610183775425, 59.646786376833916, 57.54666566848755, 58.73455032706261, 56.11147128045559, 55.04649482667446, 53.79338666796684, 55.017582178115845, 50.066827833652496, 46.08256682753563, 42.69111581146717, 42.888082042336464, 40.16849957406521, 40.89245952665806, 40.25260046124458, 38.81607234477997, 39.3093428760767, 38.743849620223045, 38.78973975777626, 40.44534511864185, 41.632169634103775, 42.59693406522274, 41.40831604599953, 42.73338094353676, 39.30305041372776, 41.02234795689583, 39.03446942567825, 41.03436291217804, 40.2140249311924, 39.91924814879894, 40.34739397466183, 40.522480979561806, 41.729429215192795, 41.08600214123726, 42.085204124450684, 41.96018323302269, 38.97016927599907, 42.78533935546875, 42.70431250333786, 42.52213127911091, 42.968603521585464, 42.607159316539764, 41.93905256688595, 48.22249799966812, 55.06013609468937, 59.53857198357582, 60.23702770471573, 58.52662168443203, 59.30380158126354, 62.340062856674194, 61.89940810203552, 60.785623267292976, 63.20166662335396, 59.89265598356724, 52.44625635445118, 55.911947786808014, 43.21649841964245, 0.6193229486234486, 3.1861900677904487, 1.1544065549969673, 12.655748147517443, 56.03338547050953, 48.85594300925732, 41.76744617521763, 45.96392959356308, 60.79066939651966, 66.5850430727005, 36.726245284080505, 18.015247508883476, 31.940451487898827, 36.11349396407604, 32.41481803357601, 0.6612593389581889, 0.1260095211910084, 0.033510873108753, 0.06169019441585988, 0.062222919150372036, 0.04773432629008312, 0.02075374788546469, 0.03230094604077749, 0.038611535346717574, 0.04041106534714345, 0.04820836569706444, 0.04006316507002339, 0.04870622062298935, 0.007442689666277147, 0.07973734085680917, 0.020934735439368524, 0.07374093605903909, 0.03353533429617528, 0.027759592267102562, 0.06895992424688302, 0.05103625633637421, 0.08958008183981292, 0.0363880460645305, 0.022257378041103948, 0.016371690544474404, 0.013056149509793613, 0.015749498052173294, 0.07349668783717789, 0.07488015500712208, 0.03306299440737348, 0.030566372515750118, 0.04025102491141297, 0.054168961869436316, 0.14626532880356535, 0.30039697769097984, 0.37440346903167665, 32.89338335394859, 63.24371516704559, 34.09954883158207, 50.40311738848686, 31.005542054772377, 66.22363686561584, 74.1708192229271, 68.59025627374649, 62.74530351161957, 61.22484929859638, 62.97655150294304, 8.985700830817223, 0.027665897978295106, 15.535428375005722, 67.81800851225853, 76.84837594628334, 71.82258322834969, 64.34903025627136, 65.23990765213966, 62.282951921224594, 64.0991784632206, 61.47449970245361, 58.87022964656353, 61.07219249010086, 55.7208826392889, 53.56557369232178, 52.459415048360825, 48.83721001446247, 50.04713349044323, 47.723356783390045, 48.26280623674393, 47.4126398563385, 46.19346387684345, 48.195188865065575, 46.00870259106159, 46.12588070333004, 47.29732744395733, 49.71699200570583, 46.21206387877464, 44.37905743718147, 46.51195518672466, 48.03337834775448, 47.87914082407951, 44.07318904995918, 44.599544405937195, 45.57973600924015, 46.45600698888302, 46.66750743985176, 47.788458690047264, 47.383229434490204, 45.511962845921516, 44.629274010658264, 45.28085544705391, 46.34385600686073, 46.71355336904526, 44.90151800215244, 43.15364219248295, 45.52501134574413, 47.901951000094414, 46.26052267849445, 48.349456787109375, 57.873026356101036, 60.70593774318695, 61.31211541593075, 61.857367157936096, 59.366574212908745, 66.84681862592697, 47.295944318175316, 39.545002430677414, 60.64656212925911, 60.4015588760376, 61.10089614987373, 59.80343297123909, 61.19505509734154, 58.073822781443596, 57.22981967031956, 54.04041141271591, 47.934940829873085, 46.08010835945606, 45.60196861624718, 43.12759459018707, 44.162708446383476, 43.00681807100773, 42.403817027807236, 42.98995457589626, 43.32335248589516, 41.941571831703186, 45.58365739881992, 43.16999651491642, 45.51890887320042, 44.08442124724388, 46.86761610209942, 42.00654074549675, 42.79955819249153, 42.895791828632355, 44.341944828629494, 42.305303514003754, 42.805307283997536, 43.34258325397968, 44.6352206915617, 44.65481624007225, 43.13223794102669, 44.456501081585884, 43.35523657500744, 41.92136451601982, 47.46244378387928, 43.430677726864815, 44.78200301527977, 43.95732946693897, 46.223531663417816, 45.34629173576832, 50.532561242580414, 57.86169156432152, 60.50366699695587, 60.8770539611578, 61.70030638575554, 62.5306948274374, 62.20382496714592, 65.4996009171009, 61.5490934997797, 65.27263149619102, 64.10344943404198, 60.02118028700352, 62.97026664018631, 51.09848387539387, 0.9315919142682105, 1.0819737729616463, 1.7939724423922598, 14.089731350541115, 63.429069221019745, 54.77461941540241, 44.26004022359848, 50.92694208025932, 66.02398037910461, 72.54478767514229, 33.789740055799484, 24.03221894055605, 34.555383771657944, 39.770007357001305, 43.69652286171913, 1.5080445539206266, 0.09240971281542443, 0.0926621543476358, 0.027720030229829717, 0.05850783178175334, 0.029388626826403197, 0.029842132862540893, 0.004360112034191843, 0.056061646246234886, 0.11938090305193327, 0.10978883728967048, 0.08694276359165087, 0.009085207657335559, 0.007560119229310658, 0.0667569182405714, 0.06338817634969018, 0.11418500100262463, 0.16977420717012137, 0.19560238608391955, 0.20999258500523865, 0.22116092790383846, 0.28221774380654097, 0.09790012874873355, 0.0795057907816954, 0.08545897289877757, 0.16816867457237095, 0.10371147160185501, 0.12129674985771999, 0.12010903155896813, 0.16845083911903203, 0.08376933270483278, 0.08411343689658679, 0.1684828702127561, 0.3777253517182544, 0.23129747773054987, 0.4640687716891989, 47.71947339177132, 74.12544965744019, 43.82063180208206, 53.70501101016998, 38.151526004076004, 70.46221822500229, 78.32406476140022, 77.24877566099167, 68.74654188752174, 68.76500129699707, 68.70464533567429, 11.408679764717817, 0.1407870469847694, 17.17908527702093, 71.83723524212837, 77.87799909710884, 75.12216657400131, 69.6168015897274, 69.50714707374573, 65.32278880476952, 66.84374079108238, 63.5914459079504, 60.317279398441315, 66.7631471157074, 58.312522172927856, 55.03988318145275, 55.268672704696655, 52.41722211241722, 52.62083038687706, 49.47983533143997, 51.19057573378086, 49.15206491947174, 49.660432040691376, 51.99885316193104, 47.75248222053051, 47.096683010458946, 51.67728781700134, 52.16127544641495, 46.86335653066635, 45.644351541996, 48.541969656944275, 51.497424468398094, 48.66061449050903, 47.3630715161562, 48.20823356509209, 48.22208762168884, 49.88335467875004, 50.99984496831894, 51.05840742588043, 50.80235056579113, 48.61492954194546, 47.70392842590809, 48.65770764648914, 50.33647656440735, 50.04644192755222, 47.149496376514435, 46.611908823251724, 49.104176089167595, 51.4304568618536, 48.13649341464043, 52.12736986577511, 58.913288936018944, 64.13726761937141, 60.78371196985245, 66.01299896836281, 59.97400961816311, 71.96745425462723, 44.94081549346447, 31.803531534969807, 63.49182665348053, 62.82168321311474, 64.02703553438187, 61.247207298874855, 61.737639382481575, 59.935890063643456, 60.333470329642296, 56.27023436129093, 51.397721618413925, 46.69405281543732, 49.611243680119514, 45.69999195635319, 46.988103836774826, 45.734418109059334, 44.119060188531876, 44.83058340847492, 44.60549868643284, 43.69537152349949, 47.006882429122925, 45.63628077507019, 47.295454144477844, 46.68084852397442, 48.35554786026478, 44.46014888584614, 45.93404419720173, 43.17430168390274, 46.92493982613087, 44.71315070986748, 44.52148139476776, 45.60577601194382, 45.846325904130936, 46.36325016617775, 43.76214534044266, 47.90560640394688, 47.11839124560356, 44.124702885746956, 49.55682300031185, 46.92309312522411, 47.404428496956825, 47.9738849401474, 49.574473053216934, 46.7995997518301, 53.671637400984764, 59.9525635689497, 63.05174946784973, 61.74285650253296, 61.35481372475624, 64.83687847852707, 64.64971572160721, 68.64374980330467, 64.82962846755981, 69.05206829309464, 65.87936773896217, 65.55563271045685, 65.0855827331543, 54.12135846912861, 1.2154741468839347, 7.424786388874054, 5.6820593029260635, 14.078251216560602, 68.72324153780937, 59.601697996258736, 51.47648759186268, 56.50478437542915, 72.14032977819443, 75.76560884714127, 43.12535651028156, 29.527409970760345, 50.90189002454281, 50.20874261856079, 60.032522678375244, 5.227334378287196, 0.320665268227458, 0.21400536264991388, 0.14698809158289805, 0.14840241725323722, 0.11422633862821385, 0.09920685042743571, 0.12791391665814444, 0.14363116468302906, 0.19488708931021392, 0.16606023302301764, 0.15051462891278788, 0.14868734258925542, 0.07897963034338318, 0.18511195055907592, 0.14836254908004776], [0.07155559316743165, 0.024990689380501863, 0.11640638258541003, 0.03499339843983762, 0.0326166333979927, 0.05742165412812028, 0.027282090741209686, 0.05604978301562369, 0.04846929368795827, 0.04862287372816354, 0.038020362771931104, 0.07293387272511609, 0.12711913586826995, 0.018883754673879594, 0.0590974124497734, 0.11425542339566164, 0.07734402592177503, 0.09496116457739845, 0.4918249760521576, 0.341298546991311, 7.753333859145641, 58.13922867178917, 37.98975728452206, 29.180973060429096, 26.23348642140627, 44.8596328496933, 61.011209562420845, 68.61794158816338, 48.99060018360615, 52.331464514136314, 55.90401001274586, 13.12860332429409, 0.03863100188027602, 12.75503396987915, 60.578762367367744, 77.85683423280716, 68.24569836258888, 60.81086911261082, 55.867315381765366, 59.32489424943924, 56.974336579442024, 59.207978323102, 57.221482917666435, 55.50870582461357, 49.73092965781689, 49.08434875309467, 45.83164729177952, 47.390160262584686, 46.78641065955162, 47.38215409219265, 48.82245160639286, 46.48255616426468, 44.77998532354832, 46.22887797653675, 45.979257971048355, 45.98602920770645, 45.2088987082243, 45.63792608678341, 44.22147609293461, 44.34924043715, 47.335519194602966, 45.22739231586456, 45.076255425810814, 43.294314444065094, 42.89400972425938, 42.698810398578644, 45.189671739935875, 45.51342956721783, 44.65744189918041, 43.9063324034214, 43.33594501018524, 44.170623421669006, 42.75753624737263, 41.11871838569641, 40.72869211435318, 40.16640968620777, 41.88174404203892, 42.45323337614536, 44.1611011326313, 43.48034866154194, 45.53590156137943, 50.89798383414745, 58.854232504963875, 57.38033339381218, 60.85256427526474, 55.60111306607723, 63.81526529788971, 50.939447209239006, 25.903396233916283, 51.790232956409454, 59.20216463506222, 58.29512670636177, 57.457925230264664, 56.82175576686859, 56.965684443712234, 57.55392327904701, 57.04123578965664, 49.206307008862495, 42.64306738972664, 41.66064530611038, 43.68592523038387, 41.14365264773369, 37.53160446882248, 39.831826239824295, 39.95270535349846, 40.63794158399105, 39.1920355707407, 40.05825228989124, 41.234786957502365, 45.34158758819103, 42.97803841531277, 40.94913728535175, 39.80228662490845, 40.052089020609856, 40.24647518992424, 40.47309882938862, 41.3141380995512, 41.00274860858917, 41.08351327478886, 39.92352671921253, 42.26833149790764, 40.14285854995251, 39.539754912257195, 40.73929354548454, 40.983156859874725, 40.7294786721468, 43.28213229775429, 41.0334699600935, 41.58392742276192, 41.59010589122772, 44.72793951630592, 46.91792920231819, 54.02847245335579, 56.90720558166504, 58.58072318136692, 60.7188418507576, 59.40465196967125, 58.614256381988525, 61.69370613992214, 60.3367305546999, 60.155970454216, 58.01128953695297, 60.633764415979385, 52.77799375355244, 59.384478852152824, 3.105143504217267, 1.7669662227854133, 1.73445861088112, 19.828538708388805, 56.27633683383465, 55.89611403644085, 53.53227227926254, 58.45151871442795, 58.32457512617111, 55.050784796476364, 23.541841953992844, 29.27056085318327, 27.81359363347292, 37.95624688267708, 20.225909985601902, 0.12190859866677783, 0.06578500164323486, 0.10573228035354987, 0.0965535017894581, 0.04223042924422771, 0.07141790993046016, 0.06959670179639943, 0.00816134141132352, 0.021517111708817538, 0.05710800025553908, 0.08280846668640152, 0.03238806675653905, 0.007217044303615694, 0.04631449017324485, 0.04080388411239255, 0.0673965085297823, 0.09203601177432574, 0.03237099735997617, 0.016401127832068596, 0.06810779770603403, 0.03362147537700366, 0.0574557558138622, 0.026060565760417376, 0.040237317443825305, 0.056287463230546564, 0.07174964994192123, 0.02977791111334227, 0.022310005588224158, 0.10065299196867272, 0.10544765929807909, 0.01713803594611818, 0.04014829311927315, 0.10194135291385464, 0.08243017175118439, 0.34371346584521234, 0.3252796159358695, 8.128629270941019, 67.23798483610153, 32.91022405028343, 38.37385207414627, 33.186020851135254, 51.528244614601135, 72.50001847743988, 71.61771342158318, 56.85768283903599, 58.40043805539608, 65.78742787241936, 15.707549639046192, 0.021236904576653615, 13.127862364053726, 64.0286086499691, 80.57465359568596, 71.23422279953957, 62.345234379172325, 57.14059665799141, 61.47948503494263, 60.487077087163925, 61.33442021906376, 60.10667949914932, 57.30964198708534, 53.82812060415745, 52.18381203711033, 49.98274214565754, 50.14142543077469, 49.8697742074728, 49.74033035337925, 50.8679274469614, 50.016412138938904, 47.491835206747055, 49.37982089817524, 45.97400285303593, 48.332426100969315, 49.00793485343456, 47.61153258383274, 47.71661214530468, 44.72657918930054, 50.065858885645866, 47.90874123573303, 46.83957740664482, 44.72215622663498, 45.361870899796486, 43.72777998447418, 48.17306645214558, 46.996729373931885, 46.65069334208965, 47.98429258167744, 46.79217115044594, 45.41985958814621, 43.85813198983669, 43.97062875330448, 45.377108082175255, 45.15391185879707, 44.34916444122791, 46.004211232066154, 48.61337162554264, 46.35259173810482, 50.337434113025665, 55.78563496470451, 62.66773447394371, 60.41453517973423, 64.15206402540207, 61.433040127158165, 65.36123514175415, 56.009697541594505, 35.47807686030865, 54.27457004785538, 63.03082779049873, 61.33647970855236, 62.86354556679726, 60.296441316604614, 61.819961965084076, 60.56064493954182, 57.821736708283424, 51.50951161980629, 45.96123933792114, 46.867414712905884, 47.119576781988144, 44.66382935643196, 40.91377258300781, 43.93121346831322, 43.74114006757736, 42.50962235033512, 43.33686836063862, 43.41088078916073, 44.351079538464546, 45.298912078142166, 45.28720870614052, 44.25125889480114, 43.423834294080734, 42.278978526592255, 41.79625242948532, 44.32158172130585, 42.53264531493187, 44.22314040362835, 43.8612250238657, 43.30883726477623, 44.149998128414154, 40.338449254631996, 43.101167008280754, 42.92012572288513, 44.931859374046326, 46.187634989619255, 44.796370044350624, 43.99209380149841, 44.54594448208809, 45.37127919495106, 47.99847722053528, 49.15860816836357, 55.99930889904499, 58.97212117910385, 61.361307576298714, 62.87376321852207, 63.15440855920315, 60.187295973300934, 64.09092530608177, 60.02410613000393, 64.96323689818382, 61.06809251010418, 65.02899616956711, 57.944842502474785, 65.30180633068085, 3.927160045132041, 2.233264851383865, 2.2122536413371563, 21.332997679710388, 62.52747640013695, 61.462598741054535, 58.89672942459583, 60.60892894864082, 64.01635810732841, 62.92218782007694, 28.49949862807989, 35.59253431856632, 31.527217961847782, 45.8635313808918, 22.17009086161852, 0.1225211302516982, 0.07108593243174255, 0.11276007004198618, 0.047861289203865454, 0.02690694251214154, 0.0648104355786927, 0.024551972492190544, 0.025567981938365847, 0.1701015981961973, 0.06849994853837416, 0.029507756371458527, 0.02543136553867953, 0.0714819053246174, 0.043967407327727415, 0.012977397436770843, 0.0483459895622218, 0.23216494446387514, 0.1343664899468422, 0.15732727741124108, 0.10516260037547909, 0.21301524859154597, 0.2116328798001632, 0.14457747718552127, 0.14628606440965086, 0.1012152578914538, 0.19332443800522014, 0.15866722504142672, 0.1323690588469617, 0.30054603063035756, 0.2337557528517209, 0.24200606014346704, 0.13947022467618808, 0.3273976460332051, 0.2489847270771861, 0.7400156941730529, 0.6200520345009863, 17.391984052956104, 80.73280870914459, 49.08185988664627, 47.41385959088802, 39.48148503899574, 58.55645388364792, 77.37707197666168, 79.21752601861954, 67.67008244991302, 67.43875086307526, 73.56143072247505, 18.636833354830742, 0.21844634466106072, 14.773327019065619, 67.11728811264038, 83.05972024798393, 73.84579986333847, 65.47818526625633, 61.57563127577305, 64.44766536355019, 64.67077419161797, 65.42412176728249, 63.99268537759781, 60.580092296004295, 56.98442503809929, 54.72197324037552, 52.438440173864365, 53.07161919772625, 54.08126302063465, 51.455201134085655, 55.11457197368145, 52.031599804759026, 49.78126175701618, 53.717044964432716, 48.09332773089409, 51.9325315207243, 50.77421307563782, 49.83733154833317, 50.02142786979675, 46.285099759697914, 52.7826789021492, 49.60146300494671, 49.00955356657505, 47.91072092950344, 47.94369176030159, 47.29277528822422, 53.53359840810299, 50.884205773472786, 51.03703357279301, 48.510172963142395, 50.08328475058079, 47.874254286289215, 47.87699393928051, 47.79373660683632, 47.15161666274071, 45.5533692240715, 49.84295144677162, 47.56267100572586, 50.81849969923496, 48.66765931248665, 51.77916035056114, 56.069278344511986, 66.81354761123657, 61.36438921093941, 68.51272523403168, 61.96948394179344, 71.75875425338745, 50.193543434143066, 27.983034141361713, 57.248203083872795, 63.83584499359131, 65.31407207250595, 63.20454306900501, 62.373687252402306, 63.572249338030815, 62.70412892103195, 62.503309696912766, 53.76506298780441, 47.47353918850422, 46.59733660519123, 49.329344406723976, 47.54252448678017, 42.45577543973923, 47.02097587287426, 47.35137194395065, 46.05405315756798, 45.19103966653347, 44.92062337696552, 46.26370690762997, 48.74695725739002, 50.240945890545845, 46.183800995349884, 45.88149681687355, 44.10701863467693, 44.770482033491135, 45.934040397405624, 46.0543305426836, 46.87371477484703, 46.516818925738335, 46.62733219563961, 46.47058680653572, 42.72434502840042, 46.30053073167801, 46.368984058499336, 46.74042172729969, 48.19981701672077, 48.7730048596859, 45.782037153840065, 46.6082002222538, 46.92681312561035, 49.85895238816738, 52.29395292699337, 58.547265976667404, 60.24409532546997, 61.549834460020065, 67.37288519740105, 65.88515862822533, 63.42383690178394, 68.24100941419601, 63.68490569293499, 65.80648764967918, 62.65361063182354, 69.58286181092262, 59.71964746713638, 71.0875278711319, 4.832589710131288, 5.3761918656528, 9.50014192610979, 21.765826754271984, 68.24752226471901, 67.51438200473785, 62.964190766215324, 67.47192308306694, 66.81737780570984, 69.05243307352066, 34.75134685635567, 44.47084531188011, 44.84965078532696, 54.70537193119526, 40.22647686302662, 0.19538149324944243, 0.23522703093476593, 0.20839604723732919, 0.1950925454730168, 0.33383363974280655, 0.1709434311487712, 0.22239837009692565, 0.11272529300185852, 0.2066852929419838, 0.18417319311993197, 0.17356244061375037, 0.11003108171280473, 0.22616387897869572, 0.1617585521307774, 0.09065448903129436, 0.1740494230762124], [0.023615450772922486, 0.034205812771688215, 0.02302105913258856, 0.027534771616046783, 0.08243999778642319, 0.07149888566345908, 0.038169007530086674, 0.05114957857585978, 0.06759835785487667, 0.03413892300159205, 0.0389247402199544, 0.06657270976575091, 0.00853948513395153, 0.08946244401158765, 0.03388634788279887, 0.03466876078164205, 0.045970567807671614, 0.15556730388198048, 0.05680546375515405, 0.44153912749607116, 0.4611555451992899, 40.067599788308144, 51.51765078306198, 63.39067988097668, 30.55056966841221, 43.50217469036579, 54.54945869743824, 58.00524026155472, 63.147082552313805, 52.73841507732868, 58.82953383028507, 22.35703133046627, 0.020496602992352564, 8.50578848272562, 47.937144711613655, 81.0629653930664, 69.85245734453201, 65.95269620418549, 58.479933589696884, 56.035045981407166, 52.98308774828911, 55.474382266402245, 51.58256269991398, 53.610152900218964, 52.565292567014694, 51.337396055459976, 46.807716116309166, 47.158011719584465, 48.64119753241539, 47.0486231893301, 46.342883259058, 47.14927978813648, 45.41100226342678, 45.82633517682552, 42.825225815176964, 45.18222413957119, 47.42387965321541, 45.01779556274414, 45.34264013171196, 46.22751384973526, 45.103275775909424, 47.69301541149616, 44.70196411013603, 44.75500926375389, 42.009219601750374, 44.01551194489002, 45.66963158547878, 44.027124121785164, 46.03823460638523, 45.061025843024254, 44.58341047167778, 43.229383528232574, 42.19316013157368, 44.45067599415779, 41.951132118701935, 41.99841298162937, 42.08206929266453, 42.75182895362377, 43.213675171136856, 44.45196032524109, 48.50542701780796, 46.71538487076759, 52.87440977990627, 56.21958687901497, 58.508686646819115, 58.322226852178574, 60.48145338892937, 59.22351948916912, 25.35995129495859, 45.12382887303829, 60.34023016691208, 58.54467071592808, 59.59008201956749, 58.05233873426914, 55.70208124816418, 59.01874087750912, 60.07841281592846, 52.27800138294697, 45.709457248449326, 44.639229476451874, 44.006012454628944, 41.56810127198696, 40.48613213002682, 38.59892159700394, 43.57247091829777, 39.10247437655926, 39.42950002849102, 41.647475212812424, 42.24315024912357, 44.353120028972626, 44.0043481439352, 42.28959895670414, 41.79364196956158, 40.781425684690475, 39.896183386445045, 41.12689554691315, 41.46879740059376, 39.98832084238529, 42.605848386883736, 39.33393135666847, 45.239775851368904, 43.53646405041218, 43.22839938104153, 40.863695070147514, 42.319298163056374, 41.860476583242416, 42.194573655724525, 42.0401955395937, 43.233312517404556, 44.29138474166393, 43.70272792875767, 42.46169552206993, 50.51800422370434, 54.93008807301521, 59.23806130886078, 58.8720915466547, 57.88136310875416, 54.852750822901726, 57.031903490424156, 56.253978833556175, 62.849387526512146, 59.922837764024734, 59.41029466688633, 53.581563234329224, 65.24991631507874, 5.242062862962484, 0.8327193791046739, 0.5267408571671695, 21.215555481612682, 55.6347868591547, 51.336503103375435, 61.42497316002846, 53.64642955362797, 61.71184256672859, 43.509029522538185, 23.93550843000412, 33.61577779054642, 30.855054929852486, 41.83438338339329, 1.6821595234796405, 0.06644771725405008, 0.07193522396846674, 0.0390579520171741, 0.02479104423400713, 0.034188186764367856, 0.05443462847324554, 0.07240922626806423, 0.008437777505605482, 0.1148752131848596, 0.046938710584072396, 0.04338347069278825, 0.032271297241095454, 0.026072315813507885, 0.06464777165092528, 0.027871458041772712, 0.0335382509365445, 0.02340974227990955, 0.022343279779306613, 0.0730027885583695, 0.046253411419456825, 0.034608554051374085, 0.0435713379556546, 0.010233769316982944, 0.03150236174406018, 0.060929129394935444, 0.014950346940167947, 0.051666592044057325, 0.06955745702725835, 0.017195079271914437, 0.08019648535992019, 0.016450528892164584, 0.03501544393657241, 0.057496262234053575, 0.11531018593814224, 0.05208466238400433, 0.5319678329396993, 1.0129774315282702, 46.014459282159805, 54.38750758767128, 53.137070685625076, 47.39464022219181, 47.02215760946274, 66.30739957094193, 66.56201630830765, 70.37423774600029, 61.48462235927582, 67.0773446559906, 26.507227532565594, 0.15540462511125952, 8.33301555365324, 49.63126100599766, 82.56067782640457, 71.76010698080063, 69.00580197572708, 60.47596648335457, 58.72796148061752, 56.25935174524784, 58.08271050453186, 55.60852646827698, 58.56911860406399, 54.65663954615593, 50.92500418424606, 49.65861573815346, 48.860958740115166, 51.086107939481735, 49.806431606411934, 49.371860325336456, 50.853549018502235, 47.681038454174995, 48.94169680774212, 45.68999469280243, 47.9679686576128, 48.112782686948776, 47.11275614798069, 46.8211217969656, 47.86384664475918, 47.09996223449707, 48.7077471613884, 47.33660973608494, 44.97510105371475, 42.94449381530285, 45.32289259135723, 48.51683020591736, 47.114792838692665, 47.461471036076546, 47.95607149600983, 45.85730731487274, 46.223968639969826, 45.96561290323734, 46.13889880478382, 47.21990279853344, 45.62750704586506, 44.8881009221077, 45.38413770496845, 47.41344541311264, 46.927930265665054, 50.27430050075054, 50.42926758527756, 59.19548459351063, 57.91528008878231, 61.37168861925602, 61.33055202662945, 62.35300496220589, 64.93704110383987, 32.95658156275749, 47.07197293639183, 64.49015468358994, 59.36889968812466, 63.40320400893688, 61.17664508521557, 59.759575724601746, 61.186779141426086, 64.69808712601662, 54.730287194252014, 47.019797936081886, 47.109176740050316, 45.41426248848438, 43.258873745799065, 45.280217081308365, 42.17229925096035, 44.293007254600525, 42.464134991168976, 43.718778267502785, 43.26381728053093, 45.49174793064594, 46.70549400150776, 46.344285383820534, 44.721612855792046, 44.60736818611622, 42.061656787991524, 40.87771251797676, 44.0746633708477, 45.238206535577774, 42.189436331391335, 46.488229259848595, 41.462064161896706, 47.21260339021683, 46.98594555258751, 45.31237095594406, 43.392037600278854, 43.852208107709885, 45.62732845544815, 44.07914713025093, 44.997193068265915, 44.445337280631065, 46.508732959628105, 47.46065028011799, 45.84721885621548, 52.52416357398033, 56.921318024396896, 61.6132340580225, 60.635865703225136, 60.36414988338947, 57.611019015312195, 59.300507158041, 59.08486872911453, 67.1633492410183, 61.76423415541649, 63.74935783445835, 60.52586920559406, 68.37238356471062, 6.78365059196949, 1.3222504360601306, 1.4768115361221135, 24.92694742977619, 64.23024103045464, 55.030178502202034, 65.36657005548477, 57.62481227517128, 70.2207563817501, 53.82839798927307, 29.204271510243416, 39.43209148943424, 37.769794687628746, 51.476715579628944, 1.910929810255766, 0.07503323038690723, 0.06475872272858396, 0.04429706190421712, 0.026526482361077797, 0.06686639244435355, 0.046787275350652635, 0.023189363382698502, 0.01398002967107459, 0.0644438443123363, 0.024465105962008238, 0.07037363393465057, 0.01345952439805842, 0.010536625868553529, 0.09204819041769952, 0.050419360923115164, 0.0501025788980769, 0.15548183815553784, 0.12511600507423282, 0.11501326007419266, 0.16678213491104543, 0.19348913541762158, 0.11138231740915217, 0.13737910485360771, 0.12199652832350694, 0.24539578997064382, 0.076452335488284, 0.09504043337074108, 0.1565932488301769, 0.07507718779379502, 0.16691126860678196, 0.21483261982211843, 0.08907004084903747, 0.24992639373522252, 0.336573114618659, 0.2725021995138377, 0.47237073245923966, 1.4729351503774524, 61.98751777410507, 68.09562161564827, 68.97530481219292, 49.728740975260735, 55.10832130908966, 77.31370657682419, 75.79089269042015, 75.97052425146103, 64.72308978438377, 77.1006216108799, 28.93118966370821, 0.4220629163319245, 9.418382663279772, 51.27536818385124, 85.94728410243988, 74.00656163692474, 72.2297465801239, 64.37649518251419, 61.54401697218418, 60.236491933465004, 62.10934303700924, 57.68097706139088, 62.07392893731594, 57.40977801382542, 54.31391693651676, 52.13787630200386, 52.337263002991676, 55.405670553445816, 53.174354285001755, 53.44323165714741, 53.9023382216692, 49.90139991044998, 52.141995280981064, 47.27850325405598, 51.848141849040985, 51.55552335083485, 48.00394892692566, 49.66835841536522, 49.9885368347168, 48.90122517943382, 50.63464276492596, 50.87130926549435, 50.14970138669014, 46.47130496799946, 48.64810176193714, 50.86446963250637, 49.55923967063427, 50.134509801864624, 50.93896083533764, 48.92668001353741, 50.679643750190735, 48.604696691036224, 50.01605875790119, 50.024061128497124, 49.694474413990974, 49.11800354719162, 47.36046485602856, 50.791566744446754, 48.524870574474335, 54.05323952436447, 51.35762996971607, 58.90514977276325, 60.01654073596001, 62.86654360592365, 63.53318743407726, 66.95175379514694, 61.62192039191723, 24.548366144299507, 50.998632833361626, 64.42600652575493, 63.225768730044365, 64.52112302184105, 62.50357948243618, 60.10884918272495, 63.64854544401169, 66.23742252588272, 57.41045817732811, 49.993054792284966, 49.013626947999, 47.81649738550186, 46.378270760178566, 46.090614795684814, 43.30071710050106, 47.91346438229084, 42.98299714922905, 46.92292973399162, 44.62917901575565, 45.5107469111681, 48.29062074422836, 51.45188391208649, 46.6957551240921, 47.06710919737816, 44.43784788250923, 42.75084100663662, 45.33754080533981, 49.400655180215836, 45.29632821679115, 48.76247942447662, 45.130930691957474, 48.72728571295738, 48.39187391102314, 48.834185376763344, 46.48319832980633, 46.41104780137539, 48.252265602350235, 46.56388700008392, 46.234756261110306, 48.79472069442272, 49.52048175036907, 48.48116531968117, 48.724637255072594, 56.125059351325035, 60.43956443667412, 62.953893318772316, 63.521020486950874, 63.70999574661255, 59.42185364663601, 62.75324888527393, 61.16606645286083, 69.90282744169235, 65.25172501802444, 68.03471848368645, 61.340830475091934, 71.99475958943367, 8.415443580597639, 2.2783534694463015, 2.9341997019946575, 25.143446512520313, 69.80594024062157, 60.629801228642464, 71.34088307619095, 63.747499734163284, 73.8315050303936, 55.42879991233349, 32.802488431334496, 53.03377702832222, 43.85015621781349, 68.14689606428146, 7.212319364771247, 0.3790875489357859, 0.1845936494646594, 0.16116728307679296, 0.11473187478259206, 0.17787241871701553, 0.13166459742933512, 0.1235363660089206, 0.0737231838866137, 0.2863535250071436, 0.1730123013840057, 0.1319574489025399, 0.1766711042728275, 0.11322009770083241, 0.13375159091083333, 0.16172883653780445, 0.164944265561644], [0.034733557695290074, 0.0641869127866812, 0.059736156690632924, 0.03720408567460254, 0.01638916441152105, 0.07817576566594653, 0.04846477400860749, 0.07951528285047971, 0.09126356962951832, 0.027534571236174088, 0.014294626998889726, 0.0617513176985085, 0.03573956113541499, 0.05814692907733843, 0.07716460429946892, 0.005644540060529835, 0.06985151820117608, 0.07957575304317288, 0.06410970716387965, 0.305360906640999, 0.4216182214440778, 9.705539904534817, 54.31637540459633, 40.427406281232834, 28.94587017595768, 25.729380771517754, 58.91287475824356, 60.72536610066891, 63.97386118769646, 56.369477435946465, 65.36704123020172, 39.3365266174078, 1.726660004351288, 2.233416843228042, 38.64166930317879, 74.97986420989037, 77.1058501303196, 69.94491398334503, 64.74227875471115, 60.32347686588764, 59.87301483750343, 57.82200649380684, 58.131317496299744, 57.851527109742165, 59.323245137929916, 55.30576631426811, 47.700383216142654, 48.868307545781136, 46.80453188717365, 47.817880511283875, 47.98892833292484, 46.51522681117058, 46.83011591434479, 46.32978916168213, 44.42371264100075, 45.536821112036705, 48.62138919532299, 45.8767356723547, 47.09738217294216, 46.029688864946365, 46.53115935623646, 46.203309148550034, 42.817622423172, 44.12631779909134, 44.062728211283684, 43.49715895950794, 44.37408730387688, 46.47355444729328, 43.66175852715969, 43.29155579209328, 44.54472854733467, 44.34942662715912, 42.792159989476204, 42.20094971358776, 40.66495053470135, 42.936206459999084, 41.96554854512215, 43.226176500320435, 43.741151466965675, 45.371833965182304, 48.33347484469414, 49.66185696423054, 50.52404209971428, 53.30602861940861, 53.11858847737312, 58.59474062919617, 53.68586763739586, 69.49311822652817, 34.13590908050537, 32.73083567619324, 62.905442118644714, 56.38765566051006, 62.27490775287151, 56.15522213280201, 57.43482246994972, 58.704338148236275, 59.72819700837135, 53.58936421573162, 47.03946568071842, 44.39272150397301, 44.45534974336624, 41.69785290956497, 41.7174256592989, 41.23820677399635, 41.26292064785957, 40.233077108860016, 42.33315221965313, 41.59635275602341, 42.35346972942352, 45.60904383659363, 42.73975320160389, 42.751281782984734, 42.500012665987015, 39.72816400229931, 40.555888786911964, 40.43141506612301, 43.66832077503204, 40.81925645470619, 41.56310833990574, 42.40974470973015, 44.701367542147636, 45.09645514190197, 46.46493650972843, 45.99432036280632, 48.198756873607635, 45.47347471117973, 44.82510030269623, 42.33858972787857, 43.250126615166664, 42.706375792622566, 45.038732439279556, 43.913958594202995, 43.24704498052597, 43.0444398522377, 47.42512598633766, 44.82681021094322, 47.33650714159012, 47.43213661015034, 54.9028093367815, 57.95363523066044, 60.94099313020706, 61.290365383028984, 62.8697544336319, 54.33181397616863, 70.4204660654068, 8.844157475978136, 0.7329940272029489, 1.4812270179390907, 27.157479040324688, 62.50612914562225, 52.25690871477127, 58.04863393306732, 53.9660570025444, 62.927085757255554, 15.896366257220507, 27.144204452633858, 26.930473521351814, 42.23129868507385, 21.79172046482563, 0.3146232361905277, 0.041828259418252856, 0.06296699270023964, 0.078032776073087, 0.02471702428010758, 0.06483109697001055, 0.06929622846655548, 0.027100442675873637, 0.059822156763402745, 0.11600450961850584, 0.07677577828872018, 0.04983046303095762, 0.03728990392119158, 0.01584558020113036, 0.025505663797957823, 0.06806518358644098, 0.04441166063770652, 0.027851484992424957, 0.0700392147700768, 0.034002783431787975, 0.05372666782932356, 0.06258383669774048, 0.012909229317301651, 0.08764508762396872, 0.035642209913930856, 0.05129215256602038, 0.07166301904362626, 0.032329789610230364, 0.03641602874267846, 0.0743417713965755, 0.10295904517988674, 0.04497101734159514, 0.09262076477170922, 0.021172241249587387, 0.1501239772187546, 0.12076056300429627, 0.2608953067101538, 0.5130148655734956, 11.557082701474428, 66.74730196595192, 42.616636008024216, 34.798414930701256, 32.947975024580956, 63.24178107082844, 67.79557451605797, 69.55602005124092, 60.695530101656914, 70.25921791791916, 45.50904080271721, 2.2260407265275717, 2.036575055681169, 38.37981015443802, 77.96495363116264, 77.33168721199036, 72.41535902023315, 66.39812350273132, 63.01740311086178, 62.39384517073631, 59.83168065547943, 61.822868809103966, 60.61667673289776, 61.01195432245731, 56.85784623026848, 48.44151444733143, 49.86157424747944, 49.24982227385044, 51.44480489194393, 50.2710934728384, 49.249757677316666, 48.302054330706596, 49.81021620333195, 46.87918268144131, 48.2625288516283, 51.55609332025051, 47.55643554031849, 48.845839351415634, 46.63618192076683, 50.34863971173763, 47.49477244913578, 45.631139650940895, 46.8686268478632, 46.05134390294552, 46.61653317511082, 45.837305188179016, 48.6376067250967, 45.955376252532005, 47.44234286248684, 45.801879689097404, 47.32383482158184, 44.819685593247414, 46.35542258620262, 44.06246602535248, 45.246816873550415, 45.26442892849445, 47.29442819952965, 47.48627610504627, 49.56824138760567, 49.69129018485546, 51.48582749068737, 55.47037348151207, 56.83160483837128, 57.185878828167915, 64.05563279986382, 56.59828595817089, 75.28421267867088, 44.10166472196579, 35.41478365659714, 65.75571477413177, 59.87433336675167, 62.993107214570045, 59.82759967446327, 62.0773259550333, 61.35324440896511, 63.690783977508545, 58.25494006276131, 50.62973342835903, 45.835880264639854, 48.098871633410454, 45.10786592960358, 44.419783651828766, 43.089041858911514, 43.2343764603138, 42.93101213872433, 44.75542724132538, 43.67039926350117, 45.77092655003071, 46.89593978226185, 44.13660764694214, 45.753884464502335, 45.550378784537315, 41.77785761654377, 43.83730910718441, 43.357573449611664, 45.747299417853355, 44.523328095674515, 43.4574168920517, 44.93522219359875, 49.47779484093189, 48.06616298854351, 48.92934747040272, 49.34086158871651, 50.78482210636139, 49.314027428627014, 47.83301889896393, 45.976419523358345, 46.69673167169094, 44.55373406410217, 47.07497477531433, 44.96430963277817, 45.04884369671345, 45.18427602946758, 47.70123057067394, 47.883377596735954, 49.67721574008465, 49.29510444402695, 56.60010226070881, 60.51174156367779, 64.1394791007042, 64.14647832512856, 67.69344359636307, 57.96887621283531, 75.347600877285, 9.870185069739819, 0.8528607327025384, 2.284499164670706, 31.770625300705433, 69.51793849468231, 58.377392292022705, 64.02124464511871, 59.52240765094757, 72.17334240674973, 19.016355089843273, 33.710043132305145, 30.268641896545887, 50.49394391477108, 26.44519206136465, 0.1797469353186898, 0.08107335510430858, 0.11312939983326942, 0.04111901856958866, 0.061051691372995265, 0.07188604926341213, 0.037368794219219126, 0.025113945266639348, 0.004483154552872293, 0.05414276405645069, 0.06662132043857127, 0.010168758108193288, 0.01749681610817788, 0.03919722716091201, 0.03717611041793134, 0.021098688848724123, 0.021477367845363915, 0.11530272735399194, 0.1574055294622667, 0.10940620821202174, 0.08735164985409938, 0.14036933658644557, 0.16363266797270626, 0.18093860184308141, 0.2337177994195372, 0.16068595577962697, 0.1984976526000537, 0.10773233865620568, 0.13335626368643716, 0.2083169194520451, 0.1774572761496529, 0.17772532504750416, 0.186303824884817, 0.17103805497754365, 0.20453480130527169, 0.240388757083565, 0.4773084487533197, 0.5798989359755069, 20.906464867293835, 77.08574920892715, 50.20365469157696, 46.1622903496027, 39.67843987047672, 72.13754832744598, 75.13980522751808, 78.48256945610046, 64.08937498927116, 80.91190829873085, 49.45989400148392, 3.0507251992821693, 2.6243652775883675, 41.17071479558945, 79.8358516395092, 79.86469969153404, 75.19432470202446, 70.205397605896, 65.07430493831635, 65.74631407856941, 64.24370750784874, 66.03775843977928, 65.1302607357502, 66.77012354135513, 60.796889662742615, 51.56260997056961, 53.439371064305305, 54.48520414531231, 53.068613559007645, 51.85685098171234, 52.91195556521416, 51.76041975617409, 54.794207364320755, 51.176611483097076, 50.90437889099121, 55.64754657447338, 50.076798498630524, 52.69494540989399, 49.29723992943764, 51.517627984285355, 49.53664608299732, 48.1597937643528, 49.543569311499596, 47.76041999459267, 49.90726299583912, 48.11804540455341, 52.43081398308277, 48.362550884485245, 50.91073215007782, 48.849570751190186, 49.537265449762344, 48.4934538602829, 47.29606211185455, 47.69648462533951, 48.07179428637028, 46.721415147185326, 49.17430132627487, 49.93678741157055, 51.955322697758675, 53.475419729948044, 55.83915889263153, 58.00452210009098, 57.899317145347595, 58.32520589232445, 66.01197302341461, 57.22163110971451, 74.95664745569229, 31.848878301680088, 34.535636231303215, 69.41850543022156, 61.21252655982971, 68.07488232851028, 61.21434286236763, 63.28637547791004, 64.37657877802849, 66.1132375895977, 61.50856867432594, 52.73061029613018, 49.53347325325012, 50.69654904305935, 47.579747289419174, 47.255297899246216, 47.40795090794563, 46.3007815182209, 45.415018647909164, 46.87485471367836, 46.19377166032791, 46.75962209701538, 50.32120518386364, 47.62634798884392, 49.26243759691715, 45.77876552939415, 44.345376044511795, 43.80913361907005, 44.83149155974388, 49.895871207118034, 47.55033686757088, 46.23452067375183, 48.24788063764572, 50.53955666720867, 49.945625737309456, 51.12157143652439, 53.8594651222229, 54.26127456128597, 53.401331305503845, 50.945063307881355, 47.79727801680565, 49.03973914682865, 46.35834462940693, 51.20675906538963, 47.85993665456772, 47.276177778840065, 47.10254609584808, 50.65708816051483, 49.36483450233936, 52.595941722393036, 51.61169953644276, 59.16949398815632, 63.489850759506226, 68.97823065519333, 66.35292872786522, 70.32577514648438, 61.81596837937832, 76.59450396895409, 11.204190887510777, 1.0037226718850434, 6.743544694036245, 32.2490481287241, 74.87046048045158, 61.89429737627506, 69.51587900519371, 63.45674313604832, 74.91096630692482, 23.098042868077755, 45.085405334830284, 39.16569158434868, 58.99302385747433, 43.18744137883186, 0.4039612220367417, 0.12990830495255068, 0.17107023450080305, 0.13774912484223023, 0.24472525954479352, 0.20059427915839478, 0.11060781951528043, 0.10367765193223022, 0.14738698111614212, 0.17462176736444235, 0.1528457592939958, 0.10907444593613036, 0.0922993925632909, 0.11444334260886535, 0.10311551217455417, 0.09120677306782454, 0.1580855148495175], [0.05208829519688152, 0.1481640394194983, 0.02826905623805942, 0.041787979353102855, 0.05761279055150226, 0.09619586082408205, 0.058775361176230945, 0.05331408196070697, 0.023793942855263595, 0.036437732851481996, 0.018327965844946448, 0.0741469650529325, 0.039750527939759195, 0.07175042919698171, 0.16682847461197525, 0.05409126642916817, 0.07642829732503742, 0.06619546868023463, 0.08428897708654404, 0.14373546611750498, 0.18857393588405102, 0.24732869875151664, 40.51105119287968, 42.61521488428116, 46.426136791706085, 28.973145112395287, 41.58356264233589, 74.66990724205971, 61.25357575714588, 69.75461259484291, 60.19381262362003, 59.08309802412987, 15.22217033430934, 0.0817692892451305, 12.245765347033739, 60.61511881649494, 78.915905803442, 72.4063915014267, 71.08303651213646, 65.91493383049965, 60.8551025390625, 60.82743622362614, 60.2691587805748, 64.00870531797409, 62.89594642817974, 60.93547202646732, 54.95225988328457, 49.4106562435627, 45.5874115973711, 49.56343084573746, 47.42638371884823, 48.19183364510536, 47.17954136431217, 46.61891184747219, 49.52482111752033, 47.11367949843407, 47.380881160497665, 48.866145461797714, 46.42111346125603, 45.375865548849106, 45.448753237724304, 47.54926912486553, 46.35706029832363, 45.036030784249306, 44.75370213389397, 43.60653229057789, 45.20727999508381, 47.228988111019135, 44.52307730913162, 45.422086268663406, 43.762392327189445, 46.01934961974621, 42.10438169538975, 44.255560263991356, 42.24544532597065, 42.99042195081711, 47.05388970673084, 44.86244849860668, 42.59103678166866, 47.93966017663479, 50.44190190732479, 56.10868602991104, 51.58694386482239, 52.86242142319679, 50.83309471607208, 59.21873554587364, 54.6724770963192, 66.2512993812561, 53.28634187579155, 29.608305729925632, 52.38274656236172, 58.95765155553818, 60.23034006357193, 59.27738159894943, 56.22537016868591, 56.71762615442276, 56.81957088410854, 55.007926896214485, 50.06105214357376, 45.20668342709541, 45.86098551750183, 44.722984582185745, 42.7058058232069, 40.30052348971367, 40.76458498835564, 41.202572286129, 43.17360632121563, 41.342841759324074, 42.91928976774216, 44.71483401954174, 42.599476128816605, 44.04633209109306, 42.2726708650589, 41.024076864123344, 41.67818896472454, 41.73716939985752, 41.750806868076324, 40.50977826118469, 42.796700745821, 42.316125333309174, 43.2952643930912, 46.66497677564621, 47.43803009390831, 46.50999069213867, 48.60172525048256, 46.717873737215996, 48.23870413005352, 43.70052024722099, 43.44259388744831, 42.21152074635029, 44.55675110220909, 41.66805490851402, 45.63658095896244, 43.17043349146843, 46.04840286076069, 43.72540511190891, 46.58895805478096, 45.00298395752907, 53.83857764303684, 53.41628350317478, 62.37839139997959, 58.75574178993702, 67.10682347416878, 54.40995678305626, 72.5366485118866, 12.256916798651218, 0.9520186088047922, 0.8819767890963703, 37.87620037794113, 53.197757229208946, 55.547049567103386, 55.33244468271732, 61.673943400382996, 28.07932287454605, 18.361882008612156, 40.01066364347935, 25.75569625943899, 49.92597699165344, 6.092879958450794, 0.05175776117539499, 0.06768270293832757, 0.015068158245412633, 0.07291521513252519, 0.0409483505791286, 0.05779702129075304, 0.04545096795482095, 0.022284204824245535, 0.02581550674221944, 0.05549916510062758, 0.054243243430391885, 0.058546972650219686, 0.0545165912626544, 0.0499054051033454, 0.0056957338711072225, 0.01560227079608012, 0.05894129797525238, 0.051412658795015886, 0.035604475415311754, 0.037337234389269724, 0.029797219940519426, 0.03296247792604845, 0.06615290651097894, 0.025251604383811355, 0.04159195217653178, 0.05431007011793554, 0.14251481130486354, 0.03151029901346192, 0.03405590636248235, 0.02807238524837885, 0.0633233720145654, 0.03218522295355797, 0.05800385413749609, 0.04893456462014001, 0.14295413304353133, 0.11636820650892332, 0.05364258249755949, 0.20889146049739793, 1.0227325768209994, 46.59064896404743, 47.4388812482357, 44.596610963344574, 39.97068978846073, 44.106642454862595, 79.92945581674576, 68.60519707202911, 75.0361467897892, 67.35957831144333, 63.230450078845024, 19.08754236996174, 0.0834759246208705, 11.212862972170115, 61.64490535855293, 80.85763961076736, 73.2204370200634, 73.56519252061844, 68.6991660296917, 62.94364146888256, 63.2595869153738, 63.17987859249115, 66.5458595752716, 67.05934882164001, 62.52170071005821, 56.164212450385094, 51.067029163241386, 49.28592033684254, 51.65578097105026, 49.530319422483444, 49.53850798308849, 50.71859925985336, 48.15054886043072, 50.04312850534916, 47.795473113656044, 50.047635063529015, 50.02733655273914, 48.91765549778938, 47.248522862792015, 48.83880972862244, 48.32072272896767, 47.70697586238384, 48.21779005229473, 47.15901106595993, 47.70932033658028, 48.82696956396103, 48.839151710271835, 49.27127592265606, 47.098320722579956, 45.894020944833755, 46.55413292348385, 46.38982594013214, 46.9572950899601, 45.75267992913723, 46.559942811727524, 48.65208014845848, 46.70625016093254, 47.383898198604584, 49.199634566903114, 52.18243271112442, 56.89627356827259, 53.26051466166973, 56.20952881872654, 52.616984993219376, 62.90509253740311, 56.336867585778236, 70.10859400033951, 66.04497045278549, 33.31739120185375, 56.54480382800102, 62.33599707484245, 64.68959078192711, 60.701157599687576, 59.89072568714619, 60.03213509917259, 61.87864601612091, 57.575722709298134, 52.883149310946465, 48.743324652314186, 47.38336622714996, 45.68092457950115, 45.58443635702133, 42.056933641433716, 42.61063612997532, 44.788508266210556, 46.793360486626625, 44.503477960824966, 46.91411420702934, 47.13733322918415, 45.0328503549099, 46.45465046167374, 45.24722345173359, 43.098647743463516, 43.09734061360359, 42.94923596084118, 44.6251056343317, 43.37932728230953, 44.959214106202126, 44.530342519283295, 46.60027004778385, 50.60838237404823, 50.54175294935703, 48.990915566682816, 52.70058050751686, 49.09181535243988, 50.76797381043434, 46.668958961963654, 45.83252124488354, 43.462774604558945, 45.805842876434326, 45.705486461520195, 47.82429836690426, 45.87624549865723, 46.80238880217075, 45.747170224785805, 49.04963381588459, 46.93434052169323, 55.46659268438816, 55.190320909023285, 64.96629193425179, 59.936969205737114, 71.67852535843849, 59.39462810754776, 73.93770933151245, 13.605407439172268, 0.8679168310482055, 3.8696380192413926, 42.21565492451191, 60.67052744328976, 60.688447281718254, 61.00413054227829, 68.55472058057785, 33.43491889536381, 23.29938266426325, 49.55571345984936, 29.57892380654812, 58.66610459983349, 5.677201738581061, 0.06206998477864545, 0.06494275308796205, 0.030336460731632542, 0.04532927428954281, 0.07060190371703357, 0.01938550401973771, 0.0034256968547197175, 0.015965002894517966, 0.04033543307741638, 0.030059565433475655, 0.08063641565968283, 0.053602528787450865, 0.10724859937909059, 0.04019616906589363, 0.00801229589342256, 0.04263124836143106, 0.03528234621626325, 0.1937259844271466, 0.2558242413215339, 0.07090361643349752, 0.15052001690492034, 0.13316873781150207, 0.14644944079918787, 0.18130810232833028, 0.07476363040041178, 0.17535677558043972, 0.17785494856070727, 0.11859928796184249, 0.10388570561190136, 0.11038259995984845, 0.14834843343123794, 0.3473767958348617, 0.11530082745593973, 0.16512699716258794, 0.29536809597630054, 0.21208606485743076, 0.26739473920315504, 0.2959017001558095, 1.1638971394859254, 66.82050123810768, 58.17902393639088, 66.66318967938423, 47.43969440460205, 54.60365518927574, 88.21283653378487, 73.67315232753754, 81.38820514082909, 72.43077859282494, 69.69392225146294, 21.03482197970152, 0.32934079645201564, 14.500952884554863, 64.1774770617485, 81.03730157017708, 74.02571260929108, 76.72582492232323, 71.63532927632332, 64.61251571774483, 68.04340481758118, 65.67996203899384, 71.49337649345398, 70.40045633912086, 65.73502108454704, 60.50538070499897, 54.518258571624756, 51.75688214600086, 55.53614795207977, 50.4690096527338, 54.01115298271179, 53.63150015473366, 52.759667336940765, 54.491614401340485, 52.14880831539631, 52.75740645825863, 53.30732434988022, 50.62248341739178, 50.38247309625149, 50.11059768497944, 52.577068135142326, 50.16672447323799, 52.039461582899094, 49.90869551897049, 51.70639045536518, 51.69558763504028, 52.611315697431564, 51.55585393309593, 51.34078927338123, 49.61909405887127, 50.713412538170815, 48.990983963012695, 51.17527395486832, 48.754625245928764, 48.32633122801781, 52.430183216929436, 48.323241993784904, 48.91487404704094, 51.87057204544544, 55.32526686787605, 63.29950377345085, 54.43022109568119, 59.380758851766586, 55.83348199725151, 64.56260919570923, 59.86185863614082, 72.16726273298264, 50.75780935585499, 27.907537892460823, 62.9974427819252, 62.15183235704899, 66.00323349237442, 62.6229652762413, 60.8408685028553, 61.498392820358276, 63.53188410401344, 58.88953261077404, 56.71610623598099, 49.078193083405495, 50.85202910006046, 46.033591255545616, 48.326817601919174, 43.689056262373924, 44.715567380189896, 44.98034857213497, 50.35132236778736, 45.77875033020973, 48.044230565428734, 49.49142850935459, 48.195181265473366, 49.44013126194477, 48.939359933137894, 45.279476121068, 45.089307725429535, 44.29948590695858, 46.404192969202995, 46.444299817085266, 48.95389795303345, 46.817344799637794, 48.462082743644714, 51.905381977558136, 52.23323978483677, 52.080271393060684, 55.038796439766884, 52.528335750103, 54.62896943092346, 48.98806191980839, 47.57528632879257, 45.13140946626663, 48.65313269197941, 47.175642773509026, 49.90855112671852, 48.485588282346725, 49.430882558226585, 48.26808035373688, 50.61681032180786, 49.350026696920395, 58.59313331544399, 58.23596768081188, 67.4109211564064, 63.60939994454384, 72.41880163550377, 62.02963471412659, 78.4377546608448, 14.826451018452644, 1.1133811064064503, 6.056367242708802, 46.75964489579201, 64.14783105254173, 67.29265630245209, 65.9466241300106, 72.5695851445198, 35.58759458363056, 27.54959899932146, 60.98037041723728, 36.36738494038582, 71.31010472774506, 13.532843682914972, 0.22748323943233117, 0.15709862171206623, 0.07139073990401812, 0.1719338569091633, 0.12509241962106898, 0.18725122092291713, 0.15704180288594216, 0.1262465928448364, 0.11197441766853444, 0.12118411410483532, 0.28288196597713977, 0.17697934788884595, 0.2628017059760168, 0.14292327454313636, 0.07672034727875143, 0.1494750878191553, 0.1411440793890506], [0.008247950972872786, 0.04797996603883803, 0.05217468489718158, 0.02266688028612407, 0.04333798817242496, 0.0060433011094573885, 0.03984340772149153, 0.04756663431180641, 0.04391425471112598, 0.04104376850591507, 0.037558809999609366, 0.050848441023845226, 0.03887784761900548, 0.061597730236826465, 0.06825556672993116, 0.06394823809387162, 0.057409137807553634, 0.14556978800101206, 0.07485114445444196, 0.04626460300642066, 0.0774427612486761, 0.3777679509948939, 6.107543846592307, 71.48564770817757, 29.275462590157986, 52.06822603940964, 29.673618525266647, 51.67743980884552, 70.54519817233086, 67.30274856090546, 62.38187961280346, 61.53474546968937, 38.776812851428986, 1.2389179388992488, 0.1926269824616611, 26.871004812419415, 67.19326123595238, 80.52012652158737, 72.93454796075821, 69.3840716779232, 63.804344683885574, 65.4217354953289, 65.25093466043472, 69.58668440580368, 70.0079146027565, 72.37933695316315, 61.28183864057064, 50.32435141503811, 48.13996642827988, 50.87599441409111, 45.99436216056347, 45.32460629940033, 45.91034486889839, 46.15824356675148, 45.3906087577343, 47.352686673402786, 45.28698831796646, 47.88832113146782, 44.75967921316624, 47.95546352863312, 48.25393371284008, 46.84043996036053, 48.478186279535294, 45.27486316859722, 43.589011430740356, 43.90097849071026, 46.35465122759342, 44.80576694011688, 46.87298521399498, 42.483521550893784, 43.75546149909496, 43.93713355064392, 42.11919330060482, 40.854476764798164, 43.20317253470421, 44.135224521160126, 44.67180512845516, 44.370485097169876, 46.165827959775925, 51.06288738548756, 60.09401857852936, 58.928776904940605, 58.63737054169178, 53.23538661003113, 53.055656254291534, 52.118003368377686, 56.8840192258358, 59.38650794327259, 68.39053139090538, 42.318321615457535, 41.677960976958275, 61.70329302549362, 58.13073992729187, 57.53284201025963, 56.6938242316246, 55.36193490028381, 55.38753792643547, 53.034973964095116, 48.82299117743969, 45.862866416573524, 44.37919802963734, 44.25287000834942, 44.26730163395405, 41.72853246331215, 40.46127766370773, 40.91222606599331, 40.869877338409424, 41.46896839141846, 43.65975223481655, 42.26861268281937, 41.99797980487347, 43.40771555900574, 43.897501677274704, 41.866187676787376, 41.35872110724449, 41.96416161954403, 41.33165895938873, 42.648877277970314, 41.218124851584435, 44.38837453722954, 43.688680082559586, 45.775930881500244, 46.89891502261162, 47.3768799751997, 49.4726575165987, 48.60427871346474, 49.98475983738899, 48.84354047477245, 46.090914979577065, 43.662233501672745, 45.26055693626404, 44.273594096302986, 45.999024510383606, 45.992891639471054, 49.670026525855064, 46.64174482226372, 49.508436396718025, 42.84341923892498, 49.84271205961704, 53.22720944881439, 57.03817695379257, 57.39146299660206, 67.69232645630836, 58.54136869311333, 72.02815979719162, 12.397581450641155, 0.8710064215119928, 0.7653175271116197, 33.34457874298096, 56.12304545938969, 56.373790204524994, 59.172989800572395, 56.85073301196098, 15.409420486539602, 20.863597467541695, 25.82933820784092, 38.664426282048225, 39.15086477994919, 0.33725307032000273, 0.011388873936084565, 0.08590030585764907, 0.09881504098302685, 0.07400232789223082, 0.06663481268333271, 0.06987603876041248, 0.03740432453923859, 0.037505445870920084, 0.07605751292430796, 0.052903551841154695, 0.0915382310631685, 0.006150034005258931, 0.014904998934071045, 0.053177281879470684, 0.10028736549429595, 0.04486705729505047, 0.027798404735221993, 0.056106768824975006, 0.009725390737003181, 0.026364790646766778, 0.04828621698834468, 0.004597478227879037, 0.004376728720671963, 0.0637344698770903, 0.040971995404106565, 0.03541770282026846, 0.06976888747885823, 0.07542512146756053, 0.06991675298195332, 0.06128522669314407, 0.09247637251974083, 0.028094321278331336, 0.0811639564926736, 0.09858446312136948, 0.07189030176959932, 0.06849006313132122, 0.09218637089361437, 0.13760780508164316, 0.4704903974197805, 8.576631881296635, 80.44139474630356, 32.27012179791927, 62.236757799983025, 36.75551511347294, 63.46855670213699, 78.46008226275444, 72.5964193046093, 68.70597526431084, 66.97652086615562, 44.68652553856373, 1.5619719726964831, 0.1810284610837698, 26.80353943258524, 70.1590096950531, 81.74044623970985, 73.71292099356651, 71.31204262375832, 67.37847849726677, 68.06128665804863, 69.17522728443146, 71.93761825561523, 72.92763993144035, 73.31486195325851, 62.08068497478962, 52.99458593130112, 52.14340500533581, 52.99161449074745, 48.716646283864975, 47.59586602449417, 47.46437408030033, 48.403839468955994, 47.87289775907993, 51.16526909172535, 47.66175448894501, 48.49445700645447, 47.602386474609375, 49.949106350541115, 49.55121450126171, 48.021146804094315, 51.15428388118744, 46.80119566619396, 47.33346350491047, 45.71206010878086, 49.09281089901924, 48.3191192150116, 50.35147815942764, 45.076084434986115, 47.47138850390911, 47.39262633025646, 45.69638594985008, 45.36970607936382, 48.121503219008446, 46.82017184793949, 47.451918348670006, 47.997094094753265, 48.76697838306427, 54.01066280901432, 61.13963507115841, 60.321352779865265, 63.04353050887585, 57.09140829741955, 56.45545542240143, 54.6906553208828, 61.61401301622391, 60.303755924105644, 85.28979018330574, 49.242614060640335, 45.04243724048138, 65.66359251737595, 61.81264355778694, 61.174061223864555, 58.931151777505875, 58.58092837035656, 57.36601576209068, 56.65396437048912, 51.29084475338459, 49.051541313529015, 47.68382370471954, 47.25430615246296, 47.068743109703064, 45.60467027127743, 42.98491224646568, 43.682395219802856, 44.82015676796436, 45.48020415008068, 45.49077898263931, 44.67871315777302, 45.966293066740036, 44.67478796839714, 46.58987760543823, 44.64562073349953, 43.05746175348759, 44.786235988140106, 43.70699889957905, 45.55436097085476, 43.928287625312805, 46.613709926605225, 47.885136902332306, 48.19002494215965, 49.978896751999855, 51.295195519924164, 54.750429913401604, 51.95416375994682, 52.769330218434334, 51.09376832842827, 48.41483227908611, 45.906849056482315, 47.40746073424816, 46.053031012415886, 47.60090835392475, 46.69756382703781, 50.62350556254387, 48.133765161037445, 53.11821609735489, 46.32811725139618, 51.98362737894058, 55.31945317983627, 62.71487854421139, 60.837794467806816, 71.33967474102974, 61.588113605976105, 76.63412064313889, 13.457971550524235, 0.7041457376908511, 1.170732497703284, 38.78397546708584, 60.096545442938805, 62.58961446583271, 65.1544426381588, 63.85386362671852, 18.859079629182816, 26.365457139909267, 32.72959694266319, 42.44298532605171, 48.035502433776855, 0.5117166414856911, 0.033601567265577614, 0.029497950745280832, 0.06600118926144205, 0.0642354047158733, 0.06587315394426696, 0.07046623912174255, 0.01961136924364837, 0.08180760632967576, 0.008054577901930315, 0.07098246220266446, 0.03502380051941145, 0.024985525888041593, 0.07206259135273285, 0.050261157302884385, 0.05387203229474835, 0.019928436995542143, 0.05989319884974975, 0.09693014915683307, 0.18998734129127115, 0.1441522265668027, 0.19606876652687788, 0.1621325797168538, 0.12801100441720337, 0.17538102896651253, 0.30998193367850035, 0.1434682632680051, 0.12428297399310395, 0.21229594422038645, 0.15183713607257232, 0.20472167409025133, 0.222709730733186, 0.1296859871945344, 0.12389679744956084, 0.1524858028278686, 0.35739528480917215, 0.1721366264973767, 0.13802083994960412, 0.3722230391576886, 0.8242593111936003, 18.19979790598154, 91.97420910000801, 43.349658474326134, 69.79579478502274, 42.20686599612236, 65.45435294508934, 80.61308473348618, 78.42092156410217, 72.3241563141346, 71.4773565530777, 50.101109594106674, 2.0413882099092007, 0.3622654656646773, 32.06872500479221, 71.99559554457664, 83.89597177505493, 77.92884796857834, 75.14279946684837, 71.39585852622986, 70.12667343020439, 72.31370687484741, 76.69825360178947, 77.55085185170174, 78.30596253275871, 65.24056881666183, 57.76335284113884, 55.292512625455856, 58.11511516571045, 51.82231083512306, 50.769657120108604, 50.611315816640854, 52.09345668554306, 51.31603740155697, 52.28656992316246, 50.982312709093094, 51.002577021718025, 49.877229407429695, 53.82262609899044, 52.91074723005295, 51.063392758369446, 53.8892213255167, 50.69740019738674, 49.30928148329258, 48.57858829200268, 52.787751629948616, 51.83952011168003, 52.88630694150925, 46.63302429020405, 50.00563211739063, 51.857755333185196, 48.95321398973465, 49.007558673620224, 51.1139452457428, 50.83874121308327, 49.00389946997166, 50.23726388812065, 52.07554064691067, 57.51504376530647, 66.20390832424164, 64.19490292668343, 65.44081807136536, 59.16776888072491, 58.82632680237293, 57.0294564217329, 64.79071855545044, 61.97735331952572, 76.59613028168678, 38.492390513420105, 45.6686170399189, 69.93758037686348, 64.08396407961845, 62.1298049390316, 60.7288733124733, 60.857268422842026, 61.612363904714584, 60.47636926174164, 54.681778997182846, 50.73547415435314, 48.1299539655447, 49.33431074023247, 49.63139019906521, 48.35973143577576, 44.92612548172474, 44.74908918142319, 47.127278968691826, 47.288337126374245, 48.37559558451176, 46.29539340734482, 48.16740095615387, 47.8141301125288, 50.614610239863396, 47.77372308075428, 45.45748896896839, 46.58189803361893, 46.50697745382786, 46.76231995224953, 45.190872475504875, 48.78788486123085, 50.757934749126434, 49.590029418468475, 51.70874632894993, 53.60501937568188, 59.58320438861847, 55.8919570595026, 56.062906086444855, 52.65157453715801, 50.53877390921116, 47.6429682970047, 51.07514172792435, 49.941198974847794, 50.42138300836086, 49.717987552285194, 53.20495784282684, 48.53550620377064, 53.78684721887112, 49.26961161196232, 55.00008411705494, 58.83880153298378, 65.39167150855064, 62.050826177001, 74.98993366956711, 64.51291546225548, 78.7210750579834, 15.322644542902708, 0.8482095447834581, 1.5554930828511715, 42.099327966570854, 67.35024601221085, 68.08522537350655, 70.0086897611618, 69.36116650700569, 21.45848784595728, 34.54641245305538, 43.371328711509705, 49.03152018785477, 63.594459146261215, 1.4156893221661448, 0.10734162016888149, 0.1828324142843485, 0.22340452938806266, 0.1605825894512236, 0.24686761724296957, 0.10281785900588147, 0.076280283392407, 0.17311832460109144, 0.15795647021150216, 0.18812615366186947, 0.15654235234251246, 0.1317128518712707, 0.260804349090904, 0.10170774708967656, 0.18444188026478514, 0.14967598719522357, 0.1402451010653749], [0.03864984872052446, 0.03533087896357756, 0.03528528512106277, 0.02428278068691725, 0.02496882385457866, 0.0023885190375949605, 0.043975084845442325, 0.09695827655377798, 0.03833712253253907, 0.03459999708866235, 0.04571357691020239, 0.01695532104349695, 0.06635757599724457, 0.04326402944570873, 0.028420292946975678, 0.07089284787070937, 0.06745048493030481, 0.03216764518583659, 0.052510336026898585, 0.011511362627061317, 0.13038050383329391, 0.09554389151162468, 0.088156405108748, 38.38953763246536, 45.156837701797485, 44.23519715666771, 56.61315456032753, 17.646950371563435, 60.285387709736824, 71.30510419607162, 65.65062001347542, 60.216117426753044, 51.465627774596214, 8.33632042631507, 0.10705316220992245, 3.0408405046910048, 42.16753430664539, 75.49747243523598, 79.90932449698448, 71.53548583388329, 70.46294778585434, 70.92415943741798, 69.19438585639, 72.08121255040169, 68.46315309405327, 68.21123421192169, 68.91047269105911, 52.13449448347092, 49.30961586534977, 47.643401473760605, 50.272176414728165, 47.52251856029034, 47.2018613666296, 46.92296393215656, 45.598613396286964, 48.73357057571411, 46.14287719130516, 49.65627506375313, 49.17319938540459, 45.34836642444134, 47.02526584267616, 47.98792138695717, 48.04400637745857, 46.36315897107124, 44.17285770177841, 45.494065806269646, 47.16051958501339, 45.32267980277538, 45.75146019458771, 45.9731213003397, 44.73930090665817, 43.09472635388374, 44.147391468286514, 43.447735011577606, 46.29753649234772, 44.725351855158806, 43.54152537882328, 44.419722855091095, 48.11133876442909, 58.73652242124081, 60.701465383172035, 60.49017012119293, 61.840465664863586, 58.69847886264324, 56.2086396664381, 53.98770444095135, 55.69504402577877, 57.84546263515949, 63.98854359984398, 63.95287871360779, 48.65747585892677, 60.32913476228714, 57.508743703365326, 55.79495586454868, 53.92134480178356, 53.422682359814644, 52.136371582746506, 50.0906715542078, 48.282063603401184, 46.63330927491188, 45.51969163119793, 44.97530244290829, 43.155800476670265, 43.700402453541756, 41.21647574007511, 41.721848621964455, 40.91302402317524, 42.10950382053852, 42.228969410061836, 42.0519483089447, 41.71370945870876, 43.546400517225266, 41.973771303892136, 43.31225328147411, 41.86709962785244, 42.679173052310944, 41.87770485877991, 42.89075329899788, 43.39908242225647, 42.51404531300068, 43.13069522380829, 43.545131385326385, 47.4718064814806, 44.89522933959961, 48.28635357320309, 49.72155936062336, 50.876024812459946, 49.70440328121185, 46.46991044282913, 43.89666572213173, 43.73578615486622, 43.64095464348793, 48.96426759660244, 58.25443089008331, 59.8580664396286, 57.6571599394083, 56.22316248714924, 52.37751804292202, 48.65086041390896, 49.266856759786606, 60.034528970718384, 60.64213916659355, 62.33155511319637, 63.028772100806236, 70.33903643488884, 7.895881785079837, 0.7208462571725249, 2.4824602296575904, 37.99106061458588, 63.31558831036091, 52.51912884414196, 65.40164977312088, 42.440089881420135, 12.682910040020943, 40.050485506653786, 27.808631099760532, 49.052639454603195, 21.845413483679295, 0.11571608876693062, 0.13022972911130637, 0.07481638225726783, 0.13916912052081898, 0.02194843124016188, 0.013404481160250725, 0.0394236155989347, 0.0402467686944874, 0.08278246183181182, 0.04053060678415932, 0.05559186676691752, 0.025220506540790666, 0.027079634710389655, 0.030802733563177753, 0.030071120672801044, 0.05092033286928199, 0.05675219239492435, 0.012511333334259689, 0.032126129444804974, 0.01715098271233728, 0.02760152408882277, 0.038098284567240626, 0.012473254664655542, 0.051835297053912655, 0.04639119855710305, 0.11433610969106667, 0.025340671381854918, 0.01966911760973744, 0.031747133180033416, 0.038326283465721644, 0.06911639124155045, 0.021299014915712178, 0.03531963171553798, 0.11163427654537372, 0.059851156183867715, 0.04112291855562944, 0.09676310655777343, 0.017111730521719437, 0.1904761791229248, 0.12079003368853591, 0.2824825420975685, 45.38922943174839, 47.92081318795681, 48.18276733160019, 67.81987801194191, 23.551440238952637, 74.0998162329197, 74.08777847886086, 71.53749972581863, 66.27429574728012, 57.24669076502323, 8.770595323294401, 0.237215259403456, 2.9837195947766304, 43.608416989445686, 78.93778502941132, 82.77175650000572, 73.93188044428825, 74.04739424586296, 73.2665665447712, 72.5086060166359, 75.75845763087273, 71.85653820633888, 70.37475451827049, 71.08809024095535, 54.42440740764141, 52.52650044858456, 50.68310156464577, 52.14918069541454, 50.329887717962265, 48.9385087788105, 50.167807415127754, 47.163422629237175, 50.676178336143494, 50.41707403957844, 52.52365060150623, 50.390042290091515, 46.805778220295906, 49.51765850186348, 49.834610894322395, 49.652353674173355, 48.86092834174633, 46.81006819009781, 48.930931985378265, 48.06179702281952, 50.82661226391792, 48.5151506960392, 49.587928131222725, 45.994795337319374, 46.142615005373955, 46.36445850133896, 46.64364852011204, 49.13315713405609, 47.546605467796326, 48.12692552804947, 47.2493664175272, 51.112854704260826, 60.19264608621597, 63.06274987757206, 63.76975134015083, 63.54533538222313, 61.34024150669575, 57.2419448196888, 56.725176349282265, 59.226027354598045, 56.94712243974209, 68.71877297759056, 79.05263766646385, 50.20936198532581, 62.73565962910652, 61.0489035397768, 59.93262603878975, 58.63152265548706, 57.16671645641327, 55.21848499774933, 53.68537366390228, 49.8890695720911, 49.473166689276695, 48.91263596713543, 48.580438792705536, 46.07040748000145, 46.51095204055309, 43.005408346652985, 44.32305224239826, 44.6024626493454, 46.0856294631958, 46.192076951265335, 45.750852227211, 43.93493726849556, 44.402794763445854, 44.42022442817688, 45.53603835403919, 45.228612050414085, 45.193581730127335, 44.211406633257866, 45.53684011101723, 44.88343097269535, 45.941491797566414, 46.42302095890045, 47.97030173242092, 49.16075885295868, 48.222630992531776, 50.827265828847885, 51.83850936591625, 54.7624296694994, 52.67807811498642, 49.65354301035404, 47.129498049616814, 44.802502915263176, 46.0800551623106, 50.89422583580017, 61.40612617135048, 61.63216084241867, 59.898211285471916, 58.943508714437485, 53.78433175384998, 52.72138059139252, 48.876066729426384, 63.32208216190338, 63.64072546362877, 67.74093344807625, 65.14213129878044, 74.27038908004761, 7.759164646267891, 0.9821723657660186, 2.376740165054798, 42.31457881629467, 64.856888204813, 57.55890101194382, 68.80856215953827, 51.30058743059635, 16.295362897217274, 48.986842185258865, 31.733104214072227, 55.297672748565674, 24.64291837066412, 0.03954825930122752, 0.15005537308752537, 0.006647531308772159, 0.1009437654283829, 0.03426536641200073, 0.06440376833779737, 0.07575090203317814, 0.05544141116843093, 0.07667800033232197, 0.06490571249742061, 0.007719745453869109, 0.015974871603248175, 0.009718507317302283, 0.03227737171982881, 0.0740701898757834, 0.015172397525020642, 0.011968592389166588, 0.051872341355192475, 0.1501767142326571, 0.13045250700088218, 0.14744265703484416, 0.129395124677103, 0.0587725595687516, 0.08874800070771016, 0.12822462420444936, 0.26922722056042403, 0.08951788986450993, 0.1375036669196561, 0.10888792196055874, 0.11650132553768344, 0.16375570121454075, 0.10265540287946351, 0.10573176085017622, 0.20439155196072534, 0.21817505999933928, 0.14989986346336082, 0.20952878723619506, 0.20604551711585373, 0.35155894642230123, 0.1515827575349249, 0.3449255711166188, 62.66511261463165, 59.817868396639824, 59.67450588941574, 69.67695236206055, 26.835847198963165, 74.6938307583332, 83.56323882937431, 76.58432811498642, 73.54196816682816, 64.22906309366226, 11.362179759889841, 0.1755615638103336, 4.102397616952658, 47.20902018249035, 80.44664606451988, 83.70795026421547, 75.49282148480415, 74.9532276391983, 77.43790671229362, 75.12351170182228, 79.56812560558319, 74.17309910058975, 72.09941357374191, 76.10473304986954, 57.495528012514114, 55.106592401862144, 53.36171083152294, 56.251132786273956, 53.35320308804512, 52.845280542969704, 52.05025680363178, 50.23288272321224, 52.79153622686863, 53.4360196441412, 53.98914456367493, 53.32436643540859, 48.36523354053497, 51.80326245725155, 50.717546716332436, 51.97445087134838, 50.8180171251297, 49.24122713506222, 51.48030638694763, 52.30708882212639, 52.93973967432976, 51.67745120823383, 52.0071405172348, 50.117832496762276, 48.81115481257439, 49.50681768357754, 50.71969360113144, 52.94849440455437, 49.026698246598244, 49.27828274667263, 51.13575227558613, 55.03942720592022, 63.36254619061947, 64.73982408642769, 65.91739609837532, 67.76813238859177, 62.74816855788231, 58.4192318469286, 57.839128375053406, 61.52149558067322, 59.484569281339645, 68.32408055663109, 66.63416683673859, 44.757722318172455, 64.48440179228783, 62.80645363032818, 60.18314279615879, 58.217952847480774, 58.559041544795036, 54.87712271511555, 56.08101971447468, 53.330826088786125, 52.09714248776436, 49.63382586836815, 49.98483583331108, 47.06734098494053, 47.45461620390415, 46.02313041687012, 47.2774925082922, 46.13954097032547, 48.00719775259495, 49.011495262384415, 46.22724786400795, 46.50157034397125, 47.60238267481327, 48.57614502310753, 47.80854441225529, 47.96094663441181, 46.794922202825546, 45.110711976885796, 48.870382234454155, 48.56555499136448, 46.43763117492199, 48.284533470869064, 48.2010405510664, 52.01441332697868, 48.898500725626945, 54.020861461758614, 55.5246801674366, 58.48117232322693, 53.760674223303795, 52.57929861545563, 49.84222948551178, 47.406005412340164, 48.826597183942795, 53.00746724009514, 63.48395727574825, 62.69143380224705, 60.160260424017906, 61.177009865641594, 56.5250638872385, 55.75808644294739, 53.403603583574295, 66.84960007667542, 65.61892211437225, 70.32667949795723, 66.60028785467148, 76.344895362854, 9.029741417616606, 0.7947319268714637, 6.292688911780715, 47.87547782063484, 74.5320126414299, 64.47630822658539, 76.37913152575493, 52.86960683763027, 20.44612716883421, 56.02368839085102, 39.37324024736881, 66.4786259829998, 35.54714575409889, 0.31683492532465607, 0.22684776806272566, 0.18027029786026105, 0.2811078471131623, 0.14192579837981611, 0.15219495515339077, 0.21738725539762527, 0.12075123420800082, 0.2625399059616029, 0.13046877487795427, 0.18684817536268383, 0.15923401806503534, 0.10441150981932878, 0.09172682563075796, 0.36135413800366223, 0.1953766989754513, 0.11786470277002081, 0.1345500972820446], [0.05711639023502357, 0.032047454369603656, 0.017009913426591083, 0.06091722534620203, 0.03527181514073163, 0.13441158283967525, 0.01380130566758453, 0.047437341054319404, 0.03496366429317277, 0.06547686934936792, 0.01766188088367926, 0.07673533124034293, 0.0246279387283721, 0.06605888382182457, 0.039413162448909134, 0.07215274003101513, 0.07690695289056748, 0.04032967772218399, 0.02447937375109177, 0.0997760851169005, 0.005900849109821138, 0.23303760623093694, 0.2675307006575167, 5.116100572049618, 60.20306892693043, 32.87659965455532, 39.93458792567253, 18.938276879489422, 34.96386185288429, 78.18093404173851, 64.48414340615273, 59.40225809812546, 64.76013779640198, 19.33175716549158, 0.27757172123529017, 0.27151107613462955, 9.687678012996912, 52.17174008488655, 77.01525539159775, 79.1679234802723, 75.03251418471336, 71.96512877941132, 74.20754805207253, 71.95706561207771, 70.79544514417648, 71.39918714761734, 63.30981642007828, 54.20766323804855, 51.59225217998028, 48.806823045015335, 47.830476835370064, 48.456964418292046, 45.76781451702118, 49.212196692824364, 46.076483353972435, 48.305945321917534, 49.813430830836296, 45.60303255915642, 48.54215584695339, 46.87041275203228, 48.11980091035366, 46.82517237961292, 47.47769996523857, 46.80930823087692, 46.34581670165062, 47.21390672028065, 46.140642911195755, 45.27547873556614, 43.63305106759071, 45.25159701704979, 43.708180636167526, 45.48048533499241, 45.000924468040466, 45.96651345491409, 43.82658988237381, 47.277921885252, 45.21205633878708, 47.30730950832367, 54.9163556098938, 56.59750320017338, 60.37190146744251, 61.05091743171215, 61.06067530810833, 59.74954046308994, 60.677644461393356, 58.80637787282467, 57.122319638729095, 60.28444916009903, 58.557574823498726, 61.56270056962967, 58.98253262042999, 59.10043269395828, 57.66592986881733, 54.01928074657917, 53.59640143811703, 50.49152724444866, 47.70325966179371, 49.9721635133028, 48.68715226650238, 45.48624962568283, 45.49552872776985, 48.500396087765694, 45.06215438246727, 43.73047024011612, 43.27602982521057, 41.828026324510574, 42.014854699373245, 43.384810388088226, 42.46315084397793, 44.55652691423893, 42.298486679792404, 42.410265281796455, 40.480504631996155, 43.82136516273022, 42.988936230540276, 42.185416147112846, 42.6539272069931, 44.106676653027534, 44.1433484852314, 42.491102144122124, 42.29172304272652, 42.392539232969284, 43.991185650229454, 42.450653314590454, 45.53713649511337, 48.66973400115967, 50.49557402729988, 48.918472453951836, 47.21359893679619, 46.33088730275631, 46.694539189338684, 49.05850253999233, 60.04122421145439, 61.01556412875652, 63.42415228486061, 63.21659982204437, 61.36930614709854, 57.787006571888924, 54.21463966369629, 51.32514551281929, 53.93979661166668, 63.05141508579254, 65.34499481320381, 64.09577384591103, 63.89173239469528, 2.0540987653657794, 0.31172541668638587, 2.006761855445802, 37.204480022192, 60.95684967935085, 55.33561371266842, 56.18274785578251, 16.101128719747066, 22.552698031067848, 42.55627244710922, 37.66454793512821, 56.95294752717018, 5.121243121102452, 0.20767552574397996, 0.10600849287584424, 0.051231815959909, 0.05771702890342567, 0.06055345795175526, 0.08583544957218692, 0.039534577808808535, 0.00971368985119625, 0.06185049831401557, 0.07051179214613512, 0.015492802158405539, 0.04431681416463107, 0.023098492965800688, 0.08347007649717852, 0.023623781380592845, 0.05138746288139373, 0.009941435491782613, 0.053817480729776435, 0.02801235477818409, 0.02830868321325397, 0.14341307716676965, 0.07858657409087755, 0.03347232224768959, 0.0881378588383086, 0.025106609136855695, 0.05926673344220035, 0.028517523569462355, 0.02231565518741263, 0.0722009722085204, 0.07061896569211967, 0.03348416321387049, 0.04941295301250648, 0.014043269929970847, 0.11517627281136811, 0.06882771805976517, 0.04997378659027163, 0.06756711343768984, 0.09405727323610336, 0.025312679426860996, 0.1319845818215981, 0.43634795292746276, 6.745327273383737, 68.22585582733154, 34.34634558856487, 54.33310590684414, 23.473413325846195, 40.13344645500183, 86.97150394320488, 72.49965369701385, 67.52525702118874, 71.55268371105194, 21.84325709939003, 0.32783732400275767, 0.4797090293141082, 9.243819080293179, 54.522734731435776, 78.68227154016495, 78.92674282193184, 78.59309792518616, 77.14038267731667, 77.88891211152077, 72.2022208571434, 74.01134938001633, 74.62935581803322, 65.18054723739624, 55.935016348958015, 53.85984510183334, 51.169999837875366, 49.124584794044495, 50.13481758534908, 49.14607264101505, 50.11511944234371, 48.534012883901596, 50.26808403432369, 54.43732291460037, 48.98611642420292, 50.429822355508804, 48.98395054042339, 50.129589065909386, 49.09905396401882, 50.6722417473793, 47.75740295648575, 47.185632437467575, 47.63235166668892, 50.844433307647705, 49.14413094520569, 47.35421799123287, 48.25910523533821, 47.05248758196831, 47.09625743329525, 47.50666581094265, 48.50928381085396, 48.152604550123215, 49.55908767879009, 50.213754549622536, 50.61982735991478, 56.15089416503906, 61.18036508560181, 63.47790040075779, 65.30663967132568, 63.8401235640049, 65.65219312906265, 61.68411925435066, 61.32842034101486, 58.90281669795513, 64.35551270842552, 60.27260519564152, 71.49181097745895, 70.24429231882095, 62.77169689536095, 59.63560737669468, 57.24531143903732, 57.60066457092762, 54.31761413812637, 50.60674086213112, 50.89434362947941, 51.48678883910179, 48.64234887063503, 48.915531411767006, 50.9126016497612, 49.94304947555065, 46.320137679576874, 46.10240936279297, 45.04438653588295, 46.34216129779816, 45.63428968191147, 45.280809849500656, 47.21972420811653, 45.525672510266304, 43.5837297141552, 43.43258522450924, 46.53516814112663, 46.714974492788315, 45.46490237116814, 45.047768354415894, 47.54268407821655, 46.86199240386486, 45.255974382162094, 44.65099364519119, 44.98661443591118, 45.91578237712383, 46.1247293651104, 48.90619531273842, 50.59661440551281, 52.919277772307396, 51.25298738479614, 49.68290403485298, 47.93051786720753, 48.21970134973526, 51.97784788906574, 63.10638293623924, 63.77570182085037, 64.871297031641, 65.3302364051342, 62.661248221993446, 61.47069230675697, 56.75677925348282, 54.430791065096855, 58.33885855972767, 64.5522129535675, 66.72162294387817, 67.43785411119461, 68.309086561203, 2.4944089259952307, 0.7733944687061012, 2.455677129328251, 41.44781872630119, 67.41831555962563, 61.16923548281193, 64.09173846244812, 24.370860569179058, 27.762440778315067, 48.15872982144356, 38.96728903055191, 64.83994111418724, 4.697832791134715, 0.1889360891073011, 0.13085402373690158, 0.08065082074608654, 0.04829499659535941, 0.04616688813257497, 0.0444631211576052, 0.10817131900694221, 0.06592861464014277, 0.04683033475885168, 0.11557183010154404, 0.057794553649728186, 0.06284552539000288, 0.03223053106921725, 0.0172346153340186, 0.061067770002409816, 0.043939394963672385, 0.05230120994383469, 0.04237226479745004, 0.09472514677327126, 0.07176041108323261, 0.2343127049971372, 0.1825671410188079, 0.11111319981864654, 0.3968350309878588, 0.19416024471865967, 0.17636492382735014, 0.10831459061591886, 0.09432835009647533, 0.21344469976611435, 0.22591864370042458, 0.08986149681732059, 0.13691023079445586, 0.11007084598531947, 0.24870882625691593, 0.20316311944043264, 0.10786483428091742, 0.17729891667841002, 0.21382632694439963, 0.1806999568361789, 0.33277827606070787, 0.5860127485357225, 13.756480682641268, 83.72525453567505, 45.24090439081192, 59.566625878214836, 29.26740512251854, 49.356870129704475, 94.23134878277779, 75.9576353430748, 72.19777509570122, 80.2474607527256, 25.02303097397089, 0.4921703418949619, 0.9807644819375128, 12.60606961324811, 57.04451501369476, 80.59117510914803, 84.80152398347855, 81.19988724589348, 79.07175824046135, 81.49351269006729, 75.63106566667557, 77.88425356149673, 78.40552479028702, 68.67674723267555, 59.39595423638821, 55.81238552927971, 54.52808104455471, 50.42572617530823, 52.40850158035755, 51.940959468483925, 53.43995623290539, 51.27800904214382, 54.41018097102642, 57.81002193689346, 50.3571018576622, 53.08699697256088, 51.91492326557636, 53.827364444732666, 51.900449842214584, 53.52239280939102, 50.18732316792011, 49.02376860380173, 52.909991070628166, 54.26356203854084, 53.725035935640335, 48.998066782951355, 51.294971331954, 49.4061154872179, 51.804090812802315, 50.38369283080101, 51.69259339570999, 51.7747487872839, 52.329097241163254, 51.904625818133354, 52.537139877676964, 60.272852182388306, 63.78900870680809, 66.9265079498291, 67.04582914710045, 66.93919166922569, 66.86059668660164, 65.87606191635132, 62.273786813020706, 61.56257137656212, 65.38619220256805, 63.027776554226875, 67.78793692588806, 62.66007788479328, 62.31882959604263, 62.14837834239006, 60.544214621186256, 59.113348200917244, 54.200496822595596, 52.170748338103294, 53.920961022377014, 53.75200308859348, 51.18282034993172, 50.518851578235626, 52.254906222224236, 51.247568875551224, 48.2866233587265, 48.61089415848255, 47.44399957358837, 48.46055142581463, 49.17224943637848, 49.45664897561073, 49.62865814566612, 47.593631744384766, 47.46618278324604, 46.484448462724686, 49.7615560144186, 48.542235642671585, 46.93642280995846, 46.716748997569084, 49.30324740707874, 50.085975006222725, 50.54957292973995, 49.96095411479473, 47.608260959386826, 49.16553519666195, 47.44265824556351, 52.30400338768959, 53.62534448504448, 56.94796599447727, 55.07759615778923, 51.6278562694788, 51.22321218252182, 52.20744676887989, 54.56903524696827, 67.21647039055824, 65.74726402759552, 66.38748407363892, 67.64215394854546, 64.1466075181961, 63.32531578838825, 59.05788257718086, 57.011331394314766, 61.96242772042751, 68.49495738744736, 70.60041680932045, 68.55858877301216, 68.15828025341034, 2.9055853374302387, 0.7655726477969438, 3.1722350791096687, 46.61393031477928, 74.28858250379562, 67.28813454508781, 69.12412002682686, 23.467785827815533, 34.05050106346607, 61.6604845225811, 48.88699114322662, 76.5598726272583, 10.393507238477468, 0.4259785171598196, 0.33563192293513566, 0.19774091430008411, 0.1794747749227099, 0.15985065372660756, 0.14859055168926716, 0.15008231304818764, 0.10689919625292532, 0.14482370694167912, 0.20486689754761755, 0.1742248667869717, 0.304158478975296, 0.16787150379968807, 0.2020393148995936, 0.1724133882089518, 0.18819929973687977, 0.0790270313154906, 0.2570574532728642], [0.035177187601220794, 0.02616876532556489, 0.05487016525876243, 0.012298796154937008, 0.060387658450054005, 0.052883343159919605, 0.034029233574983664, 0.08671913223224692, 0.044206527309142984, 0.047068901840248145, 0.03827814034593757, 0.010629732005327241, 0.09481391505687498, 0.03451073156611528, 0.02171123713196721, 0.05016439979954157, 0.03289227075583767, 0.06844360468676314, 0.02421841236355249, 0.06774321765988134, 0.06285527721047401, 0.2078140847152099, 0.21561018278589472, 0.2037233518785797, 50.90507045388222, 50.30338793992996, 35.66544480621815, 30.788321010768414, 28.135134279727936, 61.99374184012413, 51.514386758208275, 60.53762957453728, 73.27707678079605, 31.39749862253666, 0.9474680561106652, 1.2604067358188331, 0.7691023615188897, 18.424770534038544, 51.815710589289665, 82.57436469197273, 78.82341876626015, 78.89296263456345, 75.31446665525436, 75.15597715973854, 71.99020743370056, 70.87351575493813, 61.74550496041775, 52.204201743006706, 51.53643697500229, 50.182668417692184, 50.85083596408367, 51.2612709403038, 49.78516034781933, 48.78375068306923, 51.17747783660889, 47.8562318533659, 49.19800825417042, 48.67845833301544, 46.9377451390028, 48.03170643746853, 46.71185106039047, 47.48104378581047, 48.52723404765129, 47.664307951927185, 46.20900124311447, 46.21506951749325, 46.9120205193758, 45.56252673268318, 45.96662364900112, 43.38832899928093, 44.41814213991165, 43.494768887758255, 43.27271640300751, 45.7757218927145, 45.08629448711872, 45.427162796258926, 48.92379976809025, 51.910173520445824, 58.58208350837231, 58.782450556755066, 61.127798706293106, 60.078735798597336, 62.45833531022072, 59.7188913077116, 60.40200725197792, 63.46334718167782, 60.92084661126137, 59.57488663494587, 59.79369789361954, 62.493301033973694, 57.9676678776741, 57.049112766981125, 58.249578550457954, 52.89910085499287, 52.14634224772453, 52.19498723745346, 52.03203298151493, 50.84595702588558, 49.75951932370663, 45.59561535716057, 47.53049433231354, 45.52971929311752, 45.50122082233429, 45.29075011610985, 44.061846658587456, 43.24862949550152, 42.24204830825329, 43.134130239486694, 44.56288777291775, 41.79665520787239, 42.64489509165287, 42.78145596385002, 42.22541660070419, 42.38461285829544, 42.844015806913376, 42.51225180923939, 43.728391751646996, 42.64407813549042, 43.73318709433079, 43.47472496330738, 41.55924014747143, 43.664334788918495, 42.059000730514526, 44.28907826542854, 46.48750349879265, 49.829131588339806, 50.815843641757965, 49.17436972260475, 46.73270434141159, 46.6223468631506, 44.88993622362614, 51.46937437355518, 60.88488534092903, 63.15953828394413, 65.91320872306824, 66.79968595504761, 62.97161936759949, 60.68371273577213, 59.685810282826424, 55.434131026268005, 63.72066177427769, 62.73245260119438, 60.83060145378113, 68.63903045654297, 47.417325004935265, 0.5008763575460762, 0.4947789019206539, 0.7828417711425573, 43.464446514844894, 53.19156356155872, 54.44195106625557, 28.86420115828514, 6.487101204693317, 41.6302203387022, 27.769270911812782, 47.83296190202236, 30.913290604948997, 0.2872990508330986, 0.10949162198812701, 0.005572623167608981, 0.04465180107217748, 0.024504369284841232, 0.06699220873997547, 0.016520645149284974, 0.06147381754999515, 0.10150624657399021, 0.0638573250034824, 0.008376952937396709, 0.057324321460328065, 0.041498630816931836, 0.046098981620161794, 0.04272618760296609, 0.02412141922832234, 0.019262212881585583, 0.0481850696814945, 0.042211318941554055, 0.016525578575965483, 0.07453550162608735, 0.07430563622619957, 0.05320774704159703, 0.02161910877475748, 0.03280571036157198, 0.058958378504030406, 0.05358571914257482, 0.06014033773681149, 0.02186587287724251, 0.02793411200400442, 0.015503089252888458, 0.01781825139914872, 0.07059077892336063, 0.024579845703556202, 0.024911672917369287, 0.012506018629210303, 0.04806786229892168, 0.021649586924468167, 0.11746860371204093, 0.03527813452819828, 0.1446030812803656, 0.3313768934458494, 0.5438261653762311, 59.83950823545456, 55.07757715880871, 38.92846651375294, 43.794025629758835, 33.36874544620514, 72.43365123867989, 62.38350212574005, 65.87393403053284, 80.83644434809685, 35.99710240960121, 1.4281141804531217, 1.8728836392983794, 1.2106683547608554, 18.80291484296322, 56.99706315994263, 85.6675811111927, 80.49670457839966, 81.63811013102531, 75.37822723388672, 77.60135874152184, 74.15570363402367, 72.80641883611679, 65.64178928732872, 54.05225157737732, 52.35242798924446, 51.582216918468475, 51.62385508418083, 53.36569681763649, 52.63076305389404, 50.19326604902744, 53.3371527493, 50.45661851763725, 52.89452210068703, 53.85324105620384, 49.85757686197758, 49.93504710495472, 50.99403128027916, 49.95806246995926, 50.28109833598137, 48.82019452750683, 50.17538420855999, 49.420729503035545, 49.74473051726818, 48.51345598697662, 47.51967631280422, 46.72641567885876, 47.00022518634796, 45.203324407339096, 46.09593831002712, 47.970571517944336, 49.875033125281334, 47.524008080363274, 50.558244064450264, 54.172378331422806, 59.769702181220055, 60.947882160544395, 66.37410879135132, 61.58065840601921, 65.38252919912338, 62.33355760574341, 63.253321051597595, 63.68066892027855, 63.17147724330425, 63.431349098682404, 65.5735145509243, 64.85298961400986, 66.7676916718483, 61.185046434402466, 58.2660810649395, 56.951192021369934, 56.36681377887726, 53.33804190158844, 55.43487198650837, 52.99512170255184, 52.640410736203194, 47.8907074034214, 49.015732035040855, 48.631804436445236, 48.38138647377491, 46.63416042923927, 46.508542969822884, 45.25324992835522, 45.88723070919514, 45.04594065248966, 47.29917034506798, 46.04760870337486, 45.34032605588436, 45.50844043493271, 44.86890435218811, 43.556158393621445, 45.51190584897995, 45.35628139972687, 47.387929782271385, 45.38498505949974, 46.48970738053322, 44.59276556968689, 45.1733174175024, 45.334447771310806, 44.22861211001873, 46.05599105358124, 49.55028735101223, 51.83672346174717, 53.15570868551731, 51.54324620962143, 49.508273005485535, 48.141421750187874, 47.45050482451916, 54.74726848304272, 63.476703464984894, 66.37841016054153, 68.00429731607437, 68.51526349782944, 64.31732475757599, 63.979408890008926, 61.44228883087635, 57.38218769431114, 64.35678943991661, 65.51337137818336, 62.04781673848629, 70.5689848959446, 50.78181266784668, 0.23627231625141576, 1.5329534048214555, 1.9494416937232018, 46.072041392326355, 62.535406574606895, 58.579484447836876, 37.343066185712814, 8.976223189383745, 46.663677245378494, 29.15010541677475, 52.58961886167526, 33.05454410612583, 0.39663194969762117, 0.11781015491578728, 0.029488575564755592, 0.013908506116422359, 0.01955481944605708, 0.025998127021011896, 0.026857441262109205, 0.05785863439086825, 0.04990642184566241, 0.023377649959002156, 0.036964628015994094, 0.032567328817094676, 0.029833299449819606, 0.04280572356947232, 0.06997015050728805, 0.0319385998591315, 0.02422170935460599, 0.05952335326583125, 0.010301677684765309, 0.1073129138967488, 0.1529352177749388, 0.14528379397233948, 0.14583626354578882, 0.11817054924904369, 0.1550658792257309, 0.08966617097030394, 0.2348738131695427, 0.14608939527533948, 0.08603964408393949, 0.10033136743004434, 0.10187984371441416, 0.16965773451374844, 0.17184612021083012, 0.18987336225109175, 0.11576410572160967, 0.1266773947281763, 0.19934332987759262, 0.17765615688404068, 0.2436711871996522, 0.12455424381187186, 0.2789779723389074, 0.3477952483808622, 1.2055743718519807, 74.70409780740738, 68.96404221653938, 52.60938160121441, 48.9677520096302, 39.699631333351135, 77.5284406542778, 65.06549701094627, 72.8457011282444, 89.34224233031273, 38.60612981021404, 1.6682933550328016, 2.2102122008800507, 1.8766442500054836, 20.373741053044796, 60.81176586449146, 89.9735176563263, 84.71122562885284, 84.27624776959419, 79.81277167797089, 82.11053118109703, 78.10333460569382, 78.51241305470467, 69.03030306100845, 58.214901611208916, 53.984717801213264, 54.903953075408936, 54.52439144253731, 55.6347830593586, 55.819236561656, 54.498594626784325, 56.88143916428089, 52.496048882603645, 55.59092961251736, 55.78737147152424, 53.45006749033928, 54.84102085232735, 52.302130088210106, 51.59042067825794, 52.47787445783615, 50.40064372122288, 52.75680609047413, 51.46572656929493, 52.85654313862324, 50.95292128622532, 52.07191564142704, 49.43117134273052, 49.661682173609734, 49.51410189270973, 46.73627994954586, 52.13711254298687, 48.73235084116459, 50.14226518571377, 55.64415715634823, 56.03279650211334, 64.27751809358597, 62.784574404358864, 67.67866998910904, 63.42968478798866, 68.55092078447342, 62.79314674437046, 65.25512963533401, 68.04296404123306, 64.69460651278496, 64.53378394246101, 66.69645309448242, 67.24360093474388, 64.86918434500694, 60.4354340583086, 62.06678532063961, 58.156950920820236, 57.648089826107025, 56.471710950136185, 55.87531395256519, 55.92875808477402, 56.6897926479578, 50.40698558092117, 50.57471238076687, 50.01772686839104, 49.769053012132645, 49.12877216935158, 47.767586410045624, 46.45320273935795, 48.56916859745979, 48.03668797016144, 50.05876086652279, 48.13615523278713, 48.182797729969025, 50.18749415874481, 47.337772473692894, 47.60221928358078, 48.53854224085808, 49.01745714247227, 50.867216885089874, 48.31270515918732, 48.454125970602036, 47.72998362779617, 47.977722734212875, 48.65147218108177, 46.58540524542332, 48.77134054899216, 51.40555299818516, 54.98169310390949, 57.51304127275944, 54.29438978433609, 51.91645838320255, 51.460422053933144, 50.66298924386501, 56.925672590732574, 68.33601951599121, 69.78988230228424, 70.1334522664547, 69.74704340100288, 65.35309597849846, 66.88441380858421, 64.4679182767868, 61.18246637284756, 67.21119627356529, 69.27266925573349, 65.4884523153305, 72.44883522391319, 52.27172411978245, 0.93181521166116, 2.0114166056737304, 1.677659258712083, 53.36104966700077, 66.07973098754883, 65.23665502667427, 37.81954541802406, 11.200507935136557, 62.80413955450058, 39.75845977663994, 62.0390772074461, 51.23502194881439, 0.9894861420616508, 0.18873434368288144, 0.07459183063474484, 0.2182862485642545, 0.10784995422000065, 0.10891040161368437, 0.09094047563849017, 0.11784917704062536, 0.19939634890761226, 0.1408692027325742, 0.16036358167184517, 0.18169965944252908, 0.13990049221320078, 0.08924040084821172, 0.17199753317981958, 0.1334191087516956, 0.10424420004710555, 0.16353375453036278, 0.09394798456924036], [0.0698148412629962, 0.01609095277672168, 0.05247423796390649, 0.024549838817620184, 0.03733456636837218, 0.0714631586743053, 0.010448004159115953, 0.07360331961535849, 0.05506779547431506, 0.03053206302865874, 0.03045756253413856, 0.011444575829955284, 0.011016371463483665, 0.10216206021141261, 0.010608041811792646, 0.08125773427309468, 0.08602092711953446, 0.10009810299379751, 0.02312422322575003, 0.03453284385614097, 0.052622682342189364, 0.06359193299431354, 0.12253657434484921, 0.25530087877996266, 12.169085461646318, 60.154967308044434, 35.475287809967995, 40.85274785757065, 22.592297606170177, 38.20217728614807, 66.0934330523014, 60.25660425424576, 72.5128997862339, 47.65036270022392, 3.775564804673195, 0.8658028382342309, 0.4818621778395027, 4.580008238554001, 21.519922949373722, 73.75713542103767, 80.83743989467621, 78.4800311923027, 74.64436501264572, 71.88100889325142, 69.77637782692909, 69.75175514817238, 55.42466193437576, 58.04005019366741, 58.81817243993282, 58.2220034301281, 53.01027908921242, 52.82150141894817, 51.349889785051346, 49.893454536795616, 47.90651835501194, 49.7915668040514, 48.71887296438217, 47.77194857597351, 46.28625109791756, 48.65114539861679, 49.584496915340424, 47.52575598657131, 47.09306560456753, 47.515074759721756, 50.034274980425835, 46.095212548971176, 45.29840290546417, 46.32922299206257, 43.71383473277092, 44.83495697379112, 45.929024666547775, 44.917830526828766, 43.52926343679428, 44.25734616816044, 44.858781695365906, 47.64780543744564, 48.72179500758648, 53.570194244384766, 54.71791885793209, 57.004822343587875, 57.02835828065872, 60.507656782865524, 59.18507695198059, 60.45953996479511, 60.994068682193756, 61.281071081757545, 61.77165895700455, 60.57322986423969, 60.61084404587746, 62.17337340116501, 59.426918774843216, 56.80220201611519, 57.07338586449623, 55.110502392053604, 52.61516109108925, 53.64253856241703, 51.400430873036385, 51.8905171751976, 54.15054090321064, 51.22380115091801, 47.3313470184803, 43.92199516296387, 46.274011954665184, 43.813567981123924, 45.12909539043903, 43.96183602511883, 43.6429875344038, 44.03876669704914, 42.04961143434048, 42.76741571724415, 40.86357727646828, 41.577330976724625, 44.93969075381756, 42.99343518912792, 45.078299716115, 42.644564509391785, 43.54327328503132, 43.708085641264915, 44.57737639546394, 42.450113743543625, 41.47709235548973, 43.476374074816704, 41.97913281619549, 43.623380586504936, 46.19620352983475, 49.70917962491512, 49.76287454366684, 46.85303248465061, 47.28081353008747, 45.54939463734627, 46.600650027394295, 52.95307695865631, 58.63511346280575, 65.48149108886719, 65.66448926925659, 60.0682407617569, 65.26717498898506, 64.9013002216816, 59.32150103151798, 59.37737703323364, 58.89688901603222, 68.49940314888954, 60.18394075334072, 69.0527294576168, 27.170611135661602, 0.2287551766494289, 0.905231541255489, 2.4904338642954826, 51.08503259718418, 44.499875754117966, 51.630219742655754, 14.476505946367979, 25.424072854220867, 37.14708410203457, 27.698921486735344, 55.553110241889954, 4.433849081397057, 0.07217657039291225, 0.005910671434321557, 0.0451281634013867, 0.08354239878826775, 0.08026457740925252, 0.05204275330470409, 0.05689347875886597, 0.060596472831093706, 0.09821387910051271, 0.010811663014465012, 0.017279457752010785, 0.047135769345914014, 0.0025159165716104326, 0.0860890859621577, 0.035692542369361036, 0.03440842279815115, 0.07104565607733093, 0.008974947704700753, 0.0034886298180936137, 0.014343296115839621, 0.1022183224267792, 0.08473731591948308, 0.01602481999725569, 0.028022434999002144, 0.01889605391625082, 0.029067900286463555, 0.0542928151844535, 0.03418273940042127, 0.043188779382035136, 0.0030211373132260633, 0.09942628865246661, 0.026805459383467678, 0.060187798080733046, 0.020129221338720527, 0.010116226112586446, 0.12930413737194613, 0.022625600176979788, 0.028687247177003883, 0.03439979162067175, 0.06562915805261582, 0.06351680538500659, 0.14892683364450932, 0.41519701131619513, 11.233060788363218, 69.33523669838905, 35.54213382303715, 43.67907039821148, 30.29708717018366, 54.83704246580601, 71.64755702018738, 66.94770321249962, 77.75993943214417, 54.5448799431324, 4.71536030061543, 1.5730419661849737, 0.8695538900792599, 3.723820843733847, 24.200529009103775, 79.93625745177269, 84.29808899760246, 81.26416459679604, 76.17046192288399, 75.46285629272461, 73.44703406095505, 71.76134571433067, 56.83141104876995, 60.33769190311432, 59.87913630902767, 58.79815511405468, 56.41654551029205, 55.995976477861404, 51.67745500802994, 52.1933077275753, 50.923780649900436, 52.884779423475266, 50.14736071228981, 50.43160825967789, 49.40366081893444, 50.9499916434288, 51.09898544847965, 50.30345253646374, 49.46503512561321, 48.46508838236332, 50.06779298186302, 49.61609601974487, 46.860461086034775, 48.54871429502964, 46.84323661029339, 50.15527568757534, 48.1118593364954, 48.28133784234524, 46.24453313648701, 48.98523487150669, 47.67240911722183, 50.64663492143154, 53.31041358411312, 55.40220133960247, 59.74501870572567, 60.88103994727135, 60.92357486486435, 64.06800493597984, 63.70940677821636, 63.98473620414734, 64.40131545066833, 63.10854122042656, 65.06196320056915, 64.219411611557, 62.20133610069752, 64.70953971147537, 62.106295600533485, 60.121293514966965, 57.621909230947495, 57.392059564590454, 56.9501356780529, 55.0520995259285, 54.684032276272774, 53.46247382462025, 56.87426894903183, 52.81807400286198, 49.96168367564678, 47.06037975847721, 47.41957828402519, 46.486899331212044, 46.19637452065945, 46.225648149847984, 44.78886544704437, 44.969579949975014, 44.54289324581623, 46.27069093286991, 43.41714285314083, 44.967170879244804, 46.68793514370918, 45.764003321528435, 47.42467761039734, 45.32833389937878, 44.670634791255, 44.62903842329979, 46.352261155843735, 45.076513811945915, 44.759489223361015, 45.7720360904932, 45.75640372931957, 46.81607186794281, 49.73309174180031, 52.069837152957916, 50.937516912817955, 51.2966850399971, 49.354871436953545, 47.250126376748085, 49.592430889606476, 56.83825448155403, 61.14443801343441, 68.58095437288284, 66.83104947209358, 60.47673024237156, 66.38990834355354, 66.50568053126335, 60.92549756169319, 62.108575478196144, 61.895783096551895, 71.00198686122894, 61.877749264240265, 72.75715827941895, 27.57828366011381, 0.4037039342802018, 2.9776259092614055, 2.5339123187586665, 57.69200026988983, 51.07782818377018, 59.47019845247269, 23.317669183015823, 24.628224559128284, 45.19914083182812, 29.922982044517994, 63.807551711797714, 4.915537359192967, 0.09214348217938095, 0.054598060523858294, 0.002860151334971306, 0.053731079897261225, 0.0755648678750731, 0.029243843091535382, 0.05061729912995361, 0.04544975825410802, 0.0267835882914369, 0.03284505903138779, 0.02044151522568427, 0.0676043247221969, 0.0169314962477074, 0.06410248606698588, 0.032256287304335274, 0.016706842579878867, 0.025421316859137733, 0.05292777183058206, 0.06010272198182065, 0.1749029225902632, 0.13302891718922183, 0.18307916354387999, 0.0973554739903193, 0.15303200867492706, 0.12618594453670084, 0.10557819565292448, 0.21904343215283006, 0.17085701547330245, 0.14402686298126355, 0.16549830848816782, 0.18441001244354993, 0.18290428386535496, 0.20001613127533346, 0.20748047449160367, 0.14758036995772272, 0.20974444050807506, 0.12699064041953534, 0.1688959644525312, 0.10743507140432484, 0.26845808839425445, 0.18792152870446444, 0.23369059228571132, 0.49692293687257916, 24.036666601896286, 84.95706483721733, 50.87911404669285, 59.25897918641567, 33.92062783241272, 53.79074200987816, 81.66224643588066, 73.30802232027054, 83.91822338104248, 62.17608645558357, 4.330880306661129, 1.7955930554307997, 0.9595498046837747, 4.678225368261337, 29.354612343013287, 83.76459002494812, 89.55854192376137, 81.8035152554512, 79.34108018875122, 77.0711275935173, 77.18088090419769, 76.7691045999527, 60.55075027048588, 63.11368614435196, 65.09183719754219, 62.33420357108116, 58.28359052538872, 59.02168191969395, 56.479899510741234, 54.6824249625206, 51.86553731560707, 56.54266074299812, 52.160549685359, 52.279901280999184, 52.03750468790531, 54.31750774383545, 54.986686035990715, 52.740371972322464, 51.52814581990242, 52.44613096117973, 52.034172266721725, 51.61573871970177, 50.07459841668606, 51.58466778695583, 48.8783124089241, 53.45927819609642, 52.28104121983051, 51.83225490152836, 48.261157125234604, 50.318894907832146, 48.97397607564926, 53.59422415494919, 56.436680629849434, 59.24276165664196, 61.96389824151993, 62.99644723534584, 62.55082994699478, 66.73854723572731, 64.43595439195633, 65.13938784599304, 65.46459719538689, 64.79558989405632, 67.37575024366379, 66.34155973792076, 66.55694738030434, 67.39511400461197, 65.0578062236309, 63.199417144060135, 60.80952398478985, 59.762311577796936, 57.93125823140144, 56.12136974930763, 56.61972060799599, 55.69490343332291, 60.08860386908054, 56.18152432143688, 53.59647363424301, 48.794595301151276, 50.49123466014862, 49.21821556985378, 49.184063002467155, 48.72518062591553, 48.10445353388786, 48.37575137615204, 45.916606932878494, 48.715050369501114, 44.88804392516613, 47.27416388690472, 50.56129530072212, 47.867950424551964, 50.46091228723526, 47.6333662122488, 46.81601867079735, 47.03302122652531, 49.653227627277374, 47.370864897966385, 46.89356490969658, 50.28110213577747, 47.468861639499664, 49.10207860171795, 51.690332517027855, 56.1075384914875, 53.978569731116295, 53.478318974375725, 52.442771941423416, 50.07744826376438, 54.14544157683849, 60.12373298406601, 62.57066868245602, 69.89947602152824, 68.69317755103111, 62.82311953604221, 71.52221694588661, 68.49493458867073, 63.96246939897537, 64.52341809868813, 65.02657949924469, 73.7303164601326, 63.464399725198746, 75.02010405063629, 31.868622042238712, 0.4692253621760756, 3.470786246471107, 4.004301130771637, 62.364769130945206, 54.45880316197872, 65.3090563416481, 21.1751826480031, 38.879456743597984, 59.577128514647484, 35.500643849372864, 79.93450954556465, 11.765597462654114, 0.2963681844994426, 0.13896799850044772, 0.21025088208261877, 0.18523059028666466, 0.16841266304254532, 0.1362018656800501, 0.15851584175834432, 0.1596274899202399, 0.3324272105237469, 0.06988990950048901, 0.1865974481916055, 0.16755831748014316, 0.10747942957095802, 0.16998411621898413, 0.12045085735735483, 0.11916399555047974, 0.15173820778727531, 0.10244009099551477, 0.11118390422780067], [0.029663260429515503, 0.008609849082859, 0.08217586000682786, 0.02269942717248341, 0.09699958449346013, 0.009613583406462567, 0.02926476052380167, 0.11915071110706776, 0.02788821202557301, 0.08854713843902573, 0.029173658185754903, 0.018543489240983035, 0.032828961848281324, 0.07464473834261298, 0.02601495336421067, 0.07410947917378508, 0.07832029892597347, 0.030537046550307423, 0.00639156874967739, 0.06714260496664792, 0.06351321339025162, 0.031307841127272695, 0.030720960021426436, 0.31861967174336314, 0.4214666155166924, 29.436822831630707, 57.75379255414009, 41.07629366219044, 34.617768824100494, 16.222184523940086, 67.83755466341972, 66.4065970480442, 67.89063781499863, 54.27040547132492, 6.330381464213133, 0.26377944101113826, 2.627374716103077, 1.843351386487484, 7.25808790884912, 53.86777527630329, 80.65130308270454, 78.49870339035988, 75.19614100456238, 74.98662784695625, 70.0104832649231, 65.23949727416039, 60.25340102612972, 66.32025048136711, 67.3613566160202, 72.0579881966114, 68.38373735547066, 59.806609600782394, 54.20860178768635, 50.83463743329048, 49.64403972029686, 49.48552742600441, 50.09078174829483, 48.44546623528004, 46.46350018680096, 46.54530979692936, 50.85446856915951, 48.63781191408634, 45.998465940356255, 47.50484950840473, 46.46149009466171, 46.808916851878166, 46.676490157842636, 46.09412580728531, 45.32327637076378, 46.614241898059845, 44.665702655911446, 43.65737736225128, 45.90764321386814, 44.621343836188316, 46.16103261709213, 46.14887706935406, 52.44967617094517, 54.5699205994606, 54.38655383884907, 56.480621472001076, 58.89776676893234, 57.423746064305305, 61.03098750114441, 61.96058101952076, 62.0648056268692, 63.228272795677185, 60.606717467308044, 59.51086767017841, 61.90833002328873, 62.419478595256805, 60.021856650710106, 57.34551586210728, 56.267544105648994, 54.46240536868572, 55.44828146696091, 54.32225748896599, 57.55363069474697, 54.98987786471844, 55.806910023093224, 58.84468361735344, 55.40375545620918, 49.06414523720741, 46.10262595117092, 45.46190433204174, 45.380641892552376, 43.40000957250595, 43.26693311333656, 43.52294437587261, 43.393804505467415, 42.11383938789368, 44.47678819298744, 43.163783848285675, 46.64249338209629, 43.84310379624367, 45.37971094250679, 43.833231925964355, 45.615199506282806, 45.223980098962784, 42.895157262682915, 43.680293932557106, 43.23785327374935, 44.99367065727711, 43.78455653786659, 45.06356790661812, 45.77570669353008, 48.36552232503891, 48.68886597454548, 48.88502664864063, 43.203993290662766, 46.049421206116676, 43.51759046316147, 49.35548700392246, 56.4669194072485, 64.23836499452591, 62.254791632294655, 66.38906478881836, 60.36716692149639, 68.84244874119759, 62.07139067351818, 63.942543268203735, 63.00420641899109, 68.81345629692078, 55.0019384175539, 65.9708820283413, 3.0836649192497134, 0.12264330260222778, 1.1355149187147617, 7.983590103685856, 48.590257465839386, 65.41048809885979, 38.01750339567661, 5.55989395827055, 41.73379138112068, 22.623588927090168, 44.52346868813038, 35.17942428588867, 0.7959200162440538, 0.13792238663882017, 0.11490305114421062, 0.030201150511857122, 0.023926395806483924, 0.03431130164244678, 0.041257499615312554, 0.05747477334807627, 0.028670266838162206, 0.05295690854836721, 0.06052904500393197, 0.015436138255608967, 0.04884030073299073, 0.021703667225665413, 0.018748707916529384, 0.02660019432369154, 0.05287100495479535, 0.016661178233334795, 0.07841529382858425, 0.038430562635767274, 0.021762250507890712, 0.09592799746314995, 0.04628793984011281, 0.0297916927956976, 0.06446829065680504, 0.05253936142253224, 0.04320617161283735, 0.0260903277376201, 0.004675422287618858, 0.036493264051387087, 0.016175687487702817, 0.03051685827813344, 0.040647543282830156, 0.12240815311088227, 0.02636751247337088, 0.07491831624065526, 0.04461935437575448, 0.03187746544426773, 0.01592857272044057, 0.0369526534632314, 0.03932065003027674, 0.014976373131503351, 0.09364875804749317, 0.31333029619418085, 0.7312267657835037, 38.97237315773964, 59.93304021656513, 44.1267965734005, 42.05926671624184, 27.63716720044613, 77.48377785086632, 71.85786053538322, 73.77058669924736, 60.24554304778576, 6.936405720189214, 1.5507377567701042, 2.9597815917804837, 0.07330129519687034, 7.973268907517195, 62.33716741204262, 83.24626743793488, 80.21623402833939, 76.91340565681458, 78.0659294128418, 73.197281062603, 66.71233624219894, 63.94663944840431, 68.11034202575684, 68.27568635344505, 75.69958359003067, 70.12212127447128, 61.89540311694145, 55.86643382906914, 53.935924619436264, 50.13692647218704, 51.017274633049965, 51.7135226726532, 52.71547190845013, 49.09193314611912, 50.491033270955086, 52.49116614460945, 51.07017919421196, 49.15916293859482, 51.14448420703411, 48.95700618624687, 49.822329953312874, 48.98039773106575, 48.90090599656105, 47.791832908988, 49.99842010438442, 46.890190690755844, 45.936715453863144, 49.937858954072, 48.91517423093319, 48.5218421369791, 50.709407553076744, 54.84763629734516, 56.723873019218445, 57.67546355724335, 59.175630658864975, 60.691422522068024, 61.42947591841221, 63.86661574244499, 64.36821162700653, 64.51101556420326, 65.86948826909065, 63.60700987279415, 62.193709909915924, 64.50732216238976, 65.77625647187233, 61.11043743789196, 59.78857956826687, 58.26010398566723, 58.697924092411995, 58.48548889160156, 55.96379600465298, 57.8259202837944, 57.410488575696945, 56.969655230641365, 60.971136912703514, 57.308118268847466, 50.9511885792017, 48.768038526177406, 47.813240960240364, 46.646270379424095, 46.58507466316223, 45.02689227461815, 46.29673853516579, 45.94540178775787, 46.55672438442707, 46.73514001071453, 46.57023265957832, 48.72382029891014, 46.40790916979313, 45.98110467195511, 46.83543562889099, 47.44927369058132, 47.07931034266949, 44.470480531454086, 45.32018333673477, 44.52293671667576, 47.176148146390915, 46.18256986141205, 48.20756480097771, 48.47902603447437, 50.52656516432762, 50.65291218459606, 50.15917047858238, 45.505400598049164, 48.7701778113842, 46.05880290269852, 51.12754471600056, 58.68321508169174, 65.10869309306145, 64.35843095183372, 66.85230553150177, 62.409986704587936, 70.81924706697464, 64.7912809252739, 65.44998317956924, 66.6606818139553, 71.24703571200371, 58.16347137093544, 67.88205027580261, 3.331122128292918, 0.414299636031501, 4.081953288987279, 8.822211753576994, 57.19190910458565, 63.48466783761978, 51.02740868926048, 9.866466969251633, 43.68703857064247, 27.412646748125553, 46.8928999453783, 43.11624459922314, 0.7383007986936718, 0.20431683253264055, 0.003508860531837854, 0.032246865739580244, 0.05064766410214361, 0.010915341972577153, 0.1287164751556702, 0.03178399565513246, 0.06793838023440912, 0.022754804376745597, 0.04212412401102483, 0.02811025333357975, 0.023387917572108563, 0.04411962552694604, 0.05237660472630523, 0.01390263851135387, 0.0171759875229327, 0.041754296980798244, 0.07502752327127382, 0.011187542258994654, 0.10935634330962785, 0.16407163348048925, 0.12207492138259113, 0.14397166203707457, 0.15769717865623534, 0.16038379777455702, 0.12787823419785127, 0.20284567319322377, 0.11280039834673516, 0.1292948011541739, 0.06740698023349978, 0.08871360958437435, 0.12647829134948552, 0.24589549284428358, 0.12436381613952108, 0.25974797608796507, 0.10044387701782398, 0.12695374083705246, 0.1462293791701086, 0.141473934345413, 0.13484377996064723, 0.15459832618944347, 0.2486093042534776, 0.4927812481764704, 0.48584228614345193, 56.048535257577896, 75.44321894645691, 61.82709418237209, 51.66665978729725, 26.844719722867012, 79.88607734441757, 81.22593104839325, 79.70736533403397, 67.92597591876984, 7.731897309422493, 1.7626928770914674, 4.591958122327924, 2.779322862625122, 8.742844462394714, 67.93956398963928, 84.2389489710331, 84.03030216693878, 80.89124500751495, 81.51211649179459, 76.33703738451004, 71.06782972812653, 66.14986762404442, 72.20439434051514, 71.87552198767662, 77.92137756943703, 73.29631134867668, 65.63689514994621, 59.08399097621441, 57.321782335639, 54.10390220582485, 54.39877398312092, 55.37095181643963, 54.816580563783646, 51.28197982907295, 51.6898575425148, 57.74465784430504, 52.26819410920143, 50.98504476249218, 55.4555656760931, 52.74223767220974, 51.29058636724949, 51.67424418032169, 51.997006461024284, 51.34816847741604, 53.169216960668564, 48.4835097938776, 48.05101320147514, 54.62645776569843, 50.67668370902538, 51.51524171233177, 51.89800277352333, 57.71065726876259, 59.47267211973667, 59.23182964324951, 62.55586087703705, 63.96259859204292, 62.36986465752125, 66.18738681077957, 67.35814198851585, 66.74971863627434, 66.76763847470284, 65.23353919386864, 64.73628267645836, 67.04430922865868, 67.49124884605408, 63.86347711086273, 61.8867851793766, 60.22393740713596, 60.688876658678055, 59.35805507004261, 58.30864258110523, 60.82665726542473, 57.91792094707489, 59.868626073002815, 65.10669440031052, 58.3273071795702, 54.819160625338554, 49.31369684636593, 49.78853456676006, 48.65120619535446, 46.7253365367651, 46.98421284556389, 49.475302174687386, 48.992853462696075, 48.387188762426376, 50.12209966778755, 48.78281593322754, 52.793531119823456, 48.990056812763214, 47.94263541698456, 49.094091430306435, 51.06734834611416, 50.97302220761776, 46.97781018912792, 49.211786314845085, 46.72606609761715, 50.93732692301273, 49.48189102113247, 50.20947977900505, 51.083535477519035, 53.083242774009705, 53.417195454239845, 53.941430523991585, 47.26079240441322, 51.61390341818333, 47.85244345664978, 55.563384890556335, 63.13817583024502, 68.48810255527496, 67.67161756753922, 67.65175983309746, 63.57191875576973, 73.62678721547127, 65.59081882238388, 68.05892318487167, 69.17317539453506, 75.24125218391418, 58.77743102610111, 73.06724444031715, 4.586908193305135, 0.2695856482023373, 6.2540739588439465, 10.748869869858027, 62.71041378378868, 75.73033913969994, 51.09394311904907, 9.279087837785482, 65.28870463371277, 35.48050493001938, 55.69060206413269, 53.43144468963146, 1.6654701065272093, 0.27413685398641974, 0.2453371009323746, 0.10365546171669848, 0.1340195507509634, 0.1683859308832325, 0.20729492272948846, 0.1028056135692168, 0.12811524647986516, 0.1352948573185131, 0.18242472287965938, 0.10540629940805957, 0.27735151117667556, 0.13104276673402637, 0.08464943821309134, 0.08291762176668271, 0.13236984552349895, 0.18443512672092766, 0.13764681236352772, 0.11832266725832596], [0.0547144515439868, 0.027641659435175825, 0.06392902389052324, 0.10209370098891668, 0.004239911013428355, 0.05337393988156691, 0.06786682977690361, 0.0028731233805956435, 0.038578350213356316, 0.019602003339969087, 0.07674546897760592, 0.02282362744153943, 0.026231738411297556, 0.07218480081064627, 0.026967759658873547, 0.04858884996792767, 0.09308741238783114, 0.03852470406854991, 0.008302612004627008, 0.020689566954388283, 0.02034696561167948, 0.04144677324802615, 0.021418693650048226, 0.13070446613710374, 0.2638612553710118, 10.399265829473734, 65.8931989967823, 32.39935286343098, 46.3042127341032, 22.308585830032825, 21.82203333824873, 80.02556025981903, 60.92040203511715, 70.12464433908463, 11.045271065086126, 0.1493384435889311, 3.060800121165812, 0.29973890050314367, 0.9996248292736709, 26.69725153595209, 85.61803936958313, 72.26637661457062, 80.65385654568672, 68.49058762192726, 74.33172538876534, 65.56453183293343, 65.17307683825493, 70.03795579075813, 72.32831329107285, 70.87399452924728, 71.05437085032463, 68.2932186126709, 56.1787124723196, 48.35497789084911, 50.329826921224594, 49.32185120880604, 50.74605278670788, 47.00028598308563, 49.65667024254799, 50.56255303323269, 49.49813514947891, 47.4423960596323, 48.829067051410675, 46.44710026681423, 49.06149297952652, 48.31082426011562, 46.299462988972664, 47.05244578421116, 46.57247453927994, 46.48738570511341, 45.80285623669624, 44.633108004927635, 47.782208025455475, 46.767214089632034, 46.58966861665249, 47.43315115571022, 50.06587028503418, 52.938246354460716, 53.5055673122406, 54.54079136252403, 53.70874620974064, 56.89404308795929, 56.229831129312515, 60.424863025546074, 60.50339721143246, 62.617231383919716, 60.56567206978798, 59.54688973724842, 62.52043537795544, 62.619047686457634, 60.19090577960014, 57.86623612046242, 56.2505704164505, 54.13786098361015, 54.48074698448181, 59.320224300026894, 57.4557289481163, 60.06913751363754, 60.45054964721203, 60.88051937520504, 60.47281265258789, 58.71013663709164, 49.14804853498936, 45.515291467309, 47.35024340450764, 45.1574494689703, 45.23747697472572, 44.179412350058556, 43.37567187845707, 44.87273074686527, 43.450942039489746, 42.33572468161583, 46.352458745241165, 44.165254309773445, 45.37070542573929, 43.073538690805435, 43.14510025084019, 44.153524339199066, 44.90639694035053, 43.51468741893768, 42.42934785783291, 43.42945039272308, 44.481902718544006, 43.594600930809975, 47.473440393805504, 45.41629537940025, 45.18412783741951, 44.78007651865482, 46.242895424366, 45.09386368095875, 48.59922498464584, 46.551051288843155, 52.008728832006454, 58.76145288348198, 63.973268419504166, 65.50258755683899, 70.11732593178749, 64.78958621621132, 67.15534687042236, 67.36591637134552, 66.4132010936737, 61.466440334916115, 67.15536206960678, 23.468507789075375, 1.221930356696248, 0.4654865706106648, 1.3454346545040607, 11.02038050070405, 50.745448619127274, 66.44577294588089, 11.95146068930626, 22.356733046472073, 37.080287486314774, 23.16352855414152, 60.82026220858097, 20.749768875539303, 0.1259408873738721, 0.11770272903959267, 0.05291424989991356, 0.07762551511405036, 0.006453387331930571, 0.04303547022573184, 0.009852159764704993, 0.01732000684569357, 0.025798678543651477, 0.03199079139449168, 0.026338746829424053, 0.01595928279130021, 0.07337849339819513, 0.05865588282176759, 0.0480610419617733, 0.14216049516107887, 0.02135630315024173, 0.016695298472768627, 0.02137703133485047, 0.02332904485228937, 0.05081484770926181, 0.008643918299640063, 0.0549815170961665, 0.04074036369274836, 0.04836760461330414, 0.0320630691567203, 0.06094130432757083, 0.02212412357039284, 0.0418676229310222, 0.02492440075002378, 0.039679493274888955, 0.021571431352640502, 0.02440854317683261, 0.07030098509858362, 0.03770860879740212, 0.019745432655327022, 0.0465977902058512, 0.10773873596917838, 0.06439885532017797, 0.06594175807549618, 0.05780201594461687, 0.04152819798036944, 0.01606608711881563, 0.16613143467111513, 0.45187964919023216, 13.387064505368471, 77.3970665037632, 34.852421432733536, 53.89396347105503, 22.83638320863247, 36.020797938108444, 90.22673606872559, 67.81111568212509, 77.27469027042389, 12.457600180059671, 0.7535217725671828, 5.141853215172887, 0.45638997748028487, 0.5913927254732698, 35.038725435733795, 87.48473480343819, 74.96245354413986, 81.1734102666378, 73.07060346007347, 77.74799287319183, 68.6894841492176, 68.30879777669907, 73.65850031375885, 74.95703503489494, 72.23431393504143, 74.29466977715492, 69.01120528578758, 56.66753724217415, 51.188083067536354, 53.285395726561546, 51.85346536338329, 53.75170290470123, 48.855745419859886, 52.1263325214386, 53.01913261413574, 52.521036341786385, 49.644009321928024, 52.01551906764507, 48.8272849470377, 50.26809923350811, 50.30578941106796, 50.02636380493641, 49.751190170645714, 48.572368025779724, 49.025626704096794, 48.56048606336117, 48.22929583489895, 50.5190035700798, 49.19917479157448, 49.544367268681526, 49.83734294772148, 52.62277588248253, 56.61547243595123, 58.2070018351078, 56.85344986617565, 58.38812671601772, 58.75107184052467, 59.61371675133705, 63.46396654844284, 64.03258323669434, 65.72873622179031, 64.44500550627708, 63.52410212159157, 63.74400772154331, 62.34667830169201, 62.60302394628525, 60.77418968081474, 58.78655433654785, 56.932208240032196, 58.787876665592194, 59.65799577534199, 59.43930231034756, 61.231669932603836, 62.11870953440666, 63.14572602510452, 62.31607474386692, 57.617965042591095, 51.46914258599281, 47.86980092525482, 48.727407306432724, 47.08649195730686, 46.69579692184925, 45.473904088139534, 45.6332029402256, 45.43481558561325, 46.2559325248003, 45.108576491475105, 48.742602691054344, 46.223109886050224, 48.65931116044521, 47.03716680407524, 47.57263407111168, 45.95689617097378, 47.40153305232525, 46.233050152659416, 45.39265684783459, 45.8307771384716, 47.8678098320961, 47.27873504161835, 49.87026818096638, 49.491698294878006, 48.021378591656685, 46.89780168235302, 47.87910282611847, 47.54892714321613, 51.11024424433708, 50.37770055234432, 55.5213363468647, 61.21567279100418, 66.17925524711609, 66.87534749507904, 70.807726085186, 66.33452251553535, 69.82154980301857, 69.03098702430725, 69.89494666457176, 64.35513272881508, 72.46641308069229, 21.27816092222929, 1.3715770142152905, 1.693053301423788, 1.3199735269881785, 13.453600835055113, 59.28376145660877, 70.94667702913284, 22.598468475043774, 20.84328755736351, 44.62199740111828, 23.24616651982069, 67.36429005861282, 21.820562817156315, 0.1271574158454314, 0.08755181450396776, 0.062248623435152695, 0.03426360752200708, 0.032903347309911624, 0.052676458362839185, 0.031789146160008386, 0.05393164901761338, 0.01725690388411749, 0.03123260961729102, 0.0486367370467633, 0.033293980450253, 0.02185416920838179, 0.091626116191037, 0.06872603640658781, 0.03088682260568021, 0.04714192917163018, 0.05061406336608343, 0.01418146988726221, 0.03749524134036619, 0.12336576852248982, 0.12851743114879355, 0.15248060779413208, 0.20154845842625946, 0.12233341141836718, 0.11769844684749842, 0.1684329385170713, 0.16807014704681933, 0.12307426775805652, 0.17452004860388115, 0.1725448967772536, 0.09146590877207927, 0.1097347421455197, 0.14111592230619863, 0.12320965775870718, 0.15264922374626622, 0.19473315303912386, 0.13063538703136146, 0.14779824967263266, 0.1494938344694674, 0.18175408855313435, 0.10444406783790328, 0.10411675102659501, 0.27861544804181904, 0.5174947064369917, 22.049614526331425, 90.51713168621063, 47.029666006565094, 66.21007159352303, 32.6192432641983, 32.24073797464371, 92.20540389418602, 77.09313601255417, 84.38176050782204, 14.65857032686472, 1.5919385896995664, 8.276852667331696, 1.612019205931574, 0.8697646006476134, 39.84078235924244, 88.7002743780613, 76.01752012968063, 84.50197085738182, 74.05706852674484, 82.37986072897911, 72.16109186410904, 70.86343869566917, 76.1125074326992, 77.61754587292671, 76.77686378359795, 75.26740998029709, 72.92514726519585, 59.46324482560158, 53.88914152979851, 56.65206827223301, 54.488038793206215, 56.13699831068516, 52.51961901783943, 54.53010633587837, 56.99177384376526, 56.59828595817089, 51.89236007630825, 55.164364501833916, 52.134707272052765, 53.034305199980736, 52.511107474565506, 51.75306335091591, 53.63414101302624, 51.96911595761776, 52.840735986828804, 53.073663488030434, 49.49312321841717, 54.20533396303654, 51.82927206158638, 51.63219563663006, 54.485766515135765, 55.87130516767502, 60.044074058532715, 62.30922371149063, 59.929988980293274, 61.877148896455765, 63.588542863726616, 61.640421599149704, 66.11142888665199, 66.90737217664719, 66.60889059305191, 67.96493142843246, 63.408728912472725, 66.38964995741844, 63.60943414270878, 66.18937030434608, 64.40028950572014, 61.36185094714165, 59.665382578969, 59.61837910115719, 61.53990179300308, 63.06103616952896, 63.03599551320076, 64.46293294429779, 66.23841807246208, 64.49971497058868, 61.21045187115669, 54.66130189597607, 49.88509498536587, 52.355517223477364, 49.41161759197712, 51.38868190348148, 47.72226624190807, 48.28145943582058, 47.40505166351795, 48.457477390766144, 47.49249257147312, 53.24771694839001, 48.69837686419487, 49.91459660232067, 49.23545524477959, 47.89907455444336, 48.578276708722115, 49.485052451491356, 50.0970172137022, 49.151776134967804, 48.10400515794754, 49.751577749848366, 50.00462517142296, 53.23834665119648, 53.87520767748356, 49.46298323571682, 49.98883701860905, 52.064475640654564, 50.48416703939438, 56.07616737484932, 53.002405911684036, 56.87057554721832, 64.63194027543068, 70.90128466486931, 71.2788400053978, 73.02000537514687, 67.99083083868027, 71.9640040397644, 70.93762591481209, 71.45100116729736, 67.27625638246536, 72.65383422374725, 28.128520734608173, 1.2375774420797825, 1.5659026242792606, 6.649432769045234, 14.44811386987567, 63.532742857933044, 80.43754175305367, 18.646051660180092, 31.251151375472546, 61.912555396556854, 30.503915771842003, 80.27795031666756, 32.29294717311859, 0.23096915159840137, 0.22380560083547607, 0.1576364561333321, 0.20822602120460942, 0.08139101657434367, 0.14069423399632797, 0.16802735481178388, 0.10918106287135743, 0.11629255939624272, 0.20454110956052318, 0.12639194988878444, 0.06858798951725475, 0.19191094354027882, 0.16646694479277357, 0.16547398088732734, 0.1824033193406649, 0.1316426447010599, 0.1346974284388125, 0.06728132721036673, 0.06130615154688712], [0.017006779708026443, 0.014226119346858468, 0.027686709654517472, 0.005906625337956939, 0.10532704545767047, 0.025043259411177132, 0.03983027541835327, 0.022126322182884905, 0.07221163687063381, 0.0746787287062034, 0.04280636552721262, 0.08619968080893159, 0.02202779836807167, 0.024653797008795664, 0.1145208821981214, 0.02391149533650605, 0.06954449170734733, 0.08637253442429937, 0.10736372132669203, 0.033937140469788574, 0.13387377810431644, 0.05757752740464639, 0.09619954187655821, 0.10076137521537021, 0.5691315012518317, 0.4968447145074606, 37.83722206950188, 60.50975427031517, 34.97344113886356, 60.91282904148102, 10.294742938131094, 45.22417388856411, 69.04567703604698, 75.3994756937027, 26.307434253394604, 0.8961521065793931, 1.0074269981123507, 0.8569179056212306, 0.5774605949409306, 2.9765614913776517, 71.21309593319893, 76.96885988116264, 77.5933563709259, 72.71238148212433, 72.99766257405281, 67.41101995110512, 71.74495339393616, 74.32361662387848, 69.69162717461586, 72.55261525511742, 73.65213185548782, 67.48391523957253, 57.86078341305256, 54.28565785288811, 49.37559932470322, 53.35545256733894, 50.46263739466667, 49.85383406281471, 48.578713685274124, 50.63021220266819, 50.51108479499817, 52.0796862244606, 47.63256445527077, 48.585291132330894, 46.126614063978195, 47.88963586091995, 45.40742665529251, 51.085781157016754, 48.05427722632885, 45.83563707768917, 44.82769176363945, 46.06798321008682, 46.385285183787346, 48.301256373524666, 45.76713055372238, 46.63218833506107, 49.08332280814648, 51.216665133833885, 52.76947841048241, 53.147926703095436, 51.85960963368416, 58.99633727967739, 57.02067509293556, 58.323556780815125, 57.93253116309643, 60.675816759467125, 61.42870455980301, 61.46483302116394, 62.760882675647736, 63.48383568227291, 62.51558683812618, 58.87824721634388, 59.323416128754616, 61.43583297729492, 53.7491000443697, 56.214943528175354, 65.06855964660645, 63.44970591366291, 60.185855850577354, 63.395771607756615, 61.72021731734276, 61.61312386393547, 53.46753515303135, 47.47923508286476, 46.34617008268833, 45.60352273285389, 44.41489711403847, 42.113915383815765, 44.48415979743004, 45.4816784709692, 45.645366087555885, 45.2101032435894, 44.86640028655529, 45.751509591937065, 46.83956600725651, 43.20210479199886, 43.92710208892822, 45.03967098891735, 43.893378898501396, 44.08785246312618, 44.66327838599682, 46.447753831744194, 44.85597364604473, 46.297620087862015, 45.80586567521095, 45.6793362647295, 46.38173997402191, 46.705756187438965, 43.66477556526661, 45.396950617432594, 47.46315434575081, 47.16928951442242, 50.18769174814224, 53.30140806734562, 59.032382145524025, 64.47112530469894, 66.46556228399277, 66.02195888757706, 65.28026148676872, 69.04164165258408, 68.47294896841049, 64.7658982872963, 39.27280403673649, 0.11388345155864954, 0.0633208041836042, 0.3376402339199558, 1.464796105865389, 16.74968171864748, 66.74131348729134, 33.815251886844635, 9.0015022829175, 39.81723502278328, 28.095783591270447, 36.15874953567982, 54.24055427312851, 3.8093309802934527, 0.12906955933431163, 0.12241860255016945, 0.08909560783649795, 0.03096222109888913, 0.0650510324339848, 0.049057557043852285, 0.11099663068307564, 0.01796105545508908, 0.023938422309583984, 0.036879674371448345, 0.0211444403976202, 0.042281344285584055, 0.033193950075656176, 0.02704048456507735, 0.06831731341662817, 0.04635669982235413, 0.15508740150835365, 0.029085478054184932, 0.06803189084166661, 0.02707904284761753, 0.057311352429678664, 0.04896745660516899, 0.02262895282910904, 0.07006102649029344, 0.09233451841282658, 0.018594177927298006, 0.015873394040681887, 0.02831615292961942, 0.03734496756806038, 0.058814528019865975, 0.003706964098455501, 0.061741406316286884, 0.003936428274755599, 0.01755880584823899, 0.11830191680928692, 0.04233581792504992, 0.055528435404994525, 0.030636887677246705, 0.09968164682504721, 0.05690062193025369, 0.06356939396937378, 0.03504222804622259, 0.0699818912835326, 0.09424454678082839, 0.4078428028151393, 0.5222509824670851, 48.109644055366516, 62.89563104510307, 36.8552977591753, 58.08206453919411, 14.359196741133928, 69.38325852155685, 71.67779579758644, 81.60788655281067, 30.479068905115128, 0.15999745053704828, 3.309541898779571, 1.9811427989043295, 0.5640203005168587, 4.574186475947499, 76.16685211658478, 78.47954481840134, 81.23573452234268, 76.37115955352783, 75.6176295876503, 68.61674085259438, 76.26176342368126, 77.01244354248047, 73.8823615014553, 74.35567170381546, 76.58495128154755, 69.1027119755745, 61.71002246439457, 55.57495906949043, 51.12548902630806, 54.20519337058067, 53.991834819316864, 52.9744204133749, 52.215099558234215, 53.20469185709953, 53.99232119321823, 54.081943184137344, 49.16770488023758, 50.48170477151871, 48.98232042789459, 51.31856046617031, 49.462173879146576, 52.206439822912216, 52.09439903497696, 49.80698637664318, 50.251235738396645, 49.56515595316887, 48.04695501923561, 50.47538571059704, 47.08314813673496, 49.76085685193539, 52.210813388228416, 54.80572834610939, 56.175224259495735, 57.26822800934315, 55.67636802792549, 60.395665392279625, 59.59395781159401, 61.40274815261364, 58.90370585024357, 63.23494903743267, 64.90330651402473, 63.656722605228424, 63.94315883517265, 66.88104718923569, 65.15793085098267, 59.86764192581177, 62.55372539162636, 60.953403264284134, 55.92414893209934, 59.71441134810448, 67.11271315813065, 63.940939754247665, 65.03579020500183, 67.17787206172943, 64.06494989991188, 63.741112276911736, 55.487210378050804, 48.5334999114275, 47.76929251849651, 47.29503616690636, 45.73030672967434, 45.34830182790756, 46.72231949865818, 46.7655573785305, 45.894184336066246, 45.88792987167835, 46.412879303097725, 49.02997367084026, 47.76406019926071, 45.709396451711655, 47.258702516555786, 47.83082261681557, 45.94118781387806, 46.60439282655716, 47.04366445541382, 49.25156258046627, 48.0605810880661, 47.049466744065285, 48.64088214933872, 48.44351314008236, 46.77319496870041, 49.20500747859478, 46.71162307262421, 48.778833746910095, 49.74799834191799, 49.93165008723736, 52.63900861144066, 56.286820471286774, 59.57246236503124, 67.68272817134857, 66.24297022819519, 68.30074980854988, 65.10498449206352, 72.37435162067413, 68.15448805689812, 68.42441037297249, 35.92599682509899, 0.04827126642339863, 0.5665405746549368, 2.1072161151096225, 0.6459241930861026, 21.004940383136272, 71.78431168198586, 45.67071072757244, 13.19456398487091, 34.958728328347206, 34.426190704107285, 36.28225810825825, 63.00307407975197, 2.973099877126515, 0.13851494702976197, 0.03073216459597461, 0.029884292416682, 0.03607697115512565, 0.050004099612124264, 0.03086153206822928, 0.06151387497084215, 0.025823043251875788, 0.07624180303537287, 0.029799171788909007, 0.08732137022889219, 0.02370207610510988, 0.025499721050437074, 0.013872044401068706, 0.04112939379410818, 0.03255995557992719, 0.045341653312789276, 0.03524415158608463, 0.02618954731588019, 0.024065951110969763, 0.11866239277878776, 0.09295753654441796, 0.13014246738748625, 0.11070221327827312, 0.22000127763021737, 0.09649237850680947, 0.09511367592494935, 0.2936656982637942, 0.19840442400891334, 0.16926423297263682, 0.11903613834874704, 0.25616717291995883, 0.09537852616631426, 0.21524243376916274, 0.3597459336742759, 0.1823514432180673, 0.14129109884379432, 0.22444006288424134, 0.2509638271294534, 0.12908646545838565, 0.20281506702303886, 0.14151331270113587, 0.1921323558781296, 0.20693079539341852, 0.9333132219035178, 1.4585471036843956, 64.5439749956131, 77.41323843598366, 53.27860549092293, 87.22428157925606, 15.138327833265066, 60.99532641470432, 80.30010312795639, 94.16201770305634, 32.97560714185238, 0.9742419538088143, 5.814129766076803, 1.8185809906572104, 0.7713064807467163, 6.5456014405936, 76.96520447731018, 79.16830345988274, 83.79523918032646, 81.00657641887665, 79.97177794575691, 71.11735627055168, 79.21214550733566, 79.23081770539284, 71.9935816526413, 78.43327850103378, 79.694012850523, 70.78646242618561, 64.91523787379265, 59.92465786635876, 54.076019302010536, 57.71758429706097, 57.38593429327011, 55.92020094394684, 54.856136441230774, 57.98202730715275, 56.343350037932396, 59.262334406375885, 51.453624218702316, 53.31098735332489, 49.74381096661091, 51.77066020667553, 50.635714307427406, 56.05350159108639, 55.26443213224411, 51.09237760305405, 51.452028304338455, 52.00647935271263, 51.30973353981972, 54.17688108980656, 49.47529837489128, 51.173925027251244, 54.53495867550373, 58.37485022842884, 60.09518891572952, 59.537606835365295, 58.0475015938282, 64.08951178193092, 60.77797047793865, 63.320851027965546, 61.854794695973396, 63.3633441478014, 66.77547365427017, 65.14283806085587, 64.89467337727547, 69.5485420525074, 67.09469452500343, 63.885637521743774, 63.451921194791794, 63.69780220091343, 57.901350036263466, 61.1588354408741, 66.91808760166168, 65.59305310249329, 66.02724820375443, 68.47712874412537, 63.639118149876595, 65.07368937134743, 57.45116539299488, 50.966148376464844, 49.524574130773544, 51.299588084220886, 48.35194185376167, 45.9950765222311, 49.52053874731064, 50.02018913626671, 49.08304542303085, 49.289735332131386, 48.729576990008354, 50.481822565197945, 51.421344950795174, 46.12856335937977, 49.69265051186085, 50.18893048167229, 49.76759769022465, 48.271431773900986, 50.47345161437988, 51.34346432983875, 51.01568631827831, 48.88582840561867, 50.610932037234306, 51.150499284267426, 49.59920972585678, 52.57348872721195, 50.85190370678902, 49.94030222296715, 52.411754205822945, 52.391714081168175, 55.715980902314186, 59.7054286301136, 62.751698568463326, 69.88406404852867, 69.1096656024456, 68.99911433458328, 67.32575252652168, 73.01087066531181, 70.8661137521267, 68.24832782149315, 43.95826041698456, 0.23265213472768664, 0.34955372277181596, 1.2280338979326189, 9.574696775525808, 23.08700256049633, 77.07124918699265, 43.87816831469536, 12.93454298749566, 61.07448376715183, 46.390627697110176, 48.04570108652115, 71.47635340690613, 7.784073734655976, 0.34450370469130576, 0.27000781148672104, 0.2648994605988264, 0.11186288771568798, 0.25845806405413896, 0.18864898185711354, 0.21218931244220585, 0.2155431965366006, 0.18567746708868071, 0.17024268046952784, 0.12362501554889604, 0.15786695235874504, 0.07533961863373406, 0.08002466332982294, 0.14387858187546954, 0.09907739018672146, 0.23015010257950053, 0.10224064622889273, 0.14512481109704822, 0.12536927039036527], [0.04083103558514267, 0.035493097602739, 0.03451016382314265, 0.04979899225872941, 0.04151495435507968, 0.0038402953350669122, 0.04986817526514642, 0.03562099933333229, 0.0513465037511196, 0.020197454396111425, 0.04292361743864603, 0.08994223506306298, 0.061689641515840776, 0.02283497673488455, 0.06577916836249642, 0.023040377236611675, 0.07320561751839705, 0.02757658792688744, 0.035790016045211814, 0.043120130721945316, 0.051999204079038464, 0.07097812063875608, 0.03883327422954608, 0.05201867803407367, 0.10276936707668938, 0.6075308157596737, 6.303791915997863, 69.07452508807182, 36.418910175561905, 42.75152117013931, 34.09758813679218, 12.414652034640312, 65.845777541399, 71.87894180417061, 51.16127550601959, 2.007873058319092, 1.3739921408705413, 0.9039917984046042, 0.2442621742375195, 0.3417588269803673, 27.772821821272373, 92.10671558976173, 73.67154121398926, 78.94507303833961, 72.32832849025726, 78.8088807463646, 70.33819288015366, 80.55270597338676, 75.83847373723984, 74.1601113975048, 72.20459192991257, 68.83427157998085, 58.31345312297344, 50.046768710017204, 49.60567697882652, 52.8632839769125, 49.776189029216766, 49.7630113363266, 52.03345790505409, 47.948471903800964, 47.283028811216354, 49.1068397462368, 48.27087700366974, 47.66417495906353, 47.226142063736916, 50.44317863881588, 50.075392574071884, 48.13221104443073, 46.211353316903114, 47.75117889046669, 47.79154032468796, 46.11452691257, 49.80116128921509, 49.17101450264454, 45.8188533782959, 46.216798424720764, 48.26034776866436, 50.00296086072922, 54.651935398578644, 52.992602437734604, 53.147941902279854, 54.48011241853237, 54.41817194223404, 57.16412499547005, 59.20827850699425, 60.04894159734249, 60.64754627645016, 59.88077022135258, 60.37187106907368, 63.20029489696026, 62.24363923072815, 59.08753618597984, 59.64804410934448, 61.64097256958485, 64.03721898794174, 55.02846099436283, 52.54069648683071, 64.77251753211021, 62.34578534960747, 60.76130077242851, 63.9816127717495, 62.27591089904308, 56.02898150682449, 47.77324050664902, 47.18090549111366, 44.89991828799248, 42.988533452153206, 43.30019652843475, 43.8440727442503, 44.19958546757698, 45.82342453300953, 45.90192832052708, 44.66141268610954, 47.99855701625347, 44.5582178235054, 45.89674159884453, 45.20001098513603, 44.19966906309128, 44.397608041763306, 45.68210631608963, 43.97788256406784, 43.80918301641941, 44.48170132935047, 48.53182800114155, 45.785339176654816, 46.47401802241802, 45.99020518362522, 47.53661200404167, 47.11981236934662, 50.35231411457062, 49.84024219214916, 50.61445064842701, 51.20049700140953, 54.940662905573845, 55.89812032878399, 62.37240672111511, 66.7326195538044, 68.90517577528954, 64.16320502758026, 66.97026640176773, 59.99145068228245, 57.01750226318836, 2.9337537009269, 0.3492126613855362, 0.1794278563465923, 2.734122625552118, 1.1965465312823653, 27.414768934249878, 74.01153177022934, 13.09232572093606, 23.64597536623478, 49.35625836253166, 29.29331213235855, 51.706747636199, 35.93528352677822, 0.12606133794179186, 0.05303891215589829, 0.08888693075277843, 0.05432047131762374, 0.042878049571299925, 0.00923458250326803, 0.02373648021603003, 0.024344894736714195, 0.06381376835634, 0.05200698920816649, 0.028836893834522925, 0.005558591474255081, 0.027451356072560884, 0.031388987554237247, 0.01153750848970958, 0.05377678506192751, 0.012735625205095857, 0.07161149915191345, 0.0382616015849635, 0.00999875341221923, 0.03789566340856254, 0.005672592315022484, 0.023763015706208535, 0.05230593742453493, 0.06734726703143679, 0.027959638173342682, 0.022605098347412422, 0.06688277906505391, 0.01916529767186148, 0.057064773864112794, 0.0462009861075785, 0.04576202431053389, 0.07612838802742772, 0.035610342092695646, 0.019692268906510435, 0.060755997474188916, 0.018573382949398365, 0.04369601505459286, 0.06621161781367846, 0.04311247917939909, 0.03476952959317714, 0.04484073331695981, 0.12113269811379723, 0.04648119138437323, 0.05096980072266888, 0.12479897442972288, 0.6661982426885515, 8.031102754175663, 78.99855136871338, 38.3968598395586, 54.487104043364525, 30.48391554504633, 25.96159391105175, 77.76522874832153, 76.7390938103199, 55.267205983400345, 2.652080040425062, 3.538012714125216, 3.830657573416829, 1.9851679704152048, 0.4197225091047585, 33.229129537940025, 90.64801186323166, 76.57940357923508, 81.76503092050552, 75.71388602256775, 80.81635862588882, 73.01022469997406, 82.50089943408966, 78.3375084400177, 76.69377744197845, 75.11038720607758, 73.26844364404678, 59.83185164630413, 53.313316628336906, 52.67134867608547, 56.363021582365036, 51.25606141984463, 51.86174891889095, 53.98732826113701, 52.460171207785606, 48.793736547231674, 52.64953404664993, 50.33785589039326, 49.674031510949135, 51.28899805247784, 51.78751230239868, 51.59282974898815, 52.255350798368454, 49.86498646438122, 52.53738306462765, 50.68744853138924, 50.27094528079033, 50.28462074697018, 52.39477291703224, 48.14397521317005, 49.000175669789314, 49.86113727092743, 53.65546926856041, 58.07547949254513, 56.397535130381584, 56.42141304910183, 56.71567305922508, 58.91198940575123, 62.09568277001381, 61.64566531777382, 63.02341438829899, 64.9466697871685, 63.66189792752266, 65.43363645672798, 66.43053576350212, 62.454584911465645, 62.53526598215103, 62.46579051017761, 64.40560922026634, 66.9842192530632, 54.682679548859596, 57.67633371055126, 68.1619280576706, 64.49266254901886, 63.684696704149246, 67.9454156756401, 65.14470756053925, 59.53962832689285, 50.43718636035919, 49.80917885899544, 48.0497782677412, 44.16111633181572, 45.84039442241192, 46.505670323967934, 46.97274126112461, 46.80694855749607, 46.60437382757664, 46.85138337314129, 52.11915850639343, 48.63440729677677, 47.698669508099556, 47.04494118690491, 47.06477992236614, 47.225575894117355, 48.97697031497955, 45.89590944349766, 47.78956823050976, 48.18647213280201, 49.76855143904686, 48.404937610030174, 49.536820873618126, 48.718378990888596, 49.121685549616814, 47.92622409760952, 51.78069166839123, 51.961402371525764, 52.98382870852947, 54.20035243034363, 57.519873306155205, 60.50225347280502, 64.13363501429558, 68.50998938083649, 71.30558297038078, 64.31943744421005, 68.861493319273, 58.822572603821754, 58.45602907240391, 2.803707104176283, 0.771224785130471, 0.643547479994595, 4.678341262042522, 1.2101000477559865, 33.34209747612476, 75.49531415104866, 25.910311862826347, 19.463560692965984, 53.500452786684036, 30.976600907742977, 56.14952623844147, 40.8524476736784, 0.18491813127184287, 0.02607939219160471, 0.04576661820465233, 0.06818414243753068, 0.04862154528382234, 0.09333483700174838, 0.028979065209568944, 0.02466864181769779, 0.010662238073564367, 0.027079712635895703, 0.0950423332687933, 0.01597330567165045, 0.03739742998732254, 0.0437733802391449, 0.06691831309581175, 0.024880205855879467, 0.012165520347480197, 0.04612720549630467, 0.04264792070898693, 0.02217434099293314, 0.04520976624917239, 0.17394221242284402, 0.11872310788021423, 0.17282428569160402, 0.2174830369767733, 0.10554605323704891, 0.1765955684822984, 0.14708535745739937, 0.061484764228225686, 0.13242488319519907, 0.11938185300095938, 0.17866446840343997, 0.12847312493249774, 0.07359038398135453, 0.18785703607136384, 0.18074996274663135, 0.13106889033224434, 0.2260581377777271, 0.19366751803318039, 0.1678306856774725, 0.14080586784984916, 0.1650965987937525, 0.20358749432489276, 0.09766935050720349, 0.202167498646304, 0.1868869154714048, 0.91008405899629, 17.363251894712448, 91.3284869492054, 51.29165790975094, 69.6831688284874, 47.20677450299263, 20.165472328662872, 77.9970771074295, 85.51550567150116, 61.996386498212814, 3.634224976412952, 7.640364496037364, 4.473346062004566, 2.2095063887536526, 0.6224972626660019, 35.976412519812584, 92.75065943598747, 78.92860472202301, 85.193632543087, 77.80055925250053, 86.64732053875923, 77.0498563349247, 85.3594708442688, 80.6617297232151, 76.28577813506126, 78.69822308421135, 76.3062134385109, 63.927921652793884, 54.019850715994835, 55.736499801278114, 59.66333068907261, 54.814574271440506, 55.13233222067356, 57.00210548937321, 53.81828673183918, 51.776804476976395, 54.397930428385735, 54.298098385334015, 52.44617275893688, 53.67765247821808, 56.88476778566837, 55.86984224617481, 54.07731883227825, 51.67414538562298, 54.62762050330639, 53.336195200681686, 51.947373524308205, 54.465384408831596, 55.57635739445686, 51.20865896344185, 52.45451711118221, 52.324982061982155, 56.46747037768364, 60.99306173622608, 59.46859493851662, 58.46177436411381, 59.1839712113142, 60.83155520260334, 63.487776070833206, 64.20770823955536, 64.88409474492073, 68.83587509393692, 64.97389152646065, 65.83918869495392, 70.05892306566238, 66.70827805995941, 64.94090169668198, 64.04658928513527, 66.79338589310646, 68.67392018437386, 57.79677964746952, 59.83047612011433, 70.81624522805214, 65.5642582476139, 65.26097372174263, 71.75731033086777, 66.03375345468521, 61.44135408103466, 52.521526515483856, 52.05057978630066, 50.13865537941456, 45.8846240490675, 47.7392665296793, 48.95176246762276, 49.20321397483349, 50.673358887434006, 51.26010440289974, 48.410272523760796, 55.188409611582756, 49.82671871781349, 51.305264979600906, 49.772054851055145, 49.00389187037945, 50.18592104315758, 51.09574422240257, 48.67604546248913, 50.317906960844994, 50.64587876200676, 53.95665630698204, 50.59544026851654, 53.0432803183794, 51.00579544901848, 52.889399975538254, 50.21490968763828, 55.8321862667799, 56.072785556316376, 56.95394687354565, 56.01507805287838, 59.20216463506222, 63.387488052248955, 67.46750012040138, 72.3332530260086, 74.06124070286751, 65.54899826645851, 68.98834571242332, 62.22663514316082, 63.0341412127018, 4.0307543613016605, 0.55452223517932, 0.36462626710999757, 8.127309791743755, 2.8110561473295093, 34.559020176529884, 87.24644958972931, 22.137406915426254, 32.539006769657135, 76.17778792977333, 42.19241537153721, 65.91010048985481, 56.07401289045811, 0.3598759579472244, 0.3524282982107252, 0.14375529630342498, 0.14552948938217014, 0.15400414791656658, 0.15904886706266552, 0.14750480448128656, 0.16487128275912255, 0.19937240722356364, 0.14044211158761755, 0.1474503308418207, 0.07914610891020857, 0.08084352681180462, 0.16151575109688565, 0.15056405594805256, 0.1666299204225652, 0.07213942590169609, 0.12679428298724815, 0.161512530175969, 0.1440154784359038, 0.1298695945297368], [0.13593729003332555, 0.10536334390053526, 0.01704299465927761, 0.007786861115164356, 0.042054640434798785, 0.05091893392091151, 0.09055181290023029, 0.10155158437555656, 0.03956662374548614, 0.021947518398519605, 0.04803298506885767, 0.04470073457923718, 0.030478832486551255, 0.030050177265366074, 0.028472963167587295, 0.04479240837099496, 0.008222222568292636, 0.11895943738636561, 0.013422226838883944, 0.09837362638791092, 0.03874271365930326, 0.0270537745745969, 0.0920415110886097, 0.1807843241840601, 0.14641383255366236, 0.31527181388810277, 0.2652285585645586, 45.42688921093941, 57.20800124108791, 27.172801718115807, 62.16089107096195, 13.132000342011452, 32.422383427619934, 75.03971099853516, 69.18945372104645, 11.860252283513546, 1.570873826276511, 3.049830822274089, 0.6636396737303585, 0.693651472683996, 1.0423422558233142, 51.25820070505142, 84.19750079512596, 79.00829404592514, 81.212677359581, 75.240917801857, 81.68515920639038, 74.61384505033493, 75.35875707864761, 76.76539599895477, 76.00787624716759, 68.26210588216782, 58.163414373993874, 51.90043844282627, 53.073614090681076, 51.46297171711922, 52.02368102967739, 54.29843656718731, 51.92369319498539, 48.70837792754173, 49.705159440636635, 49.72011923789978, 52.20626123249531, 47.971840649843216, 48.39465156197548, 49.51179921627045, 48.84228654205799, 48.59291732311249, 49.3092130869627, 48.56072165071964, 47.21328355371952, 48.04654464125633, 46.9645830988884, 48.85846987366676, 47.92102597653866, 46.98011286556721, 48.894172757864, 51.40736550092697, 54.89674486219883, 56.15768440067768, 56.828644797205925, 57.19621427357197, 59.354673251509666, 59.59459237754345, 61.91530264914036, 62.14773237705231, 64.93608355522156, 61.92421317100525, 61.861543133854866, 63.41461859643459, 63.204056695103645, 62.0547703653574, 61.793139204382896, 62.154032438993454, 65.87879776954651, 69.24959689378738, 56.92875422537327, 50.55865824222565, 58.369074538350105, 61.456287279725075, 63.89172479510307, 62.004130482673645, 55.88023468852043, 50.42740948498249, 47.97255881130695, 46.645730808377266, 44.43971358239651, 43.41783821582794, 42.918556407094, 44.17506918311119, 45.32761953771114, 45.972543731331825, 46.60112500190735, 46.497671753168106, 51.55919775366783, 54.49269354343414, 55.14511093497276, 49.34984810650349, 46.28822319209576, 46.64986878633499, 46.6832309961319, 44.44753356277943, 45.90171933174133, 46.083566173911095, 47.237305864691734, 45.28940498828888, 47.86466360092163, 48.00620220601559, 52.778567522764206, 57.86360666155815, 58.736332431435585, 59.93065394461155, 64.69846710562706, 64.09768894314766, 62.613260596990585, 63.95073562860489, 66.6704472899437, 71.00501909852028, 66.33590564131737, 59.30980145931244, 60.79742543399334, 32.08394318819046, 0.168253650481347, 0.18238141114125028, 1.643279178533703, 4.841791866347194, 1.9941451074555516, 57.561051696538925, 50.114701464772224, 7.089483356103301, 45.0600378960371, 44.23077039420605, 29.071905612945557, 54.43594738841057, 13.592818714678288, 0.22911458392627537, 0.08714663155842572, 0.0024084067399599007, 0.07852290524169803, 0.032579251419520006, 0.08714805648196489, 0.019406397332204506, 0.01726317874272354, 0.024203604662034195, 0.05764418339822441, 0.02573647172539495, 0.05046062062319834, 0.06344758527120575, 0.10347949850256555, 0.0701322800887283, 0.047093826869968325, 0.09345258615212515, 0.05325695143255871, 0.02671053498488618, 0.027547842692001723, 0.04167968516412657, 0.08096426681731828, 0.04668272529670503, 0.04481372656300664, 0.03960840294894297, 0.010646216960594757, 0.06564055001945235, 0.032649562490405515, 0.016008093843993265, 0.036658087628893554, 0.060963475989410654, 0.047235703241312876, 0.05256901764369104, 0.026783356370287947, 0.04096560180187225, 0.03390045611013193, 0.02829886831023032, 0.026085731988132466, 0.06370137751218863, 0.06281833309913054, 0.06583212059922516, 0.0615628864034079, 0.018073142018693034, 0.1217947828990873, 0.04896950122201815, 0.10836728310096078, 0.26629241241607815, 0.2965556806884706, 54.000099375844, 58.65973234176636, 34.19769376516342, 60.3267864882946, 12.338546868413687, 52.464354783296585, 77.91676461696625, 75.15476122498512, 13.188632503151894, 1.016445814166218, 6.343636102974415, 4.561112802475691, 2.300899322144687, 1.8113480787724257, 57.27673575282097, 85.11398121714592, 80.9172736108303, 83.04016649723053, 78.40186178684235, 85.67543148994446, 77.45547696948051, 76.60714209079742, 77.90166422724724, 79.32526543736458, 71.12710654735565, 61.729124039411545, 54.329784885048866, 55.06935440003872, 52.89146326482296, 53.76557596027851, 56.28302067518234, 53.12926970422268, 52.04985402524471, 51.88153825700283, 53.28548692166805, 54.63033735752106, 50.202271565794945, 52.14889571070671, 51.89971648156643, 52.37602472305298, 50.53015597164631, 50.2633722871542, 51.35827213525772, 51.311823427677155, 50.266191735863686, 50.24246580898762, 51.21077544987202, 51.206151098012924, 49.3023506551981, 50.65062090754509, 53.88734042644501, 58.42131033539772, 59.142770022153854, 58.87662090361118, 57.848244085907936, 61.099258437752724, 63.13002146780491, 64.59489226341248, 65.44465586543083, 65.18446862697601, 64.09847170114517, 62.12197355926037, 66.02314442396164, 63.793044090270996, 62.62706905603409, 63.52786771953106, 63.52907985448837, 68.31943720579147, 71.75107106566429, 58.26530210673809, 54.44131650030613, 62.5384996086359, 63.79682868719101, 64.95696723461151, 62.605277225375175, 59.34549294412136, 54.07169513404369, 49.740858525037766, 48.90175715088844, 47.98121854662895, 46.70550160109997, 45.34166358411312, 46.988780200481415, 48.657692447304726, 46.137967854738235, 48.40053744614124, 48.92096891999245, 53.235512003302574, 55.56278072297573, 56.29020608961582, 52.56093040108681, 47.9316084086895, 48.738555908203125, 48.11675347387791, 48.07757757604122, 47.966737523674965, 48.435791954398155, 48.53949598968029, 47.645871341228485, 50.193387642502785, 49.680608958005905, 56.274721920490265, 59.79918099939823, 60.84632121026516, 62.44227357208729, 67.40596622228622, 66.5728609263897, 65.09949758648872, 66.68187707662582, 68.28030690550804, 71.33971273899078, 68.85624960064888, 58.93162675201893, 62.59193994104862, 31.634155623614788, 0.264614891493693, 0.9830501780379564, 4.199852412566543, 1.5510126482695341, 2.732139606960118, 61.03295959532261, 61.830354407429695, 12.107067089527845, 32.754037231206894, 51.155670806765556, 32.19970017671585, 64.22037675976753, 15.809355676174164, 0.2427651733160019, 0.17161655909148976, 0.05784228487755172, 0.07406828997773118, 0.039135473052738234, 0.026254232907376718, 0.03194213248207234, 0.04961113241733983, 0.02087215383653529, 0.02748376937233843, 0.048371972152381204, 0.02821114831021987, 0.03556099298293702, 0.046071945180301555, 0.039142991008702666, 0.059349104412831366, 0.06648848342592828, 0.04899152074358426, 0.034053713316097856, 0.06945984976482578, 0.022700121080561075, 0.22795333061367273, 0.17618723883060738, 0.0963229758781381, 0.1035187061643228, 0.23319360567256808, 0.20147278904914856, 0.21199722978053614, 0.17355108575429767, 0.1197667456290219, 0.14251460350351408, 0.08293088394566439, 0.18147248803870752, 0.060481692271423526, 0.1377510989550501, 0.10962054788251407, 0.14066168339923024, 0.09738967215525918, 0.17783275834517553, 0.10214905036264099, 0.16705729358363897, 0.14830460218945518, 0.16973448742646724, 0.28832547075580806, 0.2713644871255383, 0.3717978479107842, 0.5105640564579517, 0.952908176695928, 68.56257855892181, 73.71235862374306, 44.70837436616421, 87.1054695546627, 18.168751671910286, 46.288872957229614, 88.4654925763607, 84.79289084672928, 13.799351882189512, 3.238085783086717, 10.297988913953304, 5.225520925596356, 1.622512936592102, 3.1198769761249423, 60.50676763057709, 88.37875083088875, 84.86843839287758, 87.2510777413845, 81.09333336353302, 88.66299837827682, 79.6421380341053, 78.37992176413536, 79.16341692209244, 82.4547091126442, 75.09490683674812, 64.64043661952019, 58.07506151497364, 57.55739629268646, 57.90353871881962, 57.43047550320625, 61.15477345883846, 56.682265251874924, 55.486773401498795, 54.761715307831764, 56.55776113271713, 60.627152770757675, 52.36662022769451, 55.82302875816822, 55.3313959389925, 56.224051639437675, 54.87843744456768, 53.95862840116024, 54.58572015166283, 53.570931404829025, 53.38630311191082, 53.43715198338032, 53.9229217171669, 55.617965161800385, 51.16509050130844, 52.99056574702263, 57.27678894996643, 62.11523272097111, 62.2634057700634, 63.63642409443855, 62.06867761909962, 64.86413821578026, 66.62323102355003, 67.02090248465538, 66.0537251830101, 68.68718907237053, 66.93273201584816, 65.18683210015297, 69.24769699573517, 68.31499144434929, 64.43177461624146, 65.92427372932434, 65.09053766727448, 71.21051967144012, 72.0551535487175, 58.578283712267876, 56.049280017614365, 65.80747559666634, 66.78077816963196, 65.22448047995567, 64.76073816418648, 60.51880918443203, 57.87793189287186, 51.58296547830105, 50.396114364266396, 50.42025446891785, 48.25599320232868, 47.18491427600384, 48.65167737007141, 52.17115871608257, 49.417754262685776, 51.66456609964371, 50.893758460879326, 55.38094148039818, 56.98971815407276, 60.48675410449505, 55.42035296559334, 51.59825585782528, 50.24540685117245, 51.576916202902794, 49.66430023312569, 50.89441202580929, 51.980663537979126, 51.690290719270706, 52.02315665781498, 52.658847346901894, 53.315630704164505, 60.035387724637985, 63.7904754281044, 64.10288706421852, 64.91440951824188, 70.18303200602531, 70.47194570302963, 67.98120975494385, 70.6525120139122, 71.46713510155678, 72.94542297720909, 70.21210044622421, 62.26285099983215, 65.70243403315544, 37.1242169290781, 0.2527418051613495, 0.4999166715424508, 4.5660805609077215, 16.350459940731525, 3.1873587425798178, 68.94685953855515, 62.088725343346596, 11.003630049526691, 65.16269579529762, 64.21872764825821, 42.30164431035519, 71.96943014860153, 26.114984080195427, 0.5586669221520424, 0.4357805661857128, 0.22490282164653763, 0.2250205262680538, 0.16024535754695535, 0.16827827494125813, 0.21629555616527796, 0.18592219770653173, 0.10213165442110039, 0.16525538871064782, 0.10634708291036077, 0.10787585517391562, 0.17310909228399396, 0.15313372743548825, 0.1738421560730785, 0.10394148543127812, 0.17985472484724596, 0.11037049553124234, 0.11061331140808761, 0.15275215962901711, 0.16673100093612447], [0.038859917331137694, 0.09876723925117403, 0.09827099478570744, 0.0746216946572531, 0.011217209612368606, 0.031232572509907186, 0.03824235769570805, 0.03637670604803134, 0.017340072663500905, 0.016213429407798685, 0.040198907590820454, 0.05795205965114292, 0.04042913293233141, 0.07663574986509047, 0.06068781636713538, 0.05381416704040021, 0.035331031103851274, 0.06879125634441152, 0.011635690916591557, 0.09115925335208885, 0.08290996280265972, 0.014033637780812569, 0.03605540063290391, 0.0928421993739903, 0.03376463195309043, 0.050632190323085524, 0.3424155683023855, 10.506239589303732, 78.21827083826065, 33.609078750014305, 54.17484439909458, 51.889962404966354, 12.767805084586143, 58.783366307616234, 78.5599485039711, 32.67515726387501, 1.040062615647912, 4.584997370839119, 2.7142558665946126, 2.2302045905962586, 0.1034492782491725, 3.46050922293216, 76.82674750685692, 80.47525852918625, 82.08390220999718, 80.92319369316101, 79.33052435517311, 78.66207182407379, 77.30952680110931, 78.39768201112747, 74.30645674467087, 67.35180392861366, 57.76059418916702, 52.219780907034874, 51.98495730757713, 49.64260719716549, 50.48199735581875, 52.332194074988365, 52.62524574995041, 53.51209156215191, 54.16263185441494, 50.79983130097389, 50.01371808350086, 51.2150464206934, 51.73966906964779, 49.34729844331741, 49.59777720272541, 51.89502373337746, 48.63052390515804, 48.623391687870026, 49.76716451346874, 49.823317900300026, 47.724519520998, 48.642899841070175, 46.75370581448078, 47.21142925322056, 48.47686015069485, 52.46009901165962, 54.751151874661446, 56.14129588007927, 54.761586114764214, 56.04374751448631, 58.36836397647858, 61.43446505069733, 63.176196590065956, 65.5162364244461, 58.970323875546455, 55.54076090455055, 57.23647691309452, 64.77111160755157, 65.24274230003357, 61.13364279270172, 61.64055839180946, 66.65354579687119, 64.31867748498917, 62.2648610919714, 65.24477899074554, 57.17267073690891, 57.25740619003773, 60.6306029856205, 61.69074609875679, 61.697532534599304, 55.66455066204071, 49.80146147310734, 48.170672580599785, 44.18797709047794, 43.63365903496742, 43.986667692661285, 44.103496223688126, 47.21468187868595, 45.89744836091995, 45.79952381551266, 47.30100564658642, 55.67815773189068, 60.458897799253464, 62.87626728415489, 62.24753022193909, 57.808198034763336, 50.274114310741425, 45.55265486240387, 46.33588783442974, 43.843221589922905, 46.10145941376686, 45.54044611752033, 47.54876375198364, 45.850338488817215, 47.25479632616043, 50.02132527530193, 56.037379056215286, 59.350683465600014, 64.94476228952408, 69.12274450063705, 66.74507528543472, 66.02600187063217, 65.89891389012337, 68.37840244174004, 70.78235104680061, 69.02547731995583, 67.18177065253258, 49.859632551670074, 55.1013258844614, 10.119692031294107, 0.2026716247200966, 1.4872673875652254, 2.9701201245188713, 2.559588490985334, 3.159175179898739, 68.16164687275887, 16.470719687640667, 18.596437722444534, 49.683781787753105, 37.2709384560585, 38.45253825187683, 59.27350200712681, 4.5729900151491165, 0.07002652404480614, 0.05376837281801272, 0.012706292745860992, 0.04275196239177603, 0.03326394573377911, 0.07440068307914771, 0.07494231729651801, 0.03128511285467539, 0.02422514920908725, 0.030331690577440895, 0.05713979757274501, 0.028140570066170767, 0.014268931990955025, 0.030303307139547542, 0.06484317913418636, 0.061388630128931254, 0.06295460625551641, 0.02194744418375194, 0.012193657021271065, 0.010000431593653047, 0.041187188544427045, 0.06057351449271664, 0.008364134191651829, 0.08033830978092737, 0.05940843540884089, 0.0789480445382651, 0.03919927177776117, 0.052876055269734934, 0.043133682338520885, 0.04784962264238857, 0.07513447417295538, 0.03151371289277449, 0.02347524608921958, 0.008034733800741378, 0.05610796739347279, 0.02559504435339477, 0.03631472929555457, 0.03575543567421846, 0.004170008123765001, 0.06590353747014888, 0.1123538555111736, 0.0806375956744887, 0.06562417824170552, 0.1504611794371158, 0.0614130764734, 0.028491049306467175, 0.06776263224310242, 0.4443442972842604, 11.749248839914799, 89.37604531645775, 33.270520716905594, 65.4534637928009, 40.18717557191849, 25.747897177934647, 74.91188585758209, 81.90215036273003, 37.94501468539238, 1.0436939145438373, 7.674636282026768, 4.924094025045633, 6.6409962717443705, 0.4074963979655877, 5.260349856689572, 79.6804627776146, 81.61480978131294, 82.73535445332527, 83.32610115408897, 82.97408044338226, 82.79959380626678, 77.34425693750381, 80.41686326265335, 76.49705439805984, 70.0486408174038, 58.51622924208641, 53.158695325255394, 55.35889506340027, 53.18955346941948, 53.24310779571533, 53.35199095308781, 56.60576395690441, 56.58040791749954, 55.92585124075413, 54.5562869310379, 52.9516938328743, 52.75075301527977, 53.58381651341915, 53.406879007816315, 52.63575978577137, 54.209251552820206, 53.080438524484634, 52.52039797604084, 54.31475289165974, 52.48739294707775, 51.11402124166489, 50.6603217869997, 50.91599866747856, 48.47312495112419, 52.01234623789787, 55.78713968396187, 58.765393272042274, 60.02435691654682, 58.7081341445446, 58.40189337730408, 62.721083611249924, 64.50388714671135, 66.06383264064789, 66.4359238743782, 63.93802911043167, 57.30693273246288, 59.50606092810631, 65.01323461532593, 66.48040428757668, 63.69075357913971, 64.25348818302155, 68.8241109251976, 66.42745032906532, 65.22670716047287, 69.56994250416756, 60.21816931664944, 60.4719652980566, 62.59428061544895, 64.0360714495182, 64.05768468976021, 57.59019233286381, 51.85066491365433, 50.997154712677, 47.688748240470886, 45.85870943963528, 46.06220752000809, 45.11107675731182, 48.237533792853355, 49.25614893436432, 47.41787597537041, 48.821950033307076, 55.95684997737408, 63.9025542140007, 66.35752648115158, 65.20338401198387, 59.148405119776726, 52.956466376781464, 48.30916754901409, 50.05376033484936, 47.34560765326023, 48.942217379808426, 49.014907479286194, 51.069309040904045, 48.44472147524357, 49.63631473481655, 52.12646171450615, 56.793280094861984, 61.732631251215935, 66.84918969869614, 69.57525461912155, 69.44727748632431, 68.87808322906494, 69.49521571397781, 69.130420088768, 73.92966896295547, 69.77050334215164, 67.450021058321, 53.96829508244991, 60.22058978676796, 10.100497361272573, 0.20815271185711026, 6.147393733263016, 3.1320978328585625, 0.9827894764021039, 5.269320700317621, 69.95133563876152, 27.500773519277573, 15.778174549341202, 54.1642239689827, 42.64591723680496, 44.15147624909878, 66.43235206604004, 4.557582316920161, 0.10405706008896232, 0.12496097042458132, 0.058406840325915255, 0.02066530243610032, 0.05443450601887889, 0.059489682025741786, 0.05410643592767883, 0.06561963629792444, 0.058437205298105255, 0.01511778287749621, 0.05255693176877685, 0.05941867333604023, 0.022627676335105207, 0.03828987370070536, 0.08379748236620799, 0.01120255312343943, 0.08131599286571145, 0.03659385474747978, 0.04237596440361813, 0.014658117015642347, 0.07166830313508399, 0.15703035896876827, 0.1974058197811246, 0.18963134789373726, 0.2117720028036274, 0.14801810350036249, 0.15289043658412993, 0.09082381002372131, 0.2563389058923349, 0.08704692401806824, 0.11602946804487146, 0.17096329102059826, 0.12406322406604886, 0.13444920972688124, 0.16111629753140733, 0.12076607716153376, 0.14022068440681323, 0.1764927661861293, 0.12318042456172407, 0.13543185777962208, 0.17994400521274656, 0.1980033377185464, 0.13856145000318065, 0.1879454852314666, 0.17554076883243397, 0.12598857778357342, 0.18994037818629295, 0.5784575664438307, 20.433468148112297, 101.45486757159233, 48.23137052357197, 80.94038397073746, 69.11411896348, 21.79767284542322, 70.65071851015091, 95.40510579943657, 39.42864887416363, 1.9774136552587152, 11.631196774542332, 6.183227235451341, 6.3826224859803915, 0.24673137377249077, 5.124032646417618, 83.37572649121284, 83.6190578341484, 86.19496241211891, 85.96231609582901, 85.54982542991638, 84.83165636658669, 81.50073990225792, 82.4187022447586, 79.69872459769249, 74.05502423644066, 64.76570829749107, 56.64874345064163, 56.59770078957081, 54.784852266311646, 55.84036722779274, 57.52449005842209, 60.39387188851833, 60.01006968319416, 61.82442672550678, 58.056586906313896, 57.32077918946743, 53.9200072735548, 56.755491122603416, 55.24811200797558, 57.97768034040928, 57.05110386013985, 54.909576773643494, 54.38295163214207, 58.187083303928375, 55.938025787472725, 52.71730720996857, 53.56040216982365, 52.45817631483078, 52.02627629041672, 54.12410952150822, 57.147101908922195, 61.39732964336872, 62.461367547512054, 61.75054728984833, 61.39514476060867, 66.99466869235039, 65.29324918985367, 69.81203511357307, 70.55037349462509, 66.70968398451805, 60.821611136198044, 60.98230831325054, 67.30676114559174, 71.72288417816162, 65.89143589138985, 66.95802345871925, 70.51309749484062, 66.74144268035889, 66.84111893177032, 69.43510293960571, 59.52269643545151, 62.084351778030396, 63.31786438822746, 66.28195613622665, 66.92884102463722, 60.920622423291206, 53.71289938688278, 54.613356068730354, 50.1235131919384, 48.021986559033394, 48.43127399682999, 49.48292076587677, 51.298763528466225, 52.17683181166649, 48.99223029613495, 51.86941310763359, 60.767692029476166, 66.11399754881859, 67.42520838975906, 67.60023459792137, 62.20785655081272, 56.18197649717331, 50.99982976913452, 53.009169548749924, 48.70301641523838, 50.58645375072956, 51.91479027271271, 54.41162869334221, 50.76701246201992, 54.68992196023464, 54.7493089735508, 60.88889792561531, 63.75311583280563, 70.28680443763733, 73.87782454490662, 73.33409652113914, 69.25883039832115, 73.35083842277527, 72.21513256430626, 75.88385090231895, 70.13358905911446, 73.06783720850945, 54.58488039672375, 62.89169445633888, 14.453980755060911, 0.3500040282960981, 6.595390643924475, 10.74715331196785, 11.163026746362448, 4.396395916119218, 81.6816557943821, 25.018552914261818, 29.165070913732052, 76.03334248065948, 52.09885999560356, 53.15993405878544, 77.44752019643784, 8.353723492473364, 0.26319124444853514, 0.47610326029825956, 0.1518779541947879, 0.1589002148830332, 0.2445435372646898, 0.3077799518359825, 0.18458248756360263, 0.13156443717889488, 0.1502829897799529, 0.22720128268701956, 0.17648556735366583, 0.1353148210910149, 0.13556105084717274, 0.16435059194918722, 0.1677704232861288, 0.1465150763397105, 0.18032560270512477, 0.1121854325174354, 0.1638166612247005, 0.0893451104639098, 0.17272221070015803], [0.02181275180191733, 0.03842112622805871, 0.028115088425693102, 0.08657176396809518, 0.08602247820817865, 0.020997782739868853, 0.03532534625264816, 0.12181900659925304, 0.061931021336931735, 0.07943788426928222, 0.06411077585653402, 0.029081546526867896, 0.04930654016789049, 0.06266041149501689, 0.045845783097320236, 0.050077004489139654, 0.010164797822653782, 0.038020856300136074, 0.06669715308817104, 0.054640489106532186, 0.10431698989123106, 0.06335722879157402, 0.0931630223931279, 0.020671215497714, 0.1477271519252099, 0.07162730689742602, 0.4623941006138921, 0.5204138997942209, 46.32502041757107, 59.92227539420128, 32.59857997298241, 53.11250880360603, 18.643144816160202, 20.57737972587347, 83.78493413329124, 50.012331157922745, 2.7783130668103695, 5.831979783251882, 4.626230858266354, 2.8604378225281835, 1.0555852577090263, 1.1049137357622385, 45.14646425843239, 93.5688391327858, 76.97595030069351, 80.48905178904533, 83.62782776355743, 80.40913447737694, 76.7780265212059, 76.42054170370102, 67.1750146150589, 59.39459390938282, 55.049337074160576, 57.76427999138832, 52.39399015903473, 53.97490292787552, 51.793945357203484, 55.96982628107071, 54.09852169454098, 56.22152857482433, 52.50689350068569, 53.5662804543972, 54.28642921149731, 57.21023552119732, 56.54756247997284, 56.231434643268585, 53.63015502691269, 53.71657378971577, 50.73675848543644, 50.702024549245834, 49.725207164883614, 47.407601326704025, 47.78809770941734, 47.94285960495472, 49.206280410289764, 47.994426637887955, 48.0590383708477, 53.57799142599106, 55.6906096637249, 56.538948342204094, 57.29767642915249, 59.870305582880974, 59.939192086458206, 62.81699426472187, 63.62306021153927, 65.44653296470642, 58.810569047927856, 54.27533000707626, 54.9640354514122, 61.405043229460716, 62.39862531423569, 63.29666532576084, 64.88455832004547, 62.27939911186695, 59.461888298392296, 59.363340586423874, 58.77693325281143, 68.6554379761219, 66.39697596430779, 63.68407353758812, 62.165678814053535, 58.37089464068413, 54.233904629945755, 52.04854689538479, 46.689865440130234, 46.85291849076748, 44.87692192196846, 47.3462650179863, 44.67625468969345, 46.009580343961716, 46.40704661607742, 49.168738424777985, 54.43829946219921, 60.27163624763489, 63.56631025671959, 65.42184948921204, 63.016988933086395, 61.92873112857342, 59.09480519592762, 47.98338443040848, 45.81297509372234, 47.81299017369747, 45.76704315841198, 46.45306974649429, 46.52605623006821, 49.2793732881546, 47.980234399437904, 50.49587421119213, 54.28797572851181, 63.00922594964504, 66.54878541827202, 66.77608922123909, 69.3425703048706, 65.67837372422218, 67.28227525949478, 72.05556392669678, 69.76563960313797, 71.44926846027374, 59.04798410832882, 57.67947234213352, 46.74538046121597, 0.05578108102781698, 0.11295316944597289, 4.369838191196322, 5.974406590685248, 0.8615316299255937, 17.976708076894283, 60.81704758107662, 12.488766107708216, 26.393879614770412, 51.80907994508743, 65.79266399145126, 50.68964101374149, 32.343252673745155, 0.21837094245711342, 0.11409167593228631, 0.010063406534754904, 0.13482003123499453, 0.024914676760090515, 0.1036435502464883, 0.038157270464580506, 0.018241409161419142, 0.005851111300216871, 0.04994966679078061, 0.08346967573743314, 0.02266339404741302, 0.018904169301094953, 0.0627394205366727, 0.018078969733323902, 0.02381079702900024, 0.029107974405633286, 0.03472924952802714, 0.041155424623866566, 0.03902343843947165, 0.05859883764060214, 0.04097956531040836, 0.03095713553193491, 0.05001513163733762, 0.040730441178311594, 0.008444458690064494, 0.07653877342818305, 0.0219734583151876, 0.009681441679276759, 0.09109589620493352, 0.06309058997430839, 0.06227482124813832, 0.07821819424862042, 0.02301760257978458, 0.03253641836636234, 0.06754595480742864, 0.05914207860769238, 0.08218075076001696, 0.02138772568287095, 0.04553392151137814, 0.02161649455956649, 0.06917109494679607, 0.04750598600367084, 0.03749590185179841, 0.049630669454927556, 0.05592773683019914, 0.07282525941263884, 0.18030255159828812, 0.2484269140404649, 0.5124095699284226, 56.957127302885056, 61.89972348511219, 39.951820001006126, 59.08260025084019, 14.919774010777473, 41.13536149263382, 86.77476570010185, 57.183880135416985, 3.372664824128151, 6.207428136840463, 7.992755211889744, 6.75820573233068, 2.5526526756584644, 0.5989645316731185, 47.20871239900589, 95.32299980521202, 77.62057811021805, 82.60647296905518, 84.29070219397545, 81.44409254193306, 78.48421096801758, 79.14161369204521, 69.13111165165901, 62.9193227738142, 58.7138794362545, 57.55432985723019, 54.963533878326416, 55.66921681165695, 55.20596466958523, 57.38267406821251, 55.60209721326828, 59.04866807162762, 56.92839704453945, 56.98767766356468, 55.99882252514362, 59.95327793061733, 59.60909239947796, 57.71620877087116, 56.01623699069023, 57.58336029946804, 55.02052702009678, 53.06820698082447, 52.80656822025776, 51.60808973014355, 50.62491528689861, 50.14225758612156, 51.40809506177902, 52.19010069966316, 50.83082623779774, 56.00539617240429, 58.332680091261864, 58.84849861264229, 59.86686296761036, 60.70158317685127, 63.3756060898304, 63.79850819706917, 66.97655886411667, 67.01360687613487, 61.35300502181053, 55.70836991071701, 56.47640369832516, 64.64587032794952, 64.01261910796165, 65.30054479837418, 67.1510910987854, 65.51998302340508, 63.32944616675377, 62.41020329296589, 62.22067326307297, 69.14932027459145, 68.65350008010864, 65.58521792292595, 63.8996359705925, 62.23015375435352, 56.51230037212372, 53.23672793805599, 47.67745904624462, 47.0461381226778, 46.34676665067673, 47.24904723465443, 47.95496955513954, 49.211983904242516, 48.88073667883873, 51.25823490321636, 56.96107529103756, 63.33561323583126, 64.87993776798248, 65.748191177845, 66.39097228646278, 64.49366569519043, 60.5818098038435, 50.56683920323849, 48.099035024642944, 50.039807483553886, 48.64460214972496, 49.01231221854687, 49.94313687086105, 51.922146677970886, 52.39015616476536, 52.49176651239395, 58.06857146322727, 67.19206809997559, 70.09210288524628, 67.37768813967705, 71.86605289578438, 68.66394951939583, 70.0806351006031, 71.49970695376396, 71.9081774353981, 72.57862865924835, 61.10613226890564, 64.1188158094883, 49.42615941166878, 0.10515439222217537, 0.37025747587904334, 6.3187887612730265, 4.025788977742195, 0.5795584386214614, 20.062085576355457, 70.52220180630684, 18.329663537442684, 27.21528723835945, 70.34982785582542, 65.74202790856361, 59.22333709895611, 36.01015470921993, 0.30557206249795854, 0.22808466106653214, 0.024685698226676323, 0.08019560962566175, 0.00843962823637412, 0.0894730344589334, 0.023501349278376438, 0.05227019188168924, 0.04392267066577915, 0.05837099459313322, 0.050018341426039115, 0.03381827809789684, 0.037073753410368226, 0.03403363451070618, 0.06064152861654293, 0.038092488393886015, 0.04164196921919938, 0.05725404749682639, 0.02823804745275993, 0.041039185744011775, 0.03142073292110581, 0.051443413394736126, 0.14037067245226353, 0.19009689713129774, 0.08937635488109663, 0.14552105858456343, 0.16823714511701837, 0.10619856431731023, 0.11825719499029219, 0.24988216173369437, 0.21155171853024513, 0.19587708462495357, 0.20473988639423624, 0.1722299589891918, 0.2421212859917432, 0.20029136416269466, 0.2953785454155877, 0.13884744403185323, 0.07757501196465455, 0.1369442805298604, 0.19819255569018424, 0.149201606400311, 0.11783437119447626, 0.17869212082587183, 0.19209649530239403, 0.24341931712115183, 0.22356645116815343, 0.30301387945655733, 0.6196737173013389, 1.4079836918972433, 70.32813861966133, 78.15833285450935, 50.017947256565094, 78.74515816569328, 27.22363919019699, 36.56033098697662, 91.17626711726189, 63.0169053375721, 3.3155992487445474, 10.971092395484447, 14.674345180392265, 7.622395260259509, 2.1993376594036818, 1.534691930282861, 49.31807801127434, 98.15243437886238, 80.84134608507156, 85.01378059387207, 89.16418388485909, 86.43292084336281, 80.82286387681961, 83.38472440838814, 71.29021659493446, 65.1037609577179, 60.823875814676285, 61.161814481019974, 58.58146034181118, 59.39225323498249, 56.532595083117485, 62.44938299059868, 59.03500400483608, 62.48950883746147, 59.04017552733421, 60.831414610147476, 61.05832323431969, 64.85378757119179, 62.63163261115551, 61.36459060013294, 58.57665739953518, 61.316504180431366, 57.98681125044823, 56.62738859653473, 55.54928004741669, 53.683857545256615, 52.2770020365715, 53.93270619213581, 55.20149230957031, 54.944728687405586, 52.076935172080994, 58.36745962500572, 60.52001751959324, 62.259165197610855, 63.36495906114578, 65.21209314465523, 65.29609903693199, 68.69277477264404, 68.61106395721436, 68.87699648737907, 63.770800083875656, 56.643617525696754, 56.651722490787506, 65.20972967147827, 67.11171761155128, 68.38760554790497, 69.28878039121628, 67.04843580722809, 65.60414850711823, 64.84005510807037, 63.744456097483635, 70.71023851633072, 69.0103617310524, 67.28320240974426, 68.17062199115753, 63.81778836250305, 58.82765293121338, 55.958905667066574, 49.49606046080589, 50.71638397872448, 48.884205892682076, 51.64967469871044, 51.1839184910059, 51.45414479076862, 51.53918042778969, 52.751151993870735, 59.059565886855125, 67.20550417900085, 68.5846933722496, 68.3861692249775, 68.36915373802185, 68.63643899559975, 62.392260655760765, 53.200200498104095, 50.7286611199379, 52.83913627266884, 50.114959850907326, 52.03527420759201, 52.500764429569244, 56.72281667590141, 55.4192890226841, 54.978797659277916, 60.629459246993065, 71.24679252505302, 70.55693954229355, 70.45661732554436, 72.87201851606369, 71.75908863544464, 71.11802503466606, 75.02673849463463, 74.0785601735115, 72.82689213752747, 68.1753945350647, 62.391721084713936, 53.31769019365311, 0.19974161084974185, 0.3883301670430228, 9.614065513014793, 18.163038678467274, 2.3200291581451893, 22.260624803602695, 78.60414013266563, 18.473710007965565, 46.00485719740391, 71.75643637776375, 71.80289268493652, 65.41588380932808, 56.24304302036762, 0.5609957815613598, 0.31645675655454397, 0.12896010739495978, 0.29268585552927107, 0.16774913849076256, 0.21682470745872706, 0.15144721168326214, 0.08644421846838668, 0.15385139908175915, 0.10813045635586604, 0.20578058523824438, 0.17217836488271132, 0.10036507577751763, 0.18168066046200693, 0.24964891956187785, 0.08201673612347804, 0.13876785611500964, 0.1890225344686769, 0.18446450092596933, 0.1936672508600168, 0.16925326402997598, 0.17447427293518558], [0.021455897513078526, 0.06447750070947222, 0.07067162106977776, 0.13578819256508723, 0.01882998607470654, 0.06999816658208147, 0.015694508620072156, 0.024635219197080005, 0.059943397718598135, 0.0747256695467513, 0.04364259155408945, 0.03799244688707404, 0.022097771761764307, 0.08804656725260429, 0.030463546099781524, 0.05618687253445387, 0.027639080471999478, 0.045831277820980176, 0.023205935540318023, 0.04758909541124012, 0.08491100074024871, 0.12199568227515556, 0.07297464631847106, 0.05419387947767973, 0.01912149240524741, 0.1011572961579077, 0.025106531211349647, 0.6108159176073968, 8.689862955361605, 72.55193129181862, 42.379445135593414, 56.65060915052891, 73.4988784790039, 14.395336601883173, 49.1997067630291, 61.42097197473049, 5.414145179092884, 5.366879990324378, 7.035390408709645, 4.356864737346768, 4.814747292548418, 0.7121542829554528, 31.080031357705593, 97.11880624294281, 73.89047786593437, 85.27414262294769, 70.29148578643799, 77.61443004012108, 69.1875310242176, 66.31247609853745, 59.39265601336956, 59.318468794226646, 56.52603663504124, 55.552392080426216, 52.68161192536354, 54.11640353500843, 54.816922545433044, 54.72782112658024, 57.82099574804306, 60.34727118909359, 59.66683030128479, 55.611843690276146, 57.69807614386082, 60.36910101771355, 60.52887484431267, 59.03357908129692, 59.03106741607189, 59.84163612127304, 57.41397298872471, 52.18603111803532, 51.12336494028568, 50.43872907757759, 47.46389150619507, 47.969378381967545, 50.310782343149185, 44.82177548110485, 50.09344920516014, 56.09574772417545, 58.32102231681347, 57.80017286539078, 59.21349182724953, 58.06210421025753, 59.03895579278469, 60.89736767113209, 60.738304406404495, 60.789138078689575, 62.02187933027744, 57.446085065603256, 54.807130470871925, 57.57710203528404, 60.76020263135433, 58.70314121246338, 59.16331931948662, 63.18777836859226, 62.96323321759701, 65.18082842230797, 67.40652099251747, 62.90528632700443, 60.401144698262215, 61.35072134435177, 59.933427795767784, 56.04391850531101, 52.45595723390579, 47.75553725659847, 45.71990668773651, 44.491197019815445, 43.1927040964365, 43.03565852344036, 45.86313620209694, 47.86214433610439, 47.94767014682293, 55.62839940190315, 58.9718209952116, 59.75501596927643, 62.62914374470711, 63.2290593534708, 62.586369439959526, 61.7628738284111, 62.9397314786911, 56.80786371231079, 47.86375164985657, 44.96972434222698, 45.26817172765732, 45.3909507393837, 46.970609575510025, 48.06971959769726, 48.92326019704342, 51.71987973153591, 54.3816065043211, 58.06486286222935, 66.83589041233063, 69.95812967419624, 67.31395795941353, 68.98829251527786, 70.98353505134583, 66.9472624361515, 70.93028470873833, 65.12177959084511, 57.56518967449665, 63.59316721558571, 7.532222298905253, 0.17482493771240115, 1.6440706048160791, 6.379964528605342, 2.046574931591749, 0.4620873858220875, 32.396856397390366, 29.665409065783024, 14.909715000540018, 47.12222903966904, 22.736779153347015, 31.388789489865303, 59.12683367729187, 10.00898877158761, 0.5017853993922472, 0.29942607041448355, 0.06619399922783487, 0.15603414445649832, 0.06279484412516467, 0.12189966320875101, 0.059170873937546276, 0.10644946960383095, 0.045519731647800654, 0.02737104270636337, 0.021452145956573077, 0.023482912474719342, 0.027953467215411365, 0.041213330696336925, 0.09220568899763748, 0.036335550248622894, 0.03808894463873003, 0.05095322856504936, 0.029223235505924094, 0.048191882597166114, 0.03976499610871542, 0.016745849861763418, 0.07639168718014844, 0.062135278931236826, 0.008731938869459555, 0.06777590184356086, 0.03979349086876027, 0.051140695068170317, 0.03319350849778857, 0.011187070067535387, 0.06542966875713319, 0.011648684994725045, 0.028999811947869603, 0.041509380826028064, 0.008968417732830858, 0.06136681840871461, 0.0641126609116327, 0.04254953790223226, 0.07598193260491826, 0.05362218456866685, 0.06344120280118659, 0.10680596766178496, 0.05793976226414088, 0.07662250252906233, 0.06293614162132144, 0.01944920626556268, 0.0993240207026247, 0.07625716549227946, 0.061452046647900715, 0.7046916021499783, 11.0736327432096, 82.98733413219452, 40.25831535458565, 57.44524531066418, 56.32490202784538, 22.069154977798462, 68.31613898277283, 66.14935845136642, 8.140663225203753, 3.9528642408549786, 8.37468696758151, 6.6596010234206915, 6.341971792280674, 0.7343176030553877, 34.83181893825531, 99.05037939548492, 80.94071835279465, 84.36935797333717, 73.57264012098312, 82.0010058581829, 72.79327914118767, 69.91938695311546, 63.147485330700874, 63.41929994523525, 56.814642548561096, 57.78007194399834, 55.35997040569782, 57.587198093533516, 55.223960503935814, 56.69845998287201, 60.747359320521355, 62.28462763130665, 60.99012829363346, 58.63634079694748, 60.2042468637228, 62.15528257191181, 61.04249708354473, 61.051890179514885, 61.696365997195244, 61.40454925596714, 58.42942290008068, 54.402277395129204, 54.15939062833786, 54.260263815522194, 49.718793109059334, 51.71258792281151, 52.23194405436516, 48.63540664315224, 53.26024107635021, 60.272893980145454, 62.436516880989075, 60.56704379618168, 61.89452536404133, 59.81333903968334, 64.45233151316643, 63.81090313196182, 66.64096087217331, 68.20880994200706, 63.67816865444183, 60.86104542016983, 56.51367969810963, 61.071124747395515, 63.10882240533829, 63.127034828066826, 63.305028676986694, 65.46144336462021, 64.27753329277039, 66.1932384967804, 68.65141779184341, 65.54011434316635, 65.29783174395561, 64.14323329925537, 62.23178766667843, 60.157524570822716, 56.452563777565956, 50.37301920354366, 48.87611612677574, 45.66637136042118, 45.870842188596725, 44.643671438097954, 48.79833810031414, 49.072542786598206, 50.24461269378662, 57.34276480972767, 61.54111012816429, 62.42334298789501, 65.64919888973236, 66.69584512710571, 67.26601973176003, 63.77946361899376, 66.0100731253624, 60.01280173659325, 52.48021513223648, 48.70216526091099, 49.50657069683075, 48.810672238469124, 50.43518386781216, 50.630542784929276, 52.85771727561951, 53.57018284499645, 58.034726679325104, 60.84094449877739, 69.85988214612007, 71.53286397457123, 68.49022284150124, 70.58508083224297, 72.16943621635437, 69.81964230537415, 71.6010931134224, 66.44411623477936, 61.11451081931591, 68.25642138719559, 5.81970501691103, 0.17911406146595255, 3.719376507215202, 9.637217670679092, 2.599835218861699, 0.2719215431716293, 35.15626832842827, 39.951956793665886, 13.80487298592925, 45.30608989298344, 25.205702371895313, 37.58441783487797, 70.22607609629631, 11.59989595413208, 0.5983892187941819, 0.31307128665503114, 0.03435127000557259, 0.14006710436660796, 0.06018407249939628, 0.09426779084606096, 0.0388560210558353, 0.08242490992415696, 0.028576899094332475, 0.02889214301831089, 0.05012292487663217, 0.03636548477516044, 0.08730343994102441, 0.02693906080821762, 0.04106453008716926, 0.02565825492638396, 0.08575082989409566, 0.05508624897629488, 0.013162543800717685, 0.02040075461991364, 0.03858649157336913, 0.014539357616740745, 0.3297360643045977, 0.15902859158813953, 0.1129380296333693, 0.20863458834355697, 0.09636588685680181, 0.1814336291863583, 0.10283382260240614, 0.1599546879879199, 0.13097101589664817, 0.15492599923163652, 0.08842748196911998, 0.09094563356484286, 0.1762799924472347, 0.22738831874448806, 0.08967508416390046, 0.13748880912316963, 0.15906428889138624, 0.1495023543247953, 0.14662970846984535, 0.23047094786306843, 0.14224694052245468, 0.16537753137527034, 0.14831252832664177, 0.17750517436070368, 0.1657559970044531, 0.29284452670253813, 0.3128755674697459, 1.2483438081108034, 21.17140755057335, 97.82721742987633, 57.152452021837234, 81.23327225446701, 96.45163044333458, 22.250120267271996, 63.52955102920532, 78.01086276769638, 7.917921552434564, 10.227521695196629, 17.159115448594093, 14.468455128371716, 12.321083955466747, 0.795925062848255, 36.78277485072613, 102.70250782370567, 82.5372862815857, 90.33519744873047, 78.79382595419884, 85.07390856742859, 76.9962640106678, 72.49286726117134, 65.23746058344841, 64.86666887998581, 59.922624975442886, 60.843452364206314, 58.645281717181206, 60.679187178611755, 59.622372686862946, 61.18642956018448, 65.1901227235794, 65.82403510808945, 66.24172389507294, 61.8743522465229, 64.87999856472015, 65.26619464159012, 64.5168748497963, 65.74534893035889, 64.99536037445068, 65.23432195186615, 64.58091661334038, 58.136378824710846, 56.9007421284914, 56.676785945892334, 52.673769146203995, 54.48050759732723, 54.40187841653824, 48.814000859856606, 57.39757686853409, 62.62513116002083, 64.63790595531464, 63.85796740651131, 64.47264522314072, 62.27928511798382, 66.68213546276093, 66.18642926216125, 68.65906298160553, 68.80887374281883, 65.83328381180763, 61.652565747499466, 56.755061745643616, 62.0538280159235, 65.66163942217827, 67.78312638401985, 66.56244948506355, 69.84041199088097, 68.2501745223999, 68.72842445969582, 70.5617880821228, 68.67169350385666, 66.97226509451866, 64.70659866929054, 64.1442820429802, 62.932230681180954, 57.26943254470825, 51.49413004517555, 51.44879087805748, 48.1936651468277, 47.537257969379425, 46.48865483701229, 51.19466431438923, 52.72743746638298, 53.58194321393967, 60.753241404891014, 63.622585237026215, 65.79939723014832, 69.22657012939453, 68.71656149625778, 67.9849411547184, 66.16823583841324, 68.05231913924217, 62.73811809718609, 56.4605775475502, 50.898903384804726, 52.31806643307209, 51.62702411413193, 54.121784046292305, 52.71370880305767, 56.580624505877495, 59.55894649028778, 60.833318307995796, 62.45770074427128, 74.04098019003868, 74.25182327628136, 69.23643440008163, 71.49623394012451, 73.47627729177475, 69.62704584002495, 72.01217785477638, 71.15637257695198, 64.21792209148407, 69.17117670178413, 9.755276385694742, 0.4715305322315544, 4.397627525031567, 18.870756402611732, 8.919063806533813, 1.2604859378188848, 40.07657490670681, 40.12892849743366, 24.772320427000523, 68.93737524747849, 35.26644341647625, 44.739012122154236, 76.98066964745522, 20.618400424718857, 1.3244146574288607, 0.4515364207327366, 0.19703600759385154, 0.2597872505430132, 0.21472285618074238, 0.239362544962205, 0.23834978055674583, 0.2333901560632512, 0.17637023760471493, 0.20801943697733805, 0.16189564164960757, 0.17583537177415565, 0.15919419442070648, 0.14719715458340943, 0.19085994368651882, 0.13190891244448721, 0.25928042305167764, 0.1271958590950817, 0.12920232955366373, 0.11543494096258655, 0.13979645795188844, 0.07195584825240076], [0.035046985212829895, 0.034700324322329834, 0.04064162836584728, 0.09606909457943402, 0.05303292673488613, 0.03528154098603409, 0.05424897652119398, 0.051828710493282415, 0.048436973156640306, 0.040877390129026026, 0.019327592381159775, 0.014487451808236074, 0.04752265092974994, 0.06332590273814276, 0.0344808712543454, 0.054307680402416736, 0.10975556680932641, 0.08408573252381757, 0.03835980998701416, 0.06635184661718085, 0.0447669489949476, 0.08573404993512668, 0.054232088950811885, 0.14485996827716008, 0.15486438613152131, 0.07674900160054676, 0.024140683526638895, 0.3373078705044463, 0.4086287075188011, 42.60532021522522, 56.911978125572205, 58.69347833096981, 78.05354207754135, 28.271189779043198, 16.325434483587742, 85.15989795327187, 19.61472038179636, 2.089551812969148, 5.067066103219986, 7.248690063133836, 3.737386828288436, 0.3175684640882537, 16.358766295015812, 99.7101379930973, 75.13649940490723, 79.5063105225563, 76.05677202343941, 68.18161860108376, 61.71449102461338, 61.18987217545509, 59.4323068857193, 57.18716695904732, 58.64651285111904, 57.83274091780186, 55.577721521258354, 52.35180102288723, 59.52266223728657, 60.35300888121128, 60.459095388650894, 59.52486611902714, 58.885550424456596, 60.220585986971855, 62.46980309486389, 61.109962463378906, 62.29103408753872, 61.74919456243515, 63.75472694635391, 63.95524978637695, 68.6838148534298, 65.22109106183052, 58.15559819340706, 48.644906133413315, 50.770147293806076, 47.18064330518246, 49.50393743813038, 48.17285366356373, 49.704798460006714, 57.089124619960785, 62.31340728700161, 59.99615862965584, 61.967530846595764, 61.38656482100487, 60.203144922852516, 62.669976353645325, 65.8544334769249, 63.281420543789864, 64.72153186798096, 64.88609343767166, 59.37584191560745, 55.28709411621094, 58.53413388133049, 57.83304490149021, 65.6154415011406, 69.07749652862549, 65.27422741055489, 64.13396939635277, 59.47997912764549, 62.741518914699554, 60.931691229343414, 56.745174676179886, 56.67339272797108, 50.86074583232403, 49.810934364795685, 47.50044174492359, 46.571186408400536, 44.231993928551674, 45.17592407763004, 44.54277165234089, 45.120059475302696, 46.91117316484451, 56.0571113973856, 62.23198525607586, 63.03813099861145, 61.34753331542015, 63.19943994283676, 64.28172826766968, 63.509659096598625, 62.44985416531563, 64.21585500240326, 62.39183507859707, 57.9173319786787, 47.17696510255337, 47.09468811750412, 45.68583771586418, 50.07277451455593, 50.773088335990906, 52.398701906204224, 54.199398681521416, 54.70578230917454, 58.30190934240818, 64.08277854323387, 65.90745583176613, 73.27348977327347, 67.58819684386253, 73.07176619768143, 68.64998906850815, 72.03017368912697, 54.239247143268585, 71.6213384270668, 19.326693937182426, 0.37311486317776144, 1.1448143259622157, 1.0880931071005762, 5.796201378107071, 1.37602859409526, 0.26446203875821084, 35.77051676809788, 18.798752166330814, 32.20136068761349, 48.870416432619095, 31.448001712560654, 58.43686670064926, 45.51862008869648, 1.3314480800181627, 0.08885801667929627, 0.10917441322817467, 0.041430750279687345, 0.07518544487538747, 0.029070985765429214, 0.04581812325341161, 0.09581644524587318, 0.15375270828371868, 0.03401429785299115, 0.055947759974515066, 0.0592629596212646, 0.045307110049179755, 0.05427989439340308, 0.02749668088654289, 0.025453728303546086, 0.04825926218472887, 0.07342241369769908, 0.03078392011957476, 0.08639606792712584, 0.011902845526492456, 0.04019769046863075, 0.029244123252283316, 0.1002931987750344, 0.014973545548855327, 0.05439711661892943, 0.06844894072855823, 0.10945760936010629, 0.03481213629129343, 0.06464489211793989, 0.07187514711404219, 0.053063696177559905, 0.06469628584454767, 0.06406336746294983, 0.010577585926512256, 0.10763728438178077, 0.08417556950007565, 0.04527254823187832, 0.03409669479879085, 0.04410906847624574, 0.07575925119454041, 0.05433171856566332, 0.005862408179382328, 0.043255624623270705, 0.018909188074758276, 0.05352025429601781, 0.05233416872215457, 0.02987262028909754, 0.02176564583351137, 0.016133546487253625, 0.5742882995400578, 0.7558793085627258, 49.64155085384846, 65.05270689725876, 64.7058767080307, 93.46148729324341, 23.00376422703266, 31.75611387938261, 87.55293354392052, 20.874240696430206, 1.0305036348290741, 5.228158459067345, 12.232790943235159, 11.34909326210618, 0.5297505331691355, 18.996626548469067, 104.12664100527763, 77.70158976316452, 81.27619475126266, 77.7927316725254, 70.15397116541862, 64.59850206971169, 65.83590567111969, 59.248503148555756, 59.716425240039825, 60.84692917764187, 62.402748093008995, 56.27008996903896, 54.79362979531288, 60.46466588973999, 64.58225414156914, 60.73558755218983, 63.22427541017532, 60.756809413433075, 62.90939770638943, 64.66165468096733, 65.169877409935, 65.94944357872009, 64.02525722980499, 66.02480873465538, 68.45996886491776, 68.7608291208744, 64.63222905993462, 58.95651921629906, 52.138480469584465, 54.45473738014698, 50.37625662982464, 52.23972603678703, 51.08929216861725, 54.04227331280708, 58.69894243776798, 64.79650944471359, 63.245516270399094, 65.0587409734726, 62.11827255785465, 64.46966618299484, 63.700678646564484, 68.61793398857117, 63.358199223876, 68.32783475518227, 65.80470934510231, 60.55406369268894, 56.67920261621475, 61.12553022801876, 60.62680318951607, 66.18837475776672, 68.47267538309097, 69.20415133237839, 68.49372625350952, 61.82349197566509, 64.44427594542503, 62.550514563918114, 60.669178515672684, 58.82636860013008, 55.45506410300732, 52.131029069423676, 49.22829642891884, 48.48854832351208, 45.45631483197212, 48.38664539158344, 46.18511192500591, 48.954855501651764, 48.453396409749985, 58.97918500006199, 64.68743249773979, 66.05107292532921, 64.04874756932259, 65.3143684566021, 64.76819336414337, 66.31800100207329, 66.61749333143234, 66.60129860043526, 63.8162000477314, 60.17411828041077, 50.07370166480541, 50.442779660224915, 48.07196147739887, 51.29190109670162, 53.327189683914185, 56.32210157811642, 55.65195053815842, 58.13433453440666, 61.03026933968067, 68.18403527140617, 65.4820154607296, 75.56747227907181, 69.35644716024399, 75.53088024258614, 68.3276979625225, 73.48205298185349, 55.48080772161484, 79.2270179092884, 18.083104267716408, 0.5749052320607007, 3.1923635490238667, 2.4665478710085154, 9.796574469655752, 0.9186919627245516, 0.4114378255326301, 41.92547969520092, 22.571841403841972, 32.17244043946266, 57.85387918353081, 29.473745450377464, 67.42032945156097, 48.123353719711304, 1.4147643093019724, 0.22678887122310698, 0.08434375500655733, 0.03252787624660414, 0.03454163459537085, 0.0755648010817822, 0.0716356783232186, 0.025432241272937972, 0.09081237352802418, 0.05071034960565157, 0.010427472643641522, 0.049528535091667436, 0.02223382041847799, 0.06200550327776, 0.032358904063585214, 0.03276328177889809, 0.04436977382283658, 0.027013748695026152, 0.035732065443880856, 0.02272231871756958, 0.015858298756938893, 0.029321126639842987, 0.027682284598995466, 0.14901779126375914, 0.17766360804671422, 0.16993402125081047, 0.13876975601306185, 0.24711619218578562, 0.13634792034281418, 0.2003387428703718, 0.1898147919564508, 0.14811128756264225, 0.21180320269195363, 0.12341780049609952, 0.15169256570516154, 0.22465896676294506, 0.24596709525212646, 0.18666677962755784, 0.14397250808542594, 0.14961373584810644, 0.2158784246421419, 0.12231283908477053, 0.1492479906301014, 0.138613430026453, 0.21965264633763582, 0.17852924909675494, 0.2593688276829198, 0.22911848762305453, 0.16252576955594122, 0.12019976653391495, 0.6511610245797783, 1.1073447740636766, 64.25221905112267, 83.7150102853775, 69.43720042705536, 105.06575301289558, 38.75909060239792, 28.8156720623374, 97.07035884261131, 27.021875716745853, 7.5516563560813665, 13.680949285626411, 17.881447188556194, 10.241523943841457, 0.437190854572691, 21.209857687354088, 106.64630860090256, 82.73646399378777, 85.667664706707, 82.09013387560844, 75.36283046007156, 68.80457997322083, 68.58311265707016, 63.62949326634407, 63.422655165195465, 64.88781094551086, 64.81764391064644, 60.901129469275475, 57.07240171730518, 65.05595952272415, 68.47611799836159, 65.4409472644329, 64.92260947823524, 66.50835558772087, 68.22691977024078, 69.47236374020576, 67.05174162983894, 69.03385207056999, 66.70429587364197, 68.42187210917473, 70.67940697073936, 73.63970652222633, 72.18861758708954, 62.80817873775959, 54.91879127919674, 57.80496060848236, 52.631853595376015, 53.89014847576618, 52.42408834397793, 56.25555194914341, 62.20479391515255, 68.39563831686974, 66.24673202633858, 69.01937484741211, 64.60808515548706, 67.49738171696663, 66.10329732298851, 72.40934774279594, 67.469232827425, 71.98855832219124, 68.41617241501808, 60.479496493935585, 57.569574639201164, 61.04304425418377, 60.44714502990246, 66.28192573785782, 70.65507307648659, 68.67279544472694, 66.574836820364, 65.12793526053429, 66.29586338996887, 64.51939031481743, 61.44611142575741, 60.808653831481934, 57.32677526772022, 52.937995567917824, 50.512806102633476, 50.54724745452404, 47.87544742226601, 51.268372759222984, 50.72936028242111, 50.284130573272705, 52.40962632000446, 61.15801468491554, 65.50597697496414, 69.54421788454056, 66.77842989563942, 70.02082630991936, 67.09299981594086, 68.36012542247772, 68.53439167141914, 71.35482832789421, 64.38809975981712, 63.98347467184067, 52.400434613227844, 54.06822212040424, 49.56777401268482, 57.445663288235664, 56.793348491191864, 59.44238394498825, 58.509579598903656, 62.96769417822361, 65.11230289936066, 68.86555910110474, 68.84789004921913, 80.90676337480545, 70.41912853717804, 77.2911585867405, 68.90639171004295, 74.5718877017498, 61.25191904604435, 79.82172399759293, 22.455453649163246, 1.049231761135161, 2.2421338129788637, 5.466579515486956, 16.380636021494865, 4.118111673742533, 0.4316359682707116, 46.39807529747486, 27.27666724473238, 51.03374294936657, 70.74287116527557, 50.9709969162941, 74.99540537595749, 65.49241170287132, 2.2410323470830917, 0.3298196301329881, 0.19872124685207382, 0.2138561909669079, 0.13140659721102566, 0.15675787202781066, 0.15360745514044538, 0.1952999460627325, 0.2889123314525932, 0.150282574177254, 0.18345111311646178, 0.21186126832617447, 0.13775840168818831, 0.14928459335351363, 0.08470475790090859, 0.11310859743389301, 0.14536255068378523, 0.1800488558365032, 0.1159588155860547, 0.187270546448417, 0.10415891243610531, 0.13330064713954926, 0.07145145500544459], [0.06864421462523751, 0.03176527869072743, 0.04469324259844143, 0.03547973152308259, 0.03248855355195701, 0.04406557491165586, 0.03153120902425144, 0.024479186358803418, 0.1111379949725233, 0.02447791357553797, 0.09683167358161882, 0.020167586662864778, 0.057086144006461836, 0.08844572395901196, 0.03719751395692583, 0.03987510113802273, 0.05270612942695152, 0.05504020242369734, 0.03532590657414403, 0.05374771142669488, 0.0433605531725334, 0.0162947168428218, 0.10760192846646532, 0.07557718010502867, 0.006358927239489276, 0.06215028144652024, 0.07980158858117647, 0.16118971077958122, 0.6959596707019955, 19.429837502539158, 64.43864464759827, 28.92275031656027, 25.561779364943504, 69.4798569381237, 15.894799791276455, 61.10570669174194, 42.826882526278496, 0.5542726954445243, 4.465256771072745, 2.9661851981654763, 4.2052452731877565, 0.2918956463690847, 6.3105930760502815, 89.25134360790253, 82.05437779426575, 86.57228216528893, 70.57466939091682, 80.4802818596363, 76.55851230025291, 76.97392880916595, 68.93705606460571, 65.89370056986809, 58.640212789177895, 58.47951181232929, 55.9318321198225, 59.88403804600239, 59.88524258136749, 62.05206871032715, 62.083827406167984, 64.13024559617043, 59.5896602421999, 60.955375358462334, 60.06677024066448, 64.69236463308334, 64.58945855498314, 65.22961020469666, 63.70944857597351, 67.81563743948936, 69.79523241519928, 71.34496405720711, 66.7173519730568, 59.49344180524349, 50.81075571477413, 47.84387871623039, 48.357208371162415, 48.00789311528206, 45.88789947330952, 52.908463552594185, 63.52391593158245, 64.71156880259514, 60.514792799949646, 58.10561567544937, 59.955056235194206, 61.73412077128887, 61.97876684367657, 61.69043071568012, 67.22546830773354, 67.28950247168541, 62.07218863070011, 41.55764043331146, 58.638841062784195, 66.55006974935532, 63.76146778464317, 65.32407313585281, 63.45310293138027, 60.82903213799, 60.06507933139801, 55.01238785684109, 53.89696530997753, 52.52590008080006, 52.029430121183395, 48.21884259581566, 47.68292315304279, 46.10968977212906, 45.44037088751793, 44.3732513487339, 43.81141349673271, 45.272875875234604, 47.71575339138508, 53.84116530418396, 62.33352340757847, 63.0520648509264, 60.966995134949684, 61.179840713739395, 62.6822154968977, 64.69639241695404, 63.87610003352165, 61.6338175535202, 64.56959322094917, 62.723253294825554, 61.828655898571014, 50.47105774283409, 45.388359278440475, 46.343548223376274, 49.19163219630718, 50.92840500175953, 52.45645880699158, 54.87762808799744, 54.94721755385399, 60.44977068901062, 61.11819662153721, 68.77232730388641, 65.22314295172691, 71.9691489636898, 69.18544873595238, 72.58059695363045, 61.61952652037144, 63.42748090624809, 39.299812987446785, 0.6060659349896014, 0.13567704852903262, 2.0106887072324753, 3.151948442682624, 7.365292981266975, 0.29910712502896786, 2.4078163225203753, 32.22194418311119, 30.409129858016968, 50.25785878300667, 26.082754209637642, 34.89145673811436, 54.942258819937706, 9.581551607698202, 0.47781607776414603, 0.2881406166125089, 0.07334137117140926, 0.136917058553081, 0.02808814104355406, 0.06469068262958899, 0.0416543148458004, 0.04679099722125102, 0.011326685671519954, 0.034847328934120014, 0.05092791761853732, 0.021999362979840953, 0.015665555583836976, 0.06561539863469079, 0.012792334564437624, 0.06547844270244241, 0.033591826577321626, 0.09612829569960013, 0.024519477556168567, 0.05442323650640901, 0.01829463228204986, 0.03540239602443762, 0.03080679125559982, 0.015967559593264014, 0.026259624610247556, 0.06458510470110923, 0.034272658012923785, 0.013607556884380756, 0.04015611164504662, 0.05047665843449067, 0.02449512954626698, 0.09899600627250038, 0.07169417440309189, 0.10433011848363094, 0.008670995557622518, 0.0751015821879264, 0.04062295221956447, 0.08982193292467855, 0.05143347974808421, 0.016022957206587307, 0.04642882544430904, 0.017319919643341564, 0.07114354535588063, 0.07391401231870987, 0.059465799713507295, 0.05611832035356201, 0.1025021642271895, 0.028834632139478344, 0.05721704401366878, 0.17144586512586102, 0.3018105908995494, 0.9969121310859919, 20.9384211525321, 74.18106347322464, 34.80120778083801, 54.63911488652229, 66.97643727064133, 16.584791466593742, 82.99145311117172, 42.317618653178215, 0.720993677387014, 8.021051343530416, 7.949761468917131, 14.18632596731186, 0.4615125776035711, 7.826741170138121, 91.59614458680153, 87.12985664606094, 89.70533564686775, 72.77576208114624, 85.9811782836914, 79.0796922147274, 77.92911395430565, 69.37694326043129, 67.21661478281021, 60.977782756090164, 62.72737607359886, 58.441947028040886, 60.809311196208, 62.057605013251305, 65.15745207667351, 66.38531059026718, 66.55976682901382, 62.77323201298714, 64.10917192697525, 60.971273705363274, 67.20436424016953, 66.98804944753647, 67.81271159648895, 66.05408996343613, 70.55590599775314, 73.20188641548157, 73.91472816467285, 69.63667452335358, 60.20156420767307, 53.21424454450607, 50.6480560451746, 50.15165828168392, 50.63219949603081, 49.54759329557419, 57.01209895312786, 66.08174487948418, 67.27943301200867, 61.98217146098614, 61.988463923335075, 64.21099126338959, 65.56023806333542, 66.46321401000023, 65.81099420785904, 69.98769208788872, 68.69957640767097, 64.89970430731773, 47.546844854950905, 60.9077563136816, 67.18351855874062, 68.50333213806152, 70.17220258712769, 65.6704093515873, 62.15768404304981, 64.02566760778427, 58.59293572604656, 56.49459712207317, 55.49280367791653, 53.79219353199005, 53.60013663768768, 51.592043191194534, 50.98376043140888, 47.367923855781555, 48.36442418396473, 46.49319939315319, 47.73872695863247, 48.14991809427738, 54.641413763165474, 66.18662685155869, 63.89173999428749, 62.80016876757145, 62.91363067924976, 65.67774295806885, 68.44972461462021, 67.0233191549778, 64.48580771684647, 67.6009413599968, 68.68779703974724, 64.86584812402725, 54.79181729257107, 47.44006298482418, 50.63751541078091, 53.084675297141075, 53.06547112762928, 56.002246141433716, 58.173696622252464, 58.43491740524769, 61.38973765075207, 63.500440791249275, 72.464110404253, 67.66987726092339, 74.02201920747757, 71.21349111199379, 74.00807395577431, 62.77240365743637, 70.09884372353554, 41.308791786432266, 0.364935623947531, 0.46264132484793663, 5.049229860305786, 4.032003069296479, 4.646483296528459, 1.4125128113664687, 3.5069460561499, 39.56963650882244, 33.16394783556461, 58.866623640060425, 34.91693057119846, 39.366647601127625, 63.60579393804073, 8.769116252660751, 0.38108929933514446, 0.27154491806868464, 0.06821897884947248, 0.12043188064126298, 0.0390902873914456, 0.1329576561693102, 0.05503526714164764, 0.02622966781927971, 0.07283199069206603, 0.17134785710368305, 0.013745500800723676, 0.06071156880352646, 0.033393717676517554, 0.04084240899828728, 0.01816967131162528, 0.031023700612422545, 0.04393652285216376, 0.050378750602249056, 0.1080020796507597, 0.061641464999411255, 0.0708906065847259, 0.01942228485859232, 0.11695197244989686, 0.19116349692922086, 0.1216161331103649, 0.09855249139945954, 0.12030110679916106, 0.10803723518620245, 0.13785971968900412, 0.15454670239705592, 0.092584162048297, 0.19201181625248864, 0.27243742486461997, 0.16148520429851487, 0.0674546483787708, 0.15630477602826431, 0.18934070802060887, 0.18134820798877627, 0.1673038795706816, 0.14350023498991504, 0.14666786970337853, 0.17858657258329913, 0.2071791625348851, 0.23090856266207993, 0.15724216791568324, 0.2586031687678769, 0.24309686879860237, 0.19676812196848914, 0.3046174527844414, 0.25270757731050253, 0.3353887953562662, 1.4667893364094198, 34.12048190832138, 87.58420586585999, 43.759698271751404, 51.701378524303436, 92.01969265937805, 22.975337952375412, 75.09057506918907, 52.81268589198589, 0.5794417730066925, 16.030741296708584, 5.250762021169066, 11.957834847271442, 0.37684753944631666, 9.461679439991713, 95.50771549344063, 90.46323537826538, 94.92135375738144, 75.97522839903831, 90.66702604293823, 83.58954101800919, 83.11151906847954, 74.37557503581047, 72.07637161016464, 63.44465218484402, 66.05141490697861, 59.96015176177025, 66.8834638595581, 63.85388642549515, 70.84187865257263, 68.55077639222145, 70.79475358128548, 65.54463610053062, 68.16217884421349, 63.470486998558044, 72.32704415917397, 71.26680225133896, 73.38550016283989, 68.30781742930412, 74.4971913099289, 75.694719851017, 78.50915282964706, 72.07305058836937, 67.39759147167206, 57.25191168487072, 55.46016722917557, 52.01766975224018, 54.28531967103481, 51.34416349232197, 59.61383454501629, 68.67590367794037, 71.82556986808777, 63.27844150364399, 66.31670147180557, 67.26744845509529, 69.83402073383331, 67.23004326224327, 70.21816492080688, 72.86998942494392, 72.79987558722496, 64.61308568716049, 48.52548234164715, 61.79714038968086, 68.05526778101921, 70.86219236254692, 72.6479597389698, 67.54034981131554, 67.1028944849968, 68.12993377447128, 60.530364364385605, 58.571466878056526, 57.425083592534065, 56.370909959077835, 56.769759356975555, 53.44891235232353, 52.87573590874672, 49.66719187796116, 50.36062426865101, 48.987305760383606, 50.26845641434193, 51.34460046887398, 58.5169930011034, 70.17594158649445, 68.71839299798012, 65.05017623305321, 64.98986586928368, 68.99213030934334, 71.00704059004784, 68.28201681375504, 64.41864252090454, 69.23002034425735, 72.59878277778625, 66.56697124242783, 57.64443442225456, 50.55963858962059, 55.063039138913155, 56.5970928221941, 56.7102013528347, 59.53488238155842, 62.93296404182911, 61.851355880498886, 66.09641969203949, 68.27794343233109, 77.08353772759438, 70.99539041519165, 76.32470324635506, 75.72004169225693, 74.97557803988457, 71.07547491788864, 69.76576119661331, 44.86809879541397, 1.01931216660887, 0.3359189856564626, 6.745011890307069, 11.265246961265802, 18.06236308068037, 3.2632314087823033, 3.1523913564160466, 43.64218197762966, 44.16256785392761, 68.99334624409676, 44.58178795874119, 48.05364266037941, 76.68819934129715, 18.604535087943077, 1.1154358461499214, 0.5299111932981759, 0.1874186345958151, 0.2404030508478172, 0.13766417861916125, 0.1560516146128066, 0.17587616021046415, 0.10519821604248136, 0.18639090849319473, 0.21626760688377544, 0.20999975415179506, 0.08948510920163244, 0.18150683463318273, 0.21706905215978622, 0.0996198778739199, 0.10976995705277659, 0.17622442042920738, 0.12639628403121606, 0.2373409940628335, 0.1669226383091882, 0.16486938286107033, 0.16172711475519463, 0.20655215164879337], [0.04373976837086957, 0.04795344910235144, 0.07487380222300999, 0.00943457089306321, 0.08968344816821627, 0.01864499648945639, 0.11163360119098797, 0.0552721755229868, 0.008647642953292234, 0.06091231232858263, 0.08264947638963349, 0.11067974846810102, 0.04675860247516539, 0.05241587175987661, 0.006549726449520676, 0.02087952336296439, 0.04221838047669735, 0.05193152763240505, 0.22041437186999246, 0.047345949278678745, 0.07782034372212365, 0.08148356981109828, 0.09197013132506981, 0.04937018304190133, 0.02609938193927519, 0.017488938210590277, 0.12542203709017485, 0.1134533250296954, 0.1594243641011417, 1.2770002079196274, 55.71549452841282, 61.51819355785847, 17.166656143963337, 48.710293024778366, 29.754723273217678, 19.75149594247341, 56.11539267003536, 2.6812107022851706, 4.588790517300367, 20.837597362697124, 14.795350637286901, 0.14336715306853876, 0.04673423776694108, 49.42925624549389, 95.30131056904793, 70.5879458785057, 90.62774375081062, 78.12212079763412, 83.58190342783928, 81.76010638475418, 81.12713634967804, 70.72147831320763, 63.2673005014658, 63.11148226261139, 55.91914460062981, 61.94405950605869, 62.32889145612717, 67.40201443433762, 63.481445610523224, 62.86959484219551, 59.86356854438782, 65.7514514029026, 66.54026627540588, 68.71572554111481, 65.9633356332779, 68.89851853251457, 69.14724558591843, 70.61073705554008, 71.81287854909897, 70.80784767866135, 67.84165844321251, 65.43139457702637, 58.120301887393, 54.4916296005249, 46.091120168566704, 51.82821571826935, 47.556329146027565, 52.050199806690216, 60.53854152560234, 68.57052013278008, 65.07027715444565, 63.248844891786575, 61.642051711678505, 64.73746061325073, 62.5496482104063, 65.83978906273842, 64.15361434221268, 65.37325009703636, 65.57600721716881, 43.355859741568565, 58.35998922586441, 63.82730305194855, 65.3284353017807, 63.905738443136215, 60.33195421099663, 56.5313221514225, 53.98863919079304, 50.86412765085697, 50.69532170891762, 49.993028193712234, 49.119173884391785, 48.587692603468895, 47.381979301571846, 47.93025568127632, 45.95601461827755, 45.75674571096897, 45.01393496990204, 47.83542796969414, 50.64127340912819, 56.56413719058037, 59.931421503424644, 62.22548760473728, 63.49331237375736, 61.630663722753525, 61.296935230493546, 64.74861681461334, 65.13108149170876, 61.10657684504986, 60.96828706562519, 64.62116405367851, 63.25277008116245, 56.863580122590065, 46.83005891740322, 48.12366910278797, 49.120606407523155, 53.23537141084671, 53.681577667593956, 56.69858157634735, 55.13131387531757, 62.50650532543659, 59.79197658598423, 63.21948006749153, 66.06646209955215, 71.76225006580353, 71.78317174315453, 70.64644753932953, 56.42974980175495, 43.63332465291023, 4.237713105976582, 0.13124580349540338, 0.6472676584962755, 2.96859260648489, 1.0201428970322013, 5.962674720212817, 0.7646167615894228, 9.524666760116816, 22.097719945013523, 38.69954779744148, 30.70899836719036, 29.018318988382816, 58.394833356142044, 22.334278151392937, 0.3720417770091444, 0.010651435186446179, 0.041767470102058724, 0.007993036233528983, 0.06674696604022756, 0.05024816971854307, 0.044331167300697416, 0.05166409471712541, 0.0125146507343743, 0.029811081403749995, 0.048790517466841266, 0.053645436055376194, 0.027373892553441692, 0.07394404703518376, 0.011230157306272304, 0.021095091287861578, 0.03699065884575248, 0.03552626418240834, 0.021407592976174783, 0.02337134170375066, 0.02266954459628323, 0.04925603701849468, 0.0315785803104518, 0.03991548881458584, 0.038398201286327094, 0.022003917911206372, 0.019469492872303817, 0.0335500028450042, 0.054281757184071466, 0.0305109804685344, 0.0587100596021628, 0.030487224321404938, 0.0327350616134936, 0.08680724742589518, 0.056888265171437524, 0.02979840552143287, 0.12561809766339138, 0.0605986436130479, 0.057829783399938606, 0.015525399139733054, 0.03209730071830563, 0.07958596499520354, 0.15966677921824157, 0.009166263171209721, 0.03154519850795623, 0.08760397264268249, 0.09738000939250924, 0.07632441891473718, 0.055324226050288416, 0.011278400615992723, 0.05326566053554416, 0.04991494912246708, 0.24801542283967137, 2.640376193448901, 65.815249979496, 64.91140007972717, 14.889229349792004, 59.58617202937603, 20.409833416342735, 32.137653306126595, 64.13332343101501, 2.277453155256808, 4.088362120091915, 10.087290219962597, 16.26578338444233, 0.24750056531047449, 0.09777287268661894, 58.01528312265873, 94.12839710712433, 76.50452479720116, 93.98918017745018, 80.81695139408112, 86.57608956098557, 84.82657983899117, 82.69637614488602, 72.35779970884323, 65.02843379974365, 64.93819624185562, 59.14127670228481, 63.91852855682373, 65.56918278336525, 69.64932784438133, 65.87385803461075, 64.69371736049652, 64.52043905854225, 66.34741142392159, 67.10978731513023, 70.68044051527977, 69.68686982989311, 71.63440212607384, 70.33861085772514, 72.02896535396576, 75.07409155368805, 72.74448215961456, 68.71311128139496, 68.42315644025803, 60.49545183777809, 55.29877468943596, 50.844809487462044, 54.38595727086067, 50.25529012084007, 53.766145929694176, 64.33573096990585, 69.4476954638958, 68.13400715589523, 65.34948617219925, 64.69636961817741, 66.25857219099998, 64.27282154560089, 68.65362167358398, 67.23413944244385, 66.85070961713791, 68.18472683429718, 44.577342197299004, 61.02109283208847, 65.77485054731369, 67.7475754916668, 67.94853150844574, 67.54804819822311, 60.450143069028854, 56.984843015670776, 52.43378542363644, 54.264268800616264, 54.01258550584316, 52.49977648258209, 50.79849757254124, 50.81362836062908, 50.08382432162762, 46.86247117817402, 47.57907472550869, 47.6179276406765, 49.79735389351845, 52.78450280427933, 60.20445965230465, 63.76525238156319, 66.22915416955948, 65.20843774080276, 64.07796040177345, 63.69891934096813, 67.40263760089874, 67.8281919658184, 63.97476553916931, 65.91481983661652, 66.67958199977875, 65.24247631430626, 59.98522661626339, 49.20767493546009, 50.46052470803261, 52.53367066383362, 56.7810295522213, 57.5106056034565, 59.493187218904495, 57.49659575521946, 64.69799593091011, 60.93582160770893, 64.53439190983772, 70.13504818081856, 76.07007130980492, 75.07592305541039, 71.66213303804398, 59.71783496439457, 52.68849715590477, 3.0945981200784445, 0.07311094173928723, 2.3863477120175958, 5.019169673323631, 4.232887364923954, 2.581034777686, 0.3575966146308929, 12.064849454909563, 26.308775581419468, 47.29993790388107, 45.18294610083103, 27.270549573004246, 67.52236157655716, 24.164299853146076, 0.37201452534645796, 0.044552624167408794, 0.011654105455818353, 0.05692926511983387, 0.03374772582901642, 0.049598226469242945, 0.03589428779378068, 0.07565914289443754, 0.0725105962192174, 0.052069437224417925, 0.06963950887438841, 0.1122413385019172, 0.024331940549018327, 0.044110979506513104, 0.07075568413711153, 0.039658724272158, 0.07678888461668976, 0.008397102246817667, 0.10811411426402628, 0.09258142352337018, 0.053918490739306435, 0.0453563218616182, 0.10991411923896521, 0.03585017824661918, 0.15332009556004778, 0.10774851005407982, 0.17537755571538582, 0.1330325091839768, 0.17477651999797672, 0.1823570390115492, 0.13501389505108818, 0.12475463852752, 0.16888840938918293, 0.18392865546047688, 0.26715241314377636, 0.24971960170660168, 0.27591999736614525, 0.14091254415689036, 0.12206943691126071, 0.11892469745362177, 0.29590368911158293, 0.15086115250596777, 0.49180562084075063, 0.22363257652614266, 0.1356007854337804, 0.30345762439537793, 0.2130043093347922, 0.3435432171681896, 0.204941913834773, 0.24466845556162298, 0.36126234917901456, 0.5043418903369457, 1.1547067388892174, 8.46822939813137, 84.24079567193985, 85.09600818157196, 29.11090862005949, 79.97078999876976, 41.16994723677635, 31.615475825965405, 66.32892161607742, 2.803975702263415, 10.941377989947796, 43.31255726516247, 34.834155812859535, 0.15922889724606648, 0.1668651812360622, 60.01793526113033, 97.68183723092079, 79.7631387412548, 96.11196666955948, 85.57308778166771, 89.63959157466888, 89.99089792370796, 86.71986624598503, 76.59388080239296, 67.92477518320084, 70.0262600183487, 61.7917674779892, 66.10097944736481, 68.12119424343109, 75.82323655486107, 71.19735717773438, 69.31747645139694, 65.48535168170929, 70.47275885939598, 70.99349051713943, 75.80457955598831, 73.92722949385643, 74.87462505698204, 74.01897937059402, 75.57213842868805, 78.43490481376648, 76.25509858131409, 72.35000252723694, 71.87787786126137, 65.03177762031555, 58.25470067560673, 50.993719696998596, 57.89359465241432, 53.474811762571335, 57.77160219848156, 67.32970431447029, 74.16150972247124, 69.7540882229805, 71.02276414632797, 67.48128578066826, 70.02167746424675, 66.13336890935898, 71.87615275382996, 67.45664030313492, 71.5090924501419, 69.52782556414604, 49.7438907623291, 61.48368000984192, 69.18331325054169, 68.97294893860817, 69.91329967975616, 67.14435026049614, 63.029619455337524, 58.39304745197296, 55.051043182611465, 55.858610048890114, 57.473842576146126, 54.81573320925236, 53.89012187719345, 52.987354919314384, 53.369002640247345, 50.11907123029232, 50.02754174172878, 50.38328245282173, 54.10211630165577, 57.19070076942444, 62.359221428632736, 65.31800866127014, 67.79945030808449, 67.0750267803669, 66.87365278601646, 65.02071261405945, 69.50735226273537, 69.47846621274948, 67.99628734588623, 64.66079592704773, 69.3313381075859, 68.22534665465355, 64.86964792013168, 52.44758628308773, 53.064669370651245, 54.895171746611595, 59.99074772000313, 59.73774969577789, 64.3991419672966, 62.66170799732208, 69.79547560214996, 63.011654019355774, 68.12357291579247, 71.66900306940079, 78.06366473436356, 74.79164510965347, 77.723438590765, 64.00463953614235, 52.17963606119156, 4.727137293666601, 0.20611415093299001, 1.4864885481074452, 11.25446978956461, 9.57990724593401, 15.80252269282937, 2.7951226523146033, 13.29737601801753, 32.20046393573284, 57.58765026926994, 46.866977736353874, 42.904299572110176, 81.01523235440254, 45.29806472361088, 0.6393561861477792, 0.15069623244926333, 0.09214567151502706, 0.11627794650848955, 0.18607778154546395, 0.09252267511328682, 0.19631916715297848, 0.0787544107879512, 0.15646600018953905, 0.21460630930960178, 0.22784278029575944, 0.22941702394746244, 0.11141149865579791, 0.33483595470897853, 0.13446687284158543, 0.0812097915331833, 0.1302090083481744, 0.10904373586527072, 0.3198154200799763, 0.15503120608627796, 0.1359345589298755, 0.11421082032029517, 0.16392109624575824, 0.11301198464934714], [0.065610084857326, 0.05635182598780375, 0.0445401189790573, 0.030682225478813052, 0.05306687256961595, 0.0874711356300395, 0.004547620283119613, 0.04185052755929064, 0.10407055975520052, 0.025601612360333093, 0.040234530679299496, 0.027686516696121544, 0.08288795070257038, 0.053060504942550324, 0.07088245038175955, 0.04503815944190137, 0.07582625970826484, 0.019541245565051213, 0.02384839979640674, 0.06381801344105043, 0.05262890896119643, 0.06285416398895904, 0.056349454825976864, 0.05598354633548297, 0.02474463402904803, 0.17035333468811586, 0.1521985768340528, 0.25198454735800624, 0.19723151897778735, 0.25651524018030614, 26.54004067182541, 58.50479565560818, 71.84065505862236, 65.7879750430584, 74.13331523537636, 25.867237374186516, 39.54138122498989, 8.89166347682476, 1.7399329296313226, 10.737867560237646, 10.985626615583897, 3.0923650274053216, 0.6504292669706047, 1.3047691178508103, 75.44374331831932, 93.56234908103943, 72.63564839959145, 84.35724422335625, 82.45044574141502, 80.01854583621025, 81.20792001485825, 80.7208925485611, 69.28612053394318, 58.73160928487778, 62.5860920548439, 65.8751879632473, 68.13676580786705, 61.95328541100025, 65.33429458737373, 62.66598276793957, 64.1616091132164, 64.12437871098518, 66.98555678129196, 65.1620802283287, 68.85861307382584, 66.69975891709328, 74.54688504338264, 72.28776186704636, 71.37803748250008, 71.6316206753254, 71.24263554811478, 69.75326746702194, 64.73347842693329, 57.49747730791569, 48.72279055416584, 49.73127543926239, 50.03414958715439, 50.2895300835371, 60.734941586852074, 68.67373019456863, 66.80306017398834, 63.79388764500618, 63.212701231241226, 62.35186502337456, 60.24530366063118, 65.4725843667984, 64.06441032886505, 64.54412698745728, 64.36105281114578, 41.00557565689087, 59.57178220152855, 64.45635929703712, 66.41303390264511, 65.73882088065147, 59.50893357396126, 55.31061865389347, 53.78260284662247, 49.69088360667229, 50.47108054161072, 49.038576409220695, 46.546970307826996, 48.078352734446526, 45.88526241481304, 47.2559704631567, 45.788512006402016, 46.466182842850685, 47.12527647614479, 47.394549027085304, 50.73687627911568, 57.55077324807644, 62.600242495536804, 63.56639005243778, 64.72523286938667, 63.597362190485, 63.99508684873581, 64.88255962729454, 66.90880849957466, 65.91283634305, 65.87581112980843, 66.10391288995743, 61.889308243989944, 60.724670737981796, 50.72639264166355, 48.0224197357893, 48.976920917630196, 52.37165495753288, 55.99559269845486, 58.26887011528015, 62.7136892080307, 58.955326080322266, 63.06150734424591, 64.20538276433945, 65.95455050468445, 70.60914874076843, 72.53261312842369, 59.95691433548927, 54.083041325211525, 12.06995828077197, 0.13540508109144866, 0.17269026866415516, 1.4095634571276605, 4.025646485388279, 1.6098214988596737, 1.6667888732627034, 0.18856571288779378, 7.972054872661829, 34.5402567833662, 36.224751994013786, 15.846471134573221, 33.63151654601097, 35.632994547486305, 1.5323101705871522, 0.1650773177971132, 0.060415017724153586, 0.034173759413533844, 0.16090848133899271, 0.028621055025723763, 0.021642044848704245, 0.05462122666358482, 0.08846332028042525, 0.05231676906987559, 0.024286302177642938, 0.020332939020590857, 0.05707020638510585, 0.030676928399770986, 0.07108774327207357, 0.01528062770375982, 0.05037135510065127, 0.01658080920606153, 0.012305595155339688, 0.0406714589917101, 0.0317595084925415, 0.05549125751713291, 0.07666661578696221, 0.0047878952318569645, 0.14957489183871076, 0.09007942848256789, 0.07297597476281226, 0.017368316948704887, 0.07946813420858234, 0.05100867441797163, 0.04556332540232688, 0.019614360098785255, 0.02345187956962036, 0.12796460534445941, 0.043185254180571064, 0.07175969862146303, 0.028011603353661485, 0.04189867810055148, 0.03314684596261941, 0.05345602512534242, 0.05504409498826135, 0.06041798260412179, 0.12272703170310706, 0.06816525477916002, 0.07456552149960771, 0.07104023097781464, 0.003704004088831425, 0.030507317969750147, 0.030370592103281524, 0.027008436773030553, 0.03447017690632492, 0.06694638112094253, 0.20287014922359958, 0.13399687071796507, 0.29167929547838867, 36.44346445798874, 72.26265281438828, 55.771906301379204, 78.13921988010406, 72.33395218849182, 21.435098201036453, 60.174467861652374, 7.9711077734827995, 1.16000531706959, 3.4006270486861467, 5.566224893555045, 6.006165286526084, 0.5366725148633122, 2.039299509488046, 86.10908702015877, 92.94751927256584, 73.02514269948006, 86.38919278979301, 84.99567836523056, 83.15549030900002, 84.2771065235138, 81.83986410498619, 71.3700807094574, 60.818164721131325, 66.07891023159027, 68.67779597640038, 70.24266600608826, 66.88138157129288, 67.41232708096504, 67.16168493032455, 67.15628162026405, 66.69399842619896, 70.71237400174141, 68.29151630401611, 71.24464184045792, 72.09695890545845, 76.63234993815422, 72.89386734366417, 75.55593609809875, 75.4124253988266, 73.39037910103798, 71.69101148843765, 67.79589369893074, 59.56200532615185, 51.52326688170433, 50.10628491640091, 52.616726607084274, 53.838418051600456, 64.38922449946404, 70.72528570890427, 70.04019767045975, 66.17243081331253, 66.92075505852699, 64.56712335348129, 64.51341703534126, 65.61091974377632, 66.71698719263077, 68.89766737818718, 67.59912505745888, 43.54341767728329, 62.16053768992424, 66.90582945942879, 70.57340025901794, 68.16775694489479, 63.95788684487343, 57.01866880059242, 54.95857134461403, 51.513983979821205, 53.82693886756897, 50.40573924779892, 50.49506105482578, 50.10968193411827, 49.86430250108242, 49.66126039624214, 49.5060159265995, 48.41083489358425, 49.35188479721546, 50.614823028445244, 53.49614381790161, 60.67486301064491, 65.30560612678528, 65.36505773663521, 66.18824556469917, 64.72061231732368, 67.21628800034523, 67.6048855483532, 69.43176671862602, 66.55697017908096, 68.7288348376751, 69.18515235185623, 67.20111161470413, 62.823317125439644, 54.075931906700134, 51.188546642661095, 53.43505449593067, 54.883791357278824, 59.7405843436718, 62.062107771635056, 66.01404011249542, 61.418771892786026, 65.28143182396889, 66.6357171535492, 70.22242829203606, 70.4998742043972, 76.76399007439613, 62.096203342080116, 61.941445246338844, 10.580283366143703, 0.11880006117280573, 0.700126503361389, 3.7949886498972774, 5.202884590253234, 3.427535304799676, 0.5694666551426053, 0.2872150990879163, 10.606047883629799, 38.04698221385479, 51.37711152434349, 21.56435776501894, 38.599605560302734, 42.075146064162254, 2.1597948437556624, 0.1593029487412423, 0.08328042807988822, 0.0162659233683371, 0.24048315826803446, 0.05448703152069356, 0.035657932312460616, 0.061149499015300535, 0.02488813755917363, 0.10516732785617933, 0.055917335630510934, 0.030968171267886646, 0.09233147560735233, 0.01884166747913696, 0.02058683330687927, 0.049017826167983, 0.057240202731918544, 0.017855067490017973, 0.08834063584799878, 0.011168077580805402, 0.009913322937791236, 0.06325209615170024, 0.08023472080822103, 0.036868772222078405, 0.02523173337976914, 0.210299878672231, 0.2564171579433605, 0.14831315173069015, 0.20803422055905685, 0.15872509771725163, 0.2093771516229026, 0.1229971660359297, 0.1427533375681378, 0.2739389083581045, 0.12667540577240288, 0.15373651462141424, 0.15162235853495076, 0.1568999933078885, 0.16365358169423416, 0.12004988981061615, 0.1251601183321327, 0.10608782846247777, 0.3499205515254289, 0.12191191606689245, 0.1498386065941304, 0.1552891024039127, 0.1375021380954422, 0.09139250294538215, 0.18828840198693797, 0.12396087447996251, 0.3105801937635988, 0.27593546372372657, 0.41749695665203035, 0.28289232635870576, 0.4674812260782346, 61.224096938967705, 83.49528327584267, 77.62249320745468, 90.04085764288902, 100.66533073782921, 33.47501054406166, 52.6529386639595, 10.127631705254316, 3.436080808751285, 28.401169404387474, 23.852366991341114, 6.041256878525019, 0.6502659351099283, 2.645764066837728, 87.81637340784073, 98.46440523862839, 78.02306771278381, 91.21918961405754, 88.54444473981857, 85.4789288341999, 86.53082638978958, 86.85485020279884, 75.77645346522331, 64.57602247595787, 68.35634082555771, 73.39898943901062, 75.35854429006577, 67.83851981163025, 71.74555376172066, 73.06810319423676, 71.15391030907631, 69.54799488186836, 73.77543523907661, 69.20972183346748, 73.91465216875076, 73.48725110292435, 81.71732068061829, 76.09579592943192, 75.85246458649635, 80.71612760424614, 79.1496692597866, 75.06543561816216, 73.24697479605675, 63.569787070155144, 54.49246555566788, 53.98932695388794, 57.61165738105774, 55.912076979875565, 66.73806846141815, 75.21500319242477, 73.15323382616043, 68.2445964217186, 70.73129698634148, 68.19132328033447, 66.63774624466896, 68.26825395226479, 70.66328063607216, 72.88990035653114, 70.79979971051216, 46.58990420401096, 65.11772900819778, 69.85582396388054, 71.4205040037632, 73.36951822042465, 65.61385318636894, 60.68792290985584, 58.08478519320488, 53.69193971157074, 57.06719219684601, 52.27947950363159, 52.84320205450058, 51.33697807788849, 51.708392947912216, 52.400898188352585, 53.1779070943594, 50.807852670550346, 54.37904164195061, 53.830149695277214, 57.96135261654854, 61.5959145873785, 69.16975557804108, 67.81499907374382, 71.306973695755, 69.15825739502907, 70.67718788981438, 70.40689319372177, 74.36204016208649, 67.58332550525665, 69.465022534132, 73.1287631392479, 70.720946341753, 66.41692489385605, 58.4738577157259, 55.74817277491093, 57.490717470645905, 58.66510905325413, 63.612025603652, 64.26184013485909, 70.79083979129791, 64.7991693019867, 70.45139640569687, 68.92234325408936, 72.29539185762405, 72.76075288653374, 79.80529367923737, 67.73404821753502, 62.071721255779266, 12.636053804308176, 0.3260044567286968, 0.33318847592454404, 4.503147387877107, 13.026747889816761, 7.283236859366298, 3.6135486233979464, 0.8695041364990175, 12.449328973889351, 53.44080738723278, 49.884270429611206, 26.509433314204216, 50.45799404382706, 58.660708889365196, 4.068016586825252, 0.6084396201185882, 0.239280300156679, 0.14882026123814285, 0.24394729582127184, 0.1439302205108106, 0.14249426865717396, 0.1307210754021071, 0.12420592422131449, 0.19095357303740457, 0.12761578109348193, 0.16438951017335057, 0.15722116513643414, 0.15344308427302167, 0.12882107344921678, 0.1520908169914037, 0.17385496554197744, 0.2136707431054674, 0.17636088654398918, 0.1352536235935986, 0.09487560237175785, 0.20298743824241683, 0.14089779026107863, 0.17604821972781792, 0.15302853542380035], [0.0494847446680069, 0.06574053957592696, 0.030375254646060057, 0.06376644902047701, 0.003254355597164249, 0.040038180668489076, 0.022759184903407004, 0.09791345029952936, 0.056059508860926144, 0.061580412220791914, 0.0350815767160384, 0.03022676017280901, 0.06990077454247512, 0.09138698878814466, 0.022975838219281286, 0.08815685039735399, 0.06729337968863547, 0.14498929493129253, 0.028023897029925138, 0.16875773202627897, 0.06408985471352935, 0.03305372498289216, 0.16469447349663824, 0.13241864915471524, 0.13504539179848507, 0.1888931484427303, 0.10857234592549503, 0.43407294375356287, 0.18800681631546468, 0.5473505356349051, 9.086405877023935, 56.8401999771595, 78.88532504439354, 55.73869988322258, 38.349142000079155, 42.618684098124504, 23.573461957275867, 17.43910152465105, 0.2699119853787124, 6.336699100211263, 4.121786551550031, 7.739246590062976, 0.19408657914027572, 0.19785170210525393, 2.3841238813474774, 52.23838470876217, 94.06540408730507, 72.41645336151123, 80.23549899458885, 80.85766240954399, 85.61452075839043, 75.29055073857307, 74.06203106045723, 61.48338742554188, 67.98625588417053, 67.06583127379417, 76.77001655101776, 67.50446453690529, 66.72821179032326, 59.12635490298271, 66.00397065281868, 64.11621674895287, 68.9573621749878, 66.74082711338997, 71.50612860918045, 69.89940002560616, 77.62372434139252, 72.92700916528702, 72.12867960333824, 66.9257327914238, 71.74342587590218, 69.8018516600132, 69.15996730327606, 61.0301249474287, 51.63614742457867, 48.6310026794672, 53.354502618312836, 50.023213773965836, 58.671006336808205, 68.1407555937767, 70.67303091287613, 68.0173534154892, 66.5993683040142, 67.36673712730408, 66.69112578034401, 66.45345613360405, 66.5955001115799, 66.18342742323875, 63.98133158683777, 23.889954574406147, 57.635725289583206, 62.18212053179741, 66.22653231024742, 66.71549767255783, 64.71304312348366, 66.09506696462631, 61.01913973689079, 58.996082693338394, 54.7260732203722, 51.85265600681305, 49.770348742604256, 47.224067375063896, 47.86570854485035, 45.666169971227646, 46.36734254658222, 45.26917867362499, 49.086913615465164, 47.98682704567909, 52.80836172401905, 56.84993125498295, 62.9308095574379, 64.99963134527206, 64.57938149571419, 63.57372745871544, 61.81073606014252, 63.75635325908661, 65.18441542983055, 66.5521140396595, 61.611429154872894, 66.4229665696621, 64.59918603301048, 62.88986295461655, 55.307954996824265, 48.531250432133675, 47.93991096317768, 52.599756717681885, 55.877263247966766, 61.69022552669048, 60.9585215896368, 64.26005423069, 59.93150509893894, 64.30195078253746, 67.91139990091324, 73.98500919342041, 66.19861900806427, 68.38588804006577, 28.719094544649124, 0.9378546907100827, 0.13094165653456002, 1.8664397788234055, 4.894735850393772, 3.4445165935903788, 1.7281825351528823, 1.7937095439992845, 0.23534575972007588, 13.237021006643772, 44.331852570176125, 48.916295170784, 69.57654654979706, 47.256179451942444, 22.842768765985966, 0.21868448500754312, 0.06432129346649162, 0.05142771697137505, 0.04633540018403437, 0.05995106039335951, 0.02917282698035706, 0.02745197019976331, 0.03802375809755176, 0.015828015420993324, 0.04190863030089531, 0.053882515130680986, 0.009339685457234737, 0.0757127556425985, 0.008859549307089765, 0.01744107710692333, 0.061952710602781735, 0.04242161761794705, 0.048603945251670666, 0.06865123534225859, 0.023619912935828324, 0.02047991394647397, 0.018857178365578875, 0.07943833697936498, 0.04428756241395604, 0.05418227970949374, 0.023713822447462007, 0.043676622735802084, 0.06345381189021282, 0.05295217735692859, 0.038898924613022245, 0.04725577833596617, 0.022835522213426884, 0.08756868352065794, 0.02018827959545888, 0.10219510062597692, 0.011319272543914849, 0.059973246898152865, 0.018281969387317076, 0.0980534045083914, 0.07202355438494124, 0.047229228002834134, 0.051751786886597984, 0.1432935320190154, 0.07833302675862797, 0.21353763149818406, 0.09338810094050132, 0.03253472998039797, 0.13629080465761945, 0.16653755272272974, 0.24341137614101171, 0.10962621789076366, 0.11259966966463253, 0.6191495829261839, 0.36081094527617097, 1.3099052547477186, 12.403428386896849, 64.73616108298302, 87.63277485966682, 61.6843244433403, 64.41630184650421, 36.87059573829174, 30.874658077955246, 22.958164773881435, 0.3195964568294585, 5.040882658213377, 1.791345002129674, 12.346291802823544, 0.7054783974308521, 0.38460229989141226, 3.223273940384388, 62.83057473599911, 97.15828612446785, 70.85353642702103, 83.10605496168137, 85.35352036356926, 87.89629071950912, 77.88135051727295, 76.31035521626472, 64.34721395373344, 69.54501584172249, 69.70549643039703, 79.61172446608543, 70.20371049642563, 68.22176724672318, 63.02734337747097, 70.33218160271645, 67.22537711262703, 71.52099341154099, 71.60911068320274, 75.29341578483582, 70.66943630576134, 78.95829632878304, 75.34269914031029, 76.73679873347282, 71.0884702205658, 73.67230117321014, 70.2849805355072, 70.6866417825222, 63.66443619132042, 54.58052583038807, 51.78856864571571, 54.18728493154049, 51.717987433075905, 62.10780791938305, 70.4006615281105, 75.16160845756531, 70.31124472618103, 69.49147671461105, 68.59929978847504, 69.79324132204056, 67.18227982521057, 71.01563572883606, 68.2190389931202, 66.84721380472183, 27.89814669638872, 59.31124158203602, 64.86703366041183, 68.49624171853065, 70.23055225610733, 69.8248328268528, 67.26199194788933, 62.1324609965086, 60.50818495452404, 56.949273124337196, 53.35712067782879, 52.071277275681496, 49.78122375905514, 49.397626742720604, 49.468432143330574, 48.732981607317924, 48.245045989751816, 50.9857477247715, 51.33739225566387, 55.94262354075909, 59.677287340164185, 65.5527600646019, 68.97088944911957, 67.06144630908966, 66.78863614797592, 65.00623539090157, 65.83306342363358, 70.16507416963577, 71.3447816669941, 63.254119008779526, 69.11399737000465, 66.46101012825966, 67.81442150473595, 60.064209178090096, 50.09377598762512, 51.082695722579956, 57.20981374382973, 59.99094530940056, 64.19100433588028, 63.929517567157745, 66.22918456792831, 64.43732991814613, 68.22457149624825, 70.64980655908585, 78.81888180971146, 69.11993265151978, 74.42369565367699, 33.14777210354805, 0.7297600444871932, 0.1901684995391406, 4.647036641836166, 3.831168171018362, 3.46422566100955, 0.7378432201221585, 0.704792415490374, 0.30153216677717865, 18.044593334197998, 53.81165228784084, 53.73286351561546, 58.97461764514446, 54.47543486952782, 29.188812039792538, 0.43687128578312695, 0.12255595924216323, 0.07657035923330113, 0.09378005139296874, 0.08937950900872238, 0.021972990762151312, 0.012543467400973896, 0.07554022115073167, 0.056702976871747524, 0.056378201916231774, 0.13317396253114566, 0.011129894082841929, 0.03624722725362517, 0.016662553061905783, 0.036128862120676786, 0.05651804109220393, 0.029520283824240323, 0.0679107203905005, 0.008189249874703819, 0.03421273700951133, 0.019161932032147888, 0.03484764805762097, 0.056116832347470336, 0.050545778358355165, 0.12476467236410826, 0.12190804205602035, 0.0832108294707723, 0.13080683798762038, 0.20752662123413756, 0.10387678499682806, 0.1496425163350068, 0.1705827919067815, 0.3123152756597847, 0.12849648774135858, 0.17503073526313528, 0.06479064250015654, 0.15742455812869594, 0.16084814473288134, 0.24244869186077267, 0.19904400687664747, 0.26233575597871095, 0.1567791122943163, 0.3637631790479645, 0.17713588167680427, 0.36974910472054034, 0.28022935206536204, 0.24603817815659568, 0.29122486361302435, 0.30821007094345987, 0.40636512741912156, 0.3960931801702827, 0.347940293722786, 0.9728893451392651, 0.8549410023260862, 1.867647401522845, 22.616766393184662, 84.28373336791992, 95.83529591560364, 64.35229808092117, 57.769257724285126, 59.90751698613167, 34.60890009999275, 21.890518963336945, 0.16164414264494553, 9.958741217851639, 12.24362701177597, 17.499732971191406, 0.43199442559853196, 0.834064269438386, 3.799095991998911, 63.47750902175903, 100.13907417654991, 73.90835210680962, 85.46995371580124, 89.27525192499161, 91.66040673851967, 79.53347146511078, 78.3083564043045, 70.54493978619576, 75.54120808839798, 73.88258948922157, 85.27027443051338, 74.23455700278282, 72.16563642024994, 66.37663185596466, 76.02317422628403, 68.23715642094612, 75.3193911910057, 75.93985989689827, 78.43952536582947, 72.49909892678261, 82.25398108363152, 77.84969061613083, 79.72932055592537, 73.38149517774582, 74.95430678129196, 73.16583395004272, 75.54557785391808, 67.67823681235313, 58.174296990036964, 54.286710396409035, 57.88747698068619, 55.33017240464687, 65.0249607861042, 74.0921938419342, 79.45621401071548, 73.66847857832909, 73.83091226220131, 73.06814879179001, 73.29016327857971, 69.45260480046272, 71.41709938645363, 69.59134295582771, 70.07826402783394, 28.577126562595367, 62.326926961541176, 66.16395726799965, 70.97355678677559, 72.47152000665665, 71.53393551707268, 72.78945654630661, 66.58359915018082, 63.88968050479889, 60.549469739198685, 56.33013054728508, 55.097769275307655, 52.3777574300766, 53.202001601457596, 50.474800541996956, 50.69134332239628, 49.80078510940075, 56.09885975718498, 52.38425888121128, 59.06107820570469, 63.00392523407936, 67.23825082182884, 71.15206360816956, 70.61353370547295, 67.40955322980881, 66.3164658844471, 71.03832051157951, 72.45601683855057, 74.52113762497902, 63.607192263007164, 69.48298797011375, 69.19666573405266, 71.9143559038639, 62.60534182190895, 53.518938794732094, 54.32559750974178, 60.54069221019745, 63.36075268685818, 65.8727864921093, 67.76864916086197, 70.29548317193985, 67.01967135071754, 69.24844935536385, 73.72313484549522, 78.72229099273682, 74.42249491810799, 74.2055493593216, 36.16906218230724, 1.1511590355075896, 0.240123528346885, 6.333608916029334, 17.738215774297714, 9.865304231643677, 8.589997664093971, 6.151452390477061, 0.44986305583734065, 25.27345273643732, 61.18022829294205, 57.893400862812996, 73.34412038326263, 65.90532034635544, 43.105745762586594, 0.5527922592591494, 0.1975500932894647, 0.26125542644876987, 0.18868208164349198, 0.20310831925598904, 0.14617071981774643, 0.1168352623062674, 0.13535675243474543, 0.177274574234616, 0.12531550921266899, 0.32686139980796725, 0.13465423544403166, 0.15494792227400467, 0.3737066814210266, 0.2144603437045589, 0.13184140669181943, 0.11893893184605986, 0.22145455121062696, 0.20298123388784006, 0.11598494660574943, 0.06867933305329643, 0.22197564278030768, 0.3098028089152649, 0.12635540653718635, 0.2267224935349077], [0.034347937762504444, 0.09913657646393403, 0.06505682118586265, 0.03552550348103978, 0.058642910080379806, 0.004251955142535735, 0.022988829514360987, 0.18085712887113914, 0.023617148435732815, 0.01654605999647174, 0.03611461288528517, 0.05324980826117098, 0.01663667251705192, 0.09155904830549844, 0.050243060031789355, 0.012707556252280483, 0.08774440182605758, 0.044476631956058554, 0.04131901994696818, 0.018491587143216748, 0.022371292143361643, 0.04856060753809288, 0.07327842962695286, 0.04666685075790156, 0.025740162054717075, 0.02587281724117929, 0.10093607677845284, 0.014904319868946914, 0.08326436800416559, 0.17516178369987756, 0.33385658694896847, 25.672577619552612, 62.781059592962265, 40.733943432569504, 25.200599245727062, 57.0201925188303, 43.348776921629906, 10.60281615704298, 0.031065349940035958, 0.3690583136631176, 1.9698679726570845, 1.800380798522383, 0.33628643781412393, 0.3553365671541542, 0.15235750033752993, 0.2694029314443469, 21.495948135852814, 85.52517235279083, 76.97452917695045, 84.89732444286346, 85.30125796794891, 88.82721036672592, 74.39094141125679, 62.6058965921402, 65.46567633748055, 76.07967719435692, 72.24004402756691, 69.52056795358658, 64.38040897250175, 64.98579248785973, 65.09578138589859, 67.62357294559479, 67.79503494501114, 69.55082193017006, 73.82225632667542, 75.79614400863647, 75.98115608096123, 75.54098010063171, 67.96078965067863, 68.7015675008297, 71.21776208281517, 71.19810953736305, 68.57032254338264, 65.10164827108383, 55.06425887346268, 48.96908573806286, 52.859860360622406, 50.77870063483715, 57.29964092373848, 67.80438244342804, 69.40296426415443, 66.67100965976715, 67.29732245206833, 64.2969198524952, 64.88460391759872, 66.57041385769844, 67.79789999127388, 65.97425624728203, 64.35210049152374, 23.72759308665991, 54.48214910924435, 61.76490671932697, 61.1437426507473, 67.14983716607094, 65.14261767268181, 66.87390357255936, 65.58927610516548, 62.233052998781204, 59.55116830766201, 55.396699234843254, 51.5657752007246, 49.00375507771969, 47.80273452401161, 46.82216294109821, 45.256335362792015, 47.97055631875992, 47.398725003004074, 48.44098627567291, 51.22343637049198, 56.27453573048115, 61.82733736932278, 65.77445536851883, 65.79311236739159, 63.8769967854023, 63.24742756783962, 61.69074609875679, 64.83220472931862, 68.13229724764824, 66.93947285413742, 63.38583514094353, 65.3165191411972, 62.08085976541042, 59.167689085006714, 49.46242846548557, 50.54597832262516, 51.26110374927521, 59.9438164383173, 62.71915331482887, 65.60865506529808, 62.705907225608826, 66.03788763284683, 69.5993909239769, 68.57262521982193, 70.9703041613102, 70.09959608316422, 36.20574541389942, 4.333780976012349, 0.02949642377643613, 0.8971077552996576, 2.2780437860637903, 4.233797416090965, 0.8796216279733926, 1.697838194668293, 0.26372048479970545, 1.4075665455311537, 41.176767870783806, 38.8142978399992, 94.45889577269554, 51.49935096502304, 49.24252666532993, 9.220622275024652, 0.4803712625289336, 0.15493834856897593, 0.08224378878367133, 0.07112922190572135, 0.051904279680456966, 0.055802774004405364, 0.07327146086026914, 0.04241604408889543, 0.02749150626186747, 0.07287717264262028, 0.022051537816878408, 0.11522353277541697, 0.03682389455207158, 0.03903514581907075, 0.0610120013152482, 0.041451719662291, 0.02879968440538505, 0.04630490162526257, 0.011852165189338848, 0.013796500261378242, 0.0790533701365348, 0.04232676001265645, 0.03836457457509823, 0.023506282705056947, 0.027406556328060105, 0.09152963699307293, 0.0783615697582718, 0.044489567590062506, 0.07000520214205608, 0.02186176694522146, 0.030317448763526045, 0.005732237332267687, 0.020333397296781186, 0.02538248027121881, 0.04623394488589838, 0.005486276140800328, 0.05685496871592477, 0.014414380875678034, 0.0795813265722245, 0.008842812949296786, 0.07148481454350986, 0.04935352182656061, 0.024217653517553117, 0.04882838184130378, 0.04547105047095101, 0.018394508661003783, 0.044087215937906876, 0.014810192351433216, 0.04737637362268288, 0.03680073583382182, 0.08537011555745266, 0.06930837000254542, 0.0764710598741658, 0.06394705807906576, 0.14719066821271554, 0.8853786159306765, 31.141046583652496, 80.70571616292, 32.937795370817184, 28.652544915676117, 75.5663551390171, 38.80739361047745, 15.351266507059336, 0.18184391810791567, 1.7182300379499793, 4.381940541788936, 3.638246823102236, 2.1935006976127625, 1.380189845804125, 0.26168916723690927, 0.0809312857745681, 31.37987706810236, 89.85092863440514, 77.61254534125328, 85.41516825556755, 88.19701418280602, 90.66226869821548, 75.29609844088554, 65.17488554120064, 70.36736771464348, 78.62947717308998, 74.63352799415588, 70.7334552705288, 69.41872581839561, 68.76387655735016, 70.04245474934578, 69.4417753815651, 68.39664906263351, 72.76323035359383, 74.11531180143356, 79.67953562736511, 78.68802443146706, 77.23008826375008, 72.03441426157951, 71.75671756267548, 73.91976669430733, 73.56700882315636, 71.41611903905869, 67.65889585018158, 55.87275668978691, 51.16303861141205, 56.20089568197727, 54.84926640987396, 61.659245789051056, 70.97183927893639, 73.42655315995216, 71.40180140733719, 72.33351901173592, 67.89497718214989, 71.12039610743523, 68.77098977565765, 69.55332979559898, 70.52575081586838, 67.85544410347939, 25.583236813545227, 60.01033566892147, 66.23212561011314, 66.25502318143845, 68.9012923836708, 68.6127282679081, 67.57525473833084, 68.91607359051704, 64.62881684303284, 63.35572175681591, 59.54707972705364, 52.93588288128376, 52.212663888931274, 51.726134195923805, 49.35816965997219, 49.33925807476044, 50.254271775484085, 48.69070887565613, 50.46877786517143, 52.889631763100624, 57.226019874215126, 64.96531918644905, 66.91779881715775, 67.21173584461212, 67.21056550741196, 67.14752689003944, 67.94736117124557, 67.64935836195946, 70.31497612595558, 68.70956987142563, 67.98504754900932, 69.42414432764053, 68.36117416620255, 64.38398078083992, 52.912004962563515, 55.57764932513237, 55.24568013846874, 62.40440480411053, 66.67390510439873, 69.40538853406906, 64.78480607271194, 69.56657588481903, 73.94937470555305, 72.5974528491497, 73.76167997717857, 71.46176978945732, 41.78652875125408, 3.745424346998334, 0.08128903806209564, 1.713428758084774, 3.275669328868389, 4.257703833281994, 1.404616478830576, 0.8682243176735938, 0.33949284232221544, 2.265565493144095, 49.012354016304016, 49.57304812967777, 78.9207011461258, 49.91491578519344, 60.98642349243164, 11.833364926278591, 0.5553432286251336, 0.08171291570761241, 0.06358768790960312, 0.025342272565467283, 0.060863946564495564, 0.05734110141929705, 0.05889510670385789, 0.025628902985772584, 0.033934535531443544, 0.027802087643067352, 0.021993479604134336, 0.06621667183935642, 0.0499277808557963, 0.009488713349128375, 0.08822369563858956, 0.0507837109034881, 0.0533779920078814, 0.06719091135892086, 0.006265361898840638, 0.030660205957246944, 0.06664498752797954, 0.04855773913732264, 0.036167271973681636, 0.03975875093601644, 0.030271235227701254, 0.13241048553027213, 0.2686104958411306, 0.11779214299167506, 0.1427047565812245, 0.1446038085850887, 0.09888176005915739, 0.13345725514227524, 0.2063444393570535, 0.13019501144299284, 0.13495956984115764, 0.11027086962712929, 0.13573787495261058, 0.10400767758255824, 0.17199355526827276, 0.09372350716148503, 0.20959008863428608, 0.18318673042813316, 0.1532038307050243, 0.2735843398841098, 0.15914893825538456, 0.1341253810096532, 0.11172691883984953, 0.2544380578910932, 0.21912573633017018, 0.12518812698544934, 0.26058200164698064, 0.2046877282555215, 0.15092825749889016, 0.27195428672712296, 0.5778953747358173, 1.0486213001422584, 52.97382764518261, 97.34002277255058, 57.32393302023411, 39.986823722720146, 82.82028749585152, 61.06218762695789, 21.252791583538055, 0.3299147734651342, 5.124006047844887, 9.426917005330324, 9.303021803498268, 1.5601455769501626, 0.5280530930031091, 0.38534177583642304, 0.37481209554243833, 29.50937233865261, 95.55759161710739, 81.46797806024551, 91.84826865792274, 92.18949034810066, 95.33209651708603, 77.45832681655884, 70.33465147018433, 71.11794903874397, 84.21573221683502, 75.67121431231499, 74.08587858080864, 71.49946376681328, 74.88283261656761, 71.5636271238327, 73.78250285983086, 72.62537375092506, 74.04287248849869, 78.26343521475792, 84.65231359004974, 81.13091334700584, 78.16312819719315, 73.78197848796844, 75.4996307194233, 74.79280784726143, 77.47009098529816, 74.69054013490677, 72.55253165960312, 59.983155727386475, 54.999814331531525, 60.01495622098446, 58.52543994784355, 64.2759981751442, 75.59242933988571, 75.40326789021492, 72.33652845025063, 75.50871223211288, 70.59907168149948, 71.05867981910706, 70.67313730716705, 74.04210492968559, 74.02251318097115, 69.5988817512989, 29.454334191977978, 60.79984210431576, 69.96501490473747, 68.0579200387001, 72.5300444662571, 70.79253450036049, 71.08048304915428, 73.5355693101883, 70.2493004500866, 67.30580359697342, 60.80638915300369, 56.38492740690708, 55.2238617092371, 55.5697875469923, 54.25919987261295, 50.920983999967575, 55.48479750752449, 53.35436962544918, 54.52529959380627, 55.06902001798153, 61.096875965595245, 68.3070270717144, 73.01468566060066, 70.62681779265404, 71.31582722067833, 71.54367059469223, 71.39440700411797, 70.88229328393936, 73.51273253560066, 71.12729653716087, 71.8076728284359, 73.54828342795372, 71.02231577038765, 68.87296110391617, 57.66412116587162, 58.890566155314445, 59.09066341817379, 65.7812038064003, 71.40637636184692, 70.00338524580002, 68.08762684464455, 73.82031843066216, 78.31545442342758, 72.59974032640457, 76.70712992548943, 73.659997433424, 40.7218486815691, 4.691001707687974, 0.2553856617305428, 1.287726319860667, 10.31627543270588, 13.208632729947567, 5.039555104449391, 3.486130773089826, 1.4261745032854378, 2.5693537294864655, 59.3061688542366, 54.59851026535034, 99.46387320756912, 65.26804134249687, 74.20139998197556, 20.230836421251297, 0.9741818101610988, 0.3547178237931803, 0.20456451689824462, 0.23147909610997885, 0.19861655950080603, 0.09899721597321332, 0.19791747123235837, 0.15789764758665115, 0.11892025941051543, 0.11151619342854246, 0.12503162288339809, 0.1789422839647159, 0.14746521832421422, 0.07628058025147766, 0.174741267983336, 0.1594198666862212, 0.12203402162413113, 0.1359985172166489, 0.12277131565497257, 0.13087370549328625, 0.1143299053364899, 0.14283571596024558, 0.13775587838608772, 0.13268699491163716, 0.05313422247127164], [0.16294533532345667, 0.06824631956988014, 0.06437498785089701, 0.011149864349135896, 0.03620303235948086, 0.06060949010134209, 0.08051533426623791, 0.05718995562347118, 0.026520144419919234, 0.05584053447819315, 0.04485135716095101, 0.016894344335014466, 0.029585804331873078, 0.03814102856267709, 0.027298089589748997, 0.05302860001393128, 0.03413985810766462, 0.030922219339117873, 0.05393522616941482, 0.01033702896165778, 0.029429836431518197, 0.10830716913915239, 0.05597590221441351, 0.03290978173026815, 0.045866804430261254, 0.09714270767290145, 0.04028227675007656, 0.011054893566324608, 0.08989891590317711, 0.05038115144998301, 0.16980249783955514, 2.7440519677475095, 52.882541343569756, 76.61778911948204, 37.66934707760811, 28.49099088460207, 59.31569114327431, 18.25474675744772, 0.23739984637359157, 0.2770818740827963, 3.7999625829979777, 4.375946838408709, 3.768370603211224, 0.9700183023232967, 0.16478789504617453, 0.21723891492001712, 0.5377526662778109, 23.61506212502718, 90.3751865029335, 80.39233937859535, 86.71284422278404, 79.90664184093475, 77.18718096613884, 66.96110889315605, 70.48570096492767, 69.9271385371685, 75.84440901875496, 74.26782041788101, 70.96523523330688, 65.19361093640327, 67.07764104008675, 70.63099756836891, 74.03486251831055, 77.56195485591888, 78.77856597304344, 79.73392590880394, 80.96090286970139, 74.4565486907959, 71.63696318864822, 70.76263770461082, 71.26514554023743, 69.90645244717598, 70.89953675866127, 66.03890597820282, 59.93385337293148, 50.978756099939346, 52.84346804022789, 49.934853315353394, 55.74061498045921, 66.97366341948509, 72.07759514451027, 69.63748008012772, 68.2429701089859, 66.09558373689651, 58.111467361450195, 65.40829181671143, 66.10514402389526, 62.653143256902695, 65.45171588659286, 26.013651117682457, 51.70590788125992, 66.41778364777565, 60.021393075585365, 69.04717415571213, 62.915621772408485, 67.52845644950867, 64.71577897667885, 65.06291314959526, 63.78871992230415, 60.634562373161316, 51.34552001953125, 47.72536687552929, 48.58423478901386, 49.017498940229416, 47.99070283770561, 49.87327761948109, 47.612771317362785, 49.79227356612682, 51.55217573046684, 53.69040459394455, 60.04812464118004, 65.40434002876282, 64.95084956288338, 63.142564594745636, 62.96066075563431, 62.810378819704056, 64.72785472869873, 66.71908468008041, 66.2689608335495, 65.31040146946907, 66.21396258473396, 66.39443010091782, 65.09794726967812, 54.64212812483311, 50.242686197161674, 55.58020278811455, 56.92058086395264, 61.565132439136505, 64.35880333185196, 65.46230211853981, 71.32522031664848, 66.61138325929642, 79.68477174639702, 72.18905836343765, 55.19931882619858, 5.636147316545248, 0.028307371467235498, 0.15195337124168873, 0.674814220983535, 2.7678156550973654, 0.8362099074292928, 1.0526882694102824, 0.2875472547020763, 0.04832327984331641, 15.952108316123486, 57.37114168703556, 25.643425583839417, 32.91584014892578, 37.607721984386444, 44.238639771938324, 0.7407557044643909, 0.1517251756740734, 0.03619892457209062, 0.09586129322997294, 0.03634497923485469, 0.023662801650061738, 0.05981424546916969, 0.012791660137736471, 0.042159906661254354, 0.017525544644740876, 0.012824561399611412, 0.0030161496169966995, 0.03586434955650475, 0.02892431140935514, 0.05486870322783943, 0.03894935725838877, 0.018976814426423516, 0.055335643992293626, 0.01788965157174971, 0.023400174140988383, 0.009317115818703314, 0.08807875419734046, 0.013852471183781745, 0.03877744617057033, 0.06847097509307787, 0.06616982005652972, 0.04725722181319725, 0.033945793911698274, 0.0626823642232921, 0.030551256822946016, 0.03022951725142775, 0.0071791752907302, 0.02932477986178128, 0.04008404539490584, 0.018138968662242405, 0.09120252798311412, 0.06641449872404337, 0.032223721864284016, 0.03421335670282133, 0.03774206110392697, 0.07422204813337885, 0.06730955850798637, 0.028067340499546845, 0.03970798432419542, 0.09667747755884193, 0.03883160439727362, 0.09708368466817774, 0.014268282611737959, 0.03351936327817384, 0.045958541304571554, 0.04423084006702993, 0.03177752783813048, 0.0493376992380945, 0.07149342345655896, 0.19758602807996795, 0.009671631414676085, 0.16723557229852304, 3.8474628841504455, 68.54680940508842, 81.11560016870499, 32.27503873407841, 48.489524871110916, 73.12166512012482, 22.006161957979202, 0.13310765905771405, 0.32148094789590687, 0.9288774942979217, 2.1198456874117255, 2.598173995502293, 3.7256962805986404, 1.1270961142145097, 0.38237784581724554, 0.663004870293662, 36.173557341098785, 93.20184722542763, 81.41570806503296, 84.98661205172539, 85.1203116774559, 79.44898679852486, 68.38939145207405, 71.3484750688076, 74.49689492583275, 81.39691427350044, 77.79550552368164, 72.512466609478, 65.21039843559265, 69.7983406484127, 73.81814494729042, 78.64181131124496, 78.51019397377968, 81.12542644143105, 78.63822430372238, 80.78567147254944, 75.6293785572052, 74.20250952243805, 73.74579682946205, 72.45125189423561, 73.23242157697678, 73.1801287829876, 67.9135961830616, 60.65983481705189, 53.9960677921772, 56.97846315801144, 52.76671215891838, 59.7530210763216, 72.35902324318886, 74.98863413929939, 70.93846946954727, 69.24184530973434, 68.57258722186089, 61.901167407631874, 69.25443023443222, 67.32710525393486, 65.23179888725281, 65.46654269099236, 26.91902093589306, 55.102777406573296, 67.85299703478813, 64.5609600841999, 70.86568057537079, 67.46078208088875, 71.4550593495369, 68.50079387426376, 66.3438168168068, 67.50946506857872, 61.88667878508568, 53.91390100121498, 50.045636370778084, 50.751410499215126, 52.16241158545017, 50.11817827820778, 52.07203343510628, 50.72598226368427, 52.59315267205238, 56.65282063186169, 58.340313881635666, 61.90517999231815, 67.5637337565422, 67.34973683953285, 67.02119126915932, 65.88803887367249, 66.18905872106552, 69.08151671290398, 71.83345064520836, 68.10135930776596, 65.85900083184242, 70.29962494969368, 68.84851321578026, 68.56713831424713, 56.7871206253767, 52.39677540957928, 57.589949145913124, 62.24678926169872, 65.18740206956863, 66.28815740346909, 69.38708111643791, 73.30933704972267, 70.24308398365974, 81.04955211281776, 75.01185089349747, 59.68267165124416, 6.02080162614584, 0.07984341602423228, 0.38468031445518136, 0.45471138786524534, 2.046607229858637, 0.2557403489481658, 1.0787757695652544, 0.10315146180801094, 0.2234068448888138, 22.792062386870384, 68.97230297327042, 38.470017313957214, 37.390651032328606, 45.89679479598999, 53.230667263269424, 0.8913966023828834, 0.18988363357493654, 0.02060153339698445, 0.07470887474482879, 0.04955407610395923, 0.13625999068608508, 0.033879624024848454, 0.05697807988326531, 0.0188059813081054, 0.015567653317702934, 0.038782904666732065, 0.021555150487984065, 0.03272597401519306, 0.05799522296001669, 0.002175750632886775, 0.0482395581639139, 0.021774219494545832, 0.01163059978352976, 0.018334047745156568, 0.02416082912532147, 0.05007206178561319, 0.033184205676661804, 0.043920058305957355, 0.01588785664353054, 0.009586471824150067, 0.043944456410827115, 0.2253543888218701, 0.10811332016601227, 0.2292349305935204, 0.1548463964718394, 0.16148642142070457, 0.1057409263739828, 0.16289423103444278, 0.17972259287489578, 0.10081813466968015, 0.2595301705878228, 0.19498862995533273, 0.13405193807557225, 0.12434521049726754, 0.11893412272911519, 0.11106335718068294, 0.21206843142863363, 0.09080829171580262, 0.13098100520437583, 0.21336998033802956, 0.07712834296398796, 0.17343523650197312, 0.17410239757737145, 0.18350346421357244, 0.12069744334439747, 0.1781192867201753, 0.15059270284837112, 0.17911735660163686, 0.1818564158747904, 0.3794004680821672, 0.16413869394455105, 0.49829973955638707, 5.774739179760218, 92.39160910248756, 99.5219112932682, 53.82580652832985, 49.99502308666706, 80.06405219435692, 29.736985825002193, 1.1041878559626639, 2.8663066076114774, 7.2620392218232155, 15.57973874732852, 14.425849914550781, 3.2419271394610405, 0.3990555665222928, 0.3022719395812601, 0.5015610926784575, 37.09389075636864, 94.9998651444912, 85.05512997508049, 89.4960504770279, 87.64424264431, 81.34682536125183, 73.66413161158562, 74.69575345516205, 76.83275118470192, 83.4214760363102, 81.67184472084045, 76.53933852910995, 70.10598734021187, 71.8464307487011, 78.09284716844559, 83.20988059043884, 84.09772574901581, 85.00511705875397, 82.8953866660595, 82.45893448591232, 77.66370579600334, 78.47129166126251, 78.95163148641586, 73.8051800429821, 75.75244635343552, 75.92295840382576, 71.72237500548363, 65.9864991903305, 57.104312404990196, 60.0720139592886, 55.402900502085686, 62.60254517197609, 73.7727677822113, 79.78597551584244, 73.44507336616516, 73.96233201026917, 70.20448565483093, 62.58491411805153, 71.39162555336952, 66.43249645829201, 66.90158888697624, 65.52298486232758, 29.992164932191372, 56.198547407984734, 72.00891762971878, 66.22699588537216, 71.2825334072113, 69.30104613304138, 72.63358891010284, 71.22076392173767, 68.91836866736412, 71.05187058448792, 64.85599905252457, 56.89068406820297, 52.65624448657036, 54.67412240803242, 54.531462863087654, 51.31574101746082, 55.475780591368675, 53.554174304008484, 57.49693773686886, 59.3331778049469, 61.66309878230095, 65.26938647031784, 71.68286472558975, 71.00810453295708, 71.29910811781883, 69.90622445940971, 69.40080597996712, 72.98808708786964, 78.06005492806435, 71.90874740481377, 67.98619508743286, 75.12504681944847, 75.73300659656525, 73.0735445022583, 60.546863079071045, 55.536083355546, 62.955531030893326, 65.66083386540413, 67.64837801456451, 69.62236449122429, 72.01016396284103, 76.70914381742477, 72.35638618469238, 83.68746936321259, 79.82349470257759, 58.766954988241196, 6.3212918769568205, 0.25921377819031477, 0.31639590044505894, 3.446211777627468, 9.442316628992558, 5.479369154199958, 3.738981317728758, 1.3173796911723912, 0.3097947937203571, 25.25615606456995, 75.12838304042816, 40.057568326592445, 49.114636927843094, 51.996508687734604, 75.51308199763298, 1.726329184602946, 0.35749235772527754, 0.16061375965364277, 0.17213818500749767, 0.25273156352341175, 0.37358016008511186, 0.18613786582136527, 0.1798437855904922, 0.11887606451637112, 0.1521239019348286, 0.11226559930946678, 0.09586938263964839, 0.1146520122711081, 0.1676486962242052, 0.20704063324956223, 0.11833845273940824, 0.0789269304368645, 0.07095811233739369, 0.1647319074254483, 0.19423235178692266, 0.13888501154724509, 0.12562093266751617, 0.14048416167497635, 0.1657484270981513, 0.11740061556338333, 0.2656354632927105], [0.033788599612307735, 0.047838902319199406, 0.02288105297338916, 0.07797609083354473, 0.040095051444950514, 0.042792943786480464, 0.0429138210893143, 0.06060139698092826, 0.03217270292225294, 0.02415545783151174, 0.025177849747706205, 0.011161948368680896, 0.04467327511520125, 0.07190030592028052, 0.02819440545863472, 0.03556433264748193, 0.027758072719734628, 0.06256040709558874, 0.07595302595291287, 0.14427653630264103, 0.07910099375294521, 0.07886251201853156, 0.10443586710607633, 0.04927821610181127, 0.04527658180450089, 0.0747219513868913, 0.010583672465145355, 0.016407510302087758, 0.055733587287249975, 0.0846575053583365, 0.22319640149362385, 0.6760703504551202, 12.35310198739171, 70.7266004383564, 58.6324118077755, 27.210735082626343, 47.210885882377625, 48.89759637415409, 4.550936948508024, 0.09284838888561353, 1.749772501643747, 2.4114358657971025, 2.729609180241823, 8.828470967710018, 1.4468147582374513, 0.16896989720407873, 0.1269164404948242, 0.07859735749661922, 30.902014710009098, 89.96094793081284, 83.3806586265564, 92.2987724840641, 81.29996627569199, 73.859973102808, 75.84831520915031, 76.9075083732605, 75.47813147306442, 74.28822532296181, 75.53939938545227, 74.18601840734482, 72.58761897683144, 70.97275882959366, 76.79236695170403, 74.17987793684006, 80.57990491390228, 77.23762705922127, 76.14880308508873, 73.23710292577744, 69.67020392417908, 71.14666029810905, 75.01026257872581, 70.11754631996155, 73.42055708169937, 70.44759660959244, 59.68689702451229, 48.19148786365986, 52.517658323049545, 52.49282285571098, 53.87534826993942, 64.20446321368217, 68.94060507416725, 71.33597373962402, 68.80778700113297, 71.5569318830967, 67.02884405851364, 60.90427190065384, 64.6612823009491, 66.13984376192093, 66.0757640004158, 23.063288033008575, 50.97647622227669, 66.81771978735924, 61.48691363632679, 67.60208129882812, 63.73608514666557, 65.72660833597183, 67.72133409976959, 69.13672775030136, 64.0081961452961, 62.80602425336838, 50.66945269703865, 49.017669931054115, 48.631477653980255, 48.76431852579117, 49.20614741742611, 49.06291790306568, 49.51581560075283, 48.94423507153988, 51.45986348390579, 53.68693917989731, 55.94352789223194, 59.41037446260452, 65.50982996821404, 65.10938465595245, 63.966124802827835, 62.373482063412666, 62.73465648293495, 68.1113375723362, 66.505376547575, 64.35192570090294, 62.93304763734341, 65.03287956118584, 65.10369256138802, 59.339743852615356, 52.4710576236248, 54.98834654688835, 58.865259513258934, 61.52386285364628, 64.84953939914703, 68.77545833587646, 72.88867682218552, 77.5633379817009, 65.32519787549973, 63.53600688278675, 12.189036291092634, 0.2604498399887234, 0.4705084761371836, 0.6312074046581984, 2.466869428753853, 1.5303048281930387, 1.3379644928500056, 1.2501168879680336, 0.18570857791928574, 2.8332920791581273, 48.83820176124573, 42.53801442682743, 15.27399955317378, 35.302883461117744, 46.93891927599907, 9.763710033148527, 0.41098731220699847, 0.14063934475416318, 0.0844292801048141, 0.03904638193489518, 0.0410461730643874, 0.022093710358603857, 0.004652782608900452, 0.04966648179106414, 0.02106108979205601, 0.0713244586950168, 0.05248266134003643, 0.0444092746329261, 0.03223571868147701, 0.0681275685201399, 0.0832401962543372, 0.05925046185438987, 0.013379108986555366, 0.025480152471573092, 0.05949607933871448, 0.018886294674302917, 0.03022101409442257, 0.043587424006545916, 0.06038839688699227, 0.0843050742696505, 0.06895018726936541, 0.026919718584395014, 0.013871439550712239, 0.02652868839504663, 0.0689794501522556, 0.014158118210616522, 0.008062609795160824, 0.030680529671371914, 0.03177792488713749, 0.0351254413544666, 0.006769439733034233, 0.10888124263146892, 0.05221030798566062, 0.028280815567995887, 0.011059993048547767, 0.049632803129497916, 0.09109584425459616, 0.017302015330642462, 0.01297713490203023, 0.04500962757447269, 0.09085688754566945, 0.038855820675962605, 0.09392115593072958, 0.11098592149210162, 0.06863369839265943, 0.06588284639292397, 0.034722440323093906, 0.06668416550382972, 0.013712029940506909, 0.08678930971655063, 0.06455586408264935, 0.13069915235973895, 0.07234664837596938, 0.8723394968546927, 16.519366577267647, 90.43156787753105, 50.51791302859783, 30.02290528267622, 61.3251069188118, 58.10192987322807, 5.878333020955324, 0.3412019193638116, 1.857117097824812, 1.351847166661173, 2.7078912081196904, 3.5382649255916476, 3.203766974620521, 1.0948793054558337, 0.5826235085260123, 0.11947595732635818, 40.95994010567665, 89.43247988820076, 86.82389706373215, 92.81220093369484, 82.39370718598366, 76.55658960342407, 79.6212163567543, 78.89366179704666, 76.73582598567009, 77.46287897229195, 78.68812322616577, 76.59413918852806, 72.83413454890251, 72.69525200128555, 77.90006071329117, 76.00824862718582, 81.07341483235359, 78.53547021746635, 78.26097294688225, 74.96127560734749, 75.13576224446297, 72.18401223421097, 76.78717643022537, 74.26718965172768, 74.64008644223213, 72.00539141893387, 62.20874950289726, 52.40662828087807, 56.96355655789375, 56.18585988879204, 56.90013036131859, 66.052775233984, 71.41658261418343, 72.62200713157654, 70.48072323203087, 73.63395363092422, 71.71522378921509, 63.12225468456745, 68.51096972823143, 69.65387240052223, 67.1139594912529, 25.942511335015297, 53.81827913224697, 72.16195821762085, 66.75659626722336, 71.43933579325676, 67.80913218855858, 69.91337567567825, 69.77435633540154, 71.76761537790298, 68.66614580154419, 66.8673375248909, 53.86398307979107, 50.825225338339806, 50.82531653344631, 52.27170892059803, 52.991823479533195, 51.29706121981144, 52.180130034685135, 51.271537989377975, 52.5079270452261, 56.645726412534714, 61.58462159335613, 65.22605359554291, 67.74841144680977, 66.89731031656265, 69.4214616715908, 65.74151113629341, 68.92871171236038, 68.57806652784348, 69.28495779633522, 68.17253708839417, 68.21948736906052, 68.91713753342628, 68.92117291688919, 63.35186876356602, 57.03177809715271, 59.486377984285355, 62.52421997487545, 63.44590611755848, 69.72948834300041, 70.50954088568687, 73.364327698946, 80.20260035991669, 69.91251692175865, 63.38312208652496, 13.120209574699402, 0.3962497436441481, 0.38196565699763596, 0.923086367547512, 1.3383080181665719, 0.7698086486198008, 0.3683037275914103, 0.46915292856283486, 0.2487876423401758, 6.354251308366656, 58.024592623114586, 59.694720804691315, 22.452358715236187, 40.125702470541, 56.140330731868744, 11.350218951702118, 0.5203218734823167, 0.043626152983051725, 0.044868437689729035, 0.0058500500290392665, 0.04739828553283587, 0.037797573750140145, 0.02672669339517597, 0.029149941001378465, 0.01892125354061136, 0.01858600131527055, 0.01045037068251986, 0.11190121964318678, 0.04113428825803567, 0.07512395051890053, 0.06773027460440062, 0.07888992695370689, 0.030537130041921046, 0.017709281855786685, 0.02154845631594071, 0.04461560652998742, 0.024720632973185275, 0.027282111150270794, 0.011033884293283336, 0.08170460365363397, 0.035771562543231994, 0.050011617568088695, 0.09111849460168742, 0.17153265187516809, 0.1764181803446263, 0.10412068440928124, 0.12500227836426347, 0.09772365345270373, 0.11754895604099147, 0.12704495078651235, 0.17890404851641506, 0.12548739061458036, 0.2389025766751729, 0.0693274060904514, 0.10308151438948698, 0.12304098243475892, 0.20710058393888175, 0.06273983613937162, 0.14965388603741303, 0.19680620898725465, 0.18288335530087352, 0.15847379167098552, 0.166136332845781, 0.18445166177116334, 0.29383428453002125, 0.12150861075497232, 0.14369763142894953, 0.2204460318898782, 0.10227194259641692, 0.2520746737718582, 0.15272535325493664, 0.32998925540596247, 0.27600368193816394, 1.4849612675607204, 31.96184813976288, 103.85713666677475, 74.15318816900253, 38.69718052446842, 64.20735105872154, 65.68968951702118, 8.647706117480993, 0.5077823682222515, 7.6422719936817884, 3.5203932970762253, 8.337751999497414, 24.04018521308899, 2.9485527193173766, 0.3752963320584968, 0.46799678122624755, 0.2575628855265677, 39.33996543288231, 91.95204108953476, 92.50099003314972, 100.39424568414688, 88.53765830397606, 79.40584391355515, 82.29131028056145, 82.6563186943531, 80.95300689339638, 80.52711814641953, 82.36514031887054, 79.93271604180336, 78.76639902591705, 75.76005354523659, 84.42341387271881, 78.6405573785305, 85.16068071126938, 81.18205100297928, 80.36102145910263, 77.32569113373756, 75.26337459683418, 76.19784325361252, 81.72666817903519, 79.31781023740768, 82.03893542289734, 77.59224683046341, 67.37339437007904, 55.99002219736576, 60.16019582748413, 59.592042714357376, 61.72266438603401, 70.83228796720505, 76.60820603370667, 77.16815158724785, 71.52472481131554, 76.7002446949482, 71.62517622113228, 65.6867104768753, 74.18799430131912, 73.19532796740532, 69.03028786182404, 28.962218798696995, 58.24989013373852, 73.08072611689568, 68.73559847474098, 73.61607939004898, 72.51122787594795, 71.95450454950333, 75.6939446926117, 76.0079674422741, 70.51287710666656, 68.63944843411446, 55.26581905782223, 54.218580052256584, 54.933021515607834, 55.62905676662922, 56.001121401786804, 56.53908893465996, 55.72221256792545, 53.78042936325073, 58.762779012322426, 61.11329488456249, 64.422297924757, 68.26472014188766, 73.33244740962982, 72.47491702437401, 73.8140107691288, 71.69728875160217, 73.66284728050232, 72.74371460080147, 74.31132808327675, 71.56745731830597, 70.51697328686714, 73.59309062361717, 72.72272452712059, 69.34703126549721, 61.12244099378586, 62.35283777117729, 65.90189293026924, 67.8550261259079, 72.55447715520859, 73.30989941954613, 78.42912152409554, 80.83111703395844, 72.19173341989517, 65.13947904109955, 13.92242917791009, 0.2984542428748682, 0.5484756908845156, 1.4719206048175693, 9.798460118472576, 5.630902172997594, 5.371672483161092, 3.546384614892304, 0.4919821926159784, 5.29204823076725, 69.21052739024162, 55.872536301612854, 25.186617895960808, 50.7068806886673, 71.18707492947578, 22.44520179927349, 0.9774976666085422, 0.33243754121940583, 0.19248392607551068, 0.18244272738229483, 0.27280570822767913, 0.12475653842557222, 0.06130610701802652, 0.15396163769764826, 0.0908747807261534, 0.14722707797773182, 0.19224539981223643, 0.18853697692975402, 0.14303287491202354, 0.1984825573163107, 0.17189648235216737, 0.19817781663732603, 0.1158347210730426, 0.17709503386868164, 0.1308269501896575, 0.09738859604112804, 0.10051092263893224, 0.1774815740645863, 0.15227764524752274, 0.2511365694226697, 0.18325594312045723, 0.12800168304238468], [0.11034573006327264, 0.06477950286353007, 0.028174547442176845, 0.07610466156620532, 0.06672608942608349, 0.06472522218246013, 0.028969539744139183, 0.09799721650779247, 0.04284931732399855, 0.06670417380519211, 0.01938491772307316, 0.11232551289140247, 0.04875991500739474, 0.04047445960168261, 0.018790629983413965, 0.03191740783222485, 0.07103427153197117, 0.022180062951520085, 0.04468762082979083, 0.04028560528240632, 0.03793020667217206, 0.022084331467340235, 0.04569457050820347, 0.07491335127269849, 0.03726396957063116, 0.04471634194487706, 0.04251915066561196, 0.040994705123011954, 0.03748391616682056, 0.06404939282219857, 0.08395637618377805, 0.04929566399368923, 0.6850924319587648, 47.24422909319401, 87.81756654381752, 44.51385520398617, 36.77441909909248, 75.64368098974228, 27.593731731176376, 0.314975815708749, 0.5429396848194301, 0.6748941948171705, 0.7840563997160643, 2.9952094657346606, 5.805537477135658, 2.8904934972524643, 0.47550235816743225, 0.4715407738694921, 0.8170709875412285, 52.13889464735985, 97.6732724905014, 76.83768332004547, 89.44598436355591, 79.64280679821968, 82.78025284409523, 74.64018523693085, 85.29940366744995, 83.8173919916153, 84.04213473200798, 78.62893760204315, 74.61127638816833, 75.97154259681702, 79.62883114814758, 82.11702883243561, 81.56608119606972, 80.01279294490814, 77.84603521227837, 73.74158665537834, 72.32440710067749, 70.64133301377296, 70.14947220683098, 69.91690188646317, 74.3369235098362, 71.55117139220238, 61.49612434208393, 52.74459734559059, 53.059934824705124, 54.29387301206589, 49.33794714510441, 58.437151685357094, 65.36863714456558, 71.12446188926697, 74.82395857572556, 69.9105866253376, 76.5890322625637, 74.02157843112946, 72.37901017069817, 67.30100065469742, 71.43273174762726, 20.577864199876785, 53.91183391213417, 68.85970741510391, 66.49256363511086, 69.7571812570095, 68.7311527132988, 70.49373373389244, 67.53167867660522, 69.50762584805489, 67.05070048570633, 62.55703881382942, 49.710399359464645, 51.061667650938034, 48.47780629992485, 49.773863554000854, 50.57659327983856, 50.54645709693432, 51.14076420664787, 50.74682414531708, 51.82923026382923, 48.66989739239216, 52.724561020731926, 54.59235839545727, 58.32468532025814, 60.59149548411369, 63.17883364856243, 60.863013714551926, 63.62612284719944, 65.05049541592598, 66.33742555975914, 66.05767697095871, 68.93587812781334, 67.58514940738678, 70.77473625540733, 63.32560457289219, 58.204148188233376, 59.44190517067909, 61.24571777880192, 63.30584943294525, 67.5746163725853, 71.23894974589348, 80.35965353250504, 61.817260310053825, 62.967656180262566, 20.40259100496769, 0.31494574388489127, 0.08181469383998774, 1.2457353668287396, 1.2472335551865399, 0.48894116829615086, 0.3285246714949608, 0.12536449095932767, 0.4186795838177204, 2.586534507572651, 29.44598414003849, 64.10257548093796, 26.52898706495762, 36.90920166671276, 54.11168418824673, 23.381205573678017, 0.5957858834881335, 0.11969533617957495, 0.05220890532655176, 0.009341487020719796, 0.011047293974115746, 0.10858754510991275, 0.08223617434850894, 0.047541460662614554, 0.037034757260698825, 0.04000693996204063, 0.049333331699017435, 0.0356145352270687, 0.04366871144156903, 0.10219003917882219, 0.020249679328117054, 0.11301103470032103, 0.02606926929729525, 0.02708080915908795, 0.039386931239278056, 0.05337316062650643, 0.06003484515531454, 0.08029078264371492, 0.039805242777219974, 0.006493073678939254, 0.03490839655569289, 0.07733940234174952, 0.029704473745368887, 0.028400815281202085, 0.02628074613312492, 0.06759133713785559, 0.03250529269280378, 0.06032949262589682, 0.04255135245330166, 0.025773695997486357, 0.08696211138158105, 0.034173024687333964, 0.018498249773983844, 0.0913733481138479, 0.06255602100281976, 0.03427661366004031, 0.06089418166084215, 0.040057803053059615, 0.027654927180265076, 0.04637472658941988, 0.052293146509327926, 0.04202119183901232, 0.006701762358716223, 0.0401748842705274, 0.026493736950214952, 0.019656039112305734, 0.022169203475641552, 0.039362900497508235, 0.041305112099507824, 0.07080045048496686, 0.06763758035958745, 0.034842809254769236, 0.09806719361222349, 0.09108031110372394, 0.06839375462732278, 1.5638956194743514, 55.02228632569313, 99.03394907712936, 30.755979046225548, 51.39640308916569, 85.08099138736725, 35.43141536414623, 0.2953122864710167, 0.4236914258217439, 1.3930426561273634, 2.0492283767089248, 3.4166975738480687, 4.166163420304656, 4.575336389243603, 2.20717616379261, 1.1556685622781515, 0.7200606493279338, 61.99143536388874, 97.7594518661499, 81.45731583237648, 93.98863300681114, 82.6252743601799, 79.4020365178585, 75.94125062227249, 87.6504211127758, 87.51119658350945, 83.02421495318413, 81.33031904697418, 77.9263325035572, 78.01309704780579, 83.01033809781075, 81.03306859731674, 85.42119473218918, 80.88743761181831, 78.56928080320358, 75.61731040477753, 73.19298729300499, 73.0343534052372, 72.83152028918266, 71.01075679063797, 76.26680955290794, 71.73989966511726, 63.28729882836342, 54.53923724591732, 57.51896895468235, 56.46485231816769, 53.006581887602806, 62.739170640707016, 70.21451711654663, 73.64792168140411, 78.80394101142883, 72.1684330701828, 77.67041623592377, 76.42767772078514, 73.98993372917175, 67.82126873731613, 73.01049068570137, 22.240953259170055, 59.85285311937332, 72.67208844423294, 69.35479804873466, 72.09502100944519, 70.86120441555977, 73.82590413093567, 69.84208390116692, 71.93135619163513, 69.14337739348412, 65.56451663374901, 53.60013663768768, 52.867611944675446, 52.276223078370094, 52.527484595775604, 54.113869071006775, 54.467774480581284, 54.53080549836159, 54.63264003396034, 56.491143107414246, 52.83263862133026, 55.57345815002918, 61.83441258966923, 65.65280109643936, 65.25839745998383, 64.68121603131294, 62.308361157774925, 67.16630548238754, 71.17198973894119, 73.00247311592102, 67.87158563733101, 69.64049711823463, 71.22415333986282, 72.29070290923119, 65.49623429775238, 60.73246791958809, 60.53153470158577, 64.57028478384018, 65.54113268852234, 70.36938160657883, 75.85667476058006, 82.84255430102348, 64.24677774310112, 67.65117466449738, 21.690854877233505, 0.3330881375586614, 0.016651561854814645, 2.9408757062628865, 1.7414808715693653, 0.43294680886901915, 0.6081994017586112, 0.4749980539781973, 1.08239543158561, 5.150568997487426, 35.978403612971306, 82.10980162024498, 39.04802329838276, 28.336570970714092, 65.9247525036335, 31.763698272407055, 0.8673883031588048, 0.2692806551931426, 0.06115810421761125, 0.05821050886879675, 0.06136229130788706, 0.01635068405448692, 0.030299238314910326, 0.045128100318834186, 0.020300503456383012, 0.040282647823914886, 0.023002494308457244, 0.019114889146294445, 0.05694599683920387, 0.0874675955856219, 0.073076023691101, 0.07325525235501118, 0.0372985536523629, 0.028721102098643314, 0.017019234801409766, 0.04230536760587711, 0.04471592263143975, 0.09377288224641234, 0.05671308121236507, 0.02458689054037677, 0.09579939069226384, 0.01951509970240295, 0.06513365573482588, 0.12307115815929137, 0.11186368181370199, 0.12251817650394514, 0.1036165509140119, 0.09942611053702421, 0.12126724948757328, 0.1257570128655061, 0.19084811385255307, 0.125617919547949, 0.12906225660117343, 0.13315442920429632, 0.14536669186782092, 0.11777804218581878, 0.18183876760303974, 0.06462256831582636, 0.12195573246572167, 0.2021964275627397, 0.19070247479248792, 0.08978222060250118, 0.1682134557631798, 0.08635818128823303, 0.21347448957385495, 0.15176750777754933, 0.13048281631199643, 0.22284692415269092, 0.12345574650680646, 0.07642055672477, 0.20253297669114545, 0.06559055153047666, 0.1636173648876138, 0.155773056903854, 0.1195337186800316, 1.7350372485816479, 79.45264980196953, 112.2748401761055, 62.21998929977417, 54.30513180792332, 94.2694379389286, 45.81033043563366, 0.5821975751314312, 0.8528623951133341, 4.143041186034679, 2.8035560622811317, 9.634611960500479, 17.35254406929016, 9.368273802101612, 1.7407832527533174, 1.541815954260528, 0.8149352646432817, 60.80839164555073, 102.79137745499611, 83.98801043629646, 95.3323321044445, 85.30495136976242, 86.52102291584015, 78.33636850118637, 93.58681216835976, 94.11813005805016, 87.6912385225296, 84.300437271595, 80.56535169482231, 83.24075013399124, 87.02816650271416, 86.13538920879364, 88.3595010638237, 83.29127982258797, 79.85854402184486, 79.28518518805504, 77.9513731598854, 76.10980957746506, 75.87134197354317, 74.89468798041344, 79.8166398704052, 77.41369441151619, 67.44706481695175, 58.42902772128582, 60.85203230381012, 60.8363201469183, 56.10710151493549, 65.65341666340828, 73.49557265639305, 78.0177403986454, 80.53553089499474, 75.53695231676102, 79.4302462041378, 76.93327099084854, 74.02920842170715, 72.84231930971146, 74.55168038606644, 26.16441372781992, 61.873736679553986, 75.41000112891197, 73.36635679006577, 75.23980066180229, 75.54506868124008, 77.42605894804001, 73.92295852303505, 75.36450237035751, 71.15258798003197, 67.5261689722538, 55.95861688256264, 56.02485112845898, 54.85459752380848, 55.45171648263931, 56.29871003329754, 57.17947617173195, 56.9269835203886, 58.154431656003, 60.046038553118706, 56.34400740265846, 59.534339010715485, 61.84838443994522, 67.34179526567459, 68.38267341256142, 69.80695858597755, 67.23825842142105, 72.36526250839233, 76.04957520961761, 77.65729933977127, 70.8658629655838, 71.18685454130173, 75.53240016102791, 78.8461035490036, 68.82140547037125, 63.70349809527397, 66.99867367744446, 68.52349385619164, 71.38015776872635, 75.21752625703812, 78.14552754163742, 84.75447490811348, 67.4130566418171, 73.04845824837685, 23.201365023851395, 0.49063118698541075, 0.19126292987493798, 1.9745583459734917, 10.097335930913687, 2.331666983664036, 1.974959105718881, 1.0910892463289201, 1.3963596406392753, 3.843446974642575, 45.080089420080185, 82.2426424920559, 40.71015290915966, 50.39556719362736, 73.43143209815025, 47.23249152302742, 0.8131815993692726, 0.4731207469012588, 0.1606302204891108, 0.2217755449237302, 0.24500240717316046, 0.2604416763642803, 0.2173236830276437, 0.1550746662542224, 0.1237358404614497, 0.1439813247998245, 0.15408035164000466, 0.16408876224886626, 0.11888300359714776, 0.1702433335594833, 0.15721527248388156, 0.2166116368607618, 0.14404574321815744, 0.1571434919605963, 0.21156063914531842, 0.11235172554734163, 0.21616287500364706, 0.18224507861305028, 0.20975218852981925, 0.11600071724387817, 0.16351833270164207, 0.35382896836381406, 0.12914849416119978], [0.02619220977067016, 0.014105116806604201, 0.04763624405313749, 0.014183893927111058, 0.030414601460506674, 0.021547254036704544, 0.06990482666878961, 0.024031511748034973, 0.08261309631052427, 0.01804013314540498, 0.011941725715587381, 0.046140512204146944, 0.056637519446667284, 0.011044238181057153, 0.08203721939935349, 0.05934816930675879, 0.024449596930935513, 0.029601960886793677, 0.0951846623502206, 0.05911832988203969, 0.08898058978957124, 0.06237184221390635, 0.07214690675027668, 0.09173082580673508, 0.05287639294692781, 0.06509159080451354, 0.10585304262349382, 0.1322340770275332, 0.026615404640324414, 0.015683743768022396, 0.21691519010346383, 0.27617345564067364, 1.1385692423209548, 10.95671871677041, 80.40139049291611, 71.24905720353127, 29.595996290445328, 60.43372794985771, 79.84283566474915, 19.3182260915637, 0.2969203720567748, 0.808187717339024, 2.37655539996922, 0.6127381988335401, 3.065722044557333, 6.564947627484798, 2.8872116608545184, 0.3619598492514342, 0.4018996248487383, 3.853764133527875, 87.70128518342972, 98.93563315272331, 86.09568893909454, 81.85329258441925, 88.58355224132538, 84.50045093894005, 85.99583029747009, 84.09295320510864, 83.71573984622955, 88.70632365345955, 84.95691284537315, 81.20568573474884, 78.60116869211197, 80.66293805837631, 84.2202539741993, 80.30992180109024, 74.24014270305634, 75.94274014234543, 68.3487032353878, 68.6281706392765, 66.93981483578682, 74.41669642925262, 72.03879922628403, 71.61015182733536, 60.03951050341129, 54.41598705947399, 52.68122434616089, 53.00610311329365, 51.466133147478104, 55.497226640582085, 61.16447053849697, 64.59900364279747, 72.04467371106148, 69.6610464155674, 71.31379812955856, 66.43608346581459, 72.91186317801476, 72.4117948114872, 75.00029191374779, 23.663002252578735, 50.24696856737137, 72.93491274118423, 64.37518805265427, 71.05859622359276, 66.41555696725845, 67.84545823931694, 66.42606720328331, 69.04508426785469, 64.77883279323578, 58.14974270761013, 50.06621986627579, 51.230994164943695, 48.82469728589058, 51.764105558395386, 50.486735701560974, 52.0654521882534, 50.86011506617069, 53.024623319506645, 53.5815404355526, 51.46655112504959, 51.81023508310318, 51.28808990120888, 56.106349155306816, 58.35643641650677, 59.74823333323002, 60.50626985728741, 61.93885378539562, 64.90080624818802, 68.48383918404579, 69.40497055649757, 64.87371370196342, 67.50945746898651, 65.37266492843628, 68.76807913184166, 63.6093657463789, 61.74403063952923, 66.60265132784843, 69.17547807097435, 72.7013848721981, 74.95112255215645, 70.93032270669937, 74.80904057621956, 22.33624454587698, 0.07059140974888578, 0.30855113232973963, 5.7368756365031, 4.672987824305892, 0.16781317099230364, 0.20102972688619047, 0.16113161545945331, 0.4598015412921086, 4.248675042763352, 24.556079730391502, 68.92875730991364, 27.645179070532322, 29.950348176062107, 49.562100917100906, 64.56583142280579, 8.356152512133121, 0.23496892681578174, 0.24837106000632048, 0.05210506773437373, 0.07428708995576017, 0.032013953823479824, 0.051677828159881756, 0.10722750012064353, 0.04791901716089342, 0.025403221443411894, 0.04001517780125141, 0.04360668644949328, 0.035797649034066126, 0.01731682674289914, 0.03536647607688792, 0.027057784027419984, 0.018747563153738156, 0.01847835650551133, 0.05834225121361669, 0.058927071004291065, 0.0483430692111142, 0.017419636460545007, 0.07357309936196543, 0.028714229811157566, 0.02259270077047404, 0.031400817388202995, 0.012597986496984959, 0.08160110373864882, 0.01619980172108626, 0.021753554392489605, 0.07886149527621455, 0.054612038875347935, 0.02755940906354226, 0.046111813353491016, 0.028390731349645648, 0.037084766881889664, 0.019662523627630435, 0.045505033413064666, 0.04486421115871053, 0.07609317312017083, 0.04682659804529976, 0.018098939071933273, 0.07937115777167492, 0.11383332690456882, 0.037722520355600864, 0.04892411518085282, 0.055921168823260814, 0.051323170628165826, 0.1296671960153617, 0.06166096864035353, 0.059429742468637414, 0.07642634547664784, 0.04592462886648718, 0.03469334071269259, 0.05146682073245756, 0.09331961555290036, 0.060592250010813586, 0.04089075249794405, 0.1375626676599495, 0.36686179402749985, 1.3285787589848042, 13.208764772862196, 94.98569950461388, 67.8166101872921, 30.5422006174922, 93.73815044760704, 86.18936911225319, 27.41464924067259, 0.3391213231952861, 0.7786349812522531, 1.707986737601459, 0.8815160044468939, 0.8820483915042132, 1.1048219469375908, 2.5744157703593373, 2.2961816377937794, 0.6272486702073365, 5.952169708907604, 98.16795274615288, 97.75486931204796, 89.02180552482605, 85.04740118980408, 92.68926993012428, 86.49198487401009, 85.35485029220581, 84.77368667721748, 88.46010446548462, 92.5368221104145, 85.85733532905579, 84.538654088974, 81.40761449933052, 82.85293534398079, 83.58682036399841, 84.64719146490097, 76.35333091020584, 76.85522317886353, 72.96773537993431, 74.34462189674377, 69.6980108320713, 77.051140666008, 74.46749970316887, 75.17143473029137, 62.39470012485981, 57.63916790485382, 56.530425399541855, 58.63728314638138, 53.2641738653183, 58.543830960989, 66.75580590963364, 69.75232511758804, 75.0741295516491, 73.1408540904522, 75.74044659733772, 72.56456941366196, 77.3883193731308, 77.66378939151764, 75.78669771552086, 26.05400875210762, 56.427188739180565, 76.55891507863998, 69.82763707637787, 74.87152442336082, 67.89150416851044, 70.06064057350159, 68.2620906829834, 71.59225478768349, 67.9681384563446, 62.644559517502785, 53.48605535924435, 53.146254792809486, 51.44561804831028, 55.52446357905865, 52.074355110526085, 55.03335893154144, 53.34537550806999, 54.95856374502182, 55.972497537732124, 56.167541071772575, 56.251577362418175, 56.98884800076485, 59.34054560959339, 64.8837223649025, 66.99866607785225, 66.97382301092148, 65.12398347258568, 66.30192786455154, 71.96872338652611, 74.6833585202694, 68.23334142565727, 70.66727802157402, 68.95650342106819, 72.53772765398026, 67.94676840305328, 64.32939291000366, 68.75626936554909, 75.26702240109444, 75.64330860972404, 78.47626179456711, 69.32271257042885, 78.53647336363792, 23.11160434037447, 0.0741731480229646, 0.238159894652199, 9.20768491923809, 4.994571693241596, 0.37932275037746876, 0.408977041952312, 0.2763865113956854, 0.896027663256973, 9.07210249453783, 29.768752120435238, 78.51059675216675, 53.78853812813759, 22.673607543110847, 51.244061663746834, 73.24832752346992, 9.088620208203793, 0.5878644366748631, 0.24132876133080572, 0.09877987802610733, 0.03741547159734182, 0.060276722215348855, 0.04868732925388031, 0.09266436594771221, 0.049879760190378875, 0.061032892772345804, 0.04410449313581921, 0.011414901055104565, 0.0915480793628376, 0.044458145057433285, 0.019758976850425825, 0.05226772052992601, 0.07841562779503874, 0.031701583866379224, 0.02682142483536154, 0.029671526099264156, 0.03769365081097931, 0.013173343904782087, 0.042807211575564, 0.016328347264789045, 0.029719170124735683, 0.06059659157472197, 0.07401136725093238, 0.07037668416160159, 0.10734559065895155, 0.09132105638855137, 0.13793792721116915, 0.18175588455051184, 0.14810466760536656, 0.137673084391281, 0.1866315572988242, 0.09426206146599725, 0.2117488774820231, 0.11981435440247878, 0.09765718670678325, 0.1374901449889876, 0.12102655615308322, 0.21766613965155557, 0.1900015163118951, 0.16699311265256256, 0.10819425879162736, 0.08735730501939543, 0.11267179899732582, 0.14849638799205422, 0.30538373510353267, 0.2098338247742504, 0.13679015130037442, 0.34154030901845545, 0.14329313125927, 0.2193408997845836, 0.20339701470220461, 0.3141311922809109, 0.19838897249428555, 0.29400497849565, 0.34178634581621736, 0.8363518060650676, 2.0298539288342, 19.666868783533573, 109.98608618974686, 89.02235269546509, 46.35434724390507, 85.06230399012566, 96.11293181777, 35.02788841724396, 0.7399769243784249, 1.71969331568107, 7.491747345775366, 2.8084022272378206, 9.331021551042795, 17.53452580422163, 6.412903536111116, 0.9374319040216506, 0.5689214437734336, 5.834651039913297, 95.6626483798027, 104.77452144026756, 92.95191943645477, 87.17193558812141, 93.14773812890053, 89.78963792324066, 89.01723057031631, 85.01064956188202, 91.136574447155, 95.43748006224632, 92.42274463176727, 88.78086805343628, 84.86788362264633, 84.03398036956787, 85.5699947476387, 87.07618072628975, 81.46700531244278, 80.00492736697197, 78.039011657238, 77.98049479722977, 73.70766207575798, 81.9490322470665, 79.67508226633072, 80.03622248768806, 66.33680999279022, 62.900768369436264, 60.09576268494129, 62.797299921512604, 55.5624121427536, 63.38219873607159, 70.65992921590805, 72.26291120052338, 76.53091818094254, 78.94761890172958, 79.46778059005737, 75.56513920426369, 78.89271184802055, 80.31358480453491, 77.95897275209427, 31.043365225195885, 58.63174304366112, 81.24086424708366, 74.5661424100399, 79.00498822331429, 73.43731418251991, 75.36694183945656, 73.1749914586544, 74.45203453302383, 71.92207708954811, 65.78862860798836, 55.916758328676224, 55.71934372186661, 53.84773135185242, 60.91727860271931, 56.350212469697, 58.58085997402668, 57.44192808866501, 59.74879190325737, 61.79499730467796, 62.03874282538891, 61.51588708162308, 61.46389067173004, 65.02769663929939, 69.4639889895916, 71.21273875236511, 72.77590647339821, 70.16930714249611, 71.8713042140007, 77.78950944542885, 79.34744864702225, 71.00948765873909, 76.57538339495659, 74.7758911550045, 79.41706091165543, 73.15278545022011, 69.21955570578575, 73.99501785635948, 79.98410448431969, 77.34854310750961, 81.74610033631325, 76.00329369306564, 86.42352014780045, 24.648849852383137, 0.1430701307253912, 0.43111842416692525, 6.81735715828836, 11.692222449928522, 1.7689851019531488, 1.7825488303788006, 1.0392090864479542, 1.0064096027053893, 6.265979669988155, 41.33899636566639, 84.52976256608963, 46.29277154803276, 46.31563872098923, 64.3992255628109, 89.83021214604378, 15.846017058938742, 0.9203142975457013, 0.39254526898730546, 0.23827258235542104, 0.17101448436733335, 0.2796399680664763, 0.17270772397750989, 0.2457708862493746, 0.22260504338191822, 0.1328128483146429, 0.2353100772597827, 0.1446080388268456, 0.16068703931523487, 0.17883792315842584, 0.2056374546373263, 0.16618884721538052, 0.15566253627184778, 0.12257561131264083, 0.11246320354985073, 0.15414908935781568, 0.1101662045402918, 0.07243978048791178, 0.16398189298342913, 0.20710457669338211, 0.09873178685666062, 0.0964776542969048, 0.161802769289352, 0.1872749102767557], [0.048824255500221625, 0.07032258159597404, 0.01497487492088112, 0.0438855892571155, 0.02089323639665963, 0.05539454083191231, 0.01384544768370688, 0.06192502107296605, 0.04554231149086263, 0.06331767232040875, 0.10080419713631272, 0.191368849191349, 0.07149564247811213, 0.14140887768007815, 0.15841064974665642, 0.09863282888545655, 0.06516914523672312, 0.035181618222850375, 0.08776705959462561, 0.021672558250429574, 0.035323379561305046, 0.05133212463988457, 0.06890435965033248, 0.09482257592026144, 0.07041615899652243, 0.018869926607294474, 0.061990018366486765, 0.06806964389397763, 0.013036567015660694, 0.029438545534503646, 0.07347941063926555, 0.11204507754882798, 0.12134243646869436, 0.5200485256500542, 38.26964646577835, 83.34096595644951, 68.22036132216454, 26.499057970941067, 63.78714680671692, 70.22292986512184, 13.172874748706818, 0.5326637299731374, 1.3956490787677467, 0.8750253589823842, 0.6700324744451791, 1.7899653199128807, 4.436053913086653, 2.1178089966997504, 0.016131329321069643, 0.5637256382033229, 9.879244733601809, 70.31063675880432, 94.67292308807373, 92.16539964079857, 85.5355153977871, 87.89375245571136, 91.75762832164764, 91.45286187529564, 84.68231678009033, 83.31426098942757, 83.2877080142498, 81.62459805607796, 85.62234833836555, 85.68889796733856, 82.63268396258354, 71.32798656821251, 78.88959601521492, 69.80533227324486, 64.22939747571945, 60.17204739153385, 66.3857513666153, 76.09736144542694, 72.56454661488533, 67.97435492277145, 59.170090556144714, 53.58204960823059, 54.60823394358158, 53.97393777966499, 53.118136301636696, 51.22502088546753, 58.63548204302788, 63.51345129311085, 65.94105362892151, 69.06456962227821, 69.44548398256302, 66.49004057049751, 70.90115547180176, 68.34380149841309, 78.34571599960327, 22.97030322253704, 44.61260810494423, 73.93898606300354, 66.94693565368652, 72.22429007291794, 67.44700402021408, 69.24705862998962, 69.44041505455971, 67.00349181890488, 65.83835273981094, 56.41815662384033, 50.25460235774517, 50.5268919467926, 50.74207819998264, 51.525516360998154, 53.04695472121239, 55.42520150542259, 56.56112775206566, 58.722603768110275, 57.36790046095848, 55.42729139328003, 56.07790768146515, 55.74345342814922, 54.446355029940605, 55.914888828992844, 55.27721464633942, 57.09633283317089, 59.27702061831951, 67.1143850684166, 66.2680184841156, 70.42165160179138, 72.81847178936005, 74.5728300511837, 72.14925929903984, 69.18679386377335, 70.63326224684715, 65.25488644838333, 70.87867587804794, 70.50023138523102, 72.32968881726265, 71.4683510363102, 77.27282837033272, 24.819933772087097, 0.22266022948315367, 0.6979937490541488, 28.022945299744606, 23.238390237092972, 2.2158169001340866, 0.1791998092085123, 0.2491440810263157, 0.17726719728671014, 11.064258646219969, 33.58513243496418, 80.71449369192123, 35.25377109646797, 27.723926045000553, 57.07136057317257, 62.756003737449646, 25.24330325424671, 0.6547588971443474, 0.2540642232634127, 0.04263809467374813, 0.16186643071705475, 0.047386986334458925, 0.07982095863553695, 0.12835050729336217, 0.07292417285498232, 0.05829724366776645, 0.04288928568712436, 0.030446036980720237, 0.017809546006901655, 0.05623449986160267, 0.03138621563266497, 0.020553247413772624, 0.07727167394477874, 0.03449494608503301, 0.03019293308170745, 0.03849576401989907, 0.07206617592601106, 0.02652310002304148, 0.0358685204264475, 0.043302409612806514, 0.07620474018040113, 0.0508468750922475, 0.07529457769123837, 0.041296829731436446, 0.10603926231851801, 0.025010074277815875, 0.02326268942852039, 0.06217309877683874, 0.041936382913263515, 0.03993942678789608, 0.05675361731846351, 0.008279784469777951, 0.02814219165884424, 0.08762421100982465, 0.024936757508839946, 0.06088355410611257, 0.02516802185709821, 0.07114085878129117, 0.043046869614045136, 0.03120416309684515, 0.007754535945423413, 0.03228010653401725, 0.04624025685188826, 0.042557690394460224, 0.07474947022274137, 0.019652506489364896, 0.026146063028136268, 0.07749185431748629, 0.0691315607400611, 0.06748754036379978, 0.011673552508000284, 0.06781064177630469, 0.04838811757508665, 0.0046180431399989175, 0.10764612336060964, 0.04234165491652675, 0.09440253517823294, 0.16570235457038507, 0.7169932045508176, 43.531273528933525, 98.1084631383419, 55.28781607747078, 31.76841761916876, 105.22369533777237, 71.11276611685753, 23.48537128418684, 0.4412110982229933, 1.35175027186051, 0.9132877620868385, 0.5330068396870047, 0.7933547382708639, 0.298480277415365, 3.872353211045265, 0.22903976059751585, 0.388515496160835, 13.053624797612429, 79.37512636184692, 97.62452110648155, 99.17908608913422, 86.98631554841995, 91.3921183347702, 96.02011799812317, 94.91142109036446, 86.25822901725769, 85.36559611558914, 87.8474709391594, 86.02549910545349, 88.63385394215584, 86.06498658657074, 83.65623503923416, 73.81320521235466, 81.87378108501434, 75.17439857125282, 69.31599453091621, 68.16217124462128, 71.45493775606155, 74.42320927977562, 74.86159175634384, 71.66331097483635, 62.95024171471596, 56.456112787127495, 57.885459288954735, 53.00071880221367, 56.060238629579544, 54.21001151204109, 62.4121829867363, 68.27985852956772, 70.1167331635952, 70.73764264583588, 74.28931206464767, 69.64469969272614, 75.75179278850555, 69.85514000058174, 80.8438615500927, 23.665042743086815, 48.48345659673214, 77.89596453309059, 68.48308682441711, 76.09308287501335, 70.28630286455154, 73.06945592164993, 72.02300727367401, 71.8750736117363, 69.14208546280861, 60.55184081196785, 54.16858993470669, 54.30484302341938, 53.08729335665703, 55.08418880403042, 55.003477334976196, 56.62345960736275, 59.19383928179741, 60.76427601277828, 62.94082202017307, 58.686570301651955, 57.735435739159584, 59.6217305213213, 58.97697351872921, 61.41370676457882, 59.75168734788895, 59.08884331583977, 63.802406787872314, 71.19908228516579, 71.00582465529442, 72.28438764810562, 72.11674824357033, 73.22934374213219, 74.83852699398994, 70.6246443092823, 71.61202892661095, 68.65812063217163, 75.21696388721466, 72.50090762972832, 74.84117925167084, 74.82674762606621, 84.47053134441376, 27.322384491562843, 0.24251118069514632, 1.346655220258981, 33.11138905584812, 20.03799296915531, 1.956524276174605, 0.5599412193987519, 0.09097172747715376, 0.2887756278505549, 20.03505002707243, 37.65607438981533, 81.04388281702995, 65.48746436834335, 19.206175804138184, 51.164672523736954, 70.27607381343842, 28.571671955287457, 0.8464970241766423, 0.2573107631178573, 0.037082440248923376, 0.11275858574663289, 0.11002674757037312, 0.04617344500729814, 0.058691257290774956, 0.05341755590052344, 0.07422651586239226, 0.018230616478831507, 0.13777521875454113, 0.03509497990307864, 0.01087955097318627, 0.035614735606941395, 0.037505560903809965, 0.010294437106495025, 0.03576839357265271, 0.05336092261131853, 0.015763663795951288, 0.05402038019383326, 0.008387059133383445, 0.07424416413414292, 0.018245695064251777, 0.03203484528057743, 0.03607936087064445, 0.0921865861164406, 0.04502219213463832, 0.047955300760804676, 0.13389792758971453, 0.16115105972858146, 0.12041968715493567, 0.21442259807372466, 0.11689245962770656, 0.11330940775224008, 0.08937281483667903, 0.06141341415059287, 0.1665913435863331, 0.15744895994430408, 0.28958427195902914, 0.24802226544125006, 0.2070485445437953, 0.17530905548483133, 0.3331161313690245, 0.15656130679417402, 0.12363943547825329, 0.13061166799161583, 0.21368243935285136, 0.12438418067176826, 0.08264160962426104, 0.08524216929799877, 0.19394049479160458, 0.1976059770095162, 0.1549526274902746, 0.10668871575035155, 0.18586857011541724, 0.22673793020658195, 0.21583747293334454, 0.21480958355823532, 0.20353181840619072, 0.21522362774703652, 0.25804685486946255, 1.2385915126651525, 63.20553481578827, 113.85538816452026, 87.87793770432472, 42.26005174219608, 89.35968339443207, 88.40390548110008, 27.731575034558773, 0.40383348357863724, 1.8225304037332535, 3.560751643963158, 2.4288534186780453, 3.347942875698209, 13.812578022480011, 7.6179043762385845, 0.24479239422362298, 0.7945105293765664, 12.977368589490652, 74.57964688539505, 101.16621986031532, 98.08678150177002, 91.69869348406792, 95.06552562117577, 97.92473539710045, 97.21977442502975, 89.96570527553558, 86.48180142045021, 92.44732931256294, 85.92825472354889, 91.30554378032684, 90.5702756345272, 86.0117894411087, 75.48954606056213, 87.35375583171844, 80.311768501997, 78.99713024497032, 77.20809504389763, 78.81318971514702, 79.43245768547058, 81.3075202703476, 74.67888996005058, 67.74309933185577, 60.782287046313286, 61.576623022556305, 58.473177552223206, 59.945777133107185, 57.196639850735664, 65.57708635926247, 72.37185895442963, 73.0689163506031, 73.19897577166557, 76.5712796151638, 71.66338697075844, 78.81839543581009, 71.36118158698082, 79.81197372078896, 28.45803715288639, 53.21966305375099, 77.67964214086533, 75.42633265256882, 76.71764016151428, 74.63991165161133, 74.87070366740227, 77.02229261398315, 72.84809499979019, 74.368826597929, 62.91360788047314, 58.28944981098175, 56.196738705039024, 57.682417184114456, 56.61464408040047, 61.162038668990135, 59.279604479670525, 64.51846316456795, 65.47221958637238, 67.57841616868973, 62.74341881275177, 64.0510730445385, 65.26176407933235, 65.28498843312263, 66.65538489818573, 66.5979091823101, 64.31642800569534, 70.96192941069603, 79.14789855480194, 78.69414210319519, 74.40778970718384, 75.3324168920517, 77.99171179533005, 79.13051828742027, 75.09315893054008, 75.71406081318855, 72.29072570800781, 79.59098517894745, 76.67091026902199, 78.69047909975052, 78.67712661623955, 85.76111689209938, 29.88092590123415, 0.5626633577048779, 1.0547344596125185, 31.877944841980934, 31.149113550782204, 4.941902719438076, 1.8433245504274964, 1.0669655282981694, 0.376753049204126, 15.86456386372447, 52.289643958210945, 94.92774501442909, 51.560014709830284, 39.97456558048725, 74.5932349562645, 80.2540647983551, 42.52442255616188, 0.975721855647862, 0.39263581100385636, 0.25291309284511954, 0.25591938465368, 0.19184417993528768, 0.16728758200770244, 0.1952068362152204, 0.1733011897886172, 0.13243531779153273, 0.12872011167928576, 0.1690136393881403, 0.11389785664505325, 0.11831085968879052, 0.08877609099727124, 0.08196545371902175, 0.15343977429438382, 0.14951381308492273, 0.1171770658402238, 0.08977052435511723, 0.19920730905141681, 0.1574609975796193, 0.17484788491856307, 0.10881007809075527, 0.18480201484635472, 0.17074410512577742, 0.20713261503260583, 0.1768275341601111, 0.16795640549389645], [0.024866066087270156, 0.04571706129354425, 0.0585767587472219, 0.07532330622780137, 0.042802435855264775, 0.03865895116177853, 0.11859272737638094, 0.04082893530721776, 0.07624166944879107, 0.04487017802603077, 0.06178568655741401, 0.05350364874175284, 0.04463878751266748, 0.07602925194078125, 0.04247807650244795, 0.023840956055209972, 0.01585942125529982, 0.057635221965028904, 0.06214113818714395, 0.01587006921909051, 0.0737824963289313, 0.07182540837675333, 0.05844025552505627, 0.02873141424061032, 0.07616753631737083, 0.06604683876503259, 0.08075787554844283, 0.13930729357525706, 0.016907931203604676, 0.027567648758122232, 0.06277918480918743, 0.11464478375273757, 0.039307643892243505, 0.09037063238793053, 1.6177743533626199, 59.062069952487946, 77.48214393854141, 58.765632659196854, 22.949347347021103, 74.75559264421463, 79.43006381392479, 13.559105973690748, 1.9629598245956004, 0.36884700937662274, 0.12236209542606957, 0.37977513391524553, 0.05213295022258535, 7.081938860937953, 0.6690863845869899, 0.08033453967073001, 0.497511905268766, 2.4544559698551893, 33.64519961178303, 56.82269051671028, 67.61971235275269, 80.6670418381691, 92.07700878381729, 90.26548638939857, 84.22045156359673, 91.93753346800804, 90.05659639835358, 84.64543595910072, 82.00577080249786, 78.5612328350544, 70.14526963233948, 81.18703633546829, 70.6615175306797, 69.22700330615044, 70.82133695483208, 70.61553999781609, 67.6567755639553, 74.93283793330193, 74.49764728546143, 65.79068049788475, 58.83776418864727, 58.917559906840324, 62.24430799484253, 64.29394081234932, 60.59238463640213, 55.820083916187286, 52.2172312438488, 56.90921187400818, 58.71856838464737, 62.90538132190704, 62.399670258164406, 68.27240332961082, 68.62123981118202, 77.21463069319725, 68.30912455916405, 34.44779634475708, 59.75083999335766, 62.606417164206505, 75.49916714429855, 71.57181948423386, 71.61569952964783, 68.38322058320045, 70.32977253198624, 67.6073706150055, 62.728698402643204, 50.853153839707375, 50.71546822786331, 51.556043922901154, 53.64927560091019, 53.33268418908119, 58.44121366739273, 58.64560469985008, 62.26870268583298, 59.53790321946144, 58.97025927901268, 59.95448246598244, 59.170683324337006, 60.02105489373207, 60.719628408551216, 58.35456311702728, 62.36288443207741, 55.519960820674896, 59.0448796749115, 63.52216422557831, 77.79597669839859, 74.3292935192585, 68.19392994046211, 65.9208083152771, 70.49144625663757, 72.22131103277206, 73.3131292462349, 71.83978870511055, 72.0438301563263, 67.3881983757019, 75.94178259372711, 64.54086676239967, 14.709781128913164, 0.14798463264014572, 0.7487873453646898, 11.916257478296757, 12.148589361459017, 1.287704708520323, 0.6945029832422733, 0.19002055982127786, 0.039382341055897996, 17.117859162390232, 32.798757031559944, 91.85944005846977, 36.352675929665565, 16.25845357775688, 51.268433555960655, 58.72534342110157, 48.094661459326744, 0.16034315776778385, 0.23482217453420162, 0.0282041257378296, 0.17446587182348594, 0.10346734212362207, 0.04238586094288621, 0.030288438210845925, 0.0699202559189871, 0.08978967176517472, 0.03789742972003296, 0.06265540941967629, 0.1393650920363143, 0.018159841565648094, 0.011682122458296362, 0.021758465554739814, 0.046399187776842155, 0.03894196175679099, 0.06713275666697882, 0.06558550492627546, 0.025214684392267372, 0.08915217433241196, 0.057006544957403094, 0.0378407852986129, 0.02901998352172086, 0.02431641853036126, 0.016804383049020544, 0.03892938977514859, 0.07445595823810436, 0.012700486367975827, 0.05048847342550289, 0.028581992082763463, 0.03996953942987602, 0.07942515643662773, 0.06382853709510528, 0.08430702611804008, 0.057737597526283935, 0.02652276605658699, 0.11915923096239567, 0.08589134071371518, 0.02720664400840178, 0.06391888615326025, 0.061873872255091555, 0.0511209131218493, 0.026604656486597378, 0.019889969626092352, 0.01051807032126817, 0.0354198402055772, 0.025666670881037135, 0.08937723061535507, 0.051384071266511455, 0.06206550962815527, 0.002746285240391444, 0.07512805459555238, 0.06931163545232266, 0.028161728696431965, 0.04457615395949688, 0.04327192589698825, 0.09898572752717882, 0.032993915301631205, 0.05847495835041627, 0.155967291793786, 0.04083309875568375, 0.24226524779805914, 3.372519719414413, 71.36583253741264, 86.84047937393188, 40.595532059669495, 33.8388904184103, 117.33457267284393, 73.41563254594803, 25.382163003087044, 2.6421502232551575, 0.8797062328085303, 0.22108502103947103, 0.2009430737234652, 0.10051456658402458, 0.8265905454754829, 0.3119074209826067, 0.24644843739224598, 0.4949090152513236, 4.481162717565894, 41.290389373898506, 64.29256528615952, 78.63393053412437, 87.79126435518265, 92.36695602536201, 89.03296172618866, 87.55739450454712, 95.00933423638344, 90.81682160496712, 82.26126909255981, 80.9191507101059, 83.07981356978416, 74.56578522920609, 80.78191727399826, 76.48477345705032, 72.19567000865936, 76.87664642930031, 76.76967456936836, 70.7241989672184, 79.69332128763199, 78.68705928325653, 72.74716481566429, 60.64506120979786, 61.06187604367733, 62.40864537656307, 66.62401378154755, 62.2730116546154, 57.19813697040081, 56.08993023633957, 61.9390931725502, 65.61069935560226, 68.42577069997787, 69.10604059696198, 71.93891778588295, 74.43858325481415, 79.21420499682426, 73.42982858419418, 36.10408566892147, 61.003731563687325, 69.92067888379097, 77.65388712286949, 74.04525116086006, 73.0689999461174, 72.9624916613102, 73.058360517025, 68.96680846810341, 66.69525235891342, 54.5963291823864, 54.79952707886696, 53.37444394826889, 56.73407927155495, 58.74225631356239, 60.59284821152687, 61.50182783603668, 65.93093857169151, 64.33200716972351, 61.62628635764122, 62.2276496887207, 65.00660017132759, 63.08758154511452, 65.40063142776489, 60.81275001168251, 67.40425631403923, 60.29212474822998, 63.44741843640804, 66.73191279172897, 79.65286865830421, 77.55883902311325, 66.22169896960258, 65.49191012978554, 75.68499237298965, 76.9037389755249, 77.23866820335388, 76.15223050117493, 76.6969008743763, 73.0299836397171, 81.71318650245667, 68.81876081228256, 16.838627345860004, 0.1893339544767514, 1.8790940498001873, 13.07093096897006, 15.431480202823877, 0.3414790966780856, 0.8725285960827023, 0.4700172337470576, 0.20982659625587985, 32.761754617094994, 36.636463701725006, 97.11087986826897, 73.5817900300026, 11.895849723368883, 39.46504332125187, 65.23528710007668, 54.13286805152893, 0.6159714690875262, 0.24275304662296548, 0.009109845104831038, 0.06399648511433043, 0.0777604227187112, 0.04308180621592328, 0.07196121398010291, 0.04638574748241808, 0.020599711424438283, 0.050099291183869354, 0.07078059803461656, 0.007766818953314214, 0.015423039349116152, 0.026596632014843635, 0.038400635530706495, 0.03199186008714605, 0.02176237481762655, 0.04317839673603885, 0.037309118124539964, 0.02767733076325385, 0.05062780051957816, 0.0174859677645145, 0.07130596437491477, 0.1504146764636971, 0.09816031088121235, 0.046053677215240896, 0.023326870359596796, 0.06642437670961954, 0.02187260044593131, 0.18345469026826322, 0.14677464991109446, 0.11059057942475192, 0.15847803675569594, 0.2007979986956343, 0.14952034398447722, 0.1768645821721293, 0.14543326251441613, 0.1847063223249279, 0.1634762974572368, 0.14228812971850857, 0.10359040505136363, 0.12637450941838324, 0.13804509333567694, 0.1259930751984939, 0.1242911747249309, 0.14037120679859072, 0.09115428096265532, 0.09249504495528527, 0.12268512262380682, 0.16664081515045837, 0.11668342631310225, 0.09178345891996287, 0.1485167525243014, 0.14440356229897588, 0.17938663746463135, 0.2071497289580293, 0.27677471400238574, 0.16604585020104423, 0.09536979108816013, 0.27853036823216826, 0.4045773233519867, 0.19471183855785057, 0.42870234756264836, 5.128557728603482, 92.61783376336098, 103.0920097231865, 76.81040838360786, 37.40836948156357, 97.86982834339142, 96.81500494480133, 31.36109657585621, 2.198587912134826, 0.8700470323674381, 0.30603735940530896, 1.4104950008913875, 0.49385656078811735, 15.019256472587585, 2.427686406299472, 0.16555524605792016, 0.7394197792746127, 4.177512936294079, 38.38411532342434, 64.71760287880898, 75.13186365365982, 90.32606273889542, 93.59884232282639, 92.01384097337723, 88.19336637854576, 95.45141011476517, 93.1050968170166, 85.3166015446186, 82.42810294032097, 82.02086359262466, 74.96912598609924, 87.46132045984268, 82.35985100269318, 81.66540786623955, 81.2517012655735, 81.53062149882317, 81.16564348340034, 84.08741310238838, 84.06274482607841, 76.35855183005333, 65.30879035592079, 66.90171048045158, 69.7892515361309, 74.67635929584503, 70.48700049519539, 61.921199932694435, 60.23890100419521, 65.02417042851448, 67.99356669187546, 73.89248415827751, 73.12916591763496, 75.51672220230103, 76.48254677653313, 84.99180257320404, 75.22036090493202, 44.3566158413887, 74.05194640159607, 73.25007542967796, 83.45608457922935, 78.86345341801643, 76.70177221298218, 76.59290805459023, 78.38065132498741, 76.44146338105202, 71.96585074067116, 58.81665252149105, 58.17200191318989, 58.8126627355814, 61.3505769520998, 63.50333243608475, 65.29596224427223, 67.04935535788536, 72.16067388653755, 69.23602402210236, 67.27782189846039, 69.43688124418259, 70.21511748433113, 71.67600989341736, 73.3485509455204, 67.69371718168259, 75.03556162118912, 67.31287881731987, 69.59204971790314, 73.4681685268879, 87.61682331562042, 83.72153833508492, 69.06773865222931, 69.56130176782608, 81.28588423132896, 84.54170912504196, 83.06030541658401, 79.94934394955635, 82.14749559760094, 76.98030486702919, 83.99649158120155, 71.50573343038559, 18.418725058436394, 0.3379538655281067, 2.6091827172785997, 14.309813641011715, 21.03703536093235, 4.850989747792482, 2.1115060849115252, 0.6376221729442477, 0.16802348080091178, 25.950568802654743, 52.26601302623749, 103.88622790575027, 51.9778136909008, 26.88989169895649, 73.92988935112953, 76.45042330026627, 71.66697397828102, 1.0056827729567885, 0.3582422237377614, 0.22148011077661067, 0.21963802602840587, 0.3066543216118589, 0.13907644111895934, 0.33275960362516344, 0.17024725209921598, 0.09967038844479248, 0.13280958286486566, 0.21705576771637425, 0.18742755521088839, 0.18255787901580334, 0.14755865471670404, 0.1874634751584381, 0.10369707393692806, 0.10901022789767012, 0.12745618965709582, 0.2588427934097126, 0.09869096873444505, 0.17695334303425625, 0.12332173690083437, 0.15122177690500394, 0.24093641754006967, 0.16785275714937598, 0.14535756345139816, 0.09557405981468037, 0.19154098292347044, 0.17090236069634557], [0.05083906027721241, 0.03165563379297964, 0.028047510313626844, 0.1005831261863932, 0.02491929477400845, 0.04127028681978118, 0.09425745272892527, 0.03457715007243678, 0.0896528568409849, 0.02021792282903334, 0.02487125926563749, 0.11213179008336738, 0.07196703983936459, 0.039177727230708115, 0.00803676728537539, 0.04729029562440701, 0.009064639034477295, 0.024414715990133118, 0.04036832877318375, 0.010151769420190249, 0.06200038616952952, 0.03144253721984569, 0.01439686433513998, 0.13682518067071214, 0.044130490568932146, 0.10733698916737922, 0.02440395299345255, 0.06695440373732708, 0.09070010884897783, 0.13683261699043214, 0.01666839005338261, 0.07903027450083755, 0.13884831976611167, 0.07632917608134449, 0.25493847322650254, 7.086126711219549, 78.5011276602745, 74.95843335986137, 53.25549513101578, 20.271617732942104, 66.54138341546059, 97.5919796526432, 28.172657266259193, 6.4389041159302, 0.009213315333909122, 0.3825459867948666, 0.33612672763410956, 0.7357679971028119, 1.584061374887824, 0.26714356674347073, 0.4310908756451681, 0.0990314364025835, 0.20017101749544963, 7.106216233223677, 14.248731918632984, 20.974834598600864, 46.81131832301617, 84.74839523434639, 100.33387452363968, 85.81700429320335, 75.27520716190338, 81.328966319561, 85.25124505162239, 78.3159863948822, 90.95843240618706, 78.25249940156937, 73.30844029784203, 85.19101828336716, 76.09679907560349, 86.35763168334961, 75.52135035395622, 70.841164290905, 71.7888106405735, 60.55176481604576, 64.3138137459755, 71.34596720337868, 72.03994676470757, 72.57716953754425, 69.05274465680122, 65.18475741147995, 59.59055699408054, 58.68508458137512, 57.57457137107849, 60.26549577713013, 64.03936207294464, 67.09457293152809, 65.13767033815384, 68.97557079792023, 76.7742571234703, 30.36811675876379, 45.0048116594553, 64.54468935728073, 75.04084333777428, 75.6766252219677, 71.13184109330177, 70.64685791730881, 71.38008177280426, 67.58982315659523, 59.625279530882835, 51.155119836330414, 51.2725905328989, 53.51395346224308, 56.50689706206322, 56.37625627219677, 60.57248130440712, 61.14766024053097, 64.14321810007095, 63.43668781220913, 64.07605290412903, 61.08998313546181, 62.57098786532879, 62.25988335907459, 63.33018332719803, 62.113507613539696, 62.280345261096954, 62.13445968925953, 66.05456873774529, 69.05554130673409, 71.13823235034943, 69.53097179532051, 70.34291222691536, 77.68258318305016, 77.34622523188591, 70.6953053176403, 72.19693154096603, 70.59429913759232, 65.32607942819595, 76.8708935379982, 44.402897357940674, 2.317969906143844, 1.7353540565818548, 1.6566571919247508, 2.6385055063292384, 1.0910938773304224, 2.0635875687003136, 0.2537879958981648, 0.8827493945136666, 1.9737714319489896, 26.23243197798729, 33.03600110113621, 91.45712524652481, 30.385460928082466, 12.449338473379612, 49.41536419093609, 55.03948800265789, 63.45465324819088, 3.1406523613259196, 0.05971326514554676, 0.05172809753275942, 0.01782643172191456, 0.032381958881160244, 0.06091139206546359, 0.141655330080539, 0.056090300568030216, 0.0687265039596241, 0.022913366083230358, 0.0820345179818105, 0.10163962535443716, 0.024075730761978775, 0.01930041307787178, 0.0606796453212155, 0.05462410990730859, 0.053711331347585656, 0.042293760416214354, 0.027671751668094657, 0.04690344743721653, 0.047935837937984616, 0.0488016422605142, 0.022175726953719277, 0.07338882409385405, 0.05289150678436272, 0.039596031347173266, 0.07413540239213035, 0.05435730410681572, 0.026695688320614863, 0.008534207536285976, 0.005716115101677133, 0.0456086038320791, 0.035428449118626304, 0.07483445355319418, 0.009230143532477086, 0.05113239414640702, 0.03190242015989497, 0.06558741224580444, 0.09834652315475978, 0.05704034978407435, 0.05204333217989188, 0.03212097522919066, 0.10964928384055384, 0.09219792613293976, 0.04013769896118902, 0.022432493351516314, 0.038954901101533324, 0.009506560145382537, 0.07134001411031932, 0.027552724168344866, 0.0980628965771757, 0.09600248682545498, 0.045144305113353767, 0.03986688927398063, 0.06381138606229797, 0.13363770092837512, 0.1101537661452312, 0.04210922539641615, 0.08682977902935818, 0.08403208266827278, 0.0641426956281066, 0.014634440649388125, 0.03672179358545691, 0.10548995429417118, 0.4824879567604512, 11.818594168871641, 94.78619500994682, 74.65599238872528, 30.62177024781704, 32.15425081551075, 118.74039083719254, 99.51558083295822, 39.44467641413212, 11.443183813244104, 0.17066497734049335, 0.17327659501461312, 0.6321057002060115, 0.6925710837822407, 0.9350064466707408, 0.6199701013974845, 0.815879157744348, 0.12965640518814325, 0.18568662519101053, 10.108246095478535, 18.0908577516675, 25.64106971025467, 58.84834282100201, 95.20674884319305, 99.95179742574692, 81.08660012483597, 76.5543781220913, 86.47987112402916, 85.60859307646751, 81.00911468267441, 85.9133443236351, 81.74771144986153, 75.67372217774391, 84.13002401590347, 74.5857797563076, 88.3570083975792, 77.04344227910042, 74.76462855935097, 74.86047461628914, 63.911894112825394, 65.38171604275703, 73.56913670897484, 74.93007928133011, 74.55710649490356, 72.84324645996094, 69.9252538383007, 61.77780322730541, 62.21576392650604, 60.72168029844761, 64.99423563480377, 67.21378773450851, 72.36501932144165, 69.04039531946182, 73.81372958421707, 74.63700100779533, 36.768924593925476, 56.7886633425951, 65.87960332632065, 77.6522608101368, 78.37058946490288, 75.78731328248978, 74.08419147133827, 75.95332637429237, 71.10078155994415, 62.10244260728359, 55.78316509723663, 54.115369990468025, 57.18664638698101, 60.7639492303133, 59.53568033874035, 63.734337240457535, 64.3875601887703, 67.85338461399078, 66.69675707817078, 67.0302651822567, 65.47668814659119, 64.00821134448051, 67.75773614645004, 68.56567919254303, 67.25075215101242, 69.09228533506393, 65.81279531121254, 67.8067535161972, 72.31491521000862, 80.84424152970314, 72.26384595036507, 66.34661346673965, 72.13180303573608, 72.44948878884315, 71.55698508024216, 70.95870718359947, 73.38495299220085, 70.22021681070328, 79.2470808327198, 50.66418617963791, 3.3480440452694893, 2.2307296749204397, 3.7676495919004083, 5.314685991033912, 0.3836338862311095, 0.7555201090872288, 0.36799282708670944, 1.2054204801097512, 3.517005303874612, 46.4202319085598, 28.928877487778664, 94.32642728090286, 64.18747052550316, 10.222422368824482, 32.41650894284248, 55.95022313296795, 70.83720490336418, 3.9146537287160754, 0.32179695437662303, 0.029703716754738707, 0.05907289931201376, 0.03296026632597204, 0.04710521883680485, 0.045106273755664006, 0.08182665726053528, 0.06520377384731546, 0.03833962728094775, 0.10556115594226867, 0.04922757565509528, 0.07197454295237549, 0.054537241521757096, 0.0541194791730959, 0.07656712346943095, 0.06345004178001545, 0.059774176916107535, 0.04169201223703567, 0.046755292496527545, 0.038907782145543024, 0.0455973380303476, 0.053951126683386974, 0.02778443566057831, 0.02471614112437237, 0.08738400007132441, 0.044709970607073046, 0.04686815831519198, 0.053012836797279306, 0.13156779168639332, 0.15474579093279317, 0.2865059918258339, 0.110468926577596, 0.1748405079706572, 0.0912220093596261, 0.13011356815695763, 0.16309720842400566, 0.13934383692685515, 0.28101166477426887, 0.12488574633607641, 0.06359284583595581, 0.20282483368646353, 0.20140984008321539, 0.16751604474848136, 0.09137170796748251, 0.13106455618981272, 0.12454838084522635, 0.2121671667555347, 0.12888791126897559, 0.21008222160162404, 0.21591823344351724, 0.12828644510591403, 0.11713975065504201, 0.20052671403391287, 0.1383374846773222, 0.30371051863767207, 0.18769155198242515, 0.20823517930693924, 0.2360625853179954, 0.2159126673359424, 0.214194031432271, 0.21073301089927554, 0.23370209557469934, 0.1516416692174971, 0.8160872559528798, 18.00358783453703, 116.9027790427208, 94.65442568063736, 71.06067851185799, 35.21207973361015, 85.7718551158905, 110.51127880811691, 50.25864914059639, 11.446290146559477, 0.20011163083836436, 0.39149168645963073, 1.333224365953356, 1.2427399400621653, 4.612767705693841, 1.5181083139032125, 0.8805683709215373, 0.27697735000401735, 0.2698113798396662, 10.207668710500002, 18.671533092856407, 25.208381228148937, 54.38037157058716, 96.03898018598557, 103.81984546780586, 84.05740231275558, 76.05125471949577, 87.6884038746357, 83.14143866300583, 83.62389117479324, 98.11391204595566, 87.39502921700478, 82.4531663954258, 90.98735645413399, 84.94423672556877, 95.92797294259071, 84.9321685731411, 80.3078243136406, 82.36725300550461, 67.48304888606071, 73.65298300981522, 81.2760503590107, 81.90093442797661, 81.23630449175835, 78.68023484945297, 73.79289910197258, 66.99464589357376, 65.68621650338173, 65.00001132488251, 67.45793983340263, 73.24663281440735, 75.9397991001606, 73.7500450015068, 76.41225814819336, 79.78352844715118, 40.53376257419586, 55.454900711774826, 71.25043272972107, 79.41124722361565, 83.00957053899765, 78.51519450545311, 77.27909043431282, 81.6398960351944, 77.45912477374077, 67.16114535927773, 59.82816964387894, 57.84578561782837, 62.987430319190025, 64.22658562660217, 61.67200930416584, 68.37160840630531, 68.26015278697014, 74.29382622241974, 71.88394993543625, 72.6393873989582, 72.66226217150688, 69.80450391769409, 73.35436463356018, 74.75767493247986, 75.46781122684479, 75.65259531140327, 73.71653839945793, 77.27206081151962, 80.92770785093307, 86.80972382426262, 79.83383774757385, 72.07389414310455, 80.78612744808197, 76.4414481818676, 76.05820834636688, 75.59861540794373, 78.97231757640839, 72.10745394229889, 81.8956071138382, 55.014933720231056, 3.4835606859996915, 2.318955003283918, 3.599840383976698, 7.650323761627078, 2.39588163793087, 4.372493298724294, 1.2591570778749883, 1.1687849834561348, 2.8698071697726846, 38.21047984063625, 47.600551173090935, 101.81644856929779, 44.13017459213734, 20.959990695118904, 68.59802305698395, 68.18403527140617, 88.74654069542885, 6.623782245442271, 0.529141912702471, 0.17046989640221, 0.1277294781175442, 0.15502457128604874, 0.17281352455029264, 0.3378089686157182, 0.14052218932192773, 0.20321410498581827, 0.14800498232943937, 0.14661816065199673, 0.11502269277116284, 0.14495898562017828, 0.11206685216166079, 0.11057817813707516, 0.22772523894673213, 0.10325718816602603, 0.13015404489124194, 0.1276039215736091, 0.1363876846153289, 0.10815372268552892, 0.13621354708448052, 0.1303286277106963, 0.10229203995550051, 0.18728470662608743, 0.20845598308369517, 0.09819131038966589, 0.13799719512462616, 0.10164684645133093, 0.19989741733297706], [0.08197303846827708, 0.10053164340206422, 0.012942347657372011, 0.05736724357120693, 0.02796794466121355, 0.017596306570339948, 0.09327675652457401, 0.14031989470822737, 0.122627628443297, 0.05596433584287297, 0.042816113636945374, 0.15486995223909616, 0.060056779329897836, 0.06005883878970053, 0.1658943630172871, 0.09003518905956298, 0.026153998442168813, 0.06712074129609391, 0.04250748781487346, 0.03637427551439032, 0.07869233755627647, 0.062230607800302096, 0.04018368985271081, 0.10181796344113536, 0.04771712330693845, 0.006751062765033566, 0.04084335523657501, 0.042751160872285254, 0.04151852037466597, 0.04655789234675467, 0.052249504515202716, 0.03296361341199372, 0.0032293674848915543, 0.2167295344406739, 0.07764294074149802, 0.49185768992174417, 15.552294719964266, 88.5848517715931, 68.87141078710556, 69.2211440205574, 21.494844295084476, 35.53745627403259, 102.33934611082077, 51.91404931247234, 20.74922550469637, 2.078305366449058, 0.4624536802293733, 0.4042299388675019, 0.3415311954449862, 0.4469709360273555, 0.06544534291606396, 0.38983803300652653, 0.21947129513137043, 0.29431454313453287, 4.395232703536749, 0.44745003688149154, 0.19291306554805487, 4.559855069965124, 40.29940254986286, 91.38134971261024, 91.6636897623539, 74.9958385527134, 67.81471788883209, 67.96970397233963, 65.55503234267235, 72.3513400554657, 90.79830899834633, 82.66353830695152, 80.4395404458046, 81.19721218943596, 82.85991936922073, 73.97680923342705, 71.62054046988487, 69.448903799057, 72.73004293441772, 71.56829327344894, 72.71808877587318, 71.90341249108315, 72.4099937081337, 66.97275906801224, 63.615570813417435, 57.829488292336464, 57.505981251597404, 53.90950843691826, 59.25163418054581, 60.2406071126461, 72.53745406866074, 67.15815111994743, 80.29274672269821, 34.00472491979599, 29.88235842436552, 81.51585549116135, 72.93569549918175, 75.67087233066559, 70.05518406629562, 73.42593759298325, 68.27823221683502, 67.75216564536095, 53.14887285232544, 52.61991463601589, 53.63735184073448, 54.4749902933836, 55.54890766739845, 60.1407902687788, 63.81718799471855, 65.21245792508125, 65.53264394402504, 65.52936092019081, 63.93528565764427, 65.83764597773552, 66.00104480981827, 65.1946596801281, 64.30462583899498, 67.83276692032814, 70.49323216080666, 69.74961206316948, 65.02766624093056, 66.76151320338249, 72.45287820696831, 79.80750516057014, 75.05416542291641, 75.78292831778526, 70.46850308775902, 76.24689862132072, 78.10486972332001, 72.27011561393738, 71.71555057168007, 29.671944715082645, 1.5781330992467701, 0.6043323373887688, 23.925026692450047, 17.944037429988384, 0.026887722742685582, 0.5349498416762799, 0.4258698667399585, 0.13894485833588988, 8.84969187900424, 25.957805514335632, 30.774259865283966, 100.76265871524811, 26.830953061580658, 21.438839100301266, 52.85786546766758, 51.14823080599308, 64.4791428744793, 6.057116277515888, 0.2458438096800819, 0.19595765217673033, 0.14107605413300917, 0.0742536413599737, 0.02992938902025344, 0.025687037268653512, 0.04049917683005333, 0.05914633482461795, 0.0509200879605487, 0.054449130038847215, 0.08953665135777555, 0.0665234905318357, 0.013192617479944602, 0.022056790367059875, 0.050992473334190436, 0.02478370810422348, 0.05369732702092733, 0.043897908908547834, 0.030880347367201466, 0.02182109354180284, 0.01730630679958267, 0.09744059090735391, 0.03653945532278158, 0.04335425604949705, 0.024863629987521563, 0.006929034880158724, 0.05588741594692692, 0.07866683736210689, 0.04376417760795448, 0.02246692714834353, 0.029433517483994365, 0.05114895146107301, 0.02613407177705085, 0.08369898452656344, 0.0738323612313252, 0.0400795405585086, 0.09719899215269834, 0.07095839435351081, 0.04988952314306516, 0.024734201288083568, 0.05439330940134823, 0.07146411604480818, 0.08546649827621877, 0.07687861769227311, 0.059620125612127595, 0.017780682028387673, 0.04530666476057377, 0.033120766893262044, 0.053671659843530506, 0.04261446840246208, 0.11521763270138763, 0.03927681878849398, 0.058960304377251305, 0.03340781477163546, 0.047059595308382995, 0.08520301358657889, 0.040076208315440454, 0.05548057430132758, 0.024876348543330096, 0.08350818578037433, 0.006247729397728108, 0.059489670893526636, 0.03207941867003683, 0.19483772164676338, 0.11105834026238881, 0.8102482161484659, 26.81026317179203, 105.21503940224648, 65.14444157481194, 40.39909780025482, 22.378861159086227, 85.24624451994896, 111.63099512457848, 55.133768543601036, 31.231386736035347, 1.8702412373386323, 0.6620821729302406, 0.29660356405656785, 0.29784069454763085, 1.1119313654489815, 0.07632578446646221, 0.3555360861355439, 0.1492652975139208, 0.2470366784837097, 7.277612686157227, 2.822518232278526, 1.2203021440654993, 7.523452844470739, 57.26154416799545, 102.54572823643684, 93.20236399769783, 72.7079889178276, 68.2663768529892, 67.4589429795742, 72.18251511454582, 75.87688967585564, 86.86367332935333, 81.55197635293007, 82.83950686454773, 83.17009672522545, 80.71954742074013, 74.51195731759071, 73.77672716975212, 70.06028339266777, 74.81992319226265, 73.80127385258675, 78.63000154495239, 75.81339508295059, 74.73037719726562, 70.5927412211895, 68.49245712161064, 62.27710783481598, 62.6241660118103, 60.33579960465431, 65.34279093146324, 65.71898594498634, 76.19057044386864, 73.24070513248444, 83.618533462286, 36.96975901722908, 36.7974154651165, 81.81803047657013, 78.35318639874458, 76.3508914411068, 72.78167456388474, 77.88603946566582, 74.54519793391228, 70.68669497966766, 57.985530719161034, 55.93579150736332, 56.58279798924923, 57.73920513689518, 59.38208118081093, 62.16416649520397, 67.57698744535446, 68.59105423092842, 68.58881995081902, 67.3388010263443, 65.70006296038628, 69.35221418738365, 69.97117057442665, 67.80141860246658, 67.9993423819542, 69.83955323696136, 74.86745104193687, 73.96457388997078, 71.80477738380432, 70.55249378085136, 68.19255441427231, 78.64624187350273, 77.19535812735558, 80.10205775499344, 74.93455544114113, 78.39013561606407, 84.99859660863876, 77.18867808580399, 77.9170686006546, 35.24488717317581, 1.3719581812620163, 0.8409231388941407, 30.43149545788765, 21.763377785682678, 0.06668349757092074, 0.9769205725751817, 0.3369511349592358, 0.4829188477015123, 16.545860655605793, 49.05153751373291, 22.968549616634846, 102.16513305902481, 61.703741401433945, 11.980480682104826, 35.28258115053177, 53.45441445708275, 73.01281616091728, 7.775401649996638, 0.39852834481280297, 0.21453133755130693, 0.09770984208444133, 0.022563298734894488, 0.003281888812125544, 0.009361823722429108, 0.0942091314936988, 0.03498217345622834, 0.06468826322816312, 0.05748223193222657, 0.08890878700185567, 0.0778348749736324, 0.016033443753258325, 0.11259756938670762, 0.04413283946632873, 0.009087525013455888, 0.017929154237208422, 0.010603434002405265, 0.02692037909582723, 0.016391812023357488, 0.04678388373577036, 0.05046730366302654, 0.0033425053470637067, 0.05196560705371667, 0.04299179854569957, 0.025379695362062193, 0.03979955050454009, 0.008661958981974749, 0.023514505701314192, 0.07731962410616688, 0.12309412020840682, 0.17814178863773122, 0.1405293881543912, 0.1967105906805955, 0.26230791059788316, 0.09326227722340263, 0.22850173321785405, 0.2977892488706857, 0.15662297926610336, 0.15076483658049256, 0.13686605816474184, 0.22674938896670938, 0.20611557585652918, 0.1473941799486056, 0.32591005554422736, 0.18458352657034993, 0.11250713127083145, 0.14974886609707028, 0.1211101071385201, 0.14835045207291842, 0.24425822601187974, 0.13067748164758086, 0.11708553676726297, 0.2277825921191834, 0.09717767024994828, 0.13576266268501058, 0.24478124716551974, 0.12542356591438875, 0.13011117844143882, 0.15180655958829448, 0.1917763179517351, 0.1744524686364457, 0.11075495029217564, 0.38082144339568913, 0.22665825323201716, 1.0132467420771718, 36.310004219412804, 124.96048226952553, 87.61043205857277, 88.94262537360191, 30.657490231096745, 57.90567800402641, 117.92802482843399, 78.32980245351791, 33.98219212889671, 3.2069637905806303, 0.6758682487998158, 0.5477491579949856, 0.8035098121035844, 1.6141309426166117, 0.16513587324880064, 1.2339620548300445, 0.46546763100195676, 0.2799010556191206, 7.498986907303333, 3.8033458264544606, 0.8776895503979176, 6.280025616288185, 50.45419044792652, 102.92677938938141, 101.13025099039078, 80.71219861507416, 75.56116461753845, 71.06855168938637, 73.63330006599426, 79.6414464712143, 93.28895375132561, 84.5302565395832, 89.05242428183556, 85.59020206332207, 89.66025486588478, 84.6511660516262, 82.95012652873993, 79.83942344784737, 82.73440450429916, 80.63990369439125, 84.54412579536438, 83.7400433421135, 84.23631191253662, 75.99804237484932, 76.75759121775627, 67.53787234425545, 68.60242322087288, 65.22255018353462, 71.01185113191605, 68.94536241889, 82.5976650416851, 78.31884384155273, 88.8449402153492, 43.600182831287384, 40.268749594688416, 88.65015506744385, 84.39686089754105, 81.09728515148163, 76.55236423015594, 81.38576567173004, 80.71024551987648, 75.3511118888855, 62.13430769741535, 59.739767387509346, 63.455515801906586, 62.9911807179451, 66.09314426779747, 68.47249299287796, 73.75575229525566, 74.19661223888397, 76.20095148682594, 75.77336803078651, 71.27459943294525, 74.24915581941605, 78.05965974926949, 76.42725214362144, 77.15965524315834, 77.2513747215271, 83.0711804330349, 82.58330181241035, 81.152313798666, 77.90229499340057, 77.9144923388958, 90.64869582653046, 86.52552947402, 85.77728882431984, 86.68854832649231, 88.0322778224945, 92.55035698413849, 83.65706339478493, 82.16235280036926, 38.01918290555477, 1.567190873902291, 0.5395563819911331, 39.445607364177704, 28.688772171735764, 0.08918360428651795, 1.8090355466119945, 0.9491435287054628, 0.45182971749454737, 12.914143782109022, 37.36512780189514, 43.905450850725174, 109.49755400419235, 45.57575762271881, 30.527105927467346, 78.48561689257622, 63.730564042925835, 87.46170803904533, 12.99561521038413, 0.8790420403238386, 0.36645230662543327, 0.39724983216729015, 0.2064502250868827, 0.08801010553725064, 0.09795909238164313, 0.20750726602273062, 0.20117777050472796, 0.11119568211142905, 0.09618456533644348, 0.12893696723040193, 0.17091610527131706, 0.17038883903296664, 0.1551814316189848, 0.12217432464240119, 0.13776166713796556, 0.10714719232055359, 0.10646671711583622, 0.07144749935832806, 0.08280362788354978, 0.07477831008145586, 0.21392074297182262, 0.11646043320070021, 0.09877573684207164, 0.08286439493531361, 0.23741048877127469, 0.1730119451531209, 0.08639343330287375, 0.1017878099810332, 0.11134064581710845], [0.015136917299969355, 0.05268078879453242, 0.09160210029222071, 0.008954257555160439, 0.0756084913155064, 0.04951683142280672, 0.04175642323389184, 0.058746361755765975, 0.030953938730817754, 0.04308738345571328, 0.018071125232381746, 0.0708014152769465, 0.13188008742872626, 0.03473380631476175, 0.1516800679382868, 0.07320992939639837, 0.07578584234579466, 0.04529828962404281, 0.02777057048660936, 0.10382994805695489, 0.10648351191775873, 0.009354874437121907, 0.022038878632884007, 0.025592984893592075, 0.0746723313932307, 0.029715051205130294, 0.04380190097435843, 0.03017730159626808, 0.007188460485849646, 0.09173358659609221, 0.05753286495746579, 0.025944707231246866, 0.036689335756818764, 0.13414923363598064, 0.08561575901694596, 0.19219834764953703, 0.4744661715812981, 19.16698280721903, 80.61718091368675, 69.19986516237259, 67.51148656010628, 20.55698812007904, 26.80105246603489, 96.98572218418121, 66.43199488520622, 29.969624541699886, 12.190442215651274, 0.1720269222278148, 0.7653563562780619, 0.17123464989708737, 0.4441030399175361, 0.6245519430376589, 0.03199581573426258, 0.8063857234083116, 2.9743661591783166, 21.320519149303436, 11.455928329378366, 1.886649588122964, 0.41957636538427323, 1.7643803427927196, 20.270667783915997, 42.131124660372734, 71.1305795609951, 83.33284959197044, 87.99524500966072, 93.99998679757118, 83.98603454232216, 85.26401236653328, 88.49861159920692, 84.64552715420723, 86.5061505138874, 83.3897553384304, 75.92013895511627, 78.13245624303818, 77.29843139648438, 73.91025200486183, 69.30293843150139, 69.1054630279541, 67.25812375545502, 62.79644496738911, 67.39321410655975, 65.35416752099991, 61.86216250061989, 58.40814024209976, 63.47604610025883, 61.01294606924057, 70.24557664990425, 59.78598810732365, 83.7388502061367, 29.394956678152084, 18.492788784205914, 90.98892197012901, 70.9167954325676, 74.21299695968628, 69.95163962244987, 71.39702886343002, 63.41719105839729, 58.91773469746113, 50.23099422454834, 56.70032948255539, 56.23843766748905, 57.96229496598244, 58.85420210659504, 61.33326508104801, 60.195066556334496, 63.852564096450806, 63.75835195183754, 66.1081762611866, 70.72588607668877, 64.30515021085739, 68.22631180286407, 68.8965730369091, 67.70418182015419, 71.86476096510887, 66.55437871813774, 65.18331348896027, 72.81701266765594, 76.546580940485, 70.64483642578125, 51.814475655555725, 37.09152348339558, 24.700798764824867, 26.172832176089287, 27.202899903059006, 20.01910798251629, 12.492943983525038, 4.303545048460364, 0.22413639089791104, 0.5591648141853511, 0.2946879621595144, 8.854696210473776, 5.315104443579912, 0.18853702145861462, 0.08648627597722225, 0.15126428712392226, 19.96132828295231, 20.051049068570137, 30.771145932376385, 99.45311978459358, 21.02201096713543, 17.25986324250698, 62.518641874194145, 46.950311064720154, 61.37404829263687, 5.281514720991254, 0.24319722200743854, 0.13808824180159718, 0.10536707690334879, 0.06338645456708036, 0.09083217402803712, 0.060482931658043526, 0.00851093935125391, 0.020617970112652984, 0.04780073737492785, 0.026591769092192408, 0.06704424071358517, 0.03221384387870785, 0.1163257853477262, 0.048388726136181504, 0.08752575027756393, 0.04527801414951682, 0.035300495437695645, 0.06313559380942024, 0.11910288711078465, 0.03736672362720128, 0.010452163896843558, 0.10821909847436473, 0.015470803045900539, 0.030992946012702305, 0.04624550754670054, 0.08519160677678883, 0.05380145405069925, 0.035516193238436244, 0.02648750290973112, 0.032542630142415874, 0.03723212030308787, 0.016758403289713897, 0.03375795633473899, 0.07974763444508426, 0.02557809555582935, 0.03321655960462522, 0.01864157704403624, 0.021686338077415712, 0.05302957222738769, 0.057302828863612376, 0.02207927558629308, 0.06812111183535308, 0.06546177406562492, 0.0688121106941253, 0.04943545121932402, 0.13778684078715742, 0.10640039879945107, 0.07724476367002353, 0.0695306877605617, 0.12830529565690085, 0.042198546580038965, 0.0793112738756463, 0.022402913200494368, 0.03581344564736355, 0.018861757416743785, 0.03410588629776612, 0.04854660692217294, 0.04771987296408042, 0.037053451960673556, 0.03467114678642247, 0.05516150646144524, 0.09074485293240286, 0.01385749181281426, 0.06331843673251569, 0.09625394130125642, 0.08251828694483265, 0.22044420620659366, 0.9875946154352278, 32.737306728959084, 92.65805840492249, 67.65982300043106, 36.783200427889824, 10.335500501096249, 69.3114347755909, 119.97091680765152, 64.04091238975525, 47.71518722176552, 17.44972575455904, 0.3969659161521122, 0.430728915380314, 0.452934181666933, 0.599300101166591, 0.6389784626662731, 0.2273612006683834, 0.6737730768509209, 2.6964951446279883, 20.076809786260128, 11.387674491852522, 2.015437977388501, 0.3104248770978302, 6.37369628995657, 38.02064202725887, 60.79343184828758, 81.81309834122658, 84.4852365553379, 81.7064380645752, 85.33565372228622, 83.1264978647232, 87.3169358074665, 83.22067961096764, 83.26493203639984, 86.82789444923401, 77.31125950813293, 74.26320746541023, 75.85865065455437, 78.27605813741684, 78.59209477901459, 74.98423397541046, 72.15283870697021, 75.16806051135063, 73.45521122217178, 73.0178850889206, 71.58773303031921, 66.62138432264328, 62.49103255569935, 69.37834918498993, 66.31009742617607, 77.50317960977554, 66.02953568100929, 85.80704122781754, 33.618072867393494, 23.39249286800623, 94.56826150417328, 75.32465770840645, 80.5978475511074, 75.87350025773048, 77.33690813183784, 69.79100704193115, 64.42146956920624, 55.85881143808365, 61.38377957046032, 59.36197645962238, 61.30029805004597, 61.47601582109928, 63.62346678972244, 67.46044769883156, 67.76886194944382, 69.25978794693947, 67.79202550649643, 75.27766183018684, 70.22436618804932, 72.5869046151638, 73.54115501046181, 73.72574150562286, 77.64998853206635, 73.53056117892265, 71.00010976195335, 73.05427953600883, 77.76138335466385, 79.5382972061634, 70.35157576203346, 49.236329197883606, 37.231545969843864, 35.28185158967972, 36.565339118242264, 28.169123455882072, 18.12394067645073, 6.9175872299820185, 0.21790552680613473, 1.0875655291602015, 2.5421089539304376, 13.826176542788744, 5.214176159352064, 0.3289298841264099, 0.08007300682947971, 0.3572960151359439, 37.967589274048805, 39.92471605539322, 16.752907745540142, 112.31172099709511, 50.88622346520424, 11.490306034684181, 46.87026455998421, 50.84027633070946, 73.13625633716583, 9.512848444283009, 0.444029982900247, 0.09014512339490466, 0.07021073994110338, 0.0893440269283019, 0.028294780931901187, 0.031209736625896767, 0.056485342065570876, 0.04824048213777132, 0.08821881972835399, 0.06405586434993893, 0.041888781561283395, 0.03503341875330079, 0.04401840771606658, 0.03882062061165925, 0.07134362836950459, 0.03800676662649494, 0.030241803506214637, 0.08250741448136978, 0.0416326255799504, 0.03762961088796146, 0.03829599270829931, 0.0077564947514474625, 0.036637274097302, 0.016168744696187787, 0.05729080978198908, 0.06198575472808443, 0.04479803756112233, 0.07075843750499189, 0.008796624460956082, 0.02186288016673643, 0.0400373123557074, 0.08840727328788489, 0.0870580413902644, 0.16677147767040879, 0.09373184890137054, 0.13532292534364387, 0.10992906609317288, 0.13717447989620268, 0.224997861078009, 0.11350715300068259, 0.17849675787147135, 0.1022927078884095, 0.1673658934305422, 0.1427689375123009, 0.13793449848890305, 0.26175109203904867, 0.26829552836716175, 0.14928916498320177, 0.1076700130943209, 0.1434258124209009, 0.22915134992217645, 0.1484152118791826, 0.06665100634563714, 0.11065128710470162, 0.11237499929848127, 0.16490941430674866, 0.08892075042240322, 0.11150692400406115, 0.10837203284609132, 0.1911337219644338, 0.17377886571921408, 0.14113892888417467, 0.11907813648576848, 0.1160007320868317, 0.17784834344638512, 0.277042540255934, 0.24617734568892047, 1.0230810893699527, 45.76000213623047, 115.70319101214409, 89.05388340353966, 91.95041477680206, 28.531384617090225, 51.092727184295654, 109.72753286361694, 89.40840438008308, 51.1934407800436, 18.162491507828236, 0.35519211553037167, 0.850989333121106, 0.5394005903508514, 1.5817951527424157, 0.799730618018657, 1.7577406740747392, 2.477777930907905, 7.757632378488779, 31.15134973078966, 17.762182988226414, 1.9000337761826813, 0.41644500684924424, 4.871635464951396, 32.535499557852745, 57.78742454946041, 84.99556437134743, 91.94754973053932, 93.66801381111145, 94.82610806822777, 88.11335027217865, 92.3431845009327, 92.0763248205185, 92.82638937234879, 95.79352095723152, 89.80924487113953, 86.18734762072563, 85.18319830298424, 90.34169510006905, 88.83458197116852, 81.07499554753304, 77.88220167160034, 82.94973134994507, 77.67468720674515, 81.4860574901104, 77.98810958862305, 72.48086750507355, 68.9362733066082, 74.68510642647743, 70.57122677564621, 83.66082519292831, 68.40296432375908, 93.37914571166039, 33.671395406126976, 24.549152702093124, 97.04929277300835, 78.58493596315384, 84.8596228659153, 80.20102724432945, 82.89106249809265, 71.74645811319351, 67.84377872943878, 60.91740019619465, 66.5546827018261, 66.19482681155205, 66.48515403270721, 65.5534516274929, 68.12554880976677, 69.41662073135376, 71.52352407574654, 74.21588480472565, 73.84121730923653, 83.0463145673275, 75.5131807923317, 78.42318624258041, 79.69566196203232, 80.77584519982338, 88.32053795456886, 81.17806881666183, 77.37790793180466, 84.00126412510872, 92.38588660955429, 90.29029905796051, 72.88672372698784, 48.71250830590725, 32.514790669083595, 30.018484219908714, 34.824508130550385, 25.3118097782135, 15.124238189309835, 6.235324339941144, 0.2536010934272781, 1.27684275386855, 7.141829347237945, 16.86783827841282, 6.653726063668728, 0.9150715288706124, 0.2671012346399948, 0.49823330249637365, 29.0322832390666, 33.88340882956982, 40.08132465183735, 113.4523057937622, 35.354104712605476, 22.19114363193512, 87.3222479224205, 61.37300334870815, 88.96241471171379, 14.982780329883099, 0.6769638962578028, 0.3017130133230239, 0.31154183903709054, 0.20185781526379287, 0.21924094733549282, 0.1285730180097744, 0.18395500170299783, 0.2225108796847053, 0.21619918086798862, 0.17562225664732978, 0.11383890043362044, 0.20492523035500199, 0.1186557876644656, 0.1432280449080281, 0.2048461025697179, 0.10700373517465778, 0.09519492625258863, 0.1720673099043779, 0.19400534365558997, 0.0969958292262163, 0.17165126191684976, 0.13047434098552912, 0.060650282248388976, 0.16742603707825765, 0.12913892045617104, 0.12516578834038228, 0.08735029172385111, 0.16361399553716183, 0.05383500283642206, 0.1667209670995362, 0.06342174368910491], [0.07829497684724629, 0.033606216820771806, 0.04935930315696169, 0.1669318409403786, 0.021686950349248946, 0.005146101157151861, 0.05801426275866106, 0.12226004269905388, 0.032336802905774675, 0.020478496444411576, 0.059104681786266156, 0.044571044272743165, 0.10613201593514532, 0.024838680838001892, 0.02574309353803983, 0.05309596104780212, 0.04727466970507521, 0.021370463327912148, 0.0476855078159133, 0.04617453596438281, 0.04784634606039617, 0.04172438842942938, 0.029234564390208106, 0.03372682323970366, 0.029229868450784124, 0.025409453628526535, 0.061454558817786165, 0.06631987489527091, 0.01657912082009716, 0.04137539719522465, 0.007554385210823966, 0.056834927017916925, 0.03436288461671211, 0.09406265380675904, 0.08709773886948824, 0.20447531074751168, 0.16162913641892374, 0.8517863403540105, 35.8739510178566, 88.74514997005463, 56.17640219628811, 70.06694823503494, 27.740185372531414, 14.97012510895729, 80.90501546859741, 72.5496818125248, 33.76813821494579, 26.066217496991158, 4.506323542445898, 0.47874806681647897, 0.17340194375719875, 0.15674990136176348, 0.6083157111424953, 1.054007748607546, 3.012681403197348, 32.536392509937286, 44.87054206430912, 39.59513694047928, 40.63887633383274, 13.109670840203762, 1.9403570936992764, 0.3527818573638797, 2.37666345667094, 15.625533889979124, 40.01792125403881, 61.78772829473019, 84.84082147479057, 89.15419802069664, 84.15368154644966, 88.03537845611572, 88.05557057261467, 91.39510497450829, 92.48107150197029, 93.64761650562286, 81.7983703315258, 71.39371544122696, 66.60454362630844, 67.40636140108109, 66.15767240524292, 60.94807215034962, 63.95244553685188, 59.93308201432228, 65.40918856859207, 57.51157075166702, 66.77260860800743, 62.8464312851429, 77.95037761330605, 67.49224439263344, 87.42144539952278, 13.445244133472443, 8.9921984821558, 87.24284738302231, 67.31378316879272, 70.31614646315575, 61.41553446650505, 66.91413581371307, 55.831289514899254, 52.40704245865345, 53.051985651254654, 55.36401338875294, 56.97362221777439, 58.86877052485943, 57.64779344201088, 57.91002877056599, 67.42957815527916, 69.27453115582466, 66.77162826061249, 72.47857242822647, 67.56401494145393, 71.67258247733116, 73.68301659822464, 77.83892959356308, 76.11690759658813, 76.76418006420135, 77.50340759754181, 79.71115753054619, 61.557722836732864, 42.91811563074589, 24.242324866354465, 9.157188478857279, 2.348840399645269, 0.4375109577085823, 0.2584709180518985, 0.04245715907018166, 0.011966187830694253, 0.6741797144059092, 0.11650478394585662, 0.766535836737603, 2.220000713132322, 1.7251219181343913, 0.3747108665993437, 0.2155734019470401, 0.35213060793466866, 2.4186319671571255, 25.954607985913754, 13.175774943083525, 38.47150683403015, 100.33802390098572, 12.121377121657133, 21.683564968407154, 55.11300265789032, 51.78253456950188, 63.93978461623192, 8.497564774006605, 0.5878636648412794, 0.1719576946925372, 0.06174115027533844, 0.006104813555793953, 0.06182470497151371, 0.003179532268404728, 0.0748734237276949, 0.06527266741613857, 0.06173491994559299, 0.021310705596988555, 0.07237951809656806, 0.05538592449738644, 0.05297391486237757, 0.04752018328872509, 0.07740718268905766, 0.04542372371361125, 0.056505194515921175, 0.04286123250494711, 0.012823139259126037, 0.03426387098443229, 0.015500060362683143, 0.08186446226318367, 0.03800029880949296, 0.018176664198108483, 0.05523425177671015, 0.04043405337142758, 0.01901155621453654, 0.08144831037498079, 0.035241925143054686, 0.020118951870244928, 0.08884522947482765, 0.021306080161593854, 0.013948084852017928, 0.06936718520591967, 0.10793491528602317, 0.0477448647870915, 0.014671031312900595, 0.060424658222473226, 0.047613196657039225, 0.03761030762689188, 0.01739894909405848, 0.04913027638394851, 0.014950623390177498, 0.050578874433995225, 0.05703574475774076, 0.0309649280825397, 0.06123108702013269, 0.08225958168623038, 0.052338877649162896, 0.08547479548724368, 0.010077601964439964, 0.046912234465708025, 0.03733541612746194, 0.008096124256553594, 0.0388163829484256, 0.020737179438583553, 0.07980457943631336, 0.10652960670995526, 0.03349577040353324, 0.03212632982467767, 0.0625843190937303, 0.029489338121493347, 0.03596960836148355, 0.06291931713349186, 0.07505091576604173, 0.03997138366685249, 0.10350787822972052, 0.2013510768301785, 0.0960711800144054, 1.0553343524225056, 51.39225751161575, 100.43941766023636, 55.416594967246056, 43.33628699183464, 11.340212188661098, 47.017837241292, 116.31530776619911, 63.733170703053474, 44.96796503663063, 41.102052479982376, 5.5557056330144405, 1.0424906853586435, 0.04155057744355872, 0.46586815326008946, 0.5141492828261107, 1.4024115283973515, 3.405394130386412, 42.07978181540966, 47.78152786195278, 40.85754320025444, 38.275524750351906, 11.257904805243015, 1.806197336409241, 0.23756865528412163, 8.581849951297045, 30.09310271590948, 57.76155933737755, 75.70228904485703, 90.59730738401413, 88.98826092481613, 88.48627746105194, 83.54480981826782, 82.97418683767319, 86.07830867171288, 85.64453154802322, 84.59023252129555, 80.24551525712013, 73.10062184929848, 72.09347069263458, 74.54506114125252, 74.58353027701378, 67.59369134902954, 75.33889174461365, 68.3486120402813, 74.21779990196228, 63.808874040842056, 72.93898612260818, 66.83232620358467, 83.40867072343826, 72.6435899734497, 91.3325147330761, 15.927846617996693, 10.49252612516284, 91.47457391023636, 73.48811745643616, 75.73007315397263, 68.40228796005249, 71.91046491265297, 63.05947445333004, 58.44189003109932, 58.65375906229019, 61.984819918870926, 60.82415319979191, 64.42861318588257, 62.36174449324608, 62.925911620259285, 70.76619431376457, 71.45791679620743, 71.37850105762482, 74.69028934836388, 72.20279082655907, 74.92143854498863, 75.79825669527054, 77.32801660895348, 75.94805225729942, 76.31768122315407, 78.01537692546844, 81.31124407052994, 75.84301829338074, 58.637400940060616, 37.20417223870754, 15.033930335193872, 5.52657924592495, 1.6180753684602678, 0.7899260160047561, 0.6131047010421753, 0.06407155335182324, 0.7318151404615492, 0.24213332362705842, 2.4460472585633397, 2.9263664223253727, 1.3515536324121058, 0.5763671442400664, 0.23641396255698055, 0.5388449295423925, 4.63487159460783, 50.99918760359287, 22.10642147809267, 16.683432273566723, 125.88393151760101, 39.701044857501984, 9.457852095365524, 39.485148042440414, 53.280224204063416, 75.240408629179, 14.337225370109081, 0.5263941257726401, 0.16938196728006005, 0.18361744325375184, 0.019195484528609086, 0.058176340389763936, 0.05739825792261399, 0.04601002779963892, 0.05265665786282625, 0.053774020561832, 0.050650139164645225, 0.05781401276180986, 0.09433214989257976, 0.023903294604679104, 0.05710204452043399, 0.050792394031304866, 0.12349994882242754, 0.031255545691237785, 0.014795370734645985, 0.07227442998555489, 0.03633128661022056, 0.0350950763822766, 0.0850069901207462, 0.06520418945001438, 0.02208320154750254, 0.04400550176796969, 0.02082072114717448, 0.038243957023951225, 0.053706258768215775, 0.03514207659463864, 0.08420460231718607, 0.06350640789605677, 0.016619371199340094, 0.19445863261353225, 0.1855077824438922, 0.1515998417744413, 0.28315786679740995, 0.11248983922996558, 0.08594551749411039, 0.13039331330219284, 0.20234387746313587, 0.09039762429893017, 0.12277510060812347, 0.2056091045960784, 0.15538584877504036, 0.26739358145277947, 0.13762454793322831, 0.2205764569225721, 0.13933303125668317, 0.1370223396224901, 0.1879535597981885, 0.13856657082214952, 0.10691699295421131, 0.1665103159029968, 0.08506111495080404, 0.15113825560547411, 0.1065592777740676, 0.19887038884917274, 0.24844729341566563, 0.1981258811429143, 0.13834263518219814, 0.18394222192000598, 0.15148771810345352, 0.15778083354234695, 0.1541810017079115, 0.1527196090319194, 0.1911594596458599, 0.15983325778506696, 0.36322058003861457, 0.14528097381116822, 0.9640091028995812, 66.91528335213661, 119.49541792273521, 74.96424704790115, 96.32459565997124, 38.161895647645, 34.81839805841446, 98.24333310127258, 85.73168367147446, 54.32856135070324, 38.117244243621826, 6.9096029084175825, 0.8287730533629656, 0.17237960564671084, 0.5025425681378692, 1.0716733569279313, 4.328942885622382, 10.788986217230558, 47.86445081233978, 53.99480625987053, 51.9252473115921, 47.7041982114315, 18.04766546934843, 2.522368775680661, 0.25802945892792195, 5.038724849000573, 20.530178658664227, 45.05733624100685, 65.14408439397812, 91.58542156219482, 93.27399015426636, 94.12000715732574, 90.65647020936012, 94.41764518618584, 97.79927372932434, 101.80514797568321, 99.91702169179916, 93.78731220960617, 80.27160465717316, 80.50061076879501, 82.15417563915253, 84.85032096505165, 74.35425817966461, 82.61718079447746, 76.24960407614708, 82.22416028380394, 70.8267630636692, 80.77803388237953, 75.49062520265579, 93.35899159312248, 80.78402996063232, 96.72979071736336, 15.094525683671236, 10.824598856270313, 99.25275653600693, 81.15257978439331, 83.43924388289452, 73.66416960954666, 77.79654666781425, 68.66922363638878, 64.987403601408, 65.94926878809929, 68.40858042240143, 68.70798155665398, 69.96251463890076, 69.3651182949543, 68.75452145934105, 78.9732675254345, 81.24822065234184, 78.28215301036835, 83.22995111346245, 80.67550778388977, 81.24837264418602, 84.26380723714828, 85.14759421348572, 85.46948254108429, 85.02339407801628, 86.71343699097633, 91.99972853064537, 79.97615531086922, 58.173594027757645, 32.03776806592941, 10.661204773932695, 3.0769656412303448, 0.9405522490851581, 0.4287303116871044, 0.31023061252199113, 0.24875138100469485, 0.6541200564242899, 0.13857829675544053, 3.3969813818112016, 5.170262390747666, 3.6709697172045708, 2.0818394143134356, 0.3853371151490137, 0.5402647471055388, 4.590009776875377, 42.90353961288929, 25.651804134249687, 48.88142064213753, 116.83277919888496, 27.087467797100544, 29.33003146201372, 78.44110608100891, 64.24477905035019, 88.15276935696602, 18.70247483253479, 0.7715652824845165, 0.3214902989566326, 0.2991450933041051, 0.1956563550629653, 0.23323712521232665, 0.19849714793963358, 0.11561508988961577, 0.12583093077410012, 0.11489919197629206, 0.13088986946968362, 0.17338494857540354, 0.15638663491699845, 0.10421469225548208, 0.14942255860660225, 0.1727764171664603, 0.12275614615646191, 0.1331250401563011, 0.1034265685302671, 0.18993904232047498, 0.11943263074499555, 0.20078849920537323, 0.21134428825462237, 0.1684556482359767, 0.10991137329256162, 0.15291909832740203, 0.13783910282654688, 0.11560844024643302, 0.22110960097052157, 0.09114135275012814, 0.1289333010208793, 0.10653019300661981, 0.07815198725438677], [0.003148763521494402, 0.019494946682243608, 0.030382848672161344, 0.0418638825067319, 0.07815857010427862, 0.07454516438883729, 0.0333803182002157, 0.004444267869985197, 0.0811270865960978, 0.03190794916008599, 0.06393829331500456, 0.03161273765726946, 0.02226326698291814, 0.024037779185164254, 0.013368863637879258, 0.025531748433422763, 0.036809051598538645, 0.014335200212372001, 0.06243528099730611, 0.024528518770239316, 0.12021951508359052, 0.02991665191075299, 0.05500026003574021, 0.03699441040225793, 0.04699536984844599, 0.05030312204326037, 0.041420386187382974, 0.03925331497157458, 0.07144432296627201, 0.020460653358895797, 0.024281847436213866, 0.059389358502812684, 0.06141182595456485, 0.07912158835097216, 0.07906625382020138, 0.1105494199146051, 0.059299733038642444, 0.12433021911419928, 0.5902720824815333, 23.61237946897745, 90.92396825551987, 67.50693440437317, 75.47798708081245, 39.51415568590164, 10.836028642952442, 63.456097170710564, 86.44847720861435, 44.270197078585625, 28.23057945817709, 19.367245361208916, 0.7751249789725989, 0.9142216213513166, 0.21268840675475076, 0.17370655084960163, 2.536616111174226, 3.5837024124339223, 20.383282341063023, 76.61734074354172, 66.88710406422615, 43.72646525502205, 19.26063258200884, 16.4056196808815, 2.9898714646697044, 0.37338491587433964, 0.19680377474287525, 2.806272441521287, 12.667933143675327, 35.69098323583603, 56.385238990187645, 66.86359092593193, 76.63184836506844, 85.57374134659767, 90.3390884399414, 95.4318867623806, 92.91435465216637, 85.06872564554214, 71.03933125734329, 64.93245854973793, 55.32861448824406, 53.28194171190262, 58.80336843430996, 59.330438151955605, 62.5410682708025, 62.49575190246105, 71.98511570692062, 65.88860884308815, 71.20122537016869, 55.652300119400024, 80.1599058508873, 4.3150878790766, 2.274784273467958, 76.09120577573776, 61.6947852820158, 61.708312556147575, 54.631929472088814, 55.434799790382385, 49.459023848176, 53.15313242375851, 53.42519022524357, 57.79370941221714, 55.652592703700066, 57.16092936694622, 55.188485607504845, 57.25082114338875, 66.45404130220413, 72.24382102489471, 71.25183865427971, 74.11056205630302, 73.58268678188324, 79.38464865088463, 73.17452028393745, 82.27864935994148, 92.106252014637, 85.91528981924057, 57.34828971326351, 31.296948418021202, 14.193059206008911, 3.131828047335148, 0.7202611479442567, 0.5041941732633859, 0.44750385743100196, 0.5128889973275363, 0.4747390444390476, 0.051383013706072234, 0.1195062072656583, 0.9287923551164567, 1.9270485453307629, 3.924174355342984, 0.47417139052413404, 0.30478016124106944, 0.1443560648476705, 0.12378755331155844, 14.023462906479836, 42.91097581386566, 25.830671936273575, 61.46370828151703, 89.97597232460976, 7.733390154317021, 30.377563051879406, 62.87913993000984, 54.87276814877987, 71.83215871453285, 8.01540769636631, 0.21504886681213975, 0.11149478246807121, 0.019235708932683337, 0.037000295633333735, 0.03248807857744396, 0.03041588166524889, 0.022512300201924518, 0.11887731874594465, 0.09575417905580252, 0.10725068481406197, 0.05987782154988963, 0.022281314159044996, 0.048575187029200606, 0.11471530262497254, 0.025970836395572405, 0.044595739236683585, 0.026619655291142408, 0.03679229019326158, 0.11975941320997663, 0.08961655097664334, 0.0851357082137838, 0.03406575466215145, 0.024630102088849526, 0.053820738758076914, 0.07622687102411874, 0.01810088720958447, 0.04256250322214328, 0.040333013675990514, 0.016592186329944525, 0.06815996326622553, 0.0018448918058311392, 0.06315013990388252, 0.005677894496329827, 0.042663027124945074, 0.024856227064447012, 0.04405080988362897, 0.024813841155264527, 0.0825884347432293, 0.05715719351428561, 0.013824972756992793, 0.1140966780076269, 0.035133682904415764, 0.04056067860801704, 0.06377634184900671, 0.046340365151991136, 0.03657349392597098, 0.06581773777725175, 0.032698288196115755, 0.013287325728015276, 0.03712861296662595, 0.009114258100453299, 0.05390769620134961, 0.029045967967249453, 0.03993478836491704, 0.07202443754067644, 0.04871813209319953, 0.046162223734427243, 0.03237759134208318, 0.05341814590792637, 0.0595145328406943, 0.051366181796765886, 0.019122095400234684, 0.050023391740978695, 0.03648539357527625, 0.08202016484574415, 0.0511251173884375, 0.030584868691221345, 0.027655899393721484, 0.013885611788282404, 0.12683945009484887, 0.08094779113889672, 1.281334231607616, 37.68325053155422, 102.36928090453148, 66.36666879057884, 54.580111652612686, 11.176184490323067, 25.65174713730812, 100.24584844708443, 69.63890120387077, 37.166383266448975, 50.82888834178448, 33.29644672572613, 0.4730517271673307, 1.0957080172374845, 0.2199665005900897, 0.6457818194758147, 0.7343826745636761, 2.3167302226647735, 26.991486847400665, 81.9785338640213, 78.56907561421394, 57.13963910937309, 28.62316869199276, 21.151610612869263, 1.8295565829612315, 0.35751836257986724, 0.5134959553834051, 6.306975670158863, 25.51811210811138, 53.44308726489544, 69.58355337381363, 76.4151231944561, 85.66184341907501, 86.00653812289238, 89.62036460638046, 91.82341039180756, 82.4641478061676, 72.56421223282814, 72.18873918056488, 70.0776332616806, 72.42850631475449, 66.57636433839798, 72.52050697803497, 69.88904938101768, 75.21954774856567, 71.01980790495872, 81.94370493292809, 72.05546513199806, 80.43648540973663, 61.402683556079865, 86.31888896226883, 4.77533295750618, 3.8322323514148593, 87.63510793447495, 70.66747561097145, 71.81450486183167, 65.40174096822739, 63.84993463754654, 57.584340646862984, 60.46255320310593, 63.0302008241415, 64.70487356185913, 63.38079281151295, 65.61305522918701, 61.06426231563091, 62.841575145721436, 73.40804055333138, 80.21927386522293, 77.49077707529068, 78.85366514325142, 77.10806921124458, 83.28019201755524, 75.08092358708382, 79.00142401456833, 87.2469511628151, 87.9734417796135, 72.48773753643036, 48.43177177011967, 24.661666564643383, 8.159516863524914, 2.9720568330958486, 1.4619713136926293, 0.45976956957019866, 0.20577822520863265, 0.947226828429848, 0.8092774276155978, 0.7071338617242873, 2.1491839131340384, 3.2797802332788706, 3.018391546793282, 0.21684131672373042, 0.6188253534492105, 0.07535857308539562, 0.329724041512236, 26.614813059568405, 62.380796670913696, 20.650531500577927, 34.505443051457405, 117.52476766705513, 23.6655006185174, 8.109763283282518, 48.2424621284008, 52.36134611070156, 84.77440103888512, 13.335627615451813, 0.1831917473464273, 0.14254517998779193, 0.13708217156818137, 0.058369729231344536, 0.04130380963033531, 0.023369573536911048, 0.08421330770943314, 0.041205345187336206, 0.10054841593955643, 0.026819421036634594, 0.10797690600156784, 0.005036246138843126, 0.03947356955904979, 0.05016175775381271, 0.03756522957701236, 0.03151757577143144, 0.011075143065681914, 0.056446828311891295, 0.051898702440666966, 0.06741783785400912, 0.0877475633751601, 0.002526609528104018, 0.028319312623352744, 0.018247416846861597, 0.012865597527706996, 0.05062200805696193, 0.022935992310522124, 0.027372805307095405, 0.04577995459840167, 0.05005517421523109, 0.12151840710430406, 0.07734524304396473, 0.019110449247818906, 0.08407049623201601, 0.1657423414872028, 0.09962086493032984, 0.2261595003074035, 0.17642206919845194, 0.14548601437127218, 0.10432981420308352, 0.14500768535071984, 0.18634303996805102, 0.19510559242917225, 0.16458332946058363, 0.1610109570901841, 0.10598931577987969, 0.16139072889927775, 0.16987665323540568, 0.09580783633282408, 0.14787117310333997, 0.08104896813165396, 0.23401393118547276, 0.07615972150233574, 0.16106798371765763, 0.22178117040311918, 0.1701331394724548, 0.24746228533331305, 0.11312203030684032, 0.1503072728519328, 0.11180184606928378, 0.073963647155324, 0.15999215160263702, 0.1494676514994353, 0.13602201361209154, 0.19134097412461415, 0.2174767287215218, 0.23189165600342676, 0.25623542082030326, 0.14735683507751673, 0.3069898020476103, 0.1657326045096852, 1.4163515553809702, 46.97722502052784, 118.29913571476936, 87.48298689723015, 99.52896371483803, 50.86581476032734, 25.767156444489956, 80.25487035512924, 97.66346901655197, 61.79115951061249, 45.277276039123535, 29.410915821790695, 1.1881702370010316, 0.9680873528122902, 0.4477005562512204, 0.9091884945519269, 4.884477825835347, 4.671526802703738, 38.43746446073055, 95.84362506866455, 91.16790756583214, 57.55494922399521, 30.450277850031853, 26.719379648566246, 4.150114031508565, 0.36212671373505145, 0.30927944637369365, 3.5203631361946464, 17.18073818832636, 41.484574154019356, 58.49582813680172, 75.69131523370743, 88.50638598203659, 91.34601160883904, 100.32398745417595, 101.07689425349236, 96.43631726503372, 88.27210575342178, 84.79569509625435, 79.29273918271065, 77.98679485917091, 74.01671469211578, 79.477409273386, 77.70271450281143, 80.85402980446815, 80.92277571558952, 88.4581209719181, 78.52980852127075, 82.56697028875351, 65.22524803876877, 87.8978942334652, 3.7708991300314665, 3.4260094491764903, 90.43417453765869, 75.00951781868935, 77.94714018702507, 70.88067457079887, 71.03572145104408, 64.03696820139885, 69.40897554159164, 68.89195248484612, 71.20814099907875, 70.1345694065094, 71.26671865582466, 66.34841457009315, 70.7896238565445, 79.2993812263012, 87.2395795583725, 83.25688406825066, 86.47379904985428, 84.10081878304482, 90.76892137527466, 79.3965420126915, 87.61327430605888, 100.12899711728096, 96.20709076523781, 70.22817358374596, 41.420817375183105, 18.136244416236877, 4.173392532393336, 1.5002125804312527, 1.4099221816286445, 0.5688156432006508, 1.1229834286496043, 0.8581663761287928, 0.9565340727567673, 0.8890358009375632, 2.2801331989467144, 3.8268905505537987, 5.702858436852694, 3.2098509231582284, 0.6804211169946939, 0.5267380073200911, 0.3276162233669311, 23.573161773383617, 61.78305834531784, 37.384381368756294, 76.4933305978775, 108.64729642868042, 19.4634011015296, 39.9210986495018, 86.85139238834381, 66.41124039888382, 97.91386038064957, 16.634836681187153, 0.34194326552096754, 0.3004401706857607, 0.2665218844776973, 0.22263879625825211, 0.1375460287090391, 0.11724906900781207, 0.17752306011971086, 0.18079679226502776, 0.13233647856395692, 0.26337152696214616, 0.1378185601788573, 0.09147678123554215, 0.21739179734140635, 0.2410244956263341, 0.1770145702175796, 0.13659279939020053, 0.14299226459115744, 0.12030907004373148, 0.1945231104036793, 0.18654950545169413, 0.24158673186320812, 0.07596723065944389, 0.17944676626939327, 0.1308594859438017, 0.0889327509503346, 0.1841735196649097, 0.09840339393122122, 0.09163684022496454, 0.1086107520677615, 0.19877800630638376, 0.15396938571939245, 0.13322962360689417, 0.10058237661723979], [0.12070178490830585, 0.059481555508682504, 0.04371163355244789, 0.014205572988430504, 0.017936594267666806, 0.018676502513699234, 0.01829173790611094, 0.07890249151387252, 0.03932220111892093, 0.035606865130830556, 0.04967326131009031, 0.04553782149741892, 0.039063967124093324, 0.046478200529236346, 0.034499992689234205, 0.024059275492618326, 0.08659095590701327, 0.082623115304159, 0.10074313322547823, 0.020217909841449, 0.05386302262195386, 0.004133188785999664, 0.018521786987548694, 0.0346545857610181, 0.04478433009353466, 0.05769718758529052, 0.028685768447758164, 0.01972799960640259, 0.05052145817899145, 0.06092291761888191, 0.020055294153280556, 0.04242785907990765, 0.0329284727195045, 0.011477760035631945, 0.046088561866781674, 0.07633020024513826, 0.1191828386799898, 0.023153011134127155, 0.05846702479175292, 0.08611645636847243, 11.895127762109041, 78.10592606663704, 75.66808328032494, 75.05513817071915, 47.96898700296879, 29.22711968421936, 46.54308311641216, 96.68964967131615, 63.218017145991325, 34.213329926133156, 33.88450317084789, 12.176472265273333, 0.06326138784061186, 0.6644023640546948, 0.6017006223555654, 1.5032279561273754, 1.6877899901010096, 35.91644413769245, 62.12429143488407, 31.323858574032784, 22.31248252093792, 27.50359106808901, 18.909164741635323, 2.0851060515269637, 0.39050510502420366, 1.8552739592269063, 6.3553807977586985, 2.0783267403021455, 1.1098315031267703, 7.868658620864153, 22.806212827563286, 40.70322588086128, 50.8014652132988, 61.88582003116608, 76.07749611139297, 83.28992709517479, 83.86678174138069, 75.10497629642487, 59.45172004401684, 48.55898894369602, 39.573447704315186, 46.13181598484516, 53.50040338933468, 59.488213285803795, 61.353985369205475, 69.84919711947441, 69.61813151836395, 86.16102263331413, 33.546393513679504, 0.5823455296922475, 1.6037538181990385, 56.26402549445629, 69.12176415324211, 56.419410556554794, 54.336540922522545, 50.83651453256607, 52.26675018668175, 49.81482535600662, 49.95566099882126, 48.31211619079113, 50.3191152960062, 51.3474465161562, 53.63063000142574, 55.78875079751015, 57.577926591038704, 62.68937051296234, 66.04683235287666, 70.67104741930962, 76.47354885935783, 82.31953516602516, 99.42935585975647, 92.16761872172356, 56.04234538972378, 19.9584898352623, 3.0741122318431735, 0.343839512206614, 0.5978202586993575, 0.9414879488758743, 0.9001249121502042, 0.637476296396926, 0.09812568969209678, 0.17843374953372404, 0.7128704851493239, 0.41393114486709237, 0.3927946899784729, 0.7170882588252425, 0.756144403712824, 0.12216187140438706, 0.32165075128432363, 0.7913130009546876, 2.4251457676291466, 24.384999610483646, 27.551248110830784, 29.819162115454674, 84.03470993041992, 68.53776589035988, 6.961888577789068, 49.1508299857378, 63.423228934407234, 59.75274369120598, 68.7380987405777, 7.064772332087159, 0.1244300750840921, 0.16645849915221334, 0.12525098689366132, 0.03588342275179457, 0.02275881197419949, 0.02959962497698143, 0.04128216489334591, 0.03668397002911661, 0.0552635443455074, 0.021273180755088106, 0.036104797982261516, 0.06716826843330637, 0.09319353208411485, 0.03156457227305509, 0.042678129830164835, 0.01702371366263833, 0.048114710371010005, 0.11775312828831375, 0.05316026814398356, 0.07615069698658772, 0.11136331100715324, 0.06935070952749811, 0.11338101758155972, 0.061590694676851854, 0.05395647014665883, 0.03250350411690306, 0.11477175037725829, 0.009510552899882896, 0.026466314593562856, 0.08848580735502765, 0.0822251163481269, 0.0865909484855365, 0.10606446565361694, 0.06054412544472143, 0.12848493992350996, 0.03763734035601374, 0.010106592108058976, 0.03168085568177048, 0.007739693455732777, 0.009254573178623104, 0.046805992315057665, 0.07632670472958125, 0.030353647016454488, 0.03633781379903667, 0.06721199577441439, 0.03270209170295857, 0.09058170660864562, 0.009384802469867282, 0.06626035465160385, 0.06318853120319545, 0.07643217875738628, 0.08704849737114273, 0.09975234381272458, 0.07989936653757468, 0.03718744672369212, 0.03286563136498444, 0.07697728622588329, 0.01793541796359932, 0.04048265291203279, 0.04571195531752892, 0.02576550639787456, 0.06266903525101952, 0.02229968045867281, 0.047144905183813535, 0.06349359842715785, 0.0379827395954635, 0.010243574943160638, 0.02212565053923754, 0.04243564420903567, 0.03422103422053624, 0.07315074311918579, 0.009512194901617477, 0.2250708290375769, 0.09509711861028336, 17.491800896823406, 93.40202048420906, 75.86371198296547, 65.2805882692337, 18.29114120453596, 28.826068304479122, 88.74562114477158, 109.181859344244, 36.87072113156319, 40.64300671219826, 54.72599722445011, 17.556403130292892, 0.12636564817512408, 0.7899844378698617, 0.3320697625167668, 1.1753485375083983, 0.7204820704646409, 44.969579949975014, 69.12734225392342, 39.75378602743149, 31.6999813914299, 40.83569437265396, 27.624694369733334, 6.777694886550307, 0.9800936398096383, 1.7814623261801898, 4.368000514805317, 5.051959063857794, 8.505950924009085, 17.13838756084442, 34.15246479213238, 53.40431034564972, 62.428575307130814, 70.29869019985199, 82.03944459557533, 85.84557116031647, 84.66626644134521, 77.00965449213982, 62.130040526390076, 58.3076698333025, 57.00896792113781, 62.44435966014862, 68.28291356563568, 72.1411581337452, 70.84986582398415, 74.87378150224686, 71.71238914132118, 87.79330864548683, 45.537113696336746, 0.553049398586154, 1.8907106202095747, 70.01805245876312, 77.41646826267242, 67.05951601266861, 62.992377653717995, 61.56944140791893, 60.94790875911713, 59.02183011174202, 59.65365640819073, 61.4209795743227, 61.83253929018974, 62.3378399759531, 64.18642178177834, 66.34687945246696, 67.64830961823463, 74.3929249048233, 77.2786496579647, 75.92596024274826, 80.46494588255882, 81.12713634967804, 94.35789719223976, 93.16910818219185, 71.01524814963341, 34.99477319419384, 9.683507736772299, 2.417744002304971, 0.7708979432936758, 0.41245248983614147, 0.837737841065973, 0.4721099714515731, 0.12606647360371426, 0.35164079046808183, 2.140683294273913, 1.6470268461853266, 0.5143852857872844, 0.8613652107305825, 0.8227522170636803, 0.8043347834609449, 0.21072526287753135, 0.8250229514669627, 3.463273337110877, 42.059384509921074, 42.25353889167309, 26.023458391427994, 74.24802348017693, 108.43305632472038, 21.879913732409477, 20.96023578196764, 50.21199144423008, 60.56378357112408, 82.44087785482407, 10.969676971435547, 0.23751965869450942, 0.15100211603567004, 0.20280199038097635, 0.08311321478686295, 0.07525164444814436, 0.07732066311291419, 0.07941232470329851, 0.07071258762152866, 0.007129346104193246, 0.03811192524153739, 0.055170197010738775, 0.08954074059147388, 0.03128620381176006, 0.045125562173780054, 0.028652616711042356, 0.028160865949757863, 0.044119128288002685, 0.10165958912693895, 0.03905752528226003, 0.09680921619292349, 0.06730893510393798, 0.041836359960143454, 0.04831809223105665, 0.05553126669838093, 0.04271255063940771, 0.0336356095795054, 0.02618219077703543, 0.032673121968400665, 0.04926767018332612, 0.079424035793636, 0.022901632728462573, 0.0999336430686526, 0.05772929660452064, 0.1284878046135418, 0.1962460359209217, 0.09852914343355224, 0.15310770773794502, 0.13401512755081058, 0.0798564481374342, 0.09218581428285688, 0.1863561462960206, 0.32343920844141394, 0.09787104398128577, 0.13694387977011502, 0.21967252105241641, 0.12107320755603723, 0.14780932251596823, 0.06079632948967628, 0.1253508502850309, 0.12283122181543149, 0.17830779223004356, 0.18629316764418036, 0.13729650381719694, 0.09816956546274014, 0.12930523575050756, 0.11015159165253863, 0.26230200310237706, 0.08376608209800906, 0.05230507282249164, 0.20765367691637948, 0.12456068565370515, 0.17793609498767182, 0.19256216328358278, 0.19118221389362589, 0.1874056173255667, 0.13305164175108075, 0.0958840103703551, 0.1138884165266063, 0.13461493130307645, 0.11646498256595805, 0.16293960594339296, 0.10911922712693922, 0.2874597703339532, 0.19666297448566183, 22.14199896901846, 112.38121166825294, 94.47173148393631, 96.5257340669632, 62.200682535767555, 42.610324546694756, 67.39324450492859, 113.62666323781013, 76.5343151986599, 48.30107778310776, 53.552555590867996, 18.245053477585316, 0.1332832215121016, 1.0201717517338693, 1.18143082363531, 5.9755185060203075, 4.50031416490674, 43.531702905893326, 77.77071565389633, 51.713716462254524, 34.55515578389168, 36.51688791811466, 27.215203642845154, 3.59442591201514, 0.496413140790537, 2.2079831454902887, 6.311952453106642, 3.4148867335170507, 4.355820268392563, 9.045388977974653, 24.41627573221922, 43.23915660381317, 55.03963619470596, 67.39932417869568, 83.99057909846306, 92.59468540549278, 96.16006448864937, 91.41736418008804, 76.09553754329681, 70.00653147697449, 66.24691441655159, 70.30005812644958, 78.19851189851761, 80.63086777925491, 76.63469061255455, 83.38524118065834, 79.37023222446442, 96.94337725639343, 39.564092606306076, 0.4570744454395026, 2.3171147145330906, 73.2305520772934, 87.55611777305603, 77.93434247374535, 74.40387591719627, 68.47361773252487, 70.79647868871689, 69.31590333580971, 69.02195110917091, 69.11889150738716, 68.60112369060516, 70.74264317750931, 74.20538976788521, 75.24429202079773, 76.87674522399902, 80.81020295619965, 81.9627495110035, 84.73272487521172, 87.3777325451374, 88.08640211820602, 105.5616720020771, 95.94203978776932, 58.94451566040516, 23.536318950355053, 5.143188843503594, 1.0783328558318317, 0.6213572050910443, 1.3199586840346456, 1.1152413440868258, 0.7461980811785907, 0.3977726603625342, 0.6983411335386336, 1.8489013449288905, 3.0061258049681783, 1.4016001531854272, 2.7489879028871655, 2.5578909320756793, 1.2122734123840928, 0.5894837435334921, 0.6063299614470452, 4.428363600745797, 40.08148044347763, 43.052005246281624, 43.46750535070896, 99.15429621934891, 84.67096298933029, 20.050448700785637, 63.52871507406235, 80.71167424321175, 73.44780921936035, 94.63709861040115, 14.274221900850534, 0.3169628418982029, 0.30745313968509436, 0.3785830072592944, 0.20489830523729324, 0.21353766118409112, 0.13438876922009513, 0.15602699015289545, 0.17465088923927397, 0.08243263568147086, 0.08235344110289589, 0.19218723027734086, 0.1795109175145626, 0.09595236959285103, 0.17470727761974558, 0.08188527208403684, 0.13568194670369849, 0.43312136200256646, 0.25424162624403834, 0.10329106720746495, 0.22055822977563366, 0.19770673097809777, 0.13458855537464842, 0.1826835988322273, 0.19476466462947428, 0.15970687003573403, 0.1772724516922608, 0.24257193290395662, 0.06957844496355392, 0.10036683466751128, 0.14100506028626114, 0.20186986774206161, 0.19104781094938517, 0.19585660134907812, 0.12470895191654563], [0.0926882482599467, 0.042105696484213695, 0.022608280305576045, 0.03799548227107152, 0.05637656919134315, 0.03553307709807996, 0.05663900374202058, 0.05431545439932961, 0.02499687147064833, 0.029405666537059005, 0.06975437849177979, 0.06660862971330062, 0.05749263313191477, 0.05576344388828147, 0.022468378047051374, 0.05136493498866912, 0.011811655986093683, 0.04698401869973168, 0.04816731750906911, 0.021566833747783676, 0.020166816684650257, 0.046846880941302516, 0.01629338468774222, 0.03180584448273294, 0.03999614542408381, 0.0656372623052448, 0.02229754492873326, 0.08349775860551745, 0.03559485718142241, 0.12971080461284146, 0.0213737491867505, 0.07138335553463548, 0.03643623371317517, 0.016955443497863598, 0.07653339285752736, 0.06444500206271186, 0.01092400932975579, 0.021405186562333256, 0.00947175249166321, 0.030603919622080866, 0.2335408714134246, 4.029329437762499, 49.380683451890945, 74.78025332093239, 65.5759996175766, 84.5245948433876, 25.701288878917694, 25.909595601260662, 91.85375556349754, 95.6890569627285, 41.634415313601494, 33.53522211313248, 30.50259154289961, 8.15544443204999, 0.2832260850118473, 0.3030070220120251, 0.5215091316495091, 1.5055070025846362, 11.958293672651052, 34.29973728954792, 26.875251084566116, 23.678136840462685, 14.685586877167225, 6.544776884838939, 1.0358424670994282, 4.857875453308225, 10.128822941333055, 28.959481045603752, 21.46740786731243, 12.040559258311987, 3.3580861939117312, 1.1553863086737692, 3.6761735379695892, 6.344464933499694, 16.383901946246624, 18.147142231464386, 23.354700095951557, 30.916900411248207, 37.9545521736145, 39.30427394807339, 37.3458818346262, 35.898250713944435, 46.20729513466358, 61.2903767824173, 66.24617725610733, 69.43727642297745, 53.19194354116917, 27.485726326704025, 0.41212532145436853, 0.22916472342330962, 0.5322040140163153, 34.31945063173771, 65.63495725393295, 44.58665169775486, 49.197955057024956, 42.45015174150467, 44.107379615306854, 42.08303064107895, 43.073914870619774, 43.51828582584858, 41.85579523444176, 40.210171937942505, 43.2337760925293, 40.0345491617918, 46.715567260980606, 49.35494743287563, 60.83210997283459, 70.03522753715515, 74.36421364545822, 72.66017228364944, 33.994609862565994, 5.686687929555774, 0.31779505661688745, 0.135585957323201, 0.8066676207818091, 1.7622230085544288, 1.0310527053661644, 0.8577254810370505, 0.3960112470667809, 0.16921422706218436, 0.19862148736137897, 0.27460301178507507, 0.2228916756575927, 0.31662011810112745, 0.796015189262107, 0.8455215452704579, 0.3610857477178797, 0.35542399215046316, 0.7079287909436971, 16.336096711456776, 42.78139516711235, 30.55138472467661, 51.91848747432232, 87.0169723033905, 48.41306157410145, 11.8623355217278, 40.092708840966225, 57.26554535329342, 62.60348752140999, 55.113762617111206, 5.343479420989752, 0.11284105319646187, 0.057590032592997886, 0.08050821707001887, 0.02964378276374191, 0.03954759507905692, 0.034292529016966, 0.07267078137374483, 0.08889969569281675, 0.017732971209625248, 0.01858783813077025, 0.038241478250711225, 0.1120638390420936, 0.06417622586013749, 0.09433885148609988, 0.021216341519902926, 0.02446332851832267, 0.021090775699121878, 0.01207679473736789, 0.07956168192322366, 0.059513712767511606, 0.08922454857383855, 0.040792673971736804, 0.0741382448177319, 0.15091896580997854, 0.03752730583073571, 0.07065712692565285, 0.05161355817108415, 0.050929505814565346, 0.020219201178406365, 0.07769121744786389, 0.036279488413129, 0.1354231301229447, 0.06765965925296769, 0.026696413769968785, 0.03311184627818875, 0.037619480572175235, 0.02800931568344822, 0.11898545708390884, 0.02691278135898756, 0.043336529852240346, 0.02427783612802159, 0.0254547209260636, 0.01763390191626968, 0.03169278570567258, 0.035582982818596065, 0.06654245240497403, 0.01492416397013585, 0.10997703851899132, 0.07280476129380986, 0.015409611114591826, 0.041305100967292674, 0.03217232813767623, 0.02516062078939285, 0.041894347668858245, 0.01671626785537228, 0.024680926217115484, 0.06430029810871929, 0.044335779748507775, 0.011663273762678728, 0.10238084534648806, 0.03366146229382139, 0.026562584134808276, 0.034820830551325344, 0.06271494450629689, 0.0682964145380538, 0.03303378718555905, 0.09944565128535032, 0.03790446528000757, 0.08473720459733158, 0.03482137602986768, 0.045214215424493887, 0.0396845510113053, 0.04143453152209986, 0.14057902299100533, 0.052182117506163195, 0.44804405188187957, 6.733115678653121, 68.9092567563057, 82.97980293631554, 60.339462608098984, 59.38049666583538, 17.153622843325138, 50.010796040296555, 123.292326182127, 72.24129036068916, 39.7200932353735, 45.8634477853775, 41.689975932240486, 10.789450742304325, 0.3224100871011615, 0.6591949809808284, 0.4776119574671611, 1.5571267576888204, 15.53097976371646, 40.12365438044071, 37.37353675067425, 37.28784754872322, 20.318900495767593, 4.812632706016302, 3.4607894578948617, 11.034141462296247, 18.022081442177296, 17.46818706393242, 6.871118098497391, 7.222488094121218, 7.576168840751052, 4.879796002060175, 11.316225975751877, 18.04929368197918, 32.42366015911102, 33.85378561913967, 42.50970594584942, 55.3422025591135, 62.2264489531517, 62.405886724591255, 54.80705827474594, 53.735660165548325, 62.08567790687084, 70.35974532365799, 77.3844587802887, 84.32006701827049, 67.36394047737122, 40.89101940393448, 1.2034196499735117, 0.33486593747511506, 0.9683008538559079, 45.2530637383461, 77.71430388092995, 61.033685356378555, 67.61767566204071, 60.50498552620411, 63.488813415169716, 59.93622824549675, 60.6795709580183, 59.62623707950115, 62.77026817202568, 60.245360657572746, 62.749289497733116, 58.89805555343628, 62.48543165624142, 59.61929105222225, 69.49943348765373, 76.55996382236481, 83.72545212507248, 82.08976909518242, 52.311732172966, 15.671132393181324, 2.5774197466671467, 0.6526742340065539, 0.9023228567093611, 2.230006051249802, 1.1384921777062118, 0.9361587942112237, 0.6168226234149188, 0.19788636040175334, 0.3538695489987731, 0.8536661113612354, 0.5829639465082437, 0.3128178580664098, 0.040857927306205966, 1.1110291513614357, 0.535488462774083, 0.46946222602855414, 1.3830837467685342, 27.452717497944832, 65.80996826291084, 32.956000193953514, 37.4992948025465, 97.63737961649895, 85.99577710032463, 16.579380556941032, 18.75507351011038, 55.29999062418938, 68.80847856402397, 71.87436684966087, 9.131425861269236, 0.09144039373495616, 0.08620538050308824, 0.0948971914476715, 0.021746407510363497, 0.0986707526317332, 0.07164477705373429, 0.04829273675568402, 0.04577349791361485, 0.03935957938665524, 0.03936771332519129, 0.023177956572908442, 0.012459229001251515, 0.09679171635070816, 0.037267439111019485, 0.059238064277451485, 0.025884563583531417, 0.051049347821390256, 0.041537886718288064, 0.05218186146521475, 0.023142565405578353, 0.11377208487829193, 0.044286801712587476, 0.060065785291953944, 0.10936156060779467, 0.018739881925284863, 0.048532702785450965, 0.10072705830680206, 0.03024713027116377, 0.020103364913666155, 0.03820705373072997, 0.010132095085282344, 0.07302095633349381, 0.05271729503874667, 0.03414149825403001, 0.07882628779043444, 0.18493998009944335, 0.18009472056291997, 0.24058964161667973, 0.17302183056017384, 0.12333982303971425, 0.13784103241050616, 0.129471966647543, 0.12036905041895807, 0.17447753838496283, 0.1573305280180648, 0.13518118998035789, 0.18006798840360716, 0.13519812579033896, 0.2378946213866584, 0.09256805744371377, 0.09480356209678575, 0.08087261157925241, 0.16872531501576304, 0.14856500696623698, 0.1322198277921416, 0.10951153381029144, 0.17669348744675517, 0.1483127658138983, 0.1563562810770236, 0.2347748848842457, 0.2415675250813365, 0.17167808313388377, 0.15080593671882525, 0.1562425246811472, 0.16251549823209643, 0.09954944063792937, 0.1973732394981198, 0.14597795438021421, 0.21482858253875747, 0.16708582174032927, 0.27304340328555554, 0.0805617704463657, 0.13900322082918137, 0.25245037861168385, 0.17584686022019014, 0.5798890208825469, 9.846318550407887, 82.76254579424858, 103.10018688440323, 81.83262929320335, 101.79361179471016, 35.61822094023228, 41.30099080502987, 111.47988483309746, 113.19663271307945, 58.15139181911945, 47.487119659781456, 47.44619965553284, 12.790069989860058, 0.4675587359815836, 0.4377765575191006, 0.7380702579393983, 2.9444280406460166, 15.179787408560514, 56.15443177521229, 68.3301754295826, 54.29545372724533, 24.013609439134598, 11.340291984379292, 4.080643309280276, 9.167498275637627, 17.68688052892685, 48.55990469455719, 26.003391668200493, 20.386278480291367, 6.130075212568045, 1.2286760634742677, 4.230544790625572, 7.731010057032108, 19.30646952241659, 20.235943347215652, 29.566519372165203, 45.25708392262459, 60.04512660205364, 68.54742497205734, 68.84017646312714, 67.82118514180183, 70.90513005852699, 83.13098922371864, 82.02576532959938, 83.40164110064507, 61.11695408821106, 29.419111981987953, 0.494304372696206, 0.6241128884721547, 0.8177267492283136, 48.46082501113415, 85.54436892271042, 68.42348322272301, 78.95347818732262, 71.27389267086983, 72.60637477040291, 71.3459900021553, 70.14872744679451, 70.54098799824715, 71.57790675759315, 70.29413044452667, 72.41770729422569, 68.61852675676346, 73.14949482679367, 72.09473222494125, 80.73369786143303, 85.25051549077034, 88.17696645855904, 78.17195132374763, 36.41652010381222, 6.755275139585137, 0.8220791188068688, 0.4263522627297789, 1.9410439068451524, 2.936956691555679, 2.820004904642701, 1.156602124683559, 1.065302286297083, 0.3521221474511549, 1.3761891354806721, 1.2812766409479082, 3.771316157653928, 1.6033566207624972, 2.6181796845048666, 2.6023803697898984, 0.8375577663537115, 0.36403824866283685, 1.6333898529410362, 25.801968276500702, 59.89506505429745, 45.840056240558624, 66.66983172297478, 103.5543005168438, 61.99810400605202, 20.500585846602917, 54.31922145187855, 75.88806107640266, 80.63430279493332, 82.78981313109398, 11.757552344352007, 0.24089378857752308, 0.16170679475180805, 0.23589730903040618, 0.1416750712087378, 0.205794834473636, 0.14334407227579504, 0.17127444385550916, 0.16433920740382746, 0.1186335009697359, 0.1665911209420301, 0.08605968207120895, 0.12478882184950635, 0.16612892621196806, 0.20257294876500964, 0.14173904433846474, 0.07118122419342399, 0.09399432427017018, 0.17113361391238868, 0.130845429666806, 0.11861833889270201, 0.16535609815036878, 0.09606920590158552, 0.10828898652107455, 0.355609588441439, 0.1765201662783511, 0.2007613514433615, 0.14703817170811817, 0.1014878338901326, 0.18544931604992598, 0.17975039372686297, 0.11305645413813181, 0.17862025124486536, 0.24301996745634824, 0.11864743850310333, 0.17659380217082798], [0.04288964191800915, 0.03667897166451439, 0.05707357202481944, 0.05155053499038331, 0.04794164895429276, 0.033162494146381505, 0.058436941835680045, 0.07930547770229168, 0.0241894166538259, 0.08435522118816152, 0.037388509372249246, 0.06177940798806958, 0.04486706471652724, 0.016046436903707217, 0.15371208311989903, 0.026350559965067077, 0.016224964238062967, 0.06026432092767209, 0.055784131254768, 0.051766340402537026, 0.05932325540925376, 0.034028914451482706, 0.025711207163112704, 0.010076218786707614, 0.056535856347181834, 0.0714956276351586, 0.06831069345935248, 0.12253513457835652, 0.03831906979030464, 0.10884165647439659, 0.024411018239334226, 0.09774979189387523, 0.05681432128767483, 0.06785683304769918, 0.03631302606663667, 0.058449873758945614, 0.049237268103752285, 0.02847374984412454, 0.04812371262232773, 0.07703053532168269, 0.10631709272274747, 0.05922412674408406, 0.8104281721170992, 35.514125525951385, 84.77188557386398, 73.5795709490776, 67.39515960216522, 50.771226435899734, 22.141877375543118, 62.800560146570206, 93.4985277056694, 76.72605291008949, 60.064345970749855, 39.513395726680756, 28.127468191087246, 5.46969392336905, 0.0629834906430915, 0.18714208068558946, 1.0986089240759611, 6.852984521538019, 11.396129038184881, 2.567125861532986, 2.3333182325586677, 13.586097825318575, 10.369084049016237, 4.134720107540488, 6.244040122255683, 64.59942162036896, 80.39708152413368, 35.62523916363716, 1.1772441607899964, 0.585586637025699, 0.17182473151478916, 0.1338453241623938, 0.05097052431665361, 0.1937566648120992, 0.42337803170084953, 0.5759647220838815, 0.9600248385686427, 3.524781111627817, 5.894443681463599, 8.751882277429104, 14.042370691895485, 19.94199302047491, 14.580043740570545, 5.436364961788058, 0.7155390700791031, 0.26633694127667695, 0.03861570992739871, 1.0644548130221665, 0.7398569933138788, 5.601781960576773, 44.04971770942211, 40.126067250967026, 34.727807119488716, 31.546465829014778, 28.50339911878109, 25.1457928866148, 21.905927136540413, 19.199661053717136, 17.560102231800556, 19.783469326794147, 21.588879749178886, 28.28016109764576, 33.73875059187412, 38.26828233897686, 41.91985219717026, 42.56544515490532, 20.711337737739086, 3.7789670471102, 0.49439111491665244, 0.10514611727558076, 1.1144965840503573, 1.3789989659562707, 0.7346790586598217, 0.2568246267037466, 0.1050393890182022, 0.1025170813954901, 0.057287243762402795, 0.0652999932935927, 0.17941472033271566, 0.07690201760851778, 0.18305133300600573, 0.42444868362508714, 0.20236283191479743, 0.5197306489571929, 0.21591814438579604, 7.074847491458058, 18.18393185734749, 26.011616326868534, 32.50683009624481, 74.61934715509415, 75.20092114806175, 27.950519286096096, 19.801714047789574, 52.249700501561165, 58.80474016070366, 65.4195848107338, 35.64190126955509, 1.0640722210519016, 0.23966272885445505, 0.08665977526106872, 0.07953500913572498, 0.05173658028070349, 0.010244113000226207, 0.009830135604715906, 0.0680681670201011, 0.06776128895580769, 0.002697197041925392, 0.028836134988523554, 0.03742523826076649, 0.01778693091182504, 0.05633486791339237, 0.025929686162271537, 0.045110748906154186, 0.0733115516777616, 0.01874818655778654, 0.07038344512693584, 0.044418933684937656, 0.04840332047024276, 0.07667855694307946, 0.12456925003789365, 0.015983916528057307, 0.011386169735487783, 0.021651661227224395, 0.049944252823479474, 0.012616375988727668, 0.02338654830964515, 0.05899867712287232, 0.0813428066612687, 0.02361607603234006, 0.05198257997108158, 0.04593169782310724, 0.044814305438194424, 0.04803993157111108, 0.08316712439409457, 0.048977019177982584, 0.02467781105224276, 0.03090312944550533, 0.02605537072668085, 0.06413310708012432, 0.020267832260287832, 0.01269665039217216, 0.016528654778085183, 0.06333389566862024, 0.06612629309529439, 0.013508345655282028, 0.08721769219846465, 0.03918861082638614, 0.06965512366150506, 0.015625698542862665, 0.020401838155521546, 0.016647409538563807, 0.054381765294237994, 0.10088135080877692, 0.06097864177718293, 0.047219717380357906, 0.05582430741924327, 0.0466578113992, 0.05152055964572355, 0.12424183674738742, 0.039985584662645124, 0.014814768619544338, 0.054821424710098654, 0.08988894143840298, 0.11263146327110007, 0.03257005249906797, 0.1502843404887244, 0.02045778681349475, 0.02367002274695551, 0.06443775127991103, 0.08455352304736152, 0.06151495850645006, 0.058521034588920884, 0.05817727178509813, 0.11295381511445157, 0.08227303682360798, 0.18034852022537962, 1.223762333393097, 52.953449338674545, 93.3947704732418, 78.95473971962929, 49.711702689528465, 21.156637743115425, 31.422111801803112, 95.33373802900314, 91.04059159755707, 61.400042697787285, 57.47910149395466, 56.82154297828674, 43.83304953575134, 7.468686858192086, 0.12291423845454119, 0.23964491731021553, 0.4704249993665144, 8.445207383483648, 10.614036954939365, 6.931498283520341, 3.605472631752491, 8.471703361719847, 7.9560278076678514, 7.842288985848427, 21.86213828623295, 72.97820761799812, 57.347590550780296, 34.77262571454048, 2.69914407748729, 0.6097189045976847, 0.8517449581995606, 0.6744632148183882, 0.5181924439966679, 0.7557878759689629, 2.8318662056699395, 2.664817194454372, 5.6590035650879145, 11.497107669711113, 19.940281212329865, 27.70723544061184, 30.156065337359905, 37.51711964607239, 26.673058234155178, 12.852474991232157, 2.533066151663661, 0.24260196019895375, 0.11178529617609456, 3.3398768585175276, 0.7194665749557316, 11.45824620500207, 71.94818928837776, 57.537865340709686, 52.39728458225727, 51.312894970178604, 50.31708620488644, 48.17598469555378, 46.327144503593445, 45.37884458899498, 42.88040645420551, 44.03882369399071, 46.47605091333389, 50.651688650250435, 55.38161404430866, 60.38075499236584, 62.50139079988003, 60.17582058906555, 36.34788438677788, 8.957873973995447, 1.2694577313959599, 0.30793072655797005, 0.417339057312347, 1.152790216729045, 1.0276656621135771, 0.40477428934536874, 0.27969031536486, 0.20086759730475023, 0.07641629679710604, 0.14882667339406908, 0.20047415513545275, 0.09698700509034097, 0.19137972907628864, 0.316242246190086, 0.29272797983139753, 0.369189198827371, 0.10656677346560173, 12.630399707704782, 45.174141973257065, 35.44287174940109, 28.400683030486107, 72.45755955576897, 105.27754604816437, 48.594380244612694, 12.938513774424791, 27.008069157600403, 53.916750848293304, 73.26937079429626, 47.17683590948582, 2.5787643995136023, 0.14146091707516462, 0.0404215890011983, 0.0657354632858187, 0.12810577667551115, 0.08047338065807708, 0.047383832206833176, 0.05186774375033565, 0.07673120489926077, 0.023045735542837065, 0.04939690406899899, 0.03729729571205098, 0.011040734316338785, 0.08140628255205229, 0.13571203337050974, 0.2095899698906578, 0.05376839508244302, 0.0951973011251539, 0.029395738456514664, 0.03101436625001952, 0.025952431133191567, 0.05100583570310846, 0.09368913830257952, 0.06147291212982964, 0.0751396692066919, 0.06409780311514623, 0.09247952664736658, 0.059269965495332144, 0.05214092459937092, 0.05080986789835151, 0.16463900537928566, 0.12403808010276407, 0.03275600873166695, 0.028342311779852025, 0.02989242635521805, 0.0429745065048337, 0.02836420142557472, 0.16991892596706748, 0.11264163069427013, 0.12208621687022969, 0.17527605959912762, 0.09478663370828144, 0.11698321686708368, 0.128073938540183, 0.14589703059755266, 0.17930268571944907, 0.15689702471718192, 0.12320548688876443, 0.1639049471123144, 0.14116664067842066, 0.0910743219719734, 0.17325620079645887, 0.0922023864404764, 0.14189206034643576, 0.16348331817425787, 0.29354612343013287, 0.1626030568149872, 0.12351183060673065, 0.21978267061058432, 0.17326691740890965, 0.1515976747032255, 0.2749796072021127, 0.12997981830267236, 0.14282568212365732, 0.16970119468169287, 0.11803504792624153, 0.14508678345009685, 0.1990725498762913, 0.2591921074781567, 0.20255565672414377, 0.18248738982947543, 0.14850104867946357, 0.14774420647881925, 0.22343097953125834, 0.1392567384755239, 0.17121887183748186, 0.21729751490056515, 0.21850016521057114, 0.3399159852415323, 1.7871657013893127, 59.454573690891266, 109.18432161211967, 97.59962484240532, 78.88184443116188, 66.86770230531693, 35.926581993699074, 83.96625280380249, 105.54200425744057, 91.61418601870537, 73.50846156477928, 62.733459547162056, 43.022644221782684, 8.988445233553648, 0.15599359350744635, 0.3463824070058763, 1.5784646314568818, 10.704553797841072, 15.389740392565727, 17.087563388049603, 11.352026704698801, 33.97555768489838, 27.6479472219944, 8.689082097262144, 18.55538472533226, 96.27664983272552, 105.11565193533897, 51.04818217456341, 1.9263750314712524, 0.6108527875039726, 0.3909368865424767, 0.27362266439013183, 0.1194082289293874, 0.25867708667647094, 1.0512133548036218, 1.0116831259801984, 2.6635649241507053, 7.7183329872787, 17.33287062495947, 28.68878737092018, 29.188783541321754, 34.44938845932484, 21.473713628947735, 9.483896847814322, 1.2007122952491045, 0.2805436070775613, 0.12886842247098684, 5.5583930388092995, 1.236630817875266, 10.772724989801645, 84.34666559100151, 73.4462209045887, 67.87485346198082, 64.23152536153793, 62.62899935245514, 62.445761784911156, 60.1008278131485, 63.464646711945534, 57.31988623738289, 62.95262798666954, 65.59464901685715, 71.38106971979141, 72.24939912557602, 77.09800735116005, 70.71396231651306, 63.31276886165142, 27.985325418412685, 3.8339797826483846, 0.8524591417517513, 0.4256193176843226, 1.454192774835974, 2.076317360624671, 0.9685675520449877, 0.42843125585932285, 0.49978860653936863, 0.30302839586511254, 0.17636208882322535, 0.1240553573006764, 0.439353680703789, 0.1808739162515849, 0.6001159292645752, 1.1359423957765102, 0.604441047180444, 0.47324100451078266, 0.2160742477281019, 11.257431730628014, 30.740487277507782, 41.32171869277954, 46.69104337692261, 88.02171438932419, 87.74084106087685, 38.69969218969345, 30.757449567317963, 67.98171892762184, 72.37849339842796, 86.3673135638237, 52.773171812295914, 3.043134156614542, 0.3094474389217794, 0.18241920130094513, 0.23757861490594223, 0.14520206867018715, 0.17996744223637506, 0.10958971906802617, 0.23379225167445838, 0.18296981550520286, 0.13384376565227285, 0.09214550082106143, 0.15640646510291845, 0.08225792669691145, 0.18286582577275112, 0.24182079039746895, 0.28312393580563366, 0.11900798126589507, 0.18305243138456717, 0.11354754809872247, 0.12870118691353127, 0.1719320163829252, 0.14752935472643003, 0.31617821368854493, 0.15075594565132633, 0.12878111621830612, 0.16358849534299225, 0.24341385491425171, 0.16258695221040398, 0.1516888549667783, 0.1560293056536466, 0.2034556443686597, 0.27070602402091026, 0.20963031303836033, 0.11197167914360762, 0.1713250286411494, 0.11450416903244331, 0.12061861983966082], [0.0246939805947477, 0.07506560286856256, 0.08883962625986896, 0.04139756514632609, 0.08502382945152931, 0.014531290471495595, 0.1376919646281749, 0.03616492678702343, 0.02408178483165102, 0.06060367537429556, 0.04551078876829706, 0.04218390771711711, 0.055809245532145724, 0.09420241505722515, 0.03214054195268545, 0.022449206517194398, 0.017104236685554497, 0.028305258201726247, 0.008318874315591529, 0.1189001472084783, 0.004504247781369486, 0.06723625658196397, 0.0193068716180278, 0.0668334485089872, 0.017356392490910366, 0.04370330294477753, 0.08305129740620032, 0.04239687812514603, 0.06344863169942982, 0.09760919943801127, 0.09991362734581344, 0.04494410706683993, 0.020671601414505858, 0.019799577894445974, 0.17032163013936952, 0.042391174720251, 0.10271587307215668, 0.05613232839095872, 0.006733253076163237, 0.056513606759835966, 0.012360514083411545, 0.15370077278930694, 0.010365079360781237, 0.15668517124140635, 12.385358456522226, 63.63000623881817, 79.23974722623825, 74.83493998646736, 65.98507806658745, 30.79297386109829, 36.2612110376358, 70.38681507110596, 87.5207644701004, 63.406927809119225, 40.34308880567551, 35.04437193274498, 20.896568298339844, 1.8498802674002945, 0.09800762883969583, 0.17868190887384117, 0.2244814598816447, 0.7281673955731094, 2.4787316797301173, 6.425794819369912, 2.0612547313794494, 9.204842671751976, 18.313605599105358, 18.413906916975975, 27.25565817207098, 9.832694381475449, 1.8239369220100343, 1.4524902286939323, 0.26014713279437274, 0.29083784844260663, 0.2060663269367069, 0.9791522996965796, 0.4889158165315166, 0.1739693304989487, 1.1484918161295354, 0.059314961908967234, 0.1597355169360526, 0.15765575197292492, 0.2555760374525562, 0.21181429037824273, 0.10849217913346365, 0.7332664250861853, 0.6865406292490661, 0.01610443760000635, 0.283513919566758, 0.28844534244854003, 0.5459136783611029, 0.28981133946217597, 5.306313615292311, 13.02439771592617, 11.717565190047026, 11.55357738956809, 9.541501756757498, 7.465890683233738, 6.224028021097183, 4.871536195278168, 2.7151435939595103, 4.545482816174626, 6.935068666934967, 8.212915398180485, 9.733734391629696, 11.286868751049042, 8.873412106186152, 3.449388169683516, 0.16881140414625406, 1.4482859917916358, 1.8418706534430385, 0.6778557796496898, 0.06594141668756492, 0.04928580827254336, 0.029691914751310833, 0.025914319994626567, 0.11207074843696319, 0.0226523991295835, 0.059132107853656635, 0.07980485403095372, 0.14640595094533637, 0.2892193727893755, 0.0851992063689977, 0.09038673699251376, 0.08725012405193411, 4.145813137292862, 18.878036811947823, 17.5502797588706, 27.58212525397539, 65.44770330190659, 71.16298422217369, 41.77366644144058, 22.038452625274658, 38.96880514919758, 66.24772757291794, 65.50409987568855, 53.39337833225727, 16.690716482698917, 0.16339276131475344, 0.137676008453127, 0.07312613350222819, 0.0508935079415096, 0.029220973810879514, 0.03954772495490033, 0.045679783215746284, 0.04804488169611432, 0.034361526486463845, 0.09469620301388204, 0.022121878573670983, 0.029472682472260203, 0.05090413549623918, 0.10887101583648473, 0.026443337701493874, 0.03044918554223841, 0.04214918262732681, 0.03761616688279901, 0.03597917835577391, 0.09143855320871808, 0.017130421510955784, 0.118765254446771, 0.013842855732946191, 0.10202832520008087, 0.06530881000799127, 0.051633770563057624, 0.03694469764013775, 0.012178854885860346, 0.05504494845808949, 0.05827206630783621, 0.04015565893496387, 0.04433237700141035, 0.04678028431953862, 0.01654257004702231, 0.05125748684804421, 0.027356396421964746, 0.03550333552993834, 0.06767883634893224, 0.005760555368397036, 0.03067041419853922, 0.0968123109487351, 0.02891828331485158, 0.07297267962712795, 0.07341894044657238, 0.13225598522694781, 0.04364734129921999, 0.04604144662152976, 0.008779072668403387, 0.17223493137862533, 0.020087928241991904, 0.08321505229105242, 0.09361397358588874, 0.06340431806165725, 0.037865372651140206, 0.02726445731241256, 0.049776364176068455, 0.03148764866637066, 0.047328148866654374, 0.05294417329423595, 0.06430391978938133, 0.01577700018970063, 0.048156779012060724, 0.03770033385080751, 0.0698434584774077, 0.055470458828494884, 0.08574581297580153, 0.01522661883427645, 0.13478569948347285, 0.0924059798126109, 0.04151629764237441, 0.1098379452014342, 0.06891178112709895, 0.0298828322411282, 0.12524225923698395, 0.04940820326737594, 0.07905026795924641, 0.061038688945700414, 0.033130385127151385, 0.14718026330228895, 0.11531213036505505, 0.09019882520078681, 0.1695764545002021, 22.21063658595085, 81.89418599009514, 83.14090669155121, 76.29332453012466, 40.63381500542164, 24.84219867736101, 52.59590372443199, 97.5841672718525, 95.8207730948925, 54.969286769628525, 38.82947042584419, 53.329796344041824, 28.25574740767479, 1.893122778274119, 0.16190310765523463, 0.1581768732285127, 0.17899675760418177, 0.35188002919312567, 2.7119852509349585, 1.229727182071656, 0.42612181103322655, 5.206522895023227, 19.786862544715405, 35.95810130238533, 68.36533114314079, 25.15515748411417, 1.3954726257361472, 2.782800388522446, 2.157564125955105, 1.5583210811018944, 0.18353053776081651, 0.9790395526215434, 0.3860919683938846, 0.37761684972792864, 1.8988692574203014, 0.3514743712730706, 0.32588648493401706, 0.4596568224951625, 0.29702347121201456, 0.31709918926935643, 0.10115612356457859, 1.0869055520743132, 1.6020637401379645, 0.11230505930143408, 0.8005275658797473, 0.20806729065952823, 0.6609115982428193, 1.113861899357289, 18.124898225069046, 45.50956517457962, 40.02655439078808, 32.28819742798805, 29.16141550987959, 28.371952772140503, 26.091478541493416, 25.63804317265749, 27.013464868068695, 29.93458092212677, 32.12280750274658, 31.52448020875454, 27.654380276799202, 23.57386663556099, 16.311023756861687, 9.051386006176472, 0.28675131616182625, 0.6434789055492729, 2.3885553935542703, 0.7422790070995688, 0.22358789923600852, 0.12413660020683892, 0.2386589889647439, 0.08906419272534549, 0.05110321661049966, 0.012378986139083281, 0.2441107464255765, 0.23681933846091852, 0.22619319381192327, 0.25349205709062517, 0.28688196383882314, 0.17477456072811037, 0.155081479169894, 4.187067048624158, 33.52358713746071, 33.54638211429119, 15.186346806585789, 55.3328550606966, 91.21531382203102, 71.3214661180973, 23.18247053772211, 19.23001952469349, 48.04851293563843, 65.3129169344902, 67.09203466773033, 24.49817653745413, 0.5538011051248759, 0.0900120117876213, 0.08916489474358968, 0.08106425637379289, 0.048744326195446774, 0.11398131857276894, 0.023714325252512936, 0.017098036041716114, 0.02572622452134965, 0.04690742905950174, 0.048499205950065516, 0.06347983900923282, 0.05499515405972488, 0.04016736631456297, 0.04079947575519327, 0.03367988239915576, 0.02834260307281511, 0.0626957525673788, 0.055653706222074106, 0.009938343519024784, 0.07821207895176485, 0.061964748238096945, 0.028765905553882476, 0.09890641420497559, 0.03563976082659792, 0.0929412835102994, 0.0798590382328257, 0.047767199721420184, 0.07234554257593118, 0.07251410657772794, 0.07960029586683959, 0.0583183911658125, 0.052554126450559124, 0.0711660621163901, 0.054239959426922724, 0.06413833922124468, 0.0909268572286237, 0.04753990586323198, 0.10800299991387874, 0.14681263302918524, 0.2168656443245709, 0.20739212923217565, 0.22076052438933402, 0.09451557911233976, 0.20170402742223814, 0.18277192924870178, 0.10516827780520543, 0.17311305535258725, 0.22813848161604255, 0.16792900540167466, 0.17884847649838775, 0.1647280779434368, 0.10854395135538653, 0.12615018786164, 0.15500788780627772, 0.05893983594432939, 0.17374100134475157, 0.27312794874887913, 0.14215656177839264, 0.10744188431999646, 0.1023295109916944, 0.10818688926519826, 0.09306698106229305, 0.21725758735556155, 0.17412840243196115, 0.33541031763888896, 0.1462213194463402, 0.2459320955676958, 0.18030203209491447, 0.22306569444481283, 0.1973622853984125, 0.12697857309831306, 0.2553646737942472, 0.18042761832475662, 0.15432438463903964, 0.2833744551753625, 0.1934694091323763, 0.2775776881026104, 0.21407070133136585, 0.24859766737790778, 0.15706446807598695, 0.34867884940467775, 24.413442984223366, 93.62035676836967, 103.93021434545517, 94.77958336472511, 80.34747138619423, 44.2206135392189, 49.89855006337166, 92.36096754670143, 111.3072220981121, 72.31436043977737, 53.50328743457794, 55.06739370524883, 32.81884275376797, 2.2151742596179247, 0.2318801824003458, 0.22656539571471512, 1.6193402255885303, 2.1819614293053746, 8.511411231011152, 13.693779297173023, 4.054724900051951, 34.06120128929615, 27.260698601603508, 26.83153063058853, 40.9044136852026, 11.226312350481749, 6.6916898265480995, 6.230998747050762, 1.834449414163828, 1.0139554040506482, 1.4115064591169357, 2.9161186097189784, 1.611732558812946, 1.0501078516244888, 3.967543803155422, 0.8246429718565196, 0.3048463608138263, 0.46542719879653305, 0.4818944464204833, 0.4276518226834014, 0.4816107382066548, 1.7195657850243151, 1.6512190899811685, 0.29813250701408833, 1.327862141188234, 2.2540817968547344, 1.6186700365506113, 1.1571155721321702, 16.217734962701797, 53.46685878932476, 55.833219811320305, 51.87020726501942, 48.426376059651375, 48.27515937387943, 46.61743752658367, 45.547574535012245, 46.629881858825684, 45.51086090505123, 43.883404433727264, 36.736911311745644, 29.688179343938828, 20.33153861761093, 13.24545655399561, 5.517645450308919, 0.2523425890831277, 1.8167288275435567, 2.574676531367004, 1.2571191997267306, 0.2141926361946389, 0.2534042758634314, 0.38075055344961584, 0.17908793786773458, 0.17617821431485936, 0.15404875099193305, 0.36587132373824716, 0.3802319703390822, 0.8846928714774549, 1.348383652511984, 0.945181172573939, 0.2725587214808911, 0.2001428307266906, 5.980522837489843, 32.898307889699936, 38.23454014956951, 40.83916738629341, 82.35485807061195, 83.73161539435387, 55.81946074962616, 31.063331253826618, 51.73249885439873, 78.35729017853737, 81.84821605682373, 78.89126792550087, 28.004533387720585, 0.5457093205768615, 0.27336694998666644, 0.27539405215065926, 0.2626827545464039, 0.19400019315071404, 0.276931218104437, 0.1233094246708788, 0.12043181384797208, 0.07148869597585872, 0.23486599093303084, 0.11935904680285603, 0.16251757624559104, 0.16823531943373382, 0.18102148489560932, 0.11700597111484967, 0.12251506690517999, 0.1431015384150669, 0.1328122545965016, 0.1472450527944602, 0.1370613617473282, 0.13652407651534304, 0.19315359561005607, 0.1838941901223734, 0.34283381304703653, 0.14082747919019312, 0.24207830079831183, 0.13664176629390568, 0.1488837445504032, 0.17878488928545266, 0.25661673629656434, 0.18871883279643953, 0.15631463174941018, 0.19250969344284385, 0.13738701614784077, 0.18092810787493363, 0.17567944654729217, 0.1429956339416094, 0.24672420462593436], [0.021942861421848647, 0.01931532096932642, 0.02989723547216272, 0.019694762522703968, 0.0519551093748305, 0.07869944733101875, 0.05539414007216692, 0.03135087084956467, 0.02307116152223898, 0.011778687003243249, 0.025330066091555636, 0.04473707755096257, 0.041382184135727584, 0.00942234308240586, 0.0478540643962333, 0.047155577267403714, 0.022437421212089248, 0.002996302964675124, 0.027742149941332173, 0.10159753815969452, 0.04563998183584772, 0.07133280785637908, 0.04626278474461287, 0.03759196915780194, 0.019826779462164268, 0.03875506670738105, 0.046634726895717904, 0.006748301975676441, 0.023681077036599163, 0.026026540144812316, 0.011813515993708279, 0.04607017515809275, 0.0749044974509161, 0.030006303350091912, 0.05803801519505214, 0.05490028161148075, 0.06723052720190026, 0.06952979718334973, 0.05469964940857608, 0.09005777261336334, 0.04782713556778617, 0.034352219954598695, 0.14082087407587096, 0.16162906220415607, 0.3448360681068152, 0.34813161939382553, 28.773581720888615, 62.63463445007801, 73.53843435645103, 66.04775950312614, 37.3585769534111, 27.208652794361115, 50.13618931174278, 82.27417320013046, 98.59593138098717, 71.6628398001194, 51.04025959968567, 41.53416909277439, 11.948982272297144, 0.6637967715505511, 0.10514420253457502, 0.2808509155875072, 0.1025516728986986, 1.222733894828707, 1.8087318004108965, 0.9651709499303252, 4.689738750457764, 3.143930872902274, 8.039728291332722, 6.6765044163912535, 3.78606079146266, 2.306874026544392, 3.654929115436971, 4.022648921236396, 0.3679465764435008, 0.21101211779750884, 0.05313145797117613, 0.06195558271429036, 0.07395102322334424, 0.26052580622490495, 0.2530627098167315, 0.11270441638771445, 0.6541133474092931, 0.44190562970470637, 0.24173783313017339, 0.1107400405453518, 0.267166662379168, 0.6465123896487057, 0.03342153337143827, 0.18111420882632956, 0.09685044249636121, 0.17051457369234413, 0.3845511213876307, 0.2222155049093999, 1.1936026392504573, 3.8212231546640396, 2.12668817024678, 0.7136125734541565, 1.119254759978503, 1.0353286634199321, 1.1508012609556317, 1.317609935067594, 0.5754104268271476, 0.16823552723508328, 0.10688662427128293, 0.15547351125860587, 0.09329305408755317, 0.1265758986119181, 0.5215030163526535, 0.2814148290781304, 0.3340210171882063, 0.19579467654693872, 0.07483037916244939, 0.0871163148258347, 0.08141649450408295, 0.043125340598635375, 0.16195464238990098, 0.20608103630365804, 0.07136728803743608, 0.2120534103596583, 0.0656669185264036, 0.06918719955137931, 0.09770820935955271, 1.22119034640491, 9.965700544416904, 19.458164982497692, 30.281500406563282, 57.77534879744053, 79.96312201023102, 54.392956495285034, 29.18491154909134, 34.41314600408077, 65.43833300471306, 68.3691917359829, 59.36371296644211, 31.970944851636887, 4.183517089113593, 0.02946876393252751, 0.1957592464168556, 0.02276410348713398, 0.08394819029490463, 0.06879197622765787, 0.027212488421355374, 0.02395756044279551, 0.03295109709142707, 0.01935600179422181, 0.0175283722273889, 0.031080979570106138, 0.029986799709149636, 0.04210392275126651, 0.08231536892708391, 0.01895824032544624, 0.06048556257155724, 0.07453012105543166, 0.05090834718430415, 0.020274125672585797, 0.03602405973651912, 0.07268252214998938, 0.02670719532034127, 0.019967776388511993, 0.013176046250009676, 0.05244224397756625, 0.013354712737054797, 0.022593671128561255, 0.033961286244448274, 0.053841440967516974, 0.02887340378947556, 0.05763274690252729, 0.05006201681680977, 0.06165403327031527, 0.08510063431458548, 0.030325621664815117, 0.016190389433177188, 0.031109160772757605, 0.03860324926790781, 0.10724363441113383, 0.008846871569403447, 0.04518895271758083, 0.03943945303035434, 0.0244915839357418, 0.06462781529990025, 0.051530445052776486, 0.019966249419667292, 0.048581176160951145, 0.025625498383305967, 0.05141140827618074, 0.012536062622530153, 0.038494932814501226, 0.016237254203588236, 0.03664121119072661, 0.007809416838426841, 0.08790403036982752, 0.012786395527655259, 0.051449851525831036, 0.03632685969932936, 0.038333374686772004, 0.06758236457244493, 0.013858825823263032, 0.07030963854049332, 0.10730243477155454, 0.05361562769394368, 0.042372198004159145, 0.08076454745605588, 0.05849230605235789, 0.019477088753774296, 0.05511494411621243, 0.03862518344249111, 0.05031273656641133, 0.03186220317729749, 0.032449149221065454, 0.034921911064884625, 0.041233138617826626, 0.0868463511869777, 0.08046117232879624, 0.043646647391142324, 0.11412127278163098, 0.06614029742195271, 0.03811999238678254, 0.19388634769711643, 0.12973997101653367, 0.8859748870600015, 1.5374561632052064, 46.72316685318947, 75.80291524529457, 83.97575229406357, 60.127004608511925, 27.513964511454105, 28.525981307029724, 68.73318940401077, 103.92086684703827, 87.0269125699997, 57.55302652716637, 53.74992460012436, 53.00245150923729, 14.097880963236094, 0.6423272704705596, 0.18076878361171111, 0.09530536524835043, 0.25031435885466635, 1.4304009452462196, 0.3022280044388026, 2.4568113684654236, 2.8375096153467894, 4.0790326707065105, 17.13603548705578, 8.056590836495161, 10.275295581668615, 6.855801120400429, 6.6002800315618515, 5.096830856055021, 0.44631873664911836, 0.15555116959149018, 0.13811481068842113, 0.035633107472676784, 0.08508532380801626, 0.7176253956276923, 0.5671163625083864, 0.33518227050080895, 0.8295445307157934, 0.4142833681544289, 1.0877272579818964, 0.17459031514590606, 0.1734633935848251, 0.3574437915813178, 0.10670217830920592, 0.21339628205168992, 0.493576978915371, 0.2089010935742408, 0.8885653980541974, 1.6201863926835358, 3.834326039068401, 3.515050783753395, 3.4782015485689044, 5.325542483478785, 5.9897596668452024, 5.917137488722801, 6.281785871833563, 3.8144383812323213, 2.59756151586771, 1.322228943463415, 0.7347944774664938, 0.5959346098825336, 0.4931869951542467, 0.34023697895463556, 1.4539438881911337, 0.40399604360572994, 0.6177006138022989, 0.2018538225092925, 0.1947762569761835, 0.04561948371701874, 0.048435295902891085, 0.004664626358135138, 0.03561496938345954, 0.11636968338279985, 0.22394536208594218, 0.21070528426207602, 0.2670956833753735, 0.13794000522466376, 0.031222137913573533, 0.7138367020525038, 12.891920674592257, 34.810300692915916, 37.33740068972111, 45.61284363269806, 72.46909573674202, 77.47351080179214, 33.10391865670681, 21.013106144964695, 47.13577151298523, 64.28798273205757, 68.20327743887901, 47.2820408642292, 8.518614694476128, 0.099566962744575, 0.20421573717612773, 0.06628031842410564, 0.047674145534983836, 0.08564030926208943, 0.09041682365932502, 0.043438664215500467, 0.056735512625891715, 0.015563895267405314, 0.012795383863704046, 0.05252742026641499, 0.0361420500848908, 0.02663950032001594, 0.05847045351401903, 0.10633771700668149, 0.044858971596113406, 0.08637855324195698, 0.018224291525257286, 0.006840801406724495, 0.018660748573893216, 0.02411559336906066, 0.012743297156703193, 0.05672749372024555, 0.016726568865124136, 0.01475894056056859, 0.018954596380353905, 0.006543454373968416, 0.017547245042806026, 0.015517770789301721, 0.11391925276257098, 0.0447817325766664, 0.04312303994083777, 0.031455246498808265, 0.01757273781549884, 0.012158212975919014, 0.01591884130903054, 0.069051067403052, 0.03904589953890536, 0.06307599192950875, 0.06873226302559488, 0.11355491762515157, 0.1597987924469635, 0.16683502035448328, 0.1838982422486879, 0.17000942345475778, 0.11684347045957111, 0.1258892784244381, 0.15567595430184156, 0.16092016274342313, 0.13334041141206399, 0.12001522409263998, 0.12573445157613605, 0.12762930302415043, 0.06877151521621272, 0.1948701831861399, 0.10115394907188602, 0.10703434134484269, 0.11774821527069435, 0.13417633686913177, 0.16385336784878746, 0.259513576165773, 0.28356082329992205, 0.19912435178412125, 0.13205450697569177, 0.09948935636202805, 0.1918872690293938, 0.19235700397985056, 0.07979291287483647, 0.12262581760296598, 0.11536039964994416, 0.11901952166226692, 0.17344889201922342, 0.16849133069626987, 0.18983294488862157, 0.21534099098062143, 0.18507974134990945, 0.18119955580914393, 0.1590704487171024, 0.3380556881893426, 0.08733840251807123, 0.2394811253179796, 0.31064823386259377, 0.3579868655651808, 0.7300088123884052, 1.4879673812538385, 49.93364118039608, 93.1567132472992, 101.19486272335052, 83.46472531557083, 52.42468111217022, 37.04568274319172, 69.91769224405289, 103.72708484530449, 109.38094586133957, 84.39015805721283, 67.5663024187088, 62.779832258820534, 18.322090543806553, 0.7835206878371537, 0.28278388374019414, 0.4466328729176894, 0.37948629003949463, 7.578438268974423, 4.9978086445480585, 10.612310897558928, 25.96322402358055, 7.2047102730721235, 16.328067742288113, 25.871419049799442, 11.887037046253681, 12.912683710455894, 12.86544844508171, 7.256467770785093, 1.250439751893282, 0.5492232413962483, 0.18327938014408574, 0.13845422450685874, 0.13993767381180078, 1.5824797097593546, 1.117403784301132, 0.3389802557649091, 1.3775413879193366, 0.8278086769860238, 1.509362964425236, 0.34733674954622984, 0.5686802754644305, 2.7891705092042685, 0.6723065336700529, 0.6647301558405161, 1.1222182447090745, 0.39722189772874117, 0.8122106920927763, 1.5396402147598565, 7.011569011956453, 10.499361008405685, 10.63869098201394, 12.097388058900833, 10.328863207250834, 8.996908329427242, 6.953012254089117, 2.7971272822469473, 1.3600181532092392, 0.4779876919928938, 0.22229792783036828, 0.25209699757397175, 0.22844565653940663, 0.8400745969265699, 3.091850155033171, 0.2873063535662368, 0.9138614719267935, 0.4359471338102594, 0.2293355658184737, 0.18910261220298707, 0.2579292986774817, 0.10555849905358627, 0.6218978448305279, 0.6026933784596622, 0.3997976251412183, 1.8277009762823582, 0.549428133526817, 0.43025207065511495, 0.2615167514886707, 1.995968297123909, 21.226911172270775, 46.661165580153465, 60.43556705117226, 77.88108453154564, 92.09325671195984, 73.27465251088142, 39.6483188867569, 46.807054951786995, 81.64675086736679, 81.05709850788116, 84.42797362804413, 55.34233555197716, 8.631860967725515, 0.16215907438891008, 0.2820200356654823, 0.22345760778989643, 0.145375968713779, 0.11315072173601948, 0.11457613509264775, 0.15153950516832992, 0.13381703349296004, 0.13432915991870686, 0.10654572615749203, 0.07965686978423037, 0.15323272993555292, 0.13419616705505177, 0.2450297775794752, 0.1857315399684012, 0.23717076022876427, 0.20368789206258953, 0.14549294603057206, 0.11201976289157756, 0.06001308538543526, 0.12892142665805295, 0.08222741700592451, 0.0987673579948023, 0.11686684811138548, 0.24055173271335661, 0.11683872813591734, 0.09685925178928301, 0.11600370067753829, 0.11864801737829112, 0.18330974882701412, 0.13421408249996603, 0.137680743355304, 0.14317299239337444, 0.11806904571130872, 0.11836909601697698, 0.1791171042714268, 0.21189696562942117, 0.12694723962340504, 0.21375611977418885], [0.0518937820015708, 0.0632090367435012, 0.04408135297126137, 0.02371107093495084, 0.034468147132429294, 0.04313767138228286, 0.05289932159939781, 0.07264280240633525, 0.032934940536506474, 0.025554003586876206, 0.0507333821587963, 0.01647120512643596, 0.06616146347369067, 0.014649105487478664, 0.05089620935905259, 0.03608199920563493, 0.01255096030945424, 0.0663180863193702, 0.0413469024351798, 0.013885839998692973, 0.003258292922510009, 0.012716235669358866, 0.06983543586102314, 0.040454128466080874, 0.0384847579698544, 0.04788042548170779, 0.044637236424023286, 0.014144039669190533, 0.030838278726150747, 0.010219679643341806, 0.03522780578350648, 0.03129516895569395, 0.04849997778364923, 0.030716896762896795, 0.024718015047255903, 0.02031602918577846, 0.008573411487304838, 0.02910228769906098, 0.014244622016121866, 0.15397453622426838, 0.01901059327792609, 0.23492623848142102, 0.07637387563590892, 0.03874167836329434, 0.06800739996833727, 0.1586541929282248, 0.5763147783000022, 4.4434459414333105, 26.997256837785244, 68.58635768294334, 79.76620897650719, 60.49601420760155, 39.43980127573013, 30.935986787080765, 51.491500586271286, 77.6175306737423, 79.70440909266472, 78.49890097975731, 61.96937754750252, 33.40031795203686, 7.2026916313916445, 0.0518082865892211, 0.2101127980859019, 0.2406687694019638, 0.33086825511418283, 0.7421998050995171, 0.650131992297247, 2.7517083194106817, 0.9089660283643752, 2.6624185731634498, 6.991467140614986, 4.994042096659541, 3.593688989058137, 1.0343353729695082, 0.3256282472284511, 0.09009856104967184, 0.022726252100255806, 0.08853077408275567, 0.13421480980468914, 0.049676445123623125, 0.14980344363721088, 0.028905854196636938, 0.0658768201537896, 0.060150545978103764, 0.07719812711002305, 0.12746490247081965, 0.008825406803225633, 0.348628027131781, 0.5723946949001402, 0.07701845315750688, 0.08678602942381985, 0.21133566449861974, 0.19199131813365966, 0.11399952345527709, 0.1649978634668514, 0.13174428924685344, 0.1317890704376623, 0.12362721972749569, 0.22138207306852564, 0.22432670724811032, 0.3396628238260746, 0.16192733135540038, 0.47731569211464375, 0.6856919685378671, 0.07708186967647634, 0.4523557814536616, 0.11259380669798702, 0.3688945068279281, 0.6797431502491236, 0.034007291978923604, 0.1360681900405325, 0.05949364509433508, 0.10123957807081752, 0.09787871036678553, 0.028194913829793222, 0.18462986627127975, 0.12593109102454036, 0.11732974046026357, 0.32038455829024315, 0.4350531427189708, 0.09745720017235726, 0.3026170382509008, 5.822603786364198, 21.24006036669016, 33.65625321865082, 42.38751970231533, 63.90074551105499, 55.933754816651344, 33.003079667687416, 54.74424384534359, 66.82276591658592, 69.53695267438889, 65.01353859901428, 45.73943004012108, 16.966321393847466, 0.8284129633102566, 0.2736664214171469, 0.17320211307378486, 0.12486469902796671, 0.0269431815831922, 0.10868076627957635, 0.00683127918819082, 0.044080855732318014, 0.037356997781898826, 0.030017463395779487, 0.038200522831175476, 0.045449064346030354, 0.03079094269196503, 0.025865445859380998, 0.02118453678122023, 0.0341439139447175, 0.048711059425841086, 0.07551481743576005, 0.019949760753661394, 0.08133988259942271, 0.011140938167955028, 0.0317273289692821, 0.05669508784194477, 0.0018764454898700933, 0.03496605029795319, 0.0539365583244944, 0.028693243730231188, 0.031917467204038985, 0.08200650932849385, 0.03983599366620183, 0.0163619090380962, 0.03103265833487967, 0.010405705452285474, 0.01661344515014207, 0.04546645286609419, 0.05161773275176529, 0.0055496142704214435, 0.05875681490579154, 0.05666849669069052, 0.04420826764544472, 0.05336647758667823, 0.0783863797551021, 0.053210184996714815, 0.025761240904103033, 0.019666887455969118, 0.01521463686003699, 0.009041247467393987, 0.03213775147742126, 0.05062357769929804, 0.06542937189806253, 0.017451469029765576, 0.044951086965738796, 0.03655555621662643, 0.0066136958685092395, 0.03750246614799835, 0.018419242587697227, 0.025730523411766626, 0.029349042524700053, 0.10555204979027621, 0.0583997045760043, 0.03886069287545979, 0.026127308956347406, 0.013371572476899019, 0.07720583802438341, 0.026347550556238275, 0.023227159108500928, 0.021539999543165322, 0.04185681726085022, 0.02817651413351996, 0.030512201301462483, 0.05093144653073978, 0.037572268847725354, 0.08237635862315074, 0.03322035197925288, 0.01623153410037048, 0.034894507261924446, 0.027140123456774745, 0.07847828732337803, 0.05753488730988465, 0.03764019762456883, 0.06638735096203163, 0.045787368653691374, 0.20426468923687935, 0.10197950672591105, 0.2136217910447158, 0.12485758925322443, 0.21356831188313663, 0.5278094904497266, 11.726629603654146, 47.06701800227165, 84.39385905861855, 83.21004018187523, 52.270435988903046, 34.70610648393631, 39.952959939837456, 76.32682353258133, 96.72601372003555, 83.80819648504257, 70.98750963807106, 66.69027462601662, 39.12569873034954, 7.0235564187169075, 0.18540751829277724, 0.11888515582541004, 0.20037203561514616, 0.30042844475246966, 0.5080050718970597, 0.269676991738379, 1.6381468414328992, 7.106671733781695, 4.298224383965135, 2.7922730427235365, 4.859714079648256, 2.9318331414833665, 2.258153040893376, 0.31558903749100864, 0.04500345661654137, 0.10233791210339405, 0.14150678180158138, 0.05446462979307398, 0.0629253285296727, 0.20609022409189492, 0.08656610138132237, 0.08783428333117627, 0.08903133042622358, 0.3013947803992778, 0.21816502616275102, 0.09721569047542289, 0.90946213924326, 0.48440676473546773, 0.02211582821473712, 0.07962108342326246, 0.1636600829078816, 0.34821865847334266, 0.04353197444288526, 0.45965869270730764, 0.6914801266975701, 0.536460141884163, 0.03427653202379588, 0.11334681199514307, 0.10648066207068041, 0.24068665516097099, 0.3377040586201474, 0.6595938408281654, 0.9190688550006598, 0.6916266563348472, 0.514162047766149, 0.10068949821288697, 0.7087325071915984, 1.0583823826164007, 0.12744179199216887, 0.17098666867241263, 0.10784487792989239, 0.06988927867496386, 0.10419040176202543, 0.1448756127501838, 0.1831812088494189, 0.00834216569273849, 0.34383140795398504, 0.7391193578951061, 0.4903393448330462, 0.15025737084215507, 0.2811188012128696, 5.981762045994401, 27.00488492846489, 41.92805215716362, 47.70027682185173, 75.65084740519524, 85.02922296524048, 47.9958363622427, 42.43059799075127, 44.40808407962322, 64.09904927015305, 69.76633876562119, 60.11015631258488, 27.649520337581635, 2.570912833325565, 0.29173706425353885, 0.13475298561388627, 0.1263776412815787, 0.11904148923349567, 0.014259050294640474, 0.0661851379845757, 0.04158996693149675, 0.03613620938267559, 0.04397733726364095, 0.046475617855321616, 0.02763939217402367, 0.052168588154017925, 0.010228275568806566, 0.037810275607625954, 0.01339371723588556, 0.04153908899752423, 0.0401897346455371, 0.043668785656336695, 0.013273523636598838, 0.05567499472817872, 0.05777595171821304, 0.057579739004722796, 0.03725847396708559, 0.002793857602227945, 0.012339479762886185, 0.017125243175541982, 0.04740528769616503, 0.0023185614145404543, 0.05357329187972937, 0.04278880631318316, 0.0392699316580547, 0.020628234015021008, 0.044003234506817535, 0.04553703482088167, 0.006034247371644597, 0.04014942860521842, 0.024976464264909737, 0.04087133420398459, 0.035552547342376783, 0.07234583201352507, 0.1935244319611229, 0.16492243157699704, 0.10480918223038316, 0.06938084814464673, 0.10236327871098183, 0.14308742276625708, 0.09369754683575593, 0.1330240338575095, 0.10102402127813548, 0.20099601853871718, 0.15328004927141592, 0.1657052934751846, 0.15086772793438286, 0.1439377013593912, 0.08621854620287195, 0.0915380529477261, 0.1131583064852748, 0.16726031550206244, 0.1499003532808274, 0.13492339756339788, 0.13519402913516387, 0.15764179959660396, 0.14873586420435458, 0.18495097872801125, 0.12770299828844145, 0.14804390055360273, 0.2101866714656353, 0.18281964934431016, 0.09684908436611295, 0.23543460963992402, 0.14662538917036727, 0.18481743667507544, 0.16574183682678267, 0.08381719380849972, 0.09790107869775966, 0.16693811950972304, 0.13604283827589825, 0.20712446625111625, 0.10753161739557981, 0.16640209592878819, 0.25176056718919426, 0.25479669333435595, 0.14321333554107696, 0.3006577683845535, 0.22188125643879175, 0.3077307326020673, 0.6348159641493112, 9.913267157971859, 54.97018352150917, 100.80292895436287, 107.65369534492493, 79.14405316114426, 54.6764212846756, 45.29064752161503, 70.81259742379189, 95.88946580886841, 91.83911114931107, 88.86143893003464, 80.40888369083405, 50.11201500892639, 10.32600861042738, 0.19330865994561464, 0.31332584330812097, 0.45957337541040033, 0.48025248921476305, 4.897101698443294, 7.418455453589559, 7.198176998645067, 17.36229244619608, 15.089192669838667, 13.887289613485336, 16.985048688948154, 15.733287557959557, 6.803121697157621, 0.5271201836876571, 0.2767767326440662, 0.2146338133024983, 0.19770181796047837, 0.29100741434376687, 0.14956099883420393, 0.3128600417403504, 0.5703600822016597, 0.2553899068152532, 0.4267821740359068, 0.37419237254653126, 0.933189787901938, 0.19869401003234088, 1.5665715071372688, 0.9483929502312094, 0.16175982862478122, 0.07439363267621957, 0.35782852093689144, 1.1140208970755339, 0.29862276976928115, 0.936164315789938, 0.7701794255990535, 0.6661302025895566, 0.40638626378495246, 0.3376128041418269, 0.26946203608531505, 0.33445472829043865, 0.6103693228214979, 1.0967850219458342, 1.5998856257647276, 1.0751008917577565, 1.2774927564896643, 0.21104569255840033, 1.051561392378062, 1.403585309162736, 0.22957336477702484, 0.2691427938407287, 0.2239323448156938, 0.2083512512035668, 0.2120526830549352, 0.34787955635692924, 0.33381119719706476, 0.5402994202449918, 1.1588545725680888, 1.5416814177297056, 1.081677032634616, 0.29398283280897886, 0.8125635387841612, 13.659362643957138, 46.65057174861431, 60.38663327693939, 63.2407171279192, 80.35649210214615, 74.77179497480392, 50.314460545778275, 63.78593847155571, 80.01042187213898, 86.55709058046341, 83.53547751903534, 70.54652810096741, 29.741435386240482, 1.6936496319249272, 0.4060918092727661, 0.3041397174820304, 0.36723197728861123, 0.20929514430463314, 0.189360820222646, 0.18310910178115591, 0.1372361375251785, 0.16308479971485212, 0.10982228588545695, 0.20168747752904892, 0.20613881992176175, 0.1276898177457042, 0.09440917739993893, 0.07890736742410809, 0.20862226869212463, 0.15457105968380347, 0.11337523625115864, 0.0862028200936038, 0.18970213393913582, 0.09619293676223606, 0.15701827680459246, 0.13169791986001655, 0.131222648487892, 0.10452505099237897, 0.1248524832772091, 0.10901609086431563, 0.17047961853677407, 0.1372480861027725, 0.11265247347182594, 0.13268887996673584, 0.15736156463390216, 0.11141509065055288, 0.11160489491885528, 0.13259526545880362, 0.2180393657181412, 0.15781440830323845, 0.09884690138278529, 0.14088107709540054, 0.0708843873871956, 0.15848251932766289], [0.01832052024838049, 0.10334438309655525, 0.04234324682329316, 0.05940757451753598, 0.025729857334226836, 0.008227780326706124, 0.06692229100735858, 0.02611124702525558, 0.03458215585851576, 0.03655256536148954, 0.08029923570575193, 0.012801639240933582, 0.04092703980859369, 0.0387901777139632, 0.05184270368772559, 0.0822401003097184, 0.018132521254301537, 0.006000495886837598, 0.013328573368198704, 0.010455043429828947, 0.029504279409593437, 0.011813103174063144, 0.050383455818518996, 0.07505753572331741, 0.0106944769686379, 0.0421810541593004, 0.10640499269356951, 0.007139122508306173, 0.013993097963975742, 0.05532932460482698, 0.021843558351974934, 0.03712293924763799, 0.042738893171190284, 0.04073888681887183, 0.029181738318584394, 0.019893166427209508, 0.036568796131177805, 0.062165573399397545, 0.02895147215895122, 0.031134408636717126, 0.12911306403111666, 0.019183699223503936, 0.16329789999872446, 0.12510987493442371, 0.03819586585450452, 0.006239044878384448, 0.40609605435747653, 0.28295389492996037, 0.8356473594903946, 7.376673370599747, 33.88330243527889, 54.69916306436062, 72.56399944424629, 49.31868977844715, 42.45852269232273, 37.94077791273594, 41.91538743674755, 68.1788295507431, 74.76248547434807, 73.53570610284805, 51.719883531332016, 22.59199172258377, 3.3432646142318845, 0.45363794546574354, 0.3498614171985537, 0.08785343816271052, 1.0816668206825852, 1.1695543234236538, 1.970514531712979, 1.3339074980467558, 1.7690857965499163, 1.1414540000259876, 0.8830723771825433, 0.9457178344018757, 0.16933662205701694, 0.06411328431568108, 0.037917196823400445, 0.05549699802941177, 0.04952595612849109, 0.15489142999285832, 0.07419632529490627, 0.04030425174278207, 0.07936280861031264, 0.02837504420313053, 0.044724576073349454, 0.1050110389769543, 0.1885161077370867, 0.19989421125501394, 0.046714841737411916, 0.11008769273757935, 0.08685527922352776, 0.006040593198122224, 0.1554083061637357, 0.37440121290273964, 0.016768130990385544, 0.07046459897537716, 0.12786171399056911, 0.086890768725425, 0.03896937669196632, 0.16047862940467894, 0.045013423659838736, 0.1588826408260502, 0.1005892785906326, 0.2390731222112663, 0.12915524770505726, 0.1768869356601499, 0.07416290638502687, 0.04164147569099441, 0.019891713673132472, 0.14147760055493563, 0.1009275643446017, 0.04456297341675963, 0.06080183251469862, 0.1274689842830412, 0.03722691042639781, 0.5652934696990997, 0.3391093300888315, 0.4344362992560491, 0.019844919406750705, 0.6214813515543938, 2.7246936690062284, 10.661833640187979, 28.102760016918182, 42.8990026563406, 42.036608532071114, 40.46899504959583, 34.38766837120056, 32.31931775808334, 51.656958907842636, 62.515708431601524, 60.300412103533745, 57.92739383876324, 27.803795859217644, 4.9627583753317595, 0.36424462508875877, 0.4316591826500371, 0.04161667311564088, 0.13159118418116122, 0.04416101881361101, 0.14376014994923025, 0.09930107349646278, 0.012236579132149927, 0.038026251713745296, 0.03056264507904416, 0.07521883409935981, 0.0775150019035209, 0.06627959111938253, 0.05061095747805666, 0.05836951771925669, 0.03533709445036948, 0.03261766498326324, 0.04507587167609017, 0.037329122715163976, 0.05574395509029273, 0.03740244319487829, 0.014412772270588903, 0.052086376745137386, 0.044113265321357176, 0.020209434514981695, 0.017066227592295036, 0.03669770718261134, 0.050821838740375824, 0.012952862962265499, 0.009313421778642805, 0.026635967697075102, 0.031801951918168925, 0.09507902504992671, 0.035204283412895165, 0.038297228384180926, 0.05512745301530231, 0.05733544996473938, 0.04706796302343719, 0.031068873286130838, 0.04341170199040789, 0.024537558128940873, 0.02170368577935733, 0.039976085172384046, 0.04723159916466102, 0.035733946788241155, 0.04333515316830017, 0.018299940493307076, 0.026967230878653936, 0.011676712201733608, 0.026114063475688454, 0.03551001114828978, 0.024625890400784556, 0.020285395185055677, 0.021005992748541757, 0.05847623113368172, 0.01219227477122331, 0.06248104924452491, 0.02236222124338383, 0.06595885715796612, 0.012123675278417068, 0.044784975762013346, 0.04152963032538537, 0.034059542886097915, 0.010133949526789365, 0.06852583464933559, 0.12149515561759472, 0.007301694595298613, 0.04402894621307496, 0.02482861546013737, 0.039159021398518234, 0.03742301181773655, 0.02186198216804769, 0.02825660485541448, 0.046290466852951795, 0.049515042846906, 0.09410284110344946, 0.025714465191413183, 0.02900053368648514, 0.06509105645818636, 0.07799501559929922, 0.054231228059506975, 0.04742708828416653, 0.09468462551012635, 0.09052610490471125, 0.05069927305157762, 0.135892879916355, 0.043618486597551964, 0.009142336330114631, 0.2664551208727062, 0.8002389001194388, 1.2841314752586186, 20.830736830830574, 56.76197737455368, 73.83702993392944, 76.69440820813179, 48.07405896484852, 36.16426303982735, 44.180149510502815, 61.358016952872276, 90.58842346072197, 80.14353632926941, 74.8348031938076, 55.5521184951067, 21.965380646288395, 4.653483470901847, 0.5906362691894174, 0.22614677989622578, 0.04156831477303058, 0.6538303219713271, 0.5701476498506963, 0.40756399277597666, 1.5375782316550612, 2.300632861442864, 3.315377435646951, 1.6758589865639806, 0.7130650465842336, 0.19054369971854612, 0.07002432728768326, 0.01407259404004435, 0.03676700151117984, 0.09633873909479007, 0.08322738678543828, 0.08244201642810367, 0.06600795764825307, 0.13607298431452364, 0.036122275560046546, 0.055025040346663445, 0.3309662779793143, 0.07448217089404352, 0.8355597860645503, 0.13064114609733224, 0.058712200698209926, 0.22849110566312447, 0.03779903578106314, 0.12869879719801247, 0.3206236782716587, 0.025416465068701655, 0.0850970868486911, 0.1195362197177019, 0.28242275468073785, 0.4502822208451107, 0.6395254551898688, 0.316679400857538, 0.24695882719242945, 0.2065982687054202, 0.2846378576941788, 0.30820668675005436, 0.23106456210371107, 0.13187346747145057, 0.0983642233768478, 0.23982892540516332, 0.18963586015161127, 0.10341177010559477, 0.14008927973918617, 0.055196086832438596, 0.05722790905565489, 0.144522825430613, 0.27700727339833975, 0.09987722500227392, 0.8251828397624195, 0.0665273645427078, 0.11155098531162366, 3.117017154581845, 13.771633319556713, 35.10446950793266, 54.14965555071831, 66.18765279650688, 64.3786458671093, 50.00522553920746, 29.99992411583662, 41.63555145263672, 64.29634988307953, 71.09879046678543, 67.61084362864494, 40.34054674208164, 9.453806262463331, 0.4906621790723875, 0.24741235363762826, 0.03499307560559828, 0.03623058459197637, 0.06430917419493198, 0.07441605295753106, 0.07222216794616543, 0.047341681929538026, 0.10147988548851572, 0.06723852755385451, 0.09174399892799556, 0.05731618010031525, 0.049037474527722225, 0.047461705762543716, 0.025369689356011804, 0.06941078638192266, 0.020587471553881187, 0.07069303203024901, 0.02686419480596669, 0.061994296847842634, 0.01808638193324441, 0.02445868267386686, 0.09161722526187077, 0.05226813613262493, 0.04052433563629165, 0.011097578189946944, 0.06011456665873993, 0.07751834898954257, 0.03543293169059325, 0.0192823269389919, 0.02160880405426724, 0.03269374254159629, 0.018053849889838602, 0.005707207474188181, 0.07102536575985141, 0.06278147804550827, 0.007200329746410716, 0.05345347213733476, 0.04801775619853288, 0.05000507924705744, 0.06348631053697318, 0.05230603019299451, 0.3109065012540668, 0.23117181728594005, 0.11449119629105553, 0.1690950381453149, 0.10277847322868183, 0.08434976640273817, 0.18098933505825698, 0.09617722549592145, 0.1118162288912572, 0.16072515601990744, 0.13205045484937727, 0.08345840993570164, 0.20807267865166068, 0.08352711054612882, 0.1535195403266698, 0.3355812787776813, 0.12848862097598612, 0.2142918761819601, 0.0856315296550747, 0.07832476665498689, 0.11347446881700307, 0.17247578798560426, 0.13972917484352365, 0.16566095757298172, 0.07225815468700603, 0.16530537977814674, 0.23787247569998726, 0.11673184402752668, 0.13595066353445873, 0.14446852990658954, 0.054921414266573265, 0.13576012453995645, 0.20939010952133685, 0.24129597324645147, 0.14942855515982956, 0.1475468694115989, 0.13886850618291646, 0.17069399531465024, 0.15377501724287868, 0.12516308692283928, 0.22294601571047679, 0.21506531280465424, 0.2588882722193375, 0.4558043635915965, 0.1778355785063468, 0.11336504656355828, 0.6388883362524211, 0.7268656091764569, 1.4480824652127922, 20.794971249997616, 64.34801191091537, 88.10271084308624, 103.71478870511055, 71.3336406648159, 55.9613261371851, 54.93590176105499, 59.817355424165726, 94.2061485350132, 89.31207194924355, 93.8731724023819, 72.99078494310379, 34.21581879258156, 5.963323535397649, 0.571257071569562, 0.892962533980608, 0.173544243152719, 1.5162747935391963, 2.926752814091742, 5.262866746634245, 8.93185866996646, 8.164728283882141, 13.037429116666317, 3.185898195952177, 2.8885596385225654, 0.7333588076289743, 0.11205951974261552, 0.11182560963789001, 0.178432606626302, 0.25185303878970444, 0.2369027558597736, 0.19285265472717583, 0.2164425904629752, 0.33832146611530334, 0.1511969298007898, 0.16981263557681814, 0.685877624200657, 0.41029892570804805, 2.4103956716135144, 0.23046023125061765, 0.3199256141670048, 0.4480495140887797, 0.1663580271997489, 0.3044686670182273, 1.2643149448558688, 0.1221999732661061, 0.2996641810750589, 0.43531013361644, 0.5750775884371251, 0.8577418082859367, 0.7009014242794365, 0.44494350731838495, 0.3067993075819686, 0.35587625694461167, 0.30037750373594463, 0.29092340322677046, 0.5291709455195814, 0.36255941551644355, 0.16709109098883346, 0.25116290082223713, 0.3660050587495789, 0.6589376041665673, 0.20961342175723985, 0.1272038000752218, 0.34845819405745715, 0.3142974927322939, 2.176029235124588, 1.0207369714044034, 1.775098736397922, 0.12299337366130203, 1.0383974737487733, 8.597255274653435, 31.05941366404295, 57.62873746454716, 70.19707605242729, 61.7346603423357, 57.22750559449196, 50.27983300387859, 46.907855942845345, 65.22511124610901, 77.85099014639854, 77.78659120202065, 80.3964051604271, 45.978984385728836, 7.857561316341162, 0.4460276960162446, 0.49723656848073006, 0.10460811216034926, 0.2596255810931325, 0.2503259957302362, 0.18556624883785844, 0.22936501423828304, 0.11427849676692858, 0.15593530522892252, 0.13147119374480098, 0.17960049473913386, 0.24372272193431854, 0.11936544411582872, 0.1274482932058163, 0.12946553964866325, 0.1798015128588304, 0.10531823616474867, 0.14176145719829947, 0.2114050998352468, 0.11877657219883986, 0.09091850064578466, 0.09458451721002348, 0.1986030672560446, 0.13515174156054854, 0.10211854067165405, 0.12474638584535569, 0.15693831781391054, 0.16218608856434003, 0.15208327677100897, 0.14128498354693875, 0.14072267309529707, 0.07162499139667489, 0.19322114589158446, 0.09415653548785485, 0.12369901509373449, 0.1977501466171816, 0.11601094403886236, 0.1205611701880116, 0.12982757412828505, 0.11453519822680391, 0.14573280815966427, 0.20370690588606521], [0.026274241208739113, 0.02740744690527208, 0.05840327801706735, 0.08639170409878716, 0.054749325063312426, 0.11764026246964931, 0.03660143949673511, 0.0375656414689729, 0.01657683871599147, 0.06302523644990288, 0.033728144262568094, 0.05746894377807621, 0.030611892143497244, 0.028588144487002864, 0.0636812875745818, 0.04463103206944652, 0.056265373204951175, 0.04130831075599417, 0.04615281330188736, 0.06133560367743485, 0.01174945473394473, 0.011788559422711842, 0.03474622615613043, 0.04763395823829342, 0.045761181972920895, 0.055555861472385004, 0.06608880721614696, 0.03206870947906282, 0.047263151573133655, 0.08138919089105912, 0.07985115662449971, 0.021599369501927868, 0.07454221064108424, 0.06934166274731979, 0.05436558276414871, 0.02201799459726317, 0.02722510678722756, 0.04821756090677809, 0.05940317358181346, 0.012354204900475452, 0.041878499105223455, 0.036437432281672955, 0.0743711159157101, 0.11402721298509277, 0.010989304410031764, 0.011443489511293592, 0.12654398626182228, 0.07549671645392664, 0.20338558562798426, 0.5747128080110997, 1.5762993413954973, 14.723138362169266, 38.14254708588123, 62.60757230222225, 64.159374833107, 61.84239216148853, 38.64012658596039, 32.841497138142586, 54.70359742641449, 66.33600443601608, 71.80952712893486, 73.67889001965523, 45.236371234059334, 17.89964061230421, 4.113502996042371, 0.7447989250067621, 0.25392407609615475, 0.47514393052551895, 0.3705381561303511, 0.38838205800857395, 0.5571386322844774, 0.4568500496679917, 0.8286605437751859, 0.48042523150797933, 0.458332949783653, 0.3776864631799981, 0.22266788844717667, 0.07748932359390892, 0.0770860405464191, 0.15599530044710264, 0.13070033979602158, 0.06831423350377008, 0.08336738552316092, 0.06681604514596984, 0.03300450574897695, 0.14529318956192583, 0.5700250470545143, 0.19326948939124122, 0.18191909766755998, 0.2032096520997584, 0.1796685645240359, 0.1993457047501579, 0.21296067105140537, 0.09626712926547043, 0.027708588168025017, 0.01160670170065714, 0.1723590333131142, 0.1156697045371402, 0.09257506331778131, 0.06515955668874085, 0.07747978699626401, 0.06140898352896329, 0.0623388760141097, 0.117225490976125, 0.1796126808039844, 0.07125467454898171, 0.12064676950103603, 0.09708653451525606, 0.1554924063384533, 0.07137318068998866, 0.14517121016979218, 0.0651338932220824, 0.35728179558645934, 0.6367487541865557, 0.5228995007928461, 0.37425735499709845, 0.049717148212948814, 1.685028369538486, 3.5430417442694306, 12.208587191998959, 26.408520229160786, 33.556136190891266, 46.23765170574188, 42.15862758457661, 34.09291818737984, 40.29752545058727, 50.76526835560799, 67.70820960402489, 74.78136286139488, 69.08980026841164, 35.76360873878002, 9.420876279473305, 0.15591265488183126, 0.1913444622186944, 0.13455489155603573, 0.11659904412226751, 0.12396503050695173, 0.04312797151214909, 0.024033509980654344, 0.016092772893898655, 0.032446340192109346, 0.10662232321919873, 0.00738262301638315, 0.05962336508673616, 0.05017738738388289, 0.045095961613697, 0.010642507149896119, 0.059387866785982624, 0.09652259876020253, 0.009272489551221952, 0.06707730339257978, 0.03590098196582403, 0.034855329286074266, 0.04861160421569366, 0.06750439453753643, 0.060192996825207956, 0.05428747543192003, 0.04188730468740687, 0.04206416961096693, 0.035663116213981993, 0.030763119575567544, 0.026878316020884085, 0.006203331804499612, 0.020307813610997982, 0.02185641606047284, 0.06460402204538696, 0.036715570677188225, 0.03588198669604026, 0.029183038932387717, 0.02721716580708744, 0.06831101258285344, 0.05297987059748266, 0.031148212583502755, 0.009034138620336307, 0.03859293712594081, 0.08983236009953544, 0.023709059714747127, 0.09241141233360395, 0.02810036421578843, 0.04876589300693013, 0.0524167808907805, 0.04060704057337716, 0.045877639786340296, 0.015468440233235015, 0.03716290390002541, 0.023599084561283235, 0.028988785488763824, 0.0942230541841127, 0.08042860688874498, 0.026792362332344055, 0.11631086075794883, 0.06626170536037534, 0.0540250631456729, 0.053635877193300985, 0.008689671703905333, 0.016749473397794645, 0.02033697259321343, 0.06101660634158179, 0.04413558912347071, 0.010889895584114129, 0.057698983582668006, 0.06391441842424683, 0.02091086240397999, 0.05214584503846709, 0.014491359215753619, 0.04581569643050898, 0.019995942748209927, 0.012318549343035556, 0.03082523362536449, 0.02464859455358237, 0.08644962872494943, 0.03904925033566542, 0.05976556058158167, 0.09413094623596407, 0.09271400820580311, 0.07295551375136711, 0.01713904526695842, 0.06478672396042384, 0.07691882725339383, 0.04780369854415767, 0.11840718303574249, 0.051028059315285645, 0.23604076617630199, 0.08398928301176056, 0.3710882953600958, 0.9515868569724262, 5.358545612543821, 27.086097970604897, 56.88835099339485, 74.14845362305641, 69.14558127522469, 58.44591781497002, 31.662279814481735, 40.97252883017063, 71.16468653082848, 83.8125966489315, 82.0719176530838, 71.83208271861076, 41.94330453872681, 16.394440680742264, 5.7592711597681046, 0.8285949379205704, 0.11097884140326641, 0.3356397897005081, 0.41564324987120926, 0.3100705164251849, 0.13246709655504674, 0.24597326992079616, 0.48852693114895374, 0.23744076839648187, 0.27308365737553686, 0.22134355560410768, 0.022896651062183082, 0.024773746627033688, 0.029338604217628017, 0.053176903384155594, 0.15506571595324203, 0.05498982915014494, 0.11297971606836654, 0.13364148588152602, 0.08695710188476369, 0.14372837118571624, 0.2941737725632265, 0.14766825508559123, 0.06968020083149895, 0.23107330460334197, 0.7504636491648853, 0.20600124058546498, 0.08469243824947625, 0.07526121073169634, 0.018894944405474234, 0.04282813271856867, 0.08207753286114894, 0.1500915305223316, 0.2730335178785026, 0.09300472229369916, 0.055723913392284885, 0.024987570504890755, 0.06617549748625606, 0.08869669603882357, 0.13248386909253895, 0.011276209424977424, 0.10408123926026747, 0.15650873305276036, 0.24023305450100452, 0.056119492946891114, 0.05246158063528128, 0.05951423598162364, 0.26075352681800723, 0.548176160082221, 0.6191260123159736, 0.19408270512940362, 0.07991471415152773, 0.6679998803883791, 4.187388131394982, 14.713573325425386, 36.63098059594631, 47.86092460155487, 66.9181863963604, 66.75313085317612, 42.94607073068619, 28.882751762866974, 32.210567593574524, 57.414501160383224, 78.92342939972878, 75.1166720688343, 44.90368768572807, 16.171360351145267, 0.43672083760611713, 0.28578171506524086, 0.14006723795318976, 0.04561149820801802, 0.061421934005920775, 0.019499844856909476, 0.07825174674508162, 0.07103617143002339, 0.04771129744767677, 0.05243218787654769, 0.05184539026231505, 0.015653491973353084, 0.10249904720694758, 0.04431266184838023, 0.04080148697539698, 0.05041828851972241, 0.023168607367551886, 0.06874088678159751, 0.016028380450734403, 0.039485173037974164, 0.04839450746658258, 0.07891454399214126, 0.07007172825979069, 0.06996802796493284, 0.0371194400213426, 0.049119838076876476, 0.03239030804252252, 0.06189841507875826, 0.03588863633922301, 0.012957286162418313, 0.022797090095991734, 0.042870212491834536, 0.07548826339188963, 0.02948061974166194, 0.051423857803456485, 0.03192767544533126, 0.05118408102134708, 0.06833317311247811, 0.04541223155683838, 0.007587399186377297, 0.024309329164680094, 0.03784942760830745, 0.009673711283539888, 0.06754098983947188, 0.12383528825012036, 0.21075644792290404, 0.26433148013893515, 0.14515724295051768, 0.15650946035748348, 0.2127005928196013, 0.08313380196341313, 0.207577517721802, 0.1049640090786852, 0.09698535752249882, 0.19272797391749918, 0.18543500744272023, 0.156591274717357, 0.16337140230461955, 0.23921546613564715, 0.1355092489393428, 0.2149772792472504, 0.19364004372619092, 0.1427887231693603, 0.16616401495411992, 0.13220087334048003, 0.1466963384882547, 0.1085661786783021, 0.09226710171788, 0.1212316560850013, 0.19091624300926924, 0.16493960487423465, 0.10686228924896568, 0.11882281542057171, 0.13360187003854662, 0.17261537112062797, 0.10596503270789981, 0.208276531775482, 0.20925049670040607, 0.23737692885333672, 0.12860176881076768, 0.12923870963277295, 0.19793071114690974, 0.1843038111110218, 0.10430631780764088, 0.16158683400135487, 0.1341688263346441, 0.14109926851233467, 0.2352186298230663, 0.22114578809123486, 0.15985699166776612, 0.40362856176216155, 0.18914714106358588, 0.5839190608821809, 0.8299106766935438, 3.6064216308295727, 28.03877145051956, 64.91035893559456, 92.0024111866951, 89.80632662773132, 87.79535293579102, 57.05244138836861, 50.24103328585625, 74.41751718521118, 89.96077314019203, 94.16106015443802, 92.32705816626549, 65.87344765663147, 26.489547081291676, 8.013823181390762, 1.1392515432089567, 0.3662860655458644, 1.174926997628063, 1.2081297347322106, 1.7143231350928545, 1.5528269321657717, 2.5625475822016597, 4.01294756680727, 0.6674740836024284, 0.9150080604013056, 0.5132632772438228, 0.24523242842406034, 0.11214695216040127, 0.18924335308838636, 0.26021172932814807, 0.29162980907130986, 0.19634091207990423, 0.19592979195294902, 0.18227678316179663, 0.09139458838035353, 0.6034690712112933, 2.353202090598643, 0.2547196880914271, 0.4126180778257549, 1.023843779694289, 1.1265614116564393, 0.5113953212276101, 0.622926817741245, 0.3808505355846137, 0.15353800496086478, 0.23210062994621694, 0.4146171861793846, 0.6590246432460845, 0.6373046524822712, 0.5509554140735418, 0.22464050212875009, 0.16125976952025667, 0.25821852847002447, 0.11531642740010284, 0.36782703129574656, 0.11978966314927675, 0.2689105906756595, 0.2449720978620462, 0.7612680725287646, 0.6500090926419944, 0.30246549169532955, 0.5012930289376527, 0.6726459029596299, 1.2024821690283716, 2.1903048316016793, 1.0248037031851709, 0.10486766346730292, 2.237427528016269, 11.791642215102911, 33.69170531630516, 58.57609882950783, 65.67566826939583, 73.55680257081985, 65.77278345823288, 51.62610836327076, 59.407444819808006, 62.91869580745697, 80.49825489521027, 88.24017986655235, 90.85507795214653, 54.27512101829052, 16.699034236371517, 0.3959617606597021, 0.40645412576850504, 0.28671973035670817, 0.23994657065486535, 0.1582559267990291, 0.12872303574113175, 0.15867292473558336, 0.17941887635970488, 0.1564677368151024, 0.24798873520921916, 0.1637423870852217, 0.18923308176454157, 0.1844085133052431, 0.21045231580501422, 0.1292144859326072, 0.18726181879173964, 0.19053964759223163, 0.14994394703535363, 0.13581133272964507, 0.09443763876333833, 0.1594181449036114, 0.14165345986839384, 0.1615561536164023, 0.2010915774735622, 0.1993078552186489, 0.08690882517839782, 0.15563037159154192, 0.10541669689700939, 0.15718726383056492, 0.10838436734047718, 0.10417696146760136, 0.07335633286857046, 0.18458275473676622, 0.0819613719068002, 0.1117340731434524, 0.10599459987133741, 0.10336239502066746, 0.09330891378340311, 0.1648500276496634, 0.2057411623536609, 0.09623576610465534, 0.07866133804782294, 0.09408509635250084, 0.22929523751372471], [0.0380670178856235, 0.04124681268876884, 0.03133378289930988, 0.06237300738575868, 0.09905743383569643, 0.05994281513267197, 0.052427089322009124, 0.002939783780675498, 0.012977128408238059, 0.017175028297060635, 0.02204424064984778, 0.056399238092126325, 0.011571621307666646, 0.03959664732974488, 0.05836255266331136, 0.07298389347852208, 0.05976588341582101, 0.018812219059327617, 0.03158884050208144, 0.04524508876784239, 0.0036698942858492956, 0.04286733295884915, 0.066843274544226, 0.03765905188629404, 0.03201255858584773, 0.032860395513125695, 0.04186152247712016, 0.046461064339382574, 0.02320535852049943, 0.021599274878099095, 0.0053659150944440626, 0.022996158222667873, 0.019608909024100285, 0.03864936632453464, 0.01644040414248593, 0.07442888469086029, 0.1286175913992338, 0.02085076142975595, 0.023573172475153115, 0.028383669814502355, 0.0479718506539939, 0.014567266080121044, 0.04938680343911983, 0.09434308914933354, 0.09059755146154203, 0.051989266721648164, 0.3030718263471499, 0.05765859590610489, 0.13220970489783213, 0.03855563307297416, 0.22245143365580589, 0.5497498693875968, 3.3016948448494077, 19.029367491602898, 47.84979119896889, 63.65152448415756, 67.39263653755188, 53.07641074061394, 36.790473237633705, 32.77962885797024, 44.13502313196659, 62.04449571669102, 77.32816860079765, 76.49070873856544, 67.93852284550667, 27.03528329730034, 7.462367322295904, 1.6190767334774137, 0.8120680216234177, 0.33505022758617997, 0.09331459863460623, 0.1118903026508633, 0.06239137554075569, 0.24729855271289125, 0.3820850537158549, 1.0446233209222555, 0.3546632017241791, 0.9278671641368419, 0.21284632093738765, 0.11592452094191685, 0.4341218958143145, 0.25982818740885705, 0.34592655021697283, 0.13593237701570615, 0.08514768647728488, 0.5728520953562111, 0.1833054592134431, 0.03189252733136527, 0.2029385752393864, 0.26648584578651935, 0.20903055381495506, 0.381799831520766, 0.24802987987641245, 0.18303497607121244, 0.06829701567767188, 0.09493030607700348, 0.3256140276789665, 0.1518160739215091, 0.1700943399919197, 0.13180432899389416, 0.0677161589555908, 0.07236954363179393, 0.043229126240476035, 0.3005666920216754, 0.27041005552746356, 0.11578102668863721, 0.13510979537386447, 0.08240857525379397, 0.45544267049990594, 0.5234039237257093, 0.14642576628830284, 0.320221790461801, 0.972581502282992, 0.2245933609083295, 0.10411149662104435, 1.0774921509437263, 7.067037960514426, 16.902747005224228, 33.15172389149666, 39.42251980304718, 43.204103484749794, 37.10125856101513, 36.01593799889088, 38.01058016717434, 62.77818314731121, 65.69131582975388, 65.92413693666458, 58.03344614803791, 37.60878972709179, 11.91210525110364, 0.44468752574175596, 0.16365650575608015, 0.17488692188635468, 0.05278878612443805, 0.15509308635955676, 0.09952399239409715, 0.04095197225979064, 0.06044725661922712, 0.025315204584330786, 0.04735399787023198, 0.08826018703985028, 0.051431969477562234, 0.05004587881558109, 0.05561423509789165, 0.02634062446304597, 0.04016806393337902, 0.0503721454879269, 0.017901407190947793, 0.039181274696602486, 0.07457381871063262, 0.03160411390126683, 0.03630326682468876, 0.05552834634727333, 0.14454617339652032, 0.034474080603104085, 0.02105943851347547, 0.03872284265526105, 0.09174690814688802, 0.04474893707083538, 0.10897667540120892, 0.052676770064863376, 0.029440269172482658, 0.029474775328708347, 0.02575917216745438, 0.0198999403801281, 0.023833877821743954, 0.002239231857856794, 0.05306173690769356, 0.00830339960884885, 0.09598154341802001, 0.014167535136948572, 0.06554826395586133, 0.06458483010646887, 0.04406651001772843, 0.026052660032291897, 0.06175829388666898, 0.05308966392476577, 0.06396328142727725, 0.0692358250671532, 0.04872793586400803, 0.05060116855020169, 0.050173928975709714, 0.08344773785211146, 0.011705382294167066, 0.06076845442294143, 0.030209085925889667, 0.030269491180661134, 0.023644713655812666, 0.028336161230981816, 0.010758214466477511, 0.07432508049532771, 0.04984523548046127, 0.12761475692968816, 0.07612187939230353, 0.06965297143324278, 0.025721053607412614, 0.026906397033599205, 0.035312373511260375, 0.0207165866959258, 0.03470144496532157, 0.046298292800202034, 0.0913531839614734, 0.08752071851631626, 0.05564725324802566, 0.019488228390400764, 0.04091627495654393, 0.05850728259247262, 0.06391553906723857, 0.04866198491072282, 0.025360438485222403, 0.03580325224902481, 0.06774794514058158, 0.057907612426788546, 0.073008080071304, 0.01914493870572187, 0.06123581450083293, 0.05802915766253136, 0.03440011074417271, 0.04042135151394177, 0.05661689516273327, 0.06787756123230793, 0.0559247571072774, 0.20468743139645085, 0.29679753177333623, 0.014030013317096746, 0.11642825367744081, 0.4626336065120995, 2.079647406935692, 8.84121073409915, 39.0988227725029, 69.2869108915329, 78.78071665763855, 72.34513118863106, 50.409516245126724, 36.30574844777584, 43.928914591670036, 61.12651817500591, 82.02008843421936, 86.60018026828766, 72.13979780673981, 49.753310456871986, 23.944798931479454, 7.834322713315487, 2.281830282881856, 0.42633074044715613, 0.3516928298631683, 0.12022546710795723, 0.30496332328766584, 0.09165754614514299, 0.47134407504927367, 0.037755226803710684, 0.35169015813153237, 0.2299184782896191, 0.3214494214626029, 0.17316623765509576, 0.20016258669784293, 0.1984017522772774, 0.07386575045529753, 0.49820842570625246, 0.14086801529629156, 0.082320927613182, 0.16752560361055657, 0.12104527311748825, 0.07905063161160797, 0.05268935317872092, 0.17731898435158655, 0.3784910700051114, 0.9182501176837832, 0.3739963861880824, 0.1086962029512506, 0.13855919387424365, 0.12959304061951116, 0.276596361072734, 0.12154286087024957, 0.22173042234499007, 0.03360764545504935, 0.03555436931492295, 0.06509894548798911, 0.059806905628647655, 0.24401318369200453, 0.3704528685193509, 0.052742030820809305, 0.10645484275300987, 0.13088655949104577, 0.8716389688197523, 0.321668948745355, 0.1316761749330908, 0.6561464758124202, 1.30405867472291, 0.6201603880617768, 0.10005855394410901, 0.6114033423364162, 8.004740718752146, 22.9315946996212, 43.65790173411369, 52.07267940044403, 62.79425248503685, 61.79718218743801, 50.1297714561224, 36.799391359090805, 42.494259774684906, 62.2285882383585, 72.50959396362305, 70.6607423722744, 48.66760991513729, 19.738523438572884, 1.3851583166979253, 0.385388174909167, 0.10711516864830628, 0.052372649079188704, 0.1245106352143921, 0.060091871782788076, 0.015050382880872348, 0.09995589265599847, 0.03208649875887204, 0.023700252277194522, 0.0983533583348617, 0.04484968361794017, 0.06403751103789546, 0.03453812052612193, 0.01983651458431268, 0.053765612028655596, 0.04570634468109347, 0.010222643595625414, 0.0194469000416575, 0.09605213650502264, 0.06320361164398491, 0.05744292779127136, 0.022969871351961046, 0.04232813669659663, 0.030540560619556345, 0.022493421820399817, 0.04290720113203861, 0.0837139536452014, 0.03721450542798266, 0.03349594109749887, 0.0441235292237252, 0.011718088790075853, 0.05547328641114291, 0.02848572996299481, 0.029423852865875233, 0.03853052250633482, 0.028795879043173045, 0.04111207577807363, 0.0592226127628237, 0.025763561970961746, 0.06438182303099893, 0.04390756424982101, 0.02742729750025319, 0.05413106038758997, 0.0030713558953721076, 0.031578083071508445, 0.10443646824569441, 0.10254727196297608, 0.22805675631389022, 0.17327058361843228, 0.14438867481658235, 0.1343412569258362, 0.16729503317037597, 0.10234867324470542, 0.09291912298067473, 0.07557999284472317, 0.150731232133694, 0.20131935743847862, 0.08123222665744834, 0.17641819518757984, 0.16384759393986315, 0.20285180333303288, 0.22500451072119176, 0.2106704775360413, 0.07534650576417334, 0.16187282803002745, 0.08337974970345385, 0.09876705371425487, 0.1902616093866527, 0.14347886113682762, 0.16252793662715703, 0.17796508327592164, 0.13914431794546545, 0.1149941943003796, 0.17032854695571586, 0.09980673581594601, 0.08132221206324175, 0.1009116081695538, 0.14882648043567315, 0.08663703585625626, 0.16597371344687417, 0.19140545191476122, 0.20003636222099885, 0.1812671506195329, 0.13499854743713513, 0.17007583082886413, 0.1555158878909424, 0.09209910174831748, 0.18098593602189794, 0.19161498988978565, 0.14001530245877802, 0.15671506494982168, 0.40897300466895103, 0.3608603129396215, 0.2039750586845912, 0.15751250262837857, 0.5174551054369658, 1.3343499368056655, 7.102931784465909, 40.27654677629471, 78.04256826639175, 96.727594435215, 94.65918302536011, 78.82565304636955, 53.69548872113228, 53.011768609285355, 65.97739487886429, 87.31276363134384, 101.75875246524811, 101.73528492450714, 87.59460210800171, 42.833098992705345, 17.19129402190447, 3.4330915566533804, 0.877390910172835, 0.6937601824756712, 0.836533127585426, 0.622758676763624, 0.22063483425881714, 0.6881466368213296, 0.9189650730695575, 1.8150743725709617, 0.8556407585274428, 1.772820521146059, 0.35777416604105383, 0.3653331776149571, 0.5138986150268465, 0.7236502098385245, 1.174157657660544, 0.17134101450210437, 0.10536864283494651, 1.6081364080309868, 0.24169775715563446, 0.13565804954851046, 0.4760517255635932, 0.7974693831056356, 1.3529601506888866, 1.4483250584453344, 0.8333953865803778, 0.6064080353826284, 0.31471398600842804, 0.4481363750528544, 0.7925968570634723, 0.5065089021809399, 0.5837272305507213, 0.28298880555666983, 0.37361364578828216, 0.2034719567745924, 0.20948814722942188, 0.3772197710350156, 0.4160229623084888, 0.10516910901060328, 0.7906750508118421, 0.49846841488033533, 2.100339434109628, 2.5837855925783515, 0.4263254563556984, 1.2294709333218634, 1.2636632798239589, 0.9657997568137944, 0.4005994711769745, 3.4795965487137437, 16.94043528288603, 47.11797706782818, 74.14850682020187, 72.56737366318703, 69.46110874414444, 58.363739624619484, 56.08252823352814, 56.97555251419544, 81.8962150812149, 85.62775164842606, 85.3444692492485, 82.63819366693497, 56.694580391049385, 19.782583974301815, 1.1549793742597103, 0.6150943099055439, 0.29396882106084377, 0.13615340343676507, 0.28912728710565716, 0.12929509801324457, 0.1063247220008634, 0.13609478861326352, 0.1375704156816937, 0.07123842151486315, 0.2847502485383302, 0.11904381215572357, 0.1463190306094475, 0.14170710230246186, 0.14656008017482236, 0.1043875384493731, 0.141687331488356, 0.11399535258533433, 0.11317275610053912, 0.24846572836395353, 0.2060816003358923, 0.21731436165282503, 0.1219843645230867, 0.20006949169328436, 0.1479436512454413, 0.15051728580147028, 0.1597722977749072, 0.17481980205047876, 0.11469549470348284, 0.23447493847925216, 0.10958759652567096, 0.10808543025632389, 0.11743538518203422, 0.10765309954877011, 0.14741886378033087, 0.12852736108470708, 0.08006781921721995, 0.15826616843696684, 0.11865088948979974, 0.1768130177515559, 0.12056718158419244, 0.24304321152158082, 0.15181582159129903, 0.1432187235332094, 0.1396286880481057, 0.1506699455785565], [0.020152214929112233, 0.015488609024032485, 0.06738461932400241, 0.03333632368594408, 0.019753225205931813, 0.02726359827647684, 0.08737646727240644, 0.03305701640783809, 0.035642358343466185, 0.04056789599417243, 0.029867326920793857, 0.013588418751169229, 0.029518005430873018, 0.01113366975914687, 0.0578468268213328, 0.0925134279532358, 0.05675384367350489, 0.026168859949393664, 0.06441426972742192, 0.07196040503913537, 0.0730177947843913, 0.07087483594659716, 0.06367519454215653, 0.022682938506477512, 0.06645957677392289, 0.015657855801691767, 0.02184997978474712, 0.015483914939977694, 0.024828264795360155, 0.03357514680828899, 0.13158736954210326, 0.022532252842211165, 0.011514937923493562, 0.06737277464708313, 0.038109450179035775, 0.07581104568089359, 0.055560626060469076, 0.06097804805904161, 0.036834781858487986, 0.03989185883256141, 0.0687981212104205, 0.05758118990343064, 0.06160390861623455, 0.05693470506230369, 0.020065552489541005, 0.03998570340627339, 0.18824869708623737, 0.07558515819255263, 0.02879386411223095, 0.03592710185330361, 0.05095799315313343, 0.2291995895211585, 0.08966992623754777, 0.18798538309056312, 4.332029744982719, 18.49143035709858, 42.18488037586212, 61.47895686328411, 58.09923581779003, 57.10411861538887, 45.69333091378212, 27.67068140208721, 39.42882366478443, 52.928777262568474, 75.89319080114365, 79.86799031496048, 64.9121980369091, 46.60867899656296, 30.098192542791367, 10.512241367250681, 4.1996481735259295, 1.6224560583941638, 1.528631611727178, 0.20780231425305828, 0.626493520103395, 0.8058610546868294, 0.7669502520002425, 1.3605541619472206, 0.7349045528098941, 0.30476047948468477, 0.22743240231648088, 0.482276949333027, 1.0371681209653616, 0.4866395308636129, 0.4951865191105753, 0.2081949994317256, 0.8081108902115375, 0.49034433206543326, 0.24512548494385555, 0.2408312403713353, 0.2084879993344657, 0.8721339516341686, 0.4511925094993785, 0.20233051880495623, 0.28901136363856494, 0.26388669619336724, 0.32343710074201226, 0.2700609195744619, 0.17335596028715372, 0.2740978467045352, 0.07719427536358126, 0.1748419922660105, 0.19328825088450685, 0.623954840702936, 0.8289176831021905, 0.09741250061779283, 0.8403850521426648, 0.013964823065180099, 0.1995746573084034, 0.3257019573356956, 0.10445689214975573, 0.40748205967247486, 1.0451315436512232, 3.0848034331575036, 6.552271032705903, 22.353007346391678, 32.16143622994423, 45.76795130968094, 51.12817928195, 47.917131185531616, 24.472660906612873, 36.281612142920494, 45.008717849850655, 64.65454146265984, 64.5128470659256, 53.939751014113426, 40.165657326579094, 10.407972112298012, 0.03939828609873075, 0.08317309868289158, 0.13021178398048505, 0.24745150934904814, 0.2493642020272091, 0.08530433900887147, 0.05312249282724224, 0.059280615314492024, 0.019900519255315885, 0.1281574449967593, 0.02242795511847362, 0.014160322389216162, 0.016541970762773417, 0.06013143196469173, 0.08038987420150079, 0.03674795800179709, 0.038622014471911825, 0.016903951436688658, 0.024199958861572668, 0.02184719302022131, 0.016624434501864016, 0.03446880393312313, 0.12404733468429185, 0.017861245869426057, 0.013874135402147658, 0.022039418545318767, 0.07820429382263683, 0.02351847248064587, 0.04134899158088956, 0.013528759354812792, 0.044991812319494784, 0.0398099071753677, 0.05700706075003836, 0.04576155304675922, 0.015675468821427785, 0.022019733078195713, 0.03614056207879912, 0.006765367661500932, 0.02386642841884168, 0.04348187205323484, 0.039511211289209314, 0.026488920411793515, 0.04159609707130585, 0.03583539837563876, 0.04422836129378993, 0.05797203826659825, 0.04486319070565514, 0.019963406994065735, 0.10303374234354123, 0.040556081003160216, 0.028905262333864812, 0.047583117411704734, 0.022500327504531015, 0.04633303273294587, 0.03367058699950576, 0.029917475694674067, 0.052341571645229124, 0.01909940237965202, 0.03409420118259732, 0.028307582979323342, 0.04198238122626208, 0.07068737686495297, 0.012149949161539553, 0.03563474390830379, 0.02212815157690784, 0.04939392063533887, 0.0586115061014425, 0.06486335070803761, 0.032232475496130064, 0.002656345986906672, 0.05507973663043231, 0.06597602303372696, 0.025718624929140788, 0.05301901517668739, 0.053867928218096495, 0.03608011043979786, 0.036131133092567325, 0.054395502447732724, 0.0015807394152034249, 0.03619261260610074, 0.053256914325174876, 0.06217675385414623, 0.06603668618481606, 0.09060826065251604, 0.02049571612587897, 0.04606239373970311, 0.06584536793525331, 0.045474898506654426, 0.039041339041432366, 0.038137555311550386, 0.012731316110148327, 0.048119426719495095, 0.044379755709087476, 0.04914407661999576, 0.20444519439479336, 0.07746952309389599, 0.0567218830838101, 0.09413119114469737, 0.02010220159718301, 0.3116639668587595, 0.2720152318943292, 1.1583132203668356, 15.089637245982885, 40.97703918814659, 65.74857875704765, 81.51900932192802, 63.33447329699993, 46.702583357691765, 43.121628910303116, 40.653201565146446, 61.069357842206955, 82.98368632793427, 102.24773302674294, 76.41739547252655, 52.5466887652874, 32.26772792637348, 19.487657099962234, 7.878841599449515, 2.822124478407204, 1.0296332440339029, 0.3530345734907314, 0.3920000576181337, 0.6701656454242766, 0.5370244709774852, 0.715333049884066, 1.0625059925951064, 0.056969827201101, 0.11470705736428499, 0.10586447911919095, 0.26785273337736726, 0.8403347642160952, 0.4472996777622029, 0.6219588790554553, 0.34162832773290575, 0.18583101744297892, 0.2433086183737032, 0.4042757739080116, 0.07752512479783036, 0.15714257169747725, 0.34058653051033616, 0.31253168592229486, 0.0570272805634886, 0.11291909744613804, 0.2724602830130607, 0.08162607700796798, 0.312842734856531, 0.4140408046077937, 0.1392647239845246, 0.2624799107434228, 0.1661521554342471, 0.1250859777792357, 0.5322345905005932, 0.27818906935863197, 0.10652734315954149, 0.12201039906358346, 0.035357058222871274, 0.2071708207949996, 0.4315507400315255, 0.006365652488966589, 0.24940626695752144, 0.41604362369980663, 3.144561401568353, 10.975939985364676, 31.45684953778982, 48.26037056744099, 61.940939873456955, 78.50296676158905, 71.47462069988251, 44.05312992632389, 32.67485328018665, 37.79641605913639, 59.25467401742935, 75.0857113301754, 66.84380918741226, 51.10096514225006, 17.62399770319462, 0.9823831357061863, 0.32207246928010136, 0.15808400086825714, 0.2321041774121113, 0.029061621717119124, 0.1327684530406259, 0.06976053831749596, 0.020935356988047715, 0.0466800980939297, 0.01915897457365645, 0.057310309712192975, 0.0407710960280383, 0.08012367325136438, 0.06424366481951438, 0.053044864180264995, 0.05277239208226092, 0.06254046558751725, 0.059649826362146996, 0.024703498638700694, 0.028456164654926397, 0.056116980777005665, 0.019156876151100732, 0.0817591515078675, 0.025262931412726175, 0.12327985008596443, 0.03175293677486479, 0.08878795051714405, 0.01177017271402292, 0.028820635234296788, 0.035333443083800375, 0.029790577718813438, 0.06738674186635762, 0.020588367697200738, 0.0362075594603084, 0.037751178388134576, 0.04673629351600539, 0.04118449454836082, 0.06704490864649415, 0.043652376771206036, 0.025108698282565456, 0.036211923288647085, 0.023755271395202726, 0.031093189754756168, 0.026756577826745342, 0.07061021577101201, 0.06644630717346445, 0.02511934068024857, 0.02675834413821576, 0.15373042901046574, 0.1099293926381506, 0.12987899011932313, 0.11506531431223266, 0.16655052546411753, 0.1170914368412923, 0.21322754735592753, 0.15281172440154478, 0.20466696296352893, 0.18752885836875066, 0.14531956549035385, 0.07396962886559777, 0.12005746713839471, 0.1391250517917797, 0.15617590950569138, 0.17526908341096714, 0.10763729180325754, 0.13630397035740316, 0.2071771290502511, 0.20022099371999502, 0.1770002319244668, 0.12714040582068264, 0.14240231656003743, 0.08724014958715998, 0.14803840866079554, 0.08617659259471111, 0.3014274942688644, 0.13927419378887862, 0.1026382295822259, 0.09095544475712813, 0.18114877806510776, 0.08169284803443588, 0.08280272988486104, 0.1965803882922046, 0.13067823863821104, 0.16393123398302123, 0.19058076257351786, 0.11164039926370606, 0.2182931950665079, 0.19326788635225967, 0.12240606767591089, 0.11763630682253279, 0.1817679073428735, 0.19302125583635643, 0.10159121506148949, 0.10071131735458039, 0.3414388722740114, 0.252964241662994, 0.1422981487121433, 0.22453467187006027, 0.10893066966673359, 0.31903168244753033, 0.30014847696293145, 0.7654703501611948, 13.281889948993921, 47.2912135720253, 75.57611301541328, 98.67797657847404, 91.31651759147644, 76.01058170199394, 66.03525817394257, 48.13937745988369, 64.0173764526844, 80.44823437929153, 104.96437445282936, 101.04448199272156, 86.7679488658905, 66.68465852737427, 49.054003581404686, 22.49432746320963, 8.828460518270731, 4.46290897205472, 3.854327453300357, 1.207277155481279, 1.23758444795385, 1.1638346803374588, 1.0214825626462698, 1.7273123818449676, 1.4878519624471664, 0.4366230819141492, 0.3060868161264807, 0.7309534179512411, 1.9012801093049347, 0.4369630746077746, 0.6509213405661285, 0.3217111621052027, 1.4197942893952131, 1.4815338514745235, 0.858347222674638, 0.2184988887165673, 0.3649842494633049, 1.0537304822355509, 0.834089502459392, 0.3703842347022146, 0.7856936368625611, 0.62045659404248, 0.6395205273292959, 0.630019255913794, 1.174833308905363, 0.736401256872341, 0.7308301620651037, 0.7144329138100147, 0.6810508738271892, 0.901031163521111, 0.6306568498257548, 0.08559863024856895, 0.9463848173618317, 0.10002743569202721, 0.3075066930614412, 0.8023940969724208, 0.13281587627716362, 0.4979754803935066, 1.880596037954092, 6.37115802615881, 24.457304030656815, 53.52970361709595, 77.36700251698494, 81.69129207730293, 79.23776373267174, 72.9278527200222, 47.6921908557415, 56.8433728069067, 63.336209803819656, 81.8565984070301, 86.2905652821064, 79.89575922489166, 60.571747943758965, 16.42455216497183, 0.8507196069695055, 0.41620461037382483, 0.30437868903391063, 0.41786583373323083, 0.32764374220278114, 0.2674796408973634, 0.22318716917652637, 0.13232374330982566, 0.10827282996615395, 0.3130638651782647, 0.14247267215978354, 0.10162154663703404, 0.22986226802458987, 0.16387481591664255, 0.13597509503597394, 0.22331786138238385, 0.1483054185518995, 0.16280542564345524, 0.0789402519876603, 0.13769148965366185, 0.10951333722914569, 0.1592034415807575, 0.23696294403634965, 0.10807599755935371, 0.31252429413143545, 0.1648014466627501, 0.1732328231446445, 0.1041109771176707, 0.1197379057703074, 0.12700526072876528, 0.09786908471141942, 0.16833565779961646, 0.16429304581834003, 0.15518906089710072, 0.11809526578872465, 0.13768489938229322, 0.1911788445431739, 0.1200853347836528, 0.11408761638449505, 0.12770797067787498, 0.12844557641074061, 0.13249572861241177, 0.06527240024297498, 0.12007855155388825, 0.17670289787929505, 0.24324075639015064, 0.16871106578037143, 0.11670429550576955], [0.009371337127959123, 0.03864834587147925, 0.061681377701461315, 0.010107381567650009, 0.08065194881055504, 0.028951275489816908, 0.015519947137363488, 0.06553478655405343, 0.02920679693488637, 0.045619602460647, 0.04818804569367785, 0.03963831521105021, 0.029600020170619246, 0.03347166915773414, 0.010075238224089844, 0.03605459540267475, 0.034745424636639655, 0.023258700384758413, 0.03148950774630066, 0.027610192373686004, 0.0917128509900067, 0.059089705246151425, 0.08223201832151972, 0.04503464537265245, 0.029670023250218946, 0.07337988863582723, 0.008336136670550331, 0.03213436357327737, 0.031747786269988865, 0.08066789756412618, 0.027933212149946485, 0.02133539685019059, 0.04739778829389252, 0.1439119636779651, 0.07314943693927489, 0.07627838349435478, 0.016945136922004167, 0.04091286478796974, 0.0259520916006295, 0.03517394441587385, 0.06654189579421654, 0.13088734616758302, 0.09025948093039915, 0.04180645883025136, 0.07956736677442677, 0.08793639543000609, 0.05910509738896508, 0.03468923663604073, 0.08714254974620417, 0.12026182492263615, 0.1003887206024956, 0.0984460896870587, 0.026502026739763096, 0.1132900822267402, 0.3492599807213992, 0.42705670930445194, 1.9894447596743703, 6.900580767542124, 19.646796360611916, 41.150560677051544, 59.936832413077354, 57.22259245812893, 39.19987455010414, 27.432080805301666, 30.406990572810173, 49.37218330800533, 59.26065869629383, 77.67585754394531, 87.42461442947388, 76.85986652970314, 60.62367595732212, 43.58554981648922, 38.18716809153557, 34.33838501572609, 28.30765452235937, 20.95712374895811, 19.025653190910816, 12.294630724936724, 8.297652751207352, 4.397032856941223, 1.0488632996566594, 0.5047202075365931, 0.5779150268062949, 1.1306045134551823, 1.159086360130459, 0.4415236314525828, 0.07130338170100003, 0.22675793850794435, 0.29173391754738986, 0.36385185085237026, 0.1534093907685019, 0.5672754195984453, 0.5579883616883308, 0.12429237700416707, 0.19808124838164076, 0.15591433213558048, 0.31346604984719306, 0.28535919554997236, 0.2081241094856523, 0.3772542957449332, 0.10876485903281718, 0.3054740693187341, 0.1137162531085778, 1.5198505204170942, 0.8689263300038874, 4.569365959614515, 5.2774223405867815, 4.601142704486847, 5.5467243399471045, 4.710849467664957, 7.482122462242842, 8.157615065574646, 15.724740866571665, 23.901967629790306, 42.92921103537083, 33.870117142796516, 52.42058493196964, 52.70696796476841, 36.96704216301441, 38.50795067846775, 44.750647097826004, 65.13083830475807, 65.8856450021267, 62.46721923351288, 42.5690321624279, 15.052657630294561, 0.29081024054903537, 0.05635295405227225, 0.1373732864158228, 0.1851793672540225, 0.03309486222860869, 0.1857920695329085, 0.12230463835294358, 0.11254711818764918, 0.05640487099299207, 0.02979795837745769, 0.04030666001199279, 0.046803201839793473, 0.04571354351355694, 0.015291168056137394, 0.023982292514119763, 0.017892575633595698, 0.09637172755901702, 0.0727994846238289, 0.05913699489610735, 0.035737791113206185, 0.03512243565637618, 0.021228822588454932, 0.014299540944193723, 0.07396912420517765, 0.02444649660901632, 0.07982486233231612, 0.0355729489820078, 0.03210309689166024, 0.05682425122358836, 0.11794120335252956, 0.01846511659095995, 0.05893515670322813, 0.03262217724113725, 0.07196479113190435, 0.05422895337687805, 0.07276233271113597, 0.05884811020223424, 0.014983180481067393, 0.04366369823401328, 0.03576215953216888, 0.08417455275775865, 0.05687646502337884, 0.03413713813642971, 0.029353207828535233, 0.02608772094390588, 0.03368783451151103, 0.023078748126863502, 0.12308262434089556, 0.020422451307240408, 0.04827950426260941, 0.051306368404766545, 0.026118037676496897, 0.012396226229611784, 0.060801450308645144, 0.07650307612493634, 0.03188991868228186, 0.03954510517360177, 0.02293627618200844, 0.03519158155540936, 0.056041734424070455, 0.09082296397536993, 0.03145153204968665, 0.03111904617981054, 0.010929480813501868, 0.045209198506199755, 0.06261195667320862, 0.06566084775840864, 0.1073078450281173, 0.04812331928405911, 0.0661404310085345, 0.12525646394351497, 0.05958125191682484, 0.04267378455551807, 0.06805411074310541, 0.06445777442422695, 0.10369351904955693, 0.011843139745906228, 0.032969539461191744, 0.03636816763901152, 0.029745735300821252, 0.061696491538896225, 0.10103775101015344, 0.06507792786578648, 0.02738992294325726, 0.01948494067619322, 0.09029197957715951, 0.03127322364889551, 0.055480433293269016, 0.03394854356884025, 0.018382320740784053, 0.016714503399271052, 0.05451827964861877, 0.09595090014045127, 0.008689962996868417, 0.08094554985291325, 0.01814013197872555, 0.03564221733540762, 0.02264675324113341, 0.032179159607039765, 0.2482445683563128, 0.0454697480017785, 0.03094745236012386, 0.05543608254811261, 0.06989795438130386, 0.6668196874670684, 1.2374069262295961, 9.094845224171877, 29.170525521039963, 52.412715554237366, 77.05408930778503, 68.81863921880722, 46.31867855787277, 32.93115332722664, 34.689296185970306, 53.06868955492973, 79.30769518017769, 83.78843754529953, 90.4333233833313, 81.10869213938713, 54.29741822183132, 34.96420003473759, 20.599678829312325, 10.130531899631023, 4.2570018209517, 3.567968406714499, 1.7597827082499862, 4.867598656564951, 3.0355120031163096, 0.8420295920222998, 0.9825934306718409, 0.18381963396677747, 0.6433367694262415, 0.44153114198707044, 0.06137488555395976, 0.7288860913831741, 0.3789326181868091, 0.16499338089488447, 0.1648273624596186, 0.10542496442212723, 0.35582504875492305, 0.29080032545607537, 0.42705724365077913, 0.1925369302625768, 0.09241636988008395, 0.2999996318249032, 0.242421351140365, 0.435578731703572, 0.43575836112722754, 0.3307596640661359, 0.19395702984184027, 0.11358204312273301, 0.06616840255446732, 0.1174349695793353, 1.089514943305403, 2.3734120186418295, 0.9609648725017905, 1.2247411371208727, 0.6275781244039536, 3.2832242734730244, 4.377249218523502, 7.717042006552219, 14.70008784905076, 25.216695182025433, 42.63338550925255, 69.34615731239319, 67.3130764067173, 79.28315609693527, 72.03044727444649, 51.37887082993984, 42.38493584096432, 27.730845473706722, 51.25038452446461, 71.1014199256897, 75.52008882164955, 53.72013799846172, 23.679352775216103, 2.2189742932096124, 0.08735637733479962, 0.12759786564856768, 0.20176123216515407, 0.10300282447133213, 0.20347838377347216, 0.040275474966620095, 0.14435398683417588, 0.04589469805068802, 0.10313987688277848, 0.032113219785969704, 0.02524859311961336, 0.07839134472305886, 0.00658371356621501, 0.021265147006488405, 0.0261188336298801, 0.048785789986141026, 0.028424538031686097, 0.025781601725611836, 0.037473522388609126, 0.025650364041212015, 0.05219359853072092, 0.0315480594872497, 0.017140416384791024, 0.09217852639267221, 0.06136957919807173, 0.0498577109829057, 0.04146865918301046, 0.05698570916138124, 0.05830679881910328, 0.06486091646365821, 0.004218896174279507, 0.05425468734756578, 0.032380823395214975, 0.034527949392213486, 0.04171558655798435, 0.08746156192501076, 0.004628978686014307, 0.03235077383578755, 0.06443902777391486, 0.04257631087966729, 0.017194055108120665, 0.03308239043690264, 0.010822118019859772, 0.047906894178595394, 0.018813387941918336, 0.018292424392711837, 0.05058507878857199, 0.04684168590756599, 0.026578445686027408, 0.10670352159650065, 0.2006658518803306, 0.11306879605399445, 0.10345946051529609, 0.12149907415732741, 0.13209510245360434, 0.1211105746915564, 0.1246667088707909, 0.1315945090027526, 0.13614004477858543, 0.24128623626893386, 0.14770874666282907, 0.16746560839237645, 0.15536456397967413, 0.141310780600179, 0.14507682382827625, 0.17519414133857936, 0.1286874571815133, 0.24435725819785148, 0.2551734074950218, 0.21641967294272035, 0.0834943373047281, 0.18265176069689915, 0.18346343276789412, 0.1161349198082462, 0.17011802934575826, 0.09017540302011184, 0.06741823119227774, 0.17253884085221216, 0.22386329539585859, 0.2242574648698792, 0.2247159043326974, 0.19181225274223834, 0.1866135824820958, 0.13155076681869105, 0.31099552928935736, 0.18225296022137627, 0.20644382777391002, 0.13663201447343454, 0.16697751270839944, 0.20177312137093395, 0.29822955024428666, 0.13109207502566278, 0.1805080522899516, 0.192699950421229, 0.18617904017446563, 0.14018791116541252, 0.11310004789265804, 0.1417152362409979, 0.30162419308908284, 0.21205856086453423, 0.2693309431197122, 0.14269892330048606, 0.25102946266997606, 0.7755434315185994, 0.9767105150967836, 8.14092256128788, 34.664255529642105, 63.63762483000755, 98.00060212612152, 99.32549983263016, 80.52561342716217, 56.46338179707527, 45.38697995245457, 50.610080882906914, 74.49894681572914, 81.56097427010536, 100.17521783709526, 106.74638003110886, 99.80735957622528, 86.12484857439995, 64.7296330332756, 53.39463986456394, 46.350384056568146, 39.543049335479736, 30.91394416987896, 27.719983756542206, 15.485620647668839, 11.910709775984287, 7.482994990423322, 0.7165450660977513, 1.1485421634279191, 0.7799628318753093, 1.4472162304446101, 1.624936731532216, 0.3893790295114741, 0.2287180395796895, 0.37467672780621797, 0.5665538739413023, 0.8482405368704349, 0.9728748584166169, 1.4616059395484626, 1.5173865901306272, 0.734985654707998, 0.6600311142392457, 0.35877018759492785, 0.7351035077590495, 0.4966344789136201, 1.0953807597979903, 0.5962444713804871, 0.5659715551882982, 0.3941919462522492, 0.12678604514803737, 1.6483283950947225, 3.2132154051214457, 6.536850985139608, 6.355620184913278, 7.606810871511698, 8.54278614744544, 11.023258846253157, 18.22045359760523, 25.074810795485973, 42.86217123270035, 63.94036218523979, 86.80322617292404, 64.6480818092823, 78.94251957535744, 77.8452980518341, 60.41957750916481, 61.889171451330185, 61.42884895205498, 80.96258997917175, 84.0054439008236, 87.17554539442062, 60.16537494957447, 21.82811301201582, 1.3796906475909054, 0.15664619364542887, 0.27925218106247485, 0.24984624178614467, 0.25168979598674923, 0.30317261000163853, 0.20246055792085826, 0.20448467665119097, 0.22814569529145956, 0.1835171494167298, 0.11462910217233002, 0.10115919605595991, 0.11528833711054176, 0.05877995878108777, 0.09982233576010913, 0.202551708498504, 0.18524371145758778, 0.14348877622978762, 0.15668892650865018, 0.11010757487383671, 0.12646438350202516, 0.23321324290009215, 0.12573958723805845, 0.1130781471147202, 0.17085900442907587, 0.15010647737653926, 0.11894552953890525, 0.19327805377542973, 0.38652199844364077, 0.2834154217271134, 0.22707284661009908, 0.09261936211260036, 0.13997087749885395, 0.12510683212894946, 0.13639046024763957, 0.18278800416737795, 0.18642034207005054, 0.14230687636882067, 0.16733237804146484, 0.08621270550065674, 0.15140970353968441, 0.16901334252906963, 0.2119530423078686, 0.26173292426392436, 0.08844597628922202, 0.1181512905168347, 0.16598389571299776, 0.31500309705734253, 0.13610977999633178, 0.12246596641489305], [0.048688004608266056, 0.035249049760750495, 0.004543662780633895, 0.0735423447622452, 0.03413332720811013, 0.03822616403340362, 0.06420249788789079, 0.07627976388903335, 0.08226627585827373, 0.0204237148136599, 0.08721366975805722, 0.08516268528182991, 0.014549060269928304, 0.053602688349201344, 0.059925404348177835, 0.02041114839812508, 0.06357098958687857, 0.01449069499358302, 0.03748596449440811, 0.09252715768525377, 0.0633961841231212, 0.041498363643768243, 0.0670243363128975, 0.02225947089755209, 0.037623647731379606, 0.03217711127945222, 0.019214589265175164, 0.07137472435715608, 0.0882332248147577, 0.02577867024228908, 0.08008960125152953, 0.08045884198509157, 0.03320538286061492, 0.0478799356642412, 0.031141900617512874, 0.031784748935024254, 0.048171480957535096, 0.03517830453347415, 0.012248549046489643, 0.13614384457468987, 0.0011807225132542953, 0.023420846664521378, 0.06253534476854838, 0.033707200855133124, 0.03666889329906553, 0.05441368506581057, 0.1105280163756106, 0.0753157066355925, 0.082730941940099, 0.04168027146079112, 0.04380993472295813, 0.1190217629482504, 0.08194684807676822, 0.050353502738289535, 0.008051459954003803, 0.32068661239463836, 0.32787832024041563, 0.7215105090290308, 1.1849050247110426, 3.9143625693395734, 27.034278251230717, 45.67544147372246, 64.50125008821487, 59.10812348127365, 43.209635987877846, 32.327498719096184, 21.9166349619627, 35.06798766553402, 39.77203644812107, 69.21917572617531, 73.3240194618702, 80.72637185454369, 82.02625930309296, 87.32553854584694, 68.51606905460358, 66.37569710612297, 48.65703888237476, 45.453958958387375, 32.209325060248375, 17.14921697974205, 12.64840504154563, 13.145597912371159, 16.22909065335989, 21.2091813236475, 16.314477771520615, 10.784400813281536, 6.450996492058039, 5.003725402057171, 3.128522699698806, 1.28137840423733, 1.0293031367473304, 1.2759712943807244, 1.518636723048985, 1.0772805497981608, 1.3519574794918299, 0.7526769710239023, 1.2636970030143857, 1.372184744104743, 1.5196870104409754, 2.8065412770956755, 2.413556152023375, 3.7587298080325127, 5.571745997294784, 11.144825723022223, 13.607089798897505, 15.391122568398714, 24.25935935229063, 30.561159700155258, 27.829984053969383, 27.354593463242054, 31.14531185477972, 34.452363699674606, 38.06361012160778, 32.24899873137474, 28.91570169478655, 31.95639543235302, 37.11311012506485, 43.06146293878555, 46.674928441643715, 62.58507750928402, 75.32342657446861, 67.0931214094162, 52.96989485621452, 18.528309278190136, 2.4124865094199777, 0.10180251934798434, 0.07663870361284353, 0.08706490625627339, 0.02925243716163095, 0.1895230685477145, 0.039387354263453744, 0.2383248443948105, 0.06245458425837569, 0.10857852059416473, 0.04214344211504795, 0.0841079895326402, 0.01193560670799343, 0.04024395966553129, 0.016428407325292937, 0.03572454377717804, 0.015148414095165208, 0.07009022257989272, 0.06827904828242026, 0.055980718752834946, 0.045586521227960475, 0.03554918912413996, 0.0818148348480463, 0.03281980003521312, 0.08291500198538415, 0.024469482777931262, 0.031787012485438026, 0.017060572426998988, 0.02129792766936589, 0.027705094507837202, 0.020363057228678372, 0.0431026494334219, 0.016357587883248925, 0.050286356927244924, 0.11017928860383108, 0.04210674291243777, 0.0335134186752839, 0.06128439177700784, 0.02709006002987735, 0.0098759279717342, 0.04404339582833927, 0.043600482094916515, 0.026393691732664593, 0.04829542704101186, 0.07059221126837656, 0.009254244778276188, 0.030706347133673262, 0.061349867755779997, 0.00901987175893737, 0.047585113788954914, 0.04535273357760161, 0.003574080933503865, 0.015949415937939193, 0.05393372703110799, 0.04174571775365621, 0.05154372949618846, 0.043504659697646275, 0.02566161685535917, 0.0378042233933229, 0.04770714513142593, 0.024282812228193507, 0.04274570237612352, 0.06136787967989221, 0.07734712067758664, 0.04085816108272411, 0.030714770509803202, 0.04784194883541204, 0.05542367012822069, 0.0017656247518971213, 0.030495217251882423, 0.06574830244062468, 0.015442815729329595, 0.06850555175333284, 0.03390761783521157, 0.025402588762517553, 0.012107914844818879, 0.06405520383850671, 0.04985184430552181, 0.07774625511956401, 0.06397802790161222, 0.04320807151088957, 0.04490326296945568, 0.05813809751998633, 0.07439208900905214, 0.010778999239846598, 0.047694914537714794, 0.03513077368552331, 0.025186492057400756, 0.012058821776008699, 0.05282101388729643, 0.06837300417828374, 0.015622013779648114, 0.05344115248590242, 0.03291567809355911, 0.0584918162348913, 0.03591027365473565, 0.0575993242819095, 0.05407097611168865, 0.10110692659509368, 0.10990191833116114, 0.05449647163914051, 0.0662027120415587, 0.07095812718034722, 0.26591121568344533, 0.14587470679543912, 0.10573677034699358, 0.1278249331517145, 0.6047519179992378, 1.211002974305302, 1.2867111805826426, 0.8809192583430558, 3.4500355599448085, 57.16354362666607, 81.20516896247864, 66.78187251091003, 48.456242457032204, 31.68326608836651, 35.79208821058273, 39.42383073270321, 56.76143780350685, 83.57290551066399, 96.70734152197838, 87.98397481441498, 75.61177030205727, 72.46387481689453, 59.97959531843662, 48.494874984025955, 40.845714434981346, 32.25591816008091, 26.56021948903799, 19.588021114468575, 9.7478012368083, 5.859595751389861, 6.714077750220895, 3.6762345721945167, 5.559014780446887, 3.9811959955841303, 3.7580220960080624, 1.9181785150431097, 1.6917364345863461, 0.7858867140021175, 0.8940218458883464, 0.5548263969831169, 0.5171815201174468, 0.48591421509627253, 0.49113893473986536, 0.5863762821536511, 0.7686452579218894, 1.2812338932417333, 1.1860297643579543, 0.8590571314562112, 0.3307191131170839, 0.8913458988536149, 1.3585989293642342, 3.605224695056677, 5.427055461332202, 6.636011889204383, 11.26650184392929, 18.942384459078312, 26.4643145352602, 37.69848771393299, 41.27070263028145, 57.5432800501585, 63.60913395881653, 69.0082186460495, 60.954698994755745, 62.69102722406387, 44.126469790935516, 57.01812542974949, 52.771260514855385, 37.921858727931976, 50.32109498977661, 78.61455917358398, 78.89982506632805, 66.30087152123451, 29.846404753625393, 5.17290847375989, 0.061966963548911735, 0.12692769145360216, 0.05030667693063151, 0.09320657161879353, 0.21154949208721519, 0.04947487781464588, 0.12814971181796864, 0.019038106547668576, 0.12857859896030277, 0.051084956066915765, 0.10186021390836686, 0.01307398424614803, 0.037769550253869966, 0.054670635145157576, 0.027691806353686843, 0.038223473748075776, 0.022196046957105864, 0.02104649174725637, 0.044197554743732326, 0.056745761685306206, 0.019782109593506902, 0.011050924003939144, 0.04831147969525773, 0.04644958702556323, 0.03443092471570708, 0.043690393285942264, 0.018148152739740908, 0.053431048145284876, 0.055748278100509197, 0.056757728816592135, 0.048454792122356594, 0.03660005910205655, 0.017321962404821534, 0.07775300124194473, 0.07463181755156256, 0.07605199876707047, 0.05423006288765464, 0.07454674516338855, 0.03039957668079296, 0.027652719290927052, 0.03273083879321348, 0.004905216719635064, 0.05452423538372386, 0.035277132628834806, 0.023157660689321347, 0.09757844483829103, 0.08819600610877387, 0.062409996025962755, 0.03821345104370266, 0.05155073908099439, 0.039430755059584044, 0.12776014365954325, 0.09683084979769774, 0.10227744933217764, 0.18771105562336743, 0.11459710818598978, 0.21893049211939797, 0.22207235946552828, 0.15359442302724347, 0.1624259803793393, 0.1127904313034378, 0.2398238639580086, 0.1263818863662891, 0.10433638221002184, 0.1398534103645943, 0.16217045893426985, 0.09581911697750911, 0.14128986687865108, 0.0962188006087672, 0.15492960606934503, 0.12103126879082993, 0.17323835956631228, 0.14051340229343623, 0.19171785155776888, 0.09261051571229473, 0.15856289392104372, 0.12546776823000982, 0.1494669687235728, 0.1365101835108362, 0.19955619267420843, 0.291300414246507, 0.2386966603808105, 0.16574615612626076, 0.12200662153190933, 0.14109665615251288, 0.09298656194005162, 0.29261401563417166, 0.12160068901721388, 0.17451219668146223, 0.12247161415871233, 0.2192440049839206, 0.12158859201008454, 0.0968890415970236, 0.2528434793930501, 0.06643482614890672, 0.12317827975493856, 0.13212086982093751, 0.24991398502606899, 0.21190409024711698, 0.14764881081646308, 0.16745370434364304, 0.10470886612893082, 0.32262997061479837, 0.32588247733656317, 0.31982845219317824, 0.16983932320727035, 0.6491949269548059, 1.085833297111094, 0.916799723636359, 1.3956350670196116, 3.7531438702717423, 72.474225461483, 110.96484526991844, 101.64037361741066, 84.24819767475128, 65.52786380052567, 51.88755713403225, 39.776011034846306, 54.40481945872307, 66.87935248017311, 94.6400548517704, 94.74530920386314, 101.92551791667938, 100.63793420791626, 105.69166302680969, 89.28154438734055, 92.83323660492897, 69.05858114361763, 67.57742062211037, 57.47676081955433, 42.97116458415985, 32.70262598991394, 32.11317501962185, 32.6550829410553, 30.722535140812397, 22.884843908250332, 14.344133399426937, 10.595011375844479, 6.653550323098898, 4.0807682275772095, 1.6677316976711154, 1.276491153985262, 1.1796310264617205, 1.5310240583494306, 1.825000864919275, 2.625202895142138, 1.82331838645041, 3.439487563446164, 3.482328839600086, 5.344274528324604, 5.725575042888522, 8.16676402464509, 12.785199601203203, 22.055359818041325, 31.608387306332588, 39.1136609762907, 40.54196633398533, 47.51358523964882, 55.577850714325905, 58.95436853170395, 65.98453089594841, 73.05792734026909, 73.26041087508202, 76.26069948077202, 60.36015249788761, 57.007926777005196, 56.671933606266975, 61.600238755345345, 64.31806951761246, 63.569403290748596, 73.84000897407532, 93.74715596437454, 87.92982012033463, 76.18907332420349, 33.17306734621525, 4.045033995062113, 0.1780328858876601, 0.28465982526540756, 0.20889304869342595, 0.10353393503464758, 0.42453319940250367, 0.2026261607534252, 0.3490867931395769, 0.12112554381019436, 0.21128171036252752, 0.14244978432543576, 0.2529197128023952, 0.05855081326444633, 0.21339971077395603, 0.12278396185138263, 0.25627098453696817, 0.10918287371168844, 0.09739227709360421, 0.09609129963791929, 0.24876733717974275, 0.12912297912407666, 0.11768285432481207, 0.19945687847211957, 0.14008666737936437, 0.1651250824215822, 0.15652210655389354, 0.157764402392786, 0.1811694839852862, 0.09055200585862622, 0.16547604405786842, 0.09621540899388492, 0.10804437464685179, 0.15630155510734767, 0.17226546333404258, 0.17666090716375038, 0.1559888437623158, 0.15905208798358217, 0.18031329789664596, 0.1595688157249242, 0.06132727306976449, 0.11595669304369949, 0.10738948127254844, 0.24864881619578227, 0.12676164333242923, 0.13738029228989035, 0.10714511430705898, 0.1775645461748354, 0.15269749303115532, 0.1364050805568695, 0.20504964399151504, 0.19331228162627667, 0.11630507200607099], [0.05135147614055313, 0.037089427569299005, 0.05855255360074807, 0.03849551911116578, 0.027703918203769717, 0.06997138247243129, 0.01853402871347498, 0.026420342255732976, 0.06654972545220517, 0.026734432140074205, 0.04073664553288836, 0.023452977948181797, 0.07714293358731084, 0.004358613823569613, 0.020013724606542382, 0.039711431600153446, 0.03551017442077864, 0.029977224148751702, 0.029271380481077358, 0.010690666968002915, 0.047106127967708744, 0.024184396024793386, 0.11281006853096187, 0.10606324853142723, 0.05289759981678799, 0.017099377473641653, 0.06412497314158827, 0.07007717562373728, 0.03820970690867398, 0.030868639987602364, 0.0722752686124295, 0.03704050890519284, 0.03524122752423864, 0.061035946710035205, 0.05443138528789859, 0.04783559976203833, 0.04489085797104053, 0.0058838775839831214, 0.0191661567077972, 0.014793154496146599, 0.035149787508999, 0.006829873282185872, 0.1171447972592432, 0.04917220772767905, 0.001047512107561488, 0.03362812502018642, 0.10629319556755945, 0.07987173637957312, 0.1000848482362926, 0.14327073324238881, 0.04205288154480513, 0.08041279172175564, 0.12285776101634838, 0.1128609872830566, 0.05995440005790442, 0.05095154388982337, 0.1824374432908371, 0.45382466982118785, 0.5910703958943486, 0.9848116210196167, 1.9269086653366685, 7.367615606635809, 17.37148605287075, 37.93754808604717, 53.249035477638245, 65.5375836789608, 61.88016973435879, 56.24748878180981, 43.80012050271034, 43.214856907725334, 55.791030675172806, 52.56802462041378, 70.11550202965736, 61.45242288708687, 72.1601191163063, 54.800716415047646, 50.81197164952755, 49.29269537329674, 41.48625746369362, 33.718687668442726, 26.8734347820282, 25.82762259989977, 33.18606644868851, 46.46896809339523, 50.156609416007996, 42.398440316319466, 44.285358265042305, 42.369979843497276, 38.86413216590881, 35.13259939849377, 30.70351716130972, 29.612800888717175, 22.706120498478413, 18.410914577543736, 10.99760927259922, 6.8859928753226995, 2.107704863883555, 2.561120046302676, 7.355322316288948, 9.76495161652565, 10.476541332900524, 7.427487093955278, 17.165060229599476, 29.454562179744244, 31.50416649878025, 27.247860990464687, 39.99747835099697, 36.75018019974232, 36.0811273008585, 47.400054931640625, 38.282812759280205, 31.54518149793148, 32.2046285122633, 33.6836763471365, 39.463375210762024, 44.278507232666016, 46.44445180892944, 55.50098843872547, 80.92946335673332, 75.73308259248734, 47.99166418612003, 22.0183365046978, 5.275492994114757, 0.032073811744339764, 0.13588946603704244, 0.2300181784084998, 0.015821254455659073, 0.06305206508841366, 0.04621790336386766, 0.14220402954379097, 0.02211581708252197, 0.017632645831326954, 0.03994147882622201, 0.06235215303604491, 0.1171460589102935, 0.07511610601795837, 0.054857815921423025, 0.05584671285760123, 0.07644324417924508, 0.07677290617721155, 0.049489446173538454, 0.09187653166009113, 0.06491754233138636, 0.028870323876617476, 0.045349282590905204, 0.018383265123702586, 0.007290893563549616, 0.04763526070746593, 0.01322987700405065, 0.05571924528339878, 0.06219635397428647, 0.08261381619377062, 0.08068089999142103, 0.07149583543650806, 0.11156756489071995, 0.06541963492054492, 0.033357341308146715, 0.05213722870394122, 0.09859691635938361, 0.02398499764240114, 0.011570297501748428, 0.006819606596764061, 0.03403529692150187, 0.041853288348647766, 0.035219616183894686, 0.060647354475804605, 0.04885188565822318, 0.07230849456391297, 0.07743087204289623, 0.07730115205049515, 0.025590802979422733, 0.03950237231038045, 0.07350249885348603, 0.07179572246968746, 0.026841165963560343, 0.041886877952492796, 0.04146157909417525, 0.04597870916768443, 0.01936215048772283, 0.048886017029872164, 0.03982761481893249, 0.05121415284520481, 0.05607940584013704, 0.04184078687103465, 0.062282947765197605, 0.0654057864448987, 0.04754261841299012, 0.009672904197941534, 0.07326599123189226, 0.04665228239900898, 0.017363736042170785, 0.11152023071190342, 0.02209731534094317, 0.04527095632511191, 0.010974866854667198, 0.004813495152120595, 0.026517700898693874, 0.04295731465390418, 0.007091445550031494, 0.10032717429567128, 0.03904484568920452, 0.02469912367814686, 0.05260651094431523, 0.08467120540444739, 0.11333205067785457, 0.02002472880121786, 0.03456655962509103, 0.03366010787431151, 0.027487411462061573, 0.05951986517175101, 0.021118496770213824, 0.041946988203562796, 0.04104162740986794, 0.089246271236334, 0.07413647850626148, 0.06307939096586779, 0.022051938576623797, 0.013529105381167028, 0.08251919978647493, 0.13438580062938854, 0.017462701434851624, 0.054524042425327934, 0.15608906338457018, 0.07093153602909297, 0.0472303634887794, 0.06776031674235128, 0.05989010038319975, 0.08177069932571612, 0.06507806887384504, 0.2059786199242808, 0.07754997190204449, 0.0534983683610335, 0.3495802322868258, 0.6444787268992513, 1.106165056116879, 2.5368120381608605, 2.370298085734248, 30.25808036327362, 55.15798844397068, 69.02590289711952, 63.70105862617493, 53.47493715584278, 35.01903489232063, 39.77003015577793, 36.804931461811066, 58.97853523492813, 72.86314219236374, 73.34142252802849, 91.6970519721508, 80.37281602621078, 76.66487619280815, 64.2323537170887, 54.5711175352335, 55.26526428759098, 46.15674264729023, 35.1535514742136, 36.39735013246536, 36.51448644697666, 46.63189195096493, 53.94653744995594, 46.03664629161358, 39.845315515995026, 31.758855432271957, 30.17125502228737, 24.01127826422453, 23.72206248342991, 23.45497291535139, 19.51007589697838, 17.27245956659317, 12.458114102482796, 12.592571787536144, 10.133447293192148, 10.64659170806408, 9.42259568721056, 9.66371649876237, 10.148029960691929, 12.725735642015934, 14.746075831353664, 27.983761802315712, 40.27938902378082, 48.39516453444958, 54.3070051074028, 60.092008486390114, 69.02320504188538, 69.36239764094353, 75.3352439403534, 68.64953309297562, 56.93791173398495, 54.821603894233704, 41.07050657272339, 34.13560509681702, 34.54490393400192, 31.661609150469303, 50.69679602980614, 80.84193885326385, 84.28325459361076, 62.450040355324745, 33.81763815879822, 10.148948561400175, 0.0225250521543785, 0.19123340724036098, 0.19841508124954998, 0.08833541854983196, 0.12656457343837246, 0.0402498226321768, 0.07332125896937214, 0.028285509652050678, 0.08019567641895264, 0.03745390000403859, 0.10039229775429703, 0.0790678197517991, 0.02432396802760195, 0.028484074973675888, 0.021863893198315054, 0.016695101803634316, 0.028319036173343193, 0.08431322305114008, 0.07606986226164736, 0.03128060059680138, 0.05433969294244889, 0.052762376799364574, 0.05434532584331464, 0.0183904546793201, 0.013792936097161146, 0.09280714773922227, 0.06460565477027558, 0.03982970396464225, 0.024517700112483, 0.07718931039562449, 0.12725054053589702, 0.08726538260816596, 0.03364709060406312, 0.01889360853965627, 0.03686311705678236, 0.08631763776065782, 0.036488269397523254, 0.08905479713575915, 0.049605525491642766, 0.0563077053084271, 0.0482574402121827, 0.014046207907085773, 0.03255790354160126, 0.14670092496089637, 0.08182173682143912, 0.05353215463401284, 0.10442868311656639, 0.08978351936093532, 0.03349911748955492, 0.0556359800248174, 0.04531614569714293, 0.011925366925424896, 0.06525014323415235, 0.15494655672227964, 0.1712516599218361, 0.15464098483789712, 0.1145640603499487, 0.10598415043205023, 0.15127314836718142, 0.1778239119448699, 0.16610347054665908, 0.11130716753541492, 0.23277580621652305, 0.0873048797075171, 0.1718632786651142, 0.11922950492589734, 0.09521397718344815, 0.06286629068199545, 0.23300156753975898, 0.10981686078594066, 0.20603208424290642, 0.1996514102211222, 0.13640515477163717, 0.1117642859753687, 0.10636787788826041, 0.19860768341459334, 0.19206180731998757, 0.16790714173112065, 0.1832213145098649, 0.149258395540528, 0.2794925181660801, 0.2522131585283205, 0.15890836366452277, 0.1857316290261224, 0.20407484786119312, 0.17976912553422153, 0.1495758121018298, 0.10780041586258449, 0.21616887155687436, 0.1761323495884426, 0.13875529897632077, 0.16439589264336973, 0.14305861259344965, 0.12370545693556778, 0.1766026485711336, 0.22951023769564927, 0.2926666784333065, 0.10857947054319084, 0.17737936548655853, 0.24136107444064692, 0.1772289618384093, 0.1929184386972338, 0.2513745316537097, 0.15363294049166143, 0.27450638415757567, 0.35243643214926124, 0.2672937180614099, 0.18454643402947113, 0.2745948184747249, 0.35489311907440424, 1.0017484403215349, 1.0265121865086257, 2.454229169525206, 5.18974157050252, 41.18460685014725, 68.58845517039299, 89.58079352974892, 96.6794890165329, 92.60466367006302, 84.61639031767845, 75.16567423939705, 59.137222319841385, 62.46391341090202, 73.47198352217674, 72.05244049429893, 87.69272804260254, 76.24408677220345, 91.13299503922462, 72.00810447335243, 74.48457598686218, 75.52157074213028, 78.89616966247559, 72.17586547136307, 66.19054064154625, 62.51184403896332, 69.53239291906357, 80.90918764472008, 80.06183311343193, 76.11601084470749, 72.81884416937828, 71.96297809481621, 66.32292553782463, 58.4762591868639, 53.49534586071968, 51.463955864310265, 46.567120626568794, 46.19035944342613, 39.257973432540894, 38.460954800248146, 31.358066238462925, 35.90476356446743, 43.906180411577225, 49.33277182281017, 53.69542792439461, 59.027476608753204, 66.04057788848877, 73.11816930770874, 66.60316050052643, 65.54331377148628, 80.2140985429287, 70.9518675506115, 68.3482776582241, 71.67117655277252, 66.17183804512024, 54.62208040058613, 63.42702113091946, 61.59902282059193, 69.97737184166908, 69.31927755475044, 64.22232985496521, 71.27111881971359, 98.56108725070953, 93.74008074402809, 75.02368345856667, 40.20543359220028, 8.648495525121689, 0.11021428086678497, 0.23054902179865167, 0.3862465429119766, 0.16400435037212446, 0.2559714240487665, 0.1339062990155071, 0.1966653938870877, 0.1587064252817072, 0.1465287318569608, 0.17806377407396212, 0.22064215183490887, 0.24315095652127638, 0.12908713339129463, 0.14759930956643075, 0.2538767270743847, 0.1197110622888431, 0.15699007519287989, 0.221525322413072, 0.14493529626633972, 0.21947942906990647, 0.13682749617146328, 0.1972285652300343, 0.11998074391158298, 0.13283508305903524, 0.1176928510540165, 0.17368875414831564, 0.22235971904592589, 0.08377253878279589, 0.26138453045859933, 0.20029560924740508, 0.2529697632417083, 0.20694842882221565, 0.14684067136840895, 0.11647353952866979, 0.22036436595954, 0.24636175454361364, 0.15393649373436347, 0.2899819740559906, 0.15910200483631343, 0.17488252837210894, 0.11650468746665865, 0.0788175972411409, 0.19846384035190567, 0.24200163694331422, 0.1568868721369654, 0.12555587600218132, 0.21476753347087651, 0.30759545392356813, 0.1416215772042051, 0.21459427167428657, 0.13630959583679214, 0.10538179369177669, 0.10334241640521213], [0.06901563727296889, 0.041155847648042254, 0.1394815943785943, 0.08695131313288584, 0.07384842130704783, 0.05922103198827244, 0.06676492601400241, 0.0546330490760738, 0.04417405834828969, 0.05554938623390626, 0.04661057741031982, 0.08748997875954956, 0.008119705998979043, 0.03295343114587013, 0.16951035882811993, 0.018250583962071687, 0.014702849966852227, 0.03136588078632485, 0.049105470097856596, 0.012368235202302458, 0.034074519426212646, 0.02949277426523622, 0.044962779502384365, 0.028274900651013013, 0.04720298195024952, 0.03390785161172971, 0.0910025266057346, 0.08425179548794404, 0.05530154601729009, 0.011292198068986181, 0.04010192002169788, 0.04860826084041037, 0.04824356576136779, 0.06901870234287344, 0.014282652446127031, 0.014173833187669516, 0.04016876897367183, 0.05975781998131424, 0.042137059645028785, 0.010600850400805939, 0.03019507603312377, 0.01839743272284977, 0.021307065362634603, 0.046422083032666706, 0.03305396247014869, 0.08949315408244729, 0.05964761847280897, 0.06713548777042888, 0.08821671202895232, 0.04590994547470473, 0.016115369435283355, 0.08991415961645544, 0.023801681600161828, 0.00294331779514323, 0.0345126314641675, 0.2095741918310523, 0.06406638058251701, 0.04525479605945293, 0.059342744207242504, 0.36723369907122105, 0.1670945345540531, 0.7136767543852329, 12.986741736531258, 33.32633972167969, 39.945618733763695, 46.48787587881088, 59.357982873916626, 70.58068826794624, 81.84025928378105, 67.71653115749359, 67.56069391965866, 63.50148193538189, 56.33579224348068, 53.17418709397316, 58.179434314370155, 59.30181048810482, 51.27639792859554, 39.9285576492548, 41.83575890958309, 39.114485532045364, 24.76938508450985, 18.330189809203148, 15.278718899935484, 20.34160617738962, 27.796652242541313, 33.55415649712086, 44.621119648218155, 41.86529092490673, 37.773248702287674, 43.83737750351429, 35.44517442584038, 23.943619094789028, 22.786419689655304, 33.738461807370186, 21.054104045033455, 18.954359516501427, 6.862906739115715, 13.251073602586985, 16.393849812448025, 13.335753958672285, 13.74511169269681, 11.357605755329132, 8.528198730200529, 10.199243612587452, 24.079703092575073, 33.94893631339073, 26.092508286237717, 22.707674615085125, 38.94500322639942, 37.61264652013779, 43.99690434336662, 39.9651724845171, 53.07147100567818, 50.8391135931015, 64.05978977680206, 82.23496690392494, 92.2938859462738, 68.67531850934029, 43.3263923227787, 21.28304935991764, 5.980609282851219, 0.2627557225059718, 0.28811716474592686, 0.16133601777255535, 0.09152326194453053, 0.05047952683526091, 0.015991525397112127, 0.033449582842877135, 0.024818635429255664, 0.06692719660350122, 0.02164457557228161, 0.13737992121605203, 0.07685926990234293, 0.04462414493900724, 0.028755404164257925, 0.032258803184959106, 0.02485597287886776, 0.00936154448936577, 0.07013200549408793, 0.013882129260309739, 0.04037904538563453, 0.034328471228946, 0.013405377303570276, 0.061511099338531494, 0.06130808855232317, 0.04612339456798509, 0.09304942184826359, 0.05011205612390768, 0.03061807237827452, 0.011573477604542859, 0.10876023545279168, 0.055251848098123446, 0.040162449586205184, 0.05711803780286573, 0.033840457181213424, 0.0327158956497442, 0.043151916906936094, 0.013082765708531952, 0.09434695573872887, 0.07696027620113455, 0.04046196183480788, 0.021216452842054423, 0.06780184732633643, 0.04927601934468839, 0.04451233668078203, 0.0150387079702341, 0.12507555802585557, 0.12893358303699642, 0.0026375666357125738, 0.06486389247584157, 0.01408991020070971, 0.07465726579539478, 0.07178881307481788, 0.03296770264569204, 0.04582331828714814, 0.047830545736360364, 0.03434653510339558, 0.033704310189932585, 0.026817586076504085, 0.061877141415607184, 0.0752018389175646, 0.017566509341122583, 0.06525294855237007, 0.03275352995842695, 0.08206061931559816, 0.030243141227401793, 0.10649010218912736, 0.07666650446481071, 0.023783074102539103, 0.050637804670259356, 0.0460517290775897, 0.0047230199288605945, 0.06861078087240458, 0.030584286105295178, 0.08112610696116462, 0.01734791716444306, 0.06258410387090407, 0.024194043944589794, 0.06249186975765042, 0.034427098944433965, 0.035851640277542174, 0.0527248575235717, 0.007440947938448517, 0.14596269582398236, 0.06109972317062784, 0.046279542439151555, 0.024792148178676143, 0.011362901550455717, 0.026835612843569834, 0.0807772456028033, 0.05279759912809823, 0.041536202043062076, 0.06807480182033032, 0.09347672821604647, 0.03585606718843337, 0.027141856371599715, 0.009281193088099826, 0.014584154578187736, 0.015553316879959311, 0.023251963539223652, 0.09881868492811918, 0.09807874143007211, 0.09069351115613244, 0.14853003696771339, 0.06113955794717185, 0.05334374560334254, 0.02220778216724284, 0.13497543695848435, 0.0667430178145878, 0.042754192545544356, 0.11679990639095195, 0.17395119240973145, 0.11632101333816536, 0.016402263318013866, 0.11678083319566213, 0.42020606284495443, 0.9830298135057092, 3.732412657700479, 19.833966717123985, 43.22124816477299, 58.35580565035343, 72.31265053153038, 74.93938878178596, 76.08517929911613, 64.13661405444145, 56.14487908780575, 59.5766307413578, 54.42209713160992, 64.04929473996162, 56.68205626308918, 72.7071225643158, 64.27558779716492, 57.5672909617424, 64.2676842212677, 61.190054565668106, 57.517137452960014, 50.1889418810606, 56.71662300825119, 57.08260037004948, 62.149814665317535, 65.21020844578743, 68.60436111688614, 82.47636035084724, 77.07763284444809, 82.09840223193169, 80.89341849088669, 81.89327403903008, 78.2156565785408, 75.60619980096817, 74.09831911325455, 55.699087008833885, 39.90006297826767, 35.58562628924847, 31.65615264326334, 43.383944034576416, 46.700284481048584, 41.50594420731068, 37.18714915215969, 38.43492619693279, 49.873114228248596, 54.90751728415489, 64.82213526964188, 68.07492792606354, 57.6846856623888, 49.31013263761997, 55.75347349047661, 42.17409275472164, 31.766352429986, 43.55887904763222, 45.765067264437675, 59.861440658569336, 80.40160328149796, 99.29960042238235, 84.8851726949215, 64.74775806069374, 37.59874686598778, 10.885297749191523, 0.8535343653056771, 0.3246433282038197, 0.18642259819898754, 0.11960856427322142, 0.0552375172264874, 0.08210183819755912, 0.11262154075666331, 0.04885110269242432, 0.024615286965854466, 0.04468721635930706, 0.09344607009552419, 0.036362657192512415, 0.01828246662626043, 0.0596175132523058, 0.052536593211698346, 0.06288392411079258, 0.023819433772587217, 0.05965875068795867, 0.02157814036763739, 0.04943152154737618, 0.04744392019347288, 0.04684473613451701, 0.0496030838257866, 0.0708090742409695, 0.03431113465921953, 0.025018441992870066, 0.03809069239650853, 0.034162274678237736, 0.044993845804128796, 0.08708850655239075, 0.03599477458919864, 0.06364186468999833, 0.03304653728264384, 0.020837797965214122, 0.015388192732643802, 0.041545382409822196, 0.04951277558575384, 0.07226822563097812, 0.04305628746806178, 0.0234044860189897, 0.047756549902260303, 0.04454024885490071, 0.036075431198696606, 0.06192572240252048, 0.011673990375129506, 0.09331384164397605, 0.04124421888263896, 0.03130180004518479, 0.02146066581190098, 0.061072486350894906, 0.06075351127947215, 0.06024810871167574, 0.011777015315601602, 0.04403259386890568, 0.046353263678611256, 0.11142876843223348, 0.16122874774737284, 0.2398232850828208, 0.18767035624478012, 0.17515145300421864, 0.17942619393579662, 0.18940947542432696, 0.13031470502028242, 0.2553184231510386, 0.08761776174651459, 0.2258153515867889, 0.1300075597828254, 0.2334570829407312, 0.15837456652661785, 0.2796007232973352, 0.09460385015700012, 0.13137017260305583, 0.12677703547524288, 0.23401284764986485, 0.14486523752566427, 0.15509976568864658, 0.19005282840225846, 0.14600815979065374, 0.15849274612264708, 0.17872004042146727, 0.0717012544919271, 0.20108243421418592, 0.27848367230035365, 0.10590962396236137, 0.1714250404620543, 0.08472210931358859, 0.16467734472826123, 0.16930318088270724, 0.16163093241630122, 0.14904447889421135, 0.15746867138659582, 0.1621598907513544, 0.18909679376520216, 0.11936590424738824, 0.10335696249967441, 0.12198676908155903, 0.09582166996551678, 0.11883540966664441, 0.17148230457678437, 0.19618195889052004, 0.23319292289670557, 0.22049194114515558, 0.1697323055122979, 0.3221500385552645, 0.27535893372260034, 0.11103310724138282, 0.23581334244227037, 0.177656973246485, 0.14285176119301468, 0.19977447314886376, 0.24701940128579736, 0.20565968938171864, 0.11782454515923746, 0.1410405052592978, 0.48471751681063324, 0.7887378078885376, 2.8419024171307683, 19.5354338362813, 53.51089842617512, 75.09717911481857, 86.19832143187523, 99.129848331213, 107.94979065656662, 107.86435604095459, 88.26396659016609, 87.45474681258202, 80.2231116592884, 81.31801530718803, 69.95871484279633, 83.50352883338928, 86.32134363055229, 79.58042934536934, 69.79900941252708, 77.80649453401566, 77.02733874320984, 61.583876833319664, 52.65458397567272, 44.99187335371971, 47.28039935231209, 55.02545155584812, 56.72082178294659, 76.45065888762474, 71.14910736680031, 66.80672317743301, 71.2251640856266, 61.80715665221214, 50.59548206627369, 54.88547846674919, 64.85211566090584, 65.8095882833004, 67.46676295995712, 52.79755890369415, 65.41532143950462, 54.04815159738064, 52.503557279706, 58.3713848143816, 50.9748575091362, 37.46090546250343, 36.95053584873676, 61.70893952250481, 78.78626435995102, 63.380998000502586, 54.456713274121284, 67.03528091311455, 72.10148826241493, 73.00993591547012, 68.52426141500473, 75.8260104060173, 73.2586781680584, 78.06511625647545, 102.19554662704468, 115.68062022328377, 100.19296288490295, 74.63552668690681, 44.635722264647484, 10.081429034471512, 0.6339326896704733, 0.4097000719048083, 0.231518815853633, 0.13272520067403093, 0.14902819617418572, 0.1325256668496877, 0.249645386938937, 0.15950313565554097, 0.13830529031110927, 0.1414558110991493, 0.2761633327463642, 0.2092620445182547, 0.13984392571728677, 0.1772014726884663, 0.15039158082799986, 0.13098792202072218, 0.07194125762907788, 0.14554635097738355, 0.10433755480335094, 0.19429487030720338, 0.1504971884423867, 0.12863520998507738, 0.13253124780021608, 0.19834668491967022, 0.18202613020548597, 0.14919752458808944, 0.11390673273126595, 0.12383673543808982, 0.16633374412776902, 0.25054353405721486, 0.1935081195551902, 0.1064920169301331, 0.11347063191351481, 0.0871452437422704, 0.05733240344852675, 0.11424370488384739, 0.11231172378757037, 0.12783621379639953, 0.11716740307747386, 0.1799462761846371, 0.08279582048999146, 0.16138537059305236, 0.08935228703194298, 0.23022767185466364, 0.07000348035944626, 0.24603535799542442, 0.22931643325136974, 0.13514642778318375, 0.15779506793478504, 0.11558680664165877, 0.15743717463919893, 0.15770670783240348, 0.07762615336105227, 0.2602374670095742, 0.26449549477547407], [0.03355709035531618, 0.03980402194429189, 0.06723091311869211, 0.029652701523446012, 0.030985749035608023, 0.02627122994454112, 0.016702551110938657, 0.03219932747015264, 0.08551251143217087, 0.06837022112449631, 0.01769090256857453, 0.056900017079897225, 0.0255291509165545, 0.01708438609057339, 0.07731214325758629, 0.09145796779193915, 0.071157007914735, 0.020036612440890167, 0.04985862753528636, 0.09836274650297128, 0.026806821224454325, 0.04406059881148394, 0.06348357201204635, 0.004395966579977539, 0.0698604536592029, 0.011683320099109551, 0.037382416339823976, 0.022872278932482004, 0.07187985233031213, 0.068391936365515, 0.0780827522976324, 0.04169215324509423, 0.03050639214052353, 0.10521724470891058, 0.021407355488918256, 0.023835545798647217, 0.016310168357449584, 0.06418742486857809, 0.0806842916063033, 0.051330662608961575, 0.01743932192766806, 0.07230980816530064, 0.0164168409537524, 0.04992293834220618, 0.07843946557841264, 0.14467783039435744, 0.016631763210170902, 0.039215012729982845, 0.02827458894898882, 0.0170963346681674, 0.09648353952798061, 0.037747619790025055, 0.021181967094889842, 0.036670848858193494, 0.035497524513630196, 0.08322394322021864, 0.021090271038701758, 0.17653131333645433, 0.14737139601493254, 0.03397934269742109, 0.04692358932516072, 0.24900080199586228, 0.01807110667868983, 1.385879684239626, 13.870826046913862, 26.89027927815914, 46.28087818622589, 46.33968383073807, 50.74364371597767, 70.10040163993835, 82.13406711816788, 84.47221085429192, 82.30692744255066, 71.48411259055138, 72.33036518096924, 68.20350542664528, 67.44794636964798, 66.28409162163734, 58.665519431233406, 55.18489859998226, 42.904212176799774, 49.05370719730854, 50.834014266729355, 54.240508675575256, 42.00335271656513, 42.67372414469719, 44.46025148034096, 39.09142456948757, 43.73562276363373, 46.32456064224243, 56.98439083993435, 43.38764503598213, 39.14199225604534, 28.041786588728428, 19.647463224828243, 46.69761702418327, 75.49854397773743, 47.05008611083031, 25.472136475145817, 37.79583469033241, 27.33831513673067, 26.528922468423843, 34.85503189265728, 42.96487212181091, 41.037927120923996, 49.065364971756935, 47.222437262535095, 57.73010082542896, 58.93437780439854, 62.86365956068039, 66.66844859719276, 73.16629752516747, 77.81478568911552, 82.75167837738991, 79.21241909265518, 57.472581043839455, 14.511818401515484, 5.353941209614277, 3.204505085013807, 0.41106482211034745, 0.08187039944459684, 0.24337271024705842, 0.07720416077063419, 0.17214746185345575, 0.02778200141619891, 0.02331988489459036, 0.03952557184675243, 0.003919385317203705, 0.24029692373005673, 0.17686438921373338, 0.019066163440584205, 0.10707547116908245, 0.07300843630218878, 0.027701823491952382, 0.022565163380932063, 0.06633631346630864, 0.08773945170105435, 0.008189640429918654, 0.06781330608646385, 0.05485567853611428, 0.06677334939013235, 0.029577215827885084, 0.03458417078945786, 0.03878480456478428, 0.06979889993090183, 0.04106360982405022, 0.045923092620796524, 0.045000443496974185, 0.07083441116265021, 0.03331094965687953, 0.06531219420139678, 0.028217421313456725, 0.03598545692511834, 0.037844369871891104, 0.06619763575145043, 0.05386494849517476, 0.02882226610381622, 0.016645426148897968, 0.016302756157529075, 0.018439332525304053, 0.04128954555199016, 0.05171264972887002, 0.02352711479034042, 0.008300177760247607, 0.12831985659431666, 0.05348818980564829, 0.02820278245053487, 0.009572668805049034, 0.014859352213534294, 0.053805053466930985, 0.016457872443425003, 0.04974248142389115, 0.06518827780382708, 0.02532700473238947, 0.06122894963482395, 0.01499804477134603, 0.023740795804769732, 0.11112829510238953, 0.03042085034394404, 0.07618479125085287, 0.07629113359143957, 0.02857855593902059, 0.06198350602062419, 0.03447158698691055, 0.02546695151977474, 0.05451346682093572, 0.07481624124920927, 0.11535096695297398, 0.01854893289419124, 0.03133297024760395, 0.0672873979783617, 0.08000124857062474, 0.05023965357395355, 0.0744580956234131, 0.016517240546818357, 0.102230627235258, 0.12018481967970729, 0.050265907048014924, 0.03609118328313343, 0.06142551857919898, 0.033482897852081805, 0.07173513353336602, 0.062061179196462035, 0.04321882894146256, 0.03752684569917619, 0.0565631080098683, 0.04792144027305767, 0.008558084282412892, 0.047629112013964914, 0.06377772966516204, 0.02852154600986978, 0.05473131313920021, 0.08310414574225433, 0.07199607265647501, 0.020066871657036245, 0.07501917410991155, 0.038431011635111645, 0.0326440112257842, 0.020592469918483403, 0.019219021742173936, 0.01096971171136829, 0.0545669645362068, 0.1757965871365741, 0.03072529045311967, 0.016499312114319764, 0.03341834213642869, 0.03808899287832901, 0.02334583408810431, 0.017406485603714827, 0.008038116138777696, 0.06942338062799536, 0.019131485423713457, 0.031868407531874254, 0.18914853630121797, 0.034037612422253005, 0.06216813009814359, 0.16085230075987056, 0.6225467787589878, 0.16686277667758986, 7.506393659859896, 26.801048666238785, 40.130741000175476, 57.685590013861656, 64.31949064135551, 75.44339373707771, 83.21589186787605, 81.4172811806202, 82.63464465737343, 73.65075632929802, 62.350208312273026, 65.31679272651672, 56.72576151788235, 44.09719996154308, 48.615552708506584, 51.322474256157875, 49.68884691596031, 35.749401301145554, 28.79250280559063, 24.87078834325075, 27.946624495089054, 37.930545061826706, 34.567809104919434, 57.31314539909363, 44.46661613881588, 40.9390564262867, 48.91684994101524, 46.76860861480236, 37.880516946315765, 43.08580823242664, 53.4857589751482, 34.566490575671196, 70.82009822130203, 69.7302559018135, 57.03591987490654, 41.18202678859234, 46.99731454253197, 43.55868145823479, 34.107836186885834, 19.754723869264126, 21.942114494740963, 31.16035334765911, 40.53411975502968, 33.19230571389198, 33.4467438608408, 42.36505910754204, 48.191503062844276, 59.573108330368996, 68.00225302577019, 80.79732924699783, 87.40793332457542, 90.81870630383492, 80.90220361948013, 33.55251878499985, 14.653579294681549, 6.068225931376219, 0.8770165115129203, 0.07454747246811166, 0.20230654743500054, 0.07442723712301813, 0.17940519115654752, 0.01539065851829946, 0.05058012866356876, 0.00942529311942053, 0.058690396399470046, 0.08454833543510176, 0.10885165320360102, 0.052261267555877566, 0.04549830213363748, 0.05312085268087685, 0.12162032624473795, 0.020522468694252893, 0.07203758839750662, 0.08612516176071949, 0.07091120860422961, 0.03054209129913943, 0.04248752404237166, 0.08135925265378319, 0.020121109664614778, 0.016095587488962337, 0.02244534178316826, 0.15227219788357615, 0.07965019045514055, 0.12508623010944575, 0.022519196609209757, 0.04837823216803372, 0.029026779739069752, 0.04777987931447569, 0.0241675065990421, 0.011953085213463055, 0.020036619862366933, 0.07666445613722317, 0.0031297492341764155, 0.05796187455416657, 0.009868839533737628, 0.031150264621828683, 0.05474228579259943, 0.04026867318316363, 0.040783998265396804, 0.04581279463309329, 0.06097078243328724, 0.10591506390483119, 0.029885802687203977, 0.07058261529891752, 0.039690428820904344, 0.016300418392347638, 0.04528534656856209, 0.051413872206467204, 0.054939281471888535, 0.05401681046350859, 0.0162258863565512, 0.0872762847575359, 0.051449413658701815, 0.15157336194533855, 0.24198676430387422, 0.25539848604239523, 0.14892039180267602, 0.20316969486884773, 0.13332936825463548, 0.14357965963426977, 0.1973543147323653, 0.19308638671645895, 0.1659616906545125, 0.23403002094710246, 0.1835889893118292, 0.11751978963729925, 0.06427279411582276, 0.17189030768349767, 0.16488530935021117, 0.14014764223247766, 0.2008501419913955, 0.1025591314828489, 0.31325130199547857, 0.2975706715369597, 0.1355028070975095, 0.141226279665716, 0.10523044009460136, 0.13459127163514495, 0.22339360497426242, 0.19087594439042732, 0.1252323589869775, 0.19676895317388698, 0.1512922512483783, 0.14109272276982665, 0.22767702903365716, 0.12443340732716024, 0.1663275991450064, 0.1513472740771249, 0.09412598126800731, 0.18077198968967423, 0.16316438763169572, 0.2357361590838991, 0.16898653615498915, 0.16787987522548065, 0.16174060699995607, 0.11249780989601277, 0.11302807441097684, 0.15814819664228708, 0.2610556996660307, 0.23345570254605263, 0.17702874523820356, 0.11983822929323651, 0.13563937711296603, 0.261689048493281, 0.10638343330356292, 0.119979630690068, 0.12634703511139378, 0.11392772066756152, 0.17516873020213097, 0.1836464018560946, 0.3322151640895754, 0.21731366403400898, 0.13991227751830593, 0.17989155021496117, 0.5815018562134355, 0.12014151536277495, 3.222583089955151, 21.18764977902174, 39.131276831030846, 69.27603587508202, 74.02630537748337, 86.72562673687935, 101.74325689673424, 108.69551584124565, 105.56770607829094, 106.44195556640625, 90.93638598918915, 96.30899369716644, 93.34658145904541, 100.27407333254814, 103.14172625541687, 97.43422731757164, 87.97316819429398, 70.97426354885101, 86.61075130105019, 84.02065828442574, 84.39513579010963, 76.92471385002136, 86.33538007736206, 92.85610377788544, 67.77833104133606, 71.1616162955761, 77.19879314303398, 93.88136476278305, 78.43847662210464, 71.44032374024391, 67.8904478251934, 47.11434826254845, 100.8304014801979, 148.22291761636734, 91.25387415289879, 57.33962997794151, 81.44850790500641, 67.27713793516159, 63.39505344629288, 65.23296922445297, 90.19994750618935, 80.27539685368538, 90.34129232168198, 79.45586442947388, 89.92251679301262, 85.87548315525055, 90.46695157885551, 86.44502699375153, 95.19060730934143, 98.1208048760891, 105.52114337682724, 106.62253707647324, 92.65493497252464, 42.41573318839073, 17.734281085431576, 6.636077435687184, 0.6737332383636385, 0.27878406399395317, 0.24593637033831328, 0.15246769442455843, 0.32015475968364626, 0.06604092384804972, 0.2348165787407197, 0.16393276280723512, 0.13498688087565824, 0.35199440899305046, 0.3416279121302068, 0.29488780768588185, 0.19083260296611115, 0.1440806093160063, 0.22607428691117093, 0.16843305726069957, 0.16027614183258265, 0.2172842007712461, 0.20570175431203097, 0.1464561201282777, 0.10549002850893885, 0.133404191583395, 0.178541895293165, 0.08259741473011672, 0.11036942683858797, 0.1826946419896558, 0.20933760999469087, 0.15976971510099247, 0.13013227027840912, 0.2524790551979095, 0.14966731891036034, 0.11322604972519912, 0.13792931829812005, 0.166719067201484, 0.16195222298847511, 0.1653139293193817, 0.14884400996379554, 0.18701769673498347, 0.13137225061655045, 0.10106774119776674, 0.1629888400202617, 0.2161071397131309, 0.17410487635061145, 0.1135537821392063, 0.07514381781220436, 0.21407426364021376, 0.11908239641343243, 0.1041309408901725, 0.08284450537757948, 0.17465281882323325, 0.12451330694602802, 0.08638547005830333, 0.1566304304287769, 0.10220222524367273, 0.13777039479464293, 0.17413929715985432, 0.1358919744961895], [0.03725968366779853, 0.008268391575256828, 0.013745585220021894, 0.015731506537122186, 0.013817699709761655, 0.02260635999846272, 0.01656849512073677, 0.013901925121899694, 0.02060783237538999, 0.05082130810478702, 0.01677620555710746, 0.022556882868229877, 0.05426193070888985, 0.012884938823845005, 0.051873109478037804, 0.009646520848036744, 0.006387372368408251, 0.032123743440024555, 0.02958836474135751, 0.0017696824443191872, 0.018700683540373575, 0.00955956526013324, 0.032257827260764316, 0.04776614216098096, 0.04985666455468163, 0.034699248208198696, 0.06056087942852173, 0.07906255792477168, 0.05929193677729927, 0.08184374150005169, 0.042175996422884054, 0.0631410931237042, 0.030873193063598592, 0.06093475116358604, 0.026488951953069773, 0.05909542720473837, 0.03609903891629074, 0.020067294681211933, 0.01078048631825368, 0.03995591730927117, 0.037476939978660084, 0.04745085185277276, 0.06826313663623296, 0.016211212241614703, 0.04648164780519437, 0.057443989062448964, 0.06763723155017942, 0.03351790495798923, 0.04895048368780408, 0.09169764438411221, 0.03572380534023978, 0.044559993693837896, 0.057927542802644894, 0.03649123798822984, 0.051136939800926484, 0.00748069829569431, 0.053373873088276014, 0.08831410406855866, 0.04603036635671742, 0.03301468059362378, 0.07339052361203358, 0.05889643885893747, 0.05929680526605807, 0.23966268432559446, 0.22975771425990388, 0.10702541330829263, 3.6245656572282314, 11.528759971261024, 19.58986021578312, 40.004606768488884, 62.06596076488495, 68.7104894220829, 65.39884552359581, 65.144152790308, 82.78950154781342, 80.85789039731026, 83.69290307164192, 78.64832416176796, 79.44965556263924, 70.83085164427757, 80.25075137615204, 76.50450199842453, 82.29343816637993, 74.52770367264748, 76.03469520807266, 74.04361724853516, 67.83227294683456, 75.81103920936584, 92.29118809103966, 72.742969840765, 85.7674853503704, 91.52092382311821, 87.65245780348778, 65.44435188174248, 58.9531259983778, 54.79533590376377, 75.33514514565468, 55.55983208119869, 63.16574715077877, 65.94400987029076, 55.17882652580738, 48.01522672176361, 40.55035628378391, 57.61646032333374, 51.59400388598442, 52.29693576693535, 56.03274330496788, 74.04919534921646, 75.7294499874115, 82.02630490064621, 82.50905379652977, 76.04457467794418, 61.51438236236572, 43.730705827474594, 16.006679087877274, 1.4326132577843964, 0.4475698492024094, 0.25930408271960914, 0.0900317974446807, 0.16407553717726842, 0.10039546672487631, 0.08718994329683483, 0.07454751699697226, 0.017642239945416804, 0.03323693155834917, 0.08913464480428956, 0.04084301013790537, 0.07857284435885958, 0.017384234160999767, 0.09024578830576502, 0.023632753946003504, 0.03263044105551671, 0.04479828989133239, 0.07773950157570653, 0.04269588571332861, 0.08201651347917505, 0.031634530823794194, 0.009506932146905456, 0.07380884257145226, 0.023718011871096678, 0.044896806284668855, 0.058880397336906753, 0.06494497953099199, 0.05239810845523607, 0.027626063201751094, 0.05393707782786805, 0.05470213189255446, 0.022848344669910148, 0.02762605763564352, 0.06053285593225155, 0.020285814498492982, 0.03786289016716182, 0.07009074208326638, 0.1057585004309658, 0.023381978535326198, 0.050475994212320074, 0.00788660205216729, 0.0624231543042697, 0.027178798627573997, 0.07583468308439478, 0.05890995336812921, 0.06020182467182167, 0.02635079374158522, 0.03434358506638091, 0.02925810345914215, 0.026801448075275403, 0.02081427002849523, 0.018415292506688274, 0.03717283754667733, 0.053379669261630625, 0.029064436312182806, 0.030463234397757333, 0.047383739438373595, 0.006085853074182523, 0.06274581784964539, 0.01212522172863828, 0.03957133638323285, 0.02606012232718058, 0.047988868100219406, 0.012760216268361546, 0.05625806676107459, 0.065312632068526, 0.043591598587227054, 0.07935037021525204, 0.030271246359916404, 0.03626653793617152, 0.014428486319957301, 0.006523171477965661, 0.02136087106919149, 0.06483171295258217, 0.08209913678001612, 0.03180682411766611, 0.03558540593076032, 0.031682020853622817, 0.028363748715491965, 0.021277668893162627, 0.02328235819732072, 0.05500775943801273, 0.08849668723996729, 0.0629437634779606, 0.022281347555690445, 0.021459073905134574, 0.04427908337675035, 0.029838234731869306, 0.07464139867806807, 0.11647555817035027, 0.01773897518432932, 0.028984262098674662, 0.024091325140034314, 0.046583533548982814, 0.04688208471634425, 0.05182259890716523, 0.03775963887164835, 0.09460509696509689, 0.041419629196752794, 0.03751290816580877, 0.05147825722815469, 0.03020656262378907, 0.019368937428225763, 0.028241338877705857, 0.06857052678242326, 0.005178781166250701, 0.05116650696436409, 0.027368055561964866, 0.04182373231742531, 0.0025110452997978427, 0.07482069413526915, 0.008825860440992983, 0.06402358834748156, 0.021642467872879934, 0.028931489832757507, 0.005320613008734654, 0.0813424281659536, 0.04822181712370366, 0.07039078496745788, 0.023818114605091978, 0.06986051303101704, 0.1174435784923844, 0.04687221415224485, 0.22711623256327584, 0.5532427132129669, 2.0670394459739327, 13.450572397559881, 24.087825156748295, 37.939805164933205, 61.50383412837982, 83.79349127411842, 91.57052636146545, 89.00896981358528, 87.36080065369606, 88.9556510746479, 82.21388563513756, 75.08977711200714, 74.48130056262016, 70.22087797522545, 68.04353401064873, 60.5728954821825, 61.1293376237154, 54.058654233813286, 56.233965307474136, 52.313696667551994, 56.638206616044044, 57.314334735274315, 56.09464578330517, 60.51361866295338, 56.86298355460167, 66.94368302822113, 49.51305694878101, 48.00954222679138, 37.75559484958649, 34.70828376710415, 61.29680223762989, 88.99130076169968, 62.072492614388466, 42.654390782117844, 55.79456448554993, 46.94877974689007, 48.09068687260151, 44.231917932629585, 58.15107263624668, 58.51387716829777, 59.587935134768486, 57.540316209197044, 75.40361747145653, 80.71828588843346, 91.26260608434677, 97.78475850820541, 94.15726035833359, 77.96930059790611, 60.109365954995155, 28.428113758563995, 4.801060426980257, 0.7545604230836034, 0.15313570154830813, 0.12958837993210182, 0.18320823786780238, 0.061734682458336465, 0.07163599002524279, 0.1012415299192071, 0.06894514808664098, 0.0421495388582116, 0.04936741854180582, 0.018001901407842524, 0.12301837661652826, 0.08257722831331193, 0.08410694310441613, 0.07757297105854377, 0.15161288873059675, 0.043505854555405676, 0.07762342225760221, 0.08051972778048366, 0.06018252512149047, 0.07769287243718281, 0.041123579067061655, 0.03643587748229038, 0.014915822230250342, 0.015565603134746198, 0.040209650178439915, 0.04635403551219497, 0.052532426052493975, 0.03347064499394037, 0.008704555475560483, 0.09500199012109078, 0.027128430920129176, 0.04165539467066992, 0.03377672896021977, 0.037180396320763975, 0.10268295140122063, 0.03756025718757883, 0.1236478440114297, 0.046099842511466704, 0.037794612580910325, 0.029052973841316998, 0.04905871108348947, 0.045703242503805086, 0.043637904891511425, 0.052570869302144274, 0.032936343195615336, 0.02969054734421661, 0.059369001392042264, 0.008094771692412905, 0.011820475483546034, 0.0646035470708739, 0.06145870742329862, 0.019786877892329358, 0.0330889955512248, 0.0566121751035098, 0.06417988464818336, 0.013827016446157359, 0.042520601564319804, 0.027988123656541575, 0.047789623713470064, 0.08736419214983471, 0.23003851325483993, 0.10759740878711455, 0.1346684995223768, 0.21775062574306503, 0.1285274649853818, 0.18838611315004528, 0.144934969721362, 0.10983234198647551, 0.14266592741478235, 0.06609061063500121, 0.12767221400281414, 0.2049665234517306, 0.14463469677139074, 0.2098729062709026, 0.19023027591174468, 0.20823473401833326, 0.14760815596673638, 0.21542132104514167, 0.09758774394867942, 0.1869018326397054, 0.119633841823088, 0.18374412786215544, 0.19139595242450014, 0.1802688284078613, 0.19757305533858016, 0.12929922435432673, 0.20693428348749876, 0.1637833981658332, 0.30933727452065796, 0.25067842681892216, 0.1936248890706338, 0.22407360520446673, 0.08493903165799566, 0.11516860642586835, 0.19349354377482086, 0.1252959610428661, 0.2309717788011767, 0.10680765233701095, 0.09823250700719655, 0.11996101762633771, 0.1322624715976417, 0.18500776786822826, 0.1393530544009991, 0.12014920401270501, 0.16880463575944304, 0.2174004804692231, 0.20597838243702427, 0.1003031361324247, 0.1245376790757291, 0.11397996044252068, 0.0991219784191344, 0.11691535488353111, 0.139710858638864, 0.09102453870582394, 0.1038270239951089, 0.12110692332498729, 0.31737906800117344, 0.23558002605568618, 0.13336261647054926, 0.2039719416643493, 0.2505951578496024, 0.1284624676918611, 0.3138864616630599, 0.41233151976484805, 0.7414971990510821, 6.798452697694302, 18.72557759284973, 33.42757388949394, 62.88734368979931, 86.66903257369995, 99.8214340209961, 97.93702393770218, 102.06443846225739, 113.02994325757027, 105.03391832113266, 104.00573909282684, 100.11879846453667, 99.7412583231926, 99.63831424713135, 103.31201031804085, 102.4324943125248, 101.05304673314095, 102.2579088807106, 95.25308355689049, 95.18242254853249, 89.8809090256691, 102.01640143990517, 117.08137705922127, 94.9051134288311, 113.0192506313324, 121.14692330360413, 120.1816838979721, 103.80275398492813, 81.68017387390137, 86.5672816336155, 95.02051323652267, 76.1526408791542, 95.41332855820656, 102.71980449557304, 88.54202046990395, 78.12009170651436, 66.7067201435566, 89.32770431041718, 76.3623896241188, 77.54752323031425, 80.11724174022675, 98.76950606703758, 98.66595402359962, 106.84922531247139, 112.85574540495872, 107.44553491473198, 89.03954297304153, 61.95051535964012, 30.259216502308846, 6.93029279820621, 0.4862617183243856, 0.25425970496144146, 0.2580442128237337, 0.3168707265285775, 0.15047435997985303, 0.21448164334287867, 0.21508842328330502, 0.12243841047165915, 0.12420850689522922, 0.16448379261419177, 0.07859925739467144, 0.19101870391750708, 0.14351739344419912, 0.22688143188133836, 0.18470529816113412, 0.1973295269999653, 0.12522250326583162, 0.18696248094784096, 0.13568838854553178, 0.1690532552311197, 0.2235069902963005, 0.16111798962811008, 0.19038060534512624, 0.1271569260279648, 0.11315193885820918, 0.1944987679598853, 0.10775310394819826, 0.19363058876479045, 0.07109713144018315, 0.11031509420718066, 0.21834136045072228, 0.16283472563372925, 0.10955710167763755, 0.22274063376244158, 0.2038860009633936, 0.16608466452453285, 0.20545043342281133, 0.21043796266894788, 0.10732471404480748, 0.15750929655041546, 0.17051932343747467, 0.15469232661416754, 0.13209596334490925, 0.14796774135902524, 0.11953951485338621, 0.24572327005444095, 0.11839566490380093, 0.10800138945342042, 0.09467467330978252, 0.1589836916537024, 0.13619767996715382, 0.19864320260239765, 0.07692788887652569, 0.1635837901267223, 0.14849886676529422, 0.10828515703906305, 0.31081055640242994, 0.1499170664465055, 0.21529882214963436, 0.15037504577776417], [0.027815501962322742, 0.03694188861118164, 0.05004790858947672, 0.038571348050027154, 0.07598598473123275, 0.043830822469317354, 0.025117455625149887, 0.019753685337491333, 0.026485855341888964, 0.02962457227113191, 0.040619931678520516, 0.04185729594610166, 0.039141439920058474, 0.057418744909227826, 0.05156437233381439, 0.026320317447243724, 0.04047760630783159, 0.020519522367976606, 0.04318472354498226, 0.03531482259859331, 0.09287959619541653, 0.05064163786300924, 0.06529470920213498, 0.03458191094978247, 0.05169531315914355, 0.09803571170778014, 0.0937645701924339, 0.01629630132811144, 0.02121689813066041, 0.05420242159743793, 0.023293611011467874, 0.0593870096054161, 0.038039046339690685, 0.03721483197296038, 0.06440364959416911, 0.031750380076118745, 0.014449378704739502, 0.04657328448956832, 0.06433549075154588, 0.08200993805075996, 0.09041835248353891, 0.09066139842616394, 0.09957091839169152, 0.01981951754714828, 0.03424844915571157, 0.042290524652344175, 0.01911086670588702, 0.017974955881072674, 0.05604000893072225, 0.028983770425838884, 0.019082525941485073, 0.023280738460016437, 0.03434684309468139, 0.03997601095761638, 0.054853329638717696, 0.09046593157108873, 0.010991725666826824, 0.09037104799062945, 0.04694944575021509, 0.02495442433428252, 0.03100922316662036, 0.11753131519071758, 0.133513257605955, 0.05932722589932382, 0.007966286448208848, 0.04885041620582342, 0.2021026349393651, 0.13217626372352242, 0.09608154039597139, 0.3472353721735999, 5.097678210586309, 9.065187815576792, 12.780346311628819, 27.061708979308605, 39.02013659477234, 48.13084691762924, 72.74801596999168, 77.88584187626839, 79.55031976103783, 97.38913133740425, 86.94752722978592, 70.17217218875885, 86.18949830532074, 90.55242419242859, 96.2094846367836, 95.78656733036041, 93.06995630264282, 99.43614229559898, 102.53314331173897, 103.20882305502892, 105.9535525739193, 97.88067296147346, 99.0834604203701, 99.30112794041634, 94.10202652215958, 98.32596346735954, 89.10716414451599, 89.43949431180954, 93.1808191537857, 85.31416967511177, 80.14444828033447, 69.07880365848541, 63.590009585022926, 57.59341076016426, 65.3600800037384, 75.70620283484459, 76.20912104845047, 70.72480693459511, 60.77897362411022, 41.365575939416885, 19.92512572556734, 5.886449385434389, 2.1790410485118628, 0.19136445567710325, 0.034761570059345104, 0.25742012599948794, 0.0755897891940549, 0.06494241170003079, 0.08506320780725218, 0.09660885116318241, 0.010761252633528784, 0.04105875617824495, 0.035588548926170915, 0.05918511946219951, 0.027555846754694358, 0.03952651808504015, 0.08796045585768297, 0.018955344094138127, 0.12307386699831113, 0.08425647843978368, 0.03557521624315996, 0.03269583539804444, 0.01554773778480012, 0.0738331775937695, 0.02770740815321915, 0.01822369966248516, 0.026135429907299113, 0.06441639226977713, 0.01753069143887842, 0.012588333011080977, 0.04590659838868305, 0.07176838917075656, 0.09493529330939054, 0.024973684921860695, 0.046169181368895806, 0.02571247623563977, 0.035634762461995706, 0.03798974175879266, 0.02573860539996531, 0.0629076431505382, 0.08567326061893255, 0.04098656376299914, 0.0229979672076297, 0.03483322070678696, 0.0393851946137147, 0.0086710883260821, 0.0330913852667436, 0.027494716050568968, 0.09098957612877712, 0.08615746002760716, 0.021754919944214635, 0.018706780283537228, 0.04962312181305606, 0.004842462103624712, 0.05023023943067528, 0.07415290223434567, 0.003054447220165457, 0.05104935524286702, 0.05730716300604399, 0.05317368246323895, 0.05504894121258985, 0.018554255948401988, 0.06902509223436937, 0.05041280404839199, 0.0366161822603317, 0.024052672233665362, 0.02254738523333799, 0.027185587423446123, 0.0379933189105941, 0.01139053263614187, 0.06089097558287904, 0.03357959598361049, 0.056678237378946505, 0.02798865614749957, 0.03213827840227168, 0.07484217931050807, 0.045996149638085626, 0.05229060465353541, 0.0809894033591263, 0.11506689508678392, 0.052206905238563195, 0.0060982177183177555, 0.04033627541502938, 0.015104987323866226, 0.057242718612542376, 0.021403214304882567, 0.042815312117454596, 0.045119732603779994, 0.010371786520408932, 0.08478948147967458, 0.051898242309107445, 0.07570902263978496, 0.03887381033564452, 0.04571066026983317, 0.027680111961672083, 0.054595366527792066, 0.07164520007790998, 0.07087052406859584, 0.08247964331530966, 0.058726108545670286, 0.07137613443774171, 0.07562713406514376, 0.044982702456763946, 0.011354794514772948, 0.03900937474099919, 0.06525137519929558, 0.08223579585319385, 0.08885358605766669, 0.09949194645741954, 0.024813870841171592, 0.043061593823949806, 0.03699553104524966, 0.03371306382177863, 0.0284489045952796, 0.04662081162678078, 0.03948269055399578, 0.030368159714271314, 0.03829752895398997, 0.026412377155793365, 0.06200607473147102, 0.034460699680494145, 0.10363364999648184, 0.036075052703381516, 0.09142266382696107, 0.036232165366527624, 0.062465538358082995, 0.017966786690521985, 0.1252613918040879, 0.06881271925522014, 0.04839505294512492, 0.07761637185467407, 0.1831716499873437, 0.2559706522151828, 0.34112301422283053, 0.5986189877148718, 4.7789080906659365, 14.813701752573252, 24.984575137495995, 29.714941307902336, 47.01330028474331, 67.53668680787086, 79.78325486183167, 95.3475920855999, 99.24647927284241, 100.62584325671196, 101.71340569853783, 102.68961891531944, 87.56853550672531, 98.26982527971268, 99.39094752073288, 109.23135548830032, 105.39185911417007, 105.92230305075645, 111.31549805402756, 118.25421452522278, 108.87354388833046, 108.86612668633461, 106.23522385954857, 101.55179277062416, 97.14660555124283, 93.43315601348877, 88.30451801419258, 87.72488191723824, 90.44166013598442, 98.62453624606133, 90.81006556749344, 87.16284647583961, 83.5085141658783, 78.12628537416458, 75.16881287097931, 78.69737192988396, 85.16488328576088, 84.86989751458168, 82.63244077563286, 77.70957693457603, 60.49317196011543, 38.87678548693657, 16.82791192084551, 6.673784237354994, 0.7700399018358439, 0.1180298083636444, 0.08131736583891325, 0.20578579511493444, 0.17631471011554822, 0.08545766671886668, 0.009864305011433316, 0.05083009513327852, 0.032168305697268806, 0.022901597476447932, 0.04147747589740902, 0.03212821487977635, 0.0650545724784024, 0.04684069885115605, 0.029896333762735594, 0.008270718208223116, 0.13471489859512076, 0.053520695873885415, 0.04789340193383396, 0.009078129423869541, 0.045266759480000474, 0.06179726777190808, 0.07350146726821549, 0.04769138562551234, 0.033028365796781145, 0.03114329585514497, 0.051376542178331874, 0.03702273817907553, 0.016928509103308897, 0.04434462985955179, 0.006332805496640503, 0.05491608564625494, 0.06729064116370864, 0.05958819470833987, 0.043076050860690884, 0.02353247309656581, 0.06890066375490278, 0.07614305286551826, 0.045973347150720656, 0.029304003437573556, 0.05173734840354882, 0.051447439545881934, 0.04153560832492076, 0.0459152406983776, 0.016306739635183476, 0.1129962362756487, 0.03610745487094391, 0.018238724442198873, 0.014622137696278514, 0.012847466859966516, 0.049448535282863304, 0.039466433809138834, 0.013096599341224646, 0.02359624584642006, 0.01848671123298118, 0.021944820691714995, 0.033251418280997314, 0.011169046083523426, 0.016816958741401322, 0.0350815989804687, 0.03290203741926234, 0.006920636551512871, 0.012850699840782909, 0.10650378739228472, 0.11785953000071459, 0.1522187632508576, 0.09829809059738182, 0.1604737460729666, 0.13960808602860197, 0.22274409217061475, 0.10244772769510746, 0.09565894666593522, 0.09523122469545342, 0.15397131530335173, 0.12275744491489604, 0.15895115589955822, 0.18914840271463618, 0.17578760714968666, 0.15315180615289137, 0.12520323711214587, 0.11871987211634405, 0.18367360898992047, 0.14819075673585758, 0.16824133082991466, 0.15268771152477711, 0.135741897393018, 0.27459544187877327, 0.13618659228086472, 0.28472246252931654, 0.19426790066063404, 0.13400938332779333, 0.19343843188835308, 0.15928608714602888, 0.17576181009644642, 0.16822262870846316, 0.15607284003635868, 0.18818870186805725, 0.17241632711375132, 0.1173234693123959, 0.1731872552772984, 0.08094790988252498, 0.16943451133556664, 0.17479903675848618, 0.30277947953436524, 0.23107707471353933, 0.2007559486082755, 0.12850643252022564, 0.21584591857390478, 0.1300967956194654, 0.09769633499672636, 0.12284029086004011, 0.19849766744300723, 0.11537696438608691, 0.04878395688137971, 0.14185199921485037, 0.10052328681922518, 0.15334595198510215, 0.10285704440320842, 0.1746736138011329, 0.1264075201470405, 0.2865613263566047, 0.06374324206262827, 0.12868094112491235, 0.11933706438867375, 0.3746076190145686, 0.25576584914233536, 0.1683105732081458, 0.08282966242404655, 0.16484125546412542, 0.5855874088592827, 0.29213164933025837, 0.21640606195433065, 1.5756475576199591, 7.59733323007822, 15.111230537295341, 21.569609083235264, 41.079781875014305, 61.64751201868057, 83.4393122792244, 105.00503227114677, 113.8964031636715, 111.75375133752823, 128.73253226280212, 121.02836966514587, 110.23707792162895, 121.08461424708366, 125.09678855538368, 128.6790007352829, 128.84933799505234, 126.63871541619301, 133.12003523111343, 138.8541555404663, 135.8535933494568, 134.20987755060196, 126.91803842782974, 122.82747432589531, 125.1918974518776, 126.10298976302147, 128.75996679067612, 123.48129764199257, 124.83040004968643, 129.04771775007248, 119.84883695840836, 117.30208441615105, 113.53217750787735, 109.76023390889168, 102.16720774769783, 109.07747134566307, 112.04602405428886, 110.0224806368351, 100.7186570763588, 89.73361372947693, 66.3020646572113, 36.725481525063515, 13.919716123491526, 4.148963643237948, 0.47084078018087894, 0.2489084194530733, 0.3352764045121148, 0.261977476766333, 0.26107591576874256, 0.11145219061290845, 0.24457605817588046, 0.1361142922542058, 0.1627361387363635, 0.09489054922596551, 0.13598297664429992, 0.14713690703501925, 0.19856912142131478, 0.11723163595888764, 0.09951614047167823, 0.19822423055302352, 0.29031466401647776, 0.15711855579866096, 0.14046997181139886, 0.09065865247976035, 0.1955150204594247, 0.14389507239684463, 0.19044857122935355, 0.10743287464720197, 0.25025148410350084, 0.1876399727188982, 0.12370505617582239, 0.17374009592458606, 0.1509996669483371, 0.1471667710575275, 0.08248762140283361, 0.13418263028142974, 0.19113609683699906, 0.23721427976852283, 0.14262193290051073, 0.08447539716144092, 0.14591962157282978, 0.10466116087627597, 0.11014220348442905, 0.19208758953027427, 0.11872995048179291, 0.1024489151313901, 0.1499508786946535, 0.15790998208103701, 0.13572270545409992, 0.15246671478962526, 0.25270434154663235, 0.11018406803486869, 0.05416014144429937, 0.09557901736116037, 0.09958068505511619, 0.1437319631804712, 0.16754994605435058, 0.12656798731768504, 0.13550987234339118, 0.13569392496719956, 0.211925953917671, 0.16202953993342817, 0.13432058069156483, 0.26136582833714783, 0.1315557985799387, 0.1755807112203911, 0.09194888363708742], [0.053504283278016374, 0.026594151386234444, 0.029193718437454663, 0.00841606875837897, 0.08710695634363219, 0.02354024152737111, 0.021454403940879274, 0.026443220813234802, 0.04560538291116245, 0.04737772062071599, 0.10783001271192916, 0.009703887008072343, 0.09211525830323808, 0.04746994731249288, 0.06391265211277641, 0.054345837925211526, 0.05800587277917657, 0.0644588060094975, 0.07214816097985022, 0.09564740626956336, 0.028773100675607566, 0.009433068971702596, 0.05165330760064535, 0.0248632236616686, 0.048696713711251505, 0.02887308095523622, 0.04399507830385119, 0.03530317459080834, 0.06556481384905055, 0.10386878464487381, 0.007108623949534376, 0.008730038043722743, 0.07458071326254867, 0.11382580152712762, 0.01979719931114232, 0.06938316364539787, 0.021409147775557358, 0.07697839944739826, 0.024081436022242997, 0.037756399397039786, 0.06851135534816422, 0.01715842830890324, 0.027229541119595524, 0.05574477887421381, 0.023149508197093382, 0.0863704044604674, 0.018551270659372676, 0.01587049409863539, 0.07391220889985561, 0.0489273286802927, 0.07547728702775203, 0.08004176241229288, 0.0762977015983779, 0.06922628104803152, 0.06992803362663835, 0.13867862027836964, 0.06965075983316638, 0.03364068215887528, 0.03162074543070048, 0.03727022216480691, 0.09055821021320298, 0.056647779638296925, 0.030832438023935538, 0.10263069678330794, 0.0678845374204684, 0.06519206275697798, 0.03708254414959811, 0.07906442813691683, 0.013091231758153299, 0.04507180470682215, 0.09614059308660217, 0.02834828421327984, 0.40777369402348995, 0.2828787302132696, 0.9860625851433724, 1.4409325551241636, 9.783095642924309, 12.789482921361923, 11.74384742975235, 24.12646148353815, 19.934401027858257, 22.97887746244669, 28.46785392612219, 40.472255274653435, 36.83030650019646, 37.86026783287525, 32.13646396994591, 30.748774632811546, 30.55016878992319, 40.75884349644184, 53.615917190909386, 45.4433461278677, 60.15810213983059, 66.7537996172905, 69.80644181370735, 64.78833228349686, 60.128703117370605, 51.15964159369469, 39.616127014160156, 45.28977356851101, 44.979964792728424, 31.870470643043518, 34.65980216860771, 37.623209953308105, 39.447837844491005, 31.842469945549965, 23.121366016566753, 9.082766622304916, 5.08985348045826, 0.7741791266016662, 0.07572085989522748, 0.12028695404296741, 0.044894234742969275, 0.13099645671900362, 0.08090670584351756, 0.12075820297468454, 0.06517561676446348, 0.025442213882342912, 0.0051903837174904766, 0.1132938226510305, 0.04396432370413095, 0.018615533226693515, 0.025240750474040397, 0.021810473408550024, 0.018000580384978093, 0.06667515583103523, 0.06222938696737401, 0.07944381402921863, 0.014914673756720731, 0.012848190453951247, 0.0815945357317105, 0.06000859539199155, 0.09702481751446612, 0.0627317615726497, 0.02644617827172624, 0.05629631705232896, 0.03098686782323057, 0.008711280261195498, 0.08550275961169973, 0.03807010150921997, 0.01643004932702752, 0.01611033767403569, 0.02955294203275116, 0.037958705142955296, 0.01712451958155725, 0.03415009974560235, 0.0840722477005329, 0.03270506771514192, 0.06905461486894637, 0.11840855600894429, 0.039624811834073626, 0.01708153995423345, 0.1420252164825797, 0.03291839806479402, 0.029960058272990864, 0.016212496157095302, 0.022628442602581345, 0.04212229832774028, 0.03621121453761589, 0.0297315825446276, 0.10212024761131033, 0.09905730024911463, 0.04637555408407934, 0.08905904222046956, 0.04096394681255333, 0.05165613518329337, 0.0367810874740826, 0.015502850837947335, 0.0258950575516792, 0.07469906355254352, 0.04044704466650728, 0.05819833393616136, 0.038312835749820806, 0.04918506172543857, 0.03656657339888625, 0.034994908710359596, 0.05849954570294358, 0.013735274005739484, 0.06483342731371522, 0.03844037382805254, 0.07572335351142101, 0.038938399447943084, 0.04811828752281144, 0.04223660762363579, 0.025615791091695428, 0.03950413491111249, 0.01942530168889789, 0.10548286678385921, 0.019773181556956843, 0.08359059385838918, 0.05095679829537403, 0.0471368788566906, 0.0320599929546006, 0.04795308916072827, 0.08304015776957385, 0.047026224638102576, 0.06086918612709269, 0.08996274060336873, 0.05314772955898661, 0.03810286732914392, 0.05018793701310642, 0.030123507021926343, 0.09354947353131138, 0.04275678264093585, 0.05791392810351681, 0.039594053523615, 0.04837366795982234, 0.10319544890080579, 0.02061392726318445, 0.06940253369975835, 0.03774830998736434, 0.06155909402878024, 0.05887293504201807, 0.03856730705592781, 0.048563939781161025, 0.02918695561675122, 0.03129195545625407, 0.04947961642756127, 0.01600055918970611, 0.019331540606799535, 0.06772209613700397, 0.2091327475500293, 0.0861375333624892, 0.08142213482642546, 0.08799090617685579, 0.051074788643745705, 0.15341513499151915, 0.08687814479344524, 0.03836267096630763, 0.04690381480031647, 0.0626043051306624, 0.13054162409389392, 0.06709317050990649, 0.05045821235398762, 0.0871299480786547, 0.07403362425975502, 0.11621691228356212, 0.05723183130612597, 0.04688345768954605, 0.10443873179610819, 0.07197081737103872, 0.06616941929678433, 0.0304495195086929, 0.17778521636500955, 0.08690903297974728, 0.19826240662951022, 0.4221307783154771, 0.4897211951902136, 1.5469279862008989, 2.324931132607162, 6.183601515367627, 9.051884729415178, 24.64171953499317, 29.667208269238472, 31.191828958690166, 47.95900113880634, 42.951135858893394, 43.69595289230347, 52.81838558614254, 65.88271915912628, 64.25965905189514, 66.37987688183784, 65.10786473751068, 63.78414496779442, 56.001087203621864, 67.5702466070652, 77.73095458745956, 70.93786150217056, 84.24955800175667, 92.59653210639954, 92.73163765668869, 89.42448511719704, 86.20744854211807, 75.88185980916023, 66.01713314652443, 70.71241959929466, 69.35651555657387, 63.14909264445305, 60.464859679341316, 57.60715842247009, 59.944842383265495, 50.958149805665016, 41.85653239488602, 24.0061504393816, 13.461318220943213, 3.4824105352163315, 0.5105133529286832, 0.10298801120370626, 0.1107252124347724, 0.07206449867226183, 0.18048667843686417, 0.16841900098370388, 0.04638471960788593, 0.05455504564451985, 0.022544910170836374, 0.11367881175829098, 0.06219687347766012, 0.05619825707981363, 0.01882119533547666, 0.0310737510517356, 0.032372388886869885, 0.016687676616129465, 0.057785291646723635, 0.055857010156614706, 0.030269977287389338, 0.01497723866123124, 0.10725619897129945, 0.11990304104983807, 0.06293936254223809, 0.08185235783457756, 0.05789347080281004, 0.02857023646356538, 0.08412246883381158, 0.06680758466245607, 0.028359319949231576, 0.020534348623186816, 0.020229543006280437, 0.09633926601964049, 0.026930010317300912, 0.018544828817539383, 0.06061994325136766, 0.03399303161131684, 0.06092537041695323, 0.0387358005536953, 0.06781269010389224, 0.036209489044267684, 0.01462348654968082, 0.039263693906832486, 0.03288597734353971, 0.042943655425915495, 0.009637176281103166, 0.08593722028308548, 0.009271973758586682, 0.049627066327957436, 0.0774382712552324, 0.05416964464529883, 0.03995398772531189, 0.06377616373356432, 0.04305383838072885, 0.10168220236664638, 0.027715300893760286, 0.028772770419891458, 0.0496891989314463, 0.049165832679136656, 0.026054185145767406, 0.05450688397104386, 0.05828434143040795, 0.06545858283061534, 0.014195760868460638, 0.03913543223461602, 0.023883731591922697, 0.030938563286326826, 0.18677354499232024, 0.09514796314761043, 0.20290271466365084, 0.12316063890466467, 0.17984800098929554, 0.11783230060245842, 0.09471078621572815, 0.12205450490000658, 0.21546650299569592, 0.17551657481817529, 0.16255512891802937, 0.2415348112117499, 0.17080228950362653, 0.18823885620804504, 0.13699023431399837, 0.18068196717649698, 0.14098589803325012, 0.1507308313739486, 0.1753587942221202, 0.1532816226244904, 0.12215810129418969, 0.15926308056805283, 0.16684354020981118, 0.06646285706665367, 0.20617659523850307, 0.2522184723056853, 0.15285747038433328, 0.13144688098691404, 0.16253590729320422, 0.1563949024421163, 0.11768180047511123, 0.17805964773287997, 0.14976945327362046, 0.18677958607440814, 0.11454999665147625, 0.13035415759077296, 0.1528166967909783, 0.12942849163664505, 0.08817113674012944, 0.13771221041679382, 0.1269551954464987, 0.2480315274442546, 0.08952753036282957, 0.19995836250018328, 0.16207573120482266, 0.37873897701501846, 0.18167359521612525, 0.21676871983800083, 0.31096370599698275, 0.18122282956028357, 0.3430202999152243, 0.1726107846479863, 0.20322100695921108, 0.17840214888565242, 0.22085410921135917, 0.198144672322087, 0.15381273318780586, 0.10834609478479251, 0.18023785116383806, 0.31267857179045677, 0.1830794010311365, 0.14637751184636727, 0.16841843695146963, 0.18475285498425364, 0.2732613275293261, 0.12164172978373244, 0.13888959801988676, 0.2716466219862923, 0.2009324758546427, 0.20355507731437683, 0.29677595011889935, 0.25428502704016864, 0.6248157913796604, 0.6496219884138554, 2.56997499614954, 3.932492109015584, 14.22221029177308, 18.24504777789116, 20.659217834472656, 32.315639555454254, 30.392910428345203, 35.74560150504112, 43.37451294064522, 56.55871868133545, 57.60023519396782, 57.29236051440239, 57.59056091308594, 56.07904762029648, 46.31416440010071, 58.70484732091427, 70.70500999689102, 66.69353485107422, 83.68106290698051, 93.91809359192848, 95.86019977927208, 86.34040340781212, 83.34568530321121, 69.07368153333664, 60.11305175721645, 66.6972890496254, 69.53845739364624, 65.67756816744804, 64.91610422730446, 64.11361008882523, 62.23057173192501, 45.419555604457855, 34.59808208048344, 18.160593509674072, 8.383414149284363, 1.6877119755372405, 0.3010434773750603, 0.4272354778368026, 0.3608004958368838, 0.3129718982381746, 0.37632672989275306, 0.21492063853656873, 0.14887277560774237, 0.15842243505176157, 0.14792817004490644, 0.2420199679909274, 0.18439539213432, 0.09655504545662552, 0.1137585926335305, 0.20812495553400367, 0.11775331382523291, 0.1852933908230625, 0.274348336388357, 0.19735109381144866, 0.11710989405401051, 0.14203817438101396, 0.2409884420922026, 0.15027136774733663, 0.22507786459755152, 0.16496322001330554, 0.1894252237980254, 0.1441280177095905, 0.15692647313699126, 0.16121754131745547, 0.09453471910092048, 0.1403176088933833, 0.0724922280642204, 0.14894483814714476, 0.10979484868585132, 0.16145011555636302, 0.11092755157733336, 0.15715337736764923, 0.29058367770630866, 0.1912599167553708, 0.18164794659242034, 0.3440437512472272, 0.07444312650477514, 0.07288490582141094, 0.2899168728617951, 0.16641722089843825, 0.11462571055744775, 0.23701630445430055, 0.08916899139876477, 0.17967999359825626, 0.2512017893604934, 0.14548035920597613, 0.17410726606613025, 0.1803847073460929, 0.09712465121992864, 0.2867650310508907, 0.09632670145947486, 0.18132471159333363, 0.1030897225427907, 0.11332673690048978, 0.12594234198331833, 0.19803532428340986, 0.15063950268086046, 0.1625939877703786, 0.0906342061352916, 0.11773430742323399, 0.12324766314122826, 0.1491914241341874], [0.031168718123808503, 0.029695553130295593, 0.02322361535334494, 0.05097854322229978, 0.038204252123250626, 0.060762869761674665, 0.015878440644883085, 0.02116690706316149, 0.0078038052743067965, 0.03291616420028731, 0.06287262862315401, 0.023359574952337425, 0.005869179349247133, 0.039511682552983984, 0.057743909492273815, 0.012033362399961334, 0.0696161386440508, 0.0563486941246083, 0.012809490235667909, 0.028167677010060288, 0.020428920979611576, 0.01599028972123051, 0.02946963781141676, 0.03474759912933223, 0.032244676403934136, 0.009932731027220143, 0.06403015635441989, 0.02722975634242175, 0.042886391311185434, 0.058467778071644716, 0.0671346639865078, 0.07178230443969369, 0.0475515650032321, 0.07971842351253144, 0.053246539100655355, 0.061895628314232454, 0.05481344291183632, 0.024947982492449228, 0.02714492515224265, 0.012906417505291756, 0.05254101270111278, 0.04385968830320053, 0.03776557605306152, 0.03916748559277039, 0.04570952107314952, 0.008967862049757969, 0.024361639443668537, 0.016000104624254163, 0.08898292013327591, 0.10221355783869512, 0.017368689877912402, 0.09528260357910767, 0.04203231663268525, 0.06744412472471595, 0.06790169587475248, 0.008387473808397772, 0.03259644698118791, 0.052380359993549064, 0.041786224173847586, 0.0388982492586365, 0.06352424912620336, 0.06293791535426863, 0.045090332423569635, 0.014581453160644742, 0.070263632806018, 0.07539056707173586, 0.024814217795210425, 0.049793864018283784, 0.051614333715406246, 0.01842651006882079, 0.09879771925625391, 0.017198084970004857, 0.05430477118352428, 0.0315705688262824, 0.07522248546592891, 0.11098592891357839, 0.06872076715808362, 0.01827943680837052, 0.016075857492978685, 0.09883823309792206, 0.049729612583178096, 0.06665580804110505, 0.08737689029658213, 0.17461109528085217, 0.18238184158690274, 0.9466267575044185, 0.3116545861121267, 0.786356523167342, 0.48178428201936185, 0.060359601557138376, 0.07445191353326663, 0.21728423045715317, 0.1000636005483102, 0.07239062804728746, 0.044251523722778074, 0.33561271615326405, 0.36094925191719085, 0.06581326262676157, 0.19409827538765967, 0.13391317130299285, 0.5807870195712894, 0.5142633954528719, 1.5202568611130118, 0.9375938703306019, 0.7659207447431982, 0.12905244540888816, 0.0579849071073113, 0.22757349943276495, 0.08163839665940031, 0.017674651389825158, 0.10124609412741847, 0.08011672674911097, 0.03964480529248249, 0.10032249876530841, 0.040986660242197104, 0.08457576521323062, 0.0563083027373068, 0.0215224978455808, 0.10614272512611933, 0.030370796193892602, 0.020082549526705407, 0.0098232540403842, 0.0639478224911727, 0.01201559352921322, 0.028489099313446786, 0.05602101737167686, 0.04624174856871832, 0.058809730035136454, 0.07700268994085491, 0.02997350227815332, 0.056161806496675126, 0.02754813955107238, 0.024459343185299076, 0.024510406656190753, 0.08986431697849184, 0.059607171424431726, 0.07724834082182497, 0.04683746679802425, 0.02026358346483903, 0.034423254619468935, 0.037546174935414456, 0.015500087265536422, 0.015121396208996885, 0.040333496071980335, 0.06300692766672, 0.01576839313202072, 0.07774830344715156, 0.01788988349289866, 0.08776947899605148, 0.04930559021886438, 0.037806282853125595, 0.06371102543198504, 0.02284213845996419, 0.014998120841482887, 0.019956586656917352, 0.028338675256236456, 0.03377225380972959, 0.028794259305868763, 0.015829963558644522, 0.04809889149328228, 0.04551839949272107, 0.04793249085196294, 0.01629312122531701, 0.05152575467946008, 0.052677100320579484, 0.05413838167442009, 0.04433449212228879, 0.07438407381414436, 0.07064204648486339, 0.060452095422078855, 0.013851825515303062, 0.022371550039679278, 0.0321995575359324, 0.03347289370140061, 0.04893309516774025, 0.012824371224269271, 0.0033135968396891258, 0.0211091178789502, 0.051294560835231096, 0.0327751858276315, 0.0402733709779568, 0.018130339340132196, 0.008109558057185495, 0.04010664008092135, 0.040556218300480396, 0.030638084390375298, 0.045741433423245326, 0.10075018362840638, 0.03845162478683051, 0.06638159189606085, 0.03951930069888476, 0.029324004317459185, 0.0358933526877081, 0.0548079139116453, 0.015244622409227304, 0.047743881441419944, 0.02217761386418715, 0.06442238140152767, 0.04799841954081785, 0.028804781104554422, 0.02487353023752803, 0.06387904766597785, 0.04261376707290765, 0.03867293693474494, 0.054366929762181826, 0.026951348918373697, 0.028321424033492804, 0.045156962441978976, 0.045601931924466044, 0.010566885084699607, 0.019196139473933727, 0.05002872036129702, 0.02874279693060089, 0.012228242958371993, 0.09558215664583258, 0.05860088596818969, 0.019202727889933158, 0.02704378897760762, 0.031027646982693113, 0.03146362163533922, 0.0714474251435604, 0.03417043830268085, 0.13469227793393657, 0.01055235476087546, 0.055624454471399076, 0.038203951553441584, 0.03254982155340258, 0.04875031161645893, 0.019358898025529925, 0.052161355924909, 0.030421520132222213, 0.04661127502913587, 0.033610139071242884, 0.036452616623137146, 0.03103101818851428, 0.026957076443068217, 0.04825839387194719, 0.04609465860994533, 0.03784666310821194, 0.05715067374694627, 0.02512307182769291, 0.1453318851417862, 0.046414060416282155, 0.08848657918861136, 0.12930766999488696, 0.029223031415313017, 0.030416518056881614, 0.058390167978359386, 0.029072522011119872, 0.07486910442821681, 0.15281507890904322, 0.07990486585185863, 0.1482309217681177, 0.11214747908525169, 0.288641833467409, 0.5509001389145851, 0.2764262311393395, 0.45220512547530234, 0.43482426437549293, 0.9935212880373001, 0.922340004472062, 1.8870820524170995, 1.6077801771461964, 1.5177649073302746, 1.3125041965395212, 0.3682667389512062, 0.6317003688309342, 0.9538496355526149, 0.949783141259104, 1.7623498267494142, 1.9551806920208037, 3.411916005425155, 2.3689503455534577, 1.2288637971505523, 0.9796804713550955, 0.9732688497751951, 2.9675058647990227, 2.404536148533225, 4.053285252302885, 4.006843194365501, 3.039535037241876, 0.9675477223936468, 0.02892491625971161, 0.09841546867392026, 0.1339341443963349, 0.06895025406265631, 0.1054110936820507, 0.12525353988166898, 0.035103811460430734, 0.044719644502038136, 0.03778161386435386, 0.018523679464124143, 0.06675316297332756, 0.02150351370801218, 0.023576985258841887, 0.06943577449419536, 0.044325831258902326, 0.04655530967283994, 0.021079426405776758, 0.025850940583040938, 0.03185451452736743, 0.04880244378000498, 0.03648158264695667, 0.06327582261292264, 0.0983148482919205, 0.08796483452897519, 0.0562360212643398, 0.03242655082431156, 0.03840769706584979, 0.0319248775485903, 0.025460626566200517, 0.057378205092391, 0.025699260440887883, 0.04136256917263381, 0.045464912909665145, 0.036380869496497326, 0.011698231701302575, 0.03472951670119073, 0.1116264914162457, 0.016285185811284464, 0.07066275240504183, 0.03889196697855368, 0.02392895064986078, 0.01805302239517914, 0.034707211452769116, 0.013448048011923674, 0.06311784905847162, 0.043491163742146455, 0.017688588923192583, 0.02551802055677399, 0.014305319491541013, 0.0670429048477672, 0.036252028949093074, 0.018607916936161928, 0.044297496060607955, 0.007323077261389699, 0.032772180129541084, 0.04806019220268354, 0.029401835199678317, 0.03422947243961971, 0.10240669435006566, 0.05319240313838236, 0.04807311299373396, 0.0018749559762909485, 0.0487421517027542, 0.037719136162195355, 0.06396017924998887, 0.03184317080012988, 0.026620341777743306, 0.04019803185656201, 0.061207705657579936, 0.019548733835108578, 0.0763771113997791, 0.07961464158142917, 0.09481307643000036, 0.18978673877427354, 0.15061898971907794, 0.16145715111633763, 0.15769046964123845, 0.07450575634720735, 0.10225027188425884, 0.15749000071082264, 0.19954210671130568, 0.19275133672636002, 0.14252392487833276, 0.1658709705225192, 0.19907243113266304, 0.12412288531777449, 0.15900913247605786, 0.09846268410910852, 0.19981823017587885, 0.08162667814758606, 0.15549481089692563, 0.14263946242863312, 0.1273060977109708, 0.18996570026502013, 0.1122537991614081, 0.27691969997249544, 0.14727800415130332, 0.09552990944939665, 0.13385602593189105, 0.17248467891477048, 0.12589448830112815, 0.12847281323047355, 0.1580460325931199, 0.1124927113414742, 0.2641234116163105, 0.11889351982972585, 0.11450505960965529, 0.07895181464846246, 0.14809176907874644, 0.20739316823892295, 0.12789111788151786, 0.13661222881637514, 0.10399771796073765, 0.10448711982462555, 0.1718974916730076, 0.09298075834522024, 0.31963516725227237, 0.12656221340876073, 0.14115015015704557, 0.195471664192155, 0.08828519741655327, 0.24427781871054322, 0.13482246547937393, 0.2604290598537773, 0.146546394971665, 0.14745113236131147, 0.11033994873287156, 0.14771704387385398, 0.18233888607937843, 0.061396916207741015, 0.12099907442461699, 0.20346269477158785, 0.2268785671913065, 0.08245333418017253, 0.08961239494965412, 0.19415981427300721, 0.24664430500706658, 0.20289670326747, 0.13829916017130017, 0.12813320645364001, 0.10031150755821727, 0.19241842412156984, 0.1282467253622599, 0.172436008870136, 0.32921944046393037, 0.23972242721356452, 0.1617397164227441, 0.08180778444511816, 0.11852174837258644, 0.22946251760004088, 0.11886023450642824, 0.1441741199232638, 0.1457812704029493, 0.20829556044191122, 0.26263365405611694, 0.949121086159721, 0.7998501334805042, 0.9956711414270103, 0.8318498788867146, 0.13031463080551475, 0.2408457122510299, 0.356693509966135, 0.2319282290409319, 0.5908460298087448, 0.6156472396105528, 1.4112282427959144, 0.8813237585127354, 0.5221452412661165, 0.41377772809937596, 0.28509306139312685, 1.0376692190766335, 1.1420768103562295, 1.9403433194383979, 1.7273480049334466, 1.1609996762126684, 0.4192218859679997, 0.12650263379327953, 0.49600953119806945, 0.32842727203387767, 0.18122999870683998, 0.2543155144667253, 0.18593555636471137, 0.12535444227978587, 0.21186269324971363, 0.13891738402890041, 0.2755317650735378, 0.1977757507120259, 0.2328807013691403, 0.1718717539915815, 0.1709617770393379, 0.09926575468853116, 0.09093091677641496, 0.12584215204697102, 0.07289053130079992, 0.15400772506836802, 0.11542136708158068, 0.1427554155816324, 0.35413832520134747, 0.11480416738777421, 0.16210001427680254, 0.11740604808437638, 0.1477112848078832, 0.13854559772880748, 0.08317792264278978, 0.21557509404374287, 0.1288988208398223, 0.22594709764234722, 0.367344991536811, 0.10334322534617968, 0.10213720568572171, 0.13885735912481323, 0.07861392965423875, 0.3063031967030838, 0.13083707308396697, 0.17086200270568952, 0.11458944180049002, 0.16499274264788255, 0.06406757544027641, 0.1399773490265943, 0.1520149249699898, 0.1036508975084871, 0.14864459488308057, 0.1468883766210638, 0.09585255815181881, 0.14453716372372583, 0.17219942703377455, 0.11216407350730151, 0.0919507464277558, 0.11752361911931075, 0.06676755321677774, 0.1811066537629813, 0.1446827285690233, 0.08801845469861291, 0.10645554779330269, 0.1792769628809765, 0.16624213341856375, 0.20117658306844532, 0.20391337136970833, 0.11885231579071842, 0.1529010641388595, 0.13669150503119454, 0.08474318630760536, 0.13644079270306975, 0.18020509276539087, 0.1839225846924819, 0.10167740809265524], [0.1028711897379253, 0.025674969947431237, 0.012341494693828281, 0.04951301678374875, 0.015504922357649775, 0.061488285718951374, 0.011260296851105522, 0.03350515115016606, 0.05054400462540798, 0.006379533897415968, 0.005002599482395453, 0.03797766701609362, 0.04767205267853569, 0.032340361503884196, 0.03961544964113273, 0.01991219509363873, 0.041286881241831, 0.03756957856239751, 0.02416240247839596, 0.024080092734948266, 0.08878337146597914, 0.06567860735231079, 0.025766341314010788, 0.01777306017174851, 0.04809345897228923, 0.029647211486008018, 0.03699314132973086, 0.022501908279082272, 0.056241138372570276, 0.023989214896573685, 0.02437176604871638, 0.004694693543569883, 0.06215152083314024, 0.07646083307918161, 0.021762623437098227, 0.03077244466112461, 0.018247528169013094, 0.011395877027098322, 0.05471275573654566, 0.0561832360108383, 0.025102545878326055, 0.04370228620246053, 0.020929492166033015, 0.05574829665420111, 0.03635826738900505, 0.010799102165037766, 0.03955461950681638, 0.020034829431097023, 0.06233003703528084, 0.04645556131436024, 0.04103684055735357, 0.04430322544067167, 0.047904831008054316, 0.13895325944758952, 0.07026148057775572, 0.06435129849705845, 0.034735739609459415, 0.08920033971662633, 0.03296318667707965, 0.006865803434266127, 0.03124286980892066, 0.023305787799472455, 0.032104659112519585, 0.02973238777485676, 0.038539721426786855, 0.050193577335448936, 0.01807476732210489, 0.03821259757387452, 0.01381660968036158, 0.017613012314541265, 0.024157691696018446, 0.019035614786844235, 0.027143654224346392, 0.010303889284841716, 0.06310309516265988, 0.06907068978762254, 0.05370845552533865, 0.11348028725478798, 0.028463586131692864, 0.05198641316383146, 0.06798512069508433, 0.01696394851023797, 0.060955030348850414, 0.07450488061294891, 0.16750054870499298, 0.22003290796419606, 0.12032528597046621, 0.11824713146779686, 0.1641823470708914, 0.1685240148799494, 0.14302223251434043, 0.10252523759845644, 0.06531353006721474, 0.08385615656152368, 0.03574666719941888, 0.02508932080672821, 0.18127117305994034, 0.06839052628492936, 0.11806149064796045, 0.05345511599443853, 0.06708202345180325, 0.060273864946793765, 0.07102298346580938, 0.0785202557744924, 0.01145681570051238, 0.05866742692887783, 0.05632145359413698, 0.027079562350991182, 0.03990668694314081, 0.021345245149859693, 0.045343612582655624, 0.13033729599555954, 0.014501657442451688, 0.06680052683805116, 0.07320609991438687, 0.026946077814500313, 0.03562060970580205, 0.025678615747892763, 0.05528624664293602, 0.007276129463207326, 0.015020430728327483, 0.03552725123881828, 0.06647113943472505, 0.01928494300955208, 0.008298794582515256, 0.05304078607878182, 0.025637762373662554, 0.018477272969903424, 0.023955267206474673, 0.08647655384265818, 0.019194610649719834, 0.05662102521455381, 0.08699473619344644, 0.03384618285053875, 0.05181805696338415, 0.10367928465711884, 0.026190000025962945, 0.0212811495657661, 0.03539925302902702, 0.03867386833007913, 0.035931970342062414, 0.054502182465512305, 0.13389880332397297, 0.0163408839944168, 0.1207693203468807, 0.007028433037703508, 0.09538043348584324, 0.015728508260508534, 0.06646884619840421, 0.015948291584209073, 0.016065675226855092, 0.031795799513929524, 0.017362945654895157, 0.05634412991639692, 0.012644727885344764, 0.02928014895587694, 0.01520820522273425, 0.05328745741280727, 0.01237535889231367, 0.06746647821273655, 0.038218883564695716, 0.028872696893813554, 0.02690408338821726, 0.021566167670243885, 0.029021870432188734, 0.05159150154213421, 0.038656568867736496, 0.035437184196780436, 0.0889252033084631, 0.06541587965330109, 0.11864990985486656, 0.00551581732906925, 0.06414413539459929, 0.03920419592759572, 0.02091927279252559, 0.02293396624736488, 0.034636451382539235, 0.023503308548242785, 0.040740218973951414, 0.01901138552057091, 0.044917979757883586, 0.048865177523111925, 0.009736866195453331, 0.025405462729395367, 0.04513733263593167, 0.04580320237437263, 0.015509404929616721, 0.04157029259658884, 0.08081519903498702, 0.010779088297567796, 0.05390852740674745, 0.02657473123690579, 0.04930181268719025, 0.015961008284648415, 0.02576510563812917, 0.011811463027697755, 0.03553740381903481, 0.02361345996177988, 0.03741241023817565, 0.04483977965719532, 0.03696107312862296, 0.049169031335623004, 0.04828628007089719, 0.0338377409207169, 0.016354992221749853, 0.009179732223856263, 0.024641199051984586, 0.0790442936704494, 0.02757135393039789, 0.032298070218530484, 0.121564012079034, 0.05389155077864416, 0.04412704329297412, 0.016283256227325182, 0.03745001115021296, 0.03931116538296919, 0.048229364765575156, 0.04461769938643556, 0.03673291466839146, 0.008830543392832624, 0.011654746485874057, 0.0219251445014379, 0.05342651733371895, 0.02198515270720236, 0.07624445992405526, 0.025848391305771656, 0.027745997977035586, 0.08470622735330835, 0.09712869592476636, 0.16030363098252565, 0.01970791523490334, 0.04112080714548938, 0.056367474171565846, 0.013386332866502926, 0.025401854036317673, 0.03704840906721074, 0.047223342771758325, 0.02496182540198788, 0.023200441792141646, 0.06161720048112329, 0.049705296114552766, 0.057212179235648364, 0.04479244176764041, 0.036353970353957266, 0.04911200470814947, 0.03981629335612524, 0.09444419934879988, 0.05120286106830463, 0.022265365405473858, 0.025185926169797312, 0.002390527010902588, 0.027643911853374448, 0.06560983252711594, 0.09512384334811941, 0.05525356616999488, 0.07774571335176006, 0.05003155536542181, 0.039000565448077396, 0.018472181836841628, 0.13568031397880986, 0.131666348897852, 0.4305866901995614, 0.24936153029557317, 0.1517023323685862, 0.1379080186598003, 0.0841116631636396, 0.1709130624658428, 0.13698535098228604, 0.16286157653667033, 0.07676929933950305, 0.032008343187044375, 0.09829075817833655, 0.13362910685827956, 0.1046851470891852, 0.14570030209142715, 0.22696986619848758, 0.14968328992836177, 0.0940632178389933, 0.12075141232344322, 0.18645700416527689, 0.08496145193930715, 0.12436947872629389, 0.026088821177836508, 0.04334930592449382, 0.002658935618455871, 0.05369730104575865, 0.08260605332907289, 0.0789106625597924, 0.11110859108157456, 0.08930530166253448, 0.035820199191221036, 0.006313464664344792, 0.0394442658580374, 0.05176421043870505, 0.01529232209577458, 0.06640767096541822, 0.035195975069655105, 0.06407469263649546, 0.015905694162938744, 0.02159772007871652, 0.04593422112520784, 0.03226165674277581, 0.051539922278607264, 0.037710850083385594, 0.025255047949030995, 0.07140195375541225, 0.05469542658829596, 0.0718783754564356, 0.02038113965681987, 0.021899041312281042, 0.02770612423773855, 0.047464974923059344, 0.08260610527941026, 0.021472697881108616, 0.01832705114793498, 0.06966778470086865, 0.08201711461879313, 0.012277644018467981, 0.010591757236397825, 0.049488655786262825, 0.07262266793986782, 0.0064614326765877195, 0.12255489797098562, 0.02908040176407667, 0.07910636690212414, 0.010860817310458515, 0.06253103289054707, 0.022826397507742513, 0.011224683039472438, 0.04921887026284821, 0.027951908705290407, 0.006758579793313402, 0.049891523231053725, 0.0571841742930701, 0.03230940281355288, 0.02548604697949486, 0.03126113777398132, 0.03937172834412195, 0.048429926464450546, 0.02729225259827217, 0.03912398831744213, 0.025593263198970817, 0.04428815984283574, 0.037953977662255056, 0.06459332027588971, 0.03325269106426276, 0.04768708487972617, 0.04123608494410291, 0.028121118375565857, 0.03161722393997479, 0.03451965960266534, 0.07417969376547262, 0.21478513721376657, 0.13014556956477463, 0.1202899671625346, 0.11962849835981615, 0.12611625686986372, 0.12200702229165472, 0.10463439903105609, 0.1001466617162805, 0.19625097862444818, 0.14952194702345878, 0.13306510430993512, 0.09843372550676577, 0.31816417118534446, 0.09864258070592768, 0.13743761577643454, 0.1095714548137039, 0.1614199546747841, 0.07190665870439261, 0.15429542603669688, 0.06561261558090337, 0.188755331619177, 0.1367494964506477, 0.12699889310169965, 0.17558998806634918, 0.12517982977442443, 0.1259361079428345, 0.16775958793004975, 0.16323783056577668, 0.22251077578403056, 0.15068815788254142, 0.0938884865900036, 0.11983576536295004, 0.18442372733261436, 0.13763731287326664, 0.13973297463962808, 0.086788122280268, 0.05518710684555117, 0.07134097890229896, 0.12147095418185927, 0.11940850352402776, 0.19927192042814568, 0.10312399492249824, 0.17155561392428353, 0.16555545385926962, 0.1702725890208967, 0.059698722761822864, 0.17678923933999613, 0.12616877123946324, 0.2414730199961923, 0.19398846721742302, 0.06266044118092395, 0.24031979672145098, 0.2151497543673031, 0.386027253116481, 0.227990408311598, 0.153869136411231, 0.13104105979437009, 0.1968891068827361, 0.13542421365855262, 0.18062786461086944, 0.09695947141153738, 0.14514830749249086, 0.10029816374299116, 0.2107423174311407, 0.14985906018409878, 0.15523320384090766, 0.15719625866040587, 0.1871671949629672, 0.29469864908605814, 0.17692189081571996, 0.35726030298974365, 0.1473955306573771, 0.15422793512698263, 0.14207456930307671, 0.13657041621627286, 0.19099544500932097, 0.1533499892684631, 0.15123004443012178, 0.19450860883807763, 0.20114897517487407, 0.13574326294474304, 0.19330310868099332, 0.15087416977621615, 0.20297171955462545, 0.2310599311022088, 0.3982487035682425, 0.3427802596706897, 0.2775394229684025, 0.32186781463678926, 0.3076519462047145, 0.33659490407444537, 0.3983032365795225, 0.1995932258432731, 0.16006890451535583, 0.16316689609084278, 0.10645804140949622, 0.25589676399249583, 0.1742791326250881, 0.3090175869874656, 0.16253707988653332, 0.24715064268093556, 0.23845190007705241, 0.1518977398518473, 0.21319480380043387, 0.05864650207513478, 0.16867541300598532, 0.190533502609469, 0.12598128989338875, 0.23760457523167133, 0.17601789557375014, 0.1730832803878002, 0.3147664706921205, 0.14203240047208965, 0.19757091795327142, 0.1480167082627304, 0.10861943519557826, 0.14229853462893516, 0.19917554513085634, 0.15726167155662552, 0.2496105059981346, 0.20007750688819215, 0.20819287688937038, 0.2030198700958863, 0.09045773083926179, 0.2279665705282241, 0.1793859843746759, 0.12597710418049246, 0.18188871414167807, 0.11199223663425073, 0.15985501755494624, 0.1296994200674817, 0.2081188847660087, 0.15876909223152325, 0.1629865393624641, 0.11640344368061051, 0.2509403455769643, 0.2045144367730245, 0.11950485655688681, 0.157273382646963, 0.1360170857515186, 0.13032561459112912, 0.09348504769150168, 0.21380714984843507, 0.16051248618168756, 0.20143977832049131, 0.0885716886841692, 0.20407667354447767, 0.11918660879018717, 0.22107080148998648, 0.08649518917081878, 0.1128005245118402, 0.12958303646882996, 0.10401092818938196, 0.18507099885027856, 0.07546669658040628, 0.11425645498093218, 0.3164953482337296, 0.18409356067422777, 0.17419875803170726, 0.13048431545030326, 0.11938917057705112, 0.1590630123973824, 0.17821889778133482, 0.13247431023046374, 0.09358299634186551, 0.17610214417800307, 0.15336158161517233, 0.07705884825554676, 0.18196447257651016, 0.14102321321843192, 0.2067749889101833, 0.1421895279781893, 0.11584606851101853, 0.1060928231163416, 0.12118855214794166, 0.18912701401859522], [0.08545607110136189, 0.01710077642201213, 0.05119256748002954, 0.012821019499824615, 0.016865966463228688, 0.043242392130196095, 0.03571474371710792, 0.024836079610395245, 0.04534853302175179, 0.015475846867047949, 0.002555439414209104, 0.0838279104209505, 0.0224999991041841, 0.04718887372291647, 0.014871987277729204, 0.0661803362891078, 0.025380893930559978, 0.0629823180497624, 0.029365905975282658, 0.012301167316763895, 0.07667633792152628, 0.029450020992953796, 0.03979245557275135, 0.00823895799840102, 0.101329370518215, 0.07947509555378929, 0.02043180793407373, 0.041227227411582135, 0.05142533096659463, 0.02936956847406691, 0.017156229696411174, 0.031164740212261677, 0.06366426270687953, 0.012625797553482698, 0.018605365803523455, 0.015085835275385762, 0.0636948985629715, 0.09108563972404227, 0.041175770602421835, 0.10269754202454351, 0.025143339880742133, 0.03341695432027336, 0.08009350494830869, 0.006150759918455151, 0.03024927693331847, 0.08394853168283589, 0.05276173113088589, 0.02735709960688837, 0.028725271113216877, 0.07723410642938688, 0.055985676299314946, 0.04111669564736076, 0.04081916493305471, 0.05268826964311302, 0.03362134921189863, 0.049105733560281806, 0.041393613209947944, 0.09151617443421856, 0.03084996384131955, 0.05360652896342799, 0.057244381023338065, 0.03868418047204614, 0.028345217288006097, 0.12621916306670755, 0.06742083613062277, 0.07294885668670759, 0.023376777935482096, 0.029080320127832238, 0.03607821425248403, 0.0163250150217209, 0.10133587915333919, 0.04723296100564767, 0.06939913466339931, 0.03623960910772439, 0.08545191507437266, 0.13996470283018425, 0.06007381161907688, 0.03876348266203422, 0.03997605548647698, 0.022721749119227752, 0.07624255260452628, 0.029648925847141072, 0.075195597455604, 0.1503809235873632, 0.07676555149373598, 0.14470002060988918, 0.04817629378521815, 0.13231194316176698, 0.11182064466993324, 0.15490242862142622, 0.013094147470837925, 0.2070182203897275, 0.10212013628915884, 0.06083362241042778, 0.04209035629173741, 0.01648083078180207, 0.015435837685799925, 0.026501095344428904, 0.14500967430649325, 0.015138037015276495, 0.09514088305877522, 0.0249610684113577, 0.02987597294122679, 0.018530197376094293, 0.0521756756643299, 0.028506389498943463, 0.03520643193041906, 0.05245768807071727, 0.035290398518554866, 0.07595251387101598, 0.08187226223526523, 0.10690718176192604, 0.028600260047824122, 0.07575107272714376, 0.05006047314964235, 0.026756830156955402, 0.1152829713828396, 0.06062235152057838, 0.0606201992923161, 0.062264713196782395, 0.016134364705067128, 0.03423450420086738, 0.04921618368825875, 0.1095020491629839, 0.0018079857295560942, 0.05488514550961554, 0.019750520077650435, 0.019202521943952888, 0.08597615335020237, 0.04331193136749789, 0.030763165959797334, 0.046406086039496586, 0.0662994732556399, 0.017092911512008868, 0.03492336196359247, 0.04036299273138866, 0.005219094164203852, 0.03004791185958311, 0.08554763728170656, 0.09320330616901629, 0.07369668921455741, 0.05697740452887956, 0.07057716793497093, 0.057310046249767765, 0.02287413430167362, 0.031348533084383234, 0.026581757520034444, 0.015961169701768085, 0.00986457867838908, 0.017403568963345606, 0.00480236386465549, 0.05374207110435236, 0.04749947736854665, 0.06440066616050899, 0.13085525570204481, 0.0659657220239751, 0.013887388304283377, 0.021674589879694395, 0.03136161343718413, 0.01999036736378912, 0.051492951752152294, 0.02099535777233541, 0.034306088055018336, 0.03943515599530656, 0.07004282902926207, 0.0068626335360022495, 0.03843121572572272, 0.038661971702822484, 0.023613168668816797, 0.059023227368015796, 0.049713960688677616, 0.02053306656307541, 0.024565872918174136, 0.03196432640834246, 0.06761836615623906, 0.014581308441847796, 0.039277163887163624, 0.08031755933188833, 0.02731699209107319, 0.03553123657184187, 0.043188423151150346, 0.022651588333246764, 0.08062201799475588, 0.022052415406506043, 0.025065674126381055, 0.029584524127130862, 0.04809982288861647, 0.04347485875769053, 0.017031951501849107, 0.02738687086093705, 0.029120806138962507, 0.03407057862204965, 0.054222886319621466, 0.023229116522998083, 0.08557805049349554, 0.00887130028786487, 0.12430644812411629, 0.037489163150894456, 0.00967963083894574, 0.037249605302349664, 0.022823516119387932, 0.07793960685376078, 0.00910725964786252, 0.07384537108009681, 0.06443851569201797, 0.06689233792712912, 0.06252645383938216, 0.04500088136410341, 0.025380762199347373, 0.02576176411821507, 0.014617651413573185, 0.01574459245603066, 0.04067127716552932, 0.07779870269587263, 0.04844730756303761, 0.004880371006947826, 0.027774362861237023, 0.02196192534029251, 0.041323554469272494, 0.025313939222542103, 0.04705446335719898, 0.05973417886707466, 0.01385893714541453, 0.025998685487138573, 0.01331091953034047, 0.12737024895614013, 0.05406556956586428, 0.031183549945126288, 0.023058339065755717, 0.07781313004670665, 0.023678071338508744, 0.050804476195480675, 0.027807035912701394, 0.025768244922801387, 0.013552709388022777, 0.0458373151923297, 0.06171712695504539, 0.04269942204700783, 0.023981270205695182, 0.11634094742476009, 0.030211330922611523, 0.03231558861443773, 0.030625458603026345, 0.013790244884148706, 0.09883412159979343, 0.017490576501586474, 0.07974214255227707, 0.07244470834848471, 0.053046723260194995, 0.030634251197625417, 0.01964649694855325, 0.050191328627988696, 0.05180225292860996, 0.017298402926826384, 0.05014773858420085, 0.08881579589797184, 0.056745620677247643, 0.044970501548959874, 0.06491802472737618, 0.11230561591219157, 0.12970899377251044, 0.15617864060914144, 0.10993965654051863, 0.019274708793091122, 0.07082439216901548, 0.026214088284177706, 0.10297880857251585, 0.0566617505683098, 0.0986409405595623, 0.09187060932163149, 0.14740102255018428, 0.01831143079471076, 0.06507704471005127, 0.07861764781409875, 0.06923792534507811, 0.07479189138393849, 0.0865176465595141, 0.045750109129585326, 0.06571812671609223, 0.029788199135509785, 0.13370139204198495, 0.06246050659683533, 0.06121235521277413, 0.12944327521836385, 0.03757683305593673, 0.07072656968375668, 0.10787656021420844, 0.09859247831627727, 0.023681171660427935, 0.034998934861505404, 0.06106893146352377, 0.01565567759826081, 0.06613494653720409, 0.0796767593419645, 0.05250532653008122, 0.041493086973787285, 0.022728302283212543, 0.025018375199579168, 0.022917366259207483, 0.0236741416665609, 0.04790949540620204, 0.09664741315646097, 0.012426163539203117, 0.014215448190952884, 0.055308997179963626, 0.09369899402372539, 0.05543411956750788, 0.029462425991368946, 0.07034939539153129, 0.009972888638003496, 0.035482948733260855, 0.022514389347634278, 0.03362423987709917, 0.048085595917655155, 0.012397812570270617, 0.030741274458705448, 0.09412506100488827, 0.011136312732560327, 0.05033140529121738, 0.030740087022422813, 0.05843518294568639, 0.00427521683377563, 0.027494688220031094, 0.04954476957209408, 0.04689387744292617, 0.046150371636031196, 0.03036134865396889, 0.047376726142829284, 0.017252833204111084, 0.03899314397131093, 0.09639172843890265, 0.02795169348246418, 0.015562078860966722, 0.022645966564596165, 0.0480151178635424, 0.060949660910409875, 0.011219956486456795, 0.01757678808644414, 0.05126045172801241, 0.05199899256695062, 0.05740146771131549, 0.0405157823843183, 0.04730620355985593, 0.041636855821707286, 0.05355327986762859, 0.098086467187386, 0.050379989988869056, 0.014829251631454099, 0.05019182586693205, 0.07223868073197082, 0.029078628031129483, 0.03945829987060279, 0.21033477445598692, 0.16975125996395946, 0.06237645837245509, 0.08918866573367268, 0.08375805206014775, 0.1418083906173706, 0.16565510944928974, 0.13793139631161466, 0.07326861101319082, 0.15649961947929114, 0.08446976426057518, 0.18157016951590776, 0.15386509912787005, 0.18309531267732382, 0.15356684481957927, 0.21205934754107147, 0.16886905417777598, 0.1820902814506553, 0.10467177358805202, 0.1322922614053823, 0.3996933385496959, 0.09878262397251092, 0.11722063733031973, 0.13345640909392387, 0.21916927071288228, 0.22086755692726, 0.1234516424301546, 0.23733199923299253, 0.16561446944251657, 0.1738774377736263, 0.13418286776868626, 0.12375444610370323, 0.22672265680739656, 0.11895963034476154, 0.11757660846342333, 0.13598079473013058, 0.15966009988915175, 0.2890716854017228, 0.15159783797571436, 0.12933989404700696, 0.10386580863269046, 0.09503330875304528, 0.1783514305134304, 0.10921027380391024, 0.10000529742683284, 0.16797009069705382, 0.14102701301453635, 0.12527136626886204, 0.13573705859016627, 0.3103475453099236, 0.20846619503572583, 0.0775582468486391, 0.16187015629839152, 0.2219301788136363, 0.1631902885856107, 0.15348612883826718, 0.12471331574488431, 0.20733440498588607, 0.10191108071012422, 0.1889509617467411, 0.11286670182016678, 0.27069456526078284, 0.14503324491670355, 0.20067664270754904, 0.18130341195501387, 0.21241415350232273, 0.07826679007848725, 0.1317425971501507, 0.25905219779815525, 0.1123950669716578, 0.3019498474895954, 0.15576738689560443, 0.24368640122702345, 0.09540608953102492, 0.16823557176394388, 0.18981005705427378, 0.18645360512891784, 0.1537478546379134, 0.18357189022935927, 0.195193818944972, 0.28741129324771464, 0.1218986687308643, 0.12701375089818612, 0.26468052703421563, 0.22281777259195223, 0.39312705339398235, 0.2493293210864067, 0.3944162232801318, 0.3866497369017452, 0.17901951185194775, 0.27737656608223915, 0.40348514914512634, 0.2700729720527306, 0.2027093555079773, 0.1346831940463744, 0.14700289000757039, 0.19295875215902925, 0.16521342768101022, 0.39150350145064294, 0.12128325761295855, 0.1526004052720964, 0.17607645102543756, 0.1418708052369766, 0.15448231366463006, 0.13728838472161442, 0.11468075565062463, 0.10268359706969932, 0.25995933974627405, 0.16062230919487774, 0.1852556600351818, 0.25568872515577823, 0.1976895279949531, 0.08720118683413602, 0.14852398104267195, 0.16597279318375513, 0.12111888674553484, 0.20803233550395817, 0.21955098694888875, 0.21152923145564273, 0.19317823491292074, 0.12526338075986132, 0.17643146478803828, 0.11930616878089495, 0.15909872454358265, 0.12114567085518502, 0.25743752194102854, 0.14242643635952845, 0.1434459543088451, 0.1817631279118359, 0.2243231300963089, 0.1890075727715157, 0.09929839434335008, 0.13320173369720578, 0.1499426705413498, 0.13010205002501607, 0.09499109539319761, 0.118999275873648, 0.16325748263625428, 0.18846512219170108, 0.13215548358857632, 0.3060431481571868, 0.18979123618919402, 0.12774203525623307, 0.19466040772385895, 0.11837614641990513, 0.13192276092013344, 0.11660364543786272, 0.10201417986536399, 0.12183226135675795, 0.11867014822200872, 0.1344595552654937, 0.16329227451933548, 0.0778508534131106, 0.18003448785748333, 0.19326487323269248, 0.14602037554141134, 0.10367665003286675, 0.07844802254112437, 0.12251202409970574, 0.1709131960524246, 0.16425221285317093, 0.0987074889417272, 0.1453645247966051, 0.10347085248213261, 0.20598869828972965, 0.09029084409121424, 0.1643896586028859, 0.14090389071498066, 0.1133643341017887, 0.22888123785378411, 0.16693051991751418, 0.1106844685273245, 0.16855025722179562, 0.13382015051320195, 0.12771558511303738, 0.14759929472347721], [0.04537410743068904, 0.06411904338165186, 0.019487508507154416, 0.054002457327442244, 0.03528217181155924, 0.03370081838511396, 0.030200614310160745, 0.03854367707390338, 0.024921333824750036, 0.027427191744209267, 0.022457399827544577, 0.02202822139224736, 0.0504154349619057, 0.03566889754438307, 0.0540630425530253, 0.02253826238302281, 0.0725762837100774, 0.056656214146642014, 0.043914436537306756, 0.0393623550189659, 0.018826099076250102, 0.027216021044296212, 0.0503530017886078, 0.04588681644236203, 0.02858733554603532, 0.041300362354377285, 0.024871446657925844, 0.030472555772576015, 0.020970621990272775, 0.06240403658011928, 0.048149583890335634, 0.03345245866512414, 0.05181780092243571, 0.06602136083529331, 0.08083245396846905, 0.019172028951288667, 0.022226436049095355, 0.04146882245549932, 0.07562371276435442, 0.03751589902094565, 0.05381499824579805, 0.045482768982765265, 0.05405468225944787, 0.01537214286145172, 0.05340036404959392, 0.057267276279162616, 0.04985241575923283, 0.009310553377872566, 0.04977193726517726, 0.01919785197969759, 0.04407516717037652, 0.031021908325783443, 0.0464961159741506, 0.03670008576591499, 0.049482688918942586, 0.10654952595359646, 0.08825398268527351, 0.015210133879008936, 0.02147908406186616, 0.0638424523640424, 0.057330726194777526, 0.06432236958062276, 0.05376971610530745, 0.041755848069442436, 0.06228222788195126, 0.07815617296728306, 0.02519258880056441, 0.02742795430094702, 0.028421767965483014, 0.014558676648448454, 0.022559725293831434, 0.04820553811441641, 0.07800041843438521, 0.02069736878183903, 0.07931603846373037, 0.02256870528071886, 0.032167385434149764, 0.0704395811771974, 0.0735237316985149, 0.026613903646648396, 0.0258613287951448, 0.013630204448418226, 0.06284705421421677, 0.0677124853245914, 0.11448253542766906, 0.07772933415253647, 0.004029334495498915, 0.07573525756015442, 0.09211849406710826, 0.038622508000116795, 0.06385472006513737, 0.09477226572926156, 0.009107406222028658, 0.03455305995885283, 0.057173505920218304, 0.047196651430567726, 0.08864443399943411, 0.0380024807236623, 0.03941531838790979, 0.050398636449244805, 0.009583071860106429, 0.0688885519048199, 0.018087419084622525, 0.01321902773270267, 0.010426693388581043, 0.032923522594501264, 0.1329677493777126, 0.030279122402134817, 0.024170454780687578, 0.04465013866138179, 0.06780119423638098, 0.0275241885901778, 0.06611111617530696, 0.047133557745837606, 0.051574810640886426, 0.029987760790390894, 0.05797444282507058, 0.05363816300814506, 0.042062236316269264, 0.03832203467027284, 0.049458405846962705, 0.01481263680034317, 0.09961196657968685, 0.0719368715363089, 0.09267626999644563, 0.03946127959352452, 0.06817416797275655, 0.027332343415764626, 0.016858140515978448, 0.028136449291196186, 0.03131006014882587, 0.14090880373260006, 0.08554077241569757, 0.05151527555426583, 0.032501262830919586, 0.04106234817299992, 0.042174081681878306, 0.014388013296411373, 0.050785325074684806, 0.009120389167946996, 0.033567944265087135, 0.07788626870024018, 0.017752545354596805, 0.16850023646838963, 0.06894827994983643, 0.015483731258427724, 0.02607679653010564, 0.017367982982250396, 0.039027809689287096, 0.05425704366643913, 0.057633845281088725, 0.04336342157330364, 0.07751934346742928, 0.025617735518608242, 0.02248307442641817, 0.042508229962550104, 0.06444698359700851, 0.05399578541982919, 0.028081721466151066, 0.059404553976492025, 0.030241052081692033, 0.023157452887971886, 0.041104197880486026, 0.047847808091319166, 0.005169660635147011, 0.049742440605768934, 0.04128948618017603, 0.05052799650002271, 0.032799721229821444, 0.013121596730343299, 0.0507986280717887, 0.06963078121771105, 0.0038578480553042027, 0.010367277973273303, 0.07186817834735848, 0.02061165629129391, 0.01948983142938232, 0.08251731473137625, 0.04380955622764304, 0.03557955409632996, 0.040796818866510876, 0.042700383128249086, 0.024203172361012548, 0.0565134657517774, 0.034625987100298516, 0.013236335544206668, 0.018937439781439025, 0.009756858726177597, 0.024793732663965784, 0.007464058880941593, 0.03974306193413213, 0.020331306295702234, 0.01647443903493695, 0.01207796361995861, 0.06282490852754563, 0.018783885716402438, 0.016916350868996233, 0.025906423543347046, 0.04119393095606938, 0.09320428580394946, 0.011693442065734416, 0.017304202810919378, 0.05705984600353986, 0.030243352739489637, 0.02881098731450038, 0.08108145193546079, 0.05190018673602026, 0.0729220503126271, 0.009866421059996355, 0.04428549924341496, 0.07407878394587897, 0.028315035997366067, 0.12685202207649127, 0.017001621781673748, 0.02636537694343133, 0.02823939074005466, 0.01792890932847513, 0.019842891488224268, 0.038988123342278413, 0.03636448658653535, 0.06884397109388374, 0.059014688958995976, 0.01947985696460819, 0.02084691896016011, 0.02745567908277735, 0.07217108592158183, 0.07709635639912449, 0.026197399238299113, 0.019768628480960615, 0.03182562271831557, 0.03345885968883522, 0.025311877907370217, 0.015606196757289581, 0.008063017048698384, 0.0274777783852187, 0.06244624993996695, 0.053666539024561644, 0.03156475780997425, 0.026477431965759024, 0.03923723634216003, 0.07017951778834686, 0.03301677345007192, 0.0433451276330743, 0.04016405262518674, 0.04534031373623293, 0.054141097934916615, 0.005319251167748007, 0.022692664351779968, 0.0819572975160554, 0.03311709326226264, 0.03676034073578194, 0.07468785712262616, 0.057952456700149924, 0.11968298684223555, 0.046477258001687005, 0.03071486142289359, 0.08010696750716306, 0.024957608147815336, 0.053155318018980324, 0.08912900448194705, 0.028344356396701187, 0.1085942392819561, 0.036986525083193555, 0.03354402113473043, 0.02265836785227293, 0.04933502008498181, 0.05121539594256319, 0.06033020137692802, 0.10174314011237584, 0.0097860501773539, 0.08170345332473516, 0.06302041991148144, 0.08948715010774322, 0.016549657557334285, 0.07699158741161227, 0.006175125554364058, 0.03342827949381899, 0.11227409690036438, 0.04005380287708249, 0.04429129170603119, 0.019744393648579717, 0.04459447016415652, 0.06728793974616565, 0.062479127082042396, 0.07116041437257081, 0.03825085157586727, 0.04991556881577708, 0.05071787498309277, 0.05230986338574439, 0.038030541327316314, 0.08214379922719672, 0.02849747073923936, 0.027071651056758128, 0.0018057543002214516, 0.015185182874120073, 0.020344766999187414, 0.06097452656831592, 0.020601824689947534, 0.048414307966595516, 0.0528959596704226, 0.08405702625168487, 0.035773870622506365, 0.04715612645668443, 0.019242772323195823, 0.024105819284159224, 0.029687725327676162, 0.05238154000835493, 0.00345089346410532, 0.016403723493567668, 0.02118141233950155, 0.02499854872439755, 0.041589506799937226, 0.021848653195775114, 0.01230970665346831, 0.07242412117193453, 0.055507562501588836, 0.043479148371261545, 0.017785031013772823, 0.01736832993628923, 0.06116454234870616, 0.07338729526964016, 0.054735324447392486, 0.053336131168180145, 0.03349454957060516, 0.05963890565908514, 0.04688390668889042, 0.02017042166698957, 0.02647318317031022, 0.02056274504866451, 0.02242035738163395, 0.049816677637863904, 0.04955466240062378, 0.04670209535106551, 0.04584816539136227, 0.04729217696876731, 0.01510157158918446, 0.010012446964537958, 0.024048441991908476, 0.02719259700825205, 0.08908684307243675, 0.03871270120725967, 0.017150088424386922, 0.04913490738545079, 0.029091311334923375, 0.018546101600804832, 0.005332516129783471, 0.06649571936577559, 0.039869427419034764, 0.008839780348353088, 0.033903287403518334, 0.029264962759043556, 0.050459767153370194, 0.1241645346453879, 0.18313990090973675, 0.16720511455787346, 0.07944097902509384, 0.1909929810790345, 0.1616816656314768, 0.1794342091307044, 0.1805780516588129, 0.07658290895051323, 0.09628402054659091, 0.1439012767514214, 0.10140852056792937, 0.12386147864162922, 0.0818880254519172, 0.17877677018987015, 0.08178969088476151, 0.12342186746536754, 0.13488499884260818, 0.17915634904056787, 0.13514354825019836, 0.1305181425414048, 0.14615264110034332, 0.1435190558549948, 0.16806423955131322, 0.19413581321714446, 0.14135741716017947, 0.12030520345433615, 0.11606106869294308, 0.1237814305932261, 0.15215611114399508, 0.2153155650012195, 0.13251215976197273, 0.12912070815218613, 0.14102092740358785, 0.17074872128432617, 0.10455777970491908, 0.21955400006845593, 0.11007998182321899, 0.1774694028426893, 0.17321823252132162, 0.12783000944182277, 0.10942456152406521, 0.12733658513752744, 0.11700171118718572, 0.22282066696789116, 0.1336407140479423, 0.11142017436213791, 0.11947379767661914, 0.1021427643718198, 0.1209316132008098, 0.23900868894997984, 0.1101858788751997, 0.14197353331837803, 0.09248302216292359, 0.08262477029347792, 0.2185012784320861, 0.19960256206104532, 0.12600201065652072, 0.11755104889743961, 0.12607049604412168, 0.1472640220890753, 0.13664310215972364, 0.16200442565605044, 0.12131953379139304, 0.18580195493996143, 0.17814086837461218, 0.16818792588310316, 0.1226015345309861, 0.0924256541475188, 0.1614061210420914, 0.16200791375013068, 0.13377260853303596, 0.3139064402785152, 0.18034519540378824, 0.12419376042089425, 0.12955355836311355, 0.3095409495290369, 0.1634253267548047, 0.15781690191943198, 0.21126599167473614, 0.22545407409779727, 0.09565533982822672, 0.24438822059892118, 0.14741582097485662, 0.23213543667225167, 0.22073048225138336, 0.1675856878864579, 0.26274556992575526, 0.2575736021390185, 0.18955550040118396, 0.17628538043936715, 0.17771086801076308, 0.2851536206435412, 0.17383848986355588, 0.1561093091731891, 0.22244411607971415, 0.21595802740193903, 0.09232762386091053, 0.37084968003910035, 0.11125566248665564, 0.11694358618115075, 0.2609845425467938, 0.13463608251186088, 0.2717493649106473, 0.10995481861755252, 0.1104016657336615, 0.23915599042084068, 0.21865116257686168, 0.13814191392157227, 0.1466406328836456, 0.20243496866896749, 0.1384257260360755, 0.12005553013295867, 0.14923850598279387, 0.15136934554902837, 0.13259103521704674, 0.15628933935659006, 0.11978442358667962, 0.14189226814778522, 0.1260102039668709, 0.11708329548127949, 0.13139588059857488, 0.1228285871911794, 0.1057609124109149, 0.2140146098099649, 0.13276505400426686, 0.2805607358459383, 0.07748130839900114, 0.11369948799256235, 0.1782190758967772, 0.13628932036226615, 0.27524882869329304, 0.19805105781415477, 0.12180054196505807, 0.12288352096220478, 0.15169163059908897, 0.07358357848715968, 0.09806715650483966, 0.14762458711629733, 0.14501035708235577, 0.11418795475037768, 0.12285825083381496, 0.0974287091230508, 0.27456091716885567, 0.16562920849537477, 0.1354963652556762, 0.12203679725644179, 0.16038246190873906, 0.1509347587125376, 0.1310158713022247, 0.12885436619399115, 0.14230030094040558, 0.23372174764517695, 0.0927539802796673, 0.16883656295249239, 0.09191981371259317, 0.1853969501098618, 0.1786333427298814, 0.11966797319473699, 0.13553893484640867, 0.08308265314553864, 0.14299753383966163, 0.20811205700738356, 0.14116834761807695, 0.1484720010193996, 0.2095233992440626, 0.15618079283740371, 0.15027544955955818, 0.04825334355700761, 0.09885027073323727, 0.14246373670175672, 0.16300953109748662, 0.19634578056866303, 0.1272474680445157, 0.243226729799062, 0.09093744767596945], [0.04809305079106707, 0.07032287103356794, 0.010459417462698184, 0.026755234539450612, 0.021607581365969963, 0.019161663003615104, 0.04020959822810255, 0.11070391279645264, 0.05626223392027896, 0.0014866004175928538, 0.016292692635033745, 0.06347608374198899, 0.054391268495237455, 0.0033296722222075914, 0.0319380692235427, 0.03352930063556414, 0.031477451557293534, 0.05351219828298781, 0.04029683397675399, 0.03785093787882943, 0.10524878598516807, 0.044643444489338435, 0.017740702533046715, 0.04655402575735934, 0.04009867683635093, 0.07342867000261322, 0.04855979117564857, 0.07872119967942126, 0.09302266742452048, 0.032097200528369285, 0.0177006914964295, 0.002592844584796694, 0.03217661775124725, 0.0705274885694962, 0.027604026981862262, 0.0063932311604730785, 0.042074114389833994, 0.01447592625481775, 0.045940811396576464, 0.049875619006343186, 0.047054314927663654, 0.10630403092363849, 0.029345521033974364, 0.05088692509161774, 0.04116231546504423, 0.013618426564789843, 0.08067555652814917, 0.02841789580998011, 0.03647937475761864, 0.05744138041336555, 0.027487096049298998, 0.026442846028658096, 0.016148250288097188, 0.06653332398855127, 0.07587808388052508, 0.05412612510554027, 0.06551633676281199, 0.03209767921362072, 0.024100770824588835, 0.07682505689444952, 0.005789736615042784, 0.025837810135271866, 0.027335005870554596, 0.036812402395298705, 0.0364209343388211, 0.02653213381563546, 0.021906099136685953, 0.11172760903718881, 0.04641359286324587, 0.0443702339543961, 0.0070169594346225495, 0.030835955803922843, 0.05804378910397645, 0.014190771780704381, 0.011032746951968875, 0.030707464065926615, 0.03468076502031181, 0.01832709753216477, 0.05879178119357675, 0.1086217284318991, 0.05078533991763834, 0.05318519688444212, 0.06826545955846086, 0.022032633460185025, 0.05439229636976961, 0.028980512397538405, 0.08987061781226657, 0.005954787475275225, 0.06930583927896805, 0.07503846994950436, 0.07479088206309825, 0.010828690665221075, 0.046483992991852574, 0.07863683975301683, 0.008961824678408448, 0.05713385668059345, 0.07967489655129611, 0.05790751594759058, 0.0827842133003287, 0.02503288233128842, 0.02025015801336849, 0.02598914703412447, 0.052889599464833736, 0.05862826750671957, 0.035233156668255106, 0.06817179310019128, 0.02464398025040282, 0.034184902760898694, 0.04187459169770591, 0.021176770205784123, 0.015545167170785135, 0.02189257906138664, 0.02992218462168239, 0.04444051162863616, 0.07999788664164953, 0.02856837738363538, 0.06948173569981009, 0.016317728986905422, 0.03181985994160641, 0.03520226848195307, 0.026188612209807616, 0.027208291576243937, 0.014935930721549084, 0.04398378652695101, 0.08316690174979158, 0.02387236374488566, 0.020730180985992774, 0.004023049896204611, 0.008281432965304703, 0.024944294018496294, 0.006823324292781763, 0.03127272269921377, 0.04545684205368161, 0.056436868690070696, 0.025017152511281893, 0.02323808537767036, 0.0422580519807525, 0.057426088460488245, 0.020742068336403463, 0.051571574877016246, 0.02597372149466537, 0.05414004408521578, 0.016914961197471712, 0.052507282089209184, 0.0774914090288803, 0.04515789383731317, 0.007498617915189243, 0.030029924055270385, 0.053873171491432004, 0.05780509585747495, 0.008750007382332115, 0.011728655117622111, 0.0327567508793436, 0.046796411188552156, 0.021140082135389093, 0.05530739785172045, 0.01937241253472166, 0.054389891811297275, 0.016545202815905213, 0.09296046060626395, 0.0350468738906784, 0.05565469698922243, 0.03684562092530541, 0.05201428080908954, 0.0273900695174234, 0.03588551189750433, 0.048169677538680844, 0.031223985861288384, 0.014739576072315685, 0.06453719164710492, 0.10377095473813824, 0.05842701189976651, 0.03165924434142653, 0.04251654943800531, 0.06355382371111773, 0.04681863108999096, 0.02326528323465027, 0.015422690539708128, 0.06446895858971402, 0.02332785184989916, 0.056867896928451955, 0.032379413314629346, 0.070612917188555, 0.07661131836357526, 0.07429309393046424, 0.08252054307376966, 0.026895942028204445, 0.029035332991043106, 0.02938682711828733, 0.04523707728367299, 0.040081433035084046, 0.03782043560931925, 0.048887245284277014, 0.02871307577152038, 0.02549610122514423, 0.03045939934963826, 0.03966555574152153, 0.016654947903589346, 0.006648909384239232, 0.079340996890096, 0.1098363273194991, 0.05956121392955538, 0.0387673603836447, 0.11390887753805146, 0.027578545341384597, 0.051623146719066426, 0.06552896069479175, 0.03973147329816129, 0.060863189573865384, 0.04898558727290947, 0.06823089774115942, 0.03055342018342344, 0.040791505089146085, 0.07840874066459946, 0.04512186256761197, 0.03341370371344965, 0.011521569940668996, 0.09496187703916803, 0.03145349874102976, 0.02125219652953092, 0.03788070542213973, 0.06324555040919222, 0.03907465405063704, 0.03018135186721338, 0.026758806125144474, 0.08397520447033457, 0.05119941008160822, 0.005324849280441413, 0.07409433193970472, 0.048023960553109646, 0.05159304149856325, 0.005960218140899087, 0.04911190080747474, 0.053545550399576314, 0.008375178276764927, 0.057939491380238906, 0.008725121315364959, 0.047844490691204555, 0.028543250118673313, 0.006637636161030969, 0.006000172124913661, 0.08402300620218739, 0.03635089786257595, 0.04133847905904986, 0.01924380205309717, 0.08075892939814366, 0.02328054550162051, 0.011760085999412695, 0.044178585449117236, 0.0347337951825466, 0.012716000037471531, 0.03765933019167278, 0.03568778891349211, 0.04080174672708381, 0.040776105524855666, 0.09414072032086551, 0.03166060989315156, 0.048229858293780126, 0.04264041759597603, 0.0665783129807096, 0.05414321305579506, 0.08020554698305205, 0.04406049120007083, 0.06026248411217239, 0.0672676568501629, 0.06557225759024732, 0.13949796615634114, 0.022498585312860087, 0.08180608492693864, 0.034247491785208695, 0.056918195987236686, 0.036477909015957266, 0.07386286350083537, 0.04744698526337743, 0.024633935281599406, 0.06522989744553342, 0.021319722691259813, 0.027944576286245137, 0.04392077447846532, 0.0322360971767921, 0.08657143000164069, 0.05003729216696229, 0.05094074193038978, 0.031709918184787966, 0.059216994704911485, 0.0960463032242842, 0.015700464355177246, 0.11499499581987038, 0.035034108950640075, 0.032382315112045035, 0.02202322859375272, 0.05920500530919526, 0.05902105287532322, 0.08462767844321206, 0.04985920269973576, 0.04039490508148447, 0.029364367874222808, 0.025320163986179978, 0.04557353364361916, 0.01779823567630956, 0.07756621009320952, 0.06425820349249989, 0.05813518087961711, 0.10906148803769611, 0.052893373285769485, 0.060453219775808975, 0.02676036092452705, 0.04003963898867369, 0.05483667955559213, 0.03344879616633989, 0.06416693417122588, 0.03197356243617833, 0.07508964103180915, 0.013989450308145024, 0.0509238506492693, 0.02639248388732085, 0.035369778634049, 0.05058770228060894, 0.034277036684216, 0.06249405167181976, 0.062489294505212456, 0.05924073229834903, 0.05281013771309517, 0.00881630900039454, 0.041015752431121655, 0.024216375168180093, 0.04120292578591034, 0.06285210823989473, 0.040901246466091834, 0.021139785276318435, 0.06591817262233235, 0.03420998364163097, 0.04364803520729765, 0.043764426227426156, 0.0685179307765793, 0.044357112783472985, 0.03010303116752766, 0.035117860315949656, 0.02357791850954527, 0.06558280350873247, 0.05261801052256487, 0.027674193333950825, 0.07475780454115011, 0.027506121004989836, 0.013479161625582492, 0.035450999275781214, 0.03792330840951763, 0.06485212201368995, 0.012688068381976336, 0.032338250093744136, 0.0464488856960088, 0.028442245675250888, 0.11251511677983217, 0.11272045419900678, 0.13966857106424868, 0.07783497145283036, 0.09956792753655463, 0.09062908531632274, 0.18099674169206992, 0.1474477184819989, 0.20275538350688294, 0.1401054734014906, 0.09260972161428072, 0.1938732116832398, 0.12259328927029856, 0.1638715949957259, 0.10258067602990195, 0.1417991879861802, 0.1195647701388225, 0.23968419176526368, 0.19304113055113703, 0.11208113850443624, 0.17169387603644282, 0.12456176918931305, 0.09214577541570179, 0.22142321773571894, 0.24238553509349003, 0.13552879710914567, 0.08006617907085456, 0.20428726536920294, 0.21582277840934694, 0.12198829048429616, 0.18809758097631857, 0.13654827052960172, 0.25054831348825246, 0.17200986767420545, 0.1457270490936935, 0.13910853158449754, 0.1997285193647258, 0.12444592735846527, 0.1346301898593083, 0.11139149777591228, 0.119409512844868, 0.20700867637060583, 0.10691009840229526, 0.07948101789224893, 0.19069573609158397, 0.1101069143624045, 0.15373543108580634, 0.09682427436928265, 0.15891839750111103, 0.22270550049142912, 0.10310389014193788, 0.07372103165835142, 0.17162050731712952, 0.1132675060944166, 0.14816524169873446, 0.3406345919938758, 0.1442046370357275, 0.1195001439191401, 0.0805359437072184, 0.13744239520747215, 0.08776085524004884, 0.1743532286491245, 0.10761093071778305, 0.15902531129540876, 0.10572066574241035, 0.0901448933291249, 0.11833377720904537, 0.22515904071042314, 0.16942811402259395, 0.2336998246028088, 0.11043190083000809, 0.1606337382690981, 0.19511938153300434, 0.09112930769333616, 0.0997215298411902, 0.15386073529953137, 0.09159994064248167, 0.09601211990229785, 0.13065625622402877, 0.25788560102228075, 0.08765273174503818, 0.11665471261949278, 0.1759743908769451, 0.12580039881868288, 0.20166156173218042, 0.16810476081445813, 0.20124290138483047, 0.15744318603537977, 0.20363191928481683, 0.2045628396444954, 0.3218856261810288, 0.17310639086645097, 0.19454767549177632, 0.11273759038886055, 0.08948363974923268, 0.08322748326463625, 0.11660754913464189, 0.1473025543964468, 0.2585949457716197, 0.06947060348466039, 0.16396354709286243, 0.21592044504359365, 0.1077030757733155, 0.12505422870162874, 0.20376081549329683, 0.18844857229851186, 0.22387205273844302, 0.10191511799348518, 0.1253885217010975, 0.17290866788243875, 0.18460065533872694, 0.17054276046110317, 0.14092303812503815, 0.1696779951453209, 0.08858123270329088, 0.22504212276544422, 0.1548887582612224, 0.1701186379068531, 0.14316279528429732, 0.13435810367809609, 0.10519677627598867, 0.18275211390573531, 0.14239750744309276, 0.1507258738274686, 0.22846355714136735, 0.14756570511963218, 0.16119278327096254, 0.15907942870398983, 0.12664456211496145, 0.17677263007499278, 0.12654005287913606, 0.06578713160706684, 0.21504291478777304, 0.2114044170593843, 0.09672182088252157, 0.11796754959505051, 0.14408811985049397, 0.13820575346471742, 0.09292390241171233, 0.10823086893651634, 0.11276143559371121, 0.10633624013280496, 0.2010440206504427, 0.12720642727799714, 0.24164078989997506, 0.0996200559893623, 0.14285141980508342, 0.13790543598588556, 0.13719901529839262, 0.1632669079117477, 0.13813464087434113, 0.15930581343127415, 0.1536629381007515, 0.10193392401561141, 0.1490189490141347, 0.18621162045747042, 0.10859568646992557, 0.15710498933913186, 0.1054622202354949, 0.12223481709952466, 0.26798771519679576, 0.15041745209600776, 0.1923156515113078, 0.16160040046088398, 0.18026710662525147, 0.08263179843197577, 0.09581493126461282, 0.17045165441231802, 0.11122208772576414, 0.14603394200094044, 0.23466764454497024, 0.13636323827086017, 0.06535285647260025, 0.1241710878093727, 0.2289165640831925, 0.09814752367674373], [0.01846516111982055, 0.036212301783962175, 0.04544317540421616, 0.01823857044655597, 0.026028766587842256, 0.12200708908494562, 0.03768438138649799, 0.01927498338773148, 0.007354362032856443, 0.027023483817174565, 0.05869013293704484, 0.024758586405368987, 0.06103569809056353, 0.059727907719206996, 0.013657439412781969, 0.02468688751832815, 0.04605720612744335, 0.029720229540544096, 0.05462070716021117, 0.00428833893238334, 0.00994001984508941, 0.04756493479362689, 0.10564734155195765, 0.027690158785844687, 0.04811569000594318, 0.019075525633525103, 0.021542272370425053, 0.03728509109350853, 0.011827614944195375, 0.04957899742294103, 0.039141773886512965, 0.07922613469418138, 0.002252699518976442, 0.058955543499905616, 0.06860045759822242, 0.03514754251227714, 0.028089090992580168, 0.03520842830766924, 0.008605197672295617, 0.057923861750168726, 0.01434689924280974, 0.047714299435028806, 0.018089693767251447, 0.056347610589000396, 0.10269892984069884, 0.01641725470108213, 0.047178094027913176, 0.03270293032983318, 0.016942390975600574, 0.04404618630360346, 0.03844939834380057, 0.04514864667726215, 0.01947283624758711, 0.07176168015575968, 0.052250569497118704, 0.058189903138554655, 0.07396025554044172, 0.021454405796248466, 0.012741064219881082, 0.013628541109937942, 0.07723239206825383, 0.0369111117470311, 0.0016851127452355286, 0.004802803123311605, 0.032167259269044735, 0.07273799026734196, 0.028917084746353794, 0.05472195094625931, 0.019852839977829717, 0.060264717976679094, 0.03374260129930917, 0.02533923903683899, 0.01827728086936986, 0.019447504892013967, 0.044031591969542205, 0.06325317226583138, 0.054220474339672364, 0.03508312780468259, 0.02906877973146038, 0.014187156593834516, 0.019446939004410524, 0.07437426262185909, 0.07116357592167333, 0.07201755783171393, 0.07774899364449084, 0.06729588814778253, 0.06691006041364744, 0.10088302064104937, 0.046416598561336286, 0.00845027341711102, 0.026820845960173756, 0.06015762235620059, 0.05122593815030996, 0.047686880789115094, 0.025410793205082882, 0.05071974519523792, 0.00908584497665288, 0.04880498563579749, 0.02766971076198388, 0.08363273300346918, 0.0402814715198474, 0.021215330343693495, 0.017871183226816356, 0.03612769694882445, 0.08241997464210726, 0.08489318919600919, 0.057039102975977585, 0.016967084084171802, 0.08316452687722631, 0.062443377828458324, 0.04250772901286837, 0.07010995628661476, 0.05698353466868866, 0.03524182495311834, 0.08394602322368883, 0.015624776424374431, 0.048949904812616296, 0.04815733562281821, 0.009577703349350486, 0.016039288166211918, 0.0926286909088958, 0.060437979773269035, 0.03156737016979605, 0.013650397359015187, 0.02575237966084387, 0.009144872619799571, 0.02599431052658474, 0.032955883943941444, 0.032904234176385216, 0.036383760161697865, 0.04421244593686424, 0.07673035142943263, 0.05968914905679412, 0.01358263556539896, 0.046618373671662994, 0.024051117434282787, 0.09057454488356598, 0.025643569679232314, 0.0073627209349069744, 0.01348946449070354, 0.05556145355512854, 0.08094621036434546, 0.021260944595269393, 0.05964008938462939, 0.03039249288121937, 0.015299011629394954, 0.027371953692636453, 0.03422709385631606, 0.07370662657194771, 0.03749277369934134, 0.03186500849551521, 0.0598255743534537, 0.04421965219080448, 0.041897802366293035, 0.08932785553042777, 0.07003853941569105, 0.06221823248779401, 0.02751692296442343, 0.05244436651992146, 0.03625754681706894, 0.03680937814351637, 0.0477492694335524, 0.020342349453130737, 0.05565347244555596, 0.014158055128064007, 0.06783580058254302, 0.02230607220553793, 0.008970769413281232, 0.041648696787888184, 0.04844665076234378, 0.002840673901118862, 0.06268607496167533, 0.06833394494606182, 0.06362026077113114, 0.00905001779756276, 0.005319092533682124, 0.03630236511526164, 0.05811926552269142, 0.007524315706177731, 0.10822576296050102, 0.019099960845778696, 0.04295473940146621, 0.008768511906964704, 0.04175203343038447, 0.06797755078878254, 0.07295787378097884, 0.07318814736208878, 0.04219887683575507, 0.026073141452798154, 0.029230981672299094, 0.01882973374449648, 0.06616633938392624, 0.06566343043232337, 0.03770397408516146, 0.011215271679247962, 0.02948818222648697, 0.05182569737371523, 0.015499164219363593, 0.1016196541604586, 0.04209146209177561, 0.008661437623231905, 0.023135570663725957, 0.012068831492797472, 0.016711878051864915, 0.04398432829475496, 0.09505677546258084, 0.046709732050658204, 0.07598575466545299, 0.036103547463426366, 0.07736655752523802, 0.014381494456756627, 0.06941063795238733, 0.09220375199220143, 0.02519960395147791, 0.014307990295492345, 0.01960216661245795, 0.023557969579997007, 0.05669917707564309, 0.034479680107324384, 0.08456920462776907, 0.0685554686060641, 0.012463564999052323, 0.01846832823503064, 0.049049341469071805, 0.006568219378095819, 0.027046644390793517, 0.05276889285596553, 0.029040873123449273, 0.03015057500306284, 0.024175994913093746, 0.02660981070221169, 0.09092789623537101, 0.0589182320254622, 0.021711619338020682, 0.049299352467642166, 0.021408555912785232, 0.02043578770098975, 0.012235637532285182, 0.010760670047602616, 0.03009003801707877, 0.07562118204077706, 0.04507757490500808, 0.033444647560827434, 0.046212500528781675, 0.085905456362525, 0.0684150616871193, 0.02722048135183286, 0.04188962760963477, 0.02352175462874584, 0.055050228838808835, 0.010977222245855955, 0.06783784891013056, 0.07409683297737502, 0.06880645552882925, 0.01464919918362284, 0.06887215044116601, 0.02167920789361233, 0.07851037778891623, 0.042543118324829265, 0.03767208399949595, 0.06686021777568385, 0.10365562498918734, 0.06400476006092504, 0.0637233599263709, 0.008764842914388282, 0.027333365724189207, 0.045337590054259636, 0.10416479766718112, 0.11286900247796439, 0.055739416857250035, 0.03894816982210614, 0.03616285990574397, 0.03085753931372892, 0.04129578701395076, 0.024546360000385903, 0.04126113613892812, 0.05705076953745447, 0.009317514723079512, 0.006730613349645864, 0.06496687288745306, 0.0695371518668253, 0.03938962523534428, 0.02822056059812894, 0.02913731150329113, 0.089450547384331, 0.05166179034858942, 0.033270194617216475, 0.04424858110724017, 0.05107852535729762, 0.07292438065633178, 0.10229920910205692, 0.02478405320289312, 0.04526000964688137, 0.025936547317542136, 0.09173978352919221, 0.040879111911635846, 0.06107453096774407, 0.034851507225539535, 0.03284166370576713, 0.019438743838691153, 0.032388489780714735, 0.018757224061118905, 0.05564372433582321, 0.06284930292167701, 0.03679650188132655, 0.08037286417675205, 0.03208636517229024, 0.019761344301514328, 0.04681549922679551, 0.053996983988326974, 0.030399452371057123, 0.04029884890769608, 0.034174438478657976, 0.014410014264285564, 0.04042539992951788, 0.007845187428756617, 0.034009956289082766, 0.028593619681487326, 0.029268350663187448, 0.038147021405166015, 0.04128237640543375, 0.06425415878766216, 0.013184963154344587, 0.02412787220237078, 0.026907198553089984, 0.034803505113814026, 0.005583826814472559, 0.038674617899232544, 0.006496542291642982, 0.062060444470262155, 0.09763997630216181, 0.03553070593625307, 0.027550119229999837, 0.013515503669623286, 0.06412253889720887, 0.02099836347042583, 0.014657343326689443, 0.04843920331040863, 0.015499518594879191, 0.012043253373121843, 0.04002066227258183, 0.020325810692156665, 0.0370548360660905, 0.010917695508396719, 0.07591997811687179, 0.06170968321384862, 0.050577579386299476, 0.014967818951845402, 0.01083708621081314, 0.009056992130354047, 0.01253810816706391, 0.03417908803385217, 0.11381688091205433, 0.15415029163705185, 0.12201347897644155, 0.22849818575195968, 0.07879243843490258, 0.19604212342528626, 0.18000845331698656, 0.1255750679410994, 0.14785708714043722, 0.12089273208403029, 0.20412948477314785, 0.0930154908564873, 0.11258888625889085, 0.1271617945167236, 0.10754860515589826, 0.15143217577133328, 0.12232860972289927, 0.12839142931625247, 0.08420523314271122, 0.15807797462912276, 0.13656778901349753, 0.14110631891526282, 0.2311714758980088, 0.14087211195146665, 0.08419038276770152, 0.11273281095782295, 0.14471005444647744, 0.055039890721673146, 0.20945697702700272, 0.11886928870808333, 0.11067191138863564, 0.2110914682270959, 0.15335153293563053, 0.15570025221677497, 0.12484448292525485, 0.16848766448674724, 0.19912300107534975, 0.10350671305786818, 0.12202070749481209, 0.19761262665269896, 0.19367682456504554, 0.1623619330348447, 0.09992000239435583, 0.17817956395447254, 0.2977554366225377, 0.15897140168817714, 0.19107111438643187, 0.10059611377073452, 0.06756407805369236, 0.13441334915114567, 0.14013953797984868, 0.19154424837324768, 0.06840464935521595, 0.08576091568102129, 0.18391874036751688, 0.1394721245742403, 0.17027291556587443, 0.14976569800637662, 0.09011310714413412, 0.0901546303066425, 0.14527959341648966, 0.11416624693083577, 0.05942360861808993, 0.14833767228992656, 0.1826382239232771, 0.14741089311428368, 0.10153947252547368, 0.1619177873362787, 0.09783556932234205, 0.12922149180667475, 0.11868705434608273, 0.12701792176812887, 0.16274053225060925, 0.0833472065278329, 0.07732784710242413, 0.1628955965861678, 0.14746545581147075, 0.1639647939009592, 0.11430922910221852, 0.177679282205645, 0.21841725247213617, 0.16248762316536158, 0.1665330256219022, 0.22173224802827463, 0.15839408501051366, 0.11505105765536427, 0.15599494421621785, 0.2248087470070459, 0.0956161915382836, 0.2550136379431933, 0.21787646430311725, 0.24299414071720093, 0.16570605046581477, 0.1300142242689617, 0.10729208181146532, 0.12270516803255305, 0.09521887535811402, 0.11841248939163052, 0.17246069270186126, 0.16268580628093332, 0.12364972906652838, 0.1338100276188925, 0.06044552370440215, 0.08303199414513074, 0.1118175350711681, 0.11931698187254369, 0.14210640743840486, 0.11388288010493852, 0.14183810621034354, 0.20743634639075026, 0.11898043274413794, 0.15446037577930838, 0.09694171181763522, 0.19139492826070637, 0.229500649147667, 0.06401656020898372, 0.13552118267398328, 0.11448658013250679, 0.21348204463720322, 0.15421635762322694, 0.17728401435306296, 0.12032967948471196, 0.15791229758178815, 0.09212376331561245, 0.07803404514561407, 0.09651526634115726, 0.1711217247066088, 0.1645311713218689, 0.1416899883770384, 0.18754908931441605, 0.047089615181903355, 0.1609562459634617, 0.10829916878719814, 0.12689050985500216, 0.0960328258224763, 0.1263814262347296, 0.2600179397268221, 0.153700802475214, 0.12816081434721127, 0.05965664669929538, 0.1698099638451822, 0.1277895030216314, 0.07992054001078941, 0.15307870460674167, 0.1444132992764935, 0.1314224346424453, 0.1051238676882349, 0.09977772526326589, 0.17148631217423826, 0.19606447691330686, 0.11516996455611661, 0.1519196925801225, 0.14622743474319577, 0.12259889248525724, 0.20414544094819576, 0.15635316405678168, 0.16959310829406604, 0.08900460568838753, 0.1923887975863181, 0.15081214107340202, 0.1265073983813636, 0.12067549061612226, 0.10840153321623802, 0.17402619385393336, 0.16284959827316925, 0.12842834374168888, 0.09669847291661426, 0.09109414473641664, 0.1679362339200452, 0.1220055676822085, 0.08845715303323232, 0.15641983860405162, 0.10171677160542458, 0.1654978038277477, 0.16695204220013693, 0.12516425951616839], [0.017431490414310247, 0.019083583501924295, 0.034147561600548215, 0.017838634485087823, 0.03989302771515213, 0.019074898518738337, 0.02230492373200832, 0.03987284500908572, 0.03658963192719966, 0.007948378424771363, 0.023676130622334313, 0.02397590818873141, 0.044848217876278795, 0.06455029055359773, 0.03514701187668834, 0.024611832268419676, 0.04433399488334544, 0.0502971848618472, 0.02484819331584731, 0.12465047067962587, 0.007420669217026443, 0.029284137999638915, 0.038417482282966375, 0.06728815496899188, 0.017909145935846027, 0.0023713473638053983, 0.05378350891987793, 0.07780527070281096, 0.032877182893571444, 0.018102254616678692, 0.059320724685676396, 0.01716809292702237, 0.06049595263903029, 0.0481217719061533, 0.04969570756657049, 0.02296968024893431, 0.012436237266229, 0.02221929287770763, 0.04209648643154651, 0.04154420610575471, 0.014794029302720446, 0.06025913702615071, 0.06521076487842947, 0.03603275770728942, 0.011227190570934908, 0.02491753959475318, 0.055746419020579197, 0.08817316280328669, 0.035579598625190556, 0.041091251114266925, 0.07560322948847897, 0.08084960500127636, 0.07724473398411646, 0.03526270156726241, 0.10149892899789847, 0.11950889384024777, 0.05704419410903938, 0.054281731208902784, 0.05125393938214984, 0.006435522909669089, 0.04889947587798815, 0.04952789313392714, 0.03687101350806188, 0.012882200298918178, 0.10474962487933226, 0.0076453497877082555, 0.06320354485069402, 0.07902041135821491, 0.07204196706879884, 0.009714970055938466, 0.021823232782480773, 0.09406963741639629, 0.021589921962004155, 0.01903843123727711, 0.054174654142116196, 0.03648173478723038, 0.0073523016453691525, 0.020959274552296847, 0.030158246954670176, 0.039706815441604704, 0.0073656881340866676, 0.041365567449247465, 0.04836023137613665, 0.010744620176410535, 0.06339283703709953, 0.054904649150557816, 0.022230798022064846, 0.02206938461313257, 0.060084917859057896, 0.02034623274084879, 0.039601356256753206, 0.01955376374098705, 0.059288808624842204, 0.011984707198280375, 0.018813504830177408, 0.03140022367006168, 0.07854200812289491, 0.0384457172913244, 0.050485805404605344, 0.04713501606602222, 0.012619889130291995, 0.05390589649323374, 0.04411193687701598, 0.06468506457167678, 0.038473699969472364, 0.04311150696594268, 0.0604170289443573, 0.034158601047238335, 0.0181130751298042, 0.018847502615244593, 0.03116973486612551, 0.007597054991492769, 0.041361366893397644, 0.0018849091043193766, 0.0681720973807387, 0.07743177004158497, 0.06231507533811964, 0.06994808645686135, 0.03594542547944002, 0.033100250220741145, 0.06696516487863846, 0.04325386573327705, 0.02918675894761691, 0.02842326524842065, 0.05352444371965248, 0.063643178291386, 0.007049292025840259, 0.07286017746082507, 0.02986404662806308, 0.03359681380970869, 0.06983587372815236, 0.04999599535949528, 0.06630028961808421, 0.0113824256004591, 0.03418313273868989, 0.09265678119845688, 0.024346659192815423, 0.04054842203913722, 0.018783323539537378, 0.08226911086239852, 0.01829942841141019, 0.036860107647953555, 0.03894947229127865, 0.024526359120500274, 0.044109187219874, 0.0676159912836738, 0.05273318070976529, 0.051799503271467984, 0.019864554778905585, 0.0494381786120357, 0.038493244428536855, 0.03451390795817133, 0.03433143239817582, 0.04155501177592669, 0.08165985214873217, 0.10159779791138135, 0.07187806375441141, 0.03741607644769829, 0.051572124066296965, 0.011183300885022618, 0.03953694897063542, 0.04111673646548297, 0.02006681970669888, 0.05237402947386727, 0.049098364033852704, 0.06634651799686253, 0.0823877654329408, 0.03291068715043366, 0.019568055649870075, 0.02974085753521649, 0.060572085858439095, 0.035299968512845226, 0.06289248849498108, 0.03295282629551366, 0.05153113525011577, 0.010898677046498051, 0.038890523501322605, 0.007220971192509751, 0.07521962819737382, 0.042454810172785074, 0.04586853363434784, 0.014169669739203528, 0.03402012742299121, 0.01695251943601761, 0.005213410240685334, 0.05192384269321337, 0.014631125104642706, 0.021491014085768256, 0.02930965489213122, 0.061095140408724546, 0.044930648218723945, 0.045317106778384186, 0.05597836243396159, 0.014159376150928438, 0.07134958039387129, 0.040173993693315424, 0.016641680158500094, 0.05142301175510511, 0.06245158598176204, 0.03722908491909038, 0.035499268560670316, 0.05221306135354098, 0.02206564418884227, 0.05345978410332464, 0.06826080629252829, 0.03339774382766336, 0.03477714031760115, 0.04088103036337998, 0.018257424708281178, 0.061121969047235325, 0.04637568024918437, 0.018998410923813935, 0.015278791815944714, 0.041185938025591895, 0.08823330645100214, 0.01594321714947, 0.0625878591381479, 0.014994236626080237, 0.05232108094787691, 0.03774765689740889, 0.04008609743323177, 0.006096996421547374, 0.07088927071890794, 0.09565197047777474, 0.05514685275556985, 0.029263216856634244, 0.029812341199431103, 0.0398184492951259, 0.07881334473495372, 0.01822914888180094, 0.030970180632721167, 0.06893918864079751, 0.06937272162758745, 0.07474253856344149, 0.05063344826339744, 0.01669248944381252, 0.020238482175045647, 0.009218334107572446, 0.011318536890030373, 0.029111046897014603, 0.0326965293061221, 0.05692622973583639, 0.05846572603331879, 0.03112144702754449, 0.02854761951311957, 0.010956538590107812, 0.033301053117611445, 0.03374613392225001, 0.07021618730504997, 0.03103928942437051, 0.061069580842740834, 0.04865803297434468, 0.015507271255046362, 0.0228057954882388, 0.014618769273511134, 0.05574326489295345, 0.014021622409927659, 0.03578462805307936, 0.07461136396159418, 0.008488144285365706, 0.059465410085977055, 0.07329748055781238, 0.04516847686318215, 0.055366947781294584, 0.07685758522711694, 0.02992029028973775, 0.08681276900460944, 0.06480359297711402, 0.015675734139222186, 0.050829631290980615, 0.07364825665717945, 0.020850531363976188, 0.044482005105237477, 0.07121603091945872, 0.027633143290586304, 0.049365863742423244, 0.021196750676608644, 0.02875019799830625, 0.011321748534101062, 0.03640796901891008, 0.014472330549324397, 0.07340127733186819, 0.031721209961688146, 0.055680085861240514, 0.041954584085033275, 0.030529150099027902, 0.011638371925073443, 0.03345638091559522, 0.09565958491293713, 0.015092904232005822, 0.06721466008457355, 0.06983254890656099, 0.043789154588012025, 0.0700563212740235, 0.06598056497750804, 0.006706993108309689, 0.04859439381107222, 0.02740434658335289, 0.01767834728525486, 0.06891460870974697, 0.02888082712161122, 0.003711925355673884, 0.10085147936479189, 0.018680027715163305, 0.046502264667651616, 0.011384005447325762, 0.07887995991040953, 0.008678176764078671, 0.006668517853540834, 0.023066337562340777, 0.03129873868601862, 0.014276799684012076, 0.02562957648478914, 0.05065764969913289, 0.07042847864795476, 0.05691699370800052, 0.010235422450932674, 0.0354631964728469, 0.012505273698479868, 0.06219347444130108, 0.022765506146242842, 0.053335934499045834, 0.0320079164521303, 0.057257969747297466, 0.02208173209510278, 0.03047149264602922, 0.027945637557422742, 0.061041776280035265, 0.015331595623138128, 0.05352155305445194, 0.046009218858671375, 0.07538775433204137, 0.036945762622053735, 0.02564964601333486, 0.027614585887931753, 0.03827653359621763, 0.03532625167281367, 0.055536020154249854, 0.033908441619132645, 0.012086746010027127, 0.03019717816641787, 0.04201390023808926, 0.026213952842226718, 0.016132385026139673, 0.034138563059968874, 0.08086792862741277, 0.01832763558923034, 0.06708357454044744, 0.08784734513028525, 0.03576854200218804, 0.0774579455901403, 0.022845541207061615, 0.11359200274455361, 0.0707270075508859, 0.19625650020316243, 0.15437545924214646, 0.18338619003770873, 0.1480478042503819, 0.06485664169304073, 0.08581428352044895, 0.09040549848577939, 0.1247371980571188, 0.05147567826497834, 0.08006187461433001, 0.1174347914638929, 0.22263113729422912, 0.1532147848047316, 0.1647713006241247, 0.11182347967405804, 0.10212468565441668, 0.14470157912001014, 0.18626541132107377, 0.1805535310995765, 0.15380881464807317, 0.15124135476071388, 0.17042472929460928, 0.09537034027744085, 0.1498207208351232, 0.15202846174361184, 0.3120118856895715, 0.14545702608302236, 0.09861811951850541, 0.09176587002002634, 0.09741497939103283, 0.10708246220019646, 0.07636924463440664, 0.13937074720161036, 0.10218092560535297, 0.12509046035120264, 0.1070932752918452, 0.20517085155006498, 0.08803488584817387, 0.158602005103603, 0.15673410845920444, 0.18663225491764024, 0.20664143201429397, 0.10952717828331515, 0.07696843982557766, 0.2294266570243053, 0.17992123612202704, 0.14914931467501447, 0.2391661430010572, 0.14193305658409372, 0.22972275910433382, 0.22374921245500445, 0.12594928848557174, 0.18633918080013245, 0.24211368639953434, 0.20099536544876173, 0.21210209524724633, 0.0981919263722375, 0.13903566752560437, 0.17623892199480906, 0.11858510551974177, 0.0819551749737002, 0.16069788951426744, 0.2549762337002903, 0.10563865842414089, 0.16504677099874243, 0.17534371378133073, 0.22053862223401666, 0.10672636490198784, 0.190149070112966, 0.1995961053762585, 0.16727506939787418, 0.12590864847879857, 0.08454031281871721, 0.13319897290784866, 0.10064572634291835, 0.0891009290353395, 0.07403614756185561, 0.10553282816545106, 0.0869503706053365, 0.12907773780170828, 0.11451936079538427, 0.18973731173900887, 0.13317712408024818, 0.13565708475653082, 0.1235920048202388, 0.18297401606105268, 0.2448879976873286, 0.150441215664614, 0.19377444667043164, 0.17144834389910102, 0.1509004714898765, 0.16728948190575466, 0.1363713722093962, 0.13044011313468218, 0.22142214904306456, 0.25308120413683355, 0.16875167610123754, 0.16209658555453643, 0.08287530450616032, 0.15107702842215076, 0.0838339737674687, 0.14679333718959242, 0.12351917044725269, 0.20714031852548942, 0.14101530192419887, 0.12401239437167533, 0.13861552288290113, 0.1525558764114976, 0.15121732401894405, 0.21183812816161662, 0.22439418331487104, 0.15718382026534528, 0.19105929939541966, 0.2454212011070922, 0.1774904946796596, 0.20566421648254618, 0.15022225241409615, 0.10308921046089381, 0.11587559114559554, 0.090090293524554, 0.12634203303605318, 0.09641339915106073, 0.14866590936435387, 0.08735856667044573, 0.13534370547858998, 0.08398137171752751, 0.1391782340942882, 0.20610953477444127, 0.1287572190631181, 0.12093660785467364, 0.149952897336334, 0.08459673830657266, 0.10860416179639287, 0.09367474805912934, 0.12113732169382274, 0.1625085368868895, 0.19274205988040194, 0.15224438218865544, 0.07328376566874795, 0.09064572426723316, 0.1560321555007249, 0.1486424426548183, 0.11046071100281551, 0.1309649896575138, 0.08370396433747374, 0.1597155976924114, 0.10581558643025346, 0.17387381609296426, 0.10810924577526748, 0.14376782375620678, 0.20513775176368654, 0.0865312575479038, 0.11616661693551578, 0.2640818216605112, 0.09441233152756467, 0.11012885224772617, 0.1204114047868643, 0.07301995443413034, 0.06638283128268085, 0.14056637679459527, 0.134624193306081, 0.0840548517589923, 0.16175187280168757, 0.20805267035029829, 0.1359593021334149, 0.14109313837252557, 0.1264836496557109, 0.13371460227062926, 0.14607931690989062, 0.24194135970901698, 0.17169984290376306, 0.07809561371686868, 0.2042432560119778, 0.10936453661997803], [0.12481132376706228, 0.04054582823300734, 0.020518937926681247, 0.02566039973316947, 0.023104832762328442, 0.035959203451056965, 0.018805602812790312, 0.019338182828505524, 0.028081556338293012, 0.048603392351651564, 0.020722343906527385, 0.017696119866741356, 0.02498920694051776, 0.05166717091924511, 0.04696255949966144, 0.028304772094998043, 0.06538768546306528, 0.07156103310990147, 0.06932538744877093, 0.04243939205480274, 0.041913947788998485, 0.01576743019541027, 0.05448537653137464, 0.04442800272954628, 0.028146651966380887, 0.04072912757692393, 0.012400203213474015, 0.034183685638708994, 0.04378177392936777, 0.03632505999121349, 0.012938541367475409, 0.007417151900881436, 0.03628974860475864, 0.023759249306749552, 0.022287431311269756, 0.05276304844301194, 0.033388864030712284, 0.026809314840647858, 0.03767969101318158, 0.015925262741802726, 0.02651015511219157, 0.04352193318482023, 0.03896058595273644, 0.014048396315047285, 0.03716811377671547, 0.05924523342400789, 0.03326259131426923, 0.049994370056083426, 0.03294955342425965, 0.025416439093532972, 0.0782588342553936, 0.02035498822806403, 0.02160852018278092, 0.06892418983625248, 0.017934191564563662, 0.021820540641783737, 0.013177523123886203, 0.09271887669456191, 0.017837881205196027, 0.06215139466803521, 0.05801160215924028, 0.02985256003739778, 0.05631236228509806, 0.012823965826100903, 0.07458083200617693, 0.028135228458268102, 0.024932935448305216, 0.09028410539031029, 0.009087740236282116, 0.019338576166774146, 0.028557432560774032, 0.028102089709136635, 0.045961561845615506, 0.1062059190007858, 0.01677040938375285, 0.021390603360487148, 0.010203543497482315, 0.007944790140754776, 0.014670586024294607, 0.0020952345676050754, 0.0236428471544059, 0.03715445454872679, 0.032123951241374016, 0.032589979164185934, 0.026779517611430492, 0.06981925704167224, 0.0335662039287854, 0.05891886285098735, 0.07705066978815012, 0.02320285562745994, 0.0200614150162437, 0.06628487521084026, 0.07904749232693575, 0.09396193694556132, 0.037588956038234755, 0.026768172028823756, 0.04323377950640861, 0.01969063432625262, 0.07090769824571908, 0.07365616052993573, 0.08741609053686261, 0.01705624756141333, 0.0354384087404469, 0.01941364440426696, 0.0495640654116869, 0.07454641119693406, 0.007086789037202834, 0.032172617575270124, 0.02819141274812864, 0.08411869872361422, 0.08807490987237543, 0.09631028515286744, 0.06491916021332145, 0.03772411968384404, 0.10916959668975323, 0.033467175453552045, 0.022042862110538408, 0.036268601106712595, 0.022002327859809157, 0.054709067262592725, 0.04926062720187474, 0.03947769961087033, 0.04540998656011652, 0.03641439601778984, 0.0677780169644393, 0.03841014615318272, 0.12861211434938014, 0.024291311674460303, 0.024820711587381084, 0.025327095645479858, 0.03064862103201449, 0.06988544919295236, 0.10913395133684389, 0.005764417319369386, 0.04889197647571564, 0.04970173380570486, 0.03154972931952216, 0.022230018767004367, 0.05640965413476806, 0.06252229039091617, 0.009113050255109556, 0.030250553427322302, 0.04262909613316879, 0.019960516328865197, 0.039589077423443086, 0.03785981025430374, 0.04998395772418007, 0.12179778859717771, 0.03833084767393302, 0.02638452064275043, 0.05658461544953752, 0.01911799503432121, 0.011532616808835883, 0.020311893567850348, 0.03073179908824386, 0.013232428136689123, 0.015911054324533325, 0.016551093613088597, 0.01826798546971986, 0.029690525079786312, 0.027374584606150165, 0.0268390953715425, 0.020509161986410618, 0.012792429188266397, 0.10608290060190484, 0.039362258539767936, 0.040997940886882134, 0.029100786705384962, 0.02527378346712794, 0.06514362277812324, 0.02276073970278958, 0.012688529441220453, 0.0028310361858530086, 0.07149183526053093, 0.02650756316143088, 0.04553070801193826, 0.09592482849257067, 0.07242447740281932, 0.027183179154235404, 0.01704146769043291, 0.011300616806693142, 0.053434350702445954, 0.022103642149886582, 0.06442738347686827, 0.002230163509011618, 0.021300449116097298, 0.02580191987362923, 0.014195923213264905, 0.030264169981819578, 0.04263729315425735, 0.014298228270490654, 0.009601709971320815, 0.04734334062959533, 0.06878949745441787, 0.07458109175786376, 0.05320143507560715, 0.09144299125182442, 0.044729203364113346, 0.04547690230538137, 0.04604215166182257, 0.02764833319815807, 0.027340321503288578, 0.015244584374158876, 0.01606460653420072, 0.05582832614891231, 0.021933571588306222, 0.041939514776458964, 0.03172665732563473, 0.046510662068612874, 0.03576634524506517, 0.01262702766325674, 0.04974894181941636, 0.028402687348716427, 0.037213032264844514, 0.0627816264750436, 0.08565933792851865, 0.0379980983416317, 0.06436888739699498, 0.00248870595896733, 0.03607959835790098, 0.016725756213418208, 0.005059623790657497, 0.07373269079835154, 0.02086225173115963, 0.03345848490425851, 0.03286742365162354, 0.05374071668484248, 0.03740290332643781, 0.021266557087074034, 0.012581773353304015, 0.019196254506823607, 0.01140664466220187, 0.009658796898293076, 0.07439823399181478, 0.009186858696921263, 0.03905210760422051, 0.0195060362239019, 0.12256352172698826, 0.05894385467399843, 0.03115907391475048, 0.04525565695075784, 0.026501405191083904, 0.044917771956534125, 0.03804295003646985, 0.007190640544649796, 0.0175978001425392, 0.018453563207003754, 0.02457311999023659, 0.17104522412410006, 0.032417555994470604, 0.026116382687177975, 0.01322995864029508, 0.01688742751866812, 0.03637235706264619, 0.07646781668881886, 0.017487991972302552, 0.06398340105079114, 0.05062915493908804, 0.01796831922547426, 0.012489337004808476, 0.01226945534654078, 0.060795494573540054, 0.04480462783249095, 0.028587274318851996, 0.025955861710826866, 0.02126533439877676, 0.051544341768021695, 0.06275582200032659, 0.04368094203528017, 0.06837160151917487, 0.02630679366120603, 0.03300072821730282, 0.009023379334394122, 0.029438662422762718, 0.034935395888169296, 0.04088156099896878, 0.04791125800693408, 0.04267115735274274, 0.02245886000309838, 0.032046330015873536, 0.04874461563304067, 0.0437220124877058, 0.021605184228974395, 0.029211817563918885, 0.04012824771052692, 0.02664737079612678, 0.0515565797832096, 0.015330282949435059, 0.03344270313391462, 0.07810454917489551, 0.02640841223183088, 0.028733499675581697, 0.033179144229507074, 0.045835589698981494, 0.05917244729062077, 0.04269401550118346, 0.02369355996052036, 0.018168532114941627, 0.06149197790364269, 0.022327247534121852, 0.029435332035063766, 0.03624030672654044, 0.023701768113824073, 0.02723650246480247, 0.018554061134636868, 0.02072479484922951, 0.08511150677804835, 0.06922275584656745, 0.07423774455673993, 0.00418035505390435, 0.04119573066418525, 0.09503508990746923, 0.026742443624243606, 0.008825862296362175, 0.054564344754908234, 0.07415014886646532, 0.009639116069593001, 0.03524507184920367, 0.07079421644448303, 0.02169224371755263, 0.02547169198805932, 0.04178558592684567, 0.03150156764604617, 0.11826251618913375, 0.02518931036320282, 0.03830890236713458, 0.030939357384340838, 0.010887672851822572, 0.045493211000575684, 0.020795363816432655, 0.07486655144020915, 0.02681476962607121, 0.04356446195743047, 0.027604409187915735, 0.05681687798642088, 0.04184519893897232, 0.07423797462251969, 0.06768657694919966, 0.021846872041351162, 0.005505594244823442, 0.04779953509569168, 0.040427585554425605, 0.07623424055054784, 0.06723878730554134, 0.03597441747842822, 0.023152255998866167, 0.02569287611549953, 0.026897982934315223, 0.00591363213970908, 0.015202729100565193, 0.03875067690387368, 0.05750520511355717, 0.2712820196757093, 0.2000498099368997, 0.07898184936493635, 0.03824402381724212, 0.11698182905092835, 0.126490002439823, 0.11644170139334165, 0.1283224392682314, 0.1466297233127989, 0.10541297873714939, 0.11422569295973517, 0.0786773907020688, 0.09743545524543151, 0.1874367133132182, 0.17174313979921862, 0.16249750857241452, 0.19835245882859454, 0.20358929032227024, 0.2026824897620827, 0.16807642561616376, 0.12547431397251785, 0.12601152498973534, 0.12645513634197414, 0.09715357271488756, 0.1842576643684879, 0.12039000866934657, 0.08576174688641913, 0.28130401158705354, 0.23871156270615757, 0.11352975139743648, 0.11790040749474429, 0.10348648953367956, 0.12136870107497089, 0.09408202386111952, 0.11419092334108427, 0.10720620048232377, 0.19644791493192315, 0.16849324543727562, 0.1764712735894136, 0.16903078299947083, 0.14787779306061566, 0.16456136188935488, 0.14040645881323144, 0.09587929031113163, 0.09938932227669284, 0.2229421862284653, 0.08998947276268154, 0.19079669786151499, 0.12001757670077495, 0.19366633059689775, 0.2574903628556058, 0.17545365553814918, 0.09684006727184169, 0.18272717774379998, 0.13552324584452435, 0.08679586288053542, 0.06802550837164745, 0.16530656721442938, 0.07704828749410808, 0.15916649746941403, 0.12548241822514683, 0.25377701211255044, 0.16025411488953978, 0.13126278383424506, 0.20388999371789396, 0.14186917251208797, 0.1515239052241668, 0.14127808157354593, 0.1507028820924461, 0.10853619591216557, 0.13932633708463982, 0.10927967203315347, 0.21819866029545665, 0.213593723019585, 0.1286411174805835, 0.11525607595103793, 0.15155822213273495, 0.1434703858103603, 0.1847553634434007, 0.18363262759521604, 0.1323072676314041, 0.1482727937400341, 0.11054591697757132, 0.07979715053807013, 0.18406176706776023, 0.3175695624668151, 0.14954533951822668, 0.16174356074770913, 0.17694139445666224, 0.10571802369668148, 0.16554847767110914, 0.26515992474742234, 0.13946078455774114, 0.22097479726653546, 0.06514959706692025, 0.09290133370086551, 0.09254565942683257, 0.1539493922609836, 0.17098819749662653, 0.15823082736460492, 0.09928494662744924, 0.09699827831354924, 0.22598203795496374, 0.08058274353970774, 0.15087706415215507, 0.14276110043283552, 0.10092225798871368, 0.17293954122578725, 0.28224864683579654, 0.17163163953227922, 0.26805625995621085, 0.11703904863679782, 0.1738567466964014, 0.1460379347554408, 0.2839820663211867, 0.09877423770376481, 0.08574625826440752, 0.14700311265187338, 0.1783935696585104, 0.15824788191821426, 0.2269049728056416, 0.15396926697576419, 0.09655320493038744, 0.07734326150966808, 0.07667800033232197, 0.27371424541343004, 0.1698136597406119, 0.13709315535379574, 0.09409408376086503, 0.11423353003920056, 0.18528403976233676, 0.1977775467094034, 0.20576575712766498, 0.10207617146079428, 0.0946071972430218, 0.19450247869826853, 0.14712731848703697, 0.1123179355636239, 0.15869355644099414, 0.14446841116296127, 0.1381418397068046, 0.14940056134946644, 0.15260024199960753, 0.10256788140395656, 0.14153323194477707, 0.1309534121537581, 0.1717804846703075, 0.2006392681505531, 0.13239340129075572, 0.12935926410136744, 0.10417612284072675, 0.10626115705235861, 0.10181096498854458, 0.07598189549753442, 0.17382041114615276, 0.1026894451933913, 0.09784512818441726, 0.144898010767065, 0.11862175277201459, 0.12563899654196575, 0.11591633505304344, 0.15121353906579316, 0.09574723255354911, 0.12525226338766515, 0.20093223836738616, 0.12762421189108863, 0.17286238755332306, 0.13175843458157033, 0.10423556886962615, 0.09022284852107987, 0.10499267824343406, 0.08778212519246154, 0.08762122757616453, 0.11971898100455292, 0.14357758162077516, 0.14332253515021876], [0.0441298374789767, 0.051720653791562654, 0.025682105697342195, 0.04129218388698064, 0.028541726860566996, 0.03333511769596953, 0.03943619129131548, 0.06563447925145738, 0.02523422514059348, 0.03286248094809707, 0.031245908903656527, 0.04940755017742049, 0.023622000226168893, 0.03590349784644786, 0.07402325645671226, 0.028303820290602744, 0.06280631772824563, 0.03632544961874373, 0.08832008577883244, 0.03862620760628488, 0.03137882013106719, 0.02248945318569895, 0.022259027464315295, 0.01567595863889437, 0.05410651385318488, 0.02152447195840068, 0.033474222145741805, 0.022634940105490386, 0.018108260446751956, 0.033340186564601026, 0.08305672992719337, 0.0469515682925703, 0.04124675702769309, 0.03142618399579078, 0.025134255993179977, 0.03253055539971683, 0.049081220422522165, 0.034538369145593606, 0.0673259080213029, 0.03276269548223354, 0.040013255638768896, 0.05306659426423721, 0.05383046460337937, 0.03397294909518678, 0.07031444023596123, 0.03884611709509045, 0.11127250181743875, 0.023882857713033445, 0.0148019183325232, 0.004329397788751521, 0.040046199574135244, 0.06252979350392707, 0.0353888555400772, 0.02994131533341715, 0.04886623137281276, 0.04570315715682227, 0.0760583886585664, 0.011183635779161705, 0.00555671059373708, 0.0062598008935310645, 0.012483695754781365, 0.005980661990179215, 0.07254177384311333, 0.0387846672674641, 0.04573655751300976, 0.05902121614781208, 0.037401890294859186, 0.013369804310059408, 0.04716688759799581, 0.02161751686799107, 0.0525171934714308, 0.10596154461381957, 0.028377780872688163, 0.01724510373605881, 0.03248138069466222, 0.03742762055480853, 0.07281731843249872, 0.07223632812383585, 0.06349859308102168, 0.09621823657653295, 0.02481571507814806, 0.12333016769844107, 0.026932607834169175, 0.07474581885617226, 0.02443473356834147, 0.04110253918042872, 0.014535119025822496, 0.023860867877374403, 0.06949536895263009, 0.011413331412768457, 0.01942079128639307, 0.025264987161790486, 0.04824132447538432, 0.011457146883913083, 0.05936852641752921, 0.019181905081495643, 0.08032703655771911, 0.04655197000829503, 0.08934658733778633, 0.04031819669762626, 0.024156357685569674, 0.04084373744262848, 0.03494435361062642, 0.028692299347312655, 0.03112530248472467, 0.06541015027323738, 0.06852857317426242, 0.0347252530627884, 0.06462402292527258, 0.060383517266018316, 0.1003487039997708, 0.020587707185768522, 0.02911746832978679, 0.03726841874595266, 0.06245184573344886, 0.0271145045189769, 0.037561403805739246, 0.057093428185908124, 0.06438819065806456, 0.06290949109825306, 0.02992661338794278, 0.05837687982420903, 0.028269956092117354, 0.03503002713841852, 0.019511056852934416, 0.055541460096719675, 0.05857101823494304, 0.05016801405872684, 0.05501370404090267, 0.061164085927885026, 0.030182170085026883, 0.026931943611998577, 0.02223639196017757, 0.029806982893205713, 0.024750975680944975, 0.041522821120452136, 0.05805775632325094, 0.015495877432840643, 0.026741241345007438, 0.030977477799751796, 0.015582104788336437, 0.08548221696401015, 0.0552671734476462, 0.0289156227154308, 0.03197037862264551, 0.08196228474844247, 0.04893327699392103, 0.030047260624996852, 0.0385536552494159, 0.027756280433095526, 0.027165208048245404, 0.0429199067002628, 0.03393759317987133, 0.02844839993485948, 0.01307392858507228, 0.017153372427856084, 0.09275168704334646, 0.026468171818123665, 0.029005309406784363, 0.04364312961115502, 0.02395151193923084, 0.049660744989523664, 0.028707585734082386, 0.059858499735128134, 0.017091518129745964, 0.023261181013367604, 0.06235656139324419, 0.027874274492205586, 0.07254550684592687, 0.03048884591407841, 0.02828041851898888, 0.009725333220558241, 0.03234539326513186, 0.03062861829675967, 0.045219217499834485, 0.05785438930615783, 0.021756656569777988, 0.04626840651326347, 0.021394225041149184, 0.10451751077198423, 0.017465362034272403, 0.042923238943330944, 0.04022683831863105, 0.051916053853346966, 0.03316806396469474, 0.049179647758137435, 0.009264041127607925, 0.0568873411975801, 0.022067751888243947, 0.017730659419612493, 0.039462808417738415, 0.06874334329040721, 0.01439103476513992, 0.0668432968086563, 0.039928791811689734, 0.03393605693418067, 0.014977591181377647, 0.04698491298768204, 0.0392316442594165, 0.03811318689258769, 0.016068675358837936, 0.014943307669454953, 0.023682706050749402, 0.06088603659009095, 0.03617631133238319, 0.0356516500323778, 0.05516467914276291, 0.1318486945820041, 0.005428618223959347, 0.043214186807745136, 0.06780243362300098, 0.011000418999174144, 0.039316033871727996, 0.026416946930112317, 0.06872688987641595, 0.025719365221448243, 0.011427870085753966, 0.04796837369212881, 0.08749478787649423, 0.04619711951818317, 0.016435474426543806, 0.021923222338955384, 0.03158058781991713, 0.05255648648017086, 0.017731843145156745, 0.012693527805822669, 0.04598575585987419, 0.010394212367828004, 0.03675955034850631, 0.01885304089228157, 0.051086102685076185, 0.04723385900433641, 0.051744432203122415, 0.01992314177186927, 0.023817838155082427, 0.018378281602053903, 0.026045769191114232, 0.0323568483145209, 0.09439079440198839, 0.06976473145186901, 0.10058442494482733, 0.04023165856779087, 0.039109549834392965, 0.016603509648120962, 0.02401208046649117, 0.03140947454085108, 0.024601711229479406, 0.034138403498218395, 0.048695737787056714, 0.03898686911270488, 0.020031007370562293, 0.053372039983514696, 0.08688684276421554, 0.03136732797429431, 0.015942133613862097, 0.053946491971146315, 0.05074907858215738, 0.022461771077360027, 0.02076652024697978, 0.04177361508482136, 0.05428878161183093, 0.06295211263932288, 0.0593428110005334, 0.06484472280135378, 0.024474970960000064, 0.0010002780027207336, 0.06323985071503557, 0.04043127402837854, 0.10516055946936831, 0.011776081137213623, 0.052217384363757446, 0.012620455017895438, 0.030581391729356255, 0.06991332425968722, 0.12713350384728983, 0.05785909823316615, 0.04523614959907718, 0.036660751939052716, 0.01810831054172013, 0.08255648528574966, 0.04944958542182576, 0.008319851167470915, 0.0648141092096921, 0.022861553043185268, 0.03734430705662817, 0.02382823749940144, 0.07168012554757297, 0.023176607719506137, 0.014936478055460611, 0.012121700237912592, 0.046428131536231376, 0.022498340404126793, 0.06374753167619929, 0.05688728553650435, 0.01548976770209265, 0.06535389547934756, 0.010989577149302932, 0.06122126098489389, 0.031091352939256467, 0.03217476238205563, 0.011942402925342321, 0.033057305845431983, 0.03954495674406644, 0.03575884213205427, 0.041681024740682915, 0.03398835608095396, 0.053482582879951224, 0.0286611718183849, 0.02342553147173021, 0.0301616719661979, 0.00943886236200342, 0.10011682737967931, 0.018938734829134773, 0.03391551799722947, 0.05622347896860447, 0.06275925814406946, 0.03434162208577618, 0.029042264650342986, 0.02692298588954145, 0.08592895275796764, 0.043445124611025676, 0.047176554071484134, 0.044118382429587655, 0.02271028108225437, 0.0513012884039199, 0.029323187955014873, 0.03247764027037192, 0.023141522688092664, 0.06326020040432923, 0.03668894241855014, 0.011548649981705239, 0.036295155150583014, 0.04179108524112962, 0.08160868106642738, 0.06907814837177284, 0.06066085414204281, 0.06598147039767355, 0.03421080000407528, 0.006759908237654599, 0.061111549293855205, 0.03734416233783122, 0.042184545964119025, 0.04159565178269986, 0.0332196395174833, 0.019454627654340584, 0.0649049851926975, 0.05478638420754578, 0.05791840696474537, 0.03585824539186433, 0.023234428444993682, 0.04096597658644896, 0.03987293406680692, 0.10563227595412172, 0.20463257184019312, 0.09877350297756493, 0.2762550621991977, 0.13768400880508125, 0.13068224623566493, 0.15571521391393617, 0.20325563556980342, 0.1398648097529076, 0.1409269418218173, 0.11883717597811483, 0.18151723954360932, 0.14287297177361324, 0.19810999918263406, 0.1421529400977306, 0.18964693299494684, 0.10643672692822292, 0.1946538471383974, 0.15488573029870167, 0.09954718450899236, 0.07488165414542891, 0.13175065687391907, 0.1335977140115574, 0.16653056169161573, 0.12832189007895067, 0.05676803724782076, 0.10886916788876988, 0.1566843845648691, 0.07744464630377479, 0.11439790090662427, 0.20105892297578976, 0.17016292928019539, 0.2883063827175647, 0.09409864796907641, 0.14522796962410212, 0.10861680057132617, 0.15080094948643818, 0.09296387448557653, 0.2541063178796321, 0.14856614987365901, 0.1082835985289421, 0.17170938692288473, 0.14378992491401732, 0.10170039982767776, 0.1378083779127337, 0.14888674282701686, 0.16252397355856374, 0.17328498128335923, 0.10763580750790425, 0.11869901034515351, 0.1350131825893186, 0.14014434709679335, 0.117873690178385, 0.09075100533664227, 0.11592958238907158, 0.1270492552430369, 0.2689019520767033, 0.10656821323209442, 0.12091639917343855, 0.0953187387494836, 0.1289299168274738, 0.07379555070656352, 0.23433029389707372, 0.15130111249163747, 0.19220470043364912, 0.17245883733266965, 0.12156798256910406, 0.13328716973774135, 0.12040776826324873, 0.0785746774636209, 0.11028150460333563, 0.17938904202310368, 0.12450799316866323, 0.11090430009062402, 0.12025761694530956, 0.12223178171552718, 0.14325060619739816, 0.11173387276357971, 0.11734457599231973, 0.10068941657664254, 0.07009347318671644, 0.30018395162187517, 0.09586656247847714, 0.09599617114872672, 0.09583724022377282, 0.1727009704336524, 0.1267595059471205, 0.19543359201634303, 0.13083696918329224, 0.12782609090209007, 0.25395696808118373, 0.0992642629717011, 0.17158112896140665, 0.14514729817165062, 0.1845884247450158, 0.0901933629938867, 0.13879705220460892, 0.19019674567971379, 0.1711565611185506, 0.09587644788553007, 0.1122435501019936, 0.09585233550751582, 0.0893318334419746, 0.17672149610007182, 0.15564499190077186, 0.17734350491082296, 0.08950491712312214, 0.10545021228608675, 0.17193482170114294, 0.1478895338368602, 0.2126571029657498, 0.08827600962831639, 0.09918630035826936, 0.11025515093933791, 0.16893203282961622, 0.13654233334818855, 0.1401202124543488, 0.14970181393437088, 0.12099718194804154, 0.20206172775942832, 0.15310052374843508, 0.239897514693439, 0.0832256353169214, 0.1522838050732389, 0.13839755411027, 0.1715722231892869, 0.136701850569807, 0.12621365633094683, 0.1624538702890277, 0.15145487064728513, 0.2142250828910619, 0.07934919762192294, 0.17730307270539925, 0.15339180186856538, 0.09110595230595209, 0.3320046019507572, 0.1505930590792559, 0.11906677420483902, 0.11806373193394393, 0.11911627545487136, 0.1472240500152111, 0.13692626118427143, 0.13124920253176242, 0.23285377625143155, 0.14098270679824054, 0.1852927080472, 0.17140938114607707, 0.09721074777189642, 0.1041096486733295, 0.10228098195511848, 0.07844298335839994, 0.1616152879432775, 0.1849829059210606, 0.1347212662221864, 0.09107710502576083, 0.08645533584058285, 0.1535369362682104, 0.1287557792966254, 0.10471005356521346, 0.24196359445340931, 0.17768003919627517, 0.20124024449614808, 0.09924081852659583, 0.1233888122078497, 0.17803659662604332, 0.12805001169908792, 0.1309095066972077, 0.16969974007224664, 0.17017907841363922, 0.09068980041774921, 0.175966449896805, 0.10535227847867645, 0.14421361702261493, 0.16697225830284879, 0.17546527757076547, 0.17324272339465097], [0.07635078742168844, 0.0313255227956688, 0.02065641150693409, 0.0373454722284805, 0.053849671385250986, 0.05135221086675301, 0.06221451061719563, 0.060923129130969755, 0.020814078925468493, 0.04732658664579503, 0.03795152486418374, 0.046372496435651556, 0.004235667784087127, 0.017719022544042673, 0.02165711972338613, 0.017226574163942132, 0.024834231662680395, 0.007785604102537036, 0.08098296893876977, 0.03639464746811427, 0.021855460545339156, 0.032216203908319585, 0.052211770016583614, 0.008979433059721487, 0.03824702580459416, 0.008824813085084315, 0.03631952728028409, 0.023707556865701918, 0.01802007474907441, 0.05856590854818933, 0.050829460597014986, 0.029974624776514247, 0.07011464665993117, 0.03420576453208923, 0.040325313893845305, 0.04945634638716001, 0.09272845039959066, 0.019551207042241003, 0.04242321323545184, 0.0544868682482047, 0.05687363744073082, 0.048095143647515215, 0.07533030468039215, 0.053360573801910505, 0.08440678560873494, 0.013109654646541458, 0.003340035154906218, 0.02883558950998122, 0.016899585752980784, 0.041235042226617225, 0.04361007064289879, 0.02414042563032126, 0.030371913126145955, 0.06919709237990901, 0.027734043833334, 0.022040576295694336, 0.054983795489533804, 0.025325292226625606, 0.04638217775209341, 0.011757599804695928, 0.027055993596150074, 0.06098595564253628, 0.03482276755676139, 0.08060257372562774, 0.02450446947477758, 0.023335416190093383, 0.035124090645695105, 0.06842120666988194, 0.04403391860250849, 0.07745521448669024, 0.005603556346613914, 0.04268174037861172, 0.04477005859371275, 0.12567365483846515, 0.04058071288454812, 0.04260000765498262, 0.023192203952930868, 0.08018620661459863, 0.039567903950228356, 0.025515087218082044, 0.010594344548735535, 0.022677292618027423, 0.05717091953556519, 0.06550153091666289, 0.03500718012219295, 0.02169206189137185, 0.0365087972022593, 0.021678972261724994, 0.05004390099202283, 0.07786619360558689, 0.035364219947950915, 0.02306540060089901, 0.02054366257652873, 0.008526239653292578, 0.030940513279347215, 0.04329765615693759, 0.025618242034397554, 0.08215427835239097, 0.07168666386860423, 0.025598198481020518, 0.016339295798388775, 0.02480458286299836, 0.006901939068484353, 0.01750694642396411, 0.049208509881282225, 0.01480912922488642, 0.01897602589451708, 0.03533654897182714, 0.019808457691397052, 0.0497394831472775, 0.008800441883067833, 0.08602670102845877, 0.017526116098451894, 0.05062322146841325, 0.030808670744590927, 0.037926236182102, 0.013520336906367447, 0.020759020844707265, 0.035330240716575645, 0.035076292624580674, 0.049269607188762166, 0.02811430731526343, 0.03061335788515862, 0.006549360941789928, 0.008078224582277471, 0.05030956017435528, 0.02013848705246346, 0.036426474471227266, 0.048327487820643, 0.018658564804354683, 0.11354608606779948, 0.04163918245467357, 0.046106889203656465, 0.04740994096209761, 0.023493230182793923, 0.03402106623980217, 0.029907618118159007, 0.042800428345799446, 0.04480675779632293, 0.028084267032681964, 0.034878083533840254, 0.00481892303469067, 0.0406069663586095, 0.03333237174956594, 0.027478429619804956, 0.021752246357209515, 0.04999414370104205, 0.021638888865709305, 0.01673349124757806, 0.03275330731412396, 0.0498770105332369, 0.015247306200762978, 0.03753287564904895, 0.012712414536508732, 0.017799799752538092, 0.010469570970599307, 0.004445214572115219, 0.013735146912949858, 0.048780483630253, 0.014764313709747512, 0.049533997298567556, 0.044662176296697, 0.017424293437215965, 0.029163307081034873, 0.03715557890245691, 0.07466951865353622, 0.013583353593276115, 0.03172221186105162, 0.050524226389825344, 0.029500527853087988, 0.03239359204599168, 0.029462815618899185, 0.06192441622260958, 0.017274767378694378, 0.043778619801742025, 0.05124497794895433, 0.03206993773346767, 0.01697442763543222, 0.04168791929259896, 0.027542426869331393, 0.040702681144466624, 0.011351829634804744, 0.03683783579617739, 0.04214235486870166, 0.02481750736478716, 0.02221088248916203, 0.029008298406552058, 0.046705305139767006, 0.04620717190846335, 0.06394770374754444, 0.04801922936167102, 0.01994842303247424, 0.04642432431865018, 0.023087440531526227, 0.02541237583500333, 0.003748023186744831, 0.03314573274110444, 0.033360269080731086, 0.033331017330056056, 0.007175551290856674, 0.029477478601620533, 0.08466048879199661, 0.07281768950633705, 0.0197335527263931, 0.06432682988815941, 0.02029982439125888, 0.03240697296860162, 0.006234928277990548, 0.039602020478923805, 0.0188224699741113, 0.05768162845924962, 0.037647274002665654, 0.04127912950934842, 0.02837489762896439, 0.03324908422655426, 0.03017413448105799, 0.03743613669939805, 0.09180667329928838, 0.018736095116764773, 0.03566301231330726, 0.09715893844258972, 0.03608350576541852, 0.01378679575282149, 0.01508932800788898, 0.020523123639577534, 0.05073655855085235, 0.026265496853739023, 0.031021405520732515, 0.02446896327455761, 0.04445983715413604, 0.015184432377282064, 0.05981050133414101, 0.07188947798567824, 0.036775417465833016, 0.036321319566923194, 0.015321101654990343, 0.058888983985525556, 0.025135575160675216, 0.07883952770498581, 0.03142704859783407, 0.03677212975162547, 0.03981204456067644, 0.024730616714805365, 0.0475298089440912, 0.04971472510078456, 0.046161526115611196, 0.048072467325255275, 0.011138205209135776, 0.010710240185289877, 0.05881679528101813, 0.02166592159483116, 0.019796375527221244, 0.03158019077091012, 0.0703428644919768, 0.11769065429689363, 0.03630284751125146, 0.04577706764393952, 0.0221420371599379, 0.010019365636253497, 0.04680208490754012, 0.09111456121900119, 0.02069899779598927, 0.03872507280902937, 0.05419118177087512, 0.061893186648376286, 0.023975607618922368, 0.01637718243728159, 0.0709451395960059, 0.09475559709244408, 0.03720794113178272, 0.033871352788992226, 0.026041628007078543, 0.017542714231240097, 0.027137334836879745, 0.07189922980614938, 0.04152801615418866, 0.014087445342738647, 0.05699802881281357, 0.03379797293746378, 0.07944940982270055, 0.03940031958336476, 0.026827467772818636, 0.024769900446699467, 0.014061870006116806, 0.023956588229339104, 0.027349863667041063, 0.023129650180635508, 0.015543740391876781, 0.059254291336401366, 0.05444096270366572, 0.030080876204010565, 0.01900553183077136, 0.051923178471042775, 0.020028133403684478, 0.02143232133676065, 0.06167553328850772, 0.02192219817516161, 0.0548005666496465, 0.019387183128856122, 0.02830039527907502, 0.05609874249785207, 0.03860229189740494, 0.020551390189211816, 0.06501967669464648, 0.03850191271340009, 0.01870135332865175, 0.038137199080665596, 0.07112528110155836, 0.035607392055680975, 0.06613840494537726, 0.007613186498929281, 0.013465384581650142, 0.02675766321772244, 0.029649035313923378, 0.0700215293909423, 0.07384492579149082, 0.04044929337396752, 0.020170232419332024, 0.009231257681676652, 0.034194142499472946, 0.01231003876455361, 0.03636856097728014, 0.11278214151388966, 0.0441247463459149, 0.04492911197303329, 0.06663185151410289, 0.031822828532313, 0.015124664441827917, 0.05269093766401056, 0.055205827520694584, 0.030286304536275566, 0.032221781148109585, 0.01201372981086024, 0.015224084399960702, 0.02202531773946248, 0.025429847846680786, 0.03623125623562373, 0.051593928365036845, 0.02644721171236597, 0.03343492171552498, 0.015520675369771197, 0.05429460376035422, 0.048992077354341745, 0.06368202230078168, 0.05863933663931675, 0.03430043660046067, 0.05312916844559368, 0.09791724267415702, 0.033083930393331684, 0.03921944706235081, 0.05505049601197243, 0.05133563499839511, 0.11699912851327099, 0.10444840198033489, 0.10601702757412568, 0.1302456110715866, 0.10965597059112042, 0.15461937349755317, 0.07942625481518917, 0.13196359388530254, 0.06101866951212287, 0.12466964777559042, 0.1298371478333138, 0.1488009505555965, 0.1111900492105633, 0.22834432369563729, 0.0986182531050872, 0.15716155583504587, 0.10843907104572281, 0.20541804609820247, 0.19942251703469083, 0.06990671914536506, 0.1680405650404282, 0.07661063558771275, 0.1485886369482614, 0.11077150760684162, 0.1388316511292942, 0.18614528729813173, 0.1510932220844552, 0.0932278267282527, 0.10988881942466833, 0.19257412670413032, 0.0995543239696417, 0.08984085769043304, 0.06609890042454936, 0.08783654688159004, 0.15658143383916467, 0.19520970090525225, 0.23327218426857144, 0.11112728578154929, 0.1299829056370072, 0.1549053972121328, 0.15341810358222574, 0.22078675188822672, 0.09198830652167089, 0.1522316617774777, 0.24318935524206609, 0.1430337951751426, 0.10916693980107084, 0.08911298151360825, 0.11275235170614906, 0.11116739886347204, 0.12398556573316455, 0.10769594373414293, 0.1470789304585196, 0.1924248956493102, 0.08376373691135086, 0.21321696433005854, 0.14863877644529566, 0.1270909490995109, 0.14019043446751311, 0.18733379227342084, 0.0724798341980204, 0.15994783054338768, 0.21510046091862023, 0.17700787604553625, 0.15424674114910886, 0.13959676085505635, 0.12343954542302527, 0.18287035287357867, 0.14552297332556918, 0.11100909134256653, 0.13663164339959621, 0.09219377010595053, 0.15188614750513807, 0.2147258396144025, 0.14471833681454882, 0.14112295786617324, 0.21107525972183794, 0.1663027223548852, 0.17128947976743802, 0.1528708141995594, 0.15907957713352516, 0.11301132413791493, 0.11298187571810558, 0.14646800933405757, 0.24368098354898393, 0.1300491942674853, 0.1426259256550111, 0.10833905180334114, 0.18401576875476167, 0.1915992415160872, 0.21776959503768012, 0.20855313021456823, 0.17996499314904213, 0.10058665138785727, 0.12166491447715089, 0.1053912412317004, 0.15233079786412418, 0.20744969020597637, 0.14934872975572944, 0.1504251259029843, 0.0796422346320469, 0.08689804919413291, 0.09955368572263978, 0.10870681566302665, 0.09292126778746024, 0.1955199780059047, 0.08221118623623624, 0.1438263792078942, 0.07681898612645455, 0.1264489468303509, 0.08509489009156823, 0.12411759380484, 0.16232535999733955, 0.11273421361693181, 0.08708012028364465, 0.23844560666475445, 0.1329594521666877, 0.08435744763119146, 0.1257428081589751, 0.1485461267293431, 0.09951044077752158, 0.17297010286711156, 0.147054543485865, 0.09542617946863174, 0.16913815692532808, 0.14647998759755865, 0.21530084079131484, 0.19386549334740266, 0.1431314618093893, 0.13018427998758852, 0.1974230821360834, 0.18670863675652072, 0.12138798949308693, 0.38816686486825347, 0.10069430732983164, 0.09773036988917738, 0.16704881825717166, 0.11619351236731745, 0.16155708872247487, 0.17598420206923038, 0.1354865392204374, 0.13507089199265465, 0.09407742254552431, 0.19379286677576602, 0.07706110438448377, 0.11917140218429267, 0.318116644048132, 0.1057858337298967, 0.06701179401716217, 0.15111000946490094, 0.23025899048661813, 0.1901678167632781, 0.1028451626189053, 0.11325679690344259, 0.18003235047217458, 0.08469602282275446, 0.0907546938105952, 0.12173436465673149, 0.096811360999709, 0.09870470588793978, 0.19374326162505895, 0.1484944435651414, 0.06526754659716971, 0.10675151628674939, 0.20442065899260342, 0.1713322423165664, 0.06853560131276026, 0.19855138409184292, 0.2582006872398779, 0.17331339069642127, 0.11484116344945505, 0.2828008937649429, 0.16842174693010747, 0.08550701953936368, 0.23748151230392978, 0.16749346861615777], [0.040519229660276324, 0.023983155260793865, 0.02845966759196017, 0.010817573293024907, 0.03297438568552025, 0.030772921491006855, 0.09392844382091425, 0.021408698776212987, 0.03610800034948625, 0.022096554639574606, 0.016538402887817938, 0.039116269981605, 0.02140412529115565, 0.01790744085155893, 0.043194274985580705, 0.0316862288309494, 0.019376926647964865, 0.029597732500405982, 0.03798990132054314, 0.005659829230353353, 0.14198101416695863, 0.047570690148859285, 0.013872602867195383, 0.06022408910212107, 0.057466208963887766, 0.021544992341659963, 0.014984699100750731, 0.035002471195184626, 0.07049370600725524, 0.01699391086731339, 0.0136211140670639, 0.026289750239811838, 0.08918737439671531, 0.07950927145429887, 0.014020617727510398, 0.03774455843085889, 0.06249807411222719, 0.05169464893697295, 0.023996352501853835, 0.032993985805660486, 0.034879426821134984, 0.018004758676397614, 0.00149155657254596, 0.0070186635912250495, 0.019048941903747618, 0.03644461256044451, 0.04188108548987657, 0.07590011824504472, 0.06774098379537463, 0.04138119336857926, 0.045347505147219636, 0.09470713484915905, 0.024119691879604943, 0.08485651225782931, 0.02009414372878382, 0.016064242881839164, 0.002115062202392437, 0.05496881152794231, 0.05327093349478673, 0.05726038172724657, 0.011438208202889655, 0.07117149463738315, 0.06211917432665359, 0.03223447558411863, 0.03006173064932227, 0.046464611805276945, 0.050448946640244685, 0.05238345474936068, 0.024210228330048267, 0.014632380261900835, 0.08431308204308152, 0.031014427477202844, 0.04852889556786977, 0.02917664904089179, 0.061414059819071554, 0.02893196295190137, 0.01819766141125001, 0.01887175971205579, 0.03188539900293108, 0.05541212231037207, 0.052218289783922955, 0.04750463900563773, 0.025632808537920937, 0.024231297902588267, 0.08453386355540715, 0.056679658591747284, 0.1365588980843313, 0.05582158002653159, 0.02134986501914682, 0.07907400184194557, 0.014848565097054234, 0.0775582023197785, 0.03225190121156629, 0.004225630700602778, 0.0052329825302877, 0.03539216180797666, 0.04803786097909324, 0.023507130608777516, 0.07031881890725344, 0.038119124074000865, 0.02094426647090586, 0.05215240191319026, 0.0731915315554943, 0.014102074928814545, 0.015284212277038023, 0.018654484847502317, 0.043646276317304, 0.00887537467860966, 0.04822193586733192, 0.06833643114077859, 0.051257987797725946, 0.04039736530103255, 0.032673867826815695, 0.04367399924376514, 0.018979567794303875, 0.06585270035429858, 0.021885675232624635, 0.02005203798034927, 0.05305029670125805, 0.030221876841096673, 0.05365464610804338, 0.053984879559720866, 0.05549488661927171, 0.04634274373529479, 0.04223887859552633, 0.014470027108473005, 0.05105925549287349, 0.010984306973114144, 0.03860959091980476, 0.03513815434416756, 0.0450977984291967, 0.06537129884236492, 0.033599010566831566, 0.04598505824105814, 0.03609401828725822, 0.030506996990879998, 0.04540314766927622, 0.03844081540592015, 0.0577935554611031, 0.10141925202333368, 0.051537180042942055, 0.03508933586999774, 0.05712608639441896, 0.06716624979162589, 0.03745957372302655, 0.044118452933616936, 0.044696162949549034, 0.017994170084421057, 0.025252361374441534, 0.035181595958420075, 0.014798652882745955, 0.037253393966238946, 0.061231228028191254, 0.04766049001773354, 0.032256472841254435, 0.03472407675872091, 0.027195020120416302, 0.026241339946864173, 0.04527181721641682, 0.00870644609676674, 0.024736010273045395, 0.012632444413611665, 0.006892480396345491, 0.011327874035487184, 0.04285944392904639, 0.03055520875932416, 0.017862392487586476, 0.014109796047705458, 0.03425732895266265, 0.030748066965315957, 0.03845229643047787, 0.010579312347545056, 0.037466831927304156, 0.022352831219905056, 0.029212643203209154, 0.011053786838601809, 0.038348800226231106, 0.07646897443919443, 0.05829381865623873, 0.031155040342127904, 0.030172267979651224, 0.03941273571399506, 0.030645767474197783, 0.030921235993446317, 0.062450665718642995, 0.031797558403923176, 0.039635665743844584, 0.06423901897505857, 0.06018704480084125, 0.058221069630235434, 0.045657856462639757, 0.016356602682208177, 0.06361545165418647, 0.025681497136247344, 0.05876573552086484, 0.03464285982772708, 0.049744425850803964, 0.026520224200794473, 0.05576316929364111, 0.024893686968425754, 0.016148925642482936, 0.025770124411792494, 0.08392741758143529, 0.08453096917946823, 0.0521688145090593, 0.0842184730572626, 0.0924244370253291, 0.04983829268894624, 0.04655638578697108, 0.022896059199410956, 0.03292130357294809, 0.02471888336003758, 0.07046554892440327, 0.006486416150437435, 0.004768207909364719, 0.02693435559194768, 0.047842687272350304, 0.0638526123657357, 0.03566078587027732, 0.007645675405001384, 0.031229166052071378, 0.04101140715647489, 0.06430058012483642, 0.06868630924145691, 0.09291981317801401, 0.01493251684223651, 0.038439353374997154, 0.012203831865917891, 0.055456933187088, 0.023231732593558263, 0.04273507853213232, 0.027556132481549866, 0.027613708298304118, 0.0619757802633103, 0.05491545110999141, 0.08971795061370358, 0.016355456064047758, 0.03474755088973325, 0.06701448059175164, 0.01906453813717235, 0.0520369756850414, 0.034713300774456, 0.04181160191365052, 0.04270961173460819, 0.01985565642826259, 0.06190032610902563, 0.02169151270209113, 0.008263518448075047, 0.023361272615147755, 0.029818406401318498, 0.03301488839497324, 0.07993303777766414, 0.03296084520115983, 0.028443553710530978, 0.03299940719443839, 0.05760774023656268, 0.01870602514827624, 0.04096625118108932, 0.03787874986301176, 0.00967371313890908, 0.04868273164902348, 0.03155447535391431, 0.054608216814813204, 0.06092917021305766, 0.037055388966109604, 0.03069243743084371, 0.024533966134185903, 0.07895708389696665, 0.021676517608284485, 0.034283148270333186, 0.037884902267251164, 0.05123405353515409, 0.032804096190375276, 0.02030315106821945, 0.016077061627584044, 0.03470169729553163, 0.03837563257548027, 0.05874865499208681, 0.07799272236297838, 0.036228528842912056, 0.018625472439453006, 0.008149105251504807, 0.05589582819084171, 0.027092132477264386, 0.014301044720923528, 0.053744553588330746, 0.06321804641629569, 0.08711690112249926, 0.11185403389390558, 0.04211981955450028, 0.01806043273973046, 0.037681242101825774, 0.026196102335234173, 0.06896622508065775, 0.040619196952320635, 0.01391474943375215, 0.004553415992631926, 0.03273686503234785, 0.039320097130257636, 0.018683974085433874, 0.05368030215322506, 0.038669775385642424, 0.034414875772199593, 0.048971902069752105, 0.07164376773289405, 0.010849648915609578, 0.017645967382122763, 0.08346034694113769, 0.010847864978131838, 0.012078468280378729, 0.047172127160592936, 0.017732030537445098, 0.014825427715550177, 0.020243773687980138, 0.014245002366806148, 0.031184915496851318, 0.039886975500849076, 0.09231254342012107, 0.04584317444823682, 0.05595191600150429, 0.050006841847789474, 0.008784635065239854, 0.02723816673096735, 0.02591936103272019, 0.013471307847794378, 0.042203860357403755, 0.060793141965405084, 0.04690390014729928, 0.039689167169854045, 0.03957777822506614, 0.05347752143279649, 0.031503868303843774, 0.07679459915379994, 0.05431602585304063, 0.032234586906270124, 0.02045168079348514, 0.051234105485491455, 0.00893491162059945, 0.05833613220602274, 0.042469051986699924, 0.029341713816393167, 0.08353433906449936, 0.03974368533818051, 0.0033067424101318466, 0.028999262758588884, 0.05002019308449235, 0.023750389918859582, 0.04081798491824884, 0.023814476226107217, 0.05058052200183738, 0.019393624970689416, 0.027143333245476242, 0.13834803801728413, 0.22521394479554147, 0.20658905123127624, 0.10041698900749907, 0.11571455252123997, 0.14583393320208415, 0.2047668708837591, 0.11933481568121351, 0.15691845794208348, 0.1307690775138326, 0.12017271525110118, 0.15445233089849353, 0.23970396257936954, 0.12506208062404767, 0.10048770825960673, 0.10678768114303239, 0.18250650755362585, 0.09504493078566156, 0.19589186820667237, 0.13285509136039764, 0.23669537011301145, 0.12221127617522143, 0.18315478839213029, 0.16390524397138506, 0.10528448328841478, 0.15929999499348924, 0.13607136643258855, 0.16488596244016662, 0.16260013275314122, 0.15734284766949713, 0.15882174018770456, 0.1187093261978589, 0.17600516031961888, 0.16172865842236206, 0.11847075540572405, 0.10919880020082928, 0.26385214179754257, 0.19258491753134876, 0.11419312009820715, 0.1345774083165452, 0.1045584624807816, 0.21485384524567053, 0.10099283623276278, 0.11188636184670031, 0.07486322661861777, 0.13124835648341104, 0.23714358278084546, 0.171707026893273, 0.163156847411301, 0.10327511845389381, 0.13234835292678326, 0.17530348937725648, 0.24510281975381076, 0.13148817408364266, 0.14899318164680153, 0.06612811135710217, 0.1285530987661332, 0.14518211974063888, 0.15400824457174167, 0.14983578643295914, 0.09493540463154204, 0.09945179626811296, 0.1780979277100414, 0.16811403766041622, 0.22700856177834794, 0.22271470312261954, 0.15732971165562049, 0.14283550815889612, 0.13717145193368196, 0.16448711743578315, 0.13516702980268747, 0.1278544557862915, 0.1158757098892238, 0.08746889434405603, 0.10667244045180269, 0.08541761300875805, 0.09298769742599688, 0.09722206552396528, 0.1323584164492786, 0.14865924487821758, 0.17672073910944164, 0.1050851350009907, 0.1287910609971732, 0.10707464738516137, 0.17856421909527853, 0.14935834798961878, 0.20551480731228366, 0.18616060522617772, 0.16720196785172448, 0.10982236010022461, 0.09803802720853128, 0.19040732266148552, 0.1326831357437186, 0.09460222485358827, 0.11206671115360223, 0.10881556256208569, 0.21747760445578024, 0.09226366557413712, 0.2134854585165158, 0.12008129750029184, 0.0916123270872049, 0.12319598739850335, 0.15428715851157904, 0.09495838894508779, 0.11160471680341288, 0.08767665858613327, 0.18526901869336143, 0.09426543081644922, 0.10926951945293695, 0.11762363094021566, 0.1540273177670315, 0.1694668986601755, 0.2565667749149725, 0.11066236736951396, 0.08340727596078068, 0.20719244697829708, 0.10076075181132182, 0.10730644236900844, 0.18274835863849148, 0.08039466847549193, 0.1384486138704233, 0.14748772024177015, 0.11356564165907912, 0.10907121759373695, 0.1301748547120951, 0.20197166071739048, 0.12313234081375413, 0.09669442079029977, 0.1660251888097264, 0.10268534111673944, 0.0828240517876111, 0.12398563252645545, 0.0779820725438185, 0.1145528168126475, 0.11931118569918908, 0.10283829775289632, 0.09444218812859617, 0.11132094179629348, 0.09807813286897726, 0.16814638045616448, 0.12385375288431533, 0.19247006275691092, 0.2277996318298392, 0.08969469170551747, 0.14740590588189662, 0.1037578632531222, 0.10826067358721048, 0.11431696228100918, 0.06947844798560254, 0.12787891697371379, 0.2008256214321591, 0.09686141143902205, 0.2016186507535167, 0.1230689614021685, 0.14399459440028295, 0.12262560980161652, 0.1981608066125773, 0.08040922199143097, 0.12388926465064287, 0.13433257379801944, 0.11652419110760093, 0.11341087418259121, 0.07019070937531069, 0.15084927814314142, 0.17555933736730367, 0.08845448872307315, 0.1683479774510488, 0.10216114736977033, 0.13450445519993082, 0.15575144556351006, 0.10110566494404338, 0.1552094699582085, 0.24179303407436237, 0.1684354618191719, 0.1164806418819353, 0.1331233629025519], [0.013459665406116983, 0.03365098687936552, 0.054573228262597695, 0.020050520288350526, 0.07983297400642186, 0.020856205082964152, 0.02235192765510874, 0.03653825675428379, 0.06103535670263227, 0.10890633464441635, 0.047286677654483356, 0.040068464004434645, 0.015158772621362004, 0.04190239997114986, 0.05891828768653795, 0.03201341947715264, 0.04096327145816758, 0.04040499457914848, 0.03252325266657863, 0.0670268596149981, 0.07275310039403848, 0.07544789055828005, 0.041672924198792316, 0.006504786624645931, 0.014009169171913527, 0.045131187653169036, 0.0762219208991155, 0.008711998289072653, 0.04766547353938222, 0.0319540253985906, 0.02604497509310022, 0.06342289401800372, 0.03599361683882307, 0.009052914028870873, 0.0417528238176601, 0.02430494121654192, 0.025939710722013842, 0.11807486414909363, 0.056486796675017104, 0.03401983427465893, 0.04315842925279867, 0.05767058159108274, 0.025302038884547073, 0.023733706439088564, 0.02269617842102889, 0.038364763822755776, 0.04283864524040837, 0.02262200076074805, 0.05841538244567346, 0.05643057527777273, 0.08288504148367792, 0.03605723373766523, 0.044831820123363286, 0.06532072889967822, 0.10763464975752868, 0.047750768571859226, 0.05239796002570074, 0.07345555059146136, 0.12214981892611831, 0.010666262369340984, 0.02665654188604094, 0.012827671926061157, 0.07315961920539849, 0.12217687020893209, 0.005959540003459551, 0.038264061804511584, 0.07779350766213611, 0.042651642579585314, 0.018980979730258696, 0.04314069934480358, 0.05393695908423979, 0.07866122672567144, 0.06087727924750652, 0.03937214023608249, 0.046743436687393114, 0.06361403415212408, 0.03556680399924517, 0.0803090023691766, 0.026627854167600162, 0.0611681640293682, 0.00288372310478735, 0.02321259817108512, 0.013820772201142972, 0.03937501605832949, 0.040682153339730576, 0.023418560849677306, 0.05188665367313661, 0.0428653514245525, 0.06290152785368264, 0.03378723034984432, 0.03800500031502452, 0.03483590357063804, 0.05300420933053829, 0.052053199033252895, 0.04731347660708707, 0.08032044628635049, 0.02939432095445227, 0.018027906262432225, 0.0663846124371048, 0.02798455021547852, 0.06385591492289677, 0.05991768601234071, 0.0024236402487076703, 0.04350910516222939, 0.03652387393231038, 0.028737190004903823, 0.021435356720758136, 0.08035765757085755, 0.04106454493012279, 0.03140557084407192, 0.07252566181705333, 0.028757873660651967, 0.12514594331150874, 0.03556473340722732, 0.06582990157767199, 0.009265939170290949, 0.04414250222907867, 0.047155933498288505, 0.034243005502503365, 0.056869366380851716, 0.011048108481190866, 0.021145716891624033, 0.050024033698718995, 0.041466863185632974, 0.013832807053404395, 0.029490117376553826, 0.013263014825497521, 0.032871138100745156, 0.04176581140200142, 0.039005177895887755, 0.0063987021803768585, 0.04369014837720897, 0.026431910482642706, 0.06057360355043784, 0.00832887568321894, 0.017373860791849438, 0.03924190445104614, 0.02485509899997851, 0.04627859249012545, 0.044631358614424244, 0.05102374001580756, 0.00954854807787342, 0.04729033273179084, 0.031033929262775928, 0.08125023116008379, 0.060430383891798556, 0.03921726885891985, 0.015426786267198622, 0.031434006232302636, 0.023834900130168535, 0.09388116901391186, 0.04148720545344986, 0.061207739054225385, 0.08475150578306057, 0.012803058598365169, 0.061040733562549576, 0.03821502068603877, 0.06845518219051883, 0.06194615001732018, 0.06976673525059596, 0.056623151467647403, 0.02866189355700044, 0.045106236648280174, 0.064920985896606, 0.017833354104368482, 0.06638212624238804, 0.05749051801103633, 0.015470749240193982, 0.008852036917232908, 0.11033791524823755, 0.028454600578697864, 0.06355458812322468, 0.08157194475643337, 0.030867838468111586, 0.0437608305219328, 0.040905951682361774, 0.028165517360321246, 0.057643326217657886, 0.027239137089054566, 0.02571237419033423, 0.07902935423771851, 0.056786190179991536, 0.06572975617018528, 0.04673761082813144, 0.018347278382861987, 0.06428096516174264, 0.028336732684692834, 0.0665833818493411, 0.04801001930900384, 0.03295878203061875, 0.027373940793040674, 0.09014163530082442, 0.06711655558319762, 0.010704683354560984, 0.04236871733155567, 0.04088195062649902, 0.04968653462128714, 0.042533789528533816, 0.04364472522865981, 0.024043888915912248, 0.046935244754422456, 0.06179874464578461, 0.04999282267817762, 0.03592336142901331, 0.04576200575684197, 0.035748886220972054, 0.052023650423507206, 0.044397715682862327, 0.06416634787456132, 0.01795103646145435, 0.02333162567083491, 0.05240239064733032, 0.03137476429401431, 0.046040593151701614, 0.05215963414229918, 0.05798954181955196, 0.06741513643646613, 0.03478956386970822, 0.0394075926305959, 0.06876802712213248, 0.030792523466516286, 0.039110581419663504, 0.03958938170399051, 0.051629503213916905, 0.019780048278335016, 0.011585619140532799, 0.016116898259497248, 0.0425889904727228, 0.05070802668342367, 0.02710165052121738, 0.07799058497766964, 0.0235262557544047, 0.022015634567651432, 0.05906236452574376, 0.015859538143558893, 0.03267515916377306, 0.008848012621456292, 0.03342020863783546, 0.04457506671315059, 0.14799010968999937, 0.06692570488667116, 0.006911781338203582, 0.033362517788191326, 0.01518376722742687, 0.042236325607518665, 0.015217337349895388, 0.00920562946703285, 0.03146616349113174, 0.049547467278898694, 0.042699188270489685, 0.03265857958467677, 0.049559690451133065, 0.04284974405891262, 0.0818273400363978, 0.026181038592767436, 0.03303533456346486, 0.047278977872338146, 0.07261347273015417, 0.048496875606360845, 0.03019977197254775, 0.0714122992940247, 0.02758659393293783, 0.06420586723834276, 0.027247261750744656, 0.039284359008888714, 0.06804401011322625, 0.05859318989678286, 0.008097146564978175, 0.046593782608397305, 0.08640071377158165, 0.042234154825564474, 0.04297919316741172, 0.06614236801397055, 0.016981830558506772, 0.01583972651133081, 0.017362598700856324, 0.03682582413603086, 0.06809363010688685, 0.008419774858339224, 0.011726528864528518, 0.029532688822655473, 0.015253766596288187, 0.06045071502740029, 0.0352766242576763, 0.05376381603127811, 0.024003271173569374, 0.008570015233999584, 0.02180844734539278, 0.04387585227959789, 0.08394647593377158, 0.05903591438254807, 0.03967203098000027, 0.09262639767257497, 0.03612865060858894, 0.04848451142606791, 0.04320395259128418, 0.07761598593788221, 0.02684283950657118, 0.011260022256465163, 0.084963299887022, 0.05757415063271765, 0.057143107551382855, 0.022361113587976433, 0.02228367047791835, 0.016985129404929467, 0.012011418948532082, 0.08501497562974691, 0.015363437469204655, 0.008576391210226575, 0.010237019923806656, 0.03505461078020744, 0.028471562363847625, 0.08914986625313759, 0.02516090466087917, 0.037028615988674574, 0.08460033030132763, 0.039707724572508596, 0.05980045265459921, 0.0179362194830901, 0.040461119497194886, 0.08208841274608858, 0.039689857367193326, 0.027778747098636813, 0.011154237454320537, 0.03999679109256249, 0.0022989912122284295, 0.026002485283243004, 0.012867102232121397, 0.005984141271255794, 0.07003209015238099, 0.030956077971495688, 0.0572244320937898, 0.01759608021529857, 0.01353718736936571, 0.04381243576062843, 0.06900889857206494, 0.028637812720262446, 0.02974020258989185, 0.07960648537846282, 0.021192928616073914, 0.01847591298428597, 0.02085177260596538, 0.031668799492763355, 0.02051369650871493, 0.015841320273466408, 0.06428981898352504, 0.06200049749168102, 0.05011925495637115, 0.05689566067303531, 0.029805103404214606, 0.026160106317547616, 0.021052983684057835, 0.08110330818453804, 0.11545157991349697, 0.07724854120169766, 0.11011867740307935, 0.1661104170489125, 0.2179770401562564, 0.11109379265690222, 0.11553375792573206, 0.24385396332945675, 0.22528191067976877, 0.12233270637807436, 0.1399805402616039, 0.14682052948046476, 0.11400832532672212, 0.09239927821909077, 0.16610473219770938, 0.1368383166845888, 0.1504689868306741, 0.18205287720775232, 0.16441910702269524, 0.14267452148487791, 0.13729890837566927, 0.08458085634629242, 0.06947641450096853, 0.22642299241852015, 0.1538545309449546, 0.17736643727403134, 0.0725912454072386, 0.14854493929306045, 0.07385200588032603, 0.23947686539031565, 0.10390409603132866, 0.10014396772021428, 0.08236371984821744, 0.17008484050165862, 0.11297895907773636, 0.19393178197788075, 0.27913901838473976, 0.2572296018479392, 0.12233508125063963, 0.10674813209334388, 0.17884098080685362, 0.1563242796692066, 0.23099315265426412, 0.08575301922974177, 0.12739325553411618, 0.11036360840080306, 0.09394070410053246, 0.0807341565086972, 0.15525971335591748, 0.1668400372727774, 0.10138667916180566, 0.19350118789589033, 0.1512234244728461, 0.16799348319182172, 0.12151242539403029, 0.1674720799201168, 0.14552702545188367, 0.1767863004351966, 0.08380862200283445, 0.07367413534666412, 0.15255758335115388, 0.1479258545441553, 0.2253894181922078, 0.16786889143986627, 0.09339424592326395, 0.1944691117387265, 0.11118801572592929, 0.10710493443184532, 0.15440259216120467, 0.1363090763334185, 0.26982087932992727, 0.16702379303751513, 0.14613435458159074, 0.18088218377670273, 0.20958700129995123, 0.11915675218915567, 0.24499446619302034, 0.07446258561685681, 0.15603322419337928, 0.15727431775303558, 0.10672240183339454, 0.20878361159702763, 0.12246466765645891, 0.22991923528024927, 0.13507246534572914, 0.13661092263646424, 0.17641726008150727, 0.30219211417715997, 0.2172598583274521, 0.15025063214125112, 0.15524749760515988, 0.19856886909110472, 0.14007762802066281, 0.211635269515682, 0.11426205077441409, 0.15301694307709113, 0.11211679870029911, 0.1227650890359655, 0.1323000984848477, 0.14366465038619936, 0.1725394939421676, 0.1501934719271958, 0.10369132229243405, 0.11550897019333206, 0.09116190281929448, 0.20835079107200727, 0.1852177214459516, 0.09744733702973463, 0.12329959121416323, 0.13366691186092794, 0.09494171288679354, 0.1438616163795814, 0.13496998959453776, 0.25368593574967235, 0.09926839673426002, 0.16681820328813046, 0.09219441577442922, 0.12481216981541365, 0.07375828747171909, 0.11118403781438246, 0.10926119255600497, 0.1008482881297823, 0.13293487223563716, 0.11692153697367758, 0.16057346103480086, 0.0931595491420012, 0.18296098394785076, 0.10225463571259752, 0.10193419861025177, 0.2530947112245485, 0.08589926685090177, 0.07715906787780114, 0.19053884607274085, 0.13949902000604197, 0.10389464106992818, 0.16748364258091897, 0.19540553883416578, 0.13448585697915405, 0.18487446330254897, 0.14666657836642116, 0.17849843512522057, 0.1440460846060887, 0.11696036614011973, 0.2022263064282015, 0.13876696553779766, 0.13141519128112122, 0.10447300417581573, 0.1461137822479941, 0.084104404959362, 0.22012814035406336, 0.12395523415762, 0.20218618592480198, 0.1453606953145936, 0.1032644537917804, 0.11244160705246031, 0.18223973514977843, 0.22161635424708948, 0.15460507973330095, 0.18953722872538492, 0.0938624817354139, 0.12533404806163162, 0.21601359941996634, 0.17501265654573217, 0.11507600123877637, 0.1128945397795178, 0.13302951090736315, 0.15639588207704946, 0.14197866898030043, 0.3111826692475006, 0.09444522351259366, 0.1562852575443685, 0.16414010402513668, 0.1797057015937753, 0.1416882814373821, 0.14449039357714355], [0.023200156065286137, 0.012697733927780064, 0.0917290520737879, 0.009696072193037253, 0.03950262092985213, 0.04894495097687468, 0.040758512914180756, 0.10740684752818197, 0.028540496750792954, 0.028402477691997774, 0.020974464459868614, 0.01395717616105685, 0.01568380685057491, 0.008653838031023042, 0.03464752793661319, 0.028065644692105707, 0.01758853813953465, 0.036840244065388106, 0.021905805988353677, 0.03713401951245032, 0.02951742098957766, 0.04637457815988455, 0.02448631468723761, 0.0604666712024482, 0.05556630349019542, 0.030534189281752333, 0.01943265822774265, 0.04932641859340947, 0.03424299065954983, 0.03408596705412492, 0.09524246823275462, 0.05646483652526513, 0.06059559338609688, 0.048205185594270006, 0.01615093686268665, 0.036393823684193194, 0.035292691754875705, 0.02664350606210064, 0.04280551576812286, 0.018216589887742884, 0.03391544749320019, 0.026504689194553066, 0.09572196984663606, 0.07184132002294064, 0.027184932478121482, 0.08615001628641039, 0.022227334047784097, 0.05464158377435524, 0.03156461309117731, 0.019056968230870552, 0.05913759603572544, 0.05881076162040699, 0.08647411217680201, 0.03073531130212359, 0.054702354536857456, 0.09939545241650194, 0.015277103429980343, 0.022132498706923798, 0.02469981016474776, 0.03260860336013138, 0.007298771461137221, 0.1988746042479761, 0.02944213010778185, 0.0819809571839869, 0.06442992904339917, 0.03148466152197216, 0.07989786739926785, 0.05528481429792009, 0.02907801761466544, 0.04928128117171582, 0.02445736165100243, 0.047930720829754137, 0.04825100950256456, 0.025473452733422164, 0.05240779719315469, 0.061140077450545505, 0.04784198594279587, 0.06367782174493186, 0.04401718317240011, 0.043974157160846516, 0.00854494734085165, 0.025920355510606896, 0.04288577532861382, 0.014926806943549309, 0.021311625860107597, 0.08646321002743207, 0.01129646077970392, 0.045468861135304905, 0.04901015978248324, 0.045249422910274006, 0.020361502429295797, 0.031086430644791108, 0.05475122125062626, 0.06047376984497532, 0.031431434690603055, 0.013340582245291444, 0.047238868501153775, 0.07619940413860604, 0.05377321533160284, 0.04773883854795713, 0.031192244205158204, 0.050274159730179235, 0.0232442730339244, 0.014468989957094891, 0.006061750436856528, 0.016233005408139434, 0.01123497384469374, 0.07065545709338039, 0.042817215726245195, 0.03257042357290629, 0.025263115094276145, 0.027751181878556963, 0.06852478079963475, 0.017691080684016924, 0.014959187774366, 0.013480404722940875, 0.05260681893560104, 0.0650620087981224, 0.06731119123287499, 0.04913122262223624, 0.05147137380845379, 0.020556956296786666, 0.0359479079634184, 0.052494153496809304, 0.03008874296938302, 0.030705441713507753, 0.12919909378979355, 0.06409184366930276, 0.03044340050109895, 0.08141775615513325, 0.011121470706711989, 0.04091553280886728, 0.06093079180573113, 0.034478303423384205, 0.03436583465372678, 0.08188672669348307, 0.08961627638200298, 0.11400726405554451, 0.037583345401799306, 0.04315703401516657, 0.05837267555762082, 0.06559031404322013, 0.05952299332420807, 0.04562822992738802, 0.06836621352704242, 0.01075187188689597, 0.0233880418818444, 0.09269837857573293, 0.04429184831678867, 0.0451454925496364, 0.062429930112557486, 0.07371499799774028, 0.020577370924002025, 0.11132798477774486, 0.030112825661490206, 0.05884116741071921, 0.06508167571155354, 0.0487515361601254, 0.029437669800245203, 0.02217338918853784, 0.03126648494799156, 0.023929711351229344, 0.0785077728505712, 0.023684852712904103, 0.04279098451661412, 0.0952235286240466, 0.024541441416658927, 0.037709759126300924, 0.03139364082016982, 0.07510337076382712, 0.0057114349328912795, 0.0330207179649733, 0.04747369515825994, 0.02758125603577355, 0.021463070370373316, 0.05554427654715255, 0.020222140083205886, 0.03886851140123326, 0.03442876506596804, 0.031172050366876647, 0.04376678625703789, 0.03450367003097199, 0.07881435405579396, 0.0030145869322950603, 0.07865454739658162, 0.033602691619307734, 0.07311158740776591, 0.016934620689426083, 0.03930249709810596, 0.026815413439180702, 0.02779343049041927, 0.01888031853013672, 0.06900788182974793, 0.017619461577851325, 0.06361437554005533, 0.06975235242862254, 0.03402119611564558, 0.0195803994211019, 0.019395265117054805, 0.06354554876452312, 0.025985905704146717, 0.0655196986917872, 0.030748191275051795, 0.0666205857123714, 0.01012579517919221, 0.024718534550629556, 0.03230057867767755, 0.04351058945758268, 0.034867619251599535, 0.09451510413782671, 0.08625842921901494, 0.05380196242185775, 0.015605630869686138, 0.07327491184696555, 0.06918561135535128, 0.07596486320835538, 0.027699522834154777, 0.038956129355938174, 0.047346294377348386, 0.0310445364084444, 0.051769954661722295, 0.03336921196023468, 0.04502355768636335, 0.05403558308898937, 0.016717295729904436, 0.043500997198862024, 0.049066841311287135, 0.028957823087694123, 0.07056669623125345, 0.03521809478115756, 0.03550002926203888, 0.042350894655101, 0.024362199765164405, 0.05637544112687465, 0.03567514642782044, 0.0321765398257412, 0.020039729461132083, 0.0697723681514617, 0.08161156802088954, 0.05766268142906483, 0.04954586423991714, 0.04257887871062849, 0.011819041283160914, 0.026581700003589503, 0.07782147920806892, 0.05541953636566177, 0.08890853467164561, 0.003604357311814965, 0.03913611129974015, 0.02701490459003253, 0.03853262649499811, 0.03146771457977593, 0.023705669955234043, 0.05716416970244609, 0.04592958641296718, 0.062383063486777246, 0.05127991084009409, 0.06832579616457224, 0.027693036463460885, 0.03596288450353313, 0.033433975477237254, 0.09090995852602646, 0.016518938209628686, 0.043140729030710645, 0.07351245847530663, 0.025183059624396265, 0.018035042012343183, 0.046350187476491556, 0.033220492987311445, 0.03519211219099816, 0.03803751009400003, 0.06472983834100887, 0.04920505147310905, 0.023708562475803774, 0.0701756808848586, 0.030012804563739337, 0.042121029255213216, 0.03206109133316204, 0.010522939737711567, 0.010894537717831554, 0.0357398245978402, 0.03812438590102829, 0.0718502925883513, 0.06337046128464863, 0.026575940937618725, 0.04892142489552498, 0.08938883038354106, 0.05510457260243129, 0.03714663602295332, 0.03198711776349228, 0.03772366697376128, 0.03275458380812779, 0.028037367010256276, 0.029895127772761043, 0.03469324794423301, 0.037853817411814816, 0.08332612953381613, 0.03159246960422024, 0.047336286515928805, 0.05508037858817261, 0.024548885157855693, 0.04798807771294378, 0.06643100408837199, 0.06948483787709847, 0.019566241098800674, 0.02586171842267504, 0.0134238298778655, 0.027858008470502682, 0.023364163280348293, 0.04616283600626048, 0.04598869847541209, 0.08768793180934153, 0.05800739047117531, 0.033695519450702704, 0.031346410542028025, 0.050587138248374686, 0.03956291300710291, 0.028444258750823792, 0.1015500481298659, 0.08143694067257456, 0.06306699709966779, 0.038111123722046614, 0.0452601135475561, 0.0502977377618663, 0.018256767907587346, 0.03971848571381997, 0.02181804331485182, 0.06491718610050157, 0.10645962218404748, 0.04385433370771352, 0.03165922578773461, 0.058594885704224, 0.01258358512131963, 0.05348040838725865, 0.034230129240313545, 0.0451770523795858, 0.03244626597734168, 0.025188996805809438, 0.027776212664321065, 0.015604693908244371, 0.01767129317158833, 0.04306883718527388, 0.033073328813770786, 0.007348754179474781, 0.03199323677108623, 0.054338594563887455, 0.052886890625813976, 0.02427494546282105, 0.031854729750193655, 0.08211688153096475, 0.04835164472751785, 0.05741812150517944, 0.1379137925687246, 0.10741873673396185, 0.185872518341057, 0.13834955199854448, 0.11960585543420166, 0.09767793715582229, 0.15570587769616395, 0.15975502057699487, 0.18721644388278946, 0.07891716377343982, 0.13581710663856938, 0.05802671970741358, 0.1662262514582835, 0.11181524925632402, 0.0901285363943316, 0.13357537536649033, 0.12909200188005343, 0.09617451665690169, 0.1712024852167815, 0.12411851406795904, 0.10121503524715081, 0.13618773518828675, 0.13818157429341227, 0.09845144799328409, 0.18442041735397652, 0.12110733892768621, 0.09503552777459845, 0.18072275561280549, 0.1226921433408279, 0.13681725453352556, 0.17285637615714222, 0.1200454295030795, 0.10815189700224437, 0.1558091549668461, 0.18755116732791066, 0.15998251852579415, 0.11942003649892285, 0.1543816487537697, 0.1938964705914259, 0.13836427620844916, 0.15022948093246669, 0.14128796698059887, 0.1783694647019729, 0.10963501234073192, 0.15176413842709735, 0.15138059650780633, 0.12380310130538419, 0.20450279989745468, 0.06883269787067547, 0.11079643634730019, 0.10900597539148293, 0.11007438602973707, 0.15826121089048684, 0.17928717483300716, 0.12719486461719498, 0.18653582024853677, 0.11615759984124452, 0.07702851668000221, 0.12042451111483388, 0.16351957950973883, 0.07478115992853418, 0.2530631551053375, 0.12830409337766469, 0.2164799947058782, 0.13486522802850232, 0.08447958287433721, 0.11282684106845409, 0.1146854757098481, 0.15691545966546983, 0.1963905172306113, 0.310800670995377, 0.12098854334908538, 0.12949402327649295, 0.1175403619708959, 0.1761882333084941, 0.14458712510531768, 0.0993757409742102, 0.13716026034671813, 0.24782951484667137, 0.17036497156368569, 0.14664210233604535, 0.1385982011561282, 0.1913667711778544, 0.0994637596886605, 0.059393915289547294, 0.1702417602064088, 0.12280232258490287, 0.16252885689027607, 0.13964885962195694, 0.14422118692891672, 0.09024554339703172, 0.15974005887983367, 0.22276554023846984, 0.1154840637173038, 0.049779084147303365, 0.12735729105770588, 0.11229644296690822, 0.19733806169824675, 0.12820059346267954, 0.12144415522925556, 0.2558402420254424, 0.13960848678834736, 0.12188905049697496, 0.11448495482909493, 0.10354892641771585, 0.11541675092303194, 0.24434116843622178, 0.167398473713547, 0.18461986212059855, 0.19109346787445247, 0.15130302723264322, 0.1301553362281993, 0.2388094668276608, 0.12780013057636097, 0.12131658746511675, 0.11322548569296487, 0.20374846615595743, 0.1537962575093843, 0.18528899730881676, 0.18394104932667688, 0.21582778048468754, 0.11137321867863648, 0.1087484130403027, 0.1912817804259248, 0.11384292287402786, 0.10149938170798123, 0.16618902533082291, 0.21404108963906765, 0.18014269298873842, 0.25585282885003835, 0.10916492115939036, 0.14920871617505327, 0.1398143733968027, 0.16108028852613643, 0.13019184989389032, 0.1723451106227003, 0.16654562728945166, 0.19168233236996457, 0.09558305464452133, 0.15370151493698359, 0.12781945610186085, 0.1791587535990402, 0.15003202512161806, 0.1358983272803016, 0.21271061181323603, 0.12748315930366516, 0.11871826907736249, 0.19292523676995188, 0.22048493527108803, 0.10982956635416485, 0.147625106619671, 0.18541283207014203, 0.16858868562849239, 0.13648294669110328, 0.09588697153958492, 0.17009656643494964, 0.14071749290451407, 0.13821562402881682, 0.16565663827350363, 0.1134546534740366, 0.07988652738276869, 0.17152267741039395, 0.20108289434574544, 0.10880158049985766, 0.12048405362293124, 0.21144668979104608, 0.09336284565506503, 0.15510375844314694, 0.30620707373600453, 0.18714631092734635, 0.18310874555027112, 0.18041556584648788, 0.1627351442584768, 0.1609551624278538, 0.1632588481879793, 0.11611430294578895], [0.019345518958289176, 0.047134771157288924, 0.021551719910348766, 0.017858178944152314, 0.09135880944086239, 0.023520305585407186, 0.05084875272586942, 0.02305613859789446, 0.01673711849434767, 0.014390269425348379, 0.021180009680392686, 0.037195016629993916, 0.022140645633044187, 0.08719695659237914, 0.053798637600266375, 0.02456317892210791, 0.06422556383768097, 0.03315834554086905, 0.01863882553152507, 0.02188725229643751, 0.015905903819657397, 0.02929138507170137, 0.011226723945583217, 0.0066372641595080495, 0.04528015153482556, 0.0065115025972772855, 0.029916551720816642, 0.051028827438130975, 0.05378084460971877, 0.02215803600847721, 0.033353782710037194, 0.019831148856610525, 0.05453826939628925, 0.07678069130633958, 0.06229384249309078, 0.03042517706489889, 0.0565432332950877, 0.012855621207563672, 0.021181707343203016, 0.03334443907078821, 0.008709935118531575, 0.019504331139614806, 0.0440250870451564, 0.02483203305018833, 0.04615987854776904, 0.012349978369456949, 0.0887377219623886, 0.10380921245086938, 0.03243685183406342, 0.01702233883406734, 0.03912435568054207, 0.05087698402348906, 0.060200203079148196, 0.02085745189106092, 0.05518921825569123, 0.03523722734826151, 0.020694346385425888, 0.00901092145795701, 0.03093899187661009, 0.027535623230505735, 0.00910964565264294, 0.015482991893804865, 0.04584387948852964, 0.03729414158442523, 0.024284691717184614, 0.008101963103399612, 0.03635162516729906, 0.05009464162867516, 0.06222418451216072, 0.01083480225133826, 0.036571620003087446, 0.06748461630195379, 0.04842037131311372, 0.04693645445513539, 0.019340696853760164, 0.03556078518158756, 0.014409942832571687, 0.04006375507742632, 0.01680000808846671, 0.019858595333062112, 0.019844142007059418, 0.039104800089262426, 0.027907700823561754, 0.011422113802836975, 0.015610196933266707, 0.03676471940707415, 0.01961684258276364, 0.008768841234996216, 0.02053183088719379, 0.01931982951646205, 0.015775111423863564, 0.04030305317428429, 0.032334094066754915, 0.07717654545558617, 0.05287084910378326, 0.031258588496712036, 0.036047407702426426, 0.026205711292277556, 0.0021705815743189305, 0.05799034704978112, 0.010663232551451074, 0.07469983538612723, 0.0290618258077302, 0.07634568144567311, 0.060937359812669456, 0.03893748660630081, 0.04091613394848537, 0.013915060208091745, 0.052700214509968646, 0.03181386709911749, 0.03318906674394384, 0.029168763721827418, 0.04008887306554243, 0.04297357882023789, 0.054993480516714044, 0.047708536658319645, 0.011487653791846242, 0.04587710172927473, 0.030403895980271045, 0.06462205623392947, 0.01751132138451794, 0.024529708061891142, 0.02070977192488499, 0.05754144047386944, 0.04234508734953124, 0.02970899899082724, 0.0250321123530739, 0.019087429682258517, 0.025944074550352525, 0.025962539184547495, 0.08400966980843805, 0.04289105570933316, 0.06945606481167488, 0.03942591625673231, 0.04595658945618197, 0.05372403691580985, 0.039086758479243144, 0.043120394184370525, 0.03381464157428127, 0.05383280979003757, 0.045172016907599755, 0.0049535453763382975, 0.049143386422656476, 0.0037947592409182107, 0.01499779058576678, 0.006434912493205047, 0.013004529428144451, 0.032298047954100184, 0.05819861966301687, 0.040886318165576085, 0.04071380964887794, 0.03392440150491893, 0.002432577794024837, 0.03610125422710553, 0.029473938557202928, 0.07578871445730329, 0.03818364268227015, 0.0017765765323929372, 0.027623415589914657, 0.027571634091145825, 0.05863523627340328, 0.04041704334667884, 0.028561909566633403, 0.05813557050714735, 0.05835669711814262, 0.0458155813976191, 0.01812588088796474, 0.05187944741919637, 0.035793103379546665, 0.01988413634535391, 0.04582410867442377, 0.027925224785576575, 0.02372001010371605, 0.020592412402038462, 0.024105908341880422, 0.008578128763474524, 0.056924782547866926, 0.03300103991932701, 0.035903327152482234, 0.04978574863343965, 0.057662006074679084, 0.01051391614964814, 0.07713594255619682, 0.02315296103915898, 0.045540344799519517, 0.018183495667472016, 0.05275504066958092, 0.07162535504903644, 0.01626260782359168, 0.037785970271215774, 0.022413477672671434, 0.04076991601323243, 0.11161686576087959, 0.06422352293157019, 0.03101055717706913, 0.035477980054565705, 0.02837079911842011, 0.048676323203835636, 0.07404835589113645, 0.023217731977638323, 0.03932731080567464, 0.015527107007073937, 0.03317848371807486, 0.016766169865150005, 0.0378823715436738, 0.03423464149818756, 0.009737550826685037, 0.034799074492184445, 0.04028910079796333, 0.03665188327431679, 0.020947971643181518, 0.04601156775606796, 0.03670746271382086, 0.01341797618806595, 0.01132800762206898, 0.03175347112119198, 0.03042035681573907, 0.032007126064854674, 0.07102002971805632, 0.05497338315763045, 0.03531266294885427, 0.0178729662366095, 0.051531625067582354, 0.16682276007486507, 0.04781404779350851, 0.03651499042462092, 0.02608798811706947, 0.038768525555497035, 0.02103217015246628, 0.03753719494852703, 0.03848488413495943, 0.03387898577784654, 0.017223420036316384, 0.03257647949794773, 0.01617486555915093, 0.06121875994722359, 0.025577891465218272, 0.004970218187736464, 0.07678822410525754, 0.019171177336829714, 0.0454456244915491, 0.03978471868322231, 0.01646563716349192, 0.037760403283755295, 0.03568382213416044, 0.03220454847905785, 0.07383852105704136, 0.028939037474629004, 0.027919120620936155, 0.011228795465285657, 0.043491475444170646, 0.0858226623677183, 0.04870117030804977, 0.05372139858081937, 0.06763731318642385, 0.018247049483761657, 0.06076030564145185, 0.089272298355354, 0.039531995134893805, 0.043315252478350885, 0.015566825823043473, 0.07383938194834627, 0.009471790526731638, 0.06093849900935311, 0.030093709792708978, 0.022702553469571285, 0.06578681990504265, 0.01147098237197497, 0.03979477478424087, 0.031082662389962934, 0.02409418797469698, 0.06727711923304014, 0.024675794265931472, 0.007234977838379564, 0.036727667684317566, 0.04153724104980938, 0.02914177366619697, 0.033793338225223124, 0.04290756107366178, 0.07764783149468713, 0.08556898144888692, 0.0310402876129956, 0.042863830021815374, 0.043906528953812085, 0.05782488522527274, 0.009495533686276758, 0.054446766298497096, 0.10181733261561021, 0.039657781744608656, 0.06751289212843403, 0.02913386793807149, 0.08596174084232189, 0.04481693264096975, 0.028889454588352237, 0.029260719529702328, 0.07826510540326126, 0.043152848302270286, 0.014486457330349367, 0.06643904896918684, 0.056389141172985546, 0.015454399726877455, 0.07918881950899959, 0.09261469400371425, 0.013613920800708001, 0.01778736877895426, 0.024538940378988627, 0.022614566296397243, 0.037607969861710444, 0.04099917656276375, 0.0480894142674515, 0.0441049606888555, 0.018219482408312615, 0.033149744049296714, 0.03524679734255187, 0.017833693636930548, 0.02192372143326793, 0.04615950376319233, 0.014238215426303213, 0.025636205718910787, 0.009226312195096398, 0.059917600665357895, 0.04073174364748411, 0.001639809499920375, 0.07400428716209717, 0.031176124757621437, 0.04723359925264958, 0.0540145283594029, 0.05389553611166775, 0.024868695145414677, 0.14789702952839434, 0.029352467536227778, 0.015982365439413115, 0.011712832529156003, 0.07926062229671516, 0.0142745370612829, 0.022064731347199995, 0.04219859853037633, 0.05178417050046846, 0.06361744060995989, 0.11548943686648272, 0.0414856692077592, 0.02936139742814703, 0.020113782811677083, 0.01935714841238223, 0.019076366115768906, 0.026733779050118756, 0.041425058007007465, 0.01971700468857307, 0.022441846267611254, 0.017970011322177015, 0.027600735556916334, 0.02140111588232685, 0.1306016935268417, 0.13791251607472077, 0.07426268814015202, 0.14312846353277564, 0.16516514355316758, 0.07784502755384892, 0.150473217072431, 0.06739145450410433, 0.12200075856526382, 0.09204853922710754, 0.19925373781006783, 0.1888657928793691, 0.09963936667190865, 0.13900783698773012, 0.09493635458056815, 0.16335801396053284, 0.19654838688438758, 0.1851806734339334, 0.11861016784678213, 0.15309053444070742, 0.11684790850267746, 0.07313111331313848, 0.13039859739365056, 0.07513645570725203, 0.15389365697046742, 0.08637194070615806, 0.186264609801583, 0.07949974969960749, 0.1382874936098233, 0.2114438993157819, 0.11271681025391445, 0.15662318706745282, 0.1372754416661337, 0.23795331042492762, 0.17615486634895205, 0.07722005757386796, 0.12951245822478086, 0.11754716004361399, 0.18387194053502753, 0.13937629846623167, 0.09459180510020815, 0.21735063783125952, 0.21482122043380514, 0.15758754860144109, 0.13597175537142903, 0.13243071647593752, 0.12161751350504346, 0.2980279235634953, 0.144986801315099, 0.12464073370210826, 0.09218450810294598, 0.19087885360931978, 0.1730510563356802, 0.0776957742345985, 0.13110861007589847, 0.07552334471256472, 0.11133363252156414, 0.2087119349744171, 0.14568407874321565, 0.11417760921176523, 0.17578955157659948, 0.1121098521980457, 0.13412401545792818, 0.0964381943049375, 0.12506559840403497, 0.13952141802292317, 0.1511371275410056, 0.15699123294325545, 0.11228392293560319, 0.1392179835238494, 0.14328052959172055, 0.15591198694892228, 0.13579604448750615, 0.08116639815852977, 0.16628111101454124, 0.15511152130784467, 0.09668991595390253, 0.12584605574375018, 0.1171251451887656, 0.05442816807772033, 0.10175149669521488, 0.1494447933509946, 0.19039662089198828, 0.10399855658761226, 0.11108631922979839, 0.16128350340295583, 0.19889548828359693, 0.11848942041979171, 0.19194208405679092, 0.11587986591621302, 0.08936163809266873, 0.11848692680359818, 0.13003813626710325, 0.14049214718397707, 0.1388443715404719, 0.20035653957165778, 0.10506990613066591, 0.11513463090523146, 0.17985297337872908, 0.12153635965660214, 0.13314397976500914, 0.11365653248503804, 0.10819008792168461, 0.12373915786156431, 0.1267729833489284, 0.13893578929128125, 0.06351408912451006, 0.12496315233875066, 0.10130100563401356, 0.07538434787420556, 0.152818359201774, 0.19504439493175596, 0.08307140960823745, 0.09445330550079234, 0.07703932235017419, 0.2565100451465696, 0.14440854953136295, 0.09452795071410947, 0.07517131438362412, 0.176514258782845, 0.13827949325786904, 0.12000639253528789, 0.13041431608144194, 0.16814479226013646, 0.10987906760419719, 0.12000232556601986, 0.1791800680803135, 0.12333553342614323, 0.06520587412524037, 0.07719791930867359, 0.17662154365098104, 0.15038169542094693, 0.13665985985426232, 0.10965047869831324, 0.1298762738588266, 0.15786696720169857, 0.14281524752732366, 0.11177907697856426, 0.1975510283955373, 0.121197376283817, 0.14969670795835555, 0.09121855837292969, 0.0952505947498139, 0.051468004458001815, 0.11879206824232824, 0.13073633395833895, 0.07879711396526545, 0.13053387607214972, 0.13446268712868914, 0.10765401981188916, 0.14708921662531793, 0.13222741254139692, 0.1747561851516366, 0.1940588525030762, 0.0996484950883314, 0.17575793608557433, 0.10395065837656148, 0.2672550966963172, 0.19914139149477705, 0.06553748797159642, 0.13331822119653225, 0.1454976067179814, 0.21422051126137376, 0.14794170681852847, 0.1659379864577204, 0.18864065496018156, 0.13794347847579047, 0.09836696190177463, 0.15194338193396106, 0.149416591739282, 0.19135250709950924, 0.12013470244710334, 0.1280580268939957, 0.2025648148264736, 0.08838912777719088, 0.07919616677099839], [0.035700746811926365, 0.007435433317368734, 0.03773572687350679, 0.09886806743452325, 0.03257604163081851, 0.07495485959225334, 0.08789523591985926, 0.03339227791002486, 0.013186612577555934, 0.06670726113952696, 0.03254373965319246, 0.039080572678358294, 0.012222094264870975, 0.07177051913458854, 0.020606945508916397, 0.06211777166754473, 0.040637602214701474, 0.0457498493778985, 0.030751842641620897, 0.025551144462951925, 0.03277490752225276, 0.044715087715303525, 0.013101581007504137, 0.09268427034839988, 0.03089845948125003, 0.05634641202050261, 0.048413113108836114, 0.0007389310462713183, 0.03595706606574822, 0.06816153661930002, 0.05301027267705649, 0.012556338097056141, 0.01143454199336702, 0.048353681922890246, 0.03348792961332947, 0.036069727793801576, 0.0724128182628192, 0.020223754254402593, 0.040081971092149615, 0.03768723123357631, 0.02616715672047576, 0.037222524333628826, 0.03705466166138649, 0.042344634639448486, 0.0844144074653741, 0.06862667767563835, 0.10225414589513093, 0.0560178224259289, 0.02107035179506056, 0.03460653912043199, 0.04571007397316862, 0.011767303385568084, 0.05838457960635424, 0.0341034557641251, 0.026864977771765552, 0.049730117243598215, 0.03689971235871781, 0.09478090432821773, 0.05943510819633957, 0.07222898086183704, 0.02857322175259469, 0.06965215507079847, 0.016224086648435332, 0.051075653245789, 0.05338114242476877, 0.05059435934526846, 0.05853545451827813, 0.058635644454625435, 0.024009950502659194, 0.03278845171735156, 0.012005704411421902, 0.06079960607166868, 0.020842920639552176, 0.09693128464277834, 0.02757261558144819, 0.02187900146964239, 0.0625829683849588, 0.03667642238724511, 0.02786273595120292, 0.09085804529604502, 0.03655545602669008, 0.026076644389831927, 0.014656222683697706, 0.034790662248269655, 0.002831606248037133, 0.038014533201931044, 0.013753063285548706, 0.05581654084380716, 0.0732646553660743, 0.003986226847700891, 0.04706873856775928, 0.09198814324918203, 0.041515336561133154, 0.02693540016480256, 0.00930677028009086, 0.004580746508509037, 0.0806532401475124, 0.07264306957949884, 0.03177113052515779, 0.04630506118701305, 0.019884518551407382, 0.04145719671214465, 0.018952473837998696, 0.0644833043043036, 0.03200463244866114, 0.03058108744880883, 0.040979168261401355, 0.025381363338965457, 0.04856571351410821, 0.022964785785006825, 0.04273113401723094, 0.05871547728020232, 0.05540440026379656, 0.03495564167678822, 0.04493484506383538, 0.06613275720155798, 0.043454635233501904, 0.0073494453044986585, 0.059017739185946994, 0.04705884573922958, 0.002816364390128001, 0.07201749103842303, 0.0380266932916129, 0.06134172639576718, 0.026300201534468215, 0.039832535258028656, 0.046271453029476106, 0.046003422685316764, 0.019958174852945376, 0.03656787586805876, 0.07060088697471656, 0.011924455939151812, 0.01380277511998429, 0.01453486576792784, 0.029310337667993736, 0.06838003231678158, 0.013727668847423047, 0.042667929010349326, 0.04881011016550474, 0.0709986336005386, 0.02355293410801096, 0.045460437759174965, 0.03367974881257396, 0.04827514414500911, 0.03340560317155905, 0.023416688782162964, 0.041353162450832315, 0.06285643496084958, 0.013383945006353315, 0.02321309355465928, 0.0680719742376823, 0.06279984620050527, 0.030498675660055596, 0.026280122729076538, 0.02930061182269128, 0.08257911336841062, 0.03781137027544901, 0.062144125331542455, 0.041879853524733335, 0.050500347788329236, 0.0380062879412435, 0.1365751659614034, 0.039087871700758114, 0.06876812360133044, 0.05393865118094254, 0.03161740576615557, 0.043786171154351905, 0.004475790592550766, 0.03935402441129554, 0.04267682365025394, 0.0639539748954121, 0.09195398961310275, 0.04919361868815031, 0.04307127514039166, 0.01916286342748208, 0.02817423202941427, 0.01204060483360081, 0.01465786839617067, 0.0028376262253004825, 0.08104009204544127, 0.04391096328618005, 0.005796743416794925, 0.03937132016289979, 0.023515424109064043, 0.028925454316777177, 0.04394278657855466, 0.05230095761362463, 0.02295949983817991, 0.030152819999784697, 0.013955895956314635, 0.03770804476516787, 0.012831341846322175, 0.046569121041102335, 0.014720873950864188, 0.043170737772015855, 0.04048685346788261, 0.012091754579159897, 0.02170297517295694, 0.02329904724319931, 0.09163013120996766, 0.095465164486086, 0.016363404465664644, 0.07895017450209707, 0.03069068225158844, 0.018274633257533424, 0.04304497713746969, 0.019868534545821603, 0.028246628535271157, 0.01772898958734004, 0.06328230898361653, 0.06802636926295236, 0.05632055188470986, 0.05649875267408788, 0.03684597344545182, 0.039539902718388475, 0.03591229971789289, 0.0837092410074547, 0.024903167904994916, 0.05193382457946427, 0.09665280857007019, 0.07048978746752255, 0.03712080928380601, 0.016365918490919285, 0.044666350877378136, 0.017644147264945786, 0.05722793132008519, 0.04465619087568484, 0.052587166865123436, 0.04597980383550748, 0.024524939763068687, 0.011565579297894146, 0.044908569325343706, 0.05225138214882463, 0.1257460142369382, 0.030781272507738322, 0.05243684856395703, 0.022711535311827902, 0.026347467064624652, 0.11886027903528884, 0.03659158377558924, 0.030288530979305506, 0.07636090289452113, 0.03891849504725542, 0.03660592206870206, 0.03182183034368791, 0.03757389044039883, 0.020593701883626636, 0.13901036028983071, 0.012113535685784882, 0.0818126677768305, 0.019728890183614567, 0.08382888263440691, 0.055951329704839736, 0.019856717699440196, 0.04025501024443656, 0.011914026908925734, 0.01926537628605729, 0.0797248059825506, 0.0548172761045862, 0.07188429037341848, 0.024834222385834437, 0.06859826826257631, 0.016152588141267188, 0.02645598018716555, 0.02264153037685901, 0.04001104403869249, 0.05391221588070039, 0.018307911159354262, 0.06445852399338037, 0.008237502461270196, 0.03978059976361692, 0.05804804532090202, 0.06984656807617284, 0.09809270122786984, 0.12095974059775472, 0.06951562216272578, 0.024512070922355633, 0.04023579975182656, 0.012655465834541246, 0.05073774969787337, 0.004832263603020692, 0.031103594665182754, 0.02260726541862823, 0.00406595948334143, 0.06438547439756803, 0.05795852004666813, 0.06317987033980899, 0.05448444513604045, 0.01633567411772674, 0.026223771455988754, 0.09878166660200804, 0.024007694373722188, 0.013082207242405275, 0.04131497895286884, 0.06703485996695235, 0.05672143779520411, 0.02692725323868217, 0.09639912765123881, 0.026371970925538335, 0.032246613409370184, 0.028180254557810258, 0.028029631976096425, 0.0321560899465112, 0.07560645783087239, 0.08852307801134884, 0.033093199817813, 0.05185179499676451, 0.029872553495806642, 0.008549558860977413, 0.017030296512530185, 0.008827302990539465, 0.044843386494903825, 0.04252727347193286, 0.053102621823200025, 0.013539567808038555, 0.07459163025487214, 0.030247076465457212, 0.05673159408615902, 0.0263081499360851, 0.05360049530281685, 0.051857917715096846, 0.016478257384733297, 0.0058123549570154864, 0.031131443756748922, 0.03236529024434276, 0.008763530240685213, 0.032188904006034136, 0.04913344906526618, 0.0015037412458696053, 0.031357565021608025, 0.02907456106186146, 0.05962974013527855, 0.030646071754745208, 0.025535034292261116, 0.030294312309706584, 0.020865335354756098, 0.04855835883063264, 0.0235269867698662, 0.08095208075246774, 0.07636238718987443, 0.13336233445443213, 0.019545943359844387, 0.01351981833067839, 0.06849025608971715, 0.03956390748498961, 0.07552338181994855, 0.01531993370008422, 0.059394375421106815, 0.07524079424911179, 0.02936967051937245, 0.08557791690691374, 0.04889596180873923, 0.22415234707295895, 0.12070692799170502, 0.14559573348378763, 0.20275254850275815, 0.1361908670514822, 0.15697590017225593, 0.21130796754732728, 0.14144300163025036, 0.10387616901425645, 0.1358226579031907, 0.12209366803290322, 0.11948597631999291, 0.10189064938458614, 0.14131469913991168, 0.09472333593294024, 0.18178500642534345, 0.15362838370492682, 0.17120367265306413, 0.12048716322169639, 0.14902960625477135, 0.0818296184297651, 0.1055746927158907, 0.11901055651833303, 0.166198747465387, 0.1368317412561737, 0.09404162134160288, 0.21797453169710934, 0.14084913505939767, 0.12557027366710827, 0.13971105159725994, 0.11490475066239014, 0.09894436021568254, 0.07169484233600087, 0.1728608290432021, 0.14795135473832488, 0.189698378671892, 0.2071250748122111, 0.15635307499906048, 0.15738737653009593, 0.18626354110892862, 0.12089495852706023, 0.1371568167814985, 0.1383509620791301, 0.13283065985888243, 0.23935148696182296, 0.13688268227269873, 0.14690096344565973, 0.1397693101898767, 0.11341445875586942, 0.07147957498091273, 0.09908739433740266, 0.11759970409912057, 0.11362819728674367, 0.11974071108852513, 0.13972696324344724, 0.13094447669573128, 0.15095582086360082, 0.21581752400379628, 0.14267098886193708, 0.23030577547615394, 0.19704197446117178, 0.15288457361748442, 0.21326987945940346, 0.08976680619525723, 0.12061664572684094, 0.1607391974539496, 0.09707009594421834, 0.1579492268501781, 0.16231777524808422, 0.13286491739563644, 0.07700336529524066, 0.19381943566258997, 0.131896874809172, 0.2374754860647954, 0.08755610411753878, 0.1787671074271202, 0.15556595317320898, 0.09345151745947078, 0.09297160024289042, 0.17356095631839707, 0.06511027066153474, 0.21322446002159268, 0.12214385948027484, 0.10929800308076665, 0.07370925377472304, 0.17314478958724067, 0.14299226459115744, 0.09211266820784658, 0.13606401917058975, 0.29844245756976306, 0.1610662174061872, 0.17500232585007325, 0.1732451724819839, 0.11045625811675563, 0.16433836135547608, 0.11669612445984967, 0.16119532141601667, 0.2601526246871799, 0.17078490840503946, 0.19473782856948674, 0.10350474636652507, 0.2464596289792098, 0.07973649480845779, 0.10981854546116665, 0.11101211930508725, 0.102637146046618, 0.1587139061302878, 0.10568317986326292, 0.16783038881840184, 0.18392034340649843, 0.15875041979597881, 0.300854051602073, 0.14536198665155098, 0.1308442125446163, 0.2099696229561232, 0.14133334188954905, 0.1583456524531357, 0.11213875142857432, 0.1335814906633459, 0.17576871206983924, 0.07299999066162854, 0.11220959684578702, 0.1205040248169098, 0.1768297457601875, 0.20814457791857421, 0.12802384357200935, 0.18136515864171088, 0.1652124332031235, 0.08972770985565148, 0.14091414719587192, 0.23361774306977168, 0.11258768397965468, 0.10405337161500938, 0.178705939615611, 0.14482891681836918, 0.16934567625867203, 0.12384703644784167, 0.14131967152934521, 0.1478338727611117, 0.12902927555842325, 0.08783518132986501, 0.105946753610624, 0.13879804668249562, 0.16086681716842577, 0.11830563496914692, 0.09424727046280168, 0.1980522007215768, 0.10484911719686352, 0.0681018308387138, 0.09095678804442286, 0.12617507949471474, 0.19426570390351117, 0.21575243765255436, 0.12058808788424358, 0.14107789465924725, 0.16617992660030723, 0.11616617164690979, 0.2635253593325615, 0.10377695129136555, 0.09493036544881761, 0.1077739211905282, 0.17795841878978536, 0.13129143073456362, 0.15913848881609738, 0.2680724981473759, 0.1244360048440285, 0.10929985844995826, 0.21093131275847554, 0.15715008223196492, 0.10946738344500773, 0.1500157720874995, 0.12400144769344479, 0.24255490803625435, 0.13600132253486663, 0.14366119197802618, 0.10104233006131835], [0.016732062613300513, 0.022449039533967152, 0.011436705353844445, 0.027912842051591724, 0.0326375916483812, 0.023357127720373683, 0.05581454446655698, 0.007636100772288046, 0.040346728565054946, 0.024383764721278567, 0.006075503360989387, 0.03970362420659512, 0.0692320846428629, 0.014532131881423993, 0.04238450652337633, 0.036388832741067745, 0.021837962558493018, 0.0828993871982675, 0.037745564040960744, 0.016384164191549644, 0.03703251226397697, 0.026928889674309175, 0.01263739639398409, 0.05833179806359112, 0.008024095113796648, 0.03667544275231194, 0.03560846074833535, 0.026635754329618067, 0.06142479498521425, 0.08287390926852822, 0.027602444351941813, 0.04326630412833765, 0.025551383805577643, 0.04941499762935564, 0.019622471772891004, 0.015604523214278743, 0.04030462652735878, 0.05481448562932201, 0.03564872225979343, 0.018496492739359383, 0.05210775801970158, 0.022376370288839098, 0.06544735413626768, 0.06730598135618493, 0.03738386352779344, 0.07001852369285189, 0.010026207310147583, 0.05697996493836399, 0.0734589496278204, 0.01808498112950474, 0.009531819141557207, 0.040935778597486205, 0.06486306869192049, 0.01608564085472608, 0.02051624393061502, 0.08058180843363516, 0.05150548662641086, 0.037198630889179185, 0.08005549956578761, 0.030370454805961344, 0.048289805272361264, 0.07073266271618195, 0.07154547769459896, 0.017011464515235275, 0.04392558359540999, 0.02763776315987343, 0.05211830764892511, 0.02107011245243484, 0.019121468285447918, 0.009774937443580711, 0.04212195322907064, 0.012711149174720049, 0.04250507212418597, 0.003100504904978152, 0.05048271064879373, 0.017235238738066982, 0.03589350111724343, 0.03617744681832846, 0.04772876018250827, 0.02915974477218697, 0.07746537448838353, 0.027143396328028757, 0.03454675170360133, 0.031512258283328265, 0.04421043842739891, 0.029961921063659247, 0.05443248366646003, 0.022805580265412573, 0.04232026250974741, 0.08076448066276498, 0.042395575655973516, 0.03640081100456882, 0.0684737581468653, 0.013800649794575293, 0.03333336251671426, 0.057812257582554594, 0.029591849124699365, 0.014471450176642975, 0.0879195932066068, 0.010670987066987436, 0.048452454357175156, 0.09004250663565472, 0.02738018967647804, 0.05153197758772876, 0.015273276731022634, 0.05334013876563404, 0.07434117025695741, 0.03768454094824847, 0.053941693986416794, 0.049839676794363186, 0.03857180447084829, 0.03644306147180032, 0.043206230984651484, 0.10192653964622878, 0.05702004833437968, 0.041077584464801475, 0.03185962050338276, 0.045345371472649276, 0.04918919919873588, 0.022595597001782153, 0.02420859189442126, 0.018101514324371237, 0.01498305060522398, 0.10218937866738997, 0.032275623962050304, 0.06308447467745282, 0.03334108456328977, 0.015003912376414519, 0.07982564900885336, 0.03231746995879803, 0.024116699169098865, 0.03199474704160821, 0.07523438209318556, 0.04735445058031473, 0.08431500420556404, 0.0703640676510986, 0.019318994600325823, 0.010371767966717016, 0.018155551952077076, 0.020231309317750856, 0.05447928349894937, 0.0165072939125821, 0.02959762488899287, 0.03183869936037809, 0.027471039684314746, 0.013472849659592612, 0.04137698910199106, 0.03394260267668869, 0.07584505088743754, 0.02931872208137065, 0.01673469723755261, 0.06827946388511918, 0.0464445255784085, 0.0773080466024112, 0.05344172765035182, 0.0350932395667769, 0.02944204847153742, 0.049158567053382285, 0.054646467106067576, 0.02772009145701304, 0.028690425424429122, 0.04438040137756616, 0.008991060658445349, 0.049613911760388874, 0.06070539042411838, 0.01737498700094875, 0.027477283001644537, 0.012291922939766664, 0.05114332598168403, 0.03236085220123641, 0.037676663050660864, 0.03264322083850857, 0.019460447947494686, 0.02137946372386068, 0.030767184689466376, 0.0237490800282103, 0.05106466203869786, 0.005129689952809713, 0.053688677289756015, 0.05268745699140709, 0.10402336658444256, 0.07836007804144174, 0.05483587803610135, 0.04101886574062519, 0.05035096088249702, 0.00927288845559815, 0.03430294505960774, 0.004336684751251596, 0.035472447343636304, 0.0442331926751649, 0.011828603855974507, 0.013179546403989661, 0.03868699321174063, 0.03179017032380216, 0.0380782391584944, 0.0805642269551754, 0.04927879497699905, 0.043151319478056394, 0.025616670536692254, 0.07909465581178665, 0.13575855118688196, 0.07866260712035, 0.02515356110961875, 0.05661750372382812, 0.003080669152950577, 0.038144691061461344, 0.05179562183911912, 0.03687387448735535, 0.03220804770535324, 0.016053251674748026, 0.01837980486016022, 0.0377477199799614, 0.0748909087269567, 0.03916433146514464, 0.003924982502212515, 0.04417732008732855, 0.09758092361153103, 0.05308941901603248, 0.04049142138683237, 0.07705282943788916, 0.042006200455944054, 0.039535724426968955, 0.02760566712822765, 0.033724095846991986, 0.0834538605704438, 0.04506981204031035, 0.008125834283418953, 0.03792292991420254, 0.06325327616650611, 0.029320525500224903, 0.021312919052434154, 0.008986312768684002, 0.010385312161815818, 0.06037076345819514, 0.01786272830941016, 0.02118032509315526, 0.01595818997884635, 0.03929752841941081, 0.04866224837314803, 0.05007147919968702, 0.025409316331206355, 0.032127680533449166, 0.03605537465773523, 0.038357910088961944, 0.03304565041617025, 0.009124586013058433, 0.08265444135759026, 0.016128852403198835, 0.04295710314181633, 0.06390569818904623, 0.05798015736218076, 0.05377813577069901, 0.0403167272452265, 0.02564666257967474, 0.07028990483377129, 0.0294904105248861, 0.05650915758451447, 0.06471233107731678, 0.02031905714829918, 0.02470586980052758, 0.051969792766612954, 0.11309218112728558, 0.014294376524048857, 0.014876961522531928, 0.04021410677523818, 0.04998457370675169, 0.043814254022436216, 0.04164675236097537, 0.023307902920350898, 0.04831877500691917, 0.043530044858925976, 0.0660266300837975, 0.08426383312325925, 0.04461524287762586, 0.02265666647872422, 0.0517022745043505, 0.05741964661865495, 0.006315308901321259, 0.027474468406580854, 0.07827001842088066, 0.09840910104685463, 0.022213110787561163, 0.07112204533768818, 0.082485543389339, 0.04023716530355159, 0.0338761396415066, 0.05767268186900765, 0.06451037785154767, 0.014283864002209157, 0.062042703430051915, 0.034982284778379835, 0.05358476919354871, 0.03610823412600439, 0.06601603221497498, 0.02333272776013473, 0.04425594692293089, 0.038207669713301584, 0.05617181435809471, 0.05213416734477505, 0.02182419386372203, 0.019230853431508876, 0.0345881895191269, 0.06039792606316041, 0.01073809020454064, 0.06894915568409488, 0.03353410604177043, 0.018735818666755222, 0.03329356484755408, 0.0447314260964049, 0.012785989201802295, 0.028439351299311966, 0.08219001276302151, 0.028820874576922506, 0.03363288960827049, 0.0739311336656101, 0.0924754077277612, 0.01612575950275641, 0.04347114059783053, 0.04779433264047839, 0.02731539832893759, 0.02113785012625158, 0.01941723639902193, 0.06554464969667606, 0.0251715433478239, 0.0450427125178976, 0.01643947460252093, 0.0898933201096952, 0.058635815148591064, 0.040221583913080394, 0.028739076915371697, 0.06457722309278324, 0.045449179378920235, 0.005241380858933553, 0.05054963752627373, 0.05934244363743346, 0.01163335964520229, 0.053828727977816015, 0.0518454013945302, 0.01619602604478132, 0.09113054707995616, 0.054600094008492306, 0.046034500119276345, 0.0547962733253371, 0.04129064764128998, 0.1062194409314543, 0.0034265695740032243, 0.0408914723811904, 0.03934130028937943, 0.009844749420153676, 0.05822015678859316, 0.048437236619065516, 0.012884153074992355, 0.14032967621460557, 0.10394905533757992, 0.06916403712239116, 0.11389631297788583, 0.15815422288142145, 0.18560503347544, 0.14589793601771817, 0.11410250386688858, 0.11495687911519781, 0.11204322217963636, 0.13860994193237275, 0.1166391052538529, 0.09017008182127029, 0.10337981322663836, 0.09008052686112933, 0.08096008852589875, 0.09455350285861641, 0.12152334980783053, 0.10165734784095548, 0.12588580517331138, 0.18289874744368717, 0.07799011000315659, 0.1819530435022898, 0.13009269896429032, 0.2122637498541735, 0.1501965444185771, 0.12452025344828144, 0.14722330786753446, 0.08989677851786837, 0.12981528416275978, 0.1139021388371475, 0.12024105963064358, 0.07949784238007851, 0.15914871561108157, 0.0935992642189376, 0.12931571487570181, 0.18525962310377508, 0.09760298766195774, 0.09839324135100469, 0.1487205908051692, 0.1299162904615514, 0.2136376136331819, 0.13368355081183836, 0.142746212950442, 0.21985795407090336, 0.21419841010356322, 0.09823319720453583, 0.15935589355649427, 0.2396365607273765, 0.14988518378231674, 0.0732259449432604, 0.13138874113792554, 0.2058392742765136, 0.10854667503735982, 0.06870301498565823, 0.1336456270655617, 0.14856883644824848, 0.1385419166763313, 0.2228441188344732, 0.11052985690184869, 0.12877684144768864, 0.14710495015606284, 0.1435291045345366, 0.20758582977578044, 0.1214684679871425, 0.17604765569558367, 0.18597650807350874, 0.12929140211781487, 0.09232903394149616, 0.09699795176857151, 0.13622329890495166, 0.04998072196030989, 0.16318343114107847, 0.1009760117449332, 0.0990225603163708, 0.19351202325196937, 0.12106450216379017, 0.11416977213229984, 0.13658549665706232, 0.18410901218885556, 0.12770803004968911, 0.19773367093876004, 0.10950578216579743, 0.090821531630354, 0.11455964457127266, 0.17585097171831876, 0.14792442962061614, 0.11558711834368296, 0.1591016337624751, 0.1821981303510256, 0.15574405377265066, 0.12052796650095843, 0.17430723033612594, 0.13930273678852245, 0.10835808789124712, 0.24181687185773626, 0.14584132499294356, 0.14845223020529374, 0.17067006847355515, 0.10772312118206173, 0.2212770888581872, 0.18842900928575546, 0.10129656759090722, 0.17779958434402943, 0.20025250531034544, 0.17583289300091565, 0.27682280517183244, 0.21174472145503387, 0.2924001880455762, 0.15009812079370022, 0.21643044892698526, 0.11547126909135841, 0.12287765799555928, 0.15232241159537807, 0.10334191174479201, 0.11162860653712414, 0.11933648551348597, 0.17320196464424953, 0.10613692153128795, 0.17204845935339108, 0.10402028667158447, 0.17408011830411851, 0.19313140539452434, 0.1876607973827049, 0.1174969389103353, 0.11126805635285564, 0.18982464767759666, 0.19265184440882877, 0.3016967454459518, 0.11388730330509134, 0.15199616347672418, 0.19083671446423978, 0.11976871974184178, 0.1099987314955797, 0.16184047039132565, 0.1482030763872899, 0.12103106098948047, 0.0943545404879842, 0.2137477631913498, 0.21899505896726623, 0.18244078295538202, 0.21175331552512944, 0.1180533789738547, 0.16843164718011394, 0.10907865391345695, 0.10817638045409694, 0.10683801359846257, 0.11396888759918511, 0.14600703172618523, 0.10633270750986412, 0.18174623663071543, 0.11502189867314883, 0.15775763400597498, 0.19922826730180532, 0.17028959904564545, 0.1629742790828459, 0.1421766888233833, 0.13774743274552748, 0.20222532679326832, 0.1592879870440811, 0.09934819245245308, 0.14710879448102787, 0.11553729797014967, 0.12937143532326445, 0.2446034285821952, 0.05454354977700859, 0.17749568971339613, 0.10905863819061778, 0.1568001150735654, 0.12074203899828717, 0.11149966579978354, 0.11402055592043325, 0.10924835340119898, 0.12090674383216538, 0.11043449834687635, 0.10346470007789321], [0.038820038025733083, 0.016614781015960034, 0.005527155954041518, 0.030764225375605747, 0.00944611036175047, 0.05687833523552399, 0.024358014052268118, 0.08795959496637806, 0.05493968965311069, 0.0757770033669658, 0.021683658924303018, 0.03093312705459539, 0.018958449982164893, 0.03729458687303122, 0.0431020520045422, 0.07047999853966758, 0.04690674628363922, 0.02708650328713702, 0.017302273226960097, 0.027367298571334686, 0.005809711983602028, 0.02046756646450376, 0.04949437403411139, 0.10136392491403967, 0.040532599450671114, 0.03083002047787886, 0.10653237492078915, 0.025207858489011414, 0.03442898771027103, 0.018768224545056, 0.07642944765393622, 0.05298257943650242, 0.048523236691835336, 0.06260679132537916, 0.013518357227439992, 0.07171282457420602, 0.025121158942056354, 0.03162654902553186, 0.010656536524038529, 0.014466637348959921, 0.01800078262021998, 0.0825758627615869, 0.05777880156529136, 0.03412024685530923, 0.01769835002050968, 0.02102905127685517, 0.07944158758618869, 0.0555051356786862, 0.021470721912919544, 0.04218542540911585, 0.05383706229622476, 0.06651289266301319, 0.037658543515135534, 0.007623710616826429, 0.033232519490411505, 0.03729354415554553, 0.00669628762807406, 0.06371053561451845, 0.05417796041001566, 0.12276255089091137, 0.05786973692011088, 0.022805340922786854, 0.095781208074186, 0.023951560178829823, 0.02737549744779244, 0.028370266627462115, 0.065845568315126, 0.05819150246679783, 0.01980410685064271, 0.05148927812115289, 0.04984014063666109, 0.011417209134378936, 0.07996866086614318, 0.032227106057689525, 0.020314264729677234, 0.0459344511909876, 0.01957608197699301, 0.026591585410642438, 0.03011014650837751, 0.04965258878655732, 0.021931827541266102, 0.03934699998353608, 0.02291509157657856, 0.032413425942650065, 0.01610805371456081, 0.07819194448529743, 0.027747317144530825, 0.03214998578187078, 0.03959068046242464, 0.041270676447311416, 0.06402052327757701, 0.04480292831431143, 0.01982392590434756, 0.03995393948571291, 0.0037398472704808228, 0.022569538341485895, 0.08470627188216895, 0.015205684703687439, 0.05898397146665957, 0.027661294807330705, 0.030482654547085986, 0.029252487256599125, 0.032620633573969826, 0.05785219254903495, 0.01737279766530264, 0.07418177177896723, 0.039431307959603146, 0.010540177045186283, 0.08639053150545806, 0.07136623418773524, 0.06944750042748637, 0.019857929255522322, 0.046951011681812815, 0.05399456829763949, 0.01980219953111373, 0.09411457445821725, 0.09578356068232097, 0.10242087679216638, 0.03574123838916421, 0.03381818904017564, 0.019978188720415346, 0.003939506332244491, 0.04276756604667753, 0.0587937404634431, 0.028174354483780917, 0.020902051255689003, 0.028432508697733283, 0.02411896457488183, 0.05481024425534997, 0.00781484379331232, 0.037820064535480924, 0.009002904407680035, 0.021506862649403047, 0.02132410321792122, 0.02990522469190182, 0.036696404713438824, 0.033972303426708095, 0.02035406982031418, 0.019028490169148427, 0.03291581539087929, 0.020759596009156667, 0.03282439392933156, 0.10347181727411225, 0.06256429594941437, 0.03033797285752371, 0.02003277182666352, 0.024323504185304046, 0.03116964580840431, 0.039804292828193866, 0.028641413991863374, 0.025903516179823782, 0.019419926684349775, 0.039285680031753145, 0.04085898486664519, 0.011081052416557213, 0.0768205891654361, 0.020668645811383612, 0.03800557547947392, 0.02818807122821454, 0.07795061290380545, 0.044808546372223645, 0.06031250115483999, 0.0030231413438741583, 0.04588713185512461, 0.022956130487727933, 0.04129407636355609, 0.061051773009239696, 0.03742195425729733, 0.015108265761227813, 0.06949211092432961, 0.02011190703342436, 0.05050672283687163, 0.05493309938174207, 0.009819410643103765, 0.027847019118780736, 0.010594788909656927, 0.07065849989885464, 0.03322756565466989, 0.008326271672558505, 0.06615379708819091, 0.0356684040161781, 0.05179365514777601, 0.04524766030954197, 0.008849752030073432, 0.01556344255732256, 0.029819402734574396, 0.05665318247338291, 0.0692741347302217, 0.05669718811986968, 0.018350293357798364, 0.012883338567917235, 0.023420841098413803, 0.022204594642971642, 0.032385472950409167, 0.02733324326982256, 0.009343554829683853, 0.05774781318905298, 0.09044466161867604, 0.013794812803098466, 0.06404493251466192, 0.041823873325483873, 0.04236250555550214, 0.046756290685152635, 0.019927156790799927, 0.019419420168560464, 0.05377517831220757, 0.012040119654557202, 0.035338767993380316, 0.03214908778318204, 0.022141307999845594, 0.09311329107731581, 0.06902068387717009, 0.08232390362536535, 0.08266780743724667, 0.0117472041711153, 0.02576633203716483, 0.06860433160909452, 0.09164285904262215, 0.025080578307097312, 0.04884982990915887, 0.028155969630461186, 0.01002048256850685, 0.033922304937732406, 0.01710818862193264, 0.0240970600862056, 0.022978587876423262, 0.065414484415669, 0.058404053561389446, 0.0531792263063835, 0.05271532463666517, 0.017348447800031863, 0.04260737347067334, 0.014028196910658153, 0.039771905503585, 0.06813061874709092, 0.031309125042753294, 0.10144308980670758, 0.016718358856451232, 0.04694223949627485, 0.02752306423644768, 0.11659968236926943, 0.025260196598537732, 0.0595283219445264, 0.03002835626830347, 0.05074325643363409, 0.021700179131585173, 0.07263013394549489, 0.11268506859778427, 0.05533432668016758, 0.016722392429073807, 0.04412311733176466, 0.0819771944952663, 0.008241675186582142, 0.09335815528174862, 0.01795945983758429, 0.04133477574214339, 0.0155905893916497, 0.0650657937512733, 0.02405769657343626, 0.028547168658406008, 0.05068474551080726, 0.0808706003590487, 0.04254105515428819, 0.01297363567573484, 0.013972350297990488, 0.08614919992396608, 0.07756012448226102, 0.04010027245385572, 0.057966253225458786, 0.042899590407614596, 0.06548174525960349, 0.0657549372408539, 0.019763464988500345, 0.055948331428226084, 0.040672616742085665, 0.04118857264984399, 0.036783276809728704, 0.00971569736066158, 0.04360330225608777, 0.011419241691328352, 0.03616746864281595, 0.06588477597688325, 0.032974497007671744, 0.0695162158808671, 0.032939475058810785, 0.02645020813361043, 0.03390073441551067, 0.015607256173097994, 0.025447850493947044, 0.011422041443438502, 0.0387263938318938, 0.0653190071170684, 0.044386743029463105, 0.009714965417515486, 0.02490569862857228, 0.046173645387170836, 0.019905855297110975, 0.0403150240163086, 0.08017220970941707, 0.06803554220823571, 0.0481811288773315, 0.007966244702402037, 0.02128452262695646, 0.0342404970433563, 0.02226052474725293, 0.020634033899114, 0.07362944321357645, 0.023506913530582096, 0.0414628964063013, 0.024621617485536262, 0.03429683347349055, 0.059794352200697176, 0.044419876212487, 0.04817047905817162, 0.03095696483796928, 0.03930793704057578, 0.03436915205384139, 0.059577574575087056, 0.06177754890813958, 0.03911234773113392, 0.021631118579534814, 0.027581851609284058, 0.022895129659445956, 0.058536170690786093, 0.035652893129736185, 0.026853461495193187, 0.057690100074978545, 0.07005871841101907, 0.011346407318342244, 0.01163864466434461, 0.024407068158325274, 0.032755184947745875, 0.05428742719232105, 0.025811567793425638, 0.045749099808745086, 0.008781364049355034, 0.022574278809770476, 0.027317685999150854, 0.0353672330675181, 0.02645864078658633, 0.06799608963774517, 0.04750418629555497, 0.08134583462378941, 0.023789757142367307, 0.015659095188311767, 0.030308350033010356, 0.04987273205188103, 0.05337897164281458, 0.051693550558411516, 0.043188089184695855, 0.06365126770106144, 0.01860561442299513, 0.1250364468432963, 0.13222034729551524, 0.09092389605939388, 0.17288100061705336, 0.19831115088891238, 0.1966059923870489, 0.08655048659420572, 0.1218688566586934, 0.1297431770944968, 0.21160328295081854, 0.14368019095854834, 0.17367903201375157, 0.19212968414649367, 0.08795060755801387, 0.10312994694686495, 0.13986446836497635, 0.10952835087664425, 0.17950520297745243, 0.07496634803828783, 0.1163146531325765, 0.15035956457722932, 0.22245894419029355, 0.1671350112883374, 0.12621711473912, 0.06683557105134241, 0.15133495442569256, 0.16892731277039275, 0.16501175647135824, 0.12840260606026277, 0.12130546267144382, 0.23445415834430605, 0.13203999056713656, 0.1415630811243318, 0.12262601056136191, 0.15229475917294621, 0.10411779003334232, 0.09738173859659582, 0.16576413094298914, 0.06971963855903596, 0.1596892811357975, 0.13512962555978447, 0.2770203648833558, 0.19978297816123813, 0.2636173559585586, 0.11724865340511315, 0.1112608500989154, 0.12217781273648143, 0.1722105295630172, 0.0809436573763378, 0.10713084280723706, 0.1048879834706895, 0.15540652500931174, 0.09771791665116325, 0.10986522655002773, 0.15862901927903295, 0.11665135069051757, 0.12515688256826252, 0.18889809114625677, 0.18475595716154203, 0.18369468598393723, 0.13235924765467644, 0.1149322694982402, 0.18735037185251713, 0.1251462401705794, 0.20148332754615694, 0.12054482067469507, 0.12140577877289616, 0.17561373679200187, 0.10442059370689094, 0.1749516965355724, 0.1574362543760799, 0.16709725081454962, 0.1486167940311134, 0.12304511619731784, 0.12490769906435162, 0.16896234214073047, 0.11014967691153288, 0.22540087695233524, 0.1468893265700899, 0.19904124608729035, 0.13834129931638017, 0.15948100481182337, 0.1913838999462314, 0.1909785091993399, 0.09637409501010552, 0.18121760484063998, 0.12366642738925293, 0.07525204520788975, 0.18551371962530538, 0.10028493867139332, 0.23044534376822412, 0.10226969388895668, 0.15530455391854048, 0.14155981567455456, 0.131438079115469, 0.09293751340010203, 0.09734498002217151, 0.1360888811177574, 0.14611036836868152, 0.12138009304180741, 0.11922194244107231, 0.15186573844403028, 0.12279929462238215, 0.12614095554454252, 0.09903413039864972, 0.17397823627106845, 0.16286969563225284, 0.10129402944585308, 0.24551392503781244, 0.14374711783602834, 0.1595055402140133, 0.10547375321038999, 0.19583724613767117, 0.11949032530537806, 0.07118287918274291, 0.17367345106322318, 0.1735414972063154, 0.1639683562098071, 0.075448654970387, 0.1267731614643708, 0.06666458764811978, 0.1955035320133902, 0.184922702901531, 0.18201710568973795, 0.1585488673299551, 0.08568949881009758, 0.10793099674629048, 0.11122771320515312, 0.12719152495265007, 0.1327881051111035, 0.14700004016049206, 0.11618333010119386, 0.19608764676377177, 0.11852325493237004, 0.11243384418776259, 0.08747315427171998, 0.11436574364779517, 0.10048240932519548, 0.20703341957414523, 0.10606982395984232, 0.22518681187648326, 0.1168189053714741, 0.19609607756137848, 0.09357641349197365, 0.08126401284243912, 0.1649465662194416, 0.1516679412452504, 0.1361402525799349, 0.11073876405134797, 0.09399353759363294, 0.167965890141204, 0.14556653739418834, 0.10583422917989083, 0.10804978490341455, 0.12459268706152216, 0.17043126019416377, 0.12715260672848672, 0.1237393805058673, 0.23945820779772475, 0.1521289040101692, 0.16921146627282724, 0.10531479259952903, 0.14482795202638954, 0.08145644431351684, 0.15372544177807868, 0.1211796909046825, 0.18269449356012046, 0.16733043361455202, 0.1270182483131066, 0.22534215822815895, 0.09797308928682469, 0.1060806741588749, 0.21064739674329758, 0.14951719727832824, 0.1894012078992091, 0.1370382512686774], [0.044519208968267776, 0.03688492506626062, 0.04443016980076209, 0.04070391682034824, 0.04474599816603586, 0.0641720624116715, 0.03447766517638229, 0.06438492520828731, 0.059056449608760886, 0.05541195161640644, 0.0607949082768755, 0.07801090498105623, 0.06170933069370221, 0.010718260946305236, 0.02639713344251504, 0.028550790339068044, 0.06525423246785067, 0.026345990190748125, 0.03755687299417332, 0.04710632092610467, 0.019300294334243517, 0.028218052138981875, 0.05154917686013505, 0.030657942406833172, 0.038042237574700266, 0.09092864580452442, 0.10147368113393895, 0.0516700727166608, 0.026826753455679864, 0.017254501181014348, 0.04419339500600472, 0.00999700936517911, 0.035582018026616424, 0.013072940600977745, 0.04066476481966674, 0.02598632316221483, 0.031156706463661976, 0.05319217678334098, 0.026817070283868816, 0.00997807346720947, 0.05743745816289447, 0.04462516539206263, 0.04917498707072809, 0.06405365274986252, 0.007426616139127873, 0.04325937989051454, 0.03784172411542386, 0.029223921992524993, 0.046524848221451975, 0.07190788324805908, 0.009159184937743703, 0.02490835737262387, 0.035681213485077024, 0.027708979650924448, 0.010366238038841402, 0.04167817489360459, 0.03602062730351463, 0.032299495142069645, 0.02850322052836418, 0.06026660303177778, 0.07283009821549058, 0.043808550617541187, 0.033873085703817196, 0.047427644894924015, 0.06694231415167451, 0.02594956644315971, 0.03694711333082523, 0.033230545377591625, 0.03835510477074422, 0.04600801657943521, 0.030678139955853112, 0.023551698432129342, 0.038094922638265416, 0.0185720470835804, 0.04761334137583617, 0.03786155430134386, 0.05797405319754034, 0.03309639105282258, 0.04362836458312813, 0.01754871820594417, 0.041769882082007825, 0.014920245430403156, 0.02793109702906804, 0.012757210570271127, 0.08181741752196103, 0.028754038612532895, 0.016713657350919675, 0.04978160373866558, 0.08233036773162894, 0.0739561885711737, 0.05698829554603435, 0.047508249554084614, 0.03853518319374416, 0.03620902520196978, 0.01960319819772849, 0.02282618599565467, 0.05436509665742051, 0.06165434497233946, 0.0546295535605168, 0.07263685038196854, 0.05615402878902387, 0.07933894856250845, 0.02044501445197966, 0.03842326361336745, 0.05465603338961955, 0.08613883954240009, 0.02160193176678149, 0.04673392977565527, 0.03765541536267847, 0.04699981160229072, 0.012100497078790795, 0.034063431739923544, 0.04575272891088389, 0.05559545134019572, 0.07467964154784568, 0.016011019761208445, 0.03943803552829195, 0.060458900916273706, 0.04863081099756528, 0.04048650836921297, 0.09572358030709438, 0.043758581814472564, 0.023349741495621856, 0.03411856589082163, 0.023717627809674013, 0.12821177020668983, 0.03340454932185821, 0.029546958467108198, 0.044620790431508794, 0.04653005067666527, 0.0461068817821797, 0.008774400848778896, 0.030455946507572662, 0.01726267593767261, 0.02638728514284594, 0.047246007961803116, 0.04533521147095598, 0.02292279135872377, 0.036216535736457445, 0.06745307502569631, 0.04404320286994334, 0.038131851906655356, 0.03134565726213623, 0.013159320096747251, 0.013386934933805605, 0.024293181886605453, 0.041557694639777765, 0.0362399393634405, 0.019308556293253787, 0.012323455866862787, 0.04487944002903532, 0.02048329999524867, 0.032195984094869345, 0.03019298688741401, 0.029619226952490862, 0.05233108138781972, 0.028355252979963552, 0.00350297877957928, 0.07930011197458953, 0.055791482227505185, 0.05646284014801495, 0.026355905283708125, 0.026473149773664773, 0.09538631871691905, 0.025375370496476535, 0.03659664151200559, 0.04258991073584184, 0.039161054883152246, 0.05160933535080403, 0.043662533062160946, 0.019650413632916752, 0.02527778549847426, 0.024846547603374347, 0.02968011274788296, 0.03716677048942074, 0.004973741069989046, 0.04032048622320872, 0.07529310081736185, 0.027460354613140225, 0.007309658767553628, 0.013343490536499303, 0.03731710363354068, 0.04871206132520456, 0.028716983179037925, 0.06597965955734253, 0.027838950118166395, 0.04392581737192813, 0.10551231520366855, 0.03299711024737917, 0.016157803584064823, 0.037418529245769605, 0.02488296293449821, 0.024464172711304855, 0.06358404396451078, 0.019284913323645014, 0.01853683774243109, 0.05022633573389612, 0.02268375115818344, 0.09586001673596911, 0.06474266265286133, 0.04889153118710965, 0.04463577068236191, 0.05689045450708363, 0.02982869256811682, 0.024718499298614915, 0.03810999194683973, 0.04520392925769556, 0.0360240857116878, 0.034333261792198755, 0.03954455598432105, 0.035920359441661276, 0.022045014338800684, 0.061038644416839816, 0.007668944053875748, 0.061392589486786164, 0.033075978280976415, 0.0036698792109746137, 0.04257149434124585, 0.040217557761934586, 0.027161261677974835, 0.049969960818998516, 0.04854264756431803, 0.020365933050925378, 0.07635393412783742, 0.0625445919285994, 0.04653309348213952, 0.07407827928545885, 0.05764335219282657, 0.02469044611643767, 0.03820907608314883, 0.05779752224043477, 0.04533527826424688, 0.012535447567643132, 0.0437807275011437, 0.02301911656104494, 0.03384006013220642, 0.05584069775068201, 0.025213862463715486, 0.026034319707832765, 0.07979292771779001, 0.020920311799272895, 0.04412531779962592, 0.04523145922576077, 0.025287752541771624, 0.01578863892063964, 0.0315815229259897, 0.05141144909430295, 0.051395878836046904, 0.05655859946273267, 0.006836431084593642, 0.06324946894892491, 0.013536643746192567, 0.03187094196619, 0.029607801589008886, 0.06002810274367221, 0.036377173601067625, 0.10562936673522927, 0.07573317212518305, 0.017999914307438303, 0.026129808138648514, 0.015486854772461811, 0.06700753408949822, 0.030545571971742902, 0.02074179003102472, 0.15924011851893738, 0.03790968628891278, 0.05227800669672433, 0.006152789228508482, 0.03842626560071949, 0.061364027933450416, 0.09673890512203798, 0.06480369687778875, 0.04863376474531833, 0.025370186594955157, 0.006092759222156019, 0.027750447152357083, 0.09877115779090673, 0.06500964285805821, 0.038688596250722185, 0.02900403105741134, 0.10369264331529848, 0.10722859849920496, 0.005319976153259631, 0.027874571351276245, 0.039225421351147816, 0.04008324758615345, 0.04896293692581821, 0.029364019064814784, 0.034780587593559176, 0.07860662692110054, 0.028946048914804123, 0.011389126266294625, 0.0563642532506492, 0.07380758834187873, 0.048056711530080065, 0.05289574073685799, 0.02112199228577083, 0.012431735212885542, 0.029150035625207238, 0.056806087159202434, 0.011811549302365165, 0.05190476578718517, 0.028006944521621335, 0.039037620881572366, 0.03407593692827504, 0.03278688949649222, 0.022919492512301076, 0.023807509314792696, 0.015153120239119744, 0.0342646650824463, 0.02191896055592224, 0.039245926891453564, 0.06137072210549377, 0.12803852325305343, 0.05115589425258804, 0.04646848581614904, 0.05423719121608883, 0.03548930151737295, 0.01755231020069914, 0.006499743731183116, 0.02669275683729211, 0.0542445458995644, 0.03451769662206061, 0.018647425167728215, 0.03472837750450708, 0.05592862740741111, 0.02285016107634874, 0.020198432175675407, 0.047695100074633956, 0.04191844891465735, 0.03389858589798678, 0.03513484065479133, 0.027876083477167413, 0.03429097050684504, 0.06069422852306161, 0.07557817458291538, 0.0798079339438118, 0.050009643455268815, 0.048214009730145335, 0.08317105035530403, 0.07477367165847681, 0.05219383972871583, 0.008253710038843565, 0.05957432025752496, 0.09492312208749354, 0.030453311883320566, 0.05632034037262201, 0.06444897997425869, 0.03094982723268913, 0.05825566113344394, 0.051824279871652834, 0.03342882126162294, 0.1658723657601513, 0.20160254614893347, 0.1706485016620718, 0.14482348429737613, 0.06782983371522278, 0.15452060848474503, 0.16200644429773092, 0.1047135861881543, 0.22762173903174698, 0.13107246748404577, 0.15932361013256013, 0.29842046031262726, 0.13247224705992267, 0.16813319991342723, 0.19742239936022088, 0.11802727021859027, 0.2722891140729189, 0.14403719367692247, 0.1907232846133411, 0.1134955754969269, 0.12111177697079256, 0.1124495999829378, 0.18778589379508048, 0.15440740127814934, 0.08126489599817432, 0.17819903790950775, 0.27976473793387413, 0.16976442566374317, 0.17439642164390534, 0.10516042588278651, 0.19405753148021176, 0.14861496834782884, 0.15523639507591724, 0.17093700414989144, 0.09246609377441928, 0.11544213979505002, 0.23222654272103682, 0.1472430193098262, 0.1014857781410683, 0.1550857984693721, 0.10347450384870172, 0.10560947717749514, 0.0985839287750423, 0.11842621912364848, 0.12502244993811473, 0.2428141253767535, 0.13000610517337918, 0.20276323542930186, 0.14348242344567552, 0.25119742553215474, 0.2140384030644782, 0.14349164091981947, 0.0904163189989049, 0.1906450028764084, 0.1604313842835836, 0.09369295294163749, 0.09900878605549224, 0.1965019729686901, 0.13119003851898015, 0.1932855643099174, 0.1936133115668781, 0.1090409528114833, 0.17913853749632835, 0.1446411682991311, 0.13612043723696843, 0.2899429964600131, 0.23774286702973768, 0.11874836316565052, 0.09053441695868969, 0.11350186890922487, 0.13849277165718377, 0.1520853250985965, 0.1577204227214679, 0.06502948046545498, 0.17146959900856018, 0.16668709547957405, 0.11471084231743589, 0.1504207620746456, 0.1488261835766025, 0.0771477427042555, 0.190798286057543, 0.1925947138806805, 0.12056727064191364, 0.13176539592677727, 0.16367128933779895, 0.13340986159164459, 0.08969288828666322, 0.12128312402637675, 0.2848138951230794, 0.17551700526382774, 0.15405407961225137, 0.20661741611547768, 0.1577184782945551, 0.19550008844817057, 0.17873020784463733, 0.17725511512253433, 0.12991960044018924, 0.1792657416081056, 0.10594249368296005, 0.11605239298660308, 0.13301594444783404, 0.1740248134592548, 0.09627744511817582, 0.10792477754876018, 0.16191695613088086, 0.14650435972725973, 0.11916519782971591, 0.21918531594565138, 0.11908622589544393, 0.11917971423827112, 0.13661205070093274, 0.11756095656892285, 0.14401727443328127, 0.17616433615330607, 0.1280634742579423, 0.11233218479901552, 0.13916802214225754, 0.13394220412010327, 0.16340099915396422, 0.08821581403026357, 0.0933576283568982, 0.09857831071713008, 0.20280550816096365, 0.13332813628949225, 0.13229034666437656, 0.16326328623108566, 0.10692831070628017, 0.1171266072196886, 0.10067669616546482, 0.14287815196439624, 0.15509955788729712, 0.15988038416253403, 0.14557545800926164, 0.11828326663817279, 0.19008150498848408, 0.1457839272916317, 0.1761579536832869, 0.2398217117297463, 0.23249408695846796, 0.23633219272596762, 0.2251297258771956, 0.14193853363394737, 0.1652089599519968, 0.12667409959249198, 0.13911681395256892, 0.07491512500564568, 0.0807044557586778, 0.1322507456643507, 0.13837708567734808, 0.1913662368315272, 0.11056792907766066, 0.15554551442619413, 0.18059041583910584, 0.06471334039815702, 0.12256589659955353, 0.13592253613751382, 0.12169615889433771, 0.18956396088469774, 0.1881208101985976, 0.1887036336120218, 0.1384596124989912, 0.11403033742681146, 0.15141304320422933, 0.2375668889726512, 0.220285490504466, 0.08363590197404847, 0.10829251914401539, 0.13106848957249895, 0.12810212530894205, 0.16506643791217357, 0.12538362352643162, 0.08717993172467686, 0.16585865087108687, 0.19123305100947618, 0.1674691855441779, 0.12362023611785844], [0.02247353597340407, 0.024652572465129197, 0.05630112616927363, 0.02971325520775281, 0.05628443897876423, 0.08351962227607146, 0.06063648201234173, 0.04407482949318364, 0.05459823863930069, 0.010645565726008499, 0.046550908737117425, 0.021694455317629036, 0.016006763544282876, 0.07338063078350388, 0.025042344714165665, 0.05904228943109047, 0.1136568070796784, 0.0245712813193677, 0.09152690588962287, 0.023401163052767515, 0.03846720246656332, 0.09834079377469607, 0.05345807716366835, 0.07449558892403729, 0.017750942315615248, 0.051479158937581815, 0.06404911080608144, 0.009789965006348211, 0.025775992944545578, 0.019763724740187172, 0.11781373948906548, 0.016193406263482757, 0.0675800268072635, 0.04661893028242048, 0.04645334971428383, 0.05171620832697954, 0.024651618805364706, 0.072868823481258, 0.01934506253746804, 0.05842462589498609, 0.019816903331957292, 0.04301616325392388, 0.05488870039698668, 0.0406805762759177, 0.021023412809881847, 0.025944293483917136, 0.011483339130791137, 0.07459790882421657, 0.007479227451767656, 0.009034667400555918, 0.0461284374614479, 0.0627454616187606, 0.023792243337084074, 0.052296590074547566, 0.04695373907452449, 0.0559261078160489, 0.01878872080851579, 0.03223949250241276, 0.014137930866127135, 0.05134943523444235, 0.07942334559629671, 0.07493220182368532, 0.004480027328099823, 0.05988895005430095, 0.020172854055999778, 0.0634815682133194, 0.02182731459470233, 0.03589324507629499, 0.04080987324414309, 0.017033843978424557, 0.042879645188804716, 0.04982923477655277, 0.026628382947819773, 0.016103973757708445, 0.03608295286539942, 0.013743735416937852, 0.07002734040725045, 0.0549944638623856, 0.03302167904621456, 0.039578334835823625, 0.06179006151796784, 0.015056821011967259, 0.03141633940686006, 0.009344536319986219, 0.014870170871290611, 0.04323520071920939, 0.04092773742740974, 0.0603450331982458, 0.05149743432411924, 0.01161519372544717, 0.04703847378550563, 0.053046196335344575, 0.043303971833665855, 0.018149445932067465, 0.06006417112075724, 0.03265678729803767, 0.05755108468292747, 0.04323366818425711, 0.03405857438337989, 0.06373786149197258, 0.06518714231788181, 0.08586585536249913, 0.14840868097962812, 0.026389162776467856, 0.07435864783474244, 0.06943498781765811, 0.031828472565393895, 0.019190823841199744, 0.012167576096544508, 0.04085533721081447, 0.031999081184039824, 0.05805537773994729, 0.07123865900211968, 0.02737530077865813, 0.042625582063919865, 0.0641613086918369, 0.04769367144035641, 0.053425422665895894, 0.006889056312502362, 0.07513189892051741, 0.0386193204758456, 0.04079188729519956, 0.030649819600512274, 0.04313288452976849, 0.07300933430087753, 0.002557386392254557, 0.038342488260241225, 0.0336323775263736, 0.05879653093870729, 0.05816211341880262, 0.09032191781443544, 0.13820360123645514, 0.03502546293020714, 0.026759897082229145, 0.015685645521443803, 0.028297964745434, 0.04309450065193232, 0.09924590223818086, 0.007337568622460822, 0.03368971956660971, 0.03352177896886133, 0.018371316546108574, 0.07512133073760197, 0.03578396383090876, 0.024795894169074018, 0.08578860521083698, 0.03834113012999296, 0.07775332036544569, 0.02103815000737086, 0.011107972895842977, 0.03376158914761618, 0.07456716906744987, 0.03888148785335943, 0.08949852723162621, 0.03306641570816282, 0.03192038384440821, 0.013789824643026805, 0.03985219474998303, 0.055696108829579316, 0.016915994638111442, 0.0540002976777032, 0.005762048940596287, 0.04848500495427288, 0.030259327468229458, 0.09345781087176874, 0.028383577046042774, 0.024176404949685093, 0.03119316817901563, 0.03773215343244374, 0.015835611302463803, 0.02453230928949779, 0.061308645163080655, 0.01784401134500513, 0.034542257999419235, 0.03486768975562882, 0.007094615448295372, 0.03748615003132727, 0.05482486085384153, 0.08887206553481519, 0.05798849910206627, 0.019923331019526813, 0.06701461417833343, 0.06393983698217198, 0.08987224311567843, 0.04048000344482716, 0.024072227824945003, 0.02231482769275317, 0.012471569989429554, 0.05307908832037356, 0.048647724543116055, 0.03226321154215839, 0.06963350489968434, 0.04307995826820843, 0.05769273469923064, 0.04611052943801042, 0.041903357341652736, 0.07365897326963022, 0.025185102385876235, 0.01621329582121689, 0.030336913441715296, 0.02791261940728873, 0.08757784162298776, 0.04365471453638747, 0.05306417486281134, 0.021127057443663944, 0.05548730929149315, 0.05081554532807786, 0.026957087575283367, 0.04641884355805814, 0.0146669801142707, 0.08572818696848117, 0.05628725171845872, 0.045883569546276703, 0.033688175899442285, 0.0441253883036552, 0.024401962182309944, 0.046135614029481076, 0.03166056165355258, 0.02123867645423161, 0.009833853764575906, 0.022450442193076015, 0.03350922554091085, 0.04396437565446831, 0.044662551081273705, 0.053804949566256255, 0.027537278219824657, 0.027041846406063996, 0.026390771381556988, 0.005183682587812655, 0.03856301373161841, 0.019628041591204237, 0.055454840330639854, 0.027204540019738488, 0.035572114065871574, 0.06008326658047736, 0.06277269843849353, 0.015682250195823144, 0.05603868419711944, 0.05391648694057949, 0.030499738786602393, 0.05119055254908744, 0.019585995214583818, 0.05059103452367708, 0.013705136316275457, 0.04261801586835645, 0.01343575248029083, 0.07097368259564973, 0.04979499579349067, 0.014728918831679039, 0.0858135413727723, 0.046708585432497784, 0.03188169197528623, 0.04483895958401263, 0.043688051810022444, 0.018818297248799354, 0.054113875958137214, 0.07074375040247105, 0.031395562982652336, 0.05794915785372723, 0.04434228838363197, 0.01637555156776216, 0.023628477320016827, 0.08529791943146847, 0.02707716335862642, 0.028732776081596967, 0.062450517289107665, 0.02269632685056422, 0.023350953051703982, 0.0037541359324677614, 0.02423545764031587, 0.017248187359655276, 0.01148083994849003, 0.0946108040807303, 0.0281335029649199, 0.04769185688928701, 0.06440874814870767, 0.036382016114657745, 0.04631441966921557, 0.033714674282236956, 0.07213986376882531, 0.05675461179635022, 0.03359649839694612, 0.044352626500767656, 0.10381819985923357, 0.01316666364800767, 0.04938369384035468, 0.004511036113399314, 0.03974018240114674, 0.030987561731308233, 0.040738441530265845, 0.04183091630693525, 0.03902438467775937, 0.0430289727228228, 0.02621567833557492, 0.065163905674126, 0.035676304178196006, 0.00695291394549713, 0.06106483851908706, 0.022540216086781584, 0.07553393515991047, 0.021936031807854306, 0.03459683925029822, 0.02313004351890413, 0.09888938933727331, 0.03996027371613309, 0.043081650364911184, 0.008051419135881588, 0.030905068306310568, 0.06153219859697856, 0.021796231594635174, 0.017686779938230757, 0.030903539482096676, 0.04232315317494795, 0.027919237509195227, 0.03480095954728313, 0.04581851288094185, 0.037887818907620385, 0.005906937967665726, 0.024698023444216233, 0.028560224891407415, 0.058105520947719924, 0.07305638646357693, 0.03129055650788359, 0.04415451759996358, 0.052240539371268824, 0.056060417991830036, 0.034381768564344384, 0.0326487906568218, 0.03534710231178906, 0.027442207247077022, 0.015259377232723637, 0.026163407019339502, 0.041261677906732075, 0.050703432789305225, 0.05199067680223379, 0.029697575482714456, 0.014744516920472961, 0.04053521181049291, 0.08875744082615711, 0.030321434096549638, 0.06235713284695521, 0.06696105338050984, 0.06431002766476013, 0.00678410271575558, 0.014463862644333858, 0.02444747995468788, 0.0444223327212967, 0.03856232353427913, 0.030856234989187215, 0.09081328636966646, 0.03777713871386368, 0.04145794999203645, 0.08709903762792237, 0.12152277093264274, 0.1097856015258003, 0.147854964598082, 0.1301564642926678, 0.15092374524101615, 0.14767733897315338, 0.17187212506541982, 0.11371185217285529, 0.10267161138472147, 0.17486819007899612, 0.10464803970535286, 0.19806311029242352, 0.1549084548605606, 0.10960151921608485, 0.16808283777209, 0.21172667242353782, 0.14731911913258955, 0.18230445042718202, 0.14762516599148512, 0.17829704593168572, 0.14967241004342213, 0.1637059179483913, 0.13651845103595406, 0.07207347865914926, 0.16396161750890315, 0.10540309333009645, 0.11691979292663746, 0.276561212958768, 0.07232554911752231, 0.22526668180944398, 0.08099590457277372, 0.1993667965871282, 0.08655648314743303, 0.114880126202479, 0.15425520163262263, 0.06549577927216887, 0.15470044570975006, 0.1363286838750355, 0.12900959380203858, 0.11418414011131972, 0.1601556022069417, 0.14175765740219504, 0.12984065077034757, 0.13746620330493897, 0.10921483059064485, 0.14885632961522788, 0.13580722123151645, 0.10800049887620844, 0.10288044431945309, 0.2150598802836612, 0.1655142943491228, 0.1294484850950539, 0.11667608647258021, 0.256670675589703, 0.14642977388575673, 0.17562994529725984, 0.12418022364727221, 0.16930092475377023, 0.1336213736794889, 0.14014609856531024, 0.1743311868631281, 0.09971984516596422, 0.11927986706723459, 0.14508483902318403, 0.19729443825781345, 0.1503330995910801, 0.15137694514123723, 0.15738378453534096, 0.16146372654475272, 0.13377612631302327, 0.21566715004155412, 0.07577929660328664, 0.17952038731891662, 0.11705914599588141, 0.10648515206412412, 0.1476096105761826, 0.16667312826029956, 0.10047227158793248, 0.16480615187902004, 0.15817230159882456, 0.1404541640658863, 0.11265095206908882, 0.07728509939624928, 0.10552248262683861, 0.10744777697254904, 0.1681904194992967, 0.16195860545849428, 0.22893899178598076, 0.12138342528487556, 0.09968413301976398, 0.12578718859003857, 0.10951897013001144, 0.07890721899457276, 0.17930985486600548, 0.1504460841533728, 0.16185197368031368, 0.09255862474674359, 0.11572508359677158, 0.15921617683488876, 0.167559371329844, 0.1815814501605928, 0.26699181238655, 0.10624041402479634, 0.16063065093476325, 0.11055200258851983, 0.1146361006249208, 0.1876287514460273, 0.15307244088035077, 0.15734703338239342, 0.10675283730961382, 0.12985282199224457, 0.18839417287381366, 0.1070524645911064, 0.116770413442282, 0.27697838901076466, 0.12130312490626238, 0.12609155819518492, 0.14434491778956726, 0.16706576891010627, 0.11693059117533267, 0.1853110094089061, 0.1601130177732557, 0.26742543443106115, 0.12476591917220503, 0.18808775494107977, 0.16624067880911753, 0.18168313923524693, 0.07798294827807695, 0.107489789952524, 0.15901386737823486, 0.17267542571062222, 0.16931143356487155, 0.12303943876759149, 0.11864934582263231, 0.11135184482554905, 0.08513485474395566, 0.1792736232164316, 0.15339301899075508, 0.1226636151841376, 0.12411458810674958, 0.08876178981154226, 0.18348684010561556, 0.1955082075437531, 0.1331023155944422, 0.20270018256269395, 0.10455386116518639, 0.14305274962680414, 0.1541644221288152, 0.22339010203722864, 0.11289946764009073, 0.20469482318731025, 0.13115039299009368, 0.18688388750888407, 0.11314229835988954, 0.13958381779957563, 0.16237566276686266, 0.11643907419056632, 0.1801970330416225, 0.12257416412467137, 0.11184138769749552, 0.10476739189471118, 0.14080134074902162, 0.10895349812926725, 0.19305155030451715, 0.10552099833148532, 0.20938525587553158, 0.10530341547564603, 0.13948616600828245, 0.07740716784610413, 0.08650974268675782, 0.1725019412697293, 0.12450592257664539, 0.2280188028817065, 0.12938089028466493, 0.1349512132583186], [0.047453764782403596, 0.03737604129128158, 0.026848580018850043, 0.03518577796057798, 0.06960829414310865, 0.06740694312611595, 0.0035733840104512637, 0.03768791400943883, 0.03022052984306356, 0.06062958746042568, 0.05020259071898181, 0.03008323437825311, 0.025084296466957312, 0.03691492267535068, 0.04492397631111089, 0.031062949092302006, 0.01908923681185115, 0.0260940904263407, 0.039010788532323204, 0.10968537448206916, 0.010142578848899575, 0.025875552055367734, 0.028972730979148764, 0.08571620128350332, 0.027623289424809627, 0.09090414008824155, 0.038343475316651165, 0.025042886481969617, 0.03714518141350709, 0.15180699003394693, 0.014240555046853842, 0.044053210731362924, 0.05796981924504507, 0.07022538251476362, 0.007822276402293937, 0.028956915812159423, 0.009718271685414948, 0.06132328031526413, 0.021256003747112118, 0.002173483371734619, 0.03409184857446235, 0.06447441337513737, 0.06282408474362455, 0.054094624647405, 0.04237245775584597, 0.02586951282864902, 0.02618168426124612, 0.0232356641208753, 0.06564132185303606, 0.02546690699091414, 0.02686659379833145, 0.05438031810626853, 0.025169957007165067, 0.02737564773269696, 0.02881592074118089, 0.010469950393598992, 0.012689919112744974, 0.08160540819517337, 0.045439011955750175, 0.09351925327791832, 0.0037576697150143445, 0.051789142889901996, 0.04501069997786544, 0.06174849382659886, 0.12459770397981629, 0.016114326717797667, 0.014282844476838363, 0.0355712457530899, 0.025272020866395906, 0.050053663944709115, 0.0376622023031814, 0.08697277604369447, 0.05631930507661309, 0.019458930255495943, 0.01931141727254726, 0.055881178195704706, 0.04168829407717567, 0.05545104053453542, 0.042828748701140285, 0.037637418281519786, 0.02499690672266297, 0.06809250204241835, 0.027085030123998877, 0.023199913011922035, 0.051792686645057984, 0.019856110993714537, 0.024431280726275872, 0.05918582821323071, 0.05871049375855364, 0.014639561468356987, 0.030664818405057304, 0.026348172104917467, 0.01976795869268244, 0.04184319142950699, 0.021077830788271967, 0.022364453252521344, 0.01171352829260286, 0.012781589193764376, 0.028927933090017177, 0.09933854453265667, 0.030646737832284998, 0.06969643160118721, 0.0321171383257024, 0.03097786186117446, 0.028286891902098432, 0.08251058345194906, 0.03490728333417792, 0.09636942690121941, 0.007083223017616547, 0.05077412977698259, 0.00813056918559596, 0.0948562916892115, 0.03801011371251661, 0.017222204769495875, 0.033964763206313364, 0.053500728390645236, 0.04026327034807764, 0.02440632972138701, 0.012112235999666154, 0.05445138616778422, 0.008456082578049973, 0.027377903861633968, 0.04090656395419501, 0.05050734253018163, 0.11678168666549027, 0.0924059798126109, 0.04173986962996423, 0.02681332429347094, 0.03353621745191049, 0.07283818762516603, 0.02114455543051008, 0.02376791202550521, 0.031074914368218742, 0.026833434640138876, 0.050427231399226, 0.03219474841898773, 0.049285500281257555, 0.026874276882153936, 0.05966637625533622, 0.042350991134298965, 0.0383688753208844, 0.012889533645648044, 0.04435542068677023, 0.007006713158261846, 0.040409729481325485, 0.05361141600587871, 0.023519056921941228, 0.024975556989375036, 0.028543012631416786, 0.1422507848474197, 0.07395427383016795, 0.046878437060513534, 0.09341563461930491, 0.02172849763155682, 0.059034563673776574, 0.00946926722463104, 0.048322329894290306, 0.02421104654786177, 0.026986895936715882, 0.010939634321402991, 0.039795676493668, 0.04986581523553468, 0.09535926001262851, 0.024006718449527398, 0.03999336979177315, 0.031442611434613355, 0.03752250413526781, 0.06356885962304659, 0.07046246159006841, 0.023186064536275808, 0.06698385215713643, 0.019732613909582142, 0.03893738641636446, 0.04972105933120474, 0.039830824607633986, 0.015468244491785299, 0.09342933466541581, 0.020922883340972476, 0.05186201065953355, 0.02551086068706354, 0.09750915050972253, 0.026635244103090372, 0.040673006369615905, 0.027336614475643728, 0.0485351964016445, 0.01603374803380575, 0.03277853662439156, 0.052678855499834754, 0.03941953007597476, 0.01602742493560072, 0.0043090569124615286, 0.041963352559832856, 0.013896039890823886, 0.009138603327301098, 0.010362279608671088, 0.061043060195515864, 0.051231166580691934, 0.007664756949452567, 0.06910165218869224, 0.08353755256393924, 0.059641633051796816, 0.10284378964570351, 0.021447014005389065, 0.02064030875772005, 0.01607474056072533, 0.07109019978088327, 0.05152874182385858, 0.04747206243337132, 0.04548618286207784, 0.039882110722828656, 0.03899160401488189, 0.04328954077209346, 0.09145779709797353, 0.02751966705545783, 0.014491528982034652, 0.06406767191947438, 0.04250339487043675, 0.058868890337180346, 0.021101993261254393, 0.031232490873662755, 0.011878682125825435, 0.04375745375000406, 0.030548958020517603, 0.07586719657410868, 0.04086393499164842, 0.04999377633794211, 0.054173756143427454, 0.0373611649411032, 0.01947805725649232, 0.05452645069453865, 0.0956879423756618, 0.027058069754275493, 0.023753512505209073, 0.05947419340373017, 0.03714183432748541, 0.04778944930876605, 0.050512867819634266, 0.017242623107449617, 0.035097915097139776, 0.06355769030051306, 0.1209716965968255, 0.046439653378911316, 0.050512993984739296, 0.037354392843553796, 0.00913644274987746, 0.013401593278103974, 0.05730842094635591, 0.006232728737813886, 0.04250402198522352, 0.046810330168227665, 0.08726142696104944, 0.013700025701837149, 0.024866021558409557, 0.00944814199101529, 0.007974801665113773, 0.021672526709153317, 0.021917967933404725, 0.02353836018301081, 0.020990977245674003, 0.010945132708002347, 0.07299739314476028, 0.009786071514099604, 0.013650204400619259, 0.074029334646184, 0.02093424933264032, 0.004864281245318125, 0.007901899571152171, 0.044291996746324, 0.03628530685091391, 0.0424068451684434, 0.0438749208842637, 0.01761573785188375, 0.04330712225055322, 0.010957139729725895, 0.11059545533498749, 0.026279319354216568, 0.028701294177153613, 0.038429393753176555, 0.08490388354402967, 0.03368843194039073, 0.037068873789394274, 0.04657409714127425, 0.053235811355989426, 0.028704854630632326, 0.06116753320384305, 0.024104913863993715, 0.014214411967259366, 0.04486248937610071, 0.025330272037535906, 0.021785674543934874, 0.04060992752783932, 0.02766468642221298, 0.021795578504679725, 0.034318526450078934, 0.008514123164786724, 0.012623157363123028, 0.04904792396700941, 0.05886594772164244, 0.021215812739683315, 0.04489460952754598, 0.05858227661519777, 0.010032568443421042, 0.03732653633051086, 0.012094911489839433, 0.018564523561508395, 0.05647407626383938, 0.07577997195767239, 0.017176087712869048, 0.017559902371431235, 0.0055852086006780155, 0.057310309712192975, 0.01804050050850492, 0.03615382796851918, 0.007804358174325898, 0.039801550592528656, 0.07928227074444294, 0.010850768630916718, 0.03250204579671845, 0.041446231480222195, 0.03081129052588949, 0.02494446100172354, 0.05157963831152301, 0.006532808729389217, 0.01804020364943426, 0.006901823107909877, 0.06574355269549415, 0.059492331492947415, 0.06758962277672254, 0.10251184925436974, 0.0034957034131366527, 0.07186840841313824, 0.019742632903216872, 0.009574562209309079, 0.02572604083979968, 0.005042055763624376, 0.024580882854934316, 0.0025796554609769373, 0.0486957192333648, 0.01676003786997171, 0.05163373345567379, 0.0398933876567753, 0.06526036260765977, 0.005606365375570022, 0.03303951656562276, 0.028565941283886787, 0.03582872646802571, 0.05749343094066717, 0.0213297954906011, 0.05784495660918765, 0.034124473386327736, 0.07093280510162003, 0.030212442288757302, 0.18725166621152312, 0.08659138635266572, 0.1174597127828747, 0.11929094733204693, 0.16948378994129598, 0.21495456952834502, 0.11234196630539373, 0.08612540666945279, 0.20016381866298616, 0.16016332054277882, 0.20868664258159697, 0.1362741063348949, 0.11552454787306488, 0.0859527979628183, 0.11361928409314714, 0.14233743801014498, 0.08288820303278044, 0.07097627269104123, 0.07159645581850782, 0.2431382064241916, 0.17213573592016473, 0.22354310320224613, 0.14261086005717516, 0.19392826419789344, 0.15237765706842765, 0.2023109854781069, 0.19747890648432076, 0.10124816471943632, 0.08910787553759292, 0.24358833383303136, 0.09067376260645688, 0.12085833353921771, 0.16006363526685163, 0.14229451218852773, 0.10109085909789428, 0.08673641685163602, 0.1332573502440937, 0.1434382062871009, 0.12175582014606334, 0.14344957598950714, 0.11486727962619625, 0.1433323314995505, 0.1616020777146332, 0.12094007368432358, 0.13511570286937058, 0.15143596072448418, 0.1348073108238168, 0.18767973699141294, 0.12140292892581783, 0.15393869049148634, 0.1554648281307891, 0.1152285051648505, 0.16826404054882005, 0.10129536531167105, 0.16457144025480375, 0.0974717091594357, 0.14906280994182453, 0.16113596444483846, 0.14266534853959456, 0.32563857792411, 0.16951000259723514, 0.1435241469880566, 0.16415153309935704, 0.1549935940420255, 0.21488955739187077, 0.1544140509213321, 0.2279685891699046, 0.2668242057552561, 0.0685764936497435, 0.21090115187689662, 0.19900149665772915, 0.11105516387033276, 0.1499627679004334, 0.0941272874479182, 0.22071111219702289, 0.14188634580932558, 0.12193132322863676, 0.23390548856696114, 0.14793516107602045, 0.11878049816004932, 0.1289135598926805, 0.13845906330971047, 0.1269767919438891, 0.13275476783746853, 0.13932192872744054, 0.13582212355686352, 0.15818143001524732, 0.24610522377770394, 0.16425964917289093, 0.09150139827397652, 0.07675758824916556, 0.1284365964238532, 0.14252251479774714, 0.11485465569421649, 0.1242908407584764, 0.0915168052597437, 0.22280447330558673, 0.16690737975295633, 0.16416740021668375, 0.18952539889141917, 0.10690525959944353, 0.1369927279301919, 0.12511726672528312, 0.09143154733465053, 0.21223960036877543, 0.1876833289861679, 0.10144047744688578, 0.15261704422300681, 0.13540331477997825, 0.17827007628511637, 0.08460694283712655, 0.17690498469164595, 0.1927507875370793, 0.12428191272192635, 0.10645746253430843, 0.11397984169889241, 0.0698121398454532, 0.14953616657294333, 0.15328655048506334, 0.15062057791510597, 0.14062720321817324, 0.1444861336494796, 0.19265323964646086, 0.1951974703115411, 0.2279467403423041, 0.23436382412910461, 0.1827652647625655, 0.10867142264032736, 0.12362083725747652, 0.12363640751573257, 0.11513544726767577, 0.12659477884881198, 0.0891048030462116, 0.1704362325835973, 0.2417531659011729, 0.10076144943013787, 0.30057464784476906, 0.1636411136132665, 0.10029302808106877, 0.11517825434566475, 0.18614371394505724, 0.09477145678829402, 0.10961267369566485, 0.06936446152394637, 0.11340754936099984, 0.13860219391062856, 0.1214275236998219, 0.10910901517490856, 0.09025853840284981, 0.23918909020721912, 0.1470416152733378, 0.15423065138747916, 0.21998233802150935, 0.10963463384541683, 0.21463932003825903, 0.2379166631726548, 0.09703497009468265, 0.17150247615063563, 0.09204488043906167, 0.14142596191959456, 0.06682453531539068, 0.15655844210414216, 0.13846504501998425, 0.22461607062723488, 0.10973146185278893, 0.19629147020168602, 0.17599132668692619, 0.12991930358111858, 0.21084694541059434, 0.13932985486462712, 0.2100020251236856, 0.09452581332880072, 0.15907009248621762, 0.14528670319123194, 0.1200518936093431, 0.1802094714366831], [0.020725340327771846, 0.03390886093256995, 0.033595292406971566, 0.015026915243652184, 0.01386861289574881, 0.017630766342335846, 0.030734454121557064, 0.05880054595763795, 0.09442207592655905, 0.03310192747449037, 0.018058063433272764, 0.02770554907328915, 0.105784616607707, 0.011644163460005075, 0.04647310939617455, 0.01709008949546842, 0.04464760793780442, 0.026512568947509862, 0.023585865055792965, 0.04432608729985077, 0.03003485191584332, 0.05124212068039924, 0.07795001176418737, 0.11470940997241996, 0.05249407186056487, 0.021248359626042657, 0.027966024354100227, 0.024255512325908057, 0.06866073483251967, 0.0461570546758594, 0.04838029904931318, 0.06743272533640265, 0.02275207698403392, 0.020344726181065198, 0.033552589229657315, 0.03829404085990973, 0.04594129750330467, 0.055987902742344886, 0.06395531818270683, 0.045859290185035206, 0.1187230485084001, 0.00891110445081722, 0.013499078086169902, 0.030002715066075325, 0.027525166369741783, 0.03508815214445349, 0.01962520844244864, 0.0015262563829310238, 0.057227330180467106, 0.07409710015053861, 0.008240160277637187, 0.012907217169413343, 0.09319354692706838, 0.090805419604294, 0.03006175291375257, 0.0675760860031005, 0.019264977381681092, 0.06438977885409258, 0.031220983873936348, 0.03797715122345835, 0.010980240931530716, 0.010641041408234742, 0.05666635559464339, 0.09921433127601631, 0.026556813936622348, 0.05462809895107057, 0.05109422549139708, 0.011236783757340163, 0.017956708325073123, 0.010909449320024578, 0.0175491542177042, 0.025469899701420218, 0.029460487130563706, 0.055951774993445724, 0.035785919390036725, 0.019730801213881932, 0.04983189908671193, 0.04666942601033952, 0.06577946522156708, 0.040932219999376684, 0.00947407634157571, 0.07144253439037129, 0.06782592259696685, 0.017143607619800605, 0.01745289766404312, 0.05925585355726071, 0.03883223151206039, 0.07887367391958833, 0.046300485846586525, 0.047041728103067726, 0.0536885696783429, 0.03917981266567949, 0.03301069897133857, 0.06861323738121428, 0.07940688476082869, 0.07095003777067177, 0.031073784448381048, 0.04130474844714627, 0.01812466562114423, 0.06248779536690563, 0.0023918925626276177, 0.17423585057258606, 0.03357008165039588, 0.051915753283537924, 0.025652427211753093, 0.018419606240058783, 0.0395272824971471, 0.054834245311212726, 0.06610550553887151, 0.015847062641114462, 0.06360601895721629, 0.009199079086101847, 0.06289245880907401, 0.021112075337441638, 0.02389657631283626, 0.04719640652183443, 0.04258972519892268, 0.04550174569885712, 0.031045059622556437, 0.035842645447701216, 0.079603746853536, 0.028998542875342537, 0.01880783667729702, 0.07569694047560915, 0.022575004259124398, 0.005725377104681684, 0.019785944641625974, 0.012419243012118386, 0.03265249397372827, 0.06690193389658816, 0.04140688652114477, 0.07300653640413657, 0.04466518199478742, 0.028055705479346216, 0.01455582030757796, 0.01656380289205117, 0.0486709760298254, 0.013033966715738643, 0.08510935454978608, 0.06728815496899188, 0.031252918488462456, 0.027281628754280973, 0.025258181667595636, 0.038643670341116376, 0.028810937219532207, 0.13424767210381106, 0.044508559149107896, 0.014310218593891477, 0.037101131238159724, 0.022741963366570417, 0.050599450478330255, 0.012999459631828358, 0.0520684464572696, 0.03281691679148935, 0.0026965033657688764, 0.037215006377664395, 0.017783656185201835, 0.012589388716151007, 0.04851821606280282, 0.03769154311157763, 0.04299275220546406, 0.028188837495690677, 0.05400983056460973, 0.0007033247720755753, 0.04602283355779946, 0.07195733254775405, 0.03582957622711547, 0.048973301018122584, 0.04055564684676938, 0.09519392435322516, 0.02182210471801227, 0.03503330372041091, 0.023249705554917455, 0.03914194829121698, 0.038425456659751944, 0.03800102240347769, 0.06973039970034733, 0.046912063771742396, 0.028843717882409692, 0.052826836035819724, 0.021335330056899693, 0.01348777796010836, 0.022920418341527693, 0.06844628383987583, 0.059700537312892266, 0.018624670919962227, 0.021855056074855383, 0.03510861315589864, 0.01359297089948086, 0.030761676098336466, 0.05105577482027002, 0.011090243915532483, 0.018893152118835133, 0.021066674453322776, 0.01999919335503364, 0.04814791776880156, 0.02571587156126043, 0.029510313070204575, 0.006230051440070383, 0.10896891995798796, 0.05611482112726662, 0.014996623558545252, 0.010761533721961314, 0.04125191495404579, 0.06121612532297149, 0.013573041451309109, 0.04358893056632951, 0.041654979067971, 0.007587541585962754, 0.025466864317422733, 0.023321185508393683, 0.06306445895461366, 0.017717443624860607, 0.04496870926232077, 0.07002488389844075, 0.10546030549448915, 0.08157523247064091, 0.06859273184090853, 0.08065219371928833, 0.06883666836074553, 0.016013834356272127, 0.01389525321428664, 0.056490629867766984, 0.04662968771299347, 0.0536458553688135, 0.12024706360534765, 0.041001844583661295, 0.02950102509203134, 0.10339466360164806, 0.029375245903793257, 0.015229938089760253, 0.041558336597518064, 0.05173855439352337, 0.05199888124479912, 0.10745177714852616, 0.026868007589655463, 0.03586862803786062, 0.034660927412915044, 0.032888764108065516, 0.06985897678532638, 0.035510330271790735, 0.13238436193205416, 0.02886222704546526, 0.06783424949389882, 0.026665455079637468, 0.02271070596179925, 0.0435897729039425, 0.004103669862161041, 0.01452948334190296, 0.020763807697221637, 0.07051668289932422, 0.044298104621702805, 0.05053964821854606, 0.025079453953367192, 0.03706351919390727, 0.03271958041295875, 0.04886383794655558, 0.02304553330759518, 0.0865315024566371, 0.08101711515337229, 0.009868237466434948, 0.04015836777398363, 0.04447647610504646, 0.023147912579588592, 0.024506974223186262, 0.05105877680762205, 0.01983732723601861, 0.03215400822227821, 0.02748669528955361, 0.053708266277681105, 0.06416573931346647, 0.014283891832747031, 0.01905907778564142, 0.05737728482927196, 0.03838529904896859, 0.04409894558193628, 0.004774848275701515, 0.06615526654059067, 0.029505446436814964, 0.023049572446325328, 0.018463843807694502, 0.062291541835293174, 0.01607663303730078, 0.032736876164563, 0.04904882938717492, 0.03868780215270817, 0.0472484236524906, 0.040953979769255966, 0.03738550738489721, 0.0449192822270561, 0.03465985500952229, 0.004691213334808708, 0.03649917525763158, 0.02010780110140331, 0.06351198142510839, 0.008327290270244703, 0.06644975816016085, 0.02987854262755718, 0.06362946340232156, 0.0456067447521491, 0.023838607157813385, 0.052580795527319424, 0.025339806779811624, 0.06718757911585271, 0.03098204015259398, 0.059994798866682686, 0.046400816790992394, 0.02230681806395296, 0.011150319842272438, 0.0320929925510427, 0.018468829184712376, 0.04290783566830214, 0.013438760033750441, 0.03587224600778427, 0.061646170215681195, 0.050658469772315584, 0.06036331229552161, 0.05187453811231535, 0.026484237459953874, 0.08693864467204548, 0.017186514887725934, 0.039725751339574344, 0.03661939947050996, 0.04297419480280951, 0.027393086347728968, 0.03816413533058949, 0.0372159340622602, 0.012027351003780495, 0.050889340782305226, 0.0706018740311265, 0.020327105739852414, 0.04811952690943144, 0.0489744699007133, 0.06437572999857366, 0.00495489933200588, 0.03535716583428439, 0.046093048149487004, 0.042347272974438965, 0.05126292679051403, 0.04918232691125013, 0.03209732298273593, 0.05882439116248861, 0.07399795664241537, 0.04453727655345574, 0.014981836266088067, 0.04587663788697682, 0.036848378003924154, 0.0635501797660254, 0.012747353921440663, 0.034409988729748875, 0.056753791723167524, 0.030968358660175, 0.12225314814713784, 0.15085140068549663, 0.14302368712378666, 0.16374903672840446, 0.10289833007846028, 0.1211101071385201, 0.09983717871364206, 0.19835783197777346, 0.15131868654862046, 0.07505131652578712, 0.10825965684489347, 0.09829962684307247, 0.25796545611228794, 0.0687745506002102, 0.20340695948107168, 0.11407389407395385, 0.14269237755797803, 0.11541718879016116, 0.08695679760421626, 0.14080312190344557, 0.16860934701981023, 0.24403256858931854, 0.08930054449592717, 0.3087543323636055, 0.24732915888307616, 0.07774107492878102, 0.11620099321589805, 0.15407692291773856, 0.16973702557152137, 0.081469023716636, 0.1680466061225161, 0.15519268257776275, 0.0801698571012821, 0.10238412563921884, 0.12146856446634047, 0.08974828218924813, 0.12466216692700982, 0.1708897144999355, 0.14096741855610162, 0.22100611589848995, 0.23423837148584425, 0.10938528706901707, 0.1636185820098035, 0.08927071015932597, 0.08404173800954595, 0.12687387090409175, 0.20363188959890977, 0.10282774441293441, 0.17032192699844018, 0.2726948313647881, 0.15422177530126646, 0.14956270577386022, 0.2971537923440337, 0.2182050427654758, 0.11204530761460774, 0.14666390663478523, 0.12139449812821113, 0.20747996983118355, 0.12356192557490431, 0.16179842030396685, 0.11317194715957157, 0.09250798058928922, 0.18017677241005003, 0.3175253007793799, 0.15301346982596442, 0.2071368452743627, 0.12803435238311067, 0.16920125432079658, 0.1536846236558631, 0.09523540298687294, 0.13820423948345706, 0.10490426619071513, 0.1671289702062495, 0.13796802872093394, 0.20852415676927194, 0.15861603169469163, 0.1256685340194963, 0.11738075569155626, 0.22181802545674145, 0.2141060127178207, 0.08733917435165495, 0.17558347200974822, 0.18464558495907113, 0.15506268799072132, 0.1122151110030245, 0.15061082609463483, 0.2832883066730574, 0.19317183759994805, 0.1338198091252707, 0.0937555605196394, 0.15866666100919247, 0.10821250078151934, 0.13731821905821562, 0.16007864149287343, 0.15231053723255172, 0.07375030196271837, 0.11671657062834129, 0.1531280277413316, 0.1899157091975212, 0.1697393410722725, 0.09465568175073713, 0.2749773213872686, 0.12651642289711162, 0.09083189943339676, 0.07987258984940127, 0.08564965290133841, 0.1426381414057687, 0.10317446838598698, 0.17707750434055924, 0.08474369096802548, 0.14624325733166188, 0.16873640270205215, 0.13877768215024844, 0.22925400378881022, 0.12554796470794827, 0.0856959109660238, 0.1291376439621672, 0.1256481249583885, 0.11551288131158799, 0.0914200885745231, 0.15381804696517065, 0.07650023369933479, 0.21174187160795555, 0.22150172211695462, 0.12009337966446765, 0.06956398050533608, 0.11000172977219336, 0.18966784671647474, 0.08367724702111445, 0.14999196399003267, 0.1470250653801486, 0.14031918224645779, 0.13498950807843357, 0.10371451440732926, 0.08866430129273795, 0.07877909461967647, 0.11328228225465864, 0.14633221115218475, 0.26123604155145586, 0.10439413614221849, 0.16106773138744757, 0.14176126423990354, 0.09161096153547987, 0.20530605601379648, 0.11726092852768488, 0.27409481874201447, 0.08750259527005255, 0.17738389258738607, 0.1208006389788352, 0.09261828599846922, 0.09194421552820131, 0.13848058559233323, 0.17802553862566128, 0.1386931663728319, 0.07271128779393621, 0.12343922629952431, 0.1795640107593499, 0.12014483276288956, 0.21103712817421183, 0.14738131110789254, 0.12632632919121534, 0.0921320753695909, 0.10833050226210617, 0.21970234054606408, 0.107476156699704, 0.13318938435986638, 0.18962155154440552, 0.09498276849626563, 0.13791094272164628, 0.1212568000482861, 0.09974026164854877, 0.15306874498492107, 0.0958317334880121, 0.08085508947260678, 0.2174814636236988, 0.21383493585744873], [0.028288982903177384, 0.06884434958919883, 0.018724218898569234, 0.028328760163276456, 0.1033472700510174, 0.012116912457713624, 0.012123440574214328, 0.05822588616865687, 0.022776204205001704, 0.04640125094738323, 0.035090133678750135, 0.034663899714360014, 0.0464862008811906, 0.024198738028644584, 0.05756148588261567, 0.05526452398044057, 0.028414170228643343, 0.028239845305506606, 0.07205904388683848, 0.03019812811544398, 0.024198693499783985, 0.03131775993097108, 0.01002475826680893, 0.07968424761202186, 0.05100699345348403, 0.09666903933975846, 0.032100562457344495, 0.07909551670309156, 0.02364723324717488, 0.04545444120594766, 0.03512077695631888, 0.05150992838025559, 0.03196046352968551, 0.07862630867748521, 0.017525405492051505, 0.022088810328568798, 0.040062404368654825, 0.03615809902839828, 0.04994589296984486, 0.05679523696016986, 0.007459224252670538, 0.018441609063302167, 0.05344095581676811, 0.06149928805825766, 0.007810201659594895, 0.028125085154897533, 0.03999378539447207, 0.052910769227310084, 0.015905686741461977, 0.053244542723405175, 0.1027760464057792, 0.02788065881759394, 0.049034353796741925, 0.029582934075733647, 0.027625306211120915, 0.044017212858307175, 0.02793791180010885, 0.07038375682896003, 0.03456398437265307, 0.09683885014965199, 0.02372242208366515, 0.0037823716365892324, 0.005458423338495777, 0.05875703012861777, 0.03585710990591906, 0.03480652565485798, 0.08151646179612726, 0.013708701408177149, 0.06192616398038808, 0.01882578737422591, 0.02842835081537487, 0.03781721097766422, 0.02586875212728046, 0.05976310036203358, 0.029855409884476103, 0.027916569488297682, 0.026843472187465522, 0.03602228971431032, 0.04758859446155839, 0.024177614650398027, 0.041209074479411356, 0.07260577665874735, 0.01681985868344782, 0.01737343962304294, 0.03460580439423211, 0.008525319390173536, 0.050720576400635764, 0.023302943518501706, 0.031572413063258864, 0.01748140170093393, 0.01073304638339323, 0.03133617632556707, 0.03692971367854625, 0.03673015387903433, 0.06836627289885655, 0.015619855985278264, 0.007271656168086338, 0.04444281599717215, 0.09530843773973174, 0.01945634572621202, 0.036814710474573076, 0.15173277526628226, 0.023705541934759822, 0.04797735367901623, 0.03384680996532552, 0.0016904469316614268, 0.04136875497351866, 0.0545314416376641, 0.07581623329315335, 0.08725503706955351, 0.06812851846916601, 0.05365279073885176, 0.03461829845036846, 0.008758657113503432, 0.06681128055788577, 0.024941505398601294, 0.05399056441092398, 0.03791706323681865, 0.057218298243242316, 0.059186306898482144, 0.008926244263420813, 0.04814943917153869, 0.05610309148323722, 0.02698148939089151, 0.04514552594628185, 0.07106109274900518, 0.0262348053365713, 0.0766136561287567, 0.025456494659010787, 0.03562803860404529, 0.035877518967026845, 0.04211343337374274, 0.02670933085028082, 0.05645988268952351, 0.011948456067329971, 0.05939146249147598, 0.04552086342300754, 0.0255908549297601, 0.024864370279829018, 0.08180546894436702, 0.08037943960516714, 0.044547688885359094, 0.014403020450117765, 0.023557438944408204, 0.027502525299496483, 0.06459298630943522, 0.012131164476159029, 0.008853108392941067, 0.10132180803338997, 0.030177572480170056, 0.030970661173341796, 0.021131521461938974, 0.05339679803000763, 0.032545728608965874, 0.034319535770919174, 0.02477711041137809, 0.017330409900750965, 0.03484886517981067, 0.04261487287294585, 0.0017988952322411933, 0.0035361590425964096, 0.028644538433582056, 0.07362052259850316, 0.03981409659900237, 0.03152153884002473, 0.0839186750818044, 0.06833044943050481, 0.03724269961821847, 0.03546533014741726, 0.08691512601217255, 0.055912125753820874, 0.012835062789235963, 0.07190918200649321, 0.03262369122239761, 0.02838204636645969, 0.04934112053888384, 0.06745598424458876, 0.002029330694313103, 0.004025263815492508, 0.02304940360772889, 0.035105785573250614, 0.034672760957619175, 0.03634258951933589, 0.030585625681851525, 0.023480060772271827, 0.012390265856083715, 0.022060855480958708, 0.04247290002240334, 0.06364352710079402, 0.02060324404737912, 0.008617427338322159, 0.032022184241213836, 0.030327814711199608, 0.07433037942973897, 0.04257120119291358, 0.036672570640803315, 0.02771918232610915, 0.006032050150679424, 0.03134936428978108, 0.03370454396645073, 0.0392012124939356, 0.03659021822386421, 0.039713231308269314, 0.032618819022900425, 0.03711660501721781, 0.07560557467513718, 0.07868836706620641, 0.017834688114817254, 0.032984723802655935, 0.07630610271007754, 0.024963710457086563, 0.03397616630536504, 0.04307098199205939, 0.023703686565568205, 0.0055893284479680005, 0.08473427311400883, 0.017731266125338152, 0.031959561820258386, 0.03899086557794362, 0.06538393761729822, 0.05509951486601494, 0.02611377032735618, 0.06492414744570851, 0.06705975160002708, 0.05008157982956618, 0.029146258093533106, 0.031310664999182336, 0.05678181893017609, 0.028060557269782294, 0.05805265034723561, 0.012431387331162114, 0.044855999294668436, 0.06130600311735179, 0.029884860159654636, 0.03737444567377679, 0.056678304172237404, 0.022093469160608947, 0.034953960712300614, 0.006792986687287339, 0.04055465979035944, 0.027201291268283967, 0.028744271949108224, 0.03345095581607893, 0.0180855433063698, 0.011676909798552515, 0.011864192620123504, 0.02745746765867807, 0.009890127112157643, 0.05193622913793661, 0.024898371775634587, 0.05800222141260747, 0.008576928339607548, 0.028760441491613165, 0.06744077763869427, 0.017152635846287012, 0.02729900985286804, 0.022040147705411073, 0.023209061837405898, 0.037058042144053616, 0.029852207517251372, 0.045280797203304246, 0.034695322246989235, 0.06108897316153161, 0.022738538355042692, 0.030645437218481675, 0.04702876649389509, 0.02384495994192548, 0.02978122665808769, 0.01898638813145226, 0.015459833175555104, 0.03789362250245176, 0.019770162871282082, 0.11586175751290284, 0.048720547783887014, 0.01814116727473447, 0.05292678106343374, 0.042462261335458606, 0.07907861057901755, 0.03470117037068121, 0.08094897857517935, 0.00916575201699743, 0.012028816745441873, 0.09640173258958384, 0.024506905574526172, 0.013310240465216339, 0.029547118028858677, 0.0883030534896534, 0.012115493100282038, 0.05710498342523351, 0.01238511906194617, 0.04149187727307435, 0.029285941418493167, 0.008295572733914014, 0.04068315523909405, 0.029653373167093378, 0.046227592101786286, 0.05124880372022744, 0.02743760407611262, 0.08178512667655014, 0.04857778454606887, 0.0020273816289773094, 0.050482502847444266, 0.04313409794121981, 0.08332342069479637, 0.04664489802962635, 0.08458137584966607, 0.013380915188463405, 0.027393103046051692, 0.05256667616777122, 0.014908089051459683, 0.023184029196272604, 0.019132735942548607, 0.021288565476424992, 0.08059289611992426, 0.005870087088624132, 0.05177620354515966, 0.10386477704741992, 0.03168031391396653, 0.047708102501928806, 0.021794949534523766, 0.060437760839704424, 0.027974306722171605, 0.060800522624049336, 0.05386921955505386, 0.05286841114866547, 0.04450334185094107, 0.05037811235524714, 0.027482734076329507, 0.044307526186457835, 0.017283012639381923, 0.0359646396827884, 0.029440382350003347, 0.062192632103688084, 0.03836175812466536, 0.03317320333735552, 0.016339408975909464, 0.027894318045582622, 0.0654910146840848, 0.0018204766547569307, 0.03595168920583092, 0.02106843334331643, 0.06040071282768622, 0.026672407147998456, 0.02725754791754298, 0.013540888830902986, 0.05943600619502831, 0.02806469659844879, 0.015691042790422216, 0.04292756195354741, 0.05939511756878346, 0.038978698066785, 0.024298679345520213, 0.11070761611335911, 0.1295776930055581, 0.06632148535572924, 0.143670350080356, 0.12175402414868586, 0.06298258522292599, 0.12850257335230708, 0.1283560585579835, 0.0981426403450314, 0.10828733153175563, 0.16436132340459153, 0.14590728707844391, 0.15024604566860944, 0.07050126849208027, 0.15231941331876442, 0.11814103403594345, 0.2529481815872714, 0.21862690919078887, 0.13046163541730493, 0.07460501117748208, 0.10313762817531824, 0.09311406291089952, 0.1105157783604227, 0.13586031447630376, 0.09208629970089532, 0.13355901843169704, 0.19761699048103765, 0.21968485554680228, 0.13039846380706877, 0.2613622660282999, 0.23283151182113215, 0.1976670854492113, 0.13042994571151212, 0.15242460533045232, 0.13000852457480505, 0.16929826786508784, 0.1495125365909189, 0.09835010030656122, 0.13625625026179478, 0.220235692395363, 0.11530019663041458, 0.134359187213704, 0.0912456022342667, 0.24898784409742802, 0.19155744375893846, 0.11213111472898163, 0.19289653049781919, 0.14404826652025804, 0.2212257173960097, 0.14478797995252535, 0.2032396348658949, 0.13848106056684628, 0.164427790150512, 0.12415729128406383, 0.1672994563705288, 0.11442443268606439, 0.16971433069556952, 0.15897276723990217, 0.13324134954018518, 0.20113313774345443, 0.09735807150718756, 0.11140978429466486, 0.07227641151985154, 0.14780249475734308, 0.10368131814175285, 0.10988233305397443, 0.15553610399365425, 0.07613163121277466, 0.11341439938405529, 0.15409066749271005, 0.10723548562964424, 0.2143094947678037, 0.14868572470732033, 0.18087404983816668, 0.11345758495735936, 0.13489984179614112, 0.1049526764836628, 0.19968206092016771, 0.1164535089628771, 0.10873365172301419, 0.11257600257522427, 0.1363059741561301, 0.234525790438056, 0.12127229609177448, 0.09366547863464803, 0.2088875271147117, 0.1631218774127774, 0.12451084301574156, 0.13639635290019214, 0.11862963438034058, 0.2094490805757232, 0.10006790500483476, 0.13547978567657992, 0.19986758299637586, 0.12099553438019939, 0.10022715505328961, 0.2020897067268379, 0.1794037810759619, 0.2046592000988312, 0.09522744716377929, 0.1424567011417821, 0.19875773083185777, 0.11799791085650213, 0.15540941938525066, 0.1147663920710329, 0.0849024586204905, 0.1717722023022361, 0.16460259561426938, 0.18227927677799016, 0.21218570560449734, 0.31870804668869823, 0.13667390128830448, 0.1861016044858843, 0.08777350885793567, 0.16506314277648926, 0.23813909967429936, 0.14107253635302186, 0.08487878410960548, 0.16438364720670506, 0.1520860820892267, 0.1263426712830551, 0.13880226208129898, 0.17256392544368282, 0.06989282614085823, 0.14630720077548176, 0.1645190891576931, 0.12047479161992669, 0.2645023522200063, 0.1412409741897136, 0.15655226743547246, 0.08745569895836525, 0.1751377826440148, 0.16008673090254888, 0.1276228908682242, 0.06303941147052683, 0.09726036776555702, 0.23171564826043323, 0.1493364991620183, 0.09410359067260288, 0.19990675355074927, 0.2512839302653447, 0.15735979832243174, 0.14193819224601611, 0.10345321905333549, 0.1539018502808176, 0.1207829535997007, 0.1687230885727331, 0.125940160069149, 0.19770241167861968, 0.12414142416673712, 0.16458699567010626, 0.10875537438550964, 0.10138562531210482, 0.11663287121336907, 0.15192105813184753, 0.1588624544092454, 0.0964222158654593, 0.19442348449956626, 0.09848330097156577, 0.07816808443749323, 0.1585932626039721, 0.14730001625139266, 0.15132067550439388, 0.1347890985198319, 0.08705640866537578, 0.23585234972415492, 0.14321851573185995, 0.13318551034899428, 0.09429194033145905, 0.2332053316058591, 0.07229548471514136, 0.14914786006556824, 0.17391877539921552, 0.27592278784140944, 0.07151548750698566, 0.12257120295544155], [0.061934739496791735, 0.04569280790747143, 0.07096799774444662, 0.0453272185404785, 0.06347078480757773, 0.03333403787110001, 0.02586402650194941, 0.028254220706003252, 0.020977292042516638, 0.022982220689300448, 0.038912865857128054, 0.05429163888038602, 0.0460957718314603, 0.0070299971139320405, 0.016478270372317638, 0.05377688896260224, 0.027757252646551933, 0.04742771168821491, 0.005293922595228651, 0.056118988286470994, 0.005710882032872178, 0.06274730956647545, 0.009699998154246714, 0.059144787446712144, 0.021626402231049724, 0.028768185802618973, 0.02374405383307021, 0.026639136667654384, 0.06751252847607248, 0.03277434349001851, 0.0616528309910791, 0.04091483147931285, 0.0014855036624794593, 0.02842478294041939, 0.027698960657289717, 0.08717265867744572, 0.03309291038021911, 0.07595085888169706, 0.05166386836208403, 0.05129716948431451, 0.020328068676462863, 0.041096334825851955, 0.021397998862084933, 0.06516873705550097, 0.011379916213627439, 0.0536755338544026, 0.05986341646348592, 0.01612498952454189, 0.015788720556884073, 0.04511737257416826, 0.09264194566640072, 0.022951714709051885, 0.03666406562842894, 0.014872227548039518, 0.041164994618156925, 0.025377817728440277, 0.027751298766816035, 0.022475159421446733, 0.01977019441255834, 0.1291464309906587, 0.08383248205063865, 0.04026170070574153, 0.051367740306886844, 0.04761197582411114, 0.02139409330993658, 0.0487967515073251, 0.031234461275744252, 0.04958201796398498, 0.044838291651103646, 0.021746761885879096, 0.03502944084175397, 0.03435400481976103, 0.028301423153607175, 0.030253119402914308, 0.03106919797573937, 0.04353427510068286, 0.010819706967595266, 0.05403872979513835, 0.05069849379651714, 0.02475294237228809, 0.045239459577715024, 0.016360940535378177, 0.031142735533649102, 0.039967316697584465, 0.04550046920485329, 0.020416675542946905, 0.04444279744348023, 0.046313072671182454, 0.05616827060293872, 0.0157957078772597, 0.017329584261460695, 0.005542818516914849, 0.054626132259727456, 0.01223900873810635, 0.029925323906354606, 0.04916143174341414, 0.042671702831285074, 0.02647901088494109, 0.022978339256951585, 0.009583847404428525, 0.043996395615977235, 0.02312493568751961, 0.02536005442379974, 0.0484935878921533, 0.021044487948529422, 0.0636008387664333, 0.01960574747499777, 0.05036416740040295, 0.042759892239701, 0.06916049707797356, 0.047894674717099406, 0.07794264965923503, 0.040503626005374826, 0.02864926034817472, 0.10942790861008689, 0.024934703615144826, 0.01095443181839073, 0.02926708901213715, 0.035151516713085584, 0.030030347079446074, 0.017838476778706536, 0.02848378924682038, 0.026008168279076926, 0.024256603282992728, 0.013829758681822568, 0.023931846881168894, 0.023830781210563146, 0.03205178109055851, 0.03584728387068026, 0.07259306366904639, 0.02356032589887036, 0.022186065070854966, 0.029769055436190683, 0.0616343292495003, 0.04699418983364012, 0.029726185275649186, 0.07234118616906926, 0.0645145338785369, 0.05690367586794309, 0.030864231630403083, 0.025842407740128692, 0.05657982488628477, 0.05809470785607118, 0.03709489348693751, 0.09378125367220491, 0.01124680367865949, 0.04851205252634827, 0.014383852630999172, 0.03377460270712618, 0.04725685816083569, 0.11707627476425841, 0.03724123758729547, 0.018601328520162497, 0.013539827559725381, 0.05252379487501457, 0.004093038596693077, 0.04073126496223267, 0.022676413173030596, 0.044465202881838195, 0.03836158743069973, 0.045249203976709396, 0.017000347143039107, 0.012204952508909628, 0.02759207840426825, 0.06608273644815199, 0.07035562943201512, 0.018641001879586838, 0.0646037697151769, 0.04746049606183078, 0.012206173341837712, 0.019294442499813158, 0.03640376846306026, 0.08670613722642884, 0.014160629452817375, 0.031177794589893892, 0.07593036076286808, 0.08907493160222657, 0.07160863446188159, 0.00644896784251614, 0.02490751132427249, 0.03426213806960732, 0.04948169444105588, 0.07544035775936209, 0.016264483601844404, 0.13571618939749897, 0.02184374945500167, 0.023379533158731647, 0.041946023411583155, 0.034522910209489055, 0.021242331531539094, 0.03147742558212485, 0.08103822925477289, 0.03740045794984326, 0.04590273179928772, 0.058296787246945314, 0.03590784312109463, 0.02876064372685505, 0.03795882388658356, 0.023073595766618382, 0.021449605956149753, 0.03618636001192499, 0.09887539243209176, 0.05772818338300567, 0.06737083022017032, 0.06259191868593916, 0.06724912542267703, 0.0825535983312875, 0.020719841013487894, 0.043740599576267414, 0.008078400842350675, 0.021983492151775863, 0.06850877267424949, 0.042658770908019505, 0.0637902422749903, 0.07611081397044472, 0.028224063535162713, 0.025947942995117046, 0.026464468501217198, 0.09439601170015521, 0.03132883648504503, 0.02249857974675251, 0.02278962409036467, 0.02298717081430368, 0.01923734165757196, 0.06555420855875127, 0.05743713161791675, 0.062310466601047665, 0.026490460368222557, 0.027922807239519898, 0.04325815163610969, 0.03845539118628949, 0.0213898612128105, 0.03473409575235564, 0.02389871184277581, 0.024351891333935782, 0.0796071533113718, 0.03536215306667145, 0.06646615962381475, 0.026629639032762498, 0.08111922725220211, 0.04980653618986253, 0.06520227470900863, 0.047548533329973, 0.010191340734309051, 0.034817928753909655, 0.026590104826027527, 0.020379313973535318, 0.0319255417707609, 0.030301956430776045, 0.01377412079818896, 0.07200642561656423, 0.018442549735482316, 0.015651150497433264, 0.029617278814839665, 0.005443058562377701, 0.0596001618396258, 0.02325608060345985, 0.021563334521488287, 0.051117191251250915, 0.0787359313108027, 0.029925861963420175, 0.04186847269011196, 0.03127673400740605, 0.05793619995529298, 0.07579029523185454, 0.06640596402576193, 0.007648625905858353, 0.02119593060342595, 0.047170965699478984, 0.0545933664398035, 0.02422258137812605, 0.030352359390235506, 0.05298282434523571, 0.02051919396762969, 0.03543131380865816, 0.0750754882756155, 0.042043556459248066, 0.048447919834870845, 0.043652473250404, 0.02668006425665226, 0.0669834142900072, 0.037141734137549065, 0.01075917090929579, 0.04973951283318456, 0.016592989704804495, 0.04729408428829629, 0.03158206840453204, 0.033847251543193124, 0.07623527955729514, 0.04120045814488549, 0.044670284260064363, 0.03231356626201887, 0.03349894679558929, 0.04686009116994683, 0.009026725492731202, 0.01951471007487271, 0.028738581531797536, 0.04170909276581369, 0.006696666587231448, 0.008943720913521247, 0.08857364795403555, 0.017040925922628958, 0.040258787776110694, 0.04006189599749632, 0.07251990275108255, 0.06785396835766733, 0.07798282953444868, 0.05900497053517029, 0.01538816211905214, 0.06001552705129143, 0.016484151892655063, 0.009978109646908706, 0.01850717224442633, 0.08920140098780394, 0.09362977390992455, 0.04329070965468418, 0.05108258490508888, 0.023669991205679253, 0.06762501579942182, 0.04649906972190365, 0.050171899201814085, 0.02560700220783474, 0.022027592422091402, 0.016239456526818685, 0.0340340501134051, 0.026839342135644984, 0.08283093891805038, 0.01671654430538183, 0.006314688744168961, 0.0357136861566687, 0.011789551117544761, 0.017289936877205037, 0.03275633527664468, 0.07872438349295408, 0.033054222221835516, 0.03241113641706761, 0.05984617266221903, 0.0618511328502791, 0.012715153061435558, 0.03537177872203756, 0.0336354759929236, 0.027592115511652082, 0.04221924507874064, 0.011566070970729925, 0.035167688110959716, 0.03148090254398994, 0.04289418757252861, 0.05953318301180843, 0.03457653408986516, 0.09847820983850397, 0.03160604348522611, 0.015022157149360282, 0.2629875991260633, 0.11518100771354511, 0.20785724802408367, 0.14716706791659817, 0.11662838864140213, 0.14752879069419578, 0.1996663273894228, 0.16716474172426388, 0.18966403207741678, 0.09957589078112505, 0.11689482707879506, 0.12990941817406565, 0.22076800523791462, 0.10847764788195491, 0.17663200793322176, 0.2298327602329664, 0.10030593402916566, 0.13151459454093128, 0.14267277001636103, 0.12733281502733007, 0.1081839800463058, 0.17345125204883516, 0.08944386805524118, 0.13043233542703092, 0.09587457025190815, 0.21540233690757304, 0.10479965305421501, 0.20424954942427576, 0.15780174726387486, 0.2221745828865096, 0.15376728406408802, 0.1336270140018314, 0.08629437143099494, 0.07510881070629694, 0.14725287503097206, 0.13210029748734087, 0.12079936248483136, 0.28195953578688204, 0.18813930451869965, 0.10826071069459431, 0.1635354763129726, 0.17785566102247685, 0.12254373606992885, 0.18190401722677052, 0.10578921050182544, 0.1438686074106954, 0.12578470981679857, 0.104499150038464, 0.14008083409862593, 0.2802950469776988, 0.28162797389086336, 0.11737117456505075, 0.1296908556832932, 0.1367129827849567, 0.12158787954831496, 0.09888093627523631, 0.12121465348172933, 0.13202066504163668, 0.15299458958907053, 0.23645169334486127, 0.18971844634506851, 0.12363195462967269, 0.1194738941558171, 0.12477274693083018, 0.16914814623305574, 0.1801444444572553, 0.15776748972712085, 0.11840852632303722, 0.10278181289322674, 0.10418367790407501, 0.10235944922897033, 0.07469252523151226, 0.08826861783745699, 0.10611732141114771, 0.14548454491887242, 0.1520118079497479, 0.19723264704225585, 0.07673562809941359, 0.11160617883433588, 0.15090431581484154, 0.10673113691154867, 0.08548056197469123, 0.19607707858085632, 0.1586768581182696, 0.11554378434084356, 0.10821074931300245, 0.10276109213009477, 0.24366364697925746, 0.14296818932052702, 0.24450145749142393, 0.09249149006791413, 0.11269781869486906, 0.18488719855668023, 0.17861615458969027, 0.10711018141591921, 0.0943147020007018, 0.1224017706408631, 0.164195453398861, 0.11026382664567791, 0.08723649079911411, 0.20846665516728535, 0.11839266662718728, 0.09645593905588612, 0.09957090354873799, 0.10786599945276976, 0.19029709888854995, 0.11231918237172067, 0.13655591465067118, 0.10128616268048063, 0.1452026327024214, 0.1755867077736184, 0.20271699962904677, 0.10593522805720568, 0.0973986966710072, 0.20091044891159981, 0.13862649182556197, 0.130352821724955, 0.10824331475305371, 0.0872169723152183, 0.11682332115015015, 0.17470236460212618, 0.1767915251548402, 0.17559816653374583, 0.07943542033899575, 0.09784816356841475, 0.13664510595845059, 0.09435016181669198, 0.15409408137202263, 0.18181052146246657, 0.12465480482205749, 0.1055984414415434, 0.16908541991142556, 0.15974762878613546, 0.11447767436038703, 0.26855863456148654, 0.10994923024554737, 0.17739714734489098, 0.22940541675779969, 0.23653056879993528, 0.1855882757809013, 0.10791435037390329, 0.15143918164540082, 0.20645807700930163, 0.15747787401778623, 0.20608927414286882, 0.11006798871676438, 0.10328081072657369, 0.1325011908193119, 0.34530415548942983, 0.11306962725939229, 0.21985829545883462, 0.06447617968660779, 0.21292475110385567, 0.09005663712741807, 0.1154505780141335, 0.10672701799194328, 0.11927665356779471, 0.18112906662281603, 0.13612192153232172, 0.19596397527493536, 0.12759262608597055, 0.18867464532377198, 0.14346628915518522, 0.13955926755443215, 0.21608707203995436, 0.159102939942386, 0.08264257441624068, 0.16978329105768353, 0.1506500708637759, 0.10723003084422089, 0.14355833031004295, 0.12863822310464457, 0.17212172417202964, 0.21288526884745806, 0.144020302395802, 0.1284359730198048], [0.001819143803913903, 0.03507373221509624, 0.007731927807981265, 0.008095176162896678, 0.07668309888686053, 0.06678813297185116, 0.05184586152608972, 0.00988876898190938, 0.04233216655848082, 0.05956219356448855, 0.0066778113978216425, 0.03080469097767491, 0.023159464108175598, 0.020615209323295858, 0.04028228788229171, 0.04521338421909604, 0.04810537044249941, 0.035042406161664985, 0.025346771835756954, 0.04012507873994764, 0.043959536851616576, 0.04751528140332084, 0.0361315152986208, 0.016634772618999705, 0.04529577374341898, 0.03939747344702482, 0.018289680301677436, 0.05502454310772009, 0.053094910908839665, 0.04575871804263443, 0.03029214894922916, 0.028765378629032057, 0.06518758018501103, 0.030857589408697095, 0.00787469985880307, 0.050443747895769775, 0.04931511568429414, 0.022500921222672332, 0.05429734599601943, 0.09906552324537188, 0.03423559515795205, 0.006613916657443042, 0.03532213275320828, 0.025174797665385995, 0.028551551040436607, 0.034443556069163606, 0.0019527651738826535, 0.039348187419818714, 0.04646596993552521, 0.0264734095253516, 0.05984095907479059, 0.04113089664315339, 0.04120656230952591, 0.07922259464976378, 0.07173103687819093, 0.05438443702587392, 0.057802182927844115, 0.07665870449272916, 0.0018029267175734276, 0.056878398318076506, 0.04945134431181941, 0.03563200538337696, 0.08925056827138178, 0.03050598952540895, 0.050727222333080135, 0.058186711903545074, 0.010396117831987794, 0.02795391064864816, 0.00828950289360364, 0.037103302020113915, 0.04001718159997836, 0.060705802316078916, 0.06379885118803941, 0.05761481290392112, 0.09754674771102145, 0.06273075967328623, 0.03076791384955868, 0.035535782226361334, 0.07377045869361609, 0.04496228226344101, 0.03169383213389665, 0.005166436931176577, 0.03955496089474764, 0.02138966639904538, 0.04135643903282471, 0.03824022402113769, 0.03276654351793695, 0.05766368703916669, 0.011178281183674699, 0.0432527933298843, 0.04592931552906521, 0.041521949096932076, 0.02595406571344938, 0.0380606873659417, 0.03783911175560206, 0.03990244927990716, 0.025284210641984828, 0.016698884901416022, 0.019043121610593516, 0.04102151149709243, 0.03330736879433971, 0.015433561147801811, 0.12016173888696358, 0.02706473238504259, 0.016395489365095273, 0.06697153992718086, 0.057580700085964054, 0.013860327744623646, 0.04765063800732605, 0.054601492956862785, 0.04386563290609047, 0.03978309337981045, 0.02998538035171805, 0.012232291373948101, 0.005629075094475411, 0.056519217396271415, 0.03081483799178386, 0.011110785635537468, 0.06889883065014146, 0.03714599406521302, 0.07447660478646867, 0.01781088187271962, 0.02846228551788954, 0.07139480687328614, 0.01732428903778782, 0.05134031052875798, 0.014281333278631791, 0.0701566670613829, 0.042189388477709144, 0.012142994310124777, 0.02987159983604215, 0.02116490140906535, 0.047661198768764734, 0.024706333642825484, 0.04253144063113723, 0.05752273093094118, 0.004099277739442186, 0.03645429387688637, 0.014484752246062271, 0.01735818663291866, 0.06595556202228181, 0.02298096274898853, 0.039909202823764645, 0.049153724539792165, 0.058140272012678906, 0.0488555110496236, 0.06606649825698696, 0.03626088648161385, 0.09333122274256311, 0.02787044501019409, 0.04908559909381438, 0.008030591689021094, 0.06361332911183126, 0.04152384899498429, 0.026484385889489204, 0.004705603578258888, 0.05469766787427943, 0.025301361674792133, 0.03314612236863468, 0.10111774710821919, 0.007143467782952939, 0.021115270283189602, 0.0272720179418684, 0.06632954507949762, 0.016554514913877938, 0.0067218880121799884, 0.02552207082771929, 0.029249162435007747, 0.007285076053449302, 0.05536606091482099, 0.05374195607146248, 0.021163975579838734, 0.05031494074501097, 0.0235756104302709, 0.055179974806378596, 0.00706897378222493, 0.04290931625291705, 0.06004712398862466, 0.03324275370687246, 0.013225725615484407, 0.048925562368822284, 0.07060070885927416, 0.03237740580516402, 0.016124375397339463, 0.018593817985674832, 0.031221714889397845, 0.03470538205874618, 0.011072232919104863, 0.01675434559729183, 0.03232023445889354, 0.019593368451751303, 0.02886415477405535, 0.03274983406299725, 0.04936974146403372, 0.05280215962557122, 0.01750567178532947, 0.02567774929048028, 0.06095005795941688, 0.00432032178650843, 0.02006167847866891, 0.02071606162644457, 0.052846959370072, 0.022220730788831133, 0.03452800134255085, 0.0182454241803498, 0.04195767513010651, 0.05626207806926686, 0.04120127821806818, 0.01995759226701921, 0.05284017614030745, 0.06009994263877161, 0.029460735750035383, 0.05084159842226654, 0.029400465937214904, 0.0391143663728144, 0.027906967952731065, 0.08303964568767697, 0.04430880639120005, 0.049788082687882707, 0.054831169109093025, 0.02635377531987615, 0.011144555210194085, 0.03634272681665607, 0.07166928277001716, 0.03485472814645618, 0.02380095058470033, 0.06516297056805342, 0.016807423999125604, 0.028235360878170468, 0.009421735448995605, 0.005413508561105118, 0.020797048491658643, 0.04577802501444239, 0.0859660749847535, 0.04505233075178694, 0.0323568483145209, 0.056081487564370036, 0.05607477483863477, 0.05059195107605774, 0.014205311381374486, 0.052066739517613314, 0.03991318073531147, 0.05179559586395044, 0.06435275310650468, 0.020212766758049838, 0.03554728922608774, 0.07580975434393622, 0.03624502307502553, 0.044517245987663046, 0.06378912905347534, 0.047884414525469765, 0.05502757107024081, 0.13446923287119716, 0.03249552974011749, 0.02951974205643637, 0.02527514901885297, 0.04101575985259842, 0.02905599438236095, 0.06129649991635233, 0.00846852561153355, 0.05620721109153237, 0.04854326725762803, 0.04255262894730549, 0.02869896012271056, 0.04168300627497956, 0.035768337911576964, 0.04169233507127501, 0.054311190760927275, 0.042048514005728066, 0.01107486290493398, 0.05832011294842232, 0.06734822440193966, 0.021385319269029424, 0.05579762721026782, 0.04986405263480265, 0.05800551654829178, 0.03526471649820451, 0.06159695840324275, 0.04453946959984023, 0.031069153446878772, 0.023393402043438982, 0.023899014267954044, 0.07571701557026245, 0.06374387288815342, 0.009740558380144648, 0.039147685092757456, 0.01784373860573396, 0.05572372414462734, 0.057009691663552076, 0.011396912323107244, 0.032465847543790005, 0.04733311754534952, 0.008874091690813657, 0.012208617790747667, 0.0396357510908274, 0.05781680694781244, 0.04644114138500299, 0.025512422907922883, 0.009211760534526547, 0.036493275183602236, 0.00903079617273761, 0.016420794745499734, 0.027294050451018848, 0.03212994779460132, 0.01854240570537513, 0.04839542772970162, 0.04363043888588436, 0.0788017746526748, 0.052138761238893494, 0.05544416453631129, 0.03936942768632434, 0.03465186950052157, 0.0344865375518566, 0.02713708807277726, 0.04293135061743669, 0.043366794634494, 0.0595828104269458, 0.03781425722991116, 0.02992026616993826, 0.011536180973052979, 0.040008550422498956, 0.0279865911215893, 0.0837436098663602, 0.06801943760365248, 0.03127962467260659, 0.00675032711114909, 0.010160344008909306, 0.014218260930647375, 0.037579842464765534, 0.009710021786304424, 0.020267524269002024, 0.027411224436946213, 0.10345089613110758, 0.025313642363471445, 0.12614097038749605, 0.035058106295764446, 0.03608362821978517, 0.03614876281062607, 0.055288384028244764, 0.04889902687864378, 0.011666271111607784, 0.08004229675862007, 0.01717511549941264, 0.05348079059331212, 0.05934659966442268, 0.04638403683202341, 0.07526248722570017, 0.022516385724884458, 0.05759016617957968, 0.015234441070788307, 0.04287085073883645, 0.028870253372588195, 0.11742452014004812, 0.13221264380263165, 0.1772142227855511, 0.1462798600550741, 0.18714252597419545, 0.1759206593851559, 0.19277722283732146, 0.06225345110578928, 0.11803116649389267, 0.09949134531780146, 0.15022091654827818, 0.113045834004879, 0.08415761694777757, 0.06147463762317784, 0.16036554094171152, 0.13725711061852053, 0.11059968557674438, 0.09843570704106241, 0.14312568790046498, 0.1520991587312892, 0.143611082166899, 0.1996454581967555, 0.09074017740203999, 0.18719308107392862, 0.16159749124199152, 0.15058887336635962, 0.15072689799126238, 0.19756134424824268, 0.16254453104920685, 0.10658980230800807, 0.14540862321155146, 0.14666117553133518, 0.13131385843735188, 0.18764978391118348, 0.21415805211290717, 0.13072742818621919, 0.17360803816700354, 0.08900634231395088, 0.1776312355650589, 0.25815470376983285, 0.17369181179674342, 0.1440960163017735, 0.10832855783519335, 0.13035163428867236, 0.11169211953529157, 0.07869686465710402, 0.28068327927030623, 0.10336518549593166, 0.07601032717502676, 0.10201331897405908, 0.19586834212532267, 0.10212957640760578, 0.11500752327265218, 0.13889810303226113, 0.1342732019838877, 0.16784376231953502, 0.14131404604995623, 0.14955933642340824, 0.07366252815700136, 0.1007267169188708, 0.16526473977137357, 0.0919284819974564, 0.1597661676350981, 0.12990701361559331, 0.08881822272087447, 0.15180878603132442, 0.11206735682208091, 0.08501574004185386, 0.15450046659680083, 0.1473883615108207, 0.15206582145765424, 0.1392491240403615, 0.14288405945990235, 0.14320634450996295, 0.2668928395723924, 0.16780969774117693, 0.12041447727824561, 0.09716976637719199, 0.10008769066189416, 0.12544011580757797, 0.14856135559966788, 0.28358377050608397, 0.17388071806635708, 0.1251864348887466, 0.16108849667944014, 0.1920218500890769, 0.13690485764527693, 0.17857996746897697, 0.11421162183978595, 0.07338690193137154, 0.1503104344010353, 0.12332492071436718, 0.12249124396475963, 0.1214351381349843, 0.11191217374289408, 0.10817401300300844, 0.144513132981956, 0.10987831803504378, 0.18242764694150537, 0.26962720847222954, 0.16216364601859823, 0.21443683246616274, 0.14695847989059985, 0.18168422277085483, 0.14387377275852486, 0.12127046298701316, 0.1702761958586052, 0.16519540833542123, 0.09943280470906757, 0.11271675830357708, 0.11059807511628605, 0.2032530083670281, 0.1931232714559883, 0.10397696009022184, 0.16496467462275177, 0.14399707317352295, 0.13714048953261226, 0.05599295676802285, 0.191183386486955, 0.17079954355722293, 0.2386237814789638, 0.15346907428465784, 0.13644512684550136, 0.19003063818672672, 0.08713184055523016, 0.17753906082361937, 0.12727520952466875, 0.13762086688075215, 0.16717473103199154, 0.08549215432140045, 0.08428154076682404, 0.14666760253021494, 0.0938611087622121, 0.08411685077589937, 0.16449323273263872, 0.1457578779081814, 0.09550666538416408, 0.12537332251667976, 0.11300086727715097, 0.1285849220585078, 0.18097250314895064, 0.11098891234723851, 0.16711363743524998, 0.10459448632900603, 0.15039438614621758, 0.2643483120482415, 0.1499512349255383, 0.18845474696718156, 0.1737634587334469, 0.15153615066083148, 0.1493213148205541, 0.10389353526988998, 0.2572543598944321, 0.10179543183767237, 0.11814490804681554, 0.10524315308430232, 0.14305945864180103, 0.19335829478222877, 0.20621738367481157, 0.2364810527069494, 0.12900484405690804, 0.09313125847256742, 0.10819573566550389, 0.16166186513146386, 0.09184474547510035, 0.17990324646234512, 0.16773957962868735, 0.18975947226863354, 0.14651713951025158, 0.12185930521809496, 0.16265079175354913, 0.11393008811865002, 0.2346341439988464, 0.08979966849437915, 0.15768298879265785, 0.15870222472585738]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.02675547202670714, 0.0442381724860752, 0.044025992465321906, 0.03295090042229276, 0.01889983886940172, 0.048959530467982404, 0.018777731456793845, 0.06345336660160683, 0.035365151343285106, 0.012056569357810076, 0.04282845926354639, 0.06571118763531558, 0.016724659690225963, 0.02886684134864481, 0.04221783128741663, 0.016432344418717548, 0.08707339642569423, 0.023547124947072007, 0.07568273576907814, 0.05658934293023776, 0.009048934261954855, 0.03445684793405235, 0.008301749257952906, 0.081054845941253, 0.017386620165780187, 0.12187658983748406, 0.09797678518225439, 0.08547850622562692, 0.10923702080617659, 0.020408296695677564, 0.014776268781133695, 0.027548705438675825, 0.020844649843638763, 0.05725504939618986, 0.0172621694218833, 0.04116460870136507, 0.04336808226071298, 0.018935153966594953, 0.027311895391903818, 0.03949902151362039, 0.013174035029805964, 0.025701520280563273, 0.019173427899659146, 0.04160855773079675, 0.045770225042360835, 0.03434170001128223, 0.09722834409330972, 0.01587398219271563, 0.029293145817064214, 0.017846877890406176, 0.032596751261735335, 0.08738891308894381, 0.013570660084951669, 0.04414994597027544, 0.043992217324557714, 0.016192925722862128, 0.031137009864323772, 0.009426737524336204, 0.039633888300159015, 0.011194575035915477, 0.05056339694419876, 0.029929337069916073, 0.018833192152669653, 0.040879731604945846, 0.019235135623603128, 0.035724536355701275, 0.009796481990633765, 0.08030992263229564, 0.02533903123548953, 0.03822343664069194, 0.05276967953250278, 0.03408999691600911, 0.060987254400970414, 0.04578978434437886, 0.03648801335657481, 0.11277754019829445, 0.04831121623283252, 0.050040661517414264, 0.03362609524629079, 0.023872220881457906, 0.07251639239257202, 0.015097468440217199, 0.0218550746285473, 0.03328314509417396, 0.06578297558007762, 0.009553169802529737, 0.05092376530228648, 0.047939507858245634, 0.008917419199860888, 0.007797620401106542, 0.055599607367184944, 0.10000144568039104, 0.013136290326656308, 0.10134755313629285, 0.04981636593583971, 0.01023078217258444, 0.05208554182900116, 0.00857359053043183, 0.011822263131762156, 0.01112293552068877, 0.013203628168412251, 0.04446182239917107, 0.05060268253146205, 0.015020212722447468, 0.02266112122015329, 0.04190963962173555, 0.0744903419399634, 0.020293768466217443, 0.0382918997638626, 0.03370243626704905, 0.010520333871681942, 0.061865597308496945, 0.007272037446455215, 0.02416009625449078, 0.029139832950022537, 0.08193679939722642, 0.03204834494681563, 0.0291442672823905, 0.051906342850998044, 0.04625892928743269, 0.06452576257288456, 0.03147240124235395, 0.03453871795500163, 0.027638208448479418, 0.06260984897380695, 0.014487084445136134, 0.0361153810081305, 0.02182953176088631, 0.043828239795402624, 0.04615398960595485, 0.026708967197919264, 0.02773329797491897, 0.020590868734871037, 0.04423803147801664, 0.032602536302874796, 0.02729280364292208, 0.06341677872114815, 0.022741159991710447, 0.07050459331367165, 0.03662842769699637, 0.029574759319075383, 0.0381202669814229, 0.06887143797939643, 0.08909673590096645, 0.051833964898833074, 0.04202470961899962, 0.030698309674335178, 0.006055087806089432, 0.045949546474730596, 0.022038381393940654, 0.015654056005587336, 0.10646710303262807, 0.05412909740698524, 0.030617272714152932, 0.10389146467787214, 0.01569837892020587, 0.015633489238098264, 0.023613075900357217, 0.021041469262854662, 0.04396879143314436, 0.018294250075996388, 0.05174603524210397, 0.028002562139590736, 0.06918267987202853, 0.05983068032946903, 0.05439899425255135, 0.025887476513162255, 0.002992306963278679, 0.03170401440002024, 0.027100368461105973, 0.03325445737573318, 0.01473795076890383, 0.03205039698514156, 0.04379319187137298, 0.05872273919521831, 0.037259316304698586, 0.01958488384843804, 0.10812132051796652, 0.004072139254276408, 0.0635921853245236, 0.01778210138581926, 0.09272351511754096, 0.042520475399214774, 0.050761338861775585, 0.04130998800974339, 0.03364017749845516, 0.07638868890353478, 0.08880928726284765, 0.030101717566139996, 0.05539611789572518, 0.03440590691752732, 0.05350043524231296, 0.05121285037603229, 0.004674783576774644, 0.02718744279263774, 0.025381329942320008, 0.07556571392342448, 0.021588305935438257, 0.07637274014996365, 0.042962646984960884, 0.02799816120386822, 0.05738633903092705, 0.03537165255693253, 0.029767678752250504, 0.04785966761119198, 0.02718016603466822, 0.041314949266961776, 0.012431869727151934, 0.019185233613825403, 0.05718319094739854, 0.03073079904424958, 0.01541673016618006, 0.031094991318241227, 0.03332435655465815, 0.046049027660046704, 0.07577909622341394, 0.024413161190750543, 0.0425374000769807, 0.0986111952806823, 0.05830650196003262, 0.0265557396778604, 0.04061706698848866, 0.05633755819872022, 0.0345671644754475, 0.010972940053761704, 0.05629235027299728, 0.037161415893933736, 0.06026027993357275, 0.030823790148133412, 0.03196104982635006, 0.05135667117428966, 0.021617442653223407, 0.026595448289299384, 0.016081592439149972, 0.036485000237007625, 0.05172503246285487, 0.014008426096552284, 0.02858017567632487, 0.06169128537294455, 0.008836118777253432, 0.03986080737377051, 0.03032169013749808, 0.03780376697250176, 0.07736905114143156, 0.014324848179967375, 0.03963556184316985, 0.02758353999524843, 0.029369726180448197, 0.04522161834756844, 0.004124300176044926, 0.015382442943518981, 0.018747414724202827, 0.03948622317693662, 0.0224011357568088, 0.05435084371129051, 0.02866676946723601, 0.06313805031822994, 0.030571406132366974, 0.026528489870543126, 0.0684064750385005, 0.0024282438835143694, 0.045513913210015744, 0.052946941505069844, 0.047307183194789104, 0.004831496407859959, 0.07102543255314231, 0.05383512158005033, 0.024769110059423838, 0.00850108177473885, 0.09810937728616409, 0.04374123411253095, 0.02899132919992553, 0.009298154873249587, 0.031102255088626407, 0.06650152296060696, 0.042213730921503156, 0.0714111267006956, 0.025801040428632405, 0.03676828542666044, 0.02956846776214661, 0.027184201462659985, 0.037654862462659366, 0.04957868572091684, 0.04433049565705005, 0.04595807004079688, 0.02552298738009995, 0.007078245062075439, 0.039873787536635064, 0.019372269671293907, 0.010411035000288393, 0.03873122521326877, 0.060305836668703705, 0.04759246847243048, 0.04843222341150977, 0.05680524853232782, 0.031073459758772515, 0.020710213502752595, 0.053699657364632, 0.06970432063098997, 0.027520334988366812, 0.01712107601633761, 0.02124438171449583, 0.04072925374202896, 0.017877048048831057, 0.04243418217811268, 0.028396993220667355, 0.030627061642007902, 0.060836854463559575, 0.03292272849648725, 0.02669603898539208, 0.07653778637177311, 0.03850560118735302, 0.08296343454276212, 0.01707286610326264, 0.02610610579722561, 0.031183876490104012, 0.040481569376424886, 0.08339263338712044, 0.07591140631120652, 0.018698924650379922, 0.005675303937096032, 0.04339749357313849, 0.06559974674019031, 0.053870466363150626, 0.08262151968665421, 0.01171228426755988, 0.13124566990882158, 0.07762999026454054, 0.01925741118611768, 0.021457639704749454, 0.029986773733980954, 0.07183372043073177, 0.009263375050068134, 0.0289645562224905, 0.028480076653067954, 0.06141084631963167, 0.06410794085240923, 0.1098451588768512, 0.020714013298857026, 0.05204313180001918, 0.06594376187422313, 0.03258856537286192, 0.01803640385332983, 0.025631036660342943, 0.052813032089034095, 0.023321788503380958, 0.026074460620293394, 0.015320114598580403, 0.03354978391143959, 0.06693919713143259, 0.07111278333468363, 0.024086313787847757, 0.07763934132526629, 0.2140887948917225, 0.0912566008628346, 0.15975766262272373, 0.10301112168235704, 0.1717697680578567, 0.09007153945276514, 0.15898676414508373, 0.1510152520495467, 0.15926305088214576, 0.15681816410506144, 0.2224421122809872, 0.16402756475144997, 0.10437463992275298, 0.17996739770751446, 0.12011507264105603, 0.22934672771953046, 0.08450134264421649, 0.2058064565062523, 0.1885086714173667, 0.12076606231858023, 0.12670752592384815, 0.13009795336984098, 0.16553909692447633, 0.1895400192006491, 0.19271016237325966, 0.16193599964026362, 0.1600237819366157, 0.2020684367744252, 0.1288608377217315, 0.10011863822001033, 0.08587716569309123, 0.09730277408380061, 0.10725978354457766, 0.09140054040472023, 0.10515275949728675, 0.16411319375038147, 0.1240951957879588, 0.13976355112390593, 0.17520177061669528, 0.12468183384044096, 0.19560769986128435, 0.12593069026479498, 0.13871982431737706, 0.16552579763811082, 0.08486146980430931, 0.13623487640870735, 0.1376990447170101, 0.0749885976256337, 0.07449918091879226, 0.25521235540509224, 0.230265922145918, 0.11467910808278248, 0.18833122390788049, 0.1605641990317963, 0.08131404101732187, 0.11292706811218522, 0.10087504255352542, 0.12706261390121654, 0.1056776731275022, 0.13192647165851668, 0.13829343079123646, 0.16284545708913356, 0.1674407464452088, 0.13583776802988723, 0.09705021380796097, 0.10576918735750951, 0.13377625989960507, 0.09422826406080276, 0.11986291312496178, 0.14838711416814476, 0.142160777177196, 0.09660073206759989, 0.09555218872264959, 0.1224876222840976, 0.17586848640348762, 0.1919475314207375, 0.11029171655536629, 0.16598209971562028, 0.12403790940879844, 0.15834519232157618, 0.12448319801478647, 0.12435332217137329, 0.19087342108832672, 0.1282984233694151, 0.1008780334086623, 0.19332109834067523, 0.10299337693140842, 0.06544477888382971, 0.14167081128107384, 0.14835327223408967, 0.22952640167204663, 0.06504974109702744, 0.26746090909000486, 0.20819804223719984, 0.08706037173396908, 0.09220886538969353, 0.07061150710796937, 0.19233275059377775, 0.07988746248884127, 0.14421890111407265, 0.09587943874066696, 0.141851153166499, 0.13673422305146232, 0.14777760312426835, 0.19414590642554685, 0.1325780327897519, 0.14487298554740846, 0.1594144044793211, 0.1267429708968848, 0.17900475795613602, 0.12515671929577366, 0.07008320186287165, 0.09480899461777881, 0.07739471460809, 0.16385491151595488, 0.24030346947256476, 0.19577328785089776, 0.13054506765911356, 0.09567234243149869, 0.22858442331198603, 0.1598922733683139, 0.0962941137549933, 0.2125045025604777, 0.12253365770447999, 0.09868652326986194, 0.21591142052784562, 0.11761282527004369, 0.14707416587043554, 0.13353406742680818, 0.13523560424800962, 0.14493529626633972, 0.09286260843509808, 0.10579895490081981, 0.16691481607267633, 0.13921103702159598, 0.17591763142263517, 0.08910100325010717, 0.2259685011813417, 0.10669100898667239, 0.15315513097448274, 0.15283660119166598, 0.22296740440651774, 0.14765743457246572, 0.10695932505768724, 0.09803497698158026, 0.1315125758992508, 0.1769213713123463, 0.1910800053155981, 0.13818448351230472, 0.21846822317456827, 0.22776058001909405, 0.12344364949967712, 0.10500380303710699, 0.24412269500317052, 0.2271401000325568, 0.08017555679543875, 0.1419378657010384, 0.12426909583155066, 0.14491720270598307, 0.15615696989698336, 0.18747344962321222, 0.058422584988875315, 0.11772917918278836, 0.12325694740866311, 0.14596152323065326, 0.0644472507701721, 0.12290145867154934, 0.21337014361051843, 0.15019989892607555, 0.1835521194152534, 0.10071377386339009, 0.11260116880293936, 0.2092968364013359, 0.2676501567475498, 0.12976790545508265], [0.04353454598458484, 0.03878168383380398, 0.039833693008404225, 0.05026197737606708, 0.05519128142623231, 0.011758828986785375, 0.018783433006319683, 0.061368410315481015, 0.03250755624321755, 0.008351340493391035, 0.06500293384306133, 0.005104089568703785, 0.0012611507963811164, 0.08557872584788129, 0.08854863757733256, 0.07589864879264496, 0.021928849673713557, 0.04844999413762707, 0.03754578159714583, 0.0734887839644216, 0.022661226976197213, 0.07104067626642063, 0.025390770060766954, 0.03638256530393846, 0.053220419213175774, 0.06260425318032503, 0.03664281051896978, 0.039880147742223926, 0.03252016904298216, 0.022423223927034996, 0.037610496874549426, 0.011551605584827485, 0.028273446041566785, 0.020260700221115258, 0.034736578236334026, 0.047501388398814015, 0.01278236288271728, 0.020855258844676428, 0.07900170923676342, 0.05360007598937955, 0.035552755143726245, 0.018516868403821718, 0.11613907583523542, 0.04492927524552215, 0.031500324548687786, 0.04912515927571803, 0.03790160801145248, 0.010277459550707135, 0.036548817515722476, 0.04167861276073381, 0.012072946701664478, 0.09069847612408921, 0.05872990834177472, 0.07431622667354532, 0.10664496614481322, 0.021193156826484483, 0.008019086544663878, 0.0555566592811374, 0.05877649295143783, 0.041421284186071716, 0.022152278797875624, 0.013096514921926428, 0.08435821204329841, 0.0540909510164056, 0.0376889159088023, 0.06627263719565235, 0.0813945046684239, 0.02614891287521459, 0.04408150511153508, 0.05292675137752667, 0.06458270756411366, 0.03784958717005793, 0.11444342424510978, 0.02646824603289133, 0.03357965164468624, 0.04170979038462974, 0.05575385905103758, 0.03651839688245673, 0.02936475935712224, 0.03997454150521662, 0.004784800939887646, 0.06533699677675031, 0.037033139378763735, 0.02575186015747022, 0.008896562994777923, 0.05381829338148236, 0.0444905435142573, 0.04456724076590035, 0.054014164707041346, 0.013098910203552805, 0.05328621431544889, 0.01663746290432755, 0.008620615790277952, 0.024796486031846143, 0.01799264682631474, 0.11875997777679004, 0.033109946380136535, 0.09877342876279727, 0.00556904462428065, 0.009704767380753765, 0.07356645714025944, 0.00728263763448922, 0.0731925705622416, 0.005393997034843778, 0.023784979566698894, 0.07192005446995609, 0.0126536392235721, 0.07376313369604759, 0.013937819094280712, 0.032590565460850485, 0.023062652799126226, 0.04507376768742688, 0.005387424853324774, 0.04487142854486592, 0.012457047087082174, 0.047920917058945633, 0.029237853959784843, 0.019309851340949535, 0.05865288825589232, 0.049026104825316, 0.042132929593208246, 0.0306222154176794, 0.033840034157037735, 0.05128269018314313, 0.044913434103364125, 0.023032966892060358, 0.08377029749681242, 0.011765638191718608, 0.042499394694459625, 0.051949951448477805, 0.038203172298381105, 0.01829233533499064, 0.07674099382711574, 0.06281604728428647, 0.032313232295564376, 0.011157006592839025, 0.042136016927543096, 0.019016061050933786, 0.047737524946569465, 0.026103699383384082, 0.046415002943831496, 0.07231825380586088, 0.06678180245216936, 0.023087752233550418, 0.0637286737037357, 0.0038717533516319236, 0.061933648539707065, 0.0781369068135973, 0.04225958451570477, 0.029088429946568795, 0.026660093062673695, 0.10469280605320819, 0.03550461202394217, 0.03309360057755839, 0.11534181627212092, 0.02407053943898063, 0.03572214664018247, 0.009703111463750247, 0.009878847395157209, 0.016659274624544196, 0.027973375326837413, 0.07726478681433946, 0.0568773147824686, 0.02623999480420025, 0.026293798655387945, 0.013762297458015382, 0.030965774130891077, 0.030470284800685477, 0.033226656523765996, 0.005982120310363825, 0.01468045194997103, 0.07992862942046486, 0.03681543777929619, 0.031798497220734134, 0.020173822558717802, 0.03014917605469236, 0.04202217889542226, 0.03540684519975912, 0.022986925905570388, 0.06316412938758731, 0.03931641978851985, 0.018501489248592407, 0.05389156191085931, 0.13255152327474207, 0.016187342916964553, 0.00927618359128246, 0.0377532749553211, 0.018714274119702168, 0.0378737403661944, 0.05558578857744578, 0.05193174656596966, 0.027348789408279117, 0.05231542578258086, 0.05750360949605238, 0.06851000463939272, 0.033823131743702106, 0.0077633062755921856, 0.048746530374046415, 0.0391114014928462, 0.033333622268401086, 0.03029125651664799, 0.09796963830012828, 0.006173726605993579, 0.04797512723598629, 0.04987658750906121, 0.007932999269542051, 0.04218583359033801, 0.0116831763079972, 0.05642015181365423, 0.03512956027407199, 0.017431594314984977, 0.09973009422537871, 0.029780139411741402, 0.041459805361228064, 0.05278807737340685, 0.055532543192384765, 0.028605918923858553, 0.013008989735681098, 0.0448332784435479, 0.005636432097162469, 0.026255756165483035, 0.037555722665274516, 0.02347058354644105, 0.03369320394995157, 0.014185546133376192, 0.036913089570589364, 0.01607490012247581, 0.07007846696069464, 0.06048520634067245, 0.03996953942987602, 0.06355599078233354, 0.04999980628781486, 0.010409520091343438, 0.011902954993274761, 0.0260652078941348, 0.05912561035074759, 0.025513296786812134, 0.03922433410480153, 0.03427109208132606, 0.04540625355730299, 0.05799413200293202, 0.011078529114456614, 0.035672493249876425, 0.013849669576302404, 0.05397682725742925, 0.08871203623129986, 0.02620077972096624, 0.03573517133190762, 0.03226514483685605, 0.0029079957403155277, 0.07110805585398339, 0.07285418090759777, 0.03193604316038545, 0.038529175508301705, 0.05547085958824027, 0.0014137299808680837, 0.02015995552937966, 0.039232661001733504, 0.02249546643724898, 0.04083160332811531, 0.04405639454489574, 0.056915947279776447, 0.03797107303398661, 0.060437107749748975, 0.040874725818866864, 0.04137583506235387, 0.017513724087621085, 0.02839239932654891, 0.022145378679852, 0.056565568229416385, 0.022710288503731135, 0.04836731888644863, 0.008254136773757637, 0.11704913442372344, 0.10159068813663907, 0.01576292164827464, 0.023573653015773743, 0.0338121553795645, 0.043874293769476935, 0.07160897584981285, 0.10948253810056485, 0.06417738361051306, 0.04125501713133417, 0.004663864265239681, 0.019228729033784475, 0.008654296307213372, 0.021834491162735503, 0.02776020824967418, 0.06737359843100421, 0.020584517806128133, 0.016048731995397247, 0.07990619429619983, 0.05700219968275633, 0.03927884856238961, 0.03667617005703505, 0.04435459690284915, 0.014531525175698334, 0.03852424393699039, 0.010930548578471644, 0.06503468292066827, 0.016795779702079017, 0.06174982227094006, 0.03183231317962054, 0.0430698947457131, 0.023561741545563564, 0.02321397671039449, 0.03191585303284228, 0.08518975882907398, 0.03444611647864804, 0.0398272363236174, 0.030018333563930355, 0.06370139235514216, 0.005350541041480028, 0.03479589067865163, 0.05516649740457069, 0.058913860775646754, 0.02449398107273737, 0.049377686154912226, 0.05024546087952331, 0.041939689181162976, 0.04881286724412348, 0.030913684640836436, 0.014652076861239038, 0.05220299412030727, 0.06160456170619, 0.06117851327871904, 0.02268067681143293, 0.061698076024185866, 0.008224916564358864, 0.01501874048699392, 0.0370598826702917, 0.1114836725173518, 0.018374563442193903, 0.07396138360491022, 0.013277056259539677, 0.011009804384229938, 0.06159529599244706, 0.03277002047980204, 0.08955480428994633, 0.01912116029416211, 0.045827912181266584, 0.05687778233550489, 0.03840338147711009, 0.01532143654912943, 0.035261076263850555, 0.02058659025351517, 0.023431793342751916, 0.054244082057266496, 0.02608044604130555, 0.07871932946727611, 0.030645036458736286, 0.04581928842526395, 0.09304730672738515, 0.08254475935245864, 0.09801473119296134, 0.12887440418126062, 0.10965289067826234, 0.10418931080494076, 0.08208253493648954, 0.1551584101980552, 0.13779506378341466, 0.20650643535191193, 0.19894904165994376, 0.135737385135144, 0.16196595272049308, 0.16840059572132304, 0.20604596240445971, 0.15958803734974936, 0.10140468366444111, 0.1379401091253385, 0.13525543443392962, 0.18344989599427208, 0.10795694965054281, 0.1500760790077038, 0.08653837474412285, 0.09511535317869857, 0.14867598772980273, 0.23945693130372092, 0.148963421524968, 0.10960793879348785, 0.1225682046788279, 0.14174904848914593, 0.13327079795999452, 0.19592787721194327, 0.09280423109885305, 0.22186579008121043, 0.08757368559599854, 0.22292266774456948, 0.1359091032645665, 0.12344192029559053, 0.22158672771183774, 0.16105333372252062, 0.10416435237857513, 0.15881641156738624, 0.21040284424088895, 0.16268035891698673, 0.12422778047039174, 0.1600764150498435, 0.08174803413567133, 0.14739088481292129, 0.08345990907400846, 0.10571825376246125, 0.16353411076124758, 0.21210930892266333, 0.18888519261963665, 0.16761817911174148, 0.17025713750626892, 0.22270388260949403, 0.09399157832376659, 0.07974094769451767, 0.10823453514603898, 0.16003372671548277, 0.0994019684731029, 0.14209043642040342, 0.13472683232976124, 0.09212799355736934, 0.08782118442468345, 0.10453262089868076, 0.14457934739766642, 0.07001872407272458, 0.14591194776585326, 0.22256900469074026, 0.19569925119867548, 0.10040009772637859, 0.17167073587188497, 0.12199344841064885, 0.17878704151371494, 0.1453351802774705, 0.1845596294151619, 0.08693891926668584, 0.196393990481738, 0.14115446945652366, 0.08976328099379316, 0.13424483709968626, 0.09954107663361356, 0.12230006672325544, 0.1135426276596263, 0.16283257340546697, 0.13604990352177992, 0.14543719589710236, 0.15031490213004872, 0.1592072265339084, 0.1416143189999275, 0.10328934542485513, 0.09038753851200454, 0.1092859728669282, 0.05198263934289571, 0.14360763860167935, 0.117871434049448, 0.28166232048533857, 0.2007806027540937, 0.2543518500169739, 0.14601320639485493, 0.11459131201263517, 0.13906590262195095, 0.15097495343070477, 0.21847781172255054, 0.1681180007290095, 0.0747247418621555, 0.19726792874280363, 0.09293570998124778, 0.08825282493489794, 0.12737064971588552, 0.16690516815287992, 0.1392882055370137, 0.1428042192128487, 0.10373858967795968, 0.20569409534800798, 0.13295594922965392, 0.11501832152134739, 0.10842164541827515, 0.1684866996947676, 0.11184995950316079, 0.09894413757137954, 0.10543312062509358, 0.11597305739996955, 0.11009627938619815, 0.14961762470193207, 0.26098712522070855, 0.09998870300478302, 0.0908403005450964, 0.10941008222289383, 0.0933020118100103, 0.20488374429987743, 0.19816325569991022, 0.1346542502869852, 0.18092188867740333, 0.15667576080886647, 0.058149003380094655, 0.06315735357929952, 0.1645816076779738, 0.10564446201897226, 0.10770533932372928, 0.10420862148748711, 0.0925508544605691, 0.0977137457812205, 0.1345497855800204, 0.23165851773228496, 0.14091095596086234, 0.12385522233671509, 0.1635512989014387, 0.26274055300746113, 0.13550921925343573, 0.14993909338954836, 0.17220298934262246, 0.09850567672401667, 0.16804528509965166, 0.22057952941395342, 0.08559998837881722, 0.10581477006780915, 0.1926398216164671, 0.07184207701357082, 0.1845214088098146, 0.27123057399876416, 0.156026114418637, 0.1025220834708307, 0.160148982249666, 0.1348501179018058, 0.1323381409747526, 0.13193104328820482, 0.1402135449461639, 0.130199137784075, 0.15489589772187173, 0.17453806794947013, 0.15273731667548418, 0.18100852699717507, 0.16120375221362337, 0.15680645301472396], [0.03619245675508864, 0.004447678502401686, 0.0005397649329097476, 0.012677747890847968, 0.0025975384369303356, 0.03721596745890565, 0.036690311681013554, 0.08065606773016043, 0.00807630149211036, 0.0880709096963983, 0.028337513795122504, 0.026106751465704292, 0.03676487525808625, 0.020587779545166995, 0.008645834896015003, 0.03393530365428887, 0.01738072380248923, 0.034538666004664265, 0.031684521891293116, 0.009772191497177118, 0.012849223894590978, 0.02668794029887067, 0.022457600207417272, 0.013950005159131251, 0.01764271677529905, 0.042817126668524, 0.012147642937634373, 0.016339802314178087, 0.022396530730475206, 0.07793671247782186, 0.056437521780026145, 0.017470267630415037, 0.015307109388231765, 0.061161584890214726, 0.026430092220834922, 0.015006714911578456, 0.041796836885623634, 0.04813720857782755, 0.03312300817924552, 0.012567780158860842, 0.04670489695854485, 0.0970787568076048, 0.03727531700860709, 0.06184618643601425, 0.009825933193496894, 0.04944869484461378, 0.015163982498052064, 0.02626123507070588, 0.023336280792136677, 0.04505420096393209, 0.034732652275124565, 0.015774367420817725, 0.05734265621867962, 0.07722214300883934, 0.01671626971074147, 0.03748578266822733, 0.09703063595225103, 0.010056396949948976, 0.029258686045068316, 0.023049603987601586, 0.019831193385471124, 0.049619032579357736, 0.01081832935597049, 0.08437318116193637, 0.019025135661649983, 0.09278646408347413, 0.01904689172079088, 0.0358059536665678, 0.05347317615814973, 0.02193368291045772, 0.03839148113911506, 0.08467495325021446, 0.028881324360554572, 0.019982296507805586, 0.004474562338145915, 0.03749349729332607, 0.040288510790560395, 0.02553268539486453, 0.05366840923670679, 0.040371642462559976, 0.04198714952508453, 0.021619231229124125, 0.018844005244318396, 0.016600101334915962, 0.16500032739713788, 0.0737144191225525, 0.053380107128759846, 0.04089683439815417, 0.021673433984688018, 0.053056100296089426, 0.028929432228324004, 0.01927406312461244, 0.08940423736930825, 0.032963127305265516, 0.03272613728768192, 0.07886387014877982, 0.028785756148863584, 0.06070009148970712, 0.019764611606660765, 0.0345205093617551, 0.08660982130095363, 0.06455866940086707, 0.04143190431932453, 0.02318814440513961, 0.04779776507348288, 0.003989055358033511, 0.041251707152696326, 0.013465918000292731, 0.03902494499925524, 0.011106851325166645, 0.04760317395266611, 0.022218417143449187, 0.021313228899089154, 0.04890061136393342, 0.029340244363993406, 0.03928093770809937, 0.028321490826783702, 0.01576218506670557, 0.04998975389753468, 0.02647344477736624, 0.024496352234564256, 0.01867114977358142, 0.060429523000493646, 0.057276204315712675, 0.04196036541543435, 0.013890592526877299, 0.024644540571898688, 0.0206074316156446, 0.07482534740120173, 0.023512234729423653, 0.035139171086484566, 0.048753944429336116, 0.06264288938837126, 0.017656001218711026, 0.02309570620127488, 0.08293397127999924, 0.0038315393840093748, 0.0942303123883903, 0.04479192226426676, 0.012008907706331229, 0.01754323187924456, 0.09770800155820325, 0.011482071913633263, 0.0071666617532173404, 0.0642303135828115, 0.03638704787590541, 0.02844162783731008, 0.09739540895679966, 0.015718596878286917, 0.03836000665614847, 0.049636120529612526, 0.10510567764868028, 0.08320230219396763, 0.010651882330421358, 0.05628767474263441, 0.05706455864128657, 0.03579845426429529, 0.02616373727505561, 0.07645095509360544, 0.02506633649318246, 0.07151069323299453, 0.02007977574976394, 0.04856263731198851, 0.01963211783731822, 0.03351342609676067, 0.05893630703212693, 0.06720403995132074, 0.02988831856782781, 0.06722729885950685, 0.019328787238919176, 0.017918586054292973, 0.014473456758423708, 0.06043968300218694, 0.040865708724595606, 0.03837544332782272, 0.029958904233353678, 0.022430209392041434, 0.023023300418572035, 0.03110848912911024, 0.0055845889073680155, 0.014852447457087692, 0.06614086145418696, 0.010056982318928931, 0.039882210912765004, 0.013087183342577191, 0.04563166978186928, 0.034455593704478815, 0.1281258146627806, 0.03445553433266468, 0.0659855299454648, 0.032734334308770485, 0.05785370653029531, 0.039267193133127876, 0.014984940298745641, 0.02328354192286497, 0.04015924350824207, 0.006790320985601284, 0.02216520701040281, 0.08558748319046572, 0.074002068140544, 0.037697528532589786, 0.01275259533940698, 0.030769240438530687, 0.031892553306533955, 0.028364835961838253, 0.04559536020678934, 0.05559655342949554, 0.023964258325577248, 0.07090127124683931, 0.01604147193575045, 0.020950183243257925, 0.01372988786897622, 0.026413375344418455, 0.018079582005157135, 0.013880207097827224, 0.05578398282523267, 0.04819707392016426, 0.09306991996709257, 0.04109044217329938, 0.019352450617589056, 0.021016202845203225, 0.04248431054293178, 0.016276025853585452, 0.041798169040703215, 0.09519433253444731, 0.02679305809579091, 0.07808793248841539, 0.03328469247207977, 0.04086687389644794, 0.048201088939094916, 0.04104895982891321, 0.04589874646626413, 0.02041234325588448, 0.048829843872226775, 0.04582960427796934, 0.00877884167493903, 0.028606601699721068, 0.059629250317811966, 0.02864277397748083, 0.030413946515182033, 0.024542909013689496, 0.044075015030102804, 0.042821887545869686, 0.05556835552852135, 0.028327886284387205, 0.07839636906282976, 0.029910727716924157, 0.05895592570595909, 0.06257193264900707, 0.021129972228663974, 0.0263968551371363, 0.01960047822649358, 0.10334263904951513, 0.03754007077077404, 0.022713579928677063, 0.015927129243209492, 0.03386750475328881, 0.054775764074292965, 0.04869462085480336, 0.07348927378188819, 0.06635899349930696, 0.014535173759213649, 0.043258930891170166, 0.023816435495973565, 0.013120794283167925, 0.012261624760867562, 0.03971103084040806, 0.04837614673306234, 0.0587850870215334, 0.030965085788920987, 0.02733219869696768, 0.0708063728234265, 0.05670408638252411, 0.020408111158758402, 0.05630689636745956, 0.043039017691626213, 0.020622480515157804, 0.02625355940836016, 0.026378813527117018, 0.04386720996990334, 0.029702299252676312, 0.02703061771171633, 0.010173801929340698, 0.03291429027740378, 0.012790983855666127, 0.04146547165873926, 0.09979260532418266, 0.06680330989183858, 0.010481734771019546, 0.12138767036958598, 0.05545763822738081, 0.08410678725340404, 0.0057724756516108755, 0.04643695938284509, 0.021916340774623677, 0.10458186239702627, 0.014641221096098889, 0.055628387854085304, 0.0618828707956709, 0.02692401933018118, 0.04638301637896802, 0.11600277299294248, 0.02451916956488276, 0.027290304460620973, 0.049120480034616776, 0.04524924479483161, 0.01834890183090465, 0.030109523104329128, 0.03441664208367001, 0.07999361187103204, 0.036564732872648165, 0.0572300093335798, 0.016851835971465334, 0.04259374021785334, 0.07340124022448435, 0.06935902158147655, 0.06111620627052616, 0.025552530423738062, 0.048182854370679706, 0.058874341411865316, 0.001548957288832753, 0.040290325341629796, 0.03334286200697534, 0.09505637470283546, 0.011191912581125507, 0.021742273747804575, 0.04741605254821479, 0.07876608477090485, 0.026389724953332916, 0.018759942176984623, 0.013303887681104243, 0.05851344241818879, 0.03035822977835778, 0.052255723712733015, 0.049836043981486, 0.025092174364544917, 0.034353207011008635, 0.011895092866325285, 0.06948527574422769, 0.03895611080224626, 0.08981311621027999, 0.045914246220490895, 0.037871202221140265, 0.03984595328802243, 0.034029786475002766, 0.04111919297429267, 0.012967698494321667, 0.030883815052220598, 0.03866588282107841, 0.03462685170234181, 0.04082787403604016, 0.021310443989932537, 0.133917742932681, 0.05204750304983463, 0.05967360106296837, 0.09966618788894266, 0.09846649132668972, 0.1358041784260422, 0.16693356272298843, 0.1430690026609227, 0.15955468523316085, 0.1771204301621765, 0.16540741024073213, 0.2603980677668005, 0.10917771578533575, 0.1378714753082022, 0.12531142740044743, 0.14584561460651457, 0.10681741900043562, 0.10121605941094458, 0.11823018823633902, 0.1535023670294322, 0.056397263979306445, 0.12228330160723999, 0.2152278579887934, 0.14397105347597972, 0.1786685799015686, 0.1286332804011181, 0.09917903473251499, 0.10746884654508904, 0.1596470084041357, 0.11575410157092847, 0.15977262431988493, 0.03846841587801464, 0.26333231187891215, 0.14191491849487647, 0.11286135835689493, 0.08736305666388944, 0.11455096144345589, 0.13940365402959287, 0.14242278499295935, 0.1805017440347001, 0.16681119741406292, 0.22920408693607897, 0.18011216103332117, 0.13081237440928817, 0.12867818033555523, 0.08503666118485853, 0.1916500786319375, 0.11643996476777829, 0.14802502031670883, 0.16166940535185859, 0.14263354009017348, 0.12843674485338852, 0.12324824201641604, 0.11634106616838835, 0.13316021795617417, 0.09048366890056059, 0.17633468873100355, 0.22060716699343175, 0.11078051727963611, 0.06616860293434002, 0.12300130721996538, 0.20479758095461875, 0.12728828616673127, 0.17167029058327898, 0.1653379897470586, 0.09033113528857939, 0.11915141614736058, 0.12429821028490551, 0.25754667702130973, 0.19146756967529655, 0.18105044349795207, 0.16897608671570197, 0.2018044251599349, 0.1146148752013687, 0.10363267036154866, 0.13886814995203167, 0.14044175535673276, 0.13806397357257083, 0.15540143387624994, 0.19421494100242853, 0.1529122854117304, 0.08289907549624331, 0.10770441163913347, 0.13131820742273703, 0.19361439510248601, 0.16944577713729814, 0.11657443450530991, 0.10281802227837034, 0.1422696650843136, 0.2250899319187738, 0.09886016356176697, 0.15483979135751724, 0.1610950572649017, 0.058995489598601125, 0.09404240801814012, 0.18021221738308668, 0.14642915048170835, 0.11914251037524082, 0.11063049954827875, 0.1658324382151477, 0.1388121474883519, 0.12592910206876695, 0.2585724141681567, 0.14102395536610857, 0.13998224720126018, 0.10354509693570435, 0.11729898586054333, 0.12179546567494981, 0.16253872745437548, 0.11286932902294211, 0.17321107821771875, 0.1578882074682042, 0.0769966933876276, 0.2017255051760003, 0.1330856914864853, 0.20398905558977276, 0.07661782699869946, 0.09259614031179808, 0.1362925412831828, 0.17086339794332162, 0.060577295735129155, 0.20822355727432296, 0.19146035599987954, 0.1491330171120353, 0.16524265345651656, 0.21710105356760323, 0.07671460305573419, 0.15760338603286073, 0.21703347360016778, 0.13903917046263814, 0.12940615299157798, 0.09093922140891664, 0.14201631071045995, 0.1984976526000537, 0.1730292520369403, 0.13716829038457945, 0.11327781452564523, 0.1808795120450668, 0.14486780535662547, 0.15741559298476204, 0.12198300639283843, 0.15342361031798646, 0.1761829195311293, 0.18083058967022225, 0.1723576826043427, 0.15641286241589114, 0.09278230063500814, 0.30730773811228573, 0.14581481547793373, 0.09294848234276287, 0.14713425014633685, 0.20107763994019479, 0.14428627328015864, 0.12187400716356933, 0.15012672316515818, 0.1405953650828451, 0.1092376590531785, 0.09008580353111029, 0.11588492736336775, 0.12457434117095545, 0.19272280856966972, 0.22029028477845713, 0.14133559801848605, 0.11589773683226667, 0.17782104725483805, 0.14566300174919888, 0.2114596328465268, 0.1768165355315432, 0.1340108082513325, 0.13187355652917176, 0.06797471578465775, 0.12029072415316477, 0.1252974453382194, 0.16964486567303538, 0.11647376217297278, 0.11718187495716847], [0.016319474889314733, 0.06461646786192432, 0.027265414682915434, 0.06461145836510696, 0.014276410984166432, 0.06968003013753332, 0.03823784543783404, 0.11532437580171973, 0.03966772281273734, 0.045233930577524006, 0.04007899136922788, 0.01797995424567489, 0.07757737941574305, 0.04410342444316484, 0.045620099699590355, 0.023180207135737874, 0.013579405367636355, 0.006519605458379374, 0.051286170855746605, 0.006982485747357714, 0.029229068786662538, 0.0405013958516065, 0.0635636794322636, 0.013698868879146175, 0.04298405423469376, 0.03572587593225762, 0.028037971860612743, 0.02831762238201918, 0.04649719579902012, 0.03741458844160661, 0.03886343882186338, 0.04028214687423315, 0.035294814297230914, 0.04624830915417988, 0.014287309422797989, 0.028989891288802028, 0.012337748703430407, 0.03637473564594984, 0.02943499064713251, 0.03493257943773642, 0.06659054357442074, 0.03298390001873486, 0.00801357517048018, 0.048561783842160366, 0.04700255383795593, 0.027447261272754986, 0.002538941239436099, 0.027223975012020674, 0.06690419744700193, 0.03179010724124964, 0.044680796781904064, 0.02786606262816349, 0.06283693874138407, 0.03932233099476434, 0.026621720317052677, 0.052939987581339665, 0.02756310124823358, 0.04407695945701562, 0.04913403536193073, 0.014760728208784712, 0.06373780954163522, 0.033829618114396, 0.09441301430342719, 0.014132573487586342, 0.0338749225193169, 0.071436315192841, 0.045633020490640774, 0.0385176685085753, 0.0592176997452043, 0.062271206988953054, 0.07983914867509156, 0.029348916359595023, 0.027585723764786962, 0.010642202869348694, 0.028904703867738135, 0.029968863855174277, 0.04524944146396592, 0.02095671970891999, 0.04561397327051964, 0.0439134977204958, 0.018651043137651868, 0.01952350266947178, 0.02943872364994604, 0.08077962047536857, 0.019382719110581093, 0.008138249486364657, 0.039568968932144344, 0.05015664435632061, 0.053645332154701464, 0.04821916765649803, 0.046024837356526405, 0.015144798908295343, 0.03931377032131422, 0.06294393417192623, 0.04982553517038468, 0.02011738037253963, 0.042186887440038845, 0.020933061896357685, 0.11108798906207085, 0.01660073030507192, 0.02623992615554016, 0.015312369359889999, 0.014355225212057121, 0.0669301206653472, 0.043024560654885136, 0.043276497526676394, 0.024741483612160664, 0.040633290336700156, 0.04692904039984569, 0.009373777866130695, 0.035639994603116065, 0.033284447563346475, 0.018048428501060698, 0.016057441098382697, 0.06097121658967808, 0.039011259796097875, 0.058713566249934956, 0.04219975999149028, 0.05578630945819896, 0.04644407286832575, 0.04323267741710879, 0.05531834452995099, 0.016781320809968747, 0.06817574132583104, 0.019332837509864476, 0.013013641146244481, 0.0773151934845373, 0.04562257476209197, 0.06634294826653786, 0.01693508824246237, 0.05118289358506445, 0.018939989058708306, 0.031820153089938685, 0.058545113570289686, 0.056307430713786744, 0.023981179292604793, 0.02610561412438983, 0.1112102133629378, 0.028906574079883285, 0.025287891694460995, 0.04329843170125969, 0.03822662416496314, 0.07038916708552279, 0.0202011558576487, 0.04597072736942209, 0.030582952094846405, 0.020742919950862415, 0.0106398112984607, 0.031966274545993656, 0.015229890777845867, 0.016784473082225304, 0.06480886222561821, 0.04092327340913471, 0.015118179926503217, 0.00816887513792608, 0.023304053029278293, 0.028181937377667055, 0.048231290638796054, 0.03197707650542725, 0.05532168048375752, 0.03166793117998168, 0.04031023716379423, 0.05355252287699841, 0.011853793275804492, 0.016269990337605122, 0.006904280080561875, 0.03806583416007925, 0.009931312597473152, 0.02622454700031085, 0.05375971566536464, 0.02388032698945608, 0.018114355334546417, 0.05666910896252375, 0.0494380450254539, 0.023080186037987005, 0.0686807579768356, 0.0231085824634647, 0.02122495414369041, 0.056672096106922254, 0.014457613760896493, 0.04828857701795641, 0.1196861854987219, 0.05452968274767045, 0.039703924776404165, 0.03330810723127797, 0.10480720069608651, 0.02730829412030289, 0.11858411846333183, 0.019403152291488368, 0.017085560539271683, 0.012282286152185407, 0.04173038869339507, 0.024474349411320873, 0.06314610262052156, 0.10907376316026784, 0.08318244974361733, 0.04229972357279621, 0.018030021383310668, 0.04568475189444143, 0.021413968024717178, 0.011554993488971377, 0.11375485963071696, 0.05932655054493807, 0.01593615932506509, 0.028212037032062653, 0.07252973620779812, 0.06603688656468876, 0.025686283988761716, 0.0425020775583107, 0.07151242985855788, 0.041205757079296745, 0.019587704009609297, 0.005536591434065485, 0.027322797541273758, 0.019546410912880674, 0.03333289125293959, 0.061753904083161615, 0.042650599862099625, 0.07804285443853587, 0.02616555182612501, 0.009474513281020336, 0.008284995274152607, 0.0396494066080777, 0.002704096232264419, 0.062440980691462755, 0.009879102508421056, 0.062269544578157365, 0.005446604636745178, 0.051874074270017445, 0.02247766973596299, 0.020720406901091337, 0.0524893072724808, 0.05319245137798134, 0.038150810069055296, 0.017539511864015367, 0.03631543804658577, 0.030149502599670086, 0.04797638517629821, 0.1027634076308459, 0.013868856876797508, 0.054357140834326856, 0.047235495439963415, 0.03045232853764901, 0.06920138199348003, 0.08159711840562522, 0.024260124773718417, 0.10492969959159382, 0.06089184018492233, 0.06618326777243055, 0.04894529607554432, 0.05575225230131764, 0.06869958626339212, 0.07975137486937456, 0.005988865968902246, 0.02304426237969892, 0.03831699177681003, 0.1024549116846174, 0.039283546357182786, 0.04162827288382687, 0.010540313414821867, 0.047371126638608985, 0.03626295336289331, 0.03158698513288982, 0.07780288098729216, 0.030492009318550117, 0.031329552657552995, 0.04930783892632462, 0.0471765392285306, 0.02625354827614501, 0.04873701233009342, 0.03528010864101816, 0.018622292336658575, 0.01897809277579654, 0.02863493689801544, 0.06845798008725978, 0.04509806560236029, 0.02540344594308408, 0.04793505497218575, 0.04795546403329354, 0.026661467891244683, 0.05247639761364553, 0.03161367647408042, 0.06368150279740803, 0.035430115240160376, 0.10231998923700303, 0.03349211532622576, 0.017551475284562912, 0.08552409635740332, 0.03488721195026301, 0.014372971818374936, 0.004041660640723421, 0.04910813811875414, 0.011894635517819552, 0.0764252025692258, 0.07382524403510615, 0.029022636699664872, 0.02554792725277366, 0.018668060583877377, 0.07016330186161213, 0.02508665649656905, 0.05045718819019385, 0.05973428276774939, 0.0847551497281529, 0.036884654182358645, 0.02525457297451794, 0.011530411702551646, 0.040522135168430395, 0.016201083781197667, 0.050347261276328936, 0.03481228101009037, 0.06216448986378964, 0.03706919291289523, 0.05939014889008831, 0.041492619420751, 0.057889055024133995, 0.076109025394544, 0.05099675552628469, 0.06211537453054916, 0.01986574035981903, 0.01917691970447777, 0.044885295574204065, 0.051292564457980916, 0.06673607873381115, 0.0040894006815506145, 0.09728248376632109, 0.05324711797584314, 0.05543115097680129, 0.054820886653033085, 0.049778716784203425, 0.04947982422891073, 0.045246035006130114, 0.0380526313529117, 0.04603367633535527, 0.0403255588025786, 0.021567598159890622, 0.008741026467760094, 0.027774231130024418, 0.019092142320005223, 0.035968257652712055, 0.05288501670293044, 0.042563200840959325, 0.004160486832915922, 0.011420986666053068, 0.12243097415193915, 0.04465853235160466, 0.030813234952802304, 0.022899261566635687, 0.0206229684772552, 0.03662421971966978, 0.03417431973502971, 0.048131913354154676, 0.06178556410304736, 0.10808066566823982, 0.1943893902353011, 0.11782925779698417, 0.12981368112377822, 0.10894918625126593, 0.2264316607033834, 0.18265064747538418, 0.17815271305153146, 0.11219954074476846, 0.24561074562370777, 0.1103730930481106, 0.16782688588136807, 0.12969517498277128, 0.11556302080862224, 0.1230926433345303, 0.11749998171580955, 0.08676733472384512, 0.16985532391117886, 0.18933687853859738, 0.25293595099356025, 0.17497134860605001, 0.08465555350994691, 0.1296331759658642, 0.06739968492183834, 0.12661063112318516, 0.17221091547980905, 0.1255692940321751, 0.09729872937896289, 0.134522563603241, 0.12503050966188312, 0.13276067533297464, 0.1544400557759218, 0.1219060159928631, 0.1495028886711225, 0.08637645296403207, 0.15006206725956872, 0.11165588788571768, 0.13763239985564724, 0.16454783995868638, 0.13710483675822616, 0.31885475444141775, 0.09456476123887114, 0.1613773257122375, 0.11860587081173435, 0.14669849071651697, 0.11696583576849662, 0.19768881553318352, 0.07546996945166029, 0.1413553094607778, 0.08289782868814655, 0.15640159661415964, 0.07029222775599919, 0.175480610341765, 0.14143124601105228, 0.15934274269966409, 0.16633141378406435, 0.12500998185714707, 0.21853252284927294, 0.11135279477457516, 0.14153020398225635, 0.12579652480781078, 0.1610681469901465, 0.1902175258146599, 0.11178337401361205, 0.14346519077662379, 0.17901715182233602, 0.14395621052244678, 0.156252350716386, 0.15653684560675174, 0.12895598105387762, 0.22386069787899032, 0.1049623911967501, 0.12454838084522635, 0.14641021087300032, 0.16642605245579034, 0.09850298272795044, 0.1823908809456043, 0.11101814554422162, 0.1604990681516938, 0.19810167228570208, 0.24921862233895808, 0.15769885590998456, 0.06716048330417834, 0.1370833144756034, 0.131230307451915, 0.08881816334906034, 0.16937708394834772, 0.09617600837373175, 0.1669107936322689, 0.20726869523059577, 0.10610017037834041, 0.15648688422515988, 0.1628129807068035, 0.19384095794521272, 0.16820113611174747, 0.10513813918805681, 0.10006858778069727, 0.15858322876738384, 0.25383780885022134, 0.09844758140388876, 0.19255391060141847, 0.1263842315529473, 0.12343412774498574, 0.15543128305580467, 0.1814017613651231, 0.10647568968124688, 0.09132315666647628, 0.23661472834646702, 0.18081056652590632, 0.09114837346714921, 0.1021364783809986, 0.14446288958424702, 0.10772848690976389, 0.08169014661689289, 0.22883995960000902, 0.17561470158398151, 0.1459600537782535, 0.1876273562083952, 0.09341803917777725, 0.18404272355837747, 0.10438401324790902, 0.13480533671099693, 0.11854097741888836, 0.18439493200276047, 0.08929662595619448, 0.1440074187121354, 0.11254782322794199, 0.21574316080659628, 0.12159527133917436, 0.07098033223883249, 0.12717528676148504, 0.07071692176396027, 0.16499057557666674, 0.11317749100271612, 0.15790802281117067, 0.11880176069098525, 0.14153072348563, 0.15842782304389402, 0.1382277804077603, 0.20062602823600173, 0.1954101846786216, 0.1325107942102477, 0.09557510624290444, 0.07118109802831896, 0.2140070844325237, 0.1767982341698371, 0.17422562377760187, 0.10966206362354569, 0.1576685020700097, 0.14203222235664725, 0.24953477724920958, 0.1488100492861122, 0.18237550364574417, 0.1394178587361239, 0.17810586869018152, 0.10070333926705644, 0.14172377093927935, 0.12958655424881727, 0.10585772557533346, 0.13536510901758447, 0.12728770729154348, 0.1269198692170903, 0.14188774104695767, 0.17185542674269527, 0.12624463357497007, 0.11242197724641301, 0.08719634060980752, 0.3266985429218039, 0.2034005176392384, 0.14213731046766043, 0.1131361979059875, 0.10963582870317623, 0.14031600585440174, 0.11765213683247566, 0.12102615539333783, 0.08290653408039361], [0.04374462572741322, 0.05653084685036447, 0.032923396429396234, 0.0360923187690787, 0.028112041909480467, 0.06168495114252437, 0.019222155460738577, 0.02668617027666187, 0.058998083404731005, 0.03494663571473211, 0.008458083593723131, 0.04222353840305004, 0.10767166808363982, 0.030797792715020478, 0.02383822124102153, 0.032716259302105755, 0.03518040852213744, 0.052407708135433495, 0.04681858656113036, 0.03513465511787217, 0.07971462371642701, 0.07650617088074796, 0.0673531299980823, 0.04875456041190773, 0.04798503861820791, 0.03456743164861109, 0.013394108718784992, 0.01577328388520982, 0.031561637078993954, 0.018499650577723514, 0.023861441186454613, 0.01810688932891935, 0.04935426768497564, 0.04570502736896742, 0.029815181769663468, 0.061898726780782454, 0.01907478905195603, 0.06536522807436995, 0.04262345210008789, 0.027637288185360376, 0.025410533453396056, 0.04360894257843029, 0.03862645251501817, 0.02593494613392977, 0.07105288459570147, 0.06897267434396781, 0.06903430970851332, 0.01285671494770213, 0.0695494566753041, 0.0755489562288858, 0.0528338344884105, 0.05245503860351164, 0.010935758455161704, 0.014914956700522453, 0.037166492184042, 0.033457995086791925, 0.006913653405717923, 0.03509111702442169, 0.058614344816305675, 0.03809780959272757, 0.050991337848245166, 0.026968789388774894, 0.06215818531927653, 0.0332395142322639, 0.060419344445108436, 0.018415739650663454, 0.025700182559376117, 0.027518455499375705, 0.036311463845777325, 0.009095054101635469, 0.03906351441401057, 0.05457577382912859, 0.017708567538647912, 0.03762534724955913, 0.05937234476732556, 0.02426232153084129, 0.012278944632271305, 0.013743333729507867, 0.043280835379846394, 0.015486052325286437, 0.017684562772046775, 0.01603400964086177, 0.053526903939200565, 0.05942781288467813, 0.05774051787739154, 0.027189472566533368, 0.011159103160025552, 0.03140048713248689, 0.014662358389614383, 0.037333033833419904, 0.05923575248743873, 0.06791281324694864, 0.07109391794074327, 0.04634453231119551, 0.0484544804203324, 0.030360333767021075, 0.023178398150776047, 0.041937210407922976, 0.036544249596772715, 0.04703592450823635, 0.0020421911858647945, 0.025375058794452343, 0.019237085616623517, 0.03920633331290446, 0.01308269520450267, 0.07091998821124434, 0.039390063102473505, 0.03944710086216219, 0.05709258584829513, 0.013701839325221954, 0.02524551506212447, 0.013644514910993166, 0.08368737733690068, 0.02686491839995142, 0.014421506421058439, 0.026379431365057826, 0.050372241967124864, 0.029357892635744065, 0.06350390685838647, 0.015171722170634894, 0.02994386275531724, 0.12613678467459977, 0.006426178342735511, 0.033058983099181205, 0.0901769392658025, 0.033291319850832224, 0.023759301257086918, 0.03976845822762698, 0.005118331382618635, 0.012473176739149494, 0.014397307768376777, 0.006046350872566109, 0.05030237247410696, 0.0964493933133781, 0.030106062840786763, 0.029467448475770652, 0.06424898601835594, 0.03818774304818362, 0.018017911388596985, 0.05189590825466439, 0.05386223223467823, 0.04474327448406257, 0.03805791544436943, 0.017398756135662552, 0.04675825737649575, 0.056181428881245665, 0.01647216620767722, 0.0189138970017666, 0.020442383538465947, 0.14424392633372918, 0.09184153197566047, 0.050365243514534086, 0.046927474468247965, 0.01255864246559213, 0.0180861629996798, 0.02206832890806254, 0.025532219697197434, 0.02532179485569941, 0.04487669779337011, 0.00847212873850367, 0.04158687217568513, 0.05024723461247049, 0.026881731755565852, 0.026075709283759352, 0.08159199758665636, 0.016041868984757457, 0.06287733383942395, 0.028850408343714662, 0.03713700294611044, 0.07148238029913045, 0.10252007225062698, 0.009168486831185874, 0.02675710475159576, 0.021948416397208348, 0.05166859584278427, 0.014993307086115237, 0.0433122838876443, 0.014785114253754728, 0.02138535081030568, 0.05498006248672027, 0.019299776686239056, 0.07921018594061024, 0.007735123681413825, 0.030490378449030686, 0.023950940485519823, 0.04921697407553438, 0.020530925467028283, 0.012230100182932802, 0.06132728420197964, 0.017679022639640607, 0.026528120652073994, 0.05962893119431101, 0.01670396675763186, 0.025021954206749797, 0.03894633671734482, 0.05508306887350045, 0.06702738653984852, 0.04958098266797606, 0.0740414836036507, 0.04826565949770156, 0.0348999397829175, 0.04260575929947663, 0.04160713651799597, 0.04008266871096566, 0.03759798426472116, 0.027963543725491036, 0.055038135542417876, 0.017670024099061266, 0.04970344074536115, 0.028470758988987654, 0.05623708995699417, 0.04323115601437166, 0.02681943959032651, 0.021062245687062386, 0.03446795046329498, 0.022554593342647422, 0.010685607376217376, 0.04363545209344011, 0.023887106508482248, 0.07403864117804915, 0.022853552691231016, 0.01864928981376579, 0.05336297464964446, 0.058307403669459745, 0.018993612939084414, 0.014031288883415982, 0.04449491105333436, 0.03836103081994224, 0.02290074586198898, 0.022585143851756584, 0.015104966914805118, 0.10208250198047608, 0.009864357889455277, 0.024134816849255003, 0.011317920907458756, 0.008712661583558656, 0.0917576915526297, 0.014455850232479861, 0.024221319727075752, 0.030285258108051494, 0.02710089538595639, 0.008331771914527053, 0.0029833626922481926, 0.0069354150309663964, 0.02638660978846019, 0.048579020221950486, 0.047883279039524496, 0.015426058962475508, 0.03012740515259793, 0.04124810031498782, 0.030000774349900894, 0.016172750438272487, 0.04649698057619389, 0.12567611876875162, 0.04729466687422246, 0.011252429158048471, 0.048750627029221505, 0.03328774269903079, 0.011852706029458204, 0.020137273641012143, 0.11209486081497744, 0.04610976502590347, 0.06338504448649473, 0.034178880232502706, 0.026526311667112168, 0.031559722337988205, 0.0746170042839367, 0.04485956160351634, 0.03513950505293906, 0.04936345176247414, 0.02698373809835175, 0.05708179502107669, 0.0052179461545165395, 0.040984081279020756, 0.09324100727098994, 0.017795766179915518, 0.03389349476492498, 0.03326199388538953, 0.05393534491304308, 0.04205451798043214, 0.009007667140394915, 0.052597460453398526, 0.05809557616885286, 0.041020550415851176, 0.10879355046199635, 0.023038668441586196, 0.04654008080251515, 0.05663097741489764, 0.02725241967709735, 0.007475223101209849, 0.03210454779036809, 0.0603345206764061, 0.05367087316699326, 0.07304191458388232, 0.03911508625606075, 0.034991661814274266, 0.04905127476376947, 0.010389352228230564, 0.030236445199989248, 0.006014477949065622, 0.025494251422060188, 0.030403484088310506, 0.025341216860397253, 0.0233387985281297, 0.03143867805192713, 0.04018498490040656, 0.02791117221931927, 0.02451726595609216, 0.02857732768461574, 0.02384988223639084, 0.03680248359160032, 0.016357671374862548, 0.04458784649614245, 0.010776082599477377, 0.021598332350549754, 0.01606802597962087, 0.05453979450976476, 0.006244503838388482, 0.007126858981791884, 0.030094260837358888, 0.01967128468095325, 0.04500918599660508, 0.04259286077285651, 0.042525525714154355, 0.008089300208666828, 0.05611351123661734, 0.03819231096713338, 0.04718633557786234, 0.032031041773734614, 0.030450020458374638, 0.012867348068539286, 0.015934339207888115, 0.027804067321994808, 0.01746270885632839, 0.040183726960094646, 0.03804513566137757, 0.009685959503258346, 0.05624318670015782, 0.03564984290278517, 0.01362211225568899, 0.01166883708719979, 0.037533688300754875, 0.0035523429642125848, 0.05462210981932003, 0.029285891323524993, 0.12693186232354492, 0.14850269624730572, 0.053204630021355115, 0.03967505523178261, 0.02206038607255323, 0.040192974120145664, 0.07645364908967167, 0.10250299543258734, 0.12867170880781487, 0.09359009869513102, 0.13053052156465128, 0.11532235716003925, 0.21741869277320802, 0.08541897113900632, 0.14409616473130882, 0.09008594453916885, 0.12200721525005065, 0.12277343819732778, 0.11504264912218787, 0.18921829818282276, 0.11407654354115948, 0.12793310859706253, 0.12911410303786397, 0.11782356552430429, 0.14009147649630904, 0.10838919872185215, 0.11727981618605554, 0.10992997151333839, 0.17148261627880856, 0.1820644992403686, 0.17995770525885746, 0.11593421339057386, 0.14667943236418068, 0.09083603319595568, 0.2039623976452276, 0.12755657255183905, 0.12321159476414323, 0.10645041213138029, 0.10521483272896148, 0.12165537787950598, 0.1639096374856308, 0.14800645178183913, 0.14643968897871673, 0.19913772528525442, 0.1330844743642956, 0.10707763824029826, 0.08462761907139793, 0.14643064962001517, 0.17106036393670365, 0.08829799946397543, 0.14861501287668943, 0.163820268062409, 0.11670245497953147, 0.13770213205134496, 0.09304667590186, 0.183142943715211, 0.10576167682302184, 0.09786328853806481, 0.12831463187467307, 0.11254468394326977, 0.08977380464784801, 0.1319628517376259, 0.2285313152242452, 0.10979461862007156, 0.12943181645823643, 0.13059197139227763, 0.10706874731113203, 0.16570780193433166, 0.08392473100684583, 0.13470413745380938, 0.10092236188938841, 0.09531225980026647, 0.10732130758697167, 0.16955702507402748, 0.08776069196755998, 0.14753297640709206, 0.14642837864812464, 0.13020045880693942, 0.17353098839521408, 0.1056061226699967, 0.1495551210246049, 0.17738810798618942, 0.1060248794965446, 0.20099342102184892, 0.23789888131432235, 0.1532669726293534, 0.09308526015956886, 0.14582370640709996, 0.12476195610361174, 0.16726968140574172, 0.09533873962936923, 0.16698662628186867, 0.10790864325826988, 0.2065698296064511, 0.09421824506716803, 0.09214308141963556, 0.11072813649661839, 0.1527535993955098, 0.21933401265414432, 0.22065895405830815, 0.08309022305184044, 0.13207677140599117, 0.19360332225915045, 0.10830031169462018, 0.09874530878732912, 0.17510750301880762, 0.19066232460318133, 0.08070022551692091, 0.08465754988719709, 0.13966581027489156, 0.11163203525939025, 0.1081719869398512, 0.23120285390177742, 0.1616908237338066, 0.11782472327467985, 0.1928857248276472, 0.14589658530894667, 0.18107739830156788, 0.1607307666563429, 0.16100484179332852, 0.09513622237136588, 0.1271356115466915, 0.1408570760395378, 0.21075677446788177, 0.11681564734317362, 0.1362934467033483, 0.12126440706197172, 0.16355067549739033, 0.12081738925189711, 0.12953377270605415, 0.107430522039067, 0.20276319090044126, 0.1353243354242295, 0.0905389069521334, 0.08196647788281552, 0.15550567593891174, 0.18138942687073722, 0.11648165120277554, 0.11432853978476487, 0.24606817576568574, 0.15518462285399437, 0.13325628155143932, 0.1592475251527503, 0.11456976004410535, 0.16736152960220352, 0.09391716317622922, 0.10040547087555751, 0.13172297476558015, 0.1992045482620597, 0.15051060647238046, 0.12881902512162924, 0.14357896201545373, 0.11690664949128404, 0.14705700741615146, 0.16933332692133263, 0.08257797046098858, 0.18024392193183303, 0.2671747369458899, 0.11386333935661241, 0.16395260783610865, 0.10370627656811848, 0.13968946994282305, 0.09823942382354289, 0.11381899603293277, 0.08118931567878462, 0.08081750711426139, 0.12407634523697197, 0.06667696667136624, 0.11469361706986092, 0.1474674150813371, 0.10819073359016329, 0.12464447412639856, 0.12917294050566852, 0.10722785635152832, 0.11755928673665039, 0.119524998444831, 0.1898785275989212, 0.24832534370943904, 0.09143191098701209, 0.10990649738232605, 0.10045618924777955, 0.14788611995754763, 0.1824490207945928], [0.09145548159722239, 0.025017683146870695, 0.042488125181989744, 0.022368162135535385, 0.011494139234855538, 0.036972958623664454, 0.03746783382666763, 0.03156621241942048, 0.04408099674037658, 0.047549127048114315, 0.020255225026630796, 0.049906384738278575, 0.014925539726391435, 0.08482308592647314, 0.07271816750289872, 0.01529426095657982, 0.04102322956896387, 0.03067970959818922, 0.026840802311198786, 0.06825098767876625, 0.046904809278203174, 0.00864525138240424, 0.0362243134441087, 0.046073266203165986, 0.04511427410761826, 0.07112644627341069, 0.02696893410757184, 0.08192170411348343, 0.10340733948396519, 0.036592722972272895, 0.011832742256956408, 0.10460932928253897, 0.04814335727132857, 0.027109929178550374, 0.03714141872478649, 0.02657581848325208, 0.007098124415279017, 0.047777816143934615, 0.022831473797850776, 0.04977775570296217, 0.0314024092949694, 0.029922323774371762, 0.0686297427455429, 0.0220280135908979, 0.07618846488185227, 0.04626989823009353, 0.07183388370322064, 0.10491214779904112, 0.04561760237265844, 0.04329141098423861, 0.024914439272833988, 0.06396960452548228, 0.08904654445359483, 0.05505419561814051, 0.05307624218403362, 0.00812720076282858, 0.020449361581995618, 0.028953681903658435, 0.04380591599328909, 0.043681754686986096, 0.026380186500318814, 0.03968539705965668, 0.06745752791175619, 0.04013629259134177, 0.03885731981426943, 0.033444936998421326, 0.01953079798113322, 0.05795957760710735, 0.02311298896529479, 0.01935414085892262, 0.06533252162626013, 0.04394264928123448, 0.012467843480408192, 0.06646624868153594, 0.05344639946997631, 0.021467484293680172, 0.056247183165396564, 0.04892452707281336, 0.039818360237404704, 0.021726679369749036, 0.059830305544892326, 0.05549840068852063, 0.10622880683513358, 0.006967898370930925, 0.045543888554675505, 0.012151308219472412, 0.02586647002317477, 0.05932528147241101, 0.04880284453975037, 0.018078504035656806, 0.05816098164359573, 0.07375842105830088, 0.03147361094306689, 0.05672661056451034, 0.029747837434115354, 0.026689931110013276, 0.062046020830166526, 0.07920668300357647, 0.006412842876670766, 0.024402639392064884, 0.12440899809007533, 0.027236426394665614, 0.03274727365351282, 0.05734928730817046, 0.033274291272391565, 0.0814889206958469, 0.021763180047855712, 0.04278276894183364, 0.0151898027434072, 0.035298395159770735, 0.018338751106057316, 0.02442761637212243, 0.05108258861582726, 0.025733148759172764, 0.07218937244033441, 0.025391159688297193, 0.04321072468883358, 0.05968390207272023, 0.017517915366624948, 0.06011230310832616, 0.0023912216147436993, 0.08058454695856199, 0.04643754939024802, 0.03426257593673654, 0.062218559032771736, 0.08632481432869099, 0.009810666288103675, 0.01831670932006091, 0.03535581141477451, 0.05569639826717321, 0.07422636001138017, 0.0778161283233203, 0.041686590848257765, 0.08056320279138163, 0.02047901594778523, 0.05447251140139997, 0.026377854301244952, 0.020225216285325587, 0.02987086510984227, 0.009540751816530246, 0.04235764077748172, 0.06059282888600137, 0.048562470328761265, 0.06866910625831224, 0.09250352028175257, 0.03876873706758488, 0.008159291228366783, 0.06200040101248305, 0.03403883696591947, 0.022523545594594907, 0.018663809933059383, 0.027339169319020584, 0.04062485211761668, 0.07971339175128378, 0.07151427038479596, 0.047502676025033, 0.014115519861661596, 0.047725888070999645, 0.044401018240023404, 0.05757810256909579, 0.04552102298475802, 0.033860324474517256, 0.022323501543723978, 0.021481015501194634, 0.05002721009077504, 0.10259462098474614, 0.058743148256326094, 0.010208660605712794, 0.03905153243977111, 0.024587571460870095, 0.06958694997592829, 0.018301979544048663, 0.01631836908927653, 0.04058359612827189, 0.04240071131789591, 0.037345464807003736, 0.0653226139547769, 0.043533440184546635, 0.03323556229588576, 0.06747573279426433, 0.016819339180074167, 0.01888337246782612, 0.023340260559052695, 0.04481968229811173, 0.033277148540946655, 0.04635023571609054, 0.04695556104707066, 0.011885235289810225, 0.07807549409335479, 0.007601594152220059, 0.03255953997722827, 0.016079779743449762, 0.06596738443477079, 0.012380476928228745, 0.013366417333600111, 0.10522690005018376, 0.03964513183746021, 0.0332513106695842, 0.016697051796654705, 0.019825111485261004, 0.024512063500878867, 0.020927451259922236, 0.0934644159860909, 0.014253878453018842, 0.05239453130343463, 0.03141689972835593, 0.03399846413230989, 0.012111188643757487, 0.046048753065406345, 0.0066817809602071065, 0.09791611460968852, 0.024551801798224915, 0.026825684763025492, 0.022243054590944666, 0.04123559883737471, 0.05035388865508139, 0.07068650113069452, 0.022292949179245625, 0.0578026504808804, 0.01710438882582821, 0.025971892100642435, 0.06366977686411701, 0.06884777831146494, 0.0367337458737893, 0.06290973600698635, 0.035833876972901635, 0.05363636701076757, 0.033275564055657014, 0.012126253313908819, 0.05296948424074799, 0.02234180847153766, 0.057332640935783274, 0.006404596224456327, 0.00347237469668471, 0.05746094342612196, 0.043823983578477055, 0.01931854560098145, 0.008168241529347142, 0.025316456958535127, 0.04946135217323899, 0.053006840244052, 0.07694262050790712, 0.08326271301484667, 0.053473862644750625, 0.030396609945455566, 0.04663805913878605, 0.027505536563694477, 0.013468845772877103, 0.02235683881735895, 0.024261694416054524, 0.05634512068354525, 0.013184029903641203, 0.03625992911111098, 0.058863654485321604, 0.06286516261752695, 0.04246962344041094, 0.04198954295134172, 0.014688954179291613, 0.06114273062848952, 0.0321456442179624, 0.09636320770368911, 0.022013311645423528, 0.023205349243653473, 0.005860171531821834, 0.03219458143576048, 0.026298700540792197, 0.0934124730702024, 0.017941191872523632, 0.03289952524937689, 0.07794186298269778, 0.07034535810817033, 0.035449440765660256, 0.009950082439900143, 0.0028794794116038247, 0.05843835562700406, 0.017581007195985876, 0.09681863404694013, 0.015447494042746257, 0.03645532546215691, 0.04684907398768701, 0.05892399109143298, 0.019004036403202917, 0.023705404637439642, 0.027517596463439986, 0.027608435339061543, 0.04562192167213652, 0.028952613211004063, 0.03362971321621444, 0.030720073154952843, 0.0326849332486745, 0.07535121098044328, 0.03341595242090989, 0.020730023279611487, 0.07367032070760615, 0.019380657795409206, 0.024879391348804347, 0.021327609865693375, 0.021589432144537568, 0.02900070252508158, 0.02851982237189077, 0.030401383810385596, 0.016483714025525842, 0.02482457446603803, 0.0410711389122298, 0.04485327561269514, 0.01636361968849087, 0.03927680023480207, 0.07019919212325476, 0.05113292107125744, 0.03896188471117057, 0.04295607526728418, 0.05953800326096825, 0.009361064876429737, 0.05301629520545248, 0.02245969862997299, 0.025505802950647194, 0.04531365579168778, 0.03164769281283952, 0.06082305422751233, 0.029725116582994815, 0.03939569600333925, 0.0444426935428055, 0.0918255461147055, 0.027790246676886454, 0.0343655637698248, 0.02172116521251155, 0.07552258030045778, 0.04162732664553914, 0.06395850199623965, 0.0308248773944797, 0.03712530298798811, 0.03208514433936216, 0.059024763613706455, 0.03174753022904042, 0.015788037781021558, 0.04316188395023346, 0.020160846106591634, 0.09156827320111915, 0.0392038025893271, 0.05233295159996487, 0.04901266082015354, 0.11963153374381363, 0.022168750765558798, 0.062220956169767305, 0.0561044459027471, 0.03085414027736988, 0.06045953916327562, 0.03455329373537097, 0.04472046457522083, 0.05295599199598655, 0.05983322218526155, 0.0322311173658818, 0.13395183719694614, 0.27771943830884993, 0.09680123810539953, 0.19955846364609897, 0.11524754125275649, 0.12622492213267833, 0.09841903098276816, 0.13879865524359047, 0.11159731759107672, 0.11582380408071913, 0.1008781669952441, 0.14961942069930956, 0.1760284637566656, 0.20244783750968054, 0.14418433187529445, 0.11010885136784054, 0.17844344198238105, 0.13161061360733584, 0.09773223267984577, 0.23183620272902772, 0.10832751882844605, 0.0871080621436704, 0.05686472053639591, 0.14014728600159287, 0.08467734296573326, 0.12289661244722083, 0.11115220710053109, 0.14520883705699816, 0.20197510428261012, 0.22890084539540112, 0.08956143166869879, 0.19050089264055714, 0.14446704561123624, 0.10387172354967333, 0.17545552575029433, 0.09812459131353535, 0.068528046249412, 0.11804446578025818, 0.1823287334991619, 0.14302815485280007, 0.169728520559147, 0.18691940669668838, 0.20636775763705373, 0.0561738515534671, 0.1391194708412513, 0.1151019541430287, 0.18469710485078394, 0.1264643538161181, 0.15510116092627868, 0.2274337678682059, 0.19234569364925846, 0.1766292768297717, 0.22055199573514983, 0.13905229163356125, 0.1125645512365736, 0.11537065613083541, 0.10090896612382494, 0.11315763113088906, 0.09199393200105987, 0.12531383195891976, 0.1771254767663777, 0.09826536930631846, 0.13851255731424317, 0.16686402348568663, 0.2161651459755376, 0.15950858301948756, 0.16091006953502074, 0.122544589539757, 0.12364584763417952, 0.10962584681692533, 0.1861503190593794, 0.10441492369864136, 0.12296385102672502, 0.1583475968800485, 0.22732621582690626, 0.11240159787121229, 0.14246125792851672, 0.15400264877825975, 0.11880167905474082, 0.11557711419300176, 0.2372895335429348, 0.07796923338901252, 0.21428115956950933, 0.11417843299568631, 0.1477645116392523, 0.11239658837439492, 0.19065790140302852, 0.1662940243841149, 0.1641638675937429, 0.12658254825510085, 0.14569616090739146, 0.17061161692254245, 0.15635729039786384, 0.14220668643247336, 0.11999815469607711, 0.14729063550475985, 0.2284740807954222, 0.2796582842711359, 0.12719677935820073, 0.13394607813097537, 0.2772677078610286, 0.12768649292411283, 0.14182550454279408, 0.14787801570491865, 0.1647305121878162, 0.11871374939801171, 0.11893665345269255, 0.11899788805749267, 0.07051703170873225, 0.18317585054319352, 0.1019640700542368, 0.13271623553009704, 0.10637674655299634, 0.17907944769831374, 0.14974570454796776, 0.11869266498251818, 0.09216419552103616, 0.14913592633092776, 0.10311936392099597, 0.17373093782225624, 0.12846769241150469, 0.1594380641472526, 0.1804375185747631, 0.19593029661336914, 0.171878284891136, 0.12560689123347402, 0.11457016080385074, 0.08610724631580524, 0.16091927216621116, 0.09358784998767078, 0.19101904530543834, 0.19688547035912052, 0.1430049553164281, 0.2136006992077455, 0.09335886032204144, 0.15213803242659196, 0.06521918825455941, 0.12077153936843388, 0.08077355712885037, 0.12378101499052718, 0.13131059298757464, 0.13194606435718015, 0.17820448527345434, 0.15192457591183484, 0.18564015190349892, 0.17734040273353457, 0.10656799058779143, 0.15606911445502192, 0.13566560461185873, 0.14941288100089878, 0.11882246661116369, 0.15330574242398143, 0.09254604534362443, 0.16747289628256112, 0.16502351209055632, 0.09274025054764934, 0.14039848814718425, 0.14033168001333252, 0.0586021216440713, 0.1268666869145818, 0.1394969123066403, 0.1467569125816226, 0.09397793764946982, 0.12795437854947522, 0.1905077649280429, 0.13108354032738134, 0.18858281197026372, 0.15799534390680492, 0.1619036716874689, 0.11360911666997708, 0.13989204657264054, 0.06197639253514353, 0.19619656435679644, 0.17094792856369168, 0.18211866117781028, 0.14578471396816894], [0.047697864574729465, 0.020182579901302233, 0.00596730425968417, 0.0056727175524429185, 0.048849937520571984, 0.02878445553506026, 0.06488020488177426, 0.011912435929843923, 0.07124030656996183, 0.04792160354554653, 0.0450797382654855, 0.022317096809274517, 0.08469026375678368, 0.042201967880828306, 0.022355458422680385, 0.04148658576013986, 0.05103392599266954, 0.013143337946530664, 0.05828481269418262, 0.02548433818446938, 0.07949655846459791, 0.03832257272733841, 0.02771088511508424, 0.03599317526095547, 0.028527859831228852, 0.026030877997982316, 0.034614921678439714, 0.01776215616700938, 0.03154682752210647, 0.10719924655859359, 0.030033122711756732, 0.015641524842067156, 0.012950126292707864, 0.028163533970655408, 0.029921451750851702, 0.06152679205115419, 0.057455915375612676, 0.06009072887536604, 0.00852274692078936, 0.02604706423880998, 0.024851126654539257, 0.05688925964932423, 0.08598187530878931, 0.011677044312818907, 0.06739310949342325, 0.0420026047504507, 0.03485243119939696, 0.014382712506630924, 0.04887016475549899, 0.017368487642670516, 0.053954982140567154, 0.008516012858308386, 0.017949615248653572, 0.015165509466896765, 0.015444451237272006, 0.012971928736078553, 0.030355402195709758, 0.0917547674907837, 0.036338359277579, 0.021390037472883705, 0.024891965185815934, 0.02825686831783969, 0.007629476640431676, 0.02338883226912003, 0.04444616679393221, 0.07127784439944662, 0.03270962450187653, 0.03329534600197803, 0.05095512475236319, 0.022502609608636703, 0.0346737739891978, 0.04658582678530365, 0.049719467424438335, 0.04178478440735489, 0.068219438981032, 0.07962460120324977, 0.024785767564026173, 0.03502284685964696, 0.026189473101112526, 0.04621409985702485, 0.014232658595574321, 0.0441092985420255, 0.055597655518795364, 0.06640548905124888, 0.0469118188630091, 0.0408071272977395, 0.05582973994023632, 0.00048647919356881175, 0.07389380363747478, 0.02938241133961128, 0.002687302126105351, 0.016144387409440242, 0.0411436875583604, 0.0463144345121691, 0.07008944332483225, 0.028917513336637057, 0.056077884437399916, 0.02628518603160046, 0.04947258457832504, 0.0492056822986342, 0.019118306736345403, 0.057372460869373754, 0.0259199343418004, 0.0050975572776224, 0.01991200027987361, 0.06155125694931485, 0.04440551936568227, 0.04290420656616334, 0.0014297398456619703, 0.04879248786892276, 0.04964703010045923, 0.056768219074001536, 0.0499196357850451, 0.04881450739048887, 0.0629150794702582, 0.028263929852982983, 0.030538204300682992, 0.04738040719530545, 0.062013188216951676, 0.05267376807751134, 0.05006679624784738, 0.03640399852884002, 0.06097438184951898, 0.02641598770424025, 0.007755861606710823, 0.03192495176335797, 0.06738824100466445, 0.005647529060297529, 0.011387194826966152, 0.11411768078687601, 0.03556057366949972, 0.011186550564161735, 0.04209168102534022, 0.05668223384418525, 0.009359718806081219, 0.05158588719496038, 0.025770825741346925, 0.06494498695246875, 0.04363387874036562, 0.00026852166911339737, 0.07055646943626925, 0.0136221985303564, 0.03953565021220129, 0.0345291850680951, 0.02256600757391425, 0.058657894041971304, 0.04620804393198341, 0.020014084548165556, 0.11229253184865229, 0.0373053925432032, 0.03278662603406701, 0.08808599013718776, 0.05054951507190708, 0.019975878785771783, 0.03635718756413553, 0.040087592860800214, 0.013410129831754602, 0.03832486967439763, 0.03627162164775655, 0.1107714037061669, 0.026805418565345462, 0.030575714299629908, 0.031215714625432156, 0.01619439517526189, 0.013244999190646922, 0.03498163539916277, 0.011766769039240899, 0.06624922985793091, 0.0845120740996208, 0.02236247728433227, 0.06901050903252326, 0.04024578163807746, 0.035642209913930856, 0.07180007145507261, 0.04482529664528556, 0.03402527050639037, 0.038983592530712485, 0.035337309673195705, 0.052292434047558345, 0.02509970530809369, 0.010154532064916566, 0.014460856946243439, 0.017015180819726083, 0.03315543261123821, 0.028629673215618823, 0.06081685729441233, 0.03296092683740426, 0.03474936544080265, 0.04164973579463549, 0.03499970669508912, 0.01697030500508845, 0.0060717058840964455, 0.050552906686789356, 0.04195876608719118, 0.015474561096198158, 0.015694888970756438, 0.025726508392835967, 0.02740398107562214, 0.08355625468539074, 0.09357976057799533, 0.021097672106407117, 0.04320820138673298, 0.05644531061989255, 0.07288935870747082, 0.07365852055954747, 0.010859362701012287, 0.028815432779083494, 0.042739204873214476, 0.07129188583348878, 0.022596402232011314, 0.04982724211004097, 0.019298672741570044, 0.028379829200275708, 0.0630542915314436, 0.056148492367356084, 0.03818138655333314, 0.05240200844127685, 0.0392197810288053, 0.040103934952639975, 0.03293567155196797, 0.01663174836721737, 0.03311525273602456, 0.024097490531858057, 0.022874531350680627, 0.02541268382628914, 0.006340552126857801, 0.09322737401816994, 0.03265871317125857, 0.03784365741012152, 0.09191813645884395, 0.025351627336931415, 0.0028623135358429863, 0.015696759182901587, 0.10026537565863691, 0.04857443746004719, 0.0005574962324317312, 0.03299135860288516, 0.03918971662642434, 0.02903794164012652, 0.023377008001261856, 0.04378505051136017, 0.05506954694283195, 0.047775797502254136, 0.05315878755936865, 0.057316725578857586, 0.08063179950113408, 0.0312400496477494, 0.014733511798112886, 0.017331434064544737, 0.020862691453658044, 0.06061428808607161, 0.07455173981725238, 0.024571411195211112, 0.024960840200947132, 0.026375479428679682, 0.04775267960212659, 0.024829446665535215, 0.06719377604895271, 0.05980927679047454, 0.04978853168722708, 0.042198913943138905, 0.025762398654478602, 0.08241575924330391, 0.015174406889855163, 0.03742370201507583, 0.02234406831121305, 0.020971070989617147, 0.06288153439527377, 0.02554167094785953, 0.02900108473113505, 0.05521908969967626, 0.11252864613197744, 0.026090047576872166, 0.04800293179869186, 0.060701141628669575, 0.0659620483929757, 0.05746266520873178, 0.0708845432382077, 0.010890279645536793, 0.016803152939246502, 0.056733928140602075, 0.07338639727095142, 0.051289658949826844, 0.048179455334320664, 0.0206861104015843, 0.02499700876796851, 0.039291097709792666, 0.008017684813239612, 0.02827371507009957, 0.04299589149013627, 0.020964849936717656, 0.0319975375168724, 0.014484633502434008, 0.0582874732936034, 0.031178692588582635, 0.040964377258205786, 0.03320920863188803, 0.03545214960468002, 0.08442725404165685, 0.08768143801717088, 0.04086848064616788, 0.09130766804446466, 0.043760522530646995, 0.02274220641993452, 0.06222142001206521, 0.12681862543104216, 0.06358963233651593, 0.02240376667032251, 0.06752012806828134, 0.07031131579424255, 0.013638517430081265, 0.025144421560980845, 0.04103068444237579, 0.008999770689115394, 0.0175076125015039, 0.032313918782165274, 0.09473455720581114, 0.05368040605389979, 0.044578480592463166, 0.013925083840149455, 0.01030701558192959, 0.04230611346429214, 0.032901547601795755, 0.05389117228332907, 0.0671820501156617, 0.023413668241119012, 0.010970136590913171, 0.028436744505597744, 0.02046413217613008, 0.06371449126163498, 0.03512881441565696, 0.0502544928167481, 0.031114276025618892, 0.03821368853095919, 0.014360626191773918, 0.07851940972614102, 0.032756275904830545, 0.020353867585072294, 0.033259715492022224, 0.01291387052333448, 0.05823692561534699, 0.042020134278573096, 0.04545402931398712, 0.044290723963058554, 0.04191166197415441, 0.07716612570220605, 0.01285194572119508, 0.05094128369819373, 0.015879566853982396, 0.013466515429172432, 0.04371340728539508, 0.08386756337131374, 0.14103765541221946, 0.08932865704991855, 0.1337653206428513, 0.07293392467545345, 0.14628435746999457, 0.1208699110429734, 0.14509684697259218, 0.15916505770292133, 0.15557521517621353, 0.11795028724009171, 0.1497048418968916, 0.17082771548302844, 0.17700955329928547, 0.11989685153821483, 0.10913053745753132, 0.1328019832726568, 0.10612195983412676, 0.12911457801237702, 0.13113709370372817, 0.09437296801479533, 0.1818392871064134, 0.10049594609881751, 0.15775367093738168, 0.20085900323465466, 0.1368866304983385, 0.11259838574915193, 0.17518066393677145, 0.2120140171609819, 0.19003344350494444, 0.20610045088687912, 0.08466409562970512, 0.1858071648166515, 0.1040189953346271, 0.0882716903288383, 0.14412169461138546, 0.19877008016919717, 0.08834163032588549, 0.15098973701242357, 0.10411136303446256, 0.11732803352060728, 0.10641065528034233, 0.15121668577194214, 0.18329539569094777, 0.09026912885019556, 0.16024730197386816, 0.11959826326346956, 0.21259655855828896, 0.13624992716358975, 0.1103672078170348, 0.069435499899555, 0.15344829414971173, 0.0990075763547793, 0.15458573936484754, 0.1652897204621695, 0.18068324367050081, 0.09914885900798254, 0.11420684983022511, 0.20453232253203169, 0.06861649540951476, 0.17541757231811062, 0.1505907584214583, 0.0847229702048935, 0.11581584083614871, 0.1082796799892094, 0.17450207378715277, 0.2551984624005854, 0.1466997226816602, 0.1576432542060502, 0.2658070478355512, 0.19621333689428866, 0.1466178786358796, 0.13774918421404436, 0.11629715329036117, 0.07547077097115107, 0.17207338067237288, 0.1320359978126362, 0.11158335037180223, 0.07877205905970186, 0.14472255221335217, 0.24023857607971877, 0.09849999929429032, 0.14250831009121612, 0.07875709736254066, 0.11045669598388486, 0.14366172632435337, 0.09157705280813389, 0.13364880345761776, 0.07668004123843275, 0.15865204069996253, 0.12055109182256274, 0.048342353038606234, 0.1062357088085264, 0.12218932344694622, 0.13055266725132242, 0.14253112371079624, 0.18294810026418418, 0.1300240948330611, 0.11723248200723901, 0.1531294675078243, 0.23554383893497288, 0.12220320902997628, 0.1308761545806192, 0.06273378021433018, 0.15341167658334598, 0.19665877392981201, 0.1761596160940826, 0.1330979072372429, 0.11933733156183735, 0.09971148116164841, 0.11287154804449528, 0.12892141181509942, 0.11117227477370761, 0.16112852812511846, 0.191098662908189, 0.10517865302972496, 0.12604826129972935, 0.11031726127839647, 0.07717666419921443, 0.08588967830291949, 0.14527404215186834, 0.2041161706438288, 0.12224306978168897, 0.16876510897418484, 0.1472391007700935, 0.08844567200867459, 0.16258521558484063, 0.19712426379555836, 0.1893523448961787, 0.11468321215943433, 0.29273186868522316, 0.2186408021952957, 0.15781883150339127, 0.1793981110677123, 0.25359408755321056, 0.10533763590501621, 0.12257175214472227, 0.07993651845026761, 0.2011305995984003, 0.11766162147978321, 0.1873200773843564, 0.20406711468240246, 0.13346433523111045, 0.1627083824132569, 0.11186981937498786, 0.12720292434096336, 0.21159949799766764, 0.12911301950225607, 0.1348855035030283, 0.18935498694190755, 0.1616535530774854, 0.08788680512225255, 0.18618686241097748, 0.13615801959531382, 0.09682164716650732, 0.10074208679725416, 0.094861360557843, 0.15278468054020777, 0.17910708527779207, 0.1638848942820914, 0.19945629959693179, 0.12793523113941774, 0.0921380496583879, 0.0946816272335127, 0.0993784423917532, 0.1075332352775149, 0.0930367385444697, 0.12340685381786898, 0.2755923243239522, 0.20118620130233467, 0.10992423471179791, 0.11464857612736523, 0.18472410418326035, 0.12811123888241127, 0.18611730833072215, 0.2297788209398277, 0.14753689494682476], [0.02525360632716911, 0.010739353710960131, 0.0474008682067506, 0.049336901429342106, 0.03480427694739774, 0.05887820429052226, 0.028363462988636456, 0.052897733403369784, 0.055562310735695064, 0.02497053450497333, 0.02050275910733035, 0.11966801030212082, 0.03307628627226222, 0.025704492582008243, 0.0362070733535802, 0.03103983119217446, 0.044845245574833825, 0.06707063148496673, 0.032057024363894016, 0.021983794576954097, 0.0181019651790848, 0.06636071528191678, 0.08218374161515385, 0.01817474574636435, 0.07465439368388616, 0.04143325502809603, 0.029044257316854782, 0.0340588823746657, 0.013894204930693377, 0.07074983601341955, 0.020879998337477446, 0.03888909115630668, 0.01583547029440524, 0.014256529775593663, 0.017089419707190245, 0.02332690746698063, 0.020093013808946125, 0.01075394340659841, 0.01738638267852366, 0.021755725174443796, 0.04478963644942269, 0.013448746558424318, 0.06722621532389894, 0.029058532527415082, 0.04459869298443664, 0.05324029392795637, 0.040192666128859855, 0.03711448618560098, 0.08638218976557255, 0.029415039862215053, 0.04156384333327878, 0.04733662790386006, 0.01800431709853001, 0.06685016167466529, 0.04156891591264866, 0.05661624949425459, 0.05495259189046919, 0.09014034396386705, 0.07851088244933635, 0.07176206607255153, 0.032822776047396474, 0.05082768315332942, 0.031922907146508805, 0.03313753943075426, 0.05758804363722447, 0.03822029735601973, 0.02117806154274149, 0.11595670788665302, 0.04538578512438107, 0.02234924479125766, 0.06020540924509987, 0.0400093593634665, 0.035311649917275645, 0.025785384823393542, 0.05454267775348853, 0.09251198818674311, 0.01918679026857717, 0.030594987874792423, 0.05900095922697801, 0.020956313383067027, 0.028557347213791218, 0.02789162033877801, 0.036067490218556486, 0.031111710050026886, 0.044173995265737176, 0.054556611576117575, 0.04146644758293405, 0.08072868688032031, 0.05671051338140387, 0.02494272808689857, 0.006301836601778632, 0.003492830373943434, 0.0407421040290501, 0.03280839322542306, 0.0254950009912136, 0.051669965105247684, 0.011822719552583294, 0.052551959379343316, 0.004607762539308169, 0.03850425418931991, 0.04477101596421562, 0.018192011812061537, 0.017166526995424647, 0.029898959110141732, 0.031420521409017965, 0.06322988367173821, 0.06777605027309619, 0.03484006330836564, 0.04899861196463462, 0.008503723820467712, 0.029968539165565744, 0.03981577385275159, 0.05868667081813328, 0.018728682916844264, 0.02879580297303619, 0.03206057554052677, 0.03730924057890661, 0.1129352836869657, 0.07072809850797057, 0.03451928110735025, 0.06769409490516409, 0.046981996347312815, 0.03509750320517924, 0.011703014843078563, 0.03156270206090994, 0.016579939037910663, 0.039424420829163864, 0.009581530048308196, 0.12663117377087474, 0.11027138170902617, 0.04543423252471257, 0.09451615798752755, 0.02500635240721749, 0.023788454673194792, 0.03676741340314038, 0.058499404694885015, 0.025063666616915725, 0.03896674948919099, 0.06459185082348995, 0.07145135852624662, 0.020528953209577594, 0.06213677806954365, 0.06230927916476503, 0.047698128037154675, 0.014522553537972271, 0.0563097425037995, 0.07601472068927251, 0.02099865290801972, 0.05973804545646999, 0.03578891766665038, 0.048077825631480664, 0.026112356536032166, 0.0031425116230821004, 0.04269644232408609, 0.04925716879370157, 0.008453129757981515, 0.050093175887013786, 0.05252783215837553, 0.03496340083074756, 0.03123543348920066, 0.02359936472203117, 0.03591772481740918, 0.020687689320766367, 0.05501380052010063, 0.030596572360082064, 0.052876652698614635, 0.049727627338143066, 0.01938067263836274, 0.09230942639987916, 0.07512172407587059, 0.06360984101775102, 0.01696492443443276, 0.03977868502261117, 0.09013921589939855, 0.01865273152361624, 0.025431758876948152, 0.05847247586643789, 0.012348133204795886, 0.006869486342111486, 0.08015167448320426, 0.04064618144184351, 0.056243557773996145, 0.04315799138566945, 0.04707844585936982, 0.011331865862302948, 0.026926574173558038, 0.03982256450399291, 0.0649917199916672, 0.04583048001222778, 0.029384827030298766, 0.09136664652032778, 0.021330352101358585, 0.0692223699297756, 0.07334750873269513, 0.03867137842462398, 0.041190572737832554, 0.009952669752237853, 0.08685930908541195, 0.051123480952810496, 0.011806315305875614, 0.05096517714264337, 0.017781984497560188, 0.10573265884886496, 0.015988733066478744, 0.02971206406073179, 0.12931319157360122, 0.010021423240687, 0.07432329191942699, 0.03066126722842455, 0.02755877452727873, 0.033767804634408094, 0.021898421618971042, 0.022085292548581492, 0.016126778100442607, 0.01885293884697603, 0.057443807236268185, 0.011081405864388216, 0.006034662046658923, 0.034568548580864444, 0.01660988840740174, 0.013822240725858137, 0.008751847908570198, 0.02788076271826867, 0.012678126386163058, 0.04275868253898807, 0.05273300630506128, 0.02932164614321664, 0.03813566283497494, 0.03447655195486732, 0.06345552625134587, 0.02509821544663282, 0.017874988589028362, 0.010955231482512318, 0.047239180203177966, 0.07505391404265538, 0.07707060387474485, 0.046444391991826706, 0.05726438561396208, 0.02999009670020314, 0.028769497548637446, 0.07043152887490578, 0.05309282547386829, 0.04208119818940759, 0.0466298806713894, 0.03170534655509982, 0.03705084331159014, 0.0972165958955884, 0.0480590938241221, 0.03137150626571383, 0.04494237786275335, 0.02159091458452167, 0.04972161965270061, 0.03917921523679979, 0.02986419505759841, 0.07303272679564543, 0.07998085435247049, 0.06555373358423822, 0.005271066302157124, 0.030330781446537003, 0.01294600830078707, 0.056171113028540276, 0.0807028156123124, 0.04567758645862341, 0.08161826961440966, 0.0816552434116602, 0.060516543526318856, 0.05897185219509993, 0.025287292410212103, 0.058251675800420344, 0.03840973797196057, 0.06980320438742638, 0.043374709639465436, 0.09438597786356695, 0.061463119491236284, 0.015306088935176376, 0.017609227361390367, 0.09065690101124346, 0.0069461386010516435, 0.01548906173411524, 0.03760403276828583, 0.05672947154380381, 0.053557866340270266, 0.02466094389092177, 0.029158201105019543, 0.029530473511840682, 0.03641268536739517, 0.05414040031610057, 0.0467905593541218, 0.036048598849447444, 0.029398204242170323, 0.012774741026078118, 0.03359352980623953, 0.05142230300407391, 0.10436263197334483, 0.02504305160982767, 0.0456555224081967, 0.01406357972882688, 0.010379707091487944, 0.05257080621959176, 0.03130624179902952, 0.016861500589584466, 0.044666911198874004, 0.04556072788545862, 0.015095029557414819, 0.06177344112074934, 0.02396327497990569, 0.051501412235666066, 0.07138215325539932, 0.03172065335093066, 0.026581314086797647, 0.06271642138017341, 0.030557628160750028, 0.02556554027250968, 0.03193047334207222, 0.01796948996343417, 0.03603748889872804, 0.02263802929519443, 0.034675710994633846, 0.053781056121806614, 0.0543089049460832, 0.12264997450984083, 0.0655022136925254, 0.025167142412101384, 0.04541703325230628, 0.10357355087762699, 0.03249664296163246, 0.015614421608916018, 0.026251772687828634, 0.03985672927228734, 0.019550028882804327, 0.01925385444337735, 0.01720407966786297, 0.06969591951929033, 0.022763376182410866, 0.02537067270168336, 0.019914310214517172, 0.026915610797004774, 0.06205734971445054, 0.06405382344382815, 0.049093280322267674, 0.02404546412435593, 0.04489519211347215, 0.08900295812054537, 0.06330135991447605, 0.08914289006497711, 0.05058039212599397, 0.049776134110288695, 0.030277029545686673, 0.0035569786041378393, 0.04100251622730866, 0.03227622510166839, 0.011261500985710882, 0.18089310819050297, 0.0802121966262348, 0.1799858029698953, 0.16196841665077955, 0.1634305514744483, 0.14466862776316702, 0.09967829231754877, 0.17792052472941577, 0.09839716731221415, 0.08263414361863397, 0.09823891916312277, 0.216591450443957, 0.163345234177541, 0.11239383500651456, 0.13340413221158087, 0.08556497385143302, 0.14505815139273182, 0.21926089626504108, 0.14598847803426906, 0.15418071969179437, 0.08913077821489424, 0.3508344618603587, 0.1113662870193366, 0.10531642532441765, 0.15693215798819438, 0.11724999669240788, 0.12239161806064658, 0.10753429654869251, 0.08118209458189085, 0.2469598810421303, 0.06809541868278757, 0.15034942683996633, 0.08395255412324332, 0.1285588281461969, 0.20952550694346428, 0.08401033774134703, 0.09458024986088276, 0.07527829497121274, 0.10566680066403933, 0.11340026147081517, 0.21127820742549375, 0.09528347189188935, 0.09732257458381355, 0.1377475366462022, 0.16240309254499152, 0.155404610268306, 0.08933384466217831, 0.19647390494355932, 0.1693465223070234, 0.08831451967125759, 0.07781905238516629, 0.10754597795312293, 0.06177005692734383, 0.19431519031058997, 0.12524044839665294, 0.11444409959949553, 0.10624275178997777, 0.1903504296205938, 0.13853332260623574, 0.1914124281029217, 0.1328429498244077, 0.1703111213282682, 0.09911131375702098, 0.11320151432300918, 0.1362933576456271, 0.09384927892824635, 0.05937714646279346, 0.16296862391754985, 0.13090986292809248, 0.09847523382632062, 0.26986395358107984, 0.14565062272595242, 0.18137498467694968, 0.19058100006077439, 0.22063845593947917, 0.2056297066155821, 0.11254458746407181, 0.20221352664520964, 0.15164082316914573, 0.1053355356270913, 0.16866371675860137, 0.08375874225748703, 0.08621905828476883, 0.11952111701248214, 0.24875993054592982, 0.2123033211682923, 0.1893327373545617, 0.23220735078211874, 0.13679444091394544, 0.20361989649245515, 0.133424021769315, 0.11959858238697052, 0.18704696703935042, 0.13111620966810733, 0.1663566319621168, 0.08436851305305026, 0.16729285125620663, 0.18471469375072047, 0.08769879685132764, 0.19930939888581634, 0.12896475323941559, 0.15678564319387078, 0.11912173766177148, 0.14767987711820751, 0.11740705740521662, 0.10223669800325297, 0.2677658130414784, 0.10155355848837644, 0.08209897350752726, 0.1377512325416319, 0.1430366004933603, 0.11490702163428068, 0.14185277104843408, 0.13217776286182925, 0.08674000142491423, 0.12371843709843233, 0.16468541929498315, 0.18139102990971878, 0.25221954099833965, 0.14206276915501803, 0.16852538043167442, 0.09728750810609199, 0.10936057355138473, 0.16826648963615298, 0.13177042768802494, 0.16295820416416973, 0.13178770488593727, 0.0870878534624353, 0.21886199188884348, 0.21375414566136897, 0.09920916592818685, 0.18753935233689845, 0.0886634032940492, 0.18074680119752884, 0.11854091062559746, 0.15538978215772659, 0.09744480630615726, 0.10193791677011177, 0.1776628362131305, 0.10198804884566925, 0.13977379276184365, 0.13666866172570735, 0.11429859412601218, 0.1913613238139078, 0.1687380502698943, 0.2097649683128111, 0.12670075753703713, 0.13443703850498423, 0.1324624358676374, 0.10724310006480664, 0.1717363714124076, 0.18268018495291471, 0.07480369153199717, 0.1263379809097387, 0.10867448771023192, 0.08958641978097148, 0.20986526214983314, 0.0964752868458163, 0.11168451252160594, 0.1285555330105126, 0.08013861268409528, 0.1307737233582884, 0.143033305357676, 0.12846631201682612, 0.10832890664460137, 0.17895714176120237, 0.2691731625236571, 0.18817203323123977, 0.24586694984463975, 0.1877435320056975, 0.20141717250226066, 0.14311270031612366, 0.11456252410425805, 0.1059231607359834, 0.13290251459693536, 0.1511830961680971], [0.022950352868065238, 0.052084606722928584, 0.03350332917761989, 0.041549501329427585, 0.02997213672642829, 0.035210595378885046, 0.047806540969759226, 0.04010963093605824, 0.06812684863689356, 0.02405172970611602, 0.02733214303589193, 0.03610859777836595, 0.03122885806078557, 0.03151177217660006, 0.01518049621154205, 0.04509473335929215, 0.06541064009070396, 0.038842818248667754, 0.06951076109544374, 0.043822951993206516, 0.015068364191392902, 0.0682591661461629, 0.05023009842261672, 0.0259743782953592, 0.04004937596619129, 0.009156807282124646, 0.03564309678040445, 0.01275240052564186, 0.04093756346264854, 0.014627486725657945, 0.07647584672668017, 0.028682669981208164, 0.027117643803649116, 0.04567209085507784, 0.021454730485857, 0.031931961348163895, 0.04315967235015705, 0.010181832894886611, 0.013986667254357599, 0.02290021893713856, 0.040763010329101235, 0.0050922819991683355, 0.043920496173086576, 0.050557381837279536, 0.014710945870319847, 0.06503227836219594, 0.038399500044761226, 0.038881550935911946, 0.02465553548972821, 0.04578825923090335, 0.049778635147958994, 0.06534272615681402, 0.06554374427651055, 0.019328442140249535, 0.01790946877008537, 0.05804226399050094, 0.0253766395690036, 0.023807587240298744, 0.023275081439351197, 0.03734734244062565, 0.09694838372524828, 0.02233037754194811, 0.027925145004701335, 0.016031252562243026, 0.025854187479126267, 0.044996599172009155, 0.09630111962906085, 0.027765835584432352, 0.013126178564561997, 0.05083149779238738, 0.05810557660879567, 0.01480316885135835, 0.049574759759707376, 0.030485708484775387, 0.0856290063529741, 0.047955920454114676, 0.0070181501178012695, 0.018630288977874443, 0.07523109437897801, 0.03091553815465886, 0.03246379550546408, 0.04471512482268736, 0.03151465170958545, 0.007652845015400089, 0.012420513940014644, 0.025552881088515278, 0.021141302968317177, 0.04696871190390084, 0.06263339731958695, 0.024935128494689707, 0.10398622209322639, 0.036665869047283195, 0.03209585353033617, 0.06259511734242551, 0.035331101607880555, 0.01543532096548006, 0.07601480232551694, 0.03587391955079511, 0.01956812986463774, 0.03761275300348643, 0.013020423448324436, 0.038711101879016496, 0.013755487325397553, 0.05260284844553098, 0.03600083051424008, 0.044094960248912685, 0.13241293461760506, 0.017711309774313122, 0.022101903668954037, 0.05007839230529498, 0.08872358404914849, 0.044813114291173406, 0.04057610043673776, 0.04320747408200987, 0.10323014430468902, 0.04003163492598105, 0.03189132876286749, 0.016664796203258447, 0.01806991367629962, 0.06470721767982468, 0.06602181354537606, 0.029983688255015295, 0.04435537244717125, 0.05598040334007237, 0.002721462024055654, 0.041211367715732194, 0.06722969599650241, 0.013780276913166745, 0.01034172304571257, 0.05006419502024073, 0.014095426213316387, 0.05106289572722744, 0.08307802214403637, 0.028704004871542566, 0.05060473456978798, 0.011633828125923174, 0.07106342309270985, 0.022191833413671702, 0.0454095486929873, 0.011579798847378697, 0.03934043939807452, 0.03347714249684941, 0.0181778330806992, 0.07731324905762449, 0.040875976337702014, 0.042328671042923816, 0.04375568372779526, 0.04116340271139052, 0.03776988050958607, 0.03064730186451925, 0.07380296476185322, 0.0748435448622331, 0.022754789533792064, 0.019069189547735732, 0.05060146540927235, 0.051782808659481816, 0.03452036835369654, 0.015444303735421272, 0.04357272948254831, 0.012470695182855707, 0.039025995138217695, 0.0772570313711185, 0.04649388953112066, 0.03413090409594588, 0.027859032634296454, 0.023188185223261826, 0.02705360202526208, 0.023981481717783026, 0.015287179940060014, 0.04310452706704382, 0.01854376012488501, 0.038878864361322485, 0.0326966183638433, 0.004631790498024202, 0.05245987369562499, 0.015040647758723935, 0.00649047848128248, 0.03597764211008325, 0.04210818267893046, 0.06894099205965176, 0.056446460948791355, 0.02445949532557279, 0.02343170428503072, 0.03294118199846707, 0.059547654891503043, 0.03431422570429277, 0.0403689595987089, 0.03268469576141797, 0.016354383660655003, 0.02249346078315284, 0.06341469328617677, 0.07513774704420939, 0.04842500602535438, 0.018178649443143513, 0.040281282272189856, 0.05207636146224104, 0.017302948581345845, 0.08692394272657111, 0.01566104889207054, 0.0024545312180634937, 0.03221783663320821, 0.048788636122480966, 0.03457480117504019, 0.057400866571697406, 0.03808597975876182, 0.025540702445141505, 0.04406355626997538, 0.058844432860496454, 0.03209809110558126, 0.04793899577634875, 0.03294598369393498, 0.03981480163929518, 0.11834049364551902, 0.05709482342354022, 0.0590503380226437, 0.07504290799261071, 0.020245686573616695, 0.04599776380928233, 0.05690687081369106, 0.031020073365652934, 0.04528933932306245, 0.008996632332127774, 0.005505306198756443, 0.006905677173563163, 0.05811739159980789, 0.010209266383753857, 0.07221031584776938, 0.02003458452236373, 0.048343915259465575, 0.05384168587625027, 0.04703898215666413, 0.03520611651765648, 0.022505377819470596, 0.02446689824864734, 0.03707179785124026, 0.02047835358098382, 0.03351679173647426, 0.01827907130063977, 0.0410455533710774, 0.04897048456768971, 0.07190007585450076, 0.05355297187634278, 0.050762132959789596, 0.09194387414027005, 0.04207353922538459, 0.0209796465060208, 0.06852362304925919, 0.04107046355784405, 0.09508317365543917, 0.013164079118723748, 0.03935685570468195, 0.07541813785792328, 0.03607886734243948, 0.0936204005847685, 0.03226508546504192, 0.10233296197839081, 0.008236668472818565, 0.0510507987200981, 0.05457684994325973, 0.035004742167075165, 0.04297561972634867, 0.034437199574313127, 0.05206105095567182, 0.007712338356213877, 0.04402483471494634, 0.005811932396682096, 0.0548179848556174, 0.027728036147891544, 0.022159455365908798, 0.039005344879115, 0.015416763562825508, 0.04863075904722791, 0.07362454503891058, 0.023935589160828386, 0.023380022976198234, 0.03443986759521067, 0.01347109262496815, 0.06072235592000652, 0.025471701264905278, 0.0170198248088127, 0.04271541904017795, 0.04023812638479285, 0.05463805857289117, 0.06618349041673355, 0.030106697377050295, 0.04275308674550615, 0.05427493684692308, 0.060732642086804844, 0.07345336867729202, 0.039202618863782845, 0.0212851107789902, 0.04552580983727239, 0.018570534957689233, 0.02368411613133503, 0.03803176587098278, 0.06605839400435798, 0.0343129121029051, 0.03795260097831488, 0.021499871618289035, 0.014291950628830818, 0.03513026902510319, 0.04379567806608975, 0.03394008679606486, 0.03380464855581522, 0.045005812935414724, 0.04326944712374825, 0.009224070909112925, 0.030262939872045536, 0.06062999564164784, 0.03602550692448858, 0.029403668304439634, 0.05273848706565332, 0.041036788607016206, 0.08176727802492678, 0.0795888964785263, 0.07449992306646891, 0.011734879881259985, 0.04351178802608047, 0.015105414058780298, 0.07656698988284916, 0.02363699717534473, 0.03218465521058533, 0.041908129351213574, 0.03522967228491325, 0.007441798161380575, 0.024314153124578297, 0.03464141263975762, 0.04388626090076286, 0.031334602972492576, 0.08576067819376476, 0.03497104495181702, 0.12312491933698766, 0.061127063891035505, 0.00857254781294614, 0.04033396362501662, 0.015833286524866708, 0.047482682566624135, 0.026228213209833484, 0.021875003149034455, 0.01951726862898795, 0.1096607574436348, 0.019493909530865494, 0.03562634279660415, 0.02658990073541645, 0.062498667830368504, 0.04599496220180299, 0.05027517647249624, 0.08027470772503875, 0.03273126181738917, 0.03753475328267086, 0.05055735586211085, 0.04478623370232526, 0.0941297884855885, 0.18120329623343423, 0.1696964746224694, 0.23046395683195442, 0.09643711076932959, 0.10143650695681572, 0.24851879192283377, 0.09073948720470071, 0.12054577062372118, 0.10962916421703994, 0.1339260401437059, 0.08521442039636895, 0.14374517340911552, 0.15299749880796298, 0.1281680873944424, 0.19307157344883308, 0.17395082133589312, 0.12044635252095759, 0.15813370991963893, 0.17374361370457336, 0.1459993579192087, 0.22233153227716684, 0.16978605184704065, 0.07923619821667671, 0.12693825963651761, 0.0663501545204781, 0.09940674048266374, 0.10711475304560736, 0.19483974028844386, 0.1331386956735514, 0.1908188287052326, 0.11856370940222405, 0.1753838936565444, 0.17349239671602845, 0.16395441867643967, 0.11738191344193183, 0.15341473423177376, 0.138895342242904, 0.16084541362943128, 0.11735067644622177, 0.1404999100486748, 0.14603174524381757, 0.13619906036183238, 0.13727610959904268, 0.10621152963722125, 0.13709950813790783, 0.13133134343661368, 0.13505440147127956, 0.09234726850991137, 0.16407856513978913, 0.2654020133195445, 0.12079482054105029, 0.16231476212851703, 0.11946389742661268, 0.1416633601184003, 0.13010969414608553, 0.08700971273356117, 0.13432602805551142, 0.11411619649152271, 0.15952142217429355, 0.17591194657143205, 0.06068565671739634, 0.22657045716186985, 0.16815723065519705, 0.16379450069507584, 0.13352171808946878, 0.20709724427433684, 0.22006772953318432, 0.1404622386326082, 0.17371449182974175, 0.14821066113654524, 0.09492890341789462, 0.19355536467628554, 0.163769104401581, 0.1893988627125509, 0.15922500839224085, 0.1287130909622647, 0.1504071065573953, 0.19753812986891717, 0.16798358294181526, 0.1373029753449373, 0.14037289889529347, 0.17916489858180285, 0.12908042437629774, 0.14720243867486715, 0.07584191902424209, 0.13758543675066903, 0.1468025249778293, 0.15995443565770984, 0.06363225387758575, 0.14753640512935817, 0.11269173308392055, 0.1352164865238592, 0.16799121221993119, 0.22912831365829334, 0.14572590618627146, 0.18787354143569246, 0.08218981980462559, 0.14450327726081014, 0.13166710588848218, 0.08172473069862463, 0.10279215101036243, 0.14316240936750546, 0.14077103143790737, 0.17159096983959898, 0.128079118730966, 0.17158190079499036, 0.23160040756920353, 0.08451142100966536, 0.18179655424319208, 0.1330663065891713, 0.16806493717012927, 0.14706503745401278, 0.13105257792631164, 0.301400717580691, 0.14103781868470833, 0.10519731062231585, 0.10988787689711899, 0.19331286050146446, 0.19588357099564746, 0.12073349687852897, 0.16301652212860063, 0.18810032692272216, 0.1296743206330575, 0.13797078951029107, 0.12097436090698466, 0.16731060342863202, 0.11938412397284992, 0.24130967329256237, 0.20178380829747766, 0.05388925383158494, 0.17373121983837336, 0.09530790339340456, 0.12911909027025104, 0.16944690520176664, 0.11200739871128462, 0.17070793284801766, 0.1775782016920857, 0.18181408377131447, 0.14502454694593325, 0.12678230472374707, 0.13735161570366472, 0.17968878062674776, 0.1289309558342211, 0.13151245715562254, 0.07913867259048857, 0.26711797749157995, 0.18963437585625798, 0.16825918690301478, 0.11631108340225182, 0.2231426106300205, 0.19089221226749942, 0.13890289730625227, 0.16832127497764304, 0.20272569759981707, 0.2680429012980312, 0.12993500742595643, 0.08841634233249351, 0.0762061651039403, 0.09390431659994647, 0.16584092838456854, 0.13250215561129153, 0.2091144907171838, 0.07223022024845704, 0.2282769960584119, 0.08506053607561626, 0.07736272062174976, 0.19788664241787046, 0.1692597207147628, 0.10901413159444928, 0.10350696538807824, 0.15624209423549473, 0.11952546599786729, 0.12732947536278516, 0.12547973165055737, 0.11680268944473937], [0.007709231076660217, 0.07185721682617441, 0.0365820323349908, 0.07406212273053825, 0.03271664521889761, 0.0407065588660771, 0.08685802516993135, 0.033628236342337914, 0.05380630769650452, 0.011545942070370074, 0.06755034832167439, 0.010768516403913964, 0.055380410340148956, 0.03039624629309401, 0.013115662331983913, 0.06071588439226616, 0.03851296329230536, 0.05022374934924301, 0.020054898959642742, 0.026642765769793186, 0.05771966723841615, 0.03790723349084146, 0.03627911733929068, 0.009152940692729317, 0.010219657378911506, 0.02702190675336169, 0.07753008234431036, 0.05611319582385477, 0.03334748929773923, 0.03572821740817744, 0.012076966359018115, 0.032818564359331504, 0.03673874423839152, 0.018534236514824443, 0.04744359364849515, 0.0548055687249871, 0.06561959919054061, 0.05242328952590469, 0.019757256923185196, 0.07483570778276771, 0.07629801330040209, 0.028627623032662086, 0.03112034308287548, 0.03652544357464649, 0.06729222935973667, 0.05802887193567585, 0.0030378043265955057, 0.048383879911853, 0.02639753420226043, 0.060227799840504304, 0.07081746793119237, 0.028465157629398163, 0.015088773252500687, 0.03875688496918883, 0.06084167842345778, 0.005641857660521055, 0.06700560450553894, 0.03634008848166559, 0.06438295109546743, 0.02062280706013553, 0.02978510437969817, 0.009793939207156654, 0.05124062154209241, 0.04077185672940686, 0.03625619239755906, 0.012547092792374315, 0.007857764048821991, 0.04532080267381389, 0.04820764952455647, 0.030940743345126975, 0.022831989590486046, 0.04010007207398303, 0.002284420070282067, 0.03876570539432578, 0.05304731326759793, 0.03785799941397272, 0.017663014514255337, 0.04599234613124281, 0.08991118360427208, 0.04706637111667078, 0.02300916992680868, 0.0339808010176057, 0.03384027906577103, 0.016128357019624673, 0.045409945741994306, 0.023792918691469822, 0.03148342213535216, 0.023998565957299434, 0.030625271210737992, 0.006089100897952449, 0.028535630117403343, 0.04716321767773479, 0.04519659312791191, 0.05103667193907313, 0.06682395644020289, 0.03507918328978121, 0.04477147238503676, 0.014528185511153424, 0.04683516614022665, 0.021434263908304274, 0.018021275172941387, 0.0053718216622655746, 0.020683668735728133, 0.10316476851585321, 0.05324085424945224, 0.054055673026596196, 0.08102487059659325, 0.08027072239201516, 0.04644049200578593, 0.0811453879578039, 0.014497466163447825, 0.003129587817056745, 0.0664569644141011, 0.045430566315189935, 0.02516992546588881, 0.02812937291309936, 0.011377578448446002, 0.0601329867640743, 0.07341401258599944, 0.018205416854470968, 0.029441642145684455, 0.027283682647976093, 0.02451127496897243, 0.037200007573119365, 0.029766264960926492, 0.06273341656196862, 0.01798267607227899, 0.03131208250124473, 0.09591960377292708, 0.055215364118339494, 0.09058286435902119, 0.04018472143798135, 0.05079357775684912, 0.04302245295548346, 0.03550456378434319, 0.0298350045341067, 0.04888244729954749, 0.08147847867803648, 0.022891216685820837, 0.054517077369382605, 0.044371080002747476, 0.029583243922388647, 0.04698034877947066, 0.018258374657307286, 0.030403756827581674, 0.028118914196966216, 0.04900641564745456, 0.011110419200122124, 0.06030060823832173, 0.030870365480950568, 0.006474850242739194, 0.028134898202551994, 0.022835210511402693, 0.04533494429779239, 0.037599038114422, 0.058294538539485075, 0.042093280353583395, 0.06241300914552994, 0.026397083347546868, 0.06423678511055186, 0.043669602018781006, 0.07165835093474016, 0.041607670864323154, 0.04343997410614975, 0.05335367924999446, 0.031102067696338054, 0.0950980166089721, 0.0812283823324833, 0.05776463767688256, 0.04560446635878179, 0.02924943146354053, 0.049957381415879354, 0.04550379031570628, 0.12157484743511304, 0.03233173403714318, 0.050895110980491154, 0.012008916055492591, 0.02031419051490957, 0.01987999516131822, 0.03967039825511165, 0.06931225143489428, 0.019664787178044207, 0.03730011587322224, 0.04973412484105211, 0.07114108142559417, 0.025178920295729768, 0.029568332320195623, 0.032926654457696714, 0.052670962759293616, 0.09222536333254538, 0.03261082980316132, 0.016728106966183987, 0.07640634459676221, 0.059210074177826755, 0.03458664214122109, 0.06509633312816732, 0.03503767125948798, 0.028287548702792265, 0.05221841965976637, 0.009776581300684484, 0.056251810456160456, 0.05074525652162265, 0.0234367545999703, 0.013669902855326654, 0.0284721430944046, 0.028556193174154032, 0.07356766684097238, 0.032496876738150604, 0.02161498985515209, 0.01883066328446148, 0.05046859499998391, 0.013258441340440186, 0.023013778663880657, 0.017528251628391445, 0.04897498198261019, 0.0336914042418357, 0.050578588707139716, 0.023541569971712306, 0.029614924351335503, 0.05714552695280872, 0.007918858573248144, 0.05822460967465304, 0.016139390900207218, 0.05214201555645559, 0.03752329823328182, 0.029813020264555234, 0.011029356264771195, 0.06641897387453355, 0.014155381541058887, 0.02108491273247637, 0.03979117165727075, 0.02506122680642875, 0.07386744255200028, 0.02426636066957144, 0.035907045312342234, 0.01231339419973665, 0.05221191102464218, 0.022930505983822513, 0.04868236057518516, 0.06204472578247078, 0.05649176164297387, 0.018999728235939983, 0.029446909538819455, 0.0051620471276692115, 0.013737845547439065, 0.01962892660230864, 0.016571233645663597, 0.025852512080746237, 0.061103827247279696, 0.05986480799037963, 0.05313215558999218, 0.05423482376500033, 0.07616365488502197, 0.027112910756841302, 0.01466555055230856, 0.01696236402494833, 0.03702180678374134, 0.08308994845720008, 0.005745133075834019, 0.026613105837896, 0.009009111545310589, 0.017667363499640487, 0.03445705573540181, 0.08748586726142094, 0.027757825955632143, 0.01723446875985246, 0.0403906266001286, 0.04953385257977061, 0.07243437765282579, 0.04361348081147298, 0.0478385943279136, 0.06633184573729523, 0.02015660658798879, 0.03189228242263198, 0.02436563590890728, 0.048218737210845575, 0.02176539350330131, 0.08843862160574645, 0.027034215272578876, 0.07125359843485057, 0.06305979826720431, 0.0515218101645587, 0.06195378671691287, 0.07678898109588772, 0.01259344455320388, 0.03138845320791006, 0.09880351542960852, 0.07950406157760881, 0.03731928925844841, 0.05086922486952972, 0.01737931557727279, 0.012870406644651666, 0.02954975079774158, 0.02739137940807268, 0.014517041236103978, 0.04307074079406448, 0.06845006137154996, 0.039145250848378055, 0.042897512394119985, 0.07127459379262291, 0.00796579477537307, 0.041763948611333035, 0.06424501552828588, 0.05183377565117553, 0.10236733083729632, 0.09259190264856443, 0.07092516098055057, 0.044361012769513763, 0.03922314666851889, 0.00696967674230109, 0.03367933320987504, 0.020574469126586337, 0.07324486970901489, 0.06562467548064888, 0.01587143291544635, 0.03198624573997222, 0.011843172214867081, 0.029652443627128378, 0.053741751980851404, 0.007130554413379286, 0.04739542826428078, 0.08074640194536187, 0.031863472249824554, 0.07661010124138556, 0.013843891956639709, 0.015626670756319072, 0.04137398340390064, 0.03834943847323302, 0.04439401607669424, 0.007552523347840179, 0.03170424075506162, 0.06073072363506071, 0.02976783645863179, 0.06818042427767068, 0.038131150577100925, 0.03493364441965241, 0.016742471234465484, 0.04584275513479952, 0.02343413667404093, 0.037399767752503976, 0.06585200273548253, 0.05912824868573807, 0.09342911944258958, 0.005663400352204917, 0.0337439668510342, 0.05974451698421035, 0.04708892869530246, 0.031938711181283, 0.03374254192749504, 0.010210644923063228, 0.020747558373841457, 0.035857885450241156, 0.07605286707985215, 0.17118638061219826, 0.11680916097247973, 0.12437623227015138, 0.20746491907630116, 0.10823294695001096, 0.14302088180556893, 0.0956470871460624, 0.1964494289131835, 0.08008937860722654, 0.16186585184186697, 0.13643619138747454, 0.14417536673136055, 0.169633881887421, 0.10191799752647057, 0.15529290220001712, 0.11181717141880654, 0.1400375075172633, 0.11039667107979767, 0.1439265246153809, 0.22485388442873955, 0.15886569017311558, 0.09716201093397103, 0.13839259656379, 0.10733958668424748, 0.19761984032811597, 0.18075636005960405, 0.129891769902315, 0.11259136503213085, 0.1664755240199156, 0.10693193238694221, 0.14068097923882306, 0.10047927004052326, 0.21286843693815172, 0.23931979725603014, 0.16281894757412374, 0.09126723583904095, 0.13016548880841583, 0.12588052108185366, 0.1307592514785938, 0.3221875021699816, 0.09857311568339355, 0.1262280688388273, 0.21186828904319555, 0.12250763058545999, 0.14380089385667816, 0.12663993111345917, 0.16180140373762697, 0.1350698826718144, 0.1418152332189493, 0.14495073293801397, 0.14133892284007743, 0.09379070121212862, 0.11195440936717205, 0.1712247941759415, 0.12059519023750909, 0.15992141008609906, 0.11174509403645061, 0.1493255895911716, 0.1231914825621061, 0.13323615450644866, 0.10377165235695429, 0.09622677127481438, 0.13764427421847358, 0.15051649912493303, 0.09955249086488038, 0.12006366407149471, 0.09697389134089462, 0.15996187197742984, 0.12408580019837245, 0.06555975982337259, 0.08605738883488812, 0.12108544557122514, 0.09478003601543605, 0.14447109773755074, 0.16058301989687607, 0.10136201017303392, 0.0989529988146387, 0.20384384697536007, 0.13339654746232554, 0.12272228195797652, 0.11779810243751854, 0.1539087522542104, 0.24267691711429507, 0.08464039885438979, 0.16146350390044972, 0.10779171047033742, 0.12016285952995531, 0.11758821565308608, 0.07280018966412172, 0.13049770379438996, 0.1551359231234528, 0.1632807415444404, 0.17514628765638918, 0.13253112905658782, 0.16904100979445502, 0.23957548197358847, 0.14507458254229277, 0.2237750095082447, 0.10568744721240364, 0.1396172441309318, 0.1480623651877977, 0.12090829492080957, 0.18696274812100455, 0.20406006427947432, 0.2248892848729156, 0.19795478641754016, 0.19671207497594878, 0.11442548653576523, 0.2764370961813256, 0.16936181054916233, 0.1852604394662194, 0.17604808614123613, 0.16250693384790793, 0.1049573445925489, 0.15286916663171723, 0.07342897428316064, 0.20096800988540053, 0.13679120515007526, 0.1515123128774576, 0.11231769807636738, 0.1377287899958901, 0.18790882313624024, 0.16359845496481284, 0.09147931938059628, 0.1618897044681944, 0.14137228979961947, 0.1436732296133414, 0.18339232017751783, 0.19325118802953511, 0.1912847044877708, 0.2038857783190906, 0.0819065049290657, 0.10756761155789718, 0.13041342550422996, 0.088813725305954, 0.12500879442086443, 0.22813609190052375, 0.1107079500798136, 0.17858827952295542, 0.139165751170367, 0.11292497525573708, 0.14732849987922236, 0.12380186191876419, 0.13766545511316508, 0.11959244482568465, 0.11142005561850965, 0.20388322533108294, 0.08984424188383855, 0.15495121740968898, 0.1131411109236069, 0.09804573070141487, 0.15027166460640728, 0.11594795796554536, 0.11253816788666882, 0.19752321270061657, 0.19710419612238184, 0.17054608528269455, 0.10187137580942363, 0.19707210565684363, 0.09212118064169772, 0.2444456479861401, 0.119662570359651, 0.15906271553831175, 0.09279459802201018, 0.15037175064207986, 0.19324701715959236, 0.16596866684267297, 0.16710609721485525, 0.23322689841734245, 0.1247163733933121, 0.1879864072543569, 0.13677416543941945, 0.17842635774286464, 0.11785941125708632, 0.13405205681920052], [0.03430265933275223, 0.016159655242518056, 0.08993745563202538, 0.10106735528097488, 0.11712913794326596, 0.036578562794602476, 0.027478201409394387, 0.019650634421850555, 0.02021139007410966, 0.08029755103052594, 0.04323121909692418, 0.059128367429366335, 0.02412791673123138, 0.018098677464877255, 0.03509553280309774, 0.05109301579068415, 0.013839116236340487, 0.06799522874644026, 0.038897340127732605, 0.07510789786465466, 0.029928294352430385, 0.02120071745594032, 0.021321529820852447, 0.013009828362555709, 0.016078156295407098, 0.02462685890350258, 0.013141712643118808, 0.0369785469956696, 0.02278713418490952, 0.05127019983774517, 0.024437525898974854, 0.08080752522801049, 0.04804024698387366, 0.014090099448367255, 0.019647927438199986, 0.06935105833690614, 0.043682452305802144, 0.0421279163856525, 0.03667058910650667, 0.017798975968617015, 0.030620707002526615, 0.06620930973440409, 0.025483735189482104, 0.03603437558922451, 0.004022029443149222, 0.027387985937821213, 0.05021550408855546, 0.026242614585498814, 0.03899706251104362, 0.006473907715189853, 0.041003369697136804, 0.015649911110813264, 0.02508391611627303, 0.018272477318532765, 0.03543791521224193, 0.056561334276921116, 0.01464872791984817, 0.041519229125697166, 0.03348478661791887, 0.045339219068409875, 0.033246486709685996, 0.03525235231791157, 0.026239883482048754, 0.03485614564851858, 0.0195114149391884, 0.06507260666694492, 0.03059465019759955, 0.0635971428710036, 0.022833306902612094, 0.04160780445090495, 0.03333456850668881, 0.04162243589235004, 0.037141114444239065, 0.04103651030163746, 0.030339473851199728, 0.06387245739460923, 0.04850823046581354, 0.07526498826337047, 0.011537916670931736, 0.023196719921543263, 0.04647565496270545, 0.023301770925172605, 0.038442236618720926, 0.028882775259262417, 0.03555767187208403, 0.055463252574554645, 0.013103312994644511, 0.027464015256555285, 0.05515672703040764, 0.05810291229863651, 0.08856897984514944, 0.030746001939405687, 0.02092374794301577, 0.002425873881293228, 0.03892874410666991, 0.036366638814797625, 0.031106886090128683, 0.05183412074984517, 0.024534242584195454, 0.021072322197142057, 0.03867148974677548, 0.05555441057367716, 0.02031264313700376, 0.04834821600525174, 0.05890923348488286, 0.0774320743221324, 0.027210024491068907, 0.07063204975565895, 0.06337066166452132, 0.03141273627988994, 0.027152678740094416, 0.06128807654022239, 0.04431986810232047, 0.022414589038817212, 0.030923998638172634, 0.003770328667087597, 0.056210829061456025, 0.025395729462616146, 0.01090146381102386, 0.040380603895755485, 0.04992991453036666, 0.042925580419250764, 0.0778521150641609, 0.022689823781547602, 0.03272634508903138, 0.01738819537422387, 0.051647875079652295, 0.06618962797801942, 0.03797473182203248, 0.0392663693492068, 0.026768672978505492, 0.04119957869988866, 0.057305144364363514, 0.06959617487154901, 0.035440534993540496, 0.008570382597099524, 0.03536809024808463, 0.06236772329430096, 0.03624547578510828, 0.07524629356339574, 0.040926780056906864, 0.03863410776830278, 0.025948811307898723, 0.020723585148516577, 0.04183254161034711, 0.025578056593076326, 0.021947792993159965, 0.0913123955251649, 0.03628912891144864, 0.04659430582250934, 0.03031411466508871, 0.040573558580945246, 0.018682575137063395, 0.04826378186407965, 0.046798889961792156, 0.049255491539952345, 0.04912624281132594, 0.0222975356518873, 0.025375552322657313, 0.06796400659368373, 0.06326716917101294, 0.06262973853154108, 0.06749671330908313, 0.08060372405452654, 0.044568873490788974, 0.04774873137648683, 0.046008506396901794, 0.04076882505614776, 0.07900574652012438, 0.014852094936941285, 0.04112050657568034, 0.020874704969173763, 0.005264098927000305, 0.020401676738401875, 0.037913534324616194, 0.05417220134404488, 0.06605911388760433, 0.026292870970792137, 0.018966496718348935, 0.06466279271990061, 0.06751983863068745, 0.07737332591204904, 0.02294351583259413, 0.04537298307695892, 0.011498080966703128, 0.06463438330683857, 0.017728963612171356, 0.05636913287162315, 0.03197110963810701, 0.036078355260542594, 0.019008108938578516, 0.044686296096188016, 0.010890376124734757, 0.016755473661760334, 0.14018946967553347, 0.0588991105905734, 0.02004195404879283, 0.014796935738559114, 0.06845649579190649, 0.018511916423449293, 0.04636218800442293, 0.019609137234510854, 0.05179464591492433, 0.03310294421680737, 0.04083044928847812, 0.025017479056259617, 0.027422154416854028, 0.046403421729337424, 0.028609434848476667, 0.07593559290398844, 0.02188242277043173, 0.02441902044665767, 0.018890203937189654, 0.029369113908614963, 0.012304383599257562, 0.042431321198819205, 0.08723685445147566, 0.01575999387569027, 0.052261553282733075, 0.03316183363494929, 0.03387936798390001, 0.05110885693284217, 0.025973198280553333, 0.04067040885274764, 0.0456165707873879, 0.03581918615964241, 0.07472062294255011, 0.003251464700042561, 0.014097538551141042, 0.07092581407050602, 0.04094494041055441, 0.055393193833879195, 0.09911125438520685, 0.03296057431725785, 0.023278118678717874, 0.05257073571556248, 0.030043349506740924, 0.046938892410253175, 0.0033645983876340324, 0.008515705794707173, 0.04845545263378881, 0.024770635172899347, 0.03134973165288102, 0.07109813333954662, 0.015711999185441528, 0.025854951891233213, 0.019082112194155343, 0.05598591378657147, 0.029841431532986462, 0.04147357591136824, 0.022930786144570448, 0.03509784088237211, 0.005954350071988301, 0.035731030147871934, 0.045184722475823946, 0.014082459038036177, 0.045694934160565026, 0.027934084173466545, 0.047953935209079646, 0.02972803693410242, 0.024992910257424228, 0.054502182465512305, 0.08074436846072786, 0.038121476682135835, 0.017293059463554528, 0.040799516573315486, 0.03298115778306965, 0.024747647148615215, 0.021018245606683195, 0.009678685528342612, 0.0521844181639608, 0.049030049340217374, 0.031845055855228566, 0.03333980064780917, 0.022571853842237033, 0.03798028679739218, 0.05384564894484356, 0.025607341740396805, 0.04759724790346809, 0.00847643133965903, 0.06319440159131773, 0.06924332075868733, 0.04468245548196137, 0.03371340149897151, 0.07732338679488748, 0.008933511744544376, 0.03447658535151277, 0.03946265256672632, 0.021565202878264245, 0.0023908322191346087, 0.03578285803087056, 0.029255220215418376, 0.017794463710743003, 0.022148640418890864, 0.022655447501165327, 0.02034813820500858, 0.07970830803969875, 0.07868341694120318, 0.04732667570351623, 0.07026531005976722, 0.017604473905521445, 0.03065296074055368, 0.007511039611927117, 0.029871700025978498, 0.03215352582628839, 0.10616179089993238, 0.0064594089326419635, 0.033352049795212224, 0.028596925949386787, 0.047122896794462577, 0.02913481974246679, 0.05031173837778624, 0.03930488310288638, 0.022938085166970268, 0.033410601536161266, 0.02624853321322007, 0.011715993150573922, 0.042460172189748846, 0.025127036751655396, 0.050198579410789534, 0.023654515571251977, 0.013814229241688736, 0.04922969077597372, 0.07935724250273779, 0.04208778475003783, 0.025165504121105187, 0.014232073226594366, 0.034793805243680254, 0.059504632590687834, 0.08770744287176058, 0.04641199724574108, 0.06730284207151271, 0.03613372318795882, 0.060732070633093826, 0.012577916040754644, 0.002228013136118534, 0.04575127430143766, 0.03079149373661494, 0.0776017812313512, 0.05312576198775787, 0.019239197026763577, 0.057800795111688785, 0.05296701659972314, 0.010031707552116131, 0.03520750433381181, 0.023422922822646797, 0.007187623250501929, 0.023813311054254882, 0.029364104411797598, 0.0035773403533312376, 0.061275137195480056, 0.08714157753274776, 0.1542918785708025, 0.0733500394562725, 0.19275458733318374, 0.23583847156260163, 0.24154901591828093, 0.19296094891615212, 0.11309350215015002, 0.1342841115547344, 0.1371279323939234, 0.1235210926097352, 0.13659691088832915, 0.18503657804103568, 0.12777632247889414, 0.09875701245618984, 0.11354408226907253, 0.17611394432606176, 0.09179942251648754, 0.12060084540280513, 0.1732230416382663, 0.12195471572340466, 0.242611994035542, 0.10482703830348328, 0.148779769660905, 0.21529661054955795, 0.19963290105806664, 0.16798629920231178, 0.10162855251110159, 0.23066524212481454, 0.19159639166900888, 0.06778098555514589, 0.17811885627452284, 0.1257918492774479, 0.1360800940892659, 0.1421615044819191, 0.0909081996360328, 0.13409055944066495, 0.2347166114486754, 0.11729690042557195, 0.20601171971065924, 0.08904111935407855, 0.21944411768345162, 0.09866713837254792, 0.11992499377811328, 0.1362885782145895, 0.1386291190283373, 0.09161985988612287, 0.14469219837337732, 0.11045095176086761, 0.13685663288924843, 0.1674747368087992, 0.1460029202280566, 0.11671751315589063, 0.12324311377597041, 0.25146712199784815, 0.0773327675415203, 0.10398530925158411, 0.09311415939009748, 0.11138043977553025, 0.16585119970841333, 0.14340464636916295, 0.09623142454074696, 0.0845591039978899, 0.09589774010237306, 0.07514693483244628, 0.100838350772392, 0.23206098441733047, 0.08084160464932211, 0.14214584516594186, 0.1724000889225863, 0.15511460864217952, 0.1195209908473771, 0.26990717626176775, 0.13687444443348795, 0.14185568026732653, 0.11788066636654548, 0.12431504961568862, 0.12667214032262564, 0.15437292109709233, 0.14943875226890668, 0.21730640582973137, 0.10307682401617058, 0.10973461598041467, 0.11669341562082991, 0.13897068507503718, 0.11262395273661241, 0.2051860507344827, 0.13210050528869033, 0.1449538499582559, 0.1783806859748438, 0.12124234301154502, 0.1651256761397235, 0.11819165592896752, 0.195352905720938, 0.16027320292778313, 0.12345401730271988, 0.21585265727480873, 0.12539249961264431, 0.09408717436599545, 0.17881833045976236, 0.16217161668464541, 0.21688108099624515, 0.2402969088871032, 0.17439913790440187, 0.08817195310257375, 0.1612411712994799, 0.12752041511703283, 0.18428460432915017, 0.17284276516875252, 0.17165314697194844, 0.1287117402534932, 0.09616692448616959, 0.1599171946872957, 0.1032889743510168, 0.08490264415740967, 0.19372666720300913, 0.1692992920288816, 0.10963021806674078, 0.20411753619555384, 0.06407381690223701, 0.10325481329346076, 0.15450300474185497, 0.1679437592974864, 0.22739670501323417, 0.1702555493102409, 0.1280853379284963, 0.08564191230107099, 0.14739023172296584, 0.2257386432029307, 0.1724634089623578, 0.20739962492370978, 0.13489236094756052, 0.17802755726734176, 0.12889307661680505, 0.13500390574336052, 0.12288317215279676, 0.10413828073069453, 0.1107290419167839, 0.14245260448660702, 0.08281561356852762, 0.17184015334350988, 0.13934299087850377, 0.10569413396297023, 0.08555561536923051, 0.11411228537326679, 0.10238524628221057, 0.1280529357609339, 0.11000574479112402, 0.15288638445781544, 0.12816725618904456, 0.14250657346565276, 0.14230778178898618, 0.10837830399395898, 0.19848175579681993, 0.16826372884679586, 0.13145063625415787, 0.25750202941708267, 0.10612316211336292, 0.08435755895334296, 0.08873980739735998, 0.1654426325694658, 0.12825239537050948, 0.13298164238221943, 0.2771487564314157, 0.16699289000825956, 0.1775861278292723, 0.1463949226308614, 0.21957271703286096, 0.14000224065966904, 0.20313422020990402, 0.08294075450976379, 0.16032026993343607, 0.12781009019818157, 0.12529533763881773, 0.17375293507939205, 0.13066268322290853, 0.18478908663382754], [0.1284533689613454, 0.012036820808134507, 0.10622596440953203, 0.05046157428296283, 0.05189127354242373, 0.033797505384427495, 0.050283889286220074, 0.07494757912354544, 0.058830584384850226, 0.05179382213100325, 0.045969113198225386, 0.015739213740744162, 0.04486814454139676, 0.06358141676173545, 0.06550986523507163, 0.026322874145989772, 0.10028487187810242, 0.03377828004886396, 0.02182927571993787, 0.11506624199682847, 0.011137362871522782, 0.05285972431011032, 0.02199899376137182, 0.04271750076441094, 0.060365579556673765, 0.05218164995312691, 0.047508182760793716, 0.039313232264248654, 0.023915163401397876, 0.020230455847922713, 0.030570341150450986, 0.060810333816334605, 0.04687038475822192, 0.023286981777346227, 0.035886721598217264, 0.0472056648141006, 0.04788291909790132, 0.021953553914499935, 0.0855522089113947, 0.02257129908684874, 0.05313393674441613, 0.030724937932973262, 0.05611623120785225, 0.0591812268976355, 0.027747144595196005, 0.10388831797172315, 0.0559904000692768, 0.0746949965832755, 0.025116281176451594, 0.014495460509351688, 0.020904520752083044, 0.02663370600203052, 0.027982077008346096, 0.040941344705061056, 0.055480180963058956, 0.07772470315103419, 0.010362189623265294, 0.07777841979986988, 0.07209763556602411, 0.04404974861245137, 0.043898402436752804, 0.06149378132249694, 0.015435128934768727, 0.03042570398974931, 0.07079032016918063, 0.013479684839694528, 0.06634124132688157, 0.021997411131451372, 0.074883049383061, 0.042304822127334774, 0.01703411115158815, 0.06426799242035486, 0.0988030775624793, 0.0554463093430968, 0.07520059210946783, 0.04919383391097654, 0.025497038186585996, 0.06333690136671066, 0.029943922127131373, 0.03194465949491132, 0.06895677754073404, 0.018414745172776747, 0.026957798181683756, 0.07913011562777683, 0.039412821060977876, 0.045001270991633646, 0.047982682299334556, 0.06863930160761811, 0.04476853348023724, 0.043085554061690345, 0.06143579361378215, 0.017209009383805096, 0.05617992232146207, 0.006967781018829555, 0.03111823167273542, 0.05099386486108415, 0.03660218164441176, 0.010258723104925593, 0.029102258013153914, 0.035440798455965705, 0.02417156985757174, 0.03762991887924727, 0.03336327848955989, 0.005430363662526361, 0.04659902217099443, 0.05524726162548177, 0.03133281439659186, 0.030415740657190327, 0.008676566303620348, 0.06293126571108587, 0.07078744805767201, 0.010780279444588814, 0.08581478818086907, 0.04304833535570651, 0.03162329470796976, 0.036683149955933914, 0.019174583794665523, 0.05234845135419164, 0.0506993212911766, 0.01568817995575955, 0.08497827642713673, 0.0071003726588969585, 0.02857316423614975, 0.010423210860608378, 0.009917317547660787, 0.031915585859678686, 0.035727749855141155, 0.0027030442379327724, 0.035425098321866244, 0.023877464154793415, 0.012320626428845571, 0.05734827798733022, 0.007416647240461316, 0.0658181459584739, 0.0659173636813648, 0.044731567104463466, 0.041244968451792374, 0.040723294296185486, 0.021018202933191787, 0.009696985962364124, 0.030941290679038502, 0.050055511892423965, 0.015987853621481918, 0.025554712337907404, 0.03082497016293928, 0.017512206395622343, 0.0701108765497338, 0.010802197848533979, 0.02213909825513838, 0.10663063527317718, 0.019138782590744086, 0.0659162356168963, 0.0928162167838309, 0.06793088454287499, 0.034890020979219116, 0.02835791357938433, 0.06630728807067499, 0.07939850591355935, 0.028735978448821697, 0.017836226215877105, 0.012754100971505977, 0.046922446417738684, 0.06270466576097533, 0.0337495886196848, 0.01914561406010762, 0.10094775818288326, 0.039938261616043746, 0.02510858696041396, 0.03535238640324678, 0.027085455003543757, 0.027269925085420255, 0.06258339140913449, 0.05236869343207218, 0.03178182116243988, 0.03768040347495116, 0.038151945555000566, 0.03985226896475069, 0.0211256065449561, 0.027623146561381873, 0.026107076155312825, 0.07788292903569527, 0.018007595535891596, 0.04536615531833377, 0.060271408437984064, 0.031903340423014015, 0.01988187836104771, 0.04271510733815376, 0.037220112353679724, 0.011694928216456901, 0.04947317829646636, 0.05339967756299302, 0.06533229156048037, 0.06194622052134946, 0.017314965807599947, 0.025895278340613004, 0.07052705812384374, 0.05337526832590811, 0.020755909390572924, 0.0309918402126641, 0.018702646520978305, 0.05669120640959591, 0.015252523498929804, 0.013375485450524138, 0.027157886761415284, 0.02329568345885491, 0.030510904398397543, 0.014994252396718366, 0.013368700365390396, 0.037041124887764454, 0.02040093644609442, 0.04874977355939336, 0.025913850586221088, 0.06048578521586023, 0.04791182203916833, 0.07504475594032556, 0.04344482775195502, 0.05517701734788716, 0.05815571239509154, 0.03524730942444876, 0.03445687390922103, 0.017657845455687493, 0.003530066242092289, 0.029734252420894336, 0.039394549385178834, 0.01236180542036891, 0.030095440852164757, 0.01160344181698747, 0.06828926023445092, 0.04373398332973011, 0.05153316873474978, 0.08161258476320654, 0.04383223254990298, 0.06818651731009595, 0.04145517807046417, 0.04748834515339695, 0.021360737482609693, 0.03795279022597242, 0.07105773082002997, 0.07930284307803959, 0.018319249320484232, 0.09558830905007198, 0.06437506206566468, 0.07178487227065489, 0.04781109404575545, 0.05028447187214624, 0.006708621194775333, 0.052396805986063555, 0.014140285329631297, 0.10289581419783644, 0.02954654843051685, 0.02150460652046604, 0.05998160719173029, 0.05079638307506684, 0.043090567269246094, 0.06742670651874505, 0.005986911801301176, 0.10732710376032628, 0.07515762918046676, 0.031509883410762995, 0.02567019979323959, 0.045599430886795744, 0.008144480743794702, 0.027626018672890496, 0.016078063526947517, 0.01497180521255359, 0.03306083846837282, 0.04025999747682363, 0.026571052039798815, 0.03881807504512835, 0.04287389725504909, 0.007188043027781532, 0.07212531025288627, 0.03390546189621091, 0.028637925897783134, 0.058599264375516213, 0.032554875579080544, 0.02594205961941043, 0.030620217185060028, 0.034636588679859415, 0.023136004820116796, 0.01645326556172222, 0.08164158047293313, 0.035900666553061455, 0.007261097262016847, 0.043860638252226636, 0.053622759733116254, 0.0784954457776621, 0.05194660807319451, 0.04174214060185477, 0.036412106492207386, 0.06047497954568826, 0.009416461562068434, 0.06662068961304612, 0.04372465453343466, 0.033752197268768214, 0.04399403929710388, 0.053369101078715175, 0.006534594522236148, 0.03829592591500841, 0.05165065071196295, 0.01454437824577326, 0.046826683392282575, 0.022305137099465355, 0.006221888279469567, 0.009386402725795051, 0.01667117867327761, 0.03478521488432307, 0.12097585262381472, 0.040515960499760695, 0.052595657034544274, 0.071806891792221, 0.026797802274813876, 0.011862817791552516, 0.048334905586671084, 0.03393342973140534, 0.02451911204843782, 0.06627018068684265, 0.02792407260130858, 0.053680034980061464, 0.04558084379823413, 0.010591742393444292, 0.008327020314027322, 0.05088722566142678, 0.0389273748442065, 0.09101307252421975, 0.03858715579553973, 0.03708991738676559, 0.008192143322958145, 0.05510978247912135, 0.06290670804446563, 0.06611305318074301, 0.056295530375791714, 0.05509728471224662, 0.10868665893212892, 0.016948684387898538, 0.03755283200007398, 0.010012208549596835, 0.05196509497181978, 0.02543813578085974, 0.0329034846072318, 0.052806282255914994, 0.05330612613761332, 0.033714752207743004, 0.03076036064157961, 0.058794653305085376, 0.013444400356092956, 0.008321421737491619, 0.03321964693896007, 0.014921896708983695, 0.04798267487785779, 0.07491275755455717, 0.0751412425597664, 0.17907845322042704, 0.13506160030374303, 0.17164314282126725, 0.12142915642471053, 0.2693439752329141, 0.13033300638198853, 0.1223203496192582, 0.2490417833905667, 0.11225213675061241, 0.1228643067588564, 0.16375746752601117, 0.2651048870757222, 0.12857612018706277, 0.16751341754570603, 0.2404956115060486, 0.14322284987429157, 0.14779030869249254, 0.09418009125511162, 0.0967094641237054, 0.2834989578695968, 0.1778104790719226, 0.14325609809020534, 0.08994232412078418, 0.201005621929653, 0.12881889153504744, 0.1576725096674636, 0.15195219864835963, 0.1192175637697801, 0.15807444200618193, 0.14390157361049205, 0.12115542267565615, 0.1443941963952966, 0.08566456264816225, 0.0761635806702543, 0.20052527426742017, 0.13957535731606185, 0.09883150181849487, 0.09206465125316754, 0.13319530669832602, 0.17323767679044977, 0.22468163195298985, 0.1764666722738184, 0.12519323296146467, 0.1314585327054374, 0.11154255451401696, 0.12476306932512671, 0.10906276453169994, 0.13811365293804556, 0.08904379850719124, 0.0946272278088145, 0.05840100704517681, 0.19306948059238493, 0.2121723024174571, 0.17971518624108285, 0.1565430499613285, 0.15981733129592612, 0.1550570476683788, 0.1554825357743539, 0.19748468039324507, 0.1218998190597631, 0.1909933818387799, 0.16662315203575417, 0.13230075157480314, 0.09992335690185428, 0.2051092532929033, 0.07954356609843671, 0.19364767300430685, 0.12481510872021317, 0.15858267957810313, 0.20959648594725877, 0.08295402411022224, 0.14156112185446545, 0.2248524149763398, 0.2323906315723434, 0.19015570491319522, 0.21511019789613783, 0.17837848921772093, 0.1965393772115931, 0.12001527604297735, 0.16951184312347323, 0.13024760002736002, 0.10893806887906976, 0.12477783806389198, 0.1576665576430969, 0.13839127554092556, 0.12675132747972384, 0.18423629051540047, 0.14622323418734595, 0.13965926453238353, 0.13373536756262183, 0.14933182363165542, 0.10965074587147683, 0.12645587848965079, 0.1534978547715582, 0.129175181791652, 0.1336214627372101, 0.10719451907789335, 0.09092051186598837, 0.20307893020799384, 0.12154972573625855, 0.13473698490997776, 0.11999455527984537, 0.1294341022730805, 0.088419155072188, 0.2007012820104137, 0.2273195216548629, 0.10024582006735727, 0.08192100649466738, 0.13388449471676722, 0.1999709938536398, 0.22018510760972276, 0.13088771724142134, 0.1910698675783351, 0.1709630832192488, 0.18874283385230228, 0.2241508330916986, 0.09192840778268874, 0.13895878102630377, 0.09490934782661498, 0.08931531323469244, 0.20991167606553063, 0.10177609146921895, 0.1441028292174451, 0.1292447210289538, 0.12054596358211711, 0.21947372937574983, 0.11240939042181708, 0.09503752415184863, 0.1753910628031008, 0.08781084630754776, 0.12849029822973534, 0.2408783370628953, 0.07279192956048064, 0.16287627106066793, 0.2309240587055683, 0.1465042112977244, 0.08492166540236212, 0.11726582670235075, 0.09765532391611487, 0.15527068229857832, 0.18159056373406202, 0.10911661476711743, 0.12403157888911664, 0.08478525123791769, 0.1072956292773597, 0.11779853288317099, 0.23501137766288593, 0.13611386180855334, 0.1216385088628158, 0.2051415218738839, 0.16649513156153262, 0.16022957948734984, 0.16305388184264302, 0.13457951601594687, 0.17079522425774485, 0.18277840077644214, 0.1251316792331636, 0.18778225727146491, 0.17770423321053386, 0.10192498855758458, 0.11139492649817839, 0.18164282577345148, 0.21316857630154118, 0.1473181988694705, 0.11209237462026067, 0.18626127013703808, 0.11483978305477649, 0.1040120265679434, 0.12408493930706754, 0.10022864677011967, 0.10803417753777467, 0.14678119565360248, 0.1448432996403426, 0.2345495391637087, 0.10099045393872075, 0.14227907551685348], [0.06226172234164551, 0.06108938505349215, 0.03875550457451027, 0.06013891652401071, 0.06096687131503131, 0.0364215317677008, 0.021444143749249633, 0.10865074640605599, 0.048360071814386174, 0.04988404980394989, 0.04207386577036232, 0.04903295113763306, 0.012481098237913102, 0.015224607614072738, 0.06374134958605282, 0.03600039635784924, 0.025508567450742703, 0.15325784421293065, 0.01764093747624429, 0.04594143851136323, 0.039137079802458175, 0.01543326707178494, 0.01821261383156525, 0.03296337221399881, 0.06271792793995701, 0.08088955481071025, 0.07281965619768016, 0.05245100132015068, 0.08403453175560571, 0.05189323281229008, 0.04222865551128052, 0.031379150386783294, 0.03781646511924919, 0.026097537702298723, 0.006208611257534358, 0.01834996681282064, 0.025564629286236595, 0.056627329759066924, 0.08740782301174477, 0.10253712680423632, 0.0058614225144992815, 0.027185485378140584, 0.06973328665480949, 0.014063766193430638, 0.03776847413973883, 0.05403033610491548, 0.01591026764799608, 0.01913563031848753, 0.01755454777594423, 0.0268474389667972, 0.05506341680302285, 0.01806803233193932, 0.020609607963706367, 0.04569574310153257, 0.04141120210988447, 0.040059788298094645, 0.01145735097452416, 0.014252261498768348, 0.007984921776369447, 0.06157445277494844, 0.03824537081527524, 0.014839758587186225, 0.07177646373747848, 0.02532141821575351, 0.038017011975171044, 0.005346563129933202, 0.05084461525257211, 0.0177084153983742, 0.05524280873942189, 0.044898917694808915, 0.024132156249834225, 0.01526397762063425, 0.06454192654928192, 0.059206745645496994, 0.013885000444133766, 0.023338447863352485, 0.022658130365016405, 0.042484625955694355, 0.029190664499765262, 0.02773896983853774, 0.05003230122383684, 0.0532753232982941, 0.03887698672770057, 0.056122535752365366, 0.02078952682495583, 0.018794624593283515, 0.07762115128571168, 0.019440951728029177, 0.031394323596032336, 0.01858275256381603, 0.06538252753671259, 0.05153270118171349, 0.00216546701722109, 0.027009139957954176, 0.02893089611461619, 0.08417572535108775, 0.08353341137990355, 0.02318680111784488, 0.024538877296436112, 0.08410010792431422, 0.08141420868923888, 0.025755903006938752, 0.07317476643947884, 0.023575482409796678, 0.041636039459262975, 0.07767394767142832, 0.00927555740418029, 0.017252710749744438, 0.020621165058400948, 0.05944861899479292, 0.028231412652530707, 0.06426811116398312, 0.02786778441077331, 0.005064485321781831, 0.07348129569436423, 0.07411545346258208, 0.05916936737776268, 0.027228016006120015, 0.08201507371268235, 0.00960986895734095, 0.07425825751852244, 0.024558182412874885, 0.07367685902863741, 0.02151671280444134, 0.06934877252206206, 0.09840809914749116, 0.05525196684175171, 0.011741616726794746, 0.014964637921366375, 0.08437899217824452, 0.008816356312308926, 0.010775521350296913, 0.031091972632566467, 0.012414243719831575, 0.028143113777332474, 0.06183308010804467, 0.030096082809905056, 0.013772183792752912, 0.03477132930129301, 0.052189290363457985, 0.03941850220144261, 0.06200679832545575, 0.06614560377784073, 0.0207485009013908, 0.033494475355837494, 0.021803946219733916, 0.10127565386937931, 0.03341434567118995, 0.0375830374105135, 0.1321433568955399, 0.023434192335116677, 0.08356838137842715, 0.053399339885800146, 0.013945415903435787, 0.07415781525196508, 0.025047832896234468, 0.03332332496938761, 0.04171839187620208, 0.08335659469594248, 0.03093567818723386, 0.04814907551917713, 0.04735951944894623, 0.05321981065208092, 0.08454006048850715, 0.10028283097199164, 0.03700212502735667, 0.04222406161716208, 0.031602262242813595, 0.024771791067905724, 0.016468615031044465, 0.0443733546853764, 0.044277150082052685, 0.017228772776434198, 0.011868818055518204, 0.046387654801947065, 0.0247441757528577, 0.09367343445774168, 0.0377285094873514, 0.004113725035495008, 0.07412871564156376, 0.026613387854013126, 0.03251641748647671, 0.04836872896703426, 0.043770782722276635, 0.012769883669534465, 0.014471696013060864, 0.027114276308566332, 0.018390771947451867, 0.016215921168623026, 0.052303840857348405, 0.08375362885999493, 0.010752071339084068, 0.02258203054225305, 0.04719498901977204, 0.06941117972019129, 0.03767073700146284, 0.044513353423099034, 0.01932168674102286, 0.06189979918417521, 0.0520630250684917, 0.0458248767972691, 0.03954550593334716, 0.0299580804494326, 0.04559587228868622, 0.0825452343269717, 0.07263764447998255, 0.033560749143362045, 0.021999400087224785, 0.010929314757959219, 0.03871710956445895, 0.02284245016198838, 0.011387126178306062, 0.10705775610404089, 0.030437131208600476, 0.04071882656717207, 0.03246129446779378, 0.020561153141898103, 0.02839237335138023, 0.03854397022223566, 0.04616503276338335, 0.05189011208130978, 0.05001089026336558, 0.045876559961470775, 0.015377062372863293, 0.008067088656389387, 0.12529130035545677, 0.023878909487393685, 0.033376217834302224, 0.0021750829318989418, 0.07651388179510832, 0.040664401167305186, 0.013577336630987702, 0.02158188264729688, 0.03657358669443056, 0.011067430295952363, 0.03237979552068282, 0.03521820610330906, 0.03332925101858564, 0.05841189435159322, 0.03602330274588894, 0.04162166776950471, 0.034429280858603306, 0.02168891704059206, 0.07239011596539058, 0.057197020869352855, 0.059316282931831665, 0.04847209158469923, 0.02859697604435496, 0.0328894765698351, 0.020790448943444062, 0.008843076411721995, 0.04591034623445012, 0.02091744896461023, 0.08536392604582943, 0.028705761906167027, 0.04082735824340489, 0.024233856456703506, 0.06309318749117665, 0.06731399655109271, 0.06988894470850937, 0.028543420812638942, 0.00665485445097147, 0.044665478853858076, 0.03659798108856194, 0.0414832572278101, 0.030660393349535298, 0.07880581935751252, 0.06456217975937761, 0.06969827954890206, 0.04398508899612352, 0.06207876809639856, 0.06744285565218888, 0.03256830103055108, 0.023637314443476498, 0.05570920773607213, 0.06582549322047271, 0.0733092732843943, 0.05832932671182789, 0.012686860536632594, 0.038336922152666375, 0.02264231334265787, 0.08503951845341362, 0.049203734160983004, 0.06584372036741115, 0.007052668797769002, 0.021697253214369994, 0.03428154523135163, 0.09599154756870121, 0.01468670639951597, 0.007654483770238585, 0.039027991515467875, 0.07789592404151335, 0.03954230356612243, 0.024624144498375244, 0.054680501998518594, 0.013730437985941535, 0.11758777778595686, 0.008759213724260917, 0.05393373816332314, 0.04837488137127366, 0.030887184402672574, 0.020189331589790527, 0.02023067292611813, 0.056976031555677764, 0.0409180078713689, 0.03809291512880009, 0.03438170548179187, 0.04713033682492096, 0.03827267442829907, 0.09590343237505294, 0.05183459943509661, 0.059650549956131727, 0.06345994945149869, 0.061060790103510953, 0.03769930226553697, 0.10972631876938976, 0.07510568626457825, 0.03943443611206021, 0.024605980433989316, 0.010873356823140057, 0.04425507861014921, 0.024158424566849135, 0.02507834815332899, 0.07025564729701728, 0.019663761158881243, 0.015118743958737468, 0.02218228382844245, 0.03087121524004033, 0.039174940466182306, 0.019081974896835163, 0.03388382829143666, 0.05897614923014771, 0.020000759286631364, 0.012434060918167233, 0.04321477310440969, 0.014951540870242752, 0.04900872372672893, 0.05812501345644705, 0.1171785501355771, 0.043737044688896276, 0.027503974342835136, 0.023608125775353983, 0.046697764919372275, 0.05440680906758644, 0.030539608815161046, 0.012804027101083193, 0.03806403445196338, 0.08482711578835733, 0.06454018992371857, 0.04031848984595854, 0.02636169403558597, 0.010824605142261134, 0.1881942679756321, 0.11165845571667887, 0.13033977476879954, 0.16284104873193428, 0.1158311587641947, 0.14610649435780942, 0.15463240561075509, 0.26933147746603936, 0.1562206313246861, 0.09804724468267523, 0.10453186390805058, 0.12163678708020598, 0.0558003323385492, 0.12641636654734612, 0.11760439447243698, 0.11803852117736824, 0.28356123890262097, 0.21354739816160873, 0.12745854968670756, 0.14831399777904153, 0.08791932603344321, 0.14310438826214522, 0.12670489872107282, 0.13385362137341872, 0.1413478731410578, 0.14742355415364727, 0.16212097252719104, 0.19762027077376842, 0.13514488411601633, 0.1354040569276549, 0.14582689764210954, 0.09746554191224277, 0.1288762447074987, 0.13546739181037992, 0.0844463420799002, 0.11160486523294821, 0.11157905333675444, 0.10405716398963705, 0.17717431008350104, 0.23487801372539252, 0.1386949178413488, 0.12818402872653678, 0.09765645940206014, 0.12332320635323413, 0.12427633919287473, 0.14818551717326045, 0.2133199298987165, 0.21587889961665496, 0.09102703974349424, 0.32175135682336986, 0.14279658993473276, 0.0927503511775285, 0.09923660312779248, 0.16826142818899825, 0.11483630238217302, 0.18763538624625653, 0.09905623897793703, 0.14086518029216677, 0.13407101127086207, 0.1201854356622789, 0.16906475852010772, 0.1264716120203957, 0.19448122358880937, 0.16618489898974076, 0.19535127299604937, 0.08859537803800777, 0.10215544025413692, 0.14326616161270067, 0.12953126424690709, 0.2593821566551924, 0.11223700435948558, 0.16083680471638218, 0.11340792785631493, 0.2202985671465285, 0.1585149808670394, 0.19285312970168889, 0.11635484785074368, 0.2172666712431237, 0.12950721866218373, 0.14317314082290977, 0.09870520312688313, 0.1168684363074135, 0.21392969327280298, 0.16139378654770553, 0.1836566286510788, 0.11356419447110966, 0.2370110500487499, 0.17114878341089934, 0.18585758632980287, 0.18848873733077198, 0.12820912816096097, 0.13621338381199166, 0.1101106547866948, 0.10300093941623345, 0.19117039890261367, 0.13746903830906376, 0.20841927645960823, 0.10965071618556976, 0.1395923673408106, 0.15497986431000754, 0.19733175344299525, 0.17352286929963157, 0.16352566512068734, 0.09762218702235259, 0.1125661691185087, 0.21207632787991315, 0.17790725512895733, 0.15765892836498097, 0.22691004909574986, 0.2141957383719273, 0.09182176858303137, 0.16857848851941526, 0.08013082755496725, 0.12279612565180287, 0.21017861174186692, 0.25810711726080626, 0.18725542147876695, 0.09272379713365808, 0.20980792382033542, 0.07486060683731921, 0.1914505151216872, 0.128121480520349, 0.13529931020457298, 0.15396592731121927, 0.12281700226594694, 0.11213940451852977, 0.16738679230911657, 0.10250879160594195, 0.15558674815110862, 0.30951889290008694, 0.12418342972523533, 0.1311677592457272, 0.15309847542084754, 0.17436428664950654, 0.1218018629879225, 0.21246084943413734, 0.16121362277772278, 0.1141787001688499, 0.18892126099672168, 0.172893913986627, 0.16813450609333813, 0.10463921556947753, 0.1853110094089061, 0.11948796527576633, 0.13438246096484363, 0.08949265684350394, 0.15351982234278694, 0.1111467597365845, 0.10802370583405718, 0.2780882560182363, 0.07623527955729514, 0.22120749024907127, 0.08022810085094534, 0.07860272322432138, 0.115254866250325, 0.12820307223591954, 0.11650001193629578, 0.11413129919674248, 0.1451328708208166, 0.09507552953436971, 0.16853002627613023, 0.23664931242819875, 0.24525932385586202, 0.15362401987658814, 0.17273316479986534, 0.1322413797606714, 0.21398228185717016, 0.11370835665729828, 0.1910154681536369, 0.0706479094515089, 0.15143386786803603, 0.14340820867801085, 0.13092323642922565, 0.09857965400442481, 0.10923716181423515, 0.07255260177771561], [0.016288438273477368, 0.048386043272330426, 0.0018901014709626907, 0.04511711282248143, 0.03122752961644437, 0.014732590607309248, 0.03157402723445557, 0.050749646325130016, 0.044911482254974544, 0.01563565259857569, 0.03496954210277181, 0.030127881982480176, 0.01987125080631813, 0.03223404513846617, 0.03371373917616438, 0.06304390146397054, 0.06504928096546791, 0.03433695397689007, 0.01332274008746026, 0.05521576487808488, 0.06371942654368468, 0.01646800275921123, 0.02164613408240257, 0.03751875257876236, 0.05243855179287493, 0.02420566597720608, 0.049546528462087736, 0.017886710811580997, 0.045206790236989036, 0.025883070011332165, 0.05100545349705499, 0.05352772030164488, 0.08669667484355159, 0.09847647321294062, 0.04947918598190881, 0.05058874870883301, 0.02702455622056732, 0.04357401339802891, 0.011909874592674896, 0.10101070714881644, 0.04039784398628399, 0.049822314249468036, 0.004457522163647809, 0.011624822163867066, 0.018447253096383065, 0.030089555621088948, 0.025093055664910935, 0.07730718571110629, 0.0391156280238647, 0.01690117765974719, 0.040182613738579676, 0.010378327624493977, 0.040507822850486264, 0.022619182454945985, 0.0432018003630219, 0.020318830793257803, 0.023944287131598685, 0.012471652553358581, 0.03664512601972092, 0.03765557863516733, 0.04091756258276291, 0.13992194028105587, 0.05112608218041714, 0.0470259537542006, 0.03236380965972785, 0.06186266211443581, 0.11476031388156116, 0.06901099142851308, 0.052866589176119305, 0.04468448896659538, 0.07024556893156841, 0.03669976293167565, 0.05098846202599816, 0.013685100184375187, 0.04838253662455827, 0.049830507559818216, 0.033838382878457196, 0.030358443145814817, 0.029272319297888316, 0.0029766381385343266, 0.07518065060139634, 0.06766448321286589, 0.019544887654774357, 0.053786655626026914, 0.03398733191716019, 0.0420818364364095, 0.0298025596930529, 0.020944247917213943, 0.030775986560911406, 0.032083533878903836, 0.02615440847876016, 0.03301656193798408, 0.05487372756761033, 0.06301292421994731, 0.02355462063860614, 0.05973041617835406, 0.05271030400763266, 0.024760167179920245, 0.03681059526570607, 0.011763029542635195, 0.049458576540928334, 0.034552447687019594, 0.027349728225090075, 0.044939060462638736, 0.03854781454720069, 0.02248225806397386, 0.00574576575672836, 0.02998978685354814, 0.03189347728039138, 0.12510077620390803, 0.07883727899752557, 0.02820680118020391, 0.029419060447253287, 0.01586204845807515, 0.048782988378661685, 0.1049252318625804, 0.026173340665991418, 0.05388041114201769, 0.040930787654360756, 0.018810057554219384, 0.046154594456311315, 0.018229848355986178, 0.018327091966057196, 0.05146925126609858, 0.021597336017293856, 0.0350158892251784, 0.05454043646750506, 0.0120730747221387, 0.03296648552350234, 0.04409432200191077, 0.01880696650914615, 0.043069442035630345, 0.054742204156355, 0.024480167849105783, 0.03685964380565565, 0.01678907068708213, 0.05043957702582702, 0.030177620719769038, 0.017067038388631772, 0.021759168739663437, 0.04862620968197007, 0.024567030668549705, 0.03801426231802907, 0.01571974720718572, 0.03156939994369168, 0.01624169781280216, 0.014236747829272645, 0.08202875891583972, 0.024087204365059733, 0.04864665956120007, 0.016770396396168508, 0.01568629490066087, 0.03937134984880686, 0.0343451806838857, 0.021616388803522568, 0.02852121389878448, 0.022782287960581016, 0.0878072097839322, 0.05340224539395422, 0.04643875166948419, 0.04584263268043287, 0.031193884351523593, 0.043092096093459986, 0.04060230196046177, 0.02634041666169651, 0.028546730791276786, 0.013865426299162209, 0.08590847690356895, 0.0743294665880967, 0.047518717547063716, 0.05745489863329567, 0.019442525081103668, 0.023093112395145, 0.039900586489238776, 0.024740739609114826, 0.02795014610455837, 0.09217227750923485, 0.0625916440912988, 0.029275312008394394, 0.05511245792149566, 0.019423403646214865, 0.04920308849250432, 0.055982210469665006, 0.030260275561886374, 0.03017401759279892, 0.061925937625346705, 0.04157543939072639, 0.023629533025086857, 0.022214298223843798, 0.04122164646105375, 0.04568874464894179, 0.05170957352675032, 0.013478506680257851, 0.023385234708257485, 0.021891673641221132, 0.04815713153220713, 0.01987283343623858, 0.08479973053908907, 0.029594005063700024, 0.041403862269362435, 0.0526920583070023, 0.03373393672518432, 0.07483102483092807, 0.010612120840960415, 0.04531573380518239, 0.03569921427697409, 0.016354194412997458, 0.0445344972104067, 0.0986107722565066, 0.07590891269501299, 0.033389301897841506, 0.031838432187214494, 0.018201717248302884, 0.06741758552379906, 0.06920389045262709, 0.0682280256296508, 0.06698921046336181, 0.006432641521314508, 0.019452872475085314, 0.02995437342178775, 0.045112711886758916, 0.06894922989886254, 0.03929614060325548, 0.051862749096471816, 0.028378584247548133, 0.03695910272654146, 0.011028214285033755, 0.06951797477086075, 0.02711744156840723, 0.0352630577981472, 0.04827856915653683, 0.020251551395631395, 0.04742808647279162, 0.08187445157091133, 0.07908929750556126, 0.025048380230145995, 0.014652974859927781, 0.07878232296206988, 0.047440005364478566, 0.05489138697157614, 0.03617957678216044, 0.04382898936455604, 0.09967659279936925, 0.010975595087074907, 0.04054900833580177, 0.03424064918363001, 0.013358391934161773, 0.03741779823030811, 0.04444710190000478, 0.0027058859677708824, 0.049634179813438095, 0.041868457847158425, 0.04910585601464845, 0.0847190294007305, 0.045501382046495564, 0.03869850392220542, 0.035759343081736006, 0.05445627321023494, 0.012201034896861529, 0.007477916633433779, 0.052414580422919244, 0.03393144448637031, 0.049471809034002945, 0.0759568925423082, 0.04935461649438366, 0.03583815174351912, 0.031167638298938982, 0.0394900563696865, 0.02455802656186279, 0.025843687944870908, 0.03610051207942888, 0.05007485597161576, 0.02691492987651145, 0.009593186405254528, 0.020081024413229898, 0.02407764179224614, 0.07526472851168364, 0.026867250599025283, 0.01682553054706659, 0.006799388638683013, 0.02498397294402821, 0.07507204471039586, 0.0191144345808425, 0.1000377738091629, 0.046080702522885986, 0.03405502320674714, 0.018628570906003006, 0.02574362046289025, 0.029942849723738618, 0.011258621452725492, 0.035664277675095946, 0.022351313527906314, 0.027146845459355973, 0.05269764667900745, 0.01671232148510171, 0.009725353629619349, 0.08696797434822656, 0.04894850586424582, 0.05410554906120524, 0.024969953774416354, 0.01718329767754767, 0.02808295528666349, 0.022565373037650716, 0.026232196687487885, 0.051682611301657744, 0.03864840524329338, 0.01949290763150202, 0.01916345900099259, 0.021292515557433944, 0.021027437105658464, 0.056952208615257405, 0.02510724367311923, 0.058721195528050885, 0.08796800349955447, 0.008673248903505737, 0.03835038842225913, 0.02282607096276479, 0.042046974049299024, 0.031217224895954132, 0.006266024265642045, 0.08533835905836895, 0.07036417897325009, 0.049261172680417076, 0.06169176776893437, 0.057421706078457646, 0.03814826821326278, 0.06395256481482647, 0.034153357773902826, 0.050255843525519595, 0.04500423958234023, 0.06051414638932329, 0.017306737245235126, 0.029633316626132, 0.04068049463967327, 0.02176524321839679, 0.03524023304635193, 0.05368839527363889, 0.032911496091401204, 0.059425026120152324, 0.03632546817243565, 0.03068270416406449, 0.014582587718905415, 0.06592111152713187, 0.036084737730561756, 0.012455935720936395, 0.023069345115800388, 0.05292361580359284, 0.07484786416171119, 0.02327887010324048, 0.01842617981310468, 0.024354511115234345, 0.035108780139125884, 0.12754584109643474, 0.13471204874804243, 0.08284811221528798, 0.1276166271418333, 0.08335124381119385, 0.111524661333533, 0.12194036258733831, 0.19402570818783715, 0.11771674820920452, 0.18051281687803566, 0.12319851812208071, 0.1367774754180573, 0.13173118291888386, 0.07755712620564736, 0.1746458574780263, 0.15112817724002525, 0.12765461025992408, 0.10575378037174232, 0.15780942107085139, 0.14382862049387768, 0.1585448597325012, 0.21333452052203938, 0.15224178467178717, 0.14598617737647146, 0.13913824717747048, 0.1280081397271715, 0.10854624459170736, 0.08199809337384067, 0.06848261939012446, 0.13241226668469608, 0.18644109251908958, 0.08030831217183731, 0.19426773738814518, 0.1301359958597459, 0.13843049062415957, 0.16196469106944278, 0.07555208067060448, 0.12398839331581257, 0.08980121958302334, 0.17778572102542967, 0.16363045637262985, 0.2790808933787048, 0.08974623386166058, 0.11774511309340596, 0.08707364875590429, 0.11572150644497015, 0.1137884269701317, 0.18486422166461125, 0.13677631766768172, 0.13600305916042998, 0.1953089705784805, 0.10069402531371452, 0.09306531865149736, 0.11680208830512129, 0.1067448963294737, 0.08220858129789121, 0.16461337159853429, 0.16897332592634484, 0.14144182903692126, 0.18893035972723737, 0.1688495505368337, 0.24998534994665533, 0.1549191863159649, 0.14128110953606665, 0.071733545337338, 0.10809707455337048, 0.1965320744784549, 0.19817953841993585, 0.18084190000081435, 0.11827150359749794, 0.12897600419819355, 0.11636216542683542, 0.146806443517562, 0.07272088376339525, 0.1191319347708486, 0.11935951435589232, 0.13747773627983406, 0.17669596621999517, 0.2667628152994439, 0.20065939519554377, 0.16742832289310172, 0.24050279549555853, 0.12310243226238526, 0.223366605641786, 0.14531402906868607, 0.13953065034002066, 0.11830693372758105, 0.20473384531214833, 0.27347375988028944, 0.12659330939641222, 0.11552045121788979, 0.12008757606963627, 0.17192318482557312, 0.19994176807813346, 0.09421895010746084, 0.08991858281660825, 0.14567569247446954, 0.1287276518996805, 0.10124107720912434, 0.15597947785863653, 0.19478492526104674, 0.1798221148783341, 0.12541289383079857, 0.1342139785992913, 0.09289069872465916, 0.19502370385453105, 0.0944174597680103, 0.21855536615476012, 0.11294337309664115, 0.23976447730092332, 0.137544410827104, 0.14527991996146739, 0.1033028970414307, 0.10916829050984234, 0.06901804183144122, 0.1890280857332982, 0.14191108901286498, 0.1712313696043566, 0.10794602523674257, 0.182867577241268, 0.20620163530111313, 0.12118284503230825, 0.12287511242902838, 0.1264855347108096, 0.08646767033496872, 0.15365809929789975, 0.10954806974041276, 0.0918998202541843, 0.17180421855300665, 0.2370048308512196, 0.1075718566426076, 0.13853673648554832, 0.11354029731592163, 0.19181532523361966, 0.16327041084878147, 0.1642064520274289, 0.1913350963150151, 0.12730081361951306, 0.11732298691640608, 0.10510118765523657, 0.09568087712978013, 0.1360441296128556, 0.07084866039804183, 0.13247793191112578, 0.23285515664611012, 0.08593549850047566, 0.07734997052466497, 0.13682099495781586, 0.1832851837389171, 0.19189192971680313, 0.1202043604280334, 0.16144598921528086, 0.12452481023501605, 0.1550020693684928, 0.13635783543577418, 0.06733989750500768, 0.1669938993290998, 0.17440691561205313, 0.1703119376907125, 0.09341913755633868, 0.18923682218883187, 0.17024823173414916, 0.1437137063476257, 0.20106529060285538, 0.06378578938893043, 0.06588329910300672, 0.11665520985843614, 0.14522914221743122, 0.13662772485986352, 0.17206610762514174, 0.15318349585868418, 0.1611420648987405, 0.10266167402733117, 0.19845923903631046, 0.14219365431927145, 0.10436325537739322], [0.02847363481123466, 0.02470155421178788, 0.03248569628340192, 0.013156697532394901, 0.02111945599608589, 0.019257272033428308, 0.03500461229123175, 0.013940580811322434, 0.07720908863120712, 0.029922613211965654, 0.04639673497877084, 0.010004772229876835, 0.057225504497182555, 0.02659031448274618, 0.03198492842784617, 0.0515162774536293, 0.03615822148276493, 0.08059563464485109, 0.020148151670582592, 0.028917570853081997, 0.029678813989448827, 0.015374976937891915, 0.02298250827152515, 0.02359498234000057, 0.0710925375460647, 0.06511079758638516, 0.018191388408013154, 0.04780416238645557, 0.04606191134371329, 0.044539703376358375, 0.007472939141734969, 0.04747947648866102, 0.004783498006872833, 0.012097493236069568, 0.03723781628650613, 0.07268753906828351, 0.0038317209782690043, 0.033621341790421866, 0.009276518485421548, 0.019278349027445074, 0.02127317518898053, 0.06726686275214888, 0.05329951731255278, 0.030106307749520056, 0.01788854020560393, 0.018652360449777916, 0.100726805976592, 0.03151724551571533, 0.02962424016004661, 0.0725229232921265, 0.016792022579465993, 0.055171885396703146, 0.026867989035963546, 0.06770447755116038, 0.04576838080538437, 0.027625573384284507, 0.03878682691720314, 0.020976553605578374, 0.026036434828711208, 0.008556711309211096, 0.11815977326477878, 0.03391205216757953, 0.043677735957317054, 0.017070656358555425, 0.037814064271515235, 0.027513334680406842, 0.07522980304202065, 0.0465686423558509, 0.026355573172622826, 0.042497168251429684, 0.03198947408236563, 0.10196634102612734, 0.049347825843142346, 0.021371448528952897, 0.022005656392138917, 0.03318744886200875, 0.11230402029468678, 0.020819177480007056, 0.02427565421385225, 0.06472295863204636, 0.08514200162608176, 0.05047453960287385, 0.012756398846249795, 0.018209556183137465, 0.023550603764306288, 0.061051483571645804, 0.05047702579759061, 0.014696842281409772, 0.06955110424314626, 0.018298741924809292, 0.046194518290576525, 0.04308637784561142, 0.0931793793279212, 0.09576997937983833, 0.04259612251189537, 0.036607458314392716, 0.027118150319438428, 0.002564178435022768, 0.05263499086140655, 0.025642033433541656, 0.030881872480676975, 0.030943069978093263, 0.050867009558714926, 0.0234211954739294, 0.03443208246608265, 0.005870371887795045, 0.027470141685626004, 0.03253319373470731, 0.04000968961918261, 0.04241860820911825, 0.03803642655839212, 0.04547077958704904, 0.053137703143875115, 0.05311865592375398, 0.010233563371002674, 0.02335854893317446, 0.017503352573839948, 0.02780925864499295, 0.02599757968710037, 0.01793662209820468, 0.017249424890906084, 0.037255728020682, 0.018320253075216897, 0.05371341678255703, 0.039975465479074046, 0.0375037166668335, 0.006365505450958153, 0.0150058419603738, 0.05452320008771494, 0.04368005887954496, 0.061130551985115744, 0.017102926794905216, 0.009412644139956683, 0.060731046469300054, 0.05887954386707861, 0.018432001961627975, 0.03810937596426811, 0.04128759741433896, 0.021080866172269452, 0.03580957534722984, 0.03858997966744937, 0.037048115918878466, 0.05670757076586597, 0.015073558297444833, 0.01909567308757687, 0.01528934515590663, 0.009855822263489245, 0.021389592184277717, 0.032110340252984315, 0.07371066385530867, 0.11244567402172834, 0.045948132683406584, 0.01878230679722037, 0.04196180889266543, 0.10575527951004915, 0.08501845630235039, 0.03538209457474295, 0.0336126809270354, 0.07761761124129407, 0.042081172214238904, 0.029393239274213556, 0.018276677874382585, 0.10710668590036221, 0.05152881974936463, 0.06215903878910467, 0.012426938155840617, 0.06565682531800121, 0.06207201826327946, 0.048715935336076654, 0.056997457359102555, 0.09043551093782298, 0.020610350111383013, 0.08409546207985841, 0.05531049631827045, 0.09262469073291868, 0.0146932948155154, 0.025130938593065366, 0.05733008423703723, 0.04790136888914276, 0.013978233673697105, 0.058460972577449866, 0.04519187306868844, 0.05890308108064346, 0.006880160281070857, 0.031468282322748564, 0.011251040414208546, 0.038707532148691826, 0.0050151334289694205, 0.03773221651499625, 0.04928044254484121, 0.012315624353504973, 0.041634744411567226, 0.024639670227770694, 0.03110956709861057, 0.049209908829652704, 0.09651669126469642, 0.03506496002955828, 0.018056857443298213, 0.014032426224730443, 0.04431578257936053, 0.026632260669430252, 0.023598303450853564, 0.0064876829037530115, 0.029377720966294874, 0.03548933120328002, 0.03129279408312868, 0.07487159062293358, 0.03704934046254493, 0.021202353891567327, 0.07671305196709, 0.022239941281441133, 0.11303528808639385, 0.017405068101652432, 0.05166090719285421, 0.03486936700937804, 0.017841308072092943, 0.06246222837944515, 0.06952145544346422, 0.01677339281741297, 0.01348175357634318, 0.015187030821834924, 0.03206737732398324, 0.06404358922736719, 0.026905580671154894, 0.01953586128365714, 0.049146436649607494, 0.051810279255732894, 0.032645547471474856, 0.07389436766970903, 0.016285449273709673, 0.06524623211589642, 0.020687231044576038, 0.03676620370242745, 0.03312730150355492, 0.10382519831182435, 0.045976375113241374, 0.06852625767351128, 0.0953060999745503, 0.08230635925428942, 0.02126637897163164, 0.05193570221308619, 0.04336995247285813, 0.01784540287189884, 0.012765300907631172, 0.018452717158652376, 0.022913764987606555, 0.009567983070155606, 0.05188671304495074, 0.0083779288615915, 0.04860807159275282, 0.030353036599990446, 0.038531045720446855, 0.02112077516358113, 0.03708906391693745, 0.06926540707354434, 0.06667960129561834, 0.06580875036888756, 0.02461040363414213, 0.05154301703441888, 0.07307474719709717, 0.008367457157874014, 0.03154112782794982, 0.06549662532052025, 0.04687191729317419, 0.0013408535141934408, 0.05161663437320385, 0.047525715999654494, 0.0192770818102872, 0.06030169177392963, 0.04253072074789088, 0.03797713638050482, 0.08989946509245783, 0.03670563703053631, 0.007505756911996286, 0.03000225122377742, 0.05290477638482116, 0.028797047925763763, 0.051223181071691215, 0.023834840758354403, 0.07318465926800855, 0.08292116181110032, 0.029582635361293796, 0.08420172278420068, 0.02272243560582865, 0.030536564154317603, 0.031606633492629044, 0.07364420453086495, 0.008907957744668238, 0.042369088405393995, 0.04001364897703752, 0.015440726583619835, 0.04594232908857521, 0.0031792616164239007, 0.0035074305060334154, 0.014287973644968588, 0.03240394129534252, 0.02920381164585706, 0.05255607087747194, 0.01577292765432503, 0.03266703264671378, 0.046142545688780956, 0.06040755171852652, 0.0904648554569576, 0.056361065726378, 0.0447842781431973, 0.04819741159735713, 0.04886279522906989, 0.03516543198202271, 0.020732420416607056, 0.05221086830715649, 0.056567356805317104, 0.007250233147715335, 0.08641415406600572, 0.034200510126538575, 0.13648658321471885, 0.06603377696592361, 0.098521937179612, 0.029617167492688168, 0.036483553049038164, 0.03224254272936378, 0.08108818321488798, 0.046361583154066466, 0.01736648384394357, 0.030518116218445357, 0.062217030208557844, 0.03814047566265799, 0.034285363581147976, 0.026180760287388694, 0.03496048790111672, 0.0702681895927526, 0.0181323524157051, 0.05373733991291374, 0.03601775890274439, 0.03572956811694894, 0.054525155646842904, 0.03351277300680522, 0.039170877207652666, 0.01967227173736319, 0.03482915002678055, 0.0342905808793148, 0.01785294123692438, 0.06888723088195547, 0.011088051796832588, 0.06559648871188983, 0.059257571629132144, 0.06688853070954792, 0.04228974168654531, 0.020307503764342982, 0.028933005669387057, 0.05251651440630667, 0.026046830462291837, 0.003988060416304506, 0.09937585971783847, 0.11306618369417265, 0.1410193688934669, 0.10905158778768964, 0.09715349107864313, 0.14275885914685205, 0.1546086568851024, 0.08873892424162477, 0.1324206084245816, 0.10028998527559452, 0.09988636084017344, 0.11416719687986188, 0.1181551199988462, 0.1710301436833106, 0.06468715000664815, 0.11496893159346655, 0.13909932895330712, 0.2008947599097155, 0.13458763511152938, 0.19633390620583668, 0.2580019400920719, 0.16754069889429957, 0.13167038618121296, 0.09930052430718206, 0.15165348420850933, 0.14490215195110068, 0.0669588714663405, 0.10791587177664042, 0.15815643448149785, 0.10887806623941287, 0.15649684384698048, 0.17353839502902701, 0.08488268780638464, 0.18171591247664765, 0.12661330285482109, 0.22428312833653763, 0.12170233356300741, 0.12757582386257127, 0.0680234377796296, 0.0978300254791975, 0.13628197310026735, 0.19805117655778304, 0.1152547326637432, 0.22597433446208015, 0.10598383130854927, 0.10032931168098003, 0.18787484761560336, 0.1614821911789477, 0.06355982026434503, 0.17422507458832115, 0.12529616884421557, 0.0907990890846122, 0.19724202778888866, 0.16613521962426603, 0.1580666346126236, 0.0932128427666612, 0.15590463968692347, 0.16018276481190696, 0.15885221277130768, 0.12189549233880825, 0.26811756135430187, 0.12831102503696457, 0.20387353288242593, 0.11799251544289291, 0.158372147125192, 0.10418834601296112, 0.18230216461233795, 0.1793697164976038, 0.06338111852528527, 0.13325399573659524, 0.15161369025008753, 0.14426150039071217, 0.09244551401934586, 0.08670232258737087, 0.08776485541602597, 0.10142292565433308, 0.15493679005885497, 0.22319846466416493, 0.13905744213843718, 0.2710831834701821, 0.26826839544810355, 0.1666285251849331, 0.12201652920339257, 0.16211114649195224, 0.10735281917732209, 0.14393378281965852, 0.1876126616843976, 0.15986871760105714, 0.12701044091954827, 0.14049740158952773, 0.14108623639913276, 0.08476110917399637, 0.10800406118505634, 0.196564580546692, 0.14039393136044964, 0.2677909273188561, 0.17161106719868258, 0.08814981483737938, 0.12158079945947975, 0.12101269283448346, 0.1622717472491786, 0.10287004683050327, 0.10316278698155656, 0.15383428515633568, 0.10812069711391814, 0.10445672887726687, 0.19956021511461586, 0.17095189163228497, 0.1082683028653264, 0.17826320399763063, 0.13818475068546832, 0.10922002562438138, 0.146607696369756, 0.1575066545046866, 0.14961688255425543, 0.13041229743976146, 0.11630624459940009, 0.07881943776737899, 0.07174358659540303, 0.10676296762540005, 0.13714341359445825, 0.1427284607780166, 0.09209851545165293, 0.11721756483893842, 0.09939297364326194, 0.16815938288345933, 0.1473039941629395, 0.12546159356134012, 0.1710548423579894, 0.11433318562922068, 0.16421612963313237, 0.18703691835980862, 0.081531215691939, 0.12460050929803401, 0.15034979791380465, 0.06709383844281547, 0.1287320305709727, 0.14608192926971242, 0.23371146147837862, 0.15793968283105642, 0.12637596402782947, 0.1347236559377052, 0.1592414840706624, 0.11385330552002415, 0.12348625619779341, 0.13317804434336722, 0.09634584886953235, 0.16274053225060925, 0.11371731437975541, 0.1639411342330277, 0.20766023750184104, 0.09078425355255604, 0.08843262505251914, 0.18980680644745007, 0.12322783295530826, 0.12784900842234492, 0.11162851747940294, 0.13426396966679022, 0.1389240930438973, 0.160604853881523, 0.1151082401338499, 0.11523469467647374, 0.17861401720438153, 0.1580456763622351, 0.1463089374010451, 0.1690339297056198, 0.14873252453980967, 0.22536477888934314, 0.11190860401256941, 0.14729087299201638, 0.14307348523288965, 0.10207795261521824, 0.12046981180901639, 0.1696876430651173, 0.1457231750828214, 0.09212954464601353], [0.10930060059763491, 0.03816145988821518, 0.07459235013811849, 0.09178533655358478, 0.037529213150264695, 0.016768611531006172, 0.025084452317969408, 0.029868881720176432, 0.03961198381148279, 0.01798083925677929, 0.06205427351233084, 0.04782224481459707, 0.007693061070312979, 0.08206281607272103, 0.016693940342520364, 0.09270954789826646, 0.059691483111237176, 0.06084174521674868, 0.028263579188205767, 0.009152830298262415, 0.004648598751373356, 0.04560587643936742, 0.05427890733699314, 0.04832163598621264, 0.04233529471093789, 0.07385711927781813, 0.013655112779815681, 0.06741797886206768, 0.0541745873488253, 0.03300755597592797, 0.01134300642661401, 0.05910241081437562, 0.03381276394065935, 0.02369423531490611, 0.030548928334610537, 0.011201477009308292, 0.0655891934002284, 0.03549190645571798, 0.050132535689044744, 0.03745507630810607, 0.04120774974580854, 0.015581141851725988, 0.02764150358416373, 0.028422226241673343, 0.029280547860253137, 0.022163958346936852, 0.01789323243428953, 0.02695363473321777, 0.04338194186857436, 0.014016889363119844, 0.020299050702305976, 0.09389458704390563, 0.05732159777835477, 0.045577904893434606, 0.07405384036246687, 0.012314253235672368, 0.07167783231125213, 0.02894826979172649, 0.02345009099371964, 0.01697630712442333, 0.031241237084032036, 0.04702068821643479, 0.0089683861915546, 0.00639086278169998, 0.05763633889728226, 0.036058892437722534, 0.056564455007901415, 0.017952030939341057, 0.03807603497989476, 0.021623496722895652, 0.04553927239612676, 0.01980331460799789, 0.041488222195766866, 0.004204248034511693, 0.05918446266150568, 0.06347567556076683, 0.04315369435062166, 0.022779426981287543, 0.05174369376618415, 0.026241423438477796, 0.07326973165618256, 0.027071853292000014, 0.03225533364457078, 0.04059159276948776, 0.03261598772951402, 0.09612381312763318, 0.02795137435896322, 0.09429366953554563, 0.01647242967010243, 0.02463826571329264, 0.07195840124040842, 0.02868917305022478, 0.08726426196517423, 0.04437283147126436, 0.05863617880095262, 0.03513425435812678, 0.05193894910917152, 0.009457289888814557, 0.04125526946154423, 0.07019804179435596, 0.029157342069083825, 0.06316138344118372, 0.023657534256926738, 0.08439736033324152, 0.04284914663003292, 0.06455522583564743, 0.06409098277799785, 0.04092850555025507, 0.05623914570605848, 0.04455580798094161, 0.019719123520189896, 0.014104406200203812, 0.026389003214717377, 0.12435288430424407, 0.017122528770414647, 0.01760789891704917, 0.05064470293291379, 0.01949078323377762, 0.05446087823656853, 0.0570577568578301, 0.021982993057463318, 0.028227117472852115, 0.03387070340977516, 0.05242149723926559, 0.05099651432828978, 0.01567842442455003, 0.046196332841645926, 0.08787075246800669, 0.046144735024427064, 0.0362980346835684, 0.019499416266626213, 0.040837982087396085, 0.03593962188460864, 0.0447793428611476, 0.024570288696850184, 0.012592906496138312, 0.0656857987632975, 0.02867459912522463, 0.029197943113103975, 0.02115783245244529, 0.02552193353039911, 0.04035351921629626, 0.025544489253661595, 0.028203537585795857, 0.017956997762667015, 0.017013980395859107, 0.056525046966271475, 0.05464782523631584, 0.11725839780410752, 0.04703203565441072, 0.06352447919198312, 0.06636283040279523, 0.06124782616097946, 0.022315811038424727, 0.03636711378931068, 0.017304622124356683, 0.01641433063923614, 0.046494438720401376, 0.0796864740550518, 0.0444694294128567, 0.026293462833564263, 0.05374525491788518, 0.09394548353157006, 0.02447897299134638, 0.06349660412524827, 0.05947816389380023, 0.07501253188820556, 0.058100886235479265, 0.02410894743661629, 0.049493353581056, 0.0201562058282434, 0.027210454936721362, 0.029975253746670205, 0.035995260695926845, 0.05076953959360253, 0.037095509469509125, 0.07215698511572555, 0.012294069601921365, 0.03759068153158296, 0.11403402590076439, 0.021941171180515084, 0.05408806406194344, 0.008860359175741905, 0.020409775424923282, 0.1064896717434749, 0.046926602444727905, 0.04763631084642839, 0.02441477536194725, 0.050054124076268636, 0.03269839580752887, 0.03273982249083929, 0.02325203033251455, 0.047656263486715034, 0.027813587221316993, 0.06519907605252229, 0.04559648456051946, 0.03187687543686479, 0.035951926693087444, 0.009650582251197193, 0.05366726632928476, 0.013788770793325966, 0.052573385182768106, 0.012260351977602113, 0.03544952240190469, 0.036625659486162476, 0.015824122856429312, 0.026770224067149684, 0.0050555011603137245, 0.0749351481499616, 0.04393215902382508, 0.04579182525048964, 0.044371688563842326, 0.04742479133710731, 0.025494659603282344, 0.005139654213053291, 0.04072091200214345, 0.05508423404535279, 0.0479184457071824, 0.049824269808596, 0.04860458349867258, 0.05514493059308734, 0.0420329474582104, 0.09561518221744336, 0.034787886615958996, 0.01901915209600702, 0.03500070859445259, 0.05620775657007471, 0.06258559558773413, 0.13438577094348148, 0.057079164107562974, 0.008399395483138505, 0.008942309905251022, 0.021651789247698616, 0.02897802805819083, 0.020315274050517473, 0.031188789507723413, 0.06106560293119401, 0.07130894038709812, 0.058152376441285014, 0.03312141627247911, 0.036870367839583196, 0.03717175772180781, 0.07943952441564761, 0.06415897092665546, 0.0519723939942196, 0.022872885638207663, 0.07092083425959572, 0.06500716408481821, 0.03756050951778889, 0.014509050160995685, 0.0625233665050473, 0.04161950811976567, 0.038579715765081346, 0.07426535245031118, 0.01983519170607906, 0.07690306403674185, 0.07763742658426054, 0.029221641743788496, 0.04395250500238035, 0.016441120314993896, 0.03910589475708548, 0.03068060388613958, 0.016730747156543657, 0.01936428416229319, 0.03476896927168127, 0.025597348721930757, 0.049563660941203125, 0.019421132674324326, 0.09293608847656287, 0.027937700288021006, 0.029037054773652926, 0.024383517957176082, 0.013397477141552372, 0.05803854211990256, 0.012870511473010993, 0.017077508236980066, 0.024772308715910185, 0.04506870995101053, 0.06413380469894037, 0.03537792741553858, 0.03527039021719247, 0.07829059817595407, 0.053089196371729486, 0.04280297762306873, 0.022369344005710445, 0.04961159254889935, 0.03699042877997272, 0.06237963476451114, 0.05604807236522902, 0.02529642453737324, 0.013893092636863003, 0.012213400932523655, 0.028631363456952386, 0.07107163866749033, 0.08661818530526944, 0.045896011652075686, 0.029437233788485173, 0.041344234414282255, 0.10506340491701849, 0.09023332764627412, 0.05571104084083345, 0.0034010190529443207, 0.04822746486752294, 0.03367992692801636, 0.03214634183677845, 0.03643765492597595, 0.08944679211708717, 0.049021614831872284, 0.03865912927722093, 0.049712617401382886, 0.02179748953494709, 0.04395636417029891, 0.044638909967034124, 0.02925665998191107, 0.021408581887953915, 0.04145095153944567, 0.016005984289222397, 0.026283573715772945, 0.029257723108457867, 0.02741839172813343, 0.03329072984342929, 0.05142006542882882, 0.09397568894200958, 0.021527243879972957, 0.0511114396067569, 0.03783291111176368, 0.014974727419030387, 0.015097940631676465, 0.06840646761702374, 0.02581098520749947, 0.050594136700965464, 0.04684769730374683, 0.03726077833562158, 0.025526039462420158, 0.03601603712013457, 0.02825917454174487, 0.010995250868290896, 0.03657415814814158, 0.004205503191769822, 0.07032853362034075, 0.03527408611262217, 0.05363440403016284, 0.030393646920856554, 0.010408359557914082, 0.012131141284044133, 0.01893115564598702, 0.0447295892809052, 0.01808424825867405, 0.015306336626963457, 0.05297146948578302, 0.04526376120338682, 0.014022607610968407, 0.17705917329294607, 0.1087604506756179, 0.3532847069436684, 0.17691270302748308, 0.0972063913650345, 0.15052875940455124, 0.13375950220506638, 0.118957359372871, 0.1882108030258678, 0.11039273769711144, 0.14197917364072055, 0.07507270522182807, 0.24968480982352048, 0.16256151138804853, 0.14064546005101874, 0.1966718802577816, 0.17368597851600498, 0.14893691200995818, 0.17510962556116283, 0.133984001877252, 0.11717790446709841, 0.12031577905872837, 0.16351266269339249, 0.1680387690430507, 0.09981760827940889, 0.20392490434460342, 0.06585370967513882, 0.14260133088100702, 0.11708369624102488, 0.0902575439249631, 0.20111826510401443, 0.1123727134836372, 0.13378237519646063, 0.09608269072487019, 0.18666214862605557, 0.09705167583888397, 0.14250473293941468, 0.1158223494712729, 0.2663383662002161, 0.10438563855132088, 0.15751162689412013, 0.21625052264425904, 0.09227663089404814, 0.1109622692456469, 0.20016542170196772, 0.13581102102762088, 0.17813717247918248, 0.10926454706350341, 0.10850189384655096, 0.11116707973997109, 0.1488914035144262, 0.13960740325273946, 0.2092801232356578, 0.20549600129015744, 0.18906605400843546, 0.1226350424985867, 0.18147348251659423, 0.08613103214884177, 0.10012654951424338, 0.1602653064765036, 0.18736701080342755, 0.1598017758806236, 0.17431218788260594, 0.13390203908784315, 0.08260119968326762, 0.09476532664848492, 0.18112879944965243, 0.1883170785731636, 0.14248364110244438, 0.2224834350636229, 0.18839972413843498, 0.11535452184034511, 0.15685997670516372, 0.11344392944010906, 0.15718007984105498, 0.20029657403938472, 0.12892693339381367, 0.12672864744672552, 0.1666858041426167, 0.26369655795861036, 0.1997212166315876, 0.1771609514253214, 0.10079793340992182, 0.14282470248872414, 0.11963594952248968, 0.13222419162048027, 0.10677566577214748, 0.3178102261153981, 0.13432044710498303, 0.08486734019243158, 0.18979715852765366, 0.20987283205613494, 0.2583690360188484, 0.1282196369720623, 0.1939734461484477, 0.1012923447706271, 0.11840801424114034, 0.1463804507511668, 0.12261239957297221, 0.21294648118782789, 0.14813439804129303, 0.16666018520481884, 0.09506224509095773, 0.126738325052429, 0.17018770216964185, 0.17975039372686297, 0.11321444253553636, 0.1770517963450402, 0.07274341536685824, 0.14906061318470165, 0.19601926527684554, 0.21254606283036992, 0.09761842433363199, 0.15369905100669712, 0.11464737384812906, 0.07828597459592856, 0.15878653270192444, 0.13112844026181847, 0.19696078350534663, 0.2392990913358517, 0.11439125126344152, 0.1308244714164175, 0.20176360703771934, 0.19025067012989894, 0.17007756745442748, 0.1022766626556404, 0.1291401672642678, 0.17093096306780353, 0.1432231764192693, 0.09777592291356996, 0.18635950080351904, 0.14318930479930714, 0.18927611148683354, 0.21926298912148923, 0.15347483335062861, 0.15793704078532755, 0.148115903721191, 0.22466720460215583, 0.12892512255348265, 0.08339006555615924, 0.11857095276354812, 0.09600796387530863, 0.18341820628847927, 0.11979592687566765, 0.09247061345377006, 0.0871749890211504, 0.20427236304385588, 0.15967601153533906, 0.277302143513225, 0.11780002460000105, 0.10756155563285574, 0.12764091021381319, 0.181174797762651, 0.12244350160472095, 0.12619073881069198, 0.13956526410765946, 0.15968736639479175, 0.1980458924663253, 0.15399746858747676, 0.11588002918870188, 0.189033399510663, 0.19629108428489417, 0.12865152239101008, 0.11054194648750126, 0.14898011984769255, 0.13422004936728626, 0.17559424799401313, 0.11385520541807637, 0.16771250608144328, 0.17651736096013337, 0.11225506823393516, 0.08093977594398893, 0.08065475412877277, 0.10273943626089022, 0.11303390027023852, 0.12437324141501449], [0.04075462406035513, 0.027505339894560166, 0.07444251052220352, 0.03700731263961643, 0.0325683641131036, 0.024364185010199435, 0.05230983369983733, 0.0916670604783576, 0.03385958603757899, 0.04318120205425657, 0.02867681258067023, 0.044213377332198434, 0.04427010710060131, 0.03133307785901707, 0.012284785334486514, 0.03509085356199648, 0.04813778374227695, 0.06001625064527616, 0.08915508355130441, 0.04910401548841037, 0.031976612663129345, 0.05796204895887058, 0.05330809282895643, 0.06291183628491126, 0.025723445178300608, 0.00597854269472009, 0.06102638042648323, 0.02084716943500098, 0.03203001760994084, 0.0286113533002208, 0.07814099604729563, 0.03791826551605482, 0.07911661596153863, 0.00929196165088797, 0.05736016348237172, 0.03262970632931683, 0.04010003867733758, 0.06386039749486372, 0.014771138685318874, 0.07476872895495035, 0.00978443693384179, 0.02211003204138251, 0.02142843062756583, 0.05743847490521148, 0.03843101905658841, 0.02359356112719979, 0.05377401685109362, 0.035873125452781096, 0.02636984096170636, 0.06409981433534995, 0.04681297592469491, 0.0061995732903596945, 0.005529605969059048, 0.060066694422857836, 0.04080689723195974, 0.044230201820028014, 0.02348258964048, 0.07446168761816807, 0.022362523668562062, 0.0318982530006906, 0.09380264236824587, 0.008004444898688234, 0.028421996175893582, 0.10862148352316581, 0.10022297676187009, 0.06407999157090671, 0.00993550480416161, 0.04811965307453647, 0.03122752590570599, 0.036855161233688705, 0.042334374447818846, 0.05968654040771071, 0.04899701634712983, 0.08432372444076464, 0.08237920104875229, 0.03912422209396027, 0.016434223907708656, 0.06404295840184204, 0.09853508803644218, 0.07055908921756782, 0.06196668524353299, 0.02698442458495265, 0.022246049156819936, 0.03491912430035882, 0.08965134285972454, 0.04754250338010024, 0.06899507236084901, 0.022488924405479338, 0.047074868707568385, 0.03746508045878727, 0.03972955855715554, 0.02783052303129807, 0.07007431835518219, 0.0806338329857681, 0.030158731206029188, 0.06986198990489356, 0.055975059876800515, 0.045965083336341195, 0.03715266597282607, 0.049875641270773485, 0.037858659925404936, 0.024569830420659855, 0.025382127751072403, 0.07183937559602782, 0.026595932540658396, 0.072171048814198, 0.025876537256408483, 0.055032569434843026, 0.09538626676658168, 0.08034219121327624, 0.0271393367802375, 0.04084053507540375, 0.024933738823165186, 0.09808055227040313, 0.043691243045032024, 0.0329549636808224, 0.0638588092988357, 0.023861797417339403, 0.007885856193752261, 0.05045654994319193, 0.06076147823478095, 0.03502233106701169, 0.03378212437382899, 0.020652409475587774, 0.04861772322328761, 0.08590273268055171, 0.028434393752831966, 0.0429768516914919, 0.0366885527910199, 0.017955641487787943, 0.03815580472291913, 0.012677444537985139, 0.04999972094083205, 0.07126550248358399, 0.036963459133403376, 0.037475596691365354, 0.06174204085255042, 0.01909815000544768, 0.04542702627077233, 0.017143102959380485, 0.044122100589447655, 0.034501829504733905, 0.012577925317600602, 0.008922360048018163, 0.010884826715482632, 0.05526100991119165, 0.028564972781168763, 0.04934869044518564, 0.03408684649912175, 0.047361222677864134, 0.061703434330411255, 0.038735117777832784, 0.032521779503440484, 0.08865743642672896, 0.04768401980982162, 0.03104196486674482, 0.05702468304662034, 0.08404173800954595, 0.057307474708068185, 0.09906685168971308, 0.07578679971629754, 0.02132298071956029, 0.09267529036151245, 0.023201909389172215, 0.01532697389848181, 0.07513149816077203, 0.07159940956626087, 0.0380446643976029, 0.04613565484760329, 0.019112800000584684, 0.04815817053895444, 0.025204010453308, 0.04581813067488838, 0.053069217756274156, 0.03383368137292564, 0.03170650430547539, 0.022499021324620117, 0.03404534189030528, 0.009742782040120801, 0.049210161159862764, 0.014186740991135594, 0.04286275761842262, 0.06283696100581437, 0.017232524332939647, 0.02301287509908434, 0.09033877940964885, 0.0434857534855837, 0.023563097820442636, 0.02979923116072314, 0.020324315264588222, 0.008129445759550435, 0.022610803607676644, 0.04735788672405761, 0.035753673073486425, 0.014404951889446238, 0.07914040921605192, 0.04293378486181609, 0.06859596018330194, 0.015775467654748354, 0.03436233913816977, 0.015039043792057782, 0.06028235140547622, 0.0335295084369136, 0.06244250951567665, 0.040625783512950875, 0.04624568195140455, 0.0712267252674792, 0.030817519000265747, 0.010597215732559562, 0.03431485281907953, 0.05307302868459374, 0.10101829931954853, 0.04444726888323203, 0.025599465698178392, 0.0033949450380532653, 0.03606065503845457, 0.02343291027500527, 0.025647553156886715, 0.044301295856712386, 0.05505816610821057, 0.038302608954836614, 0.050000095725408755, 0.02613944307086058, 0.030014891854079906, 0.051745018499786966, 0.04214717882859986, 0.08313469996210188, 0.012085002890671603, 0.030795354759902693, 0.01253789572729147, 0.07054645786411129, 0.05719526940083597, 0.026991762570105493, 0.0332209902262548, 0.02180201292503625, 0.05772264696133789, 0.1027560826332774, 0.030447237404587213, 0.018085179654008243, 0.027601368237810675, 0.05687150747689884, 0.0327319408825133, 0.05367166355426889, 0.029364247275225352, 0.042543563613435254, 0.02847997089702403, 0.058395478044985794, 0.007496397038266878, 0.0405492903519189, 0.05283967147988733, 0.04628472262993455, 0.06722574777086265, 0.06559092260431498, 0.0677320483373478, 0.037534927687374875, 0.04905957197479438, 0.026008485547208693, 0.03900200521457009, 0.019640179416455794, 0.05012478766730055, 0.017191656115755904, 0.03844070408376865, 0.06801930401707068, 0.014886118697177153, 0.013804607297061011, 0.04446972627192736, 0.05455106031149626, 0.027521670854184777, 0.03531609909259714, 0.04017367085907608, 0.08250076483818702, 0.110855615203036, 0.031951780401868746, 0.06667666981229559, 0.06585784343769774, 0.04571054894768167, 0.0677407463081181, 0.03115694024018012, 0.05706035066395998, 0.05485449109983165, 0.07574485352961347, 0.0694737872981932, 0.049219835054827854, 0.05107417266117409, 0.04596652310283389, 0.04809411577298306, 0.011582379665924236, 0.03814486917690374, 0.041280669465777464, 0.040208525824709795, 0.0340806829626672, 0.021063941494503524, 0.044033818412572145, 0.07444041766575538, 0.07085266057401896, 0.04819328154553659, 0.028476245315687265, 0.09550855786073953, 0.03227060333301779, 0.04334424818807747, 0.031492817724938504, 0.03750802483409643, 0.05691616621334106, 0.01966832536709262, 0.0456834086071467, 0.010584012925392017, 0.055057698555174284, 0.010143512099602958, 0.06995129253482446, 0.07563791747088544, 0.06070019539038185, 0.013214173159212805, 0.08907439725589938, 0.01727481747366255, 0.026551771043159533, 0.018037507797998842, 0.02052086008916376, 0.024767683280515485, 0.03416426363401115, 0.08010271500097588, 0.04737332339573186, 0.052825771053903736, 0.05997018924972508, 0.044240680945222266, 0.055498415531474166, 0.028083736397093162, 0.04709580469352659, 0.031177568234852515, 0.10794650763273239, 0.02529834113374818, 0.027802790827990975, 0.05167032875760924, 0.022818319230282214, 0.04431845431099646, 0.0271033723038272, 0.07172447629272938, 0.039645870274398476, 0.05678262787114363, 0.05104781528643798, 0.021333235345082358, 0.034609930735314265, 0.0177573266410036, 0.012791875360562699, 0.03447596565820277, 0.0253326636084239, 0.03897448266798165, 0.013518766336346744, 0.03648761259682942, 0.038181575800990686, 0.050696950129349716, 0.06321135224425234, 0.07207976464997046, 0.10861613263841718, 0.10694658980355598, 0.1690781765501015, 0.1961633755126968, 0.12638099578907713, 0.12070178490830585, 0.15341436315793544, 0.14522010285872966, 0.12833523389417678, 0.1613605977036059, 0.14293186861323193, 0.15661447425372899, 0.14800866338191554, 0.10211905275355093, 0.12109216200769879, 0.1567890719161369, 0.08760825483477674, 0.12879414833150804, 0.18524256855016574, 0.18403381778625771, 0.08010566132725216, 0.20405111397849396, 0.18929459096398205, 0.13089656364172697, 0.06535175809403881, 0.12323274597292766, 0.2550409489776939, 0.13785271381493658, 0.10355308244470507, 0.1393678379827179, 0.2515567734371871, 0.14129273156868294, 0.133937350474298, 0.09847045439528301, 0.17415503069059923, 0.34649224486202, 0.23040771688101813, 0.18311106105102226, 0.09684878008556552, 0.24728733144002035, 0.21495207591215149, 0.1418096077395603, 0.1358350962982513, 0.11202977446373552, 0.08584611423430033, 0.11209100906853564, 0.1492757024243474, 0.14542668708600104, 0.09928573330398649, 0.17997337941778824, 0.14904438983649015, 0.08105499437078834, 0.1783667632844299, 0.12459020828828216, 0.2948196488432586, 0.15836206875974312, 0.14971978875109926, 0.09303592960350215, 0.16896047192858532, 0.18646301556145772, 0.18041010363958776, 0.21779448667075485, 0.1672639074968174, 0.12543524731881917, 0.1846414289320819, 0.13166007032850757, 0.08239629270974547, 0.10363562410930172, 0.10595632731565274, 0.11833292373921722, 0.1518271170789376, 0.09738426189869642, 0.08802886703051627, 0.10201158234849572, 0.15640885481843725, 0.20050713617820293, 0.20844899205258116, 0.2321032274630852, 0.1736837372300215, 0.19838527659885585, 0.12413748336257413, 0.15218083950458094, 0.12110826661228202, 0.12357072744634934, 0.19448448903858662, 0.15904965373920277, 0.16921719565289095, 0.08756432711379603, 0.15180212154518813, 0.1436659714090638, 0.1479305449174717, 0.1102408571750857, 0.13024013402173296, 0.14707426977111027, 0.18196934106526896, 0.2164878317853436, 0.13073042646283284, 0.11465599018265493, 0.14746483240742236, 0.11512028519064188, 0.14119928033323959, 0.1029629043478053, 0.1437275399803184, 0.1532849474460818, 0.17024881060933694, 0.18802333652274683, 0.16568025341257453, 0.16029433929361403, 0.16702932945918292, 0.1337107876315713, 0.09910374385071918, 0.14645561546785757, 0.17261370870983228, 0.19743215118069202, 0.12206915489514358, 0.10175228337175213, 0.18142809276469052, 0.10283698415150866, 0.15938770200591534, 0.13486282347002998, 0.15237608371535316, 0.20268577005481347, 0.17183711053803563, 0.10050417651655152, 0.14995859703049064, 0.12614539358764887, 0.16949747514445335, 0.112143337901216, 0.18156687438022345, 0.10442259750561789, 0.15199533227132633, 0.0897916236135643, 0.21218389476416633, 0.15853648830670863, 0.1605373778147623, 0.09492740427958779, 0.10942505876300856, 0.10304642564733513, 0.10275219377945177, 0.12491915782447904, 0.15896028431598097, 0.15001226915046573, 0.09310965455370024, 0.14979603700339794, 0.1344564085593447, 0.13130645180353895, 0.1290981617057696, 0.22174630430527031, 0.16038535628467798, 0.1482444436987862, 0.14125477813649923, 0.1352574530756101, 0.12656543432967737, 0.11542503329110332, 0.1298078626859933, 0.18732824100879952, 0.12092128992662765, 0.13395971880527213, 0.1562160745379515, 0.15152620588196442, 0.10317066116840579, 0.18578313407488167, 0.1579593200585805, 0.1264885626733303, 0.1800394750898704, 0.1233748227241449, 0.14964080939535052, 0.0847354531288147, 0.1528682908974588, 0.15537781873717904, 0.17699623916996643, 0.17561697255587205, 0.13772674166830257, 0.1346306796767749, 0.18255171919008717, 0.17931133916135877], [0.0024644235827508965, 0.07474154408555478, 0.012687344787991606, 0.08261305920314044, 0.019990543623862322, 0.017150917774415575, 0.016867957274371292, 0.056975389597937465, 0.04117105054319836, 0.017828136806201655, 0.06288156408118084, 0.06627406211919151, 0.050367559015285224, 0.020374512278067414, 0.03194493408955168, 0.07014065893599764, 0.004659886353692855, 0.017444776713091414, 0.03791508912399877, 0.07308542670216411, 0.037087431192048825, 0.042194000925519504, 0.10075160855194554, 0.07179336986155249, 0.0022733653167961165, 0.10038803782663308, 0.0764772122784052, 0.01636050823435653, 0.025545886346662883, 0.02069200862024445, 0.03544365201378241, 0.02045668657956412, 0.03517037839628756, 0.02465465418936219, 0.040258227454614826, 0.03162937660817988, 0.041640284543973394, 0.023992665883270092, 0.00764340999921842, 0.022069868864491582, 0.04104032494069543, 0.11398229820770212, 0.00520933677762514, 0.051331271170056425, 0.017079870121960994, 0.052450248040258884, 0.055825049566919915, 0.016827051949803717, 0.0706797550083138, 0.052818883923464455, 0.01516400569016696, 0.037379202840384096, 0.03329520499391947, 0.030722947121830657, 0.05854765171534382, 0.044888876436743885, 0.03849587905278895, 0.030680288473377004, 0.016405257883889135, 0.02273125974170398, 0.024438373802695423, 0.04955030970450025, 0.07640891242772341, 0.10962509724777192, 0.07805199769791216, 0.03642104937171098, 0.006702732252961141, 0.07782754997606389, 0.03539940145856235, 0.04938980913721025, 0.04262025344360154, 0.03134775011858437, 0.06423935294151306, 0.021471462205227, 0.05014135611418169, 0.08024837632547133, 0.10799367853906006, 0.059398817174951546, 0.025401881866855547, 0.0670219020685181, 0.03807771223364398, 0.09282044702558778, 0.022433857047872152, 0.03746212300029583, 0.06853017621324398, 0.011908265987585764, 0.04048974042234477, 0.04831434809602797, 0.05445604685519356, 0.010800408344948664, 0.05631801002891734, 0.03085889187786961, 0.08318675420014188, 0.08906710194423795, 0.07373965214355849, 0.030049769084143918, 0.02791254890325945, 0.011759020089812111, 0.10018615139415488, 0.09763656242284924, 0.010737648626673035, 0.07194605190306902, 0.02322025342436973, 0.06039985935785808, 0.03471729352895636, 0.027930514443141874, 0.058025766047649086, 0.03310195716039743, 0.013497835916496115, 0.04611340154951904, 0.07102515795850195, 0.041410574995097704, 0.03683995091705583, 0.03262057791289408, 0.03338034788612276, 0.05071835737908259, 0.027222448043175973, 0.0654440738435369, 0.057335268138558604, 0.015559472994937096, 0.0637211037974339, 0.004291655404813355, 0.034327706816839054, 0.07445526061928831, 0.01473903708756552, 0.039649024402024224, 0.032837396356626414, 0.04490919272939209, 0.02477435889886692, 0.027944687608396634, 0.03589134146750439, 0.009560401103954064, 0.04288712232664693, 0.051657515577971935, 0.01818699860450579, 0.04174493849859573, 0.04243334726197645, 0.04154111877141986, 0.03246966218284797, 0.042082686195499264, 0.03172102813550737, 0.030267324109445326, 0.023678845027461648, 0.03714104765094817, 0.011050886896555312, 0.026259622754878365, 0.024833840179780964, 0.050726417102850974, 0.04678240686189383, 0.009128189140028553, 0.022731205935997423, 0.03508661960950121, 0.03046250709303422, 0.09798057755688205, 0.06498559727333486, 0.07491110256523825, 0.05067122729087714, 0.06024802707543131, 0.05748013165430166, 0.03448192510404624, 0.008760890050325543, 0.026934331472148187, 0.04728678897663485, 0.041344898636452854, 0.038353115814970806, 0.05066774661827367, 0.02643477146193618, 0.03504014261125121, 0.015871809555392247, 0.05414149498392362, 0.02432215533190174, 0.048353025122196414, 0.04291699377063196, 0.06835666208644398, 0.03467906550213229, 0.047544815170113, 0.06847575452411547, 0.015363103502750164, 0.05186733185837511, 0.017043770203599706, 0.07130761936423369, 0.022697158055962063, 0.037016396527178586, 0.0684599467786029, 0.022861254328745417, 0.019675763542181812, 0.03937020694138482, 0.029573349238489754, 0.07006023239227943, 0.02031887161138002, 0.015596500597894192, 0.027073818127973936, 0.011426834789745044, 0.023636286568944342, 0.04180527510470711, 0.03119649671134539, 0.02229030342277838, 0.04264358285581693, 0.05809086353110615, 0.03649838858109433, 0.07127325050532818, 0.06345531844999641, 0.025398813086212613, 0.013081010529276682, 0.07384618744254112, 0.02566315495641902, 0.014081243771215668, 0.060066520018153824, 0.030397352093132213, 0.07398030094918795, 0.04641013074433431, 0.050007680474664085, 0.011316443105897633, 0.030655226146336645, 0.12868293008068576, 0.01019861563690938, 0.04366361659776885, 0.09515005600405857, 0.017462436117057223, 0.07447028168826364, 0.011604116243688622, 0.03306985556264408, 0.04152430912654381, 0.05450761498650536, 0.08166045328835025, 0.024668100049893837, 0.01623444888537051, 0.031622630485799164, 0.030010542868694756, 0.07806346387951635, 0.09855587559286505, 0.025733300899446476, 0.0438372531789355, 0.0948404245718848, 0.01280408740058192, 0.04254526684235316, 0.04008322532172315, 0.031011076680442784, 0.03149603864585515, 0.020229379733791575, 0.044418117322493345, 0.04721455945400521, 0.07717938045971096, 0.07771725940983742, 0.050512418820289895, 0.02376916068897117, 0.055932853938429616, 0.035563816854846664, 0.06746241124346852, 0.058149979304289445, 0.08982820407254621, 0.01591904911038, 0.09609106957213953, 0.04409884910273831, 0.05239276128122583, 0.08011051497305743, 0.015143035379878711, 0.04424535647558514, 0.03445756039582193, 0.016899630281841382, 0.04315736427088268, 0.04259661232936196, 0.0405245694128098, 0.02759051618340891, 0.06353549266350456, 0.007357633512583561, 0.04541080292256083, 0.04026812770462129, 0.10251162661006674, 0.04011832890682854, 0.03824079176411033, 0.027342546090949327, 0.036460821065702476, 0.05790189417893998, 0.035078255605185404, 0.1148591679520905, 0.01674629886110779, 0.058257197379134595, 0.03416398532863241, 0.049057074647862464, 0.05727098701754585, 0.029507778635888826, 0.01817374755773926, 0.0812758129904978, 0.03284288082795683, 0.07105072494596243, 0.08939168023061939, 0.01638497313251719, 0.0038908351280042552, 0.044906847542733885, 0.06548767501953989, 0.0358221992792096, 0.03524775842379313, 0.03079846064792946, 0.051058858443866484, 0.030361048084159847, 0.025473853493167553, 0.05314651243679691, 0.012815787358704256, 0.028564100757648703, 0.05259551231574733, 0.0875898495723959, 0.03016982074768748, 0.09240367915481329, 0.01454521687264787, 0.032296797435265034, 0.033839151001302525, 0.04865854876697995, 0.015799708053236827, 0.061973917472641915, 0.03671244252473116, 0.027981344137515407, 0.04297435807529837, 0.03227277411497198, 0.033423325658077374, 0.012525784804893192, 0.03689876612043008, 0.013350719982554438, 0.047686353864264674, 0.007678073861825396, 0.027077066879428457, 0.006673506477454794, 0.0517059258709196, 0.03719483480381314, 0.06340104519040324, 0.0028625354843825335, 0.029550799081334844, 0.05754447585786693, 0.010067322291433811, 0.03186909401847515, 0.022672759951092303, 0.007211433667180245, 0.022473897770396434, 0.05488497481564991, 0.0824704258411657, 0.05382185940106865, 0.03365430799021851, 0.051304694861755706, 0.04421856865519658, 0.014931876739865402, 0.04217682020680513, 0.02232443479442736, 0.03062964246055344, 0.039551023801323026, 0.06623253895668313, 0.010661894830263918, 0.028752452271874063, 0.0453053288947558, 0.03592155801015906, 0.0529696809098823, 0.07860713158152066, 0.01318642518526758, 0.16041379538364708, 0.13358028838410974, 0.11295731805148534, 0.12450252354028635, 0.06712792528560385, 0.20479437487665564, 0.09391387546202168, 0.1675694200093858, 0.09494983198237605, 0.06881761742988601, 0.14094651967752725, 0.13845284411218017, 0.10517543953028508, 0.0968433178786654, 0.1315093698212877, 0.10829611113877036, 0.20650695485528558, 0.13221421715570614, 0.12267790894838981, 0.1359784198575653, 0.09785162939806469, 0.17608161637326702, 0.21914305805694312, 0.10518783339648508, 0.11556041587027721, 0.17648020904744044, 0.14309965335996822, 0.15568851144053042, 0.16466030501760542, 0.1161270827287808, 0.12040001282002777, 0.12066715629771352, 0.15140850126044825, 0.13071240711724386, 0.06955117845791392, 0.13322227634489536, 0.1084606527001597, 0.08611538767581806, 0.2590600645635277, 0.15405603888211772, 0.1796396356076002, 0.41386812168639153, 0.076125360064907, 0.19504029827658087, 0.07876408097217791, 0.07847157830838114, 0.2898366318549961, 0.08884952650987543, 0.2204216449172236, 0.10367092065280303, 0.11480608212877996, 0.09956149311619811, 0.13059410877758637, 0.13642100704601035, 0.18520123092457652, 0.09747089279699139, 0.210735474829562, 0.19716282578883693, 0.07147425378207117, 0.19239948451286182, 0.17597980855498463, 0.12302561255637556, 0.18080133420880884, 0.24513958574971184, 0.16328181023709476, 0.17238432570593432, 0.173001391813159, 0.11322887730784714, 0.19734554254682735, 0.1700425529270433, 0.1708190471981652, 0.1251127544674091, 0.11879074721946381, 0.11478907952550799, 0.19593656033976004, 0.1851925626397133, 0.20207747613312677, 0.20010783104225993, 0.1365753886057064, 0.18160977051593363, 0.1278387667844072, 0.27350427699275315, 0.2386095470865257, 0.10781533303088509, 0.244191863166634, 0.12732843635603786, 0.16463495325297117, 0.25648757291492075, 0.22538619727129117, 0.11031586604076438, 0.13797365420032293, 0.10347175048082136, 0.2759360277559608, 0.30797237588558346, 0.12084376518032514, 0.20413503603776917, 0.15442740957951173, 0.1259699498768896, 0.19668313121655956, 0.2647795295342803, 0.08821784009342082, 0.18431521049933508, 0.07900389115093276, 0.15002556843683124, 0.17491398059064522, 0.15986827231245115, 0.17547727067722008, 0.1509003824321553, 0.10248829348711297, 0.16127289069117978, 0.21971770300297067, 0.12404367589624599, 0.2991182869300246, 0.1151317439507693, 0.1693439099472016, 0.1610527845332399, 0.1596121719921939, 0.20305104029830545, 0.1396124646998942, 0.08427461652900092, 0.13047768065007403, 0.10793793582706712, 0.10587388213025406, 0.15816909552086145, 0.12173186361906119, 0.16943464492214844, 0.1858046860434115, 0.1387615775456652, 0.06247933488339186, 0.17196945031173527, 0.15854042168939486, 0.09007251908769831, 0.12930897617479786, 0.11059885437134653, 0.1702037622453645, 0.22794369753682986, 0.14683489745948464, 0.11064326448831707, 0.11228732197196223, 0.12782937119482085, 0.10056107697892003, 0.09577851407811977, 0.1204348640749231, 0.1020124729257077, 0.08915163998608477, 0.15027314890176058, 0.1187936490168795, 0.13086325605399907, 0.20088485965970904, 0.09819650542340241, 0.10332269011996686, 0.11380715877749026, 0.0811912675271742, 0.23568561882711947, 0.14311976556200534, 0.18174875993281603, 0.1112234013271518, 0.21675461903214455, 0.17050474765710533, 0.14522911253152415, 0.06886586445034482, 0.09183169109746814, 0.12478604621719569, 0.0884863936516922, 0.10127428831765428, 0.16478663339512423, 0.10877133056055754, 0.09328864573035389, 0.22625672165304422, 0.17535778490127996, 0.11713535714079626, 0.16029839141992852, 0.1350444566924125, 0.14527592720696703, 0.17739736998919398, 0.2410081386915408], [0.033795130511862226, 0.018220916608697735, 0.04311411190428771, 0.032059651566669345, 0.0320862204534933, 0.02667991768248612, 0.08411694725509733, 0.01560906515805982, 0.02810417143336963, 0.008080841580522247, 0.03426350362133235, 0.0492590204521548, 0.0582081302854931, 0.01594221710547572, 0.02275079121318413, 0.035889259743271396, 0.06903913366841152, 0.04904873661871534, 0.06277347027207725, 0.043711852486012504, 0.005882732357349596, 0.0338927377742948, 0.03915031971700955, 0.006053620209058863, 0.017557238061272074, 0.037236224379739724, 0.08400498685659841, 0.0911453009757679, 0.03566270803275984, 0.04439957105205394, 0.024104707918013446, 0.03677571803564206, 0.02301970471307868, 0.036706779937958345, 0.02860635308024939, 0.03739871761354152, 0.044014882514602505, 0.019073323310294654, 0.022631876890955027, 0.03970178739109542, 0.026458462671143934, 0.036063415827811696, 0.033404482528567314, 0.03920216615370009, 0.031549050254398026, 0.09583166669472121, 0.05182332621188834, 0.0720968192035798, 0.04623217857442796, 0.01923398900544271, 0.056460439300280996, 0.06491919732070528, 0.02736780879786238, 0.034525641312939115, 0.04194666908006184, 0.04158560681389645, 0.026567584354779683, 0.03595184134610463, 0.07911133929155767, 0.027078517778136302, 0.05353451466362458, 0.018100905763276387, 0.01871029620815534, 0.039423504276783206, 0.027084293542429805, 0.055231387086678296, 0.0829539202095475, 0.01710239430394722, 0.04499733018747065, 0.03179638952133246, 0.019480138980725314, 0.04002901885542087, 0.061524951524916105, 0.052495348354568705, 0.0744890357600525, 0.0866688294627238, 0.04960423044394702, 0.07387363206362352, 0.09137765257037245, 0.05074887078080792, 0.020053409098181874, 0.0726483907783404, 0.030756822452531196, 0.03105070736637572, 0.11445669384556822, 0.09301992147811688, 0.0427532537287334, 0.017831088698585518, 0.03302022072602995, 0.09790049240109511, 0.08274027815787122, 0.009036168394231936, 0.15813899401109666, 0.04241497168550268, 0.030676820788357873, 0.08836095585138537, 0.04472617911233101, 0.06028175397659652, 0.0656830305524636, 0.07287216314580292, 0.027976913515885826, 0.05325769729097374, 0.026649268838809803, 0.02486510686139809, 0.05830948910443112, 0.006900099006088567, 0.06433056289097294, 0.07101307579432614, 0.062463438080158085, 0.024008180480450392, 0.034141787691623904, 0.01401574181727483, 0.012250716117705451, 0.030285211723821703, 0.03912794767529704, 0.06117674696724862, 0.005881384431631886, 0.025883765774779022, 0.03389473415154498, 0.027149682318849955, 0.039185323112178594, 0.010017423064709874, 0.03084658892476, 0.02438360887026647, 0.04172073706286028, 0.04400378369609825, 0.03852691195788793, 0.04671090835472569, 0.06575453648110852, 0.007239071710500866, 0.012428126519807847, 0.03817253644228913, 0.089486712240614, 0.027791055617854, 0.031897867083898745, 0.03470819479844067, 0.05467494331242051, 0.06120526399172377, 0.016882802083273418, 0.05078316913568415, 0.03928753169020638, 0.02481605832144851, 0.036420277538127266, 0.02002951379836304, 0.02342965224670479, 0.004981054007657804, 0.006659207610937301, 0.033168761583510786, 0.08501819655066356, 0.027927989285672083, 0.019473951324471273, 0.012404001154209254, 0.04959280508046504, 0.026010990295617376, 0.013986223821120802, 0.004994729933969211, 0.05037383016315289, 0.02096274409268517, 0.08418088327744044, 0.03463174987700768, 0.05275262868963182, 0.011305200496281032, 0.04487579608394299, 0.02943348965345649, 0.022341793628584128, 0.07894507594755851, 0.10847477577044629, 0.026931060456263367, 0.014975624490034534, 0.018123337176803034, 0.00835671735330834, 0.0021140083526915987, 0.04833204460737761, 0.024310796761710662, 0.022634168271906674, 0.0774129937053658, 0.04671276001317892, 0.023177776602096856, 0.013363870839384617, 0.06028532370692119, 0.03555900773790199, 0.025789412829908542, 0.1191335081239231, 0.03480921594018582, 0.014502820758934831, 0.04848704586038366, 0.03532167262164876, 0.07641720963874832, 0.059552007587626576, 0.02150601845642086, 0.023177479743026197, 0.07684673502808437, 0.08843634321237914, 0.05797489924589172, 0.02922945099271601, 0.058124237912124954, 0.040087822926579975, 0.03424812632147223, 0.05114619438245427, 0.04646648943889886, 0.021365455686463974, 0.044616693776333705, 0.04075132521393243, 0.04080706792592537, 0.022846296342322603, 0.025101848259510007, 0.02460375770169776, 0.047857548779575154, 0.03443701774813235, 0.03336215784656815, 0.0284954483868205, 0.011426174278312828, 0.015061801750562154, 0.008587641241319943, 0.11765158764319494, 0.08215061214286834, 0.016707838913134765, 0.0674718216760084, 0.06226385972695425, 0.03272258982178755, 0.016456000375910662, 0.05767020309576765, 0.05849620974913705, 0.05792930911411531, 0.04213225794956088, 0.006176366332510952, 0.03164837558870204, 0.05444354537758045, 0.014861205727356719, 0.03418963395233732, 0.055051549861673266, 0.00973906851868378, 0.024437067622784525, 0.018426719725539442, 0.020425377224455588, 0.005376728186092805, 0.05789337803435046, 0.0694591373030562, 0.04176783375442028, 0.059166294886381365, 0.017189685713674407, 0.09159075285424478, 0.006635217223447398, 0.04396118441945873, 0.03422171328566037, 0.04009055031929165, 0.05099409492686391, 0.01728504241327755, 0.024441164277959615, 0.04945778986439109, 0.04278131804312579, 0.00960103183388128, 0.07247946312418208, 0.006982592431086232, 0.03905100922565907, 0.08513544846209697, 0.05919779163377825, 0.04908087161311414, 0.0612165891652694, 0.05043890909291804, 0.11012085189577192, 0.036897990576107986, 0.06585357608855702, 0.02498033456504345, 0.02688685814064229, 0.05323925863194745, 0.05403259594459087, 0.02374103329202626, 0.05481504224007949, 0.03079917310969904, 0.0478955170547124, 0.04625758228939958, 0.0751115195453167, 0.04924640023091342, 0.061731146124657243, 0.12190862093120813, 0.008070214953477262, 0.012684148914559046, 0.01235018153238343, 0.05329856365278829, 0.04838522319914773, 0.02124191407347098, 0.021647347493853886, 0.008386282661376754, 0.03673717088531703, 0.03986469622759614, 0.04142050864174962, 0.00939698204092565, 0.012834882818424376, 0.050015083397738636, 0.06362749671097845, 0.046953271521488205, 0.05472371725772973, 0.023271415229828563, 0.01260583192561171, 0.04746079663163982, 0.04951983712089714, 0.05417234977358021, 0.04890388794592582, 0.03313217741379049, 0.060607764607993886, 0.04455102483916562, 0.033068898192141205, 0.11099023337010294, 0.035330411410541274, 0.05243186875304673, 0.03811156529991422, 0.024170723809220362, 0.02222143768449314, 0.06907057104399428, 0.07085509481839836, 0.05679649118974339, 0.08104162829113193, 0.07321689816308208, 0.05993056598526891, 0.11109215251053683, 0.005964582896922366, 0.01222270189828123, 0.038437312468886375, 0.04831400670809671, 0.008305125102197053, 0.03946824464946985, 0.06702772792777978, 0.015130437423067633, 0.045197951258160174, 0.0460633473994676, 0.04593353092786856, 0.05006450672226492, 0.012972098502359586, 0.05346458579879254, 0.033068612465285696, 0.05617687951598782, 0.003315914891572902, 0.0823837355710566, 0.062063405639491975, 0.04655338008888066, 0.0581255106953904, 0.06729063374223188, 0.026314166898373514, 0.03898172602930572, 0.033230270782951266, 0.03972139864345081, 0.08142816106555983, 0.018346692086197436, 0.10452078364323825, 0.013368679956329288, 0.022870692591823172, 0.012238841754879104, 0.03842679623630829, 0.06301278321188875, 0.06889265598147176, 0.0203353639881243, 0.17790220852475613, 0.1335570146329701, 0.11857337958645076, 0.10261341216391884, 0.10990523573127575, 0.10219549396424554, 0.14675634854938835, 0.11843038999359123, 0.09958326772903092, 0.14287487167166546, 0.07425161529681645, 0.2417786660953425, 0.15692335611674935, 0.18070541904307902, 0.12444276580936275, 0.21534094645176083, 0.08622740744613111, 0.1259356626542285, 0.12521497788839042, 0.10958324011880904, 0.13423535245237872, 0.16823270707391202, 0.13543819572078064, 0.15035586868179962, 0.13797234802041203, 0.19450310210231692, 0.1996159355621785, 0.18971675424836576, 0.1250356453238055, 0.22142370755318552, 0.10621954483212903, 0.21048828028142452, 0.14079283573664725, 0.1562784000998363, 0.22928152262466028, 0.08565600568545051, 0.08453855392872356, 0.19642591767478734, 0.2586446102941409, 0.12018746172543615, 0.06715298019116744, 0.09225875255651772, 0.19671485060825944, 0.1305233227321878, 0.1360485379700549, 0.21694659779313952, 0.18307018355699256, 0.15331488568335772, 0.1705166368628852, 0.08991749185952358, 0.14245350990677252, 0.12093009179807268, 0.05088478028483223, 0.1299039856530726, 0.13674103596713394, 0.15109157451661304, 0.13914553506765515, 0.1105531603388954, 0.13212968653533608, 0.1405046449508518, 0.1784267436596565, 0.12447225133655593, 0.1318992199958302, 0.08824858727166429, 0.2110491064377129, 0.16483941493788734, 0.22092887316830456, 0.18996408238308504, 0.11648826373857446, 0.10923071997240186, 0.11470118697616272, 0.14990694355219603, 0.10829548031324521, 0.15776938962517306, 0.17622998653678223, 0.29017935565207154, 0.18475070275599137, 0.17522897775052115, 0.19217155611841008, 0.1851274466025643, 0.18672019941732287, 0.1902444360894151, 0.1254218292888254, 0.17421241354895756, 0.17967497667996213, 0.16184559121029451, 0.13782868307316676, 0.16481309838127345, 0.17939701268915087, 0.17571376345586032, 0.1774324884172529, 0.17220560170244426, 0.24401840841164812, 0.12057701504090801, 0.18622566189151257, 0.1460792130092159, 0.23482775548473, 0.17098864278523251, 0.12506059632869437, 0.23525943310232833, 0.23290737415663898, 0.11619987257290632, 0.13166458258638158, 0.12240579308127053, 0.18439628271153197, 0.15494309831410646, 0.2518673177110031, 0.24808545189443976, 0.18725460511632264, 0.16329794452758506, 0.14169176953146234, 0.14330071600852534, 0.08078562445007265, 0.14219170989235863, 0.0666301891033072, 0.15929923800285906, 0.11814453697297722, 0.0863130809739232, 0.08120267433696426, 0.11116609268356115, 0.1483329077018425, 0.1341197406873107, 0.1148579953587614, 0.16100184351671487, 0.1174100037314929, 0.121313655981794, 0.16088572709122673, 0.2657962421653792, 0.22472126263892278, 0.14765525265829638, 0.17995288129895926, 0.12758216180372983, 0.11784988208091818, 0.22655908745946363, 0.23854291706811637, 0.13704559853067622, 0.18260065640788525, 0.13306033972185105, 0.09284279309213161, 0.2266269049141556, 0.13569463742896914, 0.13841457897797227, 0.13482199050486088, 0.0868065126996953, 0.15269075433025137, 0.2372922794893384, 0.1430962691665627, 0.0699162037926726, 0.14173818344715983, 0.1695193981868215, 0.08419355915975757, 0.07643796008778736, 0.09874319366645068, 0.12037742926622741, 0.15694706031354144, 0.2132296995841898, 0.10857759290956892, 0.19323753251228482, 0.1848757397965528, 0.21765102952485904, 0.12524359510280192, 0.17336056160274893, 0.22151463548652828, 0.14266215730458498, 0.14820012263953686, 0.14461825077887625, 0.21241629088763148, 0.159814570506569, 0.19629400834674016, 0.15574185701552778, 0.17722051619784907, 0.12108721188269556, 0.12194085982628167, 0.1277105533517897, 0.0933084313874133, 0.2311573750921525], [0.04292605539376382, 0.054208666770136915, 0.04401774720463436, 0.04500871102209203, 0.05327004662831314, 0.012465181025618222, 0.019609818155004177, 0.03379744972335175, 0.02841932073351927, 0.03993099970102776, 0.07035908041871153, 0.04951148795953486, 0.030298089841380715, 0.06681324724922888, 0.0432433420792222, 0.018667299882508814, 0.03011088123457739, 0.05456951381347608, 0.04012431061710231, 0.05962915012787562, 0.04549416094960179, 0.09424207542906515, 0.04338445774919819, 0.031962463617674075, 0.05492259428137913, 0.015933693539409433, 0.07485272522899322, 0.05403485207352787, 0.1583418229711242, 0.04732078676170204, 0.03832260241324548, 0.03957099499530159, 0.03388829230971169, 0.05275733019516338, 0.02603065349831013, 0.043003684040741064, 0.04203548189252615, 0.04711782792583108, 0.09992633291403763, 0.08462260957458057, 0.016076939173217397, 0.02052766372798942, 0.018897248774010222, 0.039311317523242906, 0.025966292596422136, 0.039033283028402366, 0.02259081942611374, 0.016347325836250093, 0.04641271341824904, 0.004910445613859338, 0.07091719773598015, 0.04868362593697384, 0.05842722712259274, 0.02283121590153314, 0.031151184884947725, 0.05030943029851187, 0.032135298679349944, 0.02633407315443037, 0.04331327094405424, 0.09693948537460528, 0.023059632258082274, 0.12178710909211077, 0.0403609035856789, 0.00957341095272568, 0.0455365190282464, 0.042708702603704296, 0.07298053897102363, 0.05091817321954295, 0.08455944538582116, 0.044377102531143464, 0.01547048392239958, 0.06752478133421391, 0.02858692365407478, 0.06304459166130982, 0.06408105284208432, 0.007860163968871348, 0.042214554705424234, 0.050120579689973965, 0.06629997791606002, 0.03164689871482551, 0.09826387016801164, 0.03301676602859516, 0.057291351549793035, 0.057947614186559804, 0.04824962168640923, 0.051002147229155526, 0.01473463522415841, 0.04160961529123597, 0.04379054982564412, 0.07686862096306868, 0.06327148104901426, 0.050216494855703786, 0.1046562627016101, 0.0343370578775648, 0.020955725231033284, 0.038654962118016556, 0.025003155606100336, 0.02971638892631745, 0.030756443957216106, 0.04208977741654962, 0.028394121109158732, 0.04608163391822018, 0.03462999469775241, 0.06340062216622755, 0.06991711663431488, 0.0173077391445986, 0.07732690457487479, 0.07279250843566842, 0.007594576218252769, 0.07022203542874195, 0.06188659637700766, 0.07537249577580951, 0.04292131678084843, 0.020511349466687534, 0.07784732079016976, 0.040063172491500154, 0.07421325368341058, 0.01974719711142825, 0.0685901491669938, 0.03002289406140335, 0.03984246519394219, 0.05071145169495139, 0.05998672801069915, 0.0804759633319918, 0.04189758714346681, 0.0600468493939843, 0.033429544855607674, 0.019057027602684684, 0.058071244857273996, 0.011405264267523307, 0.033439081453252584, 0.01875890502560651, 0.03500756974972319, 0.044777123839594424, 0.02218982219346799, 0.04886188238742761, 0.03801724575168919, 0.01420132233761251, 0.01580846725119045, 0.028661875003308523, 0.05742499008192681, 0.086123588407645, 0.05296434857882559, 0.0838773300347384, 0.012422976014931919, 0.01951166912476765, 0.055775611399440095, 0.02628749225550564, 0.02189578142861137, 0.02426172410196159, 0.020201846054987982, 0.03140712193271611, 0.06806251927628182, 0.012848016049247235, 0.019910352712031454, 0.03603856501285918, 0.05899809082620777, 0.013656289083883166, 0.043890658125746995, 0.029118234597262926, 0.01391182351653697, 0.023279890556295868, 0.010942882145172916, 0.017505920404801145, 0.054870439853402786, 0.0282300860635587, 0.059048760958830826, 0.028580891848832835, 0.021430616252473556, 0.033947790288948454, 0.07078974871546961, 0.030938047493691556, 0.0219753619239782, 0.07841302285669371, 0.02922020012192661, 0.05690080375643447, 0.07639049232238904, 0.017933480958163273, 0.01931809474626789, 0.02584879577625543, 0.039563851823913865, 0.015468639685423113, 0.028867227265436668, 0.05265915518975817, 0.01210956797876861, 0.05671655817423016, 0.018016167341556866, 0.007958466067066183, 0.03402462854865007, 0.02613900705910055, 0.0605464557884261, 0.056408199525321834, 0.007008914553807699, 0.029295518834260292, 0.011463183327578008, 0.03520973077684175, 0.03164507674227934, 0.03498624784697313, 0.032643710655975156, 0.04262283240677789, 0.040500434770365246, 0.037694062702939846, 0.03736200356797781, 0.056797893848852254, 0.05251431022770703, 0.09029026521602646, 0.012591525173775153, 0.04357571291620843, 0.01735933325107908, 0.05726756571675651, 0.034232585749123245, 0.014499109092867002, 0.04074837146617938, 0.07853842354961671, 0.10252022810163908, 0.03568083127902355, 0.02122161262377631, 0.030282467632787302, 0.04952065719407983, 0.02503421263099881, 0.0383416978729656, 0.02804528015985852, 0.05445915645395871, 0.02172904867620673, 0.05426458388683386, 0.03725162765476853, 0.042256063024979085, 0.025759661984920967, 0.013282857999001862, 0.03712509889737703, 0.06519063041196205, 0.06445761115173809, 0.027232183165324386, 0.07972589693963528, 0.0017435656877751171, 0.13250580697786063, 0.04097880831977818, 0.0828633559285663, 0.06868103257147595, 0.0661185896024108, 0.009862508086371236, 0.06929648079676554, 0.03266920713940635, 0.034762776049319655, 0.04277061998436693, 0.024417020358669106, 0.06298003965639509, 0.012722312931146007, 0.006915224903423223, 0.024016127026698086, 0.03520298836519942, 0.06685707849101163, 0.07290804598596878, 0.18374250998022035, 0.08562767048715614, 0.06488799743237905, 0.02133878289896529, 0.05003139580367133, 0.07030721913906746, 0.033814671260188334, 0.034770947095239535, 0.046497581715811975, 0.03052514250157401, 0.050606842269189656, 0.06014058264554478, 0.021737158494943287, 0.049902035752893426, 0.02062691670289496, 0.14844408142380416, 0.04859060143644456, 0.003707724104060617, 0.008322263147420017, 0.009248328005924122, 0.060248056761338376, 0.0067203090929979226, 0.046000049624126405, 0.03267259875428863, 0.06330110758426599, 0.0246964371035574, 0.002495760536476155, 0.06546348100528121, 0.07238227146444842, 0.09762492554727942, 0.02183870099543128, 0.03484475368168205, 0.08414888186962344, 0.019106027903035283, 0.03129916913167108, 0.02740385491051711, 0.04175561058218591, 0.04271265454008244, 0.06676451783278026, 0.02969494271383155, 0.023996341369638685, 0.07416762644425035, 0.009112904608628014, 0.0684435898438096, 0.01619317063159542, 0.03899210125382524, 0.0228599963884335, 0.039703739239485, 0.018401325287413783, 0.042953833981300704, 0.07534146658144891, 0.060505708170239814, 0.05119884604937397, 0.045506064998335205, 0.0413047632900998, 0.02809391124173999, 0.03611446816648822, 0.005633644404952065, 0.05209812123212032, 0.0549393111577956, 0.02655511812918121, 0.04998893753509037, 0.056605755526106805, 0.05140131506777834, 0.016215245814237278, 0.027643154862744268, 0.06317198131000623, 0.030928026644687634, 0.04465619829716161, 0.037037937363493256, 0.016911133570829406, 0.0374070445104735, 0.04692988644819707, 0.058468019269639626, 0.056267829713760875, 0.08558021756471135, 0.016816075585666113, 0.035348887176951393, 0.032241852532024495, 0.04387649423733819, 0.023784070435795, 0.01995799488213379, 0.0629576193750836, 0.023772368622303475, 0.03690414298034739, 0.10241994910757057, 0.015668535306758713, 0.023832803562982008, 0.0733608822338283, 0.01493698735430371, 0.029597123939311132, 0.04560720488370862, 0.015018289632280357, 0.002547612075431971, 0.07962493516970426, 0.062173410478862934, 0.09141686023212969, 0.013399240669969004, 0.0368708762107417, 0.16208352375542745, 0.14088995318161324, 0.0828549251309596, 0.12353571291896515, 0.12722220533760265, 0.16939741879468784, 0.08343546272953972, 0.113620686752256, 0.10370046555181034, 0.18156398000428453, 0.16171584895346314, 0.09758909465745091, 0.12355054845102131, 0.18328329868381843, 0.2206092153210193, 0.1332880900008604, 0.17034263291861862, 0.13899032230256125, 0.12329527933616191, 0.13115493493387476, 0.10056754850666039, 0.19782759714871645, 0.10302914102794603, 0.12786327250069007, 0.15033667674288154, 0.1201210543513298, 0.1522217466845177, 0.18887213082052767, 0.25824839249253273, 0.1869804409216158, 0.20049413375090808, 0.08059299259912223, 0.12793135712854564, 0.18147403170587495, 0.15595604083500803, 0.18062651390209794, 0.15564819797873497, 0.18714580626692623, 0.16048462595790625, 0.19677774020237848, 0.12635021150344983, 0.19141106255119666, 0.13296455814270303, 0.11722395473043434, 0.12447393601178192, 0.08705649030162022, 0.1582713337847963, 0.14376150065800175, 0.13395548856351525, 0.11299051431706175, 0.238883473793976, 0.1196426511160098, 0.18952826358145103, 0.19751559826545417, 0.12047465061186813, 0.20961279835319147, 0.09025797437061556, 0.17752715677488595, 0.1229401542514097, 0.22153440630063415, 0.14811740285949782, 0.1445229144883342, 0.17114568123361096, 0.14214416791219264, 0.12412307827617042, 0.14682590262964368, 0.17488705547293648, 0.1827524701366201, 0.1612686159205623, 0.17327047971775755, 0.16303083073580638, 0.16742113890359178, 0.08826648787362501, 0.13011132687097415, 0.15268282819306478, 0.23459476564312354, 0.16460731567349285, 0.20313591230660677, 0.18644561961991712, 0.1970629475545138, 0.25875397317577153, 0.16771933384006843, 0.1660523217287846, 0.18706323491642252, 0.17006213078275323, 0.20286584476707503, 0.10447454042150639, 0.1255838994984515, 0.24726615054532886, 0.1065900843241252, 0.09671920852269977, 0.10856328430236317, 0.19013844255823642, 0.16777144744992256, 0.15517175401328132, 0.11042620855732821, 0.0929498478944879, 0.1467979681910947, 0.2086336532374844, 0.19539903762051836, 0.14243120094761252, 0.17665024992311373, 0.15966082719387487, 0.16867284517502412, 0.17915701697347686, 0.15575447352603078, 0.18507776723708957, 0.1600758361746557, 0.09421100170584396, 0.24661052244482562, 0.0846272925264202, 0.11914826201973483, 0.2522378572029993, 0.13173242972698063, 0.12506999191828072, 0.13387530692853034, 0.20077318127732724, 0.07977215500432067, 0.18771436560200527, 0.11848746857140213, 0.19372380251297727, 0.13638032251037657, 0.20823752449359745, 0.1835164666408673, 0.10917538544163108, 0.13019703008467332, 0.08825006414554082, 0.13662589917657897, 0.10201823199167848, 0.11189925295184366, 0.1633908020448871, 0.08477456431137398, 0.12461366015486419, 0.11565513617824763, 0.07901951335952617, 0.1712046077591367, 0.11903738515684381, 0.10784174606669694, 0.14930368139175698, 0.20238131139194593, 0.25775845628231764, 0.11637234769295901, 0.19000013591721654, 0.26007665845099837, 0.194343377079349, 0.16802827507490292, 0.16514253773493692, 0.10109923052368686, 0.26707048004027456, 0.178734794317279, 0.16082196176284924, 0.11020754216588102, 0.1892335418961011, 0.1150304036855232, 0.06011123441567179, 0.17344782332656905, 0.1645252638263628, 0.15524351969361305, 0.10354418409406208, 0.12826806952944025, 0.20786363049410284, 0.10935177910141647, 0.22310679458314553, 0.08588038661400788, 0.1531027353485115, 0.09178319174679928, 0.11253966702497564, 0.1319153097574599, 0.08107319183181971, 0.09435724932700396, 0.13149948441423476, 0.1755187864182517, 0.15896546450676396, 0.26243846921715885, 0.13419587019598112, 0.11798288236605003], [0.05510506613063626, 0.08662850115797482, 0.052488004803308286, 0.06849637880804949, 0.08545612305169925, 0.07979740286828019, 0.02348648034967482, 0.01829473618272459, 0.0411033629643498, 0.031714886863483116, 0.02728920051595196, 0.056385007410426624, 0.013456000124278944, 0.028057735253241844, 0.04161894408753142, 0.01646218246605713, 0.04408392822369933, 0.014496131225314457, 0.053881884305155836, 0.0849226673017256, 0.04238376808643807, 0.02774965305434307, 0.07878388147219084, 0.05750452975917142, 0.08239101603976451, 0.0440750818233937, 0.02955468422442209, 0.022774770004616585, 0.036432830966077745, 0.0680795664084144, 0.029301418908289634, 0.04929577902657911, 0.0020831445181102026, 0.0214087618587655, 0.0448987655545352, 0.07789298513671383, 0.01952175491169328, 0.09203610825352371, 0.07948240570840426, 0.045311377398320474, 0.023182158984127454, 0.035358642708160914, 0.03850064364087302, 0.013970917025289964, 0.013504860344255576, 0.04837980181036983, 0.0335964130499633, 0.10738660173956305, 0.02017648130276939, 0.048777767369756475, 0.02291168326337356, 0.07587762374896556, 0.014458687091973843, 0.050290501822018996, 0.04785226839885581, 0.04859664994000923, 0.04270813486073166, 0.05647156409395393, 0.039453282952308655, 0.03603440898586996, 0.007847836895962246, 0.06530585626023822, 0.012759139226545813, 0.06011560937622562, 0.028863182560598943, 0.03690796504088212, 0.06597490981221199, 0.01473683290896588, 0.05012935558625031, 0.045494943915400654, 0.025731013229233213, 0.02338923488423461, 0.05074619904917199, 0.07313644193345681, 0.0298137141726329, 0.0738543807528913, 0.046799312985967845, 0.060759244370274246, 0.1783549482934177, 0.054783178129582666, 0.09927414837875403, 0.0983308044669684, 0.09267750196158886, 0.0401197093015071, 0.05794493503344711, 0.10115734810824506, 0.08437371550826356, 0.03773158197873272, 0.072856652259361, 0.0637644823291339, 0.014455066338996403, 0.05390093894675374, 0.15321097016567364, 0.0829923634591978, 0.041805764922173694, 0.05083391719381325, 0.02245639421744272, 0.0711337712709792, 0.03704634960740805, 0.12917448417283595, 0.06776961585273966, 0.04496240471780766, 0.04909069393761456, 0.045849590314901434, 0.008487583036185242, 0.1022811971779447, 0.03697862121043727, 0.036929947455064394, 0.03182791224389803, 0.0513162055722205, 0.01619873488380108, 0.05519019046914764, 0.03918863309081644, 0.008759282372921007, 0.04128354157728609, 0.021320232917787507, 0.0030855170007271226, 0.04705729465058539, 0.04621514257451054, 0.050313337706029415, 0.0288557555177249, 0.03256059382692911, 0.08434903167653829, 0.019574827747419477, 0.05568515472987201, 0.02463796699885279, 0.06853323386167176, 0.035581962365540676, 0.03913325032044668, 0.012979886414541397, 0.06515174929518253, 0.020930017235514242, 0.17617505276575685, 0.026785532718349714, 0.03198233091097791, 0.06040840147761628, 0.0031335636413132306, 0.04809288009710144, 0.03361462535394821, 0.03727922070538625, 0.042637460137484595, 0.004716583653134876, 0.012015871834591962, 0.030739541543880478, 0.03774107033677865, 0.015323745556088397, 0.07630982086993754, 0.04845849172852468, 0.03773189368075691, 0.02561020643042866, 0.01458548395021353, 0.09204525893437676, 0.021678755183529574, 0.051695717629627325, 0.020977414496883284, 0.03533409988449421, 0.016009828614187427, 0.045554998505394906, 0.05899491072341334, 0.06012547622958664, 0.04268859040166717, 0.03314203684567474, 0.055217946792254224, 0.05126947995449882, 0.037859609874431044, 0.015633810216968413, 0.04776109926751815, 0.01727200473396806, 0.008929044943215558, 0.039788351496099494, 0.04137951611483004, 0.06938351987628266, 0.032617030446999706, 0.1366655743913725, 0.07400720380246639, 0.030272994117694907, 0.07441899928380735, 0.0247497307282174, 0.06795839595724829, 0.03836664145637769, 0.12394578661769629, 0.030993443251645658, 0.019142753080814146, 0.03130534751107916, 0.05392086932261009, 0.035130699470755644, 0.002382749999014777, 0.02461689928168198, 0.11276124263531528, 0.038214567975956015, 0.025421023710805457, 0.023794434528099373, 0.055842516012489796, 0.043148488184669986, 0.03097783959674416, 0.02464828285155818, 0.052664535760413855, 0.02462405729602324, 0.03880094627675135, 0.06591149329324253, 0.022571798181161284, 0.12320212495978922, 0.06110756025009323, 0.022237074736040086, 0.015692805391154252, 0.030684578086948022, 0.04696656709711533, 0.03952996165025979, 0.05259409110294655, 0.018432016804581508, 0.04175731381110381, 0.10451815644046292, 0.018647712749952916, 0.046744160281377845, 0.05646948608045932, 0.01769887880072929, 0.0039027723414619686, 0.02302055261679925, 0.03547087027982343, 0.022446069087891374, 0.023331451266130898, 0.039129851284087636, 0.030190393081284128, 0.08933837176300585, 0.13062383921351284, 0.05767215494415723, 0.05214159995375667, 0.02313903834874509, 0.01065486761945067, 0.030897858341631945, 0.026593880502332468, 0.03676549866213463, 0.0710429398168344, 0.010036295880127, 0.0480404362315312, 0.029933313126093708, 0.05028294304793235, 0.055844556918600574, 0.024344653538719285, 0.01259072922039195, 0.04519233320024796, 0.0479048792476533, 0.02827166117640445, 0.028580081052496098, 0.05816134900669567, 0.0320241843292024, 0.027407569359638728, 0.02603609158541076, 0.060768172406824306, 0.03209255839465186, 0.03649270372989122, 0.09384916018461809, 0.009999544727179455, 0.1732800088939257, 0.20613139844499528, 0.18787501088809222, 0.04800589296792168, 0.030163582996465266, 0.1495621120557189, 0.03454174591752235, 0.05402398332080338, 0.016174529737327248, 0.04622310210834257, 0.04450183900189586, 0.09535649922327138, 0.06387593064573593, 0.06966523913433775, 0.059905288435402326, 0.06766718463040888, 0.06087062960432377, 0.1254836650332436, 0.025049688265426084, 0.06329497002298012, 0.02508809255232336, 0.05905749974772334, 0.11042324738809839, 0.10817229864187539, 0.07760305772535503, 0.03044822075025877, 0.05429282631666865, 0.06082446801883634, 0.018508146313251927, 0.02518228593544336, 0.036890105257043615, 0.04193669832602609, 0.06394880212610587, 0.055065928972908296, 0.07270566973602399, 0.049241479791817255, 0.015419211722473847, 0.054098750988487154, 0.07134158746339381, 0.023227465244417544, 0.07769247167743742, 0.005152420544618508, 0.017040955608536024, 0.013762508970103227, 0.04456288806977682, 0.02202614523412194, 0.061385843364405446, 0.046681055464432575, 0.08967584857600741, 0.054115389939397573, 0.04088152389158495, 0.03768705311813392, 0.008080801690084627, 0.07127874981961213, 0.054863266996107996, 0.05053157736256253, 0.05783309708931483, 0.06457405412220396, 0.0622844320605509, 0.06469869782449678, 0.032398245311924256, 0.0230369856217294, 0.05901590237044729, 0.043138387554790825, 0.04803355652256869, 0.06310967059107497, 0.08109732647426426, 0.009764925871422747, 0.03529866604367271, 0.027104791661258787, 0.02024966448516352, 0.03165057976730168, 0.015471879160031676, 0.03360113681992516, 0.02551125031459378, 0.054016929207136855, 0.027081788794021122, 0.010489119140402181, 0.019917069148505107, 0.03920452989405021, 0.021726358390878886, 0.07590506837004796, 0.004192251681160997, 0.05989216726447921, 0.04090148024260998, 0.025475441689195577, 0.05346578065655194, 0.05258621691609733, 0.07008610366028734, 0.0355730825685896, 0.049293693591607735, 0.007878394826548174, 0.009394821463502012, 0.02285898335685488, 0.028923157369717956, 0.02634810531162657, 0.017900412713061087, 0.20130248100031167, 0.02195627945184242, 0.18686085124500096, 0.16081831039628014, 0.10364126443164423, 0.09522574764559977, 0.21449798543471843, 0.11338883981807157, 0.08416751719778404, 0.1653585917665623, 0.218505063385237, 0.14539899013470858, 0.11422966344980523, 0.13570983661338687, 0.23990349640371278, 0.1118406381283421, 0.11230275864363648, 0.1626241931808181, 0.16635246109217405, 0.09487642615567893, 0.1608161284821108, 0.32269017363432795, 0.14040386129636317, 0.10582331218756735, 0.16093310579890385, 0.17222163209225982, 0.1338651543483138, 0.192811272572726, 0.181320600095205, 0.17521319969091564, 0.09252507967175916, 0.15597866149619222, 0.17861569445813075, 0.1211488398257643, 0.10188008120167069, 0.07973021623911336, 0.1537587642087601, 0.2575484581757337, 0.075070642051287, 0.318204514333047, 0.17404859187081456, 0.07063854354782961, 0.11518215062096715, 0.1227913833281491, 0.1578552561113611, 0.13040814141277224, 0.11942891258513555, 0.09900420700432733, 0.09565194079186767, 0.30705401266459376, 0.18039054062683135, 0.2078039024490863, 0.11028840657672845, 0.12918689288198948, 0.12112094249459915, 0.10935027254163288, 0.1259437669068575, 0.10024836563388817, 0.166533159208484, 0.06257398097659461, 0.12170553964097053, 0.22412545164115727, 0.13916738389525563, 0.188116698700469, 0.14552954875398427, 0.16080484783742577, 0.12787397427018732, 0.16861236013937742, 0.10203930156421848, 0.06704712766804732, 0.1478490125737153, 0.15748188161524013, 0.13838774291798472, 0.10163372528040782, 0.12444924475857988, 0.13709423888940364, 0.12288227415410802, 0.17844348651124164, 0.21072459494462237, 0.25053771561942995, 0.3085960471071303, 0.24424246279522777, 0.23641647101612762, 0.21277016174281016, 0.28726265591103584, 0.2524145180359483, 0.17024570843204856, 0.173494445043616, 0.2680176089052111, 0.17904799547977746, 0.29436500917654485, 0.20973598002456129, 0.13213029509643093, 0.17185352684464306, 0.31110512965824455, 0.17296070727752522, 0.24456157145323232, 0.11569917522137985, 0.13778035441646352, 0.14962880144594237, 0.19487362675135955, 0.2792682411381975, 0.22395125473849475, 0.19984056882094592, 0.15336931479396299, 0.14198105869581923, 0.1876945057301782, 0.21448299405165017, 0.0789688914665021, 0.17046762543031946, 0.13928835396654904, 0.11390371961169876, 0.19701792887644842, 0.1755298741045408, 0.16215897048823535, 0.0886562118830625, 0.11859798920340836, 0.13709177495911717, 0.09211676486302167, 0.1222444798622746, 0.1697206834796816, 0.08281061891466379, 0.10990306866005994, 0.10579975642031059, 0.18552356050349772, 0.16295529494527727, 0.12374771482427604, 0.3199443459743634, 0.20563925063470379, 0.13847850757883862, 0.12615639221621677, 0.2394092408940196, 0.09757766558323056, 0.15262670698575675, 0.33691613527480513, 0.11252633805270307, 0.23498721333453432, 0.15084964921697974, 0.12668382172705606, 0.1523774047382176, 0.09359949428471737, 0.14065052149817348, 0.13751726306509227, 0.09975831068004481, 0.08882117646862753, 0.16287345089949667, 0.0757673331827391, 0.08934079858590849, 0.14354583254316822, 0.15853794291615486, 0.16393706726375967, 0.07355744746746495, 0.11532492499100044, 0.19471808744128793, 0.11673990375129506, 0.17818149353843182, 0.21329880837583914, 0.12336065512499772, 0.12812155473511666, 0.15532785735558718, 0.13147704186849296, 0.12816008704248816, 0.10660497180651873, 0.12385407200781628, 0.1589410923770629, 0.12274810127564706, 0.11664630408631638, 0.21071061288239434, 0.12727045977953821, 0.11273787240497768, 0.12396946855005808, 0.1475256885169074, 0.12525820056907833, 0.1151247083907947, 0.07991096630576067, 0.2303513730294071, 0.3447324346052483, 0.08795074114459567], [0.01953929000592325, 0.022141619701869786, 0.02039125141891418, 0.008659286322654225, 0.004605202129823738, 0.023197929622256197, 0.06483669276349247, 0.0770378825836815, 0.024824138454278, 0.05240977872745134, 0.04231585786328651, 0.06115299082011916, 0.04987554108083714, 0.03403251386771444, 0.11084790428867564, 0.02861835546354996, 0.053931010770611465, 0.039098395354812965, 0.01202607729283045, 0.02852775221981574, 0.018730734955170192, 0.02674646420928184, 0.018155973120883573, 0.022977971893851645, 0.026901792007265612, 0.06171131964947563, 0.035163669381290674, 0.04206792487821076, 0.011263717224210268, 0.03844034785288386, 0.00896991130503011, 0.07222421627375297, 0.023286145005840808, 0.0331601712241536, 0.011485935719974805, 0.024787752809061203, 0.07909153879154474, 0.043598199990810826, 0.07791064825141802, 0.015404410514747724, 0.05794267519377172, 0.03190927760442719, 0.04928787886456121, 0.03505180175125133, 0.05623329016088974, 0.0171763864273089, 0.13100588199449703, 0.06356150493957102, 0.025572624072083272, 0.0611278839642182, 0.010515008034417406, 0.035754923592321575, 0.0673357340565417, 0.031350945064332336, 0.002510046647330455, 0.03325107318232767, 0.06893249446875416, 0.058961499235010706, 0.025563907547621056, 0.10095249308506027, 0.0718686162144877, 0.01536330573799205, 0.028982030089537147, 0.04003842557722237, 0.01334060079898336, 0.03669256409921218, 0.11380588970496319, 0.09300197634729557, 0.007234467148009571, 0.025920618973032106, 0.08255808832473122, 0.06229595761396922, 0.05142312678799499, 0.07136608575819992, 0.08554411208024248, 0.05345125311578158, 0.1061909350391943, 0.06375451528583653, 0.10358615996665321, 0.03318175658932887, 0.07635151472641155, 0.08723869497771375, 0.13884288724511862, 0.08860502595780417, 0.17721998185152188, 0.016728609771234915, 0.062292380462167785, 0.017036113094945904, 0.02677164156921208, 0.04442838493559975, 0.13206636649556458, 0.06272940154303797, 0.13403138058492914, 0.07906218685093336, 0.044309923323453404, 0.06048695409845095, 0.04808252713701222, 0.04717502524727024, 0.022661471884930506, 0.0070393361147580435, 0.05871459041372873, 0.06441030665882863, 0.03484153647150379, 0.09232306707417592, 0.15435962181072682, 0.08580870999139734, 0.035698865467566065, 0.04760478070238605, 0.023663473293709103, 0.03853477130178362, 0.04999939068511594, 0.054958321270532906, 0.018126059003407136, 0.020118938882660586, 0.02267204563395353, 0.02719274358241819, 0.019517459732014686, 0.013024586896790424, 0.06367269350448623, 0.037040828028693795, 0.045903963764430955, 0.05632652988424525, 0.06633890356170014, 0.014986618480179459, 0.0469380018330412, 0.02588895153166959, 0.01082056043742341, 0.036180248425807804, 0.03998618951300159, 0.024476865291944705, 0.04790354709257372, 0.10529964536544867, 0.04882860077486839, 0.029962318112666253, 0.04884821202722378, 0.03281417455582414, 0.03700283748912625, 0.047578998492099345, 0.0732754313503392, 0.017934135903487913, 0.01664254847128177, 0.044531888561323285, 0.05237995552306529, 0.04623471300874371, 0.038338343365467153, 0.04385929125419352, 0.030022808714420535, 0.01286693339352496, 0.023420876350428443, 0.019515819585649297, 0.08350753269041888, 0.0687014045251999, 0.010507534607313573, 0.0369731256068917, 0.04392578768602107, 0.021602293563773856, 0.0619855617696885, 0.07354219633270986, 0.07863510312745348, 0.057936979210353456, 0.04982724582077935, 0.0226081355867791, 0.04731755099783186, 0.060571625726879574, 0.06878513362607919, 0.03724393900483847, 0.044938748760614544, 0.028772861332981847, 0.056352393730776384, 0.07307716659852304, 0.062323409656528383, 0.05438976935693063, 0.011638100113486871, 0.08849201170960441, 0.012126032524975017, 0.00728969545889413, 0.023457267561752815, 0.025202427823387552, 0.0122735455079237, 0.03111591617198428, 0.012187266202090541, 0.0811370239534881, 0.03565814382454846, 0.042321234723203816, 0.03548013970430475, 0.014906308824720327, 0.06012616642692592, 0.022047045968065504, 0.07866874468163587, 0.05538939032703638, 0.02876394813938532, 0.01513335962954443, 0.0532244416535832, 0.056431989069096744, 0.06215045585122425, 0.06094642885727808, 0.060737955864169635, 0.012130339764553355, 0.01611628227692563, 0.00987731114946655, 0.015625574233126827, 0.03341367773828097, 0.047232912766048685, 0.025105668464675546, 0.012842498181271367, 0.02592433156678453, 0.04917229678540025, 0.03868025080009829, 0.02417046962364111, 0.0601052564161364, 0.031760076235514134, 0.04226731398375705, 0.033062701259041205, 0.026764082795125432, 0.019987903433502652, 0.024707862467039376, 0.043455243794596754, 0.028036687945132144, 0.05778036007541232, 0.044022088768542744, 0.03983346665336285, 0.04484118602704257, 0.0032848979890331975, 0.03568475352949463, 0.09094244975131005, 0.022702163842041045, 0.02393791208305629, 0.03785660046560224, 0.038720304510206915, 0.04204948250844609, 0.06672525079920888, 0.007765462678435142, 0.0879532570252195, 0.11824047440313734, 0.03178704959282186, 0.06134313647635281, 0.04015921011159662, 0.03586646096664481, 0.049100601609097794, 0.058631202700780705, 0.03771490592043847, 0.03948580015276093, 0.02859693151549436, 0.03847393374599051, 0.04346184148744214, 0.04914155331789516, 0.04741007083794102, 0.06070062954677269, 0.02270506192871835, 0.04980646939657163, 0.027040089371439535, 0.03926243225578219, 0.08897802195861004, 0.15455519256647676, 0.19288688257802278, 0.17651099333306774, 0.17100590514019132, 0.11340021694195457, 0.2942518168129027, 0.03305382517282851, 0.10349587028031237, 0.06517750924103893, 0.061222693329909816, 0.05857265095983166, 0.05250143396551721, 0.032549320603720844, 0.1376440961030312, 0.1400096176075749, 0.12515609589172527, 0.15219801280181855, 0.07091852618032135, 0.06867265372420661, 0.08922886787331663, 0.04743271376355551, 0.02323494423762895, 0.06696552853100002, 0.04743190482258797, 0.044417557000997476, 0.043117340246681124, 0.0355679691710975, 0.05229127258644439, 0.05714895567507483, 0.06616622806177475, 0.06405190128134564, 0.05669307291100267, 0.02192092168115778, 0.03441109824052546, 0.10008690398535691, 0.12154236363130622, 0.0451007855735952, 0.05104247924464289, 0.01253106147487415, 0.05723265137930866, 0.052962834597565234, 0.045273602081579156, 0.036869391915388405, 0.03808200555795338, 0.04375371332571376, 0.044698734491248615, 0.04215743530949112, 0.07271446418599226, 0.010637222130753798, 0.033367300929967314, 0.03173676537699066, 0.05334626148396637, 0.03056247438507853, 0.029212342633400112, 0.006719832263115677, 0.03792678537138272, 0.09898485921439715, 0.05058308241132181, 0.055271355449804105, 0.026935151545330882, 0.03542240061506163, 0.03663269875687547, 0.041438186599407345, 0.05084548727609217, 0.03270000626798719, 0.021988496082485653, 0.008364477434952278, 0.021786205179523677, 0.0795355137961451, 0.027067767769040074, 0.01985672141017858, 0.02878585633879993, 0.020181858162686694, 0.04704108985606581, 0.06551510479766876, 0.012248427519807592, 0.03328056242025923, 0.0933143388829194, 0.043494952406035736, 0.05511817245860584, 0.02330042392713949, 0.019637095792859327, 0.02145334452507086, 0.053032414652989246, 0.018578297822386958, 0.008966785935626831, 0.02849003256415017, 0.020213878124195617, 0.031054711253091227, 0.03047124217118835, 0.010114668530150084, 0.06352197815431282, 0.07339411560678855, 0.020980399785912596, 0.020654565414588433, 0.03799164907832164, 0.074110911518801, 0.0470520254020812, 0.029527551305363886, 0.0847264657204505, 0.097096197278006, 0.13156370987417176, 0.1257923836237751, 0.06371264331392013, 0.24440055509330705, 0.19903444801457226, 0.11045947161619551, 0.12524889403721318, 0.1438647333998233, 0.11455747007858008, 0.12451367801986635, 0.14239501382689923, 0.10209807223873213, 0.14864927041344345, 0.15597165562212467, 0.15197131637251005, 0.14980826759710908, 0.0989211532578338, 0.1666101792943664, 0.17468495381763205, 0.07332298817345873, 0.07179990818258375, 0.07943285992951132, 0.13893429015297443, 0.18229793437058106, 0.11361117984051816, 0.1948025735327974, 0.0825311557855457, 0.09720372705487534, 0.10094408455188386, 0.11823619963251986, 0.0836644449736923, 0.2102674765046686, 0.07300888901227154, 0.13174687192076817, 0.1336688266019337, 0.21071828668937087, 0.17132069449871778, 0.0946408610616345, 0.26036464143544436, 0.07759810017887503, 0.13881532388040796, 0.10181870558881201, 0.2290306321810931, 0.1921918909647502, 0.17250566685106605, 0.10263633710565045, 0.16587116348091513, 0.08925351459765807, 0.16206467320444062, 0.17811421043006703, 0.12472939066356048, 0.12383073888486251, 0.12959741929080337, 0.10954438126645982, 0.2678616688353941, 0.2188831876264885, 0.11845408676890656, 0.2895868249470368, 0.10274506916175596, 0.08188019579392858, 0.12900218716822565, 0.151450299017597, 0.1336896067368798, 0.21884698566282168, 0.1901706517674029, 0.15592708223266527, 0.12081378241418861, 0.08201781223760918, 0.13170810212614015, 0.14163986372295767, 0.10644093490554951, 0.1318325602915138, 0.2538886311231181, 0.16931092890445143, 0.28121756622567773, 0.26576480478979647, 0.2986686344956979, 0.30371506058145314, 0.24392209248617291, 0.16847037244588137, 0.31898730201646686, 0.19968059146776795, 0.3035234083654359, 0.17786597687518224, 0.2117016026750207, 0.0982092109916266, 0.11299574645818211, 0.28839802311267704, 0.2022729133022949, 0.33231775858439505, 0.3069897723617032, 0.29283832234796137, 0.17248930991627276, 0.22212583862710744, 0.1919202203862369, 0.1444682033616118, 0.11915290786419064, 0.22846139007015154, 0.176116764487233, 0.2263529782067053, 0.17955673771211877, 0.17708728584693745, 0.24387155222939327, 0.2436658288934268, 0.19272222969448194, 0.18496503500500694, 0.12755247589666396, 0.20443235523998737, 0.08856393324094824, 0.20060750422999263, 0.1962631498463452, 0.15011755021987483, 0.13712650747038424, 0.09354939931654371, 0.0968757645750884, 0.20476854813750833, 0.18697744264500216, 0.2289301305427216, 0.11763321206672117, 0.32754877698607743, 0.14118832623353228, 0.17093611357267946, 0.15203365677734837, 0.13376760645769536, 0.08850876198266633, 0.2039915937348269, 0.18320267176022753, 0.1464122295146808, 0.16225677070906386, 0.22881206969032064, 0.10441913909744471, 0.1693604004685767, 0.1572499901521951, 0.17856766266049817, 0.10488093306776136, 0.09866732390946709, 0.16327597695635632, 0.08466776183922775, 0.1196030352730304, 0.10517662696656771, 0.16195575561141595, 0.09764576505403966, 0.14173129631672055, 0.17382153921062127, 0.10119499725988135, 0.0410016887326492, 0.15062253718497232, 0.10789362961077131, 0.15710589475929737, 0.1917282267822884, 0.13937386422185227, 0.07029778644209728, 0.22995594190433621, 0.13059059099759907, 0.13699298026040196, 0.12528475461294875, 0.21249663579510525, 0.19233267637901008, 0.15414773864904419, 0.08858095810865052, 0.13998638838529587, 0.09195763355819508, 0.15291051910026, 0.15894584212219343, 0.12775914918165654, 0.07816717159585096, 0.15608354180585593, 0.14544377132551745, 0.11143955183797516, 0.15694306755904108, 0.14190540416166186, 0.12427415727870539, 0.08745508297579363, 0.11912639834918082], [0.04723079764517024, 0.018984573580382857, 0.029808880935888737, 0.02668719072971726, 0.051476565131451935, 0.07245984073961154, 0.06879925669636577, 0.012944587087986292, 0.0536111525434535, 0.03682153452245984, 0.04137853276915848, 0.06681459053652361, 0.03374241205165163, 0.017670816341706086, 0.05450506570923608, 0.01670299083343707, 0.021424888727779035, 0.02069440575724002, 0.04737636249046773, 0.03205310582416132, 0.018048035162792075, 0.04822522358153947, 0.0311793419677997, 0.01673528353421716, 0.014834951325610746, 0.030869456350046676, 0.05129063858476002, 0.05452117773529608, 0.07186083108535968, 0.06823094227002002, 0.009793222106964095, 0.07130252823117189, 0.0989532882522326, 0.03492849391477648, 0.05503495915036183, 0.02080645521346014, 0.03414267826883588, 0.005388952286011772, 0.04626525238563772, 0.038527798824361525, 0.020009598265460227, 0.0031129590706768795, 0.05682517519744579, 0.02839183529431466, 0.03629050188465044, 0.025906866976583842, 0.054569235508097336, 0.00980674125457881, 0.06360308005241677, 0.014087461113376776, 0.07514327604440041, 0.0467154651414603, 0.015243442394421436, 0.016776598895376083, 0.03196940269845072, 0.06329278068733402, 0.014381625260284636, 0.10611817488097586, 0.031841441596043296, 0.11903348888154142, 0.12852972111431882, 0.02852005243767053, 0.04180130461463705, 0.08924045279854909, 0.05457637867948506, 0.01315868092206074, 0.062369519291678444, 0.029997573838045355, 0.040285527356900275, 0.043176062681595795, 0.023853136553952936, 0.003732221703103278, 0.008709626199561171, 0.07401303708320484, 0.05661211573169567, 0.17240553628653288, 0.0452490926545579, 0.12645739247091115, 0.03405156479857396, 0.10551871993811801, 0.08095565048279241, 0.07192582095740363, 0.15831402211915702, 0.059849363897228613, 0.1040923863183707, 0.05705933763238136, 0.018180658807978034, 0.03008728464919841, 0.034697444789344445, 0.06406265500118025, 0.13404983037617058, 0.09015891992021352, 0.19786645600106567, 0.12071725868736394, 0.08661669358843938, 0.029489599728549365, 0.026897660100075882, 0.022435135397245176, 0.023948543348524254, 0.08310472461744212, 0.0565284051845083, 0.0733958744967822, 0.05534564443223644, 0.019202026560378727, 0.021285723050823435, 0.05609712461591698, 0.0562959088711068, 0.049868008281919174, 0.02901064173784107, 0.0731156395340804, 0.06332488599582575, 0.061178773030405864, 0.022725118469679728, 0.020637149063986726, 0.06545123556861654, 0.017908179288497195, 0.03249129578762222, 0.07079144081217237, 0.018478905694792047, 0.07307979380129836, 0.024608667008578777, 0.04451656321180053, 0.03384801224456169, 0.02871088458050508, 0.021649065565725323, 0.027314901089994237, 0.025282624301325995, 0.01768700258253375, 0.033756961856852286, 0.026818814330908936, 0.05959129688562825, 0.010878738321480341, 0.04543379836832173, 0.03866494029352907, 0.020081948387087323, 0.04176414899120573, 0.028332921756373253, 0.01121031227739877, 0.045061258788337, 0.02029476108873496, 0.058724375630845316, 0.022024145146133378, 0.020710957505798433, 0.047435103479074314, 0.03369525969901588, 0.005691539345207275, 0.0660266968770884, 0.04807462326425593, 0.04123333528696094, 0.026460987828613725, 0.044563619085238315, 0.008889208311302355, 0.032316397555405274, 0.06722226709825918, 0.01423527930455748, 0.07252960262121633, 0.04352974057837855, 0.023683535400778055, 0.026371212079538964, 0.018531382957007736, 0.05048411701864097, 0.05390829734096769, 0.022212068070075475, 0.06419411161914468, 0.030084766913205385, 0.027192099769308697, 0.0400713732233271, 0.022908954015292693, 0.08215724694309756, 0.018184978107456118, 0.046632032899651676, 0.03476855737972073, 0.012117580390622607, 0.09119946291320957, 0.036648205932579, 0.03220405866159126, 0.04340258470620029, 0.014844374745734967, 0.051814413018291816, 0.033631943369982764, 0.11398585309507325, 0.036525105897453614, 0.03573895257432014, 0.031916754742269404, 0.021708888234570622, 0.015597558158333413, 0.04232942061207723, 0.008204393398045795, 0.053307224516174756, 0.08174056813004427, 0.02696008770726621, 0.03479251390672289, 0.029460878613463137, 0.06910117721417919, 0.01603183143743081, 0.08846606622682884, 0.05160853012057487, 0.03275043149187695, 0.008784758447291097, 0.038439342242782004, 0.025424498817301355, 0.027389583410695195, 0.00293639935534884, 0.02517124463338405, 0.06917308390256949, 0.0007270556977800879, 0.04201641240797471, 0.08819870752631687, 0.07374854307272471, 0.048668734743841924, 0.006503472559415968, 0.019066493696300313, 0.054963668444543146, 0.06128865912614856, 0.061980882528587244, 0.07419841815135442, 0.023596869250468444, 0.023077928053680807, 0.018607764795888215, 0.04147716419538483, 0.019095196257694624, 0.02900647828937508, 0.08165309860487469, 0.02781626822979888, 0.11639926538919099, 0.02633000804053154, 0.045194611593615264, 0.03576272356440313, 0.024195878904720303, 0.022188462207850534, 0.06398244368028827, 0.055864030873635784, 0.056263951992150396, 0.0020044385973960743, 0.03047037942451425, 0.016646285184833687, 0.08668261114507914, 0.05318180155882146, 0.07933528977446258, 0.09755516366567463, 0.064205637172563, 0.02816648771840846, 0.05858196862391196, 0.039997143612708896, 0.010769082291517407, 0.07400109592708759, 0.07410769059788436, 0.03784183172683697, 0.02460386345774168, 0.032845337336766534, 0.15489208308281377, 0.13116042682668194, 0.11541442057932727, 0.034236979263368994, 0.1398311014054343, 0.2250166522571817, 0.0816974048211705, 0.0728799111675471, 0.1364166580606252, 0.05660251234075986, 0.14012058352818713, 0.007319091928366106, 0.030698148257215507, 0.006063745422579814, 0.06162726029288024, 0.06675521130091511, 0.09598629316315055, 0.06632955992245115, 0.0994798049214296, 0.10222604076261632, 0.06813829997554421, 0.017767134122550488, 0.038443876765086316, 0.012233272864250466, 0.08400687933317386, 0.18007689417572692, 0.052439357023104094, 0.010565945340204053, 0.1568174664862454, 0.04034849858726375, 0.015453538835572544, 0.03477557809674181, 0.05834693416545633, 0.025825701995927375, 0.04838246612052899, 0.04018282525066752, 0.04002619498351123, 0.042748960404424, 0.020060758215549868, 0.037475481658475474, 0.0024364024056922062, 0.025506398524157703, 0.04663817417167593, 0.03158236897434108, 0.02544275008403929, 0.06015385595674161, 0.0292998770964914, 0.05436776838905644, 0.04461827084014658, 0.011056638541049324, 0.025044482099474408, 0.07613010238856077, 0.0563851669721771, 0.032458158893859945, 0.020253952243365347, 0.04506699558987748, 0.05086522469355259, 0.04045465539093129, 0.05207372683798894, 0.04236400098307058, 0.02082348564726999, 0.055789519246900454, 0.046565425145672634, 0.034613648895174265, 0.015803596907062456, 0.05732726778660435, 0.06636223668465391, 0.04514061663940083, 0.03164100235153455, 0.0525606833252823, 0.04068585294589866, 0.05073407977761235, 0.03372385835973546, 0.05661026407324243, 0.02541848927648971, 0.05912272710702382, 0.02341771665669512, 0.02895488232752541, 0.008336142236657906, 0.04090190697752405, 0.05839386758452747, 0.005837211338075576, 0.022657187837467063, 0.04585826973197982, 0.05112098733661696, 0.041710473160492256, 0.013224940794316353, 0.04908295704808552, 0.03278274831245653, 0.04259867549990304, 0.08766565995756537, 0.024123276452883147, 0.030901826976332814, 0.011646778602880659, 0.03285939361376222, 0.04218976326228585, 0.06066854650271125, 0.06299265616689809, 0.0710384275589604, 0.002754389261099277, 0.03623527867603116, 0.10421940489322878, 0.12951205746503547, 0.08697552199009806, 0.1328791814739816, 0.07203034503618255, 0.1984074668143876, 0.19155621179379523, 0.1150961579696741, 0.11453470098786056, 0.07003468024777249, 0.09601859885151498, 0.12231955552124418, 0.18687342322664335, 0.13026686618104577, 0.13469162484398112, 0.13339099619770423, 0.12775974289979786, 0.16423400054918602, 0.12198816431919113, 0.16882382769836113, 0.15702571312431246, 0.1985235683969222, 0.2126827961183153, 0.10944590569124557, 0.1360160022159107, 0.13608289940748364, 0.14680610212963074, 0.08333988895174116, 0.11962617543758824, 0.2300949758500792, 0.12478393851779401, 0.12388506409479305, 0.16921712143812329, 0.13907296786783263, 0.09304889492341317, 0.13309278641827404, 0.0961122356238775, 0.23150293389335275, 0.10363159424741752, 0.13850093528162688, 0.2946672710822895, 0.09282598344725557, 0.10582200600765646, 0.14330494625028223, 0.1175862415402662, 0.08550065191229805, 0.1206976140383631, 0.11834736593300477, 0.11273296680883504, 0.16388986667152494, 0.16116864862851799, 0.16477848461363465, 0.15889953210717067, 0.12944247369887307, 0.20264024671632797, 0.16785810061264783, 0.15760638430947438, 0.0796295958571136, 0.14562219846993685, 0.12383556284476072, 0.1960728780250065, 0.1990107141318731, 0.0968507541983854, 0.14410094416234642, 0.17850806820206344, 0.13808806368615478, 0.08545290955225937, 0.26963650016114116, 0.10912908284808509, 0.1721270676353015, 0.16405656788265333, 0.23060306499246508, 0.10627294977894053, 0.13186463591409847, 0.18405545881250873, 0.20275486400350928, 0.29837201291229576, 0.21214175561908633, 0.19482252246234566, 0.21492844593012705, 0.24774106568656862, 0.24689059413503855, 0.17272411059821025, 0.3099534352077171, 0.22557026473805308, 0.2628207643283531, 0.1002596908074338, 0.16078549262601882, 0.15445724391611293, 0.19748450227780268, 0.1567974136560224, 0.3406944981543347, 0.14239777461625636, 0.32536012411583215, 0.2569336927263066, 0.2861147018847987, 0.23316236125538126, 0.13016243115998805, 0.1709064721944742, 0.09500081010628492, 0.2977714373264462, 0.1530910687870346, 0.29852908104658127, 0.2627586614107713, 0.10839078691788018, 0.09881797988782637, 0.2097377018071711, 0.2546219917712733, 0.1270586805185303, 0.2698478935053572, 0.21945851534837857, 0.10610356199322268, 0.30025956162717193, 0.23412443697452545, 0.06319512889604084, 0.16870554420165718, 0.11061445431550965, 0.09121812050580047, 0.17325835302472115, 0.11248582421103492, 0.12421503037330694, 0.08015534811420366, 0.08383645996218547, 0.1904209188069217, 0.1102428906597197, 0.1368699173326604, 0.11802815337432548, 0.11104196106316522, 0.09661985721322708, 0.10523112287046388, 0.13306759792612866, 0.1984034146880731, 0.11649408217635937, 0.11912599758943543, 0.21833870356203988, 0.10938651161268353, 0.16154757438926026, 0.23131843598093837, 0.07938515467685647, 0.2186446316773072, 0.09734299848787487, 0.1588551962049678, 0.16005682235118002, 0.11418264839448966, 0.14811719505814835, 0.19024356035515666, 0.09457906984607689, 0.14143164677079767, 0.17208896577358246, 0.1181118973181583, 0.1596240166691132, 0.09489058633334935, 0.15145418787142262, 0.17056324373697862, 0.20121567940805107, 0.12133005002397113, 0.1691322642727755, 0.1400474226102233, 0.08882579262717627, 0.1398099650396034, 0.12689655093709007, 0.09779397936654277, 0.13654647453222424, 0.13814866746542975, 0.12196731739095412, 0.1867546944413334, 0.13805595837766305, 0.10048783442471176, 0.14373426383826882, 0.1785368486889638, 0.16961713903583586, 0.21799936395836994, 0.11527661859872751, 0.16020908136852086, 0.10617064472171478, 0.12756151525536552, 0.19760685274377465], [0.033174257187056355, 0.08052876713918522, 0.038395596347982064, 0.0319373604725115, 0.014575108725694008, 0.018761435749183875, 0.01943214243510738, 0.03263374732341617, 0.0628632033476606, 0.01208834348290111, 0.043947462108917534, 0.024810809482005425, 0.039359835427603684, 0.056970179721247405, 0.02384890816756524, 0.038744977209717035, 0.041745966373127885, 0.06992332841036841, 0.08291194433695637, 0.024381397270190064, 0.01742695960274432, 0.014352546058944426, 0.017293573400820605, 0.061976177312317304, 0.06238459231099114, 0.07362186588579789, 0.05314696143614128, 0.02040966781351017, 0.02348179554246599, 0.005450722164823674, 0.02756072637566831, 0.04552589147351682, 0.028241086547495797, 0.03003700043336721, 0.023095503966032993, 0.02716729348321678, 0.017182395968120545, 0.030467702126770746, 0.026898788164544385, 0.04578697531542275, 0.04492078507610131, 0.01358367549983086, 0.026641752738214564, 0.04945305496221408, 0.017576699028722942, 0.09312778522144072, 0.047834942961344495, 0.06314275553449988, 0.05953985863015987, 0.011512717974255793, 0.046403826199821196, 0.026805826746567618, 0.022047585880500264, 0.02961593181680655, 0.037635937696904875, 0.05975626518193167, 0.03723095142049715, 0.012208659536554478, 0.009966118395823287, 0.06083053507609293, 0.06740236407495104, 0.07384882948826998, 0.016235224429692607, 0.07236519464640878, 0.08211404652683996, 0.04035957885207608, 0.05195996302063577, 0.11238907783990726, 0.046427040579146706, 0.03278223994129803, 0.09701801944174804, 0.0060853052764286986, 0.05893118621315807, 0.13316449272679165, 0.14909292629454285, 0.12040433211950585, 0.19178675254806876, 0.2162527639302425, 0.12637352978345007, 0.1472376610036008, 0.23739903001114726, 0.22643255128059536, 0.1266242124256678, 0.11489168886328116, 0.1176058936107438, 0.08859853958711028, 0.08157151431078091, 0.020443268549570348, 0.13817881350405514, 0.1474535814486444, 0.2411954419221729, 0.27846924494951963, 0.21871366625418887, 0.16337120934622362, 0.1923038365202956, 0.10112155432580039, 0.0268598328329972, 0.03480075916741043, 0.031341419598902576, 0.05710405945137609, 0.07584821243654005, 0.03360830967721995, 0.034416886992403306, 0.05198458376980852, 0.04566568612062838, 0.05366834986489266, 0.03376226821274031, 0.06208736216649413, 0.03976604995841626, 0.08831739920424297, 0.06303134432528168, 0.044458594056777656, 0.018338242734898813, 0.08458976211841218, 0.031098659383133054, 0.04162816156167537, 0.02130074040906038, 0.0164605293321074, 0.04234269021253567, 0.045023290513199754, 0.07197572296718135, 0.027067251976404805, 0.04197301161184441, 0.037590666688629426, 0.029706561035709456, 0.04247349002980627, 0.04607689901604317, 0.011802365224866662, 0.048404979170300066, 0.06815175511292182, 0.03544458711985499, 0.041330957392347045, 0.0317224159516627, 0.04104307088709902, 0.05955825276032556, 0.05982855407637544, 0.03547310785506852, 0.026675102999433875, 0.03185888948792126, 0.08640633182949387, 0.03904594406776596, 0.058095709755434655, 0.04485221434151754, 0.021634322802128736, 0.013818934457958676, 0.049161138595081866, 0.003473677629699523, 0.026521962681727018, 0.01066671044100076, 0.017280739812122192, 0.10059186126454733, 0.042312959776609205, 0.019924099142372143, 0.016719117702450603, 0.003981076342824963, 0.07174140468123369, 0.00749279344745446, 0.03855908405967057, 0.0511079663556302, 0.018832928690244444, 0.064200902270386, 0.10317259817384183, 0.02378436729486566, 0.001428006119112979, 0.052366144154802896, 0.01774572501744842, 0.02905492568970658, 0.0710023294959683, 0.0455842576775467, 0.04028292984003201, 0.06118981618783437, 0.04398622448206879, 0.017719803654472344, 0.0641672607162036, 0.024820917533361353, 0.01978739739570301, 0.03259396078647114, 0.03503835032461211, 0.05356537687475793, 0.013732723800785607, 0.03346721627167426, 0.0326574886275921, 0.031082469431567006, 0.0187031122186454, 0.03891263579134829, 0.06765982994693331, 0.033495900279376656, 0.029658108069270384, 0.024967397075670306, 0.04722136494820006, 0.05132313723152038, 0.047135242421063595, 0.027716312069969717, 0.06328153715003282, 0.05216615762037691, 0.04712414360255934, 0.01104367878724588, 0.011146254728373606, 0.026220648869639263, 0.05116036569233984, 0.03464707522653043, 0.056464432054781355, 0.04635019489796832, 0.01685996805463219, 0.021596152291749604, 0.008058568801061483, 0.047154890780802816, 0.0307538334527635, 0.0168091068189824, 0.0917626268346794, 0.03130901743134018, 0.01890210984129226, 0.00723284741070529, 0.04179406867478974, 0.009693396750662941, 0.04246579766913783, 0.023719466480542906, 0.0568098127405392, 0.016841162032505963, 0.02936520835646661, 0.044414699732442386, 0.09222214241162874, 0.04475406531128101, 0.024142240181390662, 0.03653586332802661, 0.04316002858104184, 0.086551399435848, 0.06764115008991212, 0.0322379339922918, 0.049460940281278454, 0.015050761376187438, 0.04024650152132381, 0.0487433465605136, 0.00932695205847267, 0.13062063313554972, 0.035421565698925406, 0.10105930297868326, 0.06545934724272229, 0.03775199846131727, 0.15320011996664107, 0.037867309656576253, 0.07729269156698138, 0.08597631662269123, 0.08264765070634894, 0.030714256572537124, 0.043044342601206154, 0.10364772111643106, 0.020890076702926308, 0.0587192882085219, 0.15002184285549447, 0.10042348279966973, 0.1480420897132717, 0.21940188948065042, 0.34853326971642673, 0.22132227080874145, 0.295905529637821, 0.1503480612882413, 0.23003771173534915, 0.22302921046502888, 0.15520379994995892, 0.04387457207485568, 0.05147807169123553, 0.06656136974925175, 0.04688119042839389, 0.19791371596511453, 0.15369716595159844, 0.18702551897149533, 0.2019291208125651, 0.3557950956746936, 0.13035457319347188, 0.14796174480579793, 0.12213366237119772, 0.0408646251889877, 0.01662553102505626, 0.04158156210905872, 0.1259256585035473, 0.09249425085727125, 0.05879290554730687, 0.050120178930228576, 0.011949789150094148, 0.027055399878008757, 0.03919174640031997, 0.0024793435341052827, 0.052835456081083976, 0.07434407947584987, 0.07811669071088545, 0.029678511564270593, 0.06706249012495391, 0.008582127084082458, 0.02460507872456219, 0.01941210444783792, 0.03190735173120629, 0.018756799181574024, 0.016313955165969674, 0.06024571899615694, 0.04588109819451347, 0.02067418594378978, 0.0545519805746153, 0.03595604190195445, 0.036239256587577984, 0.008891791912901681, 0.02828310138283996, 0.09266512293834239, 0.050796973082469776, 0.05497915706655476, 0.02691752182727214, 0.019463924909359775, 0.007294265233213082, 0.05160924258234445, 0.07029466942185536, 0.10088815630297177, 0.024739708023844287, 0.0267779665227863, 0.03148214935208671, 0.08319157816004008, 0.061360079707810655, 0.005016267523387796, 0.12288685320527293, 0.062050759443081915, 0.08177822470315732, 0.059074327946291305, 0.020674456827691756, 0.022746713111700956, 0.04945410881191492, 0.03459795247181319, 0.013749119698331924, 0.06245750089874491, 0.048186168060055934, 0.0773276986728888, 0.027124341686430853, 0.020258616641513072, 0.03252324153436348, 0.029211724795459304, 0.08790590058197267, 0.042583031026879326, 0.05615956521069165, 0.028976666217204183, 0.08501019619870931, 0.010465051291248528, 0.07564786967122927, 0.005645126821036683, 0.019754906170419417, 0.03365213349752594, 0.020677108150266577, 0.059980623846058734, 0.06090132112149149, 0.030475433450192213, 0.031558987611788325, 0.03526763684931211, 0.07071526677464135, 0.032723799522500485, 0.04031517244584393, 0.16005670360755175, 0.14321459719212726, 0.13175674248486757, 0.1705846918048337, 0.102670832129661, 0.20071802486199886, 0.09378219619975425, 0.09842441897490062, 0.15251548873493448, 0.13164861156838015, 0.15340918296715245, 0.10583304916508496, 0.13099795585731044, 0.10275787120917812, 0.10545298791839741, 0.22958762885536999, 0.2096462988993153, 0.13271895179059356, 0.11737967215594836, 0.17450243001803756, 0.0804107656585984, 0.10468177031725645, 0.17131708766100928, 0.12477111420594156, 0.12280181050300598, 0.20423179725185037, 0.14422494219616055, 0.12800287047866732, 0.08737476033275016, 0.10308271666872315, 0.06469951418694109, 0.090469545830274, 0.13456715183565393, 0.20510540896793827, 0.1509317010641098, 0.05837404482008424, 0.06776344860554673, 0.14595966786146164, 0.11760168563341722, 0.09750434881425463, 0.09393615473527461, 0.14506304956739768, 0.11783234513131902, 0.12077781793777831, 0.16653461381793022, 0.22275899449596182, 0.1717469989671372, 0.21380001038778573, 0.1051385622122325, 0.154633489146363, 0.22421685454901308, 0.11561431805603206, 0.09774878999451175, 0.1626713789300993, 0.16167736117495224, 0.13600889244116843, 0.16059719491750002, 0.10163906874367967, 0.20686266623670235, 0.19136834453092888, 0.23275651037693024, 0.14842031785519794, 0.12282905474421568, 0.230759643309284, 0.14468724082689732, 0.17314238502876833, 0.176196530519519, 0.3503159084357321, 0.13107030041282997, 0.2357226816820912, 0.2685126510914415, 0.1251264990423806, 0.13878443569410592, 0.2825310785556212, 0.2870622166665271, 0.1916340333991684, 0.47957354283425957, 0.4978928645141423, 0.351435363991186, 0.5599834921304137, 0.34701762604527175, 0.30888803768903017, 0.38757311704102904, 0.34444863733369857, 0.3557700110832229, 0.18401769833872095, 0.2279767973232083, 0.256285768118687, 0.28409181511960924, 0.32138075795955956, 0.36038400256074965, 0.4480980505468324, 0.36999080737587065, 0.21361438441090286, 0.3505203255917877, 0.340891582891345, 0.13079070369713008, 0.09599253462511115, 0.0793926503683906, 0.3011164750205353, 0.31118323327973485, 0.17248521326109767, 0.155406866397243, 0.25270487589295954, 0.18249740882311016, 0.20425735681783408, 0.17909298447193578, 0.24816932942485437, 0.1176446485624183, 0.26843496307265013, 0.1063883092137985, 0.2203102337080054, 0.09512254458968528, 0.19277297775261104, 0.1494864872074686, 0.16537824383703992, 0.19130959612084553, 0.13837698177667335, 0.21910065173869953, 0.22983868257142603, 0.13182190305087715, 0.13958077499410138, 0.1567933615297079, 0.10853736850549467, 0.1120899329544045, 0.0952161145687569, 0.16666328738210723, 0.09600256104022264, 0.1542313044774346, 0.1295869253226556, 0.10912445184658282, 0.16747990215662867, 0.1257836411241442, 0.13332994712982327, 0.2588937641121447, 0.13727328943787143, 0.12016189473797567, 0.16218101227423176, 0.14470968337263912, 0.10073781202663668, 0.09870230875094421, 0.17958165903110057, 0.14926599513273686, 0.19770606304518878, 0.10397056277724914, 0.15531396435108036, 0.08837812914862297, 0.112134439550573, 0.1180288138857577, 0.057462112308712676, 0.22252916620345786, 0.12649948708713055, 0.16787996428320184, 0.15735755703644827, 0.09171691053779796, 0.18768610461847857, 0.16382133675506338, 0.17667487438302487, 0.15796402527485043, 0.10984585649566725, 0.15866358851781115, 0.16331830905983225, 0.10202915640547872, 0.13957638147985563, 0.15351495385402814, 0.17124302132287994, 0.17200946691446006, 0.16522548015927896, 0.13045290776062757, 0.17096156923798844, 0.24410638259723783, 0.08431048452621326, 0.16661065426887944, 0.17615375312743708, 0.18502393184462562, 0.1487121154787019], [0.05193281525862403, 0.0494293915835442, 0.05118343164213002, 0.03454656987742055, 0.04160303244134411, 0.02077785840810975, 0.03571587549231481, 0.07458351115928963, 0.04387607863463927, 0.029060328524792567, 0.044809704122599214, 0.02543258451623842, 0.047715846812934615, 0.014355359726323513, 0.030859702674206346, 0.03690838435431942, 0.038427260078606196, 0.0696533870359417, 0.011879338926519267, 0.009594933235348435, 0.05997498352371622, 0.03600425181502942, 0.013384031281020725, 0.016048429570219014, 0.02078451361740008, 0.027304420109430794, 0.09197600913466886, 0.04088110086740926, 0.043957284433417954, 0.015944239457894582, 0.013666132745129289, 0.01136766799390898, 0.018111976751242764, 0.02438738454657141, 0.06041991218808107, 0.03718500505783595, 0.045689434846281074, 0.00854304837048403, 0.04292395511583891, 0.07809033704688773, 0.03449573276157025, 0.0327648514212342, 0.006976003551244503, 0.06170848835608922, 0.040609211355331354, 0.015566493711958174, 0.030079903990554158, 0.03425369242904708, 0.047392014384968206, 0.006402135541065945, 0.023356673154921737, 0.03205040811735671, 0.010545175409788499, 0.025421333557460457, 0.015738067122583743, 0.0057394714167458005, 0.06458044401369989, 0.039837032672949135, 0.0533074137638323, 0.059299194981576875, 0.07976137902005576, 0.05343596116290428, 0.07298914046259597, 0.11504098671139218, 0.033374967315467075, 0.09044808291946538, 0.025793062341108453, 0.02671738500794163, 0.030700168754265178, 0.043149909397470765, 0.1277100486913696, 0.05566044863371644, 0.09333375346614048, 0.21351527801016346, 0.1937684352742508, 0.24776883685262874, 0.23478126735426486, 0.15846668189624324, 0.10209365646005608, 0.2612632932141423, 0.2005083384574391, 0.1576983364066109, 0.1505898530012928, 0.07291383473784663, 0.0782894181611482, 0.07718805616605096, 0.07902018129243515, 0.06227560792467557, 0.084963522531325, 0.047060467331903055, 0.0684761701268144, 0.14659494627267122, 0.1998036098666489, 0.20564116537570953, 0.07320404416532256, 0.10183953767409548, 0.08730195564567111, 0.06203505188750569, 0.04163360521488357, 0.142287194612436, 0.12648618780076504, 0.05877263749425765, 0.025195650159730576, 0.03106426269368967, 0.07741281558992341, 0.08421802776865661, 0.06082975953177083, 0.004963056462656823, 0.02256273841339862, 0.05025093792937696, 0.044721767044393346, 0.027966675588686485, 0.01815989351598546, 0.03478124810499139, 0.09238139246008359, 0.08163819627952762, 0.09269105357816443, 0.04190467836451717, 0.01800996484234929, 0.024059034294623416, 0.07943913849885575, 0.039603040931979194, 0.03555095172487199, 0.0331776562234154, 0.01707739691482857, 0.02314463785296539, 0.04396373369672801, 0.06715410083415918, 0.06605731789022684, 0.0638882874045521, 0.01960500347195193, 0.06942956271814182, 0.06713476046570577, 0.029613835249620024, 0.03247258995543234, 0.023665636654186528, 0.026766941919049714, 0.0888410363404546, 0.016259737567452248, 0.01964540784683777, 0.031190670852083713, 0.06328224219032563, 0.011239216146350373, 0.05177672304853331, 0.04084234962647315, 0.003423428897804115, 0.04825116164283827, 0.0426205280382419, 0.07215612422442064, 0.059174443667870946, 0.05337022172170691, 0.004543071381704067, 0.0890141274430789, 0.019110783214273397, 0.024951928862719797, 0.010462628179084277, 0.06920679225004278, 0.0446461087994976, 0.045806994749000296, 0.059819139933097176, 0.02424142450763611, 0.021600642285193317, 0.034920590042020194, 0.059433597925817594, 0.024995990170282312, 0.048422304607811384, 0.05647527483233716, 0.015095677081262693, 0.0205390000337502, 0.047712325322208926, 0.03625466728408355, 0.031439078811672516, 0.04221021314151585, 0.04639674982172437, 0.06733609770890325, 0.019002221852133516, 0.03651919098047074, 0.01864409106929088, 0.03353087398863863, 0.07647733844351023, 0.02648574587510666, 0.02587046277767513, 0.013812292236252688, 0.023960740545589942, 0.009854022555373376, 0.015348392280429834, 0.047473053200519644, 0.014674412723252317, 0.05003842023143079, 0.10668451519450173, 0.06522111041704193, 0.025281028683821205, 0.03582149794965517, 0.0720508505764883, 0.022016749644535594, 0.03197762569470797, 0.020621927615138702, 0.018377190644969232, 0.03875581256579608, 0.044726587293553166, 0.07789204260916449, 0.016846935941430274, 0.049642669982858934, 0.0827010185457766, 0.056823394043021835, 0.05491430820256937, 0.04188708946458064, 0.04532169325102586, 0.07215960489702411, 0.07479509004042484, 0.0332506464474136, 0.009646454982430441, 0.03416720996028744, 0.02967741875181673, 0.07360244388110004, 0.03822549610049464, 0.05469218340294901, 0.03851992092677392, 0.03134226564725395, 0.04090982569323387, 0.03701792535139248, 0.04218911759380717, 0.024094265900203027, 0.0066724229418468894, 0.0168618475436233, 0.0143566464248579, 0.04137552336032968, 0.020596084177668672, 0.03307701728772372, 0.03731940429133829, 0.020504078274825588, 0.04898632942058612, 0.06861248781206086, 0.04697129086707719, 0.05848088811035268, 0.06213354972715024, 0.03342522926686797, 0.0757075086585246, 0.06216571811819449, 0.11100311705376953, 0.047959731382434256, 0.09199798412737437, 0.05104880234284792, 0.03466729503998067, 0.033172305338666774, 0.0582874065003125, 0.15904292988125235, 0.0335190404439345, 0.05408255361544434, 0.1662748769740574, 0.09392313004354946, 0.09033869777340442, 0.11705583601724356, 0.3229231189470738, 0.18042248266283423, 0.2644525689538568, 0.20996301784180105, 0.1090666682284791, 0.09442767172004096, 0.05279196993797086, 0.07527966052293777, 0.10399758437415585, 0.09042819336173125, 0.05669125464919489, 0.04366246997960843, 0.05492006355780177, 0.06944820546777919, 0.10455812109285034, 0.27480698365252465, 0.13008722191443667, 0.08497118891682476, 0.11080846656113863, 0.05661497671098914, 0.04647252681024838, 0.08071141710388474, 0.18967704934766516, 0.2612701209727675, 0.08491681917803362, 0.05693475701264106, 0.06233541760593653, 0.1192161017388571, 0.10912453348282725, 0.06553782193805091, 0.09946162972482853, 0.03770910232560709, 0.12068559124600142, 0.037201465893303975, 0.06629338022321463, 0.055318507802439854, 0.05219140548433643, 0.10977876634569839, 0.03390220015717205, 0.06650934519711882, 0.04566628354950808, 0.05043661214585882, 0.04459054420294706, 0.04457459173863754, 0.06521461662487127, 0.018304530676687136, 0.056698045300436206, 0.026846759901673067, 0.060039899180992506, 0.03361928233061917, 0.054592357118963264, 0.0737837357155513, 0.06084450229536742, 0.06104799918830395, 0.02642204548465088, 0.05025938728067558, 0.08825772310956381, 0.0273333007862675, 0.035739512895816006, 0.04038326449517626, 0.08406325287069194, 0.009645310219639214, 0.02134998190740589, 0.03561009347322397, 0.07428254801197909, 0.023942596890265122, 0.04591388627886772, 0.05016824783524498, 0.04680740610638168, 0.04976842690666672, 0.046388608461711556, 0.09486221402767114, 0.09387105354107916, 0.07966679229866713, 0.02316640875505982, 0.03014528534549754, 0.011410173574404325, 0.020112018355575856, 0.029664718749700114, 0.020957502674718853, 0.07110160659067333, 0.10007963093812577, 0.05849454733834136, 0.03249067238357384, 0.06910292868269607, 0.014817142564425012, 0.07131343038054183, 0.04925320943584666, 0.013044507995800814, 0.05259085533907637, 0.014212076985131716, 0.031782878722879104, 0.06715060531860217, 0.016714928278815933, 0.04148081185121555, 0.021853942853340413, 0.013971029275126057, 0.08179774318705313, 0.021895059689995833, 0.18223690014565364, 0.1652390614617616, 0.11190378005267121, 0.12814570422051474, 0.09567377477651462, 0.1816643332131207, 0.10361654349253513, 0.21369930094806477, 0.09999512258218601, 0.08623851739685051, 0.1354983838973567, 0.1187801716150716, 0.14329703495604917, 0.22494925040518865, 0.16035546257626265, 0.1510939939180389, 0.28455052175559103, 0.12926002411404625, 0.20741345855640247, 0.12527519575087354, 0.10684872278943658, 0.16055892978329211, 0.1672638184390962, 0.1444025826640427, 0.15189394005574286, 0.14051096804905683, 0.14857466972898692, 0.1387248857645318, 0.1796718596597202, 0.130223257583566, 0.14348332886584103, 0.15577170619508252, 0.15091436449438334, 0.20420114655280486, 0.11930698514333926, 0.11091909851529635, 0.17709748295601457, 0.09771905955858529, 0.21986714185914025, 0.2629160857759416, 0.11797163882874884, 0.1837019738741219, 0.17901617218740284, 0.15008461370598525, 0.20608324790373445, 0.14266836165916175, 0.14903316856361926, 0.11661889657261781, 0.10002368784626015, 0.19266888411948457, 0.15470486890990287, 0.1472888543503359, 0.10951594216749072, 0.13900452700909227, 0.19381912396056578, 0.11648169573163614, 0.21752967353677377, 0.13731813000049442, 0.17008584982249886, 0.17796496453229338, 0.14531385095324367, 0.15791643876582384, 0.1983503214432858, 0.2406221179990098, 0.18317662237677723, 0.17485474236309528, 0.13400178373558447, 0.05702492424461525, 0.152389754075557, 0.2268914063461125, 0.2637014858191833, 0.2632346749305725, 0.1925202616257593, 0.2978611778235063, 0.22370861697709188, 0.3454359609168023, 0.37390317243989557, 0.37964935472700745, 0.24612830457044765, 0.49484581395518035, 0.3247176617151126, 0.2326765810721554, 0.2534427191130817, 0.3133178281132132, 0.25414900621399283, 0.276392656378448, 0.22871017281431705, 0.1666454758378677, 0.14683715358842164, 0.13113409542711452, 0.0761958269868046, 0.20830788009334356, 0.30727048229891807, 0.25787369697354734, 0.22562950296560302, 0.17147875711089, 0.20958674896974117, 0.17651451111305505, 0.21023464389145374, 0.45709136640653014, 0.4210275609511882, 0.34116015129256994, 0.1856830925680697, 0.15401259355712682, 0.19081992708379403, 0.23858131578890607, 0.22690144018270075, 0.19935925636673346, 0.08816328481771052, 0.338620581314899, 0.16760315804276615, 0.19447234750259668, 0.2043892364599742, 0.17392689449479803, 0.2046764179249294, 0.23913371114758775, 0.17390215129125863, 0.13278881757287309, 0.1934076624456793, 0.17545842012623325, 0.1300554579938762, 0.1860576990293339, 0.1980107295094058, 0.14063590118894354, 0.11959837458562106, 0.15155322005739436, 0.12435904412996024, 0.0912602299649734, 0.1971564136329107, 0.21161315351491794, 0.09064521218533628, 0.22125440882518888, 0.14321346912765875, 0.22234377771383151, 0.10352377503295429, 0.08594834507675841, 0.12140963794081472, 0.16793955874163657, 0.08224502074881457, 0.12423755455529317, 0.16067602584371343, 0.1681170507799834, 0.12797821633284912, 0.1794093323405832, 0.13890715723391622, 0.15346821339335293, 0.18767923233099282, 0.17151979787740856, 0.16101968474686146, 0.20451905293157324, 0.23855666164308786, 0.1427756019984372, 0.17477007815614343, 0.07734262326266617, 0.10537110676523298, 0.10436110314913094, 0.16030538245104253, 0.17695323913358152, 0.19565479655284435, 0.115342862700345, 0.10940962209133431, 0.1367973501328379, 0.1196427624381613, 0.17177637317217886, 0.16082461865153164, 0.13211885117925704, 0.13870193855836987, 0.06705655294354074, 0.18613065214594826, 0.17974700953345746, 0.14180610480252653, 0.16646676667733118, 0.16183159430511296, 0.12589420628501102, 0.1646328455535695, 0.14446306769968942], [0.02822639944497496, 0.02858411091438029, 0.0296906605217373, 0.09071467720787041, 0.02685182505956618, 0.024116777094604913, 0.05569112901866902, 0.0433878196781734, 0.05248128094535787, 0.06260285794269294, 0.019545308823580854, 0.0148126525709813, 0.04365983164461795, 0.07619060226716101, 0.03662009708932601, 0.02798815148707945, 0.03817195385636296, 0.049487301366752945, 0.02634448177559534, 0.01990798526094295, 0.023128690954763442, 0.0038914977267268114, 0.028857915167463943, 0.05000810349883977, 0.07527467329055071, 0.06107087589043658, 0.03598049937863834, 0.03667639641207643, 0.02355987689952599, 0.08333720979862846, 0.06364861081237905, 0.017589111448614858, 0.05043897217547055, 0.005480379313667072, 0.009617020477890037, 0.02503021059965249, 0.045287817920325324, 0.07292190930456854, 0.008205619797081454, 0.04238538596837316, 0.04227295801683795, 0.03517247496347409, 0.05727692048822064, 0.03479102590063121, 0.08405423577642068, 0.017886167188407853, 0.038572001139982603, 0.037993864389136434, 0.014166217824822525, 0.015044597839732887, 0.08191373344743624, 0.023361816238320898, 0.028644250851357356, 0.013133226184436353, 0.06607285846257582, 0.062275029049487785, 0.01659747227677144, 0.039610043095308356, 0.026381266325188335, 0.09642356657423079, 0.10650611773598939, 0.036898873731843196, 0.03281096476712264, 0.23127006279537454, 0.04362459076219238, 0.12686017085798085, 0.03214145479432773, 0.029062105968478136, 0.0388040113466559, 0.10773558184155263, 0.10955734658637084, 0.08153994334861636, 0.10593102750135586, 0.6126668339129537, 0.7352724799420685, 1.0866947821341455, 0.739393358817324, 0.5097729864064604, 0.23897981940535828, 0.35453009011689574, 0.44840405287686735, 0.21335357887437567, 0.29849710932467133, 0.16406158480094746, 0.15545397793175653, 0.0994008181442041, 0.1325811943388544, 0.0814787606941536, 0.09460153465624899, 0.3100007842294872, 0.05648482998367399, 0.3324659209465608, 0.9644171060062945, 0.6959894159808755, 0.9011962765362114, 0.5664375051856041, 0.22210446477402002, 0.025410932357772253, 0.06746118669980206, 0.010510383526707301, 0.14357925887452438, 0.08372239186428487, 0.031135555254877545, 0.029206687468104064, 0.07569893685285933, 0.1347740032360889, 0.16628436162136495, 0.09414250889676623, 0.08116219018120319, 0.053585626374115236, 0.02636720262671588, 0.06830757643911056, 0.04591801633068826, 0.1021326266345568, 0.0472975352749927, 0.08129245936288498, 0.00880015059010475, 0.05729114003770519, 0.07575403389637358, 0.007193488536358927, 0.0055599407914996846, 0.0430914726894116, 0.039394345294567756, 0.012003409319731873, 0.04218513597152196, 0.03626227429776918, 0.03124498121906072, 0.046596090687671676, 0.006696377613479854, 0.050722045853035524, 0.021146774452063255, 0.01928834019054193, 0.055603796790819615, 0.039814931515138596, 0.06675321492366493, 0.018008089064096566, 0.08026443640119396, 0.0593316119920928, 0.07187675757450052, 0.027615815997705795, 0.01180386621854268, 0.023985108964552637, 0.01599388171598548, 0.021348653463064693, 0.05450903619930614, 0.01573505585838575, 0.018716520971793216, 0.011893804312421707, 0.04225711316394154, 0.012390270494506694, 0.0901818522834219, 0.020063027332071215, 0.022991350961092394, 0.03464406581770163, 0.04131565059651621, 0.04774106499098707, 0.07015785449766554, 0.06916485348483548, 0.044840551490779035, 0.004527650944510242, 0.006685933740300243, 0.008484848221996799, 0.05121408605191391, 0.07158331238315441, 0.11284256717772223, 0.001791525589851517, 0.07186615228420123, 0.06166134342493024, 0.06444453450967558, 0.041494715987937525, 0.058229103378835134, 0.046381654537981376, 0.03834370909316931, 0.07826802204363048, 0.023592175166413654, 0.027244354387221392, 0.029138992467778735, 0.023508011909143534, 0.07568263928988017, 0.08214943212806247, 0.03587682505894918, 0.0265118082461413, 0.02140978231182089, 0.08093315598671325, 0.032341485857614316, 0.029780061486235354, 0.07511469593737274, 0.017638176686887164, 0.04454769630683586, 0.050070718498318456, 0.0198222133985837, 0.005834226512888563, 0.06476842259871773, 0.05655333021422848, 0.024577418880653568, 0.03472418065939564, 0.020213243587932084, 0.039811933238524944, 0.015204037135845283, 0.04224145755870268, 0.029572018938779365, 0.02803012921503978, 0.04008400457678363, 0.06389785368810408, 0.009429804449609946, 0.07394314161501825, 0.010678718390408903, 0.010962075939460192, 0.01754468092258321, 0.01853392481280025, 0.025369412906002253, 0.0041813156713033095, 0.008101454732241109, 0.0480938857072033, 0.023408469496644102, 0.01615000917809084, 0.01661044872889761, 0.07106550852768123, 0.011373618162906496, 0.029095623212924693, 0.13150564423995093, 0.022934858679946046, 0.07739380176644772, 0.0458186575997388, 0.034783686060109176, 0.014126165042398497, 0.054838616561028175, 0.028228325318195857, 0.010659697145456448, 0.021256341424304992, 0.02426204508083174, 0.03459647188719828, 0.043007483836845495, 0.01997519786527846, 0.02638021433085669, 0.12664813926676288, 0.09050865701283328, 0.03337042166094761, 0.04296887360396795, 0.20550040964735672, 0.08749098065891303, 0.19338979152962565, 0.05360688519431278, 0.06844286996056326, 0.06299459317233413, 0.1031119424442295, 0.09955346307833679, 0.11580414458876476, 0.12264453456737101, 0.5008476215880364, 0.44934016827028245, 0.8797988528385758, 0.731539714615792, 0.6550865108147264, 0.45204117021057755, 0.4955065925605595, 0.4501808137865737, 0.22015230468241498, 0.4845044610556215, 0.1462731510400772, 0.08774952264502645, 0.17145255929790437, 0.0886922208883334, 0.1491472515044734, 0.09326019178843126, 0.19661089056171477, 0.11499809799715877, 0.3458014834905043, 1.0134738986380398, 0.6729102856479585, 1.0457434295676649, 0.6544938019942492, 0.17241040477529168, 0.039263716171262786, 0.07735842358670197, 0.15225542534608394, 0.13677467009983957, 0.16464503161842003, 0.07318180942093022, 0.08635960621177219, 0.08379992403206415, 0.13658514042617753, 0.12275717032025568, 0.09747116739163175, 0.062234830620582215, 0.07596562019898556, 0.014227248339011567, 0.04844377122935839, 0.054224136838456616, 0.020262154830561485, 0.08038896878133528, 0.027500931537360884, 0.08827146768453531, 0.07065724566928111, 0.02598705603304552, 0.008337382550962502, 0.03345829565660097, 0.06704483443172649, 0.07333106274018064, 0.03961888207413722, 0.0026809676637640223, 0.018351829603489023, 0.013069388496660395, 0.042366965863038786, 0.03518658319080714, 0.025682035193312913, 0.06888400996103883, 0.04814159095985815, 0.043220324369031005, 0.03741077751328703, 0.044504473626147956, 0.01845136644988088, 0.048385123009211384, 0.06579517648788169, 0.015323534971685149, 0.034560069543658756, 0.036666384839918464, 0.02837900356098544, 0.028580515208886936, 0.046924090274842456, 0.05460772699734662, 0.02982020982017275, 0.007539740317952237, 0.034254115453222767, 0.004175940666755196, 0.04297164181480184, 0.03470934141660109, 0.04728296691610012, 0.031041901784192305, 0.034168033744208515, 0.020924122727592476, 0.016682661553204525, 0.014759282876184443, 0.06589612341485918, 0.013842698026564904, 0.011965746252826648, 0.02181088158977218, 0.016918304572755005, 0.006154573165986221, 0.03410608296690043, 0.04652786876249593, 0.016237025993177667, 0.044364137211232446, 0.047920219440129586, 0.03469467286777217, 0.0755972923070658, 0.018619782022142317, 0.03686725081934128, 0.069742645137012, 0.03473517186648678, 0.06916687954799272, 0.012824247842218028, 0.12473525363020599, 0.14957646519178525, 0.1842866971855983, 0.14653642050689086, 0.16285057790810242, 0.10812165448442101, 0.1179384277202189, 0.17124112142482772, 0.1208858894824516, 0.1149708685989026, 0.1989148138090968, 0.1273455354385078, 0.0912345145479776, 0.20097121596336365, 0.055657090415479615, 0.0710704512312077, 0.19132056506350636, 0.17622309940634295, 0.11171936377650127, 0.21377648430643603, 0.10372857810580172, 0.18766734312521294, 0.11386782935005613, 0.13775673927739263, 0.12617835978744552, 0.1493611087789759, 0.09065457066753879, 0.16891938663320616, 0.07534518474130891, 0.23979828954907134, 0.12813160341465846, 0.09258286328986287, 0.14190096611855552, 0.15283326152712107, 0.115191657532705, 0.13578998856246471, 0.13247517112176865, 0.14748144167242572, 0.10290291655110195, 0.18748486385447904, 0.12942872912390158, 0.1843215781264007, 0.10491879002074711, 0.14292082545580342, 0.31790584442205727, 0.07048930507153273, 0.1421742991078645, 0.13442856317851692, 0.10574215833912604, 0.14526733313687146, 0.1901043631369248, 0.057144406309816986, 0.08056347738602199, 0.15636833355529234, 0.17909408285049722, 0.1892012287862599, 0.1574911584611982, 0.2263084493461065, 0.17227289965376258, 0.2945381077006459, 0.34543563437182456, 0.09659670962719247, 0.1421915169339627, 0.4462226136820391, 0.18499531463021412, 0.3354190749814734, 0.20499787176959217, 0.10004088340792805, 0.19512773811584339, 0.3310919977957383, 0.23695356328971684, 0.3345561056630686, 0.4594789445400238, 0.7192076544743031, 0.9312092629261315, 1.5252267569303513, 1.063229141291231, 0.630559598794207, 0.40472453576512635, 0.44631989439949393, 0.5688091716729105, 0.27619224681984633, 0.31652132340241224, 0.2345977193908766, 0.1693544039153494, 0.5982840119395405, 0.5119895143434405, 0.6213243724778295, 0.34713728993665427, 0.5320266704075038, 0.14892825856804848, 0.5078273720573634, 1.2654769700020552, 1.0528032132424414, 1.2997759482823312, 1.0048223566263914, 0.5055677995551378, 0.15215430030366406, 0.21385785337770358, 0.32415760739240795, 0.2748320979299024, 0.2463350520702079, 0.14327039185445756, 0.24219756392994896, 0.20096115244086832, 0.23169096442870796, 0.28922251949552447, 0.24190940283006057, 0.2298410574439913, 0.281307366094552, 0.12201328601804562, 0.22027572384104133, 0.15170127851888537, 0.2817023667739704, 0.24099345901049674, 0.1207436049298849, 0.13823812594637275, 0.1520817627897486, 0.14293611369794235, 0.13752757891779765, 0.21967532637063414, 0.16716057085432112, 0.10272350235027261, 0.15621727681718767, 0.10197803727351129, 0.10238808870781213, 0.12404457389493473, 0.18366602424066514, 0.14009886828716844, 0.14709099777974188, 0.18929678772110492, 0.13783962232992053, 0.21197793394094333, 0.14367587165907025, 0.1369516277918592, 0.13532267301343381, 0.17117631708970293, 0.12780491000739858, 0.13001757877646014, 0.09763180525624193, 0.11847123780171387, 0.15466280397959054, 0.09996291337301955, 0.1507741876412183, 0.166872973786667, 0.11947961611440405, 0.123785215546377, 0.13887453242205083, 0.1696402792003937, 0.1863128345576115, 0.13417474867310375, 0.1257920719217509, 0.15680510230595246, 0.22136182727990672, 0.1592193977558054, 0.12566327961394563, 0.2095094765536487, 0.2719978953246027, 0.11967609971179627, 0.12033131220960058, 0.1839355574338697, 0.08614462087280117, 0.1724947424372658, 0.12466402229620144, 0.17006466892780736, 0.041770869138417765, 0.12466849002521485, 0.20098681590752676, 0.1433151136734523, 0.19490782491629943, 0.13670542772160843, 0.10332310572266579, 0.11940497832256369, 0.18345811899052933, 0.1449596683960408, 0.1104205459705554], [0.08824538119370118, 0.021910746836510953, 0.01458694227039814, 0.03242682170821354, 0.04072929084941279, 0.012742128274112474, 0.04398114819196053, 0.04200112416583579, 0.021414168404589873, 0.013078610609227326, 0.08473390946164727, 0.020382623952173162, 0.05693681647244375, 0.009788674597075442, 0.012383554058033042, 0.04067052388563752, 0.023864393078838475, 0.12338235552306287, 0.10372975812060758, 0.019069959525950253, 0.06849113182397559, 0.08853856663336046, 0.07010571120190434, 0.029364872534642927, 0.036866798109258525, 0.09676567438873462, 0.050855933004640974, 0.0234848030959256, 0.01972342055523768, 0.04085728163772728, 0.04338563034252729, 0.009205751921399496, 0.01769806614902336, 0.03429241027333774, 0.05531799943128135, 0.024458278203383088, 0.034324114822084084, 0.01354944857666851, 0.009024252285598777, 0.017725384605000727, 0.055953979172045365, 0.008332618890563026, 0.04946171582560055, 0.022388654688256793, 0.05231945193372667, 0.0525023208319908, 0.02036700359894894, 0.03309450970846228, 0.041050685322261415, 0.016821313292894047, 0.027967547612206545, 0.03871675333357416, 0.027943186614720616, 0.020831307883781847, 0.0344457045866875, 0.05138466127391439, 0.03176899685058743, 0.019653744020615704, 0.05993376093101688, 0.17968089901842177, 0.16992766846669838, 0.057743954021134414, 0.07793668279191479, 0.17448028433136642, 0.0040543680643168045, 0.05946956982370466, 0.042167253923253156, 0.00861328615428647, 0.22092557803262025, 0.27117675344925374, 0.2317510190187022, 0.7407394365873188, 3.9337505539879203, 11.551660392433405, 13.973643779754639, 16.81906219571829, 31.752591468393803, 46.50188572704792, 62.91643112897873, 69.72384944558144, 59.228710010647774, 58.088983967900276, 63.11023212969303, 68.48232686519623, 78.62157359719276, 84.17451202869415, 82.32525765895844, 86.95088624954224, 89.30065736174583, 89.82574358582497, 84.14596036076546, 51.31338134407997, 34.53396052122116, 32.30929769575596, 22.663382291793823, 18.06634146720171, 3.2867443095892668, 1.7046898207627237, 0.4486754711251706, 0.5028017854783684, 0.6539142143446952, 0.5491094850003719, 0.3502592974109575, 0.1559975862619467, 0.08518695351085626, 0.12357903207885101, 0.09776507271453738, 0.06948990674572997, 0.0733001522894483, 0.18365055788308382, 0.0736710628552828, 0.03716561273904517, 0.06619685649638996, 0.048284276272170246, 0.057927717207348906, 0.04941056700772606, 0.04702081438153982, 0.04148614047153387, 0.09320979253971018, 0.08362501466763206, 0.023232736348290928, 0.023071259856806137, 0.03198735896148719, 0.04477697169932071, 0.04846654774155468, 0.019944840314565226, 0.027749545442929957, 0.03211622919479851, 0.00260336035353248, 0.029665407091670204, 0.046473621478071436, 0.05874831731489394, 0.006377429908752674, 0.020480403763940558, 0.012327833610470407, 0.028950791238457896, 0.0361934178363299, 0.052919033041689545, 0.07261380669660866, 0.12347188079729676, 0.03424185146286618, 0.08247667472460307, 0.0052162034990033135, 0.07293122325791046, 0.02648335059348028, 0.03383450515684672, 0.027505193320394028, 0.04778481088578701, 0.005809805679746205, 0.0633069037576206, 0.023539276735391468, 0.03645598226285074, 0.05021178221795708, 0.02206899313023314, 0.030576846074836794, 0.04060926330566872, 0.038149615211295895, 0.029331650293897837, 0.04395700612803921, 0.03370425081811845, 0.057850689699989744, 0.07686110300710425, 0.07293131231563166, 0.032422984804725274, 0.055563620626344346, 0.04104870378796477, 0.03870278240356129, 0.0218884712739964, 0.025032752455445006, 0.0013519525646188413, 0.02985268620250281, 0.0305508838937385, 0.05963930641883053, 0.006515087170555489, 0.06303000845946372, 0.05231220486166421, 0.03419648768613115, 0.05074181295640301, 0.020763056272699032, 0.02393342394498177, 0.05529408372240141, 0.06149804867163766, 0.03506686363834888, 0.034866851128754206, 0.08004200732102618, 0.00872726797751966, 0.028624086698982865, 0.0348303782811854, 0.049717827278072946, 0.015992243424989283, 0.034625033440534025, 0.05079151458630804, 0.016767717243055813, 0.054391958692576736, 0.012945241105626337, 0.04577485233312473, 0.07040437369141728, 0.08762079713051207, 0.01429732377800974, 0.12001835595583543, 0.041154793798341416, 0.05809194335597567, 0.024769573901721742, 0.055968703381950036, 0.017191964107041713, 0.028951596468687057, 0.052101913606747985, 0.013597309680335457, 0.017393483176419977, 0.03992486213974189, 0.020597891307261307, 0.027121026141685434, 0.0084739813246415, 0.023671776070841588, 0.0489404758263845, 0.044518518770928495, 0.045905236547696404, 0.06362144078593701, 0.03276746007031761, 0.003325403945382277, 0.02323432454431895, 0.008672820313222473, 0.025867692711472046, 0.021731982014898676, 0.03905248981027398, 0.02135258684575092, 0.020498304365901276, 0.015500148492719745, 0.09758525775396265, 0.03127774332824629, 0.0276329225016525, 0.03488919719529804, 0.013710215389437508, 0.06439401651732624, 0.07528091475251131, 0.1505628091399558, 0.12400286519550718, 0.08487088765832596, 0.0616825985343894, 0.19233905884902924, 0.056551693778601475, 0.11262790096225217, 0.017427608981961384, 0.06895090715261176, 0.05686045318725519, 0.42797525064088404, 0.35778841527644545, 0.21526970027480274, 2.824785760603845, 10.832089204341173, 10.977978575974703, 15.957882106304169, 34.22160588204861, 50.203301310539246, 68.46492379903793, 76.53395041823387, 62.391994670033455, 62.965699285268784, 70.99047347903252, 76.19913518428802, 87.54483997821808, 97.95706406235695, 94.96435225009918, 96.79424285888672, 100.08231282234192, 100.61142683029175, 94.81688216328621, 57.57092736661434, 34.86059859395027, 32.81302146613598, 22.832342125475407, 18.005778416991234, 3.9393873140215874, 0.9662686754018068, 0.15810617624083534, 0.4319997096899897, 0.7226404140237719, 0.46047799405641854, 0.3412120422581211, 0.13220673630712554, 0.04451350185263436, 0.09469981727306731, 0.17323500505881384, 0.177299584611319, 0.058033384193549864, 0.16022799129132181, 0.04785627228557132, 0.029659212013939396, 0.08302468399051577, 0.018682985173654743, 0.0168409987600171, 0.03573324174794834, 0.037361907088779844, 0.020748803326569032, 0.021521766830119304, 0.0969821291801054, 0.02041314663074445, 0.034233940168633126, 0.022619778028456494, 0.03312800654384773, 0.061584349314216524, 0.03835304160020314, 0.004245528143655974, 0.0128742500419321, 0.05135517203598283, 0.011038280590582872, 0.03692294529173523, 0.029799904659739695, 0.015002339023340028, 0.02940387981652748, 0.03875884794979356, 0.05084329422970768, 0.11763491900637746, 0.014438935759244487, 0.056129374643205665, 0.07084506840328686, 0.027187413106730673, 0.037785536114824936, 0.023465681661036797, 0.037477578225662, 0.07029413507552817, 0.05089258396765217, 0.0456115241831867, 0.03469967494311277, 0.008671039158798521, 0.018381396766926628, 0.022224704989639577, 0.07883428072091192, 0.0431009684689343, 0.05709281591407489, 0.05346770281903446, 0.005523192421605927, 0.09286287560826167, 0.02808808538247831, 0.03825940853857901, 0.029139333855709992, 0.042983041203115135, 0.023060439343680628, 0.04392424401885364, 0.0368876524589723, 0.020153573059360497, 0.04125472027226351, 0.024016869174374733, 0.027548031939659268, 0.06431255096686073, 0.030977351634646766, 0.03308143677713815, 0.0043229842412984, 0.010089973566209665, 0.0399896627641283, 0.015038399051263696, 0.06729906453983858, 0.16504461877048016, 0.12312270773691125, 0.16214712581131607, 0.1105779258068651, 0.13303978223120794, 0.16446281952084973, 0.0760087018716149, 0.10170511988690123, 0.11903354083187878, 0.1509230921510607, 0.1410227530868724, 0.11943427089136094, 0.1907953471527435, 0.08130699061439373, 0.11900543569936417, 0.21617733204038814, 0.09837563760811463, 0.2147161471657455, 0.2055102653685026, 0.07412196951918304, 0.158386351831723, 0.17807483207434416, 0.1774337945971638, 0.1598439595545642, 0.3173478681128472, 0.1749459671555087, 0.16965138172963634, 0.1230131667398382, 0.13079423632007092, 0.1426863216329366, 0.11874858580995351, 0.08239212926127948, 0.06875730308820494, 0.1702326614758931, 0.1435313606634736, 0.15000726707512513, 0.12372628902085125, 0.11050787448766641, 0.08936709287809208, 0.17995424685068429, 0.14230991917429492, 0.09991590573918074, 0.14286825171438977, 0.06952551499125548, 0.13997665140777826, 0.19271246303105727, 0.1300124282715842, 0.09501471795374528, 0.15702516393503174, 0.13309251924511045, 0.2177988801850006, 0.14379409578396007, 0.2659122250042856, 0.10972051517455839, 0.10300384121364914, 0.11080016192863695, 0.17467493482399732, 0.150004283641465, 0.17914122407091781, 0.3412741154897958, 0.30972918786574155, 0.13196835847338662, 0.2731599798426032, 0.4043078050017357, 0.1595476348302327, 0.1274083656608127, 0.10925062437308952, 0.1986016274895519, 0.5099370901007205, 0.5225238553248346, 0.3195078147109598, 1.458091246895492, 8.334831856191158, 18.09153601527214, 19.839153438806534, 27.718173153698444, 48.78329090774059, 69.08235266804695, 92.46503636240959, 103.98332789540291, 85.86659163236618, 81.85000196099281, 92.77921110391617, 101.91785752773285, 113.04920062422752, 123.92670974135399, 121.93558618426323, 124.09416675567627, 128.1412535905838, 128.53079348802567, 118.96070301532745, 77.42460742592812, 54.606334045529366, 49.26115706562996, 34.84469644725323, 26.755291521549225, 6.233024513348937, 3.554315264336765, 0.8491451852023602, 0.5013199243694544, 0.7406579190865159, 0.8558768802322447, 0.7523387297987938, 0.25029402400832623, 0.1653220335720107, 0.23759457108099014, 0.24115535110468045, 0.4241275414824486, 0.3211996442405507, 0.41873705573379993, 0.26046346582006663, 0.2192805483355187, 0.14704781962791458, 0.13436481269309297, 0.11684111042995937, 0.12381404056213796, 0.12021806789562106, 0.11592092894716188, 0.3389899036847055, 0.14770215639146045, 0.11253628283157013, 0.2100646772305481, 0.21303116023773327, 0.12063641654094681, 0.18568797589978203, 0.10584941352135502, 0.2080364470020868, 0.08948720947955735, 0.16487008047988638, 0.10479426506208256, 0.14646895928308368, 0.13388388615567237, 0.10737627846538089, 0.12850457715103403, 0.182036965561565, 0.07591493151267059, 0.12119155784603208, 0.19079053803579882, 0.16572294174693525, 0.27780656644608825, 0.24188501585740596, 0.1258289863471873, 0.12380008076434024, 0.1669745144317858, 0.14530098211253062, 0.09738529348396696, 0.11661537137115374, 0.1713527404353954, 0.056133471298380755, 0.17327994952211156, 0.08746517618419603, 0.1484605867881328, 0.22428781870985404, 0.12328899334534071, 0.12829388142563403, 0.09534458033158444, 0.13858991878805682, 0.11865477834362537, 0.14404142391867936, 0.12074929720256478, 0.1953679564758204, 0.12898746295832098, 0.1281259037205018, 0.12241350399563089, 0.16928768483921885, 0.09472582954913378, 0.0892959134944249, 0.17026399495080113, 0.1782212726539001, 0.10359378924476914, 0.13264249573694542, 0.1493021080386825, 0.1176864760054741, 0.19294984638690948, 0.11288494381005876, 0.11999362759524956], [0.029336173683987, 0.03808375331573188, 0.031078242900548503, 0.021342412001104094, 0.05760233740147669, 0.030007340501470026, 0.03333133274281863, 0.032260350562864915, 0.06283265654928982, 0.02297859529790003, 0.014602886385546299, 0.027438448269094806, 0.029873438506911043, 0.012947971281391801, 0.02795862699713325, 0.03864841637550853, 0.06178870338771958, 0.007238394500745926, 0.02830077377439011, 0.04480090596189257, 0.02718150932196295, 0.07819219681550749, 0.022156946906761732, 0.03568867206922732, 0.02608862821944058, 0.0181469374729204, 0.032024180618464015, 0.029111982003087178, 0.020491450632107444, 0.026901059136434924, 0.03203923879482318, 0.06601960194529966, 0.05638107031700201, 0.03298421543149743, 0.08550020662369207, 0.027581948088482022, 0.08744859660509974, 0.024455634302285034, 0.058532040638965555, 0.02320674633665476, 0.07300039142137393, 0.08503522141836584, 0.024190027070289943, 0.034240241002407856, 0.04437191120814532, 0.07191774639068171, 0.052159463448333554, 0.033147517606266774, 0.07539713507867418, 0.08679924707394093, 0.012195040199003415, 0.028955349880561698, 0.0652207616076339, 0.016732121985114645, 0.11476288171252236, 0.016810095730761532, 0.07604636586620472, 0.08986600165371783, 0.10036553590907715, 0.17868511495180428, 0.10589673285721801, 0.1258426418644376, 0.25521286006551236, 0.6627679173834622, 0.15679306467063725, 0.10633649988449179, 0.07410260688629933, 0.5862742220051587, 3.0119375931099057, 18.17029818892479, 55.32861828804016, 76.2013466656208, 100.83618476986885, 107.37078532576561, 108.97087186574936, 117.94567108154297, 121.33834943175316, 120.55022612214088, 112.20882251858711, 118.89049038290977, 123.91961932182312, 117.24249601364136, 122.46282309293747, 115.43013006448746, 112.44216799736023, 114.23406824469566, 116.92737132310867, 118.32160010933876, 112.08007782697678, 115.19773453474045, 121.26414701342583, 128.35404217243195, 120.92028066515923, 133.9356842637062, 130.58478087186813, 130.28655767440796, 114.02590781450272, 108.01335364580154, 87.23773285746574, 67.20083802938461, 43.428739830851555, 11.626463178545237, 5.013408707454801, 0.39927984355017543, 0.22881978802615777, 0.7504758797585964, 0.6734267610590905, 0.6423547596205026, 0.15465441771084443, 0.09945400786818936, 0.04745898950204719, 0.2252215295447968, 0.12750098569085822, 0.030118310132820625, 0.041038877752725966, 0.05901671502215322, 0.022364555297826882, 0.07438848217134364, 0.11251191070186906, 0.0714259770757053, 0.0789413800521288, 0.01962149028258864, 0.06910393800353631, 0.08253715233877301, 0.030031894457351882, 0.06850552206742577, 0.06273513834457844, 0.07290153735084459, 0.018530464549257886, 0.018744754124782048, 0.018307764585188124, 0.0644191233732272, 0.05787003748991992, 0.04379707701446023, 0.0842877673858311, 0.041641776260803454, 0.04352008523710538, 0.021404644794529304, 0.0436265797179658, 0.013139950042386772, 0.04695726056525018, 0.05308044273988344, 0.022475009136542212, 0.019782441704592202, 0.03965910647821147, 0.05248309920716565, 0.10391286079538986, 0.039972938466235064, 0.025361048901686445, 0.0432030174852116, 0.010601187150314217, 0.014893665411364054, 0.03149725576804485, 0.025488030369160697, 0.03250462847063318, 0.020088998790015467, 0.01158801813289756, 0.019061491620959714, 0.02490530529030366, 0.016048017678258475, 0.017934161878656596, 0.07315515147638507, 0.0568284035398392, 0.015604051950504072, 0.02005615875532385, 0.062488856638083234, 0.05281093923258595, 0.03278103766206186, 0.036064747982891276, 0.0074240571211703354, 0.05550342131755315, 0.024561624122725334, 0.015586761765007395, 0.03574199537979439, 0.09340085845906287, 0.022122763584775385, 0.028395453264238313, 0.020122655187151395, 0.03733354220457841, 0.054934175495873205, 0.06135946743597742, 0.11103447279310785, 0.05285418046696577, 0.017291011135966983, 0.01274534270123695, 0.029654679347004276, 0.029291470418684185, 0.04572881320200395, 0.039241006452357396, 0.04008222713309806, 0.02076877080980921, 0.14178663084749132, 0.08108093243208714, 0.08407466710195877, 0.11062986130127683, 0.018822495949279983, 0.021069346184958704, 0.028839385595347267, 0.06358460799674504, 0.05337048518413212, 0.032508079457329586, 0.023917534563224763, 0.04750637563120108, 0.04384347608720418, 0.022481656924355775, 0.161457997164689, 0.04445003709406592, 0.07174050668254495, 0.02996844083099859, 0.06962606115848757, 0.03590369080484379, 0.012859992457379121, 0.08566232136217877, 0.04938996127748396, 0.06272720478591509, 0.028978777627344243, 0.012323558839852922, 0.015461490947927814, 0.04223779877065681, 0.023703066872258205, 0.08346053247805685, 0.03139852415188216, 0.06730989989591762, 0.020427223316801246, 0.034440375966369174, 0.05517022669664584, 0.05158122650755104, 0.002391280754636682, 0.028373075656418223, 0.0545978824084159, 0.04558586442726664, 0.06491541236755438, 0.06612979603232816, 0.030710354731127154, 0.07797840633429587, 0.09827729561948217, 0.08705150306923315, 0.0746847697882913, 0.18235916155390441, 0.6790597212966532, 0.40307236660737544, 0.24657718517119065, 0.07618605290190317, 0.3372673789272085, 2.38300365395844, 19.18511923402548, 57.63618506491184, 86.64194762706757, 117.32849299907684, 121.24624237418175, 129.37784403562546, 133.40321123600006, 135.6903237104416, 133.9056658744812, 135.27655631303787, 137.74908363819122, 143.32365810871124, 139.13810670375824, 140.24989664554596, 137.79063820838928, 133.4581258893013, 135.11848479509354, 147.47592329978943, 143.75908434391022, 135.373055934906, 137.80310153961182, 137.62957245111465, 150.93501448631287, 142.70099312067032, 155.51782697439194, 154.97390896081924, 156.0152354836464, 128.7563493847847, 132.94861882925034, 106.3283796608448, 76.54353350400925, 48.77093777060509, 11.950294151902199, 3.964811749756336, 0.3173077030805871, 0.22232663410250098, 0.8001737098675221, 0.6476602249313146, 0.5231068271677941, 0.11886529595358297, 0.12394117045914754, 0.026523270717007108, 0.050307107376283966, 0.06927137394086458, 0.03314457870146725, 0.021693466405849904, 0.03523327912262175, 0.054828230204293504, 0.0452411034348188, 0.09832442199694924, 0.04632156284060329, 0.09110380007768981, 0.01959950415766798, 0.022676253611280117, 0.062302065489348024, 0.06455557464505546, 0.022038418501324486, 0.010026913278124994, 0.029671271913684905, 0.021532225546252448, 0.01817942498746561, 0.05314157344400883, 0.020022589560539927, 0.04171787608356681, 0.041578166783438064, 0.0635909459379036, 0.0032628838016535155, 0.03708275566168595, 0.04716086135886144, 0.04029083742352668, 0.04604266374371946, 0.017904255182656925, 0.016594390508544166, 0.03825279600278009, 0.0845395632495638, 0.05070508035714738, 0.06290854857070372, 0.07055746391415596, 0.021998954798618797, 0.01951981790625723, 0.03425526578212157, 0.05289620457915589, 0.00982063147603185, 0.028338627016637474, 0.045613502006744966, 0.02682092945178738, 0.0812210128060542, 0.03495031676720828, 0.09144452007603832, 0.029356964951148257, 0.025666099427326117, 0.04161419805313926, 0.05141710054886062, 0.04752307395392563, 0.029958817031001672, 0.06957169141969644, 0.04972216884198133, 0.010064387097372673, 0.049290298265987076, 0.032615698291920125, 0.0266444448789116, 0.04301307591958903, 0.024476844882883597, 0.01296225762416725, 0.03838466822344344, 0.057206349665648304, 0.016425592730229255, 0.12651125754928216, 0.11390015730285086, 0.11257189107709564, 0.12607904558535665, 0.2820962097030133, 0.14149639173410833, 0.13973966881167144, 0.15188015095191076, 0.12624778028111905, 0.1639526226790622, 0.1247782981954515, 0.13707708043511957, 0.16988774092169479, 0.1322072558104992, 0.16419267776655033, 0.1948611141415313, 0.17421002383343875, 0.18618140020407736, 0.15493282699026167, 0.12633502716198564, 0.10642609195201658, 0.09244659755495377, 0.18850625201594085, 0.12872618244728073, 0.14771413465496153, 0.12500407436164096, 0.21778060850920156, 0.22374061838490888, 0.09923684803652577, 0.2152728321379982, 0.164700455206912, 0.11866013664985076, 0.12244862984516658, 0.11798448540503159, 0.16172402742085978, 0.05862732126843184, 0.1828541888971813, 0.19861091917846352, 0.24159550404874608, 0.13847484136931598, 0.19527983386069536, 0.16750026668887585, 0.14027449011337012, 0.14556153531884775, 0.2008500084048137, 0.17162795847980306, 0.11690982588334009, 0.1260847007506527, 0.08521691401256248, 0.12695936631644145, 0.10079381449031644, 0.11372103253961541, 0.1812108067679219, 0.11621389174251817, 0.17139099072664976, 0.11720243244781159, 0.31585638877004385, 0.1603982102824375, 0.2822940959595144, 0.2879003982525319, 0.1119550847215578, 0.33494187402538955, 0.5231062334496528, 1.05173178948462, 0.32373927359003574, 0.19733669614652172, 0.3708413086133078, 1.8566183745861053, 5.54741115309298, 27.712842039763927, 77.16902554035187, 107.78988003730774, 141.89256370067596, 146.42230063676834, 150.4759383201599, 155.5647772550583, 155.191850066185, 152.094666659832, 142.95594424009323, 149.14485454559326, 157.6872217655182, 151.29376083612442, 154.44619327783585, 144.3407267332077, 142.18691110610962, 144.51731085777283, 150.81828474998474, 151.69144749641418, 142.09383130073547, 147.63571232557297, 156.07271879911423, 167.6349663734436, 159.48023915290833, 174.06270146369934, 171.64779424667358, 171.23829782009125, 155.01497715711594, 154.0252822637558, 129.24720704555511, 102.46806040406227, 65.76076850295067, 17.667340077459812, 7.841582698747516, 0.5617055715993047, 0.2253419058979489, 0.9610297065228224, 1.0724607459269464, 0.9461170504800975, 0.47562917636241764, 0.24451368808513507, 0.16820217511849478, 0.29261410469189286, 0.2248464777949266, 0.12509246414992958, 0.2223179509746842, 0.17930068192072213, 0.16586464742431417, 0.1504404586739838, 0.35369095858186483, 0.1698829763336107, 0.2421339470311068, 0.09366615398903377, 0.22288118168944493, 0.10819697505212389, 0.13449918595142663, 0.2313765016151592, 0.10528159633395262, 0.11117575544631109, 0.15352178161265329, 0.12878450041171163, 0.12133251395425759, 0.14369218406500295, 0.11447200435213745, 0.16512969858013093, 0.1692537241615355, 0.11723776609869674, 0.1117576882825233, 0.18004922691034153, 0.15073516551638022, 0.2259337538271211, 0.10613451697281562, 0.12325777861406095, 0.12475183320930228, 0.19572866993257776, 0.16591879451880231, 0.1579875810421072, 0.12668633018620312, 0.1649096072651446, 0.09883710503345355, 0.06853579427115619, 0.1242710328369867, 0.12532969907624647, 0.08738316886592656, 0.15896775032160804, 0.1677120162639767, 0.12355947648757137, 0.13691339234355837, 0.13987539277877659, 0.07385826218524016, 0.10431114918901585, 0.20532741502393037, 0.23358351521892473, 0.15325956599554047, 0.13793994585284963, 0.15612523566232994, 0.1501479634316638, 0.1745768080581911, 0.0929847733641509, 0.13794549711747095, 0.07809909438947216, 0.12212644127430394, 0.1376221582177095, 0.14856377500109375, 0.13328688772162423, 0.19106528110569343, 0.09319707212853245], [0.06893263547681272, 0.07606765066157095, 0.043947899976046756, 0.04606035283359233, 0.025180332231684588, 0.01863691821199609, 0.03833332273643464, 0.011213367142772768, 0.011783059180743294, 0.029199538730608765, 0.010011179747380083, 0.03061112958675949, 0.05833469986100681, 0.06663896128884517, 0.026248227077303454, 0.07213057950139046, 0.019982556259492412, 0.037466980356839485, 0.03797632743953727, 0.008409041547565721, 0.03961175374570303, 0.044141140388092026, 0.04524296993622556, 0.01704214675555704, 0.053293750825105235, 0.011240690237173112, 0.05481309781316668, 0.086385321628768, 0.047485012910328805, 0.09384841803694144, 0.028200698870932683, 0.06427205938962288, 0.018945152551168576, 0.11602886690525338, 0.024792428339424077, 0.0623215023369994, 0.01192217012430774, 0.0455911633616779, 0.04096839598787483, 0.014848006630927557, 0.05531120135856327, 0.04358839622000232, 0.08023669492104091, 0.03301170087070204, 0.0405041195335798, 0.02680642603081651, 0.052792960705119185, 0.12652878707740456, 0.052984238136559725, 0.0027431454918769305, 0.052246357809053734, 0.05396014006691985, 0.06162064033560455, 0.04991342771972995, 0.01683087772107683, 0.013777204421785427, 0.07480904983822256, 0.0511028306937078, 0.15782784117618576, 0.31739402969833463, 0.18715168407652527, 2.0271988213062286, 5.734605258330703, 19.14510928094387, 33.43160167336464, 50.414216592907906, 58.508789241313934, 66.2364573776722, 83.28750282526016, 108.0742035806179, 103.657715767622, 104.55833584070206, 98.8476374745369, 89.06693190336227, 97.90661036968231, 98.3108326792717, 89.0259625017643, 107.85348862409592, 86.90031096339226, 98.68001326918602, 88.64063277840614, 84.85916689038277, 84.61328208446503, 97.95198753476143, 104.14503201842308, 75.32239302992821, 84.19338181614876, 63.00023943185806, 92.59748965501785, 92.26876929402351, 103.62577468156815, 79.1681058704853, 91.99961453676224, 101.70297905802727, 98.09533104300499, 79.51810508966446, 92.74851635098457, 105.6628605723381, 111.53599262237549, 114.71157342195511, 124.63443696498871, 111.4442427456379, 97.96466365456581, 76.8762056529522, 36.645457819104195, 30.717413015663624, 14.59970198571682, 12.619771678000689, 1.1118920613080263, 0.5088090256322175, 0.1528939395211637, 0.04804150121344719, 0.09475630213273689, 0.04692839844210539, 0.13453936582664028, 0.11077149276388809, 0.0709982996340841, 0.017161341238534078, 0.0979059175006114, 0.05248754838248715, 0.028174044637125917, 0.033762023304007016, 0.08567426251829602, 0.026249902475683484, 0.03518603400152642, 0.04162399811320938, 0.025062863242055755, 0.025452279260207433, 0.0980642027570866, 0.0742881883343216, 0.009899474462145008, 0.02743387478403747, 0.032303168773069046, 0.019737105758395046, 0.06594931313884445, 0.07138655419112183, 0.024159159293049015, 0.01639124984649243, 0.01353520676275366, 0.05168772840988822, 0.03810628491919488, 0.06501545387436636, 0.04957686003763229, 0.03842229511064943, 0.03232525508792605, 0.04368074907688424, 0.06316850063740276, 0.041901164295268245, 0.0064701422434154665, 0.024980516391224228, 0.030945979196985718, 0.0027853811161548947, 0.01845108999987133, 0.05340938485460356, 0.041890158245223574, 0.01906494260765612, 0.014215446335583692, 0.052950166136724874, 0.07145080191548914, 0.06022303154168185, 0.054085841329651885, 0.0277647409166093, 0.037078822278999723, 0.004781406078109285, 0.016275087036774494, 0.019729459781956393, 0.06856340216472745, 0.016748842572269496, 0.04679698635300156, 0.03292044268164318, 0.04220308852382004, 0.04611704920534976, 0.019145979567838367, 0.011855109660245944, 0.01994680700590834, 0.05175870370294433, 0.03773959346290212, 0.030917239528207574, 0.01813094233511947, 0.020157771759841125, 0.0023302184672502335, 0.06294681370491162, 0.04188772400084417, 0.06193584529682994, 0.03304737219878007, 0.012408072761900257, 0.0059656784924300155, 0.01859531712398166, 0.0163895299192518, 0.020883059696643613, 0.016599912087258417, 0.05617234499368351, 0.04182792174105998, 0.05531168746529147, 0.01839426375227049, 0.03199295104423072, 0.014064691094972659, 0.05608346909866668, 0.04616760430508293, 0.026066070640808903, 0.03482464890112169, 0.06085564564273227, 0.056455789745086804, 0.027563604053284507, 0.02456153877574252, 0.05788718852272723, 0.09470628880080767, 0.015275685000233352, 0.05685676100256387, 0.07385508579318412, 0.0410245505918283, 0.011018816840078216, 0.007444411448886967, 0.0242095789508312, 0.03726764320163056, 0.015139762508624699, 0.0371508440002799, 0.07571844049380161, 0.022000110693625174, 0.01926997945702169, 0.05008183958125301, 0.08286308875540271, 0.05251677786873188, 0.10893596860114485, 0.0526070267369505, 0.06610884520341642, 0.04926749206788372, 0.040589002674096264, 0.04687702326918952, 0.07952409956487827, 0.07075601810356602, 0.0057166540864272974, 0.04416186857270077, 0.00630050027211837, 0.17804404778871685, 0.16463946551084518, 0.14315267238998786, 1.649865887593478, 5.040853209793568, 18.82733043283224, 37.61267311871052, 60.55181801319122, 67.44211748242378, 79.91394504904747, 96.52369737625122, 121.43759250640869, 119.27629128098488, 118.380626142025, 110.79849019646645, 120.54014906287193, 120.4514542222023, 125.72755470871925, 120.1827022433281, 144.9823147058487, 115.2140660583973, 140.80190062522888, 116.8365789949894, 122.08155915141106, 132.18189597129822, 127.00275108218193, 142.34714090824127, 110.94339162111282, 131.11602276563644, 108.8081493973732, 130.61593919992447, 130.56012779474258, 153.9133858680725, 111.51163592934608, 138.92872273921967, 129.6838340163231, 120.05881369113922, 118.66800472140312, 132.70990043878555, 121.35857954621315, 133.9907357096672, 135.29183149337769, 147.3277160525322, 131.14721149206161, 118.98383617401123, 89.00781467556953, 45.53524039685726, 37.44922488927841, 16.52603141963482, 12.980930898338556, 0.8672084065619856, 0.5425013427156955, 0.1858114099013619, 0.04408706008689478, 0.04125141400436405, 0.040680316524230875, 0.09722093745949678, 0.08254921965999529, 0.026830321330635343, 0.03584346181014553, 0.04476501198951155, 0.028016328978992533, 0.050151482719229534, 0.010846810200746404, 0.011622461206570733, 0.026973229287250433, 0.031376764382002875, 0.026841761537070852, 0.030414889042731375, 0.07293115646461956, 0.020806028478546068, 0.05980851608910598, 0.014902860621077707, 0.016770574511610903, 0.05304447826347314, 0.018767506517178845, 0.02446670529025141, 0.018313822365598753, 0.018156535297748633, 0.08262748655397445, 0.0381377074518241, 0.017525613293400966, 0.03912128318916075, 0.05470861084177159, 0.06201082076586317, 0.017109086620621383, 0.02820016637997469, 0.04449331543582957, 0.05273776718240697, 0.014126725363894366, 0.03776131241465919, 0.02210714137618197, 0.014702264597872272, 0.030655252121505328, 0.03519105834129732, 0.06895587212056853, 0.026781560372910462, 0.0060442552330641774, 0.04523993826296646, 0.006473579314842937, 0.05945592172793113, 0.024519420039723627, 0.041768676092033274, 0.05652339939842932, 0.0354130458435975, 0.03415556937397923, 0.05155105820449535, 0.05382405244745314, 0.06215557667019311, 0.00898625989066204, 0.046832720763632096, 0.020614519125956576, 0.048228663436020724, 0.017523268106742762, 0.008647897138871485, 0.04854707447520923, 0.04971599788405001, 0.03944866679375991, 0.17295693716732785, 0.19273263460490853, 0.08380114857573062, 0.1343930439907126, 0.07729009405011311, 0.11885416373843327, 0.14397702034329996, 0.12417206744430587, 0.14557930233422667, 0.1953754818532616, 0.16776031523477286, 0.17771720595192164, 0.17780749563826248, 0.10524458542931825, 0.16575305809965357, 0.18784464220516384, 0.11842944004456513, 0.22577950585400686, 0.11286889857728966, 0.0898066298395861, 0.10671912896214053, 0.14582761010387912, 0.2165435373899527, 0.09738124877912924, 0.21336059959139675, 0.10023962313425727, 0.15400861564558, 0.16424731467850506, 0.1355933491140604, 0.21680744510376826, 0.15966878301696852, 0.1578227203572169, 0.17691016488242894, 0.2041200891835615, 0.11362145858583972, 0.1131485027144663, 0.07296723226318136, 0.14510440203594044, 0.23155736300395802, 0.09367952749016695, 0.12076671540853567, 0.24238725687609985, 0.13384395861066878, 0.10600710505968891, 0.10938136852928437, 0.21164807898458093, 0.14412384683964774, 0.2136421704199165, 0.21642102365149185, 0.15681703604059294, 0.15477148408535868, 0.19212011044146493, 0.18793067196384072, 0.23332725162617862, 0.2405212601297535, 0.17833081365097314, 0.20330099563580006, 0.0793272745795548, 0.4298928414937109, 0.4825959837762639, 0.22103878523921594, 4.029422057792544, 10.391524694859982, 27.318742386996746, 50.750787332654, 76.3846868276596, 84.00122612714767, 97.37917587161064, 115.89000418782234, 140.12280106544495, 134.71458166837692, 131.72563165426254, 119.52193289995193, 112.03001171350479, 122.23007798194885, 124.03764098882675, 113.29968318343163, 135.91814428567886, 114.71074506640434, 129.77831214666367, 117.46536165475845, 112.43084460496902, 116.2289460003376, 127.90210962295532, 139.38852846622467, 104.79806497693062, 112.17878133058548, 90.48041805624962, 121.90576538443565, 120.11186644434929, 132.58710622787476, 107.89587914943695, 121.04919254779816, 131.49785667657852, 127.25819617509842, 108.41828271746635, 125.48760518431664, 132.20004379749298, 141.5829563140869, 144.03078496456146, 162.95285761356354, 152.54741996526718, 140.22037982940674, 111.83920115232468, 61.649700701236725, 51.81886062026024, 24.684484340250492, 21.241392195224762, 2.1137263532727957, 0.7006367447320372, 0.4500813066260889, 0.19153247791109607, 0.2559009793912992, 0.20542922284221277, 0.22325724276015535, 0.25591015233658254, 0.1621077919844538, 0.2478968127979897, 0.18054067710181698, 0.09501210559392348, 0.1335627885418944, 0.13198339438531548, 0.23874421720393002, 0.11237971193622798, 0.09394356879056431, 0.15934398950776085, 0.22967031894950196, 0.16400181222707033, 0.21271450066706166, 0.1834487827727571, 0.11585423213546164, 0.08491957996739075, 0.15313295560190454, 0.11807124246843159, 0.1366881505236961, 0.22619132359977812, 0.10372880817158148, 0.15625157888280228, 0.0811839870584663, 0.1121023713494651, 0.1044318891945295, 0.2036596162361093, 0.17483264120528474, 0.07202906854217872, 0.15427382953930646, 0.17743998410878703, 0.13072971400106326, 0.16323174495482817, 0.1335780174122192, 0.1468460148316808, 0.12923348491312936, 0.09442534879781306, 0.11491086595924571, 0.15069885965203866, 0.12117954247514717, 0.11764833703637123, 0.1157284232613165, 0.13793599762720987, 0.13710682571399957, 0.12592602957738563, 0.16919834510190412, 0.10910180149949156, 0.13968155864859, 0.14194276387570426, 0.08939758030464873, 0.08916969643905759, 0.1986425940413028, 0.09497086444753222, 0.13421234587440267, 0.1610458825598471, 0.14488328655716032, 0.1528539674472995, 0.1121174888976384, 0.11332714508171193, 0.09692060513771139, 0.06930043644388206], [0.0062044051355769625, 0.020818858356506098, 0.029406401263258886, 0.08843344883644022, 0.04717135903774761, 0.057492198975523934, 0.06550747551955283, 0.02412082551018102, 0.05387361306929961, 0.020487674955802504, 0.07945823395857587, 0.04496621564612724, 0.08795187663054094, 0.022311460197670385, 0.05990561498038005, 0.057350430215592496, 0.06330959775368683, 0.09296388190705329, 0.0013858154875379114, 0.03262528312916402, 0.0774340632779058, 0.08780932490481064, 0.04671211805543862, 0.06218483584234491, 0.040909818271757104, 0.025356184123666026, 0.05050678963016253, 0.012148783989687217, 0.045704596923314966, 0.08782005636021495, 0.020232569113431964, 0.0293314369264408, 0.022818768229626585, 0.03315515801659785, 0.05132085512741469, 0.004462471360966447, 0.055933562689460814, 0.02677949163626181, 0.07250684095197357, 0.08764155500102788, 0.05826667089422699, 0.036367028442327864, 0.021120437486388255, 0.058192727010464296, 0.043713822888094, 0.04049649025546387, 0.0617508538562106, 0.022694473336741794, 0.02873704714147607, 0.07055764202959836, 0.05669155150826555, 0.05320536845829338, 0.016950996177911293, 0.056904173106886446, 0.09992355728172697, 0.01782533148798393, 0.17035426979418844, 0.13383858546148986, 7.073263926431537, 30.724566131830215, 57.560945302248, 77.83098042011261, 90.76060742139816, 81.66891887784004, 100.11125206947327, 95.83332002162933, 90.29597595334053, 96.78286626935005, 108.40833485126495, 73.92006307840347, 80.19630789756775, 57.5977349281311, 76.87317341566086, 30.315041206777096, 42.0028967410326, 45.54405592381954, 31.869741082191467, 34.2729639261961, 35.475895777344704, 30.813513658940792, 34.232477098703384, 36.1035080999136, 21.180964037775993, 41.10274784266949, 27.502893805503845, 31.735382191836834, 35.23965485394001, 39.77511428296566, 25.586907416582108, 33.64796206355095, 26.790585927665234, 37.51709304749966, 19.726854264736176, 49.61599342525005, 58.94925020635128, 54.45887915790081, 45.772142484784126, 65.66345572471619, 75.43196395039558, 94.17581096291542, 89.15197893977165, 107.98952892422676, 104.8146016895771, 105.50856605172157, 118.82441952824593, 109.55039396882057, 110.82699626684189, 109.3440118432045, 88.13845932483673, 40.08203521370888, 4.810250708833337, 0.3408314986154437, 0.36754421365913004, 0.2064677991438657, 0.023723054764559492, 0.0772881941520609, 0.07666463425266556, 0.0146708531974582, 0.0958329728746321, 0.04499023525568191, 0.024577289004810154, 0.03183714456099551, 0.03620735908043571, 0.03835347946733236, 0.05440138396807015, 0.022144977920106612, 0.058693090395536274, 0.02338802703889087, 0.10708390196668915, 0.03216450961190276, 0.04180363495834172, 0.018606501289468724, 0.030024126026546583, 0.03358276124345139, 0.041489610011922196, 0.020580076052283403, 0.07737444655504078, 0.04787119687534869, 0.044270481885178015, 0.008497359904140467, 0.03335468441946432, 0.026998376961273607, 0.05858582037035376, 0.026721520625869744, 0.036155876296106726, 0.027767447900259867, 0.07614185800775886, 0.03763351087400224, 0.047239981722668745, 0.016988463503366802, 0.038312078759190626, 0.028253510099602863, 0.025273865103372373, 0.015238434752973262, 0.037651682359864935, 0.027589521705522202, 0.011794716465374222, 0.04455746297026053, 0.03926436183974147, 0.04130337547394447, 0.01670114103035303, 0.014855722183710895, 0.050903089068015106, 0.09734574443427846, 0.026387748985143844, 0.08181856785085984, 0.013572551633842522, 0.018674482016649563, 0.031879988746368326, 0.011382622269593412, 0.05254408890323248, 0.07282831706106663, 0.027347605682734866, 0.06461436758399941, 0.025126860491582192, 0.016895385197130963, 0.010367835511715384, 0.01815201005229028, 0.02397881369688548, 0.08294989776914008, 0.022786304834880866, 0.018428973999107257, 0.03932848710974213, 0.06069796894735191, 0.05304336504195817, 0.014210720710252644, 0.023586165625602007, 0.020204120737616904, 0.062394388660322875, 0.033982838212978095, 0.026292692855349742, 0.03492531010124367, 0.008278893892565975, 0.04399580189783592, 0.044384297652868554, 0.006340701020235429, 0.05055902569438331, 0.01173511551314732, 0.02504442829376785, 0.027320886511006393, 0.027875363593921065, 0.02503307714505354, 0.07721125570242293, 0.017924614148796536, 0.008439011326117907, 0.02460124553181231, 0.01154089268311509, 0.02705028462514747, 0.010938663963315776, 0.01861095046479022, 0.05216077704972122, 0.060023371552233584, 0.06062468557502143, 0.03707865529577248, 0.021756667701993138, 0.03488887807179708, 0.04222268864396028, 0.039263567741727456, 0.04469793668249622, 0.03994955710368231, 0.08656409758259542, 0.07690415499382652, 0.05737950014008675, 0.027967269306827802, 0.04956284086802043, 0.03618957722210325, 0.11836106597911566, 0.026013597089331597, 0.08950680959969759, 0.03002396275405772, 0.03995572806161363, 0.05372168430767488, 0.16364657582016662, 0.42613748519215733, 6.788729494437575, 32.41467364132404, 62.51631259918213, 91.49915859103203, 103.13289552927017, 98.79819452762604, 104.04075041413307, 108.53479966521263, 101.43852084875107, 110.4900911450386, 112.07865670323372, 106.10152423381805, 111.33736968040466, 101.88930585980415, 115.02885639667511, 65.5217233300209, 88.60522627830505, 75.22113606333733, 52.754195630550385, 57.070251032710075, 52.587992548942566, 60.278434082865715, 65.33114835619926, 61.91935323178768, 44.44021135568619, 75.87584093213081, 68.3568499982357, 58.08423802256584, 56.65906369686127, 53.34414057433605, 53.46003815531731, 62.28752687573433, 59.18209031224251, 63.605767339468, 48.702112063765526, 78.0477587878704, 89.34797242283821, 88.95948126912117, 79.51530084013939, 104.32468637824059, 124.99566078186035, 123.84536370635033, 131.65199160575867, 135.5234670639038, 130.3705331683159, 129.70689117908478, 139.9653223156929, 131.8434253334999, 128.1825953722, 126.54739871621132, 99.55394357442856, 43.942240476608276, 4.915055735036731, 0.14810267864959314, 0.2987605717498809, 0.1165957267221529, 0.010230073421553243, 0.10775657719932497, 0.07048647006740794, 0.0599979604157852, 0.21237336506601423, 0.14830178202828392, 0.04604637077136431, 0.0532609367655823, 0.022747217772121076, 0.04430882494489197, 0.011433006675360957, 0.007029140861050109, 0.01931178278027801, 0.06321220571408048, 0.034483650597394444, 0.03608816274208948, 0.01629390419111587, 0.02833450253092451, 0.048579580543446355, 0.03751761338207871, 0.04889585048658773, 0.07178538435255177, 0.009781797671166714, 0.022864788807055447, 0.05705776056856848, 0.053267564144334756, 0.03919442926417105, 0.048862364783417434, 0.047323399121523835, 0.07694605665165, 0.12345139752142131, 0.016570402440265752, 0.04770138235471677, 0.0767996754439082, 0.060068494130973704, 0.0294182385187014, 0.056459934639860876, 0.014790219302085461, 0.014762121591047617, 0.06794125976739451, 0.03204700908099767, 0.033493146911496297, 0.018737414284260012, 0.05789147442555986, 0.05085238182800822, 0.023115621734177694, 0.050455592572689056, 0.14510837994748726, 0.029880828442401253, 0.01408525136866956, 0.01897973477753112, 0.1194418927480001, 0.043207863709540106, 0.08412281022174284, 0.02183067652367754, 0.04662511979404371, 0.04629232964362018, 0.03650210674095433, 0.020834647548326757, 0.03651063030702062, 0.013774640301562613, 0.05847491753229406, 0.14049146440811455, 0.10893901882809587, 0.12130731061915867, 0.15095277805812657, 0.10954087832942605, 0.15298139420337975, 0.10187931678956375, 0.19007234688615426, 0.15542427718173712, 0.11955754904192872, 0.16938360000494868, 0.17079906858270988, 0.15743588330224156, 0.13828890369040892, 0.15155176544794813, 0.07456987048499286, 0.11976506837527268, 0.1876354159321636, 0.18169988208683208, 0.06541796508827247, 0.22318166244076565, 0.14391125121619552, 0.10196487157372758, 0.18014233675785363, 0.09378839313285425, 0.07765077039948665, 0.15102826931979507, 0.12069925418472849, 0.17046796681825072, 0.13950859371107072, 0.1640498885535635, 0.08271995073300786, 0.11665971469483338, 0.2367465931456536, 0.18707365466980264, 0.10976176374242641, 0.20571336150169373, 0.15401406300952658, 0.17690029431832954, 0.19045164372073486, 0.19968369364505634, 0.10805961093865335, 0.09852664239588194, 0.19498990644933656, 0.11648921368760057, 0.19909451744752005, 0.26440038112923503, 0.1076289129559882, 0.06769667757907882, 0.16011524421628565, 0.25447219668421894, 0.2475757448701188, 0.2261957319569774, 0.2084508622647263, 0.1575222099199891, 0.1580486004240811, 0.2946837467607111, 0.6880637537688017, 14.805367849767208, 53.69411699473858, 87.94287621974945, 112.82813608646393, 126.97190433740616, 112.29292720556259, 127.83799946308136, 120.40378198027611, 115.25187402963638, 122.97940537333488, 136.90514892339706, 97.92173355817795, 106.68549969792366, 82.43127197027206, 108.69757533073425, 49.93208706378937, 65.49526914954185, 66.60208895802498, 44.5156829059124, 48.4391737729311, 45.97351647913456, 38.793474957346916, 53.92736367881298, 50.091617703437805, 30.41618037968874, 54.688124656677246, 40.39925739169121, 47.87894323468208, 46.91835857927799, 54.171709567308426, 37.769467905163765, 48.21741387248039, 40.77783867716789, 58.435403779149055, 27.33847662806511, 73.55376273393631, 84.23985332250595, 75.38119867444038, 67.02927723526955, 101.82454213500023, 105.11286288499832, 127.73373305797577, 117.9375471174717, 136.2285876274109, 132.5748708844185, 140.40210127830505, 157.37746238708496, 149.9664768576622, 145.88959962129593, 146.7441889643669, 120.37982806563377, 61.53060369193554, 8.765639439225197, 0.31144319276791066, 0.785542179364711, 0.30253368022385985, 0.13695326051674783, 0.20911852800054476, 0.13563094631535932, 0.18226574000436813, 0.4736849572509527, 0.21831372287124395, 0.21918970945989713, 0.2238975974614732, 0.13522413064492866, 0.20669811725383624, 0.19291644974146038, 0.1633930136449635, 0.1405160443391651, 0.14237280876841396, 0.14332167425891384, 0.17728805163642392, 0.10696580400690436, 0.09113293679547496, 0.15848936192924157, 0.14164681022521108, 0.16674027778208256, 0.1640200096881017, 0.18240416538901627, 0.20638323883758858, 0.13939730124548078, 0.16805036138975993, 0.1858983896090649, 0.10112550997291692, 0.193716692738235, 0.14854122855467722, 0.18392509315162897, 0.10912472644122317, 0.16106681112432852, 0.17248773656319827, 0.15131197753362358, 0.15171383565757424, 0.10911183533607982, 0.1349229077459313, 0.08520631614373997, 0.20953655010089278, 0.10063652371172793, 0.09434754203539342, 0.10790868036565371, 0.15192545164609328, 0.15897241100901738, 0.20302120596170425, 0.09425670315977186, 0.2878872473957017, 0.07424532188451849, 0.1399009968736209, 0.08649041716125794, 0.17174904729472473, 0.08850672107655555, 0.12230437860125676, 0.11763793954742141, 0.1910005064564757, 0.1349806468351744, 0.15835294034332037, 0.095114195428323, 0.15574525605188683, 0.06806450081057847, 0.19815835752524436], [0.05271225956676062, 0.07319289710721932, 0.022297815812635235, 0.032694926267140545, 0.007284480943781091, 0.07518283251556568, 0.00789688265285804, 0.04584804664773401, 0.03216400866222102, 0.045408290752675384, 0.05629233543004375, 0.06467561703175306, 0.061539375165011734, 0.018318470065423753, 0.06839066729298793, 0.029739805540884845, 0.028309353001532145, 0.023596605788043234, 0.024505050205334555, 0.0315461781428894, 0.052475803895504214, 0.053083125603734516, 0.10803999597555958, 0.06144187551399227, 0.040642285166541114, 0.013388625175139168, 0.08000450659892522, 0.06035669233824592, 0.031836929338169284, 0.03659447444078978, 0.035671702862600796, 0.024642893004056532, 0.04533249892119784, 0.06540289206895977, 0.06080292347178329, 0.03954483057896141, 0.06400386948371306, 0.07710427511483431, 0.011805934955191333, 0.026983120260410942, 0.004927923191644368, 0.090041957446374, 0.03752232230908703, 0.02336066034331452, 0.04109855384740513, 0.11065784026868641, 0.0291960116737755, 0.08793153436272405, 0.03784524931688793, 0.010824835208040895, 0.008777391703915782, 0.05858278498635627, 0.10818821770953946, 0.28110971732530743, 0.04177032737061381, 1.30080652423203, 13.19693885743618, 47.87031389772892, 84.77958396077156, 80.1436199247837, 86.80646359920502, 84.0472112596035, 84.25535649061203, 81.66378915309906, 80.41701525449753, 94.3358963727951, 82.75747686624527, 76.7628501355648, 71.90087422728539, 37.26582393050194, 32.26145826280117, 26.199814528226852, 39.128533378243446, 53.135501369833946, 45.47738470137119, 66.036656498909, 65.58605387806892, 86.0044938325882, 74.6914292871952, 101.42323046922684, 71.50950282812119, 88.36864337325096, 105.29356598854065, 81.07286766171455, 91.45124316215515, 94.20694649219513, 87.31669262051582, 102.26945266127586, 103.16525459289551, 99.48952943086624, 134.28927809000015, 98.64308685064316, 109.90882873535156, 68.91902223229408, 49.46626625955105, 83.68709698319435, 71.69612601399422, 31.913358941674232, 36.838126480579376, 47.15037412941456, 42.102227210998535, 48.882644176483154, 55.053520649671555, 71.47986441850662, 72.9752741754055, 95.3426219522953, 98.52464720606804, 96.04660257697105, 99.71852794289589, 109.33971807360649, 101.84464305639267, 49.70939241349697, 14.8496307246387, 1.9223093683831394, 0.26669153943657875, 0.3732422454049811, 0.049716780849848874, 0.027927388146054, 0.12097822749637999, 0.018842821518774144, 0.027135421951243188, 0.04006010000011884, 0.03368498837517109, 0.033207457163371146, 0.017201834671141114, 0.07108276346116327, 0.07965709985001013, 0.04181841854006052, 0.08593395483330823, 0.04244748146447819, 0.066490272001829, 0.05421275971457362, 0.056579394440632313, 0.024800632781989407, 0.047460559144383296, 0.07433437218423933, 0.05339568480849266, 0.12445044703781605, 0.07193595127318986, 0.13346486957743764, 0.0053450296672963304, 0.044139418605482206, 0.08419821242569014, 0.026897116476902738, 0.03521067701512948, 0.026796748425113037, 0.05824564585054759, 0.022582566743949428, 0.025200928685080726, 0.046877475979272276, 0.011694507975335, 0.00330773317728017, 0.08881955116521567, 0.011091982396465028, 0.07573992566904053, 0.07970697959535755, 0.018701473927649204, 0.009048581741808448, 0.03760191764740739, 0.012380759872030467, 0.0372787012020126, 0.03355405497131869, 0.03792668147070799, 0.05291958594170865, 0.05247236775176134, 0.06968964837142266, 0.020778433572559152, 0.023375482887786347, 0.03384425326657947, 0.03285918581241276, 0.04372166367829777, 0.012171963116998086, 0.02983797683555167, 0.0704766514536459, 0.03436068414885085, 0.07484039815608412, 0.02410248518572189, 0.02699108350498136, 0.10610198864014819, 0.0846162271045614, 0.028556415818457026, 0.04434738322743215, 0.018157407321268693, 0.1016468316083774, 0.014597168137697736, 0.0828203781566117, 0.03166671776853036, 0.018711296252149623, 0.038152758206706494, 0.02143805628293194, 0.1248948450665921, 0.11721127884811722, 0.050951814773725346, 0.04517245848546736, 0.004692757929660729, 0.035604590448201634, 0.03611896187067032, 0.05286717176204547, 0.10917496241745539, 0.08046325034229085, 0.08938254439271986, 0.04871933808317408, 0.0067776372179650934, 0.04075951852428261, 0.013572645329986699, 0.01613763757632114, 0.02914217628131155, 0.03729476127773523, 0.042665988294174895, 0.09730783553095534, 0.05160991051525343, 0.018398468018858694, 0.030500306529575028, 0.0646979408338666, 0.04849529483180959, 0.03458014834905043, 0.036235620063962415, 0.04839721259486396, 0.041095084307016805, 0.05341492127627134, 0.07567532171378843, 0.06674061325611547, 0.04352617455879226, 0.005017577877879376, 0.046362499706447124, 0.03457867889665067, 0.12864037533290684, 0.03912564330676105, 0.06785452496842481, 0.2712405187776312, 0.07610811255290173, 0.9121038881130517, 11.736921351402998, 51.50569662451744, 98.98572206497192, 94.2500513792038, 103.12162533402443, 95.11182993650436, 102.24882736802101, 97.39262714982033, 115.81515580415726, 141.59827709197998, 109.16363552212715, 112.56053164601326, 115.60324877500534, 55.59719167649746, 53.24330538511276, 25.211614854633808, 43.90055291354656, 22.378560975193977, 26.548863798379898, 38.5650198161602, 28.68265450000763, 42.84563831984997, 37.88854591548443, 36.07021048665047, 45.44314853847027, 43.3793842792511, 33.57158236205578, 41.92545689642429, 31.920589953660965, 50.05994260311127, 28.16182404756546, 53.04480403661728, 42.53493279218674, 50.996208563447, 56.25700727105141, 55.57746693491936, 25.899256356060505, 47.38765239715576, 39.80835869908333, 52.544788867235184, 43.617452904582024, 40.32631270587444, 41.329200491309166, 74.12989541888237, 68.21409925818443, 86.8309798836708, 106.34965091943741, 110.46818152070045, 106.31704106926918, 123.91607791185379, 119.1850733757019, 119.8191225528717, 118.40348571538925, 128.5224947333336, 117.7284899353981, 63.25806699693203, 17.440211065113544, 1.6925767832435668, 0.10753121663583443, 0.27206118567846715, 0.08902819856302813, 0.06463268378865905, 0.11164502284373157, 0.03881176307913847, 0.027014730185328517, 0.04757583694299683, 0.07170692450017668, 0.06125470215920359, 0.0416431158373598, 0.052858841154375114, 0.034204792318632826, 0.03843465558020398, 0.024134291779773775, 0.04490253937547095, 0.05850559420650825, 0.023537406523246318, 0.024751292949076742, 0.046954317949712276, 0.04117530304938555, 0.004013959514850285, 0.02377692911977647, 0.06442664875066839, 0.020868806750513613, 0.061783808923792094, 0.061011240613879636, 0.02374902251176536, 0.041003610895131715, 0.04414830582391005, 0.011390472336643143, 0.020911495084874332, 0.026698916663008276, 0.09110244194744155, 0.02792270704958355, 0.03550802961399313, 0.029332646627153736, 0.027590191493800376, 0.0122329333316884, 0.1070485905802343, 0.028109375743952114, 0.06285577444941737, 0.033947723495657556, 0.033527378473081626, 0.05266001608106308, 0.07107719735358842, 0.013418114413070725, 0.020965054027328733, 0.003844436519102601, 0.046915826460462995, 0.034753974177874625, 0.10754048606031574, 0.02821343226969475, 0.03391884281882085, 0.03465910915110726, 0.049410403735237196, 0.044733975373674184, 0.03284057274868246, 0.04680127967731096, 0.029742319566139486, 0.013108090570312925, 0.06132705413619988, 0.1364114333409816, 0.13488109514582902, 0.1967601216165349, 0.1486904447665438, 0.10393970427685417, 0.17513378988951445, 0.11806460766820237, 0.13798199594020844, 0.099117859499529, 0.18244826380396262, 0.10651883814716712, 0.12350875811534934, 0.12117488178773783, 0.12244981728144921, 0.23000513145234436, 0.28549765062052757, 0.13686268881428987, 0.15648642409360036, 0.14602126611862332, 0.253587081679143, 0.11665200378047302, 0.16860161384101957, 0.22560766898095608, 0.14785989245865494, 0.1402551942737773, 0.0825239421101287, 0.15392702393000945, 0.11798435923992656, 0.17120616626925766, 0.18274748290423304, 0.16653186787152663, 0.13311985996551812, 0.17928880755789578, 0.1877427304862067, 0.13657092087669298, 0.1683117903303355, 0.13986105448566377, 0.1484018235350959, 0.14271787775214761, 0.23698779114056379, 0.11668150415061973, 0.16098524909466505, 0.1334132903139107, 0.12525641941465437, 0.13560142368078232, 0.2062884665792808, 0.1156314839317929, 0.18279260548297316, 0.23834054823964834, 0.12946012197062373, 0.24978209054097533, 0.12779967044480145, 0.32807564246468246, 0.41940997587516904, 0.14421380998101085, 4.361378895118833, 25.081270448863506, 79.52959567308426, 121.76256626844406, 105.29735818505287, 111.50627061724663, 106.44837722182274, 106.09682768583298, 103.63339707255363, 104.7411136329174, 116.47423043847084, 108.63408833742142, 95.23734480142593, 92.19120025634766, 51.88899725675583, 45.8392658829689, 35.94003327190876, 58.31621177494526, 76.99208423495293, 64.50364395976067, 95.5163486301899, 99.17185127735138, 128.49667131900787, 113.11497509479523, 150.47525435686111, 110.5544064939022, 129.59704667329788, 152.80498534440994, 114.04688268899918, 134.77934539318085, 134.21028792858124, 125.79935565590858, 150.550277531147, 147.20060527324677, 137.15623944997787, 178.0214810371399, 133.16006988286972, 156.2937757372856, 100.6644643843174, 77.62680977582932, 109.78447660803795, 105.36352783441544, 45.338597148656845, 48.57258841395378, 67.68671795725822, 54.94383953511715, 70.55905982851982, 81.1290742456913, 97.9234130680561, 95.1743745803833, 119.75716307759285, 123.13803926110268, 126.05657905340195, 125.84280252456665, 142.21337288618088, 136.10817968845367, 85.2451653778553, 27.77868300676346, 3.828868344426155, 0.346874866518192, 0.4408296343171969, 0.18631366576300934, 0.2733494946733117, 0.1468942841165699, 0.2172163684736006, 0.15235687693348154, 0.15201351488940418, 0.19239589251810685, 0.21535782288992777, 0.13134047185303643, 0.15321769402362406, 0.19773178588366136, 0.09876144307781942, 0.1385719291283749, 0.10203348312643357, 0.16830617969390005, 0.11874825184349902, 0.14454767253482714, 0.1704656661604531, 0.11864399493788369, 0.1478226514882408, 0.09803699562326074, 0.24894153408240527, 0.14668045652797446, 0.16583524353336543, 0.13926055311458185, 0.11135740351164714, 0.19755001907469705, 0.10180444151046686, 0.11494819598738104, 0.1068069992470555, 0.12429564245394431, 0.14590284903533757, 0.14340703608468175, 0.11897623960976489, 0.06762488963431679, 0.12984482164029032, 0.17199869093019515, 0.30450402293354273, 0.10531427309615538, 0.31444903928786516, 0.08969034272013232, 0.18583924043923616, 0.0962782911665272, 0.21811861224705353, 0.12621433910680935, 0.12316567066591233, 0.1407287290203385, 0.10774222406325862, 0.1263584048138, 0.2582240797346458, 0.0987350448849611, 0.1161522934853565, 0.09091320913285017, 0.18019688461208716, 0.10316054569557309, 0.08643552049761638, 0.1338405892602168, 0.24675417254911736, 0.15994131448678672, 0.18165272602345794], [0.050495457035140134, 0.010034194674517494, 0.014236078040994471, 0.02387375156104099, 0.01761080256983405, 0.06078433638322167, 0.06513723288662732, 0.046382641594391316, 0.04007508025097195, 0.06449852575315163, 0.052360852641868405, 0.015528324129263638, 0.025855252461042255, 0.03244541250751354, 0.053492097213165835, 0.07727385585894808, 0.07653987180674449, 0.031912684062263, 0.05955064574663993, 0.02198246798798209, 0.029464205290423706, 0.06858013759483583, 0.017803196933527943, 0.03587001956475433, 0.033720455612638034, 0.014864062068227213, 0.06235641296370886, 0.03356912056915462, 0.03924374497728422, 0.0998789096774999, 0.07604426558827981, 0.0908912712475285, 0.006297990885286708, 0.035025377583224326, 0.03519694357237313, 0.008650896343169734, 0.018127489493053872, 0.057841535308398306, 0.023747078084852546, 0.020349373880890198, 0.03266649458964821, 0.026088947342941537, 0.015751154896861408, 0.029602487811644096, 0.06607056522625498, 0.00948526421780116, 0.07361690833931789, 0.05342016083886847, 0.09759313936228864, 0.012561161129269749, 0.04371895112853963, 0.10054286467493512, 1.0024676704779267, 10.9118621237576, 31.367180049419403, 69.76380810141563, 78.41523706912994, 82.37562015652657, 73.33140626549721, 78.8281001150608, 82.62354925274849, 85.01866713166237, 56.05413615703583, 38.56273993849754, 41.91509485244751, 23.038000389933586, 33.94932769238949, 34.65450145304203, 26.123453825712204, 65.53073644638062, 75.4527260363102, 120.79844400286674, 103.31140995025635, 91.76250725984573, 110.87752595543861, 62.53386005759239, 58.867360800504684, 47.71477684378624, 49.84798237681389, 70.78616604208946, 64.84301134943962, 64.24031049013138, 71.01793840527534, 90.42630136013031, 107.50079914927483, 81.33847340941429, 88.49667370319366, 57.76807598769665, 69.12306368350983, 77.86243513226509, 79.47742447257042, 67.16692864894867, 97.08576321601868, 66.65366739034653, 81.06351256370544, 113.18555250763893, 92.11769700050354, 104.70623910427094, 156.8324500322342, 94.44775477051735, 85.76598063111305, 61.41019955277443, 41.209335923194885, 44.86655227839947, 35.51124528050423, 38.767491951584816, 61.92765958607197, 67.64573335647583, 85.79738974571228, 84.7382877767086, 82.35074669122696, 93.63256931304932, 92.90039420127869, 82.83444553613663, 55.35450629889965, 13.18632697686553, 1.2137983180582523, 0.2842585608595982, 0.4148428881308064, 0.25272147031500936, 0.14174955314956605, 0.035970840326626785, 0.07940459152450785, 0.12909182376461104, 0.03178376930009108, 0.05710580349841621, 0.05669237900292501, 0.05848697372130118, 0.018961171808768995, 0.018449464696459472, 0.030415681285376195, 0.09071694817976095, 0.03997424464614596, 0.013210326051193988, 0.0467204226879403, 0.018054675529128872, 0.05171210796106607, 0.06021721310389694, 0.03284915568656288, 0.04205134158837609, 0.05034513873397373, 0.01841074499679962, 0.05249649126199074, 0.0355964750633575, 0.031006577410153113, 0.05653355940012261, 0.01975543866137741, 0.026870304536714684, 0.0253162417357089, 0.027801859432656784, 0.05564360188145656, 0.07278173245140351, 0.08733496637432836, 0.05995987339701969, 0.03763160726521164, 0.08108367837849073, 0.028483429305197205, 0.04736752722237725, 0.06027954979799688, 0.04930567927658558, 0.0510669998038793, 0.033153554977616295, 0.07530074493843131, 0.007633542682015104, 0.06972882634727284, 0.05708951335691381, 0.011696894907800015, 0.03839110264379997, 0.049828106712084264, 0.03326322585053276, 0.026053578440041747, 0.023210733525047544, 0.060517849706229754, 0.08781621203524992, 0.05951807659585029, 0.029325805880944245, 0.05288649357680697, 0.04471642729185987, 0.04077145225892309, 0.021418701071524993, 0.03554951566911768, 0.06740736615029164, 0.016322677256539464, 0.05198442791879643, 0.03241956350393593, 0.023255626038007904, 0.06261030910536647, 0.014621079208154697, 0.02538679585995851, 0.012935014310642146, 0.06641410538577475, 0.029770907094643917, 0.06442699013859965, 0.02808202574669849, 0.01728605173411779, 0.07353320892434567, 0.04187384955002926, 0.03783658845350146, 0.030016416967555415, 0.02010843007155927, 0.018426927526888903, 0.014659084590675775, 0.07790417672367766, 0.03797490993747488, 0.016108827403513715, 0.048620387533446774, 0.10065961934742518, 0.040083518470055424, 0.08611290890257806, 0.018874004708777647, 0.04886785667622462, 0.042598386062309146, 0.040180984724429436, 0.05483106149767991, 0.010030889334302628, 0.04938213161949534, 0.02572927845903905, 0.029571675695478916, 0.0731912198534701, 0.04586753173498437, 0.0324460841511609, 0.026401983377581928, 0.07983878502273001, 0.056251569258165546, 0.088722804794088, 0.051613483956316486, 0.17892135540023446, 0.06327639406663366, 0.655121065210551, 8.933680672198534, 33.04235436022282, 71.95372179150581, 95.60789331793785, 96.66644811630249, 90.7818178832531, 100.02007976174355, 109.13499265909195, 114.1372038424015, 93.50428819656372, 74.90088164806366, 69.12790462374687, 41.100285574793816, 58.651558980345726, 43.02105590701103, 28.43531247228384, 38.4539707750082, 45.619641467928886, 82.22135603427887, 88.69824528694153, 80.54591193795204, 84.07528415322304, 74.53683838248253, 68.63158285617828, 59.75777082145214, 56.964012533426285, 70.97140610218048, 63.807414919137955, 66.3643205165863, 74.73663926124573, 83.74894246459007, 88.60262721776962, 79.45369094610214, 78.7137034535408, 59.307380989193916, 67.08100765943527, 68.85924383997917, 73.35205435752869, 71.82648941874504, 95.37493541836739, 70.08293777704239, 78.66226941347122, 85.79662218689919, 82.26243942975998, 71.85264721512794, 95.82251340150833, 64.29946571588516, 39.744788110256195, 34.82582286000252, 32.02743262052536, 54.97776411473751, 56.12825497984886, 70.9675607085228, 100.29595255851746, 111.23179614543915, 112.0329375565052, 103.41668710112572, 94.7463807463646, 109.27537232637405, 109.97496038675308, 101.00822433829308, 63.38236212730408, 15.56998087093234, 1.069935425184667, 0.07314236427191645, 0.3638880082871765, 0.2969503548229113, 0.12222335091792047, 0.07547313842223957, 0.052308189842733555, 0.05759900886914693, 0.05940409013419412, 0.052653310776804574, 0.03779554026550613, 0.035320533424965106, 0.010923218014795566, 0.01718158517178381, 0.06430198278394528, 0.037079341782373376, 0.07066441481583752, 0.027046918985433877, 0.04830012112506665, 0.024494947720086202, 0.01611672756553162, 0.07016575837042183, 0.04645604742108844, 0.11233519791858271, 0.06135618343250826, 0.04003560170531273, 0.0333945266174851, 0.03928693797206506, 0.0504693928087363, 0.014500809538731119, 0.013295745393406833, 0.024095230692182668, 0.08714473908185028, 0.03908411643351428, 0.03631216146459337, 0.06287249503657222, 0.01952426893694792, 0.044996391370659694, 0.07718082764768042, 0.02581679251306923, 0.02595767811726546, 0.01000042231680709, 0.06073621923860628, 0.027840705297421664, 0.07357794558629394, 0.04276364379620645, 0.027958745740761515, 0.046413221789407544, 0.06286396775976755, 0.0513961237447802, 0.022845142302685417, 0.027852115817950107, 0.05097529632621445, 0.04532236860541161, 0.03899799019563943, 0.013701733569178032, 0.0358476957626408, 0.018152557386201806, 0.04650299568311311, 0.04466055099328514, 0.18165704532293603, 0.13784322916762903, 0.13730998121900484, 0.13879864040063694, 0.11507514776894823, 0.15138335729716346, 0.15800221619429067, 0.1531049024197273, 0.099043718946632, 0.23690844071097672, 0.1258842763490975, 0.0997402764915023, 0.10562808281974867, 0.11053277354221791, 0.1850760157685727, 0.2052757318597287, 0.15713035594671965, 0.15398427320178598, 0.2188040895271115, 0.13065592967905104, 0.0912829842127394, 0.18268992193043232, 0.12135808836319484, 0.12620055000297725, 0.22255475545534864, 0.1036014556302689, 0.14401207939954475, 0.18946084688650444, 0.15347115229815245, 0.1708084048004821, 0.2190106440684758, 0.25934531644452363, 0.18521034449804574, 0.07578787583042867, 0.16215186071349308, 0.18949231394799426, 0.10564874421106651, 0.1687013139599003, 0.10371795055107214, 0.13810773059958592, 0.16198496654396877, 0.15223382884869352, 0.15517447027377784, 0.33388659940101206, 0.1547512531396933, 0.15843684755964205, 0.2997219795361161, 0.1976892162929289, 0.2075030209380202, 0.18710589356487617, 0.617770078824833, 0.18835703580407426, 4.666191413998604, 24.91783171892166, 61.52395784854889, 107.79684126377106, 114.85560849308968, 111.31936624646187, 95.88726192712784, 101.4087076485157, 107.1917313337326, 107.18578845262527, 79.69877779483795, 53.833554312586784, 57.99542158842087, 31.43649782985449, 50.11608839035034, 51.60868249833584, 37.61072762310505, 102.5025549530983, 122.41368412971497, 178.1426641345024, 158.97973001003265, 143.14178466796875, 174.59091871976852, 107.13292568922043, 98.07044237852097, 77.17967256903648, 74.05541181564331, 108.75330314040184, 103.27259883284569, 101.99215114116669, 107.44331583380699, 142.45982766151428, 165.0566679239273, 130.74422031641006, 138.1761047244072, 93.07368770241737, 108.98452073335648, 121.1190328001976, 121.45419001579285, 103.39057490229607, 152.13482290506363, 102.67078712582588, 119.94401425123215, 162.15494602918625, 137.09339082241058, 162.067611515522, 231.7094385623932, 137.2420996427536, 127.25434318184853, 87.49120965600014, 62.59320147335529, 57.15453051030636, 52.60678254067898, 54.422275722026825, 81.11539497971535, 85.94100683927536, 112.9948103427887, 110.45052766799927, 104.22261625528336, 119.33420017361641, 127.5687763094902, 119.110376983881, 84.53852489590645, 25.917839258909225, 2.8203494986519217, 0.6960672524292022, 0.5013234866783023, 0.6423288735095412, 0.45634954527486116, 0.206468838150613, 0.2796080260304734, 0.2510690042981878, 0.27217078604735434, 0.16607886092970148, 0.19080403028056026, 0.18188555259257555, 0.15010520088253543, 0.2318217308493331, 0.1668034345493652, 0.205631458084099, 0.23939209728268906, 0.13483995047863573, 0.19448891223873943, 0.11599434219533578, 0.1132117782253772, 0.1537134635145776, 0.09857970595476218, 0.22813380608567968, 0.15133032342419028, 0.15149607468629256, 0.10604150360450149, 0.09416025364771485, 0.10337153828004375, 0.1458652815199457, 0.1493691239738837, 0.17011479358188808, 0.1532988849794492, 0.12340256420429796, 0.09498686515144072, 0.21096880605909973, 0.24949051556177437, 0.17073739611078054, 0.18167206639191136, 0.12621653586393222, 0.1331250846851617, 0.13348288892302662, 0.1938999883714132, 0.11216028855415061, 0.20059877657331526, 0.1304859184892848, 0.19617051497334614, 0.14205665385816246, 0.3002101939637214, 0.15208376658847556, 0.1330996587057598, 0.11969250117545016, 0.19907145149772987, 0.24474528268910944, 0.10558680456597358, 0.19881702843122184, 0.1840182178420946, 0.19363257772056386, 0.1647589958156459, 0.09293090828577988], [0.020080710855836514, 0.05119161382026505, 0.01756628855218878, 0.07081708943587728, 0.010472419889993034, 0.016498692421009764, 0.008210208125092322, 0.01534819190055714, 0.016232602793024853, 0.04935824930726085, 0.01576711849338608, 0.06337780854664743, 0.0039060275867086602, 0.03858225762087386, 0.07695057633100078, 0.06015269820636604, 0.02889673505706014, 0.02276400144182844, 0.02321416966879042, 0.020827728876611218, 0.015264679877873277, 0.01562882483995054, 0.06542970586451702, 0.02882335706090089, 0.047542139727738686, 0.0054079053461464355, 0.02649237881996669, 0.04487661615712568, 0.029068738913338166, 0.04743780860735569, 0.02881100030208472, 0.01577740280481521, 0.021690635112463497, 0.03479800951026846, 0.04830840720387641, 0.08584114926634356, 0.04508760503085796, 0.07386894169030711, 0.0071631226364843315, 0.003805167398240883, 0.041743888359633274, 0.06314520462183282, 0.026805086454260163, 0.023219023314595688, 0.05505380227987189, 0.03545838735590223, 0.06731595582095906, 0.08512693602824584, 0.12555835477542132, 0.19192609819583595, 2.919202856719494, 24.4009093567729, 47.897824421525, 75.78340709209442, 82.56441682577133, 72.54516005516052, 81.33278891444206, 75.5260469019413, 70.74480146169662, 25.719497501850128, 35.66384129226208, 35.140221789479256, 28.69029588997364, 44.88589324057102, 93.9316588640213, 123.98491501808167, 84.81002792716026, 103.88827219605446, 108.0284996330738, 63.22006903588772, 47.20068722963333, 19.914341904222965, 9.325974471867085, 3.614128567278385, 0.9095427661668509, 0.6621159554924816, 0.45854463998693973, 0.7690667978022248, 0.8114505547564477, 1.693321424536407, 0.46217104070819914, 0.7852377800736576, 1.0382105712778866, 1.125923995859921, 1.0073840129189193, 0.41001946257892996, 0.8101747732143849, 0.6768917595036328, 1.5717921894975007, 1.1391510860994458, 1.6704308590851724, 0.6620713672600687, 1.502200704999268, 0.37807546730618924, 0.6140700867399573, 0.6856965401675552, 2.833356438204646, 8.597186878323555, 19.882131032645702, 56.180574372410774, 86.5297320485115, 103.51939558982849, 147.2917091846466, 113.48008990287781, 74.45093259215355, 51.296525448560715, 38.89656722545624, 33.4620076417923, 41.90819822251797, 54.4875980168581, 74.54261407256126, 78.34190860390663, 91.55379205942154, 78.27279791235924, 91.40882983803749, 94.66847732663155, 71.18626177310944, 47.936415150761604, 31.122060902416706, 12.093498017638922, 3.349839448928833, 0.5913747358135879, 0.4127150616841391, 0.13159902126062661, 0.03485914021439385, 0.03141626890283078, 0.009984185981011251, 0.02130338987626601, 0.058059285147464834, 0.10264642289257608, 0.05069797800388187, 0.031076524828677066, 0.04514273918175604, 0.050805544888135046, 0.012550563260447234, 0.018162812011723872, 0.07711371523328125, 0.035317813453730196, 0.06828077006503008, 0.010037497231678572, 0.05786321715277154, 0.029591479906230234, 0.03132013480353635, 0.041568504020688124, 0.020017789720441215, 0.030326133746712003, 0.02949516027001664, 0.019248434909968637, 0.02075836218864424, 0.03789138492720667, 0.0077758216684742365, 0.04674712887208443, 0.044074176403228194, 0.027217444112466183, 0.010661596115824068, 0.04328715476731304, 0.035966480209026486, 0.028331871617410798, 0.049940616299863905, 0.031195583869703114, 0.01579763560584979, 0.018142872359021567, 0.036887418682454154, 0.040853095924830996, 0.023259605804923922, 0.06318344007013366, 0.07796224977937527, 0.03566672676242888, 0.04725073915324174, 0.07034610025584698, 0.04160089876677375, 0.03580645832698792, 0.029487616338883527, 0.055508868681499735, 0.0624008230806794, 0.02019317962549394, 0.017449884544475935, 0.05046034973929636, 0.039229106114362366, 0.00790932939708, 0.029538108356064186, 0.02389307523117168, 0.05346520178136416, 0.005468172375913127, 0.01941783382790163, 0.04323531575209927, 0.03441126893449109, 0.010992019742843695, 0.005829898400406819, 0.049986473604803905, 0.01313496652073809, 0.06999012912274338, 0.06744756828993559, 0.04553301238047425, 0.033081199289881624, 0.06966057102545165, 0.019957952208642382, 0.05099045098177157, 0.053746238263556734, 0.023232764178828802, 0.046356440070667304, 0.007414492229145253, 0.03311723055958282, 0.0564671891334001, 0.047196592058753595, 0.024455198290525004, 0.025061865053430665, 0.042138759163208306, 0.02675655370694585, 0.05633255612337962, 0.059997184871463105, 0.12062614521710202, 0.041745253911358304, 0.07224704473628663, 0.060237855941522866, 0.026891730340139475, 0.05103489449538756, 0.0574029037670698, 0.07722849579295143, 0.029900525041739456, 0.06101715182012413, 0.035070006633759476, 0.02675439405720681, 0.018691449367906898, 0.09174808074021712, 0.3874822781654075, 1.44390185829252, 23.612208478152752, 52.760001718997955, 87.9002121090889, 95.57459190487862, 86.05273604393005, 90.22850677371025, 89.3823453783989, 103.80259439349174, 61.95362739264965, 59.48146104812622, 67.7466407418251, 46.01276837289333, 40.47110013663769, 66.55121728777885, 44.40773069858551, 51.45279586315155, 71.77342906594276, 83.08081671595573, 69.69599694013596, 58.276222720742226, 31.25656608492136, 14.70629196614027, 5.095842909067869, 1.6413807054050267, 0.4388247668975964, 0.05769296105427202, 0.639036528300494, 0.40306182811036706, 0.764216179959476, 0.1207717323268298, 0.32462649629451334, 0.36808414093684405, 0.24885311460820958, 0.03620041999965906, 0.15620154328644276, 0.17358437849907205, 0.4276778572238982, 1.1674156319350004, 0.7126426161266863, 0.9259474358987063, 0.5301601393148303, 0.18610225757583976, 0.24612438603071496, 0.7943109807092696, 1.3365035899914801, 4.140646364539862, 13.119424916803837, 28.745250441133976, 61.39171354472637, 80.50286024808884, 86.68880671262741, 96.28427222371101, 67.81776532530785, 44.05531860888004, 22.364032454788685, 35.85241757333279, 43.5090447217226, 73.96446749567986, 88.8975977897644, 102.07968324422836, 100.88476896286011, 104.09147009253502, 93.19737106561661, 106.49867132306099, 112.32202604413033, 83.18822175264359, 54.73077356815338, 33.32169637084007, 14.099196642637253, 2.988073923625052, 0.15363124839495867, 0.2908285864396021, 0.09835315053351223, 0.01799832611141028, 0.08027215473703109, 0.025134050047199707, 0.013187532840674976, 0.021444882186187897, 0.057118342083413154, 0.06850011923233978, 0.030880035665177274, 0.06487978185759857, 0.02996687118866248, 0.011060727774747647, 0.05181693260965403, 0.06448151572840288, 0.019302049513498787, 0.06744373880792409, 0.03267655811214354, 0.035515102281351574, 0.03971639656811021, 0.05253802184597589, 0.028960300005564932, 0.050488915003370494, 0.022088968034950085, 0.017423844437871594, 0.06866691692266613, 0.02175458226702176, 0.013773181981378002, 0.1137312593345996, 0.014654773640359053, 0.020373985353216995, 0.018808899803843815, 0.01583079847478075, 0.03642544288595673, 0.026083702214236837, 0.022712390637025237, 0.10169824759941548, 0.0038261179952314706, 0.02521731901651947, 0.08031220102566294, 0.02994857724843314, 0.02272662317409413, 0.03746460177353583, 0.018231395733891986, 0.04402646372909658, 0.07995656385901384, 0.030721455405000597, 0.0475466074567521, 0.04764928358781617, 0.0185605604929151, 0.018947896642202977, 0.06368156959069893, 0.04481595300603658, 0.034628866633283906, 0.12150623588240705, 0.19721393007785082, 0.21543457580264658, 0.255453820573166, 0.09888633168884553, 0.11944479454541579, 0.13009200134547427, 0.12524672696599737, 0.12956382968695834, 0.12129242313676514, 0.11974966138950549, 0.12039347449899651, 0.142792864353396, 0.18785590800689533, 0.14408170769456774, 0.17178937559947371, 0.1728059398010373, 0.12430324204615317, 0.1399335771566257, 0.11976742098340765, 0.14238253090297803, 0.14470211346633732, 0.19287028815597296, 0.13122321252012625, 0.22906913480255753, 0.1250308213639073, 0.13014861237024888, 0.16464584798086435, 0.15355746407294646, 0.12229473068146035, 0.09580465251929127, 0.13265517161926255, 0.17128876730566844, 0.21773829124867916, 0.17193758249050006, 0.35730563336983323, 0.13839747989550233, 0.1348605376551859, 0.2285965351620689, 0.12154788521002047, 0.19758490001549944, 0.24044471501838416, 0.16239587886957452, 0.25415568554308265, 0.20552579109789804, 0.17178183537907898, 0.22281597659457475, 0.12269399871001951, 0.3047400852665305, 1.0078008030541241, 9.954114966094494, 50.76155215501785, 85.38616821169853, 114.56715077161789, 109.21304807066917, 94.2322227358818, 103.41790303587914, 100.58792129158974, 94.06905189156532, 39.192160964012146, 52.15731605887413, 47.765435725450516, 40.83656072616577, 60.54615631699562, 115.20561531186104, 164.49162304401398, 116.6467259824276, 148.05150121450424, 165.40302693843842, 98.66640999913216, 77.64588475227356, 33.961046263575554, 18.11258878558874, 6.238075392320752, 1.2679468374699354, 1.2498310720548034, 0.7933022535871714, 0.97189647029154, 0.9128739405423403, 1.966182051692158, 0.9513838647399098, 0.9875503240618855, 1.0286050429567695, 1.2649263557977974, 1.0237737209536135, 0.8747077197767794, 1.1640176642686129, 1.265089272055775, 2.1051471261307597, 1.6309481277130544, 2.2796380380168557, 1.0539602511562407, 1.6987140476703644, 0.6516992300748825, 1.4723699307069182, 2.170154512859881, 5.118479719385505, 15.902985502034426, 31.326398737728596, 89.46249067783356, 133.82448703050613, 158.16506892442703, 212.95317381620407, 162.4461168050766, 104.47015017271042, 74.93765607476234, 58.29891890287399, 49.119139686226845, 56.64413429796696, 72.48671159148216, 100.02391755580902, 104.30939599871635, 113.77439931035042, 96.07660576701164, 115.58370262384415, 128.92396599054337, 104.80640932917595, 71.08489841222763, 48.98659139871597, 25.348293520510197, 8.80091579630971, 1.5204386576078832, 0.5536719120573252, 0.15415578352985904, 0.08423666309681721, 0.14248769322875887, 0.11639349890174344, 0.16982146713417023, 0.10436990502057597, 0.3176735225133598, 0.1617755918414332, 0.11336907642544247, 0.11047734253224917, 0.07422025213600136, 0.17440975061617792, 0.17741844698321074, 0.0966030327253975, 0.08923034474719316, 0.20935068663675338, 0.13890789938159287, 0.14317548600956798, 0.1418981608003378, 0.10723948580562137, 0.1757454828475602, 0.1581574883311987, 0.19827536452794448, 0.09272190465708263, 0.17374490504153073, 0.07800121995387599, 0.0823354885505978, 0.21541807043831795, 0.1996456808410585, 0.17318277270533144, 0.10145872685825452, 0.13688290491700172, 0.1088932654238306, 0.14007057761773467, 0.0906383918481879, 0.19523968367138878, 0.1168290653731674, 0.08239055590820499, 0.18654950545169413, 0.1412672462174669, 0.10997848570696078, 0.10164462742977776, 0.13885066495276988, 0.1378985191695392, 0.11694615401211195, 0.13811020937282592, 0.15798863489180803, 0.18700864253332838, 0.14201504905940965, 0.10784464044263586, 0.17154752451460809, 0.1216198512702249, 0.12093019569874741], [0.031077651037776377, 0.033892066130647436, 0.05075387285614852, 0.010224964662484126, 0.01959375622391235, 0.034318630350753665, 0.04098013676411938, 0.04973577983037103, 0.038851920689921826, 0.07042183642624877, 0.016730077368265484, 0.06328316245344467, 0.020141327622695826, 0.06044105968612712, 0.054907688245293684, 0.04624787499778904, 0.01577607250510482, 0.014202073762135115, 0.03311429907626007, 0.06240016999072395, 0.07205609013908543, 0.10138543235370889, 0.01864394078438636, 0.03853560992865823, 0.02384717525274027, 0.030733880812476855, 0.007441681273121503, 0.0284538398773293, 0.04176775211817585, 0.016859873430803418, 0.006926542655492085, 0.08129272653604858, 0.05056931186118163, 0.11179899622220546, 0.024030845670495182, 0.0017002433969537378, 0.09206619492033496, 0.020490981223701965, 0.08314675986184739, 0.03308565588667989, 0.05331507643859368, 0.02201558632805245, 0.03359155198268127, 0.04835731473576743, 0.05888390769541729, 0.048664571295375936, 0.12741725658997893, 0.5045295646414161, 8.714768718928099, 35.85710272192955, 54.72695857286453, 63.63520435988903, 37.907966673374176, 53.555530831217766, 67.4544820189476, 81.96456581354141, 75.16372874379158, 49.06920276582241, 19.577379785478115, 77.66499012708664, 65.09208038449287, 50.53593926131725, 84.15614381432533, 68.54781255126, 68.09454247355461, 76.39511346817017, 75.14869675040245, 34.086158350110054, 7.449120283126831, 1.1871875147335231, 0.5909424496348947, 0.23255856474861503, 0.34041859733406454, 0.14459669881034642, 0.21275781240547076, 0.2057764885830693, 0.3704843355808407, 0.29697929858230054, 0.6517482711933553, 0.8679478231351823, 0.5309006839524955, 0.34960834484081715, 0.821523517370224, 0.5516997585073113, 0.876258808420971, 0.293408262077719, 0.742732904618606, 0.3247424791334197, 1.1155819008126855, 0.6265522388275713, 1.3131797290407121, 0.6362508027814329, 1.0240489686839283, 0.1353740890044719, 0.1252356095938012, 0.022345413453876972, 0.05401829846960027, 0.40643480024300516, 0.42917254264466465, 0.8548780088312924, 0.5404836509842426, 1.4890788216143847, 8.88438306748867, 42.12201654911041, 83.07523861527443, 113.81943449378014, 108.36260050535202, 95.1829469203949, 53.98693688213825, 30.372117944061756, 26.486830227077007, 36.25890076160431, 55.99596127867699, 54.812085404992104, 73.28430399298668, 77.5065766274929, 82.44125783443451, 86.88867598772049, 96.5447710454464, 91.80164515972137, 78.32132890820503, 49.48961600661278, 9.626260958611965, 0.4057170246960595, 0.04656876852095593, 0.009340991637145635, 0.027905030947295018, 0.0655136798741296, 0.07542843144619837, 0.06129613997472916, 0.02929992348072119, 0.02940823065728182, 0.04469374725886155, 0.050248314437340014, 0.04904801673546899, 0.0080303690447181, 0.0877176177164074, 0.026258066100126598, 0.04884227855654899, 0.10283975236234255, 0.025141783225990366, 0.028210398741066456, 0.07604200945934281, 0.0315507163759321, 0.028086055608582683, 0.09571206959662959, 0.04761610587593168, 0.034759321351884864, 0.062403361225733534, 0.060253162737353705, 0.017331589915556833, 0.06331758326268755, 0.13359499775106087, 0.022233744348341133, 0.07022184247034602, 0.07650566622032784, 0.036742388183483854, 0.09671085193986073, 0.05064945267804433, 0.02822854610712966, 0.02295352369401371, 0.0641076588362921, 0.027499207899381872, 0.09786963390070014, 0.050893092338810675, 0.04697397002018988, 0.032434643944725394, 0.07047203529509716, 0.01914390712045133, 0.027347102877683938, 0.02571038708993001, 0.027082883461844176, 0.04661118597141467, 0.02122757949109655, 0.06023856840329245, 0.01126288694649702, 0.018652046892384533, 0.042484280857024714, 0.06288807271630503, 0.008138371940731304, 0.066977128299186, 0.07026008534012362, 0.01711844881356228, 0.07994483050424606, 0.04283819995180238, 0.03821838632575236, 0.03625089717388619, 0.03613102548115421, 0.06831355072790757, 0.028831186718889512, 0.029764923529000953, 0.028392950371198822, 0.05107072909595445, 0.048589506768621504, 0.031142650186666287, 0.040049988238024525, 0.051438793525449, 0.020129323384026065, 0.05369615442759823, 0.05849339700944256, 0.04676799806475174, 0.014797022013226524, 0.03762065687624272, 0.08487321800203063, 0.007397994286293397, 0.022727775358362123, 0.016073295228125062, 0.038367680463125, 0.06044235844456125, 0.14902350580086932, 0.052421077925828286, 0.026427006741869263, 0.06139909441117197, 0.011968465296376962, 0.09578053271980025, 0.07006619925959967, 0.07441055364324711, 0.08688287969562225, 0.06013990358042065, 0.007239527203637408, 0.07108063349733129, 0.10232560729491524, 0.11734759653336369, 0.43768874660599977, 4.486737968400121, 29.87228136509657, 58.65177556872368, 77.32531115412712, 53.403029814362526, 67.7320647239685, 82.69810125231743, 104.69510570168495, 112.96305164694786, 91.83465778827667, 41.856813579797745, 46.11731976270676, 41.39112576842308, 35.482062846422195, 35.62796741724014, 43.039196133613586, 63.648192062973976, 92.86491930484772, 74.00044396519661, 40.762989073991776, 12.932082619518042, 1.607413615565747, 0.26847115019336343, 0.6039346056059003, 0.5082091328222305, 0.07948050581035204, 0.3623008809518069, 0.24589627952082083, 0.2365711345919408, 0.3478394210105762, 0.4564225726062432, 0.5228483816608787, 0.4018024035030976, 0.20474312215810642, 0.40786040655802935, 0.35857135138940066, 0.20324830315075815, 0.07622629214893095, 0.2620553132146597, 0.36226656404323876, 0.8384885382838547, 0.518369193887338, 0.7288771262392402, 0.6934159446973354, 0.4051077214535326, 0.15628712775651366, 0.06809757833252661, 0.03136047424050048, 0.0857988913776353, 0.7349586999043822, 0.7092355645727366, 0.5215850088279694, 0.1645122020272538, 2.0418577222153544, 12.83019108697772, 50.29236853122711, 75.55352702736855, 96.54945999383926, 73.27676519751549, 49.50706087052822, 28.326813094317913, 29.608949795365334, 47.94106990098953, 64.89489376544952, 96.96610003709793, 94.10613790154457, 101.90439864993095, 93.82629811763763, 97.52373531460762, 102.18275651335716, 114.84656497836113, 104.70949172973633, 93.15613567829132, 58.00248920917511, 11.485613286495209, 0.47577371704392135, 0.05070251252618618, 0.0106464284726826, 0.08782629040069878, 0.11006903514498845, 0.03690810604894068, 0.07288665728992783, 0.04308333132939879, 0.018212940376542974, 0.00694076127729204, 0.06246487042517401, 0.04405794563353993, 0.04471495412872173, 0.06194604982738383, 0.0738133474078495, 0.05794047472591046, 0.0928518250293564, 0.06952161871595308, 0.07672635867493227, 0.046486015344271436, 0.015164626311161555, 0.07642958124051802, 0.06198980685439892, 0.0168645471057971, 0.06749159249011427, 0.03132923353405204, 0.019148087267240044, 0.014780740220885491, 0.010048044077848317, 0.030184537536115386, 0.0044862395679956535, 0.05235710479610134, 0.08117121469695121, 0.0503360919537954, 0.039121620866353624, 0.06312454323051497, 0.06763405515812337, 0.044870823694509454, 0.047364402780658565, 0.022093753032095265, 0.08272090068203397, 0.05117775792314205, 0.04431389752426185, 0.06414991672500037, 0.06885591967147775, 0.05839380079123657, 0.055361518971039914, 0.042876431689364836, 0.053905488312011585, 0.025794268331083003, 0.038446448306785896, 0.014818713134445716, 0.010969342492899159, 0.1054226489213761, 0.16367492586141452, 0.20735836151288822, 0.11174564322573133, 0.22722127614542842, 0.13738615525653586, 0.1112795076915063, 0.24181850458262488, 0.07935330912005156, 0.23748416919261217, 0.12113975593820214, 0.10949046423775144, 0.16920827503781766, 0.16299179376801476, 0.10208840947598219, 0.2836317429319024, 0.11973900414886884, 0.15704486053436995, 0.19234122592024505, 0.19417808594880626, 0.17742010939400643, 0.15827094786800444, 0.23792068561306223, 0.14127373258816078, 0.2686067554168403, 0.11963617958826944, 0.1022862437821459, 0.18690638942644, 0.14911997015587986, 0.10393581542302854, 0.11816902784630656, 0.10020554371294565, 0.19620800827397034, 0.3793687338475138, 0.11275217359070666, 0.0887938728556037, 0.22478063445305452, 0.1828510273480788, 0.17789175908546895, 0.16075735038612038, 0.23858851462136954, 0.1205300296714995, 0.12779107637470588, 0.18011787557043135, 0.17110710439737886, 0.2703342377208173, 0.23371168412268162, 0.7573921617586166, 19.798330329358578, 65.86141750216484, 92.61883690953255, 94.82070475816727, 61.49509459733963, 77.60974869132042, 91.51289105415344, 111.17714747786522, 104.18433710932732, 70.77614217996597, 32.51987099647522, 96.59889534115791, 84.29555833339691, 73.8252429664135, 120.05315199494362, 113.7391448020935, 103.52227583527565, 112.04808354377747, 109.15131658315659, 54.9877043813467, 12.926438972353935, 2.504527308046818, 0.9150307404343039, 0.5921281641349196, 0.468679764890112, 0.20659482514020056, 0.40890469739679247, 0.4710229329066351, 0.49237128579989076, 0.7851278828456998, 0.9411401487886906, 1.1817705491557717, 1.1096378322690725, 0.9025511413346976, 1.571162729524076, 0.9204798261635005, 1.0911474307067692, 0.7041879510506988, 1.1722375731915236, 0.5912929808255285, 1.7423999472521245, 1.3639450049959123, 2.175415330566466, 1.2308906321413815, 1.745300735346973, 0.3860225627431646, 0.19363698607776314, 0.16425933747086674, 0.13162581279175356, 0.7849234656896442, 0.5333288724068552, 1.040262698661536, 1.0828338330611587, 3.217703914269805, 16.129239611327648, 72.26675659418106, 132.83027797937393, 165.45923352241516, 151.31317019462585, 130.55169224739075, 73.925139605999, 46.35237894952297, 36.87842711806297, 49.677797108888626, 74.03572127223015, 77.40476489067078, 95.72811126708984, 94.61825922131538, 101.64677247405052, 112.50802606344223, 125.68676769733429, 123.41387405991554, 114.88763317465782, 81.41541928052902, 24.61920764297247, 0.6041685305535793, 0.17348019580822438, 0.17510184785351157, 0.2485075854929164, 0.23482520249672234, 0.1508920406922698, 0.2408891130471602, 0.2583061018958688, 0.14787847583647817, 0.12313031475059688, 0.1751382279326208, 0.20058889116626233, 0.1193276242702268, 0.2627942548133433, 0.11831431809696369, 0.13211107347160578, 0.1482505293097347, 0.14134681929135695, 0.18398443527985364, 0.1844495243858546, 0.11925250408239663, 0.14108770585153252, 0.20518882636679336, 0.13888498186133802, 0.15312828007154167, 0.14470857015112415, 0.12803444144083187, 0.1484932264429517, 0.10948450479190797, 0.31548780854791403, 0.06867950374726206, 0.1515141682466492, 0.1463841021177359, 0.185086524579674, 0.25021713750902563, 0.11189104479853995, 0.09131561644608155, 0.20508137822616845, 0.16746209061238915, 0.04646413683076389, 0.2293550397735089, 0.13069156761048362, 0.16249698906904086, 0.12257538124686107, 0.1680541760288179, 0.15744030650239438, 0.12363956906483509, 0.08293901046272367, 0.17936691117938608, 0.1999429109855555, 0.1371764688519761, 0.16976436629192904, 0.1549914714996703], [0.050935023682541214, 0.06580089844646864, 0.02773365606117295, 0.011712113573594252, 0.097460576944286, 0.055344100765069015, 0.017003115353873, 0.01556058528876747, 0.06677917524939403, 0.02610350085888058, 0.037061749171698466, 0.02116600164299598, 0.028947371793037746, 0.06848164717666805, 0.06325705369818024, 0.02411233348539099, 0.039813528856029734, 0.0465895338129485, 0.005376717981562251, 0.028764400849468075, 0.027299065513943788, 0.07521408435422927, 0.05452660654555075, 0.027950279691140167, 0.029272927858983167, 0.021925107394054066, 0.016361064845114015, 0.04785235374583863, 0.04582637222483754, 0.029023595925536938, 0.04308819981815759, 0.03922200376109686, 0.03297309434856288, 0.013950499615020817, 0.06314795056823641, 0.016781797639850993, 0.06692255818052217, 0.03883502940880135, 0.03318404982564971, 0.07513368749641813, 0.03157360421027988, 0.03992993100837339, 0.04415226518176496, 0.034425930061843246, 0.097713411814766, 0.2047996292822063, 8.678615558892488, 31.604614108800888, 59.88691829144955, 70.7701613008976, 61.028035059571266, 52.14490972459316, 29.72903475165367, 58.41671258211136, 39.37615469098091, 21.76143988966942, 16.94637816399336, 15.559354741126299, 40.98280727863312, 93.8145263493061, 68.64466175436974, 77.58221536874771, 79.31609272956848, 51.33815221488476, 32.83159486949444, 5.64282450824976, 0.5814974033273757, 0.41937559959478676, 0.1525186057551764, 0.015240822613122873, 0.3622888878453523, 0.11250225536059588, 0.1192794217786286, 0.19886421418050304, 0.10131429007742554, 0.30220395885407925, 0.26760156091768295, 0.2676374511793256, 0.36430554057005793, 0.6923558015841991, 0.11101814554422162, 0.23271388141438365, 0.21601817104965448, 0.30278354650363326, 0.21324423083569854, 0.11175227060448378, 0.24488663213560358, 0.2624530449975282, 0.41574477567337453, 0.2839810570003465, 0.3059417410986498, 0.1956974997301586, 0.3675092733465135, 0.2984000067226589, 0.2004361423314549, 0.1938467170111835, 0.20697372121503577, 0.2650545397773385, 0.38774974818807095, 0.6393732852302492, 0.2562565868720412, 0.13349341257708147, 0.537407478550449, 0.7555348332971334, 1.0690196743234992, 9.070149399340153, 38.15561458468437, 92.1005979180336, 106.54778748750687, 84.02091667056084, 71.59124404191971, 32.20005735754967, 19.958767220377922, 25.456743501126766, 27.926818057894707, 48.02138239145279, 60.60769021511078, 75.94335570931435, 72.15628892183304, 69.76215898990631, 78.51522490382195, 84.65319514274597, 84.36523139476776, 32.22460024058819, 1.2819135817699134, 0.1156141325191129, 0.23631552408915013, 0.018786496220855042, 0.02057895912003005, 0.04372330011392478, 0.04417443684360478, 0.07250506721902639, 0.07036914394120686, 0.06418772914912552, 0.0829900182725396, 0.06414914489141665, 0.014444398893829202, 0.10990876835421659, 0.0310003173945006, 0.043437250424176455, 0.060197126877028495, 0.03228272260457743, 0.021636122510244604, 0.007363996501226211, 0.04620285260898527, 0.07309252905542962, 0.027852965577039868, 0.06493856737506576, 0.05054438312072307, 0.010017774657171685, 0.04996613133698702, 0.06619275984121487, 0.06507247308036312, 0.017230618868779857, 0.007354651006608037, 0.02512637438485399, 0.03416006678889971, 0.05397286047809757, 0.014079929242143407, 0.09838647296419367, 0.005809311223856639, 0.01609676008229144, 0.04834161460166797, 0.0814866645669099, 0.0027125910401082365, 0.013551981155615067, 0.032396556925959885, 0.0039006484075798653, 0.037374174789874814, 0.037680221648770384, 0.03879543954099063, 0.050546205093269236, 0.05791032126580831, 0.007618211302542477, 0.01267225414267159, 0.01764208409440471, 0.02396771302301204, 0.050237605246366, 0.05350790866941679, 0.05120430825627409, 0.02946914428321179, 0.02215361837443197, 0.03554494775016792, 0.030117551286821254, 0.05323404875525739, 0.017260651729884557, 0.03516765842505265, 0.007310848986890051, 0.02190569281083299, 0.11040594050427899, 0.06753149777068757, 0.03449195522989612, 0.02578423449449474, 0.043065219215350226, 0.01131354223616654, 0.0650534444139339, 0.04386208915093448, 0.07694668005569838, 0.03259747114498168, 0.03776683770411182, 0.014050126446818467, 0.0060711005698976805, 0.032978055605781265, 0.08982676430605352, 0.018031360959867015, 0.02102632017340511, 0.024357934271392878, 0.07322601915802807, 0.0874251224740874, 0.006609167839997099, 0.009815481898840517, 0.034379475328023545, 0.17210388294188306, 0.04031088654301129, 0.07275374606251717, 0.06671753988484852, 0.05814298085169867, 0.0703884546237532, 0.02072905106615508, 0.03174648751155473, 0.14400397514691576, 0.2448238167562522, 4.345679562538862, 28.03023900836706, 66.32177039980888, 84.46471765637398, 73.15966308116913, 69.20029073953629, 40.807150304317474, 77.83021286129951, 64.56568703055382, 51.64220429956913, 41.75351992249489, 28.597311079502106, 32.38227277994156, 80.75067535042763, 72.91025206446648, 52.869359850883484, 73.98509278893471, 52.06366628408432, 36.68755576014519, 5.920672249048948, 1.0392330726608634, 0.5264194181654602, 0.405191732570529, 0.10862265611649491, 0.17625213222345337, 0.11714461914380081, 0.17818564956542104, 0.11684097684337758, 0.20864157937467098, 0.4674251493997872, 0.5301609705202281, 0.4674332239665091, 0.8843112294562161, 1.3622179976664484, 0.7845379645004869, 0.7495726563502103, 1.3147382391616702, 1.3885073619894683, 0.7209219562355429, 0.8860236906912178, 1.1955423164181411, 1.5551835182122886, 1.602672419976443, 1.256188724655658, 0.8680978557094932, 0.6051680550444871, 0.4442368046147749, 0.4633394186384976, 0.3358902200125158, 0.15733032021671534, 0.175517569296062, 0.4122820927295834, 0.6826839549466968, 0.4141724022338167, 0.08354860314284451, 0.08459872726234607, 0.5451562721282244, 1.3854541070759296, 1.1117559811100364, 9.572453945875168, 41.79961524903774, 81.50298938155174, 84.83246192336082, 55.44831566512585, 39.78807158768177, 24.59451086819172, 28.310584165155888, 39.91280369460583, 57.42260992527008, 86.79526180028915, 89.26773592829704, 93.92399847507477, 88.84104922413826, 88.57074692845345, 88.93662929534912, 98.93115699291229, 97.3468928039074, 35.655375346541405, 0.45890903449617326, 0.25767242652364075, 0.04336360339948442, 0.043022872268920764, 0.04664205560402479, 0.038983674166956916, 0.059856525622308254, 0.05498836711922195, 0.0361860037810402, 0.05644865770591423, 0.0643459327693563, 0.027108945832878817, 0.012608190099854255, 0.04143199337704573, 0.051703061180887744, 0.022567334162886254, 0.07427249933243729, 0.0038409908665926196, 0.04116929536394309, 0.037772555951960385, 0.04500759037910029, 0.10162737991777249, 0.05251003545708954, 0.048280970004270785, 0.04702064368757419, 0.029365842892730143, 0.034655984709388576, 0.03072068913752446, 0.049188356861122884, 0.04871493343671318, 0.024317641218658537, 0.005286684800012154, 0.047100298397708684, 0.023492842410632875, 0.006518689369841013, 0.06032607132510748, 0.014178460478433408, 0.029950061543786433, 0.016653578641125932, 0.05615336085611489, 0.046145907617756166, 0.01837926680309465, 0.04283113841665909, 0.043894331756746396, 0.0385602492315229, 0.03335157853143755, 0.03186832589562982, 0.07277864511706866, 0.02740025178354699, 0.018594070315884892, 0.044032567893736996, 0.04463855373614933, 0.07225623994600028, 0.13482725975336507, 0.1400875876424834, 0.1326622220221907, 0.13487609307048842, 0.13102875498589128, 0.12612266902578995, 0.14618284651078284, 0.14077337662456557, 0.12155377044109628, 0.15794789098436013, 0.1199501971132122, 0.08896271145204082, 0.20013793255202472, 0.13794021302601323, 0.1664136437466368, 0.08571094687795267, 0.13855005061486736, 0.0997490412555635, 0.2024067670572549, 0.20592181594111025, 0.17162853735499084, 0.11447906217654236, 0.22226234927074984, 0.09914227615809068, 0.08789044164586812, 0.08236170120653696, 0.08912435121601447, 0.14767598826438189, 0.14760039310203865, 0.15301943669328466, 0.12013724059215747, 0.19981346558779478, 0.1967683297698386, 0.13668059546034783, 0.09690809252788313, 0.24795171688310802, 0.1544854900566861, 0.22536023694556206, 0.11623602258623578, 0.12979255960090086, 0.11094033136032522, 0.08094439952401444, 0.15123984077945352, 0.4044925404014066, 0.5448389297816902, 18.248952068388462, 68.75565379858017, 94.86604392528534, 100.87092250585556, 84.0375217795372, 79.2496494948864, 54.286881387233734, 93.00247192382812, 62.69839882850647, 33.03250528872013, 26.597531586885452, 27.226506136357784, 67.76213631033897, 132.02592194080353, 93.51120382547379, 122.84619972109795, 117.5142802298069, 76.03015825152397, 53.52933123707771, 9.3039071559906, 1.697303729597479, 1.1110924417153, 0.40749556676018983, 0.12199830205645412, 0.4117771651363, 0.2750569983618334, 0.2936718729324639, 0.5442955589387566, 0.38630796305369586, 0.6360718561336398, 0.4527121310820803, 0.5647009983658791, 0.7362715294584632, 1.0687916865572333, 0.4010324995033443, 0.45083675358910114, 0.4646891774609685, 0.45189894502982497, 0.26330856315325946, 0.46326232433784753, 0.5127368867397308, 0.6940243276767433, 0.7313063833862543, 0.5414090200792998, 0.5058290355373174, 0.5509233532939106, 0.5321990861557424, 0.5041003657970577, 0.5547009443398565, 0.5523375899065286, 0.6994830910116434, 0.8238106383942068, 0.6667663715779781, 1.0458292812108994, 0.35700025444384664, 0.2578943583648652, 0.6211729149799794, 1.4970163581892848, 2.551688477396965, 14.677228275686502, 63.84150668978691, 138.87222737073898, 159.98219221830368, 123.28971952199936, 103.04834246635437, 50.3112231194973, 27.703074663877487, 32.218672558665276, 38.550170212984085, 70.49603641033173, 85.07706999778748, 94.467354118824, 92.67252802848816, 89.25025686621666, 96.03273332118988, 109.52355220913887, 118.82820412516594, 58.028844594955444, 2.4251980148255825, 0.6377949449233711, 0.28152805112767965, 0.16825295286253095, 0.09527242131298408, 0.3325978451175615, 0.2442364365560934, 0.16878263850230724, 0.19231706159189343, 0.15958849748130888, 0.11832826305180788, 0.19893690012395382, 0.10001707531046122, 0.1599606400122866, 0.19518970744684339, 0.16387171373935416, 0.222085525165312, 0.08478309900965542, 0.18626775650773197, 0.09315326315118, 0.11896905562025495, 0.12929848220665008, 0.0859601452248171, 0.08579257570090704, 0.1184428358101286, 0.14633154321927577, 0.1358018777682446, 0.11924384321901016, 0.14209806569851935, 0.13013357645832002, 0.16069888399215415, 0.1214014520519413, 0.19815906998701394, 0.0984050118131563, 0.07565849722595885, 0.14799555705394596, 0.08973357282229699, 0.13514057965949178, 0.14622399117797613, 0.17910450260387734, 0.14197277632774785, 0.08613085403339937, 0.13010541937546805, 0.1539552552276291, 0.21782766067190096, 0.07825441847671755, 0.11809750707470812, 0.20871891116257757, 0.09289115143474191, 0.07350647676503286, 0.23245358053827658, 0.2097240462899208], [0.08412750059505925, 0.02790642247418873, 0.07366053920122795, 0.021159951284062117, 0.013345023071451578, 0.01390985589750926, 0.02726512338995235, 0.03423941721848678, 0.06595210361410864, 0.038262581219896674, 0.04042669868795201, 0.029728317094850354, 0.0215535047755111, 0.03029701743798796, 0.017973612593777943, 0.0356294746597996, 0.05474071243952494, 0.04092111004865728, 0.022351534316840116, 0.02892920030717505, 0.016094147722469643, 0.0576632417505607, 0.09385437006130815, 0.03276589413871989, 0.07120323629351333, 0.07552821320132352, 0.043124216244905256, 0.045725057934760116, 0.006602992243642802, 0.026841922954190522, 0.04674013784097042, 0.0017792945322980813, 0.09485048067290336, 0.027080527142970823, 0.032355185903725214, 0.046579678091802634, 0.06123051556642167, 0.052575908484868705, 0.057911594049073756, 0.08045220718486235, 0.04702016871306114, 0.02797147913952358, 0.07402618794003502, 0.08100942650344223, 4.714441699907184, 37.08400748670101, 59.524151757359505, 67.50188827514648, 41.319826394319534, 52.41398088634014, 45.34112401306629, 32.937685176730156, 31.04409098625183, 19.903085008263588, 20.00509813427925, 33.53914350271225, 53.00756223499775, 68.74768182635307, 70.98270669579506, 34.6898053586483, 38.564902022480965, 48.522161319851875, 11.8504592590034, 2.0147815626114607, 0.2789926074910909, 0.44878857443109155, 0.06531563776661642, 0.1232163593522273, 0.1931843502097763, 0.1311709059518762, 0.27587496384512633, 0.16726870177080855, 0.2052531557274051, 0.036384198028827086, 0.07831881463062018, 0.29733294679317623, 0.10708381290896796, 0.2302429749397561, 0.2240941478521563, 0.3955305431736633, 0.3040568938013166, 0.25237663881853223, 0.3489687026012689, 0.4888126580044627, 0.21327100752387196, 0.19511384511133656, 0.7188956555910408, 0.4299506696406752, 0.32520103733986616, 0.3556538204429671, 0.6649398570880294, 0.19063903600908816, 0.22487818234367296, 0.15999774739611894, 0.08205307909520343, 0.15573259501252323, 0.023143005128076766, 0.16751677205320448, 0.19642854487756267, 0.3647207870380953, 0.3421505622100085, 0.35364850773476064, 0.3433448262512684, 0.30722509254701436, 0.07149222859879956, 0.1734088160446845, 0.16726289817597717, 3.336266102269292, 18.771234042942524, 53.12906451523304, 95.38530126214027, 116.56727224588394, 93.71228903532028, 68.60426232218742, 50.05964241921902, 23.488625809550285, 20.059982389211655, 42.94386304914951, 61.25497788190842, 64.82766017317772, 71.39044001698494, 76.64912223815918, 73.8783261179924, 84.46103185415268, 53.70177738368511, 8.398617133498192, 0.6712058396078646, 0.19016364589333534, 0.06603316098335199, 0.018893487940658815, 0.03652854204119649, 0.07721314817899838, 0.06322569053736515, 0.11688068174407817, 0.058676841072156094, 0.08254701548139565, 0.049268230504821986, 0.057048583912546746, 0.05157421692274511, 0.06617746417759918, 0.063649375224486, 0.032893699390115216, 0.05365738834370859, 0.05021454671805259, 0.04545578078250401, 0.047684357487014495, 0.05712964499252848, 0.051907274246332236, 0.036159720621071756, 0.02980168766953284, 0.12902416958240792, 0.07904775950009935, 0.05113378196256235, 0.02988706619362347, 0.043052398614236154, 0.017200170404976234, 0.02375309690251015, 0.017139785559265874, 0.050563946133479476, 0.08127527864417061, 0.06869026488857344, 0.03449782190728001, 0.06041775624908041, 0.007053738881950267, 0.07966813558596186, 0.029213483685452957, 0.048344085953431204, 0.015137998052523471, 0.06430812776670791, 0.05304198835801799, 0.031158806741586886, 0.057798535272013396, 0.018418242543702945, 0.03824648774752859, 0.015087711053638486, 0.053679047923651524, 0.015745267810416408, 0.010653512272256194, 0.05161633380339481, 0.056887415412347764, 0.016137249804160092, 0.01896403649880085, 0.03808033201494254, 0.036665787411038764, 0.015784497736603953, 0.042453837959328666, 0.03968382741732057, 0.07567768916487694, 0.05536983844649512, 0.04434766153281089, 0.007916706344985869, 0.06450222907005809, 0.05926921221544035, 0.07506607784307562, 0.041460803549853154, 0.07207775342976674, 0.04806735392776318, 0.020561359087878373, 0.010676904767024098, 0.028241613472346216, 0.0691701153118629, 0.03801247374212835, 0.045575218318845145, 0.01474612830861588, 0.07155151877668686, 0.00933448578507523, 0.06986580454395153, 0.021065436922071967, 0.03783076630497817, 0.026216706210107077, 0.10804300167365, 0.04770848470798228, 0.05289711742079817, 0.013808263302053092, 0.04524684394709766, 0.07158933120081201, 0.07318893403862603, 0.016846386752149556, 0.13594108982942998, 0.05475629754073452, 1.1295214528217912, 23.074905909597874, 63.198782578110695, 77.13982790708542, 54.86601211130619, 70.52244499325752, 76.4307327568531, 68.72930601239204, 47.01528757810593, 47.514953166246414, 31.51781726628542, 16.901211887598038, 36.196435913443565, 31.74784742295742, 44.94618080556393, 36.36976361274719, 40.397832468152046, 48.86458374559879, 19.96086660772562, 3.8177361292764544, 0.29245739278849214, 0.1905564498156309, 0.07462251101969741, 0.18025944766122848, 0.09752782294526696, 0.19366891327081248, 0.40095252566970885, 0.8206632791552693, 0.9664114052429795, 0.7632730586919934, 0.9607791574671865, 1.372268577106297, 0.8195901929866523, 1.1790654505603015, 0.5739350966177881, 1.0412369901314378, 1.4743913034908473, 2.1024996181949973, 1.3266530935652554, 2.7022359240800142, 3.10541613958776, 2.129971431568265, 2.9822918213903904, 4.0482215490192175, 3.277076678350568, 3.366206595674157, 3.2272022170946, 2.2962286602705717, 1.6705024614930153, 1.1787940026260912, 0.3121156676206738, 0.5756127065978944, 0.37454688164871186, 1.2207015976309776, 1.0185924614779651, 0.862774281995371, 0.7591604324989021, 0.5946894048247486, 0.45952596701681614, 0.574063042877242, 0.013390013918979093, 0.05371604398533236, 0.10618909451295622, 4.378321710973978, 22.43701133877039, 56.63474500179291, 87.97843471169472, 79.74454253911972, 56.60944975912571, 50.17440766096115, 35.51010154187679, 23.250338695943356, 41.81553639471531, 84.55686271190643, 98.3339050412178, 90.55074468255043, 93.25174614787102, 93.60900297760963, 85.07170468568802, 99.75869938731194, 59.68842834234238, 6.965469885617495, 0.6967129209078848, 0.16681698616594076, 0.2140790579142049, 0.07374181179329753, 0.06444387399824336, 0.07856304800952785, 0.03488925285637379, 0.0642975966911763, 0.027391776457079686, 0.026195543869107496, 0.06394854237441905, 0.0051974670532217715, 0.018393395439488813, 0.05346253376046661, 0.05223065396421589, 0.03208767135220114, 0.020333926077000797, 0.07228235612274148, 0.051651467074407265, 0.027148995832249057, 0.03492457908578217, 0.03666517142846715, 0.028698906317004003, 0.01398230249833432, 0.0320116568764206, 0.04054700453707483, 0.015578980346617755, 0.015849611918383744, 0.04451132735994179, 0.07321094613871537, 0.03755683959752787, 0.04856663377722725, 0.05683301598764956, 0.1329832008923404, 0.017771286438801326, 0.03663366354885511, 0.016939374145295005, 0.040683459519641474, 0.03618264185206499, 0.018134194797312375, 0.030073222806095146, 0.05299085438309703, 0.059892389908782206, 0.0067077848871122114, 0.039243826613528654, 0.01802271308406489, 0.07388129102764651, 0.03422897891141474, 0.020349188343971036, 0.10431882299599238, 0.12465490872273222, 0.14312396611785516, 0.1332030992489308, 0.11688034035614692, 0.10625086346408352, 0.0985355481680017, 0.17115437920438126, 0.09168534699711017, 0.15108963008970022, 0.16353431856259704, 0.2180693336413242, 0.1797372428700328, 0.2060093151521869, 0.09423496565432288, 0.12285453267395496, 0.17747226753272116, 0.18967721262015402, 0.14394964993698522, 0.18797975761117414, 0.13008545560296625, 0.14862501702737063, 0.12731411290587857, 0.12360714463284239, 0.2180942994891666, 0.22311970795271918, 0.23234243650222197, 0.10227060673059896, 0.14745638676686212, 0.20892788510536775, 0.08959545171819627, 0.12708912341622636, 0.09270021168049425, 0.2164614706998691, 0.08989002497401088, 0.14019712863955647, 0.1576128409942612, 0.14904879819368944, 0.1078729162691161, 0.14133344579022378, 0.1516484227613546, 0.1833334975526668, 0.11255426506977528, 0.22918376693269238, 0.1659170282073319, 9.208369832485914, 55.85467346012592, 98.30488979816437, 91.83063760399818, 64.62864965200424, 79.69820782542229, 72.69938617944717, 58.41936103999615, 53.444979563355446, 41.99068799614906, 37.58705109357834, 53.375811874866486, 79.9457797408104, 108.11014965176582, 119.45229783654213, 55.523046255111694, 61.13069415092468, 76.40804037451744, 21.527727730572224, 5.7267415802925825, 0.6309816136490554, 0.31988043221645057, 0.15260785643476993, 0.3310261247679591, 0.30064075835980475, 0.3895113692851737, 0.3621617134194821, 0.6626189535018057, 0.5247170501388609, 0.9808340657036752, 0.5477451207116246, 0.7488413737155497, 0.3897292341571301, 0.585888602072373, 0.3260545071680099, 0.3356641618302092, 0.8700462011620402, 0.8943237515632063, 0.4483300755964592, 1.1246952367946506, 1.3664238969795406, 0.7324929884634912, 1.3051058747805655, 1.8050831649452448, 1.386321885511279, 1.5714557887986302, 1.5315156569704413, 1.7047983524389565, 0.8270727633498609, 0.5595715111121535, 0.26273948431480676, 0.2691548166330904, 0.23307502531679347, 0.43399009038694203, 0.327969070058316, 0.300343869603239, 0.4883664194494486, 0.6402225990314037, 0.7306916476227343, 1.6675335145555437, 0.18193260475527495, 0.20133558078669012, 0.399573941831477, 5.7299296092242, 28.523693829774857, 86.04404211044312, 146.6046604514122, 153.36802393198013, 129.88739669322968, 97.84389093518257, 69.03825223445892, 31.67567029595375, 28.76728355884552, 62.238121926784515, 78.82587343454361, 84.82469514012337, 98.07445496320724, 100.55437669157982, 93.14212203025818, 112.75652512907982, 85.85716053843498, 18.57904225587845, 1.495321886613965, 0.5685878335498273, 0.292709722998552, 0.15308630419895053, 0.1345326122827828, 0.3397901466814801, 0.1484463523956947, 0.2937956037931144, 0.19005175970960408, 0.19784202449955046, 0.14606534969061613, 0.14117516053374857, 0.11905104067409411, 0.1861118758097291, 0.1645095006097108, 0.15076486626639962, 0.11490954493638128, 0.19958923308877274, 0.26506136753596365, 0.13881076709367335, 0.15399110096041113, 0.13485005852999166, 0.15911295893602073, 0.11121110394014977, 0.21895715006394312, 0.22405680298106745, 0.11907624400919303, 0.12359673230093904, 0.08960380830103531, 0.12945531285367906, 0.10334008606150746, 0.08635472288005985, 0.10241148120258003, 0.30329565808642656, 0.18024726159637794, 0.11707555488101207, 0.1677317128633149, 0.11028136359527707, 0.13027872570091859, 0.09246711051673628, 0.091934723459417, 0.18282181641552597, 0.12007703015115112, 0.08624778682133183, 0.10521092161070555, 0.14181944861775264, 0.13054822920821607, 0.11237698825425468, 0.13499215012416244, 0.27299050299916416], [0.01817289594328031, 0.027402088599046692, 0.03672616854601074, 0.04940120852552354, 0.020453938777791336, 0.04711351233709138, 0.03886067803250626, 0.020254152623238042, 0.06083558910177089, 0.047667165636084974, 0.015476517583010718, 0.012131260955356993, 0.033782940736273304, 0.06459510885179043, 0.0334621177171357, 0.010740547641034937, 0.050145801578764804, 0.02499755981261842, 0.03663876581413206, 0.02946908862213604, 0.013975160254631191, 0.044192022032802925, 0.020731834119942505, 0.047459375418839045, 0.07374147782684304, 0.03689295881486032, 0.027177876509085763, 0.08064631590968929, 0.028619819349842146, 0.0032745144153523142, 0.04880050677456893, 0.059064115994260646, 0.053887023677816615, 0.04535836647846736, 0.0925225266837515, 0.07426858821418136, 0.023623987326573115, 0.08888909782399423, 0.09401969087775797, 0.08276522174128331, 0.008079546532826498, 0.07934704539366066, 0.5235691554844379, 18.0641033872962, 60.67964695394039, 74.28422033786774, 66.35374948382378, 57.99614354968071, 65.62425702810287, 46.300621926784515, 27.565852627158165, 16.98718037456274, 23.402262143790722, 41.51750698685646, 40.0348075479269, 59.48467567563057, 59.19738829135895, 55.4783720523119, 59.963381588459015, 41.665767431259155, 13.67775745689869, 0.8570345118641853, 0.37346257420722395, 0.22701335605233908, 0.04117775213671848, 0.48502245044801384, 0.2283005221397616, 0.045016021176707, 0.40913215081673115, 0.11994212996796705, 0.24495615652995184, 0.2060218426049687, 0.438519002054818, 0.3630195767618716, 0.4617315111681819, 0.9129741007927805, 1.080717109143734, 0.7839489961043, 1.2433236837387085, 3.5489285783842206, 2.095313728787005, 2.872141906991601, 6.031015003100038, 7.839273847639561, 5.771916881203651, 2.9678464215248823, 6.3970498368144035, 7.2805200051516294, 8.304012659937143, 5.342016024515033, 2.9625141201540828, 1.9842832116410136, 0.5698550655506551, 0.935968745034188, 1.0070698172785342, 0.05639529728796333, 0.2717565785860643, 0.3185008093714714, 0.5107853352092206, 0.6574238010216504, 0.1738902323995717, 0.12174382703960873, 0.10761458208435215, 0.13728707854170352, 0.18081323825754225, 0.17436056106816977, 0.036089120112592354, 0.2599486231338233, 0.38048691290896386, 0.34644569735974073, 15.836995393037796, 52.89609141647816, 81.07757180929184, 74.32636767625809, 88.20632368326187, 89.21151414513588, 50.67118160426617, 18.540766909718513, 18.07255793362856, 18.218787387013435, 33.907708525657654, 61.6561109572649, 76.38717949390411, 77.2544601559639, 72.96376839280128, 75.10614663362503, 28.678887002170086, 8.725637085735798, 1.5212730690836906, 0.3586833563167602, 0.08334196696523577, 0.027272561565041542, 0.07671407613088377, 0.06017650259309448, 0.041193741708411835, 0.07026047125691548, 0.07400183065328747, 0.024419116925855633, 0.03345887453178875, 0.049896859272848815, 0.05186994792893529, 0.08579187808209099, 0.0618132202362176, 0.03398894979909528, 0.062127612545737065, 0.05605231002846267, 0.02630783823406091, 0.05371105304220691, 0.04427532068802975, 0.03136506813461892, 0.05299720345647074, 0.040488085433025844, 0.030543796383426525, 0.01472407167966594, 0.03029209143278422, 0.08743025071453303, 0.045676881418330595, 0.04171371263510082, 0.04601485175953712, 0.09148228797130287, 0.03372926119482145, 0.09994783293223009, 0.023248818688443862, 0.052454608157859184, 0.08264315329142846, 0.06543208815855905, 0.016336188054992817, 0.07938188922707923, 0.06206345758982934, 0.025135586292890366, 0.01502579831139883, 0.021008879703003913, 0.02892049862566637, 0.04365268847323023, 0.1112915453268215, 0.04897150873148348, 0.030052164365770295, 0.060834913747385144, 0.07484815359930508, 0.03558291602530517, 0.04143908830883447, 0.09195321777951904, 0.09167540221824311, 0.026368306571384892, 0.07377405068837106, 0.052454745455179363, 0.055128644162323326, 0.02710778993787244, 0.04770887433551252, 0.03180800784321036, 0.028589832872967236, 0.06195808375196066, 0.036092942173127085, 0.018997778242919594, 0.03694505758176092, 0.03388241821085103, 0.06805941709899344, 0.03477813850622624, 0.01986196468351409, 0.04718221665825695, 0.10216783412033692, 0.06300045613897964, 0.023963796338648535, 0.045233514974825084, 0.08369209739612415, 0.04832112761505414, 0.04465115911443718, 0.036073408846277744, 0.041939700313378125, 0.03865986771415919, 0.08462963029160164, 0.017812021069403272, 0.042087254114449024, 0.12518836447270587, 0.07203389250207692, 0.06332494536763988, 0.02318024980922928, 0.21611113246763125, 0.6881014548707753, 9.365720339119434, 61.14658109843731, 92.85809487104416, 82.30650186538696, 69.19570818543434, 80.17298474907875, 70.19747123122215, 57.0814224332571, 34.97885584831238, 32.007935866713524, 31.55147396028042, 31.68037824332714, 48.15922759473324, 35.534576028585434, 50.11949300765991, 60.356200709939, 53.180194571614265, 19.701728112995625, 2.4619598546996713, 0.5438882682938129, 0.4292279068613425, 0.1490262072184123, 0.5515910487156361, 0.42427107284311205, 0.3053254319820553, 1.4197663846425712, 0.8431750524323434, 0.2943782787770033, 0.8842166501563042, 2.2581281047314405, 2.4713869113475084, 2.926226304844022, 5.377615839242935, 4.809693088755012, 5.691592041403055, 6.859927698969841, 7.078808778896928, 5.69327867589891, 8.184050247073174, 8.54436781257391, 8.812095746397972, 12.335971556603909, 7.6091524958610535, 11.860123090445995, 13.221508339047432, 11.000702306628227, 8.899232670664787, 7.243973566219211, 5.226479424163699, 7.604908598586917, 7.654158705845475, 4.3864694237709045, 3.4962676791474223, 2.9622984817251563, 2.525984519161284, 2.3819615598767996, 2.225819150917232, 1.1381491273641586, 0.3637822374003008, 0.7077611843124032, 1.25149704515934, 0.5878331477288157, 0.08647378563182428, 0.07750624456093647, 0.38735391630325466, 0.21780802344437689, 0.9217925369739532, 16.126524657011032, 55.73109269142151, 70.44466316699982, 44.14304830133915, 56.05449713766575, 49.68461014330387, 27.30228926986456, 20.466929152607918, 33.987527042627335, 38.80530372262001, 57.45490439236164, 90.99324613809586, 90.30957162380219, 91.76524311304092, 89.88929137587547, 87.81261160969734, 28.693204633891582, 7.262789206579328, 0.6430010811891407, 0.22240347607294098, 0.09587989887222648, 0.01401624183927197, 0.042842842085519806, 0.027006327218259685, 0.05819392928970046, 0.08826484772725962, 0.042541500442894176, 0.030065215032664128, 0.048622992471791804, 0.04618528226274066, 0.04246431708452292, 0.06222727184649557, 0.09575256117386743, 0.032523145055165514, 0.03936198394512758, 0.028454454004531726, 0.022283663056441583, 0.045181345703895204, 0.11044676604797132, 0.022368162135535385, 0.04591218304994982, 0.08643550565466285, 0.017559009938850068, 0.06730901674018241, 0.050395471189403906, 0.019271755045338068, 0.08322642199345864, 0.06309524324024096, 0.026190218959527556, 0.004135827584832441, 0.014127203121461207, 0.03829610774118919, 0.07278767705429345, 0.020891757667413913, 0.0557752996974159, 0.007686115495744161, 0.11102591583039612, 0.06420388570404612, 0.098420084832469, 0.062341028242371976, 0.02835216193489032, 0.047830397306825034, 0.05869864908163436, 0.031083170761121437, 0.03772582291276194, 0.039986861156648956, 0.0838119319814723, 0.09504039626335725, 0.12808382394723594, 0.14121349988272414, 0.14025936514372006, 0.275522384326905, 0.147904762707185, 0.06529059028252959, 0.15305486682336777, 0.1840217801509425, 0.12359305866993964, 0.15924264182103798, 0.1525268584373407, 0.10043035508715548, 0.08256998495198786, 0.11366254388121888, 0.1310394864412956, 0.05970502730633598, 0.1400174546870403, 0.17850222007837147, 0.1206643064506352, 0.1540118217235431, 0.1085646943829488, 0.17541173903737217, 0.1822180941235274, 0.1608567388029769, 0.15625448810169473, 0.19997366558527574, 0.13920796453021467, 0.1584893767721951, 0.0958627404179424, 0.1593151644919999, 0.09559125537634827, 0.21352632116759196, 0.19680831668665633, 0.175693562196102, 0.17397617310052738, 0.20875251560937613, 0.18440650950651616, 0.27019061730243266, 0.10221579170320183, 0.3491231583757326, 2.0388435339555144, 30.435205958783627, 92.57630959153175, 108.15428048372269, 94.27658155560493, 84.42113399505615, 99.05690744519234, 71.5233188867569, 44.65336471796036, 30.13576302677393, 48.7185537815094, 65.97920358181, 63.36715154349804, 93.61509785056114, 102.70839750766754, 97.29540556669235, 86.72200173139572, 70.14748111367226, 27.269229143857956, 2.43328754324466, 1.31839589914307, 0.8226776460651308, 0.14382675028173253, 0.4556006588973105, 0.47086809121537954, 0.2576914255041629, 0.7829549338202924, 0.5662514339201152, 0.397370089776814, 0.7114038232248276, 1.386274981778115, 1.354191165883094, 1.9949839124456048, 4.231731751933694, 4.770221756771207, 4.424643125385046, 5.572715420275927, 9.937200173735619, 7.604714808985591, 9.911482203751802, 16.444083116948605, 18.97526029497385, 18.24103519320488, 8.837978057563305, 15.534828007221222, 16.309281550347805, 18.2783130928874, 11.618438959121704, 7.88833586499095, 5.180208357051015, 5.0382432248443365, 4.500171197578311, 2.7242046827450395, 1.4251391775906086, 1.542378324083984, 1.1795665486715734, 0.7810603198595345, 0.9281221660785377, 0.4438512143678963, 0.13503108319127932, 0.28195499384310097, 0.6417147908359766, 0.36015901307109743, 0.2758925379021093, 0.1941476875799708, 0.3976845525903627, 0.28487656207289547, 2.085609049536288, 25.431275367736816, 85.86333900690079, 121.79159671068192, 106.88998952507973, 124.14826825261116, 123.82229894399643, 75.53110063076019, 29.72536414861679, 29.648412577807903, 29.11823272705078, 49.15649548172951, 84.63819354772568, 99.5027831196785, 100.37210807204247, 95.95481470227242, 111.06964364647865, 52.13811568915844, 24.72548983991146, 3.0381466867402196, 0.4022734594764188, 0.34291058080270886, 0.1686951392912306, 0.212748906633351, 0.18851080880267546, 0.1636915054405108, 0.3414523496758193, 0.1412822524434887, 0.09635527414502576, 0.1222930831136182, 0.15064910607179627, 0.1619897162890993, 0.10144791376660578, 0.22036740876501426, 0.13538146595237777, 0.1309410628164187, 0.10084261070005596, 0.17820328299421817, 0.14052886865101755, 0.1844375758082606, 0.08523349359165877, 0.14613120787544176, 0.1965242819278501, 0.1392059458885342, 0.07551388232968748, 0.10939860861981288, 0.1853789307642728, 0.16041654133005068, 0.14348372962558642, 0.1816480653360486, 0.29887542652431875, 0.09617617906769738, 0.3062301396857947, 0.10914197395322844, 0.11783063819166273, 0.18019462848315015, 0.1712528325151652, 0.17844177957158536, 0.11582818275201134, 0.16312468273099512, 0.12822674674680457, 0.0968447353807278, 0.11645782084087841, 0.10119593978743069, 0.13193264632718638, 0.22327343642245978, 0.11614944363827817], [0.05302140118146781, 0.05638218724925537, 0.038257026244536974, 0.009389957613166189, 0.008081786891125375, 0.06187910068547353, 0.02614350447402103, 0.07861924343160354, 0.03904965480614919, 0.04315910460718442, 0.029063755391689483, 0.05944044423813466, 0.03485099514364265, 0.02513043764338363, 0.04373580159153789, 0.032466812335769646, 0.008200980446417816, 0.01236465805050102, 0.026257579993398394, 0.08828582824207842, 0.03225153013772797, 0.0036534139690047596, 0.03438396532146726, 0.1051992921566125, 0.04560863722872455, 0.017160372735816054, 0.06201420495926868, 0.015663041558582336, 0.020936112123308703, 0.04263205730239861, 0.040730018154135905, 0.04416067742567975, 0.05222320280154236, 0.0447725484991679, 0.05437669271486811, 0.06719478536979295, 0.007748730959065142, 0.13652947935042903, 0.07014367205556482, 0.030007455534359906, 0.06726953448378481, 1.8138661561533809, 38.71858857572079, 81.1632876098156, 67.45420843362808, 63.11101108789444, 77.95456498861313, 68.86610627174377, 40.39706110954285, 29.081207513809204, 40.08030630648136, 67.74882182478905, 30.678147822618484, 53.71631160378456, 63.515465185046196, 40.451538786292076, 54.489950090646744, 36.19653470814228, 13.275383748114109, 1.366519604343921, 0.7312353746965528, 0.014510687524307286, 0.026880599980358966, 0.14825009886408225, 0.02710048163862666, 0.022408995100704487, 0.13546578877139837, 0.25661560823209584, 1.8214532802812755, 1.326478065457195, 1.1525152064859867, 1.7093388712964952, 2.6947529381141067, 1.4366108807735145, 2.4001435842365026, 3.4679242875427008, 4.068987909704447, 5.667599653825164, 5.579188372939825, 3.7111829593777657, 1.0054635722190142, 8.245718088001013, 8.506556991487741, 7.043349081650376, 8.126274347305298, 9.625556096434593, 14.997132159769535, 12.754108719527721, 8.362502921372652, 9.683855418115854, 11.035763025283813, 5.363926598802209, 8.626672346144915, 7.150474833324552, 0.7948991179000586, 3.2003433583304286, 3.1720002042129636, 7.145043974742293, 6.433522179722786, 4.682059837505221, 2.140891570597887, 2.4162252712994814, 0.7302694546524435, 0.16683640074916184, 0.11687163496389985, 0.07868999236961827, 0.11276493853074498, 0.17131337692262605, 0.20269529923098162, 0.02581193701189477, 0.1892680220771581, 1.3824083330109715, 21.603704653680325, 70.72157710790634, 69.21131774783134, 76.42979800701141, 144.05932903289795, 115.35172507166862, 78.5906508564949, 70.59961125254631, 50.535794869065285, 17.082530558109283, 48.22087548673153, 65.11475756764412, 63.71551685035229, 69.7815303504467, 82.39772737026215, 80.85133954882622, 56.171709448099136, 21.623993664979935, 3.640710753388703, 0.33523386460728943, 0.19792342325672507, 0.0741100060986355, 0.13638609641930088, 0.03966437201597728, 0.020175087920506485, 0.013019903017266188, 0.028830236769863404, 0.06455757102230564, 0.10188136511715129, 0.049422441370552406, 0.03584381061955355, 0.014336930344143184, 0.08778782488661818, 0.06929987241164781, 0.061111719987820834, 0.02787125024042325, 0.06238762769498862, 0.006432094651245279, 0.008573669383622473, 0.00666139230816043, 0.042912626231554896, 0.05737358151236549, 0.060995414314675145, 0.06222149793757126, 0.06945731904124841, 0.021773811313323677, 0.07605839608004317, 0.027120985323563218, 0.03882260585669428, 0.03200134102371521, 0.04896489619568456, 0.06390856287907809, 0.06199030038260389, 0.028583281564351637, 0.07409907426335849, 0.03542661972460337, 0.0030835626012049033, 0.02555512051912956, 0.06987950459006242, 0.047268213020288385, 0.01488971347498591, 0.09492912606219761, 0.030557811842299998, 0.039345285622403026, 0.0638707578764297, 0.0362182500975905, 0.0317478011129424, 0.007451729488821002, 0.048084953959914856, 0.05225522647378966, 0.038617457685177214, 0.0561151588044595, 0.040733643545536324, 0.02355095071834512, 0.04345871333498508, 0.06987551183556207, 0.07355450114118867, 0.03533662689733319, 0.09037784606334753, 0.012973254397365963, 0.04242553986841813, 0.03805569271207787, 0.05814336305775214, 0.03320788389828522, 0.050014393200399354, 0.024357756155950483, 0.04273638471204322, 0.03849624270515051, 0.03631253624917008, 0.058032386004924774, 0.06889978059916757, 0.034462514231563546, 0.026932195942208637, 0.009455853833060246, 0.03567510189895984, 0.04746881553728599, 0.03787035988352727, 0.06807995974668302, 0.06545602242113091, 0.0617347195657203, 0.0738183272187598, 0.03740284766536206, 0.04562006259220652, 0.00716699386430264, 0.024985553718579467, 0.37482147628907114, 31.737090200185776, 88.64121794700623, 85.5538760125637, 74.45429161190987, 95.41747033596039, 109.24404680728912, 84.34410452842712, 39.02905851602554, 23.702466934919357, 35.31839802861214, 31.77946362644434, 55.78607194125652, 53.427492901682854, 40.42399786412716, 51.27801664173603, 45.01831233501434, 21.18261504918337, 1.0356681514531374, 0.9024169016629457, 0.38623742933850735, 0.11244591893046163, 0.13491572375642136, 0.20683203038061038, 0.271596452803351, 0.4360935150180012, 0.737107009626925, 2.1185535192489624, 1.9432384078390896, 0.4444981296546757, 2.9736883705481887, 2.7887116838246584, 4.655391918495297, 4.830609066411853, 4.4681051932275295, 5.914791589602828, 6.018718862906098, 7.173472149297595, 10.663402006030083, 9.586929269134998, 15.534461326897144, 14.394167214632034, 7.0336648263037205, 13.576989714056253, 14.8228545114398, 18.621966652572155, 17.298814952373505, 14.96946394443512, 16.375137716531754, 15.633446015417576, 14.328020364046097, 17.508159019052982, 13.432145286351442, 8.929083868861198, 6.491423947736621, 5.906059658154845, 4.471738748252392, 6.448684791103005, 6.581731326878071, 4.578415174037218, 3.7062700605019927, 1.3888939912430942, 1.2820140388794243, 0.9144636802375317, 0.4934466874692589, 0.38808721757959574, 0.20233080082107335, 0.10751235124189407, 0.09161902125924826, 0.18030517880106345, 1.7177595756947994, 22.868877165019512, 66.2410095334053, 60.08011892437935, 76.35617315769196, 106.52947247028351, 59.82516020536423, 39.364196732640266, 22.86000084131956, 51.587293446063995, 41.08095221221447, 70.93387931585312, 85.88207200169563, 74.31853249669075, 83.86287555098534, 93.97097915410995, 90.00466838479042, 55.71630768477917, 16.43941506743431, 1.6371724312193692, 0.1492987832170911, 0.16871949657797813, 0.029315811007109005, 0.14934708218788728, 0.03644814518338535, 0.042857403022935614, 0.02769137961877277, 0.09564950654748827, 0.06423357161111198, 0.01793306350009516, 0.04834481325815432, 0.01636913941183593, 0.053788184450240806, 0.037859576477785595, 0.05700894209439866, 0.07924258810817264, 0.015267262551788008, 0.039905621961224824, 0.03177973201673012, 0.027152406000823248, 0.07919484574813396, 0.05242648447165266, 0.014318108551378828, 0.08552351006073877, 0.04305979411583394, 0.01162064943855512, 0.05690658879757393, 0.04889294126769528, 0.07030679611489177, 0.04867156603722833, 0.022188258117239457, 0.04783486503583845, 0.040492159823770635, 0.04202009346045088, 0.01659210098296171, 0.0335189513862133, 0.026109358259418514, 0.02757745809503831, 0.032087526633404195, 0.07018713964498602, 0.025246106924896594, 0.014630711357312975, 0.09110978178796358, 0.054693196434527636, 0.054982352012302727, 0.18019547453150153, 0.14655853650765494, 0.2229911382892169, 0.07379817790933885, 0.12381037435261533, 0.14952355006244034, 0.13291815906995907, 0.1646625908324495, 0.16983460314804688, 0.2079237296129577, 0.0930988191976212, 0.1449748082086444, 0.1295480367843993, 0.07342007593251765, 0.20604464138159528, 0.1080244776676409, 0.13722561387112364, 0.16548840823816136, 0.1798024182789959, 0.12067310090060346, 0.10671172974980436, 0.1017570034309756, 0.1649708196055144, 0.19122942932881415, 0.16078244982054457, 0.18126468668924645, 0.1944131389609538, 0.1514212365145795, 0.18243168422486633, 0.19982251978944987, 0.11814796569524333, 0.10820341689395718, 0.15140060480916873, 0.14667178824311122, 0.25950995448511094, 0.15671202214434743, 0.20008782274089754, 0.3114763816120103, 0.13851606025127694, 0.1088523434009403, 0.3523642657091841, 6.335372971370816, 63.72231088578701, 116.90344780683517, 93.15665245056152, 89.40489336848259, 112.20503032207489, 97.99097344279289, 61.93090081214905, 46.61746792495251, 61.418684497475624, 110.6198313832283, 53.1842565536499, 75.0629049539566, 96.69392824172974, 62.08540812134743, 80.31000539660454, 55.87879076600075, 26.787912771105766, 1.5170068480074406, 1.677875134628266, 0.4001426644390449, 0.24929936800617725, 0.5315587017685175, 0.43554883799515665, 0.2531903295312077, 0.9154335188213736, 1.0202115308493376, 7.711062552407384, 6.115112565457821, 6.38151959516108, 8.866906855255365, 8.820816278457642, 6.611489430069923, 10.249012392014265, 9.968926571309566, 12.296129744499922, 16.635283157229424, 16.555191054940224, 22.503148689866066, 19.828382916748524, 21.901969648897648, 23.88827696442604, 26.490918807685375, 25.93697313219309, 32.88348488509655, 38.4959015250206, 34.894876554608345, 28.48319750279188, 28.742795772850513, 30.060299076139927, 18.190254718065262, 17.618421502411366, 23.56296692043543, 16.488282345235348, 13.61046876758337, 15.010572038590908, 17.94030413031578, 12.435347624123096, 10.310235656797886, 7.73331368342042, 5.543995136395097, 1.991764297708869, 1.3967086281627417, 0.340428720228374, 0.2022705235867761, 0.41628556384239346, 0.2713333169231191, 0.2738473570207134, 0.16286448575556278, 0.31849217077251524, 3.4688756614923477, 40.513065084815025, 115.57649821043015, 94.58353668451309, 98.24981555342674, 172.5798386335373, 148.63074213266373, 99.4882071018219, 87.25824415683746, 68.33195373415947, 26.62415485829115, 63.19716766476631, 85.96670866012573, 86.75023421645164, 91.0782627761364, 106.06671050190926, 113.09140115976334, 85.49861177802086, 41.92974306643009, 6.6532819624990225, 0.747489893110469, 0.2590942627284676, 0.1911374178598635, 0.24632380111142993, 0.21227908262517303, 0.24388649908360094, 0.08891115445294417, 0.20924157608533278, 0.2020226462627761, 0.20825854211580008, 0.2521114842966199, 0.11231418029638007, 0.17152834741864353, 0.18290578300366178, 0.1637617126107216, 0.18962950736749917, 0.15475367254111916, 0.19384345156140625, 0.17991483880905434, 0.10042567213531584, 0.12202072233776562, 0.1457837491761893, 0.10010340934968553, 0.17308050475548953, 0.22248125314945355, 0.16055124113336205, 0.12359452070086263, 0.17798528453567997, 0.12498831114498898, 0.10806844249600545, 0.10260634691803716, 0.11105174256954342, 0.11079880379838869, 0.13900378486141562, 0.14648495998699218, 0.1637778023723513, 0.10637272411258891, 0.09209436684614047, 0.10922819667030126, 0.09944366232957691, 0.14433115837164223, 0.15234127698931843, 0.23945586261106655, 0.17369150009471923, 0.1733161514857784], [0.06564669500221498, 0.013837412079737987, 0.051933724389527924, 0.06310940341791138, 0.02045467907009879, 0.06754225891199894, 0.055065298147383146, 0.1034676464041695, 0.03973313941969536, 0.045853527408326045, 0.017855646365205757, 0.042278613182133995, 0.011927615632885136, 0.027247912985330913, 0.05121198948472738, 0.07214239449240267, 0.034853377437684685, 0.06327090959530324, 0.0574840390618192, 0.03241298436478246, 0.06438755241106264, 0.0749487814027816, 0.040891654207371175, 0.04240338676027022, 0.03356420013005845, 0.04366182802186813, 0.05003130674595013, 0.06837417677161284, 0.0888422757270746, 0.08648847273434512, 0.034090813278453425, 0.030975930421845987, 0.040660415834281594, 0.05638090704451315, 0.03225966036552563, 0.062476692837662995, 0.060878385047544725, 0.06471158150816336, 0.05007300802390091, 0.1629645421053283, 9.358310736715794, 50.35499297082424, 80.72915330529213, 71.29673704504967, 65.35992801189423, 100.02874329686165, 63.796935081481934, 22.141548693180084, 23.85978039354086, 41.48874253034592, 62.78130657970905, 61.593395322561264, 38.112733885645866, 34.91631880402565, 37.05294795334339, 39.90749537944794, 14.913479648530483, 1.558405151590705, 0.09861066835583188, 0.16448462381958961, 0.20283866731915623, 0.1316558400867507, 0.02265903207444353, 0.07991040969500318, 0.10395316683570854, 1.4204460731707513, 0.5623390094842762, 0.920251066563651, 2.8340285271406174, 1.772322985343635, 0.9305500576738268, 2.0672258734703064, 2.5177498860284686, 6.856273720040917, 6.235255943611264, 7.062957929447293, 4.5029345992952585, 8.57167599722743, 12.27401303127408, 6.406510379165411, 4.946434451267123, 7.980235833674669, 7.501829154789448, 4.107581488788128, 14.79044510051608, 6.586657287552953, 9.878001250326633, 16.25762902200222, 8.957613687962294, 8.28362675383687, 7.714042067527771, 9.789644591510296, 17.82014697790146, 15.05052499473095, 9.679710790514946, 14.582917336374521, 8.26674995943904, 8.341272510588169, 9.104434959590435, 7.112237960100174, 7.205657372251153, 3.150289594195783, 5.366090107709169, 3.699142117984593, 0.33894985739607364, 0.13931251829490066, 0.19717769842827693, 0.14247843122575432, 0.0841129248146899, 0.14876393222948536, 0.14284229138866067, 0.03557848911441397, 0.10002262657508254, 1.783563969656825, 30.06536230444908, 49.01434890925884, 50.29239892959595, 71.31094068288803, 96.03255093097687, 194.31265085935593, 77.61375367641449, 27.651123851537704, 27.734018303453922, 36.18081495165825, 45.40618412196636, 68.28903123736382, 66.96982562541962, 73.57831701636314, 81.66561305522919, 87.70430982112885, 67.02575862407684, 6.199122732505202, 0.5332204594742507, 0.09013521572342142, 0.03354866697918624, 0.04546856798697263, 0.05094577369163744, 0.003608197926041612, 0.029775411931041162, 0.05143809590663295, 0.0899353034037631, 0.05653066502418369, 0.035023529635509476, 0.020025201920361724, 0.04011806544440333, 0.017498012821306475, 0.05131818339577876, 0.03897096488799434, 0.02406430725386599, 0.006839111165390932, 0.045412903200485744, 0.0665421481244266, 0.035111143879476, 0.01009252840958652, 0.07482568136765622, 0.06612107579712756, 0.05119725414260756, 0.0733883268549107, 0.009668267630331684, 0.017036690114764497, 0.08122165847453289, 0.028370852924126666, 0.05387594341300428, 0.02535770367103396, 0.060776584650739096, 0.006979987028898904, 0.06992030786932446, 0.04370023787487298, 0.044847160315839574, 0.04799158436071593, 0.0375060173246311, 0.015798502063262276, 0.04158879804890603, 0.024885825769160874, 0.02718963398365304, 0.04007632705906872, 0.05222697291173972, 0.06743573845596984, 0.03917256930435542, 0.03372309394762851, 0.02820700712618418, 0.03357208173838444, 0.07764973881421611, 0.05642072326736525, 0.055655071773799136, 0.008047641604207456, 0.057024148700293154, 0.0336869995953748, 0.016121531116368715, 0.024547306238673627, 0.09830713737756014, 0.0673914396611508, 0.05645573037327267, 0.0323084899719106, 0.06185043152072467, 0.0034461912628103164, 0.06327218608930707, 0.04707339554443024, 0.16368901182431728, 0.018265662547491957, 0.04085991997271776, 0.13273903430672362, 0.059735811591963284, 0.06264406940317713, 0.04776874338858761, 0.057225159398512915, 0.01815266314224573, 0.014861894997011404, 0.04121749043406453, 0.02436867871438153, 0.025531535065965727, 0.00881233201653231, 0.06102530060161371, 0.1649917778559029, 0.06235322172869928, 0.0855658421642147, 4.524348825216293, 45.43178714811802, 92.24295347929001, 95.30016303062439, 88.07868853211403, 102.57464468479156, 72.05819338560104, 47.22406357526779, 41.780452877283096, 39.08282943069935, 40.7856472581625, 60.47601968050003, 39.029943868517876, 38.57656739652157, 48.10919567942619, 54.67637188732624, 24.459405317902565, 3.342142724432051, 0.23974227224243805, 0.04458601710211951, 0.3165307635208592, 0.11472686528577469, 0.35364901239518076, 0.3936248563695699, 0.7040464680176228, 1.7030027112923563, 0.6153040705248713, 0.528428026009351, 1.1626205267384648, 1.2626121612265706, 1.3250792655162513, 1.3335130317136645, 0.10467389613040723, 2.394343907944858, 3.3920661080628633, 2.956885672174394, 1.1968152481131256, 2.80796667560935, 2.7773545682430267, 5.372579684481025, 9.044244289398193, 22.335174903273582, 20.18113698810339, 15.19688744097948, 17.75388613343239, 8.8912682980299, 10.505069252103567, 9.797791354358196, 14.739753920584917, 7.556016147136688, 10.316645912826061, 10.728221777826548, 15.763718225061893, 5.709851011633873, 0.6988569558598101, 1.7079739132896066, 0.6432697980199009, 3.51016400847584, 4.9823857471346855, 6.503678765147924, 3.2110200729221106, 5.650414125993848, 3.7155104521661997, 3.5503554018214345, 2.3536706529557705, 0.7236681994982064, 0.5640165600925684, 0.48229449370410293, 0.5889208987355232, 0.2935167937539518, 0.10369265815825202, 0.11073477129684761, 0.0468616014404688, 2.6869113463908434, 34.30930897593498, 53.81411835551262, 56.36855028569698, 67.78938084840775, 68.27502518892288, 163.0201292037964, 69.07308116555214, 21.585344038903713, 46.49649761617184, 60.61403967440128, 68.29103752970695, 84.81885105371475, 80.38746044039726, 85.87710186839104, 96.77928686141968, 98.55852618813515, 69.47482600808144, 4.101981064304709, 0.3658327617449686, 0.16580159455770627, 0.07064076256938279, 0.1093739693169482, 0.04120057688851375, 0.006936640502317459, 0.03745555870409589, 0.028426944445527624, 0.012140032213210361, 0.03551008165231906, 0.06709026129101403, 0.04952626783051528, 0.03236908632970881, 0.011418550566304475, 0.02761264331638813, 0.06476097885752097, 0.06482487035100348, 0.05530158683541231, 0.04229639132972807, 0.02314500521606533, 0.059572398095042445, 0.03234143390727695, 0.09743812697706744, 0.027585723764786962, 0.04229177146044094, 0.02759912324108882, 0.06347722664941102, 0.02324296314327512, 0.05418912973254919, 0.03624401375418529, 0.014324358362500789, 0.05904505764192436, 0.0210921653706464, 0.026999775909644086, 0.03190655763319228, 0.03159311156196054, 0.06239303053007461, 0.020843377060373314, 0.027507176710059866, 0.07009584063780494, 0.10756616436992772, 0.010032786449301057, 0.016225511571974494, 0.01268090109078912, 0.176095346105285, 0.09745043920702301, 0.1328268155339174, 0.15302141080610454, 0.09444843701203354, 0.15200542547972873, 0.1519566515344195, 0.248890029033646, 0.14357565203681588, 0.13725055003305897, 0.13360152865061536, 0.11051662440877408, 0.10354452548199333, 0.13840617786627263, 0.17015745223034173, 0.18908503814600408, 0.25620689266361296, 0.1941764829098247, 0.16701473883586004, 0.15773646795423701, 0.13096130860503763, 0.2191633780603297, 0.21764538920251653, 0.1541400351561606, 0.18239545257529244, 0.2914467063965276, 0.21151346823899075, 0.2234947745455429, 0.12279913877137005, 0.2826651994837448, 0.12849875871324912, 0.16078347398433834, 0.2651102305389941, 0.1768712911871262, 0.2880317287053913, 0.1515914555056952, 0.15156830049818382, 0.26996969478204846, 0.1845765206962824, 0.19951185677200556, 21.513115614652634, 82.0076934993267, 116.64594322443008, 98.5489659011364, 94.82369139790535, 123.61711755394936, 84.19797956943512, 33.74076068401337, 41.00464090704918, 67.40995600819588, 104.02257978916168, 114.60270166397095, 58.47576141357422, 61.036899983882904, 55.54070010781288, 72.55746379494667, 27.580208256840706, 5.404891725629568, 0.9859350544866174, 0.18348051700741053, 0.4928429058054462, 0.6077596347313374, 0.3619752562372014, 0.33273627050220966, 0.650390200316906, 4.00893023237586, 4.161221785470843, 4.648207454010844, 7.394853970035911, 7.183115081861615, 6.294065387919545, 12.017561942338943, 17.703227251768112, 22.74947427213192, 23.094919435679913, 25.092886425554752, 18.98924734443426, 23.877937719225883, 27.464641258120537, 21.23134173452854, 21.57036904245615, 25.118804834783077, 22.75136087089777, 12.81397545710206, 34.22877989709377, 28.114991560578346, 31.236402466893196, 36.98282651603222, 26.715655848383904, 22.445057407021523, 25.698775313794613, 23.657872527837753, 40.71505084633827, 36.74206383526325, 29.02594517916441, 34.95558589696884, 28.12774747610092, 26.96933403611183, 31.61293376237154, 31.00002285093069, 24.053609892725945, 24.668534696102142, 21.175055354833603, 13.73266451060772, 9.795189443975687, 3.0266753397881985, 0.7370485283900052, 0.25345595902763307, 0.37342006398830563, 0.2236247542896308, 0.3568305401131511, 0.10414379488793202, 0.31517040682956576, 3.8710211450234056, 49.96030814945698, 77.36965477466583, 69.49122592806816, 89.97702866792679, 119.8027454316616, 202.773155272007, 88.29890951514244, 44.82915088534355, 41.8572011590004, 51.302194744348526, 61.83848977088928, 91.52319610118866, 86.71602085232735, 94.93416666984558, 99.73377272486687, 110.00075340270996, 99.65572491288185, 19.80637449771166, 0.6884860654827207, 0.2245132386451587, 0.09795072095585056, 0.27898114873096347, 0.1755949159269221, 0.09549927359330468, 0.10330234043067321, 0.09235797770088539, 0.24435329512925819, 0.20263947488274425, 0.13826732203597203, 0.12345340874162503, 0.1252682789345272, 0.1489563414361328, 0.17382919817464426, 0.1378459157422185, 0.13419736933428794, 0.18277467519510537, 0.12663466186495498, 0.17410230851965025, 0.09374462126288563, 0.0846524810185656, 0.24700734880752861, 0.19383620820008218, 0.09252256379113533, 0.13221470697317272, 0.18764972453936934, 0.08552181054255925, 0.16334619896952063, 0.11468674478237517, 0.17499365756521001, 0.11959443378145806, 0.19856031954986975, 0.06861913003376685, 0.15059725963510573, 0.12435541502782144, 0.1149482702021487, 0.11459567584097385, 0.1040255707630422, 0.13186172669520602, 0.22974879364483058, 0.11684228302328847, 0.15358490869402885, 0.09344906837213784], [0.05819653051730711, 0.049399189883843064, 0.03857411997159943, 0.04937772326229606, 0.03192324482370168, 0.16559671727009118, 0.08144425082718953, 0.06913117482326925, 0.02461760803271318, 0.018139196872652974, 0.07454090446117334, 0.07518013109802268, 0.03806986773270182, 0.0463746338209603, 0.00893783753781463, 0.0837761456205044, 0.07116071865311824, 0.07403328287182376, 0.06588823438505642, 0.047937800918589346, 0.041030049906112254, 0.056693855876801535, 0.049558532700757496, 0.0632216755184345, 0.028001135360682383, 0.01941433089086786, 0.05175060316105373, 0.012638229454751126, 0.014420219722524052, 0.027878198598045856, 0.0433171523764031, 0.03687622338475194, 0.046819959534332156, 0.03511058726871852, 0.06554497624165379, 0.028731256534229033, 0.07934567242045887, 0.3470883972477168, 2.33147865626961, 22.034061960875988, 63.16000185906887, 88.68642792105675, 65.45941427350044, 59.79269094765186, 65.49197092652321, 84.27879363298416, 84.18522745370865, 37.210966274142265, 53.76640051603317, 41.35942026972771, 34.238188192248344, 34.857307970523834, 45.48314519226551, 45.82961060106754, 19.204771779477596, 4.150970410555601, 0.09328935819212347, 0.18911007820861414, 0.04258712026057765, 0.45219868363346905, 0.3313529072329402, 0.14244997728383169, 0.269793271436356, 1.254606822039932, 0.6726048176642507, 2.3861244739964604, 1.4290122385136783, 12.610571421682835, 39.114588126540184, 66.40525951981544, 74.46723371744156, 72.51014113426208, 61.191855669021606, 42.89486467838287, 22.535878233611584, 9.194678217172623, 5.389130646362901, 2.258312157355249, 0.599926058202982, 6.227322919294238, 7.182758850976825, 19.455140344798565, 12.030266560614109, 5.9484615828841925, 7.904326831921935, 9.863520227372646, 10.198852233588696, 10.203180201351643, 11.517776660621166, 13.674831613898277, 11.558073498308659, 15.45246647670865, 20.36872912198305, 8.065008334815502, 4.963458012789488, 3.44495618250221, 4.094832222908735, 6.935158912092447, 17.169528789818287, 26.848321929574013, 29.72723364830017, 31.944619864225388, 30.16124065965414, 25.548069700598717, 20.938776433467865, 6.775100100785494, 1.972360520157963, 0.7538055698387325, 0.04197414709778968, 0.2568416961003095, 0.1857862510951236, 0.15900312107987702, 0.029784833495796192, 0.08671833813423291, 0.3050581697607413, 4.330254765227437, 27.73773830384016, 57.10591971874237, 52.34377585351467, 44.67971630394459, 86.45667716860771, 93.1817615032196, 36.4982271194458, 17.578149363398552, 22.61601023375988, 30.78980103135109, 51.736218854784966, 62.82800227403641, 62.847252041101456, 69.61715877056122, 84.20142218470573, 77.43612840771675, 28.01546160131693, 1.0132694221101701, 0.07367946396698244, 0.038785910364822485, 0.1302530473913066, 0.052251144661568105, 0.0334657690837048, 0.049146425517392345, 0.024663437507115304, 0.136280236474704, 0.04329042763856705, 0.05510452436283231, 0.04138518612307962, 0.03417424552026205, 0.01769337020959938, 0.04010961980384309, 0.03403074013476726, 0.054087793178041466, 0.010563983287283918, 0.05366723293263931, 0.03784479289606679, 0.02657393713889178, 0.015888634043221828, 0.08211287393351085, 0.08056027130805887, 0.0748648370790761, 0.06859573753899895, 0.08752204696065746, 0.01982524321647361, 0.008905637605494121, 0.03384363357326947, 0.018179107719333842, 0.0603133397817146, 0.021131209759914782, 0.034848145296564326, 0.1039323273289483, 0.05748248426243663, 0.034461033646948636, 0.024344540361198597, 0.0919271090242546, 0.05305129860062152, 0.025933517499652226, 0.03946395132516045, 0.07783101580571383, 0.04113202099688351, 0.03988054479123093, 0.026488681069167797, 0.03293995374406222, 0.023376937497232575, 0.07342400931520388, 0.05730797565774992, 0.08426749191130511, 0.02714569513045717, 0.03003741232532775, 0.0313509524858091, 0.016718993392714765, 0.024010549786908086, 0.012579033900692593, 0.019301930769870523, 0.05646433557558339, 0.03191343363141641, 0.09493921184912324, 0.010686091627576388, 0.01430862668712507, 0.017653910217632074, 0.06786442521843128, 0.06558232853421941, 0.032972916233120486, 0.03707506701175589, 0.049486384814372286, 0.03054739579965826, 0.04867686497163959, 0.03661041577288415, 0.008757830546528567, 0.07097773472196423, 0.021372389201133046, 0.018437139478919562, 0.06846946111181751, 0.10363114153733477, 0.04821068861929234, 0.04114073009986896, 0.14363337628310546, 0.4900762683246285, 16.92182958126068, 70.50718501210213, 102.1304789185524, 91.58795982599258, 88.83494675159454, 90.41649788618088, 131.76303684711456, 94.07404482364655, 23.086254000663757, 19.951334819197655, 44.0342753380537, 45.20878091454506, 40.935606211423874, 50.25679484009743, 58.652364537119865, 26.808619759976864, 4.879575138911605, 0.18318135727895424, 0.4534036642871797, 0.13163630675990134, 0.40659572754520923, 1.2272683577612042, 0.7103682006709278, 0.9722518699709326, 1.3325241347774863, 0.1758045281167142, 1.4853065740317106, 1.4634066866710782, 17.79328241944313, 47.64000445604324, 75.6953202188015, 85.26254564523697, 84.87444207072258, 71.44041493535042, 50.39581038057804, 26.835056841373444, 12.528559472411871, 5.967657677829266, 2.9766194382682443, 1.5938448999077082, 2.5670738518238068, 3.15475981682539, 4.700576243922114, 8.416061997413635, 9.032507669180632, 8.555903043597937, 2.7092387108132243, 1.1170933884568512, 3.8092172238975763, 4.08119760453701, 1.6739842621609569, 0.7354228687472641, 1.7457215627655387, 3.702186942100525, 3.1134448712691665, 2.296066456474364, 1.871836083009839, 5.871639680117369, 11.126805189996958, 23.9627605676651, 34.247296303510666, 39.25214074552059, 42.50433303415775, 44.03225764632225, 40.11849045753479, 28.993337228894234, 11.009165402501822, 0.7747278409078717, 0.6554243958089501, 0.10970759438350797, 0.8446231309790164, 0.4975099163129926, 0.19668176566483453, 0.14487601350992918, 0.07306582658202387, 0.32378665229771286, 5.659953989088535, 33.8143665343523, 56.234915256500244, 48.80553111433983, 55.69307193160057, 68.7729960680008, 42.29109227657318, 33.14405970275402, 27.650272697210312, 39.08474452793598, 58.062537387013435, 73.46708938479424, 76.94970890879631, 69.84050318598747, 83.0301958322525, 94.09203305840492, 84.42641571164131, 24.814057387411594, 0.4577550245448947, 0.06582399408216588, 0.0853279689908959, 0.16860556206665933, 0.06602460402064025, 0.049708290680428036, 0.009799496037885547, 0.04522046430793125, 0.06744528247509152, 0.01880494786746567, 0.03269314511271659, 0.0821780641854275, 0.04287830932298675, 0.03263467500801198, 0.05916868831263855, 0.042769317515194416, 0.039369212463498116, 0.0938521881471388, 0.043568154142121784, 0.026840065729629714, 0.062185804345062934, 0.012247800405020826, 0.08470526998280548, 0.04054655924846884, 0.06074722528865095, 0.03641443312517367, 0.05453699290228542, 0.040070657050819136, 0.016469783913635183, 0.03531352384015918, 0.021997861986164935, 0.059360418454161845, 0.0587299120525131, 0.021329574701667298, 0.01189508730021771, 0.06023879846907221, 0.022678572822769638, 0.02191695304645691, 0.05913788918405771, 0.06298138294368982, 0.03117200954875443, 0.014924685328878695, 0.028602972597582266, 0.08989873778773472, 0.1292157475836575, 0.11662843317026272, 0.15343158098403364, 0.057083045539911836, 0.2985164645360783, 0.14967441384214908, 0.16090327146230265, 0.09109033009735867, 0.038460411815322004, 0.11651828361209482, 0.13994680222822353, 0.09121368988417089, 0.13059093238553032, 0.1634097268106416, 0.1464122295146808, 0.10377792350482196, 0.19549587304936722, 0.20032686850754544, 0.15755464177345857, 0.16718087601475418, 0.15779006585944444, 0.23384875879855826, 0.1515129956533201, 0.14906733704265207, 0.17700320051517338, 0.1569605228723958, 0.166183652181644, 0.14869185484712943, 0.13670936110429466, 0.1997632221900858, 0.14395506761502475, 0.07650415966054425, 0.1603114086901769, 0.2616400667466223, 0.19835183542454615, 0.25814879627432674, 0.4000298283062875, 5.56827868334949, 45.14977008104324, 98.3946941792965, 116.88013225793839, 90.0114244222641, 84.8830372095108, 97.11611598730087, 97.10131198167801, 105.03589421510696, 59.30945947766304, 81.00580886006355, 75.17619207501411, 52.79962979257107, 54.50750894844532, 74.80596274137497, 77.28501051664352, 34.99200314283371, 7.127572037279606, 0.629646519664675, 0.7266046106815338, 0.37229796638712287, 0.5542633740697056, 0.9090797847602516, 0.6234548706561327, 1.0963924555107951, 4.0171292424201965, 4.626641711220145, 5.950284535065293, 4.992440482601523, 20.748070366680622, 44.666173830628395, 73.93574103713036, 83.8051338493824, 81.50933504104614, 69.4999198615551, 49.180966168642044, 28.356979675590992, 15.270738378167152, 15.437109600752592, 12.527696918696165, 13.882892299443483, 21.66449949145317, 22.310050651431084, 39.8545528203249, 27.419965155422688, 15.705088321119547, 33.92392985522747, 30.95116127282381, 33.74078348278999, 31.407383792102337, 34.69737455248833, 30.243386551737785, 30.631398931145668, 33.91639105975628, 41.147406846284866, 26.907482855021954, 21.23995777219534, 16.484626941382885, 14.0809072740376, 13.969322461634874, 25.388096384704113, 35.41913442313671, 39.46145251393318, 42.35008031129837, 39.46367159485817, 36.69559992849827, 37.42744445800781, 18.03715903311968, 8.98216512054205, 2.644914099946618, 0.5252289539203048, 0.4700665717246011, 0.3596921428106725, 0.27671635150909424, 0.16391732613556087, 0.24960827955510467, 0.4996096598915756, 8.600326459854841, 50.560740530490875, 90.44296726584435, 75.06750270724297, 53.25943171977997, 118.52045863866806, 127.5183454155922, 50.470692962408066, 26.94432757794857, 34.664392322301865, 44.719177186489105, 72.19975098967552, 84.54795598983765, 84.18607100844383, 87.89084181189537, 97.83687651157379, 108.31870526075363, 55.12759767472744, 3.2370909489691257, 0.49852648051455617, 0.3396361361956224, 0.40330074029043317, 0.15211982012260705, 0.1175216153205838, 0.11989693317445926, 0.11691469437209889, 0.2840306918369606, 0.12487765692640096, 0.1763804495567456, 0.12579232425196096, 0.13704911631066352, 0.12863077194197103, 0.1863478045561351, 0.13397387898294255, 0.1566670331521891, 0.14639006898505613, 0.16911948448978364, 0.1751409738790244, 0.1393912750063464, 0.0908291683299467, 0.19560427113901824, 0.1787989158765413, 0.1838079674053006, 0.13409038132522255, 0.2163303628913127, 0.15673977846745402, 0.07767031114781275, 0.12694413744611666, 0.11183686801814474, 0.15162590600084513, 0.17840657208580524, 0.1291733857942745, 0.1684568208293058, 0.14312199200503528, 0.12438826990546659, 0.14615050371503457, 0.21635832701576874, 0.19409956672461703, 0.1378319930518046, 0.1523685286520049, 0.1533762612962164], [0.05528482543013524, 0.02757271948212292, 0.04993421527615283, 0.06302712892647833, 0.03499545418890193, 0.07173668462201022, 0.013092312510707416, 0.04166776256170124, 0.012719338774331845, 0.08234715511207469, 0.03108471071755048, 0.04636870035028551, 0.026584544284560252, 0.0436685407476034, 0.0521044331981102, 0.0480447963491315, 0.05296127979818266, 0.09428703473531641, 0.025052721794054378, 0.032506587740499526, 0.033783964900067076, 0.027557540706766304, 0.037145096066524275, 0.034445519049768336, 0.04672936185670551, 0.04447290637472179, 0.039621746764169075, 0.05808221751067322, 0.06197101938596461, 0.015150686922424939, 0.016301392461173236, 0.054367159827961586, 0.0739534426247701, 0.09070931148016825, 0.1722497891751118, 0.20933333522407338, 0.43445425922982395, 14.787798542529345, 68.77269968390465, 80.80161541700363, 82.87884995341301, 64.54794198274612, 61.14485219120979, 39.15952071547508, 36.65411755442619, 29.468864612281322, 25.32601721584797, 67.52159401774406, 69.33288842439651, 36.63915775716305, 39.54762049019337, 41.095277443528175, 29.427458234131336, 6.7882459703832865, 0.2723305259132758, 0.19809855526546016, 0.131634570134338, 0.24908687628339976, 0.07046386424917728, 0.15119829535251483, 0.10032953432528302, 0.33151724841445684, 0.210349231492728, 1.3056326215155423, 1.6038427571766078, 15.532028507441282, 66.51480004191399, 121.5048260986805, 129.63680773973465, 128.99792522192, 125.592882335186, 131.3437369465828, 134.39921379089355, 135.33727705478668, 131.75153106451035, 111.3337142765522, 100.1649659872055, 78.61137494444847, 46.817679181694984, 13.86430749669671, 4.835398234426975, 20.74143022298813, 21.40314381569624, 18.980321623384953, 12.497645281255245, 4.292276278138161, 7.8164199739694595, 5.015492895618081, 9.818346351385117, 5.285540604963899, 1.8777775391936302, 4.382400317117572, 4.94438398629427, 3.951922603882849, 17.70108226686716, 53.74810449779034, 90.83736330270767, 116.26038551330566, 133.4694492816925, 136.2177962064743, 143.0988621711731, 138.15923362970352, 139.9933648109436, 141.33831024169922, 129.193933904171, 94.84798729419708, 45.408897176384926, 18.096857629716396, 1.4514072868041694, 2.7887085964903235, 8.97889919579029, 7.1033763606101274, 0.7883385324385017, 0.1387238022289239, 0.15840869047679007, 0.023106270673451945, 0.252357610152103, 10.25748498737812, 33.22240009903908, 52.35989838838577, 51.194892302155495, 66.64023891091347, 79.50096800923347, 70.48318549990654, 30.669926963746548, 19.832167513668537, 20.219495929777622, 24.135066121816635, 58.41662518680096, 56.32220797240734, 70.53209647536278, 77.61611714959145, 88.64023759961128, 49.67577941715717, 3.849369431845844, 0.5282984767109156, 0.06556998661835678, 0.03693004393426236, 0.06853671453427523, 0.011500474392960314, 0.0773724724422209, 0.07528756439569406, 0.07591180707095191, 0.09005095227621496, 0.01812955451896414, 0.02391285903286189, 0.017268570445594378, 0.02969987614051206, 0.016518476222699974, 0.018883960619859863, 0.042599566077115014, 0.04697765478340443, 0.06835014602984302, 0.03489306749543175, 0.015182949009613367, 0.017457328285672702, 0.08284326599095948, 0.004743011068057967, 0.04403331746289041, 0.06567154952790588, 0.01107449090341106, 0.06335751080769114, 0.026216644982923754, 0.06957535762921907, 0.02443993231281638, 0.0464656619442394, 0.029752646551060025, 0.03731624274223577, 0.010678806520445505, 0.06434548005927354, 0.01095281857487862, 0.04962138147675432, 0.029441918595694005, 0.053999258670955896, 0.012259660852578236, 0.06743541191099212, 0.022433894155255985, 0.061214577945065685, 0.032045491388998926, 0.052539302050718106, 0.03477954858681187, 0.022135515537229367, 0.029827672115061432, 0.03477174861473031, 0.028954372100997716, 0.16463504231069237, 0.03077271925576497, 0.019181413408659864, 0.03735717589734122, 0.020339189759397414, 0.03297063783975318, 0.05244364292593673, 0.0330125951586524, 0.03599078925617505, 0.01832756508520106, 0.026491328681004234, 0.07028853186056949, 0.05192731594434008, 0.0531282333395211, 0.02085486179566942, 0.06396955999662168, 0.08906854913220741, 0.01617988062207587, 0.06169467327708844, 0.02442050288664177, 0.06530811981065199, 0.0780888601730112, 0.01258354059245903, 0.014211802390491357, 0.05905763333430514, 0.13922843296313658, 0.13240616623079404, 0.7096198189537972, 10.939176958054304, 66.49124890565872, 95.27860298752785, 97.69485533237457, 90.84972023963928, 87.63022139668465, 75.00722274184227, 60.93101866543293, 47.769148126244545, 44.42845858633518, 30.315128602087498, 44.11717168986797, 41.96339786052704, 41.17399401962757, 52.779312282800674, 39.500138238072395, 10.709754768759012, 0.2464803497423418, 0.16273806832032278, 0.14093258214415982, 0.13416842557489872, 0.4182627046247944, 0.4184125590836629, 0.3627667418913916, 0.674731278559193, 0.9309275436680764, 1.1790267401374876, 3.1925846496596932, 19.985838867723942, 75.57008653879166, 130.88747262954712, 135.32438814640045, 131.08629316091537, 130.38603633642197, 132.51301020383835, 136.87160432338715, 140.74501007795334, 133.57139021158218, 119.9010081589222, 111.30931198596954, 90.0492475926876, 57.57953770458698, 20.73035191744566, 5.856183059513569, 0.8469179703388363, 2.145416890271008, 6.036856714636087, 1.1132438387721777, 3.2915078289806843, 5.304789897054434, 4.890423081815243, 6.92618521861732, 3.753712414763868, 0.6799112912267447, 1.2648090370930731, 3.1121054431423545, 7.238165577873588, 25.843661539256573, 67.91313260793686, 102.53647193312645, 126.29824608564377, 142.17268466949463, 146.39424294233322, 150.98497420549393, 147.7038350701332, 144.78657960891724, 147.67694771289825, 139.51322257518768, 106.10781669616699, 59.21892173588276, 24.066120721399784, 2.774632964283228, 2.059031375683844, 9.421462398022413, 7.567938007414341, 1.1647687177173793, 0.28653989313170314, 0.08047484268900007, 0.03435285449086223, 0.27681695704814047, 15.057615414261818, 41.31003051996231, 57.96759568154812, 48.90208013355732, 60.31178489327431, 42.63129182159901, 29.79117091745138, 28.55815228074789, 26.944734156131744, 42.977050468325615, 49.01000574231148, 86.4928512275219, 75.21650791168213, 80.42687952518463, 89.12145897746086, 101.13811656832695, 50.29840260744095, 2.1796917635947466, 0.407848086906597, 0.10563236501184292, 0.021759523115179036, 0.08241189265390858, 0.09606214807718061, 0.03792073315707967, 0.0775977291050367, 0.018699149150052108, 0.035829401822411455, 0.021680938953068107, 0.02707382183871232, 0.03762142499908805, 0.017879157603601925, 0.03105821604549419, 0.04682067570684012, 0.05685477204679046, 0.00116230437924969, 0.041746081406017765, 0.01757903864927357, 0.006929328028491, 0.035845075981342234, 0.15942434925818816, 0.03812403338088188, 0.045498699182644486, 0.03907279125996865, 0.041250315625802614, 0.043568098481046036, 0.03334265791636426, 0.008381201732845511, 0.04573194877593778, 0.029421444596664514, 0.023321189219132066, 0.043285310530336574, 0.07619935960974544, 0.021947909881419037, 0.022475502664747182, 0.03712303201609757, 0.03548994347511325, 0.020665771844505798, 0.027334566148056183, 0.04017135906906333, 0.1717338926391676, 0.2564118738519028, 0.10937472630757838, 0.1672552095260471, 0.15376474591903389, 0.1959354619611986, 0.13699970411835238, 0.14341944479383528, 0.08072366996202618, 0.25935808138456196, 0.15758244262542576, 0.1961360199493356, 0.1385204982943833, 0.12180780759081244, 0.15522152243647724, 0.11896610929397866, 0.1834795076865703, 0.21540760615607724, 0.09567887333105318, 0.1292381456005387, 0.21206852048635483, 0.12997575133340433, 0.10815251298481598, 0.13478737673722208, 0.2017648983746767, 0.20052235020557418, 0.11724607073119842, 0.17967188934562728, 0.16252385481493548, 0.19395796494791284, 0.24484768422553316, 0.1751330032129772, 0.17910229100380093, 0.280814787838608, 0.28960766445379704, 0.5146715173032135, 0.9411846182774752, 30.079868026077747, 107.60767981410027, 115.76824352145195, 114.35636848211288, 85.99855095148087, 86.02549150586128, 56.398857459425926, 49.989460185170174, 51.718261018395424, 36.181282326579094, 105.56885361671448, 113.5992819070816, 64.1737912595272, 68.34125563502312, 76.24703541398048, 47.84631818532944, 13.014273159205914, 0.7743537391070276, 0.3530391748063266, 0.28624469647184014, 0.50936718005687, 0.3566707408754155, 0.28064795304089785, 1.0243461839854717, 1.791200372390449, 5.3029536455869675, 7.264973614364862, 5.752802956849337, 18.170499578118324, 73.64590018987656, 133.8225719332695, 142.58605688810349, 141.13388121128082, 141.54577910900116, 144.84667718410492, 145.96260130405426, 148.23091238737106, 135.65232574939728, 118.97590219974518, 109.29249420762062, 87.73438140749931, 53.85164514183998, 18.50544210523367, 13.574929274618626, 42.41515941917896, 46.003447473049164, 42.72927716374397, 30.019120685756207, 18.502615056931973, 17.820496559143066, 15.49119209870696, 19.41809993237257, 15.17927348613739, 13.277877364307642, 17.789307832717896, 14.638790488243103, 7.48829523101449, 21.9249090179801, 62.975502759218216, 97.6877573132515, 121.84164002537727, 142.87092000246048, 149.43769723176956, 153.96015375852585, 153.8020670413971, 154.79879915714264, 154.41655486822128, 143.20113748311996, 102.43003964424133, 54.815474823117256, 26.95542298257351, 8.252339232712984, 7.868418283760548, 11.790067199617624, 8.844926934689283, 0.8371472696308047, 0.3597125964006409, 0.2542490774067119, 0.13519119413103908, 0.705235447967425, 19.3074194714427, 59.9192925542593, 89.99772995710373, 75.41059389710426, 97.2013758122921, 108.89392599463463, 99.05560791492462, 42.8003903478384, 30.766154900193214, 33.09348821640015, 37.76627227663994, 75.40115520358086, 76.39911845326424, 92.46377483010292, 91.77924156188965, 111.71305552124977, 81.4945462346077, 9.970274548977613, 1.0128041845746338, 0.23255771870026365, 0.08792397929937579, 0.15789467899594456, 0.1818801200715825, 0.31670380267314613, 0.14062441274290904, 0.20081484544789419, 0.15734853252070025, 0.1507914499961771, 0.13391321583185345, 0.18893169559305534, 0.09252191812265664, 0.1140821170702111, 0.19001506792847067, 0.18589510931633413, 0.09531213363516144, 0.19626981433248147, 0.17335956712486222, 0.08122922838083468, 0.1672241135383956, 0.26124153344426304, 0.12321103815338574, 0.07514948782045394, 0.13450590980937704, 0.07503673332394101, 0.10939899453660473, 0.10333717684261501, 0.14942601701477543, 0.12237092698342167, 0.20224057050654665, 0.09798826620681211, 0.10490340529941022, 0.09565844942699187, 0.13617186807096004, 0.0883375559351407, 0.19512223138008267, 0.11223512672586367, 0.14723592437803745, 0.1310804084641859, 0.20203284337185323], [0.10077488972456194, 0.05293191301461775, 0.029532829830714036, 0.04851965211855713, 0.06054191013390664, 0.036123604004387744, 0.04877615690929815, 0.02987571690027835, 0.029724222295044456, 0.057692486079758964, 0.06400032201781869, 0.02325221401406452, 0.03536555952450726, 0.027617873602139298, 0.03605199046432972, 0.1367413773550652, 0.04707093903562054, 0.09601860627299175, 0.03181537365890108, 0.03052252457564464, 0.059017201128881425, 0.008171263925760286, 0.031405199770233594, 0.05157690720807295, 0.02928717152826721, 0.04432976835232694, 0.09813740820391104, 0.013764569357590517, 0.03507199558953289, 0.014716918303747661, 0.03394053208467085, 0.06138704935438, 0.028829915790993255, 0.022101796057540923, 0.19980346143711358, 6.583154825493693, 56.57910078763962, 95.62256053090096, 88.78841444849968, 82.53097862005234, 67.86453321576118, 61.894050389528275, 34.43038947880268, 35.56975834071636, 32.70861066877842, 66.98646873235703, 48.15853603184223, 39.66762185096741, 39.430867955088615, 33.86683791875839, 35.52069537341595, 11.138548459857702, 1.252149660140276, 0.5320182989817113, 0.07691412945860066, 0.236079758615233, 0.10262037350912578, 0.0967171230877284, 0.4038516216678545, 1.2883075699210167, 2.1291136275976896, 2.209097435697913, 4.636283218860626, 26.91837877035141, 80.73252752423286, 125.22788152098656, 125.72525963187218, 113.06430101394653, 103.79615753889084, 103.34394380450249, 103.68366077542305, 99.93073895573616, 103.54634374380112, 105.50705373287201, 105.69294735789299, 109.40417021512985, 120.53482174873352, 125.52709266543388, 135.7736000418663, 129.2591080069542, 81.34418070316315, 7.95117499306798, 2.057025320827961, 3.7815038859844208, 2.9181904485449195, 9.097832813858986, 39.668647795915604, 56.053360998630524, 58.83246727287769, 30.455622263252735, 6.591835934668779, 4.513925984501839, 40.18140748143196, 88.73562008142471, 114.66254845261574, 122.25929081439972, 119.1512855887413, 113.6994369328022, 111.53758093714714, 114.49074447154999, 112.35918805003166, 107.73474499583244, 103.0540269613266, 105.89951187372208, 114.00836795568466, 124.39761087298393, 127.05953523516655, 106.90584227442741, 66.1657127737999, 24.95014898478985, 0.632089254213497, 0.5902565270662308, 0.657389780972153, 0.3429472725838423, 0.087099208321888, 0.015364668506663293, 0.12254343178938143, 0.20688119024271145, 2.2965651797130704, 20.72934117168188, 40.393071323633194, 42.46884673833847, 65.69764629006386, 73.21988224983215, 75.05498617887497, 74.45477798581123, 26.26581508666277, 20.937602296471596, 8.261666782200336, 39.166854321956635, 56.1841955780983, 70.10391265153885, 71.08866021037102, 83.5866379737854, 71.16223186254501, 13.285248968750238, 0.6011595076415688, 0.0416461697750492, 0.06870323020848446, 0.049904054394573905, 0.044442218568292446, 0.10028007018263452, 0.0451097061886685, 0.04615493213350419, 0.05832794260641094, 0.06450395085266791, 0.07681143106310628, 0.02506391338101821, 0.04198064831143711, 0.010821934338309802, 0.04551786514639389, 0.005773857437816332, 0.07653797190869227, 0.025205196034221444, 0.030087145496509038, 0.014511543777189218, 0.00676060307341686, 0.026802975044120103, 0.06980946069234051, 0.040969412730191834, 0.038713350586476736, 0.05382581504818518, 0.042998210701625794, 0.029070306700305082, 0.0510830005077878, 0.08751972403842956, 0.02392532525846036, 0.06486469399533235, 0.05726858988055028, 0.007932841563160764, 0.05707496726245154, 0.026578592260193545, 0.03414086371776648, 0.03504605752823409, 0.019188894257240463, 0.01913675652758684, 0.03728754760231823, 0.0390345372579759, 0.02949366669781739, 0.049360115808667615, 0.02456857433571713, 0.0674583665386308, 0.04511645973252598, 0.006210620158526581, 0.056512270894018, 0.029921900750196073, 0.03441911714617163, 0.0696711392083671, 0.04487125785090029, 0.022259394827415235, 0.0005207691992836772, 0.04767554077261593, 0.001130225741690083, 0.049663843456073664, 0.0354714306013193, 0.04697920216131024, 0.051709054023376666, 0.031673975972807966, 0.024996049542096443, 0.028659661547862925, 0.011957677252212306, 0.04254454324836843, 0.010535192595853005, 0.01465186627683579, 0.06213599510374479, 0.07710207093623467, 0.03773845426621847, 0.06315693055512384, 0.11003804305801168, 0.02443121949909255, 0.03183125190844294, 2.386228018440306, 48.763501569628716, 99.03102323412895, 107.13121578097343, 99.55461233854294, 94.61015805602074, 93.7114454805851, 62.76062808930874, 35.66472664475441, 29.758937247097492, 32.23763734102249, 23.60576782375574, 45.430909395217896, 44.21704553067684, 46.75973989069462, 48.79224322736263, 16.867370903491974, 1.583529047202319, 0.5057560675777495, 0.04470213723834604, 0.11135672073578462, 0.6379040109459311, 0.505938398418948, 0.6984098860993981, 0.7221277977805585, 1.4099961589090526, 0.2507721452275291, 7.591666309162974, 33.98304708302021, 90.69319143891335, 132.44049489498138, 128.81555020809174, 116.25129640102386, 107.205281406641, 107.45973855257034, 108.97821307182312, 106.41254514455795, 109.44478243589401, 110.63587412238121, 112.48737037181854, 114.1783632338047, 124.47714820504189, 130.94875574111938, 140.86028069257736, 139.21917915344238, 98.83662566542625, 13.260582592338324, 0.46488115622196347, 3.065703995525837, 1.8685227795504034, 14.115154836326838, 50.710600689053535, 68.69576901197433, 71.58529356122017, 41.48678943514824, 12.25179847329855, 9.191710576415062, 54.98026058077812, 102.16316476464272, 121.98601707816124, 122.00858786702156, 119.38216879963875, 113.69002863764763, 114.701017588377, 115.82603842020035, 112.37205415964127, 109.5059135556221, 107.83741548657417, 112.18913957476616, 115.23342981934547, 126.26066610217094, 132.73473590612411, 117.17580199241638, 80.58330193161964, 31.927516981959343, 2.106620972044766, 1.847570228856057, 0.16113664722070098, 0.25762893666978925, 0.2506790799088776, 0.040519849353586324, 0.07472693861927837, 0.2569916989887133, 2.7592449774965644, 25.527778789401054, 48.578842878341675, 45.649268478155136, 59.54403609037399, 55.211554169654846, 38.856080397963524, 45.59158377349377, 24.32160761207342, 18.340348564088345, 22.814977057278156, 49.30773876607418, 68.28954041004181, 81.84984996914864, 81.61981031298637, 95.97775787115097, 77.63713762164116, 11.41240356490016, 0.5832285666838288, 0.07732671161647886, 0.15101400524144992, 0.0011196158129678224, 0.028309545959928073, 0.05268806926324032, 0.07551483227871358, 0.1401993105537258, 0.09953263841453008, 0.04167238614172675, 0.10940936233964749, 0.07037968985969201, 0.07172675468609668, 0.040804206946631894, 0.02839518423570553, 0.08114486103295349, 0.035481638842611574, 0.043787581234937534, 0.043308172389515676, 0.03869747233693488, 0.03810095258813817, 0.026474411424715072, 0.06843810537247919, 0.052209328350727446, 0.06663463456789032, 0.026131212653126568, 0.020660662157752085, 0.031866570716374554, 0.020100600413570646, 0.027384052555134986, 0.028315548079262953, 0.02972597190819215, 0.019063226391153876, 0.0552002465701662, 0.03203988075256348, 0.015173806677921675, 0.10305054456694052, 0.09937871698639356, 0.0070945866900729015, 0.04337265760113951, 0.2282596446457319, 0.10695653458242305, 0.06744270722265355, 0.17698311799904332, 0.12735484197037295, 0.144870298972819, 0.11941494536586106, 0.1840370980789885, 0.12558502756292, 0.11581224884139374, 0.10740594952949323, 0.16816877847304568, 0.13191388483392075, 0.134385785786435, 0.14101142791332677, 0.16813398658996448, 0.16233147529419512, 0.20123147231061012, 0.1014335457875859, 0.16637701133731753, 0.17527080519357696, 0.12300000846153125, 0.14271541382186115, 0.14464974752627313, 0.19080894329817966, 0.12602231581695378, 0.17698415700579062, 0.10257752932375297, 0.21378939767600968, 0.19502229377394542, 0.1063867803895846, 0.23279974790057167, 0.26812269701622427, 0.15330385736888275, 0.2340334199834615, 18.416490778326988, 94.55854162573814, 134.8802375793457, 115.18832623958588, 108.69597941637039, 91.26541033387184, 83.6506949365139, 46.74251541495323, 56.45412549376488, 55.754324644804, 92.69741669297218, 76.03542476892471, 63.82521316409111, 60.13344906270504, 58.419600427150726, 62.06466883420944, 19.368522092700005, 3.258657641708851, 0.9707611030898988, 0.13452804065309465, 0.22470382216852158, 0.6359576841350645, 0.31057538464665413, 1.6025688755325973, 3.403070317581296, 9.655697979032993, 9.215537197887897, 9.19199176132679, 30.956841967999935, 92.68753722310066, 141.56152546405792, 139.94073003530502, 123.73564839363098, 113.07693153619766, 111.55400365591049, 111.48168593645096, 110.47399520874023, 115.78196078538895, 115.5739751458168, 115.21077543497086, 118.42046320438385, 134.05507385730743, 140.57692229747772, 155.48976927995682, 149.6229448914528, 98.77231791615486, 11.66010657325387, 11.356127634644508, 14.834458138793707, 9.992725644260645, 14.347340427339077, 57.235846146941185, 71.8548434972763, 81.99887797236443, 50.927322059869766, 11.581354849040508, 7.069307388737798, 53.09474095702171, 105.06560862064362, 133.63455802202225, 126.23125568032265, 124.38827097415924, 117.64310091733932, 119.10415291786194, 118.87180298566818, 120.01452326774597, 115.66174283623695, 112.17017099261284, 118.33448141813278, 127.30553403496742, 138.13681483268738, 143.89175802469254, 119.04936745762825, 76.01413071155548, 32.77021676301956, 4.504240779206157, 4.186404459178448, 1.3546499912627041, 0.8057406486477703, 0.30026805179659277, 0.1688116861623712, 0.12476265372242779, 0.283898352063261, 4.475236460566521, 29.92753230035305, 66.62248626351357, 63.03555093705654, 100.67802205681801, 112.63325214385986, 108.30544397234917, 105.53821206092834, 38.19327816367149, 35.760952681303024, 16.696872152388096, 55.16635179519653, 73.19441601634026, 96.44093781709671, 87.90320634841919, 105.45331701636314, 102.27642148733139, 29.293452724814415, 0.9571792662609369, 0.21328559814719483, 0.19733294087927788, 0.08895883001969196, 0.16575074259890243, 0.20643998344894499, 0.1685200518113561, 0.28278302284888923, 0.17100198660045862, 0.26892451336607337, 0.2200837153941393, 0.15042646176880226, 0.22036300040781498, 0.08980020284070633, 0.1560274651274085, 0.11228118441067636, 0.10840280228876509, 0.11481922556413338, 0.09722855189465918, 0.09178843873087317, 0.10766616876935586, 0.05063753378635738, 0.1974289005738683, 0.15092775283847004, 0.17708405008306727, 0.13058431242825463, 0.09869214874925092, 0.13461850845487788, 0.09913567846524529, 0.10692221025237814, 0.11045332663343288, 0.10443545150337741, 0.17816672479966655, 0.1008062603068538, 0.0888249020499643, 0.08730076078791171, 0.13650532986503094, 0.1348296643118374, 0.10570024183834903, 0.10436619428219274], [0.05218818456341978, 0.023459323310817126, 0.04874878650298342, 0.05065006866061594, 0.1376457288279198, 0.1457864951225929, 0.041330545500386506, 0.11255245422944427, 0.016097808365884703, 0.018914498141384684, 0.012838061065849615, 0.03252326750953216, 0.027511377265909687, 0.06233683510799892, 0.016859545030456502, 0.0377123974612914, 0.0475603297672933, 0.07331856497330591, 0.18145660607842728, 0.10474848939338699, 0.07416856897179969, 0.07060464224196039, 0.12351702564046718, 0.10546006800723262, 0.038622392967226915, 0.11439963011071086, 0.22641450224909931, 0.23604502610396594, 0.22428562195273116, 0.11928988606086932, 0.08923483474063687, 0.037972958089085296, 0.01740795691148378, 0.4337130318162963, 14.455441776663065, 96.84245467185974, 95.52979990839958, 91.14462241530418, 76.94871336221695, 75.03961980342865, 51.56246177852154, 28.962439186871052, 52.017681151628494, 80.9688064455986, 82.47490882873535, 58.1803272664547, 41.13536149263382, 30.361476615071297, 30.916752219200134, 22.044228315353394, 3.191410512663424, 0.6235793139785528, 0.17101877398090437, 0.13626993546495214, 0.04643669963115826, 0.3353928623255342, 0.23148896667407826, 0.47447676945012063, 1.7102093808352947, 2.4269178975373507, 10.37302253767848, 55.01100093126297, 105.43997973203659, 129.46081638336182, 121.64247751235962, 106.55053094029427, 98.51932749152184, 104.31653961539268, 106.96368277072906, 105.63397452235222, 103.0827534198761, 99.94095280766487, 112.0219637453556, 117.45222195982933, 124.29685547947884, 113.1471897661686, 105.3951421380043, 93.70323032140732, 97.19233989715576, 96.05647444725037, 129.30300325155258, 92.64723658561707, 14.04021905735135, 14.566241931170225, 46.0039072483778, 99.92300257086754, 116.91930055618286, 124.023277759552, 119.26847890019417, 119.68293026089668, 90.64438685774803, 87.35754042863846, 101.25592544674873, 94.12211984395981, 92.97984033823013, 102.23051235079765, 102.22330033779144, 112.39123553037643, 116.78150475025177, 113.85589733719826, 114.87615019083023, 112.67820373177528, 114.17369708418846, 117.32569634914398, 111.94244921207428, 112.31952577829361, 108.37686493992805, 112.84366205334663, 119.06104803085327, 120.17968520522118, 86.34412720799446, 22.04992040991783, 0.8846190723124892, 0.934823522111401, 0.28069830033928156, 0.586767423665151, 0.04081394763488788, 0.12426200089976192, 0.01486645085606142, 0.25613018427975476, 6.161869531497359, 31.46760106086731, 37.428759187459946, 46.70673653483391, 67.96679332852364, 66.40351921319962, 78.01566570997238, 78.45871433615685, 98.92870992422104, 42.82867603003979, 32.18802720308304, 52.584097757935524, 64.84772309660912, 73.73540058732033, 82.74028658866882, 87.99009248614311, 31.571466587483883, 1.1393015342764556, 0.1987439565709792, 0.08741604600800201, 0.1882772400858812, 0.10616579107590951, 0.10743586550233886, 0.061643012377317064, 0.1575022016186267, 0.09528891183435917, 0.24092909996397793, 0.8471150847617537, 0.3157406731043011, 0.23546932730823755, 0.1595165388425812, 0.06467380619142205, 0.11952850880334154, 0.006255885136852157, 0.050484647654229775, 0.06278780856519006, 0.030524444882757962, 0.03220886777853593, 0.026907449027930852, 0.021127643740328494, 0.02190592287661275, 0.035914277541451156, 0.05106990531203337, 0.04166024460573681, 0.03544672450516373, 0.09291820271755569, 0.07326084072701633, 0.04940423648804426, 0.03595266513002571, 0.07017297204583883, 0.07997305438038893, 0.09895229377434589, 0.011810834057541797, 0.0746600711136125, 0.03266425701440312, 0.025747062172740698, 0.03167866263538599, 0.01545526154586696, 0.02434678164718207, 0.07249891481478699, 0.12100492254830897, 0.09292816233937629, 0.05186050781048834, 0.05745965208916459, 0.009951626107067568, 0.09256770863430575, 0.08483615514705889, 0.018638703077158425, 0.041703541501192376, 0.07883184647653252, 0.03527291351929307, 0.015611154303769581, 0.06265284901019186, 0.053532514575636014, 0.18075912084896117, 0.075188161135884, 0.11046206913306378, 0.09794871715712361, 0.014090934364503482, 0.08730925837880932, 0.09011079164338298, 0.16368472221074626, 0.20893554406939074, 0.197477437031921, 0.2224716349155642, 0.03708787276991643, 0.07336771741393022, 0.06152482164907269, 0.025516773748677224, 0.4719518939964473, 9.667109716683626, 98.89554530382156, 113.86354252696037, 109.61052194237709, 93.42710673809052, 98.28529044985771, 77.5718343257904, 48.585515320301056, 34.35372859239578, 33.85787419974804, 39.332749620079994, 49.60113242268562, 54.068248718976974, 34.21365670859814, 44.2760069668293, 28.41330025345087, 4.969769949093461, 0.8127670059911907, 0.17894793913001195, 0.09980318092857487, 0.2816293394425884, 0.4597700445447117, 0.7427130150608718, 0.3408763837069273, 0.7284941186662763, 2.3443267168477178, 15.086444467306137, 63.14251899719238, 113.55225563049316, 131.0113763809204, 124.90388810634613, 108.28155845403671, 105.01355141401291, 108.81823405623436, 109.67963263392448, 107.84477189183235, 107.24964022636414, 102.85038828849792, 115.14825358986855, 121.79558649659157, 128.83766502141953, 118.77435341477394, 111.44654542207718, 99.49682503938675, 102.26661801338196, 101.85523688793182, 130.59961527585983, 102.64527529478073, 21.857686825096607, 23.382265716791153, 59.44999113678932, 113.085967451334, 127.89241254329681, 131.72230303287506, 127.74359732866287, 132.70903408527374, 104.59367394447327, 98.69076669216156, 107.01973736286163, 98.08502599596977, 97.723179012537, 104.81240540742874, 107.9973641037941, 120.6021237373352, 122.52108156681061, 122.24660709500313, 122.7508932352066, 121.24368891119957, 119.92182344198227, 122.0342668890953, 120.8982266485691, 119.92370054125786, 115.10737538337708, 113.06362465023994, 122.85639077425003, 130.46063393354416, 102.51266241073608, 31.333964131772518, 3.0300310347229242, 0.28961375006474555, 0.05474335077451542, 0.6071191909722984, 0.06998851866228506, 0.04835456136788707, 0.11586485226871446, 0.37384267256129533, 8.446623757481575, 41.668716073036194, 44.71215516328812, 43.43524128198624, 59.00564298033714, 54.182341396808624, 39.96403634548187, 34.837165251374245, 38.01150731742382, 42.90282145142555, 52.953475937247276, 70.3185023367405, 79.23293799161911, 83.29732149839401, 95.02998232841492, 97.60506615042686, 33.567463383078575, 0.6401067052502185, 0.3192507050698623, 0.15673145157052204, 0.217193792341277, 0.03192338583176024, 0.13200411514844745, 0.07465154383680783, 0.14807667379500344, 0.10125199420144781, 0.23712401976808906, 0.891497356351465, 0.4090384620940313, 0.1983140007359907, 0.16977402905467898, 0.08658275517518632, 0.12124775326810777, 0.015163999196374789, 0.07346443409915082, 0.06765340294805355, 0.04905798006802797, 0.051729926926782355, 0.01490121119786636, 0.016135390724230092, 0.043352938737371005, 0.03599306393880397, 0.024732113997743, 0.013782116511720233, 0.05659233378537465, 0.054154913013917394, 0.14260640717111528, 0.09056108974618837, 0.008362917997146724, 0.034347537002759054, 0.0872714385332074, 0.0751041945477482, 0.06377349942340516, 0.07003530365182087, 0.05730159689846914, 0.013865083983546356, 0.1332726830150932, 0.08335577833349817, 0.1476892430218868, 0.1968487785779871, 0.3279021580237895, 0.2753770421259105, 0.12874204956460744, 0.19861372449668124, 0.11006026295945048, 0.26229036622680724, 0.1278757257387042, 0.1084620034089312, 0.21078096848214045, 0.3578065533656627, 0.15063306083902717, 0.12675242585828528, 0.15137390233576298, 0.17599632876226678, 0.40248672303278, 0.2309266710653901, 0.2808627305785194, 0.17099437216529623, 0.17892972682602704, 0.1979707574355416, 0.28364302357658744, 0.28188692405819893, 0.32945689803455025, 0.5536875268444419, 0.5576117662712932, 0.28001050755847245, 0.2494925045175478, 0.24250807851785794, 0.08175506969564594, 0.5961077974643558, 38.276562094688416, 142.88348972797394, 130.03402322530746, 113.91618490219116, 106.22751027345657, 99.11170050501823, 69.94631230831146, 39.5716618001461, 81.32243826985359, 115.94132423400879, 118.72991859912872, 84.31173786520958, 70.65907806158066, 48.477844297885895, 61.2969846278429, 39.44061443209648, 7.632028693333268, 1.1655122903175652, 0.21886059665121138, 0.2149909792933613, 0.2851971104973927, 0.35208860237617046, 0.46713844290934503, 1.4094705996103585, 6.466546207666397, 7.876750761643052, 13.996769338846207, 60.337790697813034, 114.98566031455994, 140.8822587132454, 133.88151437044144, 116.15352764725685, 107.98188373446465, 112.92103350162506, 115.97264975309372, 113.76464903354645, 113.81264045834541, 109.15863499045372, 118.9196652173996, 127.82365143299103, 131.64998531341553, 119.75432083010674, 112.19822868704796, 101.59287616610527, 105.57964503765106, 106.85773685574532, 141.39027625322342, 111.40650317072868, 22.64221552759409, 21.746685281395912, 62.95601740479469, 131.84096306562424, 128.0621874332428, 132.8997078537941, 122.9940801858902, 137.19934433698654, 131.61417603492737, 110.88155373930931, 114.61454942822456, 102.72490382194519, 96.3138498365879, 102.27690026164055, 109.54413190484047, 122.45606705546379, 126.11340880393982, 126.53853759169579, 126.55005857348442, 124.38374161720276, 129.302000105381, 128.4178939461708, 126.58786654472351, 122.37459942698479, 120.99569901823997, 120.53328663110733, 134.4932359457016, 138.11280012130737, 97.44292885065079, 25.968902818858624, 2.3264132905751467, 1.658415428828448, 0.5799083167221397, 1.3027505949139595, 0.15421073214383796, 0.2221530457609333, 0.27821082912851125, 0.4844584478996694, 12.548515051603317, 58.18228796124458, 58.55649948120117, 68.38244542479515, 100.62734797596931, 102.07742616534233, 119.41202759742737, 99.86060991883278, 119.21252310276031, 59.233908131718636, 47.66640543937683, 70.68143606185913, 87.43376433849335, 95.9963008761406, 102.83250644803047, 114.93274435400963, 60.432341024279594, 1.7569051939062774, 0.7286020566243678, 0.2615684346528724, 0.4961918917251751, 0.2066447865217924, 0.21606771682854742, 0.22021164681063965, 0.3223231964511797, 0.27721887454390526, 0.38484860386233777, 1.1547699104994535, 0.5172155995387584, 0.47269148868508637, 0.24814123171381652, 0.20948641060385853, 0.2216894706361927, 0.14128256414551288, 0.19612220115959644, 0.3311629471136257, 0.2481083694146946, 0.12268983526155353, 0.12419113321811892, 0.11733758496120572, 0.10907745163422078, 0.11366666280082427, 0.12712032330455258, 0.19643682724563405, 0.1745227797073312, 0.22686019161483273, 0.2803207846591249, 0.21050794719485566, 0.08718935700017028, 0.14097161911195144, 0.21344489272451028, 0.24535943957744166, 0.13866953639080748, 0.1940268510952592, 0.15874921751674265, 0.08411210103076883], [0.024706934782443568, 0.029272877764014993, 0.048289541809936054, 0.022419438973884098, 0.033799973025452346, 0.10245019162539393, 0.0899564175051637, 0.09368034385261126, 0.11903080230695195, 0.04854721548326779, 0.07986024793353863, 0.1536498317727819, 0.0635722883453127, 0.11359106763848104, 0.03880335825670045, 0.09439360714168288, 0.03660304253571667, 0.023089813548722304, 0.09303615224780515, 0.1213336197542958, 0.1947182061849162, 0.08604008937254548, 0.060058660674258135, 0.061559446548926644, 0.17972605128306895, 0.11409560189349577, 0.11428243757109158, 0.41762229055166245, 0.15218886954244226, 0.20208739122608677, 0.14810221851803362, 0.10683929751394317, 0.09787108851014636, 20.480768010020256, 106.58611223101616, 102.12271213531494, 103.17738354206085, 86.32059127092361, 86.40017420053482, 45.11686384677887, 35.69552779197693, 65.9503099322319, 80.80059707164764, 59.464836940169334, 50.419061332941055, 36.64405569434166, 27.251924872398376, 32.54963859915733, 8.19993244484067, 0.41508426424115896, 0.5445505608804524, 0.09106263314606622, 0.4017682943958789, 0.10957558115478605, 0.04019835098006297, 0.6732726912014186, 1.2087981426157057, 2.679197760298848, 9.931721817702055, 74.3009926378727, 127.16142296791077, 126.96462392807007, 108.09312656521797, 93.93728256225586, 93.11325117945671, 95.07219806313515, 91.55072942376137, 89.27312403917313, 83.25792521238327, 93.2350954413414, 90.30652418732643, 82.01392516493797, 94.1721859574318, 105.56848123669624, 100.60749784111977, 96.35798826813698, 88.36766302585602, 98.72840747237206, 102.23896309733391, 108.15433368086815, 98.39493736624718, 104.19936910271645, 55.239980444312096, 82.3209410905838, 76.0841229557991, 106.46058216691017, 84.15415272116661, 79.42776873707771, 76.46891310811043, 92.68050760030746, 89.77533549070358, 61.3445732742548, 78.92160549759865, 95.68020343780518, 105.10611444711685, 111.13832876086235, 106.0520888864994, 110.66914513707161, 105.58792859315872, 109.23126429319382, 108.69661018252373, 109.68638107180595, 101.24237537384033, 96.25559896230698, 101.38765677809715, 106.99342757463455, 108.35981905460358, 108.50265339016914, 99.42567765712738, 99.8619170486927, 112.3574249446392, 133.95246416330338, 93.29686492681503, 24.91355884820223, 0.9098621271550655, 0.7762493623886257, 0.06523026851937175, 0.3803757985588163, 0.12151563889347017, 0.19659140176372603, 0.26939168048556894, 1.0373103758320212, 17.729402147233486, 35.203017219901085, 43.2068507373333, 46.65328860282898, 60.17778128385544, 54.202769100666046, 168.7950897216797, 85.80301344394684, 15.925478395074606, 21.987677849829197, 44.52099122107029, 67.51491397619247, 70.03362402319908, 80.04558518528938, 97.30334714055061, 45.40868058800697, 1.8654505256563425, 0.17919226898811758, 0.07067494589136913, 0.11111204206827097, 0.28364180645439774, 0.14374312508152798, 0.27464608603622764, 0.2180491472245194, 0.4000973637448624, 0.30796845734585077, 0.2936890017008409, 0.17332529474515468, 0.21122484700754285, 0.15377445321064442, 0.03725571317772847, 0.009804926703509409, 0.006847465892860782, 0.06762768010958098, 0.05076879002444912, 0.017216742562595755, 0.0477982029406121, 0.06237558263819665, 0.031245137070072815, 0.023415944779117126, 0.020781925377377775, 0.08795041459961794, 0.019949866509705316, 0.04975830401235726, 0.03129115022602491, 0.02761894415016286, 0.005422967697086278, 0.046536563022527844, 0.03923250886145979, 0.08071452670264989, 0.009541878025629558, 0.14057592081371695, 0.053167207224760205, 0.047189545366563834, 0.015261278058460448, 0.09076238246052526, 0.0302031691535376, 0.07652745567611419, 0.030584824162360746, 0.05249809801171068, 0.13816244172630832, 0.047903016456984915, 0.04626062138413545, 0.03859125245071482, 0.14335159765323624, 0.10600238500046544, 0.08251443519839086, 0.05735999278840609, 0.0689731196325738, 0.028768740558007266, 0.03432709454500582, 0.1259678421774879, 0.09327176929218695, 0.09548989284667186, 0.16125301597639918, 0.07728884724201635, 0.06016198618453927, 0.10792008717544377, 0.17416573246009648, 0.17270748649025336, 0.14288085338193923, 0.41925272962544113, 0.13898649282054976, 0.150138805329334, 0.11234162491746247, 0.05004909973649774, 0.2362955900025554, 16.137188784778118, 117.94401437044144, 115.5962647497654, 119.03199478983879, 100.72818696498871, 111.19193628430367, 75.27645349502563, 41.055128797888756, 16.579500250518322, 52.7238542586565, 50.62706217169762, 50.03875494003296, 41.705786883831024, 32.461050152778625, 45.66919840872288, 12.078702561557293, 0.21721899567637593, 0.48183344188146293, 0.14237732102628797, 0.12710678653093055, 0.6459186121355742, 0.377124865190126, 0.8753032784443349, 1.0677237063646317, 1.8391260132193565, 14.992143027484417, 81.51860654354095, 131.9583159685135, 129.0442219376564, 110.61613038182259, 99.58837732672691, 96.58980622887611, 99.17111411690712, 94.75372955203056, 89.61352497339249, 88.28555703163147, 95.7937641441822, 92.9587970674038, 87.69599586725235, 97.35877856612206, 107.2358925640583, 102.31156200170517, 98.05182337760925, 92.3609447479248, 103.95215436816216, 108.10001939535141, 115.87546616792679, 105.40467202663422, 108.86241048574448, 65.43216973543167, 91.54700562357903, 91.12022012472153, 112.34203577041626, 92.56788924336433, 85.0880666077137, 82.22092285752296, 97.36776888370514, 98.75828146934509, 68.55700805783272, 83.28079238533974, 100.05694538354874, 108.58608931303024, 114.94819432497025, 111.9937464594841, 111.11746028065681, 106.89068868756294, 110.72758600115776, 111.48135915398598, 112.38406911492348, 108.78655895590782, 101.96435183286667, 107.0148204267025, 110.60711726546288, 114.3770469725132, 114.24624279141426, 106.38517141342163, 104.0308253467083, 115.979755371809, 143.997802734375, 108.99726524949074, 35.25700092315674, 3.245693212375045, 0.517592194955796, 0.1847146640648134, 0.331629550200887, 0.052191824797773734, 0.2510459383483976, 0.2946837467607111, 0.9551416255999357, 22.46356051415205, 45.3906087577343, 44.745597168803215, 45.889278799295425, 57.20118820667267, 56.959844157099724, 164.46002393960953, 92.87292927503586, 32.2840366512537, 42.68512353301048, 61.61874756217003, 80.08705615997314, 82.16999039053917, 88.09511885046959, 109.14415776729584, 50.78349217772484, 1.1263779527507722, 0.0688279110181611, 0.06644342021900229, 0.19505678879795596, 0.1973544483189471, 0.1682481585885398, 0.35895118257030845, 0.20468379487283528, 0.35966263501904905, 0.19348934321897104, 0.36918106488883495, 0.13248815870610997, 0.21023183857323602, 0.1372470470960252, 0.00972966921835905, 0.02309172643435886, 0.08144577222992666, 0.04862708541622851, 0.036603098196792416, 0.0768294429872185, 0.038505419361172244, 0.035798899552901275, 0.015599864382238593, 0.02512858041882282, 0.016164874396054074, 0.09663549426477402, 0.06478578885435127, 0.04841463080083486, 0.03616949099523481, 0.04710745270131156, 0.024728772477828898, 0.005202033580644638, 0.051393826797720976, 0.060610380678554066, 0.01548263659060467, 0.09752014913829044, 0.056035158995655365, 0.030930228967918083, 0.1427353627514094, 0.15026299632154405, 0.16674048558343202, 0.20899963594274595, 0.16801405552541837, 0.13618901168229058, 0.1961006343481131, 0.15677629213314503, 0.28654666151851416, 0.11837291065603495, 0.27223627315834165, 0.2306195258279331, 0.29960287967696786, 0.2025220077484846, 0.09861133628874086, 0.20911716244881973, 0.08178857766324654, 0.17279614345170557, 0.25901897926814854, 0.22136365296319127, 0.3205399343278259, 0.18499918864108622, 0.16775094933109358, 0.210438244685065, 0.4423567664343864, 0.3738554968731478, 0.1996876418706961, 0.7643251272384077, 0.1990277983713895, 0.5725406901910901, 0.22764038178138435, 0.16678753774613142, 0.3997120406711474, 42.81041420996189, 149.03766989707947, 122.45960086584091, 130.8352330327034, 115.74185013771057, 109.00123983621597, 59.407547414302826, 50.45995853841305, 101.2137933075428, 114.84211921691895, 82.4202373623848, 82.07574784755707, 60.88282585144043, 46.611635237932205, 60.38919433951378, 17.18005232512951, 1.761168921366334, 1.1476316372863948, 0.2818641846533865, 1.12980940612033, 0.3458201262401417, 0.3010556782828644, 1.592325100209564, 4.791388995945454, 8.52942606434226, 12.634701076894999, 77.42626413702965, 133.83606880903244, 137.98158556222916, 116.0997985303402, 103.47133576869965, 99.77721959352493, 104.44493472576141, 100.7769763469696, 95.94711631536484, 90.22836998105049, 99.46203410625458, 94.7637914121151, 90.48049405217171, 101.01051941514015, 113.04239898920059, 109.06990215182304, 100.70266753435135, 96.41538798809052, 108.41659560799599, 115.35012155771255, 121.64053201675415, 111.63994744420052, 109.4365444779396, 77.47761458158493, 109.64009955525398, 116.1573426425457, 111.88933566212654, 101.67365223169327, 90.29147699475288, 89.87963229417801, 102.19175443053246, 108.71928736567497, 75.38997620344162, 86.09147116541862, 101.3371878862381, 114.42270532250404, 116.70016631484032, 117.47038498520851, 115.43915078043938, 112.08475157618523, 113.70813846588135, 115.97003549337387, 116.06047064065933, 113.76115322113037, 109.25695091485977, 114.7446620464325, 117.95560374855995, 122.48873770236969, 119.54726994037628, 109.6229700744152, 109.72647652029991, 124.73228931427002, 152.2671926021576, 111.48183032870293, 32.215739116072655, 3.1281954422593117, 1.7364929267205298, 0.258828098885715, 0.5217048805207014, 0.34166216966696084, 0.4804627248086035, 0.4745861026458442, 2.099098088219762, 32.41726890206337, 62.74317182600498, 63.25687386095524, 74.93685811758041, 96.31818920373917, 67.71841585636139, 181.13638669252396, 96.0457894206047, 25.22261906415224, 37.07887016236782, 58.16178046166897, 87.2130037844181, 89.63880881667137, 95.89660942554474, 115.60907006263733, 74.57431197166443, 3.67886901833117, 0.3336221573408693, 0.13857094949344173, 0.3062655549729243, 0.46239309129305184, 0.2760912256781012, 0.4802203690633178, 0.2629119891207665, 0.6373533967416734, 0.35756603814661503, 0.5023230111692101, 0.27032464917283505, 0.3471569420071319, 0.21535090607358143, 0.21618472383124754, 0.0838641420705244, 0.28195395483635366, 0.16889324819203466, 0.13935335126006976, 0.14478891505859792, 0.20681454538134858, 0.1500916641089134, 0.17476915789302438, 0.11319565135636367, 0.14074744598474354, 0.2162473907810636, 0.11226425602217205, 0.17177493340568617, 0.2746332617243752, 0.15050820191390812, 0.1146321598207578, 0.17514615406980738, 0.16133420693222433, 0.17010323092108592, 0.06755098656867631, 0.21214073145529255, 0.11990015409537591, 0.2821966668125242], [0.023916586469567847, 0.05626619327813387, 0.08567315671825781, 0.015969272099027876, 0.023106381995603442, 0.017967133644560818, 0.046416687619057484, 0.07281748912646435, 0.06714994480716996, 0.07677411587792449, 0.08810213184915483, 0.06805299752159044, 0.04763287470268551, 0.027663202126859687, 0.047749161822139286, 0.01360827305688872, 0.012035440413455945, 0.07546823282609694, 0.03179031133186072, 0.04371862087282352, 0.10317441643564962, 0.027128948568133637, 0.028680326649919152, 0.06961442428291775, 0.061568422825075686, 0.07536336735938676, 0.13542946806410328, 0.31827671045903116, 0.2697645057924092, 0.07352757602347992, 0.10428767505800352, 0.06270533369388431, 22.693816758692265, 113.00980433821678, 93.89886662364006, 101.75318956375122, 74.80802223086357, 53.270713314414024, 35.407355055212975, 22.716404646635056, 61.601929664611816, 74.11145880818367, 47.5179398059845, 33.92295330762863, 28.890366554260254, 33.830557465553284, 20.308996327221394, 2.6136424904689193, 1.1577219958417118, 0.21326132991816849, 0.03809026566159446, 0.3863827121676877, 0.07762425346300006, 0.26406959106680006, 0.7151779113337398, 2.095369538292289, 8.869905844330788, 53.87694798409939, 129.79038029909134, 126.77833512425423, 99.8608911037445, 93.86066347360611, 94.74883541464806, 97.36578539013863, 96.04895085096359, 90.15940368175507, 92.45425254106522, 89.93451654911041, 88.12712833285332, 95.22361993789673, 91.41464352607727, 88.67735400795937, 87.44698002934456, 94.13572311401367, 88.63324597477913, 89.84864115715027, 90.76773583889008, 104.73018541932106, 101.43409788608551, 106.03676050901413, 106.84328243136406, 115.00125467777252, 81.46500661969185, 43.34067575633526, 81.72880366444588, 105.23171290755272, 93.40098693966866, 97.12451353669167, 85.83880752325058, 101.38509571552277, 76.80176004767418, 78.82791012525558, 101.82675361633301, 93.25842618942261, 95.65137058496475, 105.26043936610222, 108.09132546186447, 104.75623682141304, 108.69575142860413, 107.52388671040535, 115.43572336435318, 115.51530629396439, 114.29186314344406, 110.93785911798477, 108.41430053114891, 96.96489170193672, 95.94302013516426, 96.99880108237267, 98.01465377211571, 102.40547776222229, 102.69597217440605, 94.45575714111328, 112.67409235239029, 123.14355656504631, 98.7730398774147, 33.5140610486269, 2.361220372840762, 0.7568402413744479, 0.08674658427480608, 0.17292309523327276, 0.07029240587144159, 0.410722988890484, 0.02448740564432228, 6.504010297358036, 29.667983427643776, 40.45527398586273, 43.68608862161636, 33.23957517743111, 47.67956033349037, 53.60651269555092, 49.054303765296936, 41.829432249069214, 21.39140624552965, 37.91710138320923, 56.87054514884949, 77.54681646823883, 72.98875585198402, 91.33051604032516, 43.651248291134834, 1.273782611824572, 0.34810508019290864, 0.09919099815306254, 0.17363986145937815, 0.061777901428285986, 0.09748238124302588, 0.09845115113421343, 0.29797021416015923, 0.14820160693489015, 0.20731021097162738, 0.17764155141776428, 0.14751700538909063, 0.11781206965679303, 0.0634296698262915, 0.0721264976891689, 0.12749668123433366, 0.033242137724300846, 0.04241013288265094, 0.0670180503220763, 0.06967539171455428, 0.07040013602818362, 0.009330966149718734, 0.035039170397794805, 0.024550640337110963, 0.03885080004693009, 0.007510095229008584, 0.09984081523725763, 0.017671196692390367, 0.0359974388993578, 0.03566031089576427, 0.060738163665519096, 0.16762101411586627, 0.018022271506197285, 0.06325602953438647, 0.01825502757128561, 0.05120436391734984, 0.03942334100429434, 0.025975296703109052, 0.04270328121492639, 0.11280993494438007, 0.031176959673757665, 0.032038752688094974, 0.023049887859087903, 0.029343294590944424, 0.05764615380030591, 0.1489811736973934, 0.05051579559221864, 0.05786238965811208, 0.03915796383807901, 0.08953152311732993, 0.06840597037808038, 0.04387901753943879, 0.07241712271934375, 0.02596131835161941, 0.02745525420323247, 0.011226683127461001, 0.06973001378355548, 0.10723507744842209, 0.03986521202023141, 0.0537655007065041, 0.13362460944335908, 0.09089910090551712, 0.10088432682096027, 0.23081411694874987, 0.1882340619340539, 0.41409875149838626, 0.009430573500139872, 0.12376343351206742, 0.06627792128711008, 17.960843928158283, 124.18456390500069, 108.75737652182579, 119.27430778741837, 104.41836655139923, 84.57763999700546, 63.46864029765129, 35.61458073556423, 33.403369188308716, 62.061002030968666, 40.88849633932114, 40.92249311506748, 36.13701470196247, 44.20186534523964, 29.313946925103664, 3.9190104324370623, 1.4109160657972097, 0.21707396517740563, 0.1836094874306582, 0.47040208184625953, 0.2562137204222381, 0.6404092640150338, 0.33852368651423603, 0.6158200709614903, 11.511423401534557, 62.97489479184151, 134.0449208021164, 130.9677243232727, 101.32680684328079, 97.21879407763481, 99.5326267182827, 99.73053529858589, 101.34699895977974, 93.41460540890694, 98.6124224960804, 92.58932769298553, 89.19846564531326, 97.79554232954979, 95.59194177389145, 89.47558477520943, 89.72920596599579, 96.26945301890373, 91.67280167341232, 92.64214485883713, 93.75119894742966, 110.56386798620224, 107.79108837246895, 110.38406163454056, 111.54606208205223, 114.74628835916519, 84.14131700992584, 51.05875700712204, 88.14567133784294, 112.28285014629364, 102.04486951231956, 104.75674599409103, 94.9715718626976, 110.29052585363388, 86.09466299414635, 82.75215715169907, 101.8779444694519, 99.11953568458557, 101.27713590860367, 106.77579045295715, 113.12993869185448, 110.0967438519001, 111.45416021347046, 114.85901311039925, 121.51162773370743, 123.24493512511253, 120.67248076200485, 114.90723252296448, 114.11086365580559, 104.37943384051323, 101.15671277046204, 100.7419802248478, 103.82359966635704, 108.31082448363304, 110.54818242788315, 101.45317286252975, 115.92403516173363, 133.65121632814407, 117.48124480247498, 42.73207761347294, 4.0521168150007725, 0.4385703586740419, 0.21491587394848466, 0.20873978035524487, 0.08763103134697303, 0.3325012174900621, 0.24166949617210776, 7.2035556100308895, 39.87797096371651, 45.52123814821243, 42.873684614896774, 37.29975990951061, 58.138426914811134, 48.34923639893532, 30.42818583548069, 35.84810860455036, 41.13717399537563, 59.986499547958374, 68.77550393342972, 93.95321130752563, 80.51784664392471, 102.32403293251991, 51.76121011376381, 0.938118954654783, 0.15634329349268228, 0.06072763258998748, 0.09162760048639029, 0.0756333903700579, 0.08484649326419458, 0.18047331977868453, 0.2863354462897405, 0.14950634707929567, 0.17408084560884163, 0.1816282351501286, 0.0969808007357642, 0.08723460574401543, 0.1092115874052979, 0.04357369056378957, 0.10031962665379979, 0.018546897554188035, 0.058423653681529686, 0.054549772685277276, 0.029842075346095953, 0.06504561475594528, 0.04912652111670468, 0.04132187350478489, 0.05702948845282663, 0.018682968475332018, 0.04380873615446035, 0.17768553108908236, 0.04181145348411519, 0.025905221264110878, 0.026456102641532198, 0.04241569527948741, 0.10134762735106051, 0.05037745555455331, 0.020464642402657773, 0.06879855165607296, 0.024927382328314707, 0.05474044897709973, 0.12088056828361005, 0.15312845818698406, 0.2350787349860184, 0.17794363520806655, 0.11118997499579564, 0.08508560582413338, 0.21489310485776514, 0.1676274708006531, 0.15815864608157426, 0.1843648453359492, 0.23441031225956976, 0.19794755789916962, 0.1089773433341179, 0.17119025462307036, 0.11434563144575804, 0.09089257000596263, 0.07488058545277454, 0.13980125222587958, 0.08709811736480333, 0.13333057053387165, 0.21104403014760464, 0.19542057474609464, 0.1645137753803283, 0.32177154324017465, 0.1889502938138321, 0.2849085337948054, 0.4108483821619302, 0.397037043585442, 0.41700060828588903, 0.22587932471651584, 0.3204170643584803, 0.20583820558385924, 46.202252805233, 151.4677459001541, 116.25435143709183, 135.14587372541428, 103.62402677536011, 70.49513205885887, 50.32590553164482, 38.73178906738758, 97.52564281225204, 110.0758145749569, 72.74589568376541, 55.968158170580864, 49.31313067674637, 56.28188073635101, 40.34305080771446, 5.246934676542878, 1.9292717822827399, 0.3520803793799132, 0.4045701987342909, 0.6672089884523302, 0.18187924433732405, 0.41613404697272927, 2.3315888503566384, 7.035399908199906, 13.82712934166193, 59.510423094034195, 139.47709411382675, 140.62993705272675, 110.7729783654213, 102.03131183981895, 104.24807488918304, 101.85850471258163, 106.90781056880951, 96.1443105340004, 101.08192518353462, 96.24966368079185, 94.03024837374687, 102.41660356521606, 101.40616938471794, 93.5646365582943, 93.07222858071327, 101.59769430756569, 94.88322660326958, 95.06137624382973, 93.64222839474678, 111.19569808244705, 110.00229611992836, 112.52716943621635, 117.60660007596016, 116.64903625845909, 82.41522923111916, 62.12845981121063, 98.5578802227974, 120.86595118045807, 111.67990610003471, 108.70984107255936, 102.0042496919632, 121.05176880955696, 100.17709493637085, 85.00001773238182, 106.46791577339172, 100.74956461787224, 105.09760290384293, 108.9264902472496, 119.09324750304222, 112.82720133662224, 115.32377377152443, 117.21530467271805, 123.97578030824661, 127.99233198165894, 126.69009625911713, 120.48410207033157, 117.58361890912056, 107.99752369523048, 105.69274216890335, 106.45020872354507, 111.47672340273857, 112.48830512166023, 109.71908211708069, 102.75811403989792, 122.8422099351883, 138.85652661323547, 119.03367429971695, 37.55869321525097, 3.4120383113622665, 0.6563459651079029, 0.25699499412439764, 0.3969238809077069, 0.12176793941762298, 0.6582485348917544, 0.41465515445452183, 11.802825964987278, 53.93830709159374, 65.26737257838249, 63.92890200018883, 52.48205043375492, 61.206184700131416, 72.98703834414482, 67.13957011699677, 55.68561293184757, 35.69433845579624, 53.232126384973526, 76.47804781794548, 100.20300194621086, 90.38362205028534, 107.67444983124733, 77.1114282310009, 2.183794118463993, 0.6905969709623605, 0.1441250936477445, 0.3091239515924826, 0.14972474629757926, 0.16246854997007176, 0.2520798984915018, 0.3318515117280185, 0.3897378430701792, 0.26732298836577684, 0.3718068724265322, 0.1740995774162002, 0.2795223821885884, 0.1746095812995918, 0.2122304867953062, 0.1844984170747921, 0.15933866088744253, 0.1606265245936811, 0.13663183635799214, 0.14068669377593324, 0.14099937543505803, 0.13298756472067907, 0.18416065082419664, 0.1314817916136235, 0.10083302957355045, 0.14058804750675336, 0.3209729626541957, 0.15302786749089137, 0.1457640525768511, 0.1661585972760804, 0.16666294599417597, 0.3092887974344194, 0.1520079339388758, 0.14647492615040392, 0.18354411906329915, 0.1493721519364044, 0.11453175466158427], [0.020995211198169272, 0.031577923509757966, 0.038060642837081105, 0.12737624550936744, 0.04235452746797819, 0.016659571483614855, 0.05783842199889477, 0.05312372108164709, 0.10957039354252629, 0.07159166154451668, 0.05883729339984711, 0.09597658587154001, 0.03694780352816451, 0.012534154375316575, 0.03312127526442055, 0.022540472127730027, 0.019203538686269894, 0.09563319414155558, 0.08616530452854931, 0.07064992067171261, 0.15235525905154645, 0.05471039199619554, 0.04361367005913053, 0.006942894024177804, 0.05460246517031919, 0.1307307678507641, 0.024008469918044284, 0.3260448295623064, 0.24399742047535256, 0.2469485261826776, 0.22182213695487007, 27.116488739848137, 122.6525317132473, 94.22382518649101, 107.1750958263874, 66.67758330702782, 51.32354959845543, 36.04135863482952, 27.612998597323895, 66.93544507026672, 44.971065670251846, 34.92301404476166, 39.100088104605675, 31.957816556096077, 29.655136317014694, 8.882550615817308, 0.31260883959475905, 0.5920276476535946, 0.10716571632656269, 0.0818362606514711, 0.16611644328804687, 0.06437336254748516, 0.513098401715979, 3.6059514060616493, 4.970412589609623, 42.69724488258362, 114.64850440621376, 127.49411031603813, 103.19459661841393, 93.99580702185631, 97.15165928006172, 102.36842215061188, 102.19104006886482, 97.59607583284378, 100.1761981844902, 102.34532698988914, 107.61489182710648, 96.65526911616325, 82.80229166150093, 82.22644776105881, 85.22985979914665, 85.45836433768272, 86.07377171516418, 79.1422900557518, 82.93613567948341, 93.24404016137123, 104.1325230896473, 104.49529722332954, 110.02700999379158, 110.66796720027924, 104.83947515487671, 97.82795459032059, 115.34802407026291, 60.907372534275055, 69.44115221500397, 96.47058382630348, 78.02371367812157, 91.41513749957085, 80.04526600241661, 91.38072654604912, 53.34162510931492, 83.99557203054428, 89.16006490588188, 105.05664110183716, 98.54907989501953, 107.1570011973381, 108.75958040356636, 108.36134657263756, 100.09965509176254, 103.33179205656052, 102.35071510076523, 106.5264630317688, 105.52147015929222, 103.11228543519974, 104.53741416335106, 101.55252233147621, 95.58082357048988, 91.38003498315811, 84.72029954195023, 83.33414912223816, 91.43244937062263, 105.906131118536, 99.06551018357277, 95.47306135296822, 110.30650019645691, 133.11781615018845, 104.11911740899086, 35.182403326034546, 0.5848020385019481, 0.30904175131581724, 0.17074723698897287, 0.08957194790127687, 0.014570494422514457, 0.27665451576467603, 2.6574847754091024, 18.183063603937626, 30.319570563733578, 36.22375264763832, 44.976457580924034, 70.95904156565666, 81.41715198755264, 51.72362633049488, 29.300132766366005, 23.54851819574833, 26.19321808218956, 48.75101163983345, 59.16606277227402, 71.56232759356499, 90.02606123685837, 58.3351119607687, 5.786769334226847, 0.5395174340810627, 0.09441709611564875, 0.07384667726000771, 0.0831708573969081, 0.06988452892983332, 0.2751910302322358, 0.19395619863644242, 0.2406555146444589, 0.0430023259104928, 0.06050925934687257, 0.03413375023228582, 0.1578779361443594, 0.053941501028020866, 0.03906033431121614, 0.028536307327158283, 0.057723897480173036, 0.017748229765857104, 0.0627110037021339, 0.03708025462401565, 0.010271249630022794, 0.0915518197871279, 0.009504237223154632, 0.049644265600363724, 0.009160698919004062, 0.03090446160058491, 0.04374343086965382, 0.029051374513073824, 0.0941374697140418, 0.024079645590973087, 0.04617432445229497, 0.03191591240465641, 0.038526043645106256, 0.02657112625456648, 0.03388591001566965, 0.04777839872986078, 0.03233847273804713, 0.045433264021994546, 0.06214339802681934, 0.04528096418653149, 0.04259857530996669, 0.05649615515721962, 0.07581138706882484, 0.11405340337660164, 0.13471651647705585, 0.024399461144639645, 0.01376606942358194, 0.07478223604266532, 0.016920033776841592, 0.03300553733424749, 0.020532188973447774, 0.05792363910586573, 0.029718021651206072, 0.006516309395010467, 0.08314273742143996, 0.05823426501592621, 0.07969378420966677, 0.09450396450120024, 0.08780752148595639, 0.03221849343390204, 0.05738580468459986, 0.13618277764180675, 0.040570964774815366, 0.3298513940535486, 0.1289045947487466, 0.26225809764582664, 0.25302117923274636, 24.645154550671577, 129.28610175848007, 108.61273348331451, 121.75596982240677, 93.5805045068264, 86.28162056207657, 53.818351328372955, 21.712452918291092, 25.734550394117832, 43.269585371017456, 38.19682717323303, 47.872479781508446, 41.777983009815216, 40.35447679460049, 11.790162194520235, 0.19615291123045608, 0.8906001294963062, 0.04502617746766191, 0.222692824609112, 0.518392170779407, 0.2107708901166916, 0.9083751006983221, 2.984920567832887, 6.215954404324293, 50.8177625387907, 124.291330575943, 129.9742904305458, 106.37067139148712, 97.0792655646801, 101.88215464353561, 105.97663253545761, 107.28377759456635, 102.99879312515259, 104.92924153804779, 107.0981727540493, 110.93367174267769, 98.55091139674187, 86.55344277620316, 86.98782026767731, 87.54749983549118, 88.17311346530914, 89.428049325943, 83.37794557213783, 87.4946066737175, 96.01145446300507, 109.85177859663963, 109.53202575445175, 113.30102071166039, 113.48823666572571, 107.19722583889961, 100.42411968111992, 119.5680320262909, 68.34186360239983, 75.60839608311653, 106.41564577817917, 86.54030308127403, 100.12107074260712, 88.50722193717957, 97.12305441498756, 64.05858904123306, 85.32185286283493, 95.75753688812256, 107.34821453690529, 103.24983045458794, 111.785107254982, 110.67543759942055, 109.32834148406982, 102.7493517100811, 105.96730023622513, 108.24049785733223, 108.36563274264336, 109.29703116416931, 109.5613905787468, 110.20340412855148, 105.24383425712585, 99.26435351371765, 97.57364183664322, 89.91490200161934, 85.75670912861824, 95.41223421692848, 111.60369738936424, 104.05874624848366, 101.79126352071762, 112.64247804880142, 139.40932095050812, 115.18813624978065, 46.47872596979141, 2.0697722118347883, 0.4554448672570288, 0.2364348465926014, 0.0926363276084885, 0.04176482434559148, 0.3498740930808708, 2.3577024741098285, 23.90574462711811, 40.85893012583256, 40.41529633104801, 46.63319528102875, 53.7540739774704, 52.60495863854885, 33.655246272683144, 30.20596046000719, 36.88541494309902, 47.4604868888855, 68.45738500356674, 75.21783784031868, 79.92735832929611, 101.75684496760368, 68.40419545769691, 5.9257421270012856, 0.5994696670677513, 0.15631337009835988, 0.1217142672976479, 0.0968185301462654, 0.09859930607490242, 0.15002274827565998, 0.21078990394016728, 0.058013212619698606, 0.03692172816954553, 0.07328333522309549, 0.05492314347065985, 0.12561126990476623, 0.124558592797257, 0.05853687944181729, 0.053886804744252004, 0.02553081703808857, 0.03784648870350793, 0.026340253389207646, 0.12234919689944945, 0.03655873631942086, 0.06634729725192301, 0.04078157144249417, 0.14422764361370355, 0.029017558554187417, 0.017459883129049558, 0.045147425844334066, 0.03103864746663021, 0.0400217309652362, 0.03565170569345355, 0.030400511786865536, 0.04005493836302776, 0.06364009095705114, 0.03978619926783722, 0.029064777700114064, 0.04993070491764229, 0.09478777661570348, 0.1782979810377583, 0.11432403494836763, 0.22158038977067918, 0.12305567695875652, 0.19056857650866732, 0.23737161507597193, 0.18304061639355496, 0.21622037660563365, 0.1174724183510989, 0.14956006372813135, 0.23075709032127634, 0.07846874330425635, 0.12809479288989678, 0.11393313834560104, 0.15148961800150573, 0.13302884297445416, 0.1342485033092089, 0.35681848763488233, 0.22179521183716133, 0.28483292378950864, 0.16666704264935106, 0.2606719796312973, 0.1665436234907247, 0.17804781789891422, 0.31236862123478204, 0.1533464269596152, 0.40087005821987987, 0.295860911719501, 0.4231527750380337, 0.2019283192930743, 55.935392528772354, 158.30116242170334, 116.59035980701447, 139.5638358592987, 90.78117191791534, 72.93086215853691, 54.64473098516464, 43.16058821976185, 102.06339731812477, 76.24499872326851, 54.43800687789917, 67.69989565014839, 54.320950359106064, 53.651760667562485, 17.870007902383804, 0.6545107229612768, 0.9763973287772387, 0.29068935953546315, 0.43790002120658755, 0.4124175198376179, 0.14751724287634715, 2.2115782275795937, 9.946750961244106, 10.337295904755592, 46.255335956811905, 126.85352548956871, 139.80974346399307, 112.86567807197571, 98.18144202232361, 101.72694057226181, 110.76687589287758, 111.17357566952705, 106.15767762064934, 107.17679813504219, 113.12299266457558, 116.04582622647285, 104.04079601168633, 88.083635866642, 87.89355486631393, 89.46344822645187, 92.27813959121704, 91.76349520683289, 86.44872039556503, 89.0722744166851, 100.54778024554253, 115.83831936120987, 112.41683095693588, 116.91339567303658, 122.03647077083588, 111.97429150342941, 107.26059883832932, 124.11988377571106, 72.68417179584503, 90.6335574388504, 115.82175225019455, 96.47615432739258, 108.43068525195122, 99.4092321395874, 108.8832637667656, 73.16389605402946, 86.88656330108643, 101.71274453401566, 109.76211100816727, 110.44222131371498, 119.37402203679085, 117.16511696577072, 113.59132513403893, 104.47887450456619, 108.82362216711044, 112.27195233106613, 111.56401991844177, 112.7619056403637, 114.43487986922264, 114.84383672475815, 111.15316316485405, 106.09408423304558, 102.86018416285515, 94.38800677657127, 91.00756376981735, 103.32814425230026, 118.14183175563812, 108.22269201278687, 105.6653380393982, 117.75262624025345, 144.59955364465714, 109.87496495246887, 41.29379779100418, 1.6061943559907377, 0.4800766002153978, 0.4739932157099247, 0.2682292100507766, 0.19127349805785343, 0.43645152705721557, 4.716059463098645, 33.662990257143974, 54.24648195505142, 60.33191621303558, 73.02667781710625, 105.50542742013931, 115.65670430660248, 74.50292900204659, 40.587351098656654, 36.191025003790855, 39.255632758140564, 65.14024659991264, 80.92971414327621, 89.43026080727577, 111.07550293207169, 93.73495101928711, 11.955415327101946, 0.9464367676991969, 0.4266988456947729, 0.18582611926831305, 0.24101811315631494, 0.19658601377159357, 0.33182494284119457, 0.4615519708022475, 0.34912826435174793, 0.18981749337399378, 0.185262517479714, 0.19518788176355883, 0.24038292380282655, 0.15132818603888154, 0.16574278677580878, 0.14614508603699505, 0.09543438762193546, 0.13234387035481632, 0.12654270976781845, 0.1354885578621179, 0.20796784287085757, 0.13433420652290806, 0.08416065233177505, 0.3459951840341091, 0.15353374503320083, 0.173271132807713, 0.18796749733155593, 0.10987903049681336, 0.20931142702465877, 0.09169197437586263, 0.09666591489803977, 0.18836212693713605, 0.2119271265110001, 0.24938311195001006, 0.08975377408205532, 0.12693413329543546], [0.0444500630692346, 0.0262074275087798, 0.06251037149922922, 0.03671814964036457, 0.027005716801795643, 0.05369675185647793, 0.04594761318003293, 0.013574068398156669, 0.11156907887198031, 0.010812094387802063, 0.061339284729911014, 0.028805565925722476, 0.041451211291132495, 0.06257297165575437, 0.04911938165605534, 0.02088811557769077, 0.031648750373278745, 0.08129111607559025, 0.0880253863579128, 0.11443736089859158, 0.01536897389087244, 0.04990386885765474, 0.030872072420606855, 0.07592304318677634, 0.03329809936985839, 0.021589075913652778, 0.28409597114659846, 0.07893593268818222, 0.43022173165809363, 0.5328856618143618, 21.866224966943264, 115.90035483241081, 104.27079007029533, 91.53356194496155, 71.8743896484375, 66.33366376161575, 24.92264036089182, 34.08317930996418, 73.36374253034592, 67.00169071555138, 41.30507938563824, 31.87820702791214, 29.185605011880398, 22.7986778318882, 0.9370000928174704, 0.4546202521305531, 0.25617168517783284, 0.07829361871699803, 0.24248373607406393, 0.10183642065385357, 0.39414525032043457, 2.13450672570616, 3.3646144811064005, 18.76241471618414, 95.95967084169388, 129.1065537929535, 101.18051469326019, 90.3173004090786, 99.33116912841797, 96.32664754986763, 99.94502618908882, 101.23431220650673, 115.62970295548439, 108.8546285033226, 104.37791392207146, 103.32502841949463, 103.39658617973328, 104.04861599206924, 94.8026405274868, 82.40734085440636, 83.1973184645176, 86.87209367752075, 87.94436573982239, 92.03777208924294, 102.46587932109833, 105.4305562376976, 107.10141018033028, 103.65301162004471, 103.82832661271095, 101.70344263315201, 106.34268969297409, 103.07114124298096, 101.11662492156029, 91.10392659902573, 43.62927787005901, 103.84094953536987, 82.89220243692398, 94.49471265077591, 93.84914249181747, 74.4973737001419, 74.07757982611656, 97.46198862791061, 104.52891021966934, 101.07269927859306, 102.43890836834908, 101.23830959200859, 95.08127197623253, 99.33266624808311, 102.48513668775558, 105.2894090116024, 106.13879263401031, 103.77621620893478, 107.60287687182426, 114.63059976696968, 107.70285710692406, 103.71728897094727, 90.34729599952698, 84.89393502473831, 82.21379444003105, 82.85552680492401, 79.23628941178322, 83.37271705269814, 93.49122449755669, 102.40509778261185, 102.61859312653542, 96.9400942325592, 104.49699193239212, 123.60232874751091, 88.28054890036583, 9.589712619781494, 0.2788667392451316, 0.030426318116951734, 0.04736471819342114, 0.10712221162975766, 0.4359986982308328, 0.40831112768501043, 11.510550398379564, 32.508855387568474, 24.061302579939365, 38.2228709757328, 47.005142122507095, 53.404880315065384, 69.43186551332474, 37.40113086998463, 22.67790701240301, 22.7189714089036, 47.32560932636261, 78.21588456630707, 72.49289005994797, 86.1273792386055, 83.30156967043877, 10.94032259657979, 0.7681840576697141, 0.06141332138213329, 0.025431142894376535, 0.161369206616655, 0.11119804956251755, 0.256936572259292, 0.15629383677151054, 0.017789591511245817, 0.022981135298323352, 0.03287616986199282, 0.017396707808075007, 0.0366824226512108, 0.10720744729042053, 0.047351723187603056, 0.0017452049064559105, 0.047188973912852816, 0.022368392201315146, 0.018114149388566148, 0.029297687760845292, 0.024760041014815215, 0.021052031879662536, 0.05556197676924057, 0.04175202971964609, 0.07567386710434221, 0.07552733746706508, 0.046394471428357065, 0.06297035462921485, 0.032160843402380124, 0.07994896426680498, 0.02348802772758063, 0.046673470715177245, 0.03638482143287547, 0.0671395992685575, 0.03928963567886967, 0.032665318285580724, 0.0315381221298594, 0.0529776701296214, 0.06300499066128395, 0.07422287191729993, 0.10458487551659346, 0.007592453675897559, 0.06775649468181655, 0.0703144921862986, 0.05554644361836836, 0.09874118986772373, 0.06889937983942218, 0.017573010554770008, 0.04057151767483447, 0.04172144581389148, 0.027951099764322862, 0.030118378781480715, 0.08396062126848847, 0.03239879079046659, 0.09989920741645619, 0.08003394759725779, 0.07524678338086233, 0.05494712226209231, 0.1278322358848527, 0.1342023120378144, 0.1058871072018519, 0.40994955226778984, 0.09491856530075893, 0.46435785305220634, 0.46638166008051485, 21.909016370773315, 125.58494076132774, 119.09380227327347, 108.54845613241196, 98.55267450213432, 82.38061308860779, 49.167271703481674, 46.00004285573959, 28.80391549319029, 63.652178049087524, 38.946876525878906, 42.25624054670334, 36.93834610283375, 29.645097255706787, 1.7130445037037134, 0.5005082522984594, 0.1866482853074558, 0.20050416758749634, 0.5282241431996226, 0.22602842218475416, 1.0234480071812868, 0.845487822080031, 2.3440863797441125, 22.0479654148221, 104.17492881417274, 132.691251039505, 106.17840930819511, 96.31517216563225, 104.72682639956474, 100.91278865933418, 105.193190574646, 104.76026460528374, 118.81225258111954, 113.73278394341469, 110.02348378300667, 106.23846128582954, 106.18331864476204, 109.34184595942497, 97.95446500182152, 87.47545570135117, 87.80487522482872, 88.38212504982948, 89.22085404396057, 95.9802733361721, 105.56712850928307, 109.51042011380196, 109.20427814126015, 105.61461836099625, 105.88205561041832, 105.39064317941666, 110.05529567599297, 105.18533259630203, 104.83392745256424, 95.87039083242416, 53.070148676633835, 108.96058961749077, 91.61933854222298, 100.92307850718498, 101.44782274961472, 83.48978877067566, 80.50870433449745, 102.60922282934189, 107.5439116358757, 105.74266389012337, 103.15891653299332, 109.84012842178345, 101.46388068795204, 103.64877864718437, 104.02509525418282, 112.36164271831512, 109.37618091702461, 108.15783709287643, 109.04886648058891, 119.51878666877747, 113.90176847577095, 108.84522780776024, 95.3811214864254, 87.69205927848816, 86.6515003144741, 86.93222165107727, 84.01220753788948, 85.51489010453224, 96.48595780134201, 110.22026762366295, 111.96946576237679, 101.52805924415588, 107.34231725335121, 130.19223153591156, 105.01398459076881, 18.012650348246098, 0.26008823595475405, 0.07135100531741045, 0.21359617210691795, 0.039254109069588594, 0.3745152958435938, 0.3516338439658284, 13.973900265991688, 41.91537223756313, 30.52452016621828, 36.9560569524765, 44.9706856906414, 45.33610448241234, 36.23425528407097, 39.729763716459274, 34.425514340400696, 41.15110784769058, 59.07480686903, 90.16875118017197, 83.46747636795044, 97.27318435907364, 100.70564657449722, 14.878851156681776, 1.0046633589081466, 0.0739695323863998, 0.08136265169014223, 0.04314822472224478, 0.0886522265500389, 0.21548679331317544, 0.12742430699290708, 0.020008139945275616, 0.013466740856529213, 0.051316008903086185, 0.12358035310171545, 0.026751015429908875, 0.012951193129993044, 0.045794623147230595, 0.040798481277306564, 0.034564704255899414, 0.10062216315418482, 0.013257406044431264, 0.06341841886751354, 0.038745262936572544, 0.07532892428571358, 0.030074081842030864, 0.053819892709725536, 0.043999482950312085, 0.0474610452511115, 0.03686994852614589, 0.07233659227495082, 0.05563305225223303, 0.12835075962357223, 0.12167377572041005, 0.07000941754085943, 0.038276021514320746, 0.034359359415248036, 0.04822920891456306, 0.1112035711412318, 0.125584804918617, 0.3223283321131021, 0.17044346110196784, 0.0920253545336891, 0.2337691411958076, 0.12168662971816957, 0.20897579815937206, 0.19762248237384483, 0.16907406505197287, 0.2142092157737352, 0.16395585844293237, 0.0878848458523862, 0.2050723833963275, 0.16566129896091297, 0.15879533457336947, 0.29385209607426077, 0.25141371705103666, 0.16567146638408303, 0.22962386050494388, 0.15528441203059629, 0.1742284736246802, 0.27632375538814813, 0.2226235970738344, 0.3509819117607549, 0.22306039551040158, 0.45704814372584224, 0.27937421982642263, 0.5845681135542691, 0.45165664865635335, 53.81228305399418, 153.72842699289322, 126.53035283088684, 121.22212886810303, 96.68477073311806, 86.77965983748436, 38.798061311244965, 53.973185420036316, 104.42730367183685, 103.38345408439636, 62.56952114403248, 57.45208874344826, 49.715578481554985, 39.694262221455574, 2.8634983208030462, 1.0267006326466799, 0.336043993011117, 0.3661657782504335, 0.6431173905730247, 0.2022464928450063, 1.3054376444779336, 7.365738982334733, 9.642467088997364, 22.49745089560747, 102.33717262744904, 144.04704809188843, 111.9344088435173, 100.33567562699318, 107.64005407691002, 106.1133947968483, 110.45043647289276, 110.82644909620285, 119.67803612351418, 117.50909730792046, 112.98355534672737, 112.04112231731415, 109.78155076503754, 112.82397910952568, 99.82715651392937, 90.92054843902588, 92.11626067757607, 94.3364891409874, 92.620600014925, 99.73313435912132, 108.24841663241386, 115.11877477169037, 109.50364127755165, 107.67627373337746, 108.89552190899849, 111.49664953351021, 117.10434302687645, 110.29338330030441, 111.36010766029358, 98.61249849200249, 58.77428479492664, 119.48949784040451, 99.67435151338577, 108.58644649386406, 110.589729398489, 93.78117933869362, 85.86786076426506, 105.21821603178978, 111.25254303216934, 110.91827496886253, 108.24234455823898, 114.98686105012894, 106.99699178338051, 109.08567890524864, 109.29852828383446, 117.6094651222229, 113.96249681711197, 111.72518447041512, 112.95303538441658, 122.79257699847221, 114.97610002756119, 112.28573799133301, 99.63283494114876, 93.09128075838089, 91.9370698928833, 92.22860544919968, 87.53689080476761, 90.19300907850266, 103.34300145506859, 114.71000790596008, 113.14889967441559, 102.99286544322968, 112.41136685013771, 138.47783893346786, 101.4048470556736, 14.853303227573633, 0.40042094013188034, 0.15898596262559295, 0.2661438344512135, 0.223396796209272, 0.6685110123362392, 1.3086482346989214, 20.074638202786446, 54.75226901471615, 39.33180347084999, 59.600558057427406, 71.03623822331429, 79.01896387338638, 95.38381174206734, 53.57376605272293, 35.06823845207691, 33.83227117359638, 61.777522042393684, 98.29912930727005, 91.96026384830475, 102.52942711114883, 120.12753680348396, 26.304837092757225, 1.144982110708952, 0.19347631110576913, 0.1967368775513023, 0.2510792756220326, 0.2272620497387834, 0.45818846847396344, 0.31972796539776027, 0.13702372001716867, 0.13659642107086256, 0.14355347666423768, 0.19451801927061751, 0.12072354467818514, 0.18328844918869436, 0.17152813961729407, 0.10984276173985563, 0.11725869466317818, 0.19685176201164722, 0.25296988198533654, 0.21480202849488705, 0.13379181531490758, 0.1375051066861488, 0.08304579809191637, 0.16323646501405165, 0.15034182724775746, 0.17520390800200403, 0.21803703537443653, 0.17247047420823947, 0.24896158691262826, 0.2415347221540287, 0.2402906896895729, 0.12583459698362276, 0.0718375202268362, 0.09460712302825414, 0.15535159123828635], [0.048704725195420906, 0.04319522493460681, 0.051380902295932174, 0.09909549116855487, 0.011149758593091974, 0.048611645033815876, 0.0658354973711539, 0.035475178447086364, 0.041876354298437946, 0.028972148393222596, 0.045966103789396584, 0.10978682606946677, 0.06001814683258999, 0.09507788214250468, 0.014163915311655728, 0.016923356743063778, 0.0460578146885382, 0.06073723969166167, 0.052694922997034155, 0.15612582938047126, 0.01407363211910706, 0.02398511267529102, 0.05330727275577374, 0.12833792046876624, 0.0991178149706684, 0.16249459935352206, 0.0697119944379665, 0.23087811976438388, 0.1674935725168325, 20.439230538904667, 114.93541941046715, 101.73436537384987, 95.50908342003822, 80.23806765675545, 47.78201423585415, 34.95093874633312, 61.986670419573784, 62.94671170413494, 52.54949301481247, 37.07672707736492, 30.502715036273003, 27.414611242711544, 14.727041702717543, 0.24323667457792908, 0.13258978840894997, 0.15790998208103701, 0.14610549987992272, 0.27381903666537255, 0.05578843200055417, 1.1028902255930007, 1.09772962750867, 2.172563108615577, 44.1063916683197, 118.52387085556984, 109.49900552630424, 92.3299004137516, 99.51159864664078, 98.68970274925232, 96.09211653470993, 98.62212717533112, 110.92637613415718, 114.76333424448967, 106.50992631912231, 99.48564603924751, 104.43023711442947, 106.0823504626751, 98.06107208132744, 104.42825362086296, 94.20621693134308, 80.55039569735527, 78.05365607142448, 81.8003386259079, 84.52168419957161, 97.13355705142021, 96.35000109672546, 104.17696550488472, 99.91875439882278, 103.72282147407532, 94.49709132313728, 96.98009088635445, 88.4096659719944, 90.90683877468109, 89.437146037817, 110.5164085328579, 72.01075673103333, 57.573040053248405, 92.48663440346718, 71.64624989032745, 95.54477870464325, 43.83399188518524, 84.01829481124878, 93.72983649373055, 96.22007846832275, 97.3607924580574, 103.0885823071003, 100.03904834389687, 96.42513826489449, 97.9817247390747, 96.3098980486393, 100.56938588619232, 103.53999808430672, 98.61549273133278, 99.26412552595139, 99.63640674948692, 104.14936378598213, 99.00557979941368, 96.931863874197, 89.6300844848156, 81.66841730475426, 79.82344150543213, 78.24287071824074, 82.30283886194229, 85.34693911671638, 85.65409943461418, 94.77513760328293, 103.75312864780426, 95.99712923169136, 90.33752292394638, 103.36877167224884, 121.42836660146713, 20.959312431514263, 0.3287387662567198, 0.027767351421061903, 0.13556401943787932, 0.21906504349317402, 0.18604953540489078, 0.041559575984138064, 4.92163460701704, 25.535674765706062, 27.592016123235226, 46.12040139734745, 56.08162008225918, 81.7527423799038, 59.752990677952766, 44.37131725251675, 30.134148113429546, 31.151463724672794, 46.189572885632515, 54.832247123122215, 76.42479747533798, 83.46773475408554, 90.59571906924248, 20.78766994178295, 1.3094578287564218, 0.1494276794255711, 0.052242617384763435, 0.15118538198294118, 0.10613811638904735, 0.0343069155496778, 0.06964900836464949, 0.014796650011703605, 0.01555174352688482, 0.07012873262283392, 0.048900396141107194, 0.05504159395059105, 0.05544794948946219, 0.06205342375324108, 0.06044820285751484, 0.03208549685950857, 0.013543691366066923, 0.05432439356809482, 0.0125747832498746, 0.06361355175613426, 0.023661304367124103, 0.029398528931778856, 0.02078827816148987, 0.025626377828302793, 0.03240050144086126, 0.05762320288340561, 0.034408337451168336, 0.019074091433139984, 0.0355278449569596, 0.04522198571066838, 0.024654416702105664, 0.08065475412877277, 0.03259402386902366, 0.028299645709921606, 0.03269262560934294, 0.048137705816770904, 0.02090066158416448, 0.06205220292031299, 0.01864336933067534, 0.07589367640321143, 0.08340061147464439, 0.02648425601364579, 0.028570002687047236, 0.08685237742611207, 0.0537629774044035, 0.09430663485545665, 0.03581680757633876, 0.013103510591463419, 0.03615021370933391, 0.07353038876317441, 0.010233047578367405, 0.02952618946437724, 0.054760041675763205, 0.009543011656205636, 0.13187849923269823, 0.0438960795145249, 0.06224487930012401, 0.14517643488943577, 0.15622843871824443, 0.09671084451838396, 0.27293686056509614, 0.24506927467882633, 19.260037913918495, 128.69723975658417, 111.85553267598152, 110.45828685164452, 95.60195043683052, 75.04224926233292, 60.914060175418854, 33.644356057047844, 27.638759315013885, 58.52621890604496, 37.19863213598728, 38.11448559165001, 38.296902403235435, 21.24253213405609, 0.28483336907811463, 0.09541716979583725, 0.30086435261182487, 0.2736798988189548, 0.6291756418067962, 0.6373798765707761, 1.2737156404182315, 0.15864939865423366, 2.008226439356804, 49.57268714904785, 124.7545713186264, 112.34552398324013, 96.01401552557945, 105.9129099547863, 104.51928913593292, 100.56848153471947, 104.12519708275795, 114.97771874070168, 118.14961373806, 107.9840724170208, 104.70924094319344, 107.30403050780296, 110.0292518734932, 103.79296571016312, 106.22699350118637, 98.47366154193878, 84.9525810778141, 82.37008765339851, 84.19141352176666, 87.99670413136482, 100.38007244467735, 99.36401456594467, 104.94409874081612, 101.16881892085075, 108.40030208230019, 100.58084607124329, 98.75506684184074, 92.15167477726936, 93.10472443699837, 93.94918352365494, 115.70463493466377, 78.73044535517693, 63.37674222886562, 99.1177649796009, 77.45284751057625, 103.68493750691414, 52.886983305215836, 86.31259649991989, 96.20481848716736, 101.43647655844688, 104.99002307653427, 109.02356743812561, 107.27425530552864, 102.57773011922836, 102.66302794218063, 101.37070968747139, 103.30526188015938, 106.95014029741287, 102.41916462779045, 103.77034172415733, 102.0327177643776, 106.29880204796791, 103.38601514697075, 100.96910163760185, 92.43010103702545, 83.8421742618084, 84.28443253040314, 80.68240821361542, 86.80429771542549, 88.69220361113548, 88.65295931696892, 96.73495844006538, 109.41516682505608, 103.5163177549839, 95.6447285413742, 103.17307457327843, 130.16631692647934, 31.8044263869524, 0.1942535029957071, 0.18334709369810298, 0.09249725655536167, 0.044910977594554424, 0.1275174762122333, 0.2720995101844892, 5.188373643904924, 32.13981159031391, 38.67012217640877, 37.41541810333729, 50.62643140554428, 61.00026614964008, 28.91070306301117, 33.96339073777199, 33.09204809367657, 51.90460681915283, 62.473853677511215, 72.36007198691368, 84.24798488616943, 91.61298528313637, 105.40864661335945, 31.110021248459816, 0.7371917925775051, 0.14881886600051075, 0.031004260054032784, 0.10508820749237202, 0.06746923900209367, 0.07945065663079731, 0.03954057436203584, 0.02969457349536242, 0.04412338821566664, 0.04787208374182228, 0.036640669422922656, 0.0238089694903465, 0.015924975159578025, 0.029336292427615263, 0.08783892175415531, 0.039203431515488774, 0.04624901048373431, 0.0396237765380647, 0.02579759129730519, 0.04731065273517743, 0.04989269953512121, 0.08118282930809073, 0.045315796887734905, 0.09556813005474396, 0.019089301749772858, 0.04235961117956322, 0.06655699107795954, 0.045636441791430116, 0.04417523836309556, 0.03343023134220857, 0.019007806513400283, 0.02921124796557706, 0.08945992813096382, 0.10469958186149597, 0.11794285092037171, 0.0897282590449322, 0.15640014200471342, 0.11988027938059531, 0.18649173667654395, 0.2016337015083991, 0.20539312477922067, 0.16989666153676808, 0.15285497676813975, 0.13337450567632914, 0.2087449308601208, 0.264298053807579, 0.2755132707534358, 0.09965715595171787, 0.16800745041109622, 0.14474606345174834, 0.10342447567381896, 0.18097467022016644, 0.18663752416614443, 0.16514887567609549, 0.2870593371335417, 0.19443424564087763, 0.252998469513841, 0.21240158152068034, 0.3483639709884301, 0.29958070430438966, 0.42884507740382105, 0.24190699827158824, 48.618109971284866, 156.03569358587265, 121.02279156446457, 124.8690439760685, 101.61130517721176, 70.84249421954155, 53.553839921951294, 85.81150978803635, 97.8690455853939, 76.41379326581955, 60.62498688697815, 55.3104704618454, 49.095660746097565, 30.985353738069534, 0.9357781615108252, 0.2045170046039857, 0.5082628643140197, 0.3394091874361038, 0.6526818929705769, 0.3317662241170183, 2.7195518324151635, 5.088986176997423, 5.448557082563639, 50.101599767804146, 131.44932568073273, 119.99952927231789, 99.71419617533684, 111.35782778263092, 108.12652677297592, 106.97533294558525, 104.71689373254776, 118.18698853254318, 120.51959976553917, 113.02004858851433, 107.9666617512703, 114.21310096979141, 116.04454189538956, 107.1787740290165, 111.3931354880333, 102.77725741267204, 87.1867547929287, 86.60845622420311, 87.86998093128204, 91.79351359605789, 104.52967777848244, 103.6143296957016, 109.00560960173607, 106.26605540513992, 115.16608223319054, 107.87202402949333, 105.64865693449974, 96.6363613307476, 98.1052865087986, 103.79212975502014, 121.89279288053513, 84.56072330474854, 73.01851585507393, 107.93855845928192, 88.97470325231552, 112.91810765862465, 60.65334856510162, 88.79701718688011, 100.8225966989994, 107.54012703895569, 108.79922747612, 115.2578017115593, 113.35631534457207, 108.32600086927414, 106.02656945586205, 104.75666999816895, 108.1264279782772, 111.27475664019585, 107.71975100040436, 106.67180523276329, 107.39805266261101, 110.69661006331444, 110.27636781334877, 107.2857914865017, 98.32090213894844, 87.10609272122383, 90.05341216921806, 87.57164373993874, 91.42014563083649, 95.48417955636978, 93.01791429519653, 104.11149501800537, 115.75172960758209, 105.97734689712524, 99.62397381663322, 113.82735326886177, 132.79173284769058, 26.01169992238283, 0.42277840606402606, 0.30728666111826897, 0.21075653698062524, 0.39771976007614285, 0.284500026027672, 0.37998133222572505, 8.828694205731153, 46.210342571139336, 50.57272508740425, 69.16689053177834, 78.1413933634758, 116.04635819792747, 81.40772849321365, 60.837159901857376, 43.91629546880722, 43.904215916991234, 61.04934811592102, 77.18727216124535, 97.14988857507706, 98.84945377707481, 121.70624569058418, 45.101930648088455, 1.6586652654223144, 0.45446472766343504, 0.11475604653242044, 0.2458903126535006, 0.18728500348515809, 0.1372769704903476, 0.1670559131889604, 0.09564899446559139, 0.11606236002990045, 0.15588437905535102, 0.15479788969969377, 0.136900152429007, 0.14251726039219648, 0.11513349541928619, 0.10997627410688438, 0.11232801392907277, 0.1549112898646854, 0.21970722387777641, 0.05797031277325004, 0.11699185546603985, 0.17922812956385314, 0.19309729628730565, 0.15024555585114285, 0.23451621673302725, 0.149501092673745, 0.10899695087573491, 0.2049682303913869, 0.1721449088654481, 0.11981486648437567, 0.09351203218102455, 0.131168560765218, 0.11287452405667864, 0.16171697701793164], [0.008598711301601725, 0.03276680698036216, 0.04705726867541671, 0.03263125370722264, 0.07966216129716486, 0.0027316104296915, 0.05874075483006891, 0.04209039710985962, 0.05095760723634157, 0.03724083682755008, 0.022954562700761016, 0.027606073454080615, 0.05104089475935325, 0.03209342299669515, 0.062307987827807665, 0.02927760338934604, 0.04724183709186036, 0.015977498806023505, 0.0811416252690833, 0.06273909399169497, 0.006631766700593289, 0.013324692863534437, 0.054095081068226136, 0.1526631909655407, 0.05527775647351518, 0.05529536021640524, 0.20258868229575455, 0.14303685282357037, 31.1413486674428, 115.12101665139198, 110.89147880673409, 97.08557322621346, 83.3774895966053, 57.26354666054249, 41.49695008993149, 30.59457130730152, 79.2113247513771, 94.38467055559158, 42.1184029430151, 43.28012980520725, 28.59908178448677, 8.040513899177313, 1.0374920535832644, 0.022922060343262274, 0.18549580418039113, 0.039573191752424464, 0.18685052054934204, 0.12794207374099642, 2.16205429751426, 1.7189797852188349, 1.643018655013293, 71.56251758337021, 121.45982891321182, 100.04802346229553, 99.91967394948006, 105.66923663020134, 95.80651625990868, 97.53505110740662, 107.29170396924019, 108.11030924320221, 103.15449357032776, 104.24768730998039, 104.29458439350128, 102.47847944498062, 101.57947048544884, 97.51498058438301, 102.54933804273605, 102.206801623106, 99.55446034669876, 78.96227851510048, 77.64194056391716, 80.8926509320736, 87.76741683483124, 97.93925061821938, 102.59805142879486, 105.57583764195442, 95.76585084199905, 90.57726725935936, 87.09590926766396, 89.81358423829079, 96.6314671933651, 91.36503338813782, 85.2144630253315, 93.09579491615295, 96.45824208855629, 45.47975577414036, 67.48247891664505, 88.50404530763626, 53.02724897861481, 70.76957613229752, 101.96896478533745, 100.38737565279007, 101.16331681609154, 100.69553911685944, 97.44950249791145, 99.14100453257561, 95.6434366106987, 101.34155005216599, 100.45223817229271, 95.7646881043911, 98.7497927248478, 101.2337726354599, 102.69245356321335, 103.3664233982563, 102.3554040491581, 98.85791972279549, 92.94770166277885, 85.45749798417091, 78.04278865456581, 78.69879305362701, 79.37267929315567, 75.70587605237961, 80.07937297224998, 78.9710484445095, 78.19676399230957, 73.32611694931984, 83.88632789254189, 94.19683903455734, 93.76154959201813, 90.15061855316162, 122.2168242931366, 16.812534146010876, 0.34976036637090147, 0.29994521755725145, 0.09578163109836169, 0.09290238755056635, 0.04624757442798, 0.45546683482825756, 0.5861821363214403, 16.903113685548306, 28.678554520010948, 35.66016688942909, 40.729132890701294, 77.13985070586205, 63.271183893084526, 46.95287972688675, 20.48708327114582, 13.268458619713783, 36.811052933335304, 67.90723532438278, 63.83481904864311, 75.46200513839722, 84.69667240977287, 38.95010255277157, 2.450479958206415, 0.218349568604026, 0.08094157936284319, 0.04863091489824001, 0.06871629200759344, 0.03724436945049092, 0.03567729494534433, 0.04721953555417713, 0.005619932762783719, 0.03780988226935733, 0.053013467622804455, 0.026456178711669054, 0.02377071177761536, 0.02813582217640942, 0.0076390656522562495, 0.034986830432899296, 0.047291701994254254, 0.027608984528342262, 0.019212385086575523, 0.029244306933833286, 0.06079513463191688, 0.028815100667998195, 0.0237893823577906, 0.02245919211418368, 0.02305083595274482, 0.05047273989475798, 0.04712768364697695, 0.045698537287535146, 0.026735847786767408, 0.050194367722724564, 0.01893469197966624, 0.023874033577158116, 0.08692203540704213, 0.08283314309665002, 0.030093340574239846, 0.009453729435335845, 0.04289606149541214, 0.04599592699378263, 0.04878950072452426, 0.08370378622203134, 0.02674878342077136, 0.05717692351026926, 0.00871950604050653, 0.05947572964942083, 0.027576717802730855, 0.02872836215829011, 0.027061223881901242, 0.016805117775220424, 0.026984487667505164, 0.046340365151991136, 0.04855291888816282, 0.008078770060819807, 0.04852171157835983, 0.052695334888994694, 0.09625959646655247, 0.056965177645906806, 0.06549646946950816, 0.026862434060603846, 0.18583273922558874, 0.028334187118161935, 29.040278010070324, 133.5939610004425, 121.17702528834343, 115.36591351032257, 98.76578226685524, 93.90805453062057, 59.16062146425247, 29.407366812229156, 52.942068949341774, 83.24222445487976, 46.485014632344246, 43.38243551552296, 41.178037002682686, 12.286739498376846, 0.7736813533119857, 0.13546163274440914, 0.24885057646315545, 0.06778750161174685, 0.3957316651940346, 1.0935883247293532, 1.9966833712533116, 1.1444140411913395, 2.0786425983533263, 78.31139624118805, 125.99223330616951, 102.67743676900864, 107.59786874055862, 112.63408049941063, 98.22744235396385, 103.9437036216259, 111.91117689013481, 113.71747836470604, 106.66411444544792, 107.24458649754524, 106.63937017321587, 105.52185013890266, 103.79426524043083, 104.48331266641617, 105.4057739675045, 106.84748500585556, 104.53974723815918, 81.02586418390274, 80.2660645544529, 83.1446684896946, 92.15498819947243, 101.94476008415222, 107.63221889734268, 106.1855149269104, 100.22130936384201, 94.51456278562546, 90.88640347123146, 96.51185721158981, 100.87504148483276, 96.22953236103058, 89.05465096235275, 96.01948723196983, 99.31308209896088, 53.24750795960426, 75.48763856291771, 94.32737722992897, 62.547326534986496, 74.75265920162201, 106.93462952971458, 104.90657195448875, 106.4725211262703, 104.4883131980896, 101.44501090049744, 102.2777210175991, 101.00311741232872, 104.81492087244987, 102.63946160674095, 102.27785781025887, 103.61514285206795, 107.15183347463608, 106.82020246982574, 105.94251796603203, 106.09895557165146, 104.5130118727684, 96.23853787779808, 89.06767666339874, 82.1989980340004, 84.29817259311676, 85.04161790013313, 79.34684067964554, 83.47959011793137, 84.31220144033432, 83.33119288086891, 76.32107824087143, 86.92320093512535, 97.17362210154533, 103.27628463506699, 90.7139079272747, 128.56433808803558, 25.67691318690777, 0.5315427307505161, 0.258961507352069, 0.1906043480266817, 0.10219438074273057, 0.07431529898894951, 0.4530769708799198, 0.40581771929282695, 20.462546087801456, 38.629335165023804, 36.572114154696465, 39.322794154286385, 57.438835054636, 26.857954412698746, 31.431941874325275, 27.91537307202816, 29.563323743641376, 54.74920637905598, 84.76355642080307, 79.94305148720741, 83.82805421948433, 99.77296382188797, 53.8118726760149, 3.1101119751110673, 0.21252439211821184, 0.04289880002033897, 0.047167351440293714, 0.03845736529910937, 0.008533534964954015, 0.04626716341590509, 0.024184976755350363, 0.09928658677381463, 0.08118180514429696, 0.028738336623064242, 0.006936680856597377, 0.018451579817337915, 0.08652448916109279, 0.01240870729816379, 0.04007838280813303, 0.0469026793143712, 0.04152374138357118, 0.05540900900086854, 0.03926813566067722, 0.05043336524977349, 0.053045517270220444, 0.04548039039946161, 0.0479617129167309, 0.021465215177158825, 0.004940103226545034, 0.02029210048931418, 0.07418218738166615, 0.040657217177795246, 0.03905418190697674, 0.048275841763825156, 0.011769682896556333, 0.19876347505487502, 0.17085146420868114, 0.11427327946876176, 0.13376560265896842, 0.2266799536300823, 0.11300131998723373, 0.11524004556122236, 0.2697455958696082, 0.11002421684679575, 0.22223960986593738, 0.1203180722950492, 0.18697932770010084, 0.11801764456322417, 0.15090931789018214, 0.1022951198683586, 0.1548018676112406, 0.10293294384609908, 0.09076171452761628, 0.17860992054920644, 0.29439267644193023, 0.11585308180656284, 0.11319172539515421, 0.1750937881297432, 0.23471373191569, 0.12990374816581607, 0.4028422711417079, 0.32119341020006686, 0.32017007761169225, 55.87687946856022, 152.6288115978241, 132.9178100824356, 125.89439615607262, 105.80223709344864, 79.1053256392479, 60.54389163851738, 44.79671582579613, 130.03247290849686, 138.21098685264587, 61.85344956815243, 76.32037907838821, 50.42334370315075, 18.381234370172024, 1.8229614431038499, 0.12538766080979258, 0.3376090043457225, 0.22090059734182432, 0.2658067212905735, 0.8480185456573963, 3.9217016380280256, 4.7821160685271025, 2.2974818805232644, 83.18414077162743, 129.09782946109772, 109.06816184520721, 107.62775793671608, 118.68768766522408, 103.15372601151466, 108.59415248036385, 115.98396554589272, 119.15785923600197, 113.91173154115677, 113.15390780568123, 108.89311283826828, 111.24897882342339, 111.48810759186745, 109.58845272660255, 109.67915385961533, 112.47882843017578, 110.23016229271889, 87.09531649947166, 85.69471925497055, 90.05895987153053, 96.51010170578957, 108.03821191191673, 110.23944899439812, 112.47606217861176, 104.22588407993317, 100.36928862333298, 92.98826828598976, 100.8333957195282, 105.81023186445236, 101.79331541061401, 92.00409829616547, 102.86933407187462, 102.53391847014427, 58.18604215979576, 84.1995906829834, 101.57667383551598, 73.00969272851944, 78.06564062833786, 111.0938635468483, 109.72734287381172, 109.44921299815178, 111.43904462456703, 106.67187362909317, 105.80661445856094, 107.06157311797142, 110.44977530837059, 108.36950093507767, 108.08925837278366, 109.23489689826965, 110.65937966108322, 112.467520236969, 109.12933856248856, 110.30202403664589, 105.76186046004295, 100.57307928800583, 94.56671118736267, 88.13478872179985, 87.17167720198631, 86.65048956871033, 82.32920184731483, 86.9487963616848, 87.8926733136177, 87.36454725265503, 80.04672512412071, 91.82873770594597, 102.07605823874474, 106.37748822569847, 98.51850673556328, 135.5791872739792, 22.00937658548355, 0.8840027335099876, 0.5232343578245491, 0.12851980602135882, 0.39755286590661854, 0.12129924347391352, 0.8532221289351583, 1.008698029909283, 27.536797486245632, 49.00626294314861, 56.45730972290039, 60.83216316998005, 113.93277481198311, 87.32689127326012, 61.30311369895935, 28.441266752779484, 24.603968560695648, 50.4611174762249, 86.82618454098701, 89.07457709312439, 93.85490298271179, 108.50726634263992, 74.31734696030617, 6.121844854205847, 0.3206724225310609, 0.18091549136443064, 0.11858839323394932, 0.308471989701502, 0.13249675277620554, 0.1484232270740904, 0.15728357975604013, 0.15989160543540493, 0.21823889954248443, 0.08816328481771052, 0.16496353171532974, 0.10683628439437598, 0.13524770125513896, 0.09099949864321388, 0.17202720424393192, 0.14636807172792032, 0.12278035501367413, 0.08551209582947195, 0.18927677941974252, 0.166664311545901, 0.1374922675313428, 0.10531393912970088, 0.11325837025651708, 0.10652772165485658, 0.12039696259307675, 0.18821586447302252, 0.20825563289690763, 0.11183148744748905, 0.13299091922817752, 0.12462169019272551, 0.10394680663011968], [0.015909135872789193, 0.0965335602813866, 0.0708028550434392, 0.03919277798559051, 0.02375915653828997, 0.013947405786893796, 0.06646352499956265, 0.03593267909309361, 0.018227712826046627, 0.023061194478941616, 0.05330393680196721, 0.04038591396238189, 0.013530755732062971, 0.022039837858756073, 0.01664312178036198, 0.0022044775460017263, 0.08490696345688775, 0.06300412976997904, 0.006061308858988923, 0.01609116243344033, 0.01619719492737204, 0.075545327126747, 0.06614395620999858, 0.09169152166577987, 0.2229153353255242, 0.3194325609365478, 0.5111556965857744, 24.481845013797283, 124.21538785099983, 108.5526891052723, 101.17235273122787, 65.95660239458084, 54.34841148555279, 19.92629986256361, 31.377027221024036, 74.98326882719994, 67.97203704714775, 29.626673944294453, 35.052891075611115, 27.135265432298183, 4.862230494618416, 1.367839202284813, 0.166741376160644, 0.13795897451927885, 0.04598426414304413, 0.22322429140331224, 0.1622190250782296, 2.6364260679110885, 3.3364214189350605, 4.293187754228711, 90.77560901641846, 115.56420966982841, 96.2700305879116, 106.90911769866943, 107.14107245206833, 98.28918904066086, 105.47500625252724, 104.45235192775726, 104.32054460048676, 102.43165835738182, 103.92925679683685, 103.89641135931015, 98.17339405417442, 90.02207145094872, 91.95704162120819, 96.04756012558937, 101.61137357354164, 99.44525420665741, 90.08223742246628, 74.23303708434105, 73.10119941830635, 75.858855843544, 89.53518837690353, 95.71361124515533, 100.40347918868065, 95.26031836867332, 93.46150249242783, 84.07073959708214, 97.03612267971039, 100.23288354277611, 110.2253745496273, 94.93742689490318, 88.63310158252716, 83.13647612929344, 105.89151710271835, 67.23087921738625, 36.29471763968468, 65.7311224937439, 41.57805293798447, 86.29033729434013, 90.97772777080536, 94.77182418107986, 92.56757766008377, 99.66003388166428, 94.68891263008118, 97.34771355986595, 94.31375116109848, 97.46587201952934, 97.14530602097511, 95.0525227189064, 91.44755735993385, 99.58172768354416, 96.57798126339912, 99.35797289013863, 96.05279624462128, 98.93704667687416, 92.3663404583931, 84.86212313175201, 76.83714374899864, 83.37460935115814, 86.02342441678047, 86.64818689227104, 80.63253208994865, 77.39160239696503, 72.817742228508, 79.5806573331356, 73.91396820545197, 75.27269169688225, 84.28529128432274, 97.40268900990486, 94.06690880656242, 108.40740770101547, 4.362940136343241, 0.29651373450178653, 0.14108185772784054, 0.10579801979474723, 0.10653489080141298, 0.08612436024122871, 0.14935076324036345, 0.12907300289953128, 7.243965491652489, 25.38506794720888, 29.403910897672176, 38.39839495718479, 60.48444002866745, 62.80474752187729, 54.97434049844742, 26.957368478178978, 19.837029352784157, 28.194971568882465, 67.37616062164307, 77.00542911887169, 71.65502741932869, 91.69541046023369, 68.8006129860878, 3.8886920968070626, 0.23258033936144784, 0.06308990719844587, 0.054808366621728055, 0.0410487186309183, 0.08825666183838621, 0.015240450611599954, 0.04619619925506413, 0.02645002445206046, 0.08929196526878513, 0.0361797623190796, 0.01891249619802693, 0.05560476900427602, 0.01773314746969845, 0.008434250448772218, 0.040337908139918, 0.005152173780516023, 0.034974996888195165, 0.00734653469407931, 0.0683842551370617, 0.05963128380244598, 0.03064180626097368, 0.08308776654303074, 0.027446665699244477, 0.10087127986480482, 0.07189609794295393, 0.03355850785737857, 0.08193630215828307, 0.05610910659015644, 0.032604977968730964, 0.02221774364443263, 0.0686768617015332, 0.06070057388569694, 0.02747080405242741, 0.056691262070671655, 0.04187561586149968, 0.0291737249790458, 0.039947360346559435, 0.06409616296878085, 0.035556176444515586, 0.05530149777769111, 0.06445687642553821, 0.025304497248725966, 0.0843510206323117, 0.02153728884877637, 0.04921987958368845, 0.04266949123120867, 0.04908723924017977, 0.030204851973394398, 0.007428660755977035, 0.0320407824619906, 0.06802261399570853, 0.027126017084810883, 0.04352542870037723, 0.053799843590240926, 0.10536122135818005, 0.12673853285377845, 0.5033674207516015, 28.41586321592331, 146.18753403425217, 114.60896372795105, 122.28161841630936, 80.02571225166321, 73.23264956474304, 37.03867591917515, 46.715479865670204, 33.808906227350235, 64.15863767266273, 34.34704475104809, 41.90073162317276, 38.346440345048904, 7.582592871040106, 1.251234384253621, 0.1266450816183351, 0.201069624745287, 0.033148931397590786, 0.7996287359856069, 1.0450600599870086, 2.809037030674517, 1.6978222830221057, 5.61471551656723, 99.22901540994644, 121.72729656100273, 101.23157635331154, 112.48999983072281, 110.01302674412727, 103.09045180678368, 109.40573573112488, 109.492447078228, 108.58789801597595, 104.68138843774796, 108.95722299814224, 106.88960194587708, 99.84748542308807, 93.83129104971886, 95.57460710406303, 101.03061273694038, 104.01257112622261, 102.21848979592323, 95.01253366470337, 78.98729637265205, 77.7350203692913, 80.60336485505104, 94.54879134893417, 98.740703612566, 102.8110907971859, 98.39745283126831, 95.57510867714882, 87.94101431965828, 99.86135467886925, 105.18613815307617, 113.39039951562881, 99.65594530105591, 93.45568120479584, 86.74253582954407, 111.12869247794151, 71.78388610482216, 42.59754963219166, 75.89550107717514, 46.06509156525135, 88.19474950432777, 94.64068561792374, 99.7932243347168, 98.61598670482635, 102.84947633743286, 100.52414551377296, 102.66598418354988, 99.1157814860344, 104.49351131916046, 100.05379155278206, 100.36715313792229, 96.51128724217415, 102.11455777287483, 100.89626714587212, 103.16840842366219, 99.03127402067184, 101.23744323849678, 95.02368226647377, 90.50040498375893, 80.73840200901031, 87.82537892460823, 89.99243304133415, 92.40807741880417, 85.87464720010757, 81.8992093205452, 75.21482080221176, 85.84296450018883, 78.54541808366776, 78.87096181511879, 85.78396886587143, 103.36190164089203, 95.17921552062035, 119.68138754367828, 8.670224659144878, 0.5019611993338913, 0.18859289033571258, 0.24034753820160404, 0.12880948110250756, 0.05398200002673548, 0.07340624972130172, 0.2075057668844238, 8.076246231794357, 33.30888345837593, 32.55128771066666, 35.89824691414833, 52.16201260685921, 35.2567995339632, 27.810090221464634, 31.50571681559086, 36.3714849203825, 49.72222812473774, 74.53858628869057, 93.10977816581726, 81.25839650630951, 100.73330149054527, 87.99378588795662, 5.207823375239968, 0.34200572466943413, 0.07861513935495168, 0.05845008527103346, 0.09988739984692074, 0.023132702262955718, 0.024159582317224704, 0.042649716706364416, 0.05546664418943692, 0.06758278759662062, 0.04008059069747105, 0.04578480824420694, 0.050788664739229716, 0.017899472040880937, 0.051971295615658164, 0.005350183882910642, 0.01930353380885208, 0.026519274251768366, 0.026966759614879265, 0.040893858385970816, 0.062027222229517065, 0.042911064010695554, 0.10045702787465416, 0.028069027030142024, 0.022731521348759998, 0.06827485514804721, 0.09051276108948514, 0.07002624945016578, 0.007596998866574722, 0.016599657901679166, 0.06603995905607007, 0.18872288492275402, 0.2987990149995312, 0.12934253609273583, 0.09363625285914168, 0.16773429553722963, 0.21452399028930813, 0.167420337384101, 0.15090156986843795, 0.12286950179259293, 0.10288925361237489, 0.11783840847783722, 0.12608042598003522, 0.19641815481008962, 0.10129064525244758, 0.1499711096403189, 0.04967782922904007, 0.21512898907531053, 0.14698075916385278, 0.11052703674067743, 0.1456795516423881, 0.14347026706673205, 0.18538764357799664, 0.21745348465628922, 0.2557599713327363, 0.33453413809183985, 0.4489888355601579, 0.6622804154176265, 51.816945523023605, 170.06004184484482, 132.0184287428856, 134.10699427127838, 91.99644550681114, 76.93222224712372, 30.85955198854208, 48.87987032532692, 113.70547860860825, 95.00814869999886, 45.1140595972538, 63.86059686541557, 45.76674297451973, 11.225752830505371, 2.3936896305531263, 0.5941842100583017, 0.3706682100892067, 0.15778758708620444, 0.41986630763858557, 0.4420882277190685, 4.924112549051642, 9.26626542583108, 5.2245348785072565, 107.39055186510086, 122.32776314020157, 103.19262072443962, 116.07051730155945, 117.2127740085125, 106.79250955581665, 114.29728165268898, 114.11483064293861, 113.03633451461792, 109.89161565899849, 111.95385619997978, 112.52311125397682, 105.43792024254799, 98.80158394575119, 100.79469099640846, 109.26350936293602, 112.33169272542, 107.97520369291306, 102.22705453634262, 83.75584289431572, 81.1981925368309, 84.49304893612862, 97.6664936542511, 104.8834615945816, 105.32033935189247, 104.90236937999725, 103.43574687838554, 94.20764565467834, 106.5619607269764, 108.63427832722664, 116.76736190915108, 102.67651721835136, 98.89865353703499, 92.04981744289398, 117.7139063179493, 76.17053791880608, 49.86084848642349, 85.9655611217022, 53.98092560470104, 89.79526922106743, 102.81685888767242, 103.1767375767231, 105.61006620526314, 109.68223169445992, 104.81517925858498, 108.49712088704109, 103.01292836666107, 106.80966943502426, 105.9914593398571, 102.89008855819702, 101.51368841528893, 106.69338047504425, 106.6003006696701, 110.07481142878532, 103.14970582723618, 110.20251497626305, 103.33825930953026, 94.50230464339256, 84.8004524409771, 92.49363362789154, 95.96626728773117, 98.45720082521439, 88.82754474878311, 86.40371561050415, 79.23026293516159, 91.25961184501648, 81.44346937537193, 83.44270169734955, 92.90515154600143, 107.68871426582336, 101.17517977952957, 123.46338540315628, 7.256975518539548, 0.6448607845231891, 0.4642497666645795, 0.3581504645990208, 0.2825559553457424, 0.19693086011102423, 0.2231668640160933, 0.34197220928035676, 12.390151899307966, 44.42002683877945, 49.946704879403114, 54.60423655807972, 89.4663816690445, 95.10959565639496, 73.55309396982193, 38.29898849129677, 29.452434293925762, 41.42407760024071, 84.06747177243233, 102.01744258403778, 91.76109373569489, 108.90672370791435, 105.40001347661018, 8.094180319458246, 0.5722217448055744, 0.1994555871351622, 0.11209549164050259, 0.18222404614789411, 0.12283666917937808, 0.1891016325680539, 0.17000595020363107, 0.2084785740589723, 0.17721784446621314, 0.19796148058958352, 0.10159695186302997, 0.1432236810796894, 0.1861189558985643, 0.08608256990555674, 0.08053728699451312, 0.16397711355239153, 0.09920049764332362, 0.08104559878120199, 0.1851143254316412, 0.10455515250214376, 0.17998464521951973, 0.23858314147219062, 0.1831006264546886, 0.22311945562250912, 0.16058588458690792, 0.14621524867834523, 0.2649751299759373, 0.1403466417104937, 0.09594273651600815, 0.18880863266531378], [0.020864413236267865, 0.05290830529702362, 0.016932696671574377, 0.013140179180481937, 0.040108629036694765, 0.025708951034175698, 0.012246132428117562, 0.07898485506302677, 0.022665924770990387, 0.020006911690870766, 0.06365402849041857, 0.049164006995852105, 0.027669443588820286, 0.057580644424888305, 0.03657711189589463, 0.08459935808787122, 0.08827936413581483, 0.04999365017283708, 0.0428542860026937, 0.02419524622382596, 0.10007455464801751, 0.13546534348279238, 0.059664502332452685, 0.07230466508190148, 0.23830194171750918, 0.5242090648971498, 13.213242832571268, 104.57661285996437, 101.44928187131882, 103.63589733839035, 82.68012821674347, 74.54805538058281, 33.746281787753105, 64.22929108142853, 54.91589203476906, 73.15410777926445, 42.527872771024704, 36.616738960146904, 25.504729226231575, 1.733433734625578, 0.33858507697004825, 0.16421759908553213, 0.40174502064473927, 0.08429893670836464, 0.5880926619283855, 0.4226510238368064, 16.31855685263872, 0.9175409807357937, 8.493184559047222, 92.10939824581146, 105.99278926849365, 102.8972701728344, 105.18018007278442, 103.10884281992912, 97.37180426716805, 111.24690413475037, 98.41620862483978, 104.31823432445526, 102.4384979903698, 102.9254798591137, 97.16451779007912, 97.71128565073013, 96.2730248272419, 98.28717514872551, 81.47332057356834, 84.32163253426552, 91.85404434800148, 95.49661248922348, 84.18942242860794, 72.39223346114159, 72.55548790097237, 82.83806294202805, 90.45108363032341, 98.94520863890648, 99.35097366571426, 98.19113910198212, 83.8923391699791, 87.70823881030083, 95.71891576051712, 99.69311490654945, 98.69331255555153, 101.24056667089462, 90.73797583580017, 83.22575613856316, 91.96895018219948, 110.79369485378265, 41.222601011395454, 30.122758224606514, 53.37071634829044, 95.72013929486275, 95.12039467692375, 97.5784295797348, 96.69705167412758, 96.77468150854111, 95.41503086686134, 92.28468284010887, 94.5014762878418, 97.55897462368011, 95.79355135560036, 94.93916720151901, 91.92513093352318, 94.06113311648369, 98.83130595088005, 98.34073707461357, 97.96204179525375, 96.6253799200058, 85.65416023135185, 76.93407654762268, 77.22626566886902, 87.71129384636879, 89.27976608276367, 87.90550142526627, 83.44327926635742, 82.04059973359108, 78.06659817695618, 79.16139543056488, 75.12326091527939, 79.92364212870598, 78.34782108664513, 86.07622638344765, 94.83581274747849, 104.71149042248726, 69.95781049132347, 0.12399562183418311, 0.15368293155916035, 0.07224592409329489, 0.12860947230365127, 0.05525457549083512, 0.055492597093689255, 0.02043858930846909, 0.3676887246547267, 3.178724655881524, 19.028278850018978, 44.5467234402895, 36.660360619425774, 57.8345800191164, 88.05052444338799, 66.47574573755264, 31.963729038834572, 18.22564221918583, 30.189877822995186, 37.737268432974815, 79.02553752064705, 70.2866980433464, 85.47094166278839, 55.32329097390175, 1.8876524968072772, 0.06389757167198695, 0.022451037766586524, 0.08807272795820609, 0.034928085733554326, 0.03416654573811684, 0.02114318987878505, 0.03939755879400764, 0.03749661431356799, 0.09368695638841018, 0.0801439413044136, 0.0491585633426439, 0.04673420808103401, 0.050100311636924744, 0.06532799452543259, 0.04577493396936916, 0.0245132732015918, 0.053039747072034515, 0.05911421467317268, 0.00782805680501042, 0.03749567178601865, 0.026013892093033064, 0.042419717719894834, 0.08604932168964297, 0.023048364600981586, 0.021230663114693016, 0.0446168496273458, 0.021000254091632087, 0.06241271228645928, 0.014291153747763019, 0.038686210245941766, 0.03282561476225965, 0.034773748702718876, 0.05222432344453409, 0.02448780640406767, 0.028404819167917594, 0.06175837181217503, 0.06092075796914287, 0.06435957344365306, 0.05669488375133369, 0.0398185828817077, 0.05255965174001176, 0.047644960577599704, 0.05123714458022732, 0.03276304429164156, 0.012249459105078131, 0.034061780461343005, 0.004199227405479178, 0.031438607547897846, 0.047483669623034075, 0.016131518568727188, 0.04611280783137772, 0.08699491430888884, 0.12217770141432993, 0.19351067254319787, 0.513589228503406, 18.58928080648184, 128.70262026786804, 109.19589579105377, 129.50665712356567, 110.63626170158386, 102.6117230951786, 58.938268795609474, 45.67442312836647, 23.134733699262142, 59.46126513183117, 47.916245833039284, 43.53044517338276, 36.67440086603165, 2.5280710821971297, 0.3758522303542122, 0.07024617749266326, 0.20501948310993612, 0.126492703857366, 1.7766047618351877, 2.3597242031246424, 13.097233157604933, 1.330801045987755, 11.818716712296009, 105.23542910814285, 113.71055513620377, 108.79437133669853, 109.08706963062286, 106.06299430131912, 104.5742417871952, 113.50206032395363, 101.16513311862946, 106.51358172297478, 106.80774673819542, 105.65972954034805, 98.3748060464859, 101.06173306703568, 99.93965327739716, 102.81300589442253, 86.78092136979103, 89.11191388964653, 93.76242354512215, 99.20962885022163, 89.52008798718452, 75.63522264361382, 75.55259987711906, 87.05256879329681, 95.662731975317, 104.09561187028885, 102.10093170404434, 101.39392644166946, 87.44067996740341, 91.89576610922813, 99.65240389108658, 102.47629076242447, 101.17988392710686, 102.89055213332176, 93.96185204386711, 89.56468239426613, 92.89967983961105, 113.98122981190681, 46.825320571660995, 34.92432117462158, 57.94390395283699, 97.02946543693542, 100.07002428174019, 101.62224858999252, 99.92843627929688, 99.35832247138023, 96.50048062205315, 96.09958693385124, 97.95319586992264, 100.27458250522614, 100.8424924314022, 99.29862767457962, 99.03370589017868, 98.87591555714607, 103.406982421875, 100.92528238892555, 101.4242336153984, 98.71792763471603, 90.70980414748192, 80.31781017780304, 81.50984421372414, 91.51393219828606, 94.56760033965111, 91.69683918356895, 88.33885297179222, 88.1292562186718, 84.53423112630844, 83.15817296504974, 79.79023888707161, 84.28048834204674, 82.63063967227936, 88.35790514945984, 102.35443890094757, 105.17488315701485, 79.992266446352, 1.2193257152102888, 0.23870602628448978, 0.19303838460473344, 0.254497904679738, 0.34063738246914, 0.08797281261649914, 0.05014693335397169, 0.26131788559723645, 2.8329396480694413, 26.14396322518587, 44.776459112763405, 37.18477427959442, 48.47337193787098, 51.571395099163055, 37.18404471874237, 27.426662296056747, 28.930114321410656, 59.89319935441017, 64.82024297118187, 92.3146404325962, 83.54969635605812, 91.74734607338905, 78.76259163022041, 2.6480249455198646, 0.12821712851291522, 0.059068234913866036, 0.011033112459699623, 0.029518033261410892, 0.044089097282267176, 0.03772478019527625, 0.014887104825902497, 0.045593096656375565, 0.05286989173328038, 0.051661979596246965, 0.046878978828317486, 0.028973751432204153, 0.031889235906419344, 0.031467974331462756, 0.04316540544095915, 0.10769553555292077, 0.014314904328784905, 0.02408292959444225, 0.04899988845863845, 0.01194108654090087, 0.04880588734522462, 0.01878552771813702, 0.019909066941181663, 0.04881867454969324, 0.012977337137272116, 0.07362099015153944, 0.041540413731127046, 0.01570147924212506, 0.08658927865326405, 0.12367302508209832, 0.08203077013604343, 0.12671515520196408, 0.09594836199539714, 0.10436963042593561, 0.11708478719810955, 0.09277317221858539, 0.2054865166428499, 0.07731315999990329, 0.14868069294607267, 0.09405617485754192, 0.16042942501371726, 0.10138423749594949, 0.1202613944769837, 0.20251233014278114, 0.2599205105798319, 0.1561190461507067, 0.17432115302653983, 0.13129760540323332, 0.0755338609451428, 0.236558607139159, 0.2291072960360907, 0.1685507025104016, 0.2487139470758848, 0.28647986822761595, 0.7289601874072105, 33.29216815531254, 155.92247486114502, 119.58608105778694, 135.77416241168976, 106.99592784047127, 98.8702766597271, 52.44285933673382, 89.86800491809845, 81.94932863116264, 103.66636410355568, 72.04728037118912, 65.18613293766975, 49.82283912599087, 4.82716835103929, 0.7606860506348312, 0.43975648877676576, 0.576906893402338, 0.24729662312893197, 0.9450823778752238, 1.132313353009522, 28.258644752204418, 5.338202929124236, 9.387828502804041, 117.8307044506073, 117.02796712517738, 111.21847406029701, 110.73977574706078, 110.02107471227646, 107.83268094062805, 120.05936846137047, 105.6217847764492, 110.05072832107544, 112.69581958651543, 111.24713212251663, 107.35433980822563, 105.97240716218948, 104.94016975164413, 108.23521614074707, 90.04381388425827, 95.45416116714478, 99.59232151508331, 102.96459496021271, 94.64808762073517, 81.01831778883934, 81.41696959733963, 91.4752122759819, 100.26392787694931, 106.87295123934746, 106.08222126960754, 107.91295543313026, 91.44283801317215, 95.89813694357872, 103.55746954679489, 107.01098263263702, 102.93932631611824, 106.82277113199234, 97.09951087832451, 92.53366827964783, 98.82129728794098, 118.00480350852013, 51.433264911174774, 48.96764561533928, 64.667027592659, 98.8463607430458, 106.45289897918701, 106.58266961574554, 102.48400434851646, 105.74951872229576, 102.15062543749809, 101.47810712456703, 102.87153795361519, 105.37220656871796, 105.184785425663, 104.34507608413696, 105.02603754401207, 106.44591495394707, 106.91482499241829, 103.95607575774193, 103.34878474473953, 102.29893147945404, 94.35248628258705, 86.31809860467911, 88.72270837426186, 97.51067161560059, 96.99335217475891, 95.96400260925293, 90.87813511490822, 92.69410327076912, 88.10710340738297, 89.24449637532234, 83.47154974937439, 89.40103277564049, 85.23739099502563, 95.80571070313454, 107.25777179002762, 113.11911687254906, 79.40440759062767, 0.9856198495253921, 1.3999268179759383, 0.2431736810831353, 0.330932317301631, 0.5111578933428973, 0.3886512201279402, 0.16743712476454675, 0.6360655033495277, 6.178613333031535, 34.708709344267845, 69.31313708424568, 47.44499512016773, 84.32520434260368, 121.37083008885384, 87.80774027109146, 47.7225436270237, 26.053900457918644, 45.65811060369015, 52.755791544914246, 101.17704167962074, 93.40923249721527, 99.90915611386299, 94.73937392234802, 4.645730461925268, 0.3342267405241728, 0.09216835896950215, 0.21141946781426668, 0.1998039215686731, 0.21207396785030141, 0.0908201809215825, 0.10387046189862303, 0.11265244378591888, 0.2225938072660938, 0.14406043774215505, 0.11869537382153794, 0.09748591386596672, 0.13902515871450305, 0.11783834168454632, 0.18677399028092623, 0.18506329535739496, 0.17082645383197814, 0.14964279835112393, 0.13740389258600771, 0.08920298918383196, 0.22238346777157858, 0.14728855749126524, 0.20185929955914617, 0.11027317770640366, 0.10077718296088278, 0.14075185434194282, 0.1179631931881886, 0.13132534688338637, 0.1157207642972935], [0.025281594571424648, 0.01947894041222753, 0.04381984981591813, 0.05196439735300373, 0.04960957761795726, 0.018984109738084953, 0.06998458527959883, 0.016257516690529883, 0.04345241250121035, 0.02904760440287646, 0.05052759202953894, 0.04913987977488432, 0.06445161459851079, 0.02683739770873217, 0.04076729623193387, 0.024274108691315632, 0.03366330282005947, 0.046844090466038324, 0.06676513381535187, 0.08712287541129626, 0.04229416488669813, 0.027492702974996064, 0.054392129386542365, 0.246779925073497, 0.88567137834616, 17.556051649153233, 112.98814550042152, 104.04683008790016, 110.54762005805969, 78.52299928665161, 62.03240476548672, 29.484730660915375, 24.17399313300848, 52.42811232805252, 89.04898166656494, 38.238560333848, 28.19780431687832, 26.507579013705254, 2.493166630156338, 0.4112126282416284, 0.19491116458084434, 0.6262534204870462, 0.0347394614800578, 0.13452786253765225, 1.4580000517889857, 7.736168280243874, 1.3152177259325981, 14.25605982542038, 95.66745892167091, 99.50120240449905, 109.01182606816292, 110.03576472401619, 102.39926889538765, 101.97975620627403, 100.50215989351273, 97.55140542984009, 100.99101126194, 102.76464968919754, 97.6312543451786, 93.8248997926712, 96.94666028022766, 97.12056934833527, 95.83420157432556, 91.45981550216675, 84.72450971603394, 76.35254815220833, 78.60458850860596, 82.84427180886269, 73.31892013549805, 67.64575615525246, 74.47063833475113, 85.0610576570034, 92.86734357476234, 95.0111049413681, 95.12371569871902, 90.33632218837738, 82.94879660010338, 85.55468916893005, 95.18750667572021, 97.84791871905327, 86.12751603126526, 92.87275448441505, 92.949198782444, 86.69335126876831, 86.41134560108185, 95.19233241677284, 82.21394643187523, 15.061994679272175, 64.29485276341438, 90.00898495316505, 82.0675478875637, 92.06047967076302, 92.96455755829811, 90.4695962369442, 92.19780430197716, 92.24074959754944, 88.53390410542488, 94.34359475970268, 95.44961661100388, 95.49976631999016, 88.61081957817078, 85.21757885813713, 93.76268953084946, 93.7326255440712, 97.37154588103294, 97.4100150167942, 87.53312140703201, 73.51497441530228, 73.4683509171009, 85.09845525026321, 90.51871240139008, 90.60261189937592, 88.82078871130943, 78.59981596469879, 80.58716252446175, 80.38075000047684, 77.87735313177109, 71.39398902654648, 85.16697317361832, 78.42326983809471, 88.49712207913399, 92.83203586935997, 105.20037978887558, 31.25633429735899, 1.030844310298562, 0.3045611979905516, 0.19864735862938687, 0.03434247184486594, 0.12222711360664107, 0.05745105430833064, 0.0528669008781435, 0.40280457003973424, 1.2614832655526698, 22.010047249495983, 43.56213167309761, 43.30794811248779, 63.54791544377804, 97.88411557674408, 88.53244498372078, 47.0468220859766, 16.41564354300499, 19.40853014588356, 38.292202055454254, 72.0279698073864, 66.32840484380722, 80.59236064553261, 42.84831337630749, 0.29069378273561597, 0.10825916702742688, 0.10758811709820293, 0.019520591595210135, 0.046062100591370836, 0.08094201722997241, 0.04698722477769479, 0.02182382835599128, 0.014117639620963018, 0.02994394068082329, 0.01679044737102231, 0.007639745181222679, 0.03394743776880205, 0.04193443477561232, 0.06857995205791667, 0.040413492170046084, 0.05517573714314494, 0.0026868380518862978, 0.04412512855196837, 0.05755133701313753, 0.051930811459897086, 0.06453571477322839, 0.05850631780049298, 0.07697344932239503, 0.060211045856704004, 0.011111730946140597, 0.038595723890466616, 0.015418276616401272, 0.03962320879509207, 0.048241517433780245, 0.0278893215363496, 0.03869064457830973, 0.03796246412093751, 0.017057501790986862, 0.0518509563698899, 0.03195553566911258, 0.025917253333318513, 0.04228898469591513, 0.09926631872076541, 0.07377819929388352, 0.07470612137694843, 0.057966813546954654, 0.010821348969329847, 0.07367001642705873, 0.03159047322697006, 0.010882895276154159, 0.10370918578701094, 0.042211307809338905, 0.04782395175425336, 0.0365523093205411, 0.02164504498068709, 0.05806707027659286, 0.20439083949895576, 0.6899813446216285, 23.770300894975662, 136.86406552791595, 112.92541086673737, 128.72893005609512, 83.59536230564117, 72.98266857862473, 60.28560809791088, 36.65126010775566, 30.094050765037537, 56.72269508242607, 43.006069511175156, 34.147445261478424, 37.41844654083252, 3.047834266908467, 0.3607220359845087, 0.1813371351454407, 0.36804169008973986, 0.1524355891160667, 0.49843249493278563, 4.024450974538922, 3.178588100709021, 0.6092423864174634, 17.820544056594372, 105.5316536128521, 106.26048490405083, 112.97249034047127, 115.3102844953537, 109.23310339450836, 107.16775462031364, 104.61845621466637, 99.50143039226532, 104.75283220410347, 106.26270398497581, 102.28769168257713, 98.57307180762291, 100.70003047585487, 99.16855305433273, 101.69767454266548, 94.67351585626602, 89.12310048937798, 79.28704708814621, 83.88207212090492, 84.64801982045174, 76.79169818758965, 70.65267160534859, 78.57982903718948, 89.24413159489632, 98.40294733643532, 99.0359553694725, 98.87587755918503, 93.39674636721611, 86.33525848388672, 90.85665106773376, 98.53302955627441, 102.19808489084244, 91.51442617177963, 95.02453342080116, 98.67363721132278, 89.0132787823677, 90.88029339909554, 98.48914951086044, 87.87720054388046, 19.483285434544086, 65.53460463881493, 91.15450948476791, 88.75801607966423, 95.87652370333672, 98.26442956924438, 95.36497995257378, 96.21933370828629, 94.35052558779716, 94.15747314691544, 100.26132881641388, 100.1399253308773, 99.647616147995, 93.52332517504692, 90.4575964808464, 95.49935594201088, 97.18337997794151, 101.37130245566368, 99.5556914806366, 92.88983836770058, 76.71441793441772, 77.0091225206852, 89.11297783255577, 94.2723485827446, 94.72557306289673, 93.54425445199013, 83.0365414917469, 83.76960575580597, 84.01337787508965, 84.30084004998207, 75.40300950407982, 86.57155260443687, 82.35022231936455, 92.47609376907349, 95.41320696473122, 111.50936365127563, 39.16331671178341, 1.2229794566519558, 0.4682274704100564, 0.6417054100893438, 0.2561970963142812, 0.2666717389365658, 0.05491531752340961, 0.08111276314593852, 0.30239225656259805, 0.8664253517054021, 30.207826159894466, 38.25494505465031, 43.38056221604347, 66.51688233017921, 65.53674012422562, 43.53078335523605, 24.866737760603428, 18.310748152434826, 32.688627541065216, 55.79755112528801, 86.40762940049171, 77.81334936618805, 91.78513124585152, 64.50905486941338, 0.8826644928194582, 0.025150609217234887, 0.01550610979393241, 0.011466335599834565, 0.0364487092156196, 0.05952209161478095, 0.06922251093783416, 0.05024050333304331, 0.024333116853085812, 0.030049813613004517, 0.019693289359565824, 0.014089783107920084, 0.0601573774474673, 0.026905959166469984, 0.05074339744169265, 0.05336525304301176, 0.04077592740941327, 0.041898674389813095, 0.011958368377236184, 0.09438700944883749, 0.055613047661609016, 0.055181088027893566, 0.09250560571672395, 0.047284770334954374, 0.02957457192678703, 0.021068724636279512, 0.06971721173613332, 0.046653377066832036, 0.037689346354454756, 0.12131158538977616, 0.08931126110837795, 0.11766373660066165, 0.16027758159907535, 0.1426237734267488, 0.1627520503825508, 0.191307102504652, 0.10605158196995035, 0.12054451639414765, 0.2545527048641816, 0.2560664189513773, 0.23064281442202628, 0.1807408343302086, 0.08702325692865998, 0.12665033602388576, 0.15192481339909136, 0.1219001530262176, 0.15700953430496156, 0.2587464329553768, 0.1339672293397598, 0.17416265996871516, 0.151527140988037, 0.2197481459006667, 0.40389098518062383, 1.1277368548326194, 32.47396185994148, 160.69392442703247, 127.27838069200516, 147.0185798406601, 103.47641229629517, 86.41345828771591, 46.67293734848499, 34.84596937894821, 85.18263593316078, 134.87120926380157, 61.0140024125576, 49.45885665714741, 45.692487359046936, 5.96272649243474, 0.8696362981572747, 0.6086849444545805, 0.9958489006385207, 0.3584541811142117, 0.38377231161575764, 2.5755082117393613, 15.830453094094992, 5.800235336646438, 15.362137723714113, 116.68713301420212, 107.1813502907753, 116.35151222348213, 122.08559453487396, 111.9874919950962, 107.56995543837547, 107.39772588014603, 104.27137523889542, 108.12960460782051, 109.92015212774277, 108.3840237557888, 102.16197922825813, 105.33201232552528, 105.20376920700073, 105.45946508646011, 99.28991094231606, 93.22195574641228, 85.96742302179337, 88.9827512204647, 91.09296798706055, 82.6635991036892, 75.58590888977051, 82.43771642446518, 93.84377717971802, 102.85418808460236, 100.12699082493782, 103.72405260801315, 99.05329003930092, 89.62696865200996, 97.10082560777664, 106.03432103991508, 106.69315248727798, 94.8529726266861, 98.30400064587593, 104.29214492440224, 95.81602334976196, 94.58093762397766, 106.31435081362724, 90.8741757273674, 26.788684129714966, 70.24069771170616, 93.32493022084236, 95.36811858415604, 100.49429431557655, 105.55689185857773, 98.91648218035698, 104.05548602342606, 99.76265117526054, 98.73378038406372, 102.38270178437233, 104.8743724822998, 103.62301602959633, 98.74512657523155, 95.46869158744812, 101.8330080807209, 100.92903658747673, 107.15395376086235, 104.78311657905579, 97.67848581075668, 82.07498028874397, 81.30456402897835, 94.74052906036377, 100.91544091701508, 99.0323455631733, 97.01694890856743, 88.1757353246212, 88.70746359229088, 89.29032951593399, 88.18424686789513, 78.40015947818756, 94.39974814653397, 86.47651970386505, 98.28342095017433, 99.42935585975647, 113.96112129092216, 38.16154986619949, 2.596021885983646, 2.206092271953821, 0.42963392101228237, 0.28577554039657116, 0.3165235201595351, 0.22628576931310818, 0.2201138762757182, 0.578148536151275, 2.791712572798133, 38.12081225216389, 64.4741803407669, 50.993590503931046, 82.77456074953079, 137.49118387699127, 115.22924244403839, 68.39839696884155, 23.57290718704462, 29.11312960088253, 51.935548558831215, 95.13193845748901, 87.99380868673325, 101.61461859941483, 78.2396712899208, 1.7097213445231318, 0.1950787118403241, 0.20713068544864655, 0.12167307068011723, 0.20596895716153085, 0.23776465648552403, 0.2643212385009974, 0.19841335946694016, 0.09130099613685161, 0.14591081970138475, 0.0714559449988883, 0.09435825122636743, 0.1926934640505351, 0.10778501629829407, 0.28419155976735055, 0.13723723590373993, 0.14657274121418595, 0.17591265903320163, 0.11801501736044884, 0.17123172583524138, 0.1482113142265007, 0.1409165665972978, 0.08100632432615384, 0.19236262945923954, 0.11471998557681218, 0.05083430682134349, 0.12739675847114995, 0.1985904507455416, 0.08646253467304632], [0.07183392823208123, 0.018964003102155402, 0.05218848884396721, 0.05635257555695716, 0.05752140990807675, 0.04554564002319239, 0.07816432174877264, 0.020116916530241724, 0.06288656615652144, 0.04601979446306359, 0.04755966925586108, 0.05642103496938944, 0.011469320888863876, 0.04276598527212627, 0.08302801623358391, 0.05078171452623792, 0.10373458208050579, 0.05277340882457793, 0.023837390035623685, 0.07639729039510712, 0.020895819070574362, 0.029470316876540892, 0.141533870191779, 0.2032525630784221, 20.94357557594776, 110.77528864145279, 96.94032981991768, 103.86587619781494, 73.21727558970451, 67.608662545681, 87.03345581889153, 75.27064740657806, 75.06696313619614, 68.43010246753693, 49.74365137517452, 35.3808780759573, 27.397373467683792, 3.587730433791876, 0.5403152131475508, 0.1558132070931606, 0.17143425793619826, 0.1258693146519363, 0.3302638797322288, 0.389289318700321, 6.4506948832422495, 2.010643584653735, 8.904192354530096, 105.30016243457794, 97.99944698810577, 106.55125290155411, 100.38821920752525, 101.55677050352097, 106.01500287652016, 102.45900928974152, 98.12339633703232, 100.76405704021454, 100.06244748830795, 96.22667491436005, 93.29714611172676, 91.96104660630226, 89.68050017952919, 92.39693641662598, 92.63524442911148, 95.40193676948547, 83.74275639653206, 72.36519411206245, 71.90129980444908, 73.80799189209938, 72.44811326265335, 68.65048304200172, 79.00200918316841, 87.25085735321045, 97.38439679145813, 89.21578511595726, 95.38715556263924, 92.05136016011238, 81.63293480873108, 82.89986282587051, 93.01138624548912, 89.29201662540436, 95.24689748883247, 92.27997109293938, 97.41053178906441, 84.97163325548172, 88.52999791502953, 85.8981603384018, 104.36567857861519, 35.715529918670654, 52.407148852944374, 105.24930596351624, 86.64903804659843, 98.0625768005848, 86.95106863975525, 94.72969964146614, 87.55087405443192, 93.16251933574677, 86.67847886681557, 91.7069086432457, 92.32752934098244, 97.73788422346115, 92.4342580139637, 88.06675717234612, 82.06579238176346, 96.3508066534996, 94.60024818778038, 93.2615116238594, 77.44602307677269, 71.44578024744987, 72.51710996031761, 84.84747871756554, 86.3330926001072, 89.48565423488617, 85.8029754459858, 81.86958611011505, 75.99340662360191, 76.82633712887764, 77.38391920924187, 83.72985988855362, 76.06526836752892, 81.12506166100502, 83.39799329638481, 92.47325152158737, 92.94827163219452, 79.33601126074791, 15.27692824602127, 1.4429732831194997, 0.21236309374216944, 0.10608960961690173, 0.14635376312071458, 0.016915404630708508, 0.08383414446143433, 0.0632659372058697, 0.25585333351045847, 1.6707762842997909, 22.599530518054962, 40.18687158823013, 46.312378495931625, 70.77897682785988, 109.31628093123436, 122.91247576475143, 102.00089067220688, 36.49529367685318, 30.748111568391323, 51.220943704247475, 64.92277666926384, 77.02204182744026, 83.8346354663372, 25.524341873824596, 1.199769708327949, 0.4415849922224879, 0.12088505085557699, 0.05578460622928105, 0.09542606814648025, 0.04240261121594813, 0.015545582773484057, 0.039832063994253986, 0.03490325347229373, 0.053430610278155655, 0.038618641410721466, 0.014086982428125339, 0.03909815044607967, 0.02849747073923936, 0.018252661975566298, 0.048891286278376356, 0.01022911790641956, 0.019362946441106033, 0.05315548871294595, 0.035035292676184326, 0.05996092353598215, 0.0855358742410317, 0.036815215134993196, 0.017795864514482673, 0.07360438830801286, 0.03245344625611324, 0.05106523720314726, 0.07843015162507072, 0.11097961323685013, 0.015236881808959879, 0.10417856450658292, 0.06390740512870252, 0.048040681140264496, 0.048677662780391984, 0.049107718805316836, 0.025501856580376625, 0.08513290289556608, 0.04548158154648263, 0.04659025369619485, 0.033431956835556775, 0.07724234426859766, 0.052903689138474874, 0.043338455725461245, 0.053508038545260206, 0.0365194433106808, 0.04904001638351474, 0.03748664355953224, 0.03216822777176276, 0.10512461725738831, 0.05344183155102655, 0.055534829007228836, 0.22245514439418912, 29.71535548567772, 136.05113714933395, 107.07491800189018, 124.39623534679413, 87.27869465947151, 99.66460883617401, 98.44269320368767, 52.77542509138584, 35.08411779999733, 55.34418985247612, 58.58695484697819, 42.88626194000244, 41.65709629654884, 4.089710572734475, 0.4089591413503513, 0.10941950007691048, 0.21717051859013736, 0.12670608615735546, 0.6428012356627733, 1.317728441208601, 1.35990938404575, 1.5888375998474658, 12.3966552503407, 111.34553164243698, 105.92038035392761, 111.76995366811752, 106.13811627030373, 106.79797366261482, 110.2242574095726, 104.95932072401047, 102.59084701538086, 105.44409111142159, 101.7872965335846, 100.1469549536705, 95.71773782372475, 94.83825981616974, 93.6577695608139, 95.76487049460411, 93.8589383661747, 100.13541877269745, 89.47832062840462, 76.09596312046051, 75.41607320308685, 79.3628378212452, 76.69018283486366, 73.09591010212898, 82.82319813966751, 89.92397591471672, 100.81935167312622, 93.62707480788231, 98.18159401416779, 95.5900114774704, 84.34831470251083, 87.28658303618431, 96.1274166405201, 92.31977015733719, 96.38035386800766, 95.4209053516388, 101.7556594312191, 88.2239243388176, 93.0135141313076, 88.78617256879807, 107.96215519309044, 41.39180973172188, 55.16034811735153, 108.07254686951637, 91.72956302762032, 102.92695418000221, 91.26167893409729, 99.8905523121357, 91.61332726478577, 95.00171184539795, 90.4813452064991, 94.57793578505516, 95.13677179813385, 101.04030981659889, 98.73982965946198, 91.92628607153893, 87.00197830796242, 99.7713603079319, 100.13934016227722, 95.44392451643944, 81.65429726243019, 74.33200657367706, 74.85798954963684, 89.87125754356384, 90.90992420911789, 92.16159224510193, 89.98788848519325, 86.24199628829956, 81.67779520154, 80.77362611889839, 83.06583032011986, 87.65094548463821, 81.30850821733475, 85.45888110995293, 87.92672708630562, 94.54912573099136, 95.98253041505814, 88.73923748731613, 18.77876903861761, 1.2364312098361552, 0.6283218157477677, 1.014215333852917, 0.578134999377653, 0.06753154972102493, 0.18624379998072982, 0.04039837091113441, 0.34406954830046743, 1.2542134243994951, 27.18728084117174, 32.91056603193283, 50.91767057776451, 82.84307107329369, 87.73460179567337, 83.61011311411858, 64.68130722641945, 27.061997763812542, 54.11252774298191, 65.84623351693153, 76.31960391998291, 85.20287364721298, 97.46365293860435, 43.331351056694984, 1.5376860508695245, 0.28204494214151055, 0.1026012928923592, 0.027712473311112262, 0.06146442567114718, 0.07874707836890593, 0.01961847530765226, 0.05654983840940986, 0.017103320133173838, 0.0601716303935973, 0.033273419248871505, 0.03170123134623282, 0.009613026795705082, 0.057396176198381, 0.018897191257565282, 0.04683668754296377, 0.03349686878209468, 0.0022848099297334556, 0.03759043291211128, 0.06391704562702216, 0.0568266112532001, 0.029478237447619904, 0.03290484644821845, 0.060983064977335744, 0.0851095252437517, 0.0514388603187399, 0.06404134051990695, 0.0229437440430047, 0.29633360041771084, 0.09934188419720158, 0.31935591192450374, 0.14393164543434978, 0.14119539147941396, 0.15841683925827965, 0.15720712370239198, 0.11647804436506703, 0.2179823539336212, 0.17296726786298677, 0.13931369088822976, 0.16924550116527826, 0.13446918834233657, 0.18116773251676932, 0.15850689145736396, 0.14402033208170906, 0.25780880358070135, 0.16515169583726674, 0.13842732907505706, 0.20640790782636032, 0.20547587424516678, 0.27178427553735673, 0.20366493001347408, 0.4534505680203438, 37.741717994213104, 158.46158981323242, 121.39919936656952, 137.38869577646255, 98.35717499256134, 96.60343989729881, 106.79251715540886, 86.5971252322197, 110.43643042445183, 92.603280544281, 76.45610019564629, 60.073134899139404, 56.6390273720026, 8.346406035125256, 1.0938858962617815, 0.6825293507426977, 0.5727914173621684, 0.2556392387486994, 0.45782238186802715, 1.1732546123676002, 12.179387658834457, 8.500187583267689, 10.38799088448286, 121.5959832072258, 107.80403807759285, 117.50008419156075, 107.45758026838303, 110.60194194316864, 114.61347788572311, 109.35732632875443, 105.24409264326096, 111.36617973446846, 105.53719371557236, 105.43999493122101, 99.06916558742523, 101.7800161242485, 100.33273458480835, 101.91545605659485, 98.98206666111946, 105.44417470693588, 92.94821843504906, 82.13765412569046, 79.4477328658104, 84.38579589128494, 80.42036667466164, 76.48820847272873, 87.59462490677834, 97.16940432786942, 106.8031033873558, 98.38950365781784, 103.31541493535042, 99.54281017184258, 89.9534623324871, 91.44223004579544, 100.62341898679733, 97.68369913101196, 99.94642451405525, 100.39689794182777, 105.2262943983078, 94.02057409286499, 94.28642302751541, 92.47436106204987, 110.35681709647179, 47.370093539357185, 59.31263230741024, 110.63267469406128, 96.48302435874939, 106.6074138879776, 95.81242114305496, 103.087297976017, 94.50443252921104, 100.45430526137352, 95.80606028437614, 99.03774127364159, 102.13891446590424, 106.89998298883438, 102.38058909773827, 96.60742968320847, 92.0010356605053, 106.19661793112755, 104.20395165681839, 100.42586758732796, 87.25816816091537, 78.20726662874222, 80.1295454800129, 95.64402937889099, 96.2390698492527, 95.77547952532768, 93.78787457942963, 90.75254425406456, 87.25028738379478, 87.3273016512394, 87.95590192079544, 92.37591594457626, 85.96426159143448, 90.74047610163689, 94.97908785939217, 100.12317582964897, 100.30313417315483, 91.24928399920464, 17.505647353827953, 6.46531792357564, 2.818757384084165, 1.1285652103833854, 0.966908287955448, 0.20065320568392053, 0.43931292195338756, 0.18187063542427495, 0.5800620303489268, 2.994453781284392, 39.603040516376495, 55.469024553895, 57.48980171978474, 86.97657287120819, 139.1311302781105, 152.73731857538223, 139.10672038793564, 49.71210926771164, 47.14180178940296, 66.19500160217285, 89.14415135979652, 97.22086116671562, 110.36367192864418, 55.360650569200516, 2.360492474399507, 0.5771267472300678, 0.4441391379805282, 0.14274999790359288, 0.21311925316695124, 0.1748341997154057, 0.16140646243002266, 0.19427006773184985, 0.1254118696670048, 0.12147839050157927, 0.15156651934375986, 0.19359943340532482, 0.1072645110252779, 0.15841441985685378, 0.10934878824627958, 0.1169046679569874, 0.13249054842162877, 0.07981462811585516, 0.11762349735363387, 0.10572700368356891, 0.17780841590138152, 0.19125127815641463, 0.09626323299016804, 0.0958418712252751, 0.12345401730271988, 0.09668052778579295, 0.1483185397228226, 0.1628638178226538], [0.05534532530873548, 0.05012453162635211, 0.08273376952274702, 0.04191047453787178, 0.02877401166188065, 0.03733684847247787, 0.08355492624104954, 0.03138265703455545, 0.07192306758952327, 0.08744223639951088, 0.039785494227544405, 0.00977540685198619, 0.04604111636581365, 0.05799775739433244, 0.03121033776551485, 0.03397586944629438, 0.0777133482915815, 0.07300473298528232, 0.001705195841168461, 0.026302908518118784, 0.058948392907041125, 0.05766641072113998, 0.18470327951945364, 30.949192978441715, 128.59905302524567, 103.49022075533867, 118.02523881196976, 71.72248139977455, 73.55766892433167, 26.04089755564928, 22.327733002603054, 106.88887998461723, 76.6858358681202, 44.863299652934074, 38.04949767887592, 32.38049067556858, 8.300058972090483, 0.4206758423242718, 0.05821174825541675, 0.07258199082571082, 0.08922598091885448, 0.21009197342209518, 0.07979573303600773, 2.14050707872957, 1.4644044893793762, 2.9687890084460378, 100.89123621582985, 107.48909577727318, 110.72131633758545, 98.51762518286705, 95.72616577148438, 95.63762292265892, 97.16633409261703, 97.21013814210892, 99.33502212166786, 95.32339498400688, 96.29700154066086, 92.05098778009415, 89.43156033754349, 81.8607933819294, 86.4086401462555, 89.04972642660141, 90.28462216258049, 88.02655532956123, 84.48337465524673, 71.0600857436657, 71.89322143793106, 67.99571737647057, 70.03051578998566, 70.25352582335472, 81.33535757660866, 89.94430482387543, 94.19831335544586, 85.81748306751251, 95.29267743229866, 85.66958740353584, 82.52782478928566, 76.47479519248009, 87.82971829175949, 83.89351710677147, 90.43237343430519, 87.8177185356617, 92.14583069086075, 87.09850072860718, 91.51747360825539, 77.51688167452812, 102.54893526434898, 60.05227781832218, 45.485892444849014, 96.3876722753048, 81.40752330422401, 91.48443818092346, 82.77627825737, 90.76094940304756, 86.01207822561264, 91.70770660042763, 86.14767014980316, 89.06449243426323, 86.96827411651611, 93.12203630805016, 89.38769549131393, 88.95907089114189, 79.93980646133423, 78.25039431452751, 85.53951278328896, 81.27997174859047, 72.37679108977318, 70.44828057289124, 70.9495496749878, 82.22092285752296, 86.16161540150642, 89.7444735467434, 87.8063115477562, 77.31971025466919, 75.42209967970848, 74.18006792664528, 79.58950325846672, 75.80661624670029, 79.89569842815399, 77.96649634838104, 80.03834277391434, 89.66989874839783, 89.10709574818611, 91.36478260159492, 59.63186837732792, 8.611110281199217, 0.6234070763457566, 0.5514869105536491, 0.33542355755344033, 0.07061337732011452, 0.04587705720041413, 0.13701288466108963, 0.1712102777673863, 0.21241033886326477, 5.419522365555167, 24.051354713737965, 49.594212993979454, 61.196312829852104, 97.45833322405815, 114.06113192439079, 105.39806798100471, 90.8106279373169, 21.295632384717464, 18.401557579636574, 38.05319108068943, 63.42083506286144, 73.21228265762329, 76.6450260579586, 6.544399280101061, 0.4275661788415164, 0.03871319102472626, 0.038168744067661464, 0.00643833564936358, 0.06962384955841117, 0.015484279520023847, 0.020884263831248973, 0.008473818979837233, 0.040900296517065726, 0.018514756993681658, 0.10235662164632231, 0.02670840131031582, 0.011586465188884176, 0.14828337676590309, 0.06669692302239127, 0.03781295847147703, 0.012352879239188042, 0.03705916278704535, 0.0751471723197028, 0.017161439573101234, 0.013750616053584963, 0.033111245138570666, 0.02077410499623511, 0.038388412358472124, 0.06901783403009176, 0.10528351849643514, 0.0015423393028868304, 0.015538511961494805, 0.028651856009673793, 0.1524698021239601, 0.023478602452087216, 0.011938443567487411, 0.05447415154776536, 0.04665947752073407, 0.03912222571671009, 0.01669952500378713, 0.03161510881909635, 0.09436699372599833, 0.028086050042475108, 0.08658941966132261, 0.05861966230440885, 0.05069847895356361, 0.031185119587462395, 0.043690716120181605, 0.05206267254834529, 0.07218529804958962, 0.07173189034801908, 0.07391920735244639, 0.03315359208500013, 0.1668204297311604, 42.399021685123444, 150.68450152873993, 112.49687746167183, 140.2323415875435, 90.00630989670753, 101.2125925719738, 49.024855345487595, 57.655841410160065, 79.42040473222733, 59.840302392840385, 56.24378018081188, 39.32363010942936, 47.917533963918686, 8.589872270822525, 0.42594013328198344, 0.05494384196936153, 0.14607158373109996, 0.05756863276474178, 0.39882128534372896, 0.6241209630388767, 1.3519314746372402, 0.991778428433463, 4.917361261323094, 108.43122482299805, 112.05687627196312, 115.71462079882622, 105.46397164463997, 101.85111030936241, 100.23741289973259, 100.95534637570381, 102.13672578334808, 103.60346987843513, 99.9294014275074, 100.98370045423508, 95.0599779188633, 93.0477274954319, 83.5241237282753, 92.05556273460388, 93.27388375997543, 94.83281090855598, 88.86548191308975, 88.8955307006836, 73.54547917842865, 73.60335767269135, 70.99288254976273, 74.19481873512268, 74.46207359433174, 85.27507737278938, 94.56316977739334, 97.92472779750824, 89.4941733777523, 97.24844008684158, 91.24328032135963, 84.13734242320061, 78.45933750271797, 92.36669763922691, 87.19384521245956, 93.01415249705315, 90.8205834031105, 95.69158762693405, 92.44740530848503, 95.02340108156204, 81.27297252416611, 104.40844908356667, 65.47452226281166, 47.58187897503376, 98.54376018047333, 86.54537200927734, 94.16090816259384, 86.83420971035957, 95.66730692982674, 92.68660247325897, 93.59615966677666, 91.50884807109833, 92.16650918126106, 92.51302018761635, 97.31710240244865, 94.06055554747581, 92.58134812116623, 82.5257197022438, 82.11636006832123, 90.02271741628647, 86.17584943771362, 75.78741207718849, 74.27651435136795, 75.52814438939095, 86.50178074836731, 90.04056885838509, 93.8049204647541, 91.92080676555634, 80.04479482769966, 79.49478194117546, 79.43868935108185, 82.75804683566093, 78.39464217424393, 82.42224365472794, 83.44242051243782, 85.34536600112915, 92.54192143678665, 95.01314923167229, 92.38327994942665, 65.93105256557465, 12.910189144313335, 0.48988197406288236, 0.36426107108127326, 0.58366987737827, 0.2667210769141093, 0.045084721787134185, 0.08126354528940283, 0.05593422320089303, 0.42887820687610656, 6.331902332603931, 31.021438501775265, 41.20561972260475, 56.60581335425377, 112.50316992402077, 119.37008544802666, 95.15766307711601, 53.3123704791069, 22.152570001780987, 38.25063608586788, 47.14836023747921, 80.60544714331627, 80.3582476079464, 97.44433477520943, 15.359797049313784, 0.6623632390983403, 0.042109919304493815, 0.14946352515835315, 0.017835426551755518, 0.10245277429930866, 0.018254073911521118, 0.12180125442682765, 0.03683510469272733, 0.04172852961346507, 0.04538714696536772, 0.04977791155397426, 0.07267860361025669, 0.03717449995747302, 0.06479242365458049, 0.03690511890454218, 0.07928450460894965, 0.06880511224153452, 0.05112016726343427, 0.058090878374059685, 0.039408505472238176, 0.01080211342923576, 0.04447429419087712, 0.05496023972227704, 0.04339552317105699, 0.09669640232459642, 0.06277198597672395, 0.028999145870329812, 0.09173849219223484, 0.13259857543744147, 0.25637823971919715, 0.09096015739487484, 0.08376260142540559, 0.13055792165687308, 0.18338106921873987, 0.13185138115659356, 0.14472246315563098, 0.176080473465845, 0.15358133154222742, 0.08611751763965003, 0.20465575653361157, 0.2224736980861053, 0.12807439867174253, 0.12148941139457747, 0.16637475520838052, 0.19941712904255837, 0.13661571691045538, 0.14026822638697922, 0.20356959372293204, 0.11218618950806558, 0.21327663300326094, 53.82271349430084, 172.86467134952545, 128.72268319129944, 153.38130801916122, 98.58811140060425, 102.06217378377914, 44.061280488967896, 32.50409424304962, 146.27681404352188, 113.34959730505943, 66.7243891954422, 65.04994824528694, 62.94192776083946, 16.02830182760954, 0.8702939003705978, 0.370945981121622, 0.5930733634158969, 0.18119621614459902, 0.4173651215387508, 0.4718658939236775, 6.937322420999408, 6.376377996057272, 3.5232863668352365, 114.11093965172768, 116.99537247419357, 122.3609733581543, 109.27924051880836, 106.3475838303566, 106.5909531712532, 105.76495349407196, 107.17875882983208, 109.21138375997543, 105.35812452435493, 106.53758123517036, 100.02528548240662, 99.24045279622078, 88.17424580454826, 95.02291470766068, 99.21292707324028, 100.96530944108963, 97.0981353521347, 94.2903596162796, 79.44976195693016, 79.45533245801926, 76.24657943844795, 77.51321107149124, 79.74897310137749, 87.88295343518257, 99.8299303650856, 102.53992214798927, 93.89011189341545, 100.85324585437775, 95.08178114891052, 89.51789170503616, 82.48646020889282, 97.81207904219627, 91.44362837076187, 97.03216329216957, 95.555539727211, 101.70918792486191, 97.25707322359085, 99.4509918987751, 87.60552272200584, 107.03672245144844, 69.42191004753113, 53.050469532608986, 100.3139939904213, 90.84859549999237, 101.6005289554596, 92.54511326551437, 99.0755644440651, 96.20601162314415, 98.17473158240318, 94.68286335468292, 94.84160363674164, 96.2527947127819, 100.58363512158394, 98.17394122481346, 98.19297060370445, 88.27677950263023, 87.10639670491219, 94.70045641064644, 92.0469979941845, 80.73062002658844, 77.97540307044983, 79.66567397117615, 90.1314827799797, 96.16486743092537, 99.34187695384026, 97.83648893237114, 84.95464816689491, 83.56127053499222, 84.40253019332886, 89.45201843976974, 84.64214533567429, 89.0904450416565, 86.99937164783478, 88.3795715868473, 99.4491071999073, 99.43136215209961, 95.35061672329903, 67.31588065624237, 11.669585164636374, 4.928338397294283, 2.570483931340277, 0.7777173304930329, 0.216085558058694, 0.14588557183742523, 0.25455665308982134, 0.18686984607484192, 0.6454762327484787, 10.895613245666027, 47.2603440284729, 65.74480175971985, 71.87517240643501, 104.69569087028503, 128.2616463303566, 122.42608666419983, 124.54495176672935, 29.42380852997303, 31.985581666231155, 55.00343553721905, 88.73015597462654, 91.99079900979996, 111.32471635937691, 20.827309414744377, 1.2347683240659535, 0.27075212623458356, 0.27166006970219314, 0.18016041547525674, 0.17935292911715806, 0.18079760862747207, 0.11582941471715458, 0.11819955238024704, 0.13532118871808052, 0.1136852239142172, 0.22435158403823152, 0.13847307505784556, 0.10289176207152195, 0.19732491084141657, 0.12118258528062142, 0.2124042235664092, 0.14716096746269614, 0.24744624010054395, 0.18828829808626324, 0.07093685722793452, 0.13497858366463333, 0.19168812112184241, 0.2504933055024594, 0.1676947539090179, 0.16582241922151297, 0.17512629419798031, 0.15158575581153855], [0.04289038035494741, 0.031172688613878563, 0.05118320528708864, 0.05753515077230986, 0.016557544731767848, 0.05468712195579428, 0.038472301021101885, 0.026177396503044292, 0.03277894480561372, 0.005371113838918973, 0.0022840459814688074, 0.031870129314484075, 0.048615478226565756, 0.027041742505389266, 0.03160672997182701, 0.03234443960536737, 0.028465380273701157, 0.015445425306097604, 0.04937058380164672, 0.10187703097471967, 0.05019960357458331, 0.10176494441111572, 10.872082058340311, 119.091856777668, 101.79976746439934, 110.94776138663292, 65.39807796478271, 97.96150222420692, 37.510591596364975, 40.80887161195278, 50.26142679154873, 43.98438781499863, 58.85567642748356, 38.907164856791496, 24.928176663815975, 0.916400448186323, 0.15938373893732205, 0.015434291235578712, 0.07410538994008675, 0.05955106134933885, 0.042795207336894237, 0.12830458319513127, 1.612982691731304, 1.064670926425606, 1.0549471294507384, 77.37801432609558, 114.78583663702011, 100.95989093184471, 102.14567810297012, 91.5945714712143, 89.61239263415337, 82.91301771998405, 87.60156333446503, 84.52898740768433, 88.18595677614212, 91.19871631264687, 85.34970536828041, 80.62896028161049, 80.43362036347389, 77.74808406829834, 77.09999084472656, 82.85519242286682, 86.68032556772232, 86.28812581300735, 82.06289693713188, 70.11516004800797, 69.36688140034676, 71.60354018211365, 70.44495195150375, 70.30046090483665, 82.01682820916176, 90.11562243103981, 90.63230350613594, 89.04053092002869, 94.3199448287487, 89.10916283726692, 79.49125573039055, 77.92760163545609, 83.53842616081238, 83.7392757833004, 89.70942422747612, 89.47792544960976, 90.31115233898163, 85.37451043725014, 87.1905317902565, 83.98060843348503, 93.07451605796814, 81.41503170132637, 43.37832033634186, 96.62501513957977, 86.64210721850395, 85.48411175608635, 80.96452787518501, 87.6938983798027, 89.29243460297585, 90.87119668722153, 88.52153196930885, 89.56228852272034, 85.77415019273758, 88.83917212486267, 89.70508486032486, 91.73662304878235, 83.66308227181435, 76.72128036618233, 75.14202430844307, 75.09310573339462, 69.00783106684685, 69.25744727253914, 69.9346773326397, 82.0983262360096, 85.87694987654686, 83.94264087080956, 80.38744524121284, 78.24658691883087, 72.22796067595482, 73.6189216375351, 72.69062384963036, 77.39085003733635, 76.18310004472733, 79.86847668886185, 81.37558221817017, 84.05416488647461, 86.66108340024948, 89.87549811601639, 78.53968039155006, 49.13726091384888, 3.7502781115472317, 0.9656725230161101, 0.4644032724900171, 0.18823116755811498, 0.042828819205169566, 0.10227762002614327, 0.033176424258272164, 0.13030651170993224, 0.1613415393512696, 3.2915831124410033, 18.12709830701351, 47.09193326532841, 36.04228958487511, 64.2445282638073, 118.85402753949165, 143.50689947605133, 85.42990386486053, 26.50493625551462, 23.759764060378075, 50.957918018102646, 80.39702832698822, 85.7622492313385, 52.56072521209717, 0.40976882446557283, 0.17201706650666893, 0.03322370277601294, 0.029248275568534154, 0.03464204346528277, 0.03969424345996231, 0.02224860028945841, 0.02471321520715719, 0.06280561268795282, 0.029602430295199156, 0.08767981271375902, 0.02102834067045478, 0.025487635175522882, 0.03890904379659332, 0.00967847587162396, 0.03156871345709078, 0.011151087037433172, 0.04214641441649292, 0.056926088727777824, 0.03589230254874565, 0.018825308688974474, 0.0327404830022715, 0.049322485210723244, 0.07210453753941692, 0.03907901045749895, 0.029683897701033857, 0.05287665640935302, 0.046717995865037665, 0.06192319910041988, 0.017871986601676326, 0.06725317012751475, 0.06553362880367786, 0.10652527256752364, 0.07849509696825407, 0.03970489327912219, 0.09635740410885774, 0.02705088019865798, 0.07145820854930207, 0.025097465877479408, 0.02174201770685613, 0.023921647916722577, 0.012963957142346771, 0.024840246769599617, 0.011075965921918396, 0.06009060642099939, 0.06059234277927317, 0.024575971692684107, 0.08199508025427349, 0.22890222579007968, 16.283323243260384, 144.61764067411423, 109.06992495059967, 131.61867499351501, 84.03633624315262, 104.1062892973423, 52.75022104382515, 58.42974208295345, 18.512076549232006, 47.11172640323639, 57.717918679118156, 34.827304780483246, 36.118676885962486, 0.4844125238014385, 0.42075750825461, 0.08644351342809387, 0.10130766269867308, 0.0643967921496369, 0.04069097376486752, 0.3170220652827993, 1.4472866454161704, 0.22111016500275582, 1.7829285725019872, 85.50708532333374, 119.09859761595726, 106.18653327226639, 105.94392389059067, 94.03860032558441, 94.06961426138878, 87.00858995318413, 93.5311071574688, 88.30767944455147, 92.90841937065125, 93.92991095781326, 91.96948975324631, 84.92988109588623, 85.96990808844566, 82.2395570576191, 81.67415499687195, 86.45227700471878, 90.93038231134415, 89.20206785202026, 87.16964051127434, 74.45942893624306, 73.51245895028114, 73.96343395113945, 76.02556809782982, 72.05332964658737, 84.78884026408195, 93.78644585609436, 94.55358669161797, 91.6024598479271, 98.56646776199341, 90.44572591781616, 85.24855479598045, 81.51960209012032, 85.98588243126869, 88.02456423640251, 92.00773850083351, 95.52732244133949, 94.2745752632618, 90.53350120782852, 89.95257318019867, 87.24698916077614, 97.15537548065186, 84.75439891219139, 46.68328799307346, 98.04878354072571, 92.480987906456, 90.65798252820969, 84.88863050937653, 90.77630817890167, 91.92987307906151, 95.01244246959686, 91.9799391925335, 90.88960289955139, 89.01686578989029, 90.55162623524666, 94.27574560046196, 94.84128445386887, 88.0310770869255, 80.09917750954628, 79.71284464001656, 78.24632853269577, 73.23279395699501, 72.49313324689865, 72.79207840561867, 86.81394159793854, 91.24100044369698, 87.84583702683449, 84.46791708469391, 81.92917451262474, 79.34155896306038, 75.37132680416107, 76.92527621984482, 82.18066021800041, 80.81961125135422, 82.28857442736626, 85.88454946875572, 87.6104548573494, 91.3141617178917, 92.32068970799446, 81.8119204044342, 57.107732221484184, 7.486699316650629, 0.3394229320110753, 0.4836477851495147, 0.23008495685644448, 0.6978998822160065, 0.2304952309350483, 0.03913711690984201, 0.101266161800595, 0.23261796624865383, 2.7743760030716658, 23.875589445233345, 44.65650334954262, 40.461828634142876, 77.00434997677803, 111.35449916124344, 126.58516108989716, 40.30752271413803, 25.577388927340508, 35.645146295428276, 58.297976553440094, 87.00001761317253, 96.98495462536812, 75.53740829229355, 0.6832782668061554, 0.06270484387641773, 0.07327358340262435, 0.01986650106118759, 0.04531531820248347, 0.056842545163817704, 0.024040638309088536, 0.057355350654688664, 0.022870056200190447, 0.029359978070715442, 0.048509922562516294, 0.04542735652648844, 0.0342535551317269, 0.0032682140454198816, 0.03804820815275889, 0.0078077507168927696, 0.02046671485004481, 0.020601355281542055, 0.05163709167391062, 0.1089180531562306, 0.03180420804710593, 0.053447961690835655, 0.0645054128835909, 0.061392775023705326, 0.023987789973034523, 0.013594875435956055, 0.061153321075835265, 0.1256293783080764, 0.1327803570893593, 0.12624962080735713, 0.11748139091650955, 0.17102269252063707, 0.21090615395223722, 0.2515142335323617, 0.18948508542962372, 0.2092797076329589, 0.05367463585571386, 0.11847594301798381, 0.12736497970763594, 0.12383211927954108, 0.07727143645752221, 0.07527656576712616, 0.156609294062946, 0.15786903037223965, 0.23518017173046246, 0.24283217440824956, 0.21297386643709615, 0.23500313982367516, 0.3992613492300734, 22.050161696970463, 169.62730586528778, 123.61990660429001, 143.13666254281998, 84.69894468784332, 124.18059691786766, 49.4290966540575, 58.49461980164051, 71.18901282548904, 73.47901314496994, 80.05576103925705, 66.79570376873016, 44.06990222632885, 2.707146448083222, 1.4911062503233552, 0.16561063996050507, 0.4587756557157263, 0.2610812889179215, 0.41186889458913356, 0.5424400116316974, 5.273076798766851, 9.221779312938452, 2.5259085232391953, 89.20525208115578, 123.87621805071831, 111.5433718264103, 109.03878182172775, 97.5077685713768, 99.92399051785469, 90.51656931638718, 99.18413981795311, 93.09439659118652, 97.55591198801994, 103.25350865721703, 96.69258311390877, 90.68473309278488, 90.19754603505135, 86.04053869843483, 86.51118144392967, 92.3358964920044, 95.10135009884834, 93.54275733232498, 91.69196784496307, 78.57077032327652, 76.85178816318512, 77.79242768883705, 78.04163351655006, 75.65785422921181, 90.98864078521729, 99.1589243710041, 98.81731510162354, 94.3106809258461, 103.0736643075943, 97.0591950416565, 87.938894033432, 84.57341462373734, 90.19324466586113, 91.91102609038353, 98.17642629146576, 98.64522993564606, 96.5662930905819, 93.57683390378952, 93.85097399353981, 90.01132562756538, 102.07770735025406, 91.21295034885406, 51.74694947898388, 100.91500774025917, 97.8000944852829, 93.64380910992622, 88.56981977820396, 95.12248456478119, 95.21343648433685, 98.18130522966385, 95.48815414309502, 96.3930755853653, 95.13239443302155, 96.57685652375221, 97.26314529776573, 97.35683307051659, 92.5686340034008, 84.63094353675842, 84.24361512064934, 81.36767864227295, 76.0783776640892, 76.26984938979149, 78.70415836572647, 92.78896138072014, 93.68234664201736, 90.42309433221817, 89.63427186012268, 88.52346986532211, 83.39929282665253, 81.16682901978493, 81.12408131361008, 87.04789504408836, 86.40597268939018, 89.11225587129593, 90.34021317958832, 93.01039829850197, 96.03374406695366, 96.61639720201492, 83.88183653354645, 58.965786918997765, 6.308303223922849, 5.47448119148612, 2.2572175785899162, 0.6021666910964996, 0.3565376589540392, 0.39996760664507747, 0.20665056043071672, 0.21072138886665925, 0.5621946172323078, 10.10639464482665, 32.7289167791605, 70.84482729434967, 44.39033903181553, 79.16036188602448, 126.53591573238373, 160.0349485874176, 110.99051669239998, 39.34832878410816, 40.42422965168953, 67.15420693159103, 103.08675080537796, 105.69052308797836, 88.8872167468071, 2.4134302837774158, 0.3641918732319027, 0.20984917238820344, 0.13221859582699835, 0.17011094925692305, 0.11229240568354726, 0.055926367567735724, 0.11020848469343036, 0.15252985671395436, 0.06296892228419892, 0.15901026054052636, 0.1422645294223912, 0.14215653209248558, 0.16015904577216133, 0.18052210856694728, 0.10104021494043991, 0.076508107886184, 0.1254297257401049, 0.20207639259751886, 0.19805876130703837, 0.0974262303498108, 0.14153142110444605, 0.22950582933844998, 0.14142000989522785, 0.13284145068610087, 0.11988605328951962, 0.17856182937975973], [0.037015420602983795, 0.09640758071327582, 0.017442611497244798, 0.03343521857459564, 0.03643644151452463, 0.03269185748649761, 0.03278038086136803, 0.08406962791923434, 0.07861525809857994, 0.049280865569016896, 0.036757572524948046, 0.058800000479095615, 0.11335499788401648, 0.06002868904033676, 0.041226767280022614, 0.03923570009646937, 0.028527240137918852, 0.04102069142390974, 0.059576138519332744, 0.010030098019342404, 0.04110828711418435, 0.3383200411917642, 77.48601213097572, 100.59001117944717, 113.97910952568054, 80.22092297673225, 81.26517534255981, 190.86494386196136, 119.25443485379219, 41.269729882478714, 110.7092709839344, 48.60712096095085, 39.23597641289234, 33.18802334368229, 0.3064881992759183, 0.3247157618170604, 0.17035985074471682, 0.2505007269792259, 0.11337953328620642, 0.02439585059619276, 0.24613456829683855, 1.396917498204857, 0.6053493765648454, 2.136781378649175, 43.65944065153599, 125.31677395105362, 96.80963203310966, 105.74957191944122, 86.73790767788887, 95.08753404021263, 78.77353504300117, 84.87750470638275, 71.92722201347351, 78.38094010949135, 75.1701731979847, 78.22130307555199, 73.90880808234215, 77.48955354094505, 69.88527998328209, 71.83318465948105, 75.07900089025497, 80.42248696088791, 80.19022062420845, 81.67271867394447, 75.90196073055267, 69.34045001864433, 68.4217657148838, 69.23654079437256, 69.87119793891907, 69.5498263835907, 76.24128252267838, 87.61844202876091, 89.30239766836166, 92.40542516112328, 88.4415690600872, 83.98905918002129, 80.03909513354301, 76.75997748970985, 75.39730980992317, 80.13557195663452, 81.2094247341156, 86.25066742300987, 88.75708892941475, 87.4816645681858, 86.33477210998535, 83.19528177380562, 86.43023818731308, 89.68371480703354, 48.028700798749924, 82.21519276499748, 86.17913246154785, 79.95652556419373, 79.00634095072746, 78.26964408159256, 83.8498954474926, 87.78816372156143, 87.90104046463966, 85.98585963249207, 86.9872958958149, 84.75359335541725, 89.49730440974236, 89.7769770026207, 85.89438334107399, 74.13801178336143, 71.93480640649796, 73.03142756223679, 70.10100960731506, 68.24032545089722, 69.91190135478973, 79.96053814888, 85.48015236854553, 83.16910117864609, 78.12231838703156, 73.89116942882538, 74.13510873913765, 77.06235006451607, 73.5827323794365, 72.60497644543648, 77.22131833434105, 75.792997777462, 79.20553386211395, 83.7062631547451, 87.03106194734573, 84.50571745634079, 80.332872569561, 80.01441925764084, 39.043782725930214, 1.8666235939599574, 1.0718200053088367, 0.4472674091812223, 0.24154011014616117, 0.11574657619348727, 0.19600935018388554, 0.04156886767304968, 0.11399098875699565, 0.11892319089383818, 0.3189739730441943, 15.567737091332674, 36.20054729282856, 63.43584805727005, 117.93851226568222, 110.93336775898933, 93.35245594382286, 37.35532432794571, 36.19254492223263, 64.48433339595795, 74.31924685835838, 71.62155121564865, 84.47788774967194, 5.519941002130508, 0.6015387154184282, 0.11546543581061997, 0.08875396015355363, 0.06708328510285355, 0.07215245059342124, 0.056390310055576265, 0.03441334323724732, 0.02154963818611577, 0.093296015256783, 0.01866231636086013, 0.062120840448187664, 0.08100517399725504, 0.01350247155642137, 0.032083396581583656, 0.01509890913439449, 0.0812720280373469, 0.012753654755215393, 0.023036007842165418, 0.04079714170075022, 0.03073682528338395, 0.013970806630823063, 0.026602634134178516, 0.07291877001989633, 0.054903936688788235, 0.043208665229030885, 0.07716273408732377, 0.02802518651151331, 0.06044374626071658, 0.050183009152533486, 0.07581342797493562, 0.026785107838804834, 0.04972910421201959, 0.02349066606257111, 0.007018503101789975, 0.08274166597402655, 0.031811533044674434, 0.039671804624958895, 0.008966361983766546, 0.020316951304266695, 0.021487603917194065, 0.04708506210590713, 0.058419289853191, 0.0556750874966383, 0.030468379336525686, 0.08491513450280763, 0.015542663350061048, 0.03896611866366584, 0.6309436750598252, 104.13942351937294, 113.4038507938385, 127.7674600481987, 90.58624997735023, 84.03041616082191, 181.5832883119583, 105.83235427737236, 25.672615617513657, 84.03551548719406, 57.25523270666599, 38.49845118820667, 45.614078566432, 0.38571810408029705, 0.36572520970366895, 0.21985219500493258, 0.21415661234641448, 0.03174530378601048, 0.09722443297505379, 0.22918027883861214, 1.5878482279367745, 0.3118077357066795, 1.4719349727965891, 53.09951730072498, 132.30645328760147, 103.25242951512337, 109.54221680760384, 91.79550468921661, 98.5716050863266, 82.46464177966118, 89.16652455925941, 76.0967230796814, 83.34871754050255, 80.42245656251907, 81.87716290354729, 77.63719081878662, 81.81151762604713, 74.08526301383972, 74.71589997410774, 78.02473202347755, 84.29284527897835, 84.2707608640194, 87.15916067361832, 78.95889669656754, 72.69817784428596, 72.82264396548271, 71.89616248011589, 71.57843872904778, 72.82021209597588, 79.9140514433384, 92.58614346385002, 92.94003367424011, 94.5566189289093, 92.25780308246613, 87.84060090780258, 83.91633868217468, 78.65996673703194, 78.58218491077423, 83.69560092687607, 86.4786171913147, 91.14766225218773, 92.41973519325256, 90.38750544190407, 89.49439376592636, 86.74692079424858, 89.58756476640701, 92.07312539219856, 50.834614634513855, 84.00029137730598, 89.70085948705673, 82.70341336727142, 84.3255615234375, 81.28002494573593, 86.5205517411232, 91.03135049343109, 91.49922698736191, 91.0412147641182, 89.79505643248558, 87.90515944361687, 93.51453244686127, 91.97684615850449, 91.65491223335266, 79.4884742796421, 75.52293866872787, 76.24616146087646, 72.55627065896988, 71.54069915413857, 72.81024143099785, 83.34089756011963, 89.46547731757164, 87.84902125597, 82.66113683581352, 78.20565551519394, 76.98142200708389, 81.58976152539253, 76.77851289510727, 75.1378521323204, 80.32099440693855, 80.20067006349564, 82.79207020998001, 88.03282499313354, 91.30201756954193, 85.87339326739311, 82.70898386836052, 83.5989037156105, 47.42002286016941, 3.6425700411200523, 0.3685812611365691, 0.2356388041516766, 1.924883492756635, 0.22976072737947106, 0.2658579294802621, 0.05086634533654433, 0.07069134735502303, 0.1041739409265574, 0.20482254680246115, 20.514303110539913, 33.08069050312042, 56.16857461631298, 122.85926342010498, 118.05144980549812, 80.99897682666779, 23.982443511486053, 41.06435090303421, 71.58422201871872, 83.17032471299171, 78.80581051111221, 102.54112288355827, 13.173157833516598, 1.371066179126501, 0.16584236815106124, 0.12076999570126645, 0.08033517791773193, 0.09675818611867726, 0.023798074762453325, 0.004937119329042616, 0.09412575120222755, 0.0589015003060922, 0.007518526954299887, 0.04143950391153339, 0.08773983019636944, 0.03290777422080282, 0.0057192005806427915, 0.0449043650587555, 0.0903853120689746, 0.03172974465996958, 0.08683700754772872, 0.03787049347010907, 0.03685676427267026, 0.022632279506069608, 0.01676312334893737, 0.003546973293850897, 0.021156669135962147, 0.006206059661053587, 0.051540438071242534, 0.14254014822654426, 0.1946112627047114, 0.14915522217052057, 0.18990429496625438, 0.14097593841142952, 0.1164853322552517, 0.3339604282518849, 0.19295407662866637, 0.19210452534025535, 0.18527455511502922, 0.22049544408218935, 0.1498976073344238, 0.35150675859767944, 0.1213956336141564, 0.16231590503593907, 0.11328302440233529, 0.16908473713556305, 0.15910521091427654, 0.18318726477446035, 0.10546059493208304, 0.14968664443586022, 1.0571749974042177, 122.03192621469498, 129.38907623291016, 145.21898120641708, 106.63616314530373, 103.59771698713303, 191.90958380699158, 138.1103378534317, 62.01184406876564, 158.95135313272476, 74.66019496321678, 64.52748388051987, 58.629596158862114, 0.775370184564963, 0.7687507022637874, 0.6097013305407017, 0.761500810040161, 0.2914911165134981, 0.531109613366425, 0.49932188470847905, 4.761006301268935, 7.34418511390686, 5.813292386010289, 53.788465932011604, 135.40556699037552, 105.46576514840126, 113.36472049355507, 97.74109125137329, 102.8728374838829, 86.81860774755478, 93.5339418053627, 79.56189393997192, 88.26304703950882, 84.03018057346344, 87.01343089342117, 82.25623816251755, 87.0989491045475, 79.9141426384449, 79.35948640108109, 84.76181611418724, 91.32381319999695, 89.84934791922569, 91.61817580461502, 83.64510163664818, 77.34298780560493, 77.1578161418438, 77.36796766519547, 74.97126907110214, 76.90915748476982, 84.72461611032486, 95.92500150203705, 96.60865321755409, 99.66851502656937, 95.15561878681183, 90.97563788294792, 88.05775165557861, 83.59199568629265, 84.20862659811974, 88.6785851418972, 89.8382905125618, 95.28792008757591, 98.00340637564659, 94.98433157801628, 96.42006933689117, 91.29738181829453, 94.3377810716629, 96.16248115897179, 56.25658929347992, 87.96343311667442, 96.46109953522682, 88.4399351477623, 90.66658526659012, 86.16688951849937, 92.51884907484055, 95.92000856995583, 95.68071261048317, 91.9134047627449, 95.2573013305664, 92.69386768341064, 96.79863542318344, 97.99358010292053, 94.55947637557983, 82.78872638940811, 79.6026049554348, 81.23829558491707, 76.03950574994087, 76.27095133066177, 78.2822898030281, 88.370900452137, 94.77905139327049, 90.6380107998848, 86.34954571723938, 82.88410887122154, 81.68350249528885, 87.0407210290432, 82.77797296643257, 80.11475667357445, 84.60404098033905, 83.87548327445984, 88.28202322125435, 93.66881936788559, 96.65369600057602, 89.41486403346062, 83.9858977496624, 85.34702271223068, 46.42722353339195, 2.9174915235489607, 4.159377459436655, 2.721350323408842, 2.522235307842493, 0.21378086297772825, 0.8010214800015092, 0.12344196482445113, 0.29557987523730844, 0.3562782041262835, 1.3813342968933284, 28.45038626343012, 61.194108948111534, 77.7111804485321, 123.4051801264286, 121.54248207807541, 122.11223110556602, 53.23236957192421, 53.92307750880718, 83.2390858232975, 95.34009128808975, 90.3956750035286, 120.72189331054688, 19.88216333091259, 2.0659441547468305, 0.21712233836296946, 0.2883217600174248, 0.2131961693521589, 0.18067779630655423, 0.09810279443627223, 0.18730315641732886, 0.1518816500902176, 0.2521386765874922, 0.17300305422395468, 0.151628102757968, 0.2719414624152705, 0.11734298779629171, 0.14980555133661255, 0.15536674589384347, 0.23363671236438677, 0.13265389512525871, 0.20115163206355646, 0.11967220343649387, 0.11825096094980836, 0.10582837363472208, 0.13835354475304484, 0.14078905078349635, 0.15590017195791006, 0.08378654310945421, 0.13708537764614448], [0.03204450804332737, 0.034709378523984924, 0.08430273650446907, 0.023406875734508503, 0.04294048274459783, 0.04154918220592663, 0.017194754582305904, 0.05108321944135241, 0.042473619905649684, 0.012724430835078238, 0.020767594505741727, 0.046580550115322694, 0.048196246425504796, 0.10153167255339213, 0.032257953425869346, 0.16670210170559585, 0.09151066769845784, 0.13775142550002784, 0.16220326186157763, 0.17528855736600235, 0.6242725986521691, 16.809171326458454, 112.73994281888008, 108.6893829703331, 95.03603920340538, 94.31888848543167, 64.81138944625854, 47.372141629457474, 45.42321480810642, 98.84055465459824, 31.498217917978764, 35.087982192635536, 37.483734637498856, 0.4296659224200994, 0.10992931842338294, 0.10795944326673634, 0.03403284412343055, 0.048359017964685336, 0.14646038005594164, 0.15828767587663606, 0.17104807397117838, 0.44388277048710734, 2.302068709395826, 15.309266410768032, 126.42577484250069, 99.6700045466423, 106.52366638183594, 89.53865379095078, 94.53247502446175, 88.80774021148682, 91.38128891587257, 78.5980224609375, 79.90292564034462, 69.64316457509995, 70.26896059513092, 68.20618808269501, 71.59048408269882, 66.8672463297844, 70.7422935962677, 66.66008904576302, 72.61962085962296, 72.01730757951736, 79.20446991920471, 76.25935435295105, 72.64836251735687, 64.53648939728737, 72.23322719335556, 68.4130185842514, 72.1717768907547, 67.45214134454727, 71.81825906038284, 86.58422872424126, 91.09359875321388, 89.4464023411274, 89.1352066397667, 83.94881173968315, 74.50793713331223, 73.31055298447609, 74.04759183526039, 80.8891399204731, 84.36300471425056, 87.42726668715477, 85.97597256302834, 86.70667335391045, 86.71997264027596, 85.06492584943771, 83.35937216877937, 91.40721872448921, 48.882731571793556, 77.99043506383896, 91.95343181490898, 77.78906866908073, 78.80813598632812, 74.70526054501534, 80.95940575003624, 78.4585927426815, 87.38859236240387, 85.2542544901371, 88.63960683345795, 80.71863546967506, 88.6929939687252, 85.80720841884613, 90.51794484257698, 76.56968370079994, 69.72619771957397, 67.68567681312561, 68.16033214330673, 67.21808150410652, 69.6465539932251, 76.1440609395504, 83.3532240986824, 80.46151846647263, 79.49289724230766, 71.93453282117844, 75.77592149376869, 74.4195918738842, 75.3339672088623, 73.75404238700867, 73.32631453871727, 73.3127948641777, 81.7521496117115, 81.85869589447975, 89.12819981575012, 77.45442062616348, 81.10874533653259, 86.67958080768585, 85.81742227077484, 29.30136200040579, 0.4435144574381411, 0.3119530185358599, 3.207402192056179, 0.40015053120441735, 0.12049162352923304, 0.10084885216201656, 0.07041985489195213, 0.025902180314005818, 0.07052800065139309, 0.059602614637697116, 18.22650097310543, 33.636004105210304, 56.59727141261101, 74.08929079771042, 35.62781162559986, 56.24616265296936, 21.93933494389057, 25.081473737955093, 62.26179465651512, 77.31351658701897, 73.2519981265068, 50.66081956028938, 0.9753731056116521, 0.00925204431041493, 0.050800780300050974, 0.06922094500623643, 0.0322602206870215, 0.038784670978202485, 0.02839252549165394, 0.03919847025827039, 0.08580194902606308, 0.019616128265624866, 0.01510740301455371, 0.04747951359604485, 0.04107260836462956, 0.019995157927041873, 0.07170814162236638, 0.008384650864172727, 0.07406232311041094, 0.05913376284297556, 0.05631566484225914, 0.05182101813261397, 0.04600951571774203, 0.011672109958453802, 0.03292453933681827, 0.023682615137659013, 0.042941351057379507, 0.05680882197339088, 0.022586398081330117, 0.044988472654949874, 0.03402068032301031, 0.02455409317917656, 0.067977758590132, 0.09483706264290959, 0.057243234405177645, 0.06820331211201847, 0.08861075533786789, 0.09346371836727485, 0.026813751028385013, 0.14605656266212463, 0.021743882352893706, 0.08727716791327111, 0.027786858772742562, 0.20286241604480892, 0.10531395397265442, 0.21389200701378286, 0.19675504532642663, 0.3257699083769694, 0.9928592923097312, 28.426759131252766, 130.39392471313477, 120.92133700847626, 103.93741115927696, 104.29021462798119, 79.81163933873177, 82.08843156695366, 53.54497879743576, 55.21953374147415, 44.077152237296104, 27.217920497059822, 48.04316282272339, 0.32599477912299335, 0.2966868330258876, 0.19500627822708338, 0.4913065710570663, 0.04335214092861861, 0.1389366650255397, 0.16118847881443799, 0.31800164084415883, 0.11155736778164282, 2.054094015620649, 20.625395849347115, 136.10447108745575, 99.40876856446266, 111.9057659804821, 94.46138843894005, 99.58251804113388, 90.94216927886009, 97.73697227239609, 81.78503304719925, 83.0018949508667, 72.6423892378807, 74.02510464191437, 71.34685635566711, 74.11325991153717, 72.51080229878426, 73.9919476211071, 72.20094412565231, 76.60602495074272, 75.20836874842644, 82.65033781528473, 79.91886958479881, 77.98482656478882, 67.74879902601242, 74.97849628329277, 71.4962263405323, 76.61917984485626, 71.89610928297043, 75.65211653709412, 90.5764465034008, 93.39803069829941, 91.18518143892288, 93.4468124806881, 85.84533557295799, 78.37586358189583, 74.34305638074875, 79.35969918966293, 84.67796981334686, 88.54796335101128, 91.92912831902504, 88.68727147579193, 89.47099462151527, 88.49538937211037, 89.9535459280014, 87.75800853967667, 96.4071424305439, 52.08632826805115, 80.16005024313927, 96.78320065140724, 83.03226292133331, 83.59500512480736, 77.89436101913452, 83.81716400384903, 81.28675818443298, 90.434440523386, 88.21244135499, 91.86205431818962, 84.74987715482712, 93.00281390547752, 90.34614086151123, 93.93979802727699, 81.07523113489151, 74.224593937397, 70.91629385948181, 72.34897658228874, 71.28032952547073, 72.14919090270996, 79.76280435919762, 86.10773429274559, 83.4712153673172, 83.73900979757309, 76.81948989629745, 80.0272473692894, 79.54902783036232, 78.81542399525642, 76.95026367902756, 76.90215826034546, 77.37628161907196, 86.34727343916893, 86.42418891191483, 94.25381317734718, 82.68240809440613, 83.47000703215599, 89.54189881682396, 88.83075937628746, 39.51475225389004, 2.274810397066176, 0.3905639721779153, 0.5611208186019212, 0.5417666165158153, 0.21556899358984083, 0.0017804740832616517, 0.07238912890898064, 0.03671488790132571, 0.03215837947209366, 0.03467061986157205, 18.45597255975008, 41.822136640548706, 58.28169442713261, 86.3991330564022, 51.272917315363884, 47.21262238919735, 37.925065755844116, 41.55522756278515, 71.8446372449398, 83.71405273675919, 82.13120207190514, 77.86345347762108, 3.062558239325881, 0.12143938321969472, 0.05598572453891393, 0.051485033036442474, 0.022501416606246494, 0.07049690466374159, 0.03982624926720746, 0.05469048388476949, 0.034406062768539414, 0.04202056101348717, 0.03503728534269612, 0.028757331892848015, 0.03962261136621237, 0.051515709710656665, 0.002381637937105552, 0.07021564553724602, 0.007582539974464453, 0.03783239902986679, 0.06385654574842192, 0.003346458443047595, 0.038815381049062125, 0.05726452662202064, 0.05902392127609346, 0.030141825081955176, 0.02231306138128275, 0.026279174635419622, 0.20207196939736605, 0.2425983385182917, 0.15035177202662453, 0.2501205395674333, 0.11324852937832475, 0.18160368490498513, 0.17291191848926246, 0.17447370890295133, 0.17840180749772117, 0.2178024870227091, 0.12016898224828765, 0.2785267465515062, 0.1195385203754995, 0.21033622906543314, 0.1316759077599272, 0.4625226109055802, 0.14212933980161324, 0.301514295861125, 0.24459999985992908, 0.5425079329870641, 1.2205276382155716, 34.821593686938286, 149.37028884887695, 134.41637367010117, 125.29701501131058, 119.8014535009861, 90.70991054177284, 61.38955906033516, 62.04703778028488, 148.02923440933228, 43.08424651622772, 54.407182931900024, 64.10560011863708, 1.1257507489062846, 0.4896348685724661, 0.45203481742646545, 0.8861563273239881, 0.15877667698077857, 0.671797301620245, 0.3895532264141366, 0.6206870754249394, 2.96949933283031, 9.869889635592699, 20.280209071934223, 140.5216884613037, 103.9351312816143, 119.69275653362274, 98.69540244340897, 103.21325361728668, 94.52785447239876, 102.54662498831749, 83.8656722009182, 88.08573335409164, 77.39117681980133, 80.02268001437187, 77.95109957456589, 81.28719136118889, 76.05788916349411, 78.47678616642952, 76.97924852371216, 82.93735161423683, 79.46493834257126, 88.64263907074928, 85.5501826107502, 83.10609295964241, 71.0678069293499, 81.45389601588249, 76.19918078184128, 80.65406933426857, 74.01309728622437, 79.54284936189651, 94.01298210024834, 98.50893884897232, 93.19337368011475, 98.1323866546154, 91.97104766964912, 82.071742862463, 77.65494346618652, 82.25987076759338, 87.2336594760418, 91.63673400878906, 95.5344432592392, 90.72849154472351, 93.38894158601761, 94.40506786108017, 93.18396538496017, 93.950604647398, 100.28056338429451, 59.73397269845009, 85.18952116370201, 101.33164018392563, 86.1142547428608, 86.4306865632534, 82.30106815695763, 89.07361954450607, 85.21818682551384, 95.7862177491188, 93.60152497887611, 97.78313219547272, 89.71493393182755, 98.06074529886246, 92.92000114917755, 99.43535953760147, 84.2072282731533, 78.13714519143105, 73.73625934123993, 74.48415040969849, 76.2043485045433, 76.57392427325249, 83.92378628253937, 90.65908446907997, 88.68018105626106, 89.04078930616379, 80.84435552358627, 86.4191047847271, 84.07691806554794, 83.39573621749878, 80.79067960381508, 82.6307612657547, 83.35770785808563, 89.93995025753975, 89.92798089981079, 98.45444217324257, 82.71724462509155, 88.72717693448067, 89.7805792093277, 93.78962248563766, 35.813477262854576, 2.570717381313443, 2.8357669338583946, 12.372906524688005, 1.6908287582919002, 0.6032428645994514, 0.25312644545920193, 0.31568174657877535, 0.14153600757708773, 0.22735438775271177, 0.17690606822725385, 28.01488023251295, 57.52950958907604, 70.10971114039421, 89.97607871890068, 58.239756077528, 77.42669731378555, 34.32199269533157, 38.99419918656349, 82.32002913951874, 99.94430422782898, 95.96081078052521, 88.80971610546112, 3.0987724335864186, 0.19144189136568457, 0.18623156938701868, 0.21711273497203365, 0.10261684088618495, 0.1687257454614155, 0.11866375833051279, 0.13375876005738974, 0.14340409717988223, 0.20553264854243025, 0.19135730137350038, 0.08578248249250464, 0.14768254884984344, 0.12377494422253221, 0.12266986406757496, 0.1359077970846556, 0.17291922122240067, 0.17562084656674415, 0.1108243188355118, 0.10876597967580892, 0.18800081976223737, 0.11404404489439912, 0.1600024674553424, 0.10321132343960926, 0.10049144868389703, 0.13013935036724433], [0.03842679252556991, 0.016170511007658206, 0.07731727891950868, 0.05380250047892332, 0.06310051248874515, 0.03137907617201563, 0.029483113357855473, 0.053501162547036074, 0.06335171463433653, 0.03200260267476551, 0.02096544179948978, 0.04332881151640322, 0.06256785825826228, 0.024718196873436682, 0.034833031459129415, 0.0316992423904594, 0.09582824539393187, 0.04714067865279503, 0.06474274428910576, 0.04138046977459453, 0.1121607561071869, 66.97542652487755, 107.81014814972878, 87.10393443703651, 88.5339193046093, 54.76404458284378, 17.74322770535946, 17.427751533687115, 57.756266221404076, 103.42908203601837, 62.11296044290066, 52.14049056172371, 2.146118190139532, 0.1647977507673204, 0.08811930514639243, 0.1360223995288834, 0.06827044679084793, 0.10366444170358591, 0.21330556191969663, 0.06916342856129631, 0.33356029191054404, 0.38240818481426686, 1.2579393619671464, 97.7853436768055, 111.54917791485786, 103.76293212175369, 99.17964845895767, 94.94732156395912, 95.7501956820488, 93.09112876653671, 89.46622207760811, 88.88032391667366, 78.82858648896217, 75.99958509206772, 67.60576710104942, 68.06338414549828, 65.98482728004456, 68.46446022391319, 65.04764556884766, 69.28409144282341, 68.44595521688461, 72.38423869013786, 70.24852529168129, 69.75148156285286, 64.5978257060051, 66.84434115886688, 66.28687307238579, 67.69054815173149, 68.67081955075264, 73.56768518686295, 66.28734424710274, 77.64941856265068, 88.65290611982346, 89.13636937737465, 80.52437469363213, 72.5394831597805, 68.89077454805374, 71.6303363442421, 73.13393846154213, 81.21184140443802, 81.35483533143997, 83.45875203609467, 82.81405583024025, 84.59305197000504, 82.34136119484901, 83.09723943471909, 81.14447101950645, 94.04352486133575, 49.554562121629715, 66.46034896373749, 89.78231191635132, 75.81516578793526, 75.87266430258751, 70.48038125038147, 75.38354694843292, 75.88882863521576, 79.16552200913429, 81.08801364898682, 87.31603905558586, 84.78085309267044, 86.79185718297958, 81.44476890563965, 78.33946913480759, 69.26351174712181, 68.80217850208282, 65.7600237429142, 66.48576959967613, 63.792785704135895, 66.84903010725975, 69.43773999810219, 78.04627686738968, 79.60918620228767, 81.60390436649323, 76.33749336004257, 76.7515267431736, 74.8260560631752, 75.30324965715408, 73.13518479466438, 73.03163275122643, 73.73659372329712, 78.84022906422615, 83.35093662142754, 87.03243747353554, 85.52333325147629, 80.93601420521736, 82.95620620250702, 84.56827729940414, 86.15637168288231, 26.623978167772293, 0.5387486284598708, 1.0089122434146702, 0.7322892243973911, 0.1611499019782059, 0.16151494957739487, 0.029828837286913767, 0.13631287612952292, 0.037037558868178166, 0.037538107790169306, 0.5857391632162035, 5.090667586773634, 29.192281253635883, 22.199394889175892, 46.065292954444885, 36.7935548722744, 22.261025682091713, 24.801278673112392, 37.023727521300316, 61.52081921696663, 74.04676347970963, 84.36485901474953, 34.14846360683441, 0.6903949880506843, 0.1808125406387262, 0.04865333889028989, 0.10039506596513093, 0.06969868773012422, 0.03336300760565791, 0.04726802006189246, 0.01628278125281213, 0.0519679893477587, 0.05213004842516966, 0.04947434346831869, 0.06130477486294694, 0.048486749001313, 0.026876642477873247, 0.04353454969532322, 0.04359707563708071, 0.04805953911272809, 0.12504184967838228, 0.02418488398689078, 0.03562375270121265, 0.06826781216659583, 0.05311079657985829, 0.041256490294472314, 0.026856044169107918, 0.07680533803068101, 0.03286131577624474, 0.029443228486343287, 0.05571948648139369, 0.022857851581647992, 0.058855795141425915, 0.028508243012765888, 0.073085716139758, 0.0415061858802801, 0.040185285470215604, 0.04117744414543267, 0.03485162967990618, 0.04498901813349221, 0.009173698563245125, 0.0450221958453767, 0.05899273994145915, 0.026618124611559324, 0.05788644637505058, 0.032881684019230306, 0.08035909733735025, 0.07596619907417335, 0.26891836838331074, 88.6539776623249, 121.35515972971916, 97.0457361638546, 108.32962587475777, 68.92468392848969, 38.05777743458748, 26.1457035318017, 31.755131632089615, 97.22047358751297, 34.68091003596783, 55.927333161234856, 4.735967069864273, 0.16760900616645813, 0.021517955901799724, 0.3769615927012637, 0.03142849207506515, 0.30298594501800835, 0.11221157838008367, 0.1656314794672653, 0.27394941716920584, 0.9773739357478917, 2.671679388731718, 106.78915053606033, 114.71060067415237, 109.48527306318283, 102.64467492699623, 99.51623439788818, 99.86349016427994, 98.25525686144829, 91.7405216395855, 94.79138553142548, 83.33103328943253, 79.60593357682228, 71.67075097560883, 72.47229516506195, 69.28197875618935, 73.84101212024689, 68.51160809397697, 71.20639309287071, 73.62804874777794, 77.4762998521328, 74.23040762543678, 72.35321715474129, 67.72328719496727, 70.83555579185486, 70.22395581007004, 70.78186467289925, 71.68912678956985, 74.51238289475441, 71.32620066404343, 81.1681817471981, 92.56070762872696, 92.40145057439804, 83.1709098815918, 74.57450956106186, 72.20293521881104, 74.9782682955265, 77.03647345304489, 84.84044909477234, 84.65368911623955, 88.64159792661667, 83.96889746189117, 89.90598008036613, 85.57843789458275, 85.19569203257561, 82.47018948197365, 97.27310836315155, 52.7041295170784, 69.62877094745636, 92.96115294098854, 78.23210969567299, 79.4404524564743, 74.3766313791275, 80.7377940416336, 78.72830227017403, 83.34440097212791, 85.20346641540527, 91.58322528004646, 89.89581182599068, 89.47168618440628, 85.75164020061493, 81.99091359972954, 71.68853402137756, 71.0870186984539, 69.39272001385689, 70.0326056778431, 67.88408696651459, 69.80475470423698, 73.78581628203392, 81.62689313292503, 82.37602293491364, 85.20795777440071, 80.16735345125198, 79.17188286781311, 79.81220170855522, 79.85788285732269, 76.02395698428154, 75.60474827885628, 78.21975275874138, 80.67552298307419, 87.18420892953873, 91.69220343232155, 86.15051999688148, 82.27580711245537, 88.3581331372261, 88.35972905158997, 92.5707770884037, 34.34158444404602, 0.8691186353098601, 0.7879426411818713, 0.9465483867097646, 0.20059171132743359, 0.17169812112115324, 0.05218405080086086, 0.1340461493236944, 0.07372638254310004, 0.060568701665033586, 0.8908968104515225, 4.640492917969823, 34.85077232122421, 24.99420952051878, 48.03055129945278, 34.41581726074219, 26.21287252753973, 36.16140939295292, 51.45699083805084, 70.26927977800369, 83.35969895124435, 94.33981016278267, 55.63420929014683, 0.8631020144093782, 0.022082769246480893, 0.055925176420714706, 0.039197809746838175, 0.02362300769163994, 0.02664363222720567, 0.027967753558186814, 0.04852727026445791, 0.038501634408021346, 0.036235827865311876, 0.04901455329672899, 0.016293932021653745, 0.012365608927211724, 0.025162873207591474, 0.0212662991907564, 0.09680657414719462, 0.03695674269692972, 0.04013670819404069, 0.04472465028811712, 0.019669991488626692, 0.07175006554462016, 0.06599934873520397, 0.017295868492510635, 0.06660598024609499, 0.03715934159117751, 0.08386872854316607, 0.17132780427346006, 0.16638165718177333, 0.1818256315891631, 0.1910957833752036, 0.16776706877863035, 0.17091111803893, 0.21170406660530716, 0.1663483347510919, 0.06344597481074743, 0.09452315644011833, 0.14479883015155792, 0.15047247492475435, 0.35629539226647466, 0.1317989410017617, 0.17274117999477312, 0.2713140507694334, 0.12830033811042085, 0.22692490689223632, 0.20878839102806523, 0.33665074326563627, 100.93446269631386, 138.15908163785934, 114.38125714659691, 120.75101494789124, 79.1729848086834, 32.10757412016392, 26.76880929619074, 87.24517285823822, 122.41821348667145, 86.52665421366692, 86.68839633464813, 5.696373609825969, 0.4545744467759505, 0.16185872722417116, 0.7251646660733968, 0.28603671700693667, 0.567067974479869, 0.36851241951808333, 0.49430256185587496, 1.4091142499819398, 4.07758304849267, 2.0419847778975964, 111.57049477100372, 118.8889628648758, 115.54778695106506, 104.925646930933, 104.55268934369087, 105.25945901870728, 102.31787726283073, 94.85763877630234, 99.65778440237045, 86.58385634422302, 85.77621728181839, 76.25655770301819, 77.55798026919365, 72.7889321744442, 79.55774456262589, 74.54377681016922, 77.74233877658844, 78.09375911951065, 80.94129592180252, 79.23134967684746, 79.2801770567894, 72.53293231129646, 74.33818504214287, 74.84713733196259, 74.42365765571594, 76.02504372596741, 78.31611558794975, 73.7165080010891, 84.95477735996246, 95.30982211232185, 97.16875836253166, 87.42955416440964, 80.11131405830383, 76.81449696421623, 79.70871046185493, 80.2104203402996, 89.46523413062096, 88.621124625206, 91.31397172808647, 90.72501093149185, 93.62160310149193, 91.44232124090195, 90.3521217405796, 88.56402888894081, 99.45948824286461, 58.38528446853161, 73.93179684877396, 98.14326167106628, 83.48626255989075, 82.2912722826004, 79.23179805278778, 83.92760887742043, 84.06731218099594, 86.18728682398796, 89.25788685679436, 95.40143519639969, 94.4367353618145, 92.27282747626305, 90.00961571931839, 86.58667579293251, 77.36115083098412, 74.04753863811493, 72.47189238667488, 74.41789716482162, 69.83183965086937, 72.42995783686638, 77.7422247827053, 86.98154300451279, 88.64563331007957, 89.84570771455765, 85.38354635238647, 84.03616145253181, 83.9564037322998, 83.95169958472252, 81.85080751776695, 80.96377551555634, 83.25302347540855, 86.14951685070992, 91.87384888529778, 97.07265391945839, 87.76297867298126, 83.49964544177055, 90.71551904082298, 89.43858236074448, 98.32156330347061, 33.305858820676804, 1.206304170191288, 7.772276317700744, 3.2513743825256824, 0.45588543580379337, 0.36566631286405027, 0.1097361373831518, 0.43440851324703544, 0.20959348767064512, 0.19386874395422637, 0.8618410758208483, 9.054417293518782, 48.7504530698061, 35.439451932907104, 67.05167323350906, 53.498017117381096, 29.505688436329365, 39.55553166568279, 53.275523856282234, 85.26451393961906, 95.26053875684738, 113.4334284067154, 58.52806940674782, 1.0311208642087877, 0.28029142529703677, 0.12345281502348371, 0.1859779775259085, 0.21751509775640443, 0.19920107501093298, 0.14259493356803432, 0.10785860024043359, 0.14357203035615385, 0.119436779350508, 0.11838180158520117, 0.11072792127379216, 0.09664956538472325, 0.18973321508383378, 0.17912581708515063, 0.3803740470902994, 0.07371959189185873, 0.15370470617199317, 0.15032594528747723, 0.1987329579424113, 0.13337698444956914, 0.13485065224813297, 0.10130187394679524, 0.11859193327836692, 0.13010677008423954], [0.038895058023626916, 0.06051316675439011, 0.03320543481095228, 0.054701482513337396, 0.15369528089649975, 0.031165170657914132, 0.009323117010353599, 0.034635705524124205, 0.07388638216070831, 0.06858925858978182, 0.032714411354390904, 0.02787720412015915, 0.04112208363949321, 0.0214782343027764, 0.035610557315521874, 0.05094676074804738, 0.040225417105830275, 0.03608858576626517, 0.17892674339236692, 0.19356467120815068, 8.902733232825994, 101.34544864296913, 100.50524532794952, 85.0111511349678, 51.62208817899227, 41.627735272049904, 31.883021369576454, 55.96917651593685, 84.78621080517769, 89.94217693805695, 64.86052840948105, 6.984112160280347, 0.16202530969167128, 0.09692770006950013, 0.11838044345495291, 0.11021302663721144, 0.1768263170379214, 0.11112992782727815, 0.16590727638686076, 0.19012134347576648, 0.5154988635331392, 0.6011340371333063, 56.1689317971468, 122.18874379992485, 99.74776357412338, 108.29485774040222, 95.07870331406593, 100.37567988038063, 97.64504000544548, 101.80168256163597, 92.5667417049408, 93.95175218582153, 85.45194268226624, 79.47762966156006, 70.75385257601738, 68.94337892532349, 64.82253804802895, 64.84532162547112, 65.47088205814362, 63.77719894051552, 64.39106360077858, 68.11703726649284, 63.47474656999111, 66.17648899555206, 63.8768295943737, 65.04943147301674, 68.62578436732292, 71.30417704582214, 68.70668202638626, 70.3744201362133, 73.46784934401512, 68.78993555903435, 71.66349336504936, 75.14566451311111, 68.70006278157234, 66.43102213740349, 65.90009182691574, 73.45246016979218, 74.83218133449554, 81.93432703614235, 84.76365521550179, 90.23901700973511, 77.68564581871033, 82.77690902352333, 76.80921524763107, 82.5432975590229, 73.78195568919182, 89.70392972230911, 51.00603103637695, 61.263432428240776, 93.08813452720642, 75.63283637166023, 79.40779700875282, 72.2011037170887, 75.55395260453224, 70.57076320052147, 72.28055745363235, 75.83507671952248, 84.37663838267326, 82.04040974378586, 88.70903670787811, 74.93037566542625, 70.63212230801582, 68.58973190188408, 68.76757755875587, 66.4788007736206, 67.78623461723328, 65.02408683300018, 65.72859182953835, 67.44435176253319, 74.90609496831894, 73.40942367911339, 80.44163033366203, 80.49808010458946, 79.42867308855057, 76.40163391828537, 77.55591318011284, 71.93805143237114, 73.07359009981155, 72.29590103030205, 82.0785216987133, 79.02923092246056, 92.2584642469883, 75.26418015360832, 79.07665997743607, 86.72580152750015, 83.23082506656647, 75.34872561693192, 85.38032412528992, 17.689878568053246, 0.060023475452908315, 0.564007832435891, 0.06003916074405424, 0.11824900910141878, 0.020826417130592745, 0.08532828069292009, 0.05120880938193295, 0.10074591627926566, 0.28571501083206385, 0.505298845237121, 4.731670925393701, 26.442625299096107, 43.022480830550194, 60.12762397527695, 60.0656720995903, 35.123552083969116, 26.86490423977375, 53.349669277668, 62.869393453001976, 73.20241838693619, 83.89099404215813, 14.214441608637571, 0.688138265395537, 0.1472776776063256, 0.2504454518202692, 0.17673890688456595, 0.08682088067871518, 0.025530280836392194, 0.051299759579706006, 0.0612568469659891, 0.050319386209594086, 0.059337719867471606, 0.06728422900778241, 0.005809858557768166, 0.07718079796177335, 0.0449584564921679, 0.01794899369997438, 0.037215384872979484, 0.060987187607679516, 0.022744212074030656, 0.012793903279089136, 0.03275340008258354, 0.06776577152777463, 0.022148174721223768, 0.02435559650621144, 0.0052387258256203495, 0.02283823661855422, 0.07371694984612986, 0.02504839692846872, 0.06475480418885127, 0.14960362779675052, 0.0173105500289239, 0.05284734157612547, 0.06286043513682671, 0.0797237892402336, 0.020112519305257592, 0.034114098161808215, 0.0059627831888064975, 0.04075120647030417, 0.06685436965199187, 0.13990696374094114, 0.08906292365281843, 0.08288746088510379, 0.1264091528719291, 0.16527193860383704, 0.3993512084707618, 14.60657961666584, 124.08080667257309, 110.6402362883091, 99.30219188332558, 67.00696483254433, 62.62496016919613, 42.26336896419525, 75.15952616930008, 90.07130160927773, 80.43292880058289, 61.32876992225647, 10.273191444575787, 0.5395714624319226, 0.058084061747649685, 0.19361930812010542, 0.0765467737801373, 0.05791389099613298, 0.12229063402628526, 0.0883287243777886, 0.12563984259031713, 0.07831156384781934, 0.9339926135726273, 62.69614934921265, 124.82686623930931, 103.86452347040176, 110.1475927233696, 98.0766436457634, 105.32641902565956, 101.00028276443481, 104.46733072400093, 98.51957067847252, 97.96121343970299, 91.41611784696579, 83.331778049469, 74.2857326567173, 73.30128148198128, 68.71121898293495, 68.38271901011467, 68.07570308446884, 68.47239419817924, 69.54987958073616, 72.80014157295227, 67.81457349658012, 70.81121429800987, 68.03372293710709, 69.95609298348427, 71.18696093559265, 73.30245941877365, 71.41013815999031, 73.31812977790833, 78.39586570858955, 71.07954069972038, 72.78029143810272, 77.93681994080544, 70.25729522109032, 69.06619593501091, 69.20054912567139, 76.92578539252281, 78.89098674058914, 87.37528547644615, 87.78617262840271, 93.1570628285408, 82.73904785513878, 88.07937249541283, 82.33432397246361, 87.52781689167023, 79.63147580623627, 93.92452284693718, 54.80697087943554, 65.9964470565319, 97.85430997610092, 79.19722750782967, 81.63980484008789, 77.30030089616776, 78.72792229056358, 75.1490843296051, 76.17856308817863, 76.44555196166039, 85.08647069334984, 83.10523420572281, 92.45821192860603, 79.56817880272865, 74.33578357100487, 71.33438542485237, 72.93644785881042, 70.66198870539665, 70.5657322704792, 69.49043557047844, 68.71466919779778, 70.97354158759117, 78.20762380957603, 76.99424251914024, 84.09397155046463, 84.6632494032383, 82.18668669462204, 81.14072442054749, 80.9886945784092, 77.6971971988678, 76.80071130394936, 76.36252641677856, 86.21640846133232, 84.90071386098862, 94.52232956886292, 77.18161806464195, 81.71602115035057, 86.24179869890213, 85.82780331373215, 79.02853935956955, 95.04484713077545, 27.53274690359831, 0.21130998618900776, 0.9056116989813745, 0.32321620790753514, 0.2166572047281079, 0.028648280713241547, 0.08852891129208729, 0.054015634159441106, 0.23653444281080738, 0.5142677889671177, 0.7719238882418722, 6.06395211070776, 26.299399584531784, 39.78231869637966, 51.03897146880627, 35.53075723350048, 39.025011733174324, 40.272082015872, 64.58346247673035, 70.27912124991417, 82.74904891848564, 98.20490196347237, 26.579241268336773, 0.7473085715901107, 0.21461422060383484, 0.177005278528668, 0.0855222855170723, 0.11947477731155232, 0.03416966646909714, 0.03827594729955308, 0.010730924768722616, 0.042272909777238965, 0.06003875627357047, 0.05900498166738544, 0.06156887182442006, 0.035646696196636185, 0.017634091163927224, 0.07636510345037095, 0.00441134156062617, 0.08142776030581445, 0.05371980296331458, 0.20712226949399337, 0.04306502996769268, 0.046524295321432874, 0.018351028083998244, 0.035262419551145285, 0.037663890689145774, 0.2120353316422552, 0.17486731434473768, 0.09709897291031666, 0.10048633528640494, 0.25440424564294517, 0.1249345944961533, 0.14300673647085205, 0.1832601139904, 0.13592679606517777, 0.20072727202204987, 0.1479729512357153, 0.16307945625158027, 0.16502020211191848, 0.13722179923206568, 0.22579792595934123, 0.35994827281683683, 0.09522464926703833, 0.20664254523580894, 0.3163568931631744, 0.4108475806424394, 16.834614761173725, 145.52039623260498, 122.86130771040916, 119.81229811906815, 74.14153799414635, 68.15384969115257, 46.633142083883286, 91.35091334581375, 111.64778262376785, 100.26908800005913, 96.54841884970665, 12.308950256556273, 0.7176166085992008, 0.13899149489589036, 0.561039597960189, 0.4025796992937103, 0.7538975367788225, 0.22726718540070578, 0.3647933393949643, 0.48553105909377337, 1.51366516482085, 1.6121697728522122, 65.05131617188454, 128.34648817777634, 108.2783742249012, 114.46437388658524, 103.2994481921196, 108.05493101477623, 105.50763890147209, 106.01026833057404, 101.99943915009499, 99.45380374789238, 95.18906459212303, 88.29142391681671, 78.95247504115105, 78.49380165338516, 74.80977013707161, 71.83572292327881, 74.93927478790283, 73.79833281040192, 74.1877131164074, 77.3123462498188, 71.59530982375145, 74.47766795754433, 70.62072291970253, 72.40369364619255, 74.95089456439018, 75.71475237607956, 76.24378278851509, 76.88999891281128, 81.68419405817986, 72.92902305722237, 76.7096833884716, 81.63782894611359, 73.92790585756302, 71.75599560141563, 73.69814738631248, 79.53213393688202, 82.88378968834877, 89.77763056755066, 90.1891028881073, 95.51330119371414, 85.44071048498154, 92.29043573141098, 87.46328115463257, 91.5391780436039, 86.12638369202614, 99.23771694302559, 61.782385781407356, 69.26088228821754, 99.47677731513977, 85.27660489082336, 87.47768998146057, 80.87726935744286, 81.64062559604645, 79.60129022598267, 80.02948924899101, 83.65636423230171, 92.0635575056076, 88.56327652931213, 98.65792125463486, 85.05343526601791, 77.18088090419769, 73.51720869541168, 74.72017854452133, 73.87831091880798, 73.38436782360077, 74.42828580737114, 70.64840823411942, 74.63696300983429, 82.58464694023132, 80.15349179506302, 89.22969236969948, 88.5445511341095, 87.80800625681877, 85.15588536858559, 84.39166277647018, 80.57044342160225, 80.76254591345787, 80.83701431751251, 92.87877336144447, 87.19078257679939, 97.19028040766716, 77.2663763165474, 87.63812497258186, 89.81692805886269, 92.03581139445305, 84.16087076067924, 97.73006424307823, 24.93534877896309, 0.616902062902227, 2.6229018811136484, 0.7407929899636656, 0.5311158474069089, 0.2782554173609242, 0.20574883616063744, 0.2316283865366131, 0.4470643575768918, 0.7374572439584881, 0.8484605688136071, 9.616991356015205, 45.2605265378952, 61.44460290670395, 80.47229468822479, 83.500025421381, 46.314548179507256, 41.094711273908615, 73.17783370614052, 86.14760175347328, 93.34522113204002, 114.54901814460754, 25.540291517972946, 1.4049235498532653, 0.4422610887559131, 0.42961020197253674, 0.23690087080467492, 0.27215347916353494, 0.2422235836274922, 0.16311735031194985, 0.24190305004594848, 0.15578521328279749, 0.1743868479388766, 0.18296580790774897, 0.12308922945521772, 0.14204681297997013, 0.10388548296759836, 0.1483737406670116, 0.11855054370244034, 0.10160447724047117, 0.1426493626786396, 0.2812191692646593, 0.15323359082685784, 0.07915476235211827, 0.12145265282015316, 0.055886432601255365, 0.132915650610812], [0.021037741826148704, 0.026914005902654026, 0.0290854186823708, 0.041104424235527404, 0.07541306156781502, 0.02239517074485775, 0.09852550690993667, 0.031089525400602724, 0.08113148011034355, 0.00990728000033414, 0.04759196010127198, 0.046199876596801914, 0.11449015728430822, 0.01533183403807925, 0.09365431673359126, 0.1172963141289074, 0.04210568906273693, 0.10933111028862186, 0.23541546222986653, 0.4481836053309962, 23.317424096167088, 104.02106747031212, 94.25178408622742, 76.53202012181282, 55.51367975771427, 30.635871291160583, 50.0931566208601, 33.86532939970493, 28.958797082304955, 46.21688202023506, 16.42476685345173, 0.5343359371181577, 0.1068093889625743, 0.17362251004669815, 0.19484009651932865, 0.19444665435003117, 0.25459658063482493, 0.2556015376467258, 0.3177464014152065, 0.34466929268091917, 0.5751808360219002, 30.87347064167261, 117.8015524148941, 99.94204714894295, 108.11825081706047, 98.27876999974251, 105.59053525328636, 98.6490449309349, 100.42419567704201, 99.11040857434273, 98.04822877049446, 104.7692397236824, 92.01915308833122, 84.26326006650925, 73.13856661319733, 66.54428645968437, 63.71499627828598, 64.8003776371479, 61.792177855968475, 64.94961842894554, 64.11218896508217, 65.86480692029, 62.82213918864727, 65.49368843436241, 63.88347923755646, 67.77106583118439, 67.08795368671417, 64.514389783144, 67.27376371622086, 73.91709163784981, 74.80056703090668, 73.96230161190033, 68.64035278558731, 68.01994487643242, 63.045776188373566, 67.47623965144157, 68.61326023936272, 71.68876960873604, 74.22394037246704, 81.35127112269402, 78.61509874463081, 83.07335391640663, 80.11963561177254, 83.71737375855446, 78.51616725325584, 79.37606111168861, 75.19937083125114, 87.819694429636, 49.07486066222191, 60.09246826171875, 88.27576875686646, 73.11137527227402, 75.47384530305862, 75.2542094886303, 79.74070474505424, 73.77774551510811, 74.88872990012169, 69.63410586118698, 70.17002150416374, 75.86992844939232, 75.36642506718636, 67.74300053715706, 67.15419173240662, 66.98980495333672, 67.89152696728706, 65.45236185193062, 62.3921162635088, 66.14055052399635, 64.81137424707413, 65.14526233077049, 69.45737734436989, 73.84568586945534, 76.58581003546715, 79.2167204618454, 80.94126552343369, 77.25889071822166, 73.46010535955429, 72.43154615163803, 72.08511114120483, 76.50275409221649, 75.83573788404465, 85.959732234478, 76.77904486656189, 76.66991472244263, 83.34385380148888, 75.24165496230125, 71.4329445362091, 82.92782172560692, 83.7667179107666, 89.27860334515572, 14.681296907365322, 0.7250726991333067, 0.34979123971424997, 0.20402263035066426, 0.06610278927837498, 0.09314061695476994, 0.05843093786097597, 0.07028050182270817, 0.23148283653426915, 0.16763802414061502, 0.14950950862839818, 9.380274508148432, 25.40074970573187, 42.39237584173679, 60.26817463338375, 38.46793122589588, 22.64666508883238, 30.56967504322529, 64.43837106227875, 72.16336414217949, 69.32254537940025, 64.39530417323112, 2.6310702553018928, 0.17368726985296234, 0.028827815513068344, 0.051880972532671876, 0.028041782788932323, 0.07945899837068282, 0.048889909594436176, 0.01712497600237839, 0.047062118610483594, 0.05700429253920447, 0.017572947472217493, 0.032711531821405515, 0.06685025815386325, 0.048034495339379646, 0.02167619291867595, 0.0780749820114579, 0.06795920489821583, 0.02651854694704525, 0.007930107676656917, 0.009287522680097027, 0.015037018656585133, 0.034420983647578396, 0.04337981932621915, 0.029702761239605024, 0.04720853321487084, 0.026824564120033756, 0.009587246440787567, 0.030394622845051344, 0.02675321218703175, 0.012018858978990465, 0.03402824280783534, 0.03307893573946785, 0.08967223431682214, 0.0540606083086459, 0.05760922082117759, 0.040816500622895546, 0.03611816035117954, 0.021421113051474094, 0.07344372817897238, 0.0416653357387986, 0.12351551908068359, 0.14744342886842787, 0.386960607720539, 0.2907528873765841, 36.40262804925442, 121.369598954916, 105.1605199277401, 90.67091703414917, 61.47271379828453, 45.497204437851906, 52.68109515309334, 28.90297807753086, 37.121063098311424, 54.96356047689915, 21.789305694401264, 0.4357134463498369, 0.06989321947912686, 0.031700849140179344, 0.11690624873153865, 0.2420926687773317, 0.2370495823561214, 0.19965282030170783, 0.3699438145849854, 0.2877116552554071, 0.8478476735763252, 38.18348988890648, 122.80869573354721, 103.98705929517746, 111.02225258946419, 103.56744021177292, 107.62907266616821, 102.39717900753021, 101.48646667599678, 102.47945219278336, 101.35193109512329, 110.03504276275635, 96.60018727183342, 88.59555959701538, 77.18991681933403, 70.22167593240738, 68.50111305713654, 70.05989581346512, 66.49110451340675, 69.60591897368431, 68.10312241315842, 71.25103309750557, 66.64770171046257, 68.5808327794075, 67.36854583024979, 70.08043751120567, 69.64354455471039, 67.56830111145973, 69.7838482260704, 77.70121738314629, 75.34025207161903, 76.80620580911636, 72.27233469486237, 69.6285505592823, 66.6557876765728, 70.51526337862015, 72.59789362549782, 75.60465708374977, 77.81864628195763, 84.12145167589188, 82.07263201475143, 83.78668203949928, 83.28597530722618, 88.23707923293114, 82.8388760983944, 84.2215459048748, 78.91927242279053, 91.91804811358452, 54.506448805332184, 64.25022035837173, 93.42544242739677, 75.99203869700432, 79.57403808832169, 79.69774425029755, 83.1407319009304, 77.72250384092331, 78.45226228237152, 73.39060708880424, 76.34945511817932, 78.82490068674088, 78.73907089233398, 70.5163425207138, 71.19285061955452, 70.75916469097137, 69.76327612996101, 66.8306314945221, 65.89316099882126, 67.6118391752243, 67.05227360129356, 68.74145776033401, 71.60973384976387, 76.50480598211288, 79.53541696071625, 83.44954892992973, 82.58033037185669, 81.79445654153824, 78.95925387740135, 75.12354969978333, 74.27204579114914, 80.55281236767769, 83.07291314005852, 89.52172949910164, 77.17734709382057, 77.82683104276657, 82.39006698131561, 81.02421507239342, 79.21026840806007, 91.32237687706947, 85.03531783819199, 98.37526962161064, 20.764975659549236, 0.5621965765021741, 0.4716694029048085, 0.2453581037116237, 0.08516226225765422, 0.24252890318166465, 0.09430679812794551, 0.015905955769994762, 0.6027907482348382, 0.06347264017676935, 0.3065595938824117, 10.11327512562275, 29.632204547524452, 40.63248887658119, 51.06398552656174, 42.35095426440239, 38.106095641851425, 48.25662776827812, 73.37619826197624, 80.45529440045357, 76.43685802817345, 84.5131042599678, 6.1645331885665655, 0.2724100247723982, 0.04153009787842166, 0.18170725903473794, 0.0713086361065507, 0.08259149981313385, 0.030966015328885987, 0.04267524658644106, 0.07007584717939608, 0.06064981469535269, 0.03612787877500523, 0.011753802791645285, 0.03788421949138865, 0.04299804742913693, 0.02327343387150904, 0.08228112623328343, 0.0587467773584649, 0.09344741338281892, 0.034776546599459834, 0.056465793895768, 0.03177793601935264, 0.044702293089358136, 0.04001721870736219, 0.04187345250102226, 0.11119078393676318, 0.11318858611048199, 0.10751886729849502, 0.1390558687853627, 0.27362109103705734, 0.0690079783089459, 0.20332838088506833, 0.21180459792958573, 0.23874408361734822, 0.22967383672948927, 0.1764393612393178, 0.18569916748674586, 0.1709791729808785, 0.10845272656297311, 0.17327300301985815, 0.19445214624283835, 0.30508031544741243, 0.22853881091577932, 0.636532997014001, 0.5640045669861138, 47.56204403936863, 139.13915544748306, 119.965331107378, 110.33315196633339, 77.30087846517563, 47.58668191730976, 63.97623986005783, 51.884080320596695, 41.90876439213753, 75.21163657307625, 29.14587054401636, 1.6022150195203722, 0.20456687692785636, 0.49179594323504716, 0.27440871752332896, 0.6786467903293669, 1.3365766173228621, 0.4414473386714235, 0.8615100779570639, 0.5957561382092535, 1.9377991184592247, 37.652373388409615, 126.47669211030006, 109.27348762750626, 116.30784496665001, 107.86151379346848, 110.70396646857262, 108.24028506875038, 105.26354759931564, 107.40288600325584, 102.6838356256485, 108.92300203442574, 99.84566152095795, 94.66735258698463, 82.72115841507912, 75.80888092517853, 71.76031976938248, 75.62456041574478, 70.17357051372528, 72.90773659944534, 73.2531988620758, 74.15903225541115, 69.14544448256493, 73.13847541809082, 71.61902815103531, 74.19127732515335, 74.30557519197464, 73.27332258224487, 73.46012815833092, 82.27554112672806, 79.14270043373108, 79.1836242377758, 74.6800222992897, 72.91948556900024, 71.97701454162598, 75.0939416885376, 75.24507477879524, 79.22802105545998, 83.19441542029381, 89.11746919155121, 86.09448060393333, 87.76655048131943, 86.24467134475708, 91.88019454479218, 87.25177690386772, 87.11243078112602, 83.3534748852253, 96.0606998205185, 61.5976282954216, 68.61451417207718, 97.12731018662453, 81.93419024348259, 83.0694629251957, 84.70675706863403, 85.91912761330605, 82.20822393894196, 82.36413717269897, 76.28038242459297, 77.82726421952248, 83.10201197862625, 82.52941310405731, 75.38940623402596, 72.60357052087784, 73.67480143904686, 72.18164876103401, 71.55669629573822, 70.1778718829155, 72.62383863329887, 71.00800573825836, 71.55558675527573, 76.4733512699604, 82.341178804636, 83.99450048804283, 88.99110317230225, 84.29725304245949, 88.05514499545097, 80.61332032084465, 80.31603947281837, 77.71849125623703, 84.77044925093651, 85.0004281103611, 92.26933166384697, 78.2745686173439, 82.26757675409317, 85.1464618742466, 88.6386188864708, 81.76299422979355, 95.03445088863373, 87.94876590371132, 100.67376628518105, 17.98809226602316, 1.6593215614557266, 1.8983085500076413, 0.4464541043853387, 0.2783016976900399, 0.6579757214058191, 0.1733516261447221, 0.15798467182321474, 0.5903131084050983, 0.38199635222554207, 0.5042530107311904, 17.828823812305927, 41.58780321478844, 63.93147826194763, 87.08928242325783, 53.22947412729263, 34.606673419475555, 44.66189906001091, 87.67025604844093, 94.11238476634026, 91.38384237885475, 90.40444493293762, 5.193092515692115, 0.4728289047488943, 0.22591894055949524, 0.2607897139387205, 0.25850303820334375, 0.22653711988823488, 0.17750726721715182, 0.15422852884512395, 0.22565745224710554, 0.17333185533061624, 0.19048603484407067, 0.1238054019631818, 0.20951130223693326, 0.13120949763106182, 0.257010935456492, 0.17866828304249793, 0.11069151893025264, 0.1369262018124573, 0.19327582733239979, 0.16849446255946532, 0.1634155452484265, 0.13951487228041515, 0.19430849613854662, 0.1695188193116337], [0.03206900262739509, 0.07059871990350075, 0.04140849698160309, 0.06276823070948012, 0.016972229022940155, 0.06843052804470062, 0.02872303539334098, 0.05681061426002998, 0.05191299620491918, 0.015250075339281466, 0.027846661032526754, 0.05794167329440825, 0.07113427593139932, 0.08026762021472678, 0.12388539063977078, 0.05689170502591878, 0.04365778702776879, 0.0541930222971132, 0.06293005601037294, 0.08110759779810905, 51.95592686533928, 101.31744414567947, 85.6429736316204, 90.46193584799767, 61.917654722929, 48.5472247749567, 51.77390903234482, 100.93891605734825, 76.45348593592644, 43.023578971624374, 3.8515096670016646, 0.2578847104450688, 0.3164427151205018, 0.3612459625583142, 0.15381871489807963, 0.13677201321115717, 0.06495732886833139, 0.3649569384288043, 0.1970152571448125, 0.7722146320156753, 13.634898606687784, 108.6849220097065, 95.42266845703125, 104.65700134634972, 100.9451325237751, 104.90113824605942, 99.69382166862488, 102.05710485577583, 97.7266900241375, 98.24672251939774, 99.88700330257416, 93.47169354557991, 97.89586454629898, 88.69542583823204, 74.1929492354393, 68.54879289865494, 64.80705007910728, 61.956940814852715, 64.20130178332329, 63.39424788951874, 61.526294723153114, 63.36129605770111, 62.90379300713539, 64.19657483696938, 62.46830217540264, 65.432800501585, 62.18610271811485, 64.9034433066845, 73.65727677941322, 77.0754973590374, 75.68140536546707, 73.32157999277115, 71.93665310740471, 66.78626507520676, 66.05119451880455, 71.06225922703743, 70.19168794155121, 75.0335781276226, 79.29345354437828, 82.32978701591492, 84.14833143353462, 87.21558004617691, 80.71637839078903, 83.17542403936386, 73.69758501648903, 78.13563287258148, 74.94622841477394, 89.18806940317154, 56.09574772417545, 56.976874843239784, 88.90773564577103, 73.94646406173706, 79.17851731181145, 74.62396770715714, 81.55209794640541, 78.91503944993019, 78.36680486798286, 72.51252740621567, 69.58636522293091, 66.55121728777885, 67.67410263419151, 65.03658816218376, 67.16641187667847, 67.2975580394268, 68.24458882212639, 63.589177429676056, 61.40237957239151, 59.93423715233803, 63.68224583566189, 62.463195249438286, 68.90142917633057, 70.27009293437004, 75.60290157794952, 77.43735194206238, 80.14083847403526, 77.85668984055519, 74.15542244911194, 73.78337681293488, 71.73112973570824, 76.83528944849968, 82.49646127223969, 76.51533901691437, 74.17350187897682, 82.84361824393272, 72.90216609835625, 74.15165305137634, 86.17845609784126, 80.63134655356407, 84.2826846241951, 84.24727812409401, 81.79773196578026, 8.593141045421362, 0.7475305034313351, 0.21090431342599913, 0.12894977669930086, 0.07458707346813753, 0.14055126666789874, 0.10159074008697644, 0.05058007300249301, 0.03776553894567769, 0.04569742035528179, 0.23944709042552859, 13.775074984878302, 30.00521533191204, 50.814943090081215, 42.56350725889206, 29.858961179852486, 22.346709184348583, 52.97554895281792, 61.93424083292484, 78.98983463644981, 83.88897255063057, 28.772297389805317, 0.46660457155667245, 0.09388623046106659, 0.03056009951251326, 0.07741723879007623, 0.06773851986508816, 0.012184403367427876, 0.06941266401554458, 0.08279788366053253, 0.08465312668704428, 0.08029041899135336, 0.07077032671077177, 0.030140973467496224, 0.01819440152758034, 0.04376122014946304, 0.053330587325035594, 0.04719005373772234, 0.02021772615989903, 0.012215355563967023, 0.05166650669707451, 0.024516536795999855, 0.028340499084151816, 0.06846918651717715, 0.019473470783850644, 0.010194014321314171, 0.011082846558565507, 0.02100233396049589, 0.004341070844020578, 0.0369607094762614, 0.06407832916011102, 0.06315615872154012, 0.034595896722748876, 0.02620891922560986, 0.02056904588243924, 0.03472469645203091, 0.03405190247576684, 0.015352123427874176, 0.026263997715432197, 0.05958065819868352, 0.09749292716151103, 0.006995022940827766, 0.022400362067855895, 0.07192278557340614, 0.2869966998696327, 72.7951942384243, 120.33418491482735, 96.74034655094147, 102.66409948468208, 67.90650576353073, 49.570958241820335, 42.30265885591507, 60.875936821103096, 66.89661875367165, 50.90189382433891, 4.283714862540364, 0.2035625433200039, 0.33245606522541493, 0.6058146141003817, 0.24600905628176406, 0.3365944290999323, 0.21070972230518237, 0.3838613396510482, 0.2627210196806118, 0.8023967687040567, 17.907523289322853, 119.53401625156403, 100.305505245924, 109.30197849869728, 102.87426620721817, 108.07337522506714, 107.13218852877617, 104.21349674463272, 100.96387311816216, 100.92166498303413, 104.07557174563408, 96.01657658815384, 98.92045676708221, 92.93577030301094, 78.40262934565544, 72.07609042525291, 66.61398231983185, 65.42666763067245, 68.22249680757523, 66.53977230191231, 66.1163230240345, 66.82553216814995, 67.42963895201683, 69.418376237154, 67.15492129325867, 69.77615743875504, 66.07777789235115, 68.06173503398895, 76.94837898015976, 80.18898949027061, 80.42431086301804, 76.22302070260048, 73.49951684474945, 69.9941897392273, 69.309291690588, 74.66346278786659, 74.49928119778633, 78.5554951429367, 82.40224912762642, 86.47312268614769, 87.86064863204956, 89.44645553827286, 83.55272099375725, 85.41879326105118, 77.0134998857975, 81.86026141047478, 77.55715191364288, 91.22057273983955, 61.54877811670303, 60.277430936694145, 92.64913648366928, 77.1145136654377, 81.12981900572777, 77.72176668047905, 83.53474795818329, 80.90756893157959, 81.44888028502464, 73.66464078426361, 73.58139485120773, 70.30068889260292, 70.90563163161278, 66.54509201645851, 72.14098334312439, 70.68178564310074, 71.97022050619125, 67.11658895015717, 64.29983049631119, 63.84105831384659, 67.3088738322258, 64.66872990131378, 71.25135228037834, 72.982387393713, 78.74253630638123, 80.56492611765862, 83.92092883586884, 80.59740677475929, 79.35287475585938, 76.12627789378166, 75.80119773745537, 78.40503081679344, 85.21910637617111, 79.04361695051193, 77.43267059326172, 82.08167552947998, 76.75862476229668, 80.62015995383263, 87.48898297548294, 84.56341356039047, 89.01984483003616, 86.18746921420097, 88.40243875980377, 13.529114183038473, 0.7087421254254878, 0.251083075418137, 0.2324377282639034, 0.15193851344520226, 0.043182582448935136, 0.26009387627709657, 0.007940985706227366, 0.13989880011649802, 0.10508243358344771, 0.22564222337678075, 16.01177081465721, 28.16512417048216, 32.373924627900124, 25.3739782422781, 33.55291396379471, 33.84038753807545, 63.53542931377888, 71.72865986824036, 91.22950226068497, 93.59506532549858, 42.78102658689022, 0.3723667486337945, 0.1342232257593423, 0.028482794768933672, 0.060669685699394904, 0.032773961283965036, 0.00475557701975049, 0.0404551414976595, 0.0389856037509162, 0.004158595284025068, 0.011953492467000615, 0.01416037619492272, 0.01537182002721238, 0.05560305835388135, 0.004719791586467181, 0.0477933344518533, 0.028972445252293255, 0.01027804955811007, 0.010903847960435087, 0.021844686416443437, 0.012802656910935184, 0.021656102981069125, 0.124466084089363, 0.023187003353086766, 0.10645418966305442, 0.21772758947918192, 0.10446512256748974, 0.1343711803201586, 0.11154630235978402, 0.14043219649465755, 0.11369432264473289, 0.11383465534891002, 0.27948569040745497, 0.1417910392046906, 0.2562858274905011, 0.20458817656617612, 0.18481175182387233, 0.134445276344195, 0.1818801200715825, 0.19531121186446398, 0.09943256722181104, 0.10419129976071417, 0.18797102995449677, 0.4786839452572167, 86.8561041355133, 138.87888461351395, 110.97937569022179, 120.86565479636192, 84.17306050658226, 65.51103830337524, 71.22800633311272, 142.88985818624496, 105.45872792601585, 69.05149072408676, 6.730337552726269, 0.5095927929505706, 0.6790707050822675, 0.5745149217545986, 0.42386401968542486, 0.5584078235551715, 0.2963438123697415, 0.9832008637022227, 0.5545680702198297, 1.331125928554684, 20.416310168802738, 124.42642092704773, 101.06399014592171, 113.84948328137398, 108.32271784543991, 114.93190839886665, 112.76993080973625, 109.17280063033104, 105.85394471883774, 107.64361828565598, 106.43726661801338, 101.22201606631279, 106.28706067800522, 97.58144661784172, 82.19911202788353, 77.38246008753777, 73.02138090133667, 70.2877239882946, 74.07362043857574, 71.41119450330734, 70.51646411418915, 69.75832119584084, 72.22029268741608, 70.57629570364952, 70.1062761247158, 71.90367087721825, 69.28566455841064, 71.897112429142, 79.88513499498367, 84.55275133252144, 82.76538044214249, 80.1970374584198, 80.50911471247673, 71.86727643013, 74.31746855378151, 78.47243160009384, 78.39487016201019, 82.76761472225189, 88.28892365098, 89.16278555989265, 92.31932938098907, 94.19330522418022, 86.79501101374626, 91.12135246396065, 82.96683803200722, 85.09968638420105, 84.12736415863037, 96.40449777245522, 66.25837460160255, 65.68563133478165, 95.05619332194328, 82.25243836641312, 85.53964957594872, 81.4388944208622, 87.5597807765007, 85.0689460337162, 85.78101262450218, 79.63801145553589, 78.34621757268906, 74.28962364792824, 72.94083282351494, 70.97679421305656, 75.39016619324684, 74.59967941045761, 73.70702371001244, 70.84513127803802, 68.13907608389854, 67.53624603152275, 70.81936866044998, 68.2655180990696, 75.28838485479355, 77.52314373850822, 83.71026813983917, 87.31300681829453, 88.25249120593071, 84.1402530670166, 82.19245478510857, 81.99858158826828, 79.60139662027359, 83.71940284967422, 89.81014162302017, 82.95652538537979, 77.82132133841515, 87.46719494462013, 81.80902495980263, 84.8562790453434, 93.52427512407303, 87.51751944422722, 94.00585368275642, 91.5047898888588, 89.53516557812691, 12.43994252756238, 2.305709389038384, 1.0878148907795548, 0.4965444712433964, 0.6014775624498725, 0.46960771665908396, 0.4954926995560527, 0.16119548468850553, 0.29585663694888353, 0.12655384198296815, 0.7281735702417791, 26.045094430446625, 44.94791731238365, 69.16749849915504, 58.2462727278471, 39.97836157679558, 36.252954080700874, 72.78367325663567, 83.78401458263397, 100.96904084086418, 109.4806981086731, 45.97754426300526, 0.6784841709304601, 0.19920701219234616, 0.24907838611397892, 0.11346304716425948, 0.2600304374936968, 0.10124322201590985, 0.1881190438871272, 0.22941215545870364, 0.12745282030664384, 0.11262856147368439, 0.18023249285761267, 0.17261663277167827, 0.09869719535345212, 0.12516479386249557, 0.1325825450476259, 0.13247561641037464, 0.1066249875293579, 0.13157800363842398, 0.15342739527113736, 0.18610363797051832, 0.15516669256612659, 0.27692507312167436, 0.09420161353773437], [0.04800733644515276, 0.01850522410677513, 0.03457920582150109, 0.05546962762309704, 0.035415160964475945, 0.054552295987377875, 0.07172551529947668, 0.007737806081422605, 0.039772413874743506, 0.013321039641596144, 0.028903681559313554, 0.03591427011997439, 0.031372289231512696, 0.009737394047988346, 0.01588428691320587, 0.03852421425108332, 0.011881226764671737, 0.121298783342354, 0.11301041129627265, 1.9784002960659564, 90.43927386403084, 89.57698613405228, 81.63557946681976, 50.42012147605419, 46.14921145141125, 49.703289940953255, 90.48250034451485, 56.63013204932213, 37.416075468063354, 19.336102232336998, 0.8444260165560991, 0.3297467512311414, 0.11543504486326128, 0.30938165495172143, 0.21915928140515462, 0.23742291232338175, 0.13178182707633823, 0.5951256689149886, 1.5672060730867088, 8.983886428177357, 83.18020418286324, 91.12612500786781, 117.05983981490135, 96.00447043776512, 104.33538660407066, 96.83338835835457, 103.24870571494102, 98.18550020456314, 99.16042909026146, 96.21289685368538, 91.63236424326897, 91.63849711418152, 95.06824627518654, 90.7304598391056, 79.68116194009781, 64.61782023310661, 63.431573286652565, 61.7028446495533, 63.14640998840332, 63.968495875597, 64.47844371199608, 62.854642644524574, 61.603650972247124, 62.81003303825855, 61.90692789852619, 61.88365034759045, 63.0218792706728, 67.09518849849701, 69.63599815964699, 72.39631444215775, 76.96673199534416, 71.53984040021896, 65.67347958683968, 65.51847830414772, 66.34620308876038, 73.79192635416985, 82.43320986628532, 74.76350381970406, 80.4079033434391, 80.9150393307209, 81.62910461425781, 79.74930748343468, 79.24290105700493, 76.11492410302162, 71.364426612854, 74.1126899421215, 73.36813509464264, 83.23463246226311, 61.88470669090748, 56.104521453380585, 86.61955922842026, 69.58809033036232, 74.64582413434982, 74.83038023114204, 81.89392760396004, 74.75297078490257, 75.23613765835762, 70.5625632405281, 70.87258860468864, 63.2739045470953, 64.90000069141388, 60.85366241633892, 66.87568187713623, 63.57282690703869, 69.10727173089981, 66.53861716389656, 65.10583564639091, 56.74790292978287, 60.88352121412754, 61.97128124535084, 68.4767259657383, 68.00404652953148, 75.10693699121475, 75.05079120397568, 77.63619527220726, 75.26942387223244, 76.87794595956802, 70.49068629741669, 75.36538392305374, 76.56798899173737, 79.18126076459885, 75.56449323892593, 83.5886138677597, 73.36747393012047, 78.72050508856773, 83.67193579673767, 81.7577201128006, 76.63007006049156, 81.52622133493423, 80.30288457870483, 90.38940533995628, 67.86093860864639, 1.443823368754238, 0.12581656279508024, 0.27313462807796896, 0.21857777901459485, 0.0979603391897399, 0.6396196782588959, 0.42603509849868715, 0.040860083245206624, 0.16481050086440518, 0.2373925139545463, 2.765607498586178, 19.460140876471996, 57.637465596199036, 89.17563647031784, 49.831172078847885, 27.984561659395695, 24.089191183447838, 57.711725011467934, 60.43716676533222, 72.67114609479904, 61.88375674188137, 3.4323339723050594, 0.29645777656696737, 0.023413705348502845, 0.046338780666701496, 0.08944040964706801, 0.026709965386544354, 0.02023694778472418, 0.08628104245872237, 0.006137333075457718, 0.02158066552510718, 0.054165425535757095, 0.030103756616881583, 0.07695252075791359, 0.06512779276818037, 0.016092884216050152, 0.04832722435821779, 0.025427964646951295, 0.006684727750325692, 0.04300271924876142, 0.058692689635790884, 0.07594745984533802, 0.08577466025599279, 0.04944443120621145, 0.03171315765939653, 0.04596483471686952, 0.02714448914048262, 0.07006714920862578, 0.018667735894268844, 0.023115935291571077, 0.030226144190237392, 0.03717677464010194, 0.041800061517278664, 0.025883136804623064, 0.04687516418925952, 0.06788378785131499, 0.0884815028985031, 0.08957250451203436, 0.04763744262163527, 0.05891855114896316, 0.09066479746252298, 0.10958496190141886, 0.11149136858875863, 4.730641655623913, 111.04794681072235, 101.7566929757595, 96.19529619812965, 68.53331252932549, 68.89489352703094, 59.43739861249924, 55.80410957336426, 54.18525584042072, 47.69344858825207, 21.604614704847336, 0.6715700263157487, 0.21489855222171172, 0.4705187474610284, 0.08686454864800908, 0.7352223701309413, 0.2743644855218008, 0.5369674146641046, 0.8303682552650571, 1.5989923174493015, 12.23798431456089, 100.67465543746948, 99.6675118803978, 120.27648121118546, 102.31204837560654, 111.13813117146492, 101.36083021759987, 108.81369709968567, 102.66650095582008, 102.83319801092148, 99.79762449860573, 95.10519549250603, 94.33667153120041, 99.53267991542816, 95.48054695129395, 83.22044402360916, 68.69498625397682, 68.48370239138603, 65.00330194830894, 67.02039331197739, 68.47100347280502, 68.3078782260418, 68.01501274108887, 64.92494255304337, 64.42601412534714, 65.88632896542549, 65.36534652113914, 66.47782042622566, 69.92024570703506, 72.25097224116325, 76.6459684073925, 79.2633743584156, 75.62907457351685, 68.2583136856556, 69.20828551054001, 71.03408753871918, 77.58698791265488, 84.67170774936676, 77.4153359234333, 82.78235793113708, 84.04945313930511, 82.3934032022953, 82.15599954128265, 82.69272834062576, 79.52047616243362, 77.20533639192581, 77.67367646098137, 76.31833478808403, 87.49386191368103, 64.47662740945816, 59.99404214322567, 90.52786991000175, 73.4974953532219, 74.4778123497963, 75.31464904546738, 84.55012187361717, 76.61491647362709, 79.1992262005806, 73.66387322545052, 74.6259056031704, 66.26697733998299, 68.3131143450737, 63.14286857843399, 69.52561408281326, 65.57915344834328, 71.6770738363266, 69.62939411401749, 67.10254490375519, 61.94584921002388, 63.07628095149994, 64.29150894284248, 71.42083078622818, 72.97188475728035, 80.35159036517143, 80.48000827431679, 81.72036051750183, 77.66936749219894, 80.38441300392151, 73.5560654103756, 79.11653503775597, 81.78230479359627, 82.1680448949337, 79.00293633341789, 83.87372016906738, 78.07121872901917, 82.75731727480888, 85.86134791374207, 86.12006083130836, 82.55840554833412, 83.56953889131546, 83.65966245532036, 92.86437213420868, 74.54166412353516, 3.0564146814867854, 0.46044554735999554, 0.15194716688711196, 0.5915659724269062, 0.03776234028919134, 0.4370177263626829, 0.3255176672246307, 0.2137959434185177, 0.0224206560960738, 0.3110022976761684, 2.462833095341921, 25.551088638603687, 51.294025182724, 36.695151552557945, 35.04888229072094, 35.998580530285835, 41.83245308697224, 67.3123088479042, 67.40836009383202, 77.7176097035408, 83.06893095374107, 7.909925356507301, 0.5268904741387814, 0.13412793399766088, 0.195729679253418, 0.09337359195342287, 0.11160353678860702, 0.07234284115838818, 0.04029848896607291, 0.012749778888974106, 0.03860844059090596, 0.04495796296396293, 0.08090296541922726, 0.03677249711472541, 0.03337629575980827, 0.054852951143402606, 0.053801680405740626, 0.08050011281738989, 0.03745929541764781, 0.04083918065589387, 0.013921674599259859, 0.017457445173931774, 0.051680614924407564, 0.004654629165088409, 0.2075180716929026, 0.1610964970313944, 0.10979754268191755, 0.13108342158375308, 0.1498556908336468, 0.213901536189951, 0.12904707225970924, 0.1762519244221039, 0.1423820262425579, 0.16016450797906145, 0.17354177922243252, 0.19471624691504985, 0.20108004449866712, 0.2320824473281391, 0.17325465712929145, 0.14340083173010498, 0.1682071029790677, 0.23935779521707445, 0.20269077213015407, 4.979846533387899, 130.64045548439026, 115.41939944028854, 114.67042163014412, 79.60503682494164, 69.93863672018051, 69.21567991375923, 127.56190627813339, 77.80715569853783, 62.53416024148464, 30.33529032021761, 0.944466395303607, 0.9495610313024372, 0.4699146095663309, 0.7018714409787208, 0.7617342006415129, 0.7228097424376756, 0.8144528092816472, 1.680933851748705, 2.478398960083723, 10.512974727898836, 103.61762791872025, 100.99712893366814, 122.9909111559391, 106.06003805994987, 112.75905579328537, 106.19662553071976, 112.38405391573906, 105.0521269440651, 107.68565163016319, 101.1834405362606, 98.35810974240303, 100.67491382360458, 101.0631237924099, 99.72168937325478, 86.44372746348381, 72.19187781214714, 72.43884176015854, 70.38641229271889, 70.77000930905342, 73.62849712371826, 71.37292295694351, 71.8394011259079, 68.3749370276928, 69.23144906759262, 69.00855302810669, 69.59309846162796, 71.6543510556221, 73.51116701960564, 76.00004106760025, 79.38002049922943, 81.68562278151512, 79.4287870824337, 73.8528598845005, 73.38847160339355, 73.79309669137001, 82.10052251815796, 87.32829719781876, 81.51123493909836, 86.78662106394768, 88.45218569040298, 89.56601232290268, 88.23230668902397, 86.89018070697784, 82.37853839993477, 81.74344807863235, 80.85528373718262, 81.63748696446419, 89.82301533222198, 70.75780436396599, 65.99523112177849, 93.97708922624588, 78.87368246912956, 81.43523141741753, 82.537552267313, 87.67512738704681, 80.25377601385117, 84.9923725426197, 77.89043962955475, 78.1553766131401, 71.46787226200104, 69.45129007101059, 67.60854095220566, 73.73841762542725, 70.44124335050583, 75.17220228910446, 73.54847341775894, 70.54474979639053, 64.42117318511009, 66.8409213423729, 69.44029346108437, 76.34981229901314, 77.27421909570694, 83.57116520404816, 83.1583097577095, 88.2020603120327, 82.35536724328995, 84.79102894663811, 77.50055775046349, 82.59850099682808, 84.50357437133789, 82.82517403364182, 80.5504184961319, 87.43322476744652, 84.40095707774162, 85.48085153102875, 91.44574105739594, 91.07937231659889, 86.02339401841164, 89.23055112361908, 87.9755012691021, 98.43573197722435, 74.74641233682632, 2.9239034419879317, 0.8516274020075798, 1.1328523303382099, 0.6796957121696323, 0.3253815573407337, 1.207077072467655, 1.1986203887499869, 0.2698726812377572, 0.5035517108626664, 0.4903715243563056, 5.09774518199265, 37.43308335542679, 87.86314129829407, 120.48207297921181, 67.18892186880112, 38.377902656793594, 40.286449044942856, 79.03971835970879, 81.6420391201973, 93.1112676858902, 93.22663709521294, 7.431638371199369, 0.6411911314353347, 0.19770487560890615, 0.3375158499693498, 0.27645499678328633, 0.2210745122283697, 0.18554477108409628, 0.273177464841865, 0.0929499369522091, 0.11373606845154427, 0.1288896330515854, 0.3132852033013478, 0.12088623087038286, 0.19046393368626013, 0.09303379221819341, 0.09026023792102933, 0.12301886643399484, 0.1416792717645876, 0.11923037323867902, 0.12331648991676047, 0.14553042448824272, 0.17373199167195708, 0.14203520579030737], [0.11725860560545698, 0.07298381926375441, 0.018762513718684204, 0.028147989687568042, 0.030605236934206914, 0.11555777382454835, 0.04157425937592052, 0.0627320510102436, 0.03416215593460947, 0.10920550921582617, 0.027285658616165165, 0.06632818694924936, 0.012518258499767398, 0.04346797904872801, 0.03208066176739521, 0.10057533363578841, 0.08058983105001971, 0.10244104094454087, 0.3140684956451878, 14.093085620552301, 101.59887224435806, 83.23226138949394, 74.81325075030327, 57.8373234719038, 26.74783442169428, 49.4971814006567, 109.09983694553375, 48.77957470715046, 39.08869631588459, 1.6554287890903652, 0.08130189205985516, 0.11416512628784403, 0.10852199862711132, 0.20547787804389372, 0.33386225695721805, 0.19254191749496385, 0.9888477763161063, 1.1540263378992677, 2.4912878684699535, 98.87426644563675, 114.07591313123703, 101.77540317177773, 100.36986619234085, 104.54844117164612, 97.98598051071167, 100.78453034162521, 100.00326186418533, 100.30839309096336, 99.87127214670181, 92.70907446742058, 91.07254028320312, 92.4250017106533, 90.66283106803894, 92.0295037329197, 75.87669968605042, 62.74892471730709, 61.73899970948696, 63.357587456703186, 60.62677659094334, 63.84973704814911, 61.048690751194954, 62.71465055644512, 64.71403107047081, 63.17549742758274, 60.67609414458275, 59.736336171627045, 64.33962196111679, 66.87094733119011, 67.74708151817322, 71.39182314276695, 73.66666987538338, 68.8337092101574, 64.29908573627472, 66.25365525484085, 70.86095362901688, 72.86724597215652, 78.73469352722168, 89.99744117259979, 77.97816932201385, 79.57174301147461, 76.0643944144249, 82.5165393948555, 74.1335280239582, 76.90979585051537, 70.54097279906273, 78.00783053040504, 71.62225797772408, 84.53010454773903, 52.63009808957577, 54.85364377498627, 89.6949090063572, 68.68819981813431, 74.54072177410126, 73.10008227825165, 78.94166842103004, 74.23876717686653, 71.06947883963585, 64.44709539413452, 63.1168095767498, 61.06343016028404, 65.46213492751122, 62.51695096492767, 62.2604875266552, 64.47085931897163, 69.5548041164875, 68.77389281988144, 64.42594572901726, 57.3553117364645, 58.61510753631592, 59.99977603554726, 63.90181705355644, 70.9628413617611, 75.59898778796196, 76.29384130239487, 76.17961183190346, 74.80017945170403, 73.65540727972984, 73.14695656299591, 73.38347107172012, 84.52372089028358, 81.22438073158264, 81.34614899754524, 77.58807465434074, 80.89005947113037, 80.19427120685577, 81.46031767129898, 82.32919424772263, 81.27578437328339, 74.17407184839249, 80.24995341897011, 77.07368105649948, 95.17787039279938, 36.501901522278786, 0.5713101499713957, 0.2466176322195679, 0.1379756283131428, 0.026755831968330313, 0.12880599300842732, 0.15469033765839413, 0.24485623376676813, 0.15940481593133882, 0.016905786396819167, 0.068978166236775, 6.313744056969881, 25.342107452452183, 60.197468027472496, 60.64095363020897, 28.076927103102207, 20.14739479869604, 29.988042153418064, 55.96641406416893, 63.223564848303795, 80.8838278055191, 24.64839957654476, 0.42407084139995277, 0.18580139090772718, 0.09264593842090108, 0.022140413711895235, 0.06073650125472341, 0.08689243855769746, 0.08664831650094129, 0.08628458250313997, 0.02543043785408372, 0.01901635234389687, 0.036987512139603496, 0.06729475266183726, 0.0825697771506384, 0.048459612371516414, 0.024965430384327192, 0.030097880662651733, 0.06932728734682314, 0.0360166716563981, 0.0730153160111513, 0.03757125210540835, 0.05212807431234978, 0.094019817042863, 0.007892914018157171, 0.039574100883328356, 0.016743220803618897, 0.06886098111863248, 0.03414300852455199, 0.049838815903058276, 0.0049817224044090835, 0.026525046305323485, 0.0902887289703358, 0.06387851331965066, 0.017859579747891985, 0.04335455290856771, 0.021489190257852897, 0.03230198875826318, 0.01809936024073977, 0.1449703107937239, 0.04479625269595999, 0.13588634901680052, 0.5823151906952262, 20.541692040860653, 123.74720737338066, 93.38081762194633, 91.66473850607872, 68.71853739023209, 41.03394113481045, 31.875672563910484, 86.09566614031792, 54.96503859758377, 46.00032024085522, 1.8327560112811625, 0.1575736259110272, 0.07604632875882089, 0.23646886664209887, 0.3036129113752395, 1.4284670865163207, 0.7104315503966063, 1.4047326100990176, 1.149094202555716, 4.468090469017625, 108.36842939257622, 112.58319362998009, 108.09043630957603, 101.3498792052269, 107.73691847920418, 101.68812945485115, 104.27592739462852, 100.52183523774147, 100.94248026609421, 103.48560020327568, 96.7524603009224, 93.84223446249962, 97.37280741333961, 93.05814653635025, 94.6855080127716, 78.82531106472015, 67.8013426065445, 66.43371239304543, 67.1789588034153, 65.06188720464706, 67.22971647977829, 64.9602198600769, 66.64419069886208, 66.13667473196983, 67.17666372656822, 62.78530776500702, 63.46509888768196, 68.05296510457993, 71.69016793370247, 72.62554854154587, 74.51038420200348, 75.63696295022964, 71.1807444691658, 65.95177665352821, 70.4810956120491, 72.22265616059303, 76.73980817198753, 81.5786737203598, 90.61116144061089, 81.28044292330742, 83.59922289848328, 80.70155158638954, 84.85947847366333, 77.04533457756042, 79.82308432459831, 74.71273094415665, 80.2742113173008, 76.94430559873581, 88.43618854880333, 54.97254699468613, 59.29290756583214, 92.30808198451996, 73.99997279047966, 77.85324722528458, 75.16240641474724, 80.20755529403687, 76.314876973629, 74.9703799188137, 66.53577491641045, 66.01888865232468, 64.60299342870712, 67.73135796189308, 65.48483490943909, 64.22739878296852, 66.76605015993118, 71.2923064827919, 70.66559091210365, 67.98041179776192, 60.77068626880646, 62.16743431985378, 63.41664008796215, 67.74525001645088, 74.01625871658325, 77.59437471628189, 79.18089598417282, 81.16415396332741, 78.37393328547478, 77.15710937976837, 75.05078360438347, 78.53718772530556, 85.13576164841652, 81.67518854141235, 82.62384563684464, 80.87154686450958, 83.17912504076958, 83.9081235229969, 85.63470527529716, 83.94248127937317, 84.24608498811722, 79.02983129024506, 82.23762676119804, 79.73863005638123, 99.02166813611984, 45.620112642645836, 0.33425696077756584, 0.24893991620047018, 0.26296946103684604, 0.6045022001489997, 0.5932006565853953, 0.12524436693638563, 0.3484786773333326, 0.3120257193222642, 0.023475572634197306, 0.15096837800228968, 5.378547739237547, 32.864983677864075, 54.48949031531811, 39.90484692156315, 29.894513972103596, 30.25374099612236, 37.05762170255184, 67.21267819404602, 71.89590409398079, 93.0456680059433, 37.73973070085049, 0.22525673703057691, 0.27641498018056154, 0.045747927215415984, 0.01884502940811217, 0.07893409216194414, 0.07745776005322114, 0.07991438018507324, 0.05030384192650672, 0.03513003895932343, 0.02936478347692173, 0.01549077238450991, 0.0921183975879103, 0.06089997783419676, 0.06386827168171294, 0.006918088201928185, 0.03949869496864267, 0.03714896636665799, 0.06275755862588994, 0.016310249993694015, 0.026010979163402226, 0.04237800902046729, 0.0870494547416456, 0.20238466589944437, 0.14874661050271243, 0.07339685413171537, 0.16857816197443753, 0.18570595071651042, 0.33606462471652776, 0.10405167951830663, 0.1312102991505526, 0.3692753176437691, 0.1870232925284654, 0.0938151623995509, 0.16476450255140662, 0.1322044208063744, 0.18473778938641772, 0.09779092171811499, 0.2670067147118971, 0.2370492261252366, 0.24086165358312428, 0.7923347305040807, 25.365476198494434, 144.04330909252167, 108.45643267035484, 107.1064867079258, 76.83947682380676, 45.51711916923523, 67.80170738697052, 144.08044070005417, 70.06235048174858, 65.75292572379112, 2.900439463555813, 0.23133169073844329, 0.2818686672253534, 0.28956948837731034, 2.269525593146682, 2.4541771598160267, 0.9772692038677633, 3.1691631814464927, 2.4548117257654667, 3.5754053201526403, 108.20109397172928, 115.45929729938507, 111.96355327963829, 108.20123836398125, 111.96883499622345, 107.83344849944115, 107.52821087837219, 108.27175498008728, 108.28715175390244, 105.57383894920349, 101.97651118040085, 100.59750437736511, 99.26436871290207, 98.28753232955933, 99.11208808422089, 86.37153133749962, 71.79911568760872, 71.12780570983887, 70.81109270453453, 70.62539666891098, 71.67619988322258, 69.72164556384087, 69.9315994977951, 70.29258772730827, 69.70527604222298, 67.73321226239204, 67.01959535479546, 72.97723487019539, 73.84131610393524, 76.23394891619682, 79.62126955389977, 81.87688171863556, 74.11687731742859, 70.49998819828033, 72.78105139732361, 77.99866542220116, 80.63978970050812, 90.50928890705109, 87.79025360941887, 84.25517410039902, 86.43553510308266, 84.88112211227417, 87.85101234912872, 81.4034803211689, 83.25358584523201, 79.24748361110687, 83.91134575009346, 80.92097461223602, 91.9673390686512, 59.42704796791077, 62.71835155785084, 97.58985176682472, 77.39224076271057, 82.30247408151627, 78.72375771403313, 83.84765356779099, 82.45331838726997, 79.47821483016014, 68.553307056427, 69.74545508623123, 68.534095287323, 71.9635708630085, 69.71235126256943, 68.33500877022743, 69.49418976902962, 73.62577646970749, 73.60328167676926, 69.65777859091759, 63.690886572003365, 64.38547030091286, 67.35271587967873, 70.48099681735039, 76.45237639546394, 83.71583104133606, 82.75268912315369, 85.11090338230133, 82.38398730754852, 82.14328542351723, 80.01544520258904, 82.51016333699226, 90.12131452560425, 83.1556499004364, 87.4395552277565, 85.22447168827057, 87.24654838442802, 87.1720039844513, 89.69755366444588, 90.10629013180733, 87.3547513782978, 82.1920596063137, 87.11384430527687, 83.39107006788254, 104.33767408132553, 43.828250393271446, 0.9997626906260848, 1.1308520939201117, 0.3238094807602465, 0.633747746469453, 1.1015999573282897, 0.7755551277659833, 0.7739651505835354, 0.38858991872984916, 0.1900936762103811, 0.23213882086565718, 9.889935459941626, 43.79668168723583, 85.57760193943977, 84.42716047167778, 39.6428319811821, 30.889150500297546, 45.37317909300327, 79.55103412270546, 81.73030838370323, 110.33018052577972, 38.02693448960781, 0.4375065938802436, 0.32074461865704507, 0.12049210592522286, 0.1661994302412495, 0.16109529475215822, 0.16902610746910796, 0.22547846107045189, 0.1647985671297647, 0.12336669620708562, 0.17511885787826031, 0.13476668565999717, 0.1767303276574239, 0.2626176830381155, 0.2125800383510068, 0.08738944001379423, 0.1072237448533997, 0.16104466543765739, 0.15188717166893184, 0.18930043908767402, 0.0805232604034245, 0.1324780358118005, 0.20883044111542404], [0.026495230522414204, 0.03434223064687103, 0.02060241840808885, 0.05010754757677205, 0.08832132516545244, 0.04556691739708185, 0.038082951796241105, 0.03636032313806936, 0.04202165197057184, 0.10819465212989599, 0.046175274401321076, 0.03285738239355851, 0.07717774031334557, 0.10823454256751575, 0.10952722281217575, 0.03150071046547964, 0.03720680564583745, 0.2695735660381615, 0.1781039687921293, 31.671182736754417, 93.78609627485275, 81.87638014554977, 82.32229381799698, 76.95041567087173, 61.31619639694691, 97.89535537362099, 93.41233313083649, 52.099137380719185, 12.227777112275362, 0.44020005560014397, 0.18799777695676312, 0.02662441060238052, 0.20798672310775146, 0.2015716876485385, 0.3330104792257771, 1.001529002096504, 0.75489058974199, 0.5311349651310593, 80.64355909824371, 111.44007056951523, 93.73363628983498, 97.68122166395187, 91.35551869869232, 94.40032571554184, 94.8316253721714, 94.54505234956741, 93.3228251338005, 101.31603062152863, 88.20932552218437, 87.07007065415382, 87.33689993619919, 86.7489042878151, 88.13430994749069, 83.24276402592659, 68.04769858717918, 63.70966136455536, 64.18491706252098, 62.14880391955376, 62.96147771179676, 61.04025900363922, 62.99900069832802, 61.97261497378349, 60.22918492555618, 62.58925348520279, 57.007128819823265, 60.72851613163948, 63.146242797374725, 68.7303015589714, 75.62953814864159, 76.86238959431648, 72.79183521866798, 65.8685003221035, 60.83804525434971, 65.2252784371376, 66.6686537861824, 74.7809448838234, 70.55714473128319, 78.406543135643, 86.91976591944695, 76.50702506303787, 76.5255680680275, 74.8534981906414, 71.87540039420128, 75.150026679039, 72.33117073774338, 73.60373765230179, 70.85017740726471, 82.50304251909256, 53.334633484482765, 53.265260607004166, 88.12956780195236, 67.67356306314468, 72.07879588007927, 69.09116819500923, 76.30078732967377, 68.03349494934082, 68.32778915762901, 56.94409020245075, 62.02204272150993, 60.16860477626324, 56.90805673599243, 55.03319934010506, 61.712583526968956, 59.9902081489563, 69.34940993785858, 66.76139920949936, 67.27779909968376, 60.7398547232151, 58.757067918777466, 57.65949301421642, 64.17864739894867, 66.05920448899269, 72.81325086951256, 72.6503612101078, 74.81941401958466, 73.57213094830513, 74.36079382896423, 69.00340050458908, 80.63203051686287, 74.20000165700912, 79.08367440104485, 79.79286834597588, 76.93449452519417, 76.87334060668945, 79.8216100037098, 81.1758041381836, 81.44702598452568, 74.30882781744003, 78.5889333486557, 72.05674186348915, 81.21309533715248, 79.43068698048592, 85.11047780513763, 7.334539806470275, 0.792908143484965, 0.041482392625766806, 0.09520796578726731, 0.04254250234225765, 0.23214593064039946, 0.03319364208437037, 0.3202717815292999, 0.05103762559883762, 0.057346789981238544, 0.3029918821994215, 17.567490935325623, 29.286035522818565, 60.3171806037426, 55.91128662228584, 36.19433082640171, 38.92779774963856, 51.96615591645241, 63.468712493777275, 69.90146711468697, 57.67879597842693, 1.8442091904580593, 0.1530972434557043, 0.039809087102185, 0.03761002932151314, 0.094737644540146, 0.09024447470437735, 0.03910935687599704, 0.036920436832588166, 0.040371505165239796, 0.014775091549381614, 0.023495432506024372, 0.0276217680220725, 0.06139188444649335, 0.07001969628618099, 0.08708622815902345, 0.08667854417581111, 0.02462277523591183, 0.10231704291072674, 0.03349249382154085, 0.008867910528351786, 0.09721195747260936, 0.039043643409968354, 0.04246337084623519, 0.07700378831941634, 0.027718328856281005, 0.06618832921958528, 0.06590970471734181, 0.02097467968269484, 0.05119182533235289, 0.04423529295308981, 0.06419489829568192, 0.10335300685255788, 0.057967696702689864, 0.031271438783733174, 0.10337892264942639, 0.17287062539253384, 0.09504323868895881, 0.10014118466642685, 0.025771803520910908, 0.06203727090905886, 0.08482485223794356, 50.461155474185944, 111.746356934309, 95.65232813358307, 95.342538356781, 91.87174379825592, 60.21259121596813, 68.8202503323555, 99.83796313405037, 54.37178783118725, 13.75321190804243, 0.5401740269735456, 0.13682161836186424, 0.532748275436461, 0.3177716344362125, 0.5007037636823952, 0.7037304912228137, 1.6019434528425336, 0.492204183829017, 1.7923181061632931, 94.9153120815754, 114.00803357362747, 103.3681333065033, 100.4105544090271, 97.78491050004959, 98.08729067444801, 100.05470350384712, 98.05651232600212, 96.48807048797607, 102.7389706671238, 92.79334634542465, 88.92157450318336, 92.77853474020958, 90.96575081348419, 94.18499127030373, 84.93570238351822, 71.49436444044113, 67.72678300738335, 68.66870686411858, 64.9127984046936, 66.00753486156464, 64.77615013718605, 67.06682682037354, 66.72856137156487, 66.59315943717957, 65.43036863207817, 61.975138038396835, 64.25899788737297, 66.66681468486786, 70.73935255408287, 80.04981055855751, 79.44323390722275, 75.33911973237991, 68.39897453784943, 65.28295174241066, 67.73676127195358, 71.03934645652771, 76.80328756570816, 75.05280509591103, 78.8933578133583, 85.6691238284111, 78.27305629849434, 81.25514388084412, 78.01590889692307, 77.24894285202026, 78.19564685225487, 76.0339580476284, 78.18159520626068, 75.47381490468979, 84.28867310285568, 54.920983761548996, 57.93363690376282, 90.69215029478073, 71.13458454608917, 75.73804512619972, 71.36508777737617, 76.7361831665039, 70.12458354234695, 69.4797733426094, 61.311940625309944, 66.01336374878883, 62.652679681777954, 60.13310328125954, 58.4363879263401, 64.50385674834251, 63.91919732093811, 73.42261657118797, 69.67994660139084, 70.7868880033493, 63.44306007027626, 63.74060310423374, 61.0288330167532, 66.3559153676033, 71.03521227836609, 76.08453333377838, 75.04696860909462, 79.23819690942764, 73.83405089378357, 77.0004589855671, 72.48627841472626, 82.71284446120262, 77.42260113358498, 82.31593295931816, 83.65847691893578, 80.9303905069828, 78.43093782663345, 83.53976368904114, 82.18556195497513, 84.43235099315643, 79.53024163842201, 81.3543489575386, 76.07033729553223, 84.87139463424683, 81.6168312728405, 94.73299786448479, 10.877319127321243, 1.1342365248128772, 0.25177493516821414, 0.9139438800048083, 0.5742757127154619, 1.2102078669704497, 0.23240728536620736, 1.1772961704991758, 0.07981891772942618, 0.12817280745366588, 0.33486142521724105, 17.759329341351986, 36.079204604029655, 40.96432127058506, 29.290399588644505, 39.666736498475075, 47.197749987244606, 59.77483570575714, 71.61414161324501, 78.78124102950096, 76.69050961732864, 4.192371089011431, 0.17398500465787947, 0.06816073509980924, 0.00789279249147512, 0.02743674132943852, 0.0762428568850737, 0.011675737205223413, 0.06163443686091341, 0.058809422043850645, 0.032368325628340244, 0.034154860622948036, 0.05499586281075608, 0.029385355810518377, 0.0626513127645012, 0.050990005693165585, 0.034941592821269296, 0.035921609960496426, 0.028066218001185916, 0.02594924360892037, 0.02983508245961275, 0.054346810138667934, 0.02954882125777658, 0.18788765708450228, 0.15821862645680085, 0.11340161217958666, 0.16484860272612423, 0.17188968427944928, 0.08544659387553111, 0.15937156771542504, 0.08352797143743373, 0.18807404005201533, 0.25954777433071285, 0.1447343672043644, 0.12207823878270574, 0.2757375774672255, 0.22325743571855128, 0.3124032646883279, 0.24480576772475615, 0.2174347231630236, 0.42546159646008164, 0.29594803985673934, 60.26642292737961, 133.96456271409988, 109.26038593053818, 112.31880381703377, 95.46597093343735, 78.1344473361969, 137.2134491801262, 113.98433044552803, 70.52733153104782, 20.04269141703844, 0.7849129568785429, 0.5795786844100803, 0.5110379622783512, 0.9207058546599001, 1.4020075625739992, 1.0787299345247447, 4.524005893617868, 4.842329537495971, 1.9954593619331717, 95.60747534036636, 117.16300427913666, 106.82271033525467, 104.95238229632378, 101.83831259608269, 103.3025336265564, 101.5848357975483, 104.16655406355858, 101.8667958676815, 102.67163068056107, 101.21904462575912, 94.93297353386879, 96.44232094287872, 97.71471306681633, 96.44990533590317, 91.51912271976471, 76.29337012767792, 72.68632248044014, 73.33126187324524, 69.46516692638397, 70.48360347747803, 68.43998953700066, 69.33893010020256, 69.83494028449059, 70.24211883544922, 71.67037859559059, 66.76798045635223, 67.95805379748344, 72.19543442130089, 73.54361727833748, 84.49573919177055, 81.31784051656723, 79.79720011353493, 70.5341711640358, 69.16090205311775, 71.86489775776863, 75.78285232186317, 79.62461337447166, 79.2417611181736, 81.53040871024132, 88.06004673242569, 84.94285359978676, 84.20369446277618, 83.80664616823196, 80.47715842723846, 81.93292871117592, 81.60151809453964, 80.8227650821209, 78.69918823242188, 87.6464769244194, 60.099220499396324, 62.23629042506218, 95.3008621931076, 75.20978227257729, 80.00607490539551, 74.92111176252365, 82.47172459959984, 76.04902043938637, 76.29744350910187, 65.09869202971458, 69.37877476215363, 66.59556850790977, 65.25656595826149, 61.91617280244827, 68.7152087688446, 67.42333129048347, 76.36957123875618, 74.04638350009918, 72.893897742033, 66.69670388102531, 67.6622624695301, 64.32997807860374, 70.54876238107681, 75.29627323150635, 80.96964240074158, 80.31166970729828, 83.15572589635849, 79.27010759711266, 80.7903528213501, 76.75866276025772, 86.89844146370888, 81.08445703983307, 88.37338551878929, 86.81933730840683, 85.21375626325607, 82.53148019313812, 87.78169646859169, 85.92647641897202, 88.03950503468513, 83.8304252922535, 88.00576284527779, 79.4842641055584, 89.72066402435303, 86.15728363394737, 96.2690882384777, 10.079961363226175, 2.919184807687998, 2.5176921766251326, 0.7391573558561504, 0.4606469365535304, 1.8668836425058544, 0.625006256159395, 1.6929987980984151, 0.15110101463505998, 0.1781067592673935, 1.0262380074709654, 30.294955484569073, 45.65665528178215, 86.38569697737694, 72.54251539707184, 50.587760880589485, 56.05062134563923, 71.39611691236496, 84.69851151108742, 92.34991773962975, 89.85170379281044, 3.6467417422682047, 0.42277362663298845, 0.1695363488397561, 0.2061915717786178, 0.19394750066567212, 0.3333464643219486, 0.20392469654325396, 0.19512613507686183, 0.1978599399444647, 0.15187149751000106, 0.14573375810869038, 0.15981620323145762, 0.10541635550907813, 0.14037148881470785, 0.1225570056703873, 0.17724281031405553, 0.12139188576838933, 0.19802831840934232, 0.10143163846805692, 0.08214547648094594, 0.14255171088734642, 0.1568337788921781], [0.05916016103583388, 0.007317034323932603, 0.019698256182891782, 0.0557972116075689, 0.048172330716624856, 0.023818190675228834, 0.031029522760945838, 0.09638967268983833, 0.04955595373758115, 0.08326954077347182, 0.07028862091829069, 0.014167214158078423, 0.0921394003671594, 0.0702930441184435, 0.026495575621083844, 0.04600092535838485, 0.030773986472922843, 0.06755280483048409, 1.0889824968762696, 78.85200083255768, 91.81600078940392, 80.49351274967194, 53.54076862335205, 40.555486008524895, 28.54727726429701, 49.31734465062618, 59.20573644340038, 36.94766700267792, 0.3960771200945601, 0.17475418135290965, 0.13643461803440005, 0.2917851851088926, 0.305019281222485, 0.27538143564015627, 1.2627478851936758, 1.433402665425092, 1.4042629790492356, 41.12576700747013, 119.85282674431801, 91.27467423677444, 105.81368207931519, 87.98069939017296, 90.77048689126968, 88.82377535104752, 92.66987577080727, 93.06541174650192, 99.1694650053978, 86.84005379676819, 86.80579483509064, 84.85570147633553, 79.06257793307304, 80.5334410071373, 73.99551942944527, 63.88313725590706, 63.290965631604195, 63.13075102865696, 65.71737483143806, 61.24054245650768, 63.277305364608765, 61.93817362189293, 62.17483252286911, 60.9192468971014, 63.19242551922798, 58.071755692362785, 57.51856617629528, 61.79098851978779, 63.45983237028122, 73.24206545948982, 80.66442757844925, 77.9877296090126, 69.68109413981438, 61.11334428191185, 59.948957562446594, 64.43194940686226, 67.20163598656654, 71.10095635056496, 80.99125564098358, 75.14502614736557, 78.68213474750519, 82.53254413604736, 75.39271205663681, 78.1117245554924, 74.89234730601311, 74.65865984559059, 72.35942602157593, 77.37747475504875, 71.40854984521866, 84.24897283315659, 47.21454128623009, 56.08600504696369, 82.83914968371391, 70.2914097905159, 69.49303463101387, 63.47784720361233, 70.15346959233284, 63.87597844004631, 60.575152561068535, 57.17534959316254, 56.499392464756966, 55.179069712758064, 55.175391510128975, 55.63420169055462, 58.093843907117844, 60.22333703935146, 67.36264854669571, 69.00857582688332, 64.47704538702965, 60.624040737748146, 58.63863207399845, 55.30324324965477, 60.27939163148403, 61.37347832322121, 65.70568665862083, 67.12031275033951, 71.08528599143028, 69.54019010066986, 68.90443861484528, 69.8221729695797, 79.44981515407562, 75.89108571410179, 77.47020497918129, 75.80007299780846, 71.11338168382645, 74.22762617468834, 79.73486825823784, 78.94978478550911, 80.50412178039551, 76.69876277446747, 74.26169514656067, 72.56659090518951, 75.90270549058914, 78.3754152059555, 85.8779302239418, 60.460698902606964, 0.2377830320619978, 0.8287842152640224, 0.5799369339365512, 0.39961841132026166, 0.04902994915028103, 0.3823496145196259, 0.3308873134665191, 0.4420344962272793, 0.05642295342113357, 0.24586172512499616, 4.131055204197764, 22.675777226686478, 38.280464485287666, 86.83984860777855, 28.51216334849596, 29.109136015176773, 53.0196949839592, 61.68976195156574, 62.03637175261974, 76.27709180116653, 17.641919441521168, 0.3457814158173278, 0.12816635076887906, 0.03365631178894546, 0.03924196382286027, 0.05572126763581764, 0.07351966472924687, 0.021489960236067418, 0.03614465873397421, 0.03893949411576614, 0.061733064576401375, 0.024654817461851053, 0.039257990501937456, 0.0725219065498095, 0.046009734651306644, 0.03257585609389935, 0.04457196453586221, 0.05512137482583057, 0.02696064802876208, 0.023568548895127606, 0.047820920080994256, 0.04540772300970275, 0.019100339341093786, 0.06303124784608372, 0.02192085488786688, 0.059583174079307355, 0.0026211396607322968, 0.03419803877477534, 0.025491082451480906, 0.045175527266110294, 0.05328977662429679, 0.05276087766105775, 0.013795280356134754, 0.031600815054844134, 0.09909621105180122, 0.030092373926891014, 0.07350543775828555, 0.04859791530179791, 0.04668892222980503, 0.16663898946717381, 3.1557876616716385, 101.30140900611877, 104.83493819832802, 91.80547535419464, 67.79804438352585, 55.17337381839752, 33.73765625059605, 62.21148155629635, 65.15448823571205, 38.12200918793678, 0.3436991572380066, 0.28104004450142384, 0.4168642609147355, 0.44396111159585416, 0.8743584947660565, 0.4447448195423931, 2.634847015142441, 0.7693925115745515, 1.3066882523708045, 51.55511677265167, 122.05306068062782, 97.36846804618835, 108.4924927353859, 90.36311835050583, 94.7597636282444, 93.73446464538574, 96.74106851220131, 96.7426036298275, 104.66527730226517, 92.86304220557213, 91.25282540917397, 86.99093610048294, 83.2858157157898, 83.56276765465736, 78.5909852385521, 67.32735604047775, 65.4719004034996, 67.92983651161194, 68.65527838468552, 66.05773776769638, 66.23164683580399, 65.18164917826653, 65.40951535105705, 65.08881255984306, 65.03246918320656, 62.17674382030964, 62.79524803161621, 65.4026909172535, 66.80581882596016, 77.57173553109169, 86.54123783111572, 80.89431524276733, 72.45734676718712, 64.45518895983696, 62.61728078126907, 68.63653019070625, 68.83310124278069, 75.20634725689888, 82.26008355617523, 79.21348303556442, 82.49228909611702, 82.76431649923325, 77.93340012431145, 82.75335788726807, 79.43643227219582, 78.26563149690628, 75.29723078012466, 81.30295291543007, 75.27793541550636, 88.4859050810337, 50.99615916609764, 59.578055664896965, 87.1450862288475, 76.64546683430672, 73.64212319254875, 66.03444501757622, 73.69103416800499, 65.88201999664307, 64.11750867962837, 60.235815569758415, 60.119697600603104, 58.05577374994755, 58.8812642544508, 58.76902587711811, 62.43302866816521, 62.74494633078575, 70.88299244642258, 70.75073674321175, 67.95704305171967, 65.58184370398521, 60.2365755289793, 58.86313162744045, 61.29880852997303, 64.74655732512474, 66.64656937122345, 70.05091309547424, 73.28716143965721, 71.75426289439201, 71.10443696379662, 72.55296483635902, 81.89078897237778, 79.1905626654625, 82.517648935318, 78.69823068380356, 73.47538813948631, 77.22631886601448, 81.71151459217072, 82.29713156819344, 84.73122015595436, 80.11598780751228, 77.03859373927116, 76.00370407104492, 79.07757192850113, 83.97923290729523, 86.72414481639862, 73.59378978610039, 0.7330489461310208, 0.8674872166011482, 0.539494160329923, 1.1213900079019368, 0.40760626550763845, 0.6438072316814214, 0.2357717079576105, 1.3557230774313211, 0.6843032024335116, 0.5562471644952893, 3.5482633765786886, 29.015889018774033, 39.42117087543011, 56.603871658444405, 27.474387735128403, 42.391623482108116, 63.46762955188751, 72.71614328026772, 69.80484589934349, 90.56922689080238, 31.912560984492302, 0.3577149426564574, 0.10540911956923082, 0.11363021592842415, 0.05870485714694951, 0.0267569192146766, 0.03303115998278372, 0.03822638296696823, 0.08137793993228115, 0.03289125772425905, 0.015063025366544025, 0.04693193477578461, 0.02265517476189416, 0.02227508939540712, 0.03877529023156967, 0.03165677670040168, 0.0462959327705903, 0.006829766598457354, 0.03289581451099366, 0.03706765295646619, 0.06415016163373366, 0.04834173705603462, 0.10599344954243861, 0.14234448841307312, 0.2029168006265536, 0.08840188529575244, 0.10955589939840138, 0.13762965390924364, 0.20067834964720532, 0.1666530012153089, 0.22023150668246672, 0.15767353383125737, 0.12494341121055186, 0.11215556107345037, 0.16685829410562292, 0.10063596710097045, 0.14945950271794572, 0.09429901299881749, 0.14034349500434473, 0.43310761742759496, 4.296472677960992, 117.44231209158897, 118.98554608225822, 108.62813025712967, 78.16105350852013, 59.70023810863495, 42.232381626963615, 73.90004575252533, 70.8636362850666, 58.72224658727646, 0.9395727328956127, 0.3837487706914544, 0.8952317840885371, 1.084185135550797, 1.1489641782827675, 0.7697215501684695, 6.552340378984809, 9.432893134653568, 3.263851488009095, 51.35000757873058, 128.4238824248314, 99.42917346954346, 113.08453872799873, 96.49293422698975, 98.9429135620594, 97.9631133377552, 104.26628351211548, 99.09172877669334, 105.14772981405258, 101.23765602707863, 97.3839408159256, 92.20925688743591, 86.23246639966965, 88.52782443165779, 85.26693060994148, 69.96157988905907, 70.49415171146393, 70.57712405920029, 71.83667287230492, 68.062464594841, 70.90509966015816, 68.77230450510979, 69.51253518462181, 69.07986760139465, 68.888418674469, 65.8151663839817, 65.162672996521, 70.60196712613106, 70.69210588932037, 79.83306258916855, 88.34339752793312, 86.84602707624435, 75.90031161904335, 67.43601500988007, 66.51496723294258, 71.76821574568748, 72.69557878375053, 79.94888797402382, 85.76626941561699, 85.5553351342678, 84.02991458773613, 87.8340196609497, 83.34672644734383, 85.55642187595367, 84.87821146845818, 83.63883957266808, 81.12765312194824, 85.34949257969856, 80.07863581180573, 93.2418742775917, 53.49824510514736, 63.80455747246742, 91.03354677557945, 79.41937878727913, 77.22302824258804, 70.29461681842804, 78.03050771355629, 72.17103973031044, 68.99383261799812, 66.74206584692001, 63.06543253362179, 62.02326625585556, 60.8190842717886, 61.91751033067703, 64.74128320813179, 68.40278193354607, 76.25521257519722, 73.91987308859825, 70.00443398952484, 68.49270790815353, 65.3431785106659, 62.24682725965977, 64.91145327687263, 68.26823875308037, 72.50238195061684, 73.60313728451729, 78.76873210072517, 77.31615364551544, 73.68965104222298, 78.4392061829567, 87.89046943187714, 81.25483229756355, 84.45777922868729, 82.91071504354477, 77.19936311244965, 82.48475030064583, 86.1837986111641, 86.63524478673935, 88.96384343504906, 83.51296752691269, 80.25254487991333, 80.73596253991127, 82.58982986211777, 89.18828219175339, 91.14714547991753, 74.7842887043953, 0.3680430259555578, 4.367550713941455, 3.7695692013949156, 1.6473175305873156, 0.6956219044514, 1.9131699088029563, 1.1931492760777473, 1.142143306788057, 0.41322067205328494, 0.5622449645306915, 7.10215425118804, 42.04128988087177, 58.98848310112953, 121.44870311021805, 39.291392639279366, 42.39565886557102, 69.83017534017563, 87.00887873768806, 80.81996083259583, 106.70313075184822, 32.068238630890846, 0.49367262690793723, 0.2418583133840002, 0.2003903072909452, 0.16653587546898052, 0.07479820706066675, 0.1153302016609814, 0.1695602756808512, 0.14701051928568631, 0.06303376372670755, 0.24372864427277818, 0.21024392073741183, 0.09361863427329808, 0.18561542354291305, 0.15516878542257473, 0.18868573301006109, 0.2058382797986269, 0.16910063393879682, 0.1797407161211595, 0.11950323867495172, 0.18930247257230803, 0.1413590944139287], [0.055907721107359976, 0.027031140925828367, 0.04631807103578467, 0.04715056777058635, 0.016371896490454674, 0.013828782757627778, 0.09392117819515988, 0.028224820525792893, 0.038930814698687755, 0.015562131738988683, 0.0893465502304025, 0.056575071430415846, 0.05352264401153661, 0.09317635878687724, 0.04041175183374435, 0.045600774174090475, 0.10166029416723177, 0.23840751964598894, 10.142315067350864, 88.73454853892326, 82.06875622272491, 79.02220889925957, 56.09945632517338, 36.59151591360569, 36.25105418264866, 33.14904883503914, 42.29411691427231, 9.28331796079874, 0.14725855988217518, 0.38952454982791096, 0.5310848553199321, 1.1185064376331866, 0.05952919396804646, 0.2945149230072275, 0.5896574654616416, 1.1748929182067513, 7.029392430558801, 114.53751236200333, 97.45261833071709, 98.84260654449463, 80.41683286428452, 89.04811531305313, 87.86237373948097, 92.62275069952011, 97.65710055828094, 104.93200019001961, 87.77285814285278, 90.31717121601105, 86.90633744001389, 84.11551639437675, 73.82845759391785, 73.49857449531555, 63.589527010917664, 65.63995778560638, 64.43422168493271, 64.99092221260071, 62.1482377499342, 65.35447910428047, 61.83281667530537, 63.264887630939484, 60.14102205634117, 64.55299571156502, 57.82796457409859, 57.28645943105221, 59.787565022706985, 61.910910084843636, 68.49317148327827, 81.83998569846153, 76.8444013595581, 77.80675292015076, 69.85045105218887, 65.13491168618202, 60.096640437841415, 65.4562908411026, 63.81745398044586, 70.29025465250015, 72.70304158329964, 79.23020213842392, 70.75750797986984, 81.96771964430809, 72.9649767279625, 78.05617153644562, 72.28618115186691, 78.71808841824532, 71.0425154864788, 75.22270157933235, 70.90812429785728, 80.17870724201202, 44.62702453136444, 53.80167402327061, 79.21959310770035, 72.01125830411911, 67.77709990739822, 58.705778270959854, 60.98294287919998, 58.17233249545097, 59.9848922342062, 58.74511756002903, 61.71411104500294, 57.613059505820274, 55.641683489084244, 53.28039139509201, 55.93904413282871, 54.54901032149792, 63.24180006980896, 68.90499338507652, 66.82344228029251, 60.815926641225815, 56.99234381318092, 54.80198174715042, 54.97667737305164, 56.05610065162182, 58.13417874276638, 59.92569521069527, 61.13553509116173, 62.866501808166504, 61.66160546243191, 66.65523290634155, 77.80043005943298, 79.61800172924995, 78.35019215941429, 70.78220665454865, 68.6599749326706, 75.25097966194153, 79.50274631381035, 77.09139570593834, 76.82275012135506, 77.2356815636158, 72.2993740439415, 72.25552439689636, 71.1837387084961, 78.75325173139572, 78.50391671061516, 86.55114009976387, 42.21628189086914, 0.18429802235914394, 2.0626067463308573, 1.41407998977229, 0.3587250947020948, 0.1983991844463162, 0.5160240666009486, 0.2503553550923243, 0.09722727540065534, 0.08625493370345794, 0.09944635632564314, 11.002727597951889, 25.0732908770442, 45.86367957293987, 52.45817631483078, 20.816896073520184, 37.239263355731964, 52.59789101779461, 67.63934969902039, 69.41812545061111, 61.75073727965355, 2.3838305845856667, 0.1893670839490369, 0.020025098019686993, 0.1529510403634049, 0.039628277663723566, 0.06225731398444623, 0.012725070937449345, 0.02291320652147988, 0.052651577861979604, 0.05615065943857189, 0.04587033334246371, 0.04506620891334023, 0.05215600504016038, 0.027083918757853098, 0.0704060286807362, 0.10817699643666856, 0.023732698973617516, 0.06533688545459881, 0.056526523840148, 0.04069880713359453, 0.039324858007603325, 0.003923382246284746, 0.030789267293585, 0.04283428883354645, 0.060297851159702986, 0.023829356287023984, 0.06952238312806003, 0.017954554241441656, 0.04339579776569735, 0.023380974780593533, 0.02657898745383136, 0.11673948814859614, 0.0248910430673277, 0.0636963828583248, 0.01830620978580555, 0.08013351412955672, 0.09370948799187317, 0.20781714236363769, 0.27878528111614287, 22.36295711249113, 109.02992829680443, 87.0719401538372, 90.90741634368896, 62.6961075514555, 48.28171022236347, 50.07898338139057, 36.036095917224884, 46.18052937090397, 11.752694305032492, 0.20927963341819122, 0.7447752950247377, 2.0792223047465086, 1.6462868358939886, 0.24133636092301458, 1.0208330349996686, 1.4974704338237643, 0.9451289847493172, 10.905532613396645, 122.7103342115879, 100.90840369462967, 104.0015821158886, 85.21606653928757, 93.37385639548302, 89.14167389273643, 99.7205038368702, 97.8480327129364, 109.25830364227295, 92.95971661806107, 95.90877637267113, 90.97829014062881, 86.79422825574875, 77.16685205698013, 75.35147666931152, 66.49118050932884, 69.46567609906197, 67.50866711139679, 69.0784464776516, 65.58422237634659, 67.70625650882721, 63.864655047655106, 67.28059574961662, 63.26902560889721, 66.96465790271759, 61.292835250496864, 62.377673238515854, 62.789848521351814, 66.22744426131248, 73.99994239211082, 83.32571357488632, 78.6952592432499, 80.77739551663399, 71.88772693276405, 69.29263338446617, 62.93649025261402, 69.68971207737923, 68.53853344917297, 73.40438514947891, 76.62608787417412, 81.25750735402107, 76.37581810355186, 84.5594009757042, 74.7985227406025, 80.5617342889309, 74.88485410809517, 81.87569618225098, 74.8029837012291, 79.24446657299995, 74.23188954591751, 81.41414254903793, 46.634453013539314, 57.353377640247345, 80.309549421072, 76.31467178463936, 71.26215130090714, 60.541828349232674, 63.90537366271019, 62.86668799817562, 65.60931622982025, 62.904678359627724, 65.4755026102066, 61.31999619305134, 58.143340051174164, 55.66047728061676, 58.15431386232376, 59.94058281183243, 66.54861822724342, 71.17736265063286, 70.50195649266243, 63.70852142572403, 59.9757195264101, 58.73276062309742, 58.63051950931549, 57.9264210909605, 59.95487384498119, 60.64846582710743, 61.701229736208916, 64.65511903166771, 64.44029375910759, 69.16650295257568, 80.4435758292675, 83.46160188317299, 79.76794168353081, 74.54599589109421, 71.05335250496864, 77.21825569868088, 81.63667380809784, 82.26989462971687, 80.602126121521, 81.70600488781929, 76.16980075836182, 76.39314517378807, 75.70920467376709, 84.2338040471077, 83.73854622244835, 89.2670975625515, 55.05950912833214, 0.27891150559298694, 1.1690507316961884, 0.5251857312396169, 0.7443249598145485, 0.843569221906364, 0.7114054856356233, 1.202440490014851, 1.6996325296349823, 0.14342327427584678, 0.22203476226422936, 12.19660073518753, 29.846039973199368, 41.67987607419491, 37.602698653936386, 31.075709089636803, 52.50391066074371, 61.867657005786896, 75.48172608017921, 78.20616468787193, 84.51410740613937, 5.1587038859725, 0.3406749351415783, 0.16558583738515154, 0.14356284256791696, 0.030797000472375657, 0.0755377126915846, 0.011089404360973276, 0.052341285918373615, 0.19357332465006039, 0.04607470596965868, 0.017179939459310845, 0.06409284556866623, 0.03870110886055045, 0.03252369424444623, 0.03381542454008013, 0.036326852277852595, 0.027099329454358667, 0.09388395948917605, 0.054702985362382606, 0.015477187371288892, 0.044962504907744005, 0.18928716948721558, 0.14818191033555195, 0.23863020847784355, 0.24102848838083446, 0.09195385602652095, 0.15685602847952396, 0.17267597489990294, 0.16783430735813454, 0.09585289953975007, 0.12259641371201724, 0.2751110267126933, 0.21818341658217832, 0.23578417603857815, 0.25088456575758755, 0.17008160473778844, 0.22315273352432996, 0.2732735878089443, 0.44161524216178805, 28.463425263762474, 130.5543977022171, 105.43874099850655, 104.17046785354614, 78.35471391677856, 54.37737353146076, 51.878376826643944, 48.47582660615444, 69.74775776267052, 16.541849970817566, 0.3544547769706696, 1.080542674753815, 3.3110067201778293, 4.146342258900404, 0.954344974597916, 1.4483431074768305, 9.45186361670494, 7.034984780475497, 9.780546929687262, 126.47704929113388, 106.38578698039055, 106.7637450993061, 88.77861857414246, 99.79741930961609, 93.58013212680817, 104.14532840251923, 98.17185133695602, 110.0955431163311, 97.95208632946014, 100.62259063124657, 94.81650978326797, 93.4992116689682, 80.64447104930878, 82.48125448822975, 70.22740602493286, 75.1141794025898, 70.18952965736389, 73.95562916994095, 68.61269786953926, 73.03661048412323, 67.06839993596077, 72.04714357852936, 66.43792256712914, 72.452612221241, 65.21327868103981, 66.52242243289948, 67.53157988190651, 69.69480380415916, 77.49159023165703, 89.44411486387253, 82.03554600477219, 84.37942743301392, 75.14906153082848, 73.27853590250015, 68.11890676617622, 74.46284875273705, 71.39150395989418, 77.63398379087448, 80.90576782822609, 84.40984100103378, 78.11203613877296, 85.36276146769524, 78.82506027817726, 85.1314602792263, 79.37942013144493, 87.1984201669693, 78.55927973985672, 81.79446414113045, 79.1552321612835, 85.18208116292953, 50.305774211883545, 62.648032531142235, 83.13589856028557, 81.44076392054558, 74.64885637164116, 63.91732782125473, 68.97244736552238, 65.87127417325974, 67.72586345672607, 67.06989705562592, 67.14027687907219, 67.17790246009827, 61.810519471764565, 62.38092966377735, 61.77653029561043, 62.894654497504234, 69.25339668989182, 75.2330294251442, 73.4897817671299, 67.18904346227646, 62.83809833228588, 62.66277574002743, 61.7261677980423, 60.560686737298965, 62.950256913900375, 65.46303167939186, 65.7420127093792, 69.86561983823776, 65.9164309501648, 75.31025648117065, 84.205761551857, 88.1874006986618, 83.8705587387085, 79.09533977508545, 74.79875072836876, 84.24514263868332, 86.37666866183281, 83.87568846344948, 84.42613452672958, 86.70369431376457, 81.66166886687279, 81.4733661711216, 78.19440051913261, 87.69720420241356, 87.20520660281181, 91.53730854392052, 52.44770407676697, 0.47351361019536853, 6.228517005220056, 7.759855734184384, 2.0777007238939404, 1.1956086941063404, 2.219195868819952, 2.0295915054157376, 1.7595251533202827, 0.29310350655578077, 0.3648628934752196, 18.403888754546642, 41.30332387983799, 64.79552149772644, 73.72033059597015, 30.01706499606371, 54.198471531271935, 72.43830978870392, 88.99207592010498, 91.80464699864388, 92.56719768047333, 4.972552824765444, 0.4445143084740266, 0.1817821417353116, 0.27611717116087675, 0.16324998694472015, 0.12425691718817689, 0.20205012056976557, 0.12224710706504993, 0.3925104474183172, 0.09471241151914, 0.14243860758142546, 0.11815580277470872, 0.22327809710986912, 0.10991293922415935, 0.13110807572957128, 0.1512583054136485, 0.14352876314660534, 0.15437378198839724, 0.1393490913324058, 0.21185255551245064, 0.08615500351879746], [0.0302587430269341, 0.03387395401659887, 0.0897530467773322, 0.061753629488521256, 0.033867185629787855, 0.020296868788136635, 0.04371452421764843, 0.038718604992027394, 0.06976890232181177, 0.028201928980706725, 0.015914562827674672, 0.06526570607093163, 0.0544442429963965, 0.01040226467011962, 0.0619273105985485, 0.05479855914018117, 0.0886090483982116, 0.3747411462245509, 51.37218698859215, 87.37109810113907, 87.16984570026398, 59.39642161130905, 60.120316967368126, 34.11971054971218, 48.98050792515278, 63.198155611753464, 27.9106917232275, 1.3503618026152253, 0.11970005623879842, 0.7786060671787709, 0.8572216518223286, 1.0507202125154436, 0.712597374804318, 0.6293693126644939, 1.441143206320703, 0.1500471352483146, 60.779627189040184, 116.2819455564022, 89.1340135037899, 90.58726072311401, 82.20339059829712, 92.13933303952217, 87.91825354099274, 104.03703421354294, 99.86396133899689, 90.91952249407768, 89.51162204146385, 90.26411846280098, 84.80596214532852, 80.77719792723656, 66.43014818429947, 65.55265367031097, 62.36334800720215, 66.3536810874939, 63.26543480157852, 63.74753773212433, 61.99102118611336, 63.36750492453575, 61.33733846247196, 62.57623538374901, 60.24338096380234, 58.81490081548691, 56.98242634534836, 61.40474684536457, 57.24000312387943, 66.50577932596207, 75.6799690425396, 74.26243990659714, 67.59625241160393, 73.34672704339027, 63.85808899998665, 61.90949656069279, 58.393032252788544, 60.570015236735344, 63.48209157586098, 69.56258609890938, 70.50825655460358, 79.8162978887558, 71.07236668467522, 74.7894336283207, 80.2496874332428, 73.66109177470207, 73.8736143708229, 76.21865853667259, 74.6826821565628, 74.75321397185326, 72.16154783964157, 77.61268973350525, 45.400955602526665, 54.86049860715866, 76.33253082633018, 72.57544443011284, 67.99088403582573, 57.4859981238842, 57.7134083211422, 62.428799495100975, 67.8064115345478, 66.77963823080063, 67.15644881129265, 60.71534223854542, 58.186053559184074, 51.706128269433975, 52.70311117172241, 55.60383751988411, 65.24963513016701, 68.3093449473381, 70.74793249368668, 61.79250843822956, 58.60892526805401, 55.71635328233242, 55.05417421460152, 56.30409434437752, 58.424623757600784, 57.39811643958092, 58.19479689002037, 57.204376235604286, 59.66081142425537, 57.594185918569565, 69.1684028506279, 74.68180060386658, 72.05175653100014, 61.305123791098595, 66.24008238315582, 73.70494142174721, 81.15602239966393, 76.0548797249794, 79.6586063504219, 71.67505994439125, 72.93068736791611, 66.29723891615868, 69.83345076441765, 75.13606622815132, 83.64261656999588, 74.28383275866508, 89.93326261639595, 33.553939908742905, 0.9897199482657015, 1.5409410512074828, 1.7209384613670409, 0.32921353296842426, 0.40430112567264587, 1.4349838555790484, 2.7190789952874184, 0.1689523528330028, 0.08178049567504786, 1.778458587359637, 23.30760732293129, 29.353288114070892, 71.48206070065498, 29.89703893661499, 19.456709660589695, 53.52163664996624, 51.33328087627888, 68.54502350091934, 79.51945781707764, 25.682297497987747, 0.11571945069590583, 0.06734785332810134, 0.05338595525245182, 0.05603639467153698, 0.007705158541284618, 0.004626849186024629, 0.06553759187227115, 0.07705455864197575, 0.12371268545393832, 0.077087124082027, 0.034947867679875344, 0.035328277735970914, 0.03363168732903432, 0.022770810646761674, 0.032343252169084735, 0.05555340125283692, 0.008731113230169285, 0.054808158820378594, 0.018171801275457256, 0.03172354772686958, 0.028060705699317623, 0.015345301235356601, 0.03082347659074003, 0.054655406274832785, 0.04955104443070013, 0.028018338343827054, 0.08364480032469146, 0.02433007219224237, 0.04813045132323168, 0.06113489354902413, 0.1206751046993304, 0.02592257453216007, 0.02011251559451921, 0.00867971300976933, 0.032954622292891145, 0.01899681159557076, 0.1184141963312868, 0.8222497534006834, 79.76763010025024, 100.82685247063637, 99.59583252668381, 70.31420856714249, 71.88666298985481, 40.13284608721733, 28.9755142852664, 49.15981650352478, 35.75336828827858, 0.7131194311659783, 0.15803613234311342, 2.2853175457566977, 2.501665586605668, 2.319300309754908, 0.8471334900241345, 1.1220231489278376, 0.18430698750307783, 0.3914846508996561, 72.4780024588108, 120.34196689724922, 93.8618566095829, 92.88345471024513, 84.46871504187584, 95.32387375831604, 94.05296355485916, 105.85861846804619, 103.67334812879562, 93.00312548875809, 93.55513706803322, 93.79517018795013, 90.15140891075134, 83.38341727852821, 69.84363421797752, 68.33183214068413, 66.11678659915924, 68.37637335062027, 67.01907858252525, 67.05759331583977, 65.00955641269684, 66.83361813426018, 64.10760641098022, 66.56114995479584, 63.85288327932358, 61.20689146220684, 58.636097609996796, 64.20809581875801, 62.12152138352394, 71.82708218693733, 78.30524057149887, 76.70889303088188, 71.05814024806023, 75.33668026328087, 68.4233084321022, 65.84803462028503, 60.609787702560425, 65.07168307900429, 68.38515847921371, 73.1508019566536, 74.54286485910416, 82.86489710211754, 75.2713617682457, 82.09569677710533, 84.52974736690521, 77.00523152947426, 78.61237809062004, 78.70562508702278, 77.21757933497429, 78.89512851834297, 77.41367921233177, 80.56127831339836, 49.12775382399559, 57.02084608376026, 81.39376044273376, 77.35861256718636, 70.60189113020897, 60.49643598496914, 60.67372687160969, 66.29984557628632, 70.94369038939476, 71.15709453821182, 70.82471117377281, 65.61555549502373, 60.51736146211624, 56.2699493765831, 55.47199219465256, 58.06759491562843, 68.09426128864288, 69.78909954428673, 73.99608939886093, 65.47503903508186, 62.15934835374355, 58.90528276562691, 57.82450295984745, 58.71734485030174, 60.7544269412756, 60.04801444709301, 60.572538301348686, 59.6851909160614, 60.77439866960049, 61.526648104190826, 72.34255492687225, 77.13006243109703, 75.57716935873032, 64.87662434577942, 71.11525118350983, 77.25781917572021, 83.28356623649597, 78.7496343255043, 82.42874130606651, 73.44637289643288, 75.29146268963814, 68.53830546140671, 72.67006695270538, 77.41433277726173, 87.36991256475449, 77.86636412143707, 93.68213385343552, 45.34441463649273, 0.27771071065217257, 0.36764431453775615, 0.6117000232916325, 0.803048136876896, 1.2590963998809457, 0.532688369276002, 3.0702430894598365, 0.5755945388227701, 0.17565320420544595, 0.8495135873090476, 27.35451176762581, 33.338187485933304, 50.94122551381588, 25.84340315312147, 31.947636902332306, 68.11203673481941, 59.023825004696846, 76.58000394701958, 88.81632015109062, 46.005206778645515, 0.3034261870197952, 0.034303561042179354, 0.019993458408862352, 0.03991190424130764, 0.04181630712992046, 0.028057815034117084, 0.06316959159448743, 0.055581164997420274, 0.023784899785823654, 0.02069123678666074, 0.034492463601054624, 0.02988247972098179, 0.033062860820791684, 0.012602696351677878, 0.051313964286237024, 0.013294203581608599, 0.006170283968458534, 0.014321752496471163, 0.03514787276799325, 0.033720366554916836, 0.14323928102385253, 0.10397480786195956, 0.17903117841342464, 0.208794372738339, 0.2050770292407833, 0.19107262836769223, 0.129666201537475, 0.17886766843730584, 0.29164738312829286, 0.23559742199722677, 0.13451557257212698, 0.18724148394539952, 0.1640166254946962, 0.11307225446216762, 0.20298283692682162, 0.1987753642606549, 0.15535209589870647, 0.8845296583604068, 90.42127802968025, 113.54548439383507, 114.54774901270866, 82.02426820993423, 81.21982097625732, 48.59683111310005, 66.75911173224449, 89.16704133152962, 45.65688706934452, 2.850122801028192, 0.24434107937850058, 5.933172153308988, 5.150958951562643, 5.084928469732404, 2.890300895087421, 2.3216502461582422, 3.65610942710191, 0.9433024702593684, 73.27150627970695, 122.58912831544876, 97.95163035392761, 98.70449155569077, 89.97092619538307, 99.4599974155426, 97.29687988758087, 106.12610891461372, 104.90569800138474, 103.53753581643105, 96.94143176078796, 99.02182012796402, 94.50166627764702, 89.95186641812325, 75.39564549922943, 71.0083857178688, 69.5103009045124, 72.47510701417923, 71.66869908571243, 71.47161886096, 69.23933744430542, 71.27214476466179, 68.07459354400635, 70.92531457543373, 67.40259200334549, 65.21977633237839, 64.5459508895874, 67.68050909042358, 64.60497692227364, 72.95967981219292, 82.46718764305115, 78.66529405117035, 71.3877421617508, 79.88071203231812, 70.66090196371078, 70.33196121454239, 64.84991177916527, 68.44583362340927, 72.13013872504234, 76.28523096442223, 79.10895064473152, 85.3590452671051, 79.02989208698273, 82.17360779643059, 87.05108687281609, 82.12531238794327, 80.72227567434311, 83.50320965051651, 81.78649216890335, 83.69722723960876, 80.59899508953094, 84.03646543622017, 53.278430700302124, 60.851728320121765, 83.1291501224041, 82.01707899570465, 73.35409104824066, 62.755281776189804, 63.39053928852081, 71.96522757411003, 73.23682174086571, 73.71683478355408, 74.61148157715797, 67.86616712808609, 64.61745545268059, 58.98788273334503, 59.233805537223816, 62.086787447333336, 71.27131640911102, 73.36232900619507, 77.86704808473587, 68.77941012382507, 65.3425857424736, 62.4348259717226, 61.07232928276062, 62.51043051481247, 64.38598707318306, 62.85665273666382, 65.69642275571823, 63.75212028622627, 64.97646778821945, 64.81027230620384, 75.21460801362991, 81.73254266381264, 79.54883024096489, 69.69242513179779, 73.3896191418171, 81.39794781804085, 87.70777523517609, 84.17926177382469, 86.36243462562561, 77.24584981799126, 81.36067181825638, 73.84907528758049, 77.28210747241974, 83.00679668784142, 90.63962951302528, 82.87353783845901, 97.60836437344551, 42.20257602632046, 2.192718177102506, 5.4509704280644655, 5.564773371443152, 0.8206528297159821, 0.8052936382591724, 5.340132275596261, 7.390857534483075, 0.34232333418913186, 0.2334027280448936, 2.834138246253133, 39.9005151540041, 43.53856913745403, 97.63923391699791, 39.24935169517994, 30.548892058432102, 73.42863544821739, 71.93160697817802, 88.53328853845596, 105.4876671731472, 42.41852603852749, 0.31840064912103117, 0.07691294944379479, 0.11060086559155025, 0.24892925895983353, 0.13294524746015668, 0.16283048054901883, 0.20546523184748366, 0.18745602399576455, 0.2009257223107852, 0.177733592572622, 0.09841994382441044, 0.07338791125221178, 0.09269961054087617, 0.11098713861429133, 0.11683148477459326, 0.13649428670760244, 0.12602550705196336, 0.12839015282224864, 0.10513889617868699, 0.14377839193912223], [0.01610459716175683, 0.013577418267232133, 0.03468614930170588, 0.07407557044643909, 0.06718271062709391, 0.0443428783910349, 0.016961569926934317, 0.0750433532812167, 0.03155409685859922, 0.15782300237333402, 0.06834866915596649, 0.02824997376592364, 0.06001171983371023, 0.12213349909870885, 0.04318430052080657, 0.0369018608762417, 0.35594480170402676, 22.127787731587887, 96.11622244119644, 81.52992233633995, 73.29687371850014, 49.07723553478718, 19.979814291000366, 41.255085468292236, 108.07361841201782, 52.380497083067894, 10.557871218770742, 0.10129030386451632, 0.08642301530926488, 0.7157906284555793, 0.9702943218871951, 0.14475511765340343, 0.23218703077873215, 0.44328228395897895, 1.1456547933630645, 10.050156712532043, 120.27673959732056, 93.56962189078331, 97.64560997486115, 78.7906265258789, 83.25541734695435, 83.7644000351429, 98.91756892204285, 100.31332522630692, 85.32572865486145, 92.58786097168922, 89.48384553194046, 85.83500012755394, 80.2423158288002, 70.69206029176712, 64.79444235563278, 63.273600563406944, 64.4779497385025, 61.61717064678669, 61.05397246778011, 61.42210431396961, 63.16522277891636, 62.31732867658138, 60.55965319275856, 61.18029288947582, 57.207195684313774, 55.80614246428013, 58.4644266217947, 57.34876088798046, 59.14211265742779, 73.10692951083183, 75.54202124476433, 68.77143815159798, 71.83364063501358, 65.64926728606224, 65.26011496782303, 62.64110550284386, 57.12307579815388, 58.33505116403103, 63.991917818784714, 66.24699041247368, 69.40886154770851, 74.97832149267197, 72.92987421154976, 66.3986174762249, 75.88964179158211, 75.93194872140884, 71.99732825160027, 75.96518933773041, 75.03214940428734, 72.29844689369202, 73.18188428878784, 77.21181884407997, 51.05936497449875, 57.35783480107784, 76.13010808825493, 71.07480615377426, 63.842684626579285, 58.11308227479458, 66.89094185829163, 68.99991989135742, 73.35467621684074, 71.06865048408508, 69.54379990696907, 65.30544653534889, 58.87870319187641, 54.327151626348495, 52.39145569503307, 52.74708241224289, 60.54544195532799, 63.412543907761574, 70.6922198832035, 63.92159879207611, 56.72835297882557, 56.35389447212219, 55.79763852059841, 52.88762927055359, 54.68830704689026, 55.95941483974457, 59.296042397618294, 56.87742657959461, 59.296000599861145, 56.842263266444206, 57.39548698067665, 61.45904213190079, 57.87732772529125, 57.39511460065842, 59.74027656018734, 72.65840157866478, 78.3590380847454, 77.13930353522301, 72.06032127141953, 69.25903558731079, 64.44756656885147, 66.0381232202053, 60.27838088572025, 70.47285005450249, 77.83463582396507, 84.21632498502731, 73.88439059257507, 91.38494431972504, 22.102840170264244, 1.2320335395634174, 0.5533760029356927, 1.6656212671659887, 0.6058656144887209, 1.8183556152507663, 1.1770098796114326, 0.8104856440331787, 0.16186985943932086, 0.28850195347331464, 9.187883231788874, 26.92174918949604, 49.114329144358635, 58.79266060888767, 21.72676295042038, 28.904026821255684, 56.26073107123375, 59.717660173773766, 70.06983608007431, 71.01244390010834, 2.76388144120574, 0.29167148808483034, 0.056969433862832375, 0.05263607810775284, 0.011412954772822559, 0.005164650674487348, 0.04352847521658987, 0.038127640218590386, 0.023671679591643624, 0.052656008483609185, 0.07195454949396662, 0.07989308054675348, 0.07467680654372089, 0.00907240189917502, 0.04920682520605624, 0.05205296525673475, 0.05600836746452842, 0.04008910313132219, 0.06679245227132924, 0.022596220405830536, 0.04402191436383873, 0.024132022663252428, 0.04941134626278654, 0.04176326583547052, 0.03223138453904539, 0.10013653140049428, 0.07368236576439813, 0.08946973932324909, 0.059979777797707357, 0.042767079939949326, 0.028095184025005437, 0.1152298113447614, 0.08074693629168905, 0.10921050386969, 0.0699980701028835, 0.08223184762755409, 0.3585283661959693, 38.16820710897446, 115.57733416557312, 92.27202951908112, 86.36964663863182, 65.78032225370407, 39.757513627409935, 40.55427387356758, 67.38323584198952, 56.645015850663185, 12.501869704574347, 0.035767213557846844, 0.2711044385796413, 2.614024132490158, 2.564394995570183, 1.6683274344541132, 1.9657703675329685, 0.21754093933850527, 1.1604940658435225, 14.38760781660676, 127.92072862386703, 93.38058203458786, 102.097207903862, 81.91103428602219, 88.18743109703064, 87.08990558981895, 103.11284020543098, 103.43757078051567, 90.73359087109566, 94.84985679388046, 95.1734322309494, 87.68648117780685, 85.48654362559319, 73.01293015480042, 67.97292619943619, 65.8768978714943, 67.83605754375458, 64.40440848469734, 65.50855323672295, 64.12643820047379, 68.65772545337677, 65.0037807226181, 63.8733945786953, 64.79136452078819, 62.18661189079285, 59.78580951690674, 62.620419412851334, 62.708814069628716, 63.61841306090355, 76.72574892640114, 78.45369100570679, 70.42297393083572, 73.1002114713192, 69.18785020709038, 68.77725183963776, 65.71425899863243, 61.350512355566025, 60.9371667355299, 69.5054903626442, 69.65479955077171, 72.09315150976181, 77.43842348456383, 73.4508490562439, 71.93774744868279, 80.96283316612244, 77.15036854147911, 76.54347270727158, 79.16448086500168, 78.0837732553482, 75.94394087791443, 77.82577469944954, 80.9812393784523, 54.96690429747105, 59.09953214228153, 77.44418397545815, 73.58465507626534, 67.0613095164299, 60.36121644079685, 71.85507908463478, 70.6692387163639, 77.70658269524574, 74.86151576042175, 73.28425079584122, 66.79947316646576, 62.39758417010307, 56.24037176370621, 55.883187130093575, 55.975123196840286, 61.90785504877567, 67.28599146008492, 72.14421316981316, 66.40858054161072, 61.55603192746639, 58.552437499165535, 57.8523288667202, 54.584519416093826, 57.516024112701416, 57.387344017624855, 62.24114276468754, 58.38395074009895, 61.13194428384304, 59.343121871352196, 59.545924589037895, 61.94798469543457, 60.8248295634985, 60.50579488277435, 63.141071274876595, 72.81531795859337, 81.18162542581558, 79.48904424905777, 73.07675153017044, 72.56061002612114, 68.18240895867348, 68.28710854053497, 63.57293710112572, 72.8493945300579, 80.64040526747704, 88.20353463292122, 78.21577057242393, 96.05803236365318, 33.9515695720911, 0.3832135337870568, 0.45794459874741733, 1.094434610567987, 1.791741605848074, 4.671809887513518, 0.3915476147085428, 1.4868884766474366, 0.3629712777910754, 0.5776312295347452, 9.060360174626112, 34.481534734368324, 43.27618561685085, 38.809456899762154, 31.079174503684044, 40.59164486825466, 68.71052742004395, 66.85020044445992, 76.23565882444382, 84.26317647099495, 7.096136324107647, 0.3764979285188019, 0.1250958483433351, 0.06254121515667066, 0.05723227659473196, 0.04153520756517537, 0.021283821297402028, 0.03178166902216617, 0.0638484489172697, 0.07311408102395944, 0.029638715750479605, 0.04058773731230758, 0.06349171337205917, 0.07283224302227609, 0.04109381894522812, 0.018276228875038214, 0.02298727100424003, 0.04124327635508962, 0.03226313361665234, 0.08488397172186524, 0.10711472335970029, 0.11398564529372379, 0.11406930017983541, 0.16293564287479967, 0.15887551620835438, 0.21301415021298453, 0.18150788848288357, 0.2137687659705989, 0.1434853475075215, 0.22250510577578098, 0.140342945815064, 0.18293502362212166, 0.2339007388218306, 0.21313458593795076, 0.12678890983806923, 0.28997808520216495, 0.597778995288536, 40.798832550644875, 133.8164922595024, 107.73666009306908, 98.35060134530067, 72.9751905798912, 38.108960688114166, 54.33344788849354, 147.21568286418915, 75.29376536607742, 21.077584885060787, 0.36604320514015853, 0.32070071320049465, 4.288589525967836, 4.64195916429162, 3.3572511887177825, 2.898337463848293, 2.6672381395474076, 3.8193346560001373, 12.437715847045183, 131.1217376589775, 96.2846066057682, 107.26838082075119, 86.88055202364922, 94.59115907549858, 90.0607305765152, 104.95906233787537, 102.773617208004, 97.26554676890373, 100.84165647625923, 98.56117084622383, 92.82458826899529, 89.8513314127922, 77.86439582705498, 72.82474905252457, 71.39219552278519, 73.01102265715599, 68.74052301049232, 68.3349783718586, 68.00772473216057, 72.34668150544167, 69.75764483213425, 67.52369910478592, 65.90399041771889, 66.7726618051529, 62.98473246395588, 66.84128612279892, 64.7371718287468, 67.14729130268097, 80.42639315128326, 81.85888588428497, 69.98773008584976, 76.92307233810425, 70.92431142926216, 74.07288327813148, 67.7322319149971, 64.90149021148682, 64.9369803071022, 73.28823298215866, 73.32313790917397, 76.76028907299042, 81.98001578450203, 78.58139455318451, 73.93683537840843, 81.78843006491661, 83.14541324973106, 80.72924450039864, 83.61675515770912, 82.60536342859268, 79.27668124437332, 80.07163658738136, 83.35413604974747, 59.732726365327835, 62.77258604764938, 82.79357492923737, 79.80992183089256, 71.29454836249352, 63.51365268230438, 74.33079063892365, 73.34929570555687, 79.34997171163559, 78.29408437013626, 78.16075712442398, 70.73194295167923, 66.24904990196228, 61.745425164699554, 58.665686622262, 60.69326542317867, 67.89300128817558, 69.85010147094727, 77.54542574286461, 68.84620293974876, 62.35399670898914, 61.825353875756264, 62.399077489972115, 59.38873842358589, 62.1430966258049, 61.39421001076698, 66.03004485368729, 61.8348153680563, 66.17451310157776, 61.70317143201828, 63.27944464981556, 67.0270049571991, 64.0372721850872, 63.888563364744186, 66.27679601311684, 78.31677675247192, 86.9128730893135, 83.22435781359673, 78.51589366793633, 77.76967450976372, 73.88442859053612, 72.48943984508514, 68.4401187300682, 76.204774081707, 85.4439403116703, 89.73963260650635, 80.94051316380501, 98.59770208597183, 28.989127054810524, 1.4668388525024056, 3.5682498291134834, 4.765144754201174, 1.7656336817890406, 4.344605170190334, 7.011163383722305, 2.0009671663865447, 0.3706485580187291, 0.46348799660336226, 14.860439244657755, 46.03869438171387, 67.11455225944519, 83.78684163093567, 30.17464444041252, 43.301081880927086, 75.51957204937935, 81.13545790314674, 87.15894788503647, 100.6038348376751, 7.418200392276049, 0.4998289200011641, 0.23472492350265384, 0.16620959766441956, 0.14458197460044175, 0.19548404321540147, 0.1596890584914945, 0.18706338334595785, 0.1164828980108723, 0.20963298476999626, 0.1467671839054674, 0.1706593667040579, 0.1451244845520705, 0.12987404741579667, 0.08901298453565687, 0.15229665907099843, 0.1675254848669283, 0.15918837598292157, 0.14421827771002427, 0.20624675787985325], [0.038391926427721046, 0.017804898307076655, 0.024074639804894105, 0.09325729741249233, 0.023404712374031078, 0.04374705997179262, 0.025998776400228962, 0.053695850147050805, 0.07910259679192677, 0.0831786054186523, 0.038589352552662604, 0.037873532564844936, 0.03822245329502039, 0.028104214106861036, 0.031818754141568206, 0.037955332081764936, 0.24872043344657868, 65.71998909115791, 80.74171543121338, 83.43890950083733, 61.207400634884834, 42.72067442536354, 33.48485201597214, 44.709556102752686, 60.12478552758694, 31.113912239670753, 2.7533370070159435, 0.15547723683994263, 0.4519588511902839, 0.4557640798157081, 1.1481121927499771, 0.7142461894545704, 0.18596700858324766, 0.9192241716664284, 0.2858378808014095, 78.15938159823418, 110.12297004461288, 95.67910149693489, 93.02866771817207, 75.50826385617256, 85.17560631036758, 87.36857503652573, 99.96774137020111, 84.53012734651566, 94.25393477082253, 85.66220059990883, 85.62240913510323, 77.29061901569366, 70.04279673099518, 62.94406704604626, 63.234325870871544, 63.792717307806015, 64.65482264757156, 61.291934698820114, 62.341453582048416, 61.100124791264534, 63.49995441734791, 61.07877753674984, 62.39235185086727, 60.1198685914278, 54.16581608355045, 57.17801705002785, 58.829716220498085, 58.02756026387215, 66.15134194493294, 72.97763764858246, 70.48962235450745, 69.97870177030563, 67.47546449303627, 64.23882856965065, 65.0553971529007, 60.502211675047874, 58.090355694293976, 55.84143877029419, 58.18527080118656, 64.23537835478783, 70.76804101467133, 69.23712596297264, 72.64747336506844, 71.13003998994827, 68.75831365585327, 73.963053971529, 70.57444900274277, 73.45155581831932, 70.4067488014698, 73.15195709466934, 68.52034762501717, 75.67222505807877, 52.90433697402477, 63.92979875206947, 75.82763671875, 64.85690340399742, 59.93785835802555, 62.32100307941437, 70.07503420114517, 70.73083341121674, 72.96099454164505, 69.2358036339283, 64.31097149848938, 58.13964664936066, 57.713526114821434, 52.779114693403244, 54.40722472965717, 53.919315710663795, 59.34470638632774, 60.79688586294651, 66.82867839932442, 65.25885343551636, 62.11847014725208, 54.86124336719513, 55.44841445982456, 53.410823196172714, 51.734717935323715, 52.66652673482895, 56.24436154961586, 55.8377605676651, 57.76646487414837, 56.38102501630783, 57.97254301607609, 55.418806448578835, 56.80766612291336, 56.90655201673508, 56.73834644258022, 57.30877183377743, 64.46737870573997, 61.74346826970577, 64.50960963964462, 61.38077013194561, 61.417913138866425, 57.98700504004955, 62.37193934619427, 59.37632828950882, 72.16596320271492, 74.58048284053802, 86.26905083656311, 72.9313637316227, 91.70646026730537, 11.911272145807743, 0.8518900035414845, 1.8704237462952733, 2.457050043158233, 0.33461016369983554, 0.8519459317903966, 1.3056218158453703, 0.2744911552872509, 0.04844869537919294, 0.23935778037412092, 22.28460531681776, 34.51760619878769, 62.01855070888996, 32.0963267236948, 29.499109089374542, 45.417009741067886, 63.13126400113106, 65.49018502235413, 65.12470543384552, 23.06404799222946, 0.8440190821420401, 0.1425077163730748, 0.1275131865986623, 0.03852126050333027, 0.03292474713816773, 0.06561503498232923, 0.013124082925060065, 0.050803296180674806, 0.08609979515313171, 0.04446038634341676, 0.06515928951557726, 0.03662995281047188, 0.013831144642608706, 0.042404225387144834, 0.01993460795347346, 0.07897865812992677, 0.03432497942412738, 0.027551670318644028, 0.05055783083662391, 0.09058031879249029, 0.014465044514508918, 0.05280182565911673, 0.07743482026853599, 0.04178134084213525, 0.03185184650646988, 0.06271631005802192, 0.03064817388803931, 0.05728421579988208, 0.01951135927811265, 0.013454795061988989, 0.04927218615193851, 0.015933626746118534, 0.09111598614254035, 0.05846319159900304, 0.027295139552734327, 1.6487920889630914, 83.69775921106339, 87.58206278085709, 93.22241932153702, 74.42159056663513, 53.90050292015076, 49.19015407562256, 38.135095685720444, 58.36866796016693, 40.29023364186287, 2.404360407963395, 0.2744625083869323, 1.6760694002732635, 3.302067699842155, 2.0019973861053586, 1.0600718669593334, 0.6421481457073241, 0.12108022085158154, 1.1591891921125352, 88.27735707163811, 110.99562361836433, 102.64660522341728, 94.64985072612762, 80.3619334101677, 87.98443078994751, 91.6740708053112, 102.44001030921936, 90.79304248094559, 95.1887834072113, 90.63666567206383, 87.48372405767441, 81.80507317185402, 72.36392498016357, 64.97703775763512, 66.19047224521637, 66.80382773280144, 66.50716245174408, 64.79957967996597, 63.979682475328445, 65.9563060104847, 67.37892687320709, 64.1674380004406, 66.9134746491909, 63.37160870432854, 57.73028701543808, 61.73763558268547, 62.12120220065117, 63.78672122955322, 71.33927196264267, 78.31114545464516, 73.08104529976845, 71.12258478999138, 68.62174898386002, 67.71239697933197, 66.74154907464981, 64.29909333586693, 60.34906089305878, 59.6800421923399, 60.08286237716675, 68.92638623714447, 73.04569199681282, 73.83161142468452, 74.60611626505852, 74.78766292333603, 72.05580711364746, 77.60565251111984, 72.51270219683647, 76.48343592882156, 71.65699571371078, 76.07156842947006, 71.57135590910912, 78.58855336904526, 55.93085557222366, 67.64143198728561, 81.4409539103508, 69.78403821587563, 61.59583479166031, 66.77700117230415, 72.69830703735352, 73.08381915092468, 73.5600171983242, 72.95618399977684, 68.00525486469269, 60.757143795490265, 59.69552256166935, 55.546225011348724, 58.5213665664196, 57.13960491120815, 62.68748961389065, 65.39653524756432, 70.9486149251461, 70.0068886578083, 64.67192932963371, 58.82166065275669, 58.386747390031815, 55.578682869672775, 54.2850536853075, 55.707362964749336, 59.440176263451576, 57.57122375071049, 59.73311394453049, 58.6487091332674, 61.242757737636566, 57.914185747504234, 58.17999288439751, 58.46618212759495, 61.02254055440426, 59.14971224963665, 65.48239544034004, 63.30827750265598, 67.62515366077423, 62.99508310854435, 63.835328221321106, 60.04839822649956, 65.87729305028915, 61.06490068137646, 74.88518849015236, 76.73747509717941, 88.45615267753601, 77.14961618185043, 97.98639088869095, 22.427960224449635, 1.272510748822242, 0.645175336394459, 1.0337921208702028, 1.9850132474675775, 2.3630115017294884, 2.1372520783916116, 1.2735961843281984, 0.14795036026043817, 0.13258005143143237, 24.587319754064083, 43.9167096465826, 48.34137462079525, 21.99071578681469, 41.324002370238304, 51.10233686864376, 75.36888733506203, 71.91309437155724, 80.31885892152786, 47.27731391787529, 0.50787991611287, 0.08045800335821696, 0.03697902197018266, 0.030836462319712155, 0.04210685052385088, 0.11898189477506094, 0.0047055344657565, 0.05175265891011804, 0.058324365454609506, 0.09847633962635882, 0.057230254242313094, 0.058500343511695974, 0.024583213198638987, 0.067710051080212, 0.028116860303271096, 0.03053573665965814, 0.00987620442174375, 0.061065324625815265, 0.06015259430569131, 0.14767355402000248, 0.09693111394881271, 0.28181463887449354, 0.17601658939383924, 0.089940327743534, 0.16004055447410792, 0.167807026009541, 0.18596601410536095, 0.2843686955748126, 0.12434656862751581, 0.09215043610311113, 0.1366552585386671, 0.12238887211424299, 0.13351889792829752, 0.1349911408033222, 0.1128088662517257, 1.5477178688161075, 99.05512154102325, 101.62604838609695, 109.24886494874954, 83.73450323939323, 63.81057634949684, 50.12544348835945, 67.91730478405952, 79.59105357527733, 52.533761858940125, 4.865255607292056, 0.2560029801679775, 3.299397868104279, 5.536046912893653, 4.07268226146698, 2.717057503759861, 1.9356831070035696, 3.6940321046859026, 1.0602742061018944, 87.20727369189262, 116.23878747224808, 105.73007136583328, 98.99210572242737, 85.0438217818737, 93.2833680510521, 94.60816696286201, 103.73307332396507, 94.46798488497734, 99.43654507398605, 94.23721566796303, 95.31752049922943, 83.83332833647728, 76.57313391566277, 70.79669907689095, 70.87251260876656, 69.98856604099274, 71.45755961537361, 69.00773987174034, 69.4440096616745, 68.6720658838749, 72.6934053003788, 67.59604722261429, 70.43458610773087, 67.59360015392303, 63.135523572564125, 65.16676917672157, 65.97324550151825, 65.59081882238388, 72.82304674386978, 78.64111974835396, 74.46240797638893, 73.31489995121956, 71.49630233645439, 70.14007151126862, 70.26323050260544, 68.75863283872604, 63.75467374920845, 61.725240647792816, 62.679494842886925, 71.91328436136246, 76.56949371099472, 75.99380940198898, 77.97165647149086, 77.13721364736557, 75.91703072190285, 80.18601804971695, 77.26870939135551, 80.49197003245354, 75.94788506627083, 78.99930372834206, 75.22532343864441, 81.79615125060081, 60.44144153594971, 70.04513740539551, 82.80400916934013, 72.69355729222298, 65.26437073945999, 69.72856879234314, 76.98312431573868, 77.53922447562218, 78.43052744865417, 75.603828728199, 72.99236565828323, 66.0939422249794, 62.65816278755665, 59.36775974929333, 61.14566154778004, 60.128429532051086, 65.43172135949135, 66.46103292703629, 74.07627269625664, 72.13697835803032, 70.16160875558853, 61.95949047803879, 62.712021097540855, 59.68746319413185, 59.33989204466343, 59.55894649028778, 63.322796523571014, 59.91634011268616, 63.66135075688362, 62.614795714616776, 64.54968228936195, 62.286546528339386, 62.75807082653046, 62.45392754673958, 65.88570579886436, 62.934692949056625, 72.06927359104156, 67.55486503243446, 70.9247750043869, 68.1948646903038, 68.76918867230415, 64.18617859482765, 69.44277092814445, 66.18009120225906, 80.03114596009254, 82.54151925444603, 93.7419730424881, 79.56156715750694, 100.73222994804382, 17.4995980784297, 1.9450848712585866, 7.90911789983511, 5.065923789516091, 1.601236928254366, 4.4975583627820015, 5.224944306537509, 0.7648852409329265, 0.3855507052503526, 0.5045580037403852, 38.559920489788055, 51.08274132013321, 86.41639173030853, 41.93298049271107, 41.460407450795174, 60.35350285470486, 85.13073071837425, 83.54243874549866, 94.10926893353462, 49.23277258872986, 1.4828999969176948, 0.16847947117639706, 0.25389771501068026, 0.14576822344679385, 0.15980769821908325, 0.19163738790666685, 0.09288421235396527, 0.12059057407896034, 0.19486622011754662, 0.13600479578599334, 0.16178317659068853, 0.12930191092891619, 0.10880029658437707, 0.15028585446998477, 0.14405414432985708, 0.11464534036349505, 0.14532158413203433, 0.15866326197283342, 0.15699475072324276], [0.04481866555579472, 0.048485272127436474, 0.04583190493576694, 0.05264836065180134, 0.09106488927500322, 0.024017845098569524, 0.03420148976147175, 0.023981810118129943, 0.08903508569346741, 0.05430909790447913, 0.04463398210646119, 0.051671078326762654, 0.11017966709914617, 0.05942627292824909, 0.09313337359344587, 0.343351861811243, 14.076831042766571, 91.89700484275818, 76.13452345132828, 74.38855513930321, 48.08054901659489, 44.74647492170334, 24.491331204771996, 63.15158911049366, 51.18038088083267, 18.080163225531578, 0.02451171283610165, 0.18861445714719594, 1.3766417861916125, 2.8953406121581793, 0.8418986178003252, 0.6481729005463421, 0.677822056459263, 0.8624270756263286, 44.35795336961746, 115.16460031270981, 93.07946339249611, 102.24809780716896, 79.56405982375145, 82.94904738664627, 75.313471108675, 90.12267485260963, 80.34383118152618, 89.18944492936134, 89.54746171832085, 88.04537191987038, 70.4798872768879, 65.95095589756966, 62.5059125572443, 61.76170729100704, 61.720179319381714, 60.53042136132717, 58.18519860506058, 60.8593887090683, 60.53211227059364, 61.480598375201225, 59.43952649831772, 62.61163808405399, 61.416875794529915, 55.05722925066948, 59.12170395255089, 58.22976641356945, 58.335047364234924, 62.61478431522846, 72.36436575651169, 72.93027698993683, 68.97806346416473, 65.44165402650833, 61.29045657813549, 65.61852693557739, 61.79175227880478, 63.97566229104996, 58.016677647829056, 54.485671520233154, 55.09262055158615, 59.95189480483532, 62.46014781296253, 71.09305277466774, 67.93538421392441, 68.92219886183739, 62.5718580186367, 67.98017621040344, 66.09337225556374, 67.09098592400551, 65.41335314512253, 67.09541648626328, 68.64004120230675, 74.293362647295, 54.71079424023628, 69.07023891806602, 72.34701588749886, 61.49279572069645, 56.47848218679428, 66.5417329967022, 68.44397932291031, 69.11082074046135, 68.27472120523453, 69.15334805846214, 61.00410394370556, 54.39624711871147, 53.509652093052864, 52.385592609643936, 52.92221121490002, 54.36243653297424, 56.85494318604469, 65.4445418715477, 66.93399354815483, 68.19642260670662, 61.64443418383598, 59.261836633086205, 53.594615533947945, 53.52892845869064, 50.48133619129658, 50.56974224746227, 53.574514612555504, 57.238452807068825, 52.716345861554146, 56.3319506496191, 56.520409137010574, 58.03603380918503, 55.93674525618553, 58.353913351893425, 55.24199053645134, 58.67740139365196, 54.593118354678154, 54.940431118011475, 53.68311658501625, 56.52931205928326, 57.00874753296375, 58.939708918333054, 55.498951748013496, 61.478128507733345, 59.32947680354118, 69.62933331727982, 72.07863628864288, 82.02985391020775, 73.95614594221115, 85.65061122179031, 6.449116067960858, 0.4168773820856586, 4.980244562029839, 3.89953528996557, 0.059801339521072805, 0.5896816891618073, 2.035190504975617, 0.9137874352745712, 0.33465685963165015, 6.055354597046971, 25.0383460521698, 38.34249995648861, 68.47896784543991, 14.958039857447147, 27.933118119835854, 48.16188745200634, 65.82812368869781, 65.42335420846939, 60.02825550734997, 3.8395609706640244, 0.5972525454126298, 0.0443726236699149, 0.0030960726599005284, 0.025998459132097196, 0.018833225549315102, 0.07857098898966797, 0.008609926080680452, 0.03635805958765559, 0.03145799615595024, 0.08025737857678905, 0.09029011678649113, 0.022863775775476824, 0.030265880632214248, 0.14146914007142186, 0.015642407997802366, 0.027919315434701275, 0.06294916631304659, 0.06618408413487487, 0.03945704935176764, 0.0756765685218852, 0.013995888439239934, 0.06320663218502887, 0.06495795969385654, 0.042874813807429746, 0.02875384936487535, 0.04357010227977298, 0.07795573372277431, 0.04107648979697842, 0.05900632866541855, 0.03221145045245066, 0.08840834940201603, 0.05681980946974363, 0.13822451495798305, 0.4587357578566298, 25.10199073702097, 112.33785599470139, 85.91228038072586, 84.17542397975922, 59.17835891246796, 58.30946333706379, 31.786403954029083, 46.31770581007004, 55.17081655561924, 22.343720644712448, 0.031499474789598025, 0.5729505338240415, 5.615506824105978, 4.646091917529702, 2.798172226175666, 1.0838445788249373, 0.5407479149289429, 0.5979362118523568, 54.07285027205944, 120.50744041800499, 98.4499280154705, 104.01734367012978, 84.48117077350616, 85.76829850673676, 79.0025943517685, 93.40781897306442, 86.18436098098755, 94.9521853029728, 92.59773284196854, 89.80143249034882, 75.20899191498756, 67.68681675195694, 65.64533069729805, 65.61337441205978, 65.1137088239193, 64.50147047638893, 64.13839235901833, 65.67151889204979, 63.06156054139137, 65.71124196052551, 64.36984553933144, 65.712169110775, 64.20763224363327, 60.67821063101292, 61.21310032904148, 62.386807948350906, 61.56089186668396, 65.68240150809288, 74.34745654463768, 73.45502123236656, 70.50837814807892, 67.1126751601696, 65.62034323811531, 68.27079981565475, 65.59204995632172, 66.67066767811775, 61.450310200452805, 59.25256133079529, 56.37266926467419, 63.34596008062363, 67.01770305633545, 72.34215974807739, 71.01006522774696, 71.28274619579315, 66.38911038637161, 71.41530588269234, 68.63228961825371, 71.31978660821915, 68.28608259558678, 70.49491927027702, 71.08511880040169, 77.15400874614716, 55.10135628283024, 71.77326947450638, 75.22482946515083, 65.8849686384201, 59.77219104766846, 71.36797562241554, 71.74269631505013, 71.15931361913681, 70.93596160411835, 73.18205907940865, 65.85241198539734, 57.430589497089386, 56.73302672803402, 56.12622208893299, 55.90167693793774, 56.300704926252365, 58.95534887909889, 65.34766986966133, 69.86987560987473, 70.10198995471, 63.412236124277115, 62.34782584011555, 57.05694414675236, 56.44725926220417, 52.52924770116806, 53.32359507679939, 55.81309229135513, 59.00093503296375, 56.52945265173912, 59.20184165239334, 57.17239335179329, 58.84232394397259, 58.225423246622086, 61.10775478184223, 58.69436368346214, 61.24376468360424, 58.211291804909706, 58.865844681859016, 56.62122532725334, 58.60382594168186, 57.254016771912575, 62.01670400798321, 58.62745687365532, 65.4643540084362, 62.43220791220665, 70.82912653684616, 74.21067908406258, 85.94910800457001, 76.20067790150642, 95.47556161880493, 17.778869792819023, 0.45552356459666044, 0.9666285873390734, 1.244778768159449, 2.5027226423844695, 2.604292379692197, 3.565546511672437, 2.2941238107159734, 0.3993578877998516, 4.845167985185981, 33.02151247859001, 38.283310532569885, 39.86660197377205, 19.45204921066761, 47.25520670413971, 57.921336963772774, 73.6201223731041, 71.0117295384407, 77.79553592205048, 16.23877063393593, 0.3854915115516633, 0.15668851090595126, 0.11099245239165612, 0.08527975907782093, 0.047002858118503354, 0.020157499020569958, 0.031126332214626018, 0.048872224215301685, 0.0702374498359859, 0.05234417287283577, 0.020606092039088253, 0.02860194472305011, 0.00846732611535117, 0.033665017181192525, 0.05807823588838801, 0.030797662839177065, 0.013077034473099047, 0.017095167640945874, 0.1530114363413304, 0.1376315686502494, 0.20263331505702808, 0.07413323532091454, 0.19956152129452676, 0.12205708757392131, 0.1672098197741434, 0.13959356962004676, 0.2898889087373391, 0.11479028180474415, 0.30833053635433316, 0.14379516447661445, 0.17042756429873407, 0.3125282720429823, 0.3129155543865636, 1.0008442075923085, 28.904102817177773, 129.58636164665222, 100.19749984145164, 102.26770475506783, 68.51470112800598, 61.45115755498409, 36.96002773940563, 89.95348513126373, 73.63783702254295, 33.03962990641594, 0.26309001550544053, 0.5368812661617994, 5.763281369581819, 9.311617892235518, 4.098126646131277, 4.613884370774031, 4.650554778054357, 2.0571514265611768, 49.38120782375336, 123.04217800498009, 101.00288182497025, 109.92502346634865, 87.84897565841675, 90.21805733442307, 84.46526482701302, 94.86738905310631, 88.41053232550621, 100.7894016802311, 97.68857046961784, 96.39987722039223, 78.46550077199936, 73.63423481583595, 70.04544898867607, 69.40930992364883, 69.55582246184349, 67.34963044524193, 67.28319481015205, 70.53102493286133, 67.5354252755642, 69.41195458173752, 66.6028793156147, 67.26264551281929, 68.20915952324867, 63.50767180323601, 66.29052087664604, 65.41227400302887, 66.09683766961098, 69.97864097356796, 78.80719363689423, 77.81283259391785, 73.09070438146591, 69.31885197758675, 66.52871489524841, 73.41597452759743, 68.83698463439941, 70.7348383963108, 63.51945877075195, 60.79169534146786, 59.46737140417099, 65.82260638475418, 69.07603740692139, 78.65780845284462, 76.03693708777428, 75.34625574946404, 70.38567513227463, 76.43216148018837, 74.22066494822502, 74.43658456206322, 72.98820868134499, 75.34337550401688, 76.77465990185738, 81.16762697696686, 64.0762808918953, 74.88623723387718, 78.51397097110748, 70.87570443749428, 62.39338539540768, 74.47402775287628, 74.1190356016159, 73.49185645580292, 74.53110069036484, 78.37956458330154, 68.2428865134716, 58.91358532011509, 59.45402272045612, 58.7619848549366, 59.84336502850056, 61.16988904774189, 62.99579367041588, 70.53154170513153, 72.77542769908905, 73.58258798718452, 68.56069386005402, 65.99836215376854, 61.154921650886536, 60.02642780542374, 55.83027496933937, 56.75707943737507, 59.57258775830269, 62.92760632932186, 58.71572993695736, 61.31389372050762, 62.878311574459076, 63.002530708909035, 61.80172674357891, 65.14685064554214, 62.251660600304604, 66.6295462846756, 61.135455295443535, 62.542816177010536, 60.0357411056757, 63.81136670708656, 61.34340673685074, 65.6585767865181, 61.648963540792465, 67.39252254366875, 65.05461439490318, 76.34548053145409, 80.19324526190758, 89.51608300209045, 81.94863706827164, 97.1553298830986, 15.298762824386358, 1.2981769465841353, 14.380779583007097, 7.673178110271692, 2.126846336759627, 4.598348904401064, 5.490348665043712, 3.2968624541535974, 0.4967550333822146, 10.235056690871716, 41.44503727555275, 54.61355745792389, 93.18237707018852, 19.935901947319508, 46.35769486427307, 66.35665252804756, 88.1491519510746, 80.76884597539902, 98.20828378200531, 15.615373235195875, 0.8604548033326864, 0.23681344580836594, 0.39433417143300176, 0.1518034574110061, 0.11657544382615015, 0.17902374209370464, 0.1380237640114501, 0.17776366439647973, 0.1376596960471943, 0.21115680690854788, 0.23380599624942988, 0.30328966153319925, 0.1317440962884575, 0.22339612827636302, 0.14264816039940342, 0.09197872539516538, 0.15993577806511894, 0.15070742403622717], [0.029394899829640053, 0.07437026244588196, 0.046862614472047426, 0.03015102029166883, 0.049566232482902706, 0.026714696577982977, 0.02854640239092987, 0.027698569174390286, 0.07167481177020818, 0.007934502118587261, 0.05754862446337938, 0.03204930602805689, 0.06402919898391701, 0.011414522559789475, 0.08590758632635698, 0.13783518428681418, 47.25635804235935, 86.10346332192421, 78.0765688419342, 62.6160154491663, 41.87569856643677, 20.402526408433914, 45.2570915222168, 57.97888107597828, 34.60374377667904, 7.17280576005578, 0.3531438473146409, 0.5994397436734289, 3.466145507991314, 2.4708568397909403, 2.0675726048648357, 0.14038702938705683, 2.2882906487211585, 19.914298206567764, 115.33149495720863, 92.80568808317184, 98.92272904515266, 90.85525274276733, 80.98171815276146, 68.85252580046654, 79.46950569748878, 78.50219920277596, 85.74198111891747, 88.6201822757721, 83.047606498003, 73.27374055981636, 61.58478498458862, 63.54513019323349, 62.34168156981468, 62.211443558335304, 59.81794439256191, 61.54565468430519, 62.00347311794758, 60.889904871582985, 60.732885897159576, 62.262999191880226, 58.50579120218754, 60.84852509200573, 57.806841507554054, 54.5754075050354, 56.320418268442154, 57.049249559640884, 58.76964144408703, 65.85587739944458, 67.28685781359673, 69.8095652461052, 67.60412558913231, 62.95552723109722, 63.63273449242115, 62.01784394681454, 61.98687180876732, 58.79563964903355, 56.21428616344929, 55.17740540206432, 54.32299464941025, 55.46135276556015, 61.428187787532806, 65.75812384486198, 66.75167173147202, 63.249589651823044, 63.5294446349144, 62.66679972410202, 60.51414303481579, 65.36518692970276, 63.5207848995924, 66.9610632956028, 68.4768095612526, 73.54284971952438, 49.56276588141918, 72.08538472652435, 72.83342018723488, 58.48691761493683, 60.01131981611252, 68.08839440345764, 69.45762813091278, 68.52936074137688, 70.44376641511917, 67.29616731405258, 67.57704824209213, 59.277222007513046, 53.887492418289185, 53.57326827943325, 52.880508452653885, 51.931501775979996, 54.49159160256386, 59.730898663401604, 63.645019233226776, 65.17969608306885, 63.34433376789093, 58.29649843275547, 52.04380854964256, 50.9550491720438, 52.77472972869873, 49.11751337349415, 50.78989863395691, 53.77241179347038, 54.75559003651142, 56.37264646589756, 55.295290276408195, 54.05372589826584, 53.85426700115204, 56.41591474413872, 55.61386898159981, 55.814182832837105, 57.33699671924114, 53.36592860519886, 55.9889430552721, 54.912004843354225, 55.61930648982525, 56.690343618392944, 61.16575486958027, 59.42343056201935, 62.100044935941696, 60.17950639128685, 66.03850319981575, 71.18292555212975, 79.60315212607384, 79.33104112744331, 74.00972306728363, 3.3429364068433642, 0.739073819713667, 5.100233573466539, 0.5776301608420908, 2.3388236621394753, 1.78186985431239, 0.6291276100091636, 0.14026222983375192, 0.04775665751367342, 22.234273217618465, 26.98458831757307, 65.43647110462189, 52.260290533304214, 12.149461414664984, 32.05452136695385, 53.84666360914707, 67.56472170352936, 61.029209196567535, 42.31243573129177, 5.251382812857628, 0.41055324487388134, 0.06352486510877497, 0.057289974865852855, 0.0820057671808172, 0.09849418827798218, 0.010540222501731478, 0.03864556652843021, 0.04626760499377269, 0.024925593752413988, 0.08931666394346394, 0.04948067769873887, 0.041266394255217165, 0.01203840251037036, 0.02698652486287756, 0.04428874242876191, 0.03700331988511607, 0.053029750342830084, 0.004289284242986469, 0.023705007588432636, 0.06676761258859187, 0.026746330622700043, 0.05818851903313771, 0.03197172933141701, 0.061296585263335146, 0.03253509734349791, 0.0522742291650502, 0.01803748182283016, 0.08351250507985242, 0.048001592222135514, 0.020658537760027684, 0.024864863808033988, 0.11563248583115637, 0.3699370758840814, 63.937740325927734, 96.3352806866169, 84.9603782594204, 74.94797632098198, 51.26822076737881, 32.51939222216606, 37.837742641568184, 40.296138525009155, 45.725560784339905, 7.415879191830754, 0.4013010085327551, 3.296286785043776, 5.044954139739275, 4.419734738767147, 3.0527105927467346, 0.9959587978664786, 1.9064019969664514, 27.514374889433384, 120.02922847867012, 95.77014461159706, 103.98618534207344, 93.50446298718452, 84.83073681592941, 71.4497472345829, 83.26433926820755, 81.1546316742897, 88.29597607254982, 90.7199876010418, 84.0135982632637, 74.06171947717667, 67.35116556286812, 65.22322654724121, 65.95831990242004, 65.67219525575638, 63.33845168352127, 65.6034417450428, 65.72681352496147, 64.41258564591408, 64.23160895705223, 65.7676613330841, 63.053254187107086, 64.25987184047699, 60.1622249186039, 58.76236863434315, 59.714263156056404, 62.072766199707985, 63.12712222337723, 69.36240524053574, 70.9506668150425, 71.99871897697449, 69.50278490781784, 65.67819893360138, 65.99376440048218, 63.702833130955696, 64.33812484145164, 60.80512762069702, 59.44719448685646, 56.50437779724598, 57.30252116918564, 57.58708789944649, 64.0297257900238, 68.27874138951302, 70.02682998776436, 67.75959804654121, 67.25744739174843, 64.86318826675415, 65.58881253004074, 67.48738825321198, 67.89700627326965, 71.82078212499619, 73.31514313817024, 75.20607367157936, 53.66985149681568, 76.12284287810326, 75.73380455374718, 62.013580575585365, 64.00926008820534, 70.87087869644165, 71.3561886548996, 71.61000743508339, 72.12288871407509, 70.60947552323341, 69.05963748693466, 63.08804132044315, 56.39683596789837, 54.744308441877365, 56.12157493829727, 54.45879176259041, 58.7300019711256, 62.7485029399395, 64.99427363276482, 68.21703270077705, 66.20474427938461, 60.780957117676735, 56.767658069729805, 52.92342334985733, 55.615958869457245, 53.19615751504898, 53.987214267253876, 54.86085198819637, 58.52787561714649, 57.49891743063927, 59.803858548402786, 56.8952514231205, 58.60830970108509, 58.26160870492458, 58.54626663029194, 58.54740656912327, 58.07506911456585, 57.431034073233604, 60.371783673763275, 57.7740378677845, 59.315843135118484, 59.94331866502762, 63.60316067934036, 62.743859589099884, 65.74833557009697, 62.71444536745548, 69.62412759661674, 71.4958843588829, 83.62383037805557, 78.57575565576553, 88.66030052304268, 10.305618904531002, 0.9952564293053001, 0.3096880728844553, 1.7619441985152662, 5.195094058290124, 2.159119904972613, 2.0196785498410463, 0.48596379056107253, 0.04809348865819629, 21.246873401105404, 38.91415648162365, 53.512577936053276, 31.23660385608673, 20.25062195956707, 42.09034524857998, 66.525097489357, 75.01491352915764, 70.56377917528152, 68.601154088974, 16.08830440789461, 0.703691840171814, 0.09922688841470517, 0.04786166398844216, 0.055581109336344525, 0.11124833006761037, 0.05158121537533589, 0.09466893650824204, 0.06128897824964952, 0.06300878303591162, 0.06226285040611401, 0.03800861457420979, 0.031089731346582994, 0.02007993716688361, 0.03852292291412596, 0.02549229029682465, 0.008690114209457533, 0.04969129920937121, 0.18721881875535473, 0.1955805966281332, 0.11726936674676836, 0.15669806976802647, 0.14192357193678617, 0.09759039341588505, 0.18019540031673387, 0.12203471182147041, 0.1298974102246575, 0.18501766811823472, 0.21875678503420204, 0.10059178704977967, 0.17665498482529074, 0.09881963487714529, 0.18630087113706395, 0.5302578653208911, 79.19787347316742, 111.8622887134552, 99.35896083712578, 85.61395838856697, 61.853506565093994, 31.81540209800005, 62.311438992619514, 81.83727264404297, 56.472714096307755, 12.467901427298784, 0.8311710215639323, 4.90046689286828, 8.970008622854948, 8.780269604176283, 6.810024976730347, 7.051379950717092, 5.232606595382094, 23.421813994646072, 121.49361670017242, 100.14210641384125, 109.12942975759506, 100.7804037630558, 89.11046236753464, 74.89965811371803, 88.15903142094612, 87.11597219109535, 93.6040024459362, 96.13934800028801, 89.33164849877357, 80.32948315143585, 69.40434738993645, 69.2598183453083, 70.58739110827446, 70.27790531516075, 69.00893300771713, 68.90022084116936, 69.0767365694046, 66.49380996823311, 68.86534631252289, 71.43787667155266, 65.2796383202076, 69.21512514352798, 66.16583436727524, 62.93498933315277, 65.09412467479706, 66.52437552809715, 64.19921949505806, 71.83152034878731, 72.90451437234879, 74.69403594732285, 72.22878903150558, 67.14545220136642, 70.26620954275131, 67.62706875801086, 68.21721509099007, 65.59484660625458, 63.636169508099556, 60.49075148999691, 60.660389587283134, 61.487947180867195, 66.95058345794678, 72.38569781184196, 75.07330879569054, 70.81614643335342, 73.33873987197876, 68.63928884267807, 69.43751960992813, 71.84923499822617, 73.30293819308281, 75.95637381076813, 77.88523390889168, 81.80305927991867, 59.02126394212246, 81.35420456528664, 81.77959933876991, 64.76646825671196, 67.37094730138779, 74.44010317325592, 74.88787114620209, 75.05926474928856, 74.18078228831291, 73.61288756132126, 74.43283036351204, 67.15053632855415, 59.9308705329895, 58.4670826792717, 59.14896368980408, 58.87877158820629, 61.34428448975086, 65.42212307453156, 69.54528942704201, 70.73748305439949, 71.08856901526451, 64.76244807243347, 58.55442099273205, 57.03917250037193, 59.074331894516945, 55.30664786696434, 58.35094191133976, 58.067708909511566, 60.04278592765331, 62.273418232798576, 61.77849858999252, 60.9899877011776, 60.96879243850708, 62.562597915530205, 60.66157892346382, 61.964726597070694, 62.07709036767483, 59.526792615652084, 63.06703224778175, 61.383202001452446, 61.812647357583046, 63.60498458147049, 67.91747197508812, 67.6636303961277, 67.4649466574192, 66.84796616435051, 72.61041775345802, 78.57330098748207, 87.06316262483597, 84.24763530492783, 89.09693509340286, 9.18654190376401, 2.208686820231378, 13.872849438339472, 4.668216705322266, 8.012160770595074, 5.7966207806020975, 1.9575022486969829, 0.6715744792018086, 0.18597340589622036, 34.994932785630226, 42.42454491555691, 83.82267370820045, 65.16613081097603, 19.262403286993504, 49.403596222400665, 76.10173881053925, 89.06019866466522, 83.9359000325203, 78.92832353711128, 14.130063336342573, 0.5898682354018092, 0.16547742445254698, 0.1067836290167179, 0.25091440009418875, 0.19483197742374614, 0.12543707300210372, 0.18677707761526108, 0.17350691312458366, 0.26195966522209346, 0.1781491655856371, 0.15369407861726359, 0.18837158189853653, 0.10121254163095728, 0.1759013783885166, 0.1504492902313359, 0.1138524743146263, 0.10250664679915644], [0.013736051405430771, 0.08063419663812965, 0.017442331336496864, 0.05535887692531105, 0.05634726920106914, 0.021224547817837447, 0.013746801414526999, 0.02467457343300339, 0.07583703569252975, 0.041908303755917586, 0.042608252915670164, 0.018557259791123215, 0.017913862284331117, 0.05524418913410045, 0.14896192238666117, 3.420284343883395, 72.95785591006279, 68.56846824288368, 75.41777551174164, 54.518463760614395, 41.734137162566185, 29.58625741302967, 72.12206795811653, 46.11297279596329, 24.91203512996435, 0.3538778907386586, 0.04865796618105378, 1.3192063244059682, 3.346706754527986, 2.308178306557238, 1.8591035599820316, 0.48790513013955206, 1.3519559358246624, 95.0042425096035, 96.53364524245262, 94.50352057814598, 91.14262372255325, 83.89151081442833, 73.78071695566177, 72.21339985728264, 69.81015801429749, 77.59432151913643, 78.41339036822319, 76.77308678627014, 71.40674874186516, 64.12892326712608, 63.35736706852913, 62.59564854204655, 60.30508205294609, 59.281037002801895, 58.17628048360348, 60.58964878320694, 59.185441732406616, 61.936539709568024, 61.9064187258482, 58.49090740084648, 62.439723908901215, 58.62530618906021, 53.321102410554886, 56.342753469944, 58.992670476436615, 58.71747024357319, 61.93270951509476, 67.01306730508804, 68.25535744428635, 69.76777508854866, 64.8031210899353, 63.469407856464386, 61.780960857868195, 61.34958900511265, 60.07300190627575, 57.72459112107754, 55.54763853549957, 53.062628880143166, 53.31272006034851, 54.01431441307068, 56.04628577828407, 61.20035961270332, 63.24365437030792, 61.30704268813133, 61.151619628071785, 61.365080773830414, 59.1334643214941, 59.959832578897476, 60.045282393693924, 63.51645693182945, 71.35656103491783, 70.03487795591354, 51.598594039678574, 71.32649704813957, 66.99970722198486, 59.45482447743416, 57.55465283989906, 67.1522082388401, 65.48708438873291, 71.04959070682526, 68.77989649772644, 67.66169250011444, 67.01486080884933, 66.02999925613403, 61.66975982487202, 53.595740273594856, 52.157688438892365, 51.72945521771908, 53.291106820106506, 59.38507542014122, 62.020758390426636, 59.91450481116772, 59.26749832928181, 60.13518936932087, 55.023996233940125, 51.9470239430666, 53.385835736989975, 50.88322542607784, 49.13508363068104, 51.01203091442585, 54.65966418385506, 56.74056552350521, 54.06609423458576, 54.05809946358204, 56.02173529565334, 54.77652691304684, 54.273247718811035, 54.33716408908367, 56.56288705766201, 56.82796463370323, 55.194857865571976, 56.879752054810524, 58.34795527160168, 61.27208836376667, 63.95936876535416, 65.60641318559647, 67.90392190217972, 68.6401703953743, 67.30568960309029, 68.03089588880539, 73.79241272807121, 76.43925949931145, 83.89946758747101, 64.90959897637367, 0.6799123005475849, 0.10557704532402568, 3.8574406737461686, 1.4413751126267016, 2.6286291237920523, 0.7902869372628629, 0.3548405453329906, 0.1856731774751097, 3.3977465657517314, 33.223684430122375, 41.13207086920738, 81.27257734537125, 40.00815577805042, 34.172280728816986, 45.74354141950607, 55.17682783305645, 59.65727761387825, 69.37090918421745, 52.75372065603733, 15.79450037330389, 0.7014254992827773, 0.03527160362864379, 0.051368167041800916, 0.04104392064618878, 0.05910651489102747, 0.07130608311854303, 0.009814110781007912, 0.01930824830196798, 0.06564924056874588, 0.07072593143675476, 0.06822761002695188, 0.04541006448562257, 0.0417058607126819, 0.030717828158230986, 0.014815667545917677, 0.044567326112883165, 0.036010270632687025, 0.03317934460937977, 0.04180108939181082, 0.038803814677521586, 0.058330228421255015, 0.06866618961794302, 0.03424751033890061, 0.03789003050769679, 0.05850834015291184, 0.055714168993290514, 0.041018735864781775, 0.047799160311114974, 0.07892254434409551, 0.05514037751709111, 0.3356432035798207, 7.515708385035396, 94.13041099905968, 78.25161784887314, 89.22351390123367, 66.88497617840767, 57.3026579618454, 40.793182253837585, 48.47917042672634, 48.124786242842674, 32.422094643116, 0.08776040995144285, 0.3357193776173517, 5.498406132683158, 5.343965794891119, 3.381852018646896, 2.11668211966753, 0.8759465720504522, 2.7716790977865458, 102.34952196478844, 99.27281185984612, 100.6836685538292, 94.38293784856796, 84.95486095547676, 77.35672026872635, 77.16110676527023, 74.12107989192009, 80.95824301242828, 81.11800163984299, 80.74872985482216, 73.33794951438904, 68.16473990678787, 66.05542749166489, 64.71142441034317, 63.212803825736046, 64.22767996788025, 61.19144909083843, 62.874177396297455, 63.4371779859066, 65.79001933336258, 66.34876415133476, 61.573913767933846, 65.6179341673851, 63.199048563838005, 56.125557124614716, 60.53201347589493, 63.44482697546482, 62.533844858407974, 64.61167976260185, 69.30232286453247, 70.17818346619606, 70.98422661423683, 66.20024532079697, 63.406061455607414, 63.662270307540894, 64.18283477425575, 63.07387948036194, 62.86938585340977, 60.1029746979475, 56.139464378356934, 55.50995975732803, 57.85166010260582, 59.29475426673889, 64.5907960832119, 64.88261282444, 62.820478677749634, 63.991439044475555, 65.21690368652344, 62.63369210064411, 61.38713859021664, 64.31730955839157, 67.31156408786774, 76.61158785223961, 73.68712797760963, 54.36117120087147, 75.59477761387825, 70.3636135160923, 61.73361919820309, 60.96696853637695, 70.8991339802742, 68.33192333579063, 71.26217409968376, 71.59934520721436, 70.01776367425919, 69.70203101634979, 69.59315165877342, 63.895729780197144, 54.87856283783913, 54.99325968325138, 54.73003260791302, 56.063696444034576, 62.58218206465244, 64.59331154823303, 62.377038672566414, 61.866266280412674, 62.50580616295338, 58.45776177942753, 54.288538098335266, 54.21623557806015, 53.570304438471794, 52.93483793735504, 52.33152151107788, 57.94235363602638, 57.31815353035927, 55.42787276208401, 56.55629441142082, 57.608138769865036, 58.39134894311428, 55.68961411714554, 58.207499608397484, 56.83149464428425, 61.70948289334774, 58.238517343997955, 61.48453876376152, 60.49249179661274, 66.45038589835167, 65.88966518640518, 70.89057683944702, 70.61698392033577, 72.58713260293007, 72.3025506734848, 71.63323938846588, 74.016904681921, 81.0325138270855, 84.2495048046112, 83.70696231722832, 4.220391260460019, 1.0864740377292037, 1.1728792637586594, 2.2877650894224644, 5.173343550413847, 2.0678298035636544, 1.1802958720363677, 0.2753860072698444, 2.08789415191859, 36.39390751719475, 49.46684002876282, 63.16146098077297, 32.81103037297726, 50.52514784038067, 62.213442251086235, 63.339751213788986, 67.72546827793121, 77.20041945576668, 70.74686095118523, 26.45958948880434, 1.1793737090192735, 0.033624644347582944, 0.06617597988224588, 0.05272474249068182, 0.030268014306784607, 0.028837181416747626, 0.05413074126408901, 0.00807032163720578, 0.05639292241539806, 0.0048331193920603255, 0.020283996236685198, 0.06405196065315977, 0.051805173279717565, 0.03415497194509953, 0.05466770366183482, 0.020202803425490856, 0.09251115698134527, 0.13720544229727238, 0.09919551783241332, 0.12467628257581964, 0.18170130701037124, 0.09627395702409558, 0.15896558325039223, 0.1662684796610847, 0.14829459803877398, 0.18698817410040647, 0.10757507756352425, 0.13039301644312218, 0.15454034961294383, 0.2571022493066266, 0.5117055389564484, 9.74909981712699, 113.20341154932976, 90.94659984111786, 103.95320311188698, 77.05386132001877, 60.98811440169811, 41.57957285642624, 100.84472671151161, 70.79217731952667, 44.300948828458786, 0.7589725800789893, 0.36956238036509603, 6.376517163589597, 8.709579147398472, 8.497690167278051, 7.1111673675477505, 4.380628662183881, 1.7019690480083227, 107.73956313729286, 103.44919815659523, 103.6597828567028, 98.93328487873077, 90.22231310606003, 81.91313937306404, 81.20793521404266, 76.92722171545029, 87.1011757850647, 83.91355723142624, 87.04488560557365, 76.29955619573593, 73.07950258255005, 69.98804926872253, 68.91993418335915, 66.97327584028244, 68.32601845264435, 63.93358334898949, 69.04469668865204, 67.21605241298676, 70.39300873875618, 69.54569980502129, 63.75151991844177, 69.50169816613197, 66.59384340047836, 60.52775390446186, 64.37448129057884, 68.14543694257736, 66.40274405479431, 66.38958156108856, 71.58932134509087, 74.01171416044235, 74.10253688693047, 69.59097817540169, 68.10133650898933, 67.82889872789383, 68.05348947644234, 66.73584178090096, 66.51048347353935, 64.31444451212883, 61.15553721785545, 60.99235497415066, 61.553144082427025, 63.086566999554634, 66.95293933153152, 70.52985459566116, 66.87727019190788, 66.45721033215523, 68.47651317715645, 66.40390679240227, 64.63713079690933, 67.43341594934464, 71.47022053599358, 79.38870683312416, 77.36630335450172, 59.999810233712196, 78.48803356289864, 72.85387828946114, 65.87251290678978, 63.50163012742996, 74.87846285104752, 72.81015783548355, 78.95935267210007, 77.02758193016052, 74.69177886843681, 75.0481541454792, 71.50142446160316, 67.14172840118408, 59.37235750257969, 57.82513752579689, 58.461128398776054, 59.55084532499313, 63.706819117069244, 69.32281896471977, 64.38550069928169, 64.83016043901443, 67.55943238735199, 61.011809930205345, 57.90995657444, 58.464498817920685, 57.60795637965202, 56.90891169011593, 56.337775737047195, 60.56730218231678, 60.99999636411667, 58.20352502167225, 60.06888672709465, 61.60297080874443, 59.622251093387604, 59.16883662343025, 59.304386749863625, 62.10551664233208, 64.09242242574692, 61.8648337572813, 64.07504975795746, 64.30826604366302, 68.70516210794449, 69.74536389112473, 72.05459117889404, 72.9445718228817, 76.06347486376762, 75.54186165332794, 76.15947291254997, 80.56060954928398, 86.13082185387611, 90.00486597418785, 83.41930255293846, 3.708344274200499, 1.5838969149626791, 15.136570427566767, 5.306169698014855, 8.940064329653978, 4.023919003084302, 1.1175801185891032, 0.3662467317190021, 6.022048909217119, 50.38172073662281, 60.32865218818188, 107.4030151963234, 53.077136501669884, 49.22377087175846, 66.09262749552727, 74.7787258028984, 79.81933012604713, 94.72987443208694, 81.33768305182457, 24.18787568807602, 0.8641046262346208, 0.15838464489206672, 0.1249416300561279, 0.15444133226992562, 0.15119473304366693, 0.19479647307889536, 0.17965691280551255, 0.0702822903986089, 0.1874819991644472, 0.18065401789499447, 0.13549958617659286, 0.16826513892738149, 0.13121004682034254, 0.0754322312423028, 0.1277663034852594, 0.10641083339578472], [0.03480151615804061, 0.017153546832560096, 0.03986803218140267, 0.020633761159842834, 0.08606256160419434, 0.020836827607126907, 0.024875387462088838, 0.06097320554545149, 0.030238450854085386, 0.036839817330474034, 0.022070701925258618, 0.061622184002771974, 0.01034464432450477, 0.0618789299915079, 0.06144161205156706, 25.478345341980457, 80.02011895179749, 68.88309136033058, 64.79592427611351, 38.90439100563526, 22.01385274529457, 35.340889021754265, 57.238984778523445, 32.52330981194973, 12.429178655147552, 0.41949692589696497, 0.6867869035340846, 1.2792505184188485, 3.022380145266652, 2.8373811347410083, 0.510066223796457, 1.3839744427241385, 32.826001569628716, 113.94260108470917, 85.38101568818092, 94.84716653823853, 76.06667429208755, 71.54465854167938, 68.07662263512611, 67.02938362956047, 69.00142461061478, 67.50033795833588, 66.90329879522324, 67.66194328665733, 63.33334095776081, 63.29384207725525, 61.22701518237591, 62.543834522366524, 60.10625012218952, 58.586172088980675, 58.25297176837921, 59.964479729533195, 59.353582710027695, 57.85577908158302, 61.59992717206478, 61.11359126865864, 60.48469461500645, 54.33606214821339, 55.21993272006512, 55.769900009036064, 56.85261771082878, 60.61657413840294, 66.40028178691864, 66.78067937493324, 66.23786330223083, 64.29676786065102, 61.76714099943638, 60.28680123388767, 59.314068630337715, 60.07312349975109, 61.23107336461544, 56.5090287476778, 52.68313564360142, 52.17251904308796, 53.10192637145519, 53.5422657430172, 53.24746996164322, 55.163703337311745, 58.541076108813286, 61.27076603472233, 63.31170491874218, 59.74814213812351, 59.108305871486664, 55.94562917947769, 60.52179962396622, 65.48401415348053, 70.46386733651161, 65.00961720943451, 47.195827290415764, 76.10932320356369, 66.61924123764038, 60.92137098312378, 57.5005741417408, 67.59714156389236, 64.84079226851463, 67.09842592477798, 64.25613284111023, 68.60145047307014, 64.07295227050781, 64.96059983968735, 64.36263352632523, 59.06964294612408, 51.48546651005745, 52.57209800183773, 50.4784369468689, 60.750490352511406, 60.15921168029308, 63.46207045018673, 56.37006260454655, 60.46410731971264, 56.280957385897636, 55.364955738186836, 50.91514751315117, 51.13730639219284, 50.63872754573822, 48.607356548309326, 50.5838280916214, 54.72398713231087, 52.610373347997665, 55.75531259179115, 53.98970313370228, 56.02166309952736, 53.77334274351597, 56.27870790660381, 54.03758816421032, 56.7377270758152, 55.451959669589996, 65.72927579283714, 65.01051396131516, 71.94240599870682, 68.32313060760498, 77.55500882863998, 70.38053780794144, 73.96221801638603, 74.03101712465286, 75.1866415143013, 71.09994560480118, 77.85620346665382, 70.97601145505905, 87.21276059746742, 50.673161298036575, 1.2851402023807168, 1.8018576130270958, 4.961667358875275, 1.5106292464770377, 2.5313495937734842, 0.5877578048966825, 0.18568500730907544, 0.15254207246471196, 18.345132507383823, 27.533269375562668, 44.03763435781002, 58.46534237265587, 9.175336305052042, 20.280760042369366, 35.60111425817013, 56.193619072437286, 53.80221739411354, 65.1137924194336, 56.29991076886654, 18.363838903605938, 0.5795004323590547, 0.03421970206545666, 0.044707065098918974, 0.0821956159779802, 0.061194187437649816, 0.034510779805714265, 0.07266737491590902, 0.059719332202803344, 0.049670556181808934, 0.02126595409208676, 0.031685256617492996, 0.030668171057186555, 0.07231169322039932, 0.012952651450177655, 0.03854843424051069, 0.02536636824515881, 0.10221245203865692, 0.0586486209067516, 0.06079169477743562, 0.04205635479593184, 0.036264608352212235, 0.024158068335964344, 0.014831483640591614, 0.02379172383371042, 0.04323034707340412, 0.02059486705547897, 0.07648930186405778, 0.08933449033065699, 0.09154463579761796, 0.032936491625150666, 42.12010145187378, 94.96921598911285, 80.98266810178757, 73.32759127020836, 49.53072980046272, 31.697156243026257, 34.89244848489761, 43.48447524011135, 39.66436542570591, 12.568678669631481, 0.5530725535936654, 1.8209160841070116, 4.115563435479999, 6.239675106480718, 4.206890109926462, 1.4013803587295115, 1.1157487356103957, 41.92159630358219, 116.84580489993095, 90.16128078103065, 97.66056597232819, 79.62891474366188, 74.05726611614227, 72.05125495791435, 71.47459030151367, 72.19111785292625, 69.44194257259369, 68.96417900919914, 70.40490970015526, 67.59282499551773, 65.18193796277046, 63.48807245492935, 65.27330785989761, 63.226806074380875, 62.30398379266262, 62.63862803578377, 62.63140082359314, 63.34771178662777, 60.43554425239563, 63.008849769830704, 63.94778698682785, 63.95481660962105, 58.081942945718765, 57.89168335497379, 59.16445925831795, 58.69220159947872, 63.00846979022026, 69.23986941576004, 69.36551347374916, 68.22188124060631, 66.75370082259178, 65.89804753661156, 63.516270741820335, 62.6178165525198, 62.12726667523384, 63.193766847252846, 60.20186819136143, 56.394955068826675, 56.18859954178333, 55.33750981092453, 55.30581571161747, 59.05333802103996, 58.023255094885826, 62.434502989053726, 64.9140827357769, 68.23289304971695, 64.0347795188427, 64.88737776875496, 60.07504619657993, 63.31768199801445, 68.48143771290779, 75.50456285476685, 68.63852128386497, 51.89685143530369, 78.75836625695229, 70.49786031246185, 63.491883650422096, 61.03393234312534, 72.18056201934814, 67.41603568196297, 68.61379981040955, 68.75271275639534, 69.56029862165451, 65.77072396874428, 69.31526497006416, 68.17100197076797, 62.40854278206825, 53.12856674194336, 56.0147550702095, 53.00098858773708, 62.35622338950634, 63.10097962617874, 66.72812819480896, 59.67071749269962, 62.96419456601143, 61.17120757699013, 57.14973136782646, 53.541243597865105, 53.37409056723118, 52.90140353143215, 50.30464947223663, 52.18988411128521, 57.49571420252323, 55.02851419150829, 57.8345800191164, 57.60967008769512, 58.376115560531616, 56.28001883625984, 59.01723995804787, 57.49490104615688, 59.34343725442886, 57.841168865561485, 66.71485170722008, 70.32092660665512, 74.85154509544373, 72.55413517355919, 79.4544205069542, 76.30434393882751, 77.88840293884277, 77.71105125546455, 77.96837344765663, 76.85355126857758, 80.92406004667282, 76.49124071002007, 84.60716441273689, 72.0295125246048, 3.4874414652585983, 2.295069247484207, 0.7629120780620724, 1.6957382136024535, 3.814119673334062, 1.3685728004202247, 0.6030350632499903, 0.21685553627321497, 18.45785915851593, 34.33353267610073, 43.92430163919926, 43.17367471754551, 18.037183731794357, 38.569438979029655, 45.744134187698364, 62.82727651298046, 63.692995458841324, 71.88249081373215, 71.54199108481407, 29.14232913404703, 0.7297595695126802, 0.022302964462141972, 0.0773808809753973, 0.005012478395656217, 0.06066594156436622, 0.0917488377308473, 0.0312902448058594, 0.040398014680249617, 0.03165626461850479, 0.03876507827953901, 0.021714081412937958, 0.06015803795889951, 0.038947019493207335, 0.014547439604939427, 0.027401778752391692, 0.13469048193655908, 0.2472078474238515, 0.17495641659479588, 0.09628691492252983, 0.14346657117130235, 0.12020868714898825, 0.12004370029899292, 0.1378255512099713, 0.1408056600484997, 0.2846729167504236, 0.16536019480554387, 0.22511866787681356, 0.22402450471417978, 0.1639021121081896, 0.17880872706882656, 47.81935103237629, 110.698631554842, 93.3283120393753, 88.15319493412971, 59.49638284742832, 34.72654178738594, 49.59085397422314, 83.8450925052166, 53.69758240878582, 20.82971278578043, 0.9038552432321012, 2.029206301085651, 4.353039292618632, 14.255045279860497, 6.559236533939838, 6.39026197604835, 2.4604601226747036, 40.04037044942379, 123.73105064034462, 94.75955843925476, 102.81300589442253, 84.04628410935402, 78.84899139404297, 75.95430672168732, 74.24801588058472, 75.99117994308472, 73.73701930046082, 75.28593018651009, 76.79219216108322, 72.56438702344894, 69.78303506970406, 67.73016482591629, 69.29796829819679, 67.93856084346771, 66.3640621304512, 65.93802139163017, 66.05519190430641, 67.48391523957253, 61.73741899430752, 67.5606407225132, 68.81007447838783, 66.69139176607132, 61.92041337490082, 61.525789350271225, 63.315379321575165, 64.8100671172142, 66.24189868569374, 72.12231114506721, 72.3743288218975, 70.21488949656487, 69.1137845814228, 67.10738584399223, 66.88078880310059, 66.04788109660149, 66.83048710227013, 69.18136775493622, 65.88957399129868, 60.38407601416111, 59.232844188809395, 59.216277077794075, 60.290164053440094, 61.32750079035759, 61.1727274954319, 65.45209586620331, 66.60263612866402, 72.88856282830238, 66.60822942852974, 67.25436195731163, 63.467074781656265, 65.70843771100044, 71.82874649763107, 78.30613732337952, 72.16807588934898, 57.51574672758579, 83.75292465090752, 74.0414209663868, 66.67408749461174, 64.16989266872406, 74.26773682236671, 70.36619737744331, 73.86454045772552, 70.37444293498993, 73.04131463170052, 69.49865072965622, 70.76693147420883, 73.08600783348083, 65.59627532958984, 57.01006606221199, 59.2432252317667, 55.65986551344395, 67.60434597730637, 66.21599167585373, 69.97238650918007, 61.5727586299181, 67.24433049559593, 64.60459694266319, 61.910412311553955, 55.676379427313805, 55.88265135884285, 57.48999930918217, 53.77755671739578, 56.02561108767986, 60.40090911090374, 58.627118691802025, 61.757018342614174, 59.82348829507828, 61.61331385374069, 59.81542132794857, 60.93069188296795, 61.11353047192097, 63.70151460170746, 60.87148725986481, 70.45183718204498, 72.12253913283348, 77.85856693983078, 74.99889358878136, 83.88457998633385, 77.06809535622597, 82.58305862545967, 81.78089126944542, 83.16039964556694, 79.61566865444183, 84.96249094605446, 77.29745104908943, 92.7897821366787, 69.49702441692352, 3.5534930834546685, 4.911767961457372, 13.53750603273511, 4.4391094241291285, 8.908390179276466, 1.3781701354309916, 0.44629786745645106, 0.3472590912133455, 30.774679742753506, 41.704449355602264, 60.33389590680599, 75.2298603951931, 14.299734681844711, 34.4629043340683, 54.52979475259781, 75.15770986676216, 73.81434515118599, 86.54251456260681, 83.2393366098404, 28.358507193624973, 0.782000235049054, 0.195040802937001, 0.24333453417057171, 0.17695448594167829, 0.13132340245647356, 0.11344380327500403, 0.140896380180493, 0.11554010328836739, 0.09931087726727128, 0.12683875247603282, 0.09711619815789163, 0.1728609626297839, 0.18750942894257605, 0.16951271885773167, 0.1711561603588052], [0.05112985229061451, 0.10173049391596578, 0.026624013553373516, 0.02322285650734557, 0.03183157845342066, 0.054086817253846675, 0.03623775002779439, 0.015318300975195598, 0.06138359094620682, 0.03143478177662473, 0.010299434543412644, 0.05015176473534666, 0.06995826130150817, 0.053569169249385595, 2.321797963231802, 76.11924067139626, 74.32712763547897, 71.2658903002739, 58.587038442492485, 50.541429966688156, 29.07869204878807, 62.504879012703896, 35.66968537867069, 31.590361073613167, 1.5375779941678047, 0.03381689028174151, 0.6794947385787964, 3.702799896709621, 4.253152152523398, 1.8042910262010992, 0.6068163353484124, 0.669804367935285, 84.73566591739655, 98.68227034807205, 89.96062874794006, 80.14727532863617, 74.78574022650719, 75.59939816594124, 74.02869164943695, 71.72755032777786, 65.71742802858353, 66.11714377999306, 64.06794413924217, 60.304743871092796, 61.005430072546005, 59.795650988817215, 60.1258684694767, 59.004753828048706, 60.10045163333416, 56.95985175669193, 59.6806463599205, 59.73728612065315, 58.110441416502, 59.00256134569645, 58.71450640261173, 59.85133700072765, 57.28922948241234, 51.49304710328579, 56.36939384043217, 55.63154183328152, 59.4172140955925, 60.32993271946907, 66.21054276823997, 63.949565291404724, 60.50212807953358, 62.317518666386604, 60.51945514976978, 62.8871650993824, 58.45273084938526, 57.03007198870182, 57.16038979589939, 52.136740162968636, 53.61180201172829, 52.495611906051636, 53.73491160571575, 51.436464339494705, 54.07767981290817, 52.867182567715645, 56.83575041592121, 62.9502759128809, 66.18777438998222, 62.708658277988434, 60.42744308710098, 55.27957431972027, 61.96810461580753, 64.82149690389633, 71.10353261232376, 56.16994634270668, 49.284727200865746, 74.70623329281807, 62.940875217318535, 61.47620961070061, 57.87472866475582, 66.5414822101593, 63.15450355410576, 65.18655851483345, 64.08824265003204, 67.77110382914543, 67.56889387965202, 70.14407649636269, 69.77823972702026, 62.036364153027534, 50.33511243760586, 50.25379300117493, 51.03862568736076, 56.82755425572395, 56.69261209666729, 58.58612649142742, 57.38745801150799, 58.08129698038101, 58.52005183696747, 52.05457717180252, 50.57989150285721, 49.66543257236481, 50.60240909457207, 48.88229839503765, 46.23471446335316, 53.2244735956192, 53.98309908807278, 52.70074009895325, 52.43299886584282, 54.64609891176224, 53.615590408444405, 54.312283024191856, 54.86202992498875, 54.452955275774, 63.054378926754, 71.10866993665695, 73.08881968259811, 72.77687922120094, 72.61783495545387, 72.7911588549614, 75.49399182200432, 76.79464682936668, 78.85992720723152, 77.64305010437965, 76.61583602428436, 75.15678271651268, 83.4372527897358, 77.5934399664402, 81.1722019314766, 43.073048517107964, 1.4224413223564625, 1.7584068258292973, 3.7859104620292783, 1.701596905477345, 1.2542882328853011, 0.15551171702099964, 0.29960914340335876, 4.01408133096993, 28.49931813776493, 30.316069051623344, 47.083132937550545, 32.5248297303915, 21.49590063840151, 29.000858925282955, 38.73398534953594, 55.220947265625, 59.36920367181301, 57.154158130288124, 49.33561787009239, 13.01720755174756, 0.3799901786260307, 0.02146394796000095, 0.12397970276651904, 0.03905194433173165, 0.02742959259194322, 0.01945654053997714, 0.05570308872847818, 0.07154317703680135, 0.08155804433044977, 0.07821210863767192, 0.03011584805790335, 0.029799767362419516, 0.024578118354838807, 0.027243512049608398, 0.025480634867562912, 0.10724402774940245, 0.06502955468022265, 0.024260983809654135, 0.028901397599838674, 0.06326203350909054, 0.05704268754925579, 0.025571436635800637, 0.0684934770106338, 0.05181636857741978, 0.035841554490616545, 0.0674221126246266, 0.08353062090463936, 0.21232761908322573, 4.73151845857501, 93.99967521429062, 84.39170837402344, 80.56141510605812, 74.38662484288216, 65.39797157049179, 42.95623518526554, 46.973843201994896, 36.60484179854393, 41.21283933520317, 1.2424389249645174, 0.16880220151506364, 3.757925438694656, 6.816424308344722, 4.6365416049957275, 3.5303143272176385, 1.4207422197796404, 1.0495192394591868, 87.31974765658379, 102.1171036362648, 91.98159590363503, 85.95168426632881, 77.17433005571365, 79.70313236117363, 77.32724905014038, 77.63336062431335, 69.63471382856369, 68.98053333163261, 67.24468007683754, 64.08691272139549, 63.40108372271061, 64.39376905560493, 64.0764632821083, 62.01419614255428, 63.08478109538555, 61.00338578224182, 65.01077994704247, 62.77338020503521, 62.52393499016762, 62.69357308745384, 61.745991334319115, 63.79707187414169, 61.3038394600153, 54.91516247391701, 59.10932421684265, 58.560823649168015, 64.19896110892296, 63.11881586909294, 69.73344013094902, 66.32044047117233, 62.76809088885784, 63.415279760956764, 64.75570723414421, 66.09904155135155, 62.68754281103611, 59.29461747407913, 59.978474378585815, 56.3429244607687, 56.28968931734562, 56.43587127327919, 57.65796549618244, 54.454665184020996, 57.02121086418629, 55.842935889959335, 60.22540032863617, 67.03683122992516, 68.71808141469955, 63.99032190442085, 63.20809207856655, 58.59616555273533, 63.68072971701622, 67.35168993473053, 76.94581031799316, 59.102492183446884, 52.49767519533634, 76.85190975666046, 66.0892304778099, 64.29157733917236, 60.51481179893017, 68.41329976916313, 67.2283485531807, 69.8475632071495, 67.46102526783943, 71.28859788179398, 70.36752730607986, 73.90557065606117, 72.28409886360168, 65.46043261885643, 52.19437927007675, 52.521233931183815, 54.163623601198196, 58.767433762550354, 60.1011697947979, 61.642686277627945, 60.40099270641804, 61.33563995361328, 62.72864520549774, 55.24174354970455, 53.46892207860947, 53.922830522060394, 53.40698540210724, 52.931703105568886, 49.77890968322754, 56.0914995521307, 54.948380291461945, 56.95801265537739, 55.69110743701458, 57.99294412136078, 57.726107239723206, 58.38706277310848, 56.03262551128864, 59.0995055437088, 66.3083191215992, 74.36323329806328, 74.85559567809105, 76.06795862317085, 76.69404342770576, 77.88470193743706, 78.35375636816025, 81.23964831233025, 81.56391531229019, 81.5685586631298, 79.2136350274086, 80.25370761752129, 84.06557947397232, 81.7687015235424, 76.57390147447586, 67.22396358847618, 1.710066650994122, 1.8876761267893016, 3.7640699464827776, 2.164833848364651, 3.4247949393466115, 1.3892077119089663, 0.48084757290780544, 2.3458117246627808, 38.47546622157097, 39.65021498501301, 40.00716023147106, 26.705597788095474, 28.29226154834032, 36.77739053964615, 55.984459295868874, 64.9221383035183, 68.76367896795273, 64.70263928174973, 64.24447506666183, 20.177812166512012, 0.27074360637925565, 0.010070526514027733, 0.024512172967661172, 0.04606662769219838, 0.043400425056461245, 0.06243886557058431, 0.07903640464064665, 0.09843076433753595, 0.07834641510271467, 0.026486671704333276, 0.04801661329111084, 0.084280620503705, 0.046475295021082275, 0.07341079908655956, 0.15595212229527533, 0.29208094580098987, 0.1728816982358694, 0.15375906106783077, 0.11613423703238368, 0.1998910348629579, 0.18210076057584956, 0.09636340808356181, 0.20542834710795432, 0.14943116751965135, 0.15851121075684205, 0.1930472458479926, 0.373639710014686, 0.3061424772022292, 4.755890350788832, 111.05444446206093, 98.3188046514988, 96.83608621358871, 83.05192306637764, 72.7957110106945, 43.09356361627579, 85.56370988488197, 53.16782243549824, 53.11237581074238, 2.825977709144354, 0.12811348016839474, 3.6095510004088283, 11.85529449954629, 10.269321352243423, 8.539031948894262, 4.7599689569324255, 0.9701436362229288, 92.54897385835648, 107.19236209988594, 99.6456478536129, 89.45664659142494, 83.32040905952454, 81.98164969682693, 82.59956493973732, 80.49042731523514, 72.52046138048172, 71.68424025177956, 73.48947778344154, 67.57963970303535, 67.85663723945618, 66.93121209740639, 67.77263894677162, 64.29133415222168, 66.93513348698616, 63.26312452554703, 67.21207782626152, 66.02990806102753, 64.2201791703701, 66.31011262536049, 65.50720810890198, 65.56436464190483, 65.98766192793846, 59.68240946531296, 64.16359260678291, 63.120001405477524, 68.53337332606316, 66.01328015327454, 73.65266382694244, 68.56086865067482, 65.4775620996952, 67.82411098480225, 68.11222672462463, 70.22239029407501, 65.29787734150887, 62.691243812441826, 63.80730852484703, 59.22514580190182, 58.97629335522652, 61.80635489523411, 61.19301840662956, 59.1069645434618, 59.63043965399265, 60.0981679558754, 63.73479701578617, 70.51175236701965, 73.21575567126274, 69.2451511323452, 66.95401087403297, 61.13990865647793, 66.97917312383652, 70.79555153846741, 80.82279548048973, 63.758405148983, 58.045396506786346, 79.31857019662857, 69.79377329349518, 67.9117038846016, 64.43762630224228, 73.24148789048195, 70.66179871559143, 73.49773854017258, 71.3727405667305, 74.17195156216621, 73.33528205752373, 77.79337763786316, 75.9250482916832, 69.15081739425659, 54.41711939871311, 55.33487655222416, 56.14918425679207, 62.84741923213005, 63.637773022055626, 65.20215287804604, 62.820729464292526, 64.68766048550606, 65.5641670525074, 57.60568410158157, 56.872540041804314, 55.61647564172745, 56.33276380598545, 55.91291293501854, 54.69458431005478, 58.5175059735775, 57.66564108431339, 59.69808742403984, 58.077257797122, 59.95398089289665, 60.16205012798309, 60.3368179500103, 61.29468195140362, 61.14540696144104, 70.35835459828377, 76.98774486780167, 79.4277535378933, 80.82393541932106, 79.59014922380447, 80.52892684936523, 81.54240846633911, 83.4709569811821, 86.29025369882584, 85.95761194825172, 84.40115466713905, 83.28019201755524, 88.46989274024963, 85.18537938594818, 81.87543779611588, 64.3428061902523, 2.839591666124761, 6.6437335498631, 13.2095836289227, 4.709271602332592, 6.30597204901278, 0.7717880455311388, 0.6127369520254433, 6.308950614184141, 50.70534937083721, 50.00139534473419, 69.07327115535736, 42.296978160738945, 28.663640320301056, 43.64641115069389, 59.25033465027809, 76.12171053886414, 81.01542234420776, 79.29177403450012, 78.01140993833542, 19.80087049305439, 0.2609610906802118, 0.09215621001203544, 0.12194991402793676, 0.16778018994955346, 0.10462016463861801, 0.1035222684731707, 0.14031863305717707, 0.16458427940960974, 0.1891361127491109, 0.13137965725036338, 0.10977328929584473, 0.1714170549530536, 0.12859841430326924, 0.1866893409169279], [0.13402642303844914, 0.04455016394786071, 0.03645814933406655, 0.025528189835313242, 0.07613085937919095, 0.043070106257800944, 0.034041193284792826, 0.05299179691064637, 0.07079566363245249, 0.05810019974887837, 0.07778847590088844, 0.06485287158284336, 0.18580188072519377, 0.32446194731164724, 20.315604172647, 90.36956280469894, 61.17265149950981, 64.21747371554375, 36.832464784383774, 17.803610265254974, 22.61117309331894, 56.34884834289551, 44.904683232307434, 17.490953542292118, 0.23357129946816713, 0.3084900387329981, 2.136124726384878, 6.1044009402394295, 2.338185771368444, 1.2573198764584959, 0.36403652688022703, 5.163753340020776, 103.35945457220078, 88.66821929812431, 93.19111660122871, 83.60727846622467, 86.8416041135788, 85.41261479258537, 85.73967844247818, 80.34190848469734, 80.60728624463081, 70.87445050477982, 66.82028084993362, 61.606223434209824, 60.33421128988266, 60.1907803863287, 60.585237219929695, 58.48390057682991, 59.76003549993038, 58.182143568992615, 59.98630575835705, 59.343969225883484, 59.92226779460907, 59.161370024085045, 59.67803210020065, 59.204322919249535, 53.20884123444557, 53.00380803644657, 56.73725210130215, 55.695408806204796, 58.2623116672039, 59.53820340335369, 65.45230865478516, 61.27330809831619, 60.77486224472523, 59.657471403479576, 64.21243518590927, 60.460999086499214, 58.812719732522964, 56.17408812046051, 53.13966974616051, 52.529046311974525, 55.274794176220894, 51.805952712893486, 52.82982677221298, 52.25441224873066, 56.07202559709549, 53.01800787448883, 57.805728167295456, 64.47001576423645, 72.00428947806358, 66.0357141494751, 65.37990733981133, 58.73734697699547, 58.56333911418915, 65.20163610577583, 70.46408772468567, 55.0374399125576, 52.133042961359024, 73.12100395560265, 63.818966299295425, 59.34911035001278, 56.55734695494175, 66.17443710565567, 66.14498108625412, 64.18652057647705, 68.59325811266899, 69.61910426616669, 67.21777752041817, 69.44448843598366, 67.43026971817017, 63.50451037287712, 49.749886840581894, 52.864910289645195, 50.9096872061491, 54.38671723008156, 54.91791732609272, 54.87986996769905, 57.26923115551472, 55.07737196981907, 56.441620364785194, 55.611148327589035, 51.50809429585934, 52.80661761760712, 48.795058876276016, 49.94735084474087, 45.14256566762924, 48.283469527959824, 55.0783447176218, 53.05763594806194, 53.322337344288826, 55.87001323699951, 53.384274020791054, 56.05765476822853, 53.841127306222916, 58.767821341753006, 68.35210785269737, 72.23698899149895, 73.39501485228539, 74.19429436326027, 73.57963174581528, 77.03975647687912, 74.35232028365135, 75.91828465461731, 76.28519296646118, 75.38336455821991, 72.75955215096474, 77.37868309020996, 74.10124495625496, 78.1215052306652, 72.03996956348419, 82.77555629611015, 24.212918244302273, 2.5617273012176156, 2.488729893229902, 0.9057072876021266, 2.3423453606665134, 0.807079483056441, 0.14951644028769806, 0.1259529250091873, 16.232457272708416, 23.433116488158703, 39.73546341061592, 48.4835097938776, 30.0316771119833, 20.74890062212944, 16.207718700170517, 19.818353354930878, 46.21904410421848, 55.374508425593376, 51.34958200156689, 49.40263107419014, 5.967663377523422, 0.24438140768324956, 0.03612571912526619, 0.04972872200596612, 0.0849931564880535, 0.09917969524394721, 0.01685023664322216, 0.04958525372785516, 0.021324181143427268, 0.0066483221598900855, 0.04173395471298136, 0.03635359556938056, 0.06986391206737608, 0.02990487959323218, 0.009330014345323434, 0.025394525328010786, 0.043930225729127415, 0.03831262423773296, 0.05733573569159489, 0.05246480897767469, 0.02698171760130208, 0.04811454338778276, 0.03983602706284728, 0.007199227193268598, 0.036239672190276906, 0.03078516136156395, 0.29462487960699946, 0.3389446920482442, 29.248957112431526, 104.8902328312397, 70.53430035710335, 75.91941699385643, 50.17174020409584, 35.2541396766901, 21.102285459637642, 40.34365877509117, 51.12535983324051, 19.747914634644985, 0.5274964228738099, 1.5485205757431686, 5.604175357148051, 11.299390979111195, 4.6658803056925535, 1.5038447105325758, 0.617533007171005, 8.314482048153877, 108.5857929289341, 91.97717294096947, 96.42453789710999, 87.53080353140831, 90.67922338843346, 89.15856778621674, 90.2076306939125, 84.63853552937508, 85.25092586874962, 74.81964960694313, 69.1102659702301, 63.67567598819733, 64.75434690713882, 64.09981682896614, 63.59789416193962, 61.51381239295006, 63.53267066180706, 61.2066862732172, 63.74105527997017, 64.16673123836517, 62.92422071099281, 61.62594437599182, 61.86116315424442, 62.02347904443741, 56.14195704460144, 57.721570283174515, 59.298238679766655, 60.77681913971901, 61.9877153635025, 61.858043521642685, 67.32826039195061, 63.86263355612755, 64.59826648235321, 63.81948307156563, 65.47785088419914, 62.79466286301613, 63.72640706598759, 60.32883457839489, 56.06004483997822, 56.11540026962757, 58.79897207021713, 56.46875090897083, 58.11346985399723, 56.65659382939339, 57.73100137710571, 55.34353628754616, 61.452814266085625, 67.91611924767494, 74.37055170536041, 70.03170892596245, 68.87177556753159, 62.46479116380215, 62.74780757725239, 68.35422053933144, 74.70902234315872, 60.50919950008392, 60.98761282861233, 74.06564846634865, 68.58303666114807, 62.829731181263924, 60.004320591688156, 69.19339030981064, 69.49381738901138, 65.43524757027626, 72.90725022554398, 72.22603797912598, 71.94096967577934, 70.18054693937302, 69.33955326676369, 64.87932220101357, 52.63233996927738, 53.86314332485199, 54.12723295390606, 56.60865940153599, 57.68968619406223, 57.64339327812195, 60.47252006828785, 57.33405187726021, 60.63208490610123, 58.39691564440727, 55.35890646278858, 53.59178848564625, 50.720890536904335, 53.65408234298229, 50.57152435183525, 53.22628989815712, 55.811146795749664, 55.657908618450165, 55.46377323567867, 57.91292041540146, 56.255608946084976, 57.79446557164192, 56.76506280899048, 60.25900572538376, 70.85133254528046, 75.98810970783234, 75.88403329253197, 77.48546496033669, 74.39031824469566, 78.10591086745262, 76.61455169320107, 77.07603693008423, 77.56173446774483, 79.82568338513374, 75.65714746713638, 79.35888603329659, 77.24268838763237, 81.0422033071518, 74.5806348323822, 83.66525575518608, 44.45031501352787, 1.8671572278253734, 1.1537711578421295, 3.004941693507135, 3.120295428670943, 3.0682952189818025, 0.5743492743931711, 0.7617520715575665, 14.50843658298254, 37.48989790678024, 42.69420124590397, 30.325826928019524, 29.607731960713863, 44.806317910552025, 34.20520976185799, 27.4123864620924, 53.493240773677826, 65.98654478788376, 64.31840389966965, 61.874302849173546, 7.720000147819519, 0.30764648399781436, 0.08548212048481219, 0.07869077904615551, 0.07475724050891586, 0.05678234214428812, 0.07488989940611646, 0.04951312439516187, 0.019891960437234957, 0.07207407237729058, 0.05766998045146465, 0.06957949139177799, 0.04082580344402231, 0.07866771309636533, 0.2020815431023948, 0.07745269118458964, 0.17670788511168212, 0.16065886738942936, 0.1648086603381671, 0.0864523152995389, 0.11537234822753817, 0.13665450154803693, 0.26619038195349276, 0.1630870855296962, 0.242835751560051, 0.17698173760436475, 0.5030225298833102, 0.8510380773805082, 32.82838024199009, 120.99104046821594, 79.98038068413734, 88.01130294799805, 56.00487560033798, 34.261788725852966, 33.8729327917099, 78.60844910144806, 64.77982833981514, 28.646499440073967, 0.6058341474272311, 1.5160762541927397, 7.096134899184108, 17.508630193769932, 7.970924433320761, 5.390727510675788, 2.7714382857084274, 8.181849215179682, 111.17499679327011, 95.03983899950981, 103.71653661131859, 91.72056511044502, 94.63152810931206, 93.10548439621925, 93.81986886262894, 89.48443070054054, 88.32195147871971, 77.66877472400665, 73.31095576286316, 67.1458549797535, 68.42008620500565, 67.49705493450165, 68.5726024210453, 65.39233267307281, 66.63871139287949, 64.66540887951851, 66.44291549921036, 66.69131577014923, 67.27051109075546, 65.23638904094696, 64.45743083953857, 65.34408286213875, 60.05594842135906, 62.29611821472645, 64.51204150915146, 64.46840465068817, 64.28150787949562, 65.27786001563072, 71.70010060071945, 68.72828766703606, 66.54639914631844, 66.50265589356422, 70.99762469530106, 68.38037833571434, 68.19514587521553, 63.07947278022766, 60.47438196837902, 59.676876962184906, 63.61959099769592, 62.4504317343235, 61.964718997478485, 59.52961206436157, 60.48686049878597, 59.00381527841091, 65.23005858063698, 71.92525371909142, 77.77355030179024, 72.27891594171524, 71.94631978869438, 66.06631770730019, 65.65217033028603, 72.78371885418892, 77.2768485546112, 64.18256878852844, 62.94109180569649, 75.97889140248299, 73.28382521867752, 64.5951734483242, 62.99472592771053, 72.35334634780884, 73.43364357948303, 69.78335425257683, 77.19095036387444, 75.1700896024704, 72.13159784674644, 74.47359457612038, 74.10515874624252, 68.88271898031235, 57.38433077931404, 57.17819184064865, 57.07741364836693, 59.011570662260056, 60.846609994769096, 60.984128415584564, 64.12385433912277, 58.09301555156708, 62.357693910598755, 61.961287781596184, 59.267350137233734, 57.41061396896839, 53.561583906412125, 56.80804990231991, 52.892189025878906, 56.83360353112221, 59.86532025039196, 57.10293687880039, 58.106869608163834, 61.73434115946293, 59.89837847650051, 62.31202036142349, 59.91567514836788, 63.99008631706238, 76.62611827254295, 79.40581351518631, 79.62345823645592, 80.91173350811005, 75.14181151986122, 81.34898364543915, 76.26133784651756, 81.31392672657967, 81.6302977502346, 82.3513014614582, 77.5940403342247, 84.53485429286957, 80.89245334267616, 84.77075323462486, 75.77664345502853, 87.30592399835587, 45.47015368938446, 3.005205779336393, 11.789991203695536, 8.620612621307373, 6.701866630464792, 4.082849090918899, 0.6148263055365533, 1.316612963564694, 26.984409727156162, 42.92193062603474, 59.82089303433895, 65.84868058562279, 40.1554586738348, 35.14611527323723, 26.499221362173557, 37.13810138404369, 67.96417146921158, 78.54978784918785, 79.48674157261848, 73.79102200269699, 8.409707788378, 0.29170550813432783, 0.17446636164095253, 0.17927625041920692, 0.23832594277337193, 0.16381171852117404, 0.12705004191957414, 0.10773679896374233, 0.05344873352441937, 0.16848879255121574, 0.12381652675685473, 0.14970752847148106, 0.1295022462727502, 0.16829884727485478], [0.01934896437887801, 0.026958126582030673, 0.016297280963044614, 0.03182626096531749, 0.10771693909191526, 0.021684208113583736, 0.11445236712461337, 0.018026342186203692, 0.071560253854841, 0.03016238442796748, 0.11294568117591552, 0.037903667471255176, 0.06211951200384647, 0.06851081358036026, 60.480826422572136, 79.79381069540977, 67.71883383393288, 45.63341572880745, 33.15550468862057, 30.41843555867672, 76.41955375671387, 68.9553938806057, 37.0525261759758, 3.0168329179286957, 0.12538461800431833, 0.9634457831270993, 4.037354132160544, 5.469061732292175, 7.177484259009361, 6.157680731266737, 1.454176150728017, 40.108470395207405, 100.83301573991776, 96.68724820017815, 89.4096127152443, 91.06706857681274, 89.01362836360931, 90.4162546992302, 85.66523283720016, 84.87897902727127, 79.20643821358681, 76.78843036293983, 71.57273903489113, 67.34279841184616, 60.99302373826504, 59.72119018435478, 59.25026245415211, 60.299082174897194, 59.24789138138294, 58.155997171998024, 58.1726098805666, 60.518136620521545, 57.601173743605614, 59.23529125750065, 58.03175523877144, 57.08766169846058, 51.73769697546959, 55.032982751727104, 57.077102065086365, 56.02632164955139, 60.966428965330124, 64.54118594527245, 62.598372995853424, 58.12763549387455, 56.262706965208054, 61.670812368392944, 58.559881299734116, 55.991990491747856, 55.41803888976574, 54.992131143808365, 54.4138515740633, 55.08634328842163, 55.71661926805973, 55.464263409376144, 56.31131775677204, 56.34596049785614, 55.79117886722088, 52.99976505339146, 53.80911402404308, 66.12363383173943, 72.1067775785923, 68.48077654838562, 70.33033490180969, 64.66263502836227, 61.62799246609211, 62.831334695219994, 72.79454067349434, 53.597180396318436, 61.976733952760696, 73.6820438504219, 60.66102035343647, 63.37609626352787, 56.07968218624592, 67.77179539203644, 66.22932136058807, 66.68484091758728, 66.5545155107975, 65.6313094496727, 64.79626625776291, 69.10559982061386, 65.10798633098602, 56.38007506728172, 48.72511602938175, 50.628810077905655, 50.9475901722908, 52.074757888913155, 53.670790046453476, 54.23785261809826, 53.308316096663475, 55.657137259840965, 53.56580547988415, 54.87491503357887, 53.52996960282326, 52.71212808787823, 51.20930872857571, 51.05567157268524, 47.91287161409855, 46.67117044329643, 50.599525049328804, 54.06174726784229, 51.36822760105133, 53.87067072093487, 51.295856684446335, 54.8528154194355, 54.27696771919727, 59.712644442915916, 67.62353494763374, 74.71336171030998, 73.20511624217033, 74.18787270784378, 72.16604679822922, 70.87983101606369, 72.53930076956749, 73.55709135532379, 72.269446849823, 76.71462312340736, 73.8224159181118, 73.46620783209801, 79.06233474612236, 77.74682253599167, 78.91652137041092, 79.61835131049156, 71.51928350329399, 7.906987639144063, 1.7552452767267823, 1.8824951048009098, 2.0201302506029606, 3.7821857118979096, 1.677661039866507, 0.09643113648053259, 5.6551614962518215, 30.24157974869013, 24.83830388635397, 59.63670551776886, 44.20053921639919, 12.19490222632885, 11.948256511241198, 19.792643934488297, 33.8551839441061, 49.40170392394066, 51.45833216607571, 51.61844417452812, 23.71804039925337, 0.3657996322726831, 0.02209174923336832, 0.06149105764052365, 0.10751908994279802, 0.018988377087225672, 0.021280284963722806, 0.0588233966846019, 0.0497109772550175, 0.007112618095561629, 0.07039864431135356, 0.013619806959468406, 0.029104564237059094, 0.05805364482512232, 0.11692768195644021, 0.037405066686915234, 0.03811490496445913, 0.03660699076135643, 0.08073345146840438, 0.050048602497554384, 0.08709897083463147, 0.05243035477178637, 0.09006825916003436, 0.019509748817654327, 0.07731382793281227, 0.05503656590008177, 0.1156994052871596, 0.2178178049507551, 73.27966824173927, 91.44901648163795, 78.34935620427132, 63.660153821110725, 41.41780033707619, 39.01352874934673, 52.56558895111084, 53.81954826414585, 48.77143554389477, 2.7405157824978232, 0.10605798670439981, 3.7908418849110603, 6.400344260036945, 9.271389450877905, 18.730853609740734, 3.0337766837328672, 0.981177887879312, 40.708621591329575, 104.50051814317703, 99.71591368317604, 93.95571157336235, 97.10374385118484, 95.58998867869377, 94.42766144871712, 90.11569082736969, 86.99075371026993, 84.10119116306305, 79.95529443025589, 75.38561403751373, 71.23812139034271, 66.12940192222595, 63.51114481687546, 64.97057810425758, 62.87244848906994, 63.05171526968479, 61.14685468375683, 60.160731598734856, 60.70700168609619, 61.788233667612076, 61.9762247800827, 63.06800879538059, 60.96553221344948, 56.26950100064278, 58.86567749083042, 58.74977231025696, 60.76391503214836, 62.909671291708946, 63.28650087118149, 65.07590845227242, 61.728550270199776, 60.41294686496258, 65.43371245265007, 63.16290870308876, 58.561287224292755, 57.671507969498634, 58.26422296464443, 57.26105399429798, 57.54917733371258, 59.59390461444855, 61.12956941127777, 57.591203078627586, 61.20066739618778, 59.94978591799736, 57.53965124487877, 57.51775301992893, 68.07286843657494, 71.26500874757767, 71.75959020853043, 74.17553097009659, 70.56653022766113, 62.266008630394936, 68.33142176270485, 73.51993694901466, 67.65201821923256, 74.99392345547676, 75.19891485571861, 65.6277984380722, 65.18859520554543, 63.831802010536194, 69.21206250786781, 69.96157988905907, 66.61118566989899, 71.32683143019676, 68.60284119844437, 69.90223467350006, 71.56884804368019, 68.6791031062603, 59.80117209255695, 53.489475175738335, 53.88105556368828, 52.095356583595276, 56.06424741446972, 56.51720970869064, 55.210068449378014, 57.54315085709095, 56.567393615841866, 56.83996818959713, 57.73567132651806, 56.881040185689926, 54.51562911272049, 55.19851706922054, 53.19059461355209, 52.20506429672241, 48.313123136758804, 53.05342197418213, 56.36568143963814, 53.42500403523445, 56.30934566259384, 54.64877776801586, 56.62983566522598, 57.19047278165817, 58.7965402007103, 71.54734879732132, 76.64637118577957, 75.09844064712524, 76.7715060710907, 76.47587433457375, 70.69261506199837, 73.09444338083267, 73.46743136644363, 76.34475857019424, 75.43650850653648, 76.56822457909584, 75.22330954670906, 82.93090716004372, 77.83493220806122, 81.86368122696877, 76.55020594596863, 87.10576593875885, 15.225634798407555, 4.823353830724955, 1.5686458395794034, 2.1338206250220537, 4.1691377107053995, 2.720191623084247, 0.12863240466685966, 1.8437883630394936, 36.67696192860603, 35.5515269190073, 44.86508175730705, 27.368869297206402, 14.711598381400108, 13.97950116544962, 33.88084016740322, 46.66071720421314, 59.3994652479887, 62.382647171616554, 63.98145318031311, 29.703503921628, 0.32968363899271935, 0.059379513913881965, 0.048584411924821325, 0.011911352394236019, 0.02440882148221135, 0.06132073103799485, 0.024334437875950243, 0.058269888104405254, 0.04906032896542456, 0.03547196865838487, 0.0594966285279952, 0.012001356353721349, 0.03575293092580978, 0.1866360695566982, 0.24100990500301123, 0.09462175075896084, 0.1045772536599543, 0.2870964742032811, 0.1417710309033282, 0.25465440878178924, 0.08265444877906702, 0.21555867773713544, 0.08308353630127385, 0.16126278263982385, 0.11529282710398547, 0.1940142345847562, 0.23554579820483923, 89.54018130898476, 100.46461030840874, 89.9081839621067, 67.53416374325752, 52.58421175181866, 42.26947143673897, 105.3320275247097, 93.66735264658928, 64.1109274327755, 5.275110639631748, 0.23680416896240786, 3.7293419474735856, 12.197805270552635, 13.996422607451677, 15.300602875649929, 11.718561686575413, 2.4456983897835016, 49.453468546271324, 106.77452132105827, 109.83807653188705, 96.64622560143471, 100.40686100721359, 96.43945589661598, 100.19316047430038, 92.52084016799927, 93.5726161301136, 86.29105925559998, 84.94843170046806, 77.66507372260094, 75.56443244218826, 70.33680215477943, 68.02240714430809, 66.41527578234673, 69.07805889844894, 65.71362063288689, 66.14691898226738, 61.943402141332626, 65.76947763562202, 62.18027763068676, 67.24313735961914, 64.00598466396332, 65.56241914629936, 62.06936918199062, 61.40396788716316, 61.91907584667206, 64.44529429078102, 65.22909343242645, 67.59212583303452, 69.48377072811127, 64.2065455019474, 63.03518235683441, 67.52297714352608, 65.17109334468842, 63.018026277422905, 61.21248856186867, 62.554614543914795, 62.653504237532616, 60.75585186481476, 62.48201943933964, 63.518018648028374, 63.39487485587597, 63.508021384477615, 63.04032728075981, 61.896356865763664, 59.593026861548424, 72.98020631074905, 74.95403319597244, 74.4433405995369, 76.47478759288788, 72.36500412225723, 67.32700645923615, 71.21974557638168, 77.18089610338211, 64.9430675804615, 66.38933077454567, 77.54435420036316, 68.26173350214958, 70.2126932144165, 64.2210379242897, 74.97272059321404, 71.45689085125923, 72.13750272989273, 73.6746646463871, 73.82526576519012, 73.68563085794449, 76.07150003314018, 72.94309750199318, 62.751740366220474, 56.88536435365677, 56.992507204413414, 56.910872384905815, 58.33723224699497, 59.12633590400219, 58.60547125339508, 61.93755425512791, 60.21666079759598, 59.29443508386612, 60.26801884174347, 59.4632638245821, 59.29632358253002, 58.056301921606064, 57.52697512507439, 57.10376903414726, 51.419536247849464, 56.860775873064995, 58.507546707987785, 57.526116371154785, 60.243867337703705, 55.751653388142586, 59.85724948346615, 61.598103269934654, 62.25590117275715, 74.89597991108894, 78.89751479029655, 78.43976855278015, 78.34751710295677, 79.31249812245369, 73.87800693511963, 76.66147917509079, 77.05162703990936, 79.2073729634285, 79.9071130156517, 80.84604263305664, 77.7967594563961, 87.2876925766468, 79.97027322649956, 86.15677446126938, 81.3940492272377, 92.67670020461082, 15.518777668476105, 7.016477398574352, 13.404421973973513, 5.571112856268883, 10.75523927807808, 5.517517207190394, 0.18002660624915734, 7.900209752842784, 53.01608517765999, 42.55777336657047, 81.79723799228668, 56.10587038099766, 17.956523559987545, 17.501131296157837, 35.30545212328434, 53.14841687679291, 72.15020164847374, 73.8080906867981, 83.22221472859383, 35.71758560836315, 0.44638178951572627, 0.12035145409754477, 0.2761879423633218, 0.1525187838706188, 0.14407014503376558, 0.18125992210116237, 0.12088931820471771, 0.13779257016722113, 0.12234763096785173, 0.20792898401850834, 0.133200932177715, 0.12371308621368371, 0.12625837814994156], [0.12830912513891235, 0.019879963620041963, 0.03406788091524504, 0.1168055392918177, 0.01862716268078657, 0.08254564250819385, 0.06150271678052377, 0.05791446987132076, 0.11928519568755291, 0.018053057647193782, 0.08682623156346381, 0.14732385403476655, 0.3946491685928777, 10.73808129876852, 90.96021831035614, 63.76117140054703, 67.86649391055107, 28.0228541046381, 29.738393649458885, 46.01722553372383, 47.615001797676086, 53.24658080935478, 20.8524963632226, 0.08661387342726812, 0.1829871372319758, 2.175604607909918, 3.9482762245461345, 3.4375168941915035, 15.819365289062262, 0.4646273417165503, 5.428374940529466, 61.101625710725784, 75.08332505822182, 98.80003362894058, 89.94264051318169, 91.90624594688416, 88.02673012018204, 87.46168524026871, 85.01315742731094, 79.942527115345, 81.24999135732651, 74.80157777667046, 71.70699343085289, 68.30552235245705, 64.76932570338249, 59.36972424387932, 57.899849116802216, 56.570600643754005, 58.12890462577343, 56.17049731314182, 58.352541625499725, 61.23414359986782, 59.09743085503578, 55.68156234920025, 58.682101741433144, 54.508181512355804, 50.991694405674934, 54.612542912364006, 56.26731991767883, 59.94780622422695, 61.03935085237026, 59.843912199139595, 60.58010369539261, 58.125298619270325, 54.70535293221474, 58.29819694161415, 56.35671392083168, 54.567386135458946, 56.58727414906025, 54.47185166180134, 56.70241177082062, 59.72870238125324, 57.867623046040535, 56.56297065317631, 58.34065206348896, 55.79628199338913, 58.562024384737015, 52.74309642612934, 51.432759538292885, 61.56869664788246, 74.10743102431297, 67.08533182740211, 67.14340031147003, 64.7332276403904, 66.26978918910027, 60.65533585846424, 72.84635469317436, 44.54290084540844, 61.44013814628124, 75.53727149963379, 61.23369142413139, 63.20353992283344, 58.192536011338234, 65.61294883489609, 67.284866720438, 67.48442441225052, 63.26453424990177, 62.21365123987198, 59.90431375801563, 56.94792419672012, 54.64161515235901, 50.95542535185814, 45.66948339343071, 52.2830855101347, 49.869888201355934, 51.38519749045372, 53.2750678807497, 54.961029812693596, 49.8667723685503, 54.09618861973286, 54.41703960299492, 54.757505133748055, 53.956933692097664, 52.11866453289986, 50.38163334131241, 48.685989528894424, 47.56500408053398, 47.47769616544247, 47.51467578113079, 51.129395216703415, 54.242712557315826, 55.15375167131424, 51.676208674907684, 55.299329459667206, 53.478858545422554, 59.46009859442711, 68.28621938824654, 72.31142699718475, 66.51336371898651, 71.77996471524239, 68.58931392431259, 74.20091360807419, 73.13780665397644, 73.13473641872406, 72.54221901297569, 75.55804878473282, 73.93661499023438, 76.08452573418617, 72.99406036734581, 76.40683963894844, 74.05278235673904, 74.73359942436218, 81.2697122991085, 43.55806589126587, 2.3734979890286922, 0.2290603774599731, 3.5603457782417536, 2.297862572595477, 3.2283511804416776, 0.5580838315654546, 0.04489557060878724, 16.46000426262617, 26.076163463294506, 39.62223708629608, 63.197977021336555, 64.73858535289764, 52.20983684062958, 12.468207310885191, 23.607684820890427, 28.08962032198906, 54.6744529902935, 53.59312981367111, 50.408402904868126, 3.0279990937560797, 0.09960853043594398, 0.1670679508242756, 0.09031861525727436, 0.1602358283707872, 0.06404117724741809, 0.08348307150299661, 0.038208196638152, 0.07542662802734412, 0.03442294291744474, 0.05557307187700644, 0.048381267552031204, 0.03611415646446403, 0.06987998698605224, 0.008621628821856575, 0.027399589416745584, 0.08612789286416955, 0.08730978530365974, 0.025474775611655787, 0.11650234228000045, 0.009700734735815786, 0.032785078656161204, 0.06067873619031161, 0.10421936778584495, 0.23543299175798893, 0.6296177837066352, 14.744238629937172, 103.09799060225487, 71.49352088570595, 79.13994178175926, 44.81264837086201, 39.956166967749596, 39.23767112195492, 45.37658371031284, 55.558239966630936, 26.286434680223465, 0.10816138907102868, 0.5293863464612514, 3.3962021861225367, 5.4111347906291485, 4.694234859198332, 6.795249469578266, 0.3505061654141173, 10.369509626179934, 73.514564037323, 78.09964120388031, 101.66397035121918, 92.03261196613312, 94.62302416563034, 94.1533313691616, 93.61388191580772, 88.26798677444458, 83.766368329525, 79.27116394042969, 75.64179629087448, 75.54481789469719, 71.10224828124046, 68.88335734605789, 62.78504177927971, 61.40997916460037, 60.35614751279354, 59.28838200867176, 59.928438663482666, 61.512455865740776, 62.21458598971367, 61.43089324235916, 59.345736131072044, 61.30103141069412, 58.77745762467384, 55.565151795744896, 58.45211148262024, 59.32020150125027, 62.88513220846653, 61.97850465774536, 62.77777656912804, 62.90001221001148, 61.80011183023453, 58.63612420856953, 62.36712120473385, 59.52730938792229, 57.34805032610893, 58.26078034937382, 57.426094338297844, 59.008295238018036, 61.067925319075584, 61.979314014315605, 60.20015448331833, 60.65269500017166, 59.7121162712574, 62.30826996266842, 57.88080833852291, 56.92390948534012, 64.46430087089539, 74.79362860321999, 72.01255023479462, 70.36359831690788, 70.70991933345795, 67.32316866517067, 68.36983770132065, 72.51793071627617, 66.54500842094421, 79.54272776842117, 77.68763691186905, 65.70955485105515, 66.40782818198204, 63.106257542967796, 68.28634858131409, 68.1426402926445, 68.66027131676674, 68.18007588386536, 66.17500707507133, 62.68641047179699, 59.93297182023525, 56.528145521879196, 53.02850291132927, 50.82104556262493, 54.70736302435398, 53.001273572444916, 53.73728647828102, 56.988399624824524, 58.79399813711643, 53.53150092065334, 54.97788190841675, 56.932018250226974, 57.1668266505003, 56.69499836862087, 54.48637828230858, 54.82475772500038, 51.43063545227051, 50.756418630480766, 48.62909138202667, 51.308787390589714, 54.69238802790642, 55.838501527905464, 55.38302756845951, 54.380265176296234, 58.13046634197235, 57.59373754262924, 61.53946861624718, 70.87119027972221, 75.0270576775074, 73.33570763468742, 72.32865527272224, 72.10002154111862, 76.55560165643692, 76.118503510952, 75.96352502703667, 76.36343076825142, 78.4001974761486, 76.81511253118515, 77.73139536380768, 74.75958243012428, 78.06823208928108, 75.2215464413166, 77.3742525279522, 80.84057852625847, 66.63207694888115, 2.302577644586563, 2.7326815528795123, 3.7727470183745027, 2.467770930379629, 5.734131708741188, 0.8688855415675789, 0.18274230271345004, 14.646766260266304, 38.20327542722225, 40.67506179213524, 38.25066648423672, 32.08433456718922, 31.15695632994175, 19.81644205749035, 34.719873145222664, 38.45521330833435, 62.68288806080818, 64.96098741889, 61.5073299407959, 4.079794054850936, 0.2945203852141276, 0.13787941628834233, 0.05651824889355339, 0.10405415829154663, 0.011670169242279371, 0.04248955381626729, 0.00552824227270321, 0.13683494733413681, 0.059173111512791365, 0.07731831050477922, 0.063950546173146, 0.049068837688537315, 0.24532089242711663, 0.06685864442260936, 0.15842252410948277, 0.31933522084727883, 0.21986844803905115, 0.1337646081810817, 0.1546160041471012, 0.14385263639269397, 0.27117883146274835, 0.19591411779401824, 0.1696961629204452, 0.4200135200517252, 0.8777762926183641, 15.920587107539177, 118.82769495248795, 81.44076392054558, 92.09972396492958, 43.5089535266161, 48.02952155470848, 57.26907156407833, 67.22315803170204, 75.3227350115776, 35.74286565184593, 0.22145563474623486, 0.8884945081081241, 7.237197579815984, 8.49900584667921, 15.28897074982524, 28.594204746186733, 0.7207512622699142, 9.614930916577578, 80.84531307220459, 87.04917937517166, 101.55166357755661, 98.0304229259491, 98.32822054624557, 95.45947328209877, 97.017952054739, 92.01065674424171, 88.63845929503441, 86.26842767000198, 82.20770716667175, 78.8821180164814, 75.61682403087616, 70.69218188524246, 67.8315281867981, 65.39024278521538, 64.77774605154991, 63.552638590335846, 63.97623986005783, 62.80725158751011, 67.86863699555397, 65.75459763407707, 61.55190534889698, 64.63631004095078, 62.637552693486214, 59.13824826478958, 61.234686970710754, 63.32783505320549, 67.5579808652401, 66.71399295330048, 64.19953867793083, 66.38656452298164, 65.36441937088966, 61.84627555310726, 67.18071430921555, 63.116049617528915, 60.46020492911339, 61.469552367925644, 61.47968642413616, 61.096283197402954, 64.79264125227928, 65.2457745373249, 62.890041545033455, 64.54604968428612, 62.25675992667675, 66.55008494853973, 59.2012070864439, 57.984820157289505, 66.67934641242027, 81.36803582310677, 74.54060778021812, 71.82629942893982, 72.67450511455536, 72.77370259165764, 71.68475702404976, 76.68446034193039, 55.46232931315899, 59.41762827336788, 78.76666501164436, 72.44623616337776, 68.96760642528534, 68.63615021109581, 72.51940503716469, 72.64447912573814, 72.0814861357212, 71.57003358006477, 69.45983201265335, 66.17288678884506, 62.90631227195263, 60.57590872049332, 56.33901447057724, 52.50284291803837, 58.03511045873165, 58.7558937817812, 57.20723748207092, 60.15921168029308, 61.33387304842472, 56.52101330459118, 56.866745352745056, 59.94833819568157, 59.643845334649086, 60.862025767564774, 57.953616231679916, 56.86672255396843, 54.2011845856905, 52.466163486242294, 51.167735159397125, 56.27773515880108, 56.65358819067478, 60.83535499870777, 60.81330858170986, 57.97554865479469, 61.89656965434551, 59.83704216778278, 65.50435066223145, 74.56465288996696, 78.01626607775688, 76.1315368115902, 76.80318117141724, 75.09023308753967, 81.06489568948746, 80.42945578694344, 78.71082320809364, 78.8429269194603, 82.35117986798286, 81.45102337002754, 81.53795510530472, 77.29758784174919, 83.38479280471802, 78.78365010023117, 80.91096594929695, 84.70942452549934, 69.0129379928112, 6.018003076314926, 6.896906364709139, 12.5251111574471, 5.044980738312006, 9.133377056568861, 1.483840208966285, 0.2592418610583991, 24.446689300239086, 48.08262750506401, 56.50736443698406, 84.80298310518265, 89.60006609559059, 72.45044633746147, 22.652210891246796, 36.86405248939991, 47.34666019678116, 76.872269064188, 76.16942837834358, 72.8752863407135, 4.615938160568476, 0.35735693061724305, 0.24325855309143662, 0.17395399772794917, 0.281472775968723, 0.11477041451144032, 0.25762605713680387, 0.12100985783035867, 0.3467435360653326, 0.1678438959061168, 0.18044939293758944, 0.12715325981844217, 0.12097796774469316], [0.09650325839174911, 0.04112981681828387, 0.025385415465279948, 0.06371495881467126, 0.06605293179745786, 0.030867138993926346, 0.06317186256637797, 0.08237773159635253, 0.04046848160214722, 0.044254555396037176, 0.0628358032554388, 0.08347531605977565, 0.2801240561529994, 33.155702278018, 89.84680205583572, 62.66973316669464, 52.39205606281757, 24.037075079977512, 73.90702977776527, 86.46070495247841, 41.585040763020515, 44.39063921570778, 7.8476533479988575, 0.11903267994057387, 0.16569712985074148, 4.0110125206410885, 3.469654619693756, 4.563220264390111, 3.1466771755367517, 0.48359972366597503, 61.52965374290943, 75.73294579982758, 79.56010043621063, 97.97990083694458, 85.02151697874069, 86.3132956624031, 86.32273435592651, 86.12448379397392, 81.47505328059196, 78.93598392605782, 75.02711847424507, 74.22431275248528, 73.76878559589386, 69.82189938426018, 61.79890729486942, 57.82121613621712, 57.95434199273586, 56.21452935039997, 56.921633407473564, 55.99662244319916, 58.48168909549713, 62.7959243953228, 56.59222908318043, 59.74271982908249, 57.322926074266434, 53.40665102005005, 53.04532080888748, 54.41015437245369, 55.52480936050415, 57.54235289990902, 62.96350680291653, 61.41887828707695, 57.86362186074257, 57.90820486843586, 53.60925994813442, 55.78815422952175, 54.19227786362171, 58.3785018324852, 57.57933631539345, 58.163938745856285, 61.35728359222412, 58.26223947107792, 60.41717603802681, 61.17054641246796, 60.69081075489521, 53.38220313191414, 59.75391022861004, 52.403660640120506, 54.31542165577412, 56.71241283416748, 67.83380806446075, 65.02914056181908, 66.35938078165054, 66.30980104207993, 67.6513722538948, 59.32664595544338, 70.61037227511406, 32.05266326665878, 42.485288456082344, 63.385652750730515, 64.93699550628662, 68.43327909708023, 59.08433675765991, 63.54956075549126, 59.29906323552132, 67.18082830309868, 60.59146128594875, 55.16588822007179, 50.6016643345356, 51.37850604951382, 47.08159402012825, 49.00026686489582, 47.286767810583115, 49.84090335667133, 49.91043582558632, 49.77374576032162, 51.28194943070412, 53.56778897345066, 48.39985728263855, 51.037041172385216, 53.04640755057335, 55.12646533548832, 54.980511367321014, 51.2557802349329, 48.01608927547932, 48.391113951802254, 47.9777455329895, 47.82188169658184, 44.93172638118267, 49.073279947042465, 53.15062835812569, 53.37476313114166, 50.50057455897331, 52.555576488375664, 51.204935163259506, 57.96032287180424, 65.64350679516792, 65.75142100453377, 72.38156363368034, 69.51293796300888, 66.57849982380867, 68.09192061424255, 67.70157516002655, 68.44872906804085, 67.5390274822712, 72.27516934275627, 70.70613473653793, 69.36809733510017, 69.8444701731205, 69.42366555333138, 69.43827956914902, 72.7380833029747, 77.32245370745659, 82.12605714797974, 10.525588151067495, 2.5818728702142835, 2.624238459393382, 2.2549517126753926, 1.4516589045524597, 0.48541670897975564, 0.16416943370131776, 4.813795918598771, 43.69107775390148, 28.519164472818375, 42.53777503967285, 87.61743128299713, 116.33603945374489, 52.20065653324127, 22.63063944876194, 22.43601579219103, 43.92717428505421, 52.6850089430809, 63.33931803703308, 13.551875911653042, 0.2924151497427374, 0.21504123753402382, 0.13257963582873344, 0.023646236913918983, 0.1312507313559763, 0.03751568008738104, 0.06310600438155234, 0.13008487672777846, 0.023899149709905032, 0.039900653282529674, 0.028571529655891936, 0.00740398249035934, 0.05820467929879669, 0.0488064662204124, 0.012506068724178476, 0.04486182515393011, 0.026215800789941568, 0.01970592071302235, 0.05705995732569136, 0.03302978329884354, 0.04501583563978784, 0.03668004777864553, 0.06383858577464707, 0.05194062636292074, 0.2154891236568801, 43.56541469693184, 101.57959967851639, 72.69859582185745, 63.569771870970726, 29.800180234014988, 75.79872786998749, 68.72505784034729, 31.894580349326134, 59.07073348760605, 9.282040279358625, 0.06519809641758911, 1.5331834112294018, 3.7281407369300723, 4.200747264549136, 0.6722640234511346, 0.29772058536764234, 0.3999896929599345, 74.02252078056335, 89.15007904171944, 86.68901190161705, 96.22536778450012, 88.39067459106445, 88.79533007740974, 90.99935621023178, 88.78844484686852, 86.78250968456268, 80.91451495885849, 78.204165995121, 75.52140355110168, 77.95455738902092, 71.56643137335777, 65.62319308519363, 59.93777476251125, 61.770534217357635, 59.98521141707897, 61.16068974137306, 58.262475058436394, 61.87551498413086, 64.20000985264778, 61.22300259768963, 63.219115287065506, 60.904138907790184, 54.29063178598881, 55.26672720909119, 56.930688321590424, 60.88707022368908, 61.57968185842037, 64.48689445853233, 64.90577638149261, 60.91638945043087, 60.02020753920078, 55.85061527788639, 58.88827867805958, 56.159033328294754, 61.68956816196442, 61.937022283673286, 61.51424176990986, 62.70820990204811, 63.92307311296463, 62.26639240980148, 64.04392942786217, 62.27186031639576, 58.2675401866436, 61.681865975260735, 55.21956034004688, 54.794515147805214, 57.875496223568916, 69.79824185371399, 68.35491970181465, 71.07357501983643, 72.01828792691231, 70.45143440365791, 65.20377919077873, 74.26392182707787, 48.078489527106285, 57.392694130539894, 66.00890278816223, 65.63014671206474, 70.68316116929054, 64.97943922877312, 64.68525901436806, 59.982323572039604, 68.15701112151146, 62.34518118202686, 58.430300652980804, 52.75210194289684, 53.14304396510124, 50.60103356838226, 51.751619428396225, 50.85219629108906, 52.98992358148098, 53.32275152206421, 53.11214402318001, 54.797741174697876, 55.75905539095402, 52.91400745511055, 54.458506777882576, 55.53416445851326, 58.32365557551384, 57.26920075714588, 57.86586374044418, 50.25341682136059, 50.67839741706848, 48.81299391388893, 51.35716259479523, 47.08327353000641, 50.8803603798151, 54.02146942913532, 54.92051258683205, 53.295924961566925, 55.7413749396801, 53.907471746206284, 63.05106170475483, 67.60425478219986, 72.4496103823185, 75.33349603414536, 73.00682008266449, 68.09682995080948, 70.95657169818878, 69.37589451670647, 69.72654730081558, 68.8074754178524, 75.83563148975372, 73.4776984155178, 73.3819891512394, 68.97567719221115, 71.88963443040848, 67.44194269180298, 76.65485233068466, 75.4159440100193, 92.68441379070282, 27.024138495326042, 3.7571379309520125, 0.6393402151297778, 3.497922015376389, 2.6029441645368934, 1.3397142989560962, 0.0907050070236437, 2.720460221171379, 47.79561750590801, 38.474185690283775, 45.52190691232681, 85.1674747467041, 109.97808381915092, 42.23884887993336, 35.70701077580452, 30.739218145608902, 51.69652618467808, 63.13792884349823, 73.2762636244297, 18.01285743713379, 0.37473363569006324, 0.3139788442058489, 0.21048293681815267, 0.03161593260301743, 0.07602683996083215, 0.09611569403205067, 0.03810325695667416, 0.08736513467738405, 0.03584529120416846, 0.008319141488755122, 0.020391982434375677, 0.03271213667176198, 0.15836606151424348, 0.12406688285409473, 0.3436868079006672, 0.17470542225055397, 0.2067067113239318, 0.2229440415976569, 0.10538834685576148, 0.24422487389529124, 0.15522652451181784, 0.11163991686771624, 0.2973832644056529, 0.2505193400429562, 0.4131973983021453, 50.56250363588333, 115.89970886707306, 81.29425138235092, 74.06150668859482, 36.64068907499313, 86.95740669965744, 97.151560485363, 55.32353796064854, 71.45140394568443, 13.239572569727898, 0.2836407971335575, 0.9927647723816335, 10.900248046964407, 8.336671907454729, 16.24531388282776, 6.651174975559115, 0.36199989554006606, 72.62707605957985, 87.83769026398659, 90.58569520711899, 96.4284136891365, 90.64128622412682, 90.51568776369095, 93.70541140437126, 91.07352823019028, 90.47316804528236, 85.1854857802391, 84.12376195192337, 82.72296711802483, 82.78258591890335, 75.74324324727058, 70.22662326693535, 63.83124724030495, 66.31445199251175, 64.15204882621765, 63.36635358631611, 61.81193299591541, 66.17320597171783, 69.66689810156822, 62.71019719541073, 67.58126601576805, 63.47815878689289, 58.818731009960175, 60.31274624168873, 60.42995475232601, 63.44211392104626, 65.18921077251434, 66.95689871907234, 69.43643286824226, 63.430277556180954, 62.40877076983452, 58.9790254086256, 62.273760214447975, 61.360160037875175, 65.28145462274551, 64.84323173761368, 63.28877314925194, 67.5522355735302, 65.89376136660576, 65.63833147287369, 67.33535081148148, 66.5422573685646, 58.65589454770088, 65.34823223948479, 56.709878370165825, 60.20237356424332, 63.296600729227066, 75.00502645969391, 71.33067682385445, 71.08730748295784, 73.43998163938522, 76.64153024554253, 68.59495282173157, 83.25607851147652, 36.280977576971054, 43.29046905040741, 71.19551047682762, 71.70774579048157, 75.16612261533737, 65.07191106677055, 66.83245539665222, 62.288381829857826, 72.8342105448246, 65.59566736221313, 60.92970013618469, 56.86668075621128, 55.89365936815739, 53.03533874452114, 54.88355956971645, 51.58407121896744, 56.48186780512333, 57.135387137532234, 55.949751958251, 57.15296879410744, 58.1692698597908, 55.44253617525101, 58.13707418739796, 58.21455202996731, 60.98768122494221, 59.575000628829, 60.662688463926315, 53.44406381249428, 53.6718387901783, 50.60566931962967, 53.85700285434723, 51.684826612472534, 54.1578821092844, 56.97068117558956, 59.228539019823074, 53.96061949431896, 58.27273830771446, 57.210436910390854, 66.8255777657032, 71.341103464365, 77.6600731909275, 79.09208714962006, 78.3820116519928, 70.46029552817345, 75.85860505700111, 75.62433242797852, 75.79889506101608, 72.82224118709564, 81.70340582728386, 77.39626094698906, 77.49804228544235, 72.49022260308266, 76.54787287116051, 71.3439229130745, 81.82451292872429, 81.84431746602058, 100.95247372984886, 28.19970801472664, 5.925463791936636, 11.889881193637848, 9.879519268870354, 4.348163204267621, 1.7974626738578081, 0.22603680845350027, 6.979145826771855, 58.574103936553, 44.49745528399944, 61.586517691612244, 100.22602871060371, 132.9226890206337, 68.48479673266411, 35.95030792057514, 32.505838349461555, 67.14818805456161, 70.92925116419792, 87.711993008852, 21.880861781537533, 0.4428625846048817, 0.7007161248475313, 0.3024405555333942, 0.225789480318781, 0.19617268204456195, 0.2787012403132394, 0.19315098325023428, 0.3016854351153597, 0.16135656042024493, 0.07970050064614043, 0.20449675881536677, 0.15646807820303366], [0.06480481009930372, 0.009844075921137119, 0.13675163383595645, 0.12367043498670682, 0.0268186454923125, 0.10221540578640997, 0.05854913601069711, 0.11314290692098439, 0.05962283074040897, 0.06676837700069882, 0.08495784510159865, 0.2626925805816427, 0.4054643679410219, 67.95334964990616, 80.50613567233086, 72.91453063488007, 47.162556275725365, 38.10364097356796, 52.72418104112148, 60.05087189376354, 54.21124644577503, 28.460212536156178, 2.291265414096415, 0.10640583874192089, 0.7561537844594568, 1.9435064122080803, 5.467607835307717, 2.101730634458363, 0.2848356548929587, 41.01355902850628, 116.85336649417877, 100.34978047013283, 105.3929078578949, 89.8298017680645, 92.11418598890305, 82.90595769882202, 89.05028879642487, 84.30672213435173, 84.7670066356659, 75.33297926187515, 77.89497658610344, 72.08360642194748, 71.6998802125454, 68.98608863353729, 68.57248842716217, 60.038089379668236, 57.099175080657005, 55.849555134773254, 58.20629507303238, 54.001919478178024, 56.59629486501217, 58.23662884533405, 57.553410306572914, 58.57266001403332, 53.526640981435776, 47.33514301478863, 55.316797122359276, 52.994274348020554, 55.094991624355316, 59.34517376124859, 60.41351683437824, 57.07748204469681, 56.994532495737076, 59.07531604170799, 54.24335092306137, 51.60617843270302, 56.85398943722248, 60.4964891821146, 64.5938891172409, 59.29265297949314, 63.56592647731304, 63.435741662979126, 64.72438931465149, 61.79270222783089, 60.00500835478306, 57.796107083559036, 59.1689658164978, 55.280995443463326, 56.373387426137924, 52.44994595646858, 60.230096876621246, 59.19473223388195, 64.68911200761795, 68.87121319770813, 65.25935500860214, 59.62484635412693, 52.13315315544605, 18.228435069322586, 20.41307844221592, 49.1931939125061, 58.60612101852894, 65.15774846076965, 65.45926988124847, 67.09648802876472, 66.06106638908386, 66.12079918384552, 61.48592948913574, 53.77051189541817, 49.58142288029194, 48.95870849490166, 47.70435780286789, 46.863873302936554, 47.13541813194752, 49.13927100598812, 46.81662283837795, 49.84638266265392, 51.07988007366657, 51.01125955581665, 50.6454835832119, 51.00776754319668, 51.05430364608765, 54.92374241352081, 54.905419796705246, 53.184001967310905, 49.60039526224136, 48.74885335564613, 49.05569069087505, 48.2325142621994, 44.825628474354744, 46.74378074705601, 53.866844326257706, 52.90388099849224, 51.84228256344795, 51.500255316495895, 52.12912917137146, 56.58547304570675, 59.42789912223816, 61.38743497431278, 65.53325191140175, 63.80452707409859, 62.36306682229042, 60.24065650999546, 61.06371894478798, 61.1375679820776, 59.94844079017639, 59.60873901844025, 62.58527509868145, 62.418707236647606, 61.065892428159714, 64.8115262389183, 67.18289539217949, 68.30663949251175, 75.80584868788719, 81.56147584319115, 60.92779643833637, 0.9613768535200506, 1.027974276803434, 4.212131453678012, 2.0677181845530868, 1.0553046665154397, 0.11586523818550631, 0.1326957967830822, 34.22383636236191, 59.61260341107845, 33.98856818675995, 83.09066578745842, 107.38380342721939, 104.93893101811409, 15.265371166169643, 21.884036511182785, 46.47986590862274, 64.42153796553612, 64.8471987247467, 38.676053658127785, 0.5705013871192932, 0.12065807983162813, 0.20776556310011074, 0.087370411347365, 0.04716755182016641, 0.07791819589328952, 0.07176345388870686, 0.03261980236857198, 0.04700369303463958, 0.04263682560122106, 0.12566742079798132, 0.028252754964341875, 0.06091980430937838, 0.028757868094544392, 0.019028898350370582, 0.09955444271326996, 0.05973908817395568, 0.057687736334628426, 0.033501833750051446, 0.08221499345381744, 0.03428087729844265, 0.05480643332703039, 0.030442582283285446, 0.11684997167321853, 0.5825302354060113, 80.3724056482315, 91.66476890444756, 79.13593679666519, 60.99131003022194, 48.36937911808491, 66.62975147366524, 59.79339770972729, 55.26303380727768, 39.50459159910679, 1.2607765034772456, 0.08544259369955398, 2.3651244258508086, 3.643120536580682, 2.8114475263282657, 0.32926485990174115, 0.6476810644380748, 56.99511766433716, 115.00506207346916, 100.93524545431137, 105.6263217329979, 94.46024850010872, 91.5506686270237, 86.04227900505066, 91.26969650387764, 89.78586852550507, 88.06909024715424, 79.84550312161446, 78.49260851740837, 74.32216510176659, 75.35765513777733, 73.92507120966911, 71.50100648403168, 61.98983944952488, 60.95682308077812, 59.05778758227825, 61.84276074171066, 57.241025269031525, 61.06567203998566, 62.26008474826813, 60.18562786281109, 60.42757228016853, 57.491154447197914, 51.84892080724239, 57.93831445276737, 56.24141290783882, 59.18043740093708, 61.78034149110317, 62.000452280044556, 58.96369703114033, 60.14188840985298, 60.115772411227226, 56.21880032122135, 56.56275786459446, 60.879459232091904, 64.15000453591347, 68.481954485178, 62.536512315273285, 67.09217146039009, 66.19453802704811, 66.83755472302437, 63.80678415298462, 65.83412736654282, 61.32240526378155, 64.39711287617683, 57.49805487692356, 59.36997503042221, 56.961740255355835, 64.4125172495842, 61.876103952527046, 68.27863499522209, 70.38665547966957, 72.251618206501, 62.60449826717377, 59.12772282958031, 25.356497280299664, 27.422191835939884, 56.009370759129524, 60.981050580739975, 69.82716590166092, 65.69508522748947, 70.53075894713402, 69.41041946411133, 67.47813194990158, 61.79470472037792, 56.096469685435295, 50.93523323535919, 51.27255633473396, 49.54576939344406, 50.13789162039757, 49.9350319057703, 52.0224004983902, 50.95791041851044, 52.93601207435131, 52.64426752924919, 54.892667680978775, 53.62370677292347, 52.785555347800255, 52.69565597176552, 56.04430228471756, 58.42610187828541, 56.12799659371376, 50.25225788354874, 50.822797268629074, 51.26494154334068, 51.597841680049896, 47.67948433756828, 49.25617553293705, 54.87671993672848, 54.287173971533775, 54.20700207352638, 53.077736869454384, 55.553798004984856, 59.66785244643688, 62.058068588376045, 63.56338821351528, 68.9130337536335, 65.5458976328373, 64.39055442810059, 62.24483236670494, 62.43742123246193, 62.11366720497608, 64.12437871098518, 63.20234298706055, 64.48031321167946, 64.19193148612976, 62.56157197058201, 64.14727628231049, 70.62796533107758, 68.64692643284798, 82.11500734090805, 76.73130422830582, 81.564781665802, 7.211956959217787, 3.041423298418522, 3.644363069906831, 0.6163767410907894, 2.5801693741232157, 0.25214657303877175, 0.15208384080324322, 30.754003152251244, 68.92576307058334, 41.49474240839481, 82.35962301492691, 106.95720791816711, 97.88346961140633, 23.249145559966564, 28.71074829250574, 57.24370412528515, 70.73096260428429, 73.77725914120674, 45.332646667957306, 0.5123161780647933, 0.11762415044358931, 0.1714776735752821, 0.08014308041310869, 0.0193461553499219, 0.04068649490363896, 0.055443548553739674, 0.047833276839810424, 0.07305850158445537, 0.031233811896527186, 0.1277979338192381, 0.04755516070872545, 0.18090075231157243, 0.11538532839040272, 0.19255385122960433, 0.2463819706463255, 0.11886090986081399, 0.22402818576665595, 0.18621317896759138, 0.22848049295134842, 0.1372918876586482, 0.1370525301899761, 0.16423677618149668, 0.31588334357365966, 0.6861458660569042, 93.70401307940483, 102.65145376324654, 92.11676225066185, 64.56434950232506, 54.990132451057434, 65.15436664223671, 75.24711146950722, 76.31806120276451, 49.68057096004486, 3.876846469938755, 0.21057941601611674, 3.070219815708697, 8.876357898116112, 15.026593878865242, 6.958676325157285, 0.5623605020809919, 54.531987234950066, 122.59409084916115, 107.46856167912483, 113.03340867161751, 97.35216692090034, 94.6010309457779, 87.86463841795921, 93.86265456676483, 91.81730791926384, 90.94073295593262, 81.17938354611397, 84.32295486330986, 77.88198128342628, 79.4503091275692, 76.49462252855301, 74.96425464749336, 66.17550864815712, 64.41376358270645, 64.14564236998558, 66.337311565876, 59.114301949739456, 64.31206583976746, 67.61094242334366, 63.77404510974884, 63.5528551787138, 61.946692764759064, 54.17118899524212, 63.94470155239105, 59.74344179034233, 63.717093765735626, 66.03381425142288, 65.41096687316895, 62.77469493448734, 62.10434630513191, 62.92910724878311, 59.23824369907379, 58.210459649562836, 62.02722184360027, 65.89550167322159, 69.28441822528839, 64.7662478685379, 71.24166280031204, 69.51498985290527, 72.00089246034622, 66.15264147520065, 66.98019906878471, 63.867862075567245, 66.90289601683617, 60.3440185636282, 62.74583928287029, 59.91710007190704, 69.18594270944595, 65.80334901809692, 68.44716355204582, 74.09055233001709, 74.78761732578278, 65.9118939936161, 71.33753925561905, 23.637251034379005, 30.775741785764694, 63.3038355410099, 67.49803528189659, 73.7655557692051, 68.45825895667076, 73.33933264017105, 70.8802717924118, 73.81741538643837, 65.65702646970749, 58.11699986457825, 53.82099598646164, 53.280953764915466, 51.72580361366272, 51.69735074043274, 51.712200343608856, 55.84819480776787, 54.41664442420006, 56.275029703974724, 57.38471455872059, 58.197570741176605, 57.528791427612305, 58.45589227974415, 57.18162685632706, 59.32447627186775, 61.33613772690296, 59.82187718153, 53.921063616871834, 53.45542520284653, 54.56896685063839, 53.63180413842201, 51.49895578622818, 53.5462137311697, 58.558106794953346, 58.41032512485981, 56.668304800987244, 57.722239047288895, 57.94188626110554, 65.76982721686363, 65.86451813578606, 68.55182513594627, 74.18653517961502, 68.85803550481796, 68.90450701117516, 65.65138757228851, 66.07261016964912, 66.86671435832977, 69.14793714880943, 67.3494328558445, 70.84992662072182, 68.73636603355408, 66.72877416014671, 67.7715066075325, 74.43280756473541, 71.78789868950844, 89.44090783596039, 83.97744700312614, 89.02777880430222, 9.103170577436686, 7.530049290508032, 13.860779386013746, 5.50690152682364, 3.6027602897956967, 0.27590800425969064, 0.25766936887521297, 45.136660784482956, 76.75054639577866, 53.088482692837715, 88.00744995474815, 108.53609159588814, 117.5955730676651, 24.541803896427155, 34.171060994267464, 68.80619868636131, 82.0276652276516, 83.84301021695137, 53.13183456659317, 0.5994520336389542, 0.1628040600917302, 0.27979863923974335, 0.23279679415281862, 0.1228990986419376, 0.2444886034936644, 0.26064199686516076, 0.08516674482962117, 0.18567124789115041, 0.14271406311308965, 0.20409654825925827, 0.21165940415812656], [0.059576286948868074, 0.08990578819066286, 0.014756671444047242, 0.01243865388460108, 0.026617985458869953, 0.060068516395404004, 0.06883125068270601, 0.03936904176953249, 0.00041201653118605464, 0.18150833377148956, 0.21134249225724488, 0.4997227038256824, 8.077970389276743, 89.26750794053078, 67.25781217217445, 61.14191114902496, 35.92766493558884, 30.59054732322693, 52.03822664916515, 36.4446309953928, 35.483727157115936, 17.750872895121574, 0.4748609644593671, 0.14825493766693398, 3.8717089081183076, 2.5022868532687426, 3.6176115553826094, 1.0036410950124264, 20.40105778723955, 113.38920637965202, 90.28384700417519, 89.73272457718849, 85.87215453386307, 94.83069822192192, 90.76059222221375, 87.5878232717514, 86.26139044761658, 88.73095393180847, 82.81046122312546, 81.85320898890495, 73.48793506622314, 74.48607310652733, 71.46000668406487, 72.94559016823769, 66.77594482898712, 65.82620099186897, 62.419307604432106, 62.33787417411804, 58.01102735102177, 57.03115113079548, 55.93687064945698, 59.07637998461723, 55.130800902843475, 57.89899796247482, 51.738817915320396, 49.31974612176418, 51.526736095547676, 51.673070043325424, 55.242286920547485, 61.698235496878624, 59.557646960020065, 56.14110589027405, 56.809497624635696, 55.52079677581787, 53.201614022254944, 55.50176739692688, 63.32143999636173, 68.15345451235771, 66.84056416153908, 63.577641248703, 65.48670440912247, 63.72473135590553, 64.35253366827965, 65.27545094490051, 61.333534866571426, 60.17190679907799, 61.59481264650822, 56.82461701333523, 55.797642320394516, 53.413859233260155, 54.489231929183006, 54.844372272491455, 64.38565269112587, 67.71104425191879, 65.50571858882904, 53.08777593076229, 36.94761000573635, 15.519731417298317, 12.36024085432291, 39.329911172389984, 51.95078954100609, 64.90343570709229, 61.884292513132095, 63.11970502138138, 61.90559796988964, 64.85425114631653, 58.331232368946075, 53.407908752560616, 49.935609474778175, 50.9527350962162, 48.74865956604481, 47.88243904709816, 46.98658771812916, 47.78981141746044, 47.26095199584961, 48.05936895310879, 49.71256524324417, 48.85806329548359, 50.22326163947582, 49.793356508016586, 49.88362066447735, 51.1442182213068, 51.98296241462231, 54.24578279256821, 50.75657062232494, 49.84512872993946, 48.35631541907787, 46.84528090059757, 45.94966895878315, 44.067496955394745, 50.07669970393181, 54.05714951455593, 52.118903920054436, 50.265264585614204, 49.81058098375797, 54.33010406792164, 55.94341389834881, 59.06584694981575, 61.21756128966808, 59.5346087962389, 58.181174620985985, 56.12173452973366, 54.60960566997528, 55.02593792974949, 53.745805621147156, 54.5464226603508, 58.21399345993996, 56.40996426343918, 62.420979514718056, 66.10085785388947, 67.12246343493462, 65.95967262983322, 75.91710671782494, 71.75282657146454, 84.7592930495739, 33.178174272179604, 1.9383794185705483, 1.449748557060957, 1.0142104653641582, 0.5111675115767866, 0.7437866949476302, 0.148668002220802, 5.1152261439710855, 69.67573642730713, 35.60461387038231, 55.03800228238106, 86.41389906406403, 50.32142177224159, 36.14703856408596, 27.85470362752676, 26.829989813268185, 57.57751241326332, 62.7941232919693, 58.34410987794399, 2.716007335111499, 0.07951215098728426, 0.15265774360159412, 0.07557030781754293, 0.03900882184098009, 0.08645325782708824, 0.06483299686806276, 0.09845128472079523, 0.04395265343191568, 0.06054673780454323, 0.04260664987668861, 0.007855440198909491, 0.052351431077113375, 0.037764752269140445, 0.050799199525499716, 0.04062515639816411, 0.07247798625030555, 0.0363841720536584, 0.04167950704868417, 0.0425140521110734, 0.035465998080326244, 0.19783961994107813, 0.24749979347689077, 0.6868712115101516, 10.20210200920701, 103.57113361358643, 77.09107652306557, 73.0354705452919, 50.66803157329559, 35.70401653647423, 49.350224286317825, 33.34191508591175, 44.836400896310806, 17.878654338419437, 0.3648871765471995, 0.23171241249656305, 4.090488106012344, 3.0577830830588937, 1.4019071054644883, 0.5849967780523002, 30.679160468280315, 115.69100886583328, 90.69021999835968, 96.47562995553017, 88.6010617017746, 96.69142037630081, 91.81789308786392, 90.44407680630684, 87.6468189060688, 91.2786640226841, 87.08773210644722, 85.10349377989769, 75.71282207965851, 78.70801895856857, 74.167650192976, 74.519572108984, 69.73795428872108, 70.3287921845913, 66.46801695227623, 66.7349374294281, 62.77544729411602, 61.0937525331974, 58.03339675068855, 62.64827951788902, 57.49533802270889, 60.70786044001579, 55.9551552683115, 54.662004858255386, 55.812381729483604, 55.04516489803791, 58.24017785489559, 63.11451070010662, 61.81101344525814, 58.84395785629749, 58.1240750849247, 57.994939014315605, 54.593840315937996, 57.77333490550518, 67.0834319293499, 70.1089359819889, 68.98522987961769, 67.25547909736633, 70.76885417103767, 67.9648706316948, 68.45670863986015, 66.63678869605064, 65.20590707659721, 62.962974831461906, 64.23051461577415, 60.945644080638885, 59.70384031534195, 57.30964958667755, 56.662354320287704, 57.73046560585499, 67.19466716051102, 70.49688756465912, 66.96025773882866, 53.7727689743042, 45.60645617544651, 19.81358651071787, 16.968762762844563, 45.42461693286896, 54.82814334332943, 68.10059934854507, 65.21420583128929, 64.63116511702538, 64.56806570291519, 65.72821944952011, 61.4285259693861, 54.078770354390144, 51.64163053035736, 52.12614633142948, 50.32987631857395, 49.5681007951498, 48.46106819808483, 50.50548769533634, 50.576106905937195, 50.58532901108265, 52.08963789045811, 51.12240359187126, 53.437528163194656, 52.06052005290985, 52.28512220084667, 53.71045231819153, 53.78910429775715, 57.6368348300457, 54.144354835152626, 53.618086874485016, 51.229098066687584, 50.956014320254326, 50.01665532588959, 47.705725729465485, 51.68509639799595, 56.75592049956322, 53.916355669498444, 52.57171042263508, 52.72343248128891, 57.67984852194786, 60.308524668216705, 62.51983121037483, 62.75696888566017, 62.20002517104149, 58.98482769727707, 57.0381997525692, 58.224986270070076, 57.99724169075489, 56.871092319488525, 58.16796652972698, 59.54590559005737, 59.15514595806599, 65.60104787349701, 69.77706179022789, 70.36770969629288, 68.37967917323112, 77.58428245782852, 75.71605950593948, 85.11111617088318, 45.40355086326599, 1.110101763624698, 0.9039178804960102, 0.6800660735461861, 2.0911064045503736, 3.87273580301553, 0.2593964652623981, 4.419634519144893, 74.110197275877, 44.46322292089462, 59.102894961833954, 86.55186966061592, 54.99107100069523, 33.70026245713234, 35.89843690395355, 35.075556859374046, 65.05690947175026, 70.38981691002846, 70.37213265895844, 3.665128480643034, 0.17393005604390055, 0.1818315390846692, 0.09347556304419413, 0.0580084554530913, 0.04715273855254054, 0.03495062475849409, 0.08129953203024343, 0.04626225410902407, 0.06281215843046084, 0.07785772570059635, 0.068030829570489, 0.21509740327019244, 0.13182433729525656, 0.11372839464456774, 0.1435428491095081, 0.21438091906020418, 0.12314273830270395, 0.17385514365741983, 0.24851040565408766, 0.1074874892947264, 0.41885297920089215, 0.36183142801746726, 0.8661770587787032, 11.790259089320898, 116.76493003964424, 85.54885268211365, 79.971162378788, 51.53623938560486, 43.33790950477123, 62.42636762559414, 53.916519060730934, 55.71175552904606, 28.14177632331848, 0.7784769334830344, 0.2893389476230368, 10.404300559312105, 6.8005668092519045, 12.899814750999212, 2.832782668992877, 29.81165561825037, 119.0746209025383, 97.63868674635887, 101.60228446125984, 94.44511771202087, 101.68033987283707, 96.81382700800896, 92.5712102651596, 90.90642839670181, 94.47608605027199, 90.80913081765175, 89.95369791984558, 80.7157476246357, 81.82455852627754, 75.50416007637978, 79.07092228531837, 75.20983546972275, 72.13684156537056, 68.18535760045052, 71.52522638440132, 66.21683523058891, 64.49066385626793, 60.258462354540825, 66.46762937307358, 60.01300312578678, 63.26766148209572, 59.401406943798065, 57.237286269664764, 58.01012679934502, 58.55322025716305, 61.18204079568386, 67.70224392414093, 65.18009126186371, 60.369906574487686, 62.41128623485565, 60.36239817738533, 58.41087989509106, 60.37535548210144, 71.25183865427971, 73.13107341527939, 70.93859106302261, 70.37986144423485, 72.36931309103966, 70.67440643906593, 71.10894352197647, 70.89248433709145, 67.31499910354614, 68.26755478978157, 68.26275944709778, 62.63318292796612, 62.372513115406036, 61.47892266511917, 61.1625212430954, 60.03056198358536, 71.57241225242615, 74.77047264575958, 69.23461809754372, 57.83734627068043, 54.25151288509369, 20.15807792544365, 18.185805156826973, 53.41926634311676, 59.40346643328667, 71.20902255177498, 67.42646992206573, 68.16075012087822, 68.72039929032326, 72.01992183923721, 65.68313106894493, 58.28222259879112, 55.80618806183338, 56.36310137808323, 53.7484160810709, 51.52194835245609, 52.5889652967453, 54.07173693180084, 53.95526938140392, 54.52043205499649, 57.02192522585392, 53.660352006554604, 56.1786212772131, 56.52038633823395, 56.67018190026283, 55.82030810415745, 56.68396756052971, 61.09224021434784, 57.83884339034557, 57.55510501563549, 54.01859678328037, 54.38674382865429, 53.4947606921196, 51.348765045404434, 55.54293438792229, 60.51892697811127, 55.86616024374962, 56.46244704723358, 55.20133651793003, 61.69623300433159, 60.92889457941055, 66.23338714241982, 67.91401416063309, 68.27739626169205, 63.67452085018158, 61.31227120757103, 60.70225194096565, 62.02820599079132, 60.86065784096718, 61.948357075452805, 65.19539684057236, 64.0357294678688, 68.58346223831177, 73.16565915942192, 75.69153562188148, 72.26415753364563, 83.73831063508987, 77.79843136668205, 90.74233800172806, 45.56424804031849, 3.235324756242335, 13.11803039163351, 5.07805036380887, 4.12224062718451, 6.388669386506081, 0.3451264259638265, 7.538028387352824, 86.13599717617035, 51.28241300582886, 72.87026301026344, 90.57816401124, 64.64271649718285, 49.33990404009819, 40.244978070259094, 41.61516174674034, 77.7820086479187, 79.06095162034035, 82.90862515568733, 4.318028446286917, 0.30966325546614826, 0.2659430092899129, 0.24163112713722512, 0.22160108084790409, 0.23297384090255946, 0.10883840586757287, 0.21417423093225807, 0.1454155845567584, 0.19578387087676674, 0.162305514968466, 0.07924608362372965], [0.021544456139963586, 0.0779065367532894, 0.09025127277709544, 0.03414676379179582, 0.041160816326737404, 0.03765353772905655, 0.14810713153565302, 0.09477365354541689, 0.08829211423289962, 0.1818045397521928, 0.22289405053015798, 0.45016371470410377, 15.056627467274666, 83.81367579102516, 66.61218121647835, 56.18698462843895, 33.535134717822075, 39.6177077293396, 58.238087967038155, 56.86951160430908, 32.46801137924194, 6.639712415635586, 0.5613640055526048, 0.583873582072556, 3.3180194813758135, 1.3147198338992894, 2.4546963069587946, 3.9868448674678802, 95.51290601491928, 97.53793135285378, 94.47901949286461, 91.51708602905273, 86.85911357402802, 91.29513993859291, 90.55781230330467, 84.84329134225845, 83.85396882891655, 86.25765144824982, 79.26556304097176, 80.53027957677841, 76.61585122346878, 77.7513138949871, 75.1502850651741, 77.40661919116974, 72.15824961662292, 69.92853686213493, 69.25504580140114, 68.39573711156845, 62.82728411257267, 59.81590390205383, 58.72468985617161, 56.46892949938774, 57.87614218890667, 56.87799654901028, 50.378559306263924, 52.13030330836773, 54.91196684539318, 53.270766511559486, 59.00461703538895, 59.27925869822502, 54.58798103034496, 58.019713684916496, 58.25351893901825, 54.63672861456871, 52.12601713836193, 60.540456622838974, 64.95546251535416, 69.73275616765022, 65.67860931158066, 66.85743525624275, 69.1455964744091, 66.4269107580185, 63.70773486793041, 62.94231913983822, 63.49701337516308, 61.02104723453522, 61.41447812318802, 60.13429641723633, 58.69942121207714, 54.550921618938446, 53.70439164340496, 55.00040329992771, 57.8538753837347, 65.2423395216465, 64.41830813884735, 46.165698766708374, 41.75581119954586, 24.66516237705946, 19.626642242074013, 41.10709860920906, 53.56350660324097, 64.1730996966362, 60.91552309691906, 59.866224601864815, 54.92916852235794, 55.564163848757744, 50.38421340286732, 49.485128447413445, 47.2989309579134, 47.13025040924549, 48.31476464867592, 48.73713098466396, 46.44637070596218, 47.81880006194115, 47.097496166825294, 49.51747991144657, 47.409812808036804, 50.625739842653275, 49.34560373425484, 47.71642975509167, 46.42296016216278, 50.31745098531246, 49.656822234392166, 53.55945222079754, 53.62714558839798, 48.2086743414402, 48.29950846731663, 46.66209273040295, 47.455433160066605, 44.932064563035965, 47.13511794805527, 53.56016658246517, 49.30782236158848, 51.07054017484188, 49.514440074563026, 54.62866924703121, 52.81625010073185, 53.5898619890213, 54.40024070441723, 55.054086819291115, 52.08836115896702, 51.543500795960426, 54.702522084116936, 53.773133754730225, 53.10303971171379, 57.844436690211296, 57.633624002337456, 60.664162784814835, 65.88601738214493, 73.86145502328873, 69.68359440565109, 72.74236187338829, 71.99361965060234, 73.76733407378197, 75.0254313647747, 67.20398426055908, 2.985647991299629, 1.8041639705188572, 0.9319913084618747, 0.6216261594090611, 1.7490221606567502, 0.08565017240471207, 0.3529382130363956, 43.03338624536991, 64.41661342978477, 33.10359567403793, 42.05967329442501, 35.71868754923344, 39.6767071634531, 19.64004412293434, 28.95547606050968, 54.2120786011219, 55.418403670191765, 68.7794329226017, 13.672061562538147, 0.40482674434315413, 0.2003127825446427, 0.08584504554164596, 0.045632411929545924, 0.06586481220438145, 0.02266012117615901, 0.04187250255199615, 0.08282216673251241, 0.02348135025386, 0.07436408777721226, 0.04209474609524477, 0.03720387045177631, 0.06649196409853175, 0.037795002208440565, 0.08215525056584738, 0.034359118217253126, 0.053144326811889187, 0.08330075550475158, 0.076825613505207, 0.09248737114830874, 0.20476869656704366, 0.24260813486762345, 0.5483530880883336, 19.47396643459797, 96.50805741548538, 69.8492731153965, 68.00942704081535, 37.56750114262104, 31.25903595238924, 49.8384752869606, 55.83410896360874, 45.60725413262844, 5.801631286740303, 0.523282567737624, 2.6704335305839777, 5.684272209182382, 2.460779780521989, 2.141974987462163, 7.325296327471733, 105.93888536095619, 97.43776112794876, 98.92332181334496, 88.26910391449928, 90.69995507597923, 91.33176997303963, 95.16109049320221, 87.69167169928551, 85.80710962414742, 89.04382154345512, 84.5608676970005, 85.75526520609856, 78.8472130894661, 81.50014713406563, 79.24239188432693, 81.03883668780327, 75.85723713040352, 74.05322313308716, 72.84897655248642, 72.18358665704727, 65.14733701944351, 63.03080879151821, 60.54436281323433, 59.62603189051151, 62.41103544831276, 59.10192981362343, 52.83830791711807, 54.46391008794308, 57.60799057781696, 56.574449837207794, 61.27671271562576, 60.77763229608536, 56.89709812402725, 60.06218008697033, 60.89941956102848, 56.61333695054054, 55.14552891254425, 61.4339254796505, 70.0053383409977, 73.06193992495537, 69.1936106979847, 68.6212246119976, 72.84413561224937, 68.10398876667023, 67.00364381074905, 65.46515956521034, 66.19846701622009, 64.5773296058178, 65.2487687766552, 64.24725651741028, 62.41769269108772, 59.17597644031048, 57.331794798374176, 57.78849609196186, 64.93128821253777, 67.53339618444443, 66.55778333544731, 49.5194748044014, 49.269695207476616, 29.86693125218153, 26.206127889454365, 48.88839326798916, 57.2278855741024, 67.07171335816383, 63.4548394382, 64.46730270981789, 58.32186967134476, 56.39944262802601, 53.59474092721939, 51.07904031872749, 50.36855824291706, 49.79306772351265, 49.684526547789574, 50.157441571354866, 48.91772009432316, 49.689234495162964, 49.2011658847332, 52.75267191231251, 50.191020369529724, 52.01237663626671, 53.22554133832455, 52.72031284868717, 49.14517968893051, 53.18904049694538, 52.74274304509163, 54.39121998846531, 54.933948665857315, 52.16444827616215, 50.48445962369442, 48.112585097551346, 50.291581973433495, 48.81912678480148, 50.1910849660635, 56.04895323514938, 51.05129800736904, 54.64008003473282, 52.754788398742676, 57.0222520083189, 56.578850001096725, 57.3908132314682, 57.11145222187042, 56.986153945326805, 54.35691922903061, 55.42237065732479, 56.96639120578766, 57.70632170140743, 57.27886363863945, 60.40546506643295, 60.30374072492123, 63.288548961281776, 68.29520970582962, 75.34640774130821, 71.90739467740059, 77.20790505409241, 73.00637170672417, 78.18800926208496, 73.58379632234573, 70.92618852853775, 8.139879517257214, 1.0504796379245818, 0.652992941904813, 0.9575787198264152, 2.8210911713540554, 0.20258344273315743, 0.03283834630565252, 44.254310131073, 74.19207528233528, 39.843187630176544, 44.44584645330906, 38.895089104771614, 29.935057796537876, 28.771653324365616, 34.78457227349281, 60.83022527396679, 61.793351992964745, 78.45793917775154, 17.487433031201363, 0.6009558623190969, 0.17289245937718078, 0.08653147277073003, 0.021666478205588646, 0.06748371830326505, 0.03939192589314189, 0.04834559622395318, 0.0382510890631238, 0.053560768137685955, 0.05785064888186753, 0.026270179805578664, 0.136837960453704, 0.24818307399982587, 0.25920380372554064, 0.18712076620431617, 0.12865521828643978, 0.14481782913208008, 0.2232975562219508, 0.24814753996906802, 0.21958438359433785, 0.31086891889572144, 0.33437427948229015, 0.8453474671114236, 23.132180236279964, 109.8488299548626, 81.70255467295647, 76.83996319770813, 46.066132709383965, 51.44360035657883, 69.48126286268234, 80.47839716076851, 59.6690683811903, 8.892128001898527, 0.5954298900905997, 2.820978364907205, 9.941735230386257, 9.986561425030231, 7.453327132388949, 6.355982115492225, 107.46239840984344, 105.03006532788277, 104.04198914766312, 96.43248707056046, 96.21079176664352, 97.66039118170738, 99.28718268871307, 90.54374545812607, 87.65719994902611, 91.44435793161392, 86.88326507806778, 88.80907773971558, 83.20553362369537, 84.50060293078423, 83.68556186556816, 83.06700825691223, 76.92600578069687, 76.97215810418129, 77.01691970229149, 76.5246333181858, 68.63068610429764, 67.84230440855026, 67.4453093111515, 63.94793897867203, 63.795916736125946, 62.93972387909889, 56.078333258628845, 59.96486730873585, 60.60212731361389, 60.869788751006126, 63.50835956633091, 65.17182290554047, 59.000612050294876, 61.70683063566685, 62.3825141787529, 61.168042346835136, 59.278384745121, 66.11618623137474, 73.6967034637928, 75.65017864108086, 73.0498717725277, 71.0546064376831, 76.76895260810852, 72.24340304732323, 69.5595994591713, 69.89980280399323, 70.12407436966896, 66.7724946141243, 67.86877378821373, 69.47098821401596, 64.5899373292923, 60.80587238073349, 60.37434473633766, 61.56817227602005, 65.9744082391262, 71.91062450408936, 71.0021160542965, 55.15443183481693, 56.56642846763134, 30.795147344470024, 27.248269468545914, 55.333208441734314, 63.65531288087368, 72.70796611905098, 67.12990343570709, 67.88517370820045, 61.444127932190895, 62.30637386441231, 56.396592780947685, 54.03807073831558, 52.21758842468262, 52.601633816957474, 52.48448230326176, 54.53185424208641, 52.8971553593874, 53.633255660533905, 52.45058432221413, 56.3521009683609, 52.30493053793907, 56.643617525696754, 55.9185404330492, 54.9166975915432, 51.44859328866005, 55.67368537187576, 55.4085735976696, 59.809242859482765, 59.42420192062855, 54.25648681819439, 55.35279639065266, 51.88110128045082, 53.56394737958908, 52.5698409229517, 52.624668180942535, 59.0062091499567, 54.025861993432045, 59.003157913684845, 57.06216886639595, 61.49439923465252, 60.23538999259472, 61.52845300734043, 60.523323342204094, 62.261961847543716, 59.067317470908165, 59.64460909366608, 59.57391008734703, 62.92957462370396, 60.237145498394966, 65.24039402604103, 64.04864877462387, 67.21052750945091, 72.18693047761917, 79.92687955498695, 73.87544587254524, 81.06650680303574, 77.80506581068039, 81.40945360064507, 77.14290574193001, 81.71042025089264, 9.706189669668674, 4.039979316294193, 5.039747944101691, 3.469972852617502, 5.42980176396668, 0.3884948347695172, 0.6702960259281099, 56.248130947351456, 78.79625022411346, 51.035342663526535, 54.05372969806194, 54.04378943145275, 54.44222845137119, 31.057319976389408, 42.10683636367321, 73.2959009706974, 72.25356370210648, 92.36327022314072, 20.604859851300716, 0.8760678686667234, 0.3912489447975531, 0.2529127663001418, 0.1702603732701391, 0.13845328940078616, 0.23156151903094724, 0.15808710304554552, 0.18333348270971328, 0.1707321120193228, 0.2935962926130742, 0.083882332110079], [0.024908900995797012, 0.03228981382562779, 0.0776672683423385, 0.03230325412005186, 0.057037139995372854, 0.049602493818383664, 0.04482783479033969, 0.039966318508959375, 0.09401997289387509, 0.04041943306219764, 0.31789969943929464, 0.35333208565134555, 32.09993652999401, 77.05207541584969, 60.01964896917343, 44.69917505979538, 55.05637429654598, 35.555843487381935, 30.489459447562695, 36.65709279477596, 25.898312106728554, 0.4972573189297691, 0.291715512285009, 3.4063348174095154, 3.4727374417707324, 1.0034310375340283, 0.49926690640859306, 65.31825944781303, 102.25562140345573, 91.1381247639656, 86.82966515421867, 71.55394524335861, 78.99953931570053, 87.07277610898018, 88.42491835355759, 89.42520707845688, 82.13812530040741, 86.4062462747097, 85.70645302534103, 83.0555708706379, 80.44437378644943, 80.81043094396591, 76.81476294994354, 76.76395207643509, 78.79101410508156, 77.87198022007942, 76.91457599401474, 71.26104176044464, 69.15362164378166, 61.389418467879295, 58.428621143102646, 56.46175928413868, 58.02495360374451, 54.432789757847786, 49.654451161623, 52.35343113541603, 55.222923159599304, 54.22535128891468, 59.04274418950081, 58.53798687458038, 56.474386006593704, 56.73786386847496, 56.80273778736591, 50.04069663584232, 56.21449135243893, 59.876309260725975, 67.09831193089485, 68.08632731437683, 66.77630960941315, 67.51527115702629, 65.38861647248268, 66.30440533161163, 64.23597112298012, 62.89287619292736, 62.066583931446075, 62.279182523489, 59.323997497558594, 60.476787239313126, 59.61480349302292, 56.73664413392544, 51.331616565585136, 53.16939175128937, 61.01172253489494, 62.755334973335266, 62.78294429183006, 51.864701360464096, 49.112733229994774, 42.552852630615234, 38.856467977166176, 49.602017775177956, 52.20627263188362, 61.50546044111252, 61.020591259002686, 54.937585070729256, 52.32978880405426, 49.77584324777126, 47.95348383486271, 49.59613189101219, 50.04944756627083, 50.2130363881588, 49.10940460860729, 47.456128522753716, 48.74589331448078, 47.65457667410374, 46.847203597426414, 49.030600637197495, 48.171109557151794, 51.57782435417175, 50.64165338873863, 51.997264847159386, 49.976221695542336, 48.1350114941597, 47.940427735447884, 51.29885092377663, 51.305504366755486, 52.09576316177845, 48.31179700791836, 47.18530185520649, 46.02044776082039, 44.52359788119793, 43.433155193924904, 52.83709958195686, 50.55626817047596, 52.040286138653755, 50.21365575492382, 51.68534718453884, 50.47468654811382, 51.40889301896095, 51.45681604743004, 51.738061755895615, 50.58477804064751, 52.79261156916618, 51.605293080210686, 54.07473497092724, 50.43576903641224, 63.27020354568958, 62.462131306529045, 68.91000151634216, 72.08460956811905, 73.39759111404419, 74.39204335212708, 75.11791840195656, 73.15984547138214, 73.85547414422035, 71.61801740527153, 60.818472504615784, 50.71881964802742, 4.0662886295467615, 0.8249467180576175, 1.9711374607868493, 0.8067354827653617, 0.7439709850586951, 0.20984010334359482, 15.855364557355642, 70.21957084536552, 57.28124991059303, 24.096359498798847, 26.082985997200012, 47.79927670955658, 23.259247317910194, 17.22607545554638, 34.962877705693245, 58.609711825847626, 66.59037038683891, 35.01203566789627, 0.3180737479124218, 0.06831930979387835, 0.05708551689167507, 0.03631944564403966, 0.05627675403957255, 0.062349919171538204, 0.12110055569792166, 0.07544895925093442, 0.02651005306688603, 0.01902009462355636, 0.051532096331357025, 0.028845144661318045, 0.07504519380745478, 0.14654410915682092, 0.058336885485914536, 0.07213374105049297, 0.07009446024312638, 0.09111937775742263, 0.07854531068005599, 0.094485826411983, 0.05991961559629999, 0.27660396066494286, 0.4769900080282241, 40.88778577744961, 89.07759413123131, 66.40738740563393, 56.34581610560417, 54.16348300874233, 34.93271492421627, 30.481717362999916, 46.4402112364769, 32.69425503909588, 0.17943599028512836, 0.36358737910632044, 6.437100162729621, 3.8169146608561277, 0.4656640032771975, 0.3251571615692228, 74.84421908855438, 102.279172539711, 95.24432882666588, 89.66552898287773, 76.54164880514145, 79.39686879515648, 89.3484815955162, 89.43327024579048, 91.49196177721024, 85.05155056715012, 87.30723112821579, 88.70415776968002, 86.80992901325226, 82.4262410402298, 84.4365231692791, 80.56557208299637, 81.70245587825775, 82.45958045125008, 79.68650445342064, 80.10504439473152, 73.46452832221985, 71.75287216901779, 63.899453580379486, 61.07956409454346, 59.46690022945404, 59.54583719372749, 56.64312355220318, 51.87925837934017, 54.84950199723244, 56.722432896494865, 57.93028548359871, 62.51030512154102, 60.61084404587746, 57.74794086813927, 57.92214632034302, 59.317078068852425, 53.28766420483589, 58.014678955078125, 65.11665746569633, 69.38231617212296, 73.25158774852753, 69.08987626433372, 72.30764240026474, 67.21704795956612, 70.4896679520607, 70.5534665286541, 66.08814373612404, 66.15035399794579, 64.17654991149902, 63.99827867746353, 64.93324130773544, 62.541049271821976, 59.58972103893757, 53.220951184630394, 54.37896564602852, 62.184613198041916, 66.68072953820229, 66.76893800497055, 57.36777886748314, 53.07581037282944, 48.812062963843346, 44.38694201409817, 54.0206752717495, 55.49944952130318, 65.88873043656349, 63.41494157910347, 57.332961335778236, 54.70244988799095, 52.402991876006126, 50.1182846724987, 51.03012174367905, 52.661944180727005, 53.42871643602848, 49.3449729681015, 49.90029416978359, 49.261582642793655, 50.83147220313549, 49.946628883481026, 50.668058171868324, 49.96159628033638, 53.88379521667957, 53.88667546212673, 55.53750067949295, 52.68600448966026, 51.70825615525246, 50.69198548793793, 54.13555830717087, 53.74027691781521, 51.523597463965416, 50.99113203585148, 49.27466154098511, 48.93726244568825, 47.56623141467571, 47.120408937335014, 53.49128007888794, 52.99780435860157, 53.00739884376526, 53.403364196419716, 52.11099274456501, 52.49372720718384, 53.90263460576534, 53.35662670433521, 54.896114096045494, 53.32289971411228, 56.35732188820839, 55.01331880688667, 56.5498423576355, 55.72664313018322, 66.79193437099457, 65.79881966114044, 72.27893874049187, 73.78574788570404, 76.71364277601242, 76.73050627112389, 76.79134860634804, 75.52784040570259, 77.58161500096321, 72.98445448279381, 65.24230152368546, 66.16655632853508, 11.170441098511219, 0.7665164221543819, 0.6513615231961012, 1.488819366786629, 1.6248732036910951, 0.32033872324973345, 14.469540920108557, 77.38162413239479, 68.02053764462471, 32.53046862781048, 29.649221934378147, 39.21282805502415, 25.41623007506132, 29.784365482628345, 44.29419279098511, 65.59193596243858, 74.47728037834167, 42.919536754488945, 0.3480065823532641, 0.05232284725934733, 0.026342609708081, 0.11107416285085492, 0.04977567768946756, 0.058920874071191065, 0.11464046445325948, 0.032523479021620005, 0.03485164081212133, 0.034875022174674086, 0.05211438539845403, 0.14164890308165923, 0.1945608263486065, 0.1906722693820484, 0.17814986320445314, 0.23585462069604546, 0.14716810692334548, 0.13411328400252387, 0.19586994516430423, 0.13643188693094999, 0.4454636637819931, 0.5266243102960289, 0.7788090594112873, 45.808954909443855, 102.37536057829857, 78.0533292889595, 63.32611754536629, 71.16106912493706, 46.79337188601494, 45.614967718720436, 59.038351625204086, 42.64634661376476, 0.5058090866077691, 0.889954223530367, 10.436550378799438, 9.88840414211154, 8.313344959169626, 1.1410898133181036, 78.72692674398422, 107.28310883045197, 99.79890882968903, 92.84816980361938, 81.27350449562073, 84.67543914914131, 94.85987305641174, 91.9607426226139, 96.23387172818184, 86.28796622157097, 91.78415849804878, 93.8474553823471, 88.22385594248772, 85.38243681192398, 87.48161897063255, 84.72628802061081, 85.16543805599213, 86.66209414601326, 81.88226222991943, 81.99133157730103, 77.63898432254791, 79.22282293438911, 66.88616171479225, 65.16573563218117, 64.22084793448448, 64.22812074422836, 60.30599020421505, 55.36973588168621, 58.600227534770966, 62.26380094885826, 60.855448320508, 64.02261257171631, 64.54266026616096, 59.72047962248325, 61.89791478216648, 62.629193142056465, 55.37117600440979, 59.905533492565155, 65.6785637140274, 71.08502000570297, 76.68591186404228, 73.7889777123928, 74.9534860253334, 70.77690973877907, 73.87691259384155, 72.75619313120842, 71.33284270763397, 68.20080757141113, 68.91229659318924, 66.86704874038696, 68.68015944957733, 64.92949470877647, 62.93673723936081, 56.98397286236286, 58.08691307902336, 66.61395952105522, 71.18003770709038, 70.81596404314041, 58.39854575693607, 57.39607594907284, 50.578044801950455, 47.65905663371086, 60.58211758732796, 59.565425142645836, 69.42255601286888, 66.41678050160408, 60.83811745047569, 58.06171663105488, 55.41661016643047, 52.08043098449707, 54.06352557241917, 55.41284456849098, 56.37486934661865, 53.78781236708164, 53.17123465240002, 55.09970337152481, 53.75454895198345, 53.68225023150444, 56.74135588109493, 54.28924486041069, 57.587764263153076, 55.372346341609955, 57.647763043642044, 56.00860320031643, 54.88122269511223, 53.149074241518974, 57.40823909640312, 57.63945668935776, 55.78319929540157, 54.16631005704403, 52.07112528383732, 52.294781282544136, 50.82608409225941, 47.54873335361481, 57.4727064371109, 55.997048020362854, 56.36901766061783, 57.19938710331917, 56.80566743016243, 56.43151670694351, 57.04379305243492, 58.14389482140541, 58.242522329092026, 56.240109577775, 59.08214807510376, 57.09249883890152, 59.21555131673813, 57.141854390501976, 69.31119918823242, 69.96398895978928, 75.30410081148148, 78.18192198872566, 79.83316898345947, 80.58992117643356, 80.96486985683441, 79.67082649469376, 80.73059722781181, 78.39614689350128, 67.35216110944748, 65.86633443832397, 9.438259396702051, 2.1580291260033846, 7.186584770679474, 4.151563653722405, 1.8414768995717168, 0.43108422600198537, 21.59654773771763, 87.56317019462585, 74.8567508161068, 40.117586106061935, 42.220324873924255, 66.93381115794182, 33.02471190690994, 30.146847032010555, 53.192361518740654, 74.48394522070885, 84.75284859538078, 50.564916506409645, 0.4327567893778905, 0.17125594953540713, 0.18770016089547426, 0.20842833066126332, 0.21296997758327052, 0.1863186084665358, 0.2081192409968935, 0.11528542047017254, 0.15350613713962957, 0.11611282607191242, 0.1879393105627969], [0.020669968689617235, 0.025660080609668512, 0.029762667400063947, 0.014409504965442466, 0.022590524422412273, 0.02378974972089054, 0.05492100608535111, 0.0676368159474805, 0.043556921737035736, 0.05211027761106379, 0.06525362390675582, 0.046028692813706584, 45.565874353051186, 74.02900323271751, 55.04909388720989, 46.93388074636459, 22.574784345924854, 32.796879932284355, 47.03153930604458, 40.91363199055195, 19.916186705231667, 0.2650229539722204, 0.7285270700231194, 4.2968046851456165, 1.3051108620129526, 1.7456809524446726, 19.99948963522911, 107.11766570806503, 88.39767381548882, 94.6713499724865, 79.16628956794739, 75.0309182703495, 72.68933951854706, 79.52853932976723, 84.88116770982742, 86.95749789476395, 85.23321121931076, 83.33845049142838, 81.71666711568832, 84.22942668199539, 81.4933530986309, 80.59816673398018, 81.0983794927597, 79.22381848096848, 79.8074671626091, 81.21444046497345, 76.6643214225769, 72.31422364711761, 68.93802121281624, 66.76645293831825, 57.63888292014599, 57.47334860265255, 57.137146443128586, 53.23059506714344, 47.6082419604063, 53.258743956685066, 51.633821949362755, 56.096762269735336, 59.938899502158165, 56.017707511782646, 53.159280493855476, 56.40534371137619, 52.77769736945629, 48.14523674547672, 56.91450119018555, 66.3657720386982, 68.82117748260498, 65.44397950172424, 65.21972313523293, 68.78244996070862, 66.60216495394707, 66.53840437531471, 64.17851060628891, 65.16148746013641, 63.88354763388634, 59.38526540994644, 59.3129400908947, 60.363773703575134, 57.98783339560032, 57.00477294623852, 53.7029667198658, 53.95805463194847, 58.398469761013985, 62.19186320900917, 64.0537329018116, 52.67747774720192, 55.66285975277424, 54.546624049544334, 48.74912694096565, 54.72449630498886, 56.27901948988438, 61.00994423031807, 60.47920770943165, 55.98744973540306, 53.84620763361454, 51.07894532382488, 50.72990745306015, 51.80560693144798, 49.86299157142639, 46.471293568611145, 45.38071408867836, 46.3116679340601, 47.58425384759903, 49.22102741897106, 48.50807547569275, 49.91691827774048, 48.97586077451706, 52.08342902362347, 51.599916368722916, 52.75393344461918, 53.028035536408424, 51.23947151005268, 48.003036975860596, 48.87016944587231, 49.62724842131138, 48.36089037358761, 49.17678639292717, 46.83996878564358, 46.01553462445736, 46.52442991733551, 41.16382576525211, 49.01290498673916, 51.9378512352705, 50.70848420262337, 51.30084581673145, 47.96680971980095, 51.0211656242609, 49.95609037578106, 50.70608653128147, 51.58366084098816, 51.29203788936138, 52.41267375648022, 54.087954461574554, 53.584325686097145, 60.21512567996979, 67.12254703044891, 68.87128919363022, 72.95838788151741, 72.4164305627346, 74.43565741181374, 73.16745266318321, 73.18734839558601, 73.83164942264557, 74.24553081393242, 75.41666597127914, 73.44220831990242, 76.9725912809372, 65.7759676873684, 5.156674319878221, 1.1762229655869305, 1.570669231005013, 0.3862528660101816, 0.03575783281121403, 1.2074893503449857, 51.03340096771717, 69.36071813106537, 47.360548451542854, 32.82138481736183, 46.764204651117325, 28.446586467325687, 11.860872600227594, 23.93341664224863, 57.18076050281525, 56.08773395419121, 52.592647299170494, 1.073677868116647, 0.08619530955911614, 0.05542907296330668, 0.051681624245247804, 0.009719930385472253, 0.037834065151400864, 0.028238051163498312, 0.043424374161986634, 0.05221154366154224, 0.04301683489757124, 0.02686584793991642, 0.050737560450215824, 0.021892180157010444, 0.032218612177530304, 0.04098808145499788, 0.04751143707835581, 0.054231331960181706, 0.023530194703198504, 0.0411697146773804, 0.04994412294763606, 0.04624168177542742, 0.050395526850479655, 0.05406750657130033, 55.352838188409805, 81.94190382957458, 64.68370869755745, 57.476061657071114, 37.882899418473244, 29.908662512898445, 43.71179424226284, 52.75270231068134, 20.24376902729273, 0.4121275182114914, 3.7430706107988954, 4.822202017530799, 1.2824980379082263, 1.1702216626144946, 25.27988389134407, 112.77265146374702, 90.02467051148415, 97.62136727571487, 80.63032060861588, 77.40841269493103, 74.876479357481, 85.03596380352974, 87.05854967236519, 90.68150326609612, 87.74630516767502, 85.67223966121674, 82.19122365117073, 87.57466077804565, 84.84180942177773, 84.58722308278084, 84.01852279901505, 82.96385139226913, 81.77317008376122, 83.12987208366394, 78.36783081293106, 78.18588137626648, 72.14247286319733, 69.15701866149902, 60.176200568675995, 59.109404012560844, 57.95371122658253, 55.77916391193867, 50.36500543355942, 56.072553768754005, 54.6791685372591, 58.698592856526375, 61.486419662833214, 57.684199288487434, 55.56520879268646, 57.74004489183426, 54.07046020030975, 53.76859299838543, 59.80122908949852, 67.88300782442093, 72.34709188342094, 69.85628753900528, 69.04282718896866, 69.95976358652115, 70.57852238416672, 69.71744298934937, 66.79451063275337, 67.20238074660301, 67.99941837787628, 63.19414682686329, 63.97840574383736, 64.92706283926964, 61.49875000119209, 61.34231619536877, 57.59697116911411, 58.20372261106968, 62.32580982148647, 65.69696232676506, 66.11579865217209, 59.27931569516659, 59.073465541005135, 59.713723585009575, 54.127829521894455, 59.86276298761368, 59.530360624194145, 62.03636795282364, 64.74800884723663, 60.00057019293308, 59.357580095529556, 54.16146531701088, 53.61030489206314, 54.56545203924179, 52.041030898690224, 48.14826138317585, 49.12934213876724, 48.208875730633736, 49.45835508406162, 51.883643344044685, 50.73940694332123, 53.045700788497925, 50.874060317873955, 54.578291550278664, 55.52131734788418, 54.300800040364265, 53.723561614751816, 54.81836646795273, 53.069419115781784, 50.91360479593277, 52.45015874505043, 51.89330242574215, 52.06314191222191, 51.57445773482323, 48.67688521742821, 48.4220214933157, 44.682414159178734, 51.539032235741615, 53.173624724149704, 55.15356168150902, 53.521701246500015, 52.06243135035038, 53.0848652869463, 52.94439822435379, 54.26642708480358, 55.68463258445263, 53.68661619722843, 56.22383885085583, 57.23458081483841, 57.746489346027374, 63.443364053964615, 72.89461210370064, 72.55614906549454, 75.74044659733772, 73.32987114787102, 73.97515252232552, 75.69891482591629, 77.54509896039963, 74.95953530073166, 75.83059296011925, 76.21941089630127, 77.55420327186584, 75.68047061562538, 77.94240564107895, 12.02861174941063, 0.9563384426292032, 2.424688604660332, 1.7304923362098634, 0.05298739968566224, 0.48650187731254846, 54.21577200293541, 77.01531618833542, 57.77358189225197, 39.47581574320793, 45.3132639080286, 26.248239129781723, 19.920522272586823, 30.903177447617054, 63.73031705617905, 62.49302364885807, 62.04066552221775, 1.5974729927256703, 0.06008498094161041, 0.03764995686651673, 0.05273864291666541, 0.03810328293184284, 0.07943947246531025, 0.029962310691189487, 0.06594019214389846, 0.0360658278077608, 0.09625486156437546, 0.047869014961179346, 0.08233246058807708, 0.056811838803696446, 0.08082464657491073, 0.23667065659537911, 0.14930244942661375, 0.17338693753117695, 0.14916200540028512, 0.13754969491856173, 0.12299734415137209, 0.11736134852981195, 0.14805129234446213, 0.12754840892739594, 59.93385337293148, 94.68933060765266, 73.93932044506073, 64.02436047792435, 37.844107300043106, 44.452420100569725, 65.09100884199142, 61.887807324528694, 27.645192369818687, 0.5364896496757865, 4.368858318775892, 7.735197432339191, 8.170195240527391, 3.879715078510344, 24.73306093364954, 115.70703640580177, 93.99757012724876, 103.0417612195015, 86.88381984829903, 81.60094052553177, 79.5843431353569, 87.60211050510406, 90.94949528574944, 94.56367895007133, 92.95384973287582, 88.0625393986702, 86.24466374516487, 92.95352295041084, 86.4534093439579, 89.27171811461449, 89.16589379310608, 86.28065541386604, 86.6376918554306, 89.09441962838173, 83.36098328232765, 80.60197412967682, 75.55850476026535, 72.94309750199318, 64.16217908263206, 63.117326349020004, 62.1208868175745, 58.54469731450081, 53.96139085292816, 59.087125808000565, 59.2667231708765, 60.64514480531216, 64.21233639121056, 59.38843823969364, 57.30922020971775, 60.07277391850948, 57.482897490262985, 55.289613381028175, 63.634102419018745, 72.4399209022522, 74.29531574249268, 71.94948881864548, 72.5093811750412, 74.05902162194252, 75.26041835546494, 72.17230886220932, 69.68330562114716, 71.22978463768959, 69.88385125994682, 66.10299333930016, 67.07618951797485, 67.1068462729454, 63.753701001405716, 64.1821052134037, 59.75769482553005, 61.44307918846607, 64.5776715874672, 69.53098699450493, 71.9134895503521, 63.537287414073944, 64.15536224842072, 63.323970660567284, 57.995178401470184, 63.484781831502914, 62.750900611281395, 67.17162519693375, 68.16649541258812, 60.9922181814909, 62.612367644906044, 57.26508937776089, 55.976168140769005, 57.88965806365013, 53.9370721578598, 52.18916594982147, 51.01777620613575, 50.86182497441769, 52.354943454265594, 54.322272688150406, 54.98187929391861, 56.22274450957775, 54.9528868496418, 58.72714452445507, 59.032055363059044, 58.06966580450535, 58.80855895578861, 58.615867495536804, 53.882621079683304, 54.37182202935219, 55.197730511426926, 54.042736887931824, 55.68223491311073, 54.30184118449688, 50.682079419493675, 51.3739462941885, 49.86901804804802, 54.54026699066162, 57.116874530911446, 56.62923909723759, 56.4351911097765, 54.05232757329941, 57.299678921699524, 56.31734423339367, 58.41223642230034, 57.62196622788906, 57.713811099529266, 60.3164928406477, 61.361292377114296, 60.09228587150574, 66.97439298033714, 75.56555718183517, 73.60851019620895, 77.51748964190483, 76.74426153302193, 78.74747604131699, 78.29878091812134, 81.20010763406754, 79.05983448028564, 79.53192874789238, 78.27263832092285, 82.02940553426743, 79.55163449048996, 77.48915076255798, 8.915745634585619, 3.040035185404122, 8.13416937366128, 2.4607529444620013, 0.09576917786034755, 1.4492006739601493, 67.64209315180779, 82.71371081471443, 66.39815390110016, 49.15672346949577, 64.32742461562157, 38.50299194455147, 21.103026419878006, 39.155166149139404, 74.68965858221054, 74.65198740363121, 74.15892586112022, 1.7421895335428417, 0.25103902153205127, 0.2194097710889764, 0.1248672668589279, 0.1633889169897884, 0.12930756609421223, 0.18353650462813675, 0.141171524010133, 0.09990576800191775, 0.23361713450867683, 0.1032158060115762], [0.03105345145741012, 0.0036522320988296997, 0.07790593561367132, 0.05992444326693658, 0.047285872424254194, 0.08816672838293016, 0.047728723075124435, 0.03046677815291332, 0.023326790578721557, 0.027601618712651543, 0.009994045412895503, 0.46554653614293784, 61.24813824892044, 73.97406578063965, 57.37583063542843, 41.16159528493881, 36.96615681052208, 105.77237069606781, 39.451147466897964, 55.029475539922714, 9.662518613040447, 0.44309268007054925, 2.5033550709486008, 2.137100324034691, 0.33814430062193424, 0.3564582788385451, 81.84817805886269, 97.48724207282066, 89.20847430825233, 85.07878750562668, 77.70687147974968, 69.16758969426155, 70.66784799098969, 68.70965346693993, 80.33231779932976, 84.38136532902718, 86.6875983774662, 82.414241284132, 83.29184979200363, 79.3727020919323, 81.30945056676865, 77.61579796671867, 81.73421457409859, 78.15613657236099, 76.211978495121, 73.67433026432991, 74.16694343090057, 72.2253692150116, 70.85920572280884, 61.85816511511803, 56.941700130701065, 55.288883820176125, 57.275462821125984, 50.80323591828346, 49.500589817762375, 50.55906102061272, 49.51144203543663, 59.717967957258224, 58.459559082984924, 54.8310349881649, 55.54439350962639, 54.66147668659687, 51.714275032281876, 51.3048280030489, 61.78318753838539, 65.74350222945213, 67.09043875336647, 66.81536391377449, 68.02480101585388, 67.50488251447678, 67.49580100178719, 66.8603079020977, 66.09033241868019, 61.987658366560936, 60.47456815838814, 55.992058888077736, 56.87018036842346, 59.610787108540535, 60.469111651182175, 55.85197940468788, 54.647090658545494, 55.83048015832901, 59.9828327447176, 65.84922775626183, 57.84719534218311, 52.23239243030548, 56.34201630949974, 50.70335827767849, 48.455471098423004, 54.04685586690903, 56.166811510920525, 55.863412991166115, 64.48589891195297, 60.49109727144241, 59.78154234588146, 57.51988850533962, 58.9429197460413, 60.46534605324268, 59.11732278764248, 52.500722631812096, 46.61059029400349, 46.03097699582577, 48.608960062265396, 45.345303788781166, 50.2646604180336, 50.030775368213654, 50.485724955797195, 51.85163386166096, 52.5527798384428, 51.069704219698906, 53.0799825489521, 50.333831906318665, 52.31146238744259, 49.23834688961506, 50.260693430900574, 48.91340732574463, 49.82628934085369, 48.748982548713684, 46.87409095466137, 45.204266756772995, 42.574496269226074, 44.17480319738388, 52.15251311659813, 49.05636325478554, 50.55889382958412, 49.656932428479195, 51.07514172792435, 49.90696281194687, 51.10826075077057, 51.12991198897362, 52.90640406310558, 52.51252859830856, 54.63353678584099, 61.3546047359705, 67.8554593026638, 70.92309549450874, 73.00238952040672, 69.73891943693161, 71.44602343440056, 70.08978500962257, 74.69568505883217, 72.22500443458557, 74.55206036567688, 75.22412270307541, 76.70497924089432, 73.03678527474403, 73.31854775547981, 78.91047969460487, 66.22869059443474, 0.5526223371271044, 1.4666295074857771, 2.298184367828071, 0.23001016321359202, 0.2680962468730286, 22.9577049985528, 68.90613332390785, 59.25517559051514, 35.46214811503887, 48.675965666770935, 44.050226882100105, 23.925418071448803, 24.310455210506916, 47.92871676385403, 52.70767092704773, 64.2510487139225, 4.59448641166091, 0.44931330252438784, 0.10522082186071202, 0.05580727141932584, 0.10199456490227021, 0.04481219031731598, 0.017752994353941176, 0.06166619707073551, 0.017009514522214886, 0.04472331071156077, 0.013060929868515814, 0.07623311248607934, 0.06006258292472921, 0.07417233166052029, 0.058078555011888966, 0.02345448450796539, 0.07106255477992818, 0.01495999114922597, 0.020660222435253672, 0.039406208525178954, 0.10687546979170293, 0.017915469034051057, 0.6739548139739782, 72.74002879858017, 81.13382399082184, 66.8644268810749, 45.41606359183788, 37.74106442928314, 110.78851953148842, 43.63970831036568, 64.22356098890305, 7.858501765877008, 0.4330443567596376, 3.582815397530794, 1.9884356763213873, 0.3394071391085163, 0.9344612946733832, 87.39945977926254, 97.19637528061867, 94.86219853162766, 85.90673267841339, 79.7702519595623, 71.91381633281708, 73.55723574757576, 71.68987914919853, 81.68790265917778, 85.12182399630547, 89.84029680490494, 84.8987227678299, 85.32176926732063, 83.11262100934982, 84.62964400649071, 82.38340973854065, 87.53343299031258, 80.91470494866371, 80.71744233369827, 77.13053360581398, 79.88482341170311, 76.9045141339302, 72.06684932112694, 67.12091311812401, 61.52901157736778, 58.876408115029335, 59.79291133582592, 54.70771640539169, 53.18847052752972, 52.84147694706917, 52.04166926443577, 60.62029413878918, 59.79147881269455, 54.93443883955479, 54.7321642935276, 55.200447365641594, 53.945845887064934, 54.370138719677925, 66.05038896203041, 69.58118990063667, 70.8494782447815, 69.43577170372009, 71.29888013005257, 68.39694544672966, 71.70330762863159, 68.95975604653358, 69.5532537996769, 65.39366260170937, 63.215589076280594, 60.447509810328484, 60.02945624291897, 62.47677192091942, 62.419056817889214, 59.06231313943863, 57.23900377750397, 58.893917575478554, 61.83948531746864, 67.4725766479969, 60.765385553240776, 56.23228579759598, 59.10089626908302, 52.170174568891525, 50.87976761162281, 55.97097761929035, 56.75852335989475, 58.35838571190834, 63.74595321714878, 62.49183811247349, 62.93393298983574, 60.406889989972115, 60.88420897722244, 64.08594757318497, 63.28255668282509, 53.28402779996395, 50.32652489840984, 49.90817494690418, 49.82328750193119, 48.54223944246769, 53.12297724187374, 52.30919770896435, 55.981218069791794, 54.91032913327217, 55.05903035402298, 53.37637424468994, 57.23977513611317, 53.43314699828625, 53.231294229626656, 53.30451250076294, 53.15082594752312, 51.33405603468418, 52.35112465918064, 51.35097652673721, 49.322269186377525, 48.273970037698746, 44.420555010437965, 46.1122964322567, 53.48454684019089, 52.1181857585907, 54.20935034751892, 50.64910098910332, 52.4183164536953, 51.93492539227009, 53.96391771733761, 53.94746080040932, 56.328736022114754, 54.561150670051575, 56.52881048619747, 64.37682956457138, 70.55911302566528, 72.01411575078964, 74.04935494065285, 71.8386259675026, 74.33402806520462, 71.58773303031921, 77.71673575043678, 73.52016493678093, 77.28071674704552, 73.78616586327553, 79.1100449860096, 73.60198214650154, 77.91863411664963, 78.35304200649261, 77.49181061983109, 1.4139687269926071, 1.98923280229792, 3.0522358557209373, 0.6356444384437054, 0.38512162514962256, 21.31637927144766, 78.97997796535492, 66.89625397324562, 47.71177880465984, 47.59659178555012, 35.48399314284325, 26.626183949410915, 34.6391236782074, 56.24519370496273, 58.68461720645428, 73.72760340571404, 6.599361905828118, 0.45564183325041085, 0.12519974901806563, 0.22107941040303558, 0.043316206138115376, 0.06866361436550505, 0.0687500523054041, 0.098251305607846, 0.08077639955445193, 0.04598083171003964, 0.055009911666275, 0.21491005551069975, 0.14755613141460344, 0.1495778010576032, 0.13650017936015502, 0.16072805039584637, 0.1315512863220647, 0.22285961487796158, 0.2104507276089862, 0.18646347569301724, 0.1988119669840671, 0.10897697968175635, 0.5697036674246192, 81.57091453671455, 92.90661066770554, 73.73552218079567, 58.07394437491894, 49.05783377587795, 112.37815663218498, 58.03747773170471, 74.623853713274, 11.955195888876915, 0.5422810139134526, 7.327647926285863, 6.852431176230311, 4.747649542987347, 0.723214183235541, 90.41853457689285, 100.17947360873222, 97.95705646276474, 90.96882104873657, 84.47328999638557, 75.32141268253326, 76.61362454295158, 75.11183872818947, 87.90626138448715, 89.68075096607208, 91.80343866348267, 86.0437685251236, 88.058602809906, 82.76383772492409, 89.05050918459892, 84.09888088703156, 90.41101098060608, 86.22130259871483, 87.23749727010727, 82.34592095017433, 82.22602978348732, 78.34013789892197, 78.0589833855629, 69.91405203938484, 63.79394844174385, 60.93774050474167, 62.914713621139526, 57.8132251650095, 56.72312445938587, 55.76990380883217, 55.6321270018816, 62.038389444351196, 63.897325694561005, 56.79582215845585, 56.45792908966541, 58.57365556061268, 57.99192197620869, 55.62357746064663, 69.95179921388626, 69.98011529445648, 72.22377330064774, 72.78480559587479, 74.64258670806885, 72.7478563785553, 74.2799873650074, 72.91310951113701, 73.4072045981884, 68.21618154644966, 66.1314994096756, 63.20801228284836, 63.08693177998066, 63.14145885407925, 65.82923322916031, 61.6576536744833, 60.32692328095436, 61.42734043300152, 65.23914009332657, 70.00419840216637, 64.52848702669144, 59.60902780294418, 60.8633328974247, 52.75118999183178, 53.613808304071426, 58.81726808845997, 63.02233524620533, 62.12628252804279, 69.62413519620895, 64.54468175768852, 65.54680198431015, 62.82466225326061, 65.91374829411507, 64.7713015973568, 65.19053310155869, 56.74522027373314, 52.1744379401207, 52.75800682604313, 55.18011085689068, 51.674407571554184, 57.4105341732502, 53.976973816752434, 58.97815525531769, 59.7477887570858, 58.16585764288902, 55.99436156451702, 59.62176851928234, 57.26513497531414, 58.237514197826385, 56.31387881934643, 56.19478181004524, 55.28084725141525, 57.554113268852234, 55.76647639274597, 53.944166377186775, 51.186908930540085, 47.20938116312027, 49.32817406952381, 56.36898726224899, 53.785380497574806, 56.983855068683624, 54.80818681418896, 56.66897736489773, 56.55106209218502, 57.559277191758156, 58.015408515930176, 60.990911051630974, 58.3026123046875, 61.54741398990154, 68.83915811777115, 73.0838343501091, 75.62188535928726, 77.17641234397888, 74.4351178407669, 78.1900991499424, 73.97706001996994, 82.53916338086128, 75.90865597128868, 81.2014451622963, 77.3980924487114, 85.05785062909126, 77.75284141302109, 82.46327385306358, 83.30102249979973, 79.39432293176651, 0.7235592522192746, 6.84348170645535, 7.45020417496562, 0.6164267321582884, 0.43458226486109197, 29.826706610620022, 86.97262108325958, 75.70314779877663, 53.19858558475971, 63.96580561995506, 60.093699395656586, 33.42897601425648, 38.507756888866425, 65.81671670079231, 66.94954231381416, 85.19332855939865, 8.260598089545965, 0.7675447419751436, 0.3277720743790269, 0.2843729703454301, 0.26285683270543814, 0.15665291750337929, 0.09847053603152744, 0.234880032367073, 0.21620499930577353, 0.1280967818456702, 0.14849433966446668], [0.04954411277140025, 0.020670738667831756, 0.040458432922605425, 0.015818304418644402, 0.06792985295760445, 0.02937599361757748, 0.014099783547862899, 0.11052357091102749, 0.043497705773916095, 0.09503741282969713, 0.06807015597587451, 0.8285030303522944, 58.38072091341019, 73.8163286447525, 61.164174154400826, 54.527613669633865, 53.104742020368576, 34.157016947865486, 45.717740803956985, 64.96360927820206, 0.9553691977635026, 0.10888413700740784, 2.8470665775239468, 2.802217109128833, 1.9411873491480947, 25.972514525055885, 111.77828282117844, 85.58882653713226, 94.57768499851227, 78.85209202766418, 74.4874258339405, 70.95359265804291, 72.31694430112839, 62.04763434827328, 66.50514096021652, 70.2011190354824, 82.77899131178856, 83.67601677775383, 83.77576902508736, 81.0227483510971, 84.95261907577515, 79.96169328689575, 79.2298449575901, 74.86715465784073, 74.46300834417343, 77.82952129840851, 77.78330057859421, 71.9688905775547, 64.63297381997108, 58.59137021005154, 57.310458943247795, 57.25414976477623, 53.34054596722126, 51.1994444578886, 52.77620404958725, 49.97406341135502, 51.88229821622372, 62.07354515790939, 54.972733184695244, 53.01214478909969, 54.0572065114975, 52.92169824242592, 49.251102805137634, 53.933040574193, 62.477334290742874, 66.12326145172119, 66.81810736656189, 66.43479913473129, 67.50822633504868, 64.93285372853279, 67.38528773188591, 64.8813284933567, 66.56391620635986, 60.742275193333626, 55.99242366850376, 56.0650871694088, 57.463852912187576, 60.834302455186844, 60.689906403422356, 61.904005855321884, 57.15797692537308, 59.31416742503643, 61.91771171987057, 61.71047084033489, 52.46221549808979, 52.36673042178154, 56.45424708724022, 49.210558980703354, 52.065600380301476, 52.72973254323006, 52.39266403019428, 50.027040168643, 60.065873488783836, 65.59033244848251, 65.63288256525993, 61.40529401600361, 63.55914004147053, 61.272050365805626, 61.82469271123409, 56.000342443585396, 50.823124051094055, 48.23487013578415, 48.89885030686855, 49.88737106323242, 51.41841910779476, 50.941822081804276, 51.09279938042164, 50.978892892599106, 53.89870181679726, 51.97896122932434, 52.83489570021629, 50.39703771471977, 50.95366984605789, 48.51482771337032, 48.63110527396202, 49.178386107087135, 48.61129313707352, 48.10878150165081, 48.9578041434288, 47.19007819890976, 45.298646092414856, 43.60897175967693, 49.061728566884995, 49.530319422483444, 52.34151117503643, 48.992492482066154, 50.664611756801605, 49.97553013265133, 51.04861535131931, 51.960896998643875, 52.75742545723915, 52.128266617655754, 64.4796596467495, 66.8475253880024, 71.51364460587502, 69.69938635826111, 71.7824649810791, 70.20568639039993, 71.95708841085434, 69.6185190975666, 72.93739780783653, 70.03350242972374, 74.7400514781475, 70.80486863851547, 73.97195309400558, 68.86474594473839, 78.32775056362152, 66.66895776987076, 86.68314501643181, 31.825680546462536, 0.9111457457765937, 3.056092648766935, 0.2919695049058646, 0.1859552678070031, 3.025217168033123, 56.70670934021473, 65.23704260587692, 50.59170126914978, 43.42644475400448, 44.09123808145523, 19.311139471828938, 18.542982190847397, 42.83699758350849, 54.51390400528908, 59.43587489426136, 9.202832579612732, 0.53722312906757, 0.10994983880664222, 0.07879099866840988, 0.04167404113104567, 0.11572184041142464, 0.0425022556737531, 0.08275999702163972, 0.026772843848448247, 0.03382810413313564, 0.06699767094687559, 0.03898954455507919, 0.1131226314464584, 0.03404967974347528, 0.039500056809629314, 0.021319281113392208, 0.03345664437802043, 0.045887770102126524, 0.030461789065157063, 0.03504585714836139, 0.09325527877081186, 0.06269157427595928, 0.7501735584810376, 70.20649954676628, 81.3626629114151, 70.52383571863174, 59.01983521878719, 55.502037182450294, 38.04625265300274, 51.32221207022667, 73.97849634289742, 0.4678641149075702, 0.48417358193546534, 4.163156831637025, 1.4653184590861201, 0.6920996715780348, 31.249032989144325, 115.81919118762016, 86.41668811440468, 96.828783005476, 80.31201928853989, 78.75221058726311, 73.16657111048698, 76.88811421394348, 65.82520544528961, 68.95616143941879, 73.34758579730988, 83.61664116382599, 86.08473032712936, 87.69764497876167, 82.43203952908516, 87.35267668962479, 81.0204304754734, 81.77193894982338, 78.42636287212372, 80.92651471495628, 80.66167652606964, 78.89293223619461, 73.9302921295166, 67.5891999900341, 60.77754110097885, 59.138088673353195, 59.24386739730835, 58.77871535718441, 54.2234817892313, 56.61834888160229, 53.18004637956619, 56.311500146985054, 64.9055939912796, 55.2204342931509, 53.343927785754204, 53.50481875240803, 54.62605498731136, 54.23181474208832, 57.84141205251217, 64.464141279459, 69.34175714850426, 69.7516031563282, 68.90816241502762, 70.56466072797775, 67.39729508757591, 70.68739414215088, 69.95755210518837, 68.05103480815887, 64.23990771174431, 61.14013284444809, 59.146535620093346, 59.607116505503654, 64.26111057400703, 64.82696861028671, 63.5528589785099, 60.12653723359108, 62.02018082141876, 63.98725166916847, 63.11943143606186, 53.568461537361145, 56.46398976445198, 57.18047931790352, 52.63378009200096, 55.948342233896255, 55.51022954285145, 54.14568476378918, 54.01936814188957, 62.871631532907486, 65.62282830476761, 68.05098921060562, 65.4163321852684, 66.21916070580482, 64.0444765985012, 64.50201004743576, 59.15245570242405, 52.36607685685158, 51.582756489515305, 51.46179378032684, 53.591416105628014, 54.2123331874609, 54.71357949078083, 55.3251376748085, 54.744403436779976, 54.052008390426636, 54.29023660719395, 56.15886993706226, 55.23990444839001, 53.380166441202164, 51.374174281954765, 52.4385579675436, 51.504207104444504, 52.11575388908386, 50.02772033214569, 51.778810769319534, 49.035213589668274, 48.0828782916069, 45.525870099663734, 51.809570118784904, 54.010393023490906, 53.85196432471275, 50.89989893138409, 51.29078395664692, 52.50172957777977, 54.16642785072327, 54.313688948750496, 55.52277646958828, 56.035190373659134, 65.56354388594627, 69.45457309484482, 74.77728188037872, 71.55692428350449, 74.44910869002342, 72.06786766648293, 76.1686684191227, 72.02375203371048, 74.10804659128189, 73.49985122680664, 76.9238018989563, 72.2638763487339, 76.10395789146423, 70.25108635425568, 77.35284447669983, 71.61863297224045, 85.73501989245415, 44.12275739014149, 0.4559492308180779, 0.5275981861632317, 0.9911160764750093, 0.42298629647120833, 2.397595108486712, 60.454140454530716, 74.71283733844757, 58.50075267255306, 49.396684393286705, 33.383697643876076, 18.78538828343153, 30.41835006326437, 51.82484529912472, 61.27667471766472, 70.30587941408157, 13.708967082202435, 0.627909597242251, 0.25100250786636025, 0.16344160947483033, 0.05867338266398292, 0.14173972711432725, 0.06670617760391906, 0.01564313715789467, 0.08680621584062465, 0.023872942620073445, 0.04005076378234662, 0.11451289668912068, 0.21570338169112802, 0.1254513073945418, 0.16223072132561356, 0.12195920571684837, 0.152947255410254, 0.12106953392503783, 0.16621897841105238, 0.17608596535865217, 0.32282465079333633, 0.27171997586265206, 1.4838189538568258, 79.56509336829185, 90.81953465938568, 78.55135336518288, 69.25961315631866, 67.59933024644852, 44.93190497159958, 63.46922546625137, 81.4930035173893, 1.2064021336846054, 0.7120963954366744, 7.093822248280048, 8.921606820076704, 4.344356283545494, 31.679325699806213, 119.25643354654312, 92.31279373168945, 100.71528285741806, 86.25898897647858, 83.64247217774391, 77.12195366621017, 81.91077589988708, 68.58837157487869, 74.19705301523209, 77.56365716457367, 89.55655843019485, 91.15539103746414, 90.7471713423729, 85.92116430401802, 93.0303244292736, 84.87087026238441, 86.82251393795013, 83.17900344729424, 84.05845865607262, 83.91439318656921, 85.10128229856491, 78.92346739768982, 71.60784155130386, 64.96558517217636, 63.74187223613262, 61.17925174534321, 62.523520812392235, 57.441050335764885, 60.44919312000275, 56.13647013902664, 57.878034487366676, 66.88614651560783, 57.51293867826462, 53.531717509031296, 56.66420102119446, 57.67686188220978, 56.379733085632324, 59.376221895217896, 67.24733233451843, 72.30836436152458, 72.28373408317566, 72.08990648388863, 74.89600270986557, 69.18741703033447, 74.67442899942398, 71.7136962711811, 71.6305111348629, 67.19201490283012, 62.73867666721344, 63.33586782217026, 63.393594324588776, 68.21036785840988, 68.56339931488037, 67.33525201678276, 64.16270345449448, 65.72438165545464, 67.8610298037529, 68.641796708107, 60.1991019397974, 58.91636677086353, 59.81400020420551, 52.633312717080116, 55.2314954996109, 56.78601488471031, 57.88921348750591, 57.13282227516174, 66.49709299206734, 68.94014149904251, 71.98488771915436, 68.45840334892273, 68.17920953035355, 66.4640499651432, 67.8862452507019, 63.21408435702324, 55.335275530815125, 55.772035494446754, 52.78343506157398, 55.500038489699364, 58.54413874447346, 56.899879574775696, 58.15332591533661, 57.146406546235085, 57.58080683648586, 57.691137716174126, 60.99389769136906, 57.80391186475754, 58.49217273294926, 55.30505955219269, 56.74777753651142, 54.05159421265125, 54.871119037270546, 54.09798592329025, 55.50771027803421, 51.326152458786964, 51.58739224076271, 50.39461724460125, 54.13913391530514, 56.65072314441204, 58.464457020163536, 53.87139268219471, 55.538568422198296, 56.102119982242584, 55.97165398299694, 60.036083087325096, 60.245565846562386, 56.849011704325676, 70.53398877382278, 74.3962687253952, 76.85688748955727, 74.97836709022522, 78.53389710187912, 74.98095855116844, 78.86374980211258, 77.29462400078773, 77.79328644275665, 76.06484279036522, 79.7167356312275, 76.00036785006523, 78.17124456167221, 76.03621512651443, 82.21789821982384, 73.72948050498962, 91.52252733707428, 41.16077072918415, 2.332065487280488, 11.835146080702543, 1.141830536071211, 0.3603042068425566, 4.748417576774955, 71.21568739414215, 80.02736896276474, 67.6775224506855, 61.32993645966053, 59.34524975717068, 28.66878904402256, 31.112173832952976, 61.578503921628, 69.42790612578392, 84.18225601315498, 18.139202557504177, 0.8312753972131759, 0.4489137599011883, 0.2614422101760283, 0.18205808708444238, 0.23819962923880666, 0.20709130709292367, 0.14374220481840894, 0.10111937241163105, 0.0943508668569848, 0.15197858941974118], [0.025739165721461177, 0.03080965965637006, 0.03630775310739409, 0.010199134212598437, 0.07181693305028602, 0.05734699036111124, 0.0633515662048012, 0.007990711455931887, 0.09904075035592541, 0.03531744237989187, 0.03119766930467449, 1.3815138372592628, 60.78794114291668, 64.54807117581367, 49.62147653102875, 33.71773771941662, 40.847302749753, 56.12434878945351, 56.026374846696854, 46.28194212913513, 0.05706676653062459, 0.3078900568652898, 2.4640307435765862, 0.7501726085320115, 0.7596976880449802, 79.14581626653671, 95.69504544138908, 89.8415507376194, 82.87391021847725, 76.32487043738365, 70.69900631904602, 71.4270168542862, 66.14200204610825, 64.69697758555412, 61.13429255783558, 60.18333278596401, 67.35476016998291, 76.88894256949425, 78.11214253306389, 80.82040160894394, 78.78142341971397, 79.1028405725956, 73.8126428425312, 75.13538986444473, 75.34083724021912, 72.96088054776192, 67.23321229219437, 61.86531253159046, 56.56189151108265, 57.169748693704605, 53.48564498126507, 57.22671903669834, 54.3111202865839, 50.93372851610184, 52.26787872612476, 50.59183806180954, 57.071288377046585, 59.95971858501434, 54.00776356458664, 55.24672508239746, 53.52005213499069, 52.85451024770737, 48.6589577794075, 55.14410398900509, 65.9062322974205, 66.2741893529892, 65.25834426283836, 68.5952340066433, 63.82532715797424, 64.19633165001869, 66.97506174445152, 65.41013851761818, 66.46628424525261, 64.99858260154724, 61.541087329387665, 52.72896498441696, 56.09509035944939, 60.39154641330242, 62.521487921476364, 63.866471350193024, 59.49357479810715, 57.86059342324734, 62.911521792411804, 55.92220723628998, 47.559999749064445, 49.75841738283634, 52.844569981098175, 54.968310222029686, 59.913756251335144, 59.027142226696014, 50.57511895895004, 50.43614141643047, 52.63536460697651, 58.76299560070038, 60.86655132472515, 61.51222787797451, 64.52822864055634, 62.66585357487202, 58.831053748726845, 55.82672595977783, 52.30784498155117, 50.81529647111893, 49.479778334498405, 52.15869918465614, 52.894761487841606, 53.26485022902489, 52.0068821310997, 53.318932726979256, 51.67895592749119, 56.50769121944904, 54.83788222074509, 54.37670096755028, 49.14956085383892, 49.21679064631462, 49.48984779417515, 50.624694898724556, 49.73001770675182, 49.038713201880455, 47.713538110256195, 48.33895795047283, 46.59601807594299, 40.894720405340195, 46.278944090008736, 52.781421169638634, 49.796631932258606, 48.809600695967674, 49.43892292678356, 49.39558245241642, 50.92672549188137, 52.94737346470356, 50.191210359334946, 58.15713331103325, 63.068191185593605, 69.81695204973221, 69.16236877441406, 69.24483954906464, 68.35586205124855, 67.80353128910065, 67.22875893115997, 66.47368624806404, 67.59268060326576, 70.64061105251312, 69.22627374529839, 70.7848285138607, 69.14129510521889, 73.15207868814468, 67.07868978381157, 77.42573976516724, 73.58305156230927, 83.46626803278923, 7.253257418051362, 0.9323981241323054, 2.9052250692620873, 0.16648155025904998, 0.06731464964104816, 33.58190640807152, 72.22808226943016, 56.22687868773937, 42.96677581965923, 38.22354353964329, 41.43602415919304, 18.951260782778263, 32.044733092188835, 50.25907851755619, 58.43061223626137, 15.360756497830153, 0.46553697728086263, 0.2760115190176293, 0.06501295283669606, 0.046282997136586346, 0.03148387484543491, 0.10437784600071609, 0.04305520393245388, 0.010148423261853168, 0.030689366794831585, 0.0413765586563386, 0.00848519981445861, 0.021145607424841728, 0.04911712181637995, 0.017382484547852073, 0.012377168804960093, 0.08251230523455888, 0.04875571445154492, 0.059044549270765856, 0.06875206352560781, 0.03723786452610511, 0.12181336627691053, 2.578153107315302, 73.16227734088898, 71.70402958989143, 62.178902104496956, 48.40057544410229, 33.051511868834496, 42.68272586166859, 69.92280676960945, 46.014124900102615, 0.07906850252766162, 0.8569369046017528, 1.6472434345632792, 0.46989222639240324, 1.5588422468863428, 85.85105046629906, 97.11179941892624, 94.09293740987778, 85.5135677754879, 78.31732392311096, 72.67667099833488, 73.10007467865944, 69.39008295536041, 67.74658754467964, 63.56838494539261, 64.35393959283829, 69.70966100692749, 79.03496101498604, 81.39485478401184, 85.5871394276619, 80.64667493104935, 81.16270244121552, 77.70162016153336, 78.40009868144989, 77.95132756233215, 75.82087308168411, 70.27999520301819, 65.1966355741024, 58.983083590865135, 59.736944139003754, 56.84154510498047, 58.880188912153244, 55.9978573769331, 53.18663142621517, 53.197464644908905, 53.21259543299675, 58.91726352274418, 59.95662175118923, 55.142865255475044, 56.38355188071728, 55.36940909922123, 54.670672193169594, 52.13351033627987, 57.083789706230164, 68.59174579381943, 68.50818067789078, 68.85966941714287, 70.92473700642586, 66.48562520742416, 65.74050799012184, 70.81421613693237, 68.28200921416283, 67.25501552224159, 68.34790527820587, 64.19389218091965, 56.90568946301937, 57.88403436541557, 63.84129390120506, 64.57477614283562, 66.74942225217819, 63.41786362230778, 60.596154034137726, 66.74065992236137, 59.051555916666985, 50.59626862406731, 53.300264328718185, 55.285300612449646, 58.962245509028435, 61.42884515225887, 60.153793171048164, 50.05530305206776, 53.267696276307106, 54.85037975013256, 59.92716193199158, 64.34241861104965, 64.234329611063, 65.1747639477253, 66.5683163702488, 61.143875643610954, 58.515400886535645, 55.92768274247646, 52.70851828157902, 53.07524800300598, 55.571497455239296, 55.086088702082634, 55.75839042663574, 54.984140172600746, 56.48241117596626, 55.04064694046974, 58.658136427402496, 57.779881954193115, 57.23850220441818, 52.33238026499748, 52.327280938625336, 52.008094266057014, 54.28630381822586, 52.80942186713219, 52.6515669375658, 49.1760378330946, 52.03910440206528, 48.63735593855381, 43.529670014977455, 48.23948308825493, 56.46875090897083, 52.054390981793404, 52.239574044942856, 52.16388210654259, 53.52859787642956, 52.55993865430355, 55.75043365359306, 53.75327982008457, 62.438549771904945, 67.37467110157013, 72.92953222990036, 69.95575860142708, 72.93335482478142, 71.00754976272583, 73.00910755991936, 70.3924311697483, 70.23371368646622, 69.21935811638832, 70.99298894405365, 71.60090312361717, 73.7114542722702, 69.79712471365929, 74.84150603413582, 69.05962988734245, 80.91535091400146, 73.80233019590378, 90.07828563451767, 12.214474026113749, 2.03544057905674, 2.9003100330010056, 0.1334253724780865, 0.07323183017433621, 32.65696384012699, 81.90528899431229, 61.41168147325516, 54.11091662943363, 38.579565435647964, 33.332161009311676, 21.013130843639374, 41.773909628391266, 54.83073480427265, 70.13727486133575, 25.070727914571762, 0.5259378533810377, 0.14616199216106907, 0.10718062607338652, 0.033997929785982706, 0.06575521183549426, 0.04408773544128053, 0.04265654817572795, 0.03367851684743073, 0.07295759918633848, 0.01574974481627578, 0.16542161494726315, 0.13159213413018733, 0.14417607919313014, 0.20489872083999217, 0.20632906205719337, 0.17085429921280593, 0.14837029710179195, 0.1865430487669073, 0.3166909486753866, 0.2000430563930422, 0.2524684276431799, 2.6245699916034937, 84.09878969192505, 81.04832857847214, 67.61812403798103, 47.4765258282423, 51.804493591189384, 81.60068973898888, 76.50552794337273, 55.299542248249054, 0.11017716606147587, 0.9897572337649763, 6.234089406207204, 5.673450864851475, 1.2919562053866684, 86.62398219108582, 101.67697325348854, 97.84933984279633, 89.48177844285965, 82.2350125014782, 77.64014706015587, 79.83691558241844, 72.57235899567604, 73.01834866404533, 68.0909326672554, 66.82503059506416, 72.74090275168419, 81.96002885699272, 84.61518198251724, 89.0457746386528, 83.89657974243164, 87.16808259487152, 82.1018448472023, 81.65108263492584, 82.31483861804008, 81.92637786269188, 74.90861803293228, 68.5967843234539, 62.698702812194824, 63.98839920759201, 58.13389375805855, 63.36654357612133, 59.68110993504524, 58.50399389863014, 58.251303657889366, 56.63314528763294, 61.5418016910553, 63.52967642247677, 55.78711308538914, 58.70414815843105, 55.58052957057953, 57.050511091947556, 53.08168865740299, 59.88765545189381, 72.81188294291496, 71.50209322571754, 71.08331769704819, 73.72781619429588, 69.71131011843681, 69.16195079684258, 73.7131717801094, 73.0363216996193, 71.09445869922638, 71.93383365869522, 68.29054355621338, 60.660423785448074, 63.67944158613682, 68.92799735069275, 67.77603596448898, 69.24099415540695, 64.85824093222618, 64.63621124625206, 71.46880701184273, 62.868557497859, 55.50636515021324, 54.895840510725975, 55.81041343510151, 58.32015596330166, 63.85994330048561, 65.53937718272209, 52.47017987072468, 58.44278298318386, 58.51900689303875, 64.90411967039108, 66.59249067306519, 64.81534123420715, 68.00698757171631, 69.6947506070137, 65.10476410388947, 61.29779778420925, 59.39904727041721, 57.27305755019188, 56.9708027690649, 58.77740062773228, 57.638700529932976, 58.885018453001976, 57.3913300037384, 59.907076209783554, 58.720468282699585, 62.782267928123474, 60.54720126092434, 61.17670588195324, 56.8435437977314, 54.92835536599159, 56.159797087311745, 58.02751466631889, 55.961744114756584, 56.99631080031395, 53.213602378964424, 55.518638491630554, 51.49276211857796, 46.03059321641922, 52.03890681266785, 58.87876398861408, 56.422951966524124, 55.39260685443878, 55.483900755643845, 55.68352684378624, 57.10737504065037, 59.43817377090454, 55.83961486816406, 64.20078501105309, 68.89701381325722, 76.01334035396576, 72.8610523045063, 75.34119442105293, 74.69529747962952, 75.20196229219437, 74.66226205229759, 74.01992172002792, 74.54759940505028, 75.75341910123825, 75.11720404028893, 77.40749314427376, 76.05003118515015, 79.56846758723259, 73.65415334701538, 86.91049441695213, 79.58197966217995, 92.24421501159668, 10.235246680676937, 10.175520535558462, 10.436782166361809, 0.19990826753200963, 0.29000539623666555, 44.57594007253647, 89.29554283618927, 69.31816041469574, 63.60693007707596, 55.60238219797611, 54.09864328801632, 29.709135219454765, 51.0973135381937, 64.05459925532341, 80.97976505756378, 33.12184229493141, 0.7636019785422832, 0.44969494454562664, 0.305475820787251, 0.10962129745166749, 0.18908060010289773, 0.17454780492698774, 0.15806742128916085, 0.09233595075784251, 0.2673908503493294, 0.1515429190476425], [0.01810890797059983, 0.009214700367010664, 0.05882783472770825, 0.07599479402415454, 0.11690286453813314, 0.01815349063690519, 0.02259823348140344, 0.05417020867753308, 0.05401220914791338, 0.10304200986865908, 0.090936794586014, 2.4355417722836137, 63.63918274641037, 53.28499294817448, 52.830807119607925, 18.93160443753004, 65.71605250239372, 49.26701255142689, 77.30250477790833, 26.56354621052742, 0.34812734462320805, 2.1651385445147753, 2.5189491966739297, 1.4142798352986574, 15.686120688915253, 111.10745161771774, 83.28092157840729, 92.93811857700348, 74.40908923745155, 76.59478515386581, 66.84630185365677, 71.7149806022644, 63.50101836025715, 67.67645090818405, 60.34657582640648, 61.469571366906166, 57.54698105156422, 64.49482843279839, 66.16137340664864, 74.3655663728714, 71.99184894561768, 73.47396701574326, 69.14571806788445, 74.5651164650917, 65.84893897175789, 62.97054782509804, 55.696677938103676, 55.06242737174034, 55.01633584499359, 59.083892181515694, 54.93608795106411, 57.16926231980324, 50.39634995162487, 50.09795196354389, 49.56242009997368, 51.394609585404396, 59.00926798582077, 58.915690407156944, 51.657927855849266, 55.009237825870514, 49.242921844124794, 53.83209899067879, 49.29279036819935, 55.508253648877144, 65.35938084125519, 66.49988204240799, 64.56634819507599, 68.72324153780937, 65.96952930092812, 67.04897537827492, 65.73097810149193, 65.70276841521263, 65.05358844995499, 66.14030733704567, 63.62253963947296, 62.57250018417835, 51.67841635644436, 59.93290342390537, 62.30575829744339, 65.79052850604057, 64.20912176370621, 61.116049736738205, 62.51190863549709, 51.804417595267296, 45.965837091207504, 53.127062022686005, 53.27947184443474, 58.103928565979004, 60.575410947203636, 61.264279782772064, 51.46204076707363, 49.003941267728806, 44.13681283593178, 44.67585951089859, 57.87780649960041, 65.1153427362442, 63.9159294962883, 60.539582669734955, 54.63983304798603, 52.11168810725212, 48.72939079999924, 51.23816817998886, 48.769015073776245, 53.059224262833595, 54.41322460770607, 53.71116667985916, 55.337076634168625, 52.99304321408272, 53.433504179120064, 56.277001798152924, 53.48727509379387, 55.31800165772438, 52.64994062483311, 49.334770515561104, 47.93642275035381, 48.599912747740746, 51.255312860012054, 49.6192042529583, 47.1815400570631, 48.88431988656521, 45.270637795329094, 42.73164823651314, 43.41042101383209, 50.809893161058426, 48.160150945186615, 49.183584228158, 47.651814222335815, 49.58102010190487, 50.087285935878754, 53.45170520246029, 55.13626500964165, 63.08724336326122, 67.53306180238724, 68.91508564352989, 68.63011613488197, 71.46082744002342, 66.68015956878662, 68.12669634819031, 61.903542280197144, 63.23176860809326, 61.70503333210945, 65.25728031992912, 64.16642725467682, 69.53165575861931, 64.08937498927116, 69.93573367595673, 63.205504417419434, 75.28747290372849, 69.82755348086357, 85.37647113204002, 46.64184361696243, 0.17070849688025191, 1.8129443493671715, 0.39997170330025256, 0.21627979294862598, 7.27420711889863, 66.19480401277542, 62.98330754041672, 49.55440253019333, 39.07622158527374, 50.21083250641823, 22.073194161057472, 45.49338944256306, 50.24333216249943, 55.97902178764343, 24.580710008740425, 0.1633437498821877, 0.0603958925785264, 0.06302386347670108, 0.06708822038490325, 0.0353559895302169, 0.13240640371805057, 0.008314799924846739, 0.040263114497065544, 0.03729547002876643, 0.05284670332912356, 0.03156221595418174, 0.07800602907082066, 0.015334721920226002, 0.024639224939164706, 0.10838317248271778, 0.017757000096025877, 0.023174492598627694, 0.04001054308901075, 0.011175538020324893, 0.05197536629566457, 0.007578220674986369, 3.2149217510595918, 73.6980789899826, 60.05124047398567, 67.72791534662247, 28.76647610217333, 50.096352249383926, 53.989684134721756, 88.1928800046444, 26.872146651148796, 0.33969250973314047, 1.9820795673877, 1.0926934727467597, 1.2016496574506164, 19.448956176638603, 116.35545641183853, 85.54828271269798, 95.40913358330727, 79.16575759649277, 79.98535081744194, 71.51281625032425, 74.92305725812912, 67.74309173226357, 70.52982419729233, 62.82629236578941, 66.20168924331665, 59.171059504151344, 66.55208364129066, 68.5233798623085, 77.55531281232834, 73.97388339042664, 77.3130302131176, 71.96392804384232, 77.36798286437988, 66.72525554895401, 65.17037138342857, 58.05119879543781, 55.81982932984829, 57.221019342541695, 58.62391546368599, 58.18585976958275, 59.18428659439087, 53.66650007665157, 53.358610197901726, 54.03865970671177, 53.58397610485554, 61.707309409976006, 58.81881080567837, 52.65717163681984, 56.76366068422794, 50.917074009776115, 55.73524586856365, 50.39006128907204, 58.056491911411285, 67.19465956091881, 68.85893225669861, 66.89454406499863, 69.66324269771576, 68.64621967077255, 69.1001509130001, 68.3149154484272, 67.36376568675041, 67.14913040399551, 69.40247029066086, 67.93685093522072, 65.44071167707443, 55.24036802351475, 61.34198181331158, 65.92970743775368, 69.29005712270737, 66.18244707584381, 66.00387185811996, 64.93880420923233, 55.166404992341995, 50.403067991137505, 55.09415186941624, 56.899191811680794, 60.77704332768917, 62.5519622862339, 63.14566142857075, 53.060793578624725, 49.59255248308182, 47.670782804489136, 47.28754296898842, 59.159671515226364, 66.38445943593979, 65.70202365517616, 63.496538400650024, 57.28445693850517, 53.98438721895218, 48.8561026006937, 52.183139473199844, 51.16744637489319, 56.24941147863865, 56.85650110244751, 56.37717202305794, 58.04932549595833, 57.99099862575531, 57.0391421020031, 57.561454474925995, 56.38525038957596, 57.1128885447979, 55.63332013785839, 52.4775742739439, 51.308787390589714, 50.54773762822151, 54.428081810474396, 52.67816551029682, 49.33130890130997, 51.445013880729675, 49.443608075380325, 46.89603477716446, 47.73183032870293, 53.52133646607399, 50.213686153292656, 50.95636390149593, 50.4918160289526, 51.911974623799324, 52.061321809887886, 54.62363451719284, 59.41161699593067, 65.43603032827377, 71.08812063932419, 70.11405810713768, 72.30154752731323, 72.42204666137695, 70.12332960963249, 69.93011757731438, 64.04499337077141, 66.20122566819191, 66.55616462230682, 68.64494293928146, 66.55209884047508, 71.02394208312035, 67.4420490860939, 72.23873689770699, 65.7209238409996, 76.25651970505714, 73.25890615582466, 85.35155206918716, 57.17416025698185, 0.484001730219461, 0.7497537997551262, 0.505463780136779, 0.36958333861548454, 6.268671825528145, 72.04367056488991, 70.38577392697334, 58.45419377088547, 43.66326704621315, 34.44376856088638, 25.621489360928535, 57.39400885999203, 54.92367781698704, 65.9696888923645, 34.716384932398796, 0.054880503375898115, 0.05851232919667382, 0.02130377022695029, 0.04772786960529629, 0.11770000535761937, 0.09662249183747917, 0.1303484133677557, 0.020594974666892085, 0.05378853697038721, 0.025352098600706086, 0.13778802822344005, 0.17063278297428042, 0.15563295426545665, 0.1612328295595944, 0.36308821057900786, 0.1302805810701102, 0.10973480151733384, 0.16473809693707153, 0.19924238295061514, 0.26149603072553873, 0.14686501381220296, 4.319414421916008, 87.9432561993599, 68.90313148498535, 69.70774590969086, 27.393284887075424, 89.98069167137146, 68.28590780496597, 92.44590818881989, 33.900652304291725, 0.5628002691082656, 4.879955593496561, 7.5130893755704165, 4.571098666638136, 18.688048906624317, 119.87231969833374, 89.94940415024757, 99.39366817474365, 83.88679906725883, 84.84150543808937, 75.14444097876549, 79.30283144116402, 71.41494870185852, 75.29012516140938, 67.99933478236198, 70.40419533848763, 65.83269104361534, 72.3147252202034, 72.031230032444, 82.89331957697868, 78.22813510894775, 79.89634439349174, 75.76262980699539, 82.089753895998, 70.96829786896706, 68.52152556180954, 62.350139915943146, 57.514188811182976, 60.998750030994415, 62.99080453813076, 60.88832415640354, 61.89091935753822, 57.33529441058636, 57.02658757567406, 57.969959154725075, 57.744141072034836, 65.247233659029, 60.4437480121851, 53.5014483332634, 57.9973328858614, 51.00532427430153, 56.106280758976936, 53.38526576757431, 61.06172785162926, 70.49436450004578, 73.83705273270607, 69.68519791960716, 73.87333318591118, 71.13973706960678, 74.89678546786308, 72.87188172340393, 71.34137704968452, 71.33646011352539, 73.69793459773064, 68.7737788259983, 67.78214603662491, 57.56203964352608, 66.20512425899506, 69.20086830854416, 72.89579764008522, 69.83885407447815, 68.6919692158699, 68.49080041050911, 60.95595292747021, 53.82257290184498, 58.18269453942776, 57.92534574866295, 60.98438300192356, 62.90712542831898, 65.61946168541908, 52.96226866543293, 54.326182678341866, 51.78962118923664, 50.97405955195427, 63.028350323438644, 69.56059500575066, 68.84961515665054, 67.05442428588867, 60.758154541254044, 59.10829447209835, 54.075529128313065, 56.52358576655388, 54.029676988720894, 59.82967436313629, 58.37450444698334, 59.32830646634102, 61.66401833295822, 61.83354243636131, 60.63176192343235, 61.69048011302948, 59.934525936841965, 60.7074348628521, 60.958145409822464, 54.74582076072693, 55.6205490231514, 52.548322677612305, 58.26896511018276, 55.356645584106445, 53.7057975679636, 54.719602167606354, 52.44588017463684, 49.81093816459179, 51.388142332434654, 56.16660252213478, 53.48652273416519, 52.82461725175381, 53.66758681833744, 56.95123001933098, 55.52824057638645, 58.75443086028099, 63.24233964085579, 69.02508974075317, 73.14216122031212, 72.0635586977005, 78.0759608745575, 75.35054951906204, 73.54647472500801, 74.13048058748245, 69.70955461263657, 69.24903452396393, 70.47745540738106, 70.39707452058792, 70.46803191304207, 74.26041841506958, 70.61664193868637, 77.86939635872841, 70.82167893648148, 81.67478576302528, 75.54927885532379, 90.52020192146301, 56.1267464607954, 0.4303718829760328, 10.294461753219366, 0.6132930878084153, 0.33315288252197206, 10.032538957893848, 83.08579444885254, 75.56187137961388, 69.84585329890251, 53.71810890734196, 64.27067086100578, 34.26671706140041, 62.95740433037281, 65.05212172865868, 75.9223884344101, 46.7980570346117, 0.3082849091151729, 0.2174048442975618, 0.10847603742149659, 0.2398162940517068, 0.2229930233443156, 0.21643055282766, 0.1870924755348824, 0.11222574597923085, 0.07818744707037695, 0.14895249711116776], [0.06018463653163053, 0.01393639880916453, 0.029876676126150414, 0.09018184486194514, 0.035981545806862414, 0.08418206329224631, 0.027476407267386094, 0.049621912112343125, 0.014464968444372062, 0.063940631080186, 0.043673594773281366, 2.036047358997166, 60.43405093252659, 60.31227506697178, 54.38096433877945, 40.9941952675581, 52.312153950333595, 42.12331607937813, 86.23138725757599, 7.529866425320506, 0.25732427020557225, 1.3503660773858428, 0.3485113912029192, 0.21220534283202142, 56.353742480278015, 98.38362157344818, 82.38382011651993, 87.17384308576584, 71.02986976504326, 73.36553603410721, 68.03271979093552, 67.81933844089508, 65.7224589586258, 67.68699154257774, 62.19158962368965, 59.28745485842228, 58.12621057033539, 60.02741955220699, 58.67805115878582, 60.06895512342453, 62.117615193128586, 66.11543387174606, 62.64710158109665, 59.78623889386654, 57.43689715862274, 57.157752737402916, 55.055048167705536, 56.43374718725681, 55.662658363580704, 54.96847741305828, 55.064171478152275, 54.1120907664299, 50.64509220421314, 52.46046379208565, 49.089109897613525, 51.47596322000027, 57.35085837543011, 54.06107850372791, 52.851952984929085, 52.536490112543106, 50.03365561366081, 54.26882475614548, 50.75144849717617, 52.33612686395645, 64.79610666632652, 65.17772778868675, 63.54377746582031, 66.66809901595116, 66.03704407811165, 64.28019315004349, 65.94682171940804, 65.23348599672318, 66.29020929336548, 61.41304939985275, 71.28723755478859, 70.99115744233131, 57.34891667962074, 53.4511162340641, 58.8705488294363, 65.42007118463516, 63.93294498324394, 58.29470492899418, 57.263964638113976, 49.51760530471802, 50.033811405301094, 54.47125509381294, 56.40258505940437, 60.40469370782375, 57.89267510175705, 60.03045938909054, 52.943965047597885, 44.44581225514412, 45.62757924199104, 46.728600561618805, 59.14050154387951, 63.603753447532654, 57.07129217684269, 53.511548191308975, 48.83605107665062, 51.92956008017063, 48.33536334335804, 47.728862687945366, 45.99580228328705, 47.16062977910042, 53.311849907040596, 55.93356482684612, 53.79719406366348, 54.78310815989971, 55.55266946554184, 53.56943428516388, 53.68715196847916, 52.23252922296524, 51.35545648634434, 51.484767347574234, 47.678971365094185, 49.210961759090424, 51.08560636639595, 50.51988132297993, 47.43410110473633, 45.576395988464355, 45.57650238275528, 46.048665046691895, 40.7614653557539, 47.880067974328995, 49.916006326675415, 49.086932614445686, 48.78889560699463, 48.84683109819889, 48.32920007407665, 51.31821848452091, 53.23478244245052, 64.65263396501541, 68.00038352608681, 67.92926654219627, 68.61162632703781, 67.10329726338387, 65.04807874560356, 57.74774707853794, 58.795354664325714, 60.87496407330036, 61.558478996157646, 64.15338635444641, 66.79445743560791, 67.27763190865517, 67.57197931408882, 63.47731523215771, 63.342057690024376, 65.92928946018219, 75.07942646741867, 73.34525272250175, 84.47429314255714, 13.215895090252161, 2.559269070625305, 0.7090958626940846, 0.2570860704872757, 0.47483219881542027, 49.60677891969681, 63.260362073779106, 56.750129610300064, 38.94115023314953, 55.13060711324215, 21.957731656730175, 20.132577493786812, 47.20210835337639, 49.55915987491608, 26.9960618019104, 0.14506356907077134, 0.0347301883448381, 0.1111751988355536, 0.035230299399700016, 0.06456923016230576, 0.011395659021218307, 0.060662056421278976, 0.035950954479631037, 0.07791383206495084, 0.0038557282960027806, 0.10234833927825093, 0.009395040397066623, 0.02856672424968565, 0.16471249284222722, 0.09190575743559748, 0.03391781865502708, 0.05927623664319981, 0.0544601546425838, 0.004391330476209987, 0.05860653742274735, 0.10863169547519647, 3.5283070849254727, 73.84017616510391, 67.67369985580444, 61.24389387667179, 37.018521800637245, 47.816550582647324, 51.60311959683895, 90.1772703230381, 7.514725662767887, 0.2975432120729238, 3.1562707107514143, 1.7640938144177198, 0.36080601741559803, 63.450412675738335, 101.86611950397491, 85.77685564756393, 90.19276589155197, 73.31895053386688, 76.07637897133827, 71.06682658195496, 71.40627756714821, 69.30693581700325, 71.09584182500839, 65.42840793728828, 62.20067873597145, 61.84616535902023, 61.297379806637764, 60.818225517868996, 63.883760422468185, 63.40035796165466, 68.24371486902237, 65.27831599116325, 61.75954520702362, 59.77740436792374, 58.167077377438545, 59.69672329723835, 60.08924603462219, 57.36101143062115, 58.70672821998596, 58.664455488324165, 58.016050681471825, 52.856429144740105, 54.317196160554886, 52.517829313874245, 53.6088951677084, 60.71444548666477, 57.25361779332161, 53.40817853808403, 52.88339629769325, 51.41456991434097, 57.227133214473724, 51.27229034900665, 54.152714386582375, 65.95755234360695, 67.36257255077362, 64.61080580949783, 69.41667392849922, 68.22948843240738, 67.61688530445099, 66.68419495224953, 66.76749408245087, 68.81446704268456, 64.33614134788513, 68.46153438091278, 71.82820692658424, 62.04657420516014, 55.783628672361374, 60.63014321029186, 66.66772663593292, 67.90780529379845, 62.65019081532955, 60.31762897968292, 53.08997221291065, 53.49302418529987, 57.673582658171654, 58.29481512308121, 61.96656949818134, 57.992066368460655, 60.19158594310284, 54.6042175590992, 45.22570140659809, 47.77815364301205, 49.32575739920139, 61.12810268998146, 64.78194862604141, 57.49751150608063, 55.245357155799866, 52.193121537566185, 54.192391857504845, 51.2590404599905, 50.49643278121948, 48.86375918984413, 50.21525926887989, 54.9829888343811, 60.07182016968727, 56.7467325925827, 58.78294453024864, 58.53810466825962, 56.51344411075115, 56.195632964372635, 56.739573776721954, 56.05690240859985, 55.42694941163063, 51.24673672020435, 49.94611971080303, 54.099445044994354, 53.0863244086504, 49.74756136536598, 47.53088191151619, 50.120610147714615, 49.381925985217094, 43.66198271512985, 49.77613963186741, 53.21331739425659, 51.21988356113434, 51.940514892339706, 51.25172205269337, 51.84126801788807, 53.53771738708019, 58.15928019583225, 66.47329106926918, 69.17835831642151, 69.29697275161743, 69.4021587073803, 69.10638257861137, 67.67980992794037, 59.23300378024578, 60.83719789981842, 64.02673155069351, 65.21418303251266, 66.50967791676521, 70.81058353185654, 69.43657726049423, 71.28050431609154, 64.37182143330574, 66.58593982458115, 67.44288504123688, 77.74877563118935, 74.02303755283356, 90.51553577184677, 18.93944911658764, 1.9867356237955391, 1.1049505462870002, 0.31189373577944934, 0.4612159263342619, 51.881249472498894, 71.27715289592743, 65.03146603703499, 49.23819109797478, 43.78775596618652, 20.236228331923485, 25.848916657269, 56.42901264131069, 57.50145949423313, 39.15330424904823, 0.13167583354515955, 0.022693243226967752, 0.053846940281800926, 0.07862382248276845, 0.02591988795757061, 0.014212121513992315, 0.012988293092348613, 0.03315422662126366, 0.03447418079304043, 0.028041257719451096, 0.1863325311569497, 0.12638552288990468, 0.11369334300979972, 0.311232868116349, 0.19680567464092746, 0.21365351043641567, 0.12033318242174573, 0.18152558128349483, 0.09935355075867847, 0.31170125235803425, 0.24010019522393122, 5.2205507922917604, 85.71935713291168, 76.38880580663681, 72.8701414167881, 54.01949353516102, 71.8690775334835, 57.208962589502335, 103.80955561995506, 9.527635350823402, 0.45575805357657373, 4.410558706149459, 4.999623522162437, 0.927532782079652, 64.48479697108269, 104.30127963423729, 91.28926545381546, 93.07847544550896, 77.72611364722252, 79.4073486328125, 76.42950922250748, 75.82044750452042, 73.55380073189735, 73.86444166302681, 70.94488352537155, 67.7209997177124, 66.05650663375854, 65.96109375357628, 65.30188232660294, 67.4561159312725, 67.73818999528885, 72.9530681669712, 68.83788138628006, 66.92241936922073, 63.85666027665138, 63.10728348791599, 62.41599038243294, 63.073697090148926, 60.40435552597046, 60.97429074347019, 61.59026049077511, 60.40326498448849, 58.26144531369209, 59.453673139214516, 57.2895410656929, 57.10330545902252, 62.05235369503498, 55.51578104496002, 54.26346704363823, 52.233467772603035, 51.33127838373184, 58.34286354482174, 54.64427500963211, 54.606668427586555, 70.61386048793793, 71.22052073478699, 67.50616684556007, 71.20164334774017, 73.48006948828697, 69.36493590474129, 71.90706789493561, 69.66698929667473, 72.89584323763847, 68.1685397028923, 73.01544561982155, 74.81760531663895, 63.97945448756218, 59.378699362277985, 63.570516631007195, 69.02383580803871, 70.6297816336155, 64.87434446811676, 64.02763590216637, 57.11217038333416, 56.43905930221081, 58.61112155020237, 58.960641995072365, 64.09916326403618, 61.66538245975971, 62.36386477947235, 55.67892909049988, 46.65151409804821, 50.324476808309555, 49.508265405893326, 63.44525635242462, 68.51769536733627, 64.6912094950676, 57.12035894393921, 56.221049800515175, 58.323951959609985, 54.88648161292076, 54.07822698354721, 52.781310975551605, 53.64520221948624, 57.04753205180168, 60.96919521689415, 59.751197174191475, 61.476619988679886, 62.04931005835533, 58.7654996663332, 60.765966922044754, 58.64645205438137, 58.64474594593048, 58.407243490219116, 55.7186483591795, 54.16025698184967, 57.361866384744644, 55.31550519168377, 52.34922856092453, 50.08047290146351, 52.43782080709934, 53.025318682193756, 47.04687148332596, 52.89224982261658, 54.44244123995304, 54.266377687454224, 55.218678787350655, 55.08355803787708, 52.4990963190794, 56.659405678510666, 60.12425735592842, 68.87704208493233, 73.1694969534874, 72.41767689585686, 75.2065372467041, 72.59723246097565, 72.43464678525925, 62.39463932812214, 63.81133630871773, 67.78577104210854, 67.89080500602722, 70.70256292819977, 73.11335116624832, 73.6552856862545, 75.93840837478638, 69.75697606801987, 71.86935111880302, 72.9255348443985, 82.32932344079018, 80.80924540758133, 92.17124372720718, 18.419783301651478, 4.473199769854546, 3.1570014590397477, 0.36520805151667446, 1.0751013667322695, 64.92897793650627, 77.08375051617622, 76.2129208445549, 58.24159897863865, 76.10670894384384, 33.77136804163456, 31.425273232162, 63.98908317089081, 65.57690396904945, 54.597594514489174, 0.5930595891550183, 0.14681147527880967, 0.13099737698212266, 0.14372345816809684, 0.15603071573423222, 0.10541333496803418, 0.17154664878034964, 0.08577293847338296, 0.15397691109683365, 0.10393042743089609], [0.10036831896286458, 0.045069103289279155, 0.021377550838224124, 0.025818905778578483, 0.017213323117175605, 0.021918359416304156, 0.02815782314428361, 0.04753615059598815, 0.04043795706820674, 0.1641340332571417, 0.20118027896387503, 3.570968583226204, 54.99260611832142, 51.320167779922485, 38.396605253219604, 50.37104710936546, 45.41379891335964, 55.95355935394764, 77.56472110748291, 1.6781660565175116, 0.08409535817918368, 0.8307975728530437, 1.960001327097416, 2.958328169770539, 89.6758796274662, 85.4247285425663, 87.92434081435204, 76.36045172810555, 72.77327701449394, 67.04160377383232, 68.96927073597908, 68.20855155587196, 69.99510169029236, 68.27876418828964, 65.66675394773483, 58.568772822618484, 58.340021297335625, 59.884585216641426, 58.08259651064873, 57.29628950357437, 58.46462041139603, 56.17609441280365, 56.920451670885086, 54.59498405456543, 57.86286570131779, 59.44193936884403, 55.57983040809631, 55.18382705748081, 54.03163008391857, 55.56870460510254, 55.155051201581955, 51.639840826392174, 49.85877379775047, 50.292577520012856, 49.46804076433182, 51.760461553931236, 57.49599538743496, 54.17270131409168, 53.65207985043526, 50.62568284571171, 51.08379006385803, 51.48464195430279, 49.898401871323586, 52.640042155981064, 63.35362046957016, 65.47680974006653, 63.62548828125, 67.43860647082329, 65.0031803548336, 65.11407360434532, 61.28205142915249, 63.84383976459503, 64.19098913669586, 66.98522999882698, 57.12719477713108, 54.73612368106842, 63.99051949381828, 51.684526428580284, 54.85138289630413, 62.55663603544235, 62.62547314167023, 56.926512345671654, 52.01286680996418, 45.82225799560547, 53.813677579164505, 48.00756253302097, 49.6480181068182, 47.6770980656147, 46.18054457008839, 47.90269576013088, 49.94320146739483, 44.655557200312614, 46.07712171971798, 48.38876947760582, 61.56629137694836, 59.8734138160944, 58.07071074843407, 49.70724552869797, 52.425653859972954, 52.87201210856438, 52.431323155760765, 51.145190969109535, 49.702028408646584, 47.058787643909454, 47.829097509384155, 49.9075897783041, 56.77599482238293, 55.90456858277321, 55.26770755648613, 54.66988183557987, 54.49743188917637, 53.21370117366314, 51.856759786605835, 50.26370666921139, 50.58052606880665, 49.169802367687225, 50.65665118396282, 50.362147986888885, 49.594805762171745, 48.098522052168846, 45.65239571034908, 46.55604802072048, 44.05197098851204, 43.95769044756889, 51.04305624961853, 50.39696551859379, 50.598282516002655, 48.585351929068565, 50.67674830555916, 51.5830946713686, 54.22510050237179, 62.51631259918213, 67.52374470233917, 64.61276650428772, 66.85024604201317, 60.50868272781372, 55.58658264577389, 55.4837791621685, 60.697589591145515, 63.20816047489643, 68.66296917200089, 66.46682381629944, 70.8461420238018, 66.78917571902275, 66.59141913056374, 60.093106627464294, 61.2155169993639, 62.141360118985176, 73.08619782328606, 71.7018561065197, 84.13629367947578, 49.55839231610298, 0.13575191638665274, 2.236173595301807, 0.15750319609651342, 0.32725479744840413, 22.328910939395428, 64.61897537112236, 56.78537271916866, 44.999792128801346, 35.65455459058285, 36.79366506636143, 33.19629929959774, 44.14641872048378, 57.66471393406391, 37.396669909358025, 0.3935908363200724, 0.06647840506047942, 0.02847228039172478, 0.024151737816282548, 0.057170466825482436, 0.05042409953603055, 0.06639259794610552, 0.0030661706023238366, 0.02786537243082421, 0.0803904233907815, 0.09338434567325749, 0.03777979931328446, 0.05710512072255369, 0.12703711370704696, 0.06874134691315703, 0.018140434403903782, 0.01661861049797153, 0.07109868252882734, 0.024368337326450273, 0.15194584586424753, 0.3072206990327686, 7.041433984413743, 68.4405443072319, 58.251953423023224, 46.61853946745396, 33.92857700586319, 45.20551308989525, 69.88173097372055, 80.26918798685074, 1.9719437300227582, 0.32574618933722377, 1.664075581356883, 1.0605455352924764, 3.987523131072521, 97.61845663189888, 88.29028397798538, 92.80133351683617, 79.33861032128334, 75.37745207548141, 69.77853611111641, 74.91199225187302, 71.51759639382362, 73.7507213652134, 70.74568301439285, 68.83424878120422, 59.817465618252754, 61.93089321255684, 61.62750989198685, 60.73302648961544, 58.906593695282936, 62.103996723890305, 58.687394857406616, 58.82478028535843, 56.87589146196842, 59.71835933625698, 60.328864976763725, 57.667255997657776, 57.76473976671696, 57.73961931467056, 57.50000797212124, 57.94216364622116, 54.60788816213608, 52.4657417088747, 54.77086141705513, 52.33758598566055, 56.2973915040493, 58.26724760234356, 54.35639105737209, 55.981225669384, 50.04014566540718, 49.531915336847305, 52.92525105178356, 52.88408786058426, 54.96381126344204, 65.4748946428299, 69.14940387010574, 66.2264259159565, 69.34209153056145, 70.48020645976067, 67.77212217450142, 64.62216719985008, 66.23853966593742, 68.42814937233925, 69.58549126982689, 57.5230423361063, 57.71146282553673, 67.80530959367752, 54.156221598386765, 59.08490672707558, 63.907334357500076, 65.77878713607788, 59.33399856090546, 54.31346096098423, 50.90583421289921, 54.99438062310219, 49.711831882596016, 47.468056082725525, 49.35487903654575, 46.0099983215332, 49.03117820620537, 50.73230132460594, 46.26148782670498, 47.63687342405319, 50.105072781443596, 63.30512747168541, 62.600964456796646, 58.75755809247494, 53.43715578317642, 53.56292903423309, 55.44914402067661, 55.2266051620245, 55.57270959019661, 52.90611147880554, 50.38672126829624, 48.54539327323437, 53.46280060708523, 58.93693886697292, 58.9518378674984, 59.01568964123726, 55.5608656257391, 56.96579463779926, 55.21179735660553, 55.30762441456318, 51.48350201547146, 54.316371604800224, 50.83812564611435, 52.60164901614189, 53.46900187432766, 52.4831485748291, 51.479075253009796, 48.93446959555149, 50.43619841337204, 46.992914378643036, 46.81508392095566, 52.40326166152954, 54.121844843029976, 52.500551640987396, 50.33573180437088, 52.539894729852676, 55.413995906710625, 58.33283968269825, 65.20741939544678, 69.61117789149284, 66.32496982812881, 69.23384293913841, 62.443067729473114, 57.76826597750187, 58.74730624258518, 63.402641639113426, 66.19382366538048, 69.64875787496567, 69.14829432964325, 72.37777903676033, 69.36286121606827, 69.61228743195534, 63.22071120142937, 63.47219690680504, 65.31905740499496, 75.26676401495934, 74.93046686053276, 84.45814400911331, 59.08510431647301, 0.3507577831624076, 1.0506224865093827, 0.9619220055174083, 0.5811384413391352, 22.946106120944023, 74.50373455882072, 63.372558653354645, 55.30456177890301, 39.65632885694504, 25.438265092670918, 35.4162085801363, 53.913080245256424, 62.688937336206436, 48.050861209630966, 0.38489488419145346, 0.05078879832581151, 0.0143595899680804, 0.02090576570481062, 0.031585749457008205, 0.03829738052445464, 0.09731516052852385, 0.02571164874098031, 0.07130495505407453, 0.014724568918609293, 0.17757897352566943, 0.09970840124879032, 0.14702629734529182, 0.24725644325371832, 0.18440570798702538, 0.1288540248060599, 0.14650563622126356, 0.16882599476957694, 0.16172398289199919, 0.34456067194696516, 0.5475131550338119, 9.455827753990889, 81.87013328075409, 66.11687019467354, 54.57364819943905, 67.8371898829937, 68.67989346385002, 71.65704131126404, 92.30955630540848, 2.6373237697407603, 0.4136569064576179, 3.907427228987217, 5.005885111168027, 3.7949976744130254, 99.852394759655, 92.12750807404518, 96.26425489783287, 84.52068105340004, 81.3407988846302, 75.21988973021507, 79.28637832403183, 75.8992400765419, 79.20440152287483, 72.86892548203468, 73.40929448604584, 63.97477313876152, 63.75278905034065, 66.31376802921295, 63.88568311929703, 62.43050180375576, 65.37560597062111, 62.54649817943573, 61.79042994976044, 58.36104936897755, 62.734572887420654, 65.87292328476906, 60.98216772079468, 62.16826647520065, 59.112706035375595, 60.3829512745142, 60.502812042832375, 57.64863699674606, 57.718055471777916, 58.81976455450058, 56.968222707509995, 57.782446816563606, 59.643313363194466, 56.385580971837044, 56.52265481650829, 50.00063918530941, 50.77063366770744, 54.71624694764614, 53.46581384539604, 57.57653586566448, 68.9578029513359, 72.78551235795021, 68.32848832011223, 71.73492953181267, 74.12819311022758, 71.24676212668419, 67.01625913381577, 68.85055750608444, 71.98358058929443, 74.87603098154068, 62.9021704941988, 61.48900732398033, 70.47585189342499, 56.15356542170048, 62.26767294108868, 69.55822393298149, 69.35856744647026, 62.495121136307716, 59.42104049026966, 54.370868280529976, 59.6916201710701, 52.21126176416874, 50.06162591278553, 49.54467125236988, 45.89404374361038, 49.364629313349724, 51.100763753056526, 47.66585826873779, 50.447145625948906, 54.97020252048969, 67.44626685976982, 66.05800375342369, 61.84607796370983, 55.84149196743965, 58.105258494615555, 59.16402608156204, 58.410621508955956, 57.0054417103529, 55.70760615170002, 53.19080740213394, 51.748051419854164, 56.20242699980736, 62.18941234052181, 61.620879247784615, 59.06137838959694, 59.91459220647812, 60.73568254709244, 57.913269996643066, 57.55292773246765, 55.05019582808018, 57.55585357546806, 54.00382697582245, 57.05819047987461, 56.65388837456703, 56.008531004190445, 55.39157330989838, 50.75203746557236, 53.56221467256546, 52.065813168883324, 50.98887495696545, 56.62636265158653, 57.31219545006752, 54.629478603601456, 54.358826726675034, 55.50646394491196, 56.56353302299976, 61.05563297867775, 68.88376772403717, 72.34032064676285, 69.38639715313911, 73.36354494094849, 67.454314827919, 60.944743528962135, 61.59107364714146, 66.83358773589134, 69.04302477836609, 73.35567936301231, 72.01088592410088, 75.47548681497574, 72.23510429263115, 71.61779701709747, 66.22884258627892, 66.61108687520027, 69.19526740908623, 80.41852757334709, 80.06925791501999, 89.34654369950294, 61.08428344130516, 0.3720220358809456, 5.9196957014501095, 1.08916298719123, 0.6204131932463497, 30.124825313687325, 84.8510505259037, 71.3807125389576, 64.03068333864212, 51.41756035387516, 57.40392632782459, 48.56932058930397, 62.748799324035645, 73.64151522517204, 60.26606194674969, 0.7041563652455807, 0.15250894299242646, 0.1254372511175461, 0.1985300102387555, 0.22944969328818843, 0.12420898929121904, 0.1982104266062379, 0.12501410819822922, 0.11199484157259576, 0.16457363701192662], [0.016080343775684014, 0.04261515488906298, 0.038281539382296614, 0.03182932974596042, 0.10687230082112364, 0.06829285965068266, 0.05025852638937067, 0.12845623365137726, 0.10122362189576961, 0.12105997506296262, 0.22730092343408614, 7.432956900447607, 53.375853672623634, 57.05254778265953, 44.485254138708115, 54.758439883589745, 38.801492527127266, 72.36194908618927, 50.90448908507824, 0.22904069570358843, 0.6569060194306076, 9.925032276660204, 3.545957850292325, 14.995369054377079, 116.24810457229614, 75.80503553152084, 93.73294472694397, 69.61205184459686, 74.96390506625175, 62.18610271811485, 72.11728781461716, 62.91681110858917, 71.91663578152657, 66.3848926126957, 71.74142718315125, 61.93384565412998, 61.72677956521511, 55.37085302174091, 58.70885990560055, 55.718868747353554, 58.79729636013508, 55.89416094124317, 58.94155561923981, 55.29756635427475, 58.97541180253029, 55.43606512248516, 54.395950734615326, 55.09372629225254, 56.75280846655369, 54.41284462809563, 53.4127838909626, 48.477475717663765, 50.559847578406334, 49.761696606874466, 47.98138193786144, 53.960433304309845, 57.29770302772522, 52.64845110476017, 52.811169773340225, 50.55825926363468, 49.9286824464798, 48.00974361598492, 52.91393905878067, 49.95105564594269, 59.66295450925827, 65.6240214407444, 61.69783651828766, 64.57823395729065, 67.25077494978905, 64.30695131421089, 62.76098147034645, 63.41649569571018, 65.77507093548775, 66.23141884803772, 56.63471460342407, 62.40804880857468, 65.68440780043602, 55.655944123864174, 50.804155468940735, 55.44917441904545, 59.671800434589386, 56.28993630409241, 49.15644608438015, 44.055911377072334, 47.18554124236107, 47.70395502448082, 50.957986414432526, 53.450356274843216, 52.867706939578056, 52.06055425107479, 48.32525208592415, 46.542904525995255, 44.40315954387188, 44.421299770474434, 58.39578330516815, 61.21304713189602, 58.11510756611824, 56.39356814324856, 54.212766364216805, 55.96090815961361, 56.53595790266991, 55.831779688596725, 55.22598199546337, 54.769588485360146, 55.29858849942684, 47.952100709080696, 51.713784858584404, 57.05533303320408, 55.71777820587158, 54.56319876015186, 52.01399154961109, 51.8267147988081, 50.36939799785614, 49.48410630226135, 52.14280463755131, 49.74492810666561, 50.83100102841854, 52.564612403512, 52.305413112044334, 46.79593674838543, 46.6950673609972, 47.525809183716774, 45.860833525657654, 41.74257650971413, 48.35185445845127, 50.26236914098263, 48.74349944293499, 48.01584988832474, 52.26356215775013, 50.66689923405647, 54.12420831620693, 59.39640261232853, 61.82313099503517, 60.938192680478096, 56.9185783714056, 52.8559085726738, 54.95864354074001, 55.81579014658928, 62.72017925977707, 66.40097334980965, 66.14520147442818, 68.8588334619999, 70.42943358421326, 67.75225684046745, 65.94630494713783, 61.837634816765785, 60.11834867298603, 64.0231141448021, 68.26699241995811, 73.62902149558067, 71.51957228779793, 78.21518540382385, 8.272395506501198, 1.8836272065527737, 1.760708789806813, 0.3669301012996584, 4.301256621256471, 63.35018925368786, 62.77584247291088, 53.672271966934204, 35.07267661392689, 33.61597917973995, 23.67844272404909, 33.63443858921528, 50.513790249824524, 41.55431941151619, 0.3928025270579383, 0.017244057307834737, 0.04596822262101341, 0.013255676840344677, 0.08923533197958022, 0.07668415273656137, 0.06783957069274038, 0.059132349051651545, 0.06352372220135294, 0.014184400442900369, 0.025095423115999438, 0.026578302822599653, 0.038402093850891106, 0.05211103460169397, 0.0646272957965266, 0.07517783786170185, 0.09967517529730685, 0.03793798437982332, 0.1251968546421267, 0.19523607683368027, 0.5407169822137803, 11.646786388009787, 66.11493989825249, 65.02073541283607, 56.324613243341446, 51.37404128909111, 43.162043541669846, 85.8153247833252, 52.65901833772659, 0.24673757812706754, 0.60472680372186, 14.651878885924816, 7.45331478305161, 17.748309932649136, 121.37933403253555, 76.9043393433094, 98.72144624590874, 72.01006516814232, 78.23679864406586, 65.62678009271622, 74.19821575284004, 67.6354207098484, 74.8634384572506, 70.26383087038994, 74.42446321249008, 65.3882060945034, 64.66182187199593, 59.26602020859718, 63.64936999976635, 57.413068637251854, 61.393757835030556, 57.63607867062092, 61.565466821193695, 58.519481867551804, 61.68590135872364, 56.224146634340286, 57.80760906636715, 58.351340889930725, 58.04244786500931, 56.37052237987518, 58.95621903240681, 51.84204317629337, 53.4259881824255, 53.85117016732693, 52.1875624358654, 58.09572480618954, 59.094106033444405, 52.29244440793991, 53.2561144977808, 51.54517650604248, 51.21724270284176, 48.5596539080143, 56.528514102101326, 51.63930505514145, 62.36324541270733, 66.27852112054825, 64.95838075876236, 66.92301213741302, 68.39454397559166, 67.33945459127426, 66.56280666589737, 66.16398006677628, 67.30555281043053, 67.69359558820724, 59.84181471168995, 61.73630565404892, 69.02944430708885, 57.32839398086071, 53.91241908073425, 59.84653405845165, 63.671754598617554, 61.49538338184357, 54.81402710080147, 45.83074674010277, 48.97633954882622, 49.780304208397865, 51.01993829011917, 55.73041632771492, 55.14352262020111, 52.49020479619503, 48.164163529872894, 48.26637044548988, 47.86271050572395, 46.18061676621437, 62.67648920416832, 64.76569309830666, 60.93672215938568, 60.60111656785011, 58.17246928811073, 57.621479853987694, 55.52680805325508, 58.32863710820675, 57.339306995272636, 57.84849867224693, 57.311823070049286, 51.546776220202446, 55.11269487440586, 58.89110192656517, 59.32818867266178, 56.62483133375645, 55.03380350768566, 53.73577415943146, 53.74972701072693, 54.071911722421646, 56.40784777700901, 54.22176048159599, 55.01255124807358, 56.33065491914749, 55.88455505669117, 50.94042755663395, 48.497557640075684, 49.62231628596783, 48.126287162303925, 44.23730984330177, 50.05088768899441, 52.03865222632885, 51.27128720283508, 51.437125504016876, 53.06949131190777, 52.30883292853832, 57.47396036982536, 62.81359724700451, 64.04949232935905, 62.999289482831955, 58.98881748318672, 54.690028354525566, 55.16893185675144, 58.83085235953331, 64.18259918689728, 69.10124525427818, 66.83547243475914, 70.03315284848213, 71.588926166296, 70.57546734809875, 68.14462378621101, 64.14358288049698, 62.357967495918274, 67.34915167093277, 68.93998950719833, 79.16581839323044, 74.67858597636223, 84.2664746940136, 13.385350797325373, 2.2565317153930664, 0.8110822120215744, 0.5039626825600863, 3.833306268788874, 65.22283136844635, 72.09656372666359, 59.65463675558567, 44.1947141289711, 29.741669073700905, 23.20204708725214, 42.98348732292652, 55.44663615524769, 50.60501575469971, 0.7499365461990237, 0.049758085078792647, 0.021119251905474812, 0.12165514781372622, 0.12639655120437965, 0.06343895409372635, 0.013348179054446518, 0.04269647200999316, 0.05223992709943559, 0.06549284778884612, 0.11455994143034332, 0.20461997017264366, 0.17107916995882988, 0.21961127902613953, 0.30619427911005914, 0.1396752503933385, 0.1640088329440914, 0.2115590509492904, 0.31952072808053344, 0.3986119106411934, 0.9297504974529147, 16.21921118348837, 80.8524338901043, 71.86162233352661, 58.86369779706001, 73.06235790252686, 57.21123866736889, 88.0821843445301, 61.69729694724083, 0.47315414354670793, 0.8427063713315874, 19.615214355289936, 6.957789547741413, 18.112094812095165, 125.37716031074524, 79.69636872410774, 102.36259326338768, 75.02530217170715, 83.64624917507172, 68.20913672447205, 79.32284876704216, 71.4513735473156, 79.60396528244019, 73.54034185409546, 77.61860981583595, 67.87150204181671, 69.55653682351112, 59.38371129333973, 66.84911370277405, 60.98535194993019, 66.05137690901756, 62.16162823140621, 64.53400433063507, 60.409584045410156, 65.96242368221283, 60.5320780724287, 60.67548617720604, 60.99362790584564, 64.01098519563675, 59.925797805190086, 61.48950129747391, 55.538815408945084, 57.9435695707798, 57.50088192522526, 55.14598868787289, 59.20492708683014, 59.49973426759243, 53.84331598877907, 54.11832623183727, 51.99150435626507, 51.64207510650158, 49.31829459965229, 59.79741409420967, 53.76689828932285, 64.80748325586319, 68.84916678071022, 69.94659349322319, 69.63083043694496, 72.97807842493057, 68.53613197803497, 69.88135099411011, 69.35093745589256, 70.64677432179451, 69.86695736646652, 63.724955543875694, 64.11133781075478, 73.58710214495659, 62.23571665585041, 56.31268568336964, 61.731141731143, 66.84584587812424, 65.21525457501411, 58.764956295490265, 48.78316931426525, 50.033340230584145, 50.72594426572323, 51.65817104279995, 55.54914325475693, 52.86022134125233, 53.19931514561176, 49.449087381362915, 49.58836130797863, 48.99003021419048, 50.142109394073486, 66.42783030867577, 67.22251206636429, 64.5855675637722, 63.807946890592575, 60.25534652173519, 61.69263079762459, 60.42223356664181, 63.513329699635506, 62.50118561089039, 61.446392610669136, 60.321291983127594, 55.02184174954891, 57.928944155573845, 61.60586625337601, 60.325665548443794, 60.784559324383736, 60.478903725743294, 57.51458398997784, 56.54633514583111, 56.2497116625309, 58.61744061112404, 58.590545654296875, 60.73695547878742, 58.08855839073658, 59.22651752829552, 54.23623010516167, 51.9238755851984, 52.946579307317734, 52.67467349767685, 48.22389632463455, 55.16652278602123, 54.766028076410294, 54.076995849609375, 51.390414610505104, 58.23008179664612, 55.58059796690941, 60.54233372211456, 65.5400687456131, 69.30111452937126, 67.72033855319023, 62.25398987531662, 57.43118226528168, 58.484797328710556, 62.2188151627779, 68.12646076083183, 73.67024168372154, 71.37396410107613, 72.91030526161194, 73.73898759484291, 75.08705645799637, 71.82986363768578, 68.3818906545639, 66.32397428154945, 70.82037180662155, 74.00504171848297, 83.14779192209244, 78.04953709244728, 86.53000563383102, 11.717674434185028, 5.001654513180256, 5.279674669727683, 0.4683551494963467, 5.981477536261082, 78.52825820446014, 74.73011121153831, 69.18558552861214, 51.53674095869064, 50.82946591079235, 35.16797550022602, 52.03927539288998, 64.70045819878578, 61.020161882042885, 1.2655447726137936, 0.12747670261887833, 0.10021045673056506, 0.2514583943411708, 0.15633815783075988, 0.1541506330249831, 0.20457278442336246, 0.16408905910793692, 0.2552332839695737, 0.15588149952236563], [0.058861509678536095, 0.01678459553659195, 0.07403954659821466, 0.04073245610925369, 0.04316507147450466, 0.06659252510871738, 0.031788136839168146, 0.030653608264401555, 0.0682191940722987, 0.1254255697131157, 0.4118585342075676, 10.386883243918419, 55.713742822408676, 43.64373989403248, 28.37834782898426, 37.38348841667175, 39.97345604002476, 92.34538838267326, 30.00942550599575, 0.2011215899256058, 0.6980131636373699, 1.4083596342243254, 9.71769355237484, 41.1494929343462, 104.57788959145546, 77.97534987330437, 91.99260011315346, 68.83137613534927, 71.86137914657593, 61.30456142127514, 69.71114292740822, 68.16929966211319, 71.0433742403984, 71.56135484576225, 74.23410102725029, 68.33534315228462, 64.44967925548553, 56.57616354525089, 60.11598140001297, 57.79704563319683, 56.77898146212101, 54.062530025839806, 57.38464616239071, 53.097400814294815, 56.86446167528629, 53.805367425084114, 55.68552553653717, 53.64553280174732, 56.692000329494476, 55.19580781459808, 51.56188040971756, 48.81672151386738, 50.254169180989265, 47.21453368663788, 51.464085057377815, 55.170409977436066, 55.59249132871628, 49.66410644352436, 53.08576203882694, 51.025729179382324, 49.785148948431015, 46.49267882108688, 52.563217878341675, 50.85417978465557, 55.02070941030979, 63.02471771836281, 66.30966424942017, 63.74109327793121, 66.23600140213966, 63.432078659534454, 59.44130100309849, 60.103715658187866, 64.76408958435059, 65.29587864875793, 59.433374628424644, 60.97588285803795, 63.53665664792061, 58.373113721609116, 57.63719201087952, 57.44950868189335, 61.252059638500214, 59.048348888754845, 50.72390757501125, 42.457196563482285, 54.25002336502075, 56.38750746846199, 59.85864020884037, 63.110376521945, 62.66893520951271, 62.73670457303524, 53.951488584280014, 51.31756491959095, 46.4921810477972, 39.63368967175484, 54.47343237698078, 61.53222620487213, 62.38597959280014, 57.11156241595745, 57.65491805970669, 53.47040019929409, 51.387397572398186, 55.99178530275822, 58.36485296487808, 59.51391890645027, 57.397094294428825, 55.549827218055725, 51.77558094263077, 52.735219448804855, 54.03446473181248, 54.33261193335056, 51.711770966649055, 50.52395090460777, 53.47803018987179, 53.493111580610275, 54.392253533005714, 48.832376673817635, 53.75886932015419, 52.18136876821518, 53.44053380191326, 50.06213128566742, 47.9169487953186, 48.77863995730877, 46.303992345929146, 41.81778587400913, 44.610366225242615, 50.406438410282135, 50.931102856993675, 51.29844434559345, 50.008052587509155, 51.75875164568424, 52.05564871430397, 52.8890123963356, 53.325054198503494, 53.41133996844292, 51.106851026415825, 51.59136302769184, 51.24970816075802, 53.523278161883354, 61.4460164308548, 66.02391958236694, 65.14088496565819, 68.89714300632477, 67.13921293616295, 68.77079978585243, 61.65174499154091, 61.04004241526127, 59.140231758356094, 66.9501730799675, 70.13735085725784, 75.61395138502121, 67.82079756259918, 83.93541365861893, 37.81158484518528, 0.1792049003415741, 2.4419192550703883, 0.00019791876894714733, 0.05334999819751829, 41.05032205581665, 70.98963752388954, 56.335210874676704, 37.62667156755924, 23.60359624028206, 18.204636946320534, 34.24085184931755, 47.51486957073212, 34.00377877056599, 0.7288391282781959, 0.029087114489811938, 0.0383719292585738, 0.07303738748305477, 0.023601652392244432, 0.03746327703993302, 0.06503606331534684, 0.04037760561914183, 0.04447163730219472, 0.1561523537384346, 0.04231480030284729, 0.08281208836706355, 0.014884416395943845, 0.09849369846051559, 0.06317261955700815, 0.0677965409704484, 0.026672865424188785, 0.02320961659279419, 0.08380200204555877, 0.2830152556998655, 0.4330575669882819, 19.84870422631502, 67.8938752412796, 51.061333268880844, 35.63552141189575, 38.04609686136246, 49.736348167061806, 100.97266584634781, 31.151024848222733, 0.056159142186515965, 0.8378925640136003, 1.5391809144057333, 11.472688280045986, 45.63713952898979, 107.41394340991974, 80.61906561255455, 93.97654205560684, 73.06564092636108, 76.11160308122635, 63.81360858678818, 73.14469948410988, 69.20848309993744, 76.32049307227135, 72.37686708569527, 78.63380894064903, 70.9628413617611, 68.8524042069912, 57.896854877471924, 64.00777816772461, 59.68177109956741, 61.51756279170513, 57.38908052444458, 61.30499079823494, 56.89580239355564, 58.087490648031235, 55.84672428667545, 57.70986311137676, 56.47857718169689, 58.35708998143673, 57.60604128241539, 54.69208404421806, 53.20526942610741, 53.03235970437527, 52.207184582948685, 55.15439383685589, 57.043462470173836, 56.592810451984406, 50.30318275094032, 54.49681632220745, 49.82573837041855, 51.74349166452885, 48.82592462003231, 55.25136083364487, 52.23882548511028, 57.54856176674366, 66.0749052464962, 69.5346499979496, 66.99118047952652, 68.8398876786232, 65.04074513912201, 62.89910025894642, 62.94720947742462, 68.07561188936234, 67.24705874919891, 62.59155236184597, 63.05110730230808, 67.77756348252296, 61.782051399350166, 61.66810691356659, 59.423590153455734, 64.89006042480469, 61.05067424476147, 55.46498917043209, 44.1605843603611, 56.33722096681595, 58.199903815984726, 62.22086705267429, 65.34054905176163, 66.15274786949158, 64.73736941814423, 56.08473211526871, 53.098601549863815, 50.26420824229717, 43.26964616775513, 53.39279696345329, 62.2371681779623, 63.97424876689911, 59.4346209615469, 60.459851548075676, 55.30089117586613, 55.417776703834534, 59.95371490716934, 60.0896830111742, 61.63783773779869, 60.20349070429802, 57.77697131037712, 53.71305897831917, 54.88656900823116, 57.20024585723877, 56.83414690196514, 53.703494891524315, 52.75216653943062, 56.11555986106396, 57.5321314483881, 57.523182928562164, 53.31748120486736, 58.42465415596962, 55.12680731713772, 56.2251041829586, 53.369671404361725, 50.88762179017067, 49.93053674697876, 48.545716255903244, 45.478836223483086, 46.821315586566925, 52.019919231534004, 53.18345859646797, 52.32540003955364, 52.08452716469765, 54.177918434143066, 54.51507434248924, 54.6061934530735, 56.139490976929665, 54.19152170419693, 53.24091151356697, 53.65142248570919, 54.50599282979965, 56.553699150681496, 61.774451807141304, 66.94111436605453, 67.58935958147049, 70.73372885584831, 69.76524442434311, 71.09071210026741, 63.44238370656967, 64.10144314169884, 61.312704384326935, 69.65013340115547, 72.88282513618469, 76.9463574886322, 69.73936781287193, 86.20203763246536, 45.42772136628628, 0.08261377166491002, 1.0380788845941424, 0.07279788158484735, 0.037439287116285414, 41.58752202987671, 78.56222838163376, 62.37902596592903, 47.01759785413742, 26.31571400910616, 25.979694239795208, 44.40371811389923, 55.9564433991909, 42.05602549016476, 1.2306726188398898, 0.08654757737531327, 0.07942141601233743, 0.06393611140083522, 0.04569303055177443, 0.005158945878065424, 0.008521321069565602, 0.05941499228356406, 0.015045207328512333, 0.09393306740093976, 0.13524688489269465, 0.217828358290717, 0.15135053952690214, 0.1910748251248151, 0.19431003980571404, 0.19106306950561702, 0.20527093758573756, 0.2764490299159661, 0.2356353754294105, 0.5358664831146598, 0.6879856798332185, 22.98550620675087, 78.73117491602898, 57.89891816675663, 39.88538816571236, 53.699961081147194, 57.88377217948437, 107.34652742743492, 36.89338691532612, 0.2986094111111015, 1.3858289807103574, 5.55843198671937, 17.507516853511333, 46.20124585926533, 115.31395509839058, 82.6763816177845, 99.57724392414093, 75.04674062132835, 80.96979439258575, 67.42500320076942, 78.23813617229462, 71.98204547166824, 80.60657188296318, 76.62063896656036, 82.025788128376, 75.4640494287014, 72.39192947745323, 62.1388940513134, 68.44357654452324, 62.833101600408554, 65.52981689572334, 61.151380240917206, 64.93522480130196, 58.63227501511574, 62.97042243182659, 58.84784124791622, 62.12981253862381, 59.59890894591808, 62.31696009635925, 60.147405713796616, 56.86663515865803, 55.83409756422043, 55.87565593421459, 54.60245065391064, 57.86787003278732, 59.81136694550514, 58.25220800936222, 49.73306134343147, 55.45297421514988, 51.31778530776501, 53.81745457649231, 48.37661772966385, 56.796718910336494, 55.44112645089626, 60.18590904772282, 69.71134811639786, 74.13996487855911, 68.40691611170769, 71.1465311050415, 68.84328469634056, 65.97626253962517, 65.63811108469963, 69.27677303552628, 71.52502879500389, 66.17349475622177, 65.31304612755775, 69.76512283086777, 66.56741201877594, 65.38810729980469, 64.27287474274635, 68.25535744428635, 65.92560365796089, 58.54204885661602, 45.035255625844, 57.13225230574608, 59.40312445163727, 63.53068336844444, 68.41313257813454, 69.34038922190666, 67.20247954130173, 57.25737579166889, 53.086955174803734, 50.69697842001915, 47.640528827905655, 60.07365547120571, 64.91043493151665, 68.07990565896034, 62.158759385347366, 63.37545409798622, 58.84801223874092, 58.707366585731506, 62.0143823325634, 64.07682046294212, 65.7703971862793, 63.180904537439346, 60.7895864546299, 58.48846413195133, 59.222922921180725, 59.993764758110046, 60.32654330134392, 57.84405671060085, 56.21565409004688, 59.881978556513786, 59.65212509036064, 59.89326015114784, 57.38512113690376, 59.77912187576294, 58.252443596720695, 60.07093861699104, 57.078602984547615, 53.996595963835716, 54.09127928316593, 51.48204289376736, 47.501756474375725, 50.1151954382658, 55.21401643753052, 55.08342504501343, 55.91005928814411, 54.80434522032738, 57.18436270952225, 57.82916530966759, 59.582714214921, 58.43820422887802, 60.289917066693306, 57.783115580677986, 57.029707208275795, 58.23048457503319, 58.45745399594307, 65.55247128009796, 70.19542694091797, 71.20687946677208, 77.4714969098568, 73.0461859703064, 77.92069360613823, 67.41997987031937, 68.2171542942524, 64.13026079535484, 74.17069762945175, 75.73911666870117, 80.49318596720695, 72.59163156151772, 92.35024452209473, 43.48416745662689, 0.23794971843017265, 6.389608886092901, 0.12252811386133544, 0.3115440654801205, 52.459749430418015, 85.19224181771278, 70.34771516919136, 54.615149572491646, 38.7596719712019, 29.413644075393677, 51.136307045817375, 65.83715200424194, 53.77271957695484, 1.6556802880950272, 0.15861242485698313, 0.24418144341325387, 0.13543639972340316, 0.2722966542933136, 0.21856361883692443, 0.15141581883653998, 0.1108479117101524, 0.19209213147405535, 0.2941130648832768], [0.04245222749887034, 0.07162502850405872, 0.05217288889980409, 0.11288535199128091, 0.028259315549803432, 0.036297786064096726, 0.05701408146705944, 0.04275961393432226, 0.021417571151687298, 0.036934274176019244, 0.08917328101233579, 27.788642272353172, 66.47273629903793, 43.25905613601208, 47.8580329567194, 41.95558927953243, 49.767586290836334, 91.20411962270737, 14.334516115486622, 0.39843314210884273, 0.8254042966291308, 1.694179109763354, 2.6863990863785148, 61.415511667728424, 81.11173197627068, 89.38524082303047, 83.6989675462246, 72.23756656050682, 64.33701530098915, 63.04890722036362, 64.60418656468391, 66.42023831605911, 71.16486892104149, 72.15794563293457, 78.4992353618145, 74.21646997332573, 69.78359743952751, 59.27634045481682, 56.37583449482918, 55.85121564567089, 56.58952742815018, 55.857169926166534, 53.14289577305317, 54.36828441917896, 54.88327078521252, 53.53904351592064, 54.812017008662224, 52.64183185994625, 55.44715292751789, 53.493453562259674, 52.22507402300835, 48.71252350509167, 49.71959486603737, 48.19399192929268, 51.39760382473469, 57.92482137680054, 55.058255195617676, 50.74390210211277, 51.22522607445717, 50.4425098747015, 52.08907172083855, 46.70490883290768, 50.95266290009022, 49.928355664014816, 52.330598160624504, 60.321421176195145, 63.74029912054539, 64.72458690404892, 66.31040900945663, 65.04405856132507, 57.54490256309509, 61.98477052152157, 61.70072056353092, 64.37647238373756, 63.99254098534584, 63.35620813071728, 62.862154841423035, 59.35617797076702, 61.42392821609974, 62.20384016633034, 59.04512666165829, 58.05212214589119, 49.70157243311405, 43.02340418100357, 58.01822416484356, 62.64434292912483, 63.170295506715775, 62.09035165607929, 62.36886151134968, 60.3287585824728, 58.72349292039871, 60.47456815838814, 52.11824655532837, 40.495635420084, 46.92310832440853, 57.40726634860039, 55.903554037213326, 61.350470557808876, 53.212470039725304, 54.424874782562256, 60.28483673930168, 61.124831065535545, 57.71990977227688, 56.70814946293831, 58.09308014810085, 56.73531800508499, 52.34497658908367, 50.743708312511444, 53.911427333950996, 55.0184865295887, 52.155640348792076, 55.03110185265541, 56.71455591917038, 59.843285232782364, 50.626442804932594, 54.088881611824036, 55.37573575973511, 53.28090436756611, 51.576068848371506, 51.419467851519585, 52.335811480879784, 45.528700947761536, 49.765485003590584, 43.052958995103836, 42.445003017783165, 50.21096549928188, 50.997964069247246, 50.97004696726799, 50.37252902984619, 51.39560893177986, 51.65325030684471, 50.92170976102352, 50.45476421713829, 49.73002910614014, 51.11234933137894, 52.38979518413544, 53.30515846610069, 57.895920127630234, 60.61258815228939, 63.58215540647507, 66.14527747035027, 63.88392761349678, 65.41026011109352, 62.129037380218506, 57.194557562470436, 56.88733644783497, 62.08489514887333, 69.04250040650368, 74.18201342225075, 76.36709377169609, 70.88869974017143, 77.7875867486, 64.85058814287186, 3.6462176078930497, 0.7740886439569294, 0.5343668104615062, 0.4684915562393144, 10.927675925195217, 69.04617860913277, 63.34320142865181, 50.200675651431084, 27.874977439641953, 18.090880550444126, 26.206239983439445, 44.24884222447872, 18.76366674900055, 0.9658543195109814, 0.07303398102521896, 0.13856505684088916, 0.037115042796358466, 0.03795651580730919, 0.024101399794744793, 0.10946929818601348, 0.024255428834294435, 0.03692918675369583, 0.0567794032394886, 0.075173511140747, 0.04138100041018333, 0.04306524519051891, 0.07897121438873, 0.026179361339018214, 0.0793108508514706, 0.026176333376497496, 0.0893118474050425, 0.06379921484040096, 0.05945879383943975, 0.08181802608305588, 41.349890381097794, 75.81523418426514, 58.3269651979208, 43.90061751008034, 37.93358489871025, 60.2652183920145, 95.21114900708199, 14.982151463627815, 0.5832073115743697, 0.6846261851023883, 1.454857501666993, 4.055916136130691, 71.89838916063309, 86.50412902235985, 90.3256143629551, 89.7431892156601, 76.0652607679367, 67.73448139429092, 65.51624402403831, 67.35953271389008, 68.97041067481041, 74.66958045959473, 75.15087023377419, 80.9228365123272, 77.22278505563736, 72.8044505417347, 61.56313754618168, 59.3794821202755, 58.95545147359371, 61.231540739536285, 60.756733417510986, 58.20703983306885, 56.73390068113804, 59.1972590982914, 56.45803548395634, 58.34259755909443, 56.00164957344532, 59.77463811635971, 56.04592099785805, 53.66278387606144, 51.43708370625973, 51.86282806098461, 49.63925197720528, 54.44691359996796, 59.62383180856705, 55.77977567911148, 50.10216973721981, 51.260176599025726, 50.27849167585373, 52.97290049493313, 48.22484627366066, 52.41353631019592, 53.27827870845795, 54.424350410699844, 60.70002906024456, 67.62757793068886, 66.9886802136898, 69.77554187178612, 67.82770559191704, 62.470490857958794, 62.75368206202984, 64.19518411159515, 66.53097957372665, 67.01230734586716, 66.17483988404274, 67.03113913536072, 63.047987669706345, 63.99118825793266, 66.19668871164322, 62.09292031824589, 61.30052603781223, 51.67455576360226, 44.789519011974335, 60.606082901358604, 66.70263156294823, 64.24048528075218, 66.30861550569534, 66.28295928239822, 62.06462703645229, 61.07826456427574, 62.400380820035934, 53.60821880400181, 43.88405799865723, 49.84168231487274, 56.4416241645813, 55.414835661649704, 63.70542459189892, 55.42782336473465, 59.35546740889549, 61.34801588952541, 61.305382177233696, 61.701632514595985, 59.839762821793556, 60.11563561856747, 59.12758983671665, 56.25728465616703, 55.31574457883835, 55.9172523021698, 56.51773028075695, 55.50906300544739, 57.15045712888241, 60.731426775455475, 62.087357416749, 54.21171002089977, 57.879037633538246, 57.04233393073082, 57.06480972468853, 52.87892013788223, 54.4467806071043, 54.88958604633808, 47.23551616072655, 50.894168838858604, 46.531611531972885, 45.91781906783581, 51.2188196182251, 52.571193650364876, 52.233741357922554, 51.38708218932152, 54.81839306652546, 53.74385632574558, 52.461782321333885, 52.479660362005234, 52.30839975178242, 53.64956818521023, 54.60504591464996, 56.757102236151695, 60.81062212586403, 65.09839564561844, 67.14839324355125, 70.14302775263786, 66.5148988366127, 68.70171189308167, 64.06451672315598, 60.85043638944626, 59.46139432489872, 66.8896347284317, 70.97170248627663, 76.72112077474594, 79.91196915507317, 74.9284453690052, 78.88819009065628, 72.51242861151695, 5.2646165527403355, 0.684427289525047, 1.083774163853377, 0.8694172755349427, 10.477870311588049, 75.32771274447441, 69.94150936603546, 60.97565487027168, 30.79237539321184, 18.03866185247898, 33.16188454627991, 53.46389874815941, 27.659578397870064, 1.1904781381599605, 0.08469256441458128, 0.07867252221331, 0.018644695919647347, 0.02306514641531976, 0.03648032470664475, 0.12640717875910923, 0.05557767319260165, 0.02746543275861768, 0.028250858777028043, 0.16226736857788637, 0.251605873927474, 0.17502460512332618, 0.2534889994421974, 0.10618910935590975, 0.21560866880463436, 0.17904005449963734, 0.1433434191858396, 0.12793874891940504, 0.22554262715857476, 0.13259419676614925, 47.298079803586006, 89.83968123793602, 54.63086172938347, 59.10957120358944, 67.84672737121582, 65.85706293582916, 103.54659453034401, 18.009810000658035, 0.9002458525355905, 2.0564603386446834, 4.457052536308765, 5.90285025537014, 74.19231846928596, 91.96429163217545, 94.21902224421501, 93.07372570037842, 78.13437893986702, 71.25550925731659, 68.4407190978527, 71.66505128145218, 72.11772099137306, 78.67350161075592, 80.68300098180771, 87.09403216838837, 81.23821958899498, 77.07217633724213, 63.920960426330566, 63.46369296312332, 63.20994257926941, 63.68261061608791, 64.06595304608345, 60.090594962239265, 59.8159608989954, 62.98341013491154, 60.86251214146614, 60.898652002215385, 57.77307651937008, 62.38065987825394, 57.62459188699722, 57.086688950657845, 52.93400578200817, 55.3981127589941, 53.824860379099846, 56.78856074810028, 60.90204142034054, 56.62068955600262, 50.17335891723633, 49.7811933606863, 49.83919344842434, 55.26678040623665, 49.74722698330879, 55.16491927206516, 55.493822023272514, 57.0290270447731, 64.7811658680439, 69.85812664031982, 69.99654561281204, 72.37611472606659, 70.7790832221508, 65.20458474755287, 68.24200496077538, 67.92301207780838, 70.85656866431236, 70.17141982913017, 69.68645185232162, 68.370650857687, 67.17380627989769, 69.86469268798828, 68.64332422614098, 66.07091546058655, 63.383319675922394, 56.52155667543411, 45.08119136095047, 62.81026862561703, 68.17373782396317, 69.1181543469429, 69.3109180033207, 68.48349720239639, 63.80583420395851, 62.54608780145645, 63.64734470844269, 55.46651288866997, 43.895282596349716, 54.149070382118225, 61.60066433250904, 59.806070029735565, 64.86366704106331, 61.29173330962658, 61.41593724489212, 63.89891400933266, 64.4595967233181, 64.52083423733711, 64.13032919168472, 62.506919503211975, 62.384474873542786, 58.854198306798935, 58.055401369929314, 59.193398505449295, 61.77193634212017, 58.51043455302715, 59.63896259665489, 63.45874562859535, 64.4371247291565, 58.98183345794678, 59.18570011854172, 59.910480827093124, 60.13758324086666, 55.917085111141205, 56.254921182990074, 58.959433659911156, 51.72063209116459, 55.96084736287594, 48.10269422829151, 49.62079256772995, 54.652357175946236, 56.821622774004936, 55.89475370943546, 54.68421846628189, 57.592274621129036, 57.69269943237305, 56.09394282102585, 57.39216975867748, 55.02148076891899, 56.773969531059265, 57.57683224976063, 59.84301544725895, 64.09166246652603, 67.70844519138336, 70.40064632892609, 73.80219340324402, 70.92303469777107, 72.46892854571342, 68.68765264749527, 66.65353059768677, 62.19225078821182, 69.1245000064373, 74.75082010030746, 81.40126883983612, 80.38745284080505, 80.06285145878792, 83.10290113091469, 75.01475393772125, 4.890938904136419, 2.0539434487000108, 1.6882970253936946, 0.7077833299990743, 15.432483348995447, 84.85582306981087, 75.75962036848068, 69.82741668820381, 44.08448584377766, 26.727165430784225, 42.01588064432144, 64.32611748576164, 40.85355341434479, 1.4924985193647444, 0.21400883590104058, 0.218646353459917, 0.07035020433249883, 0.1458202925277874, 0.1622711238451302, 0.22287781233899295, 0.1577679647016339, 0.14953031844925135, 0.1283489933121018], [0.06689670917694457, 0.039658538735238835, 0.08698675810592249, 0.09836955199716613, 0.05880806391360238, 0.027495936883497052, 0.07023225480224937, 0.05308672130922787, 0.04484612501983065, 0.045915645168861374, 0.2523419656790793, 46.48586578667164, 53.959205970168114, 25.95171444118023, 42.85101503133774, 45.71468956768513, 58.816029354929924, 85.17108455300331, 3.697714819572866, 0.174062084115576, 0.5779094458557665, 1.5656375885009766, 15.302402079105377, 76.66395664215088, 80.32167837023735, 93.58954802155495, 82.10855528712273, 75.09200379252434, 60.943200811743736, 66.75360962748528, 62.78722666203976, 70.55897623300552, 69.64840069413185, 73.90967443585396, 75.90845078229904, 75.7126472890377, 69.94999051094055, 66.82183876633644, 58.228037506341934, 56.88212692737579, 55.98526865243912, 57.74017408490181, 53.32586735486984, 54.45006363093853, 53.0874415487051, 53.702191561460495, 51.854213923215866, 55.00584080815315, 53.03929813206196, 52.89009913802147, 49.739167615771294, 47.40347854793072, 46.70133702456951, 51.11249752342701, 50.785091891884804, 57.60066457092762, 52.46172532439232, 52.86040373146534, 50.330864265561104, 50.0320141017437, 49.83797371387482, 48.75714831054211, 49.27450194954872, 52.50751666724682, 48.495878130197525, 56.7932952940464, 60.55379390716553, 66.9428014755249, 65.7154293358326, 64.83522176742554, 58.40627834200859, 56.69146075844765, 58.66512045264244, 61.99784941971302, 63.09230849146843, 63.432405441999435, 65.84599032998085, 68.53500723838806, 60.24150386452675, 60.111064463853836, 64.0412999689579, 55.59049643576145, 44.5396938174963, 45.17719700932503, 57.570475190877914, 59.985986575484276, 60.144669860601425, 58.0481893569231, 57.316580414772034, 60.39908140897751, 61.12826608121395, 59.69512738287449, 54.18377012014389, 43.461608067154884, 32.326788157224655, 41.40988156199455, 60.77608197927475, 55.0021930038929, 52.91659511625767, 58.5508643835783, 57.33375169336796, 55.765750631690025, 59.227072298526764, 55.517996326088905, 53.548231422901154, 56.812909841537476, 54.619572535157204, 51.87397666275501, 54.09979462623596, 57.24694915115833, 58.86769898235798, 59.36024375259876, 62.145904675126076, 52.485861629247665, 53.78947287797928, 59.32891063392162, 54.42150056362152, 51.75103805959225, 46.896167770028114, 48.81846182048321, 53.89688931405544, 45.57762332260609, 45.66628776490688, 46.066254302859306, 42.72952415049076, 43.71669977903366, 51.86423398554325, 50.496444180607796, 52.23437212407589, 50.06728760898113, 50.62402993440628, 50.735424757003784, 51.84263974428177, 51.8655601143837, 52.97120958566666, 53.08168865740299, 59.23945963382721, 60.4501810669899, 65.48533648252487, 65.81255972385406, 64.32715862989426, 63.12784418463707, 59.78677846491337, 57.50765696167946, 54.96269412338734, 58.33540454506874, 70.53352519869804, 72.21950232982635, 73.90091210603714, 78.36097598075867, 78.51495131850243, 67.10069820284843, 85.684984177351, 19.847423695027828, 0.5015849007759243, 1.47677484434098, 0.2291998715372756, 1.1257066950201988, 51.14640310406685, 66.08225405216217, 50.92415302991867, 35.42299881577492, 35.080067217350006, 25.912751331925392, 44.187893494963646, 21.870925314724445, 0.34017009660601616, 0.0689877028344199, 0.05460434280394111, 0.027177180745638907, 0.04730441127321683, 0.03386971635336522, 0.0355141449108487, 0.0455341738415882, 0.028497121929831337, 0.04317585859098472, 0.02686476997041609, 0.06888043280923739, 0.06967746972804889, 0.06364527114783414, 0.05976950138574466, 0.054111029821797274, 0.05222956300713122, 0.006248553181649186, 0.012279415896045975, 0.012471656264096964, 0.523821545066312, 58.32300581037998, 60.70635572075844, 42.654915153980255, 38.66213120520115, 45.344505831599236, 71.8538099527359, 87.03586488962173, 4.410897837951779, 0.31605017837136984, 0.6657324114348739, 2.4273351626470685, 18.911492116749287, 86.00837722420692, 85.77700763940811, 96.3304853439331, 85.2604253590107, 76.29791468381882, 64.43079426884651, 70.65995201468468, 65.4207855463028, 72.6432403922081, 72.54209741950035, 75.68560793995857, 78.80535453557968, 79.02553752064705, 76.12962171435356, 70.51377385854721, 59.58399094641209, 58.56850303709507, 59.67757232487202, 61.04330264031887, 57.371548265218735, 58.21170598268509, 56.165774166584015, 56.74863629043102, 56.744308322668076, 56.37225888669491, 54.977570325136185, 56.39921844005585, 52.955489829182625, 51.45514793694019, 51.678283363580704, 51.48213408887386, 53.549432158470154, 58.45198608934879, 51.877768859267235, 50.67408464848995, 50.6106698513031, 50.40235362946987, 50.49916863441467, 50.05970321595669, 50.601763129234314, 55.33913992345333, 51.41968064010143, 58.59329290688038, 62.67380274832249, 67.96901240944862, 65.81278011202812, 66.88112318515778, 62.120788022875786, 59.937835559248924, 60.32311588525772, 64.44440513849258, 64.66024115681648, 67.40263000130653, 70.37652522325516, 72.48094350099564, 62.25265994668007, 63.73655632138252, 67.9963481426239, 58.356622606515884, 46.64373591542244, 47.44689121842384, 59.52272303402424, 62.233748361468315, 59.57468904554844, 57.30101265013218, 58.63822549581528, 62.4036068469286, 61.140790209174156, 60.920930206775665, 53.833512514829636, 45.182125344872475, 33.68841849267483, 42.907282412052155, 61.78970418870449, 57.46467366814613, 57.27298155426979, 62.33271785080433, 58.74042481184006, 60.21323338150978, 61.835875511169434, 59.53663408756256, 58.06049309670925, 58.4706886857748, 57.79219329357147, 54.029901176691055, 55.29858089983463, 58.580153211951256, 61.35849192738533, 60.94122111797333, 64.75353375077248, 56.68253883719444, 60.12782536447048, 59.179069474339485, 56.8310272693634, 54.319715425372124, 49.10677894949913, 50.05639739334583, 57.08062827587128, 48.713112473487854, 48.04744519293308, 47.620557099580765, 45.406324714422226, 47.22313642501831, 52.77104772627354, 51.522164940834045, 55.044705122709274, 52.93121673166752, 52.85624295473099, 51.714172437787056, 53.682056441903114, 53.25775980949402, 53.793740049004555, 55.1899029314518, 61.57889150083065, 62.22405128180981, 66.82597294449806, 66.20371833443642, 67.60984048247337, 66.99198603630066, 62.772434055805206, 58.52776162326336, 58.43948855996132, 61.16048075258732, 73.96601781249046, 73.54872420430183, 77.22670644521713, 78.6143159866333, 81.43457025289536, 69.90011438727379, 88.1670717895031, 24.933336786925793, 0.5758399225305766, 1.2070952402427793, 0.18096929707098752, 0.9567990491632372, 54.522244557738304, 74.99054163694382, 59.154458194971085, 40.630801767110825, 23.828831054270267, 37.225766479969025, 54.530117735266685, 35.876033306121826, 0.3596933005610481, 0.10791054315632209, 0.033719813654897735, 0.040946446970338, 0.020599930358002894, 0.03954936510126572, 0.01709308406134369, 0.05658099747961387, 0.052413778903428465, 0.041687117773108184, 0.19848573370836675, 0.17552849370986223, 0.15565183450235054, 0.16881541174370795, 0.20332682237494737, 0.12880856083938852, 0.15891286107944325, 0.17156725079985335, 0.19474470085697249, 0.1451649167574942, 0.8102616935502738, 65.09941399097443, 73.38541656732559, 35.45322619378567, 58.04936349391937, 70.87723955512047, 73.39912623167038, 100.95365166664124, 5.164453452453017, 0.3133881837129593, 1.3805352710187435, 4.8038314282894135, 18.342339657247066, 86.61914125084877, 88.55360224843025, 100.02165287733078, 89.21022221446037, 82.96145752072334, 68.10287922620773, 78.04392859339714, 69.04034972190857, 77.83315390348434, 75.59575036168098, 79.16891142725945, 83.41048702597618, 82.35067829489708, 77.37724676728249, 73.8489080965519, 62.71500013768673, 65.28155341744423, 64.73711863160133, 65.4315921664238, 60.486450120806694, 61.530455499887466, 59.83625940978527, 59.29929122328758, 59.4252772629261, 59.21746261417866, 57.81255640089512, 58.03241640329361, 56.88137836754322, 53.957887440919876, 54.60270144045353, 55.43873257935047, 55.08893094956875, 60.488543808460236, 54.29286986589432, 51.49291791021824, 50.67749306559563, 50.95954053103924, 54.031177908182144, 51.11083701252937, 52.697890251874924, 56.436365246772766, 53.79572354257107, 59.50951114296913, 65.45678481459618, 70.75294062495232, 68.49659129977226, 69.90718960762024, 65.25381490588188, 61.64971210062504, 64.86291468143463, 66.80521085858345, 68.02769646048546, 70.51261872053146, 73.40072974562645, 73.50707083940506, 63.810211569070816, 69.02960389852524, 72.50242754817009, 63.18368598818779, 50.262220948934555, 49.93891529738903, 62.38700173795223, 64.5707331597805, 61.54973566532135, 59.64182764291763, 62.17494651675224, 64.24817606806755, 62.12608873844147, 63.29098463058472, 56.472672298550606, 48.86432535946369, 39.99515287578106, 47.99855701625347, 63.408231139183044, 60.27775011956692, 59.80398394167423, 65.83107233047485, 64.3938222527504, 63.39010611176491, 64.26472797989845, 61.123235151171684, 58.89686621725559, 64.57881152629852, 61.97952680289745, 56.57092742621899, 59.07011032104492, 60.751691088080406, 63.78786116838455, 64.16723281145096, 69.11394417285919, 62.613587379455566, 61.1632090061903, 62.38421268761158, 59.562020525336266, 56.585530042648315, 52.22214438021183, 50.01614235341549, 59.95081566274166, 50.02003334462643, 52.27576330304146, 51.203468441963196, 47.9188296943903, 49.17995922267437, 54.94418151676655, 54.760541170835495, 57.05797389149666, 55.27278408408165, 54.96278151869774, 54.32172931730747, 56.502094119787216, 56.885987520217896, 57.45395824313164, 57.12894268333912, 66.71139389276505, 65.93713223934174, 69.91870298981667, 70.85149213671684, 71.63760155439377, 69.88878339529037, 67.08001211285591, 63.540125861763954, 61.87307171523571, 63.320311456918716, 76.8812669813633, 75.45466393232346, 82.5613085925579, 80.55326074361801, 79.19658154249191, 76.99946343898773, 91.10917031764984, 25.511093884706497, 1.2559035024605691, 4.405136397108436, 0.32390260545071214, 2.0102519681677222, 66.31716504693031, 81.53338015079498, 67.34406754374504, 53.81677821278572, 53.97879771888256, 43.56151230633259, 63.659192472696304, 51.773023679852486, 1.0084232571534812, 0.2173586530261673, 0.14737973775481805, 0.15077564225066453, 0.1061177444353234, 0.0904708520101849, 0.07274419462191872, 0.1711036459892057, 0.10748592336312868, 0.10335484737879597], [0.013537262511817971, 0.025803127718972974, 0.06384084190358408, 0.03115327774139587, 0.11997770110610873, 0.10015607214882039, 0.006844345161880483, 0.04722801088064443, 0.05857843229023274, 0.16283399832900614, 1.9018752523697913, 57.86102660000324, 53.86271394789219, 34.866894856095314, 46.34566091001034, 44.70212370157242, 69.06604394316673, 61.28509886562824, 0.10349913573008962, 0.08234463180997409, 0.7525127485860139, 0.5464802635833621, 54.9636896699667, 98.20050939917564, 83.8496446609497, 91.21587619185448, 80.80599278211594, 73.19408923387527, 61.66092149913311, 64.77401465177536, 64.33995634317398, 66.67002171278, 70.92942595481873, 73.70250955224037, 74.32309985160828, 77.8739333152771, 73.84063214063644, 71.51083275675774, 64.58583354949951, 60.02547025680542, 57.00037278234959, 57.76165813207626, 54.64857637882233, 53.77680815756321, 54.697092175483704, 54.12910245358944, 52.1343956887722, 54.27285633981228, 53.92487861216068, 51.245064809918404, 49.34329345822334, 46.396680772304535, 47.339600175619125, 47.23627991974354, 53.75620186328888, 57.5157505273819, 51.39720484614372, 49.18257728219032, 49.12420481443405, 51.24927878379822, 49.04403671622276, 49.067705646157265, 47.5142578035593, 53.58795069158077, 47.412848845124245, 51.56379170715809, 59.23726715147495, 64.82256084680557, 64.07300546765327, 63.64294074475765, 59.4500595331192, 55.175725892186165, 55.1210468262434, 60.05079209804535, 62.14367039501667, 61.47974722087383, 66.04332134127617, 60.23209176957607, 66.15184351801872, 58.090355694293976, 55.20762138068676, 47.818807661533356, 44.2819232493639, 45.02143956720829, 55.890923514962196, 58.49540255963802, 58.997815400362015, 58.43145579099655, 57.75948844850063, 56.345090344548225, 56.54578797519207, 57.724032551050186, 51.33704647421837, 39.54240716993809, 34.46634694933891, 30.217437744140625, 48.473497331142426, 58.938827365636826, 56.85559295117855, 57.89135277271271, 57.92078599333763, 58.72332192957401, 58.066154792904854, 59.94208373129368, 54.24230217933655, 54.97417330741882, 51.89666144549847, 54.39468540251255, 52.729952931404114, 58.975039422512054, 57.14973896741867, 63.40128891170025, 52.78376564383507, 57.78361715376377, 59.83054831624031, 54.40582640469074, 52.33410157263279, 47.07617551088333, 46.481556817889214, 48.06248098611832, 52.6137475669384, 49.25919637084007, 46.253363862633705, 47.48972252011299, 43.73143158853054, 41.40618436038494, 49.34673607349396, 50.00723943114281, 49.856281131505966, 49.566216096282005, 50.397725477814674, 51.630143746733665, 50.41019640862942, 49.99524347484112, 54.34349074959755, 56.59260146319866, 58.21174778044224, 58.951431289315224, 60.989360734820366, 61.71198695898056, 62.70206183195114, 57.92233631014824, 56.993202567100525, 53.582326993346214, 59.811309948563576, 65.76797291636467, 73.92399206757545, 71.78367331624031, 71.3377520442009, 63.508682548999786, 88.73596966266632, 73.23614537715912, 77.1466675400734, 46.486952528357506, 0.16160062310518697, 0.45678346417844296, 0.043595316747087054, 0.34246962633915246, 26.150373481214046, 73.43475311994553, 54.09748815000057, 42.132325395941734, 23.41192502528429, 20.99308881908655, 42.4156191945076, 31.966483891010284, 0.6520305247977376, 0.04587723902659491, 0.03753612625587266, 0.04513664614933077, 0.01938881956448313, 0.008259539608843625, 0.03505140841298271, 0.024195593177864794, 0.012682399301411351, 0.04230592050589621, 0.0069329506368376315, 0.024034530433709733, 0.035044287506025285, 0.03253441085689701, 0.034848638824769296, 0.059203821583651006, 0.09023557635373436, 0.041853900620481, 0.18080295209074393, 0.38043612032197416, 4.273682925850153, 69.49819475412369, 61.556841284036636, 40.904797464609146, 40.38213551044464, 51.93981193006039, 78.58327925205231, 66.97100356221199, 0.13478124659741297, 0.15630045672878623, 0.4931777628371492, 0.04451825901924167, 64.97741773724556, 103.03673788905144, 86.90476432442665, 91.37444168329239, 82.01894089579582, 74.14755687117577, 64.35055017471313, 66.66646510362625, 66.19116380810738, 70.18595784902573, 74.5186373591423, 77.93994337320328, 75.69465905427933, 80.05525186657906, 77.04927116632462, 75.31293913722038, 66.20014652609825, 62.49548211693764, 61.08788184821606, 61.82278521358967, 58.00240941345692, 57.39972375333309, 58.29791575670242, 57.11591698229313, 55.74531152844429, 54.977528527379036, 57.641519978642464, 54.01586472988129, 53.01274135708809, 49.17517147958279, 51.05265073478222, 50.01725189387798, 56.42042130231857, 57.58389227092266, 50.88775858283043, 50.81976503133774, 48.8865427672863, 51.61538153886795, 51.17965131998062, 49.27376478910446, 49.129866510629654, 53.52792911231518, 52.38040588796139, 52.793094143271446, 60.63143514096737, 66.36810511350632, 66.2027607858181, 68.01873654127121, 61.27170458436012, 57.027932703495026, 59.25710588693619, 61.593497917056084, 63.85391682386398, 64.52541679143906, 66.46163329482079, 63.356998488307, 66.0228556394577, 62.03808166086674, 56.49331659078598, 50.16505256295204, 46.500954777002335, 45.83699360489845, 56.64469286799431, 60.05176104605198, 60.49694895744324, 61.63499169051647, 59.43893373012543, 58.43311250209808, 59.61130768060684, 57.402136623859406, 52.10753113031387, 41.10793836414814, 38.90636309981346, 34.75458428263664, 49.13097225129604, 62.24432699382305, 59.52472932636738, 60.78906588256359, 60.9865602850914, 60.63264347612858, 60.952168330550194, 61.53673276305199, 58.01743380725384, 56.6920231282711, 53.79378944635391, 58.15255455672741, 57.26960353553295, 60.936836153268814, 60.600869581103325, 64.07691925764084, 55.43718606233597, 62.51639239490032, 60.700093656778336, 57.05795869231224, 52.483425959944725, 49.75320786237717, 47.37314097583294, 48.59099082648754, 54.659174010157585, 52.59456239640713, 49.89315815269947, 48.5804957896471, 46.44442521035671, 45.38576401770115, 51.901016011834145, 53.05293560028076, 52.42584764957428, 51.61076098680496, 52.654029205441475, 52.81027302145958, 52.356033995747566, 52.34226733446121, 56.0933006554842, 60.388289988040924, 60.24202823638916, 61.95189468562603, 62.69391126930714, 61.6675141453743, 63.88699784874916, 59.030436649918556, 58.49908456206322, 56.71745516359806, 61.16430714726448, 69.16778728365898, 74.72643300890923, 74.52350109815598, 70.69258466362953, 68.84962275624275, 85.06452307105064, 77.30795368552208, 79.14763256907463, 51.69759012758732, 0.48009227437432855, 0.6889869261067361, 0.07163875081459992, 0.3384722111513838, 26.0916780307889, 79.48737993836403, 62.790080308914185, 51.50173343718052, 26.189783066511154, 32.603808492422104, 53.80352832376957, 45.62184154987335, 1.069998003076762, 0.009363544577354332, 0.009222787921316922, 0.01321060435657273, 0.06280463305301964, 0.054816882766317576, 0.09031616616994143, 0.037349008562159725, 0.0520610101375496, 0.025475671754975338, 0.18990960874361917, 0.10229787323623896, 0.16412258933996782, 0.12089018651749939, 0.25294785504229367, 0.14725566550623626, 0.1925847542588599, 0.18665226321900263, 0.3353249409701675, 0.5793346068821847, 4.500477081164718, 83.59741419553757, 67.69624024629593, 47.01849080622196, 62.36906670033932, 65.74035599827766, 82.30188891291618, 76.89247637987137, 0.38020747946575284, 0.2738969027996063, 2.591850897297263, 1.6056395857594907, 67.5935697555542, 105.0008524954319, 92.17570468783379, 97.76967331767082, 87.02449589967728, 79.5128233730793, 68.56710031628609, 70.30639618635178, 69.54031929373741, 73.07327851653099, 78.55328366160393, 80.54431602358818, 79.57817986607552, 84.22468453645706, 81.49237275123596, 78.70337560772896, 70.46112388372421, 64.85812693834305, 65.58807536959648, 67.45677709579468, 60.25367081165314, 61.00239023566246, 61.7529259622097, 60.45393906533718, 57.43872866034508, 59.15389582514763, 59.656817838549614, 57.11410067975521, 56.65911689400673, 51.8607571721077, 52.84621149301529, 53.129805475473404, 59.44500580430031, 61.496333330869675, 52.50351548194885, 50.255172327160835, 48.90158236026764, 52.41490423679352, 50.10585553944111, 51.10115133225918, 50.22789739072323, 56.53001122176647, 53.95626112818718, 55.47546520829201, 62.280645444989204, 69.70423489809036, 67.6934663951397, 71.49456202983856, 64.90437805652618, 61.5214803814888, 61.235074549913406, 65.4996845126152, 66.28333926200867, 67.22128853201866, 68.93683567643166, 68.069669008255, 67.16757461428642, 66.84804975986481, 60.91491512954235, 52.22777187824249, 49.02456276118755, 46.72668546438217, 56.61454528570175, 59.643518552184105, 63.245113492012024, 63.32010626792908, 62.69093222916126, 59.747021198272705, 61.912316009402275, 60.111680030822754, 53.294914215803146, 42.8154793381691, 41.42150893807411, 37.79220208525658, 52.34697908163071, 63.63516256213188, 63.841955065727234, 63.03331285715103, 64.53151166439056, 62.473724484443665, 64.08681392669678, 65.1864293217659, 61.213799491524696, 59.689849466085434, 56.463351398706436, 61.27891279757023, 59.46896351873875, 64.75107908248901, 63.50288026034832, 67.63666704297066, 59.01500567793846, 63.9771594107151, 64.25318419933319, 60.23911379277706, 57.976209819316864, 52.146292850375175, 49.16154161095619, 49.38306212425232, 57.41631746292114, 57.146862521767616, 53.574377819895744, 51.884920075535774, 50.57030461728573, 47.24009491503239, 52.79902182519436, 54.17252652347088, 55.211303383111954, 54.58965674042702, 56.765317395329475, 56.075168028473854, 55.903991013765335, 54.5235250890255, 62.05360762774944, 62.94996052980423, 63.24613183736801, 66.10155701637268, 66.63446322083473, 65.85052728652954, 67.47330620884895, 62.23062112927437, 62.887237295508385, 62.1876036375761, 64.31769713759422, 73.04180100560188, 79.19387608766556, 78.86691883206367, 74.39945295453072, 77.28108152747154, 89.43922832608223, 73.7867434322834, 84.79424357414246, 53.14962901175022, 0.7637869217433035, 2.5734453974291682, 0.3456879348959774, 0.4289666115073487, 34.16789576411247, 87.39850983023643, 69.57292154431343, 62.5390999764204, 43.21075312793255, 33.35127018392086, 58.91918241977692, 61.24066025018692, 2.3653735499829054, 0.27377527963835746, 0.1351760988472961, 0.06954875905648805, 0.14545092562912032, 0.14624828909290954, 0.14493385649984702, 0.11071719723986462, 0.218004351190757, 0.15297518984880298], [0.0492589759232942, 0.07318350893910974, 0.026565213192952797, 0.05679324429365806, 0.07957098103361204, 0.03237884557165671, 0.11236595251830295, 0.031686792863183655, 0.14545723388437182, 0.2736579312477261, 7.417856985703111, 69.73803788423538, 45.87865076959133, 52.87768140435219, 50.47378979623318, 43.37865091860294, 82.1413779258728, 40.437962114810944, 0.36501565715298057, 0.5988801049534231, 1.6196345910429955, 5.4042514599859715, 88.05972754955292, 85.19584402441978, 88.41876268386841, 82.00881823897362, 78.31139624118805, 64.097118973732, 63.0601242184639, 63.365346640348434, 66.66623711585999, 69.39527347683907, 72.53981754183769, 74.22084733843803, 74.43742051720619, 72.55677223205566, 75.77174171805382, 73.65276262164116, 68.59990775585175, 64.6747487783432, 62.4801841378212, 60.758276134729385, 57.759568244218826, 54.23875316977501, 54.29675705730915, 56.17370434105396, 54.34499926865101, 52.80395396053791, 51.28849267959595, 51.89196489751339, 50.52728332579136, 44.27627295255661, 48.46690088510513, 48.683485463261604, 52.51055650413036, 52.339637875556946, 49.97348204255104, 50.41491195559502, 47.5274620950222, 50.84743894636631, 49.78437379002571, 47.45430842041969, 48.83929990231991, 49.61269900202751, 51.14153556525707, 49.20321777462959, 56.535194143652916, 58.671006336808205, 63.13556157052517, 63.450815454125404, 64.03078213334084, 56.50239050388336, 55.29723957180977, 55.86414635181427, 61.18956819176674, 61.337023079395294, 66.36415332555771, 60.41830837726593, 54.34924364089966, 62.09808424115181, 48.904641196131706, 49.52615484595299, 43.13360966742039, 51.4242821931839, 61.80560253560543, 61.7614983022213, 61.36474259197712, 59.365065693855286, 53.782139271497726, 63.751839101314545, 61.92491993308067, 62.8507212549448, 57.82490573823452, 42.96561688184738, 45.990953743457794, 47.7842865139246, 37.381896302103996, 50.50473153591156, 57.417708188295364, 59.61317338049412, 60.11141784489155, 57.81608261168003, 58.90437461435795, 58.47356133162975, 56.71874329447746, 53.70950236916542, 52.19968758523464, 53.680669516325, 58.448832258582115, 55.189978927373886, 60.3712897002697, 53.5270057618618, 54.962948709726334, 62.493635416030884, 53.80726732313633, 49.4345797598362, 43.19640129804611, 46.550253331661224, 46.82082161307335, 45.48583164811134, 48.2249640673399, 53.56949508190155, 45.45647822320461, 46.5885628759861, 45.84147356450558, 42.28230334818363, 48.54369096457958, 49.309672862291336, 47.517225444316864, 50.13917215168476, 49.25384245812893, 48.82861107587814, 48.11986170709133, 52.66033686697483, 54.517031237483025, 55.746447667479515, 53.918080776929855, 55.197772309184074, 57.53471530973911, 57.936456352472305, 56.58090949058533, 54.97484587132931, 53.90450410544872, 54.20643970370293, 64.43566560745239, 67.87197321653366, 74.21144664287567, 71.65123522281647, 67.94878229498863, 70.35092979669571, 63.75487893819809, 80.37261083722115, 79.73593980073929, 66.0862210392952, 4.905727710574865, 0.9987512324005365, 1.0006730980239809, 0.39314017456490546, 5.152136888355017, 66.37075737118721, 62.05972149968147, 46.61915123462677, 26.94806657731533, 21.06202472001314, 41.078923121094704, 38.62824082374573, 0.5571472411975265, 0.05232208284724038, 0.07486056972993538, 0.026264222215104382, 0.03108473298198078, 0.02806618645990966, 0.03783787236898206, 0.010126185734407045, 0.009192712386720814, 0.030709963248227723, 0.07038249517790973, 0.004328244676798931, 0.014828292405582033, 0.01782552630174905, 0.036068154440727085, 0.08736329415114596, 0.027281508155283518, 0.08950958523200825, 0.25740097858943045, 0.4125841171480715, 13.769545331597328, 80.68958982825279, 52.935852482914925, 50.11271797120571, 45.74905872344971, 54.34213422238827, 87.50188708305359, 44.01550054550171, 0.5212953337468207, 0.7534639444202185, 2.510394905693829, 10.57673530653119, 100.08928164839745, 85.46188294887543, 90.53449675440788, 84.83928635716438, 81.17078840732574, 68.90791162848473, 66.4172212779522, 66.96997001767159, 71.187082529068, 71.82349517941475, 74.47050914168358, 76.57254874706268, 78.49295809864998, 75.76090469956398, 78.19120869040489, 77.96244576573372, 72.30159312486649, 69.59841057658195, 63.549644351005554, 65.16157105565071, 60.37481591105461, 59.360802322626114, 55.83533249795437, 58.55917453765869, 56.96628861129284, 55.25900222361088, 55.170607566833496, 57.05212600529194, 51.088304221630096, 47.155842036008835, 49.73949059844017, 51.44285559654236, 54.96705248951912, 54.87332671880722, 50.062264278531075, 51.0745869576931, 48.75744469463825, 49.77648161351681, 47.416014075279236, 48.409884944558144, 49.59976069629192, 52.40051060914993, 52.332536056637764, 50.69087594747543, 56.61866046488285, 62.81039401888847, 64.40902143716812, 65.34599035978317, 64.39961314201355, 59.45449769496918, 55.455181896686554, 59.812149703502655, 62.7071687579155, 65.47372430562973, 68.55701565742493, 64.63583126664162, 55.52985928952694, 65.56267753243446, 52.01852470636368, 52.98574000597, 48.60062710940838, 52.46009901165962, 65.29566586017609, 65.48898428678513, 63.678932413458824, 62.05198131501675, 57.12860070168972, 64.32411879301071, 63.03957872092724, 66.1591163277626, 61.297816783189774, 45.22756710648537, 48.04012678563595, 50.86004287004471, 41.02281153202057, 54.53427471220493, 60.424350053071976, 60.53962826728821, 63.20783369243145, 59.06611293554306, 59.86928343772888, 61.10005259513855, 59.004966616630554, 56.76048785448074, 55.3653547167778, 56.64916902780533, 61.07491694390774, 58.635839223861694, 62.409393936395645, 55.094991624355316, 59.27787937223911, 63.05094011127949, 56.63327068090439, 51.03414572775364, 45.138974860310555, 48.44608560204506, 49.046635776758194, 46.898459047079086, 47.6849028468132, 55.31404986977577, 49.20064151287079, 49.67052809894085, 48.19783732295036, 45.26650741696358, 50.18601983785629, 51.512156277894974, 49.69408303499222, 52.015264481306076, 49.99271661043167, 51.15745671093464, 49.49279643595219, 55.92006795108318, 56.19690589606762, 58.27170476317406, 56.38407625257969, 56.508850157260895, 59.50304388999939, 60.42187258601189, 58.174787163734436, 57.11429066956043, 56.508378982543945, 57.067575976252556, 66.65786236524582, 71.91270679235458, 76.0995501279831, 72.83311620354652, 69.81730923056602, 73.9748865365982, 68.46676290035248, 82.75645092129707, 79.48003873229027, 73.0343534052372, 6.8193743750452995, 0.8377864665817469, 0.5835282756015658, 0.3042125963838771, 4.290015874430537, 70.47951489686966, 67.23854720592499, 56.52766294777393, 26.962389908730984, 27.84954160451889, 54.42762963473797, 53.92032265663147, 2.435716325417161, 0.09697779503767379, 0.11032397771487013, 0.03802138693572488, 0.019073735202255193, 0.026101766088686418, 0.04144801634538453, 0.04474543784453999, 0.005183516532270005, 0.049373841829947196, 0.13610400608740747, 0.12509207823313773, 0.09110886894632131, 0.1687975853565149, 0.16827828978421167, 0.1518401046632789, 0.2468422061065212, 0.19184492208296433, 0.3184915176825598, 0.5207977979443967, 15.155009888112545, 94.19744700193405, 58.30676928162575, 67.94538527727127, 66.66193574666977, 61.042413488030434, 95.60207962989807, 50.93676455318928, 0.43948477366939187, 1.6490351571701467, 4.434096068143845, 12.907579634338617, 102.00143784284592, 91.55441522598267, 94.86585393548012, 89.41009908914566, 86.1397285759449, 71.2693253159523, 68.71887177228928, 71.43952578306198, 74.01466280221939, 75.39954409003258, 78.71067121624947, 80.21148428320885, 83.57182636857033, 78.14780741930008, 81.62096545100212, 83.83319154381752, 73.45302253961563, 73.2489886879921, 69.17700558900833, 70.97984924912453, 63.488357439637184, 62.735173255205154, 59.16608177125454, 61.766905412077904, 59.9418443441391, 57.26912476122379, 57.98606649041176, 59.823742881417274, 55.833561792969704, 50.82709103822708, 55.76011933386326, 55.29066972434521, 56.8940506875515, 57.31594204902649, 50.39497062563896, 51.56485565006733, 50.368733033537865, 50.827224031090736, 48.272032141685486, 49.08765457570553, 49.8357318341732, 54.16639365255833, 55.9708446264267, 52.95126065611839, 61.630526930093765, 63.29745948314667, 68.53168621659279, 70.63596770167351, 68.63728255033493, 61.825722455978394, 59.33569326996803, 61.22869089245796, 68.62098902463913, 70.36831766366959, 73.4801834821701, 64.7515806555748, 60.78937366604805, 65.8185026049614, 57.19616487622261, 57.132841274142265, 50.38382962346077, 55.52593030035496, 66.4959454536438, 65.58999806642532, 65.76003894209862, 66.32925599813461, 58.163243383169174, 68.26117113232613, 67.0946717262268, 68.38926985859871, 60.61432085931301, 46.997766718268394, 49.3993404507637, 53.18198807537556, 43.8603662699461, 56.379964873194695, 62.70302698016167, 65.77021479606628, 63.48889701068401, 62.672909796237946, 62.23254382610321, 63.81828993558884, 62.06294372677803, 60.69347821176052, 57.850782349705696, 59.5405250787735, 65.40739506483078, 61.798789501190186, 64.27684932947159, 61.30143418908119, 63.43909688293934, 68.25450628995895, 59.13727171719074, 53.20942260324955, 47.62857846915722, 50.44515833258629, 48.886041194200516, 46.46997883915901, 48.70030716061592, 57.65909023582935, 52.272252291440964, 52.2659370303154, 51.8761083483696, 50.60597710311413, 53.891128823161125, 53.983380272984505, 51.750813871622086, 55.59764765202999, 53.368729054927826, 54.820182770490646, 52.22455345094204, 60.48211835324764, 59.879474490880966, 62.67427012324333, 59.213499426841736, 60.067853182554245, 63.34625266492367, 65.1674835383892, 60.49041710793972, 59.76779468357563, 59.84013520181179, 59.43164952099323, 70.98710685968399, 73.494843095541, 79.58096891641617, 76.9964312016964, 71.56381711363792, 74.23531696200371, 73.59429895877838, 87.58743569254875, 76.59917771816254, 74.86411482095718, 6.550943003967404, 2.016859338618815, 2.2263314109295607, 0.38526515651028603, 8.05200258269906, 81.42501756548882, 73.53307664394379, 65.89557006955147, 41.14007703959942, 34.381934478878975, 56.94795839488506, 69.97751623392105, 3.0149133084341884, 0.15118089941097423, 0.1707983115920797, 0.1339034640113823, 0.12563687399961054, 0.15271007985575125, 0.12555231369333342, 0.11702558607794344, 0.17990348394960165, 0.11097319365944713], [0.0627119981800206, 0.03573771689843852, 0.0774158287094906, 0.02286092407302931, 0.04951454931870103, 0.07217501930426806, 0.07665553552214988, 0.01618986250832677, 0.0671271831379272, 0.431378353969194, 15.815651938319206, 68.77613469958305, 42.62360103428364, 44.660572931170464, 51.233000457286835, 49.33908328413963, 87.13000103831291, 21.04663174599409, 0.596707274671644, 0.7139591267332435, 2.345050578005612, 29.05159380286932, 97.192712277174, 83.58010992407799, 84.64226692914963, 75.723537504673, 71.3096259534359, 63.60432721674442, 66.10931620001793, 66.89506083726883, 67.99314871430397, 72.2052150964737, 73.55599701404572, 74.32884514331818, 75.67347899079323, 75.6890657544136, 75.50771668553352, 72.80190467834473, 72.13429570198059, 70.19726604223251, 65.84671229124069, 60.358355194330215, 57.52775028347969, 54.904253259301186, 54.43410448729992, 51.94678835570812, 51.15256257355213, 52.02140115201473, 54.609685465693474, 51.62624895572662, 46.93060912191868, 45.54428771138191, 47.16818757355213, 46.79040804505348, 51.33301109075546, 51.499259769916534, 48.88994358479977, 49.84154932200909, 48.779434114694595, 47.99389846622944, 49.74944606423378, 47.50915087759495, 48.01363080739975, 46.70803226530552, 49.11861911416054, 47.76742301881313, 50.48981733620167, 57.45156817138195, 59.48416270315647, 61.20421260595322, 59.20813791453838, 56.743449568748474, 54.63850311934948, 53.03218491375446, 56.560344994068146, 61.24444104731083, 59.5695973187685, 68.99273067712784, 56.85718886554241, 57.263174280524254, 52.91330449283123, 48.2891084253788, 45.70837050676346, 53.27244982123375, 62.37309068441391, 60.36185100674629, 56.72559812664986, 54.66473691165447, 54.1394454985857, 58.17807778716087, 56.31522014737129, 60.459319576621056, 58.74725304543972, 46.42273597419262, 40.92035382986069, 45.20328640937805, 49.38022367656231, 43.81778575479984, 59.69807982444763, 58.037789314985275, 59.11132670938969, 57.72346258163452, 60.696252062916756, 56.77095629274845, 57.31085032224655, 56.95314131677151, 55.04948906600475, 54.25866410136223, 57.0743016153574, 58.719704523682594, 56.40576928853989, 53.219701051712036, 59.93592046201229, 57.317602559924126, 52.19149902462959, 45.2899369597435, 45.35932503640652, 47.7645655721426, 45.90947471559048, 44.98090714216232, 45.731503665447235, 50.81788793206215, 50.12983225286007, 45.53720489144325, 47.34776973724365, 43.43009255826473, 42.59316846728325, 49.53238271176815, 46.62922449409962, 49.1445679217577, 49.13243517279625, 50.27465768158436, 45.56881159543991, 51.288215294480324, 50.265169590711594, 52.02671706676483, 51.79978184401989, 53.99380311369896, 53.84061433374882, 53.250065222382545, 51.808103397488594, 53.3389538526535, 55.72295732796192, 62.63232037425041, 66.61001533269882, 73.47763001918793, 69.92133244872093, 69.27178770303726, 68.00811231136322, 79.47576016187668, 70.60271948575974, 66.99091449379921, 67.82546371221542, 90.07904559373856, 18.361420333385468, 0.29541407944634557, 0.4046312626451254, 0.08550825150450692, 0.1005036050628405, 37.36185997724533, 74.10532593727112, 51.62953197956085, 36.65078513324261, 29.29598528891802, 38.31781268119812, 47.31568045914173, 4.043252840638161, 0.1555780353373848, 0.012796905266441172, 0.027621103799901903, 0.048600293885101564, 0.01800235597329447, 0.01831391142331995, 0.13234731392003596, 0.10253389846184291, 0.02062488507363014, 0.02405443668976659, 0.023784187324054074, 0.05780635379778687, 0.04808142133697402, 0.033899339177878574, 0.056973816244862974, 0.08613739235443063, 0.02611703021102585, 0.10682815045583993, 0.47531094343867153, 23.207685984671116, 75.84552615880966, 55.559577494859695, 40.860248655080795, 48.79386194050312, 60.31798616051674, 90.92084482312202, 22.833311073482037, 0.8375389454886317, 0.11102848366135731, 3.6092505790293217, 40.731834545731544, 100.64149841666222, 86.94510295987129, 87.0639605820179, 79.82132881879807, 72.11135253310204, 66.47506177425385, 68.73648762702942, 68.21464642882347, 71.08926817774773, 75.65172895789146, 75.43482139706612, 77.52179861068726, 77.94217005372047, 78.25822949409485, 76.83311596512794, 76.19120121002197, 76.2581916153431, 72.89005994796753, 69.0055587887764, 64.12841409444809, 58.732532635331154, 57.716356962919235, 56.880876794457436, 54.93399426341057, 55.22879384458065, 54.247135519981384, 57.046840488910675, 55.03389470279217, 48.68347406387329, 49.81431618332863, 51.420539394021034, 51.16420894861221, 52.70273879170418, 52.699820548295975, 48.82070370018482, 50.155237689614296, 47.479485869407654, 47.70383723080158, 50.69166250526905, 49.93856951594353, 48.31872783601284, 47.69118390977383, 50.921318382024765, 49.283834248781204, 52.92940802872181, 62.38400749862194, 62.50010646879673, 63.47125455737114, 63.50992888212204, 59.45459268987179, 57.31434613466263, 56.07875503599644, 58.461686968803406, 64.50457111001015, 62.31796324253082, 70.22671446204185, 61.37320853769779, 59.34542074799538, 57.41339921951294, 51.80223271250725, 47.48894736170769, 55.7046765089035, 63.05422693490982, 60.3501096367836, 57.12656021118164, 56.38061843812466, 56.676409766077995, 58.40201877057552, 56.2528882920742, 60.504715740680695, 58.1250174343586, 46.534776762127876, 44.5064228028059, 48.57497848570347, 52.095698565244675, 46.01339913904667, 61.0493291169405, 60.140398889780045, 62.71490894258022, 61.411867663264275, 61.39280788600445, 58.12488064169884, 60.72044536471367, 59.972926676273346, 58.26604686677456, 58.28081667423248, 60.662859454751015, 62.85154581069946, 57.69826993346214, 57.8873173892498, 62.08824276924133, 60.942934826016426, 51.29227727651596, 46.88078999519348, 47.9657381772995, 48.14515694975853, 43.21502409875393, 46.511844992637634, 45.61864972114563, 52.59850658476353, 53.75782057642937, 48.54054093360901, 49.47602033615112, 46.92089304327965, 44.093821942806244, 52.746820226311684, 47.53100350499153, 50.65323896706104, 50.800956040620804, 53.440313413739204, 48.89875531196594, 55.20727179944515, 53.18554848432541, 54.10922572016716, 54.79343220591545, 56.54662013053894, 55.18533177673817, 56.35307751595974, 53.651384487748146, 58.931212574243546, 59.16489243507385, 64.88966524600983, 69.68167930841446, 75.90805560350418, 69.23223942518234, 71.91010013222694, 70.60936912894249, 81.28337636590004, 71.34912103414536, 72.75176256895065, 69.8804922401905, 95.42727380990982, 23.412141613662243, 0.21170722815440968, 0.30775599530898035, 0.09785799702513032, 0.14964118046918884, 41.50841787457466, 80.23517221212387, 62.14617446064949, 39.38501201570034, 24.46923729032278, 50.06902031600475, 60.69622926414013, 7.926655858755112, 0.4482652712613344, 0.12236061855219305, 0.05817167228087783, 0.05342809439753182, 0.016812448338896502, 0.05699003588233609, 0.08101894083665684, 0.11170853584189899, 0.03354520486027468, 0.1775256873224862, 0.10516059657675214, 0.19615662196883932, 0.14738594210939482, 0.20127476920606568, 0.18938771565444767, 0.1823171114665456, 0.13380156713537872, 0.29845109616871923, 0.6363893765956163, 27.071345262229443, 93.4517066180706, 55.54657079279423, 58.89783136546612, 70.47947689890862, 66.67941480875015, 99.88093882799149, 26.68805032968521, 0.6991343409754336, 1.1910623568110168, 4.869659570977092, 49.413046315312386, 103.40037077665329, 93.3017286658287, 91.1887076497078, 83.7716880440712, 80.05487188696861, 71.5064325928688, 71.67654186487198, 71.38359278440475, 74.50764074921608, 80.35387024283409, 80.19495517015457, 79.1485521197319, 80.10705828666687, 82.57302716374397, 81.28426551818848, 78.08938175439835, 79.64931204915047, 78.23042258620262, 72.84674227237701, 68.54467391967773, 61.687748059630394, 61.669630631804466, 59.86155465245247, 58.231331929564476, 55.96669524908066, 58.836590051651, 60.45715369284153, 57.34251782298088, 51.64131134748459, 53.66406820714474, 53.88331264257431, 53.393287137150764, 56.54024787247181, 55.2483855932951, 49.1576012223959, 49.55451272428036, 47.96902120113373, 48.910394087433815, 50.21177865564823, 48.51684920489788, 51.91303476691246, 48.2689543068409, 53.43238703906536, 52.30969928205013, 56.209525018930435, 63.62927287817001, 64.32549431920052, 64.09805372357368, 67.83804103732109, 62.89243161678314, 59.50395964086056, 58.03650498390198, 62.69061304628849, 67.51467078924179, 64.35236647725105, 72.46543273329735, 64.33164238929749, 62.608123272657394, 62.61693499982357, 54.40048389136791, 49.65191289782524, 57.826737239956856, 64.64587792754173, 64.54829156398773, 58.48136231303215, 57.90045328438282, 58.793519362807274, 59.84143853187561, 59.87780258059502, 61.81067906320095, 61.10797517001629, 47.464438676834106, 46.01389691233635, 53.03439639508724, 54.020656272768974, 48.851140066981316, 63.52392353117466, 64.22586366534233, 63.94939810037613, 62.08564750850201, 67.24763631820679, 61.81333512067795, 62.34740026295185, 62.60897062718868, 61.58207952976227, 61.687516272068024, 63.93769472837448, 65.50917640328407, 62.47019827365875, 59.57238256931305, 65.41010811924934, 64.18611779808998, 55.21056242287159, 51.54934108257294, 50.00672645866871, 48.82674917578697, 43.82820099592209, 46.56485214829445, 46.893587708473206, 55.76781392097473, 56.00825361907482, 50.89131519198418, 54.07935932278633, 49.38276194036007, 46.03687807917595, 55.26211425662041, 49.12776902318001, 53.17797549068928, 52.70129106938839, 55.455269291996956, 50.651285871863365, 58.7882262468338, 57.02759072184563, 60.854608565568924, 57.757835537195206, 60.896626710891724, 58.864678144454956, 59.96867470443249, 57.317249178886414, 60.58144502341747, 61.56472586095333, 67.82465055584908, 72.78878778219223, 78.90203654766083, 74.87957999110222, 74.092186242342, 71.78580120205879, 85.33170193433762, 72.20481231808662, 78.36146995425224, 73.19145977497101, 93.83867025375366, 24.815351217985153, 0.3999721782747656, 1.4883606601506472, 0.16107994713820517, 0.5447280826047063, 51.973546519875526, 86.3659380376339, 69.55357298254967, 55.7622130215168, 43.420680463314056, 53.76152537763119, 73.30698117613792, 8.90335164964199, 0.6658363121096045, 0.2766601857729256, 0.24244511470897123, 0.16439121711300686, 0.1525446551386267, 0.18489234906155616, 0.24368156242417172, 0.33337172702886164, 0.05995156505377963], [0.037621213487000205, 0.01771527840901399, 0.07243477099109441, 0.016138617211254314, 0.05325222395185847, 0.054672906117048115, 0.037769654154544696, 0.017902295912790578, 0.10714352611103095, 0.1767552935052663, 27.529492378234863, 57.32922613620758, 35.1737891882658, 54.634425938129425, 49.16569098830223, 49.30992364883423, 89.91490200161934, 10.464232843369246, 0.2561702305683866, 0.716279020998627, 3.2939218869432807, 46.07484184205532, 93.30159947276115, 79.56863477826118, 86.85570135712624, 73.56718361377716, 66.8133120238781, 65.40193095803261, 66.60289451479912, 68.7365560233593, 74.51042219996452, 73.2347546517849, 77.42275312542915, 76.45253598690033, 76.81354701519012, 74.37378913164139, 74.45279449224472, 75.8819130063057, 74.75961282849312, 70.98921194672585, 66.1035405099392, 61.372361183166504, 58.24291370809078, 55.97889259457588, 52.05273047089577, 51.93975493311882, 51.03001154959202, 50.454958006739616, 53.21292221546173, 51.35795295238495, 46.81680902838707, 45.74604548513889, 47.683208137750626, 47.28728458285332, 51.1650563031435, 50.52995838224888, 51.178598776459694, 48.06939281523228, 48.725416213274, 48.87991592288017, 48.606771379709244, 48.886238783597946, 45.95687337219715, 47.111593410372734, 46.84440694749355, 48.62314850091934, 47.82165750861168, 52.30361960828304, 58.17400440573692, 59.02122214436531, 60.12539729475975, 55.17296724021435, 54.56822209060192, 49.34807360172272, 53.46413813531399, 57.53973104059696, 59.62548851966858, 63.3879554271698, 60.683860927820206, 51.540069580078125, 49.12009723484516, 45.6169930100441, 41.69954761862755, 48.44880245625973, 60.774182081222534, 56.36969022452831, 55.34112721681595, 59.273551404476166, 51.93321168422699, 52.553289011120796, 55.762114226818085, 58.17680865526199, 54.91505987942219, 43.83980177342892, 40.52204020321369, 41.46500140428543, 55.794032514095306, 45.647809356451035, 53.219332471489906, 60.59138149023056, 58.82224582135677, 59.93193447589874, 56.96399353444576, 59.80562165379524, 55.546320006251335, 55.15654072165489, 54.40195061266422, 54.76871073246002, 58.16537506878376, 57.8939214348793, 50.91178849339485, 60.159409269690514, 60.5916702747345, 54.878904819488525, 44.31045211851597, 43.200220093131065, 48.318655639886856, 45.20819194614887, 43.07064704596996, 44.92366321384907, 42.29314036667347, 50.721722692251205, 50.24786911904812, 45.88679753243923, 47.21239060163498, 43.93610380589962, 41.58882915973663, 45.529643297195435, 49.22488421201706, 48.2042133808136, 47.829637080430984, 50.13061501085758, 47.208674401044846, 47.507338374853134, 49.0631040930748, 49.276922419667244, 49.61768813431263, 49.65930350124836, 48.35774414241314, 51.61771081387997, 52.256654128432274, 57.613659873604774, 59.35224898159504, 65.84390804171562, 68.63338395953178, 70.513766258955, 68.9827448129654, 71.58932134509087, 72.40979611873627, 74.24530282616615, 68.88479366898537, 78.658986389637, 59.61288079619408, 76.82665631175041, 44.58439461886883, 0.02778460820991313, 0.19887585105607286, 0.03443643516220618, 0.10877625842113048, 20.289258286356926, 74.11946877837181, 53.47388841211796, 47.13829457759857, 31.651558689773083, 27.543036751449108, 54.44255903363228, 8.972783423960209, 0.14507231157040223, 0.12904830422485247, 0.05303370227920823, 0.036285447858972475, 0.025476447299297433, 0.02403566406428581, 0.024589729255239945, 0.04188119310128968, 0.08206088648876175, 0.01568346175190527, 0.040947070374386385, 0.07232065836433321, 0.08193066925741732, 0.09586436572135426, 0.01633635318285087, 0.0007900734283339261, 0.014995107721915701, 0.1374440427753143, 0.2202300075441599, 41.254390105605125, 64.05521482229233, 44.91522766649723, 51.26103535294533, 50.96052847802639, 58.89595426619053, 95.83142772316933, 11.350968461483717, 0.4128473124001175, 0.3669414413161576, 4.672335209324956, 57.89850398898125, 94.14795845746994, 85.28853625059128, 86.67496785521507, 75.88450446724892, 68.86770218610764, 69.64008674025536, 69.66760486364365, 73.42029869556427, 76.2986746430397, 75.4895992577076, 76.36865168809891, 78.80203351378441, 79.1512043774128, 78.93328607082367, 74.67565253376961, 76.14942625164986, 77.4567461013794, 73.52318957448006, 69.28973034024239, 63.46576005220413, 60.55287055671215, 59.27960827946663, 55.445355623960495, 53.72416578233242, 54.49132561683655, 54.930107071995735, 55.662589967250824, 54.473512172698975, 48.875834941864014, 48.71048301458359, 49.50869478285313, 51.01577751338482, 52.490748167037964, 52.74444155395031, 49.745376482605934, 49.201196283102036, 49.13717731833458, 49.573067128658295, 48.48012417554855, 50.85712842643261, 46.47518076002598, 47.78835229575634, 51.02427385747433, 51.35174408555031, 50.35025082528591, 54.99143198132515, 60.54239831864834, 62.949785739183426, 62.25794166326523, 58.65487240254879, 56.33250541985035, 55.10343857109547, 56.705307215452194, 61.54299482703209, 63.2616426050663, 64.51806038618088, 64.1303063929081, 57.611379995942116, 53.10507260262966, 51.01128615438938, 46.30441032350063, 48.52224871516228, 60.794453993439674, 57.062267661094666, 56.383677273988724, 62.2688090801239, 54.20187994837761, 54.46057006716728, 54.272886738181114, 59.236351400613785, 56.28526635468006, 44.94141586124897, 41.942882761359215, 47.05298915505409, 58.64175170660019, 48.10566946864128, 56.7973268777132, 60.92792943120003, 59.564969167113304, 61.598825231194496, 60.61444245278835, 61.54604606330395, 57.53558166325092, 57.66781836748123, 56.806727573275566, 59.101549834012985, 59.42848429083824, 57.627312541007996, 54.58365686237812, 62.40572713315487, 62.70417831838131, 56.75318844616413, 45.087677612900734, 46.80436089634895, 49.03827242553234, 46.495441272854805, 43.90558384358883, 46.634521409869194, 43.10716308653355, 52.45414853096008, 54.24639455974102, 49.62281405925751, 49.50267590582371, 46.47624470293522, 43.73846121132374, 49.13972698152065, 51.6018770635128, 50.348229333758354, 49.40083757042885, 51.60628482699394, 51.3069748878479, 50.58634355664253, 51.848434433341026, 53.12038578093052, 52.79201500117779, 52.670296132564545, 50.76042741537094, 54.47893068194389, 55.119842290878296, 60.80428786575794, 63.20818707346916, 68.25338155031204, 68.40698450803757, 72.2518689930439, 70.24385154247284, 74.84161242842674, 72.00355231761932, 76.32661834359169, 72.90603429079056, 78.98955345153809, 62.54352293908596, 81.05251595377922, 52.57439687848091, 0.11722983254003339, 0.40358575468417257, 0.11940040669287555, 0.2155115216737613, 23.20885442197323, 82.34793484210968, 61.73338361084461, 53.3134800195694, 23.801977895200253, 35.79549662768841, 64.14988294243813, 16.53500083833933, 0.21223231247859076, 0.12995011755265296, 0.1160158273705747, 0.029416052893793676, 0.06679016645648517, 0.02846792955097044, 0.08945889654569328, 0.0524448229407426, 0.11410738719860092, 0.11807435206719674, 0.1835772633785382, 0.3029539139242843, 0.09713160514365882, 0.21171932516153902, 0.16288805636577308, 0.13351802219403908, 0.09478475607465953, 0.24477688333718106, 0.3699449129635468, 47.013665065169334, 76.96269661188126, 47.00539290904999, 69.50991332530975, 69.50824901461601, 63.4542428702116, 107.03107595443726, 13.055428750813007, 0.37771920673549175, 0.8742151118349284, 5.763418162241578, 68.5931821167469, 95.03629758954048, 90.01335471868515, 90.80818086862564, 81.14602893590927, 72.07492768764496, 73.34162771701813, 71.12863406538963, 77.16717883944511, 79.9576123058796, 77.4979130923748, 79.69174057245255, 81.8958730995655, 81.89911052584648, 82.65367403626442, 78.84336769580841, 80.89384406805038, 80.35519257187843, 76.6890200972557, 71.97620898485184, 66.97382301092148, 64.12484988570213, 63.0159667879343, 58.20149213075638, 58.108123540878296, 56.35088123381138, 55.91401107609272, 57.29655168950558, 57.576547265052795, 51.85451790690422, 51.008280515670776, 52.64330618083477, 53.549629747867584, 56.01761631667614, 54.401437640190125, 51.46322250366211, 48.73042054474354, 50.041779577732086, 50.227209627628326, 48.70025776326656, 51.494878605008125, 48.578516095876694, 50.14562800526619, 52.271568328142166, 54.48960430920124, 51.02063365280628, 58.49721126258373, 62.52711161971092, 65.00951081514359, 65.00812768936157, 61.20543994009495, 58.857998102903366, 56.7487046867609, 58.20354402065277, 64.73653346300125, 63.3616304397583, 66.33231863379478, 68.51346239447594, 59.39126528799534, 58.295901864767075, 54.894339591264725, 48.89767237007618, 50.87477087974548, 63.87697398662567, 59.674072712659836, 58.98263141512871, 66.17696776986122, 56.02023437619209, 54.716284945607185, 57.34358936548233, 61.50195322930813, 57.7174437046051, 44.299326315522194, 47.06348039209843, 50.0620286911726, 61.15941300988197, 48.27754184603691, 58.94225098192692, 66.49678140878677, 62.2469412535429, 65.85461586713791, 64.49194058775902, 64.28352937102318, 59.28613632917404, 60.88157191872597, 60.107899233698845, 61.37918941676617, 62.897280156612396, 61.67314164340496, 56.726240292191505, 65.39702922105789, 65.57046711444855, 61.95705480873585, 48.15971776843071, 48.13564985990524, 51.70851454138756, 46.48103624582291, 44.15581941604614, 47.50678740441799, 42.87527672946453, 52.12241493165493, 56.47825799882412, 51.79206445813179, 52.41804666817188, 49.09014344215393, 48.54627102613449, 51.31390951573849, 55.78744366765022, 53.564756736159325, 54.42773602902889, 55.13979122042656, 52.69880600273609, 53.18618305027485, 55.745547115802765, 56.39970861375332, 56.20957061648369, 56.295491605997086, 52.488168105483055, 57.482160329818726, 57.19879433512688, 63.73030945658684, 64.51409339904785, 71.08535438776016, 72.14741259813309, 73.80297616124153, 74.31148007512093, 78.40510681271553, 76.2940388917923, 79.34006944298744, 77.05788150429726, 80.73104560375214, 67.1342808008194, 87.63105735182762, 50.281558111310005, 0.31025902193505317, 1.4050945406779647, 0.3279807366197929, 0.24585902370745316, 29.45283517241478, 86.93728297948837, 69.96592685580254, 63.84478211402893, 49.09803941845894, 39.49116311967373, 78.90506878495216, 19.658345840871334, 0.4218625364592299, 0.3839055716525763, 0.1809829822741449, 0.12273133615963161, 0.18294357316335663, 0.14487867039861158, 0.2415042940992862, 0.1697908906498924, 0.17452212661737576], [0.03403183109185193, 0.07600204480695538, 0.018048231831926387, 0.011566004177439027, 0.01781465940439375, 0.035919635847676545, 0.020739049650728703, 0.14333550789160654, 0.037836016999790445, 0.2154370694188401, 42.04507827758789, 63.37701581418514, 28.110177218914032, 36.58083088696003, 49.4138290733099, 59.907201603055, 83.15840095281601, 3.695078236050904, 0.09551250608637929, 1.3265033578500152, 5.118772778660059, 51.39346204698086, 90.12971207499504, 84.32155653834343, 83.01194921135902, 74.0608075261116, 65.90677186846733, 65.8926822245121, 70.48866480588913, 72.09300711750984, 75.11693805456161, 75.5197012424469, 77.59556785225868, 75.45421555638313, 73.48177939653397, 73.49077731370926, 74.38021838665009, 71.14814981818199, 75.10917127132416, 72.28150740265846, 64.61110979318619, 59.723466262221336, 56.274018958210945, 52.14161530137062, 52.52981387078762, 52.79594399034977, 51.90828122198582, 53.56620065867901, 51.876191943883896, 50.64031966030598, 47.526470348238945, 44.511366337537766, 48.77447538077831, 49.18462157249451, 51.552631705999374, 55.90709924697876, 50.716714560985565, 48.40515799820423, 46.35141000151634, 46.331020295619965, 46.75549551844597, 48.45902010798454, 46.250164434313774, 46.30261681973934, 48.07819314301014, 48.13483290374279, 48.40239554643631, 50.12555368244648, 54.87134702503681, 57.813247963786125, 59.81196731328964, 57.79543071985245, 54.70821797847748, 51.40691712498665, 54.084386453032494, 57.73559533059597, 62.04160787165165, 62.5693691521883, 64.4884979724884, 55.98458468914032, 51.22780613601208, 45.25011129677296, 48.37727129459381, 50.17641395330429, 53.955596163868904, 51.29066236317158, 50.420440658926964, 48.84870819747448, 48.73753376305103, 49.124079421162605, 52.382503375411034, 51.350566148757935, 53.48227076232433, 41.26823276281357, 37.46980458498001, 45.23871950805187, 58.91080766916275, 47.40955822169781, 52.23102070391178, 61.27584636211395, 59.341981932520866, 63.91165092587471, 58.70409116148949, 50.8993973582983, 50.914235562086105, 55.354570895433426, 59.7762606292963, 59.08323481678963, 58.2044293731451, 55.86276322603226, 58.429221510887146, 58.93663488328457, 55.90282827615738, 44.50567424297333, 46.41983672976494, 46.07960678637028, 45.48835851252079, 44.99072961509228, 43.18735398352146, 46.123080253601074, 44.999355152249336, 46.363348960876465, 51.50329515337944, 44.1925710439682, 44.79857012629509, 44.337898045778275, 40.2495264261961, 43.93601641058922, 50.043364092707634, 47.92875096201897, 48.713370859622955, 49.185795709490776, 49.98059906065464, 47.202826514840126, 46.55731335282326, 48.1728308647871, 49.60590496659279, 50.58424226939678, 51.923928782343864, 53.56274664402008, 54.89060439169407, 57.749259397387505, 64.2337216436863, 68.11761483550072, 70.51280871033669, 68.75625416636467, 68.66465628147125, 70.44581070542336, 71.49492681026459, 71.72397091984749, 74.13324683904648, 69.41627115011215, 75.72223797440529, 59.69354286789894, 60.045175999403, 4.675741251558065, 1.0930823581293225, 0.5964653939008713, 0.7042293925769627, 12.519962433725595, 72.11417198181152, 59.50203314423561, 52.17713579535484, 41.725834608078, 40.569001883268356, 53.094330579042435, 18.93966380506754, 0.3137434646487236, 0.09099186194362119, 0.04724773345515132, 0.09561419516103342, 0.06376876452122815, 0.0309265516261803, 0.022405679555959068, 0.05081191622593906, 0.06831144302850589, 0.031001441748230718, 0.1355883025098592, 0.051278367172926664, 0.04782510208315216, 0.011732733219105285, 0.1017967305961065, 0.053073232775204815, 0.051625740525196306, 0.04666015287511982, 0.24600558303063735, 52.245292738080025, 70.55197700858116, 35.9422143548727, 38.84195655584335, 58.69546942412853, 68.25414150953293, 89.6382388472557, 3.0284579191356897, 0.12327861812082119, 1.6426817793399096, 7.598053766414523, 63.064710572361946, 89.13567781448364, 89.7301635146141, 83.7150102853775, 77.85238087177277, 67.30191260576248, 68.76738756895065, 73.45140382647514, 75.69715932011604, 76.80082529783249, 79.58568066358566, 80.5894424021244, 77.18797892332077, 76.41353487968445, 78.49153697490692, 75.68354085087776, 74.37764212489128, 74.99839201569557, 72.38231599330902, 67.65285417437553, 62.96858713030815, 57.797949984669685, 55.3860218077898, 55.419475212693214, 56.557943522930145, 54.257451966404915, 55.72915479540825, 54.24683913588524, 53.53936269879341, 49.24614027142525, 49.05352100729942, 50.18445812165737, 53.78429755568504, 53.772138208150864, 57.24832087755203, 51.49493560194969, 47.29897655546665, 47.98906892538071, 46.58412091434002, 46.7850199341774, 47.637827172875404, 45.343149304389954, 48.29917408525944, 48.72377470135689, 49.69168156385422, 51.566960737109184, 51.019014939665794, 56.230731680989265, 61.69593282043934, 62.81952112913132, 59.31124918162823, 57.86728486418724, 53.03409621119499, 55.008090287446976, 59.5394117385149, 61.864484176039696, 66.01546123623848, 65.21936595439911, 60.82780100405216, 55.187851041555405, 49.40711863338947, 51.99426680803299, 50.88005639612675, 56.57539218664169, 50.9890953451395, 48.7323622405529, 49.62355501949787, 50.58116443455219, 48.383765146136284, 50.089645609259605, 49.35092344880104, 51.984588727355, 42.084706351161, 40.191359147429466, 45.928397700190544, 60.742411985993385, 50.37211865186691, 55.770853757858276, 61.900430247187614, 60.681869834661484, 65.54483368992805, 59.21913452446461, 52.14427515864372, 53.55751432478428, 58.037124350667, 60.7606890052557, 61.86012960970402, 59.44811783730984, 60.67817263305187, 61.168023347854614, 60.187493562698364, 57.12693639099598, 48.291669487953186, 48.109693452715874, 48.076927810907364, 46.37361600995064, 43.94643925130367, 42.08291284739971, 45.61705760657787, 45.65440960228443, 48.078318536281586, 52.78597712516785, 49.25472781062126, 46.766967102885246, 47.949904426932335, 42.58860871195793, 46.16938456892967, 51.17177054286003, 51.21329851448536, 49.99885328114033, 52.82566599547863, 52.445158213377, 49.85140599310398, 50.25550290942192, 50.35034202039242, 51.835321336984634, 54.04310926795006, 55.118443965911865, 56.1164528131485, 58.09596039354801, 60.5346505343914, 66.06099039316177, 69.35996577143669, 69.9187333881855, 69.35078546404839, 71.22871309518814, 71.74312189221382, 76.0356755554676, 73.54920297861099, 76.57974556088448, 74.23626691102982, 78.0901949107647, 64.04418781399727, 66.70752570033073, 7.542009148746729, 1.7847585305571556, 0.6900372728705406, 0.813576125074178, 12.450335919857025, 78.65228354930878, 66.87353119254112, 59.620278999209404, 38.39561350643635, 46.83565601706505, 65.15134960412979, 28.901815339922905, 0.30104196339379996, 0.1331851541181095, 0.02023630582698388, 0.07264766347361729, 0.019202412477170583, 0.12829074956243858, 0.013032848855800694, 0.03666463337140158, 0.05862527665158268, 0.20696223276900128, 0.18291430285898969, 0.14130111783742905, 0.10239626717520878, 0.08849738485878333, 0.16467209032271057, 0.18649173667654395, 0.16881118150195107, 0.17089434550143778, 0.4748225212097168, 61.91690996289253, 80.43419793248177, 37.187384739518166, 51.69602461159229, 70.09389638900757, 74.47025075554848, 98.34245458245277, 4.7821516916155815, 0.1871625194326043, 4.198589930310845, 10.008651539683342, 70.02504408359528, 94.98576790094376, 94.32996869087219, 87.09822714328766, 82.22710892558098, 72.16185182332993, 70.77190920710564, 76.80232241749763, 80.39367690682411, 78.49062502384186, 79.74626764655113, 84.10379022359848, 80.0708158314228, 78.81527200341225, 80.85899233818054, 78.70165050029755, 78.3666680753231, 81.32648885250092, 79.76677134633064, 69.58163067698479, 65.4387965798378, 60.76961852610111, 56.95475623011589, 57.54617929458618, 58.184039667248726, 58.5710147023201, 57.58114121854305, 56.28318406641483, 56.684092953801155, 52.13673256337643, 51.73620745539665, 54.20004844665527, 57.20673210918903, 55.29347397387028, 58.83369840681553, 53.64519841969013, 47.88361318409443, 48.2967422157526, 46.827695444226265, 47.94106990098953, 49.82200317084789, 46.68839491903782, 49.68209847807884, 51.08664371073246, 52.15379744768143, 54.01706166565418, 53.44866916537285, 58.75103384256363, 64.19821634888649, 67.10388243198395, 60.922070145606995, 60.12980505824089, 56.017080545425415, 59.28509898483753, 63.53211209177971, 68.29181268811226, 67.18174785375595, 69.50365126132965, 63.94372120499611, 61.091491654515266, 55.614887326955795, 50.20776227116585, 52.09636352956295, 57.98904933035374, 53.770116716623306, 50.92854559421539, 52.25807525217533, 53.58028270304203, 50.72921209037304, 52.227817475795746, 52.08331122994423, 51.14278569817543, 40.24677537381649, 42.4591838568449, 52.44844503700733, 62.89403893053532, 52.6664013415575, 57.72938646376133, 65.74943751096725, 62.029478922486305, 68.6881086230278, 61.425759717822075, 55.95864348113537, 55.96015579998493, 59.63319070637226, 65.15252754092216, 62.488019317388535, 62.569768130779266, 60.416435077786446, 62.92980261147022, 64.36188116669655, 60.02448990941048, 51.39484517276287, 51.93147137761116, 51.60060793161392, 46.50026701390743, 43.88405039906502, 43.327836245298386, 46.48620396852493, 46.82799182832241, 49.52274642884731, 55.59550456702709, 51.368094608187675, 49.714316949248314, 51.58260069787502, 46.78934410214424, 49.23548944294453, 56.08750596642494, 53.669235929846764, 53.45726430416107, 55.11289246380329, 54.180464297533035, 52.88216136395931, 52.07827270030975, 53.15469413995743, 56.11907087266445, 57.84042030572891, 58.72302934527397, 58.32536928355694, 61.52265451848507, 64.34877946972847, 70.43020874261856, 73.21607485413551, 73.21973025798798, 72.14868173003197, 74.869784116745, 76.81543171405792, 78.80924552679062, 77.23918497562408, 79.55129250884056, 80.50174310803413, 78.35507869720459, 68.61858755350113, 70.36111325025558, 7.532587554305792, 2.217064183205366, 2.1395343309268355, 0.8381977945100516, 17.653115540742874, 84.25977945327759, 73.2355298101902, 70.55023670196533, 66.18347302079201, 55.23208066821098, 72.88299232721329, 38.52176673710346, 0.8602830406744033, 0.2556718932464719, 0.2870645618531853, 0.267118007177487, 0.17240932123968378, 0.23270251171197742, 0.14156236866256222, 0.1340893274755217, 0.14836053043836728], [0.012568113197630737, 0.0491375828278251, 0.031337597538367845, 0.04155763526796363, 0.04293060104828328, 0.04560884503007401, 0.06607938936213031, 0.025542409384797793, 0.13240284140920267, 1.0668566403910518, 53.08857008814812, 53.36495965719223, 38.125406205654144, 46.95552438497543, 47.74772107601166, 66.1512203514576, 69.94001984596252, 0.9823500656057149, 0.0642851137672551, 2.1668553398922086, 2.9137078765779734, 60.581293031573296, 87.03835755586624, 83.01020130515099, 83.71541306376457, 73.59434455633163, 69.15007263422012, 66.7296177148819, 72.51387253403664, 72.33484894037247, 78.74591052532196, 76.09207972884178, 75.10502949357033, 74.20151397585869, 73.87487590312958, 75.81401064991951, 74.98022139072418, 69.7540046274662, 68.8951063156128, 64.54511493444443, 59.76701192557812, 53.953092098236084, 54.25222724676132, 53.86530540883541, 54.084652438759804, 51.958658918738365, 53.43804493546486, 51.46215096116066, 50.58566339313984, 49.042383804917336, 46.23401150107384, 46.96395233273506, 47.580005675554276, 47.89123557507992, 50.95592312514782, 54.16755259037018, 49.094494208693504, 48.325240686535835, 46.5781020373106, 46.02589666843414, 45.73118448257446, 45.416546165943146, 47.96293392777443, 46.73813804984093, 49.43902552127838, 48.40386226773262, 49.26477827131748, 46.62474073469639, 51.24003008008003, 53.60905855894089, 57.988585755228996, 58.1988550722599, 55.088360980153084, 51.331768557429314, 50.04607334733009, 58.202483877539635, 59.32133384048939, 62.265415862202644, 60.86464002728462, 57.31014735996723, 45.234201550483704, 49.4841443002224, 46.0882855206728, 45.740079805254936, 50.13436160981655, 49.140954315662384, 50.044686421751976, 47.23280310630798, 51.79365277290344, 43.47709983587265, 43.46789672970772, 43.9071037620306, 47.78669938445091, 40.87132886052132, 41.16703279316425, 38.235493898391724, 52.491033151745796, 48.21177877485752, 53.387302458286285, 58.88517804443836, 61.53967760503292, 58.25897544622421, 45.30905373394489, 52.57278196513653, 57.09150329232216, 59.07924883067608, 57.55289353430271, 57.88460433483124, 57.21514865756035, 60.522012412548065, 56.52344137430191, 55.16663298010826, 46.56083196401596, 44.13755759596825, 42.98543281853199, 44.546696841716766, 42.71177910268307, 44.21151302754879, 43.365678414702415, 45.69732069969177, 44.060653522610664, 43.3882188051939, 49.76494923233986, 47.27224498987198, 46.71141788363457, 45.11925391852856, 42.543163150548935, 44.359876066446304, 50.030604377388954, 49.66202795505524, 48.2549786567688, 49.88543316721916, 48.54220524430275, 49.17304739356041, 48.90436001121998, 49.34305027127266, 50.37295840680599, 48.949573785066605, 50.793565437197685, 53.71380373835564, 56.06950633227825, 59.47356127202511, 64.63147670030594, 65.83237186074257, 66.76817804574966, 66.49953246116638, 68.10990124940872, 66.66593313217163, 73.82553175091743, 69.34293508529663, 75.5446507036686, 71.97402030229568, 75.10759815573692, 69.42770093679428, 77.91419595479965, 17.80436262488365, 1.1698586633428931, 0.3226489695953205, 0.44925449474249035, 3.7382911797612906, 66.23241439461708, 64.09468710422516, 52.04166166484356, 40.65038971602917, 21.744498498737812, 49.09328207373619, 25.748425349593163, 0.12852341285906732, 0.05660700975568034, 0.0886463858478237, 0.021769024460809305, 0.05074623986729421, 0.05369629172491841, 0.05579559743637219, 0.02282623423525365, 0.039908056205604225, 0.053852573182666674, 0.009489692984061548, 0.07140846981201321, 0.04445355858479161, 0.024963411742646713, 0.030968510800448712, 0.044110370945418254, 0.052510254390654154, 0.10956746205920354, 2.002015197649598, 65.5968376994133, 62.30258546769619, 38.926578015089035, 41.1473498493433, 56.83606579899788, 72.35232800245285, 76.48259997367859, 0.7465883914846927, 0.05137334352184553, 2.437557801604271, 6.819523042067885, 68.17303866147995, 88.96269589662552, 86.16766467690468, 86.03238433599472, 77.69680961966515, 72.27218270301819, 67.72475391626358, 76.45514264702797, 76.53287127614021, 80.99941000342369, 77.93969258666039, 77.60436818003654, 77.90164902806282, 75.5068427324295, 78.64764779806137, 74.1423587501049, 72.38445147871971, 71.42755642533302, 66.56153753399849, 61.34355492889881, 56.54827684164047, 57.06297442317009, 57.069684863090515, 56.165610775351524, 56.68654762208462, 55.299192667007446, 54.639802649617195, 55.54806791245937, 52.03408487141132, 49.49604906141758, 49.997728541493416, 50.452522337436676, 51.394153609871864, 53.51252853870392, 55.68362183868885, 49.45915684103966, 48.16373035311699, 47.38183110952377, 46.522169038653374, 45.782637521624565, 45.36789357662201, 50.219446644186974, 48.33180293440819, 53.04545380175114, 49.924016296863556, 50.07666930556297, 48.22987340390682, 52.41948299109936, 53.736028745770454, 58.54541167616844, 57.305918186903, 57.12336078286171, 55.05213372409344, 54.05209578573704, 57.954402789473534, 63.0697301030159, 63.597571179270744, 64.16345581412315, 57.846389785408974, 51.844102665781975, 52.70466908812523, 48.497850224375725, 47.61779464781284, 51.27089962363243, 49.67728413641453, 52.65050299465656, 48.55692185461521, 54.33057904243469, 45.148417353630066, 44.652315974235535, 43.14659737050533, 48.575062081217766, 42.0101847499609, 42.02053539454937, 42.78522536158562, 55.04212126135826, 50.196689665317535, 57.14932858943939, 60.69360360503197, 63.00280809402466, 57.49632976949215, 47.91956305503845, 56.9418141245842, 57.92952932417393, 58.75880442559719, 59.51219379901886, 59.01860028505325, 61.09646558761597, 63.5113500058651, 59.56374943256378, 57.89007984101772, 47.20836661756039, 45.84601052105427, 44.842822551727295, 44.79103893041611, 43.3339387178421, 44.439428597688675, 43.681905046105385, 44.92042578756809, 42.82329171895981, 44.05118063092232, 52.71887272596359, 49.49396677315235, 48.74468497931957, 47.62105107307434, 45.56532338261604, 45.85580259561539, 52.22524881362915, 51.51354320347309, 50.259675085544586, 50.73529936373234, 51.924487352371216, 52.64636121690273, 51.899351701140404, 52.882317155599594, 54.24009449779987, 52.91724108159542, 53.538800328969955, 55.15741467475891, 59.113667383790016, 63.773072361946106, 65.81008225679398, 68.116824477911, 69.18709024786949, 69.10008251667023, 70.45160159468651, 68.38808432221413, 77.48949274420738, 72.6327833533287, 77.52215579152107, 75.58587849140167, 78.75775068998337, 73.514054864645, 81.09999820590019, 22.831490971148014, 1.605746098794043, 0.6844703340902925, 0.3377800842281431, 3.2074420899152756, 71.22342377901077, 71.10851034522057, 59.03441123664379, 42.66260974109173, 27.941152788698673, 57.05594100058079, 38.90719145536423, 0.05064674012828618, 0.09701719565782696, 0.06500013594632037, 0.06916008147527464, 0.02140409931598697, 0.03432493860600516, 0.03230676818930078, 0.03681327070808038, 0.054683500275132246, 0.23971916176378727, 0.1815784815698862, 0.14119142841082066, 0.13967076782137156, 0.15069454035256058, 0.13140542461769655, 0.316017345758155, 0.19871269731083885, 0.3098415193380788, 2.290583113208413, 77.03626826405525, 71.3155460357666, 46.45829826593399, 59.452335610985756, 69.21834737062454, 78.31088706851006, 85.20521432161331, 1.661161019001156, 0.14939135871827602, 4.924803161993623, 12.432894855737686, 74.65627357363701, 93.18404898047447, 91.95333302021027, 90.36013171076775, 80.79322546720505, 75.39873853325844, 70.66801518201828, 79.37577992677689, 77.90782749652863, 85.89719519019127, 82.65006422996521, 80.55588260293007, 80.33277377486229, 78.9580911397934, 84.05495524406433, 79.99630182981491, 76.48103445768356, 79.0166611969471, 72.89202824234962, 64.29359123110771, 59.3453561514616, 58.84482800960541, 60.49947962164879, 58.971498012542725, 58.516240641474724, 58.038423880934715, 56.9424144923687, 57.03589707612991, 54.5354488492012, 51.907996237277985, 53.96942362189293, 53.529023453593254, 52.48105488717556, 55.68750903010368, 58.22914704680443, 49.74321819841862, 48.89691241085529, 47.25564748048782, 48.38726855814457, 46.13482542335987, 44.40718352794647, 50.51212973892689, 49.277207404375076, 55.77110454440117, 52.578052282333374, 53.288773745298386, 51.401973590254784, 57.23596774041653, 56.739163398742676, 63.513576686382294, 61.17806240916252, 60.82586690783501, 57.990668043494225, 57.88119591772556, 63.25553633272648, 66.64633378386497, 66.35746568441391, 66.4633584022522, 62.93842814862728, 55.65731585025787, 54.379330426454544, 53.5677357763052, 53.99511404335499, 54.30419705808163, 49.293105751276016, 54.949212446808815, 50.81716597080231, 54.8772519081831, 44.95392479002476, 44.64183613657951, 43.62260542809963, 47.59022332727909, 42.10716314613819, 43.55314515531063, 47.29484997689724, 57.93327212333679, 52.58841812610626, 60.92723026871681, 61.45675465464592, 65.7000857591629, 61.874576434493065, 50.343821570277214, 57.62470968067646, 61.033856347203255, 62.11923010647297, 63.958373218774796, 61.552878096699715, 63.259176537394524, 65.37189736962318, 62.82909281551838, 62.40551054477692, 51.43923059105873, 48.657502457499504, 49.636687114834785, 45.79187102615833, 44.4722056388855, 44.723714143037796, 43.291639387607574, 47.206983491778374, 44.106137081980705, 43.9150757342577, 55.12825503945351, 52.486427798867226, 52.400229424238205, 51.234596371650696, 48.91762129962444, 49.57646794617176, 55.40879778563976, 52.552061676979065, 50.79513095319271, 53.5112252086401, 55.56409925222397, 56.93777494132519, 54.223683178424835, 54.26951251924038, 57.20830902457237, 55.56271232664585, 56.15496374666691, 59.28470380604267, 61.91337235271931, 66.21936589479446, 69.68618586659431, 72.36409217119217, 71.69692397117615, 73.06140795350075, 72.76668816804886, 70.90829148888588, 81.64700165390968, 75.0989194214344, 81.78007811307907, 77.84592121839523, 81.70966029167175, 76.34603530168533, 82.5716744363308, 23.59323039650917, 2.1849264577031136, 2.0836611790582538, 0.6350250716786832, 6.569361090660095, 82.44106024503708, 75.98386153578758, 67.26804122328758, 57.566872984170914, 33.09270165860653, 66.90745577216148, 48.50487604737282, 0.3535330295562744, 0.3458536713151261, 0.1743400629493408, 0.15490486286580563, 0.13081140961730853, 0.1017024704196956, 0.13103455858072266, 0.19746857578866184, 0.11435187290771864], [0.03509160684188828, 0.07018955162493512, 0.07760643449728377, 0.027858023313456215, 0.0472310054465197, 0.07456148421624675, 0.04036107799038291, 0.005690276302630082, 0.3308933100197464, 2.3792893532663584, 58.670611158013344, 45.94586916267872, 48.899340480566025, 42.06174798309803, 46.95496201515198, 78.56550380587578, 54.817522913217545, 0.053863085704506375, 0.04674042356782593, 2.0369790215045214, 0.6788914615754038, 76.33907407522202, 86.02937489748001, 85.62848880887032, 78.18459704518318, 75.9637302160263, 71.36604532599449, 72.28773146867752, 75.27725905179977, 78.45211029052734, 74.61059242486954, 77.86819562315941, 74.81135845184326, 74.88611564040184, 76.66132718324661, 73.23936760425568, 67.16487675905228, 57.542675882577896, 55.470609068870544, 53.973759189248085, 53.949113711714745, 55.34330829977989, 53.43828812241554, 50.28027758002281, 50.50315462052822, 53.684252724051476, 52.828132063150406, 52.3049571365118, 51.63473770022392, 48.8883400708437, 46.18293084204197, 44.4484531134367, 46.95811204612255, 48.863462805747986, 49.447088688611984, 47.98963889479637, 50.84919065237045, 52.58374437689781, 50.35680167376995, 49.36706118285656, 45.49911193549633, 44.78606879711151, 47.63900890946388, 48.49256090819836, 49.947495236992836, 49.35872822999954, 47.74099163711071, 48.26397657394409, 46.415520161390305, 49.1215031594038, 52.3563227802515, 54.314733892679214, 53.81292521953583, 51.93780183792114, 52.88778506219387, 55.26086412370205, 61.43338970839977, 59.38768208026886, 61.47819310426712, 54.27357070147991, 48.522324711084366, 44.16928589344025, 38.08885216712952, 47.19676963984966, 45.370557233691216, 47.405139058828354, 50.67499279975891, 43.54922376573086, 60.62663219869137, 52.625971511006355, 45.6313144415617, 52.17610225081444, 48.45821835100651, 41.682300344109535, 44.923138841986656, 50.69004379212856, 55.57970501482487, 49.00476962327957, 55.78264072537422, 59.4361674785614, 57.087494507431984, 51.0419125109911, 53.11364874243736, 60.22109515964985, 54.532629400491714, 60.065485909581184, 59.848095774650574, 57.58690930902958, 58.78260634839535, 57.05146864056587, 51.212652549147606, 45.832373052835464, 43.25715623795986, 44.66095671057701, 44.939515963196754, 45.355293452739716, 46.4214326441288, 45.16860567033291, 43.17986838519573, 43.19600231945515, 42.64202244579792, 44.5330897718668, 51.36967532336712, 46.70647814869881, 44.952165484428406, 44.10517193377018, 43.12529571354389, 41.85416892170906, 49.66934636235237, 48.698544055223465, 50.39669953286648, 49.97643828392029, 48.246725499629974, 48.39985728263855, 47.24198341369629, 49.51169282197952, 49.96139109134674, 48.86180229485035, 50.72822414338589, 49.829234182834625, 54.177257269620895, 56.563715413212776, 62.26089410483837, 63.696400076150894, 63.2387488335371, 64.31551605463028, 67.61796444654465, 67.54550993442535, 71.23756662011147, 69.61519047617912, 74.64476779103279, 70.47627747058868, 76.1169683933258, 69.1362489759922, 85.42013838887215, 36.95394806563854, 0.43785549234598875, 0.03460663188889157, 0.06128410605015233, 0.17829229618655518, 46.55989721417427, 70.7059295475483, 55.84081940352917, 39.39368315041065, 28.39594468474388, 50.18738016486168, 45.501312017440796, 0.32358793483581394, 0.030955029687902424, 0.05237486067926511, 0.03799257305217907, 0.05310841057507787, 0.03859751617710572, 0.03611622334574349, 0.047776647261343896, 0.08621546629001386, 0.03357965535542462, 0.027031207719119266, 0.08530309962225147, 0.03410866564081516, 0.062460788612952456, 0.0703838087792974, 0.06927330352482386, 0.11006228160113096, 0.32930380781181157, 3.9912616554647684, 69.611656665802, 48.84104400873184, 55.824309289455414, 43.90451990067959, 56.55318237841129, 85.24850159883499, 57.409983202815056, 0.11032285707187839, 0.06593247380806133, 5.593212470412254, 4.656592179089785, 80.23701891303062, 87.57087618112564, 88.27715948224068, 80.35101279616356, 77.63830795884132, 73.72555911540985, 75.33784300088882, 77.60148033499718, 80.69772139191628, 75.47471925616264, 77.40198343992233, 75.18309250473976, 77.70443201065063, 78.97998556494713, 78.32540228962898, 70.58710992336273, 59.670033529400826, 57.0191665738821, 55.407008081674576, 53.427709490060806, 57.821489721536636, 56.46650902926922, 51.64848156273365, 54.6829417347908, 54.75264899432659, 56.4629790186882, 52.8995568305254, 54.192897230386734, 51.94352053105831, 49.75833758711815, 46.428374871611595, 50.81603363156319, 51.2847650796175, 50.32612971961498, 50.95910735428333, 53.047243505716324, 52.081874907016754, 51.4388582110405, 50.33130124211311, 45.934511572122574, 44.92175191640854, 48.58192451298237, 48.909862115979195, 52.18743324279785, 51.72970600426197, 50.673503279685974, 49.78174813091755, 48.167769536376, 50.306948348879814, 53.48938778042793, 55.79039230942726, 56.06901615858078, 53.81506450474262, 54.675345942378044, 55.60188442468643, 62.57269397377968, 61.253450363874435, 63.94600868225098, 60.16398802399635, 53.83187860250473, 46.09487436711788, 44.36471700668335, 52.52270445227623, 49.62581969797611, 49.309843853116035, 52.52572149038315, 47.4513977766037, 59.7127166390419, 52.87570171058178, 46.258276998996735, 52.881819382309914, 48.19274939596653, 42.4982837587595, 46.688512712717056, 52.55448594689369, 57.49862104654312, 51.29002399742603, 59.193090721964836, 62.63000629842281, 58.612155094742775, 53.15950088202953, 55.684450194239616, 62.27200850844383, 57.95147314667702, 60.340887531638145, 62.85838924348354, 58.147003054618835, 60.1882953196764, 57.79476575553417, 55.4728015512228, 49.4578193128109, 47.15295799076557, 46.22983172535896, 47.91164048016071, 46.858918368816376, 48.18220496177673, 45.2012687176466, 43.743750527501106, 41.925407499074936, 43.82145635783672, 45.185571759939194, 53.08996841311455, 48.63140545785427, 47.37615801393986, 47.7669670432806, 46.64294175803661, 44.3582421541214, 48.799215853214264, 51.69446289539337, 50.98336145281792, 52.129520550370216, 50.47665864229202, 50.29600113630295, 50.62799692153931, 50.99355250597, 53.233403116464615, 51.892063692212105, 53.23546640574932, 52.32035771012306, 56.41922056674957, 58.563293516635895, 63.4845994412899, 63.81721079349518, 65.01342460513115, 65.64527750015259, 69.80431392788887, 69.5129531621933, 72.92097508907318, 72.43355244398117, 76.53775781393051, 74.05185520648956, 77.53816813230515, 71.60145029425621, 88.79585444927216, 41.57215565443039, 0.3398038318846375, 0.28558673802763224, 0.10855892789550126, 0.1859828014858067, 50.36090925335884, 78.59737649559975, 65.7198067009449, 45.83457313477993, 32.145697474479675, 59.94357705116272, 60.33721312880516, 1.3682733289897442, 0.11209645643248223, 0.0233443757679197, 0.06432361638871953, 0.07113026091246866, 0.028429996527847834, 0.0583649126929231, 0.0521564429072896, 0.05822957093187142, 0.10370186078944243, 0.15841296524740756, 0.16820282820845023, 0.16082165006082505, 0.10158509976463392, 0.20963081769878045, 0.16692513192538172, 0.242726462893188, 0.4638703214004636, 5.3122522216290236, 82.41987258195877, 57.57893353700638, 63.5385375469923, 58.4219790995121, 64.62728932499886, 92.02258050441742, 66.46622344851494, 0.3159924689680338, 0.311484812409617, 7.774506798014045, 9.310070425271988, 86.07205420732498, 92.47140482068062, 93.29505622386932, 85.69465845823288, 81.90237075090408, 77.08779349923134, 78.50715413689613, 79.78887096047401, 85.33620849251747, 79.07590761780739, 83.29317212104797, 79.91749405860901, 79.82309192419052, 83.78116473555565, 81.35054916143417, 74.84570100903511, 64.32889133691788, 63.25166054069996, 59.14331339299679, 58.796091824769974, 61.54807135462761, 59.8702447861433, 55.75514920055866, 54.15251299738884, 58.24321009218693, 59.00835983455181, 56.1579579859972, 57.062678039073944, 53.085876032710075, 52.70221062004566, 49.33993063867092, 54.03090052306652, 54.61977392435074, 53.092719465494156, 53.74355614185333, 52.393678575754166, 54.292079508304596, 52.91509419679642, 49.99157667160034, 46.39209821820259, 45.057442635297775, 50.02817630767822, 48.23555409908295, 54.421948939561844, 53.77802409231663, 52.631914392113686, 54.58656370639801, 52.454999685287476, 54.97584521770477, 57.38141633570194, 57.339941561222076, 58.348912820219994, 57.018148228526115, 57.80687190592289, 60.00801019370556, 65.8764722943306, 64.75650519132614, 64.45613890886307, 60.92871218919754, 53.55602100491524, 52.74185009300709, 47.40948982536793, 50.70034883916378, 55.101850256323814, 50.86837962269783, 55.30895434319973, 48.874052837491035, 61.49677790701389, 53.790894001722336, 46.30416713654995, 53.606835678219795, 50.41033320128918, 42.787634432315826, 46.38384506106377, 54.663976952433586, 61.06184184551239, 56.116570606827736, 61.41938365995884, 64.97778251767159, 63.64287234842777, 56.07590138912201, 57.39644072949886, 64.7008153796196, 61.3532368093729, 63.105322793126106, 67.39195257425308, 60.15985004603863, 64.61974292993546, 63.44731584191322, 59.508895576000214, 53.0672912299633, 49.23134386539459, 48.37963096797466, 48.66716533899307, 47.44311802089214, 48.95469971001148, 44.22107331454754, 43.02390955388546, 43.11831548810005, 43.110180124640465, 45.69094464182854, 54.93198037147522, 50.79758182168007, 50.36568559706211, 51.646015495061874, 49.0175711363554, 47.55144640803337, 53.85694585740566, 54.597579315304756, 54.46617476642132, 55.50640694797039, 53.19467939436436, 53.14291097223759, 52.61795774102211, 55.30231609940529, 56.178108304739, 53.474177196621895, 56.121457144618034, 55.978611409664154, 58.5606374591589, 62.64452911913395, 66.55925005674362, 69.53337326645851, 68.67994666099548, 70.11812388896942, 72.04198345541954, 73.89435365796089, 76.11715078353882, 75.41510045528412, 78.71843799948692, 79.76162642240524, 80.39844945073128, 77.26395204663277, 89.81464818120003, 45.10970123112202, 0.5688103591091931, 1.1456610867753625, 0.25911655684467405, 1.3437984860502183, 60.79281248152256, 81.90869361162186, 74.99889358878136, 56.161393001675606, 41.31108686327934, 67.13934972882271, 72.57992818951607, 1.3059755531139672, 0.2385851155850105, 0.1662691030651331, 0.12660792970564216, 0.21663073974195868, 0.1284433202818036, 0.10408331727376208, 0.1988573864218779, 0.21120293880812824], [0.04069430971867405, 0.06197241833433509, 0.09859839323326014, 0.015606269116688054, 0.09277715755160898, 0.02564246387919411, 0.09477375002461486, 0.20049394079251215, 0.31782913603819907, 5.812347186729312, 59.31715026497841, 43.609290942549706, 29.029792472720146, 37.22543589770794, 52.837931737303734, 79.98232617974281, 42.13954880833626, 0.22661074093775824, 0.6096093636006117, 3.808605456724763, 6.244245311245322, 85.78558757901192, 85.26652783155441, 83.38232293725014, 74.5745475590229, 74.51394841074944, 71.99978291988373, 72.03241556882858, 76.11845791339874, 77.2596050798893, 78.50607499480247, 76.14039793610573, 76.11424013972282, 75.50852984189987, 71.25875428318977, 61.02950178086758, 55.41117265820503, 52.70226001739502, 51.373300328850746, 54.714989215135574, 51.8859726190567, 53.410815596580505, 53.823762238025665, 51.103568002581596, 51.58786341547966, 52.36203387379646, 51.4051616191864, 52.74659223854542, 50.80914840102196, 50.13913035392761, 44.725994020700455, 46.471586152911186, 47.57665805518627, 49.1201314330101, 49.74384896457195, 52.93957248330116, 54.502428621053696, 53.854187205433846, 53.40553767979145, 51.633324176073074, 46.47472858428955, 47.70314186811447, 51.74860619008541, 52.534765005111694, 49.475199580192566, 47.902338579297066, 47.317063584923744, 46.44979812204838, 44.96014125645161, 45.0741009414196, 46.84741638600826, 48.87273050844669, 52.8493083268404, 51.48205429315567, 50.09390518069267, 49.5079842209816, 55.208894312381744, 60.92088840901852, 60.54552935063839, 64.92949470877647, 59.16703172028065, 48.80097895860672, 56.770694106817245, 58.15242916345596, 47.577201426029205, 52.186646685004234, 46.37350581586361, 42.544192895293236, 57.31841191649437, 54.91288639605045, 55.8834683150053, 44.30434584617615, 50.213496163487434, 53.10437723994255, 53.31716202199459, 57.509686052799225, 54.70316044986248, 49.18115235865116, 55.230830535292625, 56.346933245658875, 56.298261657357216, 53.27205464243889, 57.07748204469681, 59.491317719221115, 57.405317053198814, 56.74285300076008, 56.181672513484955, 52.34355166554451, 50.2695469558239, 47.68879383802414, 44.76074315607548, 43.391232043504715, 43.85332904756069, 45.064654648303986, 47.767742201685905, 47.71986097097397, 48.217672258615494, 45.814863592386246, 43.383214473724365, 42.580731734633446, 44.08881761133671, 44.01285968720913, 48.649082109332085, 45.675319880247116, 45.774817541241646, 44.59873124957085, 42.474561631679535, 41.93080700933933, 48.900472819805145, 48.064802661538124, 49.951036646962166, 50.462253615260124, 49.8035703599453, 47.316497415304184, 50.197084844112396, 49.30647723376751, 51.81241996586323, 47.60330222547054, 51.91037870943546, 50.18912807106972, 50.31430095434189, 51.053840070962906, 54.47746776044369, 51.45468436181545, 55.36887712776661, 58.496287912130356, 66.82873919606209, 65.46041741967201, 71.96094900369644, 69.71478313207626, 71.1510756611824, 70.37749037146568, 75.81976354122162, 70.81416293978691, 83.42048048973083, 49.35010649263859, 0.030742337585252244, 0.25000880181323737, 0.06868054275400937, 0.1454441127134487, 31.463284492492676, 78.0384036898613, 55.21576054394245, 49.44137379527092, 27.39129189401865, 36.503668427467346, 58.05593714118004, 2.2751530911773443, 0.02573104477050947, 0.03017132359673269, 0.06361151827150024, 0.0945649022469297, 0.04873485268035438, 0.047745777628733777, 0.0644261366687715, 0.06320908869383857, 0.021717523122788407, 0.028631328204937745, 0.057784727614489384, 0.041441088396823034, 0.0733821744506713, 0.033513938178657554, 0.2392048088950105, 0.25708716886583716, 0.5135575239546597, 8.834502194076777, 66.41839921474457, 54.34167444705963, 32.14298442006111, 38.47917482256889, 62.937497198581696, 86.3110613822937, 47.03082874417305, 0.3542367636691779, 0.6902481615543365, 2.9536031233146787, 9.970514886081219, 91.57656043767929, 88.38417693972588, 86.05549469590187, 75.94351530075073, 75.61039477586746, 75.08933633565903, 74.4773867726326, 78.74752163887024, 78.70450794696808, 80.53374499082565, 77.06602826714516, 78.58326405286789, 77.74812206625938, 70.19671887159348, 63.88756021857262, 58.95513229072094, 56.001892760396004, 55.5276820063591, 55.442243590950966, 54.730990156531334, 55.618531331419945, 55.03069527447224, 54.69201944768429, 53.96372772753239, 56.18532791733742, 55.1174446195364, 55.04462532699108, 54.91028733551502, 52.57495164871216, 47.59569503366947, 49.47940215468407, 51.05741947889328, 52.44888201355934, 51.76704280078411, 54.475047290325165, 55.67490130662918, 53.27803932130337, 52.74815775454044, 50.68427190184593, 48.262426257133484, 48.033005967736244, 52.29898765683174, 54.09368455410004, 49.99858729541302, 49.072181805968285, 49.99375395476818, 48.24131079018116, 47.300925850868225, 47.07058601081371, 49.967079386115074, 51.26488074660301, 56.540886238217354, 54.0343963354826, 51.478714272379875, 50.02865508198738, 56.30637042224407, 63.75234827399254, 64.30197358131409, 65.53442984819412, 61.72686316072941, 51.3581695407629, 59.47342827916145, 58.662578389048576, 52.362516447901726, 51.51342920958996, 47.330758050084114, 45.41656896471977, 60.449310913681984, 58.01144912838936, 55.0590455532074, 47.50367157161236, 50.2872996032238, 53.78634184598923, 54.59987439215183, 60.230473056435585, 57.590234130620956, 50.92742845416069, 56.87075033783913, 58.39129574596882, 59.17657680809498, 57.34912186861038, 58.8344469666481, 59.44300711154938, 58.19515027105808, 57.332239374518394, 57.30149142444134, 54.766012877225876, 52.09273472428322, 50.60136415064335, 47.981359139084816, 47.42922976613045, 47.18716375529766, 49.62834656238556, 49.90349359810352, 49.316687285900116, 50.43243281543255, 46.70062266290188, 43.831423223018646, 43.5334812104702, 43.80203939974308, 43.85092757642269, 52.48650759458542, 47.85493612289429, 49.714985713362694, 47.85020537674427, 46.126047894358635, 44.005199298262596, 50.96898302435875, 51.7739812284708, 52.20634862780571, 51.41667120158672, 52.80942186713219, 49.565779119729996, 51.18634656071663, 51.51116073131561, 54.23111937940121, 49.45994719862938, 54.897406026721, 52.42075592279434, 52.73626059293747, 52.43184752762318, 55.238718912005424, 54.4392342120409, 57.57756561040878, 61.694093719124794, 68.01657825708389, 67.75664180517197, 73.71238902211189, 71.17699027061462, 74.52131241559982, 72.57906183600426, 78.48498612642288, 71.3591904938221, 85.80625087022781, 53.79082180559635, 0.07165680726757273, 1.4661532267928123, 0.11554536511539482, 0.23820200411137193, 32.91780844330788, 85.46945214271545, 62.84440219402313, 54.67919133603573, 28.645462095737457, 44.35169890522957, 67.30093985795975, 5.0526701007038355, 0.13643880374729633, 0.09297397511545569, 0.12281744013307616, 0.12960773514350876, 0.06589557422557846, 0.06893154451972805, 0.08624299254734069, 0.06757904717233032, 0.11327906133374199, 0.1122165952983778, 0.2611183963017538, 0.25501803145743906, 0.2021420726669021, 0.15259455714840442, 0.32070905494038016, 0.41545985033735633, 0.5277907883282751, 9.704530108720064, 79.08030778169632, 57.97395274043083, 36.73153840005398, 49.91980232298374, 70.02427652478218, 92.70183205604553, 53.544519022107124, 0.35999244544655085, 1.2280979007482529, 6.524529671296477, 11.772616636008024, 95.02942755818367, 91.84924900531769, 88.62766787409782, 80.18244624137878, 82.72606775164604, 79.84580710530281, 76.4569741487503, 82.34961435198784, 82.95017972588539, 84.3365353345871, 80.13485759496689, 82.92256280779839, 79.0218137204647, 75.29568046331406, 66.76482662558556, 60.528023689985275, 58.86980026960373, 58.1534893065691, 59.05175730586052, 59.62987348437309, 59.22742947936058, 59.82072964310646, 57.04221993684769, 57.198809534311295, 56.407878175377846, 56.70769728720188, 57.582968920469284, 57.82060816884041, 55.468560978770256, 49.69987012445927, 52.46520213782787, 54.86835278570652, 54.89469677209854, 54.61614511907101, 58.05917076766491, 55.20496532320976, 54.68133442103863, 53.6227910220623, 51.43461383879185, 48.65146838128567, 47.86633551120758, 52.39025875926018, 54.59603659808636, 53.690332397818565, 49.965844452381134, 51.83234229683876, 50.54548814892769, 50.15719458460808, 49.14204105734825, 52.33114913105965, 54.49105203151703, 60.09291663765907, 57.22480773925781, 54.89415720105171, 52.750525027513504, 57.70556554198265, 68.98272961378098, 64.77869600057602, 70.19329905509949, 65.78756466507912, 57.208996787667274, 59.617733135819435, 59.29644897580147, 51.84733249247074, 51.92949168384075, 49.72351245582104, 47.630409970879555, 64.88496109843254, 60.16712665557861, 51.73476733267307, 46.703020334243774, 53.52319076657295, 56.590116396546364, 55.8348423242569, 62.79431328177452, 60.73835760354996, 54.505901634693146, 60.264937207102776, 60.4506978392601, 61.41375616192818, 57.65829987823963, 60.60220330953598, 63.5002925992012, 60.37954665720463, 61.19525648653507, 61.48047298192978, 58.45538690686226, 56.17948763072491, 53.727916181087494, 49.22630913555622, 47.785354256629944, 49.0565038472414, 49.131169840693474, 52.46033079922199, 50.3741629421711, 50.79886995255947, 47.44069755077362, 44.606961607933044, 43.85734923183918, 44.85943906009197, 45.40258191525936, 53.24280381202698, 51.211759597063065, 51.65777586400509, 50.76375223696232, 47.76326984167099, 47.2195266187191, 55.05432240664959, 52.84185692667961, 55.6056272238493, 54.3992755562067, 54.409892186522484, 51.92280404269695, 54.18014511466026, 55.3854214400053, 57.64543756842613, 52.22487263381481, 58.95080052316189, 55.716338083148, 54.35094594955444, 56.26844085752964, 59.118322134017944, 58.36761921644211, 60.66829316318035, 65.86913108825684, 73.13700869679451, 71.41224324703217, 77.29987531900406, 74.96714249253273, 78.25969621539116, 76.37511894106865, 81.70723602175713, 76.26801788806915, 89.3656338751316, 57.25720480084419, 0.2165802736999467, 3.366391835734248, 0.47360240074340254, 0.2933211636263877, 42.596508488059044, 91.46107703447342, 69.28388625383377, 68.36736023426056, 39.302822425961494, 49.307674169540405, 80.50261706113815, 5.892618829384446, 0.34510321158450097, 0.17938178381882608, 0.18425907444907352, 0.3882844210602343, 0.24347831786144525, 0.12879272340796888, 0.16868314618477598, 0.14484160754363984], [0.11082660465035588, 0.12883646559203044, 0.0647794286487624, 0.07790224713971838, 0.027602642876445316, 0.06140817087725736, 0.12607490440132096, 0.030533523204212543, 0.38247488904744387, 12.141573037952185, 67.04627752304077, 37.86713786423206, 57.96392887830734, 55.57281978428364, 55.04818193614483, 86.87950327992439, 30.781867057085037, 0.38899079721886665, 0.46479064389131963, 1.546336286701262, 20.71132253855467, 87.04996973276138, 83.71187925338745, 80.362199395895, 73.11071410775185, 69.30344760417938, 71.65131121873856, 74.85771596431732, 78.45415458083153, 78.42747241258621, 77.01220035552979, 74.80165377259254, 73.62639963626862, 65.42075514793396, 57.574438378214836, 54.400092512369156, 54.99152697622776, 54.640676602721214, 54.34342995285988, 53.75331401824951, 53.06598410010338, 53.63849177956581, 52.17346899211407, 53.432793617248535, 50.57839818298817, 53.05567145347595, 49.99376155436039, 51.05385147035122, 52.099961936473846, 47.62854427099228, 46.046050786972046, 45.47992676496506, 47.416527047753334, 52.01423853635788, 50.68155884742737, 51.238171979784966, 53.452997133135796, 52.49049358069897, 50.27954041957855, 51.60829111933708, 50.125781670212746, 44.32225428521633, 46.17408111691475, 49.72010023891926, 52.13719993829727, 48.55392001569271, 47.26958513259888, 44.73111234605312, 43.74845467507839, 43.10259573161602, 46.76815643906593, 46.84689961373806, 47.5066202133894, 50.19611209630966, 48.371195420622826, 50.70841580629349, 48.749978095293045, 53.448194190859795, 55.88753789663315, 57.30235017836094, 58.002329617738724, 58.752162382006645, 62.215243354439735, 57.458559796214104, 50.793041065335274, 59.0767789632082, 49.20594222843647, 43.6453852057457, 42.488461285829544, 41.0403323918581, 64.89548653364182, 55.55616907775402, 34.581769555807114, 44.608428329229355, 51.86092436313629, 57.68138363957405, 54.03940446674824, 52.658368572592735, 53.06877315044403, 55.26264622807503, 59.129368141293526, 56.91462658345699, 57.647953033447266, 54.643412455916405, 49.93875950574875, 50.33033229410648, 50.564916506409645, 48.70584726333618, 48.44014272093773, 45.49074478447437, 43.37099812924862, 43.31493593752384, 47.39802964031696, 44.993986040353775, 49.633024111390114, 46.676634550094604, 51.69278718531132, 47.00089395046234, 43.96467067301273, 44.82359938323498, 44.27664913237095, 46.51364229619503, 50.972349643707275, 45.42009137570858, 45.524840354919434, 45.161150470376015, 43.54755565524101, 41.33902296423912, 47.32089377939701, 49.88714687526226, 49.08896550536156, 48.05684968829155, 49.6431315690279, 48.42252306640148, 50.17785407602787, 47.40119107067585, 49.9179632216692, 46.77610941231251, 49.70366232097149, 48.22291977703571, 49.97573532164097, 48.109378069639206, 51.44041992723942, 49.21731501817703, 52.52228647470474, 52.141292318701744, 56.46519809961319, 56.53097257018089, 62.641086503863335, 61.10664144158363, 65.9734582901001, 65.19909784197807, 74.78472948074341, 67.96569898724556, 86.97629928588867, 52.04682178795338, 0.0944537804753054, 0.4663189040729776, 0.16048300807597116, 0.136508283612784, 20.86023084819317, 78.76829132437706, 55.1060376316309, 52.55051136016846, 30.27900394052267, 30.90758141130209, 64.93548318743706, 6.145465336740017, 0.24104874901240692, 0.08024966024095193, 0.007689602662139805, 0.14454975054832175, 0.018152256816392764, 0.023104595275071915, 0.046387012844206765, 0.048665142749086954, 0.02977550284413155, 0.09688690421171486, 0.031981982101569884, 0.06610759097384289, 0.03332852742460091, 0.09016949552460574, 0.1405048675951548, 0.16482440871186554, 0.6364809279330075, 19.25068661570549, 75.1742085814476, 49.211649522185326, 55.66941440105438, 54.01869557797909, 65.11440798640251, 92.72056505084038, 32.67435550689697, 0.47218305815476924, 0.5405204615090042, 2.908599288202822, 27.01315328478813, 89.66253474354744, 87.05789610743523, 83.29374969005585, 76.74050733447075, 70.46613201498985, 75.98226562142372, 77.28864312171936, 80.32786443829536, 80.57197853922844, 79.58539947867393, 77.05712914466858, 76.39518946409225, 66.71112790703773, 61.3834185898304, 56.1700489372015, 56.8352260440588, 56.74669839441776, 58.587536215782166, 55.528027787804604, 54.92173232138157, 54.42513696849346, 57.21117407083511, 54.28297899663448, 53.38922895491123, 55.16908384859562, 55.00829167664051, 53.131135404109955, 55.45399256050587, 49.92649756371975, 48.25922682881355, 47.40746073424816, 50.58333791792393, 53.12469094991684, 52.40361884236336, 54.3369285017252, 56.03072561323643, 52.08010420203209, 52.15732365846634, 51.01939111948013, 51.23077377676964, 45.70475310087204, 46.96444630622864, 50.77996216714382, 53.26878681778908, 48.46294529736042, 49.8803224414587, 47.81314976513386, 47.612478733062744, 45.42794555425644, 49.79424946010113, 50.16968071460724, 50.634623765945435, 51.90394185483456, 51.09498806297779, 51.85797952115536, 51.36440880596638, 54.476821795105934, 58.54970924556255, 59.39142867922783, 59.76924240589142, 63.46909247338772, 61.49518199265003, 60.607120245695114, 50.40191285312176, 56.48448966443539, 51.80368423461914, 45.548646077513695, 45.771420523524284, 45.56437723338604, 60.849121659994125, 57.178606018424034, 40.03301024436951, 49.1202188283205, 51.584515795111656, 58.40128920972347, 58.54807533323765, 55.219647735357285, 57.44540490210056, 56.29676453769207, 62.9017449170351, 58.49631831049919, 57.926166504621506, 55.383510142564774, 53.6957661062479, 51.149803921580315, 51.517662182450294, 49.547486901283264, 50.45565336942673, 46.404185369610786, 44.661336690187454, 45.389370024204254, 48.84107820689678, 48.24007585644722, 50.26497580111027, 47.47668541967869, 52.129493951797485, 46.71045273542404, 46.1274728178978, 44.80519317090511, 46.9051580876112, 46.4528189599514, 53.141125068068504, 47.55574397742748, 47.52407647669315, 47.24174402654171, 46.796909496188164, 44.586381912231445, 49.71425235271454, 52.14558608829975, 51.37584999203682, 50.17938159406185, 54.186338782310486, 51.41499549150467, 51.82633101940155, 50.017331689596176, 52.37768143415451, 49.540867656469345, 51.987575367093086, 49.75253909826279, 53.448794558644295, 50.41279926896095, 53.611475229263306, 51.74443781375885, 55.710775181651115, 53.507406413555145, 59.32691194117069, 57.73195132613182, 64.61940094828606, 62.4251326918602, 66.84337601065636, 65.29631182551384, 76.47796422243118, 72.68953710794449, 88.56857344508171, 54.274292662739754, 0.09482342196861282, 1.736543986480683, 0.5245002242736518, 0.17398197669535875, 21.24579805880785, 84.25469532608986, 63.96344214677811, 62.424897104501724, 31.813496500253677, 40.77851124107838, 77.44350001215935, 11.828705426305532, 0.2779412514064461, 0.08305038456455804, 0.12331379592069425, 0.030662740391562693, 0.07128197816200554, 0.04410417772305664, 0.03450813404924702, 0.09997773406212218, 0.221316660172306, 0.24638982256874442, 0.09497194056166336, 0.15350048197433352, 0.1389028676203452, 0.14127619651844725, 0.24326527694938704, 0.3010340075707063, 0.7030559086706489, 20.41251417249441, 89.8413835465908, 52.189382538199425, 72.49502554535866, 72.36118912696838, 72.54618600010872, 102.07213684916496, 38.08728285133839, 0.6598912936169654, 1.350342684891075, 4.733055476099253, 30.225455313920975, 94.10584911704063, 90.23391768336296, 86.00798964500427, 81.19152009487152, 73.63662868738174, 80.82571372389793, 81.21992737054825, 84.02569681406021, 83.74076530337334, 82.8902417421341, 80.44139474630356, 79.16361451148987, 72.23106130957603, 64.50553625822067, 58.853153362870216, 61.99252210557461, 58.75803306698799, 62.1989194303751, 59.71694961190224, 58.32089692354202, 59.34090659022331, 60.19966810941696, 58.830308988690376, 56.62946708500385, 58.334781378507614, 54.530657306313515, 54.938649013638496, 58.607454746961594, 53.790457025170326, 51.98658362030983, 52.053919807076454, 54.226650819182396, 57.39576816558838, 55.006657764315605, 57.02695615589619, 55.88087685406208, 51.88429310917854, 51.08953155577183, 50.16143895685673, 51.3980446010828, 48.89878191053867, 47.29594051837921, 52.72034704685211, 53.12314823269844, 50.70403844118118, 52.492678463459015, 50.64899459481239, 50.29593653976917, 49.05494973063469, 54.886819794774055, 53.42519782483578, 51.464446038007736, 55.97396045923233, 52.945971339941025, 56.76783666014671, 54.725598245859146, 55.92928625643253, 60.38859397172928, 61.73430696129799, 62.12771885097027, 63.25637228786945, 64.94588702917099, 62.034794837236404, 50.96796467900276, 56.70195959508419, 54.50565844774246, 46.209878996014595, 50.80499142408371, 54.204782992601395, 63.436083644628525, 54.117178693413734, 40.17735689878464, 51.243993267416954, 57.357785403728485, 63.76114100217819, 60.736700892448425, 57.703126072883606, 59.352640360593796, 60.184252336621284, 65.0055742263794, 59.253450483083725, 62.43763402104378, 57.25109472870827, 55.08536674082279, 56.24972306191921, 54.98535990715027, 53.2015760242939, 54.24000710248947, 47.689827382564545, 47.21576862037182, 47.00785517692566, 52.399492263793945, 50.74051268398762, 51.73828974366188, 48.842461332678795, 52.71623186767101, 48.19997280836105, 46.46442353725433, 44.7744832187891, 47.13348023593426, 47.871776819229126, 56.55555345118046, 49.78953771293163, 50.37662900984287, 49.90095153450966, 48.366016298532486, 47.98415958881378, 53.00156995654106, 54.80891637504101, 52.989953979849815, 53.1097387522459, 56.94860816001892, 52.6942690461874, 55.390072390437126, 53.768247216939926, 56.81123413145542, 52.71231807768345, 55.548428893089294, 54.11370187997818, 57.23113439977169, 53.11174884438515, 58.17745842039585, 56.25688187777996, 58.00764173269272, 58.969259932637215, 64.0988364815712, 61.61712884902954, 69.26714435219765, 69.20974463224411, 72.13328495621681, 72.11443036794662, 80.44339343905449, 75.46967312693596, 92.75443643331528, 57.98483155667782, 0.6117247219663113, 1.5542284632101655, 0.8080175577197224, 0.18459868122590706, 28.191029280424118, 92.70950004458427, 70.86891800165176, 73.34724381566048, 44.510283395648, 44.319966807961464, 88.11746165156364, 13.172435872256756, 0.6391508784145117, 0.30954994435887784, 0.2315968304174021, 0.2579416480148211, 0.164354094886221, 0.15931688627460971, 0.12399714323692024, 0.1872569354600273], [0.04629662667866796, 0.02235663472674787, 0.07126052267267369, 0.04352782212663442, 0.042118146011489443, 0.05623633296636399, 0.12946761766215786, 0.05548796609218698, 0.21380213293014094, 27.194135673344135, 64.68937039375305, 27.95655146241188, 32.74086333811283, 48.46860319375992, 53.24017435312271, 87.29537576436996, 24.170609414577484, 0.26300259050913155, 0.4468062979867682, 0.4864688962697983, 42.891847640275955, 88.90664130449295, 84.15527746081352, 72.62038841843605, 69.68664184212685, 69.70982819795609, 71.9404149055481, 75.04865571856499, 78.34667354822159, 77.42250993847847, 76.15808978676796, 69.3869823217392, 61.66869968175888, 57.840610295534134, 55.01568228006363, 54.376681968569756, 54.74415645003319, 54.323910400271416, 53.40327300131321, 55.49253389239311, 51.51697441935539, 53.67592737078667, 51.1843478679657, 50.46936683356762, 51.474606692790985, 51.16232804954052, 49.247800782322884, 50.30254438519478, 49.91341106593609, 49.28313888609409, 44.54241447150707, 44.09294418990612, 47.73690305650234, 49.496064260602, 48.969982489943504, 51.7662600427866, 56.309596449136734, 52.21235990524292, 50.219378247857094, 51.092153415083885, 49.991451278328896, 50.4238148778677, 49.876423850655556, 50.32167635858059, 50.85129953920841, 49.64968241751194, 47.68304854631424, 45.385289043188095, 45.35456769168377, 44.26677726209164, 45.21368645131588, 43.654489517211914, 45.177280604839325, 47.249491810798645, 49.21129614114761, 47.74348430335522, 48.04116792976856, 49.840819761157036, 49.904283955693245, 54.159626215696335, 53.55054169893265, 57.9285641759634, 62.41575099527836, 62.42910347878933, 57.16922052204609, 60.04068084061146, 47.182220220565796, 45.699817165732384, 45.40350526571274, 41.05958595871925, 41.15276835858822, 58.763858154416084, 54.65951979160309, 43.263771682977676, 48.979991152882576, 54.445085898041725, 55.869656056165695, 51.00540407001972, 53.35034944117069, 53.26718710362911, 52.83749856054783, 55.08534774184227, 51.749654933810234, 48.37659873068333, 46.40654884278774, 47.14619055390358, 45.26803873479366, 45.66908061504364, 45.666067376732826, 43.13196435570717, 43.61662834882736, 45.713659822940826, 42.90190190076828, 47.3222579061985, 49.56515595316887, 49.35707151889801, 46.328440234065056, 43.57988812029362, 44.466680735349655, 44.540016800165176, 48.55553112924099, 47.295222356915474, 49.2827171087265, 45.58683782815933, 44.87319052219391, 42.22589157521725, 43.79984311759472, 42.4868805706501, 48.18301431834698, 48.61038118600845, 51.53064988553524, 47.68568940460682, 50.421565398573875, 48.78967076539993, 50.51482379436493, 48.86855073273182, 50.23982495069504, 49.77652721107006, 48.90868037939072, 47.95866295695305, 51.04755140841007, 48.94739270210266, 49.78385701775551, 48.35749335587025, 52.49467335641384, 49.68550689518452, 52.863648757338524, 51.17624670267105, 57.446487843990326, 51.91654957830906, 61.0036251693964, 64.21703293919563, 75.8041463792324, 69.46555450558662, 85.98847389221191, 43.95813502371311, 0.29217401111964136, 1.3181514060124755, 0.30780565983150154, 0.010464385213708738, 4.993694415315986, 68.8422891497612, 59.275933876633644, 52.76839926838875, 37.72954344749451, 25.837369076907635, 61.129880994558334, 14.747217670083046, 0.11354060901794583, 0.09695348227978684, 0.09941589116351679, 0.07869751774705946, 0.03479889266600367, 0.028833658070652746, 0.024537329918530304, 0.041009121341630816, 0.03394806117285043, 0.023012676574580837, 0.07291428002645262, 0.06499622482806444, 0.03022731121745892, 0.042944182350765914, 0.14095305057708174, 0.12066203547874466, 0.21038881764980033, 36.417667642235756, 72.65873596072197, 41.23620808124542, 34.604279547929764, 51.62675812840462, 62.043199986219406, 93.05634543299675, 25.972505025565624, 0.33967843861319125, 1.2147268932312727, 1.3400312256999314, 50.68070389330387, 93.09162274003029, 87.75199726223946, 76.0290639102459, 73.87407034635544, 71.11577555537224, 76.28474459052086, 77.36818045377731, 81.77613392472267, 79.405038356781, 78.50319474935532, 71.09669297933578, 66.02993845939636, 60.45812264084816, 58.53259116411209, 56.21637225151062, 57.891531363129616, 57.38194830715656, 55.29521428048611, 57.03652784228325, 55.881386026740074, 57.61658571660519, 53.65631282329559, 52.423484176397324, 54.7593442350626, 53.74773971736431, 51.99397422373295, 53.69632847607136, 53.96743252873421, 52.24596530199051, 48.22928823530674, 48.89003857970238, 50.74493944644928, 52.06694930791855, 51.985113099217415, 54.08445864915848, 56.78974248468876, 52.85887621343136, 50.323979035019875, 48.974295258522034, 51.233703419566154, 49.92934741079807, 49.874759539961815, 50.127521976828575, 52.16357812285423, 51.643667221069336, 49.54749070107937, 47.835785150527954, 45.24778202176094, 46.26374110579491, 46.28517575562, 46.589391231536865, 48.987879529595375, 48.90350125730038, 51.31942681968212, 51.95308841764927, 49.96237903833389, 51.9790106266737, 51.38133689761162, 56.11097350716591, 54.92726482450962, 61.48635886609554, 63.33096228539944, 64.81078907847404, 58.228330090641975, 57.198877930641174, 50.01395747065544, 48.84699448943138, 45.728623420000076, 47.533123791217804, 42.81491316854954, 56.336916983127594, 54.0302849560976, 47.36053325235844, 53.811302706599236, 56.243491396307945, 58.42238947749138, 53.03352624177933, 57.03572228550911, 55.998738929629326, 53.69174212217331, 56.78124614059925, 52.799652591347694, 50.74016310274601, 49.49813514947891, 48.39474655687809, 47.990174666047096, 47.719222605228424, 47.56015934050083, 45.41476026177406, 46.30123749375343, 48.605760633945465, 45.7014624774456, 47.95046679675579, 49.88333947956562, 48.591834381222725, 47.69588805735111, 44.86157834529877, 44.82556387782097, 45.76573982834816, 47.37946383655071, 48.20758379995823, 52.33345180749893, 48.94469104707241, 49.21595089137554, 45.36456875503063, 45.382211208343506, 46.09675906598568, 50.540400221943855, 49.4053403288126, 52.82916180789471, 49.818256571888924, 51.29907891154289, 51.28100328147411, 52.361083924770355, 51.494681015610695, 52.80632123351097, 51.60053953528404, 51.30956254899502, 50.327778831124306, 53.11505846679211, 51.154048293828964, 52.15407483279705, 50.61622515320778, 55.774505361914635, 52.84350983798504, 54.7307925671339, 55.666260570287704, 59.43028159439564, 54.28571105003357, 63.74301977455616, 69.71872732043266, 79.62223470211029, 73.67464944720268, 89.48694616556168, 45.420250967144966, 0.4905268410220742, 1.9853281555697322, 0.569787856657058, 0.046675237026647665, 4.595827264711261, 74.47557806968689, 64.69611123204231, 61.51145651936531, 38.933429047465324, 32.954784259200096, 68.22432830929756, 23.708457313477993, 0.20029691542731598, 0.09459083288675174, 0.05899422052607406, 0.041243432206101716, 0.03508674206386786, 0.021631461822835263, 0.02096601510856999, 0.09153290244285017, 0.11838981678010896, 0.08252713334513828, 0.2048437573830597, 0.2896909334231168, 0.13980368647025898, 0.1579733466496691, 0.2579467243049294, 0.35420541535131633, 0.27320744760800153, 41.365249156951904, 86.03540137410164, 38.124232068657875, 40.274992659687996, 67.61622413992882, 70.12320801615715, 102.79811069369316, 29.83472228050232, 0.550088407471776, 3.304077791981399, 2.492597848176956, 54.1218676418066, 95.34531220793724, 92.32812970876694, 79.68725681304932, 76.58737555146217, 75.85548922419548, 79.29780051112175, 80.2536392211914, 87.22745060920715, 81.7794169485569, 82.75989353656769, 74.56222862005234, 68.93881157040596, 63.802672773599625, 63.17585080862045, 57.962678745388985, 62.337053418159485, 60.64490161836147, 58.137218579649925, 61.32005698978901, 58.46534617245197, 61.40455685555935, 57.85065695643425, 55.58759719133377, 56.63101740181446, 55.5375424772501, 53.99261757731438, 56.34403020143509, 56.66874177753925, 53.16646210849285, 51.68467842042446, 51.712603121995926, 55.65081059932709, 56.12043879926205, 53.68589423596859, 54.98837314546108, 58.84069383144379, 53.180912733078, 50.484987795352936, 50.434651896357536, 50.36743350327015, 51.645012348890305, 50.00826917588711, 52.11174890398979, 53.50549891591072, 51.9642636179924, 52.74161450564861, 50.427747666835785, 49.89070348441601, 49.87888991832733, 49.35625076293945, 48.499677926301956, 50.99668353796005, 52.50068463385105, 56.373911798000336, 52.66119182109833, 53.663483038544655, 55.264572724699974, 52.98646956682205, 57.38059937953949, 58.620301857590675, 65.25890663266182, 66.26980438828468, 66.75313085317612, 57.82198369503021, 60.28600327670574, 52.020853981375694, 51.278947591781616, 51.61879375576973, 48.99431258440018, 50.36597438156605, 58.389456644654274, 52.638936415314674, 48.91437627375126, 57.53643661737442, 60.23427665233612, 61.62165820598602, 55.675874054431915, 58.988486900925636, 58.05237293243408, 57.56474889814854, 59.96427834033966, 54.75084789097309, 53.70424725115299, 50.83684891462326, 52.78186574578285, 50.381887927651405, 51.18116743862629, 49.93669241666794, 47.210114523768425, 48.604096323251724, 50.756734013557434, 47.26364605128765, 50.60975030064583, 52.11852014064789, 51.76844112575054, 49.34967331588268, 46.835017651319504, 46.93373255431652, 45.63711293041706, 48.14880095422268, 48.74227970838547, 54.36821602284908, 50.924757197499275, 52.2805168479681, 48.67587827146053, 48.8223148137331, 50.007615610957146, 54.4343438744545, 54.19423095881939, 56.73639714717865, 53.05593363940716, 54.46838244795799, 53.81772816181183, 55.40564775466919, 55.523338839411736, 56.14107549190521, 54.3364193290472, 53.846040442585945, 53.04100044071674, 55.845284163951874, 55.40237993001938, 56.28783121705055, 53.307312950491905, 59.27078515291214, 55.95681577920914, 58.63097548484802, 59.38199758529663, 63.07392507791519, 56.985724568367004, 69.70788270235062, 69.21992048621178, 83.06409761309624, 77.5208942592144, 92.05921813845634, 51.18782088160515, 0.5771237786393613, 2.60866641998291, 1.3683393504470587, 0.12331247489782982, 9.167940001934767, 85.42668923735619, 70.23183658719063, 73.30353856086731, 55.055101364851, 36.838202476501465, 78.27617973089218, 27.35998347401619, 0.48848691454622895, 0.23149454762460664, 0.24802987987641245, 0.2059250813908875, 0.1541335042566061, 0.10090704396134242, 0.11830951640149578, 0.17721947719110176], [0.044843260329798795, 0.041887887273333035, 0.08982838218798861, 0.01931118906213669, 0.13185817922931165, 0.07480631131329574, 0.08138698671245947, 0.05154759608558379, 0.26025759405456483, 34.23216171562672, 57.86020964384079, 41.87789864838123, 42.16901622712612, 46.88709005713463, 57.91296221315861, 85.99380880594254, 13.900991678237915, 0.38297099992632866, 1.3892258796840906, 13.62719926983118, 73.07810425758362, 76.7106181383133, 83.39246079325676, 71.40281975269318, 70.43609082698822, 69.52318221330643, 70.58145582675934, 75.0424012541771, 75.94633474946022, 74.6191343665123, 68.27402964234352, 59.643750339746475, 57.18125447630882, 57.02528424561024, 55.20464614033699, 55.27566812932491, 55.925524458289146, 55.51317818462849, 58.0447581410408, 53.40462952852249, 52.78340086340904, 51.41601383686066, 54.824297949671745, 50.96332132816315, 49.89521004259586, 52.04016074538231, 50.780710726976395, 51.12507484853268, 51.72594800591469, 48.35549086332321, 44.65119123458862, 45.21151676774025, 46.89160421490669, 45.95672518014908, 50.45450583100319, 50.82905553281307, 53.57345826923847, 52.61173367500305, 52.21344284713268, 49.38865542411804, 53.82849298417568, 53.17954480648041, 49.68095473945141, 47.7369524538517, 46.702009588479996, 46.94507874548435, 48.921953067183495, 44.83084179461002, 41.792156249284744, 42.32683315873146, 44.07204911112785, 41.14699646830559, 45.571748837828636, 46.883495450019836, 48.01268085837364, 46.288135796785355, 45.59599533677101, 49.10221539437771, 52.070923894643784, 49.77168247103691, 52.43167653679848, 55.11008821427822, 62.24161773920059, 57.44641564786434, 59.921165853738785, 51.086905896663666, 43.93426090478897, 47.961387410759926, 50.98327025771141, 48.057256266474724, 38.83525751531124, 34.14364546537399, 54.4627321511507, 53.98680008947849, 54.31328237056732, 50.0012281537056, 50.01205377280712, 49.95431587100029, 52.91718028485775, 50.479223504662514, 49.110780134797096, 48.10492090880871, 47.838479205965996, 47.008159160614014, 43.6429875344038, 45.143519416451454, 43.09009440243244, 42.37010143697262, 43.90102408826351, 44.6078659594059, 42.93545410037041, 47.655663415789604, 48.66562262177467, 46.941487938165665, 47.182528004050255, 47.80961595475674, 43.77117745578289, 42.547168135643005, 45.20274303853512, 44.407829493284225, 49.68828834593296, 47.00475074350834, 49.51065927743912, 46.90349377691746, 45.593726858496666, 43.54588374495506, 43.22311006486416, 41.05274252593517, 47.67704486846924, 49.956276565790176, 48.42833675444126, 47.63015538454056, 47.58914798498154, 49.40238028764725, 50.05347155034542, 48.301119580864906, 48.91652315855026, 48.61689403653145, 52.44946338236332, 48.52952912449837, 48.73479790985584, 47.751121893525124, 49.91278409957886, 47.28739857673645, 50.586457550525665, 48.72154802083969, 54.05584618449211, 51.32497452199459, 56.60450242459774, 56.84836953878403, 69.12763103842735, 68.35955545306206, 76.69166475534439, 69.97171774506569, 91.41392916440964, 26.309776827692986, 1.0534061933867633, 1.8758267001248896, 1.0598764149472117, 0.1646545756375417, 0.2750474988715723, 50.30969180166721, 66.31574392318726, 52.72822022438049, 42.6859974861145, 26.48229707032442, 56.29214398562908, 27.111488208174706, 0.16169333219295368, 0.029062734938634094, 0.022057295027479995, 0.07322665740502998, 0.06684067702735774, 0.03650715705589391, 0.04229925230902154, 0.03190742965671234, 0.09312461625086144, 0.06297282598097809, 0.008958713224274106, 0.0938671498443, 0.009474286925978959, 0.13557593832956627, 0.05574838200118393, 0.14559074625140056, 0.23298838699702173, 45.24433180689812, 63.54619413614273, 49.42605681717396, 33.7188358604908, 51.87064804136753, 67.18992501497269, 93.42934101819992, 14.620321579277515, 0.6121116480790079, 1.3891693577170372, 20.118216164410114, 81.94916144013405, 81.13751739263535, 86.77707597613335, 70.8903032541275, 74.1490463912487, 71.6974863409996, 75.2106486260891, 78.27213674783707, 79.21519294381142, 75.64766317605972, 71.29400879144669, 61.813479512929916, 61.069563031196594, 59.8474308103323, 60.32856099307537, 58.196028023958206, 59.17227923870087, 57.37326577305794, 59.52871531248093, 57.81952142715454, 55.11567011475563, 54.052547961473465, 58.34206938743591, 53.29944357275963, 53.12985487282276, 52.677112966775894, 53.29368308186531, 52.63508342206478, 55.21024703979492, 50.942095667123795, 47.00885832309723, 48.270409628748894, 50.065376311540604, 48.589664697647095, 54.45778101682663, 51.53014451265335, 54.96396705508232, 54.0739294141531, 51.96772143244743, 48.55566032230854, 53.90631280839443, 53.48221376538277, 49.5216178894043, 47.90224738419056, 46.40211068093777, 47.21997119486332, 50.29165796935558, 45.65179914236069, 45.58735080063343, 44.14577275514603, 46.02013997733593, 44.94091048836708, 47.96938978135586, 48.639487624168396, 51.52822181582451, 48.07135351002216, 49.54658254981041, 51.08468681573868, 53.60609471797943, 51.73583507537842, 53.31265166401863, 55.438633784651756, 65.88846445083618, 62.81059920787811, 59.94053341448307, 50.54629750549793, 47.58836902678013, 48.99538032710552, 50.09191408753395, 49.56561952829361, 43.44037100672722, 33.41843158006668, 52.062332555651665, 55.11875554919243, 56.55937224626541, 54.04013402760029, 52.85924479365349, 53.17551702260971, 55.07590904831886, 53.27311858534813, 51.90994173288345, 49.82618294656277, 50.31994365155697, 49.069609344005585, 45.87985150516033, 45.759234577417374, 46.61413170397282, 43.383556455373764, 46.17932103574276, 45.734805688261986, 45.91794826090336, 49.83141526579857, 51.34661816060543, 46.41033723950386, 46.666276305913925, 48.238802924752235, 45.01205787062645, 44.21369411051273, 46.902874410152435, 45.569123178720474, 47.76614248752594, 49.60680551826954, 52.26772293448448, 47.521135434508324, 47.521720603108406, 45.14108754694462, 44.76485833525658, 43.85602690279484, 49.98248375952244, 50.88546350598335, 50.86033545434475, 49.5079842209816, 50.47991506755352, 51.83988109230995, 52.47528299689293, 50.25155872106552, 51.27478301525116, 49.906514436006546, 53.96403931081295, 51.664520502090454, 51.768391728401184, 50.726396441459656, 52.274140790104866, 49.30768556892872, 54.10776659846306, 52.769657000899315, 56.05655662715435, 54.90991875529289, 58.485177308321, 59.35097225010395, 71.96251451969147, 71.05627834796906, 80.26402786374092, 72.92868107557297, 92.36786037683487, 26.92179098725319, 1.0142777930013835, 1.0665312828496099, 1.124860409181565, 0.3210188867524266, 0.8291136100888252, 53.74545983970165, 72.54469648003578, 61.163239404559135, 43.06066878139973, 33.60567793250084, 66.2789086997509, 36.615701615810394, 0.06823622636147775, 0.038462512093246914, 0.05234605421719607, 0.07429794757626951, 0.07130459882318974, 0.03266303247073665, 0.02748250772128813, 0.0549007788504241, 0.2209804969606921, 0.1444602178526111, 0.12252183529199101, 0.177989128860645, 0.24014810827793553, 0.4029483982594684, 0.16584017139393836, 0.164495162316598, 0.296693779528141, 52.88021966814995, 74.2535711824894, 53.229063749313354, 52.582049667835236, 67.84709975123405, 71.69481128454208, 102.47388169169426, 17.33456913381815, 0.5944009171798825, 2.9381940001621842, 25.63416738063097, 92.62409582734108, 82.27284327149391, 91.61802381277084, 73.9067105948925, 79.41275954246521, 73.86557400226593, 77.54796400666237, 78.9094765484333, 81.49787485599518, 79.80571925640106, 75.15193417668343, 65.21897837519646, 63.823305666446686, 62.55062855780125, 61.8630288541317, 60.77042408287525, 63.27618442475796, 60.98779521882534, 64.43132624030113, 60.25725021958351, 58.54356877505779, 55.557647198438644, 60.135424956679344, 55.03429368138313, 56.53447598218918, 56.18490234017372, 54.157046154141426, 53.8504596054554, 58.23948249220848, 52.60193020105362, 50.65643459558487, 52.39599645137787, 54.25719738006592, 51.13946847617626, 57.73787520825863, 54.112189561128616, 57.06300862133503, 56.169505566358566, 53.37508611381054, 52.15564414858818, 55.62591053545475, 55.16184523701668, 52.3524621874094, 50.305439829826355, 47.22276784479618, 46.90336838364601, 51.58295027911663, 49.27457794547081, 44.95854154229164, 46.07231117784977, 48.69972579181194, 47.759888023138046, 49.59072858095169, 51.329712867736816, 53.22229631245136, 50.888294354081154, 51.65736548602581, 53.535068929195404, 55.99786497652531, 54.48160193860531, 55.272472500801086, 58.11197653412819, 67.22550630569458, 65.81100940704346, 62.11536191403866, 58.59825164079666, 50.05306497216225, 50.29969073832035, 53.9340703189373, 51.1819463968277, 46.39045290648937, 40.788850486278534, 56.280698999762535, 57.945750653743744, 60.16665168106556, 56.23172342777252, 55.78229874372482, 54.67145495116711, 57.23892778158188, 55.763983726501465, 54.86904434859753, 51.278191432356834, 54.00105692446232, 50.433219373226166, 47.93351590633392, 49.290901869535446, 49.90673862397671, 47.39470861852169, 50.33110365271568, 48.29516530036926, 48.887215331196785, 53.06409940123558, 51.64829157292843, 48.43573495745659, 48.60845848917961, 50.24216182529926, 49.037280678749084, 45.81479139626026, 47.68633157014847, 46.306393817067146, 48.90090599656105, 48.819274976849556, 55.6474743783474, 51.92101813852787, 50.17780467867851, 48.79689797759056, 48.574742898344994, 47.17219635844231, 52.51604340970516, 53.88153433799744, 53.770029321312904, 52.471737787127495, 54.198437333106995, 55.02918295562267, 55.36657825112343, 53.05043153464794, 54.39693108201027, 53.597883358597755, 58.52414421737194, 54.3882941454649, 53.23171220719814, 54.220407754182816, 56.692718490958214, 51.717516258358955, 58.06423209607601, 55.22924982011318, 60.44616848230362, 57.116779536008835, 62.92773552238941, 62.818696573376656, 74.22160729765892, 75.04628464579582, 83.83338913321495, 74.22323361039162, 99.59629610180855, 30.824439972639084, 0.9386276523582637, 6.510146493092179, 2.5519739370793104, 0.5181233945768327, 2.155997660011053, 64.1195073723793, 78.43581676483154, 71.66744515299797, 60.044074058532715, 34.84627716243267, 77.45007365942001, 43.09582069516182, 0.44528548896778375, 0.22944978234590963, 0.12764834653353319, 0.13741484668571502, 0.23914704011986032, 0.11221810185816139, 0.15209979697829112, 0.10954899742500857], [0.040475480054738, 0.036141953605692834, 0.012431919822120108, 0.09626577855669893, 0.04070349008543417, 0.01212883598782355, 0.054027809092076495, 0.07425911098835059, 0.14322670904221013, 42.79548481106758, 53.89061205089092, 21.717138066887856, 46.89971677958965, 52.32425630092621, 60.29581815004349, 78.87664631009102, 6.048488365486264, 0.1315051395795308, 0.7137580937705934, 6.821200652047992, 50.015435591340065, 88.9495638012886, 78.1778334081173, 71.77721366286278, 68.1721343100071, 69.89902764558792, 70.72687402367592, 75.02695128321648, 72.936432659626, 65.95171585679054, 57.63001039624214, 58.091434836387634, 58.77832017838955, 66.18785798549652, 68.92361238598824, 65.07446452975273, 67.2133469581604, 64.8646853864193, 64.40254658460617, 64.39178556203842, 61.12997978925705, 58.30090619623661, 56.68146349489689, 55.38863606750965, 50.83905279636383, 51.152463778853416, 49.968082532286644, 50.19139274954796, 50.70901237428188, 46.909983828663826, 46.53392180800438, 42.7309300750494, 46.47077299654484, 47.5467536598444, 50.07937856018543, 49.59713503718376, 53.98105479776859, 49.265697821974754, 51.07346601784229, 51.63439191877842, 51.20743542909622, 46.6094883531332, 50.09556569159031, 53.324849009513855, 51.10643684864044, 48.45544070005417, 47.94397294521332, 47.29035101830959, 44.50663939118385, 48.214799612760544, 44.17426362633705, 42.778587117791176, 45.02768263220787, 45.38441129028797, 46.060930788517, 48.58200050890446, 52.23124869167805, 54.54617187380791, 53.75363700091839, 52.01423093676567, 53.149769604206085, 56.34345643222332, 60.194910764694214, 60.36018669605255, 56.123053058981895, 42.1677128970623, 44.35617886483669, 48.93596671521664, 50.98608210682869, 49.03605714440346, 47.821980491280556, 30.025498643517494, 33.967581912875175, 51.60330958664417, 49.03737187385559, 56.238756850361824, 49.73327413201332, 50.86687870323658, 50.16119956970215, 50.66201649606228, 46.5738120675087, 47.16665245592594, 45.460072830319405, 45.92500448226929, 43.264174461364746, 42.593601644039154, 42.679260447621346, 43.33229720592499, 45.47382429242134, 44.55271951854229, 43.97075034677982, 48.16959723830223, 47.95422099530697, 50.434720292687416, 48.00780192017555, 47.94161707162857, 48.148933947086334, 44.462075382471085, 45.461273565888405, 48.29890049993992, 48.15847523510456, 48.651278391480446, 46.99715495109558, 46.39453388750553, 44.250662326812744, 42.72473640739918, 40.84789551794529, 42.83615402877331, 47.512802481651306, 49.11468632519245, 48.49725365638733, 49.804759696125984, 49.17837090790272, 50.22559471428394, 50.23270793259144, 49.870549365878105, 50.03135293722153, 48.61004300415516, 49.78181652724743, 52.437771409749985, 50.64164198935032, 50.58532141149044, 48.72657135128975, 46.582574397325516, 48.233057633042336, 48.985272869467735, 51.393587440252304, 52.27313384413719, 55.699497386813164, 59.46868233382702, 69.79257255792618, 68.93606051802635, 76.51058927178383, 70.87107628583908, 85.93909934163094, 18.6524049192667, 0.9208340977784246, 1.0860743466764688, 0.7413737650495023, 0.29701904801186174, 0.6832805229350924, 29.99646060168743, 71.72348454594612, 49.330887123942375, 41.042008101940155, 27.749513871967793, 53.76152537763119, 39.45376172661781, 0.04504358825215604, 0.05839560049935244, 0.008183301561075496, 0.0327369874867145, 0.030476311039819848, 0.034446825229679234, 0.03238950652303174, 0.007103584302967647, 0.10238645598292351, 0.030438990288530476, 0.025226710895367432, 0.03474918732536025, 0.03292141489509959, 0.09874323077383451, 0.021734622205258347, 0.0683993281563744, 0.1391439765575342, 52.91961595416069, 61.84418946504593, 24.89713042974472, 40.86023345589638, 61.60702899098396, 67.50333219766617, 86.0141073167324, 7.08389338105917, 0.34505354706197977, 0.31648216769099236, 6.043420862406492, 59.19755928218365, 89.2887032032013, 81.45384281873703, 73.67364630103111, 71.63646161556244, 71.73106893897057, 74.86162215471268, 77.22476854920387, 74.8667822778225, 68.17088797688484, 60.03614768385887, 59.2177551984787, 62.09145359694958, 66.91606611013412, 69.2795392870903, 67.68679395318031, 70.66299185156822, 68.81824404001236, 68.73863831162453, 64.91209924221039, 65.56790605187416, 62.10842728614807, 59.051761105656624, 56.82343527674675, 52.6197474449873, 54.080176278948784, 52.2205750644207, 52.84317925572395, 52.93793477118015, 50.09681962430477, 48.5391616076231, 48.75831104815006, 50.27154944837093, 47.92549453675747, 51.2414588034153, 51.45994707942009, 55.02341106534004, 49.16688032448292, 50.63114695250988, 53.52645859122276, 51.73043556511402, 47.46985338628292, 52.247523218393326, 54.80728626251221, 51.45837776362896, 48.56925219297409, 47.68639996647835, 49.13726471364498, 47.54980869591236, 51.12754471600056, 47.07760043442249, 45.59490479528904, 46.82353846728802, 47.58573956787586, 46.90119870007038, 50.18378175795078, 54.271043837070465, 59.36282381415367, 55.06492003798485, 56.37419678270817, 56.92682392895222, 55.91343730688095, 62.188523188233376, 61.264066994190216, 57.18651719391346, 42.30167470872402, 46.722528487443924, 50.53493231534958, 52.55595646798611, 50.205148011446, 51.75544202327728, 34.85431373119354, 32.928782254457474, 54.12851728498936, 55.13547845184803, 56.78064577281475, 54.275588393211365, 51.669296845793724, 51.88553184270859, 51.57677561044693, 47.455870136618614, 48.689223155379295, 46.23038649559021, 46.392341405153275, 46.33047312498093, 44.30040545761585, 47.158011719584465, 46.52238942682743, 47.184990271925926, 47.043611258268356, 44.5346324890852, 47.646745294332504, 48.7269589304924, 48.7002881616354, 49.27008278667927, 47.29757443070412, 48.4741622954607, 45.648314729332924, 45.92894867062569, 49.07673396170139, 49.079967588186264, 50.059650018811226, 50.103742852807045, 49.020284190773964, 48.407897651195526, 45.32565884292126, 44.36660550534725, 45.87525375187397, 51.00280120968819, 50.831836983561516, 48.954076543450356, 50.73847979307175, 51.64001941680908, 53.701051622629166, 51.999673917889595, 52.29616440832615, 51.69840708374977, 51.9520016759634, 51.964275017380714, 53.545943945646286, 52.801221907138824, 52.05520413815975, 52.38023869693279, 50.20379148423672, 51.51383198797703, 52.36600086092949, 54.06476430594921, 54.74532678723335, 58.762513026595116, 62.73250959813595, 73.44524055719376, 72.2547796368599, 81.0467554628849, 73.84709939360619, 86.1640776693821, 21.633555851876736, 0.78928331611678, 1.3151007634587586, 0.8163359644822776, 0.2626507531385869, 0.7444348570425063, 32.36785635352135, 78.94970118999481, 57.30204239487648, 45.36747179925442, 35.497729405760765, 58.42207029461861, 52.5077560544014, 0.0862064714601729, 0.06975074938964099, 0.026515954996284563, 0.08538931491784751, 0.09743370377691463, 0.020154101839580107, 0.032216433974099346, 0.06511207408038899, 0.19850823562592268, 0.19719781063031405, 0.07490012620110065, 0.27619779808446765, 0.12366626411676407, 0.13767486554570496, 0.082500193384476, 0.17129412561189383, 0.26014478760771453, 61.878178641200066, 72.119719684124, 32.12813101708889, 63.799192160367966, 73.92406046390533, 73.46907287836075, 94.29074719548225, 8.620222192257643, 0.43999047309625894, 2.8064403450116515, 10.092950016260147, 64.52818304300308, 96.16675972938538, 83.74626740813255, 77.75059193372726, 75.11604890227318, 75.71998849511147, 76.6672320663929, 79.52378958463669, 79.92139264941216, 71.16339460015297, 63.819901049137115, 62.98992678523064, 64.67702105641365, 69.38974857330322, 74.81354713439941, 72.30953469872475, 74.53969582915306, 74.43061128258705, 72.52810657024384, 68.106200248003, 69.4091047346592, 64.38426196575165, 62.80351638793945, 60.0101912766695, 53.555728420615196, 56.410287246108055, 55.3326840698719, 53.579857125878334, 55.2800302952528, 52.640327140688896, 51.79638482630253, 50.39224237203598, 52.78507277369499, 51.744297221302986, 54.38178509473801, 53.22213672101498, 58.18346969783306, 51.979591995477676, 52.82500483095646, 54.05624896287918, 53.831540420651436, 47.04443961381912, 54.561211466789246, 55.254085287451744, 53.229151144623756, 50.06587788462639, 50.867904648184776, 51.278347223997116, 48.49595032632351, 52.89332516491413, 47.60135293006897, 48.01572069525719, 49.68800336122513, 50.289001911878586, 50.81367015838623, 51.814946830272675, 57.726278230547905, 59.575749188661575, 57.045863941311836, 56.840298771858215, 58.017627596855164, 60.04497081041336, 66.48021429777145, 66.63147658109665, 61.07739821076393, 50.70875018835068, 49.662301540374756, 54.51713763177395, 55.152007564902306, 52.415869385004044, 52.198832631111145, 38.46241392195225, 39.869634211063385, 58.04545730352402, 58.2629082351923, 59.809980019927025, 57.62171544134617, 54.87136982381344, 54.214540868997574, 57.43525944650173, 48.439660146832466, 52.23662160336971, 50.50358399748802, 50.87256699800491, 50.02716936171055, 48.91290955245495, 49.377149641513824, 50.147554501891136, 49.18878614902496, 49.61339816451073, 45.54224722087383, 51.585021167993546, 50.34537188708782, 50.94477452337742, 50.68795010447502, 49.90487292408943, 48.479584604501724, 46.12615808844566, 47.77514800429344, 50.02737835049629, 51.091553047299385, 52.7713593095541, 52.418232858181, 50.27946062386036, 49.66358967125416, 48.02453242242336, 47.21155844628811, 49.23275738954544, 54.50498968362808, 53.422271981835365, 52.77835473418236, 54.416291043162346, 54.03906628489494, 59.180748984217644, 55.32725416123867, 55.33832296729088, 55.17031878232956, 53.9533656835556, 55.06416007876396, 57.526553347706795, 55.04384636878967, 55.36214008927345, 55.31430445611477, 53.27745795249939, 56.571998968720436, 57.597385346889496, 56.71874329447746, 58.73507469892502, 63.12746800482273, 65.17248407006264, 76.18289485573769, 74.94989901781082, 83.62442314624786, 76.02412417531013, 87.95223891735077, 22.45724145323038, 1.18878509150818, 6.847879020497203, 1.8159135337918997, 0.5176265118643641, 1.2338087568059564, 41.32291182875633, 85.82983240485191, 66.32379949092865, 59.34928134083748, 38.366917446255684, 70.72884991765022, 61.50656618177891, 0.2569912833860144, 0.1793265828746371, 0.15430574188940227, 0.22722958819940686, 0.14183794293785468, 0.2442576619796455, 0.11445005162386224, 0.20592177141224965], [0.044966074638068676, 0.042002860791399144, 0.0685566189349629, 0.07476499595213681, 0.044335468046483584, 0.041362287156516686, 0.06487973732873797, 0.08462807920295745, 0.20392673002788797, 51.90860040485859, 50.88223747909069, 48.44393491744995, 43.01675073802471, 50.81538766622543, 67.90470466017723, 79.85310271382332, 4.407375426962972, 0.012741214504785603, 0.21226591692538932, 2.190591716207564, 51.279152780771255, 85.19120067358017, 78.28727513551712, 77.70060181617737, 69.62481915950775, 70.98884716629982, 68.17791000008583, 70.96930861473083, 60.742248594760895, 57.272726967930794, 57.927530631423, 63.411859944462776, 66.94559812545776, 73.90043333172798, 75.41472047567368, 78.09149444103241, 72.4448074400425, 68.5252645611763, 70.03783419728279, 69.33113291859627, 67.6686917245388, 64.66200426220894, 61.2918397039175, 57.70458899438381, 54.75449189543724, 50.63799038529396, 50.7601348310709, 49.95015509426594, 49.51777629554272, 49.208921268582344, 45.16727954149246, 45.87341845035553, 45.98258279263973, 46.87887869775295, 46.667750626802444, 48.17962110042572, 52.7286572009325, 50.03680184483528, 47.17430144548416, 53.142291605472565, 48.23244966566563, 51.256038621068, 53.45180779695511, 57.5942999124527, 52.77233585715294, 51.74865938723087, 52.672458216547966, 55.94167739152908, 51.4890231192112, 52.91608974337578, 54.22851651906967, 50.85800997912884, 48.14484916627407, 45.154033452272415, 49.68649484217167, 53.64386469125748, 58.42778518795967, 59.18698064982891, 58.394525572657585, 55.36583349108696, 56.50711365044117, 57.38348342478275, 55.371951162815094, 56.4056932926178, 43.87993901968002, 37.087184116244316, 46.38531558215618, 45.464001819491386, 46.46581806242466, 49.372931867837906, 48.267555981874466, 38.41713935136795, 28.30226831138134, 39.560927376151085, 50.63063018023968, 51.195500269532204, 54.29864935576916, 51.93860359489918, 51.80391222238541, 45.312272161245346, 47.936836928129196, 45.3455925732851, 45.10353796184063, 40.2106849104166, 42.05907292664051, 40.32896876335144, 40.353952422738075, 40.912678241729736, 44.98823694884777, 46.46493270993233, 47.436601370573044, 40.953871831297874, 46.335093677043915, 46.30895107984543, 48.956117033958435, 43.711429461836815, 47.78845489025116, 44.18790489435196, 42.012384831905365, 44.114781618118286, 44.26196672022343, 51.40700452029705, 47.34806232154369, 45.99197968840599, 45.11823557317257, 43.65163207054138, 41.30371145904064, 42.73983679711819, 45.99563509225845, 48.242249339818954, 48.22396472096443, 48.509948775172234, 47.68840625882149, 50.110688880085945, 47.775432989001274, 50.422275960445404, 48.89686681330204, 50.204680636525154, 48.48240785300732, 50.29845580458641, 49.59829397499561, 49.77311119437218, 49.9783343821764, 50.11694334447384, 49.64799150824547, 50.421006828546524, 50.64686290919781, 52.31905058026314, 53.299473971128464, 61.231704130768776, 71.15951880812645, 72.1561673283577, 76.30668461322784, 70.18605664372444, 73.62351179122925, 50.464149713516235, 0.25687322253361344, 0.43664896802511066, 0.9139720816165209, 0.226825162244495, 0.5027396231889725, 18.8353556022048, 74.88363057374954, 53.598449528217316, 35.877918004989624, 25.744680650532246, 47.75059372186661, 49.965776056051254, 0.22112278151325881, 0.0874450417177286, 0.09650076477555558, 0.06084238717448898, 0.02600179323053453, 0.03822159982519224, 0.039443471760023385, 0.042346011323388666, 0.051481730479281396, 0.07164982365793549, 0.057364571839571, 0.09128078003413975, 0.09394702719873749, 0.038191821149666794, 0.08428335902863182, 0.012841137267969316, 0.20683606766397133, 62.606914937496185, 57.69982784986496, 46.541027426719666, 39.48609419167042, 62.54241339862347, 73.23204159736633, 86.69535756111145, 4.581107804551721, 0.09386877514771186, 0.3418138943379745, 2.5717801367864013, 64.7695004940033, 90.23956418037415, 83.14841508865356, 79.6748998761177, 72.29205563664436, 73.48774507641792, 71.80259630084038, 71.50602221488953, 63.21003757417202, 59.14910428225994, 59.73610818386078, 63.59388157725334, 68.91744911670685, 75.29412254691124, 77.37077951431274, 75.95939844846725, 73.10059905052185, 73.56638565659523, 73.26893761754036, 71.75637558102608, 69.76384609937668, 67.61248514056206, 64.7357127070427, 60.38514755666256, 56.90508909523487, 52.58044995367527, 52.986610159277916, 52.155020982027054, 51.41437232494354, 49.98401127755642, 45.61670422554016, 47.79759339988232, 48.74028481543064, 48.10852311551571, 49.06400464475155, 50.79920433461666, 53.12296964228153, 50.33876024186611, 47.31990583240986, 51.10170990228653, 51.591743007302284, 51.7071770131588, 54.27770107984543, 57.885056510567665, 52.7762458473444, 52.26908326148987, 55.87228171527386, 57.8849159181118, 54.61062781512737, 56.28144755959511, 56.03477619588375, 52.679909616708755, 49.91752624511719, 46.565346121788025, 52.31533817946911, 56.1931174993515, 60.511285588145256, 61.42403461039066, 60.71158044040203, 55.77124513685703, 60.66744580864906, 61.20310686528683, 59.689336493611336, 58.07677522301674, 46.079090014100075, 38.572824597358704, 48.25668476521969, 47.72310599684715, 47.84694895148277, 50.312378257513046, 49.349289536476135, 41.82847090065479, 28.759315386414528, 38.67202587425709, 52.28291451931, 56.59326262772083, 55.36711782217026, 54.01147976517677, 53.63206632435322, 46.70797146856785, 49.283336475491524, 47.957485020160675, 46.55077390372753, 42.6221989095211, 44.81824167072773, 43.05551625788212, 42.71411217749119, 44.00278262794018, 45.33868834376335, 46.32738769054413, 49.83539745211601, 41.422550082206726, 47.22639665007591, 48.46355326473713, 49.025919288396835, 43.66610549390316, 47.56539165973663, 46.0436987131834, 44.12385933101177, 43.67776706814766, 46.03159636259079, 53.80508244037628, 52.0489876717329, 47.42612533271313, 47.70607151091099, 46.077855080366135, 43.909224048256874, 44.56291817128658, 50.003808215260506, 51.327816769480705, 50.88710881769657, 49.92006830871105, 50.949341878294945, 52.64707937836647, 50.08695915341377, 53.17210100591183, 52.470271065831184, 52.037911266088486, 50.17485223710537, 53.69857795536518, 52.35299035906792, 52.390300557017326, 52.01636642217636, 53.097503408789635, 50.983144864439964, 53.143834322690964, 54.46470804512501, 54.92931291460991, 55.96384160220623, 63.498863875865936, 73.92621874809265, 75.98626300692558, 77.43287578225136, 75.23318141698837, 75.29986783862114, 57.3562540858984, 0.20933137595420703, 0.26676625886466354, 0.579492476535961, 0.13126259087584913, 0.3937874757684767, 20.91057624667883, 80.73430582880974, 63.285657316446304, 39.90366518497467, 28.913511112332344, 56.67865164577961, 62.29549504816532, 0.76676614000462, 0.06466170176281594, 0.0366348175884923, 0.02981181984068826, 0.04343173626693897, 0.04370662405563053, 0.056142480971175246, 0.032266421330859885, 0.1611182716442272, 0.13038926117587835, 0.21813620114699006, 0.17275480582611635, 0.13548278395319358, 0.19311374227982014, 0.17892432399094105, 0.1629108254564926, 0.44441097183153033, 73.72603788971901, 69.75825279951096, 62.74727560579777, 58.41179944574833, 70.79292207956314, 80.78386276960373, 95.87644010782242, 5.700475964695215, 0.20299290044931695, 0.5727648187894374, 2.766212378628552, 72.65587091445923, 94.84255358576775, 87.30137184262276, 84.52183619141579, 78.77665087580681, 77.23629713058472, 73.6847873032093, 75.60889005661011, 67.15877428650856, 61.16239584982395, 63.452779948711395, 68.5633385181427, 71.22006475925446, 79.08169850707054, 80.7716578245163, 78.94436627626419, 77.86589294672012, 75.59873700141907, 76.94840177893639, 75.14161393046379, 73.60070541501045, 72.45842590928078, 69.76123183965683, 63.81617724895477, 61.38580106198788, 53.67058105766773, 55.32909706234932, 53.85540693998337, 53.11802610754967, 53.261563405394554, 49.40318964421749, 51.012490689754486, 51.16427734494209, 51.50320015847683, 51.11562095582485, 54.43150542676449, 54.580461233854294, 52.564855590462685, 47.97059431672096, 53.13418664038181, 52.40161634981632, 52.27273866534233, 55.750794634222984, 59.3588188290596, 56.02056875824928, 53.62361937761307, 56.053687781095505, 58.92124190926552, 54.491485208272934, 59.00360248982906, 56.61311276257038, 55.482426434755325, 54.95647385716438, 49.09033723175526, 54.52153019607067, 56.988753005862236, 63.26631635427475, 65.37052184343338, 61.830681189894676, 59.53749664127827, 60.73168136179447, 62.11305923759937, 60.50153911113739, 60.44892333447933, 49.73461925983429, 45.09048566222191, 51.54461793601513, 50.07792703807354, 51.850155740976334, 52.90335662662983, 50.76933793723583, 45.1212640106678, 32.44755707681179, 46.042258590459824, 56.623208820819855, 60.61850443482399, 58.228535279631615, 58.315007239580154, 55.59993892908096, 49.990824311971664, 52.45127968490124, 51.75729252398014, 50.42500041425228, 44.20035682618618, 45.98592661321163, 44.710620045661926, 44.28292639553547, 45.58350920677185, 49.3634057790041, 50.47351621091366, 51.16115391254425, 39.87201668322086, 50.58769628405571, 50.85517153143883, 50.87307997047901, 46.9234237074852, 51.223352774977684, 50.38317985832691, 45.51603242754936, 42.71315462887287, 46.85262590646744, 54.70657266676426, 53.12219828367233, 50.15979744493961, 50.812997594475746, 49.101877212524414, 46.81502312421799, 47.63326741755009, 51.24310031533241, 53.44694785773754, 53.748241290450096, 52.24376142024994, 54.01927314698696, 55.356672182679176, 54.23431120812893, 56.515967175364494, 53.96169863641262, 55.662377178668976, 51.35201387107372, 56.63278430700302, 55.09504482150078, 55.310048684477806, 55.2048247307539, 57.26611152291298, 54.48955491185188, 56.57531999051571, 58.47739912569523, 59.208654686808586, 59.44557197391987, 67.1871891617775, 76.79195657372475, 79.2295029759407, 80.31266525387764, 77.01216235756874, 79.1615854203701, 56.1988589912653, 0.19485713622998446, 3.6989820515736938, 2.5682503636926413, 0.327105121104978, 0.838012732565403, 27.61339757591486, 89.99682560563087, 70.70336848497391, 51.746250316500664, 36.14014953374863, 66.10821425914764, 72.81292408704758, 0.777841773815453, 0.1792083735927008, 0.13186755997594446, 0.14654578641057014, 0.14312742452602834, 0.15477466047741473, 0.10422951294458471, 0.12895037041744217], [0.039475510275224224, 0.046286715296446346, 0.05406824129750021, 0.030406764381041285, 0.031752387585584074, 0.08146342050167732, 0.05288424486934673, 0.04894431272987276, 0.3952824877342209, 53.63841578364372, 44.661260694265366, 38.077015802264214, 39.26536783576012, 58.77105876803398, 66.34516954421997, 77.4625825881958, 3.4513289155438542, 0.12030985672026873, 0.5863565113395452, 2.638205559924245, 49.1684078425169, 85.11477917432785, 78.87933656573296, 74.76501613855362, 68.76467451453209, 68.44746753573418, 64.35864374041557, 60.10743945837021, 55.52889034152031, 60.201412215828896, 65.30173033475876, 70.4968723654747, 71.498361825943, 73.43685060739517, 74.8037588596344, 77.78340697288513, 82.9451335966587, 74.32436898350716, 67.36534640192986, 70.71308836340904, 67.45327368378639, 66.51537001132965, 63.62550728023052, 59.343422055244446, 55.86660102009773, 53.23686093091965, 50.362208783626556, 52.05990828573704, 50.869413167238235, 48.223033770918846, 46.42622798681259, 43.719302639365196, 46.24287262558937, 47.078846767544746, 47.670946195721626, 47.694276943802834, 49.82750527560711, 49.26961161196232, 48.343909084796906, 52.15999111533165, 51.451967507600784, 45.13816550374031, 54.55444023013115, 56.04429088532925, 54.35273565351963, 58.51718679070473, 58.967105448246, 60.538108348846436, 59.80680339038372, 59.321751818060875, 57.775071412324905, 57.25690081715584, 53.26541259884834, 51.98091432452202, 52.36552968621254, 57.00568489730358, 58.74161794781685, 60.90398691594601, 55.06407268345356, 54.194451346993446, 56.70297034084797, 59.56952512264252, 56.62906430661678, 48.38536486029625, 39.08025696873665, 32.80621603131294, 42.18988850712776, 45.51226302981377, 45.49372002482414, 44.184762462973595, 44.971305057406425, 42.50627472996712, 33.68879087269306, 31.669113747775555, 45.840459018945694, 48.64161550998688, 53.79903696477413, 53.52161765098572, 52.98662915825844, 47.92026601731777, 44.7620464861393, 43.70513319969177, 43.679856956005096, 40.687114745378494, 41.15109644830227, 42.364568933844566, 44.34310756623745, 41.08904957771301, 45.396616235375404, 48.01771938800812, 51.049329712986946, 45.57410471141338, 44.10970129072666, 41.79831951856613, 43.273700550198555, 41.748131811618805, 43.15600946545601, 46.51068985462189, 46.03642210364342, 45.367779582738876, 51.65191277861595, 51.43447324633598, 47.81979940831661, 44.11340609192848, 44.255491867661476, 42.41491623222828, 40.77962838113308, 45.00655576586723, 47.14055545628071, 47.59445250034332, 46.747869327664375, 47.34880328178406, 46.775885224342346, 50.04043824970722, 48.59898939728737, 49.63596895337105, 50.02657279372215, 51.91566802561283, 49.60834443569183, 56.68593965470791, 51.83630168437958, 53.68766114115715, 49.21557851135731, 51.28866367042065, 47.20198296010494, 52.265735641121864, 51.03001914918423, 54.28588964045048, 51.348157078027725, 58.15299153327942, 63.49735535681248, 76.52361497282982, 71.25563845038414, 82.57195562124252, 63.26457604765892, 89.29272338747978, 15.47388307750225, 0.7776442437898368, 0.23896726226666942, 0.05708848548238166, 0.36986182210966945, 9.71865015104413, 76.15207090973854, 48.41410651803017, 45.68499036133289, 39.31516796350479, 45.22957719862461, 55.384429693222046, 2.317884648218751, 0.20030524232424796, 0.04278681364667136, 0.09480145439738408, 0.07715501575148664, 0.11501875938847661, 0.029258830763865262, 0.09256397563149221, 0.048735168093116954, 0.03610197782109026, 0.0931991872494109, 0.04227040502883028, 0.014489182867691852, 0.022486065281555057, 0.0406792700960068, 0.050373689155094326, 0.8721582347061485, 64.38648104667664, 52.00878202915192, 43.242306634783745, 37.94342637062073, 69.23975542187691, 71.95299223065376, 85.90711265802383, 3.2890989957377315, 0.12605167517904192, 0.6087930605281144, 2.3467633360996842, 59.019322246313095, 89.40669447183609, 83.91397520899773, 78.8029682636261, 72.50554338097572, 71.69969022274017, 65.01581847667694, 63.45094084739685, 59.600470662117004, 63.92289072275162, 68.25885325670242, 72.17092573642731, 73.51997494697571, 77.39451304078102, 76.81040838360786, 81.44171386957169, 85.23229166865349, 76.15860655903816, 70.70081502199173, 71.94972440600395, 68.61389860510826, 69.88179177045822, 66.11652061343193, 62.83472791314125, 58.60279239714146, 56.98253273963928, 51.78920701146126, 54.59705874323845, 51.87382087111473, 51.07932150363922, 49.72574293613434, 47.14669972658157, 50.039480701088905, 48.79081830382347, 48.46239812672138, 49.615814834833145, 51.70172430574894, 50.92523597180843, 49.32345472276211, 53.17289516329765, 52.964202761650085, 48.67302082479, 55.48522308468819, 58.27030263841152, 54.020682871341705, 59.72555615007877, 60.90782471001148, 62.76467487215996, 61.21930539608002, 60.66386640071869, 58.8971322029829, 60.82112856209278, 56.56775839626789, 54.84889402985573, 56.165500581264496, 58.808543756604195, 61.74584314227104, 63.20973739027977, 58.105155900120735, 56.90800353884697, 59.20601382851601, 61.80541254580021, 56.06702886521816, 48.94164741039276, 40.63590109348297, 35.37654250860214, 45.83014637231827, 47.380710169672966, 48.84935416281223, 47.85446874797344, 47.82646805047989, 43.01582358777523, 36.75127454102039, 32.224596440792084, 46.20810069143772, 52.276720851659775, 54.597389325499535, 57.70184554159641, 54.496554136276245, 49.954673051834106, 48.44834268093109, 46.81959807872772, 44.66702498495579, 42.90308743715286, 44.28940124809742, 44.53730374574661, 45.3861477971077, 43.363535329699516, 45.79648397862911, 50.662818253040314, 52.381561025977135, 47.504218742251396, 44.579846262931824, 42.45769813656807, 43.29866141080856, 43.70285712182522, 43.707690462470055, 47.65057548880577, 48.473428934812546, 46.57226175069809, 51.62208057940006, 54.66965764760971, 49.56482537090778, 46.320962235331535, 46.79792784154415, 46.282724887132645, 43.16794462502003, 47.256247848272324, 48.974280059337616, 50.17867483198643, 49.14498209953308, 51.71392925083637, 50.92916116118431, 50.49973480403423, 51.75016030669212, 51.78621657192707, 52.564752995967865, 54.119253382086754, 51.644506976008415, 59.646759778261185, 55.87459199130535, 57.21829488873482, 53.819783851504326, 54.02224838733673, 51.168479919433594, 55.77871933579445, 51.72297276556492, 59.962370842695236, 54.26608890295029, 59.61042232811451, 64.50948804616928, 80.312969237566, 73.55968281626701, 85.66306695342064, 65.58449596166611, 94.7657673060894, 18.858574256300926, 0.7934031856711954, 0.17835750128142536, 0.03149148185912054, 0.35983579291496426, 11.969875451177359, 80.98272129893303, 58.37324671447277, 46.402958035469055, 36.53282046318054, 51.685092598199844, 66.2391248345375, 3.522285595536232, 0.2689452935010195, 0.13911567104514688, 0.10849507350940257, 0.12658670428209007, 0.07158620675909333, 0.03867035426083021, 0.01866209742729552, 0.14498231874313205, 0.11409749437007122, 0.20977175154257566, 0.14058616245165467, 0.19964222243288532, 0.1653129793703556, 0.17357766948407516, 0.3190776065457612, 1.6478417837060988, 76.38935297727585, 60.14642916619778, 51.29212528467178, 52.85905100405216, 79.01533126831055, 77.46265098452568, 95.49613371491432, 4.2071484960615635, 0.3582449251553044, 1.8077125051058829, 3.8464606879279017, 67.09917828440666, 93.06878596544266, 88.77658948302269, 79.41109523177147, 76.0755430161953, 75.80966368317604, 70.52230060100555, 66.60924777388573, 62.2294507920742, 66.66081100702286, 71.49909898638725, 76.00828662514687, 76.47108659148216, 79.68066796660423, 82.53428444266319, 84.3536040186882, 80.98979651927948, 76.73679873347282, 74.46107044816017, 75.00809669494629, 72.01084792613983, 72.00272396206856, 69.89037171006203, 64.50038373470306, 61.954634338617325, 60.35340406000614, 56.68418414890766, 56.27607084810734, 54.547646194696426, 52.150871604681015, 51.683291494846344, 48.49564254283905, 54.71640653908253, 53.415933921933174, 52.1840438246727, 52.71950729191303, 53.80046188831329, 51.37002490460873, 49.24677483737469, 52.63446785509586, 51.88268579542637, 47.84648917615414, 57.27138563990593, 59.64433170855045, 56.34945631027222, 61.29179410636425, 62.20420494675636, 64.65878203511238, 62.984789460897446, 61.628828421235085, 60.79363323748112, 63.65409694612026, 56.84232026338577, 54.950481578707695, 59.09824401140213, 61.82633802294731, 64.19909790158272, 66.3470770418644, 59.63358208537102, 61.0826001316309, 62.07822270691395, 64.97361034154892, 60.11914663016796, 51.69285178184509, 45.28750889003277, 38.998644948005676, 48.27057681977749, 49.184404984116554, 51.79000496864319, 50.56803613901138, 48.74843917787075, 45.176980420947075, 38.999028727412224, 36.01133644580841, 49.35020908713341, 55.863439589738846, 56.635736748576164, 58.979249596595764, 56.093923822045326, 52.11617946624756, 49.955444410443306, 50.567188784480095, 47.73681566119194, 44.87759828567505, 48.066235184669495, 48.474834859371185, 49.15956191718578, 45.507604479789734, 48.76620702445507, 51.27397745847702, 54.72451150417328, 48.49468119442463, 44.869740307331085, 43.4723386913538, 45.411279648542404, 45.929298251867294, 46.925760582089424, 49.11514230072498, 50.147166922688484, 45.349985137581825, 54.146190136671066, 57.17424385249615, 52.934712544083595, 47.88952946662903, 49.301936477422714, 49.68483053147793, 47.58923538029194, 51.68066963553429, 52.613846361637115, 54.697882533073425, 50.29226213693619, 52.94931896030903, 53.0095799267292, 54.98739279806614, 53.898743614554405, 53.70478682219982, 55.02874597907066, 55.45783035457134, 55.93508094549179, 63.07529680430889, 58.05133178830147, 60.29460221529007, 56.58013433218002, 57.105630934238434, 54.050043895840645, 59.45817589759827, 56.528711691498756, 63.27515847980976, 57.71417208015919, 64.48624089360237, 67.79733002185822, 83.8630123436451, 77.42475181818008, 89.51787650585175, 68.43028485774994, 97.21168845891953, 16.24825682491064, 1.2301820889115334, 1.5751937194727361, 0.15426669007865712, 0.8288938156329095, 17.128397896885872, 88.84763047099113, 66.08207166194916, 63.71703676879406, 55.08311726152897, 57.932458966970444, 79.27459135651588, 4.1592553909868, 0.40447458042763174, 0.3300507349194959, 0.2567073079990223, 0.282184851821512, 0.24626183178042993, 0.12364225563942455, 0.16738821723265573], [0.020841126497543883, 0.06791662046452984, 0.03505222477542702, 0.01834933784266468, 0.08130587739287876, 0.043156314131920226, 0.05647844009217806, 0.18520430341595784, 1.0658270143903792, 54.397425055503845, 54.520162269473076, 30.580213777720928, 27.9520658031106, 57.7352799475193, 70.40130749344826, 68.134326338768, 0.90120559791103, 0.0687239583930932, 0.44828403275460005, 1.0190156637690961, 56.629049107432365, 86.02856174111366, 78.893091827631, 77.1736004948616, 65.7556539773941, 61.44230782985687, 56.48100145161152, 62.55680702626705, 63.0686167627573, 71.90274372696877, 72.20124050974846, 71.77073121070862, 72.09673091769218, 74.5023438334465, 68.1572999060154, 61.631169095635414, 61.77784122526646, 79.43407639861107, 73.99738132953644, 68.3930392563343, 66.08542308211327, 63.30564044415951, 61.835096552968025, 59.5094845443964, 55.76169244945049, 51.87330409884453, 50.86524099111557, 49.85859900712967, 50.79859636723995, 49.38077464699745, 45.57758532464504, 44.37869645655155, 44.78120505809784, 47.192278280854225, 45.64642623066902, 46.94859355688095, 45.61571627855301, 49.259979128837585, 48.146920055150986, 48.205942288041115, 53.473010659217834, 55.95500707626343, 58.3636674284935, 54.99292530119419, 58.38412173092365, 58.09254437685013, 58.748864158988, 59.41181838512421, 61.44364535808563, 60.738931372761726, 60.039502903819084, 56.54956877231598, 59.5870877802372, 57.85942308604717, 57.72014915943146, 57.18713276088238, 59.138263463974, 60.56841552257538, 54.8844563215971, 51.80278368294239, 54.624196887016296, 48.3950125426054, 41.48552030324936, 43.14096227288246, 34.8348093777895, 36.16467721760273, 42.60872483253479, 44.20064181089401, 42.9090341180563, 42.74506911635399, 45.3193511813879, 42.55602166056633, 40.14457605779171, 33.25389660894871, 39.77842390537262, 46.46840952336788, 54.33712609112263, 55.52835077047348, 55.32462850213051, 51.92407697439194, 48.16437631845474, 45.93484215438366, 45.88619336485863, 42.566581293940544, 43.83526101708412, 47.093012407422066, 47.99954116344452, 46.73869661986828, 54.7692085057497, 59.44172278046608, 56.665614545345306, 53.000680804252625, 47.610575035214424, 44.02488984167576, 42.30648525059223, 40.62894746661186, 41.797430366277695, 48.018376752734184, 50.949300080537796, 49.88755725324154, 51.60598464310169, 47.79899172484875, 46.02763697504997, 45.50464443862438, 44.478410705924034, 43.488423228263855, 41.98608264327049, 44.99476119875908, 46.029886454343796, 46.75012640655041, 47.336590737104416, 50.258671939373016, 50.42481042444706, 51.92934349179268, 51.206177696585655, 51.342514380812645, 50.02476789057255, 54.324886947870255, 54.942771792411804, 54.74077083170414, 53.926740512251854, 57.32346944510937, 52.95132905244827, 53.48925478756428, 50.80210357904434, 51.31989799439907, 52.69796624779701, 55.471270233392715, 51.157821491360664, 55.2206014841795, 54.98254805803299, 64.26110297441483, 69.36704859137535, 74.07946452498436, 70.73673069477081, 75.7873284816742, 66.4607821404934, 1.4812772464938462, 0.23594179336214438, 0.15428275015437976, 0.5939119902905077, 6.8916065990924835, 70.27877166867256, 50.85001900792122, 41.33132457733154, 31.363408751785755, 29.15388811379671, 58.4775473177433, 2.487721284851432, 0.08859877707436681, 0.07506027424824424, 0.03826657768513542, 0.029744978310191073, 0.06747671985067427, 0.029157236313039903, 0.015412860793730943, 0.0310178895961144, 0.030724652206117753, 0.02255819461424835, 0.008787554488662863, 0.049715804925654083, 0.0583946134429425, 0.021287723138811998, 0.348696542205289, 2.162135518155992, 64.09178406000137, 60.10561555624008, 34.559707939624786, 31.811108328402042, 65.20398437976837, 75.90739443898201, 75.02559095621109, 1.1250734352506697, 0.1647995170787908, 0.499965890776366, 1.1387508013285697, 65.23191288113594, 89.41111743450165, 83.77973601222038, 79.05051738023758, 69.45054531097412, 64.31980222463608, 57.652341797947884, 63.4345181286335, 66.36607602238655, 72.98246338963509, 75.5455170571804, 77.50439554452896, 74.63994204998016, 77.18585103750229, 68.9649997651577, 63.16786743700504, 67.21574082970619, 81.39844939112663, 73.35324749350548, 71.35656103491783, 67.42311090230942, 67.75717377662659, 65.8662736415863, 60.57748183608055, 58.10955226421356, 55.448254868388176, 51.79769195616245, 52.07943543791771, 52.586191445589066, 52.48904965817928, 47.61553756892681, 49.804923087358475, 47.48400382697582, 50.83545058965683, 48.68333347141743, 50.13707086443901, 47.43336774408817, 52.08153672516346, 50.083812922239304, 47.03107573091984, 52.98715353012085, 61.316238194704056, 61.1117559671402, 56.71549826860428, 58.171853721141815, 60.155354887247086, 61.943907514214516, 61.56404189765453, 62.34919376671314, 62.74468034505844, 61.69681057333946, 58.77541333436966, 62.08391100168228, 59.249616488814354, 60.05227781832218, 58.37744548916817, 61.8528264015913, 61.95896990597248, 54.86065059900284, 55.362732857465744, 54.987962767481804, 49.57568518817425, 42.099115177989006, 42.69871920347214, 34.6958964318037, 38.43856640160084, 45.54438270628452, 46.49587444961071, 46.90994203090668, 45.22560641169548, 48.78230296075344, 44.32133473455906, 41.30450181663036, 35.00700853765011, 40.76962351799011, 46.84314161539078, 57.53508768975735, 59.699033573269844, 57.96266354620457, 54.931520596146584, 51.02851822972298, 47.05819107592106, 47.029460817575455, 47.080826461315155, 46.689531058073044, 51.22562125325203, 48.81520539522171, 48.023806661367416, 57.11536221206188, 63.74309957027435, 60.66695183515549, 55.924091935157776, 49.6380740404129, 44.20468099415302, 42.246642261743546, 42.465780302882195, 44.05230537056923, 48.82187023758888, 51.681714579463005, 51.138921305537224, 50.99356010556221, 49.017229154706, 48.78125421702862, 47.28772155940533, 45.93695484101772, 46.12969569861889, 43.86291213333607, 47.23382145166397, 47.343449369072914, 47.79630906879902, 47.67562374472618, 50.64669571816921, 51.87932677567005, 52.763972505927086, 53.13656531274319, 54.91992361843586, 53.049542382359505, 56.901490688323975, 57.92604871094227, 58.15570838749409, 57.5359920412302, 59.409800693392754, 55.44339492917061, 54.76961508393288, 54.04654808342457, 53.76849040389061, 55.37459962069988, 56.361383870244026, 55.562845319509506, 57.86300629377365, 56.60006806254387, 65.42512491345406, 72.4415472149849, 75.73385775089264, 75.42861253023148, 79.40483316779137, 76.46863952279091, 2.2799700452014804, 0.303383736172691, 0.09173602084047161, 0.5526674003340304, 10.797891039401293, 76.27144530415535, 60.03946490585804, 43.172967955470085, 30.07893707603216, 36.78544230759144, 71.33292630314827, 4.0817248262465, 0.20707129879156128, 0.09433750819880515, 0.17753692343831062, 0.04270998280844651, 0.041512538664392196, 0.05366312514524907, 0.009485626014793525, 0.12280038557946682, 0.21534015977522358, 0.09249471098883078, 0.09187648713123053, 0.11892218157299794, 0.14176941302139312, 0.36513466795440763, 0.45945454272441566, 2.5998024456202984, 75.08720844984055, 68.92285242676735, 38.8367660343647, 41.68562136590481, 76.20577722787857, 82.93593809008598, 82.87293747067451, 1.4742339681833982, 0.3471057931892574, 1.3802162068895996, 1.8322473135776818, 72.38465666770935, 91.90638273954391, 87.58768647909164, 81.05611816048622, 72.97051683068275, 67.24878385663033, 61.68361008167267, 65.86024716496468, 69.81572851538658, 74.65723112225533, 80.00167474150658, 79.79431986808777, 78.67489993572235, 78.40798705816269, 73.71713116765022, 64.93161499500275, 69.88551557064056, 78.71811121702194, 73.21782276034355, 74.16643425822258, 69.1534772515297, 70.15923008322716, 67.48832300305367, 62.49602548778057, 61.57084733247757, 58.830092400312424, 56.116885989904404, 55.70961244404316, 55.91111183166504, 55.688538774847984, 50.05437970161438, 50.98309546709061, 49.03357967734337, 55.03374271094799, 51.97681814432144, 52.216402888298035, 49.093620255589485, 51.59195579588413, 49.82664652168751, 49.14138749241829, 55.11772200465202, 60.68561263382435, 62.142002284526825, 57.36948877573013, 60.75006477534771, 62.19355411827564, 63.24592664837837, 64.27753329277039, 66.69970571994781, 65.41614979505539, 65.24024963378906, 61.5966859459877, 63.45558039844036, 61.376331970095634, 62.12369106709957, 58.53867843747139, 65.12295752763748, 64.08759668469429, 59.985264614224434, 56.71412654221058, 61.27720668911934, 51.42121955752373, 44.928986728191376, 46.059274077415466, 38.480379357934, 40.93507803976536, 46.361034885048866, 50.17449125647545, 52.43574611842632, 47.70175114274025, 48.08800421655178, 45.14245547354221, 43.47247928380966, 36.07184819877148, 42.3149473965168, 50.0122057646513, 59.435038939118385, 62.81047381460667, 58.980286940932274, 56.859867721796036, 53.95911477506161, 49.966779202222824, 51.13755717873573, 49.657206013798714, 50.17382629215717, 53.14627379179001, 51.168875098228455, 48.726757541298866, 59.470506235957146, 64.01725485920906, 61.699265241622925, 56.923727095127106, 49.7419186681509, 45.29509328305721, 44.79896530508995, 44.23789121210575, 45.209267288446426, 50.40728576481342, 53.72594028711319, 51.861528530716896, 55.643879771232605, 52.01041594147682, 51.617566421628, 50.28373919427395, 48.70410315692425, 50.18046833574772, 44.94167424738407, 50.51616512238979, 48.668187484145164, 52.181691750884056, 50.24547524750233, 54.10588189959526, 55.760715901851654, 56.33559465408325, 55.751885175704956, 56.877650767564774, 55.04853151738644, 58.64473074674606, 59.67570282518864, 61.53295956552029, 61.27371087670326, 63.57036843895912, 57.67021983861923, 58.61991807818413, 57.70746164023876, 57.01962634921074, 59.88398104906082, 61.40589438378811, 58.818696811795235, 63.75870153307915, 60.810952708125114, 70.73805302381516, 75.63467547297478, 78.92908349633217, 78.35358917713165, 83.48968997597694, 76.00764065980911, 1.930224581155926, 0.5290828971192241, 0.37611913634464145, 1.1827367660589516, 13.447399567812681, 84.8885165154934, 65.92480570077896, 58.436604514718056, 46.858762577176094, 42.553977370262146, 85.0183479487896, 5.329942647367716, 0.4641173972049728, 0.27793154411483556, 0.38624422741122544, 0.17456889676395804, 0.1747760598664172, 0.09753813879797235, 0.09666210025898181], [0.04707183703430928, 0.030978281174611766, 0.046245700505096465, 0.08818551956210285, 0.08248707963502966, 0.08786683392827399, 0.07179287262260914, 0.21881844266317785, 1.5572573756799102, 61.719312965869904, 40.61573177576065, 43.59492391347885, 42.22381688654423, 59.593251049518585, 69.81442898511887, 66.31613910198212, 1.6937289526686072, 0.10934285848634318, 0.1716130116255954, 0.610857002902776, 61.44534006714821, 84.61148098111153, 79.66464802622795, 79.04969662427902, 68.00797551870346, 60.90822368860245, 61.92716561257839, 68.89466553926468, 71.23677626252174, 75.70519968867302, 73.59254345297813, 73.45936819911003, 71.91500946879387, 71.13041996955872, 70.45901119709015, 69.23631280660629, 60.23575857281685, 58.479333221912384, 75.98500907421112, 67.92359724640846, 62.393503189086914, 60.54103799164295, 57.65869125723839, 57.886101454496384, 57.079039961099625, 54.180601090192795, 51.47793531417847, 49.46467414498329, 49.78345423936844, 48.013387620449066, 47.713177129626274, 43.512597531080246, 44.914038330316544, 46.51622235774994, 46.42321474850178, 47.64772944152355, 48.29596325755119, 50.85858754813671, 49.85859900712967, 46.40584588050842, 54.79008838534355, 61.11485280096531, 52.58932247757912, 55.89226484298706, 54.21112485229969, 55.552494674921036, 58.214479833841324, 59.363667368888855, 59.09798942506313, 57.82837115228176, 59.197300896048546, 60.177264511585236, 58.668441474437714, 59.75588992238045, 58.816451132297516, 59.98624496161938, 55.58047257363796, 50.79830378293991, 49.757862612605095, 47.894123420119286, 39.73118104040623, 43.55414070188999, 43.723015040159225, 41.97299614548683, 34.89676125347614, 38.39281685650349, 41.79681479930878, 44.88023154437542, 41.61162793636322, 46.466209441423416, 46.838380470871925, 42.418719828128815, 41.12449027597904, 38.56381148099899, 42.18576192855835, 43.929290771484375, 52.46343903243542, 55.910473465919495, 57.476327642798424, 55.77418997883797, 53.35067622363567, 50.59973403811455, 49.58191305398941, 50.18709518015385, 55.83560608327389, 58.50655876100063, 58.50276656448841, 56.39276638627052, 59.659390300512314, 56.88501097261906, 56.00112520158291, 55.68886175751686, 54.91586163640022, 47.7559894323349, 44.4256429374218, 46.694033816456795, 44.37158323824406, 42.42643341422081, 49.826893508434296, 43.754838332533836, 46.621427312493324, 44.58999551832676, 43.987446650862694, 42.390525341033936, 44.27666433155537, 41.796290427446365, 43.27468849718571, 46.21137611567974, 49.5012091845274, 46.70396268367767, 51.58644609153271, 52.24259488284588, 55.53797945380211, 54.140091463923454, 54.778240621089935, 53.02101731300354, 56.70157581567764, 57.06343799829483, 57.63680063188076, 64.30233836174011, 64.07396301627159, 56.87515430152416, 56.98934577405453, 52.6152028888464, 53.04797686636448, 50.657392144203186, 49.255005195736885, 52.86297619342804, 55.70488549768925, 54.771370589733124, 57.171747386455536, 53.7169423699379, 62.9225829988718, 65.83652123808861, 74.39508318901062, 66.28483638167381, 86.04353293776512, 17.324376180768013, 0.7583508384414017, 0.26336440234445035, 0.9840482182335109, 13.914379309862852, 67.18185424804688, 56.76222816109657, 39.30970385670662, 28.130084350705147, 33.6743288487196, 63.30856628715992, 3.646822012960911, 0.13333291572052985, 0.061970451642991975, 0.050940923756570555, 0.011845776225527516, 0.03603133278375026, 0.026523092601564713, 0.058744721609400585, 0.013596501667052507, 0.035089547382085584, 0.05108771314553451, 0.04621786625648383, 0.0889624294359237, 0.19733320805244148, 0.05626023754302878, 0.19097561482340097, 2.378400438465178, 70.60185313224792, 50.561675280332565, 44.380045384168625, 44.768148958683014, 68.87506619095802, 77.7130651473999, 69.20865789055824, 1.2028115638531744, 0.0414350102073513, 0.6831202190369368, 1.3485193764790893, 68.34695532917976, 89.31862279772758, 82.25159481167793, 79.29667577147484, 69.03062984347343, 62.95920543372631, 63.776279389858246, 69.19460624456406, 76.22250393033028, 79.2318132519722, 76.52214825153351, 76.16127401590347, 76.01419150829315, 71.70352041721344, 72.83624723553658, 72.7838708460331, 61.94307915866375, 65.24255231022835, 79.96211886405945, 68.00964742898941, 64.64612111449242, 61.65596656501293, 60.80650694668293, 60.10297849774361, 60.322314128279686, 56.38050064444542, 51.85288779437542, 51.10891431570053, 52.72663950920105, 50.9180923551321, 49.727464243769646, 46.89798027276993, 48.774528577923775, 49.0993769466877, 47.91457772254944, 50.46031191945076, 52.00664274394512, 49.921709820628166, 53.6197853833437, 46.4993816614151, 55.78617453575134, 61.266115084290504, 57.76530593633652, 56.56352162361145, 55.45385576784611, 59.26581881940365, 62.81430400907993, 62.8483197838068, 59.83514606952667, 60.22635027766228, 60.33528283238411, 62.69651412963867, 62.39499270915985, 61.70514352619648, 61.27255953848362, 62.24941112101078, 58.59049625694752, 54.2383997887373, 49.64889585971832, 47.98385180532932, 41.12404190003872, 46.26941040158272, 46.210684552788734, 41.17785081267357, 36.5613417327404, 41.517776772379875, 42.147152200341225, 48.16280700266361, 44.95984107255936, 48.57559785246849, 47.14720509946346, 45.120401456952095, 41.65600195527077, 40.123570784926414, 43.660485595464706, 42.42998242378235, 53.07283513247967, 59.4276787340641, 58.240565434098244, 60.71906603872776, 56.360414922237396, 54.24256816506386, 52.90117934346199, 52.05620348453522, 58.263007029891014, 59.87262345850468, 59.13820266723633, 58.547661155462265, 62.59681507945061, 59.96377296745777, 58.52615050971508, 57.39172138273716, 55.63317194581032, 50.65167725086212, 44.97026391327381, 47.90478564798832, 46.94971829652786, 43.27755734324455, 49.362212643027306, 43.52033771574497, 46.18019498884678, 44.85546447336674, 46.60711348056793, 45.47469824552536, 46.36888526380062, 44.71851222217083, 45.21185114979744, 47.876218780875206, 50.62545485794544, 49.89891104400158, 52.5478059053421, 54.50765334069729, 56.92394368350506, 56.479565128684044, 57.169756293296814, 57.22103834152222, 60.30350513756275, 59.68335561454296, 58.77194032073021, 65.46238571405411, 67.81029492616653, 60.585279017686844, 58.448471277952194, 56.67362071573734, 55.900483801960945, 54.9387364089489, 52.07996740937233, 56.247709169983864, 59.060200452804565, 57.40172624588013, 59.51261177659035, 55.81065282225609, 64.86970111727715, 67.05790489912033, 80.25599509477615, 68.66979360580444, 91.5071913599968, 21.527361050248146, 0.8333800092805177, 0.2050508017418906, 1.5106008667498827, 17.08354890346527, 73.30180585384369, 66.32902801036835, 45.91488182544708, 30.11385340243578, 38.55467677116394, 75.1026052236557, 6.571685615926981, 0.1741462288191542, 0.07296104275155813, 0.08621342538390309, 0.061433674782165326, 0.046190959692467004, 0.03680646521388553, 0.013548788065236295, 0.16802313941298053, 0.18419680825900286, 0.24836585012963042, 0.11603508610278368, 0.16399894753703848, 0.2565403247717768, 0.24010205059312284, 0.36968970322050154, 3.358277133665979, 83.70333731174469, 55.68972431123257, 51.16027995944023, 58.97071525454521, 76.88811421394348, 81.94846227765083, 76.54187679290771, 2.127977251075208, 0.5582699622027576, 1.2530883285216987, 2.238177275285125, 71.2170097231865, 92.2890830039978, 85.24168476462364, 83.22804361581802, 73.61265957355499, 66.3735844194889, 68.35280701518059, 74.53607082366943, 80.94410017132759, 82.50985935330391, 79.26863327622414, 77.28402256965637, 77.40667998790741, 73.17173883318901, 75.47376170754433, 74.47611764073372, 64.86744403839111, 69.55386936664581, 74.97468888759613, 72.48646840453148, 68.58201071619987, 66.55006974935532, 64.19079154729843, 63.20333853363991, 62.80573166906834, 60.05656398832798, 57.193493619561195, 54.668133929371834, 56.05743058025837, 52.17940427362919, 53.198509588837624, 49.92488645017147, 51.731039732694626, 50.923453867435455, 52.581688687205315, 53.71350355446339, 54.37353573739529, 52.84868136048317, 52.4593086540699, 46.20171703398228, 57.650096118450165, 63.5049207508564, 57.98330023884773, 61.041471138596535, 58.112272918224335, 59.93337079882622, 65.25403529405594, 64.66882109642029, 63.60770143568516, 61.98970265686512, 61.13414816558361, 64.35012459754944, 63.72518353164196, 63.957780450582504, 64.60670962929726, 64.50038373470306, 61.39587812125683, 55.76700076460838, 53.07438924908638, 50.402167439460754, 42.536885887384415, 43.92839401960373, 45.50587177276611, 43.82899895310402, 38.9244045317173, 44.7440392524004, 44.60380777716637, 50.25872513651848, 48.98783013224602, 52.28691950440407, 46.84396617114544, 43.919171914458275, 42.523430809378624, 40.15080772340298, 44.9521578848362, 44.46501262485981, 54.65147942304611, 61.39996290206909, 61.852256432175636, 61.63414813578129, 57.62265779078007, 56.76109202206135, 55.70396974682808, 54.97863806784153, 60.36052107810974, 64.29043740034103, 62.256885319948196, 61.78746610879898, 63.13784144818783, 62.38479405641556, 62.07379974424839, 60.26714488863945, 57.226703837513924, 51.44984722137451, 46.705585196614265, 48.92424054443836, 45.099255591630936, 44.58500258624554, 51.91206581890583, 45.18160097301006, 48.301222175359726, 47.239209562540054, 47.90430687367916, 48.90010803937912, 49.99999321997166, 48.11241790652275, 48.233023434877396, 51.27782665193081, 53.30488868057728, 53.16361226141453, 55.144890546798706, 57.54557132720947, 60.68528205156326, 59.80091750621796, 57.66460373997688, 57.777035906910896, 61.755870804190636, 63.97572308778763, 62.541349455714226, 66.91628649830818, 68.29818114638329, 62.87459537386894, 61.28799431025982, 59.18506175279617, 57.063981369137764, 58.36911253631115, 53.60881917178631, 60.047718062996864, 60.581635013222694, 60.62514267861843, 61.919201239943504, 59.11721259355545, 70.52373692393303, 70.7269424200058, 84.82314482331276, 71.30418464541435, 93.22226732969284, 22.084378860890865, 0.7368590729311109, 0.6038692966103554, 2.0371386129409075, 21.646119877696037, 80.80757349729538, 74.57229048013687, 56.89986437559128, 42.1831476688385, 45.57614900171757, 94.28367957472801, 8.574592340737581, 0.4978478013072163, 0.2863876341143623, 0.11986898389295675, 0.12626026320504025, 0.0829762291687075, 0.10037168831331655, 0.09090734616620466], [0.06021426306688227, 0.03610052321164403, 0.0414539980556583, 0.032169956975849345, 0.08528639387805015, 0.039074227315722965, 0.09836596000241116, 0.19616773934103549, 1.801718445494771, 56.17808550596237, 48.96163433790207, 36.24308221042156, 32.643854543566704, 56.472911685705185, 76.61383733153343, 41.384920701384544, 0.049628591441432945, 0.07528345289756544, 0.5827597074676305, 1.5451502753421664, 70.19247069954872, 84.49883982539177, 81.93467661738396, 78.61802458763123, 63.72214749455452, 57.54560172557831, 62.99038276076317, 72.44397148489952, 73.97818475961685, 74.91888508200645, 76.5917757153511, 71.92740440368652, 73.20777609944344, 70.82897454500198, 70.53615465760231, 64.80762764811516, 72.01474651694298, 55.70794813334942, 61.53084307909012, 73.48629355430603, 59.84496474266052, 60.57151235640049, 57.31061093509197, 57.53291420638561, 54.43538121879101, 52.14140251278877, 51.72040790319443, 51.343475729227066, 50.058225095272064, 49.550146758556366, 43.989950716495514, 43.00689406692982, 44.2002010345459, 44.72869947552681, 45.810797810554504, 45.942992717027664, 48.27801302075386, 49.13520522415638, 52.59475238621235, 53.111798241734505, 51.23307265341282, 64.12571623921394, 56.245968863368034, 57.92914554476738, 55.53926758468151, 55.96547931432724, 56.83160103857517, 60.500744953751564, 59.40276727080345, 55.94359248876572, 50.743476524949074, 53.224880173802376, 53.68386894464493, 60.53969286382198, 57.592274621129036, 54.60451394319534, 49.23678517341614, 46.40151031315327, 47.84847266972065, 44.48981009423733, 50.01548498868942, 45.05963131785393, 41.446276009082794, 44.620124101638794, 39.665638357400894, 41.27525098621845, 39.5857248455286, 46.823888048529625, 39.348366782069206, 45.35023972392082, 44.541266933083534, 43.54436382651329, 42.764858454465866, 39.3947546929121, 40.69453954696655, 46.266860738396645, 50.69001719355583, 54.9558012932539, 54.68975096940994, 55.56529998779297, 54.99297469854355, 55.578348487615585, 57.09590345621109, 56.124588176608086, 55.582087486982346, 56.76254354417324, 58.06649297475815, 59.09982472658157, 55.66246077418327, 53.57766084372997, 57.01842941343784, 54.19261984527111, 52.29480408132076, 51.22690558433533, 48.4478373080492, 49.92812007665634, 44.07696604728699, 43.69711562991142, 50.7609061896801, 48.869876861572266, 45.004234090447426, 46.83854766190052, 42.947260066866875, 42.37286388874054, 42.748865112662315, 42.93590247631073, 43.853032663464546, 44.8599786311388, 47.37634800374508, 49.9268851429224, 52.81313806772232, 55.09742729365826, 55.19167363643646, 57.62290857732296, 61.924570351839066, 60.86554817855358, 59.374120607972145, 61.825388073921204, 74.76375460624695, 72.97186195850372, 65.07373496890068, 61.24294392764568, 58.59753727912903, 54.81957100331783, 54.336867704987526, 52.75143317878246, 51.67900912463665, 51.94252498447895, 53.33428010344505, 56.28946132957935, 60.657448545098305, 60.96857964992523, 64.81998458504677, 64.27906841039658, 72.20816373825073, 70.23453444242477, 81.07972249388695, 42.897995710372925, 0.1791988147306256, 0.19779446767643094, 1.6854842263273895, 12.543392926454544, 69.97194573283195, 57.63545170426369, 40.434713289141655, 32.50503659248352, 41.13184668123722, 58.68407383561134, 5.435252096503973, 0.2520609588827938, 0.023752011511533055, 0.04358336816949304, 0.07492098797229119, 0.06416332733351737, 0.03800153819611296, 0.0720932346303016, 0.016887076853890903, 0.026114004103874322, 0.009490766315138899, 0.028636940696742386, 0.04783543277881108, 0.12553758948342875, 0.10203737940173596, 0.461663055466488, 3.502840851433575, 66.62291184067726, 58.891432508826256, 34.61035542190075, 36.88562013208866, 64.6430204808712, 83.5034528374672, 42.75975912809372, 0.09179016051348299, 0.16481373662827536, 0.5138460709713399, 2.3529372923076153, 75.8429878950119, 87.43030652403831, 82.95212522149086, 80.09735360741615, 67.9690808057785, 61.48326963186264, 67.56161347031593, 76.940528601408, 74.35276105999947, 76.85361966490746, 79.22319531440735, 73.59610006213188, 72.22941979765892, 72.43337765336037, 72.1455430984497, 68.03083509206772, 73.8628913462162, 59.09828960895538, 68.57504189014435, 76.23977020382881, 65.11504635214806, 65.02737745642662, 61.195731461048126, 61.6557689756155, 56.789259910583496, 55.1451451331377, 52.60895982384682, 52.83595584332943, 49.881732165813446, 51.027564480900764, 46.94203890860081, 45.78484520316124, 47.88851112127304, 47.091750875115395, 47.93751709163189, 48.44258598983288, 49.37382481992245, 49.412077367305756, 52.39015236496925, 53.93005773425102, 52.345725148916245, 67.11694613099098, 60.426534935832024, 59.28782343864441, 56.83300316333771, 59.34670887887478, 59.44382406771183, 62.74251066148281, 64.41831573843956, 58.700169771909714, 54.68721650540829, 54.50619041919708, 54.15997959673405, 58.03908124566078, 58.40955376625061, 56.570178866386414, 50.04827342927456, 48.46297189593315, 47.11787447333336, 42.736010402441025, 50.44467955827713, 49.61298018693924, 40.69239266216755, 45.14316603541374, 40.05239300429821, 43.52406531572342, 40.70246212184429, 50.31860612332821, 43.58592979609966, 47.582578137516975, 45.431019589304924, 42.289636954665184, 43.90344075858593, 41.20688885450363, 41.05170138180256, 50.62057211995125, 49.81281906366348, 59.46278505027294, 56.65438614785671, 60.88803917169571, 56.456952542066574, 59.229036793112755, 58.66124086081982, 56.44227012991905, 58.97187799215317, 57.26659029722214, 58.57020154595375, 63.101986572146416, 58.50497804582119, 57.88669042289257, 59.92845006287098, 56.236081793904305, 54.04462158679962, 53.37877191603184, 49.01395373046398, 49.857668057084084, 43.75800736248493, 43.94388198852539, 52.32174463570118, 49.363755360245705, 45.57650238275528, 49.3577478826046, 45.103294774889946, 45.65754443407059, 44.11981634795666, 44.89419959485531, 45.68166933953762, 48.56132581830025, 48.20860594511032, 52.205847054719925, 55.721441209316254, 56.99362054467201, 59.15005423128605, 60.5024928599596, 64.12195444107056, 62.137689515948296, 61.865118741989136, 62.935601100325584, 74.1209203004837, 74.34057131409645, 67.83383086323738, 64.53534945845604, 59.39378835260868, 58.661848828196526, 57.24951021373272, 54.54066216945648, 54.03166428208351, 55.771522521972656, 56.78422898054123, 60.2619581669569, 63.116478994488716, 64.00549829006195, 67.70529136061668, 67.40364834666252, 75.7926557958126, 73.18259105086327, 86.569265127182, 52.29106888175011, 0.14203986647771671, 0.20989615033613518, 1.6825786884874105, 16.433947160840034, 77.30560541152954, 66.96547865867615, 44.61345545947552, 36.4841602742672, 48.44034031033516, 67.52656415104866, 9.99389598146081, 0.639500281540677, 0.1462585901026614, 0.08373921635211445, 0.09908501204336062, 0.11040732832043432, 0.026063528785016388, 0.12353796162642539, 0.1707404834451154, 0.12106182301067747, 0.10612063881126232, 0.14120781503152102, 0.1477275081560947, 0.17114882793975994, 0.4038799420231953, 0.6908013287466019, 4.310686765238643, 79.53956633806229, 61.19306780397892, 45.486219227313995, 47.57140673696995, 73.38882118463516, 89.93931949138641, 51.802821680903435, 0.1997334769112058, 0.30385933408979326, 1.094166012480855, 3.2683922443538904, 74.54205930233002, 88.47327455878258, 86.55093491077423, 87.1113820374012, 70.18100291490555, 64.08774107694626, 69.03915658593178, 79.26752373576164, 75.49428060650826, 79.99593704938889, 79.6410208940506, 75.60633659362793, 74.90260675549507, 76.47119298577309, 76.38246014714241, 71.49050384759903, 77.5900961458683, 64.31646600365639, 67.62168064713478, 74.80374366044998, 69.32306975126266, 66.23325034976006, 63.674756437540054, 65.25214299559593, 60.2533820271492, 57.39191897213459, 56.14007994532585, 54.20179255306721, 52.913977056741714, 53.286311477422714, 48.47889684140682, 48.9414232224226, 51.93454161286354, 50.74670635163784, 50.38628429174423, 51.51477433741093, 52.94914036989212, 53.29113721847534, 54.83322747051716, 54.61400963366032, 52.28846222162247, 66.97275146842003, 61.68549858033657, 62.094968408346176, 59.58395294845104, 61.100656762719154, 59.97109517455101, 63.66314806044102, 64.52809944748878, 61.29994086921215, 55.055621936917305, 60.87686777114868, 59.91226673126221, 64.52174618840218, 63.23463745415211, 60.54602712392807, 53.020078763365746, 48.80685344338417, 47.539522647857666, 45.14031618833542, 48.03961381316185, 46.41325168311596, 42.347948625683784, 45.47368369996548, 41.21431365609169, 44.02937740087509, 41.298319548368454, 53.016400560736656, 47.16921351850033, 50.82604229450226, 46.46716319024563, 43.465081080794334, 43.49687397480011, 39.99340496957302, 41.520254239439964, 53.13283771276474, 53.00286948680878, 60.637845396995544, 59.7490768879652, 61.28970041871071, 59.31871958076954, 61.889205649495125, 62.42767855525017, 59.36894528567791, 61.10509492456913, 60.71001872420311, 61.3810171186924, 64.36807483434677, 59.992469027638435, 58.746082708239555, 62.71970048546791, 59.671412855386734, 57.33088664710522, 54.9690929800272, 50.48361226916313, 52.52648904919624, 43.925483375787735, 44.88213524222374, 53.89652833342552, 51.69841468334198, 48.88953700661659, 51.64455257356167, 48.39245907962322, 48.13343457877636, 48.52882616221905, 48.77905033528805, 49.387671276926994, 50.191685333848, 51.59566439688206, 54.42930534482002, 57.728721499443054, 60.560291558504105, 61.01786680519581, 62.037967666983604, 68.57635661959648, 64.07141715288162, 64.95509013533592, 64.15194243192673, 72.60680794715881, 77.6596400141716, 72.19326093792915, 67.59226262569427, 63.48079964518547, 61.84447064995766, 61.04347363114357, 57.34555386006832, 58.00773672759533, 60.65465569496155, 58.80083777010441, 62.56862819194794, 65.47073006629944, 67.00993627309799, 70.59849411249161, 71.34816348552704, 79.07862827181816, 76.06752544641495, 90.07097482681274, 54.452776685357094, 0.18862603465095162, 0.3771334741031751, 3.328992105089128, 22.169429697096348, 84.08197939395905, 73.36847707629204, 57.8992373496294, 50.978626906871796, 54.34232801198959, 86.30146309733391, 13.491727989166975, 1.0926228202879429, 0.28652659384533763, 0.14826654485659674, 0.19959094002842903, 0.3492768423166126, 0.24298766918946058, 0.305452398606576], [0.02125739341863664, 0.06899399624671787, 0.012738301575154765, 0.05665539036272094, 0.030518138482875656, 0.012776123276125873, 0.04731378088763449, 0.1827038446208462, 3.147243820130825, 64.43531602621078, 39.684196561574936, 39.18974429368973, 36.839995980262756, 55.71129955351353, 73.16337168216705, 15.240566097199917, 0.29244329198263586, 0.3655654698377475, 0.21253761718980968, 3.5003564972430468, 69.77721378207207, 80.78527629375458, 80.77288895845413, 73.30488368868828, 58.56995075941086, 62.19202660024166, 71.0234709084034, 72.52702742815018, 73.49413633346558, 73.8817535340786, 73.58292236924171, 72.11335122585297, 68.81688371300697, 66.96287199854851, 67.2896620631218, 66.10661834478378, 65.60055390000343, 63.032955676317215, 54.28071431815624, 66.48512363433838, 63.87378975749016, 63.09739641845226, 60.87562903761864, 60.1178091019392, 56.04864925146103, 53.62696699798107, 51.53408110141754, 50.248218700289726, 48.236135467886925, 48.391938507556915, 47.092100456357, 44.108040779829025, 43.06426718831062, 41.67095795273781, 43.31315003335476, 45.656024515628815, 45.6033593416214, 52.773403599858284, 54.921188950538635, 59.13355931639671, 60.57015582919121, 65.30344784259796, 57.894745990633965, 57.38656885921955, 54.42689247429371, 52.93013758957386, 55.32566964626312, 58.71049381792545, 60.10317608714104, 55.72496362030506, 47.847705110907555, 45.96384599804878, 46.84090733528137, 43.59501130878925, 46.46801054477692, 44.859328866004944, 47.403269559144974, 49.43978928029537, 49.851238802075386, 49.3244768679142, 45.26626043021679, 33.19803960621357, 43.29564057290554, 43.37548568844795, 48.08028303086758, 38.25245998799801, 43.365317434072495, 45.61173789203167, 36.36414371430874, 42.783876433968544, 45.279745906591415, 41.87893599271774, 39.61109608411789, 40.025015473365784, 44.33668591082096, 46.25822760164738, 45.84751904010773, 47.525801584124565, 56.416442915797234, 55.18331028521061, 56.48550420999527, 57.554732635617256, 56.744581907987595, 55.80277964472771, 57.18472748994827, 58.83496753871441, 54.904865026474, 54.84238877892494, 52.22311332821846, 57.65273317694664, 58.23129013180733, 55.235067307949066, 52.678743079304695, 49.476742297410965, 45.397406592965126, 46.42565421760082, 47.622985169291496, 50.64291872084141, 56.04011110961437, 45.69862402975559, 43.468041121959686, 44.0666040033102, 43.22122536599636, 42.50659391283989, 40.841914638876915, 41.50720193982124, 43.698274567723274, 45.457226783037186, 46.926763728260994, 52.74404637515545, 53.23731690645218, 57.9802680015564, 57.51149855554104, 58.48986245691776, 59.97815519571304, 63.08914706110954, 69.23243701457977, 75.52632048726082, 60.904492288827896, 61.190894320607185, 63.94310563802719, 62.73664377629757, 58.310386687517166, 56.28241650760174, 53.78946527838707, 53.77859026193619, 52.7857681363821, 55.16305357217789, 54.024087488651276, 58.78241255879402, 61.54897190630436, 67.82092675566673, 68.68519797921181, 70.56289002299309, 70.61335891485214, 73.84890049695969, 76.47869378328323, 66.731768399477, 0.7650530256796628, 0.15737570996861905, 1.1874337890185416, 11.146142352372408, 74.3564772605896, 57.10624270141125, 42.84873515367508, 27.9146796092391, 30.216844975948334, 63.19685988128185, 10.00290909782052, 0.2550752065144479, 0.2006817635265179, 0.05150511184183415, 0.14105217182077467, 0.026876173069467768, 0.04029994357551914, 0.01578945157234557, 0.06192739223479293, 0.06102318919147365, 0.06578451924724504, 0.052069908488192596, 0.06479444971773773, 0.05003288380976301, 0.07764717098325491, 0.24887589854188263, 4.774806210771203, 75.240917801857, 45.508778616786, 38.91982577741146, 44.079348519444466, 62.155757546424866, 81.61836639046669, 15.992800332605839, 0.3272433386882767, 0.37512640992645174, 0.494454909930937, 4.461864028126001, 77.39683091640472, 82.09742948412895, 83.69172513484955, 73.9778807759285, 61.95080414414406, 64.276864528656, 73.78868132829666, 74.32069078087807, 75.20275264978409, 77.09337159991264, 76.53291687369347, 73.61333593726158, 71.53382152318954, 70.70117980241776, 70.63197031617165, 68.50204780697823, 67.12018355727196, 65.28433486819267, 61.09485447406769, 73.75680863857269, 67.11740210652351, 65.68888396024704, 63.19252051413059, 63.7275318056345, 58.54436293244362, 55.96917651593685, 51.95737838745117, 52.725298181176186, 51.53347693383694, 51.77448660135269, 49.24340821802616, 47.25311681628227, 46.168924793601036, 44.5980054885149, 46.47513896226883, 46.4557334035635, 48.324906304478645, 54.21758830547333, 57.83521458506584, 63.00194174051285, 62.65157014131546, 67.18595042824745, 60.841617062687874, 59.89294096827507, 58.34091804921627, 55.30838057398796, 57.647858038544655, 61.88686117529869, 62.81814560294151, 58.005924224853516, 52.23611623048782, 51.04233428835869, 49.44965735077858, 47.16857135295868, 48.69692914187908, 45.75584135949612, 48.15551899373531, 48.51979024708271, 49.592043310403824, 52.86693558096886, 48.358838483691216, 34.755994006991386, 43.86704631149769, 42.6257137209177, 48.89836013317108, 40.98229430615902, 43.4359822422266, 46.05388216674328, 40.085120648145676, 45.826156586408615, 45.74707143008709, 41.98825232684612, 42.123494669795036, 40.95680147409439, 46.81410737335682, 46.859594732522964, 45.785741955041885, 49.624295979738235, 56.44174575805664, 56.14898666739464, 61.54963307082653, 57.86894537508488, 57.208252027630806, 58.742146119475365, 60.61047166585922, 60.132708102464676, 56.242324858903885, 55.95325917005539, 54.512152299284935, 60.639251321554184, 58.97398307919502, 56.246474236249924, 53.73523838818073, 52.30888992547989, 46.439238488674164, 47.04226233065128, 48.382917791604996, 52.51062110066414, 57.50107951462269, 46.93770334124565, 45.09071744978428, 46.50608070194721, 45.52285686135292, 46.54497541487217, 43.859986290335655, 44.646734073758125, 46.8839780241251, 48.99074077606201, 48.65613453090191, 55.292159244418144, 55.58564029633999, 60.422522351145744, 59.00022827088833, 61.18625856935978, 61.29953049123287, 63.332246616482735, 70.57836279273033, 77.18095690011978, 65.90996369719505, 65.07999703288078, 66.12985029816628, 65.17572909593582, 60.9069811552763, 58.420740365982056, 56.71384535729885, 57.312989607453346, 56.06507956981659, 57.695157900452614, 54.70825217664242, 61.2082289904356, 64.65035408735275, 72.69522160291672, 71.76291882991791, 74.78495746850967, 73.4419347345829, 80.26336669921875, 78.8026262819767, 77.13576972484589, 0.28939229319803417, 0.06642074018600397, 0.9557250724174082, 15.737098753452301, 81.52711048722267, 64.16866153478622, 51.36330686509609, 28.096074275672436, 38.0791474878788, 77.863559871912, 16.278256215155125, 0.420976530876942, 0.24012432986637577, 0.06409700901713222, 0.08161527875927277, 0.05212547679548152, 0.07293744245544076, 0.03064327385800425, 0.1579546445282176, 0.19826896721497178, 0.22313714842312038, 0.15114285692106932, 0.15099693584488705, 0.14754333678865805, 0.19502198207192123, 0.4400845477357507, 6.075731003656983, 88.29172790050507, 52.1542040258646, 52.53821521997452, 53.896444737911224, 69.51618298888206, 87.79621928930283, 20.44199299067259, 0.5457808636128902, 0.6542134482879192, 0.9028864733409137, 5.839796913787723, 78.68867799639702, 84.4704857468605, 86.81843295693398, 79.750447422266, 63.08263801038265, 68.05094361305237, 76.5368078649044, 79.72319528460503, 79.42564085125923, 80.05487948656082, 78.92511650919914, 77.89594173431396, 75.25689214468002, 73.68098750710487, 72.39862471818924, 71.34831547737122, 69.75978031754494, 68.8855992257595, 62.132791578769684, 68.20342183113098, 68.65248173475266, 69.9327090382576, 67.15996742248535, 67.90094286203384, 60.061241537332535, 58.68967093527317, 57.095033302903175, 56.25717446208, 54.38719980418682, 53.57729606330395, 51.13781176507473, 50.10695368051529, 48.859020844101906, 46.0562152415514, 48.62211875617504, 49.392713606357574, 51.93757385015488, 57.82228007912636, 59.49865132570267, 65.35343036055565, 65.82530423998833, 72.40288808941841, 61.06678158044815, 63.014424070715904, 59.285513162612915, 56.94505915045738, 59.52775776386261, 63.43720078468323, 65.13615041971207, 57.93563939630985, 49.343407452106476, 50.464579090476036, 51.46217755973339, 47.66315281391144, 51.55250631272793, 48.00185523927212, 49.14232984185219, 49.38743568956852, 53.88222210109234, 48.79081830382347, 49.493533596396446, 36.584136709570885, 45.21099999547005, 42.82373629510403, 50.26885539293289, 40.13406962156296, 44.30115021765232, 50.90555302798748, 44.31452929973602, 50.070916414260864, 47.50837951898575, 43.524095714092255, 42.51415550708771, 42.59310007095337, 47.20896318554878, 46.963465958833694, 47.88585126399994, 51.455527916550636, 60.9086948633194, 58.74352164566517, 62.13444069027901, 61.28723055124283, 61.41837291419506, 62.11603827774525, 62.098722606897354, 63.60970392823219, 61.570569947361946, 58.2372672110796, 58.15654054284096, 65.05706906318665, 62.990713343024254, 58.93410801887512, 57.01596334576607, 54.147793650627136, 49.150807186961174, 50.09822554886341, 48.61895352602005, 54.634528532624245, 57.93578378856182, 49.81158412992954, 46.387701854109764, 49.97982010245323, 48.662468791007996, 48.307780623435974, 46.16416744887829, 49.31726485490799, 49.66095261275768, 50.95966212451458, 50.02170905470848, 58.60859468579292, 57.05521143972874, 63.43362517654896, 63.1551419198513, 64.42736685276031, 65.57097628712654, 65.98192423582077, 71.60908788442612, 74.87572699785233, 68.53453606367111, 70.18458232283592, 68.86790737509727, 70.24599462747574, 63.87776434421539, 61.5598127245903, 58.523745238780975, 61.01095877587795, 58.88259798288345, 61.35253764688969, 57.793937399983406, 65.59103161096573, 68.94119784235954, 77.22206309437752, 75.16278639435768, 78.45702722668648, 76.86927482485771, 84.18267399072647, 80.94622045755386, 80.86082383990288, 1.8369940901175141, 0.2620584599208087, 1.428748033940792, 20.77464234083891, 87.61652693152428, 72.91166558861732, 61.763888373970985, 41.117992624640465, 42.11089454591274, 90.82808420062065, 18.907466232776642, 0.7427660934627056, 0.4696351464372128, 0.15309685753891245, 0.315327356220223, 0.17502942908322439, 0.18543496291385964, 0.18973419471876696], [0.03022621098352829, 0.0749379831540864, 0.07276198390172794, 0.05336657777661458, 0.04774526554683689, 0.04282897134544328, 0.149555403040722, 0.24270752328447998, 3.0477796448394656, 61.25263340771198, 47.64196515083313, 37.83504858613014, 50.93920782208443, 55.65790481865406, 72.4811638891697, 9.932581521570683, 0.47799140273127705, 0.40189603285398334, 0.796085485490039, 3.230405207723379, 75.46878397464752, 81.93834722042084, 78.27931836247444, 69.68789577484131, 55.463062673807144, 64.60620805621147, 65.56084603071213, 70.28236627578735, 71.64881095290184, 70.04549458622932, 68.04965928196907, 70.46408772468567, 67.73005083203316, 67.44405537843704, 65.3409518301487, 69.69902157783508, 67.37328037619591, 66.30862310528755, 54.40032050013542, 58.26430656015873, 65.50324112176895, 63.054367527365685, 65.5958953499794, 62.51378193497658, 62.84786380827427, 57.48344086110592, 53.407369181513786, 51.521401181817055, 48.98653820157051, 48.66775430738926, 47.185966819524765, 43.46606902778149, 42.727434262633324, 43.69719162583351, 43.94984006881714, 45.32548025250435, 44.27848443388939, 51.75367511808872, 58.463237285614014, 59.49337720870972, 52.218409180641174, 47.559562772512436, 55.42178928852081, 49.82524819672108, 47.630873546004295, 46.567523404955864, 51.121807023882866, 46.884137615561485, 52.85851143300533, 53.02494630217552, 56.72265328466892, 60.061712712049484, 58.75843204557896, 56.157114431262016, 56.6581479460001, 54.63782675564289, 52.46614448726177, 48.61280545592308, 43.90900366008282, 38.820339515805244, 38.26615445315838, 45.376131534576416, 43.47128614783287, 45.42558208107948, 46.76626414060593, 39.248344749212265, 46.82577274739742, 43.091279938817024, 33.093271628022194, 37.67708346247673, 43.65444011986256, 43.53824235498905, 40.424484238028526, 49.3331366032362, 38.81377346813679, 39.20924484729767, 46.13715469837189, 41.12504884600639, 46.58068969845772, 49.889981523156166, 54.80531796813011, 57.1600516140461, 57.894970178604126, 56.028605327010155, 55.68830318748951, 55.19065149128437, 50.6021773070097, 49.30267743766308, 56.77851028740406, 60.90994879603386, 57.675220370292664, 55.245159566402435, 51.29974007606506, 47.68815167248249, 44.094122126698494, 46.94767780601978, 58.867892771959305, 55.550735369324684, 57.036011070013046, 51.25109128654003, 43.22361163794994, 41.5416356921196, 40.28943568468094, 44.043854624032974, 40.910808742046356, 40.99880822002888, 44.582145139575005, 47.85199128091335, 49.40622568130493, 53.18912789225578, 55.04889629781246, 56.91957011818886, 56.875405088067055, 59.713689386844635, 60.58869503438473, 70.43618962168694, 66.48595958948135, 53.931870236992836, 58.33616070449352, 65.39518252015114, 64.83988031744957, 64.24388989806175, 62.54294157028198, 62.15402863919735, 59.967857748270035, 59.197335094213486, 54.556305930018425, 53.58073867857456, 51.4551517367363, 60.68311236798763, 62.11118593811989, 70.86618214845657, 67.60221809148788, 77.06320121884346, 72.88238435983658, 81.42060980200768, 71.1845214664936, 81.2467235326767, 2.662488631904125, 0.09460226938244887, 0.6956458906643093, 13.306165896356106, 76.30574986338615, 54.55582335591316, 48.19749154150486, 32.46177591383457, 36.394891664385796, 66.03503778576851, 15.820554625242949, 0.3564696485409513, 0.2141061017755419, 0.07078583759721369, 0.022288414656941313, 0.03086953056481434, 0.038742910328437574, 0.09041674944455735, 0.019023699605895672, 0.030600600366597064, 0.05188677241676487, 0.05789420181827154, 0.06537872774060816, 0.02262755573610775, 0.17384518403559923, 0.22376375854946673, 4.385761236771941, 73.3916862308979, 47.02352553606033, 39.40463036298752, 58.90538915991783, 60.42276933789253, 81.54620826244354, 10.764589626342058, 0.6798107153736055, 0.3367041185265407, 0.7563281594775617, 4.599931044504046, 83.4982319176197, 83.40230226516724, 80.13524517416954, 74.71497282385826, 59.14561226963997, 67.95486196875572, 68.69389191269875, 73.11471149325371, 73.92570197582245, 73.02081853151321, 71.07213869690895, 72.8108873963356, 69.9083599448204, 69.85686510801315, 68.04023578763008, 71.67611628770828, 69.04572263360023, 65.8389151096344, 60.63663326203823, 67.35394701361656, 67.23655611276627, 65.4899874329567, 67.68230259418488, 64.60883751511574, 66.22195735573769, 62.47599296271801, 53.88106316328049, 52.2359262406826, 53.640311881899834, 52.926402390003204, 49.4658824801445, 46.79094761610031, 46.157912984490395, 45.14406658709049, 47.19962328672409, 47.50725097954273, 46.756931841373444, 55.09384408593178, 60.51234193146229, 64.27805006504059, 55.18999792635441, 50.97832292318344, 56.6515477001667, 51.74253411591053, 49.14183206856251, 47.45398923754692, 51.84776946902275, 50.07619433104992, 55.731715857982635, 54.30943317711353, 58.02481301128864, 59.35192599892616, 59.09189075231552, 58.56580138206482, 57.30499483644962, 55.25236777961254, 53.368026092648506, 50.755525678396225, 45.75861141085625, 42.912480533123016, 38.705407083034515, 46.69801980257034, 44.344783276319504, 45.30127175152302, 46.97369121015072, 38.91845405101776, 45.408167615532875, 44.35744419693947, 37.9341396689415, 40.78855410218239, 43.83526861667633, 43.81648622453213, 43.15383978188038, 50.75994484126568, 37.05560401082039, 39.747197180986404, 45.29308319091797, 44.13306623697281, 48.63078989088535, 51.50177143514156, 57.404838278889656, 58.01220528781414, 59.27687242627144, 56.3193429261446, 57.95324005186558, 56.21505372226238, 51.73998445272446, 50.24577923119068, 56.94268427789211, 61.384737119078636, 59.280539229512215, 59.51071187853813, 53.558711260557175, 48.60154286026955, 45.69363109767437, 48.235595896840096, 60.9249047935009, 59.18335564434528, 57.64509178698063, 53.645878583192825, 45.89261122047901, 45.12037105858326, 43.08664798736572, 45.99131852388382, 42.78148636221886, 43.456755727529526, 46.98428504168987, 48.735276684165, 49.75353844463825, 55.797950103878975, 55.16800470650196, 60.1084616035223, 59.477383866906166, 65.12250915169716, 63.66752542555332, 72.07011714577675, 71.11472681164742, 57.80358888208866, 61.37297675013542, 68.32515969872475, 67.0561645925045, 67.52023369073868, 63.13512459397316, 64.84823986887932, 61.69571243226528, 64.29940491914749, 55.24621210992336, 56.22938275337219, 55.03300555050373, 62.982182800769806, 65.47891482710838, 72.92371094226837, 68.75956758856773, 80.1137763261795, 74.57854494452477, 85.24676889181137, 71.4053276181221, 90.10233074426651, 4.620751552283764, 0.11921663608518429, 0.9507257281802595, 18.000574596226215, 84.1674292087555, 62.810059636831284, 54.860874786973, 26.954167149960995, 43.96595500409603, 73.28887894749641, 21.50716133415699, 0.6488518766127527, 0.20535536430543289, 0.02473498425388243, 0.08679140999447554, 0.17487305856775492, 0.03435734077356756, 0.00845649261464132, 0.10802710487041622, 0.24232767726061866, 0.2528348407940939, 0.26514264754951, 0.18559504416771233, 0.1544556557200849, 0.500470669940114, 0.5892945255618542, 6.053386302664876, 86.17236122488976, 59.2932153493166, 48.27876538038254, 65.47991797327995, 69.44740667939186, 87.00282946228981, 13.638349771499634, 0.7836238760501146, 0.6505517510231584, 1.4336444274522364, 5.394126428291202, 84.49495643377304, 88.96458059549332, 84.51311945915222, 77.98468217253685, 59.80865389108658, 71.47232562303543, 70.78524649143219, 75.4697947204113, 78.73884290456772, 77.81043872237206, 73.00001084804535, 75.67990824580193, 75.21368086338043, 71.6892483830452, 71.2892210483551, 77.19241708517075, 72.26031213998795, 70.15380397439003, 60.53815774619579, 63.435756862163544, 71.69431731104851, 67.03430816531181, 70.96517443656921, 68.33339765667915, 67.09660962224007, 64.39859479665756, 58.31207759678364, 55.207059010863304, 55.43897956609726, 54.405279234051704, 52.04385034739971, 49.93576146662235, 49.507406651973724, 49.173301979899406, 48.88813868165016, 50.38963571190834, 47.84273877739906, 57.66798555850983, 64.03322160243988, 66.69604271650314, 62.19206839799881, 54.90487262606621, 57.958605363965034, 51.835792511701584, 53.071178421378136, 53.18460613489151, 54.94837649166584, 53.39933641254902, 57.87696674466133, 57.82335542142391, 59.96652401983738, 60.47748640179634, 59.79168400168419, 57.67389804124832, 57.6828845590353, 56.97909772396088, 54.74873140454292, 50.80576278269291, 47.32182092964649, 43.459104001522064, 41.12905763089657, 46.3384222984314, 45.18973633646965, 45.24128437042236, 49.05949428677559, 39.91669088602066, 46.35314650833607, 49.92505744099617, 40.77019348740578, 44.54081475734711, 45.534358844161034, 45.02788782119751, 43.57107259333134, 51.44296959042549, 37.27727271616459, 39.183345437049866, 45.00679895281792, 44.971270859241486, 50.95443740487099, 53.51420424878597, 60.544624999165535, 61.19792394340038, 63.86956438422203, 59.89165663719177, 62.277977988123894, 58.53310413658619, 55.55191330611706, 52.451063096523285, 60.66918611526489, 65.79100728034973, 60.96940040588379, 60.733064487576485, 55.853328332304955, 51.5577994287014, 48.03873986005783, 49.56550553441048, 61.08369827270508, 59.72014904022217, 61.92454755306244, 55.594307631254196, 48.55866976082325, 47.14916579425335, 44.726286605000496, 49.62925851345062, 46.21848173439503, 46.409877464175224, 49.16260555386543, 52.213298454880714, 54.510951563715935, 58.864651545882225, 58.98937225341797, 63.8113971054554, 61.32798336446285, 65.75329050421715, 66.11981123685837, 72.53436863422394, 69.25572976469994, 62.061344012618065, 66.0502065718174, 68.97968217730522, 69.51522544026375, 70.73068901896477, 66.47104158997536, 66.86371251940727, 64.51271027326584, 65.64789935946465, 59.12890836596489, 59.94771882891655, 57.74684652686119, 66.4255428314209, 68.99541333317757, 79.17893528938293, 72.07997381687164, 83.749048858881, 78.93652349710464, 91.02441966533661, 77.71025329828262, 94.36231255531311, 6.769485902041197, 0.21078251214930788, 1.6630028514191508, 22.821337915956974, 92.54312977194786, 69.21974569559097, 66.14185005426407, 47.1533265709877, 49.9111083894968, 86.03464901447296, 25.841812938451767, 0.984862205805257, 0.6387087958864868, 0.2551758714253083, 0.21535252395551652, 0.3200480982195586, 0.14974750054534525, 0.15486874995986], [0.008567967834096635, 0.14768755092518404, 0.054327796315192245, 0.048961734646582045, 0.04227031968184747, 0.21922168118180707, 0.10240817864541896, 0.5351781856734306, 5.128182973712683, 59.101044461131096, 49.334086552262306, 37.07849398255348, 37.82030537724495, 60.009267926216125, 74.69912007451057, 10.953126959502697, 0.7703849114477634, 0.6666642520576715, 0.5160088080447167, 3.6811707448214293, 70.87714076042175, 79.75453600287437, 75.84700047969818, 69.2779889702797, 60.69701962172985, 63.26456844806671, 64.18410390615463, 64.52304571866989, 67.42970734834671, 67.37676098942757, 64.73252847790718, 69.10832807421684, 66.77150666713715, 64.96551677584648, 68.60857889056206, 68.1509618461132, 66.45357772707939, 64.1140964627266, 60.15274062752724, 52.528445944190025, 64.8507933318615, 65.711659938097, 63.1536789983511, 64.9124564230442, 64.0420751273632, 62.82982237637043, 54.12955462932587, 49.72644969820976, 50.08993059396744, 48.2784765958786, 48.40331889688969, 45.04766196012497, 41.96292668581009, 41.120565086603165, 44.2304740101099, 45.62369965016842, 44.005643874406815, 46.37782618403435, 51.95309601724148, 59.6794456243515, 59.102511182427406, 57.01652191579342, 51.25999800860882, 49.369534850120544, 48.75587917864323, 45.32438211143017, 46.66797861456871, 47.61128939688206, 52.19734311103821, 53.303744941949844, 54.38364319503307, 54.56801310181618, 57.11405128240585, 55.40137678384781, 58.463898450136185, 56.182443872094154, 58.108765706419945, 56.69463358819485, 54.965110793709755, 49.64654378592968, 46.05700559914112, 40.70873558521271, 43.287919387221336, 43.400579541921616, 40.99881201982498, 43.11288557946682, 44.87663693726063, 38.921064510941505, 33.24264161288738, 34.45444218814373, 41.069936603307724, 41.5475557744503, 44.66666400432587, 43.52186903357506, 37.96182878315449, 40.78568145632744, 42.525703087449074, 44.4362785667181, 41.460836827754974, 44.99199494719505, 41.784465461969376, 48.438474610447884, 50.484824404120445, 51.15793168544769, 50.3124238550663, 50.50204887986183, 49.39784333109856, 47.55744628608227, 49.4091135263443, 55.73648080229759, 53.32599654793739, 52.37902656197548, 46.681198105216026, 46.852572709321976, 43.53954568505287, 50.42692311108112, 55.01358479261398, 60.35453639924526, 56.28819599747658, 52.04093210399151, 45.02593472599983, 44.99530836939812, 43.06674085557461, 42.81531594693661, 40.72868451476097, 42.717041820287704, 43.15143831074238, 46.22295029461384, 48.8760781288147, 50.389046743512154, 52.28571876883507, 56.21082454919815, 56.4270443469286, 60.29172956943512, 63.32275092601776, 63.724716156721115, 45.495581924915314, 56.499263271689415, 61.539347022771835, 62.38141603767872, 63.47946971654892, 66.0448868572712, 63.33508126437664, 65.8305175602436, 63.28550152480602, 63.94912451505661, 56.48560680449009, 59.61891487240791, 51.245030611753464, 57.73212231695652, 60.34952826797962, 72.62931033968925, 71.29080176353455, 80.78646942973137, 70.42545139789581, 78.67518872022629, 61.62124402821064, 85.51514849066734, 10.455658603459597, 0.12396554258884862, 0.8023221977055073, 13.298913985490799, 76.91953092813492, 57.53351837396622, 49.865465238690376, 38.90209212899208, 43.888841941952705, 63.914629966020584, 18.03241118788719, 0.18387795193120837, 0.05378150883188937, 0.048031359765445814, 0.05148925214598421, 0.0687178727821447, 0.09356263180961832, 0.008709587236808147, 0.08657681799377315, 0.03482389191049151, 0.06444226353778504, 0.05622524899081327, 0.08751919711357914, 0.07974149688379839, 0.27381226827856153, 0.4752109613036737, 6.521686473861337, 70.18068373203278, 49.88831341266632, 38.53360690176487, 46.646030992269516, 65.46405002474785, 83.2849569618702, 12.522687837481499, 0.8338366379030049, 0.7343707408290356, 0.6624982506036758, 4.915392016991973, 77.62133046984673, 81.85371816158295, 79.54154223203659, 72.9122431576252, 63.53679344058037, 65.56178078055382, 67.72407755255699, 68.19050252437592, 70.21540626883507, 71.19364857673645, 67.89032623171806, 72.07444131374359, 68.50311934947968, 66.42447128891945, 70.07663771510124, 70.45119121670723, 67.25477993488312, 66.76544979214668, 64.44752097129822, 59.60727609694004, 66.0939422249794, 68.87268751859665, 65.09582698345184, 68.62596675753593, 66.41751006245613, 66.07903942465782, 54.82107572257519, 51.003906950354576, 51.65803425014019, 51.352333053946495, 52.11674943566322, 47.31447212398052, 44.17101480066776, 43.27868968248367, 46.53456777334213, 48.05065222084522, 46.327334493398666, 49.41161759197712, 54.92473416030407, 61.831030771136284, 60.52556902170181, 62.89937384426594, 52.396688014268875, 50.45752666890621, 48.80135513842106, 47.95675925910473, 48.45200948417187, 52.44236156344414, 54.814308285713196, 55.13697937130928, 55.546635389328, 56.84204287827015, 57.9194712638855, 59.114970713853836, 59.250304251909256, 58.35890628397465, 60.933184549212456, 59.81600269675255, 58.38718056678772, 53.05121049284935, 45.817040875554085, 41.5641912817955, 42.371788546442986, 42.721339389681816, 40.74323773384094, 43.76963473856449, 45.246577486395836, 39.53115217387676, 37.94747695326805, 39.79831203818321, 43.22545453906059, 42.52047836780548, 47.816235199570656, 42.38352611660957, 38.15410606563091, 40.485505163669586, 42.83605143427849, 42.89086729288101, 44.3903998285532, 44.75462928414345, 41.97136603295803, 49.606965109705925, 52.356778755784035, 52.574776858091354, 51.52113139629364, 52.28147439658642, 49.98008608818054, 49.20386753976345, 50.136139914393425, 57.31705158948898, 52.90477395057678, 54.37279477715492, 48.063001558184624, 49.75248970091343, 46.295074224472046, 53.973063826560974, 56.55304178595543, 63.53284165263176, 60.04553698003292, 53.44263128936291, 48.33478957414627, 45.79397231340408, 45.24529315531254, 45.19102066755295, 43.20276215672493, 45.722095370292664, 46.693726032972336, 48.667313531041145, 48.98733615875244, 54.66404154896736, 55.31029187142849, 58.69517304003239, 60.175573602318764, 63.42422068119049, 65.97804844379425, 69.86560463905334, 48.90816740691662, 58.93433220684528, 63.282013311982155, 64.99284490942955, 66.50102198123932, 69.0315417945385, 67.48881697654724, 67.79773280024529, 66.90785855054855, 67.61019766330719, 59.95839625597, 63.43513369560242, 54.3586291372776, 60.768455788493156, 63.60355585813522, 75.6859727203846, 72.3982447385788, 83.80691215395927, 72.54405051469803, 84.69876989722252, 63.62202286720276, 91.3813117146492, 17.132558673620224, 0.27148611028678715, 0.7264644932001829, 16.46117080003023, 84.64553475379944, 63.723105043172836, 59.877585992217064, 38.238856717944145, 47.66295522451401, 71.93473801016808, 26.43748987466097, 0.3111727541545406, 0.08565115203964524, 0.12859207636211067, 0.05228521295066457, 0.0978016531735193, 0.1299818666302599, 0.06502674194052815, 0.2509583649225533, 0.2388294751290232, 0.29873124207369983, 0.12455161660909653, 0.19456380978226662, 0.22635179077042267, 0.41200978390406817, 0.6499703822191805, 9.040072113275528, 81.08153879642487, 60.91944448649883, 46.08556866645813, 54.01545435190201, 74.33630794286728, 91.16295263171196, 14.969534240663052, 1.1783746001310647, 0.9125230531208217, 1.1566725396551192, 6.05107412673533, 78.15930560231209, 83.40880751609802, 82.00239658355713, 76.44350007176399, 66.80755913257599, 69.60604816675186, 70.5215710401535, 71.1081075668335, 74.45293888449669, 74.51757341623306, 68.90259191393852, 75.48262283205986, 72.05294206738472, 70.05256980657578, 72.50416785478592, 74.93705570697784, 69.00108262896538, 68.8178488612175, 64.02436807751656, 55.39623185992241, 68.81514340639114, 71.51169911026955, 68.11050921678543, 71.5192075073719, 68.6631591618061, 69.65595468878746, 58.83210249245167, 53.920584842562675, 54.43928360939026, 54.37486566603184, 51.966573894023895, 51.40991136431694, 46.97065897285938, 46.10899060964584, 50.088254883885384, 53.58674615621567, 49.50765363872051, 51.85059271752834, 57.79126234352589, 66.9067870080471, 63.20937640964985, 62.655449733138084, 53.837027326226234, 52.42798313498497, 53.239440992474556, 49.275987669825554, 52.19110384583473, 52.04210244119167, 57.41161331534386, 60.14386810362339, 60.84693677723408, 61.088360622525215, 61.46875061094761, 61.32781997323036, 64.09393474459648, 59.84782978892326, 63.00108298659325, 61.37128584086895, 59.65273305773735, 53.13886418938637, 44.45851877331734, 40.30099846422672, 43.27911525964737, 44.12912204861641, 42.31927156448364, 44.85751636326313, 45.9187538176775, 43.29957336187363, 40.22159032523632, 39.7679440677166, 44.30518940091133, 43.61152142286301, 47.90870703756809, 42.528841719031334, 40.40433391928673, 39.784404784440994, 43.90031352639198, 44.29749861359596, 44.1961694508791, 46.03568874299526, 43.37194047868252, 52.11480773985386, 55.57706035673618, 55.759746953845024, 54.38792936503887, 53.657471761107445, 52.599695920944214, 49.67522844672203, 51.08003206551075, 59.113374799489975, 55.08364923298359, 55.44023349881172, 51.12415909767151, 52.188850566744804, 47.58382447063923, 56.58734634518623, 59.332908019423485, 64.95055317878723, 62.11138352751732, 56.740269139409065, 50.4220137745142, 48.78215476870537, 46.57759286463261, 47.36431024968624, 46.16363547742367, 49.160283878445625, 47.96134561300278, 50.07555976510048, 51.957157999277115, 57.043504267930984, 57.24191442131996, 61.823081597685814, 62.94586054980755, 67.10421681404114, 68.61895993351936, 68.44486847519875, 51.36836439371109, 62.1087084710598, 63.91947850584984, 67.44939789175987, 68.12607318162918, 71.61634549498558, 70.10324388742447, 70.05509287118912, 68.8880766928196, 69.90299463272095, 61.676352471113205, 66.43951088190079, 57.061237916350365, 65.85027649998665, 65.75705990195274, 79.0288357436657, 75.04228726029396, 85.81758186221123, 74.53728675842285, 85.9222586452961, 65.52148014307022, 93.53720963001251, 21.15889672189951, 0.2788214385509491, 1.8302074167877436, 20.385206937789917, 92.95967102050781, 70.28058797121048, 71.9828662276268, 53.36120925843716, 55.823891311883926, 82.53675431013107, 31.055235788226128, 0.6900112086441368, 0.3894692746689543, 0.28852255549281836, 0.14062868751352653, 0.29556402296293527, 0.24259384110337123, 0.11872556438902393], [0.0495620504807448, 0.02962240334454691, 0.06440235825721174, 0.06109298446972389, 0.07311856359592639, 0.07580954654258676, 0.15810852142749354, 0.31382726796437055, 4.659466249868274, 58.414197117090225, 46.28852717578411, 33.01777347922325, 41.34515203535557, 58.51925387978554, 78.51992145180702, 13.646523132920265, 0.42249956633895636, 0.4696052527287975, 0.4005585046252236, 2.511017359793186, 67.92976811528206, 79.70829248428345, 75.95215603709221, 75.27855098247528, 65.58318123221397, 65.80261185765266, 60.64734488725662, 64.83696207404137, 63.219149485230446, 64.53026533126831, 63.258842155337334, 66.8107357621193, 62.515564039349556, 68.47230300307274, 66.33621722459793, 67.65799149870872, 63.38726006448269, 61.89884193241596, 57.79323823750019, 46.283617839217186, 60.32946154475212, 61.48028299212456, 63.31694483757019, 63.30118328332901, 61.29481114447117, 64.3412558734417, 50.64281612634659, 49.61042672395706, 49.93156649172306, 49.12056840956211, 48.39375860989094, 45.479580983519554, 39.529404267668724, 40.60997508466244, 41.04474015533924, 43.648778423666954, 41.84512920677662, 42.961288914084435, 45.94273813068867, 52.58697420358658, 54.23241510987282, 50.742328986525536, 47.86672309041023, 45.70435032248497, 47.970313131809235, 51.39747463166714, 49.91909176111221, 52.38178141415119, 53.18775996565819, 53.67565758526325, 54.69718337059021, 56.877331584692, 56.096332892775536, 54.08230796456337, 55.98583482205868, 55.53240515291691, 56.64169102907181, 59.56001803278923, 59.42704036831856, 57.048478201031685, 43.1866130232811, 42.625063955783844, 41.67490214109421, 42.44769707322121, 44.61879797279835, 43.765804544091225, 41.73394337296486, 39.793478697538376, 34.802051335573196, 35.50690211355686, 36.297947466373444, 44.8847609013319, 47.80359327793121, 42.08594508469105, 42.03852362930775, 40.71182481944561, 42.68159732222557, 39.59316864609718, 40.895259976387024, 48.39284285902977, 51.27352528274059, 52.98296615481377, 55.44496804475784, 52.12869979441166, 53.63363943994045, 54.02777709066868, 50.898576602339745, 51.10544890165329, 48.056838288903236, 46.56211629509926, 44.911800250411034, 44.504796490073204, 44.304824620485306, 41.91813848912716, 43.63649368286133, 45.28147481381893, 45.461212769150734, 52.81611330807209, 55.95228262245655, 51.16834692656994, 44.11550357937813, 44.4459680467844, 40.5290774255991, 41.24576456844807, 40.029088854789734, 43.26168179512024, 44.78491745889187, 46.0777372866869, 48.2319100946188, 52.647683545947075, 54.485637322068214, 55.59179976582527, 56.51888161897659, 59.35156121850014, 62.93351501226425, 52.558380737900734, 55.65212532877922, 61.12363412976265, 57.27826327085495, 62.21078619360924, 59.4224464148283, 65.19292697310448, 63.30148346722126, 69.20345976948738, 66.78622707724571, 69.12898376584053, 62.369621470570564, 60.721805691719055, 50.16490437090397, 57.127430364489555, 57.16100916266441, 72.21914514899254, 68.21713149547577, 77.78859749436378, 71.79589346051216, 80.37612184882164, 68.84901478886604, 84.0673653781414, 18.538528829813004, 0.24508263333700597, 0.4489842342445627, 13.539384081959724, 78.72830986976624, 56.687763556838036, 52.53127679228783, 23.627837039530277, 35.89603163301945, 57.91651502251625, 21.010858565568924, 0.17374395509250462, 0.08980315658845939, 0.07125208445359021, 0.12250863990630023, 0.03854286813293584, 0.08996720091090538, 0.0825658586109057, 0.0925208197440952, 0.033032280625775456, 0.10846319084521383, 0.06924501285539009, 0.12420746046700515, 0.1772304461337626, 0.09472452336922288, 0.5072594806551933, 5.599545780569315, 70.01337110996246, 51.5433944016695, 35.69126442074776, 48.001562654972076, 63.60418662428856, 89.76166382431984, 15.972268134355545, 0.6893976009450853, 0.4516818223055452, 0.48765464045573026, 3.2609068835154176, 75.34146040678024, 82.07928165793419, 78.56545060873032, 77.25164070725441, 69.58917707204819, 68.49792122840881, 62.411100044846535, 67.68818467855453, 63.6474397033453, 66.0409426689148, 67.1558940410614, 68.32170188426971, 64.78483647108078, 71.22999742627144, 69.76215898990631, 69.3826125562191, 64.19308662414551, 59.882122948765755, 61.7622734606266, 53.35359066724777, 59.79793846607208, 64.62997958064079, 64.72918465733528, 65.28422847390175, 64.99934256076813, 65.04303261637688, 55.02451680600643, 52.59509436786175, 51.945127844810486, 51.7864103615284, 51.245528385043144, 47.20549397170544, 44.21940520405769, 43.938208892941475, 44.58391584455967, 45.29900327324867, 46.30118429660797, 45.040309354662895, 49.11248244345188, 55.592050552368164, 55.49599550664425, 53.40442053973675, 49.70242738723755, 50.093631595373154, 50.64214736223221, 52.92533464729786, 52.29940943419933, 55.06258316338062, 54.035543873906136, 57.144905626773834, 59.13133643567562, 59.145745262503624, 59.3335235863924, 57.82078675925732, 58.38326297700405, 59.79644134640694, 61.02941058576107, 61.73802696168423, 61.0265227407217, 58.36338624358177, 45.282694548368454, 43.13404284417629, 41.62884101271629, 42.25602015852928, 44.706383273005486, 42.810513004660606, 42.796457558870316, 42.85643734037876, 38.354723900556564, 39.57181379199028, 37.58168198168278, 45.942829325795174, 47.819989398121834, 42.77433514595032, 42.69340328872204, 40.9195900708437, 43.473254442214966, 40.76078899204731, 42.133586928248405, 50.98507136106491, 51.45688444375992, 55.760537311434746, 56.64626978337765, 54.11738008260727, 55.64871311187744, 56.28213532269001, 53.90462949872017, 51.68279752135277, 49.808069318532944, 48.66824068129063, 46.089003682136536, 47.57510393857956, 47.99202136695385, 44.91327837109566, 46.422166004776955, 46.41653090715408, 47.114922031760216, 53.929031789302826, 57.3465646058321, 52.82699592411518, 45.28071865439415, 45.19642777740955, 43.316174671053886, 42.484817281365395, 42.497440204024315, 44.88567665219307, 47.188512682914734, 48.48348319530487, 49.52739357948303, 54.33042325079441, 54.84725631773472, 60.42173199355602, 61.52018465101719, 60.936235785484314, 66.10563799738884, 59.746044650673866, 58.643112033605576, 64.58171457052231, 60.0113882124424, 64.96513679623604, 60.69507792592049, 67.1796503663063, 64.32872414588928, 69.40872475504875, 67.99371108412743, 71.59554541110992, 66.60671710968018, 65.10040953755379, 54.51685644686222, 59.39271681010723, 59.52643163502216, 74.39610153436661, 72.11607187986374, 80.60646548867226, 74.33196857571602, 84.13997188210487, 69.86400112509727, 85.95854669809341, 29.232914373278618, 0.26209909992758185, 0.5639432952739298, 16.32935967296362, 87.52188920974731, 63.76805663108826, 60.20759828388691, 27.102875970304012, 42.17103771865368, 65.32360196113586, 30.00418558716774, 0.41281952639110386, 0.22200371080543846, 0.11493549784063362, 0.14850026200292632, 0.03651113867817912, 0.04870059885433875, 0.09918232244672254, 0.25994152820203453, 0.2462180153816007, 0.13163436233298853, 0.1847485505277291, 0.19681955280248076, 0.31019359419588, 0.5371879215817899, 0.7433471060357988, 7.7308267168700695, 81.9662757217884, 59.09626431763172, 43.87506388127804, 57.385903894901276, 72.69987255334854, 94.56807151436806, 16.732679530978203, 0.8337405149359256, 0.8154336316511035, 0.708009892841801, 4.778520036488771, 76.45707294344902, 86.64432629942894, 80.17814487218857, 80.58779329061508, 71.22322618961334, 72.5917075574398, 66.07134103775024, 71.8909339606762, 67.45608553290367, 70.56219846010208, 68.76878589391708, 73.86121183633804, 66.46084293723106, 73.28118816018105, 74.08236756920815, 73.2459108531475, 67.46706694364548, 64.31177705526352, 57.31257542967796, 51.445956230163574, 60.73876038193703, 65.65381944179535, 67.26320788264275, 69.03139740228653, 67.22450315952301, 69.546307772398, 57.137625217437744, 55.96485234797001, 54.158022701740265, 53.72630126774311, 52.97459900379181, 53.07505041360855, 48.72754789888859, 48.14528614282608, 48.04630145430565, 48.08821700513363, 49.816611260175705, 49.02689203619957, 52.37437181174755, 56.28191113471985, 57.59754113852978, 55.785859152674675, 51.36080659925938, 51.64856515824795, 52.68179811537266, 57.603411823511124, 55.845268964767456, 58.58595930039883, 58.02892439067364, 59.38602536916733, 61.54260724782944, 61.685407385230064, 63.170922473073006, 59.585199281573296, 61.31736673414707, 64.80570495128632, 63.896717727184296, 64.08243656158447, 63.82848098874092, 60.00731863081455, 44.53587882220745, 44.401046857237816, 43.339102640748024, 42.5702290982008, 45.62702067196369, 44.32209849357605, 43.57260011136532, 45.07451891899109, 40.57377442717552, 40.715662613511086, 38.609390035271645, 48.52001443505287, 47.290183827281, 43.76257851719856, 43.63440379500389, 39.9501708894968, 44.86675746738911, 41.04537092149258, 41.73539109528065, 51.97447367012501, 54.48976770043373, 56.65518410503864, 58.79375874996185, 57.40655958652496, 58.1499744951725, 59.22167658805847, 56.35264813899994, 55.50502762198448, 51.8933480232954, 52.59964272379875, 47.117992267012596, 49.8039997369051, 50.147356912493706, 47.337894067168236, 46.5852190554142, 47.11567059159279, 48.74476857483387, 54.5470230281353, 60.36385729908943, 55.94081863760948, 48.339364528656006, 48.95516708493233, 44.89534713327885, 44.85205225646496, 45.76309897005558, 48.13609443604946, 49.04701195657253, 51.020181477069855, 51.796620413661, 57.457685843110085, 57.165401726961136, 61.45655706524849, 63.720308393239975, 63.874686509370804, 68.26712161302567, 59.4457695633173, 61.88637100160122, 64.64064940810204, 63.33117127418518, 67.6666322350502, 62.0389936119318, 70.85959330201149, 68.40233355760574, 72.99665942788124, 70.98594412207603, 76.2310990691185, 68.21763306856155, 66.59426897764206, 55.03118544816971, 61.65289252996445, 61.9746782630682, 80.18113911151886, 73.6303286254406, 84.70164254307747, 76.47535756230354, 87.35554173588753, 71.22882708907127, 89.15051221847534, 35.47773867845535, 0.44307109841611236, 1.4811928197741508, 21.165806651115417, 95.30476078391075, 71.97572261095047, 71.49101302027702, 35.26985563337803, 46.95720389485359, 76.58810511231422, 38.84821102023125, 0.645746374502778, 0.406896237982437, 0.2821296954061836, 0.3205360157880932, 0.20928279496729374, 0.3499788249609992, 0.2104546016198583], [0.06569524630322121, 0.06832302053226158, 0.020915389504807536, 0.04300481581594795, 0.04574623882945161, 0.14491936977719888, 0.09099418486584909, 0.32289153314195573, 3.7802653899416327, 56.90874829888344, 45.67965924739838, 37.48093418776989, 39.41153459250927, 56.768456026911736, 80.63970610499382, 16.512848027050495, 0.7457256002817303, 0.5186074529774487, 0.13848594389855862, 1.6803135350346565, 61.01676866412163, 82.47755348682404, 72.57398530840874, 74.80340927839279, 70.13283669948578, 69.97586712241173, 60.67669451236725, 60.08798070251942, 59.873375818133354, 60.89591234922409, 61.79403595626354, 64.46827545762062, 63.86109083890915, 66.62224307656288, 64.1996830701828, 68.98449271917343, 62.66525320708752, 64.55549597740173, 61.95324741303921, 40.72477452456951, 64.15617540478706, 63.979484885931015, 64.09040853381157, 62.009001821279526, 61.25062711536884, 55.576608180999756, 54.40546162426472, 47.31337018311024, 46.68465971946716, 46.161849573254585, 47.05746911466122, 46.64628177881241, 41.78308233618736, 39.69039022922516, 40.518570989370346, 43.789625465869904, 43.599738255143166, 42.56201773881912, 42.5317295640707, 43.509458899497986, 47.0133800804615, 49.738574847579, 49.01205763220787, 47.995688170194626, 48.74406561255455, 51.207515224814415, 47.368892803788185, 51.97138823568821, 51.25572703778744, 51.71720087528229, 53.53546790778637, 52.87761680781841, 54.150331914424896, 55.636599361896515, 54.244487062096596, 54.76779878139496, 57.27382130920887, 61.02331191301346, 59.34610091149807, 57.34934985637665, 52.14487552642822, 42.75287389755249, 45.892527624964714, 49.37597170472145, 45.10366715490818, 46.075419411063194, 43.60118977725506, 41.70651264488697, 35.74630066752434, 34.870018288493156, 39.23429310321808, 45.89739516377449, 49.297030940651894, 42.549432814121246, 43.58142323791981, 43.179655596613884, 38.57377454638481, 39.81477655470371, 46.23039789497852, 51.36901035904884, 53.880375400185585, 57.30125203728676, 54.466087371110916, 56.256045922636986, 54.43134963512421, 55.26145689189434, 52.54413530230522, 51.163661777973175, 51.06989040970802, 49.75420720875263, 49.3889632076025, 47.59234741330147, 46.02837793529034, 45.28373569250107, 44.63482931256294, 45.961482524871826, 50.39781667292118, 53.273122385144234, 50.24293698370457, 49.56747002899647, 42.12776944041252, 41.60355716943741, 43.22356604039669, 42.13297136127949, 40.797521620988846, 42.04209543764591, 45.169194638729095, 49.02073256671429, 48.16327057778835, 52.820825055241585, 57.04485699534416, 60.58795407414436, 57.982943058013916, 62.48637780547142, 62.501979768276215, 57.87477806210518, 61.74317568540573, 62.02342204749584, 62.43755042552948, 62.341966554522514, 58.96284207701683, 57.7220718562603, 58.9935178309679, 61.38032555580139, 61.52544356882572, 71.17746904492378, 66.67864724993706, 65.0476835668087, 57.98617668449879, 57.08948940038681, 55.057799220085144, 62.983888909220695, 62.55975566804409, 75.2882632613182, 69.94341686367989, 79.9828353524208, 68.61769840121269, 88.12087386846542, 30.924348011612892, 0.5153253790922463, 0.3724085760768503, 13.268663808703423, 77.70571634173393, 59.389281794428825, 55.28652414679527, 33.00730124115944, 30.772156678140163, 56.57709449529648, 23.2853215187788, 0.120563827076694, 0.0443329187692143, 0.028254935023142025, 0.06894834674312733, 0.04446864273631945, 0.08066642069024965, 0.013792930531053571, 0.05275331517623272, 0.053178465605014935, 0.10021609705290757, 0.06557014989084564, 0.011751024376280839, 0.04325823327235412, 0.1245427702087909, 0.4585471632890403, 5.744453854858875, 68.73333379626274, 50.77806606888771, 32.53545396029949, 43.584045097231865, 67.12803393602371, 88.03558364510536, 18.381304666399956, 0.794756863033399, 0.7731892797164619, 0.2630004828097299, 2.4722625268623233, 68.32208946347237, 86.5978167951107, 74.48490276932716, 78.85612741112709, 73.67026448249817, 71.8207137286663, 63.30838769674301, 63.30642320215702, 61.11376605927944, 64.3455420434475, 63.11462089419365, 67.72011056542397, 65.43266370892525, 69.54955279827118, 68.24130579829216, 72.64348357915878, 63.87109950184822, 64.33372467756271, 68.4110426902771, 47.00280524790287, 64.08661633729935, 66.0509817302227, 64.26677986979485, 64.74605575203896, 64.32122334837914, 57.91052274405956, 56.15803778171539, 51.45879574120045, 50.176246762275696, 49.108291268348694, 49.320863261818886, 48.11456099152565, 42.55110092461109, 43.94201248884201, 44.06106010079384, 44.94679257273674, 44.872020184993744, 46.60934396088123, 45.94296231865883, 46.701280027627945, 49.48754511773586, 51.637655943632126, 48.798668682575226, 49.461512714624405, 51.059558764100075, 53.81497710943222, 51.1006573587656, 52.48771592974663, 53.66697505116463, 56.25611811876297, 55.13011693954468, 57.81369633972645, 57.06066034734249, 58.54985363781452, 55.585492104291916, 57.49620817601681, 60.37086792290211, 60.92180795967579, 61.207419633865356, 59.1228286921978, 54.06890608370304, 43.83014649152756, 46.188166961073875, 48.19093309342861, 43.9260533452034, 45.73118448257446, 43.10949236154556, 44.363615065813065, 37.5622346252203, 38.0740861594677, 41.15410968661308, 48.55961211025715, 46.56130313873291, 43.464146330952644, 43.40985484421253, 43.68047632277012, 38.266340643167496, 42.62761741876602, 46.661568358540535, 51.80446699261665, 56.33144907653332, 59.426086619496346, 57.74453245103359, 58.60203243792057, 57.033890783786774, 56.93888068199158, 55.29825411736965, 56.083238795399666, 52.93311282992363, 51.948969438672066, 50.94682261347771, 49.072379395365715, 49.24846574664116, 48.06731812655926, 46.85253091156483, 50.32644510269165, 51.73431895673275, 55.16695216298103, 52.84229390323162, 51.87109261751175, 45.10239042341709, 45.769885405898094, 44.65106964111328, 43.97368758916855, 42.79651835560799, 45.3028828650713, 47.61068522930145, 49.60415706038475, 49.701420441269875, 55.09973756968975, 58.20410259068012, 63.780421167612076, 59.33636963367462, 62.160807475447655, 62.73739613592625, 60.418809950351715, 62.06229396164417, 63.19744125008583, 64.30372148752213, 66.13042786717415, 62.62372903525829, 61.39432020485401, 62.66496442258358, 63.344174176454544, 65.18269792199135, 71.32552430033684, 69.49259385466576, 68.85010913014412, 61.550571620464325, 60.5879844725132, 56.618527472019196, 65.39542570710182, 65.55665105581284, 78.9252533018589, 72.56311029195786, 81.91560924053192, 71.9797731935978, 91.37138664722443, 37.77774006128311, 0.8544255362357944, 0.6500384223181754, 15.323140416294336, 84.39983233809471, 64.04856517910957, 62.25013308227062, 37.405751422047615, 38.42197269201279, 66.69510796666145, 34.141167998313904, 0.1079773809760809, 0.13241070817457512, 0.06891062337672338, 0.06807526195188984, 0.1071702063200064, 0.017209155957971234, 0.037272708359523676, 0.19396241783397272, 0.1375974595430307, 0.2316956696449779, 0.1605344092240557, 0.14385027636308223, 0.31631954829208553, 0.3619113424792886, 0.6705816637258977, 7.910686265677214, 79.2449377477169, 59.568141996860504, 47.13738642632961, 56.132837533950806, 74.06396895647049, 95.86014658212662, 21.510108076035976, 1.1515429336577654, 1.109140058979392, 0.514762356178835, 3.551790062338114, 68.99061039090157, 87.94501170516014, 78.21592256426811, 82.2158919274807, 74.60529550909996, 75.98527505993843, 65.64846932888031, 68.15736830234528, 64.46981057524681, 65.24683088064194, 66.61661177873611, 70.4192653298378, 68.67746159434319, 71.86468496918678, 70.38917854428291, 73.95184457302094, 68.26965227723122, 65.42300462722778, 60.744315683841705, 49.00024026632309, 64.79970127344131, 71.5048822760582, 65.93089297413826, 68.71938094496727, 66.86114385724068, 60.25725021958351, 59.00338590145111, 54.43197660148144, 51.36667348444462, 51.44355095922947, 52.38777369260788, 49.404606968164444, 46.40311382710934, 47.34264761209488, 46.37004800140858, 49.13507983088493, 48.64141792058945, 49.91501457989216, 47.82086335122585, 50.58573178946972, 51.366069316864014, 54.90943618118763, 51.9901592284441, 52.84016601741314, 52.278092578053474, 57.55387768149376, 52.73767031729221, 56.12038180232048, 57.887704968452454, 60.121730491518974, 61.45746901631355, 61.297167018055916, 61.28661498427391, 62.903967797756195, 59.6815887093544, 59.89422529935837, 60.900384709239006, 65.43515637516975, 65.36078676581383, 60.087558925151825, 56.485002636909485, 45.64663901925087, 46.754891350865364, 50.458009243011475, 46.53266027569771, 47.05754891037941, 45.852215588092804, 44.882663413882256, 40.23714289069176, 39.58841510117054, 42.19058386981487, 49.94774982333183, 50.02754554152489, 45.14473535120487, 44.31215822696686, 45.1334423571825, 38.337822407484055, 41.897064819931984, 46.95943057537079, 56.07124663889408, 58.802258893847466, 63.614997044205666, 59.748522117733955, 63.59087213873863, 59.60880361497402, 61.87191657721996, 59.765260219573975, 58.71615931391716, 55.99513292312622, 55.62279470264912, 53.102845922112465, 51.442509815096855, 50.436851978302, 50.21170645952225, 49.40846376121044, 52.701424062252045, 53.317371010780334, 58.599790558218956, 55.026868879795074, 55.35599961876869, 48.47060188651085, 48.786775320768356, 46.570525243878365, 47.69496850669384, 45.88261015713215, 47.203031703829765, 50.39923019707203, 53.49657699465752, 53.101618587970734, 56.31636008620262, 61.55005864799023, 66.34805738925934, 63.00563134253025, 67.00588569045067, 63.73657912015915, 63.44404421746731, 63.45212638378143, 64.57702562212944, 64.73955050110817, 66.98912099003792, 64.54634606838226, 63.83503943681717, 65.00305876135826, 65.18860280513763, 67.8106901049614, 75.69345831871033, 72.55460634827614, 72.63871863484383, 62.98356592655182, 64.18233320116997, 59.459160044789314, 68.44238340854645, 69.74100172519684, 84.16146352887154, 76.84661284089088, 85.63800349831581, 76.47677108645439, 97.03002020716667, 42.10221581161022, 1.4238497405312955, 1.2916771578602493, 18.552844561636448, 93.4004245698452, 71.97673335671425, 74.95616868138313, 49.0958621352911, 42.893785536289215, 76.27408236265182, 44.98559609055519, 0.35782006045337766, 0.21521436574403197, 0.2820886397967115, 0.321952864760533, 0.1597601265530102, 0.25114618765655905, 0.19040671410039067], [0.04724195212475024, 0.07625243059010245, 0.06308904630714096, 0.05317406466929242, 0.025954631601052824, 0.08159519624314271, 0.23512362007750198, 0.31400253355968744, 3.494528797455132, 63.17849546670914, 48.41171644628048, 35.654064416885376, 37.86326587200165, 51.09649658203125, 80.34325361251831, 22.640815302729607, 0.30670968582853675, 0.5102386395446956, 0.22465044690761715, 2.624721508473158, 57.39523619413376, 79.38492223620415, 72.63187900185585, 81.3365127146244, 67.81637459993362, 72.64346078038216, 57.775181606411934, 58.798519894480705, 56.668536588549614, 59.754199013113976, 61.00073352456093, 65.95078870654106, 61.81048147380352, 68.23169231414795, 62.429707646369934, 71.56309515237808, 59.66418944299221, 75.04654303193092, 52.57590539753437, 46.78009919822216, 68.43764886260033, 62.02529914677143, 63.334047719836235, 58.818936198949814, 59.356044977903366, 55.620761811733246, 54.11171458661556, 47.299930304288864, 48.98182265460491, 45.8051323145628, 48.405469581484795, 46.07783608138561, 41.06409251689911, 41.47904925048351, 39.61339496076107, 40.65627180039883, 40.43324276804924, 42.5519634783268, 40.074196234345436, 44.2260966449976, 45.32077610492706, 47.28432834148407, 46.10324151813984, 46.02441854774952, 49.36517648398876, 50.77664494514465, 49.18510414659977, 53.10291811823845, 51.525181978940964, 54.25136089324951, 54.461394622921944, 54.46300193667412, 51.673123240470886, 56.5380971878767, 53.0829805880785, 52.49830976128578, 54.989619478583336, 58.761449083685875, 55.948205441236496, 56.5001106262207, 52.65640787780285, 47.761791720986366, 45.23400396108627, 45.06276234984398, 44.916158616542816, 46.88264809548855, 40.80515921115875, 43.42021308839321, 41.57045714557171, 38.539785370230675, 42.557199597358704, 46.207203939557076, 45.14029338955879, 42.375732734799385, 46.12135514616966, 43.67350369691849, 42.86429151892662, 44.70135234296322, 48.52327086031437, 51.86308644711971, 52.89962902665138, 55.183716863393784, 54.18793469667435, 52.788496389985085, 52.72532477974892, 53.188238739967346, 51.000707522034645, 51.858655884861946, 49.765238016843796, 49.00478482246399, 49.137808084487915, 45.455665066838264, 48.529141545295715, 43.210946917533875, 44.445398077368736, 45.109845623373985, 45.73974922299385, 48.154645040631294, 47.10698805749416, 42.484304308891296, 40.87778091430664, 40.5627816170454, 41.42049439251423, 39.86460708081722, 40.32197333872318, 41.59667953848839, 44.946933165192604, 47.26409822702408, 49.70140524208546, 60.91307982802391, 60.02323977649212, 63.96307736635208, 56.903523579239845, 64.85419034957886, 64.23508957028389, 59.0281567722559, 62.514644488692284, 62.47355729341507, 64.24046248197556, 66.56186431646347, 65.20600587129593, 62.56712727248669, 64.88774254918098, 64.85111251473427, 60.68425990641117, 66.85955554246902, 64.36144798994064, 67.19521433115005, 60.65511927008629, 63.23593318462372, 58.94214078783989, 62.69032046198845, 53.45218017697334, 65.39927870035172, 63.71380314230919, 77.14909180998802, 64.8428213596344, 86.98093503713608, 37.46321573853493, 0.6258236872963607, 0.16158520127646625, 13.484525475651026, 80.59941306710243, 52.668092250823975, 53.25738362967968, 28.90963152050972, 36.84637203812599, 59.93206366896629, 25.628262497484684, 0.15317249723011628, 0.0289871972927358, 0.04633010867109988, 0.08889193282811902, 0.030113172615529038, 0.06736501920386218, 0.023580449233122636, 0.043465325870784, 0.15108252031495795, 0.12588921905262396, 0.020148841867921874, 0.05673395782650914, 0.1092105483985506, 0.20150153985014185, 0.325635876506567, 4.742966294288635, 71.91583782434464, 56.66678488254547, 40.87329715490341, 46.685244888067245, 60.684974268078804, 88.3577835559845, 25.881950184702873, 0.36247887765057385, 0.6253930041566491, 0.3314666636288166, 3.687672195956111, 62.28911519050598, 83.1347282230854, 78.7293130159378, 86.42438650131226, 72.11854934692383, 77.37018674612045, 63.125663101673126, 63.01981218159199, 58.332835882902145, 62.87898413836956, 62.56406843662262, 67.930056899786, 63.19943994283676, 70.5075041949749, 65.45629844069481, 73.06313306093216, 60.79528234899044, 74.01616752147675, 61.01487636566162, 49.999639838933945, 72.35636338591576, 66.69045701622963, 68.1788219511509, 61.795445680618286, 61.14563874900341, 57.20643952488899, 57.46367812156677, 49.487461522221565, 50.88039077818394, 49.878540337085724, 49.93396796286106, 47.65507444739342, 45.72394207119942, 43.225363343954086, 41.68330729007721, 44.469158202409744, 42.118193954229355, 44.8865620046854, 44.75335255265236, 47.01248712837696, 47.630907744169235, 50.7996641099453, 48.48890170454979, 48.942122384905815, 50.35192273557186, 51.15804947912693, 52.247804403305054, 53.28169472515583, 54.74496200680733, 58.06460827589035, 55.04336379468441, 57.86513417959213, 56.520314142107964, 57.647421061992645, 56.679453402757645, 57.78059631586075, 57.77716130018234, 59.43163812160492, 59.228694811463356, 59.39289540052414, 53.70294012129307, 48.53899821639061, 45.97450442612171, 44.11222815513611, 45.899876430630684, 47.346682995557785, 43.04118722677231, 46.747508347034454, 46.490862518548965, 42.29361154139042, 43.96251238882542, 47.43900664150715, 45.27315326035023, 43.446781262755394, 44.78104546666145, 44.977624118328094, 44.475598856806755, 47.806211337447166, 51.8297166377306, 52.987381517887115, 57.92442239820957, 57.10614770650864, 56.55334956943989, 55.54275959730148, 55.06270855665207, 55.137249156832695, 55.70648141205311, 55.479363799095154, 52.05113835632801, 50.414038002491, 51.440264135599136, 48.671531304717064, 49.38759908080101, 45.29338717460632, 45.189105570316315, 47.032865434885025, 48.49198713898659, 51.710509434342384, 48.317230716347694, 44.72953163087368, 42.058742344379425, 43.772218599915504, 42.65313304960728, 43.515435978770256, 43.25184792280197, 45.14332942664623, 48.07220086455345, 47.07010343670845, 52.646456211805344, 63.48744548857212, 63.28617788851261, 65.85602939128876, 59.408550560474396, 65.24376824498177, 64.71169039607048, 62.925018668174744, 63.52561444044113, 65.45996144413948, 66.11343517899513, 68.61569970846176, 67.28086173534393, 65.76549544930458, 68.0580872297287, 67.82951429486275, 62.68486015498638, 69.21748861670494, 67.40136086940765, 69.99716877937317, 62.14034557342529, 64.93799865245819, 62.69038885831833, 65.21444901823997, 57.15767674148083, 66.65343940258026, 65.4545733332634, 81.10805377364159, 68.77561032772064, 90.36876484751701, 40.13900175690651, 0.7687450025696307, 0.2773564984090626, 14.787634201347828, 87.66758099198341, 58.870499432086945, 61.44519567489624, 33.590649738907814, 40.16441099345684, 68.42052698135376, 38.327771946787834, 0.2193583847838454, 0.1179357040382456, 0.09961181072867475, 0.03953526800614782, 0.046120407423586585, 0.0394255637365859, 0.04678692283050623, 0.22255880758166313, 0.23533943662187085, 0.24316413706401363, 0.20715965889394283, 0.20990833640098572, 0.2212661792873405, 0.5365416000131518, 0.6547828833572567, 6.74632946960628, 82.33613267540932, 61.50515265762806, 45.28767988085747, 56.94480836391449, 66.35945677757263, 94.24632757902145, 28.20143312215805, 0.508991297101602, 0.9984702849760652, 0.4805706924526021, 5.323760854080319, 64.11631554365158, 87.75714978575706, 79.8903027176857, 86.74692839384079, 73.1531274318695, 79.00942638516426, 64.0006573498249, 65.78431203961372, 62.60468825697899, 64.76019099354744, 65.75612515211105, 70.22622048854828, 66.23701974749565, 73.60808461904526, 69.93010997772217, 76.69247031211853, 62.86763034760952, 67.45395004749298, 60.35780422389507, 54.256619811058044, 72.94048324227333, 70.92789843678474, 69.57865163683891, 65.87010383605957, 63.75527411699295, 62.00633056461811, 59.6660665422678, 54.711269214749336, 53.96964021027088, 51.09575942158699, 52.29923464357853, 50.967238917946815, 48.130086958408356, 46.13775506615639, 43.424161076545715, 47.444835528731346, 45.81328667700291, 45.524137392640114, 45.9701194614172, 49.41276133060455, 51.47672697901726, 54.12904925644398, 49.5089265704155, 50.779133811593056, 53.866072967648506, 53.95556576550007, 53.373452201485634, 59.04341295361519, 57.643347680568695, 63.49713496863842, 59.63070943951607, 61.92969247698784, 59.53742444515228, 61.78520143032074, 58.122186586260796, 57.390912026166916, 61.09909124672413, 62.33382739126682, 63.46111670136452, 60.02762474119663, 56.59787178039551, 48.59237015247345, 48.980640918016434, 46.16466902196407, 47.054277285933495, 48.93616050481796, 44.08034406602383, 46.491664275527, 47.64505058526993, 43.87202024459839, 44.81518663465977, 48.38130287826061, 45.94420485198498, 44.71014127135277, 47.36648753285408, 47.19049237668514, 44.083729684352875, 48.923719972372055, 52.25589036941528, 55.47436326742172, 57.0085309445858, 59.178845286369324, 60.75123891234398, 59.06947575509548, 58.50353792309761, 58.35219584405422, 57.70684227347374, 59.78539913892746, 55.716015100479126, 54.75013732910156, 55.17501153051853, 50.471008345484734, 52.727502062916756, 46.834333688020706, 49.32563580572605, 50.65718695521355, 50.61953857541084, 54.37906064093113, 51.11853539943695, 47.37241141498089, 44.45112816989422, 46.433793380856514, 46.392033621668816, 44.63251143693924, 45.96397519111633, 47.62939162552357, 49.54285115003586, 50.12075833976269, 53.05660240352154, 68.64829435944557, 64.32787299156189, 69.76957619190216, 62.040110751986504, 67.37514987587929, 66.17005974054337, 66.70573219656944, 65.28260976076126, 66.83684796094894, 69.25389066338539, 71.81352451443672, 70.16809120774269, 68.03976461291313, 71.2071530520916, 70.01255795359612, 64.55804944038391, 71.52980893850327, 68.58750522136688, 73.1242261826992, 64.50605303049088, 69.19805645942688, 65.24116158485413, 71.76643744111061, 59.605752378702164, 72.24225550889969, 71.55914336442947, 84.93889421224594, 71.90122380852699, 94.75857049226761, 44.5835966616869, 1.3560886890627444, 0.7139406620990485, 18.387952409684658, 98.95773276686668, 65.60925543308258, 72.99206927418709, 43.47751021385193, 49.66018125414848, 79.57615077495575, 49.96528588235378, 0.3540826344396919, 0.25828351092059165, 0.20223824016284198, 0.25347492832224816, 0.19566060014767572, 0.28818980616051704, 0.13999719405546784], [0.08340801810845733, 0.0676304854277987, 0.0548570255341474, 0.021706741572415922, 0.07790862218826078, 0.09890717119560577, 0.0960652057256084, 0.2540812629740685, 1.9647722085937858, 59.15755122900009, 44.27696451544762, 23.424747437238693, 37.931213825941086, 50.81014394760132, 75.943743288517, 37.15143866837025, 0.43289025721605867, 0.5497336015105247, 0.13113258144585416, 5.05231149494648, 59.91573594510555, 72.78903096914291, 77.1018223464489, 73.65360617637634, 71.5823145210743, 71.0517717897892, 59.4219296425581, 54.33681070804596, 57.2306252270937, 61.7872267216444, 65.87926894426346, 65.13457730412483, 65.67664101719856, 61.326391249895096, 69.22996714711189, 64.25024315714836, 70.96487805247307, 69.72207114100456, 36.76650032401085, 65.53699851036072, 65.98070830106735, 63.581270053982735, 60.36688193678856, 59.051685109734535, 55.329366847872734, 57.14688532054424, 52.01295040547848, 48.919114619493484, 44.330575838685036, 45.323067381978035, 46.84321001172066, 47.04841420054436, 41.702579855918884, 40.72651103138924, 41.13624684512615, 41.3021307438612, 40.74373170733452, 41.36195473372936, 41.98341138660908, 46.315524727106094, 42.88295991718769, 45.004747062921524, 42.79868803918362, 45.86198106408119, 48.145118951797485, 49.55923967063427, 50.905412435531616, 51.140490621328354, 50.84316797554493, 49.363626167178154, 54.04589831829071, 52.93693922460079, 51.2753301858902, 53.066443875432014, 55.63351772725582, 56.151847913861275, 54.31262880563736, 55.42985625565052, 54.04017582535744, 58.65957275032997, 53.63674767315388, 50.777940675616264, 46.825791746377945, 45.142945647239685, 43.5759287327528, 44.42284248769283, 38.97323191165924, 51.77295908331871, 48.77255268394947, 43.93879026174545, 46.401320323348045, 45.16168624162674, 45.08380562067032, 44.18187081813812, 46.28677546977997, 47.23848760128021, 43.58599819242954, 48.64818535745144, 47.720879316329956, 50.76822079718113, 56.14302858710289, 54.965315982699394, 53.45389008522034, 52.865810841321945, 52.631648406386375, 50.82193471491337, 51.625899374485016, 52.180730402469635, 50.54787442088127, 48.82630079984665, 49.17984902858734, 50.27226381003857, 43.84076312184334, 46.39511525630951, 42.92912743985653, 43.469952419400215, 44.241865798830986, 42.934724539518356, 40.28736099600792, 39.56218130886555, 39.72214512526989, 41.74008384346962, 39.93359997868538, 41.974550262093544, 38.35537746548653, 44.59273137152195, 44.96361047029495, 46.15987367928028, 54.15781371295452, 61.84070885181427, 58.982483223080635, 60.83732329308987, 58.753773495554924, 71.28882586956024, 66.43802136182785, 59.14464332163334, 59.78866696357727, 61.64432778954506, 64.96618553996086, 65.09967237710953, 61.7302867770195, 66.26326873898506, 63.88059139251709, 65.99108934402466, 64.34946343302727, 67.51994490623474, 66.18300184607506, 69.44549158215523, 64.01319667696953, 67.5060148537159, 64.51948150992393, 69.31113839149475, 59.47973974049091, 66.02755978703499, 58.214396238327026, 76.11314579844475, 64.1871589422226, 89.89981681108475, 30.909783393144608, 0.9199357428587973, 0.24232925061369315, 15.182723701000214, 78.42727482318878, 56.01592160761356, 51.77953653037548, 33.89044225215912, 36.6308856010437, 56.594489961862564, 31.762265749275684, 0.19412530440604314, 0.12552129192044958, 0.07259096339112148, 0.028712598941638134, 0.06822516836109571, 0.029344693539314903, 0.09059477582923137, 0.014611567657993874, 0.10171472327783704, 0.08494048626744188, 0.02661238409928046, 0.021973064976918977, 0.09864008708973415, 0.11294208918116055, 0.3009337285766378, 3.70971932541579, 68.91450807452202, 48.247462660074234, 34.66440372169018, 49.9784179776907, 58.73861610889435, 84.08208578824997, 41.48108214139938, 0.6512865365948528, 0.9117568004876375, 0.037325345183489844, 6.2652353849262, 66.92697912454605, 75.2671667933464, 81.3388229906559, 76.60576656460762, 74.63878691196442, 73.29394787549973, 61.68194577097893, 58.254088908433914, 59.935228899121284, 65.88901922106743, 69.67461928725243, 66.91117197275162, 67.95760542154312, 66.39015153050423, 70.37623643875122, 65.87224692106247, 68.32218825817108, 78.28934982419014, 42.627826407551765, 67.6599445939064, 66.26112565398216, 67.05810248851776, 62.52926230430603, 60.52224040031433, 56.800731495022774, 58.014249578118324, 53.9104887843132, 50.28101474046707, 46.56739801168442, 48.47005471587181, 49.07830327749252, 50.45452103018761, 44.27691511809826, 43.111141473054886, 44.09127987921238, 44.03650961816311, 44.07570831477642, 43.504150584340096, 43.87544386088848, 48.74311946332455, 45.911754593253136, 46.341978907585144, 45.85137963294983, 49.938550516963005, 50.15630163252354, 50.834656432271004, 53.586822152137756, 54.208385199308395, 56.12183712422848, 53.11210222542286, 55.33963769674301, 54.99470740556717, 56.11626282334328, 56.02018117904663, 60.84170065820217, 59.14455972611904, 55.45152649283409, 57.85060375928879, 57.22637705504894, 60.78589305281639, 55.0334919244051, 50.98735883831978, 46.711938455700874, 46.841260716319084, 45.252398774027824, 46.66459299623966, 41.95124991238117, 54.36578035354614, 50.92903196811676, 48.499848917126656, 47.14644134044647, 46.31439998745918, 46.21246285736561, 43.98884877562523, 45.97331888973713, 45.72807624936104, 42.312868908047676, 49.60903599858284, 49.76560279726982, 52.66216456890106, 57.68407389521599, 57.64976553618908, 56.812875643372536, 57.06055015325546, 55.40321968495846, 53.96757312119007, 53.3640743046999, 55.62198154628277, 52.59527675807476, 51.653664484620094, 50.4336753487587, 51.43246315419674, 46.53279706835747, 49.68245945870876, 45.19483186304569, 44.87784527242184, 45.0053246319294, 44.545933082699776, 43.76459240913391, 41.670741364359856, 40.63756920397282, 43.96689735352993, 43.58320914208889, 43.17381531000137, 42.65604369342327, 46.92580997943878, 46.91770501434803, 49.14483770728111, 56.36562064290047, 64.24518942832947, 59.53142836689949, 62.36919969320297, 60.72983466088772, 68.53825226426125, 69.43639487028122, 62.12942115962505, 60.833154916763306, 62.90476955473423, 65.1522159576416, 66.74226343631744, 64.25160348415375, 69.94238331913948, 66.15407019853592, 68.79013314843178, 65.93391001224518, 69.07710894942284, 69.3977053463459, 73.57538357377052, 68.595150411129, 69.34707686305046, 67.13687226176262, 74.15614441037178, 65.44180601835251, 70.51682889461517, 60.454053059220314, 78.59220877289772, 66.55222803354263, 95.42251646518707, 32.1815637499094, 0.7224406872410327, 0.12065030212397687, 16.95004876703024, 86.12471178174019, 62.386576160788536, 61.562385186553, 38.5027601569891, 38.219261169433594, 63.738942593336105, 42.97751784324646, 0.12178769538877532, 0.11027104774257168, 0.09727394164656289, 0.06591312601813115, 0.07880654666223563, 0.07254952186485752, 0.043227990754530765, 0.12440415186574683, 0.1958320807898417, 0.1901543393614702, 0.11673621527734213, 0.24906018865294755, 0.23145205224864185, 0.32132387976162136, 0.48789233551360667, 4.690526258200407, 77.82845735549927, 56.23521164059639, 29.74147718399763, 54.32470075786114, 66.5106962621212, 91.82978644967079, 45.00660516321659, 1.2826109630987048, 1.4888583146966994, 0.3622940828790888, 7.7231235802173615, 65.58501273393631, 79.27921190857887, 81.20329186320305, 82.31806844472885, 74.93577137589455, 76.92293554544449, 65.21397784352303, 61.44268400967121, 61.72717094421387, 67.65670716762543, 69.75071400403976, 71.13748759031296, 71.00688099861145, 68.15166860818863, 69.43789958953857, 73.29967796802521, 63.67615856230259, 74.15108308196068, 48.84790264070034, 67.8889811038971, 71.48453056812286, 68.40929478406906, 65.29562026262283, 65.45896589756012, 60.38315646350384, 62.24631808698177, 57.114446461200714, 53.241378888487816, 48.4959427267313, 50.04674211144447, 51.62522301077843, 52.91543237864971, 46.81307002902031, 45.87211512029171, 47.10497036576271, 47.26757124066353, 47.69799314439297, 47.7785450220108, 46.365682035684586, 52.642967998981476, 48.21606494486332, 49.39281240105629, 47.7298354357481, 52.732791379094124, 53.58567841351032, 54.164170771837234, 57.46708653867245, 57.814961671829224, 60.262596532702446, 56.8164436519146, 61.36676788330078, 61.145315766334534, 59.309619069099426, 61.01779080927372, 62.75914616882801, 60.724351555109024, 60.35883016884327, 59.67414490878582, 59.30194728076458, 63.49415972828865, 57.29449599981308, 52.7961415797472, 49.552916809916496, 46.7117864638567, 46.74110569059849, 47.97998361289501, 40.988628566265106, 55.466957464814186, 55.47033168375492, 53.4550566226244, 49.04900684952736, 47.271230444312096, 48.38801331818104, 46.14677578210831, 47.446670830249786, 47.33027547597885, 43.68032433092594, 53.4183543920517, 52.636363953351974, 54.418160542845726, 60.60047060251236, 60.76495997607708, 63.828594982624054, 59.44697789847851, 60.31301602721214, 58.455272912979126, 57.47966766357422, 59.28619712591171, 56.93199545145035, 54.950056001544, 55.16862027347088, 56.650289967656136, 48.86303722858429, 51.547923758625984, 47.71612957119942, 48.43196555972099, 48.031189665198326, 47.14563958346844, 48.03812049329281, 44.851140305399895, 44.617604836821556, 45.97710728645325, 46.63787662982941, 46.37814536690712, 44.49588596820831, 50.59955544769764, 48.55163253843784, 50.99450625479221, 58.76684479415417, 66.44250512123108, 63.337152153253555, 64.97266039252281, 62.44627095758915, 70.76883137226105, 69.08172950148582, 62.56002925336361, 63.20644676685333, 63.088121116161346, 69.45843368768692, 70.77947840094566, 67.07112818956375, 72.15517178177834, 68.69186282157898, 70.96672475337982, 69.53099459409714, 72.51929864287376, 71.33671090006828, 76.21824815869331, 71.59785568714142, 73.20735812187195, 69.97047141194344, 76.5210235118866, 67.65713274478912, 72.41405948996544, 63.535581305623055, 84.10733923316002, 72.36919909715652, 100.11885166168213, 38.365040346980095, 1.9094974058680236, 0.3050054772756994, 20.134589485824108, 96.60176038742065, 69.26644518971443, 72.03734010457993, 49.841735512018204, 50.93285836279392, 74.7461311519146, 56.66564114391804, 0.20382879622047767, 0.2843472920358181, 0.21408606378827244, 0.22916080488357693, 0.18082965456414968, 0.15219351538689807, 0.18657473847270012], [0.08240486451541074, 0.049037945791496895, 0.043831431030412205, 0.11805301532149315, 0.0525220619601896, 0.07893877511378378, 0.10685525368899107, 0.5048190022353083, 4.60474063642323, 57.57135674357414, 42.8032173961401, 30.305693708360195, 34.49667692184448, 56.04820467531681, 70.03363162279129, 50.54297648370266, 0.10173096889047883, 1.4655272103846073, 0.7272455294150859, 10.837881043553352, 75.02934515476227, 71.49850621819496, 73.2423086464405, 72.17643544077873, 72.97601893544197, 62.67259821295738, 53.194318413734436, 57.726886197924614, 66.13517001271248, 69.14980664849281, 66.60026505589485, 64.75651279091835, 66.42719194293022, 70.81580445170403, 66.00963994860649, 72.5959025323391, 79.39410254359245, 36.79850600659847, 54.23329286277294, 67.8097477555275, 65.13766273856163, 61.94117546081543, 58.12091365456581, 53.604099825024605, 55.65669268369675, 55.26014216244221, 48.58690224587917, 46.69027201831341, 46.841260716319084, 47.20162957906723, 46.73021927475929, 45.428876504302025, 41.2763225287199, 42.3251498490572, 42.6450926810503, 41.23780779540539, 40.50624065101147, 42.04450070858002, 42.36119091510773, 42.775011509656906, 42.41425886750221, 42.828527837991714, 39.81614828109741, 42.261047288775444, 48.02807383239269, 51.006255224347115, 51.09829008579254, 50.86543098092079, 48.64320382475853, 51.82725436985493, 50.52559621632099, 50.63546732068062, 53.23971837759018, 51.865841299295425, 52.25907079875469, 54.24170181155205, 54.691365882754326, 56.43885411322117, 53.35962854325771, 55.734014734625816, 52.72619493305683, 51.16030655801296, 54.2107030749321, 44.636410027742386, 45.10155826807022, 42.121735364198685, 42.53553315997124, 56.353176310658455, 53.863884285092354, 54.1165479272604, 52.28577956557274, 47.305265218019485, 45.0494896620512, 44.11116041243076, 45.968572944402695, 44.93083342909813, 45.90446658432484, 50.34746557474136, 51.19980923831463, 54.3002300709486, 57.18136467039585, 51.52607873082161, 52.709776014089584, 53.69974069297314, 51.07668824493885, 50.01152940094471, 48.386254012584686, 50.65878666937351, 48.72277535498142, 49.22248654067516, 48.02840821444988, 49.517061933875084, 45.338004380464554, 45.29599383473396, 42.02589690685272, 38.65186795592308, 41.81611396372318, 44.025136828422546, 42.19442926347256, 39.25871439278126, 35.57315535843372, 41.152095794677734, 41.908942982554436, 41.52958653867245, 39.411101415753365, 44.475728049874306, 44.10834476351738, 46.024122163653374, 52.63328991830349, 61.14017844200134, 57.76483856141567, 57.524820640683174, 52.48699776828289, 68.27050343155861, 66.58813610672951, 55.03495864570141, 58.20216469466686, 59.73505564033985, 62.093630880117416, 62.09930017590523, 64.13194790482521, 67.45963454246521, 64.53382194042206, 63.3184951543808, 62.015225887298584, 66.52597144246101, 64.62856605648994, 69.82376888394356, 64.93283092975616, 71.78194060921669, 66.1805547773838, 75.23676082491875, 66.5452516078949, 75.62482640147209, 66.83330655097961, 76.89547061920166, 65.50416067242622, 89.48578342795372, 18.179163113236427, 0.5978485790546983, 0.058055281260749325, 14.0541529096663, 81.96728646755219, 52.519888803362846, 55.54742194712162, 31.796378418803215, 38.77269007265568, 62.696970105171204, 30.90980999171734, 0.033914260056917556, 0.046326464726007544, 0.013258621311251773, 0.07009713939623907, 0.009184264890791383, 0.060193200915819034, 0.0706525552959647, 0.07263483916176483, 0.014149238413665444, 0.08746123538003303, 0.11199902728549205, 0.02758809678198304, 0.11193736965651624, 0.20633618667488918, 0.5431984271854162, 5.070755705237389, 67.19016820192337, 48.08958113193512, 36.824773997068405, 44.31232921779156, 61.53990939259529, 75.8313225209713, 55.523821413517, 0.18631178070791066, 1.8701005261391401, 1.1887480434961617, 14.154010601341724, 79.37177494168282, 74.14068683981895, 79.42256301641464, 74.41672682762146, 76.60013526678085, 66.3754615187645, 55.989957600831985, 62.499243915081024, 69.39972683787346, 71.06619581580162, 69.88321289420128, 66.94938272237778, 68.96553933620453, 72.09247514605522, 70.03151133656502, 66.5515972673893, 82.96144232153893, 44.602675437927246, 57.25072994828224, 71.82605624198914, 67.18930944800377, 64.76523712277412, 60.837133303284645, 56.579723954200745, 57.24654637277126, 58.813491091132164, 50.84050431847572, 48.898842707276344, 47.87393510341644, 48.576536402106285, 50.14957219362259, 48.35785053670406, 45.90481236577034, 45.0688686221838, 44.615682139992714, 43.97002078592777, 42.78065040707588, 43.208564445376396, 44.54518832266331, 44.28106069564819, 44.22817513346672, 45.36673083901405, 43.674856424331665, 45.17149731516838, 50.84358595311642, 53.14030431210995, 53.70129480957985, 53.63833598792553, 52.14363679289818, 53.987719640135765, 53.34073215723038, 53.82405862212181, 54.87607017159462, 55.47101944684982, 53.30806910991669, 56.585837826132774, 57.11401328444481, 58.48651863634586, 59.12104278802872, 55.978964790701866, 54.3816938996315, 51.211820393800735, 55.09307652711868, 49.00032006204128, 45.26132449507713, 43.32368306815624, 44.001794680953026, 58.550773188471794, 57.30838045477867, 57.17851482331753, 51.37412488460541, 47.96559378504753, 45.52354842424393, 45.78542277216911, 46.36418491601944, 45.280114486813545, 46.48062966763973, 51.13793335855007, 52.535752952098846, 56.08416594564915, 57.90831506252289, 55.09024187922478, 55.42178548872471, 56.3870020955801, 52.33483873307705, 54.61746744811535, 51.28172144293785, 53.76574695110321, 52.462717071175575, 51.51198908686638, 51.522978097200394, 52.12266951799393, 49.623129442334175, 47.335800379514694, 43.356570303440094, 40.32054841518402, 43.22754442691803, 46.82707607746124, 43.18837992846966, 38.826138004660606, 38.25801908969879, 42.505115792155266, 44.667784944176674, 44.04159754514694, 43.886030092835426, 46.60153158009052, 48.131261095404625, 48.65074262022972, 55.95194064080715, 62.591324374079704, 60.02317138016224, 61.16133190691471, 56.33592523634434, 67.37900286912918, 65.9250944852829, 60.3457360714674, 58.76427233219147, 63.05397994816303, 63.67056906223297, 65.48288941383362, 68.70238825678825, 70.70896178483963, 66.4011025428772, 68.07864412665367, 64.80396464467049, 69.98833805322647, 67.01884299516678, 72.57622718811035, 66.18280425667763, 74.79383379220963, 70.64229056239128, 77.86843121051788, 70.82868576049805, 78.60845670104027, 69.9283392727375, 80.71761712431908, 68.59260454773903, 96.01042851805687, 18.527735508978367, 0.38529757352080196, 0.02654373358382145, 16.406077556312084, 90.67502841353416, 58.49132537841797, 65.97125440835953, 32.77070313692093, 38.09948779642582, 71.9428163766861, 40.676585510373116, 0.09839783524512313, 0.14753627154277638, 0.044409627153072506, 0.0378625636221841, 0.07340488416957669, 0.05127999247633852, 0.0317971984623, 0.18712933058850467, 0.2103828953113407, 0.15324408479500562, 0.18223875551484525, 0.2311345614725724, 0.33589511818718165, 0.4130037274444476, 0.9240698022767901, 7.239262294024229, 78.45999866724014, 56.74486689269543, 39.3065120279789, 48.52448299527168, 72.42146909236908, 81.97474166750908, 58.345329612493515, 0.4644145828206092, 3.0121354199945927, 1.5032524173147976, 14.53926907852292, 79.37768742442131, 74.9338410794735, 81.43053486943245, 77.53839612007141, 77.52833425998688, 70.23703470826149, 58.72030109167099, 64.35367360711098, 72.17571347951889, 72.75416404008865, 73.37888091802597, 70.20241096615791, 72.5518248975277, 76.1949934065342, 74.46473345160484, 64.61243212223053, 76.60024926066399, 51.624493449926376, 55.66312953829765, 74.82175469398499, 71.00696459412575, 66.29834085702896, 63.32302451133728, 58.38720716536045, 59.97320406138897, 64.20927375555038, 53.82652848958969, 51.26417778432369, 51.65660172700882, 52.814171612262726, 52.112265676259995, 53.54586414992809, 47.403835728764534, 47.27373071014881, 48.307412043213844, 46.84129111468792, 43.60526695847511, 47.58024126291275, 49.06243532896042, 47.057640105485916, 46.11506648361683, 48.344114273786545, 44.96898338198662, 46.96023233234882, 52.71593548357487, 56.14858388900757, 57.059607803821564, 58.34592618048191, 54.287740141153336, 57.13774301111698, 57.530284747481346, 55.586031675338745, 60.54144077003002, 59.82772886753082, 57.730427607893944, 61.952764838933945, 60.496397987008095, 62.28625014424324, 58.82440410554409, 57.94841431081295, 57.46664196252823, 52.2062574326992, 56.69727444648743, 50.98219111561775, 47.32044920325279, 42.731424048542976, 46.05118051171303, 60.950883999466896, 57.78279259800911, 62.156304717063904, 53.26557219028473, 49.437304213643074, 46.63809321820736, 46.434522941708565, 46.23205840587616, 47.49803267419338, 48.315824791789055, 53.48648473620415, 54.70559611916542, 58.98804612457752, 62.97722406685352, 57.95583911240101, 58.66413250565529, 60.348973497748375, 55.96418738365173, 59.14094232022762, 54.45201672613621, 58.07634964585304, 55.36153592169285, 55.23977905511856, 55.464290007948875, 55.667332112789154, 53.12788277864456, 50.97642682492733, 47.378008514642715, 44.09182325005531, 46.80023431777954, 49.472805708646774, 47.45123438537121, 41.80655747652054, 40.91010197997093, 47.261119186878204, 46.998066902160645, 47.87569060921669, 46.12801618874073, 50.02883367240429, 49.09091480076313, 50.54067000746727, 57.75879688560963, 64.4630317389965, 64.31823670864105, 63.638183400034904, 56.551932245492935, 70.99023029208183, 68.18411126732826, 58.08678388595581, 59.64438870549202, 64.30436745285988, 65.71564212441444, 67.48079940676689, 71.43166020512581, 72.40398243069649, 69.98915120959282, 71.7802307009697, 67.7477578818798, 73.5012799501419, 69.66046884655952, 77.4134512245655, 70.39905041456223, 79.89970341324806, 73.38702008128166, 83.22909235954285, 72.03009009361267, 83.09512674808502, 73.85684207081795, 85.81622913479805, 73.10076624155045, 100.07573157548904, 24.082921519875526, 0.9978033020161092, 0.3306514292489737, 17.734598368406296, 100.96559062600136, 63.71490128338337, 75.89410275220871, 46.96097329258919, 51.396494284272194, 83.99304896593094, 49.2986686527729, 0.24130774370860308, 0.40303285466507077, 0.15553415956674144, 0.2306732870056294, 0.2069331257371232, 0.18498960009310395, 0.22807673492934555], [0.08935718520660885, 0.10251866217004135, 0.010293360064679291, 0.04590810865920503, 0.03400750349101145, 0.05715198363759555, 0.04068058369739447, 0.2613798400852829, 2.7085509477183223, 57.51458398997784, 44.79013837873936, 49.159649312496185, 38.78207176923752, 52.161598429083824, 61.87944017350674, 62.152960896492004, 0.4698954621562734, 1.0802499717101455, 0.07155278784921393, 20.162223502993584, 80.17901882529259, 70.08364453911781, 72.2736494243145, 69.77172687649727, 66.54274374246597, 56.86171442270279, 60.86775206029415, 68.54823052883148, 69.78245750069618, 68.01996767520905, 65.86596205830574, 67.47706800699234, 66.41487300395966, 69.35786828398705, 72.35927402973175, 84.03239205479622, 37.67313167452812, 48.480143174529076, 68.93577173352242, 62.851564809679985, 62.00994037091732, 57.37248681485653, 54.557704254984856, 54.22136150300503, 55.98252519965172, 52.576251178979874, 50.09067915380001, 44.47605103254318, 43.714370504021645, 44.43072706460953, 46.709065809845924, 44.899906888604164, 44.90492261946201, 41.37580879032612, 42.81183913350105, 41.028906404972076, 41.504390090703964, 38.09482544660568, 40.17088584601879, 41.33070521056652, 43.08634400367737, 43.435112088918686, 41.919909194111824, 40.55837005376816, 45.17779357731342, 48.038736060261726, 49.2379517108202, 46.61662057042122, 51.10333241522312, 49.7344596683979, 48.29657882452011, 49.27394337952137, 51.856117621064186, 52.62071259319782, 54.51218269765377, 52.04310938715935, 57.44432955980301, 55.94152919948101, 58.331798538565636, 54.47170726954937, 56.93430192768574, 51.97992257773876, 54.11122441291809, 50.130299627780914, 41.085603162646294, 42.298083901405334, 43.42681713402271, 58.5722192376852, 57.137959599494934, 55.647884756326675, 55.71063458919525, 46.48848384618759, 44.60573427379131, 45.9530583769083, 45.33481255173683, 47.85185448825359, 48.40060584247112, 51.49321809411049, 51.19697459042072, 52.08323523402214, 49.33932267129421, 51.214769035577774, 51.36137656867504, 50.23633673787117, 49.41862441599369, 51.276724711060524, 48.98380234837532, 49.65980887413025, 51.6589841991663, 49.47725526988506, 47.70175114274025, 47.50628963112831, 46.88902035355568, 44.157749712467194, 38.16823750734329, 39.27836313843727, 38.14605429768562, 43.5309087485075, 39.33297000825405, 38.199411034584045, 38.50028648972511, 40.60858815908432, 40.24096168577671, 38.86534430086613, 40.15795134007931, 46.2492448836565, 46.34499974548817, 44.95078235864639, 49.35802906751633, 61.44808351993561, 55.93500874936581, 61.82560846209526, 59.31480199098587, 59.883350282907486, 64.76904451847076, 63.16555716097355, 58.348460644483566, 62.342566922307014, 61.05989255011082, 60.61847023665905, 58.370841443538666, 61.111197397112846, 60.58598957955837, 65.31346410512924, 63.414516001939774, 68.33948493003845, 63.680672720074654, 71.4397157728672, 65.34285932779312, 73.83166462182999, 68.81308391690254, 76.43995866179466, 70.02295419573784, 77.22611367702484, 68.10858651995659, 78.44961762428284, 63.672176375985146, 86.82733967900276, 5.678809527307749, 0.13419494993286207, 0.1846503940760158, 19.564352184534073, 77.95964151620865, 54.01649169623852, 47.52572558820248, 40.81595443189144, 51.211014837026596, 57.42560796439648, 45.75534738600254, 0.03659206617157906, 0.0924320514604915, 0.09853801209828816, 0.02310487729118904, 0.013511856013792567, 0.058463050590944476, 0.07106417266186327, 0.06566846219357103, 0.08570198915549554, 0.01875144644145621, 0.04968697248841636, 0.03171896867570467, 0.10009856312535703, 0.111724425223656, 0.344661099370569, 4.4905434641987085, 68.88670116662979, 49.18789699673653, 46.061949133872986, 44.46062006056309, 62.19109185039997, 67.737468034029, 69.83358755707741, 0.583487784024328, 1.2516154325567186, 0.07180337401223369, 25.230955816805363, 84.5809306204319, 73.6877891421318, 75.11865556240082, 72.00041368603706, 69.1821201145649, 60.61658553779125, 64.94841009378433, 72.36494332551956, 70.86476102471352, 70.2741739153862, 69.5813874900341, 69.45372194051743, 68.09589520096779, 70.29648631811142, 68.54201406240463, 83.8654214143753, 45.84940753877163, 49.55581985414028, 71.71919837594032, 66.25467360019684, 65.16227021813393, 61.219586580991745, 57.55896180868149, 55.203946977853775, 56.3761992752552, 53.56066435575485, 52.80568286776543, 47.70717725157738, 46.232328191399574, 48.23498032987118, 49.7050454467535, 47.64555595815182, 47.23860539495945, 44.05379869043827, 48.26153710484505, 43.44707764685154, 44.350813552737236, 41.27811223268509, 42.88011386990547, 42.71604627370834, 45.194216296076775, 45.33837676048279, 43.877795934677124, 43.37214566767216, 48.463488668203354, 49.35015209019184, 52.00242877006531, 49.77734796702862, 53.125253319740295, 53.03973510861397, 51.30779564380646, 53.69098596274853, 54.930483251810074, 56.416059136390686, 56.479325741529465, 54.114750623703, 59.55838792026043, 57.82539211213589, 58.67858313024044, 57.566933780908585, 58.241321593523026, 54.26776081323624, 54.36761565506458, 52.74427056312561, 43.30055370926857, 41.79860070347786, 45.21410822868347, 58.4856066852808, 57.61835642158985, 58.81239674985409, 57.796012088656425, 47.69294321537018, 45.484991893172264, 45.76580822467804, 47.31286101043224, 48.472706973552704, 51.41786813735962, 53.15112233161926, 53.07590536773205, 55.50782047212124, 51.471604853868484, 55.58746799826622, 55.72499781847, 53.98657210171223, 51.927865371108055, 53.416165709495544, 52.45429292321205, 51.58604331314564, 52.9690171033144, 51.072808653116226, 51.05013906955719, 50.91164030134678, 48.37924338877201, 47.73709684610367, 40.98826378583908, 40.20095743238926, 40.7565788179636, 45.524825155735016, 40.663198828697205, 39.95436206459999, 40.085933804512024, 42.36786335706711, 42.93435215950012, 42.65078857541084, 43.327509462833405, 47.335329204797745, 48.35959084331989, 48.19015793502331, 51.986142843961716, 60.82836717367172, 58.88858266174793, 62.31466501951218, 61.94904863834381, 61.46314211189747, 61.5586955845356, 64.75182384252548, 59.062978103756905, 64.7467777132988, 63.47594350576401, 63.99847626686096, 60.8149728924036, 64.33627814054489, 63.981012403964996, 68.61229509115219, 65.04146710038185, 71.45188271999359, 65.88194400072098, 73.65199506282806, 68.6983148753643, 77.50230565667152, 70.7546429336071, 79.42361935973167, 73.80727753043175, 81.08017846941948, 69.67504486441612, 81.10363081097603, 69.45784091949463, 90.87025433778763, 5.46749621629715, 0.3265127685153857, 0.2838300744770095, 22.253800369799137, 87.72666022181511, 60.51843300461769, 57.877107337117195, 45.89504688978195, 60.0248508900404, 64.09880608320236, 59.06090721487999, 0.0566759144567186, 0.05500454964931123, 0.03717515675816685, 0.017726852202031296, 0.01578188908752054, 0.0566828201408498, 0.019759427705139387, 0.3401283879065886, 0.20570556895108894, 0.10138353245565668, 0.12817994691431522, 0.24492866738000885, 0.1972872542683035, 0.2031154141877778, 0.5629286903422326, 6.574723552912474, 82.54709735512733, 56.35325230658054, 61.51431016623974, 54.74393606185913, 69.13662135601044, 73.65404695272446, 76.2617938220501, 1.027984251268208, 2.473926362581551, 0.12808797997422516, 26.746975667774677, 86.4239913225174, 75.43726846575737, 77.3472511768341, 76.97415679693222, 72.67221763730049, 63.16125579178333, 68.23185950517654, 74.67467978596687, 75.60258999466896, 75.97843542695045, 72.78251051902771, 73.53468015789986, 70.63444778323174, 73.82819160819054, 66.07202500104904, 84.38998326659203, 55.21882697939873, 53.819730654358864, 74.00224506855011, 68.94761949777603, 68.81113842129707, 64.53186124563217, 61.621677204966545, 58.340226486325264, 62.232771813869476, 57.79266446828842, 56.817146614193916, 49.830879494547844, 48.38547125458717, 52.45080851018429, 52.365130707621574, 49.94061380624771, 49.25137639045715, 47.56273940205574, 50.86445063352585, 46.021713092923164, 46.11348196864128, 44.231344163417816, 45.03786988556385, 46.57697729766369, 47.596546187996864, 49.77227903902531, 47.60304003953934, 44.339999333024025, 51.50541543960571, 54.68654774129391, 55.77083095908165, 52.11897611618042, 56.54186278581619, 56.23679995536804, 54.42973092198372, 56.94020301103592, 60.08465588092804, 61.93064622581005, 61.37716792523861, 58.07394437491894, 62.71270126104355, 60.92553175985813, 61.937390863895416, 61.2366096675396, 62.272464483976364, 57.466208785772324, 56.94967210292816, 52.21811279654503, 43.929427564144135, 41.28591701388359, 47.049964517354965, 62.22187779843807, 61.639676839113235, 59.610315933823586, 59.88905757665634, 49.85512979328632, 46.80349834263325, 46.93409353494644, 47.80090682208538, 49.79201138019562, 54.16064836084843, 55.09440265595913, 55.64368598163128, 59.95667114853859, 55.33046118915081, 59.24812696874142, 59.37114156782627, 58.46935115754604, 53.61478865146637, 56.27606324851513, 55.56771285831928, 55.5801609903574, 57.14568078517914, 55.682854279875755, 56.3423240929842, 55.12968756258488, 52.46207870543003, 49.89127345383167, 44.631641283631325, 42.47668191790581, 43.02695319056511, 48.15179519355297, 42.805641666054726, 42.840018421411514, 42.841792926192284, 47.6637227833271, 45.89727737009525, 45.530543848872185, 45.84807761013508, 50.77284134924412, 50.423837676644325, 50.5256912112236, 53.69037799537182, 65.57847708463669, 62.10294038057327, 66.36476129293442, 61.43316552042961, 68.44901785254478, 68.21580916643143, 63.658652901649475, 62.18883477151394, 64.9150250852108, 66.83022871613503, 65.25119304656982, 62.776351645588875, 65.75469642877579, 64.92569491267204, 70.93750432133675, 68.17225590348244, 74.67643529176712, 67.658911049366, 76.87505051493645, 72.16652557253838, 80.07247254252434, 74.20560255646706, 80.83482563495636, 76.31741523742676, 86.36089950799942, 73.0891540646553, 85.72182700037956, 71.54554769396782, 99.1227351129055, 8.024645950645208, 0.909902440616861, 0.3268282109638676, 24.846452549099922, 98.7652350962162, 64.40166503190994, 70.25369301438332, 58.98074671626091, 68.73013436794281, 72.74743840098381, 68.78490462899208, 0.13385130587266758, 0.22689300938509405, 0.221866725187283, 0.17782631650334224, 0.19356611097464338, 0.21330853051040322, 0.20716862403787673], [0.08340490850969218, 0.07564142782939598, 0.021940892875136342, 0.08261406852398068, 0.04642129264539108, 0.027601930414675735, 0.006906912385602482, 0.16779662109911442, 2.815140215680003, 65.26194646954536, 45.91694511473179, 38.78218196332455, 38.650260642170906, 50.855049937963486, 55.06331652402878, 68.93003404140472, 1.7900023679248989, 0.2895982243353501, 0.04907369504508097, 28.934239000082016, 84.14301931858063, 64.70443278551102, 74.43505704402924, 68.24260532855988, 66.11825332045555, 61.003002002835274, 71.77690207958221, 68.4799861907959, 72.68598809838295, 69.93650123476982, 68.23553770780563, 68.66823568940163, 69.36732977628708, 69.53505277633667, 69.32419449090958, 36.85190074145794, 48.12447085976601, 67.46438428759575, 63.43708299100399, 62.434012815356255, 57.435141652822495, 56.82258032262325, 56.75321124494076, 52.761270850896835, 49.81405019760132, 48.88712793588638, 43.29465642571449, 43.86414706707001, 44.91253741085529, 42.25677631795406, 47.892424911260605, 45.17149731516838, 46.39278598129749, 45.52013620734215, 44.093137979507446, 41.64645306766033, 41.464910209178925, 38.80322523415089, 41.28820449113846, 38.54427672922611, 41.76752597093582, 41.76621124148369, 41.529970318078995, 40.05116946995258, 43.64528261125088, 47.74344630539417, 47.428139224648476, 48.2682703435421, 48.88973079621792, 47.97063231468201, 50.16543634235859, 50.37258602678776, 51.86027839779854, 50.096899420022964, 51.978322863578796, 52.54406310617924, 55.80429956316948, 57.51722104847431, 56.052589640021324, 54.157061353325844, 56.606314927339554, 56.93299859762192, 53.188519924879074, 51.26690223813057, 49.044397696852684, 46.293805092573166, 46.88405781984329, 55.026458501815796, 54.375010058283806, 56.6008660197258, 51.1089713126421, 47.391041815280914, 47.18147926032543, 44.69528026878834, 46.1546565592289, 48.79254721105099, 51.47832289338112, 51.11801102757454, 51.70505292713642, 52.539978325366974, 51.773358061909676, 51.80436819791794, 50.30662156641483, 51.87716469168663, 49.38805125653744, 48.36846336722374, 47.40377873182297, 47.20886059105396, 49.73543241620064, 45.79411670565605, 46.749909818172455, 45.76027952134609, 46.18247486650944, 40.28582587838173, 38.771572932600975, 36.99997879564762, 38.7095944583416, 42.033359706401825, 39.234049916267395, 38.390388786792755, 39.0158998221159, 39.53049100935459, 40.69891311228275, 39.6195088326931, 40.39875201880932, 45.4484910517931, 46.859199553728104, 44.26455058157444, 45.69937638938427, 54.07914653420448, 60.37220545113087, 57.921336963772774, 62.12584935128689, 51.08294650912285, 52.81624250113964, 64.79708701372147, 60.9812405705452, 65.06468385457993, 61.13106653094292, 63.996393978595734, 60.634440779685974, 64.24548581242561, 61.353221610188484, 59.201013296842575, 59.050647765398026, 61.21707871556282, 62.58825033903122, 66.86762630939484, 64.55728948116302, 70.76840579509735, 69.93986025452614, 70.4031465947628, 69.5070406794548, 73.49611222743988, 70.23243695497513, 73.69654387235641, 73.6348731815815, 62.88292832672596, 0.4065759864170104, 0.025906215741997585, 0.6876340205781162, 25.217675529420376, 76.62399798631668, 50.856148079037666, 48.21413844823837, 33.295458778738976, 31.2789810821414, 60.4678463190794, 45.177880972623825, 0.11897828051587567, 0.024675246932019945, 0.02004824189498322, 0.09174957245704718, 0.0675366482755635, 0.0351402917294763, 0.08039112843107432, 0.031194207185762934, 0.04411909860209562, 0.024367721343878657, 0.14754531090147793, 0.03744152840226889, 0.019104666062048636, 0.03101576519839, 0.28565056272782385, 3.8057988323271275, 77.93949499726295, 49.5181068778038, 40.245415046811104, 47.29262329638004, 55.68073399364948, 61.14512577652931, 76.21007099747658, 1.9084955658763647, 0.30354119022376835, 0.00858208904901403, 31.412201933562756, 87.39973336458206, 67.9190830886364, 75.99659085273743, 71.97915762662888, 71.05985015630722, 63.87155547738075, 73.70248675346375, 73.80085587501526, 74.75643619894981, 71.52171537280083, 70.99801987409592, 67.49982118606567, 70.80151721835136, 68.78339231014252, 68.26272144913673, 44.50554504990578, 49.66814182698727, 68.33123937249184, 66.62718281149864, 65.35491228103638, 59.87008899450302, 58.029247373342514, 58.55836898088455, 56.30325458943844, 53.54622133076191, 51.85096129775047, 46.44791342318058, 46.858325600624084, 48.033496141433716, 47.77052745223045, 49.325613006949425, 49.20089989900589, 49.18137274682522, 47.86022163927555, 45.71141414344311, 43.69428098201752, 43.61028648912907, 42.0868456363678, 43.949460089206696, 42.59905055165291, 44.328706339001656, 44.33823622763157, 44.83953192830086, 43.030449002981186, 44.58555355668068, 51.5521415323019, 51.19681879878044, 51.20382182300091, 51.99074059724808, 52.425748854875565, 52.013839557766914, 54.50836390256882, 54.8860864341259, 53.946970626711845, 57.009830474853516, 55.933310240507126, 57.67505697906017, 59.408379569649696, 58.96517135202885, 56.91105857491493, 56.37795478105545, 57.689963579177856, 56.80832728743553, 50.870382115244865, 48.941598013043404, 46.0150520503521, 46.09970770776272, 56.57064624130726, 55.41101686656475, 57.88550108671188, 52.03506901860237, 49.26783710718155, 47.540989369153976, 44.71552178263664, 44.83620710670948, 49.444611221551895, 54.19307582080364, 53.50371681153774, 53.0569975823164, 54.437976479530334, 53.378597125411034, 54.39500078558922, 54.54465575516224, 53.39183181524277, 53.93576882779598, 50.913061425089836, 49.0019615739584, 48.83214108645916, 50.26089482009411, 50.04511199891567, 51.64773680269718, 49.515074640512466, 49.28023964166641, 42.29809910058975, 40.17220817506313, 39.684409350156784, 41.87677390873432, 43.96741032600403, 41.544135957956314, 41.37177720665932, 40.16155354678631, 41.7723935097456, 43.47089096903801, 40.133784636855125, 43.13068002462387, 47.55170859396458, 48.64881992340088, 46.685757860541344, 48.522788286209106, 55.67028075456619, 62.94451542198658, 61.64658486843109, 65.02184495329857, 54.316876977682114, 51.83723263442516, 66.3709169626236, 63.46612483263016, 67.9831400513649, 61.57761476933956, 65.65938234329224, 64.09322038292885, 66.89909622073174, 64.5625863969326, 62.1835682541132, 60.788340121507645, 63.1352423876524, 62.674657702445984, 68.89527350664139, 67.21005633473396, 72.80603125691414, 72.3486877977848, 73.4282174706459, 71.39221832156181, 75.76573044061661, 73.17449748516083, 77.52655595541, 79.64235842227936, 63.96888345479965, 0.5871032306458801, 0.6514728453475982, 0.5764529958833009, 28.41802340000868, 84.06782135367393, 58.35162967443466, 56.774904280900955, 41.580769792199135, 40.87260939180851, 69.67872306704521, 50.59118069708347, 0.16416330356150866, 0.03523311956087127, 0.05340739960956853, 0.06901465763803571, 0.04217096466163639, 0.013213358652137686, 0.06366314948536456, 0.1647632260574028, 0.25598294218070805, 0.23093137628166005, 0.1989313488593325, 0.1598234020639211, 0.1326887315372005, 0.2437786798691377, 0.5792507738806307, 5.852799341082573, 94.20782804489136, 55.69358490407467, 51.59435346722603, 49.927496910095215, 66.13513201475143, 67.6377385854721, 84.48833718895912, 2.2719068778678775, 0.9829335717950016, 0.07843720944947563, 33.515504971146584, 88.07013139128685, 72.54378452897072, 80.17214879393578, 75.24876058101654, 74.31892767548561, 65.71527734398842, 76.61851108074188, 75.04272043704987, 76.67386651039124, 74.2366848886013, 72.05049499869347, 70.34636244177818, 73.56067076325417, 70.77360391616821, 74.56420451402664, 55.48010855913162, 53.89588236808777, 72.33401298522949, 68.00021633505821, 68.09464886784554, 62.86329858005047, 62.836711406707764, 61.66640840470791, 59.06470701098442, 55.43251231312752, 56.41385145485401, 49.4153717905283, 50.57788521051407, 50.283754393458366, 49.459711611270905, 52.42576405405998, 51.219606176018715, 51.522506922483444, 51.494449228048325, 48.134768307209015, 46.71137608587742, 46.81669883430004, 46.490106359124184, 46.64411589503288, 45.10901726782322, 46.38504579663277, 49.208073914051056, 46.05111211538315, 45.21097719669342, 48.99417579174042, 54.25756976008415, 53.72048377990723, 54.354377165436745, 54.24367010593414, 54.58580754697323, 55.42603366076946, 58.01370620727539, 58.4218955039978, 58.812324553728104, 60.315238907933235, 58.82529705762863, 63.392598778009415, 63.415579944849014, 60.16455039381981, 59.0802101790905, 61.277100294828415, 59.476988688111305, 57.16499514877796, 51.97239898145199, 51.786117777228355, 47.17516019940376, 47.5845692306757, 60.94973266124725, 58.59113462269306, 62.59584233164787, 52.55113072693348, 50.134733989834785, 49.639232978224754, 46.98859021067619, 47.103241458535194, 51.58504016697407, 57.42999292910099, 54.82221946120262, 55.30977509915829, 57.93253876268864, 54.36274811625481, 56.916480883955956, 56.885831728577614, 58.26915889978409, 56.746683195233345, 55.76890826225281, 52.1639771014452, 52.99785375595093, 55.65434440970421, 52.713986188173294, 54.55275312066078, 50.875200256705284, 53.30606661736965, 47.09906168282032, 43.70041385293007, 42.345600351691246, 43.16325947642326, 46.866704151034355, 43.293638080358505, 44.42433200776577, 44.93651792407036, 44.905944764614105, 45.1842076331377, 45.029453337192535, 45.866141840815544, 50.253071039915085, 51.00806012749672, 50.04374407231808, 51.063168570399284, 59.47222374379635, 65.91253995895386, 63.42283375561237, 65.89582085609436, 58.920003175735474, 61.035931035876274, 66.95734709501266, 65.21125718951225, 69.86277759075165, 65.85356712341309, 68.79346936941147, 65.88999956846237, 68.91437888145447, 67.24417090415955, 62.45915226638317, 63.23006629943848, 63.736875504255295, 66.53546333312988, 71.74656450748444, 69.5373098552227, 75.47895982861519, 74.66400235891342, 75.29821872711182, 75.32217264175415, 80.19854977726936, 77.11256816983223, 82.50029146671295, 81.59445807337761, 74.94877427816391, 1.2898444687016308, 1.5953381010331213, 0.993454079143703, 30.96702542155981, 97.62580543756485, 62.83375896513462, 67.82870873808861, 49.33695539832115, 45.249484330415726, 81.15887224674225, 65.95268860459328, 0.3726518520852551, 0.08769231790211052, 0.1759101654170081, 0.16258720454061404, 0.13928280270192772, 0.08839956237352453, 0.1522422893322073], [0.03371971346496139, 0.029363618305069394, 0.0031895229676592862, 0.03160288935760036, 0.02403378086455632, 0.050434623190085404, 0.11163997623953037, 0.21364794432884082, 2.4394216015934944, 58.421648517251015, 54.01394583284855, 40.94092972576618, 25.526374764740467, 54.576672837138176, 48.51375997066498, 77.65973880887032, 4.254582300782204, 0.23286394367460161, 0.17156658286694437, 26.53622567653656, 82.42944046854973, 66.96288719773293, 74.43138644099236, 66.54813185334206, 67.60749980807304, 69.2896543443203, 71.54183149337769, 69.32561561465263, 64.26817059516907, 60.911255925893784, 66.65854632854462, 65.51720157265663, 68.07340040802956, 58.79176005721092, 37.80227914452553, 54.035756662487984, 65.70114970207214, 62.353715524077415, 63.92743527889252, 59.1671647131443, 57.73828938603401, 57.330575063824654, 54.50458690524101, 52.45583564043045, 49.140783324837685, 46.71382695436478, 42.58528009057045, 42.595094963908195, 43.156469240784645, 45.64869470894337, 45.362771451473236, 45.24622790515423, 46.03408522903919, 44.339862540364265, 42.987298518419266, 42.631709799170494, 43.341735899448395, 39.032618924975395, 40.290188044309616, 39.15703184902668, 41.41946464776993, 40.836503729224205, 42.081852704286575, 42.74081714451313, 39.84656944870949, 43.50553371012211, 44.52208936214447, 46.90752916038036, 49.13558140397072, 47.985782101750374, 47.062758430838585, 51.1306681483984, 51.22723996639252, 52.78579853475094, 52.205641865730286, 52.84078538417816, 54.270048290491104, 55.46166434884071, 55.07719337940216, 55.005251839756966, 55.728600025177, 51.39165334403515, 52.20237024128437, 50.64114801585674, 46.09446778893471, 45.120762437582016, 44.153258353471756, 56.17876946926117, 45.58335341513157, 42.011020705103874, 52.23033294081688, 45.90727083384991, 50.53147450089455, 45.164220705628395, 46.365020871162415, 51.11439362168312, 54.26642708480358, 52.9455229640007, 53.10513339936733, 55.57513006031513, 55.77380619943142, 54.64279688894749, 51.416029036045074, 51.81060366332531, 52.513242959976196, 48.30251030623913, 47.58284792304039, 46.55996561050415, 45.913323909044266, 47.714111879467964, 46.94801978766918, 46.51143841445446, 41.87946796417236, 39.25761245191097, 35.45135289430618, 38.21745626628399, 39.812523275613785, 38.90379063785076, 38.106300830841064, 38.97855542600155, 37.26507917046547, 38.65997292101383, 41.34283795952797, 40.82879014313221, 43.702412545681, 44.79476273059845, 45.780707225203514, 44.247215911746025, 43.358808383345604, 48.793626353144646, 54.682652950286865, 59.42375734448433, 61.141356378793716, 57.68994078040123, 44.36845600605011, 58.657380267977715, 60.07185056805611, 61.8039458245039, 61.74602173268795, 61.92523151636124, 62.72368647158146, 64.0287834405899, 64.30143401026726, 65.92712357640266, 63.39436188340187, 63.79500478506088, 59.65938650071621, 60.66698983311653, 64.52087983489037, 61.96427442133427, 68.42594549059868, 68.14514055848122, 70.15715539455414, 68.05348187685013, 72.073764950037, 68.5240638256073, 70.56257084012032, 25.65217651426792, 0.8109740959480405, 0.5058213765732944, 0.23817721637897193, 30.49549162387848, 74.17092561721802, 47.43564382195473, 44.08342570066452, 30.318360328674316, 45.183557868003845, 58.09341073036194, 33.86344850063324, 0.39387148688547313, 0.0781472671951633, 0.07271226000739262, 0.004197067755740136, 0.041270802612416446, 0.04342355779954232, 0.056920697024906985, 0.07687956021982245, 0.01951563961483771, 0.029632793412019964, 0.04449542684596963, 0.06553857150720432, 0.0610764939483488, 0.04146924919041339, 0.21018425206420943, 3.430589153431356, 71.77627891302109, 57.70296648144722, 44.5702213793993, 32.39746056497097, 63.17138224840164, 50.95417521893978, 88.53463366627693, 4.8656731098890305, 0.3204868856118992, 0.03349038612213917, 26.530482284724712, 85.92985063791275, 71.09657898545265, 75.5871020257473, 69.60965037345886, 70.17086505889893, 70.40834471583366, 74.45948973298073, 70.54702967405319, 65.79772531986237, 61.35608285665512, 67.62782111763954, 66.516692340374, 70.75014397501945, 59.81743901968002, 44.48419399559498, 56.71617463231087, 68.27738106250763, 64.70199331641197, 66.97669565677643, 60.99272355437279, 60.140167102217674, 58.53833265602589, 56.562111899256706, 54.09625701606274, 51.86738781630993, 48.33324305713177, 46.76742307841778, 45.41969619691372, 45.63209339976311, 47.25341700017452, 47.7306067943573, 48.02661471068859, 49.722592905163765, 46.093016266822815, 47.11749069392681, 45.70956364274025, 45.53472742438316, 41.869846880435944, 43.669643104076385, 41.450144201517105, 43.794884383678436, 44.21098105609417, 42.99390636384487, 45.65940633416176, 44.69364255666733, 44.328808933496475, 48.15886281430721, 49.562374502420425, 49.87726740539074, 49.70636397600174, 50.028966665267944, 56.23411349952221, 52.919543758034706, 55.938094183802605, 55.56679330766201, 55.82257278263569, 57.36832223832607, 57.731320559978485, 56.50528594851494, 56.526120230555534, 55.067044124007225, 55.68001963198185, 54.52297791838646, 52.1843858063221, 46.908748894929886, 47.88140930235386, 46.52556225657463, 58.31259436905384, 49.47245992720127, 47.040472626686096, 52.758930176496506, 47.230960205197334, 49.218895733356476, 44.461706802248955, 46.98442943394184, 52.432702481746674, 55.40295749902725, 55.21569214761257, 57.22144491970539, 55.785061195492744, 57.646417915821075, 56.85207813978195, 55.24990551173687, 53.64456005394459, 54.558148831129074, 51.01903013885021, 50.74077486991882, 51.85979962348938, 50.39266034960747, 49.496277049183846, 51.27544417977333, 49.55534867942333, 45.48409514129162, 41.49314269423485, 38.603884130716324, 40.25594048202038, 40.912283062934875, 40.459229573607445, 40.36061346530914, 40.60924932360649, 40.14281675219536, 41.74009904265404, 43.16271610558033, 42.19551980495453, 45.73328197002411, 48.38189944624901, 46.1616899818182, 46.58948242664337, 46.224842593073845, 50.331567227840424, 59.127764627337456, 61.633106991648674, 64.72458690404892, 61.41436032950878, 48.14397521317005, 59.417134299874306, 63.000421822071075, 63.81423935294151, 63.766726702451706, 62.839234471321106, 65.97014486789703, 67.41036638617516, 66.79525539278984, 69.49250265955925, 67.56987422704697, 66.48424968123436, 64.18163403868675, 62.58571967482567, 66.94916233420372, 65.39505332708359, 72.7092656493187, 71.10155671834946, 73.37802216410637, 71.64110496640205, 75.5261380970478, 70.7871387898922, 75.64149990677834, 24.15986929088831, 0.7871768635232002, 0.37255480885505676, 0.18213481031125411, 35.21279029548168, 82.8316792845726, 52.95565702021122, 54.65448126196861, 35.215647742152214, 44.6198733150959, 70.36856845021248, 45.29118709266186, 0.4756734083639458, 0.014501268742606044, 0.06477857517893426, 0.05508605972863734, 0.05183246947126463, 0.0332055646867957, 0.013815124457323691, 0.1047073892550543, 0.11493025827803649, 0.0651341158663854, 0.12930026336107403, 0.20345295779407024, 0.1692521953373216, 0.29675641679205, 0.563048324547708, 5.629300558939576, 82.02564373612404, 67.1796427667141, 54.43750910460949, 34.37924042344093, 75.39267405867577, 59.57317292690277, 97.22288265824318, 5.491108624264598, 0.8120462915394455, 0.22727376082912087, 29.863807819783688, 90.0595374405384, 73.09759721159935, 80.5600243806839, 72.41629377007484, 72.50779286026955, 74.23235312104225, 78.1090646982193, 75.36735981702805, 70.20563319325447, 64.41505551338196, 70.23237615823746, 70.05687117576599, 73.57805863022804, 66.34701624512672, 50.522598177194595, 58.71530815958977, 70.4970395565033, 65.93803659081459, 71.00408434867859, 63.17154183983803, 62.03411467373371, 61.29670724272728, 59.12342146039009, 59.45084989070892, 56.60922937095165, 53.044363260269165, 49.49158430099487, 48.20542171597481, 47.18864947557449, 49.57218177616596, 51.55190974473953, 50.14034628868103, 52.725203186273575, 48.275976330041885, 49.01130527257919, 48.708396926522255, 50.16060680150986, 44.5463814586401, 45.194106101989746, 44.49839003384113, 46.361848041415215, 46.55183024704456, 46.26941420137882, 48.8560152053833, 44.94524985551834, 48.466995880007744, 51.33864238858223, 52.79429107904434, 52.26158246397972, 52.94815242290497, 53.594737127423286, 60.11997498571873, 55.84889397025108, 59.12320487201214, 59.65352721512318, 58.49370785057545, 59.61205244064331, 60.484375432133675, 60.13073980808258, 60.36604218184948, 58.20059537887573, 56.11027054488659, 59.269778206944466, 54.111931174993515, 47.53417253494263, 47.88239344954491, 46.90914787352085, 60.293192490935326, 54.24880363047123, 51.43689751625061, 55.87392322719097, 49.50788922607899, 53.402668833732605, 46.61559462547302, 48.5409627109766, 55.42665682733059, 57.87281736731529, 59.47529777884483, 59.63101342320442, 59.937003403902054, 59.45963501930237, 60.94696260988712, 58.49247291684151, 58.49765203893185, 58.8891564309597, 55.72507381439209, 53.91035579144955, 55.01863852143288, 52.28544898331165, 54.02594178915024, 52.72752106189728, 51.03405073285103, 46.932398825883865, 44.25627462565899, 39.68608886003494, 43.46657060086727, 44.252087250351906, 42.54864625632763, 42.51093327999115, 43.90762813389301, 41.78445786237717, 43.54649931192398, 45.601915419101715, 45.192783772945404, 48.6171980202198, 50.8479443192482, 49.1900172829628, 48.21299850940704, 47.157958522439, 54.12450470030308, 60.426534935832024, 64.61624711751938, 66.36625841259956, 63.6570455878973, 51.927306801080704, 63.16675029695034, 65.90257689356804, 66.07844665646553, 65.31864702701569, 66.82441502809525, 68.75818446278572, 70.12123212218285, 69.17531087994576, 71.28146186470985, 70.83603456616402, 70.2568544447422, 64.09413233399391, 64.65806767344475, 67.77685672044754, 67.20642372965813, 74.31632101535797, 73.55985760688782, 75.68272769451141, 74.90439265966415, 78.35016176104546, 74.7156871855259, 79.21822518110275, 32.159760519862175, 1.0359932715073228, 1.2279115919955075, 0.22659543785266578, 39.61252100765705, 92.73286879062653, 61.243992671370506, 63.98334547877312, 46.36932983994484, 63.71322937309742, 77.18831330537796, 56.46631523966789, 0.5573232192546129, 0.21064775297418237, 0.2744130516657606, 0.13283061533002183, 0.25027469848282635, 0.1888839012826793, 0.09915684451698326], [0.03595870621211361, 0.018880613533838186, 0.08964547247160226, 0.07009338412899524, 0.03710958430019673, 0.0223967533747782, 0.11530513191246428, 0.05077492016425822, 1.1248037684708834, 53.63941133022308, 54.099308252334595, 46.86036989092827, 30.77861063182354, 54.60375778377056, 51.894438564777374, 81.3011822104454, 10.864956490695477, 0.8381373540032655, 0.19620621227659285, 17.603248916566372, 80.06177991628647, 68.38656440377235, 72.39252984523773, 67.74781867861748, 70.2559120953083, 66.25596553087234, 71.35897010564804, 56.69887036085129, 62.425326481461525, 66.78777739405632, 68.59211817383766, 63.97464394569397, 66.09933793544769, 55.15907898545265, 63.98454621434212, 63.33532825112343, 62.95105867087841, 63.88533353805542, 60.431030094623566, 58.96474577486515, 57.299447134137154, 53.967850506305695, 52.16348312795162, 46.84953287243843, 47.025387436151505, 43.58537882566452, 44.24228757619858, 43.70623134076595, 43.788675516843796, 45.78853100538254, 44.58329267799854, 45.21333687007427, 46.74622781574726, 46.702119782567024, 44.784503281116486, 42.564111426472664, 42.190268486738205, 40.09787276387215, 40.48470340669155, 38.991843312978745, 40.37749595940113, 40.71286216378212, 41.38275861740112, 41.93047262728214, 41.090637892484665, 39.55980263650417, 41.27945736050606, 42.25767306983471, 43.83835405111313, 45.36906771361828, 47.461505234241486, 46.26606658101082, 48.3053145557642, 47.06934727728367, 48.964263796806335, 51.78123123943806, 52.71893352270126, 50.83476282656193, 52.709791213274, 53.535471707582474, 51.57832592725754, 52.81137876212597, 55.57015232741833, 52.811572551727295, 52.19263896346092, 51.44303418695927, 48.747705817222595, 46.589262038469315, 33.31418417394161, 30.17312452197075, 45.78536957502365, 47.505495473742485, 53.14802549779415, 48.918350860476494, 49.79587197303772, 53.055895641446114, 52.976764887571335, 53.50057438015938, 53.33067029714584, 51.858990266919136, 54.01708826422691, 51.14127717912197, 52.9622458666563, 49.99815411865711, 49.682410061359406, 47.198186963796616, 48.219294771552086, 45.41272357106209, 44.35407757759094, 46.301925256848335, 46.21090114116669, 40.86787484586239, 39.216350466012955, 36.970887556672096, 37.85985365509987, 38.22755992412567, 39.19648513197899, 39.229478761553764, 37.24494785070419, 38.4048356115818, 41.06714755296707, 41.12978719174862, 41.57746396958828, 41.90953195095062, 42.96738378703594, 46.48517422378063, 44.163521602749825, 44.607869759202, 44.117251485586166, 45.34165978431702, 49.326015785336494, 56.51110343635082, 56.47361844778061, 62.75904357433319, 59.01433311402798, 57.667100206017494, 56.918350383639336, 58.5148499161005, 59.40807558596134, 58.62377107143402, 62.835126891732216, 63.38095620274544, 64.79577228426933, 64.35462355613708, 64.32389840483665, 65.40118619799614, 68.23100075125694, 65.33328384160995, 66.8156298995018, 67.6722939312458, 69.75235551595688, 70.30686736106873, 67.79868274927139, 67.61895999312401, 72.31670871376991, 65.75740188360214, 58.2021988928318, 5.708369566127658, 0.4710145021090284, 0.4010711802402511, 0.09536269615637138, 35.718592554330826, 67.64769405126572, 55.29945105314255, 48.64697702229023, 38.14285486936569, 45.015124306082726, 57.15433292090893, 46.421504840254784, 0.7353424793109298, 0.05812347721075639, 0.020874443362117745, 0.032869998904061504, 0.04318301289458759, 0.07597499352414161, 0.05205059038416948, 0.01927476445416687, 0.032485403135069646, 0.01641532882786123, 0.03819262266915757, 0.05312946901540272, 0.07890558626968414, 0.030173511077009607, 0.04394887961097993, 1.2453615618869662, 62.95810729265213, 58.33943612873554, 50.83974815905094, 34.85214784741402, 65.38867726922035, 56.551134288311005, 88.29855993390083, 11.595377996563911, 1.0359546798281372, 0.10643025540048257, 16.876537911593914, 84.15296718478203, 70.53373798727989, 76.37059718370438, 69.38984736800194, 73.93340036273003, 69.49721440672874, 74.35329303145409, 61.86891853809357, 65.76953083276749, 69.07647058367729, 70.06286725401878, 67.54498556256294, 67.63219848275185, 57.684921249747276, 65.92077791690826, 66.79712489247322, 63.49690318107605, 65.25804787874222, 64.12153646349907, 62.03325591981411, 59.97107617557049, 58.58341343700886, 55.239912047982216, 49.579112604260445, 48.98337297141552, 48.481283113360405, 47.360841035842896, 47.29019142687321, 46.623452603816986, 47.49445326626301, 47.57005400955677, 46.37594148516655, 48.186365738511086, 47.97419652342796, 47.87536382675171, 45.05850277841091, 45.56591995060444, 44.35358740389347, 42.68687903881073, 43.240969106554985, 43.88251528143883, 41.558430790901184, 44.27171319723129, 44.51275706291199, 42.13713213801384, 42.89013393223286, 43.93762372434139, 44.24809746444225, 48.96851196885109, 47.64793083071709, 49.44827042520046, 50.21519847214222, 51.796666011214256, 51.70744299888611, 53.40659782290459, 53.01966838538647, 55.76359614729881, 54.96946915984154, 53.74921403825283, 57.20797084271908, 53.08739215135574, 53.75353820621967, 55.91873802244663, 54.42358285188675, 53.55393871665001, 54.234463199973106, 50.42600356042385, 48.99984888732433, 36.739441975951195, 35.91858722269535, 50.02830930054188, 46.642060205340385, 55.65226972103119, 50.05475588142872, 51.12468346953392, 54.61284689605236, 55.44820547103882, 53.9224923402071, 56.030835807323456, 53.414132818579674, 57.15440891683102, 53.373847380280495, 54.56164464354515, 53.47074598073959, 52.85763368010521, 50.08324295282364, 50.4323074221611, 47.212850376963615, 47.303806096315384, 51.35822653770447, 49.10359092056751, 43.99109065532684, 40.860548838973045, 39.489916786551476, 40.778860822319984, 39.95914600789547, 42.7208112180233, 41.33910275995731, 39.95183140039444, 40.75766175985336, 42.23771654069424, 43.60411562025547, 45.18408603966236, 44.23699826002121, 46.90580405294895, 49.48370352387428, 47.29856617748737, 46.56192630529404, 46.681144908070564, 46.594209372997284, 52.60758809745312, 58.83072316646576, 58.443782329559326, 64.61950734257698, 61.43944278359413, 59.844451770186424, 58.94079566001892, 60.81575945019722, 61.935452967882156, 61.66212223470211, 65.68444579839706, 64.37342494726181, 67.08458706736565, 67.16885134577751, 66.21941149234772, 65.420101583004, 69.69409704208374, 68.47915783524513, 70.06692543625832, 69.7825638949871, 72.61973485350609, 73.41674208641052, 70.52520364522934, 68.7706857919693, 77.14263215661049, 68.06205421686172, 62.46487095952034, 5.708130178973079, 0.4718552663689479, 0.15382247016532347, 0.0864238094072789, 41.10066935420036, 78.10424655675888, 61.46861381828785, 58.25934022665024, 43.91497313976288, 50.24110168218613, 67.69554868340492, 58.74812699854374, 1.2726293737068772, 0.12301915587158874, 0.0493898202694254, 0.037940344409435056, 0.045355616821325384, 0.09339004536741413, 0.08080684245214798, 0.15361104713520035, 0.10221232587355189, 0.14114252087892964, 0.21274026803439483, 0.0878551896312274, 0.20414294733200222, 0.29632516962010413, 0.1894584868568927, 2.191510791890323, 77.31163948774338, 64.74287152290344, 60.80154441297054, 39.00101222097874, 77.2831866145134, 62.90375500917435, 97.2486224770546, 12.026968337595463, 1.5649974416010082, 0.38671109767165035, 21.039003655314445, 86.73291474580765, 73.50628808140755, 79.56146076321602, 71.63889348506927, 76.33200645446777, 71.57257184386253, 79.22473803162575, 61.261467933654785, 65.56003287434578, 69.55937147140503, 71.96710467338562, 69.90539610385895, 71.47383034229279, 60.82306265830994, 67.99572497606277, 68.25329795479774, 66.99215322732925, 66.78976088762283, 66.8828634917736, 65.95362335443497, 62.49301604926586, 61.13333500921726, 58.10536488890648, 51.75084426999092, 51.96948453783989, 50.29389224946499, 50.88753819465637, 50.42387567460537, 46.96916565299034, 51.436190754175186, 49.93187427520752, 49.16162520647049, 50.513946041464806, 51.254465505480766, 49.83716055750847, 46.90569005906582, 48.99910032749176, 47.503496780991554, 45.92596963047981, 44.63915728032589, 45.14907471835613, 44.318948462605476, 46.69624909758568, 47.27774329483509, 45.595364570617676, 45.279042944312096, 47.010492235422134, 47.10535414516926, 51.6601849347353, 50.9891751408577, 54.00255024433136, 51.8789391964674, 54.296665862202644, 53.81460092961788, 54.21345792710781, 56.0828398168087, 56.88971891999245, 57.25175589323044, 55.52495755255222, 60.295628160238266, 55.66350571811199, 56.2243328243494, 59.10343453288078, 56.24024257063866, 57.01574295759201, 56.807745918631554, 52.29636199772358, 53.75991426408291, 43.332912772893906, 43.655492663383484, 52.18209832906723, 47.593399956822395, 54.34414431452751, 53.22677247226238, 53.80405269563198, 60.06810016930103, 56.50718204677105, 57.74493522942066, 57.74409167468548, 56.209817603230476, 59.229200184345245, 56.100508868694305, 56.79412744939327, 56.49073272943497, 56.40853554010391, 53.396049588918686, 53.590739741921425, 50.05209602415562, 49.55103971064091, 51.73646584153175, 53.00072260200977, 45.09800165891647, 43.50611887872219, 42.9744666069746, 43.917541801929474, 43.18937547504902, 43.870310336351395, 44.29291605949402, 42.16383710503578, 43.08239981532097, 46.84246905148029, 46.44919395446777, 46.16844981908798, 47.48009003698826, 49.34345684945583, 52.46598869562149, 49.773194789886475, 50.16653448343277, 48.10516409575939, 49.60881941020489, 54.8329196870327, 62.592722699046135, 60.16312547028065, 67.39037945866585, 63.25885735452175, 63.04573439061642, 61.833356246352196, 64.96268972754478, 64.71194878220558, 63.77856686711311, 68.39403480291367, 68.1861175596714, 70.66815957427025, 70.84105029702187, 69.08710241317749, 70.91289684176445, 70.94290763139725, 72.3321282863617, 73.50320264697075, 72.52394199371338, 75.41378572583199, 77.85820975899696, 75.48241764307022, 74.23658609390259, 81.96403384208679, 72.16479286551476, 69.3808950483799, 9.856648296117783, 0.830617913743481, 0.5578143429011106, 0.13963602046715096, 47.172538340091705, 88.61593410372734, 70.7986369729042, 68.97973537445068, 55.557149425148964, 65.66924661397934, 79.75002944469452, 71.15717053413391, 1.8117446824908257, 0.09520313440589234, 0.1576264965115115, 0.13313072500750422, 0.30448407400399446, 0.16495597665198147, 0.1953045473783277], [0.08839002577587962, 0.041836567761492915, 0.05112679093144834, 0.04228586767567322, 0.08496709226164967, 0.018118802654498722, 0.02405115639703581, 0.026162943177041598, 0.14335461077280343, 42.30849914252758, 51.770287826657295, 40.667769983410835, 33.03255468606949, 51.916975155472755, 44.97259318828583, 79.5581017434597, 18.49313646554947, 0.18184471962740645, 0.6317682901863009, 3.6514107417315245, 73.21522369980812, 70.56283682584763, 72.98713713884354, 69.66132760047913, 71.6522079706192, 71.44371315836906, 72.9697036743164, 70.92816442251205, 74.23584893345833, 64.33392226696014, 65.94416186213493, 61.980978325009346, 60.73992311954498, 62.59173855185509, 61.323587000370026, 59.709384217858315, 61.035357266664505, 57.55728989839554, 60.76329946517944, 57.225332111120224, 55.38418270647526, 48.024251237511635, 47.33456924557686, 43.19162115454674, 46.41383685171604, 43.84549766778946, 43.90648439526558, 43.26032146811485, 44.01078499853611, 43.419863507151604, 44.55938056111336, 46.875827461481094, 49.08521130681038, 46.326912716031075, 45.4976262152195, 41.99761502444744, 43.201694414019585, 39.7581671923399, 41.966893672943115, 39.49221186339855, 40.650036334991455, 41.50895744562149, 40.07020644843578, 41.30280330777168, 41.09650857746601, 42.70496606826782, 43.21693919599056, 42.21533194184303, 44.34329755604267, 44.158977046608925, 46.75639986991882, 44.18667376041412, 47.00973227620125, 44.05977576971054, 46.511373817920685, 49.25087861716747, 51.87738887965679, 49.00228835642338, 52.8228123486042, 49.60702210664749, 51.7464555054903, 51.000183150172234, 52.26458050310612, 55.49824498593807, 55.11863775551319, 48.63405391573906, 51.86760060489178, 37.81914263963699, 16.168119125068188, 18.244853988289833, 36.880410611629486, 51.94825127720833, 51.187482699751854, 51.40669673681259, 52.847134843468666, 53.63957092165947, 52.39622823894024, 52.63841584324837, 53.322413340210915, 51.88380293548107, 53.789700865745544, 51.13587386906147, 50.80521181225777, 47.86144517362118, 50.30637837946415, 48.55808839201927, 46.76839202642441, 46.59365080296993, 41.64614148437977, 43.45490902662277, 39.65653404593468, 40.239764750003815, 37.64178715646267, 38.32230024039745, 38.535446003079414, 41.823755353689194, 40.95530055463314, 38.879380747675896, 38.431111201643944, 40.66374979913235, 37.53590203821659, 41.886330395936966, 43.11883606016636, 41.34966999292374, 43.977012410759926, 44.263285249471664, 44.322695061564445, 44.29245248436928, 44.93964895606041, 43.84661480784416, 45.03458686172962, 50.427945256233215, 54.86552573740482, 57.928636372089386, 58.22725474834442, 60.85187271237373, 60.685232654213905, 58.10132950544357, 56.00467421114445, 56.08814053237438, 53.798987567424774, 57.330962643027306, 58.92845392227173, 61.15788549184799, 61.353077217936516, 63.13175417482853, 62.804367542266846, 62.952168211340904, 65.2100944519043, 64.70050379633904, 63.2391782104969, 65.66119104623795, 63.892439156770706, 65.63915982842445, 68.05890038609505, 71.18037208914757, 44.65251736342907, 0.5617822799831629, 0.23656844801735133, 0.048580211368971504, 0.06733176356647164, 42.11040057241917, 68.21185737848282, 49.36510048806667, 44.849331602454185, 36.41520157456398, 38.04311782121658, 57.79682904481888, 41.42080597579479, 0.32262807071674615, 0.08192569686798379, 0.049650384607957676, 0.0676638820732478, 0.04012824771052692, 0.05464533904159907, 0.03432686447922606, 0.0331119019392645, 0.03888831561198458, 0.04511261169682257, 0.035817672178382054, 0.03525959196849726, 0.07876657458837144, 0.04364474749309011, 0.0369023247185396, 0.09533429416478612, 51.29538170993328, 58.33095498383045, 38.876755088567734, 34.64311346411705, 63.270891308784485, 51.08283631503582, 90.08992820978165, 19.572698436677456, 0.11038095239200629, 0.6999599060509354, 2.91408215649426, 72.45800033211708, 73.65040674805641, 73.45672354102135, 70.98383143544197, 76.32717311382294, 74.01042982935905, 74.71263974905014, 70.38366883993149, 76.84917390346527, 67.79545292258263, 69.82787266373634, 65.16862347722054, 64.99359726905823, 65.67455872893333, 64.3514697253704, 59.807468354701996, 65.53379148244858, 59.92609418928623, 62.063848078250885, 58.633388355374336, 56.66820980608463, 51.12828567624092, 50.94006657600403, 44.89555612206459, 48.183603286743164, 45.710426196455956, 46.302860006690025, 44.927219823002815, 46.94718383252621, 46.88092298805714, 47.48640149831772, 49.26960401237011, 50.4300769418478, 49.618429094552994, 48.50541181862354, 44.511898308992386, 46.201036870479584, 42.74582527577877, 44.33411344885826, 42.22191698849201, 44.419217482209206, 44.88251522183418, 42.35220439732075, 41.48951008915901, 45.141178742051125, 45.691799595952034, 47.23754905164242, 42.738993242383, 47.99181617796421, 46.46631583571434, 48.741470351815224, 46.906989589333534, 49.4689679145813, 47.348791882395744, 49.234778881073, 52.17326760292053, 54.78529304265976, 51.67149692773819, 54.679711908102036, 49.31482158601284, 51.65955796837807, 51.30739286541939, 55.60083948075771, 55.83728179335594, 58.30476678907871, 49.911256581544876, 54.747720658779144, 44.79939468204975, 20.542138516902924, 22.09190435707569, 42.45367795228958, 54.204148426651955, 52.51057170331478, 54.77881819009781, 52.46634967625141, 53.438531309366226, 53.51435624063015, 53.844676315784454, 53.480161875486374, 54.56395871937275, 55.63601419329643, 52.946332320570946, 54.50418412685394, 51.25043012201786, 51.787747889757156, 53.265602588653564, 49.669220969080925, 50.2859278768301, 44.47837270796299, 44.750510305166245, 41.434546038508415, 41.63782373070717, 40.62481328845024, 41.2223844230175, 42.38287255167961, 44.74415324628353, 43.78532789647579, 42.38522082567215, 41.290070191025734, 43.60960252583027, 39.71801094710827, 44.815938994288445, 45.10129988193512, 44.26812618970871, 47.79935650527477, 48.760328739881516, 46.889521926641464, 46.90543167293072, 48.18838343024254, 47.48781502246857, 47.096819803118706, 53.002611100673676, 58.785194009542465, 59.953160136938095, 61.01072698831558, 62.539514154195786, 61.0820871591568, 61.79915048182011, 59.44942116737366, 58.88518184423447, 57.26394943892956, 59.599589109420776, 61.73203848302364, 61.758348271250725, 63.409492671489716, 67.64787644147873, 67.68267497420311, 65.37078022956848, 68.1201682984829, 69.58546847105026, 66.23211801052094, 68.25916483998299, 66.14172086119652, 68.16309079527855, 72.80809834599495, 76.77169606089592, 47.71077945828438, 0.28793242934625596, 0.1809774013236165, 0.008354497404070571, 0.15510974015342072, 48.54879789054394, 78.43513280153275, 57.04110659658909, 56.26375950872898, 41.84911519289017, 46.14658959209919, 66.61201402544975, 48.937243446707726, 0.842291540466249, 0.07892414738307707, 0.04511608123721089, 0.05443699592433404, 0.036818966691498645, 0.05064472519734409, 0.02584216468676459, 0.19471743435133249, 0.13927741470979527, 0.13106379919918254, 0.1592211492243223, 0.1540031682816334, 0.1608416880480945, 0.17926338157849386, 0.09835335091338493, 0.8249250473454595, 66.17243081331253, 65.49570992588997, 52.75163076817989, 41.081590577960014, 74.0758927166462, 53.23377929627895, 100.74191182851791, 20.702875591814518, 0.6219435611274093, 1.2127130012959242, 4.878939623013139, 80.0050413608551, 75.21143898367882, 77.83472701907158, 74.58334028720856, 77.78434932231903, 75.18186897039413, 75.61237066984177, 70.40449932217598, 79.62937831878662, 69.89439949393272, 71.00707858800888, 66.67682334780693, 66.82122319936752, 68.31825166940689, 67.63197049498558, 62.29082129895687, 67.06325501203537, 61.81891322135925, 64.6053797006607, 63.66451978683472, 61.253328770399094, 52.48288258910179, 54.005616679787636, 46.65350519120693, 53.0383063852787, 49.002808928489685, 49.64933283627033, 49.37762841582298, 49.376036301255226, 49.331392496824265, 48.097971081733704, 52.55765877664089, 52.96712100505829, 51.67381480336189, 51.090694293379784, 47.71220438182354, 49.13048207759857, 44.69230882823467, 46.79801523685455, 45.062982738018036, 47.88625784218311, 48.08026023209095, 46.105449199676514, 45.83550788462162, 46.68368697166443, 49.06076341867447, 48.75870622694492, 47.74294093251228, 51.23112715780735, 49.47344407439232, 53.35796423256397, 49.13394369184971, 52.94948995113373, 49.40847136080265, 52.21394442021847, 54.36673790216446, 55.29526747763157, 57.10649348795414, 56.21311202645302, 52.759332954883575, 55.07674120366573, 58.13887149095535, 59.09611612558365, 59.92836646735668, 62.0971342921257, 53.403242602944374, 57.17152699828148, 48.78253474831581, 27.729715034365654, 29.602959416806698, 47.1269977837801, 56.44319348037243, 56.22617192566395, 55.47623656690121, 53.81677061319351, 57.36882761120796, 56.557050570845604, 56.592647060751915, 57.70482838153839, 58.49552035331726, 59.580894112586975, 54.87808786332607, 56.871529296040535, 54.20400783419609, 54.60089273750782, 55.203183218836784, 52.033632695674896, 53.62983964383602, 48.08280989527702, 49.557829946279526, 44.223778769373894, 44.62680034339428, 43.349453285336494, 43.526763170957565, 45.081316754221916, 46.6301516443491, 47.57652506232262, 43.93126666545868, 44.26427699625492, 47.22434476017952, 41.89811736345291, 49.075415432453156, 47.3561254888773, 45.79427249729633, 49.47377845644951, 49.34713125228882, 50.07204495370388, 49.59401920437813, 49.55050393939018, 49.58484269678593, 50.277758315205574, 55.90815179049969, 60.9833874553442, 62.33754359185696, 63.355030193924904, 65.64469993114471, 63.787443190813065, 64.05994176864624, 62.11075276136398, 62.56208874285221, 59.27202768623829, 61.736309453845024, 64.82683181762695, 67.01899498701096, 66.94336384534836, 69.2214024066925, 70.44033899903297, 70.18543347716331, 72.39794075489044, 72.59490698575974, 69.62529793381691, 72.57203981280327, 71.49618074297905, 73.55490267276764, 78.35407555103302, 80.43501108884811, 54.80802722275257, 1.417693595867604, 0.3635438595665619, 0.2489785078796558, 0.39163780049420893, 53.65816332399845, 86.62539571523666, 64.5230533182621, 65.37668511271477, 51.82493269443512, 55.34769706428051, 80.21286740899086, 61.981783881783485, 1.3772647152654827, 0.24152663274435326, 0.24737477127928287, 0.1507430025958456, 0.18082490481901914, 0.09283859995775856, 0.08303904454805888], [0.03172362565237563, 0.005727666630264139, 0.04534740495728329, 0.04879614294623025, 0.07166628449340351, 0.02265852555865422, 0.0074374579889990855, 0.042426708751008846, 0.019921856001019478, 41.29537470638752, 51.555401757359505, 53.955622762441635, 36.38979993760586, 47.479854449629784, 48.680517822504044, 75.49484297633171, 25.414455570280552, 0.17143563833087683, 1.4897002070210874, 0.12385527428705245, 34.493283703923225, 70.85343763232231, 70.7588379085064, 70.73290809988976, 69.11938548088074, 65.8527159690857, 69.61358696222305, 67.42752626538277, 67.36959457397461, 64.98128592967987, 63.52220222353935, 60.304656475782394, 59.769899770617485, 57.94399134814739, 60.19288547337055, 59.50014844536781, 58.466444313526154, 58.80819797515869, 56.94863475859165, 50.49132965505123, 47.88177788257599, 45.423363000154495, 44.463884085416794, 44.058552235364914, 42.517119348049164, 40.89182876050472, 42.76254437863827, 43.63911174237728, 44.03146728873253, 42.959617003798485, 48.22319716215134, 53.19595232605934, 53.116069212555885, 54.38446395099163, 51.16972245275974, 45.11580750346184, 43.763539865612984, 42.11347080767155, 43.00579212605953, 41.471727043390274, 43.566284850239754, 39.93565946817398, 39.284583404660225, 39.54619936645031, 41.59601837396622, 40.51202014088631, 43.93321216106415, 41.51528410613537, 42.54397630691528, 44.24576438963413, 45.98914124071598, 44.96895298361778, 46.19861260056496, 44.860263615846634, 46.621453911066055, 47.10969731211662, 47.3621329665184, 49.53326806426048, 50.11917382478714, 49.94902655482292, 49.05683442950249, 49.31140936911106, 51.79251663386822, 50.596876591444016, 48.395289927721024, 54.52592276036739, 54.628156274557114, 35.614497140049934, 18.636768758296967, 18.487068191170692, 31.141215674579144, 54.131861105561256, 51.711805164813995, 49.1469731926918, 51.8009065836668, 50.76748363673687, 49.94168534874916, 48.87430742383003, 49.83643859624863, 47.94573985040188, 49.29074227809906, 49.08164709806442, 49.15285147726536, 46.59883372485638, 45.98314896225929, 44.88855689764023, 45.11935651302338, 48.03962141275406, 43.88920672237873, 39.64873306453228, 41.3909737765789, 40.06283484399319, 40.08457727730274, 39.2121858894825, 40.72731278836727, 39.37680825591087, 39.82366807758808, 40.33368431031704, 39.88316908478737, 39.59328643977642, 41.62114642560482, 41.17778241634369, 42.92990259826183, 43.91628786921501, 44.51221749186516, 42.532101944088936, 45.215122774243355, 43.387132063508034, 43.67586337029934, 44.66593064367771, 45.53487181663513, 44.99096140265465, 48.7495107203722, 53.60868237912655, 58.10980685055256, 59.7972659021616, 59.727957621216774, 59.81893993914127, 57.91780695319176, 55.43351925909519, 54.91152986884117, 53.938489481806755, 51.80812619626522, 53.42886082828045, 54.55400325357914, 57.22752459347248, 55.32811291515827, 56.59241907298565, 58.536976128816605, 58.5003574937582, 58.370883241295815, 58.4111762791872, 61.60501129925251, 67.04525917768478, 66.67512103915215, 74.83032703399658, 48.09129863977432, 0.13416493748081848, 0.05443010508315638, 0.35807141102850437, 0.6443234102334827, 46.46557107567787, 66.06732845306396, 53.14804829657078, 49.15555313229561, 27.12419282644987, 47.18455329537392, 51.498822793364525, 37.42800682783127, 0.8506022288929671, 0.056638380337972194, 0.049395126625313424, 0.029362989334913436, 0.09854775649728253, 0.038180314149940386, 0.034931113696075045, 0.030725362812518142, 0.053020317645859905, 0.02272317960887449, 0.047474329694523476, 0.03953287457989063, 0.029516003487515263, 0.02992115118104266, 0.043555474549066275, 0.11424256939790212, 52.85533860325813, 57.59551964700222, 54.146334528923035, 46.426034197211266, 58.37947838008404, 51.566728949546814, 82.88804545998573, 26.41641240566969, 0.10336461404222064, 1.8147739511914551, 0.1388883066829294, 32.503873854875565, 71.51065036654472, 72.71786838769913, 72.6481345295906, 70.48307910561562, 68.16454231739044, 70.3171344101429, 68.21868941187859, 69.22612935304642, 67.74281054735184, 67.92634829878807, 63.62460292875767, 62.90649086236954, 58.00718195736408, 60.61227656900883, 61.394958570599556, 60.44296145439148, 61.72707214951515, 59.359483793377876, 52.18793861567974, 50.83524540066719, 47.12515488266945, 46.65933407843113, 47.73699805140495, 44.146954491734505, 45.64434014260769, 45.68947412073612, 46.88599951565266, 45.588494539260864, 45.55939570069313, 51.29016079008579, 54.35362860560417, 56.2863264977932, 55.45639403164387, 52.85061165690422, 47.800234258174896, 46.63790322840214, 46.4972347766161, 45.93272186815739, 43.59089232981205, 44.06474590301514, 45.222961753606796, 42.23975323140621, 41.005666851997375, 43.180651143193245, 45.374037846922874, 45.834774523973465, 42.1119736880064, 45.93018740415573, 46.74672558903694, 47.720620930194855, 46.47969871759415, 46.36385053396225, 48.84525418281555, 49.5379988104105, 50.30203901231289, 50.706588104367256, 52.328128293156624, 52.27410279214382, 51.47823169827461, 50.6570615619421, 51.24079763889313, 53.753188624978065, 53.34966167807579, 51.21670313179493, 55.1988210529089, 57.151673063635826, 36.190835013985634, 21.796080730855465, 21.408226042985916, 32.07868047058582, 54.39221553504467, 56.5462439507246, 52.01190926134586, 53.308042511343956, 52.99334339797497, 51.402729749679565, 49.92948040366173, 51.47696256637573, 50.23297391831875, 51.32880471646786, 50.153444185853004, 49.01023373007774, 49.90029416978359, 48.39149013161659, 48.06247338652611, 47.84070588648319, 51.65354289114475, 45.292308032512665, 41.77486337721348, 41.90105460584164, 41.15420088171959, 41.95115491747856, 42.42040693759918, 42.19105884432793, 40.12883350253105, 41.07004299759865, 43.638986349105835, 41.284256502985954, 42.194786444306374, 43.65720257163048, 44.71796125173569, 45.85028909146786, 46.80384412407875, 46.502755880355835, 47.01096720993519, 46.69569432735443, 45.601847022771835, 46.250286027789116, 46.97031319141388, 46.67490564286709, 47.43473947048187, 52.09852561354637, 58.432033360004425, 60.44227369129658, 62.85105563700199, 62.60004110634327, 60.701567977666855, 59.00562398135662, 61.026351749897, 57.15312458574772, 56.41498759388924, 55.13627640902996, 55.863549783825874, 57.63097554445267, 57.68016770482063, 58.79086710512638, 60.56429274380207, 60.8811691403389, 61.88098669052124, 60.92994712293148, 61.595052033662796, 65.41909083724022, 71.6257917881012, 70.35033702850342, 77.52682954072952, 53.02028775215149, 0.09663698598160408, 0.30604884785134345, 0.5643631133716553, 0.8670836070086807, 55.71696884930134, 74.1567675769329, 60.85291385650635, 56.97901792824268, 32.55907729268074, 52.807328179478645, 61.595462411642075, 47.33878321945667, 1.4659339073114097, 0.02283851306856377, 0.074170402076561, 0.05869076747330837, 0.01333966662059538, 0.036026371526531875, 0.03161273765726946, 0.12812479049898684, 0.16725875699194148, 0.14637877349741757, 0.12993631360586733, 0.18220011930679902, 0.15318509889766574, 0.10376338483183645, 0.17181558825541288, 0.28712313214782625, 64.79544550180435, 63.95481660962105, 71.65767207741737, 49.069772735238075, 66.07378050684929, 59.19071204960346, 91.27962157130241, 28.879366144537926, 0.31855504552368075, 2.895090775564313, 0.21293579426128417, 39.84176650643349, 73.76792684197426, 75.80224648118019, 77.06012338399887, 72.67936885356903, 70.3541748225689, 72.56372585892677, 71.94426789879799, 73.34468275308609, 70.84927305579185, 68.62014546990395, 65.64996644854546, 65.44875964522362, 62.27905333042145, 63.548709601163864, 67.17949837446213, 63.79308208823204, 64.97663497924805, 63.02672401070595, 54.045544937253, 51.639191061258316, 48.73909167945385, 49.49806295335293, 50.66423177719116, 46.75685964524746, 47.078417390584946, 48.70060354471207, 48.681118190288544, 49.2426710575819, 46.44068621098995, 52.55765877664089, 57.69527189433575, 57.51645348966122, 58.09144623577595, 56.06141656637192, 50.61587177217007, 50.02700217068195, 48.47241058945656, 49.16521981358528, 46.379608288407326, 47.68637336790562, 47.621123269200325, 43.97881731390953, 43.43999482691288, 45.96381179988384, 47.1163659542799, 48.72384309768677, 45.0706697255373, 48.309076353907585, 49.519858583807945, 52.01466031372547, 51.09641298651695, 51.46952636539936, 51.12473666667938, 52.08602048456669, 53.31479474902153, 55.568195432424545, 55.72826184332371, 56.040000915527344, 55.764884278178215, 53.41913715004921, 53.21161888539791, 56.144388914108276, 56.67353332042694, 54.39533896744251, 58.6501644551754, 56.75597369670868, 38.350874707102776, 25.606124885380268, 24.3624060228467, 34.38638783991337, 57.12534807622433, 59.17944945394993, 54.833782240748405, 56.56943030655384, 55.655731335282326, 54.74207416176796, 54.20243851840496, 54.07762661576271, 52.59954392910004, 56.26604698598385, 53.983209282159805, 52.20940366387367, 53.39557461440563, 53.13328608870506, 50.57271368801594, 49.68907870352268, 55.400362238287926, 48.94578538835049, 44.24155041575432, 46.83371812105179, 43.533572405576706, 44.97720994055271, 42.99192287027836, 46.95596896111965, 44.251220896840096, 44.664733707904816, 45.97327709197998, 42.12212294340134, 44.232347309589386, 46.00290410220623, 46.917074248194695, 47.313419580459595, 49.489562809467316, 48.90761263668537, 49.297220930457115, 49.087513983249664, 48.23162890970707, 49.32812087237835, 49.69417043030262, 49.7239076346159, 51.746466904878616, 54.12552684545517, 59.63110461831093, 62.94962614774704, 65.03899723291397, 65.08511155843735, 64.9113316833973, 61.490485444664955, 63.12526032328606, 59.257789850234985, 61.12858526408672, 57.49133303761482, 58.6798370629549, 59.974598586559296, 62.287093698978424, 62.482042238116264, 63.775481432676315, 65.45117631554604, 65.59566736221313, 65.52341043949127, 65.32224163413048, 68.33193853497505, 74.81077328324318, 74.2817048728466, 83.18518951535225, 57.06867791712284, 0.19157234608428553, 0.6600467883981764, 0.8133854228071868, 0.9729255025740713, 62.474051266908646, 83.63818600773811, 68.25587421655655, 69.80501309037209, 38.76360476016998, 67.19479635357857, 75.73518007993698, 60.35253770649433, 2.071945695206523, 0.15672490582801402, 0.18485585023881868, 0.13433650718070567, 0.23649144277442247, 0.1687546743778512, 0.10901007946813479], [0.04986029365682043, 0.13632708083605394, 0.0053051113991386956, 0.05080877694126684, 0.0505345719284378, 0.02473102304065833, 0.03111996644292958, 0.03374608939338941, 0.044598689273698255, 38.229570016264915, 54.486511275172234, 39.07671935856342, 21.848003044724464, 44.54393059015274, 53.179962784051895, 71.61759182810783, 34.408989027142525, 0.20755645557073876, 0.7886461378075182, 0.09462016998440959, 4.284352278336883, 52.63151541352272, 70.6086091697216, 69.88208815455437, 71.92028358578682, 67.37904086709023, 66.35819524526596, 65.0229012966156, 65.96927091479301, 60.59276461601257, 58.39006081223488, 56.125762313604355, 58.7246860563755, 57.06281863152981, 54.933238103985786, 54.2353979498148, 56.899286806583405, 50.50157770514488, 46.37197829782963, 44.91904266178608, 45.624820590019226, 42.84784220159054, 43.04637014865875, 41.86099335551262, 42.87335783243179, 43.00846338272095, 45.00326134264469, 43.207405507564545, 46.134897619485855, 48.75507742166519, 54.69798132777214, 56.89064607024193, 57.421336993575096, 54.565782621502876, 55.18692009150982, 49.38006788492203, 45.36339841783047, 42.98445247113705, 45.20267844200134, 42.66336590051651, 41.232206895947456, 39.801427870988846, 39.73317213356495, 41.23951390385628, 40.27211241424084, 44.455566331744194, 43.77670615911484, 46.07325352728367, 43.20970818400383, 40.82393400371075, 45.36562129855156, 43.88955630362034, 44.71654012799263, 46.7853657156229, 48.51208806037903, 49.72714126110077, 51.5033483505249, 48.41145806014538, 50.29744505882263, 50.64709089696407, 49.37382102012634, 50.44581189751625, 48.490106239914894, 49.77561146020889, 50.06041757762432, 61.45643927156925, 49.154983162879944, 24.08305451273918, 21.240132562816143, 28.97305391728878, 21.1175986379385, 37.662465646862984, 59.4128443300724, 48.073405399918556, 50.12786775827408, 51.20614729821682, 49.54339452087879, 46.31546013057232, 48.721525222063065, 47.14475043118, 47.91554667055607, 45.58363080024719, 46.87084212899208, 45.715400129556656, 44.4430536031723, 43.624288737773895, 44.21327993273735, 42.29356214404106, 44.555595964193344, 42.41731010377407, 39.89907123148441, 42.55004458129406, 42.62626089155674, 40.05685396492481, 39.373327642679214, 39.11109611392021, 39.57383528351784, 36.93291999399662, 36.917549818754196, 41.620017886161804, 41.61194711923599, 42.00044967234135, 44.14813622832298, 44.005670472979546, 44.084698632359505, 44.16761018335819, 41.12790249288082, 44.05401147902012, 43.06156173348427, 43.311508521437645, 44.27696071565151, 45.43792001903057, 44.57499772310257, 49.59629528224468, 55.30484676361084, 57.140026688575745, 57.459110766649246, 58.36485676467419, 58.66420470178127, 56.89650535583496, 57.54630468785763, 55.91153360903263, 54.937148094177246, 53.55965740978718, 52.486906573176384, 51.2199367582798, 49.641968831419945, 51.57942406833172, 51.7470520734787, 52.03940838575363, 54.74936217069626, 56.76635093986988, 62.19582259654999, 67.82657325267792, 68.67088034749031, 72.36844673752785, 66.99678897857666, 0.7116239739116281, 0.18280090269399807, 0.1926351906149648, 1.9754505855962634, 54.82131890952587, 57.4396938085556, 48.70222605764866, 43.839919567108154, 18.84971883147955, 35.56703008711338, 50.95660708844662, 32.21998728811741, 1.4327192958444357, 0.0368961277854396, 0.020430362601473462, 0.010363532910560025, 0.007188116314864601, 0.048053201171569526, 0.04744512618344743, 0.020639820795622654, 0.1206194213591516, 0.04725067235995084, 0.06180481912451796, 0.04134963724936824, 0.030375686947081704, 0.03524751722579822, 0.03501801176753361, 0.1057408150518313, 47.91308060288429, 59.39230643212795, 46.15875653922558, 27.17072892934084, 53.3982914686203, 58.035061061382294, 78.55627790093422, 38.61882872879505, 0.2546760201221332, 1.0270980675704777, 0.05109188401547726, 3.239085366949439, 52.92470768094063, 69.91762384772301, 72.08750501275063, 72.02034741640091, 70.58970898389816, 69.90739479660988, 67.53810793161392, 68.92500311136246, 63.12893472611904, 61.752644777297974, 59.984280467033386, 60.893385484814644, 58.104460537433624, 57.99016647040844, 58.033981919288635, 59.16297733783722, 53.601922541856766, 50.39856143295765, 49.08402197062969, 48.12389329075813, 46.90865010023117, 45.278476774692535, 46.01818308234215, 45.66188000142574, 45.25000490248203, 47.431551441550255, 44.8226760327816, 49.97710704803467, 51.503861322999, 56.597062423825264, 59.94375944137573, 57.926166504621506, 58.09421628713608, 56.67896322906017, 52.30556130409241, 47.387895584106445, 46.06786921620369, 48.374839425086975, 44.13578309118748, 44.15345214307308, 40.919692665338516, 42.00294613838196, 43.34865912795067, 41.962527707219124, 45.290594324469566, 45.84374584257603, 49.95556600391865, 45.59241212904453, 44.27695691585541, 47.4126398563385, 46.206045001745224, 48.4616419672966, 49.830279126763344, 51.20062619447708, 51.19407154619694, 53.80082666873932, 51.418669894337654, 52.56463900208473, 54.524406641721725, 52.09661811590195, 52.20169387757778, 49.65961508452892, 52.03746289014816, 53.752117082476616, 62.799401208758354, 51.686859503388405, 23.364972844719887, 21.27459291368723, 28.325604759156704, 20.870896875858307, 38.40875320136547, 63.188500329852104, 50.498021095991135, 52.20484010875225, 55.10843150317669, 51.983046010136604, 49.79214817285538, 48.229216039180756, 48.584443777799606, 49.76754069328308, 48.33127476274967, 48.70036795735359, 46.27388656139374, 47.32812479138374, 45.996117666363716, 45.950307324528694, 44.61829639971256, 45.087267234921455, 44.0256118029356, 40.77309273183346, 44.4131226092577, 44.98452074825764, 43.45740929245949, 41.767400577664375, 40.57784780859947, 42.08809956908226, 39.87142011523247, 38.922470435500145, 45.40388524532318, 43.958138823509216, 44.151799231767654, 46.24252684414387, 47.4391358345747, 46.07305973768234, 47.53880448639393, 45.19975259900093, 46.668958961963654, 45.5186352878809, 44.57133091986179, 46.47688306868076, 46.87670901417732, 45.800542160868645, 52.402235716581345, 57.03928269445896, 60.750687941908836, 60.2984020113945, 60.52673555910587, 62.31447122991085, 61.3635228574276, 60.37616103887558, 58.929711654782295, 59.732794761657715, 56.34179972112179, 56.85058481991291, 53.785429894924164, 53.95719587802887, 54.358579739928246, 54.26979370415211, 55.25378130376339, 58.03604520857334, 59.11842092871666, 67.57447198033333, 69.75967392325401, 73.25520515441895, 75.07425874471664, 72.75078222155571, 0.3944843227509409, 0.3113628627033904, 0.1862547392374836, 2.63376051094383, 64.9502643942833, 65.6620042026043, 54.106246680021286, 52.48225562274456, 32.05813117325306, 45.41969619691372, 62.366619631648064, 41.88796430826187, 1.798307178542018, 0.08561975919292308, 0.059366593122831546, 0.03365883880178444, 0.056302291341125965, 0.09982640272937715, 0.03541956561093684, 0.10838386268005706, 0.1874161558225751, 0.1493078374187462, 0.19922347302781418, 0.18778871395625174, 0.07394508604193106, 0.21168616600334644, 0.10850517413928173, 0.3561431332491338, 61.79050214588642, 69.87941309809685, 51.541133522987366, 27.613426074385643, 63.428898230195045, 66.83738753199577, 86.88566654920578, 43.66376481950283, 0.3401890065288171, 1.7529412941075861, 0.24274059338495135, 5.608983999118209, 57.8493308275938, 74.22362878918648, 77.41477355360985, 76.14907667040825, 73.88487696647644, 72.47740969061852, 69.8810850083828, 70.68183124065399, 65.27197793126106, 63.58856186270714, 63.967599123716354, 65.40401324629784, 61.375233829021454, 62.126472517848015, 60.638407766819, 62.82869003713131, 56.996702179312706, 52.440602257847786, 51.25863008201122, 50.712375193834305, 47.45990552008152, 47.57491774857044, 49.61129307746887, 47.25517250597477, 47.59524665772915, 50.248123705387115, 47.47238025069237, 54.002041071653366, 53.809030428528786, 59.83250141143799, 59.81792539358139, 61.35082393884659, 59.10463906824589, 59.261228665709496, 55.47225438058376, 51.39012582600117, 48.00960682332516, 51.38597644865513, 47.90009289979935, 47.27138243615627, 44.27906580269337, 45.171611309051514, 46.59543290734291, 45.68631649017334, 49.17682819068432, 47.96524800360203, 52.14503891766071, 49.232468605041504, 47.601725310087204, 49.90273363888264, 49.10211279988289, 49.773392379283905, 53.088353499770164, 55.56254133582115, 55.111060962080956, 57.339588180184364, 52.71138712763786, 55.234577134251595, 58.34533341228962, 56.07261076569557, 57.94454611837864, 50.2036052942276, 54.13593828678131, 56.10242776572704, 65.94728529453278, 52.34888657927513, 24.19182937592268, 21.522128731012344, 27.0640629529953, 20.69033246487379, 38.3003906160593, 65.71742802858353, 51.67843535542488, 54.445427879691124, 56.44534416496754, 53.69054518640041, 50.744772255420685, 51.25503547489643, 51.312260404229164, 52.64168746769428, 50.53996704518795, 52.159018367528915, 51.39975070953369, 49.545985981822014, 49.40334163606167, 49.100771471858025, 48.80110055208206, 47.437357529997826, 45.623285472393036, 44.620614275336266, 47.19054937362671, 46.95205897092819, 46.273130401968956, 43.90919744968414, 43.504861146211624, 45.468595772981644, 41.49003826081753, 40.44437997043133, 47.590295523405075, 46.878855898976326, 46.107713878154755, 48.59969615936279, 50.55842265486717, 48.270033448934555, 48.822216019034386, 46.85719706118107, 49.494605138897896, 48.439762741327286, 48.43200355768204, 48.85794550180435, 48.945656195282936, 47.91368097066879, 56.347773000597954, 60.06783418357372, 63.546927496790886, 62.045574858784676, 63.309292048215866, 65.19539684057236, 63.75788077712059, 64.07093077898026, 61.97978138923645, 61.599262207746506, 57.799526900053024, 58.933082073926926, 57.796053886413574, 56.24917969107628, 56.25232212245464, 56.798785999417305, 58.240747824311256, 61.17450959980488, 63.52116107940674, 72.10175424814224, 74.06548887491226, 77.56244122982025, 80.05318477749825, 78.01397860050201, 0.8100467675831169, 0.5851320270448923, 0.5024649691767991, 3.28154310118407, 72.85982117056847, 72.82256796956062, 65.24711206555367, 63.44569332897663, 31.935287564992905, 53.602549508214, 74.66536268591881, 55.97130060195923, 2.569455849006772, 0.2781456388765946, 0.16470343864057213, 0.18973924132296816, 0.11150550650199875, 0.19180359930032864, 0.08625180926173925], [0.04552503058221191, 0.07953174368594773, 0.0819934178434778, 0.03551338420948014, 0.09897576790535823, 0.05551729576836806, 0.1140969674452208, 0.04591186763718724, 0.14843804034171626, 28.7551337108016, 47.39734947681427, 48.61999846994877, 36.07271835207939, 38.56171779334545, 44.444763511419296, 68.28240439295769, 52.68557511270046, 0.41071476589422673, 0.15927606815239415, 0.44642652617767453, 0.15340820333221927, 24.34004422277212, 73.19761544466019, 62.6492028683424, 67.09986984729767, 60.78850731253624, 58.891174122691154, 55.40077641606331, 53.99337373673916, 50.45755706727505, 54.219549000263214, 53.25133055448532, 53.46829891204834, 51.017540618777275, 52.593213468790054, 50.47993026673794, 46.65537089109421, 42.77369678020477, 44.82506610453129, 44.6371091902256, 41.35198026895523, 44.67782020568848, 44.301647990942, 45.04746817052364, 43.55570241808891, 42.83762454986572, 45.733414962887764, 46.00720927119255, 50.837213695049286, 52.934412360191345, 55.80033257603645, 57.80996114015579, 54.74363587796688, 59.05918970704079, 57.73715704679489, 52.80452772974968, 47.853784784674644, 45.27787260711193, 44.56746272742748, 44.644005820155144, 43.85158494114876, 37.03090913593769, 38.891049921512604, 40.14073446393013, 42.987435311079025, 42.743720188736916, 42.95091927051544, 44.464115872979164, 43.81197966635227, 43.53266425430775, 42.95409969985485, 45.23554667830467, 43.139499351382256, 48.3826670050621, 47.489939108490944, 46.89250476658344, 48.119531124830246, 49.745068699121475, 50.417860597372055, 46.56352981925011, 49.15241450071335, 48.40972155332565, 51.50687836110592, 54.089979752898216, 55.10400094091892, 58.82812790572643, 53.10555137693882, 27.909016013145447, 29.621135741472244, 48.06091167032719, 35.840334221720695, 30.018972493708134, 55.25597758591175, 54.525573179125786, 50.38290627300739, 49.004815220832825, 49.03565816581249, 48.46200294792652, 46.23454347252846, 47.801013216376305, 46.95275813341141, 47.41613566875458, 43.83344851434231, 42.96811334788799, 44.17661190032959, 44.22839552164078, 40.31191907823086, 43.15357379615307, 43.510587438941, 42.3501943051815, 41.14633910357952, 42.77287222445011, 42.69583895802498, 38.416310995817184, 38.54204624891281, 37.61573575437069, 38.28204520046711, 38.060441091656685, 38.09472285211086, 45.088099390268326, 46.70154221355915, 45.032325983047485, 43.87987822294235, 45.62287129461765, 49.087840765714645, 50.875029265880585, 49.22196976840496, 45.29190145432949, 43.06581370532513, 41.831130757927895, 44.59476426243782, 46.26082666218281, 45.22914782166481, 48.70881110429764, 51.40862323343754, 52.61907488107681, 57.452377527952194, 58.93413461744785, 60.64291812479496, 60.74365831911564, 63.29715549945831, 60.77636696398258, 62.35653877258301, 59.13391649723053, 58.95453952252865, 57.04852379858494, 56.58004693686962, 53.32083262503147, 57.23535597324371, 54.93735708296299, 55.162624195218086, 55.62673129141331, 62.82152362167835, 63.393328338861465, 70.55753231048584, 65.01575008034706, 77.8650189936161, 1.8560294061899185, 0.020967718337487895, 0.18822695215931162, 3.2165922364220023, 64.76285085082054, 61.03720776736736, 55.092521756887436, 38.407582864165306, 24.027908071875572, 40.53682141005993, 54.13143552839756, 32.159502133727074, 2.1788363344967365, 0.0664790952578187, 0.08794291148660704, 0.02607948124932591, 0.02945462601928739, 0.026511581891099922, 0.024190696858568117, 0.023449089094356168, 0.08888990676496178, 0.024090421575237997, 0.050904740346595645, 0.11115157627500594, 0.06134525901870802, 0.008182355322787771, 0.00856869699418894, 0.07682556155486964, 38.70552867650986, 57.50609144568443, 53.479588106274605, 31.304667703807354, 43.376671224832535, 53.51369887590408, 73.93017053604126, 60.34244924783707, 0.4782553104450926, 0.17112614790676162, 0.47497763007413596, 0.08501118325511925, 25.16015611588955, 75.60509026050568, 67.376958578825, 69.03264373540878, 62.85036787390709, 62.43434339761734, 59.093061089515686, 53.7918895483017, 54.11888100206852, 57.020530700683594, 54.12136226892471, 55.44179141521454, 53.143055364489555, 54.30510900914669, 53.22006203234196, 49.741656482219696, 46.82070381939411, 48.80475215613842, 46.362380012869835, 45.77647425234318, 46.152665466070175, 48.10011796653271, 48.258706256747246, 46.36271819472313, 45.6822507083416, 46.662639901041985, 47.07982711493969, 55.06250336766243, 55.55271506309509, 60.67890979349613, 59.89333614706993, 56.2453418970108, 61.648526564240456, 60.70002146065235, 55.77591888606548, 50.82317344844341, 48.018798530101776, 45.57486467063427, 46.04490704834461, 44.70486715435982, 38.674811124801636, 40.591390281915665, 40.67375846207142, 45.001232251524925, 44.1264583915472, 45.17805576324463, 46.5179056674242, 45.26135869324207, 44.73594568669796, 44.339588955044746, 47.60604187846184, 46.582847982645035, 51.45568370819092, 48.691453635692596, 48.973721489310265, 50.06311163306236, 53.56796756386757, 51.677238419651985, 48.30303467810154, 50.30485846102238, 51.46270573139191, 54.61990311741829, 57.94843710958958, 57.77365028858185, 59.27549310028553, 53.58106166124344, 27.529783062636852, 30.99606916308403, 50.18361456692219, 35.3487242013216, 29.536713771522045, 57.17200957238674, 56.93557865917683, 51.90351627767086, 51.964199021458626, 52.120952010154724, 48.93367923796177, 50.204407051205635, 46.95157639682293, 48.971183225512505, 50.538101345300674, 45.82757391035557, 47.01845280826092, 46.03831820189953, 44.82051394879818, 42.67936684191227, 47.07904815673828, 44.16174329817295, 43.784944117069244, 45.3563079982996, 45.43575033545494, 45.33371441066265, 42.26457729935646, 40.23059204220772, 41.788614839315414, 41.70453295111656, 40.16890615224838, 40.40152966976166, 46.492492631077766, 48.14516834914684, 46.67284615337849, 45.55021159350872, 49.07349273562431, 53.58894623816013, 53.86867582798004, 53.01517702639103, 47.779711559414864, 46.289594918489456, 43.96963320672512, 46.62959687411785, 47.24326014518738, 46.9629567861557, 49.92704853415489, 54.193129017949104, 57.10401602089405, 61.035254672169685, 61.83220870792866, 62.46582850813866, 62.80875250697136, 66.09890475869179, 62.714285776019096, 66.04385331273079, 62.644833102822304, 61.6484771668911, 59.734166488051414, 59.75454859435558, 56.340143010020256, 59.90590587258339, 57.189146652817726, 58.19264240562916, 57.029080241918564, 66.54032707214355, 66.58904805779457, 75.87229192256927, 68.3314597606659, 81.89173892140388, 1.8425882211886346, 0.16884822951396927, 0.06275802617892623, 4.05501558445394, 72.36775517463684, 67.49991998076439, 63.90665799379349, 47.747135907411575, 33.946348652243614, 54.79580707848072, 64.83791202306747, 42.88705229759216, 2.3434753250330687, 0.0862761220196262, 0.12761739897541702, 0.02382707974902587, 0.01844105245254468, 0.034433136315783486, 0.05908300736336969, 0.1959488057764247, 0.22670132748316973, 0.157772061356809, 0.14102214452577755, 0.2090671268524602, 0.2417734859045595, 0.15877424273639917, 0.1722112568677403, 0.4632389615289867, 51.860240399837494, 67.1486896276474, 62.78499238193035, 44.330446645617485, 56.485679000616074, 59.1880863904953, 82.24798500537872, 63.670607060194016, 0.6012590148020536, 0.3696604922879487, 0.7988022803328931, 0.2648354577831924, 31.46657131612301, 77.90239378809929, 70.71619659662247, 74.79371219873428, 68.25554743409157, 65.72685912251472, 63.17715413868427, 58.51977825164795, 56.342498883605, 60.36936320364475, 59.36382316052914, 57.944869101047516, 57.482734099030495, 57.03552469611168, 56.97668485343456, 53.84381376206875, 48.275349363684654, 52.07255780696869, 50.35227611660957, 46.78593948483467, 52.00003109872341, 51.14815481007099, 51.57704919576645, 49.802308827638626, 48.04526410996914, 50.44981308281422, 52.5940228253603, 57.805804163217545, 58.34825545549393, 61.24183438718319, 62.363807782530785, 58.37248295545578, 64.46823745965958, 61.93713627755642, 58.35930906236172, 54.27840784192085, 48.9800101518631, 48.325084894895554, 49.095052778720856, 49.24470394849777, 41.060083732008934, 42.838141322135925, 44.2813266813755, 48.83789397776127, 46.299858167767525, 47.747873067855835, 49.97951611876488, 49.6086560189724, 48.14099617302418, 46.93438991904259, 49.36806432902813, 48.432926908135414, 54.03801754117012, 52.644047141075134, 52.39400535821915, 52.75946594774723, 55.191616639494896, 55.51487669348717, 51.33471719920635, 53.98358926177025, 53.33437129855156, 58.3261102437973, 61.08084462583065, 58.33910934627056, 63.215342089533806, 57.18431331217289, 27.076889164745808, 30.92258870601654, 49.465278312563896, 34.57736559212208, 29.527470767498016, 60.127270594239235, 59.70715373754501, 55.062731355428696, 53.6715842038393, 54.59156043827534, 52.50161938369274, 52.51431070268154, 50.68276718258858, 52.21575692296028, 54.743400290608406, 48.80399599671364, 49.36691299080849, 48.71039941906929, 49.34393182396889, 45.44221378862858, 49.115871861577034, 49.16778467595577, 45.50958797335625, 48.20151932537556, 47.512080520391464, 48.61807577311993, 45.09916439652443, 42.36611545085907, 44.21466305851936, 42.93297663331032, 42.73080848157406, 42.074435502290726, 49.953677505254745, 52.085066735744476, 51.06167145073414, 47.15396113693714, 49.388332441449165, 54.73954349756241, 56.92617416381836, 55.19211821258068, 51.06526605784893, 49.247485399246216, 47.15013474225998, 50.24541065096855, 52.4331546574831, 48.85007992386818, 53.94832715392113, 57.31888309121132, 58.19368734955788, 62.246439680457115, 64.81473326683044, 65.38148805499077, 66.56810358166695, 67.35917553305626, 64.05010029673576, 69.94209453463554, 64.22602325677872, 65.96158772706985, 62.94332608580589, 63.772882372140884, 60.13512097299099, 64.61404323577881, 61.924064978957176, 62.24259428679943, 62.26913586258888, 71.91449269652367, 69.68568429350853, 79.71681162714958, 71.53819128870964, 87.87449508905411, 2.4388392828404903, 0.4520893207518384, 0.45745439536403865, 5.238458756357431, 83.08897107839584, 78.79042893648148, 72.52176091074944, 59.55105431377888, 37.02007971704006, 57.113899290561676, 77.36392468214035, 56.30473650991917, 2.8966446546837687, 0.27205186430364847, 0.279136435710825, 0.1016304078802932, 0.20835227536736056, 0.18418098567053676, 0.11120088456664234], [0.08887415839126334, 0.057347090551047586, 0.04502231829974335, 0.05911576947255526, 0.06491133797680959, 0.04369975176814478, 0.013722455259994604, 0.04251058999216184, 0.49801944522187114, 22.32939161360264, 43.78870211541653, 43.29686410725117, 42.62934632599354, 37.92460598051548, 46.20935462415218, 59.0417942404747, 70.06921291351318, 5.075343959033489, 0.1778169654426165, 1.0129851498641074, 0.3273057087790221, 10.707486290484667, 74.7479322552681, 62.388650849461555, 63.64952579140663, 56.7617379873991, 53.827235251665115, 50.52820287644863, 54.434461668133736, 49.517654702067375, 49.88009065389633, 50.04846341907978, 47.22909830510616, 48.502018600702286, 49.1390810161829, 46.86581879854202, 45.91483622789383, 42.96258084475994, 45.48203185200691, 40.902266800403595, 44.70444157719612, 42.11974807083607, 44.17185835540295, 42.88207456469536, 44.939371570944786, 43.49374674260616, 47.11260035634041, 49.238069504499435, 54.26709204912186, 55.855858996510506, 57.91630603373051, 52.8571093082428, 58.78461644053459, 58.42433877289295, 56.957674473524094, 54.60493192076683, 50.35408101975918, 47.58898839354515, 45.47049567103386, 46.9064462184906, 44.259409457445145, 43.11709575355053, 39.25567075610161, 42.17459812760353, 43.58846805989742, 39.98381048440933, 41.41050472855568, 39.619702622294426, 40.06384178996086, 42.61408634483814, 42.25235715508461, 45.782063752412796, 45.0239322334528, 46.18753619492054, 45.54833069443703, 48.255807012319565, 45.80137051641941, 50.10581374168396, 47.02034890651703, 45.4056179523468, 51.43231116235256, 51.066614985466, 52.92096868157387, 52.83072732388973, 53.61848205327988, 57.467968091368675, 55.34784525632858, 38.079117089509964, 35.67122049629688, 43.53942409157753, 43.774312287569046, 39.040294513106346, 53.71315777301788, 55.66130183637142, 50.26415504515171, 50.49589321017265, 50.11025570333004, 48.65005865693092, 47.55371108651161, 47.515846118330956, 46.003515869379044, 47.50331439077854, 45.35761512815952, 44.31509166955948, 46.49733357131481, 44.25175666809082, 41.92703761160374, 43.2492982596159, 41.61097437143326, 39.695428758859634, 43.00745643675327, 42.76567921042442, 40.58107003569603, 38.34589697420597, 37.194174975156784, 40.15164367854595, 39.82841782271862, 39.61571663618088, 43.03242489695549, 47.76930011808872, 44.15658317506313, 43.302719593048096, 46.81702941656113, 52.235732451081276, 56.36902146041393, 58.29434394836426, 57.85862512886524, 50.870142728090286, 50.13657309114933, 44.09565344452858, 43.46987642347813, 42.29327715933323, 46.85664229094982, 45.53851202130318, 45.60481086373329, 49.544948637485504, 58.364674374461174, 58.754305467009544, 58.077337592840195, 62.111201137304306, 63.85782301425934, 64.00240525603294, 63.211603090167046, 62.792550176382065, 62.91771166026592, 60.56042455136776, 61.2518734484911, 57.58300691843033, 58.49324427545071, 54.63711619377136, 56.51077665388584, 57.12872229516506, 61.60288341343403, 59.02925871312618, 63.93835589289665, 62.354220896959305, 79.51649397611618, 3.125335145741701, 0.1325007455307059, 0.14202054095221683, 3.4651767974719405, 65.0114943087101, 57.88701720535755, 58.649970665574074, 35.60007691383362, 36.72972969710827, 32.29003272950649, 47.685058638453484, 39.375360533595085, 0.394062960986048, 0.11763924572733231, 0.03097764478297904, 0.055425061655114405, 0.04806866381841246, 0.12304115312872455, 0.028410134800651576, 0.025679504469735548, 0.04387012289953418, 0.018355915126448963, 0.0923651023185812, 0.08588737022364512, 0.02536084852181375, 0.06251121012610383, 0.05327360893716104, 0.4388792108511552, 33.328858986496925, 53.63667547702789, 44.51018840074539, 35.86671620607376, 45.91357469558716, 52.797517105937004, 69.01639580726624, 77.26027384400368, 5.597642557695508, 0.26870326430071145, 1.4209431339986622, 0.5072008806746453, 11.960567850619555, 77.88515791296959, 65.05177214741707, 66.60910338163376, 58.76731216907501, 55.64981125295162, 53.53262186050415, 56.13491602241993, 51.455638110637665, 51.950846537947655, 53.16020004451275, 51.04003541171551, 51.87950536608696, 51.98190987110138, 50.570053830742836, 49.08796235918999, 45.77376499772072, 47.513839825987816, 44.510199800133705, 46.64706073701382, 46.857983618974686, 46.82706467807293, 45.740353390574455, 47.167591005563736, 45.488457307219505, 47.396152541041374, 50.72627104818821, 55.09436085820198, 57.76821278035641, 60.15660122036934, 53.15082214772701, 58.30623351037502, 61.21799826622009, 60.75838252902031, 57.01661691069603, 50.95373444259167, 51.194987297058105, 47.48941853642464, 50.21334037184715, 47.58713789284229, 46.49798333644867, 40.51805421710014, 46.10776327550411, 45.56883059442043, 43.94529931247234, 43.872841000556946, 43.43356557190418, 42.20828332006931, 44.260313808918, 45.42622044682503, 45.81983372569084, 45.972038358449936, 49.27092634141445, 48.43284331262112, 50.05099028348923, 49.083087220788, 53.876609802246094, 50.75737617909908, 49.01451990008354, 51.73300422728062, 53.22615310549736, 54.61703047156334, 54.82822313904762, 54.45626489818096, 59.88331988453865, 56.85579814016819, 37.41902031004429, 37.120823711156845, 42.47586876153946, 43.79005864262581, 40.10614491999149, 54.24831345677376, 59.5643649995327, 51.78167201578617, 52.190754264593124, 52.33285143971443, 49.75492537021637, 50.56717358529568, 50.52214600145817, 47.6696352660656, 48.75520281493664, 47.66870431602001, 45.91167859733105, 47.39788144826889, 48.534328266978264, 45.21560914814472, 44.44666340947151, 43.70262913405895, 43.76923196017742, 44.905010014772415, 44.05970357358456, 42.15528756380081, 41.061637848615646, 40.315046310424805, 42.85309351980686, 42.36726678907871, 42.288633808493614, 46.34097956120968, 51.167932748794556, 47.147729471325874, 45.69312572479248, 47.70190313458443, 55.90587191283703, 59.41432245075703, 61.24530740082264, 59.728345200419426, 54.462363570928574, 50.66603288054466, 44.81475345790386, 46.985067799687386, 44.760423973202705, 50.9565918892622, 46.72581911087036, 47.770459055900574, 50.8566040545702, 59.926234781742096, 59.37043860554695, 60.59580825269222, 63.81737798452377, 68.54630783200264, 64.56083849072456, 65.70027574896812, 64.68759968876839, 67.40588262677193, 64.19294223189354, 64.28943425416946, 59.51278656721115, 61.331482976675034, 57.71085865795612, 61.580362021923065, 60.07609114050865, 66.73083364963531, 63.88936132192612, 70.02812951803207, 65.96129894256592, 83.2110433280468, 2.89825695566833, 0.27714424417354167, 0.06582719273865223, 4.333446118980646, 74.63711500167847, 65.94071164727211, 67.85358980298042, 46.24399356544018, 34.398022815585136, 41.00878268480301, 60.34810334444046, 48.39220069348812, 0.6486238294746727, 0.12147795263445005, 0.04298845145967789, 0.0699262079433538, 0.035477705459925346, 0.03454326360952109, 0.0438724866398843, 0.101257263449952, 0.3033235331531614, 0.1589305538800545, 0.13360471988562495, 0.24957770307082683, 0.23179151059594005, 0.18266517872689292, 0.2603310073027387, 0.7889994001016021, 47.86366805434227, 66.96682378649712, 60.39261415600777, 54.53272819519043, 55.75144439935684, 60.2075032889843, 72.79023930430412, 83.1902964413166, 6.599405603483319, 0.3172597900265828, 2.053302233107388, 0.5708869476802647, 14.11964999511838, 83.28887075185776, 68.38683798909187, 71.30193516612053, 61.46915338933468, 59.9557363986969, 55.876738876104355, 60.23769646883011, 56.02842293679714, 56.35927118360996, 56.12581931054592, 54.89615589380264, 54.594946056604385, 54.88524667918682, 54.00323420763016, 52.0563592761755, 48.52913394570351, 51.11616052687168, 47.081119045615196, 51.25870227813721, 49.410405457019806, 50.00283166766167, 47.0656880736351, 50.83942897617817, 48.34529221057892, 51.1037427932024, 53.98734726011753, 59.05140772461891, 60.473382622003555, 62.01839491724968, 54.74769786000252, 58.62379767000675, 63.989630341529846, 62.82295234501362, 59.34537135064602, 55.234071761369705, 53.461778461933136, 50.15881709754467, 54.60966646671295, 50.71628138422966, 49.40385460853577, 44.060353338718414, 47.81788811087608, 46.179153844714165, 45.52950270473957, 46.95839323103428, 44.46512661874294, 45.3656554967165, 47.98903092741966, 46.927117109298706, 49.81974609196186, 48.57265301048756, 50.02254880964756, 51.81421346962452, 54.39130358397961, 50.86545377969742, 55.17100654542446, 52.170953527092934, 51.65733128786087, 56.93583324551582, 57.16231249272823, 56.42994359135628, 56.293295323848724, 57.55559138953686, 62.882856130599976, 58.579621240496635, 38.12737450003624, 35.43470598757267, 43.606923669576645, 43.702940717339516, 41.216034963727, 57.34882168471813, 62.26505868136883, 55.302449092268944, 54.10218849778175, 55.42719639837742, 52.086351066827774, 52.77612425386906, 54.26514655351639, 49.20476049184799, 50.7090237736702, 49.88208934664726, 49.249955266714096, 50.81906586885452, 50.88433496654034, 47.27645896375179, 46.15909092128277, 46.371256336569786, 45.951842442154884, 48.23060676455498, 48.39274786412716, 44.79642704129219, 42.405051961541176, 43.83488863706589, 44.99373905360699, 44.82549928128719, 45.05211152136326, 48.77889074385166, 54.235534742474556, 50.00301405787468, 49.213819205760956, 52.51176863908768, 57.97854669392109, 61.11125819385052, 64.22135710716248, 63.42293255031109, 55.27306146919727, 53.198767974972725, 47.63784617185593, 49.15018022060394, 45.77003359794617, 53.00225771963596, 50.53250044584274, 50.75397536158562, 54.70832817256451, 64.12089809775352, 62.46379941701889, 63.657041788101196, 66.86264097690582, 71.0323092341423, 69.28953275084496, 68.15312772989273, 68.49135518074036, 69.628466963768, 67.75869369506836, 66.39181584119797, 63.457993268966675, 64.71255674958229, 62.03644394874573, 63.840070366859436, 63.858575373888016, 70.46423211693764, 67.34779894351959, 74.76324543356895, 69.5921865105629, 86.89638197422028, 3.8066471368074417, 0.3598841809434816, 0.2754134073620662, 5.288598015904427, 83.93562644720078, 73.29377308487892, 76.58786192536354, 56.71341598033905, 49.420136734843254, 48.74521315097809, 70.71034491062164, 56.994300708174706, 1.3852675608359277, 0.283792907721363, 0.19702604797203094, 0.20114995480980724, 0.2138977957656607, 0.20125036739045754, 0.1099346618866548], [0.0429261481622234, 0.06739606324117631, 0.02363373729167506, 0.02886947968363529, 0.06527753590489738, 0.047369486492243595, 0.1264173461822793, 0.06377619341947138, 0.3679919958813116, 20.000340789556503, 41.9982685893774, 39.97048079967499, 30.962931141257286, 44.420855194330215, 42.972874492406845, 49.98873062431812, 73.05367916822433, 15.982341393828392, 0.7203029457014054, 0.631281619425863, 0.315274159074761, 4.5639208517968655, 72.9782684147358, 67.652398198843, 68.37359189987183, 62.56765924394131, 63.26820485293865, 60.71184642612934, 59.84887853264809, 57.19054497778416, 56.949014738202095, 51.239653900265694, 50.649716556072235, 47.32706844806671, 46.19729407131672, 46.80412530899048, 43.72672364115715, 43.78682881593704, 43.343476206064224, 44.15371052920818, 41.215844973921776, 43.17217759788036, 43.84636402130127, 43.04099723696709, 42.636554539203644, 44.51135493814945, 47.599308639764786, 52.32006512582302, 52.65161633491516, 58.64880792796612, 52.80933067202568, 57.91713438928127, 69.20709997415543, 55.099441185593605, 56.115001291036606, 52.218504175543785, 52.18676067888737, 47.73412540555, 45.10014094412327, 50.29041163623333, 52.870921567082405, 47.52746969461441, 44.964324831962585, 42.124668806791306, 42.459898218512535, 40.74272856116295, 41.52042903006077, 40.47653004527092, 39.421193674206734, 43.456387147307396, 42.24943891167641, 43.065528720617294, 46.419190764427185, 44.974588081240654, 44.2194090038538, 46.3566879183054, 49.21628527343273, 49.16015088558197, 47.04242192208767, 51.380561739206314, 48.03946182131767, 52.48678877949715, 52.11696982383728, 52.97604292631149, 57.04792343080044, 56.818157359957695, 58.272647112607956, 40.25771498680115, 32.19471104443073, 37.49249316751957, 39.3308687210083, 44.113159105181694, 53.590032979846, 56.27885229885578, 52.65412800014019, 52.442752942442894, 52.334432154893875, 50.85590869188309, 46.79646112024784, 46.58193603157997, 49.40511234104633, 49.039784744381905, 43.71374733746052, 45.93454957008362, 45.347576066851616, 42.98165962100029, 42.110784351825714, 44.641528353095055, 44.10760760307312, 41.01240389049053, 39.00905258953571, 39.1916061937809, 39.859275966882706, 40.7084733992815, 39.79707330465317, 41.386311426758766, 43.10699209570885, 43.83101284503937, 47.02320635318756, 48.25125865638256, 43.02389435470104, 44.61972892284393, 46.67237117886543, 54.648884162306786, 57.41793617606163, 56.936547607183456, 56.80208422243595, 57.94715657830238, 56.277963146567345, 49.416948705911636, 44.06232923269272, 43.55486646294594, 43.19747284054756, 43.62184926867485, 45.96230708062649, 43.864223062992096, 49.14116330444813, 55.643450394272804, 59.98924300074577, 59.00137200951576, 64.57631886005402, 62.33456835150719, 64.77732047438622, 59.14716638624668, 63.97318482398987, 63.04153561592102, 65.10332778096199, 62.05549232661724, 62.01510049402714, 59.922605976462364, 63.559960797429085, 57.389745488762856, 60.333109349012375, 57.62801930308342, 68.15743669867516, 65.96477955579758, 77.61169418692589, 2.6209649350494146, 0.1261649269144982, 0.09428337594727054, 7.61084720492363, 71.52526438236237, 55.11322684586048, 54.73831996321678, 34.88397493958473, 51.18682913482189, 46.28721624612808, 59.98322032392025, 42.187772020697594, 1.028930637985468, 0.1128584862453863, 0.03758313388971146, 0.05544550411286764, 0.02780847753456328, 0.08513313296134584, 0.03557313080818858, 0.07637150818482041, 0.050937814157805406, 0.011516036302055, 0.030139554110064637, 0.04474045432289131, 0.03000458156748209, 0.1614248231635429, 0.04654653377656359, 0.8175464370287955, 30.92201493680477, 53.515834361314774, 42.245536521077156, 33.28114874660969, 51.58433340489864, 49.84240807592869, 57.20041684806347, 80.79175114631653, 19.151966013014317, 0.7404729758854955, 0.9905464632902294, 0.4383068665629253, 5.031990660354495, 75.0134240090847, 69.99045833945274, 69.7112949192524, 64.56619620323181, 64.69228863716125, 63.15861493349075, 61.95721060037613, 59.82243575155735, 59.40253548324108, 53.400172367691994, 54.15305256843567, 52.6246377825737, 49.59608629345894, 48.64195369184017, 46.09897434711456, 46.49976164102554, 47.855019718408585, 46.184435561299324, 44.14229594171047, 45.26450112462044, 46.18224687874317, 47.196883633732796, 45.0306236743927, 47.09557726979256, 48.20591948926449, 55.27570992708206, 56.18509612977505, 61.314102709293365, 56.42062649130821, 58.71257610619068, 63.84779915213585, 58.93213972449303, 60.28355620801449, 54.345698431134224, 54.46027748286724, 51.086100339889526, 47.018494606018066, 54.40588340163231, 53.99965099990368, 50.89261472225189, 45.865275487303734, 45.49305126070976, 44.7759423404932, 43.00479277968407, 43.05949464440346, 42.29352794587612, 41.29732400178909, 44.38907749950886, 44.04703885316849, 45.664129480719566, 47.64809422194958, 44.96500879526138, 46.024980917572975, 47.7419263869524, 51.07885032892227, 50.90156324207783, 48.91752250492573, 52.45726056396961, 50.240919291973114, 54.51617248356342, 54.34570603072643, 55.336442068219185, 56.364359110593796, 59.04096208512783, 57.024699077010155, 39.71805654466152, 31.775053963065147, 36.4112763851881, 39.598066583275795, 45.471863597631454, 54.91724096238613, 60.332611575722694, 55.59108540415764, 54.7325898706913, 52.63413347303867, 54.79333721101284, 49.31748524308205, 48.664361089468, 49.773795157670975, 49.32609558105469, 45.524935349822044, 48.16722996532917, 47.65470966696739, 47.116232961416245, 46.11247882246971, 45.11923871934414, 46.071775406599045, 43.94744619727135, 41.374957635998726, 41.54671601951122, 42.110921144485474, 41.77118517458439, 41.94207340478897, 42.99300581216812, 44.4573712348938, 46.440028846263885, 48.80781479179859, 50.19343703985214, 45.03861844539642, 47.281486093997955, 49.49836313724518, 56.22591353952885, 59.461956694722176, 58.51163908839226, 58.87841060757637, 58.97815525531769, 58.6319824308157, 51.08807623386383, 46.93794272840023, 45.71015261113644, 44.81354892253876, 45.33590689301491, 48.279054164886475, 47.706155106425285, 50.52001811563969, 59.15546894073486, 62.32818849384785, 62.90716342628002, 65.93071818351746, 64.41857412457466, 67.7537539601326, 60.836540535092354, 67.41077676415443, 66.18637606501579, 68.82515206933022, 66.19366407394409, 67.7237431704998, 64.30990755558014, 68.02159398794174, 60.37687540054321, 64.04503896832466, 60.544761791825294, 72.13339895009995, 67.86198735237122, 84.14558798074722, 2.8850213158875704, 0.12478543765610084, 0.24786239198874682, 8.62922865897417, 79.91598173975945, 65.34751787781715, 65.6721268594265, 46.84826374053955, 40.302415788173676, 48.11374023556709, 68.51374357938766, 52.83195085823536, 2.536800163798034, 0.1983056589961052, 0.09077701761270873, 0.06023418973200023, 0.030905940329830628, 0.13005035201786086, 0.07451418714481406, 0.19546554889529943, 0.19498876354191452, 0.08675631383084692, 0.13610093359602615, 0.12543403019662946, 0.14984553825343028, 0.2359931351384148, 0.20607686543371528, 0.9939316066447645, 47.399883940815926, 65.95480889081955, 57.12080731987953, 45.577938705682755, 62.56209634244442, 58.292668238282204, 62.46843136847019, 86.85756325721741, 19.933627769351006, 0.7250947854481637, 1.5393586736172438, 0.38588128751143813, 6.209210716187954, 80.85570931434631, 73.21251824498177, 74.01489078998566, 69.87907111644745, 67.95644268393517, 66.0478051006794, 65.7532449066639, 62.73029051721096, 63.38729426264763, 55.32402813434601, 54.94900345802307, 54.67853397130966, 52.232840806245804, 52.917742654681206, 50.71869045495987, 50.51387004554272, 52.06360548734665, 48.848009034991264, 46.069639921188354, 48.56566898524761, 50.49016311764717, 48.86024057865143, 48.36059398949146, 49.55050773918629, 52.03644834458828, 56.934453919529915, 59.479458555579185, 64.49871942400932, 59.28791843354702, 59.20852929353714, 63.74105907976627, 60.71848087012768, 61.950047984719276, 57.47563607990742, 56.846070662140846, 53.591872081160545, 49.230333119630814, 56.89003810286522, 56.731377616524696, 51.88355594873428, 47.53083251416683, 46.903869956731796, 48.60646739602089, 45.959012657403946, 47.03221186995506, 45.125443786382675, 44.19211886823177, 49.07893784344196, 47.96948857605457, 48.53029668331146, 50.01567877829075, 48.732183650135994, 49.00553338229656, 50.49646697938442, 55.292227640748024, 55.16003653407097, 50.90444728732109, 56.27202406525612, 50.90448148548603, 58.33556793630123, 56.36407032608986, 57.00868293642998, 60.82081317901611, 60.44158212840557, 60.25422178208828, 39.816957637667656, 31.237371414899826, 38.13446871936321, 40.576555877923965, 46.50842897593975, 57.40708775818348, 62.64704078435898, 58.32635723054409, 58.993073254823685, 56.568567752838135, 58.0846332013607, 51.63800552487373, 52.27406479418278, 54.1513654589653, 54.41428855061531, 47.728167325258255, 50.38581691682339, 50.00928372144699, 49.51161302626133, 47.07003504037857, 47.891851142048836, 49.587962329387665, 45.87705485522747, 42.967129200696945, 44.67039920389652, 43.175000846385956, 43.71391452848911, 44.05843444168568, 45.01554988324642, 47.56523206830025, 50.82220070064068, 52.24774740636349, 52.697206288576126, 48.43714468181133, 50.300321504473686, 51.77300088107586, 58.37751008570194, 62.70111568272114, 62.01896108686924, 61.07090815901756, 62.925945818424225, 61.56501464545727, 52.493081241846085, 48.566976115107536, 47.9042536765337, 48.48387457430363, 47.88025416433811, 52.023726627230644, 50.45966595411301, 53.063065856695175, 61.2279537320137, 64.26747143268585, 64.64568793773651, 70.74205040931702, 66.82526618242264, 71.44805252552032, 64.85828652977943, 69.58537727594376, 69.01308998465538, 72.38003611564636, 70.13206154108047, 70.47351881861687, 66.03221833705902, 69.98538941144943, 64.13649246096611, 67.5926274061203, 65.58587908744812, 75.77019900083542, 73.2500222325325, 88.65750387310982, 3.315018592402339, 0.22032877255696803, 0.22497075784485787, 10.30329817906022, 87.81947404146194, 70.7608214020729, 72.17198207974434, 56.02707400918007, 64.48298066854477, 63.57402764260769, 79.50815722346306, 67.01486080884933, 4.03958223760128, 0.4971079097595066, 0.30124522279947996, 0.1875892246607691, 0.08593560982262716, 0.2163605683017522, 0.13303267245646566], [0.11982815834926441, 0.030061869802011643, 0.004657615845644614, 0.04751581946038641, 0.04740313917864114, 0.03766864785575308, 0.13071006193058565, 0.17869698931463063, 1.0425753495655954, 26.183986477553844, 43.75419616699219, 41.50124005973339, 18.959838822484016, 44.92874354124069, 42.85033106803894, 47.73900434374809, 71.30617573857307, 26.333580650389194, 0.13640267599839717, 0.06828299650806002, 0.25429075642023236, 0.39210015849675983, 53.93820829689503, 76.67560681700706, 65.13349816203117, 64.76494073867798, 59.52570207417011, 61.82159587740898, 60.587304309010506, 61.870658844709396, 55.865084901452065, 54.64627370238304, 50.30018091201782, 49.45474147796631, 46.78597368299961, 46.6465325653553, 43.63542214035988, 42.94080801308155, 45.384361892938614, 44.0946388989687, 42.061941772699356, 42.53897577524185, 42.45699517428875, 41.2909821420908, 40.82047998905182, 47.689014226198196, 49.00690130889416, 55.21197974681854, 54.99488219618797, 57.28711299598217, 49.036672711372375, 65.91573938727379, 67.34474390745163, 56.27411015331745, 61.307217478752136, 53.259644508361816, 49.50521416962147, 45.508695021271706, 47.187509536743164, 56.16789065301418, 53.39695394039154, 51.26985847949982, 46.33948244154453, 43.35160776972771, 38.72817546129227, 42.54706174135208, 40.71353852748871, 38.841546177864075, 40.238503217697144, 41.82181365787983, 41.91642478108406, 39.9383345246315, 42.78907835483551, 45.27248449623585, 43.74315395951271, 42.19658374786377, 46.73918679356575, 46.81378439068794, 47.36360728740692, 50.87143085896969, 48.14698085188866, 50.62004774808884, 52.97961473464966, 55.543523356318474, 52.50507339835167, 56.812583059072495, 56.547722071409225, 37.276368364691734, 31.34471755474806, 36.025198101997375, 35.11234648525715, 47.917902544140816, 56.8406293541193, 53.186969608068466, 53.802194595336914, 54.92194510996342, 50.035004541277885, 52.94135458767414, 50.015340596437454, 47.17460162937641, 47.12633281946182, 49.15638908743858, 48.01390819251537, 43.785639479756355, 43.48433844745159, 41.75142623484135, 42.526235058903694, 41.9343826174736, 41.989274471998215, 43.42503122985363, 40.19075497984886, 40.93740351498127, 39.34420220553875, 40.35057820379734, 39.04770411550999, 45.42878910899162, 44.40743811428547, 47.088141068816185, 48.92608344554901, 46.88653528690338, 43.64512301981449, 44.72434490919113, 50.51072761416435, 55.386793166399, 57.263390868902206, 56.92765608429909, 55.07844731211662, 57.11442366242409, 59.23462249338627, 56.17215782403946, 52.0115102827549, 45.109340250492096, 42.90343701839447, 42.71205648779869, 44.35634225606918, 43.7485458701849, 44.536285400390625, 47.55339190363884, 52.8163792937994, 54.86005023121834, 61.24002568423748, 60.869203582406044, 64.9026757478714, 59.36200685799122, 63.230852857232094, 63.38138557970524, 64.52572077512741, 65.52529513835907, 67.85396978259087, 62.254115268588066, 66.59688323736191, 59.46107514202595, 63.14382992684841, 57.86882758140564, 68.54692339897156, 67.53456652164459, 74.51350763440132, 0.9202980890404433, 0.11798139064921997, 0.5666939320508391, 12.34535800293088, 74.54385280609131, 52.84148834645748, 43.740961477160454, 34.92164991796017, 56.6305386275053, 52.19652235507965, 57.967721074819565, 48.89384977519512, 3.685813620686531, 0.11308054425171576, 0.0941810486256145, 0.0388863860280253, 0.018005192832788453, 0.06075491393858101, 0.04055807366967201, 0.11027243555872701, 0.03180811916536186, 0.0184530437036301, 0.01562420125992503, 0.05915995323448442, 0.05415142120909877, 0.15966642298735678, 0.124454929609783, 1.5997206908650696, 38.01839254796505, 60.636868849396706, 47.409573420882225, 31.63892436772585, 57.15519167482853, 51.67842775583267, 58.87939855456352, 75.78503340482712, 29.91773072630167, 0.1744056391180493, 0.17334674281300977, 0.36625157052185386, 0.44556937529705465, 55.596047937870026, 76.80164605379105, 66.42324015498161, 66.2625315785408, 63.09756740927696, 64.81817588210106, 62.2773814201355, 63.92082363367081, 57.10463538765907, 57.739311531186104, 52.314202040433884, 53.10224935412407, 50.162362307310104, 49.15947452187538, 47.75545746088028, 46.53756581246853, 47.264953181147575, 45.51303058862686, 45.51678478717804, 46.19480140507221, 46.02353319525719, 45.283614099025726, 43.86047646403313, 48.485717475414276, 52.0997529476881, 55.929939821362495, 58.4037970751524, 60.21192625164986, 52.40429140627384, 64.57522451877594, 67.353126257658, 58.97580698132515, 62.318506613373756, 56.44487299025059, 51.795978248119354, 48.90605092048645, 50.19892394542694, 58.190651312470436, 54.53059270977974, 54.40926901996136, 49.75115217268467, 45.93489535152912, 41.190055757761, 43.38216193020344, 42.65717603266239, 43.35935555398464, 42.6895122975111, 45.27419060468674, 44.13286864757538, 45.4518386721611, 43.68372514843941, 47.43644937872887, 45.804022774100304, 44.094654098153114, 47.84475266933441, 48.981294482946396, 48.244753405451775, 53.80964979529381, 48.98615822196007, 52.758766785264015, 54.55933436751366, 57.16350182890892, 56.507246643304825, 59.845610707998276, 59.35492783784866, 39.15631368756294, 30.57623539119959, 36.09023921191692, 34.6131406724453, 47.12580844759941, 57.018353417515755, 54.244262874126434, 55.66610477864742, 56.27982884645462, 51.38992063701153, 55.13107068836689, 51.05355888605118, 48.309102952480316, 49.15646128356457, 50.15453092753887, 50.53736798465252, 45.15512019395828, 44.6444845944643, 44.130189791321754, 43.38783502578735, 43.02444912493229, 43.87509427964687, 42.99636863172054, 41.33169315755367, 42.93157450854778, 40.84680117666721, 42.712634056806564, 41.887531131505966, 46.72410920262337, 46.82396024465561, 48.49230632185936, 53.91509413719177, 50.077752247452736, 45.95619320869446, 46.911655738949776, 53.81380297243595, 55.65492197871208, 59.94412422180176, 58.944933637976646, 56.146778985857964, 58.82576443254948, 59.55342158675194, 58.18947337567806, 53.48558038473129, 46.9600423425436, 45.099058002233505, 45.10647140443325, 46.89090505242348, 46.39158524572849, 47.849111035466194, 48.93523335456848, 55.375279784202576, 56.738734021782875, 62.92404592037201, 64.11351129412651, 66.75558552145958, 63.65854270756245, 66.39234781265259, 65.91191679239273, 66.71616643667221, 67.54133015871048, 71.56334593892097, 64.38201248645782, 70.81399574875832, 63.163452073931694, 67.51252010464668, 62.948516607284546, 73.39761391282082, 69.99914467334747, 80.75825214385986, 1.0992784006521106, 0.1268821384292096, 0.5390726798214018, 15.601452682167292, 81.24116823077202, 62.44693972170353, 55.031242445111275, 41.25679537653923, 51.756422370672226, 47.86513477563858, 68.48519191145897, 60.26284731924534, 5.136343985795975, 0.21704704005969688, 0.14134496392216533, 0.039816490025259554, 0.016154478762473445, 0.1213646712130867, 0.006936260615475476, 0.21991645015077665, 0.22376785520464182, 0.16282761585898697, 0.18856718234019354, 0.18400151951937005, 0.13185066869482398, 0.22240582125959918, 0.31082056055311114, 1.8454973213374615, 51.56943820416927, 72.67856329679489, 58.101717084646225, 29.719508662819862, 61.081475391983986, 59.14090432226658, 61.620115488767624, 86.6574963927269, 33.66324484348297, 0.4398785869125277, 0.3603727219160646, 0.6508343014866114, 0.5722244165372103, 60.60491256415844, 81.32061436772346, 69.95169281959534, 69.31999951601028, 67.54581391811371, 66.7971020936966, 65.88638976216316, 68.98407474160194, 63.117523938417435, 61.02531440556049, 55.92782333493233, 55.326349809765816, 52.25625514984131, 53.45532640814781, 51.01092517375946, 48.169635236263275, 50.763079673051834, 48.59674371778965, 46.96869447827339, 48.579880222678185, 49.93072673678398, 47.42204815149307, 44.45221111178398, 52.956131994724274, 54.62208800017834, 58.831912502646446, 60.05252480506897, 62.4126997590065, 54.63106691837311, 62.88925498723984, 67.17325910925865, 61.69139966368675, 64.42236632108688, 60.551776215434074, 55.590481236577034, 51.33281350135803, 51.529840528964996, 62.86933645606041, 58.78441125154495, 55.8050899207592, 52.66236215829849, 48.083607852458954, 43.237488493323326, 48.07026296854019, 44.83855538070202, 43.83706592023373, 44.89576891064644, 47.03399017453194, 47.344110533595085, 47.170034274458885, 45.601239055395126, 49.28928315639496, 48.52583572268486, 45.64277462661266, 51.33874498307705, 51.82752035558224, 52.734482288360596, 55.21965533494949, 51.91215701401234, 56.338151916861534, 58.77870015799999, 60.468040108680725, 58.30499477684498, 61.71419844031334, 61.11747086048126, 39.94734384119511, 32.238625288009644, 36.098454371094704, 34.681730791926384, 48.66965800523758, 61.23441718518734, 55.87429940700531, 58.45719940960407, 61.29999026656151, 56.41365386545658, 59.058809727430344, 54.403204545378685, 50.79551853239536, 51.93008065223694, 55.015199705958366, 55.06000690162182, 48.029586151242256, 46.466456428170204, 46.476028114557266, 45.89960664510727, 45.61422675848007, 47.13153474032879, 46.57075323164463, 43.44926252961159, 46.14526726305485, 44.12856347858906, 46.119101867079735, 43.473691418766975, 48.538093864917755, 49.29870665073395, 52.04107649624348, 54.90012288093567, 52.66281433403492, 49.10667635500431, 48.40260073542595, 55.37792444229126, 58.412806391716, 63.383673056960106, 61.205987110733986, 58.516575023531914, 61.93294130265713, 64.13557291030884, 61.7751357704401, 57.101447358727455, 49.83914405107498, 48.000703901052475, 47.54983529448509, 50.41192911565304, 49.02818016707897, 49.71744418144226, 51.52458541095257, 57.646889090538025, 60.40279000997543, 67.2816064953804, 67.20178797841072, 68.64735960960388, 64.98956948518753, 67.77848303318024, 69.66002807021141, 69.4629554450512, 69.7753518819809, 73.42554241418839, 66.92730590701103, 73.90354916453362, 65.32164126634598, 71.29086256027222, 65.28001070022583, 76.98643013834953, 74.40880045294762, 85.86670562624931, 1.6035578912124038, 0.34566498768981546, 0.5052241554949433, 15.93305328860879, 90.42761608958244, 67.56446331739426, 59.06411424279213, 54.54850874841213, 71.97640657424927, 71.71461582183838, 78.6284664273262, 74.68714311718941, 8.313739188015461, 0.3242159105138853, 0.2020967868156731, 0.09546932793455198, 0.10360079511883669, 0.20531362592009827, 0.09989556347136386], [0.04546044518065173, 0.055116491494118236, 0.021981623794999905, 0.054034889180911705, 0.020589159939845558, 0.12668394047068432, 0.015117228122107917, 0.073249537817901, 1.5201327740214765, 35.787973031401634, 43.38726505637169, 45.86844451725483, 26.427333019673824, 32.853056117892265, 37.840907871723175, 42.7362459897995, 67.56520807743073, 49.80426572263241, 1.28833879949525, 0.20645213982788846, 0.6957478914409876, 0.7032837183214724, 24.387418180704117, 83.36146205663681, 65.38454309105873, 67.17301592230797, 59.491994082927704, 60.9495160728693, 54.47008475661278, 56.36999040842056, 54.722733199596405, 53.78463193774223, 48.281558230519295, 48.444273099303246, 47.60554030537605, 46.595368310809135, 46.799341365695, 44.01948653161526, 44.19056475162506, 44.21002350747585, 43.7907388061285, 45.234288945794106, 41.69318675994873, 42.80557706952095, 43.3008348941803, 46.09183833003044, 50.1284871250391, 54.083751887083054, 54.59621138870716, 57.45001405477524, 50.62997281551361, 63.30269940197468, 54.64509956538677, 59.339314475655556, 60.25066517293453, 52.63379529118538, 51.532713174819946, 45.65396122634411, 48.69702033698559, 55.274657383561134, 51.34954400360584, 51.937125474214554, 49.40668545663357, 48.462135940790176, 39.55471470952034, 41.98458932340145, 40.32752104103565, 41.258205100893974, 39.249511286616325, 40.57683706283569, 40.395472794771194, 41.1377439647913, 42.64933705329895, 44.748135432600975, 43.51131699979305, 43.236622139811516, 44.26359303295612, 47.109750509262085, 47.59084649384022, 48.30338045954704, 46.91141255199909, 49.72224332392216, 50.04383906722069, 51.599547788500786, 56.06435000896454, 56.57374307513237, 60.44788978993893, 39.8747943341732, 30.852157585322857, 34.592139199376106, 33.59152369201183, 48.308046609163284, 56.411556378006935, 55.86600825190544, 54.31526966392994, 54.75080609321594, 51.080362647771835, 51.06542944908142, 50.04874840378761, 49.74798694252968, 48.557841405272484, 48.14597390592098, 44.08993475139141, 42.75369465351105, 45.50130821764469, 43.80646616220474, 42.96396777033806, 41.95526249706745, 41.54654882848263, 41.59252256155014, 41.19793273508549, 40.18027514219284, 40.59423252940178, 39.196937307715416, 40.52735611796379, 44.002292454242706, 44.722213223576546, 48.2925396412611, 52.174821719527245, 48.27953293919563, 45.24031542241573, 46.43465593457222, 49.35883082449436, 56.42438068985939, 56.75716683268547, 56.54523700475693, 58.686159923672676, 54.18181322515011, 55.307020246982574, 55.8954718708992, 59.3117431551218, 52.85307392477989, 43.68564024567604, 40.823725014925, 42.2711281478405, 40.19042819738388, 44.07974749803543, 42.30232447385788, 46.01170442998409, 48.39255787432194, 54.68927599489689, 58.42744700610638, 62.434449791908264, 60.90807929635048, 63.285117745399475, 63.104163855314255, 62.82369330525398, 61.47915065288544, 67.22856134176254, 61.44304879009724, 67.17699810862541, 61.21284954249859, 63.990838676691055, 58.63439530134201, 70.39813086390495, 70.58997496962547, 63.70834283530712, 0.09646937192883343, 0.2941717836074531, 0.6844522850587964, 23.718431778252125, 69.88333448767662, 61.02038227021694, 40.15966884791851, 65.35722255706787, 87.1592366695404, 39.570248275995255, 53.95430043339729, 54.30101662874222, 6.212034914642572, 0.33645505376625806, 0.10026094503700733, 0.022229627284104936, 0.03650768027000595, 0.05162101304449607, 0.006414027993741911, 0.0016543244009881164, 0.05289433065627236, 0.06483332341304049, 0.05574972528847866, 0.05827655259054154, 0.12706626526778564, 0.015252001212502364, 0.07781439911923371, 1.5538227162323892, 51.68716348707676, 53.11465948820114, 63.591852486133575, 32.61440992355347, 37.547628208994865, 45.62567174434662, 51.17015942931175, 71.89175471663475, 52.87039339542389, 1.5639695967547596, 0.25093179603572935, 1.1912471218965948, 0.6892440060619265, 27.2603490203619, 82.7340093255043, 67.76220470666885, 70.91864973306656, 59.96209345757961, 63.44438619911671, 57.467538714408875, 59.041877835989, 58.54353077709675, 55.39045237004757, 50.55542081594467, 51.861167550086975, 50.95879577100277, 48.239676877856255, 47.73233950138092, 46.08772315084934, 47.68749810755253, 46.23338833451271, 44.70014400780201, 46.97714522480965, 45.26730917394161, 46.369128450751305, 45.522533878684044, 46.794527024030685, 52.266628593206406, 56.156814247369766, 58.36344324052334, 58.185008615255356, 52.21207492053509, 59.403542429208755, 59.37407501041889, 59.877217411994934, 63.12144912779331, 55.26918947696686, 53.895810171961784, 49.12566393613815, 51.4170777797699, 61.835662722587585, 54.613648653030396, 55.170056596398354, 51.53597339987755, 49.10069927573204, 42.151749953627586, 45.78768365085125, 44.730538576841354, 42.747071608901024, 41.563970893621445, 42.30578988790512, 42.49467775225639, 43.16001445055008, 42.44656093418598, 46.34719982743263, 43.281357139348984, 43.28578770160675, 46.18847854435444, 49.70965839922428, 48.78828004002571, 51.51386618614197, 49.51445147395134, 53.97559069097042, 53.759473487734795, 54.645240157842636, 57.71416448056698, 56.91509395837784, 59.925075843930244, 39.965829849243164, 30.99229596555233, 35.60513824224472, 32.764558866620064, 48.698270469903946, 58.41564103960991, 58.20176191627979, 55.76807610690594, 56.7287215590477, 53.726571053266525, 51.98613904416561, 51.32038436830044, 52.85924859344959, 49.64380793273449, 48.0809061974287, 45.743294432759285, 44.172234535217285, 45.193513333797455, 46.39245919883251, 44.2664884775877, 44.640232622623444, 42.90111534297466, 43.47304925322533, 42.769566401839256, 42.42851570248604, 43.92500840127468, 41.62355549633503, 42.60831445455551, 45.78797623515129, 48.0294493585825, 50.567462369799614, 55.11549532413483, 48.70707459747791, 48.32930266857147, 48.34494262933731, 51.89435116946697, 56.542121171951294, 60.48493780195713, 59.310527220368385, 58.67530010640621, 54.2721875756979, 59.40980449318886, 58.060128316283226, 59.95208099484444, 54.63564947247505, 44.87082324922085, 44.11737307906151, 44.401654824614525, 42.91387885808945, 45.8749383687973, 45.08557252585888, 50.12392356991768, 50.450884625315666, 56.59106254577637, 60.680334717035294, 64.28583204746246, 65.39749279618263, 67.54828378558159, 66.8843150138855, 65.80026358366013, 63.65432493388653, 70.50148531794548, 66.11185446381569, 69.15413081645966, 64.70384001731873, 68.51578786969185, 61.37379750609398, 75.69247797131538, 74.98781338334084, 67.22384199500084, 0.10226801663520746, 0.17604474647669122, 0.7549871876835823, 27.33786106109619, 76.59540832042694, 67.7915695309639, 44.55675110220909, 72.5333122909069, 86.86099827289581, 39.35994856059551, 63.6577333509922, 65.8644649386406, 9.374772403389215, 0.5016045528464019, 0.0944075669394806, 0.10605474351905286, 0.07069865008816123, 0.05005638762668241, 0.028558490121213254, 0.15236823179293424, 0.194529507716652, 0.2664573770016432, 0.13047489017480984, 0.18309486738871783, 0.281862611300312, 0.09891977286315523, 0.1638321572681889, 2.200697986409068, 62.668946608901024, 65.07745116949081, 65.86966305971146, 36.93362295627594, 47.99060024321079, 55.41977159678936, 54.915151074528694, 79.26315397024155, 61.97389930486679, 2.0790812373161316, 0.24608395382529125, 2.036425438709557, 0.5225455260369927, 29.695740938186646, 88.61930072307587, 71.71238154172897, 72.9159365594387, 64.5444917678833, 66.76522940397263, 60.33929541707039, 62.580992728471756, 60.38803920149803, 58.56114283204079, 54.822189062833786, 55.66254436969757, 53.102845922112465, 52.13632598519325, 52.99438454210758, 50.322968289256096, 49.42351095378399, 50.067067220807076, 47.97920845448971, 50.9949242323637, 47.066128849983215, 49.837783724069595, 48.17174792289734, 49.225438982248306, 55.13074390590191, 60.09024918079376, 59.50773283839226, 62.031116634607315, 51.921778097748756, 57.994707226753235, 63.499464243650436, 63.095504119992256, 65.71547493338585, 58.34921680390835, 58.11349645256996, 51.4772779494524, 54.59076248109341, 62.41359271109104, 57.85341180860996, 59.514925852417946, 54.334766417741776, 51.86153993010521, 43.695857897400856, 49.01407152414322, 46.26350171864033, 45.986333191394806, 44.012263119220734, 43.131823763251305, 44.35938209295273, 45.77120013535023, 45.860700532794, 50.03728821873665, 47.7214302867651, 45.8162847161293, 48.37645813822746, 51.288097500801086, 51.35865971446037, 52.85715490579605, 52.91042424738407, 55.59959314763546, 56.36233761906624, 56.38168618083, 60.01402907073498, 60.81543266773224, 65.09280994534492, 40.3633227199316, 31.26379519701004, 35.32774932682514, 31.693354547023773, 49.994297325611115, 62.06208497285843, 59.24522392451763, 59.33516889810562, 60.60106337070465, 54.98316742479801, 55.53037986159325, 53.74531924724579, 55.85451006889343, 52.68212869763374, 53.21413815021515, 47.54156693816185, 47.34092630445957, 49.005913361907005, 50.10947294533253, 47.070502415299416, 46.98474861681461, 45.7866957038641, 45.52809298038483, 45.72795085608959, 44.517924785614014, 46.80830888450146, 44.533473551273346, 43.65499868988991, 46.44600212574005, 48.92310440540314, 53.513254299759865, 57.631059139966965, 52.07358755171299, 50.91405317187309, 51.741466373205185, 53.01957719027996, 60.89196436107159, 61.10176630318165, 61.89324103295803, 59.625040143728256, 57.80026026070118, 58.86750899255276, 60.14860264956951, 64.63791355490685, 57.150616720318794, 48.47398370504379, 48.011586517095566, 46.993412151932716, 45.00715613365173, 49.18377801775932, 48.37334230542183, 52.405666932463646, 53.170520290732384, 61.10443376004696, 63.71593862771988, 68.83092775940895, 67.88088753819466, 69.47844341397285, 70.9270016849041, 69.1695199906826, 66.39271259307861, 75.58086276054382, 68.79870548844337, 74.62082147598267, 67.78926685452461, 74.14371147751808, 65.15974715352058, 78.39939191937447, 77.19266787171364, 74.0919354557991, 0.1520780668943189, 0.5791316146496683, 0.7487074309028685, 29.155736714601517, 88.4137013554573, 75.9906479716301, 57.106189504265785, 82.09691271185875, 105.12319833040237, 57.752971798181534, 73.93802851438522, 80.64794406294823, 11.785078067332506, 0.5177444836590439, 0.15703467826824635, 0.19846666051307693, 0.12829806713853031, 0.18463371059624478, 0.24513526645023376], [0.06947819565539248, 0.05947580015345011, 0.06455987168010324, 0.0894769084698055, 0.0940864544827491, 0.04214940156089142, 0.00519927325512981, 0.04455921443877742, 0.9663398622069508, 41.02072164416313, 50.80031767487526, 33.91381859779358, 38.02372746169567, 53.838152065873146, 36.505416333675385, 45.426011458039284, 57.50193066895008, 64.5084697008133, 10.649167969822884, 0.8427533344365656, 0.44224675046280026, 0.9500856406521052, 4.131518304347992, 74.77187857031822, 68.48951607942581, 64.76405918598175, 57.39169478416443, 54.00978125631809, 52.17673681676388, 49.12589572370052, 49.6041988581419, 47.240778878331184, 46.960046142339706, 46.072109788656235, 46.56854934990406, 45.301465541124344, 47.7487014234066, 44.71744067966938, 44.13452535867691, 42.95253038406372, 46.21359899640083, 40.900370702147484, 42.72560276091099, 43.35049822926521, 46.08234263956547, 47.33695551753044, 52.18873657286167, 52.22476623952389, 55.57343915104866, 52.14655123651028, 55.58542750775814, 54.24651235342026, 42.040032148361206, 59.66210335493088, 56.448900774121284, 54.90276753902435, 50.30791349709034, 47.6419385522604, 52.78076380491257, 55.36782458424568, 46.59061476588249, 51.62161320447922, 43.40383216738701, 48.44571702182293, 41.89710281789303, 37.028203681111336, 38.54046553373337, 41.00567065179348, 41.200812980532646, 40.19547052681446, 38.62839661538601, 38.53495582938194, 42.60134182870388, 42.190131694078445, 44.118425622582436, 43.707793056964874, 45.99349960684776, 45.14711022377014, 45.813404470682144, 45.03709852695465, 44.42645609378815, 49.05228607356548, 50.912073478102684, 53.94476294517517, 54.45614330470562, 52.70039051771164, 56.48508623242378, 40.44138953089714, 31.942001804709435, 36.57907538115978, 33.04157540202141, 49.96926806867123, 58.61190430819988, 56.96535766124725, 54.54921931028366, 55.77599108219147, 50.62120668590069, 46.47324286401272, 48.14299486577511, 48.11470918357372, 47.53539226949215, 47.204300835728645, 44.48871195316315, 43.84211204946041, 43.71224641799927, 44.296404272317886, 42.72574335336685, 39.44484740495682, 40.1198735833168, 42.03828044235706, 42.1465328335762, 44.258630499243736, 41.915159448981285, 38.97399187088013, 42.493632808327675, 47.848229482769966, 47.245676815509796, 50.198266580700874, 53.67400847375393, 53.567184805870056, 47.56473429501057, 47.22174949944019, 48.12896981835365, 54.83257010579109, 57.05754451453686, 58.19548465311527, 58.77522714436054, 53.687623143196106, 52.78728045523167, 63.78144711256027, 59.092057943344116, 60.04875160753727, 52.96052075922489, 43.36076907813549, 43.15827414393425, 43.25882434844971, 43.019137009978294, 41.82214044034481, 45.790955275297165, 45.82721672952175, 47.90449306368828, 49.21913892030716, 53.58768470585346, 58.50366331636906, 59.1177711635828, 59.53457459807396, 59.35299374163151, 58.42791058123112, 60.80803066492081, 63.35266292095184, 60.57161495089531, 60.10658070445061, 59.7682848572731, 63.050962910056114, 65.86334019899368, 76.11894428730011, 44.14308249950409, 0.22928245773073286, 0.3300656075589359, 0.34945762949064374, 37.86350905895233, 68.8358598947525, 59.675041660666466, 44.79123272001743, 51.3049153983593, 60.518676191568375, 44.29682984948158, 52.89709076285362, 61.465197801589966, 9.155608713626862, 0.358023022999987, 0.055451422740588896, 0.1498408627230674, 0.030635533257736824, 0.0325411421363242, 0.05442800480523147, 0.03813356255705003, 0.10618702392093837, 0.020866225931968074, 0.04218274254526477, 0.12052283083903603, 0.05188606366573367, 0.03606285921705421, 0.1131202417309396, 1.1885717092081904, 54.11522559821606, 56.72048360109329, 46.74167945981026, 25.90084847062826, 53.82706806063652, 44.544671550393105, 50.17199859023094, 65.3688271343708, 70.92440262436867, 12.652990445494652, 0.9696507907938212, 0.7490988099016249, 0.722302885260433, 4.772211899980903, 78.05601954460144, 70.22262588143349, 67.51310527324677, 58.0035113543272, 56.24147370457649, 54.23031762242317, 50.84106668829918, 53.252671882510185, 50.780437141656876, 50.00245548784733, 48.91281455755234, 50.47027878463268, 47.738859951496124, 48.67090433835983, 48.06091167032719, 47.29341745376587, 44.626496359705925, 48.784218057990074, 43.27357895672321, 47.491132244467735, 45.343115106225014, 49.89156983792782, 49.59274247288704, 53.66390861570835, 54.806932881474495, 58.376457542181015, 56.199782341718674, 52.617687955498695, 54.385497495532036, 46.514839231967926, 61.55872218310833, 58.931907936930656, 58.37180659174919, 54.29318144917488, 50.92919535934925, 53.27062971889973, 57.44082614779472, 51.385030299425125, 54.60518270730972, 46.121613532304764, 50.58128982782364, 43.43651421368122, 40.76153755187988, 42.111384719610214, 41.89723201096058, 42.676695585250854, 41.920741349458694, 40.69922849535942, 40.27395911514759, 45.25436706840992, 44.29976709187031, 48.31910401582718, 44.86003942787647, 47.905116230249405, 47.285662069916725, 47.64215134084225, 46.12228609621525, 48.466661497950554, 51.515621691942215, 53.86313572525978, 54.95627246797085, 56.08361877501011, 56.79048344492912, 58.486613631248474, 41.29434876143932, 31.54173318296671, 36.029005497694016, 31.987838745117188, 51.72264978289604, 59.20139707624912, 59.66257452964783, 58.43337468802929, 55.758831202983856, 53.26103903353214, 48.05053062736988, 50.86761586368084, 50.92094600200653, 47.987112030386925, 47.531212493777275, 46.59438416361809, 45.97660571336746, 45.00082567334175, 44.67704504728317, 43.559160232543945, 40.640286058187485, 40.12931227684021, 43.57509657740593, 41.1087629199028, 44.86488036811352, 44.05503362417221, 41.6117799282074, 43.24834071099758, 48.23722220957279, 49.45690356194973, 53.82898695766926, 56.99551664292812, 59.57655854523182, 51.570631340146065, 49.423233568668365, 48.54674220085144, 56.512022987008095, 59.55616503953934, 61.78730271756649, 60.36667674779892, 56.56341142952442, 52.39082112908363, 62.58281663060188, 62.840081825852394, 61.753701120615005, 55.47292694449425, 45.79043470323086, 43.99270176887512, 43.71057450771332, 47.35416479408741, 44.44292061030865, 48.410812094807625, 48.03767591714859, 51.41501449048519, 52.27032199501991, 56.65696240961552, 61.46847702562809, 61.800924986600876, 63.23285534977913, 61.82107150554657, 59.87553410232067, 63.03724564611912, 66.01091668009758, 63.708411231637, 64.72940504550934, 61.503982320427895, 66.04988738894463, 69.79256495833397, 80.19423320889473, 46.47076919674873, 0.32969548366963863, 0.26306050771381706, 0.19670738460263237, 45.351949632167816, 75.46385943889618, 66.57962456345558, 47.80031405389309, 66.80293098092079, 74.20742645859718, 54.0907397121191, 62.93373920023441, 73.57821062207222, 13.289020266383886, 0.44484337675385177, 0.15517006191657856, 0.060386912591638975, 0.016719323648430873, 0.09525731118628755, 0.039740360516589135, 0.20221805374603719, 0.16912110237171873, 0.189147423079703, 0.19480674440274015, 0.27602532296441495, 0.23121688049286604, 0.14758424396859482, 0.25231530773453414, 1.6642362414859235, 62.63621896505356, 71.25112429261208, 51.119808331131935, 49.915174171328545, 73.81987765431404, 56.956036761403084, 60.59948645532131, 70.45816004276276, 80.33218100667, 13.993968889117241, 0.9714697056915611, 1.0908460593782365, 0.9391497680917382, 6.175026325508952, 84.1014951467514, 72.2405532002449, 72.25545600056648, 61.396877467632294, 59.208457097411156, 57.57915772497654, 55.20847633481026, 55.37483140826225, 53.583349138498306, 53.4757237136364, 50.81167906522751, 53.84749196469784, 50.933511927723885, 52.4039114266634, 51.74495838582516, 49.828956797719, 49.144195541739464, 50.931095257401466, 45.6782229244709, 48.4052187949419, 48.76455791294575, 50.362516567111015, 54.24336992204189, 56.49071753025055, 57.39764526486397, 58.16335737705231, 59.98073525726795, 49.69883278012276, 55.17631486058235, 53.76149117946625, 60.95529556274414, 61.2262362241745, 60.66180311143398, 56.46300561726093, 52.951006069779396, 56.6134737432003, 63.479576110839844, 55.96256487071514, 59.13156442344189, 49.46864493191242, 54.21172522008419, 48.015538305044174, 42.97493778169155, 44.14661630988121, 44.411446899175644, 44.94868867099285, 45.19272297620773, 43.083862736821175, 43.00828479230404, 50.31828694045544, 47.44869612157345, 51.561781615018845, 48.97284373641014, 51.90995693206787, 49.12505976855755, 52.236579805612564, 49.67647857964039, 51.54277503490448, 54.41372998058796, 56.68130770325661, 59.005232602357864, 59.325464218854904, 58.645684495568275, 61.91857807338238, 42.506624311208725, 30.70578183978796, 35.92760033905506, 32.945356965065, 52.62174993753433, 63.53250727057457, 61.910822689533234, 59.81379881501198, 58.64711321890354, 55.19544303417206, 51.1535657197237, 53.20112004876137, 54.81146223843098, 50.74904702603817, 52.58960746228695, 52.01411314308643, 50.20106703042984, 47.35468156635761, 47.69106611609459, 45.676835998892784, 42.29717195034027, 41.318557262420654, 44.682379961013794, 43.782732635736465, 48.809026926755905, 48.784955218434334, 43.045522794127464, 44.63769055902958, 50.78581005334854, 53.20216879248619, 55.52916392683983, 60.82256868481636, 61.79641842842102, 52.781455367803574, 51.91237360239029, 52.21133016049862, 60.02184145152569, 61.53441108763218, 64.56407591700554, 63.05038534104824, 57.47577287256718, 55.92189185321331, 68.38045433163643, 65.63931182026863, 65.25610238313675, 56.62697061896324, 48.090109303593636, 47.48210392892361, 47.30335392057896, 50.00896453857422, 48.67892950773239, 50.18089011311531, 50.95036782324314, 55.19939862191677, 54.7196439653635, 59.80019174516201, 65.4764373600483, 65.28106704354286, 67.70142316818237, 65.75493961572647, 62.80763536691666, 67.20367267727852, 69.9135884642601, 67.35052719712257, 68.16851690411568, 65.06030648946762, 70.08000433444977, 74.48783621191978, 83.61452087759972, 53.01282495260239, 0.26843208353966475, 0.5646670376881957, 0.6457890628371388, 49.523776173591614, 84.87037628889084, 74.52702730894089, 59.10980299115181, 69.08536970615387, 71.2044095993042, 61.65162339806557, 69.87470135092735, 86.30515649914742, 17.569149546325207, 0.6582815456204116, 0.21744975907495245, 0.21911910152994096, 0.15286265057511628, 0.20476433273870498, 0.16801792953629047], [0.007429760526065365, 0.05969724959868472, 0.021257146654534154, 0.06145423598354682, 0.04109055720618926, 0.038800196707597934, 0.04770196865138132, 0.04185092089755926, 0.6988006120081991, 46.48324012756348, 47.73998089134693, 48.27329367399216, 45.93632787466049, 90.14464527368546, 44.13181230425835, 40.72108872234821, 55.88740110397339, 64.26474317908287, 24.01849027723074, 0.6835419370327145, 0.2212282406981103, 0.25681990664452314, 0.031115012607187964, 45.42424455285072, 81.52804523706436, 62.56352126598358, 65.55616468191147, 57.3480199277401, 58.71303588151932, 50.66675864160061, 50.132237523794174, 47.45150037109852, 50.861505791544914, 47.164596766233444, 47.82495193183422, 45.458169132471085, 48.13074432313442, 42.906511053442955, 47.87118025124073, 42.034131065011024, 43.91845755279064, 40.45794904232025, 43.3705535531044, 43.77314954996109, 49.54899542033672, 47.49009869992733, 52.52922110259533, 49.84943389892578, 60.116748958826065, 52.86238722503185, 66.57465443015099, 40.36231577396393, 45.65159015357494, 61.913018971681595, 56.85050882399082, 53.808859437704086, 49.61682938039303, 49.199790358543396, 51.695880219340324, 53.68046432733536, 48.978737220168114, 50.486325323581696, 45.968143567442894, 46.186571046710014, 48.539758175611496, 41.46131940186024, 41.40692912042141, 37.99135319888592, 40.35710245370865, 39.51816067099571, 39.346599876880646, 38.224725276231766, 41.51816435158253, 40.086302384734154, 43.33887845277786, 45.12162499129772, 44.22612324357033, 43.95241633057594, 44.865332543849945, 43.734205439686775, 44.4234124571085, 50.3894305229187, 51.38667941093445, 50.89093901216984, 54.542269483208656, 53.88967350125313, 57.64831781387329, 44.36683349311352, 34.282676205039024, 35.45198746025562, 32.60676473379135, 51.897964775562286, 57.53446452319622, 53.962739780545235, 52.97156296670437, 53.00604611635208, 49.264592081308365, 49.04253579676151, 47.83043883740902, 45.57373233139515, 42.66522780060768, 43.054106533527374, 44.05565299093723, 46.13440744578838, 42.20722317695618, 41.719336956739426, 40.6135430932045, 39.29725952446461, 40.22798918187618, 40.98978750407696, 40.69444455206394, 40.86921237409115, 41.2314697355032, 38.57220143079758, 43.64956118166447, 48.374539241194725, 44.43175680935383, 53.4784671664238, 50.165861919522285, 56.506604477763176, 51.53655856847763, 48.62871900200844, 46.796841099858284, 52.86352336406708, 54.79880131781101, 59.398348107934, 55.715920105576515, 64.74275752902031, 32.41487883031368, 37.857133001089096, 71.83884635567665, 59.30238425731659, 60.92779643833637, 47.87517003715038, 42.21686705946922, 40.39661653339863, 45.93974009156227, 40.38087397813797, 43.36571641266346, 44.46690872311592, 46.63547895848751, 44.91080470383167, 49.405036345124245, 53.499088659882545, 56.18100754916668, 56.62239946424961, 54.89282347261906, 57.6986613124609, 55.60207441449165, 55.05089499056339, 56.62081874907017, 55.69676913321018, 55.97742587327957, 67.46354073286057, 62.547660917043686, 85.63744112849236, 19.01792250573635, 0.5584501556586474, 0.09753571939654648, 0.13578632235294208, 58.14288787543774, 60.83816684782505, 62.11704142391682, 43.5546612739563, 39.58449751138687, 22.148950695991516, 31.877732053399086, 45.04660181701183, 60.58425307273865, 10.351429246366024, 0.4206364491255954, 0.16178129153558984, 0.07666673453059047, 0.09870072797639295, 0.05947924742940813, 0.09115539418417029, 0.008451910780422622, 0.09323846912593581, 0.012467747928894823, 0.07744916598312557, 0.013522947410820052, 0.02675589876162121, 0.09089784667594358, 0.06042675850039814, 1.3680080557242036, 59.175098687410355, 54.400024116039276, 51.72301836311817, 37.67598532140255, 99.29931923747063, 49.725438952445984, 47.6643231511116, 63.694659769535065, 70.37071153521538, 27.915996238589287, 0.5053751380182803, 0.43214116303715855, 0.5107978626620024, 0.2240574560710229, 48.4973980486393, 82.99063995480537, 64.92666006088257, 66.77501007914543, 60.278038904070854, 60.1948157697916, 51.64473496377468, 54.64473098516464, 52.25158520042896, 53.31100635230541, 49.91606332361698, 50.33397249877453, 49.02656905353069, 50.527176931500435, 45.701139494776726, 49.86386552453041, 44.702705070376396, 46.51497982442379, 42.5072056800127, 47.02932022511959, 45.66457025706768, 53.98544356226921, 52.69327349960804, 54.32403579354286, 52.55414396524429, 62.40192353725433, 54.33208376169205, 60.440043210983276, 44.55890938639641, 48.746068105101585, 63.62837992608547, 59.807700142264366, 56.76038905978203, 52.06368528306484, 52.39306680858135, 54.740295857191086, 57.203612476587296, 51.43537759780884, 55.05780681967735, 46.988635808229446, 50.12065954506397, 49.7236492484808, 44.46218557655811, 43.572881296277046, 40.64644172787666, 42.576487362384796, 41.38811632990837, 40.575210750103, 39.93110351264477, 43.005898520350456, 41.96706846356392, 45.79923503100872, 46.650077775120735, 45.33445157110691, 46.25236451625824, 46.47984690964222, 46.69478237628937, 47.302426770329475, 50.330795869231224, 53.46986822783947, 51.68567396700382, 57.5736366212368, 55.427116602659225, 58.514500334858894, 45.17924129962921, 35.32388873398304, 35.02120457589626, 32.16716632246971, 52.838634699583054, 58.50209780037403, 55.863986760377884, 55.469830110669136, 54.78291057050228, 52.40060180425644, 50.15235364437103, 50.297053679823875, 45.44640116393566, 44.45541054010391, 45.78262612223625, 46.73613555729389, 47.20918357372284, 45.41546702384949, 44.315619841217995, 44.457530826330185, 40.39362229406834, 42.37775042653084, 41.80335804820061, 42.39079512655735, 42.67757333815098, 43.48735548555851, 38.964461982250214, 44.975078254938126, 48.26022997498512, 48.370431661605835, 56.96456350386143, 55.388905853033066, 58.34869243204594, 55.46269789338112, 50.769786313176155, 50.30986279249191, 54.55231994390488, 57.45322488248348, 60.381704941391945, 58.288081884384155, 64.59194362163544, 37.39528298377991, 45.30992768704891, 70.28056517243385, 62.734436094760895, 62.58233405649662, 49.66732867062092, 44.693452566862106, 44.01638589799404, 48.31741690635681, 43.23461204767227, 44.56420250236988, 48.14028561115265, 48.82147505879402, 46.561933904886246, 52.42223024368286, 55.940222069621086, 58.1104452162981, 58.916549161076546, 55.89981123805046, 58.83363381028175, 59.145129695534706, 57.51570113003254, 59.84459616243839, 60.04600815474987, 60.25930970907211, 72.58973926305771, 65.0659529864788, 89.84445378184319, 19.974429979920387, 0.8079748100135475, 0.027541100280359387, 0.43747678922954947, 65.61957567930222, 68.67032557725906, 65.93532353639603, 48.029901534318924, 56.226323917508125, 29.384879618883133, 40.884069576859474, 54.79130432009697, 74.75524306297302, 16.09963160008192, 0.3285827371291816, 0.3059328650124371, 0.04996794588805642, 0.10742212834884413, 0.031860581584624015, 0.08600140121416189, 0.07414194813463837, 0.27113421354442835, 0.17030384828103706, 0.19804100913461298, 0.2725632634246722, 0.1475197810214013, 0.09194504673359916, 0.27972252457402647, 2.5324263609945774, 70.89393585920334, 64.3878261744976, 68.85889425873756, 60.498472675681114, 108.8982805609703, 57.41930790245533, 57.50273622572422, 68.90101879835129, 79.19038027524948, 29.534494690597057, 0.7777843612711877, 0.6429170107003301, 0.7686451985500753, 0.46837284229695797, 53.45577858388424, 87.46467188000679, 68.48846733570099, 69.73254337906837, 64.57688882946968, 63.622414246201515, 55.924939289689064, 57.072386518120766, 55.359389036893845, 55.78932076692581, 52.32099607586861, 52.48594522476196, 51.0588064044714, 52.43552953004837, 48.774467781186104, 54.80995371937752, 48.20251107215881, 48.86829614639282, 44.674525782465935, 49.327045530080795, 48.16957823932171, 57.53625802695751, 54.43670354783535, 57.376146018505096, 54.56030711531639, 64.18046370148659, 55.795214250683784, 58.8093189150095, 53.136717304587364, 52.22973257303238, 65.3243163228035, 61.55490718781948, 58.85928623378277, 55.5315387994051, 56.137313693761826, 59.62944030761719, 61.314402893185616, 58.27270410954952, 57.54854276776314, 51.265397518873215, 55.96409618854523, 54.603195413947105, 47.44697481393814, 44.88592743873596, 42.33862392604351, 45.83448573946953, 43.149994388222694, 42.28256173431873, 42.34218433499336, 44.7719943523407, 44.96346987783909, 47.88541428744793, 49.732745960354805, 48.46849299967289, 48.59976075589657, 50.245346054434776, 50.558871030807495, 49.95188020169735, 52.91039764881134, 57.24497325718403, 54.973059967160225, 60.92819541692734, 58.28734092414379, 60.21735616028309, 45.94767026603222, 35.94306170940399, 36.77058130502701, 32.41105243563652, 52.77949087321758, 61.83720164000988, 58.775306940078735, 57.41069756448269, 59.04983080923557, 54.47326898574829, 53.57457160949707, 52.89765693247318, 47.951097562909126, 47.05906122922897, 47.84103646874428, 49.0249465405941, 51.049139723181725, 46.21761918067932, 46.45250357687473, 46.43121711909771, 43.15216787159443, 43.75847093760967, 45.58178409934044, 45.324507504701614, 45.453453585505486, 44.58449341356754, 39.943338856101036, 48.422792851924896, 53.804732859134674, 51.42679765820503, 63.016491159796715, 59.40551072359085, 63.44648748636246, 58.67973066866398, 54.28611762821674, 51.84810385107994, 56.5165713429451, 59.843448624014854, 63.39270897209644, 61.376761347055435, 68.11007604002953, 37.97952823340893, 47.35618628561497, 72.59146437048912, 65.60953661799431, 66.42061829566956, 52.337099611759186, 47.54295386373997, 47.3542445898056, 49.95946079492569, 44.597606509923935, 48.085735738277435, 51.18543840944767, 53.044690042734146, 49.52049694955349, 55.002591982483864, 58.47327634692192, 63.86021688580513, 62.54137225449085, 60.354487001895905, 62.78389424085617, 63.034217208623886, 60.827519819140434, 63.45051907002926, 60.99083885550499, 63.17439928650856, 75.0958263874054, 68.84264633059502, 94.8785300552845, 24.580442123115063, 0.6903350225184113, 0.4056406725430861, 0.3205091500421986, 70.41822418570518, 74.95624467730522, 77.36879602074623, 57.56571784615517, 58.74951772391796, 34.51700963079929, 47.54864975810051, 62.78507977724075, 88.15409168601036, 21.795136481523514, 0.8033110946416855, 0.4173501004697755, 0.09549562964821234, 0.3387047111755237, 0.11567197550903074, 0.2062730595935136], [0.051406402490101755, 0.04170974585576914, 0.049133849825011566, 0.054541957870242186, 0.15698968927608803, 0.07091485997079872, 0.06985939980950207, 0.00570261311622744, 2.521014385856688, 55.313529297709465, 53.2645158469677, 46.58356614410877, 30.09402796626091, 62.681622728705406, 34.46617975831032, 36.74533925950527, 53.832148388028145, 68.06127905845642, 34.94495406746864, 0.046046252027736045, 0.23133413982577622, 0.07469923424650915, 0.8632969914469868, 7.804085835814476, 80.57715386152267, 62.61520989239216, 68.878303617239, 61.79336339235306, 66.41358867287636, 57.762577682733536, 58.78663793206215, 57.444884330034256, 57.66186408698559, 54.688664227724075, 51.763117611408234, 49.464978128671646, 50.02002194523811, 45.66883742809296, 46.9763358682394, 41.815027222037315, 41.97652995586395, 42.31726907193661, 43.899971544742584, 46.527940928936005, 52.15808741748333, 49.025455713272095, 51.61771081387997, 54.23555374145508, 56.868664249777794, 59.66893158853054, 53.175144642591476, 32.28119060397148, 57.05206520855427, 56.79446563124657, 57.447635382413864, 52.76369512081146, 48.93131576478481, 50.394252464175224, 54.65745650231838, 49.06839340925217, 49.13721151649952, 48.63921783864498, 45.054064616560936, 43.667515218257904, 47.596546187996864, 45.22623337805271, 42.111943289637566, 41.89979687333107, 41.28244400024414, 39.91460859775543, 38.38696137070656, 39.88800622522831, 41.5017606317997, 39.74540747702122, 43.94216068089008, 41.894382163882256, 46.04665495455265, 40.96059367060661, 43.62367317080498, 44.07856196165085, 46.64229579269886, 46.25165395438671, 48.63943822681904, 50.287208408117294, 53.312457874417305, 51.81306213140488, 53.844075947999954, 44.91195224225521, 39.59810458123684, 39.39644940197468, 36.459719985723495, 56.20097167789936, 56.244099363684654, 50.37865050137043, 52.30863153934479, 51.66642799973488, 49.51670855283737, 45.293003395199776, 45.91661833226681, 45.88448345661163, 43.72728981077671, 42.87015840411186, 43.91615487635136, 44.30103622376919, 42.4080727994442, 43.58543582260609, 38.003124967217445, 38.282520174980164, 40.56675240397453, 37.74584837257862, 39.83279898762703, 39.76867362856865, 42.36696280539036, 41.125170439481735, 48.338418379426, 45.08556492626667, 46.63463160395622, 48.830096796154976, 48.545811250805855, 55.003648325800896, 54.132142290472984, 49.90691341459751, 53.636660277843475, 48.51099371910095, 52.21384562551975, 56.832512989640236, 57.028730660676956, 60.44731602072716, 55.476080775260925, 35.28683692216873, 44.28804472088814, 61.84636674821377, 59.3479248136282, 55.634669065475464, 48.36475856602192, 43.62887129187584, 42.70716995000839, 43.106843903660774, 41.93401023745537, 43.04437145590782, 44.535282254219055, 45.466657876968384, 45.39102293550968, 49.601151421666145, 51.11099660396576, 53.885812908411026, 49.42132607102394, 51.98122210800648, 53.018707036972046, 52.80885949730873, 51.85926005244255, 58.909207955002785, 62.66376368701458, 69.37468618154526, 64.24458146095276, 76.32921740412712, 3.2626835256814957, 0.37448896444402635, 0.09315508883446455, 1.3009126810356975, 67.55711451172829, 58.7906239181757, 60.64653933048248, 32.94567234814167, 48.907719030976295, 38.80372680723667, 37.04046182334423, 52.95693755149841, 62.401136979460716, 27.363239899277687, 0.23919630388263613, 0.06191932508954778, 0.027161419384356122, 0.12563715601572767, 0.032192562794080004, 0.0953512077103369, 0.0010128516078111716, 0.041261217775172554, 0.02418488398689078, 0.04799527654540725, 0.03834651812212542, 0.08578329143347219, 0.057354170639882796, 0.04894028286798857, 3.187990221194923, 67.45914816856384, 61.33518397808075, 50.64105302095413, 45.12661412358284, 82.0893207192421, 40.22966869175434, 44.65865023434162, 60.774106085300446, 74.64950233697891, 40.554714649915695, 0.09393205065862276, 0.41300844750367105, 0.2805801504291594, 0.9328705456573516, 8.644194155931473, 82.61054635047913, 64.54468175768852, 73.66547673940659, 63.33480387926102, 67.0760603249073, 58.993305042386055, 62.0485083013773, 60.29423363506794, 60.57391382753849, 58.802730068564415, 55.05205772817135, 51.895073130726814, 53.137085884809494, 48.66647757589817, 50.44944830238819, 45.154934003949165, 44.45040240883827, 44.0042607486248, 45.634988844394684, 48.93229231238365, 54.92487095296383, 51.01428799331188, 53.66947531700134, 58.06726433336735, 60.85409939289093, 58.61834116280079, 55.10422892868519, 37.930157482624054, 60.19171513617039, 58.87880198657513, 58.66295076906681, 56.02952107787132, 52.9350621253252, 54.54656325280666, 58.27407963573933, 53.368394672870636, 52.78709426522255, 51.219066604971886, 49.00984615087509, 47.658030688762665, 50.95245011150837, 48.214860409498215, 45.58002859354019, 44.623042345047, 44.79394197463989, 42.79201179742813, 42.18930333852768, 39.97674286365509, 43.69030259549618, 43.69560331106186, 45.33316724002361, 45.93478515744209, 47.48620390892029, 45.021443367004395, 46.81645944714546, 48.02529998123646, 45.787482261657715, 48.71616370975971, 51.619861498475075, 51.189952567219734, 53.36929902434349, 53.430160358548164, 57.13960111141205, 45.658957958221436, 37.97839589416981, 36.608747988939285, 35.931521728634834, 56.63471460342407, 58.73771175742149, 53.01502123475075, 53.31111654639244, 53.511248007416725, 50.158057138323784, 47.521154433488846, 47.56773233413696, 45.79942122101784, 44.60570767521858, 44.4172415882349, 44.45859856903553, 47.350824773311615, 45.663734301924706, 45.64594365656376, 41.23043619096279, 39.09284569323063, 41.217551082372665, 39.63206335902214, 40.64456082880497, 41.92729979753494, 44.693520963191986, 43.91452096402645, 51.5529964864254, 47.974876686930656, 50.90730093419552, 53.223189264535904, 53.15730459988117, 58.40395666658878, 57.623649537563324, 51.87594495713711, 56.32197618484497, 50.38191832602024, 55.91867722570896, 58.77392001450062, 59.98431846499443, 61.90995253622532, 67.98071578145027, 38.97355489432812, 42.947123274207115, 62.83498629927635, 60.96293315291405, 60.023038387298584, 51.11118659377098, 47.34247662127018, 44.33592215180397, 44.93092842400074, 45.63894063234329, 45.493362843990326, 47.477677166461945, 47.98839636147022, 47.2233872115612, 53.76489199697971, 54.54804517328739, 57.042037546634674, 52.408436983823776, 56.0419350117445, 54.71874721348286, 55.392891839146614, 53.66752602159977, 62.75466240942478, 65.95781832933426, 72.81515076756477, 69.4882544875145, 78.76418754458427, 3.081234712153673, 0.31123975524678826, 0.08919602041714825, 2.0380177907645702, 75.606047809124, 65.29299840331078, 65.94818964600563, 38.81209395825863, 59.520104974508286, 39.18065518140793, 45.910683050751686, 57.681790217757225, 75.77105015516281, 33.41961711645126, 0.22326405567582697, 0.12658057414228097, 0.03591395099647343, 0.10512925568036735, 0.02926091805420583, 0.021347156180127058, 0.09441371192224324, 0.1877595772384666, 0.11099847863079049, 0.0862689083442092, 0.29178091033827513, 0.1480224376427941, 0.13609395740786567, 0.33184498082846403, 4.596533076837659, 79.15493577718735, 70.9867724776268, 65.75107142329216, 40.18837250769138, 81.30414605140686, 49.962861612439156, 52.90817856788635, 68.02667811512947, 82.20066234469414, 44.871644005179405, 0.16189225745620206, 0.3956578660290688, 0.7712537585757673, 0.9057541319634765, 10.63327057287097, 88.5918889939785, 68.72057408094406, 80.21428093314171, 66.67290955781937, 70.39025768637657, 62.011984661221504, 63.63553114235401, 63.421317636966705, 63.664656579494476, 60.753841772675514, 56.70153021812439, 53.211029917001724, 57.479888051748276, 51.790225356817245, 55.52906133234501, 48.05030643939972, 46.591165736317635, 47.48622290790081, 47.70121157169342, 49.810789972543716, 58.09999577701092, 52.96672202646732, 56.88635230064392, 59.134015291929245, 65.23185968399048, 55.70925526320934, 58.46014805138111, 45.538390427827835, 58.10468852519989, 62.30333782732487, 60.18185466527939, 58.53638336062431, 51.77962392568588, 57.12767735123634, 60.662893652915955, 59.81135934591293, 58.448858857154846, 55.48357017338276, 52.733479142189026, 51.770090237259865, 54.12309877574444, 50.877225548028946, 46.99821509420872, 46.91535294055939, 46.1156440526247, 44.35975827276707, 43.00391122698784, 43.43993782997131, 47.593639343976974, 47.44262024760246, 47.87127524614334, 48.6470378190279, 51.18808686733246, 47.60544911026955, 49.64498206973076, 51.796715408563614, 48.81378807127476, 51.516814827919006, 53.18951927125454, 53.710904493927956, 58.19826990365982, 57.537443563342094, 58.77963490784168, 46.343377232551575, 39.525726065039635, 38.066444769501686, 37.392117753624916, 58.12517702579498, 60.29764585196972, 53.107329681515694, 57.918183133006096, 55.86479611694813, 53.558411076664925, 51.40686772763729, 49.84811916947365, 49.659204706549644, 48.16021554172039, 47.752041444182396, 46.90165847539902, 49.34741623699665, 46.47843338549137, 48.39719742536545, 42.71543450653553, 41.99807859957218, 44.16009038686752, 43.19132097065449, 45.22349372506142, 44.59281116724014, 49.145251885056496, 45.80472953617573, 55.763151571154594, 52.38105945289135, 53.571805357933044, 56.78152732551098, 56.28537654876709, 61.73449695110321, 60.060074999928474, 55.802692249417305, 58.42715822160244, 52.15537056326866, 56.39983780682087, 61.72483406960964, 61.668008118867874, 66.7087872326374, 59.85738627612591, 36.138527020812035, 49.1335941106081, 65.4352779686451, 64.09461870789528, 63.241496086120605, 53.74384492635727, 49.054440557956696, 47.93690152466297, 46.97252467274666, 49.418267235159874, 47.58814103901386, 49.57244776189327, 50.65660558640957, 50.54847098886967, 54.65915501117706, 58.565402403473854, 62.4674092233181, 56.282199919223785, 59.124660193920135, 58.537568897008896, 59.14989843964577, 57.25417636334896, 66.395965218544, 69.04201403260231, 77.61663392186165, 72.64217644929886, 84.91822332143784, 5.497668022289872, 0.5553866887930781, 0.20416507817571983, 1.9782630284316838, 85.88290795683861, 71.24307632446289, 77.89797082543373, 42.99026615917683, 66.12631648778915, 53.79424162209034, 55.4859222471714, 71.73756659030914, 89.46889713406563, 39.68158230185509, 0.478450168739073, 0.5616279726382345, 0.1468160469084978, 0.21246130956569687, 0.09817176221986301, 0.18852063483791426], [0.07861843449063599, 0.06769973522750661, 0.04502641495491844, 0.05824128944368567, 0.08376205965760164, 0.0455279101151973, 0.028454979074012954, 0.009675041583250277, 1.658387880306691, 48.121210634708405, 59.440594241023064, 49.89799529314041, 21.851586252450943, 26.90193135291338, 31.760010570287704, 34.81464006006718, 62.247435227036476, 61.79053634405136, 54.79413516819477, 0.6748187332414091, 0.5115752178244293, 0.20747753558680415, 0.21757677022833377, 0.036852589691989124, 43.369690999388695, 66.6490088403225, 52.764504477381706, 65.10905787348747, 67.48168095946312, 65.1060788333416, 62.42544807493687, 61.662984788417816, 61.008766293525696, 59.33996804058552, 53.444189205765724, 50.7747982442379, 48.855281844735146, 49.362547025084496, 44.06234823167324, 43.62568326294422, 40.11846385896206, 43.97498331964016, 46.243081614375114, 51.724101305007935, 51.553737446665764, 52.990683540701866, 53.059919625520706, 56.42529644072056, 56.849851459264755, 58.81530739367008, 34.63414594531059, 46.260670870542526, 60.95214933156967, 56.02914869785309, 55.57802930474281, 52.70457409322262, 52.26440571248531, 50.425106808543205, 55.99482133984566, 47.150955498218536, 44.67482216656208, 48.55306126177311, 43.480234667658806, 44.48955550789833, 42.90321663022041, 44.889009073376656, 42.48681217432022, 39.07717913389206, 40.957766622304916, 40.78777514398098, 41.239023730158806, 39.06621292233467, 39.43249046802521, 40.83652652800083, 42.24579490721226, 41.71147897839546, 39.158528968691826, 41.42538093030453, 43.97349379956722, 42.118623331189156, 45.48401914536953, 44.14888098835945, 46.69385142624378, 48.847640454769135, 51.714069843292236, 48.762977197766304, 52.715110927820206, 45.28430946171284, 38.805212527513504, 36.79160177707672, 37.39505119621754, 53.208784237504005, 53.750562965869904, 53.361019268631935, 51.12523443996906, 50.045252591371536, 43.46361815929413, 44.028678238391876, 44.416481629014015, 45.25387689471245, 42.55704380571842, 42.53666169941425, 42.28661231696606, 45.34760646522045, 42.89272539317608, 41.1674165725708, 39.568937346339226, 38.08193653821945, 40.51748424768448, 39.25531357526779, 38.38672578334808, 37.079550325870514, 40.67646011710167, 44.248355850577354, 44.71829183399677, 42.952686175704, 44.62211139500141, 50.0886994600296, 46.612364798784256, 50.700713619589806, 56.061302572488785, 49.57773707807064, 51.939922124147415, 49.58651460707188, 50.93146003782749, 54.92609828710556, 56.42634138464928, 60.193675830960274, 64.18608739972115, 44.26514334976673, 41.31213180720806, 53.08557964861393, 59.277898371219635, 56.68671861290932, 56.966508999466896, 48.22300337255001, 42.52541430294514, 43.088031113147736, 44.20567274093628, 45.65703146159649, 43.807944282889366, 43.73826742172241, 45.088631361722946, 46.15925811231136, 48.89387637376785, 48.68361085653305, 49.13900502026081, 50.39310872554779, 50.36720171570778, 51.370040103793144, 51.92772477865219, 62.11766839027405, 67.38777279853821, 68.19415032863617, 77.17069745063782, 50.054744482040405, 0.39664136013016105, 0.42722327692899853, 0.813341309549287, 9.264816753566265, 72.9259604215622, 57.576478868722916, 61.08216315507889, 32.02570751309395, 44.28661599755287, 40.025745034217834, 42.9964180290699, 49.28304009139538, 62.160602286458015, 30.49383871257305, 0.4516819113632664, 0.10760825156467035, 0.14030571968760341, 0.04098383265954908, 0.03986940144386608, 0.04683990846388042, 0.012521939552243566, 0.043151011486770585, 0.057269387689302675, 0.005112355238452437, 0.022139784741739277, 0.02360509410209488, 0.04898985833278857, 0.06416205083951354, 2.5575292389839888, 57.71764129400253, 66.16336449980736, 58.50907422602177, 28.86830873787403, 35.705848038196564, 39.44956675171852, 41.318146884441376, 66.14484429359436, 67.96569898724556, 58.809839487075806, 0.7586617092601955, 0.22431066201534122, 0.3135522280354053, 0.35078467859420925, 0.029133660136722028, 46.33440211415291, 72.26991042494774, 67.8924997150898, 68.23656365275383, 67.60509833693504, 66.3551478087902, 64.92438778281212, 64.20676589012146, 60.771507024765015, 61.78478725254536, 57.1351021528244, 53.93884666264057, 51.38206645846367, 51.372912749648094, 46.0069926828146, 44.58198554813862, 42.106061205267906, 45.86989983916283, 47.86598213016987, 56.165910959243774, 54.03707519173622, 56.113044396042824, 53.98341827094555, 61.74530357122421, 57.24812708795071, 58.221460059285164, 38.692620769143105, 48.250586092472076, 61.58517636358738, 58.373489901423454, 59.10737492144108, 55.11052519083023, 55.415154844522476, 52.73235060274601, 61.354483142495155, 51.68016046285629, 52.68039219081402, 52.158083617687225, 47.76479355990887, 48.602458611130714, 45.87752602994442, 50.03482975065708, 45.687692016363144, 42.30687662959099, 44.38343860208988, 43.96331034600735, 43.10915797948837, 41.9218622893095, 41.209035739302635, 43.45400087535381, 45.10219283401966, 42.944018840789795, 42.71728500723839, 44.34471108019352, 45.215654745697975, 43.91989767551422, 44.153395146131516, 46.630839407444, 47.66212686896324, 51.62952058017254, 50.57265289127827, 52.057119235396385, 55.18582955002785, 46.14423371851444, 38.47522683441639, 36.718330308794975, 37.57400259375572, 53.872031047940254, 53.762106746435165, 56.319073140621185, 52.16752231121063, 51.49933576583862, 47.968367636203766, 46.64114065468311, 46.03281229734421, 48.28448407351971, 46.36222042143345, 44.69749554991722, 44.74639132618904, 47.30285994708538, 42.79921241104603, 43.32950055599213, 40.786072835326195, 39.500214233994484, 41.951595693826675, 42.910626232624054, 39.406051486730576, 40.32150976359844, 41.761423498392105, 48.59683871269226, 48.57782453298569, 46.582942977547646, 48.452427461743355, 56.23198181390762, 51.91106267273426, 53.11796151101589, 57.79940530657768, 52.76667036116123, 55.03967799246311, 53.01020309329033, 50.894229635596275, 59.67899724841118, 59.292235001921654, 62.919497564435005, 64.16312143206596, 43.11992660164833, 42.52640224993229, 54.64471958577633, 63.66243749856949, 59.95321333408356, 60.978117138147354, 52.51794710755348, 44.82848212122917, 47.505590468645096, 47.44367279112339, 48.40988874435425, 47.393409088253975, 46.341028958559036, 49.145628064870834, 48.543736562132835, 50.34014716744423, 52.17626944184303, 51.49496980011463, 52.38065667450428, 53.0595738440752, 54.16102834045887, 54.740672037005424, 63.54197636246681, 73.15641045570374, 69.26296457648277, 80.36580920219421, 50.35113237798214, 0.5030329199507833, 0.38910203031264246, 0.7751918316353112, 10.939678531140089, 82.05328345298767, 63.16266171634197, 69.71262484788895, 35.331362932920456, 49.781041368842125, 39.276326447725296, 54.0547214448452, 62.76813268661499, 70.90189263224602, 39.56801399588585, 0.39428061805665493, 0.06491384643595666, 0.04820202033442911, 0.1193338434677571, 0.06613617850234732, 0.1160750284907408, 0.2501561329700053, 0.2548887790180743, 0.11245686560869217, 0.22268884669756517, 0.15832867211429402, 0.2221294306218624, 0.11713509738910943, 0.1338405892602168, 3.969603292644024, 71.86574131250381, 72.8068596124649, 69.92266997694969, 29.659783467650414, 42.96092793345451, 49.12333086133003, 50.47887772321701, 73.6288695037365, 76.7998069524765, 69.60002169013023, 1.229475683066994, 1.3806326407939196, 0.5202783539425582, 0.926125788828358, 0.193505774368532, 49.04107287526131, 76.10214158892632, 51.794218942523, 70.9875400364399, 72.32454389333725, 71.08752027153969, 66.6982313990593, 68.1741102039814, 65.46343445777893, 66.10023468732834, 59.205052480101585, 57.08707273006439, 53.52556183934212, 56.96620121598244, 50.25305204093456, 48.983410969376564, 46.70283034443855, 48.39989148080349, 49.98187959194183, 58.77389341592789, 56.659439876675606, 58.21156159043312, 56.88640929758549, 62.356785759329796, 58.382495418190956, 59.100717678666115, 45.525896698236465, 51.43134221434593, 62.47725449502468, 61.71898238360882, 62.171990275382996, 57.671336978673935, 56.011943221092224, 57.20469541847706, 65.49947932362556, 58.912046402692795, 53.49297098815441, 57.72054813802242, 53.02690699696541, 51.98485851287842, 49.24193009734154, 53.90696257352829, 47.95766741037369, 44.013498052954674, 47.22357340157032, 45.18747165799141, 45.8294016122818, 45.1687690615654, 44.98024597764015, 46.128320172429085, 47.98423558473587, 45.32335616648197, 45.96231088042259, 47.95960530638695, 49.106740951538086, 46.52086190879345, 48.532314375042915, 51.925919875502586, 51.09479807317257, 51.99020482599735, 54.293656423687935, 53.307407945394516, 57.36623615026474, 47.45793342590332, 38.70816573500633, 36.326290145516396, 39.03498239815235, 56.49029195308685, 58.12882862985134, 61.704983934760094, 53.807958886027336, 54.12063650786877, 48.725591003894806, 48.28968599438667, 47.96744808554649, 49.86073449254036, 47.64992192387581, 45.19991599023342, 46.26042768359184, 49.655655696988106, 46.46695040166378, 47.28412315249443, 41.651335805654526, 42.47405245900154, 44.2987335473299, 45.541924238204956, 41.418381705880165, 43.26350949704647, 44.503348767757416, 51.542512848973274, 50.86913578212261, 50.689025446772575, 52.35662296414375, 60.0656720995903, 57.09658361971378, 58.062381595373154, 61.2775182723999, 54.87414367496967, 56.02626845240593, 53.81802074611187, 53.29213656485081, 61.742974296212196, 61.61334805190563, 65.2147302031517, 64.28645521402359, 44.73145432770252, 44.13899391889572, 56.270846128463745, 65.07403135299683, 63.477664813399315, 62.63382889330387, 55.5212527513504, 48.14083278179169, 49.150199219584465, 49.92038369178772, 51.40413947403431, 49.853826463222504, 49.41749967634678, 50.84941864013672, 51.96757324039936, 54.571003541350365, 55.45888289809227, 54.46136802434921, 55.19737333059311, 57.13373802602291, 58.273186683654785, 56.912441700696945, 68.98030534386635, 74.55960676074028, 74.18970420956612, 84.00985166430473, 57.159219458699226, 0.46539353497792035, 0.8713574276771396, 1.648247055709362, 11.940179094672203, 91.17847859859467, 70.41564032435417, 77.83214315772057, 42.877260223031044, 63.517007902264595, 55.509522780776024, 55.21011784672737, 68.6469492316246, 82.69793406128883, 49.092351123690605, 0.7987665978726, 0.18164678884204477, 0.31680274580139667, 0.2158816604060121, 0.13923224760219455, 0.16358537832275033], [0.020653301908168942, 0.03806847620580811, 0.10516533147892915, 0.028051723857061006, 0.046065084025030956, 0.08666941575938836, 0.06331614349619485, 0.0819797177973669, 4.224309325218201, 50.92691168189049, 57.825612500309944, 43.4774874150753, 37.5173856317997, 25.747819282114506, 35.43493017554283, 39.77089270949364, 70.2724640071392, 52.42665320634842, 73.27548086643219, 7.364489799365401, 0.5320727429352701, 0.17109200911363587, 0.10735293792095035, 0.245515305432491, 5.582614839076996, 56.15079917013645, 33.523875921964645, 62.22218558192253, 66.80488407611847, 69.8439534008503, 65.4303078353405, 67.47881591320038, 58.96769441664219, 60.456728115677834, 55.30396141111851, 53.98148037493229, 48.91197480261326, 47.77460463345051, 42.82561719417572, 43.43190886080265, 40.04032105207443, 42.68682964146137, 46.220032051205635, 51.43481142818928, 52.49469995498657, 55.80607786774635, 54.855855256319046, 57.270473688840866, 53.29714849591255, 46.91362023353577, 41.40355110168457, 59.59260508418083, 57.333200722932816, 58.46952974796295, 53.0820382386446, 55.931243151426315, 52.162620574235916, 50.2862698584795, 51.806971058249474, 48.458233550190926, 45.19991219043732, 45.16697555780411, 44.66449812054634, 42.0156716555357, 44.49671432375908, 43.40607404708862, 45.707124173641205, 41.71662390232086, 42.2786745429039, 39.95350331068039, 38.079436272382736, 38.125535398721695, 39.61934544146061, 40.11868044734001, 41.15330792963505, 41.819879561662674, 40.89284710586071, 40.6716001778841, 43.01222138106823, 40.53550288081169, 43.874710500240326, 44.30472582578659, 46.430054381489754, 48.28286916017532, 50.04517659544945, 52.07417652010918, 54.278590232133865, 48.25162723660469, 41.21730789542198, 37.00306423008442, 42.2153015434742, 53.66401880979538, 54.77402664721012, 53.564087972044945, 48.73143129050732, 49.49658863246441, 45.27709364891052, 45.255339816212654, 43.63940432667732, 43.11767712235451, 43.89832243323326, 44.72520366311073, 42.608033269643784, 44.41581666469574, 43.06751221418381, 40.44630266726017, 37.44243085384369, 38.52114737033844, 38.9292910695076, 41.66725315153599, 39.17026273906231, 39.604841619729996, 44.45522055029869, 41.914087906479836, 44.38857592642307, 41.42116315662861, 45.22439807653427, 47.6712691783905, 48.9559156447649, 48.622969910502434, 53.05916726589203, 51.23311065137386, 51.323435604572296, 50.33535182476044, 51.60544507205486, 58.38238142430782, 54.95841555297375, 59.57679033279419, 50.836757719516754, 43.050557523965836, 46.00460261106491, 47.81315736472607, 55.43865658342838, 59.33904469013214, 57.37483888864517, 56.539480313658714, 46.72704644501209, 43.86026367545128, 45.02266310155392, 45.919574573636055, 46.020443961024284, 46.224002838134766, 45.73042072355747, 45.18340207636356, 46.62390857934952, 45.80615445971489, 47.56058491766453, 49.13227558135986, 49.50076840817928, 50.521792620420456, 55.343646481633186, 62.59617671370506, 69.68422517180443, 68.12984257936478, 78.75161781907082, 16.024832613766193, 0.9796871803700924, 0.7378724310547113, 0.9713554743211716, 24.253851547837257, 67.29646369814873, 60.287789180874825, 59.288488402962685, 34.93796244263649, 51.61780200898647, 47.90576979517937, 44.27520141005516, 48.008489683270454, 65.68194553256035, 40.86712248623371, 0.7188678102102131, 0.13809101743390784, 0.10485997481737286, 0.022580887634831015, 0.009412484578206204, 0.0633617262064945, 0.02730802880250849, 0.041866138635668904, 0.08107772635412402, 0.03409768556593917, 0.06418292003218085, 0.1000157097587362, 0.15674871392548084, 0.14818032213952392, 5.768953040242195, 61.92738600075245, 66.49469152092934, 48.54582644999027, 34.13861073553562, 36.11856289207935, 43.789420276880264, 45.4573217779398, 75.04279643297195, 59.171086102724075, 80.34115612506866, 8.861185312271118, 0.6923320528585464, 0.4971031897002831, 0.28403386822901666, 0.3310583339771256, 6.558411028236151, 59.342016130685806, 46.14860348403454, 69.5605418086052, 66.82379186153412, 75.69341272115707, 65.28188019990921, 71.37561321258545, 58.795046880841255, 63.30510847270489, 57.03059636056423, 57.449941858649254, 52.81667947769165, 50.74919521808624, 45.166424587368965, 45.09414866566658, 42.59419061243534, 43.94726760685444, 50.01352049410343, 54.592818170785904, 55.12633614242077, 58.96880775690079, 57.15985782444477, 61.16325840353966, 55.35665698349476, 48.56580577790737, 43.83074305951595, 62.15882018208504, 57.59819470345974, 60.45031785964966, 55.162194818258286, 57.35520914196968, 53.484638035297394, 54.6516390144825, 57.269280552864075, 54.57442335784435, 48.3697172999382, 51.68864160776138, 47.29106917977333, 46.441940143704414, 46.70036047697067, 48.6267165094614, 49.288363605737686, 44.62594158947468, 42.594973370432854, 41.34898982942104, 40.153988152742386, 41.424229592084885, 41.82994522154331, 44.54435236752033, 42.51191362738609, 42.43283227086067, 42.125979736447334, 43.12151871621609, 44.87827084958553, 44.47691738605499, 47.03602306544781, 45.01491151750088, 47.11991876363754, 49.923062548041344, 50.764941573143005, 54.68788146972656, 56.38067163527012, 49.152547493577, 42.13378831744194, 37.76919052004814, 42.38813906908035, 55.0828018784523, 56.41037844121456, 54.06054653227329, 50.08350893855095, 51.305580362677574, 46.14455670118332, 44.34422850608826, 46.19551196694374, 48.10175187885761, 46.50980830192566, 47.0929554104805, 45.06298653781414, 45.16328975558281, 44.95925970375538, 42.500947415828705, 39.08713839948177, 41.961953938007355, 40.47700121998787, 44.321726113557816, 41.19387075304985, 40.79640068113804, 46.05522349476814, 45.29420793056488, 49.03946176171303, 44.866043105721474, 48.85510325431824, 52.08873733878136, 49.916572496294975, 52.79712572693825, 56.0382492095232, 54.351496919989586, 54.416306242346764, 53.84715378284454, 53.36586780846119, 60.84021493792534, 55.796612575650215, 61.16244524717331, 54.437873885035515, 45.08702404797077, 45.51281400024891, 47.4869828671217, 58.59613135457039, 61.19909048080444, 60.85161052644253, 59.29522164165974, 50.05382873117924, 48.251802027225494, 49.65610407292843, 48.623262494802475, 47.8656667470932, 49.936483427882195, 49.257475063204765, 50.00544972717762, 48.14490996301174, 48.69181841611862, 50.865693166852, 52.39209406077862, 52.265340462327, 53.20486284792423, 57.63689182698727, 66.18605688214302, 74.53534886240959, 69.76368650794029, 82.94113621115685, 16.172061413526535, 1.096925139427185, 0.48336749081499875, 0.7612869527656585, 26.90374005585909, 75.35361975431442, 67.72236004471779, 68.78973037004471, 40.61018407344818, 56.07791528105736, 49.01186004281044, 38.781030625104904, 62.69191637635231, 70.48904478549957, 53.42076726257801, 0.803685374557972, 0.07354391069384292, 0.08566432516090572, 0.04196454741759226, 0.05911984386330005, 0.14945341710699722, 0.15196589869447052, 0.19073940406087786, 0.2064439168316312, 0.08994220537715591, 0.15253255813149735, 0.22075598244555295, 0.3717654902720824, 0.24271095200674608, 7.13889685459435, 75.3492271900177, 73.55076849460602, 59.91868458688259, 51.0645554959774, 44.606121852993965, 52.06511780619621, 55.08292727172375, 82.95582622289658, 66.37808337807655, 92.56887719035149, 11.158453691750765, 1.4698086306452751, 1.0920761246234179, 0.5541858938522637, 0.4800164862535894, 8.252350632101297, 63.639444932341576, 34.120143726468086, 66.4733062684536, 72.68067598342896, 76.5691365301609, 68.94508883357048, 75.22781610488892, 61.468214839696884, 66.1682054400444, 62.657140642404556, 59.40372861921787, 55.8771226555109, 53.3062794059515, 47.540096417069435, 47.87454307079315, 45.6608996540308, 44.42566193640232, 51.68386526405811, 57.68524043262005, 56.97027079761028, 61.60796754062176, 57.15794652700424, 63.27835790812969, 55.22522583603859, 52.098632007837296, 44.81982618570328, 64.74108561873436, 59.334785118699074, 63.20362351834774, 57.62456528842449, 61.09945982694626, 56.72039620578289, 56.63678169250488, 60.32574154436588, 59.18698824942112, 53.56590807437897, 54.31988641619682, 50.30378691852093, 49.48244959115982, 51.89809776842594, 52.22004309296608, 52.2701396048069, 46.18177570402622, 45.64859591424465, 43.93247500061989, 43.19824039936066, 43.04749868810177, 44.566752165555954, 45.836036056280136, 45.225568413734436, 46.97712242603302, 44.69197444617748, 44.73836615681648, 47.75987282395363, 45.47740750014782, 50.012502148747444, 47.339326590299606, 51.212599352002144, 54.121825844049454, 53.82230691611767, 56.37105815112591, 59.044138714671135, 50.29606953263283, 42.02389821410179, 36.93150267004967, 44.239996299147606, 56.459319815039635, 60.133882239460945, 58.50435867905617, 52.93934069573879, 53.43107230961323, 49.91422042250633, 47.78716295957565, 47.19780318439007, 50.593582168221474, 48.69166262447834, 50.657270550727844, 45.87269648909569, 47.21568122506142, 48.15342530608177, 45.23507550358772, 42.12409123778343, 43.338658064603806, 43.318481147289276, 47.7727085351944, 45.12118421494961, 42.677588537335396, 49.346356093883514, 50.09450554847717, 52.215365543961525, 48.0828782916069, 50.45699089765549, 56.56303524971008, 56.969355046749115, 56.131446808576584, 59.0782380849123, 57.28270523250103, 58.13862070441246, 55.4847177118063, 56.94765441119671, 64.6536523103714, 60.42948737740517, 62.27024920284748, 55.282427966594696, 43.59292522072792, 46.529639437794685, 48.87032523751259, 61.74793682992458, 64.09370675683022, 62.37740345299244, 61.6612558811903, 52.434469386935234, 49.562982469797134, 51.432261765003204, 52.294815480709076, 50.652684196829796, 53.41208852827549, 52.652357295155525, 51.35516010224819, 52.38835886120796, 52.588798105716705, 53.87986242771149, 55.010506957769394, 55.06681613624096, 58.377384692430496, 60.12659043073654, 70.35183414816856, 77.01449543237686, 72.54492446780205, 87.10008904337883, 22.564348205924034, 1.2947080889716744, 1.0721784923225641, 2.139823827892542, 30.891132093966007, 82.39649623632431, 74.46834325790405, 75.44479206204414, 48.88386391103268, 71.7329840362072, 67.52344831824303, 53.644153475761414, 68.99371862411499, 82.39260524511337, 62.37981632351875, 1.0707295825704932, 0.14828021521680057, 0.206466359377373, 0.14248868770664558, 0.09062160446774215, 0.21952354232780635], [0.026827406545635313, 0.038579014435526915, 0.03841972356894985, 0.014714513745275326, 0.037130052733118646, 0.016665094917698298, 0.013231290795374662, 0.01899189857795136, 5.108970729634166, 55.98560683429241, 49.609913751482964, 47.61839121580124, 29.960938207805157, 18.398392349481583, 39.12968471646309, 34.788672253489494, 69.97663468122482, 54.25097331404686, 66.21463894844055, 26.065641827881336, 0.7183313264977187, 0.39984105562325567, 0.20615249028196558, 0.6785381399095058, 0.03051186733500799, 25.49325004220009, 29.99270260334015, 50.74925981462002, 68.27640071511269, 66.01528644561768, 70.1939982175827, 61.0994978249073, 62.00110204517841, 56.02955527603626, 53.77190642058849, 50.37586145102978, 47.7506735175848, 45.68131595849991, 44.95137892663479, 41.52142457664013, 41.35994844138622, 44.36342127621174, 49.65696282684803, 53.70027266442776, 57.80320890247822, 56.23322054743767, 55.80344080924988, 54.774140641093254, 51.27436123788357, 49.21558991074562, 57.19824716448784, 56.42921403050423, 57.50077173113823, 57.45449401438236, 55.8863789588213, 54.887857139110565, 51.82818531990051, 51.19329258799553, 51.17256850004196, 46.83558762073517, 43.84284920990467, 46.67712852358818, 45.370933413505554, 41.29686042666435, 45.19991219043732, 41.66805870831013, 46.020409762859344, 46.97255127131939, 45.39881631731987, 40.019904747605324, 40.408129915595055, 38.78899499773979, 40.34853771328926, 39.921178445219994, 38.47326993942261, 41.674658954143524, 42.46378920972347, 39.214283376932144, 42.2671003639698, 41.41418673098087, 43.98220293223858, 42.168719843029976, 46.25518776476383, 46.3999979943037, 49.01515066623688, 50.71369752287865, 55.798276886343956, 50.550921857357025, 39.68281723558903, 37.17050984501839, 45.23311860859394, 53.6913887411356, 54.423244670033455, 53.45118083059788, 50.52556201815605, 50.47760859131813, 48.29857751727104, 44.19734738767147, 42.307457998394966, 43.077543675899506, 42.737477123737335, 42.34036423265934, 43.22608530521393, 43.6760001629591, 42.85734549164772, 40.6173200905323, 37.95092336833477, 38.9238915592432, 40.66551670432091, 38.82891945540905, 40.7977382093668, 45.93522593379021, 42.524031177163124, 42.05497294664383, 45.09780406951904, 42.607588693499565, 47.33792446553707, 48.3784644305706, 48.895206302404404, 49.52822953462601, 52.222577556967735, 53.23826685547829, 50.904280096292496, 52.142819836735725, 50.38130275905132, 59.31642070412636, 56.8104437738657, 59.019519835710526, 58.26122872531414, 51.88636399805546, 51.13253004848957, 50.86817443370819, 51.305477768182755, 59.7077427059412, 60.03667205572128, 57.348171919584274, 52.01441332697868, 46.51136241853237, 45.036577954888344, 45.321893244981766, 46.38227954506874, 48.80143493413925, 48.30641649663448, 48.615305721759796, 50.30602499842644, 47.56462790071964, 49.06371586024761, 47.746698930859566, 49.72840279340744, 50.036486461758614, 55.47651395201683, 64.87100824713707, 65.65253511071205, 73.73343229293823, 62.93028898537159, 2.479747412726283, 1.0199802182614803, 0.41694945946801454, 0.3135355742415413, 30.536795407533646, 65.55822417140007, 61.83745242655277, 57.69148349761963, 32.389944568276405, 57.56010174751282, 49.47511978447437, 60.64931318163872, 38.31739090383053, 63.800529688596725, 55.08422300219536, 2.675541643984616, 0.07464153968612663, 0.0978881430637557, 0.07396937653538771, 0.03941820905311033, 0.05964060146652628, 0.036452464482863434, 0.05498441889358219, 0.046454088151222095, 0.008161661462509073, 0.057259346431237645, 0.052889232101733796, 0.10267709585605189, 0.03866384562570602, 7.100246278569102, 67.51310527324677, 60.11342793703079, 49.94459979236126, 39.7952152043581, 30.40037512779236, 46.66569113731384, 42.97564834356308, 74.02325794100761, 61.26692824065685, 76.03217214345932, 29.8880847170949, 0.6353516760282218, 0.46579094021581113, 0.24195166071876884, 0.8621867978945374, 0.10050292228697799, 27.458816170692444, 38.36203470826149, 55.988988652825356, 64.98106554150581, 71.2352791428566, 70.82425519824028, 65.76229602098465, 62.695788368582726, 59.52238865196705, 56.18989147245884, 53.751961290836334, 50.07145218551159, 48.99528153240681, 47.34155707061291, 44.60019797086716, 43.15253645181656, 48.093282133340836, 51.67446456849575, 57.24926322698593, 60.78498110175133, 58.430205658078194, 58.94719071686268, 57.370279133319855, 53.631317764520645, 51.39269068837166, 56.593205630779266, 59.94070440530777, 58.495968729257584, 62.15777903795242, 57.369215190410614, 56.231442242860794, 55.538344234228134, 53.93598921597004, 55.741800516843796, 50.19270367920399, 47.149454578757286, 51.05908378958702, 48.69451627135277, 45.97035124897957, 49.27637904882431, 45.598871782422066, 47.97296158969402, 47.26768143475056, 49.66566815972328, 43.181544095277786, 43.098184168338776, 40.33697873353958, 42.65892393887043, 41.353887766599655, 41.602523624897, 44.31177444756031, 43.42542260885239, 43.031452149152756, 43.87380614876747, 42.97316327691078, 47.36268773674965, 45.96547611057758, 46.84540629386902, 48.41189883649349, 50.79465217888355, 53.07627394795418, 55.03379210829735, 53.224560990929604, 40.27772091329098, 37.06957966089249, 46.45086966454983, 55.7262821495533, 55.110905170440674, 55.04960685968399, 52.65930712223053, 52.80897729098797, 49.039621353149414, 46.03346586227417, 44.60261084139347, 44.19305741786957, 46.32160060107708, 43.220286816358566, 45.742154493927956, 46.716509610414505, 44.0888974070549, 42.20086231827736, 39.02040638029575, 39.71835672855377, 43.438129127025604, 39.31917294859886, 42.82730050384998, 48.20309244096279, 45.47378249466419, 46.632180735468864, 48.198620080947876, 45.16944542527199, 50.96887283027172, 51.88587762415409, 52.085116133093834, 53.96741732954979, 54.44904148578644, 55.85180461406708, 56.83070048689842, 54.468291252851486, 54.42404642701149, 60.44641546905041, 57.49845765531063, 62.44719810783863, 59.1816533356905, 52.78121218085289, 52.84597970545292, 53.4318208694458, 52.553794384002686, 60.7636072486639, 62.5222896784544, 60.48593334853649, 54.94396112859249, 48.90920475125313, 48.09803567826748, 48.07420335710049, 49.91301588714123, 51.86334863305092, 51.571702882647514, 51.07414238154888, 52.38611698150635, 50.65233461558819, 51.806165501475334, 50.662149488925934, 52.40761622786522, 52.940894812345505, 57.270344495773315, 68.85016992688179, 69.24055337905884, 75.55016800761223, 63.93989101052284, 2.973831812851131, 1.010732939466834, 0.17872471595183015, 0.3655020607402548, 36.21419996023178, 70.75585886836052, 68.11566933989525, 63.33081789314747, 36.03013403713703, 61.89283065497875, 59.388407841324806, 58.05263511836529, 48.72090585529804, 71.69059351086617, 64.84534442424774, 3.4519136091694236, 0.19853818870615214, 0.13130492297932506, 0.013160869330022251, 0.05779772633104585, 0.00458954327768879, 0.1524725925992243, 0.11873022507643327, 0.1529500013566576, 0.3521497850306332, 0.1627439312869683, 0.17335552984150127, 0.3271589119685814, 0.2133533710730262, 10.03233851864934, 83.15694183111191, 65.30780240893364, 69.08331781625748, 40.49416109919548, 28.482160158455372, 55.96212789416313, 48.67535009980202, 82.3982821404934, 64.84353572130203, 86.72745823860168, 34.27483722567558, 0.9734331315848976, 0.7368059945292771, 0.3189825522713363, 1.5707339462824166, 0.26438156026415527, 32.13065028190613, 33.5708300024271, 51.67855314910412, 68.88895064592361, 72.73717135190964, 74.98415797948837, 68.18651273846626, 67.11000770330429, 60.20373769104481, 59.843038246035576, 58.32147069275379, 52.54662036895752, 50.95723785459995, 52.09321729838848, 45.004576072096825, 46.94818317890167, 48.98396193981171, 56.3611026853323, 60.81081971526146, 64.86662328243256, 60.659694224596024, 59.03283052146435, 57.86953814327717, 55.253245532512665, 54.0815594047308, 59.68934789299965, 60.71040630340576, 61.10306963324547, 63.820243030786514, 60.508127957582474, 60.44036619365215, 59.422852993011475, 55.625082179903984, 61.25297538936138, 56.97470135986805, 51.09007492661476, 54.94178004562855, 51.716760098934174, 50.483023300766945, 53.94493393599987, 48.70984084904194, 53.67594636976719, 53.18454913794994, 53.56789156794548, 45.8483511954546, 46.35879300534725, 44.163943380117416, 46.48667894303799, 45.958378091454506, 44.44368436932564, 47.948593497276306, 46.914064809679985, 44.19345259666443, 46.28856897354126, 46.28220051527023, 48.341876193881035, 47.29302227497101, 50.20510621368885, 49.84517052769661, 55.31121902167797, 55.5705551058054, 60.18559746444225, 53.76030184328556, 38.85772570967674, 37.62282617390156, 47.93237216770649, 57.887191995978355, 57.69572027027607, 57.5231259316206, 55.43960653245449, 55.319369584321976, 52.93510392308235, 48.367232233285904, 47.575605511665344, 47.14154340326786, 49.58055652678013, 44.78296056389809, 48.629334568977356, 50.882549062371254, 46.60716287791729, 44.12617340683937, 41.71188175678253, 42.380284890532494, 45.41415609419346, 41.2409046292305, 44.21843245625496, 50.83982415497303, 49.935240894556046, 49.401187151670456, 52.12540157139301, 51.81410327553749, 54.14936676621437, 55.27517035603523, 56.4489159733057, 59.415838569402695, 56.66222892701626, 59.38501462340355, 58.96601490676403, 56.99422471225262, 56.30059473216534, 64.58082541823387, 59.346336498856544, 64.82184648513794, 62.72648312151432, 53.11534345149994, 54.23543594777584, 53.54783624410629, 53.75592827796936, 65.56843042373657, 65.04358738660812, 63.41352045536041, 55.58785177767277, 51.00630842149258, 51.1374431848526, 50.92534236609936, 52.010932713747025, 56.16840362548828, 53.15032437443733, 53.466133028268814, 55.24453639984131, 53.695306330919266, 55.83290822803974, 55.03815047442913, 55.789639949798584, 56.867695301771164, 60.01155160367489, 72.94555217027664, 71.52651831507683, 78.68189916014671, 67.07346126437187, 6.7383460979908705, 1.0672007594257593, 0.6920451088808477, 0.5259414750616997, 40.69238506257534, 79.87224608659744, 78.02260413765907, 70.04740208387375, 47.27445267140865, 76.84228867292404, 73.38268831372261, 77.7459029853344, 55.832714438438416, 80.54544076323509, 78.38285520672798, 4.743460267782211, 0.319987895200029, 0.29776493611279875, 0.13194947823649272, 0.13058895827271044, 0.20307599130319431], [0.13180839596316218, 0.03429871110711247, 0.02916477096732706, 0.004904651295873919, 0.0697317355661653, 0.07288994500413537, 0.07610703643877059, 0.10164649022044614, 9.682099912315607, 63.46311919391155, 50.89393325150013, 45.07520288228989, 21.050796322524548, 29.01809100061655, 38.859614208340645, 38.95645581185818, 69.59360003471375, 59.729116559028625, 58.087129667401314, 47.01062522828579, 0.2666007896186784, 0.03921799245290458, 0.09607141008018516, 0.6828925281297415, 0.3840149939060211, 5.335269961506128, 26.579815037548542, 48.927766755223274, 75.07046654820442, 61.11157737672329, 65.24263590574265, 60.999848172068596, 57.2695579379797, 53.15902590751648, 52.32310876250267, 48.037140145897865, 48.300234228372574, 43.027222976088524, 43.171261847019196, 40.64666971564293, 43.48984815180302, 44.05071325600147, 50.420638248324394, 54.385729283094406, 57.168255373835564, 56.177257150411606, 55.134642496705055, 53.82835239171982, 53.32229934632778, 55.56731007993221, 57.42870859801769, 56.86142183840275, 57.025204449892044, 56.0817264765501, 53.83120223879814, 54.72586043179035, 53.5414981842041, 53.19765463471413, 48.647478595376015, 48.3837803453207, 47.56606042385101, 45.39554089307785, 43.87129828333855, 40.95227211713791, 45.01183368265629, 40.68440929055214, 45.88004909455776, 41.822383627295494, 48.918670043349266, 41.96751303970814, 37.767332419753075, 39.24087055027485, 39.63386446237564, 39.03801463544369, 40.44824056327343, 40.49467787146568, 42.78609551489353, 41.878096237778664, 43.92655111849308, 43.7765047699213, 44.61523376405239, 42.05954410135746, 44.17527437210083, 42.70208202302456, 48.487826362252235, 53.172606378793716, 54.89192292094231, 54.37126345932484, 46.49482950568199, 40.99334791302681, 48.94270375370979, 54.6744529902935, 53.76928076148033, 51.51776097714901, 49.82624754309654, 48.579735830426216, 46.0410388559103, 43.46715956926346, 43.108576610684395, 43.33613499999046, 43.75545009970665, 43.14209461212158, 43.768137618899345, 43.43985803425312, 41.92714400589466, 39.90045815706253, 39.693278074264526, 38.73438432812691, 38.75872582197189, 40.450619235634804, 46.47907555103302, 46.39031231403351, 42.827722281217575, 42.48496547341347, 42.86923125386238, 42.38737151026726, 46.56356021761894, 49.96608383953571, 49.850619435310364, 50.76560653746128, 53.65685999393463, 53.151483312249184, 51.03807091712952, 52.102352008223534, 50.15771135687828, 56.09288647770882, 55.95404952764511, 56.726738065481186, 55.882054790854454, 55.35865567624569, 55.34294351935387, 58.03610220551491, 53.971023336052895, 53.43238323926926, 58.33331845700741, 57.263440266251564, 54.331669583916664, 48.29663962125778, 44.73622687160969, 44.79638144373894, 46.098932549357414, 47.272507175803185, 49.016100615262985, 48.455892875790596, 49.817546010017395, 50.54149076342583, 48.722699359059334, 51.27100221812725, 48.956485614180565, 51.85769833624363, 53.06120775640011, 66.00428223609924, 63.77276077866554, 78.16778674721718, 48.993666619062424, 1.0772214154712856, 0.34463651943951845, 0.052445212568272837, 0.34996059781406075, 42.17861831188202, 66.15327224135399, 57.8338048607111, 62.14526250958443, 32.4240705370903, 42.024973556399345, 41.54850572347641, 23.217947334051132, 37.85717859864235, 61.34472146630287, 59.309626668691635, 5.388322714716196, 0.2890696667600423, 0.1465597833157517, 0.08610575459897518, 0.07235095283249393, 0.02733222281676717, 0.04620585830707569, 0.015466112672584131, 0.028255300530872773, 0.023248672114277724, 0.005934791697654873, 0.07003957842243835, 0.08632027980638668, 0.12235782807692885, 11.757463999092579, 77.27565541863441, 54.27826724946499, 67.36930578947067, 33.56921888887882, 31.35818213224411, 46.442806497216225, 47.25399076938629, 76.25070601701736, 65.29172167181969, 68.81607055664062, 52.22636975347996, 0.18972751538967714, 0.27272012375760823, 0.0913707802828867, 0.6949624023400247, 0.22866392217110842, 5.562162436544895, 31.883450746536255, 52.928674668073654, 77.08083227276802, 62.703615948557854, 67.56155267357826, 62.039495185017586, 59.424217119812965, 56.77535265684128, 55.18801063299179, 52.13382191956043, 52.50080622732639, 43.67004208266735, 45.91636374592781, 43.528967052698135, 45.542593002319336, 47.27639056742191, 52.547517120838165, 55.84217973053455, 59.47780184447765, 57.82698042690754, 54.93502400815487, 55.59633672237396, 55.557768791913986, 57.03903950750828, 59.423780143260956, 55.81699088215828, 59.122129529714584, 59.034988805651665, 57.11478464305401, 55.200739949941635, 57.29495197534561, 57.03527770936489, 53.47345143556595, 51.44537106156349, 51.544142961502075, 49.039355367422104, 47.827501595020294, 45.117734000086784, 48.247128278017044, 43.676528334617615, 48.92592005431652, 47.071608155965805, 51.324788331985474, 46.449608132243156, 40.87913744151592, 42.88522079586983, 41.68585695326328, 43.27153466641903, 42.382215186953545, 42.90823996067047, 45.65350145101547, 44.8663204908371, 46.879224479198456, 45.94590336084366, 47.34819911420345, 44.95474174618721, 48.414885476231575, 44.83588792383671, 51.3961561024189, 54.86459478735924, 56.137484684586525, 55.19426129758358, 46.246854811906815, 41.47103548049927, 50.488836988806725, 55.203585997223854, 56.05869971215725, 54.36564356088638, 51.682383343577385, 51.72204941511154, 48.92557807266712, 45.868159532547, 46.00649490952492, 45.36956548690796, 46.045948192477226, 45.90718723833561, 45.98197102546692, 43.687144964933395, 43.5164999216795, 41.829933822155, 42.26205423474312, 40.477605387568474, 40.19158713519573, 43.645005226135254, 49.61825430393219, 48.50387670099735, 45.49818858504295, 44.57863412797451, 47.205638363957405, 46.65657922625542, 50.16669027507305, 53.29003907740116, 54.92181211709976, 54.257356971502304, 55.398131757974625, 54.678503572940826, 54.548767134547234, 56.922560557723045, 54.09368075430393, 58.97199958562851, 56.41176916658878, 58.90966013073921, 59.53371584415436, 59.337178990244865, 57.22938649356365, 60.811750665307045, 54.39765304327011, 54.395631551742554, 60.787697955965996, 61.00685499608517, 56.45410269498825, 51.23188331723213, 46.93956904113293, 48.28356832265854, 50.47038517892361, 50.95533795654774, 51.36958032846451, 51.71242833137512, 52.83380135893822, 55.00078707933426, 52.77243085205555, 52.501630783081055, 52.183542251586914, 54.9338498711586, 55.503040328621864, 69.03547838330269, 68.20904552936554, 81.05504661798477, 49.666477516293526, 1.4630848914384842, 0.6128951185382903, 0.03546636915416457, 0.6258470797911286, 48.1433330476284, 75.07504150271416, 64.96874660253525, 68.51833373308182, 32.08819516003132, 52.555036917328835, 54.64367464184761, 30.229365304112434, 44.14839081466198, 69.36681300401688, 71.1023622751236, 6.586858201771975, 0.31943235313519835, 0.08591537887696177, 0.027906780560442712, 0.09640496093197726, 0.01772456267644884, 0.1780103988130577, 0.24881002551410347, 0.11659314404823817, 0.1785637144348584, 0.21322796295862645, 0.287087865290232, 0.27308816963341087, 0.3678002249216661, 15.429207924753428, 89.53079581260681, 63.01663175225258, 66.79028525948524, 25.825363621115685, 41.99858017265797, 54.18262258172035, 52.13376112282276, 83.32506000995636, 69.84719842672348, 74.97891426086426, 60.39531581103802, 0.39583467529155314, 0.5521823919843882, 0.15949543216265738, 1.832387549802661, 0.4991937009617686, 7.9420155845582485, 29.77044302970171, 49.262654185295105, 80.28308764100075, 65.23482352495193, 71.59943640232086, 66.02993085980415, 61.29020199179649, 58.020485043525696, 57.93310113251209, 54.17677849531174, 55.09565278887749, 46.21577247977257, 48.34951378405094, 44.969374760985374, 49.1690082103014, 48.75230737030506, 55.584504157304764, 58.12951639294624, 62.33302563428879, 59.887860640883446, 57.341218292713165, 58.13127189874649, 57.609510496258736, 57.26112999022007, 59.91931535303593, 59.22888860106468, 61.42464257776737, 59.76013049483299, 59.031181409955025, 59.26950082182884, 59.08807955682278, 58.96407701075077, 54.847176522016525, 57.05149903893471, 56.10283434391022, 54.293113052845, 52.95268937945366, 48.99562731385231, 52.6186379045248, 46.19448982179165, 52.54468247294426, 50.37766255438328, 55.10781213641167, 48.446381986141205, 43.631930127739906, 44.980428367853165, 45.828223675489426, 44.45140555500984, 44.04930733144283, 44.47618022561073, 48.42528931796551, 48.503998294472694, 51.22029013931751, 49.92891423404217, 50.099335089325905, 46.24222666025162, 52.045689448714256, 47.15111508965492, 53.74720774590969, 57.17143580317497, 59.91468720138073, 56.875028908252716, 47.1540979295969, 42.22444765269756, 51.74993231892586, 57.6728530973196, 59.00267913937569, 56.5971764177084, 54.12827789783478, 53.22587192058563, 52.65231169760227, 48.34894381463528, 47.76776120066643, 48.651122599840164, 47.36355409026146, 48.50973978638649, 48.589535504579544, 47.886311039328575, 45.27388282120228, 43.314149379730225, 44.881933853030205, 42.648835480213165, 42.038633823394775, 45.45815013349056, 50.92501178383827, 54.90300312638283, 49.54587198793888, 49.73125264048576, 51.370572075247765, 50.45476421713829, 54.40807968378067, 57.699421271681786, 58.19601282477379, 60.2430883795023, 59.7093690186739, 58.106330037117004, 58.37162800133228, 56.39570362865925, 55.33510074019432, 61.41787514090538, 58.70892830193043, 61.95515111088753, 61.03962443768978, 59.32960219681263, 58.112839087843895, 63.31736281514168, 55.98428450524807, 56.3354616612196, 64.3488858640194, 64.1078419983387, 60.249339044094086, 53.30777272582054, 49.778237119317055, 49.845964685082436, 52.62749902904034, 54.76302623748779, 55.93351922929287, 54.05042007565498, 56.38602934777737, 58.009963408112526, 55.87458059191704, 57.06953667104244, 55.0283508002758, 55.9272837638855, 58.084959983825684, 72.78585433959961, 71.16498291492462, 84.8874905705452, 56.43696941435337, 1.6314120590686798, 1.3473762315697968, 0.2104276468162425, 0.845197137678042, 53.7683080136776, 81.87425225973129, 74.42958533763885, 76.07330113649368, 46.74417592585087, 57.02938802540302, 60.52502945065498, 34.47575904428959, 54.324879348278046, 79.43169012665749, 81.81433707475662, 9.065592493861914, 0.76488227234222, 0.3184452373534441, 0.1733971494832076, 0.317425734247081, 0.22418293840019032], [0.10473337926669046, 0.02297882721904898, 0.06351112053380348, 0.013643081638292642, 0.09466384537518024, 0.02067124703899026, 0.25790724204853177, 0.19240338820964098, 16.736787110567093, 68.38931545615196, 47.832407131791115, 26.735775768756866, 32.95496664941311, 38.086397498846054, 44.60032716393471, 36.40255205333233, 53.59737038612366, 70.67500680685043, 50.44224388897419, 69.25967395305634, 4.6864766255021095, 0.31413905904628336, 0.19697957468451932, 0.07638746435986832, 0.09821541534620337, 0.691151978680864, 18.235724978148937, 46.81954488158226, 69.77117970585823, 62.38721452653408, 64.1901683807373, 57.0878516882658, 54.41379077732563, 49.53088939189911, 51.09168604016304, 45.56880779564381, 45.181388184428215, 44.71349649131298, 43.825522139668465, 42.547810301184654, 45.93207970261574, 49.24374260008335, 53.4060924500227, 55.570175126194954, 60.7227898389101, 55.55225908756256, 56.43308602273464, 55.39069935679436, 56.06262490153313, 57.603765204548836, 58.83740320801735, 56.25604972243309, 57.01615713536739, 54.03040274977684, 51.298831924796104, 55.53661532700062, 52.48778812587261, 52.30849854648113, 49.96906667947769, 49.719754457473755, 48.6513277888298, 47.448274344205856, 43.746965155005455, 41.96204133331776, 43.77116605639458, 41.46733447909355, 43.332449197769165, 42.958537861704826, 41.43155559897423, 46.61731593310833, 43.882237896323204, 42.72717207670212, 40.86084522306919, 39.16237436234951, 40.22384740412235, 41.113182082772255, 42.87927031517029, 43.367582112550735, 43.03263008594513, 43.212611228227615, 45.70026934146881, 44.981321319937706, 46.03312388062477, 43.68665099143982, 47.4657192081213, 50.56203246116638, 52.947308868169785, 54.03541088104248, 44.842583164572716, 43.999871984124184, 49.13816526532173, 55.80781817436218, 54.072648882865906, 53.13488580286503, 44.04072359204292, 46.08087211847305, 47.15124428272247, 44.33721788227558, 46.2170834094286, 43.10856521129608, 41.609728038311005, 39.36131648719311, 42.01637081801891, 41.673682406544685, 39.47570934891701, 40.09716980159283, 39.54457685351372, 38.14976289868355, 39.778849482536316, 44.701770320534706, 45.60505785048008, 44.59778130054474, 42.42946185171604, 41.28879725933075, 42.1871754527092, 42.394864708185196, 45.094445049762726, 48.495680540800095, 48.87537136673927, 48.67497391998768, 53.80556881427765, 52.44801186025143, 51.306051537394524, 55.14120854437351, 51.88115447759628, 53.485496789216995, 56.177086159586906, 57.43064649403095, 60.756174847483635, 57.72706478834152, 57.837627455592155, 59.16125603020191, 60.48461101949215, 55.46101838350296, 56.158220171928406, 57.74251475930214, 56.558604687452316, 49.89023610949516, 43.50459136068821, 45.058704167604446, 45.21520636975765, 47.1853094547987, 49.300891533493996, 50.19172713160515, 49.61803391575813, 51.03021673858166, 50.45222595334053, 52.46326804161072, 47.728174924850464, 54.18185122311115, 53.739003986120224, 65.82465827465057, 59.62379761040211, 82.2293584048748, 26.74929354339838, 2.228476870805025, 0.2860239223809913, 0.17313341988483444, 0.7737859664484859, 50.36701172590256, 67.86147817969322, 58.76143388450146, 57.75891847908497, 33.00483137369156, 28.826575577259064, 43.55871565639973, 26.118660382926464, 43.63235950469971, 60.45925498008728, 59.87492993474007, 7.036383580416441, 0.37962691218126565, 0.15089220396475866, 0.08012120189960115, 0.01802775041142013, 0.04179125222435687, 0.07776903905323707, 0.02513955121685285, 0.05818141296913382, 0.11570615140954033, 0.047520186999463476, 0.05312215886078775, 0.37216289550997317, 0.178115546295885, 21.2512868642807, 79.00376468896866, 54.66575525701046, 42.35826887190342, 19.299194812774658, 33.448472768068314, 50.155142694711685, 41.92685142159462, 64.72425252199173, 75.36568030714989, 59.825817570090294, 74.54983368515968, 5.554652614519, 0.3948929492617026, 0.29524534475058317, 0.4787366377422586, 0.13214921986218542, 0.5806297436356544, 20.8720900118351, 51.801244765520096, 73.00346866250038, 65.19186303019524, 68.08924555778503, 58.91855925321579, 56.45001411437988, 51.32389917969704, 52.77971886098385, 47.54959590733051, 49.112349450588226, 46.84476412832737, 45.32051771879196, 46.15091376006603, 47.64388404786587, 49.59381401538849, 56.338376104831696, 57.496987134218216, 64.29664626717567, 56.91680006682873, 58.091032058000565, 58.7528083473444, 58.49002964794636, 58.908273205161095, 60.8369243144989, 57.66304962337017, 57.59964242577553, 55.401897355914116, 55.220616683363914, 55.764549896121025, 56.527047380805016, 54.41103592514992, 53.4945897012949, 55.88287554681301, 52.10153125226498, 52.21987970173359, 48.817850053310394, 46.35792285203934, 48.67626965045929, 45.68128556013107, 48.58209550380707, 45.6867990642786, 45.95585122704506, 48.89731138944626, 46.068971157073975, 43.5591222345829, 43.10303270816803, 41.87549337744713, 41.55386343598366, 42.99057014286518, 44.545640498399734, 45.71301765739918, 46.70330531895161, 44.770953208208084, 46.86237998306751, 46.07785128057003, 50.98409101366997, 45.48762895166874, 50.605692118406296, 51.23894713819027, 54.68450345098972, 56.343486830592155, 46.213454604148865, 45.17324522137642, 50.03465496003628, 57.97729656100273, 54.98986266553402, 54.24974977970123, 47.3545827716589, 46.35357968509197, 48.18354249000549, 45.346675515174866, 48.28544542193413, 45.692836940288544, 42.97336846590042, 41.77593111991882, 44.01856318116188, 43.13003785908222, 42.67196103930473, 41.69798210263252, 41.05778105556965, 40.24844728410244, 42.60099604725838, 45.62285989522934, 49.60012547671795, 46.30243442952633, 44.525592774152756, 44.12001393735409, 46.908482909202576, 46.016628965735435, 50.210178941488266, 50.80671653151512, 51.69386252760887, 51.80963471531868, 56.0102105140686, 53.79001624882221, 53.80807667970657, 58.75959098339081, 52.50584855675697, 57.47366778552532, 57.090891525149345, 58.391652926802635, 62.50561997294426, 59.10952180624008, 60.03438077867031, 61.213875487446785, 61.271362602710724, 55.19459567964077, 57.80524179339409, 61.085814759135246, 59.815280735492706, 52.56936214864254, 46.674962639808655, 47.0914126932621, 47.56289899349213, 50.38040600717068, 52.87567511200905, 52.57508464157581, 53.04992236196995, 54.535023272037506, 53.92738647758961, 55.46357564628124, 51.56579799950123, 57.908140271902084, 56.79344728589058, 68.95808413624763, 63.34963448345661, 84.17863100767136, 28.32610823214054, 2.2446058178320527, 0.4510496015427634, 0.2923615963663906, 1.3973403442651033, 56.848985105752945, 76.97530433535576, 65.70108890533447, 65.40952295064926, 33.79970692098141, 41.91166363656521, 50.839827954769135, 25.24261549115181, 53.51739227771759, 64.96943056583405, 72.32373833656311, 11.575691252946854, 0.6048723240382969, 0.11471849385998212, 0.06378008969477378, 0.024802755324344616, 0.1346430735429749, 0.18843600031686947, 0.14110737276496366, 0.17388797627063468, 0.17494621948571876, 0.18375843646936119, 0.23315385624300689, 0.6186784082092345, 0.34028109221253544, 27.368753403425217, 90.63139915466309, 62.5519622862339, 44.35988746583462, 46.36840268969536, 57.72175647318363, 59.99734416604042, 49.39237542450428, 66.78231328725815, 81.57518550753593, 63.35783824324608, 87.41053998470306, 6.427363660186529, 0.8173643436748534, 0.5172742588911206, 1.1007653083652258, 0.22013863432221115, 1.33637641556561, 22.187769412994385, 50.46693876385689, 74.08742889761925, 65.6169918179512, 70.66879794001579, 59.81983669102192, 58.532363176345825, 53.35819222033024, 54.31515946984291, 51.2051897495985, 52.429256066679955, 50.173537507653236, 48.69452387094498, 48.14130775630474, 50.47893472015858, 53.0650569498539, 58.32400895655155, 61.157399117946625, 65.22096946835518, 59.28789563477039, 61.369515135884285, 59.220726639032364, 60.88805817067623, 62.94484980404377, 65.41582301259041, 60.63089556992054, 60.755635276436806, 55.82878164947033, 56.965281665325165, 58.38741235435009, 59.87529091536999, 57.55993835628033, 59.28487479686737, 61.1857645958662, 57.792949452996254, 58.32207106053829, 51.75332933664322, 49.81492035090923, 52.11013779044151, 48.50076846778393, 53.2318452000618, 49.43383499979973, 49.205037876963615, 53.2011504471302, 50.650309324264526, 47.734152004122734, 45.030524879693985, 43.51780705153942, 45.189405754208565, 46.90506309270859, 47.45945334434509, 48.153075724840164, 48.20461615920067, 48.68943594396114, 51.609845235943794, 49.70266677439213, 51.902646124362946, 48.0189049243927, 52.43849717080593, 55.36397159099579, 56.575316190719604, 59.10530783236027, 48.175046145915985, 46.86167702078819, 51.91312216222286, 60.305188447237015, 59.92116965353489, 57.176060155034065, 48.707032799720764, 49.232434406876564, 49.36183646321297, 47.22580008208752, 52.81465798616409, 50.094053372740746, 44.05461944639683, 43.31765279173851, 45.26814892888069, 46.24703340232372, 43.570643216371536, 42.265918627381325, 43.2017932087183, 41.89691282808781, 44.32522572577, 49.833520352840424, 52.670657113194466, 51.451101154088974, 48.868185952305794, 48.5063161700964, 49.93879370391369, 49.38873142004013, 53.7238048017025, 54.3079474568367, 57.221577912569046, 56.0077216476202, 63.058345913887024, 58.095945194363594, 57.096344232559204, 60.481339395046234, 56.62481613457203, 61.00992143154144, 59.31521236896515, 62.14741699397564, 65.73375195264816, 62.00337812304497, 61.05325810611248, 64.3920211493969, 65.5656261742115, 57.191529124975204, 59.73027549684048, 63.670409470796585, 61.38309180736542, 55.31523160636425, 49.10817347466946, 48.965738117694855, 49.80253301560879, 54.59746152162552, 57.39748187363148, 56.754434779286385, 56.042960956692696, 57.657585516572, 58.25750112533569, 58.28710153698921, 53.30925464630127, 61.251607462763786, 59.982008188962936, 71.83078318834305, 67.50951066613197, 88.61071318387985, 32.79125243425369, 3.1428115954622626, 1.449031939264387, 0.24101968650938943, 1.645331543404609, 63.99360492825508, 82.49787479639053, 73.05077612400055, 69.62952330708504, 45.62751844525337, 42.04109609127045, 63.9486001431942, 35.666387155652046, 60.76801881194115, 77.3267474770546, 85.01817315816879, 16.04288164526224, 0.8521852595731616, 0.29103229113388807, 0.21508312434889376, 0.17947208834812045, 0.22509868926135823], [0.08633960533188656, 0.03401378577109426, 0.16571477812249213, 0.002588622924122319, 0.06793097360059619, 0.021344044725992717, 0.2791043749311939, 0.18444654095219448, 30.028783567249775, 69.38094064593315, 47.121336087584496, 26.90943595021963, 82.41811707615852, 89.65585470199585, 50.30924342572689, 50.59273861348629, 31.86585959047079, 74.739451110363, 52.86082550883293, 72.24392741918564, 18.85622028261423, 0.27147150482051075, 0.2870422083651647, 0.05443936708616093, 0.3976160375168547, 0.05780615712865256, 9.24580067396164, 45.14821216464043, 71.42771601676941, 62.20855191349983, 60.4347462952137, 51.41173146665096, 49.31922174990177, 47.75690518319607, 47.44730919599533, 46.02226786315441, 44.516948238015175, 45.96187390387058, 45.295043885707855, 44.94269639253616, 46.79790124297142, 53.328527212142944, 54.060934111475945, 57.04726606607437, 58.03487867116928, 54.68497842550278, 57.60142832994461, 57.02796310186386, 56.29484944045544, 57.49785728752613, 56.98163978755474, 55.87988890707493, 53.72822016477585, 50.60531213879585, 50.982312709093094, 55.733026787638664, 50.91915249824524, 54.57877032458782, 52.03356049954891, 51.34762890636921, 49.44049224257469, 48.19371074438095, 45.979052782058716, 43.25634688138962, 43.35012964904308, 41.34107105433941, 41.982792019844055, 41.33153356611729, 40.68573161959648, 41.05411425232887, 44.834778383374214, 42.269520834088326, 41.401856392621994, 39.896593764424324, 38.5846571624279, 41.95836313068867, 41.26127913594246, 41.168442517519, 41.1203370988369, 43.26433025300503, 44.04363423585892, 47.481921538710594, 47.26220212876797, 47.535095885396004, 52.952917367219925, 52.23042033612728, 54.25703778862953, 53.29122081398964, 48.281060457229614, 45.5620251595974, 50.78503489494324, 54.68557499349117, 52.79643036425114, 52.36718259751797, 47.22014598548412, 43.41783061623573, 47.147790268063545, 43.5994266718626, 46.491272896528244, 44.174009039998055, 42.872176095843315, 43.37959326803684, 44.45227190852165, 41.0404159873724, 41.1615876853466, 40.00711843371391, 40.05450949072838, 39.82823543250561, 42.493762001395226, 45.87123356759548, 42.93712601065636, 43.101691380143166, 40.49356833100319, 42.55077414214611, 43.053806349635124, 44.042338505387306, 44.666010439395905, 50.54867997765541, 48.26231986284256, 47.52596877515316, 50.903242751955986, 53.469359055161476, 51.215764582157135, 53.39547961950302, 51.21357969939709, 48.720126897096634, 54.048413783311844, 54.632393047213554, 54.531025886535645, 56.071353033185005, 59.78501535952091, 58.11533935368061, 59.13356691598892, 54.69021074473858, 55.162031427025795, 58.765317276120186, 55.66621117293835, 50.41959710419178, 42.57694333791733, 45.33715322613716, 41.86396859586239, 47.500966116786, 46.850334629416466, 49.42275479435921, 48.44403751194477, 50.03802537918091, 51.483756601810455, 52.48472549021244, 50.17261415719986, 52.945070788264275, 54.56515185534954, 67.50917628407478, 63.06168593466282, 80.45941337943077, 12.704841513186693, 1.6111401468515396, 0.33390939817763865, 0.620107309659943, 2.7382463542744517, 60.25796078145504, 65.41775330901146, 56.920698657631874, 64.5244288444519, 36.632002741098404, 29.418348222970963, 56.08312860131264, 36.41658470034599, 41.10148251056671, 54.248028472065926, 58.94219018518925, 8.768684975802898, 0.4078544693766162, 0.17092039488488808, 0.049909115841728635, 0.14441683189943433, 0.024571459434810095, 0.07285039595444687, 0.03561085046385415, 0.11541818326804787, 0.057977418837253936, 0.04120743433304597, 0.02274121936352458, 0.4109878762392327, 0.27336119092069566, 36.70516401529312, 77.68400430679321, 55.75174078345299, 30.85336782038212, 42.41442605853081, 79.62614849209785, 60.349068492650986, 54.24158401787281, 40.02611741423607, 83.50773900747299, 57.85786896944046, 79.58527028560638, 21.160897314548492, 0.44772163324523717, 0.2849862218135968, 0.06272145314142108, 0.5118778953328729, 0.08257508350652643, 10.865098033100367, 48.82670357823372, 72.69547238945961, 65.21046683192253, 62.796528562903404, 55.59189856052399, 52.857219502329826, 49.70814228057861, 50.09010538458824, 47.741424813866615, 47.41884492337704, 48.48618105053902, 48.82418431341648, 46.44886717200279, 49.84428897500038, 55.4928682744503, 56.32122382521629, 61.19574286043644, 61.61245509982109, 54.798341542482376, 60.31673222780228, 57.375150471925735, 59.105820804834366, 60.089838802814484, 57.57461316883564, 55.67643642425537, 54.83395703136921, 51.62054546177387, 55.597822442650795, 58.14068779349327, 50.79196572303772, 58.486400842666626, 54.317359551787376, 54.22653302550316, 52.201363295316696, 50.98558433353901, 48.5432767868042, 46.680476143956184, 47.62327015399933, 46.239342615008354, 44.82986904680729, 43.855339139699936, 46.282090321183205, 46.41392044723034, 48.4706474840641, 45.593502670526505, 43.80609378218651, 42.43596330285072, 39.98526580631733, 43.78191947937012, 44.16531890630722, 45.24006463587284, 44.41322140395641, 47.06075593829155, 45.52645906805992, 47.61548437178135, 50.490296110510826, 49.07069608569145, 55.18118239939213, 52.75908216834068, 55.84983251988888, 55.12270733714104, 49.913373067975044, 46.101976186037064, 52.571106255054474, 57.36579157412052, 54.004887118935585, 54.89845857024193, 48.02520118653774, 46.891520619392395, 48.10878910124302, 44.561732634902, 48.781972378492355, 45.158543810248375, 44.87960457801819, 47.11290054023266, 45.491956919431686, 42.91517838835716, 43.390624076128006, 42.948502600193024, 41.2570271641016, 42.95046329498291, 44.15663257241249, 47.98207730054855, 45.56918777525425, 46.2007936835289, 44.58409823477268, 45.47451585531235, 46.9110743701458, 46.03209413588047, 48.43708388507366, 51.101645305752754, 52.63354450464249, 52.00235277414322, 54.635634273290634, 56.65784776210785, 54.170372039079666, 56.16213396191597, 53.29548418521881, 52.87338003516197, 55.20384058356285, 56.63159117102623, 57.85621605813503, 57.73724444210529, 61.54987245798111, 59.68758478760719, 62.64683559536934, 56.222987696528435, 55.906958654522896, 60.49736313521862, 59.6215595304966, 52.36185148358345, 46.799147576093674, 48.234421759843826, 45.607789903879166, 50.16680046916008, 50.300758481025696, 51.91766671836376, 51.55097879469395, 53.49513307213783, 54.2341136187315, 55.20128712058067, 54.552772119641304, 55.697278305888176, 57.48495697975159, 71.46922498941422, 66.50782361626625, 84.65288355946541, 14.598124120384455, 1.326900792773813, 0.5844766215886921, 1.7186216544359922, 3.819234911352396, 68.48922729492188, 71.90177097916603, 64.92835476994514, 71.62174880504608, 46.02709360420704, 39.162807539105415, 62.56354786455631, 36.172766983509064, 49.277385994791985, 62.61220425367355, 68.30280169844627, 12.766136024147272, 0.6894395174458623, 0.19222058239392936, 0.12294075539102778, 0.043313267233315855, 0.062343254685401917, 0.14244864141801372, 0.14428176102228463, 0.24109422782203183, 0.2319785169675015, 0.09877882417640649, 0.16548584040720016, 0.6035399611573666, 0.37354180589318275, 44.85253103077412, 88.53050708770752, 64.6606895327568, 40.40152586996555, 106.42263740301132, 105.37688791751862, 63.93810510635376, 63.54917697608471, 46.13086983561516, 88.11901196837425, 65.14632627367973, 88.35785195231438, 25.889340788125992, 0.7909399084746838, 0.6637108011636883, 0.1484564456040971, 0.7612995395902544, 0.12200939716421999, 12.920320350676775, 48.845675960183144, 78.0742509663105, 67.79508054256439, 67.75788813829422, 57.804725021123886, 54.646482691168785, 53.12506712973118, 52.26221702992916, 49.39541146159172, 48.97806465625763, 50.32449200749397, 51.64840556681156, 49.80613902211189, 52.58587226271629, 57.60576769709587, 59.831091687083244, 59.66434143483639, 63.73004727065563, 57.17775106430054, 61.066519394516945, 60.081152468919754, 61.75766050815582, 62.85791426897049, 60.407695546746254, 60.27237720787525, 58.026443123817444, 55.12287072837353, 57.53056213259697, 60.7088939845562, 55.4013691842556, 61.441848054528236, 58.30725185573101, 58.7019594758749, 57.66151450574398, 56.836928352713585, 54.82790395617485, 51.875059604644775, 51.72289676964283, 49.78463217616081, 48.686358109116554, 47.07382343709469, 49.642132222652435, 50.06111294031143, 51.74989052116871, 49.695477560162544, 46.824161633849144, 46.375147327780724, 42.703381553292274, 45.20699501037598, 47.58747607469559, 47.22530610859394, 46.59107454121113, 50.090090185403824, 48.59534539282322, 51.46430164575577, 52.95877285301685, 50.80199338495731, 56.91442519426346, 55.19890084862709, 58.7627562135458, 56.824373826384544, 50.86669631302357, 47.73042820394039, 54.406916946172714, 59.64581362903118, 55.98382852971554, 57.56398133933544, 51.2088717520237, 48.15607376396656, 51.8954873085022, 45.88197939097881, 52.01241843402386, 48.959392458200455, 46.44032523036003, 47.632955834269524, 47.389806881546974, 46.21945448219776, 46.23615838587284, 45.88038727641106, 45.34648172557354, 44.31603021919727, 49.03262972831726, 52.3078715801239, 48.73316019773483, 49.414710626006126, 48.25554862618446, 48.93054440617561, 51.01795479655266, 52.94542796909809, 51.45869314670563, 56.9682303071022, 56.92033387720585, 55.74549771845341, 58.52132096886635, 61.368538588285446, 57.662323862314224, 58.53429727256298, 57.58510060608387, 53.86459484696388, 57.668996304273605, 58.715794533491135, 60.24431571364403, 59.83305238187313, 66.00831761956215, 62.97710247337818, 63.70067484676838, 57.40287758409977, 57.8386116027832, 64.9091050028801, 61.88353255391121, 55.550993755459785, 48.88523183763027, 49.50204133987427, 46.89910501241684, 52.85740189254284, 53.529342636466026, 54.51238788664341, 55.430502220988274, 56.713077798485756, 58.4402447193861, 58.78542959690094, 57.50205226242542, 58.09084966778755, 59.39343497157097, 73.53467255830765, 70.19690126180649, 88.59306693077087, 18.487934544682503, 1.6110412334091961, 1.1379737430252135, 1.4010453829541802, 4.352443674579263, 76.09033182263374, 77.43300497531891, 72.63602837920189, 78.01926031708717, 51.531022265553474, 43.278150111436844, 82.56868779659271, 49.507817029953, 57.99254134297371, 71.36700287461281, 82.93803557753563, 21.04392059147358, 1.0219359258189797, 0.29904528928454965, 0.30137524707242846, 0.2356325849541463, 0.3243064822163433], [0.010854365264094668, 0.024554145129513927, 0.035476488337735645, 0.05890773063583765, 0.020804041378141847, 0.036253750731702894, 0.3063817456131801, 0.041602806086302735, 34.993929639458656, 76.88393443822861, 39.99486029148102, 36.37722261250019, 92.48014435172081, 85.46445161104202, 49.661040008068085, 41.571996062994, 24.44946125149727, 61.943379342556, 58.34475204348564, 58.770925775170326, 44.30645473301411, 0.0689892761874944, 0.09489036368904635, 0.14834588044323027, 0.2987210894934833, 0.0879086391068995, 2.3274943325668573, 43.765967935323715, 70.23947417736053, 62.792208194732666, 60.655271261930466, 52.584090158343315, 49.942726492881775, 48.62245313823223, 47.50095471739769, 46.761932373046875, 46.082031056284904, 46.57187417149544, 44.09611701965332, 45.53728848695755, 53.00010323524475, 55.158850997686386, 56.14527426660061, 59.972626492381096, 49.20741654932499, 57.15119808912277, 58.18567357957363, 57.344254329800606, 56.518342047929764, 53.71783912181854, 54.95654225349426, 53.510852828621864, 50.206481739878654, 48.92290681600571, 52.707066759467125, 56.1089064180851, 50.711379647254944, 54.70822937786579, 50.249263644218445, 53.000167831778526, 50.30225180089474, 48.21283891797066, 42.87957809865475, 43.6814034730196, 44.64457578957081, 43.32818202674389, 41.64267987012863, 42.512308806180954, 42.46779419481754, 42.01323978602886, 40.21899126470089, 44.54592168331146, 44.51178811490536, 42.36927308142185, 39.06454101204872, 41.17515675723553, 40.99098064005375, 40.59242382645607, 44.00845192372799, 43.71892645955086, 46.90656021237373, 48.798334300518036, 50.993822291493416, 50.25466315448284, 52.95328974723816, 49.85246993601322, 53.473405838012695, 53.79501298069954, 45.56900538504124, 45.259542390704155, 50.48426203429699, 54.38110873103142, 51.799341067671776, 54.76459555327892, 50.99276974797249, 45.989745408296585, 44.90766227245331, 43.04244115948677, 45.21256931126118, 43.035799115896225, 42.759626135230064, 40.67667290568352, 41.070346981287, 39.49204467236996, 41.10511511564255, 39.02435056865215, 42.141038328409195, 44.732636064291, 46.79401785135269, 42.732940167188644, 41.80980630218983, 41.96811340749264, 39.02684323489666, 43.432608023285866, 44.0166062861681, 40.678565204143524, 47.46162302792072, 48.04029777646065, 47.92816199362278, 46.46312780678272, 49.45282258093357, 51.591913998126984, 50.48669770359993, 54.940560311079025, 52.667191699147224, 50.13291388750076, 50.58076165616512, 52.03656993806362, 56.36709116399288, 55.01731239259243, 59.18179392814636, 55.648621916770935, 60.47552190721035, 56.37687563896179, 55.46736404299736, 56.365191265940666, 56.080863922834396, 49.82958756387234, 43.07206057012081, 46.654614731669426, 45.8205708861351, 44.83209192752838, 45.141718313097954, 46.8270418792963, 49.57834504544735, 50.47529071569443, 50.93628577888012, 50.72102352976799, 51.06256440281868, 52.7674151211977, 57.70257510244846, 62.582706436514854, 64.6767246723175, 66.73599377274513, 4.6005128882825375, 1.0176345566287637, 0.24407173914369196, 1.1255538719706237, 6.257419204339385, 66.00210875272751, 63.34382839500904, 61.727357134222984, 57.27757170796394, 22.79008649289608, 33.36576260626316, 56.93760775029659, 30.53553957492113, 39.940876588225365, 55.84939934313297, 53.37657183408737, 9.701264183968306, 0.18598318740259856, 0.1787899507326074, 0.07147240583435632, 0.10603774091578089, 0.06585969880688936, 0.024847282329574227, 0.020769164148077834, 0.04620425526809413, 0.038047881607781164, 0.0797794280515518, 0.0666873790032696, 0.26729315402917564, 0.13339351949980482, 42.09590055048466, 83.85977491736412, 52.63333551585674, 38.697552904486656, 89.062410145998, 89.41941618919373, 61.38096012175083, 52.90059797465801, 28.435777947306633, 69.28634092211723, 62.751842960715294, 68.20032119750977, 48.46371665596962, 0.1370962426881306, 0.23908020230010152, 0.2835369558306411, 0.5036550178192556, 0.01908709014969645, 2.665480733849108, 44.739517495036125, 73.23796167969704, 67.08021730184555, 63.827987015247345, 54.091583266854286, 51.21414586901665, 50.79988829791546, 50.036000087857246, 49.50435161590576, 49.326110780239105, 49.90460693836212, 46.425243839621544, 47.920972779393196, 56.66725605726242, 59.59307245910168, 59.12318967282772, 64.03094172477722, 52.63826385140419, 58.22657458484173, 59.412973523139954, 59.57038767635822, 59.38448645174503, 54.66198965907097, 56.49395115673542, 55.58888912200928, 54.45469558238983, 53.90359215438366, 55.13753794133663, 57.54079878330231, 53.58060568571091, 55.61354219913483, 54.52315650880337, 56.06075540184975, 54.73508633673191, 51.56287595629692, 47.510606199502945, 47.11721710860729, 49.24091935157776, 45.52715063095093, 45.014687329530716, 46.53326824307442, 46.33629821240902, 45.571422055363655, 45.09934678673744, 49.22561377286911, 47.43736892938614, 45.49018241465092, 42.81203672289848, 43.13475340604782, 43.269353583455086, 43.02504949271679, 45.310341864824295, 46.26600578427315, 49.414159655570984, 51.060227528214455, 51.827569752931595, 51.14968232810497, 54.95869293808937, 51.67019359767437, 54.040088430047035, 55.797889307141304, 48.04129712283611, 46.26263536512852, 51.65858522057533, 55.79556003212929, 52.68962949514389, 55.781356394290924, 52.03506901860237, 47.04880937933922, 47.49156542122364, 45.295822843909264, 47.415292114019394, 44.68552619218826, 45.4290284961462, 42.824025079607964, 42.80103251338005, 43.05435352027416, 42.31910817325115, 42.14282423257828, 43.81962105631828, 46.2018196284771, 49.838228300213814, 45.21304048597813, 45.01072034239769, 43.7906514108181, 42.90605127811432, 46.19339928030968, 48.65420423448086, 44.834402203559875, 48.894419744610786, 50.37712298333645, 52.82221958041191, 48.86001639068127, 53.56898970901966, 55.51915906369686, 52.59973391890526, 57.883726581931114, 56.27387836575508, 51.295058727264404, 52.84741222858429, 52.47600495815277, 57.91538268327713, 56.25853478908539, 60.6365192681551, 57.834523022174835, 63.50499674677849, 58.108020946383476, 57.36840583384037, 59.52062174677849, 59.28269751369953, 52.83682219684124, 46.565688103437424, 49.39748615026474, 47.578649148344994, 46.14654779434204, 49.34422440826893, 49.25152838230133, 51.76822833716869, 52.13009051978588, 55.10057732462883, 53.22796180844307, 54.28965903818607, 56.15355782210827, 63.47814738750458, 65.29615983366966, 68.41222822666168, 69.59797739982605, 5.5946331191807985, 0.9448323037941009, 0.5813358526211232, 0.6783783703576773, 6.841594157740474, 71.7250044643879, 69.48509305715561, 69.39516708254814, 65.56352108716965, 33.04675072431564, 31.2355475127697, 65.25652036070824, 33.32913637161255, 41.35337099432945, 64.90148261189461, 64.78462368249893, 15.27691399678588, 0.575789634604007, 0.18287168873939663, 0.1258493063505739, 0.07034967740764841, 0.06601062195841223, 0.15622993785655126, 0.2125943618011661, 0.19062812643824145, 0.23775710142217577, 0.18633854255313054, 0.1830874607549049, 0.5568033596500754, 0.1895124261500314, 48.09235878288746, 98.65988194942474, 53.61577659845352, 49.42419491708279, 105.72531402111053, 88.19627702236176, 65.82732573151588, 52.87699744105339, 40.89217074215412, 73.36368933320045, 68.59154060482979, 71.74551576375961, 54.638978093862534, 0.24489653238561004, 0.35759236954618245, 0.5640919622965157, 1.0927381203509867, 0.27233610686380416, 4.106659088283777, 48.4709058701992, 74.44362178444862, 68.60135167837143, 65.22837907075882, 59.482167810201645, 54.96843561530113, 54.307890459895134, 52.56440341472626, 51.403706297278404, 53.19341406226158, 52.37804241478443, 48.81396286189556, 50.78711338341236, 59.05370280146599, 60.48719868063927, 61.70206569135189, 62.011984661221504, 55.06449446082115, 60.2772181481123, 61.3000700622797, 61.13767817616463, 60.738783180713654, 56.391542851924896, 58.889870792627335, 58.462063148617744, 56.073686107993126, 55.85316114127636, 59.843277633190155, 59.89971600472927, 57.489714324474335, 57.893906235694885, 58.06289456784725, 61.18870943784714, 60.24892866611481, 56.23246058821678, 50.50635404884815, 51.65630914270878, 54.56190302968025, 52.17205546796322, 48.81211996078491, 49.64459829032421, 49.49215427041054, 49.70667935907841, 49.94859337806702, 50.97580745816231, 51.62049986422062, 47.995627373456955, 44.59648177027702, 47.13018201291561, 44.911055490374565, 45.96890352666378, 48.4240847826004, 48.16210024058819, 53.43540407717228, 55.19627518951893, 56.81376099586487, 53.93410071730614, 57.94663980603218, 54.30225916206837, 57.23213754594326, 57.774471044540405, 49.00686331093311, 44.980789348483086, 52.96875111758709, 57.726878598332405, 54.77884478867054, 59.389486983418465, 57.23692148923874, 50.06197929382324, 51.52317188680172, 48.65877538919449, 50.98982110619545, 47.215696424245834, 46.01769670844078, 44.93661671876907, 44.8836475610733, 44.594407081604004, 44.22574706375599, 44.193809777498245, 45.058206394314766, 49.915371760725975, 55.19462987780571, 49.86535124480724, 49.72651049494743, 47.909653186798096, 46.57988794147968, 51.768513321876526, 52.32753552496433, 48.998032584786415, 54.46031168103218, 55.09252555668354, 57.05842226743698, 54.36525598168373, 58.59487362205982, 56.951192021369934, 54.134140983223915, 59.51839126646519, 60.4245400428772, 53.92267853021622, 55.43121658265591, 55.16243040561676, 60.29885418713093, 60.448136776685715, 62.48147986829281, 60.32144017517567, 65.52015781402588, 58.79053272306919, 60.905734822154045, 61.59647315740585, 62.51940943300724, 56.90548047423363, 48.62063303589821, 53.54556396603584, 51.050040274858475, 50.31264044344425, 52.68815137445927, 51.65839523077011, 54.138058573007584, 54.74952556192875, 58.4035424888134, 56.3231997191906, 58.07250805199146, 58.954330533742905, 64.41552668809891, 68.48233446478844, 71.45805358886719, 71.677415817976, 9.702263530343771, 1.2472384236752987, 0.7212647097185254, 1.539653989020735, 8.223452232778072, 80.5635429918766, 75.42545109987259, 75.10133609175682, 69.36572626233101, 39.503181874752045, 46.279913038015366, 78.99971410632133, 43.43760475516319, 55.14749340713024, 74.25141289830208, 78.44629660248756, 20.707118064165115, 0.8703628310468048, 0.41330049745738506, 0.26187785086221993, 0.2406690365751274, 0.21975717041641474], [0.12407953647198156, 0.017491105281806085, 0.04212682913930621, 0.050507691339589655, 0.10259295115247369, 0.08027058880543336, 0.19390717236092314, 0.13060112949460745, 34.89801898598671, 79.63208377361298, 40.38166053593159, 48.28087046742439, 80.2289329469204, 86.97878435254097, 49.1810155659914, 32.48166024684906, 28.509163409471512, 53.395019844174385, 63.502447083592415, 51.672538071870804, 57.90563240647316, 4.889218546450138, 0.17784206487704068, 0.2866309694945812, 0.3918165690265596, 0.25131866277661175, 0.1004691916750744, 30.47324001789093, 69.50117379426956, 62.78962433338165, 60.80715291202068, 53.832475170493126, 54.698019325733185, 53.96302476525307, 50.26029445230961, 48.18879000842571, 48.02827522158623, 46.43116012215614, 46.15839175879955, 50.74296735227108, 56.30603983998299, 55.30508615076542, 58.27598713338375, 52.21093878149986, 48.5269870609045, 58.26211027801037, 58.34420867264271, 57.997443079948425, 52.899784818291664, 53.08593302965164, 51.286566182971, 53.23839984834194, 49.60294492542744, 49.993088990449905, 54.34489667415619, 57.71374270319939, 51.32810935378075, 52.83731997013092, 49.86421510577202, 49.27168250083923, 45.46420320868492, 46.868505254387856, 44.76555749773979, 42.756384909152985, 43.3400259912014, 44.783678725361824, 39.98354069888592, 40.47586128115654, 42.41679333150387, 37.17607654631138, 35.09227596223354, 37.37776592373848, 43.57995271682739, 43.22515055537224, 40.95705606043339, 42.442327961325645, 41.482849046587944, 42.164619863033295, 42.47246794402599, 46.209681406617165, 47.61838361620903, 50.26167377829552, 50.66207729279995, 48.78268674015999, 50.76384723186493, 49.86309036612511, 55.6304968893528, 53.435426875948906, 45.531873777508736, 44.925460517406464, 50.72104632854462, 56.78345002233982, 52.45795212686062, 50.75161188840866, 51.83285906910896, 48.475579619407654, 46.7430017888546, 42.843062058091164, 46.55448630452156, 42.79458425939083, 42.83462651073933, 41.53932921588421, 40.65738134086132, 39.8398058116436, 44.691317081451416, 41.274206042289734, 43.18861171603203, 41.02091543376446, 40.70074461400509, 39.23772431910038, 38.958443105220795, 41.14223912358284, 38.828022703528404, 43.448403775691986, 44.389153495430946, 42.177884951233864, 46.11510448157787, 47.890753000974655, 49.4510480761528, 47.354692965745926, 51.5701449662447, 51.75894923508167, 50.97037374973297, 56.56312644481659, 52.05778419971466, 50.60802519321442, 50.382454097270966, 49.36393015086651, 51.75375871360302, 52.761004865169525, 55.47154761850834, 57.07750104367733, 59.4359926879406, 59.39508408308029, 57.372038438916206, 56.491846069693565, 54.94042731821537, 48.98988962173462, 46.990588903427124, 46.67617477476597, 44.50738035142422, 44.19179208576679, 46.20742432773113, 45.79103507101536, 47.896524891257286, 49.275809079408646, 50.80114983022213, 48.09598758816719, 52.90904112160206, 53.88046279549599, 61.20965391397476, 65.90578392148018, 71.7785207927227, 49.74975764751434, 0.9723801130894572, 0.4967186087742448, 0.13928854692494497, 1.5310660935938358, 7.7832206804305315, 67.4355286359787, 57.598361894488335, 64.04269829392433, 37.92144075036049, 17.686373256146908, 41.44304238259792, 56.80121026933193, 34.83385942876339, 42.548832446336746, 51.10154651105404, 67.30418488383293, 10.703069027513266, 0.29202650184743106, 0.3015367384068668, 0.056997824722202495, 0.07624342091730796, 0.035930845988332294, 0.22193129203515127, 0.06457406154368073, 0.04201649033348076, 0.033948217023862526, 0.031695490833953954, 0.0372216671530623, 0.20430846110684797, 0.22861779027152807, 41.02408446371555, 90.36503344774246, 48.8313203305006, 44.30815324187279, 83.02628204226494, 90.13580694794655, 55.90247109532356, 38.20595048367977, 34.898444563150406, 59.08100053668022, 71.4894551038742, 57.77018867433071, 66.52357757091522, 6.154339285567403, 0.1591388153610751, 0.5225173837970942, 0.33032491395715624, 0.32328214030712843, 0.3112952975789085, 31.480925045907497, 72.46819138526917, 65.59207275509834, 61.53267078101635, 54.21403929591179, 57.297665029764175, 55.71930572390556, 53.412863686680794, 50.766108110547066, 50.96281595528126, 48.83951649069786, 48.620648235082626, 53.76205734908581, 59.38618876039982, 57.61386886239052, 62.342088147997856, 54.97753992676735, 48.290837332606316, 60.63852176070213, 59.307464584708214, 60.01375548541546, 56.410560831427574, 56.23449727892876, 53.67110922932625, 54.94995720684528, 53.40996444225311, 51.433584094047546, 53.91027979552746, 60.360832661390305, 53.62340658903122, 56.80354334414005, 53.33531744778156, 52.42188446223736, 50.024954080581665, 52.02668286859989, 49.626070484519005, 46.34413719177246, 48.26529510319233, 47.38718882203102, 44.91716556251049, 43.516686111688614, 46.35994054377079, 40.88447995483875, 39.03575375676155, 42.78309367597103, 47.008691132068634, 47.07590952515602, 42.680126801133156, 44.58975613117218, 44.55858260393143, 45.24485997855663, 44.635140895843506, 47.42800623178482, 49.95649695396423, 49.46453735232353, 53.563582599163055, 51.607660353183746, 53.90577703714371, 51.675308123230934, 58.33992250263691, 52.80541688203812, 46.59471854567528, 47.346314415335655, 51.55221752822399, 57.50070333480835, 54.74106341600418, 53.04937519133091, 54.739661291241646, 49.986237958073616, 48.55402261018753, 45.24935133755207, 47.99316890537739, 45.53143300116062, 45.7210960239172, 43.81154648959637, 43.11362273991108, 42.1387280523777, 45.69080024957657, 44.28206004202366, 46.080598533153534, 43.716274201869965, 45.41512504220009, 43.596136048436165, 44.864139407873154, 45.735181868076324, 42.335283905267715, 45.97574695944786, 48.304565995931625, 45.724162459373474, 49.52923268079758, 49.92445707321167, 52.64228783547878, 51.11344367265701, 54.44307200610638, 54.76098954677582, 53.57275150716305, 56.92086964845657, 54.1433896869421, 51.545944064855576, 53.050674721598625, 50.54041922092438, 54.533024579286575, 56.403907388448715, 57.75442332029343, 60.0629286468029, 61.70964628458023, 61.004195138812065, 60.17462745308876, 60.04126600921154, 57.296574488282204, 50.72826974093914, 49.36273701488972, 47.78597742319107, 47.97895006835461, 46.50443539023399, 48.59148859977722, 47.7840319275856, 51.11036963760853, 52.05558031797409, 54.41575147211552, 50.97033195197582, 57.78374254703522, 56.65524870157242, 64.3801885843277, 67.1299946308136, 76.20799630880356, 52.1281336247921, 2.100346558727324, 0.5075618019327521, 0.4295568563975394, 1.0318454378284514, 9.716122336685658, 76.69007644057274, 62.09056444466114, 72.99132451415062, 44.78836007416248, 19.279063493013382, 34.458048194646835, 69.30331081151962, 35.97909517586231, 39.578524231910706, 57.76496395468712, 76.3063882291317, 15.311149209737778, 0.7527963677421212, 0.30201287067029625, 0.11089842970250174, 0.22228979389183223, 0.04213440275634639, 0.32417918904684484, 0.15421450225403532, 0.16426282556494698, 0.1961783817387186, 0.18154590128688142, 0.25732234062161297, 0.3988407296128571, 0.48703836102504283, 49.44507099688053, 99.61092531681061, 55.10463930666447, 61.0856019705534, 90.08524686098099, 92.70058572292328, 65.57498887181282, 44.46588657796383, 45.31526640057564, 65.47960638999939, 76.52036994695663, 61.66027173399925, 72.15296030044556, 7.548776585608721, 0.18213883275166154, 0.8476977003738284, 0.7493712077848613, 1.2180216726846993, 0.5480974924284965, 35.88257275521755, 74.7927850484848, 69.13763210177422, 63.674026876688, 58.41194003820419, 60.186653807759285, 59.712462052702904, 55.55960029363632, 54.73774619400501, 51.430263072252274, 50.98312586545944, 49.75097358226776, 55.52897773683071, 61.500836089253426, 61.71601094305515, 62.59570173919201, 55.906837061047554, 49.96682099997997, 61.58168815076351, 62.53256052732468, 62.530527636408806, 60.12642703950405, 58.451138734817505, 56.046433970332146, 58.73624883592129, 56.99810430407524, 52.95039050281048, 58.415124267339706, 63.49123768508434, 56.77139326930046, 60.12757457792759, 56.29831485450268, 57.404382303357124, 53.2945342361927, 55.85421748459339, 53.64862583577633, 49.787052646279335, 51.84843823313713, 50.69162830710411, 48.01334202289581, 49.069582745432854, 50.28600387275219, 45.66626876592636, 46.803144961595535, 49.683447405695915, 51.06171324849129, 52.071284875273705, 46.22547335922718, 47.89569653570652, 45.875428542494774, 47.54100076854229, 46.34651206433773, 52.054941952228546, 51.79598584771156, 53.48734349012375, 54.833611249923706, 54.14737567305565, 55.64143270254135, 55.13867788016796, 61.31732493638992, 55.169270038604736, 46.38731047511101, 47.300686463713646, 53.98476339876652, 61.74626111984253, 56.051347106695175, 57.60898992419243, 58.470852077007294, 53.00012223422527, 52.276093885302544, 48.268034756183624, 51.67949929833412, 48.02629552781582, 47.03101493418217, 44.9875757843256, 46.86002030968666, 43.98224852979183, 49.66665230691433, 44.930837228894234, 48.551529943943024, 46.46359898149967, 48.442308604717255, 47.48629130423069, 47.39449582993984, 48.993822410702705, 46.86454966664314, 49.32651735842228, 51.08155198395252, 49.896893352270126, 53.95230174064636, 55.01288942992687, 59.529718458652496, 56.32117822766304, 58.099855184555054, 56.370001807808876, 56.10801346600056, 61.868865340948105, 56.509408727288246, 53.56815755367279, 54.4610982388258, 54.22142989933491, 55.82916542887688, 57.71733731031418, 62.01727777719498, 61.94189362227917, 64.71422106027603, 62.90180191397667, 61.803660839796066, 63.47815118730068, 61.08104221522808, 53.28164532780647, 52.90700063109398, 51.39590531587601, 50.130960792303085, 49.84305024147034, 50.8726391941309, 51.248222440481186, 52.99070633947849, 55.037287920713425, 56.398633271455765, 52.410758659243584, 60.67504160106182, 59.77550446987152, 67.21236661076546, 71.58177495002747, 76.71048894524574, 57.99437664449215, 3.750108308158815, 0.9196096728555858, 0.5210335634183139, 3.1388878310099244, 10.465114396065474, 84.91808652877808, 67.45755985379219, 78.94130364060402, 53.009230345487595, 32.271185740828514, 51.64293386042118, 79.66514959931374, 50.2925281226635, 57.79471255838871, 69.21001061797142, 89.60282474756241, 20.76364003121853, 1.1235346365720034, 0.5065009463578463, 0.21506400662474334, 0.28255165088921785, 0.19539344182703644], [0.0005224837343575928, 0.11552220268640667, 0.14024291915120557, 0.04655605924199335, 0.09307800937676802, 0.07141943875467405, 0.7253623742144555, 0.23448494262993336, 33.74863386154175, 68.63696336746216, 68.03641319274902, 41.16537608206272, 74.25302401185036, 75.49866557121277, 37.45368205010891, 27.831179089844227, 15.811614654958248, 63.236358761787415, 56.81746579706669, 59.694394022226334, 58.52867737412453, 19.095160961151123, 0.5849133606534451, 0.41155621293000877, 0.31842656491789967, 0.28195736871566623, 0.16151480114785954, 16.43907118588686, 68.73834192752838, 65.42731359601021, 61.69241040945053, 57.586415335536, 58.5265076905489, 58.68374325335026, 55.31365089118481, 52.990459352731705, 45.94801984727383, 48.40605854988098, 45.70654280483723, 57.22383879125118, 56.375762298703194, 60.21143227815628, 51.56429708003998, 45.52390560507774, 47.28775955736637, 60.42362429201603, 55.79458728432655, 55.290521532297134, 52.914714217185974, 52.751794159412384, 53.35409604012966, 53.125998079776764, 50.82438938319683, 51.584299206733704, 52.14598506689072, 55.60962460935116, 51.76573947072029, 51.79334878921509, 49.55865070223808, 48.440370708703995, 49.13000330328941, 47.802118957042694, 48.63736353814602, 45.15591435134411, 43.15104693174362, 44.49614055454731, 41.96009203791618, 41.484281569719315, 39.95224937796593, 41.121807619929314, 36.12189531326294, 35.13997480273247, 41.96137636899948, 44.61351625621319, 43.3363401889801, 42.650834172964096, 44.21720132231712, 42.812397703528404, 42.902977243065834, 44.48543652892113, 46.01380951702595, 51.067773923277855, 50.19204631447792, 49.004849418997765, 47.71368250250816, 51.085412576794624, 54.90293473005295, 50.924901589751244, 42.80098311603069, 43.25419619679451, 47.25438974797726, 53.72166931629181, 52.42896348237991, 50.54141476750374, 51.003450974822044, 50.60807079076767, 47.875291630625725, 44.03308980166912, 44.85175207257271, 43.680662512779236, 41.55001424252987, 39.99155066907406, 40.811147689819336, 40.2513275295496, 41.81225337088108, 42.47407525777817, 41.575590670108795, 39.36459571123123, 40.62982141971588, 35.29176905751228, 36.29171960055828, 42.247877195477486, 39.9901257455349, 39.88975033164024, 43.023776561021805, 41.625231206417084, 48.5830644518137, 46.536216884851456, 48.944523856043816, 49.11010377109051, 51.79611884057522, 48.87406803667545, 51.377742290496826, 54.75689336657524, 48.93526755273342, 51.74496978521347, 51.872418746352196, 51.20602570474148, 55.20369239151478, 53.26129361987114, 57.75715157389641, 57.77306132018566, 60.266882702708244, 61.633904948830605, 58.981540873646736, 56.49105951189995, 55.694276466965675, 50.722623243927956, 50.65991900861263, 50.103537663817406, 48.13397794961929, 46.73986695706844, 47.15719856321812, 46.05966545641422, 51.45150013267994, 49.56188052892685, 55.89199125766754, 53.14514145255089, 54.78930562734604, 56.2672933191061, 65.53599536418915, 59.652607664465904, 72.90268287062645, 30.468769557774067, 1.008973396383226, 0.35965830087661743, 0.3668926079990342, 0.25535778666380793, 14.74639406427741, 72.52278685569763, 52.87615768611431, 63.97283524274826, 34.354218766093254, 32.42182485759258, 28.158455528318882, 54.090295135974884, 33.43364976346493, 43.04775707423687, 53.13478320837021, 61.21422126889229, 9.095300249755383, 0.5965149099938571, 0.184206337435171, 0.09792234122869559, 0.05104180017951876, 0.13244088389910758, 0.007356581054409617, 0.12196653071441688, 0.10941313244984485, 0.1797132269712165, 0.12208159329020418, 0.02085732758132508, 0.5957154091447592, 0.22518072626553476, 37.98457436263561, 80.5100266635418, 64.92249548435211, 37.52713590860367, 89.7080411016941, 85.61019659042358, 40.85906691849232, 32.950076311826706, 26.209868788719177, 68.10640543699265, 67.84880965948105, 62.257322296500206, 67.25269764661789, 21.90547116100788, 0.3168739326065406, 0.647445892682299, 0.287028820021078, 0.42471170076169074, 0.06631941476371139, 18.156504929065704, 69.98444706201553, 67.54918813705444, 65.0756348669529, 61.26561351120472, 60.999487191438675, 61.35731399059296, 59.6089556068182, 56.824244633316994, 49.04030531644821, 50.69275684654713, 47.364526838064194, 57.10072539746761, 57.61036545038223, 60.97074173390865, 56.25842459499836, 47.24837467074394, 49.465483501553535, 62.55690202116966, 57.04361826181412, 55.91872662305832, 57.1115206182003, 55.406552106142044, 53.82093518972397, 54.15235720574856, 53.3510448038578, 54.21128064393997, 53.988293409347534, 57.22928769886494, 53.69657926261425, 55.8062906563282, 53.353499472141266, 53.151202127337456, 52.34509818255901, 52.69859321415424, 52.14453734457493, 47.44255565106869, 46.208507269620895, 48.197932317852974, 45.145210325717926, 45.44611617922783, 43.05244602262974, 45.858948826789856, 41.61695905029774, 41.69553503394127, 45.33208429813385, 47.36280933022499, 46.17161124944687, 46.136732921004295, 44.6835844963789, 43.334250301122665, 43.16556975245476, 45.29619142413139, 47.95717343688011, 52.03005708754063, 50.689086243510246, 50.94303421676159, 51.04798078536987, 53.98837320506573, 56.53348043560982, 52.318241223692894, 43.38381864130497, 42.07415051758289, 47.809536159038544, 56.055789068341255, 54.895213544368744, 50.271731838583946, 54.824202954769135, 51.05322450399399, 50.65127447247505, 46.72712244093418, 46.852135732769966, 46.14780932664871, 43.22642728686333, 41.77055440843105, 41.960445418953896, 43.76588433980942, 44.58210714161396, 44.97601680457592, 45.508866012096405, 42.07599721848965, 44.389427080750465, 40.795325338840485, 40.43858528137207, 44.18818607926369, 42.41185359656811, 43.79760883748531, 47.59909205138683, 45.62578573822975, 51.82686299085617, 50.66403038799763, 53.45868542790413, 52.037284299731255, 54.60729539394379, 51.99608691036701, 54.489668905735016, 57.83904477953911, 52.35997058451176, 54.8221168667078, 56.05202727019787, 54.23914834856987, 56.196028143167496, 54.53466609120369, 60.88167071342468, 58.50858025252819, 64.24755290150642, 62.12324269115925, 61.87562517821789, 59.80245262384415, 58.134114146232605, 54.653436318039894, 54.73187930881977, 51.11555255949497, 51.365290358662605, 48.2733316719532, 48.220727294683456, 49.42189984023571, 54.24797147512436, 52.6359573751688, 59.70974139869213, 54.97044950723648, 59.15686346590519, 60.35769782960415, 70.71678936481476, 62.068556025624275, 76.18911132216454, 32.143030017614365, 1.3262981688603759, 0.506427384680137, 0.3780504717724398, 0.4880367871373892, 17.556748911738396, 80.10429203510284, 60.102317333221436, 71.64383322000504, 39.844414964318275, 31.581783033907413, 27.755430154502392, 63.98934155702591, 36.30867429077625, 43.84306199848652, 60.64957156777382, 69.4602119922638, 11.861320026218891, 1.0275938222184777, 0.19015052472241223, 0.08908450530725531, 0.16846976388478652, 0.1735799404559657, 0.11203917005332187, 0.45291188755072653, 0.19198554422473535, 0.32361376157496125, 0.32422282733023167, 0.2618202898884192, 0.9305593196768314, 0.5146569118369371, 46.20910003781319, 90.9322290122509, 84.58882659673691, 52.3053865134716, 85.0201490521431, 83.81303742527962, 54.058988615870476, 41.573060005903244, 29.06961053609848, 73.41355785727501, 71.9183760881424, 71.08932137489319, 73.05607303977013, 24.50442150235176, 0.46761816716752946, 0.9896395588293672, 0.5216589861083776, 1.4201740315183997, 0.13118796050548553, 19.42671027034521, 73.85429620742798, 69.36359837651253, 66.92380249500275, 62.55253225564957, 63.10569517314434, 63.13864320516586, 61.81273855268955, 59.2478533834219, 50.56864410638809, 53.57037663459778, 52.24223010241985, 60.87751753628254, 59.259837940335274, 64.20496478676796, 53.50867174565792, 46.63509137928486, 48.50220859050751, 63.278171718120575, 59.006193950772285, 59.44447383284569, 57.572112902998924, 57.610076665878296, 57.78985261917114, 55.716930851340294, 54.7271903604269, 58.04682143032551, 56.88820660114288, 61.630561128258705, 58.617455810308456, 58.63248400390148, 55.567526668310165, 57.74255655705929, 58.875309973955154, 56.32993295788765, 56.324510648846626, 54.34022672474384, 50.46346575021744, 53.42542581260204, 48.536532148718834, 49.55356277525425, 48.30414041876793, 52.22844444215298, 47.396152541041374, 45.85945039987564, 50.30491545796394, 51.86894953250885, 49.54224318265915, 48.285023644566536, 48.13767895102501, 46.71759635210037, 45.73822170495987, 49.352823346853256, 50.468017905950546, 55.344999209046364, 54.94809150695801, 52.00367130339146, 53.83870303630829, 53.35555136203766, 58.77756021916866, 54.275159016251564, 44.75511185824871, 43.18358078598976, 48.62421624362469, 57.374557703733444, 56.552437618374825, 53.88697564601898, 58.67184989154339, 54.58951234817505, 54.9801579862833, 48.03783930838108, 49.344110414385796, 46.79298050701618, 46.19928136467934, 43.77995118498802, 45.6996613740921, 46.38020105659962, 46.29209138453007, 49.2552749812603, 49.30943727493286, 46.623657792806625, 50.28403177857399, 46.785745695233345, 45.63183881342411, 47.79426097869873, 45.82958020269871, 46.95436164736748, 51.89147852361202, 48.5824640840292, 56.44527576863766, 53.74105587601662, 59.44555677473545, 57.003853395581245, 58.25233340263367, 53.58537822961807, 56.71611003577709, 61.25221163034439, 54.987552389502525, 55.508819818496704, 58.01760479807854, 57.02770471572876, 61.2040264159441, 58.21455962955952, 62.30663605034351, 62.3378399759531, 66.18471935391426, 62.23839171230793, 63.98965314030647, 64.09011974930763, 61.30716808140278, 56.90555267035961, 58.14235970377922, 54.04442399740219, 53.484569638967514, 51.68568156659603, 51.04547291994095, 50.90997979044914, 57.52796307206154, 54.054675847291946, 62.22391068935394, 57.759043872356415, 62.63480544090271, 63.649742379784584, 71.61582872271538, 66.62066996097565, 79.16452646255493, 37.91771315038204, 2.8466089395806193, 0.8561039180494845, 1.2530827475711703, 3.085094355046749, 19.47229642421007, 89.7724324464798, 65.60229420661926, 79.27132353186607, 47.98575930297375, 45.698540434241295, 37.41510272026062, 76.62552550435066, 45.940591245889664, 59.298170283436775, 71.06644660234451, 81.66043773293495, 17.56756503134966, 1.4775225729681551, 0.3230037755565718, 0.23678126628510654, 0.28108593891374767, 0.3133136424003169], [0.10142999090021476, 0.03805369262408931, 0.17393663147231564, 0.0188135066855466, 0.17184460622956976, 0.15700730786193162, 0.5353964364621788, 0.30467994161881506, 23.55260867625475, 66.0355469584465, 55.768064707517624, 32.99293801188469, 21.18715960532427, 20.149043910205364, 55.825475826859474, 36.90411373972893, 11.15405922755599, 69.31141197681427, 57.58563257753849, 63.179969787597656, 55.91358929872513, 39.7285857796669, 0.08235222398070619, 0.24485792586347088, 0.4063521546777338, 0.6046883307863027, 0.40108551853336394, 4.498518286272883, 56.93630822002888, 65.9366762638092, 58.71847338974476, 61.21666073799133, 60.43566584587097, 62.40097738802433, 59.68851573765278, 58.6442481726408, 51.59573659300804, 45.25198459625244, 46.535194739699364, 56.35435424745083, 58.21321830153465, 57.90942460298538, 41.26391239464283, 49.37263548374176, 46.181057542562485, 56.402501463890076, 58.500102907419205, 58.1002351641655, 55.73260121047497, 55.149374306201935, 53.54539677500725, 56.55136227607727, 53.41791361570358, 51.15314394235611, 49.87056456506252, 53.38642090559006, 51.96909695863724, 52.14429035782814, 50.95330886542797, 49.23164784908295, 49.96322639286518, 51.338399201631546, 48.71789261698723, 44.952043890953064, 44.96848940849304, 43.4001349657774, 44.54247906804085, 41.699243634939194, 40.10723166167736, 39.5022851228714, 36.39197342097759, 36.00427262485027, 33.75181429088116, 37.97812610864639, 42.34086200594902, 43.23192559182644, 42.382807955145836, 42.369584664702415, 44.06775914132595, 44.33668211102486, 47.56134867668152, 49.352264776825905, 50.725032314658165, 48.42507652938366, 51.16276502609253, 55.26896148920059, 57.06703640520573, 46.17511086165905, 38.7888316065073, 41.26513972878456, 41.46081022918224, 54.91024173796177, 55.0806587934494, 49.90283243358135, 49.283921644091606, 49.4096264988184, 48.435921147465706, 45.68230390548706, 42.871404737234116, 45.494005009531975, 43.15179169178009, 43.01794767379761, 44.330883622169495, 40.13739824295044, 41.515873074531555, 43.36896523833275, 39.86372172832489, 36.23927861452103, 32.26646639406681, 41.330606415867805, 42.837643548846245, 38.93557973206043, 42.36729338765144, 42.25310951471329, 43.39372090995312, 43.62817592918873, 49.644343703985214, 49.44997273385525, 48.32977384328842, 48.23658004403114, 54.61478479206562, 50.40287420153618, 56.48960418999195, 51.96465499699116, 50.90670816600323, 54.719723761081696, 57.756178826093674, 55.43130397796631, 55.34935377538204, 54.59586940705776, 55.99287584424019, 57.22826175391674, 59.94305267930031, 62.84545473754406, 56.377187222242355, 59.518045485019684, 55.28286874294281, 53.78376558423042, 54.866445288062096, 50.720160976052284, 52.205470874905586, 48.65674629807472, 46.909189671278, 46.134563237428665, 51.68404385447502, 51.67067617177963, 57.297228053212166, 54.723135977983475, 60.460117533802986, 58.05080361664295, 66.66270330548286, 64.08298373222351, 76.51679813861847, 14.819592386484146, 1.664382058661431, 0.7107227691449225, 0.20729988027596846, 0.7399776962120086, 24.41926997154951, 73.19021344184875, 54.632773026824, 68.44958022236824, 43.68947044014931, 39.350004494190216, 18.989714719355106, 54.866445288062096, 28.137594647705555, 37.226195856928825, 52.53131479024887, 55.90173773467541, 3.9735724171623588, 0.3971854434348643, 0.13205404684413224, 0.0994277506833896, 0.08716615004232153, 0.08265941374702379, 0.104176464228658, 0.08921809188905172, 0.23037424602080137, 0.06804693417507224, 0.15747671626741067, 0.19916177086997777, 0.5569691257551312, 0.3865627571940422, 27.643820643424988, 74.39872339367867, 62.401437163352966, 31.85363184660673, 36.39176823198795, 35.022587701678276, 62.113241627812386, 38.095437213778496, 16.734250746667385, 76.06159776449203, 62.36024737358093, 69.51676815748215, 62.5079682469368, 44.450182020664215, 0.03938488291169051, 0.34331849485170096, 0.39896843838505447, 0.8280631445813924, 0.3619595820782706, 5.031022187322378, 58.64495113492012, 70.49520805478096, 60.64048245549202, 62.72939756512642, 62.83589445054531, 65.79644858837128, 61.02945238351822, 62.649275064468384, 53.72035838663578, 46.73696391284466, 48.439891934394836, 59.126392900943756, 60.468769669532776, 59.27670903503895, 45.84795981645584, 49.46701481938362, 47.48991250991821, 59.868762865662575, 59.250372648239136, 60.134456008672714, 56.16504840552807, 58.52906495332718, 56.27814553678036, 57.23189435899258, 56.013968512415886, 54.60800215601921, 53.31877313554287, 56.59387059509754, 52.54562862217426, 55.79953841865063, 55.35710155963898, 52.81112037599087, 52.84031040966511, 55.336715653538704, 53.288678750395775, 47.807358875870705, 47.96214736998081, 46.44453540444374, 47.63443395495415, 44.32043418288231, 43.57174515724182, 43.68679918348789, 41.933330073952675, 39.98520500957966, 36.94443717598915, 42.95459367334843, 45.624398812651634, 46.98859021067619, 47.61051803827286, 43.57531696557999, 44.02634896337986, 43.799052760005, 49.1876158118248, 51.05438344180584, 53.80206540226936, 50.06956748664379, 53.572603315114975, 56.13443344831467, 58.561914190649986, 47.716813534498215, 38.23513671755791, 40.64112961292267, 43.61608877778053, 55.71497015655041, 55.716528072953224, 52.0729073882103, 49.58907946944237, 52.495509311556816, 51.933986842632294, 47.7896062284708, 45.517210364341736, 47.105984911322594, 44.33400325477123, 44.10453736782074, 46.11942104995251, 43.24995942413807, 45.05165554583073, 48.46287690103054, 42.875006943941116, 41.878491416573524, 38.19813430309296, 44.86738443374634, 46.30639761686325, 43.78169909119606, 46.42191141843796, 45.76929643750191, 47.43731193244457, 47.27573320269585, 51.91954001784325, 51.83583430945873, 53.24477970600128, 51.47869907319546, 57.92012482881546, 52.103940322995186, 57.108229994773865, 52.52102114260197, 52.35453687608242, 57.04741045832634, 58.41806150972843, 58.59859362244606, 57.71633796393871, 57.689697593450546, 58.269584476947784, 58.63672077655792, 63.307620137929916, 65.1817099750042, 60.845390260219574, 61.00433573126793, 59.04565863311291, 57.03171730041504, 56.35319150984287, 54.509211257100105, 55.950709506869316, 51.33140377700329, 48.585883900523186, 49.145593866705894, 54.15507026016712, 56.37143053114414, 61.54961407184601, 55.89222304522991, 64.07854557037354, 62.785243168473244, 68.86742860078812, 66.36125788092613, 78.94148603081703, 15.821761060506105, 2.2142893821001053, 0.7678564439993352, 0.4164900106843561, 0.6695973384194076, 28.48859891295433, 82.22732171416283, 62.27010101079941, 76.07173562049866, 48.91537182033062, 44.132154285907745, 20.999696664512157, 63.82928654551506, 29.14641961455345, 43.578136414289474, 62.85327851772308, 65.84212213754654, 6.534384917467833, 0.6778790534008294, 0.19476220069918782, 0.1165426334773656, 0.16335820691892877, 0.11813817676738836, 0.337485303170979, 0.1946644004783593, 0.3077542735263705, 0.1854916481534019, 0.2918956463690847, 0.3644819342298433, 0.7681467127986252, 0.6392974080517888, 33.0195289850235, 87.8714932501316, 74.243805706501, 47.19870373606682, 33.20325292646885, 34.92929890751839, 71.31778791546822, 46.787478402256966, 23.11412550508976, 81.32070556282997, 68.34765449166298, 74.02160882949829, 68.78122642636299, 47.887340784072876, 0.1817798856063746, 1.0794059420004487, 0.8817868586629629, 1.9511824753135443, 0.36470535036642104, 6.520253475755453, 62.166320979595184, 72.33885392546654, 63.10333929955959, 65.50168320536613, 66.26788929104805, 67.62696996331215, 62.948353216052055, 62.336848229169846, 57.04620212316513, 49.12336125969887, 50.72872951626778, 62.161210253834724, 63.03344585001469, 63.48256655037403, 43.94059896469116, 47.257999554276466, 48.25545743107796, 61.30786344408989, 62.52122953534126, 63.11805970966816, 59.56901215016842, 61.221832260489464, 58.451963290572166, 60.915880277752876, 58.47554102540016, 57.242199406027794, 55.20789496600628, 59.49402317404747, 58.07628504931927, 58.85498486459255, 59.37071219086647, 57.9571196436882, 57.07530856132507, 58.757949471473694, 57.02204301953316, 53.128897324204445, 52.469465509057045, 52.27142013609409, 51.43929898738861, 48.230382576584816, 48.187771663069725, 47.90412448346615, 47.433952912688255, 46.20887964963913, 43.46947364509106, 47.61670410633087, 49.863303154706955, 51.71513378620148, 50.127426981925964, 46.063028275966644, 47.659170627593994, 47.52794846892357, 51.467284485697746, 53.446590676903725, 56.4655514806509, 51.88964702188969, 56.05988144874573, 58.56783427298069, 60.1063147187233, 47.245460227131844, 38.1192771345377, 43.26232396066189, 42.588946893811226, 59.243297427892685, 59.401209354400635, 53.804064095020294, 54.413691982626915, 56.49835892021656, 54.36772204935551, 50.221806317567825, 47.69231624901295, 48.519615456461906, 47.825434505939484, 47.22405977547169, 48.82468968629837, 46.22412823140621, 50.51361545920372, 52.15073861181736, 50.09422816336155, 47.024581879377365, 44.51958529651165, 49.11330319941044, 51.9763507694006, 47.60881192982197, 49.58975963294506, 50.33340632915497, 52.71736420691013, 54.067158177495, 56.31843477487564, 58.75679053366184, 56.407722383737564, 55.69179520010948, 63.18857632577419, 56.16556137800217, 61.34975999593735, 56.47876717150211, 54.916610196232796, 58.26646104454994, 60.67543677985668, 60.026830583810806, 59.74670581519604, 59.72107619047165, 60.87460309267044, 61.11992932856083, 65.76845929026604, 65.84667429327965, 62.729583755135536, 65.83293423056602, 63.084150329232216, 60.001831725239754, 59.71319921314716, 56.03740185499191, 58.91563341021538, 53.66903834044933, 52.386800944805145, 51.57684400677681, 58.085191771388054, 58.59020747244358, 64.36665371060371, 58.890976533293724, 67.32588931918144, 65.05902975797653, 72.26646780967712, 69.67094108462334, 81.46533340215683, 21.682406030595303, 3.5685846861451864, 1.9846598664298654, 0.6186337606050074, 2.2191771073266864, 33.378199338912964, 88.68763625621796, 67.82383739948273, 83.05587485432625, 54.680715054273605, 53.40949326753616, 28.796707279980183, 75.5382290482521, 35.75125940144062, 52.05957770347595, 71.72094628214836, 80.05179405212402, 10.372704304754734, 0.9970152005553246, 0.25339038285892457, 0.2813974628224969, 0.23734466027235612, 0.18982558278366923], [0.09312583337305114, 0.11127626450615935, 0.13730641891015694, 0.0325912705011433, 0.1281878730515018, 0.0733784562908113, 0.3452309500426054, 0.10398734273621812, 7.222038768231869, 66.64250358939171, 49.36831131577492, 51.371902003884315, 29.333567172288895, 20.550644360482693, 52.430551797151566, 37.41488233208656, 14.683763924986124, 56.46444194018841, 57.557073310017586, 63.77012372016907, 59.19166199862957, 45.91254495084286, 1.1956686596386135, 0.04658102880057413, 0.32226242939941585, 0.07730224300757982, 0.20356735243694857, 0.22152763791382313, 36.97051137685776, 72.99280643463135, 63.60856018960476, 61.887567937374115, 61.856842786073685, 62.77983985841274, 61.49572156369686, 59.698566198349, 52.99974985420704, 46.31558932363987, 46.08345977962017, 56.30084551870823, 56.93215884268284, 60.80748729407787, 49.647972509264946, 54.38601806759834, 45.376481115818024, 53.78325641155243, 58.711325973272324, 56.562446281313896, 58.12667794525623, 55.7151335477829, 56.470073238015175, 55.19653357565403, 55.536911711096764, 52.78748944401741, 47.22163550555706, 53.031063973903656, 50.49509905278683, 52.635721787810326, 53.61332193017006, 49.46547590196133, 49.55565266311169, 50.30904583632946, 51.06242001056671, 45.77247306704521, 43.615062832832336, 44.419415071606636, 42.3633947968483, 41.399181336164474, 36.72091417014599, 40.6525593996048, 31.595494598150253, 23.552192598581314, 25.6374504044652, 30.651961527764797, 35.8196747303009, 40.02865947782993, 44.29675005376339, 42.317747846245766, 44.38033036887646, 44.29290845990181, 46.39306336641312, 50.98732843995094, 49.71256144344807, 46.62010878324509, 52.75954954326153, 56.31090737879276, 57.52805806696415, 45.99060036242008, 36.89416967332363, 36.23794108629227, 38.22805389761925, 55.37803843617439, 58.671933487057686, 54.36307489871979, 47.875686809420586, 46.69199712574482, 50.31476452946663, 47.99601875245571, 46.826228722929955, 45.11283986270428, 41.618174985051155, 42.44447864592075, 40.97991943359375, 36.13728828728199, 36.376857832074165, 39.57973636686802, 36.67989917099476, 30.26784583926201, 37.25860811769962, 41.68755166232586, 32.585166692733765, 40.74250057339668, 43.58413629233837, 42.49216228723526, 44.442191049456596, 45.709369853138924, 47.130193412303925, 49.656221866607666, 50.01835763454437, 50.053612142801285, 53.037614822387695, 50.17844304442406, 52.89440430700779, 51.440682113170624, 52.43033900856972, 56.38203576207161, 55.65856218338013, 56.86655916273594, 60.568711906671524, 57.31917567551136, 58.115840926766396, 54.466634541749954, 68.48407477140427, 62.2452275454998, 56.47750183939934, 59.14606064558029, 55.374421030282974, 56.846910417079926, 56.268000081181526, 56.165063604712486, 54.96924877166748, 51.94812968373299, 48.037953302264214, 50.92381864786148, 51.26871854066849, 57.14425586163998, 60.82942731678486, 60.1455932110548, 62.63141982257366, 61.55735045671463, 69.29609879851341, 60.40151707828045, 52.55456194281578, 5.355611220002174, 2.2065299609676003, 0.38585952774155885, 0.19345334905665368, 1.518920639064163, 49.71142150461674, 63.52369174361229, 60.02911426126957, 58.68891857564449, 59.57943119108677, 55.89522868394852, 19.227846041321754, 50.61109162867069, 36.98571056127548, 35.6570852547884, 54.17818441987038, 55.76850168406963, 1.8533506686799228, 0.267702997662127, 0.033185170468641445, 0.10066805756650865, 0.1250581323984079, 0.051091208661091514, 0.08394313626922667, 0.12717417353997007, 0.10870634068851359, 0.02319096827704925, 0.11795543774496764, 0.09978772199247032, 0.38402523554395884, 0.07101234106812626, 9.180489778518677, 74.46048527956009, 58.407361283898354, 54.12859708070755, 27.698723897337914, 29.247087612748146, 62.303318828344345, 37.77782745659351, 14.571443852037191, 63.39720793068409, 60.459361374378204, 70.33867925405502, 63.44341345131397, 51.92220747470856, 1.124643583316356, 0.10333376296330243, 0.3559784952085465, 0.49935050192289054, 0.28502766333986074, 0.2643657970475033, 40.069134905934334, 73.85244950652122, 66.46039456129074, 64.7193355858326, 63.135223388671875, 65.67417114973068, 64.13118034601212, 61.58857338130474, 56.36287719011307, 48.07570047676563, 47.843323945999146, 57.36134961247444, 59.35083165764809, 62.89937004446983, 52.655974701046944, 52.87625268101692, 45.96484534442425, 57.32160374522209, 60.55018410086632, 59.05567489564419, 60.61494402587414, 59.71723459661007, 57.37874887883663, 58.11112158000469, 57.04278230667114, 55.733053386211395, 51.2736164778471, 55.80859333276749, 53.53202909231186, 55.79296097159386, 55.926242619752884, 53.304406106472015, 52.64533147215843, 52.6524218916893, 52.99598425626755, 52.12003245949745, 47.00041897594929, 47.258143946528435, 46.52216523885727, 45.100167542696, 40.434242114424706, 45.58188669383526, 37.10521414875984, 28.871869146823883, 30.189260356128216, 36.97493053972721, 41.918898448348045, 44.240775257349014, 46.489061415195465, 44.998986572027206, 46.15058697760105, 46.67941980063915, 47.93372869491577, 51.64953790605068, 50.785726457834244, 48.368090987205505, 56.08512729406357, 56.950576454401016, 58.80869194865227, 46.068792566657066, 38.00326555967331, 37.15928144752979, 36.99489466845989, 55.542170628905296, 58.739813044667244, 56.930749118328094, 49.333030208945274, 49.24922190606594, 51.963427662849426, 51.14520616829395, 49.905914068222046, 47.26503297686577, 44.39127758145332, 44.40571300685406, 44.09617401659489, 40.53844392299652, 39.608219638466835, 42.76290915906429, 41.30220673978329, 36.07282854616642, 40.38534253835678, 43.45666453242302, 36.530088409781456, 45.509629771113396, 47.09200166165829, 47.08859324455261, 46.12317904829979, 50.15447773039341, 52.06404246389866, 53.013003543019295, 55.14467775821686, 53.417222052812576, 56.179024055600166, 52.24550172686577, 55.958624482154846, 52.68139533698559, 52.58456893265247, 57.99696810543537, 56.86525583267212, 55.81022724509239, 63.53422477841377, 59.11821573972702, 61.108142361044884, 57.33264595270157, 69.13391590118408, 63.57594653964043, 58.448497876524925, 61.361592561006546, 59.97455678880215, 60.30022591352463, 58.94469425082207, 58.13511349260807, 57.97175645828247, 54.69171926379204, 50.01174218952656, 52.45181925594807, 54.47848990559578, 59.7136589884758, 64.36482980847359, 62.9850098490715, 66.56450137495995, 67.38380581140518, 74.52543139457703, 64.0516810119152, 52.81269729137421, 7.026705024763942, 3.0919394502416253, 0.6413926987443119, 0.053472693762159906, 1.7952534486539662, 59.088934510946274, 68.97798746824265, 70.19602730870247, 67.96338111162186, 67.3821870982647, 62.818635776638985, 21.155285015702248, 62.4606341868639, 39.31461699306965, 36.22934214770794, 62.09476321935654, 64.4267588853836, 3.479654733091593, 0.39108967990614474, 0.0718610463081859, 0.11037321179173887, 0.05185535359487403, 0.048743064544396475, 0.17974889458855614, 0.24627820355817676, 0.30313606665004045, 0.1301960801356472, 0.19113560701953247, 0.1602146474760957, 0.5911061970982701, 0.28971898660529405, 11.069604009389877, 89.93455454707146, 66.63905337452888, 74.74431484937668, 37.32331104576588, 36.57391145825386, 68.92830893397331, 46.84914529323578, 24.335100688040257, 70.92540577054024, 66.14951804280281, 73.45768108963966, 69.58347737789154, 55.788454413414, 1.607365405652672, 0.22182152839377522, 1.059316301252693, 1.0165744135156274, 0.5467870971187949, 0.5952504684682935, 42.80325539410114, 72.4978069961071, 69.85293611884117, 67.58666172623634, 65.40504679083824, 69.12198454141617, 65.85614338517189, 63.28774720430374, 57.99021206796169, 52.31419064104557, 50.886424854397774, 59.97916214168072, 63.818761110305786, 64.51917752623558, 52.652323096990585, 51.19564846158028, 46.11565925180912, 58.56911100447178, 63.73386226594448, 61.786964535713196, 63.195617347955704, 60.54076820611954, 59.92500364780426, 61.67276546359062, 60.225035548210144, 57.878342270851135, 52.248868346214294, 58.72149422764778, 57.94736176729202, 57.40420751273632, 60.81328198313713, 57.62059070169926, 55.43825380504131, 57.27046608924866, 58.27480919659138, 55.34915618598461, 51.79703839123249, 53.27890947461128, 52.0876619964838, 48.96772921085358, 48.629076182842255, 49.859556555747986, 42.12729446589947, 35.54409831762314, 37.33350209891796, 42.35528223216534, 47.74517901241779, 49.66382525861263, 49.559897035360336, 49.4471038877964, 49.488301277160645, 49.830013141036034, 51.45279586315155, 56.67389050126076, 53.82019802927971, 49.69563715159893, 57.25410796701908, 58.08427982032299, 61.75422929227352, 46.21524430811405, 37.65328913927078, 37.747197300195694, 38.20500813424587, 58.28175902366638, 62.400483414530754, 59.21548292040825, 51.932444125413895, 53.35398584604263, 55.738832876086235, 54.16223667562008, 54.02377970516682, 50.061363726854324, 46.15933030843735, 46.42538443207741, 46.42429769039154, 45.950926691293716, 46.00527137517929, 48.91421668231487, 46.05034455657005, 41.71534717082977, 44.97383952140808, 47.72450432181358, 42.5118338316679, 49.749218076467514, 51.95210047066212, 52.043322175741196, 51.664007529616356, 53.53653945028782, 55.72664313018322, 56.89266376197338, 61.521571576595306, 56.27687260508537, 59.894187301397324, 53.83113384246826, 58.45897391438484, 56.68126590549946, 55.46327546238899, 60.978751704096794, 60.049826949834824, 60.16653008759022, 64.5063342154026, 61.21115103363991, 63.58397550880909, 60.802961736917496, 67.63287484645844, 64.07022401690483, 60.44655226171017, 63.981825560331345, 62.70078130066395, 64.13466095924377, 62.510350719094276, 61.48359261453152, 61.432534754276276, 56.557780131697655, 51.99308507144451, 55.324024334549904, 57.72125869989395, 63.215554878115654, 68.15150901675224, 66.7713850736618, 67.69703060388565, 69.3029536306858, 76.53642788529396, 69.53309208154678, 65.34518480300903, 10.39178118109703, 5.0229172222316265, 1.0080186976119876, 0.6314599723555148, 2.2507427260279655, 61.33859999477863, 77.44126573204994, 73.90224203467369, 72.28748068213463, 73.0147236585617, 69.57821846008301, 29.35994915664196, 72.6473593711853, 49.81910392642021, 51.733046025037766, 69.73774150013924, 77.60464176535606, 5.9618577640503645, 0.7312759850174189, 0.199445805628784, 0.34464904689230025, 0.18621978408191353, 0.2217010036110878], [0.08211434338591062, 0.07647822159924544, 0.11078575684223324, 0.08598433923907578, 0.06430806097341701, 0.056580463133286685, 0.08122551022097468, 0.08194396854378283, 1.777621682267636, 58.22152465581894, 58.92966985702515, 49.006179347634315, 46.66202053427696, 29.10222228616476, 36.4087039232254, 26.567357406020164, 28.439606241881847, 55.7445477694273, 59.67268958687782, 57.45748445391655, 56.33903346955776, 59.99950245022774, 6.75289124250412, 0.19500608526868746, 0.5550298048183322, 0.1138813587022014, 0.2191830746596679, 0.20746520109241828, 11.543955355882645, 64.72014874219894, 57.09251023828983, 67.4567922949791, 62.72773705422878, 64.99175816774368, 62.598262801766396, 63.76962974667549, 52.88506060838699, 45.19420489668846, 46.937148571014404, 56.23124085366726, 55.98390832543373, 59.92979139089584, 49.61409732699394, 52.280057072639465, 46.28082878887653, 49.1990227997303, 55.546886175870895, 57.89180114865303, 58.25929082930088, 58.87831561267376, 57.074400410056114, 53.316694647073746, 57.32556693255901, 52.922458201646805, 51.34184941649437, 53.94799277186394, 52.85529300570488, 52.1573730558157, 54.061629474163055, 48.61082196235657, 49.57601957023144, 51.589797511696815, 51.065193861722946, 49.85083982348442, 46.331491470336914, 44.644100815057755, 45.235565677285194, 39.85437422990799, 38.192328214645386, 36.33708916604519, 34.78102706372738, 24.07953780144453, 19.5680208876729, 19.93266262114048, 30.185202173888683, 36.55309237539768, 40.32165415585041, 38.64397957921028, 43.493799939751625, 44.19563367962837, 47.27158382534981, 50.732483714818954, 45.48977963626385, 50.1892876625061, 51.88700616359711, 51.462318152189255, 52.144157364964485, 42.90779158473015, 36.32069684565067, 36.91190332174301, 33.58041308820248, 53.88680845499039, 59.46664944291115, 55.19990399479866, 51.3772939145565, 45.55871933698654, 45.6192234903574, 49.02107834815979, 47.89354965090752, 44.51529532670975, 44.26902674138546, 43.6767715215683, 40.189197063446045, 30.93808427453041, 30.450534336268902, 28.101116605103016, 28.143419735133648, 31.70125052332878, 37.441955879330635, 30.675421468913555, 38.7101112306118, 44.064985290169716, 44.153265953063965, 42.35313914716244, 45.98385192453861, 49.357865676283836, 46.051093116402626, 48.67175169289112, 49.56943452358246, 51.80113077163696, 53.194497004151344, 48.29111851751804, 53.9435014128685, 48.69292415678501, 53.093164041638374, 55.82966700196266, 57.1783172339201, 52.318267822265625, 57.159698233008385, 58.183815479278564, 60.02168565988541, 56.598350554704666, 68.61796438694, 56.1899408698082, 53.94575089216232, 60.72308622300625, 56.75868675112724, 58.64577189087868, 57.131716534495354, 56.099068745970726, 56.33780233561993, 53.86226937174797, 49.70892883837223, 51.00174106657505, 51.23080797493458, 53.47397580742836, 63.053561970591545, 63.91192451119423, 66.6032212972641, 64.57747399806976, 67.89158776402473, 65.52011981606483, 35.15563756227493, 3.4526170464232564, 1.0922040115110576, 0.43063199089374393, 0.5425402906257659, 7.4569321889430285, 64.6636837720871, 61.79383456707001, 63.73180277645588, 52.73960821330547, 72.07327097654343, 55.05443260073662, 19.169807955622673, 51.59650795161724, 29.00995373725891, 35.099145993590355, 51.499647349119186, 54.583368077874184, 1.2132998323068023, 0.1025863089307677, 0.044942730382899754, 0.015387461717182305, 0.09444593597436324, 0.11919043827219866, 0.023342281056102365, 0.025954494303732645, 0.06085424669436179, 0.07889675471233204, 0.03598216178943403, 0.05469966054079123, 0.09816776204388589, 0.19031449483009055, 2.051765928044915, 67.34166607260704, 65.93094617128372, 59.35023508965969, 51.0102754086256, 36.147076562047005, 49.06169056892395, 29.779349751770496, 30.22919051349163, 60.81690698862076, 66.8403209745884, 63.02795134484768, 61.25043712556362, 64.9709352850914, 7.23391218110919, 0.23587986856000498, 1.26290486427024, 0.35766872169915587, 0.5086435563862324, 0.33648236480075866, 13.716183844953775, 66.68392896652222, 60.156555622816086, 68.29743638634682, 64.08699631690979, 67.39298611879349, 65.25581359863281, 65.1042777299881, 56.29673033952713, 48.04598227143288, 49.38281513750553, 58.411434665322304, 59.55661341547966, 61.568666249513626, 53.3807098120451, 50.210581719875336, 44.97708074748516, 50.654021725058556, 58.80678065121174, 57.71980717778206, 59.611121490597725, 60.460451915860176, 58.7709903717041, 55.84974892437458, 60.97385376691818, 55.439310148358345, 52.0207741856575, 57.64308549463749, 54.56180423498154, 53.39706413447857, 53.733011707663536, 53.898948803544044, 54.27760988473892, 53.847138583660126, 53.51120240986347, 53.35171736776829, 51.671166345477104, 47.963933274149895, 48.94971437752247, 44.150720089673996, 42.20959044992924, 39.20338936150074, 41.07290804386139, 30.171519108116627, 25.1648735627532, 26.147548332810402, 35.2327848225832, 42.778628915548325, 45.7793240994215, 41.89049117267132, 46.17699936032295, 44.81493964791298, 48.82490627467632, 52.72818602621555, 48.67050915956497, 50.90838387608528, 53.52212682366371, 54.30706590414047, 53.57001945376396, 42.917933240532875, 38.137181773781776, 36.38538457453251, 33.388808369636536, 55.64694240689278, 61.288153901696205, 56.47199593484402, 53.14281977713108, 46.46963305771351, 47.96044506132603, 50.898367613554, 48.986952379345894, 46.62712320685387, 46.10032707452774, 45.62921695411205, 43.827357441186905, 36.09264828264713, 36.045177429914474, 32.842002511024475, 31.68995752930641, 37.85667322576046, 41.00870668888092, 34.49723929166794, 42.49321103096008, 49.028028175234795, 47.769189924001694, 46.7914529889822, 47.868277207016945, 52.750620022416115, 49.89079847931862, 52.02319845557213, 52.873193845152855, 54.88602563738823, 54.468230456113815, 51.408619433641434, 57.37052612006664, 50.07750906050205, 57.32715144753456, 57.85105973482132, 58.151179030537605, 55.30087597668171, 60.37693999707699, 59.434731155633926, 60.0902795791626, 59.35867063701153, 64.53419432044029, 55.34601375460625, 55.73283299803734, 65.05792021751404, 59.63556557893753, 60.05652979016304, 59.895380437374115, 58.66338774561882, 58.97266834974289, 56.2198680639267, 53.33378233015537, 53.12884032726288, 51.183394119143486, 56.43166109919548, 64.49973776936531, 66.52341797947884, 69.45866167545319, 69.42582383751869, 71.40441566705704, 72.6869684457779, 42.615496069192886, 4.249691488221288, 1.4877582737244666, 0.964994200039655, 0.6017740059178323, 8.776599951088428, 71.22273221611977, 70.40505409240723, 72.08541512489319, 57.79772199690342, 76.87061995267868, 64.20012384653091, 22.96727668493986, 64.32391360402107, 30.789677537977695, 33.83320212364197, 62.33340561389923, 62.593433260917664, 2.089930842630565, 0.1357362125418149, 0.07711111029493622, 0.08555217922548763, 0.09058196636033244, 0.11426029188442044, 0.12458390003303066, 0.1228754167095758, 0.25785359961446375, 0.17103760968893766, 0.08740703633520752, 0.19955576222855598, 0.2158605240401812, 0.22767732589272782, 2.247914015315473, 81.2524764239788, 76.68203607201576, 68.07616665959358, 55.70290960371494, 42.643922343850136, 54.528008848428726, 34.80261370539665, 39.047255739569664, 67.1919085085392, 73.060944378376, 70.16858518123627, 67.98089057207108, 72.27403700351715, 9.297088421881199, 0.2645436453167349, 1.926949869375676, 0.9761753969360143, 0.8979406231082976, 0.2898254105821252, 17.022590674459934, 72.13733553886414, 63.60724925994873, 70.25103315711021, 66.95663273334503, 69.05937150120735, 67.21390172839165, 68.33048701286316, 59.09059502184391, 51.24697990715504, 51.6425234824419, 61.589519530534744, 64.83559414744377, 64.25965905189514, 53.54289650917053, 53.02952125668526, 44.42659288644791, 53.94099734723568, 59.1070519387722, 58.379037603735924, 62.36000798642635, 64.25968185067177, 61.51449255645275, 57.026766166090965, 62.08551451563835, 58.100774735212326, 56.14910066127777, 57.59296238422394, 57.733524441719055, 57.415435910224915, 58.620104268193245, 55.86930267512798, 54.807240664958954, 57.76578851044178, 59.00458283722401, 58.616631254553795, 56.83173783123493, 51.54519930481911, 55.35052791237831, 48.98741215467453, 47.864933386445045, 45.922378823161125, 46.44547775387764, 36.48475304245949, 33.1248365342617, 32.15176574885845, 43.59358638525009, 49.133005142211914, 48.10315020382404, 46.866601556539536, 51.53984159231186, 49.09267030656338, 53.22528675198555, 54.852028861641884, 50.93696214258671, 54.74385246634483, 55.4498165845871, 54.84511323273182, 55.68394862115383, 42.232989594340324, 37.46281675994396, 38.97742688655853, 34.317972511053085, 56.5777974575758, 66.1723244190216, 56.856394708156586, 57.97877848148346, 49.88244652748108, 49.1743279248476, 54.90437865257263, 52.801419496536255, 49.48496885597706, 49.51724052429199, 48.49380724132061, 48.88033390045166, 43.67800645530224, 43.189098089933395, 39.166212156414986, 39.115659669041634, 44.02275815606117, 45.941244810819626, 38.84163357317448, 47.55613915622234, 51.61699265241623, 54.3635992705822, 49.82422985136509, 52.90420398116112, 57.603404223918915, 51.973390728235245, 53.71986821293831, 57.54715584218502, 58.32652822136879, 58.18372808396816, 52.829914167523384, 59.655799493193626, 54.78834047913551, 58.88830907642841, 59.057198613882065, 62.36438915133476, 57.79482655227184, 63.11894506216049, 60.57624310255051, 64.85773175954819, 61.404777243733406, 65.06447866559029, 58.95641662180424, 55.90074218809605, 65.18327549099922, 61.756110191345215, 63.640816658735275, 61.129007041454315, 60.48254773020744, 62.030748054385185, 58.569475784897804, 55.98877966403961, 56.53306245803833, 55.86239464581013, 58.07053975760937, 68.79929065704346, 68.61823797225952, 70.50914570689201, 68.47462847828865, 73.82553935050964, 64.68670293688774, 43.4729428589344, 6.712026810273528, 2.99449629150331, 0.9955434326548129, 1.0334588075056672, 10.475973263382912, 77.30452626943588, 74.10038620233536, 74.53945264220238, 66.69222012162209, 83.46065193414688, 70.46787232160568, 30.112350583076477, 73.04813146591187, 39.79969136416912, 52.74258345365524, 70.72182029485703, 76.52613803744316, 4.2078448086977005, 0.4672156262677163, 0.195649913221132, 0.16696752340067178, 0.21123106620507315, 0.22086001670686528], [0.12259572351467796, 0.028274234573473223, 0.06547574128489941, 0.12227868544869125, 0.012711484068859136, 0.09634869871661067, 0.06754827772965655, 0.3234087803866714, 0.1464097507414408, 34.49095822870731, 70.71798250079155, 41.72997258603573, 35.207151398062706, 32.91942335665226, 39.8179379850626, 20.41561670601368, 47.03618265688419, 67.87438228726387, 59.53688487410545, 56.8902812898159, 52.27707803249359, 65.54335936903954, 15.987701006233692, 0.10203148674918339, 0.43437808519229293, 0.3038819250650704, 0.4674599115969613, 0.04873312347626779, 2.559430324472487, 47.555155009031296, 60.226433873176575, 67.22888052463531, 61.044704765081406, 61.99554294347763, 59.755604937672615, 60.678020641207695, 49.846177473664284, 48.16155306994915, 47.19282925128937, 53.45169000327587, 53.983353674411774, 58.60911525785923, 53.310193195939064, 50.01922398805618, 50.679917335510254, 41.580340415239334, 51.60316899418831, 46.433717384934425, 54.46103744208813, 54.86785501241684, 58.31683114171028, 56.115111485123634, 59.57887642085552, 51.03164926171303, 49.85627733170986, 57.1170911192894, 54.271686002612114, 51.53496265411377, 51.4321705698967, 52.203745767474174, 52.918582409620285, 50.841465666890144, 49.440735429525375, 47.350053414702415, 45.76113447546959, 43.2402129471302, 41.10223866999149, 43.28080236911774, 40.68020671606064, 35.50904139876366, 37.52314992249012, 34.84609477221966, 31.306238919496536, 24.30550217628479, 33.370535150170326, 39.137554094195366, 38.39864194393158, 41.75773769617081, 42.477631866931915, 45.11381261050701, 43.10836382210255, 46.19632892310619, 48.15441705286503, 53.251376152038574, 53.29773746430874, 48.528841361403465, 43.464568108320236, 44.9744588881731, 35.06336711347103, 29.674988351762295, 32.44117721915245, 51.691525653004646, 48.86395677924156, 51.91510185599327, 48.73906508088112, 45.07509268820286, 43.40068593621254, 49.395156875252724, 46.67049787938595, 42.80345678329468, 41.90678849816322, 40.80063745379448, 34.60900269448757, 26.009955815970898, 18.936565071344376, 15.154686905443668, 21.211613193154335, 34.09254960715771, 31.878795996308327, 37.080272287130356, 40.781304091215134, 42.870101407170296, 44.864792972803116, 41.254568696022034, 46.05076253414154, 52.878399565815926, 51.03172905743122, 41.641463935375214, 49.72847118973732, 49.14132669568062, 53.70512120425701, 50.42721949517727, 56.6584937274456, 48.123938888311386, 56.28428600728512, 56.31562292575836, 55.11638067662716, 53.39723892509937, 55.0103397667408, 58.20978708565235, 58.59393127262592, 58.94619517028332, 72.94850841164589, 52.48748794198036, 53.133168295025826, 57.80481621623039, 60.07899038493633, 59.72743704915047, 56.692881882190704, 54.005992859601974, 55.20384818315506, 53.25129635632038, 53.56029577553272, 51.3645987957716, 50.07510758936405, 56.65010757744312, 58.56937699019909, 64.17822182178497, 68.1974333524704, 68.46389025449753, 59.55024875700474, 42.86782532930374, 22.715101316571236, 2.1743321511894464, 0.3963203070452437, 0.8125205535907298, 0.0933278830780182, 12.915251422673464, 68.5419000685215, 52.30287104845047, 52.07648679614067, 53.73811483383179, 77.07441821694374, 34.012404307723045, 22.359202913939953, 49.10870924592018, 28.13728116452694, 57.8958061337471, 53.333474546670914, 43.044846430420876, 0.5512745375744998, 0.10164166626054794, 0.027702821680577472, 0.06471216780482791, 0.09721977228764445, 0.0264033619168913, 0.10551828949246556, 0.12883846939075738, 0.09200288230204023, 0.05319908246747218, 0.11881655911565758, 0.062161591777112335, 0.025763580524653662, 0.3988995373947546, 0.2465093380305916, 40.73180414736271, 79.7040519118309, 47.76149533689022, 40.061907693743706, 35.59109799563885, 50.37468731403351, 24.569690600037575, 55.08600890636444, 71.11476480960846, 66.43372759222984, 62.13325135409832, 58.48982825875282, 70.37258103489876, 18.717637918889523, 0.11085229780292138, 0.7138345646671951, 0.720438847783953, 0.6955642544198781, 0.29648259398527443, 3.486399846151471, 54.038329124450684, 62.6401973515749, 68.88675436377525, 63.560485169291496, 63.33824649453163, 62.499946877360344, 61.896144077181816, 52.55374498665333, 50.216327011585236, 49.693497866392136, 54.54938270151615, 58.08910176157951, 60.78374236822128, 58.48705820739269, 47.38000340759754, 51.75908602774143, 43.72704282402992, 51.18291914463043, 47.56050132215023, 55.84322467446327, 56.909705847501755, 59.34790201485157, 57.56590023636818, 60.55063247680664, 53.60774762928486, 52.68938630819321, 61.07769839465618, 56.50475397706032, 53.31882253289223, 55.59944875538349, 54.96459782123566, 53.83767329156399, 54.361589178442955, 52.59155675768852, 50.44757880270481, 50.47208748757839, 47.46579900383949, 45.78552536666393, 48.20294804871082, 45.26246063411236, 41.70974247157574, 42.1722574532032, 40.03114454448223, 37.38419897854328, 30.70173315703869, 37.62830547988415, 44.46907080709934, 42.34539516270161, 45.34735567867756, 45.19012771546841, 48.172044306993484, 45.43539695441723, 49.408972933888435, 48.48918288946152, 53.41193273663521, 56.08787074685097, 51.44671618938446, 47.62886345386505, 46.23619258403778, 35.97328148782253, 31.880832687020302, 31.741199679672718, 53.275079280138016, 52.87445917725563, 52.95252978801727, 49.70319874584675, 47.40867666900158, 47.1700456738472, 51.8506421148777, 47.43908643722534, 43.29402945935726, 43.32370966672897, 44.71674531698227, 37.98427037894726, 30.85940569639206, 23.98575883358717, 20.894503109157085, 25.95054790377617, 40.29230833053589, 35.223631113767624, 40.159896835684776, 46.36666618287563, 47.39849701523781, 49.106740951538086, 46.39985740184784, 50.36921180784702, 56.97152853012085, 53.290411457419395, 43.712390810251236, 53.76092880964279, 51.51836134493351, 56.0853286832571, 51.042786464095116, 60.78856810927391, 50.20856782793999, 57.35887974500656, 57.985960096120834, 56.18250086903572, 56.85471139848232, 57.228824123740196, 59.99308459460735, 60.328196212649345, 58.87022204697132, 64.81750711798668, 52.63249956071377, 53.54598954319954, 60.20692951977253, 62.46984489262104, 59.93561647832394, 57.58826203644276, 55.56950256228447, 56.4870735257864, 56.99723035097122, 55.1943638920784, 51.91817209124565, 51.220035552978516, 57.56612442433834, 60.159401670098305, 65.02502158284187, 68.18335890769958, 71.10521972179413, 63.353392481803894, 46.07606157660484, 23.32632701843977, 3.0264399899169803, 0.657334387069568, 0.9771594253834337, 0.3854531573597342, 16.51141930371523, 74.9721810221672, 62.15790443122387, 57.008808329701424, 55.75181297957897, 87.43201643228531, 41.34364731609821, 24.45401530712843, 59.713218212127686, 22.841505333781242, 57.45215333998203, 63.27976383268833, 48.31205539405346, 0.5094012001063675, 0.040906664144131355, 0.10136039229109883, 0.047995888817240484, 0.08634103767690249, 0.11108554739621468, 0.26349519845098257, 0.1620766514679417, 0.19101000594673678, 0.2526043594116345, 0.21360194601584226, 0.2221520512830466, 0.18833006615750492, 0.5420209653675556, 0.33259772637393326, 51.13314561545849, 91.2860432267189, 57.938436046242714, 46.390840485692024, 47.13328644633293, 57.834154441952705, 28.26717719435692, 59.77669760584831, 77.29184255003929, 72.87176012992859, 68.43554377555847, 66.49116531014442, 77.14156821370125, 20.24413950741291, 0.23626885784324259, 1.4407107420265675, 1.4105271804146469, 1.55784681905061, 0.47950728388968855, 4.861471485346556, 58.61323423683643, 62.383505925536156, 73.25412601232529, 67.06895470619202, 66.46312281489372, 66.13934218883514, 65.38758292794228, 56.291915997862816, 53.418559581041336, 53.96927163004875, 57.945013493299484, 59.668395817279816, 61.08753226697445, 59.501675963401794, 56.85783103108406, 52.90652185678482, 42.33719900250435, 49.578580632805824, 47.03819274902344, 57.438177689909935, 61.745425164699554, 62.41690993309021, 58.62084522843361, 65.13962343335152, 55.93641087412834, 54.298261776566505, 63.84374096989632, 59.42857168614864, 57.740675657987595, 57.872091606259346, 59.53018583357334, 59.00874361395836, 57.71960198879242, 57.29092799127102, 54.803676456213, 55.11829197406769, 53.10494340956211, 49.85326789319515, 55.10267861187458, 48.80295865237713, 44.013053476810455, 45.70795252919197, 45.2998012304306, 44.36676509678364, 36.23476445674896, 46.74447990953922, 48.93255829811096, 48.36162753403187, 51.87898859381676, 48.34704011678696, 51.41973003745079, 48.076680824160576, 52.8835216909647, 54.17849600315094, 55.70487789809704, 58.12323912978172, 51.66448250412941, 49.59860935807228, 48.13308119773865, 36.53360702097416, 30.729013793170452, 32.39048033952713, 55.143370628356934, 53.16345266997814, 54.00911249220371, 54.531926438212395, 49.6318119764328, 48.65324668586254, 55.91041646897793, 51.682075560092926, 46.50352343916893, 46.26352831721306, 47.60364420711994, 42.233521565794945, 37.61162057518959, 33.125068321824074, 27.854338847100735, 34.64467518031597, 46.50940552353859, 40.0402944535017, 44.702670872211456, 49.19682651758194, 50.98135516047478, 52.98399209976196, 49.79663573205471, 54.29582990705967, 62.02143855392933, 57.87972919642925, 46.283222660422325, 57.03479513525963, 52.981191650033, 59.29845906794071, 53.398888036608696, 61.37032829225063, 52.54174143075943, 59.40491035580635, 59.73550781607628, 59.68822695314884, 57.56423592567444, 58.53223018348217, 60.70575535297394, 62.02991969883442, 56.98830842971802, 67.61256873607635, 55.41227459907532, 53.68693917989731, 61.02205038070679, 63.6846587061882, 65.51355376839638, 59.457814916968346, 56.738741621375084, 57.59393133223057, 58.62514279782772, 59.0757492184639, 54.57772918045521, 55.6696841865778, 60.42327471077442, 64.19844433665276, 67.67512857913971, 71.96218013763428, 71.78195580840111, 66.00190356373787, 49.19220596551895, 25.556849129498005, 4.518823446705937, 1.5503231040202081, 1.4888631831854582, 0.6335486134048551, 15.985396429896355, 83.66853877902031, 66.06688007712364, 64.71731409430504, 65.57293698191643, 89.14375618100166, 46.27237044274807, 37.27988317608833, 70.83763048052788, 35.14701582491398, 71.54940828680992, 72.54156544804573, 62.825889587402344, 1.6370825422927737, 0.45121578325051814, 0.23016705323243514, 0.26451229699887335, 0.13920560450060293, 0.18085745541611686], [0.08775210531894118, 0.10770078253699467, 0.08697253113496117, 0.02869782649213448, 0.17095057060942054, 0.13117666501784697, 0.180456176167354, 0.5112287239171565, 0.36752515530679375, 15.284131709486246, 73.57581675052643, 50.91201268136501, 48.80805417895317, 36.23383730649948, 46.67975798249245, 21.59977376461029, 31.51619665324688, 73.69690865278244, 58.38863588869572, 52.71841675043106, 46.87184527516365, 66.73454985022545, 20.959787406027317, 0.07934232533443719, 0.11291478556813672, 0.892224779818207, 0.17480289592640474, 0.040249058220069855, 1.369453996885568, 45.70794112980366, 70.09331122040749, 62.324688881635666, 62.69517280161381, 59.0705206990242, 58.38404953479767, 50.75223505496979, 49.46685142815113, 49.241508319973946, 50.77311873435974, 52.41774648427963, 55.23170068860054, 55.2270383387804, 61.25734895467758, 34.94799770414829, 43.70964735746384, 55.98031371831894, 49.92236718535423, 54.23134356737137, 54.021815210580826, 57.55744569003582, 55.5517803132534, 56.4353659003973, 53.787994757294655, 50.615750178694725, 51.36569693684578, 56.19257032871246, 51.54217466711998, 50.836560130119324, 53.2923037558794, 51.8074232339859, 50.971749275922775, 52.0146831125021, 49.00629714131355, 50.4225267469883, 50.982966274023056, 46.321125626564026, 42.965533286333084, 41.73523150384426, 41.83875314891338, 36.46733097732067, 38.00341375172138, 28.84181845933199, 30.57309675961733, 37.269175350666046, 41.10307462513447, 42.397976741194725, 42.006434351205826, 41.05689190328121, 40.146639347076416, 44.23213072121143, 43.58773849904537, 48.90715666115284, 49.81054678559303, 58.320779129862785, 60.63238508999348, 52.181665152311325, 40.61287812888622, 45.71032740175724, 38.23340781033039, 30.895349867641926, 47.63282284140587, 46.928960010409355, 46.49622403085232, 46.243203207850456, 51.38169027864933, 46.072634160518646, 46.6569060087204, 45.06920300424099, 45.76775752007961, 40.512875095009804, 41.402802541852, 42.44216836988926, 36.679492592811584, 24.172319322824478, 21.897094510495663, 18.028624691069126, 23.901530653238297, 32.464120388031006, 38.19529965519905, 41.392030119895935, 43.59395496547222, 43.6419577896595, 44.05195578932762, 43.03796499967575, 46.714571714401245, 47.40187503397465, 52.075392454862595, 50.963344126939774, 51.65165439248085, 50.93289256095886, 53.928936794400215, 50.04192017018795, 55.87970271706581, 48.799911215901375, 51.29219748079777, 54.271970987319946, 56.139867156744, 60.29417283833027, 55.130595713853836, 59.15274068713188, 56.05353198945522, 53.06636407971382, 55.80998785793781, 49.70871984958649, 49.92964759469032, 53.833083137869835, 57.63298183679581, 56.494289338588715, 59.82564277946949, 56.810576766729355, 59.75829519331455, 56.98061764240265, 55.11611849069595, 53.78383778035641, 48.18895719945431, 49.74469251930714, 56.63210794329643, 62.76173382997513, 65.581144541502, 65.9471333026886, 68.91136184334755, 51.54815174639225, 23.37592575699091, 0.1983518057386391, 0.11553024014574476, 0.5056671879719943, 0.13394607813097537, 28.607032857835293, 77.36734449863434, 41.30984053015709, 52.0030215382576, 67.62403652071953, 64.1022714972496, 17.404451183974743, 38.493899032473564, 40.912906229496, 51.45632967352867, 53.783716186881065, 53.99860605597496, 35.39500571787357, 1.1915237945504487, 0.12443889179849066, 0.06609758682316169, 0.047021229984238744, 0.06965404012589715, 0.09330854270956479, 0.10386969748651609, 0.08451163623249158, 0.041485123729216866, 0.10600927213090472, 0.04088783956831321, 0.07632386972545646, 0.17255018086871132, 0.5302187392953783, 0.29529530613217503, 16.97685442864895, 84.00606706738472, 57.12681859731674, 48.622798919677734, 39.54985857009888, 55.71600750088692, 18.35735835134983, 37.701303362846375, 77.34104230999947, 64.7368298470974, 58.437280878424644, 54.51473996043205, 70.64452484250069, 24.295140132308006, 0.08063435991061851, 0.14934770559193566, 1.5360433515161276, 0.539046140620485, 0.07057763548800722, 1.5482121985405684, 49.06348407268524, 72.30110675096512, 65.13081550598145, 63.4308285266161, 61.05557218194008, 62.469548508524895, 53.729717284440994, 52.547414526343346, 52.616924196481705, 53.65010395646095, 54.79897990822792, 57.48620331287384, 57.56057292222977, 63.11932884156704, 35.467707216739655, 43.51258233189583, 53.857154846191406, 50.31550548970699, 56.80029071867466, 58.49026903510094, 60.49939222633839, 57.16290146112442, 60.12580767273903, 57.192653864622116, 53.7189182639122, 52.77743898332119, 59.34008203446865, 53.7647096067667, 54.5286700129509, 55.98964981734753, 54.536607787013054, 53.77938821911812, 55.48829331994057, 52.996060252189636, 53.34620386362076, 53.33770751953125, 49.32231858372688, 47.846504375338554, 45.615644082427025, 46.77896685898304, 42.88300171494484, 40.92340886592865, 32.99390695989132, 36.131907775998116, 41.35211706161499, 45.035259425640106, 48.82741793990135, 45.68736903369427, 44.47190545499325, 42.50320069491863, 48.40218275785446, 47.02468067407608, 50.06376139819622, 51.7885572463274, 58.90289269387722, 60.570148229599, 53.46211664378643, 43.09163711965084, 48.65556836128235, 37.056645154953, 30.04225194454193, 49.672325402498245, 50.06258726119995, 48.39888073503971, 50.75625903904438, 53.39715912938118, 48.746007308363914, 47.186403796076775, 47.20959395170212, 48.40462222695351, 43.78029316663742, 45.91143921017647, 45.94932697713375, 40.578125193715096, 30.272593684494495, 25.76962251216173, 24.204450398683548, 28.50168541073799, 37.19490833580494, 41.991907730698586, 46.0648749768734, 46.781098544597626, 48.66111606359482, 48.099969774484634, 46.86689794063568, 50.2740953117609, 50.63663765788078, 54.40715633332729, 51.701712906360626, 53.71632680296898, 55.10332837700844, 55.55310644209385, 52.255548387765884, 57.511213570833206, 49.85180877149105, 52.273513823747635, 54.78061929345131, 55.02778463065624, 60.52637837827206, 56.75819657742977, 60.02188324928284, 57.37852469086647, 55.833614990115166, 52.58910208940506, 50.2439059317112, 52.73038610816002, 56.59286744892597, 58.11000443994999, 60.570402815937996, 60.637579411268234, 61.026610136032104, 61.87427245080471, 60.30189022421837, 58.28425548970699, 53.65146808326244, 50.58092124760151, 52.925186455249786, 59.13464605808258, 63.7124428153038, 67.91460692882538, 69.71797496080399, 69.30600106716156, 55.53396686911583, 27.35762570053339, 0.6864375597797334, 0.24907749553676695, 0.47237631340976804, 0.13675632420927286, 34.35190089046955, 84.85072374343872, 47.513520643115044, 52.9584688693285, 75.93196392059326, 69.40237909555435, 21.228224001824856, 43.93238000571728, 52.48865447938442, 40.380911976099014, 56.21432416141033, 63.6772795021534, 41.88167944550514, 1.1494031734764576, 0.13510955788660794, 0.051733496657107025, 0.08949698356445879, 0.04897482613159809, 0.1125546584080439, 0.2677650115219876, 0.21127307176357135, 0.18031371349934489, 0.15463274699868634, 0.18222324462840334, 0.309882634319365, 0.21664803178282455, 0.6977772794198245, 0.5406968551687896, 23.419978693127632, 95.99099636077881, 69.37939032912254, 65.37975534796715, 49.125443547964096, 67.26945474743843, 28.583314530551434, 45.952932983636856, 82.21567913889885, 71.64307326078415, 62.00911581516266, 59.3131984770298, 76.7188560962677, 27.874055989086628, 0.19416582566918805, 0.3345594898564741, 3.330378318205476, 1.4199896226637065, 0.18375723419012502, 2.1314828004688025, 53.57466280460358, 73.15607607364655, 67.2043414413929, 66.37971729040146, 62.76491425931454, 64.82356399297714, 57.20870040357113, 57.28435054421425, 54.203916639089584, 55.354038923978806, 55.95197103917599, 60.66297344863415, 59.029638692736626, 64.2134839296341, 44.836606085300446, 48.843532875180244, 52.36095853149891, 52.72700048983097, 58.901653960347176, 58.622900918126106, 63.72636526823044, 59.14667621254921, 59.89258758723736, 59.02869254350662, 55.92584744095802, 55.43257690966129, 63.47873255610466, 56.12201951444149, 57.3393639922142, 60.06277285516262, 58.37113782763481, 60.26706129312515, 59.256022945046425, 56.15935631096363, 57.71492063999176, 57.07030043005943, 53.829473331570625, 52.53025844693184, 50.720624551177025, 51.32998265326023, 46.10014848411083, 47.32515715062618, 44.47859309613705, 43.8687714189291, 47.422625720500946, 50.26564456522465, 52.89609521627426, 52.478683814406395, 48.37008208036423, 46.411268189549446, 51.71142138540745, 50.123080015182495, 54.879983961582184, 56.23064428567886, 64.47609543800354, 63.847616761922836, 56.72374002635479, 46.48990876972675, 50.61078004539013, 41.30002945661545, 30.09312741458416, 51.418962478637695, 51.59936159849167, 52.88923658430576, 51.04758560657501, 58.124132081866264, 51.374440267682076, 52.600281089544296, 50.84568344056606, 52.32259579002857, 47.63021998107433, 47.22205348312855, 50.578534975647926, 44.30321350693703, 37.29341425001621, 32.990422546863556, 29.682055972516537, 36.10182859003544, 41.6898163408041, 48.57825770974159, 48.06678995490074, 50.90261198580265, 52.312180548906326, 53.62101271748543, 49.548756033182144, 54.70676265656948, 53.07310871779919, 57.628391683101654, 57.86242872476578, 59.19246755540371, 57.99215756356716, 58.366475477814674, 55.03636457026005, 59.439857080578804, 52.72579215466976, 53.427082523703575, 57.92767882347107, 59.657178819179535, 62.30977088212967, 61.03019714355469, 61.68691970407963, 59.59263168275356, 57.089759185910225, 62.09925837814808, 54.31811951100826, 51.30820982158184, 58.651277795434, 60.56442953646183, 63.25226090848446, 63.539628088474274, 60.44571630656719, 64.13104355335236, 64.04505416750908, 60.19809119403362, 57.91977144777775, 53.47481556236744, 56.7976688593626, 62.812214121222496, 68.65854620933533, 71.95030957460403, 73.08710217475891, 71.61573752760887, 54.589432552456856, 32.83488929271698, 2.047184086404741, 0.7167511456646025, 1.2280973070301116, 0.5798785120714456, 36.59931309521198, 89.01865929365158, 54.42016303539276, 64.31721076369286, 80.81525668501854, 75.3668050467968, 28.43836560845375, 55.9839691221714, 64.27147641777992, 61.993035078048706, 71.10294744372368, 71.42048880457878, 54.68109883368015, 1.5965372929349542, 0.3750801889691502, 0.1818630803609267, 0.17501543217804283, 0.15717105532530695, 0.25611557881347835], [0.10192475107032806, 0.028540747225633822, 0.06805056327721104, 0.10207371495198458, 0.02976213119836757, 0.12146590757765807, 0.13088650011923164, 0.4425340803572908, 0.2015322499210015, 7.220063824206591, 66.84738099575043, 60.15112951397896, 39.18773040175438, 24.458652958273888, 44.294276386499405, 28.292882815003395, 32.01509468257427, 66.55062451958656, 67.03722640872002, 49.84906531870365, 42.51595661044121, 65.84593713283539, 29.40095655620098, 0.04610592812241521, 0.059109850844834, 0.44265338801778853, 0.7700849056709558, 0.15051111113280058, 0.5622323777060956, 36.63515657186508, 69.99525368213654, 59.43867154419422, 58.9118792116642, 53.732145354151726, 52.84759841859341, 49.61342476308346, 53.699550703167915, 52.56364345550537, 55.083603635430336, 52.38683134317398, 59.07193422317505, 57.225282713770866, 63.51171098649502, 38.50496023893356, 35.03176040947437, 46.62762477993965, 50.61426065862179, 59.722109735012054, 57.72139549255371, 56.604662016034126, 56.535931304097176, 52.54926882684231, 49.57949258387089, 51.082532331347466, 50.475442707538605, 54.813954904675484, 53.05753715336323, 50.69543570280075, 52.79225438833237, 51.44594103097916, 48.55280287563801, 50.704186633229256, 48.587597608566284, 49.7762156277895, 49.76786747574806, 48.09422068297863, 43.801066651940346, 41.17641068994999, 37.292962074279785, 44.48406860232353, 38.660045117139816, 34.19041335582733, 34.04599830508232, 36.817896366119385, 36.2125014513731, 36.59550949931145, 40.07698908448219, 43.21012996137142, 42.17134550213814, 44.47843350470066, 42.846664264798164, 43.35638031363487, 52.1673209220171, 59.03292551636696, 62.39979185163975, 51.66316397488117, 41.782295778393745, 43.80898542702198, 45.00496365129948, 48.95340017974377, 44.72250200808048, 41.85697317123413, 44.258011132478714, 52.4952395260334, 58.82341615855694, 51.253545954823494, 46.109309792518616, 43.01323592662811, 46.866867542266846, 40.41028060019016, 39.47791323065758, 38.86079214513302, 37.460255697369576, 35.854465663433075, 31.814129166305065, 33.537270203232765, 27.952054403722286, 33.34631145000458, 36.72160193324089, 39.68694381415844, 43.98506037890911, 44.34604100883007, 42.791020050644875, 44.49842423200607, 49.05643165111542, 46.61599740386009, 48.57718616724014, 53.81790675222874, 50.03832936286926, 53.06219570338726, 50.94969905912876, 52.629205137491226, 54.41330820322037, 48.683409467339516, 49.17339697480202, 53.938189297914505, 53.70332010090351, 58.0691946297884, 55.56718848645687, 59.595660120248795, 60.84939144551754, 53.300408720970154, 27.98891242593527, 46.568838134408, 54.76480834186077, 58.31877663731575, 58.31332013010979, 60.32109819352627, 58.2295536249876, 60.777750089764595, 58.04514192044735, 58.62509720027447, 57.29338265955448, 54.742712527513504, 50.41128695011139, 52.021085768938065, 50.04048004746437, 59.13781888782978, 60.886766240000725, 67.42510199546814, 61.28691516816616, 67.02163964509964, 26.902165040373802, 0.21338436316000298, 0.9437956719193608, 0.22793066542362794, 0.336865609860979, 42.39226944744587, 57.461417242884636, 54.59063708782196, 63.65696959197521, 65.7642263174057, 26.72059938311577, 26.800947971642017, 53.51866900920868, 31.351642683148384, 54.525770768523216, 42.80813053250313, 64.25595805048943, 17.679906003177166, 0.6622030539438128, 0.0816090521402657, 0.03910944222297985, 0.03739718878932763, 0.03407897602301091, 0.11771053643315099, 0.056169676972785965, 0.047841358828009106, 0.0150591801138944, 0.11268123911577277, 0.024387438352277968, 0.1451699188328348, 0.023438428142981138, 0.4156917269574478, 0.13639667944516987, 8.22732612490654, 76.211978495121, 65.51664680242538, 37.86890096962452, 28.00013892352581, 54.07970890402794, 28.427057415246964, 35.98514065146446, 70.42602136731148, 72.98374012112617, 54.57798756659031, 49.34019662439823, 70.39618536829948, 32.66720429062843, 0.06081470135541167, 0.3311998466961086, 0.5840060405898839, 1.637640162371099, 0.07342769778915681, 0.5254172813147306, 41.3950851559639, 71.41327679157257, 62.47959516942501, 61.82725377380848, 55.67819193005562, 55.894145742058754, 53.25713664293289, 56.74480989575386, 56.1233152449131, 55.44307954609394, 56.41256332397461, 61.23401440680027, 58.40975135564804, 65.5833712220192, 41.526755690574646, 36.755838096141815, 49.36537027359009, 52.142151072621346, 61.76894970238209, 59.81797859072685, 59.22022886574268, 58.52756783366203, 55.64349979162216, 52.26109988987446, 52.01041214168072, 49.809270054101944, 56.985648572444916, 57.48088739812374, 52.60361731052399, 55.32489448785782, 56.600391045212746, 53.40742237865925, 54.81373451650143, 52.42566525936127, 54.80629451572895, 52.048569694161415, 52.25158140063286, 48.12706992030144, 45.28191179037094, 42.95287236571312, 47.61539317667484, 45.08452758193016, 40.215807035565376, 40.58079645037651, 41.79187886416912, 39.9790645390749, 40.89236073195934, 43.900332525372505, 47.368987798690796, 44.89291526377201, 46.73255234956741, 44.86762762069702, 46.74405813217163, 50.739395543932915, 57.167913392186165, 64.40019831061363, 54.69142287969589, 42.965670078992844, 46.14600822329521, 45.025809332728386, 49.54215198755264, 46.62974886596203, 45.3180630505085, 45.28021328151226, 52.62931153178215, 58.28287996351719, 52.37386643886566, 48.31609457731247, 45.05408361554146, 46.82835280895233, 42.76336893439293, 42.156499698758125, 42.850437462329865, 41.31128065288067, 40.016450732946396, 37.630231976509094, 37.61534817516804, 33.36065948009491, 37.60392598807812, 42.33894310891628, 42.98607498407364, 49.6234068274498, 48.15840303897858, 46.3888493925333, 48.717657029628754, 54.451731741428375, 50.96284255385399, 50.686016008257866, 55.33418118953705, 52.231959253549576, 56.16051904857159, 53.442407101392746, 54.32804837822914, 55.42027696967125, 49.80342596769333, 51.646137088537216, 55.71671426296234, 54.97521825134754, 60.09751819074154, 57.45960853993893, 59.89944241940975, 62.366175055503845, 53.50938990712166, 30.582875534892082, 47.739828899502754, 55.58013059198856, 59.11934807896614, 59.3138824403286, 61.88521206378937, 61.309599950909615, 62.938044369220734, 60.50299443304539, 62.038894817233086, 60.92685028910637, 58.46935495734215, 53.808034881949425, 54.7673200070858, 51.61862276494503, 62.13354393839836, 62.48492628335953, 72.4120531976223, 64.34559524059296, 65.14153853058815, 27.867697030305862, 0.7273047231137753, 1.2297784793190658, 0.1517879613675177, 0.21410026849480346, 48.296050652861595, 65.71824878454208, 58.67234766483307, 68.04411917924881, 73.09916272759438, 27.532587312161922, 33.158685117959976, 58.71297888457775, 43.263881877064705, 48.61823916435242, 47.10895635187626, 74.62847426533699, 21.669013649225235, 0.6796096230391413, 0.17036419973010197, 0.044686637484119274, 0.04885528840532061, 0.05455429978610482, 0.12294569067307748, 0.15205175033770502, 0.22330178646370769, 0.07578858829219826, 0.44781033473555, 0.09501155640464276, 0.267276648664847, 0.21237035194644704, 0.7295455341227353, 0.47746130148880184, 11.211922522634268, 87.57353603839874, 80.36697193980217, 53.336871564388275, 35.17457574605942, 64.17823702096939, 33.65439511835575, 45.6098759919405, 75.03479406237602, 79.36903908848763, 62.167685106396675, 55.231206715106964, 76.40878513455391, 36.92169539630413, 0.20530267182039097, 0.31804005440790206, 0.8484381262678653, 2.771509769372642, 0.22740378510206938, 0.8688033709768206, 45.63741311430931, 73.35726767778397, 66.45602479577065, 63.627087995409966, 57.11715951561928, 59.59556892514229, 53.568959310650826, 60.261695981025696, 57.49694153666496, 58.38787592947483, 58.33267629146576, 65.4580007493496, 62.228079065680504, 70.8573666214943, 40.03035418689251, 37.65062928199768, 52.16487765312195, 55.24270869791508, 64.32364001870155, 62.53302030265331, 60.997788682579994, 62.711796909570694, 57.86329507827759, 54.26034741103649, 54.224188551306725, 54.97988060116768, 59.09502938389778, 59.73962679505348, 56.215897276997566, 60.76671168208122, 60.3495092689991, 57.99166738986969, 56.73982456326485, 55.772525668144226, 57.01268792152405, 56.256053522229195, 55.3435704857111, 52.41401128470898, 48.60020153224468, 48.78178618848324, 53.52399632334709, 48.60385313630104, 45.57728514075279, 46.08364976942539, 47.012183144688606, 47.34509088099003, 44.56626579165459, 48.39726202189922, 53.21606084704399, 49.316702485084534, 51.57147489488125, 48.47552262246609, 49.68614526093006, 53.79632391035557, 62.92551264166832, 67.70741924643517, 57.32693485915661, 46.26900762319565, 49.025147929787636, 47.70093038678169, 52.290947288274765, 48.49452920258045, 47.06111691892147, 48.33967611193657, 57.91256323456764, 61.439590975642204, 54.631845876574516, 50.99582098424435, 48.2523225992918, 52.408117800951004, 46.7309146374464, 44.300485253334045, 46.83545462787151, 46.35934017598629, 46.71536587178707, 42.748272344470024, 44.98224087059498, 39.010401517152786, 44.47681859135628, 47.80600234866142, 47.55640134215355, 53.00695426762104, 52.962831035256386, 51.539058834314346, 52.72220514714718, 57.232012152671814, 55.28351850807667, 54.590298905968666, 58.582338094711304, 56.981438398361206, 57.99241974949837, 55.52386321127415, 56.52841530740261, 59.656783640384674, 52.71027758717537, 53.79736505448818, 56.42555482685566, 56.061602756381035, 63.019192814826965, 59.42469209432602, 61.400141492486, 63.50209750235081, 53.129718080163, 39.93671201169491, 52.62059859931469, 55.579819008708, 61.05405606329441, 61.81544400751591, 63.91136214137077, 62.8248256444931, 64.59854006767273, 60.835032016038895, 61.742423325777054, 62.76842527091503, 60.08943222463131, 54.739000126719475, 57.06626884639263, 53.736689910292625, 64.3310572206974, 66.17974922060966, 72.68276587128639, 65.76310157775879, 66.6857984662056, 31.350253857672215, 1.6926424484699965, 1.346652964130044, 0.41983623581472784, 0.5507591902278364, 51.886755377054214, 71.48925751447678, 64.17829781770706, 75.33335164189339, 79.06601294875145, 40.639754086732864, 41.103990375995636, 70.48173397779465, 49.767270907759666, 65.10598763823509, 58.95755276083946, 86.19035705924034, 32.22227096557617, 1.0721632931381464, 0.3366811416344717, 0.08977506629889831, 0.10835366469109431, 0.14226648869225755, 0.2337201000773348], [0.03138603009574581, 0.1086862655938603, 0.011766456409532111, 0.07627622384461574, 0.04559711909678299, 0.03517082368489355, 0.08441182479145937, 0.22478375147329643, 0.04084748899913393, 1.5720085403881967, 54.7176680713892, 55.91927379369736, 49.704429879784584, 23.425374403595924, 37.940732315182686, 24.423261657357216, 40.347013995051384, 67.08277836441994, 61.12524904310703, 60.36994457244873, 40.37501469254494, 60.64905099570751, 32.643238976597786, 0.2304163554799743, 0.2228335358086042, 0.391465206630528, 0.485979316290468, 0.24654767737956718, 0.33717974612955004, 36.12192191183567, 70.99862784147263, 61.62159740924835, 63.27030993998051, 54.179358556866646, 55.85528522729874, 55.648492723703384, 58.08150976896286, 59.11661982536316, 61.80044621229172, 58.412019833922386, 56.01211041212082, 58.443079367280006, 58.88213440775871, 53.46381135284901, 50.828964337706566, 55.48507109284401, 60.68441949784756, 57.07609511911869, 56.630489230155945, 55.74653886258602, 51.142515912652016, 50.187281370162964, 51.53142124414444, 49.15575832128525, 51.56403109431267, 52.615259885787964, 53.94014619290829, 51.28949202597141, 51.89470075070858, 52.90788598358631, 48.27894777059555, 51.761396303772926, 52.65709564089775, 48.72334912419319, 48.88963580131531, 49.366559609770775, 48.38393993675709, 43.58670875430107, 36.01848766207695, 30.732085928320885, 38.80913011729717, 35.88831044733524, 31.812234967947006, 25.408746376633644, 26.214652732014656, 30.490225106477737, 38.35033133625984, 42.65034779906273, 43.33133965730667, 44.07728523015976, 43.366278782486916, 44.715145602822304, 51.5191251039505, 58.200823366642, 54.174084439873695, 52.47085243463516, 47.2992767393589, 42.657411620020866, 47.13169813156128, 43.543501272797585, 45.043242797255516, 45.99247366189957, 45.97247153520584, 55.02400763332844, 61.79250843822956, 53.77013951539993, 46.85182794928551, 45.56809723377228, 44.761632308363914, 39.23644758760929, 43.231389820575714, 45.159683749079704, 45.03317713737488, 40.464374497532845, 35.77553629875183, 30.85154391825199, 22.757090963423252, 20.59054221957922, 27.948178611695766, 37.34918765723705, 41.40438325703144, 44.17390264570713, 42.390000969171524, 49.67548303306103, 54.54332582652569, 50.978170931339264, 41.70031517744064, 51.55573233962059, 49.233019575476646, 53.93633119761944, 50.31669482588768, 52.59360484778881, 52.80639722943306, 53.029236271977425, 49.09797482192516, 53.09287525713444, 52.75012984871864, 56.214096173644066, 57.03555129468441, 57.509043887257576, 54.37334954738617, 55.39582908153534, 32.94772803783417, 51.3340750336647, 59.68060456216335, 59.29067708551884, 58.369769901037216, 61.41159027814865, 60.576687678694725, 58.91465686261654, 60.49688056111336, 59.74520109593868, 59.71916489303112, 61.086498722434044, 55.2486477792263, 52.66746148467064, 48.303809836506844, 57.49627277255058, 58.65140698850155, 63.837668895721436, 59.835438653826714, 62.234724909067154, 17.237022668123245, 0.5661513924133033, 1.094632912427187, 0.009483147241553525, 2.14122096542269, 58.70814934372902, 50.608367174863815, 58.27219873666763, 62.347442060709, 60.640623047947884, 18.869603164494038, 38.20236727595329, 47.5434934347868, 28.559639900922775, 47.599179446697235, 45.53536579012871, 59.2735780030489, 8.75562222674489, 0.590350809507072, 0.174503528396599, 0.025277826316596474, 0.07292905618669465, 0.004199120257908362, 0.05442158522782847, 0.07799132712534629, 0.04610284449881874, 0.018506103551771957, 0.057005951239261776, 0.017080706893466413, 0.07040898984996602, 0.03056785681110341, 0.16565646015806124, 0.059688510809792206, 2.016247808933258, 64.8294384777546, 67.04576835036278, 51.5473385900259, 25.785803943872452, 49.58860069513321, 26.6183240711689, 49.861167669296265, 75.04098773002625, 66.98396846652031, 64.79492872953415, 45.820016115903854, 66.40196889638901, 35.71791999042034, 0.14994454075349495, 0.44312441430520266, 0.6101896043401212, 0.959540008334443, 0.13603672297904268, 0.42173939931672066, 40.611969977617264, 73.37434396147728, 63.18843953311443, 64.25787314772606, 56.641235053539276, 59.038290828466415, 59.028145372867584, 61.738076359033585, 61.614636182785034, 64.20156016945839, 60.57964771986008, 60.143605917692184, 60.102693513035774, 59.21918772161007, 55.25770269334316, 53.42155002057552, 58.32016736268997, 63.473515436053276, 60.29120519757271, 58.31546701490879, 56.29409708082676, 53.76019164919853, 52.39012956619263, 52.843437641859055, 51.95001818239689, 52.102678790688515, 54.45516295731068, 57.88486272096634, 53.5806854814291, 55.7161632925272, 56.16587296128273, 53.3510410040617, 54.925965294241905, 57.06906169652939, 51.95413716137409, 52.9197983443737, 53.09065617620945, 48.95689599215984, 47.72678039968014, 42.29432590305805, 36.04417808353901, 43.398136273026466, 41.222506016492844, 38.779685497283936, 31.827401854097843, 31.651836074888706, 35.01388996839523, 42.21195012331009, 45.99791876971722, 49.02798257768154, 46.71193465590477, 45.54161265492439, 47.71030068397522, 53.37850593030453, 60.18476150929928, 54.697023779153824, 52.9322274774313, 49.603511095047, 45.360917150974274, 46.88184253871441, 45.72527959942818, 47.762194499373436, 48.10934767127037, 47.191001549363136, 58.0571036785841, 61.89272806048393, 55.8482214063406, 47.499191612005234, 48.120131492614746, 47.24397070705891, 41.752471178770065, 45.278073996305466, 48.35996322333813, 48.71085539460182, 43.42194199562073, 38.881858214735985, 36.020892933011055, 28.144645169377327, 25.695526488125324, 32.037194296717644, 42.82546140253544, 44.70547892153263, 48.04935649037361, 45.01613885164261, 52.37233892083168, 54.80452761054039, 52.95142024755478, 45.250582471489906, 54.14708308875561, 52.72027105093002, 57.34509028494358, 52.24060758948326, 54.24895942211151, 55.118409767746925, 55.0738837569952, 51.98334999382496, 54.709004536271095, 55.43578013777733, 57.45826341211796, 57.00760759413242, 59.19809505343437, 57.72415794432163, 56.10925979912281, 34.364124834537506, 52.94321648776531, 59.389152601361275, 59.98956598341465, 60.166845470666885, 62.25083984434605, 62.44601637125015, 61.20293587446213, 61.846226155757904, 61.07295244932175, 61.21327131986618, 62.250076085329056, 57.462264597415924, 58.19568604230881, 51.30400724709034, 60.49438029527664, 61.225100085139275, 67.9888017475605, 62.91754826903343, 64.95252907276154, 18.706451319158077, 0.40685898216906935, 1.5747530618682504, 0.12132626507082023, 2.830481417477131, 63.77193242311478, 57.79456056654453, 62.440016493201256, 69.79037627577782, 66.23673856258392, 22.816876955330372, 44.348377883434296, 54.56497326493263, 35.887755677103996, 43.04781787097454, 51.563453525304794, 68.9678344130516, 11.370435766875744, 0.9217027074191719, 0.11447238284745254, 0.1091177502530627, 0.0784381222911179, 0.05073519299912732, 0.07414155479636975, 0.20418076717760414, 0.1832603514776565, 0.1767691716668196, 0.24450024036923423, 0.08684577231178991, 0.17157194117316976, 0.15419652743730694, 0.5496186576783657, 0.1926169783109799, 2.9361601592972875, 76.91858097910881, 76.20339095592499, 67.104611992836, 32.71874472498894, 63.14551703631878, 31.12050488591194, 55.6986690312624, 75.97048625349998, 74.13741901516914, 70.57520136237144, 52.80526489019394, 75.94945818185806, 40.420847833156586, 0.3858296340331435, 0.6112975417636335, 0.7863840716890991, 2.4260634183883667, 0.30132994637824595, 0.44971406226977706, 43.73115040361881, 76.57203197479248, 66.59480094909668, 68.16280961036682, 60.052665397524834, 61.40573859214783, 61.34100526571274, 61.48639686405659, 63.08744855225086, 66.99866607785225, 62.53792583942413, 62.94362626969814, 61.603206396102905, 60.7963652908802, 58.16244162619114, 52.86152087152004, 59.8494067043066, 66.09193593263626, 63.78512531518936, 60.81599123775959, 59.78867456316948, 55.31768247485161, 54.394157230854034, 55.920360535383224, 54.20540235936642, 55.73645420372486, 57.73951672017574, 60.108465403318405, 56.790966019034386, 58.468237817287445, 59.177560955286026, 56.99148125946522, 59.98689092695713, 60.833728685975075, 55.3325092792511, 56.28283068537712, 56.98943316936493, 54.0924496203661, 52.805090099573135, 46.78075276315212, 41.04534812271595, 50.40485769510269, 47.155568450689316, 44.09966602921486, 38.26312601566315, 37.10215151309967, 43.661059364676476, 48.20242367684841, 50.50726979970932, 52.017817944288254, 49.64888446033001, 49.391102492809296, 51.08996473252773, 55.6424168497324, 62.44265355169773, 55.99387899041176, 55.833744183182716, 54.39536936581135, 51.208689361810684, 50.6049245595932, 48.81341189146042, 49.12533335387707, 51.415565460920334, 52.25842863321304, 59.40643787384033, 67.38507494330406, 58.83851274847984, 49.48067128658295, 53.00721265375614, 51.8803945183754, 45.38650497794151, 49.06306229531765, 51.28948822617531, 50.94445914030075, 47.836875692009926, 44.6392522752285, 40.90792469680309, 34.78215180337429, 33.991539627313614, 39.427429139614105, 46.68790474534035, 48.90088699758053, 52.20364697277546, 49.66822162270546, 55.232905223965645, 62.12715268135071, 57.711322233080864, 48.34380269050598, 57.42683529853821, 55.91746509075165, 59.7996673732996, 54.05921660363674, 57.089717388153076, 59.34937633574009, 58.121327832341194, 53.12764339148998, 57.820630967617035, 57.37295798957348, 60.31662583351135, 59.678495675325394, 61.315569430589676, 60.41184112429619, 58.78833644092083, 37.98934690654278, 56.913950219750404, 63.23527581989765, 62.4925372749567, 62.47554838657379, 62.94582635164261, 63.06271567940712, 62.015955448150635, 64.05393809080124, 64.02198940515518, 63.462332636117935, 65.08194252848625, 59.61200304329395, 61.19569346308708, 51.368102207779884, 64.01631250977516, 63.20006310939789, 70.98200753331184, 64.43064987659454, 65.87983131408691, 23.33334904164076, 0.5533881741575897, 2.4546084366738796, 0.1527226369944401, 3.4711966244503856, 68.54038774967194, 66.10428526997566, 66.57033786177635, 73.79844680428505, 72.43933573365211, 29.841742403805256, 49.322774559259415, 63.38971473276615, 42.839942425489426, 57.5095796585083, 60.6787122040987, 83.6018143594265, 18.955972529947758, 1.4608979900367558, 0.527780398260802, 0.20944945164956152, 0.10366674978286028, 0.1575830957153812, 0.20334311993792653], [0.07501728905481286, 0.0589939014025731, 0.07229995244415477, 0.050260044081369415, 0.01540942650535726, 0.02010351890930906, 0.0567143131775083, 0.09702250943519175, 0.23074601747794077, 0.5480925645679235, 46.7326245456934, 61.533172354102135, 39.41726088523865, 25.496709756553173, 35.30891753733158, 24.470458924770355, 23.657310158014297, 71.52432963252068, 64.0209786593914, 66.25924855470657, 51.31559282541275, 58.55182193219662, 47.02024631202221, 0.9175839659292251, 0.8381717896554619, 1.0808091354556382, 0.3116904170019552, 0.24854644434526563, 0.21424388891318813, 32.34063841402531, 68.01662385463715, 58.06998498737812, 60.954072028398514, 56.22302569448948, 57.438717260956764, 58.11914674937725, 59.668259024620056, 59.029938876628876, 59.197308495640755, 60.25747060775757, 60.127768367528915, 57.6640185713768, 53.173480331897736, 49.33127090334892, 52.5103285163641, 56.32847003638744, 55.84543615579605, 58.19331116974354, 55.65304487943649, 53.42784248292446, 53.424202278256416, 53.571299985051155, 52.41654194891453, 53.110118731856346, 51.18268355727196, 51.513923183083534, 54.50875148177147, 49.50611852109432, 49.48330454528332, 54.34980981051922, 51.19383975863457, 47.00661264359951, 52.0341494679451, 52.12400324642658, 51.361114382743835, 51.28131486475468, 49.171481877565384, 47.30465345084667, 44.283617958426476, 40.07632791996002, 37.61249452829361, 35.001244246959686, 30.23322969675064, 23.750735744833946, 30.960649363696575, 33.55846926569939, 38.55068318545818, 43.03096577525139, 41.56748190522194, 40.18009275197983, 43.18454593420029, 44.86748322844505, 51.30728267133236, 53.881678730249405, 51.67380340397358, 50.687524527311325, 50.81658460199833, 47.4983062595129, 52.94829681515694, 53.369739800691605, 45.16694515943527, 43.596675619482994, 48.92200246453285, 48.898261338472366, 56.3954072445631, 53.09107035398483, 46.582574397325516, 46.484019085764885, 40.4122830927372, 28.941570706665516, 23.539398685097694, 27.882913313806057, 26.672258377075195, 29.96135238558054, 27.26950652897358, 20.61031825840473, 19.259137362241745, 20.39866391569376, 31.277552358806133, 41.37003690004349, 42.27814257144928, 43.03018681704998, 46.31069138646126, 48.67898270487785, 48.15529100596905, 52.21952252089977, 49.36446592211723, 51.1619670689106, 51.33662469685078, 54.03349198400974, 52.61967144906521, 53.40974785387516, 52.76978239417076, 48.06974619626999, 48.55724863708019, 51.95733278989792, 54.03121590614319, 53.99270497262478, 58.64186190068722, 59.86133426427841, 68.71021583676338, 56.57592415809631, 42.52924829721451, 57.22532071173191, 57.9122706502676, 57.592514008283615, 57.0490937680006, 59.14635702967644, 58.45247246325016, 61.02289393544197, 61.702103689312935, 62.66092523932457, 60.40434792637825, 62.26164646446705, 62.86247402429581, 61.18068806827068, 56.299143210053444, 56.15769200026989, 60.04772566258907, 64.88284081220627, 59.54210579395294, 65.04140630364418, 10.87011756375432, 0.46919137181248516, 1.2371547147631645, 0.11250975847360678, 5.01187976449728, 59.10574100911617, 58.09902302920818, 61.71569176018238, 55.082171112298965, 64.92673605680466, 15.455984137952328, 48.63348014652729, 40.07175676524639, 33.73454421758652, 52.09695629775524, 52.50487960875034, 44.49253834784031, 1.963278295006603, 0.2973467210540548, 0.11043843915103935, 0.05476874335727189, 0.062055431262706406, 0.07661393072339706, 0.014619461326219607, 0.1181155709491577, 0.04246921896992717, 0.052822383149759844, 0.031614852778147906, 0.11067447179812007, 0.038280771259451285, 0.018588442981126718, 0.13159762602299452, 0.2885712106944993, 0.675728190690279, 54.534867480397224, 71.51667684316635, 43.416553884744644, 27.65498634427786, 43.51999953389168, 20.29164645820856, 29.663735255599022, 77.48550295829773, 70.02611562609673, 70.21741256117821, 53.33332255482674, 65.46810820698738, 49.05779957771301, 1.1130223819054663, 0.2131698973244056, 1.1250223754905164, 1.4752676314674318, 0.4908995475852862, 0.22660435846773908, 35.86560666561127, 72.45440572500229, 60.57328686118126, 62.76257738471031, 59.09739285707474, 61.140189841389656, 60.722637847065926, 63.58482286334038, 62.91847161948681, 63.88306885957718, 62.013785764575005, 63.00491698086262, 58.964320197701454, 54.598951041698456, 51.20495796203613, 54.506783187389374, 59.94421161711216, 57.25750498473644, 59.69998352229595, 57.687432914972305, 54.646509289741516, 56.48046188056469, 56.52115009725094, 55.44028289616108, 55.545427054166794, 52.183200269937515, 53.13734047114849, 55.66708132624626, 54.18815888464451, 53.03765282034874, 57.08943620324135, 54.037249982357025, 54.00218166410923, 55.83866871893406, 55.76258920133114, 55.167605727910995, 54.71322610974312, 54.098897874355316, 49.63589295744896, 48.66730973124504, 44.39525216817856, 42.86771513521671, 40.199752897024155, 36.38847000896931, 29.77048482745886, 36.041138246655464, 38.09048607945442, 43.53266425430775, 49.12781462073326, 45.407327860593796, 43.574484810233116, 45.77686183154583, 47.01685689389706, 50.65581142902374, 57.022331804037094, 53.23546640574932, 51.478611677885056, 51.51050716638565, 48.02258312702179, 52.36319661140442, 51.96311607956886, 49.006779715418816, 44.907479882240295, 50.63328243792057, 52.07798391580582, 58.49350266158581, 56.60047084093094, 48.36343243718147, 49.25118640065193, 43.76982092857361, 31.84009127318859, 26.82928115129471, 35.926471799612045, 33.33659917116165, 35.988024696707726, 32.63854242861271, 26.68233923614025, 25.48131488263607, 26.63539845496416, 36.96136526763439, 43.663837015628815, 45.80917529761791, 47.595474645495415, 48.41069050133228, 52.26601302623749, 52.061834782361984, 56.957556679844856, 51.13909229636192, 51.78463205695152, 55.91526500880718, 57.67115458846092, 54.09306898713112, 55.87004743516445, 55.32156586647034, 51.558171808719635, 51.83647647500038, 54.0790781378746, 55.111771523952484, 55.75849302113056, 60.400415137410164, 60.37085272371769, 68.23698163032532, 57.79718242585659, 45.554999336600304, 58.74145455658436, 61.738239750266075, 59.11169148981571, 59.006072357296944, 63.16749505698681, 61.15856185555458, 63.05544666945934, 64.86027002334595, 63.793446868658066, 62.275903299450874, 64.61557075381279, 64.5883946120739, 61.691874638199806, 58.51579986512661, 59.614035934209824, 61.02328151464462, 68.94676834344864, 63.275538459420204, 66.57028466463089, 11.117446292191744, 0.3983819636050612, 1.550932852551341, 0.07919029638287611, 6.173314042389393, 63.95587295293808, 65.79541504383087, 67.11069166660309, 64.2674258351326, 68.62677231431007, 19.2461496591568, 52.76380531489849, 46.73085764050484, 39.00726668536663, 52.09768585860729, 59.81825977563858, 53.536125272512436, 2.508595702238381, 0.42530728911515325, 0.09062466211616993, 0.07821866180165671, 0.010466873263794696, 0.019871976255672053, 0.0238947079560603, 0.2175222075311467, 0.211655322345905, 0.20883401826722547, 0.1326515499386005, 0.2074993695714511, 0.10175990522839129, 0.109345819655573, 0.24694911990081891, 0.47702981682959944, 0.8621985535137355, 65.59533298015594, 80.39911061525345, 54.994566813111305, 33.975128307938576, 56.160002276301384, 35.22596038877964, 35.97602494060993, 80.27494847774506, 75.09584918618202, 78.33298668265343, 61.23797759413719, 73.13009306788445, 55.41187942028046, 1.9511134852655232, 1.5145664289593697, 2.117482926696539, 1.972021150868386, 0.6266560801304877, 0.23501566727645695, 41.63144767284393, 74.54305484890938, 62.85558499395847, 67.80433684587479, 60.32254971563816, 62.252355962991714, 62.389258816838264, 66.7659817636013, 64.98778358101845, 68.52360785007477, 65.56228995323181, 65.22901743650436, 60.82782380282879, 57.59772352874279, 52.079036459326744, 57.07565054297447, 61.74629531800747, 61.89584009349346, 63.209228217601776, 61.07103735208511, 58.301742151379585, 58.92058454453945, 59.327462911605835, 58.22494827210903, 57.507645562291145, 57.07449920475483, 56.94656766951084, 57.75446131825447, 53.82345825433731, 55.925934836268425, 61.020203679800034, 58.53646695613861, 56.99041351675987, 59.58746396005154, 61.08846701681614, 59.989801570773125, 59.0219821035862, 58.16985882818699, 56.102043986320496, 54.789267629384995, 48.53335551917553, 48.74595411121845, 45.95847308635712, 42.90302664041519, 36.629019901156425, 45.12241534888744, 43.475971296429634, 50.2325027436018, 54.75494787096977, 51.61309786140919, 49.69308748841286, 49.4028552621603, 51.02069444954395, 53.95801663398743, 60.37590265274048, 55.905963107943535, 55.74870094656944, 55.651262775063515, 51.35283462703228, 58.53180080652237, 59.332163259387016, 52.913574278354645, 49.97615709900856, 52.25346229970455, 52.90622167289257, 59.36038434505463, 58.14492456614971, 51.7114631831646, 53.24010215699673, 46.80608980357647, 37.481135576963425, 35.37253752350807, 43.15451994538307, 41.62042446434498, 43.40495690703392, 39.716198444366455, 34.07107315957546, 33.506218269467354, 33.19082759320736, 43.09475675225258, 50.20355589687824, 49.95397388935089, 51.475302055478096, 51.12654536962509, 55.65962992608547, 54.76947829127312, 59.851621985435486, 52.79373250901699, 56.1214305460453, 56.757881194353104, 57.64387205243111, 56.99116587638855, 58.878775388002396, 56.24610185623169, 52.85715110599995, 53.876807391643524, 56.55112288892269, 56.71470791101456, 58.209498301148415, 62.57105626165867, 63.62440533936024, 66.93089291453362, 55.56404985487461, 46.13060384988785, 60.22203370928764, 63.198448196053505, 62.01119810342789, 61.814197674393654, 64.27624136209488, 63.698691353201866, 64.08051386475563, 67.98553392291069, 67.22124293446541, 64.68002289533615, 65.84801182150841, 68.99623408913612, 63.60426262021065, 60.81249542534351, 62.84234270453453, 63.24574425816536, 70.57021602988243, 66.67039409279823, 71.20879456400871, 15.029153041541576, 0.47798243758734316, 2.2834273846819997, 0.15963976504281163, 6.870765667408705, 71.20454639196396, 71.92561089992523, 71.9304670393467, 69.09619152545929, 75.76351135969162, 25.33468645066023, 57.91186407208443, 55.53519420325756, 49.078424870967865, 68.16454231739044, 67.17378348112106, 72.07880347967148, 5.257831541821361, 0.7968893204815686, 0.18708376272115856, 0.14059837820241228, 0.12962425535079092, 0.219935983477626, 0.11330770823406056], [0.06642763473792002, 0.03927213583665434, 0.07657907946850173, 0.05236612931184936, 0.04434137554198969, 0.023671677736274432, 0.005821122967972769, 0.1100310223409906, 0.41338765528053045, 0.4813822457799688, 32.491638511419296, 63.92375707626343, 45.67079432308674, 38.07885870337486, 40.755674466490746, 31.321861781179905, 17.755582742393017, 51.41075871884823, 66.59217908978462, 61.303478479385376, 62.968530133366585, 50.94684161245823, 57.43325315415859, 4.158045155927539, 0.21407151769381016, 0.6573156255763024, 0.2444037760142237, 0.6976104446221143, 0.2871767745818943, 27.343678548932076, 66.5369300544262, 61.78987517952919, 58.907030671834946, 54.82381917536259, 60.01791626214981, 63.55681076645851, 64.8200985789299, 66.74744635820389, 65.88157922029495, 58.60258720815182, 55.85906222462654, 55.613815784454346, 52.19500243663788, 51.43441244959831, 53.69766980409622, 58.618629947304726, 60.776420161128044, 58.62519599497318, 55.140680372714996, 56.08062453567982, 53.97055596113205, 57.47209846973419, 59.56634469330311, 53.65146808326244, 52.234429121017456, 48.529707714915276, 50.81061512231827, 52.05787919461727, 49.76345971226692, 52.997800558805466, 50.029791221022606, 52.67424412071705, 48.684009835124016, 50.04292331635952, 52.27357842028141, 49.70353692770004, 52.20623843371868, 51.04538172483444, 44.69849109649658, 45.297608748078346, 43.512700125575066, 39.5143760740757, 35.11183351278305, 35.88125042617321, 37.49343931674957, 44.16153810918331, 44.75393392145634, 40.20318791270256, 44.435955584049225, 42.8400906175375, 43.406222239136696, 46.130729243159294, 51.5246956050396, 55.9029346704483, 56.89492084085941, 61.478926464915276, 59.321151450276375, 61.5449783205986, 59.52780336141586, 54.94806490838528, 56.14327557384968, 55.05581192672253, 51.54983505606651, 49.979193136096, 49.07673016190529, 52.722053155303, 45.966205671429634, 44.41000297665596, 43.44311445951462, 32.93457694351673, 28.124508149921894, 23.931345753371716, 19.646296687424183, 26.45739320665598, 22.345681339502335, 17.915394566953182, 18.95199604332447, 27.066821604967117, 39.76946018636227, 43.111620247364044, 43.18187087774277, 44.0914660692215, 49.15500596165657, 49.511472433805466, 49.93592865765095, 51.31393611431122, 51.93266451358795, 50.60631908476353, 53.39126944541931, 52.666462138295174, 52.8774344176054, 51.57859571278095, 54.20125298202038, 47.6838731020689, 51.877236887812614, 54.491082429885864, 57.8171693533659, 53.258648961782455, 59.5605044066906, 56.28717765212059, 58.81607495248318, 72.31101661920547, 61.31862826645374, 53.17500405013561, 56.65104612708092, 52.43534334003925, 54.493054524064064, 54.62244898080826, 56.60175897181034, 55.6327273696661, 59.18366342782974, 60.701799765229225, 61.19986943900585, 61.968302205204964, 62.74366959929466, 57.27491945028305, 60.362899750471115, 60.21801732480526, 62.476794719696045, 60.80392308533192, 61.97157762944698, 53.651829063892365, 3.515129154548049, 0.39478147868067026, 1.0435173427686095, 0.30141170136630535, 13.672212604433298, 65.3138516843319, 62.03243136405945, 54.609978049993515, 62.337190210819244, 49.40986588597298, 18.804976232349873, 68.48757058382034, 28.487550169229507, 38.922497034072876, 35.512563809752464, 54.58344787359238, 29.706821143627167, 0.3051781008252874, 0.10997708304785192, 0.0769818875414785, 0.06857719126855955, 0.025780186078918632, 0.04099644545931369, 0.025406726235814858, 0.025554780986567494, 0.09548909874865785, 0.1965293730609119, 0.025968756526708603, 0.039304693855228834, 0.0750397241790779, 0.0792068091686815, 0.028538600563479122, 0.5083430756349117, 0.3899980994174257, 37.25276403129101, 79.40578311681747, 47.7847158908844, 39.15058359503746, 55.912247970700264, 29.247243404388428, 19.79182317852974, 68.6186483502388, 73.18857192993164, 68.17379862070084, 67.34268441796303, 56.1175699532032, 61.234550178050995, 4.94849156588316, 0.5428236129228026, 0.6369725859258324, 1.3444164278917015, 1.585347130894661, 0.3611862938851118, 31.35135769844055, 69.43299785256386, 65.9022881090641, 63.042071387171745, 58.046639040112495, 64.15309756994247, 64.61124658584595, 64.63365778326988, 67.9255959391594, 68.35605964064598, 64.26589831709862, 58.25259938836098, 55.725712180137634, 55.636428371071815, 54.634794518351555, 56.277526170015335, 60.6699650734663, 63.12064737081528, 61.44178345799446, 56.91328905522823, 59.03079003095627, 54.56240080296993, 61.95403017103672, 58.26019898056984, 55.4747698456049, 54.14524778723717, 52.33562529087067, 54.44234624505043, 54.94147226214409, 51.84482462704182, 55.76752133667469, 54.76971387863159, 57.36005388200283, 53.347864374518394, 54.52251814305782, 54.96065743267536, 51.94893904030323, 55.79870246350765, 54.25003856420517, 49.40806098282337, 48.37610475718975, 47.780802100896835, 43.25083717703819, 41.13768316805363, 40.89203014969826, 43.48953656852245, 48.11728164553642, 47.365522384643555, 46.05244964361191, 47.893454656004906, 47.828189358115196, 48.696647956967354, 48.90322767198086, 53.347488194704056, 57.204915806651115, 58.46919156610966, 59.11173328757286, 59.43949609994888, 60.75881950557232, 61.46143600344658, 56.27674721181393, 57.56280340254307, 53.28565031290054, 50.56853011250496, 51.05024166405201, 52.99007557332516, 53.11188943684101, 47.19576649367809, 45.262973606586456, 46.11716777086258, 36.763684675097466, 32.27463975548744, 30.909663699567318, 25.328260995447636, 32.84175552427769, 29.499789252877235, 24.443746358156204, 24.576771520078182, 33.738332614302635, 44.07659366726875, 45.53230695426464, 48.17387580871582, 49.309843853116035, 50.32274790108204, 51.400655061006546, 53.08880187571049, 54.09980222582817, 52.47509680688381, 52.985177636146545, 55.193596333265305, 56.36732675135136, 55.45471832156181, 53.68599683046341, 54.56560403108597, 48.58980529010296, 52.53050923347473, 55.45262083411217, 58.634372502565384, 55.33864215016365, 62.12272971868515, 58.70061054825783, 56.87699720263481, 68.47468927502632, 59.821428805589676, 55.36335602402687, 59.35242377221584, 54.503336772322655, 56.17944583296776, 57.15320438146591, 60.325201973319054, 57.927545830607414, 60.753704980015755, 60.191832929849625, 62.98861965537071, 64.54473495483398, 66.4028200507164, 62.330475971102715, 62.87262707948685, 62.238729894161224, 64.2134003341198, 63.39638717472553, 65.09760528802872, 55.27723744511604, 3.7204404501244426, 0.561184702673927, 1.70420047827065, 0.2686259028268978, 16.39942791312933, 72.15036123991013, 68.32519769668579, 59.3199697136879, 69.59629029035568, 54.216178581118584, 22.55904369056225, 73.16983133554459, 36.90819852054119, 44.46130022406578, 38.05226393043995, 58.29496331512928, 37.711061239242554, 0.8780254167504609, 0.22085744887590408, 0.05599660442385357, 0.11347998297424056, 0.032083522746688686, 0.05893585432204418, 0.0734020936943125, 0.27075901336502284, 0.13486095325788483, 0.35900337039493024, 0.10465934261446819, 0.23543737042928115, 0.1784384695929475, 0.16499931807629764, 0.22764893132261932, 0.653773978119716, 0.936067420989275, 48.38677458465099, 85.99519953131676, 62.593193873763084, 48.21558617055416, 61.94245979189873, 43.77773590385914, 26.60774353891611, 63.15321542322636, 78.85338395833969, 74.50235143303871, 72.27887034416199, 62.52968788146973, 71.00582465529442, 6.065170895308256, 1.7346418322995305, 1.1305992887355387, 1.4271267084404826, 1.4837002102285624, 0.33815534377936274, 35.999549478292465, 75.18751546740532, 66.22906297445297, 65.24152636528015, 58.904826790094376, 65.2120703458786, 68.62189337611198, 66.23392671346664, 68.9425353705883, 69.0899446606636, 64.38307642936707, 59.64432030916214, 58.893807381391525, 58.84667091071606, 55.71015581488609, 57.134213000535965, 62.687683403491974, 65.73780253529549, 65.26599705219269, 59.95998457074165, 62.00693093240261, 58.278973773121834, 62.73697055876255, 61.23773440718651, 60.54698467254639, 57.052088007330894, 53.21577966213226, 57.42769405245781, 56.17481388151646, 53.7978932261467, 59.93644863367081, 58.32389496266842, 59.854665622115135, 55.89766435325146, 59.280634224414825, 61.13333880901337, 57.564000338315964, 59.865897819399834, 56.86123564839363, 53.8529446721077, 53.672264367341995, 52.05968789756298, 50.1576391607523, 47.0756359398365, 47.00947009027004, 46.941548734903336, 52.94331148266792, 52.462109103798866, 53.00144076347351, 53.082574009895325, 53.230066895484924, 51.21381528675556, 52.16312974691391, 54.80287469923496, 60.96644036471844, 62.520081996917725, 65.09626016020775, 64.72455650568008, 64.47472751140594, 64.46522042155266, 57.99854502081871, 61.43906660377979, 54.94207642972469, 56.89999356865883, 56.152653470635414, 53.817226588726044, 57.2211979329586, 50.635592713952065, 50.19876055419445, 48.802335485816, 42.386049181222916, 37.86997631192207, 38.32769215106964, 36.175236850976944, 38.346706330776215, 36.661819741129875, 31.841140016913414, 32.348355799913406, 40.3209587931633, 48.138283118605614, 50.71543402969837, 53.177055940032005, 53.2841531932354, 53.273749351501465, 55.80841854214668, 56.15456856787205, 58.7675591558218, 55.476954728364944, 58.59256714582443, 57.90490284562111, 60.58210238814354, 58.56414087116718, 56.67662635445595, 57.14778587222099, 50.26904158294201, 54.716824516654015, 58.67290623486042, 61.6605719178915, 55.943805277347565, 63.88638988137245, 59.73678074777126, 62.925774827599525, 64.08043026924133, 58.90881657600403, 58.92981804907322, 59.4119817763567, 57.67311908304691, 56.53296746313572, 59.04759272933006, 61.46450623869896, 60.93232199549675, 63.32322970032692, 65.11082097887993, 63.19359965622425, 66.14509508013725, 67.68162623047829, 65.09062886238098, 64.73452717065811, 62.798200473189354, 67.67557695508003, 67.46564581990242, 66.25821501016617, 61.1886790394783, 6.467269118875265, 0.7042195368558168, 2.2752618603408337, 0.37796847929712385, 16.52800541371107, 76.95540860295296, 73.96214202046394, 65.7530777156353, 76.1194534599781, 60.93638397753239, 28.377665765583515, 79.9136334657669, 48.70401956140995, 52.266165018081665, 50.28391018509865, 67.24246099591255, 53.39122384786606, 1.47689109435305, 0.34314533695578575, 0.1049501309171319, 0.2743258938426152, 0.14424738474190235, 0.08317338812048547, 0.15970011649187654], [0.049176927786902525, 0.02688188018510118, 0.09237693957402371, 0.018080248082696926, 0.11864000218338333, 0.06432206530007534, 0.08447383865131997, 0.04109243112907279, 0.5588409409392625, 0.5012326478026807, 17.421225383877754, 63.11404712498188, 50.35937413573265, 35.64704239368439, 27.688707634806633, 40.36646895110607, 16.12826496362686, 27.934233359992504, 71.12262278795242, 60.84445171058178, 60.733193680644035, 52.42278501391411, 62.01420374214649, 14.994402956217527, 0.4049674258567393, 0.9307562559843063, 0.7347329088952392, 1.5251336619257927, 0.25104279164224863, 21.079384088516235, 66.17165565490723, 59.09320928156376, 59.453502148389816, 55.620906203985214, 60.057141557335854, 60.06720721721649, 64.72623601555824, 67.37809091806412, 65.20071655511856, 63.76805663108826, 56.74411453306675, 51.73658363521099, 55.97045324742794, 60.64276613295078, 49.980732053518295, 55.897242575883865, 55.78472301363945, 55.96117414534092, 55.79613380134106, 54.87681873142719, 58.13773915171623, 53.64055886864662, 64.40553322434425, 55.035787001252174, 52.058483362197876, 51.1751713603735, 51.2917947024107, 52.228984013199806, 47.30070926249027, 54.274216666817665, 52.31410324573517, 51.30333088338375, 51.68796144425869, 51.94122165441513, 52.69882880151272, 52.68871754407883, 52.855015620589256, 48.85036490857601, 48.468762785196304, 44.32130813598633, 43.016857132315636, 42.484148517251015, 40.49511104822159, 38.8821280002594, 40.686943754553795, 43.50268006324768, 44.070559591054916, 44.37612019479275, 45.86033955216408, 41.88320316374302, 41.72323174774647, 46.383989453315735, 56.67342692613602, 58.79481889307499, 61.98044255375862, 60.51490679383278, 55.13652719557285, 54.1865211725235, 51.32520630955696, 47.59900465607643, 58.688337206840515, 54.70145434141159, 56.97214409708977, 57.26602032780647, 53.96653197705746, 52.817925810813904, 48.12751069664955, 43.1525744497776, 44.00487631559372, 40.8527060598135, 41.55208893120289, 39.19159099459648, 37.446929812431335, 30.43465878814459, 25.892388224601746, 22.083085030317307, 29.2661264911294, 35.82201160490513, 42.084998935461044, 41.81609496474266, 44.476438611745834, 46.852435916662216, 51.24272033572197, 47.561344876885414, 47.3112802952528, 49.190150275826454, 48.68255451321602, 49.08914789557457, 51.023620292544365, 52.432831674814224, 48.31730671226978, 53.827562034130096, 51.3886933028698, 46.65530249476433, 51.96650169789791, 53.55691395699978, 56.67769409716129, 55.114746764302254, 57.480796203017235, 56.86636157333851, 43.22204992175102, 51.6098490357399, 61.717660054564476, 58.32428254187107, 58.797224164009094, 48.05203914642334, 51.95733278989792, 50.70601053535938, 54.626415967941284, 54.771723970770836, 58.98575484752655, 56.48456946015358, 60.15603505074978, 57.23175376653671, 64.4168946146965, 65.87413921952248, 79.24755960702896, 61.433005928993225, 62.878353372216225, 61.64632648229599, 64.19966787099838, 44.45993609726429, 0.5771404027473181, 0.43441216461360455, 0.601943809306249, 0.22177952283527702, 26.990193016827106, 63.26502442359924, 55.58375559747219, 61.694393903017044, 64.39418703317642, 37.6117991656065, 18.103398978710175, 43.28403979539871, 30.28045166283846, 31.02996524423361, 34.31397132575512, 61.35037176311016, 22.34319057315588, 0.5465673026628792, 0.03497716024867259, 0.13731661601923406, 0.0707826240977738, 0.020964421346434392, 0.04263085873390082, 0.028778473824786488, 0.010180107401538407, 0.02630292892717989, 0.12474456016207114, 0.035859388299286366, 0.0358909629721893, 0.014181493079377105, 0.13678114162757993, 0.055584289439138956, 0.852581150829792, 0.3087514528306201, 21.68576505035162, 72.71457016468048, 57.984622567892075, 39.17674899101257, 32.54297375679016, 45.396711230278015, 13.073059804737568, 33.17814387381077, 78.81382048130035, 64.98452335596085, 65.72634235024452, 55.56372307240963, 67.51929134130478, 15.904566217213869, 0.6333298876415938, 0.797130191931501, 1.1317777005024254, 2.2282039979472756, 0.2825221134116873, 25.195971094071865, 71.38969525694847, 62.74307683110237, 62.211933732032776, 57.98370681703091, 63.88293966650963, 61.47347375750542, 66.81958928704262, 67.86948814988136, 59.499669671058655, 60.15521049499512, 57.901494428515434, 55.51864609122276, 59.25460942089558, 60.66909112036228, 50.26734687387943, 58.406745716929436, 59.04739513993263, 60.67837782204151, 58.63278038799763, 57.069289684295654, 57.434765473008156, 61.40053667128086, 64.8216412961483, 55.914812833070755, 56.7330951243639, 54.05882142484188, 54.75114427506924, 56.01186342537403, 49.33070093393326, 57.883452996611595, 56.14833690226078, 54.20610912144184, 54.937197491526604, 55.535824969410896, 53.26325051486492, 56.0084930062294, 54.89682845771313, 52.74354860186577, 50.67191116511822, 47.08001330494881, 46.72649547457695, 46.58426150679588, 44.61348205804825, 44.438820630311966, 44.28370915353298, 47.97130107879639, 46.39111027121544, 48.91259416937828, 46.589288637042046, 46.34162552654743, 44.249093011021614, 46.85769863426685, 57.37026773393154, 59.840541779994965, 63.80635857582092, 63.31895112991333, 56.13607496023178, 56.79005406796932, 51.42830617725849, 47.187243551015854, 59.73531402647495, 56.500000432133675, 59.74653862416744, 55.175950080156326, 53.7319515645504, 54.22898009419441, 49.41997334361076, 45.31201757490635, 45.782044753432274, 44.05980236828327, 47.2377048432827, 44.18075367808342, 42.892653197050095, 36.31777100265026, 30.763761028647423, 27.502240240573883, 34.171258583664894, 40.94700939953327, 44.67400141060352, 46.70718491077423, 49.05464194715023, 50.551693215966225, 53.785217106342316, 50.9796604514122, 49.71175968647003, 53.40996444225311, 51.91466487944126, 51.87932297587395, 53.9432468265295, 55.14691583812237, 49.69485819339752, 56.02051556110382, 53.48257854580879, 49.11615304648876, 52.68919251859188, 56.24311901628971, 56.50241710245609, 57.92594611644745, 58.07478792965412, 57.401578053832054, 46.29970997571945, 53.50060097873211, 65.84410563111305, 56.711405888199806, 60.36080986261368, 48.21875520050526, 52.807506769895554, 54.08229276537895, 56.5825168043375, 57.00970508158207, 59.98573958873749, 58.59559938311577, 59.666723906993866, 56.47279769182205, 62.850132286548615, 62.67740495502949, 73.02122890949249, 65.54648280143738, 65.95864668488503, 64.54712122678757, 68.91418889164925, 46.232552379369736, 0.9406492032576352, 0.6057292968034744, 0.7517447147984058, 0.27285632269922644, 31.27531997859478, 67.09638923406601, 62.11013339459896, 67.25944608449936, 70.51160797476768, 43.31810876727104, 25.803178511559963, 51.50725834071636, 37.680852860212326, 42.06744387745857, 39.71942447125912, 70.79326406121254, 24.869314022362232, 1.0074692708440125, 0.1286763249663636, 0.0865488093404565, 0.04337107311584987, 0.07126305339625105, 0.13418610353255644, 0.04765659374243114, 0.1789975888095796, 0.12779873533872887, 0.23008930584182963, 0.19678916927659884, 0.293762504006736, 0.19382130587473512, 0.21598337916657329, 0.14379130530869588, 1.3034464325755835, 0.6516143283806741, 29.259058870375156, 84.97148886322975, 68.34130883216858, 46.70875422656536, 40.80761007964611, 52.85480283200741, 23.14366701990366, 38.62987093627453, 81.97237819433212, 74.1372062265873, 70.54402783513069, 61.63519687950611, 73.57325568795204, 18.766860477626324, 0.8686409296933562, 1.9051853497512639, 2.6543209701776505, 3.8236590614542365, 0.5281897075474262, 30.617700666189194, 74.12550285458565, 62.912517338991165, 64.50827971100807, 60.68647138774395, 65.3616227209568, 64.43937420845032, 68.86606067419052, 69.81675446033478, 61.4999583363533, 62.852902337908745, 59.35596898198128, 57.00543411076069, 60.37817493081093, 63.861045241355896, 52.56747364997864, 60.86636893451214, 60.681904032826424, 64.63655322790146, 62.12518438696861, 59.92014370858669, 63.210539147257805, 63.57083581387997, 66.8311558663845, 60.685833021998405, 59.66999553143978, 56.26902602612972, 57.68050968647003, 57.59002514183521, 52.84912593662739, 63.672674149274826, 61.58718265593052, 57.2001014649868, 58.50534662604332, 60.38468398153782, 56.889555528759956, 60.08973240852356, 59.35014769434929, 56.53187692165375, 56.0907281935215, 51.76537849009037, 51.551997140049934, 51.196264028549194, 50.2632886916399, 50.61776027083397, 50.863778069615364, 54.63634483516216, 53.87025274336338, 53.58578860759735, 52.10740573704243, 49.40632447600365, 48.853043764829636, 50.62034033238888, 60.370719730854034, 63.33930283784866, 67.34225884079933, 65.8656656742096, 60.062905848026276, 57.66694441437721, 55.75833722949028, 50.0357037037611, 60.58640755712986, 57.44691342115402, 60.35546734929085, 58.53437326848507, 57.229105308651924, 57.20457382500172, 52.12229333817959, 49.115290492773056, 49.44429963827133, 48.48969206213951, 50.318165346980095, 50.71586340665817, 48.9266724139452, 43.82036581635475, 38.688710778951645, 34.3245005607605, 40.23051604628563, 46.51804246008396, 50.13144716620445, 49.46638025343418, 53.145825415849686, 54.00823853909969, 57.21182383596897, 53.24706718325615, 53.49108248949051, 56.181664913892746, 55.41387051343918, 56.70240417122841, 58.35348777472973, 56.57243974506855, 52.07836389541626, 59.85141299664974, 56.86276316642761, 50.34980624914169, 55.2109120041132, 57.86099620163441, 59.677279740571976, 57.42338128387928, 60.84432251751423, 57.6412919908762, 47.73437239229679, 58.15807946026325, 61.65614515542984, 61.40491023659706, 60.44316664338112, 52.56133317947388, 54.79906730353832, 55.36283925175667, 57.683659717440605, 59.94145296514034, 61.58546894788742, 61.21489003300667, 62.64837831258774, 59.52211506664753, 64.72244381904602, 62.554409354925156, 73.91109555959702, 68.14720004796982, 69.56808060407639, 68.09742271900177, 72.39572927355766, 55.34132860600948, 1.8816349259577692, 0.738300858065486, 1.5313035808503628, 1.0005633789114654, 32.827783674001694, 75.0957503914833, 66.68207466602325, 74.20448541641235, 75.14912232756615, 49.8093194514513, 31.13625694066286, 53.371548503637314, 45.75232274830341, 43.49405452609062, 46.657126396894455, 77.87777870893478, 41.77713185548782, 1.2586617982015014, 0.21876972808968276, 0.17982898716581985, 0.20858302392298356, 0.13493303064024076, 0.40977387106977403, 0.1007085491437465], [0.09523379994789138, 0.027568865880311932, 0.11672904613078572, 0.08216789676225744, 0.18019461364019662, 0.0821718227234669, 0.1948260105564259, 0.31994897697586566, 0.46633208461571485, 0.3834810928674415, 8.213526215404272, 59.3492167443037, 49.25905577838421, 40.49715533852577, 32.869494035840034, 48.69536742568016, 48.82828429341316, 18.430871106684208, 59.729245752096176, 59.56063359975815, 63.41064780950546, 52.80053034424782, 62.18175195157528, 29.373843111097813, 0.6809527915902436, 0.6297604541759938, 1.1763350595720112, 1.5714161284267902, 0.1718407470616512, 12.434305530041456, 63.47470097243786, 61.89208209514618, 60.371441692113876, 56.961979642510414, 62.62889675796032, 61.49047404527664, 64.08944338560104, 54.81203220784664, 36.3954958319664, 28.15910529345274, 48.27338106930256, 55.69505922496319, 59.66209575533867, 54.35131452977657, 51.956971809268, 52.06624634563923, 59.12967212498188, 59.00667652487755, 56.81979887187481, 54.055344611406326, 58.274748399853706, 48.939979299902916, 58.45676243305206, 58.35851490497589, 55.336578860878944, 49.90662083029747, 50.319571271538734, 54.12539765238762, 46.766982302069664, 50.36904841661453, 53.55778411030769, 55.15348568558693, 51.029673367738724, 49.90250185132027, 51.5467344224453, 54.43478845059872, 53.44185993075371, 51.60953365266323, 49.25508879125118, 52.27592669427395, 46.64561301469803, 44.34662617743015, 45.01790575683117, 41.91818028688431, 44.7363256663084, 46.232620775699615, 46.40744559466839, 45.66646255552769, 41.66251480579376, 42.10240580141544, 40.948631912469864, 49.98021528124809, 57.93037287890911, 61.217614486813545, 60.00377342104912, 59.65475454926491, 57.38148093223572, 55.88920600712299, 52.51064009964466, 52.643773555755615, 55.48623003065586, 55.00824987888336, 57.36570417881012, 58.42640966176987, 58.9508993178606, 57.32047140598297, 49.98333491384983, 44.43214438855648, 43.229109942913055, 42.24184311926365, 38.87356325984001, 39.99360255897045, 40.37564165890217, 37.185952216386795, 34.77773644030094, 35.2419613301754, 40.38249269127846, 42.66408026218414, 43.27321037650108, 44.22245264053345, 49.3947920948267, 50.37543207406998, 49.9507212638855, 49.864230304956436, 48.4933702647686, 50.15613444149494, 51.24912679195404, 49.070878475904465, 50.691331923007965, 50.0989855080843, 48.687764033675194, 52.305473908782005, 48.701846078038216, 47.63741299510002, 54.19405236840248, 54.79976646602154, 56.00907437503338, 57.78246961534023, 56.25590153038502, 52.5981380045414, 55.14761120080948, 42.65432618558407, 53.38951773941517, 53.647550493478775, 56.588144302368164, 49.518597051501274, 47.044527009129524, 48.530220687389374, 52.41578958928585, 55.262232050299644, 57.99232475459576, 55.743145644664764, 54.79920029640198, 48.1724850833416, 48.232833445072174, 49.714582934975624, 59.1964877396822, 61.69989600777626, 67.37565144896507, 57.706469893455505, 64.91454631090164, 21.108169443905354, 0.13313042814843357, 0.3037980030057952, 0.0332215208618436, 0.5337891820818186, 52.03410007059574, 58.95453192293644, 57.689610198140144, 58.433636873960495, 59.03855301439762, 49.08613845705986, 11.19224052876234, 18.836569637060165, 35.940827429294586, 39.69233192503452, 40.2027091383934, 53.14600020647049, 9.640284106135368, 0.7252265908755362, 0.08015953382709995, 0.09074914254597388, 0.0347636295191478, 0.0603686038084561, 0.033887130848597735, 0.09407791978446767, 0.07193586221546866, 0.038579908723477274, 0.10135495234862901, 0.007092870009728358, 0.06776127411285415, 0.026490415839361958, 0.10929930183920078, 0.13549321854952723, 0.4832768003689125, 0.36305457644630224, 10.244649276137352, 72.20355838537216, 55.50901360809803, 42.31950335204601, 37.58958175778389, 50.78013315796852, 49.86410491168499, 18.266558423638344, 66.59606248140335, 67.41771519184113, 69.89449068903923, 60.2433467656374, 67.44510412216187, 33.83343771100044, 0.7000203465577215, 1.1485000094398856, 1.3298742519691586, 2.045546849258244, 0.17524799157399684, 15.092078614979982, 67.9885433614254, 65.84712266921997, 63.56080435216427, 58.24269711971283, 63.23370270431042, 63.40987265110016, 65.17834335565567, 58.07404696941376, 38.02207075059414, 28.15689381211996, 49.93158169090748, 60.14898642897606, 62.327595725655556, 57.27615438401699, 51.34121485054493, 50.121544897556305, 59.88881818950176, 60.128171145915985, 60.5161265283823, 56.908231526613235, 60.17598398029804, 52.15616852045059, 60.87922744452953, 61.77544355392456, 56.098605170845985, 53.461888656020164, 52.68737621605396, 55.444618463516235, 49.34501476585865, 52.80589945614338, 57.677724435925484, 57.18670338392258, 52.64957584440708, 52.132564187049866, 54.18719753623009, 57.307612895965576, 55.20322501659393, 58.838136568665504, 53.07756967842579, 54.69089850783348, 52.858025059103966, 47.254241555929184, 50.49933202564716, 45.59955954551697, 46.62442535161972, 49.69161316752434, 50.45028045773506, 51.95689961314201, 46.42594300210476, 43.21062013506889, 44.06736396253109, 53.41350205242634, 59.74880330264568, 62.76763491332531, 60.96887223422527, 59.68602307140827, 57.1270427852869, 56.01436749100685, 53.99196021258831, 53.473269045352936, 57.22113333642483, 55.833288207650185, 59.35435026884079, 60.3498550504446, 60.37268802523613, 57.35045179724693, 52.00685553252697, 45.834713727235794, 44.746942296624184, 44.88354116678238, 44.039944633841515, 42.6573546230793, 46.61140725016594, 41.592226177453995, 39.45304736495018, 39.6237950026989, 45.93354642391205, 48.58406379818916, 47.747949063777924, 45.371731370687485, 52.50918857753277, 51.86510793864727, 53.26488442718983, 51.8717385828495, 53.22363004088402, 53.04791986942291, 54.32582549750805, 49.771222695708275, 53.80405269563198, 51.97204940021038, 49.981545209884644, 55.152239352464676, 51.13704040646553, 48.38520526885986, 54.72655199468136, 57.029312029480934, 56.85382604598999, 59.90472413599491, 58.428157567977905, 54.03373897075653, 54.01936814188957, 46.71237163245678, 56.90911307930946, 55.51350876688957, 58.386781588196754, 49.71824213862419, 49.70430828630924, 50.974614322185516, 56.14229142665863, 58.16361956298351, 60.44447377324104, 58.118926361203194, 55.57826109230518, 47.70332045853138, 44.83086459338665, 48.521389961242676, 62.05310985445976, 66.03274270892143, 68.82172465324402, 58.954125344753265, 67.19991847872734, 22.848840840160847, 0.06406720436643809, 0.6401688675396144, 0.26874396367929876, 0.755059621296823, 57.764462381601334, 64.5745861530304, 62.05833077430725, 63.60654629766941, 66.07152342796326, 54.97922703623772, 21.53404299169779, 25.75044684112072, 47.43661276996136, 45.58811455965042, 42.54833847284317, 66.07821106910706, 13.908304385840893, 1.0605031438171864, 0.09925575053784996, 0.07530323855462484, 0.0970811687875539, 0.0962469502701424, 0.008798719172773417, 0.017615246179047972, 0.2091432415181771, 0.16797190153738484, 0.38155993970576674, 0.15692530054366216, 0.23994603630853817, 0.16611688857665285, 0.3890083119040355, 0.5662667518481612, 1.0378805827349424, 0.4433346795849502, 13.849103562533855, 83.68871569633484, 64.82617825269699, 56.28017082810402, 46.96185104548931, 69.15438920259476, 60.55586479604244, 29.62674044072628, 72.9983389377594, 69.83721256256104, 73.44259589910507, 65.88486224412918, 72.37828820943832, 38.4655449539423, 0.7945159915834665, 1.9630039972253144, 3.30929989926517, 4.096911661326885, 0.3889359376626089, 17.60647114366293, 73.54411125183105, 68.47571521997452, 65.34484282135963, 60.65113328397274, 67.12534368038177, 65.97756206989288, 68.69947761297226, 59.917084872722626, 42.5383298099041, 34.18350152671337, 55.96437357366085, 60.5923580378294, 65.83957627415657, 59.662331342697144, 54.854088351130486, 54.165329709649086, 62.01286241412163, 62.724917605519295, 61.99689567089081, 61.426223292946815, 63.23041968047619, 53.7767131626606, 63.49604442715645, 65.16034752130508, 59.062001556158066, 54.68260355293751, 55.03172501921654, 59.13833566009998, 51.92742079496384, 56.92690372467041, 58.623482286930084, 62.98395350575447, 57.6038184016943, 56.07044868171215, 57.79591329395771, 62.938473746180534, 61.141056194901466, 61.43663473427296, 58.54399435222149, 59.88745026290417, 57.575243934988976, 53.920413851737976, 54.22091692686081, 51.48771978914738, 51.53961360454559, 55.47526001930237, 55.2218022197485, 56.95594556629658, 50.360381081700325, 48.05933095514774, 49.83373314142227, 59.73668195307255, 62.766088396310806, 65.4276479780674, 64.87192019820213, 64.46811586618423, 63.5738642513752, 61.76416575908661, 55.586358457803726, 55.07174827158451, 59.302388057112694, 58.32443833351135, 62.93296404182911, 62.76218220591545, 62.27217949926853, 61.0778883844614, 55.27525395154953, 49.05431516468525, 48.74277748167515, 50.32989911735058, 47.64112539589405, 48.107189387083054, 53.04768808186054, 47.40168124437332, 44.80868138372898, 46.83830067515373, 50.926797688007355, 53.861330822110176, 53.29175278544426, 50.22594429552555, 55.2854336053133, 56.38799764215946, 57.586742118000984, 57.02207341790199, 54.99348387122154, 58.301046788692474, 56.877076998353004, 53.49492788314819, 58.112367913126945, 52.7196478843689, 52.76435628533363, 56.56715042889118, 53.590781539678574, 50.83358868956566, 56.27733238041401, 57.85686582326889, 57.51762002706528, 61.77996911108494, 58.45796696841717, 54.36307109892368, 56.517426297068596, 46.51793606579304, 54.038382321596146, 56.63127578794956, 61.29439316689968, 54.4888861477375, 51.7703752219677, 52.360312566161156, 58.22508126497269, 61.13594546914101, 62.03814245760441, 60.722345262765884, 57.676139920949936, 48.26546609401703, 45.65211072564125, 53.02760995924473, 69.09267291426659, 70.84275260567665, 70.62186285853386, 63.102894723415375, 70.3949162364006, 30.346699208021164, 0.14927113079465926, 1.6034228797070682, 0.4933924216311425, 0.7014553039334714, 61.972941756248474, 70.24828970432281, 69.57609057426453, 67.79604569077492, 70.72929069399834, 62.086350470781326, 21.138962991535664, 26.37657154351473, 53.510887026786804, 52.33000919222832, 56.8446609377861, 74.40093487501144, 26.559075750410557, 1.5118756983429193, 0.26369471743237227, 0.19191036466509104, 0.1768334861844778, 0.2569893834879622, 0.14519016462145373, 0.16501319623785093], [0.16891821403987706, 0.06372683317749761, 0.05633173976093531, 0.15118076582439244, 0.13151547027518973, 0.08882306152372621, 0.07668740334338509, 0.07876465984736569, 0.2991609455784783, 0.28716671105939895, 2.85614310298115, 46.10074125230312, 57.01559476554394, 37.740236073732376, 31.67129673063755, 45.47437526285648, 97.73359805345535, 12.44782330468297, 38.58835816383362, 62.98076547682285, 57.97985762357712, 60.43403573334217, 50.16367323696613, 61.64209730923176, 4.873980889096856, 0.5587611452210695, 0.5729339097160846, 1.1783347022719681, 0.059675163283827715, 5.130527447909117, 63.233056738972664, 62.684229388833046, 63.835191428661346, 60.205022022128105, 65.85738211870193, 61.08430244028568, 62.934100180864334, 56.40965647995472, 56.289677917957306, 49.879528284072876, 55.583056434988976, 59.180646389722824, 59.1351780295372, 55.926945582032204, 30.86228024214506, 45.342643931508064, 53.48565258085728, 56.74936205148697, 59.65595528483391, 60.42279593646526, 62.09388166666031, 57.49067947268486, 48.57297219336033, 51.6516125947237, 59.39095750451088, 54.49275813996792, 48.62359307706356, 51.42302826046944, 49.05801236629486, 50.781406089663506, 52.883449494838715, 51.69436790049076, 50.9513633698225, 52.03796446323395, 53.50339762866497, 51.15932621061802, 53.14484506845474, 53.10512959957123, 51.090842485427856, 51.547460183501244, 49.6929506957531, 43.3132716268301, 44.301685988903046, 43.37040916085243, 45.025216564536095, 45.18887758255005, 47.03839033842087, 42.05988988280296, 40.59143207967281, 42.95579060912132, 43.884829357266426, 49.36622142791748, 56.47564373910427, 60.671648383140564, 61.168350130319595, 58.88951361179352, 53.62371437251568, 54.37209941446781, 50.23477882146835, 48.07579167187214, 52.55136251449585, 53.2176947593689, 58.22814770042896, 56.92759528756142, 57.59363494813442, 59.99863609671593, 54.74610574543476, 48.309368938207626, 45.11316664516926, 43.19329306483269, 38.12631815671921, 40.759911239147186, 42.64351576566696, 44.27772827446461, 45.1538510620594, 43.24174426496029, 41.753706112504005, 45.27241989970207, 43.646908923983574, 49.914710596203804, 54.5042335242033, 50.06821095943451, 52.95424349606037, 52.76564061641693, 50.64656272530556, 48.79480428993702, 51.54306761920452, 49.75635029375553, 54.22621004283428, 52.37768903374672, 47.78713636100292, 53.45758728682995, 49.686080664396286, 48.33593711256981, 51.453407630324364, 54.59898144006729, 58.56867402791977, 57.97869488596916, 56.53641387820244, 54.79916989803314, 56.12302266061306, 47.875618413090706, 46.738255843520164, 62.67993561923504, 53.35362106561661, 44.94955502450466, 46.44594132900238, 52.47286632657051, 58.16950924694538, 60.8021941781044, 61.71914957463741, 60.13080060482025, 60.45113481581211, 56.33936785161495, 51.42579451203346, 51.02629914879799, 57.34945245087147, 60.92701368033886, 62.34410963952541, 64.25243943929672, 58.278605192899704, 4.304917249828577, 0.24342185526620597, 0.7103519327938557, 0.1360768880113028, 6.862058909609914, 64.25004556775093, 44.40895043313503, 68.2391931116581, 53.900673910975456, 73.65517169237137, 32.368232533335686, 10.728255975991488, 47.96466663479805, 26.990956775844097, 32.706110402941704, 46.467752158641815, 41.44521586596966, 7.468604212626815, 0.7198171655181795, 0.10307567368727177, 0.03878149829688482, 0.024810278846416622, 0.023701230056758504, 0.08443555125268176, 0.006562092485182802, 0.08678727623191662, 0.012712939605989959, 0.13003884872887284, 0.11552008756552823, 0.12534388893982396, 0.08623414614703506, 0.10789946289150976, 0.05016860035539139, 0.3521545644616708, 0.12109083356335759, 3.286934536881745, 58.525048568844795, 63.906065225601196, 43.878088518977165, 41.59518621861935, 55.4828330129385, 99.38542261719704, 16.979774571955204, 42.6865940541029, 74.80008825659752, 65.3168535232544, 67.70778402686119, 53.80083046853542, 66.03131398558617, 4.513541255146265, 0.49063929123803973, 1.7610419844277203, 1.9321928755380213, 0.05216167133767158, 6.593434698879719, 68.56672793626785, 65.57469248771667, 68.0289275944233, 62.65319645404816, 67.42117300629616, 63.82085099816322, 64.3578913807869, 58.504134491086006, 59.631135016679764, 52.012030854821205, 56.25439681112766, 62.62020282447338, 62.522422671318054, 58.04923430085182, 32.058830335736275, 45.57581841945648, 54.263539239764214, 59.62127834558487, 63.04251216351986, 60.07901318371296, 62.18491718173027, 60.98953552544117, 54.2208219319582, 57.96957157552242, 62.506626918911934, 58.89646723866463, 50.93963339924812, 53.9874080568552, 49.469496086239815, 54.67919133603573, 54.97326895594597, 54.40877504646778, 55.493924617767334, 54.59351733326912, 55.08422300219536, 53.68985742330551, 54.539609625935555, 55.121214017271996, 53.62805753946304, 56.26457266509533, 54.14293751120567, 48.7776368111372, 46.620082184672356, 46.78203709423542, 49.42258760333061, 49.5827642083168, 49.29229639470577, 47.140217274427414, 43.71337875723839, 45.644704923033714, 46.77854888141155, 52.39433594048023, 60.50555169582367, 62.59065181016922, 62.542189210653305, 60.46436570584774, 54.08317431807518, 55.860867127776146, 52.04461790621281, 48.14909353852272, 55.821866020560265, 55.635037645697594, 59.82341609895229, 57.12882108986378, 59.83073830604553, 61.53075948357582, 56.11617922782898, 52.042087242007256, 47.705581337213516, 46.459810584783554, 41.68918177485466, 43.5313381254673, 46.88770182430744, 47.986135482788086, 47.908281460404396, 47.74384528398514, 46.39049470424652, 49.04213301837444, 46.94646567106247, 53.83296154439449, 55.04564367234707, 52.990425154566765, 54.97811369597912, 57.712378576397896, 52.51914024353027, 51.88642859458923, 52.579040229320526, 52.47298792004585, 57.225324511528015, 53.67522440850735, 49.79760468006134, 54.9419966340065, 50.14179401099682, 51.13218426704407, 52.58193947374821, 56.62596367299557, 56.458514258265495, 59.70745772123337, 58.60342316329479, 55.345189198851585, 56.74310378730297, 51.03605702519417, 52.61523708701134, 62.17355199158192, 56.668297201395035, 47.1682445704937, 48.8703366369009, 55.48125609755516, 59.8896199464798, 63.28104816377163, 63.19960333406925, 61.82807832956314, 63.569676876068115, 59.21694204211235, 57.90182501077652, 55.830020383000374, 60.468845665454865, 64.44400995969772, 64.6422453224659, 68.19570824503899, 59.225632175803185, 5.314135495573282, 0.5046128632966429, 1.3155477144755423, 0.2680108998902142, 9.2239423468709, 71.17177695035934, 51.17451399564743, 71.5647442638874, 58.746512085199356, 83.1540235877037, 43.55274237692356, 13.478328008204699, 45.11668145656586, 42.32916623353958, 36.64831146597862, 48.80597569048405, 52.927105352282524, 7.608782015740871, 1.0832496732473373, 0.1313533406937495, 0.08286484764539637, 0.05802427062008064, 0.040865029659471475, 0.044704241227009334, 0.04096226213732734, 0.28447345714084804, 0.19132966379402205, 0.26869153836742043, 0.23875521583249792, 0.26047545892652124, 0.0947102667123545, 0.29189742752350867, 0.1443260078667663, 0.5631436163093895, 0.22491986135719344, 5.021673738956451, 71.17128297686577, 75.68337365984917, 52.47917018830776, 44.1618686914444, 65.5973468720913, 101.27281934022903, 22.56569903343916, 48.982305228710175, 76.33933246135712, 66.92225217819214, 74.39777344465256, 58.92896309494972, 77.89651170372963, 5.665246155112982, 0.9647986886557192, 3.6715171253308654, 3.014042442664504, 0.21051119780167937, 8.402402680367231, 74.25686180591583, 66.67170122265816, 71.88334956765175, 66.42201662063599, 70.92144638299942, 64.83984991908073, 67.07504957914352, 59.61554825305939, 60.47636166214943, 54.2288812994957, 59.65104974806309, 63.480298072099686, 67.28776976466179, 58.16203884780407, 35.646559819579124, 47.503359988331795, 56.066903471946716, 63.00016723573208, 64.11212056875229, 61.74972653388977, 65.1010251045227, 61.12504385411739, 52.42040254175663, 60.63316784799099, 64.60349500179291, 61.8613151460886, 53.89178618788719, 57.44256645441055, 54.517160430550575, 56.254320815205574, 57.20205835998058, 58.97965997457504, 60.641257613897324, 58.58434438705444, 59.83059011399746, 56.03200614452362, 60.481502786278725, 60.99673613905907, 56.764724627137184, 59.50760744512081, 58.77459637820721, 51.542866230010986, 51.08765825629234, 51.3316697627306, 53.110665902495384, 53.50194230675697, 55.69169260561466, 51.40266515314579, 48.780334666371346, 49.35185819864273, 52.37325467169285, 56.57990254461765, 61.90746746957302, 66.44128158688545, 62.666564136743546, 60.38497656583786, 55.99431976675987, 58.71570713818073, 53.80397289991379, 46.750715374946594, 58.60621981322765, 56.217508390545845, 61.443759351968765, 56.83290436863899, 60.453068912029266, 63.17252218723297, 60.75180508196354, 54.29256968200207, 52.677766531705856, 50.19319765269756, 45.02865917980671, 49.023723006248474, 52.45327837765217, 52.51012712717056, 53.0599120259285, 54.35416057705879, 52.25128501653671, 55.37883639335632, 51.13438434898853, 56.814691945910454, 58.764245733618736, 56.09497256577015, 59.8074721544981, 60.023194178938866, 56.57163418829441, 55.73012374341488, 56.286117509007454, 54.373087361454964, 58.83839875459671, 57.94040434062481, 53.181497901678085, 57.26397603750229, 52.26215623319149, 54.208761379122734, 55.284973829984665, 59.77990463376045, 61.37909822165966, 61.78595758974552, 59.10249978303909, 59.629618898034096, 58.87737326323986, 49.478740990161896, 48.97276774048805, 66.5204693377018, 56.88810780644417, 49.49324481189251, 49.64128866791725, 55.66794767975807, 61.67647406458855, 66.5343613922596, 65.78861340880394, 64.38268885016441, 62.83206805586815, 59.50449161231518, 57.905423417687416, 58.237958773970604, 60.52858226001263, 63.68004195392132, 66.86746671795845, 68.95982444286346, 66.05805695056915, 8.26384311541915, 0.5538362532388419, 2.3192449752241373, 0.3800866875099018, 8.841827251017094, 76.74155607819557, 56.722003519535065, 75.69016769528389, 63.40525209903717, 85.95264181494713, 43.23361650109291, 15.428197178989649, 66.14485189318657, 46.49121209979057, 46.03264890611172, 62.62592911720276, 67.88895070552826, 17.881920263171196, 1.4936599507927895, 0.20075176289537922, 0.12396537931635976, 0.19124845799524337, 0.17353833565721288, 0.2523041458334774, 0.10769743545097299], [0.15982004755642265, 0.07393738254904747, 0.181616242043674, 0.04834663894143887, 0.09051545508555137, 0.07080732277245261, 0.1496191238402389, 0.014735618569829967, 0.1352601099642925, 0.008545866676286096, 1.624375549145043, 35.460426807403564, 59.60622735321522, 34.38963286578655, 38.52893315255642, 27.531954646110535, 56.025029718875885, 24.132742546498775, 28.39490734040737, 60.09367659687996, 51.96068421006203, 66.93682819604874, 49.34667147696018, 63.67490462958813, 33.17256577312946, 0.1469940584502183, 0.39616098278202116, 1.2170473812147975, 0.15472383820451796, 2.7207456808537245, 48.70122671127319, 65.33368661999702, 61.632259637117386, 57.59580083191395, 57.84636698663235, 56.58258140087128, 57.8195708245039, 56.275253891944885, 52.76056408882141, 51.97633557021618, 55.72432905435562, 59.24834355711937, 63.66808399558067, 44.729201048612595, 36.88519835472107, 55.51066271960735, 57.584006264805794, 61.17500737309456, 51.23029500246048, 57.09251783788204, 49.27800916135311, 58.36346223950386, 41.420414596796036, 48.28190021216869, 57.57309705018997, 53.546293526887894, 51.08509719371796, 52.02987849712372, 52.049565240740776, 47.53016754984856, 54.97945502400398, 51.366525292396545, 52.69779145717621, 51.48960828781128, 53.6544319242239, 51.96041822433472, 55.08390761911869, 48.40328469872475, 52.07194983959198, 52.82429426908493, 50.71943901479244, 49.78695385158062, 46.234463676810265, 43.11594061553478, 43.63622009754181, 42.542802169919014, 41.781205236911774, 40.09404256939888, 40.15282541513443, 43.01297754049301, 47.587381079792976, 50.7221444696188, 53.605832532048225, 56.9382993131876, 60.701662972569466, 53.91034059226513, 56.105422005057335, 56.98377147316933, 53.234501257538795, 45.95452509820461, 55.78337028622627, 53.402007669210434, 55.245303958654404, 54.78333614766598, 56.50215871632099, 58.87822061777115, 56.787056028842926, 49.5665542781353, 42.001399621367455, 40.57250149548054, 40.326992869377136, 40.82944370806217, 41.20134875178337, 41.65005907416344, 40.93392290174961, 44.46935199201107, 43.405424281954765, 43.78924548625946, 48.414524495601654, 49.594144597649574, 51.43444284796715, 52.60033808648586, 52.22999095916748, 50.85386820137501, 51.31202481687069, 50.24002633988857, 49.99641761183739, 51.98222145438194, 53.232468366622925, 45.32518766820431, 48.94220978021622, 54.08807225525379, 47.172067165374756, 50.20483262836933, 48.995357528328896, 51.68370187282562, 55.20914509892464, 58.56486663222313, 55.292315036058426, 61.41736596822739, 57.41230107843876, 52.79378570616245, 50.37268862128258, 58.623448088765144, 54.33747947216034, 46.15952789783478, 48.08908335864544, 55.92180825769901, 59.1318304091692, 58.83294224739075, 61.72340154647827, 60.269618555903435, 60.463693141937256, 64.9798572063446, 60.86760766804218, 67.93762609362602, 64.57742840051651, 65.39050117135048, 58.641371726989746, 65.8928570151329, 33.86917859315872, 0.15907794440863654, 0.07096502173226327, 1.066167689859867, 0.1233552597113885, 27.1629336476326, 65.87555274367332, 48.723531514406204, 69.58197265863419, 54.87291634082794, 67.75890648365021, 22.504100538790226, 26.51405766606331, 48.54143388569355, 27.96491101384163, 37.80282251536846, 46.492576226592064, 33.83651554584503, 0.6589369510766119, 0.5148724315222353, 0.0929980949149467, 0.03582742028811481, 0.07603611680679023, 0.09671312291175127, 0.02136256873200182, 0.05503217980731279, 0.10289068595739082, 0.0334805749298539, 0.07610951521201059, 0.06038372506736778, 0.08677328674821183, 0.07211992226075381, 0.1402652429533191, 0.03185962421412114, 0.21190070605371147, 0.09374619461596012, 1.5309955598786473, 43.730071261525154, 72.8272645175457, 39.662218540906906, 48.41980241239071, 38.92399415373802, 63.96468088030815, 26.23991947621107, 34.10241387784481, 63.76690149307251, 55.83487652242184, 75.02904877066612, 52.213967218995094, 73.5454335808754, 35.264501720666885, 0.10730024543590844, 0.8341096295043826, 2.9834726080298424, 0.07334798370720819, 3.7088218610733747, 53.56452114880085, 68.44678357243538, 64.846081584692, 60.16083799302578, 59.42981041967869, 58.70278403162956, 62.01598584651947, 60.62813691794872, 53.427287712693214, 56.86359152197838, 56.605741158127785, 62.37680308520794, 64.59361553192139, 46.971646919846535, 41.165174692869186, 53.946165069937706, 60.98032481968403, 62.041767463088036, 52.84134015440941, 57.75247402489185, 52.12005525827408, 58.56421306729317, 46.71803332865238, 52.960205376148224, 61.75809368491173, 55.49409180879593, 52.308810129761696, 54.569658413529396, 53.2845863699913, 49.50719006359577, 57.14283473789692, 54.576175063848495, 57.181581258773804, 54.04259629547596, 55.21927535533905, 53.95543657243252, 55.657798424363136, 54.395794942975044, 54.69095550477505, 55.227194130420685, 54.792809039354324, 53.693649619817734, 47.848742455244064, 47.86718666553497, 46.916979253292084, 45.7863537222147, 44.04841057956219, 42.36035495996475, 43.76668989658356, 44.936479926109314, 49.00269113481045, 53.17239359021187, 54.94933024048805, 59.059805274009705, 62.76030510663986, 57.72586025297642, 59.05526451766491, 58.4471869468689, 56.021651700139046, 49.29592899978161, 56.50460958480835, 55.45126050710678, 56.11171066761017, 54.82270583510399, 54.92490515112877, 59.244471564888954, 60.75763016939163, 52.499632090330124, 45.98073989152908, 46.502919271588326, 43.68743754923344, 44.91401553153992, 44.870682656764984, 47.38815017044544, 46.40317842364311, 46.90358117222786, 49.6776907145977, 48.57674539089203, 53.10168318450451, 53.05320918560028, 56.720897778868675, 55.844873785972595, 53.05576644837856, 53.15032437443733, 53.66991609334946, 52.89148226380348, 54.789089038968086, 54.35221508145332, 56.75038419663906, 49.15714904665947, 50.76178394258022, 55.01837633550167, 48.575540855526924, 52.0291755348444, 51.27159498631954, 54.430893659591675, 55.38501866161823, 59.434096589684486, 57.99832843244076, 62.924300506711006, 57.285908460617065, 53.5129389166832, 52.37231992185116, 59.2303591221571, 55.446719750761986, 47.469925582408905, 49.96989503502846, 58.25772151350975, 60.833565294742584, 61.372224390506744, 62.87858135998249, 63.32608714699745, 61.37413568794727, 66.47664248943329, 62.25267514586449, 68.31003651022911, 67.32374623417854, 67.34259322285652, 59.55020695924759, 68.6983984708786, 34.02574919164181, 0.07923981989733875, 0.07091261868481524, 2.079779924824834, 0.10889626370044425, 31.545770466327667, 71.13843753933907, 53.33602041006088, 72.4590490758419, 64.14458602666855, 80.41309386491776, 27.590308114886284, 22.16679833829403, 51.9423121958971, 37.33129821717739, 35.611624494194984, 51.38718478381634, 44.31093469262123, 1.3073073816485703, 0.5268918990623206, 0.03267803869675845, 0.044559566958923824, 0.10500974763999693, 0.0624912537750788, 0.03750313779164571, 0.03629028295108583, 0.21407411521067843, 0.17263785819523036, 0.2873783418908715, 0.167420560028404, 0.1435040051001124, 0.2522756770486012, 0.2691500965738669, 0.2698094502557069, 0.2758364612236619, 0.2702716301428154, 1.7773280292749405, 57.35815018415451, 83.04200559854507, 48.46887677907944, 49.94024142622948, 44.995718747377396, 67.65397131443024, 33.64747568964958, 40.43887406587601, 73.82389023900032, 60.84930785000324, 79.95154783129692, 57.06335440278053, 77.03564509749413, 40.28456434607506, 0.22430432407418266, 2.518412950448692, 2.8472033701837063, 0.26431818085256964, 5.674003260210156, 58.78618575632572, 68.1232537329197, 66.73274874687195, 60.276496186852455, 62.35101006925106, 60.814391523599625, 62.745455503463745, 62.83741056919098, 56.57946176826954, 60.250102803111076, 59.43329103291035, 66.19671151041985, 65.55221289396286, 53.22226971387863, 47.09777735173702, 58.47573101520538, 63.572283536195755, 62.64373116195202, 56.8703855574131, 58.978383243083954, 57.97286219894886, 54.80157516896725, 49.0047088265419, 52.559117898344994, 63.759385496377945, 57.81374953687191, 56.209935396909714, 58.64007219672203, 57.01745666563511, 52.31530398130417, 59.56001043319702, 58.038902655243874, 62.65244409441948, 59.36609923839569, 58.44114147126675, 59.40112955868244, 62.4136421084404, 57.7756679803133, 58.77737782895565, 60.6178242713213, 56.49657301604748, 59.40613389015198, 52.650882974267006, 51.57867170870304, 51.321512907743454, 51.67231388390064, 47.747265100479126, 46.74875847995281, 45.585477501153946, 50.746778547763824, 55.5311094224453, 56.835549026727676, 57.43647538125515, 61.78975358605385, 66.51297613978386, 58.05481240153313, 61.33913196623325, 60.898462012410164, 58.2357244938612, 49.238916859030724, 60.57913854718208, 60.06548210978508, 59.07720074057579, 55.09714990854263, 56.495919451117516, 63.93280819058418, 61.689077988266945, 55.370134860277176, 48.385668843984604, 47.9936058819294, 45.81853039562702, 49.11936767399311, 49.521925672888756, 50.49748532474041, 52.33716420829296, 50.39244756102562, 53.289320915937424, 52.95520484447479, 57.697988748550415, 55.002721175551414, 59.54810567200184, 58.8202091306448, 57.56785713136196, 56.021146327257156, 56.5324392914772, 56.08971744775772, 57.54875175654888, 56.730218678712845, 60.538640320301056, 49.14793074131012, 53.17430108785629, 56.900384947657585, 52.70785331726074, 54.87035147845745, 52.7271942794323, 55.37951275706291, 59.74490471184254, 61.57396696507931, 59.65419217944145, 65.1720204949379, 59.37037020921707, 51.6787963360548, 53.234432861208916, 62.20255583524704, 58.737240582704544, 49.84388239681721, 51.759405210614204, 59.924741461873055, 62.608526051044464, 62.89169065654278, 65.4654711484909, 65.5350910127163, 65.08812099695206, 68.60108569264412, 63.54131139814854, 69.65122014284134, 70.39511382579803, 69.65679064393044, 60.75496271252632, 69.97851938009262, 39.7866390645504, 0.3507935249945149, 0.1290598965715617, 4.123076582327485, 0.2551313425647095, 32.09114000201225, 76.80128887295723, 59.932458847761154, 76.47717386484146, 66.74990102648735, 78.07206228375435, 33.895351588726044, 33.25529493391514, 66.46000698208809, 39.574253261089325, 53.26250575482845, 64.20673549175262, 61.561059057712555, 5.195586606860161, 0.8439286588691175, 0.21976807998726144, 0.1890159590402618, 0.2916191815165803, 0.18333446234464645, 0.15234776336001232, 0.19342511775903404], [0.12745377025566995, 0.06495119872852229, 0.008382660053030122, 0.04421219360665418, 0.0875257354346104, 0.034607073466759175, 0.1610043371329084, 0.06237333393073641, 0.030007019522599876, 0.16815481125377119, 0.5720347235910594, 23.91274005174637, 59.91413243114948, 46.18696242570877, 39.69066001474857, 33.3313212543726, 58.50662715733051, 30.07229693233967, 28.46033412963152, 66.93920686841011, 61.54928348958492, 61.141637563705444, 56.45005591213703, 46.588061302900314, 55.86499370634556, 1.4475503750145435, 0.22437522886320949, 2.318515651859343, 0.3768893372034654, 0.775123197818175, 35.30028820037842, 69.3549956381321, 55.91550439596176, 58.4066317230463, 57.29614891111851, 59.177431762218475, 62.44076885282993, 63.27453151345253, 60.942266061902046, 61.40870243310928, 60.839929953217506, 59.72999431192875, 57.557783871889114, 69.3360498547554, 82.37229913473129, 48.51807273924351, 44.354962930083275, 51.435521990060806, 56.00550256669521, 50.76885536313057, 63.17787230014801, 56.38212315738201, 35.43619930744171, 59.39280800521374, 55.93339003622532, 56.329294592142105, 50.131903141736984, 51.00127749145031, 49.15318965911865, 46.20672136545181, 52.2466416656971, 54.61460240185261, 51.67348422110081, 52.12824761867523, 52.626872062683105, 53.51047284901142, 51.47612281143665, 52.090622037649155, 54.270101487636566, 54.10363242030144, 54.10590849816799, 50.38758382201195, 49.49033796787262, 44.797126203775406, 43.806306570768356, 39.8716177046299, 41.043353229761124, 41.54168888926506, 43.03950011730194, 44.44695219397545, 48.8077387958765, 51.19056053459644, 57.13593430817127, 57.38165192306042, 59.12839539349079, 56.9561355561018, 51.97049528360367, 59.46159951388836, 56.60151198506355, 49.27890211343765, 53.70612435042858, 55.549519434571266, 51.418027728796005, 49.71126191318035, 56.6140741109848, 59.61443871259689, 55.0766272097826, 46.65317840874195, 44.8429973423481, 39.59782339632511, 38.80503013730049, 40.48492379486561, 39.338487312197685, 41.09788030385971, 40.6367826461792, 42.77805894613266, 42.91087321937084, 43.75262685120106, 46.73268914222717, 52.815379947423935, 52.5700993090868, 50.15600144863129, 53.13299350440502, 51.76233485341072, 50.985538735985756, 50.873254761099815, 52.1733283996582, 49.41458523273468, 51.24220736324787, 43.79405602812767, 51.90768465399742, 51.461881175637245, 49.395886436104774, 48.60036872327328, 50.719021037220955, 51.75547622144222, 54.006551429629326, 55.491207763552666, 59.43431697785854, 56.6022377461195, 61.64159573614597, 49.72762003540993, 48.66289056837559, 59.35362830758095, 57.04999051988125, 45.84223732352257, 43.98162916302681, 57.454239428043365, 60.03590069711208, 61.562123000621796, 58.76820512115955, 60.3401617705822, 61.22205264866352, 59.74186107516289, 59.66508999466896, 62.98390030860901, 61.107124015688896, 64.34572443366051, 61.48058317601681, 60.0576127320528, 15.088206622749567, 0.2447778036003001, 0.6680840696208179, 1.3724305434152484, 1.9636887917295098, 47.39448443055153, 59.48481246829033, 60.543226674199104, 65.34941017627716, 51.057354882359505, 47.12318658828735, 30.554736144840717, 32.89818249642849, 45.939116925001144, 27.736909948289394, 36.04731671512127, 40.239627957344055, 19.522505030035973, 0.33304426178801805, 0.05900098891288508, 0.058753063349286094, 0.04688454864663072, 0.04570145763864275, 0.019212906445318367, 0.1740297710057348, 0.04969934409018606, 0.17353017203276977, 0.045464786744560115, 0.12742769118631259, 0.0890267216891516, 0.07445137918693945, 0.03051809766475344, 0.21099487028550357, 0.050389559983159415, 0.0832120020641014, 0.12946577713591978, 0.6274878792464733, 28.3449799194932, 75.0968599319458, 46.14546485245228, 42.58358538150787, 44.552681520581245, 60.79630829393864, 29.056603834033012, 29.513305127620697, 72.5432525575161, 61.74286410212517, 70.12559428811073, 62.8892207890749, 53.971547707915306, 61.94806069135666, 2.5202546641230583, 0.15562997083179653, 2.700599399395287, 0.5934215197339654, 1.56317840795964, 41.25046871602535, 71.2102384865284, 59.39334377646446, 61.425254344940186, 59.724982380867004, 63.726448863744736, 64.54927191138268, 67.04725787043571, 63.949557691812515, 65.51603123545647, 60.449561700224876, 63.278129920363426, 60.05390413105488, 72.6853497326374, 78.64144653081894, 52.08422318100929, 46.92181259393692, 54.44014236330986, 55.92871628701687, 53.57762664556503, 59.42512907087803, 58.82823809981346, 42.66248434782028, 61.492818519473076, 60.14676354825497, 56.55789412558079, 53.62923547625542, 54.92014780640602, 52.47233435511589, 49.16437245905399, 55.58461055159569, 56.605501770973206, 56.57914258539677, 54.72009614109993, 55.33578850328922, 55.07614843547344, 56.29701152443886, 54.69826631247997, 55.79604260623455, 56.421204060316086, 57.516829669475555, 53.16772364079952, 51.83798499405384, 50.52799008786678, 45.33493034541607, 42.963758781552315, 43.858219385147095, 43.08030992746353, 45.54364934563637, 45.404968187212944, 52.540700286626816, 54.44720238447189, 58.84971834719181, 57.45146557688713, 61.84003248810768, 57.08240658044815, 53.7916349619627, 59.49311502277851, 55.12641593813896, 48.29855091869831, 58.95848371088505, 57.4923399835825, 53.85707505047321, 49.26775351166725, 56.89325653016567, 61.280531510710716, 60.239288583397865, 49.70877304673195, 47.18037731945515, 45.14933690428734, 43.78995604813099, 42.66599915921688, 43.515185192227364, 46.88468478620052, 46.64482645690441, 46.032603308558464, 47.07259230315685, 47.57707603275776, 52.02853336930275, 55.48134729266167, 56.362994983792305, 52.94858559966087, 55.25262236595154, 54.90002788603306, 53.69681864976883, 54.336814507842064, 54.322436079382896, 52.77863211929798, 54.07739482820034, 47.47792795300484, 52.75967873632908, 52.1750421077013, 50.10897517204285, 51.692126020789146, 52.485322058200836, 52.24010221660137, 53.85764122009277, 56.911582946777344, 60.53761437535286, 57.342787608504295, 63.42059947550297, 49.50230352580547, 50.42773626744747, 62.788340002298355, 59.09871518611908, 46.467117592692375, 46.11611522734165, 59.893784523010254, 61.009298264980316, 63.4442076086998, 62.55962647497654, 61.918395683169365, 63.09953950345516, 63.758982717990875, 61.752861365675926, 64.30597096681595, 62.90263406932354, 67.55252435803413, 62.25457884371281, 61.64776660501957, 16.730973422527313, 0.33500605495646596, 1.009483637753874, 1.9156883424147964, 3.6550404969602823, 56.976574659347534, 62.957605719566345, 64.57496613264084, 71.38561427593231, 55.43424502015114, 49.08378638327122, 28.381676450371742, 33.00792820751667, 53.76195855438709, 36.554080322384834, 35.31443104147911, 49.841085746884346, 27.553341798484325, 0.9563126158900559, 0.060364982127794065, 0.04433009118656628, 0.047636032541049644, 0.02019548584939912, 0.03219190228264779, 0.11665618949336931, 0.01779447113221977, 0.18889031343860552, 0.18754756049020216, 0.19947445252910256, 0.14505509374430403, 0.17421434313291684, 0.24946780584286898, 0.38695437368005514, 0.2579713042359799, 0.26082005293574184, 0.4568834463134408, 0.8691768196877092, 37.11847543716431, 83.21100533008575, 62.12674230337143, 49.19776126742363, 50.396612137556076, 72.45572805404663, 37.51813419163227, 37.11816385388374, 79.22766387462616, 67.23302230238914, 73.76446902751923, 66.27135470509529, 59.122851490974426, 67.94435933232307, 3.52290116250515, 0.573460478335619, 5.493095917627215, 0.6368480832315981, 2.14892053976655, 48.17309305071831, 68.19218203425407, 59.99066412448883, 63.56796696782112, 63.421351835131645, 66.36653959751129, 66.85647010803223, 68.82639080286026, 64.17698308825493, 66.86573401093483, 63.17836247384548, 65.17854854464531, 60.758336931467056, 78.34097385406494, 74.43539142608643, 52.04922325909138, 50.89414224028587, 58.411351069808006, 58.38537186384201, 55.81313408911228, 55.05293928086758, 54.70562271773815, 46.68241024017334, 62.259336188435555, 61.68224975466728, 58.88156823813915, 55.012403056025505, 57.49424748122692, 56.536060497164726, 52.924688681960106, 57.43637278676033, 61.407657489180565, 61.59902282059193, 60.17331272363663, 58.50212059915066, 57.81269319355488, 59.071219861507416, 58.308695778250694, 59.244034588336945, 59.91205394268036, 59.78711664676666, 58.13191406428814, 54.58000905811787, 54.999951124191284, 49.484433084726334, 46.9107361882925, 47.46517963707447, 46.402597054839134, 50.77303133904934, 51.08613073825836, 56.07373930513859, 56.963309571146965, 61.580430418252945, 62.409694120287895, 64.33018326759338, 61.63601003587246, 56.28672927618027, 63.16132798790932, 57.36764207482338, 50.43537385761738, 59.02729041874409, 58.94061706960201, 54.66634422540665, 50.25920391082764, 57.526750937104225, 64.11595836281776, 61.231479942798615, 51.650294065475464, 51.825590059161186, 46.572060361504555, 47.01264292001724, 48.34919460117817, 47.590037137269974, 51.24525859951973, 49.64029312133789, 49.56538774073124, 49.39957223832607, 50.260822623968124, 52.1481129527092, 58.92675161361694, 58.35585504770279, 56.61114066839218, 59.90297242999077, 59.19865742325783, 58.2338397949934, 56.9621392339468, 58.52977931499481, 54.63850311934948, 55.54657839238644, 49.15775701403618, 56.03784263134003, 56.51460684835911, 53.14588241279125, 55.252105593681335, 55.27739703655243, 54.916746988892555, 57.61390686035156, 59.84857454895973, 62.8761874884367, 59.50756564736366, 64.40894544124603, 49.434689953923225, 50.79551473259926, 63.373785987496376, 61.57922588288784, 48.016404658555984, 48.27338486909866, 63.425322622060776, 63.36314655840397, 65.85156083106995, 64.52675431966782, 63.43707159161568, 65.30844837427139, 64.58836421370506, 63.14796410501003, 67.20374867320061, 65.42051196098328, 68.00521686673164, 62.989729195833206, 65.04133030772209, 20.90327873826027, 0.3733435337198898, 1.9720072578638792, 3.8287346391007304, 4.712838660925627, 56.07817366719246, 72.31837302446365, 68.73749077320099, 77.08091586828232, 62.991347908973694, 61.21161840856075, 43.16487818956375, 40.66399298608303, 61.528388410806656, 40.903475135564804, 52.5073266774416, 60.073735266923904, 47.38120794296265, 1.439481507986784, 0.27226147649344057, 0.19080101716099307, 0.2884796593571082, 0.13338434655452147, 0.0873458907881286, 0.20448629453312606, 0.1803451805608347], [0.015774335879541468, 0.08591761274146847, 0.09775605562026612, 0.036180957176839, 0.08404382344451733, 0.02556739935243968, 0.1922102813841775, 0.03558799231541343, 0.10208202700596303, 0.34660276549402624, 0.3777901263674721, 15.628160499036312, 62.531530782580376, 43.53604607284069, 48.68127018213272, 26.757031828165054, 60.90105727314949, 24.33309629559517, 34.82818253338337, 62.82631516456604, 58.74173194169998, 54.84340712428093, 57.54240609705448, 51.61543853580952, 64.28326338529587, 8.36666464805603, 0.14150085946312174, 3.6450805189087987, 0.4254878091160208, 0.6348059303127229, 23.07719148695469, 67.80783265829086, 54.7289914637804, 58.57294499874115, 55.36001220345497, 59.52325500547886, 58.39858375489712, 59.95221398770809, 55.43621711432934, 61.239926889538765, 56.81727580726147, 61.00321479141712, 55.172792449593544, 71.56912922859192, 65.90842097997665, 56.65844053030014, 51.15352012217045, 41.990175023674965, 44.688349440693855, 51.790088564157486, 51.65304131805897, 33.02614443004131, 47.72747956216335, 59.81995068490505, 58.72311674058437, 54.15499046444893, 50.04351608455181, 50.808099657297134, 53.46435472369194, 45.621647760272026, 48.05038623511791, 53.654101341962814, 52.060919031500816, 54.55799303948879, 52.350364699959755, 52.61526368558407, 51.60889528691769, 53.610308691859245, 51.24867841601372, 54.62526462972164, 51.44920885562897, 53.6581215262413, 47.02455908060074, 47.23236992955208, 45.4444594681263, 42.04730875790119, 44.78562422096729, 42.92546443641186, 47.050599083304405, 50.582923740148544, 55.02823680639267, 53.025873452425, 52.87950150668621, 55.187911838293076, 57.13477537035942, 57.34403394162655, 56.39306657016277, 59.40861515700817, 53.306344002485275, 48.51930767297745, 57.004951536655426, 56.61118246614933, 52.246356680989265, 49.593263044953346, 53.930513709783554, 59.54082526266575, 54.58922736346722, 50.9573670476675, 45.72791665792465, 41.9532486051321, 41.08785644173622, 42.52074055373669, 42.53785103559494, 42.574952244758606, 43.362805768847466, 43.00914354622364, 44.72815990447998, 50.04649132490158, 51.214195266366005, 52.83693239092827, 52.97764644026756, 52.44725950062275, 54.012836292386055, 53.11821989715099, 51.68370187282562, 52.13272377848625, 48.99526633322239, 51.40117943286896, 49.69408683478832, 45.55408738553524, 52.39470452070236, 48.94683413207531, 49.503318071365356, 50.71395970880985, 52.33592927455902, 53.13629932701588, 54.12043511867523, 53.950238451361656, 53.743540942668915, 59.30149510502815, 58.508447259664536, 48.42037618160248, 52.374770790338516, 58.84573616087437, 54.287018179893494, 52.904587760567665, 44.98719960451126, 49.54495623707771, 56.957495883107185, 58.288245275616646, 59.723378866910934, 57.76826597750187, 57.44596727192402, 58.89948807656765, 62.349049374461174, 62.98198901116848, 63.54609154164791, 62.337877973914146, 61.20550453662872, 50.45164078474045, 5.657886900007725, 0.34027185989543796, 1.1864111688919365, 0.7730334287043661, 10.844045262783766, 46.03044122457504, 60.89773625135422, 60.0984301418066, 59.510860070586205, 64.26546514034271, 68.6414547264576, 30.530706234276295, 36.039800718426704, 33.015505000948906, 27.05065157264471, 35.540089532732964, 42.21134215593338, 11.839514896273613, 0.8131175965536386, 0.057348374466528185, 0.17812890495406464, 0.041198814287781715, 0.03769133531022817, 0.08358738778042607, 0.11759258690290153, 0.05792647410999052, 0.008372739393962547, 0.046412557567236945, 0.11298381272354163, 0.03170597738062497, 0.07559550373116508, 0.03634821128798649, 0.14728670212207362, 0.060195842961547896, 0.044880497589474544, 0.35058673296589404, 0.271998459356837, 18.939171731472015, 74.81607779860497, 50.98444439470768, 46.240364760160446, 41.10851973295212, 71.5811213850975, 27.008943110704422, 39.90339159965515, 71.197889149189, 64.22911629080772, 58.58853556215763, 66.42805069684982, 54.425114169716835, 73.65946546196938, 8.779558092355728, 0.0784124291385524, 1.995874964632094, 1.4232357172295451, 0.659627029672265, 29.63822342455387, 72.118009775877, 57.84242659807205, 62.548629865050316, 59.691737964749336, 65.09082645177841, 61.24772027134895, 60.823944211006165, 59.561515152454376, 62.451643869280815, 59.8829361051321, 63.55439029633999, 59.29798789322376, 70.16359984874725, 61.89582109451294, 65.05881696939468, 55.42881891131401, 44.437825083732605, 46.73081964254379, 50.56246183812618, 53.78876991569996, 39.6047618240118, 49.504758194088936, 62.00497783720493, 59.656836837530136, 58.19001294672489, 50.21795332431793, 53.54466341435909, 55.96058137714863, 47.15825490653515, 49.04570482671261, 57.366730123758316, 54.23343725502491, 57.15247482061386, 54.47976663708687, 55.28443045914173, 55.322318226099014, 57.35395900905132, 54.403804913163185, 57.0094770938158, 54.09669019281864, 53.445929512381554, 51.57509610056877, 48.96145574748516, 46.58322796225548, 43.776728957891464, 44.633913561701775, 44.54448536038399, 46.46514929831028, 51.81591957807541, 57.664725333452225, 55.765089467167854, 58.453008234500885, 55.565015003085136, 60.151076316833496, 59.61617901921272, 59.672347605228424, 61.273327097296715, 55.78764125704765, 49.970518201589584, 58.34118403494358, 58.16665939986706, 53.696085289120674, 50.26477441191673, 58.95606704056263, 61.225461065769196, 58.208168372511864, 52.27664865553379, 48.8717045634985, 45.6602992862463, 44.72938723862171, 43.47498334944248, 44.99089300632477, 44.07428339123726, 47.82334081828594, 44.68977816402912, 49.91278789937496, 51.78900182247162, 53.008595779538155, 56.253815442323685, 55.07892228662968, 54.75177884101868, 55.684887170791626, 53.74021992087364, 55.350060537457466, 55.01847892999649, 51.90790884196758, 55.24317607283592, 53.93786631524563, 47.89925694465637, 53.7138569355011, 50.75097352266312, 51.542839631438255, 53.625982850790024, 53.09693343937397, 53.32269452512264, 55.98804630339146, 55.58898411691189, 56.775607243180275, 59.55103911459446, 61.040091812610626, 48.558399975299835, 54.344163313508034, 62.79711753129959, 56.46438494324684, 53.78152370452881, 45.60437768697739, 51.22590623795986, 61.2329238653183, 60.61497062444687, 61.5121328830719, 59.50490199029446, 61.51423417031765, 61.536174193024635, 64.46022748947144, 65.803242623806, 68.05478900671005, 63.33370953798294, 63.99614319205284, 55.1857041567564, 6.301079811528325, 0.35604475415311754, 3.390612923540175, 0.4591218527639285, 16.212082765996456, 56.503773629665375, 65.11591270565987, 67.22299084067345, 63.34956608712673, 69.61209744215012, 64.39224153757095, 36.13056644797325, 41.09596520662308, 41.42718203365803, 28.463280871510506, 36.954438239336014, 54.48059119284153, 19.389246180653572, 0.9317760856356472, 0.09359701551147737, 0.03882472839904949, 0.06369880968122743, 0.09294751012930647, 0.05561848018260207, 0.0693312355724629, 0.037057099616504274, 0.08615008307970129, 0.26591130474116653, 0.1743611993151717, 0.13265566143672913, 0.13621856400277466, 0.16730101488064975, 0.325410976074636, 0.21433646441437304, 0.16631456703180447, 0.6339420704171062, 0.5034752399660647, 24.900282360613346, 88.65970775485039, 66.02803096175194, 61.475331857800484, 45.3950659185648, 79.3294908106327, 33.51647771894932, 43.33923943340778, 76.15434318780899, 70.47487914562225, 64.55226615071297, 69.88938376307487, 60.02841129899025, 79.62187752127647, 10.379230454564095, 0.2108822567970492, 7.2156731598079205, 1.6053933114744723, 1.2339318939484656, 36.44540995359421, 73.41824680566788, 57.560382932424545, 63.11440050601959, 62.0647182315588, 66.92678913474083, 64.84166622161865, 63.37744899094105, 62.741123735904694, 67.11343511939049, 62.488353699445724, 66.09933033585548, 62.73241460323334, 68.82938504219055, 64.55210655927658, 63.679737970232964, 51.58624090254307, 45.9482516348362, 47.832809910178185, 53.58556441962719, 56.47310167551041, 46.24369718134403, 52.32626259326935, 64.97176364064217, 62.07780472934246, 59.51194681227207, 53.05788293480873, 57.72837191820145, 59.228660613298416, 51.576806008815765, 51.784993037581444, 61.085814759135246, 59.51945520937443, 60.698155760765076, 56.37581169605255, 58.83460655808449, 59.123330265283585, 63.16219054162502, 56.88719965517521, 59.76306013762951, 57.8776279091835, 58.01826596260071, 54.668726697564125, 54.053114131093025, 48.460779413580894, 47.4088666588068, 49.098294004797935, 48.137606754899025, 53.40904489159584, 56.407612189650536, 61.86563931405544, 57.93029688298702, 59.079579412937164, 59.290023520588875, 62.521180137991905, 62.60215379297733, 60.63767060637474, 65.00142484903336, 57.08523742854595, 49.579439386725426, 60.01360349357128, 59.915420562028885, 57.37953543663025, 51.16043195128441, 59.24127213656902, 66.33633881807327, 63.181539103388786, 56.963814944028854, 53.815144300460815, 49.95169401168823, 48.40158239006996, 48.35945405066013, 48.97684872150421, 50.142793357372284, 51.33882097899914, 50.10758824646473, 51.567082330584526, 54.36928756535053, 58.524319007992744, 61.58605791628361, 58.95206205546856, 58.84201996028423, 59.66494180262089, 59.35065306723118, 57.02304616570473, 57.8945218026638, 55.43313927948475, 57.01850540935993, 54.821869879961014, 49.57609936594963, 56.18774078786373, 53.40524509549141, 52.66441784799099, 55.61973586678505, 53.38044002652168, 57.19782538712025, 58.16551186144352, 58.37872602045536, 58.62559497356415, 61.757447719573975, 60.54394103586674, 54.55790564417839, 59.14157688617706, 63.226730078458786, 59.96760696172714, 55.303676426410675, 49.894689470529556, 55.18082521855831, 62.41931140422821, 60.626628398895264, 64.80124399065971, 63.0995737016201, 61.84563718736172, 63.320113867521286, 66.60728707909584, 67.50303581357002, 68.33372443914413, 66.53893634676933, 62.816260904073715, 57.92976871132851, 9.303108248859644, 0.5261445860378444, 4.86263089813292, 1.157474177889526, 15.9192780777812, 60.51836080849171, 71.36841639876366, 69.1105243563652, 70.01261875033379, 77.25807756185532, 78.78557279706001, 39.44197855889797, 44.06193785369396, 47.87892423570156, 36.839695796370506, 51.86123214662075, 63.55293497443199, 30.472179874777794, 1.5265961084514856, 0.20008286519441754, 0.23557790351333097, 0.17602460458874702, 0.22750234231352806, 0.19009992509381846, 0.20997639134293422, 0.2332563468371518], [0.11987063888227567, 0.08675030243466608, 0.12016656284686178, 0.011632793757598847, 0.10737080141552724, 0.08710970971151255, 0.14662705158116296, 0.05754970799898729, 0.0483542014262639, 0.3730014630127698, 0.14295940229203552, 7.578826323151588, 64.35698702931404, 51.219571977853775, 37.54283666610718, 17.111420407891273, 50.59311479330063, 28.101276196539402, 24.994228519499302, 64.2115992307663, 61.51395298540592, 51.65504761040211, 54.636390432715416, 54.51106175780296, 61.41101270914078, 25.95426980406046, 0.5634200514759868, 0.5868285766337067, 0.48651648277882487, 0.1149137232278008, 18.15877340734005, 58.10360938310623, 54.86645668745041, 57.765921503305435, 60.096382051706314, 59.83667738735676, 57.213465347886086, 57.82526671886444, 54.731624722480774, 56.93436652421951, 53.541175201535225, 55.83537429571152, 56.5710262209177, 55.03623157739639, 57.198748737573624, 59.57071825861931, 63.14109027385712, 65.55697023868561, 54.43826526403427, 49.95393589138985, 39.730151295661926, 42.16878443956375, 58.562126979231834, 57.44527570903301, 56.967588141560555, 55.06469205021858, 52.33791656792164, 49.38691511750221, 52.14272104203701, 45.59162937104702, 44.99329447746277, 55.172560662031174, 52.24221110343933, 51.36693187057972, 54.88323658704758, 52.721190601587296, 53.823830634355545, 49.774197936058044, 50.88085055351257, 52.48246841132641, 53.76011185348034, 52.242359295487404, 49.737856686115265, 45.84085799753666, 43.599738255143166, 43.870849907398224, 44.78739492595196, 45.55395059287548, 50.594277530908585, 52.01696678996086, 55.592179745435715, 54.06840831041336, 54.96627353131771, 53.48304972052574, 58.670276775956154, 55.080309212207794, 55.02704367041588, 57.162365689873695, 53.63466918468475, 46.0833989828825, 57.6687341183424, 57.65017591416836, 55.841871947050095, 55.1084391027689, 60.13379484415054, 59.38704751431942, 55.54621361196041, 51.397816613316536, 47.56237842142582, 47.15371035039425, 43.31312723457813, 42.325362637639046, 40.732890889048576, 40.653045773506165, 42.85478822886944, 45.23037515580654, 49.91107799112797, 49.37655687332153, 51.58016882836819, 53.0413918197155, 54.512486681342125, 51.736074462533, 51.613173857331276, 50.07182076573372, 52.39463612437248, 50.6004635989666, 50.14638416469097, 51.36484958231449, 46.58336095511913, 47.85722739994526, 50.21661579608917, 46.33049592375755, 52.29832649230957, 54.146592915058136, 57.32277408242226, 54.2155060172081, 58.69966819882393, 55.678575709462166, 58.28842006623745, 58.59206557273865, 63.0855942517519, 28.682779893279076, 37.75799632072449, 62.7525345236063, 58.765495866537094, 55.61915449798107, 48.62073563039303, 44.92965169250965, 51.26698583364487, 57.17045545578003, 58.92498470842838, 60.31138211488724, 60.928742587566376, 56.74172446131706, 58.09024170041084, 59.834693893790245, 60.95067881047726, 58.86237546801567, 61.21841624379158, 43.56502711772919, 1.122905295342207, 2.2069828491657972, 2.9901253385469317, 0.790923343738541, 31.03182904422283, 60.192528292536736, 60.9902460873127, 52.77363158762455, 65.11998608708382, 60.46259120106697, 65.37030145525932, 23.79363354295492, 25.830345153808594, 33.62732917070389, 50.61377428472042, 42.23957844078541, 43.99586699903011, 12.61433131992817, 0.8727693487890065, 0.0224321426867391, 0.07464528011041693, 0.04266627031029202, 0.08438531527644955, 0.007618887120770523, 0.05272391499602236, 0.08743444384890608, 0.04635846613382455, 0.0487699265795527, 0.0815882052120287, 0.06283627080847509, 0.04408699329360388, 0.05958355999609921, 0.22942368843359873, 0.028784746828023344, 0.1258565645548515, 0.3133704315405339, 0.07350667714490555, 9.998335093259811, 76.92019209265709, 56.679677590727806, 44.196123853325844, 25.91184888035059, 59.09216433763504, 33.34347300231457, 30.905255936086178, 72.3408754169941, 68.14818039536476, 53.75863753259182, 62.1667655557394, 59.73255917429924, 69.69028204679489, 29.407701194286346, 0.3452626249054447, 2.99211666919291, 1.107112392783165, 0.19037714693695307, 21.150875352323055, 64.12229642271996, 55.65500557422638, 62.623858228325844, 63.078617826104164, 64.1329738497734, 59.08315122127533, 61.05244114995003, 57.46474966406822, 59.236909970641136, 54.0419465303421, 58.22542704641819, 61.54584087431431, 58.07200267910957, 58.36296446621418, 61.94567061960697, 65.41927322745323, 67.52305313944817, 55.6402737647295, 52.57218919694424, 45.286957919597626, 44.11547318100929, 60.133521258831024, 59.52228605747223, 58.06926302611828, 57.06959746778011, 53.28015960752964, 51.54986545443535, 54.470141753554344, 47.52772808074951, 48.40741507709026, 56.037481650710106, 55.031877011060715, 57.61190056800842, 56.578454822301865, 54.47161607444286, 55.29158167541027, 53.99131044745445, 56.400373578071594, 55.923103988170624, 54.663992151618004, 54.15105767548084, 51.78281955420971, 48.872783705592155, 45.092153772711754, 45.14610327780247, 46.55347555875778, 47.32908993959427, 52.622137516736984, 53.41137796640396, 58.19996081292629, 53.53441156446934, 56.687771156430244, 55.62531016767025, 61.38042435050011, 59.331878274679184, 56.712245643138885, 59.266502782702446, 55.54776772856712, 46.99216961860657, 59.89687755703926, 58.59992355108261, 56.99579402804375, 55.402170941233635, 60.256551057100296, 58.95254842936993, 57.697259187698364, 53.92929017543793, 50.22606208920479, 48.449444621801376, 46.25868737697601, 44.032888412475586, 42.787170857191086, 44.45356763899326, 45.94529539346695, 48.32228064537048, 53.61510023474693, 51.897311210632324, 55.025968328118324, 55.31280733644962, 55.78131079673767, 51.99672907590866, 54.14069563150406, 54.63382937014103, 54.82823073863983, 52.861669063568115, 52.90591008961201, 53.33027511835098, 48.67527790367603, 49.2726818472147, 53.669699504971504, 48.835386112332344, 52.845333740115166, 54.66248743236065, 59.282169342041016, 55.876841470599174, 58.54527488350868, 57.68295295536518, 60.14645956456661, 59.49231706559658, 64.92460057139397, 28.301610946655273, 38.793782740831375, 64.88019615411758, 62.20249883830547, 60.397071316838264, 50.703164488077164, 47.07763083279133, 53.16709287464619, 60.356649085879326, 60.17720751464367, 63.989569544792175, 61.402873545885086, 59.96691919863224, 60.46148546040058, 63.90611082315445, 62.31263592839241, 63.844348937273026, 62.395767867565155, 51.742959693074226, 1.07449138071388, 4.7210058476775885, 3.744717347435653, 1.216486911289394, 36.01957060396671, 60.6900317966938, 68.54859530925751, 57.23092921078205, 70.42995035648346, 65.27608171105385, 70.9754490852356, 28.962494283914566, 28.859301321208477, 40.73224872350693, 57.08676494657993, 49.46003079414368, 54.06979523599148, 18.16026482731104, 1.1863472848199308, 0.042766630940604955, 0.09879764504148625, 0.07662083269678988, 0.1474964924273081, 0.018031177278317045, 0.027201495358895045, 0.01834079943364486, 0.26977795350831, 0.17380369798047468, 0.2531892014667392, 0.23194316105218604, 0.21543099865084514, 0.1807790104066953, 0.26659045892301947, 0.2437568161985837, 0.2371038036653772, 0.5268986674491316, 0.24074280605418608, 13.00364512950182, 88.15192580223083, 71.69951543211937, 47.170573845505714, 26.74916435033083, 71.84813305735588, 35.14070816338062, 33.864713832736015, 75.87297588586807, 74.7596888244152, 60.549864917993546, 69.72929075360298, 63.45069766044617, 75.8837217092514, 31.129685193300247, 0.44315356586594135, 4.459957480430603, 1.5652712644077837, 0.20509274792857468, 27.81852386891842, 70.20103543996811, 61.020367071032524, 63.44572372734547, 63.79246652126312, 67.05074608325958, 62.61170268058777, 63.27962324023247, 58.59129801392555, 61.5947974473238, 57.10656188428402, 61.813357919454575, 62.093038111925125, 61.107826977968216, 62.524592354893684, 63.81702080368996, 67.19603508710861, 68.15680593252182, 56.89398229122162, 55.074864104390144, 50.576099306344986, 48.01111914217472, 61.76497891545296, 60.9576590359211, 61.961485370993614, 61.248810812830925, 55.760879293084145, 53.782891631126404, 55.666860938072205, 49.48787949979305, 51.425984501838684, 62.14813515543938, 59.61304798722267, 59.524657130241394, 61.35102152824402, 58.77456218004227, 58.94508183002472, 58.26916269958019, 56.93329498171806, 60.65705716609955, 60.16733184456825, 60.49586981534958, 54.84892822802067, 53.46781253814697, 47.33901120722294, 48.421006947755814, 51.20582051575184, 50.83383567631245, 57.28591226041317, 57.381169348955154, 59.10103306174278, 59.1383508592844, 62.67727196216583, 57.943763360381126, 65.41561782360077, 62.12281331419945, 58.63581642508507, 60.16470618546009, 56.920121088624, 48.582779467105865, 62.78832100331783, 60.220088213682175, 61.23663246631622, 58.54544207453728, 63.498031720519066, 63.460026159882545, 63.27768534421921, 57.45307669043541, 54.94400292634964, 54.133103638887405, 49.78704124689102, 48.43350067734718, 44.56607200205326, 47.84331254661083, 51.05384387075901, 51.25786252319813, 55.80367259681225, 58.05439442396164, 58.10837432742119, 59.01336416602135, 60.41234649717808, 56.58601261675358, 56.61546103656292, 56.709209606051445, 57.5050313025713, 57.47312821447849, 54.81593079864979, 54.300876036286354, 49.806321412324905, 50.964571461081505, 55.584591552615166, 49.94775362312794, 55.16380213201046, 55.67507989704609, 60.86012206971645, 56.46094612777233, 60.769398137927055, 58.1422533094883, 60.02475209534168, 59.92082767188549, 65.1951764523983, 32.94700227677822, 45.01849092543125, 63.219157084822655, 62.632107585668564, 61.96873918175697, 52.94312909245491, 49.22340989112854, 54.30633634328842, 61.5443779528141, 62.827812284231186, 65.28344571590424, 65.09445905685425, 61.522152945399284, 63.3057202398777, 64.79071095585823, 64.66371417045593, 63.94343242049217, 64.06747296452522, 54.37312535941601, 1.896484885364771, 3.4837012784555554, 5.797730321064591, 1.2442223355174065, 43.21516089141369, 71.89733281731606, 69.03765186667442, 62.52890892326832, 74.37257319688797, 69.42783772945404, 79.21291306614876, 31.28753822296858, 35.0505618005991, 51.309551149606705, 63.61927941441536, 57.879182025790215, 68.26560169458389, 29.278755113482475, 1.5244914963841438, 0.1304791501024738, 0.2392370329471305, 0.14960910484660417, 0.2249959166510962, 0.15313066978706047, 0.13081930606858805, 0.15210107347229496], [0.03901989839505404, 0.04563805225188844, 0.052314754138933495, 0.022640663919446524, 0.05507862340891734, 0.0523679587058723, 0.004875406966675655, 0.07520822138758376, 0.03734217709279619, 0.15225003735395148, 0.08294972707517445, 2.2190887620672584, 47.85706400871277, 53.80732052028179, 39.112547636032104, 30.26971533894539, 41.893891990184784, 27.825260907411575, 14.82607863843441, 53.44903014600277, 66.84403717517853, 57.705679535865784, 52.81487077474594, 53.61040748655796, 57.8363773226738, 46.45816907286644, 0.41717409272678196, 1.2411502003669739, 1.9583021057769656, 0.0641026790253818, 10.113414768129587, 47.71185480058193, 58.88079687952995, 52.08689823746681, 56.426056399941444, 60.72065815329552, 58.2310089468956, 55.235777869820595, 54.42265950143337, 52.8930439800024, 53.970251977443695, 54.314555302262306, 56.853624656796455, 56.69690206646919, 56.67860984802246, 55.86586765944958, 57.440054789185524, 58.48016917705536, 57.45636731386185, 54.19739618897438, 66.31336525082588, 52.36478492617607, 57.94443592429161, 57.63970747590065, 58.74373823404312, 56.1025607585907, 52.57066547870636, 47.15819410979748, 54.91554245352745, 49.95203599333763, 45.23967705667019, 47.63840094208717, 53.93799550831318, 53.4572035074234, 56.34885974228382, 54.13853734731674, 53.81322920322418, 52.996060252189636, 54.86384242773056, 54.028141871094704, 56.02814555168152, 49.956428557634354, 48.534347265958786, 43.96555222570896, 46.22679948806763, 47.06064194440842, 46.204631477594376, 50.842898190021515, 51.77854858338833, 54.959563091397285, 52.983444929122925, 54.5352778583765, 53.31197150051594, 57.418213561177254, 59.952001199126244, 56.39209382236004, 54.74488981068134, 56.673844903707504, 55.50394847989082, 44.79771137237549, 55.741903111338615, 58.462287336587906, 55.077204778790474, 58.17211210727692, 55.558452755212784, 55.29314339160919, 52.960015386343, 52.72294610738754, 52.97755144536495, 51.440074145793915, 45.34745067358017, 44.19793635606766, 39.781121760606766, 43.04933778941631, 41.365781128406525, 46.8012298643589, 50.231469199061394, 49.745874255895615, 49.98912960290909, 50.69071635603905, 50.71051329374313, 49.75780941545963, 51.48146912455559, 52.41535261273384, 51.857291758060455, 50.35113237798214, 52.82828025519848, 51.86700403690338, 45.076445415616035, 49.04935263097286, 48.03489446640015, 47.657354325056076, 53.25546853244305, 56.07152782380581, 58.80975969135761, 59.53275069594383, 59.47904817759991, 58.48539009690285, 56.05074293911457, 61.97248958051205, 38.766693994402885, 27.777746357023716, 46.90118730068207, 50.25849714875221, 56.6004404425621, 60.42852982878685, 57.26926535367966, 48.49797561764717, 45.36871053278446, 52.773122414946556, 58.687341660261154, 60.784722715616226, 59.78801719844341, 60.230043679475784, 57.379353046417236, 53.82174454629421, 61.15464046597481, 52.82313533127308, 52.08605468273163, 25.65804909914732, 0.33879085967782885, 10.17553098499775, 1.4329026360064745, 1.036467889789492, 66.84745699167252, 59.12235751748085, 58.049990460276604, 64.35143172740936, 58.186543732881546, 61.74893997609615, 53.33547703921795, 24.353784285485744, 33.22270788252354, 35.31129240989685, 37.19022698700428, 28.683121874928474, 49.48043949902058, 3.213376896455884, 0.7386418303940445, 0.07342803917708807, 0.14098658080911264, 0.09458116270252503, 0.06789645631215535, 0.09876897587673739, 0.027949465184065048, 0.05146434938069433, 0.05116026550240349, 0.04369313923234586, 0.04970891408447642, 0.03233531861042138, 0.052799788463744335, 0.09869159213849343, 0.10548018763074651, 0.046746616790187545, 0.032556389560340904, 0.29565091361291707, 0.06859334040200338, 2.807928202673793, 54.98353600502014, 65.7906349003315, 35.11833876371384, 34.80410322546959, 54.70936931669712, 34.89092096686363, 17.035186998546124, 57.073697447776794, 76.06390804052353, 59.85322169959545, 58.72035428881645, 60.10233253240585, 66.4366914331913, 53.94920490682125, 0.3432048868853599, 1.6981047741137445, 1.7908124369569123, 0.22974723513470963, 11.917333770543337, 57.085207030177116, 61.35476052761078, 55.02694107592106, 59.36823092401028, 63.787048012018204, 62.085989490151405, 58.462868705391884, 57.29920394718647, 54.68514181673527, 56.0180950909853, 56.494255140423775, 59.99602183699608, 60.54912395775318, 60.06222568452358, 59.66962315142155, 59.850455448031425, 60.03837816417217, 60.048945397138596, 57.128665298223495, 66.97374701499939, 57.55889341235161, 59.48800049722195, 60.13322487473488, 59.729648530483246, 58.75663474202156, 54.31709736585617, 50.54155915975571, 57.13420160114765, 51.97255477309227, 46.666439697146416, 49.47766564786434, 58.447038754820824, 57.39842802286148, 57.71353371441364, 55.58091714978218, 57.030068188905716, 57.690047174692154, 57.26945914328098, 56.20892845094204, 57.43642598390579, 53.470704182982445, 51.39611430466175, 45.87209232151508, 46.9588416069746, 47.08602838218212, 47.89409302175045, 52.95714654028416, 52.63082765042782, 57.49394349753857, 54.878441244363785, 57.77107022702694, 56.43753178417683, 59.44501720368862, 61.00135289132595, 57.935487404465675, 57.104396000504494, 59.3486125767231, 58.41650739312172, 46.64385370910168, 56.23258598148823, 59.861474856734276, 56.88472978770733, 59.91966873407364, 60.08647978305817, 57.15494468808174, 57.63981007039547, 56.15203410387039, 53.25422219932079, 53.39336693286896, 48.671489506959915, 45.765340849757195, 41.82485729455948, 46.478144600987434, 42.71169550716877, 49.41373787820339, 53.52291718125343, 53.073245510458946, 53.648785427212715, 53.775261640548706, 54.71270173788071, 53.05488869547844, 53.58462207019329, 54.20741245150566, 53.832319378852844, 54.5682068914175, 55.08079178631306, 54.29636187851429, 46.468128338456154, 50.595048889517784, 51.135011315345764, 48.76962684094906, 54.295560121536255, 57.53454051911831, 58.28742451965809, 60.10800562798977, 60.521951615810394, 58.93443860113621, 57.29130797088146, 64.06628742814064, 38.13715897500515, 33.48659232258797, 49.72655609250069, 51.120465695858, 56.26253217458725, 61.07813157141209, 59.263542741537094, 51.129771396517754, 45.88029608130455, 54.27397347986698, 59.13436867296696, 60.9201892465353, 62.474864423274994, 62.04159267246723, 57.80244134366512, 58.25854606926441, 62.797155529260635, 54.178887382149696, 57.75521367788315, 28.596743009984493, 0.7829697174020112, 13.65721195936203, 1.694424671586603, 3.1978934397920966, 71.89226388931274, 59.26291957497597, 64.86543014645576, 68.24037864804268, 65.35911485552788, 67.84605860710144, 61.76821254193783, 25.930393785238266, 33.56029316782951, 44.45747382938862, 41.87980994582176, 30.79382311552763, 60.01212157309055, 5.418653162196279, 0.9985383250750601, 0.08934929617680609, 0.13566349691245705, 0.08327794188517146, 0.029908968826930504, 0.06374682663590647, 0.06211017207533587, 0.07642944023245946, 0.15128563129110262, 0.16344508272595704, 0.1822303989320062, 0.08489839165122248, 0.0961789621214848, 0.16908360907109454, 0.1798416778910905, 0.14564765413524583, 0.1562633493449539, 0.34321821585763246, 0.17053992545697838, 3.6574015952646732, 65.93334004282951, 79.10077348351479, 54.48020741343498, 39.74960245192051, 61.31349474191666, 37.554471641778946, 21.413141079246998, 62.04700358211994, 84.0408656001091, 65.14206290245056, 67.07299768924713, 65.42309582233429, 69.97802540659904, 57.02082708477974, 1.443243424873799, 3.3036272786557674, 5.546928104013205, 0.2421916861203499, 15.857628285884857, 63.46536107361317, 64.58344727754593, 61.072325482964516, 60.25666505098343, 68.16384315490723, 65.19155904650688, 61.161233112215996, 59.210265800356865, 59.30623345077038, 59.091799557209015, 58.93047921359539, 62.80254743993282, 62.534316033124924, 61.90574236214161, 60.56117311120033, 61.483205035328865, 65.56258633732796, 60.91877952218056, 59.62493374943733, 65.526093095541, 55.31506821513176, 60.430539920926094, 61.70165531337261, 61.45640127360821, 62.63602897524834, 58.339344933629036, 50.437893122434616, 60.3248143941164, 53.63151155412197, 49.41340729594231, 52.27355182170868, 60.125040113925934, 59.6993413567543, 63.36182422935963, 60.47871373593807, 60.06649285554886, 61.799929440021515, 60.72466693818569, 60.705333575606346, 60.774501264095306, 57.27592259645462, 54.40861165523529, 49.396521002054214, 50.615647584199905, 51.37573219835758, 51.245847567915916, 58.42159532010555, 58.30785222351551, 60.466007217764854, 56.18192709982395, 61.682637333869934, 58.482069075107574, 63.64277735352516, 65.30606970191002, 61.741807758808136, 60.186729803681374, 61.888768672943115, 61.86158873140812, 46.45742431282997, 61.11597754061222, 61.84916339814663, 58.51143769919872, 61.305526569485664, 60.4152837395668, 59.67229060828686, 61.55997611582279, 58.59126001596451, 58.69668535888195, 57.325680926442146, 51.27282232046127, 50.41257508099079, 45.208666920661926, 49.257847443223, 45.25961458683014, 52.18638829886913, 57.39196456968784, 56.53118155896664, 54.404971450567245, 57.431490048766136, 56.683526784181595, 56.25255011022091, 56.71687379479408, 59.63534519076347, 57.23885178565979, 57.01750986278057, 58.24134819209576, 56.972432881593704, 49.14247423410416, 53.67865562438965, 52.36239865422249, 51.38933166861534, 54.47144888341427, 59.145901054143906, 61.10534191131592, 61.53682395815849, 62.576094791293144, 61.077831387519836, 60.53135611116886, 65.36389499902725, 41.06598861515522, 31.898653730750084, 47.378164306283, 54.03996683657169, 60.303440541028976, 62.66881361603737, 60.09017698466778, 52.56691128015518, 51.47386573255062, 58.11684027314186, 62.310504242777824, 65.9021133184433, 64.17225614190102, 63.13666731119156, 60.4869668930769, 60.31821794807911, 63.16051863133907, 56.27152629196644, 60.789677649736404, 34.1194711625576, 0.7802301237825304, 16.3473954051733, 2.577150911092758, 4.090157048776746, 79.83860269188881, 62.683663219213486, 72.29103729128838, 71.21445626020432, 70.34995704889297, 70.76626271009445, 67.72173687815666, 30.91785416007042, 47.04600512981415, 51.32996365427971, 51.86514213681221, 40.82245588302612, 72.73029372096062, 12.715455293655396, 1.1766445054672658, 0.2155782704357989, 0.22120897454442456, 0.1598086184822023, 0.19869188748998567, 0.1998559312778525, 0.13838235492585227, 0.16563646669965237], [0.04564143644529395, 0.033788254513638094, 0.007812390995241003, 0.09439399305847473, 0.14045297662960365, 0.18737986480118707, 0.08121450417093001, 0.04388015302538406, 0.10379583152825944, 0.13528326497180387, 0.4188355238875374, 0.6812095153145492, 27.586381025612354, 58.749958500266075, 51.77628010511398, 32.212490290403366, 27.297159545123577, 35.04491910338402, 16.15842964500189, 54.922287091612816, 68.71213853359222, 64.34867307543755, 49.99487489461899, 53.74873146414757, 50.56925967335701, 55.92962443828583, 11.961434204131365, 1.972506099846214, 1.843937742523849, 1.320154492277652, 24.802171625196934, 30.733733139932156, 55.46709045767784, 49.922857359051704, 58.58754761517048, 58.85453648865223, 58.745140358805656, 57.01785184442997, 57.86315068602562, 53.223489448428154, 52.649192065000534, 53.56627285480499, 56.29954978823662, 54.6529271453619, 56.26284755766392, 55.877073258161545, 60.24998500943184, 59.13184180855751, 57.23024524748325, 54.43418808281422, 59.33336399495602, 57.77931958436966, 60.208460837602615, 57.85274304449558, 57.10537634789944, 55.42207807302475, 54.411754086613655, 51.73900030553341, 49.20829810202122, 48.80406439304352, 45.150492042303085, 46.05897769331932, 54.989817067980766, 55.72022907435894, 53.3941724896431, 56.61022871732712, 53.81953686475754, 54.313122779130936, 52.975366562604904, 50.65379373729229, 51.397824212908745, 47.29440160095692, 47.203810662031174, 44.76137772202492, 46.10430546104908, 47.57453016936779, 50.49487106502056, 52.76065148413181, 56.22408963739872, 57.365939766168594, 57.04000845551491, 54.79058235883713, 55.09537920355797, 56.151084154844284, 58.940909653902054, 56.833318546414375, 56.144191324710846, 56.54389947652817, 56.29197679460049, 45.258505046367645, 51.877100095152855, 60.31027637422085, 56.43616385757923, 53.09407979249954, 57.65424929559231, 57.765621319413185, 55.3616689145565, 52.10202522575855, 52.64754295349121, 52.95390151441097, 49.3079249560833, 44.319719821214676, 42.881060019135475, 42.753307074308395, 43.5978801548481, 46.280752792954445, 48.794834688305855, 48.79588343203068, 52.33780637383461, 55.29411233961582, 51.7376209795475, 50.456945300102234, 53.674475848674774, 52.630892246961594, 49.83893886208534, 52.023152858018875, 54.8102843016386, 48.86605426669121, 43.79598632454872, 49.865533635020256, 47.71549880504608, 49.02841575443745, 59.649222046136856, 53.14864106476307, 56.53455577790737, 55.826041996479034, 53.53113234043121, 59.30758237838745, 56.559315249323845, 36.77826449275017, 33.3158864825964, 64.81819868087769, 60.06853334605694, 52.321345657110214, 48.30616571009159, 52.926934361457825, 59.3900303542614, 57.9174991697073, 48.58160153031349, 45.34908078610897, 52.22387708723545, 59.712196066975594, 63.176880553364754, 56.12439438700676, 57.62030191719532, 60.509252697229385, 54.316971972584724, 49.409204721450806, 52.16342233121395, 10.134638529270887, 4.947765804827213, 9.031176790595055, 0.15261977532645687, 24.500959888100624, 44.86716404557228, 56.006285324692726, 60.98122917115688, 62.91214115917683, 59.03481021523476, 64.02002111077309, 50.08654497563839, 32.741330713033676, 39.70879644155502, 38.25602039694786, 57.40244060754776, 39.98788006603718, 43.153528198599815, 0.37781348917633295, 0.31060806883033365, 0.0200704450980993, 0.2315884589916095, 0.07672840700251982, 0.02367420103837503, 0.044954404365853406, 0.02527490596548887, 0.08267938494100235, 0.10022665039286949, 0.042466380255063996, 0.03433046760619618, 0.08538348163710907, 0.1558711688267067, 0.04364790533145424, 0.049933113186853006, 0.059229054604656994, 0.15801891451701522, 0.14187165128532797, 0.3250934259267524, 0.8276180340908468, 32.42236062884331, 72.42950186133385, 53.29105742275715, 37.031881883740425, 41.122502982616425, 38.93318586051464, 17.06948585808277, 58.325255289673805, 77.21505627036095, 72.50818803906441, 55.945503786206245, 60.78327879309654, 55.98567143082619, 65.5303792655468, 19.4172677770257, 1.8448608554899693, 0.9444761916529387, 0.8604152023326606, 32.90027618408203, 37.24482625722885, 59.83996421098709, 54.08942498266697, 64.4900406897068, 59.57513742148876, 64.00622025132179, 60.058627277612686, 62.39047855138779, 54.83761243522167, 54.446362629532814, 54.58689048886299, 57.42419824004173, 56.56063757836819, 58.67066815495491, 58.384604305028915, 62.88581617176533, 60.819563046097755, 60.39886862039566, 59.450200125575066, 59.99988242983818, 61.326501443982124, 63.36571902036667, 59.86433990299702, 61.02682292461395, 57.317876145243645, 55.1740425825119, 53.026226833462715, 52.81052380800247, 51.34013570845127, 46.536216884851456, 49.195158407092094, 56.574784219264984, 57.19745300710201, 56.0820684581995, 59.34868477284908, 56.31305046379566, 56.98954336345196, 56.27611644566059, 54.23134356737137, 54.24520142376423, 48.24256852269173, 48.63009832799435, 45.72426125407219, 46.33219823241234, 47.16969609260559, 51.851383075118065, 54.21965539455414, 56.25557094812393, 59.3586478382349, 58.347309306263924, 56.037360057234764, 55.35409212112427, 58.35268221795559, 59.50688548386097, 58.05387005209923, 58.08384284377098, 59.77100171148777, 58.66210341453552, 46.073652505874634, 53.408250734210014, 60.966679751873016, 57.84387432038784, 55.8662286400795, 58.607971519231796, 59.62590649724007, 56.46256484091282, 55.215600952506065, 55.63873864710331, 55.183599069714546, 54.63094152510166, 48.71146336197853, 43.85593570768833, 46.122145503759384, 44.92513373494148, 48.96056279540062, 50.47018378973007, 52.128688395023346, 54.30444784462452, 56.39657378196716, 53.33437129855156, 55.57775191962719, 54.26647648215294, 54.694417119026184, 54.54433277249336, 55.68470478057861, 57.458723187446594, 51.51022218167782, 44.302901923656464, 53.049834966659546, 50.29720567166805, 50.18331058323383, 60.335742607712746, 54.845314621925354, 57.7723241597414, 55.60316115617752, 54.40206840634346, 62.079507037997246, 57.04809822142124, 36.012214198708534, 42.24743641912937, 73.09419259428978, 58.58471296727657, 52.76159003376961, 49.850235655903816, 53.09385560452938, 59.65785898268223, 61.06301598250866, 50.918343141674995, 46.55016973614693, 56.36789292097092, 62.355980202555656, 66.48497924208641, 61.51404418051243, 60.7639454305172, 62.22900241613388, 56.33249782025814, 55.43869458138943, 53.415557742118835, 11.172494888305664, 9.061921890825033, 11.539157163351774, 0.8057307335548103, 34.76985186338425, 52.44989275932312, 61.70646205544472, 65.80603927373886, 66.79129600524902, 65.12290433049202, 69.3592058122158, 53.484828025102615, 37.674454003572464, 41.38360217213631, 50.38724943995476, 55.799177438020706, 45.90561792254448, 53.00255410373211, 1.2147128814831376, 0.1759661827236414, 0.011169197296112543, 0.09654736422817223, 0.031033213090267964, 0.0721460829663556, 0.039507585897808895, 0.04470756604860071, 0.02216659482655814, 0.2141729395953007, 0.14733281917870045, 0.13572448660852388, 0.2805536112282425, 0.19824901828542352, 0.20759381528478116, 0.18171410163631663, 0.10967422742396593, 0.3133288712706417, 0.3386402630712837, 0.6399521010462195, 1.5638143988326192, 41.53291895985603, 83.54282632470131, 71.19087472558022, 41.976377964019775, 45.987636521458626, 46.62805795669556, 21.682483926415443, 66.99269279837608, 82.11275026202202, 74.77847501635551, 62.7980712801218, 65.06892442703247, 62.96907730400562, 70.24607822299004, 22.571731209754944, 3.627563933841884, 3.3177891187369823, 0.9659424866549671, 35.89052952826023, 46.04951620101929, 64.49969217181206, 57.36750528216362, 68.52364584803581, 64.86283868551254, 66.77440971136093, 62.81146936118603, 63.52674677968025, 57.10134856402874, 58.43712128698826, 59.08147931098938, 60.71167543530464, 58.72608058154583, 62.59035162627697, 61.85843490064144, 66.04378491640091, 63.34453135728836, 61.76202267408371, 58.94373670220375, 65.03862485289574, 60.29692389070988, 64.45802360773087, 62.02317886054516, 65.39002239704132, 61.95558808743954, 58.65120179951191, 55.683564841747284, 54.70318324863911, 53.77792909741402, 49.33470591902733, 51.87630593776703, 60.624150931835175, 61.40525221824646, 60.165086165070534, 62.3872335255146, 61.84938758611679, 60.33032789826393, 60.24335816502571, 55.88494263589382, 56.97715602815151, 51.97280175983906, 54.5297035574913, 50.501186326146126, 51.91072069108486, 50.43231502175331, 56.46639123558998, 56.796555519104004, 60.45698270201683, 63.31863574683666, 61.60916447639465, 56.147964522242546, 61.40573099255562, 61.295107528567314, 61.695150062441826, 59.15356524288654, 61.74661450088024, 62.28253394365311, 60.49840807914734, 46.96416512131691, 55.637876093387604, 66.58771052956581, 58.96456718444824, 56.85699887573719, 61.509024649858475, 63.767076283693314, 60.01625195145607, 57.82606467604637, 59.85813483595848, 59.188998341560364, 56.68961025774479, 53.12538631260395, 47.169031128287315, 48.91982138156891, 48.06490905582905, 50.63430838286877, 55.38691096007824, 54.7675783932209, 59.05003979802132, 62.36141391098499, 54.936950504779816, 57.70542114973068, 57.73402601480484, 59.595823511481285, 57.65177182853222, 57.67564594745636, 60.33118665218353, 52.926402390003204, 47.983502224087715, 54.48496475815773, 52.04862289130688, 52.10940062999725, 63.28927852213383, 57.864347621798515, 59.21653926372528, 58.64332862198353, 56.63877658545971, 62.97657050192356, 56.98950916528702, 41.12980619072914, 40.13859897851944, 65.30822038650513, 59.78100277483463, 55.00103026628494, 56.4645179361105, 56.61002352833748, 61.828614100813866, 61.38388216495514, 54.14435103535652, 49.344239607453346, 58.48839953541756, 65.2432818710804, 69.87057477235794, 62.20892809331417, 62.445039823651314, 61.72319255769253, 56.70612797141075, 57.70274989306927, 58.66529144346714, 14.191731177270412, 7.076393058523536, 19.118163026869297, 0.9065133193507791, 38.35647940635681, 54.733178839087486, 65.1958604156971, 71.3029383122921, 71.29043698310852, 67.70931914448738, 75.36496594548225, 60.43412312865257, 40.79203471541405, 53.24170187115669, 53.05209964513779, 78.31885144114494, 59.456747174263, 68.80804538726807, 3.2945590652525425, 0.5023803643416613, 0.21427825035061687, 0.5815869953949004, 0.18846964929252863, 0.24990608857478946, 0.08403942250879481, 0.12072851706761867, 0.1039537753968034], [0.014503717829938978, 0.0769808930635918, 0.029238789065857418, 0.08597533698775806, 0.021137620060471818, 0.0987401805468835, 0.1234022896096576, 0.13672558445250615, 0.12045049370499328, 0.09754553058883175, 0.49904740881174803, 0.3283380955690518, 8.332373388111591, 54.30574357509613, 36.260329484939575, 47.859864458441734, 27.443782277405262, 56.72235310077667, 16.025252491235733, 32.336033061146736, 62.25918419659138, 49.36562865972519, 57.60447956621647, 44.81191121041775, 56.204045712947845, 55.65220892429352, 40.98135955631733, 2.3841207940131426, 1.0058619570918381, 2.9846161091700196, 55.847909823060036, 26.558526679873466, 49.088251143693924, 50.58024488389492, 57.45532996952534, 58.02673950791359, 59.88348327577114, 56.64231039583683, 54.27319452166557, 51.271177008748055, 53.7084574252367, 51.68549157679081, 56.78935870528221, 54.71633434295654, 56.33648380637169, 56.678921431303024, 59.117140397429466, 57.34507888555527, 62.15353086590767, 60.87352015078068, 63.71110528707504, 60.60691885650158, 59.126974269747734, 59.472109749913216, 54.08880941569805, 54.964708015322685, 54.66692939400673, 50.918350741267204, 51.116095930337906, 52.90044218301773, 47.18157045543194, 43.91768239438534, 49.26816388964653, 54.57785837352276, 54.99702148139477, 53.240767121315, 52.682713866233826, 53.9227507263422, 54.94697816669941, 53.848612904548645, 49.54939819872379, 45.63612498342991, 45.48986703157425, 43.980363830924034, 47.80556157231331, 49.64453749358654, 54.15522985160351, 55.82257658243179, 53.193699046969414, 54.541984498500824, 55.84847219288349, 58.042907640337944, 54.51310604810715, 53.25540393590927, 57.47607305645943, 53.198338598012924, 55.48692539334297, 57.702103927731514, 57.85156890749931, 46.06065720319748, 52.722801715135574, 59.48846787214279, 53.000604808330536, 55.8965016156435, 57.40766152739525, 56.04548402130604, 54.931873977184296, 54.153151363134384, 52.08627887070179, 54.05543200671673, 54.520128071308136, 50.8821614831686, 45.019068494439125, 45.00736892223358, 44.17535416781902, 44.55100581049919, 45.65431460738182, 48.783944472670555, 50.954247415065765, 53.1723365932703, 52.73870766162872, 52.366358041763306, 50.28505012392998, 52.03957177698612, 51.53028130531311, 53.0391613394022, 52.215597331523895, 43.703848868608475, 44.41228285431862, 50.860958620905876, 48.05193655192852, 49.921915009617805, 56.39478027820587, 57.0459209382534, 55.57803310453892, 48.58703903853893, 50.72827734053135, 53.45843464136124, 30.52961379289627, 39.41974215209484, 66.67308434844017, 60.03972329199314, 54.997112676501274, 64.2368146777153, 67.3919677734375, 62.160343900322914, 55.99053896963596, 60.89288771152496, 52.69545078277588, 47.598442286252975, 48.04822415113449, 57.72520288825035, 56.51966817677021, 65.72988376021385, 58.0528175085783, 61.11027404665947, 51.583451852202415, 57.288952097296715, 28.952476121485233, 9.56665925681591, 19.61607500910759, 4.984757294878364, 3.5490993317216635, 67.01307490468025, 66.99050411581993, 63.007732629776, 55.2930673956871, 61.205952912569046, 52.29624040424824, 68.08435901999474, 45.44685333967209, 39.031349793076515, 36.06505036354065, 35.119923278689384, 33.97602126002312, 39.40280266106129, 29.680237770080566, 0.8047871966846287, 0.07250459224451333, 0.17292028991505504, 0.0437739999324549, 0.14023092604475096, 0.062105763718136586, 0.14020878035807982, 0.04031173259136267, 0.05103525814774912, 0.058766640941030346, 0.03625816279964056, 0.04893253484624438, 0.05656032866681926, 0.042141568192164414, 0.021268097043503076, 0.07836915450752713, 0.0893616455141455, 0.08949046750785783, 0.06554860534379259, 0.6685899174772203, 0.1662545421277173, 12.33716944232583, 68.2262510061264, 41.11371025443077, 48.02181176841259, 42.680863961577415, 57.577577009797096, 16.058652698993683, 35.958336889743805, 70.55782869458199, 59.59112696349621, 62.26694718003273, 53.61837565898895, 62.30123274028301, 59.28194895386696, 49.7048706561327, 3.175105112604797, 0.8322677970863879, 2.5991985155269504, 65.240538418293, 34.10104215145111, 54.587023481726646, 50.69190949201584, 62.0842681825161, 60.65942823886871, 62.73291237652302, 59.21951450407505, 56.68689340353012, 53.58458787202835, 55.69713391363621, 54.86760422587395, 59.96205545961857, 57.37894646823406, 60.218792483210564, 58.02121840417385, 61.655951365828514, 57.02395811676979, 65.34108102321625, 64.68883842229843, 65.81262812018394, 64.02356252074242, 61.25012934207916, 59.45162124931812, 57.19318203628063, 54.567659720778465, 54.521473199129105, 53.86960677802563, 53.55747252702713, 55.60976900160313, 48.817036896944046, 45.987480729818344, 51.98773115873337, 54.391018599271774, 57.39045985043049, 58.88219140470028, 55.97017966210842, 56.66831620037556, 56.55814491212368, 55.75850062072277, 53.30997280776501, 47.77213856577873, 48.98602142930031, 46.03719726204872, 48.402767926454544, 50.80580838024616, 54.768756330013275, 56.966277211904526, 56.45366571843624, 55.95459669828415, 57.44451954960823, 57.68679454922676, 59.35837425291538, 56.99188403785229, 60.968427658081055, 58.05317468941212, 56.46088533103466, 58.18692371249199, 59.87700842320919, 47.6750385761261, 54.55005146563053, 63.0530945956707, 55.0218303501606, 56.97461396455765, 60.03888353705406, 58.15429866313934, 57.64615572988987, 58.49397003650665, 54.606007263064384, 59.51451167464256, 57.426360324025154, 51.51394598186016, 46.636656895279884, 47.95808918774128, 46.64611458778381, 47.76849076151848, 50.90704254806042, 52.4850332736969, 55.28737150132656, 54.3710582703352, 53.70081603527069, 53.72895732522011, 53.15296523272991, 54.24368530511856, 56.858169212937355, 57.11050607264042, 54.89885374903679, 47.1002434194088, 47.270405888557434, 52.289138585329056, 49.55688759684563, 50.387196242809296, 57.73227050900459, 55.864039957523346, 58.40994894504547, 51.201177164912224, 52.08123654127121, 51.44140027463436, 32.82915540039539, 46.786783039569855, 73.81627544760704, 59.644358307123184, 59.895954206585884, 62.37657509744167, 64.3079848587513, 65.2197915315628, 57.82331362366676, 62.30967588722706, 53.720601573586464, 49.673833921551704, 52.360415160655975, 59.18984189629555, 59.5991825312376, 66.65646404027939, 63.16023364663124, 61.65500521659851, 56.501159369945526, 59.27220247685909, 36.91276587545872, 14.168105944991112, 28.243694454431534, 6.164158433675766, 4.810348553583026, 75.03589600324631, 62.72669591009617, 69.10454347729683, 59.29104946553707, 68.33202973008156, 55.609955191612244, 74.79254186153412, 51.4004422724247, 44.27348390221596, 40.015447586774826, 50.60796819627285, 37.8299530595541, 46.62470653653145, 36.331564262509346, 0.9325832454487681, 0.13846418412867934, 0.12163055303972214, 0.016438218517578207, 0.0949892177595757, 0.043037058421759866, 0.13438223832054064, 0.06475463349488564, 0.0508710876601981, 0.10800975345773622, 0.19257111358456314, 0.09290816145949066, 0.14836775895673782, 0.1650810582214035, 0.17050345632014796, 0.19285753805888817, 0.2488538419129327, 0.28643150988500565, 0.1934456010349095, 0.859066512202844, 0.5376813607290387, 16.79198294878006, 79.14732098579407, 56.990003138780594, 55.749080926179886, 48.790016546845436, 76.08970865607262, 22.523120418190956, 42.666371539235115, 72.6351772248745, 63.757174015045166, 66.06320187449455, 61.12184822559357, 65.51413893699646, 67.21149265766144, 54.70354802906513, 6.518113240599632, 2.3456701822578907, 3.479873458854854, 71.62171840667725, 41.07930690050125, 57.98923932015896, 56.52764014899731, 67.16689825057983, 63.25769081711769, 66.40621706843376, 62.36791916191578, 59.96891409158707, 57.61295311152935, 58.93286928534508, 56.833516135811806, 63.630534410476685, 58.72920781373978, 61.66221342980862, 60.66957749426365, 64.5516885817051, 59.32496264576912, 69.03105542063713, 67.24483966827393, 67.44317382574081, 63.78160670399666, 63.3386454731226, 63.124811947345734, 60.44668525457382, 58.7980867177248, 60.39299413561821, 55.4570247977972, 56.92074045538902, 59.02959689497948, 52.65811398625374, 48.2250514626503, 55.02692207694054, 57.94544667005539, 62.89570324122906, 60.667594000697136, 57.91410595178604, 59.67012472450733, 60.66861234605312, 58.77566032111645, 56.182941645383835, 51.43302172422409, 52.60659635066986, 50.04217095673084, 53.32299090921879, 54.859396666288376, 58.29090133309364, 58.430840224027634, 58.885660618543625, 58.62383186817169, 60.0536685436964, 62.59658709168434, 61.09021492302418, 58.44141885638237, 62.01707258820534, 58.80575850605965, 59.29770290851593, 61.40834905207157, 62.55430296063423, 49.617919921875, 55.847773030400276, 66.0280005633831, 56.54896080493927, 59.39105249941349, 62.629269137978554, 60.56571006774902, 61.39041021466255, 58.95137429237366, 57.95790620148182, 62.01540067791939, 61.97524443268776, 56.138829812407494, 51.01458437740803, 50.0292744487524, 50.091317519545555, 51.483148634433746, 52.62793220579624, 55.970681235194206, 58.22095848619938, 57.558479234576225, 58.501527830958366, 57.32353784143925, 55.69857783615589, 56.332999393343925, 60.64691171050072, 59.45884086191654, 58.12401808798313, 48.54045353829861, 49.19332690536976, 53.562347665429115, 53.40485371649265, 52.13927462697029, 60.957142263650894, 59.066948890686035, 57.312757819890976, 47.97781392931938, 52.50353068113327, 52.853514701128006, 37.12609022855759, 45.2768998593092, 63.93177464604378, 59.55972544848919, 61.935289576649666, 65.95784112811089, 63.90398293733597, 67.22762659192085, 60.71767531335354, 62.062552347779274, 57.21593901515007, 50.71632698178291, 55.2854298055172, 62.887632474303246, 61.38172388076782, 68.64962428808212, 64.35500353574753, 62.629200741648674, 57.28916108608246, 56.093270257115364, 43.00052560865879, 14.146277066320181, 32.301344722509384, 9.406865481287241, 4.343104250729084, 80.41633129119873, 69.6879717707634, 75.42175009846687, 60.95107778906822, 72.48294219374657, 61.28964342176914, 79.09945115447044, 53.99466946721077, 50.39098843932152, 50.231564193964005, 52.186536490917206, 47.77924798429012, 57.10060000419617, 52.97941714525223, 0.789777705213055, 0.26444342569448054, 0.1954026593011804, 0.2563688886584714, 0.1487500689108856, 0.1429822901263833, 0.2231156558264047, 0.18891781743150204, 0.13801421999232844], [0.10555675500654615, 0.062464321235893294, 0.11938946001464501, 0.09765630355104804, 0.038189802507986315, 0.06221364972589072, 0.02281685905472841, 0.13233307952759787, 0.06495709880255163, 0.1867153903003782, 0.24030008527915925, 0.07351167179876938, 2.126425509341061, 49.74615544080734, 53.46790373325348, 51.53880424797535, 20.523859597742558, 52.25134201347828, 29.61409281939268, 23.019561879336834, 61.846663132309914, 45.694106072187424, 54.68709111213684, 52.89864107966423, 63.20811867713928, 57.5365050137043, 44.999723732471466, 0.16810716537293047, 0.2464386261999607, 0.17683342681266367, 36.17875926196575, 39.8263431340456, 40.05362793803215, 55.90040020644665, 56.79519519209862, 60.83962596952915, 58.273631259799004, 56.49832472205162, 53.786828219890594, 56.30108870565891, 55.64142130315304, 57.31405355036259, 56.71428233385086, 56.21591627597809, 59.524246752262115, 54.891991317272186, 57.26294629275799, 58.91219079494476, 60.58629356324673, 58.94691713154316, 58.670569360256195, 56.733657494187355, 56.80979020893574, 55.880873054265976, 55.32461330294609, 53.59511710703373, 51.4987163990736, 54.17240113019943, 51.92961327731609, 50.63731402158737, 46.936377212405205, 43.71832989156246, 44.35008779168129, 52.875500321388245, 55.21745145320892, 53.675357401371, 54.6276319026947, 53.16274210810661, 52.72057503461838, 50.76178014278412, 47.414247170090675, 45.81501178443432, 44.830355420708656, 48.568697422742844, 48.804421573877335, 50.20572558045387, 53.12540151178837, 51.013440638780594, 54.60295982658863, 56.091073974967, 57.279638797044754, 55.57603061199188, 57.66510531306267, 58.07644084095955, 57.026610374450684, 49.41148839890957, 54.17518638074398, 56.15836836397648, 56.612189412117004, 46.91826358437538, 54.57546070218086, 58.10103692114353, 53.34960088133812, 54.939051792025566, 57.154158130288124, 56.4276447147131, 54.73343722522259, 54.58122879266739, 53.259249329566956, 52.82386489212513, 54.16400358080864, 52.75590933859348, 46.92867882549763, 44.85186606645584, 42.709392830729485, 41.6227575391531, 43.22624869644642, 48.632112219929695, 49.32986117899418, 53.96688915789127, 53.272111639380455, 53.098137974739075, 52.49500773847103, 52.22999855875969, 50.01679591834545, 52.38664135336876, 48.19133587181568, 42.46162712574005, 46.80168204009533, 50.515591353178024, 46.34349502623081, 50.92124618589878, 52.56558895111084, 57.29969412088394, 48.890851736068726, 52.55290903151035, 45.68219751119614, 29.07378651201725, 48.457693979144096, 68.80390360951424, 56.949957087635994, 54.55183357000351, 54.89448018372059, 54.693767353892326, 57.04311668872833, 63.709083795547485, 61.11805222928524, 59.21989448368549, 55.30996508896351, 51.61673426628113, 50.73643170297146, 52.474173456430435, 58.08698147535324, 58.56447145342827, 64.50913086533546, 49.07341293990612, 59.59605149924755, 43.06721583008766, 34.23078238964081, 22.182244509458542, 19.793308898806572, 2.434205668978393, 12.509707733988762, 70.06577789783478, 55.03202140331268, 57.34928525984287, 54.89087417721748, 53.85343864560127, 58.67866292595863, 68.98836851119995, 34.06077951192856, 54.68998655676842, 23.928845487535, 35.356950759887695, 25.583863779902458, 44.69481289386749, 14.868138581514359, 0.7845815434120595, 0.05917310780205298, 0.11905313353054225, 0.055276795392273925, 0.07486037677153945, 0.027369820018066093, 0.07504500827053562, 0.07490355492336676, 0.017352971190121025, 0.04893934405117761, 0.0752975388604682, 0.04789211059687659, 0.1253283632104285, 0.06704985135002062, 0.061059725121594965, 0.084504726837622, 0.11334478593198583, 0.05124242867168505, 0.02847257910616463, 0.2384042987250723, 0.03786966968618799, 3.530939156189561, 62.55043476819992, 62.26218603551388, 50.68549923598766, 34.28758554160595, 60.38862816989422, 32.34605312347412, 29.216903932392597, 67.02980160713196, 50.77629916369915, 58.805097341537476, 60.0568375736475, 70.21030694246292, 63.3475673943758, 51.22734256088734, 2.619891492649913, 0.6213858223054558, 0.052776551819988526, 41.383883357048035, 48.25870245695114, 43.895183801651, 56.67305834591389, 60.382666289806366, 63.34843374788761, 61.72797650098801, 60.296612307429314, 56.93532407283783, 58.918331265449524, 57.34455831348896, 60.6036776304245, 60.41543573141098, 59.26841787993908, 61.870142072439194, 57.90562480688095, 61.62470184266567, 62.023296654224396, 63.09368021786213, 61.804508194327354, 61.403644904494286, 58.11799541115761, 60.119484812021255, 57.14394807815552, 56.32992535829544, 55.7364846020937, 53.681912049651146, 54.77601774036884, 54.99528877437115, 53.9983856678009, 48.979759365320206, 44.73209649324417, 45.63219599425793, 55.90453438460827, 60.05637399852276, 55.912985131144524, 57.35415279865265, 56.829708740115166, 56.182812452316284, 54.22499790787697, 50.18069252371788, 49.18587550520897, 45.98544783890247, 47.58939117193222, 49.67959061264992, 50.59982903301716, 55.579659417271614, 54.49303172528744, 53.59873451292515, 59.50756564736366, 60.14914222061634, 59.06499579548836, 60.59557266533375, 58.845606967806816, 61.1117559671402, 54.78454068303108, 54.989258497953415, 57.86645270884037, 56.22885078191757, 49.293440133333206, 57.292896285653114, 58.69907543063164, 55.5321391671896, 55.88110864162445, 59.04464788734913, 56.566306874156, 56.126123294234276, 58.215011805295944, 55.72192758321762, 56.41825541853905, 54.98157911002636, 54.96777065098286, 50.423545092344284, 47.75340177118778, 45.91173179447651, 45.999032109975815, 46.9224813580513, 52.624007016420364, 54.6964880079031, 56.07802167534828, 55.12568257749081, 55.820501893758774, 54.32361401617527, 55.642074868083, 53.769086971879005, 55.08173033595085, 49.01339516043663, 42.92820788919926, 48.60425591468811, 50.50077214837074, 49.8457632958889, 53.12928110361099, 52.6140895485878, 59.66035544872284, 52.94819422066212, 51.29270665347576, 45.086039900779724, 33.624684512615204, 58.333014473319054, 71.26941651105881, 59.088216349482536, 57.02538304030895, 57.20796324312687, 54.99795243144035, 58.59392747282982, 61.975282430648804, 62.5775159150362, 60.89647091925144, 58.39777819812298, 53.69870714843273, 52.96228386461735, 52.92727254331112, 61.57204806804657, 60.095842480659485, 66.59671604633331, 51.438265442848206, 66.16933017969131, 42.08928890526295, 43.22281368076801, 34.917093962430954, 23.79972841590643, 4.867273773998022, 14.933123644441366, 76.9444651901722, 58.930038437247276, 65.29547587037086, 58.72582599520683, 57.66746498644352, 63.65375116467476, 74.90556299686432, 39.101855009794235, 56.72957271337509, 34.880349934101105, 44.689884558320045, 25.11258076876402, 55.67576386034489, 19.815513007342815, 0.7842307747341692, 0.05191727468627505, 0.11518826591782272, 0.04295285063562915, 0.02000506930926349, 0.019264257498434745, 0.05606195794825908, 0.06377905810950324, 0.009991683527914574, 0.24153077392838895, 0.23289490607567132, 0.28203069290611893, 0.22169432428199798, 0.23252530168974772, 0.22913868888281286, 0.15907142835203558, 0.13264132314361632, 0.14957953768316656, 0.249274016241543, 0.6970889819785953, 0.10231678315903991, 4.931350210681558, 73.82553175091743, 78.84497880935669, 63.40242885053158, 33.110534101724625, 71.34415850043297, 36.96603141725063, 31.296283453702927, 75.83234086632729, 56.18896432220936, 64.43436607718468, 65.15343189239502, 74.96862441301346, 68.76650601625443, 57.53615543246269, 3.9409034326672554, 1.066268621943891, 0.4230267583625391, 50.799344927072525, 56.535760313272476, 49.20975722372532, 61.751573234796524, 66.35526180267334, 69.51322674751282, 64.1425721347332, 64.83606532216072, 59.41575117409229, 63.395102843642235, 58.844611421227455, 64.04188513755798, 62.85622335970402, 61.38761356472969, 65.74076637625694, 60.749023631215096, 63.49367335438728, 63.26920419931412, 64.74547058343887, 64.04626250267029, 63.6287447065115, 62.42237024009228, 60.481529384851456, 61.78341172635555, 59.06000666320324, 58.93946573138237, 55.41142724454403, 58.14317665994167, 58.75545680522919, 57.24398151040077, 50.89164197444916, 46.82907477021217, 48.79655219614506, 60.5204126983881, 60.565463081002235, 58.790665715932846, 61.61177113652229, 61.00006856024265, 57.060808539390564, 58.2269773632288, 52.50708349049091, 53.828211799263954, 50.67347668111324, 51.02075144648552, 54.2515204846859, 53.34137052297592, 58.99390161037445, 55.906863659620285, 57.50668041408062, 62.58049875497818, 63.30681458115578, 59.828648418188095, 64.41927328705788, 61.483771204948425, 62.736639976501465, 54.785452634096146, 56.06589652597904, 58.992738872766495, 60.8070807158947, 50.64820043742657, 58.196104019880295, 63.044263869524, 57.957803606987, 57.10719645023346, 62.86208264529705, 59.193603694438934, 57.9682682454586, 59.70198221504688, 58.211884573102, 59.00791145861149, 58.41415911912918, 58.946620747447014, 55.01555308699608, 51.378418654203415, 50.24975001811981, 48.47892343997955, 50.20726829767227, 54.39959853887558, 54.760043397545815, 59.54136863350868, 61.515731289982796, 59.468104764819145, 60.32940834760666, 58.70591126382351, 58.613732010126114, 56.635257974267006, 51.78162641823292, 44.34887185692787, 51.164235547184944, 54.45103257894516, 50.63938871026039, 53.811876475811005, 54.58928816020489, 60.803159326314926, 57.64793023467064, 50.30424289405346, 46.88145875930786, 37.601083740592, 53.75290744006634, 62.47213996946812, 59.22267973423004, 59.986233562231064, 57.530060559511185, 57.68441587686539, 59.37223210930824, 62.08306364715099, 66.8840642273426, 63.54103781282902, 59.88583154976368, 55.38761392235756, 55.58398358523846, 55.30377522110939, 64.38179969787598, 60.99954418838024, 69.75623890757561, 51.968109011650085, 66.30743756890297, 42.100281715393066, 51.31378412246704, 42.46191971004009, 36.07835344970226, 5.520217437297106, 13.011505957692862, 80.7070840895176, 62.02945992350578, 69.02616128325462, 64.52978655695915, 66.02693662047386, 67.36477643251419, 78.493832051754, 44.72861967980862, 69.7239938378334, 40.42166858911514, 48.86448115110397, 39.44884479045868, 67.02453508973122, 32.572304382920265, 0.7372786535415798, 0.13244358531665057, 0.17093066620873287, 0.18907800258602947, 0.15402316174004227, 0.07741640016320162, 0.220903150329832, 0.12226563107105903, 0.1266552638844587], [0.1484252605587244, 0.0929758972779382, 0.059441746707307175, 0.04845499250222929, 0.1035259198397398, 0.07911104243248701, 0.03408294651308097, 0.16641722089843825, 0.10047509174910374, 0.11321183017571457, 0.13891024456825107, 0.42229630693327636, 1.2413711822591722, 38.90358924865723, 50.33760130405426, 47.69301921129227, 32.18573972582817, 38.466415107250214, 35.45468911528587, 15.202927216887474, 54.619298949837685, 63.14938522875309, 60.09936109185219, 52.79608078300953, 59.04926083981991, 51.91775791347027, 60.41823238134384, 9.977819044142962, 0.28709513833746314, 0.15203883696813136, 0.5040005617775023, 28.47065817564726, 42.14669622480869, 54.91374135017395, 61.535368636250496, 58.99243488907814, 59.555306285619736, 56.31279967725277, 55.65870277583599, 61.191072911024094, 60.14170981943607, 60.719601809978485, 57.75425612926483, 56.742309629917145, 56.82247392833233, 58.27173516154289, 57.91446693241596, 57.76548072695732, 60.60522794723511, 60.336255580186844, 61.474381908774376, 58.11972811818123, 59.06304270029068, 54.83435221016407, 54.10001881420612, 53.71930204331875, 50.32690487802029, 53.66331584751606, 50.30913323163986, 50.64609535038471, 51.47922724485397, 46.7270540446043, 43.89100782573223, 45.36395698785782, 56.09743483364582, 53.78490552306175, 55.417503118515015, 54.88251082599163, 53.89829143881798, 48.518327325582504, 43.95545236766338, 42.470290660858154, 45.15121780335903, 49.50829580426216, 48.3342994004488, 53.4853295981884, 53.31761799752712, 54.80300769209862, 55.38453608751297, 54.915838837623596, 54.93846282362938, 55.85105985403061, 55.12016907334328, 55.2479562163353, 51.99344605207443, 45.48678919672966, 53.056754395365715, 54.97377052903175, 56.792147755622864, 49.48888264596462, 55.674468129873276, 56.97758540511131, 50.836313143372536, 47.05993518233299, 54.74293291568756, 55.535498186945915, 56.51491843163967, 53.55434909462929, 55.08867256343365, 54.70829777419567, 54.213332533836365, 54.21063847839832, 50.99968157708645, 46.08462251722813, 41.96206413209438, 40.56676000356674, 41.637648940086365, 46.3093576580286, 49.74716618657112, 53.18889990448952, 53.571641966700554, 50.64359128475189, 52.589029893279076, 50.997964069247246, 53.324043452739716, 49.620864763855934, 44.5858309417963, 41.66471108794212, 48.54709178209305, 50.376450419425964, 50.34493491053581, 50.071208998560905, 51.424510180950165, 54.997466057538986, 51.65877141058445, 33.07586096227169, 40.51837719976902, 59.822663739323616, 71.71538338065147, 54.06616263091564, 55.38759872317314, 45.053361654281616, 49.77102890610695, 51.680814027786255, 54.017209857702255, 51.58963032066822, 56.64336293935776, 55.34058004617691, 54.972793981432915, 54.27164040505886, 55.10819211602211, 55.651999935507774, 57.72339418530464, 59.676352590322495, 60.47457575798035, 56.53515614569187, 56.369032859802246, 32.69970774650574, 39.571346417069435, 24.821071811020374, 7.124666143208742, 2.347962409257889, 20.586679726839066, 56.44910216331482, 59.991697669029236, 55.24892896413803, 56.75508074462414, 52.63460464775562, 68.29264104366302, 35.79533323645592, 36.88216611742973, 48.600581511855125, 28.936288990080357, 50.97002036869526, 23.790884390473366, 48.51396895945072, 4.202550267800689, 0.7064746564719826, 0.045371569285634905, 0.09433609811821952, 0.0754061373299919, 0.1380698662251234, 0.11734964486095123, 0.07107301164069213, 0.05081119263195433, 0.028000391357636545, 0.19423730933340266, 0.07034580339677632, 0.05995962106680963, 0.029304740019142628, 0.03987308620708063, 0.054581822332693264, 0.009795173955353675, 0.11345134349539876, 0.023708571752649732, 0.061750323220621794, 0.15067414613440633, 0.34550619777292013, 1.3391597662121058, 44.84173581004143, 63.17634478211403, 39.89038489758968, 31.97188340127468, 53.24495829641819, 38.51669020950794, 18.681081980466843, 59.939902648329735, 70.44332563877106, 66.33022114634514, 58.39104115962982, 66.22084021568298, 56.61293797194958, 63.085556253790855, 13.271634299308062, 0.37868922343477607, 0.818575113080442, 0.3305194160202518, 35.94676271080971, 47.09944166243076, 58.07293362915516, 63.04256536066532, 62.074267119169235, 60.80586098134518, 61.51562109589577, 59.021586924791336, 62.59975992143154, 61.515833884477615, 64.04163435101509, 59.56092618405819, 60.19388861954212, 58.4367299079895, 63.35053123533726, 60.69781757891178, 61.21202878654003, 61.080738231539726, 63.63021142780781, 62.828925624489784, 60.92482879757881, 60.57830639183521, 57.458776384592056, 56.07671454548836, 55.895278081297874, 53.75921130180359, 55.755039006471634, 52.343392074108124, 51.126051396131516, 52.97508157789707, 47.49392129480839, 47.2897582501173, 48.80855955183506, 57.54562072455883, 56.2644624710083, 57.53246583044529, 54.832889288663864, 56.70425087213516, 55.021913945674896, 48.34260195493698, 43.61638896167278, 46.38541057705879, 50.0028582662344, 49.93306361138821, 53.559501618146896, 55.0173731893301, 55.68440459668636, 58.1768124550581, 59.2581432312727, 58.11460979282856, 56.61797650158405, 59.99395854771137, 57.53837451338768, 54.50659699738026, 48.362816870212555, 56.67373090982437, 58.385900035500526, 59.00882340967655, 51.51811055839062, 56.940165013074875, 59.46903571486473, 52.864173129200935, 49.508128613233566, 58.462465927004814, 56.83975540101528, 58.73667061328888, 57.0103320479393, 58.10037575662136, 58.6051444709301, 57.57169872522354, 55.933276042342186, 53.33872586488724, 47.96619415283203, 46.77333556115627, 43.846060037612915, 45.49107916653156, 50.92390224337578, 52.779072895646095, 55.569308772683144, 57.44353540241718, 52.04939424991608, 56.372855454683304, 54.40062068402767, 55.67732557654381, 50.93586400151253, 49.295951798558235, 42.32318535447121, 49.127218052744865, 51.24804764986038, 52.64076791703701, 49.03885379433632, 55.09348690509796, 55.48234663903713, 53.91642026603222, 35.439991503953934, 43.803585916757584, 64.97543424367905, 69.4569593667984, 54.10496234893799, 56.549694165587425, 47.63503052294254, 51.70806236565113, 53.30597162246704, 55.80207668244839, 52.73380972445011, 58.983288779854774, 58.23478974401951, 59.51692074537277, 56.51010029017925, 56.83524504303932, 57.35354483127594, 59.17200185358524, 61.443622559309006, 62.09848701953888, 58.21662291884422, 58.68041083216667, 36.521941646933556, 45.33363461494446, 21.99044030159712, 10.607184022665024, 2.329585407860577, 28.20462305098772, 59.80384714901447, 64.0034843981266, 61.93555936217308, 64.52503681182861, 59.51106145977974, 74.15011033415794, 40.34744717180729, 39.82321210205555, 53.60428221523762, 37.9072181135416, 49.68448095023632, 24.29330863058567, 59.58120949566364, 5.681870263069868, 0.8213010511826724, 0.020333755383035168, 0.0936649962386582, 0.0475020118028624, 0.15833711775485426, 0.06515858447528444, 0.03153290854243096, 0.08320492939674295, 0.022425229581131134, 0.2741378336213529, 0.1993826191755943, 0.3038353775627911, 0.18200977327069268, 0.3128241217928007, 0.17513975675683469, 0.10180410754401237, 0.20258627773728222, 0.2386122039752081, 0.22277446085354313, 0.33248744322918355, 0.38944742584135383, 2.3485043551772833, 57.46026210486889, 77.29726105928421, 64.99004065990448, 39.61456149816513, 60.1025415211916, 47.146916314959526, 21.724325381219387, 68.0877636373043, 76.10977157950401, 72.72654712200165, 65.53602576255798, 71.1262021958828, 63.566504046320915, 74.59879785776138, 16.232630163431168, 0.7025271432939917, 0.48315013060346246, 2.2031246311962605, 47.3019327968359, 52.29552984237671, 59.05707322061062, 66.23889684677124, 65.9864915907383, 65.30803799629211, 65.95293179154396, 61.7960574477911, 67.83045664429665, 65.01650243997574, 66.67687654495239, 62.81498037278652, 62.708821669220924, 61.065713837742805, 65.72679832577705, 64.44204926490784, 65.18242433667183, 66.04307055473328, 66.08831092715263, 63.163718059659004, 65.0672373175621, 63.581699430942535, 60.53019717335701, 58.708069548010826, 58.18828023970127, 54.79072295129299, 58.17096456885338, 53.43296080827713, 54.41694460809231, 56.87161289155483, 52.04024814069271, 47.73029901087284, 51.291441321372986, 60.97398675978184, 60.2473783493042, 61.06383673846722, 59.405016750097275, 59.136587753891945, 58.05964954197407, 51.26783698797226, 47.095121294260025, 49.85195316374302, 52.64123149216175, 52.32378892600536, 57.19648785889149, 56.81822195649147, 60.03690384328365, 62.255357801914215, 62.530425041913986, 61.47291898727417, 59.709220826625824, 60.587802082300186, 58.897109404206276, 56.5335526317358, 51.18601217865944, 59.90805275738239, 59.48469467461109, 62.38186441361904, 53.50901372730732, 58.45501832664013, 63.311127349734306, 56.77047751843929, 50.836544930934906, 59.15331445634365, 59.498959109187126, 62.76189722120762, 58.65863420069218, 61.02140821516514, 60.27587302029133, 59.000912234187126, 59.2988770455122, 56.09573632478714, 52.588642314076424, 49.98584657907486, 46.975693702697754, 47.26700507104397, 51.79513469338417, 57.16919772326946, 61.20515115559101, 61.06009393930435, 54.671451151371, 59.99558486044407, 56.49219945073128, 59.660583436489105, 50.7662259042263, 52.12575875222683, 44.701948910951614, 52.93766498565674, 54.04819719493389, 55.36272145807743, 53.266932517290115, 55.55551551282406, 57.34358176589012, 55.900483801960945, 42.84517854452133, 44.759215638041496, 56.429821997880936, 66.48967579007149, 56.2824697047472, 59.88051563501358, 46.89360670745373, 54.34144265949726, 54.521670788526535, 57.04509638249874, 54.574134573340416, 61.857279762625694, 59.14037995040417, 60.90391092002392, 58.76494489610195, 58.28285716474056, 59.21004541218281, 60.45396946370602, 63.818168342113495, 65.99662184715271, 55.347632467746735, 56.84938408434391, 40.3976196795702, 55.274186208844185, 33.13436642289162, 15.868550799787045, 4.100179960951209, 26.762007661163807, 68.78856003284454, 66.11099570989609, 68.25839728116989, 67.52011209726334, 64.11403566598892, 78.16003516316414, 45.89108370244503, 46.0565572232008, 62.77492672204971, 42.35912762582302, 63.453585505485535, 37.70215071737766, 73.38866159319878, 14.580620359629393, 1.098930244334042, 0.14057367952773347, 0.20866350241703913, 0.23401198675855994, 0.2545063354773447, 0.17567953560501337, 0.2106985604041256, 0.1329770707525313, 0.12755584524711594], [0.04341592481068801, 0.09285586973419413, 0.05082376090285834, 0.017845545735326596, 0.04234187013935298, 0.14826108264969662, 0.0568787545489613, 0.05901984688534867, 0.1126550487242639, 0.08005839394172654, 0.023790948289388325, 0.7304985111113638, 0.2886194799793884, 17.191297821700573, 61.315645426511765, 47.06041395664215, 40.87974540889263, 27.989032119512558, 50.193121656775475, 18.906257897615433, 43.27447570860386, 58.8823813945055, 63.10759887099266, 60.64900919795036, 57.418574541807175, 55.160085931420326, 54.34242680668831, 46.33001334965229, 0.20509259949903935, 1.4388049067929387, 0.4832666181027889, 8.162757139652967, 38.077832758426666, 57.452711910009384, 61.28429710865021, 61.33255071938038, 63.93841668963432, 60.34281022846699, 65.54432451725006, 62.06395827233791, 60.814315527677536, 59.40316244959831, 61.2721111625433, 57.966383546590805, 57.376256212592125, 55.70016235113144, 60.73692128062248, 58.18880841135979, 58.85829448699951, 58.55564072728157, 58.032180815935135, 57.03395538032055, 57.469776794314384, 57.52392768859863, 57.96122722327709, 51.043394431471825, 50.791661739349365, 52.48467229306698, 52.69765466451645, 50.42785406112671, 55.09105123579502, 45.95119267702103, 44.04795840382576, 43.18731598556042, 49.35098044574261, 56.385497376322746, 53.840956315398216, 54.636990800499916, 51.097400933504105, 44.648835361003876, 44.78656657040119, 45.09891740977764, 48.05152617394924, 50.07090501487255, 53.29649493098259, 52.79107265174389, 55.71660786867142, 55.64315401017666, 54.74820703268051, 54.41473692655563, 57.7069790661335, 56.223990842700005, 57.766324281692505, 54.71674472093582, 47.152034640312195, 45.5337280780077, 49.145954847335815, 55.53446464240551, 54.44417394697666, 52.992670834064484, 54.57697682082653, 54.17704068124294, 46.587358340620995, 44.02580179274082, 50.900541096925735, 57.34125629067421, 54.67215031385422, 52.52295143902302, 54.910469725728035, 51.84495761990547, 52.041296884417534, 53.7915513664484, 53.30069750547409, 49.42929044365883, 44.189994782209396, 42.79483504593372, 41.77345745265484, 41.63900546729565, 47.404094114899635, 48.276671692728996, 51.12787529826164, 53.175254836678505, 52.24677465856075, 52.76532523334026, 54.03384156525135, 47.50150568783283, 42.4289982765913, 41.85988001525402, 48.437300473451614, 49.90385077893734, 45.5010612308979, 48.41400772333145, 48.72875243425369, 56.82792663574219, 53.29391106963158, 39.39461030066013, 61.40253536403179, 61.265583112835884, 55.2234361320734, 57.81670197844505, 52.18983851373196, 51.36427581310272, 56.043561324477196, 52.28181257843971, 53.75464014708996, 52.408041805028915, 55.05710765719414, 55.74108615517616, 59.66204255819321, 59.15214031934738, 60.34811094403267, 61.89909651875496, 60.00457517802715, 60.03629967570305, 61.44201144576073, 57.53359816968441, 41.54415875673294, 36.4531235396862, 17.28908747434616, 0.32434486609417945, 1.2341918237507343, 5.592944584786892, 57.92234770953655, 50.37661001086235, 59.46221128106117, 53.75380039215088, 56.46560087800026, 47.315691858530045, 67.00030758976936, 29.46162410080433, 52.63794086873531, 34.35418076813221, 50.72952747344971, 50.92976912856102, 25.982249602675438, 29.041307754814625, 0.7017783459741622, 0.1759523936198093, 0.010595302846923005, 0.03399549183086492, 0.0685083273856435, 0.00379710535526101, 0.027274845524516422, 0.08371664021979086, 0.05344653676729649, 0.07893096772022545, 0.0760758068645373, 0.039009356187307276, 0.10154538002097979, 0.026256758064846508, 0.01711657489067875, 0.07634239373146556, 0.0420093768480001, 0.05598180970991962, 0.10685559507692233, 0.07882921927375719, 0.02235061961982865, 0.7835680665448308, 0.35235859570093453, 20.954006016254425, 73.37678343057632, 53.48008207976818, 40.308924838900566, 43.806253373622894, 50.146961733698845, 19.608104936778545, 48.26708100736141, 67.04403564333916, 70.84234222769737, 65.4180420935154, 63.234994634985924, 63.88906493782997, 60.01074604690075, 46.988806799054146, 0.2723275276366621, 4.3410813342779875, 0.5524246883578598, 10.608159620314837, 45.16289457678795, 60.3075747191906, 63.613161742687225, 63.71778152883053, 67.4516473710537, 62.499509900808334, 66.42908424139023, 64.62545022368431, 64.24505263566971, 61.53893284499645, 61.35556988418102, 59.88538697361946, 60.06523512303829, 57.81874626874924, 61.75134904682636, 60.08883185684681, 62.028517574071884, 61.568613052368164, 59.46665324270725, 60.443292036652565, 58.295430690050125, 58.344634249806404, 57.49736711382866, 56.117007583379745, 52.08051837980747, 54.20362025499344, 54.78075608611107, 53.04711051285267, 56.02548189461231, 48.76535966992378, 46.71699978411198, 45.14155112206936, 49.87377919256687, 59.11171428859234, 57.7712108194828, 56.91899634897709, 54.34099428355694, 47.72821672260761, 47.99059644341469, 46.544302850961685, 49.1252725571394, 51.263501420617104, 55.25791548192501, 55.09380988776684, 56.636124327778816, 57.68924921751022, 59.632320553064346, 58.37424986064434, 58.26940208673477, 58.443094566464424, 58.14255729317665, 56.81981027126312, 51.25896446406841, 47.923879623413086, 52.4629070609808, 60.0420905649662, 58.05742286145687, 51.58543914556503, 57.01087921857834, 57.17148520052433, 48.7601425498724, 46.81295983493328, 53.660473600029945, 57.86576874554157, 56.86440467834473, 55.828770250082016, 57.23186016082764, 54.45095658302307, 55.69660574197769, 55.42433135211468, 57.64586694538593, 50.53660422563553, 45.81341966986656, 46.11285500228405, 44.62224058806896, 46.656062453985214, 50.46007253229618, 50.03770239651203, 55.31501121819019, 54.774911999702454, 56.205622628331184, 55.64481072127819, 56.16000607609749, 49.898238480091095, 45.13660378754139, 44.38281923532486, 51.22050292789936, 52.31594234704971, 46.38595014810562, 51.54297262430191, 52.467295825481415, 58.51033195853233, 53.58933761715889, 43.310547173023224, 64.69417333602905, 61.09110027551651, 54.59441788494587, 58.21046344935894, 52.95686535537243, 53.72600108385086, 59.10806268453598, 56.13201677799225, 56.29117503762245, 56.70760989189148, 58.9680439978838, 58.976601138710976, 61.10655024647713, 62.514826878905296, 63.90532046556473, 64.36248913407326, 62.79271736741066, 61.660530120134354, 62.33078755438328, 60.67082762718201, 45.53691990673542, 40.32239131629467, 19.121383354067802, 1.2108305585570633, 1.4520048047415912, 9.53232429921627, 65.1213464140892, 54.23326626420021, 66.03567615151405, 60.37013836205006, 62.09295451641083, 53.50687824189663, 73.09313625097275, 32.36008197069168, 56.55676558613777, 37.99343168735504, 55.15274852514267, 49.59699064493179, 33.552663177251816, 39.303483590483665, 1.0762207629159093, 0.07866210245992988, 0.06884617527248338, 0.13110320724081248, 0.041498196660541, 0.07541815270087682, 0.017932245282281656, 0.012690303174167639, 0.024115610067383386, 0.05583927653788123, 0.24030706146731973, 0.19207586359698325, 0.26164362905547023, 0.1270666957134381, 0.14246799662942067, 0.3483143955236301, 0.15854301920626312, 0.15989035862730816, 0.24659616930875927, 0.1472267069038935, 0.09093329164898023, 1.1568670417182148, 0.6358310440555215, 26.810677349567413, 83.88356924057007, 72.41463705897331, 48.65091361105442, 50.82014121115208, 65.29752776026726, 24.6546483412385, 54.10551331937313, 73.73335629701614, 74.03187587857246, 74.8009318113327, 68.50692674517632, 70.15267163515091, 65.83648324012756, 58.18155460059643, 0.2951460157055408, 7.160218460485339, 0.3413905139314011, 12.566858567297459, 52.84702084958553, 59.778722897171974, 67.395661175251, 66.19798824191093, 69.9352777004242, 65.93842417001724, 71.41155168414116, 68.38263541460037, 68.0088722705841, 61.69368714094162, 64.83472019433975, 62.04992562532425, 62.506919503211975, 61.84997655451298, 67.28738978505135, 62.55964547395706, 62.424186542630196, 64.24499183893204, 63.53779658675194, 63.38380604982376, 61.094979867339134, 62.67640560865402, 62.278038784861565, 56.902794018387794, 54.81497325003147, 56.99581682682037, 55.93086317181587, 56.110369339585304, 60.791786536574364, 50.82999028265476, 48.98371875286102, 46.80706635117531, 51.56409569084644, 61.995041370391846, 61.70714981853962, 61.2526486068964, 56.65362238883972, 50.2447684854269, 51.99492037296295, 49.126610085368156, 53.066607266664505, 53.892158567905426, 59.5394991338253, 56.21840514242649, 61.844178065657616, 61.42520874738693, 62.591651156544685, 59.47124719619751, 62.68266387283802, 61.797459572553635, 61.469955146312714, 58.09083826839924, 50.989080145955086, 51.16705119609833, 55.97040005028248, 62.0136983692646, 59.66755986213684, 54.94766592979431, 58.06805469095707, 57.458244413137436, 50.55455066263676, 46.82921536266804, 54.328147172927856, 61.71080902218819, 59.051977694034576, 56.28134496510029, 61.456253081560135, 57.022187411785126, 57.739311531186104, 57.84097507596016, 61.312199011445045, 54.31054271757603, 49.35292214155197, 49.64111387729645, 47.772347554564476, 50.08756332099438, 52.57364071905613, 52.24661126732826, 56.46741718053818, 59.935323894023895, 58.078530728816986, 57.30790168046951, 58.341598212718964, 51.164604127407074, 48.28203700482845, 46.89736470580101, 54.351170137524605, 55.84705486893654, 48.40205356478691, 52.94868819415569, 51.77808500826359, 63.12536671757698, 56.05637423694134, 46.33948244154453, 61.97491005063057, 61.75342373549938, 58.68226133286953, 60.3831222653389, 55.87279848754406, 56.16444803774357, 61.505441442131996, 57.13052339851856, 56.53909653425217, 57.293720841407776, 57.83760465681553, 61.165656074881554, 63.72737221419811, 64.62300315499306, 65.05167335271835, 66.54872462153435, 65.5962373316288, 65.17359361052513, 60.70713087916374, 59.53556254506111, 48.4805915504694, 47.702511101961136, 23.952748104929924, 1.4489691238850355, 3.154049967415631, 8.50165145471692, 68.57865929603577, 59.2913306504488, 68.66832688450813, 64.77200075984001, 66.42372652888298, 58.5840518027544, 77.73037701845169, 36.336572393774986, 62.26951964199543, 49.10434328019619, 62.33416557312012, 61.0139986127615, 44.05309572815895, 63.03014762699604, 3.1573439156636596, 0.6454109831247479, 0.3076985233929008, 0.31690617150161415, 0.11577808778383769, 0.1413333715754561, 0.11304359271889552, 0.1461833660141565, 0.07664509350433946, 0.1504571718396619], [0.065189710148843, 0.10029406708781607, 0.04894657256954815, 0.05578219424933195, 0.07500885825720616, 0.110434223752236, 0.09275836637243629, 0.03745473120943643, 0.0698530173394829, 0.12045127296005376, 0.06019908243615646, 0.27500451367814094, 0.09736127016367391, 4.363392787054181, 43.92090082168579, 43.73295150697231, 45.75313590466976, 27.12414912879467, 47.614219039678574, 29.00659091770649, 30.07515247911215, 71.06922805309296, 56.68294541537762, 59.65329922735691, 52.28340469300747, 55.09045086801052, 48.17850396037102, 64.6540854871273, 10.510159078985453, 1.4488901593722403, 0.10446987231262028, 1.6592553025111556, 21.54895719140768, 48.512213453650475, 57.29406662285328, 60.62147207558155, 63.929259181022644, 61.37350872159004, 62.987137734889984, 58.006737381219864, 58.65408964455128, 58.40696610510349, 58.03996279835701, 59.17320638895035, 58.614453971385956, 61.08888499438763, 61.22500129044056, 58.654104843735695, 53.33351254463196, 59.55651082098484, 60.67610174417496, 59.725780338048935, 58.746485486626625, 57.94556826353073, 56.88330486416817, 56.33111469447613, 52.24941171705723, 51.8854596465826, 51.495976746082306, 48.20625767111778, 50.48424303531647, 51.05309531092644, 44.03959505259991, 44.18385051190853, 43.12664844095707, 49.21090096235275, 53.68081010878086, 54.40091706812382, 44.77873899042606, 43.85683245956898, 45.0278802216053, 45.97493380308151, 53.27165946364403, 51.474067121744156, 54.672309905290604, 53.9202618598938, 53.973766788840294, 54.56601820886135, 56.14704117178917, 55.65645709633827, 57.099072486162186, 54.89381141960621, 56.899055019021034, 50.63907712697983, 43.48207376897335, 45.7413337379694, 48.148086592555046, 51.52078181505203, 50.963636711239815, 53.725465312600136, 53.3597881346941, 52.332889437675476, 43.84110130369663, 42.77681261301041, 46.307199373841286, 54.84565660357475, 58.12249056994915, 54.192752838134766, 55.56186117231846, 53.205577209591866, 54.772339537739754, 54.14937436580658, 53.562853038311005, 51.11228473484516, 47.12887868285179, 45.8216842263937, 41.81891821324825, 38.59467722475529, 43.833402916789055, 48.88776250183582, 47.938421443104744, 50.535623878240585, 49.14450712502003, 53.78329060971737, 48.77424359321594, 41.34557381272316, 41.813997477293015, 45.337799191474915, 50.241185277700424, 47.69224025309086, 45.71707583963871, 48.95787633955479, 49.85274352133274, 57.702860087156296, 50.15977844595909, 45.62427721917629, 56.80742673575878, 52.31836661696434, 57.54134975373745, 54.46293354034424, 50.45431584119797, 53.495710641145706, 58.457776978611946, 55.292554423213005, 57.356858253479004, 58.41559924185276, 58.30536335706711, 58.161476477980614, 57.57482595741749, 59.02305364608765, 59.28465060889721, 58.514758720993996, 56.49554327130318, 70.66919311881065, 62.85683512687683, 51.48528791964054, 36.72902673482895, 28.03402740508318, 3.7933680368587375, 0.11126302459160797, 0.7056607876438648, 32.36184127628803, 70.19103437662125, 48.33690606057644, 64.73634347319603, 46.467923149466515, 52.9742456227541, 47.64783203601837, 60.72610326111317, 39.94353644549847, 53.72801877558231, 28.350466825067997, 44.06752735376358, 31.55277729034424, 31.560783460736275, 11.660275664180517, 0.9462480247020721, 0.06208912476722617, 0.01966585587069858, 0.0659943837672472, 0.10174371156608686, 0.04792122505023144, 0.014643232316302601, 0.07052366650896147, 0.09336214061477222, 0.027120801642013248, 0.041435592793277465, 0.0360643880412681, 0.01785594879038399, 0.022687163182126824, 0.05811817085486837, 0.101195516763255, 0.16982580127660185, 0.024088733189273626, 0.09819890998187475, 0.11837526326416992, 0.025015597711899318, 0.5916860222350806, 0.09118123576627113, 6.108357002958655, 53.646349757909775, 52.4712286144495, 44.74571496248245, 39.832255616784096, 59.45223681628704, 28.44826977699995, 37.15212643146515, 76.88179895281792, 66.30451932549477, 66.20272278785706, 58.67337740957737, 62.07264460623264, 51.86321943998337, 70.88991567492485, 13.216495458036661, 0.7329383958131075, 1.189848796930164, 1.9106065900996327, 26.325211599469185, 54.04459498822689, 60.15224665403366, 62.58101172745228, 66.45284816622734, 62.9296088218689, 66.13466084003448, 59.73011590540409, 61.74439162015915, 57.638134360313416, 60.69464474916458, 62.47576877474785, 63.52798171341419, 64.89807799458504, 62.6045286655426, 58.927739560604095, 55.96260666847229, 61.76631264388561, 63.18066895008087, 61.17395482957363, 60.34433774650097, 61.13222926855087, 58.843669071793556, 56.865715608000755, 53.810941725969315, 52.38502264022827, 52.09722988307476, 51.22941344976425, 54.574966728687286, 55.57059310376644, 47.77430824935436, 46.24050535261631, 44.87771227955818, 54.11394126713276, 56.928340047597885, 55.76852448284626, 47.06838592886925, 44.279320389032364, 47.40673117339611, 46.97677284479141, 54.696073830127716, 51.87736228108406, 55.93776360154152, 56.49563826620579, 57.08205319941044, 58.24799783527851, 56.94268047809601, 56.631910353899, 58.83260786533356, 57.50937066972256, 59.89460147917271, 52.4400132894516, 47.01975233852863, 46.28003843128681, 50.36609597504139, 55.07283881306648, 54.776747301220894, 54.34050790965557, 54.71293732523918, 53.21316920220852, 45.428971499204636, 44.787239134311676, 47.18706116080284, 57.40696616470814, 57.84620739519596, 58.72370570898056, 57.06248804926872, 56.14434331655502, 56.21683582663536, 56.5531025826931, 56.076532155275345, 54.412286058068275, 48.965171948075294, 48.068746849894524, 42.18230791389942, 42.96981565654278, 46.508174389600754, 53.03978070616722, 50.78368216753006, 54.834553599357605, 53.1652195751667, 56.8271666765213, 51.20987109839916, 43.6975222080946, 43.57795022428036, 47.48200513422489, 48.75814005732536, 51.324978321790695, 47.120880112051964, 51.29606947302818, 52.520367577672005, 58.88116925954819, 51.54805675148964, 49.611448869109154, 56.22507758438587, 53.8246513903141, 60.94466373324394, 55.688360184431076, 53.33021052181721, 53.44703145325184, 59.23857048153877, 57.224465757608414, 59.704839661717415, 60.872513204813, 59.3024792522192, 59.59233149886131, 61.709049716591835, 61.631058901548386, 61.6703449934721, 61.68277032673359, 57.945750653743744, 68.09004351496696, 65.11777460575104, 55.7646144926548, 41.18040047585964, 31.18566758930683, 3.836242323741317, 0.5594137008301914, 0.8868357783649117, 39.37204711139202, 72.03691452741623, 53.72789338231087, 69.21251088380814, 52.170809134840965, 57.76421159505844, 52.460220605134964, 63.526294603943825, 45.41495785117149, 56.203623935580254, 37.418511137366295, 51.78918041288853, 35.55955208837986, 43.29534038901329, 20.56280180811882, 0.8870169811416417, 0.03861683428112883, 0.05593675763520878, 0.12058449588948861, 0.10812814827659167, 0.03368274337844923, 0.011617452637437964, 0.10695436008973047, 0.02087541372020496, 0.09323609425337054, 0.1438348545343615, 0.15818972722627223, 0.14228729851311073, 0.18996494327438995, 0.13975072681205347, 0.14911207370460033, 0.23210854124045, 0.133568235905841, 0.1333397880080156, 0.16056452557677403, 0.1828931664931588, 0.7338111021090299, 0.13167561090085655, 7.717433385550976, 69.56806540489197, 65.38470268249512, 58.835727497935295, 44.09274660050869, 66.26018330454826, 33.993340730667114, 39.935492277145386, 83.39721813797951, 71.24224036931992, 72.40149736404419, 64.36903238296509, 69.38984736800194, 59.71916489303112, 76.8658398091793, 16.036081910133362, 7.62677357532084, 1.301946344319731, 2.7452097181230783, 35.5917439609766, 59.217040836811066, 61.546635031700134, 64.4240154325962, 72.64193326234818, 64.19681042432785, 67.57145494222641, 62.77553848922253, 65.09151801466942, 59.61609922349453, 62.9323560744524, 66.37866094708443, 66.2703363597393, 66.21878832578659, 64.5774208009243, 60.80000929534435, 57.78401233255863, 64.39602613449097, 66.27749517560005, 64.23859298229218, 64.03494670987129, 65.38821369409561, 61.611934527754784, 60.05684897303581, 54.74678970873356, 56.51263475418091, 55.68852357566357, 54.41337659955025, 55.40331847965717, 59.05527971684933, 50.70034883916378, 47.97708056867123, 46.39027051627636, 54.77624572813511, 58.70171248912811, 58.002588003873825, 48.45768637955189, 49.48528043925762, 53.307757526636124, 50.143222734332085, 58.49039442837238, 56.102883741259575, 59.31491978466511, 60.04438564181328, 58.411229476332664, 60.47956109046936, 61.13094113767147, 59.97866816818714, 61.80211812257767, 61.26805678009987, 61.108271554112434, 54.48675826191902, 48.17372761666775, 50.03525912761688, 53.22092458605766, 57.50814713537693, 56.63050062954426, 57.324290201067924, 57.381195947527885, 54.97810609638691, 46.387257277965546, 47.845356836915016, 49.27815355360508, 59.679757207632065, 59.11486051976681, 59.28623132407665, 60.835837572813034, 56.518714427948, 59.54343192279339, 60.12812554836273, 57.431797832250595, 56.81423977017403, 53.7315221875906, 52.28734888136387, 46.400830149650574, 47.22684122622013, 48.34598757326603, 54.87222857773304, 53.652858808636665, 57.118915021419525, 53.65036994218826, 59.52406816184521, 51.54280163347721, 44.57638084888458, 45.235789865255356, 49.25368666648865, 54.28021654486656, 52.01121389865875, 48.6063040047884, 53.21047514677048, 53.90347436070442, 59.981818199157715, 54.2065043002367, 47.2423329949379, 58.016008883714676, 55.41394270956516, 59.309421479701996, 58.25025871396065, 54.59773510694504, 55.315132811665535, 61.87629014253616, 59.07668396830559, 60.622642412781715, 61.595086231827736, 61.681052818894386, 61.504309102892876, 61.31441429257393, 63.304565101861954, 63.41268450021744, 65.11107936501503, 57.457283064723015, 65.93099936842918, 63.028118535876274, 59.59004022181034, 45.24189993739128, 40.148106068372726, 4.700447050854564, 0.44334628677461296, 2.9645429737865925, 40.55021569132805, 79.94748964905739, 57.03844293951988, 74.5906662940979, 57.99579776823521, 64.23274129629135, 60.2945452183485, 71.14042863249779, 48.989551439881325, 61.72082148492336, 41.54699720442295, 50.08159004151821, 45.429674461483955, 54.42605271935463, 37.76840016245842, 0.886963902739808, 0.12303037714445964, 0.15034397947601974, 0.2299226343166083, 0.1432335961726494, 0.12485576356993988, 0.10771520988782868, 0.26431966514792293, 0.1842318821582012, 0.18576112197479233], [0.06479640898760408, 0.015667427651351318, 0.07815793927875347, 0.009633495228626998, 0.06979725978453644, 0.045811365998815745, 0.07527551191742532, 0.02065100496110972, 0.04353952950623352, 0.07867854103096761, 0.06455325172282755, 0.11581660524825566, 0.44071626383811235, 0.7280987617559731, 29.2296826466918, 55.11549152433872, 43.616347163915634, 25.330504775047302, 32.17112571001053, 53.16841520369053, 20.648023635149002, 54.64226491749287, 59.832592606544495, 61.034756898880005, 56.593813598155975, 59.997089579701424, 51.932949498295784, 57.75221183896065, 41.39213651418686, 1.232996431645006, 2.1863266825675964, 0.7819057744927704, 11.438597459346056, 35.533736273646355, 55.98625659942627, 61.9221156835556, 57.90521822869778, 65.88355511426926, 63.0204201489687, 62.35122285783291, 57.13524654507637, 55.613659992814064, 55.62070481479168, 61.35748878121376, 59.711914882063866, 57.081851810216904, 53.56738619506359, 56.8653280287981, 56.448566392064095, 56.79601214826107, 57.10738644003868, 63.78359019756317, 57.545993104577065, 59.146835803985596, 57.160291001200676, 58.97522561252117, 56.698714569211006, 55.523502230644226, 50.88081255555153, 50.451165810227394, 48.76412093639374, 53.778468668460846, 46.54006227850914, 43.61287035048008, 43.30844588577747, 44.97418910264969, 48.25397551059723, 46.449684128165245, 44.91769753396511, 44.997854232788086, 43.56573008000851, 51.024080067873, 49.1661811619997, 50.73126018047333, 53.338011503219604, 54.19907949864864, 52.333497405052185, 57.48405262827873, 57.72760435938835, 55.67412614822388, 56.645726412534714, 57.39954136312008, 50.887659788131714, 43.604746386408806, 43.23689192533493, 42.85710610449314, 47.07172974944115, 49.92898643016815, 49.458313286304474, 49.287694841623306, 51.74443781375885, 50.878604874014854, 44.08774606883526, 42.52260245382786, 45.04252463579178, 49.771883860230446, 55.646710619330406, 53.61345112323761, 55.10360576212406, 54.90118682384491, 54.23793241381645, 54.16254065930843, 52.33143411576748, 50.80667093396187, 51.18199199438095, 49.564981162548065, 42.39016056060791, 39.13433186709881, 41.12862825393677, 43.98347206413746, 46.04933761060238, 50.0610027462244, 54.193953573703766, 51.18233397603035, 43.105833157896996, 41.867027431726456, 41.67393319308758, 46.17346175014973, 49.59693364799023, 46.10571898519993, 48.79628241062164, 48.73465731739998, 49.2816873639822, 53.52592281997204, 56.76691330969334, 44.46142941713333, 56.70011669397354, 56.55182585120201, 55.619827061891556, 56.990732699632645, 49.50599692761898, 55.13089209794998, 54.824503138661385, 56.37008160352707, 57.98708103597164, 61.271115615963936, 61.02689512073994, 58.111243173480034, 60.64172878861427, 56.77457369863987, 58.10417555272579, 56.27129830420017, 64.31671679019928, 57.963184118270874, 53.958727195858955, 48.369892090559006, 34.95738320052624, 13.82249929010868, 0.20260679069906473, 0.5830383393913507, 5.663137743249536, 56.96409992873669, 54.445446878671646, 58.88130985200405, 53.93288858234882, 53.778639659285545, 62.09434524178505, 57.74055026471615, 52.12200075387955, 40.17984576523304, 58.52373763918877, 30.5335408821702, 25.68672426044941, 31.26677043735981, 36.63171015679836, 4.610913405194879, 0.5944538174662739, 0.019902009116776753, 0.06915647463756613, 0.08930408454034477, 0.133233601518441, 0.08969296250143088, 0.033163904226967134, 0.026687598910939414, 0.024286424632009584, 0.03496246943541337, 0.04080250742845237, 0.056043764197966084, 0.039140879598562606, 0.060793360898969695, 0.12469578621676192, 0.03866836901579518, 0.08552132814656943, 0.0378544185514329, 0.06333440032904036, 0.03424736190936528, 0.02930929866124643, 0.1441565458662808, 0.44686528388410807, 0.8430892007891089, 38.504652455449104, 65.04191547632217, 42.584539130330086, 31.522150933742523, 45.69192498922348, 55.81658810377121, 24.702320583164692, 59.85955595970154, 60.82318425178528, 69.31625291705132, 63.492423221468925, 66.65410816669464, 57.196073681116104, 63.70336510241032, 47.62846827507019, 1.7016364471055567, 2.300511742942035, 0.641282326541841, 13.748535308986902, 42.44104743003845, 58.3208779245615, 63.878957480192184, 60.426869317889214, 67.1674682199955, 64.02824386954308, 62.262740805745125, 57.33085624873638, 58.541444689035416, 57.58822403848171, 64.06003296375275, 61.8293322622776, 56.76841422915459, 55.77792137861252, 56.96345396339893, 55.92186525464058, 59.50105279684067, 59.280463233590126, 66.16038545966148, 59.26559083163738, 61.73477813601494, 62.350474298000336, 60.973143205046654, 57.89490558207035, 56.210870146751404, 54.076019302010536, 54.26899954676628, 51.14107958972454, 54.78787690401077, 47.3022747784853, 45.52718102931976, 46.41842320561409, 47.98845715820789, 51.74303948879242, 52.29623660445213, 45.37497639656067, 45.87321326136589, 45.835143104195595, 51.885273456573486, 52.34832040965557, 53.64926800131798, 57.14397847652435, 57.354148998856544, 56.42907723784447, 60.654138922691345, 59.595899507403374, 59.36956085264683, 58.565960973501205, 61.29484914243221, 53.90069290995598, 47.701952531933784, 45.207131803035736, 46.63797162473202, 49.92236338555813, 52.09798224270344, 50.18400974571705, 52.27699063718319, 53.100265860557556, 52.001406624913216, 47.382895052433014, 44.11335289478302, 45.537284687161446, 51.589858308434486, 58.37738089263439, 55.196571573615074, 56.65263444185257, 56.74605242908001, 56.98480121791363, 58.602841794490814, 55.07321119308472, 54.02081586420536, 53.779000639915466, 51.258048713207245, 46.0740514844656, 42.49940849840641, 43.63348424434662, 48.01935330033302, 47.12060272693634, 53.38290609419346, 55.54338276386261, 54.08834584057331, 46.92764148116112, 44.02651995420456, 42.89486087858677, 46.10657013952732, 49.65431056916714, 47.415755689144135, 49.7371157258749, 51.02709710597992, 53.209293410182, 54.58150997757912, 58.89900930225849, 48.48577067255974, 58.08409363031387, 59.41255934536457, 57.3734937608242, 59.39818851649761, 52.28179357945919, 56.486606150865555, 56.61080248653889, 58.84109281003475, 61.30232714116573, 61.16642363369465, 61.134889125823975, 58.97965997457504, 62.99183048307896, 59.25987973809242, 60.05730114877224, 56.40719421207905, 62.98506684601307, 58.7249406427145, 57.45423182845116, 50.02501867711544, 39.45196062326431, 13.902919124811888, 0.28502104338258505, 1.1528962547890842, 8.68780441582203, 66.76040366292, 58.97540420293808, 62.840366810560226, 58.60269360244274, 58.85360173881054, 68.4835883975029, 61.31566822528839, 57.71728791296482, 43.68288539350033, 65.61125412583351, 36.242329850792885, 29.18806917965412, 37.6383825391531, 50.35599231719971, 9.762081820517778, 0.7345901196822524, 0.030479960551019758, 0.11028830267605372, 0.04074448632309213, 0.040396660260739736, 0.09148935321718454, 0.07556518699857406, 0.07005966093856841, 0.032381261262344196, 0.047337596406578086, 0.15401223732624203, 0.10584703122731298, 0.1774401028524153, 0.11692596017383039, 0.3155276767211035, 0.12933979014633223, 0.23825536452932283, 0.11249755014432594, 0.28918122639879584, 0.1250336563680321, 0.12525334692327306, 0.2836158312857151, 0.5115147773176432, 1.0689715831540525, 51.857291758060455, 79.74914029240608, 59.19540859758854, 36.11554205417633, 49.772628620266914, 63.30791272222996, 28.24423022568226, 68.83912771940231, 73.7943734228611, 75.45383557677269, 70.08755072951317, 72.92444810271263, 65.86156949400902, 68.71735945343971, 55.68275548517704, 3.456953326240182, 6.223723562434316, 1.1801681038923562, 19.67507254332304, 51.41886368393898, 59.20316778123379, 66.20646938681602, 60.494133308529854, 70.15514150261879, 64.729283452034, 63.89293313026428, 59.79013368487358, 59.14442293345928, 58.6722906678915, 65.38290157914162, 64.87987697124481, 59.56592671573162, 59.88006725907326, 61.339682936668396, 59.405240938067436, 59.41130921244621, 61.39664947986603, 68.85195583105087, 61.27080403268337, 64.61047142744064, 64.82376158237457, 63.751968294382095, 59.35236677527428, 60.34979425370693, 57.01812922954559, 56.645627617836, 53.648014068603516, 58.72899502515793, 50.17474204301834, 47.88517490029335, 49.56880755722523, 51.63862869143486, 54.73939910531044, 52.53020524978638, 48.8689611107111, 48.94213758409023, 48.14968250691891, 56.05734698474407, 56.37318603694439, 56.70381769537926, 59.0932434797287, 59.56057660281658, 58.094676062464714, 62.49567210674286, 63.232790753245354, 61.003655567765236, 61.05374448001385, 62.59407162666321, 53.64449925720692, 49.14878949522972, 47.245650216937065, 46.83319754898548, 53.12579669058323, 54.041596949100494, 52.957830503582954, 52.45018154382706, 55.077599957585335, 53.77861686050892, 48.06117005646229, 45.17356060445309, 46.58435270190239, 54.23418581485748, 58.144643381237984, 56.955299600958824, 59.02390480041504, 60.259929075837135, 60.47237187623978, 61.81728310883045, 57.96511821448803, 55.424817726016045, 55.43201074004173, 53.827535435557365, 49.44740027189255, 45.920638516545296, 47.467816695570946, 49.7833364456892, 51.051438599824905, 55.237183794379234, 58.61544951796532, 55.41208080947399, 49.41935397684574, 47.22255885601044, 47.00336001813412, 50.03429397940636, 52.765557020902634, 50.39297953248024, 52.87408299744129, 52.395042702555656, 54.29999828338623, 58.51538568735123, 60.387913808226585, 44.46265295147896, 61.18432827293873, 59.71959047019482, 59.654469564557076, 60.53251504898071, 53.1857992708683, 58.82519446313381, 59.24775078892708, 60.62456890940666, 63.55452708899975, 60.81170126795769, 62.969267293810844, 61.14983752369881, 64.69025194644928, 60.29511898756027, 61.16591066122055, 57.29466699063778, 64.21023890376091, 63.03196772933006, 63.16236913204193, 51.292357072234154, 48.74498516321182, 18.92189595848322, 0.5584790103603154, 1.8684742134064436, 8.412396144121885, 68.74322846531868, 63.20404149591923, 67.07853019237518, 64.36274752020836, 64.87692832946777, 71.4921909570694, 68.36334004998207, 63.3005715161562, 48.08101639151573, 73.08585584163666, 41.50941722095013, 37.317470759153366, 46.32696971297264, 62.22280494868755, 21.926064155995846, 1.031205290928483, 0.11079719333793037, 0.22292701672995463, 0.12336679268628359, 0.17946515668882057, 0.3053227305645123, 0.18369833735050634, 0.0970055439393036, 0.2811876725172624, 0.0893464834371116], [0.10107169684488326, 0.02284087680891389, 0.10067418770631775, 0.05435848783235997, 0.036321620136732236, 0.1973654024186544, 0.049179417692357674, 0.036490840939222835, 0.052476724158623256, 0.07931115513201803, 0.07833167604985647, 0.04583123329211958, 0.48209078900981694, 0.49191495403647423, 10.885174255818129, 53.101208209991455, 38.493693843483925, 35.21336406469345, 26.44290078431368, 48.38297098875046, 31.77192483097315, 44.96683269739151, 72.89867788553238, 55.87478958070278, 62.203555181622505, 51.645475924015045, 59.67696815729141, 51.25348515808582, 62.32836328446865, 6.178915416821837, 1.2467534746974707, 0.35326078010257334, 2.737748106010258, 30.025971718132496, 56.301012709736824, 63.61615218222141, 59.78199452161789, 54.67229850590229, 56.66747644543648, 58.92536088824272, 57.3748654872179, 56.1522962898016, 57.08923481404781, 55.52717663347721, 56.56899333000183, 57.733763828873634, 55.74379161000252, 61.92078575491905, 52.13267058134079, 45.551176741719246, 55.291912257671356, 56.32027767598629, 62.03243136405945, 60.054998472332954, 60.214266926050186, 55.5031581223011, 56.465220898389816, 57.0825319737196, 53.69115315377712, 49.182356894016266, 50.718789249658585, 51.086081340909004, 52.153615057468414, 45.647262185812, 43.866176158189774, 44.843559712171555, 41.50078788399696, 42.744559943675995, 44.998823180794716, 43.216494619846344, 48.82064290344715, 52.701150476932526, 49.762270376086235, 52.96508431434631, 56.30358137190342, 54.647193253040314, 54.84526142477989, 58.51126290857792, 57.882484048604965, 54.47729676961899, 56.80909864604473, 49.08367998898029, 42.33180709183216, 43.02017815411091, 40.11470206081867, 42.90852874517441, 46.47655248641968, 49.98284853994846, 47.5627925992012, 49.60592396557331, 49.02249567210674, 48.766450211405754, 43.98803561925888, 41.03136867284775, 42.134958654642105, 44.0336749702692, 52.801677882671356, 56.84477113187313, 57.75695398449898, 55.778878927230835, 54.29331064224243, 54.81685034930706, 51.22344397008419, 52.94411323964596, 52.63200178742409, 52.28388346731663, 46.67267516255379, 42.407597824931145, 40.98809279501438, 42.12628751993179, 46.78659684956074, 46.46869070827961, 47.79662065207958, 44.20792981982231, 41.65520019829273, 42.78121657669544, 42.352595776319504, 45.65808780491352, 45.549744218587875, 46.571931168437004, 47.56058871746063, 49.653888791799545, 51.05688750743866, 48.47312115132809, 57.55004748702049, 48.57010334730148, 54.7146700322628, 57.816781774163246, 55.110099613666534, 54.329089522361755, 50.836115553975105, 49.45624619722366, 53.939363434910774, 57.621077075600624, 60.24914525449276, 59.1999227553606, 58.392431885004044, 56.10723450779915, 59.22867201268673, 54.593916311860085, 58.6836102604866, 57.677211463451385, 51.25888466835022, 50.04508540034294, 56.46823413670063, 40.218345299363136, 20.039360895752907, 1.4666401944123209, 0.2821418963139877, 0.6638822669629008, 18.711579144001007, 64.30850923061371, 53.94061356782913, 57.181915640830994, 53.73949036002159, 65.50886482000351, 55.56976094841957, 60.411521941423416, 32.21335284411907, 45.651111379265785, 55.26103511452675, 21.532428078353405, 46.762977316975594, 39.84300523996353, 28.937721513211727, 3.414269029162824, 0.46954962133895606, 0.13485014758771285, 0.09178678374155425, 0.13804657763103023, 0.1351513111148961, 0.03495772340102121, 0.018042059018625878, 0.11147821773192845, 0.014320724621939007, 0.04641945211915299, 0.055565999209648, 0.007739618313280516, 0.015388631527457619, 0.010110817711392883, 0.03156129198032431, 0.10606888143229298, 0.030482903166557662, 0.07627387123648077, 0.039687675453023985, 0.030418089554586913, 0.0644597782229539, 0.06056998929125257, 0.7398430409375578, 0.2504239889094606, 14.812772702425718, 67.60721862316132, 43.11443969607353, 39.91045542061329, 38.93661327660084, 55.31309612095356, 30.778709426522255, 48.594802021980286, 80.42536720633507, 63.55178363621235, 70.28927430510521, 57.642667517066, 65.93615189194679, 58.24586994946003, 67.56709277629852, 9.580287225544453, 1.8020733701996505, 1.4388990704901516, 3.854779629036784, 35.49864135682583, 57.921595349907875, 63.47220450639725, 61.61976210772991, 57.71625816822052, 60.14151602983475, 61.10210448503494, 58.387271761894226, 57.08196580410004, 56.95406086742878, 55.56366987526417, 57.66651123762131, 58.54944705963135, 58.75628896057606, 61.12784430384636, 53.764952793717384, 50.09650804102421, 56.89342752099037, 60.48035144805908, 61.86257667839527, 60.974963307380676, 60.866262540221214, 59.500912204384804, 58.39240148663521, 59.79810185730457, 57.54540793597698, 50.31657323241234, 54.03562746942043, 55.26321239769459, 53.08292359113693, 47.38336242735386, 45.866871401667595, 46.33326977491379, 43.146984949707985, 46.6464451700449, 45.18461801111698, 45.62474459409714, 49.467550590634346, 55.010430961847305, 51.914744675159454, 56.6332782804966, 58.49339246749878, 57.44675002992153, 57.920292019844055, 61.04411579668522, 58.33484597504139, 56.24924808740616, 58.27972613275051, 53.48889380693436, 44.6243304759264, 44.47802312672138, 44.31316517293453, 45.058821961283684, 49.42570723593235, 50.390635058283806, 50.11451527476311, 52.30411358177662, 52.94070102274418, 52.68104575574398, 46.15561790764332, 44.351653307676315, 45.852173790335655, 46.45459346473217, 54.169334694743156, 59.97566632926464, 60.53569167852402, 58.39334383606911, 58.02551597356796, 57.07879677414894, 56.503997817635536, 57.34620362520218, 54.56568002700806, 55.703589767217636, 49.201401472091675, 45.901240557432175, 43.28080236911774, 45.117099434137344, 49.46592427790165, 49.28565055131912, 51.83001682162285, 45.552795454859734, 43.692495077848434, 45.83478972315788, 45.7756344974041, 47.13992089033127, 48.93572352826595, 49.400879368186, 49.81900133192539, 50.5327208340168, 53.09735141694546, 50.84684997797012, 58.524182215332985, 52.68249347805977, 54.06064532697201, 59.36398655176163, 57.53437712788582, 55.766495391726494, 54.80228193104267, 50.82370921969414, 55.15598975121975, 59.914056435227394, 61.05862721800804, 60.97816273570061, 60.67454382777214, 57.438341081142426, 60.78506089746952, 56.55169665813446, 62.24682345986366, 59.26375173032284, 55.58375559747219, 53.28702203929424, 57.260157242417336, 42.92726173996925, 21.240392848849297, 0.6553416315000504, 0.7643609878141433, 1.5058203670196235, 22.583958953619003, 68.13566386699677, 58.72662775218487, 61.610718593001366, 60.34428834915161, 68.33063900470734, 59.69388484954834, 65.90954571962357, 37.44711220264435, 49.630048871040344, 60.660476982593536, 31.579632349312305, 54.472767412662506, 45.26270382106304, 41.79273001849651, 5.117487972602248, 0.737687487853691, 0.13038813311140984, 0.12484313221648335, 0.14158237696392462, 0.13722129457164556, 0.008906796283554286, 0.018785102838592138, 0.10700078142690472, 0.007662059706490254, 0.03277316347521264, 0.11729656645911746, 0.14880193019052967, 0.171682461805176, 0.15860540413996205, 0.12941685476107523, 0.27372745564207435, 0.0926859253377188, 0.11655156151391566, 0.18487772875232622, 0.19809146033367142, 0.19876190170180053, 0.1865986207849346, 0.8335348509717733, 0.6116628565359861, 21.51242595165968, 80.21289020776749, 57.46514864265919, 46.69051140546799, 44.43004310131073, 64.94081050157547, 37.10882395505905, 56.52305759489536, 88.68413284420967, 70.06136253476143, 77.36026167869568, 61.40654414892197, 72.4535545706749, 62.73883245885372, 75.8135698735714, 9.601973611861467, 4.996176632121205, 1.3115718215703964, 5.347710968926549, 45.33911772072315, 56.615122854709625, 66.24841913580894, 61.561496034264565, 61.47405132651329, 61.6447077691555, 65.61968967318535, 61.87625594437122, 58.65658611059189, 56.42486326396465, 56.11779414117336, 59.17031854391098, 60.12554548680782, 58.37530620396137, 61.776389703154564, 53.285376727581024, 48.55830118060112, 57.4207404255867, 61.11157737672329, 66.35902360081673, 63.29340510070324, 63.53170171380043, 62.314843609929085, 62.448866218328476, 61.20134375989437, 59.258131831884384, 52.943672463297844, 57.1993301063776, 58.724173083901405, 57.20062583684921, 49.66856360435486, 48.571957647800446, 49.265785217285156, 45.970803424715996, 48.142390698194504, 48.02875779569149, 49.18970949947834, 54.40662816166878, 59.1777129471302, 56.64689674973488, 59.74670581519604, 62.94422663748264, 60.280911549925804, 61.59017689526081, 63.31135913729668, 60.66453516483307, 56.29030108451843, 62.015750259160995, 53.81420575082302, 45.380615293979645, 46.894488260149956, 45.699657574296, 48.35873208940029, 53.3879180252552, 53.154477551579475, 53.82425621151924, 54.009724259376526, 56.1690191924572, 54.22950826585293, 46.02458193898201, 47.205011397600174, 48.96502375602722, 48.37609715759754, 56.23430348932743, 61.239128932356834, 63.022844418883324, 61.6193213313818, 59.948547184467316, 59.47957254946232, 58.34024168550968, 58.30310247838497, 57.407410740852356, 57.20476381480694, 52.79889263212681, 49.59376081824303, 46.556503996253014, 48.02721127867699, 52.839185670018196, 50.13835519552231, 52.32051730155945, 47.09932766854763, 46.918616965413094, 47.55892440676689, 47.94000595808029, 49.239673018455505, 52.14995585381985, 51.6131092607975, 50.436358004808426, 53.64672973752022, 56.08382396399975, 53.34770858287811, 60.19083358347416, 47.29163534939289, 58.31192560493946, 61.15380831062794, 56.5090249478817, 56.790270656347275, 54.85070273280144, 53.39408129453659, 57.81904265284538, 62.053436636924744, 65.40780544281006, 61.58530555665493, 61.15979678928852, 57.800967022776604, 63.342658057808876, 56.32067285478115, 64.12389233708382, 61.73488073050976, 60.660184398293495, 54.95213828980923, 58.86658564209938, 47.55762867629528, 30.417324118316174, 2.9449892230331898, 0.7733559363987297, 5.25342995300889, 23.416361287236214, 76.70272216200829, 63.895714581012726, 66.1621105670929, 63.99425849318504, 73.60256731510162, 64.33693930506706, 71.47117048501968, 40.29950134456158, 55.89454472064972, 68.21696430444717, 35.0778329372406, 59.15342465043068, 53.07760767638683, 60.38821019232273, 9.580736551433802, 0.8713958412408829, 0.2595134871080518, 0.22885345184477046, 0.18457511061569676, 0.20836998301092535, 0.08944596833316609, 0.20050053106388077, 0.13637592899613082, 0.10379318948253058, 0.1252695851144381], [0.06457208743086085, 0.030302613231469877, 0.05389089397795033, 0.05973329200060107, 0.007467001960321795, 0.08860486268531531, 0.08759601681958884, 0.03263592181610875, 0.07215032062958926, 0.03248609704314731, 0.11377791073755361, 0.0074667923036031425, 0.19258861342677847, 0.14496394316665828, 2.72901997435838, 42.629293128848076, 50.3773357719183, 31.91357932984829, 20.19607588648796, 40.298350006341934, 49.26447808742523, 27.765184231102467, 58.946544751524925, 59.859073385596275, 59.58402134478092, 57.90606938302517, 56.38308450579643, 51.76163949072361, 56.83477006852627, 18.435723446309566, 0.23492931097280234, 0.6149290187750012, 0.21690077759558335, 18.1331342831254, 52.34982892870903, 65.40285810828209, 66.62486493587494, 62.77386657893658, 62.9489079862833, 60.39344631135464, 58.26735399663448, 58.677241802215576, 59.77141968905926, 55.99245026707649, 60.179031416773796, 58.28959420323372, 57.976236417889595, 53.379182294011116, 59.18997868895531, 51.938257813453674, 51.36793501675129, 52.74887591600418, 56.92615136504173, 58.0427860468626, 61.423958614468575, 60.17109364271164, 59.28351826965809, 60.67165218293667, 56.764546036720276, 50.86055964231491, 50.91655343770981, 50.97488410770893, 50.9149157255888, 47.30184160172939, 43.4574206918478, 42.412476763129234, 43.397509306669235, 43.572957292199135, 41.19312219321728, 43.29102002084255, 51.81069865822792, 53.626309633255005, 51.57619044184685, 52.758124619722366, 54.33839902281761, 53.82135696709156, 54.286307618021965, 55.97040005028248, 57.155282869935036, 55.18462501466274, 47.7066794782877, 41.04639686644077, 39.12368483841419, 40.549980103969574, 40.6348941475153, 44.21226158738136, 45.51215283572674, 47.27211579680443, 45.802411660552025, 47.539598643779755, 45.40768504142761, 46.95323310792446, 42.66202837228775, 42.27733701467514, 41.28593981266022, 41.656617522239685, 45.23808114230633, 50.620553120970726, 56.23746491968632, 52.06439584493637, 53.33615720272064, 52.93365240097046, 53.5278645157814, 55.356387197971344, 53.693607822060585, 52.068815007805824, 51.115126982331276, 44.942191019654274, 43.132424131035805, 41.2494807690382, 41.024867221713066, 43.90201583504677, 41.87220275402069, 40.5498319119215, 41.28731533885002, 42.88131840527058, 43.15380558371544, 45.534275248646736, 46.471266970038414, 43.043318912386894, 48.35338957607746, 48.583243042230606, 52.62619189918041, 49.67590481042862, 56.07410028576851, 54.453711435198784, 55.294218733906746, 61.09403371810913, 55.56004486978054, 59.81824077665806, 56.49775855243206, 50.742226392030716, 48.26833114027977, 53.02584305405617, 55.09605176746845, 53.42769809067249, 55.56176237761974, 55.43244771659374, 55.24091139435768, 57.724906504154205, 56.09628729522228, 57.19322383403778, 59.69713747501373, 61.56905762851238, 47.98919811844826, 29.118424616754055, 2.376619759015739, 0.04510205464612227, 0.12869579892139882, 0.6899387156590819, 24.74747736006975, 59.74408395588398, 56.54640734195709, 59.58526387810707, 58.19016493856907, 57.0465175062418, 55.638845041394234, 51.52397744357586, 29.00201976299286, 58.445264250040054, 32.49844774603844, 25.344835706055164, 50.42226456105709, 38.12797486782074, 19.253994338214397, 0.8841806114651263, 0.1473002092097886, 0.0861646662815474, 0.027928597846766934, 0.09692346982774325, 0.03193922697391827, 0.08769804728217423, 0.05568642751313746, 0.05439844877400901, 0.0742971534782555, 0.05242016508418601, 0.06311793069471605, 0.06927932234248146, 0.00702124626513978, 0.03881365184497554, 0.06133639035397209, 0.015136990587052424, 0.0500939254561672, 0.13519934291252866, 0.05833772782352753, 0.06432893016608432, 0.04596277896780521, 0.07215549339889549, 0.3167675086297095, 0.020834372953686398, 3.4397162636741996, 56.925809383392334, 57.27658376097679, 36.29654914140701, 32.34210513532162, 47.90810666978359, 50.71792669594288, 32.17123590409756, 67.67257511615753, 65.83731159567833, 65.62124758958817, 63.9833302795887, 63.812430649995804, 56.8559805303812, 62.49722622334957, 25.22640746086836, 1.435017460025847, 3.9601748110726476, 0.09418403205927461, 20.996111556887627, 54.9294763058424, 66.37999087572098, 67.02199682593346, 66.063581854105, 65.0447729229927, 63.301992639899254, 62.040129750967026, 60.42074404656887, 62.41522662341595, 57.599938809871674, 63.31651546061039, 58.09759430587292, 60.18656261265278, 53.37347500026226, 62.22913160920143, 54.05366130173206, 53.4851586073637, 53.831042647361755, 57.09956265985966, 60.48789784312248, 66.27330780029297, 62.201978266239166, 60.777328312397, 62.71222248673439, 60.307700112462044, 53.62337999045849, 52.37348645925522, 52.59739704430103, 52.834124341607094, 49.453958719968796, 46.12334243953228, 43.328907787799835, 44.368159621953964, 44.03277821838856, 42.64835670590401, 46.18892312049866, 52.60995917022228, 55.0382986664772, 55.171850100159645, 55.30135475099087, 55.188519805669785, 56.18885412812233, 57.70464979112148, 56.73045426607132, 59.4584608823061, 57.33135402202606, 50.22491455078125, 44.69578944146633, 42.90642745792866, 42.64319658279419, 43.171828016638756, 44.567018151283264, 48.04256625473499, 49.29401010274887, 49.741458892822266, 50.56289881467819, 48.72431807219982, 49.024889543652534, 46.68927267193794, 43.85030061006546, 42.718508541584015, 43.69588069617748, 48.55534873902798, 54.05836544930935, 57.24270477890968, 55.25097705423832, 56.16308391094208, 54.745653569698334, 56.44708827137947, 56.07934020459652, 58.34787927567959, 54.776644706726074, 53.84757936000824, 45.88314212858677, 45.58212228119373, 42.76949420571327, 42.63155400753021, 47.2864980250597, 44.410067573189735, 43.7899636477232, 43.263779282569885, 44.04287047684193, 46.17650158703327, 48.64799156785011, 49.26097087562084, 44.44895088672638, 50.59622682631016, 51.870188266038895, 55.143199637532234, 52.49449856579304, 58.50117824971676, 58.23828935623169, 57.21504606306553, 60.72045296430588, 55.501341819763184, 59.88253332674503, 56.54964096844196, 54.45678547024727, 50.00013381242752, 54.30693671107292, 57.07707166671753, 57.16248728334904, 57.713613510131836, 58.41018073260784, 57.68758110702038, 60.06907291710377, 59.01155926287174, 58.68696168065071, 61.23361922800541, 63.793591260910034, 50.92406563460827, 31.574561521410942, 2.437365436926484, 0.25884822593070567, 1.1974499328061938, 0.7401756418403238, 29.95095044374466, 62.498240768909454, 60.35852238535881, 62.83188946545124, 62.61346958577633, 63.55047270655632, 61.33550316095352, 57.00625106692314, 31.921900883316994, 62.7689990401268, 38.80561910569668, 28.37917048484087, 47.38612487912178, 45.992944836616516, 30.024221912026405, 1.0577554162591696, 0.07321701690671034, 0.06609510062844492, 0.0322632968891412, 0.03608981402067002, 0.0472150270070415, 0.08242574112955481, 0.08257637484348379, 0.025895729195326567, 0.030487380172417033, 0.06308399970293976, 0.23548378434497863, 0.14291508123278618, 0.264023132622242, 0.18764950189506635, 0.19207938137697056, 0.18379454937530681, 0.2927189850015566, 0.1864217224647291, 0.2253985614515841, 0.12250436513568275, 0.24092491425108165, 0.18470814800821245, 0.5555300123523921, 0.21172293199924752, 5.252272915095091, 69.13035169243813, 74.20828521251678, 44.669038876891136, 33.14380891621113, 59.071827828884125, 59.943143874406815, 35.58398097753525, 71.4013834297657, 72.08650946617126, 70.89034885168076, 70.03340363502502, 70.28877273201942, 60.78560046851635, 69.85387086868286, 28.685411252081394, 2.774902512319386, 2.534137456677854, 0.8403847552835941, 27.132430784404278, 59.65217448771, 67.00416058301926, 70.51318109035492, 68.0950440466404, 67.76741802692413, 64.60839673876762, 62.031682804226875, 64.11340489983559, 64.01616051793098, 59.55683000385761, 65.41252478957176, 59.33527149260044, 61.50120846927166, 56.20206981897354, 64.5572666823864, 54.96028125286102, 55.32452970743179, 55.04573106765747, 59.08702701330185, 62.773137018084526, 70.60177713632584, 63.81664842367172, 62.818704172968864, 65.8205696940422, 65.6215363740921, 55.986948162317276, 56.791752576828, 57.372414618730545, 55.049652457237244, 52.576235979795456, 49.3965096026659, 45.8031602203846, 47.63229846954346, 47.19080775976181, 45.296354815363884, 48.378681018948555, 56.17884546518326, 57.80187517404556, 58.7327416241169, 57.38845735788345, 59.92865525186062, 58.12214858829975, 58.33286628127098, 59.073606133461, 61.12154044210911, 59.699299558997154, 50.518551394343376, 44.4796684384346, 46.32625915110111, 44.10941630601883, 44.491136223077774, 48.16119208931923, 50.200060084462166, 52.1150167286396, 50.06481014192104, 52.0946080237627, 51.210517063736916, 50.80138921737671, 47.24672555923462, 46.451226845383644, 45.08407540619373, 42.75174155831337, 50.22515393793583, 52.63590417802334, 59.16420467197895, 54.404481276869774, 57.96893320977688, 58.19253221154213, 58.84929656982422, 58.98681499063969, 60.29277451336384, 57.32117056846619, 58.82799871265888, 50.30241139233112, 48.70744317770004, 44.36378985643387, 46.766081750392914, 49.266659170389175, 47.308377251029015, 45.65673507750034, 46.02783836424351, 47.26757504045963, 46.94836176931858, 50.29425323009491, 52.56488598883152, 45.368516743183136, 53.1364893168211, 53.50258447229862, 56.809034049510956, 52.44187518954277, 61.83200731873512, 55.90190872550011, 57.632301673293114, 64.99847620725632, 58.08035843074322, 60.694792941212654, 59.50733006000519, 56.153759211301804, 51.154941245913506, 57.0912829041481, 60.114218294620514, 58.999008536338806, 60.45070543885231, 59.70283716917038, 59.57553640007973, 61.59601338207722, 60.33771090209484, 61.034019738435745, 61.69211022555828, 64.91440951824188, 53.16251792013645, 39.15504455566406, 5.704454826191068, 0.14072840247536078, 2.1033113496378064, 3.7730498146265745, 32.794204875826836, 67.78475269675255, 64.93644073605537, 65.63675835728645, 69.7271628677845, 68.46336588263512, 67.64188796281815, 61.06849528849125, 38.65800082683563, 68.1566995382309, 46.384323835372925, 37.82779477536678, 59.008671417832375, 53.69167372584343, 48.08732405304909, 1.399976215325296, 0.2906691434327513, 0.15482812479604036, 0.12357897270703688, 0.18694058759137988, 0.09908524953061715, 0.22105582494987175, 0.15795379847986624, 0.11086400889325887, 0.28412711166311055, 0.17455105553381145], [0.08972647046903148, 0.03527630884491373, 0.025120285063167103, 0.10579716632491909, 0.041015281167346984, 0.04686218402639497, 0.1328790033585392, 0.03903110853570979, 0.10957774080452509, 0.08453258706140332, 0.0618988492351491, 0.08096029632724822, 0.220488972554449, 0.20017256116261706, 0.7644916058052331, 23.798026107251644, 53.037854209542274, 34.778150618076324, 29.363539963960648, 24.497891552746296, 56.193702667951584, 36.59998185932636, 40.08320935070515, 64.24500703811646, 55.65173774957657, 58.79986122250557, 56.07457146048546, 53.495186269283295, 57.11943559348583, 28.493793234229088, 0.6934388622175902, 1.7234548763372004, 0.08344758942257613, 7.7354448940604925, 42.450543120503426, 64.3781366944313, 68.14193353056908, 62.17831693589687, 61.959213092923164, 62.3151969909668, 66.63104340434074, 61.79947346448898, 62.2331365942955, 62.18822680413723, 58.657148480415344, 60.007637813687325, 59.09952454268932, 58.49474139511585, 61.329632475972176, 62.3452153801918, 57.22518391907215, 56.29320412874222, 55.44910982251167, 54.106622859835625, 52.876161485910416, 57.61697329580784, 60.60876935720444, 60.07156938314438, 57.46710553765297, 54.85086992383003, 52.29925364255905, 48.0297077447176, 50.12679621577263, 49.02423217892647, 43.24442312121391, 43.52231740951538, 40.416569262742996, 40.030916556715965, 43.0350049585104, 41.54237665235996, 50.44009320437908, 55.1714701205492, 52.04726256430149, 54.803091287612915, 56.32720090448856, 56.302384436130524, 56.11898347735405, 58.10934327542782, 52.548881247639656, 43.782664239406586, 40.64524099230766, 39.21874053776264, 40.78435152769089, 40.06005339324474, 40.07508158683777, 41.313815116882324, 46.87544368207455, 46.44209213554859, 47.42531977593899, 45.83915948867798, 47.37219102680683, 44.116081148386, 40.906803756952286, 40.66464655101299, 39.99515287578106, 39.705342426896095, 41.41585484147072, 41.95205166935921, 49.27248425781727, 57.962617948651314, 56.512630954384804, 54.15044590830803, 53.98015804588795, 54.130736365914345, 52.55502551794052, 51.65551878511906, 52.41664834320545, 47.615453973412514, 44.86482337117195, 42.35642597079277, 38.25909823179245, 37.77386426925659, 41.218159049749374, 38.761488273739815, 40.596337616443634, 43.58476705849171, 44.89223510026932, 46.37649245560169, 43.775478824973106, 46.80648498237133, 49.32192720472813, 52.20489710569382, 54.80490379035473, 54.35517892241478, 54.971988424658775, 55.175699293613434, 56.22307129204273, 57.98572450876236, 52.51680716872215, 51.88041351735592, 55.29286980628967, 55.86252383887768, 55.8573105186224, 50.730606615543365, 50.04611514508724, 49.30271543562412, 52.5669264793396, 50.16207732260227, 53.997177332639694, 54.10783879458904, 57.85441875457764, 56.98247194290161, 59.50261831283569, 54.523008316755295, 47.70603351294994, 13.186725955456495, 0.27457623509690166, 0.5904766777530313, 2.777831917628646, 1.5761832101270556, 44.793326407670975, 63.12017619609833, 56.74656920135021, 54.04834158718586, 58.72321553528309, 59.803505167365074, 60.920139849185944, 51.16547808051109, 50.69323942065239, 52.54444308578968, 21.231351234018803, 40.26998072862625, 22.075561434030533, 43.52114327251911, 8.09969762340188, 0.5027671717107296, 0.1120763887593057, 0.02150600732420571, 0.08353082870598882, 0.11732317245332524, 0.0540275196544826, 0.034220410816487856, 0.07552453214884736, 0.06584134549484588, 0.07724209935986437, 0.08592350539402105, 0.026412063598399982, 0.024097204805002548, 0.018242409205413423, 0.0332772709953133, 0.10237024747766554, 0.01199060448925593, 0.07149922705139033, 0.06133476876129862, 0.07108564299414866, 0.11646299361018464, 0.09058175113750622, 0.08495550733641721, 0.17103530903114006, 0.13777174550341442, 0.9070714737754315, 31.24580316245556, 66.24257504940033, 35.80575607717037, 37.14926518499851, 35.060764253139496, 62.1146285533905, 38.56809005141258, 46.40844114124775, 71.72309696674347, 63.25039140880108, 65.09396508336067, 61.45717643201351, 59.942543506622314, 63.10493901371956, 33.06191951036453, 0.9229425096418709, 4.974589515477419, 0.21244358707917854, 10.249381922185421, 45.29485009610653, 68.05652931332588, 70.64675152301788, 66.75617828965187, 66.3415901362896, 67.14035287499428, 67.005824893713, 64.43397089838982, 64.56950202584267, 64.61573034524918, 61.03639841079712, 60.631689727306366, 60.85992068052292, 62.68861435353756, 63.467116579413414, 64.74411025643349, 58.166374415159225, 59.007736667990685, 55.677709355950356, 55.89549086987972, 54.939359575510025, 59.56338845193386, 61.60679340362549, 60.78935466706753, 58.87493759393692, 56.908239126205444, 54.64553654193878, 51.75690494477749, 51.58920094370842, 49.44648452103138, 45.91561138629913, 43.83102424442768, 43.776728957891464, 43.76600593328476, 44.06594663858414, 43.40668201446533, 52.74300143122673, 55.770568773150444, 54.36267212033272, 56.535638719797134, 57.27828986942768, 56.8626643717289, 60.01984655857086, 59.41070504486561, 55.24435020983219, 47.40240700542927, 42.14886210858822, 43.255400732159615, 43.16674388945103, 42.068732008337975, 44.180791676044464, 42.923070564866066, 48.637181147933006, 47.167925387620926, 48.19217562675476, 48.87558035552502, 49.63684670627117, 47.47698560357094, 45.02438060939312, 41.67246267199516, 42.31232173740864, 41.516268253326416, 45.84457039833069, 45.964301973581314, 54.01254750788212, 60.62138468027115, 57.714951038360596, 59.04992960393429, 56.927637085318565, 56.98664031922817, 55.566489323973656, 54.18198801577091, 56.37866914272308, 51.060725301504135, 47.81364753842354, 44.343035370111465, 40.33762089908123, 40.39473183453083, 43.79667028784752, 41.41730256378651, 42.98966959118843, 45.56277371942997, 47.218287885189056, 48.58876794576645, 46.93260781466961, 47.42786563932896, 51.67256087064743, 55.516829788684845, 55.408284813165665, 56.049994379282, 56.85951054096222, 58.85150045156479, 58.746124505996704, 58.907406851649284, 54.74834382534027, 52.1845567971468, 58.18422965705395, 55.818864181637764, 58.11603471636772, 52.171838879585266, 52.81298987567425, 51.90740346908569, 55.39213947951794, 52.96959847211838, 57.39350348711014, 56.38120360672474, 59.98760148882866, 60.47945089638233, 62.30693243443966, 57.117113918066025, 49.14016015827656, 15.667859818786383, 0.7397646701429039, 0.9005333902314305, 3.347076759673655, 2.3326582554727793, 50.41262447834015, 64.19801115989685, 62.86836750805378, 58.01484614610672, 65.09826645255089, 66.28615111112595, 67.05194681882858, 56.88297428190708, 54.66113470494747, 60.55706933140755, 26.26350101083517, 41.27805903553963, 23.5845098644495, 54.728185907006264, 10.200788229703903, 0.4994989314582199, 0.08011729820282198, 0.07254254567669705, 0.02226796106697293, 0.07944828917970881, 0.11536294521647505, 0.04626992049452383, 0.04852466532611288, 0.03452849116001744, 0.024260028294520453, 0.023188491359178443, 0.10721302081947215, 0.12599353533005342, 0.1242364190693479, 0.11945761885726824, 0.1576847254182212, 0.13313654344528913, 0.1253113234997727, 0.12877494154963642, 0.2507291897200048, 0.21922873158473521, 0.23993628448806703, 0.1868157583521679, 0.41496590652968735, 0.2130373497493565, 1.3574080495163798, 40.90925842523575, 79.50205475091934, 54.28655460476875, 45.82138404250145, 40.9495210647583, 69.1455888748169, 46.35571137070656, 53.26226256787777, 78.69948461651802, 68.5964423418045, 71.57935068011284, 67.22754299640656, 67.956473082304, 68.63374873995781, 39.26770471036434, 1.1539934459142387, 7.540356712415814, 0.2031608484685421, 12.771569732576609, 51.97133503854275, 67.85933509469032, 74.24458086490631, 69.85817223787308, 69.0510119497776, 68.22365194559097, 70.07989034056664, 67.66487672924995, 67.1534925699234, 68.35329338908195, 64.0003077685833, 64.61559355258942, 65.6989686191082, 62.05686405301094, 64.63379457592964, 66.50528535246849, 59.73325073719025, 62.051327750086784, 60.12642703950405, 57.127969935536385, 56.02151110768318, 60.99663354456425, 65.13064071536064, 64.0030588209629, 60.85980288684368, 57.5028920173645, 58.34133982658386, 54.18021351099014, 54.63247664272785, 53.93990680575371, 47.26323567330837, 46.06681667268276, 46.09436519443989, 45.331419333815575, 48.11763122677803, 46.181255131959915, 55.137841925024986, 60.07188096642494, 57.00171411037445, 59.31893616914749, 58.68286930024624, 59.08366039395332, 61.20981350541115, 62.30416618287563, 55.319316387176514, 47.31980703771114, 46.70559659600258, 44.69650760293007, 45.065057426691055, 43.7762463837862, 47.489160150289536, 46.64270617067814, 50.42101822793484, 51.00128509104252, 53.12505953013897, 51.38986364006996, 53.23971837759018, 50.00924572348595, 46.0778246819973, 43.447845205664635, 44.867407232522964, 44.38750818371773, 47.69635923206806, 46.04932241141796, 53.048607632517815, 61.42445258796215, 59.8938225209713, 60.34854792058468, 60.12871451675892, 59.97816659510136, 59.18752022087574, 56.10487103462219, 59.92679715156555, 53.0479084700346, 49.435985684394836, 47.122810408473015, 43.548045828938484, 41.88709795475006, 46.17243580520153, 44.07711423933506, 44.553513675928116, 48.31606797873974, 49.87300783395767, 52.004723846912384, 49.93293061852455, 49.992462024092674, 53.77223700284958, 56.86973199248314, 58.55512775480747, 57.872141003608704, 56.1789670586586, 59.44571256637573, 59.17545586824417, 61.631537675857544, 54.76322382688522, 54.66333098709583, 58.90209473669529, 57.735865116119385, 60.15110291540623, 54.539431035518646, 53.823256865143776, 54.490501061081886, 58.9613601565361, 53.87584984302521, 57.78444550931454, 58.45706261694431, 62.665124014019966, 61.052448749542236, 64.74842682480812, 60.32199114561081, 52.98722192645073, 21.530393287539482, 0.9918136952910572, 2.0764204300940037, 9.764313250780106, 3.450860590673983, 55.25158882141113, 69.87891152501106, 68.05490300059319, 60.94225086271763, 70.0915253162384, 69.05816316604614, 74.46596458554268, 61.50062330067158, 62.30888552963734, 62.9353579133749, 34.46252815425396, 54.812507182359695, 32.84874714910984, 72.32082769274712, 20.016993395984173, 0.6216630293056369, 0.25930423114914447, 0.11312760383589193, 0.15958704287186265, 0.229197793523781, 0.23117077827919275, 0.1343678851844743, 0.1510024574236013, 0.22502695326693356, 0.17763531737728044, 0.12552764470456168], [0.03129543983959593, 0.021169302344787866, 0.03446260700002313, 0.04683340353949461, 0.031035495194373652, 0.0721277816046495, 0.10968607952236198, 0.18393370206467807, 0.09878669094177894, 0.029905081828474067, 0.1025629832292907, 0.13392587687121704, 0.07879796001361683, 0.4806838551303372, 0.2567866287427023, 8.785478174686432, 46.88529275357723, 38.181703984737396, 33.1942930072546, 22.45718065649271, 36.29347890615463, 60.34431874752045, 34.264300391077995, 62.248506769537926, 57.11114443838596, 62.15041123330593, 55.97510799765587, 57.5032339990139, 52.65228129923344, 43.25581111013889, 2.4274204205721617, 5.611661430448294, 0.732327519217506, 2.154365172609687, 33.27710196375847, 61.96838200092316, 65.99469155073166, 62.59731285274029, 61.955793276429176, 62.3063700646162, 59.38991256058216, 60.87263099849224, 60.89323349297047, 59.21049378812313, 61.08557917177677, 60.969620794057846, 62.35877685248852, 58.68478439748287, 57.21625059843063, 60.55181421339512, 60.98444379866123, 61.18197239935398, 62.08037719130516, 58.96569952368736, 57.081099450588226, 55.573511347174644, 58.44333775341511, 54.68776747584343, 57.89052441716194, 55.650396421551704, 53.4945061057806, 51.16858251392841, 47.92891055345535, 48.836776837706566, 45.58260105550289, 42.644401118159294, 41.29188269376755, 41.315521225333214, 40.31646743416786, 43.305687233805656, 47.174715623259544, 56.30236543715, 55.58404438197613, 53.24106350541115, 54.935046806931496, 55.62446281313896, 56.663862839341164, 51.14830680191517, 47.877556309103966, 42.827653884887695, 40.95797561109066, 40.01254454255104, 39.31843958795071, 40.78720137476921, 40.518954768776894, 42.447309494018555, 44.96474660933018, 45.643564984202385, 44.15049210190773, 44.31443050503731, 44.17064242064953, 43.51022645831108, 40.260895416140556, 40.41403479874134, 40.8956703543663, 39.184914752840996, 39.897186532616615, 40.44781878590584, 41.859085857868195, 46.922211572527885, 53.15687142312527, 55.294458121061325, 52.53623552620411, 54.52783405780792, 52.58664362132549, 54.866240099072456, 53.16137418150902, 51.016966849565506, 47.14971676468849, 41.558464989066124, 37.174530029296875, 38.69462326169014, 39.11461092531681, 38.941765800118446, 40.83493061363697, 41.793193593621254, 46.59176230430603, 45.5095461755991, 44.02246177196503, 46.90733157098293, 51.20301626622677, 53.22063200175762, 54.123011380434036, 55.51731996238232, 55.19551143050194, 55.89313879609108, 55.319513976573944, 57.34659880399704, 52.0278912037611, 54.30600196123123, 55.79596661031246, 56.22430622577667, 57.06475272774696, 55.63802048563957, 55.58076895773411, 54.231503158807755, 54.588934779167175, 53.37443634867668, 54.668426513671875, 57.03957907855511, 59.2744405567646, 57.557278499007225, 60.91474033892155, 61.499540358781815, 38.61539751291275, 11.294001918286085, 2.437217482365668, 0.5545755510684103, 1.1465155659243464, 3.0568649573251605, 44.32563990354538, 54.54818956553936, 53.402676433324814, 58.323780968785286, 60.64626954495907, 50.985512137413025, 59.48613479733467, 49.260321110486984, 61.015187948942184, 28.371618390083313, 25.010199062526226, 36.20687775313854, 24.628612138330936, 36.89650274813175, 0.5519802903290838, 0.3912562772165984, 0.06858026375994086, 0.13654599955771118, 0.0973468873417005, 0.021673198352800682, 0.05770359974121675, 0.04618453640432563, 0.07213822362245992, 0.09072252913028933, 0.05043382909207139, 0.06779527189792134, 0.05575355848122854, 0.06646163994446397, 0.011465988645795733, 0.04479867209738586, 0.02607030088256579, 0.07108061123290099, 0.05144870490767062, 0.11531770389410667, 0.1482213629060425, 0.0285815412280499, 0.04983949496818241, 0.057673179107951, 0.06142823112895712, 0.5186076904647052, 0.15548422787105665, 12.443048860877752, 63.23015749454498, 40.67813582718372, 39.92540001869202, 35.31752787530422, 41.34167142212391, 66.74692198634148, 39.32109944522381, 69.44249734282494, 60.522080808877945, 69.40006121993065, 60.720946937799454, 63.37136931717396, 59.38344530761242, 48.40758606791496, 1.9883038708940148, 4.179984228685498, 1.0091772791929543, 1.871794166509062, 36.771941632032394, 65.82595020532608, 70.38603231310844, 67.53678560256958, 64.49590757489204, 64.0957510471344, 64.21272397041321, 63.10095302760601, 64.93165299296379, 62.891534864902496, 61.949755400419235, 63.17860946059227, 63.69349703192711, 62.300104200839996, 61.34580820798874, 63.74981760978699, 61.33684828877449, 64.39877718687057, 63.52750673890114, 61.72403231263161, 60.62755934894085, 58.25761891901493, 60.663494020700455, 58.64310443401337, 59.56927053630352, 58.28509904444218, 55.47595918178558, 52.282903119921684, 51.1790319532156, 51.37036308646202, 47.83884398639202, 42.596808671951294, 43.38766783475876, 43.402224853634834, 43.43414694070816, 44.549482092261314, 49.99854929745197, 56.907870545983315, 56.5253184735775, 55.348867401480675, 56.56275786459446, 57.173898071050644, 58.1966207921505, 54.411180317401886, 49.19243395328522, 45.29803432524204, 43.01907621324062, 41.554847583174706, 42.715841084718704, 43.140202313661575, 42.62738563120365, 45.311937779188156, 47.38424398005009, 47.8468881547451, 46.45655795931816, 47.599350437521935, 48.547087982296944, 47.211991623044014, 45.16026511788368, 42.10372433066368, 42.95944221317768, 42.6905420422554, 43.685739040374756, 43.51645052433014, 43.58555741608143, 50.34553527832031, 55.73265440762043, 56.67479485273361, 56.869025230407715, 55.31257554888725, 55.49954451620579, 54.833208471536636, 55.78129939734936, 53.53817716240883, 49.61446970701218, 44.43313233554363, 40.67593574523926, 40.74336692690849, 41.41790673136711, 41.25912085175514, 43.43226984143257, 44.21430967748165, 48.73865470290184, 46.84310361742973, 44.77588154375553, 49.32947359979153, 52.94261232018471, 56.1141387373209, 55.56957095861435, 57.79606528580189, 56.750764176249504, 57.94901467859745, 57.286721616983414, 56.35396666824818, 51.909128576517105, 54.88470710813999, 57.42351807653904, 58.94141882658005, 58.58384281396866, 58.340511471033096, 56.188660338521004, 56.068780571222305, 56.629710271954536, 57.16171592473984, 57.7870749682188, 58.09475585818291, 60.52935741841793, 59.53174754977226, 63.539449498057365, 62.37287409603596, 45.287695080041885, 15.154229030013084, 3.8407234707847238, 1.0123122297227383, 0.6702107086312026, 4.781600246205926, 48.68049882352352, 58.47135365009308, 59.3170552700758, 64.65678334236145, 67.48434841632843, 57.576444670557976, 66.03543296456337, 54.758774265646935, 67.74959698319435, 31.658877097070217, 30.914687030017376, 42.715377509593964, 28.65871198475361, 46.584185510873795, 1.2772580003365874, 0.13400804746197537, 0.011235739184485283, 0.08813985521555878, 0.03379474830580875, 0.017919194615387823, 0.04519984002399724, 0.06825650183600374, 0.054113278529257514, 0.03341336974699516, 0.09997653920436278, 0.1007515714445617, 0.09101601142901927, 0.16975621751043946, 0.08395052806008607, 0.2205084019806236, 0.10728851208114065, 0.17313603224465623, 0.18709514726651832, 0.2711878262925893, 0.30766189098358154, 0.21046502137323841, 0.20309096784330904, 0.17387025378411636, 0.24463865091092885, 0.9312274307012558, 0.5407705355901271, 18.831534907221794, 78.2799719274044, 59.61016774177551, 46.94860875606537, 41.740045845508575, 51.387944743037224, 72.40437000989914, 42.700071930885315, 75.90727284550667, 68.31209599971771, 74.98715981841087, 64.58451882004738, 70.30595541000366, 64.07050520181656, 57.349235862493515, 4.648061636835337, 11.195852234959602, 0.9775426110718399, 3.272966961376369, 44.05737429857254, 67.99919798970222, 72.65877395868301, 68.2675775885582, 68.16885888576508, 67.82397419214249, 65.28025388717651, 65.89734077453613, 67.4565415084362, 64.87462565302849, 65.69871783256531, 66.83129265904427, 65.69610357284546, 64.52161699533463, 62.37358085811138, 64.64278489351273, 64.88794013857841, 66.20392352342606, 67.24938422441483, 63.99460047483444, 62.19498284161091, 59.15014162659645, 61.84887081384659, 61.028684824705124, 61.44264221191406, 62.877521216869354, 59.354373067617416, 56.07570379972458, 53.122912645339966, 55.110263004899025, 51.25616021454334, 44.41060334444046, 45.89662380516529, 46.81633785367012, 44.154261499643326, 48.72600518167019, 52.08304904401302, 59.755373150110245, 59.26255099475384, 57.058692052960396, 58.07390257716179, 58.518908098340034, 59.49367739260197, 54.15492586791515, 50.26761285960674, 47.63553969562054, 45.3834043443203, 42.804201543331146, 44.98698301613331, 46.21264524757862, 45.94227455556393, 47.02042870223522, 47.85589747130871, 52.29254700243473, 48.85015971958637, 49.232419207692146, 49.73160982131958, 47.412411868572235, 47.00791597366333, 44.00715999305248, 44.95711661875248, 42.93816335499287, 45.18394164741039, 46.38841241598129, 44.941659048199654, 49.66275751590729, 57.146569937467575, 60.221991911530495, 58.852997571229935, 59.588835686445236, 58.00567343831062, 59.57643695175648, 58.27797442674637, 56.68057054281235, 51.881010085344315, 46.69225551187992, 40.464708879590034, 42.50893838703632, 43.29442843794823, 44.46119002997875, 44.24321852624416, 46.76473282277584, 51.7039205878973, 49.37153734266758, 47.322596088051796, 50.748648047447205, 55.56735947728157, 56.76076143980026, 57.153325974941254, 61.77912935614586, 58.856178000569344, 59.02177311480045, 57.60065697133541, 58.946278765797615, 54.850254356861115, 57.563548162579536, 58.580229207873344, 62.03575238585472, 61.496299132704735, 59.88263212144375, 59.30063635110855, 58.70973765850067, 58.587578013539314, 58.577314764261246, 58.540673330426216, 63.674380257725716, 63.48541259765625, 61.043872609734535, 62.253720089793205, 61.774280816316605, 47.42919936776161, 18.379076085984707, 4.883212493732572, 2.9525902401655912, 3.4506584890186787, 4.380876123905182, 52.98189081251621, 63.619515001773834, 62.86739856004715, 68.71397763490677, 69.23557564616203, 62.9928982257843, 69.78940352797508, 60.75197987258434, 73.22827979922295, 39.64522585272789, 41.83281786739826, 52.13971920311451, 37.608683332800865, 62.934700548648834, 4.098537499085069, 0.6258739158511162, 0.23680295184021816, 0.19744574732612818, 0.12966842798050493, 0.22766944428440183, 0.2281158312689513, 0.1327993263839744, 0.20755966164870188, 0.19664666207972914, 0.2013759090914391, 0.18989825388416648], [0.023175689311756287, 0.08605203795013949, 0.04920417944958899, 0.07907062507001683, 0.02213260260759853, 0.06308483832981437, 0.055180078707053326, 0.05593319161562249, 0.02698738575418247, 0.08665374902193435, 0.07378415873972699, 0.07640730196726508, 0.02074169911793433, 0.04675387870520353, 0.07920471631223336, 1.636937556322664, 29.448695294559002, 43.76131698489189, 28.879176154732704, 21.68855220079422, 32.81497076153755, 58.53712432086468, 46.08531408011913, 46.00838340818882, 67.18227982521057, 58.66719514131546, 61.93055123090744, 54.01182934641838, 56.62828914821148, 50.021781250834465, 7.0282976143062115, 2.4810424307361245, 3.66628504358232, 1.0074784141033888, 23.728911615908146, 63.53961668908596, 67.59585723280907, 61.09612360596657, 57.02698275446892, 59.42425511777401, 61.084082052111626, 62.536253929138184, 62.51590222120285, 62.52779558300972, 62.17101752758026, 61.18311993777752, 59.139194414019585, 61.41882508993149, 59.72019083797932, 59.82979975640774, 56.57011806964874, 58.813312500715256, 56.80128626525402, 58.11439320445061, 60.32488279044628, 60.60641348361969, 57.24799029529095, 59.25594314932823, 56.43361799418926, 57.62307956814766, 55.299200266599655, 52.828371450304985, 49.138853028416634, 48.00057090818882, 46.410375237464905, 44.283762350678444, 42.7522811293602, 39.56421419978142, 40.155120491981506, 41.00092090666294, 43.99577960371971, 45.4768755286932, 52.34162516891956, 53.23395028710365, 54.43268336355686, 55.639411211013794, 53.48226696252823, 46.94469876587391, 42.79665134847164, 39.98332791030407, 39.2170762270689, 41.03279359638691, 39.029780477285385, 39.76117663085461, 39.87944908440113, 42.39985004067421, 46.510746851563454, 41.14874057471752, 38.58922831714153, 44.99734506011009, 43.383187875151634, 42.16152682900429, 40.30222199857235, 39.146779999136925, 39.86564062535763, 38.24050962924957, 38.083266466856, 39.67143304646015, 41.334550604224205, 43.06163772940636, 48.152912333607674, 54.84168581664562, 53.88987489044666, 52.93391838669777, 54.756228402256966, 52.21097677946091, 54.83959212899208, 50.79975910484791, 46.87225945293903, 40.93208760023117, 37.561090886592865, 37.33794026076794, 38.188802003860474, 39.09744344651699, 39.79480102658272, 42.8562967479229, 45.686054304242134, 45.71999408304691, 44.28323797881603, 47.22883611917496, 49.14567746222019, 54.2463755607605, 54.4353736191988, 53.564429953694344, 54.504613503813744, 57.95768201351166, 56.12044259905815, 57.17653512954712, 58.526420295238495, 55.778107568621635, 57.22650244832039, 57.40349315106869, 55.963947996497154, 57.36975856125355, 58.51903349161148, 56.14440031349659, 58.59546639025211, 59.58484970033169, 58.703164011240005, 57.900312691926956, 59.214312583208084, 62.065846771001816, 61.56543642282486, 52.01078452169895, 40.65135106444359, 12.378532122820616, 1.9913843180984259, 0.39771254640072584, 0.18971912912093103, 6.335218129679561, 46.740554720163345, 60.94279423356056, 54.37878705561161, 58.097875490784645, 45.37060283124447, 56.768095046281815, 51.848708018660545, 50.015994161367416, 54.58478540182114, 24.385571479797363, 35.254949033260345, 21.502027809619904, 34.077164232730865, 25.847410038113594, 0.32559713639784604, 0.08855140578816645, 0.09776115417480469, 0.02675984698726097, 0.03214758122339845, 0.1117118309775833, 0.0573658334906213, 0.08296833271742798, 0.030882226856192574, 0.01934915919264313, 0.048716670062276535, 0.03904529468854889, 0.084959804371465, 0.047264127497328445, 0.010956579408230027, 0.056153405384975486, 0.019213624473195523, 0.09781045504496433, 0.026475227787159383, 0.07084555079927668, 0.040659373116795905, 0.06279894078033976, 0.0394093626528047, 0.11486407354823314, 0.06517338289995678, 0.13337242766283453, 0.04499595350353047, 1.6078066569752991, 40.97956225275993, 51.852678805589676, 29.43228207528591, 34.036578610539436, 39.72569413483143, 66.89517483115196, 48.089318946003914, 54.02631036937237, 74.90782007575035, 65.24031803011894, 67.01382726430893, 61.02286733686924, 61.53865925967693, 53.434089347720146, 6.275751795619726, 3.5070526879280806, 4.7006042674183846, 1.2963347579352558, 26.597163006663322, 66.48297294974327, 69.82662633061409, 63.84379416704178, 61.825646460056305, 62.234116941690445, 65.7925195991993, 64.54638406634331, 64.8580053448677, 65.72815105319023, 64.36118200421333, 64.3428897857666, 62.023372650146484, 63.433640375733376, 62.85118103027344, 63.81106272339821, 58.822230622172356, 60.22400960326195, 60.17721891403198, 62.1697673946619, 61.29531271755695, 62.49423958361149, 60.137689635157585, 60.79755462706089, 59.36171427369118, 58.53697992861271, 56.8757014721632, 55.261985063552856, 52.07630440592766, 49.62217569351196, 47.187612131237984, 45.24593912065029, 42.871104553341866, 42.66989015042782, 43.85610669851303, 42.94243432581425, 44.68873701989651, 47.75496728718281, 54.305576384067535, 55.73669359087944, 56.44579254090786, 56.985048204660416, 55.23734338581562, 48.939960300922394, 45.564244240522385, 42.412100583314896, 42.711725905537605, 41.72559142112732, 41.69949062168598, 42.03628934919834, 43.51718008518219, 44.853173196315765, 47.64595873653889, 45.3166077286005, 41.61720223724842, 45.86257003247738, 47.901240438222885, 44.3427237868309, 43.691013157367706, 43.17525163292885, 41.37420907616615, 40.87459668517113, 40.72138510644436, 41.41805872321129, 43.87042053043842, 44.78869065642357, 52.09036745131016, 58.739634454250336, 57.662624046206474, 55.971855372190475, 57.344698905944824, 53.859837502241135, 54.93670731782913, 53.48876841366291, 50.22098556160927, 42.929465621709824, 41.94150723516941, 39.716190844774246, 40.07875598967075, 41.299273297190666, 42.813153862953186, 46.04632057249546, 47.65246778726578, 48.90533275902271, 46.13607555627823, 48.12798947095871, 51.36557154357433, 57.40485727787018, 57.083044946193695, 55.55325463414192, 57.1476186811924, 58.090063109993935, 57.311686277389526, 59.16459605097771, 58.74501496553421, 58.63321736454964, 58.82065370678902, 58.055085986852646, 58.4961549192667, 58.97992596030235, 61.76481172442436, 59.010411724448204, 60.16109637916088, 63.12011159956455, 60.66864654421806, 60.67963555455208, 62.142465859651566, 62.76791229844093, 61.41248323023319, 53.41377943754196, 43.32223914563656, 14.433165472000837, 2.1558829536661506, 0.8917370997369289, 0.3965272178174928, 5.876725232228637, 50.93193121254444, 67.63799697160721, 57.99419045448303, 61.005061492323875, 51.60930186510086, 62.42765195667744, 57.05357752740383, 55.62776483595371, 63.003267869353294, 26.472767181694508, 43.60909715294838, 27.758880369365215, 40.63785798847675, 33.18977504968643, 0.4310380050446838, 0.03554684764822014, 0.12281703937333077, 0.0670156383421272, 0.05970327212708071, 0.1293990877456963, 0.017195476320921443, 0.07565234482171945, 0.05499237471667584, 0.029684044275199994, 0.05834989533468615, 0.060301428311504424, 0.28493842750322074, 0.14120772597379982, 0.15860908519243822, 0.1595068909227848, 0.1430730547872372, 0.17776146763935685, 0.12292157829506323, 0.34672616980969906, 0.18894774082582444, 0.23791975050698966, 0.16435845871455967, 0.28375398949719965, 0.19034744618693367, 0.47267002577427775, 0.20474750082939863, 3.263805415481329, 55.192817375063896, 69.36856091022491, 42.7754332870245, 39.55466151237488, 46.8961563706398, 74.42691028118134, 55.263132601976395, 61.64867855608463, 80.65046712756157, 71.17570593953133, 72.00986757874489, 66.0139337182045, 66.49099051952362, 58.93042981624603, 10.08552711457014, 9.643364790827036, 9.055141154676676, 2.51301652751863, 31.69207401573658, 71.57127231359482, 74.10232409834862, 67.68011391162872, 63.306461200118065, 66.20930403470993, 70.91038137674332, 66.69794261455536, 66.55079931020737, 67.8955927491188, 66.20921283960342, 66.1984746158123, 63.770473301410675, 64.23695906996727, 65.82230240106583, 65.7789771258831, 61.09558783471584, 64.36913877725601, 63.0075578391552, 64.32303965091705, 66.25749304890633, 64.32813137769699, 61.90234914422035, 64.9073114991188, 61.57449893653393, 61.291832104325294, 61.2455277889967, 57.29638069868088, 54.352636858820915, 52.09158718585968, 49.79606956243515, 47.8497190028429, 48.05726766586304, 45.43355405330658, 45.47505922615528, 46.03067301213741, 47.52442605793476, 48.73649261891842, 55.70222184062004, 56.80260859429836, 58.61687824130058, 58.91115345060825, 55.08227750658989, 49.3476290255785, 47.8555478900671, 45.263015404343605, 43.19680407643318, 43.96662376821041, 43.48306551575661, 44.58915576338768, 46.06460139155388, 47.789230048656464, 49.46653224527836, 46.4098546653986, 42.21591331064701, 49.23707775771618, 49.429697021842, 45.570057928562164, 44.97250199317932, 44.64531295001507, 45.50909399986267, 43.00837978720665, 42.108702063560486, 44.93662051856518, 45.26197046041489, 45.53058944642544, 51.549629867076874, 60.2173675596714, 60.16863137483597, 59.68669943511486, 59.75937433540821, 56.815824285149574, 60.905332043766975, 58.296665623784065, 52.58359618484974, 44.82286222279072, 43.68422672152519, 40.18614962697029, 42.25514620542526, 43.665999099612236, 45.639199018478394, 47.37980581820011, 49.91722986102104, 51.21378108859062, 49.266503378748894, 50.58304153382778, 52.679487839341164, 58.33613410592079, 59.78352963924408, 57.95583911240101, 57.02281817793846, 60.342954620718956, 59.573108330368996, 60.74232839047909, 58.59954357147217, 60.76687887310982, 61.41639702022076, 59.73399929702282, 59.11830693483353, 60.66537871956825, 63.50436218082905, 61.77250251173973, 64.63526129722595, 63.05584944784641, 63.86514142155647, 61.630568727850914, 63.744258508086205, 64.4658587872982, 63.97142171859741, 57.283807173371315, 46.11513487994671, 15.48342626541853, 4.899894073605537, 2.4674619594588876, 1.2997241760604084, 8.793734181672335, 54.45412561297417, 74.60262045264244, 61.296600848436356, 68.15854623913765, 55.9597872197628, 68.76139149069786, 60.629588440060616, 61.890440583229065, 67.41140753030777, 38.27214293181896, 54.007383584976196, 36.23370811343193, 51.12453907728195, 47.78772912919521, 0.3802916390122846, 0.13484277063980699, 0.17554657242726535, 0.19855834543704987, 0.26816194178536534, 0.20373494422528893, 0.2172619363409467, 0.15763016272103414, 0.11783047491917387, 0.09387955855345353, 0.20858139119809493, 0.19381762482225895], [0.0357249296939699, 0.05323516197677236, 0.06534355736221187, 0.056947952398331836, 0.07902942845248617, 0.020935388529323973, 0.019293542645755224, 0.017163493466796353, 0.03081429622397991, 0.023865446928539313, 0.042040079497382976, 0.042212031403323635, 0.04272252139344346, 0.02882568925997475, 0.28409371501766145, 0.22971943428274244, 11.475883908569813, 45.32264180481434, 27.69340418279171, 25.772286169230938, 25.374616608023643, 47.44518131017685, 61.33132718503475, 61.528361812233925, 63.07271674275398, 62.21594251692295, 61.75668016076088, 58.990861773490906, 51.010871976614, 49.23097908496857, 5.228824848309159, 2.6726720854640007, 5.475947437807918, 1.034950464963913, 26.446077413856983, 60.97251623868942, 70.57920634746552, 61.34705074131489, 57.49880723655224, 60.60781940817833, 59.133414924144745, 65.33237189054489, 62.715433314442635, 60.912148877978325, 60.72530910372734, 62.56295129656792, 60.02263180911541, 60.89470401406288, 59.25263732671738, 57.16161713004112, 59.214331582188606, 55.4131181538105, 54.870423674583435, 58.94636996090412, 56.94041199982166, 58.91233518719673, 59.63925518095493, 60.675440579652786, 57.29019083082676, 57.34268121421337, 57.562130838632584, 55.181436985731125, 49.463021233677864, 49.218758940696716, 46.46540008485317, 43.58952820301056, 41.419514045119286, 42.20263682305813, 39.659277498722076, 43.31166431307793, 41.91486306488514, 46.77381433546543, 52.82886542379856, 55.07630802690983, 56.151787117123604, 56.41389325261116, 50.20373448729515, 43.04433725774288, 40.924142226576805, 39.4689305126667, 41.237161830067635, 38.98047812283039, 38.91610577702522, 39.08122971653938, 40.47160170972347, 42.09037944674492, 46.95460483431816, 37.44297042489052, 31.321740187704563, 44.53989140689373, 44.67978850007057, 41.47122547030449, 41.29232347011566, 38.66270497441292, 38.99637646973133, 39.51824426651001, 41.31529703736305, 39.14439372718334, 37.87749990820885, 39.35935579240322, 42.660892233252525, 49.55201245844364, 48.84018525481224, 49.70316834747791, 53.00671108067036, 54.90047626197338, 53.737031891942024, 48.82702276110649, 45.68606190383434, 39.92839425802231, 39.59213510155678, 38.13453711569309, 38.27104099094868, 38.88948440551758, 39.234711080789566, 42.75212153792381, 43.60673367977142, 43.36960360407829, 44.64280508458614, 44.06685099005699, 50.145590007305145, 53.12985107302666, 53.13506059348583, 52.69939497113228, 54.45659168064594, 54.618698582053185, 53.69871474802494, 55.360950753092766, 53.05979423224926, 54.50077570974827, 54.21504624187946, 55.105281472206116, 55.289886966347694, 55.47913961112499, 54.285714849829674, 56.46167188882828, 54.52109321951866, 53.900647312402725, 58.25695015490055, 60.127870962023735, 59.066983088850975, 57.91177287697792, 56.879075691103935, 56.01238399744034, 40.742690563201904, 14.008272271603346, 1.0730529204010963, 0.5165032565128058, 0.2320080396020785, 4.590582121163607, 45.22805728018284, 60.0705586373806, 56.58657118678093, 49.47415083646774, 57.37200424075127, 59.40823897719383, 59.4575185328722, 60.41645027697086, 46.582506000995636, 27.0563455671072, 36.57450422644615, 26.41347326338291, 42.34518237411976, 9.206902161240578, 0.3916879399912432, 0.20387691707583144, 0.07683342832024209, 0.07109687168849632, 0.08124787855194882, 0.026177661820838694, 0.04209986320347525, 0.00852372284498415, 0.09234846336767077, 0.056162804685300216, 0.055005265821819194, 0.015027193549030926, 0.02771297611616319, 0.08690283604664728, 0.03264266793848947, 0.017698680276225787, 0.07432992671965621, 0.04216411092784256, 0.08644953966722824, 0.04559823602903634, 0.08887400254025124, 0.03579140015062876, 0.04161777891567908, 0.06547635726747103, 0.029526343460020144, 0.00771169593463128, 0.32257692189887166, 0.10876413914957084, 18.33663996309042, 61.32563129067421, 29.193903766572475, 34.05852623283863, 35.74977748095989, 53.5756279528141, 70.3637047111988, 67.95785620808601, 67.98456117510796, 68.4196226298809, 67.96329751610756, 63.13893958926201, 57.84545883536339, 53.95445242524147, 6.940420679748058, 1.7003650590777397, 3.8511919090524316, 1.5600543818436563, 29.82347298413515, 64.55303370952606, 71.9904126226902, 63.4460961073637, 61.36392183601856, 62.03763708472252, 64.04725804924965, 67.23346307873726, 65.77225148677826, 63.40480752289295, 63.30996461212635, 65.25243178009987, 64.56754133105278, 65.56023806333542, 61.7513832449913, 61.28178544342518, 60.53398557007313, 57.15032413601875, 58.93749363720417, 61.05391167104244, 59.08176049590111, 62.47934438288212, 61.63606323301792, 62.32796050608158, 59.949987307190895, 59.35723811388016, 58.16138908267021, 58.48024897277355, 52.72524878382683, 50.66862054169178, 48.958723694086075, 43.873338773846626, 43.25192391872406, 42.0705559104681, 42.526064068078995, 44.32178691029549, 45.23126430809498, 49.97846357524395, 51.277625262737274, 55.943128913640976, 58.96428219974041, 58.77065598964691, 52.42712818086147, 46.750510185956955, 40.70363245904446, 41.53053268790245, 43.22829678654671, 40.99645994603634, 42.58415535092354, 41.69863946735859, 43.55645477771759, 46.008440405130386, 50.32523296773434, 39.8787385225296, 36.51444844901562, 47.69961565732956, 48.140240013599396, 46.952773332595825, 42.15902656316757, 40.63079036772251, 41.57345898449421, 41.09268978238106, 43.24188485741615, 41.71220473945141, 39.71034295856953, 43.90018433332443, 45.9811806678772, 52.244521379470825, 53.11447709798813, 55.99915690720081, 56.82264871895313, 56.462192460894585, 54.44751776754856, 52.55471393465996, 49.46603067219257, 43.45491282641888, 41.424693167209625, 40.17435126006603, 39.46685582399368, 41.07458755373955, 42.83874548971653, 45.37509799003601, 45.911895185709, 45.51319018006325, 47.07915835082531, 47.64235273003578, 51.95632204413414, 56.821998953819275, 55.88798247277737, 55.1104149967432, 55.49128755927086, 55.95518946647644, 55.95162905752659, 57.28910408914089, 54.854586124420166, 55.519307255744934, 56.36028952896595, 57.25706420838833, 56.924696043133736, 56.92831724882126, 55.22459886968136, 57.88172788918018, 56.724693775177, 55.631754621863365, 59.695210978388786, 62.55335681140423, 61.43051326274872, 58.84459242224693, 56.67466185986996, 58.76289300620556, 42.09310010075569, 16.13330729305744, 2.8938810154795647, 0.6407748756464571, 0.07016210700385273, 3.5772622330114245, 45.83542428910732, 65.50686612725258, 62.36883491277695, 56.207062751054764, 63.13122220337391, 63.24815332889557, 64.77150678634644, 66.98133900761604, 52.0074786990881, 33.71225081384182, 45.827125534415245, 29.223487079143524, 52.65033200383186, 11.127468254417181, 0.41607206279877573, 0.06685399115667678, 0.07045005288091488, 0.06463620899012312, 0.06445212668040767, 0.049535960279172286, 0.02325929224753054, 0.0449038121587364, 0.0556899824005086, 0.029340439177758526, 0.015368109288829146, 0.00904624861504999, 0.1671007537515834, 0.15182935836492106, 0.24626955011626706, 0.2108148846309632, 0.2483382570790127, 0.1373788673663512, 0.131456098461058, 0.16437092679552734, 0.20763071486726403, 0.271567152813077, 0.1313123741419986, 0.12998097605304793, 0.13485400675563142, 0.15179222129518166, 0.5813958775252104, 0.3586546500446275, 27.42580734193325, 76.37669205665588, 45.14788918197155, 41.68356567621231, 41.23935431241989, 61.43644854426384, 74.75877687335014, 75.71092218160629, 74.94580283761024, 75.18815383315086, 72.33377739787102, 70.48931837081909, 60.899662747979164, 60.039031729102135, 8.317106757313013, 6.973805213347077, 12.234348859637976, 2.531575681641698, 32.91432023048401, 67.0873761177063, 74.37569662928581, 66.23160883784294, 65.908033400774, 64.11020547151566, 65.78406885266304, 69.22099202871323, 69.33042615652084, 64.72397133708, 66.98684871196747, 66.73371389508247, 65.66794708371162, 68.19248601794243, 65.85359752178192, 63.358134627342224, 66.55925005674362, 61.713518276810646, 60.45072823762894, 63.77324715256691, 62.00698032975197, 66.1548301577568, 64.66650322079659, 67.43108287453651, 63.26044946908951, 62.87967950105667, 63.500148206949234, 61.549834460020065, 54.99210074543953, 54.07845117151737, 52.251030430197716, 45.888515040278435, 46.12981729209423, 45.550713166594505, 47.144625037908554, 47.36754387617111, 47.18515746295452, 50.90425729751587, 54.51690584421158, 58.9580999314785, 59.81121875345707, 58.34714211523533, 53.630383014678955, 47.15600922703743, 44.33283291757107, 44.154808670282364, 45.48096790909767, 44.504059329628944, 43.287265822291374, 44.5523015409708, 48.49466599524021, 47.32885055243969, 52.5133341550827, 42.68218629062176, 34.269874691963196, 50.698980912566185, 48.290415555238724, 46.66612811386585, 45.55744640529156, 44.69940684735775, 44.09356735646725, 43.18598985671997, 47.3698503524065, 44.321114346385, 40.91889090836048, 45.61137691140175, 46.63269370794296, 55.7512354105711, 54.09942604601383, 57.83193916082382, 57.49126084148884, 57.76346303522587, 57.86604233086109, 54.547045826911926, 50.807731077075005, 46.35268293321133, 44.09034512937069, 43.03176753222942, 41.65327750146389, 44.19081553816795, 44.6135276556015, 48.612037897109985, 48.2953704893589, 46.97781398892403, 47.732772678136826, 47.01909877359867, 53.448201790452, 58.24810802936554, 56.72553353011608, 55.83206087350845, 57.75805972516537, 57.691703885793686, 58.14546413719654, 59.90096993744373, 57.89319187402725, 56.20903104543686, 59.45182643830776, 60.546065121889114, 58.06372672319412, 57.84064069390297, 58.23162071406841, 58.5456358641386, 58.25794570147991, 55.77462695538998, 60.96576400101185, 65.956389605999, 65.45429974794388, 61.59249857068062, 59.37101237475872, 57.357021644711494, 45.654576793313026, 18.584996536374092, 4.22454871237278, 1.9259258243255317, 1.105428608134389, 6.308127008378506, 55.03693833947182, 69.74022656679153, 65.57216182351112, 63.19628991186619, 67.20465302467346, 70.15572667121887, 67.7837723493576, 70.75162589550018, 58.1559781730175, 43.54253612458706, 48.04853193461895, 39.03628192842007, 67.91495651006699, 20.057926699519157, 0.6092480861116201, 0.2850991173181683, 0.16924701514653862, 0.14079659100389108, 0.19679443852510303, 0.1148654984717723, 0.12519980838987976, 0.0660379181499593, 0.21050162409665063, 0.10600469307973981, 0.20901683892589062, 0.06112593211582862], [0.07194830061052926, 0.048742044091341086, 0.05341733696695883, 0.03941409755498171, 0.08316267892951146, 0.03169889358105138, 0.039154590776888654, 0.06967597801121883, 0.08762755067436956, 0.044058261046302505, 0.02699586850212654, 0.006443555730584194, 0.048527218314120546, 0.020731936165248044, 0.24864173610694706, 0.07907864768640138, 4.766450934112072, 43.54698568582535, 37.2449516505003, 30.410484485328197, 23.89231614768505, 37.10679106414318, 49.63751167058945, 50.442034900188446, 63.76968294382095, 57.02451668679714, 61.66925825178623, 59.209555238485336, 53.57815481722355, 49.91516277194023, 6.287567736580968, 2.0670786313712597, 2.622755588963628, 2.431709677912295, 32.83812291920185, 65.80397978425026, 68.218704611063, 60.379303470253944, 57.98556111752987, 61.30509339272976, 63.59421595931053, 60.522422790527344, 59.69169616699219, 62.28029206395149, 62.046422213315964, 63.520917892456055, 59.93485651910305, 60.950865000486374, 57.643055096268654, 55.79609960317612, 54.0072163939476, 54.4019316136837, 51.16858631372452, 55.19673876464367, 57.56777733564377, 59.43151652812958, 57.23940275609493, 58.5300263017416, 57.79172591865063, 58.4952961653471, 57.204178646206856, 57.82784678041935, 50.35786181688309, 46.644940450787544, 46.49865210056305, 45.22798888385296, 39.57473963499069, 40.59955984354019, 40.36145322024822, 39.4268249720335, 45.275843515992165, 49.266788363456726, 54.88719217479229, 60.4206832498312, 60.37640042603016, 52.69508980214596, 43.6410990357399, 41.61440558731556, 40.41981428861618, 41.50448888540268, 40.94278782606125, 38.041730895638466, 39.645624831318855, 37.91070252656937, 40.6047959625721, 43.65431472659111, 48.048630729317665, 32.68948629498482, 24.384992010891438, 43.52646678686142, 45.81198714673519, 42.34774723649025, 38.98010574281216, 39.67426389455795, 37.926684468984604, 39.237256944179535, 39.487139135599136, 40.60786999762058, 38.40246073901653, 38.28445807099342, 39.569340124726295, 45.16613580286503, 47.465510219335556, 50.339235216379166, 52.87576250731945, 50.66849894821644, 46.84874251484871, 44.87062186002731, 42.42275521159172, 41.64540432393551, 38.25836107134819, 37.54038579761982, 37.74163819849491, 38.47507864236832, 41.53155103325844, 41.203222051262856, 44.567508324980736, 46.402323469519615, 43.857258036732674, 47.67746664583683, 47.98084996640682, 52.27944150567055, 52.86125488579273, 57.440381571650505, 53.812108263373375, 55.366224870085716, 53.38436521589756, 54.32543031871319, 56.27157188951969, 52.90109194815159, 50.603951811790466, 54.49570678174496, 57.96198718249798, 56.63186855614185, 49.178427904844284, 47.66727179288864, 50.04468262195587, 56.41067862510681, 57.923157066106796, 56.551939845085144, 57.24579021334648, 57.53049373626709, 59.528259336948395, 62.609814181923866, 35.5980022251606, 10.850002393126488, 2.114054085686803, 0.13753501523751765, 0.12789576372597367, 3.067560908384621, 37.84507244825363, 52.02013581991196, 56.336145624518394, 56.20643958449364, 58.100816532969475, 59.74085032939911, 54.95191790163517, 62.55656763911247, 38.954506516456604, 28.632238805294037, 29.08947966992855, 25.65702125430107, 37.11814105510712, 0.979455808410421, 0.07748825490125455, 0.18067509488901123, 0.03887706465320662, 0.08834216467221268, 0.030203978094505146, 0.08908369636628777, 0.011941750763071468, 0.13093341869534925, 0.04112884831556585, 0.05769189607235603, 0.06009337834257167, 0.02302077155036386, 0.02421904504444683, 0.02826598189130891, 0.04849742108490318, 0.010669965686247451, 0.02571799595898483, 0.05004164486308582, 0.14843434444628656, 0.06532123356009834, 0.050868775870185345, 0.06924327622982673, 0.014437502486543963, 0.10049300719401799, 0.05966902943328023, 0.059265156378387474, 0.2419265464413911, 0.18468818423571065, 6.722203139215708, 59.70361612737179, 40.769437327980995, 38.37995834648609, 41.459601894021034, 41.62770867347717, 56.38925917446613, 58.65339808166027, 71.84558719396591, 62.67601802945137, 67.56823271512985, 67.22247406840324, 58.02972234785557, 54.1747722029686, 7.895125625655055, 2.0066794473677874, 2.0120449969545007, 2.975317295640707, 36.19289830327034, 69.21575590968132, 70.47777459025383, 62.46377281844616, 61.765602082014084, 64.97347354888916, 66.84717580676079, 64.25838991999626, 62.950488701462746, 63.150179386138916, 64.58440482616425, 67.10113897919655, 64.14378046989441, 63.080023750662804, 61.69173404574394, 58.42588149011135, 57.05012731254101, 57.698547318577766, 54.13732901215553, 57.42954075336456, 60.31721480190754, 60.22641107439995, 60.21946504712105, 59.12783682346344, 60.00352643430233, 58.62846001982689, 59.17378395795822, 62.34859719872475, 52.54294976592064, 49.50436681509018, 46.995365247130394, 46.133104115724564, 43.64620216190815, 43.414137214422226, 41.157062128186226, 40.91831333935261, 46.79284751415253, 49.51640076935291, 54.091393277049065, 61.1288246512413, 61.126073598861694, 54.83241431415081, 48.47513884305954, 43.56499671936035, 43.292479142546654, 42.48776972293854, 43.647296503186226, 40.284343957901, 40.00604689121246, 40.185731649398804, 43.93734633922577, 45.40440581738949, 50.18193505704403, 34.91196423768997, 26.04556940495968, 48.243142291903496, 46.33735455572605, 45.7349044829607, 41.556793078780174, 40.25176830589771, 40.21626681089401, 43.16621191799641, 41.644758358597755, 42.94163636863232, 40.37998102605343, 41.42883114516735, 41.84598036110401, 48.75754728913307, 51.6278562694788, 52.81534194946289, 55.70699818432331, 51.4924543350935, 49.02705542743206, 48.68741825222969, 44.37417469918728, 44.05078545212746, 40.92149756848812, 38.25520344078541, 38.25489945709705, 41.31089687347412, 42.70284578204155, 43.39411608874798, 46.119265258312225, 48.43174897134304, 46.27084292471409, 49.90269184112549, 51.07194609940052, 55.13015113770962, 54.46845464408398, 57.481096386909485, 55.158866196870804, 56.300841718912125, 54.93096582591534, 56.770659908652306, 56.902854815125465, 53.05295079946518, 54.023350328207016, 56.58358074724674, 59.2224745452404, 58.71544875204563, 50.86174137890339, 49.0624163299799, 49.917001873254776, 57.591142281889915, 59.61711756885052, 59.62603949010372, 59.286508709192276, 59.67664897441864, 61.983755975961685, 62.89200983941555, 39.34348024427891, 11.402969621121883, 3.508489723317325, 0.4293312138179317, 0.11895088042365387, 3.183065210469067, 38.76135528087616, 60.36475785076618, 58.7999752163887, 62.6241622120142, 62.64691919088364, 67.91193187236786, 60.001960918307304, 68.49833160638809, 45.16564942896366, 39.8205978423357, 33.25117215514183, 31.31618108600378, 43.75845193862915, 1.2341237836517394, 0.07346204438363202, 0.09622881960240193, 0.009046422092069406, 0.06991977352299727, 0.033219735996681266, 0.06536977001815103, 0.034578085178509355, 0.11155826578033157, 0.09425360840396024, 0.052240576478652656, 0.0423657450301107, 0.05964644216874149, 0.21468934079166502, 0.11100261981482618, 0.171138719888404, 0.09239905557478778, 0.16485347121488303, 0.18514919152949005, 0.20831130881560966, 0.12442054590792395, 0.20605215191608295, 0.13278411235660315, 0.11493947575218044, 0.14298917725682259, 0.23384693311527371, 0.18665506853722036, 0.5016321607399732, 0.590150251518935, 9.849629122763872, 72.31261253356934, 57.3966421186924, 44.44094471633434, 41.23073637485504, 50.135463550686836, 61.80533654987812, 62.96651244163513, 76.72550573945045, 70.82453638315201, 72.72812023758888, 74.77049544453621, 62.95513965189457, 61.00340098142624, 10.063011422753334, 4.487764863297343, 5.1889032404869795, 4.607313573360443, 41.380307748913765, 70.46734794974327, 75.19365593791008, 65.79619020223618, 65.05443960428238, 68.8246200978756, 71.75743192434311, 66.16578117012978, 65.33507734537125, 68.42593789100647, 67.0270125567913, 70.28186470270157, 65.46843498945236, 66.45357772707939, 62.93975427746773, 61.063604950904846, 62.28417545557022, 60.31578607857227, 55.632362589240074, 60.11215880513191, 64.34658318758011, 64.94593262672424, 61.63114249706268, 62.516396194696426, 62.939974665641785, 62.6972246915102, 63.250174820423126, 63.29622074961662, 53.415660336613655, 52.38599918782711, 49.419289380311966, 48.727726489305496, 45.40881358087063, 46.16533398628235, 45.13783872127533, 42.42665380239487, 48.9688653498888, 53.10229495167732, 56.636405512690544, 63.14861387014389, 61.05686031281948, 56.64551742374897, 48.80072437226772, 45.54537445306778, 45.93404419720173, 45.044409334659576, 45.99079795181751, 42.88388326764107, 41.45053558051586, 43.21357637643814, 46.15597888827324, 48.092750161886215, 53.46539966762066, 35.57714894413948, 25.2583846449852, 51.20548993349075, 49.6027397364378, 47.3174549639225, 44.230588003993034, 43.95058862864971, 44.38286863267422, 45.24466618895531, 44.224766716361046, 47.501859068870544, 41.76968425512314, 42.72807642817497, 43.08421231806278, 50.53159609436989, 51.5914124250412, 54.16237346827984, 57.80562937259674, 52.838190123438835, 50.579503923654556, 48.503226935863495, 48.158710822463036, 47.248085886240005, 42.99114391207695, 41.32651023566723, 40.626257210969925, 43.04590657353401, 46.93264201283455, 44.49255734682083, 49.45749253034592, 49.778176322579384, 48.72194319963455, 53.18238325417042, 51.817880272865295, 57.04157777130604, 57.107192650437355, 60.42306952178478, 58.03474947810173, 60.957537442445755, 55.8392158895731, 58.09203140437603, 61.323928982019424, 56.092601493000984, 57.208730801939964, 59.75574932992458, 64.23632830381393, 60.00728823244572, 53.212052062153816, 53.303847536444664, 52.3919952660799, 55.769455432891846, 61.43382288515568, 60.81442192196846, 61.229002475738525, 59.2877284437418, 63.4556107968092, 66.84287443757057, 41.96067340672016, 14.239069037139416, 4.932189015671611, 1.426125462166965, 0.584415765479207, 4.424692997708917, 46.5000656247139, 63.77184882760048, 64.48432579636574, 66.32878482341766, 68.33244010806084, 70.60247629880905, 67.54933252930641, 72.52277165651321, 52.722630724310875, 40.05421310663223, 38.71009983122349, 40.89692048728466, 58.33748683333397, 3.127090414054692, 0.3299843572312966, 0.33759148966055363, 0.28104482393246144, 0.2061725579551421, 0.17030745511874557, 0.15845036949031055, 0.19785152398981154, 0.23715422517852858, 0.17465231416281313, 0.17168304068036377, 0.1465040777111426, 0.20328172948211432], [0.05012346293369774, 0.025917752427631058, 0.02050856641290011, 0.03044104789296398, 0.05303417725372128, 0.042506419122219086, 0.046628370400867425, 0.004649678112400579, 0.02038687831372954, 0.02270678371132817, 0.03935638444090728, 0.03989939534221776, 0.010448417906445684, 0.028630513697862625, 0.08754500158829615, 0.26827023597434163, 0.40951616771053523, 27.72408753633499, 50.47479294240475, 28.775265030562878, 23.79682347178459, 32.95863725244999, 59.06816102564335, 47.81896345317364, 48.066029995679855, 67.26542696356773, 57.030170783400536, 60.02154126763344, 53.64397868514061, 51.56387150287628, 6.385207297280431, 1.4956724178045988, 0.709529573796317, 3.681130609475076, 38.7166278809309, 68.65084782242775, 68.26943188905716, 63.45112323760986, 62.587638571858406, 63.36976580321789, 65.49611270427704, 65.3364148736, 61.51972107589245, 60.18005736172199, 60.485644564032555, 61.97247438132763, 63.06359343230724, 59.48603980243206, 58.81199777126312, 56.85853399336338, 54.75861467421055, 53.168608993291855, 50.81156127154827, 51.51573568582535, 51.86253547668457, 55.82313135266304, 58.74075919389725, 57.575544118881226, 59.10513684153557, 56.516989320516586, 59.33489911258221, 57.93344311416149, 52.31533817946911, 44.36171896755695, 43.870542123913765, 43.367342725396156, 42.61909827589989, 41.40790946781635, 40.129403471946716, 42.47105821967125, 49.85314629971981, 51.30996152758598, 54.66363117098808, 58.439252972602844, 57.15908266603947, 46.538884341716766, 39.531976729631424, 40.80593816936016, 38.98050092160702, 39.01181124150753, 41.48302383720875, 39.17569264769554, 41.501589640975, 37.07838378846645, 41.519756466150284, 43.34770917892456, 55.355452448129654, 31.347812488675117, 17.055058032274246, 45.808061957359314, 45.942084565758705, 45.54205343127251, 39.70153883099556, 39.929746985435486, 37.00937569141388, 38.42469334602356, 38.877279460430145, 40.2776525169611, 37.84508764743805, 38.435613960027695, 35.40886737406254, 39.00868020951748, 44.83952432870865, 52.624899968504906, 57.74924039840698, 53.781443908810616, 51.076365262269974, 46.7771315574646, 41.374296471476555, 40.65446689724922, 37.9856763035059, 38.716468289494514, 37.772982716560364, 37.75472089648247, 40.387462824583054, 43.21069233119488, 42.04747974872589, 42.8141114115715, 44.71426784992218, 45.44758290052414, 47.78623580932617, 52.48928524553776, 53.296054154634476, 54.35666084289551, 56.16981714963913, 53.291756585240364, 52.860407531261444, 51.37619957327843, 51.7723473161459, 48.23421277105808, 49.57987256348133, 53.05490769445896, 53.9284086227417, 57.117653489112854, 56.48667074739933, 60.236594527959824, 59.994441121816635, 59.453414753079414, 58.29284682869911, 60.21413013339043, 60.240386724472046, 60.98540894687176, 60.545920729637146, 59.85943056643009, 29.9541137740016, 8.928753286600113, 2.383806360885501, 0.378882538061589, 0.16916546795982867, 0.4651307553285733, 23.86916968971491, 63.47181312739849, 52.865503057837486, 59.020883962512016, 53.06545972824097, 56.31100997328758, 57.41802357137203, 57.77977555990219, 31.612827368080616, 26.906886287033558, 20.1389991492033, 46.613804921507835, 15.448147058486938, 0.2811089454917237, 0.0851098369457759, 0.03366682431078516, 0.02957521388452733, 0.13854699296643957, 0.07597595089464448, 0.03243729341193102, 0.034596000623423606, 0.04900950669252779, 0.095809491322143, 0.08650327115901746, 0.045505308007705025, 0.06609147152630612, 0.024162190966308117, 0.07783149078022689, 0.05157529674761463, 0.03158877370879054, 0.08501790711306967, 0.04701315912825521, 0.0630490890762303, 0.06095271855883766, 0.03424010741582606, 0.09335973605629988, 0.013955563845229335, 0.08273052633740008, 0.0827295912313275, 0.09036833173013292, 0.240703338640742, 0.36580159154254943, 0.5290178256109357, 35.38757711648941, 60.896140336990356, 27.908892519772053, 39.39972102642059, 38.83447855710983, 59.24087315797806, 51.35614424943924, 52.155552953481674, 71.60626083612442, 64.0871711075306, 66.50951072573662, 58.64821515977383, 56.218819320201874, 7.508757133036852, 1.8364241207018495, 1.0853463294915855, 4.5169121492654085, 43.11259679496288, 71.29381120204926, 71.4085878431797, 67.11129203438759, 63.342665657401085, 64.9551585316658, 68.31829726696014, 68.19506227970123, 65.8855690062046, 64.29573431611061, 62.26071551442146, 63.71454410254955, 63.835259824991226, 64.9170009791851, 62.211443558335304, 58.1354820728302, 58.12738470733166, 56.36674918234348, 54.014310613274574, 54.14113640785217, 54.87120263278484, 58.59621874988079, 60.43612942099571, 60.14168702065945, 61.05419285595417, 58.4506219625473, 60.12248285114765, 57.973929941654205, 55.343148708343506, 47.31164887547493, 44.05235476791859, 43.154975920915604, 45.424742326140404, 43.349050506949425, 41.8017203360796, 44.64872896671295, 49.39529366791248, 51.40876762568951, 54.86673407256603, 60.086365789175034, 59.901562705636024, 49.58678059279919, 42.09963954985142, 41.64922311902046, 41.81528940796852, 42.850471660494804, 43.56602646410465, 41.74876257777214, 42.03001968562603, 40.45482940971851, 43.769079968333244, 48.633020371198654, 56.67940020561218, 35.23040995001793, 21.639333441853523, 48.20444516837597, 48.47148343920708, 48.06637957692146, 41.268076971173286, 42.62218751013279, 39.608227238059044, 38.98559644818306, 39.914851784706116, 42.628229185938835, 41.10486812889576, 40.02712436020374, 38.127256706357, 42.6355741918087, 47.88640983402729, 55.19936442375183, 58.82004953920841, 55.41944481432438, 52.68634267151356, 49.513839706778526, 42.823021933436394, 43.12930829823017, 40.96949279308319, 41.38458251953125, 39.76140461862087, 39.96926486492157, 42.11315542459488, 45.88495083153248, 44.32815156877041, 45.881329625844955, 47.78652839362621, 48.34531120955944, 48.88771690428257, 54.12490747869015, 54.996143728494644, 57.904496267437935, 56.41615033149719, 55.36963328719139, 55.42854152619839, 53.308943063020706, 53.14181663095951, 51.240588650107384, 52.43022121489048, 55.14190770685673, 57.55132041871548, 58.37851703166962, 56.614727675914764, 60.49427010118961, 61.95034816861153, 60.526883751153946, 59.77075092494488, 62.71987907588482, 62.452054247260094, 62.316412925720215, 64.20582354068756, 62.62245610356331, 34.38848912715912, 10.192100945860147, 4.402390094473958, 0.767019420163706, 0.048419851809740067, 0.7657063531223685, 25.888597927987576, 68.00076350569725, 58.78006048500538, 62.846153900027275, 59.423084780573845, 60.39141342043877, 61.960140243172646, 66.0057033598423, 37.42414243519306, 36.71930305659771, 21.681087501347065, 52.49826416373253, 20.623940527439117, 0.29134037147741765, 0.09630329412175342, 0.06081058243580628, 0.040271400575875305, 0.061447181869880296, 0.04718028707429767, 0.03237228869693354, 0.03540697136486415, 0.11938143739826046, 0.04399523415486328, 0.02630121642141603, 0.07484674351871945, 0.09463372160098515, 0.12215201568324119, 0.1495990710100159, 0.17031498049618676, 0.12104810812161304, 0.20939442882081494, 0.24465336027787998, 0.17823099478846416, 0.20245053892722353, 0.18014233675785363, 0.19889419694663957, 0.21859281492652372, 0.19390929490327835, 0.16208040673518553, 0.1397693101898767, 0.42393761104904115, 0.3864014142891392, 1.0015552444383502, 46.97860814630985, 76.10501423478127, 42.221696600317955, 39.93340998888016, 47.34220303595066, 70.40784314274788, 58.71186554431915, 58.44507426023483, 78.84425684809685, 70.00986009836197, 72.78460800647736, 64.87782508134842, 61.96579433977604, 10.095651671290398, 6.4940819051116705, 2.036319044418633, 5.7757779490202665, 45.86791634559631, 75.01748979091644, 73.126620054245, 69.44496721029282, 67.82395899295807, 68.77015382051468, 70.09999126195908, 71.52431443333626, 69.01728495955467, 66.66046902537346, 68.1524133682251, 67.60589629411697, 67.91909828782082, 67.59844109416008, 65.8015251159668, 60.98967231810093, 61.24872721731663, 59.547383710742, 56.70021928846836, 57.295837327837944, 56.31184592843056, 61.78672134876251, 63.359035179018974, 63.68117429316044, 64.63820233941078, 60.29213234782219, 64.41849052906036, 63.31900432705879, 58.8540843129158, 48.85751232504845, 45.420551151037216, 45.94021886587143, 46.492865011096, 45.89953064918518, 44.60688181221485, 47.90776088833809, 53.471809923648834, 53.02463471889496, 57.21872806549072, 62.366441041231155, 61.157801896333694, 49.848776534199715, 42.43029020726681, 43.38948793709278, 42.379076555371284, 43.45221497118473, 45.22987358272076, 43.31834815442562, 46.36713355779648, 41.775718331336975, 47.39752046763897, 48.85102607309818, 62.47503161430359, 32.90671303868294, 16.994344890117645, 50.43457210063934, 51.35639503598213, 51.7020320892334, 43.54260452091694, 45.47679953277111, 42.06945776939392, 40.4665669798851, 42.05613188445568, 45.63602618873119, 44.28267180919647, 42.501452788710594, 39.26405690610409, 44.45882275700569, 49.298858642578125, 55.585473105311394, 60.77000230550766, 56.87829673290253, 56.30815252661705, 51.76667042076588, 45.65775342285633, 45.299493446946144, 44.382412657141685, 44.41600665450096, 42.293341755867004, 42.92134925723076, 45.76385132968426, 47.64355726540089, 45.788485407829285, 47.30181120336056, 50.50117492675781, 51.080670431256294, 51.386557817459106, 57.37879067659378, 56.70406088232994, 58.630086332559586, 60.36956079304218, 56.544591039419174, 56.60829082131386, 57.37211063504219, 56.62516951560974, 51.65223956108093, 55.596424117684364, 57.81366974115372, 58.581661731004715, 62.09800444543362, 58.05079221725464, 61.007599756121635, 63.73815603554249, 64.29787740111351, 62.72116720676422, 63.74319836497307, 64.17581275105476, 65.53386747837067, 67.00798317790031, 64.43463206291199, 38.3441186696291, 11.604621950536966, 6.127776335924864, 1.09536437317729, 0.7467421644832939, 2.440683846361935, 33.79683427512646, 73.44832599163055, 62.64734096825123, 67.8926669061184, 63.51749047636986, 67.52792447805405, 67.743289321661, 71.77050322294235, 45.05655348300934, 39.238457679748535, 33.36701653897762, 65.67364677786827, 31.969082951545715, 0.23859519395045936, 0.2852205326780677, 0.22503461223095655, 0.09923946781782433, 0.22704905335558578, 0.10724237276008353, 0.2027191815432161, 0.14958682557335123, 0.1492434783722274, 0.2841060346690938, 0.18988146650372073, 0.1569233412737958, 0.19495061715133488], [0.020387254953675438, 0.06018700769345742, 0.06788131649955176, 0.02440510146698216, 0.0948499611695297, 0.0038208313526411075, 0.0982741266489029, 0.08639916268293746, 0.05378854810260236, 0.030441352173511405, 0.04632715121260844, 0.045126400800654665, 0.042210929314023815, 0.061308611766435206, 0.051687112427316606, 0.14366889547090977, 0.07948065423988737, 6.044548926874995, 45.50821624696255, 42.82280154526234, 31.785476803779602, 25.70902906358242, 48.86139191687107, 68.9410762488842, 56.9761148840189, 61.20293207466602, 64.53130647540092, 61.56877264380455, 56.23305335640907, 54.79360319674015, 4.910137373954058, 1.6373690706677735, 0.34577648795675486, 4.594923863187432, 43.545275777578354, 70.99590718746185, 67.51480758190155, 62.556442245841026, 62.951670438051224, 64.04804840683937, 64.18345034122467, 67.72081732749939, 66.91415101289749, 64.67598751187325, 60.77819466590881, 60.551039054989815, 62.93555170297623, 60.482832714915276, 62.260905504226685, 55.97355768084526, 57.19458796083927, 52.04268380999565, 51.043052449822426, 49.86791230738163, 47.2051215916872, 52.93476954102516, 57.04670749604702, 57.57025860249996, 59.179232865571976, 58.146539479494095, 57.05090247094631, 59.32965539395809, 50.28758838772774, 45.3780922293663, 42.91681230068207, 41.073709800839424, 42.43307925760746, 40.521443635225296, 41.55203953385353, 44.37989339232445, 49.209658429026604, 49.55687239766121, 55.37663251161575, 57.092939615249634, 45.46719364821911, 42.33042776584625, 40.973965153098106, 37.93958477675915, 37.48106338083744, 38.61293524503708, 40.45503079891205, 38.52535754442215, 38.55573691427708, 36.19650050997734, 41.694452092051506, 44.18831527233124, 54.75066930055618, 34.106088280677795, 14.710427094250917, 46.99033431708813, 46.37549310922623, 43.759287893772125, 39.037463665008545, 36.71857729554176, 36.70785427093506, 39.30912248790264, 39.863493740558624, 40.12488931417465, 41.371955797076225, 38.19157585501671, 38.99336323142052, 39.491881281137466, 41.04038178920746, 47.301294431090355, 55.5814491212368, 55.02502217888832, 52.28701449930668, 46.13015167415142, 44.66653861105442, 41.26360081136227, 40.09334720671177, 38.689235150814056, 37.46194660663605, 37.78130427002907, 37.79559150338173, 39.518882632255554, 40.30357852578163, 43.63533094525337, 44.43338692188263, 45.76692156493664, 48.11459518969059, 51.47304877638817, 51.960338428616524, 53.601227179169655, 56.557943522930145, 52.50346228480339, 51.54490292072296, 50.68757772445679, 47.68553741276264, 47.40715675055981, 50.55032528936863, 51.21387988328934, 58.29804114997387, 56.652167066931725, 55.69668173789978, 56.016521975398064, 57.02697895467281, 58.22521045804024, 57.132446095347404, 55.09556159377098, 58.99732142686844, 61.818639636039734, 61.219123005867004, 60.84298878908157, 26.753593012690544, 9.17649619281292, 4.33724164031446, 0.34176182525698096, 0.17071814480004832, 0.20428762160008773, 25.25939729064703, 62.454147934913635, 51.883008778095245, 56.89208619296551, 52.253371104598045, 64.26453799009323, 57.529186606407166, 45.84131017327309, 29.481508433818817, 25.845293551683426, 32.54961580038071, 40.74987977743149, 2.8462543711066246, 0.2155919704819098, 0.07624517980730161, 0.019728988518181723, 0.10139495410840027, 0.03439571722992696, 0.06669504538876936, 0.038379543693736196, 0.039363301257253624, 0.044338614752632566, 0.028087076061638072, 0.07810166222043335, 0.07478915285901166, 0.04365227658126969, 0.012402566953824135, 0.06782347350963391, 0.04733842390123755, 0.012881712336820783, 0.05673242158081848, 0.044169598040753044, 0.12186564315925352, 0.03335386063554324, 0.0190121183914016, 0.0351663633773569, 0.05676595552358776, 0.07021756027825177, 0.10399738399428315, 0.03474403310974594, 0.04046294889121782, 0.12039891444146633, 0.05720300257962663, 7.961934115737677, 61.97422608733177, 42.02085077762604, 33.69469955563545, 40.56687779724598, 54.50266420841217, 76.3430866599083, 60.47792337834835, 70.33706814050674, 70.41169613599777, 68.79104509949684, 60.98888196051121, 58.3043298125267, 5.768046788871288, 0.9965357137843966, 0.2744189591612667, 5.635142270475626, 46.615887209773064, 75.30679106712341, 69.87923830747604, 67.37308278679848, 65.6324265897274, 68.63900765776634, 66.72628909349442, 68.61663445830345, 67.13156774640083, 66.10784187912941, 63.95881399512291, 64.65597778558731, 63.9419125020504, 62.754005044698715, 64.98429536819458, 59.82629254460335, 59.08100813627243, 54.139810279011726, 54.096804186701775, 53.56080114841461, 50.94621084630489, 55.905252546072006, 58.66939142346382, 58.56777347624302, 60.821329951286316, 60.325992330908775, 61.06624960899353, 60.24287559092045, 52.71607227623463, 47.12465710937977, 45.55735521018505, 43.92958715558052, 44.55071322619915, 42.06641033291817, 44.12318676710129, 45.88044427335262, 50.21984562277794, 51.59096024930477, 54.03472691774368, 58.82277399301529, 49.264584481716156, 44.344836473464966, 42.19010129570961, 42.4050747603178, 40.872332006692886, 43.110472708940506, 42.90535591542721, 41.84790685772896, 40.64134620130062, 39.31383043527603, 43.77246178686619, 46.46741397678852, 55.742503479123116, 38.827141150832176, 19.486346170306206, 49.076692163944244, 48.785247802734375, 47.66888290643692, 41.572049260139465, 40.2141997218132, 40.592993795871735, 41.74588993191719, 42.782231122255325, 42.04643480479717, 43.41279588639736, 42.37953633069992, 40.382671281695366, 40.92740625143051, 42.809996232390404, 50.60741722583771, 57.84730553627014, 54.372547790408134, 54.59345653653145, 48.72285895049572, 45.88552840054035, 43.10775205492973, 42.675297260284424, 40.832893922924995, 39.12239670753479, 41.30199775099754, 41.61690205335617, 41.929093301296234, 43.33255939185619, 45.48080451786518, 46.66870057582855, 48.12373749911785, 47.80287891626358, 53.17875064909458, 54.70882974565029, 53.623642176389694, 58.0935513228178, 55.73139287531376, 52.57502384483814, 51.8334898352623, 50.69034017622471, 49.336066246032715, 53.58187861740589, 53.27440671622753, 58.42159911990166, 61.08031265437603, 57.71235577762127, 56.3542440533638, 58.32967825233936, 59.99847270548344, 59.09544736146927, 57.43893004953861, 60.5532543361187, 64.12638500332832, 61.923703998327255, 64.2253240942955, 30.81620391458273, 9.994480200111866, 6.2777813617140055, 1.0524769057519734, 0.05954829684924334, 0.1290345744928345, 29.277672171592712, 67.79941231012344, 57.723971754312515, 63.19144897162914, 58.44721354544163, 68.82468849420547, 64.64356765151024, 52.71482214331627, 36.83213800191879, 29.625207222998142, 34.74936716258526, 51.00706458091736, 3.7583263171836734, 0.2881620201515034, 0.08596947402111255, 0.03651146893389523, 0.10526319849304855, 0.0863825534179341, 0.08283102797577158, 0.033123902467195876, 0.03759618084586691, 0.029635075516125653, 0.09536582801956683, 0.060149432756588794, 0.045330825378187, 0.016795338124211412, 0.09873485192656517, 0.20807388093089685, 0.10076006161398254, 0.08802878539427184, 0.16814934904687107, 0.12275061715627089, 0.1617247992544435, 0.10408273839857429, 0.1530798920430243, 0.19635623000795022, 0.11251464180531912, 0.22805371350841597, 0.3141533973393962, 0.39290197484660894, 0.17937897850060835, 0.5076619621831924, 0.45761078072246164, 12.290197312831879, 73.66482317447662, 60.39490543305874, 48.56930159032345, 41.824811697006226, 62.34027564525604, 82.16359153389931, 66.39992460608482, 75.9836183488369, 75.9897968173027, 74.47677880525589, 67.29188874363899, 67.04367846250534, 7.229780377820134, 2.388573680073023, 1.0414545284584165, 6.4937384985387325, 51.871020421385765, 77.21148446202278, 75.33982649445534, 69.03512120246887, 69.11985665559769, 69.35850664973259, 71.33502379059792, 72.83873230218887, 71.97972759604454, 70.8710078895092, 66.67217999696732, 64.27476704120636, 70.14652356505394, 66.29429027438164, 69.44666191935539, 61.9930312782526, 62.81495377421379, 58.102488443255424, 57.42009826004505, 56.31375342607498, 51.978467255830765, 57.522711753845215, 61.99104018509388, 61.69436730444431, 62.59504817426205, 60.575194358825684, 64.25098031759262, 62.48637780547142, 55.343980863690376, 48.8530969619751, 46.76244914531708, 47.08907961845398, 47.90950879454613, 43.903942331671715, 47.6787281781435, 48.088779374957085, 52.84635208547115, 54.57063876092434, 57.85623125731945, 62.89238981902599, 48.646201863884926, 45.62555395066738, 45.303369238972664, 42.46297225356102, 42.38506883382797, 44.46334831416607, 44.21545721590519, 44.672082513570786, 43.02595764398575, 40.99422566592693, 47.45729126036167, 49.28968593478203, 62.53040984272957, 35.85818186402321, 13.426237553358078, 50.4986746609211, 51.93568915128708, 50.434264317154884, 42.58428834378719, 42.24953770637512, 41.20027340948582, 45.45181207358837, 46.25763863325119, 44.12188343703747, 47.65241838991642, 43.41830939054489, 42.37438380718231, 43.76321688294411, 45.35323776304722, 50.72798475623131, 60.04991814494133, 57.639532685279846, 56.92762948572636, 50.057050958275795, 50.23468382656574, 46.031790152192116, 44.96574595570564, 43.345509096980095, 41.93615332245827, 43.353834450244904, 43.439820036292076, 45.78058183193207, 45.670345947146416, 48.442608788609505, 49.111627489328384, 49.34786081314087, 50.90235359966755, 56.85168296098709, 57.07196854054928, 55.476475954055786, 60.61736449599266, 56.73375628888607, 55.20322501659393, 55.170143991708755, 53.91376040875912, 52.521602511405945, 57.041600570082664, 54.10784639418125, 61.83986149728298, 61.6559399664402, 62.61183187365532, 58.27736645936966, 60.137157663702965, 60.58321952819824, 60.55264636874199, 59.489018842577934, 61.46607555449009, 65.95652639865875, 64.21003371477127, 67.58067324757576, 35.3572129458189, 11.519980542361736, 7.609339635819197, 1.8937509320676327, 0.3534482466056943, 0.18346007826039568, 31.343674510717392, 75.51809772849083, 60.454421639442444, 67.41042718291283, 63.66920493543148, 75.31385868787766, 69.72874358296394, 60.330407693982124, 42.09064923226833, 40.058263689279556, 48.82130786776543, 64.96780425310135, 8.496987204998732, 0.5639042286202312, 0.30873951909597963, 0.12771506560966372, 0.19362275168532506, 0.16318156092893332, 0.15103785786777735, 0.1019182127492968, 0.12768361339112744, 0.13750194513704628, 0.12240680240211077, 0.2558393811341375, 0.13756980712059885, 0.12503426492912695], [0.003662803528641234, 0.03270494897151366, 0.04483533790335059, 0.014416663907468319, 0.021606301161227748, 0.014544845798809547, 0.03667169490654487, 0.036306754918769, 0.062295994721353054, 0.02106668001943035, 0.07043868317850865, 0.03627521364251152, 0.053161043688305654, 0.03704585236846469, 0.0866192762623541, 0.11100273113697767, 0.2081936487229541, 0.07966455101268366, 24.596688151359558, 48.75921919941902, 31.980862319469452, 22.060523740947247, 34.76236246526241, 61.782564371824265, 61.86647906899452, 61.407600492239, 61.11663490533829, 59.97690886259079, 62.84059479832649, 55.275618731975555, 2.966872723773122, 1.355781618040055, 0.2780368993990123, 4.209899073466659, 51.821687668561935, 78.56834605336189, 71.69365614652634, 70.38716465234756, 63.84605124592781, 66.72742143273354, 62.58466713130474, 63.437694758176804, 61.34625278413296, 64.1155631840229, 63.40680621564388, 64.69722837209702, 59.71660763025284, 64.92614328861237, 64.15090128779411, 59.82294112443924, 55.598122626543045, 54.79434795677662, 49.3617794662714, 48.86146791279316, 45.42517930269241, 50.112463384866714, 54.168312549591064, 56.837167739868164, 57.08869904279709, 55.3614067286253, 58.18619795143604, 54.29394520819187, 45.87096378207207, 44.83621470630169, 40.439960807561874, 42.69444063305855, 42.41926699876785, 40.98405361175537, 43.18565547466278, 44.65789407491684, 46.64545722305775, 48.85368213057518, 51.13004118204117, 46.34783059358597, 40.66260226070881, 39.652836844325066, 39.7962411493063, 40.317516177892685, 39.853059500455856, 40.682270005345345, 40.9081868827343, 39.80047792196274, 39.77062292397022, 38.386554792523384, 42.41215378046036, 44.93983894586563, 56.85347266495228, 38.29662121832371, 14.549325238913298, 45.515040680766106, 49.364758506417274, 46.84120751917362, 42.289234176278114, 38.34281533956528, 37.74200297892094, 39.11276042461395, 41.346812546253204, 39.592382088303566, 39.02794897556305, 36.44156835973263, 36.18118353188038, 37.14006967842579, 38.94589617848396, 38.49033482372761, 43.82777161896229, 53.81114311516285, 49.97476637363434, 46.36796571314335, 42.127739042043686, 41.46941676735878, 39.02357921004295, 39.89769570529461, 36.890563666820526, 39.2788153141737, 37.63250045478344, 41.356597021222115, 43.28105315566063, 41.944991648197174, 45.2201347053051, 44.46888841688633, 48.6645320802927, 49.167366698384285, 51.5929551422596, 52.58255124092102, 53.68038073182106, 52.50551797449589, 48.506992533802986, 46.19400344789028, 45.832262858748436, 46.98189876973629, 48.58747981488705, 53.763383477926254, 56.31378002464771, 63.13486620783806, 56.025671884417534, 55.808437541127205, 55.43570414185524, 59.67765972018242, 56.33193925023079, 60.83040006458759, 60.793055668473244, 60.42971536517143, 59.03300531208515, 61.82805933058262, 21.951555088162422, 9.048641603440046, 4.783783229067922, 0.7238900719676167, 0.10790441301651299, 0.15610181348165497, 33.900317922234535, 58.14625829458237, 58.007440343499184, 46.32465563714504, 56.46886110305786, 58.542018458247185, 50.24062670767307, 40.1371930539608, 26.41858208924532, 26.829235553741455, 41.607961133122444, 23.45563977956772, 0.12524867139291018, 0.07015979150310159, 0.08176205330528319, 0.02999028038175311, 0.03771944415348116, 0.04689422625233419, 0.08941723237512633, 0.02397845746600069, 0.025822306670306716, 0.017082799749914557, 0.024237363104475662, 0.022744551606592722, 0.07131568650947884, 0.05173703670152463, 0.012515539456217084, 0.024141958165273536, 0.04538362176390365, 0.054300600313581526, 0.020936731816618703, 0.03240072779590264, 0.04092448310984764, 0.04486274170631077, 0.061680494545726106, 0.047079596188268624, 0.08987150838947855, 0.07717090513324365, 0.023940409409988206, 0.06192240500240587, 0.038180896735866554, 0.13823874935042113, 0.2814834925811738, 0.281914442894049, 33.976560831069946, 54.97988060116768, 32.04739674925804, 37.461369037628174, 41.569708585739136, 69.99380216002464, 71.09840288758278, 68.67620006203651, 66.52635142207146, 65.49488916993141, 69.8514162003994, 59.13382530212402, 3.525890652090311, 1.4313603937625885, 0.2396242113900371, 5.994982961565256, 58.23492273688316, 82.20891550183296, 73.98578435182571, 71.53939962387085, 67.8305858373642, 68.10369238257408, 65.05671948194504, 65.69937139749527, 65.07405415177345, 65.96761420369148, 66.15965589880943, 65.63904583454132, 61.918224692344666, 67.07445681095123, 64.69560965895653, 62.279437109827995, 57.97054052352905, 56.52422793209553, 51.179560124874115, 50.49907743930817, 48.860392570495605, 52.37662509083748, 55.46494737267494, 58.407216891646385, 60.274455696344376, 58.03098388016224, 59.54568140208721, 57.55844883620739, 46.97888173162937, 47.10779741406441, 44.30398866534233, 43.2335215061903, 43.36997978389263, 44.22643102705479, 44.19455833733082, 45.77110134065151, 48.45281884074211, 51.48433797061443, 53.01746070384979, 49.17262181639671, 42.40087978541851, 42.41929739713669, 41.9884879142046, 42.70944982767105, 41.552009135484695, 43.23100604116917, 44.24406588077545, 43.52120406925678, 41.05731748044491, 41.392923071980476, 45.41420929133892, 48.96141014993191, 58.95879529416561, 44.68383528292179, 20.746185667812824, 48.22827748954296, 52.79935620725155, 49.133993089199066, 45.60523644089699, 40.27968540787697, 38.29488091170788, 42.22131282091141, 42.11690582334995, 41.971970200538635, 41.298353746533394, 39.527063593268394, 38.9480696618557, 40.7255344837904, 40.645499378442764, 39.96199205517769, 48.49139057099819, 55.10865569114685, 52.40569353103638, 48.420357182621956, 45.3142062574625, 44.40985478460789, 40.55726431310177, 42.88060784339905, 39.91675928235054, 40.653851330280304, 40.641068816185, 43.31025458872318, 44.332392141222954, 44.09743554890156, 47.47692480683327, 47.831301391124725, 49.60207097232342, 50.5593916028738, 52.744669541716576, 54.76579248905182, 53.969720005989075, 53.94055277109146, 51.357751563191414, 48.39403599500656, 46.52237422764301, 49.769482389092445, 50.14452986419201, 55.25775209069252, 57.0224229991436, 64.03934687376022, 59.68297943472862, 56.93045273423195, 57.759902626276016, 59.675554633140564, 61.3757050037384, 63.81325900554657, 61.62305273115635, 63.84342938661575, 60.918836519122124, 64.70774620771408, 26.344468966126442, 10.128884688019753, 7.0381158124655485, 1.5730522968806326, 0.1741740296711214, 0.1002150060958229, 39.403042048215866, 64.5566739141941, 61.51789337396622, 52.68336743116379, 61.86897553503513, 62.33941689133644, 57.94408634305, 44.77538377046585, 36.00090600550175, 26.443702541291714, 48.032827377319336, 29.305361285805702, 0.11768620141083375, 0.06435087547288276, 0.04798091227712575, 0.07799614366376773, 0.00865204574438394, 0.08134829855407588, 0.009712052487884648, 0.022036607660993468, 0.050043693190673366, 0.04793157429958228, 0.049964335339609534, 0.048693006683606654, 0.06183987818076275, 0.012678189468715573, 0.09615971823222935, 0.13006040069740266, 0.15172421088209376, 0.16041697177570313, 0.16280768177239224, 0.06634439545450732, 0.09569601694238372, 0.0990647439903114, 0.22215582139324397, 0.24469112075166777, 0.16522733552847058, 0.3267434280132875, 0.11930702967219986, 0.1684901284170337, 0.15494195540668443, 0.32824298192281276, 0.355956171406433, 0.43520546110812575, 48.386037424206734, 71.8844287097454, 44.905070811510086, 39.346075505018234, 46.26580439507961, 74.66703459620476, 77.68395870923996, 75.99446296691895, 74.30343970656395, 71.84842944145203, 74.5824359357357, 65.64100652933121, 3.4628964448347688, 2.8477405663579702, 0.9464615257456899, 7.785680573433638, 62.57235199213028, 85.85329234600067, 77.91186287999153, 75.32387495040894, 69.7892515361309, 70.62334477901459, 69.25452142953873, 67.33635395765305, 66.57940417528152, 68.83082896471024, 71.82252243161201, 69.80308279395103, 66.05315521359444, 69.95427668094635, 69.6656821668148, 65.69489523768425, 61.70540191233158, 60.33207580447197, 54.5183801651001, 53.481328412890434, 52.33708441257477, 55.08158214390278, 58.7828229367733, 60.61915419995785, 62.00802147388458, 57.00789637863636, 61.208859756588936, 59.13069806993008, 51.892690658569336, 48.222501799464226, 44.881633669137955, 46.19927756488323, 46.743290573358536, 44.66458551585674, 47.15758614242077, 49.0317177772522, 53.02426613867283, 53.275482058525085, 54.98464174568653, 51.16177707910538, 44.6966177970171, 44.18389990925789, 44.15010832250118, 44.298513159155846, 42.92068809270859, 45.560170859098434, 46.30088411271572, 46.483057737350464, 43.016393557190895, 45.228175073862076, 47.48497277498245, 52.1797576546669, 62.48391553759575, 41.508421674370766, 12.907447591423988, 49.87780697643757, 55.69153681397438, 51.964396610856056, 47.45395123958588, 42.46512293815613, 40.84966242313385, 46.86696633696556, 45.28153941035271, 45.08297726511955, 43.79357725381851, 40.49432069063187, 41.27428583800793, 42.79277555644512, 41.4854709059, 42.11139611899853, 48.25144864618778, 59.21294465661049, 53.56386378407478, 51.10960967838764, 47.21989519894123, 46.946188285946846, 42.37639009952545, 43.962383195757866, 41.8364504724741, 43.16383324563503, 43.635205551981926, 46.483213528990746, 48.3941575884819, 47.91017755866051, 51.216501742601395, 51.26816377043724, 53.18766877055168, 52.7046462893486, 54.98128652572632, 54.69985842704773, 57.137556821107864, 55.64915008842945, 53.42306233942509, 52.94873759150505, 51.226088628172874, 51.47246740758419, 50.81624262034893, 58.06633338332176, 59.69116039574146, 66.1715492606163, 62.19275616109371, 58.88977199792862, 57.85571448504925, 62.563764452934265, 61.32629245519638, 66.08004257082939, 65.01370579004288, 66.27871111035347, 62.36268304288387, 70.20665913820267, 33.06202210485935, 11.347543895244598, 7.2802212461829185, 1.9589124480262399, 0.28055809380020946, 0.43736270628869534, 40.79648047685623, 70.059455037117, 65.2379621565342, 57.85471893846989, 70.46489328145981, 68.83711382746696, 63.84993463754654, 53.87891627848148, 39.899569004774094, 39.71881650388241, 59.3991194665432, 47.038515731692314, 0.20225340966135263, 0.1979322696570307, 0.20593610970536247, 0.23476203088648617, 0.12197770003695041, 0.13562359905336052, 0.2248944650636986, 0.08764056794461794, 0.17031184863299131, 0.12045059760566801, 0.19169802137184888, 0.07109792553819716, 0.13420070899883285, 0.2423368056770414], [0.036710683634737507, 0.03545731866324786, 0.028733956096402835, 0.07969206242705695, 0.04916071928164456, 0.09594595001544803, 0.034103930738638155, 0.11077063929405995, 0.14503079582937062, 0.04981747915735468, 0.0702101388014853, 0.032619472112855874, 0.009840268703555921, 0.04195027591777034, 0.023289616401598323, 0.1499633170897141, 0.224799559218809, 0.2849099290324375, 3.8556298334151506, 41.60441592335701, 38.63416850566864, 27.861738950014114, 24.75335754454136, 51.453126445412636, 64.55056384205818, 61.035254672169685, 63.82027342915535, 62.97773323953152, 57.90261156857014, 52.26736955344677, 4.691610150039196, 0.7669704977888614, 0.04663227409764659, 13.904116060584784, 70.90948462486267, 67.31895089149475, 64.30334150791168, 68.91116425395012, 69.07362833619118, 65.82126885652542, 66.08220085501671, 63.76949295401573, 63.58783230185509, 62.85102143883705, 62.96552449464798, 57.929742112755775, 62.01828092336655, 65.75124621391296, 63.76584514975548, 61.373546719551086, 55.85971958935261, 54.553440883755684, 49.925342425704, 48.39566230773926, 45.93006581068039, 45.726031959056854, 47.17736788094044, 50.856216475367546, 49.53944653272629, 52.76709593832493, 49.337103590369225, 47.15265020728111, 45.373361483216286, 44.02418687939644, 41.91514804959297, 40.133260264992714, 42.21137635409832, 43.70097242295742, 45.53823463618755, 45.71231469511986, 44.252053052186966, 47.95513294637203, 48.11215192079544, 43.02369676530361, 40.62874987721443, 38.083578050136566, 39.05447155237198, 38.357193768024445, 39.10752430558205, 38.83621886372566, 40.621222481131554, 39.752771481871605, 39.13563899695873, 39.75626349449158, 44.176444709300995, 48.06679755449295, 57.86951154470444, 47.87472926080227, 14.963956139981747, 42.046624794602394, 51.61654807627201, 48.412020429968834, 45.81021264195442, 39.31469678878784, 36.82401403784752, 38.89619864523411, 39.872206673026085, 39.965256080031395, 40.976347625255585, 37.10040360689163, 36.79683789610863, 37.241098657250404, 38.61777238547802, 38.29808793962002, 39.63158078491688, 44.239642918109894, 50.07009945809841, 46.141509264707565, 40.04254013299942, 41.26076616346836, 43.35223473608494, 39.68941368162632, 39.24204848706722, 37.99035765230656, 39.61037412285805, 38.6916746199131, 43.20520542562008, 40.78651361167431, 41.574519127607346, 41.85869447886944, 41.428276374936104, 45.53820043802261, 48.2699878513813, 48.70539128780365, 50.16830138862133, 45.082825273275375, 44.315714836120605, 42.69849881529808, 45.898025929927826, 46.154044792056084, 49.661135002970695, 55.199873596429825, 55.782025158405304, 59.36709478497505, 57.71951459348202, 49.896076396107674, 54.61240611970425, 55.59616193175316, 57.55666293203831, 57.47309781610966, 58.39517913758755, 62.05557592213154, 57.75137968361378, 61.27669371664524, 15.193488523364067, 5.027067549526691, 5.071792574599385, 1.5368852438405156, 0.3855213458882645, 0.2940198214491829, 38.473577722907066, 61.87746047973633, 49.79931838810444, 48.66987079381943, 67.66750618815422, 58.45745399594307, 51.42051659524441, 28.680925592780113, 28.244038335978985, 34.74038064479828, 44.9585073441267, 5.265711843967438, 0.30437171284575015, 0.07848033565096557, 0.04731713910587132, 0.050200048863189295, 0.03636443834693637, 0.0917237828252837, 0.033217969685210846, 0.06605742179090157, 0.11048090484109707, 0.007745943266854738, 0.07556631506304257, 0.05063260963652283, 0.03524191772157792, 0.016281766365864314, 0.04028174982522614, 0.01937562603416154, 0.04157286784902681, 0.13932886038674042, 0.07622019911650568, 0.02157232564059086, 0.01420922342731501, 0.07823102598194964, 0.06923986235051416, 0.019671290247060824, 0.08666980167618021, 0.05683743547706399, 0.016637576081848238, 0.027014529805455822, 0.0430042963125743, 0.06597283179871738, 0.18190268136095256, 0.26189399999566376, 6.313180262222886, 56.87658682465553, 33.72692562639713, 31.997585222125053, 36.68089471757412, 56.92966237664223, 70.13043522834778, 68.35643202066422, 74.02860045433044, 67.19225808978081, 64.85641703009605, 58.6457034945488, 4.985809838399291, 1.0051630320958793, 0.06840216316049919, 16.362123414874077, 73.29934358596802, 69.97336685657501, 68.44878986477852, 70.23154780268669, 72.03958198428154, 68.66661697626114, 70.23904860019684, 65.06115764379501, 67.76472017168999, 64.75609481334686, 64.96916458010674, 59.42791052162647, 65.69028988480568, 68.38259741663933, 66.70446306467056, 64.90956097841263, 57.98486575484276, 56.27521589398384, 52.23616562783718, 51.9557748734951, 49.610814303159714, 48.57907846570015, 48.88348773121834, 53.06648567318916, 53.06486316025257, 54.70297805964947, 52.75250472128391, 50.21818891167641, 46.51668593287468, 47.24757671356201, 43.27744334936142, 41.90395385026932, 44.868102595210075, 46.65128231048584, 47.57973209023476, 47.17185817658901, 45.46365603804588, 50.55843025445938, 49.88837420940399, 46.216859221458435, 43.419719114899635, 41.35453373193741, 41.60394474864006, 42.04939104616642, 42.690416648983955, 42.67339736223221, 42.22468324005604, 43.16959373652935, 42.19822905957699, 40.97407154738903, 45.982069820165634, 48.99661906063557, 56.352917924523354, 54.383772388100624, 24.724885672330856, 43.75442035496235, 53.7875159829855, 50.04037745296955, 47.4900759011507, 42.111050337553024, 41.12664096057415, 41.265546306967735, 42.21203371882439, 41.991383358836174, 42.10937462747097, 41.045910492539406, 39.62554670870304, 40.02053551375866, 40.031079947948456, 40.28753958642483, 41.380170956254005, 48.481944277882576, 52.1263325214386, 49.7687566280365, 44.34075929224491, 43.92392925918102, 45.36714121699333, 44.55450542271137, 41.5582749992609, 40.01570597290993, 40.91771297156811, 41.113980039954185, 44.02493543922901, 43.10304030776024, 43.54695148766041, 45.21220073103905, 44.98409517109394, 47.2474817186594, 49.42731834948063, 50.220202803611755, 51.47977061569691, 48.03396351635456, 46.39161944389343, 45.35023972392082, 48.03576461970806, 51.4417764544487, 52.360783740878105, 56.173628345131874, 58.912270590662956, 61.929852068424225, 61.4756016433239, 52.68770679831505, 55.90945512056351, 58.008367493748665, 58.21460522711277, 60.793872624635696, 60.10801702737808, 64.90184739232063, 58.85517865419388, 64.61275890469551, 21.313820108771324, 5.876800753176212, 5.824274271726608, 3.034909497946501, 0.1008061044558417, 0.56018375325948, 46.19263552129269, 64.5724506676197, 54.14574556052685, 54.55315209925175, 70.2462150156498, 67.677431255579, 57.58752107620239, 36.840774938464165, 32.580682933330536, 33.351334780454636, 56.3629037886858, 6.397717176005244, 0.24312904832186177, 0.12813724373700097, 0.10791425389470533, 0.0753504094609525, 0.01454076398658799, 0.04763897515658755, 0.016088032425614074, 0.07783255205140449, 0.007355363932219916, 0.06996724870987236, 0.050128487273468636, 0.14053067949134856, 0.057240113674197346, 0.02444618490699213, 0.10650822543539107, 0.14744593732757494, 0.13509640702977777, 0.18218080862425268, 0.1492191359284334, 0.2155498313368298, 0.12957850936800241, 0.17766960459994152, 0.12794142065104097, 0.16711800126358867, 0.21926376095507294, 0.1617395828361623, 0.08712778842891566, 0.07811376664903946, 0.15312197181629017, 0.31557241338305175, 0.5257886520121247, 0.3830461943289265, 10.271178502589464, 70.68632259964943, 52.87841476500034, 45.74641786515713, 39.80794072151184, 65.50980716943741, 77.81767353415489, 73.89026507735252, 74.9685788154602, 75.99627166986465, 70.43577164411545, 62.19665475189686, 5.451644891873002, 1.1988077661953866, 0.17030562943546101, 17.935341596603394, 71.126718968153, 72.2909764945507, 71.60045474767685, 74.38438296318054, 76.08208626508713, 74.30771827697754, 72.98392251133919, 69.37551453709602, 70.83025127649307, 67.1239073574543, 68.70443254709244, 63.10331270098686, 66.8920361995697, 69.12476599216461, 72.26672619581223, 69.6853955090046, 62.07491688430309, 59.88534897565842, 55.904154404997826, 54.21401269733906, 52.31503039598465, 51.51784457266331, 53.00258830189705, 55.457036197185516, 55.458073541522026, 56.779217049479485, 54.66153748333454, 52.660998031497, 51.33111119270325, 49.308650717139244, 45.74543371796608, 43.51910278201103, 48.402399346232414, 49.32388789951801, 50.646653920412064, 50.41415959596634, 49.10350352525711, 51.97496384382248, 53.39106805622578, 47.14625135064125, 45.238894298672676, 42.316623106598854, 43.493575751781464, 42.38115884363651, 43.934796676039696, 43.95105600357056, 46.162176355719566, 45.15028305351734, 44.19816434383392, 44.37832407653332, 47.645168378949165, 51.82429052889347, 61.97686314582825, 51.611406952142715, 14.585161115974188, 45.53473882377148, 57.96902820467949, 52.3693560808897, 51.569552198052406, 44.81553241610527, 43.32760825753212, 43.87183405458927, 45.248788967728615, 46.048623248934746, 44.37669396400452, 42.25370228290558, 40.34776255488396, 40.9956543892622, 43.02189566195011, 43.55962760746479, 42.594357803463936, 49.33220565319061, 52.81021222472191, 50.77697932720184, 45.57755872607231, 47.50915087759495, 47.27088466286659, 44.46446165442467, 43.38160715997219, 42.562705501914024, 44.773955047130585, 44.503717347979546, 46.962367817759514, 45.707800537347794, 46.88866697251797, 47.03471213579178, 45.9184118360281, 49.45532284677029, 52.88187637925148, 51.87803864479065, 55.817921832203865, 50.79049900174141, 48.9340478181839, 47.820848152041435, 50.56914947926998, 53.82899075746536, 54.70054239034653, 57.887602373957634, 63.42042088508606, 63.795323967933655, 63.311742916703224, 53.56862872838974, 56.17914564907551, 58.99063378572464, 60.15161208808422, 61.37639656662941, 61.10834375023842, 65.6521475315094, 60.07170997560024, 67.11975038051605, 28.043498396873474, 6.279835626482964, 9.752846416085958, 4.237938718870282, 0.4277930682292208, 1.086115431971848, 51.39170654118061, 68.46812322735786, 60.67790664732456, 61.49330489337444, 75.23066595196724, 69.20440971851349, 68.49475979804993, 42.52003759145737, 42.96080254018307, 46.83736212551594, 66.63937255740166, 13.976507876068354, 0.5077603412792087, 0.3763511613942683, 0.2582281467039138, 0.18922698131063953, 0.15521315101068467, 0.1810665035736747, 0.07376202789600939, 0.2793632954126224, 0.14644132170360535, 0.10071714321384206, 0.2252483952906914, 0.23289509903406724, 0.09406770783243701, 0.12832021282520145], [0.04895200880127959, 0.013653452224389184, 0.020752799791807774, 0.025574694664101116, 0.11234935809625313, 0.06219229813723359, 0.0450656189059373, 0.029658020866918378, 0.03204271946742665, 0.05371373590605799, 0.06981514554354362, 0.05221402614552062, 0.09821493295021355, 0.04724605991214048, 0.03683597671624739, 0.039549966240883805, 0.043211329539190046, 0.20441826927708462, 0.7190188521053642, 28.772622272372246, 41.82978183031082, 30.78759904950857, 22.469619289040565, 37.058191671967506, 69.77652221918106, 60.100079253315926, 51.29783257842064, 60.0426909327507, 55.33278666436672, 62.38015450537205, 7.459430554881692, 0.7133082929067314, 0.5090065556578338, 32.81630828976631, 82.9126301407814, 70.26775225996971, 70.01334831118584, 62.343262284994125, 69.1618900001049, 65.56058764457703, 63.19429121911526, 63.89096483588219, 63.13797064125538, 63.607845827937126, 58.95922467112541, 63.68383415043354, 67.18388333916664, 60.89612893760204, 62.17840813100338, 61.88323616981506, 54.64763402938843, 51.51890091598034, 47.722627222537994, 46.29925400018692, 45.70514068007469, 45.03237538039684, 44.80070561170578, 44.55824442207813, 46.00866459310055, 46.09828278422356, 45.009523406624794, 45.02229832112789, 45.13230241835117, 46.288401782512665, 41.0830345004797, 41.72613479197025, 42.60776728391647, 43.58908362686634, 46.67290695011616, 44.46396008133888, 40.89125119149685, 45.12135520577431, 44.736747443675995, 39.309297278523445, 39.82966795563698, 37.491923198103905, 37.3306180536747, 39.23948362469673, 40.13017863035202, 40.324469804763794, 40.71932561695576, 42.56839759647846, 42.14676842093468, 41.28044530749321, 44.44686099886894, 51.783286929130554, 58.19573163986206, 58.56367349624634, 16.708260141313076, 35.75188256800175, 56.997739523649216, 50.41610889136791, 50.313491597771645, 41.04403339326382, 41.18520341813564, 40.82747541368008, 43.36924262344837, 39.43137712776661, 39.4889098405838, 36.76557697355747, 36.00641191005707, 35.44620417058468, 38.23555089533329, 37.79870353639126, 38.56626234948635, 39.51196700334549, 45.922720804810524, 42.97994211316109, 40.64585655927658, 44.8664078861475, 44.09881107509136, 41.25186324119568, 38.880125507712364, 38.01974527537823, 37.31586344540119, 38.94096404314041, 41.350277960300446, 41.52207054197788, 39.919935911893845, 40.529202818870544, 40.834873616695404, 44.498401433229446, 43.495205864310265, 44.60434354841709, 44.43846344947815, 43.661503940820694, 44.56427849829197, 45.14489494264126, 44.707386419177055, 50.69658324122429, 52.08258546888828, 56.211170330643654, 57.35632248222828, 60.52488885819912, 61.982566639781, 61.18681713938713, 52.95343413949013, 57.83607333898544, 52.46452197432518, 62.93476514518261, 62.74649664759636, 64.86728444695473, 55.8564555644989, 67.80338689684868, 22.59194042533636, 4.692287463694811, 0.8089806872885674, 3.0814539128914475, 0.1614540340960957, 0.7946223265025765, 46.74186185002327, 58.38148847222328, 52.25666552782059, 63.15040737390518, 50.66730961203575, 40.057199746370316, 39.30566847324371, 23.36441807448864, 31.01343423128128, 41.90523438155651, 28.922440633177757, 0.2300466620363295, 0.04060929670231417, 0.11469119766843505, 0.04016946659248788, 0.10770696462714113, 0.06448935280786827, 0.042927532267640345, 0.02259048731502844, 0.026680234950617887, 0.030603398263338022, 0.07293814749573357, 0.004961522072335356, 0.05456564722408075, 0.0618313917220803, 0.02208176734711742, 0.06064078646886628, 0.03885930134856608, 0.04177039416390471, 0.08292859070934355, 0.10217599774478003, 0.04546674601442646, 0.03827416614512913, 0.04310927681217436, 0.031204860715661198, 0.059078354097437114, 0.02425058075459674, 0.06473312605521642, 0.08271227692603134, 0.03853632239042781, 0.037047919249744155, 0.0616262064431794, 0.032251619195449166, 0.23588844778714702, 1.0691007762216032, 39.56930212676525, 47.711839601397514, 31.53230968862772, 35.45723497867584, 45.89010335505009, 78.34963738918304, 65.96332803368568, 58.83897252380848, 66.1838074028492, 62.653606832027435, 66.58834889531136, 7.959380652755499, 0.5922363989520818, 0.538711283588782, 35.36224767565727, 84.4058284163475, 70.83399027585983, 71.55226573348045, 65.22968620061874, 72.14861333370209, 67.44023278355598, 66.59904912114143, 67.48057901859283, 65.36855354905128, 64.94977042078972, 63.3714035153389, 67.04956814646721, 69.1424198448658, 64.10994708538055, 65.53015887737274, 62.53368906676769, 58.353020399808884, 52.90380880236626, 50.26785604655743, 47.37965762615204, 48.70704039931297, 47.55435325205326, 47.01911397278309, 46.129562705755234, 47.4362213909626, 48.50501663982868, 45.73111228644848, 47.85359479486942, 48.14772941172123, 48.057712242007256, 43.065228536725044, 44.215829595923424, 44.278043657541275, 45.279172137379646, 48.5620553791523, 46.56211629509926, 43.59845012426376, 48.51455792784691, 46.87632143497467, 43.093115240335464, 40.886968821287155, 42.50834561884403, 40.04620313644409, 41.2815510481596, 41.42097316682339, 43.805242627859116, 43.24914626777172, 44.69933845102787, 44.02967758476734, 44.09288339316845, 46.838209480047226, 54.47843290865421, 56.7167180031538, 64.1251614689827, 28.871158584952354, 40.61104282736778, 57.02599100768566, 51.63871988654137, 53.964768871665, 42.921098470687866, 41.90315209329128, 42.97771543264389, 43.10894899070263, 40.92467799782753, 42.045089676976204, 39.572083577513695, 40.33780328929424, 39.26101326942444, 39.97792460024357, 39.90205027163029, 38.5105649381876, 40.96226178109646, 48.49313847720623, 47.280988320708275, 43.71240980923176, 47.36627474427223, 45.412677973508835, 44.464503452181816, 42.194007486104965, 39.61784452199936, 41.113543063402176, 41.35981924831867, 41.57897248864174, 43.574834391474724, 42.88368567824364, 43.356494307518005, 43.696766048669815, 47.954312190413475, 44.78749372065067, 46.87668241560459, 46.68553747236729, 44.90514300763607, 45.44910281896591, 46.75786279141903, 47.59852208197117, 53.14220421016216, 53.31256806850433, 56.897417306900024, 59.93871331214905, 59.8593507707119, 61.27123340964317, 63.19960333406925, 53.17661516368389, 56.852131336927414, 55.43820820748806, 63.7514591217041, 63.2297433167696, 66.77264660596848, 60.2126520127058, 71.00809693336487, 32.00926959514618, 4.390638275071979, 1.9334360025823116, 4.002955053001642, 0.3345963597530499, 2.2465004911646247, 53.37306082248688, 62.9727479070425, 58.269774466753006, 69.59700465202332, 56.10663414001465, 52.67248101532459, 45.80897390842438, 31.057986840605736, 32.602892741560936, 46.54953896999359, 34.91300158202648, 0.5727268802002072, 0.02950024398160167, 0.022697723943565506, 0.0633043136622291, 0.051734357548411936, 0.011676624999381602, 0.03557201387593523, 0.06493449298432097, 0.028868038061773404, 0.025055590194824617, 0.06576687097549438, 0.011769566935981857, 0.0585570176190231, 0.0320700638985727, 0.048079065018100664, 0.14986234047682956, 0.14049321587663144, 0.14494656206807122, 0.16108494921354577, 0.23076507583027706, 0.16376980202039704, 0.2273993767448701, 0.10674921562895179, 0.05077964022348169, 0.16128495801240206, 0.15805493836523965, 0.1759794820100069, 0.2835464256349951, 0.13093313667923212, 0.12158717450802214, 0.15229079610435292, 0.20794443553313613, 0.47041042358614504, 1.3683661865070462, 57.770903035998344, 65.2312745153904, 47.384164184331894, 40.20143620669842, 52.48192884027958, 82.43552014231682, 74.08873602747917, 66.45906463265419, 73.2200038433075, 67.74614676833153, 73.83174061775208, 9.568378664553165, 0.8396633877418935, 1.408327454701066, 37.35821597278118, 85.32446712255478, 74.8734699189663, 75.43865159153938, 69.18807059526443, 73.18989425897598, 68.43387186527252, 69.71577867865562, 69.01609942317009, 67.95639708638191, 67.71603718400002, 67.04537317156792, 70.58027788996696, 70.54471179842949, 67.92922854423523, 69.94959533214569, 69.2809908092022, 59.461056143045425, 56.988521218299866, 52.47179098427296, 50.40501348674297, 52.50776745378971, 51.027762070298195, 50.44789798557758, 48.65092121064663, 49.846196472644806, 50.67920297384262, 48.902718499302864, 50.782515630126, 50.40642701089382, 51.66171245276928, 44.213644713163376, 46.534088999032974, 46.8424728512764, 49.12657588720322, 50.31844273209572, 47.48963512480259, 45.425471886992455, 51.58864237368107, 49.64031212031841, 43.97874511778355, 43.31672564148903, 43.25383521616459, 41.3083890080452, 43.73816482722759, 43.711224272847176, 46.152236089110374, 46.64845146238804, 48.1623662263155, 47.87105105817318, 44.403292536735535, 48.00978161394596, 57.74398908019066, 61.26581870019436, 65.06874203681946, 16.021076515316963, 37.41038337349892, 61.75942361354828, 54.003283604979515, 56.43547609448433, 46.205566227436066, 45.50842523574829, 46.227722838521004, 48.467261865735054, 43.46928745508194, 45.3207191079855, 40.84501527249813, 43.51442523300648, 40.25427617132664, 42.974151223897934, 42.18613810837269, 41.240859031677246, 44.285597652196884, 49.871157333254814, 48.94774228334427, 44.589733332395554, 49.92977298796177, 47.5747961550951, 46.42457887530327, 44.48791779577732, 42.422097846865654, 43.62641662359238, 44.84156481921673, 46.17046371102333, 46.66049301624298, 45.70796772837639, 45.06685093045235, 45.855707600712776, 49.25372466444969, 48.6782531440258, 48.06230999529362, 49.87600967288017, 47.4999363720417, 47.49415688216686, 50.393747091293335, 50.66689923405647, 56.51161640882492, 56.08053334057331, 61.23154453933239, 64.17119979858398, 61.69956162571907, 61.754096299409866, 63.17371912300587, 53.762167543172836, 57.11036168038845, 56.91459238529205, 64.7734522819519, 65.00683575868607, 70.27064010500908, 64.75138306617737, 71.26441597938538, 37.75336056947708, 5.7118786778301, 3.7928244285285473, 5.588162066414952, 1.1594680021516979, 2.658837027847767, 58.57000395655632, 67.57021620869637, 61.90532438457012, 70.993292927742, 65.59405624866486, 58.77930052578449, 52.16490425169468, 37.8379250317812, 47.456257715821266, 52.172120064496994, 52.49663405120373, 1.025234148837626, 0.1517967038671486, 0.2002165259909816, 0.30364233010914177, 0.1507970309467055, 0.20311125816078857, 0.10323486436391249, 0.16263609722955152, 0.12554386805277318, 0.14624147617723793, 0.27038031024858356, 0.12382024491671473, 0.1661031588446349, 0.10201045428402722, 0.2475510016665794], [0.03436917802901007, 0.03222394079784863, 0.028765133720298763, 0.048407810463686474, 0.030859669277560897, 0.005227979991104803, 0.05934361994150095, 0.07424180410453118, 0.063718780875206, 0.07399003050522879, 0.017477473884355277, 0.10345030241296627, 0.02069889203994535, 0.06174507252580952, 0.03376591586857103, 0.11436172120738775, 0.049813716468634084, 0.1859255225281231, 0.09918508323607966, 11.1419977247715, 45.80697141587734, 34.1326754540205, 32.17229604721069, 20.90824507176876, 52.879505306482315, 68.66437509655952, 58.231039345264435, 59.47113320231438, 55.12283653020859, 63.541429191827774, 10.940252300351858, 0.5003711034078151, 2.0095962658524513, 52.71543011069298, 81.91572323441505, 68.31280276179314, 70.08737593889236, 66.81756779551506, 64.35169011354446, 65.99417477846146, 67.22206369042397, 61.17190673947334, 60.651205480098724, 61.85037933290005, 64.86276268959045, 70.96016630530357, 63.29582557082176, 63.149012848734856, 59.391451478004456, 55.128418430686, 47.62361213564873, 46.2785679101944, 45.42256124317646, 47.0535971224308, 45.68800359964371, 44.22062873840332, 44.1858834028244, 45.11010780930519, 43.18000517785549, 43.186293840408325, 42.131022065877914, 46.65998384356499, 45.679967030882835, 43.51980574429035, 41.673511415719986, 41.55822940170765, 44.911165684461594, 45.09171299636364, 47.793854400515556, 44.95589308440685, 43.366347178816795, 43.812264651060104, 40.40203124284744, 40.73251090943813, 39.89560581743717, 39.49282743036747, 37.92278207838535, 40.51830880343914, 38.268388733267784, 41.05941116809845, 41.022765934467316, 44.04338724911213, 41.053156703710556, 45.347378477454185, 46.17430530488491, 55.612493455410004, 57.60694183409214, 63.67898941040039, 21.005656644701958, 29.201733246445656, 61.403086334466934, 50.734877586364746, 52.68179811537266, 46.27746216952801, 43.33080008625984, 40.1037472486496, 42.98946060240269, 40.68743392825127, 38.691385835409164, 35.50682991743088, 38.056223317980766, 36.416930481791496, 36.968493685126305, 38.53351190686226, 37.930647656321526, 38.85995998978615, 40.810881704092026, 43.0109104514122, 39.94322866201401, 44.45482537150383, 45.18864959478378, 42.17713639140129, 41.2777778506279, 38.70973885059357, 38.52232910692692, 38.907301649451256, 38.866165056824684, 40.219698026776314, 40.31802535057068, 41.16500750184059, 40.519923716783524, 42.53943935036659, 40.33070906996727, 42.6980010420084, 42.87697523832321, 42.118896916508675, 43.612805753946304, 44.53380033373833, 46.437034606933594, 50.31111292541027, 52.893507555127144, 53.07964436709881, 57.10657708346844, 58.59500281512737, 55.115939900279045, 58.69105406105518, 58.07677902281284, 56.369314044713974, 58.776602670550346, 64.79099974036217, 59.25453342497349, 62.23337598145008, 58.94773408770561, 61.6156355291605, 52.93765738606453, 8.84705862030387, 2.693495680578053, 3.761571580544114, 0.14032783568836749, 5.07170470431447, 49.89634618163109, 59.33649882674217, 46.42926402390003, 39.429975003004074, 46.07171081006527, 42.01486609876156, 32.20656260848045, 31.44256040453911, 32.548464462161064, 47.41261325776577, 12.489120438694954, 0.5734808428678662, 0.12400477993651293, 0.07891779459896497, 0.11372514403774403, 0.05537108896533027, 0.05916028349020053, 0.04814293424715288, 0.1092762804182712, 0.0756838489905931, 0.09801192587474361, 0.013671458582393825, 0.05048445840657223, 0.01798927376512438, 0.05987042975903023, 0.03722459863638505, 0.05683527953806333, 0.08782152581261471, 0.04416882620716933, 0.049501658213557675, 0.017979768708755728, 0.010663597131497227, 0.023491645697504282, 0.01750524690578459, 0.051558572449721396, 0.13383582467213273, 0.014173886993376072, 0.050570028033689596, 0.005871832527191145, 0.03306791855720803, 0.0159523140246165, 0.06761791344615631, 0.04822602881176863, 0.23495271831052378, 0.15799298387719318, 15.518188700079918, 59.60099123418331, 33.45222696661949, 40.893211886286736, 31.421678625047207, 59.603035524487495, 76.62989526987076, 61.68090462684631, 68.18733349442482, 59.18175972998142, 70.61303213238716, 11.485953368246555, 0.3867219923995435, 2.203821181319654, 56.75118215382099, 83.14275339245796, 72.44679093360901, 72.21798241138458, 68.28450188040733, 65.9232933819294, 68.47009912133217, 69.12804141640663, 63.05324278771877, 63.09207670390606, 64.18319195508957, 68.49780723452568, 70.74856325984001, 64.53225642442703, 67.51798421144485, 64.23793181777, 58.45381759107113, 50.56544087827206, 47.80219875276089, 47.26605512201786, 49.48740452528, 47.83871479332447, 46.31731063127518, 46.02570287883282, 46.347116231918335, 47.110461071133614, 46.53703384101391, 45.432113930583, 47.64081761240959, 46.43494851887226, 43.986428305506706, 42.095254585146904, 44.50948543846607, 44.70032259821892, 46.40962667763233, 50.395077019929886, 46.442069336771965, 44.6690920740366, 46.53657406568527, 42.40980550646782, 43.47429558634758, 42.92766451835632, 42.84536853432655, 40.121230110526085, 42.927478328347206, 40.99566958844662, 44.886334016919136, 41.94049268960953, 46.0300612449646, 43.61051447689533, 48.10739077627659, 47.32899494469166, 55.128528624773026, 54.922252893447876, 68.38878348469734, 35.11095955967903, 33.40698279440403, 61.72873646020889, 53.53928670287132, 53.60879637300968, 46.827163472771645, 46.36650279164314, 42.83296599984169, 45.68306386470795, 41.88248120248318, 42.30581268668175, 39.64700035750866, 40.230641439557076, 39.93464112281799, 38.29454652965069, 41.01740442216396, 42.226233556866646, 41.581731140613556, 43.379783257842064, 44.48585070669651, 42.6986850053072, 47.7205753326416, 48.24835181236267, 42.49190390110016, 43.123274222016335, 39.710426554083824, 40.28900630772114, 40.762088522315025, 41.54732018709183, 43.16269710659981, 42.9592028260231, 42.67931744456291, 41.43176458775997, 44.744122847914696, 43.50508153438568, 44.92489814758301, 44.17705647647381, 44.68508921563625, 44.89881254732609, 46.833467334508896, 49.50280509889126, 53.96988719701767, 54.58574675023556, 56.26679174602032, 59.91911016404629, 61.03484809398651, 55.93961790204048, 57.22734600305557, 57.79366761445999, 57.78486728668213, 60.7062379270792, 63.47188152372837, 61.66280999779701, 63.903336971998215, 61.97779409587383, 65.43172895908356, 59.55743417143822, 14.370622728019953, 3.69118629489094, 4.50830846093595, 0.057489033715683036, 7.132992446422577, 56.627418994903564, 63.81093353033066, 55.416724160313606, 46.62154130637646, 52.23029114305973, 47.123984545469284, 38.31329092383385, 41.08477480709553, 36.548867002129555, 56.66542075574398, 15.809580814093351, 0.6670208391733468, 0.20243005565134808, 0.13752409082371742, 0.09322174111730419, 0.0592553674505325, 0.020138455511187203, 0.008152313184837112, 0.11429584817960858, 0.03737198545422871, 0.051506585004972294, 0.0493056087725563, 0.09538922051433474, 0.023596019491378684, 0.054458239901578054, 0.021102640785102267, 0.099556602363009, 0.23919335013488308, 0.1825713415746577, 0.1448596120462753, 0.10543329874053597, 0.12912983656860888, 0.11314620947814547, 0.1743759383680299, 0.17793786129914224, 0.28149916674010456, 0.13348092965316027, 0.1554081725771539, 0.17750889994204044, 0.20212623523548245, 0.10559157657553442, 0.21750690444605425, 0.08779879382927902, 0.63691564835608, 0.39368969039060175, 21.230443082749844, 74.44564327597618, 46.45741291344166, 46.89543440937996, 33.15389357507229, 67.939662784338, 82.37543776631355, 70.87850868701935, 77.04618573188782, 65.98704636096954, 74.81616139411926, 13.854531571269035, 0.5567895260173827, 2.7971572056412697, 58.10262143611908, 85.27203753590584, 76.18463516235352, 77.20307171344757, 69.90155830979347, 67.99967676401138, 70.23479282855988, 70.15907049179077, 65.67574426531792, 66.80732354521751, 69.57064166665077, 71.32233247160912, 74.80980053544044, 66.11807852983475, 71.52265012264252, 65.53757607936859, 62.33124352991581, 50.916549637913704, 51.39930993318558, 49.01235021650791, 53.38772803544998, 51.49513319134712, 49.35679033398628, 50.57792320847511, 50.91451294720173, 49.23086889088154, 48.927835151553154, 48.620260655879974, 51.3243817538023, 49.92728032171726, 47.51374863088131, 45.51774613559246, 45.71139134466648, 46.87233924865723, 49.40548092126846, 51.705364510416985, 50.52285276353359, 50.395111218094826, 49.49142470955849, 44.475272074341774, 44.85552906990051, 45.23698680102825, 44.72045011818409, 41.00882828235626, 44.77589674293995, 42.31215074658394, 46.6677126288414, 43.17973919212818, 50.20554319024086, 45.45615144073963, 50.31313821673393, 48.6531250923872, 59.50870178639889, 60.56361638009548, 70.18031895160675, 21.462756916880608, 28.740985170006752, 68.83230328559875, 53.26583057641983, 57.54524074494839, 49.42093849182129, 47.516317293047905, 45.57612620294094, 49.111661687493324, 45.3664268553257, 43.27327877283096, 40.343396589159966, 42.83572845160961, 41.58941052854061, 39.9288160353899, 42.80577465891838, 44.696667194366455, 44.04975950717926, 46.18685223162174, 47.13054299354553, 44.82132710516453, 51.052544340491295, 49.63166758418083, 45.24224951863289, 46.24202527105808, 42.092245146632195, 43.26279513537884, 43.37031036615372, 43.30792151391506, 45.34245774149895, 44.6008363366127, 46.96760393679142, 43.073033317923546, 48.231788501143456, 45.56349568068981, 45.85612177848816, 46.26927360892296, 45.99468894302845, 48.412784188985825, 48.81759166717529, 50.84086909890175, 57.26409763097763, 56.51320092380047, 57.67343446612358, 63.74002553522587, 63.24639402329922, 56.830556094646454, 56.64547562599182, 57.616456523537636, 60.150456950068474, 59.81457017362118, 67.39160299301147, 63.940141797065735, 66.89178541302681, 65.86887270212173, 69.12700787186623, 63.18998605012894, 17.194645442068577, 4.794086376205087, 6.57191882841289, 1.182352036703378, 7.974435444921255, 61.17232471704483, 68.3772549033165, 55.811777561903, 55.489106476306915, 59.25393305718899, 55.51341377198696, 45.27443379163742, 49.36493709683418, 43.49938943982124, 63.84776875376701, 24.21222858130932, 0.848136042477563, 0.3660710505209863, 0.41660833870992064, 0.18556574417743832, 0.2790116361575201, 0.23278337612282485, 0.19711541739525273, 0.19439633673755452, 0.1843738104798831, 0.21906393027165905, 0.10507540544494987, 0.16088789416244254, 0.17909522575791925, 0.12121747364290059, 0.13938596122898161], [0.025687938978080638, 0.04938429869071115, 0.06959725098568015, 0.03327309270389378, 0.060691708931699395, 0.0402175763156265, 0.09206449540215544, 0.04317778075346723, 0.05230105780356098, 0.04025014175567776, 0.04072040734172333, 0.11356319257174619, 0.035461708466755226, 0.02388591721683042, 0.02931023933342658, 0.07031463319435716, 0.015251035492838128, 0.082945355825359, 0.16188838344532996, 0.2413650820381008, 31.418049819767475, 44.588430002331734, 28.060519583523273, 29.92915291339159, 31.350339353084564, 68.15555199980736, 63.56865473091602, 62.38941080868244, 46.68910928070545, 67.43670657277107, 15.458375159651041, 0.3107192722382024, 6.301379995420575, 66.48353531956673, 77.5206358730793, 68.48094373941422, 64.16319742798805, 67.52324312925339, 71.53303876519203, 67.60671705007553, 65.89065313339233, 69.70681875944138, 66.35621935129166, 68.59923899173737, 67.74746909737587, 62.2222425788641, 55.70654600858688, 54.19123291969299, 49.061933755874634, 46.692422702908516, 46.930521726608276, 44.081491604447365, 43.82891155779362, 43.690712973475456, 45.21818920969963, 45.33080756664276, 42.364644929766655, 45.01102812588215, 44.694155529141426, 44.74016346037388, 43.54451581835747, 44.749130979180336, 42.79557980597019, 43.2934594899416, 41.81577958166599, 42.63640634715557, 43.495642840862274, 45.73625721037388, 45.49856476485729, 43.96951541304588, 40.974006950855255, 41.57350458204746, 42.45046332478523, 40.33828966319561, 38.937658220529556, 38.846546709537506, 38.548764288425446, 40.46962581574917, 39.011146277189255, 42.48777732253075, 40.74059687554836, 46.664672791957855, 44.204529002308846, 49.760066494345665, 46.80025331676006, 59.02211509644985, 54.24052767455578, 69.98975917696953, 29.339553751051426, 21.127464808523655, 60.889167711138725, 55.38257159292698, 57.891873344779015, 52.47038125991821, 47.11137302219868, 43.12232047319412, 44.67717804014683, 41.07956528663635, 41.413331776857376, 36.26665234565735, 36.117476150393486, 35.65010882914066, 39.19847622513771, 38.79684917628765, 39.58818331360817, 37.648524194955826, 39.50467899441719, 39.028819128870964, 38.429697677493095, 43.257365226745605, 43.61970618367195, 40.41910372674465, 39.7712042927742, 40.885201916098595, 40.11924661695957, 38.3600702136755, 39.829090386629105, 41.26301944255829, 40.45394405722618, 39.649439826607704, 40.448681339621544, 42.97428421676159, 41.840717643499374, 39.36863489449024, 41.41268961131573, 42.3194045573473, 43.388454392552376, 42.884198650717735, 46.115636453032494, 49.31691527366638, 52.20333158969879, 54.78777810931206, 57.19181030988693, 58.099308013916016, 56.31507955491543, 59.73685294389725, 58.52015443146229, 58.63630659878254, 60.00003822147846, 56.807616725564, 60.72280503809452, 55.482836812734604, 63.12812156975269, 57.60675564408302, 65.72885021567345, 33.15138190984726, 5.117686036974192, 3.3558032289147377, 0.27874196937773377, 9.59680873900652, 54.287113174796104, 52.48879887163639, 40.463295355439186, 45.32664678990841, 58.101527094841, 56.99239321053028, 24.227216877043247, 26.691052168607712, 28.018003664910793, 48.54097031056881, 2.4855316523462534, 0.0716977589763701, 0.0366434932948323, 0.06528319849167019, 0.018967461510328576, 0.021476006004377268, 0.05559419711062219, 0.028008059598505497, 0.02393283022684045, 0.10447583175846376, 0.012031899441353744, 0.03879807787598111, 0.009741995363583555, 0.031884716227068566, 0.025546838151058182, 0.10024596107541583, 0.019106534418824594, 0.059848013188457116, 0.0205013972663437, 0.006350624462356791, 0.03297190320154186, 0.024310125118063297, 0.04278348140360322, 0.013340785408217926, 0.018807406231644563, 0.01727775266772369, 0.073186329100281, 0.03145120550470892, 0.03126189847534988, 0.03973560706072021, 0.021265356663207058, 0.04366611392470077, 0.03161589178489521, 0.0784447199839633, 0.18652519269380718, 0.4565967695089057, 40.197419822216034, 49.598654955625534, 28.40777724981308, 43.21059353649616, 38.74948851764202, 79.78178054094315, 72.83294901251793, 68.87973994016647, 54.235910922288895, 73.63505557179451, 17.854333743453026, 0.4381583776557818, 6.848507411777973, 70.84441691637039, 79.82096403837204, 69.91386964917183, 66.98366448283195, 69.5458821952343, 73.85838478803635, 70.27281358838081, 69.89079728722572, 73.10763627290726, 68.91540482640266, 71.0369373857975, 72.36432775855064, 65.80844074487686, 60.29638811945915, 56.29559800028801, 54.65251296758652, 49.44716088473797, 49.46198008954525, 46.91767081618309, 46.47016882896423, 47.646581903100014, 45.991022139787674, 47.6720405369997, 47.00469754636288, 45.62287129461765, 47.74778187274933, 49.55269642174244, 43.603184670209885, 45.927215963602066, 47.547084242105484, 47.02877685427666, 44.25704598426819, 43.68112988770008, 43.79837639629841, 46.91761001944542, 46.65607005357742, 45.987951904535294, 42.06072963774204, 44.365157783031464, 44.60845872759819, 43.81545647978783, 40.728901103138924, 42.162237390875816, 41.87232434749603, 43.26891280710697, 41.38843171298504, 44.87564139068127, 42.34072521328926, 48.53145942091942, 46.30341857671738, 50.93399070203304, 49.52926307916641, 59.52833913266659, 55.186752900481224, 70.74757531285286, 45.98639018833637, 27.65858855098486, 60.3579980134964, 57.06971526145935, 59.32087406516075, 53.553969115018845, 48.95953305065632, 45.23322120308876, 45.14554850757122, 44.08995375037193, 43.853272050619125, 40.09743958711624, 38.46608452498913, 39.66400444507599, 42.67265260219574, 41.41047812998295, 40.92229172587395, 40.355118960142136, 40.98964311182499, 41.795226484537125, 42.297605127096176, 46.061151176691055, 45.984471291303635, 43.738088831305504, 43.26724089682102, 42.98194080591202, 42.11974047124386, 41.234425976872444, 43.3999677747488, 43.74233700335026, 44.00625944137573, 41.668450087308884, 43.62217225134373, 43.387166261672974, 43.472532480955124, 42.20629222691059, 43.67065005004406, 43.83290894329548, 43.38606812059879, 45.448848232626915, 49.69555735588074, 51.13841973245144, 53.80073547363281, 56.89204819500446, 60.40720917284489, 58.247579857707024, 57.361087426543236, 58.93296808004379, 61.88464589416981, 61.3937958329916, 60.75671061873436, 59.90748278796673, 61.038727685809135, 57.91177287697792, 65.18284231424332, 62.27282166481018, 69.51040729880333, 37.18002833425999, 5.886052781715989, 3.359625586308539, 0.294574651052244, 11.812089867889881, 60.55131644010544, 56.33988842368126, 43.04725170135498, 50.06104834377766, 69.54308554530144, 59.374059811234474, 31.908540800213814, 33.143026158213615, 34.44539487361908, 55.70854090154171, 2.217586417682469, 0.07843247454729863, 0.11854431708343327, 0.10920767628704198, 0.03486993104161229, 0.06895660684676841, 0.043060295065515675, 0.04757649374369066, 0.0843770032224711, 0.003693460489557765, 0.06321232445770875, 0.03286751642008312, 0.10008131561335176, 0.07394784683128819, 0.0344282863807166, 0.04097189521417022, 0.15837725310120732, 0.13328748143976554, 0.17327481386018917, 0.21193141612457111, 0.22653097490547225, 0.10497323397430591, 0.19205897231586277, 0.1473879162222147, 0.2074447920313105, 0.09741378453327343, 0.11638546886388212, 0.24680031929165125, 0.0890699443698395, 0.21754080575192347, 0.12544361874461174, 0.20498712547123432, 0.15441416966496035, 0.42168358981143683, 0.3932312806136906, 0.6677179236430675, 55.87635889649391, 65.24883717298508, 42.062420547008514, 47.06347279250622, 42.867004573345184, 84.09595504403114, 78.95649522542953, 75.55465176701546, 65.52233129739761, 82.2805492579937, 20.740998946130276, 0.4571087326621637, 7.864711582660675, 71.15952640771866, 82.66014888882637, 74.38904911279678, 70.05950823426247, 75.14154553413391, 77.67202734947205, 74.53779593110085, 72.85797446966171, 76.15059658885002, 73.14901605248451, 74.01464760303497, 74.54971969127655, 69.12773743271828, 62.935635298490524, 60.25383420288563, 56.4622912555933, 51.954216957092285, 52.843874618411064, 50.34092992544174, 47.530277743935585, 48.72854724526405, 49.732472375035286, 50.78573785722256, 48.78408506512642, 50.08447028696537, 50.99742829799652, 52.44911380112171, 46.880090832710266, 49.16628375649452, 47.932805344462395, 49.83011953532696, 46.939740031957626, 45.317021906375885, 45.15902638435364, 50.97135029733181, 47.60847754776478, 49.17821891605854, 45.542839989066124, 47.04153656959534, 48.09871584177017, 45.210544019937515, 42.80572146177292, 42.98714652657509, 42.08999566733837, 44.62249897420406, 42.15597152709961, 47.69888989627361, 44.05992776155472, 51.477103158831596, 48.753990679979324, 54.80314828455448, 48.81762586534023, 62.4052407592535, 55.55230088531971, 75.04819974303246, 28.204199373722076, 20.27111615985632, 68.40339750051498, 57.880884334445, 63.30085650086403, 54.20645110309124, 53.51325809955597, 47.335465997457504, 49.7562400996685, 47.754594907164574, 47.936871126294136, 40.709385350346565, 39.33550827205181, 40.739852115511894, 44.6299047768116, 43.25424939393997, 43.87225583195686, 43.319628685712814, 45.45451372861862, 45.28754308819771, 43.44034440815449, 48.652323335409164, 47.877590507268906, 46.59806616604328, 45.128692612051964, 45.56953735649586, 45.59321768581867, 46.13148920238018, 44.934165850281715, 46.67059287428856, 45.997299402952194, 44.9212883412838, 46.73157960176468, 48.47445487976074, 46.26663655042648, 43.245316073298454, 46.605228781700134, 47.42020145058632, 45.5208657681942, 46.123201847076416, 52.41210758686066, 54.30291272699833, 55.10292939841747, 59.06962774693966, 62.85710871219635, 61.82075992226601, 59.69655230641365, 60.264534428715706, 62.44180239737034, 63.59626404941082, 61.80037021636963, 60.73975212872028, 62.42215745151043, 61.23176872730255, 68.02974835038185, 66.4145690202713, 71.04506894946098, 40.883256420493126, 6.891203820705414, 5.789669528603554, 0.5698936572298408, 13.368617445230484, 67.27292776107788, 59.85950656235218, 49.295685812830925, 58.997944593429565, 71.46601796150208, 67.65073388814926, 36.41969293355942, 43.58014650642872, 39.42848548293114, 66.46150410175323, 4.601271897554398, 0.25840703397989273, 0.3077078447677195, 0.13908591092331335, 0.15084522601682693, 0.14932278427295387, 0.13832700555212796, 0.1884321856778115, 0.11274069256614894, 0.1426188604091294, 0.09767955503775738, 0.10807445389218628, 0.1372466018074192, 0.10919097054284066, 0.19565636990591884, 0.18294018896995112], [0.029910185949120205, 0.05927117890678346, 0.0698690403078217, 0.049078730517067015, 0.030607140542997513, 0.05082770170702133, 0.03242327053158078, 0.007399172909572371, 0.07715576532064006, 0.018960286797664594, 0.008709205030754674, 0.05965550379187334, 0.059495314926607534, 0.032117802547873, 0.0328521836490836, 0.07028741863905452, 0.15779223293066025, 0.060440276720328256, 0.030619708813901525, 0.10278308938723058, 2.350870678201318, 52.22611516714096, 34.13638025522232, 26.932052336633205, 18.29728927463293, 36.31609909236431, 67.17246875166893, 67.1355727314949, 49.01581563055515, 64.50403913855553, 35.115986689925194, 0.42789687984623015, 7.735098162665963, 65.54835990071297, 74.26367864012718, 64.6387267112732, 57.14815445244312, 56.53488636016846, 63.376708030700684, 70.05031272768974, 69.0954315662384, 64.8615999519825, 65.77662885189056, 60.41439838707447, 55.33591769635677, 53.50574970245361, 48.46886157989502, 46.43690161406994, 47.24529683589935, 47.81849607825279, 46.43103092908859, 44.13512572646141, 45.19899643957615, 46.2835456430912, 46.554995477199554, 44.57987666130066, 43.2254621386528, 45.62778063118458, 44.43126283586025, 44.566520377993584, 43.7886793166399, 44.225982651114464, 44.22294661402702, 43.66561912000179, 42.86594443023205, 42.10729993879795, 44.001494497060776, 44.10363681614399, 45.65262749791145, 42.206501215696335, 40.95491297543049, 39.674575477838516, 41.266944631934166, 41.10571548342705, 41.96747124195099, 40.28666943311691, 39.72744584083557, 40.7087279856205, 41.66731774806976, 43.59066054224968, 43.04963797330856, 45.3445628285408, 48.69137763977051, 51.400267481803894, 50.404063537716866, 55.748814940452576, 54.59957800805569, 68.69251638650894, 42.374034225940704, 17.368645705282688, 55.29688239097595, 60.45466102659702, 58.58531333506107, 54.5404227823019, 51.081297397613525, 47.669084295630455, 47.82391078770161, 45.07825791835785, 42.85099983215332, 39.92574580013752, 39.333976954221725, 36.926182955503464, 37.67673388123512, 37.597595527768135, 37.94241942465305, 39.12482097744942, 40.16230970621109, 39.272690042853355, 37.51779220998287, 41.60023234784603, 40.61558358371258, 41.06256499886513, 41.35036915540695, 40.725952461361885, 37.9009560495615, 37.97131307423115, 39.5962692797184, 39.11382056772709, 40.81284999847412, 40.907704308629036, 39.77971963584423, 42.21231870353222, 42.35946200788021, 41.09158404171467, 42.320586293935776, 43.10696929693222, 41.4253581315279, 42.49147072434425, 46.531045362353325, 49.05877232551575, 52.994791120290756, 54.79029357433319, 58.23754459619522, 55.511289685964584, 57.09465332329273, 57.801259607076645, 61.037827134132385, 59.74020056426525, 57.965072616934776, 56.48948259651661, 53.949071913957596, 50.19189052283764, 60.83045706152916, 61.151121854782104, 68.47770631313324, 43.72717581689358, 10.20402755588293, 2.4078106228262186, 0.35289852297864854, 8.025944530963898, 54.04341705143452, 52.799884378910065, 60.60866676270962, 58.35536867380142, 68.31493064761162, 25.01988284289837, 28.87091349810362, 34.63496670126915, 46.917940601706505, 21.473455242812634, 0.4076782241463661, 0.1419011887628585, 0.1640124843106605, 0.11288032765151002, 0.028698561218334362, 0.07846608641557395, 0.05832470313180238, 0.012403777582221664, 0.038485121622215956, 0.053055617900099605, 0.0531139803933911, 0.017958591524802614, 0.010119814396603033, 0.11018807563232258, 0.04242237831931561, 0.025235492357751355, 0.08148791879648343, 0.03561195255315397, 0.03683005808852613, 0.05082661817141343, 0.035776052536675707, 0.03355595486937091, 0.030157751571096014, 0.03684084891574457, 0.03892676999385003, 0.11145126292831264, 0.022777788690291345, 0.04755126814416144, 0.04435630755324382, 0.016907433964661323, 0.03510779679345433, 0.023815518943592906, 0.07172069876105525, 0.08094555727439001, 0.010259897553623887, 0.09985285287257284, 5.702890260145068, 67.5958040356636, 32.46466375887394, 35.827069133520126, 24.48860865086317, 47.524403259158134, 78.33972752094269, 68.4143029153347, 57.67676308751106, 71.91640019416809, 40.41743561625481, 0.765686760423705, 7.7370579075068235, 68.87103840708733, 80.1202055811882, 66.65464773774147, 59.95244957506657, 59.00182418525219, 65.6768462061882, 69.3805530667305, 71.69187784194946, 68.89819175004959, 68.73093232512474, 61.975274831056595, 62.14015558362007, 57.89182014763355, 52.431950122117996, 49.325852394104004, 51.111798360943794, 50.182223841547966, 49.19855162501335, 47.06641763448715, 49.793124720454216, 47.65426509082317, 46.46309740841389, 46.638716384768486, 46.43022917211056, 46.724895760416985, 45.93827337026596, 48.27692627906799, 46.28247790038586, 45.50948537886143, 46.38915717601776, 46.30420133471489, 45.13308897614479, 45.92978082597256, 45.210775807499886, 45.34777745604515, 46.527374759316444, 44.91227902472019, 43.389259949326515, 41.78749769926071, 43.43139968812466, 43.02256062626839, 44.18809488415718, 43.229588717222214, 42.53183215856552, 43.7799321860075, 44.70494695007801, 46.03208273649216, 45.92382654547691, 48.14358003437519, 50.11078007519245, 54.27974537014961, 53.78987565636635, 57.016681507229805, 57.851021736860275, 67.75902807712555, 59.81392040848732, 24.86668836325407, 55.45716539025307, 64.5799894630909, 59.14236344397068, 59.097613245248795, 52.80534848570824, 49.35118183493614, 48.405632972717285, 46.32096603512764, 45.838711112737656, 42.5324971228838, 41.85392953455448, 41.124528273940086, 40.23980274796486, 41.32653683423996, 40.49881964921951, 39.193574488162994, 41.61917433142662, 41.449141055345535, 39.608827605843544, 43.15532170236111, 44.659801572561264, 44.49008747935295, 44.21261876821518, 42.36670061945915, 42.05993168056011, 40.48770144581795, 43.0622760951519, 39.85245533287525, 42.038531228899956, 42.59311906993389, 44.51282545924187, 43.97833094000816, 44.06607963144779, 43.94784897565842, 45.49751602113247, 45.11541232466698, 44.233384653925896, 44.88654300570488, 49.18689385056496, 50.81668719649315, 54.518471360206604, 57.46399350464344, 61.20635189116001, 59.446795508265495, 60.459114387631416, 59.71801355481148, 64.25880789756775, 61.06992781162262, 60.84566004574299, 56.31708964705467, 55.591879561543465, 53.15313622355461, 63.45345251262188, 65.19459888339043, 71.0215862095356, 48.46480339765549, 10.693809874355793, 2.2261340590193868, 0.2210857335012406, 9.661862198263407, 59.320106506347656, 57.32323385775089, 63.674543648958206, 60.83989195525646, 70.97528949379921, 30.46987719833851, 39.984095469117165, 39.04364973306656, 56.27334639430046, 22.907768078148365, 0.4116684553446248, 0.09035987124661915, 0.15073500224389136, 0.1328529094462283, 0.02764094326266786, 0.05154331389348954, 0.049464027615613304, 0.04544516064925119, 0.10407582158222795, 0.04179040617600549, 0.06481140779214911, 0.04092985254828818, 0.015825649825274013, 0.10393183751148172, 0.002336964125788654, 0.10706351517001167, 0.21789117367006838, 0.08580214198445901, 0.1887450899812393, 0.15957965108100325, 0.1619207559269853, 0.1435609723557718, 0.16388706135330722, 0.1288468111306429, 0.18347217526752502, 0.298418085440062, 0.1784587005386129, 0.11462876820587553, 0.1433624923811294, 0.17203199851792306, 0.16644503659335896, 0.11581221915548667, 0.20364616852020845, 0.2052586030913517, 0.32618275028653443, 0.3997077659005299, 12.942649852484465, 79.21430379152298, 46.19841121137142, 46.90381295979023, 29.1055566072464, 48.96366722881794, 82.73394852876663, 81.23118996620178, 65.77096715569496, 81.42882496118546, 43.72757099568844, 0.6764652323909104, 9.028905462473631, 72.26758494973183, 79.44245114922523, 71.03835090994835, 62.7657426148653, 62.41379030048847, 70.00457838177681, 73.96569103002548, 75.31173840165138, 72.53672450780869, 71.27634733915329, 66.8079999089241, 65.23451954126358, 61.23307205736637, 54.72956903278828, 52.35620118677616, 55.694542452692986, 54.91499148309231, 52.87788279354572, 47.96088583767414, 51.69906444847584, 50.70306569337845, 50.87280638515949, 48.48707400262356, 48.82129266858101, 48.645103722810745, 48.218059837818146, 51.490778625011444, 48.50875183939934, 48.16552385687828, 48.278693184256554, 49.71714399755001, 45.563678070902824, 47.909326404333115, 48.24076361954212, 49.102101400494576, 49.31817680597305, 47.438660860061646, 47.27476045489311, 45.57762712240219, 45.99579468369484, 45.38656197488308, 46.85142517089844, 45.21071121096611, 43.356726095080376, 46.05499550700188, 44.82366397976875, 48.03656257688999, 48.201705515384674, 52.13275037705898, 52.54380851984024, 55.5738191306591, 53.488996401429176, 59.32927541434765, 57.98792839050293, 74.35795158147812, 44.831761345267296, 13.955376259982586, 61.927879974246025, 65.6449431180954, 63.16049203276634, 58.59247975051403, 55.169851407408714, 51.3201829791069, 53.01040828227997, 50.039222314953804, 47.949273660779, 43.97271864116192, 44.25909027457237, 41.66386753320694, 43.34349900484085, 42.20682039856911, 43.11700835824013, 41.39314725995064, 45.03382310271263, 45.578075498342514, 42.64546126127243, 46.04576960206032, 46.89147122204304, 46.99376933276653, 46.2990640103817, 45.55411398410797, 44.213583916425705, 43.46816651523113, 46.186529248952866, 42.21557892858982, 43.93856227397919, 45.58292403817177, 47.00158551335335, 47.47602045536041, 48.12672793865204, 45.99943868815899, 47.70360544323921, 49.7588125616312, 46.11280560493469, 46.32472023367882, 52.220339477062225, 54.72947023808956, 57.679012566804886, 58.447905108332634, 63.2504066079855, 61.50079049170017, 62.54402071237564, 62.3539625108242, 66.68704479932785, 64.21695694327354, 60.884554758667946, 59.148568511009216, 57.331692203879356, 53.09127174317837, 66.8093754351139, 68.05446222424507, 71.70436397194862, 50.98563373088837, 11.931483261287212, 5.735072633251548, 0.4350320063531399, 10.861663967370987, 67.06059515476227, 63.52804251015186, 75.68406522274017, 66.43422156572342, 79.13910582661629, 35.846079513430595, 46.31683945655823, 50.777306109666824, 64.24414828419685, 35.94191797077656, 0.5428002797998488, 0.32119795214384794, 0.29331861063838005, 0.24548254703404382, 0.1397216197801754, 0.18764795822789893, 0.11501855158712715, 0.21744909114204347, 0.23389236739603803, 0.1574032733333297, 0.25322271685581654, 0.0940743277897127, 0.09040350953000598, 0.27550694765523076, 0.07389542894088663, 0.1581259915838018], [0.10728691646363586, 0.04220741524477489, 0.015023608975752722, 0.032210203644353896, 0.06452734334743582, 0.055331153998849913, 0.04327132846810855, 0.014215142982720863, 0.060895873757544905, 0.05811832299514208, 0.03620791569119319, 0.03312341636046767, 0.18776748853269964, 0.037554461014224216, 0.09165283350739628, 0.03396161650016438, 0.04213378677377477, 0.012422842428350123, 0.08619270462077111, 0.10112706848303787, 0.19355379132321104, 29.169590771198273, 40.25437116622925, 62.36403577029705, 33.3751405030489, 20.549627915024757, 52.48701296746731, 57.984151393175125, 63.07128421962261, 58.825411051511765, 56.753465831279755, 0.937537585850805, 4.307727674022317, 65.00324115157127, 78.70894610881805, 67.65340134501457, 62.63115003705025, 55.04913188517094, 54.69462990760803, 52.66445964574814, 54.54697743058205, 51.496843099594116, 51.23218730092049, 47.46251218020916, 47.76936091482639, 46.137838661670685, 48.93234170973301, 46.70485183596611, 47.35043339431286, 45.63112065196037, 47.18689776957035, 45.034358873963356, 46.56202889978886, 42.134590074419975, 46.4472446590662, 46.037698835134506, 44.150666892528534, 44.76169690489769, 44.6332485973835, 45.67331738770008, 46.447351053357124, 45.09351409971714, 45.46492896974087, 44.8552630841732, 45.748009979724884, 42.717866376042366, 45.25830365717411, 45.34726448357105, 44.3291737139225, 41.42581030726433, 40.90185262262821, 41.5105077624321, 43.45269374549389, 42.30313003063202, 41.74451440572739, 42.252987921237946, 39.376234486699104, 42.058483958244324, 44.65424247086048, 43.198350593447685, 42.0227924734354, 47.35223449766636, 52.54776030778885, 54.28509168326855, 53.54246333241463, 57.990926429629326, 55.81984452903271, 61.514161974191666, 52.39683620631695, 19.430306777358055, 42.97778382897377, 63.79921495914459, 57.67224133014679, 57.43848167359829, 49.4653657078743, 51.22629761695862, 51.1750877648592, 49.004610031843185, 44.1083637624979, 43.95704448223114, 38.71024042367935, 38.08596432209015, 39.27717000246048, 39.27617445588112, 37.90217958390713, 38.23099493980408, 39.516405165195465, 39.403083845973015, 38.13624322414398, 39.7566282749176, 41.12182281911373, 40.957249850034714, 41.460236459970474, 40.48979513347149, 38.54614622890949, 40.75981244444847, 41.02462403476238, 41.300747618079185, 41.06730334460735, 40.080173313617706, 42.05079697072506, 41.94806948304176, 41.19490049779415, 40.877613723278046, 41.48596107959747, 43.25338304042816, 42.540598288178444, 44.10089336335659, 41.84731408953667, 45.05350984632969, 46.70373469591141, 50.83562918007374, 57.91643522679806, 60.83495981991291, 61.8963872641325, 61.291953697800636, 60.48097461462021, 60.76019883155823, 56.52500309050083, 49.05442155897617, 51.20110496878624, 53.115700632333755, 61.70431137084961, 64.23058301210403, 69.0003302693367, 48.80145013332367, 10.635805036872625, 0.46388937975279987, 0.24925011908635497, 13.42163885012269, 52.98703573644161, 54.833877235651016, 52.213720232248306, 50.39173699915409, 55.78051283955574, 29.15197491645813, 36.41136758029461, 35.42236424982548, 39.46975126862526, 1.8468039762228727, 0.06488717364845797, 0.02565703594882507, 0.09263744825148024, 0.053977947900420986, 0.024862062200554647, 0.03953442566853482, 0.060895955393789336, 0.03314491637866013, 0.04005396614957135, 0.01672269485425204, 0.09946594902430661, 0.03899722949427087, 0.06923661916516721, 0.02710002150706714, 0.02298850111401407, 0.09122894101892598, 0.02540063320338959, 0.06870440280181356, 0.027509894825925585, 0.025958685582736507, 0.032929021908785217, 0.06244166346732527, 0.06405115913366899, 0.01096531634175335, 0.06631600088439882, 0.08186083316104487, 0.02578657411504537, 0.027130768685310613, 0.06334882767987438, 0.017504862844361924, 0.03746965950995218, 0.06655891324044205, 0.021474740642588586, 0.02692782840313157, 0.08900672823074274, 0.22709617973305285, 0.6705504341516644, 37.94192165136337, 45.620762407779694, 56.62692502140999, 46.101600006222725, 27.531485371291637, 69.93962466716766, 64.54801797866821, 69.55964505672455, 63.41231591999531, 64.63342219591141, 0.908247985644266, 4.147900175303221, 65.62840640544891, 82.70601242780685, 70.33076047897339, 64.23126697540283, 57.19382040202618, 55.92782333493233, 55.82697294652462, 57.39814303815365, 54.51754800975323, 53.75775218009949, 52.009431794285774, 51.726844757795334, 48.52642849087715, 49.12831999361515, 50.1490668207407, 50.096352249383926, 46.43904469907284, 48.689257353544235, 49.15566332638264, 48.2260812073946, 46.18290424346924, 47.75961443781853, 49.10665735602379, 46.32032006978989, 44.60450693964958, 47.953016459941864, 46.48757569491863, 47.49857984483242, 46.89532421529293, 48.57536606490612, 46.090246215462685, 47.356862649321556, 45.5505345761776, 47.492135390639305, 46.115887239575386, 46.922321766614914, 44.48754921555519, 44.33044284582138, 43.001498356461525, 43.878130316734314, 42.840121015906334, 44.16466914117336, 45.26470631361008, 44.47044253349304, 42.96593226492405, 47.35273987054825, 44.365423768758774, 45.48327438533306, 47.67567314207554, 56.31477937102318, 56.60024285316467, 58.14815819263458, 59.64646719396114, 58.5890257358551, 56.71872429549694, 72.10327416658401, 29.176308810710907, 44.783800318837166, 66.02806136012077, 60.18070712685585, 59.57667253911495, 52.56156876683235, 53.58975939452648, 50.2509431540966, 50.06832495331764, 46.110157147049904, 46.66198253631592, 42.0822174847126, 41.07485733926296, 42.70602621138096, 43.05872708559036, 41.81088164448738, 41.20508775115013, 42.44168199598789, 41.2318155169487, 43.152988627552986, 41.82605043053627, 44.38630744814873, 42.66930878162384, 44.99349966645241, 42.28556737303734, 42.28888459503651, 42.68972888588905, 43.14728133380413, 44.51273426413536, 42.90256306529045, 43.37880291044712, 44.923078045248985, 43.81771735846996, 44.42201033234596, 43.61998736858368, 43.362976759672165, 43.68973642587662, 44.64795380830765, 47.506859600543976, 45.67373536527157, 47.72776074707508, 49.0120804309845, 55.338003784418106, 61.033529564738274, 63.41902256011963, 65.32624661922455, 63.24467271566391, 62.85618916153908, 62.29866027832031, 57.391949370503426, 53.29704590141773, 51.717242673039436, 55.14417238533497, 64.07914593815804, 67.58461743593216, 70.11434689164162, 52.19100125133991, 10.613618977367878, 0.7350314303766936, 0.5633771850261837, 16.175963804125786, 60.08146405220032, 59.37506675720215, 57.840275913476944, 57.72415794432163, 62.40606531500816, 36.64268396794796, 44.59630697965622, 39.437813982367516, 43.862224370241165, 2.789296852424741, 0.10682604275643826, 0.12044551389408298, 0.04426270417752676, 0.04888790950644761, 0.049967274244409055, 0.055051123126759194, 0.021384085448517, 0.034081955745932646, 0.1383292765240185, 0.11921717785298824, 0.07785129870171659, 0.022705869014316704, 0.04529458259639796, 0.07457898405846208, 0.05867573527211789, 0.012518659259512788, 0.17462104005971923, 0.11672518696286716, 0.11610493704210967, 0.21939256810583174, 0.11689370643580332, 0.11560089260456152, 0.15622889884980395, 0.09243369160685688, 0.16775513504398987, 0.16437310870969668, 0.12430756876710802, 0.10953021366731264, 0.34526793868280947, 0.17192751896800473, 0.17456821398809552, 0.18718573381192982, 0.1153253999655135, 0.1160986881586723, 0.4828764859121293, 0.2887380454922095, 0.9107235528063029, 56.82850420475006, 57.31105551123619, 69.38422366976738, 51.1109434068203, 33.350073248147964, 80.21184906363487, 73.54452162981033, 76.43460094928741, 68.22224602103233, 72.91461423039436, 1.199674119707197, 4.95647351257503, 69.31785643100739, 84.87758830189705, 76.12607270479202, 67.3011526465416, 63.493057787418365, 60.07457882165909, 59.70626838505268, 59.29764211177826, 57.35284186899662, 57.273414731025696, 53.04395668208599, 54.03141729533672, 53.57071101665497, 53.27927805483341, 53.44330005347729, 54.036615416407585, 51.37206919491291, 54.19073894619942, 50.888054966926575, 51.46603435277939, 47.774927616119385, 51.97480425238609, 51.627347096800804, 48.79471689462662, 50.599544048309326, 50.48501819372177, 50.41463077068329, 50.2567720413208, 48.45519371330738, 49.21757720410824, 50.07777124643326, 50.18902167677879, 46.13812744617462, 50.78387975692749, 50.84875367581844, 51.842369958758354, 46.93444311618805, 47.501756474375725, 48.73349077999592, 47.339831963181496, 46.025425493717194, 47.35250808298588, 47.923826426267624, 45.24435840547085, 45.68443179130554, 48.82160805165768, 47.805394381284714, 46.3663773983717, 51.00082911550999, 59.15555253624916, 58.6740879714489, 59.8932259529829, 61.93103760480881, 61.43599636852741, 60.51043443381786, 60.214411318302155, 15.756643954664469, 44.474690705537796, 70.09887412190437, 60.48542037606239, 62.12652951478958, 54.34102848172188, 54.35674823820591, 54.09765914082527, 53.70327070355415, 49.453863725066185, 48.80032919347286, 43.774490877985954, 42.41117723286152, 44.95028838515282, 44.891725927591324, 42.195250019431114, 43.147421926259995, 46.17251940071583, 45.77397778630257, 45.54154805839062, 44.513714611530304, 46.321399211883545, 44.2120373994112, 47.34559245407581, 46.00067742168903, 43.34776617586613, 45.82062408328056, 47.42564655840397, 47.41219148039818, 45.9456791728735, 45.922884196043015, 47.45364725589752, 45.999571681022644, 46.142778396606445, 45.42769856750965, 46.090485602617264, 47.02917963266373, 46.627343595027924, 49.41540978848934, 47.15622961521149, 51.38818792998791, 52.260214537382126, 56.7558217048645, 62.25772127509117, 67.35351383686066, 67.80567437410355, 65.84513157606125, 67.37193524837494, 66.89617037773132, 59.78794500231743, 54.285304471850395, 53.4205886721611, 56.51560619473457, 68.16527187824249, 71.96166336536407, 72.50707849860191, 54.62622977793217, 12.734202537685633, 1.6991066141054034, 1.0118192061781883, 18.35299238562584, 64.7344359755516, 65.68868637084961, 64.65445786714554, 62.41445526480675, 68.65837141871452, 42.23500348627567, 53.94399158656597, 48.50844785571098, 65.60303896665573, 5.03688907250762, 0.1285608616308309, 0.20000054617412388, 0.20558602380333468, 0.11312768547213636, 0.15010827337391675, 0.15474525658646598, 0.12340142129687592, 0.18868274957640097, 0.20966529787983745, 0.20363337389426306, 0.25224147888366133, 0.1031204622995574, 0.14762641279958189, 0.16210255242185667, 0.246363491169177, 0.18529745779233053], [0.06607987175812013, 0.01761208648531465, 0.04386500208056532, 0.05905125828576274, 0.02001183027459774, 0.11793286903412081, 0.07529655180405825, 0.06834252417320386, 0.050764930856530555, 0.06250453079701401, 0.07008738757576793, 0.07080171955749393, 0.034494667779654264, 0.031273001004592516, 0.02387333966908045, 0.0400713509588968, 0.04823042603675276, 0.029381671047303826, 0.05614807305391878, 0.1298654533457011, 0.2090013280394487, 3.4917428344488144, 44.787717908620834, 52.05407939851284, 29.966748096048832, 25.55516391992569, 45.030551478266716, 66.25322967767715, 63.824643194675446, 59.042071625590324, 71.58134937286377, 4.90660403855145, 0.4905665904516354, 54.10786159336567, 78.26406598091125, 75.96737802028656, 69.51359912753105, 64.09448191523552, 58.33836458623409, 54.09865088760853, 54.48790580034256, 48.79155546426773, 49.68292683362961, 48.748708963394165, 47.60958708822727, 46.886805072426796, 47.16844975948334, 45.666409358382225, 47.075388953089714, 46.33774593472481, 47.39077962934971, 43.93003933131695, 46.24797195196152, 46.35027006268501, 46.58449329435825, 46.482081189751625, 44.49764907360077, 45.90330384671688, 46.96317337453365, 48.34847643971443, 48.346755132079124, 43.419263139367104, 45.43815940618515, 43.418157398700714, 44.59448307752609, 44.31631900370121, 44.55137059092522, 46.64204880595207, 45.38770571351051, 41.61250948905945, 42.034233659505844, 41.728452667593956, 43.3365111798048, 43.13187696039677, 43.19792881608009, 39.60367128252983, 40.41265167295933, 41.455992087721825, 43.273495361208916, 42.55490832030773, 44.13146272301674, 46.58974081277847, 51.518752723932266, 57.63137072324753, 58.403983265161514, 60.000684186816216, 59.836536794900894, 59.74740497767925, 56.5880873054266, 23.996523655951023, 36.08887888491154, 62.824939638376236, 57.00392559170723, 58.09298515319824, 55.53113982081413, 52.22850903868675, 55.00930242240429, 54.28789213299751, 46.39391832053661, 44.3690449744463, 42.39496350288391, 41.74580633640289, 39.298536255955696, 39.85479600727558, 41.0056858509779, 41.79176107048988, 41.602037250995636, 40.479459688067436, 37.377169355750084, 40.743891298770905, 41.69980600476265, 41.99795700609684, 40.05227901041508, 40.9729316085577, 39.31432820856571, 39.96904827654362, 41.41131408512592, 40.56662701070309, 41.673693805933, 40.79811438918114, 41.15407548844814, 42.41173580288887, 41.79714158177376, 41.98194846510887, 40.62398113310337, 42.7677197009325, 41.108671724796295, 41.60120129585266, 42.47615374624729, 42.87843815982342, 42.50434063374996, 42.88314610719681, 45.50874061882496, 54.47677619755268, 52.63824865221977, 52.75220073759556, 52.37622231245041, 48.60378473997116, 47.86522977054119, 48.234068378806114, 49.083911776542664, 54.8772557079792, 62.067526280879974, 62.25207477807999, 68.65266412496567, 48.50246697664261, 5.352056510746479, 0.9856866428162903, 0.3978973114863038, 20.424257442355156, 53.3761690557003, 57.69970625638962, 50.460144728422165, 62.63460025191307, 33.076123148202896, 21.992146410048008, 30.94189926981926, 42.165657207369804, 11.783223766833544, 0.416509811184369, 0.08321678891661577, 0.06659184233285487, 0.08604046786786057, 0.017420506628695875, 0.07150785080739297, 0.057380817452212796, 0.07207168266177177, 0.04625642453902401, 0.06962237268453464, 0.02961824917292688, 0.0968744138663169, 0.07154093575081788, 0.04656950695789419, 0.0435459082655143, 0.07052402273984626, 0.04539108034805395, 0.02611951083963504, 0.04867536583333276, 0.09703313698992133, 0.047750516241649166, 0.045318587362999097, 0.011172942358825821, 0.011618410007940838, 0.06212205385963898, 0.02811879174259957, 0.09170850200462155, 0.03247986300266348, 0.04916498663078528, 0.04096171665878501, 0.06832473489339463, 0.03294556438049767, 0.09701745540951379, 0.029214858514023945, 0.01694600152404746, 0.04949551323079504, 0.1603181177051738, 0.24001863319426775, 5.1814736891537905, 55.91433025896549, 54.706671461462975, 38.46068501472473, 31.34472705423832, 51.303361281752586, 74.53510567545891, 69.09845620393753, 63.020762130618095, 77.05486446619034, 6.6190524492412806, 0.5237707821652293, 53.81914548575878, 80.007693618536, 79.57266256213188, 70.15757337212563, 66.89455166459084, 59.25547197461128, 54.96081322431564, 55.96394419670105, 53.31708982586861, 51.83831177651882, 50.454433634877205, 49.467782378196716, 50.44758640229702, 50.25198429822922, 49.9111045897007, 49.76221717894077, 51.04070417582989, 50.396251156926155, 46.31769821047783, 46.74998201429844, 48.93424540758133, 47.320502400398254, 47.94715717434883, 48.86419236660004, 47.63635665178299, 46.57100021839142, 49.81315344572067, 50.70658430457115, 46.7252529412508, 47.49297894537449, 45.13090029358864, 45.49422159790993, 46.84819534420967, 46.40713781118393, 47.02937342226505, 47.72771134972572, 44.007008001208305, 44.12760592997074, 44.554885402321815, 46.66684627532959, 44.671721532940865, 46.18835315108299, 42.322231605648994, 45.52324444055557, 44.42048281431198, 47.73589611053467, 45.86228884756565, 45.57913564145565, 46.55339576303959, 57.93504282832146, 59.37085658311844, 62.75573395192623, 59.10249598324299, 63.92563417553902, 55.814353823661804, 69.49061036109924, 38.81049804389477, 40.38247749209404, 65.97030445933342, 57.84399971365929, 61.12720973789692, 56.644020304083824, 56.03398583829403, 54.80151057243347, 53.97422656416893, 46.30718797445297, 47.41068296134472, 44.58966113626957, 44.09496948122978, 42.9203537106514, 44.219792783260345, 43.0058491230011, 44.19866591691971, 42.13903583586216, 41.57754756510258, 42.23276160657406, 43.75347800552845, 44.46264535188675, 44.87878002226353, 44.05695632100105, 42.061390802264214, 43.03965210914612, 43.58449727296829, 43.15920129418373, 43.35456021130085, 43.51010486483574, 43.55520464479923, 44.933257699012756, 44.8880173265934, 44.580062851309776, 45.66048547625542, 40.91423995792866, 44.335857555270195, 42.30589248239994, 43.00606191158295, 43.830469474196434, 47.2901002317667, 44.991842955350876, 46.25562474131584, 47.543010860681534, 55.988061502575874, 53.93074169754982, 55.85543341934681, 54.48835797607899, 52.06604115664959, 49.04207222163677, 49.78018641471863, 49.81035679578781, 57.3660309612751, 62.5464753806591, 65.35070970654488, 68.14340025186539, 50.485869348049164, 5.0489244516938925, 0.3238782926928252, 1.0134792421013117, 22.569749616086483, 59.69361126422882, 61.26601628959179, 56.23271517455578, 68.94971698522568, 36.72921672463417, 32.441317811608315, 35.47615796327591, 51.17593511939049, 17.226134352385998, 0.6142382277175784, 0.10776186129078269, 0.012569352584250737, 0.08672339215991087, 0.04073644886375405, 0.04565307332086377, 0.0010298995516677678, 0.02900476763898041, 0.0483337070181733, 0.06278237604419701, 0.009251772498828359, 0.13409597711870447, 0.08480994249111973, 0.07641553980647586, 0.0555591157899471, 0.07965442069689743, 0.019868258095812052, 0.08628271971247159, 0.1807398843811825, 0.19202205789042637, 0.09690108665381558, 0.12838194466894493, 0.2887033426668495, 0.18103595677530393, 0.224452308320906, 0.15617651806678623, 0.19653774448670447, 0.1517677601077594, 0.12320426976657473, 0.2468121045967564, 0.13813662983011454, 0.08591964622610249, 0.12570403836434707, 0.19023011263925582, 0.14041019923752174, 0.26245978369843215, 0.406847553094849, 0.3419069299707189, 9.878655765205622, 72.12800323963165, 63.01072686910629, 48.06574121117592, 38.07809114456177, 60.92188015580177, 82.43239670991898, 78.99628669023514, 71.65596976876259, 85.201346129179, 7.746685165911913, 0.8409063960425556, 59.18384961783886, 79.60705831646919, 84.14900779724121, 76.27994924783707, 68.7405002117157, 63.971740901470184, 59.632525742053986, 60.60089997947216, 56.4748115837574, 56.70967698097229, 54.49493542313576, 54.675946310162544, 53.0317023396492, 54.04455319046974, 52.58817493915558, 53.23950178921223, 54.131807908415794, 54.60849992930889, 51.07773698866367, 51.07885032892227, 51.72703854739666, 51.749544739723206, 51.42856076359749, 50.814566910266876, 50.02740874886513, 49.38474543392658, 52.80440993607044, 53.51574696600437, 47.236587703228, 49.772560223937035, 47.24466606974602, 47.69368417561054, 48.63523565232754, 50.23403786122799, 50.066843032836914, 50.50744079053402, 45.09679712355137, 46.723250448703766, 48.29118691384792, 49.647550731897354, 48.129691779613495, 48.9259048551321, 43.35827261209488, 45.37836581468582, 44.08051885664463, 47.67260670661926, 47.75403253734112, 47.46446527540684, 49.80543226003647, 58.92455913126469, 61.68969355523586, 63.07044446468353, 61.015214547514915, 66.99961602687836, 59.750604405999184, 64.37123626470566, 22.144035659730434, 31.92760057747364, 70.41563272476196, 60.07002666592598, 66.91652968525887, 59.18565072119236, 59.86323036253452, 58.964149206876755, 61.5954852104187, 51.430289670825005, 50.376989990472794, 45.47659434378147, 46.73382148146629, 43.354051038622856, 46.530300602316856, 45.1529087126255, 49.50226932764053, 44.507619738578796, 45.67372776567936, 43.41175094246864, 46.633571460843086, 46.556127816438675, 47.30406068265438, 44.12627600133419, 45.25627836585045, 45.64076453447342, 47.156484201550484, 46.49256482720375, 45.656617283821106, 47.182752192020416, 46.231290847063065, 46.248560920357704, 48.04744899272919, 47.843753322958946, 47.418757528066635, 43.97624485194683, 46.971339136362076, 45.02310387790203, 45.305934101343155, 46.16713508963585, 50.14879323542118, 48.616248071193695, 48.776759058237076, 48.99422898888588, 60.711086466908455, 56.13596096634865, 59.464624151587486, 57.77367688715458, 53.03176313638687, 51.838330775499344, 51.18344731628895, 51.51347480714321, 58.156916722655296, 66.9016344845295, 68.81408706307411, 70.8475099503994, 53.533089235424995, 6.820321949198842, 1.4665448432788253, 2.2836748464033008, 25.37083961069584, 65.94974756240845, 68.04349601268768, 63.5654629021883, 74.01356846094131, 43.30122247338295, 36.180666759610176, 43.86159360408783, 63.66131655871868, 30.48717387020588, 0.7102381763979793, 0.1878969933022745, 0.24657654692418873, 0.14033049257704988, 0.18824333878001198, 0.1913881895598024, 0.16637463646475226, 0.1536178303649649, 0.22733175224857405, 0.15679977368563414, 0.1440050289966166, 0.25636214995756745, 0.13976181449834257, 0.1504495128756389, 0.14236590679502115, 0.21075398399261758, 0.13662895682500675], [0.01769055932527408, 0.027295768522890285, 0.06607479546801187, 0.02888656763389008, 0.042628647133824416, 0.021133751615707297, 0.05243006533419248, 0.04576299281325191, 0.04952323615725618, 0.08408158391830511, 0.008285198437079089, 0.03526087588397786, 0.032647358311805874, 0.04327061600633897, 0.06358430371619761, 0.03354510467033833, 0.0050663852198340464, 0.02142998913768679, 0.011270692484686151, 0.009198137486237101, 0.13185041636461392, 0.2863703272305429, 40.00514633953571, 32.01896287500858, 39.90868091583252, 34.265466928482056, 39.7016604244709, 66.55164286494255, 58.7874510884285, 61.389323472976685, 68.61082077026367, 14.610654897987843, 0.9502309234812856, 10.545335691422224, 65.1212628185749, 77.70684108138084, 71.15924522280693, 70.10450541973114, 64.10394340753555, 58.79537746310234, 52.69365347921848, 54.83864977955818, 50.01982435584068, 47.98399239778519, 49.495615884661674, 47.34442591667175, 48.752421364188194, 47.86515757441521, 46.25982351601124, 46.09898954629898, 47.04616852104664, 45.482187643647194, 44.913798943161964, 43.362076207995415, 46.18494473397732, 47.64364466071129, 45.76345235109329, 43.99117425084114, 46.83272257447243, 45.83488471806049, 46.9742763787508, 42.69516259431839, 42.73677796125412, 45.17072595655918, 45.00563621520996, 44.285453259944916, 44.309847950935364, 45.85270956158638, 46.91892094910145, 42.69257113337517, 41.54527969658375, 42.49569229781628, 42.54348613321781, 44.861156567931175, 40.715335831046104, 42.996687814593315, 42.65626408159733, 43.351391181349754, 42.39766135811806, 43.8199782371521, 46.690792590379715, 46.164456233382225, 51.49960175156593, 56.21011018753052, 58.945583403110504, 57.62867286801338, 63.626263439655304, 59.65095855295658, 59.957662895321846, 30.979830734431744, 32.308761924505234, 65.80473214387894, 58.30156356096268, 60.26586815714836, 56.65753997862339, 57.65214420855045, 57.71136023104191, 59.97719384729862, 53.728938326239586, 42.43864595890045, 42.649838626384735, 42.4026732891798, 40.98938852548599, 40.79917453229427, 38.700201362371445, 40.07074221968651, 41.365173161029816, 40.88364779949188, 39.89388830959797, 41.3251993060112, 40.29452361166477, 41.791616678237915, 41.72801949083805, 38.20449896156788, 41.39730803668499, 38.96032400429249, 40.793421640992165, 42.060421854257584, 39.94820259511471, 42.32468627393246, 40.384111404418945, 39.52153868973255, 40.932931154966354, 41.63135267794132, 42.3025144636631, 40.4952060431242, 42.68183670938015, 41.603355780243874, 41.564278677105904, 42.739491015672684, 41.89439356327057, 42.12308809161186, 40.75925387442112, 41.29548870027065, 43.140768483281136, 42.774924114346504, 42.93446235358715, 44.4310462474823, 48.161727860569954, 48.30205053091049, 51.42552092671394, 59.484440088272095, 62.69549958407879, 64.77065563201904, 69.17933106422424, 44.82206806540489, 0.09032608126290143, 0.7471922622062266, 0.73104033828713, 20.100172832608223, 57.08156682550907, 50.19977509975433, 57.96870142221451, 53.18204127252102, 24.95024587959051, 27.448062747716904, 30.226534456014633, 44.14181336760521, 1.3949723588302732, 0.1291426905663684, 0.07278817429323681, 0.05508174413989764, 0.018272085835633334, 0.05223427935561631, 0.08110692986520007, 0.0418241998704616, 0.08113152463920414, 0.07006773550529033, 0.03619682800490409, 0.04061676641867962, 0.0938248993770685, 0.08877172716893256, 0.08406399501836859, 0.03631922671047505, 0.055570333352079615, 0.02935135802545119, 0.020488125810516067, 0.03451030483120121, 0.014659923217550386, 0.03657799134089146, 0.03016733084223233, 0.015826384551473893, 0.10160726771573536, 0.04300330925616436, 0.017370022032991983, 0.10854314241441898, 0.0253883914774633, 0.04233049301546998, 0.07828190020518377, 0.07050194384646602, 0.0572640924656298, 0.09019925564643927, 0.051962278521386907, 0.044812505730078556, 0.07654341185116209, 0.05685777032340411, 0.10612845362629741, 0.27793181128799915, 48.353761956095695, 41.065316051244736, 38.737982735037804, 45.280559062957764, 42.333517000079155, 76.1094143986702, 64.60223346948624, 65.83905190229416, 75.30791580677032, 17.31249801814556, 0.9208735206630081, 9.755817856639624, 66.1808131635189, 80.59560567140579, 72.82256796956062, 73.50998908281326, 65.90130016207695, 61.78702153265476, 55.09255975484848, 57.97250121831894, 54.11061644554138, 50.95583952963352, 52.117737382650375, 49.82218936085701, 51.82845130562782, 51.455432921648026, 49.20249201357365, 47.725252881646156, 49.758633971214294, 49.17383395135403, 47.05709673464298, 46.146046221256256, 47.709601521492004, 49.156879261136055, 49.579139202833176, 47.8728711605072, 49.83483888208866, 47.910424545407295, 47.554296255111694, 44.97786730527878, 45.97283631563187, 46.90212585031986, 46.6326405107975, 46.70577518641949, 46.54185198247433, 46.88623130321503, 48.53731110692024, 45.6554089486599, 45.78612193465233, 44.26092177629471, 43.93845587968826, 45.17636485397816, 44.62155282497406, 44.44255582988262, 45.04562146961689, 46.49255342781544, 46.23641677200794, 46.726655066013336, 48.25331434607506, 47.20674030482769, 54.60437335073948, 60.82038000226021, 62.32817329466343, 61.361736953258514, 63.58026310801506, 58.83139193058014, 62.45016574859619, 50.17063446342945, 37.802628725767136, 66.0454036295414, 61.194374933838844, 62.97272130846977, 60.32355286180973, 61.70914851129055, 57.76588350534439, 61.988935098052025, 51.96277029812336, 44.81341972947121, 44.925308525562286, 45.835975259542465, 43.53968247771263, 43.990885466337204, 43.3127548545599, 43.26019607484341, 42.829018011689186, 41.643025651574135, 42.907419204711914, 45.86818613111973, 43.61030928790569, 43.8908938318491, 43.7983687967062, 42.06083983182907, 42.765827402472496, 41.94864325225353, 44.069408252835274, 44.54301863908768, 42.55186088383198, 43.093878999352455, 42.31891818344593, 42.7701211720705, 43.36924262344837, 42.255526185035706, 43.33660617470741, 43.744126707315445, 44.27568398416042, 45.03503143787384, 43.872480019927025, 46.191415786743164, 44.46910120546818, 44.844357669353485, 43.548775389790535, 44.20464299619198, 45.42192667722702, 45.13538025319576, 47.25187808275223, 47.98786818981171, 50.898242220282555, 50.22383160889149, 53.374208360910416, 61.794594526290894, 66.34573951363564, 66.29555940628052, 69.23131987452507, 45.39183609187603, 0.09186108756694011, 0.8185173443052918, 2.1697149239480495, 24.09774262458086, 62.65429459512234, 56.28591611981392, 63.9711557328701, 57.59460769593716, 32.73215800523758, 35.83835072815418, 32.102546989917755, 54.941270872950554, 2.876294134184718, 0.05312156143190805, 0.025310983619419858, 0.03832219423202332, 0.08599754204624332, 0.05245071188255679, 0.01852435481850989, 0.04966523498296738, 0.03901302239682991, 0.11658106188406236, 0.020090236321266275, 0.04763496384839527, 0.03246347638196312, 0.048011128819780424, 0.0707632392004598, 0.01531533702291199, 0.03777047422772739, 0.05135249288287014, 0.1251292895176448, 0.16577760834479704, 0.13211070239776745, 0.13687944650882855, 0.10809299274114892, 0.07846338499803096, 0.16469110414618626, 0.10815960049512796, 0.12379193198285066, 0.24422730813967064, 0.07425497722579166, 0.12643169931834564, 0.17573855118826032, 0.17651366506470367, 0.21764782344689593, 0.13022524653933942, 0.18249570188345388, 0.13427493860945106, 0.21628098038490862, 0.09848088899161667, 0.23947606387082487, 0.6166893930640072, 64.02036309242249, 51.385303884744644, 56.72248609364033, 54.20566834509373, 50.899511352181435, 85.49154415726662, 71.36144757270813, 73.88562172651291, 82.99339100718498, 20.60710933059454, 0.9252605040092021, 12.602068427950144, 69.71092253923416, 81.55153557658195, 78.68204355239868, 76.42890125513077, 70.33246278762817, 64.10481736063957, 59.051761105656624, 61.25781632959843, 58.94603557884693, 55.15506260097027, 57.48909495770931, 54.286402612924576, 56.63936175405979, 54.9410542845726, 51.95917949080467, 53.26149120926857, 52.50180937349796, 52.51888945698738, 50.45524679124355, 49.2771428078413, 49.84184950590134, 52.82960258424282, 51.85905486345291, 50.91795556247234, 51.787592098116875, 51.47103488445282, 51.32053256034851, 47.50114470720291, 47.89746344089508, 52.074328511953354, 51.410815715789795, 49.0069355070591, 48.49913075566292, 51.70535311102867, 51.490398645401, 48.23229007422924, 46.373768001794815, 47.70938113331795, 48.032002821564674, 49.75315846502781, 46.13239735364914, 47.16779239475727, 44.665375873446465, 47.200227454304695, 45.44863544404507, 47.25852012634277, 51.69773831963539, 50.536988005042076, 57.746679335832596, 59.79045286774635, 63.16529117524624, 60.866992101073265, 68.48507031798363, 61.11522138118744, 63.597263395786285, 32.20950745046139, 26.173732727766037, 69.7954224050045, 63.27300399541855, 65.38123726844788, 63.3382198959589, 62.77111932635307, 59.5361515134573, 64.89003762602806, 57.823340222239494, 46.963424161076546, 47.686791345477104, 49.37846817076206, 44.59238938987255, 45.869633853435516, 44.96989533305168, 45.85599258542061, 44.4832668453455, 46.071543619036674, 44.438167065382004, 47.600448578596115, 44.808354601264, 45.60723893344402, 47.0332720130682, 43.96536223590374, 45.35375453531742, 45.033902898430824, 46.549542769789696, 47.159239053726196, 43.792251124978065, 46.63283810019493, 44.58371825516224, 45.77685043215752, 44.96177516877651, 43.77357132732868, 46.65259703993797, 45.60590140521526, 48.069768995046616, 46.83840326964855, 45.500609055161476, 49.18952710926533, 47.78735674917698, 47.97280579805374, 44.48117695748806, 47.68977418541908, 48.142744079232216, 48.776029497385025, 48.071843683719635, 49.69808802008629, 52.200994715094566, 50.572333708405495, 54.01886656880379, 62.75680169463158, 67.63448596000671, 71.24667093157768, 72.12877079844475, 48.494874984025955, 0.4628556570969522, 2.0638623414561152, 2.561064474284649, 26.23742301017046, 69.84285905957222, 60.24021573364735, 68.38199704885483, 64.44848611950874, 34.370014518499374, 42.03392207622528, 42.92676776647568, 69.0252797305584, 7.8714752197265625, 0.2544207213213667, 0.16158244048710912, 0.1996897644130513, 0.19661871279822662, 0.18563899415312335, 0.24199240462621674, 0.12062964073265903, 0.2754471602384001, 0.2472048788331449, 0.10624249945976771, 0.17079108307370916, 0.1589786005206406, 0.19889238610630855, 0.14052380720386282, 0.1680795129504986, 0.2163035565172322, 0.1691272621974349], [0.058267962231184356, 0.061364232024061494, 0.018521766578487586, 0.024079949871520512, 0.09965655481209978, 0.08180444478057325, 0.12214239002787508, 0.06617854029173031, 0.019470042061584536, 0.08195693386369385, 0.06420989710022695, 0.10552300955168903, 0.0363292419933714, 0.03069764730753377, 0.03845168786938302, 0.0986419795663096, 0.08851773454807699, 0.0405516800674377, 0.03779056416533422, 0.10385383036918938, 0.2661538386018947, 0.33909971185494214, 7.764443513005972, 59.42856028676033, 37.861008793115616, 61.524493619799614, 26.058781296014786, 50.34207746386528, 76.53983250260353, 58.61187770962715, 71.54015958309174, 35.333376824855804, 0.3061340464046225, 0.06198095674335491, 20.515393652021885, 80.62900587916374, 75.37938997149467, 71.50564983487129, 65.96518233418465, 61.35191448032856, 56.320308074355125, 52.292550802230835, 54.12156365811825, 54.64312747120857, 53.67580197751522, 51.7261303961277, 53.202145993709564, 48.489927649497986, 49.67120446264744, 47.85473473370075, 49.658657535910606, 47.55567938089371, 47.951070964336395, 46.263216733932495, 45.75242154300213, 45.931365340948105, 46.30115009844303, 43.761594370007515, 46.632078140974045, 46.24262183904648, 48.51466052234173, 45.80743499100208, 46.17723494768143, 45.04249423742294, 45.28451085090637, 45.06686232984066, 44.77160297334194, 45.656529888510704, 45.59025764465332, 42.52827934920788, 41.69853687286377, 43.40023376047611, 43.711619451642036, 42.85142160952091, 43.1245319545269, 44.62439887225628, 45.17457515001297, 44.033462181687355, 44.868075996637344, 44.92590509355068, 46.88057720661163, 49.095121175050735, 49.330157563090324, 53.20055767893791, 60.564760118722916, 55.875108763575554, 60.569012090563774, 58.324613124132156, 65.76399073004723, 35.344388633966446, 22.903848588466644, 61.05123281478882, 63.11739094555378, 61.1934819817543, 59.427990317344666, 57.36600436270237, 60.94817854464054, 62.33212508261204, 57.22375899553299, 49.71972405910492, 42.59512536227703, 43.199729919433594, 42.68827736377716, 42.26482808589935, 40.615674778819084, 41.03205643594265, 40.09867452085018, 40.82626327872276, 42.201527282595634, 39.97601330280304, 41.71459101140499, 41.099882796406746, 41.67734161019325, 41.78116723895073, 41.53964459896088, 38.49618650972843, 41.83590330183506, 42.35163062810898, 42.19088025391102, 41.8024954944849, 42.70139046013355, 41.10130771994591, 40.987462028861046, 41.60554066300392, 42.312842309474945, 41.044314578175545, 42.733867317438126, 42.13363632559776, 43.80070187151432, 43.58618438243866, 43.895229399204254, 41.896992623806, 43.3195298910141, 39.48668695986271, 43.724713549017906, 42.66148500144482, 46.87924347817898, 43.421596214175224, 48.95487830042839, 46.38512559235096, 54.45605970919132, 57.79405899345875, 65.94292312860489, 59.865229055285454, 72.32192203402519, 30.019257478415966, 0.34007364709395915, 0.629690217319876, 1.1919013992883265, 28.393330425024033, 57.991842180490494, 48.2918518781662, 59.07972760498524, 36.653596982359886, 22.078297287225723, 29.449521750211716, 39.0779010951519, 34.15546663105488, 0.23865449154982343, 0.08896077444660477, 0.04557839471090119, 0.03535258678311948, 0.02010406995395897, 0.029435547257889993, 0.07316712973988615, 0.043569738627411425, 0.03929872327717021, 0.030408953716687392, 0.03682656999444589, 0.033477376273367554, 0.07421427042572759, 0.003423515404392674, 0.035913520550820976, 0.027033786682295613, 0.030099073665041942, 0.08148936598445289, 0.02997711839270778, 0.016570665902690962, 0.09597567302989773, 0.004538548455457203, 0.04437779643922113, 0.02352327046537539, 0.13160434988094494, 0.027581042668316513, 0.028766979812644422, 0.016216516742133535, 0.012540312345663551, 0.0469534941657912, 0.09630316053517163, 0.017172330590256024, 0.006317752422546619, 0.09372165179229341, 0.0244259632381727, 0.013108860548527446, 0.039429322714568116, 0.07606098617543466, 0.07193399942480028, 0.37765268061775714, 8.840796556323767, 68.31789448857307, 41.98476031422615, 65.57653158903122, 35.699889957904816, 57.71386429667473, 82.33915731310844, 64.32271286845207, 78.24002847075462, 39.84526611864567, 0.7426957972347736, 0.15334244904806837, 19.81488984078169, 82.25221037864685, 77.18218803405762, 75.47623917460442, 68.27668190002441, 62.975973933935165, 56.8678130954504, 57.21049390733242, 58.22896845638752, 58.2085445523262, 56.61468967795372, 54.42870877683163, 55.537128299474716, 50.53954906761646, 52.399287074804306, 52.1080707013607, 50.79181753098965, 48.7139218300581, 49.997960329055786, 47.55760967731476, 48.55154134333134, 47.79297664761543, 49.04774911701679, 45.53289212286472, 47.348054721951485, 48.72094765305519, 52.052479684352875, 47.372631803154945, 47.8572615981102, 47.54378601908684, 47.23311088979244, 48.0409399420023, 48.62744987010956, 46.37282185256481, 47.4836428463459, 44.89755481481552, 46.316064298152924, 43.74046750366688, 47.266727685928345, 44.67606469988823, 44.99331347644329, 47.414725944399834, 50.24511806666851, 47.51769661903381, 48.383252173662186, 46.14874787628651, 50.38053520023823, 48.6468630284071, 51.73763617873192, 57.82802537083626, 62.45432652533054, 60.06499573588371, 61.031242087483406, 59.544727653265, 66.20454668998718, 52.94110380113125, 35.05410321056843, 61.02118402719498, 63.92206236720085, 62.73519225418568, 63.94666224718094, 61.36135317385197, 60.91026037931442, 62.21979171037674, 60.11527083814144, 50.01982435584068, 48.4906268119812, 46.98462702333927, 45.086906254291534, 43.39325733482838, 45.42592026293278, 42.971065789461136, 43.392269387841225, 42.125413566827774, 45.20061515271664, 43.506115078926086, 45.032018199563026, 43.230120688676834, 45.4891374707222, 45.065220817923546, 43.67195338010788, 42.135327234864235, 44.281079694628716, 45.15964575111866, 44.63947646319866, 42.11018778383732, 45.29416613280773, 42.570544481277466, 44.45476837456226, 43.661496341228485, 44.76537510752678, 43.14293056726456, 45.813526064157486, 42.60681353509426, 45.33995367586613, 46.45487844944, 46.16741627454758, 43.229854702949524, 45.903771221637726, 42.33450494706631, 45.03237158060074, 43.94230127334595, 48.06467726826668, 44.53164964914322, 51.847617477178574, 48.04831154644489, 58.261027336120605, 59.63072083890438, 68.53780388832092, 61.4256951212883, 71.98146030306816, 30.94212155789137, 0.39702733629383147, 0.9070093114860356, 2.2866740729659796, 32.81482636928558, 65.8616378903389, 53.2650326192379, 64.82079014182091, 40.231610387563705, 34.1780374199152, 32.209925428032875, 42.90768139064312, 39.61114548146725, 0.38699949625879526, 0.07530118280556053, 0.03451129188761115, 0.041416096573811956, 0.04289246578991879, 0.14358993095811456, 0.04859811197093222, 0.028138005945947953, 0.05800579114293214, 0.011605244308157125, 0.07740840723272413, 0.12644735863432288, 0.10403455074992962, 0.055210855571203865, 0.01674644729064312, 0.03144044065265916, 0.012565384877234465, 0.013076815539534437, 0.21525009273318574, 0.14021056151250377, 0.1502266459283419, 0.1059317696490325, 0.12262348725926131, 0.13937484385678545, 0.21985428786138073, 0.17815936269471422, 0.1293929576058872, 0.2074265797273256, 0.1394356702803634, 0.20721802138723433, 0.18767914327327162, 0.15823412250028923, 0.16692149540176615, 0.24407574674114585, 0.17952837282791734, 0.2050323667936027, 0.14891089231241494, 0.27439028257504106, 0.490695308544673, 0.6007100036367774, 15.907569956034422, 82.78508618474007, 55.80253645777702, 79.21263188123703, 41.163415387272835, 65.19790470600128, 90.47632187604904, 74.65118184685707, 85.22743552923203, 45.99571868777275, 1.2507028877735138, 0.2288916872930713, 24.48062527924776, 83.96011233329773, 81.76314622163773, 78.158028870821, 70.74543982744217, 67.12608844041824, 60.89610233902931, 62.76904843747616, 61.88624940812588, 61.71378046274185, 60.851994305849075, 59.54937860369682, 60.59774994850159, 55.22750951349735, 57.33919680118561, 56.2968785315752, 57.05187901854515, 53.21177467703819, 53.86773347854614, 51.048995330929756, 50.631941109895706, 50.693475008010864, 51.17971211671829, 49.27860572934151, 50.90799629688263, 52.520599365234375, 57.01571635901928, 49.26871486008167, 49.60637614130974, 50.40015734732151, 50.12780696153641, 50.07666550576687, 49.30158689618111, 50.06263665854931, 50.73898136615753, 47.0954404771328, 47.11925379931927, 47.78221942484379, 51.38414494693279, 48.275649547576904, 47.24807448685169, 48.33100877702236, 52.309091314673424, 47.15203084051609, 49.81608688831329, 49.32568900287151, 52.65380501747131, 51.189918369054794, 55.0530456751585, 58.59573997557163, 63.79368245601654, 59.855805560946465, 64.88473311066628, 62.093243300914764, 69.41221296787262, 40.23756846785545, 23.022058345377445, 59.889806136488914, 67.37608462572098, 65.30131235718727, 66.91377863287926, 63.716766983270645, 62.421895265579224, 65.77067837119102, 62.045035287737846, 53.45658794045448, 50.55270396173, 47.51327745616436, 48.290613144636154, 48.32088612020016, 48.12064066529274, 45.20115852355957, 46.06077499687672, 46.314821764826775, 48.41580502688885, 45.984642282128334, 47.59621560573578, 45.9565731883049, 46.924749836325645, 46.49023175239563, 46.64396770298481, 44.944987669587135, 48.347579687833786, 47.24563121795654, 46.35003827512264, 45.548148304224014, 47.7095977216959, 45.72103142738342, 47.81595781445503, 44.62832026183605, 48.23528051376343, 46.092081516981125, 49.24753099679947, 44.59452107548714, 47.15998001396656, 50.61880901455879, 49.96541507542133, 46.66634850203991, 48.347990065813065, 43.935875818133354, 49.365161284804344, 46.55570983886719, 51.85382254421711, 47.834516018629074, 51.83779880404472, 48.54117549955845, 60.87318576872349, 60.506250858306885, 70.5409500002861, 64.53690737485886, 72.48611882328987, 33.92693929374218, 0.24850809015333652, 1.2196704279631376, 2.3144056973978877, 36.007335260510445, 70.87970182299614, 56.83108426630497, 71.57989785075188, 44.48659926652908, 34.55617032945156, 43.92422944307327, 54.25240583717823, 56.150176003575325, 0.6347654387354851, 0.13978151109768078, 0.22248169843805954, 0.1655836999998428, 0.10326860239729285, 0.13908874592743814, 0.18895257962867618, 0.13259326166007668, 0.15526686765952036, 0.09963709570001811, 0.1068454647611361, 0.19468506186967716, 0.201379471400287, 0.09331027933512814, 0.11934646739973687, 0.12618178850971162, 0.0948029980645515, 0.23139805358368903], [0.0761154672363773, 0.045398171569104306, 0.06083217522245832, 0.02791287173749879, 0.016737593468860723, 0.02938195120805176, 0.0708223289984744, 0.10624863702105358, 0.031852054307819344, 0.1724000443937257, 0.06173980327730533, 0.04567178286379203, 0.03731665092345793, 0.03617068214225583, 0.003303027729089081, 0.047044722668942995, 0.03398479377210606, 0.0802681471395772, 0.04791268664121162, 0.03558696815161966, 0.15894661395577714, 0.22851893620099872, 0.1493823787313886, 24.632598124444485, 41.201386749744415, 41.068420484662056, 44.83680747449398, 26.54786065220833, 73.32929357886314, 65.71742802858353, 62.418904826045036, 57.34211124479771, 6.996599240228534, 0.20853466558037326, 0.7325379329267889, 41.90004006028175, 81.15275457501411, 72.15182796120644, 69.1380424797535, 65.86852312088013, 63.646854534745216, 58.81329730153084, 57.19239167869091, 57.77751848101616, 58.23863513767719, 55.99024258553982, 53.79389964044094, 51.75519123673439, 49.99940425157547, 47.04286649823189, 46.624660938978195, 48.90125937759876, 45.86128190159798, 48.276652693748474, 44.67677526175976, 47.96691231429577, 45.879957899451256, 47.62429229915142, 47.10319206118584, 46.59657284617424, 47.73646607995033, 45.9860710054636, 42.91849561035633, 45.68977810442448, 44.34035651385784, 45.853974893689156, 44.81988698244095, 45.35237900912762, 45.94047725200653, 46.44575893878937, 42.05624967813492, 43.05974543094635, 43.195751532912254, 45.58225907385349, 43.359005972743034, 46.554550901055336, 44.0760312974453, 42.23617002367973, 47.54003942012787, 51.182637959718704, 53.209931775927544, 53.57054382562637, 53.00778642296791, 52.19411328434944, 53.74463528394699, 57.02711194753647, 58.56177359819412, 60.96039488911629, 64.25566166639328, 57.591852843761444, 16.05694279074669, 27.819804400205612, 66.66035503149033, 61.46024286746979, 60.54059341549873, 57.74999275803566, 59.587444961071014, 59.07911203801632, 59.28656190633774, 51.49851121008396, 44.405770003795624, 42.13429369032383, 43.055805042386055, 41.87023065984249, 41.8585766851902, 40.23167498409748, 39.9507712572813, 42.06850402057171, 40.625280663371086, 39.81085516512394, 42.69466482102871, 42.11595967411995, 42.53635011613369, 41.036863178014755, 40.2342626452446, 40.13593152165413, 40.3157264739275, 43.36613439023495, 43.29589515924454, 41.52579814195633, 41.88917264342308, 40.735702738165855, 41.69646978378296, 42.02029600739479, 40.42561277747154, 40.35736083984375, 42.673112377524376, 45.18442802131176, 43.83006289601326, 42.54586100578308, 43.971179723739624, 43.65019574761391, 44.77064162492752, 45.35880446434021, 46.02781556546688, 42.54826247692108, 45.633472725749016, 43.35965193808079, 50.17112083733082, 48.678367137908936, 58.29179808497429, 59.94138836860657, 68.30708786845207, 58.69901083409786, 73.84465992450714, 11.022309847176075, 0.5750598362646997, 0.3504107549088076, 2.243841583840549, 32.19265155494213, 57.422252744436264, 53.965346440672874, 56.89816206693649, 19.471893645823002, 29.845173619687557, 36.18775337934494, 45.76632119715214, 9.715493470430374, 0.27065279718954116, 0.4109721427084878, 0.03525687199726235, 0.1501256099436432, 0.022795125260017812, 0.10275796768837608, 0.03658151654235553, 0.012161857848695945, 0.021568980409938376, 0.0909440973191522, 0.02784333992167376, 0.0040843800525180995, 0.0686284588300623, 0.04224254109431058, 0.0607770707574673, 0.06584770570043474, 0.026467416682862677, 0.04785477685800288, 0.04614341400156263, 0.04159421943768393, 0.06247240322409198, 0.06461796700023115, 0.017922512015502434, 0.01806122683774447, 0.02487951009243261, 0.0646814725769218, 0.054861741882632487, 0.0490471076045651, 0.08270612452179193, 0.05434421633253805, 0.03238327248254791, 0.04251952916092705, 0.04252916594850831, 0.06011733858031221, 0.07944779194076546, 0.13484461116604507, 0.04252641629136633, 0.04450221007573418, 0.14044182957150042, 0.31695669691544026, 0.21884967223741114, 29.25494559109211, 49.11452293395996, 44.41419415175915, 55.211869552731514, 35.54353214800358, 82.1602401137352, 70.77422708272934, 67.12533608078957, 63.80143404006958, 7.932763081043959, 0.42313873360399157, 0.6777474854607135, 42.68500953912735, 84.20621752738953, 74.00599166750908, 70.787822753191, 67.44764998555183, 66.83320015668869, 62.21968911588192, 62.03398548066616, 60.17024248838425, 59.484508484601974, 59.31645110249519, 56.141565665602684, 54.969142377376556, 52.210589200258255, 50.15458032488823, 48.84734787046909, 50.644415840506554, 48.58133174479008, 48.96410420536995, 48.12011629343033, 51.47272199392319, 48.085838332772255, 50.34145429730415, 50.55630996823311, 48.586526066064835, 48.29729698598385, 48.428184762597084, 44.969367161393166, 49.174354523420334, 46.66432321071625, 48.00111807882786, 46.76399566233158, 48.83887052536011, 47.571429535746574, 48.320901319384575, 44.92927551269531, 45.83288982510567, 44.20634910464287, 48.09230178594589, 47.39555597305298, 49.37417820096016, 46.00689768791199, 46.604947596788406, 48.63226421177387, 52.61887349188328, 52.43877075612545, 54.78682816028595, 54.335837960243225, 56.455710008740425, 57.78064951300621, 61.645551323890686, 59.841149747371674, 62.230317145586014, 65.10287180542946, 69.4157163798809, 25.19477415829897, 35.57196982204914, 70.40787354111671, 62.231536880135536, 62.663288712501526, 59.47781704366207, 62.36425615847111, 60.43589383363724, 62.14091174304485, 52.6303830742836, 47.31723837554455, 45.59089221060276, 46.09700605273247, 43.2196294516325, 43.86803425848484, 43.025741055607796, 43.343673795461655, 42.2545800358057, 44.11592535674572, 44.86375942826271, 43.28237168490887, 43.88104096055031, 44.033059403300285, 43.08193624019623, 42.42330998182297, 43.175479620695114, 42.56738305091858, 45.701508074998856, 46.78243227303028, 43.805010840296745, 44.87881042063236, 44.03441973030567, 44.84456665813923, 43.41421701014042, 43.09707082808018, 42.974614799022675, 45.59945695102215, 44.99858759343624, 45.1369571685791, 45.83521530032158, 47.35791519284248, 44.42515276372433, 49.187448620796204, 46.72117955982685, 49.7442327439785, 46.81679382920265, 46.368022710084915, 45.76785251498222, 52.37660229206085, 49.5815596729517, 60.72495952248573, 61.75602279603481, 71.64254888892174, 60.585263818502426, 74.72929045557976, 10.539341513067484, 0.6977049051783979, 1.9931842340156436, 1.494584963656962, 36.00736565887928, 62.484409511089325, 60.19919693470001, 63.104771822690964, 25.795919001102448, 38.78239095211029, 38.06886523962021, 54.015914127230644, 11.289895288646221, 0.23851609585108235, 0.3091849264455959, 0.07603511490742676, 0.10373227400123142, 0.045552345327450894, 0.05092425511975307, 0.039140879598562606, 0.013043173985352041, 0.04440204611455556, 0.05772727425210178, 0.06977266501053236, 0.050454924639780074, 0.04414510345668532, 0.0885483852471225, 0.05096406763186678, 0.05673718245816417, 0.0397520975820953, 0.07400412388960831, 0.15295801655156538, 0.16853778914082795, 0.12671784177655354, 0.1671461435034871, 0.19921308296034113, 0.2768001548247412, 0.1385126612149179, 0.10252403531922027, 0.17557247338118032, 0.4346278921002522, 0.21184439188800752, 0.1551955917966552, 0.16538475989364088, 0.09174969120067544, 0.11335542090819217, 0.29231727530714124, 0.17187074467074126, 0.21942645456874743, 0.18719057261478156, 0.17487510689534247, 0.2539675362640992, 0.3441303747240454, 0.17827020987169817, 43.63280028104782, 60.451385602355, 62.259191796183586, 60.371449291706085, 43.32934096455574, 87.16750502586365, 77.79746621847153, 75.55121675133705, 69.2057092487812, 9.387478921562433, 0.3492715582251549, 1.233286284841597, 48.557670414447784, 83.5447110235691, 79.21898514032364, 73.66349324584007, 72.72484481334686, 68.40501621365547, 65.32561585307121, 67.63709262013435, 63.56474094092846, 64.3035314977169, 64.22767236828804, 61.41822472214699, 57.26227752864361, 58.221083879470825, 52.94969514012337, 53.32060843706131, 55.06258316338062, 51.490531638264656, 53.76447781920433, 50.66251426935196, 54.85280022025108, 50.999240800738335, 53.68803732097149, 53.90644960105419, 50.590299144387245, 52.38585479557514, 49.51551541686058, 47.17539578676224, 52.2583070397377, 48.99249628186226, 50.02513267099857, 49.759336933493614, 50.80720290541649, 50.56369677186012, 52.145263105630875, 47.79013440012932, 49.46452595293522, 48.532280176877975, 51.54435575008392, 48.64502392709255, 51.10213167965412, 47.60169491171837, 46.91199392080307, 52.15912476181984, 55.21921455860138, 55.57425230741501, 58.557745814323425, 59.055921882390976, 58.09638977050781, 58.56491602957249, 62.08283945918083, 62.387476712465286, 64.82366278767586, 69.29998219013214, 61.52484320104122, 16.47037200629711, 33.298168033361435, 73.29910039901733, 64.07248869538307, 65.42634084820747, 60.3773807734251, 63.516278341412544, 61.85404613614082, 64.27133962512016, 54.12384733557701, 49.58232343196869, 46.828029826283455, 47.267157062888145, 46.1913625895977, 47.26070120930672, 45.74528552591801, 46.00894957780838, 46.70050106942654, 46.01301155984402, 45.71907453238964, 46.569719687104225, 47.401821836829185, 46.66424721479416, 45.18079921603203, 45.99804416298866, 45.30489295721054, 45.53239814937115, 49.315923526883125, 47.88055054843426, 44.949729815125465, 47.90557220578194, 45.707424357533455, 48.430749624967575, 47.217223942279816, 46.89494803547859, 44.27218057215214, 49.985405802726746, 49.25897978246212, 47.60997846722603, 48.646912425756454, 50.37297360599041, 48.55252929031849, 52.35562361776829, 49.6502485871315, 52.358177080750465, 46.86109945178032, 49.31252270936966, 47.53701098263264, 54.92939651012421, 51.427375227212906, 61.560698077082634, 63.304549902677536, 74.37555223703384, 61.21946878731251, 76.1351390182972, 13.669106271117926, 0.5084590287879109, 2.9467273922637105, 4.209084017202258, 37.935199812054634, 70.21798253059387, 63.44975531101227, 71.02040827274323, 28.124348558485508, 44.45390582084656, 46.30260922014713, 67.60718822479248, 21.17096107453108, 0.5168444663286209, 0.5984960880596191, 0.17613188945688307, 0.2755820530001074, 0.11053097754484043, 0.15153793181525543, 0.1371538481907919, 0.19497806177241728, 0.1932565908646211, 0.23557934327982366, 0.20736723759910092, 0.12601495371200144, 0.10131664268556051, 0.15833131416002288, 0.11899108998477459, 0.16717384045477957, 0.10718477467889898, 0.15808279858902097], [0.014889402700646315, 0.08238494527176954, 0.0522227500914596, 0.022431452489399817, 0.032872663214220665, 0.10608442200464197, 0.06339831408695318, 0.08591237317887135, 0.012176372401881963, 0.03573080379283056, 0.057959447731263936, 0.16471191396703944, 0.06073446034861263, 0.06934256074600853, 0.03674539017083589, 0.05166930459381547, 0.033236248782486655, 0.10331904617487453, 0.05989596334984526, 0.23246272379765287, 0.12596763437613845, 0.11035550414817408, 0.10689338523661718, 3.162129521369934, 56.51438266038895, 27.50457141548395, 29.106274768710136, 24.816056080162525, 32.74354599416256, 75.05744084715843, 58.066857755184174, 68.14415261149406, 17.044965773820877, 0.15181650436716154, 0.23066034395014867, 4.235338708385825, 66.52122169733047, 76.59397199749947, 73.1002114713192, 68.01686704158783, 67.61524379253387, 62.65606909990311, 62.09787905216217, 59.96358297765255, 57.096207439899445, 59.26429510116577, 54.42186154425144, 50.26504039764404, 48.92585165798664, 49.0046214312315, 45.05702085793018, 50.498587265610695, 46.970035806298256, 48.91333892941475, 48.46285030245781, 46.74829490482807, 48.55351343750954, 46.73165179789066, 46.32863402366638, 47.74461664259434, 47.01310649514198, 47.188136503100395, 44.32101555168629, 44.22077313065529, 45.15792444348335, 46.80076628923416, 45.74491314589977, 45.8456077426672, 45.74464336037636, 45.09590037167072, 42.92312756180763, 44.26213011145592, 43.56361359357834, 47.468493059277534, 44.62596818804741, 44.87757928669453, 45.04291221499443, 46.177618727087975, 50.27681216597557, 54.20099839568138, 54.2956855148077, 54.00460973381996, 55.51140747964382, 54.272689148783684, 52.572831362485886, 51.8671066313982, 54.048113599419594, 59.877886176109314, 59.132704362273216, 68.04038017988205, 43.49639520049095, 16.774741373956203, 48.09587739408016, 62.679152861237526, 61.10802836716175, 57.43245519697666, 58.52876856923103, 57.47445434331894, 60.920706018805504, 54.51427638530731, 47.58554197847843, 44.954171776771545, 43.27591583132744, 41.42999388277531, 42.034587040543556, 40.278575867414474, 39.577296897768974, 40.426068753004074, 42.41148501634598, 42.47539758682251, 41.53369031846523, 41.436225548386574, 42.3572201281786, 41.226469203829765, 39.58993501961231, 40.85894152522087, 42.1681422740221, 43.00673447549343, 41.18462584912777, 41.07716001570225, 42.148360535502434, 42.66505680978298, 41.821714863181114, 41.887101754546165, 42.52835914492607, 42.69741967320442, 42.297038957476616, 42.048186510801315, 43.42634975910187, 41.601444482803345, 44.09209683537483, 49.316584691405296, 54.89978089928627, 55.00046029686928, 51.26018799841404, 52.06959396600723, 47.93052926659584, 48.27460080385208, 47.76676185429096, 49.95538741350174, 54.46278914809227, 64.65695813298225, 61.31425470113754, 66.43286883831024, 55.60752712190151, 0.5438629759009928, 0.48058253712952137, 1.9728232640773058, 2.253306875936687, 45.453016608953476, 58.4701719135046, 59.39816951751709, 38.611859902739525, 20.803382098674774, 31.729156225919724, 31.827633641660213, 45.195956602692604, 1.0609499760903418, 0.03195472672814503, 0.023549750294478144, 0.07076728390529752, 0.09622549478081055, 0.04507240213570185, 0.09482268724241294, 0.04670580237871036, 0.036533703678287566, 0.11039311619242653, 0.011547309477464296, 0.05739568267017603, 0.08846389915561303, 0.0573973265272798, 0.08663542539579794, 0.04273657024896238, 0.05034191039158031, 0.042334062745794654, 0.013838133818353526, 0.035956746942247264, 0.01704083500953857, 0.04446042345080059, 0.0264216651339666, 0.02749569197476376, 0.009555707019899273, 0.02634837062942097, 0.05255810436210595, 0.044221206990187056, 0.014514412177959457, 0.05339423019904643, 0.05824137479066849, 0.047285174805438146, 0.008020927998586558, 0.015061593949212693, 0.02769674905721331, 0.06356900805258192, 0.07088743019266985, 0.05031686290749349, 0.14084457827266306, 0.057679543024278246, 0.04589580013998784, 0.058447190895094536, 5.522002391517162, 71.55988052487373, 32.16077506542206, 43.9129364490509, 35.64280562102795, 42.8133400529623, 84.9117636680603, 65.52764341235161, 75.92523068189621, 19.3055347725749, 0.3395787830231711, 0.49639066855888814, 4.298298954963684, 69.51905563473701, 78.20737302303314, 75.05709886550903, 71.04417219758034, 67.50665321946144, 64.81539443135262, 66.0224224627018, 63.39455187320709, 60.06859794259071, 62.13035590946674, 56.76830783486366, 54.21079806983471, 51.61057099699974, 52.661378011107445, 50.690826550126076, 52.351025864481926, 52.38561540842056, 50.39756588637829, 49.44740027189255, 49.75530914962292, 50.83437904715538, 49.75200712680817, 46.57795004546642, 48.47602799534798, 48.60535405576229, 51.098096296191216, 46.29526801407337, 46.19740046560764, 45.9098356962204, 48.462941497564316, 47.90576219558716, 48.35431292653084, 48.2862813770771, 46.519889160990715, 46.608333215117455, 45.35679817199707, 44.86727423965931, 50.350186228752136, 46.40230067074299, 47.945770248770714, 45.44266976416111, 48.95456291735172, 52.616160437464714, 55.66130943596363, 55.81447921693325, 55.900259613990784, 55.51015354692936, 58.7918246537447, 53.39693874120712, 57.29676067829132, 56.45587719976902, 61.77188694477081, 58.77317525446415, 75.69797247648239, 52.75805242359638, 17.58036084473133, 52.1592615544796, 66.7818421125412, 64.22330260276794, 61.55542775988579, 62.43783921003342, 58.872832506895065, 63.57356406748295, 56.3152239471674, 51.88904285430908, 46.43019497394562, 46.589889004826546, 44.2496781796217, 44.248253256082535, 44.43877883255482, 42.641555070877075, 43.36145684123039, 42.280342653393745, 45.657191053032875, 45.24194933474064, 43.87677378952503, 44.80195194482803, 43.91055017709732, 43.25257748365402, 45.18332988023758, 43.52470748126507, 46.60785064101219, 43.85842837393284, 42.53472000360489, 43.83272275328636, 44.541054144501686, 44.76802356541157, 44.62040528655052, 45.02728745341301, 45.62193274497986, 46.05425074696541, 43.32101561129093, 45.618311539292336, 45.38137525320053, 46.32606916129589, 50.92052422463894, 57.70669028162956, 58.38873088359833, 55.22833026945591, 54.96286891400814, 50.11648736894131, 49.78345423936844, 49.03854601085186, 52.7853349596262, 56.17925204336643, 66.12681806087494, 63.43569226562977, 67.05732733011246, 56.33665859699249, 0.4756631073541939, 1.3793549593538046, 2.601569825783372, 2.2039021644741297, 49.59026500582695, 62.90435537695885, 64.40436288714409, 43.70504580438137, 29.18034039437771, 30.665944777429104, 33.30158784985542, 53.75701881945133, 1.1784576019272208, 0.005095946353321779, 0.09111584513448179, 0.029185469466028735, 0.05847791951964609, 0.030149545273161493, 0.048251488187815994, 0.04813336054212414, 0.01819451841583941, 0.04570812583551742, 0.015838214385439642, 0.13298453675815836, 0.023863168535172008, 0.01733493700157851, 0.04272390178812202, 0.015446583056473173, 0.010065378792205593, 0.009814104287215741, 0.022853415393910836, 0.13054888229817152, 0.20615740329958498, 0.13843826833181083, 0.0835939557873644, 0.1201446249615401, 0.2557029150193557, 0.20324450335465372, 0.16022998024709523, 0.10675227327737957, 0.160377252032049, 0.2498650032794103, 0.27735542971640825, 0.13889788038795814, 0.16603151190793142, 0.13283435575431213, 0.1108813306200318, 0.16154600103618577, 0.2402385463938117, 0.09718607878312469, 0.31645565817598253, 0.24050763429841027, 0.17615289223613217, 0.49448486301116645, 11.11534595489502, 88.67194309830666, 42.85462483763695, 50.75694680213928, 38.795918226242065, 48.960661590099335, 91.69433891773224, 73.44763442873955, 83.06934893131256, 20.57695984840393, 0.4758518800372258, 0.48931473575066775, 5.102126346901059, 74.51601549983025, 80.16112178564072, 82.24706545472145, 72.37650990486145, 72.44813606142998, 68.66145685315132, 70.34369498491287, 65.96132934093475, 63.35473760962486, 65.46009823679924, 61.36673368513584, 57.97397933900356, 54.50918845832348, 56.2280186265707, 52.89875127375126, 59.032990112900734, 54.858332723379135, 54.74726848304272, 52.95526184141636, 52.830316945910454, 53.75661984086037, 50.78606463968754, 49.52031835913658, 51.33712247014046, 52.28081703186035, 52.76080347597599, 47.03210547566414, 48.514451533555984, 49.474401623010635, 53.910105004906654, 50.966330766677856, 52.20626883208752, 52.95960880815983, 48.30358564853668, 47.76039719581604, 48.84789124131203, 47.2876113653183, 52.959289625287056, 49.33007016777992, 51.13146610558033, 48.570498526096344, 51.24751567840576, 54.29861515760422, 57.85648204386234, 57.31609784066677, 57.21911944448948, 57.138996943831444, 63.72757740318775, 58.20320963859558, 58.88671696186066, 58.90129677951336, 65.15325710177422, 59.83243681490421, 75.10482430458069, 44.043478444218636, 16.463919952511787, 54.47338677942753, 71.6770738363266, 68.73009636998177, 63.37968707084656, 62.95789450407028, 60.24973042309284, 66.90481871366501, 61.708012372255325, 53.6901044100523, 50.10912336409092, 47.572459280490875, 44.84599158167839, 47.116354554891586, 46.36471688747406, 44.01417821645737, 44.384126365184784, 45.39221227169037, 49.58099350333214, 48.34694892168045, 47.87219099700451, 48.66499565541744, 47.32667326927185, 44.63420994579792, 46.399211436510086, 46.32304072380066, 49.46850433945656, 45.40102019906044, 43.560189977288246, 46.49739816784859, 48.93703445792198, 46.89806766808033, 45.68696245551109, 47.79135413467884, 49.12560693919659, 49.688919112086296, 46.35038025677204, 46.577076092362404, 48.22307176887989, 51.88015133142471, 53.8110177218914, 61.31602920591831, 60.82762621343136, 57.499225214123726, 59.413060918450356, 51.6629321873188, 53.55930782854557, 52.62872256338596, 55.620735213160515, 58.62168878316879, 66.5135309100151, 64.08819705247879, 66.8468414247036, 59.50916916131973, 1.087104210164398, 1.553687823470682, 9.08430838957429, 4.055430237203836, 55.134771689772606, 67.02933043241501, 67.85616606473923, 45.76912924647331, 32.713751792907715, 46.78375840187073, 42.78934434056282, 68.03944543004036, 3.761977208778262, 0.35643170995172113, 0.18631075654411688, 0.14240817952668294, 0.13898233679356053, 0.1138354791328311, 0.23344638117123395, 0.2023412799462676, 0.13949900516308844, 0.12988183996640146, 0.13700803101528436, 0.22858010401250795, 0.15448123012902215, 0.09905311453621835, 0.14116245496552438, 0.16447586647700518, 0.19646909582661465, 0.11904842831427231, 0.09968750237021595], [0.028761692010448314, 0.030555500052287243, 0.047120369781623594, 0.023016140548861586, 0.027466080282465555, 0.02520400859793881, 0.06321854365523905, 0.024064027093118057, 0.016060821581049822, 0.13783758884528652, 0.027534200162335765, 0.09028158950968646, 0.019977097763330676, 0.07403985087876208, 0.05780212355602998, 0.1416786335175857, 0.1114504985162057, 0.022208075315575115, 0.05801770261314232, 0.07360725299804471, 0.18716257880441844, 0.0789948740566615, 0.06023620466294233, 0.17955344257643446, 20.749419294297695, 42.85889580845833, 25.902165099978447, 26.353037506341934, 25.651581846177578, 69.58589404821396, 47.07132317125797, 70.41324645280838, 35.87813079357147, 0.2644628402777016, 0.990251504117623, 0.297121019102633, 18.730331137776375, 75.79457849264145, 72.24729403853416, 72.65678286552429, 67.90357232093811, 64.93022426962852, 61.83047220110893, 61.68444983661175, 62.710717767477036, 56.23823627829552, 54.13837395608425, 48.52829419076443, 48.017536997795105, 46.45781569182873, 49.236902967095375, 48.04722100496292, 51.31130285561085, 46.66442200541496, 48.986720591783524, 48.94140802323818, 48.41316036880016, 47.08087205886841, 47.1292320638895, 46.15713022649288, 45.54959982633591, 44.95470754802227, 47.35558971762657, 45.524566769599915, 45.85380010306835, 44.6626628190279, 45.51016554236412, 44.205942526459694, 45.70849969983101, 46.238495260477066, 45.27723044157028, 42.38419488072395, 45.34183457493782, 44.844323471188545, 46.810132786631584, 46.729801297187805, 52.44763948023319, 59.82740208506584, 58.889194428920746, 54.57478813827038, 56.17232881486416, 57.633787393569946, 57.034491151571274, 57.07640290260315, 56.849509477615356, 51.589668318629265, 53.53200629353523, 56.32068045437336, 61.12267658114433, 56.82489059865475, 68.93783882260323, 41.12154543399811, 44.923119843006134, 69.63854402303696, 61.11977733671665, 61.47684797644615, 56.56041719019413, 55.18766105175018, 54.51690964400768, 52.221240028738976, 45.576403588056564, 45.48696018755436, 43.76966513693333, 41.92616365849972, 40.668567940592766, 43.750943541526794, 41.41777753829956, 41.25137306749821, 41.84074804186821, 42.80708558857441, 40.664794743061066, 41.73392437398434, 40.84603741765022, 42.844760566949844, 42.92025871574879, 40.879061445593834, 43.2225438952446, 42.32821248471737, 41.574887707829475, 43.14580321311951, 42.566813081502914, 41.550937592983246, 41.21674932539463, 42.06330589950085, 43.96475426852703, 44.24645595252514, 42.72199295461178, 44.01608571410179, 43.135855346918106, 46.2215443700552, 50.80948658287525, 58.896087259054184, 57.91637443006039, 57.948247119784355, 55.11216290295124, 57.57545292377472, 52.17462033033371, 56.070254892110825, 48.04935269057751, 52.49108634889126, 53.54549176990986, 65.59438303112984, 58.604403510689735, 75.4389175772667, 31.359513960778713, 0.09973567517590709, 1.0520681901834905, 2.0879397494718432, 2.67829364631325, 46.348814740777016, 56.84410236775875, 46.75436317920685, 14.804561343044043, 25.157914236187935, 28.16579293459654, 45.48635981976986, 19.91058960556984, 0.054827473213663325, 0.11538394799572416, 0.04443664503924083, 0.09964317388948984, 0.015451103663508547, 0.09337161041912623, 0.030154183696140535, 0.03357622663315851, 0.00227175995860307, 0.054227120272116736, 0.035198015975765884, 0.03287275227194186, 0.04037185397464782, 0.03777491227083374, 0.045207339426269755, 0.07591626737848856, 0.043010927402065136, 0.03286813240265474, 0.014274484183260938, 0.04832560276554432, 0.07357564492849633, 0.027667219001159538, 0.053180910981609486, 0.039219866375788115, 0.023254351399373263, 0.02971780086227227, 0.034135913592763245, 0.02888693314162083, 0.07039416916086338, 0.06330789081403054, 0.036369150984683074, 0.01905407199956244, 0.07142703834688291, 0.09495749094639905, 0.08830257109366357, 0.09196404571412131, 0.04673629351600539, 0.05163606008864008, 0.03267892185249366, 0.11894732553628273, 0.07654327084310353, 0.033748275018297136, 0.24928431725129485, 29.208521582186222, 51.14136077463627, 27.568425089120865, 42.40476317703724, 33.16167175769806, 78.5601156949997, 59.283636063337326, 77.53390476107597, 39.73070986568928, 0.26506789843551815, 1.3262846320867538, 0.381890403223224, 19.887889623641968, 81.93381026387215, 76.32693752646446, 76.70518442988396, 70.83403587341309, 68.82275819778442, 65.44769570231438, 67.24812269210815, 65.83546489477158, 60.26905998587608, 58.357796743512154, 52.90532112121582, 49.38859462738037, 49.214058592915535, 51.81081265211105, 49.65760499238968, 53.34569089114666, 48.46124678850174, 51.22135028243065, 52.75282010436058, 50.534894317388535, 50.00426039099693, 49.020971953868866, 47.79090955853462, 49.37152214348316, 47.43519924581051, 51.21707171201706, 48.508010879158974, 48.622620329260826, 46.132735535502434, 47.044280022382736, 46.15423858165741, 47.228448539972305, 47.97687537968159, 48.383430764079094, 46.081852465867996, 45.59666030108929, 47.82323822379112, 48.94570179283619, 47.62296997010708, 54.56828288733959, 60.47417297959328, 59.923267140984535, 56.80180303752422, 56.291289031505585, 60.489641949534416, 56.84917509555817, 58.52404162287712, 59.70560722053051, 54.13606747984886, 58.00581403076649, 57.789476439356804, 62.05102376639843, 58.17618548870087, 83.62211287021637, 51.67414538562298, 44.333114102482796, 71.42198592424393, 62.3346671462059, 65.35170525312424, 60.13346426188946, 57.64492839574814, 56.17411091923714, 54.38002958893776, 48.10287281870842, 47.82425656914711, 46.0918915271759, 44.92799498140812, 44.25160467624664, 46.090117022395134, 43.249647840857506, 43.50386179983616, 43.164015635848045, 46.31293326616287, 43.30313757061958, 44.67891074717045, 43.257441222667694, 46.23953640460968, 44.23314526677132, 42.56713226437569, 43.83577398955822, 45.95353715121746, 45.0482015311718, 44.96965974569321, 45.293816551566124, 45.175445303320885, 43.298919796943665, 43.98536056280136, 45.70078231394291, 46.73483982682228, 45.15800043940544, 45.17218507826328, 46.542972922325134, 48.26323181390762, 53.0961848795414, 62.107203751802444, 61.57950706779957, 61.738513335585594, 58.78275454044342, 60.452681332826614, 54.95105914771557, 57.2599558532238, 50.201329216361046, 54.80310268700123, 57.22241386771202, 67.75867849588394, 60.637613609433174, 76.48711413145065, 31.662346310913563, 0.16524574079085141, 2.678513559512794, 3.348691910505295, 3.5908220428973436, 51.02289453148842, 62.078948467969894, 56.28159575164318, 21.844528131186962, 33.84599223732948, 28.7117837369442, 53.28182011842728, 23.037310726940632, 0.10621604931657203, 0.18315262132091448, 0.09812990509090014, 0.1340329836239107, 0.026899842014245223, 0.1149384886957705, 0.03493726238957606, 0.05833015049574897, 0.03080529953876976, 0.022506914065161254, 0.07128180004656315, 0.026213158744212706, 0.11772785073844716, 0.07121346308849752, 0.043602604637271725, 0.042135408366448246, 0.05564280778344255, 0.051948793698102236, 0.02439087078528246, 0.18877697264542803, 0.17760506743798032, 0.11890390247572213, 0.16031243285397068, 0.11398621674743481, 0.09329272012109868, 0.1517508688266389, 0.10489539010450244, 0.17757708847057074, 0.22819359350251034, 0.12492787063820288, 0.13497309177182615, 0.1538717042421922, 0.16690810705767944, 0.24367951409658417, 0.2452648602775298, 0.14967975730542094, 0.12393003082252108, 0.2262741472804919, 0.17625803971895948, 0.24160910019418225, 0.24035251059103757, 0.08909951895475388, 0.4020853398833424, 47.26614631712437, 64.63206186890602, 43.427907675504684, 44.18294236063957, 37.88934767246246, 88.9827436208725, 60.26769205927849, 88.21141541004181, 43.56803275644779, 0.35580192343331873, 1.927440280560404, 0.5203476408496499, 23.6543957144022, 85.47541782259941, 78.53183001279831, 80.56167349219322, 71.98151350021362, 71.46474123001099, 69.50086981058121, 70.46135947108269, 69.58030834794044, 64.04092758893967, 61.37217119336128, 58.04709501564503, 53.50429058074951, 52.01054513454437, 56.135383397340775, 55.152383744716644, 58.23800057172775, 54.310584515333176, 54.43107984960079, 56.80063650012016, 53.67232136428356, 53.53973887860775, 52.66306892037392, 50.69080375134945, 51.97330333292484, 49.063487872481346, 52.92508386075497, 49.321110248565674, 52.311827167868614, 49.71133030951023, 48.95319499075413, 48.9536889642477, 47.830039858818054, 50.52352912724018, 50.19136615097523, 49.439542293548584, 49.23243820667267, 49.96858410537243, 51.15152142941952, 50.420098677277565, 57.73302286863327, 64.4576208293438, 64.04389902949333, 58.12412068247795, 59.668198227882385, 60.95605932176113, 59.840233996510506, 59.88023065030575, 63.20990838110447, 56.621707901358604, 59.626943841576576, 58.56983296573162, 65.07045194506645, 56.640915870666504, 76.5694785118103, 37.60630466043949, 38.85896444320679, 77.84665837883949, 65.10781913995743, 66.17482468485832, 60.31137451529503, 58.6842106282711, 56.240360364317894, 59.227794259786606, 51.747185066342354, 48.72272975742817, 47.299398332834244, 45.69147281348705, 44.679739102721214, 49.787694811820984, 45.778434947133064, 48.18981595337391, 45.87221011519432, 48.50868344306946, 45.183231085538864, 48.49479898810387, 47.19387039542198, 49.665386974811554, 48.04524511098862, 45.78222714364529, 47.36794665455818, 48.19436430931091, 47.81826809048653, 45.921246483922005, 46.73421286046505, 45.9540007263422, 46.87319800257683, 46.93374015390873, 49.191453605890274, 49.15430299937725, 47.14319631457329, 48.07780176401138, 47.795062735676765, 52.23016194999218, 56.7385858297348, 64.71525460481644, 64.96566116809845, 61.79319240152836, 61.01106517016888, 63.93872067332268, 57.825912684202194, 61.08246713876724, 54.29057098925114, 58.80684144794941, 57.858746722340584, 69.09103140234947, 62.88889400660992, 78.28653797507286, 34.60117511451244, 0.12112664961023256, 3.1116480426862836, 5.531100053340197, 4.868884887546301, 59.070592895150185, 64.810751080513, 59.13650795817375, 20.380538888275623, 41.025577783584595, 39.99269060790539, 62.660362869501114, 36.19413323700428, 0.14387696399353445, 0.41848986118566245, 0.257666222169064, 0.14711692841956392, 0.11737168664694764, 0.26519409322645515, 0.20933899038936943, 0.16776166594354436, 0.11746283722459339, 0.16340073198080063, 0.17723446857417002, 0.0909765217511449, 0.2255648173741065, 0.11747073367587291, 0.150495526031591, 0.20883818913716823, 0.14252005086746067, 0.13476753170834854, 0.0982975636725314], [0.05040876305429265, 0.05814040188852232, 0.03333673557790462, 0.036082934311707504, 0.10242510703392327, 0.010579832778603304, 0.05006871841032989, 0.04351215538918041, 0.05766117486928124, 0.031682455010013655, 0.06271066231420264, 0.03534280156600289, 0.07751561046461575, 0.0910634569299873, 0.15551323100226, 0.016760143626015633, 0.016125640759128146, 0.030897112483216915, 0.032435207976959646, 0.05087532161269337, 0.1192075373546686, 0.030053759983275086, 0.02379308938543545, 0.40391975082457066, 2.34949610196054, 46.41104020178318, 37.41191849112511, 29.323193728923798, 29.145205579698086, 48.02097961306572, 48.85226480662823, 60.31620405614376, 54.08986575901508, 1.994103784672916, 0.8319567481521517, 0.1616394374286756, 1.9273153622634709, 54.343958124518394, 73.43862131237984, 75.34996435046196, 71.18591979146004, 67.84637778997421, 64.20118018984795, 64.36486780643463, 62.26318158209324, 61.180878058075905, 52.32957981526852, 48.98191384971142, 49.46082875132561, 53.32121640443802, 54.34049651026726, 51.4706739038229, 50.24643659591675, 50.98024562001228, 48.182463347911835, 49.54776808619499, 48.05789843201637, 48.143542036414146, 46.846398040652275, 47.1826533973217, 48.296077251434326, 48.794439509510994, 49.865742623806, 48.031995221972466, 47.61153258383274, 46.22747205197811, 45.53392946720123, 47.11908280849457, 45.452697426080704, 44.833174869418144, 42.94286750257015, 45.465749725699425, 44.86794300377369, 46.11173786222935, 47.45719626545906, 50.86361087858677, 60.65342076122761, 61.27387046813965, 63.62178348004818, 56.22677609324455, 58.2336688041687, 58.90495978295803, 60.32373145222664, 57.992605939507484, 60.28670243918896, 54.50931005179882, 56.61082908511162, 56.06048561632633, 62.602469176054, 61.73116832971573, 66.23470187187195, 60.51978573203087, 52.61410474777222, 66.66005864739418, 60.96805527806282, 60.08477747440338, 55.625640749931335, 56.095337346196175, 52.737662717700005, 48.64726580679417, 46.195276379585266, 45.12243054807186, 43.33279497921467, 44.11122500896454, 44.55623812973499, 43.53919230401516, 43.05914506316185, 41.97432227432728, 41.636953577399254, 40.04757106304169, 40.63598468899727, 41.53479985892773, 41.44168205559254, 43.46105329692364, 43.15569028258324, 43.9486051350832, 43.19148816168308, 42.29586482048035, 41.935294568538666, 42.44935758411884, 44.79835353791714, 42.87959709763527, 43.14906723797321, 41.020474657416344, 41.81532360613346, 43.34315702319145, 43.78372058272362, 44.81074847280979, 42.883332297205925, 48.88343833386898, 53.77444848418236, 60.43858028948307, 57.26635470986366, 55.74542932212353, 61.96917995810509, 58.663296550512314, 60.631036162376404, 56.81672103703022, 53.40940207242966, 51.494844406843185, 56.36631980538368, 66.25595033168793, 58.586362078785896, 75.47951459884644, 13.208560533821583, 1.1745654232800007, 1.2709520012140274, 0.7018402114044875, 3.859241302125156, 50.251159742474556, 60.90836048126221, 21.337889917194843, 12.768567893654108, 36.85934454202652, 28.37072353810072, 49.45006772875786, 4.246423188596964, 0.10104615212185308, 0.02737406324740732, 0.12491512054111809, 0.029185380408307537, 0.04087873712705914, 0.04260497633367777, 0.010546144840191118, 0.01597618334926665, 0.10558144625974819, 0.03947603348933626, 0.01737512429826893, 0.05132610953296535, 0.1086875049804803, 0.028193884099891875, 0.03453100704064127, 0.10718391378759407, 0.05813843890791759, 0.02674607272638241, 0.02310559902980458, 0.03481193220068235, 0.09479254862526432, 0.042006556686828844, 0.03408084994589444, 0.07960275237564929, 0.007962715790199582, 0.01884417222754564, 0.10165380779653788, 0.017376701362081803, 0.04433123038324993, 0.006760783508070745, 0.047303097671829164, 0.0710680392512586, 0.07685587086598389, 0.06111318572948221, 0.14820567390415817, 0.044310509620117955, 0.04915694174997043, 0.038460400683106855, 0.017456849600421265, 0.06399443678674288, 0.0009068042709259316, 0.026324599639337976, 0.32160969567485154, 1.8557827756740153, 61.61257289350033, 37.13381141424179, 31.192404627799988, 36.83227099478245, 59.676610976457596, 56.26493364572525, 67.32342705130577, 60.49240440130234, 2.4451046716421843, 1.4618475828319788, 0.3953100956277922, 2.20250787679106, 58.557153046131134, 78.84684830904007, 79.54213500022888, 73.16527158021927, 68.62044185400009, 69.15212452411652, 69.14669081568718, 63.85241970419884, 64.78691875934601, 56.66524596512318, 52.213420048356056, 52.268608286976814, 54.907099306583405, 55.83549588918686, 53.09777319431305, 52.59892076253891, 52.55029857158661, 49.94376003742218, 51.82752035558224, 50.118964836001396, 48.87374125421047, 49.96596224606037, 49.58088330924511, 49.62766259908676, 49.5519744604826, 50.64840942621231, 50.966672748327255, 49.937608167529106, 47.766248881816864, 47.85801015794277, 49.65751759707928, 49.468416944146156, 45.207336992025375, 45.58876432478428, 48.22384312748909, 46.64822727441788, 47.15399533510208, 48.95477570593357, 54.2743306607008, 63.61444607377052, 62.83818572759628, 66.4395260810852, 61.37222819030285, 60.87435610592365, 59.470384642481804, 61.06395073235035, 59.52032916247845, 60.879254043102264, 57.53762975335121, 58.39181251823902, 58.840538039803505, 63.71765233576298, 62.09459222853184, 66.40855014324188, 76.71367317438126, 60.833367705345154, 66.9624312222004, 63.24331618845463, 62.21052020788193, 58.76128949224949, 58.51075753569603, 55.688804760575294, 51.235196739435196, 46.81124992668629, 46.203157156705856, 46.13085463643074, 47.793922796845436, 45.65795101225376, 45.492925867438316, 45.81865578889847, 45.59998132288456, 45.68632788956165, 43.055067881941795, 43.08678478002548, 43.55297416448593, 42.62469157576561, 44.25444692373276, 45.84504917263985, 45.55574409663677, 45.970142260193825, 45.63383370637894, 43.56645584106445, 45.58321662247181, 47.25423775613308, 45.4478906840086, 44.79756698012352, 43.87809991836548, 44.92425598204136, 47.03626625239849, 46.53286926448345, 46.84659942984581, 44.196811616420746, 51.32929489016533, 57.27066367864609, 61.76197327673435, 60.08015312254429, 59.17352557182312, 63.242096453905106, 60.49696035683155, 62.31740467250347, 57.39582136273384, 55.22066608071327, 53.162453323602676, 57.96573378145695, 69.39284160733223, 60.26945136487484, 77.41450756788254, 13.576675280928612, 1.3045151252299547, 3.6750799091532826, 2.8233807859942317, 4.252847693860531, 56.8868500739336, 65.66208779811859, 31.586107201874256, 18.676417730748653, 41.06393672525883, 30.308266170322895, 58.52122977375984, 4.678901256993413, 0.09295709867728874, 0.023696018324699253, 0.08675411707372405, 0.07926484511699528, 0.04136757866945118, 0.06367618159856647, 0.029440738580888137, 0.05681533060851507, 0.054876659050933085, 0.030186680487531703, 0.04650051690987311, 0.03736993341590278, 0.061718191936961375, 0.01911342711537145, 0.019450024483376183, 0.020491556388151366, 0.041734500191523694, 0.07061892116325907, 0.05177953949896619, 0.1425532397115603, 0.1251986506395042, 0.08320367516716942, 0.0873671830049716, 0.21047377871582285, 0.1110176854126621, 0.11467948657809757, 0.15426807047333568, 0.22897454065969214, 0.10648204246535897, 0.14516942901536822, 0.17063673119992018, 0.17536216357257217, 0.19564879999961704, 0.2429783478146419, 0.23002879112027586, 0.1268586123478599, 0.14273714390583336, 0.15395188587717712, 0.11274093005340546, 0.21503322233911604, 0.1071444241097197, 0.17669822234893218, 0.5870783538557589, 8.537540528923273, 82.66836404800415, 53.65069292485714, 50.018239840865135, 43.71758513152599, 63.26307512819767, 62.49681204557419, 73.62935587763786, 67.35126435756683, 2.7182335406541824, 1.8021354731172323, 0.43542142608202994, 2.715896903537214, 63.12839515507221, 81.5008082985878, 81.72278478741646, 76.64918303489685, 74.16660144925117, 71.79607585072517, 73.81986245512962, 69.7708909213543, 67.5463230907917, 60.800670459866524, 54.92747761309147, 56.06851078569889, 60.768189802765846, 59.965843856334686, 56.440419629216194, 57.28899389505386, 56.803357154130936, 53.145954608917236, 54.24006029963493, 54.550028666853905, 52.14413456618786, 52.38533042371273, 52.18462519347668, 53.493917137384415, 52.192452773451805, 55.22877484560013, 53.75624746084213, 53.535961881279945, 50.611513406038284, 51.87399186193943, 51.9871611893177, 51.40308693051338, 48.40148739516735, 47.43394151329994, 50.97738817334175, 50.24200223386288, 50.81780053675175, 50.93573860824108, 56.60182736814022, 67.33805626630783, 65.35564944148064, 69.59442839026451, 62.579062432050705, 66.52279481291771, 62.42854870855808, 63.70619595050812, 61.31351754069328, 66.04687795042992, 61.84192858636379, 60.759150087833405, 59.61383454501629, 67.03013598918915, 66.18848875164986, 68.61649766564369, 73.61245438456535, 57.91101671755314, 68.92826333642006, 66.7353630065918, 64.27982077002525, 62.85714291036129, 61.759112030267715, 57.915014103055, 53.23365390300751, 50.817781537771225, 49.327714294195175, 46.92675992846489, 50.34703239798546, 48.340162485837936, 47.52490483224392, 47.999769151210785, 47.100190222263336, 47.47265003621578, 46.39376252889633, 44.953278824687004, 48.66713114082813, 47.62852527201176, 48.20023499429226, 47.7023097127676, 47.71821565926075, 48.46740245819092, 47.431422248482704, 47.5322650372982, 47.22296163439751, 49.96968224644661, 47.879399210214615, 48.11217091977596, 44.96679849922657, 47.909558191895485, 49.76561039686203, 48.93668867647648, 47.24580980837345, 46.31099916994572, 55.44410169124603, 58.95785294473171, 65.6420324742794, 63.74935403466225, 61.61527454853058, 66.99608981609344, 62.87936791777611, 65.87236851453781, 61.76657862961292, 57.72830732166767, 56.31171673536301, 61.18131883442402, 69.90650564432144, 62.62779101729393, 77.60281026363373, 15.702979434281588, 1.223509528208524, 4.699899405241013, 3.784233327023685, 4.648427367210388, 64.57178950309753, 69.79172140359879, 30.695780776441097, 19.049973785877228, 55.8979569375515, 38.06717053055763, 72.79405429959297, 9.044299386441708, 0.361821394180879, 0.22812956100096926, 0.3532776713836938, 0.13715505047002807, 0.10614949351293035, 0.12909746408695355, 0.18288461695192382, 0.1069681195076555, 0.15330452530179173, 0.0866444870189298, 0.09984707896364853, 0.16966751602012664, 0.16684088332112879, 0.07086534387781285, 0.12465373612940311, 0.16066311247413978, 0.11832818141556345, 0.19146243401337415, 0.17869041388621554], [0.06038902029104065, 0.09916474096826278, 0.01759766284521902, 0.054700814580428414, 0.018603358294058125, 0.034840089283534326, 0.019089205270574894, 0.03074657710385509, 0.05476989368617069, 0.018225104176963214, 0.02542200334573863, 0.027893600017705467, 0.07346263810177334, 0.007144181172407116, 0.030196920270100236, 0.07439518376486376, 0.03073673437029356, 0.030538721948687453, 0.05885000638954807, 0.06002100410114508, 0.013119029827066697, 0.021245118296064902, 0.11175048945005983, 0.07017300915322267, 0.33753677853383124, 12.688047364354134, 45.650784596800804, 37.36304171383381, 32.29824788868427, 24.051318615674973, 64.58638072013855, 64.06191006302834, 63.63799341022968, 8.007117491215467, 0.4067825706442818, 1.975307974498719, 0.3745618730317801, 23.72789327055216, 75.20560249686241, 77.88974806666374, 73.66481557488441, 70.08546084165573, 63.520317524671555, 66.78799018263817, 65.06172761321068, 60.09431876242161, 51.01406380534172, 52.117266207933426, 56.6667240858078, 61.84512801468372, 67.8120656311512, 69.24092575907707, 63.90472009778023, 57.621533051133156, 50.97333759069443, 52.720126658678055, 49.03179757297039, 47.96902880072594, 50.761460959911346, 49.96628522872925, 47.950375601649284, 47.45854899287224, 46.51929259300232, 46.40442855656147, 46.141748651862144, 46.34719982743263, 45.226210579276085, 45.96358761191368, 44.36522997915745, 45.79682596027851, 45.910785645246506, 45.15227414667606, 43.45688872039318, 45.793717727065086, 44.11450423300266, 53.5540147125721, 63.16533677279949, 61.465376392006874, 61.823750361800194, 63.12896892428398, 63.43375816941261, 62.82455585896969, 60.567579567432404, 60.70412144064903, 57.901426032185555, 60.50572268664837, 58.20640906691551, 61.438511833548546, 62.25764527916908, 63.412167727947235, 61.611626744270325, 61.54071494936943, 58.77217970788479, 57.8123664110899, 56.35845422744751, 57.303581312298775, 54.192296862602234, 52.60665334761143, 48.209852278232574, 46.13898999989033, 44.81335513293743, 45.13977661728859, 46.40713021159172, 44.37735892832279, 44.811333641409874, 45.29355816543102, 42.939816266298294, 42.38397069275379, 41.48852974176407, 40.1153290271759, 40.44869273900986, 42.46719002723694, 42.72440202534199, 44.959624484181404, 44.39999431371689, 43.046928718686104, 43.45490902662277, 42.304927334189415, 41.37463465332985, 44.52292911708355, 43.80273096263409, 44.00293841958046, 41.204103603959084, 43.44869635999203, 42.51893565058708, 43.81883829832077, 43.18437494337559, 46.25733844935894, 43.44016581773758, 46.98610134422779, 54.52543258666992, 62.619803845882416, 59.7969239205122, 62.92193703353405, 64.84560281038284, 60.83116762340069, 60.58507762849331, 58.8204675167799, 58.08048002421856, 55.7121355086565, 59.375621527433395, 63.70972216129303, 61.580901592969894, 64.74632173776627, 3.9271134976297617, 0.8043484389781952, 1.2105574482120574, 2.4195671919733286, 7.688483688980341, 53.432732820510864, 46.136835515499115, 10.374584253877401, 30.130766294896603, 32.744887322187424, 36.199000775814056, 33.134681805968285, 0.17276761529501528, 0.08897336869267747, 0.04418672309839167, 0.0981338533165399, 0.04495487934036646, 0.023385210588457994, 0.04315250691433903, 0.006813993641117122, 0.015276746271410957, 0.052006918704137206, 0.06587488314835355, 0.039497132747783326, 0.07121383416233584, 0.0628656821209006, 0.06451558030676097, 0.07211413350887597, 0.08925417510909028, 0.034771600185194984, 0.0034844134916056646, 0.030915554852981586, 0.01959552068001358, 0.03746255344594829, 0.08353370081749745, 0.028211029566591606, 0.05877661540580448, 0.06063811473723035, 0.009802445147215622, 0.01940458834724268, 0.030959848081693053, 0.04719156400824431, 0.00734337639187288, 0.03617128328187391, 0.04082692779775243, 0.023958371239132248, 0.04827470998861827, 0.06616697020945139, 0.020660960872191936, 0.06656671321252361, 0.049622439037193544, 0.04583114052366, 0.04451173183042556, 0.07842688617529348, 0.10908387121162377, 0.07212768512545153, 0.6754929001908749, 24.74270861595869, 56.77281439304352, 35.33797837793827, 41.21588297188282, 34.009634256362915, 71.17564514279366, 71.34842947125435, 72.9814450442791, 9.042782317847013, 0.38099730270914733, 4.222006648778915, 0.26916476141195744, 26.178866252303123, 80.73248952627182, 80.18024235963821, 77.25985586643219, 72.69731149077415, 68.25595781207085, 69.96590405702591, 68.4071896970272, 63.068267181515694, 55.193793922662735, 56.491538286209106, 55.603594332933426, 63.83644536137581, 69.37139555811882, 69.90542650222778, 63.39956380426884, 59.826949909329414, 54.33282472193241, 53.44670087099075, 51.29877112805843, 52.17647843062878, 54.21011030673981, 52.265435457229614, 50.1490668207407, 49.02445636689663, 48.32719758152962, 48.55538293719292, 47.46823847293854, 48.859131038188934, 49.64608021080494, 48.941985592246056, 47.21514545381069, 48.431813567876816, 48.84822182357311, 47.87079267203808, 47.198829129338264, 47.479786053299904, 46.72241069376469, 55.343885868787766, 64.80900317430496, 64.57949548959732, 63.75993266701698, 64.3409138917923, 64.85287562012672, 64.70429599285126, 63.27915586531162, 62.90890373289585, 61.18156962096691, 62.039202600717545, 62.458350509405136, 63.41327726840973, 63.878562301397324, 65.58844774961472, 62.56474860012531, 64.69663560390472, 61.95264704525471, 59.75196473300457, 59.76889282464981, 57.760955169796944, 56.02534510195255, 56.23055689036846, 51.42836317420006, 48.273935839533806, 48.27313408255577, 47.51238450407982, 46.9436614215374, 47.030463963747025, 46.28667287528515, 47.393314093351364, 44.76661004126072, 43.953643664717674, 42.26209223270416, 43.56696501374245, 44.32195030152798, 44.77177016437054, 43.92818123102188, 47.222342267632484, 45.2698740363121, 44.41833212971687, 45.599316358566284, 45.120230466127396, 44.03016395866871, 44.56618219614029, 45.75729288160801, 44.904580637812614, 44.12641279399395, 46.26152202486992, 44.92261826992035, 44.60373938083649, 46.379984468221664, 47.88466952741146, 46.74236722290516, 48.69125224649906, 56.37214869260788, 64.61308568716049, 63.46078611910343, 65.50875082612038, 66.82906597852707, 64.12402912974358, 63.72894532978535, 61.216140165925026, 61.53294816613197, 57.82452955842018, 63.3779239654541, 66.43654704093933, 64.56853687763214, 67.89049342274666, 4.173366408795118, 0.8265326579567045, 8.470664117485285, 4.157137954607606, 9.15981413796544, 58.94097425043583, 53.90554904937744, 14.932362735271454, 34.10428337752819, 37.05215759575367, 40.85625886917114, 41.664342507719994, 0.18536974297603592, 0.12061816712957807, 0.05758138286182657, 0.1618737037642859, 0.022892916204000358, 0.06858290580566972, 0.02569857952039456, 0.040435997798340395, 0.054754623997723684, 0.008828755744616501, 0.07553599833045155, 0.06895016500493512, 0.026017315249191597, 0.024271164220408536, 0.052774381038034335, 0.07688414669246413, 0.024264093408419285, 0.05592846042418387, 0.05664951997459866, 0.02937843899417203, 0.12266973790246993, 0.2049107733182609, 0.1487556053325534, 0.11047475985833444, 0.19815728883258998, 0.09610381966922432, 0.15244477690430358, 0.10184075479628518, 0.08714499141206034, 0.12979729450307786, 0.08720586978597566, 0.12614016886800528, 0.21961110091069713, 0.12163827879703604, 0.10105355875566602, 0.14457281649811193, 0.09455787410843186, 0.1306572210160084, 0.14827218517893925, 0.1983171029132791, 0.09152485014055856, 0.24496578960679471, 0.25522470474243164, 0.18603280739625916, 0.6898149254266173, 43.58573600649834, 69.23436731100082, 54.067880138754845, 52.81742423772812, 37.44393177330494, 79.37669187784195, 77.66707241535187, 81.12870946526527, 9.255425557494164, 1.061039746273309, 3.9396547246724367, 0.4329392983345315, 30.273796319961548, 84.85098972916603, 82.21275329589844, 80.87649419903755, 76.74035534262657, 72.01427534222603, 72.48487249016762, 71.75632238388062, 65.0198158621788, 55.603028163313866, 59.27103593945503, 61.952396258711815, 66.54463604092598, 72.37961053848267, 73.57780784368515, 70.01369789242744, 64.20003265142441, 56.755893900990486, 56.99615880846977, 53.781417310237885, 54.18402470648289, 56.9193497300148, 54.9796412140131, 52.47375927865505, 52.356349378824234, 51.5889273583889, 50.17155021429062, 51.65824703872204, 50.29874838888645, 50.489532351493835, 51.523536667227745, 48.8203389197588, 51.980070769786835, 51.17252290248871, 50.262562930583954, 49.381918385624886, 48.973216116428375, 48.73351737856865, 55.30919373035431, 66.42612800002098, 65.24107798933983, 66.29349991679192, 66.13200858235359, 67.43972361087799, 67.97724276781082, 64.40791949629784, 65.19389972090721, 62.08905212581158, 64.76270645856857, 64.08912420272827, 66.66675388813019, 65.71084678173065, 66.90452992916107, 65.28443366289139, 64.98734280467033, 65.37694349884987, 61.39545634388924, 61.12830027937889, 61.09124846756458, 60.13970732688904, 58.121662214398384, 52.85240136086941, 52.57276676595211, 51.73473313450813, 49.662274941802025, 50.69961927831173, 48.218891993165016, 49.0694535523653, 49.94979411363602, 48.21100741624832, 46.958157643675804, 44.96945455670357, 44.13070656359196, 45.75573116540909, 48.02127219736576, 47.64598913490772, 49.783347845077515, 49.6302692592144, 46.81539550423622, 47.62240380048752, 47.240813076496124, 46.92480683326721, 47.584398239851, 48.337863609194756, 48.42500813305378, 44.83388543128967, 49.08080354332924, 47.35034599900246, 47.497082725167274, 47.79078796505928, 49.616859778761864, 48.04430656135082, 50.321030393242836, 57.388271167874336, 66.54813945293427, 65.11949211359024, 66.78020060062408, 68.69640737771988, 64.5293153822422, 66.3482017815113, 62.89267860352993, 63.76204535365105, 59.803607761859894, 65.49542114138603, 67.90572300553322, 67.0732256770134, 67.50145509839058, 4.992188746109605, 1.2518131406977773, 9.42438444122672, 10.69638803601265, 9.089070484042168, 63.07061165571213, 58.74570272862911, 14.312992170453072, 46.781501322984695, 46.65907949209213, 48.508930429816246, 57.28830233216286, 0.6725750723853707, 0.1825966191245243, 0.1426029932918027, 0.37847545521799475, 0.19481039576930925, 0.07826851186109707, 0.27988849848043174, 0.06324592148303054, 0.12945629248861223, 0.09446433381526731, 0.2307794289663434, 0.1424552613752894, 0.22452392557170242, 0.10650317883118987, 0.1402533834334463, 0.20450346783036366, 0.11308602872304618, 0.23894625948742032, 0.14007669291459024, 0.24429134064121172], [0.045547718036687, 0.03292140747362282, 0.00990835796983447, 0.08560894610127434, 0.022779454811825417, 0.03422270776354708, 0.06260484689846635, 0.03954296407755464, 0.04107733955606818, 0.01705201360891806, 0.029100482424837537, 0.03637683221313637, 0.04821373884624336, 0.1141973800258711, 0.043962702111457475, 0.061766928774886765, 0.05976559026748873, 0.0563870483165374, 0.12419864375260659, 0.027498415656737052, 0.049256879356107675, 0.07713614293606952, 0.02690695364435669, 0.06189675637870096, 0.18790273752529174, 1.8722177250310779, 56.025903671979904, 39.29285556077957, 38.83339561522007, 19.741523377597332, 40.18016114830971, 65.9442226588726, 67.69325360655785, 18.980068936944008, 1.3387641124427319, 1.8847070611082017, 0.14827677165158093, 3.372820378281176, 51.507072150707245, 80.89888259768486, 77.17247575521469, 71.59961879253387, 68.4895084798336, 69.31550815701485, 67.15131148695946, 64.49857503175735, 54.256825000047684, 59.644077122211456, 65.6517143547535, 71.239223331213, 71.48064717650414, 69.00786146521568, 71.71692609786987, 64.8237007856369, 59.5022801309824, 52.07790791988373, 49.994358122348785, 48.881736025214195, 49.59349863231182, 51.12686075270176, 48.37208457291126, 48.911021053791046, 48.20722281932831, 46.585754826664925, 45.56077882647514, 49.14649061858654, 48.57398293912411, 48.089182153344154, 47.26052641868591, 46.760252863168716, 45.007475316524506, 46.15475155413151, 45.59583194553852, 46.01363852620125, 45.81124618649483, 53.60213153064251, 62.52098634839058, 61.34378291666508, 62.27547772228718, 59.947646632790565, 62.572021409869194, 63.09984728693962, 63.98858159780502, 62.495599910616875, 62.84928873181343, 63.533514216542244, 61.01531334221363, 62.5370404869318, 61.31614699959755, 63.51835682988167, 63.13547797501087, 60.17478324472904, 58.43068443238735, 56.60811983048916, 55.31119242310524, 55.498400777578354, 51.71956054866314, 50.11959560215473, 48.00236441195011, 47.08584979176521, 48.08713026344776, 48.457899168133736, 45.34438803792, 44.31772492825985, 46.34088456630707, 44.914030730724335, 42.873574420809746, 43.74079808592796, 41.70840494334698, 43.74109826982021, 42.040982097387314, 42.887781858444214, 43.696895241737366, 44.21500124037266, 43.7645848095417, 43.83518122136593, 43.45040626823902, 44.38778176903725, 42.75483459234238, 42.74225726723671, 43.07283192873001, 41.788090467453, 44.13740560412407, 41.88233681023121, 43.80707032978535, 44.99914236366749, 44.78726953268051, 46.05178847908974, 46.22831180691719, 46.59623086452484, 53.96602660417557, 56.3117965310812, 64.3258211016655, 62.577827498316765, 62.95031391084194, 64.11080583930016, 65.19093587994576, 59.94172655045986, 65.33300265669823, 59.12894256412983, 64.36755806207657, 58.99906553328037, 68.7052609026432, 47.27333553135395, 0.28281475708354264, 0.226505623140838, 3.058028882369399, 2.3319260822609067, 15.946393422782421, 75.99899232387543, 27.67335645854473, 15.078400298953056, 43.682900592684746, 27.393129095435143, 48.28955300152302, 8.22594964876771, 0.1589033319032751, 0.041803159983828664, 0.09028399406815879, 0.06494991481304169, 0.011985184955847217, 0.05089445046905894, 0.04015108730527572, 0.01554614216729533, 0.0727167574223131, 0.042346527116023935, 0.013626923228002852, 0.049865061955642886, 0.03555191280611325, 0.02060491759038996, 0.0332580605027033, 0.047701352668809704, 0.04176726972218603, 0.0354235806298675, 0.04860227541939821, 0.01726285776385339, 0.030548616632586345, 0.04358183934527915, 0.02106001367792487, 0.019261897468823008, 0.09579354256857187, 0.04915043311484624, 0.044092136377003044, 0.08813953609205782, 0.06110827642260119, 0.04669189824198838, 0.02103282509779092, 0.0511660839401884, 0.07819575170287862, 0.06919822044437751, 0.04023964036605321, 0.056223727588076144, 0.03297854171250947, 0.016133511235238984, 0.11329485423630103, 0.025581828558642883, 0.07186165486928076, 0.03312455926788971, 0.06538267596624792, 0.11416373105021194, 0.18965111870784312, 3.6514523020014167, 70.92662930488586, 41.39308646321297, 45.5994987487793, 27.494798339903355, 51.15113765001297, 76.53231650590897, 75.28381749987602, 23.187558464705944, 0.838999729603529, 3.8697420386597514, 0.18798183562466875, 2.6503820065408945, 55.69863103330135, 83.59680622816086, 79.3089947104454, 73.98176416754723, 72.37361446022987, 72.35745772719383, 68.52030202746391, 68.11324506998062, 57.90587939321995, 61.02385528385639, 71.23023301362991, 73.34782138466835, 72.90697664022446, 71.63152948021889, 72.6113373041153, 69.95250597596169, 59.01725135743618, 54.964081048965454, 50.41402280330658, 51.06127627193928, 50.66342622041702, 52.80782215297222, 51.10526651144028, 50.29110699892044, 48.954958096146584, 47.06868231296539, 48.0959115922451, 52.752223536372185, 51.20463117957115, 50.62297359108925, 49.0292327105999, 47.18725875020027, 46.98879539966583, 48.202100694179535, 48.88139024376869, 49.423636347055435, 48.2561793923378, 56.293097734451294, 67.01514199376106, 64.32773619890213, 64.50124248862267, 62.035060822963715, 64.72848549485207, 65.15175238251686, 64.70455437898636, 62.845048159360886, 64.58834901452065, 65.90012982487679, 61.80939473211765, 62.328264489769936, 63.11698816716671, 64.29910853505135, 63.89095723628998, 62.82804027199745, 61.33986532688141, 58.079336285591125, 57.863747254014015, 56.69426880776882, 56.66443280875683, 54.112523943185806, 49.56993989646435, 49.66275371611118, 50.630147606134415, 50.150202959775925, 46.73179619014263, 46.239145025610924, 47.36223176121712, 47.288663908839226, 46.318758353590965, 45.4241381585598, 45.141334533691406, 44.86805319786072, 45.706394612789154, 45.331856310367584, 47.41876892745495, 47.0649167150259, 47.11257375776768, 46.478676572442055, 45.00593639910221, 47.155739441514015, 44.233692437410355, 45.58147631585598, 45.65660588443279, 44.19667862355709, 46.23189501464367, 44.49601896107197, 47.20022365450859, 46.28724664449692, 48.93495596945286, 47.64628551900387, 48.94543960690498, 46.99733354151249, 55.78195296227932, 57.44828514754772, 67.63414397835732, 64.29312005639076, 62.73117586970329, 65.86144790053368, 67.44215548038483, 62.677952125668526, 67.72175967693329, 61.892636865377426, 67.68871665000916, 61.3889966905117, 71.62251636385918, 48.32166887819767, 0.2247184721636586, 0.7823755242861807, 7.29288169182837, 1.654874850064516, 21.069282330572605, 77.73575752973557, 38.75008128583431, 18.477884083986282, 46.23041309416294, 30.15332568436861, 56.83774910867214, 10.452596917748451, 0.17564541165484115, 0.09909114960464649, 0.058119302630075254, 0.045767987467115745, 0.04545475290797185, 0.0492093781940639, 0.09227105736499652, 0.03532146853103768, 0.046430918300757185, 0.03692990663694218, 0.0216701184399426, 0.06092014198657125, 0.04652642528526485, 0.007070561050568358, 0.04782671254361048, 0.008640058204036904, 0.022699408618791495, 0.04552802514808718, 0.040266914293169975, 0.03675554275105242, 0.09752360754646361, 0.16108917945530266, 0.08068809140240774, 0.16556164337089285, 0.2763230132404715, 0.21054450538940728, 0.15798277192516252, 0.13646390318172053, 0.09063082936336286, 0.11330028675729409, 0.1772268392960541, 0.174877823155839, 0.1959441599319689, 0.2709617681102827, 0.10155265306821093, 0.16777279815869406, 0.17574171273736283, 0.1322264625923708, 0.176327682856936, 0.11599164819926955, 0.1469662575982511, 0.2023478999035433, 0.19748583814362064, 0.46279664151370525, 0.36632011528126895, 6.939934305846691, 87.91766837239265, 53.17373111844063, 59.34185653924942, 34.398664981126785, 55.785919949412346, 81.43432706594467, 83.47937732934952, 25.74396438896656, 2.7359375031664968, 5.338622806593776, 0.3511340223485604, 3.9581003598868847, 60.95477119088173, 88.01811218261719, 82.3596154153347, 77.77183279395103, 74.62415769696236, 76.90666481852531, 72.5791834294796, 71.77352026104927, 61.46609075367451, 65.14268606901169, 72.55206048488617, 76.07425108551979, 76.09016463160515, 74.27342131733894, 76.44503518939018, 73.47181633114815, 62.719567492604256, 58.74229051172733, 54.195735678076744, 54.073899015784264, 55.159185379743576, 57.05254778265953, 52.70221062004566, 53.35142098367214, 52.757892832159996, 50.42252294719219, 50.08597880601883, 56.13292492926121, 54.170121252536774, 53.92066463828087, 50.60524374246597, 50.66680423915386, 49.05296243727207, 52.80890889465809, 51.90746046602726, 51.81039087474346, 51.24053165316582, 58.166518807411194, 68.55607330799103, 66.09404861927032, 66.51782467961311, 63.501436337828636, 67.07763344049454, 66.96579024195671, 65.19522964954376, 63.671712800860405, 68.12605038285255, 67.37439751625061, 64.44068133831024, 66.9103892147541, 64.17732506990433, 66.9338795542717, 65.82173243165016, 64.51742202043533, 63.51184017956257, 60.05531765520573, 60.33978559076786, 59.32334013283253, 58.226631581783295, 57.24514804780483, 52.37537495791912, 51.856923177838326, 52.37326227128506, 53.079959750175476, 50.17163001000881, 49.619120657444, 50.83659812808037, 50.14290355145931, 47.217763513326645, 46.50498256087303, 47.86760464310646, 48.930065631866455, 47.96885021030903, 49.61266100406647, 48.729037418961525, 51.01678065955639, 49.3812458217144, 49.985481798648834, 47.12634801864624, 50.790119022130966, 45.12639753520489, 46.638784781098366, 47.62610100209713, 46.69629469513893, 47.902809754014015, 46.763672679662704, 50.96102625131607, 50.960878059268, 50.36131963133812, 49.79173019528389, 50.51030583679676, 52.09987074136734, 58.76316659152508, 60.90640738606453, 68.92167448997498, 68.48348960280418, 65.35782292485237, 67.71970018744469, 69.85541358590126, 64.50637981295586, 71.47953763604164, 64.23156335949898, 70.30966401100159, 62.88522720336914, 71.70555710792542, 49.67107146978378, 0.31246201309841126, 0.8055045269429684, 10.539923831820488, 6.989860776811838, 20.87538443505764, 88.67388859391212, 37.0587844401598, 20.461814627051353, 65.21160677075386, 36.89690172672272, 68.53088825941086, 19.602667428553104, 0.36782827810384333, 0.26762260822579265, 0.11648936953861266, 0.17004550667479634, 0.15330025053117424, 0.1844289223663509, 0.13101070595439523, 0.11927676488994621, 0.15219989785691723, 0.14296902052592486, 0.12495344504714012, 0.2356113595305942, 0.1296818014816381, 0.06565744130057283, 0.12145732835051604, 0.17337518191197887, 0.12177203607279807, 0.1725097486632876, 0.11991032894002274, 0.09323826132458635], [0.03990709512436297, 0.020478746919252444, 0.06726997235091403, 0.02435255555610638, 0.012712205807474675, 0.07703316994593479, 0.055408615662599914, 0.03535149582603481, 0.08527098689228296, 0.03540378384059295, 0.01392145752106444, 0.044063585955882445, 0.10447465916513465, 0.018819529213942587, 0.041318229559692554, 0.01110928464186145, 0.047552132746204734, 0.07124442548956722, 0.03084135863900883, 0.10051349046989344, 0.02420133925625123, 0.08397722311201505, 0.019099198289040942, 0.17953055474208668, 0.0793171591067221, 0.32656914205290377, 21.31179291754961, 53.8940242677927, 35.87554693222046, 41.49531617760658, 18.862862326204777, 46.14166505634785, 75.81063643097878, 41.929712668061256, 0.40154054411686957, 0.8233320422004908, 0.7931807788554579, 0.23128296132199466, 11.254034712910652, 69.821238219738, 84.35161292552948, 76.42774611711502, 72.78351366519928, 65.3910331428051, 71.45615369081497, 61.27771586179733, 62.39729918539524, 69.95778769254684, 71.88937604427338, 73.53897392749786, 75.9281413257122, 73.48178699612617, 71.39660328626633, 63.41543935239315, 60.57605691254139, 52.81499616801739, 50.54829239845276, 48.76592583954334, 50.759428068995476, 47.7811174839735, 49.78028520941734, 47.77268573641777, 49.197396486997604, 48.39813217520714, 49.778229519724846, 48.919209614396095, 46.04517303407192, 48.29860031604767, 48.48641663789749, 45.793896317481995, 44.882963597774506, 45.460638999938965, 46.06815420091152, 45.297057777643204, 45.884646847844124, 49.21695023775101, 60.46057730913162, 64.90684032440186, 61.97718232870102, 60.56015856564045, 60.25299824774265, 60.26393786072731, 59.92465406656265, 60.05450829863548, 60.38658767938614, 61.581323370337486, 61.97612598538399, 61.16155609488487, 62.625446543097496, 62.46306225657463, 63.69684085249901, 59.05401058495045, 57.94731616973877, 54.67493176460266, 55.016803219914436, 54.69366855919361, 51.64418779313564, 47.93021768331528, 49.637390077114105, 51.942726373672485, 54.635953456163406, 54.88550886511803, 56.05563327670097, 49.71725419163704, 45.63473805785179, 45.71614868938923, 44.51135493814945, 43.235884979367256, 43.12412157654762, 43.11423450708389, 45.22154442965984, 42.29974441230297, 44.56913083791733, 45.112357288599014, 45.09328231215477, 41.97505943477154, 44.02894802391529, 41.323789581656456, 44.18705374002457, 43.98911856114864, 44.20604132115841, 43.501844108104706, 44.139039516448975, 44.210840463638306, 45.28052106499672, 43.26566398143768, 45.149298906326294, 45.904652774333954, 48.89495171606541, 44.2706910520792, 49.80350196361542, 53.403979763388634, 58.61213989555836, 63.07712450623512, 65.9671126306057, 60.678320825099945, 64.74953636527061, 65.5396355688572, 64.62772250175476, 62.228310853242874, 68.06630998849869, 59.33252044022083, 74.40474227070808, 12.398985475301743, 0.7886931602843106, 1.5547056938521564, 6.518584415316582, 0.9414160496089607, 31.218524426221848, 66.9061030447483, 8.394931331276894, 26.71186175197363, 33.047704473137856, 35.92098489403725, 51.35134510695934, 1.3374575763009489, 0.17644140956690535, 0.06639859449933283, 0.013318533965502866, 0.18516572657972574, 0.029046060735709034, 0.017362656217301264, 0.04981137870345265, 0.05745935894083232, 0.04830548685276881, 0.0379443186102435, 0.04553441503958311, 0.018672771366254892, 0.0248960674070986, 0.022511743591167033, 0.05966295866528526, 0.13331808760995045, 0.03373433377419133, 0.0315476401738124, 0.015223742084344849, 0.0533472299866844, 0.09196607177727856, 0.009574278337822761, 0.05092418832646217, 0.05743685702327639, 0.05900882970308885, 0.04051748190249782, 0.0172259173632483, 0.03124071386992, 0.022993959610175807, 0.009295503550674766, 0.030174806124705356, 0.03818626246356871, 0.06153409107355401, 0.07772724871756509, 0.07351294829277322, 0.06541467737406492, 0.015418921357195359, 0.04214156077068765, 0.01834006470744498, 0.06034550075128209, 0.038703583923052065, 0.011594109309953637, 0.09269148402381688, 0.08535615575965494, 0.07974008680321276, 0.46590668556746095, 28.44721533358097, 64.91573944687843, 39.26051929593086, 46.51803866028786, 26.116344407200813, 58.45950588583946, 81.94567322731018, 47.333322912454605, 0.39493186748586595, 2.059822208248079, 2.5986819807440042, 0.047867957400740124, 11.90412187948823, 72.98818588256836, 86.80306658148766, 79.35721412301064, 76.15668386220932, 69.63135480880737, 74.53765153884888, 62.79073767364025, 66.195297986269, 72.32263639569283, 74.15671437978745, 74.84170362353325, 79.25554677844048, 75.46480178833008, 73.62030476331711, 67.80376687645912, 63.741644248366356, 55.09751848876476, 51.25195764005184, 51.19325838983059, 52.25560538470745, 51.29636585712433, 51.42572231590748, 50.194854363799095, 51.39179773628712, 50.57533174753189, 52.78999350965023, 51.50745593011379, 49.54731971025467, 50.22370241582394, 51.53740592300892, 48.56850363314152, 47.635991871356964, 48.196784779429436, 48.77344183623791, 47.5439228117466, 50.07637672126293, 52.133411541581154, 63.832660764455795, 65.52827417850494, 63.820501416921616, 61.57578706741333, 63.727083429694176, 60.22457957267761, 63.26989956200123, 61.3026387244463, 63.96455928683281, 65.20868852734566, 64.27731290459633, 64.78997379541397, 65.71530774235725, 64.65796127915382, 65.34118741750717, 60.08869506418705, 61.79249323904514, 57.66761317849159, 58.96945372223854, 55.746740251779556, 52.92642138898373, 49.95451346039772, 51.510286778211594, 51.93221613764763, 55.03463186323643, 55.4481902718544, 57.039655074477196, 50.14742150902748, 46.625002920627594, 46.45584739744663, 46.88398942351341, 45.187357664108276, 45.860320553183556, 45.42384937405586, 47.071608155965805, 44.11338709294796, 48.03669556975365, 46.462580636143684, 47.34278820455074, 44.16977606713772, 45.0293393433094, 44.745958149433136, 47.677599638700485, 46.03796102106571, 46.8448743224144, 46.89767248928547, 45.977122485637665, 44.83878716826439, 46.637283861637115, 44.98488172888756, 47.87848345935345, 47.935111820697784, 50.49688495695591, 46.982605531811714, 53.21759596467018, 56.76351249217987, 60.862208157777786, 64.36822682619095, 66.37419238686562, 62.53242753446102, 66.38760566711426, 67.06858992576599, 68.44926863908768, 64.77048084139824, 71.8813356757164, 62.86244362592697, 76.00640192627907, 11.353253088891506, 0.4387471976224333, 3.415341996587813, 6.664519384503365, 0.24021450080908835, 34.329136312007904, 76.35134741663933, 13.766315504908562, 27.38830715417862, 39.09068360924721, 36.926011964678764, 59.818358570337296, 1.8205131869763136, 0.15442650415934622, 0.13662646320881322, 0.13377185154240578, 0.06522767842398025, 0.057917160156648606, 0.059927734691882506, 0.07857395015889779, 0.07969871949171647, 0.1337340465397574, 0.04290436612791382, 0.033868885147967376, 0.03738109902769793, 0.031633970502298325, 0.02835552571923472, 0.03626790348789655, 0.07215967169031501, 0.07128596349502914, 0.0437410671293037, 0.03215431250282563, 0.11055331618990749, 0.162345620628912, 0.11761050234781578, 0.1781543457764201, 0.16111490229377523, 0.13403868331806734, 0.23396681965095922, 0.12114795667002909, 0.18097161257173866, 0.10347691582865082, 0.2019128084066324, 0.13387149228947237, 0.16818768839584664, 0.22187304828548804, 0.17580026818905026, 0.18524154438637197, 0.11108518374385312, 0.11206500421394594, 0.168146840587724, 0.11482023488497362, 0.31615749292541295, 0.12148656154749915, 0.14826924627413973, 0.18508493638364598, 0.26072122855111957, 0.21189312130445614, 0.49897877499461174, 43.09828296303749, 78.16486850380898, 52.86120928823948, 60.42298972606659, 29.886866882443428, 60.739417746663094, 88.8244517147541, 54.05749149620533, 0.4384551179828122, 4.752884237095714, 2.538568018935621, 0.31385196663904935, 14.492230452597141, 79.79372709989548, 87.32017323374748, 82.7346020936966, 80.08493587374687, 72.49230489134789, 80.2149572968483, 69.6796578168869, 69.88181456923485, 76.40838235616684, 76.68762177228928, 79.02434438467026, 80.13646870851517, 79.86067950725555, 74.93672892451286, 70.89905798435211, 66.74839630723, 60.33756271004677, 55.850353091955185, 55.79589821398258, 55.28355270624161, 54.78620499372482, 54.062005653977394, 52.97037363052368, 54.10575270652771, 52.81254529953003, 55.08087918162346, 55.052791088819504, 51.504191905260086, 52.64025494456291, 54.06901627779007, 50.637925788760185, 49.6162936091423, 50.37515468895435, 51.7573457211256, 48.87800082564354, 52.40925393998623, 53.32300990819931, 65.43783143162727, 68.69889244437218, 66.85384064912796, 64.43785429000854, 65.57450249791145, 63.42533782124519, 64.30702731013298, 64.09133568406105, 67.64704808592796, 63.72339382767677, 66.95476323366165, 66.42430409789085, 67.4399895966053, 65.35957083106041, 67.66349360346794, 62.89799451828003, 65.11957570910454, 59.3314602971077, 61.31015472114086, 58.23095954954624, 55.672701224684715, 52.39027015864849, 53.730857223272324, 56.281470358371735, 61.30197376012802, 58.790065348148346, 60.9542316198349, 54.40242938697338, 49.281261786818504, 49.3597199767828, 49.42509926855564, 49.12129417061806, 48.96459437906742, 47.755480259656906, 50.54556034505367, 46.268198266625404, 50.16464598476887, 49.644636288285255, 50.10777063667774, 45.628061816096306, 47.730971574783325, 45.322569608688354, 50.552130192518234, 48.745330944657326, 50.40060572326183, 49.42639879882336, 47.99339309334755, 47.95704424381256, 50.246725380420685, 47.04558715224266, 50.20676672458649, 50.40094390511513, 54.68740649521351, 49.13989797234535, 53.55691775679588, 58.98130528628826, 63.87796193361282, 67.80491441488266, 68.64309623837471, 63.77030611038208, 66.82674050331116, 70.36082446575165, 69.44729268550873, 67.89217293262482, 75.2341465651989, 62.43453338742256, 76.657884567976, 14.788852985948324, 0.786690489621833, 2.6069301506504416, 23.118022195994854, 0.9962892020121217, 37.994951605796814, 81.55486419796944, 12.361638229340315, 41.311938017606735, 51.98005937039852, 46.36994920670986, 72.92350575327873, 2.719918987713754, 0.2719455590704456, 0.2230485063046217, 0.2318119938718155, 0.21994940150761977, 0.18718804931268096, 0.15174715808825567, 0.15031359595013782, 0.1581534362048842, 0.18154671764932573, 0.05706248804926872, 0.12990040850127116, 0.09690801831311546, 0.1610221338341944, 0.10605874369502999, 0.19113957008812577, 0.2190035639796406, 0.2197212801547721, 0.08912834397051483, 0.1239465361868497, 0.24799960025120527], [0.024446387142234016, 0.05934394277574029, 0.08684231390361674, 0.04898882303677965, 0.023266496646101587, 0.03971748752519488, 0.0365794867684599, 0.014711457952216733, 0.05496875586686656, 0.038114956914796494, 0.008645846955914749, 0.0327281559293624, 0.028865512904303614, 0.05993695587676484, 0.036333624375401996, 0.0387134915945353, 0.050899025809485465, 0.14501025318168104, 0.04780427370860707, 0.056115214465535246, 0.05718134299968369, 0.035274112087790854, 0.03133002021058928, 0.025631231474108063, 0.13680687930900604, 0.1250697989598848, 0.3141110058641061, 52.51336455345154, 39.96304079890251, 44.7524444013834, 24.145673252642155, 25.068130753934383, 66.1730007827282, 70.85760220885277, 5.024088034406304, 1.4302750770002604, 1.1844845535233617, 0.5078868032433093, 0.5479020997881889, 20.800756439566612, 78.10238465666771, 83.67783308029175, 75.94706431031227, 72.45059072971344, 68.28906163573265, 67.15926066040993, 70.18462032079697, 74.1997280716896, 72.00914561748505, 75.80925330519676, 67.08349272608757, 74.0102930366993, 68.68158057332039, 63.90228822827339, 55.00834107398987, 50.665683299303055, 47.36579976975918, 50.30053049325943, 48.26507851481438, 50.74748530983925, 49.560068026185036, 53.47111836075783, 50.333052948117256, 51.453563421964645, 48.2897923886776, 49.882210940122604, 47.7624224871397, 48.391079753637314, 46.43560588359833, 45.34617394208908, 45.74384160339832, 45.6115934997797, 45.410413295030594, 47.4538866430521, 48.75026687979698, 46.8815765529871, 54.95671324431896, 62.459585443139076, 60.573541447520256, 61.03362075984478, 59.63626854121685, 62.18236371874809, 58.55673126876354, 58.905005380511284, 57.80030585825443, 57.795719504356384, 58.93861457705498, 55.143560618162155, 58.6262371391058, 62.6253667473793, 60.98488077521324, 59.77532587945461, 57.28172108530998, 56.297231912612915, 52.34863579273224, 53.72950069606304, 51.01252108812332, 53.87819431722164, 54.793812185525894, 57.194701954722404, 59.0773831307888, 60.234538838267326, 59.75194193422794, 57.98925831913948, 49.639198780059814, 46.31054699420929, 44.30252194404602, 44.57585647702217, 43.475165739655495, 42.78848558664322, 41.74351125955582, 43.842723816633224, 43.72070096433163, 44.30393926799297, 44.03697319328785, 50.24640239775181, 46.169000789523125, 42.462907657027245, 44.019243344664574, 42.77867451310158, 44.687749072909355, 45.607387125492096, 43.06704103946686, 46.07584498822689, 43.677888661623, 46.58055290579796, 44.50657099485397, 48.12520042061806, 48.30112338066101, 49.085302501916885, 47.83512018620968, 51.35631524026394, 59.975567534565926, 61.672374084591866, 66.08809053897858, 63.552836179733276, 61.4934416860342, 65.105220079422, 65.57785391807556, 69.61583644151688, 65.31657993793488, 70.11517524719238, 35.10773353278637, 0.0845940962608438, 0.03235941243474372, 0.5745098751503974, 5.558899361640215, 0.14635456464020535, 62.109897807240486, 31.471378058195114, 12.592899519950151, 49.01674658060074, 19.453299343585968, 51.445743441581726, 25.915122404694557, 0.21362153871450573, 0.15014981880085543, 0.0896874706086237, 0.06443927268264815, 0.05855502124177292, 0.020160482454230078, 0.02455715453834273, 0.023323873938352335, 0.09941225463990122, 0.04300276006688364, 0.030995550951047335, 0.030167241784511134, 0.01650404887186596, 0.027278968154860195, 0.022608291437791195, 0.04778355665621348, 0.044751259993063286, 0.07299797944142483, 0.02560113924118923, 0.07480096042854711, 0.02148992869479116, 0.027377497535781004, 0.08484930600388907, 0.009036571937031113, 0.04071006922458764, 0.05428596145065967, 0.05774741614004597, 0.060810367212980054, 0.03899982701113913, 0.03844060760457069, 0.051103031073580496, 0.0561199159710668, 0.029696128294744994, 0.05241696642769966, 0.08227393482229672, 0.05945916491327807, 0.029675624609808438, 0.02943889434391167, 0.031981032152543776, 0.0479301530867815, 0.009010826834128238, 0.02566151295468444, 0.030910319001122843, 0.02550953966419911, 0.002314897060387011, 0.13173337967600673, 0.06818904061219655, 1.4776935637928545, 62.81808480620384, 44.06072571873665, 54.19429935514927, 32.53701187670231, 35.31815484166145, 77.30876684188843, 76.3061298429966, 6.889497237280011, 2.873526932671666, 3.784587658010423, 1.3319508405402303, 0.5423115903977305, 21.15106914192438, 81.45504355430603, 84.43108186125755, 80.51787704229355, 75.06011590361595, 72.61246964335442, 71.66651800274849, 73.60804662108421, 74.67578932642937, 77.26823061704636, 77.17922419309616, 69.3752333521843, 74.58677530288696, 71.10472574830055, 67.19735741615295, 55.787059888243675, 54.12309877574444, 51.112698912620544, 51.31007932126522, 49.597275629639626, 54.18171443045139, 50.41914112865925, 54.9544333666563, 52.80309900641441, 53.35413783788681, 50.93320034444332, 52.9444894194603, 49.73735511302948, 50.715814009308815, 48.53113263845444, 47.43427589535713, 47.39929877221584, 47.02492766082287, 47.58402206003666, 49.470860213041306, 50.44412478804588, 49.2545910179615, 56.5412662178278, 65.01677602529526, 64.12394553422928, 64.7892290353775, 60.87111108005047, 63.03248070180416, 59.98374469578266, 62.17208907008171, 60.07839381694794, 60.80837644636631, 61.0908342897892, 58.1353110820055, 58.150989040732384, 64.1228511929512, 63.806419372558594, 61.341130658984184, 60.63794419169426, 57.96813145279884, 55.06147742271423, 57.388852536678314, 53.2273006439209, 55.86336359381676, 57.8390371799469, 59.5218338817358, 61.57643683254719, 61.222596019506454, 61.211918592453, 59.14240524172783, 50.12838073074818, 47.746166959404945, 46.80081568658352, 47.64294929802418, 44.94022652506828, 45.04182547330856, 44.95428957045078, 47.25027456879616, 47.20562696456909, 46.52725696563721, 45.69264695048332, 51.60587064921856, 47.591359466314316, 45.076821595430374, 46.01237699389458, 46.85366325080395, 45.65422721207142, 47.87824027240276, 45.72415105998516, 47.317990735173225, 45.77808156609535, 49.179389253258705, 45.88679753243923, 49.454334899783134, 49.52446013689041, 51.707629188895226, 50.2585693448782, 53.27680438756943, 61.832592487335205, 63.111478462815285, 68.14976871013641, 64.66444373130798, 63.325171396136284, 65.6190513074398, 68.74361604452133, 73.63815620541573, 66.19840621948242, 70.48089042305946, 36.32602795958519, 0.22946940473048016, 0.11771181292715482, 3.9335783757269382, 2.2991065308451653, 0.35846065264195204, 62.135725021362305, 45.001942813396454, 13.468465637415648, 52.06978775560856, 26.92351419478655, 56.93160027265549, 29.09720655530691, 0.16334504121914506, 0.07682265233597718, 0.11042787838960066, 0.10685817032936029, 0.05746997536334675, 0.040591047290945426, 0.019966652034781873, 0.018840943885152228, 0.020284667880332563, 0.06285685798502527, 0.09014197668875568, 0.033912812868948095, 0.020886839083686937, 0.07929789295303635, 0.06936627236427739, 0.04379019730549771, 0.052120148175163195, 0.01632228206290165, 0.0289813769995817, 0.022439278436650056, 0.02691394096473232, 0.13666747428942472, 0.1284944690996781, 0.18222508515464142, 0.1421820471296087, 0.11755196173908189, 0.1356087560998276, 0.20250446337740868, 0.06819380520028062, 0.10743721621111035, 0.18878234579460695, 0.2061692182905972, 0.12810099724447355, 0.1525577317806892, 0.12822466873330995, 0.12302768314839341, 0.11356341521604918, 0.17754807049641386, 0.16746997222071514, 0.15472950821276754, 0.10547731551923789, 0.08045568785746582, 0.1227515448408667, 0.12206411571241915, 0.15583665895974264, 0.1982635198510252, 0.3177422157023102, 3.1140528386458755, 80.32944515347481, 55.983372554183006, 67.15489849448204, 39.57685612142086, 37.89106138050556, 81.80310487747192, 88.20150554180145, 7.943458557128906, 6.79931097663939, 4.2445071414113045, 0.8441790891811252, 0.9414267959073186, 24.356691129505634, 85.44956400990486, 86.07996538281441, 83.07681173086166, 78.21513220667839, 77.98202231526375, 74.4153057038784, 76.97241649031639, 77.0149514079094, 81.16455674171448, 81.46560698747635, 70.63395380973816, 78.65834802389145, 74.02556821703911, 69.92015451192856, 59.57793787121773, 55.59109680354595, 52.94025644659996, 56.394198909401894, 54.69763554632664, 57.170280665159225, 52.56981052458286, 58.822162225842476, 53.878771886229515, 55.948076248168945, 54.349961802363396, 56.331608667969704, 52.711413726210594, 54.6913430839777, 50.863230898976326, 49.42604161798954, 49.22817103564739, 50.35071440041065, 49.905750676989555, 52.42401234805584, 52.72624433040619, 51.198023334145546, 58.933655843138695, 68.89310762286186, 65.59002086520195, 67.40426391363144, 62.581232115626335, 66.34412840008736, 62.264952287077904, 62.81297028064728, 62.17331260442734, 62.357488721609116, 63.2990287989378, 59.28208574652672, 60.87727054953575, 66.36470049619675, 65.56652292609215, 64.6679775416851, 62.09086462855339, 62.40734204649925, 57.58588336408138, 59.4209036976099, 55.29014155268669, 60.48795484006405, 60.41896194219589, 62.70333096385002, 63.78580167889595, 65.42035236954689, 63.89822244644165, 62.09759406745434, 52.91870020329952, 50.57933673262596, 49.21071097254753, 49.566953256726265, 48.17577950656414, 47.376241609454155, 47.675893530249596, 50.222980454564095, 48.44675436615944, 49.06449481844902, 48.13053913414478, 56.45377591252327, 50.659964606165886, 47.63398177921772, 48.09188760817051, 48.198661878705025, 48.62021125853062, 50.732776299118996, 48.611137345433235, 51.351063922047615, 47.397885248064995, 52.63395108282566, 48.895669877529144, 51.134376749396324, 52.42145508527756, 53.83784428238869, 53.31750400364399, 55.735120475292206, 65.49020022153854, 66.83914303779602, 70.15675261616707, 66.42956301569939, 61.272331550717354, 67.26633131504059, 68.81788685917854, 74.71298173069954, 68.71818780899048, 71.01346984505653, 37.44774676859379, 0.23113347793696448, 0.32898367499001324, 3.623867444694042, 16.023871265351772, 0.2647706534480676, 73.00973072648048, 43.46581444144249, 19.086442328989506, 72.2905433177948, 32.296697571873665, 66.8248102068901, 40.16680486500263, 0.34774187311995775, 0.20810934074688703, 0.1554062429931946, 0.12167209104518406, 0.14809380256338045, 0.12338118292973377, 0.10039614950073883, 0.13471751095494255, 0.16061810863902792, 0.17536841245600954, 0.17258740699617192, 0.1655510306591168, 0.08980775048257783, 0.15124769270187244, 0.1985372684430331, 0.11482082118163817, 0.20112390542635694, 0.12200570869026706, 0.18266274448251352, 0.12073682912159711, 0.08904773188987747], [0.05503466229129117, 0.04595362457621377, 0.017135577581939287, 0.07923300698166713, 0.06625567169976421, 0.046157748583937064, 0.02161907723348122, 0.006764244235455408, 0.07694120300584473, 0.06100975631852634, 0.036488291661953554, 0.05119755100167822, 0.016608713958703447, 0.020263730039005168, 0.046572679639211856, 0.15100061689736322, 0.018349293313804083, 0.07273070237715729, 0.025180831325997133, 0.06591372715774924, 0.04611573931470048, 0.027356613500160165, 0.016561591291974764, 0.03677510205307044, 0.07392180486931466, 0.03682319693325553, 0.24187547183828428, 24.42244280129671, 60.3591987490654, 33.68666298687458, 38.8521134108305, 22.29489516466856, 42.9152125865221, 75.15751987695694, 17.025444321334362, 0.9248015005141497, 2.470756620168686, 0.5655798793304712, 0.4264470498310402, 1.974715800024569, 41.275634765625, 86.76316112279892, 80.51043704152107, 73.73403266072273, 76.15521714091301, 73.32089602947235, 71.81421607732773, 80.00347584486008, 68.16718697547913, 68.48687142133713, 73.43767896294594, 73.55202242732048, 66.1624525487423, 57.742115780711174, 52.26116828620434, 52.687258422374725, 50.00402860343456, 51.213990077376366, 51.671629920601845, 52.20477931201458, 57.42050103843212, 62.075277864933014, 62.18183554708958, 60.06981007754803, 51.28415711224079, 50.39685532450676, 48.0273062735796, 49.60447624325752, 45.719310119748116, 47.583341896533966, 45.65209552645683, 46.90403334796429, 46.72373302280903, 48.229994997382164, 47.108146995306015, 47.949003875255585, 50.54583393037319, 61.30198895931244, 63.277537152171135, 63.10549758374691, 63.706689924001694, 63.11202563345432, 64.06870409846306, 62.833257392048836, 61.58278249204159, 60.082953572273254, 58.23389299213886, 56.59637086093426, 61.10545210540295, 64.15685936808586, 62.23259702324867, 59.56552393734455, 55.755099803209305, 56.6192190349102, 53.64375449717045, 52.226692736148834, 54.04790461063385, 54.23298507928848, 55.28039127588272, 56.70191019773483, 60.488585606217384, 63.55082988739014, 62.775956466794014, 60.11371672153473, 57.31993183493614, 47.867547646164894, 44.40844506025314, 43.170532286167145, 43.242812007665634, 43.10863360762596, 42.60250076651573, 44.425441548228264, 45.356357395648956, 50.36767289042473, 56.07404708862305, 60.684666484594345, 59.13636356592178, 53.22822779417038, 44.19554628431797, 44.999989718198776, 45.261746272444725, 47.24201761186123, 44.67316925525665, 44.561094269156456, 45.34452863037586, 45.96481494605541, 46.570183262228966, 56.82672590017319, 58.75307433307171, 56.29411607980728, 54.733923599123955, 56.90901808440685, 59.956940934062004, 66.51861503720284, 65.99795937538147, 68.27026784420013, 62.31162138283253, 66.85022324323654, 61.484379172325134, 67.98525273799896, 66.8137376010418, 67.51974731683731, 6.003390960395336, 0.49864546163007617, 0.450615860754624, 3.9501326624304056, 1.991149086970836, 3.984237494878471, 64.09372195601463, 12.737481761723757, 33.6697006970644, 28.72988786548376, 26.385400369763374, 55.64422935247421, 6.185770723968744, 0.08727047374122776, 0.09242085987352766, 0.06734038732247427, 0.04773641543579288, 0.030537246930180117, 0.06787999547668733, 0.054257667070487514, 0.008474914575344883, 0.05432695026684087, 0.06724827195284888, 0.04806068573088851, 0.01470547438657377, 0.04007212279248051, 0.02046416928351391, 0.021974693991069216, 0.07028347783489153, 0.10757671028841287, 0.04474974601180293, 0.06806730612879619, 0.08400370294111781, 0.08569698708015494, 0.051171768791391514, 0.0569678345345892, 0.017727714948705398, 0.06462446821387857, 0.03395676285435911, 0.012679736846621381, 0.06886415751068853, 0.024541680759284645, 0.017603145461180247, 0.02664134826773079, 0.04883676068857312, 0.06743143399944529, 0.020352242281660438, 0.026074358574987855, 0.02663915707671549, 0.01695792598184198, 0.026437567503307946, 0.057192820313503034, 0.019768865968217142, 0.060386545228539035, 0.02770634317130316, 0.01977877735043876, 0.04913993543596007, 0.07869481632951647, 0.05229481634160038, 0.0647076110180933, 0.3368062380468473, 29.62631106376648, 66.0227720439434, 38.38728815317154, 47.58812963962555, 30.87617799639702, 56.785365119576454, 83.29780027270317, 21.46914627403021, 0.3030976530862972, 4.312771903350949, 2.683614785782993, 1.2563339481130242, 2.363324509933591, 43.977312594652176, 91.72684997320175, 81.80628910660744, 78.01108315587044, 81.21993497014046, 77.39059925079346, 76.57285273075104, 83.21605905890465, 69.40865635871887, 70.39373070001602, 74.65327933430672, 76.88363805413246, 67.54708305001259, 61.0497584939003, 55.06565719842911, 54.72707636654377, 50.61884321272373, 54.871050640940666, 54.392812103033066, 54.13766719400883, 57.12023355066776, 65.39284184575081, 63.73277932405472, 60.97375497221947, 52.50624753534794, 53.20425868034363, 51.33966453373432, 52.70770512521267, 48.95559646189213, 50.55892042815685, 47.89549134671688, 50.1825962215662, 49.115898460149765, 49.41741608083248, 49.41652312874794, 50.65681837499142, 52.337107211351395, 64.21616658568382, 64.197106808424, 65.8124989271164, 67.16050699353218, 65.34746468067169, 65.66236898303032, 63.61882343888283, 64.37835708260536, 63.50753501057625, 61.33313208818436, 60.05219802260399, 63.40706840157509, 67.35879555344582, 63.69085997343063, 61.84474803507328, 58.251045271754265, 57.36010327935219, 55.85550181567669, 54.689777567982674, 55.75070723891258, 55.882947742938995, 55.83451174199581, 59.844812750816345, 61.17294788360596, 64.55688670277596, 65.65579533576965, 61.86102256178856, 60.297094881534576, 50.19034780561924, 47.322596088051796, 44.700311198830605, 45.71177512407303, 45.99489413201809, 45.9196999669075, 46.42950341105461, 46.06748543679714, 51.20265908539295, 58.44214081764221, 62.96097233891487, 60.84971442818642, 53.70886020362377, 47.27522782981396, 46.62828594446182, 46.147056967020035, 48.771484941244125, 45.766002014279366, 45.91816104948521, 47.785380855202675, 47.47258923947811, 48.99590849876404, 58.852328807115555, 59.68967467546463, 59.4189316034317, 56.09026841819286, 58.93801040947437, 62.45306879281998, 67.98046499490738, 65.54296419024467, 70.39108604192734, 61.790281757712364, 67.85269305109978, 63.681497275829315, 69.06700149178505, 66.22587114572525, 69.30325761437416, 5.924207009375095, 0.44570011203177273, 1.375083988532424, 5.068140020594001, 0.5406688910443336, 4.176163533702493, 73.19889217615128, 17.724219225347042, 30.370172448456287, 30.10852988809347, 26.502582281827927, 66.89145863056183, 7.591030793264508, 0.07931040556286462, 0.1638741628266871, 0.10153079681913368, 0.087313399562845, 0.016808160580694675, 0.06553792583872564, 0.04241851172992028, 0.04114583978662267, 0.03215155542420689, 0.0863630571984686, 0.02230183639767347, 0.04241203278070316, 0.08455463626887649, 0.12227403218275867, 0.0272251420392422, 0.014575166242138948, 0.023735658287478145, 0.0449076416407479, 0.03169188399624545, 0.049811204298748635, 0.0228873519517947, 0.17795629624743015, 0.186728363041766, 0.15035113377962261, 0.11419105692766607, 0.13220304041169584, 0.2202470472548157, 0.1119784326874651, 0.0966266478644684, 0.1333883689949289, 0.16713352699298412, 0.11687167207128368, 0.16058760636951774, 0.11086360071203671, 0.16978281608317047, 0.19072920695180073, 0.17866716982098296, 0.1123118722171057, 0.20448647264856845, 0.13501368724973872, 0.14906006399542093, 0.10820778072229587, 0.07053712906781584, 0.19392226764466614, 0.18946852069348097, 0.1391513683483936, 0.1674479601206258, 0.2932229626458138, 42.22272254526615, 82.10288599133492, 50.053182765841484, 59.64653559029102, 33.203541710972786, 58.80738101899624, 90.55168703198433, 23.63515544682741, 4.161299206316471, 7.3045893386006355, 1.7721722996793687, 0.8571289724204689, 2.944561270996928, 47.737959399819374, 91.59797608852386, 86.0735285282135, 80.96028730273247, 84.36510980129242, 81.06365695595741, 81.0471810400486, 85.11499956250191, 72.18016684055328, 71.3112598657608, 78.64673584699631, 79.6146959066391, 71.35249525308609, 61.680289059877396, 59.35775488615036, 58.312400579452515, 53.63053500652313, 59.31306928396225, 57.919133082032204, 57.00071856379509, 60.68080969154835, 68.89651224017143, 65.82993999123573, 66.53350263834, 57.472451850771904, 56.55140407383442, 54.0060118585825, 55.154758617281914, 51.811002641916275, 54.781120866537094, 51.55191354453564, 51.453734412789345, 53.61187420785427, 51.652763932943344, 51.22704237699509, 53.07557858526707, 53.62271122634411, 66.73625975847244, 69.10493865609169, 69.05225828289986, 68.06394651532173, 68.54655101895332, 67.94577285647392, 67.25838974118233, 65.16643479466438, 64.18617099523544, 62.66051106154919, 62.31595695018768, 64.41537469625473, 69.27111133933067, 65.26579946279526, 62.63974517583847, 59.13764409720898, 59.07764911651611, 59.97028201818466, 56.55385114252567, 60.02938784658909, 57.993867471814156, 59.26141485571861, 62.82054327428341, 63.578655794262886, 68.94645676016808, 66.77482768893242, 63.902668207883835, 62.54214361310005, 53.916785046458244, 49.400225803256035, 48.557792007923126, 48.5675422847271, 47.41293624043465, 48.83258946239948, 49.0823994576931, 49.60267893970013, 55.83516910672188, 61.442930996418, 66.5145492553711, 64.97206762433052, 57.15044192969799, 50.11438608169556, 50.112926959991455, 50.32075300812721, 51.61089397966862, 49.3038971722126, 47.84974180161953, 50.75246304273605, 49.943334460258484, 49.75172594189644, 63.657889142632484, 62.73472107946873, 62.262167036533356, 58.320957720279694, 64.3584081530571, 64.24104005098343, 70.91845974326134, 69.71802055835724, 72.28229776024818, 61.46935477852821, 67.53762155771255, 61.17335066199303, 68.71995851397514, 64.85643222928047, 71.37017950415611, 8.163032624870539, 0.6854042527265847, 0.8121093444060534, 13.981786742806435, 7.342046303674579, 3.7833159137517214, 79.90422517061234, 18.149722293019295, 49.709962382912636, 48.01601707935333, 36.662583500146866, 77.1187162399292, 12.19644969329238, 0.33919295528903604, 0.41377624380402267, 0.12973167380550876, 0.3418838343350217, 0.15874452714342624, 0.2206885360646993, 0.12444579377188347, 0.1782416520291008, 0.09658260882133618, 0.16534297697944567, 0.20219829777488485, 0.13962950441055, 0.18799163197400048, 0.2572784648509696, 0.08288005425129086, 0.09317226213170215, 0.23229311336763203, 0.19735039619263262, 0.13160665053874254, 0.15757297282107174, 0.1294939490617253], [0.034349845082033426, 0.03682800233946182, 0.07055260284687392, 0.017873799297376536, 0.05950551574642304, 0.06363140040775761, 0.11965554222115315, 0.019918160105589777, 0.018796979056787677, 0.046572642531828023, 0.025833745021373034, 0.015679622993047815, 0.027839076283271424, 0.032988497623591684, 0.040043802437139675, 0.07967801357153803, 0.044771661632694304, 0.057475986759527586, 0.05445029149996117, 0.12662458349950612, 0.0255285312232445, 0.06061798398150131, 0.0674680367228575, 0.03408410797419492, 0.017392251211276744, 0.07939984177937731, 0.2673870208673179, 1.5907516283914447, 53.581323847174644, 43.90733174979687, 41.644252985715866, 29.667812436819077, 21.028592213988304, 71.42048120498657, 40.267275273799896, 0.8425857278052717, 4.676767671480775, 2.5724401138722897, 0.7932304730638862, 0.17426936596166342, 6.255035782232881, 61.34639337658882, 89.25540938973427, 84.83362466096878, 75.46021163463593, 77.91741818189621, 78.47357153892517, 76.68540269136429, 75.92475950717926, 74.56706956028938, 70.14415249228477, 70.00763341784477, 62.57390230894089, 54.838900566101074, 49.540996849536896, 49.66406084597111, 50.906122997403145, 51.53346933424473, 53.51461082696915, 61.47478088736534, 71.1532187461853, 69.16470944881439, 68.41526806354523, 66.39705955982208, 61.53066448867321, 53.2711236923933, 50.11602379381657, 49.18365642428398, 49.04473587870598, 48.55107396841049, 47.926965057849884, 47.1892536431551, 47.65066668391228, 46.84181548655033, 48.09824846684933, 48.230450972914696, 49.03902478516102, 53.67602996528149, 61.736875623464584, 63.21690000593662, 64.65789288282394, 60.84743075072765, 62.450872510671616, 62.660628855228424, 64.13096755743027, 60.37247143685818, 59.33516509830952, 56.42408050596714, 60.014910623431206, 64.08771827816963, 63.04222337901592, 61.25357575714588, 59.12772662937641, 55.50535440444946, 54.702031910419464, 57.54296846687794, 56.57569997012615, 56.833113357424736, 60.213381573557854, 61.66741535067558, 59.421017691493034, 55.389145240187645, 55.52517794072628, 62.50035725533962, 58.29887330532074, 52.55589947104454, 44.07070018351078, 43.161116391420364, 43.6524224281311, 44.246341958642006, 44.29935671389103, 42.25249394774437, 47.52718850970268, 54.370910078287125, 59.73798528313637, 60.898925587534904, 60.52786409854889, 60.2855359017849, 50.792794078588486, 44.79702740907669, 46.20925962924957, 44.240843653678894, 46.47766202688217, 45.45644782483578, 46.733205914497375, 45.93806818127632, 54.922902658581734, 60.94363398849964, 59.84562210738659, 62.15421862900257, 60.934864059090614, 55.88464245200157, 61.98486931622028, 62.55051076412201, 64.6654848754406, 67.93234437704086, 69.72862958908081, 61.09746873378754, 69.311183989048, 62.30067037045956, 69.38657194375992, 21.31420958787203, 0.390329483198002, 0.23644137749215588, 0.7295446435455233, 3.875711993314326, 1.821991663891822, 17.158697471022606, 48.32515709102154, 14.062602706253529, 47.07097738981247, 45.15629053115845, 43.401719480752945, 47.6740126311779, 2.5477929739281535, 0.16520527889952064, 0.18322612362680957, 0.023607884577359073, 0.12968980183359236, 0.06759877345757559, 0.02819930548866978, 0.042814989283215255, 0.06022313544235658, 0.04328330673160963, 0.059360867453506216, 0.042407943547004834, 0.026998050416295882, 0.0129492329324421, 0.07492791963159107, 0.021229342091828585, 0.06563024900970049, 0.0587409774743719, 0.004781660263688536, 0.007853966108086752, 0.031639629378332756, 0.05285741252009757, 0.010696384288166882, 0.01577164002810605, 0.047639383337809704, 0.04712307119916659, 0.05736179249652196, 0.02830271263519535, 0.09461668189032935, 0.019404879640205763, 0.017202756789629348, 0.031079356122063473, 0.026602693505992647, 0.05157535611942876, 0.03101031597907422, 0.05057018017396331, 0.05697708169464022, 0.02088874640321592, 0.04052059150126297, 0.02312439763045404, 0.021810373218613677, 0.06557092172442935, 0.007988933084561722, 0.03078808542340994, 0.05023338984756265, 0.0837620448146481, 0.03429382777540013, 0.032174959051189944, 0.182850225828588, 2.623423165641725, 66.71550527215004, 45.32866068184376, 46.85930214822292, 37.300652861595154, 34.47740435600281, 81.3912981748581, 43.34220327436924, 1.1922562052495778, 4.910511178895831, 5.265446333214641, 3.2623377442359924, 0.20235558855347335, 6.625218093395233, 63.38097520172596, 91.03951245546341, 85.53246796131134, 77.9788076877594, 81.98377758264542, 81.29260987043381, 76.07450947165489, 74.44069594144821, 76.37520253658295, 73.26420307159424, 71.95372179150581, 65.14738261699677, 57.43208661675453, 53.231970593333244, 51.17428980767727, 54.96654711663723, 54.24415647983551, 54.39847379922867, 62.79284656047821, 71.60629883408546, 72.54775151610374, 70.61108663678169, 68.42507913708687, 63.27621102333069, 55.19909083843231, 52.489513233304024, 50.29144898056984, 52.54683315753937, 49.76707711815834, 49.46119353175163, 49.28087040781975, 51.52115799486637, 48.6129080504179, 49.61021013557911, 51.01109616458416, 50.844391509890556, 58.64901311695576, 65.44081047177315, 68.22160005569458, 65.03718852996826, 63.66257809102535, 64.76420357823372, 64.70351323485374, 65.75081303715706, 62.54551023244858, 62.949622347950935, 59.60109002888203, 61.40804506838322, 66.07470765709877, 64.12856608629227, 63.065079152584076, 62.28479102253914, 58.39579850435257, 57.433633133769035, 58.100843131542206, 59.95430387556553, 58.813852071762085, 62.56889037787914, 64.62533622980118, 63.15693162381649, 59.12070460617542, 61.0616784542799, 65.23056775331497, 60.797053053975105, 54.27352510392666, 45.67118190228939, 45.491527542471886, 45.41125304996967, 47.165428921580315, 46.77484408020973, 46.19202375411987, 50.024387910962105, 57.27469526231289, 64.0422423183918, 63.54500859975815, 64.37137305736542, 62.3284886777401, 51.882313415408134, 47.673184275627136, 48.88922922313213, 46.725119948387146, 49.72417742013931, 46.927200704813, 48.302996680140495, 49.16884481906891, 58.307487443089485, 62.64121949672699, 61.719905734062195, 64.15848568081856, 62.948148027062416, 59.13593798875809, 65.06387069821358, 64.99347567558289, 66.23505905270576, 68.5543330013752, 71.04470416903496, 62.681903913617134, 69.41744908690453, 61.53826788067818, 70.69863393902779, 20.335574001073837, 0.519753210246563, 0.655122846364975, 1.3075496186502278, 6.288229376077652, 0.8059496968053281, 18.507366701960564, 59.02974508702755, 14.435147065669298, 55.63406489789486, 53.02575185894966, 43.416306897997856, 56.25235632061958, 2.433056468144059, 0.20270373002858832, 0.14098358253249899, 0.06371938201482408, 0.14973271696362644, 0.08079691251623444, 0.025438994816795457, 0.04181514566880651, 0.035607852187240496, 0.05422706832177937, 0.05298937008774374, 0.08144899315084331, 0.061577120795845985, 0.0028974521410418674, 0.031385128386318684, 0.0689071204396896, 0.08860760121024214, 0.014262509630498243, 0.05527154840820003, 0.04474809844396077, 0.08762933182879351, 0.03551514309947379, 0.18196450226241723, 0.08362179374671541, 0.12381801847368479, 0.12640768341952935, 0.1308747148141265, 0.18100916524417698, 0.2606609958456829, 0.17651071131695062, 0.10874376719584689, 0.10083684421260841, 0.14236654504202306, 0.07806315959896892, 0.14895626722136512, 0.14232945250114426, 0.22905801743036136, 0.11482431669719517, 0.12475316907512024, 0.1296881542657502, 0.14616258587921038, 0.32833144592586905, 0.10142570128664374, 0.15108915511518717, 0.11857108635012992, 0.15431714127771556, 0.1063855410029646, 0.1723207681789063, 0.5181244038976729, 4.950615651905537, 84.742741137743, 61.96835160255432, 62.2991618514061, 44.80923235416412, 32.9071956127882, 89.08365100622177, 55.495049357414246, 1.5195784787647426, 12.221414353698492, 9.86557686701417, 3.027934734709561, 0.18387281626928598, 7.916063452139497, 69.73883584141731, 93.95623594522476, 91.15182682871819, 81.88423812389374, 86.25786423683167, 83.35791304707527, 77.88693621754646, 77.39863961935043, 81.07729062438011, 75.26274383068085, 76.47691547870636, 68.05869519710541, 61.53886824846268, 54.50853109359741, 55.19998759031296, 58.24213095009327, 57.1908375620842, 57.8945180028677, 66.92626476287842, 75.30219331383705, 74.225103110075, 74.14396226406097, 71.47428631782532, 66.79844722151756, 59.12196233868599, 56.25609531998634, 55.180829018354416, 55.802528858184814, 54.26187492907047, 51.24571457505226, 52.11337901651859, 54.356246665120125, 51.37898862361908, 51.97845585644245, 53.907137364149094, 54.33148339390755, 57.84869246184826, 66.53841957449913, 69.67162504792213, 69.0953403711319, 64.59141165018082, 67.25465834140778, 66.37470155954361, 68.23028638958931, 64.09579664468765, 64.79451835155487, 60.88564909994602, 63.75506892800331, 69.50725346803665, 68.28805088996887, 66.74835830926895, 66.37424558401108, 60.188720896840096, 61.397075057029724, 62.549879997968674, 65.19203782081604, 60.808311849832535, 64.15558263659477, 67.04462841153145, 65.05844458937645, 62.14047856628895, 62.3855996131897, 68.49664449691772, 61.79820813238621, 57.703699842095375, 48.893397599458694, 47.70219571888447, 47.88242384791374, 49.45818029344082, 49.61705356836319, 48.920520544052124, 54.463454112410545, 61.77847199141979, 66.38410225510597, 68.10572907328606, 66.26008450984955, 64.85948726534843, 54.24839325249195, 50.2920987457037, 51.44656799733639, 49.66831661760807, 53.154716938734055, 48.52032221853733, 51.26277945935726, 52.281926572322845, 61.72842487692833, 64.6272437274456, 63.999183028936386, 68.19466710090637, 65.86656242609024, 60.676356330513954, 67.19798058271408, 66.08260363340378, 69.67350214719772, 68.1611604988575, 72.65435099601746, 62.699071392416954, 68.66645738482475, 62.16833107173443, 70.39477184414864, 25.861663073301315, 0.3825152025092393, 0.3255597915267572, 1.377677705604583, 17.893008068203926, 3.1941850762814283, 20.88678952306509, 62.93966308236122, 21.331572756171227, 69.2341697216034, 57.7588576823473, 54.39516797661781, 66.34155213832855, 4.580297023057938, 0.3219385858392343, 0.33474033640231937, 0.09886192245176062, 0.32246640126686543, 0.18899688584497198, 0.17420045012841, 0.15450101578608155, 0.16868840059032664, 0.08915134312701412, 0.1673063583439216, 0.11897328586201183, 0.10907630872679874, 0.12011539176455699, 0.11696953166392632, 0.15326200023991987, 0.19466852681944147, 0.1449545327341184, 0.12146570719778538, 0.12388381728669629, 0.14058138302061707, 0.11054467759095132], [0.0586506135732634, 0.01202320239826804, 0.04171094813500531, 0.04640221202862449, 0.009977711670217104, 0.04468301580345724, 0.05197070931899361, 0.013849907991243526, 0.03251271788030863, 0.028510935153462924, 0.0904286906006746, 0.025242331248591654, 0.08048650925047696, 0.01925829619722208, 0.06758171148248948, 0.02955124065920245, 0.0029628794163727434, 0.03531183174345642, 0.06308106079814024, 0.09715882712043822, 0.03410353368963115, 0.10535266439546831, 0.011308227531117154, 0.019819202134385705, 0.06259974834392779, 0.019456189875199925, 0.10332065663533285, 0.5711797694675624, 23.97763106971979, 58.94695892930031, 30.984058007597923, 53.78149330615997, 16.715189069509506, 32.55257584154606, 65.70436432957649, 2.6662618294358253, 2.859076070599258, 7.583528570830822, 2.2048606630414724, 1.474703955464065, 0.34683870908338577, 10.1578020863235, 76.5449470281601, 83.88664707541466, 82.97699868679047, 79.08893331885338, 80.22212371230125, 80.39290174841881, 77.17613875865936, 76.83515265583992, 73.31520393490791, 68.92672821879387, 53.97858113050461, 51.49231754243374, 52.960490360856056, 54.472911804914474, 52.57752791047096, 55.3482860326767, 63.57540316879749, 70.24577423930168, 70.25819957256317, 69.50443401932716, 68.7893807888031, 69.5400533080101, 67.0664544403553, 64.91674259305, 58.36098477244377, 51.44684538245201, 46.92267134785652, 49.33719098567963, 45.93786679208279, 47.04403303563595, 47.40922763943672, 48.119770511984825, 46.17102228105068, 48.27602192759514, 49.71903629601002, 50.10689668357372, 57.13573671877384, 61.00129209458828, 64.22337099909782, 65.20488113164902, 64.13770079612732, 62.83843271434307, 65.9327244758606, 60.79029321670532, 60.18396355211735, 59.86977361142635, 56.92392088472843, 65.35442590713501, 62.63657994568348, 62.371927946805954, 59.91455800831318, 60.03217309713364, 58.761107102036476, 60.85848055779934, 59.27590727806091, 60.37467151880264, 61.98234625160694, 63.76848220825195, 61.441297084093094, 63.62829253077507, 52.46843956410885, 56.63797862827778, 61.54459834098816, 54.057487696409225, 45.999659076333046, 43.47284406423569, 41.49848520755768, 43.75690162181854, 44.298813343048096, 45.64388796687126, 49.36191625893116, 54.78101447224617, 59.47062782943249, 61.69861547648907, 60.973033010959625, 61.378494054079056, 59.93381157517433, 50.058019906282425, 44.61021803319454, 47.98098675906658, 44.934568628668785, 46.29969857633114, 45.705862641334534, 54.40965659916401, 61.977573707699776, 63.168486803770065, 62.679760828614235, 65.11764541268349, 64.11492481827736, 65.57010233402252, 59.906141459941864, 63.77627179026604, 65.73188245296478, 70.46333536505699, 65.01236826181412, 66.349136531353, 59.04923044145107, 68.68215814232826, 54.44305680692196, 0.735766215948388, 0.2599378174636513, 0.6681208207737654, 2.519366224296391, 1.846244337502867, 0.2611172979231924, 28.91398798674345, 26.67416587471962, 22.183479443192482, 45.686457082629204, 55.17213888466358, 54.61541175842285, 32.41471163928509, 0.23800362803740427, 0.27892403304576874, 0.07079572300426662, 0.12794973270501941, 0.010274858323100489, 0.07624261197634041, 0.05130050172738265, 0.061381023115245625, 0.039962025184649974, 0.0439141396782361, 0.012517882787506096, 0.013268208003864856, 0.03978362030466087, 0.031349876371677965, 0.03054701544897398, 0.028839591541327536, 0.03641906412667595, 0.08301036796183325, 0.02999064960022224, 0.015943643884384073, 0.01575411606609123, 0.05127611475472804, 0.04552210280962754, 0.01793532519513974, 0.05481750617036596, 0.04904218345473055, 0.027829348582599778, 0.0643157867307309, 0.03674230654723942, 0.05736811930546537, 0.02376165757596027, 0.057508507670718245, 0.013277859634399647, 0.02485534205334261, 0.03163013359881006, 0.05914919209317304, 0.06481197182438336, 0.05564976170717273, 0.01418576784999459, 0.04710130029707216, 0.03217569006665144, 0.027441995734989177, 0.04134573355258908, 0.04764960271131713, 0.03569370383047499, 0.1010602900350932, 0.02020030795392813, 0.039638007219764404, 0.09586846237652935, 0.5342934862710536, 29.34286717325449, 67.29945793747902, 39.38573777675629, 50.809171199798584, 20.16102846711874, 50.06363220512867, 70.44614508748055, 4.1079044714570045, 0.9398141386918724, 6.049231700599194, 3.4313730988651514, 4.229034846648574, 0.1200268164393492, 13.212247285991907, 79.0091148018837, 85.30894115567207, 85.4082678258419, 81.88692077994347, 82.9180334508419, 80.31853213906288, 78.32955166697502, 78.89160990715027, 77.22105234861374, 70.38305327296257, 56.713343784213066, 54.38875392079353, 55.20172409713268, 57.82410018146038, 54.32374320924282, 58.46249632537365, 65.92633321881294, 71.7606845498085, 71.66860789060593, 73.8795268535614, 71.85521587729454, 73.0742284655571, 68.55151355266571, 67.298583984375, 60.570402815937996, 54.36875179409981, 49.482411593198776, 51.98100171983242, 49.27704781293869, 49.98096004128456, 49.61100809276104, 49.05788317322731, 48.225347846746445, 51.34232439100742, 51.05279892683029, 52.69873760640621, 61.022795140743256, 63.84136229753494, 66.60848021507263, 67.35590010881424, 66.52139648795128, 65.20526871085167, 67.31021896004677, 63.299439176917076, 63.21002997457981, 63.292732536792755, 60.70832021534443, 67.50391736626625, 66.23616859316826, 65.13424292206764, 61.37995317578316, 61.63934625685215, 60.09968027472496, 64.05516162514687, 61.22117109596729, 63.381503373384476, 63.83220478892326, 65.08176773786545, 62.53177396953106, 65.15210196375847, 54.87437166273594, 60.18568105995655, 63.55185583233833, 56.004260033369064, 47.14610315859318, 45.86629003286362, 43.947092816233635, 47.93068505823612, 46.23254477977753, 48.028282821178436, 49.90679942071438, 58.506946340203285, 62.17165969312191, 64.53159525990486, 63.14952962100506, 64.9465861916542, 62.68190011382103, 52.37294688820839, 47.35452197492123, 50.28762638568878, 47.04485759139061, 48.32271382212639, 48.32381196320057, 56.606273129582405, 64.12205323576927, 64.39135238528252, 66.02664783596992, 67.20426544547081, 65.55608868598938, 67.4280658364296, 63.895387798547745, 66.32852643728256, 68.35381776094437, 72.39449813961983, 67.76315465569496, 66.9373069703579, 60.85026539862156, 68.2214480638504, 60.23255154490471, 0.5739190068561584, 1.0433337651193142, 3.267395510338247, 2.1439145458862185, 1.2357212416827679, 0.20295819762395695, 33.60732704401016, 36.39996439218521, 26.713788248598576, 58.28575640916824, 56.79367907345295, 61.73573188483715, 35.032406374812126, 0.24197613674914464, 0.2011428153491579, 0.05417005282652099, 0.12714037613477558, 0.02352908704779111, 0.06663198510068469, 0.030213763311621733, 0.02441586631903192, 0.027164128223375883, 0.1212690157990437, 0.037131989738554694, 0.06374416974722408, 0.01763210035278462, 0.0544312071724562, 0.057442441684543155, 0.05551157009904273, 0.04451211032574065, 0.05029462816310115, 0.02977593885589158, 0.024418272732873447, 0.03919043650967069, 0.044767416547983885, 0.1392071630107239, 0.11713589890860021, 0.1309876993764192, 0.22691111778840423, 0.0992803749977611, 0.2018242998747155, 0.21154122456209734, 0.12090933392755687, 0.09384553850395605, 0.18361487542279065, 0.17802006157580763, 0.1627061708131805, 0.23399941477691755, 0.1684377179481089, 0.19972439302364364, 0.07735547726042569, 0.08531325962394476, 0.1740112024708651, 0.07915111098554917, 0.22876046074088663, 0.13456658780341968, 0.16364783747121692, 0.13121075928211212, 0.14117916813120246, 0.10619999666232616, 0.20640035276301205, 0.1978712057461962, 0.5951324373017997, 42.91157618165016, 83.43966946005821, 50.788830891251564, 79.30559009313583, 24.403145536780357, 46.06687746942043, 82.88027107715607, 5.258117001503706, 10.811452511698008, 16.806129589676857, 5.768755450844765, 4.094205256551504, 0.8528020733501762, 15.072482116520405, 82.8167612850666, 86.15373462438583, 90.58007150888443, 84.8319299519062, 86.18910312652588, 83.69735643267632, 81.83926373720169, 82.35988140106201, 78.00824850797653, 73.87877449393272, 61.176401898264885, 57.71837465465069, 59.339295476675034, 60.74142023921013, 60.19943632185459, 61.15373231470585, 71.3989819586277, 75.74109256267548, 75.03159463405609, 73.91977429389954, 73.9221453666687, 75.17882913351059, 72.08692744374275, 70.88911011815071, 63.86728450655937, 57.956188693642616, 52.91407585144043, 55.98369553685188, 50.497679114341736, 51.68751686811447, 53.24017435312271, 53.15376698970795, 50.891364589333534, 53.88422839343548, 54.570524767041206, 55.92154607176781, 60.89993253350258, 64.4250337779522, 67.97792673110962, 69.38490763306618, 68.49320948123932, 65.93285366892815, 68.66139605641365, 65.10249942541122, 66.40797257423401, 67.76323065161705, 63.87483090162277, 69.51986119151115, 65.95600962638855, 68.42181131243706, 65.33686324954033, 64.82684701681137, 62.875446528196335, 65.46373844146729, 63.14857967197895, 65.30529454350471, 65.5658845603466, 68.31942200660706, 63.92866641283035, 67.48639270663261, 56.02488532662392, 61.603582575917244, 66.23647257685661, 59.21144373714924, 51.12771190702915, 49.25674930214882, 46.81739039719105, 49.41491961479187, 49.84664864838123, 51.315520629286766, 53.410112634301186, 61.87733128666878, 65.28676673769951, 66.55038133263588, 64.9724780023098, 68.92929688096046, 67.08422988653183, 55.66129423677921, 49.78684365749359, 52.07384593784809, 49.758504778146744, 50.488202422857285, 51.5486229211092, 58.970521464943886, 68.38735476136208, 69.11911189556122, 69.70187902450562, 69.71719980239868, 69.67303857207298, 71.76261484622955, 65.30614569783211, 68.57944965362549, 69.30147930979729, 72.99725219607353, 70.14934301376343, 66.98443204164505, 61.551540568470955, 68.31369191408157, 60.11670336127281, 1.413460741750896, 0.4453300475142896, 3.0107302078977227, 10.635397508740425, 10.425671562552452, 0.49968630890361965, 37.21988059580326, 37.91243523359299, 36.92983835935593, 61.777351051568985, 62.22529001533985, 67.92685747146606, 47.95479856431484, 0.5989752779714763, 0.3919621784007177, 0.14219527220120654, 0.163017813465558, 0.11973426182521507, 0.2274691386264749, 0.12409522547386587, 0.19931753282435238, 0.07707363183726557, 0.2993507869541645, 0.06719585406244732, 0.13746840006206185, 0.1189906892250292, 0.16990047617582604, 0.2214416823699139, 0.21247431199299172, 0.09933576147886924, 0.27386671223212034, 0.11147856654133648, 0.11854454714921303, 0.0900194703717716, 0.17477793007856235], [0.05833476665429771, 0.02237606229755329, 0.056593443296151236, 0.0341822904010769, 0.030990411578386556, 0.062048006075201556, 0.06621675347560085, 0.02967690110381227, 0.012851507854065858, 0.0344826858054148, 0.009629369815229438, 0.06757625669706613, 0.09759534354088828, 0.037821396690560505, 0.03955590342229698, 0.020498784906521905, 0.00881307787494734, 0.03396855929167941, 0.10374762161518447, 0.01336769011686556, 0.03259360455558635, 0.03924308446585201, 0.05267452135740314, 0.03961742375395261, 0.060514283686643466, 0.022514623124152422, 0.11167666059918702, 0.18170068360632285, 2.7886629989370704, 59.294963255524635, 37.043577656149864, 59.4426005333662, 67.20760926604271, 13.07719873264432, 59.92863245308399, 15.673575662076473, 2.2461525723338127, 2.549251145683229, 3.265179041773081, 1.1020351527258754, 1.2190002389252186, 1.0480561992153525, 32.73392491042614, 95.84706768393517, 75.83716660737991, 85.87213933467865, 76.68719619512558, 78.77978950738907, 77.58842423558235, 75.22095367312431, 66.77016153931618, 54.91573244333267, 56.60605274140835, 55.959969609975815, 52.75775983929634, 50.74144743382931, 52.65154413878918, 60.5614010989666, 68.89822214841843, 71.1210648715496, 72.72044464945793, 70.56909888982773, 70.34605085849762, 70.26433244347572, 67.92143136262894, 61.36898696422577, 65.02483159303665, 60.136796683073044, 55.72517640888691, 47.36737668514252, 49.58360776305199, 46.684044152498245, 49.02309224009514, 47.5465826690197, 48.241436183452606, 47.612900510430336, 49.62930791079998, 48.929757848381996, 51.534985452890396, 58.74994330108166, 62.01673440635204, 63.56427736580372, 62.52058357000351, 62.8583550453186, 62.10221081972122, 61.98274902999401, 59.521305710077286, 59.79291133582592, 54.58017244935036, 61.16615764796734, 67.2495286166668, 64.11116302013397, 64.07324865460396, 63.48550759255886, 63.03673267364502, 65.77770799398422, 65.74675485491753, 63.14660757780075, 61.54851973056793, 65.22524803876877, 61.26068897545338, 66.88293188810349, 66.49399235844612, 57.22287744283676, 60.74159882962704, 51.724101305007935, 45.330818966031075, 43.38669128715992, 43.556614369153976, 44.227646961808205, 44.60960626602173, 45.58395378291607, 50.30006691813469, 55.56941136717796, 63.287648409605026, 60.41886694729328, 63.464965894818306, 62.51262679696083, 63.02192106842995, 56.75778239965439, 47.01796643435955, 46.655781269073486, 44.516811445355415, 46.215126514434814, 50.37817932665348, 58.462602719664574, 61.41954705119133, 63.365107253193855, 63.403454795479774, 64.05715271830559, 66.68307021260262, 63.80471706390381, 64.03569146990776, 65.79447269439697, 66.07036828994751, 67.99764007329941, 65.1642233133316, 67.60731741786003, 59.557373374700546, 67.96338111162186, 25.28196807950735, 0.11981797608314082, 0.9256018919404596, 1.7363398661836982, 2.131204940378666, 0.9301576693542302, 0.4872630239697173, 30.214040726423264, 18.655459955334663, 32.97685727477074, 21.089149564504623, 30.97655341029167, 53.06615129113197, 7.073652455583215, 0.07851720554754138, 0.1707855614949949, 0.05224337066465523, 0.3097345313290134, 0.1558134297374636, 0.061343611450865865, 0.06390140115399845, 0.030507238188874908, 0.08703022569534369, 0.02753679025772726, 0.08295291088870727, 0.0303163299759035, 0.04562248941510916, 0.03329072984342929, 0.03719697218912188, 0.07902049299445935, 0.03096830299909925, 0.033648181561147794, 0.01972790498257382, 0.017449468941777013, 0.004773173805006081, 0.06641743020736612, 0.03794942458625883, 0.037337442190619186, 0.07113984946045093, 0.025264237592637073, 0.04448562678589951, 0.0556155078811571, 0.02353293137275614, 0.018146774200431537, 0.017754749533196446, 0.033355953491991386, 0.0704380078241229, 0.08919414278352633, 0.027947819471592084, 0.02659104920894606, 0.10034091887064278, 0.025464873506280128, 0.06682819410343654, 0.021000929446017835, 0.038756257854402065, 0.03164480585837737, 0.021806300683238078, 0.052079845845582895, 0.01766967157891486, 0.09312872774899006, 0.03391721751540899, 0.03264486098487396, 0.1421194098656997, 0.34324039123021066, 4.0619055647403, 70.91549590229988, 41.412609815597534, 68.15296053886414, 63.363271951675415, 20.78345976769924, 78.7975725531578, 17.367101088166237, 0.8168348658364266, 5.4466514848172665, 4.934873096644878, 4.558708006516099, 2.2490128688514233, 1.0528572415933013, 36.75615347921848, 95.11183753609657, 77.47414916753769, 86.68730959296227, 79.81521114706993, 80.64096003770828, 82.04188406467438, 77.11581319570541, 70.2668859064579, 56.65112592279911, 59.212804064154625, 57.7810674905777, 54.388377740979195, 53.88470716774464, 56.399431228637695, 62.65235669910908, 73.35410624742508, 73.60518157482147, 75.3324168920517, 69.98032048344612, 73.28213810920715, 73.77966061234474, 71.65115162730217, 65.84767743945122, 65.91441705822945, 61.34627178311348, 57.818666473031044, 49.783572033047676, 51.04890413582325, 50.21660439670086, 51.38008676469326, 50.33097825944424, 50.40410913527012, 50.05149185657501, 52.93139152228832, 50.72078034281731, 57.13412940502167, 63.09372201561928, 64.01147156953812, 64.60249945521355, 65.39492413401604, 62.92488947510719, 63.85139375925064, 65.49945652484894, 61.74961254000664, 63.00788842141628, 58.67208167910576, 65.82892164587975, 67.59689077734947, 66.21935829520226, 64.1280797123909, 66.03616252541542, 64.83803361654282, 68.02839562296867, 67.41240307688713, 66.01649478077888, 65.07424414157867, 65.95031753182411, 64.6333310008049, 65.51066592335701, 67.83592835068703, 62.232855409383774, 64.99150738120079, 54.7488833963871, 47.35515274107456, 47.11526781320572, 45.63310034573078, 47.0841246843338, 46.921387016773224, 48.50647576153278, 52.41239637136459, 57.38457016646862, 65.64358279109001, 62.83199205994606, 65.90577632188797, 64.97332915663719, 63.96039471030235, 56.57472722232342, 48.892018273472786, 47.92839378118515, 50.434522703289986, 50.21693877875805, 53.88472616672516, 61.65461003780365, 64.0278334915638, 64.99865099787712, 63.585069850087166, 64.27887842059135, 67.98874095082283, 66.0077628493309, 63.64762969315052, 68.56225937604904, 66.41332268714905, 70.61476483941078, 66.4465557038784, 71.9382718205452, 57.56870448589325, 72.60999217629433, 24.493510387837887, 0.03487125948595349, 3.7281621107831597, 5.622598193585873, 5.88110544718802, 0.7743592606857419, 0.7179221359547228, 34.813515320420265, 23.46100129187107, 39.74049434065819, 23.68532035499811, 31.858841367065907, 62.63043187558651, 7.875607972964644, 0.04284907612600364, 0.11023870494682342, 0.015679832649766468, 0.1412536352290772, 0.05300226490362547, 0.048826975471456535, 0.11413541811634786, 0.023234773543663323, 0.08153096336172894, 0.03469452814897522, 0.05318682218785398, 0.021828951030329335, 0.01754198136040941, 0.0180148537401692, 0.05126508272951469, 0.029802648750774097, 0.0399060041672783, 0.05103042676637415, 0.08432546848780476, 0.031142765219556168, 0.03215714379621204, 0.06639549232204445, 0.11855238422867842, 0.12368417956167832, 0.13908542110584676, 0.1525217227754183, 0.09797411345061846, 0.20964407245628536, 0.12334955259575509, 0.12305072683375329, 0.14133053657133132, 0.10980129794916138, 0.20431193435797468, 0.1596816221717745, 0.2191962255164981, 0.129440633172635, 0.16858117509400472, 0.1726189037435688, 0.119928021740634, 0.11859568112413399, 0.18219585937913507, 0.20866048929747194, 0.0708821535226889, 0.15093110734596848, 0.16644120711134747, 0.21471261454280466, 0.14305246761068702, 0.1644689793465659, 0.3066118707647547, 0.7867049763444811, 9.559950716793537, 92.87083178758621, 56.12410180270672, 79.81798499822617, 82.82094106078148, 20.25109503418207, 79.88139599561691, 22.576602548360825, 4.236779781058431, 11.573580466210842, 9.35904884710908, 5.577914966270328, 1.719227246940136, 1.0515426308847964, 37.79118753969669, 96.21615707874298, 79.21634808182716, 89.50581595301628, 85.05251571536064, 84.01202514767647, 85.16091629862785, 81.01859137415886, 74.65653955936432, 58.96352604031563, 62.94351987540722, 62.35689975321293, 57.756703197956085, 57.46821507811546, 59.1419530659914, 67.30526402592659, 77.32420161366463, 77.50651583075523, 80.8869968354702, 74.5990714430809, 75.2806256711483, 76.86452507972717, 77.00750380754471, 69.53415602445602, 71.19813233613968, 65.95455810427666, 62.25815065205097, 52.577341720461845, 56.18432097136974, 51.478216499090195, 54.439367204904556, 53.317542001605034, 53.73242273926735, 52.544386088848114, 55.54492928087711, 54.600322768092155, 59.548402056097984, 64.23983931541443, 65.60968101024628, 66.04434728622437, 65.74456617236137, 66.61649778485298, 66.80977061390877, 67.69310921430588, 65.61118572950363, 64.30149480700493, 60.97448833286762, 65.24290949106216, 71.1510756611824, 69.4837099313736, 66.78408399224281, 66.82740166783333, 69.14555847644806, 70.68112447857857, 71.38676181435585, 67.64297470450401, 65.78165978193283, 68.27181056141853, 67.40278199315071, 67.95780301094055, 70.09921610355377, 60.74028789997101, 68.47301736474037, 56.33826211094856, 50.193851217627525, 48.23089174926281, 49.719385877251625, 49.80560325086117, 48.96505415439606, 51.72733873128891, 55.15112981200218, 61.13969586789608, 69.76054787635803, 66.60053104162216, 66.93824172019958, 66.32148921489716, 66.81876093149185, 59.9143186211586, 53.24701398611069, 50.89306689798832, 51.43271014094353, 51.92897871136665, 57.966014966368675, 64.7269731760025, 66.81946009397507, 67.60842695832253, 64.59857046604156, 68.58514934778214, 70.0585886836052, 67.9752516746521, 67.84292757511139, 70.54674848914146, 70.69481134414673, 71.58096179366112, 70.4905267059803, 72.29587063193321, 60.69100074470043, 71.0023820400238, 30.80414716154337, 0.27089675597380847, 2.5426340382546186, 10.871985163539648, 13.410415202379227, 3.802215149626136, 0.8187649841420352, 38.08890916407108, 29.82426904141903, 47.89959892630577, 34.86418940126896, 42.042502015829086, 72.92950183153152, 14.249116647988558, 0.6101305887568742, 0.5184135446324944, 0.1848334225360304, 0.32331559632439166, 0.2367730878177099, 0.11624500999459997, 0.15767374163260683, 0.16975130449282005, 0.1835371577180922, 0.14424432709347457, 0.1001306832768023, 0.14058185799513012, 0.22880427713971585, 0.14693433040520176, 0.19946496788179502, 0.21049383154604584, 0.11371465006959625, 0.13976080517750233, 0.09211926590069197, 0.09343444064143114, 0.1321410562377423, 0.2309544719173573], [0.06324486021185294, 0.037137797044124454, 0.03254838549764827, 0.029519858944695443, 0.033735213219188154, 0.026114475367648993, 0.029340359396883287, 0.05711175181204453, 0.04356092933448963, 0.053988872314221226, 0.045243374406709336, 0.029319095010578167, 0.06499901530332863, 0.028752359503414482, 0.07229047521832399, 0.07573165072244592, 0.03191984578734264, 0.13960036769276485, 0.0398439680429874, 0.028905125036544632, 0.1545191984041594, 0.06024004898790736, 0.06156452283903491, 0.028323607803031337, 0.11232644057599828, 0.023277695654542185, 0.08010869671124965, 0.07276868549524806, 0.7813537353649735, 20.703086480498314, 55.43568134307861, 31.02506920695305, 59.907847568392754, 19.59014520049095, 28.62745676189661, 39.19435724616051, 0.1134150598954875, 3.275235677137971, 2.0994832925498486, 4.044648790732026, 0.2666787744965404, 0.04663093452109024, 3.118618531152606, 78.85627180337906, 83.79232853651047, 80.90716615319252, 75.49465298652649, 75.13985082507133, 67.73826599121094, 61.386279836297035, 57.74173580110073, 59.192190170288086, 56.57683990895748, 54.5296997576952, 54.39382664859295, 52.749309092760086, 60.24601802229881, 66.73976317048073, 72.79645577073097, 72.4729411303997, 69.67849507927895, 71.34721353650093, 72.48573884367943, 70.01479983329773, 68.30464079976082, 64.20615032315254, 65.41212201118469, 62.93813556432724, 60.63588090240955, 53.62165488302708, 49.402095302939415, 48.47759731113911, 48.2924560457468, 48.52658048272133, 47.44661383330822, 50.20415246486664, 51.05633273720741, 49.09336566925049, 49.15478557348251, 53.74125726521015, 61.23091757297516, 63.722588270902634, 63.96289497613907, 62.61291481554508, 63.18376198410988, 67.44600847363472, 64.65232998132706, 61.5867380797863, 59.28653910756111, 59.7903236746788, 64.41377878189087, 61.123664528131485, 64.61930975317955, 65.14092296361923, 64.97691616415977, 62.52548910677433, 64.85941126942635, 61.75048649311066, 65.05060940980911, 63.180269971489906, 63.52243401110172, 62.645486667752266, 63.54176737368107, 61.53248839080334, 55.94164699316025, 49.78754661977291, 44.21905942261219, 44.67925652861595, 44.96004246175289, 43.87095630168915, 46.01002871990204, 47.253865376114845, 50.57487577199936, 55.3697244822979, 59.75726544857025, 60.10655790567398, 62.994847521185875, 60.81656500697136, 63.746599182486534, 59.43742521107197, 50.72504751384258, 46.001570373773575, 46.593172028660774, 47.40507446229458, 56.46782375872135, 61.52822881937027, 63.95834282040596, 66.64770931005478, 65.94454184174538, 63.98740366101265, 65.06121844053268, 68.93325626850128, 65.1111401617527, 63.44467878341675, 69.20111909508705, 67.02079609036446, 65.09318992495537, 63.39485585689545, 58.336719274520874, 52.94668950140476, 2.3176243621855974, 0.2604282583342865, 6.599420327693224, 3.9197870157659054, 1.0026774904690683, 1.1442504124715924, 2.8240730613470078, 28.519913032650948, 28.90472788363695, 39.19475242495537, 31.646484062075615, 60.22822357714176, 31.377471797168255, 0.21071764844236895, 0.03140394182992168, 0.1717505612759851, 0.02295231584866997, 0.06615370803046972, 0.11454938066890463, 0.04106821485038381, 0.0413686584943207, 0.10705963373766281, 0.07731093355687335, 0.016650090547045693, 0.03574541296984535, 0.02642269857460633, 0.016332020895788446, 0.04266903481038753, 0.10141809427295811, 0.09362667173263617, 0.03326614991237875, 0.054441304091596976, 0.03906444209860638, 0.03285729333583731, 0.06702937549562193, 0.1367649924941361, 0.0830073919496499, 0.034668697699089535, 0.03621649862907361, 0.02877139373595128, 0.03584228179533966, 0.0106371553374629, 0.13382965000346303, 0.032836041937116534, 0.07037813134957105, 0.02949255347630242, 0.026851368638745043, 0.11112557142041624, 0.03637060188339092, 0.0443397576600546, 0.07419754241709597, 0.014915885312802857, 0.07006289670243859, 0.014273167798819486, 0.021679213459719904, 0.031536552487523295, 0.008203580746339867, 0.0481476877030218, 0.05811662718770094, 0.03428237272601109, 0.1214560073276516, 0.03884833240590524, 0.0417948961694492, 0.029532289918279275, 0.8995212789159268, 29.813802503049374, 65.62121719121933, 42.20016695559025, 74.84504744410515, 17.375067360699177, 46.40859313309193, 44.550675228238106, 0.18110730685293674, 2.3469359893351793, 3.5738920513540506, 4.112300360575318, 4.684075629338622, 0.04957328288583085, 3.57443162240088, 80.97527369856834, 82.57786050438881, 82.88017228245735, 78.56434866786003, 80.41008442640305, 72.24065959453583, 65.2116371691227, 63.1006870418787, 63.10804724693298, 56.27216085791588, 57.90879383683205, 57.91238844394684, 57.01389245688915, 62.28192217648029, 72.671108096838, 74.11289513111115, 73.95980134606361, 71.0874442756176, 73.24482411146164, 76.29221498966217, 75.45223966240883, 70.11156544089317, 64.76653665304184, 66.49798214435577, 65.21570295095444, 63.254100009799004, 56.19591794908047, 50.53582526743412, 51.804888769984245, 51.44309878349304, 51.42489016056061, 49.24029998481274, 51.152942553162575, 52.71649405360222, 50.89828781783581, 49.9028704315424, 56.98363468050957, 64.58137258887291, 67.17471063137054, 66.35868921875954, 66.81484714150429, 66.62187829613686, 67.9515865445137, 66.42707034945488, 65.1012834906578, 62.05181032419205, 62.68949590623379, 68.99996548891068, 65.00421389937401, 67.93052807450294, 67.40718975663185, 68.16659420728683, 66.37884333729744, 66.82621613144875, 64.71726849675179, 67.39534959197044, 64.88667860627174, 65.84674268960953, 63.84336858987808, 65.12308672070503, 66.177286952734, 58.06461587548256, 52.55513571202755, 46.25474698841572, 46.40867292881012, 46.80668257176876, 47.34031833708286, 48.07544209063053, 48.811872974038124, 54.643910229206085, 57.07053601741791, 63.66532914340496, 62.17454373836517, 65.27211472392082, 62.034718841314316, 67.71185740828514, 62.213803231716156, 52.657863199710846, 48.019132912158966, 49.570589661598206, 48.36956150829792, 60.085982009768486, 62.2988236695528, 66.9620968401432, 67.2107782959938, 67.25916489958763, 65.03649696707726, 67.28950247168541, 71.65530860424042, 68.88914823532104, 66.64401590824127, 68.89799416065216, 68.87557536363602, 70.03271207213402, 64.62499424815178, 61.24063365161419, 53.69384340941906, 2.750149928033352, 2.1097814524546266, 3.516235132701695, 6.510339807718992, 2.3548550019040704, 1.044807017315179, 3.4421331714838743, 35.18031723797321, 36.78207188844681, 48.01571309566498, 31.055877953767776, 66.09731644392014, 35.902092307806015, 0.29882377304602414, 0.03525403699313756, 0.19853143516229466, 0.06349953560857102, 0.04791127284988761, 0.06577068561455235, 0.029106232213962357, 0.024582146361353807, 0.08323377667693421, 0.0901918786985334, 0.05258104043605272, 0.02907164813223062, 0.04185058322036639, 0.006295638740994036, 0.038173323118826374, 0.04245744850777555, 0.036238328902982175, 0.015367480318673188, 0.08892152225598693, 0.02567844134318875, 0.019589609473769087, 0.009066815382539062, 0.06256048131035641, 0.16634854255244136, 0.19031651347177103, 0.10977161946357228, 0.0704223188222386, 0.1053569169016555, 0.10545206765527837, 0.18425441376166418, 0.16530027380213141, 0.173826600657776, 0.1369754210463725, 0.14659206673968583, 0.20758753671543673, 0.18345825257711112, 0.16489108325913548, 0.1788075247895904, 0.1620343787362799, 0.1445791099104099, 0.3503907169215381, 0.11443526062066667, 0.11911374473129399, 0.20594957226421684, 0.216993011708837, 0.13982011761981994, 0.11742734030121937, 0.26221267820801586, 0.21536466549150646, 0.1399632333777845, 0.1700804618303664, 1.3283165730535984, 46.56963229179382, 89.05222669243813, 52.40258909761906, 91.38792335987091, 26.77073199301958, 47.16929331421852, 50.28360240161419, 0.19255968451034278, 13.584592156112194, 9.844810031354427, 12.64379683881998, 2.8099494567140937, 0.2455984111293219, 4.568199897184968, 81.1855012178421, 86.64015412330627, 89.08498093485832, 80.8526998758316, 81.48252367973328, 76.49642363190651, 67.18756914138794, 66.25255331397057, 66.40570029616356, 59.95087265968323, 59.74494270980358, 60.09514331817627, 58.71170975267887, 67.55716770887375, 75.70883229374886, 79.23184365034103, 78.7925112247467, 70.80654814839363, 74.7664600610733, 78.91859605908394, 78.36951032280922, 74.7186054289341, 67.84530624747276, 69.67173904180527, 67.54111737012863, 66.87585666775703, 60.19686006009579, 53.81097972393036, 55.21779723465443, 53.24148528277874, 54.25402455031872, 51.287770718336105, 54.4157362729311, 55.60406170785427, 53.40762756764889, 54.098004922270775, 59.3016204982996, 68.1917716562748, 67.45059862732887, 69.9617774784565, 67.40464389324188, 69.07855287194252, 69.76500123739243, 70.17323613166809, 66.62023678421974, 65.15938997268677, 63.293332904577255, 67.83405885100365, 68.66142645478249, 68.61202910542488, 68.50301295518875, 69.24565270543098, 66.098912358284, 68.69028210639954, 65.47863364219666, 71.07849195599556, 67.3650424182415, 69.33769136667252, 67.02712655067444, 66.3770042359829, 64.70954731106758, 60.48896938562393, 54.750980883836746, 48.21573056280613, 50.40974423289299, 50.87197422981262, 48.61426457762718, 53.18431735038757, 51.8364042788744, 56.95817984640598, 62.25544899702072, 66.4564199745655, 64.10366982221603, 67.53882989287376, 65.64061895012856, 71.16250544786453, 65.92846870422363, 54.835864529013634, 51.17376543581486, 53.405370488762856, 53.05293180048466, 63.71152326464653, 64.44094732403755, 70.38901895284653, 72.5425685942173, 70.58014869689941, 67.04926416277885, 67.1099317073822, 75.09870663285255, 71.01854637265205, 67.65869066119194, 73.14115047454834, 71.8924842774868, 72.86872029304504, 67.57420599460602, 62.75973133742809, 56.82409644126892, 4.026282001286745, 1.263714220840484, 16.25540044158697, 12.861656248569489, 5.415248544886708, 2.6091311825439334, 3.8864454673603177, 39.7582545876503, 45.14716722071171, 56.360156536102295, 49.106379970908165, 73.00461620092392, 51.90100081264973, 0.5451327608898282, 0.19559909094823524, 0.2448128181276843, 0.16577254689764231, 0.2109814522555098, 0.20774145814357325, 0.2219465357484296, 0.14884307485772297, 0.18989011994563043, 0.2873476763488725, 0.28229798481334, 0.17328743037069216, 0.14306941826362163, 0.119922841549851, 0.1938480231910944, 0.17114105023210868, 0.14258714101742953, 0.1534383196849376, 0.1662986256997101, 0.09285146137699485, 0.24240328726591542, 0.1710461443872191, 0.14786290557822213], [0.06870936034829356, 0.019873130295309238, 0.034733891661744565, 0.018392866659269203, 0.032715376146370545, 0.061049509458825924, 0.04981297803169582, 0.019855177743011154, 0.13315349409822375, 0.03895993657351937, 0.031997018013498746, 0.06622925124247558, 0.054282673736452125, 0.054489844260388054, 0.07018051968771033, 0.07217665202915668, 0.07034946218482219, 0.03946454875404015, 0.02504583837435348, 0.07861979262088425, 0.022902072450960986, 0.07361484516877681, 0.04435226655914448, 0.09770749689778313, 0.029379741463344544, 0.034117378454538994, 0.14749537920579314, 0.1680534190381877, 0.3202799748396501, 7.441424746066332, 55.38748852908611, 33.082081228494644, 30.584600642323494, 57.74089224636555, 16.199889220297337, 50.07953055202961, 4.850236913189292, 1.7582184984348714, 1.8095631245523691, 2.612134921364486, 2.4968524323776364, 0.36545227747410536, 0.10892807214986533, 47.51458078622818, 93.09454098343849, 79.34549555182457, 77.82197490334511, 68.09690594673157, 66.34439438581467, 64.48921233415604, 63.84787514805794, 57.84162484109402, 61.59247577190399, 61.08451522886753, 57.03039117157459, 59.50800262391567, 69.53561514616013, 72.86326378583908, 70.64103662967682, 76.26855745911598, 75.61568409204483, 73.96928563714027, 71.93016305565834, 71.81858584284782, 69.3177880346775, 68.61995548009872, 64.54547211527824, 65.85070207715034, 60.54951533675194, 57.55800046026707, 51.42870515584946, 48.743374049663544, 47.273278534412384, 50.07396385073662, 49.26928482949734, 49.59642827510834, 51.90353147685528, 50.74235178530216, 50.980899184942245, 48.88429328799248, 53.53460915386677, 58.94346311688423, 62.19421908259392, 61.61566972732544, 63.457153514027596, 65.39179310202599, 67.26426422595978, 63.1868664175272, 64.02627557516098, 46.25471279025078, 53.60715866088867, 67.31828972697258, 64.57157671451569, 65.10548606514931, 64.75779712200165, 64.88266602158546, 64.81061428785324, 66.09904915094376, 63.977554589509964, 64.50812011957169, 64.33924958109856, 62.49240808188915, 60.06542511284351, 55.59927016496658, 50.334664061665535, 47.69203506410122, 45.38072168827057, 44.292441084980965, 44.02599178254604, 45.07322318851948, 44.40560281276703, 46.599388495087624, 50.20536080002785, 55.37801183760166, 60.332672372460365, 60.77053427696228, 62.30197370052338, 63.213369995355606, 64.38740819692612, 61.94926142692566, 55.07838651537895, 47.5517275929451, 46.74389474093914, 51.426774859428406, 62.27713443338871, 61.81564919650555, 65.57629600167274, 62.916051149368286, 64.75221902132034, 66.52999922633171, 68.45882892608643, 63.70650373399258, 72.17478632926941, 68.45902651548386, 70.33187761902809, 60.5531707406044, 69.72641810774803, 50.50510011613369, 67.87462547421455, 11.60658834502101, 0.8219473133794963, 2.8657321259379387, 3.4214523062109947, 5.110467849299312, 2.374760708771646, 0.17855840065749362, 4.7491552121937275, 25.859417393803596, 33.85462537407875, 27.82591637223959, 35.62432341277599, 53.972763642668724, 6.3654811307787895, 0.08400086793699302, 0.2453709428664297, 0.10124790496774949, 0.10130004084203392, 0.040185355974244885, 0.031232791443471797, 0.041704124087118544, 0.22959255671594292, 0.019302967921248637, 0.0670766131952405, 0.04363221632956993, 0.06284949588007294, 0.07726975178229623, 0.07060700227157213, 0.07963167387060821, 0.05982770431728568, 0.03639106289483607, 0.051325486128916964, 0.029517769798985682, 0.01779942867869977, 0.024183637178794015, 0.0055872662051115185, 0.039162064203992486, 0.06341469328617677, 0.050973214601981454, 0.050975882622879, 0.04756851194542833, 0.036045455854036845, 0.04906082620436791, 0.06814819280407391, 0.05352899679564871, 0.06312085475656204, 0.021904317982262, 0.07987319841049612, 0.046753192218602635, 0.023204499484563712, 0.04853901104070246, 0.05404560950410087, 0.04853686252317857, 0.061885991526651196, 0.05738313295296393, 0.015998098970158026, 0.08946861125878058, 0.03904271201463416, 0.04292717232601717, 0.01316801157372538, 0.04222256990033202, 0.044471444343798794, 0.015600009101035539, 0.07259944613906555, 0.38897886348422617, 0.46123308478854597, 14.25819531083107, 76.62456035614014, 34.64533254504204, 42.72640451788902, 54.22136530280113, 21.702826134860516, 61.98333419859409, 3.897893065586686, 0.9927819308359176, 3.7682000873610377, 4.24550648778677, 10.810310672968626, 0.8026773005258292, 0.2249298951937817, 51.31222240626812, 92.82934561371803, 84.6197721362114, 79.94893357157707, 71.6194461286068, 70.41966810822487, 66.47813200950623, 62.99833193421364, 61.187755689024925, 65.46532675623894, 63.794123232364655, 58.86559009552002, 61.33473560214043, 70.63254788517952, 74.22487512230873, 74.71450924873352, 79.22253414988518, 77.46050789952278, 73.40675622224808, 72.20383957028389, 73.62184748053551, 69.52137351036072, 69.62088257074356, 68.60547825694084, 67.05000132322311, 64.02310654520988, 59.07778590917587, 53.006547689437866, 50.38858696818352, 51.05629473924637, 52.11792357265949, 51.04093596339226, 52.15794302523136, 53.48429225385189, 53.45924399793148, 52.05203890800476, 51.934743002057076, 56.19380906224251, 61.76428735256195, 65.93736782670021, 65.0342246890068, 65.5517341196537, 67.08084046840668, 69.0228022634983, 64.17812302708626, 67.02840328216553, 50.9751120954752, 58.519740253686905, 67.50525489449501, 65.80020278692245, 69.09393444657326, 65.99692583084106, 67.61677131056786, 67.30948939919472, 68.67848753929138, 66.24699041247368, 66.19270652532578, 67.47606486082077, 64.58497479557991, 62.47232235968113, 59.97561693191528, 53.1238017976284, 49.69375625252724, 48.46312388777733, 46.66494257748127, 47.87582740187645, 48.232286274433136, 47.142747938632965, 49.51045788824558, 52.79722072184086, 57.194394171237946, 62.57144384086132, 64.50256481766701, 64.69200745224953, 64.364153444767, 65.27453139424324, 64.84835386276245, 57.39448003470898, 50.522058606147766, 49.30322840809822, 55.552665665745735, 65.22492125630379, 66.7978848516941, 68.4649845957756, 65.07336258888245, 67.0685975253582, 66.39857187867165, 70.67765146493912, 65.24021163582802, 74.84471306204796, 68.29663082957268, 74.25078973174095, 63.29095043241978, 72.7403935790062, 53.53565789759159, 73.6632652580738, 11.207234524190426, 1.1702031386084855, 3.2600046694278717, 6.002702247351408, 1.9180041993968189, 1.7136098421178758, 0.44823374482803047, 6.329165054485202, 32.59656988084316, 47.06351459026337, 36.50924272835255, 35.80947607755661, 63.623683378100395, 7.06241455860436, 0.14828434155788273, 0.10725303742219694, 0.08394464282901026, 0.04495690169278532, 0.025722088903421536, 0.04461449701921083, 0.02086848020553589, 0.08375101650017314, 0.0664020306430757, 0.024413266946794465, 0.06660399129032157, 0.0910767339519225, 0.0460156755434582, 0.04433673711901065, 0.048421432584291324, 0.07107944606104866, 0.08465040300507098, 0.0508358764636796, 0.052157389145577326, 0.02204353932029335, 0.05371423685573973, 0.08111608796752989, 0.02482424235495273, 0.1976789894979447, 0.12421634397469461, 0.21256035659462214, 0.19020070874830708, 0.10348179916036315, 0.20213392388541251, 0.1957006167504005, 0.17888205125927925, 0.2800645655952394, 0.132675209606532, 0.1928838694584556, 0.20832474168855697, 0.1004494282824453, 0.13429727725451812, 0.08525300465407781, 0.09694935593870468, 0.20611343847122043, 0.176737348374445, 0.06270842102821916, 0.2762451471062377, 0.1788874392514117, 0.12685836001764983, 0.186876866791863, 0.21678193006664515, 0.14387686009285972, 0.16492203081725165, 0.39021706266794354, 0.727189244935289, 1.0282414499670267, 24.140621423721313, 96.03589475154877, 52.225484400987625, 57.88364298641682, 80.160331428051, 25.104629695415497, 65.25062307715416, 5.905748549848795, 5.549746127799153, 13.62317243590951, 6.540069412440062, 6.8740510661154985, 0.9317166544497013, 0.24689092068001628, 52.99510270357132, 95.25263518095016, 86.62107154726982, 84.89062920212746, 75.31911760568619, 73.90977323055267, 70.95193594694138, 68.80029380321503, 63.762318938970566, 67.30804547667503, 67.16632828116417, 63.48612315952778, 66.59779518842697, 75.41723594069481, 77.40942344069481, 76.21521592140198, 81.11701369285583, 82.5297398865223, 77.23747506737709, 75.88250577449799, 78.40904340147972, 73.00672128796577, 74.91220504045486, 74.27366450428963, 72.4197667837143, 65.5406691133976, 60.41451618075371, 56.86389930546284, 54.070786982774734, 51.79659381508827, 55.70010155439377, 54.62573580443859, 54.53997440636158, 57.36109882593155, 57.505852058529854, 56.6562632471323, 54.09851409494877, 57.51870296895504, 64.58720907568932, 69.74380597472191, 68.2289032638073, 67.40863367915154, 70.63618808984756, 71.02266535162926, 68.17105516791344, 70.26855781674385, 52.34379105269909, 60.33977039158344, 69.9869929254055, 68.43365147709846, 70.6429897248745, 67.24787950515747, 70.55446207523346, 70.9643080830574, 72.45171546936035, 68.82199063897133, 68.83752420544624, 70.24562984704971, 66.82933956384659, 66.32722690701485, 61.64623148739338, 55.182869508862495, 52.80480891466141, 52.29241020977497, 48.15288573503494, 51.53384171426296, 51.70916050672531, 49.88526217639446, 52.459707632660866, 56.41369566321373, 60.218777284026146, 66.07156902551651, 68.9162939786911, 66.42806589603424, 66.86543762683868, 68.35523128509521, 66.36096149682999, 61.39628469944, 54.103689417243004, 51.825597658753395, 56.92825265228748, 68.06716874241829, 71.01390302181244, 70.32171696424484, 67.10276529192924, 70.21325558423996, 70.22758841514587, 71.87651753425598, 65.71969270706177, 78.01852315664291, 72.70534425973892, 75.09511202573776, 68.74441400170326, 76.95272594690323, 57.45078161358833, 75.05893036723137, 13.722852487117052, 0.7732462766580284, 6.637085331603885, 12.635249197483063, 12.843615766614676, 7.90361057035625, 1.4539982727728784, 6.97152248583734, 39.086762219667435, 51.648280173540115, 46.102758944034576, 47.007087618112564, 75.7793565094471, 12.525458838790655, 0.4435641219606623, 0.49804901238530874, 0.1807200541952625, 0.2581627486506477, 0.19218451401684433, 0.22149272728711367, 0.2466823029681109, 0.3790954453870654, 0.13838404702255502, 0.13644258870044723, 0.14395699719898403, 0.16856889997143298, 0.1371677708812058, 0.1451937120873481, 0.15282695327186957, 0.18913658772362396, 0.1547481064335443, 0.08292440499644727, 0.17306040739640594, 0.10495672118850052, 0.09313784132245928, 0.10386828740593046, 0.150311874167528], [0.03658602880022954, 0.09374810935696587, 0.028630181586777326, 0.0442995443881955, 0.03709087846800685, 0.07527030946221203, 0.04404241990414448, 0.09142123890342191, 0.03867682578857057, 0.04550532285065856, 0.12876435852376744, 0.057035373683902435, 0.06040814914740622, 0.09277554709115066, 0.044700270736939274, 0.09180495151667856, 0.027979473925370257, 0.047718659552629106, 0.06395689895725809, 0.1830527579295449, 0.03797865778324194, 0.11865050357300788, 0.09459021690418012, 0.16021607239963487, 0.11907428473932669, 0.1581347786122933, 0.31766363710630685, 0.4323383962037042, 0.3092554898466915, 4.09249534830451, 33.65097530186176, 50.036718249320984, 45.8384907245636, 51.681672781705856, 31.32588006556034, 39.667070880532265, 24.183935299515724, 0.15143072116188705, 3.8980609690770507, 0.4906149487942457, 19.96404703706503, 1.6301593137905002, 0.31496931449510157, 6.405171900987625, 91.9799467921257, 76.53475597500801, 84.3426302075386, 78.11183094978333, 77.16188192367554, 72.3036602139473, 69.17652681469917, 70.09430676698685, 61.07009880244732, 61.74058422446251, 59.085849076509476, 71.49824023246765, 73.9922896027565, 75.78179597854614, 74.15675237774849, 76.46566048264503, 71.76724299788475, 74.4135046005249, 72.6748774945736, 72.45819792151451, 69.85602915287018, 70.56972965598106, 64.44315880537033, 67.68025070428848, 62.61621683835983, 58.80361162126064, 52.55022257566452, 49.32538881897926, 47.363945469260216, 48.64397518336773, 47.82618686556816, 48.36486876010895, 49.03227634727955, 50.313313007354736, 50.9990394115448, 51.59813426434994, 50.31981445848942, 50.21540746092796, 55.75867161154747, 60.71182742714882, 64.39148917794228, 65.79528585076332, 67.92925894260406, 61.81027248501778, 65.18456742167473, 37.38161891698837, 55.04625923931599, 68.17373022437096, 63.984827399253845, 66.46870091557503, 62.66106963157654, 64.51911672949791, 61.300989612936974, 62.48175345361233, 60.58044567704201, 63.00196073949337, 59.50490579009056, 58.50930601358414, 51.486465856432915, 52.823253124952316, 46.50868736207485, 45.97753286361694, 46.91275767982006, 46.26171961426735, 45.328770875930786, 45.81027343869209, 45.11126674711704, 48.5608546435833, 50.430320128798485, 54.160990342497826, 58.49463880062103, 63.64636056125164, 62.27528773248196, 64.82383757829666, 62.27321684360504, 63.673848286271095, 60.19573912024498, 51.90435603260994, 45.32365255057812, 58.454053178429604, 64.30836483836174, 63.29592436552048, 62.49352902173996, 66.63330048322678, 65.59625253081322, 68.33706825971603, 66.00777044892311, 68.1892941892147, 66.80600121617317, 71.97379231452942, 66.50355264544487, 65.0790622830391, 51.33233092725277, 64.37654837965965, 35.73493167757988, 0.03804538428084925, 0.6744030117988586, 1.5932469069957733, 1.1128795333206654, 3.3589295111596584, 1.2018831074237823, 0.026640249889169354, 6.972471959888935, 38.570605516433716, 29.739484190940857, 19.152674674987793, 56.02107413113117, 32.01118469238281, 0.47246744914446026, 0.129259682726115, 0.0755441322689876, 0.0830398163816426, 0.10453363764099777, 0.09011161542730406, 0.04883739893557504, 0.04888052513706498, 0.028574347961694002, 0.012195635772513924, 0.052977859377278946, 0.020315275905886665, 0.1045448292279616, 0.023363523177977186, 0.1046007574768737, 0.021677194818039425, 0.0556608790793689, 0.018002415345108602, 0.03216602359316312, 0.028497038438217714, 0.02351481183723081, 0.0597079439467052, 0.08474943519104272, 0.030676536916871555, 0.029546728401328437, 0.07512763899285346, 0.03844406601274386, 0.04861607936618384, 0.03854035967378877, 0.0373803309048526, 0.057549889825168066, 0.10325822717277333, 0.016854465029609855, 0.07105484386556782, 0.0443620888836449, 0.08345325200934894, 0.029373511133599095, 0.030806626127741765, 0.046193612870411016, 0.02589719122624956, 0.030210612894734368, 0.03739262458111625, 0.06122540587966796, 0.12457457865821198, 0.05177885301236529, 0.03798092875513248, 0.059995748815708794, 0.1233454114117194, 0.06805886048823595, 0.0760582328075543, 0.3113565099192783, 0.47242012980859727, 0.11394688292057253, 5.789035437628627, 55.034510269761086, 59.58365276455879, 55.09494982659817, 67.1109576523304, 33.528925850987434, 57.44410537183285, 27.92309045791626, 0.1490988486330025, 1.8403066811151803, 3.50410760845989, 10.437083300203085, 3.1387320393696427, 0.523184307385236, 8.546684738248587, 94.20386105775833, 76.51012569665909, 88.48095774650574, 79.09621372818947, 79.71902310848236, 73.91698524355888, 73.37447315454483, 71.04591250419617, 64.66864630579948, 63.54214735329151, 63.834727853536606, 73.90549466013908, 76.27947047352791, 78.27949315309525, 78.48359540104866, 79.50203955173492, 73.00461620092392, 77.21412912011147, 76.73225417733192, 76.33205965161324, 70.92456221580505, 70.88125973939896, 67.14018568396568, 70.90193063020706, 65.34247174859047, 62.50989854335785, 56.97097755968571, 51.65010027587414, 50.35412661731243, 51.9913599640131, 50.57154335081577, 50.73233552277088, 51.53317295014858, 53.219381868839264, 51.75982318818569, 53.33154425024986, 53.52468028664589, 54.07808259129524, 59.37434479594231, 64.61119338870049, 67.58141040802002, 68.2662932574749, 69.02206510305405, 66.92690312862396, 67.64421343803406, 42.14304842054844, 54.50399413704872, 70.34779876470566, 64.09756734967232, 69.08169910311699, 65.3183126449585, 68.78182679414749, 63.88952851295471, 67.27726712822914, 63.836810141801834, 67.00808957219124, 61.17678187787533, 62.63946779072285, 55.6078615039587, 54.782792776823044, 48.90277549624443, 49.00550298392773, 48.0643542855978, 48.51444773375988, 46.874429136514664, 49.222539737820625, 46.659056693315506, 51.137617975473404, 54.04972851276398, 58.53880763053894, 61.75357572734356, 65.17004460096359, 64.97896045446396, 68.64564210176468, 66.45613119006157, 67.25307002663612, 63.269348591566086, 53.26724790036678, 47.5458987057209, 59.18657407164574, 66.11438512802124, 66.19527518749237, 64.02332693338394, 68.85733634233475, 68.02451983094215, 70.19454538822174, 65.93653187155724, 71.76135331392288, 68.69811728596687, 74.70007762312889, 68.3009321987629, 71.74690648913383, 56.55632860958576, 69.74334239959717, 37.373954728245735, 0.03196581070369575, 1.3179792277514935, 4.539405517280102, 3.5091361636295915, 3.3773072250187397, 0.12223010446177796, 0.12331638601608574, 11.432652678340673, 44.64681386947632, 43.3828154951334, 21.061335057020187, 62.9621996730566, 37.22935728728771, 0.3922318748664111, 0.04920091028907336, 0.010423853746033274, 0.09924884114298038, 0.0693223817506805, 0.04485555771680083, 0.010894105416809907, 0.007197532777354354, 0.06843293260317296, 0.02147468869225122, 0.04773610373376869, 0.017904852611536626, 0.04909528041025624, 0.024064207063929643, 0.10577357345027849, 0.026267608263879083, 0.055437433256884106, 0.02133890906407032, 0.043667501740856096, 0.03975310690293554, 0.03589265135815367, 0.0677518339944072, 0.06370179311488755, 0.021070038237667177, 0.12372792916721664, 0.16713011311367154, 0.17598567152163014, 0.14338900189613923, 0.11080871146987192, 0.17537424573674798, 0.13255971658509225, 0.23938696162076667, 0.09270887254388072, 0.20338810893008485, 0.13640040502650663, 0.29629043710883707, 0.09478887499426492, 0.2545861608814448, 0.19771983730606735, 0.12346696777967736, 0.10603989314404316, 0.1828440511599183, 0.18545569851994514, 0.31072025187313557, 0.20794243173440918, 0.2257071464555338, 0.22139673790661618, 0.39819298312067986, 0.26377466158010066, 0.30678247567266226, 0.5217873479705304, 0.967763242078945, 0.777718696044758, 8.372809868305922, 74.8663567006588, 77.80823484063148, 58.89307402074337, 77.45661690831184, 42.58102811872959, 58.64622786641121, 29.97775800526142, 0.12403931948938407, 10.14437835663557, 8.666815292090178, 48.7983039021492, 3.106919671408832, 0.4905578034231439, 9.183666408061981, 98.04212629795074, 82.35988900065422, 91.33510619401932, 82.00308054685593, 83.15592348575592, 79.033213108778, 75.7147067785263, 75.75588136911392, 67.76658207178116, 68.5856357216835, 68.05479660630226, 76.9913698732853, 82.26612523198128, 81.29626527428627, 82.11721882224083, 83.41558635234833, 76.58413052558899, 77.72645562887192, 80.02638101577759, 79.20633941888809, 74.02094766497612, 75.74081137776375, 70.16426101326942, 73.02640423178673, 67.95193612575531, 66.57916098833084, 60.66793978214264, 53.54299150407314, 52.20048934221268, 53.95417504012585, 52.34447121620178, 51.730473563075066, 53.91122594475746, 55.179233103990555, 54.24704052507877, 56.759811490774155, 56.346032693982124, 55.54649859666824, 61.98394976556301, 66.53499215841293, 70.01470863819122, 71.71362787485123, 70.98142236471176, 69.65793058276176, 68.56629475951195, 45.887504294514656, 54.85362857580185, 68.64359021186829, 67.43659257888794, 71.12404391169548, 67.14478343725204, 70.3751876950264, 64.61459800601006, 67.97612562775612, 65.80130472779274, 69.86514866352081, 66.2308868765831, 65.99319443106651, 57.18041852116585, 56.71207845211029, 50.68787410855293, 52.307943776249886, 52.17707879841328, 53.32992933690548, 50.653558149933815, 50.03665745258331, 51.25105328857899, 54.44656401872635, 57.61049844324589, 61.74574434757233, 64.03198286890984, 67.53123790025711, 68.49974513053894, 70.58392569422722, 68.6360514163971, 69.8514997959137, 65.35457789897919, 56.96929804980755, 50.688957050442696, 62.844679579138756, 71.76880851387978, 67.4672569334507, 67.33944699168205, 72.98943221569061, 71.76447674632072, 70.75135990977287, 70.43508008122444, 72.54189983010292, 71.73404037952423, 74.65302854776382, 71.56621858477592, 71.84327691793442, 60.50176329910755, 69.08434376120567, 40.666637644171715, 0.08286779397167265, 1.1956249619834125, 9.358936753123999, 9.464259501546621, 10.17333660274744, 3.9938611909747124, 0.24472266202792525, 14.377794843167067, 58.903987035155296, 43.72831955552101, 32.275593504309654, 73.7135897576809, 50.292421728372574, 0.5772749392781407, 0.2753176406258717, 0.17725213168887421, 0.10778823721921071, 0.2853689918993041, 0.2599177497904748, 0.09724704621476121, 0.17174701381009072, 0.23536885535577312, 0.07184932037489489, 0.09910640073940158, 0.08566582429921255, 0.15353079128544778, 0.13425656303297728, 0.18419818865368143, 0.08240954004577361, 0.15685813617892563, 0.09846264700172469, 0.11221222404856235, 0.12183594240923412, 0.12093487865058705, 0.28600949503015727, 0.18799911282258108, 0.22054173925425857], [0.05406776261224877, 0.029631919533130713, 0.05362579511711374, 0.010674377754185116, 0.044900628345203586, 0.055700250013615005, 0.1039277482777834, 0.04833661252632737, 0.05544168576307129, 0.01628514870390063, 0.04392087095766328, 0.02668863977305591, 0.06800646486226469, 0.039605222846148536, 0.059730108187068254, 0.00977181485723122, 0.04277400046703406, 0.036292494551162235, 0.0034822837596948375, 0.08322340887389146, 0.02960944730148185, 0.021126979518157896, 0.11115971021354198, 0.030116588350210804, 0.0038371110576918, 0.05181980101042427, 0.1063831735518761, 0.08608477408415638, 0.15821013628738, 0.47805409936700016, 16.090650781989098, 53.181934878230095, 69.76400569081306, 55.058555379509926, 52.41159461438656, 25.97078751772642, 26.937453746795654, 0.44205759186297655, 1.1832004599273205, 2.4935390101745725, 11.444480493664742, 1.4473005384206772, 0.24316401832038537, 0.11916755785932764, 37.38032318651676, 105.22704675793648, 78.66346254944801, 86.65686562657356, 78.32299321889877, 84.74081844091415, 74.42220613360405, 70.67331969738007, 66.53432339429855, 65.11733382940292, 65.92694878578186, 72.14200168848038, 75.0874288380146, 75.85103586316109, 75.61613246798515, 76.00474521517754, 79.4241513311863, 73.71451690793037, 72.99051135778427, 71.28257900476456, 69.9978755414486, 71.78987458348274, 70.24549305438995, 65.56464582681656, 67.94863790273666, 60.863108709454536, 55.3195595741272, 50.669920071959496, 49.481526240706444, 48.14749762415886, 50.98531074821949, 48.967778608202934, 50.666625648736954, 48.78707930445671, 51.35352239012718, 50.68573862314224, 54.61393743753433, 48.05425822734833, 51.92558169364929, 54.153770729899406, 61.078815534710884, 60.88588088750839, 65.82126125693321, 64.32477995753288, 65.47247797250748, 47.155978828668594, 64.68262955546379, 68.1150233745575, 65.6009490787983, 63.87329578399658, 62.65411980450153, 62.79203720390797, 60.06598748266697, 59.54267576336861, 58.81287172436714, 57.16798558831215, 55.1239612698555, 53.95192936062813, 49.952784553170204, 47.88819953799248, 47.265766337513924, 45.914840027689934, 45.70627681910992, 45.52986368536949, 44.75509285926819, 45.67049793899059, 47.038869112730026, 47.8960233181715, 52.23098650574684, 52.43347004055977, 58.046031072735786, 61.57832533121109, 63.46111290156841, 63.73518079519272, 65.0036895275116, 65.41943281888962, 63.53737100958824, 52.38525062799454, 50.72611145675182, 59.7958067804575, 63.69944371283054, 67.33184739947319, 66.25645190477371, 65.59010446071625, 66.71252623200417, 68.11740964651108, 66.32243156433105, 66.49879530072212, 71.1410441994667, 68.30394923686981, 66.10142022371292, 59.20148067176342, 54.08830024302006, 55.56910738348961, 2.809580401517451, 0.2133398046134971, 0.604270234471187, 2.1984081342816353, 4.880587784573436, 0.6825730483978987, 0.5133419448975474, 0.19712966663064435, 24.939433559775352, 44.76186789572239, 20.776639133691788, 36.12566851079464, 40.18183685839176, 2.7737791975960135, 0.08990581787656993, 0.28734815132338554, 0.06874023369164206, 0.0662174288299866, 0.08735140494536608, 0.05206798632571008, 0.022325290119624697, 0.05682474104105495, 0.07111086859367788, 0.038614140285062604, 0.05720390057831537, 0.0434187375503825, 0.029357068851822987, 0.05088574136607349, 0.03624329016020056, 0.00822464753582608, 0.051619554724311456, 0.04172149405349046, 0.04291844095860142, 0.08012315374799073, 0.046693323165527545, 0.07979749192600138, 0.09781555359950289, 0.05019876123697031, 0.020883868637611158, 0.01973494054254843, 0.001957352806130075, 0.054194139229366556, 0.051110374624840915, 0.04986475396435708, 0.014327496719488408, 0.02149130537873134, 0.050067872361978516, 0.060777111575589515, 0.021955444535706192, 0.07862766680773348, 0.04735322974738665, 0.037555422095465474, 0.0730314725660719, 0.012671261520154076, 0.07073427317664027, 0.015347547159763053, 0.04338530379754957, 0.030732459599676076, 0.0349687925336184, 0.0655445086886175, 0.02304482455656398, 0.024052505250438116, 0.039444666617782786, 0.12581972434418276, 0.05501558909600135, 0.02121887224348029, 0.110174969304353, 0.6849629420321435, 24.87688321620226, 71.48529052734375, 74.1613121330738, 71.41562506556511, 51.638727486133575, 34.18730512261391, 36.192062348127365, 0.8685513376258314, 1.7088998761028051, 3.657086449675262, 7.85464022308588, 4.521524151787162, 0.7320861134212464, 0.20724951813463122, 45.24972751736641, 104.7216434776783, 80.0173071026802, 89.07060250639915, 84.07117277383804, 85.44237479567528, 74.11841243505478, 71.7129135131836, 69.91331487894058, 66.34447798132896, 65.86908549070358, 77.4536682665348, 79.07961621880531, 79.95489165186882, 77.16198071837425, 79.1042996942997, 79.88710328936577, 76.2042573094368, 76.6110634803772, 73.92520040273666, 73.66907894611359, 75.53963497281075, 70.12692421674728, 66.26130804419518, 68.49167436361313, 62.25176319479942, 56.405279114842415, 52.91615813970566, 52.77279183268547, 51.3040566444397, 52.771484702825546, 51.588304191827774, 52.951880022883415, 52.816991060972214, 53.81302401423454, 54.48738522827625, 54.68709111213684, 51.01068578660488, 54.548991322517395, 56.7947544157505, 64.15596261620522, 64.67606350779533, 66.68899789452553, 66.4363494515419, 68.81755247712135, 48.56052026152611, 63.34462635219097, 67.71618917584419, 67.70193234086037, 67.62316256761551, 65.46329006552696, 65.7238420844078, 62.9459897428751, 63.74332755804062, 61.9644758105278, 59.26873326301575, 59.091206789016724, 58.24674390256405, 53.930737897753716, 50.00486455857754, 49.72986951470375, 49.75815139710903, 48.4285419434309, 49.711178317666054, 48.423769399523735, 48.449125438928604, 49.35551360249519, 51.00138768553734, 55.054292008280754, 55.67404255270958, 59.98502142727375, 65.54141387343407, 66.57761827111244, 67.43368953466415, 66.42173543572426, 68.11359465122223, 65.26576906442642, 54.34145025908947, 52.66437225043774, 62.23128229379654, 65.94410866498947, 70.40142148733139, 69.58536967635155, 68.28788369894028, 67.81761333346367, 70.59221684932709, 68.80600869655609, 66.92519322037697, 70.41614949703217, 72.47951477766037, 69.78115797042847, 63.82259890437126, 60.74397750198841, 60.53128391504288, 2.637135679833591, 0.3830832423409447, 2.868336411193013, 3.7898688996210694, 2.7274261973798275, 0.575438984669745, 0.5096469994168729, 0.5928093369584531, 28.51047433912754, 62.85306952893734, 26.29073604941368, 34.839300736784935, 52.487259954214096, 3.448610636405647, 0.052749548776773736, 0.24460494256345555, 0.06506474732304923, 0.03772887685045134, 0.019786636694334447, 0.01761952280503465, 0.0409062559629092, 0.05906302874791436, 0.09924973914166912, 0.03524961750372313, 0.03301424643723294, 0.03938371031836141, 0.02671580237802118, 0.04394549541757442, 0.03299183357739821, 0.012750652767863357, 0.04302116904000286, 0.03355667846335564, 0.056559508593636565, 0.03269647735578474, 0.04020272222987842, 0.023797469912096858, 0.06333194382023066, 0.009291815076721832, 0.1891281717689708, 0.1320628635585308, 0.19101254409179091, 0.08853317121975124, 0.1956990285543725, 0.2173994859913364, 0.14363140217028558, 0.13109449442708865, 0.18285124999238178, 0.11485705283121206, 0.13976634159917012, 0.16639096371363848, 0.10942960812826641, 0.1550536189461127, 0.1343025910318829, 0.11245032728766091, 0.17751286301063374, 0.12647162686334923, 0.14159301936160773, 0.16882676660316065, 0.09148105600615963, 0.15238751278957352, 0.21085090847918764, 0.08247749108704738, 0.1539875238086097, 0.22630264575127512, 0.25303884234745055, 0.15556142607238144, 0.35552881308831275, 1.3712046341970563, 41.18601277470589, 87.59457170963287, 80.17785608768463, 76.96657240390778, 73.9639051258564, 39.240422174334526, 36.29629835486412, 0.6467029138002545, 4.125017328187823, 11.729080472141504, 25.513198971748352, 4.843822382390499, 0.4354672314366326, 0.19426812330493703, 44.27270494401455, 108.8553960621357, 86.94744363427162, 93.39390411973, 85.62633812427521, 90.35240292549133, 80.25305405259132, 73.5455171763897, 71.12085208296776, 70.24548545479774, 70.08970141410828, 78.46882939338684, 82.23160028457642, 82.7787709236145, 80.27017593383789, 82.72056564688683, 84.05279695987701, 79.42171946167946, 78.08486759662628, 77.6367500424385, 75.06947100162506, 77.45468661189079, 75.61700642108917, 69.67465728521347, 72.72329449653625, 66.00967034697533, 59.19279433786869, 55.95750354230404, 55.33359222114086, 53.27064871788025, 54.98382478952408, 54.711839184165, 56.58196963369846, 55.41410230100155, 59.26583781838417, 57.944147139787674, 58.160138949751854, 54.006714820861816, 57.53401234745979, 59.49110113084316, 68.41057151556015, 66.98572397232056, 68.2455463707447, 70.23423045873642, 70.65906286239624, 51.52112379670143, 66.55879408121109, 70.90670317411423, 70.44952690601349, 71.1634173989296, 70.39135202765465, 69.64007154107094, 66.29964798688889, 67.2580249607563, 64.27647694945335, 62.48605862259865, 60.87124787271023, 60.55729731917381, 55.29397174715996, 52.812583297491074, 53.49316097795963, 51.49908497929573, 52.42539547383785, 51.17402382194996, 51.313761323690414, 52.115009129047394, 51.091450452804565, 54.93082903325558, 57.96392887830734, 57.854973524808884, 63.284422382712364, 68.10892850160599, 70.00789180397987, 67.77820944786072, 67.22854614257812, 68.81496861577034, 68.86592388153076, 59.20018874108791, 55.72821244597435, 62.247374430298805, 69.51220080256462, 74.26620930433273, 72.67012014985085, 70.64546719193459, 69.78337705135345, 71.8294532597065, 69.34572413563728, 69.14483651518822, 73.54232534766197, 72.609543800354, 73.06106597185135, 67.67238512635231, 62.09309510886669, 60.57175554335117, 4.423796245828271, 0.3566759655950591, 1.510994026903063, 8.12331335619092, 11.586524471640587, 3.008287651464343, 1.7892743507400155, 0.5419482348952442, 40.04898838698864, 61.297372207045555, 31.74448650330305, 51.45294785499573, 65.2182488143444, 6.740874862298369, 0.43372469837777317, 0.45974810665939003, 0.18328209640458226, 0.331945022335276, 0.20987152587622404, 0.13554879056755453, 0.13845183479133993, 0.14657759485999122, 0.29384090448729694, 0.1497361159999855, 0.1698274043155834, 0.12095461977878585, 0.13194030529120937, 0.17046375141944736, 0.16051748825702816, 0.22047490143449977, 0.2940455888165161, 0.11062606892664917, 0.13015244185226038, 0.13384070800384507, 0.14156499586533755, 0.12831611617002636, 0.26743083726614714, 0.1269520487403497], [0.054409903823398054, 0.027909467135032173, 0.06669911235803738, 0.0544361201900756, 0.03524918334733229, 0.023517377812822815, 0.02136650582542643, 0.019445666221145075, 0.06543199167936109, 0.04799925816769246, 0.015870753850322217, 0.0018185561157224583, 0.010186902691202704, 0.052604277079808526, 0.015873750271566678, 0.059584573027677834, 0.05383756695664488, 0.023564522743981797, 0.0657651417714078, 0.05231277260463685, 0.09746684809215367, 0.06552040373208001, 0.0780538679100573, 0.03238507590140216, 0.05475206358823925, 0.017513928178232163, 0.06608709285501391, 0.07254597439896315, 0.19092219503363594, 0.02520535188523354, 2.181548676453531, 46.784776747226715, 59.31749224662781, 35.85261896252632, 51.08446262776852, 52.9258818179369, 13.348619118332863, 1.6658561420626938, 0.5035867402330041, 3.3779885759577155, 1.815217814873904, 4.800360314548016, 0.0856365317304153, 0.47850499860942364, 0.9326971205882728, 50.71259178221226, 97.74136483669281, 85.97684651613235, 85.44978439807892, 79.59577292203903, 79.12827640771866, 76.50743544101715, 67.11331352591515, 57.71232157945633, 72.73011893033981, 79.20142248272896, 78.00782293081284, 76.79873540997505, 81.12994819879532, 75.83281964063644, 75.2681091427803, 74.87380430102348, 76.06742665171623, 72.10490047931671, 71.49278372526169, 68.36571112275124, 70.32884538173676, 68.91053348779678, 68.07259485125542, 62.54117466509342, 56.12056039273739, 52.10256099700928, 51.65138840675354, 49.299022033810616, 52.028426975011826, 49.401897713541985, 49.80243802070618, 49.78984169661999, 52.05581970512867, 51.5828400850296, 56.22301049530506, 56.412886306643486, 56.738228648900986, 57.535444870591164, 61.520507633686066, 61.30386225879192, 70.40767595171928, 65.69929540157318, 70.4641105234623, 33.23803626000881, 62.179415076971054, 72.491544932127, 66.38370707631111, 65.18789604306221, 59.71606805920601, 57.15148687362671, 55.05710765719414, 53.14792290329933, 54.47030894458294, 53.60699526965618, 50.03687024116516, 50.057985708117485, 49.43034678697586, 47.829834669828415, 46.15932650864124, 46.73094503581524, 44.19409476220608, 45.91384828090668, 47.77055025100708, 46.89909741282463, 48.990015015006065, 49.06812362372875, 52.915914952754974, 56.223983243107796, 57.773346304893494, 60.06465755403042, 64.03607904911041, 65.39003759622574, 65.24047002196312, 67.15841710567474, 66.99418231844902, 55.16018092632294, 55.51663599908352, 62.555119916796684, 66.31102457642555, 65.1270917057991, 65.83705320954323, 67.71447166800499, 71.55670389533043, 64.13403779268265, 70.14464646577835, 69.85148459672928, 69.57254156470299, 64.92609769105911, 64.71976116299629, 48.08242991566658, 62.19971738755703, 20.475902371108532, 0.7373066176660359, 1.283118948340416, 3.6985985096544027, 3.711568401195109, 1.062505398876965, 0.46170963265467435, 0.3322418814059347, 2.538554244674742, 48.93174894154072, 24.21067636460066, 24.160576052963734, 47.06957146525383, 16.094841957092285, 0.269909105845727, 0.10179904609685764, 0.0648351565178018, 0.036744443932548165, 0.0492788951669354, 0.009914776619552867, 0.024307870844495483, 0.06373013573465869, 0.04854336002608761, 0.042980573562090285, 0.04661008388211485, 0.04578904961817898, 0.03492062714940403, 0.04977165153832175, 0.014863018423056928, 0.04191257852653507, 0.08125180451315828, 0.06695987336570397, 0.05136683117598295, 0.051575255929492414, 0.030565956913051195, 0.04357024699856993, 0.07587405401864089, 0.07178175525041297, 0.010150558791792719, 0.07097457317286171, 0.04180516749329399, 0.013356543986446923, 0.01915004653710639, 0.01869765001174528, 0.015856061181693804, 0.019857966362906154, 0.0159349403475062, 0.07075499393977225, 0.04949452246364672, 0.02396089639660204, 0.0763498003652785, 0.02232259797892766, 0.014653901616838994, 0.012511460427049315, 0.0349556676519569, 0.02190320476074703, 0.005845877767569618, 0.0394875775964465, 0.05771866533905268, 0.022107894656073768, 0.04769878483784851, 0.16800589190097526, 0.12108063645428047, 0.05437382802483626, 0.08062282693572342, 0.036707766994368285, 0.061158404787420295, 0.2356072183465585, 0.0528482432855526, 4.194960650056601, 66.95972576737404, 62.03129902482033, 40.40813371539116, 74.24792468547821, 54.55001346766949, 19.78233888745308, 1.6892811725847423, 0.28498936851974577, 4.53886404633522, 2.650834182277322, 8.176296763122082, 1.9928956869989634, 0.6325764593202621, 1.4375570300035179, 58.972432762384415, 101.78182482719421, 86.17611542344093, 85.94340071082115, 82.80660822987556, 81.50064870715141, 75.98491787910461, 68.76487210392952, 61.75637237727642, 76.41068503260612, 83.02296102046967, 81.59105345606804, 80.15754237771034, 80.32159477472305, 76.82738587260246, 76.19983434677124, 78.38211044669151, 78.6084794998169, 76.11221104860306, 73.70100483298302, 69.0354935824871, 74.06469851732254, 69.19403627514839, 69.62310925126076, 66.2860219180584, 59.644221514463425, 54.18867185711861, 53.854092210531235, 52.50438563525677, 54.4743899255991, 51.76683001220226, 53.04972857236862, 52.07681357860565, 54.25261102616787, 54.08753268420696, 59.481271058321, 57.155127078294754, 58.849148377776146, 57.78448350727558, 61.766099855303764, 63.92315670847893, 73.73539298772812, 67.58597016334534, 71.81484684348106, 38.43028664588928, 63.750243186950684, 75.2783913910389, 69.50859099626541, 67.22473874688148, 62.630899250507355, 60.04187397658825, 58.17077457904816, 58.05061362683773, 57.68577240407467, 55.954824686050415, 53.58198881149292, 52.61782854795456, 52.41410627961159, 51.36062800884247, 49.50903296470642, 50.285023525357246, 48.75492922961712, 49.46314662694931, 50.73699027299881, 49.010492116212845, 53.16798582673073, 51.1365008354187, 55.76026372611523, 59.27253305912018, 59.90923069417477, 61.87162019312382, 68.6208826303482, 68.44024792313576, 68.66331875324249, 70.68030372262001, 69.16247516870499, 58.23697842657566, 56.334412917494774, 62.89978042244911, 68.2552282512188, 66.62095874547958, 67.6442514359951, 71.08812063932419, 73.55886965990067, 67.62798070907593, 70.35381004214287, 70.4232931137085, 71.7852920293808, 69.13756370544434, 70.06428077816963, 55.1628065854311, 70.05231142044067, 20.834234543144703, 0.695094148395583, 2.884278930723667, 4.055003235116601, 2.1436449978500605, 1.1396891134791076, 0.8713790983892977, 0.10580717789707705, 3.562827045097947, 60.89815802872181, 40.08009731769562, 23.910712860524654, 52.075685039162636, 25.788072422146797, 0.5112706997897476, 0.1266969577409327, 0.007220770812637056, 0.10481237346539274, 0.07265860273037106, 0.020142438988841604, 0.04220152259222232, 0.07080052469973452, 0.044985641361563466, 0.03399553635972552, 0.0008089237473996036, 0.0373839600069914, 0.05879976670257747, 0.04452959903574083, 0.053956911724526435, 0.0437176078412449, 0.13967148028314114, 0.037189669455983676, 0.05496957594004925, 0.024578550655860454, 0.008266862751042936, 0.07315867667784914, 0.02954380619485164, 0.03663456525828224, 0.012165027746959822, 0.16208217304665595, 0.1283987468923442, 0.18080264038871974, 0.08880877518095076, 0.16781849961262196, 0.15304725238820538, 0.19346072600455955, 0.13755638909060508, 0.23960153135703877, 0.12023628762108274, 0.10356137223425321, 0.10812994427396916, 0.09207432143739425, 0.19978487805929035, 0.13960957032395527, 0.11962242759182118, 0.11682529526297003, 0.06918532933923416, 0.15914261515717953, 0.13033045339398086, 0.34038101497571915, 0.20496572193223983, 0.3694614482810721, 0.18686729308683425, 0.26109957543667406, 0.18022036616457626, 0.23093263793271035, 0.2054030547151342, 0.5691749614197761, 0.493822154821828, 6.02147039026022, 85.93659907579422, 81.49792045354843, 48.17982628941536, 76.77100449800491, 69.84240308403969, 26.235207729041576, 2.7282108552753925, 0.9810865146573633, 9.522282388061285, 5.713631808757782, 15.75453981757164, 1.0499651217833161, 1.0141708049923182, 2.0351983420550823, 57.834557220339775, 105.16323298215866, 90.0049115717411, 92.6049068570137, 85.78048825263977, 84.79595348238945, 81.64431899785995, 72.15766444802284, 64.94465589523315, 80.14100566506386, 87.07744985818863, 85.66350013017654, 83.52513447403908, 86.10891982913017, 79.14749577641487, 77.52842545509338, 81.38746798038483, 83.36073249578476, 79.11480233073235, 76.95017248392105, 72.01474651694298, 77.7660571038723, 73.04660394787788, 72.714334577322, 71.41542747616768, 62.2314190864563, 57.41238847374916, 57.11116723716259, 53.84426973760128, 58.29896830022335, 54.15314756333828, 55.10003015398979, 54.832779094576836, 56.27820633351803, 55.67287601530552, 62.87234589457512, 61.84490002691746, 62.34909877181053, 62.40119777619839, 64.84331533312798, 67.65011072158813, 76.99786752462387, 71.42915233969688, 74.77393046021461, 40.13517536222935, 65.4397465288639, 76.04232519865036, 72.94248193502426, 70.37766516208649, 64.20073941349983, 61.27497240900993, 60.108226016163826, 58.977406695485115, 61.27618074417114, 59.075661823153496, 56.31114296615124, 56.15166172385216, 54.817515313625336, 53.399093225598335, 51.365529745817184, 52.4877767264843, 50.81514447927475, 53.192163929343224, 54.442213252186775, 53.12991186976433, 56.343247443437576, 55.42344979941845, 59.67866666615009, 65.16838788986206, 64.92944911122322, 66.21244266629219, 70.67167058587074, 71.57012477517128, 70.82329005002975, 73.2380984723568, 73.34036618471146, 61.22686319053173, 61.721345856785774, 67.73496776819229, 72.41082966327667, 68.0141007900238, 69.68135252594948, 73.93287599086761, 77.00186491012573, 68.70128631591797, 72.36158430576324, 72.42263182997704, 71.44478470087051, 70.19599691033363, 74.28380995988846, 55.18799543380737, 71.16297662258148, 25.050537697970867, 0.8986729150637984, 3.406066931784153, 11.584551427513361, 10.92918824404478, 5.243561407551169, 6.042530760169029, 0.7762335101142526, 4.821727992966771, 72.27557212114334, 36.85789681971073, 38.87422822415829, 63.24464611709118, 37.438448667526245, 0.5793161422479898, 0.1781276729889214, 0.14118388819042593, 0.20165770256426185, 0.15989442559657618, 0.08416488257353194, 0.15849614515900612, 0.23026564012980089, 0.11127034958917648, 0.15685801743529737, 0.09001622718642466, 0.19683371298015118, 0.18685366725549102, 0.14014485175721347, 0.1535481130122207, 0.1253076721332036, 0.20284031488699839, 0.17044841864844784, 0.1215453544864431, 0.18009605642873794, 0.07747272175038233, 0.22150164790218696, 0.14385284419404343, 0.19459759234450758, 0.12372375829727389], [0.041284766120952554, 0.036947380503988825, 0.021048263624834362, 0.06544133531861007, 0.04002105190011207, 0.02854371581634041, 0.010134620242752135, 0.020878000104858074, 0.053623472194885835, 0.005886988574275165, 0.07388235972030088, 0.06744519341737032, 0.02028863465966424, 0.024934048669820186, 0.025993854105763603, 0.045194878766778857, 0.04221254348522052, 0.06957166915526614, 0.011205967002752004, 0.05440310946141835, 0.022957586952543352, 0.041544220948708244, 0.054847945357323624, 0.07178129511885345, 0.02378260098339524, 0.031173920579021797, 0.052949694872950204, 0.057728235333343036, 0.1459966565016657, 0.31987087335437536, 0.9014306170865893, 22.100355103611946, 71.66254341602325, 42.216414883732796, 29.146233424544334, 58.991230353713036, 39.059741869568825, 1.622422335203737, 0.7986400765366852, 2.1740554785355926, 2.6841560192406178, 3.9282527239993215, 3.263025269843638, 0.024374194726988208, 0.42104831140022725, 0.3479225415503606, 33.80735971033573, 93.27433973550797, 87.77275174856186, 88.14099758863449, 82.39295482635498, 76.98671132326126, 69.04416471719742, 67.81134366989136, 77.90787309408188, 76.2650540471077, 78.84715229272842, 77.51950353384018, 75.65195694565773, 78.74866917729378, 79.90705221891403, 77.38828137516975, 74.04024302959442, 74.1091713309288, 72.19199940562248, 70.11702194809914, 71.28583922982216, 70.58397129178047, 67.87098526954651, 63.965782821178436, 57.16903813183308, 54.62983578443527, 49.88640211522579, 53.02663341164589, 51.10134892165661, 50.44457696378231, 51.29598967730999, 49.91073600947857, 51.15591399371624, 54.674601182341576, 57.1089443564415, 57.861201390624046, 58.75587858259678, 62.14471913874149, 62.93478034436703, 64.49791386723518, 67.06501051783562, 65.19915103912354, 73.25838938355446, 35.37226013839245, 59.06878039240837, 71.56528383493423, 65.56231275200844, 63.48201937973499, 57.233402878046036, 56.55765473842621, 53.508512154221535, 51.74414902925491, 53.507303819060326, 52.936855629086494, 51.64539612829685, 49.21427898108959, 48.810801431536674, 47.50807173550129, 45.6098759919405, 46.62941448390484, 48.98679278790951, 48.43242533504963, 44.768639132380486, 47.489528730511665, 47.758531495928764, 50.60682065784931, 52.99387916922569, 56.21543750166893, 59.00494381785393, 60.02615042030811, 65.42922869324684, 67.84795090556145, 66.80732354521751, 70.09090974926949, 63.60639810562134, 57.602374479174614, 55.119876489043236, 59.71069514751434, 65.63029870390892, 70.14549002051353, 67.27850586175919, 67.86044463515282, 64.14836302399635, 71.50666818022728, 65.95353215932846, 69.0101033449173, 68.51875931024551, 67.56308779120445, 51.28560483455658, 53.78765657544136, 42.91266292333603, 0.16037754889111966, 0.08426342494203709, 1.0410321573726833, 5.623075542971492, 1.8803942925296724, 1.8296522903256118, 0.7110948523040861, 0.3201132290996611, 25.549587719142437, 47.50295341014862, 35.819461941719055, 38.54111149907112, 48.49810481071472, 11.66673056781292, 0.6787561532109976, 0.1902242942014709, 0.08872506834450178, 0.08892555211787112, 0.041132035839837044, 0.047625430961488746, 0.004156807171966648, 0.12498161697294563, 0.05147612726432271, 0.03216823148250114, 0.06107672401412856, 0.039800964295864105, 0.0661445944570005, 0.058751504839165136, 0.08375853445613757, 0.062257046811282635, 0.03783011321502272, 0.03471056967100594, 0.03253585433412809, 0.03414590290049091, 0.09877052696538158, 0.03978985805588309, 0.03628534766903613, 0.0517171694082208, 0.031373825477203354, 0.013221082554082386, 0.017364641462336294, 0.022181131644174457, 0.057383422390557826, 0.03617454873165116, 0.06387662826455198, 0.04500635099248029, 0.09642124365200289, 0.08339080028235912, 0.0277284443291137, 0.07508147740736604, 0.026268595320289023, 0.03900292176695075, 0.059782897151308134, 0.03684086004795972, 0.03878567287756596, 0.04328420101955999, 0.02836835559719475, 0.024285378203785513, 0.022249123503570445, 0.04230004640703555, 0.07153250495321117, 0.005528527999558719, 0.10051670396933332, 0.06512464606203139, 0.046742082267883234, 0.05038570081524085, 0.05162322093383409, 0.007987124099599896, 0.3065995214274153, 0.7331776048522443, 29.89654116332531, 87.08755731582642, 38.20882312953472, 41.26787558197975, 72.31202736496925, 39.18597109615803, 2.84325894434005, 0.09029850305523723, 1.7603709641844034, 1.9634711346589029, 3.966292957775295, 3.920171270146966, 0.2371358496020548, 0.9898898703977466, 0.7985605183057487, 43.77514064311981, 92.94994354248047, 90.46929985284805, 88.63652139902115, 84.55948457121849, 79.08936649560928, 73.44680607318878, 70.44562071561813, 79.00125682353973, 80.13089060783386, 82.96121433377266, 79.42031353712082, 77.76570752263069, 81.61201313138008, 83.70365649461746, 77.65808209776878, 75.85711553692818, 75.64355179667473, 74.92795899510384, 73.09946671128273, 72.43987530469894, 70.33534303307533, 69.39845010638237, 65.02681508660316, 59.642017632722855, 56.708901822566986, 52.0925485342741, 55.27401141822338, 52.478091046214104, 52.824761644005775, 53.5778546333313, 52.59110078215599, 54.46235217154026, 57.076022922992706, 59.159869104623795, 60.07679410278797, 61.54747098684311, 63.61335173249245, 65.71162194013596, 66.19319289922714, 68.90294909477234, 67.20265433192253, 74.54778179526329, 35.14715641736984, 60.511524975299835, 75.43295949697495, 67.2337594628334, 69.43368941545486, 60.34984365105629, 61.6754063218832, 56.3026238232851, 55.065501406788826, 55.49615889787674, 57.4023874104023, 54.46884602308273, 51.73960827291012, 53.04334111511707, 51.832011714577675, 48.49269010126591, 48.50701913237572, 50.20417906343937, 50.77736310660839, 48.95759515464306, 50.56322939693928, 51.28061190247536, 54.140494242310524, 56.356143951416016, 59.16616536676884, 63.20588439702988, 65.97256913781166, 67.70909875631332, 69.24816057085991, 67.42355167865753, 71.69175624847412, 66.12890794873238, 61.01169593632221, 57.697122395038605, 63.934723287820816, 67.45886698365211, 73.90265241265297, 69.04085129499435, 70.00128015875816, 66.46671742200851, 72.33972787857056, 69.58094671368599, 69.69970554113388, 70.64507961273193, 71.5504190325737, 57.08045348525047, 62.09884040057659, 46.236770153045654, 0.2455414884025231, 0.13762816961389035, 1.9696452096104622, 3.0309434607625008, 0.49659642158076167, 0.8144615963101387, 0.6263897975441068, 0.19152720866259187, 29.998083114624023, 62.80024476349354, 36.88369743525982, 33.723171427845955, 62.39371597766876, 13.283492513000965, 0.6372227787505835, 0.16087167081423104, 0.06058231636416167, 0.19002349872607738, 0.02231823600595817, 0.02190013041399652, 0.03336859226692468, 0.09062494413228706, 0.017095360599341802, 0.11273143798462115, 0.06527268225909211, 0.07977569504873827, 0.05693186634744052, 0.02352232793782605, 0.08615129278041422, 0.041748159419512376, 0.019939860503654927, 0.04943676482071169, 0.010845969718502602, 0.07183117486420088, 0.048090015407069586, 0.0330293046135921, 0.03204997396096587, 0.05674160936905537, 0.05812124705698807, 0.1868954798555933, 0.16593624983215705, 0.14367496623890474, 0.11706214427249506, 0.14165525586577132, 0.12092405813746154, 0.1735689418273978, 0.14917787251761183, 0.1366218173643574, 0.0977198536565993, 0.19532249250914901, 0.24098802648950368, 0.10492138753761537, 0.10074082514620386, 0.18258950934978202, 0.14325957134133205, 0.12575255997944623, 0.16944614821113646, 0.08075435776845552, 0.30804299865849316, 0.09988619014620781, 0.1078545481141191, 0.14448138390434906, 0.26015695882961154, 0.17578411905560642, 0.2921843418153003, 0.13955511152744293, 0.1707668593735434, 0.24088296806439757, 0.4339469864498824, 1.1723974021151662, 41.15741930902004, 104.30528461933136, 57.40784011781216, 43.80339972674847, 82.03209578990936, 56.670964658260345, 6.215786738321185, 1.8834730773232877, 6.685161776840687, 11.132671125233173, 14.973505027592182, 7.0328630693256855, 0.18393324193311855, 1.1775185773149133, 0.6935894885100424, 42.215255945920944, 96.93064033985138, 93.72098296880722, 92.58510231971741, 88.05376946926117, 84.53724056482315, 77.47191488742828, 74.34792011976242, 85.14463037252426, 82.96237707138062, 85.1355716586113, 82.97090381383896, 79.71343740820885, 83.91480356454849, 88.23493614792824, 82.92366474866867, 79.0483058989048, 78.63734275102615, 79.13644596934319, 76.6815496981144, 78.48350420594215, 72.87369042634964, 73.50588530302048, 70.85453197360039, 63.23547340929508, 60.7380536198616, 54.66831251978874, 59.80592183768749, 56.67396269738674, 57.57604569196701, 57.93023228645325, 56.876947805285454, 57.33278274536133, 60.95667488873005, 62.763694524765015, 64.73924651741982, 63.60957093536854, 70.2346484363079, 68.00843149423599, 71.82462751865387, 70.1610615849495, 71.94758132100105, 77.13369503617287, 39.671744629740715, 63.345975279808044, 76.94204092025757, 70.91972887516022, 72.20611184835434, 63.982349932193756, 64.42907676100731, 61.489242911338806, 57.212906777858734, 60.3694050014019, 60.76258510351181, 57.62863866984844, 54.02969218790531, 54.31982561945915, 55.31143561005592, 52.17767156660557, 51.47685997188091, 55.927006378769875, 54.61101919412613, 51.23114235699177, 53.87153707444668, 53.82968612015247, 56.52374155819416, 60.52533343434334, 64.2537921667099, 67.18160346150398, 69.7112113237381, 71.04351863265038, 71.1181466281414, 70.33826887607574, 74.82214227318764, 69.77961525321007, 63.636169508099556, 59.63435344398022, 66.09433740377426, 70.06946370005608, 76.85105100274086, 71.79270923137665, 70.38533315062523, 67.2280065715313, 75.73229983448982, 70.16294628381729, 71.72627359628677, 71.78927421569824, 76.68778136372566, 59.39126528799534, 61.95788316428661, 48.55721823871136, 0.48474073118995875, 0.14266193466028199, 4.054622305557132, 16.59376848489046, 6.382917445152998, 5.180281503126025, 1.966494347434491, 0.3220909636002034, 38.95942345261574, 60.41782960295677, 43.66816118359566, 51.7868435382843, 69.82968136668205, 18.237771168351173, 1.1383781838230789, 0.5102251621428877, 0.17131122469436377, 0.3240911109605804, 0.2287185293971561, 0.16545599122764543, 0.2020477902260609, 0.19846201466862112, 0.13267941016238183, 0.131036963139195, 0.14565574354492128, 0.1073017594171688, 0.19591116404626518, 0.10515980247873813, 0.1642711673048325, 0.1201806117023807, 0.14689907839056104, 0.13838005426805466, 0.09589112756657414, 0.15509633696638048, 0.17022001527948305, 0.14213517308235168, 0.15624961961293593, 0.13948882289696485, 0.14552105858456343], [0.053997707582311705, 0.02962757796922233, 0.11133659369079396, 0.0444625682575861, 0.044169531247462146, 0.028152201375633013, 0.08938304905313998, 0.04364996850199532, 0.014716735549882287, 0.040325384397874586, 0.01978750129637774, 0.03961798778618686, 0.07646684447536245, 0.01410401935572736, 0.053883086584392004, 0.030723772761120927, 0.04984753242752049, 0.07857741598854773, 0.008306657637149328, 0.0582180008495925, 0.010156586886296282, 0.061735131457680836, 0.0578362029773416, 0.08207857928937301, 0.05144886818015948, 0.038564909918932244, 0.06613315796130337, 0.08015721832634881, 0.0740354202571325, 0.05928829654294532, 0.07066089703585021, 1.1425310047343373, 49.78112496435642, 70.68255320191383, 39.03041124343872, 38.23976866900921, 65.24394303560257, 12.26111177355051, 0.08557529712561518, 1.4057221007533371, 2.1623884420841932, 2.553491243161261, 5.143603021278977, 0.8992418157868087, 0.14711157011333853, 0.314316462026909, 0.5275039630942047, 21.70816484838724, 92.36824795603752, 85.80732241272926, 87.24872946739197, 84.55380767583847, 72.8116625547409, 64.93086263537407, 81.16256564855576, 81.6807970404625, 81.70795038342476, 81.81254357099533, 78.20129334926605, 77.23811343312263, 76.58007994294167, 78.27597454190254, 78.59578058123589, 75.92817172408104, 73.36056590080261, 71.98446974158287, 71.6758731007576, 69.29878905415535, 69.54867124557495, 62.427230179309845, 60.582767352461815, 56.49591565132141, 52.805663868784904, 53.09431917965412, 50.84335796535015, 51.40546180307865, 49.804759696125984, 51.46246254444122, 53.73485840857029, 60.792113319039345, 62.16341033577919, 59.27934609353542, 61.885603442788124, 63.74591521918774, 65.94286993145943, 66.72362923622131, 69.80215564370155, 68.03689196705818, 71.02223217487335, 31.754291877150536, 57.31476031243801, 72.41970598697662, 64.72539246082306, 62.92025752365589, 57.668506130576134, 57.583535090088844, 53.842362239956856, 51.927736178040504, 49.441970363259315, 49.54475864768028, 47.972748801112175, 49.143389984965324, 48.083607852458954, 49.867969304323196, 48.477346524596214, 47.362383753061295, 47.704319804906845, 50.055721029639244, 47.469583600759506, 47.51737743616104, 47.96331770718098, 48.60881187021732, 54.79719780385494, 55.28541840612888, 56.156153082847595, 63.88070538640022, 66.57570317387581, 66.82705208659172, 65.68604171276093, 67.67676249146461, 69.68851134181023, 59.41664792597294, 57.13648907840252, 60.90377792716026, 68.57479110360146, 67.87701174616814, 69.90894511342049, 72.59337946772575, 70.0075726211071, 68.27112659811974, 69.27441716194153, 71.46216496825218, 64.97775211930275, 60.75993284583092, 46.15505933761597, 56.43458694219589, 2.1526248659938574, 0.07961847848491743, 0.09890440298477188, 2.060246360488236, 1.4393360470421612, 0.6789710198063403, 0.08500129784806632, 0.5737488472368568, 6.779353022575378, 48.099232614040375, 68.29957187175751, 82.38777190446854, 45.09353689849377, 49.16972257196903, 0.6073269329499453, 0.02051549992756918, 0.009077323265955783, 0.051496087326086126, 0.036669783876277506, 0.01911232502607163, 0.03760169871384278, 0.019157852075295523, 0.044277216875343584, 0.06531847277074121, 0.09961904666852206, 0.025270319492847193, 0.015221909907268127, 0.013197226217016578, 0.0302930469479179, 0.02497031742677791, 0.004495684324865579, 0.05557602191402111, 0.018959522385557648, 0.06974746909691021, 0.03699379441968631, 0.08342404107679613, 0.035156522499164566, 0.04640397091861814, 0.0407431430357974, 0.0011011297260665742, 0.07070702893543057, 0.01442470878828317, 0.016116447404783685, 0.06462522520450875, 0.06021372872055508, 0.05246189975878224, 0.04737303395813797, 0.042083187145181, 0.028077912393200677, 0.032492242025909945, 0.03745904308743775, 0.005295950513755088, 0.04776065768965054, 0.0659004352928605, 0.10672831675037742, 0.03387050674064085, 0.04448521118320059, 0.05172081335331313, 0.016469245856569614, 0.0248424639357836, 0.037421008019009605, 0.04555074599920772, 0.028375636065902654, 0.07116258886526339, 0.06371372684952803, 0.016337369925167877, 0.01403711010425468, 0.05608038176433183, 0.18904753000242636, 0.16122779779834673, 0.12203949125250801, 2.077902350574732, 66.06952473521233, 73.11648979783058, 31.89109593629837, 54.64744783937931, 81.09600841999054, 15.66442385315895, 0.062298851989908144, 0.38937077682930976, 2.0516920695081353, 0.5427383549977094, 5.160455591976643, 1.3899861951358616, 0.9356926660984755, 1.1657165293581784, 0.503403281327337, 34.463656693696976, 97.60470137000084, 88.70856553316116, 91.40833586454391, 87.36279174685478, 74.76177871227264, 66.63171216845512, 84.24184441566467, 84.39321309328079, 82.9555070400238, 84.30797606706619, 81.06740355491638, 78.95897269248962, 78.22144746780396, 80.9424814581871, 79.80438932776451, 77.51413062214851, 76.20415851473808, 73.09551492333412, 72.25576758384705, 72.93988287448883, 72.60938420891762, 66.27798154950142, 61.608993485569954, 58.70483212172985, 56.18254266679287, 54.16783757507801, 53.318195566534996, 51.994665786623955, 51.18211358785629, 52.796479761600494, 55.65877117216587, 60.90178303420544, 66.58682137727737, 63.32066483795643, 64.34915944933891, 65.44216319918633, 68.21181178092957, 71.0802474617958, 70.86777806282043, 68.47332894802094, 72.79583260416985, 34.83763262629509, 60.78574486076832, 73.18492412567139, 66.85076281428337, 64.25408855080605, 62.09652252495289, 60.13279929757118, 57.03590087592602, 54.550363048911095, 52.37998031079769, 53.17710913717747, 52.29909785091877, 52.39760756492615, 51.05270013213158, 52.747207805514336, 50.61148680746555, 50.9049716591835, 50.909022241830826, 51.805899515748024, 50.28156191110611, 52.08032079041004, 51.86022140085697, 52.718618139624596, 56.763755679130554, 57.20854461193085, 60.401384085416794, 64.08073425292969, 68.89129132032394, 70.24376034736633, 70.22536173462868, 71.40059307217598, 70.4327318072319, 63.28159533441067, 59.53574113547802, 63.12819376587868, 70.40009155869484, 68.151645809412, 71.71995833516121, 72.37867578864098, 72.08234488964081, 70.34309461712837, 71.69661238789558, 73.45201939344406, 69.75750043988228, 64.06178086996078, 55.889791175723076, 62.09303431212902, 2.207279708236456, 0.0743195514951367, 0.6436990562360734, 1.8176139425486326, 0.39081544149667025, 0.8462710550520569, 0.27374615776352584, 0.8024855295661837, 10.911538191139698, 55.71020521223545, 70.65938204526901, 65.06995037198067, 46.956588327884674, 56.83056369423866, 1.145430605392903, 0.06844468080089428, 0.016258435098279733, 0.006770886921003694, 0.024235977143689524, 0.014456673088716343, 0.019977878873760346, 0.01940581660164753, 0.08277714805444703, 0.0636823488457594, 0.03558006246748846, 0.02202847372245742, 0.012447432563931216, 0.021712457964895293, 0.030010335067345295, 0.061486942431656644, 0.05994442188239191, 0.08652403645101003, 0.0404190211702371, 0.048799007636262104, 0.017295189427386504, 0.01141711079981178, 0.02291700631758431, 0.02157786762836622, 0.03417238644033205, 0.05418730776000302, 0.13037379481829703, 0.14968413597671315, 0.22924356919247657, 0.13838695624144748, 0.07570569781819358, 0.12770789646310732, 0.11652371613308787, 0.20614619686966762, 0.14163986372295767, 0.10947289018076845, 0.13577615492977202, 0.1988214219454676, 0.16721002757549286, 0.10013538849307224, 0.17974938440602273, 0.09345295722596347, 0.08963556480011903, 0.2509900397853926, 0.13551439944421872, 0.16894625237910077, 0.10901582369115204, 0.1606759664718993, 0.12556487083202228, 0.12202692669234239, 0.14470658119535074, 0.1042449644592125, 0.12733572424622253, 0.22358601418090984, 0.32565730973146856, 0.2832698420388624, 0.2941263938555494, 2.751256381161511, 82.82951340079308, 93.91438499093056, 54.873433113098145, 56.19431063532829, 88.46885919570923, 21.891233325004578, 0.17246998439077288, 8.820260558277369, 6.980970678851008, 11.586397178471088, 20.35575471818447, 1.501637741457671, 0.4073516494827345, 0.8487299387343228, 0.3802284674020484, 32.71513491868973, 102.87057280540466, 93.15352141857147, 92.86382496356964, 91.44900128245354, 79.74546208977699, 70.91900691390038, 87.9079332947731, 86.63441643118858, 86.78342163562775, 88.94854545593262, 84.84567001461983, 83.215671479702, 79.746662825346, 83.90386015176773, 83.25028762221336, 82.1244004368782, 79.82628375291824, 76.25702127814293, 73.10876101255417, 78.1629230082035, 75.85662916302681, 69.090795814991, 66.81268125772476, 63.51893439888954, 58.49088840186596, 56.663657650351524, 56.74773193895817, 56.38705149292946, 55.168916657567024, 57.25584827363491, 59.29949641227722, 65.84994971752167, 70.67539438605309, 65.92988222837448, 67.22336322069168, 70.21447151899338, 69.77953165769577, 75.57502627372742, 74.97678637504578, 74.71992015838623, 73.41199234127998, 36.01637877523899, 61.82235963642597, 75.07441073656082, 70.96227899193764, 67.36327171325684, 64.66372177004814, 63.590085580945015, 60.29046803712845, 56.8624933809042, 55.58763138949871, 55.42192988097668, 54.65117163956165, 53.581795021891594, 54.36756245791912, 56.149404644966125, 52.5169363617897, 54.474070742726326, 55.426387041807175, 56.95143520832062, 52.742241472005844, 55.341245010495186, 56.30232743918896, 55.3114166110754, 62.74037517607212, 62.5109738856554, 63.61130364239216, 67.08906322717667, 71.48546531796455, 71.97161883115768, 75.2872297167778, 75.59420004487038, 76.07032209634781, 65.97851201891899, 63.432466238737106, 67.91842952370644, 75.87912395596504, 72.39625364542007, 74.77380126714706, 76.13666653633118, 75.99435657262802, 73.86715471744537, 71.970174908638, 75.42860493063927, 70.11019751429558, 70.62230363488197, 54.3117206543684, 63.757242411375046, 3.4218272985890508, 0.18186266475822777, 1.2440203526057303, 9.690923988819122, 3.8960584765300155, 2.2099155792966485, 0.6416037655435503, 1.4290325436741114, 11.600833553820848, 64.510278403759, 77.75103271007538, 89.79051947593689, 58.976369351148605, 71.1355496942997, 2.000480554997921, 0.3018106799572706, 0.1394670779700391, 0.1528671628329903, 0.1794132063514553, 0.1251739519648254, 0.14753074996406212, 0.09871022004517727, 0.17524889699416235, 0.17507164244307205, 0.1852567880996503, 0.20130895252805203, 0.1255103971925564, 0.06829772813944146, 0.1553231372963637, 0.12213372916448861, 0.1637252583168447, 0.1483101534540765, 0.1045300679106731, 0.15416804380947724, 0.11137607594719157, 0.19794694933807477, 0.1108032269985415, 0.09312715439591557, 0.11098612929345109, 0.13752766797551885], [0.02597810758743435, 0.018415591221128125, 0.026798247563419864, 0.00384134269097558, 0.03661075716081541, 0.0364382412226405, 0.09371518768602982, 0.020452810713322833, 0.02762241925665876, 0.13607708096969873, 0.09831304487306625, 0.06903060639160685, 0.047695890461909585, 0.06260615307837725, 0.023017480125417933, 0.05205693203606643, 0.08950962976086885, 0.036000734035042115, 0.04609613919456024, 0.016043831965362187, 0.04035949350509327, 0.05086407436465379, 0.09171040190267377, 0.0038943044364714297, 0.0976987395551987, 0.1056271477136761, 0.11537530197529122, 0.1482503511942923, 0.06118465826148167, 0.14466092427028343, 0.32331883208826184, 0.6149611389264464, 14.024215266108513, 74.31203484535217, 57.78631120920181, 32.27380380034447, 51.43799185752869, 47.3414658755064, 1.7632026434876025, 0.5624242674093693, 1.342833456583321, 0.7100645732134581, 2.4603523034602404, 4.852181458845735, 0.8228038111701608, 0.20560825854772702, 0.5823608476202935, 0.9656046016607434, 17.720888704061508, 97.4248418211937, 88.84942397475243, 87.04919457435608, 77.83067643642426, 78.42975988984108, 77.99765467643738, 77.10752964019775, 79.90389078855515, 75.32898187637329, 70.64613595604897, 77.08058908581734, 84.37526285648346, 78.82148087024689, 77.81760513782501, 72.76535823941231, 75.71769341826439, 72.69199177622795, 71.64605230093002, 69.79112103581429, 67.40566983819008, 60.5448529869318, 57.76758961379528, 57.77186818420887, 55.49970030784607, 51.5840370208025, 53.48315991461277, 50.520489290356636, 51.43799185752869, 49.32039588689804, 50.92758044600487, 57.192961648106575, 65.176572650671, 61.382806822657585, 62.78083920478821, 64.89215031266212, 69.57731410861015, 63.77162843942642, 70.4627425968647, 65.48554167151451, 75.55016040802002, 28.11972040683031, 56.46601885557175, 76.93782314658165, 66.75890654325485, 63.369325026869774, 55.71767561137676, 54.530889093875885, 49.642364010214806, 51.24868601560593, 50.96789628267288, 49.69418182969093, 47.896034717559814, 48.0709545314312, 50.216969177126884, 48.162491619586945, 49.673902317881584, 50.30685715377331, 50.64380407333374, 49.22712989151478, 48.36529053747654, 48.88547122478485, 51.26862354576588, 50.47187089920044, 51.413612365722656, 56.386979296803474, 58.198710680007935, 61.77924335002899, 66.67474865913391, 72.27547332644463, 71.46704390645027, 68.00189584493637, 69.23335656523705, 64.75935503840446, 63.07343490421772, 59.559284672141075, 66.00840881466866, 70.9190221130848, 74.24739271402359, 67.05626338720322, 72.53382906317711, 73.41508537530899, 74.24523442983627, 67.98984289169312, 73.87839451432228, 49.50425282120705, 58.57308939099312, 9.681922271847725, 0.687198112718761, 0.8905893238261342, 1.0371758393011987, 1.5102892834693193, 0.26618907577358186, 0.12718103098450229, 0.30350212357006967, 2.2075428441166878, 53.041756600141525, 41.497273072600365, 64.82415676116943, 41.51789836585522, 49.47359226644039, 17.83762414008379, 0.6917728297412395, 0.18266902305185795, 0.027186862062080763, 0.15475057036383078, 0.09260569917387329, 0.09231689982698299, 0.014743358242412796, 0.019978177588200197, 0.05494764176546596, 0.03301494776678737, 0.05846754058438819, 0.09669712220784277, 0.020645388758566696, 0.11820809450000525, 0.013896432301407913, 0.02681979396584211, 0.03046282992727356, 0.030636416413472034, 0.051012956610065885, 0.0870880093134474, 0.08439572018687613, 0.035263933532405645, 0.04894609017355833, 0.018560937132861, 0.026807199719769415, 0.025548721350787673, 0.028598690405488014, 0.014570615949196508, 0.04257637025148142, 0.043055600981460884, 0.01981735975277843, 0.037254963608575054, 0.054290477419272065, 0.03343687727465294, 0.043021781311836094, 0.09190046592266299, 0.03345896358950995, 0.05556720891036093, 0.014239797128539067, 0.029401937244983856, 0.05114691055496223, 0.03431375815125648, 0.008618749288871186, 0.03835658535535913, 0.05233580886851996, 0.006738191605109023, 0.07036547031020746, 0.045354373723967, 0.03867915613227524, 0.03402733738766983, 0.04375155367597472, 0.02328088132344419, 0.1313655564445071, 0.08356141261174344, 0.0625049538211897, 0.18696568702580407, 0.2818683406803757, 0.8808645175304264, 17.076281793415546, 94.31455671787262, 51.06466569006443, 34.55205515027046, 73.57460841536522, 54.326919838786125, 2.7490662736818194, 0.9418681659735739, 1.162637744564563, 1.0001577506773174, 1.7668618471361697, 2.4501641001552343, 1.3562283315695822, 0.9262841334566474, 1.9327103602699935, 0.879407711327076, 29.806941971182823, 101.83036342263222, 89.06409725546837, 88.35369497537613, 81.55456781387329, 81.26750081777573, 80.75972646474838, 80.77301815152168, 82.9103122651577, 78.1196965277195, 75.6599061191082, 83.98407384753227, 86.43880292773247, 79.66720148921013, 78.42716842889786, 76.02955028414726, 78.63691717386246, 75.64319461584091, 73.66723984479904, 71.04967430233955, 66.51062026619911, 62.12622173130512, 60.29380805790424, 59.78961691260338, 56.93918466567993, 55.38033351302147, 56.57120481133461, 53.181676492094994, 55.35009853541851, 52.51790151000023, 52.76556082069874, 60.321215987205505, 67.02299237251282, 62.719506695866585, 66.04622438549995, 64.60402697324753, 69.68375399708748, 66.25629991292953, 72.05089777708054, 68.33880856633186, 75.6262019276619, 29.184575267136097, 58.66838067770004, 77.48011484742165, 67.7891756594181, 66.91228151321411, 57.623265758156776, 58.874633610248566, 53.30114208161831, 54.49745088815689, 54.387047812342644, 52.772571444511414, 50.65257020294666, 51.44633620977402, 52.75550656020641, 50.74872024357319, 51.55253291130066, 52.12601713836193, 54.90386947989464, 52.955429032444954, 52.31992073357105, 50.739368945360184, 53.550986275076866, 54.115977957844734, 54.23759803175926, 57.82838635146618, 62.017653957009315, 65.99255606532097, 71.22788473963737, 72.94684410095215, 70.36891803145409, 68.75781208276749, 70.37489131093025, 67.11697652935982, 64.7394897043705, 61.825475469231606, 67.79780879616737, 73.29647853970528, 76.71135529875755, 69.08409297466278, 73.95059823989868, 74.4038987159729, 76.0362759232521, 69.90763798356056, 73.87008056044579, 56.4295370131731, 68.17961990833282, 10.208199732005596, 0.7984034798573703, 2.0993080269545317, 1.7030177917331457, 0.9645791910588741, 0.4865418642293662, 0.4968598246341571, 0.29569597681984305, 4.786732345819473, 59.00833323597908, 58.1516920030117, 67.53908827900887, 41.94206580519676, 59.25191156566143, 24.537008553743362, 0.7842964993324131, 0.12579699978232384, 0.008476320945192128, 0.08330194294103421, 0.016899062538868748, 0.07777959239319898, 0.03132672136416659, 0.10819988427101634, 0.036388777079991996, 0.10281373266479932, 0.028669174025708344, 0.0648861049558036, 0.03394373445189558, 0.10301978254574351, 0.010689582504710415, 0.00797750029960298, 0.023207314079627395, 0.052458304053288884, 0.05557997013966087, 0.02910601513576694, 0.048427722285850905, 0.06196354595886078, 0.03830428991932422, 0.038777917434345, 0.051451179970172234, 0.037569905107375234, 0.17094018054194748, 0.17659262957749888, 0.1595792206353508, 0.08906271585146897, 0.15571120631648228, 0.14693688339320943, 0.15879263315582648, 0.18496401084121317, 0.1483495021238923, 0.21066298184450716, 0.11924325692234561, 0.12873697327449918, 0.15194369363598526, 0.06684657710138708, 0.1225358247756958, 0.10709696376579814, 0.37054916960187256, 0.08365106405108236, 0.11574763746466488, 0.15265478985384107, 0.28092138993088156, 0.13073749170871451, 0.1565061800647527, 0.07394081127131358, 0.11197793544852175, 0.20793922565644607, 0.29168297653086483, 0.27330935932695866, 0.24566737149143592, 0.33948595519177616, 0.5637665453832597, 1.3739440497010946, 24.186682552099228, 109.11501333117485, 72.64099851250648, 43.80421668291092, 70.89223355054855, 67.39764466881752, 3.9885039534419775, 2.1566590620204806, 2.3560431506484747, 4.404855687171221, 5.842256806790829, 13.465147465467453, 1.8247751332819462, 0.26680007111281157, 1.6521970625035465, 0.8078415202908218, 26.605285070836544, 105.61729341745377, 95.47113105654716, 92.4399197101593, 85.56605815887451, 84.7781552374363, 84.37123507261276, 81.71246454119682, 86.00774645805359, 80.10705828666687, 75.91710671782494, 85.26933968067169, 91.0972161591053, 81.9603480398655, 82.28187918663025, 77.87082508206367, 83.39493826031685, 80.69266766309738, 77.40884587168694, 75.21096780896187, 69.32281896471977, 65.39950668811798, 63.094500973820686, 62.55901090800762, 61.5404337644577, 59.04662378132343, 61.67110115289688, 57.59834669530392, 58.22424151003361, 56.08342498540878, 57.994973212480545, 64.13872674107552, 71.06846049427986, 66.1890359222889, 68.30378964543343, 68.68425562977791, 75.8467572927475, 68.57297480106354, 74.0059232711792, 70.55353492498398, 77.95665487647057, 31.72200880944729, 60.973443388938904, 84.95141074061394, 72.11591988801956, 69.47545677423477, 62.45700538158417, 63.02690640091896, 57.38826356828213, 58.604935482144356, 56.49760656058788, 54.76442076265812, 53.365898206830025, 56.03092700242996, 58.59810344874859, 53.840336948633194, 56.051415503025055, 55.16003653407097, 58.136181235313416, 55.87374083697796, 56.382271349430084, 53.363359943032265, 57.51153275370598, 58.253773525357246, 58.58435198664665, 62.10294038057327, 67.45941415429115, 70.8286401629448, 76.71523109078407, 77.81777992844582, 72.40010663866997, 71.11005306243896, 74.67764362692833, 70.65441191196442, 67.41338342428207, 64.4178369641304, 73.21444094181061, 76.45031690597534, 79.3165411055088, 69.70948621630669, 76.30078732967377, 76.58976942300797, 79.43722262978554, 69.61117029190063, 82.39866212010384, 60.513455271720886, 70.54962873458862, 12.647452242672443, 0.8105482812970877, 4.6749836672097445, 3.07456037029624, 5.20518584176898, 2.711390107870102, 1.4345461665652692, 0.7358974870294333, 3.731547729112208, 73.85445579886436, 54.408607855439186, 75.8443634212017, 53.41987431049347, 74.4720746576786, 33.47880274057388, 1.1665954696945846, 0.2201424044324085, 0.24238877085736021, 0.2841207291930914, 0.09688629565062001, 0.24521053506759927, 0.158386574476026, 0.2737285243347287, 0.25892520148772746, 0.1851810296648182, 0.12003123221802525, 0.21031850657891482, 0.13008846872253343, 0.22451031458331272, 0.14549106097547337, 0.0753730078577064, 0.09087311831535771, 0.1888092709123157, 0.21185255551245064, 0.12947098701260984, 0.1637082631350495, 0.23981239035492763, 0.1516815522336401, 0.10818012829986401, 0.2093063062056899, 0.09834210737608373], [0.03299587086075917, 0.06725115890731104, 0.029834310626029037, 0.00937509146751836, 0.06668765359790996, 0.020992643367208075, 0.028720860900648404, 0.027484639540489297, 0.031761523423483595, 0.06434895331040025, 0.03576316885300912, 0.011849425736727426, 0.07381129908026196, 0.1524572746711783, 0.017496085092716385, 0.09410852595465258, 0.027422332532296423, 0.042377649078844115, 0.06311553355772048, 0.015605855369358324, 0.041548054141458124, 0.07486652175430208, 0.013612247257697163, 0.08121390303131193, 0.08293476537801325, 0.022118652086646762, 0.020975817024009302, 0.013222869274613913, 0.07482971122954041, 0.016256429444183595, 0.02921816849266179, 0.07584700273582712, 0.24674789397977293, 38.04676942527294, 74.03489291667938, 45.89641861617565, 39.01474088430405, 80.42010828852654, 28.226316086947918, 0.5312202230561525, 0.629987670108676, 0.3392482304479927, 1.1832550819963217, 1.1591127212159336, 4.420168390497565, 0.528783603804186, 0.7951388612855226, 1.2673665373586118, 0.41242526785936207, 40.15773095190525, 99.82103124260902, 92.44421347975731, 89.04833570122719, 70.45866161584854, 80.39704352617264, 81.05811685323715, 82.94954136013985, 76.95480063557625, 81.54610186815262, 78.9083594083786, 78.11183094978333, 80.30007272958755, 81.5397410094738, 76.25214993953705, 77.00204730033875, 74.23086360096931, 71.14707827568054, 70.52975580096245, 66.04919582605362, 60.21962083876133, 59.90049496293068, 61.750725880265236, 58.94537441432476, 55.01511991024017, 55.204676538705826, 54.1679135710001, 52.30308763682842, 51.90549977123737, 51.924152970314026, 59.595147147774696, 64.9518983066082, 66.03096440434456, 64.78029191493988, 66.13099783658981, 70.01971676945686, 69.76218178868294, 73.2294425368309, 61.450815573334694, 60.22247068583965, 24.237204641103745, 57.3686034232378, 75.10868489742279, 65.57206302881241, 67.12055593729019, 59.46805536746979, 57.81492367386818, 52.60107144713402, 51.767217591404915, 47.30921320617199, 49.23384793102741, 48.062667176127434, 49.42006453871727, 49.091192185878754, 49.872152879834175, 49.5711862295866, 50.288865119218826, 47.57277086377144, 52.173947766423225, 51.071718111634254, 49.35630016028881, 47.723466977477074, 48.96822698414326, 47.13464677333832, 54.55284431576729, 57.78339296579361, 61.85724176466465, 70.10482460260391, 69.70711514353752, 70.22474616765976, 68.86676743626595, 72.70931884646416, 66.6963467001915, 61.56420148909092, 61.62006989121437, 63.31575930118561, 67.37337917089462, 69.27428036928177, 75.57155326008797, 71.40560880303383, 74.21019271016121, 80.52059769630432, 75.38666278123856, 47.5681921094656, 68.81189838051796, 18.065385818481445, 0.16903864976484329, 1.881108891684562, 0.8685259858611971, 0.5396105884574354, 0.28696164081338793, 0.09468961274251342, 0.30066361650824547, 2.1443693339824677, 33.75521890819073, 57.617759853601456, 8.469522278755903, 24.323969185352325, 33.46413552761078, 48.35648261010647, 1.1883469275198877, 0.014690303032693919, 0.046880767404218204, 0.039000702745397575, 0.008537919202353805, 0.015087265765032498, 0.055007436603773385, 0.03707996889716014, 0.05264869090751745, 0.0406854670291068, 0.01696166640613228, 0.07448823424056172, 0.04539212677627802, 0.02360678990953602, 0.03383728449989576, 0.022234438256418798, 0.03760854131542146, 0.06313517820672132, 0.03479680723103229, 0.12688501796219498, 0.06307971008936875, 0.07637626535142772, 0.06152647292765323, 0.009825666020333301, 0.048123200540430844, 0.049822566579678096, 0.02486552060872782, 0.03474311655736528, 0.07032609937596135, 0.01506009388322127, 0.01803828519769013, 0.06515125205623917, 0.06477182163507678, 0.06311324774287641, 0.05024268524721265, 0.06062627006031107, 0.008464931761409389, 0.020154810590611305, 0.041319780648336746, 0.05221034138230607, 0.09302390681114048, 0.01826256964704953, 0.013787958141620038, 0.08249493155744858, 0.017344145198876504, 0.07403177631204017, 0.03309187879494857, 0.0724733923561871, 0.049267206341028214, 0.039280893179238774, 0.011882224025612231, 0.04236442400724627, 0.03979591027018614, 0.009343236633867491, 0.05554389063036069, 0.08372892276383936, 0.05974649480776861, 0.026979671129083727, 0.02922148774814559, 0.6299901637248695, 49.47529077529907, 86.34225770831108, 33.339175432920456, 62.280447855591774, 105.11875256896019, 32.449757158756256, 1.3209060207009315, 1.2721615238115191, 1.4037663931958377, 0.8952972711995244, 1.220519682392478, 1.6161128925159574, 2.514458312653005, 2.4657767498865724, 1.8292901222594082, 0.46501406002789736, 49.53059680759907, 105.01200869679451, 94.34237122535706, 86.31478518247604, 72.70493388175964, 84.79791417717934, 83.62364798784256, 83.52317377924919, 79.88466382026672, 83.69436219334602, 79.56174194812775, 79.96691420674324, 84.57776919007301, 84.16103035211563, 76.93732157349586, 77.5367622077465, 74.85118791460991, 73.71979102492332, 74.18386772274971, 70.45800045132637, 62.31830142438412, 62.63632535934448, 63.02946366369724, 60.82344263792038, 55.90614549815655, 56.60330168902874, 53.85119676589966, 54.8066820949316, 54.55831602215767, 54.301271215081215, 61.36897176504135, 68.45564469695091, 69.23330336809158, 68.35851430892944, 68.59271854162216, 70.77515423297882, 70.56140050292015, 76.52290061116219, 62.928674072027206, 61.86451457440853, 28.350121043622494, 59.5544171333313, 79.13067027926445, 69.18733343482018, 68.75279635190964, 61.462427750229836, 58.91049228608608, 55.529597103595734, 55.6068279594183, 51.15505903959274, 50.4649742692709, 50.40277160704136, 52.45859049260616, 50.136215910315514, 53.65492969751358, 51.94735832512379, 53.22380483150482, 49.63427044451237, 53.04068885743618, 50.89753545820713, 52.50287711620331, 51.93746365606785, 52.545115649700165, 51.163566783070564, 57.657513320446014, 61.68746307492256, 64.90131542086601, 71.4171601831913, 71.60056874155998, 74.92417439818382, 71.67113855481148, 75.29242783784866, 70.77235758304596, 62.71688863635063, 62.997480779886246, 66.0881969332695, 68.64362820982933, 71.18895202875137, 76.01567342877388, 75.42114973068237, 76.30594745278358, 78.19423332810402, 75.71096017956734, 55.16955882310867, 76.44164577126503, 19.450312703847885, 0.26093796535860747, 3.6558206425979733, 1.905502276495099, 0.6737466563936323, 0.03870446336804889, 0.08779658965067938, 0.39882357115857303, 4.884118270128965, 37.5983364880085, 82.54087328910828, 22.569880709052086, 30.10390743613243, 40.42242854833603, 59.45629499852657, 2.486246726475656, 0.3105291340034455, 0.08521666910382919, 0.024570837886130903, 0.04454761467059143, 0.03379388741450384, 0.0619528516108403, 0.05359626135032158, 0.04852725542150438, 0.044109409864176996, 0.059803243129863404, 0.020736552323796786, 0.07962406685692258, 0.00994046698906459, 0.05943068870692514, 0.1053370421868749, 0.0010205629860138288, 0.045097746478859335, 0.0210028404762852, 0.083400210714899, 0.04349192444351502, 0.0918441369140055, 0.062167948271962814, 0.02148915871657664, 0.01669952314841794, 0.07479496387531981, 0.015159434060478816, 0.1445236269501038, 0.13333913491806015, 0.09179577114991844, 0.08586547686718404, 0.13522390800062567, 0.19524683797499165, 0.20475076627917588, 0.11765846735215746, 0.10990946597303264, 0.16603927477262914, 0.06731345478328876, 0.1959164036088623, 0.17209846526384354, 0.18201710568973795, 0.10461080615641549, 0.2368566091172397, 0.11965832527494058, 0.1180484214273747, 0.14527827239362523, 0.0939366445527412, 0.12418668033205904, 0.22081648232415318, 0.15649941167794168, 0.1856460445560515, 0.17290264164330438, 0.16786243475507945, 0.12839521426940337, 0.13019164209254086, 0.1955387246562168, 0.16386978415539488, 0.18237384123494849, 0.11027282147551887, 0.9025640843901783, 66.08583346009254, 103.13607215881348, 60.37610784173012, 61.01337544620037, 100.14260038733482, 47.39436663687229, 1.1915872036479414, 1.6412042523734272, 2.218704982660711, 4.733427381142974, 3.4939336543902755, 17.224762625992298, 5.737591423094273, 1.546924898866564, 2.1607386181131005, 0.43143164017237723, 49.97454598546028, 107.94019997119904, 98.21888521313667, 91.8652081489563, 75.70469051599503, 86.80391013622284, 87.14212998747826, 88.20751681923866, 84.71799686551094, 89.37477618455887, 84.86499577760696, 79.75427761673927, 87.90446788072586, 88.24941337108612, 82.09697350859642, 82.65740543603897, 78.76054733991623, 75.92043533921242, 78.79650101065636, 74.74108502268791, 66.39310017228127, 68.37995275855064, 68.78077045083046, 65.06307274103165, 59.64230261743069, 60.99427007138729, 58.812145963311195, 58.166013434529305, 56.94589130580425, 57.49620817601681, 66.33354976773262, 72.6763366162777, 73.37036177515984, 71.68053925037384, 72.77529090642929, 73.66970211267471, 76.80093169212341, 80.9160652756691, 65.16165465116501, 58.456344455480576, 30.471934787929058, 61.25314258038998, 81.240803450346, 73.761877566576, 72.26865649223328, 65.37312090396881, 63.139038383960724, 57.070688009262085, 59.89101067185402, 54.5862103253603, 53.613644912838936, 53.67913819849491, 57.070353627204895, 55.378650203347206, 57.239892929792404, 55.37153698503971, 56.954665035009384, 53.57762284576893, 58.52914474904537, 56.998803466558456, 56.749221459031105, 54.17386405169964, 55.68611830472946, 52.771868482232094, 62.527499198913574, 65.45571327209473, 68.30600872635841, 75.5841913819313, 77.60117635130882, 78.10290902853012, 76.01315796375275, 78.42503294348717, 75.36006420850754, 67.68641397356987, 69.03822183609009, 67.84022212028503, 70.31170830130577, 74.61375385522842, 81.00270822644234, 76.1681592464447, 77.453493475914, 80.4658654332161, 82.62637630105019, 60.076402723789215, 76.39381393790245, 22.54507753998041, 0.4289468703791499, 2.3007812909781933, 5.144420927390456, 2.2069667000323534, 0.6368227314669639, 0.37286131584551185, 0.6825624208431691, 3.9683289360255003, 52.56403863430023, 73.06516215205193, 17.580022662878036, 38.0406441539526, 47.68331453204155, 74.39689949154854, 2.9829251999035478, 0.5354819912463427, 0.1583035133080557, 0.11020301506505348, 0.16383181588025764, 0.13983179902425036, 0.14849243976641446, 0.11645884500467218, 0.11337257936247624, 0.12414930577506311, 0.24184716632589698, 0.13276873505674303, 0.2116918211686425, 0.1305083610350266, 0.12463984312489629, 0.15985519567038864, 0.14358953019836918, 0.15547420887742192, 0.10803465251228772, 0.19921761006116867, 0.24474685604218394, 0.32628317771013826, 0.19182054995326325, 0.14601038623368368, 0.11185231953277253, 0.14405901281861588, 0.11364070989657193], [0.024265386600745842, 0.055859373896964826, 0.01854802747402573, 0.02259103650430916, 0.051624386105686426, 0.016298486953019165, 0.014467559467448154, 0.023378234400297515, 0.050545377598609775, 0.07369942031800747, 0.04021008804556914, 0.07834721662220545, 0.04495942499488592, 0.08665857298183255, 0.06520813767565414, 0.057795206739683636, 0.09432042395928875, 0.07412551698507741, 0.059911047501373105, 0.03130264980427455, 0.04739311647426803, 0.04031079377455171, 0.091343313397374, 0.03729443844349589, 0.10138393321540207, 0.14535321446601301, 0.019076837379543576, 0.03604006415116601, 0.052246242776163854, 0.046032492609811015, 0.1625163442804478, 0.2738672762643546, 0.620287146884948, 4.999185595661402, 69.50224533677101, 65.65361425280571, 30.48675399273634, 31.356700211763382, 86.76667973399162, 24.782439284026623, 1.9191310764290392, 0.8240681933239102, 0.5966979532968253, 0.6383848038967699, 0.6021690659690648, 4.781971676275134, 2.0790140284225345, 1.4038479700684547, 0.3912981046596542, 7.1512851398438215, 86.13493323326111, 93.03242951631546, 89.23402413725853, 91.25173106789589, 80.3915186226368, 77.22698763012886, 74.58821922540665, 74.86394762992859, 72.3082123696804, 83.0671526491642, 85.79900845885277, 82.06579998135567, 74.70572412014008, 79.08134132623672, 75.08967071771622, 77.7732615172863, 70.00374242663383, 65.59311389923096, 66.64247319102287, 61.45269647240639, 59.009674564003944, 63.96750792860985, 59.457609727978706, 57.22109153866768, 55.684731379151344, 55.563263297080994, 52.519322633743286, 53.892971724271774, 51.60392515361309, 55.5010112375021, 64.68947678804398, 68.52984711527824, 66.1721496284008, 68.64558890461922, 69.0050496160984, 72.49492675065994, 69.94493678212166, 66.99880287051201, 64.28346857428551, 23.718965649604797, 54.50485669076443, 76.7056556046009, 68.34588378667831, 68.97965177893639, 64.52310651540756, 65.88999196887016, 59.42032612860203, 54.95631046593189, 50.665991082787514, 51.47233821451664, 48.71417261660099, 51.878506019711494, 49.35863323509693, 50.40896147489548, 50.33179521560669, 55.866980999708176, 58.4610828012228, 60.672009363770485, 58.797182366251945, 59.317670837044716, 56.45775429904461, 55.91463804244995, 49.63496960699558, 50.11709913611412, 56.51709571480751, 63.515172600746155, 65.24625331163406, 72.89522767066956, 73.54428604245186, 70.00528514385223, 70.34711480140686, 73.19490239024162, 65.06770089268684, 66.24955147504807, 64.50141727924347, 70.42422026395798, 69.98528301715851, 69.24319803714752, 74.73099276423454, 81.4737917482853, 66.24168589711189, 57.64332868158817, 77.25227147340775, 24.79925148189068, 0.061996270960662514, 0.8077424287330359, 2.763919676654041, 0.3328087041154504, 0.4462105018319562, 0.0795020503574051, 0.14679799787700176, 5.716370511800051, 31.08633141964674, 66.1170069873333, 9.53825293108821, 29.649400524795055, 42.386691346764565, 53.32346208393574, 8.531294614076614, 0.3459431149531156, 0.02377036667894572, 0.057290550030302256, 0.10014968225732446, 0.038522555551026016, 0.05353123808163218, 0.05357190777431242, 0.0892325043969322, 0.05094393316539936, 0.05665977645548992, 0.059321322114556096, 0.0594822642597137, 0.024437390457023866, 0.03859051030303817, 0.059066064131911844, 0.05802851570479106, 0.022856170617160387, 0.07684427851927467, 0.03942135204852093, 0.03076186349062482, 0.002294864175382827, 0.04032112818094902, 0.05182493296160828, 0.0465166103822412, 0.03664676987682469, 0.034358439152128994, 0.02186123816500185, 0.026729127639555372, 0.02825245253916364, 0.0751495620352216, 0.04876352926658001, 0.03710783283167984, 0.031171085574897006, 0.05491504292876925, 0.026344157085986808, 0.028935079972143285, 0.04060628358274698, 0.04266055206244346, 0.04029246272693854, 0.022117900662124157, 0.02672523507499136, 0.024899141753849108, 0.016148098147823475, 0.08819444759865291, 0.021504367177840322, 0.07522211439209059, 0.06673255353234708, 0.02788934565614909, 0.015786358671903145, 0.05889246836886741, 0.1184192874643486, 0.03306297956441995, 0.11102542601292953, 0.03850752706057392, 0.11989399426965974, 0.028556298930197954, 0.04295398612157442, 0.1568495569517836, 0.3942569880746305, 0.8380683045834303, 8.515881691128016, 83.53660985827446, 64.12840649485588, 23.744629472494125, 70.01258835196495, 103.6271046102047, 32.07940623164177, 2.9297109553590417, 0.9823372412938625, 0.9919712087139487, 0.14158823993057013, 0.7562816713470966, 0.6412014621309936, 2.594410772435367, 3.5010157618671656, 0.2722698776051402, 9.733743891119957, 92.46877536177635, 95.55960550904274, 99.63329091668129, 92.02305927872658, 82.59939014911652, 78.88637378811836, 79.37074139714241, 77.56182566285133, 77.87626639008522, 87.44170591235161, 87.02105328440666, 81.65933579206467, 78.86555850505829, 81.57408356666565, 78.71985152363777, 79.830022752285, 72.41221278905869, 66.98921218514442, 65.45476332306862, 63.844158947467804, 61.700560972094536, 65.0417710840702, 62.92005993425846, 61.52723707258701, 56.74279600381851, 58.658812791109085, 56.42118886113167, 57.85367779433727, 53.35577555000782, 59.093437269330025, 67.12101951241493, 71.00029215216637, 66.46020457148552, 68.83522152900696, 70.582534968853, 73.27985063195229, 71.06496468186378, 70.10237753391266, 63.02987024188042, 25.45908037573099, 57.19606228172779, 78.0170488357544, 68.91927301883698, 74.07707065343857, 68.50162982940674, 70.19637688994408, 62.20421254634857, 56.09221391379833, 53.533750399947166, 55.5474029481411, 52.69353948533535, 53.275858238339424, 53.57434742152691, 52.051142156124115, 53.57690088450909, 57.77574397623539, 60.38662567734718, 63.06833557784557, 62.275774106383324, 60.47106854617596, 56.52992382645607, 57.736226096749306, 50.8309668302536, 54.12423111498356, 61.37409009039402, 66.82687729597092, 69.62960690259933, 71.5655954182148, 71.14245012402534, 70.67457363009453, 68.2277101278305, 73.08832570910454, 69.11293342709541, 68.75341191887856, 66.4779344201088, 72.88276433944702, 73.61142843961716, 70.40412694215775, 74.54652786254883, 79.96496111154556, 68.48956927657127, 59.691152796149254, 83.55253860354424, 26.437529772520065, 0.04463816781935748, 2.2148042544722557, 3.391574746929109, 0.2584030560683459, 0.18336610752157867, 0.04434413633134682, 0.33176453202031553, 11.791418977081776, 33.46344396471977, 93.81154730916023, 26.889270432293415, 16.54432363808155, 41.19102470576763, 61.405309215188026, 14.121934622526169, 0.8485200593713671, 0.1328592177014798, 0.1818369864486158, 0.08087071910267696, 0.04489018632739317, 0.046673481847392395, 0.023874046564742457, 0.045930083651910536, 0.0351999158738181, 0.031011902319733053, 0.01687073105131276, 0.011294880932837259, 0.030622361991845537, 0.018986030045198277, 0.021004783047828823, 0.07008522792602889, 0.027141605896758847, 0.05005011647881474, 0.029710188282479066, 0.010338831452827435, 0.053838528037886135, 0.02934824657131685, 0.04325519417761825, 0.07726366617134772, 0.03704676521010697, 0.05807753826957196, 0.06452155459555797, 0.1750993393943645, 0.17645767744397745, 0.13393408502452075, 0.06254562351386994, 0.14529194275382906, 0.1162205265427474, 0.1833387222723104, 0.15870065137278289, 0.12831480999011546, 0.17189495352795348, 0.11322721489705145, 0.13099963311105967, 0.12785798840923235, 0.13365226186579093, 0.10959558945614845, 0.10681105137336999, 0.21742880082456395, 0.13043272134382278, 0.2399795813835226, 0.1396018816740252, 0.1726785278879106, 0.35053549509029835, 0.16178945516003296, 0.20294509129598737, 0.15963598008966073, 0.35535322094801813, 0.2233723201788962, 0.20819062076043338, 0.14778662764001638, 0.47201301727909595, 0.49070614390075207, 0.8195921522565186, 1.3713975925929844, 10.764610525220633, 100.85961431264877, 85.89771956205368, 41.98198266327381, 52.32550263404846, 107.34491631388664, 46.47242210805416, 2.540882332250476, 1.0310253943316638, 1.9059995748102665, 2.9708458855748177, 2.55980484187603, 15.939333401620388, 11.560533866286278, 2.6572197396308184, 0.41240876249503344, 10.969625674188137, 92.83544048666954, 98.2586082816124, 99.69584316015244, 97.28304862976074, 85.8275905251503, 82.77906730771065, 82.54222601652145, 80.46084210276604, 78.94953399896622, 89.61931586265564, 91.08071744441986, 85.55899813771248, 81.09406292438507, 85.7595057785511, 83.05032715201378, 85.46762064099312, 78.17519634962082, 70.0405016541481, 71.91438630223274, 69.10599499940872, 65.54475769400597, 71.04039520025253, 65.2322168648243, 62.63927020132542, 61.668163910508156, 63.88787940144539, 59.19841043651104, 62.354494482278824, 58.4982106089592, 62.09452383220196, 71.67732462286949, 74.17790964245796, 69.7455082833767, 73.09994548559189, 75.33452957868576, 76.93667560815811, 74.47190746665001, 70.93088507652283, 66.28538355231285, 29.91789221763611, 59.80404853820801, 82.14505612850189, 75.23996785283089, 76.73087865114212, 72.63640075922012, 75.39024978876114, 67.53223344683647, 62.08166912198067, 57.462454587221146, 58.02478261291981, 56.33221283555031, 57.23943695425987, 57.52589598298073, 56.41293190419674, 58.87979373335838, 62.1821965277195, 67.38720282912254, 67.4992436170578, 66.34438678622246, 65.50209358334541, 61.3536623865366, 63.40051755309105, 57.19595588743687, 58.669273629784584, 65.93128055334091, 73.23948159813881, 74.80132699012756, 76.08878150582314, 73.81030976772308, 73.35350587964058, 75.95483109354973, 78.7152461707592, 73.0107718706131, 74.13168132305145, 71.2417919933796, 77.98417299985886, 75.8709467947483, 74.41149070858955, 77.77735769748688, 82.10839569568634, 73.13538238406181, 65.2143882215023, 80.96361592411995, 28.722776547074318, 0.2136249080649577, 1.6302969376556575, 5.872684624046087, 1.5006204647943377, 0.7583034597337246, 0.5920186231378466, 0.567490701796487, 9.11191200837493, 48.1319260597229, 84.03406396508217, 17.81771130859852, 39.916694685816765, 57.42422863841057, 76.75059959292412, 18.27793501317501, 1.2267811526544392, 0.2575680211884901, 0.27971750765573233, 0.17726313031744212, 0.17986707418458536, 0.08521460593328811, 0.16133575059939176, 0.16086242365418002, 0.12663574540056288, 0.12313007726334035, 0.2009442017879337, 0.1267762339557521, 0.15995097724953666, 0.171190774126444, 0.10145132022444159, 0.18458935985108837, 0.1106634212192148, 0.17208194505656138, 0.10503508456167765, 0.1125710598716978, 0.16070599376689643, 0.18187862093327567, 0.2814983652206138, 0.1477267808513716, 0.17043143830960616, 0.1740309435990639, 0.10759183525806293], [0.11544458146090619, 0.06089630049245898, 0.017580810526851565, 0.03967159311287105, 0.05926316742261406, 0.015715819390607066, 0.05414457118604332, 0.06395107309799641, 0.016839763084135484, 0.04200059353024699, 0.0682429205335211, 0.02570749642472947, 0.032161808194359764, 0.0441972504631849, 0.014073115398787195, 0.04750171494379174, 0.053730794170405716, 0.028222169203218073, 0.041532287214067765, 0.03470096999080852, 0.0740104989381507, 0.062025444785831496, 0.04269212302460801, 0.030501334404107183, 0.037935223590466194, 0.049069308952311985, 0.054777678815298714, 0.018569824351288844, 0.0821807433385402, 0.05610478729067836, 0.09661868461989798, 0.28285747510381043, 0.5648042459506541, 0.9414853365160525, 25.68095237016678, 81.66361436247826, 66.6689957678318, 32.291545048356056, 32.35138803720474, 91.7425811290741, 26.136669516563416, 4.003734011203051, 0.43224221386481076, 0.2973407838726416, 0.4796603147406131, 0.22407937911339104, 2.5332886772230268, 3.2548217475414276, 0.19546691444702446, 0.6704584672115743, 21.14982470870018, 106.01953223347664, 92.5373312830925, 78.94522503018379, 82.40937754511833, 84.87150102853775, 83.43515530228615, 83.361104875803, 88.12748551368713, 81.21453925967216, 79.56405982375145, 78.94065007567406, 85.49036622047424, 81.44391015172005, 82.05187752842903, 70.21452471613884, 71.77360385656357, 65.94405546784401, 67.21543684601784, 65.04896029829979, 65.31740069389343, 62.96045556664467, 64.00143250823021, 60.20692951977253, 61.66635520756245, 59.53725345432758, 58.42273525893688, 53.96036870777607, 56.406384855508804, 55.6208112090826, 66.60668671131134, 69.14264783263206, 74.07298967242241, 68.77236530184746, 73.53683084249496, 68.05082201957703, 73.0932654440403, 66.2120170891285, 80.71304976940155, 24.164708331227303, 47.10034981369972, 75.74747622013092, 64.73398759961128, 73.58969360589981, 67.47458294034004, 68.07663783431053, 62.72563956677914, 62.63075865805149, 54.12002854049206, 52.057461217045784, 51.853286772966385, 51.72525644302368, 51.763915568590164, 56.73547379672527, 64.1710402071476, 65.62074601650238, 67.02230840921402, 69.12662029266357, 67.21121907234192, 64.3698151409626, 64.9272908270359, 64.36858400702477, 62.21090018749237, 56.549720764160156, 55.555545911192894, 58.945412412285805, 66.51898741722107, 69.32799428701401, 73.71524646878242, 71.66754394769669, 72.71247267723083, 69.55203786492348, 71.49662151932716, 71.83311626315117, 72.42339938879013, 68.22219282388687, 71.39888316392899, 80.4688748717308, 72.97216594219208, 69.12280529737473, 77.042917907238, 78.65319550037384, 16.403953470289707, 0.11822885979199782, 0.5951806472148746, 0.6595335784368217, 0.21515955071663484, 0.5957760277669877, 0.1903966357349418, 0.27068690629675984, 10.09737677872181, 29.589817821979523, 77.88762018084526, 11.521718949079514, 31.62549588829279, 59.33395676314831, 57.13711604475975, 16.705127209424973, 0.25019997905474156, 0.08275259780930355, 0.07755742306471802, 0.0831947174447123, 0.06754732778063044, 0.02394763421762036, 0.08679058621055447, 0.05701726899133064, 0.0859574438072741, 0.040323603243450634, 0.03516474178468343, 0.042796710185939446, 0.048475542571395636, 0.05732952762627974, 0.040688268636586145, 0.054028566082706675, 0.04147944629949052, 0.013349089113035006, 0.04361768878879957, 0.03765429100894835, 0.03352069172251504, 0.10106441637617536, 0.028926602790306788, 0.0701047241454944, 0.024370198261749465, 0.0423689548188122, 0.060574690796784125, 0.06699581557768397, 0.032627702530589886, 0.04150096487137489, 0.03423172856855672, 0.10713453128118999, 0.02558624433731893, 0.007817850419087335, 0.07621161988936365, 0.05667994431860279, 0.04903773427940905, 0.05566890540649183, 0.021933285861450713, 0.05135814062668942, 0.054462648258777335, 0.018688970594666898, 0.05351372339646332, 0.04648860172892455, 0.03813690593233332, 0.029036778323643375, 0.06344285779050551, 0.044585226714843884, 0.03825537867669482, 0.053565714551950805, 0.11317186552332714, 0.024207840469898656, 0.022049396720831282, 0.039572850364493206, 0.048896358857746236, 0.02039919054368511, 0.09531879069982097, 0.04544924246147275, 0.1177612399624195, 0.16476509626954794, 0.5589192523621023, 1.0702068731188774, 35.17616406083107, 94.86050382256508, 48.36928032338619, 17.95343242585659, 80.14991238713264, 103.3587858080864, 32.25317470729351, 6.387043073773384, 0.5420919740572572, 0.12712535506580025, 0.9887280233670026, 0.5132164328824729, 0.682802164228633, 2.3562103416770697, 0.8029062976129353, 0.5421034921891987, 29.032838009297848, 113.06256830692291, 91.32335722446442, 81.81663975119591, 87.21482008695602, 88.81948918104172, 86.71110391616821, 88.4706375002861, 89.00875702500343, 81.84105724096298, 80.94603046774864, 81.92949369549751, 84.66189667582512, 82.55073755979538, 81.730627566576, 71.3474491238594, 75.63929602503777, 69.71506431698799, 71.41955405473709, 67.31078132987022, 67.09491491317749, 66.22550636529922, 66.03544056415558, 60.68106807768345, 61.455610916018486, 57.635972276329994, 59.29317735135555, 54.331027418375015, 57.10383363068104, 58.11016023159027, 71.61541074514389, 70.78029915690422, 77.33568459749222, 72.25196778774261, 75.99621087312698, 72.9876235127449, 77.60778799653053, 70.68640619516373, 78.59250515699387, 27.063019908964634, 50.854593962430954, 77.25062236189842, 69.37438979744911, 74.56311777234077, 70.58522522449493, 70.91368719935417, 65.69585278630257, 63.40563587844372, 56.37175731360912, 54.80516217648983, 56.56285285949707, 54.45167854428291, 54.29084077477455, 58.704364746809006, 64.58935216069221, 66.13149181008339, 69.089085906744, 70.02611562609673, 70.18493950366974, 68.88337254524231, 69.23647239804268, 66.24800115823746, 63.55145685374737, 58.11011463403702, 58.13269682228565, 61.11892618238926, 69.17430773377419, 72.28444084525108, 73.94854635000229, 73.07321012020111, 74.34495627880096, 72.90813937783241, 72.60092586278915, 70.17162501811981, 73.17770451307297, 70.92685729265213, 72.11306244134903, 78.79418313503265, 75.41152864694595, 70.30083328485489, 74.87884283065796, 84.38358440995216, 18.703928254544735, 0.22815952892415226, 0.6728300743270665, 0.4554201092105359, 0.3285796497948468, 0.35475386248435825, 0.2391935876221396, 0.3510967962210998, 20.361862890422344, 27.730296403169632, 99.85972076654434, 31.755344420671463, 11.958459913730621, 52.59291708469391, 64.99405324459076, 26.958740204572678, 0.5815343919675797, 0.03375247928488534, 0.06622158485697582, 0.1547786532319151, 0.08435183699475601, 0.0435837318218546, 0.027594933817454148, 0.10792947534355335, 0.04246448777848855, 0.04934514669002965, 0.017033313342835754, 0.02945944626844721, 0.046089055394986644, 0.03297053393907845, 0.04014877551526297, 0.06192236047354527, 0.02392213216808159, 0.06317363629932515, 0.055506965072709136, 0.034387509076623246, 0.02408686854323605, 0.013310349004314048, 0.020833705020777415, 0.029394571429293137, 0.060982092763879336, 0.004954101059411187, 0.058024493264383636, 0.02768745365756331, 0.20107907970668748, 0.1183511434646789, 0.1392637295066379, 0.197727347840555, 0.2041727668256499, 0.083309958135942, 0.21363552077673376, 0.1553900641738437, 0.16653538565151393, 0.11126721772598103, 0.1109708113654051, 0.1175354266888462, 0.2694175369106233, 0.1592953343060799, 0.1722211274318397, 0.12671297328779474, 0.08489488129271194, 0.14304280484793708, 0.1542586155119352, 0.08670681258081459, 0.2897513739299029, 0.12117937920265831, 0.16423622699221596, 0.3108981595141813, 0.10429267713334411, 0.14525633450830355, 0.22232176561374217, 0.2451515046413988, 0.25576386018656194, 0.16740213992306963, 0.4197377973468974, 0.32454221800435334, 0.8047885622363538, 1.5732864593155682, 43.60745944082737, 116.3243892788887, 86.28949373960495, 44.33601714670658, 56.32190778851509, 109.50484201312065, 49.32426027953625, 6.126602673903108, 0.5044041713699698, 0.5834061477798969, 1.727714566513896, 0.9459346008952707, 8.752317354083061, 9.515518750995398, 0.36546082701534033, 0.943715104367584, 26.05598084628582, 112.91159480810165, 99.09329429268837, 82.56364926695824, 90.85405200719833, 92.1463094651699, 91.60390377044678, 93.47488537430763, 96.46136552095413, 85.6519715487957, 80.75249925255775, 82.2152079641819, 90.24307519197464, 88.06470528244972, 86.09739884734154, 73.13498720526695, 77.49428048729897, 76.47264450788498, 74.58850800991058, 71.99656829237938, 72.33077555894852, 73.24304580688477, 70.92886358499527, 64.96371567249298, 67.48456120491028, 63.60138237476349, 64.70607429742813, 57.48538635671139, 60.8326381444931, 61.383714973926544, 75.83899050951004, 76.36790692806244, 82.31787085533142, 74.99613493680954, 79.50820282101631, 75.49857437610626, 80.16302168369293, 74.71713870763779, 78.57419773936272, 32.661451399326324, 52.479994744062424, 76.42756372690201, 71.05660513043404, 76.20384693145752, 75.60278758406639, 73.38697448372841, 70.131134390831, 67.598547488451, 60.64069144427776, 57.39240154623985, 59.28876958787441, 57.8276339918375, 58.254776671528816, 63.45763988792896, 70.79788461327553, 73.01685154438019, 74.76820036768913, 74.05139923095703, 77.18604862689972, 73.7666729092598, 74.36922937631607, 72.35377952456474, 70.39289474487305, 65.44005051255226, 64.22177508473396, 66.56073197722435, 73.38122919201851, 76.87729999423027, 81.55285030603409, 77.90416449308395, 78.08221533894539, 78.07069435715675, 80.32764405012131, 75.61037197709084, 76.97081297636032, 73.34539711475372, 76.87545329332352, 83.57450902462006, 77.1650205552578, 76.44905537366867, 80.76655849814415, 80.21608963608742, 18.25812667608261, 0.3016258851857856, 0.660616698442027, 1.311365682631731, 2.1283149579539895, 1.2119175377301872, 0.39038977527525276, 0.2598202909575775, 16.405433490872383, 45.06179720163345, 91.93654552102089, 19.232715480029583, 42.23927825689316, 81.54527351260185, 76.58767193555832, 39.172143638134, 0.5344721954315901, 0.15860549319768324, 0.1378944076714106, 0.20159902836894616, 0.20342226256616414, 0.13315564632648602, 0.15772674581967294, 0.11355455397279002, 0.12014533000183292, 0.12026107535348274, 0.18936904321890324, 0.10851025042939, 0.1298252140986733, 0.13717848749365658, 0.13191627454943955, 0.190602462971583, 0.12568932899739593, 0.13914612878579646, 0.16691733937477693, 0.0836992813856341, 0.09928054569172673, 0.10817544534802437, 0.1697207280085422, 0.14257272850954905, 0.148531892336905, 0.10448202869156376, 0.18731345742708072, 0.17798675398807973], [0.04290058117476292, 0.015085407612787094, 0.0603177221637452, 0.027282996161375195, 0.03685700547066517, 0.052578134927898645, 0.0708781236608047, 0.06271530073718168, 0.019243575698055793, 0.07860700541641563, 0.056513113231630996, 0.021237514993117657, 0.02582854256615974, 0.019102680817013606, 0.03507561355945654, 0.05897460556298029, 0.030485029419651255, 0.06777996139135212, 0.023698593577137217, 0.028997086410527118, 0.013814380454277853, 0.033062437796615995, 0.06603485308005475, 0.030119449329504278, 0.044439394696382806, 0.007267987639352214, 0.037476758152479306, 0.02043636286543915, 0.06437990828999318, 0.07517976744566113, 0.030631904155598022, 0.0619849420763785, 0.048640321620041505, 0.09843870531767607, 0.5394451785832644, 49.87165130674839, 78.5851639509201, 62.35844247043133, 32.91425563395023, 39.575058817863464, 92.08046659827232, 38.01574029028416, 6.6103884391486645, 0.039963105009519495, 0.3074680716963485, 0.33101965324021876, 0.604542454238981, 1.7856297525577247, 0.7913125259801745, 0.12652121717110276, 0.7957341230940074, 13.643708433955908, 92.03275635838509, 107.82776400446892, 90.55954501032829, 77.67725586891174, 80.94423696398735, 79.45943623781204, 80.06393820047379, 89.56487998366356, 90.18213406205177, 84.5743265748024, 79.14736658334732, 81.73541530966759, 74.78785291314125, 80.92726707458496, 73.12218189239502, 69.391960054636, 67.25937768816948, 69.54009890556335, 65.84884017705917, 68.30355405807495, 63.374891728162766, 64.94956523180008, 63.857306241989136, 63.035520538687706, 61.603103801608086, 55.78877739608288, 54.12117227911949, 54.622806161642075, 60.72039216756821, 71.18972718715668, 73.93330156803131, 72.35355153679848, 74.32127594947815, 72.75732547044754, 71.60145789384842, 66.28074780106544, 68.97205218672752, 26.546247638761997, 47.84241199493408, 74.28210005164146, 65.00104486942291, 71.05988815426826, 69.45333436131477, 68.44512686133385, 63.83075326681137, 65.49982890486717, 58.48615005612373, 53.861467614769936, 51.994339004158974, 51.19573585689068, 56.031348779797554, 68.89946848154068, 70.67435324192047, 69.23939064145088, 70.8728089928627, 67.25826814770699, 66.9434018433094, 67.55862683057785, 65.74518173933029, 67.97418773174286, 67.06794396042824, 66.1172653734684, 60.04712909460068, 59.39745135605335, 61.554310619831085, 67.13811859488487, 73.53961229324341, 74.78767812252045, 71.83481097221375, 74.79279264807701, 76.08800634741783, 70.56382477283478, 71.81383609771729, 78.6121729016304, 73.74990060925484, 70.0821778178215, 77.73479238152504, 76.71716898679733, 38.99879693984985, 2.735789311118424, 0.1400393628864549, 0.669192778877914, 0.07604100755997933, 0.12623636604985222, 0.4323201987426728, 0.5065234482754022, 2.6228028489276767, 15.69831233471632, 31.71813491731882, 87.68010511994362, 18.805236518383026, 34.049053341150284, 56.09122596681118, 57.28301301598549, 28.597371876239777, 0.15265830763382837, 0.22053388733183965, 0.08111450719297864, 0.07409442841890268, 0.02008346978982445, 0.14733402145793661, 0.09164018731098622, 0.054159952196641825, 0.043856300399056636, 0.026465646660653874, 0.06737063726177439, 0.04129766093683429, 0.03352388295752462, 0.08309951474075206, 0.052548823805409484, 0.02772016010567313, 0.026421961993037257, 0.05634729517623782, 0.05589382068137638, 0.03629846883995924, 0.0703029146825429, 0.002631542715789692, 0.048359711872763, 0.04627812864782754, 0.1625193128711544, 0.01955166346306214, 0.010972647833114024, 0.0450815973454155, 0.02487786994606722, 0.028756639840139542, 0.009845451677392703, 0.0387053910526447, 0.022834789342596196, 0.07750960648991168, 0.0455842576775467, 0.061571005498990417, 0.004667524444812443, 0.06450369852245785, 0.032142070776899345, 0.026397354231448844, 0.02979322904138826, 0.02543034694099333, 0.02414531452814117, 0.11454259001766331, 0.027638729807222262, 0.08072056036326103, 0.054665941061102785, 0.06411408583517186, 0.04824833777092863, 0.03749657349544577, 0.01506658303696895, 0.047109181905398145, 0.0528755097911926, 0.0568700120493304, 0.03273680566053372, 0.01074114878065302, 0.06313344158115797, 0.08106823428533971, 0.04026039823656902, 0.016811131026770454, 0.04402293481689412, 0.058646568868425675, 0.04879824693489354, 0.9355132444761693, 62.102317214012146, 86.35035887360573, 42.990649938583374, 18.97911138832569, 82.0697669684887, 109.2206172645092, 41.23585470020771, 12.699871379882097, 0.12948207469889894, 0.3891018818831071, 0.6248578266240656, 0.5739330186042935, 1.230196813121438, 0.38491533778142184, 0.5978118279017508, 0.7044074486475438, 19.028687328100204, 107.18231543898582, 108.49621653556824, 91.49459883570671, 80.96021890640259, 86.57345250248909, 80.14445587992668, 83.02253544330597, 91.23415321111679, 89.48086649179459, 81.58514097332954, 78.43179658055305, 82.34972074627876, 78.14591512084007, 80.68878427147865, 73.55990320444107, 70.63893154263496, 67.80517280101776, 70.52334174513817, 70.01500502228737, 68.24154138565063, 67.03925549983978, 66.83007672429085, 66.73123642802238, 66.50387942790985, 63.14368553459644, 59.10331293940544, 55.64356058835983, 57.78069511055946, 64.22237545251846, 71.59128963947296, 75.41263818740845, 73.54890659451485, 77.37524047493935, 73.73708009719849, 72.7452041208744, 67.60278046131134, 73.00875037908554, 26.77222341299057, 49.451496452093124, 74.8933656513691, 66.52259722352028, 74.39122259616852, 73.58169883489609, 72.50873520970345, 68.68113979697227, 70.87075710296631, 62.1503010392189, 57.02159084379673, 54.87620696425438, 55.776614248752594, 58.32698419690132, 70.5812506377697, 73.28570991754532, 75.00243499875069, 72.77831554412842, 72.62869477272034, 70.22660046815872, 68.00650119781494, 68.84064763784409, 70.12030497193336, 69.38743069767952, 67.27884784340858, 61.98807254433632, 59.626643657684326, 65.36494374275208, 69.29472327232361, 75.63719093799591, 71.62772208452225, 69.02483895421028, 71.85494989156723, 74.40170243382454, 74.94647920131683, 71.33411183953285, 77.67091020941734, 77.15911567211151, 71.82385995984077, 76.46525010466576, 78.95617604255676, 46.25535495579243, 3.6645580362528563, 0.4363481013569981, 0.4468275234103203, 0.2228762093000114, 0.5235797236673534, 0.7445583504159003, 0.7003149494994432, 3.948747874237597, 29.850101955235004, 26.489317193627357, 109.36884731054306, 42.57282055914402, 9.738960061222315, 39.794128462672234, 61.24423585832119, 39.671273455023766, 0.35084948292933404, 0.23349729250185192, 0.029590505837404635, 0.098420084832469, 0.047743091054144315, 0.03583535013603978, 0.0037674247823815676, 0.08197079718229361, 0.04263449154677801, 0.018587693411973305, 0.07129807534511201, 0.026655812725948635, 0.04682771126681473, 0.047317740245489404, 0.059156632123631425, 0.0512726711895084, 0.04256780586729292, 0.023581651512358803, 0.040600836218800396, 0.041811572227743454, 0.03936927183531225, 0.01353070749246399, 0.07847173415939324, 0.056266590327140875, 0.05548470435314812, 0.0038786001277912874, 0.04200102397589944, 0.03516907963785343, 0.04856937601289246, 0.1193551356846001, 0.09137892906437628, 0.14242890028981492, 0.131019834370818, 0.09214196077664383, 0.1021563085669186, 0.17239305336261168, 0.12237022194312885, 0.20935678709065542, 0.12356179940979928, 0.18009054969297722, 0.15638895041774958, 0.12712134746834636, 0.1178739350871183, 0.17702681565424427, 0.11620443678111769, 0.1920880496618338, 0.1308371769846417, 0.11751541096600704, 0.10947540606139228, 0.1865393974003382, 0.0903652369743213, 0.19237539439927787, 0.14727813773788512, 0.1618010178208351, 0.10656807222403586, 0.10871035570744425, 0.16219745826674625, 0.1673827995546162, 0.21391821966972202, 0.11029387620510533, 0.13674731453647837, 0.15073841612320393, 0.18884756573243067, 0.917191399494186, 76.8725274503231, 105.76265081763268, 81.11281871795654, 45.0885933637619, 60.702297538518906, 106.72374084591866, 60.12040436267853, 12.90185334160924, 0.23879633081378415, 0.43258490797597915, 0.7753049943130463, 1.687609856016934, 5.385023541748524, 2.7539665857329965, 0.5810487898997962, 0.8946216793265194, 16.5556850284338, 101.37291356921196, 113.55829730629921, 97.1705974638462, 83.52533206343651, 91.36397704482079, 82.99753278493881, 84.97831329703331, 92.37633392214775, 93.07238817214966, 86.79231315851212, 79.09977793693542, 88.44017833471298, 82.50450924038887, 89.61215704679489, 81.11659571528435, 73.30260381102562, 74.24866184592247, 75.72729930281639, 72.92419731616974, 75.81106960773468, 71.54161110520363, 73.92252534627914, 71.02817505598068, 73.23701933026314, 69.90009158849716, 63.84434133768082, 61.35122671723366, 62.87844076752663, 66.44572734832764, 77.12267562747002, 79.92859706282616, 78.9582659304142, 79.53391224145889, 76.33107170462608, 75.42893171310425, 71.88512027263641, 73.5706490278244, 32.80658081173897, 57.02461928129196, 76.72422140836716, 70.796919465065, 75.95992282032967, 78.5764928162098, 78.68949115276337, 73.77038151025772, 75.49618810415268, 67.86350727081299, 61.07461676001549, 59.172921404242516, 59.68795336782932, 64.29141014814377, 77.65337035059929, 78.43755707144737, 77.3448497056961, 78.73141810297966, 75.31374469399452, 75.74410200119019, 73.42746511101723, 72.33901351690292, 77.81854748725891, 76.63181036710739, 74.32899713516235, 68.54448392987251, 65.94989955425262, 69.96316060423851, 77.18579784035683, 79.75339606404305, 78.22140946984291, 73.93944963812828, 74.88265782594681, 79.4876155257225, 76.67355492711067, 77.61742427945137, 85.12004569172859, 80.31572788953781, 73.36205542087555, 82.86260962486267, 79.97946873307228, 41.086085736751556, 3.504882766865194, 0.4718885145848617, 0.7279309770092368, 0.4029676940990612, 2.4157407972961664, 1.1737514357082546, 0.9813187771942466, 3.1297438591718674, 25.578373074531555, 47.84680835902691, 100.26656493544579, 30.119914077222347, 46.88658848404884, 81.00896269083023, 71.61416441202164, 55.269770845770836, 0.3434787393780425, 0.4075062833726406, 0.24270611320389435, 0.1757356568123214, 0.11591551126912236, 0.1774313603527844, 0.20194271695800126, 0.11074850102886558, 0.09243247448466718, 0.13164157600840554, 0.11184914314071648, 0.12967504793778062, 0.20012389111798257, 0.1281721840496175, 0.22314894857117906, 0.12189924018457532, 0.14383920351974666, 0.13024351821513847, 0.1606587486458011, 0.10247633006656542, 0.10926612783805467, 0.12612964521395043, 0.11635078830295242, 0.08931220363592729, 0.16973105870420113, 0.08242565207183361, 0.12195598479593173, 0.1155335946532432, 0.10769605505629443], [0.05537334509426728, 0.03518562582030427, 0.0646967459761072, 0.04181851872999687, 0.026764808244479354, 0.040041520333033986, 0.04298182037018705, 0.042376020064693876, 0.015219290125969565, 0.03203851520083845, 0.11283575426205061, 0.01797273500415031, 0.06901965971337631, 0.035941944806836545, 0.07245354732731357, 0.01896799400128657, 0.05122887705510948, 0.057382309169042856, 0.026357534297858365, 0.04522381510469131, 0.06732172972988337, 0.04356375320639927, 0.028285299995332025, 0.04404029365105089, 0.04673754403484054, 0.05881542601855472, 0.13315485964994878, 0.0312866824970115, 0.10065524809760973, 0.017621354054426774, 0.04422327387146652, 0.04172280394413974, 0.08685226610396057, 0.026315818176954053, 0.1677416279562749, 1.2134243943728507, 64.49187219142914, 76.03401884436607, 73.30882787704468, 38.48809294402599, 23.809072114527225, 84.77551817893982, 57.92758762836456, 18.96749161183834, 3.0680772056803107, 0.16774008428910747, 0.020234051553416066, 0.84622195456177, 0.8704153751023114, 0.03682257723994553, 0.2673892176244408, 0.20657833461882547, 1.9489712314680219, 29.535613730549812, 68.57237443327904, 88.8133031129837, 87.57668986916542, 92.52699583768845, 97.0766133069992, 79.63635474443436, 76.42049610614777, 84.386525452137, 89.0235686302185, 88.80525514483452, 82.52727761864662, 77.85594508051872, 75.72076365351677, 74.67346385121346, 73.46549347043037, 73.2609124481678, 71.8975456058979, 71.10974907875061, 71.52521878480911, 66.49675861001015, 69.07406151294708, 68.15834864974022, 66.85825601220131, 62.011638879776, 57.811705246567726, 56.59348301589489, 56.81195229291916, 70.04956796765327, 74.20203074812889, 72.99311801791191, 72.02397242188454, 73.71547445654869, 69.90025117993355, 72.24695205688477, 70.73006585240364, 34.64259669184685, 43.63359823822975, 66.10887542366982, 66.77801191806793, 68.96059200167656, 70.08318856358528, 69.2976339161396, 71.25918745994568, 68.40782806277275, 67.71707072854042, 60.815299674868584, 53.68999421596527, 53.24200965464115, 66.31528034806252, 70.04949197173119, 73.22531595826149, 70.94484552741051, 69.45106208324432, 70.7695609331131, 70.91374799609184, 68.61936271190643, 71.35159850120544, 68.75845804810524, 71.15686655044556, 67.29964792728424, 66.62725120782852, 61.73441715538502, 64.033844769001, 71.57815754413605, 77.20651432871819, 76.67673155665398, 76.81216388940811, 80.22503435611725, 79.61616262793541, 82.56744146347046, 85.20937889814377, 71.70670464634895, 72.21029922366142, 76.180250197649, 37.86837659776211, 3.313590344041586, 0.5345984199084342, 0.18061722221318632, 0.3924995823763311, 0.2391269279178232, 0.6610679836012423, 0.08266719887615182, 0.15914384712232277, 7.830813601613045, 18.515640757977962, 41.53896063566208, 83.22754964232445, 15.3062161244452, 31.87442433089018, 62.26939804852009, 58.16305719316006, 50.026823580265045, 0.4780797479907051, 0.10802030679769814, 0.057523035211488605, 0.04272323756595142, 0.004252855924278265, 0.032402134165749885, 0.012082904468115885, 0.05479284831380937, 0.046954637073213235, 0.034754478838294744, 0.020396624568093102, 0.058768451781361364, 0.05066788762633223, 0.030026884960534517, 0.07400412388960831, 0.013588756428362103, 0.010812483087647706, 0.032494490733370185, 0.026187638140982017, 0.025614432961447164, 0.031021442628116347, 0.052191687500453554, 0.07978877169080079, 0.04193411936284974, 0.05566596279095393, 0.01926055603689747, 0.06270521495025605, 0.02917435394920176, 0.02948635654320242, 0.014774652754567796, 0.032746486976975575, 0.05155700651812367, 0.018317783578822855, 0.09160062341834418, 0.09799691964872181, 0.07243933519930579, 0.0626389856915921, 0.01888801831228193, 0.023455545779142994, 0.02292492503329413, 0.06729934655595571, 0.02418747408228228, 0.005078050389784039, 0.08947822949266993, 0.045193131009000354, 0.03305733553133905, 0.058369061298435554, 0.07699953581322916, 0.030121384479571134, 0.09867830769508146, 0.0695926125627011, 0.05705165269318968, 0.02657592238392681, 0.1039239187957719, 0.017924673520610668, 0.025391480667167343, 0.06528289421112277, 0.01884004032035591, 0.07963433818076737, 0.09061059841769747, 0.020501297076407354, 0.02586030648672022, 0.03930947328626644, 0.023944322383613326, 0.12499681615736336, 3.102070181630552, 78.55532795190811, 77.96339571475983, 52.886185348033905, 28.436917886137962, 64.5795638859272, 110.06849616765976, 55.641307309269905, 28.059288449585438, 5.37009509280324, 0.5342426639981568, 0.026202957924397197, 1.0305943549610674, 1.0490982932969928, 0.06757215262041427, 0.4444758949102834, 0.20408648473676294, 3.2659653620794415, 40.44520452618599, 81.93246513605118, 99.19891342520714, 92.3951581120491, 95.96048399806023, 93.18909510970116, 75.41750952601433, 75.95014214515686, 83.62118571996689, 86.97386741638184, 87.89046943187714, 81.36752665042877, 78.11251491308212, 79.28385525941849, 74.74497601389885, 75.45463353395462, 74.98693943023682, 72.26889207959175, 71.38109251856804, 69.47941616177559, 66.87346279621124, 68.52864637970924, 67.44226187467575, 65.90036541223526, 63.5137552767992, 59.14073333144188, 59.054857939481735, 61.819866970181465, 73.26525181531906, 77.5708919763565, 76.84030517935753, 74.63965326547623, 76.22720047831535, 74.39340367913246, 74.55008447170258, 71.85273841023445, 38.887208327651024, 49.03124660253525, 69.31042402982712, 70.5665074288845, 70.05218222737312, 72.53850281238556, 72.8210936486721, 75.1109267771244, 68.58731523156166, 69.68889132142067, 60.43916165828705, 56.13551639020443, 54.619694128632545, 68.30623671412468, 73.13035145401955, 74.19350400567055, 71.66320458054543, 71.07680484652519, 73.07129502296448, 72.67844930291176, 73.21343019604683, 74.60758298635483, 72.9769916832447, 73.00491258502007, 68.59833464026451, 67.3685610294342, 64.9172593653202, 65.90338245034218, 68.8969150185585, 75.27911335229874, 76.7757086455822, 75.73353096842766, 78.10642004013062, 77.53539428114891, 76.91752463579178, 83.52522566914558, 72.37060502171516, 70.35094499588013, 83.24349358677864, 47.61352367699146, 5.595599692314863, 0.821360838599503, 0.0626598326198291, 0.5177874094806612, 0.2927538362564519, 1.0711178742349148, 0.0764403646462597, 0.5326413467992097, 14.220642875880003, 36.60984992980957, 32.02353782951832, 108.83527234196663, 38.196280002593994, 12.133768256753683, 46.22827000916004, 59.26376312971115, 62.910655438899994, 1.2220672680996358, 0.2785506733926013, 0.017464783159084618, 0.053363605475169607, 0.025269790712627582, 0.06399454810889438, 0.02492351944965776, 0.06644415494520217, 0.06417546144803055, 0.03315659036161378, 0.030360461787495296, 0.03718213294632733, 0.010587509368633619, 0.07086785233695991, 0.06449367210734636, 0.005614757674266002, 0.0029546814675995847, 0.028519506959128194, 0.09926378799718805, 0.04777709997142665, 0.036847209121333435, 0.028159606154076755, 0.07282295875484124, 0.03465477129793726, 0.10063881694804877, 0.02648752702953061, 0.03781188606808428, 0.08311314057209529, 0.028817989477829542, 0.04937603487633169, 0.18539178476203233, 0.0987028208328411, 0.16516094299731776, 0.15975447138771415, 0.18297275441000238, 0.15949621883919463, 0.26220635510981083, 0.09712184590171091, 0.10260084018227644, 0.1297865778906271, 0.19768393220147118, 0.129521542112343, 0.11723357296432368, 0.17024751927237958, 0.19964161387179047, 0.1712393105844967, 0.12613331142347306, 0.13993719883728772, 0.09806746078538708, 0.19961142330430448, 0.14035330619663, 0.19297749880934134, 0.06783600838389248, 0.1520384065224789, 0.1159252408251632, 0.14343339717015624, 0.15989513805834576, 0.16561942698899657, 0.18172352691181004, 0.14781864389078692, 0.1744367351057008, 0.15101583092473447, 0.15352283546235412, 0.17714898800477386, 0.2703346830094233, 3.133832677267492, 95.38051351904869, 97.82905653119087, 94.6137298643589, 48.94146881997585, 43.566839620471, 98.59991356730461, 81.89463436603546, 33.23335111141205, 5.162633825093508, 0.38532717037014663, 0.11035398274543695, 1.4246303611434996, 2.511723884381354, 0.11312217131489888, 0.6975096906535327, 0.21182092517847195, 2.7946239290758967, 35.28660133481026, 79.78643909096718, 103.71541187167168, 99.43088337779045, 98.86104315519333, 99.94736686348915, 78.19487929344177, 74.45760503411293, 82.02394902706146, 90.7537753880024, 95.54843410849571, 86.05824574828148, 82.47431606054306, 80.63757821917534, 82.68458917737007, 81.21625676751137, 79.40487116575241, 77.24730134010315, 75.91174900531769, 77.190061211586, 70.20640075206757, 76.59250527620316, 72.29679018259048, 71.44790053367615, 66.99849888682365, 62.69453443586826, 63.27100910246372, 64.46452125906944, 80.33262938261032, 83.39495345950127, 79.85168918967247, 77.55668073892593, 81.15027710795403, 78.12865644693375, 76.10737010836601, 74.59799230098724, 48.29624444246292, 53.62421214580536, 69.3337319791317, 75.4245163500309, 71.5328411757946, 76.21721461415291, 77.51478418707848, 80.37715539336205, 75.51888048648834, 74.86900895833969, 66.61354154348373, 59.39814291894436, 60.162779688835144, 73.84956166148186, 77.67399564385414, 79.70240280032158, 78.04460495710373, 76.11836671829224, 77.79764860868454, 79.11651983857155, 78.8120649755001, 82.63143762946129, 78.13784435391426, 81.19598865509033, 74.4048410654068, 74.73081797361374, 72.03794807195663, 74.53877627849579, 78.23950409889221, 83.26740950345993, 80.99769249558449, 79.20921966433525, 83.84052515029907, 83.8584753870964, 82.50412926077843, 88.02596256136894, 72.45743796229362, 77.71953999996185, 84.75617721676826, 43.62339958548546, 3.887997684068978, 0.6518222484737635, 0.4929430363699794, 0.7717284362297505, 0.43074512388557196, 1.9646535837091506, 0.5754272290505469, 0.5397773638833314, 11.676792427897453, 32.529495880007744, 55.88350631296635, 94.73527014255524, 26.504962854087353, 42.71999806165695, 84.72950264811516, 69.6403831243515, 76.56575471162796, 1.653213151730597, 0.42142950813286006, 0.19049534137593582, 0.12405782123096287, 0.12283585281693377, 0.11832804040750489, 0.09820761537412181, 0.1517151269945316, 0.17706365586491302, 0.1065741726779379, 0.14744828251423314, 0.15318946272600442, 0.12792023975634947, 0.14234333066269755, 0.15071733912918717, 0.11231753480387852, 0.0967443673289381, 0.10667344235116616, 0.12222558478242718, 0.11739366163965315, 0.08189719097572379, 0.15007394162239507, 0.1899531579692848, 0.07391709965304472, 0.1865086131147109, 0.10462360078236088, 0.18438443803461269, 0.18245892104459926, 0.19036583660636097, 0.2147119614528492], [0.13483684830134735, 0.0063427103850699496, 0.030534625293512363, 0.009361289376101922, 0.0975104641111102, 0.036074696472496726, 0.030285525281215087, 0.05471495620440692, 0.10148119166842662, 0.023404146486427635, 0.036815686398767866, 0.08419730700552464, 0.04903505883703474, 0.058278129654354416, 0.019335269898874685, 0.010014304189098766, 0.09746375333634205, 0.05534175557841081, 0.032546107104280964, 0.07861060483264737, 0.05567377760598902, 0.008056116002990166, 0.04723580714198761, 0.054092060527182184, 0.04628945382137317, 0.04684852479840629, 0.0728094887745101, 0.04384821098938119, 0.04525546028162353, 0.04923345346469432, 0.07289991204743274, 0.038224516465561464, 0.04777362300956156, 0.006143085183794028, 0.04079333448316902, 0.14385361602762714, 3.163027223199606, 69.51171442866325, 69.24963489174843, 69.11202907562256, 36.516606733202934, 13.62077096477151, 62.345466166734695, 79.90441516041756, 28.875649943947792, 12.379313930869102, 0.8473423006944358, 0.5890745529904962, 0.28192640631459653, 0.5877307313494384, 0.07183501176768914, 0.0038389232895497116, 0.12767819571308792, 0.09769840558874421, 0.17930822214111686, 4.590059649199247, 22.306545339524746, 36.06596611440182, 60.20713850855827, 90.93067869544029, 106.73808887600899, 89.40829798579216, 80.05061611533165, 82.10782572627068, 91.79757177829742, 89.62877735495567, 82.19403550028801, 77.0455701649189, 77.06727460026741, 73.56302663683891, 74.19407397508621, 73.49489629268646, 69.88231614232063, 72.79289916157722, 71.11011385917664, 72.70250201225281, 69.73826587200165, 67.4784055352211, 60.11710613965988, 59.25003446638584, 53.98819841444492, 63.67330491542816, 72.17782616615295, 73.92478242516518, 74.35162872076035, 73.11139047145844, 74.95549231767654, 71.99095219373703, 75.06338372826576, 37.338358238339424, 31.23390980064869, 67.47869431972504, 61.252454817295074, 70.36495864391327, 70.71767091751099, 69.6027347445488, 68.98173406720161, 66.1199252307415, 68.91729712486267, 64.84567880630493, 54.09591123461723, 53.653390780091286, 66.026032269001, 71.41122490167618, 76.40562370419502, 71.99868857860565, 74.15363654494286, 70.10100200772285, 69.00105223059654, 71.66022554039955, 71.33315429091454, 74.21089187264442, 72.03896641731262, 69.5664694905281, 73.26435506343842, 71.18471145629883, 68.43276232481003, 70.89627653360367, 75.93809679150581, 81.06864228844643, 83.58640238642693, 81.73761919140816, 81.96243032813072, 71.40513002872467, 70.55336013436317, 90.95133438706398, 59.58228103816509, 7.451093327254057, 0.8112315915059298, 0.2616875938838348, 2.718486227095127, 0.02375839583692141, 0.23882430978119373, 0.5896454129833728, 0.24371708161197603, 0.22604431898798794, 16.63802471011877, 17.96421244740486, 48.14627788960934, 75.58603808283806, 13.245236165821552, 38.76780353486538, 58.40343989431858, 56.33826591074467, 54.22844052314758, 1.6835513175465167, 0.06412988615920767, 0.02821071415382903, 0.016589227016083896, 0.10212401030003093, 0.03527132903400343, 0.038056902412790805, 0.02027691800321918, 0.08075802397797816, 0.050762786049745046, 0.013653318637807388, 0.043019246877520345, 0.055748838422005065, 0.02633093758049654, 0.09775889062439092, 0.07366420541075058, 0.021780603819934186, 0.05714041726605501, 0.08610755059635267, 0.025976747601816896, 0.04188228405837435, 0.019424754354986362, 0.06096745761169586, 0.007654910968994955, 0.09163184557110071, 0.02320244188013021, 0.02940820653748233, 0.08955922749009915, 0.07334045832976699, 0.02723111076193163, 0.027965809131274, 0.10800388306961395, 0.027125881642859895, 0.029758084638160653, 0.029589310979645234, 0.03579628719307948, 0.03636914727394469, 0.05797266167064663, 0.06627780254348181, 0.0580803398770513, 0.04013909048808273, 0.04494217377214227, 0.041134217754006386, 0.04392911992908921, 0.03781646511924919, 0.040223639662144706, 0.0489677200675942, 0.015194202751445118, 0.027872458085766993, 0.05221939929469954, 0.05237001816567499, 0.05586134058830794, 0.0628770592447836, 0.04192916923784651, 0.045588127977680415, 0.04378174424346071, 0.07555793621577322, 0.018216038843092974, 0.06291048557613976, 0.08337104431120679, 0.08012855658307672, 0.07369669663603418, 0.049825731839518994, 0.02383025799645111, 0.09425491458387114, 0.15092153364093974, 0.1654599394532852, 7.146015297621489, 85.70029735565186, 75.10633662343025, 53.73513199388981, 15.736904963850975, 42.73528844118118, 105.8449999988079, 75.81410184502602, 39.81026619672775, 21.007868126034737, 0.5379301286302507, 0.7149031979497522, 0.6185370439197868, 0.48080034262966365, 0.14534524379996583, 0.14753076480701566, 0.17289464129135013, 0.12300184898776934, 0.823156361002475, 9.463092014193535, 33.20208638906479, 46.89948879182339, 74.65787708759308, 96.67043030261993, 96.5084145963192, 78.7535785138607, 76.57480582594872, 82.32031792402267, 93.80932062864304, 88.85478928685188, 77.17858582735062, 75.3036068379879, 75.00523164868355, 74.76845875382423, 76.48652136325836, 71.31474047899246, 71.98121711611748, 72.7628655731678, 73.1226834654808, 74.842858761549, 70.92384025454521, 70.09274885058403, 61.8962162733078, 60.91316722333431, 55.80898091197014, 65.91332271695137, 73.05639982223511, 76.46464973688126, 77.80658572912216, 74.86887976527214, 73.38410943746567, 73.16667750477791, 73.28206211328506, 39.29818667471409, 39.78478856384754, 68.49441021680832, 68.80240648984909, 73.25718864798546, 74.10291686654091, 75.22696495056152, 74.17660251259804, 71.36071041226387, 73.8880155980587, 68.37057486176491, 58.87528337538242, 57.79953829944134, 69.27912130951881, 73.20192441344261, 80.06188631057739, 76.93770915269852, 77.24654898047447, 71.9808979332447, 72.77971386909485, 73.28953251242638, 74.3834862112999, 76.63722887635231, 77.2848129272461, 72.95510485768318, 73.02285522222519, 66.76303312182426, 65.05315527319908, 76.76993295550346, 77.92691767215729, 75.05116358399391, 75.4608803987503, 72.39204347133636, 78.88253599405289, 77.14947178959846, 69.20095950365067, 83.61625358462334, 70.9374587237835, 12.486159447580576, 0.6664263491984457, 0.6864654645323753, 3.4156844532117248, 0.29669965733774006, 0.3967563633341342, 0.8923101564869285, 0.45227565919049084, 0.4190839652437717, 30.166053101420403, 32.04765893518925, 35.138823464512825, 105.73619663715363, 31.008386202156544, 15.805706921964884, 47.82975487411022, 59.0381920337677, 66.63867339491844, 2.783815646544099, 0.13984169927425683, 0.07260504193254746, 0.016637286644254345, 0.0254238253182848, 0.015134589739318471, 0.04117722150112968, 0.03789463924476877, 0.014568520309694577, 0.10271677107084543, 0.014679412015539128, 0.04712911228125449, 0.032297932921210304, 0.03782652122026775, 0.04173019202426076, 0.06896296705235727, 0.033134804616565816, 0.04668304442020599, 0.022987504780758172, 0.05558457145525608, 0.0691453943727538, 0.020686691132141277, 0.032088617590488866, 0.014328409561130684, 0.06433504546293989, 0.0548507840721868, 0.03648865160357673, 0.09140002832282335, 0.031147362824412994, 0.08605249066022225, 0.01741814845445333, 0.2459242139593698, 0.1116810244275257, 0.14878524671075866, 0.1706081288284622, 0.1364917930914089, 0.16729316295823082, 0.09328036336228251, 0.16395170241594315, 0.1832008609198965, 0.17212568724062294, 0.15013847878435627, 0.1534396703937091, 0.17490053287474439, 0.09709427511552349, 0.08688923247973435, 0.12472842587158084, 0.1518031457089819, 0.14355338760651648, 0.1240603371115867, 0.18061551527353004, 0.1728333398932591, 0.13489987148204818, 0.10413232128485106, 0.1181527302833274, 0.11534237288287841, 0.13526117865694687, 0.2085771906422451, 0.10228064798866399, 0.19239011860918254, 0.2174048888264224, 0.21298658684827387, 0.19335333723574877, 0.20345711382105947, 0.1798876019893214, 0.21259354543872178, 0.33802974270656705, 8.565626721829176, 102.23762556910515, 95.7823571562767, 92.94543698430061, 44.81962859630585, 32.74399437010288, 79.6351920068264, 99.97394263744354, 49.51408289372921, 19.63446032255888, 0.8788850612472743, 0.6507340224925429, 0.5450857384130359, 1.5072317537851632, 0.23965070606209338, 0.2658486971631646, 0.24163736117770895, 0.18103401234839112, 0.6597346707712859, 7.074967185035348, 28.897688761353493, 41.66884906589985, 65.42540609836578, 96.24209448695183, 107.4640779197216, 84.73260328173637, 77.78358936309814, 82.21909895539284, 97.18879088759422, 97.05527365207672, 86.8494164943695, 80.90386793017387, 81.46518900990486, 81.83074459433556, 82.71640866994858, 75.66419988870621, 76.82834342122078, 79.87343162298203, 80.61804726719856, 81.56240299344063, 78.66463288664818, 76.14083111286163, 69.28865119814873, 66.15714803338051, 59.83349695801735, 69.44892659783363, 78.1431032717228, 78.51078674197197, 83.84902909398079, 78.96897375583649, 79.50240433216095, 76.20210662484169, 76.55399814248085, 44.830294623970985, 42.27244667708874, 73.9211118221283, 72.88933798670769, 77.44372799992561, 79.80680599808693, 81.20937913656235, 82.91589796543121, 76.22534617781639, 78.83034959435463, 74.56098228693008, 64.32769060134888, 63.350709825754166, 77.55669593811035, 81.91782832145691, 86.07105866074562, 78.08542996644974, 81.84415027499199, 76.30869850516319, 78.52185934782028, 78.58045220375061, 80.78170448541641, 83.70087504386902, 82.91259974241257, 79.00653094053268, 81.82216465473175, 74.86686587333679, 74.01056662201881, 80.79788401722908, 84.9201612174511, 85.37334010004997, 82.19810888171196, 75.09226977825165, 82.0373547077179, 81.26013681292534, 75.84678009152412, 91.42768442630768, 68.96146595478058, 10.022476147860289, 0.9049060055986047, 0.39506729459390044, 4.280724423006177, 0.3782041557133198, 0.5204395484179258, 1.6701830411329865, 0.4148334183264524, 0.26420564157888293, 23.273519352078438, 31.545700170099735, 62.86327198147774, 89.07559543848038, 25.7263770326972, 52.205854654312134, 76.61671757698059, 69.10021930932999, 80.29270872473717, 3.8842080999165773, 0.2645932207815349, 0.16597337205894291, 0.1622970396419987, 0.177089111530222, 0.08199142146622762, 0.22230818431125954, 0.10137197721633129, 0.15318069054046646, 0.23866030998760834, 0.12717760226223618, 0.16116513084853068, 0.15064492035889998, 0.13160222733858973, 0.14574591448763385, 0.16318864101776853, 0.07762945591821335, 0.1313602871960029, 0.1325531559996307, 0.15617113007465377, 0.20954983454430476, 0.07314792295801453, 0.19348671601619571, 0.10185380175244063, 0.25168299791403115, 0.09542812389554456, 0.16234268172411248, 0.25482207478489727, 0.1494192486279644, 0.2411805692827329, 0.12702626350801438], [0.037790263595525175, 0.03812107963312883, 0.05409925193816889, 0.03824997213087045, 0.038014407036826015, 0.027738606186176185, 0.03367832017829642, 0.04509570557274856, 0.05732781326514669, 0.09086885838769376, 0.03842954960418865, 0.02642503077368019, 0.009627963445382193, 0.009833249841904035, 0.13890712754800916, 0.05635464614897501, 0.04113025468541309, 0.1273899752413854, 0.04710137451183982, 0.12487434694776312, 0.038086866625235416, 0.0580035869643325, 0.05955529530183412, 0.03558936528861523, 0.0434844918345334, 0.015681513614254072, 0.05058744252892211, 0.08025013521546498, 0.04774069020641036, 0.016057533866842277, 0.07058513117954135, 0.007286048730748007, 0.01936325443239184, 0.04595930200594012, 0.05843225517310202, 0.009341617824247805, 0.47807125782128423, 4.098401181399822, 71.82081252336502, 78.09112966060638, 62.882331758737564, 43.20713572204113, 15.176380891352892, 50.65983161330223, 92.46600151062012, 42.91340008378029, 19.26706563681364, 6.339377481490374, 0.11512616300024092, 0.400297298328951, 0.35634211788419634, 0.04631880576198455, 0.04566091411106754, 0.29161704413127154, 0.42974788520950824, 1.5710425609722733, 1.3952294387854636, 0.2652951143682003, 0.259998525143601, 5.535160610452294, 37.09863290190697, 81.51741340756416, 104.61563676595688, 99.38711732625961, 91.414415538311, 85.90997010469437, 89.5524774491787, 91.24597817659378, 82.6103487610817, 83.11016634106636, 83.42680335044861, 77.62888446450233, 81.3961087167263, 76.99785232543945, 75.888182669878, 76.43685802817345, 75.65171375870705, 70.15865251421928, 66.2814013659954, 61.628220453858376, 60.08166164159775, 56.05504430830479, 65.79986840486526, 68.22605341672897, 73.16293850541115, 73.44967871904373, 76.37377381324768, 69.75415661931038, 74.46213439106941, 44.611034989356995, 32.16688893735409, 74.06690999865532, 62.95083448290825, 74.18410331010818, 69.94976252317429, 74.03395056724548, 70.65069571137428, 70.13784483075142, 69.11664962768555, 71.62804886698723, 56.42384111881256, 57.464426681399345, 66.99436470866203, 73.84833052754402, 75.8056814968586, 76.33599624037743, 73.55133086442947, 73.37060496211052, 72.47753128409386, 73.33554044365883, 74.98291164636612, 68.05952355265617, 71.57366618514061, 73.94489094614983, 79.00798246264458, 74.5579120516777, 75.86274683475494, 81.38133510947227, 89.26015913486481, 88.18749949336052, 89.80204805731773, 87.27822348475456, 86.66503518819809, 75.91779828071594, 61.854897290468216, 25.277566015720367, 0.7662229472771287, 0.33024689939338714, 2.589947674423456, 7.40547202527523, 1.4556311164051294, 0.5381929676514119, 0.1709192816633731, 0.7960227888543159, 2.433695546351373, 16.92718729376793, 24.816088378429413, 60.533202812075615, 75.31728610396385, 9.587958063930273, 41.48205868899822, 69.22610655426979, 55.4809483140707, 39.2218753695488, 1.1896438454277813, 0.0730646020383574, 0.0842471793293953, 0.06514001594041474, 0.032420621064375155, 0.036676622767117806, 0.010848898418771569, 0.049267677604802884, 0.011853858213726198, 0.05783532353234477, 0.03207919231499545, 0.031752710419823416, 0.04931456278427504, 0.09200726097333245, 0.020986305426049512, 0.07700594796915539, 0.04991077454178594, 0.10547307785600424, 0.052558512543328106, 0.03044833763851784, 0.03309230181912426, 0.028829171787947416, 0.053377695148810744, 0.04883038935076911, 0.06556766369612888, 0.03621983829361852, 0.05720715860661585, 0.06641910746111535, 0.04274324586731382, 0.029812374596076552, 0.03201633982826024, 0.10695413744542748, 0.05681220987753477, 0.05498163583979476, 0.06534747590194456, 0.01999354932195274, 0.046517044538632035, 0.06485721314675175, 0.04698827491665725, 0.05687760793080088, 0.036756552071892656, 0.05567666084971279, 0.0337074049457442, 0.00694846105943725, 0.02284095658978913, 0.08576369131333195, 0.06464582722401246, 0.060025356797268614, 0.06345862842863426, 0.044045121321687475, 0.006491558769994299, 0.10737250093370676, 0.03549752822436858, 0.04976688323949929, 0.06493896071333438, 0.007505043986384408, 0.0658283504890278, 0.06450656321248971, 0.054088676333776675, 0.05516338780580554, 0.07994917206815444, 0.04305997594201472, 0.08499364630552009, 0.08648507369798608, 0.01564881644299021, 0.04990159417502582, 0.06077920443203766, 0.04761812822835054, 0.523718356853351, 9.155539367347956, 88.8383437693119, 76.54636055231094, 48.92415314912796, 17.161138840019703, 21.98799703270197, 90.66556692123413, 86.21028319001198, 46.09707824885845, 41.98895908892155, 11.871013306081295, 0.32668797473888844, 0.3068387898383662, 0.5470938712824136, 0.009662862939876504, 0.29078067338559777, 0.6928775610867888, 0.5130300053860992, 1.7546902690082788, 0.9027455246541649, 0.17601736122742295, 1.033241031691432, 11.020129714161158, 56.095208153128624, 91.87553599476814, 96.90477892756462, 88.67439016699791, 84.39325869083405, 86.4177368581295, 88.85219022631645, 88.68949815630913, 82.9838915169239, 81.15812748670578, 78.76007616519928, 75.31712651252747, 78.22923704981804, 77.19268307089806, 74.05430227518082, 75.38500607013702, 74.49071645736694, 71.6063292324543, 68.66687536239624, 66.2625239789486, 63.03209692239761, 60.2043342590332, 70.39063766598701, 74.25753816962242, 76.69618651270866, 77.07263991236687, 83.07569459080696, 73.30717116594315, 80.2334015071392, 48.127685487270355, 37.83688768744469, 75.33957570791245, 67.30877503752708, 72.49908372759819, 73.625867664814, 79.2451885342598, 73.24489250779152, 75.03740072250366, 71.2647807598114, 74.8881371319294, 57.376385405659676, 61.51466354727745, 69.36771735548973, 75.82881465554237, 76.72181993722916, 74.9145533144474, 75.00473767518997, 74.45387363433838, 73.60287129878998, 77.10553094744682, 78.4856928884983, 73.02060574293137, 72.25382968783379, 73.07489722967148, 80.02204924821854, 76.46612405776978, 76.66907876729965, 71.1111930012703, 78.21040526032448, 82.72751927375793, 82.17973306775093, 81.78669735789299, 83.62446114420891, 73.77288177609444, 71.88770413398743, 38.76397334039211, 1.933552490081638, 0.8610090392176062, 2.6222350168973207, 9.41604483872652, 2.580812727101147, 0.5734242021571845, 0.38995273935142905, 0.8492693910375237, 6.752181155607104, 36.29135102033615, 29.946922659873962, 40.34716218709946, 104.59888726472855, 21.85201182961464, 16.416487097740173, 60.5928748100996, 60.37329599261284, 50.91976046562195, 1.8117405264638364, 0.07269479727256112, 0.06098733232647646, 0.023490790372306947, 0.036463563301367685, 0.03127221803879365, 0.06765165147953667, 0.036026705492986366, 0.049556065059732646, 0.0032098596693685977, 0.049913798793568276, 0.032083270416478626, 0.10159356766962446, 0.04610634743585251, 0.007284499497473007, 0.041216072932002135, 0.03357947352924384, 0.03806106586125679, 0.029772294910799246, 0.035353718558326364, 0.09735640909639187, 0.02886386719183065, 0.044129251182312146, 0.09283913430408575, 0.08448687076452188, 0.0474783298705006, 0.02414286915154662, 0.04677160861319862, 0.05821639781061094, 0.04022239285404794, 0.05598588781140279, 0.10454775328980759, 0.13875078671844676, 0.1707355258986354, 0.2550789766246453, 0.1255375746404752, 0.20034462067997083, 0.15806886105565354, 0.20082830800674856, 0.12349188167718239, 0.1631845295196399, 0.16636417218251154, 0.1715980944572948, 0.1276797245373018, 0.08364338282262906, 0.15986539277946576, 0.1591535989427939, 0.1432894353638403, 0.22467789152869955, 0.15197860426269472, 0.08519936222000979, 0.22800186707172543, 0.10013285776949488, 0.0940669359988533, 0.4127665964188054, 0.12392880627885461, 0.11835962621262297, 0.1332152110990137, 0.1469850933062844, 0.1895392028382048, 0.10726226231781766, 0.12984611297724769, 0.16859204013599083, 0.20309102721512318, 0.14512644382193685, 0.2577119384659454, 0.17516421794425696, 0.13589523994596675, 0.6722879502922297, 10.578644704073668, 104.89003524184227, 99.19105544686317, 84.69424813985825, 60.58554120361805, 28.064499869942665, 72.20700100064278, 107.5586548447609, 66.45844906568527, 35.51881067454815, 9.57577021792531, 0.27714032563380897, 0.393413077108562, 0.8346075215376914, 0.15882570325629786, 0.36200642643962055, 1.451261944603175, 1.3558013294823468, 2.4959920160472393, 0.8785753778647631, 0.30012193776201457, 0.5738839181140065, 6.986827114596963, 43.250126615166664, 85.34525960683823, 106.0765215754509, 99.47366908192635, 92.0287361741066, 90.03597110509872, 92.91651293635368, 98.50438669323921, 88.21806505322456, 86.61666378378868, 88.05633813142776, 81.07540592551231, 88.6842392385006, 83.15415278077126, 80.62903627753258, 80.80083265900612, 82.01609864830971, 77.5554572045803, 76.2527959048748, 72.211484760046, 71.52073502540588, 66.2833696603775, 74.87847045063972, 77.31752917170525, 82.37917676568031, 85.27508497238159, 87.71488845348358, 79.04749274253845, 80.33565402030945, 56.429734602570534, 48.30347165465355, 79.33547168970108, 72.1244466304779, 78.59934478998184, 78.24182197451591, 85.12850403785706, 79.11806255578995, 80.56460693478584, 76.20574682950974, 80.59339419007301, 63.662665486335754, 64.82880771160126, 74.73088636994362, 80.32365426421165, 81.80311247706413, 82.93874233961105, 82.13332995772362, 79.58286121487617, 79.85318630933762, 84.26905855536461, 84.96736988425255, 77.18604102730751, 78.44387233257294, 80.72435796260834, 88.49050283432007, 86.8573048710823, 85.70698499679565, 83.6145968735218, 89.65076297521591, 91.3912595808506, 90.52251979708672, 89.78989630937576, 95.46685248613358, 83.66800680756569, 68.88727113604546, 30.607161931693554, 1.5410112286917865, 0.7142645353451371, 3.4645799919962883, 9.698419086635113, 3.0995326302945614, 1.8674876913428307, 0.6652573775500059, 1.0232348623685539, 4.616783140227199, 25.967686884105206, 37.62827128171921, 74.7041966021061, 89.48452949523926, 21.615742407739162, 59.78906974196434, 84.23275530338287, 73.13444003462791, 65.28481364250183, 3.3007351588457823, 0.30965639802161604, 0.20717275037895888, 0.17203078139573336, 0.16056592081440613, 0.08929762785555795, 0.17980179487494752, 0.10519417133764364, 0.17069087829440832, 0.1466797589091584, 0.21412988018710166, 0.15568532020552084, 0.1674899211502634, 0.10962310087052174, 0.07757312690955587, 0.13850072748027742, 0.1467101721209474, 0.21257950400467962, 0.12491290894104168, 0.19506229553371668, 0.14725017361342907, 0.14131593110505491, 0.10968519636662677, 0.22420416382374242, 0.13884514337405562, 0.11193909886060283, 0.11404917313484475, 0.12615342362551019, 0.11925730577786453, 0.1482113142265007, 0.16905888071050867, 0.33951944089494646], [0.03626740995969158, 0.03241863953007851, 0.018226048559881747, 0.01497532670327928, 0.04174202185822651, 0.044401144405128434, 0.03693371014378499, 0.026490987293072976, 0.058458664498175494, 0.008811613060970558, 0.018509333749534562, 0.027893494261661544, 0.0251365084113786, 0.05542380742554087, 0.16182918974664062, 0.06968210072955117, 0.02366164575505536, 0.029739644123765174, 0.07350062121986412, 0.03590031403291505, 0.029009992358624004, 0.025945152519852854, 0.045396449786494486, 0.009997137385653332, 0.07679471047595143, 0.020119886976317503, 0.03774809847527649, 0.07328785490244627, 0.049042146347346716, 0.05421507521532476, 0.014230263313947944, 0.04821638831344899, 0.008171478220901918, 0.018538476033427287, 0.07689347548875958, 0.14154141041217372, 0.037402532252599485, 0.1760451917652972, 3.8465069979429245, 70.67018866539001, 81.39958932995796, 78.94605338573456, 62.47293792665005, 19.199203178286552, 47.24402390420437, 101.19778856635094, 62.529737278819084, 27.193844988942146, 17.99084521830082, 2.0853366516530514, 0.6449348211754113, 0.12490430002799258, 0.10124534455826506, 0.08439390934654512, 0.07588828098960221, 2.876501460559666, 11.236430257558823, 7.496050139889121, 1.5755596873350441, 0.46809412131551653, 0.3229882795130834, 1.3151889899745584, 17.32336163520813, 55.79281657934189, 87.46161684393883, 108.57706859707832, 94.06737998127937, 86.99308678507805, 85.32771974802017, 80.2163328230381, 98.04089516401291, 87.9144537448883, 77.76130735874176, 82.70623281598091, 80.21051913499832, 84.10661727190018, 81.9321383535862, 79.21683445572853, 74.15647879242897, 70.11671036481857, 66.16953536868095, 60.42834363877773, 60.90991459786892, 67.0425233244896, 72.06123322248459, 68.34434866905212, 74.0008619427681, 70.26817783713341, 74.08703371882439, 38.93414340913296, 17.102194502949715, 77.80036926269531, 69.80732336640358, 72.49915972352028, 72.9082153737545, 71.4871372282505, 67.88432255387306, 67.68533483147621, 70.57249590754509, 66.58420711755753, 58.859514221549034, 51.610301211476326, 64.99127939343452, 70.44616788625717, 77.21388593316078, 72.39902749657631, 75.81011205911636, 73.24589565396309, 73.02888929843903, 73.07838544249535, 74.53082710504532, 79.19542640447617, 81.25629141926765, 76.22746646404266, 79.26726534962654, 79.35499504208565, 87.74521842598915, 91.54569089412689, 91.6780073940754, 77.7430759370327, 56.45591139793396, 29.586310610175133, 15.928680673241615, 8.120640199631453, 0.5010943114757538, 0.3086764959152788, 0.06351535077556036, 0.43199956126045436, 2.2352951299399137, 2.0497662853449583, 0.6413503072690219, 0.5793827574234456, 0.18883909040596336, 10.891486667096615, 12.865738179534674, 24.83433309942484, 84.12514507770538, 60.58735750615597, 9.025804828852415, 45.29369495809078, 53.21436233818531, 58.124819844961166, 34.84803646802902, 0.6119306827895343, 0.2850269805639982, 0.06933694268809631, 0.05248963752819691, 0.044991559989284724, 0.014221467936295085, 0.06953266187338158, 0.004818317720491905, 0.018652291801117826, 0.017913392875925638, 0.03601366595830768, 0.029938187180960085, 0.029266627025208436, 0.06084353750338778, 0.11778643587604165, 0.03466875336016528, 0.08885760849807411, 0.05615592126559932, 0.060200674342922866, 0.09602219084626995, 0.10734314157161862, 0.06859246466774493, 0.04919372629956342, 0.05156363760761451, 0.0694985527661629, 0.00970761908320128, 0.019587817187129986, 0.03709280434122775, 0.0037372339829744305, 0.0347822648473084, 0.031076389386726078, 0.05232836883806158, 0.0404209693078883, 0.019715965681825764, 0.03970857062085997, 0.04605516522133257, 0.06883021167595871, 0.013182062284613494, 0.08428201574133709, 0.021063540734758135, 0.05278686025121715, 0.029843247939425055, 0.002397929238213692, 0.03204278997145593, 0.012743654315272579, 0.04726547820609994, 0.036804405754082836, 0.053475539898499846, 0.09490286887739785, 0.05435160441265907, 0.02876702248613583, 0.056786876666592434, 0.02832098431099439, 0.022767738155380357, 0.021303955763869453, 0.027230734121985734, 0.018479375103197526, 0.012666272432397818, 0.042201737815048546, 0.06645999979809858, 0.02840208249835996, 0.05487159018230159, 0.024017305186134763, 0.1295091927750036, 0.042260916670784354, 0.04168293948168866, 0.02788060315651819, 0.03754097248020116, 0.10045644157798961, 0.05862575533683412, 0.1596314084599726, 8.900328911840916, 90.61678513884544, 81.86800539493561, 67.12595924735069, 30.533975958824158, 19.92668554186821, 84.66092392802238, 101.72222882509232, 44.63734857738018, 37.686503157019615, 30.532594732940197, 1.9895790587179363, 0.8115055924281478, 0.08421344129601493, 0.1254375628195703, 0.13717802736209705, 0.06695547242998146, 3.501477437093854, 13.761090785264969, 8.91307532787323, 3.3770773373544216, 0.6397136638406664, 0.031018468471302185, 5.542791550979018, 34.9357433617115, 73.75750780105591, 96.95971637964249, 102.01038256287575, 87.33658835291862, 84.54773560166359, 84.00728300213814, 83.303651958704, 96.88991412520409, 85.61181530356407, 84.54052358865738, 80.70291191339493, 81.34427949786186, 81.62582919001579, 80.04939258098602, 76.27152889966965, 71.41843691468239, 68.68307009339333, 67.06501051783562, 62.44769208133221, 65.45562967658043, 73.13661351799965, 75.98514586687088, 73.32071363925934, 73.13901498913765, 72.62323066592216, 76.6298420727253, 43.135828748345375, 25.959086045622826, 79.66365247964859, 71.57653883099556, 77.8782194852829, 74.35779958963394, 76.85377925634384, 70.82851096987724, 73.19541916251183, 75.71306526660919, 74.80816662311554, 63.20422388613224, 55.84931194782257, 69.20431092381477, 75.49729764461517, 81.36093020439148, 78.86345341801643, 76.04171723127365, 75.64882591366768, 81.17284789681435, 73.86929020285606, 73.62421095371246, 76.87598526477814, 82.16611459851265, 78.80302146077156, 78.55196133255959, 75.46031802892685, 78.71062561869621, 87.89842620491982, 94.71741870045662, 82.78843760490417, 68.83579149842262, 46.78916171193123, 28.910611867904663, 19.7702669352293, 2.548250611871481, 0.17875309567898512, 0.41676350694615394, 0.7667464285623282, 2.678567706607282, 2.6629246585071087, 1.2143415701575577, 0.19992079498479143, 0.3210676013259217, 18.429786264896393, 26.38076461851597, 18.550467789173126, 69.76492524147034, 95.85834547877312, 17.786836065351963, 22.93002348393202, 50.482388734817505, 65.61333641409874, 48.64069975912571, 1.0799683118239045, 0.5362995411269367, 0.0056253342063428136, 0.1020347596204374, 0.031189116052701138, 0.022472908858617302, 0.06428545515518636, 0.03434704718529247, 0.002389213409514923, 0.03536964133672882, 0.03709995864483062, 0.02467231544869719, 0.07749675991362892, 0.08560984409996308, 0.020107871605432592, 0.03756237972993404, 0.016868951752258, 0.03493916599836666, 0.02476005956850713, 0.055077116849133745, 0.057797384943114594, 0.0418056536000222, 0.03976163417974021, 0.03927247351384722, 0.059717150288634, 0.02797589677356882, 0.024484221830789465, 0.01576497554196976, 0.013566416855610441, 0.0547905624989653, 0.03975275067205075, 0.044820917973993346, 0.04767673191963695, 0.10000274443882518, 0.15158729947870597, 0.11385664518456906, 0.16783080442110077, 0.12878699402790517, 0.15788770280778408, 0.07757935352856293, 0.1460502395639196, 0.13719153444981202, 0.11336614494211972, 0.07560112921055406, 0.10352074707043357, 0.18580133153591305, 0.17281563224969432, 0.23185523139545694, 0.17968075058888644, 0.1957015963853337, 0.10634051490342245, 0.24390091159148142, 0.2024977543624118, 0.1415122885373421, 0.06983169543673284, 0.15578274935251102, 0.09597555428626947, 0.1669893870712258, 0.23167343490058556, 0.1723038768977858, 0.14421137573663145, 0.24870820285286754, 0.1590050061349757, 0.17962136393180117, 0.11097135313320905, 0.12193994698463939, 0.10130181457498111, 0.21327716734958813, 0.22533697803737596, 0.24955692293588072, 0.28652674227487296, 8.875549491494894, 103.12396600842476, 101.45710185170174, 103.18707302212715, 83.96130546927452, 35.84067240357399, 63.976004272699356, 117.33314394950867, 80.50646245479584, 46.28684766590595, 27.748468928039074, 3.1914620473980904, 0.7111791602801532, 0.38909238239284605, 0.30395103385671973, 0.15977859118720517, 0.28259965300094336, 5.593148348852992, 17.55620364099741, 9.986480679363012, 2.434858758933842, 1.0580263892188668, 0.5562493018805981, 2.6943508721888065, 23.122942931950092, 62.3127993196249, 91.71894639730453, 110.58695554733276, 96.9711385667324, 88.5347780585289, 91.5111431479454, 84.59680616855621, 108.06985661387444, 93.4008501470089, 88.70288103818893, 88.30708667635918, 91.45238310098648, 91.08849182724953, 90.40191426873207, 85.92318579554558, 79.78647708892822, 76.14118829369545, 76.25967353582382, 69.00755748152733, 72.83868670463562, 78.0267383158207, 83.42606619000435, 77.86766365170479, 79.25340369343758, 76.30819693207741, 82.3356918990612, 46.654595732688904, 27.60117933154106, 85.85904523730278, 77.74632856249809, 82.73777112364769, 79.3245966732502, 82.1319392323494, 78.17374482750893, 81.22278481721878, 83.88356924057007, 82.6510901749134, 71.08997493982315, 62.47034266591072, 75.2811424434185, 84.03282523155212, 85.36432698369026, 81.53912544250488, 79.74771916866302, 82.83131450414658, 89.66894119977951, 78.73052895069122, 78.11401963233948, 85.94617456197739, 89.82980936765671, 85.39679244160652, 83.34600448608398, 82.12699949741364, 88.5364119708538, 101.09264060854912, 109.31924477219582, 89.11679282784462, 62.2627180069685, 35.52838236093521, 20.009304508566856, 11.76773864775896, 1.3605177076533437, 0.363479916122742, 0.39167597657069564, 1.1277883895672858, 4.826069734990597, 5.744308037683368, 1.5504764020442963, 0.5677261110395193, 0.34234586579259485, 16.391378045082092, 24.32379249483347, 34.185587614774704, 102.26666361093521, 71.47679418325424, 19.592634066939354, 64.98576208949089, 68.28192561864853, 77.35270768404007, 60.90781711041927, 1.6241553984582424, 0.7979910238645971, 0.16970389609923586, 0.15780824847752228, 0.1329448467004113, 0.10787304243422113, 0.18673746177228168, 0.08621375192888081, 0.08647443872177973, 0.22197864105692133, 0.10206142498645931, 0.17161091876914725, 0.2981457766145468, 0.14606720505980775, 0.22426358016673476, 0.1059443861595355, 0.18258281517773867, 0.11726058713975362, 0.13743601273745298, 0.2933774481061846, 0.257561223115772, 0.134758269705344, 0.14954167330870405, 0.10120830396772362, 0.1790136785712093, 0.11361320590367541, 0.14147155947284773, 0.14552972686942667, 0.11866651169839315, 0.12987389898626134, 0.07120657595805824, 0.24769949057372287, 0.14833684108452871], [0.02909434671892086, 0.07292839567526244, 0.0667754867754411, 0.07819040081813, 0.048792558372952044, 0.07336401409702376, 0.05303859303239733, 0.0301886063607526, 0.0691728835226968, 0.031907607772154734, 0.06044731228030287, 0.0386273096955847, 0.06461372191552073, 0.11655763228191063, 0.02934004027338233, 0.08549862584914081, 0.06228002370335162, 0.012625530380319105, 0.021509452744794544, 0.053723825403722, 0.08948417409555987, 0.024777067737886682, 0.010566013988864142, 0.08611465294961818, 0.09467770127230324, 0.008174096146831289, 0.026103406235051807, 0.07715359824942425, 0.05013735222746618, 0.01409426567988703, 0.10723864717874676, 0.004533286628429778, 0.017750465485733002, 0.028933690300618764, 0.059165894126635976, 0.08062704233452678, 0.09123200608883053, 0.041068300197366625, 0.15003380627604201, 1.3712404947727919, 45.62001384794712, 74.79960948228836, 71.73712581396103, 57.12347477674484, 26.212355755269527, 40.19808478653431, 103.2760414481163, 94.24844026565552, 36.41869738698006, 22.45906725525856, 12.163381017744541, 0.2390107372775674, 0.2940560382558033, 0.23148383101215586, 0.1790312526281923, 0.5047167045995593, 0.3588170913280919, 1.9435967761091888, 7.951591545715928, 1.1129422299563885, 0.20851317298365757, 0.10684613269404508, 0.07048097075312398, 0.09335100839962251, 4.471157379448414, 30.217855721712112, 84.26618590950966, 111.54622927308083, 103.58093708753586, 86.78882494568825, 93.58224481344223, 84.1515764594078, 87.74961099028587, 85.04841953516006, 84.66798394918442, 87.32787162065506, 84.25518929958344, 82.87787720561028, 79.87865254282951, 73.48225057125092, 70.12379318475723, 63.38646970689297, 58.57756935060024, 57.82419517636299, 65.09590297937393, 66.57550558447838, 73.46450552344322, 65.62173396348953, 79.86611321568489, 23.91940489411354, 1.7951629660092294, 66.14759534597397, 78.17257449030876, 71.38530269265175, 74.2067500948906, 70.20433366298676, 69.6932002902031, 67.78602942824364, 68.38020354509354, 67.40377753973007, 65.96243128180504, 56.67180061340332, 62.77509771287441, 67.97325298190117, 73.14640939235687, 73.1315065920353, 76.43552049994469, 78.84793505072594, 76.36988282203674, 74.92763981223106, 75.51482230424881, 69.60964277386665, 66.74692958593369, 75.51020935177803, 86.69275090098381, 96.46908670663834, 88.92619505524635, 63.59653003513813, 25.799743495881557, 4.531763652339578, 0.8154640893917531, 0.16559732583118603, 0.2914371178485453, 0.3016326832585037, 0.20377637090859935, 0.36642484716139734, 0.946770734153688, 0.4319057537941262, 0.4763975366950035, 0.2753704518545419, 0.4532110918080434, 1.447938191704452, 19.28815070539713, 33.69510233402252, 48.67388717830181, 89.23054352402687, 46.503766626119614, 11.587970294058323, 41.7327768355608, 51.59783028066158, 61.12336054444313, 33.11931923031807, 0.2265449718106538, 0.24520226754248142, 0.04831736863707192, 0.045912594941910356, 0.016244903890765272, 0.05187486094655469, 0.00860275136801647, 0.03515350937959738, 0.09008863853523508, 0.08090013783657923, 0.055438041817978956, 0.06593118989258073, 0.03852732384984847, 0.05439731328806374, 0.12235731599503197, 0.11608581189648248, 0.09179989006952383, 0.02053771797363879, 0.047829799877945334, 0.04931659255817067, 0.05238594465481583, 0.005647516536555486, 0.08028327210922725, 0.15061989513924345, 0.09810278701479547, 0.036096096300752833, 0.05612570843368303, 0.038122059268062, 0.05897792667383328, 0.017415619586245157, 0.06830914979218505, 0.03599641102482565, 0.10990123555529863, 0.020140947272011545, 0.02611277213873109, 0.06852068414445966, 0.089971089764731, 0.020556483177642804, 0.048546291509410366, 0.08335341830388643, 0.03839041244646069, 0.05008262625779025, 0.03571369357814547, 0.03259889977925923, 0.03331688312755432, 0.05277914191538002, 0.025776805596251506, 0.13250289775896817, 0.04459143106942065, 0.08162975806044415, 0.05374522523197811, 0.05853903909155633, 0.04873861907981336, 0.039071095452527516, 0.022862159748910926, 0.04378291683678981, 0.11568125235498883, 0.005585473454630119, 0.03395082938368432, 0.04811572711332701, 0.06958058977033943, 0.14310057362308726, 0.10548143443884328, 0.030916072500986047, 0.0827247004781384, 0.019953688570240047, 0.04271859172149561, 0.11821635460364632, 0.04239967973262537, 0.0725108856568113, 0.04377559554995969, 0.03467288341198582, 0.2960292901843786, 3.796030031517148, 71.84117183089256, 85.19614800810814, 73.54625433683395, 38.90556514263153, 21.2015513330698, 66.54749348759651, 127.45396926999092, 70.85835456848145, 37.898763567209244, 42.91607514023781, 16.659295968711376, 0.7022282655816525, 0.45930234307888895, 0.2300269654369913, 0.48782729369122535, 0.5157141457311809, 1.6745050717145205, 7.862587971612811, 10.259269941598177, 3.2872375706210732, 0.8433504961431026, 0.6205205374862999, 0.07919381416286342, 0.5927364283706993, 11.764149740338326, 49.1767293959856, 97.2637152671814, 101.66874289512634, 91.51548251509666, 79.21437978744507, 95.55047079920769, 86.026791036129, 85.14932692050934, 87.71349012851715, 82.78534457087517, 86.79301232099533, 86.43311843276024, 85.52113696932793, 84.41865652799606, 80.26278153061867, 74.46180760860443, 69.05673444271088, 66.68492451310158, 66.1328749358654, 75.26829153299332, 73.47209751605988, 83.73195737600327, 67.6807826757431, 78.13503250479698, 29.24331061542034, 4.004283081740141, 74.4040735065937, 79.60160940885544, 70.52853986620903, 77.2147598862648, 75.58966308832169, 72.32924804091454, 73.53770479559898, 74.14736688137054, 72.36717000603676, 68.23768839240074, 59.29753951728344, 68.0463382601738, 71.79899409413338, 76.47861018776894, 72.5621223449707, 77.34468251466751, 80.15761837363243, 79.63260054588318, 79.26313117146492, 77.05653637647629, 74.66350838541985, 68.12241777777672, 73.0662488937378, 81.20660528540611, 90.1168991625309, 90.96633598208427, 76.10500663518906, 46.22836880385876, 16.21043175458908, 4.206110676750541, 0.48640038119629025, 0.521564525552094, 0.13857356185326353, 0.35347534983884543, 0.8988257974851876, 0.814043499995023, 0.8952828438486904, 1.3918787310831249, 0.13604414445580915, 0.5888044112361968, 2.4605852784588933, 37.162636667490005, 42.65516594052315, 28.207982070744038, 87.29661449790001, 78.93916815519333, 13.016858920454979, 22.24938690662384, 52.037884667515755, 66.43748179078102, 42.49276265501976, 0.5408150050789118, 0.16227961401455104, 0.049803307847469114, 0.047551513052894734, 0.012506747789302608, 0.04266641131835058, 0.052421077925828286, 0.009577396285749273, 0.03368240570125636, 0.018195770790043753, 0.0540370154340053, 0.02605702386063058, 0.0546512428263668, 0.013329467656149063, 0.09152629732852802, 0.009149030502157984, 0.03669323203212116, 0.052322179326438345, 0.03338439259096049, 0.05209524169913493, 0.0560110057995189, 0.04674598225392401, 0.05896402624784969, 0.07977343891980127, 0.049877682176884264, 0.03529890353092924, 0.03136851912131533, 0.07523375126766041, 0.03731502562004607, 0.03278744981798809, 0.017611370312806685, 0.018738085927907377, 0.10876655112951994, 0.033060897840186954, 0.10975745928590186, 0.3042489319341257, 0.18992409546626732, 0.10680496576242149, 0.1698855441645719, 0.23458646843209863, 0.08136338641634211, 0.15270118892658502, 0.1286332358722575, 0.11397046837373637, 0.1592614478431642, 0.13193699531257153, 0.11655681591946632, 0.24286499217851087, 0.06678478588582948, 0.13006850495003164, 0.1364435238065198, 0.1276441162917763, 0.15095366863533854, 0.16443381638964638, 0.22406135976780206, 0.16707185452105477, 0.2401675228611566, 0.15559182444121689, 0.2170862551429309, 0.11649865380604751, 0.17834405356552452, 0.3172014275332913, 0.25552067323587835, 0.1802894749562256, 0.1785971556091681, 0.0764785407227464, 0.12626720970729366, 0.24218767852289602, 0.11448281002230942, 0.14429255184950307, 0.12482925405493006, 0.14105937065323815, 0.4326557682361454, 3.734577354043722, 78.95124390721321, 104.74476903676987, 94.03356179594994, 72.45632082223892, 41.0287544131279, 61.190689131617546, 125.41015774011612, 108.91429290175438, 59.13557320833206, 39.98837783932686, 18.38426660746336, 0.9022428828757256, 0.35346148652024567, 0.4060402448521927, 1.0095216357149184, 1.2362101092003286, 5.484960079193115, 13.381663095206022, 18.795313350856304, 2.170743956230581, 0.6974351196549833, 0.3727524873102084, 0.1770665353978984, 0.27302357309963554, 6.000725878402591, 33.84288780391216, 91.57186388969421, 115.39263367652893, 103.81449535489082, 87.4011392891407, 102.32849389314651, 93.52046012878418, 102.4559998512268, 97.44743540883064, 93.80992859601974, 95.06231099367142, 99.95242059230804, 93.49918127059937, 97.79619589447975, 88.63928765058517, 84.58327129483223, 78.91852006316185, 77.71472945809364, 74.65198740363121, 84.52251255512238, 80.76164916157722, 90.46123668551445, 69.54194560647011, 85.29914528131485, 31.58342644572258, 3.45826568081975, 75.92704698443413, 86.09065040946007, 77.96249896287918, 83.54934677481651, 83.63164275884628, 80.12161910533905, 78.97870883345604, 79.67209562659264, 78.39877635240555, 75.90022802352905, 68.2878153026104, 72.26392954587936, 79.66046825051308, 84.39936876296997, 82.72245034575462, 83.06236490607262, 84.61990892887115, 87.15075552463531, 85.60451209545135, 82.7581836283207, 75.13944044709206, 70.76060101389885, 81.45562872290611, 91.99092820286751, 105.79102009534836, 100.32723248004913, 73.93817290663719, 29.731876999139786, 7.085328279063106, 1.3500674371607602, 0.14460501086432487, 0.365847812499851, 0.5105928517878056, 0.4268765455344692, 1.5331791364587843, 1.653255543205887, 2.335758889093995, 2.443546517752111, 0.466199655784294, 0.5477904807776213, 2.416407186537981, 27.417782172560692, 49.39250461757183, 57.235443368554115, 104.135532528162, 60.162129923701286, 21.81806445121765, 59.50014464557171, 68.04209768772125, 77.14988976716995, 52.26571664214134, 1.2187945749610662, 0.4666523658670485, 0.24127707816660404, 0.23257790511706844, 0.1458949377411045, 0.17428299179300666, 0.09568632449372672, 0.11610875168116763, 0.15220102592138574, 0.2236951544182375, 0.173509540327359, 0.1838362283888273, 0.17231993697350845, 0.10864213749300689, 0.20724864240037277, 0.13094648049445823, 0.19886552036041394, 0.1741033178404905, 0.12164164814748801, 0.09991228405851871, 0.16775129071902484, 0.1249816466588527, 0.2362513283151202, 0.22839109384221956, 0.1690778648480773, 0.19241843896452338, 0.1345808370388113, 0.1611433265497908, 0.15096738352440298, 0.12671635748120025, 0.13731060462305322, 0.09797754959436134, 0.17517946165753528, 0.1204297061485704], [0.021563134141615592, 0.07355474604992196, 0.08824226417345926, 0.05748457340814639, 0.04845441733777989, 0.02552913978433935, 0.0413500231661601, 0.04781025541888084, 0.05091211358376313, 0.0366978704551002, 0.023503380907641258, 0.02243738967081299, 0.02967164484289242, 0.1192039750458207, 0.06215343928488437, 0.042916964084724896, 0.09825937275309116, 0.023650871626159642, 0.04880796535871923, 0.061875709070591256, 0.0323309102532221, 0.024137651853379793, 0.07423311355523765, 0.018208350193162914, 0.009130238395300694, 0.09523040091153234, 0.027417744204285555, 0.07838396035367623, 0.01908472640934633, 0.04506393051997293, 0.05086352517537307, 0.016988617499009706, 0.05343161588825751, 0.021190462830418255, 0.04340238432632759, 0.03519711797707714, 0.16885666031157598, 0.06643444765359163, 0.049463775285403244, 0.2326513480511494, 1.152323791757226, 12.436183579266071, 86.3367860019207, 80.8553597331047, 72.92182624340057, 43.93049530684948, 18.08894645422697, 61.38404555618763, 93.94024640321732, 56.35153479874134, 47.6199035346508, 23.419623412191868, 4.705163072794676, 0.003842451737909869, 0.7028994639404118, 0.16066760988906026, 0.14317030581878498, 1.9760910887271166, 1.8306684982962906, 7.645125165581703, 0.2930680912686512, 0.1971436635358259, 0.39486646943259984, 0.16550832748180255, 0.036891400304739363, 0.11779502252466045, 3.6444903630763292, 25.25016948580742, 64.91487309336662, 97.6423953473568, 101.19809255003929, 92.57520765066147, 88.26887592673302, 87.63151332736015, 94.67708766460419, 100.7681380212307, 96.96185946464539, 88.43074724078178, 81.25692218542099, 71.5616512298584, 68.53787988424301, 60.865080803632736, 57.408987656235695, 49.73616197705269, 48.21703389286995, 52.690609842538834, 53.46446491777897, 67.9689972102642, 58.95718418061733, 3.387902481481433, 0.2321997215040028, 46.68723978102207, 83.87455612421036, 70.99221378564835, 72.82035648822784, 69.13915202021599, 68.68651270866394, 65.17218008637428, 63.934533298015594, 62.20121830701828, 59.950614273548126, 53.39326433837414, 59.292098209261894, 68.07925209403038, 73.05058613419533, 75.50976857542992, 74.46301594376564, 72.2837644815445, 77.99344450235367, 67.91987344622612, 72.41794288158417, 82.70971342921257, 82.40109398961067, 72.38347873091698, 49.59494635462761, 31.231951005756855, 15.979328155517578, 2.5216869497671723, 0.55730119231157, 0.2777978387894109, 0.03981236739491578, 0.11298286277451552, 0.7537463761400431, 0.5442819034215063, 0.25853919563815, 0.5094029812607914, 0.746848558774218, 0.11325920146191493, 0.4944629844976589, 0.27102306950837374, 11.094897352159023, 19.121333956718445, 23.191880732774734, 62.73379012942314, 72.64098331332207, 29.12348784506321, 22.02445987612009, 71.97237119078636, 61.8402186781168, 67.9892349243164, 16.953535079956055, 0.13106780679663643, 0.17483290837844834, 0.020488582231337205, 0.03911134954250883, 0.03154417805490084, 0.03372830011358019, 0.07451924117049202, 0.03761361389479134, 0.04785209028341342, 0.05868827014637645, 0.05412206555774901, 0.04073425581736956, 0.046925270289648324, 0.020014511283079628, 0.013682646458619274, 0.03545917774317786, 0.028421296701708343, 0.07478537532733753, 0.030127110148896463, 0.02889113369747065, 0.10066718925372697, 0.020497204131970648, 0.12210387998493388, 0.08594426326453686, 0.08071864562225528, 0.06213157561433036, 0.13225141359725967, 0.056691651698201895, 0.029919811604486313, 0.04055765435623471, 0.05126853000547271, 0.03405519018997438, 0.12347817420959473, 0.017988969484576955, 0.015262687211361481, 0.0010930408961939975, 0.0530521669134032, 0.07188170027802698, 0.049783169670263305, 0.10674931952962652, 0.007363891672866885, 0.038438941483036615, 0.003474810332591005, 0.027851369959535077, 0.02585738242487423, 0.06501625539385714, 0.07816055906005204, 0.04390892238006927, 0.1410334400134161, 0.06790908766561188, 0.04883564746705815, 0.10695425618905574, 0.011913079742953414, 0.07817545396392234, 0.032928387372521684, 0.06392734663677402, 0.0584436582721537, 0.03385242060176097, 0.020865598817181308, 0.031600414295098744, 0.008079322960838908, 0.014278890685091028, 0.01798580608010525, 0.051360545185161754, 0.03819760990154464, 0.010300602498318767, 0.09868664943496697, 0.0242876603078912, 0.0420708378078416, 0.07979499088833109, 0.055940138117875904, 0.05352544190827757, 0.06673361480352469, 0.005393533656388172, 0.28081318479962647, 1.7524840123951435, 27.492147982120514, 100.11473268270493, 85.18329709768295, 58.08920815587044, 32.443445697426796, 31.386331021785736, 106.43081456422806, 92.97793284058571, 43.94165150821209, 53.755187317728996, 35.85828445851803, 7.446354031562805, 0.053791420214110985, 0.8090838755015284, 0.31497516261879355, 0.431846174178645, 1.3854676438495517, 1.751600916031748, 0.939326339866966, 1.9299053982831538, 1.4045573445037007, 1.2839866080321372, 0.4340624943142757, 0.11339621676597744, 0.036626872897613794, 9.899886175990105, 45.83526469767094, 82.78668209910393, 97.64242574572563, 99.2357562482357, 91.07580810785294, 92.70237162709236, 83.83070647716522, 87.75351718068123, 90.07836163043976, 85.64527630805969, 82.93036758899689, 79.01139467954636, 73.97981107234955, 78.42947870492935, 73.37648704648018, 72.34669670462608, 67.1893398463726, 70.39854124188423, 66.08046054840088, 63.14445309340954, 70.1001812517643, 70.25629207491875, 7.086501941084862, 0.3701808862388134, 53.1711358577013, 85.26752337813377, 76.47370845079422, 75.48886209726334, 74.00727599859238, 73.12348142266273, 71.31676957011223, 70.43386414647102, 70.96125304698944, 67.51943573355675, 58.280398696660995, 63.71951423585415, 72.5928246974945, 79.67651098966599, 81.47390574216843, 78.46363887190819, 75.33840537071228, 84.16721642017365, 69.84538212418556, 71.43327131867409, 79.76036489009857, 85.03496065735817, 85.54119989275932, 67.89276570081711, 53.74048970639706, 31.545726768672466, 11.451554764062166, 2.4635681184008718, 0.3300037421286106, 0.1492083302582614, 1.0193514707498252, 2.2574985260143876, 1.815331808757037, 0.4649341752519831, 0.6229603628162295, 0.6884864217136055, 0.2693606883985922, 0.7650499977171421, 0.5382946715690196, 16.30411572754383, 32.88495920598507, 18.789756149053574, 59.68985326588154, 102.93591409921646, 49.7940518707037, 17.497255504131317, 47.8614641726017, 62.65540413558483, 72.49268487095833, 24.29366011172533, 0.2618041110690683, 0.4117364657577127, 0.06641596075496636, 0.06416366129997186, 0.028959043920622207, 0.07478006154997274, 0.06620040396228433, 0.010507811057323124, 0.05290966713801026, 0.014462007275142241, 0.015615380834788084, 0.08379115926800296, 0.028723543764499482, 0.0112403609091416, 0.027852781895489898, 0.03448332405241672, 0.07716647451161407, 0.05353094122256152, 0.022717125539202243, 0.010803497534652706, 0.03634272681665607, 0.09418205052497797, 0.014929885928722797, 0.058747749571921304, 0.034575309546198696, 0.1017965302162338, 0.10318738175556064, 0.011593398703553248, 0.036235586667316966, 0.031086814706213772, 0.05861060068127699, 0.05411997641203925, 0.018183356514782645, 0.07152855672757141, 0.035790453912341036, 0.09065369493328035, 0.16454758762847632, 0.25206612423062325, 0.13052410940872505, 0.26910464745014906, 0.11987874313490465, 0.12110026626032777, 0.086551176791545, 0.11750512479920872, 0.14876179484417662, 0.1529700541868806, 0.16326813987689093, 0.24655536602949724, 0.2882486436283216, 0.18969726545037702, 0.13182307564420626, 0.24449336808174849, 0.10497787981876172, 0.19648889632662758, 0.10780969270854257, 0.17045095679350197, 0.17010563547955826, 0.1779756959876977, 0.20330528524937108, 0.07476022394257598, 0.20550551562337205, 0.14645839110016823, 0.15311719238525257, 0.09773770972969942, 0.15355136361904442, 0.13970135914860293, 0.18206910055596381, 0.1745352626312524, 0.1339579524938017, 0.3203581378329545, 0.1437564243678935, 0.2867128135403618, 0.15515474398853257, 0.10790208267280832, 0.620172203052789, 1.7975606373511255, 34.148816987872124, 120.3348308801651, 106.37620389461517, 87.95216292142868, 59.49376858770847, 35.5083954334259, 80.3335489332676, 107.56519049406052, 71.81109264492989, 67.92510196566582, 40.33852905035019, 7.648782469332218, 0.1676526147639379, 1.1006713821552694, 0.3321568015962839, 1.5704617858864367, 6.375481244176626, 16.780146583914757, 21.29009038209915, 4.331267410889268, 0.8078974485397339, 0.7153083512093872, 0.22000209399266168, 0.18080182402627543, 0.1412338050431572, 3.908575242385268, 27.9007438570261, 69.35866624116898, 101.37992799282074, 110.63571453094482, 106.18321985006332, 104.82658624649048, 93.32039326429367, 102.01705500483513, 104.68622177839279, 98.22469890117645, 92.852303981781, 91.07552692294121, 83.61546322703362, 89.04788732528687, 83.01859885454178, 82.70351976156235, 79.66722428798676, 78.16554486751556, 69.17887508869171, 65.04402056336403, 78.9227606356144, 72.0134849846363, 4.19240671209991, 0.39278124226257205, 52.25893020629883, 88.55211272835732, 86.43277645111084, 82.40793362259865, 82.38058269023895, 81.93635612726212, 80.96921682357788, 81.01483717560768, 79.9084809422493, 78.59527140855789, 67.56959304213524, 73.13447803258896, 80.99698573350906, 87.03468695282936, 87.02481508255005, 83.10337230563164, 82.39942967891693, 87.89812222123146, 70.48336029052734, 77.90552482008934, 90.27239441871643, 95.09590119123459, 85.54267421364784, 58.89866732060909, 36.606905087828636, 17.421329878270626, 4.285341175273061, 1.039557361509651, 0.665158701594919, 0.327411568723619, 0.7902972085867077, 1.4958710758946836, 2.7274207351729274, 1.3465772056952119, 1.107990383170545, 2.4878659145906568, 0.36437527276575565, 0.5458467069547623, 0.5118203046731651, 15.735704228281975, 30.710810869932175, 34.365101382136345, 80.55782809853554, 82.27459117770195, 40.556713342666626, 34.68874901533127, 90.95433622598648, 72.79998198151588, 87.32315227389336, 30.09348839521408, 0.3790739527903497, 0.6110400462057441, 0.10505766811547801, 0.12376211991067976, 0.10373614801210351, 0.1784496463369578, 0.17518067877972499, 0.11586503780563362, 0.16343337163561955, 0.12074269950971939, 0.09837633522693068, 0.1654703146778047, 0.11007443055859767, 0.1707147160777822, 0.11591134782065637, 0.09116254848777317, 0.18752584524918348, 0.1242278324207291, 0.08872378442902118, 0.042157234929618426, 0.13050923676928505, 0.09527627305942588, 0.29333018814213574, 0.13837148988386616, 0.1613952560001053, 0.13070256623905152, 0.20495469361776486, 0.13353207847103477, 0.08238061112933792, 0.11052455796743743, 0.08265120559372008, 0.15148154343478382, 0.24787389527773485, 0.1479503751033917, 0.1083528260642197], [0.06721805169945583, 0.03812972194282338, 0.033018369067576714, 0.051720483097597025, 0.06254086634726264, 0.06473263623774983, 0.045677018715650775, 0.031201803067233413, 0.007971386858116603, 0.13669177220435813, 0.037707695955759846, 0.0350487552350387, 0.05388985497120302, 0.039788032372598536, 0.03681306290673092, 0.040623178574605845, 0.032587904861429706, 0.027210471635044087, 0.04134546637942549, 0.08481313372612931, 0.04679864134232048, 0.02215659067587694, 0.05184134926821571, 0.029537783666455653, 0.09890734931104816, 0.02684862083697226, 0.011226383485336555, 0.0530062650796026, 0.013540632789954543, 0.030932425725040957, 0.05964888012385927, 0.008451719677395886, 0.04815997395780869, 0.05603514044196345, 0.02906673511461122, 0.05964365911495406, 0.059758651186712086, 0.03623977980169002, 0.08073699893429875, 0.04227019351674244, 0.17119403957622126, 0.1411367766559124, 5.954757845029235, 51.45705543458462, 81.86924412846565, 71.8770419061184, 57.26284369826317, 31.931829750537872, 45.3861477971077, 85.51428973674774, 75.3982825577259, 54.65911701321602, 36.66771322488785, 23.005766719579697, 5.725250635296106, 0.05085216660518199, 0.22287911851890385, 0.11485744616948068, 0.0677385347080417, 1.4244181662797928, 4.966602819040418, 2.4943281803280115, 2.5182445719838142, 0.7529354165308177, 0.2787780377548188, 0.5280960188247263, 0.07073843662510626, 1.2722441693767905, 2.210390316322446, 11.377791222184896, 37.27667234838009, 68.9769235253334, 89.39007416367531, 97.1431477367878, 101.92982688546181, 97.12026536464691, 92.95685917139053, 79.9821437895298, 69.49517011642456, 56.537105441093445, 47.41801656782627, 43.80172781646252, 40.42105682194233, 39.891904816031456, 28.05659629404545, 28.606521785259247, 29.166326746344566, 35.086720660328865, 3.80100111477077, 0.06152770118205808, 0.2688250655774027, 16.91465936601162, 84.78881746530533, 59.75689306855202, 67.98350483179092, 56.85277350246906, 63.90889227390289, 56.351511999964714, 60.974404737353325, 57.40018732845783, 57.90259636938572, 56.86713293194771, 61.92553550004959, 65.23149490356445, 69.60844203829765, 73.98076862096786, 74.88339498639107, 74.39287170767784, 71.90924897789955, 85.92838391661644, 76.6349869966507, 38.905200362205505, 13.256277423352003, 3.5882562305778265, 0.18080948299029842, 0.12091810611309484, 0.08916536229662597, 0.12194185430416837, 0.2574200072558597, 0.3698023018660024, 0.718955205520615, 1.5759680466726422, 3.8386874925345182, 1.0980574786663055, 0.4189869813853875, 0.1909840604639612, 0.3040199348470196, 0.05514402888366021, 5.263601532205939, 16.043457314372063, 35.48332057893276, 55.18247812986374, 83.54423984885216, 45.60896024107933, 16.965838819742203, 31.474716179072857, 60.26880159974098, 56.21530070900917, 46.63617432117462, 8.839359283447266, 0.055595844678464346, 0.5026439158245921, 0.043874716793652624, 0.1482551751541905, 0.023992784626898356, 0.03511075796268415, 0.04582286928780377, 0.027886360367119778, 0.11125005927169695, 0.04395660536829382, 0.024443758084089495, 0.039348510254058056, 0.03909422448487021, 0.07462846304406412, 0.030027293141756672, 0.033390288954251446, 0.054611478553852066, 0.04583937465213239, 0.04828042823646683, 0.05263175509753637, 0.08238239228376187, 0.058541599501040764, 0.12376965270959772, 0.08333530247909948, 0.07277030337718315, 0.04886811271717306, 0.11678651062538847, 0.07243483036290854, 0.061741591853206046, 0.045178855798440054, 0.07247754096169956, 0.034856453639804386, 0.07291390153113753, 0.021543947768805083, 0.05823311468702741, 0.11971000101766549, 0.10463403537869453, 0.032093022236949764, 0.06487122489488684, 0.044399136895663105, 0.0129020258464152, 0.018997527768078726, 0.012222964433021843, 0.07304042286705226, 0.017756794150045607, 0.08929306364734657, 0.05440854569314979, 0.03189953320543282, 0.02094695119012613, 0.03454276637057774, 0.11766600757255219, 0.08723491002456285, 0.05141985762747936, 0.08237126006861217, 0.04030537238577381, 0.05170448239368852, 0.019021937005163636, 0.03527934051817283, 0.04138078147661872, 0.03621761927206535, 0.06018901891366113, 0.04261470588971861, 0.03623119315307122, 0.04894174860964995, 0.06910666168550961, 0.14233193127438426, 0.031840443407418206, 0.04854052131122444, 0.043861439771717414, 0.0290170093649067, 0.06542381321196444, 0.04524719275650568, 0.017654769253567792, 0.01655198047956219, 0.10828310128999874, 0.022774549215682782, 0.12279686779947951, 0.43023512000218034, 13.703224640339613, 71.78788349032402, 90.65798252820969, 69.21313405036926, 32.65051178634167, 20.621117278933525, 73.92280653119087, 106.04240700602531, 78.14735144376755, 48.40349368751049, 40.265542566776276, 28.482760526239872, 6.8481934536248446, 0.06250451595406048, 1.0534440726041794, 0.11191638914169744, 0.11087246195529588, 1.2183166318573058, 2.9100363235920668, 2.89400237146765, 2.376333586871624, 2.293612975627184, 1.4088179846294224, 0.37480191327631474, 0.2728684345493093, 1.9052076735533774, 7.386707682162523, 27.70415000617504, 63.009681925177574, 87.12231025099754, 91.1385427415371, 98.65189477801323, 99.02787700295448, 99.43998008966446, 95.65696388483047, 93.1040708720684, 84.1386191546917, 77.53696739673615, 67.79695004224777, 67.07834780216217, 58.024695217609406, 57.32223831117153, 47.37844169139862, 55.23502551019192, 61.39631889760494, 63.6444378644228, 11.997330877929926, 0.05088013072963804, 0.2570754132466391, 24.465982764959335, 86.01349174976349, 66.84379398822784, 77.6962548494339, 69.53976452350616, 74.48443159461021, 68.56662914156914, 72.23144888877869, 69.8280094563961, 69.63559538125992, 66.49233564734459, 70.5337455868721, 73.35749566555023, 73.14859807491302, 75.40609493851662, 76.54329031705856, 75.83349600434303, 71.80948913097382, 83.1650809943676, 86.81741461157799, 61.06810010969639, 32.49523691833019, 13.95970992743969, 2.8860695846378803, 0.7942204980645329, 0.23886230774223804, 0.23020125139737502, 0.8683520264457911, 0.15746040386147797, 0.39921008166857064, 2.8199816308915615, 1.4160662144422531, 0.9066271944902837, 0.3319143271073699, 0.1528280961792916, 0.34516270214226097, 0.2835665229940787, 9.837701562792063, 33.58555041253567, 40.27550183236599, 44.03807133436203, 89.58366617560387, 77.33378469944, 23.238067254424095, 17.661744877696037, 49.19567137956619, 65.28871223330498, 57.86585234105587, 13.385836221277714, 0.03161093423841521, 0.38212483283132315, 0.040749904001131654, 0.1354228481068276, 0.02877844228351023, 0.11273769428953528, 0.015356413041445194, 0.015316991084546316, 0.040479836461599916, 0.02698124633752741, 0.04212008301692549, 0.034920957405120134, 0.02240649591840338, 0.03627550679084379, 0.033690368945826776, 0.05955298722255975, 0.0457802366145188, 0.06645986621151678, 0.018007478647632524, 0.03336785011924803, 0.02081859674945008, 0.05188696908589918, 0.06895801692735404, 0.11747543147066608, 0.08940045983763412, 0.05540016260056291, 0.11120074355858378, 0.035906058255932294, 0.07127629331080243, 0.011214638998353621, 0.07274604256963357, 0.03368092511664145, 0.06998683398705907, 0.026969444334099535, 0.023213032327475958, 0.07123226911062375, 0.2087092335568741, 0.16792234091553837, 0.13594953546999022, 0.1174117329355795, 0.1314165716757998, 0.1467053036321886, 0.11094468776718713, 0.169503397482913, 0.11143731055199169, 0.24634832167066634, 0.1659599391859956, 0.08859272857080214, 0.16165883716894314, 0.14026509452378377, 0.2680187963414937, 0.17051988746970892, 0.1832216707407497, 0.11281546394457109, 0.10853762083570473, 0.23272042715689167, 0.1340716049890034, 0.15336403070250526, 0.11895325529621914, 0.08625382048194297, 0.2430354486568831, 0.12762885773554444, 0.15176832413999364, 0.110439181298716, 0.26404394244309515, 0.23567557014757767, 0.12490778812207282, 0.09697642948594876, 0.18130137847037986, 0.2441734282183461, 0.13503746566129848, 0.1025033813493792, 0.1536028686678037, 0.11467499658465385, 0.19316273886943236, 0.28130374441388994, 0.4072755348170176, 0.38777035020757467, 15.625107362866402, 82.7088850736618, 107.92251572012901, 87.93354392051697, 75.43598413467407, 45.60272477567196, 67.91338339447975, 99.32686015963554, 87.80617475509644, 67.05164283514023, 56.354377046227455, 35.227259919047356, 9.64655376970768, 0.15265424066456035, 0.952420971589163, 0.1431638639769517, 0.24172347999410704, 6.8285048101097345, 15.470231473445892, 13.578959908336401, 5.845054406672716, 1.7139879218302667, 0.6997913494706154, 0.8707002410665154, 0.4899505485082045, 1.4167415094561875, 2.792021781206131, 12.987046670168638, 44.42736804485321, 80.62291100621223, 100.8887055516243, 113.35562378168106, 111.07668846845627, 111.79189369082451, 109.24143254756927, 109.93159711360931, 100.28778299689293, 91.81527882814407, 79.93531510233879, 79.21912953257561, 73.40228766202927, 69.32474926114082, 58.66039350628853, 71.40570759773254, 72.18207433819771, 65.62725126743317, 5.976837510243058, 0.5791192059405148, 0.3976899554254487, 22.74762947112322, 94.95841696858406, 70.71846887469292, 88.9914983510971, 78.73722419142723, 84.85437154769897, 79.68965828418732, 84.85374838113785, 80.46300798654556, 81.98857292532921, 78.32677021622658, 82.76022791862488, 84.96654912829399, 86.90526589751244, 86.76337391138077, 84.17332649230957, 77.65044450759888, 76.57480582594872, 96.45819649100304, 89.16835606098175, 50.48568315804005, 20.055439732968807, 6.089153308421373, 0.7112395414151251, 0.1862702946527861, 0.18960589222842827, 0.29283060401212424, 1.9925995403900743, 0.20168960007140413, 0.8222477347590029, 2.80614847317338, 12.925577368587255, 3.645697273313999, 1.3343114638701081, 0.2708103699842468, 0.4874686582479626, 0.214087666827254, 6.304050777107477, 23.618761226534843, 55.16969181597233, 67.74160221219063, 99.67106848955154, 57.098171934485435, 26.739229783415794, 44.688657224178314, 74.83782783150673, 76.61367774009705, 70.23559838533401, 17.447704263031483, 0.12036805594107136, 0.5827802501153201, 0.17893990909215063, 0.26877943833824247, 0.059422135454951786, 0.3434380399994552, 0.1206902667763643, 0.1251726012560539, 0.28900596080347896, 0.13979534473037347, 0.13448189391056076, 0.13295830925926566, 0.20740332081913948, 0.20087017997866496, 0.10669265655451454, 0.14963001856813207, 0.11024604478734545, 0.3156968270195648, 0.12093029959942214, 0.15144896315177903, 0.10598591674352065, 0.14561513322405517, 0.1947837823536247, 0.2387188357533887, 0.1856632178532891, 0.12620736291864887, 0.27879914443474263, 0.10741941950982437, 0.2359524357598275, 0.143714745354373, 0.18065514595946297, 0.08571528102038428, 0.26037108327727765, 0.12846556986914948, 0.1625742021133192, 0.2606671705143526], [0.04295845385058783, 0.07364728444372304, 0.09240177183528431, 0.04992280846636277, 0.06863440343295224, 0.026592073372739833, 0.07780078813084401, 0.009926994225679664, 0.0291365433804458, 0.05205531786486972, 0.019574621801439207, 0.037797184122609906, 0.1236490833980497, 0.07282491802470759, 0.04633154472685419, 0.10306144671631046, 0.027951862321060617, 0.09660456154961139, 0.10736791446106508, 0.031953743382473476, 0.05007780600863043, 0.018007454527833033, 0.021043539854872506, 0.04185345162113663, 0.018652206454135012, 0.05598724223091267, 0.03687511387397535, 0.09188763418933377, 0.05033610308601055, 0.0660701422020793, 0.1050840514653828, 0.0545173668069765, 0.1169554160151165, 0.07057003589579836, 0.0525680528517114, 0.04235129170410801, 0.0921491818735376, 0.03729118783667218, 0.06664222673862241, 0.043361087518860586, 0.1398864804650657, 0.1499091848381795, 0.27907623269129544, 0.37110206962097436, 25.476857721805573, 72.33484894037247, 81.50561884045601, 88.25482428073883, 50.55626817047596, 31.56784538179636, 55.49517475068569, 71.64387121796608, 79.02213290333748, 67.51521795988083, 52.00105704367161, 25.24741843342781, 3.6573367612436414, 0.18077982676913962, 0.05060719107859768, 0.15329637652030215, 0.9505547373555601, 1.8226199364289641, 2.7201201394200325, 5.541558992117643, 2.8995752474293113, 0.628281383542344, 0.8372579980641603, 27.101755030453205, 19.59085576236248, 0.6355075864121318, 0.10421784638310783, 1.9156104465946555, 9.223095942288637, 16.16891138255596, 20.889595672488213, 22.47291561216116, 26.89606636762619, 24.853145889937878, 18.344475142657757, 17.95064527541399, 16.06970250606537, 14.715713560581207, 14.383010063320398, 16.046500951051712, 11.35994927957654, 3.59713445417583, 1.7286389856599271, 0.13783341797534376, 0.4006477998336777, 1.4596125902608037, 0.6622068537399173, 1.3958237506449223, 57.72863030433655, 73.33323016762733, 58.72475065290928, 56.677310317754745, 53.03463198244572, 51.47665858268738, 49.449018985033035, 50.211026296019554, 50.102515518665314, 54.94965702295303, 58.8815226405859, 66.57856822013855, 75.64663723111153, 80.75144290924072, 79.85097482800484, 87.73334786295891, 75.91540440917015, 35.72126381099224, 3.9053124049678445, 0.06640643900027499, 0.1459513558074832, 0.6077190244104713, 0.4560860531637445, 0.03073456544370856, 0.469725361908786, 0.17861489293863997, 0.2359642062219791, 0.23336826270679012, 1.0226263012737036, 2.4525392102077603, 0.8086169755551964, 0.446394287282601, 0.09646795442677103, 0.09649156214436516, 2.5376731669530272, 17.364730015397072, 14.716515317559242, 41.07613027095795, 78.00892487168312, 54.92644026875496, 23.52665986865759, 22.7648064494133, 60.917149409651756, 64.1835643351078, 58.21469262242317, 28.163832239806652, 1.1448554112575948, 0.14720469480380416, 0.13341278565349057, 0.13841782958479598, 0.07625332116731443, 0.06402938452083617, 0.022224701278901193, 0.06741384509950876, 0.05999315500957891, 0.0811073232034687, 0.053087934720679186, 0.07407734417938627, 0.041585892540751956, 0.03768974340346176, 0.12590446276590228, 0.09358706331113353, 0.03675972475321032, 0.04103038758330513, 0.06177464339998551, 0.05837893928401172, 0.09673737629782408, 0.0685576802061405, 0.06561312766280025, 0.04404716593853664, 0.10352439101552591, 0.07729873264906928, 0.04710872548457701, 0.10367385955760255, 0.057764348239288665, 0.030584601518057752, 0.04663296800572425, 0.08057244995143265, 0.04827922224649228, 0.020904201628582086, 0.016169292030099314, 0.03877585426380392, 0.03572106310457457, 0.13393323897616938, 0.05952219922619406, 0.0206242301283055, 0.10145129053853452, 0.05982855407637544, 0.07659476847038604, 0.031371394943562336, 0.091006422881037, 0.11239518571528606, 0.03411399797187187, 0.03617347261752002, 0.0579315689537907, 0.03526025990140624, 0.04928764137730468, 0.016661961199133657, 0.0604926983214682, 0.05471654068969656, 0.02696129184187157, 0.08871971003827639, 0.009425037078472087, 0.01223938723342144, 0.04336446429078933, 0.04751987900817767, 0.1413665307336487, 0.06324682690319605, 0.06332515316898935, 0.01976001400180394, 0.1615804515313357, 0.04684543746407144, 0.03195025157765485, 0.05040550502599217, 0.10441033722599968, 0.05646167126542423, 0.05289074979373254, 0.040053569100564346, 0.12203696795040742, 0.01866762642748654, 0.055715308189974166, 0.07839092912035994, 0.011668713705148548, 0.06716982694342732, 0.16279834555462003, 0.32528801704756916, 0.6769341509789228, 0.5097755987662822, 41.91564962267876, 83.88451918959618, 90.02254262566566, 69.95265036821365, 33.04550439119339, 35.08360102772713, 72.62687087059021, 88.5821995139122, 79.08030778169632, 64.44601625204086, 54.98257465660572, 31.45455826073885, 6.144547685980797, 0.45987186720594764, 0.44946948008146137, 0.21400125115178525, 0.9257330442778766, 0.9882700885646045, 1.838661131914705, 4.036589898169041, 4.308292418718338, 1.3740427256561816, 1.467119324952364, 21.187860667705536, 7.881211247295141, 1.1281412956304848, 0.502607342787087, 12.025063689798117, 29.61061030626297, 35.5312056094408, 42.70181603729725, 42.27354481816292, 51.05963096022606, 51.23659886419773, 51.62790186703205, 51.99781581759453, 57.289389073848724, 55.34651532769203, 52.61985383927822, 50.37950925529003, 36.374114379286766, 25.183131583034992, 12.133499421179295, 1.554924538359046, 0.4681435483507812, 1.88219147734344, 0.8806823648046702, 3.259209324605763, 77.54131436347961, 75.33219650387764, 64.16119873523712, 61.185946986079216, 62.15366765856743, 61.003723964095116, 60.629801228642464, 61.011441349983215, 58.876031935214996, 61.86129614710808, 65.90266048908234, 68.8309733569622, 76.20029032230377, 77.42962315678596, 76.99427291750908, 81.98157370090485, 84.79326322674751, 51.77370384335518, 12.812089808285236, 0.3633457951946184, 0.06372454736265354, 0.7858677150215954, 0.6082030828110874, 0.10382586624473333, 0.6793316442053765, 0.09227532471413724, 0.6508995511103421, 2.286896836012602, 0.8619699126575142, 0.760994665324688, 0.5549223418347538, 0.10126940498594195, 0.15271966840373352, 0.2733055892167613, 3.778188326396048, 23.334392085671425, 23.247646540403366, 29.65592287480831, 81.17877557873726, 82.10087969899178, 41.49917297065258, 12.704648673534393, 33.28014940023422, 62.56645850837231, 67.37324237823486, 36.52479909360409, 2.663954640738666, 0.30483686132356524, 0.40654751763213426, 0.08750087348744273, 0.07764951616991311, 0.042668537571444176, 0.010380283183621941, 0.10516803289647214, 0.05487674810865428, 0.027941258886130527, 0.03672656930575613, 0.04544658928352874, 0.07653613880393095, 0.07958001297083683, 0.04817497276235372, 0.10579542227787897, 0.06630642717937008, 0.03658163528598379, 0.05597524170298129, 0.06577874533832073, 0.054759032354922965, 0.010711068607633933, 0.019531378711690195, 0.02741064556175843, 0.06508950536954217, 0.07732714206213132, 0.055987843370530754, 0.041753358163987286, 0.04386570712085813, 0.04291595105314627, 0.010972674735967303, 0.15051394613692537, 0.07442187881679274, 0.11021034748409875, 0.07999976427527145, 0.04347553782281466, 0.025586570882296655, 0.097852668404812, 0.1768738144892268, 0.12480868172133341, 0.21040613937657326, 0.13739111280301586, 0.15343247156124562, 0.07639891569851898, 0.25146572676021606, 0.19287775416160002, 0.1054498931625858, 0.1318719534901902, 0.08456975381704979, 0.21684480481781065, 0.2079464541748166, 0.21171551052248105, 0.2088254241971299, 0.26698830944951624, 0.23343983542872593, 0.33405637310352176, 0.19771204475546256, 0.10713726238464005, 0.1092094648629427, 0.07557145072496496, 0.17053738731192425, 0.24661107163410634, 0.2082062652334571, 0.17505001625977457, 0.1966831905883737, 0.21376901830080897, 0.17945950152352452, 0.19754138047574088, 0.34446499426849186, 0.14524604834150523, 0.2503892267122865, 0.17061945400200784, 0.29718472505919635, 0.08904241069103591, 0.156266555422917, 0.20282367593608797, 0.163022993656341, 0.22853680711705238, 0.2245883588329889, 0.242176175233908, 0.652523310855031, 1.1192947765812278, 49.81740161776543, 99.86443251371384, 107.38894835114479, 101.79599046707153, 69.13257837295532, 48.14130775630474, 75.42390078306198, 83.52456450462341, 87.58409947156906, 82.49876394867897, 70.4901011288166, 40.96874423325062, 6.786198355257511, 0.40810368256643414, 0.5368268815800548, 0.32770382647868246, 2.4842941062524915, 9.273193404078484, 14.879074394702911, 19.58036832511425, 9.049481358379126, 1.229387337807566, 1.6560153826139867, 33.763122484087944, 23.989826515316963, 0.8004786435049027, 0.16132444026879966, 4.0966053027659655, 13.852778915315866, 17.300828844308853, 22.70472787320614, 24.60047084838152, 36.44864737987518, 40.78888848423958, 43.39723192155361, 50.80834664404392, 66.12916633486748, 67.29751244187355, 67.21841588616371, 61.75191521644592, 44.79518450796604, 27.418179251253605, 9.735721684992313, 0.47371155582368374, 1.0807674564421177, 3.5550263011828065, 1.014903096947819, 1.811794911045581, 73.8684694468975, 90.654137134552, 72.58394077420235, 71.30198076367378, 74.33708310127258, 75.51657781004906, 75.31265035271645, 76.46685361862183, 73.57206255197525, 75.35915225744247, 81.18157982826233, 82.79894024133682, 89.9104106426239, 89.27033498883247, 88.38219344615936, 97.2647412121296, 87.58663773536682, 35.976902693510056, 6.198836322873831, 0.22823849343694746, 0.2062884220504202, 1.3132668868638575, 1.6615240182727575, 0.4554295790148899, 0.9204435499850661, 0.2467124638496898, 0.7695484219584614, 2.7185341995209455, 3.840613989159465, 5.328536247834563, 4.898233087733388, 1.054783381987363, 0.4898972623050213, 0.4624387779040262, 3.3541918778792024, 23.98125797510147, 26.671492718160152, 53.79469759762287, 93.9097036421299, 63.45002509653568, 37.141293212771416, 32.06547997891903, 79.5500385761261, 75.93900874257088, 81.22456312179565, 42.624550983309746, 3.1173662608489394, 0.3518631379120052, 0.5079103144817054, 0.4096086393110454, 0.21084713836899027, 0.12260176459676586, 0.11674247900373302, 0.23086418223101646, 0.1425791555084288, 0.08452123962342739, 0.17064817511709407, 0.21669132867828012, 0.1793363643810153, 0.13410087529337034, 0.1538817974505946, 0.16050206642830744, 0.17776471824618056, 0.12980692757992074, 0.12962274136953056, 0.17715228314045817, 0.1803408464184031, 0.1104044116800651, 0.15244139271089807, 0.16941932699410245, 0.4552060441346839, 0.14083268906688318, 0.26128891215194017, 0.12895458581624553, 0.21225056931143627, 0.24440718989353627, 0.16229733650106937, 0.26334534399211407, 0.20327222999185324, 0.14528567902743816, 0.17081158119253814, 0.13522398221539333, 0.07563006554846652, 0.20201955892844126], [0.0357093928323593, 0.11138066984131001, 0.06682448336505331, 0.04191025560430717, 0.07013054346316494, 0.04052428368595429, 0.024277138509205543, 0.035839799311361276, 0.0948217224504333, 0.019238093082094565, 0.06288715245318599, 0.02437027433188632, 0.027868077559105586, 0.10499388794414699, 0.038131035544211045, 0.07848757901228964, 0.0235157877614256, 0.011813343444373459, 0.030520079199050087, 0.024270752328447998, 0.031296916713472456, 0.07061653144774027, 0.03409951495996211, 0.028822811582358554, 0.08754344307817519, 0.12135626267991029, 0.019004516943823546, 0.046296949512907304, 0.04967847860825714, 0.0638536959013436, 0.03221081591618713, 0.06346732639940456, 0.04853121477935929, 0.03289279396994971, 0.053018759135738946, 0.016097329680633266, 0.06048604867828544, 0.10163780709262937, 0.07221042716992088, 0.0528778772422811, 0.1827252481598407, 0.046380942076211795, 0.058150357799604535, 0.12324588940828107, 0.5434197059366852, 6.453333366662264, 43.28700363636017, 68.54854971170425, 84.04313787817955, 73.17434549331665, 50.433800742030144, 46.29131622612476, 48.660743683576584, 80.99016889929771, 82.99788236618042, 68.80063578486443, 42.59103298187256, 19.85832531005144, 1.4677903451956809, 0.11284699779935181, 0.3447882441105321, 0.20285342121496797, 1.4793167891912162, 4.369567930698395, 3.897845330648124, 1.271957284770906, 4.3600389920175076, 96.9264605641365, 48.19971062242985, 0.7841984764672816, 0.5722244759090245, 0.035673124075401574, 0.40754965448286384, 0.17459467897424474, 0.37405183946248144, 0.4048159980447963, 0.46568620833568275, 0.8321716741193086, 0.6961331551428884, 1.2766695069149137, 2.361950408667326, 2.5352391600608826, 1.513066696934402, 1.700893824454397, 0.5884059669915587, 0.142522900714539, 0.4925741592887789, 0.20713352045277134, 0.18680766894249246, 0.6139476026874036, 0.5888225790113211, 0.7246591150760651, 4.547826340422034, 47.2052925825119, 57.93016009032726, 47.53504268825054, 33.89125920832157, 31.74609001725912, 25.882902033627033, 27.23826840519905, 30.740601271390915, 36.95715889334679, 43.20084325969219, 56.888130605220795, 67.7193658053875, 74.59540084004402, 68.42548191547394, 43.190530613064766, 5.356207313016057, 0.24071279360214248, 0.7797920191660523, 1.3246217463165522, 0.5853407783433795, 0.36299900442827493, 0.13192699116189033, 0.06003905684337951, 0.2753350365674123, 0.23358534090220928, 0.536752191837877, 1.2578469794243574, 2.174232881516218, 0.213827395637054, 0.1134016270225402, 0.2391805555089377, 0.5315112636890262, 11.265779882669449, 25.699482075870037, 50.12390457093716, 78.66223141551018, 78.22346895933151, 28.8371105119586, 19.773289673030376, 43.493773341178894, 73.429494202137, 64.62651416659355, 43.36493745446205, 10.589167289435863, 0.09326083003543317, 0.45080819574650377, 0.04712082620244473, 0.1255294110160321, 0.059928558475803584, 0.059339693980291486, 0.02403263239102671, 0.08102393549052067, 0.0444407454051543, 0.05669721038429998, 0.0495255998976063, 0.05108741999720223, 0.01090732213924639, 0.06380696286214516, 0.03211770235793665, 0.050870197082986124, 0.006785631076127174, 0.05644509910780471, 0.0038524570481968112, 0.047417674140888266, 0.011943288864131318, 0.04056523539475165, 0.0454720709240064, 0.11028828041162342, 0.018463020023773424, 0.05184155706956517, 0.05555297822866123, 0.020487020010477863, 0.0420144234522013, 0.19524337956681848, 0.03849268781777937, 0.09694078413303941, 0.006325004596874351, 0.08257915047579445, 0.03610045641835313, 0.05313347290211823, 0.046822412332403474, 0.09839221718721092, 0.051365205872571096, 0.026998339853889775, 0.042993806055164896, 0.032157184614334255, 0.06599791639018804, 0.02687531588890124, 0.01942788436281262, 0.029635953105753288, 0.035365240401006304, 0.09091703861486167, 0.09481011526077054, 0.03492950323561672, 0.09505124646238983, 0.0811233016429469, 0.035101451430819, 0.058083145195269026, 0.06717205338645726, 0.018276531300216448, 0.01182428733955021, 0.04206249977869447, 0.01872268821898615, 0.03227691529900767, 0.06458535703131929, 0.0255669076796039, 0.014640599547419697, 0.07463373971404508, 0.018932665916508995, 0.05154651997145265, 0.053856729209655896, 0.032847634283825755, 0.09127517681918107, 0.05168284878891427, 0.05719203363696579, 0.07535520373494364, 0.09469777636695653, 0.030326528940349817, 0.03966005642723758, 0.0101349597753142, 0.0588947059441125, 0.05001962163078133, 0.011955416484852321, 0.16093699465272948, 0.11649584848782979, 0.16576327005168423, 0.13315128249814734, 0.40848707605618984, 13.508322648704052, 55.40114499628544, 84.76305484771729, 89.42224323749542, 60.06516672670841, 35.2373331785202, 46.52031093835831, 65.68783521652222, 97.38989889621735, 89.81977790594101, 66.24912589788437, 42.511795833706856, 22.2574994713068, 2.632973240688443, 0.3422011766815558, 0.34128774132113904, 0.4109518969198689, 0.16814722650451586, 1.3422336825169623, 3.8497050013393164, 2.1525825932621956, 6.53207179158926, 87.52003490924835, 51.910105124115944, 1.3692846684716642, 1.0422426299192011, 0.5672109418082982, 0.7065786758903414, 1.1719193402677774, 1.7632016935385764, 2.6197672868147492, 1.6995865758508444, 3.84029908105731, 3.402031548321247, 4.7290965635329485, 8.57429975643754, 10.3243756480515, 11.297566127032042, 9.295821189880371, 4.404034456238151, 0.8742417697794735, 0.4589752934407443, 0.5725592735689133, 0.15835981263080612, 0.9416277694981545, 3.4941274439916015, 0.6907156552188098, 13.163315411657095, 69.76756989955902, 70.73292329907417, 66.91451579332352, 58.330563604831696, 56.62589907646179, 57.1309831738472, 57.19257406890392, 62.38475985825062, 65.51996782422066, 69.35187220573425, 75.14861315488815, 77.10857078433037, 82.960644364357, 81.53037831187248, 66.39997780323029, 16.060136519372463, 0.8265399606898427, 0.7375742658041418, 3.28339003957808, 0.4586972255492583, 1.0046516032889485, 0.11027333355741575, 0.4564737214241177, 0.6197862268891186, 0.0625506552751176, 0.23090446600690484, 0.5072900571394712, 0.17644764360738918, 0.1371147666941397, 0.35878957249224186, 0.4763611120870337, 0.38312566350214183, 13.203803189098835, 33.57125177979469, 48.50892663002014, 54.676143899559975, 92.12766006588936, 56.65682941675186, 17.554140351712704, 21.2449412047863, 58.84367287158966, 70.8348186314106, 55.69771908223629, 15.869294609874487, 0.14052395563339815, 0.3252614481607452, 0.20006440056022257, 0.11558404585230164, 0.16226861538598314, 0.126923787756823, 0.01545672914289753, 0.0495163490268169, 0.07277296026586555, 0.045095601672073826, 0.05218471873376984, 0.02831600450008409, 0.04281486682884861, 0.038192407446331345, 0.03650631471828092, 0.08266430450021289, 0.023488261504098773, 0.009854035542957718, 0.04165686412306968, 0.014878540441713994, 0.05592619316303171, 0.03343849144584965, 0.03730456875928212, 0.03321185809909366, 0.08163605889421888, 0.15182800765614957, 0.06308616677415557, 0.07923446901259013, 0.022897793969605118, 0.2100802623317577, 0.19084977626334876, 0.005234826303421869, 0.06370044240611605, 0.032948596053756773, 0.027867133176187053, 0.0559049491857877, 0.015602469320583623, 0.07992915634531528, 0.03737173312401865, 0.14804931823164225, 0.2008188678883016, 0.16775376949226484, 0.19821222260361537, 0.3080770483938977, 0.10215707297902554, 0.1463842802331783, 0.28845383261796087, 0.16881708899745718, 0.15366112726042047, 0.13751370075624436, 0.19050956092542037, 0.15726652520243078, 0.28953244036529213, 0.23344614368397743, 0.1689443673240021, 0.098018523567589, 0.09856547156232409, 0.19392376678297296, 0.13635409501148388, 0.06584282979019918, 0.1565683720400557, 0.12519661715487018, 0.08436331801931374, 0.1433597315917723, 0.21030397532740608, 0.12645014910958707, 0.1567057881038636, 0.12934776081237942, 0.21280710585415363, 0.1288007979746908, 0.18068861681967974, 0.35665129660628736, 0.15391034045023844, 0.1589645294006914, 0.1189214616897516, 0.11437168825068511, 0.11610124114667997, 0.30109765415545553, 0.20650837977882475, 0.2502764202654362, 0.20244702114723623, 0.1407396831200458, 0.24856498319422826, 0.5991192546207458, 13.851517383009195, 61.30943275988102, 96.73580959439278, 105.52538394927979, 88.15254896879196, 66.88537895679474, 65.96191450953484, 67.28283762931824, 97.0754125714302, 96.28282070159912, 85.9033052623272, 58.770762383937836, 29.496204145252705, 2.70330224186182, 0.3350779245374724, 0.5923528864514083, 1.7513932334259152, 3.6570871621370316, 9.925346709787846, 15.837228130549192, 8.951459918171167, 9.051267262548208, 123.34486216306686, 50.16460418701172, 1.8403005064465106, 1.0953830159269273, 0.6261898926459253, 0.6750603765249252, 0.552816423587501, 0.4818327591056004, 0.5593666189815849, 0.2397516233031638, 0.9099617530591786, 0.9166366886347532, 1.763464235700667, 4.269689815118909, 6.888690255582333, 9.62113218382001, 8.453756924718618, 3.6158985598012805, 1.1724425246939063, 0.6601386365946382, 1.0939339874312282, 0.6068704230710864, 1.0247917100787163, 2.2087497543543577, 0.9536215884145349, 6.836521904915571, 68.38899627327919, 92.84968972206116, 86.06870278716087, 75.13080731034279, 72.18295589089394, 69.43428978323936, 75.56285932660103, 81.20103478431702, 84.13136914372444, 87.51191854476929, 90.3655806183815, 87.23327189683914, 82.4405662715435, 76.67436048388481, 50.91449774801731, 7.671270137652755, 0.3231082105776295, 1.309243852738291, 5.531919384375215, 2.2914525540545583, 1.0876913974061608, 0.33502665697596967, 0.6433183641638607, 0.65931556513533, 0.2269769017584622, 0.44454550836235285, 4.500838061794639, 6.785486368462443, 0.99476512754336, 0.6298229133244604, 0.6530495232436806, 0.8683111786376685, 18.60150285065174, 41.07738800346851, 69.98774528503418, 87.57276087999344, 93.71991142630577, 44.58372965455055, 30.379483848810196, 56.46350719034672, 88.4448292851448, 83.917296230793, 66.13969936966896, 18.9791626855731, 0.4499628598568961, 0.6972086161840707, 0.318090490764007, 0.3442143858410418, 0.20957524568075314, 0.18137381208362058, 0.15463185642147437, 0.1553370599867776, 0.12261563533684239, 0.12131511059124023, 0.16358886641683057, 0.1176829804899171, 0.15560852276394144, 0.16542228288017213, 0.12168426968855783, 0.17366580694215372, 0.1443972540437244, 0.1287425245391205, 0.15133893233723938, 0.08896772094885819, 0.16336467844666913, 0.12209066975628957, 0.16498909128131345, 0.21517581859370694, 0.15650946035748348, 0.22691540740197524, 0.13659057294717059, 0.14778359967749566, 0.1227217105042655, 0.42729223729111254, 0.29957809194456786, 0.16513759503141046, 0.11749146928195842, 0.14989610819611698, 0.18442406872054562, 0.12222034521983005, 0.11441101465607062, 0.24737836327403784, 0.11472025274997577], [0.025115067765000276, 0.0409199114801595, 0.021789576385344844, 0.054178142236196436, 0.03453492186963558, 0.08297378750285134, 0.08650908959680237, 0.04736296301416587, 0.021842643654963467, 0.028996190267207567, 0.03369629128428642, 0.01796956974430941, 0.08081788560957648, 0.08108704772894271, 0.028208686235302594, 0.029571768463938497, 0.04546355477941688, 0.08785472207819112, 0.03594709902245086, 0.10646035691024736, 0.09390040548169054, 0.0018231487342745822, 0.011664442645269446, 0.0014294543507276103, 0.04317709055612795, 0.021349135859054513, 0.05804675769468304, 0.05302668156218715, 0.0159590415933053, 0.02231455309811281, 0.051055863877991214, 0.03824473998975009, 0.06200907300808467, 0.0500381530582672, 0.12437007986591198, 0.0634696419001557, 0.03534167350153439, 0.0035671942669068812, 0.07353899767622352, 0.03683009148517158, 0.0975894954171963, 0.07341892560361885, 0.03554871043888852, 0.08856191459926777, 0.1302810263587162, 0.28989953629206866, 0.12825083686038852, 9.106543846428394, 36.650971323251724, 63.03952172398567, 76.41753226518631, 67.7628506720066, 57.85989046096802, 41.12764410674572, 58.421504124999046, 81.44596204161644, 88.28837648034096, 79.30631205439568, 41.08426183462143, 16.963788829743862, 1.5239987103268504, 0.12325154457357712, 0.08259096546680667, 0.6899746356066316, 0.36853109195362777, 1.7150107794441283, 4.723586859181523, 18.51566545665264, 10.89377224445343, 0.3857925860211253, 0.15709602419519797, 0.35668816650286317, 0.6552043638657779, 0.5107645550742745, 0.5855168751440942, 0.2055646202643402, 0.7524112227838486, 0.7210392155684531, 0.08311478071846068, 0.181997305189725, 0.18180587561801076, 0.15324733540182933, 0.2470439366879873, 0.13098245981382206, 0.864884831244126, 0.4723381076473743, 0.3478361258748919, 0.12569658720167354, 0.18447824550094083, 0.43063145654741675, 2.20244019292295, 0.2973918436327949, 0.32105661754030734, 0.7269604853354394, 6.091531505808234, 14.823737014085054, 14.60962325334549, 10.974863693118095, 9.057192094624043, 8.252008650451899, 6.621436821296811, 5.748446965590119, 4.885102892294526, 3.644672278314829, 3.820010544732213, 2.359860045835376, 0.4815402638632804, 0.11909041902981699, 0.21827870834385976, 0.47735936008393764, 0.1376357246772386, 0.11150064543471672, 0.028162726885057054, 0.10909089192864485, 0.10202218021731824, 0.03766800960875116, 0.04978253142326139, 0.09172428748570383, 0.6825076800305396, 1.3221344235353172, 0.32123342680279166, 0.37084890820551664, 0.10847983721760102, 10.177570525556803, 41.84563837945461, 59.36451852321625, 68.38246822357178, 66.78286045789719, 47.297745421528816, 21.932561807334423, 31.426095888018608, 62.99467273056507, 66.0862210392952, 45.885034427046776, 18.164180517196655, 1.7393076256848872, 0.09725473486469127, 0.3125238191569224, 0.04735941925900988, 0.028970907151233405, 0.05816072560264729, 0.10920726810581982, 0.029847784317098558, 0.03878692710713949, 0.040192758897319436, 0.031138252961682156, 0.042993312526959926, 0.0594983317569131, 0.03106729065621039, 0.06609305230085738, 0.05254866053292062, 0.06407519729691558, 0.005912580609219731, 0.04114496034162585, 0.09713057355838828, 0.04963125575159211, 0.018914891479653306, 0.008681340168550378, 0.05220130944508128, 0.02045118912064936, 0.06425692699849606, 0.03292812019935809, 0.025105377171712462, 0.029030445948592387, 0.0756545490003191, 0.056875092050177045, 0.03839466124190949, 0.062441693153232336, 0.0690186874999199, 0.03727583280124236, 0.06066753718187101, 0.044563218325492926, 0.07458993073669262, 0.020765494227816816, 0.09641283511882648, 0.061521519091911614, 0.11209333941224031, 0.06438257260015234, 0.024513531097909436, 0.10486905870493501, 0.07534375981776975, 0.022333366541715804, 0.05354816275939811, 0.07455867889802903, 0.03630556748248637, 0.034097848838428035, 0.01328103695414029, 0.0022364448614098364, 0.09969608901883475, 0.012268266054888954, 0.045483525973395444, 0.0388503547583241, 0.04540777124930173, 0.018446152862452436, 0.0645046855788678, 0.0578715477604419, 0.030223826834117062, 0.07201032931334339, 0.06809694750700146, 0.02911737927206559, 0.0701208139071241, 0.016240156001003925, 0.0567355608654907, 0.0589672545902431, 0.027635740807454567, 0.020047306788910646, 0.14316712942672893, 0.09656566558987834, 0.07978642650414258, 0.032040923470049165, 0.0390599892125465, 0.05055108842498157, 0.010618791820888873, 0.06617508930503391, 0.03327324113342911, 0.05977460365102161, 0.06846886739367619, 0.1849567229510285, 0.022895587935636286, 0.051325211534276605, 0.11901790378033184, 0.5498293682467192, 0.33994059485848993, 16.9553304836154, 51.46239414811134, 82.57919043302536, 82.1216569840908, 60.23188658058643, 43.170437291264534, 47.38517872989178, 77.35313326120377, 98.89956548810005, 98.59900921583176, 78.7752677500248, 43.21864530444145, 18.634711168706417, 1.4986329339444637, 0.36738346447236836, 0.017405659964424558, 0.32685374084394425, 0.42401571467053145, 2.2202467499300838, 3.0493014631792903, 52.71981507539749, 25.884021073579788, 1.850435275118798, 1.4236927614547312, 1.7035013157874346, 2.0588342612609267, 0.6149616139009595, 0.32477347122039646, 0.772444816539064, 0.8139203628525138, 0.8419019426219165, 0.18979868735186756, 0.518609827850014, 0.5224591994192451, 0.32428424747195095, 0.7727565185632557, 0.3578269178979099, 0.6058567680884153, 1.0809553088620305, 0.5083767988253385, 0.6820058694574982, 0.15468768076971173, 1.5340877627022564, 3.1523782946169376, 1.8548226146958768, 1.1145799420773983, 4.664830137044191, 22.424143329262733, 33.805022835731506, 29.98950507491827, 23.74228309839964, 20.67234992980957, 21.947662197053432, 22.788615971803665, 21.717174164950848, 19.462019875645638, 15.304980240762234, 12.375768721103668, 9.036783389747143, 4.651694716885686, 0.6298625736963004, 0.11298024299321696, 0.7416478847153485, 0.4008862073533237, 0.1533987038419582, 0.04699980418081395, 0.15101770113687962, 0.068100235221209, 0.08699121841345914, 0.09396739173098467, 0.14530779502820224, 0.526886674342677, 0.7971078087575734, 0.14800014352658764, 0.187223449756857, 1.0014031338505447, 5.424540946260095, 35.25796987116337, 56.339310854673386, 65.32075971364975, 82.1966801583767, 70.76400563120842, 29.92183830589056, 15.588046051561832, 46.158076375722885, 74.02992278337479, 62.09640093147755, 27.417991161346436, 2.8232950530946255, 0.15305440669180825, 0.3607527312124148, 0.028364331301418133, 0.07325791666517034, 0.09699352114694193, 0.08463825404760428, 0.08644398840260692, 0.06154657399747521, 0.06919809427927248, 0.02086773434712086, 0.02210637139796745, 0.039946351025719196, 0.07290155961527489, 0.010677268419385655, 0.05098213521705475, 0.03998264204710722, 0.027253983753325883, 0.0020083733716091956, 0.026340318327129353, 0.0819712647353299, 0.015559049043076811, 0.05126627016579732, 0.06614378551603295, 0.047928023122949526, 0.06046667491318658, 0.08120946498820558, 0.06678264107904397, 0.023509277270932216, 0.09386172474478371, 0.04923348686133977, 0.04990631052351091, 0.10037662359536625, 0.033661057823337615, 0.03621449111960828, 0.07477736755390652, 0.023083319756551646, 0.04403632316098083, 0.01648045228648698, 0.050447143221390434, 0.032453464809805155, 0.20059088012203574, 0.15709318919107318, 0.11535305238794535, 0.18378294218564406, 0.14161005907226354, 0.13115097186528146, 0.2060537994839251, 0.1260980445658788, 0.21714050613809377, 0.26655151101294905, 0.24333649344043806, 0.07575543655548245, 0.18033741769613698, 0.1678168075159192, 0.1417192438384518, 0.17494589294074103, 0.16926914599025622, 0.13315346441231668, 0.15640248719137162, 0.17573820980032906, 0.12849389022449031, 0.09410560189280659, 0.09215099271386862, 0.09453656704863533, 0.17724681791150942, 0.09710632759379223, 0.12805079837562516, 0.14807357161771506, 0.13393850822467357, 0.28035082679707557, 0.20044157485244796, 0.20836443174630404, 0.17644191422732547, 0.10990248978487216, 0.22101292881416157, 0.20117863139603287, 0.07515389617765322, 0.12098089922801591, 0.13149943988537416, 0.1660059078130871, 0.17066616477677599, 0.23484115867177024, 0.1666516059776768, 0.13387116574449465, 0.26011765468865633, 0.5289959174115211, 0.3800717258127406, 19.42238800227642, 64.20535236597061, 95.790154337883, 97.37057313323021, 85.57363495230675, 74.32472616434097, 61.26432538032532, 78.70371758937836, 97.23004907369614, 104.81992900371552, 96.61914825439453, 60.834500044584274, 26.6323434188962, 2.2531137987971306, 0.6394878728315234, 0.21198632020968944, 1.868190416134894, 2.1511588571593165, 7.9943824745714664, 18.62535037100315, 42.915223985910416, 15.530811622738838, 4.784637708216906, 0.7183743116911501, 2.4477899400517344, 2.2987343883141875, 0.4318625311134383, 0.9354142122901976, 0.5820249218959361, 1.3825651933439076, 0.9803305333480239, 0.19846008508466184, 0.5365438561420888, 0.25398157769814134, 0.18175779929151759, 0.7638983032666147, 0.4951707855798304, 2.6334439404308796, 1.4451973512768745, 0.7959833065979183, 0.5004213319625705, 0.3434922464657575, 2.902199956588447, 7.324549192562699, 1.1811816995032132, 0.6589517940301448, 1.3401876110583544, 11.910178754478693, 28.01787257194519, 30.316652320325375, 22.865459248423576, 19.497546069324017, 20.02873096615076, 18.039305917918682, 13.825666420161724, 9.625766035169363, 5.347121050581336, 3.640880319289863, 2.296805279329419, 1.0458493488840759, 0.24615589762106538, 0.45227764814626426, 1.1551922815851867, 1.2659457698464394, 0.13605334708699957, 0.09644413890782744, 0.2695286809466779, 0.26214885350782424, 0.1325692012323998, 0.22350822226144373, 0.24679797410499305, 0.9783722134307027, 4.481737911701202, 0.9055306564550847, 1.369939895812422, 1.3119437266141176, 15.727142337709665, 61.14634171128273, 79.19363290071487, 78.15419867634773, 79.83469650149345, 63.5106660425663, 34.110830426216125, 44.390833005309105, 78.63055631518364, 87.24658638238907, 73.31608548760414, 33.3543936163187, 3.741831877268851, 0.22210067982086912, 0.7580632413737476, 0.12425694687408395, 0.13207883457653224, 0.28614325972739607, 0.23721033154288307, 0.1572620723163709, 0.14388946176040918, 0.13753125997027382, 0.11568445101147518, 0.15473117062356323, 0.11518812490976416, 0.14714189426740631, 0.17374253016896546, 0.13916054129367694, 0.15662823367165402, 0.09714743515360169, 0.09675064589828253, 0.20801366306841373, 0.17485523218056187, 0.17995559755945578, 0.12525518744951114, 0.24296110030263662, 0.15397210197988898, 0.14919059292878956, 0.12083408757462166, 0.11158177701872773, 0.2267885595210828, 0.19254028477007523, 0.17533069651108235, 0.1125499235058669, 0.3210364608094096, 0.16608277946943417, 0.19451617874437943, 0.19670846813824028, 0.08755357339396141, 0.13594414747785777, 0.12619707675185055, 0.2107969395001419, 0.16729858063627034], [0.06831955470261164, 0.03801137165282853, 0.059859601824427955, 0.061625468006241135, 0.02765161534625804, 0.008851541533658747, 0.023412812915921677, 0.013579248588939663, 0.032253819663310423, 0.04134685419558082, 0.031198663782561198, 0.03363295640156139, 0.04428679429111071, 0.06976734381169081, 0.045978234193171374, 0.03413752405322157, 0.015968201551004313, 0.01463013712054817, 0.055376117015839554, 0.05578814998443704, 0.01834739527112106, 0.050101001834264025, 0.09262231586035341, 0.0413581682369113, 0.04799540271051228, 0.029403850130620413, 0.058306739447289146, 0.047571836767019704, 0.09687868121545762, 0.05906712540308945, 0.02801013019052334, 0.042760960932355374, 0.04153268055233639, 0.046278648151201196, 0.053690213535446674, 0.05759506435424555, 0.023258987966983113, 0.04415163435623981, 0.059654301512637176, 0.03685739509819541, 0.07683962525334209, 0.054315862580551766, 0.018047472985927016, 0.11326752093737014, 0.10491818888112903, 0.10596868407446891, 0.07657769907382317, 0.936341006308794, 0.1778615388320759, 10.25570098310709, 36.209203228354454, 65.40258452296257, 73.6681517958641, 70.41937932372093, 54.19574327766895, 38.18217135965824, 42.90385499596596, 62.10300877690315, 74.33155819773674, 67.0730584859848, 42.014022544026375, 10.328620970249176, 0.6799517234321684, 0.30141769791953266, 0.11791469383751974, 0.5344227980822325, 0.30463995470199734, 1.8410707963630557, 2.9851879784837365, 4.394394848495722, 2.841284000314772, 2.7417234051972628, 2.0236982591450214, 0.6461932661477476, 0.5212622636463493, 0.5076334637124091, 0.26399469352327287, 0.6297706067562103, 0.2204290812369436, 0.22960598958889022, 0.20560242526698858, 0.40415130089968443, 0.027514349567354657, 0.051764377421932295, 0.03166986447467934, 0.03295101545518264, 0.04571432276861742, 0.03595642410800792, 0.5625298898667097, 2.260308237746358, 1.6414658445864916, 1.5893853642046452, 1.6334608616307378, 0.03594626410631463, 0.14351497404277325, 0.14974007906857878, 0.23698035482084379, 0.1822229180834256, 0.27585483680013567, 0.2756000723456964, 0.26811462244950235, 0.3837960009695962, 0.33571821986697614, 0.2781833993503824, 0.223448405158706, 0.4217244079336524, 0.04557548920274712, 1.4186288206838071, 0.5882661463692784, 0.04686157175456174, 0.06123076418589335, 0.12000154631095938, 0.06605726593988948, 0.057582065637689084, 0.19324116903590038, 0.1253672072198242, 0.266270266729407, 0.15253784222295508, 0.4212674230802804, 0.2230972208781168, 1.036096103489399, 10.179203487932682, 39.463667795062065, 63.95993873476982, 69.27219808101654, 51.01231589913368, 37.76631027460098, 36.70060805976391, 51.49570696055889, 65.52515834569931, 73.7066513299942, 54.377316534519196, 26.508504264056683, 5.209183702245355, 0.08840356997097842, 0.01693734808213776, 0.11380905867554247, 0.15590881055686623, 0.035859696290572174, 0.024458101943309885, 0.006923101409483934, 0.020138802465226036, 0.04938267338729929, 0.0536470724910032, 0.03255687566706911, 0.028131270955782384, 0.07427054748404771, 0.023354964359896258, 0.07035982256638817, 0.01902715059259208, 0.03988890508480836, 0.028551630821311846, 0.06016182291205041, 0.05191658819967415, 0.03983784532465506, 0.03591672291804571, 0.04136311465117615, 0.06285394134465605, 0.014497719421342481, 0.042889812611974776, 0.020757861238962505, 0.04476719019294251, 0.0014775117756471445, 0.05177860068215523, 0.039433968559023924, 0.018607352903927676, 0.025799838149396237, 0.07786044196109287, 0.025504370605631266, 0.026081108408106957, 0.015942478712531738, 0.038817618624307215, 0.07234166856505908, 0.025708674584166147, 0.04043557106342632, 0.03325455014419276, 0.09220025647664443, 0.049611893118708394, 0.028699186477751937, 0.13213449565228075, 0.02745351943303831, 0.028338740194158163, 0.0523814138432499, 0.021955759948468767, 0.028643345431191847, 0.0475664376426721, 0.045285064552444965, 0.031127063230087515, 0.042210847677779384, 0.09566184104187414, 0.04322198677982669, 0.06704971776343882, 0.026405937169329263, 0.020339642469480168, 0.026850810172618367, 0.02660738944541663, 0.018302528733329382, 0.06936655438039452, 0.023772051354171708, 0.0325100461486727, 0.022674331448797602, 0.014537357528752182, 0.05582560246693902, 0.027890703786397353, 0.006416443220587098, 0.05430311990494374, 0.030239760744734667, 0.01460380015487317, 0.06382522711646743, 0.04543246621324215, 0.0836618326138705, 0.051074295115540735, 0.013239961863291683, 0.07376195368124172, 0.04190365048998501, 0.03475689823972061, 0.07483054985641502, 0.049603929874137975, 0.08933078701375052, 0.0359900248440681, 0.1683741158922203, 0.03534745112119708, 0.15998216229490936, 1.0891295014880598, 1.2217859644442797, 18.306213095784187, 53.746242597699165, 83.607726842165, 84.02636557817459, 64.29668426513672, 43.91184590756893, 45.83024136722088, 65.06564900279045, 91.60577327013016, 89.98174801468849, 78.09366032481194, 43.2829986512661, 9.607451017946005, 0.9097845875658095, 0.2948040934279561, 0.06344295426970348, 0.25345919479150325, 1.3183432957157493, 1.0478354548104107, 3.276488659903407, 2.1802797820419073, 2.142606466077268, 2.991158883087337, 4.1507713962346315, 4.760411633178592, 1.418285770341754, 0.6303915765602142, 0.7288285600952804, 0.3361000696895644, 0.24902382341679186, 0.05334498498996254, 0.13993333966936916, 0.5440763582009822, 0.17848779272753745, 0.2622089080978185, 0.15539545216597617, 0.13168430887162685, 0.025633710247348063, 0.16720435756724328, 0.847072871401906, 1.7996787861920893, 2.8737420961260796, 2.999450038187206, 1.7801329912617803, 0.1232797907141503, 0.6613865133840591, 1.4519466203637421, 0.9961797203868628, 0.9329694590996951, 1.712461591232568, 1.3581871264614165, 1.1787885404191911, 1.3913692021742463, 1.0570865334011614, 0.5387915542814881, 0.21884677786147222, 0.14934589475160465, 0.14453401701757684, 0.44398512749467045, 0.6887611944694072, 0.007812300082150614, 0.038358667079592124, 0.2377359798992984, 0.06211716310644988, 0.08520937379216775, 0.09025114661199041, 0.152602483285591, 0.49404215707909316, 0.16023665957618505, 0.2091109284083359, 0.09152341779554263, 0.8125527924858034, 3.9704264234751463, 27.19298243522644, 59.615297466516495, 83.85094419121742, 78.41201484203339, 55.23996144533157, 42.32415430247784, 36.76908038556576, 44.55200135707855, 72.9775008559227, 65.4890450835228, 36.06237530708313, 9.669599533081055, 0.10715812415583059, 0.19230646372307092, 0.2683174959383905, 0.011857645949930884, 0.09108480851864442, 0.039683359864284284, 0.015762997718411498, 0.03188431175658479, 0.05467003029480111, 0.023366608656942844, 0.07688204641453922, 0.09219337676768191, 0.031005579221528023, 0.029227092818473466, 0.04893043827905785, 0.018414084661344532, 0.04874500897130929, 0.01859053398220567, 0.044884445815114304, 0.022799221915192902, 0.04545856383629143, 0.043775109443231486, 0.03722629073308781, 0.01270484370252234, 0.02022494354605442, 0.015505728515563533, 0.01423524405254284, 0.0296216092465329, 0.03082555645960383, 0.024737949133850634, 0.08775565278483555, 0.08424833707977086, 0.04704004713858012, 0.044918484418303706, 0.059386237771832384, 0.034999417257495224, 0.016696754937584046, 0.014363516856974456, 0.006529459324156051, 0.041002108046086505, 0.05683273768227082, 0.04703954989963677, 0.28328103362582624, 0.1958521781489253, 0.13657479488756508, 0.21351699979277328, 0.13854567194357514, 0.104458250280004, 0.1230975340877194, 0.15596196317346767, 0.19085776177234948, 0.14598320878576487, 0.13415429508313537, 0.12533804081613198, 0.19472366839181632, 0.1709433866199106, 0.1091669472225476, 0.08562953327782452, 0.1014175673481077, 0.055052444149623625, 0.181551793939434, 0.16285869700368494, 0.12634062295546755, 0.14398098341189325, 0.19885253277607262, 0.16581303847488016, 0.15326364780776203, 0.1424175305874087, 0.21061447507236153, 0.1454216256388463, 0.18967178009916097, 0.2895413461374119, 0.09797501887078397, 0.09747020259965211, 0.1370675809448585, 0.16403946880018339, 0.1610329543473199, 0.20212767500197515, 0.12937381019582972, 0.20633339619962499, 0.19720527663594112, 0.09011029440443963, 0.1900576672051102, 0.2577516285236925, 0.24608224688563496, 0.17793737148167565, 0.24822692008456215, 0.13605874992208555, 0.25458491407334805, 1.1291028815321624, 1.138414281886071, 21.6993835195899, 66.06244951486588, 95.86507111787796, 101.26402661204338, 89.7474753856659, 74.33394446969032, 58.53038348257542, 66.02486193180084, 78.67786377668381, 90.01906961202621, 91.21013849973679, 61.0600521415472, 15.979428850114346, 1.5483977948315442, 0.6491829338483512, 0.35972761746961623, 0.9943851479329169, 7.648093281313777, 6.633436577394605, 13.871813043951988, 23.24018184095621, 7.664573471993208, 9.834145903587341, 8.125253152102232, 3.409098694100976, 3.5749443573877215, 1.595610617659986, 1.9613779219798744, 1.413979532662779, 0.8738688554149121, 1.0416255192831159, 0.47129773534834385, 1.1166603304445744, 0.1903700371622108, 0.3365693148225546, 0.14432557742111385, 0.4767342342529446, 0.13918059412389994, 0.32239218649920076, 1.783576081506908, 5.1437450386583805, 9.423846770077944, 4.735742881894112, 2.930982937105, 0.18080957204801962, 0.33480175654403865, 0.3722351213218644, 0.26836101547814906, 0.23839448753278702, 0.7088055938947946, 0.4643789300462231, 0.5285933171398938, 0.82099350518547, 0.5077003163751215, 0.3426841663895175, 0.19104798906482756, 0.41593681380618364, 0.3167992428643629, 2.1963671687990427, 0.6696046411525458, 0.09543371226754971, 0.1583938772091642, 0.3731665463419631, 0.44994923402555287, 0.7102815771941096, 0.25701244943775237, 0.2898716909112409, 0.8358295715879649, 0.3990773856639862, 0.3637961304048076, 0.4168494476471096, 1.746968252118677, 16.518458425998688, 53.72535511851311, 84.31703478097916, 83.91962170600891, 65.53354069590569, 49.88963574171066, 51.07994087040424, 66.06860518455505, 80.22308126091957, 89.59350004792213, 76.13599017262459, 44.49910819530487, 10.40953952819109, 0.22870984626933932, 0.31456039112526923, 0.3145051753381267, 0.3182643314357847, 0.20771195035194978, 0.142604254942853, 0.11492582765640691, 0.17460625647800043, 0.16537698218598962, 0.16754294018028304, 0.11913099966477603, 0.12571169732837006, 0.1669125896296464, 0.13484198396326974, 0.19158466573571786, 0.06661557621555403, 0.1361770334187895, 0.12124434681027196, 0.13001651008380577, 0.10473467060364783, 0.12905694282380864, 0.10621587120112963, 0.2073193245450966, 0.14827159146079794, 0.11572854942642152, 0.10228230297798291, 0.20970129204215482, 0.13125537720043212, 0.11826164787635207, 0.21460188610944897, 0.11237462080316618, 0.12607439974090084, 0.10270556464092806, 0.28129843063652515, 0.14011801569722593, 0.058947806610376574, 0.09834484590101056, 0.08970936396508478, 0.1853498979471624, 0.14021799783222377, 0.20086927455849946, 0.15419584466144443], [0.039616032227058895, 0.04156054819759447, 0.03810430338489823, 0.050999015365960076, 0.028009067063976545, 0.07189206065959297, 0.069955025537638, 0.11870825008372776, 0.0528915550239617, 0.07072645094012842, 0.0075331686002755305, 0.04321453190641478, 0.04102498845895752, 0.05558604090765584, 0.05289368127705529, 0.027740958794311155, 0.05269432185741607, 0.09203374822391197, 0.05352513391699176, 0.041701485752128065, 0.043432693637441844, 0.10448778775753453, 0.06203865501447581, 0.09981659153709188, 0.03794591793848667, 0.014302336057880893, 0.07946644953335635, 0.08513725930242799, 0.04769216488057282, 0.06985732179600745, 0.04208527258015238, 0.012865793269156711, 0.025577806118235458, 0.04571656034386251, 0.0394150512147462, 0.029740894642600324, 0.019496918939694297, 0.07832339368178509, 0.04938092934025917, 0.08217283946578391, 0.041141171677736565, 0.06297250685747713, 0.04702563091996126, 0.053581915635732, 0.06357745369314216, 0.09510957926977426, 0.04148541316681076, 0.2393502401537262, 0.12118683778680861, 0.4451005457667634, 0.09823096334002912, 15.630244687199593, 35.88579498231411, 66.68785035610199, 78.25994700193405, 66.09341785311699, 44.83696326613426, 31.254992969334126, 44.98220667243004, 55.097890868783, 73.53905752301216, 74.78225961327553, 42.67332896590233, 16.835350021719933, 1.9723269157111645, 0.05272207818052266, 0.10062335801194422, 0.3655779082328081, 0.6576096941716969, 0.37767363886814564, 1.0580797051079571, 3.0205866415053606, 2.922996715642512, 4.199604000896215, 0.2779275068314746, 0.2721776731777936, 0.14800939068663865, 0.24878345662727952, 0.25149749068077654, 0.10075746409711428, 0.26348991435952485, 0.3037468541879207, 0.10623224297887646, 0.15762403258122504, 0.14478864788543433, 0.06942368490854278, 0.03585516918974463, 0.25376745325047523, 0.5560304573737085, 0.4325412993784994, 0.16549734369618818, 2.098045307211578, 0.7958554197102785, 0.5098837148398161, 0.1617728904238902, 0.16544761980185285, 0.0423416660487419, 0.08085473324172199, 0.07292803944437765, 0.03721163702721242, 0.08231389947468415, 0.17476246372098103, 0.055662964514340274, 0.13174862338928506, 0.5429316696245223, 0.8174430707003921, 0.2131735041621141, 0.13880356826120988, 0.24089390732115135, 0.07680150854866952, 0.21656456985510886, 0.14736689860001206, 0.2910381689434871, 0.273251382750459, 0.2704893168993294, 1.969174628611654, 0.06790024868678302, 0.1176269631832838, 3.0968763353303075, 17.20109559595585, 39.7326173633337, 58.38970363140106, 64.12127047777176, 54.95060697197914, 27.150126434862614, 31.12895753234625, 43.465244472026825, 54.68840964138508, 70.72930589318275, 62.965596690773964, 37.871975004673004, 10.412090141326189, 0.4071580379968509, 0.2615133672952652, 0.08771778841037303, 0.033283690572716296, 0.07151375830289908, 0.10722497681854293, 0.010893057133216644, 0.0355147200752981, 0.040277174484799616, 0.05806465087516699, 0.019703660873346962, 0.05268966488074511, 0.02362079052545596, 0.057832662932923995, 0.10439286706969142, 0.05007380954339169, 0.03134199476335198, 0.0540945801185444, 0.031240821481333114, 0.05221857180004008, 0.05362062234780751, 0.0774468133749906, 0.02458955113979755, 0.038797042579972185, 0.09546165412757546, 0.05599156895186752, 0.023185624813777395, 0.023111363661882933, 0.0298651041885023, 0.037310977204469964, 0.03861906072415877, 0.042930712370434776, 0.03122609356069006, 0.05695734056644142, 0.050244989615748636, 0.0024972782284748973, 0.013083857593301218, 0.029714338743360713, 0.045058030445943587, 0.02507284141756827, 0.03488497437501792, 0.016416022735938895, 0.04984984792827163, 0.022840442652523052, 0.042051449199789204, 0.020656302040151786, 0.09643061697715893, 0.005244784069873276, 0.04085832435521297, 0.10669528375728987, 0.058551525726215914, 0.048064318543765694, 0.014247638846427435, 0.05895060079637915, 0.04859687258431222, 0.05469080300827045, 0.026384023403807078, 0.020336312081781216, 0.037077686793054454, 0.047482500740443356, 0.015293993783416227, 0.06457372015574947, 0.09744729250087403, 0.043507528098416515, 0.02668163760972675, 0.08711376925930381, 0.04322483291616663, 0.10431575792608783, 0.0284768575875205, 0.10334871723898686, 0.01108866221329663, 0.03872916946420446, 0.033479064659331925, 0.013862505948054604, 0.018108694603142794, 0.026788276809384115, 0.04242121314746328, 0.04494596243603155, 0.0703466494451277, 0.022409907942346763, 0.036026657253387384, 0.042001484107458964, 0.024225188171840273, 0.051562231237767264, 0.023098914134607185, 0.04266666364856064, 0.06572462050826289, 0.05661689145199489, 0.03098468776443042, 0.2386518198181875, 0.028258673592063133, 0.18787630222504959, 0.2896654629148543, 0.35786877502687275, 1.989459008909762, 23.236929215490818, 55.19011192023754, 85.76517507433891, 87.42505520582199, 54.98079635202885, 31.750303991138935, 30.751122906804085, 58.67876552045345, 75.17467215657234, 93.05556267499924, 74.01977732777596, 39.61308717727661, 13.340278565883636, 2.6552070351317525, 0.04633193435438443, 0.03589828425901942, 0.27597322419751436, 1.100260647945106, 0.07720331472228281, 0.4951663623796776, 1.6931099421344697, 0.5043163010850549, 1.2419622880406678, 0.6870155443903059, 0.0278967355916393, 0.07765933478367515, 0.324447876191698, 0.16876726120244712, 0.12473028124077246, 0.38880659616552293, 0.4821194359101355, 0.14813279500231147, 0.17264799593249336, 0.1118332018086221, 0.2037416977691464, 0.05631240310322028, 0.23461438802769408, 1.056256634183228, 0.745547009864822, 0.832554028602317, 1.9315060623921454, 0.9346937946975231, 1.797339180484414, 0.46531872649211437, 0.22126516996650025, 0.028986995057493914, 0.023479481897084042, 0.04432593887031544, 0.012830905834562145, 0.06824993382906541, 0.04914913064567372, 0.10574733852990903, 0.100658862356795, 0.23778981529176235, 0.5262510990723968, 0.10443836814374663, 0.30764969007577747, 0.08679269390995614, 0.029672635610040743, 0.1715108030475676, 0.21765531913843006, 0.05193839249841403, 0.09669377512182109, 0.16208797664148733, 1.7730865068733692, 0.08800994968623854, 0.04480518815398682, 1.4181876881048083, 4.317586245015264, 27.905377708375454, 56.06209293007851, 77.41228848695755, 79.8847246170044, 51.022685542702675, 31.232785061001778, 25.14906071126461, 45.820616483688354, 78.35841491818428, 75.95870688557625, 50.28530091047287, 16.796557903289795, 1.4534427900798619, 0.29289677389897406, 0.10581245456705801, 0.07092586602084339, 0.09467876996495761, 0.056184482818935066, 0.03672987186291721, 0.04513893567491323, 0.011952209479204612, 0.0435632819426246, 0.026596377829264384, 0.04267645999789238, 0.02305219222762389, 0.07024147227639332, 0.03500238584820181, 0.021721471348428167, 0.07406537333736196, 0.04406597938213963, 0.02623364758619573, 0.034675733259064145, 0.029467804706655443, 0.03847625666821841, 0.029442456652759574, 0.012830780597141711, 0.034015347991953604, 0.06666208661044948, 0.01649642887059599, 0.023445675215043593, 0.05237024452071637, 0.029983044441905804, 0.01795140382455429, 0.027256774228590075, 0.04303368907130789, 0.05239163692749571, 0.0455738342134282, 0.03167898546962533, 0.06210447980265599, 0.02887697351980023, 0.01165131312518497, 0.11019324098015204, 0.02055705277598463, 0.02076990629575448, 0.06117108066973742, 0.030167516379151493, 0.1628688198979944, 0.17462117364630103, 0.17909982707351446, 0.13659014250151813, 0.14508697640849277, 0.14365400798851624, 0.11891819623997435, 0.13885666150599718, 0.08049910349654965, 0.19142296659993008, 0.07766930924844928, 0.16993988421745598, 0.13325939857168123, 0.10833442822331563, 0.11297455072053708, 0.07523978492827155, 0.08017456973902881, 0.12585914722876623, 0.2010840966249816, 0.10838401110959239, 0.1976419860147871, 0.20465508860070258, 0.16624925803625956, 0.2071129481191747, 0.17139349918579683, 0.24621920281788334, 0.1659519982058555, 0.21438860771013424, 0.09363098361063749, 0.21525522839510813, 0.10562679890426807, 0.10989637448801659, 0.22195803903741762, 0.09810571849811822, 0.1356090381159447, 0.19014743738807738, 0.1397109031677246, 0.10347877119784243, 0.1564463332761079, 0.20929842459736392, 0.13528045965358615, 0.1800979266408831, 0.16880660987226292, 0.1391278867959045, 0.2283127378905192, 0.25392235431354493, 0.08764391503063962, 0.35933089500758797, 0.33595270884688944, 0.6080754334107041, 1.9089127122424543, 27.609561681747437, 65.77199310064316, 98.90319809317589, 104.58406046032906, 82.62418761849403, 59.39204044640064, 49.47321608662605, 61.62879042327404, 73.75357121229172, 91.37469246983528, 96.42975881695747, 60.87630160152912, 24.434991627931595, 4.041601829230785, 0.1300003015785478, 0.16724827786674723, 0.47398846596479416, 2.4293666286394, 1.4243415766395628, 3.679949822835624, 8.186433669179678, 6.734735816717148, 13.83395567536354, 2.4479469191282988, 0.489655114361085, 0.23279955494217575, 0.31280886323656887, 0.8012675761710852, 0.3028637875104323, 0.7441195927094668, 1.100028504151851, 0.5029220134019852, 0.5275354895275086, 0.527185492683202, 0.49259666120633483, 0.19716013921424747, 0.30290611961390823, 1.3468573219142854, 2.420196058228612, 0.6818542932160199, 7.482043141499162, 5.3526155557483435, 2.998359971679747, 0.5854021094273776, 0.312793604680337, 0.07407801211229526, 0.25877873122226447, 0.11225161724723876, 0.17017732694512233, 0.3342568420339376, 0.7779117731843144, 0.28978910471778363, 0.15776694053784013, 0.5479034059680998, 0.8457079133950174, 0.21357171091949567, 0.5501759215258062, 0.48701487947255373, 0.2355656580766663, 0.2589125552913174, 0.5840928421821445, 0.4953686718363315, 0.5719435284845531, 0.7915577315725386, 3.042073301039636, 0.1339919280144386, 0.10794629240990616, 3.8519259821623564, 27.340558916330338, 56.62291243672371, 81.80638790130615, 81.87896400690079, 68.420899361372, 43.87154147028923, 48.56865182518959, 59.529030695557594, 72.3375315964222, 86.99166566133499, 81.30967855453491, 61.20422400534153, 18.516604006290436, 1.2324879714287817, 0.4980738298036158, 0.28789000818505883, 0.12496764975367114, 0.1676002488238737, 0.23977568373084068, 0.1748592546209693, 0.16153296892298386, 0.156926799681969, 0.22513595991767943, 0.10847945130080916, 0.14421544270589948, 0.13168886565836146, 0.17111013235989958, 0.17052787297870964, 0.10610779223497957, 0.10317126230802387, 0.16513956914423034, 0.06728690073941834, 0.10259550414048135, 0.0732022852753289, 0.18261435645399615, 0.09265289234463125, 0.13888136018067598, 0.21626701316563413, 0.16400583466747776, 0.13246999093098566, 0.1169179227144923, 0.13051404588622972, 0.09328814849141054, 0.15781710972078145, 0.11626539679127745, 0.08601162800914608, 0.10785509730339982, 0.19194569089449942, 0.08401924351346679, 0.158649101795163, 0.11219346997677349, 0.13114046305418015, 0.17864594439743087, 0.1012861033086665, 0.14307695848401636, 0.1570443855598569, 0.1217609632294625], [0.07229349575936794, 0.03465502362814732, 0.0556600590061862, 0.019980071920144837, 0.0013636079938805779, 0.020400641442392953, 0.03689923738420475, 0.05622063654300291, 0.023079198981577065, 0.03839059798337985, 0.08617435130872764, 0.034759057889459655, 0.0599843271629652, 0.05530030291993171, 0.041071398663916625, 0.018771098511933815, 0.038802630951977335, 0.02560766828537453, 0.05180902502615936, 0.03297559538623318, 0.03863744372210931, 0.05936414403549861, 0.025988644229073543, 0.020617109221348073, 0.041975286294473335, 0.061736612042295747, 0.07125542411813512, 0.042706465028459206, 0.021815375293954276, 0.01322354277363047, 0.04706356208771467, 0.07345972888288088, 0.05651808933180291, 0.0322882850014139, 0.0447644034284167, 0.039954830062924884, 0.04006916162325069, 0.09760290602571331, 0.034600338476593606, 0.06014290927851107, 0.0598864378844155, 0.03258096949139144, 0.05753205230575986, 0.0638253013312351, 0.03889903593517374, 0.061132251503295265, 0.02124892736901529, 0.2393387071788311, 0.02930156548245577, 0.24847982916980982, 0.07070178937283345, 0.4741574975196272, 0.5247978551778942, 8.19465547800064, 44.191837683320045, 78.28941822052002, 76.16525620222092, 68.13339158892632, 52.86677598953247, 43.088760673999786, 37.50251702964306, 58.77182252705097, 72.46527314186096, 83.0381678044796, 56.38444483280182, 23.034354485571384, 10.407515186816454, 2.5531836971640587, 0.3319921041838825, 0.1278669387102127, 0.016441740008303896, 0.019945506392105017, 0.035076697095064446, 0.01960155990673229, 0.06456578659708612, 0.14385812828550115, 0.22368252306478098, 0.5903762800153345, 0.2313584228977561, 0.3985988488420844, 0.12213880545459688, 0.10923716181423515, 0.47854709322564304, 0.28891132213175297, 0.29711297422181815, 0.18827801191946492, 0.7646900857798755, 0.2318466966971755, 1.6099231434054673, 0.6996644719038159, 0.9799891454167664, 0.9920975519344211, 0.40525629941839725, 1.439948882907629, 1.186904904898256, 0.9655857214238495, 0.1184330765681807, 0.025103727748501115, 0.14454007294261828, 0.1644916890654713, 0.06631798984017223, 0.21760568430181593, 0.19544113223673776, 0.06834783052909188, 0.20770812086993828, 0.5928219831548631, 0.20023041899548844, 0.7176956324838102, 0.8614292135462165, 0.7501718366984278, 0.9775057411752641, 0.17020067491102964, 0.21887673094170168, 0.33802537887822837, 0.6186300201807171, 0.46294311177916825, 2.79486236628145, 18.98051541298628, 47.560539320111275, 55.1465130597353, 51.99029602110386, 47.702442705631256, 33.50846774876118, 35.30511774122715, 46.553760543465614, 68.2143272459507, 67.76443898677826, 61.252857595682144, 38.60883146524429, 17.71655883640051, 1.4504334703087807, 0.49597874691244215, 0.08380618033697829, 0.03041068477614317, 0.04151979315793142, 0.05663092917529866, 0.06833945168182254, 0.06652861135080457, 0.026613705122144893, 0.03948209312511608, 0.07631359840161167, 0.06385687229339965, 0.07868745422456414, 0.04565830546198413, 0.012499374552135123, 0.010908427939284593, 0.07426017225952819, 0.02953567967779236, 0.017220514528162312, 0.04606085749401245, 0.06715877636452205, 0.004160181160841603, 0.02007777937251376, 0.013607841683551669, 0.031576372421113774, 0.058636434841901064, 0.04529416699369904, 0.019464602119114716, 0.028584162864717655, 0.07280591904418543, 0.036467797253862955, 0.014932732065062737, 0.03941659859265201, 0.008864203500706935, 0.07598806274472736, 0.0489367354020942, 0.01390851261021453, 0.025797158996283542, 0.0533819328120444, 0.014496138646791223, 0.09784539535758086, 0.03873365945764817, 0.008512648146279389, 0.016091431461973116, 0.11154000152600929, 0.07733301245025359, 0.025157685595331714, 0.05407206335803494, 0.08414285563048907, 0.039347293131868355, 0.04341729778388981, 0.03176668134983629, 0.028596278425538912, 0.04410715744597837, 0.04349822898802813, 0.055910485607455485, 0.04064059678057674, 0.024349091581825633, 0.03484026368823834, 0.004526610546236043, 0.06291706100455485, 0.008899412841856247, 0.05626285361358896, 0.010481513982085744, 0.016311945801135153, 0.009819165734370472, 0.029252663516672328, 0.03801369828579482, 0.01565803020639578, 0.05612460263364483, 0.10396178317023441, 0.06550778722157702, 0.024257966979348566, 0.024732473939366173, 0.024071196239674464, 0.006996694628469413, 0.04596747305186, 0.03537923359544948, 0.03965444579080213, 0.020073382147529628, 0.08246405821410008, 0.037087787422933616, 0.030982259086158592, 0.07493218698073179, 0.024496591577189974, 0.06552468592417426, 0.03443397865339648, 0.01427299432180007, 0.053971713859937154, 0.03129053795419168, 0.06029504584148526, 0.06458762800320983, 0.017767878125596326, 0.1304070875630714, 0.019300006752018817, 0.18941164249554276, 0.2771727426443249, 0.40930426970589906, 2.3248275881633162, 17.8880113363266, 68.43263313174248, 93.81733819842339, 80.19019022583961, 53.01147602498531, 32.00336091220379, 45.63628077507019, 54.447700157761574, 92.95492887496948, 92.71131634712219, 81.5317690372467, 50.789526253938675, 18.767738230526447, 8.253005146980286, 2.2294956911355257, 1.1990896635688841, 0.19596278783865273, 0.11176891697687097, 0.08236700756242499, 0.05843798084242735, 0.08960451334132813, 0.07649689403478988, 0.07653023130842485, 0.2626521186903119, 0.3841839957749471, 0.13810394564643502, 0.028090369341953192, 0.03246530577598605, 0.029847381701983977, 0.29054526414256543, 0.3385118121514097, 0.07086135854478925, 0.1713844746700488, 0.4144467890728265, 0.06083843523811083, 3.251091535203159, 1.0665378137491643, 4.0631333738565445, 2.2619670862331986, 1.882656596135348, 5.843994738534093, 3.627069010399282, 0.8757022570353001, 0.18328034493606538, 0.023353927208518144, 0.04590541837387718, 0.1318830411764793, 0.1747546117985621, 0.08172436704626307, 0.32598314224742353, 0.2125367266125977, 0.5442289437633008, 0.19922642677556723, 0.1256636210018769, 0.6122548528946936, 0.20007856073789299, 0.11516259502968751, 0.6373572559095919, 0.3204104147152975, 0.11041820078389719, 0.22027190920198336, 0.7245368685107678, 0.9472206537611783, 0.8784330042544752, 9.98027941212058, 32.99810953438282, 55.67154608666897, 66.40595868229866, 65.84238052368164, 53.40025596320629, 39.43674623966217, 22.286623008549213, 53.37255924940109, 72.95547723770142, 74.72987562417984, 50.303904712200165, 26.429829485714436, 3.505164426751435, 0.3172000026097521, 0.16600632341578603, 0.13470127276377752, 0.04929012015054468, 0.06701383492327295, 0.03412624711927492, 0.09109555481700227, 0.016664464092173148, 0.05232930394413415, 0.031292371058952995, 0.02783901320071891, 0.11337887277477421, 0.042637493534130044, 0.043212383388890885, 0.04354592310846783, 0.011198729207535507, 0.007246591521834489, 0.022201770771062, 0.022481655068986584, 0.023628705530427396, 0.06051627264241688, 0.02085914027702529, 0.07036381532088853, 0.03288802196038887, 0.02101802110701101, 0.017281546897720546, 0.016696009079169016, 0.02229335550509859, 0.06860747089376673, 0.05266955267870799, 0.020657287241192535, 0.041583814527257346, 0.0628237878845539, 0.01999850686843274, 0.031818234638194554, 0.07458135893102735, 0.03688363744004164, 0.024206610360124614, 0.10273835272528231, 0.04630283474398311, 0.047739970323164016, 0.016943411428655963, 0.013762597100139828, 0.04532336308329832, 0.09091392159461975, 0.14719464612426236, 0.13400665222434327, 0.16436818084912375, 0.14834757253993303, 0.1249357225606218, 0.08109899630653672, 0.16284766868920997, 0.14918584318365902, 0.13610782072646543, 0.16262281278613955, 0.29056263039819896, 0.13395035290159285, 0.13768969365628436, 0.11149421101436019, 0.1069621452188585, 0.09153170758509077, 0.09464864619076252, 0.13543726061470807, 0.1410707106697373, 0.1369654168956913, 0.11989752689260058, 0.2010358273400925, 0.097741917707026, 0.14106517424806952, 0.1815127718145959, 0.21693524293368682, 0.1467181576299481, 0.11572571442229673, 0.11866710541653447, 0.1280759126530029, 0.09768216739757918, 0.18063571653328836, 0.1817650574957952, 0.10988812922732905, 0.172735940432176, 0.10982509120367467, 0.12183594240923412, 0.21672726346878335, 0.0652384692511987, 0.15121575066586956, 0.1971997699001804, 0.13225450093159452, 0.15474500425625592, 0.11387506528990343, 0.2703541569644585, 0.16176735400222242, 0.10575619235169142, 0.31614279840141535, 0.1429095448111184, 0.39235637756064534, 0.28082832461223006, 0.6302575743757188, 2.436027671210468, 24.61168024688959, 78.86112794280052, 110.49518287181854, 100.34132972359657, 89.82059866189957, 62.535045593976974, 64.21093806624413, 54.67044800519943, 81.25552386045456, 94.38205629587173, 103.93959984183311, 76.0773441195488, 36.41133338212967, 18.032171800732613, 4.223878998309374, 1.6576508386060596, 0.49867835361510515, 0.15174459025729448, 0.2320946630788967, 0.18507472443161532, 0.2548443095292896, 0.10921878623776138, 0.26730960002169013, 0.3189015097450465, 0.49319661338813603, 1.1230095522478223, 1.5177520830184221, 0.3978347039083019, 0.3066733799641952, 1.997281601652503, 1.2006067321635783, 0.9079155034851283, 0.3837947244755924, 2.231045770458877, 0.23543900315416977, 5.580818485468626, 6.783977374434471, 10.131614841520786, 3.634849567897618, 3.2680844608694315, 14.328120108693838, 6.931410888209939, 3.514907341450453, 0.3768592356937006, 0.1327610167209059, 0.6414750474505126, 0.3120623220456764, 0.289834346040152, 0.4370499652577564, 0.40710208006203175, 0.22715768893249333, 0.3681816888274625, 0.9913051163312048, 0.4131786961806938, 3.3946167211979628, 1.9263018853962421, 1.6473500663414598, 1.8864949839189649, 0.8356719394214451, 0.28448625176679343, 0.6004608201328665, 0.5112926079891622, 1.5879708901047707, 7.011507265269756, 35.301272347569466, 72.90798738598824, 80.885970890522, 71.8652093410492, 59.887735247612, 47.837320268154144, 55.86367517709732, 62.2712105512619, 87.7554702758789, 85.06947800517082, 84.79594588279724, 60.595090091228485, 31.104739531874657, 3.362687984481454, 0.5512891430407763, 0.2730715158395469, 0.23641333915293217, 0.2559975773328915, 0.30291567847598344, 0.19381275633350015, 0.19361038750503212, 0.11458777938969433, 0.21207785670412704, 0.10528924787649885, 0.236632525047753, 0.3778833104297519, 0.14336237363750115, 0.1200753528974019, 0.0969807562069036, 0.18752200092421845, 0.13443539093714207, 0.12415764009347185, 0.11545653745997697, 0.17876771598821506, 0.121585304295877, 0.10970596908009611, 0.13472089514834806, 0.11955397189012729, 0.18330606777453795, 0.1289655696018599, 0.15402489836560562, 0.14159871905576438, 0.12806120328605175, 0.1549294131109491, 0.0970233183761593, 0.1288410520646721, 0.09604979131836444, 0.18131858145352453, 0.22749229363398626, 0.13748873490840197, 0.14236897928640246, 0.11831932017230429, 0.23202352080261335, 0.287962649599649, 0.09955775269190781, 0.062437114102067426, 0.057650072340038605, 0.2541189640760422, 0.1987379154888913], [0.020745730835187715, 0.019271725359431002, 0.05396712738729548, 0.06442170604714192, 0.008405940297961934, 0.059593831319944, 0.07338957366300747, 0.012749148991133552, 0.0365027115913108, 0.07994584724656306, 0.022532445800607093, 0.10860629176022485, 0.04432453621120658, 0.009225245357811218, 0.059753003442892805, 0.01668044253165135, 0.08744854465476237, 0.037456100471899845, 0.05707511940272525, 0.028131356302765198, 0.01680670782661764, 0.021942009807389695, 0.06470669817645103, 0.01361886535960366, 0.039725350579828955, 0.046652516175527126, 0.07731263307505287, 0.12267434663954191, 0.015181798680714564, 0.09247627604054287, 0.027149559864483308, 0.07682660798309371, 0.034366621330264024, 0.035708275900105946, 0.12407300557242706, 0.014396246497199172, 0.028137998524471186, 0.038893681339686736, 0.025582656053302344, 0.07622370947501622, 0.049384558442397974, 0.09534973825793713, 0.08560668997233734, 0.0076153762984176865, 0.09280063910409808, 0.10440561716677621, 0.05051555810496211, 0.023305396316573024, 0.07245241926284507, 0.22659843612927943, 0.04482253956666682, 0.2014561797841452, 0.16634267958579585, 1.0217158938758075, 0.3755581023870036, 20.801007226109505, 49.86454948782921, 61.6729174554348, 72.06263154745102, 64.50991362333298, 50.13496197760105, 25.830081067979336, 40.50067014992237, 45.37255212664604, 65.47038808465004, 73.50070238113403, 64.32118535041809, 51.26651845872402, 38.37725669145584, 23.468954265117645, 15.160431247204542, 9.557091370224953, 6.854236079379916, 3.3151337737217546, 1.3279343373142183, 0.4503673006547615, 0.19670907669933513, 0.15992382948752493, 0.64029396395199, 0.7520320743788034, 0.20485061482759193, 0.05374418993596919, 0.22852658032206818, 0.6098337890580297, 0.25067329115699977, 0.2674755739280954, 0.40445855003781617, 0.32177424465771765, 1.002610637806356, 0.26166788244154304, 0.9640557097736746, 1.8600099300965667, 1.1031293752603233, 3.1990526150912046, 1.9706273381598294, 0.773558869259432, 0.3013039712095633, 0.3731801128014922, 0.04280684792320244, 0.02902431951952167, 0.1644839855725877, 0.3873138997005299, 0.24683870316948742, 0.7979781995527446, 1.154524467419833, 0.664860358228907, 0.3076105046784505, 0.15601158316712826, 0.08105937304208055, 0.10130267546628602, 0.33874701359309256, 0.6083282979670912, 2.5940189184620976, 4.041478810831904, 8.95350705832243, 20.66656094044447, 35.237549766898155, 45.341408997774124, 44.56802889704704, 41.80225990712643, 40.35006523132324, 32.62837037444115, 48.68002764880657, 58.83160471916199, 74.23688247799873, 61.21161460876465, 41.13976925611496, 13.08293642476201, 1.2680058530531824, 0.198089471377898, 0.299170296639204, 0.14552376000210643, 0.06260952985030599, 0.04335444900789298, 0.07543194180470891, 0.09342854798887856, 0.04702091828221455, 0.0997624518640805, 0.017128382460214198, 0.03733766483492218, 0.0917461585777346, 0.04164900477917399, 0.027069124043919146, 0.07196751481387764, 0.09418151617865078, 0.01962378722964786, 0.014046977885300294, 0.04707994870841503, 0.01995731952774804, 0.04113489681913052, 0.02539243061619345, 0.08223330965847708, 0.025575976724212524, 0.04320589701819699, 0.045431646140059456, 0.08333062694873661, 0.05546885578951333, 0.034308641043026, 0.085504911839962, 0.02025050125666894, 0.05614957590296399, 0.0245935902785277, 0.060301695484668016, 0.038785624637966976, 0.05972542523522861, 0.04863328977080528, 0.09698074878542684, 0.041163272835547104, 0.059152086469111964, 0.06410863847122528, 0.03130692086415365, 0.04537290886219125, 0.06960632745176554, 0.03918639922630973, 0.06722269754391164, 0.010051359622593736, 0.039262580685317516, 0.09237024540198036, 0.059931612413492985, 0.04864757982431911, 0.07363621160038747, 0.03504243584757205, 0.03973803759436123, 0.010489962405699771, 0.12833302229410037, 0.03838728058326524, 0.054884440469322726, 0.035535336937755346, 0.036035551893291995, 0.01505868844105862, 0.07046392362099141, 0.04118388598726597, 0.015497183612751542, 0.0216430504588061, 0.019722459473996423, 0.040242093164124526, 0.025347575210616924, 0.04910171854135115, 0.02796478867821861, 0.036741712829098105, 0.020392427722981665, 0.0291217152698664, 0.04332428070483729, 0.025754797206900548, 0.01883781202195678, 0.08590193116106093, 0.02133125381078571, 0.0938325138122309, 0.03885938298481051, 0.027243636359344237, 0.0759057214600034, 0.04332804339355789, 0.02342813826544443, 0.028463528615247924, 0.05185775815334637, 0.04206903809972573, 0.06246435834327713, 0.024811061812215485, 0.047206184317474253, 0.03470449890301097, 0.013770047335128766, 0.04477968053834047, 0.04467539765755646, 0.08796779569820501, 0.14804467238718644, 0.11779145279433578, 0.034235190687468275, 0.04616645397618413, 0.4048732918454334, 1.2905423250049353, 2.8799939481541514, 38.56221556663513, 72.90939331054688, 77.50851452350616, 72.82128363847733, 56.982578337192535, 34.388150945305824, 23.65060731768608, 54.02707792818546, 74.09290820360184, 93.47164034843445, 79.19345051050186, 68.35954785346985, 42.64496348798275, 23.0151180177927, 13.365185279399157, 6.384968385100365, 2.4263149173930287, 1.1854042229242623, 1.4401978882960975, 0.5852893029805273, 0.27417301142122597, 0.11260258630500175, 0.19429737876635045, 0.42538922221865505, 0.13631927344249561, 0.09272621653508395, 0.06367247086018324, 0.1950637056143023, 0.674338712124154, 0.49911331152543426, 0.39837816380895674, 0.4098492139019072, 0.5327388946898282, 0.28662948519922793, 0.38187808357179165, 1.2934294575825334, 2.346580233424902, 1.7228249413892627, 1.6516918083652854, 1.1146391951479018, 0.4733281920198351, 0.30208313721232116, 0.2935192279983312, 0.12508216314017773, 0.16383024252718315, 0.14125554997008294, 0.48469394620042294, 0.25827689096331596, 0.4373824771028012, 0.5002375168260187, 0.2943893813062459, 0.2018639602465555, 0.40339989122003317, 0.13316971744643524, 0.18872730812290683, 0.8564653736539185, 0.28595297306310385, 0.6654090725351125, 0.5327678087633103, 2.4183714436367154, 14.805397298187017, 31.944581866264343, 59.07622039318085, 74.62832987308502, 68.18561598658562, 59.402915462851524, 36.6461455821991, 31.238110475242138, 49.75639969110489, 76.0543705523014, 73.11421751976013, 53.36076848208904, 23.170282691717148, 3.8208849728107452, 0.14719000027980655, 0.4861252225236967, 0.10294628023984842, 0.04094967160199303, 0.012661210985243088, 0.004938531264997437, 0.1002954103751108, 0.028535871315398254, 0.1370791732915677, 0.03550335779436864, 0.040949790345621295, 0.05312835579388775, 0.07827813009498641, 0.04962302904459648, 0.050323067262070253, 0.07070247214869596, 0.01558185616886476, 0.07655985784367658, 0.017410990440112073, 0.03175204619765282, 0.12871080514742061, 0.04588803356455173, 0.019450575528026093, 0.05294980248436332, 0.05486000154633075, 0.06219698479981162, 0.05446674862469081, 0.03651651924883481, 0.021728377032559365, 0.03515577293001115, 0.04828010540222749, 0.029471803027263377, 0.015055833027872723, 0.04506622004555538, 0.006559208777616732, 0.04427228901477065, 0.03703368485730607, 0.06933715791092254, 0.08764555517700501, 0.06583522277651355, 0.06945799439563416, 0.03752172116946895, 0.04216437810100615, 0.0105439137587382, 0.06378389691235498, 0.060871831883559935, 0.08065723290201277, 0.1150676075485535, 0.2569317037705332, 0.1626111610676162, 0.1808450763928704, 0.10020164743764326, 0.1644989917986095, 0.16170182236237451, 0.09018452401505783, 0.15330310037825257, 0.13983715733047575, 0.11572664210689254, 0.16986696078674868, 0.12996536126593128, 0.09316518946434371, 0.15436895802849904, 0.20126243471167982, 0.17734179797116667, 0.10645445683621801, 0.16964182286756113, 0.12340906541794538, 0.07730737866950221, 0.12656786857405677, 0.20717160747153684, 0.07013266600552015, 0.11253942211624235, 0.1553210147540085, 0.20238140044966713, 0.17903457744978368, 0.0953608556301333, 0.14136314654024318, 0.11674403751385398, 0.12891361926449463, 0.13285909895785153, 0.16201888269279152, 0.2289191319141537, 0.15134301414946094, 0.107635020831367, 0.20238980156136677, 0.10644154346664436, 0.15821025503100827, 0.16926402517128736, 0.15211897407425568, 0.15685170918004587, 0.08967606379883364, 0.17133734829258174, 0.11151634927955456, 0.1282081485260278, 0.18390612385701388, 0.21596516686258838, 0.4617778805550188, 0.12011891696602106, 0.3614666179055348, 0.6077596347313374, 1.6522667650133371, 3.756162808276713, 45.17112113535404, 87.21643880009651, 94.80860620737076, 94.41239386796951, 83.6743600666523, 69.758290797472, 37.16564990580082, 62.14083194732666, 67.07169815897942, 92.08241969347, 97.12253764271736, 95.3295810520649, 77.35725983977318, 53.96355293691158, 37.34119288623333, 26.97014719247818, 15.613821968436241, 11.090299598872662, 7.687967866659164, 3.0218422366306186, 1.2500834022648633, 0.3281740809325129, 0.27996535529382527, 0.8923938707448542, 0.8931097167078406, 0.1836106600239873, 0.11288251698715612, 0.3523352922638878, 1.3712650747038424, 0.9891863737720996, 0.5822327232453972, 0.7751715264748782, 1.0133873345330358, 1.9424486439675093, 2.0803057216107845, 7.657028026878834, 10.215018466114998, 6.323143802583218, 7.8589078690856695, 4.797233557328582, 2.4749071849510074, 0.40035586862359196, 0.6897785305045545, 0.34136581525672227, 0.41583077574614435, 0.24153202073648572, 0.6130647438112646, 0.2484596279100515, 0.7901502039749175, 1.5324792615137994, 0.5774836905766279, 0.41169042291585356, 0.3848999901674688, 0.190729325695429, 0.3490574040915817, 1.031846150290221, 1.3481892691925168, 4.372973972931504, 10.476805418729782, 23.11068668961525, 45.53152799606323, 67.50587046146393, 76.55313178896904, 67.54746302962303, 54.855528473854065, 57.909599393606186, 53.21748577058315, 71.36641010642052, 75.99521532654762, 89.96390417218208, 83.47965851426125, 66.2970869243145, 28.050803504884243, 3.9093356765806675, 0.3542969370028004, 0.5395319208037108, 0.1956540098763071, 0.10461740384926088, 0.17846432601800188, 0.14323641633382067, 0.25290071382187307, 0.18746936781099066, 0.24889822234399617, 0.17003789223963395, 0.08901731867808849, 0.1833651278866455, 0.2501008874969557, 0.19012533623026684, 0.17542303452501073, 0.20029964653076604, 0.09104190496145748, 0.17741167859639972, 0.18126293522072956, 0.12267640238860622, 0.2247614722000435, 0.11086534475907683, 0.1492397379479371, 0.14708494185470045, 0.13976117625134066, 0.1955130315036513, 0.14423277927562594, 0.16649642289848998, 0.1221017945499625, 0.09725846044602804, 0.1663728998391889, 0.16675154358381405, 0.1367695047520101, 0.16382997535401955, 0.17353729665046558, 0.152949288894888, 0.09790878961212002, 0.17479281756095588, 0.12598065164638683, 0.26490465563256294, 0.22786614310462028, 0.11692222717101686, 0.14708761358633637, 0.08646758869872428, 0.14072126301471144, 0.16526203835383058, 0.14044934010598809], [0.027398847269068938, 0.04566443931253161, 0.033336694759782404, 0.015578705751977395, 0.03179899445967749, 0.03497642552247271, 0.05544669154915027, 0.00577807190893509, 0.051845798443537205, 0.026739552959043067, 0.06225426746823359, 0.052900223308824934, 0.0324370113958139, 0.08925743313739076, 0.04851555175264366, 0.01905776975036133, 0.010813082371896598, 0.0816983770346269, 0.03887846731231548, 0.04128876629692968, 0.025531685350870248, 0.025435881507291924, 0.06931003983481787, 0.05978415138088167, 0.04796143461135216, 0.01638153327803593, 0.05051018866652157, 0.018990970893355552, 0.026509637464187108, 0.10073574143461883, 0.09391562693053856, 0.03592180662963074, 0.034617274286574684, 0.07248029432957992, 0.029295806416484993, 0.04067353700520471, 0.023193059278128203, 0.08846545024425723, 0.04364607964816969, 0.015830165793886408, 0.06683283994789235, 0.0029683402317459695, 0.03295179471024312, 0.07365279860096052, 0.08842615352477878, 0.07225616573123261, 0.03829856053926051, 0.19138933246722445, 0.008520560368197039, 0.0803871727839578, 0.032456344342790544, 0.07651956664631143, 0.15494867926463485, 0.11159363653860055, 0.20092500984901562, 0.6580808688886464, 3.033415940590203, 19.7791413590312, 59.833227172493935, 69.28870439529419, 71.70483514666557, 70.18939286470413, 53.38699467480183, 27.76480995118618, 24.943639934062958, 38.9499581605196, 55.576410591602325, 65.32764494419098, 77.37574204802513, 77.05975100398064, 66.9083221256733, 61.47231861948967, 50.734748393297195, 42.23303899168968, 30.3032960370183, 24.457820802927017, 22.01591033488512, 15.596516747027636, 10.304094236344099, 6.433310816064477, 3.526763180270791, 1.740535197313875, 0.5084840836934745, 0.2962943259626627, 0.3579410305246711, 0.24494961078744382, 0.03973157348809764, 0.14734515367308632, 0.17111336812376976, 0.2652380580548197, 0.48346483090426773, 1.024694696534425, 0.889186249114573, 0.5207280360627919, 0.12932699552038684, 0.058733337064040825, 0.4043851071037352, 0.18218828947283328, 0.21585099486401305, 0.32801790337543935, 0.65677011734806, 0.39722451008856297, 0.7415484369266778, 0.8559287711977959, 1.3953739497810602, 2.4345894483849406, 2.25071778986603, 4.003273760899901, 5.899054734036326, 9.136194605380297, 12.178760692477226, 17.160806357860565, 17.59154174476862, 19.223466776311398, 39.745259284973145, 22.87459585815668, 53.497895523905754, 49.07014511525631, 36.288292184472084, 43.20620097219944, 41.81739069521427, 54.60148550570011, 68.4816125035286, 71.68303191661835, 48.634015917778015, 15.344475321471691, 1.0890977969393134, 0.21545448020333424, 0.15237176441587508, 0.21720724005717784, 0.06228728190762922, 0.17091853951569647, 0.04143989353906363, 0.009229569295712281, 0.047170910038403235, 0.08950102826929651, 0.08956469711847603, 0.020096759799344, 0.05849705950822681, 0.07154428283683956, 0.021187280872254632, 0.07289015280548483, 0.009456071838940261, 0.011626432624325389, 0.015964841477398295, 0.021304362089722417, 0.0713763570820447, 0.031095930135052186, 0.011207940187887289, 0.06640272826189175, 0.07029323707683943, 0.04090608526894357, 0.046976222438388504, 0.034636841010069475, 0.059389050511526875, 0.06762612902093679, 0.012135299166402547, 0.05629320003208704, 0.04688054475991521, 0.07227704976685345, 0.03408701348234899, 0.0223291622751276, 0.076005139562767, 0.0026690225649872446, 0.003476603083072405, 0.06011572069837712, 0.011872555696754716, 0.11639575503068045, 0.08364658890059218, 0.10052992904093117, 0.03264129125454929, 0.011435103242547484, 0.039226315639098175, 0.025387933201272972, 0.03575809998437762, 0.025158021417155396, 0.025661091785877943, 0.07681540897465311, 0.009402436826349003, 0.008612970741523895, 0.09869949601124972, 0.09474395279539749, 0.08157489108270966, 0.04362298030173406, 0.03691903046274092, 0.03223627900297288, 0.07307882900931872, 0.02834237300703535, 0.05838714372657705, 0.02804901872877963, 0.017916257565957494, 0.05357711765100248, 0.04377738783659879, 0.08378180078580044, 0.06501525349449366, 0.051000848470721394, 0.05177348357392475, 0.0687361518794205, 0.02338545735256048, 0.03232833871152252, 0.10169024724746123, 0.03167762733937707, 0.05329965832061134, 0.032317466248059645, 0.038598087630816735, 0.06410786663764156, 0.007076674492054735, 0.032266580892610364, 0.05837743643496651, 0.09604879684047773, 0.08559323483495973, 0.030876454802637454, 0.08659549042931758, 0.0592412926198449, 0.030446955388470087, 0.06815458269556984, 0.05793493088276591, 0.03245502331992611, 0.06338387189316563, 0.10304878567694686, 0.07198215738753788, 0.047159388195723295, 0.03091081995080458, 0.15915266383672133, 0.08477598181343637, 0.02328287584532518, 0.05915646885114256, 0.13212918187491596, 0.15212841419270262, 0.12702492764219642, 0.43299724522512406, 0.5747231980785728, 8.02621241658926, 30.491355545818806, 84.13364142179489, 83.49234983325005, 79.20668140053749, 52.46209770441055, 41.20774380862713, 24.454896859824657, 34.98383738100529, 70.2559956908226, 75.17741560935974, 92.60133504867554, 97.07328468561172, 74.19709101319313, 54.343357756733894, 39.66517858207226, 31.998223587870598, 21.487869769334793, 11.984903644770384, 6.61924053914845, 4.583842232823372, 4.1963964980095625, 3.6096087098121643, 0.9644757059868425, 0.271670816000551, 0.8954720618203282, 0.29957393591757864, 0.06045397305570077, 0.17587840149644762, 0.06419166253181174, 0.02817193508235505, 0.1713382388697937, 0.17927577544469386, 0.13135580462403595, 0.29963767156004906, 0.5179898079950362, 0.5791994766332209, 0.2788236056221649, 0.03147783747408539, 0.05713900718546938, 0.34892455965746194, 0.08080903178779408, 0.08435392985120416, 0.08472491463180631, 0.3417354344855994, 0.509427561191842, 0.5156855878885835, 0.5232717026956379, 0.5286088725551963, 1.2520343600772321, 0.8639127959031612, 1.1387344147078693, 1.4218116248957813, 1.5945490496233106, 6.333388052880764, 13.292064853012562, 20.281043127179146, 24.01061709970236, 46.90125189721584, 52.9400322586298, 74.51065018773079, 68.58432859182358, 47.81929783523083, 41.472961977124214, 33.33288297057152, 37.32183292508125, 69.31565254926682, 81.57714620232582, 62.999889850616455, 24.93346408009529, 2.9822811344638467, 0.23450362990843132, 0.36156903428491205, 0.07054673988022842, 0.10847862751688808, 0.1546862261602655, 0.026356189155194443, 0.08156657160725445, 0.11867741384776309, 0.012061679044563789, 0.1307606021873653, 0.07132347906008363, 0.04964241394191049, 0.03668205528811086, 0.04609973490005359, 0.0546331826626556, 0.03835413997876458, 0.05016801405872684, 0.024604785576229915, 0.09223667366313748, 0.041645230958238244, 0.02584902769740438, 0.039411154939443804, 0.016765950931585394, 0.12517703929916024, 0.034334100419073366, 0.06410254543880001, 0.030898522563802544, 0.04167563674855046, 0.019966158506576903, 0.039235644435393624, 0.007345734102273127, 0.042798201902769506, 0.004603571260304307, 0.056221549384645186, 0.07429232209688053, 0.08525681929313578, 0.03334940403874498, 0.03688823875563685, 0.07343327873968519, 0.025026418225024827, 0.07740300439763814, 0.06189713116327766, 0.10416483477456495, 0.04608094001014251, 0.027515297661011573, 0.034548811163404025, 0.028141267684986815, 0.020241426645952743, 0.021956390773993917, 0.1950852427398786, 0.15296940109692514, 0.11590529189561494, 0.08234834996983409, 0.21223838324658573, 0.2196648027165793, 0.31093850266188383, 0.12072042023646645, 0.09929922554874793, 0.10240138799417764, 0.14906831667758524, 0.18205869564553723, 0.16356385604012758, 0.15136315603740513, 0.12823237222619355, 0.17953046568436548, 0.17652721668127924, 0.22210620139958337, 0.15827915602130815, 0.16749378031818196, 0.09537156482110731, 0.14850532345008105, 0.1691543060587719, 0.14647701900685206, 0.12086159898899496, 0.17579612700501457, 0.255114451283589, 0.09080818039365113, 0.14560747426003218, 0.2952528849709779, 0.1809203004813753, 0.09946901409421116, 0.225317845470272, 0.21349912887671962, 0.17462513671489432, 0.19249796750955284, 0.22179991705343127, 0.15388515195809305, 0.10174334049224854, 0.28396855923347175, 0.18041123170405626, 0.1219395239604637, 0.2344198414357379, 0.205690725997556, 0.23450640554074198, 0.175157479243353, 0.18700321001233533, 0.19685844134073704, 0.1425229452433996, 0.35188151348847896, 0.1582541159586981, 0.25169246771838516, 0.29460757272318006, 0.3277865017298609, 0.7000194559805095, 0.6016706395894289, 7.52946887165308, 38.58279526233673, 100.49788132309914, 101.63177087903023, 102.25030168890953, 86.01005673408508, 73.34776058793068, 40.1622299104929, 39.265212044119835, 61.15923061966896, 72.44166880846024, 90.0608217716217, 107.79039680957794, 106.78699225187302, 93.65425854921341, 85.41102647781372, 77.17996895313263, 68.62966015934944, 57.461915016174316, 50.921576768159866, 41.271633580327034, 32.98493564128876, 20.50863951444626, 10.610439497977495, 6.092425882816315, 2.17951032333076, 0.49979964969679713, 0.2805472881300375, 0.4017055977601558, 0.28439428482670337, 0.16168800357263535, 0.20812951232073829, 0.2682504354743287, 0.6855881866067648, 0.8992517902515829, 3.1043657334521413, 2.765900082886219, 1.244362334255129, 0.2251791677554138, 0.133920444350224, 0.5158350861165673, 0.48876759479753673, 0.3665753250243142, 0.2890020125778392, 0.5912780785001814, 0.5984899727627635, 0.9692672488745302, 0.836339812958613, 1.5586006036028266, 3.1700703827664256, 4.2636842373758554, 8.538282439112663, 12.323164343833923, 18.878946863114834, 28.845965936779976, 41.54213726520538, 52.83780634403229, 57.628076300024986, 79.52009618282318, 50.43877847492695, 77.10923954844475, 69.34328466653824, 59.12060581147671, 70.03319084644318, 64.5776715874672, 70.80480024218559, 82.60078087449074, 93.3488081395626, 70.69147512316704, 32.89334535598755, 3.3680098364129663, 0.4625595104880631, 0.3612084098858759, 0.34084138402249664, 0.28809576120693237, 0.2647513279225677, 0.1476979855215177, 0.22823163599241525, 0.17689539614366367, 0.09594543051207438, 0.2726027159951627, 0.1548849287792109, 0.19173129927366972, 0.19808061013463885, 0.10086206239066087, 0.2187491112272255, 0.13233172881882638, 0.1095501403324306, 0.1566982627264224, 0.1641542196739465, 0.10845593264093623, 0.1052798968157731, 0.07673625892493874, 0.09211336582666263, 0.16239201970165595, 0.1545102777890861, 0.14890259510139003, 0.12902746471809223, 0.143318141635973, 0.11561071121832356, 0.13213390193413943, 0.16091612546006218, 0.0920538826903794, 0.10094781013322063, 0.16308503720210865, 0.12956639751791954, 0.20603307872079313, 0.14558417082298547, 0.10471784611581825, 0.11053333757445216, 0.14713992015458643, 0.18036331865005195, 0.13672073080670089, 0.163206422876101, 0.17551466007716954, 0.10892924474319443, 0.21903008833760396, 0.24418269022135064, 0.14474707277258858, 0.13987227575853467], [0.061423633524100296, 0.03723861780599691, 0.030737877277715597, 0.02893622102419613, 0.05359920396585949, 0.04222076648147777, 0.0961528682091739, 0.05367343357647769, 0.03831371148407925, 0.04568740136164706, 0.042546550757833757, 0.06942528052604757, 0.062244664077297784, 0.036999412477598526, 0.07903637495473959, 0.02881771302781999, 0.06146169085695874, 0.026215967773168813, 0.0383960750332335, 0.06955188349820673, 0.03683480783365667, 0.048165788684855215, 0.06748095009243116, 0.049479475419502705, 0.02513006100343773, 0.06418571050744504, 0.049752930863178335, 0.01091857402570895, 0.07438845990691334, 0.09653558634454384, 0.03497677433188073, 0.03452463570283726, 0.08111025468679145, 0.0398525101627456, 0.026943971970467828, 0.03589790576370433, 0.032838131082826294, 0.03276894807640929, 0.022080142043705564, 0.03343839867739007, 0.003581623009267787, 0.07622342003742233, 0.022169010517245624, 0.006972873543418245, 0.015131067320908187, 0.10174665789236315, 0.05649464488669764, 0.05117348686326295, 0.05748124487581663, 0.01965873125300277, 0.056725608665146865, 0.16257630981272087, 0.04403271261253394, 0.06019863714755047, 0.10808378268848173, 0.1848600507946685, 0.17048061301466078, 0.28666956117376685, 5.543073685839772, 43.330606296658516, 69.28240433335304, 64.7743946313858, 66.24733999371529, 63.54442723095417, 57.80211456120014, 39.830522909760475, 26.658617109060287, 19.12815649062395, 28.837158009409904, 44.40831586718559, 55.40177196264267, 58.062073811888695, 74.10081937909126, 62.62266889214516, 54.01453860104084, 44.94604021310806, 48.394837751984596, 40.19334264099598, 34.37658056616783, 39.85156238079071, 32.684827744960785, 29.617943912744522, 20.17262924462557, 15.692344754934311, 10.40842143818736, 7.211462035775185, 4.784580711275339, 2.660531736910343, 2.1213770052418113, 0.6629793997853994, 0.6471895845606923, 0.4275246482575312, 0.4499409516574815, 0.20808343979297206, 0.3774540818994865, 1.323749574366957, 3.006290146149695, 3.347900602966547, 4.099888801574707, 4.802882429212332, 7.719705663621426, 11.249321065843105, 16.162440329790115, 26.04346051812172, 34.939972534775734, 48.57896067202091, 59.75331746041775, 61.61655507981777, 52.10114747285843, 43.05838890373707, 40.55492363870144, 29.678995236754417, 21.691975817084312, 24.26482915878296, 25.26261191815138, 17.37677536904812, 29.558570198714733, 55.709308460354805, 54.975134655833244, 57.94174566864967, 62.090507447719574, 75.23954227566719, 61.77772343158722, 29.84105084091425, 1.9383055600337684, 0.17457098962040618, 0.008595575727667892, 0.17024557484546676, 0.04617222417437006, 0.15965990693075582, 0.022315490059554577, 0.02958619581477251, 0.05870908367796801, 0.07934767621918581, 0.028092779466533102, 0.04094722622539848, 0.03423515358008444, 0.12902007292723283, 0.054638433357467875, 0.06770104882889427, 0.039730616117594764, 0.011574819036468398, 0.021789407546748407, 0.04281946814444382, 0.047749974473845214, 0.030188854980224278, 0.06741866905940697, 0.02345436019822955, 0.130295809940435, 0.03144307527691126, 0.017873812284960877, 0.09886641244520433, 0.08931025178753771, 0.03651227416412439, 0.017094718641601503, 0.07635809757630341, 0.0261095382302301, 0.014779266130062751, 0.046062994879321195, 0.04469228151720017, 0.030019528421689756, 0.1276127086021006, 0.03854955117276404, 0.004298924741306109, 0.02342442938243039, 0.015488830740650883, 0.05563619895838201, 0.03078450641623931, 0.025359739011037163, 0.003945158250644454, 0.030005700355104636, 0.04369885748019442, 0.06655676101217978, 0.019585420050134417, 0.04055476740177255, 0.07112482096999884, 0.0957775567076169, 0.0530755816726014, 0.01770714075973956, 0.03669636389531661, 0.0474381611275021, 0.016831627290230244, 0.01038098729623016, 0.03419102918996941, 0.015332817383750807, 0.02303913042851491, 0.037410139266285114, 0.02743386179645313, 0.024026107057579793, 0.046051725366851315, 0.010093598957610084, 0.057839319997583516, 0.025665364701126236, 0.032215513710980304, 0.027678482947521843, 0.05561981975915842, 0.025343597299070098, 0.02469055929395836, 0.04456581955309957, 0.01085332904040115, 0.040287583105964586, 0.05920553223404568, 0.05757575738243759, 0.08134311836329289, 0.01553359523313702, 0.03873368172207847, 0.03603250908781774, 0.07846092848922126, 0.02848623276804574, 0.035899493959732354, 0.03644152151537128, 0.03844884173304308, 0.10375107260188088, 0.02896653033531038, 0.03410109944525175, 0.02835794883139897, 0.0584442779654637, 0.02089270576107083, 0.0064891931742749875, 0.060409496145439334, 0.023485530400648713, 0.0074572645189618925, 0.020387525837577414, 0.11889562752912752, 0.043763060675701126, 0.06805537239415571, 0.01779684786015423, 0.12230972948600538, 0.17600339400814846, 0.12046503237797879, 0.11702365649398416, 0.26731705118436366, 0.6912877620197833, 0.4546688182745129, 14.582625702023506, 62.121962159872055, 84.53515067696571, 79.11432355642319, 71.10618487000465, 56.92022368311882, 33.67509260773659, 24.270663745701313, 35.34191116690636, 38.147247433662415, 50.659364238381386, 69.84985068440437, 75.33003062009811, 75.8178636431694, 66.87843292951584, 57.5473952293396, 42.29627899825573, 38.689577132463455, 37.03727759420872, 22.379028350114822, 12.703512534499168, 4.4643818680197, 4.735194286331534, 3.29021162353456, 4.349910635501146, 3.952876590192318, 2.4567436845973134, 1.753193149343133, 2.170534492470324, 1.8471687566488981, 0.8615166088566184, 0.23043820430757478, 0.5496273853350431, 0.42577199230436236, 0.26490343851037323, 0.08949696872150525, 0.2838150830939412, 0.4432251979596913, 1.5814380906522274, 1.9350707461126149, 0.49565956403966993, 0.8547862793784589, 2.8385925572365522, 3.936650035902858, 5.428810967132449, 6.424313373863697, 3.1667685974389315, 9.900477044284344, 21.621719487011433, 36.640039309859276, 41.15390829741955, 52.342157140374184, 54.612010940909386, 58.3790186047554, 62.32631139457226, 58.8741510361433, 69.01478469371796, 36.81127332150936, 57.324392795562744, 62.290464118123055, 40.019562765955925, 55.09003289043903, 61.43799886107445, 83.07654574513435, 75.50086185336113, 43.0640771985054, 4.270078344270587, 0.17274604848353192, 0.19343665073392913, 0.1938842103118077, 0.19341404491569847, 0.128765961562749, 0.08863085269695148, 0.044862333525088616, 0.00907340658159228, 0.03441598528297618, 0.05597533076070249, 0.0904669779993128, 0.02111429064825643, 0.13208085321821272, 0.05871705805475358, 0.04133950322284363, 0.049542509732418694, 0.041379211834282614, 0.081368856044719, 0.04552814018097706, 0.06069461815059185, 0.05953576568572316, 0.10431312330183573, 0.07095344422850758, 0.005323471204974339, 0.03792011346376967, 0.03960699657909572, 0.044325898052193224, 0.044097680220147595, 0.031031777034513652, 0.02845539838745026, 0.06808391539379954, 0.06725692539475858, 0.011641178170975763, 0.02609103834402049, 0.06485729478299618, 0.09633332883822732, 0.09591167021426372, 0.01954417890374316, 0.03160447013215162, 0.01418436240783194, 0.02520294176065363, 0.024290140936500393, 0.03964585172070656, 0.05226706743997056, 0.030757811364310328, 0.04412385205796454, 0.019915807497454807, 0.04361863131634891, 0.04668469569878653, 0.022104747949924786, 0.07600355136673898, 0.20457651000469923, 0.17545417504152283, 0.1324464351637289, 0.15250546974129975, 0.16321172181051224, 0.13777570857200772, 0.15861091087572277, 0.21286205446813256, 0.13626862928504124, 0.15748201520182192, 0.1400699542136863, 0.13448180485283956, 0.2039239098667167, 0.10043545364169404, 0.116531434468925, 0.12524506455520168, 0.14080145949264988, 0.1301382965175435, 0.15900669823167846, 0.23561069159768522, 0.09233954275259748, 0.13287297711940482, 0.13094616879243404, 0.22902877681190148, 0.10941241998807527, 0.2473056921735406, 0.13400948722846806, 0.21439314965391532, 0.13633330003358424, 0.20001172291813418, 0.14700535393785685, 0.18909850070485845, 0.1584473712136969, 0.2802296489244327, 0.10742512662545778, 0.14095913618803024, 0.13723017065785825, 0.12039321474730968, 0.1278242949047126, 0.09574928830261342, 0.11562832980416715, 0.21338461549021304, 0.15246147522702813, 0.1858838732005097, 0.13644803606439382, 0.14644817914813757, 0.16743093525292352, 0.18528681539464742, 0.15272576885763556, 0.1252099609700963, 0.15168081008596346, 0.2858928294153884, 0.3394391108304262, 0.35347098601050675, 0.17276222730288282, 0.4035772942006588, 0.6099707598332316, 0.5274663807358593, 16.99074648320675, 73.52927684783936, 98.55869337916374, 95.76917946338654, 93.93909126520157, 86.82759806513786, 74.93551298975945, 51.36083699762821, 44.2069760710001, 37.18907564878464, 46.03650189936161, 69.1418194770813, 78.50222960114479, 80.87202563881874, 95.95007255673409, 95.09455606341362, 90.60049921274185, 80.19036501646042, 86.66296049952507, 73.07263255119324, 75.2975195646286, 71.19090512394905, 58.11014123260975, 46.44865058362484, 32.253718078136444, 24.213264025747776, 16.287408024072647, 10.43883690610528, 6.901682708412409, 4.667186010628939, 2.90412122849375, 0.9288067230954766, 0.6102664908394217, 0.5969728447962552, 0.5151032097637653, 0.2309764246456325, 0.5867091205436736, 2.0183797320351005, 4.342273520305753, 6.400100598111749, 6.913030324503779, 9.299746379256248, 15.04105780273676, 24.087853655219078, 33.195265755057335, 45.235326290130615, 60.42821444571018, 81.2220324575901, 88.05942356586456, 85.95746755599976, 85.35165086388588, 73.21073994040489, 76.27355799078941, 65.45224785804749, 50.84908425807953, 50.59762515127659, 51.722695380449295, 39.00133520364761, 57.02104367315769, 86.80340856313705, 81.84062406420708, 80.50579369068146, 75.77624067664146, 93.53575050830841, 89.98159602284431, 50.561014115810394, 5.752801056951284, 0.3438381169689819, 0.35785336804110557, 0.5021559388842434, 0.46773141890298575, 0.2765385922975838, 0.1573224682942964, 0.20703833259176463, 0.120281024283031, 0.18368916440522298, 0.1284353793016635, 0.15665098791942, 0.12750833295285702, 0.32602019025944173, 0.21057086647488177, 0.15887968707829714, 0.1351636604522355, 0.10859512985916808, 0.16303871234413236, 0.12710344686638564, 0.12863773328717798, 0.14158451434923336, 0.22845643252367154, 0.14490440808003768, 0.1441761534078978, 0.13354659487958997, 0.12515815906226635, 0.21424466074677184, 0.1273662710445933, 0.21226238430244848, 0.13481850241078064, 0.21821299858856946, 0.22679157264064997, 0.11970521416515112, 0.10871069709537551, 0.10353054341976531, 0.2235114580253139, 0.24044055899139494, 0.16831808374263346, 0.0664048211183399, 0.09238918501068838, 0.06947154601220973, 0.15056847914820537, 0.13624636485474184, 0.2624593087239191, 0.10483109785127454, 0.18206156033556908, 0.27582007460296154, 0.128922569565475, 0.1549110672203824, 0.10608537195366807, 0.14793683832976967], [0.049724321070243604, 0.01661035781580722, 0.1747793995309621, 0.07689451449550688, 0.16871640924364328, 0.02106091909809038, 0.06578361382707953, 0.025299276239820756, 0.04812920080439653, 0.02911360359576065, 0.02275390081194928, 0.018602393502078485, 0.026807899193954654, 0.0845161484903656, 0.08248337631812319, 0.03779331382247619, 0.034339161866228096, 0.02576092734670965, 0.08208923653000966, 0.05220635976002086, 0.03641580609837547, 0.034348524059168994, 0.03580314092687331, 0.025728619802976027, 0.027959790313616395, 0.01465727746108314, 0.016921345522860065, 0.05528298490389716, 0.06917539198184386, 0.03774757897190284, 0.028532579890452325, 0.030540299012500327, 0.051770897189271636, 0.04975150222890079, 0.069307843077695, 0.02831315650837496, 0.07314811591641046, 0.06359165839967318, 0.02019953612034442, 0.028094402914575767, 0.0469378237175988, 0.024277012344100513, 0.04354855031124316, 0.06464491438237019, 0.07080333743942901, 0.08377327350899577, 0.05607745028100908, 0.05445354581752326, 0.02916291374276625, 0.08216722882934846, 0.06619975087232888, 0.08298323504277505, 0.019085603998973966, 0.1018894619483035, 0.038252094673225656, 0.06100609010900371, 0.07551367452833802, 0.09766197355929762, 0.2915486478013918, 0.24559860408771783, 11.247046887874603, 62.68853835761547, 76.07216119766235, 64.77359667420387, 68.40974316000938, 77.05286577343941, 63.485211208462715, 59.74799394607544, 65.0445069372654, 38.258725851774216, 36.07305273413658, 37.87396229803562, 35.55175870656967, 38.12261335551739, 27.43393510580063, 29.895353727042675, 30.549433529376984, 41.710084453225136, 41.50958061218262, 44.184496477246284, 49.94261249899864, 53.572998493909836, 56.372589468955994, 61.55559875071049, 61.02417066693306, 62.24569492042065, 60.402284637093544, 48.820525109767914, 44.119360372424126, 35.73684677481651, 32.6055184006691, 29.501271173357964, 29.583550058305264, 29.26046099513769, 28.450752943754196, 26.75456576049328, 21.969056949019432, 22.56746593862772, 25.175423696637154, 29.761840291321278, 34.98979926109314, 40.95604531466961, 50.01421205699444, 61.05394206941128, 55.90651787817478, 60.197304636240005, 72.69487962126732, 72.39531889557838, 40.76050020754337, 33.04287873208523, 35.42160429060459, 18.177436105906963, 28.808285258710384, 29.567009545862675, 31.257324144244194, 44.7472158819437, 43.23473364114761, 51.84629134833813, 63.91351282596588, 73.1706976890564, 66.9657750427723, 42.97469079494476, 4.466790938749909, 0.04019686297397129, 0.0718142613186501, 0.1296854528482072, 0.040950502807390876, 0.10449543930008076, 0.051279973922646604, 0.040713275302550755, 0.07356174450251274, 0.10477001909748651, 0.06277349253650755, 0.030741513801331166, 0.046871460872353055, 0.03488959053356666, 0.08205851161619648, 0.06182728393469006, 0.06481983858975582, 0.08271571306977421, 0.009565591499267612, 0.039269304543267936, 0.07671475148526952, 0.07594397175125778, 0.005406649261203711, 0.037225277701509185, 0.07638362745638005, 0.1202551307505928, 0.02734969853918301, 0.027478542797325645, 0.03269141961936839, 0.07037416828097776, 0.033566508209332824, 0.012649533291551052, 0.019020504660147708, 0.0633960060076788, 0.03205147681001108, 0.082422557316022, 0.029180773526604753, 0.008722739021322923, 0.05332103588443715, 0.07400637259706855, 0.022747972907382064, 0.026185836577496957, 0.04253398619766813, 0.0678687370964326, 0.01223802168169641, 0.035310859530000016, 0.05530051072128117, 0.03614972018112894, 0.05296899071254302, 0.03357818961376324, 0.09240667000995018, 0.020854726353718434, 0.0297867575136479, 0.06362151500070468, 0.09738314125570469, 0.07817595862434246, 0.018598528768052347, 0.0308738554304, 0.06697904304019175, 0.004145102575421333, 0.0526926334714517, 0.04526037700998131, 0.010152047725568991, 0.021451051288750023, 0.03707027644850314, 0.03477384518191684, 0.04052241718454752, 0.05279907229123637, 0.03174714060151018, 0.01860787240730133, 0.05576074247073848, 0.030965035693952814, 0.09050868669874035, 0.010775868304335745, 0.018333836233068723, 0.021682562401110772, 0.042530104765319265, 0.0304703460278688, 0.05999901797622442, 0.026978415044141002, 0.05081955292553175, 0.042272794744349085, 0.08191867615096271, 0.061448213455150835, 0.04728316729597282, 0.027618363419605885, 0.06163843703689054, 0.036112486632191576, 0.039810719827073626, 0.06007588963257149, 0.02944541411125101, 0.036216279695509, 0.06164608486869838, 0.006429022159863962, 0.017165753306471743, 0.030456202548521105, 0.014412636828637915, 0.019031139636354055, 0.04027955677884165, 0.11484532689792104, 0.02498506204574369, 0.022666748554911464, 0.01271291270313668, 0.05752674594987184, 0.03267358952143695, 0.047001607599668205, 0.056938898196676746, 0.08298944681882858, 0.1220140207442455, 0.06056371072190814, 0.12498566909926012, 0.11770862169214524, 0.5227804009336978, 1.337839812040329, 23.062412180006504, 76.86039850115776, 88.70469734072685, 74.13252487778664, 73.55304837226868, 54.740166664123535, 37.3611456155777, 22.572949044406414, 34.80401962995529, 33.672413751482964, 46.38474941253662, 47.253394201397896, 58.47670756280422, 57.118212059140205, 42.84955970942974, 33.417800813913345, 35.635069236159325, 36.26147322356701, 30.65559983253479, 34.79835793375969, 29.145066887140274, 27.871926203370094, 33.94596107304096, 33.98854538798332, 31.68492279946804, 25.68452227860689, 27.936866618692875, 19.50691256672144, 14.839576464146376, 10.543217305094004, 9.721104819327593, 7.572037512436509, 6.694155419245362, 7.611492220312357, 7.502530692145228, 6.854984639212489, 12.286380417644978, 10.640557631850243, 9.657088704407215, 9.253803994506598, 21.837646700441837, 22.888524010777473, 32.18672767281532, 47.05020770430565, 53.59232425689697, 59.51280936598778, 81.40465825796127, 94.45675268769264, 79.52003538608551, 74.37675297260284, 64.84750270843506, 54.09454330801964, 47.203639671206474, 42.603652104735374, 33.18078853189945, 24.37479715794325, 34.56895284354687, 55.46623170375824, 65.00777810811996, 81.96021884679794, 83.20433288812637, 58.9351187646389, 9.333210233598948, 0.08843219460686669, 0.0919918688305188, 0.17272218101425096, 0.11259768813033588, 0.14447259687585756, 0.11451985803432763, 0.039774959441274405, 0.14978928345954046, 0.09382921125506982, 0.0342937016102951, 0.10155572555959225, 0.019907753339794, 0.03907632017217111, 0.019149627223669086, 0.03615777248342056, 0.07477521532564424, 0.0665002761525102, 0.06677757963188924, 0.04236157416016795, 0.07388529120362364, 0.1147276148549281, 0.015286489742720732, 0.07862836442654952, 0.031036738291732036, 0.02848155352694448, 0.026174529957643244, 0.01040727323925239, 0.027567068027565256, 0.029879761605116073, 0.01749081213347381, 0.012787560699507594, 0.005343950306269107, 0.04643845481041353, 0.019802527931460645, 0.06644020671956241, 0.015042801842355402, 0.0496496053528972, 0.08274338775663637, 0.13381721160840243, 0.027782079341704957, 0.0654450015281327, 0.04300022563256789, 0.07775577687425539, 0.04233108302287292, 0.0046793644833087455, 0.02964334675198188, 0.043716353611671366, 0.03587751525628846, 0.008364354052901035, 0.05449605974717997, 0.05227005829510745, 0.017205063013534527, 0.06050683623470832, 0.1743002244620584, 0.1773118003620766, 0.21270498633384705, 0.14178646757500246, 0.2683478349354118, 0.15108870982658118, 0.18846717051928863, 0.1673548502731137, 0.10138125406228937, 0.08940077153965831, 0.15896013588644564, 0.12397895319736563, 0.0982107175514102, 0.18383634713245556, 0.10254266322590411, 0.09482268724241294, 0.1496934870374389, 0.1099308769335039, 0.21507542085601017, 0.12165735199232586, 0.164986404706724, 0.16486858134157956, 0.17098050884669647, 0.13329288427485153, 0.16035144013585523, 0.1297453441657126, 0.14707376511069015, 0.150616985920351, 0.19296356127597392, 0.15989270381396636, 0.13480710302246734, 0.20052932639373466, 0.14145177381578833, 0.1400158813339658, 0.11018339268048294, 0.129457984585315, 0.11050857210648246, 0.1966543952585198, 0.08444344770396128, 0.11262370782787912, 0.09308603941462934, 0.13126955222105607, 0.14991102536441758, 0.11275576558546163, 0.13577863370301202, 0.2551784837851301, 0.2275121831917204, 0.1655847390065901, 0.1554759603459388, 0.12365082744508982, 0.23598044441314414, 0.1795647232211195, 0.15091130684595555, 0.14807901898166165, 0.23366717010503635, 0.17670622270088643, 0.13076180446660146, 0.3081567253684625, 0.49232936929911375, 0.9096949954982847, 26.130006574094296, 88.81600096821785, 103.88628870248795, 90.79121097922325, 100.62479451298714, 102.28994876146317, 85.63665837049484, 78.83125394582748, 88.86536031961441, 62.221467420458794, 60.55961899459362, 61.94706134498119, 56.25586733222008, 57.66045056283474, 47.669281885027885, 52.57035009562969, 50.830275267362595, 60.35907715559006, 60.49754552543163, 63.413007482886314, 69.82266694307327, 72.69202217459679, 81.39588072896004, 86.83460488915443, 83.12530472874641, 86.49793535470963, 83.73345449566841, 70.84824711084366, 64.3448656797409, 54.68337491154671, 46.711870059370995, 43.98629151284695, 44.32973228394985, 46.042577773332596, 46.76591835916042, 49.67221900820732, 47.12919406592846, 47.96138361096382, 54.72887746989727, 58.19300338625908, 69.62673425674438, 70.4126612842083, 85.46668589115143, 91.14097461104393, 84.98072236776352, 78.60294699668884, 92.82011210918427, 99.54472526907921, 59.430304393172264, 57.39277772605419, 56.780375987291336, 46.09813839197159, 67.68151223659515, 67.64397785067558, 69.48111847043037, 76.20004713535309, 74.96296271681786, 66.50249630212784, 74.21366572380066, 91.84082105755806, 95.6205390393734, 61.74865119159222, 9.958067703992128, 0.1964893564581871, 0.17084929713746533, 0.3100073745008558, 0.1722643946413882, 0.3597294579958543, 0.2423408132744953, 0.1811682223342359, 0.22719172382494435, 0.2964301983593032, 0.09378359885886312, 0.2001125511014834, 0.14163112122332677, 0.14170305017614737, 0.19158374547259882, 0.11372089153155684, 0.12396316771628335, 0.20917445624945685, 0.22997565334662795, 0.1515617547556758, 0.18652342638233677, 0.21193202468566597, 0.07677316592889838, 0.13794355269055814, 0.12780712160747498, 0.2864993124967441, 0.0554902853036765, 0.15034990181447938, 0.07822571220458485, 0.1529857877176255, 0.13624872488435358, 0.10846752498764545, 0.17608440684853122, 0.2078639273531735, 0.19567205890780315, 0.17587344394996762, 0.10725859610829502, 0.07306386731215753, 0.25327386567369103, 0.22951537335757166, 0.16045964526711032, 0.15954718954162672, 0.1278149290010333, 0.14443222404224798, 0.12236648894031532, 0.1709177825250663, 0.2231811874662526, 0.07241643252200447, 0.10698412763304077, 0.11646105660474859, 0.16588970232987776, 0.16897383058676496, 0.12277490764972754, 0.11883832630701363], [0.03573128618882038, 0.04968595574609935, 0.03749859955860302, 0.05659270114847459, 0.020585734928317834, 0.013346801442821743, 0.02680477475223597, 0.04215565786580555, 0.031050267643877305, 0.040217064233729616, 0.044374556964612566, 0.05980175883451011, 0.08206152473576367, 0.038186370074981824, 0.02600048333988525, 0.06732408975949511, 0.07613278154167347, 0.019814407860394567, 0.03744828194612637, 0.07679506670683622, 0.014056700019864365, 0.04640534760255832, 0.024622459823149256, 0.01663072791416198, 0.029754893403151073, 0.035461912557366304, 0.04451948727364652, 0.04818293971766252, 0.051543080116971396, 0.06709627268719487, 0.05371779545384925, 0.07413825966068543, 0.04608442439348437, 0.04754253677674569, 0.06296734893112443, 0.056420329929096624, 0.05354888635338284, 0.018278165880474262, 0.11356813527527265, 0.06351353993522935, 0.15080998884513974, 0.018965426170325372, 0.10305401039659046, 0.06398464785888791, 0.04360043385531753, 0.011067358864238486, 0.0644191011087969, 0.0478416927944636, 0.0293309285552823, 0.07576708085252903, 0.027977407044090796, 0.06432558308006264, 0.00886014116986189, 0.12267331505427137, 0.042557679262245074, 0.09465704730246216, 0.10594275343464687, 0.032737833535065874, 0.09795713311177678, 0.050696078105829656, 0.4110331175616011, 0.4905640968354419, 21.24134849756956, 46.51630975306034, 66.62823915481567, 67.94564366340637, 72.84463718533516, 67.90294915437698, 62.20722198486328, 66.72812059521675, 61.036223620176315, 61.08182117342949, 56.4349365234375, 51.010594591498375, 56.479481533169746, 44.00920428335667, 32.152616903185844, 34.5874160528183, 32.267002165317535, 45.7723780721426, 50.22548072040081, 34.19591546058655, 30.67512698471546, 36.71374395489693, 44.24738310277462, 43.97092893719673, 59.84015040099621, 66.10103264451027, 59.11000818014145, 52.65995308756828, 46.510241478681564, 44.85994063317776, 52.036041766405106, 58.98551546037197, 63.611866012215614, 43.263771682977676, 29.713997058570385, 28.487185388803482, 47.12533727288246, 40.38931332528591, 47.7318075299263, 50.20501121878624, 55.21595433354378, 41.25765413045883, 34.574276357889175, 40.396836921572685, 39.87070955336094, 36.61731272935867, 38.53685952723026, 53.59982505440712, 43.166363909840584, 53.689724430441856, 59.328663647174835, 61.58600091934204, 64.3762443959713, 64.51417699456215, 72.11600348353386, 71.89392060041428, 62.10200183093548, 28.583838902413845, 6.861954890191555, 0.5589184805285186, 0.14120364416157827, 0.13995806802995503, 0.10047783027403057, 0.05712332560506184, 0.07043166246148758, 0.06424535691621713, 0.07338375522522256, 0.10069477488286793, 0.08362298118299805, 0.07219443388748914, 0.06427842701668851, 0.09970400773454458, 0.00922405884921318, 0.01943122588272672, 0.043426715637906455, 0.09979679845855571, 0.006326528782665264, 0.03573800633603241, 0.02393168175331084, 0.04543974297121167, 0.015692742308601737, 0.02528819411963923, 0.034082872298313305, 0.07222654661745764, 0.04372038718429394, 0.03184364577464294, 0.019636876859294716, 0.07256210126797669, 0.05035533213231247, 0.024326396705873776, 0.03500598897517193, 0.03425654969760217, 0.02683792834432097, 0.03736492020834703, 0.10020138026447967, 0.022511302013299428, 0.00818714495835593, 0.05242220599029679, 0.05384232412325218, 0.020149350239080377, 0.03885981714120135, 0.009405891523783794, 0.012545385852718027, 0.018250389148306567, 0.048981657600961626, 0.02088176093820948, 0.025871182660921477, 0.042930011040880345, 0.08065680245636031, 0.09692315812571906, 0.029058304317004513, 0.07439091641572304, 0.040872703466448, 0.046153629664331675, 0.08511356994858943, 0.05925708181166556, 0.10111467461683787, 0.0356164388358593, 0.04804949043318629, 0.02419270993414102, 0.035481616578181274, 0.0571122898691101, 0.019659185818454716, 0.04061542684212327, 0.017337425051664468, 0.01889137096441118, 0.06076602388930041, 0.057538067412679084, 0.03944890799175482, 0.040360911007155664, 0.04952800074534025, 0.059692618597182445, 0.035200335187255405, 0.07137822729418986, 0.028640005766646937, 0.05635348097712267, 0.024044091151154134, 0.1075096424028743, 0.035735494166146964, 0.02966691921756137, 0.019438126000750344, 0.09647319398936816, 0.061493428802350536, 0.08842051320243627, 0.025350653268105816, 0.03352639512741007, 0.05187794457015116, 0.04456248731003143, 0.013638378277391894, 0.04739134274132084, 0.07895197049947456, 0.01753066731907893, 0.06764982579625212, 0.024613769273855723, 0.11173830338520929, 0.0056330372353841085, 0.04652035822800826, 0.013820224867231445, 0.06715113966492936, 0.085285540408222, 0.04719022072094958, 0.03782589781621937, 0.1262881382717751, 0.01263069480046397, 0.021387571687228046, 0.05091868530143984, 0.05770460906205699, 0.025841673013928812, 0.013061933623248478, 0.013228897369117476, 0.11913652866496705, 0.030308325913210865, 0.2367379397037439, 0.05409470628364943, 0.453870712663047, 3.3098522946238518, 34.976940751075745, 64.25318419933319, 85.13741835951805, 88.37308913469315, 83.93539845943451, 72.02122896909714, 65.14866694808006, 59.40405920147896, 52.720521837472916, 51.720920875668526, 51.75277836620808, 46.7727579921484, 38.17598529160023, 37.05743931233883, 35.21676488220692, 40.29087960720062, 34.33306910097599, 44.86724004149437, 49.60867501795292, 39.65997286140919, 50.96589758992195, 60.531960278749466, 72.98910543322563, 71.8234571814537, 84.50936526060104, 73.54319170117378, 78.3903332054615, 76.48920401930809, 77.34393015503883, 68.7985534965992, 66.61943882703781, 63.496694192290306, 60.97168788313866, 51.13227166235447, 41.01953610777855, 36.50101616978645, 47.19253666698933, 37.95934371650219, 42.74964027106762, 45.1712579280138, 53.30335736274719, 58.144764974713326, 57.30899602174759, 55.71099556982517, 72.19645276665688, 76.99985101819038, 47.42757685482502, 54.1536795347929, 44.22939106822014, 29.04627598822117, 36.781950294971466, 42.91477181017399, 50.25629706680775, 59.462435469031334, 73.81708100438118, 84.05490204691887, 84.09519508481026, 44.64147515594959, 13.453849721699953, 0.8648398274090141, 0.3589448594721034, 0.08445869883871637, 0.07079328875988722, 0.07538667079643346, 0.16968037001788616, 0.06019771688443143, 0.11136610148241743, 0.012099163068342023, 0.013809883039357373, 0.015402577409986407, 0.0532888897578232, 0.08277650980744511, 0.003897778615282732, 0.039236768789123744, 0.016436025471193716, 0.14319175388664007, 0.027963929642282892, 0.02909238373831613, 0.028171423000458162, 0.03444337424298283, 0.029186666179157328, 0.05362112700822763, 0.023799486698408145, 0.01723044075333746, 0.021294775397109333, 0.03508187357510906, 0.0210109410181758, 0.03460448337136768, 0.07751092009129934, 0.03041925472643925, 0.10005448697484098, 0.035234396054875106, 0.09506157715804875, 0.04579356929752976, 0.039777004058123566, 0.024403201568929944, 0.15686098602600396, 0.010488394618732855, 0.058028278217534535, 0.005812244562548585, 0.027974251061095856, 0.010370256768510444, 0.03511809780320618, 0.044200846168678254, 0.009763421167008346, 0.030938824893382844, 0.017203881143359467, 0.061773125707986765, 0.045245957080624066, 0.08132688017212786, 0.04804875570698641, 0.00835974717119825, 0.1533559858216904, 0.060976652821409516, 0.12743168394081295, 0.12813679844839498, 0.203786805504933, 0.15672123961849138, 0.14325217955047265, 0.09956950088962913, 0.13055866380454972, 0.2581820741761476, 0.10035991785116494, 0.18507825705455616, 0.12463072955142707, 0.11470290875877254, 0.1719161937944591, 0.15593775431625545, 0.08664036067784764, 0.21583392546745017, 0.15372471447335556, 0.13474235805915669, 0.18876858637668192, 0.2241143342689611, 0.2110817312495783, 0.15316228527808562, 0.08497847680700943, 0.13402605196461082, 0.1197704637888819, 0.12995262601180002, 0.13515058381017298, 0.1785658221342601, 0.12884094816399738, 0.18935764383058995, 0.09332907051430084, 0.20809385954635218, 0.11324211722239852, 0.1473332050954923, 0.11438245681347325, 0.15510081953834742, 0.15821966546354815, 0.11399381633964367, 0.2129276900086552, 0.213608595659025, 0.22946204262552783, 0.12659133528359234, 0.22966418880969286, 0.1043648287304677, 0.14201328274793923, 0.18164151959354058, 0.19025760178919882, 0.18085371499182656, 0.17384919163305312, 0.14672258083010092, 0.08673868782352656, 0.15724822384072468, 0.1726729320944287, 0.2777833817526698, 0.1823964322102256, 0.1779657808947377, 0.32986540580168366, 0.20560767967253923, 0.34600358514580876, 0.17029365117195994, 0.5455409421119839, 2.5390893034636974, 35.618665516376495, 76.43119633197784, 106.15619570016861, 108.57301041483879, 111.06503829360008, 104.142736941576, 98.6454351246357, 90.2473233640194, 89.24495235085487, 87.50375658273697, 87.03993827104568, 83.08077111840248, 87.72611305117607, 68.61454457044601, 55.95838889479637, 53.420394882559776, 47.24716253578663, 63.55042330920696, 66.72836378216743, 45.43298788368702, 44.705809503793716, 47.67962493002415, 59.23748753964901, 54.46837104856968, 75.35055711865425, 78.80749762058258, 76.50452479720116, 71.50649338960648, 66.2182867527008, 63.49659539759159, 74.00277704000473, 82.987569719553, 83.59442755579948, 59.59784120321274, 46.03017523884773, 46.6750006377697, 76.05657443404198, 67.43187323212624, 74.33359488844872, 69.01384994387627, 75.51368236541748, 57.68254637718201, 47.730678990483284, 47.52006769180298, 48.93066979944706, 59.8258251696825, 58.985089883208275, 95.25330394506454, 77.9463118314743, 90.84864109754562, 95.11436820030212, 92.98547923564911, 88.73879671096802, 84.13700044155121, 91.07390061020851, 102.17714801430702, 101.90166279673576, 52.106110006570816, 14.755636118352413, 1.1100537911988795, 0.39608759921975434, 0.2751314209308475, 0.21656136377714574, 0.1798892644001171, 0.21517396322451532, 0.29141586273908615, 0.335173720959574, 0.1322834743768908, 0.17447688529500738, 0.15734563814476132, 0.20530865353066474, 0.12742029939545318, 0.08908070551115088, 0.1028067416336853, 0.15260772284818813, 0.1612756514805369, 0.21452225366374478, 0.11165704563609324, 0.19327878108015284, 0.14854738838039339, 0.14047446922631934, 0.1366821539704688, 0.10657823964720592, 0.15039543999591842, 0.10513454719330184, 0.2018377327476628, 0.0881642199237831, 0.11536189136677422, 0.1859356157365255, 0.22622518037678674, 0.1978190179215744, 0.09411803286639042, 0.13682767428690568, 0.20999645901611075, 0.21607409929856658, 0.09173186481348239, 0.220915544196032, 0.1126240640587639, 0.1139158388832584, 0.07568304004962556, 0.09921595657942817, 0.12185094121377915, 0.10252292951918207, 0.1476828457089141, 0.10450867921463214, 0.1107327600766439, 0.10026379488408566, 0.11650350745185278, 0.10535644934861921, 0.22208126523764804, 0.1512205449398607, 0.12662842782447115, 0.2572622266598046, 0.19091873662546277], [0.10152235117857344, 0.025014055900101084, 0.061403343206620775, 0.04028732335427776, 0.055190828716149554, 0.01783841369615402, 0.07383031290373765, 0.05959610229183454, 0.03575074901164044, 0.05468195289722644, 0.01897463807836175, 0.029340079236135352, 0.014067642059671925, 0.02061750812572427, 0.07703103998210281, 0.03643756586825475, 0.03691521211294457, 0.016493280309077818, 0.05757613587775268, 0.023228806676343083, 0.05598474119324237, 0.04521954033407383, 0.013570601640822133, 0.04150472013861872, 0.03871540633554105, 0.04135493247304112, 0.044717002456309274, 0.018435683014104143, 0.033158100632135756, 0.07637661416083574, 0.047591956390533596, 0.04367454101156909, 0.033199768513441086, 0.04100368510989938, 0.033206881998921745, 0.023864576760388445, 0.021945880107523408, 0.048393305187346414, 0.024620439326099586, 0.05076199566246942, 0.006985682084632572, 0.06630265706917271, 0.021437818795675412, 0.028134625463280827, 0.05140848792507313, 0.02414939819573192, 0.029598836445074994, 0.058709536388050765, 0.10573981315246783, 0.023676911732763983, 0.018132814402633812, 0.048358179337810725, 0.03637910689576529, 0.08065745554631576, 0.04890438147413079, 0.06287631709710695, 0.056985464252647944, 0.04753949397127144, 0.07738439875538461, 0.09344359874376096, 0.2545584342442453, 0.17435020068660378, 0.31158461642917246, 0.3003057528985664, 4.4058317597955465, 21.240941919386387, 40.858808532357216, 57.8373196721077, 69.72559735178947, 61.54236026108265, 60.48149898648262, 56.8012672662735, 56.14350736141205, 48.342837542295456, 48.40895019471645, 57.8620183467865, 49.11376677453518, 60.83610735833645, 58.12435247004032, 59.09903436899185, 67.10111618041992, 71.72464728355408, 59.701359048485756, 57.219947800040245, 58.74732904136181, 61.400103494524956, 31.237213723361492, 39.313207268714905, 44.171558171510696, 38.61942149698734, 34.366473108530045, 24.376233480870724, 21.34989347308874, 48.80528412759304, 82.0810067653656, 77.88334161043167, 43.48848782479763, 81.6430726647377, 73.79562735557556, 32.06411965191364, 40.194197595119476, 54.208282604813576, 51.8862272053957, 45.71459077298641, 68.24507519602776, 76.5337224304676, 72.54452168941498, 69.8441281914711, 80.42456924915314, 66.24873071908951, 76.0443314909935, 79.18477937579155, 76.30093172192574, 81.35552689433098, 83.59347760677338, 76.96768194437027, 48.59924018383026, 17.026819847524166, 3.2377597130835056, 0.22411357727833092, 0.29787364590447396, 0.020090388461539987, 0.014572462041542167, 0.13766964082606137, 0.09249372393242083, 0.050608274614205584, 0.11210782613488846, 0.0870085995120462, 0.052884812612319365, 0.05953132393187843, 0.048492571149836294, 0.046844391035847366, 0.024133738879754674, 0.059474913286976516, 0.017229919394594617, 0.08124845000565983, 0.0627266704395879, 0.025857992841338273, 0.042959251659340225, 0.058614196386770345, 0.08470020111417398, 0.02463748645823216, 0.09548681293381378, 0.05491618583619129, 0.03221460086933803, 0.053737336202175356, 0.08775196431088261, 0.09763832131284289, 0.04027874041639734, 0.06517232905025594, 0.10678555860067718, 0.04500406146689784, 0.01923690564581193, 0.022870124848850537, 0.10924738118774258, 0.022740792628610507, 0.008109901300485944, 0.03172405980876647, 0.024091518098430242, 0.10534800370805897, 0.037105287265148945, 0.02677253956790082, 0.026906307975878008, 0.042424723505973816, 0.07345845981035382, 0.022911776031833142, 0.19408408552408218, 0.040010168304434046, 0.08982302388176322, 0.06945570115931332, 0.037266682120389305, 0.04508582758717239, 0.026042513018182945, 0.11881552010891028, 0.03208772330253851, 0.02769742626696825, 0.04734485461085569, 0.06926627538632601, 0.01595425659616012, 0.07650137660675682, 0.003217623461750918, 0.051863446715287864, 0.0159243832968059, 0.032599805199424736, 0.030049561282794457, 0.04402800368552562, 0.04038058534206357, 0.047571528775733896, 0.035005180034204386, 0.028195132763357833, 0.06444559578085318, 0.018476656987331808, 0.09478583218879066, 0.042930530544254, 0.049316325385007076, 0.017794049963413272, 0.06345812376821414, 0.06466807681135833, 0.04368676418380346, 0.07176961371442303, 0.04915159457596019, 0.04429523993167095, 0.03443628302193247, 0.03658520130557008, 0.030248321418184787, 0.1481264570611529, 0.08449801040114835, 0.02977053231006721, 0.041166200608131476, 0.013114041666995035, 0.019933227558794897, 0.08175502516678534, 0.05238336569163948, 0.05797045749204699, 0.02776799152343301, 0.013628684901050292, 0.07303096790565178, 0.04928003436361905, 0.03902721968188416, 0.12451041999156587, 0.03366512850334402, 0.0512547668768093, 0.021456897557072807, 0.09713936058687977, 0.0537418410385726, 0.016442545238533057, 0.01671874848398147, 0.051102099678246304, 0.07125238131266087, 0.01487340014136862, 0.010809566447278485, 0.08193066183594055, 0.10761096040369011, 0.08478905845549889, 0.12334482511505485, 0.10846848235814832, 0.31317043758463115, 0.1825431251199916, 0.23572422534925863, 1.571106445044279, 14.324326012283564, 39.70255337655544, 68.96753042936325, 81.1710923910141, 91.26954451203346, 85.09182840585709, 74.57989767193794, 68.33886936306953, 65.90750902891159, 59.87486533820629, 58.6282966285944, 47.235060185194016, 31.277119182050228, 38.810273855924606, 34.34788830578327, 53.50292265415192, 47.39593215286732, 33.668625354766846, 35.3801105171442, 36.74940504133701, 50.654990673065186, 40.82806438207626, 58.83312463760376, 49.41984795033932, 62.94836461544037, 54.23099398612976, 48.26491892337799, 44.65737350285053, 47.20648191869259, 68.17335784435272, 90.16881957650185, 68.26576128602028, 44.45307366549969, 62.89303578436375, 78.92183348536491, 42.54394210875034, 57.00792297720909, 58.41317877173424, 57.253811582922935, 48.00450749695301, 47.19233527779579, 33.22777681052685, 39.15639728307724, 34.385331496596336, 48.42211648821831, 43.23467284440994, 57.74425506591797, 70.08143305778503, 77.73220092058182, 82.89705857634544, 93.72177332639694, 90.34060835838318, 71.06133967638016, 31.975717395544052, 7.495712907984853, 0.3114453301532194, 0.38545336516108364, 0.03644217460532673, 0.022207490874279756, 0.11783700581872836, 0.04459903808310628, 0.06518420341308229, 0.11056653384002857, 0.15264352405210957, 0.05300985707435757, 0.0680906986235641, 0.07511489631724544, 0.030127310528769158, 0.03159403182507958, 0.053587518850690685, 0.027185225626453757, 0.05075009903521277, 0.06062059634132311, 0.06789561026380397, 0.020126924391661305, 0.044833794236183167, 0.09941789496224374, 0.043174340898985974, 0.1440855668624863, 0.0787753467739094, 0.05294197653711308, 0.023897795290395152, 0.051384575926931575, 0.01469375309170573, 0.03617737631429918, 0.046645228285342455, 0.11147379453177564, 0.04378598932817113, 0.033159603481180966, 0.05337236652849242, 0.05339008159353398, 0.009283776689699152, 0.01586969072377542, 0.021727859384554904, 0.0037686539644710138, 0.10033604296040721, 0.025456340663367882, 0.040280235843965784, 0.03863161415210925, 0.05396687505708542, 0.06273064092965797, 0.017394601964042522, 0.015638880940969102, 0.0774774863384664, 0.06943941101781093, 0.01830399633035995, 0.06912978700711392, 0.06969284702790901, 0.08009600598597899, 0.10667459268006496, 0.04323300025134813, 0.09067820064956322, 0.23365476139588282, 0.20394385879626498, 0.14490791101707146, 0.17360904748784378, 0.152942297863774, 0.12464551313314587, 0.20875183283351362, 0.13460114219924435, 0.16640080459183082, 0.10524438504944555, 0.17067778680939227, 0.16409777192166075, 0.11760152978240512, 0.1148616467253305, 0.19860578351654112, 0.09876420386717655, 0.2544724044855684, 0.184717855299823, 0.16063879971625283, 0.10895222905674018, 0.14059701265068725, 0.18998230953002349, 0.11628480395302176, 0.22619862633291632, 0.15732018247945234, 0.08752342735533603, 0.1160877117945347, 0.11903825346962549, 0.11440261354437098, 0.2031262347009033, 0.15472514438442886, 0.0760297937085852, 0.14619326626416296, 0.16040074842749164, 0.09449856166611426, 0.20266592502593994, 0.08267927361885086, 0.1514429072267376, 0.16468356392579153, 0.15970330772688612, 0.11333003945765086, 0.1321937784086913, 0.0756171447574161, 0.17159215727588162, 0.22411797079257667, 0.1284585046232678, 0.24102698924252763, 0.3017373557668179, 0.2057046486879699, 0.22096433298429474, 0.10182763362536207, 0.18188696267316118, 0.18167656380683184, 0.1333977942704223, 0.13523337780497968, 0.19194325665012002, 0.13447865814669058, 0.2679053071187809, 0.33184800879098475, 0.1655305622261949, 0.34598037076648325, 0.36925177671946585, 0.4483794729458168, 1.0001455200836062, 13.521467093378305, 42.286129742860794, 74.11925598978996, 94.46754410862923, 111.22029036283493, 104.04443621635437, 101.9860790669918, 99.43102777004242, 95.52822679281235, 90.1723761856556, 90.89649572968483, 98.19808512926102, 89.63836044073105, 104.00560230016708, 97.10407063364983, 95.92541188001633, 115.07537350058556, 110.92284232378006, 105.53647935390472, 97.38392561674118, 102.13704496622086, 84.44926768541336, 60.38692966103554, 55.88761009275913, 68.19484189152718, 56.800397112965584, 50.63846156001091, 36.68112650513649, 33.60969811677933, 69.2394894361496, 102.14776799082756, 108.18920060992241, 71.80461779236794, 138.72499287128448, 104.01460021734238, 47.37606301903725, 61.634360924363136, 85.21684169769287, 78.40558558702469, 71.87941297888756, 113.16710069775581, 118.46344649791718, 113.18233028054237, 96.99792712926865, 113.88481378555298, 83.50192531943321, 97.36981317400932, 97.6641757786274, 95.38165345788002, 101.58696368336678, 109.66062605381012, 111.43100425601006, 83.39963480830193, 36.742983385920525, 7.032407093793154, 0.4377195308916271, 0.6054468057118356, 0.13505331793567166, 0.11796268110629171, 0.3632841969374567, 0.20543222111882642, 0.15642089245375246, 0.30399200040847063, 0.35374071216210723, 0.19769117556279525, 0.14174135983921587, 0.1776640978641808, 0.2311896882019937, 0.11219905092730187, 0.2004687671433203, 0.14249814266804606, 0.10344808339141309, 0.19373022951185703, 0.17075789422960952, 0.13217077183071524, 0.1076314362580888, 0.16568117367569357, 0.15377215255284682, 0.3829650627449155, 0.17427788581699133, 0.1644810615107417, 0.14130975643638521, 0.12160074838902801, 0.17471086961450055, 0.1149869138316717, 0.2233781386166811, 0.3485114802606404, 0.19652020011562854, 0.1337710945517756, 0.13033138850005344, 0.21159896365134045, 0.14484870247542858, 0.2003880956908688, 0.13953876943560317, 0.0903988562640734, 0.18172367534134537, 0.12544735916890204, 0.09852399292867631, 0.18250974331749603, 0.15894561947789043, 0.21336674457415938, 0.11874428135342896, 0.331193286110647, 0.18355539970798418, 0.14364156959345564, 0.15950282395351678, 0.17466470802901313, 0.1679413695819676, 0.13875495758838952, 0.17941596714081243, 0.16837197850691155, 0.15341611462645233], [0.037204300897428766, 0.051848217844963074, 0.03673164559586439, 0.06771265601855703, 0.03591788437915966, 0.04843887305469252, 0.05552151858864818, 0.01377765991492197, 0.014064403512747958, 0.025130751200777013, 0.04649437192711048, 0.06611663775402121, 0.04092626055353321, 0.008553141578886425, 0.09216150152496994, 0.0707257904286962, 0.06426188454497606, 0.1319929977762513, 0.031104442568903323, 0.0383248325670138, 0.02368071895034518, 0.0792426845873706, 0.02555166767706396, 0.05105434247525409, 0.02569828080595471, 0.05834645919094328, 0.03156686179863755, 0.027939602041442413, 0.029083817498758435, 0.024936160079960246, 0.006598027739528334, 0.05444156013254542, 0.012710183455055812, 0.012283714786462951, 0.008128818644763669, 0.0893711821117904, 0.08789332860033028, 0.016078150729299523, 0.031169716312433593, 0.0219563944847323, 0.057756462920224294, 0.003426281064093928, 0.022831553578726016, 0.0453593090060167, 0.018607193342177197, 0.08011363199329935, 0.010424922438687645, 0.06362159663694911, 0.048470688925590366, 0.1422074731090106, 0.0420950058469316, 0.03972850841819309, 0.04630491275747772, 0.013049660356045933, 0.11134189262520522, 0.06056666075892281, 0.06639185579842888, 0.04806352444575168, 0.03719276050105691, 0.04456858405319508, 0.2040558637236245, 0.05609007421298884, 0.20253043854609132, 0.08542015857528895, 0.1645190000999719, 0.22840020741568878, 0.6420420482754707, 5.066308993846178, 10.636445302516222, 21.44432220607996, 37.56277799606323, 49.951181039214134, 44.55647751688957, 45.02173975110054, 41.09682396054268, 44.12993520498276, 53.75926069915295, 61.81153781712055, 58.03944602608681, 63.07566158473492, 64.46589678525925, 70.67284852266312, 76.34633168578148, 70.67620754241943, 77.78644680976868, 81.41963705420494, 84.08295974135399, 81.78240358829498, 88.35106551647186, 85.95138788223267, 86.50285989046097, 83.56000900268555, 72.72044464945793, 43.30768592655659, 50.05273438990116, 65.16913264989853, 81.9901080429554, 87.31610745191574, 49.797281697392464, 53.41605931520462, 75.08670687675476, 73.94990667700768, 82.08591610193253, 75.02461820840836, 84.57045078277588, 84.43398490548134, 91.33170157670975, 94.27478045225143, 98.04176151752472, 97.9736539721489, 85.32855570316315, 66.43577948212624, 64.11485642194748, 55.519060268998146, 34.84759949147701, 11.85497721657157, 1.9752317410893738, 0.14422327978536487, 0.15275168465450406, 0.057812383747659624, 0.07125513468054123, 0.07073772416333668, 0.08279507092083804, 0.009374995916004991, 0.04471349580853712, 0.026954042914439924, 0.034007488648057915, 0.04019933061499614, 0.11084291705628857, 0.011169856879860163, 0.04179428389761597, 0.045134983738535084, 0.024077144553302787, 0.06002809161145706, 0.07393599473289214, 0.03997326872195117, 0.029202601945144124, 0.06366357250954024, 0.04196465502900537, 0.0051194858860981185, 0.028232347758603282, 0.054430939999292605, 0.07318733099964447, 0.039287925028475, 0.02540091150876833, 0.04447301027539652, 0.03418028660234995, 0.01757909431034932, 0.10843956828466617, 0.18092261598212644, 0.06275707622990012, 0.017719727584335487, 0.051434782217256725, 0.03331523927045055, 0.04110924077394884, 0.07678197522182018, 0.027730390611395705, 0.012965941459697206, 0.02521884784073336, 0.027417996534495614, 0.023344978762906976, 0.015407060909637948, 0.056031463100225665, 0.023548169519926887, 0.04904036148218438, 0.03309030915261246, 0.04718750817119144, 0.07188978968770243, 0.0573255534254713, 0.03211714203644078, 0.1088127052935306, 0.06074060162063688, 0.10358202620409429, 0.04767968195665162, 0.02093340142891975, 0.0533421833824832, 0.05507956964720506, 0.0499766253051348, 0.05131228332174942, 0.023309652533498593, 0.028829539151047356, 0.04351266376033891, 0.02500285132555291, 0.032046363412518986, 0.0706008572888095, 0.021938091267657, 0.014158137691993034, 0.04837854015931953, 0.07776581813232042, 0.04670199145039078, 0.06173302375827916, 0.005814547075715382, 0.07317734911339357, 0.013830457228323212, 0.01887327183794696, 0.014249323521653423, 0.04844658396905288, 0.05257571923721116, 0.04896635451586917, 0.032279824517900124, 0.03153982906951569, 0.037247564396238886, 0.005740668129874393, 0.052198311168467626, 0.039280607452383265, 0.013247572587715695, 0.03668106081022415, 0.04801601215149276, 0.05287512016366236, 0.03681651389342733, 0.010611028028506553, 0.021006185706937686, 0.008191364995582262, 0.02103295126289595, 0.05139902925293427, 0.04116642696317285, 0.0634310427994933, 0.02665567913936684, 0.05835073025082238, 0.059443386853672564, 0.0057719385222299024, 0.037324094664654694, 0.05629279556160327, 0.03699127111758571, 0.08641240259748884, 0.07012312198639847, 0.04724178143078461, 0.06909273157361895, 0.03540607707691379, 0.04067434594617225, 0.05568363703787327, 0.07079322196659632, 0.12008370205876417, 0.012463569637475302, 0.027302447851980105, 0.08565011303289793, 0.2739870292134583, 0.11426507131545804, 0.39245125371962786, 0.03217688492441084, 0.2745103620691225, 0.28126963530667126, 1.9810267863795161, 13.194257151335478, 25.680906772613525, 43.90683777630329, 64.83779802918434, 71.32135972380638, 76.49961546063423, 74.60133612155914, 66.94261908531189, 67.35418260097504, 66.24748438596725, 64.96324449777603, 62.210261821746826, 66.32601097226143, 62.698505222797394, 51.649788692593575, 46.37607827782631, 41.91373072564602, 50.371107906103134, 39.81345422565937, 42.10475407540798, 42.797890082001686, 46.116236820816994, 40.848321095108986, 35.48599563539028, 25.101572759449482, 24.694211818277836, 39.48615878820419, 69.47516798973083, 64.10376861691475, 40.11289335787296, 77.80823484063148, 64.34205383062363, 31.826847083866596, 50.82589790225029, 55.87844878435135, 52.71422177553177, 39.93664361536503, 63.25763002038002, 61.73668183386326, 67.86513358354568, 78.93560394644737, 94.72109690308571, 98.28520685434341, 102.98813089728355, 90.09958729147911, 84.40209701657295, 74.36995133757591, 50.62064431607723, 21.843946762382984, 3.880678564310074, 0.08574032108299434, 0.16578648443100974, 0.054079703768366016, 0.10922480505541898, 0.10011960301198997, 0.20209246751619503, 0.026064051999128424, 0.032526095092180185, 0.06018241008860059, 0.010042134726973018, 0.1581050333334133, 0.24924213357735425, 0.006210282017491409, 0.07881052457378246, 0.007206435766420327, 0.021403062164608855, 0.054728596878703684, 0.10161380603676662, 0.023977038108569104, 0.06087335328629706, 0.008513837437931215, 0.031626419149688445, 0.010178423653997015, 0.04089433707122225, 0.05168070398212876, 0.03654997155535966, 0.0314372679713415, 0.013229984615463763, 0.11160864276462235, 0.02498366309737321, 0.07578508535516448, 0.05742175431805663, 0.14481917984085158, 0.08320247288793325, 0.03680590118165128, 0.032658720592735335, 0.027827853155031335, 0.019495495871524327, 0.0005881380604932929, 0.04925524663121905, 0.020410602919582743, 0.0550793841102859, 0.10219973904895596, 0.022858842348796315, 0.010756552983366419, 0.06657158170128241, 0.0781335226201918, 0.04967982560629025, 0.028377357848512474, 0.0010909175421147665, 0.030580796155845746, 0.034424045006744564, 0.04322618362493813, 0.09727291006129235, 0.17824619397288188, 0.05019623422413133, 0.0971754289639648, 0.04115944335353561, 0.05283489947032649, 0.12638369720662013, 0.13579985912656412, 0.1696210278896615, 0.11355295093380846, 0.0921134623058606, 0.17666283674770966, 0.1369363395497203, 0.08157420088537037, 0.1276237517595291, 0.11331472152960487, 0.1931344481999986, 0.21845667535671964, 0.14897845743689686, 0.12096846825443208, 0.11321541474899277, 0.18603743839776143, 0.21732077380875126, 0.19489243277348578, 0.08514281056704931, 0.0815894445986487, 0.19293356366688386, 0.1945322981919162, 0.14377451792825013, 0.14092894562054425, 0.12947992247063667, 0.19317905127536505, 0.22137364227091894, 0.1624201174126938, 0.10223237870377488, 0.054082835631561466, 0.10319703709683381, 0.18986003327881917, 0.13743150047957897, 0.1412442247965373, 0.09380681323818862, 0.1848745672032237, 0.24931946536526084, 0.11718778987415135, 0.13606672058813274, 0.1514961340581067, 0.20675901789218187, 0.10310370460501872, 0.16384386835852638, 0.15252007520757616, 0.12512976449215785, 0.19738456467166543, 0.11653481866233051, 0.18969046737765893, 0.213162416475825, 0.2811534149805084, 0.24073514709016308, 0.182275150436908, 0.15186979057034478, 0.24653960281284526, 0.19563227979233488, 0.18139393912861124, 0.1856807028525509, 0.23811512830434367, 0.13768264325335622, 0.11992733154329471, 0.3174755471991375, 0.16948376025538892, 0.4718429467175156, 0.3503500472288579, 0.6441167963203043, 0.4717524937586859, 1.1404493101872504, 9.126437678933144, 19.573403298854828, 39.46133092045784, 65.03284156322479, 79.47511419653893, 89.00206178426743, 100.43164327740669, 97.87283778190613, 96.76096424460411, 105.83696722984314, 103.16478341817856, 95.73457092046738, 97.69466534256935, 85.21280631422997, 88.29440295696259, 94.13528233766556, 90.13826921582222, 103.47424641251564, 108.52980673313141, 113.29439386725426, 99.84276607632637, 110.1903860270977, 110.56077495217323, 121.36490240693092, 108.98417875170708, 96.61898866295815, 61.18701092898846, 74.67819839715958, 84.26648989319801, 123.88329327106476, 127.04784706234932, 64.80996072292328, 81.86685785651207, 116.99178546667099, 107.61857002973557, 119.13230940699577, 100.44006362557411, 107.8253473341465, 99.56939354538918, 107.14532822370529, 111.30923599004745, 118.75983819365501, 122.07145169377327, 118.30536738038063, 102.3212818801403, 96.14127829670906, 81.74834221601486, 54.172891303896904, 20.687807500362396, 4.036090699955821, 0.21404033264843747, 0.17530023877043277, 0.1582542940741405, 0.22381959774065763, 0.25847572716884315, 0.23042260436341166, 0.1132030357257463, 0.15585770626785234, 0.10071547338156961, 0.21507770667085424, 0.3187689621699974, 0.3067079046741128, 0.10274866115651093, 0.10979150159982964, 0.1736620516749099, 0.09013926784973592, 0.19883662112988532, 0.1586024949210696, 0.13956729759229347, 0.1593777720700018, 0.10103277862071991, 0.11938439856749028, 0.1109072909457609, 0.17730308754835278, 0.1359214971307665, 0.22887092200107872, 0.13448477344354615, 0.16984935704385862, 0.21422370249638334, 0.24044426972977817, 0.2165407914435491, 0.1927854013047181, 0.26740257628262043, 0.2644091978436336, 0.14372225588886067, 0.13326634507393464, 0.0876498076831922, 0.3462395881069824, 0.18046674435026944, 0.14433086151257157, 0.10516308277146891, 0.11777740393881686, 0.23011005629086867, 0.1595778699265793, 0.17146434460300952, 0.25415987125597894, 0.18529805151047185, 0.08293152219266631, 0.14615811815019697, 0.08625695976661518, 0.1243629700911697, 0.1494517843821086, 0.22023530647857115, 0.16822353412862867, 0.20103429851587862, 0.13767485070275143, 0.20981761626899242, 0.11830038056359626, 0.11861329228850082], [0.024341671960428357, 0.057222521063522436, 0.004356947238193243, 0.020825431929551996, 0.09433429469936527, 0.05960280017461628, 0.050773458133335225, 0.03235323034459725, 0.04836402375076432, 0.06216904665052425, 0.04617816135578323, 0.028510727352113463, 0.03277284435171168, 0.02741211686952738, 0.016922937429626472, 0.08136485586874187, 0.11192231148015708, 0.011595689156820299, 0.021098607212479692, 0.07567489868961275, 0.03874834284943063, 0.0657896400662139, 0.05080993098090403, 0.06382432911777869, 0.03064191016164841, 0.043175224054721184, 0.030147743709676433, 0.04571536919684149, 0.07700279384152964, 0.03013092664332362, 0.04607374117767904, 0.08918187508243136, 0.06723626400344074, 0.03405453338928055, 0.035041671435465105, 0.054051357437856495, 0.018566471699159592, 0.07199789091828279, 0.02779395927063888, 0.042704617080744356, 0.07811384086380713, 0.06011849261994939, 0.0284545486283605, 0.02217340217612218, 0.021819896828674246, 0.03174682518874761, 0.032348829408874735, 0.02956098505819682, 0.057795826432993636, 0.009013496710394975, 0.03741370157513302, 0.0840587480342947, 0.0026162111043959158, 0.040288867021445185, 0.01574391710164491, 0.06968391899135895, 0.09223335626302287, 0.023492788604926318, 0.018176747689722106, 0.05924768622207921, 0.13990598410600796, 0.04034261335618794, 0.17261866625631228, 0.10823711781995371, 0.09773282639798708, 0.15807950345333666, 0.2221113964333199, 0.10146782558877021, 0.42488782724831253, 0.34447805606760085, 0.5663578282110393, 1.8527624127455056, 1.4933576295152307, 0.6777804368175566, 9.662762749940157, 15.656470879912376, 25.811129584908485, 35.36614626646042, 56.567940786480904, 69.16161641478539, 86.60757467150688, 77.19779759645462, 77.85606667399406, 85.1757887005806, 85.1299099624157, 93.01753431558609, 97.70215854048729, 96.76565319299698, 111.48028001189232, 104.17075663805008, 104.34187665581703, 101.81359112262726, 107.71101146936417, 105.69642037153244, 91.99720546603203, 91.28796592354774, 90.7905650138855, 84.9939988553524, 99.71491053700447, 97.12314561009407, 87.6636216044426, 88.8011285662651, 84.01615932583809, 90.68347156047821, 97.52106785774231, 87.63734981417656, 94.51143935322762, 82.48945444822311, 63.6594432592392, 36.17752432823181, 18.691829703748226, 6.984760500490665, 1.7305425647646189, 0.687418085290119, 0.0703367343521677, 0.34529186552390456, 0.2161654576775618, 0.027184394421055913, 0.038607438691542484, 0.13546240457799286, 0.1867477034102194, 0.035650748322950676, 0.08750135588343255, 0.09831448463955894, 0.032964915881166235, 0.023124232502595987, 0.005052520509707392, 0.045268711328390054, 0.0652098075079266, 0.02915724558988586, 0.036635251744883135, 0.1103965746005997, 0.03829220775514841, 0.027612912344920915, 0.02901452131482074, 0.02163574030419113, 0.048205586354015395, 0.06797569541959092, 0.11180275891092606, 0.019707015380845405, 0.04181094511295669, 0.04542832502920646, 0.028551513933052775, 0.026884440594585612, 0.01145335636465461, 0.026244544169458095, 0.006013279844410135, 0.0472801393334521, 0.0036401585157364025, 0.012656759954552399, 0.018084873518091626, 0.05804498025099747, 0.03664144125650637, 0.03554641720256768, 0.04792965955857653, 0.07072860316839069, 0.08114077922073193, 0.07252995143062435, 0.06370206028805114, 0.04560088549624197, 0.031791806759429164, 0.03803576975769829, 0.04447077641088981, 0.0668420574220363, 0.011100764786533546, 0.13528718351153657, 0.031204051774693653, 0.043643252065521665, 0.07038238385575823, 0.026657983507902827, 0.008174289105227217, 0.052961769615649246, 0.060488427261589095, 0.05426473973784596, 0.025605389892007224, 0.03651512030046433, 0.03767899710510392, 0.01003049042992643, 0.06884822360007092, 0.028961222124053165, 0.030004242034920026, 0.0036223038341631764, 0.06846261108876206, 0.07639553150511347, 0.08944190136389807, 0.04024133988423273, 0.03750714167836122, 0.03956093518354464, 0.05494249126059003, 0.0796767593419645, 0.05107279597723391, 0.029507283252314664, 0.06505302881123498, 0.04821703398192767, 0.02819719407852972, 0.06333628538413905, 0.1090257462055888, 0.031169727444648743, 0.08664134773425758, 0.06328640563879162, 0.05525908403797075, 0.035758849553531036, 0.07776940270559862, 0.02831818455888424, 0.038796088920207694, 0.024193474346247967, 0.02626298097311519, 0.06012713864038233, 0.044789933308493346, 0.009411087485204916, 0.037808739361935295, 0.052399318155949004, 0.062480537162628025, 0.06954573109396733, 0.03769561750232242, 0.05231516974163242, 0.07035537710180506, 0.04830196165130474, 0.07181451364886016, 0.059974323012284, 0.03764878056244925, 0.03973195198341273, 0.04796556837391108, 0.10734366849646904, 0.019026297122763935, 0.10601438552839682, 0.0236053557091509, 0.05883570520381909, 0.023747263621771708, 0.06957346515264362, 0.11530107978614978, 0.08294499959447421, 0.04614785204466898, 0.03861782133753877, 0.14614079642342404, 0.14798346004681662, 0.1401459501357749, 0.05287804793624673, 0.14410510018933564, 0.044014069862896577, 0.18198176461737603, 0.25326662231236696, 0.16975644015474245, 0.1837559131672606, 0.19808849174296483, 0.9045436594169587, 3.309801947325468, 8.352822940796614, 10.896160416305065, 12.93692545965314, 25.20772386342287, 39.980991035699844, 54.23688367009163, 68.00237461924553, 76.72580972313881, 86.68787196278572, 100.07367208600044, 99.61270362138748, 103.40076595544815, 95.52824199199677, 94.90762889385223, 101.01719945669174, 101.83524996042252, 100.95779344439507, 108.08334589004517, 96.34705245494843, 96.52214705944061, 86.5499697625637, 89.36706259846687, 79.90468114614487, 73.77890065312386, 73.17183762788773, 76.4378459751606, 81.30247414112091, 76.2601675093174, 74.56667438149452, 78.89291703701019, 88.33832859992981, 91.20858818292618, 92.97395065426826, 104.894610196352, 105.61800017952919, 111.89502775669098, 102.59916096925735, 89.88524839282036, 64.0369226038456, 36.707010716199875, 17.186335287988186, 6.050065280869603, 1.672053609509021, 0.030758653701923322, 0.3517557343002409, 0.23129363340558484, 0.014380238371813903, 0.05223616441071499, 0.10659179126378149, 0.17229768738616258, 0.03294219131930731, 0.05914861692872364, 0.04409602523082867, 0.018525803861848544, 0.014776235384488245, 0.05240350386884529, 0.016198486264329404, 0.049680415613693185, 0.03994137492554728, 0.048115994286490604, 0.1828673991258256, 0.052051777820452116, 0.02340685903618578, 0.09043937752721831, 0.08944886270910501, 0.07448073112755083, 0.012450032863853266, 0.05218824022449553, 0.06348159789922647, 0.07184018453699537, 0.06615283971768804, 0.06029129428497981, 0.0631159268959891, 0.04202584510494489, 0.007012522783043096, 0.048693696880945936, 0.03172092423483264, 0.05397517597884871, 0.05735627833928447, 0.024742060631979257, 0.049133137363241985, 0.05477021280967165, 0.08843733769026585, 0.04659236881707329, 0.006374836102622794, 0.07438007363816723, 0.03490645583951846, 0.04253591949236579, 0.020231936432537623, 0.06071650408557616, 0.06596028950298205, 0.06098244157328736, 0.032763526687631384, 0.03543359591276385, 0.14240797172533348, 0.062089443890727125, 0.012491815778048476, 0.04240611786372028, 0.005404185794759542, 0.0312511818628991, 0.06133571871032473, 0.07394524931441993, 0.02250889374408871, 0.04758576316817198, 0.10051061835838482, 0.14671591634396464, 0.1140796160325408, 0.15147458208957687, 0.11636737530352548, 0.140380127413664, 0.10722416787757538, 0.2523729874519631, 0.14198540768120438, 0.15557969774818048, 0.16119057167088613, 0.1617930323118344, 0.10003101284382865, 0.13588743255240843, 0.16255855764029548, 0.11706126111675985, 0.13664489815710112, 0.15827287745196372, 0.16201456339331344, 0.18898075155448169, 0.19095382536761463, 0.1363515865523368, 0.13762442918960005, 0.2941051684319973, 0.1665190584026277, 0.11104023185907863, 0.12954342062585056, 0.12108355309464969, 0.16651859827106819, 0.11670091131236404, 0.1460059778764844, 0.15916520613245666, 0.23042484564939514, 0.12416998200933449, 0.15218382293824106, 0.13685128942597657, 0.1579128170851618, 0.16999507031869143, 0.3252610028721392, 0.06825496559031308, 0.18112614256097004, 0.12522328994236887, 0.26862082653678954, 0.13312907743966207, 0.14889555954141542, 0.11733883919077925, 0.1402678998420015, 0.10793266657856293, 0.14947707677492872, 0.24080854549538344, 0.21561024215770885, 0.14312923536635935, 0.23267536394996569, 0.08995958647574298, 0.16649712051730603, 0.17165338445920497, 0.273546579410322, 0.16483620885992423, 0.12358505089650862, 0.24238468904513866, 0.19127796578686684, 0.2788871037773788, 0.23627054993994534, 0.36369626701343805, 0.20042944815941155, 0.20584488491294906, 0.5459633131977171, 0.5119204055517912, 0.3758190118242055, 1.0419644135981798, 0.5310283333528787, 1.4248175011016428, 3.7152295047417283, 6.423616111278534, 8.401345387101173, 23.96359082311392, 42.08233907818794, 56.015784814953804, 70.72280064225197, 92.57808029651642, 106.50447741150856, 124.08448487520218, 117.80587658286095, 121.7384147644043, 117.81797513365746, 118.97455707192421, 119.73604381084442, 125.01481175422668, 123.49805474281311, 132.2485899925232, 127.43805572390556, 122.27389723062515, 119.91838082671165, 134.3150407075882, 128.73652964830399, 113.23605179786682, 108.57364118099213, 104.73992809653282, 103.78702282905579, 125.92580527067184, 125.93253090977669, 105.0300121307373, 112.42204427719116, 110.35174816846848, 115.3250353038311, 122.31197878718376, 120.63475638628006, 120.79448461532593, 108.81725370883942, 85.8316259086132, 56.25776723027229, 33.21519948542118, 14.697080310434103, 4.477208079770207, 1.0532619198784232, 0.13612134265713394, 0.28071893204469234, 0.265368438558653, 0.09438315770239569, 0.08780634147115052, 0.22257703472860157, 0.33902932656928897, 0.07689523437875323, 0.1910222216974944, 0.2655647514620796, 0.09466550778597593, 0.09213633529725485, 0.16408042050898075, 0.1896586737711914, 0.26863970677368343, 0.14301488525234163, 0.10307539167115465, 0.34261036722455174, 0.10987046611262485, 0.21931415278231725, 0.3469629446044564, 0.13304191961651668, 0.30114547815173864, 0.15954092581523582, 0.16866781341377646, 0.16320777358487248, 0.1820264122216031, 0.11071694490965456, 0.1315978486672975, 0.10243094031466171, 0.11896559721208178, 0.11363148500095122, 0.09260321297915652, 0.12274040520424023, 0.10712275339756161, 0.16748494876082987, 0.14405493100639433, 0.12006671429844573, 0.1291043363744393, 0.17990576976444572, 0.20453486067708582, 0.1503385469550267, 0.2271973789902404, 0.1645418582484126, 0.1703261720831506, 0.16963331785518676, 0.1847854204243049, 0.2121428688406013, 0.22866214101668447, 0.1523631703457795, 0.12643814116017893, 0.27068993425928056, 0.13870079565094784, 0.14364266797201708, 0.16149163129739463, 0.09060770404175855, 0.16669794567860663, 0.13155424006981775, 0.21463621786097065, 0.21869944670470431, 0.14455208089202642, 0.1846564351581037], [0.04547287244349718, 0.07139597946661524, 0.026058806870423723, 0.09139010580838658, 0.1240355493791867, 0.05694485022104345, 0.06321005348581821, 0.1391910287202336, 0.09172351565212011, 0.05070485029136762, 0.0389372676727362, 0.028582177619682625, 0.045751326251775026, 0.036870850235573016, 0.09767315030330792, 0.12557923881104216, 0.10866350392461754, 0.10759713419247419, 0.05394155297835823, 0.02526453259633854, 0.04666742592235096, 0.06145841056422796, 0.05290853907354176, 0.0539947427023435, 0.03866181585181039, 0.017277136685152072, 0.021218913061602507, 0.09397566667757928, 0.01944585546880262, 0.07406345117487945, 0.018467472909833305, 0.11636962401098572, 0.011278055517323082, 0.0682852377940435, 0.12179554731119424, 0.033878466274472885, 0.0774046074366197, 0.13610520836664364, 0.0602906337735476, 0.021269655553624034, 0.03136563958832994, 0.06446898827562109, 0.048880499161896296, 0.11090468600741588, 0.07766913113300689, 0.07905252408818342, 0.09615664574084803, 0.10317613079678267, 0.08558593210182153, 0.06732944064424373, 0.049353302892996, 0.06478625640738755, 0.04139156859309878, 0.02173579479858745, 0.0130430060744402, 0.06532599814818241, 0.07306584884645417, 0.011517313723743428, 0.04535675972874742, 0.03522092607454397, 0.07864193088607863, 0.0861694902414456, 0.06782836426282302, 0.14835781417787075, 0.18190118222264573, 0.06731609682901762, 0.05499013714143075, 0.025138753408100456, 0.029395508390734904, 0.05088126621558331, 0.022630713574471883, 0.17078910896088928, 0.20048230391694233, 0.5941232352051884, 0.7735285896342248, 1.8166579375974834, 2.679462321102619, 2.512380061671138, 5.26372455060482, 8.345373440533876, 12.07577956840396, 6.332600070163608, 11.892688293009996, 25.89538436383009, 23.440826274454594, 28.840007856488228, 33.38642209768295, 50.85581749677658, 55.50664633512497, 67.16749861836433, 74.82903510332108, 75.1663126051426, 58.15805286169052, 62.93044097721577, 74.1659326851368, 67.30171501636505, 66.13611996173859, 59.80347476899624, 52.87358142435551, 58.776507675647736, 55.1038109511137, 39.00572016835213, 31.665496341884136, 27.020559087395668, 31.167420968413353, 19.316573180258274, 12.107112687081099, 7.142672426998615, 1.7442059190943837, 0.2993504307232797, 0.2646777662448585, 0.1680001031490974, 0.2159150570514612, 0.22282534249825403, 0.3638329409295693, 0.17229915683856234, 0.2525369427166879, 0.10515711590414867, 0.32735810440499336, 0.10761973258922808, 0.1584042821195908, 0.12509614520240575, 0.10498809177079238, 0.10322904592612758, 0.01103822121876874, 0.08677711623022333, 0.07369564278633334, 0.10088193710544147, 0.08625175731140189, 0.023047583490551915, 0.010493798381503439, 0.07566671280073933, 0.019537378975655884, 0.15216627856716514, 0.19400745135499164, 0.043305923682055436, 0.040988497057696804, 0.08069123068707995, 0.0507216302503366, 0.011041136931453366, 0.13770182034932077, 0.04864875983912498, 0.040435756600345485, 0.0427847467653919, 0.1053218355809804, 0.07598602926009335, 0.06090751434385311, 0.09395479748491198, 0.03536035706929397, 0.002697947074921103, 0.10797667593578808, 0.06957337609492242, 0.012119488637836184, 0.061583651695400476, 0.028658546470978763, 0.047673032313468866, 0.03461387525021564, 0.006870484066894278, 0.021256330292089842, 0.040203475509770215, 0.058619176197680645, 0.11326729087159038, 0.030022569371794816, 0.037071215265314095, 0.002507795852579875, 0.06314479644061066, 0.06424747203709558, 0.05781561580079142, 0.10801733820699155, 0.08039780033868738, 0.038103780170786195, 0.08982717248727567, 0.01843897258368088, 0.07005243242019787, 0.07728802345809527, 0.06328018644126132, 0.05345881188986823, 0.08631907752715051, 0.022329731873469427, 0.07049239240586758, 0.023277595464605838, 0.04153328911343124, 0.0953558980836533, 0.030058834418014158, 0.07310054425033741, 0.0372625891759526, 0.024622483942948747, 0.05123012757394463, 0.0508364070992684, 0.043980984919471666, 0.02495652461220743, 0.025708077155286446, 0.045854251002310775, 0.08727749445824884, 0.052282897449913435, 0.02783255466056289, 0.05639378330670297, 0.03871287561196368, 0.009393437358085066, 0.04005924281955231, 0.03212239273125306, 0.020718078412755858, 0.010106376885232748, 0.03597594259190373, 0.013970214768050937, 0.05954566593572963, 0.04464983438083436, 0.049317230805172585, 0.007580833034808165, 0.006747724028173252, 0.05621055817755405, 0.10786466358695179, 0.014499358640023274, 0.08684408021508716, 0.05735406302846968, 0.05259918594674673, 0.039934428423293866, 0.024537316930945963, 0.03951407968997955, 0.035795248186332174, 0.06997798016527668, 0.07379109039902687, 0.05757195387559477, 0.07525375214754604, 0.04002754940302111, 0.026826113353308756, 0.07729888107860461, 0.09973841370083392, 0.04635775367205497, 0.05311147193424404, 0.09963422358850949, 0.07488408838980831, 0.025501819472992793, 0.0977693623281084, 0.07450558565324172, 0.020757733218488283, 0.04520483467786107, 0.0355420088453684, 0.052840491553070024, 0.13463587471051142, 0.31715867982711643, 0.06865282353828661, 0.09552167903166264, 0.006434842453018064, 0.05526876535441261, 0.14644169277744368, 0.1004752772860229, 0.12362454799585976, 0.5529729276895523, 1.2609676807187498, 2.9453950887545943, 5.8042545709759, 8.044820968061686, 10.616604667156935, 18.719387724995613, 26.002177633345127, 33.802321180701256, 25.496204383671284, 34.88311618566513, 53.36620219051838, 52.66183398663998, 65.23119851946831, 68.43127280473709, 85.60435250401497, 92.42135390639305, 100.1544177532196, 104.91026535630226, 106.24681323766708, 93.1790940463543, 100.01595318317413, 106.23346835374832, 100.71812510490417, 101.05363190174103, 91.9455586373806, 86.93595305085182, 89.13404390215874, 90.24613782763481, 75.63133165240288, 57.94172666966915, 61.171427965164185, 60.993346720933914, 40.718071684241295, 29.81195580214262, 20.334464460611343, 6.47528906352818, 2.242518304847181, 0.7577648386359215, 0.058056427878909744, 0.30161329836118966, 0.2528563333908096, 0.14742695319000632, 0.1797952936613001, 0.2734121319372207, 0.03655963060737122, 0.1397113484563306, 0.2205878117820248, 0.23292092577321455, 0.1104488292185124, 0.050813749330700375, 0.013372433368203929, 0.05608453408058267, 0.013561763589677867, 0.06333379918942228, 0.07791237003402784, 0.12705482135061175, 0.027457636497274507, 0.09244851229595952, 0.06164083788462449, 0.02957318225526251, 0.06583841401152313, 0.06737757634255104, 0.05150998033059295, 0.05808962043374777, 0.024645846751809586, 0.014518377101921942, 0.01712861438136315, 0.07709120589424856, 0.0167879927175818, 0.07354126864811406, 0.015557029473711737, 0.011115418492408935, 0.07636871770955622, 0.05397933200583793, 0.02946282118500676, 0.07861235630116425, 0.06687502362183295, 0.01594969795405632, 0.04842890230065677, 0.026925720703729894, 0.008553491315979045, 0.0518825607286999, 0.02934658230515197, 0.032901421436690725, 0.03832807204162236, 0.04508283302129712, 0.0371739507681923, 0.052720489984494634, 0.07365786004811525, 0.017317546626145486, 0.012653866506298073, 0.06888207295560278, 0.06119620236859191, 0.07728401586064138, 0.007563421322629438, 0.07948430560645647, 0.024626840349810664, 0.0563190379034495, 0.02331146151846042, 0.03964931383961812, 0.0453065905458061, 0.04634468445146922, 0.03892539330990985, 0.15910175250610337, 0.23674665251746774, 0.10729815257946029, 0.23767386213876307, 0.16378562460886315, 0.1482881116680801, 0.2882039069663733, 0.14952522731618956, 0.19893997261533514, 0.13822588050970808, 0.23341509222518653, 0.16842674900544807, 0.1341886565205641, 0.24067041696980596, 0.20083353272639215, 0.19859849562635645, 0.19420107768382877, 0.11859247504617088, 0.16050430771429092, 0.15375818533357233, 0.23294746497413144, 0.12950708507560194, 0.18540649412898347, 0.2331771596800536, 0.11843569634947926, 0.14492680609691888, 0.12461036501917988, 0.21160729054827243, 0.07063113691401668, 0.2754902048036456, 0.26242255757097155, 0.19283436820842326, 0.1382179543725215, 0.17000994295813143, 0.0965419910789933, 0.27670685201883316, 0.2673029206926003, 0.22946754936128855, 0.2400800384930335, 0.1039300934644416, 0.24561539146816358, 0.29673317272681743, 0.2011370859690942, 0.07879577809944749, 0.32984795048832893, 0.2273853204678744, 0.17597973434021696, 0.24658763461047783, 0.2881011937279254, 0.24105366203002632, 0.29812944936566055, 0.2519309049239382, 0.12901560519821942, 0.1575526231317781, 0.1471822671010159, 0.3061671165050939, 0.2754315751371905, 0.2123277823557146, 0.16962334339041263, 0.25225216581020504, 0.3104275488294661, 0.19025188725208864, 0.11631013345322572, 0.3242867114022374, 0.427373576676473, 0.5757057422306389, 0.3393337258603424, 0.10294666615664028, 0.18024418910499662, 0.16978669009404257, 0.15574679971905425, 0.41900161653757095, 0.49500828492455184, 1.1986143328249454, 1.2720547732897103, 2.8128714999184012, 4.189692232757807, 6.019935272634029, 10.807444676756859, 16.063681729137897, 20.718384459614754, 16.714066229760647, 26.57465111464262, 43.54381665587425, 43.60606491565704, 58.478090688586235, 60.35287968814373, 78.00125688314438, 81.3879619538784, 92.79119566082954, 104.54046919941902, 107.08902284502983, 93.92585277557373, 100.26686131954193, 107.59080871939659, 103.79652231931686, 102.50210657715797, 96.77986443042755, 80.25454357266426, 80.19053220748901, 83.18802416324615, 69.38296213746071, 56.68191947042942, 53.8082704693079, 53.11652898788452, 31.569169610738754, 20.396942608058453, 12.121617458760738, 3.133947621099651, 1.3577778171747923, 0.5949152552057058, 0.26962450705468655, 0.3958187933312729, 0.3450078604510054, 0.49041756719816476, 0.29209442320279777, 0.38228409772273153, 0.19467988167889416, 0.3827112779254094, 0.273383870953694, 0.3821280685951933, 0.27022244059480727, 0.2662214630981907, 0.2956511214142665, 0.21319996914826334, 0.19200317765353248, 0.19918609847081825, 0.3016583912540227, 0.5067012668587267, 0.09192951358272694, 0.14653082471340895, 0.3897116897860542, 0.14482254919130355, 0.1541822188301012, 0.3269181592622772, 0.1149075262947008, 0.17132424196461216, 0.20362510636914521, 0.07381442352198064, 0.1288281980669126, 0.27974621392786503, 0.13661493023391813, 0.12966519221663475, 0.1332313008606434, 0.2212290422176011, 0.20687569834990427, 0.10940779640804976, 0.17889110546093434, 0.11947769395192154, 0.16477213182952255, 0.2517300203908235, 0.1400962856132537, 0.10510800057090819, 0.13505973009159788, 0.1618834852706641, 0.12281243805773556, 0.10284733711159788, 0.09950191350071691, 0.13070874090772122, 0.12285458462429233, 0.07128905825084075, 0.22789680864661932, 0.10763547354144976, 0.10457442607730627, 0.12217906696605496, 0.24847933935234323, 0.21367950044805184, 0.16583530290517956, 0.21442534402012825, 0.17529364849906415, 0.22539240162586793, 0.18387887219432741, 0.1674127229489386, 0.2026241272687912, 0.16428414004622027, 0.1233849827258382], [0.023669692491239402, 0.047988578662625514, 0.029995978220540565, 0.01621489329409087, 0.03413487829675432, 0.05064217220933642, 0.03023548411874799, 0.03721791559655685, 0.02572823388618417, 0.058072391475434415, 0.047034106246428564, 0.04199480106763076, 0.0669586710864678, 0.03806593806075398, 0.06065108747861814, 0.05288570318953134, 0.024658138572704047, 0.0876818313554395, 0.06718386095599271, 0.011026146476069698, 0.023725707942503504, 0.025385947956237942, 0.03447668183071073, 0.021671133326890413, 0.07030854016193189, 0.0662051240215078, 0.042875259096035734, 0.025043305795406923, 0.08459381424472667, 0.07541971863247454, 0.022608890722040087, 0.025618576000852045, 0.05779133643954992, 0.04827385280805174, 0.04002627290901728, 0.02864255689928541, 0.05955314678431023, 0.032033327588578686, 0.020138585387030616, 0.07277024400536902, 0.04778504837304354, 0.011400623989175074, 0.010126836968993302, 0.01231201287737349, 0.03131244986434467, 0.10134136362466961, 0.051841323293047026, 0.01561194469104521, 0.025149674111162312, 0.02925548924395116, 0.068530525022652, 0.05357325106160715, 0.03852328285574913, 0.06478822309873067, 0.022866989274916705, 0.03341675394040067, 0.056443444118485786, 0.044498080023913644, 0.09765508642885834, 0.024442848953185603, 0.009648775121604558, 0.1285373800783418, 0.07077618967741728, 0.038898969141882844, 0.05114559695357457, 0.09588654109393246, 0.02332922667847015, 0.025680463695607614, 0.08205658945371397, 0.228206506872084, 0.09425434313016012, 0.0900094884855207, 0.16849901934619993, 0.0448733803932555, 0.0814072547655087, 0.14247515093302354, 0.08421166756306775, 0.011406992543925298, 0.06910103620612063, 0.11281439525191672, 0.09082629621843807, 0.16452294832561165, 0.0360445355909178, 0.11781883062212728, 0.21956357377348468, 0.07980268695973791, 0.07590692373923957, 0.3672280290629715, 0.12222419696627185, 0.23641911306185648, 0.6101675180252641, 0.5418006365653127, 1.2494615418836474, 3.2333362754434347, 3.5402515064924955, 1.6962036886252463, 1.3104950543493032, 1.0926276887767017, 0.7327311881817877, 0.25444749800954014, 0.287229823297821, 0.27150056732352823, 0.46252424363046885, 0.42019935382995754, 0.08947749476647004, 0.042033203499158844, 0.2969595277681947, 0.11831469659227878, 0.047571551040164195, 0.05990722173009999, 0.07965915559907444, 0.09986814853618853, 0.12785019585862756, 0.043026968924095854, 0.052091323159402236, 0.01719655057968339, 0.06117365963291377, 0.05161505730939098, 0.05032386878156103, 0.0276940290859784, 0.014065308005228871, 0.035248693529865704, 0.09986276054405607, 0.03340325056342408, 0.11867789624375291, 0.1057360356207937, 0.050904120653285645, 0.05937873836955987, 0.10316607469576411, 0.06689519519568421, 0.033794395785662346, 0.059774095279863104, 0.017497350454505067, 0.07437416614266112, 0.018002016440732405, 0.15074622351676226, 0.0381433069560444, 0.029672301643586252, 0.08048710296861827, 0.011898027132701827, 0.04150842345552519, 0.037516923184739426, 0.03152781369863078, 0.021195570661802776, 0.04726646526250988, 0.04290061457140837, 0.009677910911705112, 0.030650047810922842, 0.13192181097110733, 0.014628504395659547, 0.0579594551527407, 0.028562579354911577, 0.01739920327963773, 0.018998880332219414, 0.027820689574582502, 0.0462822104600491, 0.0585236432380043, 0.016338984096364584, 0.027828745587612502, 0.007698184672335628, 0.05256341813947074, 0.05057190195657313, 0.0931644398951903, 0.03192424672306515, 0.06271411330089904, 0.040837844790075906, 0.006963831865505199, 0.044370308169163764, 0.02132777684892062, 0.03399090164748486, 0.011883387342095375, 0.028491355442383792, 0.11641660938039422, 0.017059615056496114, 0.017491622929810546, 0.08417210367042571, 0.04067552225023974, 0.09326183935627341, 0.08073461664025672, 0.013497077070496744, 0.05147401585418265, 0.024322355711774435, 0.0560201230837265, 0.055277403953368776, 0.019650241083581932, 0.09551425755489618, 0.029476382078428287, 0.033373419937561266, 0.05697304441127926, 0.04372404597233981, 0.018076908418152016, 0.05102380680909846, 0.04978612712875474, 0.05432931771792937, 0.02105669627781026, 0.047007930697873235, 0.030004306972841732, 0.007705725356572657, 0.05778369973995723, 0.029292822982824873, 0.03153813326207455, 0.04206337180221453, 0.022671973274555057, 0.07928086808533408, 0.05840492187417112, 0.08423384293564595, 0.05639907481963746, 0.016903101677598897, 0.034578968334244564, 0.0471938906412106, 0.03861674893414602, 0.02456945749145234, 0.02935832308139652, 0.018294129476998933, 0.043802134750876576, 0.02357321143790614, 0.07542675419244915, 0.020905465135001577, 0.13805631460854784, 0.06300424109213054, 0.03545327766914852, 0.21320647036191076, 0.03779390382987913, 0.025190063643094618, 0.09300861856900156, 0.039843712002038956, 0.047297190176323056, 0.03228861896786839, 0.07544521140516736, 0.02300566698977491, 0.03833934155409224, 0.04473238346690778, 0.015130252813833067, 0.03437494451645762, 0.018123277804988902, 0.038218182235141285, 0.16547758772503585, 0.0710197699663695, 0.06981910861213692, 0.020602154945663642, 0.03916602727258578, 0.08054423349676654, 0.21335283672669902, 0.16368236218113452, 0.2378068698453717, 0.2876926265889779, 0.130957419751212, 0.08031313613173552, 0.15143057273235172, 0.039080379719962366, 0.013844890145264799, 0.1613016563351266, 0.18581932119559497, 0.07841285958420485, 0.16937147331191227, 0.19528302509570494, 0.5017918115481734, 0.5931685958057642, 0.6414116977248341, 0.6475754419807345, 0.8337989368010312, 1.3371228380128741, 1.5163645637221634, 2.1677169436588883, 1.0277898679487407, 1.2612558715045452, 2.8233112022280693, 3.493348485790193, 5.1450317446142435, 9.011197462677956, 11.78435230627656, 6.766784247010946, 4.864631490781903, 4.0368786826729774, 3.9814534317702055, 2.673481204546988, 2.2243438800796866, 1.5046018199063838, 2.8766349283978343, 2.8922936506569386, 1.0692056268453598, 0.051370586443226784, 0.18740634463028982, 0.09868536551948637, 0.1643434228026308, 0.05655813933117315, 0.06977839439059608, 0.05250551948847715, 0.1448617345886305, 0.0968569733959157, 0.05114724081067834, 0.06101091406890191, 0.036489037520368584, 0.027266025099379476, 0.03530136003973894, 0.02219189835159341, 0.029783069039694965, 0.0364022990106605, 0.20218836783897132, 0.040230719750979915, 0.06659454375039786, 0.15456910041393712, 0.07298298805835657, 0.07829689158825204, 0.046379038467421196, 0.03978703047323506, 0.036732736552949063, 0.022714947335771285, 0.010901325586019084, 0.031851445746724494, 0.05073182735941373, 0.07494435820262879, 0.042962992083630525, 0.018788806155498605, 0.06645414425292984, 0.04274773586075753, 0.03016945152921835, 0.055431247455999255, 0.053961078883730806, 0.06884892864036374, 0.061638585466425866, 0.05386379445553757, 0.03791380891925655, 0.022121054789749905, 0.07387763223960064, 0.027840198781632353, 0.08675002041854896, 0.05213910262682475, 0.03984045397373848, 0.012974404726264765, 0.022631806386925746, 0.05432667567220051, 0.07344579877099022, 0.019507347969920374, 0.04500649942201562, 0.04156986586167477, 0.019866341499437112, 0.029792258683301043, 0.07717346554272808, 0.05509774113306776, 0.012893654420622624, 0.025801969968597405, 0.03594065346987918, 0.0221358624912682, 0.004036256877952837, 0.05872849826118909, 0.03599185052735265, 0.06487206352176145, 0.08688802277902141, 0.04973976516339462, 0.03739531857718248, 0.0633059983374551, 0.11619240656727925, 0.19186427729437128, 0.1401484289090149, 0.15969615342328325, 0.12687940732575953, 0.12686098722042516, 0.11275407348875888, 0.14864223485346884, 0.10346964278141968, 0.12645776354474947, 0.16971321747405455, 0.0981101268553175, 0.20313522953074425, 0.1018400645989459, 0.17856819700682536, 0.15330443624407053, 0.10948311697575264, 0.16948828735621646, 0.19334300654008985, 0.0926771828380879, 0.08056479840888642, 0.10670834555639885, 0.14381733984919265, 0.18146096990676597, 0.14069545111851767, 0.20034088025568053, 0.1655335901887156, 0.17233461665455252, 0.3193494403967634, 0.19219374633394182, 0.11972723368671723, 0.17949885019334033, 0.10182260928559117, 0.15255532722221687, 0.14938225998776034, 0.12744939158437774, 0.06632230913965032, 0.1473014708608389, 0.14197485434124246, 0.1831093244254589, 0.24668962054420263, 0.06931855226866901, 0.26059669617097825, 0.25736879906617105, 0.1082064003276173, 0.4206249606795609, 0.13627107837237418, 0.1259076688438654, 0.1511080501950346, 0.1648370549082756, 0.1886106128222309, 0.10580810558167286, 0.10509418178116903, 0.2236604515928775, 0.10002748022088781, 0.14863558521028608, 0.11329233093420044, 0.1330830345978029, 0.14851883053779602, 0.09058247102075256, 0.22701077337842435, 0.2733247366268188, 0.26511824573390186, 0.15292622294509783, 0.1485827294527553, 0.17775104788597673, 0.3431041329167783, 0.18259492702782154, 0.29305725591257215, 0.46476609364617616, 0.2447577507700771, 0.2393279311945662, 0.3187634702771902, 0.1208859562757425, 0.13653709378559142, 0.16117618884891272, 0.18050330254482105, 0.19247470860136673, 0.08866165924700908, 0.13213336758781224, 0.4354942456120625, 0.39890885876957327, 0.31512667948845774, 0.23943487467477098, 0.21186318306718022, 0.39884025463834405, 0.3956551052397117, 0.714518646709621, 0.2630910248262808, 0.2737610007170588, 0.7318183465395123, 1.0012923460453749, 1.9446746120229363, 4.91635431535542, 5.349438926205039, 2.855826294980943, 1.6415749699808657, 1.4382896781899035, 1.6110364836640656, 0.7649536372628063, 0.584509513573721, 0.41681055910885334, 0.7680764759425074, 1.1520455754362047, 0.4063759034033865, 0.08931658972869627, 0.2847158128861338, 0.19390484201721847, 0.22019416181137785, 0.16765052190748975, 0.16051955142756924, 0.11799717613030225, 0.20379853143822402, 0.15268253133399412, 0.0921393335738685, 0.1483508083038032, 0.2455887632095255, 0.17393008572980762, 0.11190366130904295, 0.09554314936394803, 0.08573738959967159, 0.1799452371778898, 0.3410192619776353, 0.1143978712207172, 0.2212212051381357, 0.32745698816142976, 0.17891106923343614, 0.20810990477912128, 0.2385729443631135, 0.27240393916144967, 0.1706367905717343, 0.15593116404488683, 0.14702864253195003, 0.20836505515035242, 0.1044987492787186, 0.18108116841176525, 0.14992465119576082, 0.10025436960859224, 0.13175984466215596, 0.11123072632472031, 0.10341529530705884, 0.21403494465630502, 0.1135129491740372, 0.12175092197139747, 0.16223775688558817, 0.1459389619412832, 0.12400116567732766, 0.1137843525793869, 0.19196403678506613, 0.0601040392939467, 0.23942187224747613, 0.1415963441831991, 0.14678104722406715, 0.09457222724449821, 0.16359207249479368, 0.2265846321824938, 0.1897275005467236, 0.11906941625056788, 0.23157806892413646, 0.11137942303321324, 0.10942200111458078, 0.13767455384368077, 0.196207859844435, 0.1575273901107721, 0.12890673213405535, 0.26428374520037323, 0.12669271265622228, 0.14051583653781563, 0.13060118886642158, 0.13925562525400892, 0.14207823551259935, 0.1938166155014187, 0.11128258760436438, 0.11497552186483517, 0.07498913197196089, 0.2059650089358911], [0.006155877490527928, 0.038805707154097036, 0.04082079765794333, 0.03497748308291193, 0.04540736677881796, 0.028924812359036878, 0.035955210696556605, 0.07885309416451491, 0.05065995777840726, 0.02373869181610644, 0.061430413043126464, 0.05307037921738811, 0.0407390055625001, 0.04839578024984803, 0.036706998871522956, 0.012526291320682503, 0.06832511338870972, 0.00476755250019778, 0.02162215158023173, 0.14403241424588487, 0.043458687359816395, 0.043247305147815496, 0.08277720000478439, 0.03296991795650683, 0.04997340067347977, 0.030021639831829816, 0.05723720074456651, 0.012383144021441694, 0.001307332906890224, 0.015007053516455926, 0.03326266923977528, 0.06461409298935905, 0.04401802922075149, 0.04819809808395803, 0.04728993939352222, 0.060134274390293285, 0.002404303822913789, 0.03273991897003725, 0.048030213147285394, 0.03909269566065632, 0.024922181728470605, 0.029015257896389812, 0.024473993180436082, 0.012155417862231843, 0.028919882643094752, 0.03491210729407612, 0.028489260730566457, 0.0830051580851432, 0.07797519283485599, 0.040381947183050215, 0.010564524127403274, 0.034229312877869233, 0.05620353374979459, 0.045587897911900654, 0.019959607197961304, 0.057545459203538485, 0.031915904983179644, 0.0781100855965633, 0.05314099085808266, 0.04044912268000189, 0.031725536682642996, 0.021655232812918257, 0.029499093652702868, 0.03432676428928971, 0.02936926975962706, 0.012571006645885063, 0.06812076302594505, 0.06325320195173845, 0.06920619853190146, 0.11854037627927028, 0.07914837246062234, 0.0363445339462487, 0.0828663245192729, 0.07649738385225646, 0.04033823097415734, 0.0715722246968653, 0.05293058457027655, 0.06330668111331761, 0.05794136901386082, 0.09875178031506948, 0.051660153912962414, 0.0971295048657339, 0.020485698987613432, 0.052887784913764335, 0.042339973952039145, 0.0694343718350865, 0.03558638556569349, 0.04069661779794842, 0.02335527791728964, 0.0753991685633082, 0.03991577454144135, 0.05879106873180717, 0.0660565980069805, 0.04194767840090208, 0.12919836648507044, 0.09464907663641497, 0.05210563918808475, 0.014245944894355489, 0.08069671515841037, 0.03124515562376473, 0.027915955361095257, 0.03461943022557534, 0.09182810652418993, 0.11201989647815935, 0.13873781397705898, 0.05968543089693412, 0.11384020661353134, 0.05115668463986367, 0.0217518066347111, 0.01807429791369941, 0.04045016539748758, 0.03502266503346618, 0.05707050695491489, 0.013144111635483569, 0.07682639276026748, 0.014902973798598396, 0.03331424108182546, 0.07643035307410173, 0.06653889751760289, 0.05407253833254799, 0.005614809624603367, 0.03852580986858811, 0.03181724387104623, 0.09825210712733679, 0.04451284505194053, 0.03126828094536904, 0.052522488695103675, 0.06786478144931607, 0.02681290869077202, 0.03001159300765721, 0.0249142593020224, 0.044760336459148675, 0.025494088149571326, 0.05139028675330337, 0.06258402965613641, 0.11145493655931205, 0.04546400006802287, 0.03815562289673835, 0.02508343186491402, 0.06709814289934002, 0.025939805345842615, 0.05461022061354015, 0.04451925720786676, 0.019856231592711993, 0.0350313147646375, 0.029663995155715384, 0.06165130587760359, 0.0445133163157152, 0.02510085192625411, 0.05493922952155117, 0.07521289691794664, 0.027298980166960973, 0.036662046986748464, 0.060838472345494665, 0.07960220318636857, 0.05005830978916492, 0.1080750921391882, 0.03592549139284529, 0.01706467093754327, 0.02105570922140032, 0.08383053762372583, 0.03371653707290534, 0.02947072691313224, 0.006765929374523694, 0.0970638841681648, 0.029349139003898017, 0.08331217715749517, 0.022702139722241554, 0.08785377212916501, 0.07925800251541659, 0.016462714957015123, 0.009980440918297973, 0.0555138781783171, 0.0228002182484488, 0.06775353351258673, 0.030599268211517483, 0.059608993396977894, 0.0463304352160776, 0.03202344218152575, 0.0070373851940530585, 0.011718900514097186, 0.0001945948895354377, 0.029179741941334214, 0.04037805090774782, 0.03142007612041198, 0.006400288984877989, 0.12515075242845342, 0.07363736935076304, 0.02035215136857005, 0.056491227296646684, 0.05423779977718368, 0.0096512668824289, 0.015056355314300163, 0.035274171459604986, 0.02748677878116723, 0.04311819371650927, 0.0176544575515436, 0.07115577594959177, 0.022468008828582242, 0.05087556652142666, 0.04171810986008495, 0.03160188003676012, 0.04547056436422281, 0.04152429799432866, 0.014145920085866237, 0.024777533435553778, 0.0642055258504115, 0.03558716482075397, 0.019903688225895166, 0.015544612415396841, 0.02454809105984168, 0.04190482308331411, 0.02877305985748535, 0.05750167620135471, 0.030088451676419936, 0.060824241663794965, 0.013458488174364902, 0.010022080969065428, 0.012216343548061559, 0.012550312785606366, 0.041308362706331536, 0.029250965853862, 0.07260911632329226, 0.07379601083812304, 0.09270459777326323, 0.05305808925186284, 0.043748525713454, 0.006097553496147157, 0.046630526339868084, 0.032353901988244615, 0.020436010345292743, 0.051545800088206306, 0.025041990338650066, 0.035788754394161515, 0.04627755348337814, 0.035436345569905825, 0.0734504965657834, 0.029653048477484845, 0.0081112390216731, 0.011856480778078549, 0.034843484609154984, 0.027962690255662892, 0.08065946676651947, 0.060805639732279815, 0.01964916125871241, 0.06580607121577486, 0.046537702219211496, 0.048102557702804916, 0.05339219300367404, 0.07176073020673357, 0.033422787601011805, 0.06764721343643032, 0.08016049861907959, 0.05859715667611454, 0.01312894213697291, 0.09254683202016167, 0.01201083729029051, 0.04353481315774843, 0.10939838597550988, 0.11392308966605924, 0.003240306277803029, 0.09897273252136074, 0.19083629886154085, 0.2860313735436648, 0.12887869379483163, 0.2085873283795081, 0.1536416681483388, 0.11652759756543674, 0.1750998292118311, 0.24447053961921483, 0.06662528350716457, 0.08971237708465196, 0.05873664704267867, 0.04651705938158557, 0.08112971379887313, 0.024270451758638956, 0.025372079071530607, 0.03536670614266768, 0.15721923555247486, 0.04309370655391831, 0.16476644697831944, 0.07945377365103923, 0.04945418673742097, 0.07294828523299657, 0.04166151367826387, 0.05789239839941729, 0.04384170606499538, 0.013109765041008359, 0.05136765867064241, 0.07187939219875261, 0.08552445258828811, 0.043703636911232024, 0.07467169314622879, 0.015833997131267097, 0.039797717399778776, 0.03160811036650557, 0.022723361435055267, 0.019986838451586664, 0.03564177575754002, 0.044939071594853885, 0.02714666919928277, 0.043708112061722204, 0.032562772030360065, 0.018328637488593813, 0.045264340078574605, 0.04523544826952275, 0.040760943447821774, 0.048519277333980426, 0.07146625343011692, 0.02536460193368839, 0.007513406135331024, 0.09546830377075821, 0.017663413418631535, 0.05304648948367685, 0.05149344156961888, 0.010784864061861299, 0.014179143254295923, 0.03713801968842745, 0.019241534791945014, 0.03390140976989642, 0.04885092828772031, 0.04688028129749, 0.05119836365338415, 0.0395508308429271, 0.02569603209849447, 0.05562541184190195, 0.04364665852335747, 0.03676405147416517, 0.008909459666028852, 0.013513914545910666, 0.03329667815705761, 0.04156591763603501, 0.06218557799002156, 0.02504679017874878, 0.020994274236727506, 0.06484380995971151, 0.04743662117107306, 0.007355523957812693, 0.03946660079236608, 0.03055777844565455, 0.021282943707774393, 0.030921085708541796, 0.06050322197552305, 0.02429469215712743, 0.02101390404277481, 0.06746247803675942, 0.04919553342915606, 0.053056697724969126, 0.025591734374756925, 0.01801358837838052, 0.08880375826265663, 0.04744393874716479, 0.13376815564697608, 0.13508494826965034, 0.10917634281213395, 0.12324764829827473, 0.1431062733172439, 0.12858134490670636, 0.12189161090645939, 0.13455315493047237, 0.140623715124093, 0.13205986528191715, 0.18143054185202345, 0.13763317168923095, 0.12168898232630454, 0.1258050001342781, 0.1645977419684641, 0.07324193080421537, 0.16009587416192517, 0.11816920596174896, 0.10537859503529035, 0.21150750137167051, 0.11306005355436355, 0.11875064155901782, 0.18010681757004932, 0.10128513109521009, 0.1352785003837198, 0.13523462461307645, 0.08330709344591014, 0.09280133672291413, 0.049229141586693004, 0.07986775104654953, 0.16246286511886865, 0.08511672407621518, 0.11969397804932669, 0.09155851395917125, 0.10565622505964711, 0.14066674484638497, 0.10228398023173213, 0.19429720065090805, 0.1003416239109356, 0.15562992630293593, 0.1151516186655499, 0.08788687933702022, 0.13131908315699548, 0.12052343197865412, 0.15582148946123198, 0.2598726568976417, 0.08797560309176333, 0.18527338252170011, 0.221708306344226, 0.20012274821056053, 0.11165769130457193, 0.10268812417052686, 0.13651677378220484, 0.15162531228270382, 0.12993227632250637, 0.10887297510635108, 0.16833745379699394, 0.29166765860281885, 0.1546534529188648, 0.17054106836440042, 0.17464710428612307, 0.14196443458786234, 0.20589382213074714, 0.15287403512047604, 0.14596177556086332, 0.13377093127928674, 0.13657154428074136, 0.1493164463317953, 0.1644912437768653, 0.225506232236512, 0.13792355923214927, 0.20035489200381562, 0.16716647834982723, 0.17395163769833744, 0.20140641136094928, 0.1734134618891403, 0.15946264407830313, 0.17042455117916688, 0.12683253327850252, 0.13477219239575788, 0.24926380428951234, 0.23267254378879443, 0.2594930335180834, 0.13721909781452268, 0.0963064408279024, 0.2661823370726779, 0.34025532484520227, 0.5018014891538769, 0.11631109824520536, 0.15188396559096873, 0.19194953521946445, 0.17182327690534294, 0.16723765031201765, 0.32531137985643, 0.17339698621071875, 0.11990619517746381, 0.1938219292787835, 0.09228712486219592, 0.16805522987851873, 0.08635653372039087, 0.09896873234538361, 0.23288252705242485, 0.15565119625534862, 0.47460904985200614, 0.21914270182605833, 0.13373857364058495, 0.22027501137927175, 0.19133695168420672, 0.17683930462226272, 0.1419258874375373, 0.11401169467717409, 0.1895366795361042, 0.10052975834696554, 0.14288275327999145, 0.17939137236680835, 0.15996144153177738, 0.17411424225429073, 0.1755363159463741, 0.1617832508054562, 0.16769177047535777, 0.17131598928244784, 0.092154094891157, 0.20625509961973876, 0.17653405928285792, 0.10403290318208747, 0.08221308613428846, 0.1694736967328936, 0.1322393017471768, 0.14842275209957734, 0.25193408131599426, 0.10399151360616088, 0.13502355781383812, 0.174936868424993, 0.11723015908501111, 0.11703650307026692, 0.2033235866110772, 0.11267281573964283, 0.16173272539163008, 0.14965419773943722, 0.1795797739760019, 0.06197835551574826, 0.20032962929690257, 0.07261996652232483, 0.13923030317528173, 0.07692957355175167, 0.1261389220599085, 0.11444926494732499, 0.14774013950955123, 0.098654328903649, 0.1913349181995727, 0.25506665697321296, 0.10234071742161177, 0.08873113911249675, 0.25717076438013464, 0.10688703245250508, 0.12717975449049845, 0.1830240516574122, 0.1251783751649782, 0.04555880943371449, 0.13612269336590543, 0.1281251764157787, 0.15331841830629855, 0.10120821491000243, 0.13542225438868627, 0.2299871714785695, 0.143445227004122, 0.14354946906678379, 0.09734511360875331, 0.14446275599766523, 0.1804629890830256, 0.11966487843892537, 0.1025466930877883, 0.1639628197881393, 0.11431069113314152, 0.1272305173915811, 0.211931134108454], [0.08708850655239075, 0.04162058794463519, 0.08501858246745542, 0.010704264968808275, 0.014252751316234935, 0.0428516291140113, 0.041138566739391536, 0.029887396449339576, 0.0695756396453362, 0.03196045239747036, 0.0433172414341243, 0.03359529982844833, 0.017678633012110367, 0.06415276657207869, 0.017560512787895277, 0.0473159702232806, 0.02444462454150198, 0.030845436740492005, 0.0641672384517733, 0.0054315167744789505, 0.009805969420995098, 0.016400218701164704, 0.028685812976618763, 0.03526527310896199, 0.05583466780080926, 0.0356348960485775, 0.017829051503213122, 0.03743347981071565, 0.021427456558740232, 0.13341723853955045, 0.02495965647540288, 0.036477986941463314, 0.049057052383432165, 0.11777188236010261, 0.04693467330071144, 0.018308085564058274, 0.06024975256877951, 0.018887350379372947, 0.013435009404929588, 0.028353124871500768, 0.03698562708450481, 0.0534362654434517, 0.04681735830672551, 0.08112942436127923, 0.07035199290839955, 0.007523667718487559, 0.06802296280511655, 0.039900779447634704, 0.011777386389439926, 0.01868546023615636, 0.05545415755477734, 0.016641587390040513, 0.023431444533343893, 0.05896711358218454, 0.014652817153546494, 0.03146397415548563, 0.06052942720998544, 0.01912744999572169, 0.025259066678700037, 0.0368697036174126, 0.02829952511092415, 0.039538192067993805, 0.06007809381117113, 0.022620310519414488, 0.023920336170704104, 0.08187739047571085, 0.06378200443577953, 0.06121623664512299, 0.15239762084092945, 0.07580597681226209, 0.08466408078675158, 0.016351802842109464, 0.05304887177771889, 0.05018395539082121, 0.032661577861290425, 0.0379094599338714, 0.014523395875585265, 0.04973144197720103, 0.07078790818923153, 0.027082402921223547, 0.07984190204297192, 0.020822654441872146, 0.02021656655415427, 0.20192031894112006, 0.019042739404540043, 0.05500356630363967, 0.0818855244142469, 0.04505614910158329, 0.05144313880009577, 0.02698521682759747, 0.04287194169592112, 0.04588072340993676, 0.06416418080334552, 0.06261333706788719, 0.06718637683661655, 0.06949307571630925, 0.05690289290214423, 0.09688772057415918, 0.02038246253505349, 0.04092115457751788, 0.08138695702655241, 0.08816322544589639, 0.09331589739304036, 0.026852426199184265, 0.05658632981067058, 0.14673850731924176, 0.10595205996651202, 0.03898599337844644, 0.039681029520579614, 0.20128553034737706, 0.025977204022638034, 0.0366248134378111, 0.033918056142283604, 0.05439616666990332, 0.005830332556797657, 0.06981075202929787, 0.05183976849366445, 0.024380413924518507, 0.09547346911858767, 0.041373716230737045, 0.056421617555315606, 0.03992683625256177, 0.014013685140525922, 0.048079228290589526, 0.06954767552088015, 0.08131034512189217, 0.03674224717542529, 0.07432030848576687, 0.033353289181832224, 0.03330209954583552, 0.05422466005256865, 0.04228896614222322, 0.0038127841526147677, 0.06402335086022504, 0.057553240621928126, 0.012536641497717937, 0.03418196385609917, 0.06258528388570994, 0.013825499681843212, 0.059828709927387536, 0.04753300760057755, 0.013782552523480263, 0.03402147071028594, 0.024048386330832727, 0.03269303007982671, 0.04789640392118599, 0.04084544809302315, 0.04441251410753466, 0.0319552870496409, 0.02326051122508943, 0.06821167611633427, 0.03428226882533636, 0.04485286000999622, 0.024970239501271863, 0.05807244342577178, 0.04098136872926261, 0.05909883366257418, 0.06558373861480504, 0.028387733073031995, 0.011749807254091138, 0.041438472326262854, 0.05898871007957496, 0.05790117058495525, 0.061081355015630834, 0.029051305864413735, 0.024688154735486023, 0.031001953830127604, 0.05892902656341903, 0.059231763443676755, 0.023428661479556467, 0.09119274647673592, 0.011927824361919193, 0.016531504625163507, 0.06261013841140084, 0.017171111612697132, 0.03137361396511551, 0.04913116696116049, 0.023133205068006646, 0.027753686626965646, 0.05203960659855511, 0.02086260610667523, 0.08688728805282153, 0.08536451234249398, 0.01716811333608348, 0.022690272780891974, 0.014866496312606614, 0.033957590349018574, 0.03308562620077282, 0.01096783964385395, 0.03651622238976415, 0.02214868309238227, 0.05297040821460541, 0.01723072462482378, 0.0402524127275683, 0.01418778185325209, 0.034410953521728516, 0.022397128159354907, 0.05827026288898196, 0.05202608837862499, 0.027726969310606364, 0.02014355963183334, 0.06020210297720041, 0.03354412874614354, 0.034011114039458334, 0.016761542574386112, 0.10042673340649344, 0.06595807048142888, 0.02669815039553214, 0.07469478136044927, 0.1261678955052048, 0.039080505885067396, 0.010904415703407722, 0.031534496738458984, 0.07835097931092605, 0.036363217514008284, 0.012884203169960529, 0.043048821462434717, 0.06219076560228132, 0.04293620426324196, 0.013207255415181862, 0.040956169104902074, 0.023658424834138714, 0.013612390121124918, 0.030680711497552693, 0.027933922756346874, 0.04666911801905371, 0.01442821450837073, 0.001115275408665184, 0.02810323261655867, 0.07209727933513932, 0.0788523445953615, 0.03826762411335949, 0.05209372771787457, 0.01697722738754237, 0.028315087947703432, 0.02291646826051874, 0.056682816430111416, 0.07960542410728522, 0.03141573826724198, 0.022006723229424097, 0.015641406098438893, 0.041407970056752674, 0.05313826346537098, 0.07895872404333204, 0.020392802507558372, 0.030681655880471226, 0.047592665141564794, 0.056688093100092374, 0.0281216174698784, 0.09979475013096817, 0.07980964088346809, 0.05077718371467199, 0.06461319499067031, 0.022971327816776466, 0.03150008706143126, 0.07114024279871956, 0.01144205345553928, 0.015862842556089163, 0.09140730879153125, 0.1331346287042834, 0.056096794360200875, 0.059242309362161905, 0.09486876719165593, 0.12876603577751666, 0.08840881695505232, 0.13042250939179212, 0.06513567437650636, 0.08973317948402837, 0.04196931571641471, 0.07505040368414484, 0.03753024102479685, 0.06835332242189907, 0.0650411618698854, 0.044632679637288675, 0.06534576896228828, 0.04612748380168341, 0.10417659039376304, 0.03133665872155689, 0.14034076390089467, 0.027728360837500077, 0.041557765143807046, 0.05850187604664825, 0.12091727490769699, 0.0914907781407237, 0.029454533250827808, 0.06748644198523834, 0.005746614588133525, 0.0323403169750236, 0.04266043702955358, 0.07019736643997021, 0.019922217798011843, 0.04656411154428497, 0.042939284176100045, 0.033122614840976894, 0.03149818716337904, 0.06246345292311162, 0.028583476378116757, 0.04790800368937198, 0.10393968201242387, 0.0446942890266655, 0.017611936200410128, 0.016252586974587757, 0.027503697892825585, 0.049361310666427016, 0.009402802334079752, 0.01071712453267537, 0.07419866306008771, 0.13499946770025417, 0.04166836370131932, 0.04425570572493598, 0.03184475157468114, 0.10536732923355885, 0.07045570804621093, 0.11457197906565852, 0.03105658517597476, 0.033601441100472584, 0.03697599771840032, 0.042463693680474535, 0.009200334243359976, 0.04070841423526872, 0.016717796679586172, 0.018252086811116897, 0.030469861776509788, 0.03422159454203211, 0.03539465171343181, 0.018769365597108845, 0.05803123567602597, 0.05407382224802859, 0.049630932917352766, 0.029761142286588438, 0.048621868118061684, 0.04160347401921172, 0.028263354688533582, 0.00534821904693672, 0.04735812050057575, 0.030613790186180267, 0.003642454998953326, 0.006889163923915476, 0.022170769407239277, 0.03789141461311374, 0.018313545915589202, 0.07314250527997501, 0.06334798905299976, 0.018013310073001776, 0.06524469587020576, 0.0773190452309791, 0.05048512633948121, 0.015430833755090134, 0.026838297562790103, 0.03629087295848876, 0.00992441247944953, 0.02264479211589787, 0.19227217650040984, 0.14818155410466716, 0.11182020680280402, 0.14933918573660776, 0.08044983231229708, 0.21523510135011747, 0.17692074790829793, 0.08055112062720582, 0.22430888086091727, 0.11556909157661721, 0.1699912259937264, 0.12228019200847484, 0.08441005847998895, 0.09259738711989485, 0.1558667901554145, 0.19554443919332698, 0.11307658118312247, 0.13991198065923527, 0.20167689450317994, 0.12346373943728395, 0.14319034380605444, 0.11916128671145998, 0.13719857000978664, 0.10760053322883323, 0.19749737111851573, 0.16382889181841165, 0.12238516879733652, 0.0971026836486999, 0.09102057563723065, 0.22751877346308902, 0.10049892211100087, 0.15438527043443173, 0.21479477029060945, 0.20550544140860438, 0.1630344524164684, 0.09869968154816888, 0.0804773808340542, 0.14482222264632583, 0.1877517401590012, 0.1087443609139882, 0.1703049911884591, 0.16380257526179776, 0.14791893772780895, 0.2171044229180552, 0.28550364717375487, 0.17425667523639277, 0.0842644862132147, 0.1263598000514321, 0.09729179771966301, 0.15293192263925448, 0.14155260199913755, 0.09858369870926253, 0.1296273129992187, 0.19690902612637728, 0.16844509489601478, 0.0925979066232685, 0.2219124711700715, 0.10291538463206962, 0.09301658923504874, 0.10124412743607536, 0.17096942116040736, 0.1686288951896131, 0.14469559740973637, 0.11054581307689659, 0.10428843947011046, 0.14904815994668752, 0.18820425728335977, 0.21474601118825376, 0.2246164862299338, 0.16912426392082125, 0.17266533250221983, 0.17177730827825144, 0.14986260764999315, 0.15665294718928635, 0.11746334930649027, 0.23519255075370893, 0.1550694860634394, 0.1605907827615738, 0.11738761313608848, 0.22551124915480614, 0.21378821023972705, 0.1519070760696195, 0.16803355916636065, 0.36150630796328187, 0.13860909588402137, 0.22859638673253357, 0.2647546527441591, 0.3263084404170513, 0.16145697300089523, 0.183978735585697, 0.15728723112260923, 0.15950280911056325, 0.19277199811767787, 0.21740341937402263, 0.2170141035458073, 0.2512179088080302, 0.16147211281349882, 0.3907574649201706, 0.13975494221085683, 0.23731522669550031, 0.2813803340541199, 0.23270892386790365, 0.20041850890265778, 0.21830818644957617, 0.22153048776090145, 0.23332045355346054, 0.22107957367552444, 0.17289441864704713, 0.1126715615100693, 0.24724038317799568, 0.18593641725601628, 0.13587021472631022, 0.1301631287788041, 0.17148435290437192, 0.12172127317171544, 0.15057319920742884, 0.20581417484208941, 0.13994622335303575, 0.1819769258145243, 0.11530382573255338, 0.1509827608242631, 0.09691967003163882, 0.14450694347033277, 0.18227345834020525, 0.1850484375609085, 0.1672242025961168, 0.06706006330205128, 0.08881571426172741, 0.18969422264490277, 0.11334334616549313, 0.19255665654782206, 0.19592352822655812, 0.17973532812902704, 0.14993958320701495, 0.1870544330449775, 0.21399279066827148, 0.21259131899569184, 0.13368435233132914, 0.10367426031734794, 0.14153971831547096, 0.1466232814709656, 0.11234869016334414, 0.17251057986868545, 0.13848150585545227, 0.16939439083216712, 0.13186224619857967, 0.1484438736224547, 0.16635844280244783, 0.07619086201884784, 0.09458828732022084, 0.17170091159641743, 0.1349822647171095, 0.13949378044344485, 0.12446039181668311, 0.12300191578106023, 0.09493393517914228, 0.15570667921565473, 0.14121967455139384, 0.1268434725352563, 0.10842389412573539, 0.12703890970442444, 0.10391644536866806, 0.08835063257720321, 0.18068024539388716, 0.1033595971239265, 0.2689395344350487, 0.1756649449816905, 0.09690408493042924, 0.10326764502678998, 0.14384356734808534, 0.13813876721542329, 0.10286733799148351, 0.10575760243227705, 0.22088965808507055, 0.1866610354045406, 0.09540493178064935], [0.04518166482739616, 0.03067830879444955, 0.01785384851245908, 0.05844976243679412, 0.008975106338766636, 0.027843176649184898, 0.0784743316762615, 0.02264187547552865, 0.04796203946170863, 0.02397949090664042, 0.07007680454989895, 0.04036670346977189, 0.030597815457440447, 0.055279159132624045, 0.08449861154076643, 0.06296412801020779, 0.03971439276938327, 0.08954336037277244, 0.03986596901086159, 0.011165500472998247, 0.05846438274602406, 0.004576714791255654, 0.06205740537552629, 0.07884885650128126, 0.020740014442708343, 0.06382941282936372, 0.047740612280904315, 0.026016266965598334, 0.06324864516500384, 0.01731230891891755, 0.042881422632490285, 0.09298544129705988, 0.011479777749627829, 0.035480425431160256, 0.055533552513225004, 0.009228918061126024, 0.009932327484420966, 0.06916827478562482, 0.013893862615077524, 0.04325786590925418, 0.06920323736267164, 0.05588683707173914, 0.021906173351453617, 0.010683308573788963, 0.022802543026045896, 0.013968031926197, 0.07736037543509156, 0.0678213954961393, 0.010578409710433334, 0.03485083929263055, 0.05264312851068098, 0.04749086845549755, 0.02449876606988255, 0.07736280225799419, 0.056536865668022074, 0.06176394163048826, 0.026240586666972376, 0.029203772683104035, 0.023225528238981497, 0.06555155909154564, 0.027715527248801664, 0.04211504754493944, 0.016348533681593835, 0.018736473612079863, 0.003534826423674531, 0.05725984738091938, 0.05574557297222782, 0.05111104626848828, 0.08658863298478536, 0.09069115112652071, 0.044269220234127715, 0.06898031846503727, 0.1529798802221194, 0.0494839691236848, 0.03078976082178997, 0.051967313993372954, 0.02692257214221172, 0.023403996201523114, 0.026273738403688185, 0.034496549124014564, 0.03694725062814541, 0.030980618939793203, 0.029084101370244753, 0.04134786722715944, 0.01367704788208357, 0.1441356766736135, 0.009400457147421548, 0.06485048928880133, 0.04021138680400327, 0.039023297431413084, 0.07543016065028496, 0.03438141975493636, 0.012290227132325526, 0.10597341155516915, 0.03428673655434977, 0.024533483738196082, 0.08336047612829134, 0.0534561624226626, 0.022986003787082154, 0.02172195745515637, 0.06785555655369535, 0.10588188990368508, 0.06200104297022335, 0.020123777685512323, 0.04066573332238477, 0.056971122248796746, 0.09405319884535857, 0.03672044287668541, 0.03958443157898728, 0.03411805380892474, 0.01209713422213099, 0.08306074494612403, 0.03786434477660805, 0.044638590843533166, 0.021288569187163375, 0.02453171371598728, 0.03804830463195685, 0.026914827831205912, 0.021068425921839662, 0.08058693667408079, 0.010434440482640639, 0.01520064273790922, 0.03457626691670157, 0.09386096033267677, 0.04517298541031778, 0.012918503380205948, 0.05269455192319583, 0.04637330166588072, 0.029171548630984034, 0.006743148687746725, 0.0654974787903484, 0.07742130575934425, 0.0068107861716271145, 0.07859168748836964, 0.021161246331757866, 0.043528070746106096, 0.039400642417604104, 0.029867827870475594, 0.055477171554230154, 0.025261565861001145, 0.009826411878748331, 0.02073292878776556, 0.07525105815147981, 0.0696809652436059, 0.1017882552696392, 0.057498433016007766, 0.038725239792256616, 0.016854810128279496, 0.024672931431268808, 0.05584713588177692, 0.035690130389411934, 0.012799247670045588, 0.048290517734130844, 0.011816096812253818, 0.06129101544502191, 0.025747347899596207, 0.02345617289392976, 0.05798959748062771, 0.03230323927709833, 0.011272978299530223, 0.020289144886191934, 0.061352699049166404, 0.025156481460726354, 0.05617599264951423, 0.019938443001592532, 0.053525594048551284, 0.04858936204982456, 0.008650600411783671, 0.024094249201880302, 0.03180159939802252, 0.06463648358476348, 0.02773665990389418, 0.01621764480660204, 0.19515129388310015, 0.043849873400176875, 0.0646137516014278, 0.03399092391191516, 0.03542310565535445, 0.017196112712554168, 0.030600362879340537, 0.007627948280060082, 0.04510201753873844, 0.05033062232541852, 0.04441491124453023, 0.05248076886346098, 0.032938833101070486, 0.040066846122499555, 0.04747472674353048, 0.026673895154090133, 0.03509790025418624, 0.030246612623159308, 0.015195701889751945, 0.056773829710436985, 0.040294718855875544, 0.02156764083338203, 0.05198321450734511, 0.09242114188964479, 0.09450879588257521, 0.03394702958757989, 0.0481299169769045, 0.019268788310000673, 0.04522221577644814, 0.018688373165787198, 0.018736499587248545, 0.06710902278427966, 0.03648493344371673, 0.04290723823942244, 0.04519169124250766, 0.03967001975979656, 0.08675037664943375, 0.05051227781223133, 0.0275300534121925, 0.020263841361156665, 0.047540061714244075, 0.07422654554829933, 0.06575455132406205, 0.01530297840872663, 0.051379700016696006, 0.015013810771051794, 0.025715142401168123, 0.048836315399967134, 0.05526307679247111, 0.09087526312214322, 0.04101709942915477, 0.06314280006336048, 0.0636171066435054, 0.04070771290571429, 0.04220488452119753, 0.007760841417621123, 0.037964831572026014, 0.03192231342836749, 0.004402857421155204, 0.040048830487648956, 0.04136423900490627, 0.01813268638215959, 0.03306367347249761, 0.08846287499181926, 0.07891610250226222, 0.04246589043759741, 0.06082591149606742, 0.06828254379797727, 0.050669167831074446, 0.1005966926459223, 0.02465014193148818, 0.1513523652101867, 0.06594073391170241, 0.05798959748062771, 0.03394292922166642, 0.07917526047094725, 0.023279105735127814, 0.011827057405753294, 0.09523832704871893, 0.07011734807747416, 0.04494943939789664, 0.03129787037323695, 0.1321152740274556, 0.02089071123918984, 0.011595802334340988, 0.0383538690948626, 0.04977277589205187, 0.019904478613170795, 0.08273308674688451, 0.15597124001942575, 0.13673364417627454, 0.07180495478678495, 0.05557684569794219, 0.10957987076835707, 0.0457101890060585, 0.03595963389670942, 0.06377175537636504, 0.09360397685668431, 0.04429793021699879, 0.07414113919367082, 0.06975477925152518, 0.08895489663700573, 0.06202882155776024, 0.013164980828150874, 0.09304757390054874, 0.11114025110146031, 0.03367204531969037, 0.020068847625225317, 0.018161678381147794, 0.10954391371342354, 0.0119227545656031, 0.017097752170229796, 0.05475931437104009, 0.03223518062441144, 0.11803004585090093, 0.02636412827996537, 0.036154017216176726, 0.023883293724793475, 0.044031306242686696, 0.013717231468035607, 0.02084058472973993, 0.0821582117350772, 0.019914814874937292, 0.03925373428501189, 0.021147794905118644, 0.026280690472049173, 0.023416323274432216, 0.04784181895956863, 0.020231591333867982, 0.016536543807887938, 0.0540152371104341, 0.04802496245247312, 0.007288279348358628, 0.06167425679450389, 0.047715319888084196, 0.02734055342443753, 0.06205356847203802, 0.02778961028525373, 0.05180179650778882, 0.025566466101736296, 0.06829594698501751, 0.015022840852907393, 0.03828750996035524, 0.012263081225682981, 0.04837662541831378, 0.05522553525224794, 0.0352185289375484, 0.04724395592347719, 0.011518397259351332, 0.03181804910127539, 0.03072060935664922, 0.022466713780886494, 0.060678936570184305, 0.021310995034582447, 0.01839385000494076, 0.06620067855692469, 0.04098941361007746, 0.013971822445455473, 0.008597159285272937, 0.022519606645801105, 0.08625960181234404, 0.027085295441793278, 0.02209756767115323, 0.03875539325235877, 0.019680726654769387, 0.03602459779358469, 0.04267701289791148, 0.015121668948268052, 0.05521185004909057, 0.04503107935306616, 0.016823343066789676, 0.038050304719945416, 0.01655071882851189, 0.04427865664183628, 0.03949621619540267, 0.03252095943025779, 0.041355926950927824, 0.031890430764178745, 0.034355500247329473, 0.26238803286105394, 0.12486342253396288, 0.16879065369721502, 0.1101450459100306, 0.0987942905339878, 0.1106028248614166, 0.21895640791626647, 0.14906706986948848, 0.14985517133027315, 0.07423345494316891, 0.09572487164405175, 0.12583467119839042, 0.12675592879531905, 0.12328636614256538, 0.24027348670642823, 0.16470918286358938, 0.1331733984989114, 0.12377617618767545, 0.17194604297401384, 0.21625908702844754, 0.14135167293716222, 0.18641844217199832, 0.1417575089726597, 0.19683236227137968, 0.15441069641383365, 0.10887975091463886, 0.14728879497852176, 0.10621214561979286, 0.26149870245717466, 0.07041175063932315, 0.12297660854528658, 0.23718300566542894, 0.07522631494794041, 0.1697414042428136, 0.1050098441191949, 0.09711524078738876, 0.1515069545712322, 0.23023821035167202, 0.17889560287585482, 0.1281252209446393, 0.2240575451287441, 0.1798767814761959, 0.09860654943622649, 0.26614698115736246, 0.11728797238902189, 0.12230681284563616, 0.193206288095098, 0.2063303385511972, 0.2698514558142051, 0.13685361976968125, 0.15485877549508587, 0.13879169389838353, 0.12452872877474874, 0.16091124212834984, 0.10253487809677608, 0.12936220300616696, 0.11999310809187591, 0.11168930679559708, 0.14811856060987338, 0.14944149821531028, 0.14877510897349566, 0.13988190883537754, 0.09551341892802157, 0.21023123001214117, 0.10098157043103129, 0.2145217638462782, 0.22894932248163968, 0.16473333234898746, 0.2312504849396646, 0.160738707636483, 0.14749526046216488, 0.2301705116406083, 0.29003843665122986, 0.13118071714416146, 0.09904283579089679, 0.22570189204998314, 0.14756393880816177, 0.1132735917053651, 0.1273828506236896, 0.16524311358807608, 0.13814130536047742, 0.21109730150783435, 0.16255413444014266, 0.14200531208189204, 0.10359624575357884, 0.385298493783921, 0.22633547836448997, 0.20378196670208126, 0.1545576861826703, 0.15740542556159198, 0.13108679093420506, 0.09291570167988539, 0.11061915953177959, 0.19528394535882398, 0.1765264745336026, 0.12441821556421928, 0.18027317739324644, 0.14703802327858284, 0.22030187712516636, 0.2491249336162582, 0.12310580161283724, 0.2983418817166239, 0.2261518413433805, 0.19878943538060412, 0.1722407795023173, 0.31148739508353174, 0.1883603012538515, 0.11545891975401901, 0.126814721734263, 0.1304241718025878, 0.23188524384750053, 0.2205605452763848, 0.11008398942067288, 0.1182492911175359, 0.11739121997379698, 0.06928262489964254, 0.11279606420430355, 0.13777477346593514, 0.20749951800098643, 0.21231835708022118, 0.1671655135578476, 0.1028726072399877, 0.10239778115646914, 0.1277059520361945, 0.16539417032618076, 0.11695224704453722, 0.1832298343651928, 0.19429160485742614, 0.22641614981694147, 0.10997741701430641, 0.1878570657572709, 0.26238497521262616, 0.1411613417440094, 0.14748996152775362, 0.12227018043631688, 0.12917158979689702, 0.13671339838765562, 0.14642193680629134, 0.12070083495927975, 0.10275289139826782, 0.13058256095973775, 0.09418038069270551, 0.1681654091225937, 0.15251167409587651, 0.19946443353546783, 0.10152588380151428, 0.1933040883159265, 0.13494699785951525, 0.08318156658788212, 0.17059705598512664, 0.12872775580035523, 0.08590268073021434, 0.2467944860109128, 0.0829777357284911, 0.21399258286692202, 0.11412452338845469, 0.09649588144384325, 0.14888435311149806, 0.06881873065140098, 0.1441302738385275, 0.15329719288274646, 0.186354068282526, 0.13524765672627836, 0.198218367586378, 0.13981579832034186, 0.1436592178652063, 0.18884504243033007, 0.08663438638905063, 0.08720400699530728, 0.16838925570482388, 0.13382622128119692, 0.13745898962952197, 0.10747936277766712, 0.24331332358997315, 0.10149055015062913, 0.17369155946653336], [0.0192327292097616, 0.013990255538374186, 0.004030319232697366, 0.1026183103385847, 0.03691216930747032, 0.05966122575046029, 0.02542568625358399, 0.06637535043410026, 0.020275520910217892, 0.09915167174767703, 0.08031991936150007, 0.06923021443071775, 0.025301998066424858, 0.014797931144130416, 0.009054699821717804, 0.010108596834470518, 0.0577189473551698, 0.0869083650468383, 0.028640081836783793, 0.044682748630293645, 0.061667332556680776, 0.04201730298518669, 0.04822257782507222, 0.04245648371579591, 0.01843236190325115, 0.06987321117776446, 0.03248740693379659, 0.017841215303633362, 0.04251074955391232, 0.05782520805951208, 0.04041625667014159, 0.06872914600535296, 0.025361163934576325, 0.04651824310712982, 0.07903172911028378, 0.035462636151351035, 0.031931775811244734, 0.02418965785182081, 0.09727440177812241, 0.018054573483823333, 0.04489103979722131, 0.10085490066558123, 0.030472496400761884, 0.03914490203897003, 0.049788483447628096, 0.06523549323901534, 0.0437998712004628, 0.08279697824036703, 0.024083302523649763, 0.038786541190347634, 0.01712847522867378, 0.020991498604416847, 0.017381278557877522, 0.02841340952727478, 0.012663476391026052, 0.05524495725694578, 0.02547099436924327, 0.04594254060066305, 0.032256012709694915, 0.04012987301393878, 0.0826902202970814, 0.03104754210653482, 0.026272823706676718, 0.02713516962103313, 0.014858876311336644, 0.008465605260425946, 0.03952354578359518, 0.09972869156626984, 0.029195772331149783, 0.01395069164573215, 0.07871669484302402, 0.0538336224417435, 0.03268323001975659, 0.05542472397792153, 0.0609767010610085, 0.05615448149910662, 0.032738842855906114, 0.0832280027680099, 0.016207097032747697, 0.03398104221560061, 0.04836012376472354, 0.010140700287593063, 0.025760300231922884, 0.04573849822918419, 0.038648008194286376, 0.06994560026214458, 0.038542912661796436, 0.019736185495276004, 0.04922883730614558, 0.053884856606600806, 0.09143792238319293, 0.04383934603538364, 0.047182981070363894, 0.04416470357682556, 0.035625615491881035, 0.06725557468598709, 0.0627552876539994, 0.04286777082597837, 0.029060621673124842, 0.03284783837443683, 0.0448542589583667, 0.07500124382204376, 0.06354971963446587, 0.04997952710255049, 0.04600841362844221, 0.03360572700330522, 0.04924202527035959, 0.024734325597819407, 0.02479230588505743, 0.028389067083480768, 0.04523069481365383, 0.06364155298797414, 0.03725507121998817, 0.06750227199518122, 0.030948086896387395, 0.05346719073713757, 0.031219981974572875, 0.026369534825789742, 0.06485114237875678, 0.020261314348317683, 0.06517454807180911, 0.10189899112447165, 0.06689841611660086, 0.03254990318964701, 0.03426507697440684, 0.029588553989015054, 0.08864176226779819, 0.059410212852526456, 0.03392113605514169, 0.04312301396566909, 0.006339694946291274, 0.08801806136034429, 0.02412683876173105, 0.10005847230786458, 0.020114669678150676, 0.0593057629885152, 0.012069923377566738, 0.016183778752747457, 0.037793751689605415, 0.026755742910609115, 0.0333542465523351, 0.05476052778249141, 0.01581479220476467, 0.05424951828899793, 0.016651294681651052, 0.019371338275959715, 0.04568589480186347, 0.02813938077451894, 0.058317916191299446, 0.05068266749731265, 0.046972815980552696, 0.012301229471631814, 0.03679415298392996, 0.023552512939204462, 0.005718077618439565, 0.022999787324806675, 0.05529627305804752, 0.08253057691035792, 0.06144193117506802, 0.027882018803211395, 0.01499728592534666, 0.039754453900968656, 0.03164756293699611, 0.0696215637435671, 0.0221767399852979, 0.028985191638639662, 0.007901304925326258, 0.055096535143093206, 0.023370981762127485, 0.0943384061974939, 0.05614791720290668, 0.03171287935401779, 0.04799310576345306, 0.02031346692092484, 0.05275397939840332, 0.018985796268680133, 0.044237686379347, 0.05646824669383932, 0.025370572511747014, 0.15075780102051795, 0.04461077514861245, 0.0838277545699384, 0.0637299130903557, 0.028417498760973103, 0.047932531670085154, 0.023797705543984193, 0.08240123541327193, 0.016642860173305962, 0.027869830882991664, 0.07126989599782974, 0.033679949192446657, 0.02629295631777495, 0.023936817415233236, 0.0746934454946313, 0.05232142975728493, 0.043136253880220465, 0.11712597639416344, 0.05927259640884586, 0.02888183644245146, 0.01571918503032066, 0.012113955926906783, 0.04556416402920149, 0.03598328243242577, 0.03960770533012692, 0.01779464368155459, 0.024639464281790424, 0.04892350661975797, 0.015334218187490478, 0.08648724076920189, 0.035881259391317144, 0.06348646638798527, 0.03740118154382799, 0.017873576653073542, 0.014413041299121687, 0.051568702765507624, 0.019618065271060914, 0.0874254564405419, 0.006330208907456836, 0.028169333854748402, 0.04070494840561878, 0.10323742477339692, 0.11296306969597936, 0.013973675959277898, 0.02301481581525877, 0.06515637287520804, 0.024224377375503536, 0.025644554880273063, 0.051431902684271336, 0.054625809425488114, 0.009586959786247462, 0.028546946014103014, 0.017243829097424168, 0.08430448797298595, 0.005337662923921016, 0.05972846432996448, 0.01603672961209668, 0.09411158360308036, 0.026127513046958484, 0.014605494106945116, 0.01941544596775202, 0.042399568410473876, 0.04393063019961119, 0.10105266817845404, 0.050325572010478936, 0.056685514136916026, 0.050588971353136, 0.07541577782831155, 0.054920404945733026, 0.026757843188534025, 0.011838346399599686, 0.05883420235477388, 0.03072102124860976, 0.05269246277748607, 0.10419325160910375, 0.034858735743910074, 0.01622897183551686, 0.04692940776294563, 0.04739654890727252, 0.04741927346913144, 0.026799813495017588, 0.06592183141037822, 0.03748396069568116, 0.04254630584910046, 0.07006723826634698, 0.09415141466888599, 0.03348225960507989, 0.09512488235486671, 0.032085300190374255, 0.08298211439978331, 0.02640463841089513, 0.0708509462128859, 0.051497371241566725, 0.10593498314847238, 0.007768614023007103, 0.050613647763384506, 0.0704752784804441, 0.09912977839121595, 0.022076067652960774, 0.02267007337650284, 0.03424522452405654, 0.1081296251504682, 0.07215377161628567, 0.022958115732762963, 0.026570732916297857, 0.006476700045823236, 0.05264901745249517, 0.07226457426440902, 0.02489616203092737, 0.06048473878763616, 0.07952092317282222, 0.0331335244118236, 0.01363630768537405, 0.03831715504929889, 0.06724805673002265, 0.02424852500553243, 0.0422945916216122, 0.02982159763632808, 0.06633074735873379, 0.021169769897824153, 0.0503436173312366, 0.05780507730378304, 0.0195603261818178, 0.020806889369850978, 0.028402902571542654, 0.03136511266347952, 0.023373135845758952, 0.056474725643056445, 0.026713626029959414, 0.026644669378583785, 0.007648071150470059, 0.015283972934412304, 0.0054926400571275735, 0.028763905465893913, 0.03150918579194695, 0.0747331503953319, 0.020658124012697954, 0.03708433643623721, 0.03670255340693984, 0.019288709409011062, 0.0243487891566474, 0.0024501070902260835, 0.012338258929958101, 0.0752364749496337, 0.061210470157675445, 0.04563905415125191, 0.027412948074925225, 0.05295411065162625, 0.06317621155176312, 0.04127626110857818, 0.02232086506410269, 0.054335254899342544, 0.04089910537004471, 0.029828881815774366, 0.058142713678535074, 0.042121578444493935, 0.05427134485216811, 0.04971971604391001, 0.011424180684116436, 0.026716908178059384, 0.049978614260908216, 0.03909913750248961, 0.15434096421813592, 0.05207112189964391, 0.02375159219809575, 0.026198835294053424, 0.04842597081733402, 0.030995148335932754, 0.028737043430737685, 0.026784330439113546, 0.07936782552860677, 0.07170206343289465, 0.08172846370143816, 0.08490328982588835, 0.10588278790237382, 0.1330190317821689, 0.14620726316934451, 0.13566168607212603, 0.21710519475163892, 0.15726343786809593, 0.1083479130466003, 0.08716088079381734, 0.10573864055913873, 0.26864813757129014, 0.1564886060077697, 0.1120564472512342, 0.2787860232638195, 0.22666319593554363, 0.1126365247182548, 0.11927100582397543, 0.16486552369315177, 0.16334927146090195, 0.10911824749200605, 0.15035177202662453, 0.24628840066725388, 0.1668188118492253, 0.15043915249407291, 0.07794898017891683, 0.20029252191307023, 0.13007316563744098, 0.12304395844694227, 0.10804234116221778, 0.11852310650283471, 0.13977003749459982, 0.10871155798668042, 0.22527162451297045, 0.16189158952329308, 0.1721902095596306, 0.20342097122920677, 0.12051281926687807, 0.08858731831423938, 0.1642034389078617, 0.09155397201539017, 0.10066465110867284, 0.12116447687731124, 0.11056118295527995, 0.15499479632126167, 0.22338207199936733, 0.18986393697559834, 0.2153110082144849, 0.27631835255306214, 0.14612783852498978, 0.1597607648000121, 0.09967198406229727, 0.2462161154835485, 0.08681581923156045, 0.1474173943279311, 0.15946571656968445, 0.0794313607912045, 0.09639832613174804, 0.14511489600408822, 0.19350731803569943, 0.1153328585496638, 0.24243183026555926, 0.17230460420250893, 0.1440333790378645, 0.18975121958646923, 0.0926858140155673, 0.14141420630039647, 0.2021932214847766, 0.14516816736431792, 0.1633939635939896, 0.17785643285606056, 0.16341395705239847, 0.16891732346266508, 0.09426456992514431, 0.09790662254090421, 0.3012578986817971, 0.23892350523965433, 0.11491292912978679, 0.2885739417979494, 0.12409628674504347, 0.09305816434789449, 0.1431090192636475, 0.1196327137586195, 0.12015289248665795, 0.16525660583283752, 0.1206059439573437, 0.22328722552629188, 0.23174793168436736, 0.17624034691834822, 0.2419344725785777, 0.10429365676827729, 0.24803399137454107, 0.10942215696559288, 0.17048325506038964, 0.1354740562965162, 0.2195952634792775, 0.15326645312597975, 0.22129726043203846, 0.27165796200279146, 0.15626765380147845, 0.10330126431654207, 0.10630458753439598, 0.12993549724342301, 0.24799382634228095, 0.0963055576721672, 0.15095160546479747, 0.13391186512308195, 0.11628257750999182, 0.07804868771927431, 0.10677934682462364, 0.1887813810026273, 0.12969192437594756, 0.1674971348256804, 0.11715414089849219, 0.19596324797021225, 0.1002929093374405, 0.08904519374482334, 0.12447233297280036, 0.16545027669053525, 0.16477523400681093, 0.16282512224279344, 0.14597572793718427, 0.23547891585621983, 0.1602827024180442, 0.15604101674398407, 0.1427683883230202, 0.10656475482392125, 0.15369839791674167, 0.2263551898067817, 0.12351168959867209, 0.11773565813200548, 0.12927522329846397, 0.332143324194476, 0.05868978412763681, 0.1406153288553469, 0.09997996050515212, 0.19969524146290496, 0.09749820383149199, 0.14342879585456103, 0.17833982332376763, 0.10347700488637201, 0.1334194204537198, 0.2295035880524665, 0.10485210063052364, 0.11937550763832405, 0.1192275011271704, 0.09928849409334362, 0.12320323075982742, 0.11835164070362225, 0.16699238534783944, 0.26701446273364127, 0.1348401582799852, 0.14551944070262834, 0.12416195197147317, 0.09934833346051164, 0.10637360726832412, 0.1269112603040412, 0.11107892001746222, 0.12628062773728743, 0.28191776771564037, 0.17397035466274247, 0.12546120764454827, 0.24085369776003063, 0.1184466875565704, 0.16645125579088926, 0.14366292860358953, 0.25284653704147786, 0.23978021083166823, 0.12477855052566156, 0.1686533266911283, 0.22153828031150624, 0.23396867502015084, 0.11546355817699805, 0.1837999967392534, 0.13929899636423215, 0.20377129461849108, 0.18191598064731807], [0.04257831838913262, 0.03674959072668571, 0.08387409427086823, 0.026488877738302108, 0.04151902874582447, 0.08818390910164453, 0.04920777886582073, 0.015063620940054534, 0.02311407992237946, 0.03398541717615444, 0.050622000635485165, 0.0490080223971745, 0.023972538838279434, 0.04944529580825474, 0.026809739720192738, 0.0466522564238403, 0.05357154041121248, 0.004916708876407938, 0.034950071858474985, 0.07099607319105417, 0.027939958272327203, 0.02360160415264545, 0.026411755607114173, 0.027143290571984835, 0.042318251289543696, 0.07035781134618446, 0.016027089113777038, 0.027246903664490674, 0.033104139074566774, 0.045582287275465205, 0.028543528424052056, 0.0783986622991506, 0.011658883031486766, 0.04319860541727394, 0.02857637773558963, 0.0962993162102066, 0.024827049528539646, 0.025859178422251716, 0.007661281379114371, 0.04148615902522579, 0.019915254597435705, 0.042649831739254296, 0.04391911577840801, 0.011395575529604685, 0.048113515513250604, 0.06353448334266432, 0.030684446355735417, 0.024702296359464526, 0.012603420873347204, 0.046646812770632096, 0.03535414900397882, 0.065358266729163, 0.030937036317482125, 0.016832360161060933, 0.02977909298351733, 0.031108036419027485, 0.03759212500881404, 0.017700799107842613, 0.042613577825250104, 0.04491795007197652, 0.09364100260427222, 0.06656893223407678, 0.06737687130225822, 0.02659616631717654, 0.020202775594952982, 0.06333509052637964, 0.034494575011194684, 0.031686885631643236, 0.02797108951199334, 0.030871335839037783, 0.04240403985022567, 0.040058066515484825, 0.02646372635354055, 0.03140550405078102, 0.01943713523360202, 0.009390754494233988, 0.047038087868713774, 0.030453439903794788, 0.08193958987249061, 0.012542022068373626, 0.05917842900089454, 0.09621489691198803, 0.02344203312532045, 0.06225126919161994, 0.06084479915443808, 0.026466325725778006, 0.061001024951110594, 0.08677055564476177, 0.10089306932059117, 0.06639247920247726, 0.04256320826243609, 0.0394304099609144, 0.04076173012435902, 0.01999806900130352, 0.039739488493069075, 0.04543285584077239, 0.08713910618098453, 0.028529518531286158, 0.012494696238718461, 0.06453132868045941, 0.037885889323661104, 0.08761765042436309, 0.03127174677501898, 0.056042929281829856, 0.06600619133678265, 0.043543563078856096, 0.01590929357917048, 0.021351560826587956, 0.017257915060326923, 0.012263668450032128, 0.01813482005672995, 0.031544103840133175, 0.040482189069734886, 0.02034035493124975, 0.03899002324033063, 0.052441182706388645, 0.07828393368981779, 0.036207930534146726, 0.055492526589659974, 0.09617671341402456, 0.01715464150038315, 0.020750703224621248, 0.10033524144091643, 0.04159499869274441, 0.05376735236495733, 0.07519592400058173, 0.040034737103269435, 0.01644156003749231, 0.04321288433857262, 0.05328744256985374, 0.016336286389559973, 0.014319778383651283, 0.04559405402687844, 0.060237314173718914, 0.03477449827187229, 0.05823903702548705, 0.020796259959752206, 0.012277103178348625, 0.01686102190433303, 0.09045885890373029, 0.07077860165736638, 0.04374712676508352, 0.066834821482189, 0.04359170619864017, 0.02733020046434831, 0.008986874017864466, 0.03507189168885816, 0.007462053690687753, 0.036523432354442775, 0.0620284764590906, 0.10090929266880266, 0.05940203809586819, 0.042856300933635794, 0.03885995814925991, 0.028543365151563194, 0.05552129965508357, 0.05507150992343668, 0.07353391396463849, 0.007305137696675956, 0.035377485837670974, 0.08593062259024009, 0.08466338316793554, 0.05855338109540753, 0.06884227899718098, 0.05012908470234834, 0.02749016297457274, 0.054811509617138654, 0.08362942302483134, 0.05327600607415661, 0.02513363815523917, 0.020952090562786907, 0.03614936395024415, 0.05614244015305303, 0.01603472395800054, 0.006482268936451874, 0.01667928292590659, 0.04021810324047692, 0.01758331713062944, 0.023636256883037277, 0.008524750719516305, 0.012523229961516336, 0.045649967432837, 0.029334976970858406, 0.03662583389086649, 0.032489774384885095, 0.07807616944774054, 0.028812367709178943, 0.058692403908935376, 0.02451826600008644, 0.05369654405512847, 0.018607480924401898, 0.06602259280043654, 0.01623022235435201, 0.03720483153301757, 0.014945805924071465, 0.06755407390301116, 0.043346626771381125, 0.04392441100208089, 0.018534778282628395, 0.051956586248707026, 0.0442647747695446, 0.025276360574935097, 0.09295364026911557, 0.021073802781756967, 0.025367052876390517, 0.04081375467649195, 0.07231170806335285, 0.07962982592289336, 0.038924205873627216, 0.052640115391113795, 0.04916206999041606, 0.14221949590137228, 0.060546218301169574, 0.00979578158876393, 0.014501278947136598, 0.024395685468334705, 0.0634309982706327, 0.042675053628045134, 0.07000330966548063, 0.017669975859462284, 0.08139147670590319, 0.0641288397309836, 0.029457294040184934, 0.05351833955501206, 0.039145974442362785, 0.015208443637675373, 0.008381500447285362, 0.015206272855721181, 0.07304944738280028, 0.01957561071321834, 0.04834806015423965, 0.012027391821902711, 0.07829005640815012, 0.05557972523092758, 0.032788017560960725, 0.0809781820862554, 0.07671731189475395, 0.06158130279800389, 0.01837771385908127, 0.023648535716347396, 0.02843470731022535, 0.06580607863725163, 0.05462036206154153, 0.03184460314514581, 0.040020391388679855, 0.048386169437435456, 0.012631691133719869, 0.01689998465735698, 0.04429637541761622, 0.015133774304558756, 0.028382673481246457, 0.04683478022343479, 0.06675816504866816, 0.01205929953357554, 0.04281381668988615, 0.023351665513473563, 0.03156166676490102, 0.02749223913269816, 0.02156174261472188, 0.07426195341395214, 0.09290864385548048, 0.04402850092446897, 0.010908007698162692, 0.040638073478476144, 0.10217538176220842, 0.040372481089434586, 0.09475940431002527, 0.03509666086756624, 0.1061152656620834, 0.02026857440796448, 0.0937545660417527, 0.011986874269496184, 0.14177696808474138, 0.021712333655159455, 0.024834404212015215, 0.06786115234717727, 0.0387475079332944, 0.029124153224984184, 0.042907071256195195, 0.05259300014586188, 0.01833607195294462, 0.05062965217803139, 0.046310515972436406, 0.031445286876987666, 0.012149959366070107, 0.10135237709619105, 0.025257537854486145, 0.04035376783576794, 0.033012506100931205, 0.04483758290007245, 0.008713478873687563, 0.040676082571735606, 0.05818263009132352, 0.05203454886213876, 0.14796489151194692, 0.08395230179303326, 0.023727097614028025, 0.04418782518769149, 0.03471928990620654, 0.061426327520166524, 0.02262862257339293, 0.018729892617557198, 0.040619712744955905, 0.004590797507262323, 0.07742388101178221, 0.04425480030477047, 0.0299627504136879, 0.07044785612379201, 0.02610405190353049, 0.03388832941709552, 0.02767952566500753, 0.046066449576755986, 0.01892377869808115, 0.02228438108431874, 0.046042775065870956, 0.03402769361855462, 0.05475666119309608, 0.02425468854198698, 0.022484551300294697, 0.04043653214466758, 0.015658794618502725, 0.048205723651335575, 0.03041689284145832, 0.011430205995566212, 0.030860461520205718, 0.03635540640971158, 0.04756578826345503, 0.19198639027308673, 0.04363839099823963, 0.007174591137300013, 0.03221286795451306, 0.0462455817614682, 0.03799842488660943, 0.01732018125039758, 0.026176389037573244, 0.01315155444899574, 0.03827180611551739, 0.031130898278206587, 0.02172810614865739, 0.028895957657368854, 0.03799123347562272, 0.042030873155454174, 0.039829410816309974, 0.03377589033334516, 0.030503607231366914, 0.04655294593248982, 0.04947775734763127, 0.04252856109815184, 0.040695727220736444, 0.013420203558780486, 0.0059295419305271935, 0.0572182574251201, 0.07968778765643947, 0.13959158066427335, 0.18116152816219255, 0.1453824550844729, 0.09102001902647316, 0.12363451503915712, 0.09095991248614155, 0.09892020330880769, 0.1260646924492903, 0.14312499028164893, 0.08593410326284356, 0.1639231594162993, 0.11137440611491911, 0.15138121991185471, 0.09632638975745067, 0.19380779878702015, 0.1463239436270669, 0.0815412421070505, 0.08872017759131268, 0.13256195787107572, 0.07368401333224028, 0.11708808233379386, 0.18097441788995638, 0.14523694961098954, 0.17567278206115589, 0.14962920220568776, 0.20978427899535745, 0.09943201803253032, 0.17743462580256164, 0.1094584702514112, 0.15089981839992106, 0.22175847552716732, 0.10161448139115237, 0.17649065848672763, 0.19105983374174684, 0.24184207519283518, 0.11477690088213421, 0.12923609727295116, 0.06338253602734767, 0.1147317783033941, 0.16187827539397404, 0.14778453478356823, 0.127814112638589, 0.08864679402904585, 0.09965538964024745, 0.12391498006763868, 0.09403986245160922, 0.1649126352276653, 0.07908334548119456, 0.13263853266835213, 0.10235371242742985, 0.13786985742626712, 0.16196304350160062, 0.0925753972842358, 0.19640396494651213, 0.13768690318102017, 0.171594814164564, 0.15618742763763294, 0.09415782682481222, 0.11879885889356956, 0.18140786181902513, 0.15391655964776874, 0.10417563302326016, 0.09242739819455892, 0.17537532927235588, 0.24911810585763305, 0.17484248208347708, 0.216184486343991, 0.22002101875841618, 0.16497922071721405, 0.06075008997868281, 0.08739636425161734, 0.12140651349909604, 0.10346659997594543, 0.21377716708229855, 0.17151348962215707, 0.16675569961080328, 0.19675635150633752, 0.13419380702544004, 0.11762555310269818, 0.12577068322570994, 0.15169094782322645, 0.12895237421616912, 0.1324979995843023, 0.12537718168459833, 0.18871049105655402, 0.14780503290239722, 0.2986257680458948, 0.14987188449595124, 0.22363081021467224, 0.15757073153508827, 0.10130694281542674, 0.2185413840925321, 0.12304998468607664, 0.298182824626565, 0.18511947593651712, 0.2713637746637687, 0.1288623220170848, 0.14951874094549567, 0.12241023854585364, 0.11409073340473697, 0.18005672260187566, 0.12047836877172813, 0.18911274994025007, 0.22577399911824614, 0.15979882213287055, 0.1425923954229802, 0.0847352750133723, 0.11914492977666669, 0.12933014222653583, 0.11644047684967518, 0.15134549292270094, 0.14166855515213683, 0.11510940530570224, 0.10341713583329692, 0.13149889069609344, 0.14628843928221613, 0.12961655185790733, 0.2310506097273901, 0.2076864501577802, 0.13838563521858305, 0.08139914309140295, 0.1535365206655115, 0.13389348954660818, 0.09731286729220301, 0.19999362935777754, 0.1285378698958084, 0.09472571822698228, 0.15584562410367653, 0.13685218000318855, 0.09974878150387667, 0.1175639548455365, 0.08135287760524079, 0.11713031053659506, 0.11729781326721422, 0.1953976126969792, 0.13160501781385392, 0.09637687064241618, 0.2026242163265124, 0.17419862444512546, 0.25837838707957417, 0.06202264688909054, 0.1590703596593812, 0.07456301304046065, 0.09574342533596791, 0.1519474043743685, 0.07602551893796772, 0.09219270883477293, 0.09659529954660684, 0.10820005496498197, 0.2418662395211868, 0.34142803691793233, 0.1515294416458346, 0.12484589300584048, 0.11767495787353255, 0.1269397884607315, 0.16882896336028352, 0.10395884426543489, 0.12802468962036073, 0.11234709454583935, 0.15456577559234574, 0.13243258668808267, 0.11907965788850561, 0.1619786286028102, 0.11796966471592896, 0.09183339803712443, 0.26075708912685513, 0.16651104320771992, 0.15754178777569905, 0.09712405008031055, 0.1853868123725988, 0.0997674984682817, 0.14736796729266644, 0.15058635006425902, 0.10663108056178316, 0.16680675937095657], [0.03365265300089959, 0.01765559118211968, 0.06026390903571155, 0.061939066217746586, 0.06089083828555886, 0.053874195655225776, 0.03154716148856096, 0.06809073573094793, 0.037009305306128226, 0.0845045709866099, 0.03674660358228721, 0.005714799181077979, 0.0151292054579244, 0.01976905707124388, 0.010935521895589773, 0.02892410175263649, 0.023302253321162425, 0.029913453254266642, 0.01665836178290192, 0.043571011410676874, 0.06168028303363826, 0.07507558475481346, 0.019838342122966424, 0.015135854173422558, 0.03780498038395308, 0.006030293579897261, 0.01386891624861164, 0.07453926431480795, 0.10493168112589046, 0.04429730681295041, 0.015427302059833892, 0.05538625846384093, 0.0111765547626419, 0.01648454894166207, 0.017425879777874798, 0.008166377810994163, 0.0661134539404884, 0.029996794582984876, 0.014969960047892528, 0.06663261592620984, 0.07891627319622785, 0.009916297094605397, 0.026417830085847527, 0.06581979352631606, 0.025521033676341176, 0.06609061805647798, 0.0062147562402969925, 0.16488263761857525, 0.03456789920164738, 0.04330338924773969, 0.046907967116567306, 0.07153027108870447, 0.01417495661371504, 0.01788708188541932, 0.02779952537821373, 0.07492416436434723, 0.022093521110946313, 0.0268858599520172, 0.02716216153203277, 0.03689593853778206, 0.023664955733693205, 0.033362217218382284, 0.014032822346052853, 0.011632947753241751, 0.020421239751158282, 0.08066513677476905, 0.03701594381709583, 0.02322074880794389, 0.03826893771474715, 0.02185023211495718, 0.06113083771197125, 0.06573219783604145, 0.056830808098311536, 0.01404813841872965, 0.022416976898966823, 0.03156075763399713, 0.03131320314423647, 0.0373747536650626, 0.05069408543931786, 0.0581121000868734, 0.039300103671848774, 0.019810018056887202, 0.021626151756208856, 0.015615633164998144, 0.010105361998284934, 0.02179215534852119, 0.038091913229436614, 0.0653398763097357, 0.035387449170229957, 0.025518176407786086, 0.052438956263358705, 0.013511688102880726, 0.025191713066305965, 0.01640403519559186, 0.027205797960050404, 0.017719170973578002, 0.04302706540329382, 0.028349269414320588, 0.1394573855213821, 0.05032255518017337, 0.055856642793514766, 0.03406864903809037, 0.0318542770401109, 0.010205696653429186, 0.04277338819520082, 0.022798815589339938, 0.05855059062014334, 0.02973492220917251, 0.025637498911237344, 0.06149067914520856, 0.04677386474213563, 0.04511084538535215, 0.0283287063575699, 0.03102153910731431, 0.08895632898202166, 0.026949192979373038, 0.03972276419517584, 0.012287101762922248, 0.007541854511146084, 0.02778214056888828, 0.05300563425407745, 0.010920855202130042, 0.053455847009900026, 0.029752015725534875, 0.049033422401407734, 0.07221934778499417, 0.027498233830556273, 0.023090179056453053, 0.017115454247687012, 0.03110742229182506, 0.028715077714878134, 0.02698539123230148, 0.04648866852221545, 0.018880728566728067, 0.061463980382541195, 0.025229961502191145, 0.020620255927497055, 0.03217806122847833, 0.05515818535059225, 0.018352187689743005, 0.020853603855357505, 0.022449868883995805, 0.04559908207738772, 0.0031641375744584366, 0.009151376616500784, 0.036036572346347384, 0.030075744252826553, 0.03630627252277918, 0.024538250181649346, 0.027933878227486275, 0.03649622893135529, 0.016024090837163385, 0.02431646305922186, 0.01279636349863722, 0.057003609763341956, 0.02604473389510531, 0.027899819215235766, 0.030166392025421374, 0.0059643083022820065, 0.10701536462875083, 0.03531162394210696, 0.09875945412204601, 0.09058040042873472, 0.07043188510579057, 0.0365950904233614, 0.06620228901738301, 0.06610306387301534, 0.03178860810294282, 0.05537590550375171, 0.03828405897365883, 0.004651342842407757, 0.01752601961925393, 0.022255962394410744, 0.0901734882791061, 0.030698890404892154, 0.06987953427596949, 0.005123573728269548, 0.027990626549581066, 0.04480136609345209, 0.0374757636745926, 0.027163519662281033, 0.021545897761825472, 0.06843684372142889, 0.03680294372315984, 0.05770148833107669, 0.013834146629960742, 0.06613162913708948, 0.00884085089637665, 0.019129782194795553, 0.07736914762062952, 0.05208361595578026, 0.02705237377085723, 0.027347039795131423, 0.03465089728706516, 0.016951758734649047, 0.05346122386981733, 0.01314616738454788, 0.06949604430701584, 0.0716878884122707, 0.01655411600950174, 0.03865392311126925, 0.07182792425737716, 0.017302744490734767, 0.04451536835404113, 0.017425002188247163, 0.033881052659126, 0.04383991748909466, 0.0047395146248163655, 0.05599529824394267, 0.06033387500792742, 0.04405239065818023, 0.016338792993337847, 0.0368273863568902, 0.07634684661752544, 0.08991167342173867, 0.038295699559967034, 0.03413421036384534, 0.05201604340982158, 0.032949560845736414, 0.050576555222505704, 0.004123147527934634, 0.03754419340111781, 0.06287253956543282, 0.10053419639007188, 0.012572905616252683, 0.08018841821467504, 0.009191467433993239, 0.07209621064248495, 0.007918705505289836, 0.05646124824124854, 0.009800559164432343, 0.04660920814785641, 0.05373461252020206, 0.03860839977278374, 0.02843933460098924, 0.13465827272739261, 0.012652992627408821, 0.009750719309522538, 0.04091522852831986, 0.06359131701174192, 0.04057368103531189, 0.10006716285715811, 0.07790021365508437, 0.007654184128114139, 0.016561312986596022, 0.04645878965675365, 0.13193073158618063, 0.021979250777803827, 0.060049294770578854, 0.017629536232561804, 0.033868584578158334, 0.04874946185736917, 0.02431817185424734, 0.014377290190168424, 0.04457115188415628, 0.02334424960281467, 0.016152675343619194, 0.08663214510306716, 0.0644314727105666, 0.05062332536908798, 0.04133860522415489, 0.01568634128489066, 0.029489115477190353, 0.11681422241963446, 0.03939391113817692, 0.03276992771134246, 0.13839419960277155, 0.08373042190214619, 0.026040284719783813, 0.019961238067480735, 0.06994427181780338, 0.03568319873011205, 0.06606839073356241, 0.05484099885507021, 0.09002519233035855, 0.03900930423696991, 0.03404631781450007, 0.06188219915202353, 0.019421225442783907, 0.04389026107673999, 0.03203816639143042, 0.036367796565173194, 0.013108118400850799, 0.04145097380387597, 0.06135999065008946, 0.05308137413521763, 0.019355142758286092, 0.08203483710531145, 0.019972021473222412, 0.011439760219218442, 0.024186633600038476, 0.027974284457741305, 0.041342293698107824, 0.005692860368071706, 0.03765300709346775, 0.010333230093237944, 0.04953368188580498, 0.04721324956335593, 0.04781095303769689, 0.05162488334462978, 0.06615657272050157, 0.07785915062413551, 0.032467547061969526, 0.027012318205379415, 0.06100499173044227, 0.041043924356927164, 0.012417270754667697, 0.047304348190664314, 0.07049942796584219, 0.020149391057202592, 0.0665535920416005, 0.027141522405145224, 0.058258047138224356, 0.018280266158399172, 0.06415436961106025, 0.013667066923517268, 0.029106436304573435, 0.0320539296080824, 0.04745485945022665, 0.04994965194782708, 0.03078277164604515, 0.02109823799401056, 0.07033977715764195, 0.04769996114191599, 0.03003135268954793, 0.03159685940772761, 0.02973644917801721, 0.004901123775198357, 0.03304137564555276, 0.04190425905107986, 0.050116828133468516, 0.018709004871197976, 0.027922126319026574, 0.07370216626441106, 0.07194266028818674, 0.011345802467985777, 0.04455329952179454, 0.046473940601572394, 0.03877026589179877, 0.05737193765526172, 0.06964410276850685, 0.01579886200488545, 0.051377588606555946, 0.04848556898650713, 0.08525877856300212, 0.035793908609775826, 0.034727464662864804, 0.009503733490419108, 0.019610157687566243, 0.008124966898321873, 0.009368290611746488, 0.06723898026393726, 0.15059375669807196, 0.1431610289728269, 0.13444526150124148, 0.14284123753895983, 0.23826434451621026, 0.137105445319321, 0.1412510228692554, 0.16395973245380446, 0.1759698340902105, 0.12893575010821223, 0.20413088001077995, 0.09766990711796097, 0.07283124112291262, 0.1641935238149017, 0.1330683846026659, 0.07012979389401153, 0.11863806517794728, 0.08307953612529673, 0.16271298372885212, 0.09677990135969594, 0.15236225008266047, 0.15958162519382313, 0.15325684973504394, 0.1346231542993337, 0.10208089894149452, 0.13564794149715453, 0.10809117447934113, 0.12283141477382742, 0.16920552909141406, 0.2025017619598657, 0.17760088172508404, 0.11192755846423097, 0.15593377640470862, 0.15015517710708082, 0.23369578731944785, 0.08110834736726247, 0.12251891865162179, 0.18534212023951113, 0.2280814401456155, 0.24252900708233938, 0.14626675372710451, 0.11725462769391015, 0.12697170081082731, 0.09209022566210479, 0.15947036241414025, 0.2842626872006804, 0.09373182663694024, 0.20148038864135742, 0.09205668800859712, 0.103750115231378, 0.15249601477989927, 0.20086949720280245, 0.0910320937691722, 0.19249743316322565, 0.08635988822788931, 0.18799973622662947, 0.22665148484520614, 0.11797408791608177, 0.1295199984451756, 0.21825878910021856, 0.12089524796465412, 0.09047100043972023, 0.1674938842188567, 0.16844693542225286, 0.0865845289081335, 0.1520644559059292, 0.14045928488485515, 0.09469860757235438, 0.12408279450028203, 0.19077517557889223, 0.2644615340977907, 0.14823923382209614, 0.1172146481985692, 0.09011017566081136, 0.16208482993533835, 0.12870823731645942, 0.21900598338106647, 0.10535866094869561, 0.09384805438457988, 0.12124994260375388, 0.13285040098708123, 0.13392979541094974, 0.13212291814852506, 0.12333824226516299, 0.2152746875071898, 0.1780237871571444, 0.12285223943763413, 0.13072796253254637, 0.2087211821344681, 0.19894577621016651, 0.17540609871502966, 0.17197782173752785, 0.11580522812437266, 0.09275169446482323, 0.19899230886949226, 0.24687214434379712, 0.16603519296040758, 0.19083897059317678, 0.22219169681193307, 0.15995642461348325, 0.23767371370922774, 0.19622481049736962, 0.0770971059682779, 0.1580914668738842, 0.14523513877065852, 0.10295806554495357, 0.13885266875149682, 0.13648981897858903, 0.17521058733109385, 0.1528593702823855, 0.15040961501654238, 0.2557967521715909, 0.11990313010755926, 0.11953560373513028, 0.228117048391141, 0.1297622502897866, 0.11587510132812895, 0.12010464546619914, 0.09867360990028828, 0.10403029824374244, 0.17503830516943708, 0.15503539179917425, 0.19281389977550134, 0.1535399939166382, 0.1493393786950037, 0.19054637145018205, 0.18442728964146227, 0.10141370818018913, 0.16686515155015513, 0.13752308150287718, 0.07882285164669156, 0.13211399753345177, 0.14248785650124773, 0.2502938755787909, 0.20327047852333635, 0.13829436589730904, 0.13399068120634183, 0.14040047710295767, 0.25309085205662996, 0.1523560011992231, 0.14066566131077707, 0.2270977382431738, 0.15733312553493306, 0.14162046398269013, 0.2288639309699647, 0.16209706052904949, 0.18414831632981077, 0.1387744167004712, 0.12450125446775928, 0.12463518243748695, 0.13353298389120027, 0.13794895552564412, 0.1582982885884121, 0.09681250390713103, 0.1280241849599406, 0.17011075629852712, 0.09315588293247856, 0.1344237243756652, 0.19541291578207165, 0.2062762062996626, 0.08833826097543351, 0.26236098899971694, 0.15025226486613974, 0.1612557767657563, 0.12288142068427987, 0.14460027596214786, 0.10586434553260915, 0.08624719310319051, 0.12317079890635796, 0.17894446587888524, 0.12033163133310154, 0.09832609925069846, 0.11492680729134008, 0.16774073737906292, 0.14906787138897926, 0.1882887730607763], [0.06719845157931559, 0.08062875669565983, 0.00889597948116716, 0.04068111433298327, 0.013131160230841488, 0.005824580448461347, 0.025058811115741264, 0.03667038872663397, 0.028472627345763613, 0.013082019850116922, 0.016806711537356023, 0.036350571317598224, 0.0039304563051700825, 0.07574078656034544, 0.04282929417968262, 0.007216198719106615, 0.024031086868490092, 0.05159775784704834, 0.018732838943833485, 0.020555804112518672, 0.02838749744114466, 0.021956080927338917, 0.018190436603617854, 0.032315377102349885, 0.060610952132265083, 0.0116392226118478, 0.04481958210817538, 0.04396770047605969, 0.02163259545341134, 0.10193508176598698, 0.019198616391804535, 0.006035311425875989, 0.04133800037379842, 0.06154219532618299, 0.08159065429936163, 0.06363594235153869, 0.05686299133230932, 0.028166873635200318, 0.08004333576536737, 0.042435395589563996, 0.008900464836187894, 0.05877261151908897, 0.01380210440402152, 0.020044529301230796, 0.02973324866616167, 0.01932695413415786, 0.021287281560944393, 0.024496055375493597, 0.0897790516319219, 0.03802697901846841, 0.05072089552413672, 0.016642427872284316, 0.02408135995210614, 0.04401455968036316, 0.03976799809606746, 0.02496335051546339, 0.03257490614487324, 0.05115013518661726, 0.0575609255611198, 0.0812273655901663, 0.014349108987516956, 0.020515553733275738, 0.022727869982190896, 0.05137251973792445, 0.047333611073554493, 0.062402478069998324, 0.052081556495977566, 0.01686278079432668, 0.01590069765370572, 0.032480697918799706, 0.07999420558917336, 0.05932264313742053, 0.06489334089565091, 0.02159525243769167, 0.04297073268389795, 0.03930081242287997, 0.062364665645873174, 0.03397341293748468, 0.0710715570312459, 0.0047652518424001755, 0.06528924699523486, 0.05943297452176921, 0.05045092817454133, 0.02474871955200797, 0.023387095643556677, 0.04352965152065735, 0.010107224788953317, 0.048167373170144856, 0.03287608451501001, 0.08087691603577696, 0.04446134371391963, 0.0321940025605727, 0.06055981444660574, 0.006064659191906685, 0.009080713025468867, 0.03271713874710258, 0.03674949795822613, 0.07863871738663875, 0.056448490722686984, 0.04126368912693579, 0.056165120186051354, 0.022570319451915566, 0.015013601114333142, 0.058989956887671724, 0.04421122881467454, 0.0630045824800618, 0.05312412555213086, 0.03721906592545565, 0.022074223415984306, 0.067625550145749, 0.07377626228844747, 0.06605565547943115, 0.042301564099034294, 0.033862951677292585, 0.04022591434477363, 0.03817009106569458, 0.09023609585710801, 0.0645180071296636, 0.04828016106330324, 0.02484441763954237, 0.049140447517856956, 0.0388411929452559, 0.024692151200724766, 0.10998836369253695, 0.018653297411219683, 0.010493223217054037, 0.10111022915225476, 0.044454964954638854, 0.014460676975431852, 0.01353815679976833, 0.10158763790968806, 0.01560718195833033, 0.00558126594114583, 0.07989714009454474, 0.05412382073700428, 0.058520875027170405, 0.03569757784134708, 0.029933760270068888, 0.053723803139291704, 0.04103434694116004, 0.044937939819647, 0.03816643227764871, 0.0335537655337248, 0.046316735169966705, 0.016532259760424495, 0.02103504040860571, 0.03991655008576345, 0.0019409978426665475, 0.03944339754525572, 0.0926537012855988, 0.011308133834972978, 0.02979600652906811, 0.03249191177019384, 0.006302177062025294, 0.029960815263621043, 0.03598987270379439, 0.0671544941724278, 0.031418996295542456, 0.02043007316387957, 0.08853944978909567, 0.032001240833778866, 0.05555401723540854, 0.04069525224622339, 0.028364093814161606, 0.03883826146193314, 0.021745819358329754, 0.06274488274357282, 0.032481317612109706, 0.03762693544558715, 0.011672327036649222, 0.07862305064918473, 0.04077931160281878, 0.03022173583303811, 0.014136317622615024, 0.05936378409387544, 0.03299477248219773, 0.01297027374675963, 0.007349943471126608, 0.0013064227323411615, 0.06184029749420006, 0.039840761965024285, 0.048890655452851206, 0.04136964926146902, 0.07656968387891538, 0.014416908816201612, 0.048493903304915875, 0.009862271526799304, 0.013261838521430036, 0.0470873701851815, 0.04512124658504035, 0.018471673465683125, 0.025067913556995336, 0.0481229444994824, 0.08659007275127806, 0.04105378007807303, 0.044083575703552924, 0.008058916682784911, 0.0499271166336257, 0.006544933567056432, 0.017429974577680696, 0.011120670114905806, 0.04767854647070635, 0.007661280451429775, 0.04306058821384795, 0.034823598762159236, 0.03556465919245966, 0.019288724251964595, 0.008989116231532535, 0.05036738461058121, 0.06006468691339251, 0.041625953672337346, 0.08106791516183876, 0.05401064321631566, 0.04393235198222101, 0.06830499376519583, 0.04804019503353629, 0.029434179850795772, 0.05858136006281711, 0.024699808309378568, 0.02557400075602345, 0.004370811948319897, 0.06332791395834647, 0.008854141833580798, 0.09294276038417593, 0.03355222928803414, 0.05827126107760705, 0.015547218281426467, 0.035796305746771395, 0.0701521102746483, 0.04544554656604305, 0.03369760488567408, 0.03791061397350859, 0.0782596728822682, 0.049124966317322105, 0.039829985980759375, 0.05761522479588166, 0.0274687705677934, 0.06567303382325917, 0.04437708397745155, 0.04632177064195275, 0.07886119099566713, 0.08394992692046799, 0.018722536078712437, 0.022818838733655866, 0.023511136350862216, 0.04254269901139196, 0.027003115574188996, 0.03307635306555312, 0.02798542223899858, 0.0647485998342745, 0.015973812187439762, 0.03868534564389847, 0.04823414419661276, 0.027288013079669327, 0.013560526058427058, 0.03273351423558779, 0.04259692403138615, 0.08930407711886801, 0.10499417738174088, 0.007854718460293952, 0.04482309246668592, 0.02372501588979503, 0.012042110465699807, 0.049669754662318155, 0.05121552952914499, 0.028324618979240768, 0.04215730914438609, 0.06883086476591416, 0.030039314078749157, 0.03486484361928888, 0.040797264155116864, 0.07809854520019144, 0.016418019113189075, 0.06284622300881892, 0.04010565302451141, 0.0837694811343681, 0.04957507146173157, 0.061315220591495745, 0.06885793089168146, 0.006758032459401875, 0.03239079785998911, 0.03614855872001499, 0.03152004712319467, 0.025299639892182313, 0.040145235470845364, 0.045366073682089336, 0.023062385625962634, 0.08551846345653757, 0.015185742267931346, 0.04258846725861076, 0.03266036816057749, 0.045966218822286464, 0.06914368743309751, 0.09322712168795988, 0.03307958511868492, 0.02590031010186067, 0.05758717903518118, 0.1153948724095244, 0.047463668743148446, 0.03483636741293594, 0.025697716773720458, 0.02890983767429134, 0.05173565630684607, 0.04007768518931698, 0.03670419355330523, 0.03152839999529533, 0.05997836771712173, 0.0048952928136714036, 0.08988795438199304, 0.05956551467534155, 0.02209060447057709, 0.06306541632511653, 0.03442822700890247, 0.04017458370071836, 0.03213147290807683, 0.07515140256145969, 0.04697155061876401, 0.04390662914374843, 0.03461965658061672, 0.0385504009318538, 0.03624471508373972, 0.0255586086132098, 0.01895062960102223, 0.024343985605810303, 0.04653108226193581, 0.06317157312878408, 0.06359981460263953, 0.03534066418069415, 0.07146208998165093, 0.027311821177136153, 0.0305917836521985, 0.03750644777028356, 0.0770498534257058, 0.020324940524005797, 0.010785425311041763, 0.03185443660186138, 0.012139622176619014, 0.033879408802022226, 0.009604200804460561, 0.03488546790322289, 0.03735899786988739, 0.04521975184616167, 0.03210061440768186, 0.030498349115077872, 0.05162454195669852, 0.02468373153533321, 0.07369051454588771, 0.035844734593410976, 0.07442694768542424, 0.01533348067823681, 0.01465878031012835, 0.018654056257219054, 0.15270544885424897, 0.20107608143007383, 0.06085107772378251, 0.1322116344817914, 0.09893453418044373, 0.341898855403997, 0.12131201583542861, 0.1618787503684871, 0.13084323290968314, 0.15277231635991484, 0.07256207900354639, 0.10256178837153129, 0.10482278579729609, 0.2097814588341862, 0.14738867321284488, 0.09381853175000288, 0.11619995420915075, 0.2132821100531146, 0.1322109517059289, 0.12499218515586108, 0.09044785285368562, 0.12916753767058253, 0.13594273739727214, 0.1310501733678393, 0.1723970758030191, 0.15643306367564946, 0.13187702978029847, 0.16726898378692567, 0.0799492240184918, 0.1485557301202789, 0.0834265272715129, 0.09725473486469127, 0.09595444018486887, 0.15649685868993402, 0.17014605284202844, 0.16674820391926914, 0.16037683642935008, 0.16215284034842625, 0.21523026254726574, 0.1386205546441488, 0.11663240366033278, 0.15788148361025378, 0.12200918936287053, 0.130806214583572, 0.1898574802908115, 0.1369162421906367, 0.0885171111440286, 0.16708003298845142, 0.127962393744383, 0.11142778137582354, 0.15702621778473258, 0.1512084627756849, 0.18558959680376574, 0.17739104689098895, 0.1110315635742154, 0.07081153817125596, 0.11274659264017828, 0.19604127737693489, 0.11593077724683098, 0.1851570582948625, 0.1331623998703435, 0.11312003392959014, 0.22910362982656807, 0.15299314982257783, 0.19801737915258855, 0.14930664998246357, 0.11661133408779278, 0.13561270432546735, 0.14815171976806596, 0.17811993981013075, 0.11635795744950883, 0.09747822521603666, 0.14288898732047528, 0.16655212850309908, 0.11440728907473385, 0.17813277896493673, 0.14943320100428537, 0.14042421098565683, 0.217895953101106, 0.083381842559902, 0.10036785140982829, 0.20924188778735697, 0.30568644229788333, 0.06043142289854586, 0.09684435688541271, 0.17906185879837722, 0.18525690684327856, 0.15571816766168922, 0.22034548572264612, 0.10729753659688868, 0.11806109730969183, 0.2262969163712114, 0.15997557202354074, 0.2093590729054995, 0.12399019673466682, 0.14676411141408607, 0.10718191741034389, 0.1904369195108302, 0.1413622559630312, 0.14663074747659266, 0.15596586687024683, 0.14701155829243362, 0.13560385792516172, 0.1638482470298186, 0.10431555012473837, 0.06998093391302973, 0.12914684659335762, 0.14520184602588415, 0.16654583509080112, 0.2002259809523821, 0.1388451730599627, 0.19317666155984625, 0.11918438234715723, 0.14298748516011983, 0.19126576487906277, 0.12304530915571377, 0.16819212643895298, 0.19413521949900314, 0.1314882334554568, 0.08151770118274726, 0.1299077260773629, 0.17591153096873313, 0.16200639976887032, 0.20098086388316005, 0.12475592986447737, 0.06266345430049114, 0.14322949951747432, 0.2145731946802698, 0.1561724956263788, 0.15335669828346, 0.21279683453030884, 0.07963657204527408, 0.17831178498454392, 0.207527496968396, 0.14368825068231672, 0.15144817647524178, 0.13706293510040268, 0.14521208766382188, 0.12149409434641711, 0.12433980766218156, 0.18624166259542108, 0.14423971093492582, 0.14683409593999386, 0.13262052816571668, 0.09969231148716062, 0.11309012537822127, 0.1595925644505769, 0.15896892291493714, 0.11318004399072379, 0.2051416554604657, 0.12617016647709534, 0.12447378016076982, 0.15745887503726408, 0.1142280975182075, 0.13656431576237082, 0.08794239940471016, 0.23145573330111802, 0.09255745957489125, 0.08796143549261615, 0.1459335145773366, 0.08684575004735962, 0.22273683396633714, 0.09413478313945234, 0.15507352334680036, 0.10074727440951392, 0.05923535172769334, 0.1355141619569622, 0.10073556331917644, 0.1672895858064294, 0.15097431518370286, 0.21306090551661327, 0.1292942519648932, 0.19970839231973514, 0.07319182099308819, 0.11316473348415457, 0.18912275409093127], [0.0485327621572651, 0.06220177536306437, 0.03111775113211479, 0.04029416595585644, 0.04176398571871687, 0.054618098511127755, 0.07873102571466006, 0.07806088862707838, 0.031028932753542904, 0.04493837768677622, 0.006265976026043063, 0.020649452017096337, 0.04240740920067765, 0.051138201451976784, 0.01974773702386301, 0.032259916406474076, 0.03265985978941899, 0.01850887361797504, 0.08193673260393552, 0.01652968265261734, 0.0774182406894397, 0.05214469842030667, 0.028196956591273192, 0.014997029884398216, 0.042359091676189564, 0.026647890299500432, 0.0861722361878492, 0.047261270228773355, 0.03247033011575695, 0.03620780807978008, 0.05754121782956645, 0.0725245189096313, 0.037071812694193795, 0.02016894479311304, 0.033535883485456, 0.06491871492471546, 0.012957269464095589, 0.04901233427517582, 0.013126572830515215, 0.030237300525186583, 0.049926994179259054, 0.017004794462991413, 0.023525194483227096, 0.019996712726424448, 0.0341098085482372, 0.03902263691998087, 0.029394547309493646, 0.10356255967053585, 0.021363652267609723, 0.05150744960701559, 0.028487937852332834, 0.037731715565314516, 0.06442857833462767, 0.011165631276526256, 0.06775977497454733, 0.07196195612777956, 0.014545612066285685, 0.08090186704066582, 0.04744295169075485, 0.07283243598067202, 0.042653857890400104, 0.029451009904732928, 0.07672321939026006, 0.030715011707798112, 0.0471436954831006, 0.028275258737266995, 0.04977011529263109, 0.05723906353523489, 0.029216153561719693, 0.007857000564399641, 0.015140794093895238, 0.03685158408188727, 0.014455099735641852, 0.05569717010075692, 0.04609488125424832, 0.018431235694151837, 0.09870139590930194, 0.07156777181080543, 0.10669842304196209, 0.05438554653665051, 0.02201179951953236, 0.043504336863406934, 0.04249322744726669, 0.017547024253872223, 0.04446037521120161, 0.03846271247311961, 0.06151571920781862, 0.04431891815329436, 0.027594551611400675, 0.09702322189696133, 0.020423516289156396, 0.06862266265670769, 0.03465450041403528, 0.01741219271934824, 0.07468409443390556, 0.04272481834050268, 0.007482014216293464, 0.028632903413381428, 0.03396179461560678, 0.0896913223550655, 0.07074450739310123, 0.029287256875250023, 0.012630476794583956, 0.03875822454574518, 0.018685137401917018, 0.025048324569070246, 0.01665376046730671, 0.03771654977754224, 0.04882642628217582, 0.05537148601433728, 0.06429827946703881, 0.04945346685417462, 0.036021254418301396, 0.03279548356658779, 0.017444745171815157, 0.033936235049623065, 0.024216445672209375, 0.03138612657494377, 0.06369922528392635, 0.04856685642153025, 0.01909137976326747, 0.08716420561540872, 0.03304634432424791, 0.02150266580429161, 0.028602544007299002, 0.03419728178414516, 0.030361725293914787, 0.02173716035031248, 0.050763450271915644, 0.014292998912424082, 0.03083934927417431, 0.05070831241027918, 0.051410328451311216, 0.03405349809327163, 0.03910585022822488, 0.04075459437444806, 0.042851747857639566, 0.03729356641997583, 0.05101216993352864, 0.06825900287367404, 0.08583510818425566, 0.15755054511828348, 0.040722192206885666, 0.06894364152685739, 0.034635282499948516, 0.06342963271890767, 0.03576116876502056, 0.017483117917436175, 0.03718650419614278, 0.0075264145925757475, 0.0240047480474459, 0.024415287443844136, 0.015120345142349834, 0.1038431805500295, 0.0024117978909998783, 0.019678680182551034, 0.025537108595017344, 0.024543335748603567, 0.028520636878965888, 0.016220348079514224, 0.02628677979373606, 0.038341215476975776, 0.04769142273289617, 0.05462739020003937, 0.0611620561539894, 0.012067851857864298, 0.041814845098997466, 0.06724341088556685, 0.037819263015990146, 0.026567037020868156, 0.02849713677278487, 0.08041440218221396, 0.05173771205591038, 0.055728767038090155, 0.046559951806557365, 0.033034299267455935, 0.04842708403884899, 0.0071749014477973105, 0.011662424003588967, 0.056649534817552194, 0.05297207804687787, 0.037725826623500325, 0.06853246944956481, 0.06488111772341654, 0.0330214712448651, 0.032717910580686294, 0.018007688304351177, 0.0030419067797993193, 0.018734443838184234, 0.032890207585296594, 0.022234011521504726, 0.02363080024224473, 0.07036336261080578, 0.013241458218544722, 0.045515130332205445, 0.0659992967848666, 0.05319028801750392, 0.07457427142071538, 0.058460616346565075, 0.014724538305017632, 0.0366867827688111, 0.06833574836491607, 0.1739478824310936, 0.06336674312478863, 0.04067212692461908, 0.02557800464273896, 0.033008639511535875, 0.1391254080226645, 0.05360033945180476, 0.05428866657894105, 0.03107425571215572, 0.0747731669980567, 0.04012003213574644, 0.15368309483164921, 0.07302909769350663, 0.055094468261813745, 0.10216574126388878, 0.020169375238765497, 0.04899205880064983, 0.03481475607259199, 0.02470435581926722, 0.059826357319252566, 0.05862743259058334, 0.04539309527899604, 0.038126790459500626, 0.03766898553294595, 0.060888656371389516, 0.022686474840156734, 0.04923433662042953, 0.05137565531185828, 0.06315121601801366, 0.01739390063448809, 0.06780227035051212, 0.05621800934022758, 0.05907381586439442, 0.03968620971136261, 0.038197513422346674, 0.04002239147666842, 0.08772682034759782, 0.048007043296820484, 0.05695613086572848, 0.018551009052316658, 0.04236734064761549, 0.0118418400597875, 0.0549101855722256, 0.03143780973914545, 0.05358977497962769, 0.0026105624328920385, 0.0067535897778725484, 0.020929638740199152, 0.05556698626605794, 0.029128650639904663, 0.027356203463568818, 0.04822480055736378, 0.047592965711373836, 0.034543530782684684, 0.05790415401861537, 0.0269642288913019, 0.0048690718085708795, 0.02299645508173853, 0.058663519521360286, 0.012321825925027952, 0.026483721667318605, 0.02900660259911092, 0.07496974707464688, 0.018610805745993275, 0.038751240936107934, 0.04113500071980525, 0.0563431168848183, 0.038770039536757395, 0.004049401240990846, 0.03972322432673536, 0.05647703001159243, 0.025375144141435158, 0.015313889834942529, 0.06259303190745413, 0.10537626469158567, 0.025185447484545875, 0.04913115582894534, 0.005931435798629536, 0.02894292261771625, 0.029009686222707387, 0.03411626152228564, 0.06846019910881296, 0.0641497534525115, 0.015991430773283355, 0.03871303517371416, 0.017253165315196384, 0.04087716748472303, 0.016552401648368686, 0.03059177066461416, 0.010375541787652764, 0.01787026852980489, 0.030773355647397693, 0.024328331855940633, 0.03315402995212935, 0.022174461591930594, 0.027213204593863338, 0.11169638688443229, 0.005578017189691309, 0.012038952627335675, 0.0038001054872438544, 0.02788351608614903, 0.026809032824530732, 0.05687958204362076, 0.07069871688145213, 0.010273055831930833, 0.062426634976873174, 0.011936586342926603, 0.06813468571635894, 0.03889118401275482, 0.02366807275393512, 0.04760866955621168, 0.00862090615555644, 0.07123766452423297, 0.03583400684874505, 0.034139802446588874, 0.027063216548413038, 0.02790994396491442, 0.08465723076369613, 0.029803188663208857, 0.013135518493072595, 0.02036087345913984, 0.055864457608549856, 0.02827683765644906, 0.0743206572951749, 0.04399435470986646, 0.03980341709393542, 0.034659851298783906, 0.06294604929280467, 0.025568883647792973, 0.023523715753981378, 0.0370263747026911, 0.06927409762283787, 0.03402950816962402, 0.029589917685370892, 0.01422259785613278, 0.06338859937386587, 0.009499334410065785, 0.017295439902227372, 0.0925544390338473, 0.03791531918977853, 0.0031743588033350534, 0.011192709462193307, 0.032817818500916474, 0.05475674654007889, 0.05718614840588998, 0.03466267517069355, 0.04868601194175426, 0.0280351702531334, 0.043602445075521246, 0.05105403448396828, 0.2193109318614006, 0.19648144516395405, 0.0908649769553449, 0.1674022141378373, 0.1463878425420262, 0.17570948868524283, 0.14387638511834666, 0.1608374874922447, 0.15107680577784777, 0.08752143097808585, 0.07583591504953802, 0.0709763914346695, 0.15611839306075126, 0.16617768531432375, 0.11082083816290833, 0.09319866032456048, 0.1646799422451295, 0.09994305350119248, 0.08745722778257914, 0.15636950614862144, 0.2804035192821175, 0.11014229254215024, 0.12499162112362683, 0.08195439571863972, 0.10751146066468209, 0.1745689709787257, 0.2050965031958185, 0.1838114851852879, 0.09452570200664923, 0.14672611345304176, 0.13852282863808796, 0.2577724086586386, 0.25472051929682493, 0.11175739884492941, 0.16614344262052327, 0.22538279823493212, 0.1493468150147237, 0.16874844033736736, 0.18198290752479807, 0.11796789840445854, 0.244278397585731, 0.2066165700671263, 0.12324048657319508, 0.20332833635620773, 0.1931921427603811, 0.18610289582284167, 0.1314410922350362, 0.11366074046236463, 0.17012280877679586, 0.19724036537809297, 0.1502388171502389, 0.15388086234452203, 0.18607797450385988, 0.09350488529889844, 0.10925398630206473, 0.2412013048888184, 0.16604878910584375, 0.17100014607422054, 0.18600056850118563, 0.15797205531271175, 0.11516546714119613, 0.1212080632103607, 0.20014622976304963, 0.10941613814793527, 0.12004217889625579, 0.1364299573469907, 0.13150962215149775, 0.09798644052352756, 0.12483185157179832, 0.18065535376081243, 0.15954760514432564, 0.17627343186177313, 0.06840484231361188, 0.09114674074226059, 0.174387026054319, 0.09962910276954062, 0.14406477188458666, 0.18334036984015256, 0.1685988827375695, 0.15654895745683461, 0.15531323704635724, 0.1010219581075944, 0.1934711160720326, 0.08289534249342978, 0.09995320608140901, 0.11932628098293208, 0.16447243775473908, 0.18620391696458682, 0.2063613900099881, 0.22890725755132735, 0.10093165357830003, 0.11840343518997543, 0.18680477456655353, 0.13179904490243644, 0.19519343302818015, 0.12377088467474096, 0.21759237017249689, 0.11834925840958022, 0.15494020393816754, 0.17140420095529407, 0.19729740684852004, 0.06827480319770984, 0.1647689109086059, 0.14399514358956367, 0.17850155214546248, 0.11211273915250786, 0.17631174152484164, 0.1296270012971945, 0.12824571604141966, 0.11625542974798009, 0.21398542856331915, 0.08873093131114729, 0.19820558780338615, 0.1479101210134104, 0.17483666364569217, 0.15059659170219675, 0.11136191576952115, 0.09678502960014157, 0.21129460888914764, 0.08320438020746224, 0.20080497488379478, 0.13174847495974973, 0.19937163538997993, 0.07504152017645538, 0.09586559026502073, 0.13436286826618016, 0.11041918784030713, 0.07338304276345298, 0.10994668467901647, 0.24464785354211926, 0.11560918239410967, 0.15652771719032899, 0.1454035023925826, 0.18944443057989702, 0.20465023495489731, 0.1531163463369012, 0.19925599393900484, 0.0838961212139111, 0.16110391850816086, 0.2218979102326557, 0.17611934716114774, 0.37541777710430324, 0.13395657209912315, 0.2701053296914324, 0.06832709492300637, 0.2322952655958943, 0.11825395922642201, 0.06515690722153522, 0.13600093661807477, 0.14629709272412583, 0.1749287048005499, 0.08858457236783579, 0.10297077853465453, 0.20025842764880508, 0.056654815198271535, 0.11911315101315267, 0.12366924755042419, 0.1066779026587028, 0.10201181241427548, 0.1783533749403432, 0.10674177188775502, 0.18704282585531473, 0.12903151684440672, 0.15148213715292513, 0.13404935540165752, 0.08171011038939469, 0.09499732943368144, 0.17801266978494823, 0.12427776411641389, 0.09590850866516121, 0.10167623549932614, 0.17354899289784953, 0.1322098236414604, 0.1669668999966234, 0.11002570114214905, 0.11411915023927577], [0.03655858046840876, 0.03886052218149416, 0.06499700408312492, 0.0662309952895157, 0.014229241005523363, 0.02348964560951572, 0.03387191682122648, 0.012944214158778777, 0.06473274013842456, 0.021984959748806432, 0.09288321787607856, 0.04238857720338274, 0.034756408422254026, 0.10356871949625202, 0.027016539170290343, 0.04885968934104312, 0.10509115381864831, 0.06505418656161055, 0.03253824404964689, 0.02103583450661972, 0.06503233773401007, 0.03807402747042943, 0.02813182756653987, 0.02905428373196628, 0.05740608386986423, 0.031345824245363474, 0.002820500239977264, 0.02752491218416253, 0.014574839697161224, 0.019102222540823277, 0.050935494946315885, 0.03538523014867678, 0.04798181398655288, 0.020543460341286846, 0.06497997179394588, 0.03378049535967875, 0.028120851202402264, 0.054221509635681286, 0.03979956905823201, 0.02948314304376254, 0.02287847215484362, 0.038495174012496136, 0.02805183146847412, 0.07143754715798423, 0.03723947498656344, 0.004617180393324816, 0.00220481313590426, 0.055442171869799495, 0.038086083659436554, 0.026860491489060223, 0.03914416360203177, 0.05584089441981632, 0.03095581821980886, 0.04919604922179133, 0.045787483686581254, 0.07207673668744974, 0.027229357438045554, 0.030352081084856763, 0.030530339390679728, 0.04964600222592708, 0.04083412291947752, 0.047078920833882876, 0.07443042093655095, 0.02581329143140465, 0.008958319886005484, 0.07223992754006758, 0.02953813618660206, 0.021702605954487808, 0.08282267139293253, 0.0871957691560965, 0.04464616817131173, 0.028637883224291727, 0.058235816104570404, 0.018277709459653124, 0.032118062299559824, 0.020541129997582175, 0.010334883227187674, 0.06949660091777332, 0.023002843117865268, 0.03975997547968291, 0.020275891984056216, 0.04561091191135347, 0.038132571789901704, 0.03515063726808876, 0.0322782363218721, 0.02244483526737895, 0.03032846037967829, 0.058170533084194176, 0.0338135506171966, 0.03201017629180569, 0.009595752380846534, 0.03935970555176027, 0.06866967771202326, 0.04047985501529183, 0.024280435500259046, 0.017215018924616743, 0.062058782059466466, 0.01862654484284576, 0.04200793708150741, 0.05297240459185559, 0.050387849332764745, 0.032344799546990544, 0.03869614389259368, 0.04725126607809216, 0.03175971258315258, 0.05143345377291553, 0.02583710138424067, 0.03834845883829985, 0.03679534413095098, 0.04535662985290401, 0.010550269325904083, 0.02367409528233111, 0.04433280373632442, 0.008630580978206126, 0.10475047092768364, 0.04995171882910654, 0.031433464464498684, 0.039038745235302486, 0.057107176471618004, 0.028013840928906575, 0.02682599089894211, 0.022913546054041944, 0.0778592396818567, 0.015786598014528863, 0.023894735786598176, 0.03524255967931822, 0.030505308604915626, 0.016081186113297008, 0.011732483671949012, 0.07646208730875514, 0.054151243093656376, 0.0418955091299722, 0.04415960873302538, 0.02001019940507831, 0.010768518259283155, 0.021459155541379005, 0.012133200743846828, 0.029104909335728735, 0.04956247721565887, 0.06376703531714156, 0.033351983001921326, 0.0618270761333406, 0.03276968280260917, 0.01998969015403418, 0.040009812073549256, 0.027262457224423997, 0.004996081106583006, 0.045660539326490834, 0.02837348383764038, 0.019824664341285825, 0.023016494924377184, 0.04839283021283336, 0.031070899349288084, 0.03844935752567835, 0.022408449622162152, 0.03581667770049535, 0.02626629466249142, 0.004840258852709667, 0.06621390362852253, 0.026425928772368934, 0.022694734943797812, 0.033374774357071146, 0.039785564731573686, 0.0485537426720839, 0.017376920295646414, 0.055742756521794945, 0.048349700300605036, 0.0603117033460876, 0.016296214125759434, 0.0028043320889992174, 0.04681393700593617, 0.029940851491119247, 0.014815110935160192, 0.013972705601190683, 0.007314302756640245, 0.02191224783018697, 0.003281574327047565, 0.01572964189108461, 0.04502826661337167, 0.10880082350922748, 0.015225227307382738, 0.03332238244183827, 0.019867341543431394, 0.024686575816303957, 0.003522267661537626, 0.03368650606716983, 0.06028112315107137, 0.05272522117593326, 0.044264696844038554, 0.07703818686422892, 0.09074229252291843, 0.007362919459410477, 0.025918988103512675, 0.03940171853173524, 0.054851926979608834, 0.006295894781942479, 0.03973692437284626, 0.013413390643108869, 0.05693914310541004, 0.040903910776250996, 0.06477856033598073, 0.04562078247545287, 0.03324794874060899, 0.042858631277340464, 0.05198596787522547, 0.022783354797866195, 0.050230424967594445, 0.02921410894487053, 0.0386236583290156, 0.05330301653884817, 0.11517852151882835, 0.006461238326664898, 0.03104354749666527, 0.025131972033705097, 0.037111610363353975, 0.02985558057844173, 0.06268786353757605, 0.03846053426968865, 0.010113084044860443, 0.03182648360962048, 0.021770271268906072, 0.01136860866608913, 0.018173109310737345, 0.05641684554575477, 0.04679479701735545, 0.04838406544877216, 0.014250548993004486, 0.04461626704141963, 0.017100948971346952, 0.09321060148067772, 0.04463406374270562, 0.03076198037888389, 0.03227016917662695, 0.08434454910457134, 0.01801152520783944, 0.014024206939211581, 0.058458965067984536, 0.030082425437285565, 0.08773223060416058, 0.04058064238051884, 0.007756940967738046, 0.049244440961047076, 0.05838975608639885, 0.057450475433142856, 0.08391591429244727, 0.035876212787115946, 0.02190668172261212, 0.037245452986098826, 0.03481107130937744, 0.04342533524322789, 0.03174222758389078, 0.04361895415058825, 0.03809715650277212, 0.06115832686191425, 0.03494521079119295, 0.03682134898554068, 0.06095838485634886, 0.10439737932756543, 0.02742261454841355, 0.08590712619479746, 0.028453806480683852, 0.03164277608448174, 0.021217740468273405, 0.09193067875457928, 0.03610310588555876, 0.02070342470688047, 0.07634669818799011, 0.019344164538779296, 0.034370146531728096, 0.07768607436446473, 0.05894870089832693, 0.0041258280725742225, 0.055610142153454944, 0.03944687079638243, 0.027439075383881573, 0.0548657012404874, 0.029103512242727447, 0.06044231391570065, 0.04404342551424634, 0.021571052857325412, 0.037725952788605355, 0.026271395072399173, 0.020232053320796695, 0.040139175835065544, 0.015832867211429402, 0.082680127088679, 0.011702461943059461, 0.07792624819558114, 0.01793021921912441, 0.01432563300113543, 0.056166890208260156, 0.038027914124540985, 0.020192667543597054, 0.03318735609354917, 0.005587415098489146, 0.021341137362469453, 0.044411486233002506, 0.02978354401420802, 0.06936668054549955, 0.005481017560668988, 0.018062421695503872, 0.037155768150114454, 0.031041304355312604, 0.03557132738933433, 0.07596707480843179, 0.03954532410716638, 0.02255077128211269, 0.029878763416490983, 0.04940235514368396, 0.01707986641122261, 0.04018458042992279, 0.06847035168902948, 0.02368963585468009, 0.05394241015892476, 0.1272335898829624, 0.04571545825456269, 0.0325788766349433, 0.10663908091373742, 0.041825999578577466, 0.03470456940704025, 0.08495213056448847, 0.02663979903445579, 0.038054813267081045, 0.03548369830241427, 0.043742896523326635, 0.0129661641040002, 0.029533082160924096, 0.03529895177052822, 0.07893453745055012, 0.04346513291238807, 0.04728233609057497, 0.036655679359682836, 0.08365638524992391, 0.07799382816301659, 0.05122104368638247, 0.01694371570920339, 0.11013729788828641, 0.013110802192386473, 0.019896478261216544, 0.041474978570477106, 0.051915961084887385, 0.07591155474074185, 0.013040774065302685, 0.03847405991109554, 0.015248727413563756, 0.016688021714799106, 0.031068947500898503, 0.04111469184863381, 0.021825334915774874, 0.0517473785293987, 0.054987194525892846, 0.011394502198527334, 0.06022095723892562, 0.11955049121752381, 0.15292378870071843, 0.20510000613285229, 0.1338963839225471, 0.09248766058590263, 0.11289165282505564, 0.207148689951282, 0.10076508595375344, 0.14266453217715025, 0.15320763050112873, 0.11770062876166776, 0.10993744494044222, 0.13821546075632796, 0.34120744094252586, 0.28286771674174815, 0.15442561358213425, 0.08805813733488321, 0.13878768630092964, 0.11899074117536657, 0.11678306706016883, 0.14864269498502836, 0.1436677377205342, 0.205982998595573, 0.18578525661723688, 0.14349514385685325, 0.15335718810092658, 0.12959443585714325, 0.1308731859899126, 0.11069703308749013, 0.14669789699837565, 0.17414508591173217, 0.23432606365531683, 0.07895554765127599, 0.2873822901165113, 0.13525160495191813, 0.10686211113352329, 0.11569673355552368, 0.09387535799760371, 0.1521503520780243, 0.15824332513147965, 0.16618835739791393, 0.09496776227024384, 0.12681252497714013, 0.10787808903842233, 0.1440104763605632, 0.08843335235724226, 0.1390497386455536, 0.18073390267090872, 0.15504809736739844, 0.19958780816523358, 0.17614765267353505, 0.11983421427430585, 0.17258479463635013, 0.15308274189010262, 0.20498473575571552, 0.15308505739085376, 0.1783331439946778, 0.12123396416427568, 0.14490290894173086, 0.1817803902667947, 0.27045206108596176, 0.22874812624650076, 0.10096819692989811, 0.1552661255118437, 0.24308664200361818, 0.11827645372250117, 0.1563744488521479, 0.16330210055457428, 0.23044445319101214, 0.14607081189751625, 0.12753061222610995, 0.10041140805697069, 0.15188306017080322, 0.29354597500059754, 0.1337598732789047, 0.0669946132984478, 0.21897902857745066, 0.17867641698103398, 0.08600692279287614, 0.12110326453694142, 0.1927732300828211, 0.10366914691985585, 0.3255127096781507, 0.0996561317879241, 0.19777793262619525, 0.15607680310495198, 0.2586834691464901, 0.12587390112457797, 0.13726000499445945, 0.22547722910530865, 0.11824341330793686, 0.1521003758534789, 0.24080484959995374, 0.1670043932972476, 0.1193152526684571, 0.18519339384511113, 0.11995048655080609, 0.10636033766786568, 0.22923139797057956, 0.18501082551665604, 0.30207443924155086, 0.14025060780113563, 0.10801926779095083, 0.178631576418411, 0.14101573236985132, 0.17451544728828594, 0.07943312710267492, 0.09607512824004516, 0.10378774954006076, 0.05949956743279472, 0.16552026121644303, 0.1344825915293768, 0.09262703591957688, 0.23713130765827373, 0.07788980874465778, 0.11737121167243458, 0.10499191383132711, 0.1226833785767667, 0.1537490272312425, 0.1522836714866571, 0.1174820217420347, 0.1028974840301089, 0.08235592729761265, 0.07070233856211416, 0.11022136095562018, 0.1589241120382212, 0.1078839816909749, 0.14139703300315887, 0.19054506527027115, 0.12018634850392118, 0.2057611261261627, 0.1207224908284843, 0.10315670879208483, 0.1515941123943776, 0.12472465576138347, 0.15433989552548155, 0.12319190558628179, 0.4022552620153874, 0.281336666084826, 0.13793026824714616, 0.21909349743509665, 0.10814466106239706, 0.1028232544194907, 0.17783727060304955, 0.04722053374280222, 0.22220511484192684, 0.11646900500636548, 0.10422431791084819, 0.08405506698181853, 0.08819040289381519, 0.09360314565128647, 0.20350288948975503, 0.12383604524075054, 0.17711902008159086, 0.1258358734776266, 0.1616791423293762, 0.2752745960606262, 0.1283560140291229, 0.13372511108173057, 0.167008861026261, 0.09264981243177317, 0.0742436372092925, 0.14724309352459386, 0.1564176270039752, 0.16641064547002316, 0.14931402693036944, 0.07528115223976783, 0.09216392834787257, 0.1460588039481081, 0.10830728046130389, 0.21602747758151963, 0.08424907180597074, 0.12794516107533127, 0.12250462488736957, 0.13066928833723068], [0.024012763242353685, 0.05277215088426601, 0.03043504762899829, 0.051532051802496426, 0.014761010224901838, 0.029836626126780175, 0.009586913402017672, 0.030846145491523203, 0.0784670734719839, 0.024496866171830334, 0.0678601727122441, 0.026909402731689624, 0.0679651643440593, 0.02114004502800526, 0.023488278202421498, 0.033377549989381805, 0.06298496009549126, 0.05043941746407654, 0.02736807226028759, 0.04806705335795414, 0.05965835363895167, 0.033902875511557795, 0.023486196478188504, 0.01586478883837117, 0.05464712761749979, 0.051072376663796604, 0.05319959454936907, 0.019987495252280496, 0.03180464220349677, 0.0036445100522541907, 0.02937589342764113, 0.048302451468771324, 0.019503963776514865, 0.06738660085829906, 0.035041348601225764, 0.04553859333100263, 0.04099512443644926, 0.03169557618093677, 0.035704316542251036, 0.0580941067164531, 0.03844658931484446, 0.00887734879142954, 0.04388920351630077, 0.08171012523234822, 0.04092076123924926, 0.027322676942276303, 0.064975296263583, 0.02661791309947148, 0.009254777269234182, 0.06728076317813247, 0.0384629796462832, 0.06146890082163736, 0.05069905782875139, 0.03726722759893164, 0.01776136577973375, 0.005888442256036797, 0.039378359433612786, 0.04991055560822133, 0.04113941278774291, 0.0957365456270054, 0.03896774767781608, 0.007335064337894437, 0.017994511472352315, 0.005351634317776188, 0.017430054358555935, 0.01651440925343195, 0.036013357967021875, 0.03905067525920458, 0.015225181850837544, 0.028675178000412416, 0.024997218424687162, 0.01445603205866064, 0.02340128179639578, 0.06598135907552205, 0.09878393757389858, 0.00278736520158418, 0.03187185851857066, 0.02427439256280195, 0.05013493282604031, 0.037901737887295894, 0.04711799861979671, 0.07012177127762698, 0.06862687063403428, 0.11486136470921338, 0.0900716136675328, 0.047988407968659885, 0.06698353303363547, 0.040821009170031175, 0.03882904398778919, 0.03616390262322966, 0.04534195388259832, 0.022307630715658888, 0.10400583705632016, 0.07631577289430425, 0.06276917323702946, 0.07203794462839141, 0.016285000274365302, 0.014297458292276133, 0.03213864205463324, 0.04580371445626952, 0.04115115727472585, 0.04838472596020438, 0.01814992090658052, 0.05937024820013903, 0.023177685689006466, 0.02441801112581743, 0.0587596128025325, 0.06580510642379522, 0.0701665376254823, 0.038310193704091944, 0.044739322547684424, 0.07785032648826018, 0.010050934743048856, 0.02725410806306172, 0.0449521705013467, 0.010854529464268126, 0.03808360117545817, 0.009722683753352612, 0.04991000641894061, 0.02237775996036362, 0.022380312948371284, 0.02621854488097597, 0.06211517786141485, 0.06251230850466527, 0.0839780320529826, 0.033300433424301445, 0.059816256689373404, 0.05816010590933729, 0.01841273951868061, 0.023088147427188233, 0.043183165034861304, 0.04718324082205072, 0.02940065518487245, 0.025176669732900336, 0.013711936244362732, 0.007330153639486525, 0.01892614058306208, 0.015871369832893834, 0.10149469875614159, 0.00793159197201021, 0.044295006155152805, 0.03946662305679638, 0.03453164899838157, 0.03840498822683003, 0.01688724569248734, 0.03534322459017858, 0.020418261883605737, 0.02319721159437904, 0.053598294834955595, 0.0402393323747674, 0.09824621447478421, 0.08414817682933062, 0.034113374567823485, 0.07035623799310997, 0.044201744167366996, 0.05443878078949638, 0.05470943833643105, 0.05029473206377588, 0.04369692789623514, 0.06059388644644059, 0.024909889907576144, 0.04049505419970956, 0.023032272983982693, 0.04962069127941504, 0.058783658387255855, 0.008771401644480648, 0.025639152045187075, 0.03964365867432207, 0.044213447836227715, 0.055186539102578536, 0.04245532596542034, 0.01386377502058167, 0.07496608086512424, 0.06325479014776647, 0.029830471867171582, 0.03955617801693734, 0.02708611365960678, 0.017109995751525275, 0.039952525694388896, 0.047222574648912996, 0.03761584033782128, 0.016454788819828536, 0.047311521047959104, 0.06374248507199809, 0.07135945837944746, 0.03376688066055067, 0.031054054452397395, 0.02226023902039742, 0.022402339891414158, 0.040491759064025246, 0.027056863764300942, 0.034321888379054144, 0.05523859705135692, 0.03560534372809343, 0.032933541588135995, 0.0620061897643609, 0.03115673243883066, 0.03963606650358997, 0.010521216099732555, 0.03665725642349571, 0.05863401915121358, 0.04688921675551683, 0.01948303706740262, 0.1110936219629366, 0.03989584787632339, 0.02527488370105857, 0.028664754536293913, 0.028547541587613523, 0.05309899272106122, 0.008235098830482457, 0.11244763329159468, 0.04552043668809347, 0.045173475227784365, 0.07591387024149299, 0.0280478962304187, 0.09837610516115092, 0.036575427220668644, 0.009929896950779948, 0.07722296679276042, 0.0716652232222259, 0.028169758734293282, 0.043380375936976634, 0.04573001177050173, 0.03896967726177536, 0.0633914046920836, 0.09648760649724863, 0.05624329060083255, 0.08277374901808798, 0.04786049510585144, 0.055139761534519494, 0.06056509482732508, 0.02121836572769098, 0.012249916453583864, 0.056386558499070816, 0.04811626517039258, 0.025213389344571624, 0.022476907179225236, 0.02687352545763133, 0.028867832115793135, 0.018919938083854504, 0.042295574967283756, 0.0629402679624036, 0.10046735857031308, 0.03721676897839643, 0.03099843790550949, 0.04360250444733538, 0.06278487708186731, 0.04187625781923998, 0.0065500696928211255, 0.051814917678711936, 0.044378560851328075, 0.015038327619549818, 0.004744175776068005, 0.027023129441658966, 0.028885333813377656, 0.01647873235924635, 0.06570850106072612, 0.05307115847244859, 0.05779544422694016, 0.05331227483111434, 0.029128012392902747, 0.039641565817873925, 0.054536989191547036, 0.027071853292000014, 0.017092943053285126, 0.05146320276253391, 0.022482623571704607, 0.07700494606979191, 0.028406514975358732, 0.0455243255419191, 0.0405338425480295, 0.06808072415878996, 0.04420027842570562, 0.05554619499889668, 0.06593148675165139, 0.07277938726474531, 0.04384486761409789, 0.05988457138300873, 0.052728189766639844, 0.04719983524410054, 0.011956768121308414, 0.03402201247808989, 0.04148120518948417, 0.04970619411324151, 0.11465714051155373, 0.029163869257899933, 0.012558154503494734, 0.07253427073010243, 0.01063069494193769, 0.08432415488641709, 0.06218768568942323, 0.05303573576384224, 0.008018067019293085, 0.039848001615609974, 0.04006594812381081, 0.05014744914660696, 0.03500644910673145, 0.003779487465180864, 0.08335830163559876, 0.015201113073999295, 0.06453543275711127, 0.007858977460273309, 0.07522594387410209, 0.02922864576248685, 0.038049443828640506, 0.051171230734325945, 0.047040073113748804, 0.04643552332709078, 0.03316097645438276, 0.04433068119396921, 0.03884373109031003, 0.012952997476531891, 0.02813442137266975, 0.006773075792807504, 0.06495978537714109, 0.009999450103350682, 0.028475835279095918, 0.06459786964114755, 0.01532689226223738, 0.0173941863613436, 0.06967356603126973, 0.01548639927932527, 0.06551775426487438, 0.05380701273679733, 0.04595918326231185, 0.02352958057599608, 0.02516272106731776, 0.04721419209090527, 0.05651767372910399, 0.02014212543144822, 0.02649552367074648, 0.04983932798495516, 0.11567705922061577, 0.04071106370247435, 0.030042663020140026, 0.07874477028963156, 0.07306147017516196, 0.05816118573420681, 0.04796852583240252, 0.08677960984641686, 0.009529918315820396, 0.05391006365243811, 0.03477279875369277, 0.02410232376860222, 0.04273569451470394, 0.022062744246795774, 0.04875958104094025, 0.011568470890779281, 0.09196202707244083, 0.04494609231187496, 0.06376221135724336, 0.03165305854054168, 0.18700758868362755, 0.169547124824021, 0.12301890354137868, 0.14441534760408103, 0.08647521797684021, 0.08697339202626608, 0.10858163761440665, 0.12069460834027268, 0.1474372690427117, 0.13120973511831835, 0.13616281386930496, 0.1748389346175827, 0.13237995357485488, 0.06461355864303187, 0.08985749664134346, 0.0904335590894334, 0.2955464192200452, 0.18250254448503256, 0.11323918573907577, 0.10027899406850338, 0.15414232097100466, 0.08051854034420103, 0.09279453122871928, 0.262801795033738, 0.2014799730386585, 0.10522730823140591, 0.12895832624053583, 0.15768042096169665, 0.12412932715960778, 0.09727135155117139, 0.11461051879450679, 0.1479967890190892, 0.20812399074202403, 0.07862293932703324, 0.2198612195206806, 0.12362504523480311, 0.14821454999037087, 0.11943444158532657, 0.1512081510736607, 0.22347694815834984, 0.15774507686728612, 0.06660822895355523, 0.19109909335384145, 0.16252437431830913, 0.1920467714080587, 0.13011690782150254, 0.13499412423698232, 0.0733562809182331, 0.1910101543762721, 0.30463523464277387, 0.23149334534537047, 0.20159844949375838, 0.18008538434514776, 0.14035867934580892, 0.09291767579270527, 0.14213903225027025, 0.08429140390944667, 0.15115959977265447, 0.1941417355556041, 0.15565072128083557, 0.1463069484452717, 0.1633927464717999, 0.10362685192376375, 0.07976082240929827, 0.19288980663986877, 0.07397235996904783, 0.1920454206992872, 0.16254030080744997, 0.1984154523233883, 0.2078140401863493, 0.14979688305174932, 0.2312237527803518, 0.11311503185424954, 0.10170268564252183, 0.21787028963444754, 0.1299415234825574, 0.09941478536347859, 0.0812028227664996, 0.12984808709006757, 0.13981508585857227, 0.09040371733135544, 0.3014146105851978, 0.12148132198490202, 0.23648381349630654, 0.16105702961795032, 0.18154438730562106, 0.2744967659236863, 0.1562344649573788, 0.09055133792571723, 0.1323635966400616, 0.20384914590977132, 0.1300624490249902, 0.14643167378380895, 0.15983193676220253, 0.15358018863480538, 0.22599916672334075, 0.1453547878190875, 0.20106578042032197, 0.15275595942512155, 0.11544757973751985, 0.17527922114823014, 0.13197760563343763, 0.09540892453514971, 0.1283026981400326, 0.11578455931157805, 0.1520536353928037, 0.2624139189720154, 0.11142142859171145, 0.3523963858606294, 0.10523493008804508, 0.13187300733989105, 0.2294383681146428, 0.15796219959156588, 0.12399231927702203, 0.08289509758469649, 0.2629633160540834, 0.11413753323722631, 0.08948902031988837, 0.12660935462918133, 0.12533787754364312, 0.12273907675989904, 0.09636317801778205, 0.13256770209409297, 0.16766241111326963, 0.26549469272140414, 0.11009336274582893, 0.2235588218900375, 0.1624158426420763, 0.13137446221662685, 0.1480781432474032, 0.30372173991054296, 0.1483025390189141, 0.08719230332644656, 0.131480663549155, 0.14703549997648224, 0.07685586344450712, 0.11780487824580632, 0.11068287290981971, 0.16681550187058747, 0.10958636456052773, 0.22203047265065834, 0.12689681811025366, 0.12213487207191065, 0.10546553021413274, 0.14279431896284223, 0.12898866523755714, 0.1455248732236214, 0.12083983921911567, 0.2851556986570358, 0.16648339078528807, 0.13390632870141417, 0.23881684377556667, 0.23200331954285502, 0.15756685752421618, 0.07301997669856064, 0.1136021850106772, 0.19969567190855742, 0.11870350776007399, 0.13934302056441084, 0.2072564052650705, 0.21766992460470647, 0.10222086057183333, 0.08614679536549374, 0.18839164957171306, 0.15646708372514695, 0.1876713358797133, 0.14310349768493325, 0.24559523473726586, 0.11643089572316967, 0.16611570114037022, 0.10181184072280303, 0.13911546324379742, 0.17946998064871877, 0.15143789030844346, 0.0922544629429467, 0.10985632077790797], [0.006268532260946813, 0.03507103079755325, 0.038085259875515476, 0.04266783253115136, 0.01820062258047983, 0.025420218480576295, 0.025296593375969678, 0.005193794349906966, 0.08057089144131169, 0.0166746333707124, 0.09093953311094083, 0.0607592109736288, 0.04843720693315845, 0.02252263275295263, 0.028044547289027832, 0.008802599677437684, 0.023175505630206317, 0.021552911057369784, 0.06683515544864349, 0.027190235123271123, 0.026455837323737796, 0.036418381350813434, 0.05810433351143729, 0.009590266054146923, 0.01849432195740519, 0.0037905329418208566, 0.06782853495678864, 0.03355519045726396, 0.02609427596325986, 0.035446331166895106, 0.06492480053566396, 0.045368793653324246, 0.1012613155762665, 0.02751949450612301, 0.05694101331755519, 0.06220517068868503, 0.022657352965325117, 0.022900552903593052, 0.04533641375019215, 0.03060204198845895, 0.03762722117244266, 0.03370598002220504, 0.05172735909582116, 0.04235828273522202, 0.04856818857660983, 0.02829323355399538, 0.05304874561261386, 0.05280131728795823, 0.014755402371520177, 0.009703409250505501, 0.08023208618396893, 0.052516336290864274, 0.01832924048358109, 0.06658068785327487, 0.05894738729693927, 0.04683938896050677, 0.028714376385323703, 0.019048774920520373, 0.01699711508990731, 0.024720527217141353, 0.05952211758994963, 0.030463508992397692, 0.022478662358480506, 0.06959126927540638, 0.08306648174766451, 0.04947223576891702, 0.043099829272250645, 0.04747261162265204, 0.050306005286984146, 0.01903318610857241, 0.051896876757382415, 0.061875616302131675, 0.038987793086562306, 0.06165160273667425, 0.015382681358460104, 0.05323135104845278, 0.05677408575138543, 0.03274867631262168, 0.03303564626548905, 0.03514550902764313, 0.04197457754344214, 0.03243849569116719, 0.061832167266402394, 0.055890714793349616, 0.09991095561417751, 0.056201774859800935, 0.020198717902530916, 0.016466284687339794, 0.017844775757112075, 0.03392224185517989, 0.06290043689659797, 0.04415793147927616, 0.04039480489154812, 0.02416118535620626, 0.06920824685948901, 0.022932977335585747, 0.023366079876723234, 0.04680993311922066, 0.007742849902570015, 0.05909961291763466, 0.09590354369720444, 0.05570762696152087, 0.033410096875741147, 0.058900390795315616, 0.009556253426126204, 0.03989561781054363, 0.01523123592050979, 0.030753894679946825, 0.02088293167616939, 0.02502271490811836, 0.04994833463570103, 0.012606687250809046, 0.04472026048460975, 0.02522961269278312, 0.04578715714160353, 0.04233218882291112, 0.019916158162232023, 0.019484350668790285, 0.040263504124595784, 0.050617388187674806, 0.08416773984208703, 0.017407261148036923, 0.04570855257043149, 0.05049271108873654, 0.010038804339274066, 0.012615682080650004, 0.060090758561273105, 0.021540624802582897, 0.0774515260127373, 0.03320959454867989, 0.05545028354390524, 0.04281920468201861, 0.05767765425844118, 0.07906704049673863, 0.018180807237513363, 0.09556873119436204, 0.04510055179707706, 0.028013462433591485, 0.03909322258550674, 0.01697635350865312, 0.0595728508051252, 0.022950521706661675, 0.03224918866180815, 0.03690745295898523, 0.01264990343770478, 0.05824690008012112, 0.01687726009549806, 0.0313534312590491, 0.027756931667681783, 0.02640096477989573, 0.03647624660516158, 0.03842831021756865, 0.036587798822438344, 0.031187093700282276, 0.0944681855617091, 0.01242341852048412, 0.037754770382889546, 0.05049490413512103, 0.01673645241680788, 0.013104469817335485, 0.03294041758636013, 0.0021744787773059215, 0.055982128833420575, 0.032207528201979585, 0.0165221888164524, 0.03219563528546132, 0.05304514619638212, 0.053417299859574996, 0.04792506566445809, 0.023248191573657095, 0.023052323958836496, 0.07492898090276867, 0.05273126225802116, 0.04862039124418516, 0.061946157438796945, 0.03613053937442601, 0.023363178079307545, 0.08469643842545338, 0.06317330233287066, 0.012464981573430123, 0.009941786156559829, 0.04365662927739322, 0.01048425250701257, 0.03833396469417494, 0.03758253646083176, 0.058736884529935196, 0.013174457126297057, 0.07209561692434363, 0.03871644534228835, 0.04354239419626538, 0.04437442337803077, 0.03444103276706301, 0.010812208493007347, 0.042238860041834414, 0.06473488494521007, 0.09909715357935056, 0.057205225311918184, 0.02344248026929563, 0.01947343367646681, 0.03556866678991355, 0.13024771877098829, 0.0378074109175941, 0.03749154544493649, 0.03262555772380438, 0.07912818604381755, 0.06585653725778684, 0.060971268540015444, 0.077955140004633, 0.048569220161880367, 0.010902563117269892, 0.048864223863347434, 0.06607368966797367, 0.08385184468352236, 0.06912787226610817, 0.12546433950774372, 0.05013932634028606, 0.04016988961666357, 0.02428410170978168, 0.017011176933010574, 0.03001565255544847, 0.04686409134592395, 0.02897571997891646, 0.04321274704125244, 0.04432520414411556, 0.015186397213255987, 0.07117058179574087, 0.05138757420354523, 0.052503486003843136, 0.017929803616425488, 0.045044282160233706, 0.02254386188724311, 0.04071752409799956, 0.024612299821455963, 0.1465771792572923, 0.09196101033012383, 0.015611562484991737, 0.019282473513158038, 0.01138933963375166, 0.0016714874936951674, 0.03440129446971696, 0.09533968215691857, 0.04117900265555363, 0.04908423354208935, 0.04998629548936151, 0.06924340981640853, 0.03865681377646979, 0.0375791856640717, 0.04452611094166059, 0.06322265515336767, 0.007955198761919746, 0.06291938392678276, 0.08211490741814487, 0.04938140060403384, 0.04023270870675333, 0.055456666013924405, 0.010757865657069487, 0.03185419540386647, 0.07581627782201394, 0.037309912222553976, 0.06406801330740564, 0.05236223674728535, 0.049446561170043424, 0.03145650443912018, 0.023581965069752187, 0.02079011312162038, 0.012231629007146694, 0.10129006637725979, 0.009816276924539125, 0.06572781174327247, 0.04627995804185048, 0.09696102250018157, 0.08065254252869636, 0.03805260166700464, 0.08439871846348979, 0.06389285161276348, 0.010908478961937362, 0.07439208900905214, 0.08918593463022262, 0.017791346690501086, 0.041249558635172434, 0.026548446221568156, 0.025592884703655727, 0.01085049589164555, 0.012500517459557159, 0.014658784020866733, 0.039693389990134165, 0.042003254129667766, 0.037997389590600505, 0.0036131721708443365, 0.03659033325675409, 0.034271040130988695, 0.053506372423726134, 0.03788816029555164, 0.026611424873408396, 0.017212072598340455, 0.02835279276041547, 0.00880715739185689, 0.03483459739072714, 0.05614912690361962, 0.03770374030864332, 0.014373213016369846, 0.07628467690665275, 0.04345758898125496, 0.04019331550807692, 0.04185746664006729, 0.05492954078363255, 0.05400575988460332, 0.06919525185367092, 0.03746510643395595, 0.02114610466378508, 0.07428770593833178, 0.06910489537403919, 0.01940555128385313, 0.06615336664253846, 0.0019578973569878144, 0.07078187452862039, 0.034722796553978696, 0.030372300898307003, 0.02106185977027053, 0.008253988344222307, 0.037746424932265654, 0.04370910653960891, 0.014748310222785221, 0.02254590464872308, 0.01808200882805977, 0.020538089047477115, 0.09433892570086755, 0.05493605312949512, 0.019518020053510554, 0.05460482519993093, 0.03628050886618439, 0.058157152161584236, 0.019504017582221422, 0.07254063835716806, 0.027897754189325497, 0.0564640906668501, 0.022271293310041074, 0.01726936454360839, 0.03704210823343601, 0.05939784496149514, 0.06004217386362143, 0.05439376582216937, 0.020166024442005437, 0.03523857805703301, 0.05839749297592789, 0.05421509747975506, 0.026702055947680492, 0.043876587005797774, 0.04528176199528389, 0.09305809013312683, 0.032530603639315814, 0.06826681768870912, 0.11673746208543889, 0.11441379028838128, 0.11738451095880009, 0.10006206430261955, 0.14845159195829183, 0.13650755630806088, 0.08899846812710166, 0.1274531171657145, 0.21097294724313542, 0.12777650059433654, 0.14203398866811767, 0.11545734640094452, 0.22855775052448735, 0.13172104518162087, 0.1364193594781682, 0.11285378845059313, 0.07423839764669538, 0.36531512858346105, 0.1526223580003716, 0.15850245341425762, 0.09953417466022074, 0.09065274498425424, 0.11131821069284342, 0.17052005074219778, 0.15157664223806933, 0.21725408441852778, 0.11931586122955196, 0.14760650839889422, 0.09454932456719689, 0.1378181594191119, 0.16672090772772208, 0.15204499679384753, 0.15792590857017785, 0.10276789020281285, 0.20817177020944655, 0.13408583938144147, 0.1044865780568216, 0.2124483961961232, 0.17778762092348188, 0.14391125121619552, 0.1158085826318711, 0.1915793668013066, 0.14540992939146236, 0.10665289228199981, 0.11121931209345348, 0.08688944028108381, 0.12930517637869343, 0.12923960020998493, 0.1598216505954042, 0.19697727402672172, 0.10413214316940866, 0.16975023580016568, 0.08802920841844752, 0.13702076626941562, 0.07873769020079635, 0.13426447432721034, 0.08320287364767864, 0.30084585829172283, 0.16814025031635538, 0.13808188901748508, 0.22778174607083201, 0.09216590246069245, 0.09316969430074096, 0.2039669395890087, 0.24692678125575185, 0.17308515059994534, 0.15262998727848753, 0.17067823209799826, 0.1404632776393555, 0.16155153745785356, 0.15107653860468417, 0.1643806044012308, 0.18199501937488094, 0.20108749566134065, 0.12546003505121917, 0.2124632243067026, 0.10879835215746425, 0.12402521126205102, 0.17007891816319898, 0.12773914088029414, 0.11429796330048703, 0.21987995132803917, 0.16763469931902364, 0.13757746608462185, 0.24880667100660503, 0.14302554249297827, 0.12043297159834765, 0.1677971999743022, 0.1408899383386597, 0.10411755254608579, 0.1598103402648121, 0.20753016870003194, 0.12066741604940034, 0.1525904456502758, 0.1970500044990331, 0.19961862213676795, 0.13232631114078686, 0.1967654502368532, 0.13517859246348962, 0.1024983124807477, 0.18903415650129318, 0.17903681873576716, 0.14537329698214307, 0.1325973286293447, 0.12058179447194561, 0.1912287317099981, 0.13576295954408124, 0.10277991299517453, 0.11858428915729746, 0.09807958005694672, 0.1784578841761686, 0.12991565221454948, 0.1640465488890186, 0.12545822421088815, 0.193171362625435, 0.1661996083566919, 0.16330541053321213, 0.10557007655734196, 0.1117639742733445, 0.11561945371795446, 0.14678299165097997, 0.10939554354990833, 0.11345031933160499, 0.16748701193137094, 0.11895827221451327, 0.13970677682664245, 0.08130892761982977, 0.15649411274353042, 0.11000869853887707, 0.10567247067228891, 0.14630853664129972, 0.12679273932008073, 0.20923308591591194, 0.11604722021729685, 0.15040090220281854, 0.20657702843891457, 0.12841062125517055, 0.1595801705843769, 0.12314477178733796, 0.15640763769624755, 0.17273548030061647, 0.21970143512589857, 0.1535625255201012, 0.2293900097720325, 0.09314816459664144, 0.1315462842467241, 0.05716221785405651, 0.10359774489188567, 0.08146153544657864, 0.0956858643621672, 0.16718461643904448, 0.13042602717177942, 0.1182158499432262, 0.11611080743023194, 0.16431639378424734, 0.17600753519218415, 0.14500062010483816, 0.17088870517909527, 0.14033089333679527, 0.1237421041878406, 0.10570778948022053, 0.1355694668018259, 0.12299575595534407, 0.1616005488904193, 0.12825000565499067, 0.132913839770481, 0.14328303805086762, 0.1705303814378567, 0.28194308979436755, 0.10529295861488208, 0.07822783474694006, 0.12742687482386827, 0.15437528112670407, 0.12712016003206372, 0.2252952248090878, 0.19468895072350278], [0.03773067655856721, 0.042636588113964535, 0.02067739944322966, 0.028590465553861577, 0.03068184512812877, 0.02985080485814251, 0.07933797634905204, 0.034977509058080614, 0.008782981003605528, 0.03997471219918225, 0.026988549070665613, 0.01334040598521824, 0.12560433824546635, 0.09664943179814145, 0.01555153758090455, 0.05493777120136656, 0.09199126026942395, 0.05927449259615969, 0.03799307029112242, 0.06282122747506946, 0.035358768873265944, 0.027967146852461156, 0.025823312280408572, 0.09378242626553401, 0.10739525518147275, 0.01418495334291947, 0.09641374053899199, 0.06456292190705426, 0.0402517262409674, 0.04418961005285382, 0.044968768634134904, 0.051579378559836186, 0.02302380136825377, 0.014711297462781658, 0.007010310255282093, 0.05179536950890906, 0.02924893793533556, 0.06255101892747916, 0.057077891324297525, 0.03919229930033907, 0.09885444160318002, 0.0647235894575715, 0.022984146562521346, 0.0016837727048368833, 0.028616340532607865, 0.05096396002045367, 0.010053448768303497, 0.05479821775224991, 0.0731182073650416, 0.06529456819407642, 0.030565452252631076, 0.04790502025571186, 0.034485027281334624, 0.037893889675615355, 0.03529780144162942, 0.017241561836272012, 0.04642521860660054, 0.06535786596941762, 0.02516707932954887, 0.005218550541030709, 0.022440449174609967, 0.014074173886911012, 0.02301940414326964, 0.05270412191748619, 0.059210935069131665, 0.015086308394529624, 0.03703345108078793, 0.0397125707968371, 0.017116695489676204, 0.03721252389368601, 0.017378324810124468, 0.05336834037734661, 0.054567766055697575, 0.01743148299283348, 0.016258665164059494, 0.06448552332585678, 0.010718021603679517, 0.06544589210534468, 0.029384778790699784, 0.06589114360394888, 0.055356023367494345, 0.053151084066485055, 0.03031014417501865, 0.022801769337092992, 0.04764439283462707, 0.0753023850847967, 0.015291192175936885, 0.05420451445388608, 0.034795207902789116, 0.04001037981652189, 0.06259139176108874, 0.06339893749100156, 0.05673703031789046, 0.03103595161519479, 0.08023177448194474, 0.04123251150303986, 0.0180251454730751, 0.029672225573449396, 0.024107314711727668, 0.008011654863366857, 0.025249242498830426, 0.02627450281579513, 0.014373902286024531, 0.009706696964713046, 0.009561009665048914, 0.0418699681176804, 0.0208780168031808, 0.03299760377558414, 0.056724254245636985, 0.017201133341586683, 0.06713631155434996, 0.016655541621730663, 0.03866053193632979, 0.07001148071140051, 0.05455029218865093, 0.04551287420326844, 0.025478690440650098, 0.02977328753331676, 0.036631982584367506, 0.01489853111706907, 0.0256391019502189, 0.04040781102958135, 0.04090741371328477, 0.062452031270368025, 0.030136268251226284, 0.053137153954594396, 0.01416241895640269, 0.10725818792707287, 0.010649259766069008, 0.08343738489202224, 0.06147264866740443, 0.01926033895870205, 0.05540422956983093, 0.00426361752943194, 0.07980322872754186, 0.08130343572702259, 0.033122225213446654, 0.005558156390179647, 0.02910879262344679, 0.04006945477158297, 0.03376520340680145, 0.08091673225862905, 0.013440185884974198, 0.046127706445986405, 0.025445638893870637, 0.02107729458657559, 0.029448067289195023, 0.028346087456156965, 0.05300751930917613, 0.03690190911584068, 0.05318496681866236, 0.013899449131713482, 0.04558559725410305, 0.015985154059308115, 0.021741301534348167, 0.05670518847182393, 0.03684670075017493, 0.01904268930957187, 0.023151493442128412, 0.040983368817251176, 0.033481439531897195, 0.0579323222336825, 0.011057072697440162, 0.06882204063003883, 0.033779281948227435, 0.03272171408752911, 0.05212911702983547, 0.05945462668023538, 0.029914102633483708, 0.04711599111033138, 0.004022393095510779, 0.03995176499302033, 0.043678426154656336, 0.01996134753426304, 0.03846186642476823, 0.019351866176293697, 0.007926791204226902, 0.014574018696293933, 0.051597427591332234, 0.037429242147482, 0.05087210069177672, 0.06312049110420048, 0.04324938687204849, 0.0620327697834, 0.028179840810480528, 0.020445639711397234, 0.038315095589496195, 0.004204035130896955, 0.03999452012067195, 0.046846365148667246, 0.05509783761226572, 0.12143069267040119, 0.04532474347797688, 0.048318107074010186, 0.02213557861978188, 0.030859702674206346, 0.03349811187945306, 0.040987038737512194, 0.025478525312792044, 0.050342277754680254, 0.025079745246330276, 0.03742317137948703, 0.04626210567948874, 0.05105731848743744, 0.04353454969532322, 0.05733994737965986, 0.02861401761037996, 0.0920956656045746, 0.060976994209340774, 0.00820921921331319, 0.019306101639813278, 0.022143131827760953, 0.03332898755616043, 0.09169621203909628, 0.03310229854832869, 0.03019092371687293, 0.047862528590485454, 0.04524515556113329, 0.04176554793957621, 0.05632615881040692, 0.028312993235886097, 0.10040342254796997, 0.09405369608430192, 0.07874616552726366, 0.030643316531495657, 0.06790369225200266, 0.029455804178724065, 0.03726521637872793, 0.017799985289457254, 0.04157801093242597, 0.024337582726730034, 0.015219389388221316, 0.026424234820296988, 0.034363500599283725, 0.04158568102866411, 0.028327611689746846, 0.05640982111799531, 0.04185545913060196, 0.0850328836531844, 0.01453020044209552, 0.028430055899661966, 0.02459718412865186, 0.029000042013649363, 0.02002664354222361, 0.034290079929633066, 0.01418384475982748, 0.05861535042640753, 0.012683690638368716, 0.04031156189739704, 0.01341998555290047, 0.03361853647220414, 0.04900393687421456, 0.04542059556115419, 0.06406151951523498, 0.022591891829506494, 0.04348499278421514, 0.02402928159426665, 0.007447579955623951, 0.03750793948711362, 0.03660107955511194, 0.03157660619763192, 0.034250245153089054, 0.03375616033736151, 0.0285357284519705, 0.038194129228941165, 0.0381592853955226, 0.026667015445127618, 0.13109574123518541, 0.08574649575166404, 0.0510346644296078, 0.02780454229650786, 0.01726830883853836, 0.04938145626510959, 0.046283468400361016, 0.07554848867584951, 0.03196124278474599, 0.03915596375009045, 0.05370639977627434, 0.013543939057854004, 0.02232647570053814, 0.0352313866460463, 0.05713418322557118, 0.050190616166219115, 0.05579937125730794, 0.032706540878280066, 0.023051873104122933, 0.015699555224273354, 0.03795717260800302, 0.02060395465377951, 0.03903584714862518, 0.05782560881925747, 0.05067335725470912, 0.03461990891082678, 0.05147895855770912, 0.01766687182680471, 0.01762234667694429, 0.06872804762679152, 0.011779379983636318, 0.04002725996542722, 0.04646927620342467, 0.0410221386118792, 0.090107644937234, 0.03012475383002311, 0.0765293778385967, 0.053223680952214636, 0.05941038725723047, 0.012147571505920496, 0.053096907286089845, 0.016032779531087726, 0.04310018179239705, 0.0310065143276006, 0.028297890530666336, 0.08558493020245805, 0.025014978018589318, 0.020381688846100587, 0.0544099149556132, 0.036893790020258166, 0.04559982422506437, 0.005361854155125911, 0.0447909166541649, 0.02390200326772174, 0.05302858888171613, 0.045093983790138736, 0.02961751259135781, 0.012953788791492116, 0.05478399820276536, 0.010308293931302615, 0.0663536055071745, 0.026307088664907496, 0.031440581660717726, 0.055584541769349016, 0.044901856599608436, 0.015256766728271032, 0.07610905508045107, 0.03466858637693804, 0.04512161394814029, 0.0671421670995187, 0.09792863464099355, 0.00858278852319927, 0.03138914340524934, 0.01650442365644267, 0.020777504032594152, 0.0591389541659737, 0.04526818069280125, 0.009127249395533, 0.041380280526936986, 0.025033266392711084, 0.03360249123943504, 0.007722881955487537, 0.03730821641511284, 0.06927955982973799, 0.016336618500645272, 0.07415292449877597, 0.14263843826483935, 0.16407558170612901, 0.1479026846936904, 0.13109447958413512, 0.08014974489924498, 0.11041215228033252, 0.1369064161553979, 0.06964675965718925, 0.10984762280713767, 0.07064747158437967, 0.16467194189317524, 0.24040671705733985, 0.16524507285794243, 0.1588665065355599, 0.13652556081069633, 0.20908406266244128, 0.14093562494963408, 0.16822884790599346, 0.11496598526719026, 0.0874155190831516, 0.13866633031284437, 0.15158447931753471, 0.22195254714461043, 0.15014587057521567, 0.1078902231529355, 0.14462234743405133, 0.1393128596828319, 0.14179679827066138, 0.19122099853120744, 0.11831313808215782, 0.20196953817503527, 0.1671498839277774, 0.13066946645267308, 0.08889938399079256, 0.1661527343094349, 0.13323232502443716, 0.14665525319287553, 0.1511562749510631, 0.1761666961829178, 0.18880569376051426, 0.1738414287683554, 0.14883237308822572, 0.1962951512541622, 0.06509415121399797, 0.20188591297483072, 0.09419538691872731, 0.19223892828449607, 0.16758464887971058, 0.17578358470927924, 0.11146310760523193, 0.13933608890511096, 0.12049744196701795, 0.1917455781949684, 0.09364283570903353, 0.1950741105247289, 0.10519270188524388, 0.1362884446280077, 0.139686293550767, 0.07078301743604243, 0.10640974986017682, 0.14810864551691338, 0.1311545044882223, 0.1497254884452559, 0.10190801564021967, 0.19470425380859524, 0.14026273449417204, 0.13399574265349656, 0.09913947083987296, 0.07414611158310436, 0.12900511123007163, 0.13409863400738686, 0.1325523099512793, 0.07127763659809716, 0.14261298259953037, 0.18914803164079785, 0.11887737811775878, 0.19611852010712028, 0.11130713784950785, 0.18512363196350634, 0.20030194718856364, 0.1108304712397512, 0.09980129587347619, 0.09883837410598062, 0.11176225249073468, 0.15442801814060658, 0.10956212601740845, 0.16671912657329813, 0.11083100558607839, 0.20604002522304654, 0.14183779450831935, 0.22781993699027225, 0.20682215981651098, 0.2358602313324809, 0.20617658039554954, 0.12091633980162442, 0.1269931488786824, 0.09797924169106409, 0.14159865968395025, 0.11942135010031052, 0.1536750202649273, 0.1109211913717445, 0.10040843204478733, 0.09632824512664229, 0.16637718945275992, 0.10700898215873167, 0.19733018008992076, 0.1379776024259627, 0.10279502312187105, 0.10212942055659369, 0.1488862678525038, 0.12579208676470444, 0.09533544449368492, 0.2427032039850019, 0.1574816886568442, 0.16416420898167416, 0.10444639818160795, 0.2001199874212034, 0.09695602042484097, 0.16069689503638074, 0.11128620928502642, 0.09099696049815975, 0.17042621358996257, 0.2588742010993883, 0.09684820121037774, 0.20184248249279335, 0.19746753678191453, 0.24982575851026922, 0.15046011074446142, 0.21570502925897017, 0.20480687264353037, 0.10364108631620184, 0.09565836036927067, 0.09566921798978001, 0.18258136056829244, 0.18196628341684118, 0.1556250875000842, 0.23020603082841262, 0.13893589319195598, 0.2049171706312336, 0.09688717880635522, 0.1904974936041981, 0.18650040496140718, 0.21446035854751244, 0.11511439995956607, 0.14131366013316438, 0.13170621707104146, 0.11619384633377194, 0.11004371306626126, 0.07894333932199515, 0.1352200488327071, 0.13523159665055573, 0.08878124892362393, 0.10738241602666676, 0.15412085806019604, 0.16853250504937023, 0.11186420131707564, 0.21007779840147123, 0.1128361104929354, 0.12415173259796575, 0.10631723373080604, 0.16083189169876277, 0.08082039406872354, 0.08277639106381685, 0.18340833572437987, 0.08699599784449674, 0.17370548215694726, 0.22049995634006336, 0.09120419781538658, 0.15618252946296707, 0.06240633723791689, 0.09849411406321451, 0.09550906994263642, 0.11133483480080031, 0.18016751040704548, 0.13052096270257607], [0.07342243596212938, 0.03251273272326216, 0.011578374851524131, 0.024922495285863988, 0.003640548143266642, 0.01659629040659638, 0.08405119297094643, 0.011499954889586661, 0.01165895539088524, 0.038794448773842305, 0.04352504649432376, 0.035349725803826004, 0.006414096642402001, 0.03967920012655668, 0.012263576609257143, 0.0325787430483615, 0.0486609273502836, 0.035640098503790796, 0.04021995118819177, 0.0806929673126433, 0.02408182008366566, 0.019442042685113847, 0.0647660180402454, 0.023656866324017756, 0.039909032129799016, 0.041465980029897764, 0.03881314718455542, 0.0037872269058425445, 0.031069210963323712, 0.08251600112998858, 0.06797353576985188, 0.023194267123471946, 0.02263867310830392, 0.11193671656656079, 0.02219585956481751, 0.034233068145113066, 0.033374841150362045, 0.07081774252583273, 0.030830790456093382, 0.05251373877399601, 0.010262436626362614, 0.02317220307304524, 0.06290085992077366, 0.04021883425593842, 0.03889952946337871, 0.07225329361972399, 0.05851656314916909, 0.053452737411134876, 0.020813507471757475, 0.03230767360946629, 0.06561067115399055, 0.06134577852208167, 0.05383623851230368, 0.033692639917717315, 0.04045769448566716, 0.03219733480364084, 0.05050945022958331, 0.03307583356217947, 0.060152026562718675, 0.03703339541971218, 0.020362910654512234, 0.040609211355331354, 0.033707605325616896, 0.050958675928995945, 0.018340278074902017, 0.03369299243786372, 0.010103266358783003, 0.034895434946520254, 0.06205583573319018, 0.09352942070108838, 0.05718671243812423, 0.022773267155571375, 0.017670812630967703, 0.03619955910835415, 0.04132011832552962, 0.026634457426553126, 0.024828793575579766, 0.03946010328945704, 0.013496180927177193, 0.08743716753087938, 0.05887584797164891, 0.0309116344578797, 0.06108392284659203, 0.03048707589186961, 0.029274694170453586, 0.0055770602830307325, 0.008213080236600945, 0.0389782119600568, 0.0348101287818281, 0.042934749653795734, 0.036907478934153914, 0.015439239505212754, 0.044186411396367475, 0.009584056133462582, 0.023126752093958203, 0.09926651167916134, 0.02096051579428604, 0.0520517592667602, 0.06129576147941407, 0.03944617688830476, 0.020409124190337025, 0.07865565319661982, 0.02217923174612224, 0.013987777692818781, 0.03001964716531802, 0.06460144679294899, 0.09123585783527233, 0.044468186315498315, 0.02095585696224589, 0.03795477547100745, 0.01961258636583807, 0.053117264396860264, 0.03396508975129109, 0.01126023098549922, 0.0782612239709124, 0.09466845411225222, 0.009604593215044588, 0.026507474103709683, 0.05469743780849967, 0.050374297716189176, 0.07475535545381717, 0.05499033381056506, 0.024722480920900125, 0.01970141958736349, 0.025527490361128002, 0.001695829589607456, 0.04023768109618686, 0.04191346168227028, 0.02465335728629725, 0.03558046322723385, 0.04033164070278872, 0.03592799243051559, 0.011588391062105075, 0.05343642500520218, 0.018847010942408815, 0.016189064699574374, 0.055975371578824706, 0.04174634857918136, 0.016008010352379642, 0.014976522488723276, 0.013094846945023164, 0.017859214240161236, 0.057745412341319025, 0.06084475833631586, 0.0560630823019892, 0.004526648117462173, 0.02097113036143128, 0.05095955537399277, 0.011673496846924536, 0.03900996845914051, 0.03241475067625288, 0.02772370571619831, 0.06829962803749368, 0.030741810660401825, 0.02964145242003724, 0.011020282581739593, 0.041933937536668964, 0.06125051273556892, 0.062490348354913294, 0.029486525381798856, 0.015560218853352126, 0.07159246306400746, 0.018408971263852436, 0.03284403486759402, 0.09722848510136828, 0.06416022515622899, 0.03318517789011821, 0.03272181056672707, 0.039417285079252906, 0.030874720032443292, 0.023115408366720658, 0.07779316627420485, 0.058060858500539325, 0.04945928529195953, 0.06631645359448157, 0.04198898262984585, 0.03923147727618925, 0.036413861671462655, 0.035078693472314626, 0.05220965489570517, 0.1137472155096475, 0.03047115125809796, 0.01606276786333183, 0.03128643016680144, 0.035197110555600375, 0.0035990154719911516, 0.032064000552054495, 0.02573487796325935, 0.015647068685211707, 0.01575965063238982, 0.06760286269127391, 0.03231517301173881, 0.061721372039755806, 0.04197183530777693, 0.033408671952201985, 0.07005405030213296, 0.04931801377097145, 0.0603847603633767, 0.035649141573230736, 0.018635500709933694, 0.012095052497897996, 0.0017943948023457779, 0.06056202604668215, 0.013935054594185203, 0.05013311456423253, 0.05775228462880477, 0.04857202176935971, 0.01369205132505158, 0.0192897855231422, 0.043475615748320706, 0.018794166317093186, 0.04435681963514071, 0.02591873020719504, 0.06366290457663126, 0.10260314826155081, 0.01809521720133489, 0.013773045611742418, 0.043402547598816454, 0.05510807182872668, 0.050261821525054984, 0.022270215340540744, 0.013566765665018465, 0.05023863683163654, 0.03513926756568253, 0.030914968556317035, 0.024595837130618747, 0.03419839129492175, 0.08010234392713755, 0.04027682567539159, 0.05646179743052926, 0.04330029449192807, 0.018973302212543786, 0.018406143681204412, 0.012902163143735379, 0.031045022515172604, 0.05015872979129199, 0.03781351508223452, 0.032284288536175154, 0.0299431855455623, 0.004576978717523161, 0.00940493415328092, 0.033679670887067914, 0.014859740913379937, 0.03152314558974467, 0.03815861375187524, 0.06340166859445162, 0.04888633615337312, 0.05567560328927357, 0.0673577313136775, 0.03848007501801476, 0.029790123153361492, 0.0019397672690502077, 0.03855115792248398, 0.013681112995982403, 0.038399396144086495, 0.07198971987236291, 0.039473755095968954, 0.06673746654996648, 0.09939730036421679, 0.13748805213253945, 0.039490980343543924, 0.08223625598475337, 0.0314366037491709, 0.03729610085429158, 0.06684282183414325, 0.01963016969966702, 0.04265495626896154, 0.041957441353588365, 0.030370178355951793, 0.024895444003050216, 0.03957718079618644, 0.02080231217405526, 0.03023461209522793, 0.027411053742980585, 0.025441746329306625, 0.023215355249703862, 0.037279662283253856, 0.0346297312353272, 0.03836786600004416, 0.02322959335288033, 0.06616944156121463, 0.033404771966161206, 0.033441619598306715, 0.031138022895902395, 0.026327425366616808, 0.03310088475700468, 0.06646016307058744, 0.07760279055219144, 0.05885950959054753, 0.021332673168217298, 0.01764473727234872, 0.06824061245424673, 0.038487952915602364, 0.03349951824930031, 0.02797007833578391, 0.011728752524504671, 0.1071650929225143, 0.029605343224829994, 0.03660475689684972, 0.0509367306221975, 0.010291796916135354, 0.061216748727019876, 0.0658553943503648, 0.02454924881021725, 0.05201251449761912, 0.012824638397432864, 0.051084852166241035, 0.01094550842026365, 0.046513419147231616, 0.023385305212286767, 0.011126650897494983, 0.03542476435541175, 0.051079686818411574, 0.04011958313640207, 0.0562861051002983, 0.03419866960030049, 0.05640190611302387, 0.03148090254398994, 0.03245755775424186, 0.12553555599879473, 0.037244005798129365, 0.0664515838434454, 0.04469163955945987, 0.04107910215680022, 0.021198967842792626, 0.0373046615277417, 0.03713032361702062, 0.05858988733962178, 0.035474822216201574, 0.03559325043170247, 0.020274789894756395, 0.012711228955595288, 0.02539412642363459, 0.059543881070567295, 0.00913283312911517, 0.059883242938667536, 0.02083569397655083, 0.04998260330467019, 0.04787092228070833, 0.009045226306625409, 0.05381271243095398, 0.018694969003263395, 0.04823707196919713, 0.01830382192565594, 0.08970174952992238, 0.07553015762823634, 0.030328786924656015, 0.04717457253718749, 0.05669584483257495, 0.023718809679849073, 0.08281614049337804, 0.02018234612478409, 0.10613301783450879, 0.10833438369445503, 0.07189479176304303, 0.12223993791849352, 0.20857720548519865, 0.09132279301411472, 0.13031877198955044, 0.23027196322800592, 0.14832052867859602, 0.10789855004986748, 0.14422277512494475, 0.1955205123522319, 0.10080843479954638, 0.08266975928563625, 0.2066882318467833, 0.10714863950852305, 0.14112741075223312, 0.16325583506841213, 0.10866255397559144, 0.36124192527495325, 0.09319588469224982, 0.11914297050680034, 0.1775058126077056, 0.11299504883936606, 0.08471476947306655, 0.11277663477812894, 0.16465917695313692, 0.11665405952953734, 0.0914625616860576, 0.14448936941334978, 0.18252897978527471, 0.11142730640131049, 0.16299621696816757, 0.2923341665882617, 0.12380162443150766, 0.0986630491388496, 0.12437615805538371, 0.14774303388549015, 0.19582660373998806, 0.12499334290623665, 0.15960641292622313, 0.14781515579670668, 0.10415409589768387, 0.1441208040341735, 0.08764288344536908, 0.13534444762626663, 0.13272105948999524, 0.16976564278593287, 0.09491353353951126, 0.051468130623106845, 0.15776236890815198, 0.1736022048862651, 0.09631337990867905, 0.12048862525261939, 0.2034554662532173, 0.084448954439722, 0.23046720743877813, 0.14368011674378067, 0.09560087361023761, 0.0974283306277357, 0.09134748426731676, 0.12288273428566754, 0.10095181773067452, 0.16633524326607585, 0.08792839507805184, 0.19071546237682924, 0.1340336663997732, 0.13046463369391859, 0.1403135122382082, 0.21297251572832465, 0.27898812491912395, 0.09588984365109354, 0.09465957802603953, 0.09427565018995665, 0.230846400372684, 0.17138281225925311, 0.10654196346877143, 0.22374768363079056, 0.1313723248313181, 0.19420205731876194, 0.14357062027556822, 0.14022207964444533, 0.19058612087974325, 0.2033010550076142, 0.13042584905633703, 0.17401267192326486, 0.19286046212073416, 0.15545341389952227, 0.12154867188655771, 0.08772952176514082, 0.13845239882357419, 0.11156340144225396, 0.13818531471770257, 0.1605830347398296, 0.10132415322004817, 0.16433445765869692, 0.108011794363847, 0.12135783603298478, 0.12179873112472706, 0.14809739455813542, 0.11604077837546356, 0.120433468837291, 0.1328203291632235, 0.10783353049191646, 0.12454346782760695, 0.16208101529628038, 0.13020127516938373, 0.11723945077392273, 0.17319923354079947, 0.09636773480451666, 0.16122545261168852, 0.10498889329028316, 0.1657915161922574, 0.11959989598835818, 0.1469656638801098, 0.15092586778337136, 0.14991475094575435, 0.22879347146954387, 0.0788650056347251, 0.17942715872777626, 0.11119237955426797, 0.12664987589232624, 0.12306538425036706, 0.11605067862547003, 0.08771996290306561, 0.11710229446180165, 0.1940844565979205, 0.15463095100130886, 0.11365372716682032, 0.1209974565426819, 0.11246572685195133, 0.07185326117905788, 0.06329885887680575, 0.17446671787183732, 0.1276115805376321, 0.09724412957439199, 0.1392798637971282, 0.12605587573489174, 0.14469368266873062, 0.10189911728957668, 0.12769340974045917, 0.11915097085875459, 0.09757764331880026, 0.21667957305908203, 0.15443665673956275, 0.13084351492580026, 0.08391870476771146, 0.11151960730785504, 0.07417246524710208, 0.1264550324412994, 0.09697789151687175, 0.17455717083066702, 0.11355642418493517, 0.15007993817562237, 0.09276557262637652, 0.1023878734849859, 0.12365948830847628, 0.15671910223318264, 0.10965598543407395, 0.1149347928003408, 0.14003125863382593, 0.19104349164990708, 0.16314219741616398, 0.09264273234293796, 0.2729676745366305, 0.08728469329071231, 0.12531816610135138, 0.13329349283594638, 0.17448362399591133, 0.23141365352785215, 0.17391748406225815, 0.11759203029214405, 0.1423158563557081, 0.13961681368527934, 0.3017326060216874, 0.10237283757305704], [0.014792906804359518, 0.06468133899034001, 0.0500516304600751, 0.029626978684973437, 0.023539759131381288, 0.05202859312703367, 0.013986512331030099, 0.09076981878024526, 0.02807131655572448, 0.017049451344064437, 0.09816641875659116, 0.02202495037636254, 0.022692755264870357, 0.0767550129967276, 0.04625302550266497, 0.028311215792200528, 0.02632159950735513, 0.0344523876265157, 0.03287107501819264, 0.03709053708007559, 0.04290316755941603, 0.026660117182473186, 0.011825859764940105, 0.018237924778077286, 0.07391950421151705, 0.023611803117091767, 0.014352008929563453, 0.05867991356353741, 0.04550112229480874, 0.03721534776559565, 0.03023630790266907, 0.00877640743055963, 0.05817474848299753, 0.018686857329157647, 0.02300817173818359, 0.012002360108454013, 0.05365982258808799, 0.010122068670170847, 0.05937443391303532, 0.03990732890088111, 0.03792199851886835, 0.038561202891287394, 0.0468141076999018, 0.04194482484308537, 0.04115299409022555, 0.1224776181334164, 0.01399669923557667, 0.05943817326624412, 0.05443241687316913, 0.08190398904844187, 0.04481052790652029, 0.0469471191172488, 0.01776309869455872, 0.03589946427382529, 0.010826661819010042, 0.009527525817247806, 0.006687398090434726, 0.041256226832047105, 0.03330456718686037, 0.019445322977844626, 0.060389194695744663, 0.007575138442916796, 0.02960126512334682, 0.026031013439933304, 0.03725498216226697, 0.043354178123991005, 0.02112886828399496, 0.039312924272962846, 0.04977360709744971, 0.025436627365706954, 0.05136960680829361, 0.06254323379835114, 0.02338121412321925, 0.08657667698571458, 0.02920173734310083, 0.0832501558761578, 0.021633244832628407, 0.030542284257535357, 0.026335533329984173, 0.06328286559437402, 0.06527962876134552, 0.03592697568819858, 0.07470176497008651, 0.04120828409213573, 0.03978153858042788, 0.0636253815901, 0.027673080112435855, 0.04221316317853052, 0.023833005798223894, 0.10031892161350697, 0.04878999796346761, 0.05184417314012535, 0.038421074277721345, 0.038496276101795956, 0.039336001354968175, 0.022595151713176165, 0.05699920882761944, 0.03139745916996617, 0.0205783282945049, 0.04322710017731879, 0.04096849988854956, 0.06096971745137125, 0.07536266974057071, 0.04000132190412842, 0.039928539481479675, 0.017207332130055875, 0.05904635268962011, 0.06043184221198317, 0.07359131908742711, 0.13901156256906688, 0.08689175578183495, 0.04684909254137892, 0.03654496576928068, 0.01924300981045235, 0.05038689938373864, 0.04443855978024658, 0.005849498984389356, 0.03676074149552733, 0.0631493458058685, 0.062132592356647365, 0.029111167496012058, 0.0654674663383048, 0.0681348712532781, 0.022851187095511705, 0.0222780153126223, 0.09278356970753521, 0.03305039273982402, 0.06802890740800649, 0.06327173337922432, 0.01733151941152755, 0.018421823406242765, 0.08443163271294907, 0.058149760370724835, 0.029506272076105233, 0.0384889845008729, 0.044447840336943045, 0.03854566974041518, 0.005924563511143788, 0.05171316552150529, 0.023824560157663655, 0.03757666978344787, 0.027174701972398907, 0.08701837359694764, 0.03292814617452677, 0.025517116991977673, 0.03341918818478007, 0.046660664957016706, 0.04551344194624107, 0.057364968888578005, 0.0213929819437908, 0.02261826961330371, 0.058888534986181185, 0.05551839043619111, 0.08414955722400919, 0.0426081787009025, 0.017398166128259618, 0.034517184540163726, 0.08392156945774332, 0.019388674845686182, 0.07174397993367165, 0.046421129372902215, 0.03811045578913763, 0.057313029683427885, 0.0484893613611348, 0.04682845712522976, 0.02747856135101756, 0.052271639069658704, 0.07624468256835826, 0.009640374009904917, 0.08026228417293169, 0.019115371542284265, 0.012279674720048206, 0.04025908463518135, 0.020614532113540918, 0.04341908264905214, 0.027009405275748577, 0.04340454768680502, 0.07945508725242689, 0.08020261549972929, 0.013129319704603404, 0.07190439515397884, 0.036433851419133134, 0.03887486789608374, 0.035066459167865105, 0.02353927859076066, 0.07130786427296698, 0.07743522844975814, 0.031198708311421797, 0.020158944353170227, 0.041995045976364054, 0.03612123655329924, 0.04212648404063657, 0.03003878900926793, 0.013693817636521999, 0.017724840981827583, 0.014061861656955443, 0.038421864664996974, 0.041522349856677465, 0.021864618647668976, 0.024209881376009434, 0.0289317570059211, 0.017928816560015548, 0.0419790341402404, 0.031543369113933295, 0.03661745875433553, 0.04466303718800191, 0.04809805286640767, 0.03618646391259972, 0.05444980168249458, 0.024670567690918688, 0.010178958928008797, 0.02661467919097049, 0.06854075181763619, 0.005056337467976846, 0.010997898480127333, 0.030885329033480957, 0.016487252214574255, 0.033606090655666776, 0.036643411658587866, 0.04334706092777196, 0.10244822493405081, 0.04129618035221938, 0.03421999150305055, 0.04071378367370926, 0.08466729428619146, 0.046781905912212096, 0.03773673619434703, 0.06728207677952014, 0.004998268123017624, 0.08167281004716642, 0.034628198700374924, 0.0687749736243859, 0.02162539847631706, 0.004434971542650601, 0.09441246511414647, 0.03008137529832311, 0.04102482518646866, 0.05495839548530057, 0.03848191554425284, 0.08810705970972776, 0.027133137991768308, 0.04826020842301659, 0.08083749315119348, 0.11693686232320033, 0.008397095753025496, 0.02825749914336484, 0.021704392675019335, 0.04195785695628729, 0.0040181494023272535, 0.00875589539646171, 0.02062799652776448, 0.06993902483372949, 0.05959773872746155, 0.09135398548096418, 0.021729831642005593, 0.12822368909837678, 0.018968550612044055, 0.01220438105519861, 0.011770208893722156, 0.02900558214605553, 0.050948783100466244, 0.07133513820008375, 0.020874191031907685, 0.06500618444988504, 0.023058290826156735, 0.017757512177922763, 0.044012644939357415, 0.062126554985297844, 0.04847560194320977, 0.017579699160705786, 0.04507103287323844, 0.033976652412093244, 0.06300973298493773, 0.023464167679776438, 0.03741232860193122, 0.04665882443077862, 0.009139570902334526, 0.08325834918650798, 0.03657439192465972, 0.033535171023686416, 0.06928935617906973, 0.04138672607950866, 0.16181632090592757, 0.03343564902024809, 0.0726250650768634, 0.0642787387187127, 0.02848716601874912, 0.06131854541308712, 0.005059057903054054, 0.01659675981500186, 0.025706500091473572, 0.03807167486229446, 0.020759753715537954, 0.03770301671465859, 0.03937132758437656, 0.06751538574462757, 0.013302749412105186, 0.025199748670274857, 0.07085796692990698, 0.04122108613955788, 0.024375261564273387, 0.016653066559229046, 0.019321931649756152, 0.031985622335923836, 0.009792796299734619, 0.02655282303749118, 0.0313602924143197, 0.09701721050078049, 0.04451933884411119, 0.017406357583240606, 0.031606050906702876, 0.04045225454319734, 0.04835568572161719, 0.06791391162551008, 0.07074111577821895, 0.04668152301746886, 0.0428863764682319, 0.031103442524909042, 0.156252350716386, 0.06002314519719221, 0.020992183235648554, 0.056905698220361955, 0.024647301361255813, 0.013553678818425396, 0.0551854407240171, 0.019451137704891153, 0.02611416181025561, 0.059200548712396994, 0.03487149326247163, 0.04243977055011783, 0.02225125161203323, 0.03357466441229917, 0.060795149474870414, 0.07314560003578663, 0.02228471505077323, 0.09502149376203306, 0.013307507506397087, 0.012702625608653761, 0.0433879532647552, 0.016946381874731742, 0.026523613960307557, 0.012468928871385287, 0.050927899064845406, 0.016891620653041173, 0.011443393032095628, 0.027051733668486122, 0.06605042333831079, 0.03012334374943748, 0.04243296505592298, 0.05454113408632111, 0.05657209170749411, 0.002851736539923877, 0.15393961075460538, 0.2625267847906798, 0.1664793535019271, 0.18685835762880743, 0.16491223446791992, 0.1362902851542458, 0.17115037160692737, 0.18762052844977006, 0.07700801113969646, 0.15244903683196753, 0.24192709563067183, 0.10525913152378052, 0.09869618603261188, 0.2231671757181175, 0.11770937868277542, 0.13750381534919143, 0.16255075024673715, 0.1258999208221212, 0.10223918419796973, 0.13936326635302976, 0.1341553934616968, 0.12391363678034395, 0.08757195639191195, 0.179285972553771, 0.1357021924923174, 0.11980095863691531, 0.1598266081418842, 0.18161153682740405, 0.15728501952253282, 0.17650752008194104, 0.16250938293524086, 0.13596320583019406, 0.15974789595929906, 0.15143937460379675, 0.10248982973280363, 0.13814010308124125, 0.17282370681641623, 0.13030435948166996, 0.18353420397033915, 0.17780123191187158, 0.09438643799512647, 0.08899290201952681, 0.12974319193745032, 0.145596802176442, 0.17976268369238824, 0.24920401687268168, 0.19376561511307955, 0.14906242402503267, 0.23635132529307157, 0.15876455028774217, 0.138156890461687, 0.14940943743567914, 0.12613129278179258, 0.10932908422546461, 0.14495399838779122, 0.2170158104854636, 0.11021556478226557, 0.1297241632710211, 0.23453405796317384, 0.1981926744338125, 0.16212918068049476, 0.1410214023781009, 0.0977619260083884, 0.13156568398699164, 0.21412838104879484, 0.20013582485262305, 0.17040363745763898, 0.15842201944906265, 0.14602767827454954, 0.1295062983990647, 0.1154716698511038, 0.15923481958452612, 0.09018511031172238, 0.11936707684071735, 0.12621993490029126, 0.1778653683140874, 0.09325070714112371, 0.22008864325471222, 0.11331599060213193, 0.265237731509842, 0.10307563657988794, 0.10773258356493898, 0.1192670947057195, 0.13820334890624508, 0.18712959776166826, 0.1455359609099105, 0.0957674857636448, 0.132238722871989, 0.14595745626138523, 0.1699203360476531, 0.05006819519621786, 0.19518071261700243, 0.22039400733774528, 0.1405815314501524, 0.19865727372234687, 0.11280120728770271, 0.18625842028995976, 0.10059123786049895, 0.12784926075255498, 0.07250410984852351, 0.10891973040997982, 0.16990305884974077, 0.23707502317847684, 0.11103364158771001, 0.16364740702556446, 0.14143169129965827, 0.22552846698090434, 0.11558128506294452, 0.206957156478893, 0.24896595074096695, 0.19938570650992915, 0.1472078266669996, 0.09219902451150119, 0.1351103890920058, 0.17348148714518175, 0.1366685875109397, 0.164214838296175, 0.10945472240564413, 0.10699255100917071, 0.13351641915505752, 0.10814891356858425, 0.1167745323618874, 0.12557413283502683, 0.11905613180715591, 0.13611580623546615, 0.21485627949004993, 0.15469818958081305, 0.12802874174667522, 0.13827928545651957, 0.09346847553388216, 0.1267191331135109, 0.18920624570455402, 0.2581183979054913, 0.10295097061316483, 0.1114750413398724, 0.1548718669801019, 0.14527065795846283, 0.1734560463228263, 0.15508876706007868, 0.17024956759996712, 0.1114415779011324, 0.0979044777341187, 0.25566583732143044, 0.12706541921943426, 0.11994642700301483, 0.13303909945534542, 0.13967815961223096, 0.12077264516847208, 0.14788234984735027, 0.1363406769814901, 0.18157172802602872, 0.10183268022956327, 0.18036452092928812, 0.1109485246706754, 0.09414405998541042, 0.07709945857641287, 0.1432451291475445, 0.19552564801415429, 0.12594882835401222, 0.2507501479703933, 0.10444466897752136, 0.11634910362772644, 0.10474851907929406, 0.1755710187717341, 0.13237020175438374, 0.07578418735647574, 0.19107810541754588, 0.20412828249391168, 0.09908970241667703, 0.17660716082900763, 0.25898721534758806, 0.2275128659675829, 0.20403787406394258, 0.10596053529297933, 0.13757200387772173, 0.09969920603907667], [0.019403799815336242, 0.008440659821644658, 0.020352500177978072, 0.04065537294081878, 0.07880072080297396, 0.015147937265282962, 0.049178293338627554, 0.044812034466303885, 0.04009941156255081, 0.0895894700079225, 0.041482964079477824, 0.04282890455215238, 0.017142290307674557, 0.03552166286681313, 0.04517126733844634, 0.021346083776734304, 0.01828776927141007, 0.028198598593007773, 0.011328880573273636, 0.0511766855197493, 0.02375604508415563, 0.030625169165432453, 0.02045378292677924, 0.009440706598979887, 0.030149779049679637, 0.04046464469865896, 0.030659877556900028, 0.06366387679008767, 0.06011968005623203, 0.039493381191277876, 0.02903378932387568, 0.05996677165967412, 0.054886299549252726, 0.04509417303779628, 0.02654747400811175, 0.0583927098341519, 0.016828688385430723, 0.014754589719814248, 0.03795351381995715, 0.028536652425827924, 0.05353284483135212, 0.056403141788905486, 0.02142928038665559, 0.034722599884844385, 0.07195107624283992, 0.03662856499431655, 0.0591855424863752, 0.024139377346727997, 0.03945467818994075, 0.03789568567299284, 0.05503776075784117, 0.0012379369968584797, 0.04189217317616567, 0.033815190763561986, 0.06325499052763917, 0.042064451627084054, 0.018229820525448304, 0.03436467319261283, 0.019203909760108218, 0.07426728945574723, 0.03329952429339755, 0.0750246956886258, 0.03371906037500594, 0.01214256200910313, 0.01349913374724565, 0.02669334313395666, 0.013944326801720308, 0.05016285242163576, 0.003129344299850345, 0.059610852476907894, 0.014178569945215713, 0.026452510646777228, 0.02861137742002029, 0.012767310272465693, 0.06277824228163809, 0.03283503632701468, 0.02735446127189789, 0.031248031446011737, 0.03360884773428552, 0.045903585269115865, 0.024565034291299526, 0.011305833177175373, 0.012917796484543942, 0.06279269931837916, 0.026520704741415102, 0.010558855046838289, 0.018540437158662826, 0.06628831135458313, 0.023200141222332604, 0.06423295562854037, 0.03385997195437085, 0.026486565948289353, 0.07515884630265646, 0.02712385743507184, 0.04714697948656976, 0.016853099477884825, 0.03364948774105869, 0.04193886910798028, 0.04366797300463077, 0.02273197220347356, 0.04472280605114065, 0.012871776834799675, 0.027178694726899266, 0.011194339404028142, 0.14244193240301684, 0.02713533289352199, 0.03108753458946012, 0.015126940052141435, 0.06054941324691754, 0.009974048243748257, 0.02909080110839568, 0.06810466584283859, 0.008883201553544495, 0.04923183187202085, 0.06568781740497798, 0.0405683449935168, 0.029430060931190383, 0.033843373821582645, 0.055610635681659915, 0.02613422206195537, 0.06278568602283485, 0.033830048560048454, 0.009107272635446861, 0.05680773843778297, 0.02847283143637469, 0.0274848380649928, 0.07996994478162378, 0.030676676069560926, 0.034780220230459236, 0.017636076408962253, 0.07888488777098246, 0.012696363737632055, 0.04435442991962191, 0.06944515524082817, 0.030736689841432963, 0.03240188925701659, 0.05718982203688938, 0.040459727970301174, 0.033389346426702105, 0.028231856085767504, 0.020873756875516847, 0.018021306714217644, 0.013212202757131308, 0.043512771371752024, 0.05262840059003793, 0.03514682633976918, 0.10816098088980652, 0.030078130257606972, 0.040680053061805665, 0.033470470589236356, 0.046668706127093174, 0.06341921296552755, 0.026280336096533574, 0.08848377387039363, 0.0377080596081214, 0.0541163807065459, 0.05581595454714261, 0.019648628767754417, 0.034153172236983664, 0.021795487591589335, 0.027249120830674656, 0.12130322138546035, 0.03361469214723911, 0.06648403796134517, 0.045644119309145026, 0.011880659021699103, 0.043581167701631784, 0.01775443226506468, 0.022493123105959967, 0.03396649983187672, 0.034746330056805164, 0.011767418418457964, 0.017174980057461653, 0.011351064295013202, 0.03388828488823492, 0.04452068213140592, 0.011305536318104714, 0.04003231770184357, 0.03657057728560176, 0.07082504525897093, 0.0506999187200563, 0.047262954903999344, 0.07496549456845969, 0.049459129440947436, 0.027175134273420554, 0.07879076860263012, 0.0152373642049497, 0.02707272160478169, 0.028572741211974062, 0.03388292287127115, 0.014396152801054996, 0.03949805301090237, 0.01016721258565667, 0.018394232210994232, 0.024995793501148, 0.03157429811835755, 0.07043709498248063, 0.018560861062724143, 0.046988044850877486, 0.09263978601666167, 0.019806682103080675, 0.048262000709655695, 0.009568990535626654, 0.026047335122711957, 0.02270360360853374, 0.09156101499684155, 0.02197778689151164, 0.05783431050076615, 0.024270420217362698, 0.027031641875510104, 0.030762798596697394, 0.047870770140434615, 0.025891320838127285, 0.030498514242935926, 0.03858309624774847, 0.02951829301309772, 0.03746446076547727, 0.10233019376755692, 0.019710618507815525, 0.04496480556554161, 0.038367194356396794, 0.020333725697128102, 0.0820837149512954, 0.06860092515125871, 0.0431517387914937, 0.019017061094928067, 0.09140213602222502, 0.09680317511083558, 0.004013832885902957, 0.04106849315576255, 0.05618228235107381, 0.035935254345531575, 0.015570365867461078, 0.025598525025998242, 0.04312395649321843, 0.03018927243829239, 0.09268627414712682, 0.038486576231662184, 0.018150744690501597, 0.013438285059237387, 0.01450095518521266, 0.034296918820473365, 0.0461329089011997, 0.012716293185803806, 0.03150883327180054, 0.015181163216766436, 0.00794349231000524, 0.04651087358070072, 0.04699905832239892, 0.01490032154833898, 0.026215852740278933, 0.07871803070884198, 0.04744842131913174, 0.021623559805448167, 0.060718838140019216, 0.08586123178247362, 0.016080345631053206, 0.04508301855821628, 0.03449092364462558, 0.01245032415681635, 0.03536924428772181, 0.051272400305606425, 0.017904130872921087, 0.02611980955407489, 0.05897558519791346, 0.034625642001628876, 0.04762070719152689, 0.04905503745249007, 0.04188324513961561, 0.0381500790535938, 0.03505216911435127, 0.00571425880480092, 0.035554591959225945, 0.04003492635092698, 0.06293242346146144, 0.1457049182499759, 0.04880140477325767, 0.055686501727905124, 0.0036874358738714363, 0.08901274704840034, 0.055996485680225305, 0.06344342182273977, 0.026260034646838903, 0.03465681220404804, 0.024062004740699194, 0.005534238362088217, 0.03725867805769667, 0.0202166259259684, 0.09181512636132538, 0.07526306610088795, 0.01659895286138635, 0.014630565710831434, 0.08219969036872499, 0.008165702456608415, 0.03328898579638917, 0.05501778956386261, 0.043746603550971486, 0.011642771005426766, 0.02629990838613594, 0.010392244748800294, 0.03445280693995301, 0.02336932306207018, 0.02374711519223638, 0.08133905139402486, 0.0469917592999991, 0.035022253141505644, 0.02220575053797802, 0.037237051874399185, 0.019698833202710375, 0.018707257113419473, 0.0672834349097684, 0.0607299072726164, 0.022725220514985267, 0.01761339637596393, 0.035380847766646184, 0.0712142200791277, 0.06363764186971821, 0.02744032219197834, 0.04609839532349724, 0.0401276762568159, 0.006943535981918103, 0.010109877039212734, 0.07454820719431154, 0.031867260913713835, 0.019339470454724506, 0.01904269116494106, 0.015065428069647169, 0.03905428580765147, 0.022152382698550355, 0.04591304765199311, 0.005803090170957148, 0.03649325662991032, 0.06612468263483606, 0.018572065637272317, 0.0627641637402121, 0.04097789176739752, 0.01565690585266566, 0.08353905912372284, 0.08439691504463553, 0.03467250120593235, 0.028820830048061907, 0.041736199709703214, 0.028947026694368105, 0.06181895703775808, 0.009237670765287476, 0.005869512388017029, 0.031100080595933832, 0.04982008038496133, 0.04392574315716047, 0.03249863933888264, 0.07136759231798351, 0.06929072915227152, 0.13912772352341563, 0.08619499785709195, 0.1337030841386877, 0.22956281143706292, 0.21488280384801328, 0.1842311696964316, 0.16615420376183465, 0.1651399105321616, 0.20301519456552342, 0.17630984162678942, 0.17614765267353505, 0.09221043132129125, 0.14325823547551408, 0.09449364122701809, 0.07840695951017551, 0.13242889079265296, 0.11217608145670965, 0.0800214424089063, 0.14526339975418523, 0.1456153707113117, 0.1575672285980545, 0.11080658150603995, 0.08253497042460367, 0.1762685040012002, 0.09667252001236193, 0.12940549990162253, 0.15066152962390333, 0.1945949948276393, 0.1079797706915997, 0.24510023707989603, 0.09460284083615988, 0.11392659260309301, 0.10549342754529789, 0.12448054112610407, 0.08337145249242894, 0.16282417229376733, 0.15029536880319938, 0.09041360273840837, 0.13617410935694352, 0.09909792541293427, 0.14821481716353446, 0.4062601877376437, 0.08041993118240498, 0.16726369969546795, 0.18042073119431734, 0.11722908297087997, 0.1888862019404769, 0.11752539285225794, 0.1951326066046022, 0.2145779741113074, 0.12216262097354047, 0.16605477081611753, 0.0933641369920224, 0.16372102807508782, 0.18486057029804215, 0.151526918343734, 0.11971497340709902, 0.15013668278697878, 0.13620143523439765, 0.17066156346118078, 0.1215589432104025, 0.16951709752902389, 0.09313744798419066, 0.0885046504845377, 0.08881653804564849, 0.15303494757972658, 0.11999232883681543, 0.09280702899559401, 0.09972138883313164, 0.15205519390292466, 0.18000848300289363, 0.12345515278866515, 0.13877552992198616, 0.18138164916308597, 0.14509105822071433, 0.22053026565117761, 0.1012994471238926, 0.13530517317121848, 0.128019628173206, 0.16552067681914195, 0.08254081854829565, 0.1403467752970755, 0.19171991472830996, 0.11049659384298138, 0.1350789814023301, 0.11342477460857481, 0.08549718608264811, 0.10886619187658653, 0.10036607025540434, 0.12958691047970206, 0.094084265147103, 0.08101361963781528, 0.13968844577902928, 0.19586620474001393, 0.16056949796620756, 0.11154552310472354, 0.10520975643885322, 0.13332246628124267, 0.2205207958468236, 0.21640488936100155, 0.15231374331051484, 0.12945832597324625, 0.09257113735657185, 0.09369618870550767, 0.2464599852100946, 0.1210333542258013, 0.088912653591251, 0.17135797999799252, 0.13196112995501608, 0.10938121267827228, 0.09958318609278649, 0.1283058596891351, 0.10676534991944209, 0.24476909078657627, 0.32967651437502354, 0.10640074760885909, 0.12053355487296358, 0.08602061541751027, 0.1855550572508946, 0.18932783917989582, 0.2915810648119077, 0.13244852802017704, 0.11409533472033218, 0.14620827249018475, 0.12567680154461414, 0.11129383114166558, 0.15376937692053616, 0.13375426264246926, 0.16866310819750652, 0.19501117640174925, 0.14687669521663338, 0.1636315102223307, 0.15788277494721115, 0.11554301992873661, 0.12547259218990803, 0.1763862679945305, 0.1437092386186123, 0.10423096755403094, 0.14131288829958066, 0.1546822185628116, 0.2362086993525736, 0.13021663762629032, 0.21626909117912874, 0.17670279397862032, 0.06375619253958575, 0.11674623427097686, 0.3483345819404349, 0.18774871219648048, 0.12296254484681413, 0.06935738143511117, 0.16096442443085834, 0.09422717310371809, 0.14333150029415265, 0.22868949658004567, 0.10596066887956113, 0.2061350052827038, 0.15607597189955413, 0.11827119931695051, 0.18163896660553291, 0.17745405522873625, 0.14107787981629372, 0.18134040059521794, 0.17886009853100404, 0.11406160410842858, 0.07910828164312989, 0.14706119312904775, 0.1895538083044812, 0.17750674771377817, 0.11942327226279303, 0.0988453948230017, 0.10607291129417717, 0.13694701163331047, 0.1265719355433248, 0.11242701642913744, 0.12348448246484622, 0.13111199426930398], [0.08348018454853445, 0.028564432868734002, 0.016858845556271262, 0.02039209932263475, 0.04705041123088449, 0.02698852309549693, 0.0585024623433128, 0.006725745788571658, 0.03332319880428258, 0.06709796478389762, 0.01578821218572557, 0.05343921176972799, 0.02420090138912201, 0.09515203753835522, 0.02695301503990777, 0.04418638171046041, 0.022990885263425298, 0.004520890906860586, 0.07245799279189669, 0.0546852146362653, 0.06556391585036181, 0.018638241090229712, 0.02224049974756781, 0.037517379605560564, 0.022681866103084758, 0.01718606403301237, 0.04099536934518255, 0.04722209596366156, 0.011759498775063548, 0.000812864899444321, 0.031659526357543655, 0.08961111103417352, 0.05280125049466733, 0.05061651245341636, 0.014468503850366687, 0.022714429687766824, 0.061357578670140356, 0.03190606781572569, 0.021190574152569752, 0.12533596280263737, 0.050124253320973366, 0.012691122319665737, 0.03754604134883266, 0.04586772098264191, 0.10818432143423706, 0.061895984545117244, 0.03593756984628271, 0.021233229090285022, 0.051769828496617265, 0.030604121857322752, 0.010807514408952557, 0.05057975387899205, 0.08259482463472523, 0.03322994052723516, 0.026010532019427046, 0.02136020684702089, 0.0705090090923477, 0.07130253565264866, 0.03936709363188129, 0.06805950615671463, 0.03140939290460665, 0.04816249725990929, 0.05849672183103394, 0.034176364351878874, 0.02579622574558016, 0.032819106127135456, 0.026961740841215942, 0.030528066563419998, 0.02908118287450634, 0.04274965431250166, 0.04613138749846257, 0.07178013736847788, 0.012700904753728537, 0.04149559172219597, 0.038444184756372124, 0.022012743902450893, 0.06742323326761834, 0.06342777734971605, 0.04822911985684186, 0.03308095438114833, 0.01906514855363639, 0.05914562236284837, 0.07201332758995704, 0.003207257282156206, 0.05565099367231596, 0.020919395246892236, 0.05292666231980547, 0.034916515651275404, 0.01455734078263049, 0.0277213178560487, 0.0415124718711013, 0.0199563547357684, 0.06705506122671068, 0.026784135625348426, 0.029469930959749036, 0.04546852345811203, 0.028648059924307745, 0.05206973779422697, 0.03834009854472242, 0.03529929315845948, 0.05255558106000535, 0.012747579348797444, 0.010382900181866717, 0.03332249747472815, 0.09617834613891318, 0.027095572331745643, 0.05703045695554465, 0.0975994995678775, 0.017750307779351715, 0.02011856595345307, 0.039533464587293565, 0.08359613770153373, 0.055690312656224705, 0.019817881111521274, 0.0335202575661242, 0.032898838762775995, 0.02484929540514713, 0.03488266629574355, 0.028650870808633044, 0.025461522709520068, 0.025411783972231206, 0.01785480217222357, 0.05071997897175606, 0.029551062543760054, 0.03039757844817359, 0.0649421890557278, 0.08428911067312583, 0.038923975807847455, 0.026117609086213633, 0.07136604122933932, 0.05872511406778358, 0.04202267242362723, 0.02628544763865648, 0.036796843269257806, 0.05221696133958176, 0.0640531258250121, 0.008939286581153283, 0.0226589504381991, 0.051333245282876305, 0.037152406221139245, 0.018887508085754234, 0.06568536089616828, 0.013971811313240323, 0.08301804176880978, 0.036538650092552416, 0.0173368647301686, 0.020005982150905766, 0.03504972002701834, 0.024046250800893176, 0.03190612718753982, 0.03190056107996497, 0.06926868736627512, 0.03254162453231402, 0.009085794881684706, 0.06051969023246784, 0.045481678025680594, 0.08611149140051566, 0.029903187496529426, 0.025342836597701535, 0.04421509169333149, 0.10330843346309848, 0.025277676031691954, 0.08156379597494379, 0.0586723028391134, 0.007872578244132455, 0.030681791322422214, 0.04582463559927419, 0.008727639979042578, 0.023583480906381737, 0.03609275663620792, 0.08642699322081171, 0.01583939440024551, 0.016492230170115363, 0.01735771536914399, 0.04852016420045402, 0.04021525710413698, 0.06106426335463766, 0.015860248749959283, 0.027456231982796453, 0.015865568093431648, 0.03851256624329835, 0.030535235709976405, 0.02869464453397086, 0.03251735259254929, 0.03410201228689402, 0.00808198727099807, 0.02760660594503861, 0.06270787926041521, 0.09478583218879066, 0.09972001585992984, 0.02590345680800965, 0.002337740133953048, 0.005000965829822235, 0.06772204418666661, 0.003275671933806734, 0.046613404992967844, 0.011652078464976512, 0.017279218409385066, 0.006433832204493228, 0.06126811647845898, 0.025597395106160548, 0.018280856165802106, 0.05289333246764727, 0.04500030248891562, 0.05135360610438511, 0.03466428563115187, 0.08376902100280859, 0.0030555643843399594, 0.007092090290825581, 0.020810490641451906, 0.025933838478522375, 0.01590409483469557, 0.09148826968157664, 0.013258612034405814, 0.059186559228692204, 0.13390934182098135, 0.048249688479700126, 0.05062236428784672, 0.04560271860100329, 0.08986638757050969, 0.013290010447235545, 0.0808742517256178, 0.029095844001858495, 0.010942743920168141, 0.04830703423067462, 0.022064787008275744, 0.037131748540559784, 0.09658600785769522, 0.005325352549334639, 0.04714758433692623, 0.009373312168463599, 0.04871257711783983, 0.02335797562409425, 0.04862474022957031, 0.06990358728216961, 0.1279770882683806, 0.025360466315760277, 0.007496713378714048, 0.033254483350901864, 0.05628088409139309, 0.036777413843083195, 0.038470441941171885, 0.03587279890780337, 0.0568452465813607, 0.035516631105565466, 0.011598261626204476, 0.028287539425946306, 0.06280962028540671, 0.03861427016090602, 0.06448845480917953, 0.01751536052324809, 0.009119920687226113, 0.033008249884005636, 0.10893530808971263, 0.04164353144005872, 0.06352059033815749, 0.04124264552956447, 0.07398395231575705, 0.05332965221896302, 0.02021853139012819, 0.12091397235053591, 0.042099544079974294, 0.0120327501281281, 0.017807007861847524, 0.026216611586278304, 0.019533521663106512, 0.03940994523873087, 0.05409758581663482, 0.05909856648941059, 0.028523538676381577, 0.009939005885826191, 0.019736493486561812, 0.019058981306443457, 0.031148145790211856, 0.04681340265960898, 0.020307455524744, 0.01881279422377702, 0.008459869386570062, 0.05393000887124799, 0.038854443992022425, 0.04414786795678083, 0.04230464401189238, 0.03508873101964127, 0.039163129185908474, 0.035884394965250976, 0.054321681018336676, 0.10210190172074363, 0.03798714795266278, 0.0946730183204636, 0.04373623574792873, 0.03797856130404398, 0.008416012169618625, 0.034168182173743844, 0.030654838374175597, 0.04103623941773549, 0.019712533248821273, 0.028314084192970768, 0.04240119000314735, 0.0057987741183751496, 0.06707085412926972, 0.03701642250234727, 0.03136025901767425, 0.038398045435315, 0.06012292695231736, 0.06512827516417019, 0.17265063797822222, 0.04969847577740438, 0.06252402701647952, 0.04316395083151292, 0.016997476886899676, 0.02071477585559478, 0.037596321853925474, 0.008744480237510288, 0.004948023333781748, 0.057762889919104055, 0.009400099061167566, 0.044048965646652505, 0.03557705305865966, 0.04351569543359801, 0.037814947427250445, 0.029270616068970412, 0.03536682859703433, 0.03383113209565636, 0.044843924551969394, 0.03987844080256764, 0.05926355333940592, 0.03744369918422308, 0.05260244397504721, 0.02659758010850055, 0.0660648284247145, 0.012720312843157444, 0.06137990618299227, 0.062222722481237724, 0.05490017771080602, 0.03050051433092449, 0.05297539915773086, 0.01694547274382785, 0.06499802082544193, 0.04469806655833963, 0.08886304844054393, 0.06526050361571833, 0.05080558570625726, 0.0581169908400625, 0.03247430802730378, 0.035201355640310794, 0.041685488758957945, 0.041286294945166446, 0.03691679288749583, 0.0488401745678857, 0.041365281722391956, 0.035997476006741636, 0.0333641839097254, 0.17983536963583902, 0.1046054255857598, 0.08016504798433743, 0.1506037311628461, 0.09266908600693569, 0.1895977434469387, 0.1462119386997074, 0.14871066086925566, 0.10177274438319728, 0.14695329969981685, 0.1168772010714747, 0.07397811161354184, 0.22422013484174386, 0.18795514799421653, 0.08037485313252546, 0.12918763502966613, 0.11125484612421133, 0.13690467952983454, 0.1541066830395721, 0.12114526267396286, 0.1280395919457078, 0.12117088903323747, 0.117548970883945, 0.12415443401550874, 0.14258580515161157, 0.07960912742419168, 0.10962545347865671, 0.17023898457409814, 0.16625038610072806, 0.11486945411888883, 0.17821652290876955, 0.2136548759881407, 0.18836536270100623, 0.10253304499201477, 0.13116223766701296, 0.1285226410254836, 0.16459901846246794, 0.1505199130042456, 0.09749553952133283, 0.1626555118127726, 0.12111587362596765, 0.08469272026559338, 0.10041644723969512, 0.18073445186018944, 0.10648593874066137, 0.2845108020119369, 0.13901021186029539, 0.08582295922678895, 0.23542539216578007, 0.2378660041722469, 0.10403766777017154, 0.23435111856088042, 0.16946998599451035, 0.1238917805312667, 0.10026476709754206, 0.16340104368282482, 0.17484696465544403, 0.15536313905613497, 0.12462367914849892, 0.15895458462182432, 0.0979603169253096, 0.12863424519309774, 0.13655074930284172, 0.17151258420199156, 0.11698772170348093, 0.1590722001856193, 0.13484379480360076, 0.12051183221046813, 0.10846620396478102, 0.0715710075746756, 0.12088775227311999, 0.17286589049035683, 0.07782501925248653, 0.13547469454351813, 0.10617565421853215, 0.15265283058397472, 0.17894033953780308, 0.20747017348185182, 0.15354789036791772, 0.17679902084637433, 0.12563619122374803, 0.18362020404310897, 0.13409305305685848, 0.1353240682510659, 0.07380679424386472, 0.11900709811015986, 0.12099835454137065, 0.09269342102925293, 0.10876303334953263, 0.09376525296829641, 0.14395359816262498, 0.11784758884459734, 0.18176088662585244, 0.28805978188756853, 0.11988018290139735, 0.18128196388715878, 0.12130837931181304, 0.12562370829982683, 0.14902794384397566, 0.12479734170483425, 0.2903770934790373, 0.12575968459714204, 0.1327196494094096, 0.15915175841655582, 0.11051078370655887, 0.15020999213447794, 0.12615511572221294, 0.10295716012478806, 0.12422483414411545, 0.17300940700806677, 0.12320800276938826, 0.1682745196740143, 0.19901325227692723, 0.17806801915867254, 0.14277355367084965, 0.1651038569980301, 0.11235678699449636, 0.14388051145942882, 0.1392609835602343, 0.11109221188235097, 0.12847146252170205, 0.14338935812702402, 0.1037094603816513, 0.1657254947349429, 0.08580217167036608, 0.13278791215270758, 0.31709586444776505, 0.12766440660925582, 0.12924200476845726, 0.2215026572230272, 0.27985673455987126, 0.15958704287186265, 0.13654927985044196, 0.07538374673458748, 0.2552656119223684, 0.13093518500681967, 0.08375021498068236, 0.12362727909930982, 0.08706483204150572, 0.13050730718532577, 0.20717611972941086, 0.13802588655380532, 0.1911813233164139, 0.08920813968870789, 0.08584182462072931, 0.16337837849278003, 0.10997964345733635, 0.14367358584422618, 0.14431327261263505, 0.21113466122187674, 0.15586799243465066, 0.15232313890010118, 0.15529986354522407, 0.11940253665670753, 0.10588214223389514, 0.19197206682292745, 0.21219192480202764, 0.2194250444881618, 0.08502317636157386, 0.16277492337394506, 0.1571667508687824, 0.1332439322140999, 0.1199364302738104, 0.15797039290191606, 0.09904947801260278, 0.17654023395152763, 0.07831261027604342, 0.13700014940695837, 0.13148627418559045, 0.19629328104201704, 0.09076756265130825, 0.09487192131928168, 0.09403178046341054, 0.08439760524197482, 0.13967136153951287, 0.12210932734888047], [0.02944960167951649, 0.04584200927638449, 0.02602754389954498, 0.018205285123258363, 0.012225776245031739, 0.015404106234200299, 0.031511430788668804, 0.06635793964960612, 0.01923371626617154, 0.05293792441079859, 0.028988588819629513, 0.05753818986704573, 0.059476586829987355, 0.019111972505925223, 0.027139490775880404, 0.0072419994830852374, 0.05926932724833023, 0.02277936760947341, 0.09135929183685221, 0.06400655605830252, 0.04802719260624144, 0.03587838356907014, 0.03628872073022649, 0.056534112300141715, 0.06104881555074826, 0.08040966728003696, 0.021433473521028645, 0.017151800930150785, 0.03950908132537734, 0.04040962929138914, 0.021587062838079873, 0.02277508727274835, 0.09844744781730697, 0.05355370660254266, 0.011869008230860345, 0.040654656768310815, 0.04314020952733699, 0.05122605689393822, 0.03674846637295559, 0.018361208494752645, 0.051136090041836724, 0.004191115267531131, 0.03735298276296817, 0.04167114675510675, 0.05609615982393734, 0.03274954462540336, 0.014809344447712647, 0.04607315859175287, 0.05154783357284032, 0.11235980011406355, 0.036246351519366726, 0.0600159760506358, 0.06338885170407593, 0.0292304046524805, 0.03410464691114612, 0.015237121151585598, 0.09526730791549198, 0.06738549505826086, 0.03155606726068072, 0.07660697679966688, 0.07868985878303647, 0.025911531374731567, 0.08926068374421448, 0.06576393949217163, 0.07100559494574554, 0.04701635036326479, 0.06481928197899833, 0.05018918753194157, 0.05200983905524481, 0.03516841170494445, 0.06923776949406601, 0.012784291538991965, 0.01558963573188521, 0.016167403264262248, 0.03409937024116516, 0.037369759011198767, 0.02645863150974037, 0.10567864534095861, 0.052377985120983794, 0.03881298020132817, 0.10289325378835201, 0.0485195036890218, 0.0628370203776285, 0.043099610338686034, 0.01668134795181686, 0.03713372636411805, 0.009207807670463808, 0.021560119166679215, 0.08749152984819375, 0.030864758555253502, 0.04523255760432221, 0.06233804480871186, 0.010506926046218723, 0.07131929334718734, 0.059774258552351967, 0.031291717968997546, 0.06943979693460278, 0.0933986394375097, 0.055417395269614644, 0.03730950033059344, 0.0008575463061788469, 0.005347847509256098, 0.04651126320823096, 0.070979775628075, 0.051856173668056726, 0.049748088349588215, 0.011725912881956901, 0.04791722116351593, 0.08352337754331529, 0.019611482421169057, 0.04918789301882498, 0.036779662550543435, 0.042036520899273455, 0.016033067113312427, 0.030384281017177273, 0.03805126209044829, 0.05679169320501387, 0.05148735595867038, 0.08460059005301446, 0.042344219036749564, 0.03361928975209594, 0.0462829637399409, 0.03134392805804964, 0.030119022594590206, 0.01744021436024923, 0.05679790127032902, 0.030430817387241405, 0.01443450420993031, 0.042871566911344416, 0.014641223879152676, 0.02792612463963451, 0.048599388464936055, 0.01399324453814188, 0.056242745122290216, 0.0245662792440271, 0.05349912906240206, 0.07705202791839838, 0.0472180586803006, 0.03841622434265446, 0.042857610824285075, 0.037733125645900145, 0.06356801357469521, 0.08388311136513948, 0.008442285125056515, 0.026569868314254563, 0.01757100304530468, 0.02008213949011406, 0.03889911386067979, 0.029215227732493076, 0.07070520325214602, 0.06785765683162026, 0.10308928467566147, 0.027388369999243878, 0.07027668718365021, 0.10715850265114568, 0.02322779364476446, 0.018938217181130312, 0.05865329643711448, 0.04256891166733112, 0.09847841763985343, 0.023858583917899523, 0.02377717217314057, 0.053101475205039605, 0.03298695766716264, 0.01340783102932619, 0.03878064853779506, 0.09146290307398885, 0.037897674628766254, 0.03389959521882702, 0.023275250277947634, 0.023183225821412634, 0.06505318466224708, 0.009836023618845502, 0.04598397841618862, 0.020788222500414122, 0.029079949053993914, 0.0012159465813965653, 0.012703659976978088, 0.03905481273250189, 0.05030787178839091, 0.011365322807250777, 0.009685088407422882, 0.023697986871411558, 0.058156736558885314, 0.04938592770486139, 0.02870815162168583, 0.048205449056695215, 0.043513851196621545, 0.028672465450654272, 0.03141583474643994, 0.04332517499278765, 0.035690349322976544, 0.034454699416528456, 0.037111254132469185, 0.020258336480765138, 0.04236086540913675, 0.057248340381192975, 0.06908781113452278, 0.03931063103664201, 0.04619935709342826, 0.009967899550247239, 0.03698495915159583, 0.04349235488916747, 0.05757823986641597, 0.0527478752337629, 0.013463197101373225, 0.03164867986924946, 0.039653395651839674, 0.036726654652738944, 0.014057952394068707, 0.018422007087792736, 0.020345045304566156, 0.02948009281681152, 0.04944463158608414, 0.042935703313560225, 0.020571773275150917, 0.04622374406608287, 0.0387282974406844, 0.04644856286176946, 0.018682851587072946, 0.05214067597989924, 0.030628807544417214, 0.07629598723724484, 0.025165710067085456, 0.02433782021398656, 0.025825162083492614, 0.036194193380651996, 0.11233635566895828, 0.03224232750653755, 0.023770426050759852, 0.04329883617174346, 0.06929098890395835, 0.03575110895326361, 0.09245508030289784, 0.07904869460617192, 0.05255678333924152, 0.004909489634883357, 0.000950169931002165, 0.04226324330375064, 0.06965228865738027, 0.01740381572744809, 0.031588194833602756, 0.01301629710724228, 0.0685713802522514, 0.0480083012371324, 0.0363769138493808, 0.06181860822835006, 0.04099262710951734, 0.038659678466501646, 0.04312033481255639, 0.049507580552017316, 0.051981073411297984, 0.050976487473235466, 0.004711499477707548, 0.039762094311299734, 0.02459656257997267, 0.036926644897903316, 0.0692509648797568, 0.022123335038486402, 0.05753376295615453, 0.030473724655166734, 0.01410229293469456, 0.0712165652657859, 0.0491919822525233, 0.11012830305844545, 0.013995685276313452, 0.05397064516728278, 0.026711753962445073, 0.03156378930725623, 0.08907588897272944, 0.0481966212100815, 0.03256313197198324, 0.08367315036593936, 0.049227204581256956, 0.06083139967813622, 0.011239321902394295, 0.0622100688633509, 0.03353151594637893, 0.00792959559476003, 0.06799421942560002, 0.00843749456180376, 0.011588657307584072, 0.03305816302599851, 0.03673807259474415, 0.022990243305685, 0.039389821904478595, 0.024324327969225124, 0.04218020068947226, 0.03337874855787959, 0.06297067375271581, 0.019215034553781152, 0.0880522075749468, 0.0453576280415291, 0.017316205194219947, 0.03661580747575499, 0.025156112242257223, 0.03207340727385599, 0.03990344746853225, 0.041341388277942315, 0.015464448406419251, 0.019311133401060943, 0.005218365467953845, 0.01096985364711145, 0.05201661115279421, 0.028937165407114662, 0.05227842601016164, 0.03225538559490815, 0.060257155491854064, 0.10623396476148628, 0.0542253576713847, 0.009037113704835065, 0.06921295949723572, 0.008641422828077339, 0.022961754111747723, 0.00994879295831197, 0.030429305261350237, 0.023449525106116198, 0.007796734462317545, 0.11277400015387684, 0.0364052638906287, 0.04137843628996052, 0.021792483748868108, 0.019680665427586064, 0.016839130403241143, 0.05569216431467794, 0.01466739386160043, 0.07633891305886209, 0.026998512403224595, 0.051346555701456964, 0.10283182622515596, 0.025844808587862644, 0.036057756951777264, 0.049781343986978754, 0.0681191599869635, 0.03075844590057386, 0.05798807607789058, 0.05088319579954259, 0.031146112305577844, 0.049411457584938034, 0.06265190648264252, 0.03702747308125254, 0.04079927908605896, 0.02669260840775678, 0.047623939244658686, 0.07020187869784422, 0.05778116530564148, 0.02876750488212565, 0.037775966120534576, 0.04440623182745185, 0.04517967587162275, 0.06277630527620204, 0.03446359776717145, 0.2383595917490311, 0.11952644563280046, 0.1938360746135004, 0.13272922311443835, 0.09027260952279903, 0.09446488300454803, 0.12376579354167916, 0.1723965266137384, 0.14775091549381614, 0.14788652071729302, 0.13907071173889562, 0.13734043895965442, 0.15570173651212826, 0.2345089436857961, 0.2006870327750221, 0.10519650910282508, 0.16503903781995177, 0.07785313922795467, 0.20805433276109397, 0.0988898346258793, 0.18060776725178584, 0.16676816769177094, 0.13154931220924482, 0.17363355320412666, 0.11253099874011241, 0.1058551057940349, 0.1794677393627353, 0.08577307948144153, 0.1584536349400878, 0.14186149870511144, 0.09861815662588924, 0.1880287245148793, 0.16666086798068136, 0.11958265589782968, 0.12525281257694587, 0.10569563310127705, 0.23807294463040307, 0.13181320508010685, 0.13503610010957345, 0.10001748349168338, 0.14100028085522354, 0.10009154982981272, 0.15539760439423844, 0.11895115501829423, 0.17138205526862293, 0.1590121752815321, 0.12581013579620048, 0.16934244049480185, 0.08909065029001795, 0.12566621851874515, 0.14464854524703696, 0.26289370260201395, 0.12623789487406611, 0.1398863468784839, 0.09692741805338301, 0.14469639892922714, 0.23902188433567062, 0.28231039352249354, 0.11687221383908764, 0.1692735988763161, 0.19305165420519188, 0.16280616779113188, 0.33584138669539243, 0.2153498967527412, 0.17707245773635805, 0.14600216323742643, 0.20362996001495048, 0.1902842300478369, 0.16458387864986435, 0.1691524952184409, 0.11508463983773254, 0.18233615497592837, 0.1923998407437466, 0.2088620566064492, 0.18638313078554347, 0.09300289661041461, 0.12398441540426575, 0.26828344620298594, 0.2555707236751914, 0.13860965991625562, 0.17692435474600643, 0.14630153076723218, 0.1574061973951757, 0.2070020415703766, 0.12436576798791066, 0.1095340505708009, 0.13686709717148915, 0.1839547642157413, 0.30214645725209266, 0.10197577372309752, 0.17796944710426033, 0.15953022404573858, 0.17129369516624138, 0.24621317657874897, 0.14057887456147, 0.12720529921352863, 0.18128010851796716, 0.20389045384945348, 0.17657906311796978, 0.08904312315280549, 0.11337162941345014, 0.10311822101357393, 0.09356296577607282, 0.20491700735874474, 0.07738314452581108, 0.10355993988923728, 0.09659595263656229, 0.12500916549470276, 0.18708131363382563, 0.1653892721515149, 0.17520607507321984, 0.10250219391309656, 0.0848273235897068, 0.13420387054793537, 0.18976371735334396, 0.17253636207897216, 0.1265308799338527, 0.10519246439798735, 0.16202384023927152, 0.12407106114551425, 0.12150897440733388, 0.1650686643552035, 0.13810666190693155, 0.07108106394298375, 0.09142237438936718, 0.1370514466543682, 0.11620290053542703, 0.17868619848741218, 0.1954161812318489, 0.16500690282555297, 0.11428043377236463, 0.3040910029085353, 0.14995307545177639, 0.1752074554678984, 0.0937593009439297, 0.1373251952463761, 0.1785011068568565, 0.1447914680466056, 0.1496889302507043, 0.17675514507573098, 0.13810688455123454, 0.1286700612399727, 0.18114233622327447, 0.14210139052011073, 0.16506896121427417, 0.09581027057720348, 0.1891746450564824, 0.14634098333772272, 0.21086165477754548, 0.14704016066389158, 0.1953613365185447, 0.1523979177000001, 0.12938811880303547, 0.2348276664270088, 0.2479673019843176, 0.21892505959840491, 0.18860133597627282, 0.19287057017209008, 0.16413084202213213, 0.15990910527762026, 0.14337089349282905, 0.150016900151968, 0.11210661643417552, 0.16219057113630697, 0.13340925303054973, 0.14729813119629398, 0.1559277204796672, 0.12537066562799737, 0.15843257278902456, 0.14398436760529876, 0.09123513053054921, 0.1704904984217137, 0.12186470805318095, 0.1706832490162924, 0.08064475739956833, 0.06853844373836182], [0.02772328083665343, 0.023640336839889642, 0.06810819846577942, 0.003681041807794827, 0.043831490402226336, 0.023259941626747604, 0.02298540079209488, 0.008946551279223058, 0.016780146361270454, 0.030968540486355778, 0.06515237269923091, 0.01804866969905561, 0.04140192897466477, 0.03844212900730781, 0.00915535452804761, 0.043953625645372085, 0.03855353650578763, 0.06228194586583413, 0.01633856663829647, 0.01615388689970132, 0.03651172497484367, 0.01731694177578902, 0.012964566631126218, 0.01117702602641657, 0.021397761374828406, 0.007571886908408487, 0.01579888612468494, 0.04001848035841249, 0.018299122275493573, 0.018756624776870012, 0.09400326714967377, 0.06400043333997019, 0.0679180899169296, 0.04692588627221994, 0.03143762420222629, 0.00970369497736101, 0.03076046268688515, 0.048018817469710484, 0.03778143574891146, 0.0333819546358427, 0.015442032763530733, 0.030117298956611194, 0.06653794014710002, 0.07136656815418974, 0.017726943115121685, 0.06134738156106323, 0.03562045385478996, 0.00969592005276354, 0.09244394808774814, 0.06267819335334934, 0.04859002998273354, 0.021311097079887986, 0.042952665098709986, 0.03174932993715629, 0.023469466614187695, 0.04326726892031729, 0.03040009061805904, 0.022865718347020447, 0.027115244811284356, 0.06832632308942266, 0.03434866877796594, 0.05401529277150985, 0.03707244723045733, 0.02844450922566466, 0.04984622624760959, 0.0192305380187463, 0.04545658972347155, 0.03800950144068338, 0.04117677250178531, 0.01897034660942154, 0.005146702760612243, 0.021781796822324395, 0.050188434252049774, 0.030102116470516194, 0.024177761224564165, 0.011999210619251244, 0.030362287470779847, 0.08498769428115338, 0.018545591374277137, 0.02992139237903757, 0.07001588164712302, 0.038582584165851586, 0.033695211459416896, 0.048932872523437254, 0.04675594187574461, 0.05585489503573626, 0.013282045347295934, 0.10097415637574159, 0.03384171512152534, 0.014248453353502555, 0.031421267267432995, 0.01960751564183738, 0.009840515467658406, 0.015794223581906408, 0.032092116816784255, 0.02368330162425991, 0.03552763344487175, 0.08752067398745567, 0.010903183738264488, 0.050336678250459954, 0.07128942932467908, 0.06562960334122181, 0.013172931085136952, 0.02743354267295217, 0.0045878660239395685, 0.04020661108370405, 0.026210906326014083, 0.01147890108768479, 0.03743859320820775, 0.0331664126861142, 0.029732790389971342, 0.06338910403428599, 0.03139653890684713, 0.04979542994988151, 0.07514173237723298, 0.04196696310827974, 0.08308855321956798, 0.029919655753474217, 0.04496813409787137, 0.018091617785103153, 0.043211088341195136, 0.02702195313759148, 0.016453204334538896, 0.017872433745651506, 0.04896028003713582, 0.04476155729207676, 0.07377889691269957, 0.07057742026518099, 0.01960561945452355, 0.02404766459221719, 0.04105983600311447, 0.048523763616685756, 0.04191924301267136, 0.04728173495095689, 0.02703029487747699, 0.06425325336749665, 0.04223720505251549, 0.030640744989796076, 0.06744445126969367, 0.03410258002986666, 0.017218061730090994, 0.04934255288389977, 0.02589078834716929, 0.024773689110588748, 0.0035483599504004815, 0.05642638585413806, 0.041578775344532914, 0.056633159329066984, 0.07091726452927105, 0.07290606445167214, 0.019262938330939505, 0.026579167424642947, 0.06929911542101763, 0.019806533673545346, 0.07544848427642137, 0.07004809827776626, 0.041918218848877586, 0.052225484905648045, 0.010949329553113785, 0.03688761906232685, 0.018117049330612645, 0.03241663573135156, 0.021626287198159844, 0.036572261960827745, 0.016693506186129525, 0.030789744123467244, 0.005755951269748039, 0.035279370204079896, 0.07506760666728951, 0.011558628157217754, 0.09395332061103545, 0.05398731751483865, 0.03410382312722504, 0.04263447299308609, 0.04514092463068664, 0.022119136338005774, 0.06016001949319616, 0.022183504661370534, 0.03361772382049821, 0.023874747894296888, 0.044966037530684844, 0.06463381927460432, 0.048685670553823, 0.017772423780115787, 0.0022010622751622577, 0.05676260101608932, 0.05314880938385613, 0.03893674445862416, 0.01529569051854196, 0.037538438045885414, 0.006384956213878468, 0.05932663960265927, 0.03743615154235158, 0.01677498843491776, 0.040241792594315484, 0.034079499237122945, 0.038849556949571706, 0.04522323994024191, 0.03496715609799139, 0.024931727602961473, 0.08794332708930597, 0.015741961542516947, 0.024319077274412848, 0.03642130541265942, 0.03207583780749701, 0.04458775001694448, 0.03355412176460959, 0.0060750464763259515, 0.03037284637684934, 0.050869094993686303, 0.09422873161383905, 0.027747124186134897, 0.01001315478788456, 0.040701144898775965, 0.019972370282630436, 0.030100281510385685, 0.029361781489569694, 0.03939312075090129, 0.14544405334163457, 0.010651536304067122, 0.012840404397138627, 0.020985375886084512, 0.031363613525172696, 0.028716432134388015, 0.0793000303383451, 0.04963580140611157, 0.031013715015433263, 0.056329487342736684, 0.040707067237235606, 0.014500176857836777, 0.07620922275236808, 0.03443896959652193, 0.025154626091534737, 0.03459330662735738, 0.04987422747944947, 0.037719251195085235, 0.003774912124754337, 0.057147078041452914, 0.009927716891979799, 0.04863961657974869, 0.04800868715392426, 0.030155747772369068, 0.08567737211706117, 0.012054365179210436, 0.0660837977193296, 0.03561084304237738, 0.025660666906333063, 0.04923950196825899, 0.03387765733350534, 0.03395996151084546, 0.008941054747992894, 0.06165702412545215, 0.05915288427786436, 0.09915806906064972, 0.05194805526116397, 0.027485212849569507, 0.04957808829203714, 0.039642679039388895, 0.07834330550394952, 0.039637432055315, 0.0283491117079393, 0.07408230914734304, 0.029709737427765504, 0.12489285611081868, 0.030380458956642542, 0.031060550099937245, 0.0508060643915087, 0.06972376490011811, 0.05693352875823621, 0.05494437260495033, 0.06365652952808887, 0.013171149003028404, 0.03697053180076182, 0.023213991553348023, 0.055108617307269014, 0.03814275034528691, 0.03039125349459937, 0.052601787174353376, 0.015410428404720733, 0.07878657546825707, 0.07110655671567656, 0.01129306359871407, 0.03486105124466121, 0.05136379950272385, 0.06057993778085802, 0.030639243996120058, 0.09776635663001798, 0.09454629660467617, 0.006347906346491072, 0.07279241195647046, 0.040824096504366025, 0.058794835131266154, 0.01756171135639306, 0.025288227516284678, 0.15122796641662717, 0.053784785413881764, 0.01647400487854611, 0.0015581102888972964, 0.05321247081155889, 0.026834377167688217, 0.0850315997377038, 0.038544723502127454, 0.008237245492637157, 0.07752191129839048, 0.05149100732523948, 0.02633275398693513, 0.07368710066657513, 0.061752939291181974, 0.04858703170611989, 0.032870655704755336, 0.015201242022158112, 0.05138961139891762, 0.02317169841262512, 0.018092988902935758, 0.04338986429502256, 0.04664296473492868, 0.01952720784174744, 0.030610240864916705, 0.026912222892860882, 0.027197088857064955, 0.027630456715996843, 0.03717721992870793, 0.03692314196086954, 0.1078517353744246, 0.13843043125234544, 0.0707193931157235, 0.04760737450851593, 0.030860982878948562, 0.06987951201153919, 0.04961960032233037, 0.00973426589553128, 0.06201803444128018, 0.036079947167309, 0.029626321884279605, 0.026798262406373397, 0.05851340160006657, 0.031654754347982816, 0.017735295987222344, 0.052520458921208046, 0.05238200013991445, 0.00745280096452916, 0.02547310577938333, 0.04687309359724168, 0.04225618176860735, 0.028335608330962714, 0.0037558537724180496, 0.05609832689515315, 0.05285730119794607, 0.02212430725194281, 0.039006587976473384, 0.05300086224451661, 0.03744844892935362, 0.12305320560699329, 0.11077597533585504, 0.16243484162259847, 0.09616358482162468, 0.08291181817185134, 0.127893210737966, 0.10161140147829428, 0.11372809036402032, 0.07700400354224257, 0.22084719239501283, 0.24298612552229315, 0.18112249119440094, 0.10414130127173848, 0.11858491256134585, 0.09417877765372396, 0.11431797902332619, 0.1241983320505824, 0.11876425996888429, 0.204079300747253, 0.07374950786470436, 0.20422174857230857, 0.14627303229644895, 0.11976376219536178, 0.10175766394240782, 0.20704524940811098, 0.07467104005627334, 0.12941989756654948, 0.08082380052655935, 0.1794574235100299, 0.14920993329724297, 0.15396614995552227, 0.16372228972613811, 0.09043620113516226, 0.11988053913228214, 0.18968628166476265, 0.07679335976717994, 0.11671182830468751, 0.13192259764764458, 0.12279687522095628, 0.07658103131689131, 0.06876538507640362, 0.06399999547284096, 0.1991547501529567, 0.12276186811504886, 0.11884338775416836, 0.15657836134778336, 0.08500285635818727, 0.12508321698987857, 0.1630092936102301, 0.12178868986666203, 0.19752350955968723, 0.10848905469174497, 0.13516297767637298, 0.06203338947671, 0.11646159837255254, 0.222695303382352, 0.0919669029826764, 0.10453521841554902, 0.13444066018564627, 0.12051310870447196, 0.1126514641509857, 0.17916230106493458, 0.138432034291327, 0.12900197936687618, 0.1358747121412307, 0.10170827401452698, 0.11061107012210414, 0.10742123035015538, 0.17832359997555614, 0.13198202883359045, 0.1335721099167131, 0.21393564529716969, 0.26201779022812843, 0.13207929470809177, 0.08005279814824462, 0.11931496323086321, 0.20726157061289996, 0.1349028549157083, 0.12440173246432096, 0.20794344105524942, 0.14239697309676558, 0.17778868961613625, 0.17877006117487326, 0.13704377284739166, 0.21541343943681568, 0.11366405044100247, 0.10320032481104136, 0.30073233938310295, 0.1148035291407723, 0.08207349557778798, 0.1427628073724918, 0.15399598429212347, 0.14863997872453183, 0.1592533287475817, 0.14264577068388462, 0.06609014308196492, 0.10329047348932363, 0.1148490747436881, 0.13997484056744725, 0.20789356873137876, 0.179127108422108, 0.20009567466331646, 0.09897090683807619, 0.10495343347429298, 0.11784767048084177, 0.09791735399630852, 0.115138141263742, 0.07168042240664363, 0.10248248247080483, 0.07819871287210844, 0.16325623582815751, 0.14069323951844126, 0.10816724461619742, 0.09906033563311212, 0.19927857007132843, 0.11290967959212139, 0.1681838885997422, 0.10912249999819323, 0.1438787006190978, 0.14821769669651985, 0.0836827685998287, 0.07915809459518641, 0.2675302850548178, 0.10947247457806952, 0.20274903072277084, 0.10825280682183802, 0.1477250739117153, 0.17446741549065337, 0.10357358798501082, 0.07877473821281455, 0.13294906209921464, 0.1361126743722707, 0.18900922033935785, 0.14079534419579431, 0.10767462183139287, 0.13821828091749921, 0.10604927389067598, 0.22097835957538337, 0.19427609397098422, 0.08206493119359948, 0.10827501188032329, 0.13277140678837895, 0.13384327583480626, 0.08707512562978081, 0.10711022594477981, 0.1489240728551522, 0.09882704151095822, 0.16628326324280351, 0.2688096882775426, 0.14821468357695267, 0.12749783898470923, 0.08473758309264667, 0.1462178907240741, 0.13189181336201727, 0.30342387151904404, 0.12409498798660934, 0.21064269152702764, 0.23291907040402293, 0.15057109150802717, 0.1719648638390936, 0.15908248635241762, 0.10764122518594377, 0.16201465245103464, 0.14420407300349325, 0.12060626308084466, 0.1363936811685562, 0.16116991027956828, 0.1295991410734132, 0.21521353453863412, 0.034199315268779173, 0.11245466143009253, 0.15784712217282504, 0.11992963962256908, 0.13248738687252626, 0.11488615986309014, 0.09718311761389486], [0.023329493851633742, 0.043661085874191485, 0.006413967694243183, 0.029798377690894995, 0.011366171638655942, 0.026398181726108305, 0.0719269564433489, 0.029670214353245683, 0.04430364104337059, 0.0283284187753452, 0.04922496329527348, 0.012494663769757608, 0.029274143125803676, 0.0388467479206156, 0.018385088951617945, 0.02316484838956967, 0.027039775814046152, 0.026950372994178906, 0.010226739323115908, 0.020387254953675438, 0.037981425994075835, 0.04124555103771854, 0.05897431983612478, 0.14623558352468535, 0.05598457049927674, 0.08908702118787915, 0.0467267086787615, 0.022656766668660566, 0.010954125682474114, 0.049034331532311626, 0.05974800878902897, 0.039405599964084104, 0.03386462893104181, 0.025149724206130486, 0.07744788948912174, 0.021852701611351222, 0.06456712988438085, 0.038234557723626494, 0.005266809621389257, 0.032675496840965934, 0.06714071249007247, 0.006816485401941463, 0.047126889548962936, 0.03999713248049375, 0.06497389360447414, 0.01905215725855669, 0.04762042888614815, 0.05754662066465244, 0.023033273027976975, 0.031494988506892696, 0.06070105628168676, 0.0495589742786251, 0.09109632665058598, 0.06919778257724829, 0.01416574748873245, 0.02128973250364652, 0.018529958033468574, 0.02430947388347704, 0.042551218866719864, 0.07429109755321406, 0.029823278600815684, 0.007553088307759026, 0.028008232147840317, 0.02598287032014923, 0.021041083346062806, 0.039448462703148834, 0.0976282281044405, 0.07675728396861814, 0.024541107450204436, 0.01673973642027704, 0.034917424782179296, 0.032451197548653, 0.02202736235631164, 0.04509185011556838, 0.01511003485575202, 0.03993610567704309, 0.021403971295512747, 0.055575840087840334, 0.06233020772924647, 0.09035302864504047, 0.02484971842932282, 0.012942284574819496, 0.007566996155219385, 0.025874576131172944, 0.053636452357750386, 0.030684249686601106, 0.07160064895288087, 0.013097905521135544, 0.03753600009076763, 0.07180630549555644, 0.05072634659882169, 0.034993784356629476, 0.07704200892476365, 0.031801758959773, 0.0057313184606755385, 0.018461402141838335, 0.03148276162391994, 0.0623475294560194, 0.14479402103461325, 0.03483385524305049, 0.05463055174914189, 0.0690845753706526, 0.028346193212200888, 0.013802545981889125, 0.05036582238972187, 0.025575830150046386, 0.028984529271838255, 0.00583049119086354, 0.028860186139354482, 0.033079629647545516, 0.03183117769367527, 0.015078544602147304, 0.029478083451977, 0.006636113830609247, 0.02672370996151585, 0.04973286319000181, 0.028933163375768345, 0.015530612727161497, 0.10176501862588339, 0.10255217755911872, 0.012235771118866978, 0.05897240509511903, 0.032425901445094496, 0.07567509164800867, 0.009161975413007895, 0.008165165327227442, 0.018120400127372704, 0.004730261898657773, 0.005522784704226069, 0.042588778960634954, 0.04707728439825587, 0.05923408636590466, 0.06459884927608073, 0.06360774073982611, 0.11993471591267735, 0.026352574896009173, 0.013096136426611338, 0.010885782230616314, 0.052512414040393196, 0.035603536598500796, 0.06395097661879845, 0.011900671033799881, 0.055733668923494406, 0.02836878233210882, 0.029774174399790354, 0.07064586854539812, 0.038750795647501945, 0.05763795677921735, 0.060875709605170414, 0.05719299842894543, 0.03617863796534948, 0.023481058960896917, 0.011245497498748591, 0.0542601050256053, 0.007936959555081557, 0.0039011549233691767, 0.03985313727753237, 0.0035961556523034233, 0.018857675604522228, 0.01751173327647848, 0.035462476589600556, 0.088502416620031, 0.03940143280487973, 0.05592520610662177, 0.03664905940240715, 0.04338226841355208, 0.015699111791036557, 0.06406802815035917, 0.012725340893666726, 0.10327799056540243, 0.02776392640953418, 0.03834318587905727, 0.03267232415964827, 0.041114810592262074, 0.006806548044551164, 0.04144827980780974, 0.03972161386627704, 0.05011776323954109, 0.027004583171219565, 0.016440795625385363, 0.020059003036294598, 0.03172642725985497, 0.024502500928065274, 0.0013186862588554504, 0.01647306049562758, 0.02911222505645128, 0.04149200343817938, 0.022724096161255147, 0.08210729298298247, 0.03194171316863503, 0.03172274991811719, 0.09059157717274502, 0.07243431828101166, 0.09254234202671796, 0.04677491859183647, 0.029424268468574155, 0.08448698950815015, 0.026340949152654503, 0.07053165201796219, 0.014863859832985327, 0.012856611974711996, 0.017716925976856146, 0.030955452712078113, 0.02303251974808518, 0.05232940042333212, 0.01820731118641561, 0.042739056443679146, 0.05009215172322001, 0.027663957262120675, 0.08180459321010858, 0.03790674738411326, 0.010133006071555428, 0.029583928553620353, 0.023315621256188024, 0.04954054304107558, 0.04477887901884969, 0.044852785795228556, 0.06265189906116575, 0.07756295206490904, 0.03306572180008516, 0.027169237910129596, 0.0035263153813502868, 0.02403855287411716, 0.04006856048363261, 0.02830438803357538, 0.015409531333716586, 0.052279695082688704, 0.032329080859199166, 0.017704335441521835, 0.10638541483785957, 0.04590193770127371, 0.033021935087163, 0.05377967201638967, 0.06914552053785883, 0.041522223691572435, 0.051986869584652595, 0.06746375453076325, 0.04068671383720357, 0.018513332070142496, 0.02174033859773772, 0.009376829948450904, 0.027787506296590436, 0.03221527993446216, 0.021397529453679454, 0.06795544220949523, 0.047136311113717966, 0.04585766117088497, 0.039395914936903864, 0.036336240445962176, 0.039119190332712606, 0.01594649558683159, 0.018396130253677256, 0.041675239699543454, 0.029128576425137, 0.1763798261526972, 0.018311783314857166, 0.005475952866618172, 0.03867559011268895, 0.01617200643522665, 0.07937926944578066, 0.06706706175464205, 0.024502144697180483, 0.06256504551856779, 0.01270561831915984, 0.06383048894349486, 0.0993349302734714, 0.07726670897682197, 0.011070512991864234, 0.01715655809675809, 0.032878952915780246, 0.04175860885879956, 0.029007042321609333, 0.07889188622357324, 0.031954615405993536, 0.04974818482878618, 0.08026460709515959, 0.03569443855667487, 0.042071234856848605, 0.02503646504919743, 0.017533108984935097, 0.029303328083187807, 0.03996196210209746, 0.061054262914694846, 0.0734901124087628, 0.06263603194383904, 0.018926092343463097, 0.06504653501906432, 0.05446907154691871, 0.030482815964205656, 0.024315162445418537, 0.04597502811520826, 0.046163730294210836, 0.05822044622618705, 0.05413218474132009, 0.053412902634590864, 0.0817454737261869, 0.01605195848242147, 0.021983989390719216, 0.06578340602573007, 0.08025071409065276, 0.04180280746368226, 0.07128268320229836, 0.014438764137594262, 0.016081184257927816, 0.0541467011498753, 0.03321064468764234, 0.05658545778715052, 0.027509139690664597, 0.07051826367387548, 0.03200701845344156, 0.11477336083771661, 0.016468676258227788, 0.026528141061135102, 0.01674444163654698, 0.01469444792746799, 0.014096304730628617, 0.04693001632404048, 0.07485784604796208, 0.11192595542524941, 0.006545942424054374, 0.05337201029760763, 0.043271380418445915, 0.05442938148917165, 0.0697615031094756, 0.03092977811320452, 0.04245133692165837, 0.06803564610891044, 0.08406213964917697, 0.026245095214108005, 0.08050115924561396, 0.11347392704919912, 0.03596491427742876, 0.019338746860739775, 0.07317622847040184, 0.028010000314679928, 0.04901262371276971, 0.032855857280083, 0.06650436538620852, 0.03146762552205473, 0.038234064195421524, 0.09356934824609198, 0.07327050348976627, 0.04666121785703581, 0.04312773031415418, 0.012586086158989929, 0.017025695196934976, 0.01735842783091357, 0.009212447948812041, 0.04240160560584627, 0.020520069701888133, 0.013785632436338346, 0.04558136330160778, 0.12460027181077749, 0.14994985453085974, 0.056886625025072135, 0.15199917659629136, 0.05949794955085963, 0.14324379328172654, 0.16040914953919128, 0.1438317375141196, 0.06175132511998527, 0.08025425413507037, 0.13548398623242974, 0.0650822174793575, 0.12730234244372696, 0.10795761016197503, 0.1254632559721358, 0.23175127134891227, 0.20635353808756918, 0.11447767436038703, 0.1698120270157233, 0.1712137955473736, 0.09646759819588624, 0.17045051150489599, 0.16724268207326531, 0.2588520257268101, 0.14549168437952176, 0.19413101894315332, 0.11937148519791663, 0.08757902163779363, 0.0931026041507721, 0.10834498898475431, 0.13474737497745082, 0.22172274853801355, 0.1389179629040882, 0.11947849547141232, 0.15456648805411533, 0.08045778071391396, 0.12414488999638706, 0.08045812210184522, 0.14733783609699458, 0.265919616795145, 0.1270802176441066, 0.08980180587968789, 0.2510014094877988, 0.13428923237370327, 0.16917180590098724, 0.08706368171260692, 0.1533604832366109, 0.09396836394444108, 0.08443924714811146, 0.14623626630054787, 0.15748591889860108, 0.10428955269162543, 0.10460354795213789, 0.3048861102433875, 0.12079288353561424, 0.07490023010177538, 0.15909697307506576, 0.16293503431370482, 0.13172589882742614, 0.13308345020050183, 0.1720020454376936, 0.18305887322640046, 0.1119065259990748, 0.07316498493310064, 0.10491610344615765, 0.17610413313377649, 0.13529352145269513, 0.11933647067053244, 0.20314612425863743, 0.12839208240620792, 0.19569917698390782, 0.11811738178948872, 0.15959223790559918, 0.15801582718268037, 0.0846619953517802, 0.13111802050843835, 0.1313796275644563, 0.10058237661723979, 0.24530455033527687, 0.18009705090662464, 0.12583057454321533, 0.20826131774811074, 0.14744044543476775, 0.2488386130426079, 0.18261634540976956, 0.07830757851479575, 0.1859695467283018, 0.1194098022824619, 0.19315484241815284, 0.1738762651802972, 0.20843177422648296, 0.12430292292265221, 0.13590321061201394, 0.14271847147028893, 0.1380068578873761, 0.08377673933864571, 0.17415022157365456, 0.12226506703882478, 0.2626320510171354, 0.1842299971031025, 0.17171453742776066, 0.10945677815470845, 0.08995379030238837, 0.13189377263188362, 0.1293858329881914, 0.14497238880721852, 0.12445282933185808, 0.10269225051160902, 0.13171534548746422, 0.12255117238964885, 0.1694084471091628, 0.17584512359462678, 0.2118429372785613, 0.12309439480304718, 0.14674385078251362, 0.1273788430262357, 0.16576383408391848, 0.0794339286221657, 0.25027357041835785, 0.1546028978191316, 0.13110381580190733, 0.21876466664252803, 0.1728716495563276, 0.14514753565890715, 0.20020799129270017, 0.12813084642402828, 0.13548840943258256, 0.1814660313539207, 0.14981050888309255, 0.15562562184641138, 0.09303650847868994, 0.13135691784555092, 0.16194251569686458, 0.2276136793079786, 0.19540277804480866, 0.11287378190900199, 0.145284699392505, 0.1301464601419866, 0.15287439135136083, 0.11331648041959852, 0.1615935133304447, 0.14107975002843887, 0.16269288636976853, 0.10771972956717946, 0.13992260821396485, 0.09961132091120817, 0.12274269844056107, 0.16835986665682867, 0.1574213817366399, 0.1295049922191538, 0.19852995086694136, 0.20245905878255144, 0.1069471835216973, 0.22590906999539584, 0.2538052434101701, 0.21449574414873496, 0.14797228330280632, 0.17852559773018584, 0.1392076231422834, 0.15445537370396778, 0.10708976493333466, 0.21503722993656993, 0.12783792073605582, 0.19864526577293873, 0.2896483044605702, 0.12198742217151448, 0.16136454592924565, 0.15122492361115292, 0.1228619393077679, 0.13588866451755166, 0.10717510449467227, 0.08877856234903447, 0.1105813545291312, 0.1474323560250923, 0.1659999112598598, 0.09921586752170697], [0.027591811231104657, 0.0217536879790714, 0.04489594168262556, 0.05501323648786638, 0.04064668981300201, 0.0819153810152784, 0.0012336811278146342, 0.022446814946306404, 0.04205622120935004, 0.07187133247498423, 0.03809971320151817, 0.027973390169790946, 0.04375621065264568, 0.020692808284366038, 0.04009323689388111, 0.014349664670589846, 0.025224042874469887, 0.028849642076238524, 0.02216539254732197, 0.005940390738032875, 0.018571640757727437, 0.04759980831295252, 0.037582358345389366, 0.004062402276758803, 0.00807438489573542, 0.026866142943617888, 0.029067210089124274, 0.0433879310003249, 0.01304008015722502, 0.026320673678128514, 0.10556948283920065, 0.042944056185660884, 0.05134086713951547, 0.004761658456118312, 0.02981242840178311, 0.05760860112786759, 0.010150477155548288, 0.05028480212786235, 0.05057922695414163, 0.03257464639318641, 0.0699078397883568, 0.0545601479097968, 0.010971965984936105, 0.042899865002254955, 0.028186748349980917, 0.04514867265243083, 0.009824695662246086, 0.022940743911021855, 0.07715910498518497, 0.07201237021945417, 0.041315991984447464, 0.061318927619140595, 0.10992506591719575, 0.055525923235109076, 0.03618727656430565, 0.06523397183627822, 0.10234389381366782, 0.06953833930310793, 0.03471016520052217, 0.0601541676587658, 0.05111064179800451, 0.05016605107812211, 0.021216180102783255, 0.04206787663861178, 0.016822294783196412, 0.08694898278918117, 0.019063079816987738, 0.03631939740444068, 0.02228174460469745, 0.06262378650717437, 0.02300789528817404, 0.029823827790096402, 0.05064229837444145, 0.022959839370741975, 0.02500016475096345, 0.041598594398237765, 0.03592424087401014, 0.03307663879240863, 0.018094797887897585, 0.011829827471956378, 0.01808404973417055, 0.024703468952793628, 0.020763360553246457, 0.041637553440523334, 0.12028187033138238, 0.05728267213271465, 0.05054378940258175, 0.005065559116701479, 0.009596101190254558, 0.010191041092184605, 0.03027399601705838, 0.07566994114313275, 0.05925335251959041, 0.021814562642248347, 0.05853770322573837, 0.09358833980513737, 0.022237896664591972, 0.05593383357336279, 0.033966061964747496, 0.08013453087187372, 0.0068687576458614785, 0.08389027309021913, 0.043555140582611784, 0.04344014480011538, 0.054256739385891706, 0.013279875493026339, 0.05582963232882321, 0.018150045216316357, 0.030708701597177424, 0.028335207571217325, 0.020014264518977143, 0.009551275470585097, 0.05211376199440565, 0.010542610361881088, 0.07489133917260915, 0.0403328615357168, 0.05547552769712638, 0.02013570770941442, 0.07342677752603777, 0.019697710704349447, 0.05420941633929033, 0.06957129808142781, 0.020702148212876637, 0.06128322289441712, 0.05255060124909505, 0.0043869606179214315, 0.009332651752629317, 0.05807678127894178, 0.02025379453698406, 0.03503134073980618, 0.03827950218692422, 0.028774260281352326, 0.043646016565617174, 0.07250943104736507, 0.01691182747890707, 0.04942329855111893, 0.015799323991814163, 0.028457598855311517, 0.03644087213615421, 0.06865539879072458, 0.06520841969177127, 0.06531853956403211, 0.027775856433436275, 0.028255615943635348, 0.08264958771178499, 0.023327154231083114, 0.03963103845308069, 0.00753182299376931, 0.00884300683537731, 0.04931638475682121, 0.02722558732784819, 0.02496723009244306, 0.09167135009192862, 0.03378520799742546, 0.13082291290629655, 0.0734030436433386, 0.048619378212606534, 0.023917781327327248, 0.06829195423051715, 0.04819649504497647, 0.036748080456163734, 0.026457729800313246, 0.024838354293024167, 0.06587964031496085, 0.04403780374559574, 0.029863547533750534, 0.0021277494488458615, 0.008312363825098146, 0.010524307144805789, 0.007767402930767275, 0.05930867220740765, 0.00949033215874806, 0.0032049508263298776, 0.03397459295229055, 0.0438210075662937, 0.03755447956791613, 0.019702573627000675, 0.06332843346172012, 0.06155006580229383, 0.015756743268866558, 0.04641726649424527, 0.04949839647451881, 0.04615293946699239, 0.0653908915410284, 0.03342607902595773, 0.015608189423801377, 0.0707605155184865, 0.05651779989420902, 0.04470406311156694, 0.06476998853031546, 0.050307196434005164, 0.09314751150668599, 0.03244547187932767, 0.004636371404558304, 0.06267071992624551, 0.02172531752876239, 0.010878569482883904, 0.027314253566146363, 0.042312054356443696, 0.007814649907231797, 0.03956811917305458, 0.10381426647654735, 0.05196450867515523, 0.06438255033572204, 0.06624083616770804, 0.05622449942165986, 0.027969169204880018, 0.01426647640982992, 0.04033621233247686, 0.049406488906242885, 0.025394590265932493, 0.013521215423679678, 0.026478363361093216, 0.08478674295474775, 0.03041006322746398, 0.04817482433281839, 0.030106142621662002, 0.026586805979604833, 0.04630034112778958, 0.05314013367751613, 0.0547329755499959, 0.054314311491907574, 0.01752012140059378, 0.013032141032454092, 0.035058332650805824, 0.009930630749295233, 0.057703332568053156, 0.059072112635476515, 0.05651613748341333, 0.04296839491871651, 0.012051554294885136, 0.04859194843447767, 0.04928898466459941, 0.06354960089083761, 0.06168869156681467, 0.07616902061272413, 0.08232581094489433, 0.03724009096913505, 0.08593367281719111, 0.025123261075350456, 0.012020508402201813, 0.03378138593689073, 0.027045701863244176, 0.04426028477610089, 0.06796479327022098, 0.04531674312602263, 0.01215415713886614, 0.021984425402479246, 0.018779696292767767, 0.005745795906477724, 0.0588222463557031, 0.07867198044550605, 0.04295248327252921, 0.055403027290594764, 0.003541453802426986, 0.03695123225043062, 0.025521940951875877, 0.012473273218347458, 0.03731614997377619, 0.0743627964402549, 0.03947015567973722, 0.05512807641935069, 0.08958391132182442, 0.07950340848765336, 0.019279896405350883, 0.011409501003072364, 0.018036286965070758, 0.015786291878612246, 0.06477267510490492, 0.023011756311461795, 0.08870392455719411, 0.03708428077516146, 0.101692733442178, 0.05492286516528111, 0.04981279249477666, 0.030684388839290477, 0.009057879924512235, 0.0625519169261679, 0.05214467986661475, 0.06023294663464185, 0.048559253118583, 0.07342851415160112, 0.04522846094914712, 0.059740438882727176, 0.018118654224963393, 0.049949210369959474, 0.019192751569789834, 0.03768789545574691, 0.08117344856145792, 0.026974743268510792, 0.052888185673509724, 0.02678837514395127, 0.03179667524818797, 0.01614507389604114, 0.05430876393802464, 0.03896830057783518, 0.03435607912251726, 0.05351378276827745, 0.019356497177795973, 0.036614330601878464, 0.007863626087782905, 0.011474257098598173, 0.08178715273970738, 0.03027490143722389, 0.03229212190490216, 0.07401905590086244, 0.04417773197928909, 0.05426957482995931, 0.012345579289103625, 0.046090869946056046, 0.07115012820577249, 0.035191704009776004, 0.020157807011855766, 0.08089555878541432, 0.032540808169869706, 0.01600564290129114, 0.09854037954937667, 0.031879090747679584, 0.026160069210163783, 0.053674379814765416, 0.02460587096720701, 0.033510093853692524, 0.09404828582773916, 0.01283020079426933, 0.052408980918698944, 0.017686414430500008, 0.08791390093392693, 0.015673643138143234, 0.06580697663594037, 0.03261082609242294, 0.06341499014524743, 0.02779872200335376, 0.026595893577905372, 0.019067516004724894, 0.03848283951811027, 0.05772124059149064, 0.014468639292317675, 0.04621093459718395, 0.054779010970378295, 0.03925075456209015, 0.04317178048950154, 0.037632965395459905, 0.01834370123106055, 0.048816370181157254, 0.05940328861470334, 0.030231457967602182, 0.04009612384834327, 0.03790440961893182, 0.044604600479942746, 0.08175725903129205, 0.044378698148648255, 0.07495076293707825, 0.16421308682765812, 0.22415837331209332, 0.1524538904777728, 0.16465653490740806, 0.14845200756099075, 0.19925563770812005, 0.18227755499538034, 0.11470083816675469, 0.15418011113069952, 0.14476057986030355, 0.1258075234363787, 0.11654966903734021, 0.25483964884188026, 0.14099490770604461, 0.10954564291751012, 0.17426626378437504, 0.1656393610755913, 0.11349757929565385, 0.10065289548947476, 0.09636072893044911, 0.05996112391585484, 0.19972014793893322, 0.13409372098976746, 0.07931317377369851, 0.046273312109406106, 0.1323843767750077, 0.12907491764053702, 0.12949889176525176, 0.14195205556461588, 0.11598852375755087, 0.15802874055225402, 0.14994329394539818, 0.11698919857735746, 0.14534472429659218, 0.1457122655119747, 0.14851497136987746, 0.15523829497396946, 0.16294342058245093, 0.07274502582731657, 0.24169461044948548, 0.07603679216117598, 0.07651858701137826, 0.1667414206895046, 0.1156549877487123, 0.1435324441990815, 0.12787237123120576, 0.11612648158916272, 0.12676471582381055, 0.16300478135235608, 0.12003285009996034, 0.16552765300730243, 0.16614666354143992, 0.18648998520802706, 0.12636996747460216, 0.13609995396109298, 0.20508262503426522, 0.23868195101385936, 0.14000489754835144, 0.12919376516947523, 0.23706357926130295, 0.24745376547798514, 0.10354644022299908, 0.14926468895282596, 0.11068458727095276, 0.06568749086000025, 0.15935057977912948, 0.11641274279099889, 0.2128195294062607, 0.07746863251668401, 0.13911714049754664, 0.09104943776037544, 0.13287876587128267, 0.18843830097466707, 0.12334489190834574, 0.12910340126836672, 0.12949391937581822, 0.16591809689998627, 0.1825017578084953, 0.11235823418246582, 0.09066361744771712, 0.08801653995760716, 0.09217008075211197, 0.11297222779830918, 0.16930562997004017, 0.13934380724094808, 0.1853043894516304, 0.11089726453064941, 0.17251711076823995, 0.12024737530737184, 0.1009475281171035, 0.10248262347886339, 0.1179556900751777, 0.18442093685735017, 0.10171990346862003, 0.18983545334776863, 0.3103589446982369, 0.29718318139202893, 0.1771808706689626, 0.15240735781844705, 0.12423063773894683, 0.13275859731948003, 0.15400137228425592, 0.1340179773978889, 0.16496173571795225, 0.14874049520585686, 0.12724064028589055, 0.26264000684022903, 0.1600379272713326, 0.12028948476654477, 0.17662862373981625, 0.0805072151706554, 0.10314965838915668, 0.14468998677330092, 0.06595199229195714, 0.17371873691445217, 0.11663332392345183, 0.0899329359526746, 0.10452409362187609, 0.17967828665859997, 0.22508963505970314, 0.2129302133107558, 0.17830304248491302, 0.08949000737629831, 0.2451208687853068, 0.16232755675446242, 0.05318957184499595, 0.20728242496261373, 0.21356535813538358, 0.1288995036156848, 0.1710477177402936, 0.06938391321455128, 0.18017539201537147, 0.11490833523566835, 0.27115778415463865, 0.11729752382962033, 0.09134258609265089, 0.11025521031115204, 0.2259307258646004, 0.11933290836168453, 0.10727891611168161, 0.17906592576764524, 0.18327829660847783, 0.08483204364893027, 0.12991762632736936, 0.160582990210969, 0.09065065954928286, 0.22735131526133046, 0.058619933188310824, 0.0958196513238363, 0.15944794955430552, 0.1331487443530932, 0.12857678811997175, 0.18156254023779184, 0.13974630361190066, 0.15528267540503293, 0.22576775023480877, 0.1574287289986387, 0.1571580083691515, 0.13625654712086543, 0.14590446691727266, 0.11619346041698009, 0.11320132878609002, 0.10039662447525188, 0.1637687926995568, 0.2182962081860751, 0.1356930343899876, 0.1616195181850344, 0.09245512483175844, 0.20901965908706188, 0.14160432969219983, 0.12419545993907377, 0.07738503700238653, 0.20188386464724317, 0.1489246220444329, 0.06734513706760481, 0.1602442591683939], [0.09568236142513342, 0.06883077570819296, 0.02713369089178741, 0.042641029867809266, 0.07470015450962819, 0.03394475490495097, 0.005543919214687776, 0.0534252445504535, 0.03234788317058701, 0.061867330223321915, 0.020678050677815918, 0.05197436810703948, 0.03852891575661488, 0.07385251054074615, 0.06142348509456497, 0.06165755105030257, 0.004842906000703806, 0.03489194314170163, 0.061798110109521076, 0.03829020766715985, 0.008590661782363895, 0.08147224463755265, 0.02776072589767864, 0.018264961217937525, 0.017012874595820904, 0.013424028402369004, 0.004044671441079117, 0.026780163279909175, 0.0813363870838657, 0.01974643826542888, 0.0479346245265333, 0.014554062345268903, 0.03783954220125452, 0.05466438255098183, 0.04759587493026629, 0.03441030785324983, 0.07366871024714783, 0.038444815581897274, 0.010693933345464757, 0.03586157021345571, 0.02979560762469191, 0.11824882356449962, 0.05161546549061313, 0.03468303599220235, 0.01576010890858015, 0.01880703515780624, 0.02909945269493619, 0.020631709121516906, 0.02705021597648738, 0.012657774841500213, 0.01705688024230767, 0.028067594685126096, 0.05233221316302661, 0.07129662073566578, 0.0578964245505631, 0.014531071537930984, 0.0901087062084116, 0.007453615935446578, 0.13452640792820603, 0.07869231529184617, 0.047789004020160064, 0.022647055666311644, 0.06990837413468398, 0.023680446211074013, 0.07019948156084865, 0.03613239845435601, 0.03758423597901128, 0.027537853384274058, 0.04598622712364886, 0.08142113292706199, 0.055132544148364104, 0.053362996914074756, 0.044581233960343525, 0.10164520630496554, 0.020684626106231008, 0.0594340395036852, 0.021619344406644814, 0.034378373238723725, 0.05909487801545765, 0.04060908890096471, 0.029149928013794124, 0.08095697150565684, 0.048195303897955455, 0.052436570258578286, 0.022293819347396493, 0.05495504097780213, 0.08286888492875732, 0.0528015881718602, 0.07547281929873861, 0.0011265076977906574, 0.0257739075095742, 0.026455850311322138, 0.016591052699368447, 0.04190729814581573, 0.045572234885185026, 0.0367672315769596, 0.0402926037349971, 0.06780821495340206, 0.0446763401851058, 0.05927210659137927, 0.02260773482703371, 0.04761258438520599, 0.0254448503619642, 0.04030277857964393, 0.04066073124704417, 0.0912318353948649, 0.04096338278031908, 0.023613944213138893, 0.022169203475641552, 0.039302378354477696, 0.02624792465212522, 0.05191943062527571, 0.027680447783495765, 0.01727607726934366, 0.04579254884447437, 0.02388400062045548, 0.012357913783489494, 0.017103670797951054, 0.02568412062828429, 0.04675184522056952, 0.02068945934297517, 0.03178131650201976, 0.05340674651961308, 0.04349640330474358, 0.05609275336610153, 0.01678693701251177, 0.05086761811980978, 0.04518210269452538, 0.036513955128612, 0.013267285885376623, 0.06721727986587211, 0.04851157384109683, 0.025132304144790396, 0.02608622922707582, 0.07229667957290076, 0.03556480762199499, 0.01433179004379781, 0.03903058903233614, 0.03825717096333392, 0.02902154388721101, 0.03217322984710336, 0.03968892226112075, 0.022685853291477542, 0.04404944062116556, 0.041246230102842674, 0.006506577519758139, 0.014307035708043259, 0.015987668084562756, 0.05135228137078229, 0.022367327219399158, 0.035841543358401395, 0.02705982307816157, 0.061506728088716045, 0.012906409156130394, 0.03861581382807344, 0.050201770645799115, 0.022336142174026463, 0.004258546805431251, 0.021308846517058555, 0.029589338810183108, 0.07634939218405634, 0.02298008701473009, 0.0803227246797178, 0.011204230377188651, 0.05926566846028436, 0.046463487451546825, 0.03343897013110109, 0.005030040856581763, 0.0018685271220419963, 0.009338141790067311, 0.05024736077757552, 0.045948878541821614, 0.0639527577732224, 0.06072296077036299, 0.025989427194872405, 0.04381756400107406, 0.06141116544313263, 0.05238852361799218, 0.005602026594715426, 0.03153191035380587, 0.012326510732236784, 0.017771100901882164, 0.007242327883432154, 0.0439840982289752, 0.039842057012720034, 0.09131544575211592, 0.02962097842100775, 0.010389599920017645, 0.05713539292628411, 0.04284638212993741, 0.034960870107170194, 0.025385951666976325, 0.012537451366370078, 0.028338406227703672, 0.06424374645575881, 0.07139761961298063, 0.07132518599973992, 0.055967853622860275, 0.07172837998950854, 0.028638823896471877, 0.017152491127490066, 0.07541195576777682, 0.020874973997706547, 0.0566592940595001, 0.07691867140238173, 0.016906211276364047, 0.020242556565790437, 0.003724043931470078, 0.055570941913174465, 0.07432893966324627, 0.01723936693451833, 0.03171074939018581, 0.04561450390610844, 0.013395225651038345, 0.030005353401065804, 0.09104742654017173, 0.017944314458873123, 0.06261182308662683, 0.029216361363069154, 0.0208507502975408, 0.039416194122168235, 0.07016704970737919, 0.04045155692438129, 0.040240119051304646, 0.08754897949984297, 0.018614924665598664, 0.01903764085000148, 0.027812973094114568, 0.03966123273130506, 0.054145276226336136, 0.021828103126608767, 0.04908602582872845, 0.05945465265540406, 0.0767771215760149, 0.07674743566894904, 0.02334983611945063, 0.0455019720538985, 0.03905426725395955, 0.05954463435045909, 0.058916387788485736, 0.04659602389438078, 0.009513461191090755, 0.01210511694807792, 0.07577636511996388, 0.060033676272723824, 0.011298726185486885, 0.09690951745142229, 0.043505427820491605, 0.0255761808148236, 0.04352557341917418, 0.05680577174643986, 0.05061475727416109, 0.0060491111980809364, 0.038305926354951225, 0.05828765140904579, 0.018533295842644293, 0.019649151981866453, 0.055814251318224706, 0.09492619457887486, 0.0417485750222113, 0.038326042267726734, 0.036139831063337624, 0.03732977951585781, 0.05554849936743267, 0.03827474130957853, 0.009721725455165142, 0.02155758844310185, 0.03024020046723308, 0.0029743152163064224, 0.029489217522495892, 0.045601360470755026, 0.039758917919243686, 0.0587763890507631, 0.026922048928099684, 0.04203022377623711, 0.05741245149692986, 0.025197462855430786, 0.009462552643526578, 0.058787617745110765, 0.05007390973332804, 0.017929786918102764, 0.04559829169011209, 0.025482712881057523, 0.05246871638519224, 0.009596324762242148, 0.026511492833378725, 0.07998506975127384, 0.06347388698486611, 0.04075592652952764, 0.03517017430567648, 0.03656174201751128, 0.028059868927812204, 0.05961333496088628, 0.056468424809281714, 0.003970221041527111, 0.0339908274327172, 0.01462758969864808, 0.025276946871599648, 0.012759965793520678, 0.03530047688400373, 0.04719990574812982, 0.043108286045026034, 0.04372790142951999, 0.012179584973637247, 0.02423197882308159, 0.04718481046438683, 0.04923232540022582, 0.006109122186899185, 0.04867915820796043, 0.002744852431533218, 0.06199467905389611, 0.014032268518349156, 0.017862952809082344, 0.030244568006310146, 0.053312319359974936, 0.06937013895367272, 0.0860245488001965, 0.024122886825352907, 0.031194882540148683, 0.033159774175146595, 0.12301615759497508, 0.03345231765706558, 0.047517203565803356, 0.024231310890172608, 0.016030015030992217, 0.04431553024915047, 0.022258177705225535, 0.049009944559657015, 0.04561796973575838, 0.01735023452056339, 0.08104184351395816, 0.06388631329173222, 0.04015964055724908, 0.06015358136210125, 0.03944999894883949, 0.015861501124163624, 0.05522233659576159, 0.013500455697794678, 0.040044225461315364, 0.047207839306793176, 0.03637121044448577, 0.02646087836183142, 0.0300696252452326, 0.03550712419382762, 0.02919840695540188, 0.03371294878888875, 0.07142857459257357, 0.06535681211971678, 0.05067048143246211, 0.0641075252497103, 0.017406493025191594, 0.027616289116849657, 0.1691141410265118, 0.16040003596572205, 0.18969503900734708, 0.07827816720237024, 0.11800908017903566, 0.12426757442881353, 0.05536329641472548, 0.08290383266285062, 0.24602091580163687, 0.22678722365526482, 0.1586791142472066, 0.10413545314804651, 0.10836859670234844, 0.3151369804982096, 0.10563398289377801, 0.14284778328146785, 0.10195337570621632, 0.11290359398117289, 0.16168349131476134, 0.12340338056674227, 0.10768331980216317, 0.20278517331462353, 0.12927647010656074, 0.137487621686887, 0.0975931467837654, 0.11880853649927303, 0.12079875392373651, 0.1139727170811966, 0.15428542188601568, 0.08430532659986056, 0.17276301397942007, 0.12694152508629486, 0.15036020282423124, 0.13066698767943308, 0.12325638337642886, 0.17421836557332426, 0.18909082689788193, 0.13136435416527092, 0.20868732535745949, 0.15597143297782168, 0.13883052306482568, 0.2389827583101578, 0.18215419520856813, 0.0741198321338743, 0.15717712609330192, 0.2582095633260906, 0.1497492371709086, 0.11417685964261182, 0.24770634801825508, 0.11900691999471746, 0.08605241644545458, 0.15762369119329378, 0.1718907678150572, 0.19611345865996554, 0.17425517609808594, 0.10389996969024651, 0.13034213479841128, 0.09524237917503342, 0.24658381997141987, 0.11737020977307111, 0.11702698131557554, 0.12368213123409078, 0.1117219687148463, 0.08593362086685374, 0.1445357981720008, 0.15319866535719484, 0.1012526843987871, 0.12804336205590516, 0.12081003456842154, 0.1167309311858844, 0.2753002743702382, 0.20415639504790306, 0.10120298276888207, 0.21603700675768778, 0.11930118154850788, 0.1552766640088521, 0.16023499716538936, 0.1320369477616623, 0.20472686912398785, 0.10000851092627272, 0.09436209555133246, 0.13817578554153442, 0.18626824632519856, 0.08537699526641518, 0.08902583853341639, 0.12385708512738347, 0.17707624268950894, 0.16662766429362819, 0.10617312349495478, 0.09378976610605605, 0.11344067141180858, 0.18020308896666393, 0.13444006646750495, 0.14431567717110738, 0.14573215506970882, 0.12741422862745821, 0.09641150667448528, 0.1802227707230486, 0.1990446005947888, 0.11384515673853457, 0.14649631484644488, 0.15935319213895127, 0.15531350421952084, 0.14904510229825974, 0.08599654014687985, 0.1722179213538766, 0.3169297124259174, 0.07925443278509192, 0.15778012108057737, 0.1206333440495655, 0.16803588951006532, 0.1344050667830743, 0.12735231866827235, 0.2198949723970145, 0.19028804468689486, 0.12528220162494108, 0.172120536735747, 0.09358626921311952, 0.11187417578184977, 0.09176148392725736, 0.15031757386168465, 0.1424207366653718, 0.17854480451205745, 0.14173049479722977, 0.15726645098766312, 0.17518026317702606, 0.100885447463952, 0.13411890948191285, 0.10433997420477681, 0.15770715312100947, 0.178293795324862, 0.15792997553944588, 0.12652043049456552, 0.10631330034811981, 0.16645756404614076, 0.1263003540225327, 0.13004422187805176, 0.0955431345209945, 0.17368971894029528, 0.10883535564062186, 0.30884831794537604, 0.1011915536946617, 0.08370224255486391, 0.12672965676756576, 0.20343158394098282, 0.11195411992957816, 0.1637434706208296, 0.08814787041046657, 0.18423584522679448, 0.09886116546113044, 0.1136950722138863, 0.15512746263993904, 0.1391467818757519, 0.10151354188565165, 0.12673455494223163, 0.2949605678441003, 0.1943259366089478, 0.11082745069870725, 0.14818554685916752, 0.07484560061129741, 0.17778756155166775, 0.15232745819957927, 0.1313655564445071, 0.13966720551252365, 0.09421757713425905, 0.1636609883280471, 0.11863167528645135, 0.12449024841771461, 0.11941782489884645, 0.08724473605980165, 0.16742076782975346, 0.17141482851002365, 0.15550877811620012, 0.13887680339394137, 0.06692197188385762, 0.16203737701289356], [0.03582377634302247, 0.015244051883200882, 0.02061941173451487, 0.06864318303996697, 0.03961674839956686, 0.05114614614285529, 0.02361042828852078, 0.0596415922336746, 0.060191126613062806, 0.02986272931593703, 0.04592045799654443, 0.03292202345619444, 0.009875450214167358, 0.013773233004030772, 0.05574131675530225, 0.03994511534983758, 0.05784805507573765, 0.01573661807924509, 0.0135269206839439, 0.030038659133424517, 0.06898209219798446, 0.09927293125656433, 0.037833630995010026, 0.0671311684709508, 0.03218371268303599, 0.032041498634498566, 0.027122028041048907, 0.07945345452753827, 0.0172633642796427, 0.023733073758194223, 0.06658571961452253, 0.053939549179631285, 0.019461832052911632, 0.01989970845897915, 0.018351519756834023, 0.009408104979229392, 0.04038749844767153, 0.02396464053163072, 0.03945501215639524, 0.03264754755946342, 0.03505861837766133, 0.0329669382335851, 0.047412679487024434, 0.014786191295570461, 0.041572188783902675, 0.06760996504453942, 0.08083611275651492, 0.015904504871286917, 0.022102690345491283, 0.05750770615122747, 0.02000880045670783, 0.07652139975107275, 0.07287312793778256, 0.022604595542361494, 0.06464659163611941, 0.029302693546924274, 0.0890367481042631, 0.038079096339060925, 0.040974244111566804, 0.011304757990728831, 0.02614451565023046, 0.0702698965324089, 0.037505160144064575, 0.012165863590780646, 0.03769585498957895, 0.0651152801583521, 0.0672301190206781, 0.029999891194165684, 0.019841405337501783, 0.0905994810455013, 0.06498287359136157, 0.04727854742668569, 0.058754384372150525, 0.06549505938892253, 0.029462342499755323, 0.08347875220351852, 0.012927687457704451, 0.02276703125971835, 0.1048808143241331, 0.06616818733164109, 0.05484937399160117, 0.08216999704018235, 0.04698348435340449, 0.02854112201021053, 0.07224723769468255, 0.06857203334220685, 0.05854075345268939, 0.005094922653370304, 0.0510179772390984, 0.015072107398736989, 0.06941813364392146, 0.027448847613413818, 0.016861381845956203, 0.05684100520738866, 0.045133217427064665, 0.025796235022426117, 0.03442274624831043, 0.08230132749304175, 0.021869058546144515, 0.03654914034996182, 0.03129481272480916, 0.05310949411068577, 0.012462600207072683, 0.05859673736267723, 0.023603563422511797, 0.033828397281467915, 0.02144434598449152, 0.03363664487551432, 0.07545427302829921, 0.06851833895780146, 0.021332201904442627, 0.05334935995051637, 0.012021877664665226, 0.03019840642082272, 0.03571415370970499, 0.02559738768468378, 0.04007415998785291, 0.07616339513333514, 0.024237548641394824, 0.045283710132935084, 0.024644902368891053, 0.035772631235886365, 0.05104364812723361, 0.024070519029919524, 0.059703728547901846, 0.0026414749709147145, 0.02332043593924027, 0.029127691414032597, 0.030291399380075745, 0.04501052557316143, 0.09746843628818169, 0.037432173630804755, 0.011688072627293877, 0.006148277434476768, 0.042294116647099145, 0.08002538321306929, 0.033991332093137316, 0.04477503469388466, 0.015660932003811467, 0.058226591208949685, 0.07101625960785896, 0.026275987111148424, 0.012199249104014598, 0.013956780967419036, 0.011235169586143456, 0.051765765238087624, 0.05773803168267477, 0.021355113858589903, 0.022080025155446492, 0.03325466146634426, 0.06119616897194646, 0.057311378404847346, 0.023220095717988443, 0.025920437146851327, 0.1117179611173924, 0.039699690823908895, 0.03811109774687793, 0.01144917992860428, 0.017554878031660337, 0.04438542942807544, 0.04509775018959772, 0.011806303245975869, 0.06148281609057449, 0.045913708163425326, 0.051201595706515945, 0.027151734357175883, 0.07680567941861227, 0.05045581521699205, 0.0347275759850163, 0.02027174337854376, 0.02941792681667721, 0.07206012742244639, 0.023985220286704134, 0.03149251344439108, 0.08807009333395399, 0.025252452287531924, 0.09696198729216121, 0.04084653533936944, 0.08731084657483734, 0.04367353911220562, 0.03381834118044935, 0.016540341748623177, 0.1145479483238887, 0.06573668782948516, 0.03163882785884198, 0.05589708613115363, 0.08102839579805732, 0.024195069963752758, 0.03899892901245039, 0.024689854253665544, 0.06160612763778772, 0.07454840015270747, 0.054914478896535, 0.025745661369001027, 0.028572661431098823, 0.007923918165033683, 0.08347068505827338, 0.12624349066754803, 0.04465052828891203, 0.011037283329642378, 0.04075459066370968, 0.013626257150463061, 0.07249513728311285, 0.07876210685935803, 0.055219108253368177, 0.02060732957033906, 0.06957360616070218, 0.03320029172755312, 0.046057877771090716, 0.02750084619037807, 0.0067545527144829975, 0.06491801730589941, 0.03627987432992086, 0.06641682164627127, 0.014615297877753619, 0.03755924044526182, 0.03184214663633611, 0.006538525585710886, 0.02016110585827846, 0.057272211561212316, 0.024692388687981293, 0.023736908806313295, 0.10589516692562029, 0.07779453182592988, 0.03734687859832775, 0.03952821389248129, 0.019235317449783906, 0.1114206864440348, 0.09061602351721376, 0.0316193687467603, 0.05596629511273932, 0.030708107879036106, 0.06337207174510695, 0.01777382829459384, 0.016958241394604556, 0.04997953452402726, 0.016169969239854254, 0.004058497188452748, 0.05174926729523577, 0.01775792221451411, 0.024199426370614674, 0.05218782462179661, 0.006599178996111732, 0.023088952657417394, 0.008821372302918462, 0.1078332558972761, 0.05771775991888717, 0.08199640869861469, 0.034134514644392766, 0.046458849028567784, 0.06318828629446216, 0.06401273072697222, 0.037968642500345595, 0.0390909516136162, 0.051480710026226006, 0.06383222556905821, 0.027243406293564476, 0.060259671372477897, 0.053401621989905834, 0.05523301239009015, 0.042826269927900285, 0.06277105829212815, 0.0890701002208516, 0.016159414044523146, 0.032956010109046474, 0.023248555226018652, 0.03836144271190278, 0.05137483894941397, 0.029493739057215862, 0.07808450376614928, 0.05813726631458849, 0.04639449740352575, 0.043870839072042145, 0.028551923969644122, 0.06042894412530586, 0.009116546698351158, 0.020944687639712356, 0.03211313814972527, 0.027678726000885945, 0.048056848827400245, 0.07382680996670388, 0.019765667311730795, 0.025817718342295848, 0.018028789418167435, 0.057120683559332974, 0.04900549538433552, 0.023531678998551797, 0.04805811418918893, 0.039867742743808776, 0.0031491392337557045, 0.04539009700238239, 0.03331098676426336, 0.07017625976004638, 0.03889591520419344, 0.022629015911661554, 0.017714343302941415, 0.044473867455963045, 0.044424878287827596, 0.03622454350988846, 0.054444435954792425, 0.020441120032046456, 0.06730513530783355, 0.022221888539206702, 0.04802789022505749, 0.021476842775882687, 0.017850571930466685, 0.034822014276869595, 0.030196137304301374, 0.06348147915559821, 0.03260576464526821, 0.020573606379912235, 0.03325226432934869, 0.03375584121386055, 0.026377284702903125, 0.054581213771598414, 0.050608597448444925, 0.04513084626523778, 0.025953976655728184, 0.027215633272135165, 0.009273047089664033, 0.03432454526773654, 0.0695632457791362, 0.020822437363676727, 0.01699038752121851, 0.032886893895920366, 0.012694446213572519, 0.08177687399438582, 0.03219370941224042, 0.024330610249307938, 0.01372681816064869, 0.027070626892964356, 0.018466769724909682, 0.0729284030967392, 0.06862796901259571, 0.04329789364419412, 0.011700835711963009, 0.03042632368305931, 0.10269990947563201, 0.058838696058955975, 0.047813839992159046, 0.050668960029724985, 0.019865280228259508, 0.03263470840465743, 0.06834553729277104, 0.05192643278860487, 0.014135979017737554, 0.04719666627352126, 0.09357907038065605, 0.0281501901554293, 0.05269470777420793, 0.04866437091550324, 0.16472556948428974, 0.18260972545249388, 0.14834412897471339, 0.1662519297678955, 0.22532688482897356, 0.13782669411739334, 0.09359771313029341, 0.1202960527734831, 0.27436540578491986, 0.14786446408834308, 0.1809997548116371, 0.13769632845651358, 0.11513110570376739, 0.11664453777484596, 0.09028860280523077, 0.21106810541823506, 0.1755099548608996, 0.07918060393421911, 0.14812887646257877, 0.15087523846887052, 0.2663510717684403, 0.14474827505182475, 0.17301610118011013, 0.09945437152055092, 0.14967885188525543, 0.18694472877541557, 0.10629657976096496, 0.08240413721068762, 0.23960717167938128, 0.10563990523223765, 0.24340184696484357, 0.21975060983095318, 0.20468487840844318, 0.1735113956965506, 0.11383957578800619, 0.09144346622633748, 0.11333121947245672, 0.15804742783075199, 0.23578232066938654, 0.11586713066208176, 0.1139383927511517, 0.1374783893697895, 0.11308829227345996, 0.12163516919827089, 0.14541617827489972, 0.09501947512035258, 0.126088663819246, 0.23008782154647633, 0.13360339886276051, 0.11212387136765756, 0.1389663657755591, 0.10855816348339431, 0.20884019293589517, 0.21254405903164297, 0.1232413029356394, 0.2153970379731618, 0.15756887616589665, 0.2166767677408643, 0.0786774352309294, 0.08437047232291661, 0.13198256317991763, 0.1566437297151424, 0.1599221077049151, 0.22573690657736734, 0.18291315995156765, 0.09437207743758336, 0.15854690806008875, 0.1610186160542071, 0.10147097971639596, 0.13854785385774449, 0.19850449520163238, 0.15911021298961714, 0.1975457591470331, 0.11920907360035926, 0.14952016586903483, 0.15167895471677184, 0.2472888454212807, 0.17140923271654174, 0.1236713255639188, 0.1859453081851825, 0.15593343501677737, 0.12952249206136912, 0.2615003945538774, 0.1320886902976781, 0.0845506509358529, 0.1211337445420213, 0.2183934295317158, 0.18120795692084357, 0.09548081638058648, 0.1267582888249308, 0.11104772755061276, 0.16441382293123752, 0.1743395286030136, 0.11257436985033564, 0.13325124979019165, 0.17898657533805817, 0.08376650512218475, 0.27869536250364035, 0.11372912194929086, 0.16958332678768784, 0.06490667728940025, 0.23484972305595875, 0.07208914539660327, 0.0968878912681248, 0.18345123186009005, 0.17781586706405506, 0.10039459099061787, 0.14821380784269422, 0.1257579034427181, 0.24317774805240333, 0.1554279137053527, 0.11400210612919182, 0.1595799034112133, 0.11722212904714979, 0.11674294655676931, 0.20647241530241445, 0.10378615392255597, 0.2194119233172387, 0.14103323221206665, 0.15192944440059364, 0.17958295036805794, 0.11384618832380511, 0.130188777402509, 0.10040550056146458, 0.0789998093387112, 0.18879355222452432, 0.10825285135069862, 0.12116106299799867, 0.08262498551630415, 0.18052390456432477, 0.12032294820528477, 0.11049389242543839, 0.1640438474714756, 0.2275922312401235, 0.2450288276304491, 0.08338072191691026, 0.09212777833454311, 0.15149876126088202, 0.14573433698387817, 0.13969473919132724, 0.1663360744714737, 0.18352802930166945, 0.13774560706224293, 0.11195306607987732, 0.07903504651039839, 0.10613812381052412, 0.2215904978220351, 0.10889318378758617, 0.12511104752775282, 0.12949636846315116, 0.1141884594107978, 0.2027242281474173, 0.17151893698610365, 0.14717037789523602, 0.0902405042143073, 0.15810063981916755, 0.14409996452741325, 0.1141823960642796, 0.1565704055246897, 0.1707735238596797, 0.22835331852547824, 0.15862082596868277, 0.18982310401042923, 0.10366504284320399, 0.10045308707049116, 0.1373955953749828, 0.16852420783834532, 0.12735678639728576, 0.14472259674221277, 0.1000960027158726, 0.10485978185897693, 0.1405848711146973, 0.18639090849319473, 0.15037373959785327, 0.12218164221849293, 0.2589298028033227, 0.1881077335565351], [0.014314027666841866, 0.04062205793161411, 0.04867059753451031, 0.02113528043992119, 0.03927915284293704, 0.028606737141672056, 0.03212542440451216, 0.04908062670438085, 0.018080888185068034, 0.04796525667188689, 0.049067483269027434, 0.03729427888174541, 0.021306859416654333, 0.059242929055471905, 0.006486121146735968, 0.03648642516054679, 0.04441548640897963, 0.026356051857874263, 0.03719244879903272, 0.042618331281119026, 0.016247675812337548, 0.011254490473220358, 0.04539878755167592, 0.030166264004947152, 0.02363263334700605, 0.018426940514473245, 0.06413725568563677, 0.08309526223456487, 0.023578438012918923, 0.033989851508522406, 0.03943557159800548, 0.0563314095052192, 0.06767236482119188, 0.03353905616677366, 0.09522425592876971, 0.036370034140418284, 0.011623259943007724, 0.04041109132231213, 0.020311238622525707, 0.028067064049537294, 0.05175036938453559, 0.03740623556950595, 0.06040047534042969, 0.06934331773663871, 0.04016686165414285, 0.02043183019850403, 0.06554399660672061, 0.024041074320848566, 0.053193739004200324, 0.04457770875887945, 0.029747874541499186, 0.016481079401273746, 0.050453525691409595, 0.01162315233159461, 0.03439851512666792, 0.07153177764848806, 0.023547379132651258, 0.019744618148251902, 0.05324320314684883, 0.0987992035516072, 0.06159011580166407, 0.06830784361227416, 0.0626018040929921, 0.0496966797800269, 0.037034790657344274, 0.026937817710859235, 0.013690435298485681, 0.04351559895440005, 0.03717738691193517, 0.06099921040004119, 0.057721337070688605, 0.046001611844985746, 0.011990867951681139, 0.10793308218126185, 0.053547765710391104, 0.02467132653691806, 0.025082815882342402, 0.009448392465856159, 0.041977304936153814, 0.04671990689530503, 0.03924623117200099, 0.01841167268139543, 0.08513224980561063, 0.01939624475198798, 0.03650455211754888, 0.009398060938110575, 0.03174801262503024, 0.04135440925892908, 0.007904867234174162, 0.031997589467209764, 0.014930353481759084, 0.05145994102349505, 0.019833423539239448, 0.03245253341447096, 0.008857539942255244, 0.03324608966067899, 0.022089886442699935, 0.040226508062914945, 0.02789299702271819, 0.010324758477509022, 0.03668595527415164, 0.035986217626486905, 0.023345837798842695, 0.055278287109103985, 0.011761573077819776, 0.029771298577543348, 0.036062966828467324, 0.030485697352560237, 0.023855405670474283, 0.03767924943531398, 0.025721237288962584, 0.015068570137373172, 0.038541053581866436, 0.02749761970335385, 0.01341511242571869, 0.021132599431439303, 0.02691140467504738, 0.04615133271727245, 0.017588590089872014, 0.05538948309549596, 0.013176978573028464, 0.041204265362466685, 0.058312669207225554, 0.012826248857891187, 0.03385701078514103, 0.027825893885164987, 0.02913940992584685, 0.04528921315795742, 0.07642725089681335, 0.019664340034069028, 0.0446293102868367, 0.12262388059752993, 0.06397488861694, 0.05462439192342572, 0.029829648083250504, 0.02990186090755742, 0.04059947808855213, 0.08873989645508118, 0.1007692568236962, 0.22778026177547872, 0.05052504646300804, 0.003336191061862337, 0.011042252936022123, 0.04760236872243695, 0.040669978407095186, 0.03603894350817427, 0.017708456216496415, 0.020096349762752652, 0.004850550121773267, 0.029919099142716732, 0.051992880980833434, 0.05746079870732501, 0.03160567983286455, 0.03703555506945122, 0.011090835778304609, 0.07309742723009549, 0.057545756062609144, 0.04058133257785812, 0.023247469835041557, 0.10258739988785237, 0.029275208107719664, 0.020170661009615287, 0.022762262960895896, 0.034384098908049054, 0.02187319416407263, 0.018621667077241, 0.11180193512700498, 0.012842593732784735, 0.06123967366875149, 0.018035353714367375, 0.02300185977219371, 0.03580924509151373, 0.06345306974253617, 0.07774802143103443, 0.025254964457417373, 0.03706610557856038, 0.026625607315509114, 0.05073996500868816, 0.11687821039231494, 0.05277788768580649, 0.007024707456366741, 0.09142140959738754, 0.04549654324364383, 0.01458085387639585, 0.023666916858928744, 0.03487787202175241, 0.010765993101813365, 0.02877480204915628, 0.05627973747323267, 0.016942229558480904, 0.029353415629884694, 0.01999401873035822, 0.0600078977731755, 0.020242326500010677, 0.008301963553094538, 0.04835926287341863, 0.024408379904343747, 0.012840781037084525, 0.0851517757109832, 0.0050063315575243905, 0.06095160533732269, 0.01277886829484487, 0.04812211700482294, 0.0442827681399649, 0.022303795667539816, 0.05874640999536496, 0.009271239960071398, 0.05226573528489098, 0.04894179684924893, 0.0948614941444248, 0.05665860386216082, 0.03083449377299985, 0.03569518812582828, 0.040009637668845244, 0.025472901688772254, 0.019884397952409927, 0.05062214164354373, 0.019299594860058278, 0.048020676549640484, 0.0709848890255671, 0.08901388253434561, 0.009286455842811847, 0.05569341483351309, 0.03931735860533081, 0.03516996650432702, 0.041311379536637105, 0.018436809223203454, 0.01673086404480273, 0.031440039892913774, 0.037431553937494755, 0.0484998516185442, 0.0422864688152913, 0.021081808699818794, 0.010667522165022092, 0.026350272382842377, 0.020313713685027324, 0.03589742707845289, 0.0676392279274296, 0.02259745422634296, 0.044375117286108434, 0.02428849522402743, 0.018535112249082886, 0.06340419189655222, 0.046521679250872694, 0.02833101258147508, 0.09321680583525449, 0.058940002927556634, 0.04688080080086365, 0.03065684959437931, 0.04886386392172426, 0.03639292568550445, 0.06860805719043128, 0.052278696894063614, 0.03197102800186258, 0.08591425081249326, 0.01380911584419664, 0.014113403813098557, 0.03428069547226187, 0.02526406133256387, 0.034338345503783785, 0.037471834002644755, 0.044469678032328375, 0.018275859656569082, 0.037515201402129605, 0.05239810845523607, 0.029427333538478706, 0.027250989187450614, 0.04215292676235549, 0.08458953947410919, 0.042993242022930644, 0.031890649697743356, 0.020459514162212145, 0.030840607214486226, 0.0402875793952262, 0.02616939615109004, 0.045626296632690355, 0.037941728514852, 0.005034462665207684, 0.05134826264111325, 0.028539442901092116, 0.03924502889276482, 0.023939205275382847, 0.02814934225170873, 0.05210508999880403, 0.026958827911585104, 0.021495305554708466, 0.06315331629593857, 0.03808862922596745, 0.014817270584899234, 0.02249779863632284, 0.08545254589989781, 0.02341580006032018, 0.006893065301483148, 0.008449416236544494, 0.024627794009575155, 0.09387779966345988, 0.03853348738630302, 0.028063151075912174, 0.0824047828791663, 0.01599610815901542, 0.018604644064907916, 0.032073010224848986, 0.034154010863858275, 0.07991144128027372, 0.09161666865111329, 0.008066712944128085, 0.05576391515205614, 0.05851341273228172, 0.05108701552671846, 0.03617012553149834, 0.043215459591010585, 0.047668338229414076, 0.0596397999470355, 0.02509460118744755, 0.051085449595120735, 0.049165487580467016, 0.08299806315335445, 0.039320716823567636, 0.02107770647853613, 0.032536974977119826, 0.01412777550285682, 0.018200355407316238, 0.016832020628498867, 0.014646058043581434, 0.03955356565711554, 0.023567563694086857, 0.05673118961567525, 0.05270451154501643, 0.027858049288624898, 0.052744498461834155, 0.05074703396530822, 0.014710649938933784, 0.03687451273435727, 0.03596407565055415, 0.03559365119144786, 0.03401551497518085, 0.0040754765996098286, 0.024356023241125513, 0.038940926460782066, 0.02456919402902713, 0.026793748293130193, 0.04362484309240244, 0.0897842095582746, 0.024353755979973357, 0.0711634942854289, 0.0241265623117215, 0.015083260022947798, 0.013529891130019678, 0.024512948511983268, 0.027117541758343577, 0.010816991634783335, 0.020054743108630646, 0.19549330521840602, 0.17422724165953696, 0.25427282613236457, 0.10932006713119335, 0.12051580270053819, 0.142168213496916, 0.12243501143530011, 0.07320429649553262, 0.08646634189062752, 0.13427752128336579, 0.16591613763011992, 0.09753238715347834, 0.11750868710805662, 0.12298418587306514, 0.08253645471995696, 0.14645378978457302, 0.0873000112187583, 0.14525826409226283, 0.12001783645246178, 0.12605722644366324, 0.10308103941497393, 0.12424424130585976, 0.20984737639082596, 0.2125277169398032, 0.11769889955758117, 0.15611009584972635, 0.2664648281643167, 0.16915259911911562, 0.12214116548420861, 0.12936981744132936, 0.06617132661631331, 0.19282336957985535, 0.15421626856550574, 0.23148421692894772, 0.17472813196945935, 0.15835679951123893, 0.09842237806878984, 0.1473390680621378, 0.14977625134633854, 0.10823720687767491, 0.11517682200064883, 0.15564616449410096, 0.15158382622757927, 0.21562278445344418, 0.16734374774387106, 0.1200120996509213, 0.1658851603860967, 0.1355240325210616, 0.15642335638403893, 0.119409512844868, 0.10117161218659021, 0.09964085096726194, 0.10728100154665299, 0.1295989184291102, 0.15343251609010622, 0.1550758388475515, 0.10710490474593826, 0.1303862183704041, 0.1462341140722856, 0.23205988603876904, 0.1087099252617918, 0.18560898170107976, 0.16087459487607703, 0.10471715591847897, 0.14362746878759935, 0.18167782545788214, 0.1228071836521849, 0.15116342925466597, 0.08665082496008836, 0.16560796822886914, 0.20539685036055744, 0.1768399280263111, 0.10112461939570494, 0.1594863779610023, 0.12605911149876192, 0.13533647696021944, 0.2261390318744816, 0.08984920685179532, 0.18465784523868933, 0.12698468839516863, 0.10044446331448853, 0.1317813669447787, 0.15986585291102529, 0.1678610098315403, 0.15569698676699772, 0.12325519594014622, 0.18319533934118226, 0.17245046590687707, 0.0959866568155121, 0.12038959306664765, 0.09879600489512086, 0.1754859389620833, 0.12870785139966756, 0.14321479015052319, 0.10910587589023635, 0.14408620510948822, 0.1806424552341923, 0.18960552115458995, 0.07604163838550448, 0.09547173249302432, 0.10157165204873309, 0.08497311850078404, 0.1439785788534209, 0.11030106761609204, 0.152555831882637, 0.11017757424269803, 0.16872602747753263, 0.12808052881155163, 0.07285825529834256, 0.14211230009095743, 0.09257225799956359, 0.13014567346544936, 0.13822678592987359, 0.09394543900270946, 0.12445007596397772, 0.14588972786441445, 0.07200631429441273, 0.13191630423534662, 0.17179908289108425, 0.11432336701545864, 0.08822668649372645, 0.17052572075044736, 0.10688945185393095, 0.12807484396034852, 0.17773239029338583, 0.08543373987777159, 0.10219648102065548, 0.09926945058396086, 0.22696481959428638, 0.14005493314471096, 0.1838476277771406, 0.16714053286705166, 0.09745833565830253, 0.1415957949939184, 0.11281080325716175, 0.0807168496248778, 0.16973414603853598, 0.16478718258440495, 0.25101417442783713, 0.272761476226151, 0.18360194721026346, 0.11588609995669685, 0.12121204112190753, 0.1075593959831167, 0.0974270912411157, 0.1656796151655726, 0.0679481468978338, 0.1376365261967294, 0.1544864400057122, 0.16873959393706173, 0.10486617917194963, 0.1346789044328034, 0.1335591817041859, 0.21041010244516656, 0.18322403077036142, 0.16501891077496111, 0.14536960108671337, 0.11334965442074463, 0.16783957660663873, 0.23090779082849622, 0.19557192834326997, 0.09609949294826947, 0.20249015477020293, 0.05760120191553142, 0.13772602920653298, 0.23669960035476834, 0.22647546225925907, 0.08621758883236907, 0.1487699436256662, 0.12403122265823185, 0.09574862036970444, 0.16164598317118362, 0.21896608552196994, 0.158609664067626, 0.13311022688867524, 0.13229606120148674], [0.06858668333734386, 0.01929968762851786, 0.04136823918088339, 0.08352913660928607, 0.04285992261429783, 0.08520332528860308, 0.05624241857731249, 0.03206649416824803, 0.02646447221195558, 0.03254960633057635, 0.021700069664802868, 0.019841336688841693, 0.04666262051614467, 0.029143257961550262, 0.01515806108727702, 0.009780148247955367, 0.018056710869132075, 0.013552149066526908, 0.008795437952358043, 0.03532533512043301, 0.03247740649385378, 0.06863185044494458, 0.016706439964764286, 0.038434637026512064, 0.026117278830497526, 0.06176774142659269, 0.05211671945289709, 0.041631887143012136, 0.04835231266042683, 0.09775739148608409, 0.06743273275787942, 0.062190016033127904, 0.014742332223249832, 0.022863065169076435, 0.008646582609799225, 0.03371969120053109, 0.02887285460019484, 0.05965996038867161, 0.011138873142044758, 0.015692465858592186, 0.011467802269180538, 0.028408426005626097, 0.018228597837151028, 0.002640175052874838, 0.037996458195266314, 0.034650945526664145, 0.03463704510068055, 0.011852501938847126, 0.06708097702357918, 0.03107667882431997, 0.04189829218375962, 0.05786956251540687, 0.022874060086905956, 0.04129062908759806, 0.053797683940501884, 0.02008182964345906, 0.06996176423854195, 0.010173606187890982, 0.018244464954477735, 0.033527055638842285, 0.005969502408333938, 0.025540897258906625, 0.05188397080928553, 0.052972419434809126, 0.025489535073575098, 0.14071522193262354, 0.04710032437287737, 0.03359742979228031, 0.04015303544292692, 0.041948227590182796, 0.03195073026290629, 0.054457816877402365, 0.06922870787093416, 0.06492765038274229, 0.0483708440879127, 0.02853060021152487, 0.04384435553220101, 0.024644915356475394, 0.04307559815060813, 0.03412808393477462, 0.057677349977893755, 0.08709959423867986, 0.08201801261748187, 0.02130270153429592, 0.017073812341550365, 0.04679808102082461, 0.03591415879782289, 0.03933220526960213, 0.014961801061872393, 0.08261314083938487, 0.025349874013045337, 0.022335385183396284, 0.01599369617906632, 0.07557451579486951, 0.014924764182069339, 0.025163222016999498, 0.06368802627548575, 0.04170532636635471, 0.05068004771601409, 0.06419177385396324, 0.023947305817273445, 0.057163145538652316, 0.030959194991737604, 0.05091460719995666, 0.055915064658620395, 0.04751861735712737, 0.0324777330388315, 0.025252398481825367, 0.06700667319819331, 0.022244394167501014, 0.07692663464695215, 0.025436122705286834, 0.04331041738623753, 0.10028123535448685, 0.017696993745630607, 0.03465595131274313, 0.04777849149832036, 0.043587216205196455, 0.07337769187870435, 0.03837576987280045, 0.012742516046273522, 0.048269952822010964, 0.060258316952968016, 0.012926662366226083, 0.007874771290516946, 0.016341685513907578, 0.03340703551657498, 0.015236933759297244, 0.0435898174328031, 0.04108755892957561, 0.02127630705217598, 0.03768033297092188, 0.05942897805653047, 0.05136654544912744, 0.028875042080471758, 0.030698480368300807, 0.011885140665981453, 0.03443212328420486, 0.051916647571488284, 0.05575526171014644, 0.03674426581710577, 0.07578321514301933, 0.03610950690926984, 0.04857437808823306, 0.07556299024145119, 0.06502528733108193, 0.07803924760082737, 0.02066348974040011, 0.029430662070808467, 0.062409595266217366, 0.030770040102652274, 0.06117039418313652, 0.026173288715654053, 0.06439008313464001, 0.04647868663596455, 0.0091693440117524, 0.034303334687137976, 0.018301142772543244, 0.008418980760325212, 0.06659089980530553, 0.07259437727043405, 0.01994256192119792, 0.0537772526149638, 0.01790520327631384, 0.08571430880692787, 0.06275001840549521, 0.019234822066209745, 0.029088864102959633, 0.034590237846714444, 0.06483852586825378, 0.03462901877355762, 0.024473844750900753, 0.03291106935648713, 0.009852155126282014, 0.021074144169688225, 0.06935836107004434, 0.06049460564099718, 0.03951070291805081, 0.025514573280815966, 0.011812216307589551, 0.04004006572358776, 0.05131844314746559, 0.033077881889767013, 0.06616739323362708, 0.02014220335695427, 0.08703446335857734, 0.05618852381303441, 0.016038918947742786, 0.03092912316787988, 0.04582138870318886, 0.07736572631984018, 0.017028502370521892, 0.06612359909922816, 0.050884865631815046, 0.0059778302329505095, 0.0323357787419809, 0.02300483021826949, 0.046992816860438325, 0.028655657661147416, 0.05974900326691568, 0.050866664460045286, 0.050074284517904744, 0.024553044895583298, 0.04848587697779294, 0.02765753582934849, 0.11513623394421302, 0.10977043202728964, 0.02856440874893451, 0.03579730764613487, 0.03629474696936086, 0.02372415499849012, 0.015117649290914414, 0.017080144716601353, 0.05655540451698471, 0.01533744003609172, 0.03830665737041272, 0.008888174870662624, 0.03746790061995853, 0.051911530463257805, 0.028401535164448433, 0.045027951200609095, 0.05807578309031669, 0.028587216802407056, 0.09765257796971127, 0.0623438335605897, 0.03974247934820596, 0.037429409130709246, 0.03766869238461368, 0.029745219508185983, 0.016317374611389823, 0.013272192409203853, 0.06063945060304832, 0.0821620189526584, 0.011064710324717453, 0.0761489529395476, 0.014843599201412871, 0.0324585225462215, 0.010429086814838229, 0.06185804966662545, 0.05604033918643836, 0.023760249350743834, 0.07103810843545943, 0.060271352776908316, 0.08255998080130666, 0.05681775372067932, 0.07391381193883717, 0.015364125811174745, 0.08665729648782872, 0.024541404309275094, 0.04316128652135376, 0.0500078103505075, 0.012253054810571484, 0.058283844191464595, 0.04941025530570187, 0.08054337260546163, 0.025757593248272315, 0.025591903213353362, 0.05266471016511787, 0.0751707206654828, 0.02420275119220605, 0.014937676623958396, 0.048264319921145216, 0.04385264161101077, 0.030640442564617842, 0.019245069270255044, 0.09042096484336071, 0.020153422774455976, 0.04092695817234926, 0.03757268816116266, 0.06427771455491893, 0.04935298376949504, 0.014240846339816926, 0.04185341080301441, 0.01079685067452374, 0.06342212218442, 0.040873902034945786, 0.041072281819651835, 0.014167717890813947, 0.02695356608455768, 0.047490864744759165, 0.01214077157783322, 0.031900082394713536, 0.029991432566021103, 0.021004397131036967, 0.06496302856248803, 0.012132965111959493, 0.03205848639481701, 0.023069591879902873, 0.04888481846137438, 0.047455738895223476, 0.03662118062493391, 0.029182840407884214, 0.03742835899174679, 0.09343632569652982, 0.08350507618160918, 0.02387189248111099, 0.027752066889661364, 0.0498849329596851, 0.05833447721670382, 0.008806081277725752, 0.03220649290597066, 0.0628461191081442, 0.07092594765708782, 0.055161083437269554, 0.09495310485363007, 0.031667044313508086, 0.011227534741919953, 0.02662829760083696, 0.03249751127441414, 0.029245130717754364, 0.05039235045842361, 0.025950521958293393, 0.02267961739562452, 0.01952402773895301, 0.071204327250598, 0.07004317783867009, 0.02771086285065394, 0.03872059765853919, 0.018686671792238485, 0.04198138303763699, 0.08542123468942009, 0.07192388395196758, 0.06113076720794197, 0.06308820768026635, 0.03717958737979643, 0.049231976590817794, 0.027845879922097083, 0.06749138468876481, 0.02969847533677239, 0.03883142628183123, 0.010711026861827122, 0.04577274463372305, 0.022959492416703142, 0.03215842771169264, 0.03219886733859312, 0.005637566655423143, 0.04866282353759743, 0.021959108889859635, 0.12142966850660741, 0.027465325147204567, 0.037463811386260204, 0.03776301564357709, 0.019122221565339714, 0.013779509718006011, 0.031512707282672636, 0.06523512216517702, 0.02041651969193481, 0.07611401262693107, 0.07845827160053886, 0.03130113211227581, 0.04882674911641516, 0.011250018105783965, 0.14530654822010547, 0.06955256627406925, 0.14106852875556797, 0.11435015854658559, 0.17287221358856186, 0.17177965346490964, 0.18926708697108552, 0.17629436042625457, 0.10586792268441059, 0.16031439212383702, 0.0960500436485745, 0.11844915148685686, 0.13716827554162592, 0.13402008509729058, 0.1582969824085012, 0.10720809295889921, 0.13693392014829442, 0.14849071798380464, 0.08517799578839913, 0.1164691979647614, 0.08463927078992128, 0.16511911555426195, 0.08136917516821995, 0.1934800812159665, 0.12185528277768753, 0.17580604209797457, 0.16686016431776807, 0.2509772451594472, 0.11928492109291255, 0.1491578939021565, 0.15890169917838648, 0.1153139783127699, 0.09838944155490026, 0.16562076285481453, 0.08731062393053435, 0.09373172273626551, 0.11770282551879063, 0.13021862658206373, 0.1132133293140214, 0.07605429942486808, 0.06023695052135736, 0.15177764551481232, 0.09482428285991773, 0.23201492673251778, 0.10121343962964602, 0.18258806958328933, 0.13621629303088412, 0.28703980380669236, 0.16632181039312854, 0.10915450140601024, 0.16991747135762125, 0.12262052609003149, 0.09889137087156996, 0.17548636940773576, 0.127166930178646, 0.12229945816216059, 0.20290698943426833, 0.110193560103653, 0.21775788394734263, 0.31345049443189055, 0.09199380583595484, 0.0646407064050436, 0.14721263578394428, 0.15011664479970932, 0.08741542260395363, 0.20623102434910834, 0.1939306390704587, 0.17914155061589554, 0.09652095119236037, 0.15287520771380514, 0.1617843343410641, 0.23883725283667445, 0.10983434578520246, 0.10928157935268246, 0.1405366463586688, 0.15515213162871078, 0.15158440510276705, 0.1241969368129503, 0.12342041285592131, 0.0818619538040366, 0.14246171806007624, 0.18812302179867402, 0.1604570625931956, 0.20032510219607502, 0.09907602463499643, 0.11577842175029218, 0.15660534583730623, 0.1184835574531462, 0.10243489596177824, 0.2310241892701015, 0.15647514344891533, 0.12737250508507714, 0.150046422786545, 0.15527097915764898, 0.1535606404650025, 0.2094206860056147, 0.1705779679468833, 0.10660661195288412, 0.2129066427005455, 0.17598026868654415, 0.16859678988112137, 0.13419817085377872, 0.11093114357208833, 0.10193770154728554, 0.13739636720856652, 0.1302080138702877, 0.1480372212245129, 0.09729682948091067, 0.24053064087638631, 0.10740119236288592, 0.10626609233440831, 0.10859205736778677, 0.26527697627898306, 0.22815877193352208, 0.09474796781432815, 0.22270167100941762, 0.14972746255807579, 0.18321727722650394, 0.2239247303805314, 0.12381467880913988, 0.11150561040267348, 0.15628221473889425, 0.13256569829536602, 0.1429747647489421, 0.12612428690772504, 0.22591376036871225, 0.16547512379474938, 0.16888940386706963, 0.19134205766022205, 0.08771242268267088, 0.09509843221167102, 0.16755727847339585, 0.12852707906858996, 0.18224930885480717, 0.2658126881578937, 0.1376005171914585, 0.09602296267985366, 0.14873553765937686, 0.18719612387940288, 0.09296671691117808, 0.1159028205438517, 0.3130647854413837, 0.11130656639579684, 0.09394707914907485, 0.21274960425216705, 0.20641334034735337, 0.12610294274054468, 0.131765499827452, 0.23764310753904283, 0.14804444974288344, 0.1322679189615883, 0.15141837182454765, 0.14631264813942835, 0.14682219189126045, 0.15291523915948346, 0.199716214556247, 0.13236867293016985, 0.11043695485568605, 0.16340309201041237, 0.15608423942467198, 0.20069365273229778, 0.15982843382516876, 0.23808992496924475, 0.09299008714151569, 0.12833955319365487, 0.1429739483864978, 0.07128357377951033, 0.13046490086708218, 0.14906809403328225, 0.12216532981256023, 0.121410105493851, 0.12388495277264155, 0.13572218595072627, 0.15149700979236513, 0.1259263264364563, 0.12489085231209174]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.057914577482733876, 0.022784202701586764, 0.017982195531658363, 0.017221976559085306, 0.045213365665404126, 0.04641374500351958, 0.014391950389835984, 0.014218144970072899, 0.043467181239975616, 0.015159998092713067, 0.024974048574222252, 0.07539864905993454, 0.02247150619950844, 0.03962421069445554, 0.06065244189812802, 0.0033685983316900092, 0.02944994677818613, 0.00551478156921803, 0.03924149998056237, 0.025867913500405848, 0.04556437925202772, 0.04677017255744431, 0.04907105671009049, 0.019517656401148997, 0.004861898023591493, 0.03311078871774953, 0.03503776031720918, 0.0362695287913084, 0.014313902429421432, 0.04167817118286621, 0.1188382891996298, 0.06253995350562036, 0.04644583917979617, 0.03196094221493695, 0.0237996518262662, 0.005174742955205147, 0.04269842756912112, 0.020863602439931128, 0.03135580613161437, 0.031093395700736437, 0.022185937050380744, 0.08844599855365232, 0.01819061657442944, 0.09082591772312298, 0.11867451947182417, 0.02122509144101059, 0.03736399252375122, 0.03650312348327134, 0.04655069722502958, 0.0463311439671088, 0.010776828457892407, 0.09254001168301329, 0.01665660660364665, 0.025262163289880846, 0.04730881591967773, 0.10960916333715431, 0.08352512159035541, 0.04299754276871681, 0.012104121542506618, 0.02744529087067349, 0.08358611128642224, 0.08935028323321603, 0.024923820019466802, 0.04879475513007492, 0.0911564331909176, 0.026767114468384534, 0.051828046271111816, 0.03405798437597696, 0.0071556130296812626, 0.022182599241205025, 0.07958192029036582, 0.07804018270689994, 0.03714789396326523, 0.020534810610115528, 0.05409996068920009, 0.04716724011814222, 0.053463639560504816, 0.015151272291404894, 0.03706629482621793, 0.008789087023615139, 0.001461293181819201, 0.03601650467317086, 0.002317164553460316, 0.016732337207940873, 0.031335267194663174, 0.014837802100373665, 0.016170737362699583, 0.01934358380822232, 0.06941154337255284, 0.10492611501831561, 0.024334209665539674, 0.08644560628454201, 0.02474194930982776, 0.06635146812186576, 0.004829078397960984, 0.028135187640145887, 0.02225095289759338, 0.03759321596589871, 0.023567010794067755, 0.04386099819384981, 0.012570143899210962, 0.036230514087947085, 0.0320489720616024, 0.005781359159300337, 0.03247845292207785, 0.010211513235844905, 0.047464151139138266, 0.05173426106921397, 0.0157386960927397, 0.01785308966645971, 0.027984739463136066, 0.09968561731511727, 0.06057788945327047, 0.029848582125850953, 0.008447250093013281, 0.04022651177365333, 0.04167476843576878, 0.08984560743556358, 0.04887074734142516, 0.016893618885660544, 0.010964810753648635, 0.055620242783334106, 0.040377757759415545, 0.026057428331114352, 0.03500997801893391, 0.014333009949041298, 0.024965513875940815, 0.07282269900315441, 0.04378474623081274, 0.0482451799325645, 0.06487376303994097, 0.04468576174986083, 0.03408052340091672, 0.0024183726236515213, 0.01511657039372949, 0.010386108115199022, 0.017710947977320757, 0.025038650674105156, 0.07661720359465107, 0.07837266486603767, 0.018942879723908845, 0.026746976291178726, 0.03084603788011009, 0.11424187920056283, 0.10142467712284997, 0.040264468916575424, 0.04840206624066923, 0.01846756938903127, 0.03636197070591152, 0.06258131339563988, 0.03819059660600033, 0.009688531044957926, 0.022096422908362, 0.036106059633311816, 0.09268461173633114, 0.05701833397324663, 0.011538415765244281, 0.034355845345999114, 0.04799998918315396, 0.03805359985562973, 0.02182274853112176, 0.025403566542081535, 0.026392704676254652, 0.03664308511361014, 0.025989688801928423, 0.03933689935365692, 0.023222516974783503, 0.06821896400651895, 0.025412756185687613, 0.018500223886803724, 0.02255914827401284, 0.036615766657632776, 0.052305963399703614, 0.05394582403823733, 0.03799622441874817, 0.06717681055306457, 0.07920386284240521, 0.0229164775373647, 0.019821115020022262, 0.039890760453999974, 0.10473917544004507, 0.058581720004440285, 0.02905874775024131, 0.02104200546455104, 0.05557976233831141, 0.019469205290079117, 0.04878067658864893, 0.043155601670150645, 0.02035301411524415, 0.1383674526005052, 0.012989831193408463, 0.024053527558862697, 0.08174127317033708, 0.027473104710225016, 0.05116821761475876, 0.04396456490212586, 0.048114699238794856, 0.05585882841842249, 0.06818132227635942, 0.01756717170792399, 0.06952144060051069, 0.04911232383165043, 0.03195793280610815, 0.015053044407977723, 0.015571592266496737, 0.031334669765783474, 0.03914076085493434, 0.02622541902383091, 0.03378152323421091, 0.0505469435302075, 0.030172707702149637, 0.018989219424838666, 0.053185890792519785, 0.028674292989308015, 0.017893154508783482, 0.0149418586261163, 0.05496920486621093, 0.05979565466986969, 0.011466213145467918, 0.05525769251107704, 0.11181072957697324, 0.0523877888917923, 0.05387868564866949, 0.05947550329437945, 0.03436600534769241, 0.014180503239913378, 0.016217722732108086, 0.04067920701345429, 0.009975161465263227, 0.034126113532693125, 0.015805049661139492, 0.016670815020916052, 0.026909933367278427, 0.038696147603332065, 0.0373803754337132, 0.04380707374366466, 0.02982131190947257, 0.02621947627631016, 0.04549961202428676, 0.06349267074256204, 0.03169175412040204, 0.03941558927181177, 0.01848026196967112, 0.05226495231909212, 0.021807066950714216, 0.032549116513109766, 0.02377556542342063, 0.04880248088738881, 0.035837595132761635, 0.0331781868590042, 0.013215319777373224, 0.053795884232386015, 0.05885819598915987, 0.03406975854886696, 0.03483029293420259, 0.015836218008189462, 0.023807728248357307, 0.03668245604785625, 0.04304735572077334, 0.03795343218371272, 0.03483077904093079, 0.02838815053110011, 0.03827135340543464, 0.036429661995498464, 0.08610814431449398, 0.032327474109479226, 0.07799454062478617, 0.013913873699493706, 0.02189961091062287, 0.050762567116180435, 0.05513273339602165, 0.015441852792719146, 0.049143282521981746, 0.012424915803421754, 0.07705891504883766, 0.015390390417451272, 0.03107569176791003, 0.07398418980301358, 0.027494942405610345, 0.06220857714652084, 0.0309863520305953, 0.033597448345972225, 0.04534977982984856, 0.0019966043009844725, 0.0553898504585959, 0.03918059192073997, 0.006955515173103777, 0.041951634048018605, 0.0824744557030499, 0.02728081981331343, 0.011818436432804447, 0.062001688638702035, 0.0303414052905282, 0.02914593154855538, 0.008364374461962143, 0.06117270968388766, 0.024278735982079525, 0.015136221536522498, 0.04550102210487239, 0.020445027439564, 0.04574266909912694, 0.037930807811790146, 0.033585466371732764, 0.05425011200713925, 0.013859244209015742, 0.028103245604143012, 0.02451669264701195, 0.07204791909316555, 0.07884090067818761, 0.04266591779014561, 0.008557081455364823, 0.02828792348736897, 0.025389243091922253, 0.032251366865239106, 0.054932398052187636, 0.04794805368874222, 0.07085418197675608, 0.022885765611135866, 0.029488393738574814, 0.0409019849030301, 0.04571039680740796, 0.090287133352831, 0.056046313475235365, 0.014932938938727602, 0.029954976416775025, 0.04522061273746658, 0.04209086095215753, 0.03141006083751563, 0.017974271249840967, 0.06841981885372661, 0.027835048276756424, 0.020945132928318344, 0.10026198404375464, 0.029842086478311103, 0.026860181642405223, 0.006260773106987472, 0.046807758626528084, 0.039809075969969854, 0.027783880905190017, 0.0794746947940439, 0.011072477827838156, 0.03950528524001129, 0.03068707726924913, 0.057284260328742675, 0.026848915840673726, 0.06074374832678586, 0.009358937695651548, 0.07603359350468963, 0.029037681888439693, 0.013098057661409257, 0.0327374068001518, 0.05134298968187068, 0.21201358671532944, 0.0945502299873624, 0.11430839789682068, 0.19687893945956603, 0.22886642458615825, 0.16309000959154218, 0.0856350251706317, 0.11671201384160668, 0.15607634297339246, 0.0710890197660774, 0.14668087213067338, 0.10329923083190806, 0.12412169788149185, 0.27563682349864393, 0.13748362893238664, 0.07911466411314905, 0.17368488013744354, 0.112828718702076, 0.1607451049494557, 0.12463476683478802, 0.13477527973009273, 0.2131231568637304, 0.14206827589077875, 0.11730113066732883, 0.138544024375733, 0.21200710034463555, 0.13957011775346473, 0.149070454062894, 0.11880950129125267, 0.10795092341140844, 0.17809997603762895, 0.11374540466931649, 0.0960053812013939, 0.15808080963324755, 0.07982881797943264, 0.060945605073357, 0.13382300036028028, 0.09630122352973558, 0.1549603309831582, 0.1415851674391888, 0.10671033451217227, 0.14101700886385515, 0.1722288309247233, 0.245976357255131, 0.22823271952802315, 0.2031214552698657, 0.16497788485139608, 0.18859256379073486, 0.11517248043674044, 0.09478632200625725, 0.08726697822567075, 0.10288065212080255, 0.10616668165312149, 0.11433331921580248, 0.11687665188219398, 0.20974881917936727, 0.2411533027770929, 0.15100860240636393, 0.14004473603563383, 0.17343159997835755, 0.19919877435313538, 0.21103840466821566, 0.19923815270885825, 0.15527249313890934, 0.22141627123346552, 0.22744405403500423, 0.1663318442297168, 0.18021674448391423, 0.1794112619245425, 0.14466390770394355, 0.15019376878626645, 0.18994530604686588, 0.14472841517999768, 0.1044990609807428, 0.13499464374035597, 0.16518761578481644, 0.254320798558183, 0.13783070171484724, 0.129665533604566, 0.1344402297399938, 0.11382136348402128, 0.18347720702877268, 0.07882362348027527, 0.13764592178631574, 0.1313306755037047, 0.18921654671430588, 0.20033892098581418, 0.16256229806458578, 0.16355952189769596, 0.2218757793889381, 0.09885149527690373, 0.13103003147989511, 0.08681663559400477, 0.14890265447320417, 0.2094515593489632, 0.1082025931100361, 0.13833988923579454, 0.09475705912336707, 0.1265337594668381, 0.127117132069543, 0.0868973441538401, 0.15960651682689786, 0.09765944283572026, 0.15744511561933905, 0.1699366484535858, 0.10072403034428135, 0.16927512770053, 0.15494995575863868, 0.10441377336974256, 0.11830081100924872, 0.15959312848281115, 0.18279584124684334, 0.21529668476432562, 0.14014875545399264, 0.0831896040472202, 0.19747650192584842, 0.17805837123887613, 0.14649848191766068, 0.11615638271905482, 0.1383641574648209, 0.10935780534055084, 0.12368965661153197, 0.19584391062380746, 0.14220646378817037, 0.17632054339628667, 0.1642656754120253, 0.12909121520351619, 0.2453181316377595, 0.09009210436488502, 0.1325346765224822, 0.11711867366102524, 0.19092973525403067, 0.1563013473059982, 0.1186284988943953, 0.11715429674950428, 0.12408220078214072, 0.10946676004095934, 0.08300070519908331, 0.10552998573984951, 0.2870414068456739, 0.14112209697486833, 0.09084362536668777, 0.11433900406700559, 0.12586711789481342, 0.150408768968191, 0.2138858917169273, 0.14503032085485756, 0.11206795054022223, 0.1853867678437382, 0.09782990673556924, 0.12612698832526803, 0.08981903112726286, 0.1345195504836738, 0.16581790696363896, 0.13510149816283956, 0.144565855152905, 0.2596769673982635, 0.11693001972162165, 0.1553644155501388, 0.119104623736348, 0.12884885945823044, 0.13997426169225946, 0.113918362185359, 0.1293747453019023, 0.06616950093302876, 0.12237619623192586, 0.14798193122260273, 0.2982688246993348, 0.1410125708207488, 0.15707505110185593, 0.047806047441554256, 0.129737863317132, 0.1831899958779104, 0.11736845088307746, 0.15807264600880444, 0.1755358261289075], [0.0368225846614223, 0.06915332050994039, 0.07646086276508868, 0.02266786734253401, 0.0007195481782673596, 0.019498100809869356, 0.09281510356231593, 0.07436548301484436, 0.08747812666115351, 0.06856300882645883, 0.044319897788227536, 0.023520177564932965, 0.08291314661619253, 0.05974780098767951, 0.013754984520346625, 0.018113798723788932, 0.027722297490981873, 0.05676274202414788, 0.12180280551547185, 0.040466318241669796, 0.024784990164334886, 0.059716348769143224, 0.06496320667793043, 0.053058063276694156, 0.050972940007341094, 0.012446959444787353, 0.06732525493134744, 0.0442400093015749, 0.05117733860970475, 0.06432531590689905, 0.02444828332954785, 0.03589236192055978, 0.025536373868817464, 0.04030106050777249, 0.05449693177070003, 0.08529892133083194, 0.04460502721485682, 0.017821466753957793, 0.11230402771616355, 0.0833001543651335, 0.004099787502127583, 0.026724199778982438, 0.029081648572173435, 0.06106829321652185, 0.018709785981627647, 0.07604490383528173, 0.0496098781877663, 0.03956536951591261, 0.04725638689706102, 0.02763934578979388, 0.03795413351326715, 0.031240762109518982, 0.018387131713097915, 0.02822521943016909, 0.03386464748473372, 0.05841533049533609, 0.041823609863058664, 0.08059732674155384, 0.013347044496185845, 0.0599758073076373, 0.037319871844374575, 0.004274883331163437, 0.0232674892686191, 0.011260769970249385, 0.027364901434339117, 0.03383460163604468, 0.04213316336972639, 0.008575441261200467, 0.03208204587281216, 0.05914449429837987, 0.02008176285016816, 0.0864694218034856, 0.024115368869388476, 0.021946484957879875, 0.032403269651695155, 0.0612952456867788, 0.05586624989518896, 0.10658549785148352, 0.10041294430266134, 0.015737241483293474, 0.020689156917796936, 0.025089805058087222, 0.010747617525339592, 0.0191519037616672, 0.03931467203074135, 0.09364542580442503, 0.02151013737602625, 0.02394506267592078, 0.02750612471572822, 0.05600913929811213, 0.0368076006998308, 0.046945686772232875, 0.0145658151814132, 0.05096639426483307, 0.02242537244455889, 0.025838051333266776, 0.05536196054890752, 0.01788008157745935, 0.012523006389528746, 0.05160511995200068, 0.031340536443167366, 0.05389995931182057, 0.03843546823190991, 0.05623120472591836, 0.034209093064418994, 0.03174813879013527, 0.05969773199467454, 0.01883974160591606, 0.03036830443306826, 0.027071740114479326, 0.027905246170121245, 0.03986619536590297, 0.026738486121757887, 0.04948822162987199, 0.02101196147123119, 0.03546904459653888, 0.029942018518340774, 0.10108429109095596, 0.004455838416106417, 0.021401973062893376, 0.020624870230676606, 0.023468516665161587, 0.03312028449727222, 0.02585470698249992, 0.02909098478994565, 0.04533356390311383, 0.028139970781921875, 0.03129803735646419, 0.07848443230614066, 0.07635633126483299, 0.024277724805870093, 0.05120395573612768, 0.03044500725081889, 0.09245244567864574, 0.04344596323790029, 0.023713518166914582, 0.06908136929268949, 0.031099191874091048, 0.03954916843213141, 0.06471515123848803, 0.06683456173050217, 0.050462798826629296, 0.02650075766723603, 0.04263125949364621, 0.010590222846076358, 0.028370643267408013, 0.051413920446066186, 0.049143430951517075, 0.04741256816487294, 0.04899418505374342, 0.07488000657758676, 0.039344228061963804, 0.04412312846397981, 0.03017457976966398, 0.06838137560407631, 0.016729949347791262, 0.019779897993430495, 0.012954638550581876, 0.023590946912008803, 0.007164585595091921, 0.043564814477576874, 0.0942538607341703, 0.012603469112946186, 0.033166601933771744, 0.009424771760677686, 0.016658020394970663, 0.07807829941157252, 0.08700927486643195, 0.06193271343363449, 0.01366300737572601, 0.01619454546016641, 0.046981317282188684, 0.04811675498785917, 0.013847261307091685, 0.01707827079371782, 0.07855300675146282, 0.024830120164551772, 0.008049898660829058, 0.03418907734157983, 0.015896717886789702, 0.03431954319239594, 0.015236191611620598, 0.07926908278022893, 0.04734212350740563, 0.05445313763630111, 0.049018872596207075, 0.05132328937179409, 0.04256632899341639, 0.026930359126708936, 0.005595673346761032, 0.04138290401897393, 0.047030491987243295, 0.058466171321924776, 0.005814577225464745, 0.058658573107095435, 0.05821420476422645, 0.05624917583190836, 0.011044163038604893, 0.06608570503885858, 0.04040739171614405, 0.052389128468348645, 0.020991906785639003, 0.07530533883254975, 0.014994449993537273, 0.018239097371406388, 0.04344061977462843, 0.06693603558233008, 0.008041051332838833, 0.03666119351692032, 0.022081550268922, 0.029579225192719605, 0.022758144041290507, 0.022738321276847273, 0.024968233847175725, 0.027968753602181096, 0.08971984309027903, 0.013687269110960187, 0.06517564645037055, 0.008394398973905481, 0.0387097734346753, 0.02280870841786964, 0.06183359961141832, 0.023186648977571167, 0.09976832967367955, 0.011379799325368367, 0.032627965993015096, 0.027670764611684717, 0.016112601224449463, 0.027806178732134867, 0.01047011459377245, 0.056564833503216505, 0.09494470374193043, 0.04447160390554927, 0.05267381631711032, 0.0958430660830345, 0.04178666575171519, 0.08414108189754188, 0.07582335048937239, 0.013666984359588241, 0.008373256114282412, 0.01034546532537206, 0.009250423645426054, 0.04701368234236725, 0.06262207956751809, 0.021381085316534154, 0.04546382566331886, 0.04748371044115629, 0.05618720650090836, 0.07175060731242411, 0.061080345694790594, 0.010900332963501569, 0.03841704070509877, 0.041499135477351956, 0.033090149590861984, 0.027312374077155255, 0.05402961622166913, 0.043216814010520466, 0.08517508656950668, 0.06001666624797508, 0.05592206311121117, 0.04941362094541546, 0.002584212247711548, 0.005940676001046086, 0.04535111198492814, 0.05275640622130595, 0.04502638155827299, 0.04359230733825825, 0.035581261035986245, 0.04136101437325124, 0.040671343958820216, 0.017711426662572194, 0.01845778231654549, 0.02237610682641389, 0.05471880052937195, 0.02390053752606036, 0.009786574319150532, 0.018923459574580193, 0.025432508446101565, 0.020906441059196368, 0.0791040068725124, 0.01358111045192345, 0.01004243529678206, 0.034276216611033306, 0.025088118527492043, 0.013644422142533585, 0.011767745891120285, 0.001017259965010453, 0.08507261823979206, 0.08119109683320858, 0.026254804361087736, 0.031063719070516527, 0.03468589697149582, 0.08068533803452738, 0.04349242168245837, 0.005544674813791062, 0.03491601470159367, 0.06000258028507233, 0.04815480860997923, 0.019745297213376034, 0.044303522299742326, 0.03540408069966361, 0.06337929284200072, 0.014339495392050594, 0.010684474673325894, 0.016685060545569286, 0.08049718133406714, 0.026733051745395642, 0.04442244033270981, 0.04124317616515327, 0.026028950269392226, 0.04678084093029611, 0.04256246982549783, 0.07951036241138354, 0.013290824026626069, 0.05415084233391099, 0.03803512408921961, 0.06448058062233031, 0.02763192060228903, 0.06941202576854266, 0.007091917277648463, 0.012281585750315571, 0.05458472041937057, 0.0520319290808402, 0.03959213507187087, 0.0330332231533248, 0.029850329883629456, 0.015085845479916316, 0.0503224587009754, 0.045652483313460834, 0.03859412456222344, 0.018049205900751986, 0.03937786219466943, 0.06239988797460683, 0.010718302692112047, 0.020471898751566187, 0.026219266619591508, 0.07131613921956159, 0.04863629175815731, 0.03619274990342092, 0.01828460030083079, 0.014585589706257451, 0.02538296266720863, 0.032756127475295216, 0.09261482759029604, 0.06702743106870912, 0.03915012304787524, 0.019494412335916422, 0.018726000052993186, 0.014090722852415638, 0.009419355938007357, 0.01354305682980339, 0.055781199771445245, 0.11648281637462787, 0.1281668257433921, 0.17914886819198728, 0.09630526081309654, 0.15844514477066696, 0.1307046294095926, 0.2998639375437051, 0.3943740692920983, 0.2322917032870464, 0.13014083466259763, 0.11522969260113314, 0.13976273476146162, 0.11231770549784414, 0.11848573936731555, 0.1537501107668504, 0.17300250503467396, 0.11263878084719181, 0.10297115702996962, 0.2496700856136158, 0.15448577207280323, 0.1818336616270244, 0.07181447654147632, 0.20888929342618212, 0.09617293588235043, 0.1559020421700552, 0.0933874849579297, 0.1893147625378333, 0.09107235528063029, 0.11885385945788585, 0.14504274440696463, 0.12366055700113066, 0.07322371850023046, 0.13640315097291023, 0.12358157022390515, 0.13417324953479692, 0.18860599666368216, 0.130576133960858, 0.10494209345779382, 0.14780427591176704, 0.17327353736618534, 0.18491826485842466, 0.12595973792485893, 0.18630343896802515, 0.10986639914335683, 0.1114750190754421, 0.16076054162112996, 0.22023251600330696, 0.17606215726118535, 0.1314902669400908, 0.11228207498788834, 0.2614346402697265, 0.08989576919702813, 0.08721772188437171, 0.0929141951201018, 0.16144502442330122, 0.1495271865860559, 0.1427021887502633, 0.22221553459530696, 0.13423780153971165, 0.1893228222616017, 0.20081146125448868, 0.11646971004665829, 0.11554243363207206, 0.21350012335460633, 0.12667751347180456, 0.09081816227990203, 0.16769381880294532, 0.1970991346752271, 0.1524280637386255, 0.15694021771196276, 0.159038491838146, 0.14267003891291097, 0.15123624878469855, 0.19786752469372004, 0.09679839567979798, 0.16380339162424207, 0.131510408828035, 0.20323601318523288, 0.10850233171368018, 0.20969836798030883, 0.12507339095463976, 0.1995917860767804, 0.11225995898712426, 0.09448368902667426, 0.14899333007633686, 0.207743372884579, 0.08203090372262523, 0.19049666239880025, 0.19209149322705343, 0.18539423384936526, 0.10212931665591896, 0.1609439856838435, 0.14163195242872462, 0.06476563212345354, 0.11581034894334152, 0.1077253624680452, 0.11189166820258833, 0.11764948736527003, 0.14274129993282259, 0.13583404244855046, 0.11206332696019672, 0.12178620367194526, 0.19769614795222878, 0.24388550460571423, 0.1340072904713452, 0.11715147658833303, 0.09904141086735763, 0.08354150821105577, 0.13455823122058064, 0.115079667448299, 0.19039813487324864, 0.16178759979084134, 0.2037558876327239, 0.12054591163177975, 0.16234392853220925, 0.1335436262888834, 0.15683305158745497, 0.23020145919872448, 0.07347549209953286, 0.13442133466014639, 0.11931847358937375, 0.08702480801730417, 0.11598372948355973, 0.05924855824559927, 0.14694201905513182, 0.09524612702080049, 0.06301497254753485, 0.12001908326055855, 0.15924992971122265, 0.31297587614972144, 0.09809763650991954, 0.22069450293201953, 0.12179928031400777, 0.20594780595274642, 0.12969674833584577, 0.1408315313165076, 0.19199393049348146, 0.13149556587450206, 0.1551850384566933, 0.1236130298639182, 0.13446719938656315, 0.1133198275056202, 0.1725606303079985, 0.13990372797707096, 0.10835385764949024, 0.1613400550559163, 0.10375073863542639, 0.18718395265750587, 0.08110540846246295, 0.2342370356200263, 0.19352806848473847, 0.13355257658986375, 0.26170151657424867, 0.09571116417646408, 0.12858891481300816, 0.13029739813646302, 0.07413995917886496, 0.13242613000329584, 0.10605481031234376, 0.10472150490386412, 0.0865874752344098, 0.23239731090143323, 0.1181799522601068, 0.1407843010383658, 0.04319320258218795, 0.13116039714077488, 0.1479776416090317, 0.15563224180368707, 0.14346455252962187, 0.12227395796799101, 0.09221259839250706, 0.1460210286313668, 0.12503197911428288, 0.20712317491415888, 0.1160924912255723, 0.21035506477346644], [0.029186682877480052, 0.06475072237662971, 0.029957570222904906, 0.027092382952105254, 0.00927942399357562, 0.002963216397802171, 0.08082205647951923, 0.0462921032885788, 0.029710785711358767, 0.030593568517360836, 0.10286766453646123, 0.02244747731310781, 0.06670786227914505, 0.011783270692831138, 0.01504217379988404, 0.03261729019868653, 0.05914748144277837, 0.02839685963408556, 0.02607295220514061, 0.041829131441772915, 0.05259291108814068, 0.026975420478265733, 0.0643716927152127, 0.039775408440618776, 0.0688836611516308, 0.05058586917584762, 0.02231129506981233, 0.011704152184393024, 0.024958632311609108, 0.02587254079116974, 0.023590006239828654, 0.06568988057551906, 0.032357724048779346, 0.019213795167161152, 0.025943135733541567, 0.049395115493098274, 0.0455521449475782, 0.016657092710374855, 0.05331421554728877, 0.06897355007822625, 0.06623044610023499, 0.02897243783081649, 0.048514572117710486, 0.016158733124029823, 0.028017688964609988, 0.024818772726575844, 0.05761419321061112, 0.025467328159720637, 0.02688735352421645, 0.028179657128930558, 0.03387452175957151, 0.030403036944335327, 0.014101803117227973, 0.017542662280902732, 0.057165932303178124, 0.015614349249517545, 0.08836250694002956, 0.02920239043305628, 0.09686548582976684, 0.06501720534288324, 0.041305089835077524, 0.07844441570341587, 0.04590599724906497, 0.035522148973541334, 0.008359024504898116, 0.03817726763372775, 0.031285394870792516, 0.06513845000881702, 0.06292124671745114, 0.05387042183429003, 0.06560391761013307, 0.04252304323017597, 0.011765844137698878, 0.007304822747755679, 0.056762467429507524, 0.02068907157081412, 0.06917154765687883, 0.052816635216004215, 0.019044219989154954, 0.025228480917576235, 0.03182673222909216, 0.09424057629075833, 0.03992996811575722, 0.05242049533990212, 0.05270114961604122, 0.06179331954626832, 0.011765295876102755, 0.014041006379557075, 0.02165351474104682, 0.05348629361833446, 0.06075992714613676, 0.023663488136662636, 0.015597585988871288, 0.04435101232957095, 0.06249782178201713, 0.02439754083752632, 0.044589954195544124, 0.06659290360403247, 0.044355368736432865, 0.028157079141237773, 0.03754772973479703, 0.04397245393192861, 0.0619584065862, 0.0277572378035984, 0.061080290033714846, 0.07919588475488126, 0.036572328754118644, 0.02860551445337478, 0.03820342833932955, 0.06792013082304038, 0.03862074911012314, 0.017304152715951204, 0.016684769252606202, 0.008657367870910093, 0.01792987597582396, 0.04473660999792628, 0.02633139771205606, 0.013525827871490037, 0.018469411770638544, 0.09357771967188455, 0.03758284816285595, 0.030134390617604367, 0.010385142395534785, 0.01650723825150635, 0.05753891346103046, 0.021498287132999394, 0.09722064802190289, 0.030076649672992062, 0.03249772278650198, 0.010220696385658812, 0.030779522894590627, 0.016953363628999796, 0.02947565291833598, 0.058827278116950765, 0.007293818089237902, 0.031832261229283176, 0.006366849202095182, 0.03431573597481474, 0.05129371478687972, 0.03861710887576919, 0.039360328955808654, 0.03355955799634103, 0.033439552717027254, 0.02215185020759236, 0.02308484115928877, 0.029508979059755802, 0.03795139869907871, 0.06966146902414039, 0.041993212871602736, 0.040252305116155185, 0.05646242825605441, 0.022253899223869666, 0.06766845370293595, 0.020928148878738284, 0.0546685497101862, 0.01753584379912354, 0.03179560284479521, 0.03655882908788044, 0.044331716489978135, 0.039047981263138354, 0.022874711321492214, 0.026390420716779772, 0.04259825247572735, 0.02192051164456643, 0.053018206235719845, 0.03971250029280782, 0.03625059289333876, 0.05840443576744292, 0.08178286312613636, 0.06673515847069211, 0.04266511255991645, 0.030720492468390148, 0.02698368985875277, 0.04890220327069983, 0.058377187815494835, 0.0793578807497397, 0.059527171615627594, 0.027636976483336184, 0.07204036402981728, 0.06248722391319461, 0.034139724521082826, 0.06112887102062814, 0.03570723318262026, 0.0435124893556349, 0.012896131338493433, 0.06435152114136145, 0.046026214040466584, 0.029369870899245143, 0.04747050392325036, 0.01050490833222284, 0.04045048823172692, 0.05278611439280212, 0.021186943195061758, 0.022695091174682602, 0.014567664984497242, 0.04558967535558622, 0.039227106026373804, 0.02714665806706762, 0.06312546349363402, 0.04525134507275652, 0.02490184131602291, 0.03643077150627505, 0.04061971645569429, 0.06588877615286037, 0.022388522957044188, 0.03980741726991255, 0.05562039492360782, 0.04662576917326078, 0.013438280420814408, 0.07640111987711862, 0.045555284232250415, 0.025788568636926357, 0.032301766113960184, 0.03694780352816451, 0.012530168114608387, 0.02123896403645631, 0.01708585739834234, 0.03276738956628833, 0.04032904689665884, 0.00763815373829857, 0.0776029538246803, 0.019379017649043817, 0.021389061548688915, 0.022899534305906855, 0.024677447399881203, 0.06090623042837251, 0.02047828493232373, 0.04958576580975205, 0.010732983300840715, 0.01543815596960485, 0.04777321111760102, 0.024036359827732667, 0.015506186791753862, 0.10316995612811297, 0.05124704854097217, 0.017155910572910216, 0.06182654178701341, 0.06662832631263882, 0.015324122196034295, 0.08383263048017398, 0.018798615492414683, 0.03553818678483367, 0.034249054006068036, 0.05001147656003013, 0.05848341141245328, 0.019312901567900553, 0.05489733157446608, 0.05751847100327723, 0.08546629789634608, 0.006757755081707728, 0.005172061946723261, 0.09927960316417739, 0.012348991313047009, 0.039302986915572546, 0.02255393654195359, 0.030824944187770598, 0.02329958344489569, 0.0690286471217405, 0.01809083481930429, 0.052569919353118166, 0.06939091908861883, 0.059776024863822386, 0.013390879448706983, 0.025075949160964228, 0.07113812767784111, 0.06354216457111761, 0.038053161988500506, 0.010844035496120341, 0.02140127915481571, 0.029536457077483647, 0.05145787414221559, 0.042339124192949384, 0.02875304599001538, 0.04367434805317316, 0.0027457743181003025, 0.0435061811003834, 0.08189025189494714, 0.05516405944945291, 0.056354827975155786, 0.01922366387589136, 0.04897932354651857, 0.04909710609354079, 0.008552905019314494, 0.012966838530701352, 0.0325175269972533, 0.04999843331461307, 0.06186303689901251, 0.03985860319517087, 0.03134876686090138, 0.02281193304952467, 0.07820317317964509, 0.018926652664958965, 0.03598109680751804, 0.03745279791473877, 0.07140153073123656, 0.020288400883146096, 0.05070755913038738, 0.02851237491995562, 0.0424668663617922, 0.023799030277587008, 0.013590225880761864, 0.029313020531844813, 0.051605702537926845, 0.03901547890563961, 0.06234540691366419, 0.04392276343423873, 0.021243656265141908, 0.011843925494758878, 0.026615553069859743, 0.016473873147333506, 0.032404486773884855, 0.013518613268388435, 0.031519624099018984, 0.02670528985618148, 0.03465258938376792, 0.08682303290697746, 0.014681569809908979, 0.005055494666521554, 0.03876947550452314, 0.0210586128741852, 0.002181897471018601, 0.023276899701158982, 0.07507303918828256, 0.03920194722013548, 0.037925850265310146, 0.037877224749536254, 0.03176721940690186, 0.05828122441016603, 0.09657474947744049, 0.02853555775800487, 0.05679227579094004, 0.022219628699531313, 0.07948586411657743, 0.10116763427504338, 0.03138542524538934, 0.011128118494525552, 0.045256202429300174, 0.031753237344673835, 0.04748880528495647, 0.037950144469505176, 0.04198912363790441, 0.05075512708572205, 0.028466387739172205, 0.19543805974535644, 0.016912512110138778, 0.045119376372895204, 0.06207064157933928, 0.028092968714190647, 0.027782641518570017, 0.05053305052570067, 0.011275790111540118, 0.06293875398114324, 0.11420060836826451, 0.15027913061203435, 0.1468452875269577, 0.09949567946023308, 0.08689508802490309, 0.21600086416583508, 0.21182338910875842, 0.1453897132887505, 0.0694528290478047, 0.21257239422993734, 0.19977018353529274, 0.11492976103909314, 0.18177071266109124, 0.15347582782851532, 0.12284344498766586, 0.15366633713711053, 0.2049975749105215, 0.11366011705831625, 0.08654466815642081, 0.11758224878576584, 0.22704704955685884, 0.11507167451782152, 0.08454459501081146, 0.14052607817575336, 0.14349775621667504, 0.14473320945398882, 0.13754056650213897, 0.07271516922628507, 0.08307049676659517, 0.07895560702309012, 0.0708732329076156, 0.181977697648108, 0.12479141936637461, 0.13700293988222256, 0.13794447295367718, 0.1306458216276951, 0.22756172897061333, 0.15064392588101327, 0.08601670429925434, 0.11963781231315807, 0.1806337127345614, 0.11886864303960465, 0.1564428154961206, 0.1196079260262195, 0.12181963000330143, 0.11542962718522176, 0.14512668130919337, 0.09025680177728646, 0.10483896461664699, 0.16645676252664998, 0.10772743306006305, 0.1326970139052719, 0.0913188818958588, 0.1616777470917441, 0.13207108655478805, 0.08058249120949768, 0.13548878050642088, 0.14305942895589396, 0.14535437221638858, 0.15990552812581882, 0.15083599369972944, 0.17186698940349743, 0.13719168287934735, 0.23350474366452545, 0.12438139019650407, 0.18519380944781005, 0.11506840906804428, 0.09810580013436265, 0.17370917805237696, 0.12115782723412849, 0.17617621051613241, 0.16447757341666147, 0.20402469352120534, 0.21931878378381953, 0.06546595977852121, 0.1717857687617652, 0.2597051690099761, 0.1645853035734035, 0.10521443939069286, 0.1787565095582977, 0.18626870645675808, 0.18361374735832214, 0.19583150191465393, 0.15432212851010263, 0.1540935321827419, 0.12409178190864623, 0.08079812963842414, 0.1534580162842758, 0.18200065969722345, 0.14715569821419194, 0.1265685068210587, 0.14437374280532822, 0.09477369065280072, 0.1671550195896998, 0.16467023495351896, 0.09199831067235209, 0.11323723389068618, 0.10988323105266318, 0.16537767980480567, 0.13133857195498422, 0.09378478629514575, 0.18458135949913412, 0.1782143409946002, 0.13928136293543503, 0.13915138319134712, 0.19812481245025992, 0.18249626591568813, 0.19630531867733225, 0.09089152357773855, 0.12249608276761137, 0.12871119106421247, 0.13458531961077824, 0.06747431529220194, 0.1124928003991954, 0.0786740510375239, 0.12308439065236598, 0.14633739134296775, 0.09248280694009736, 0.22527204011566937, 0.1283988359500654, 0.2192329618264921, 0.1402589346980676, 0.13230386859504506, 0.16123352717841044, 0.10206201128312387, 0.08702334598638117, 0.22196924546733499, 0.15943110280204564, 0.14806301827775314, 0.19463055854430422, 0.21548467077082023, 0.11955924113863148, 0.09259329046471976, 0.15748548845294863, 0.05422624453785829, 0.08000045447261073, 0.176722030446399, 0.08108114765491337, 0.2277200439129956, 0.22786344168707728, 0.18072784674586728, 0.08563961164327338, 0.1019283504865598, 0.11718570443917997, 0.06049671705113724, 0.05683227383997291, 0.1341215515276417, 0.1681768530397676, 0.12934620230225846, 0.11771336401579902, 0.16421886073658243, 0.1644097114331089, 0.14078772976063192, 0.18102464644471183, 0.14863297285046428, 0.1110837068699766, 0.12467000400647521, 0.13621932099340484, 0.14310606551589444, 0.18350922327954322, 0.13621706486446783, 0.14559177041519433, 0.12915374856675044, 0.1563496165908873, 0.11157830376760103, 0.1116638511302881, 0.08880185094312765, 0.2352273277938366, 0.15369217871921137, 0.1786165256635286, 0.11038198397727683, 0.14265541860368103, 0.15441065188497305, 0.15848949551582336, 0.13685038400581107, 0.2804716187529266], [0.041598549869377166, 0.025141115293081384, 0.0701270553690847, 0.02788106143270852, 0.01487661827923148, 0.03378976849489845, 0.053862098648096435, 0.031414736367878504, 0.0061657652167923516, 0.05294428461638745, 0.05268303008051589, 0.05994989893224556, 0.030557014033547603, 0.018311414096388035, 0.029700417908316012, 0.058652810330386274, 0.025809025937633123, 0.047039074925123714, 0.02691272384254262, 0.06682900304440409, 0.04896482940239366, 0.0326419517659815, 0.01737992413836764, 0.09544453278067522, 0.022875685390317813, 0.04672523922636174, 0.05851729787536897, 0.06936538920854218, 0.06706036016112193, 0.01758790916937869, 0.03584020749258343, 0.0617278584104497, 0.049066232750192285, 0.01321110901699285, 0.01712333400064381, 0.016165735287358984, 0.008027910680539208, 0.025525694363750517, 0.03243582395953126, 0.030501037545036525, 0.025360555373481475, 0.0707704306114465, 0.02349526923353551, 0.012932809204357909, 0.04035017584101297, 0.025260972142859828, 0.037425104674184695, 0.044572168626473285, 0.02690742305276217, 0.03405044415558223, 0.053682435827795416, 0.03286908606241923, 0.08265516866231337, 0.05257954129774589, 0.044300824592937715, 0.05054438312072307, 0.042779562863870524, 0.029328720665944275, 0.015519434127782006, 0.03268034306529444, 0.07206763053545728, 0.02739910331001738, 0.0194812930203625, 0.046602046422776766, 0.05231668743363116, 0.006993243641773006, 0.03811986622167751, 0.01476411054682103, 0.07038512980216183, 0.04196178662823513, 0.048186835992964916, 0.0423163476807531, 0.020336319503257982, 0.040825128089636564, 0.03300154086900875, 0.04344539178418927, 0.049714005217538215, 0.008143486265907995, 0.01645575732254656, 0.03906031204678584, 0.04067977475642692, 0.041459612402832136, 0.04990865199943073, 0.022146666306070983, 0.03581581680919044, 0.06183716563100461, 0.020386605574458372, 0.04482932279643137, 0.025192919056280516, 0.0014638505763286958, 0.05211314230109565, 0.05227494904829655, 0.08607696669059806, 0.03063197094888892, 0.026938628507195972, 0.05775375779194292, 0.018364360767009202, 0.0289556374627864, 0.04324133085901849, 0.051928996908827685, 0.018384780960332137, 0.06752286659320816, 0.03957045693823602, 0.06732247187756002, 0.057212721003452316, 0.06974376578000374, 0.015634190567652695, 0.046476040879497305, 0.032926346466410905, 0.05123393850226421, 0.05253276744042523, 0.03592040768126026, 0.049333472707076, 0.037244191335048527, 0.033578638613107614, 0.028899701792397536, 0.04624298424459994, 0.045971603103680536, 0.023134719049267005, 0.08187273720977828, 0.01835865550674498, 0.04051237592648249, 0.054317788453772664, 0.05688201999873854, 0.02026335339905927, 0.015831182536203414, 0.024901397882786114, 0.022528581066580955, 0.058222412917530164, 0.02305085821717512, 0.03368606820004061, 0.03824691448244266, 0.050236506867804565, 0.03353013926243875, 0.0062228326623881, 0.026135765729122795, 0.02612467433209531, 0.05257974538835697, 0.0018485519854039012, 0.017833578604040667, 0.034539515763754025, 0.08740453529753722, 0.054555004826397635, 0.043723340932046995, 0.012410964354785392, 0.05337009555660188, 0.010729876485129353, 0.025624771078582853, 0.037065482174512, 0.054375891195377335, 0.010346028429921716, 0.02876827486034017, 0.09589976616553031, 0.03622531163273379, 0.054012854816392064, 0.06506711477413774, 0.03125761999399401, 0.014977580049162498, 0.0012875264928879915, 0.0270516724413028, 0.008504017896484584, 0.04070243252499495, 0.014766666317882482, 0.0032979890102069476, 0.024454040540149435, 0.022436970357375685, 0.036928708068444394, 0.07436989137204364, 0.006834633695689263, 0.042809137448784895, 0.041149283351842314, 0.04426569874340203, 0.027404200009186752, 0.017759818401827943, 0.0498596145916963, 0.039706403549644165, 0.07184399175457656, 0.004100932264918811, 0.01051068038577796, 0.08043175359489396, 0.024844985382515006, 0.022927676545805298, 0.09439079440198839, 0.04127519241592381, 0.02105278144881595, 0.017858674327726476, 0.0059072951262351125, 0.07005161605775356, 0.048303416260750964, 0.05054518835095223, 0.030602622719015926, 0.01003972831313149, 0.06852053571492434, 0.026310573048249353, 0.005979986171951168, 0.043339639451005496, 0.061596650411956944, 0.042873136553680524, 0.045565737382275984, 0.061342739427345805, 0.04140250413911417, 0.05859581709955819, 0.0479166534205433, 0.01143469042290235, 0.10917171923210844, 0.07651629377505742, 0.0018100014722222113, 0.07605331236845814, 0.021142881887499243, 0.06351172167342156, 0.030763611248403322, 0.02713457404752262, 0.0289999232700211, 0.08360806401469745, 0.018926929114968516, 0.016965002359938808, 0.04133234149776399, 0.04223752046527807, 0.1130644025397487, 0.022422324072977062, 0.021376452459662687, 0.0396543196256971, 0.04282123445591424, 0.09409192411112599, 0.02802915514621418, 0.05065357901912648, 0.052026760022272356, 0.05839492514496669, 0.0863419208326377, 0.026815265009645373, 0.05933322987402789, 0.06566361596924253, 0.06287828378845006, 0.08056242353632115, 0.03523291918099858, 0.051505141527741216, 0.022838193945062812, 0.06648640541243367, 0.018478499368939083, 0.053038826808915474, 0.01171553116364521, 0.035629734411486425, 0.0024268055085485685, 0.04471745516639203, 0.06210776751686353, 0.05951576851657592, 0.05693967003026046, 0.029911876190453768, 0.015076331146701705, 0.053668182881665416, 0.06265675270697102, 0.04568622505757958, 0.06981861879467033, 0.03410677316423971, 0.05579381628194824, 0.016144795590662397, 0.02531575006287312, 0.011926247298106318, 0.05328389510395937, 0.03692519028845709, 0.0663552679179702, 0.018499717371014412, 0.04685243220592383, 0.020900101262668613, 0.05178697952942457, 0.01887281541712582, 0.09010644265799783, 0.029478333926817868, 0.044979477825108916, 0.008133703831845196, 0.05650882732879836, 0.02966534400911769, 0.0730448831745889, 0.025062957865884528, 0.049099009702331387, 0.053644345098291524, 0.047525715999654494, 0.06923367283889093, 0.06840608912170865, 0.019619584818428848, 0.0677134798024781, 0.12461769743822515, 0.06821934250183403, 0.029833123189746402, 0.017106131017499138, 0.02810890076943906, 0.041044911413337104, 0.010313583588867914, 0.05297338051605038, 0.02617111607833067, 0.014779742032260401, 0.031188329376163892, 0.08421923004789278, 0.050299129288760014, 0.1392404260695912, 0.04298344567359891, 0.0073274359874631045, 0.032341485857614316, 0.026165874660364352, 0.05045306927058846, 0.021429389853437897, 0.06111947543104179, 0.025743509140738752, 0.02443965586280683, 0.030600771060562693, 0.030374356647371314, 0.017687811523501296, 0.05445282222353853, 0.1350035791983828, 0.011351935390848666, 0.0600722568196943, 0.061056418853695504, 0.007395723314402858, 0.056303163364646025, 0.04238734152750112, 0.09960915383999236, 0.05593125089944806, 0.059920906933257356, 0.06703320497763343, 0.0037238528284433414, 0.02659812929778127, 0.05901050324609969, 0.041768939554458484, 0.02441406475554686, 0.034707371014519595, 0.03271455236244947, 0.06157407427963335, 0.024770267809799407, 0.036130480002611876, 0.02738592833338771, 0.042424849671078846, 0.015071641701069893, 0.026281120917701628, 0.02229679907031823, 0.005986591750115622, 0.03773438358621206, 0.02621827028633561, 0.03635808556282427, 0.06044615824066568, 0.033413135970477015, 0.049279210579697974, 0.044075152327422984, 0.047900170320644975, 0.08728640765184537, 0.05398077177233063, 0.00460474802821409, 0.09613633315893821, 0.023192623266368173, 0.01387873857311206, 0.035639419438666664, 0.0760930024262052, 0.020131388409936335, 0.21889081690460443, 0.10533469700021669, 0.21520511858398095, 0.21921522449702024, 0.09235089019057341, 0.11734001178410836, 0.18795326293911785, 0.20952268678229302, 0.12764012353727594, 0.13510198798030615, 0.11800030057202093, 0.23076746554579586, 0.16535139293409884, 0.11044571961974725, 0.07711987505899742, 0.10904827038757503, 0.1208336793933995, 0.24596924748038873, 0.113975596614182, 0.18421815242618322, 0.135544263466727, 0.18739130871836096, 0.12697766767814755, 0.1570147738675587, 0.12144868975155987, 0.138087484810967, 0.18225735373562202, 0.24671207793289796, 0.14570448780432343, 0.18750824150629342, 0.1402530717314221, 0.15281613275874406, 0.0833534702542238, 0.1277654425939545, 0.12326878466410562, 0.1055749598890543, 0.15356819552835077, 0.21346767665818334, 0.1246493574581109, 0.089911821851274, 0.11569995447644033, 0.11097458147560246, 0.11413449043175206, 0.10766789797344245, 0.1270487654255703, 0.17701256641885266, 0.15283419663319364, 0.27283465198706836, 0.10282277202350087, 0.137891439080704, 0.169880171015393, 0.18593690707348287, 0.18629000609507784, 0.1650059677194804, 0.12297725421376526, 0.13608059874968603, 0.09901706842356361, 0.1053144215256907, 0.08219084396841936, 0.14808226958848536, 0.13064988859696314, 0.18431000062264502, 0.12736011121887714, 0.16859221825143322, 0.1761292919400148, 0.10916726634604856, 0.11911933310329914, 0.18175187695305794, 0.24117360793752596, 0.10240424526273273, 0.1825216325232759, 0.15060163830639794, 0.09188615731545724, 0.1368973619537428, 0.1227168865443673, 0.07502689244574867, 0.11994644926744513, 0.10685382134397514, 0.16311135375872254, 0.17706929618725553, 0.13198179134633392, 0.17159879207611084, 0.1702910239691846, 0.12484003003919497, 0.11164195777382702, 0.11055006558308378, 0.07380907263723202, 0.15223186957882717, 0.10956932484987192, 0.07262510218424723, 0.16998758947011083, 0.13101557444315404, 0.2184694551397115, 0.07071013111271895, 0.24653468979522586, 0.17104503116570413, 0.16130618343595415, 0.09039286713232286, 0.15057217504363507, 0.15628353576175869, 0.11123413278255612, 0.09128095814958215, 0.18806278909323737, 0.15292929543647915, 0.13654827052960172, 0.2492486051050946, 0.15695750975282863, 0.09686750447144732, 0.11983007309027016, 0.08302671005367301, 0.12203567661345005, 0.1079089475388173, 0.14791672612773255, 0.14531328692100942, 0.08879111948772334, 0.11637124189292081, 0.1519837844534777, 0.11690440820530057, 0.2496875706128776, 0.1793225752771832, 0.17755504668457434, 0.16212768154218793, 0.11405925892177038, 0.16444439941551536, 0.12861186201917008, 0.11069784944993444, 0.22672869788948447, 0.15615260606864467, 0.12315050858887844, 0.11648488696664572, 0.12638532993150875, 0.1426181776332669, 0.20455929217860103, 0.11577456258237362, 0.09776594102731906, 0.15574662160361186, 0.07371890911599621, 0.08872566948411986, 0.09428127566934563, 0.14416770776733756, 0.18791048554703593, 0.18011858803220093, 0.11892873473698273, 0.09835442702751607, 0.098652072774712, 0.24319604941410944, 0.06280357178184204, 0.1316585563472472, 0.1086055273481179, 0.07669440921745263, 0.10810726424097084, 0.08818596485070884, 0.20820614648982882, 0.12218858129926957, 0.15123566990951076, 0.12108309296309017, 0.14285820303484797, 0.07412381746689789, 0.09531674979371019, 0.09097931222640909, 0.10016447326052003, 0.1556199518381618, 0.1081220107153058, 0.12211448527523316, 0.15187776123639196, 0.16344953561201692, 0.1422524027293548, 0.2210539992665872, 0.18209822243079543, 0.10010968791902997, 0.2065692507312633, 0.1381267889519222, 0.11540739986230619, 0.09945836427505128, 0.22849843808216974, 0.09896640942315571], [0.051815088372677565, 0.07131058053346351, 0.008691258972248761, 0.02269679996970808, 0.0341598255909048, 0.04842043810640462, 0.009498873350821668, 0.08649846204207279, 0.05023369783884846, 0.01871381955425022, 0.02821614110871451, 0.043488054143381305, 0.08004353614524007, 0.05228158755926415, 0.07028980835457332, 0.02810247562592849, 0.033206262305611745, 0.08171746507287025, 0.04346039429947268, 0.024872697176760994, 0.051278678874950856, 0.09921313641825691, 0.039106406838982366, 0.060775252495659515, 0.05931396743108053, 0.030490218887280207, 0.04478520953853149, 0.0856153731001541, 0.049919082885026, 0.01607993744983105, 0.0428466938319616, 0.032759697205619887, 0.08726673331693746, 0.00785089918281301, 0.03552666494215373, 0.026819591730600223, 0.054770851056673564, 0.020199153914290946, 0.04922646243358031, 0.06487403763458133, 0.10441578458994627, 0.03452897355600726, 0.01319368895565276, 0.035746592984651215, 0.01589637278812006, 0.05121233087265864, 0.02466876798280282, 0.060643291217274964, 0.029734102135989815, 0.032967784281936474, 0.024194787947635632, 0.09252395902876742, 0.041091455204878, 0.025627158938732464, 0.05060288662207313, 0.11001102146110497, 0.03731170450919308, 0.029828182341589127, 0.009824485077842837, 0.0021276634060996003, 0.05786086454463657, 0.001650995868658356, 0.03806284330494236, 0.053466563622350805, 0.02818659249896882, 0.039359100701403804, 0.03789895483350847, 0.02024229495873442, 0.07896832001279108, 0.06489952298579738, 0.016855374160513747, 0.013314767566043884, 0.06527384000946768, 0.025632404067437164, 0.01629680598853156, 0.004480656298255781, 0.019215990068914834, 0.008350897987838835, 0.03403241738851648, 0.03349560713104438, 0.034129798295907676, 0.1198508903326001, 0.021373224117269274, 0.006446796132877353, 0.04180868898401968, 0.04476806221646257, 0.0024516475104974234, 0.04121400976146106, 0.018709465002757497, 0.029023692404734902, 0.046146527311066166, 0.03238288285501767, 0.0353952083241893, 0.00848056974064093, 0.025547778823238332, 0.052742387051694095, 0.0920413552375976, 0.02290488704602467, 0.02810776528349379, 0.02093860945024062, 0.03772978227061685, 0.022751234646420926, 0.05199443949095439, 0.018553818081272766, 0.07842581006116234, 0.059606332797557116, 0.06201688782311976, 0.04890667099971324, 0.008663087974127848, 0.04473404958844185, 0.0358871334901778, 0.04503191426920239, 0.043194631216465496, 0.0807834425359033, 0.008906866787583567, 0.019101576872344594, 0.08560631889849901, 0.013329330358828884, 0.06237181994947605, 0.06733539266861044, 0.03000295069796266, 0.04912078060442582, 0.046597786495112814, 0.042319776403019205, 0.017620129510760307, 0.06573576014488935, 0.04870026859862264, 0.01678258802712662, 0.027386644505895674, 0.01665470113948686, 0.1051995370653458, 0.030902400285413023, 0.093104927073, 0.02474808872648282, 0.06234639397007413, 0.03569915861589834, 0.012039590874337591, 0.03637587113189511, 0.03505641048832331, 0.037273487614584155, 0.033896815875777975, 0.054183363245101646, 0.024731947014515754, 0.022210144052223768, 0.06065103181754239, 0.028368301791488193, 0.07145682073314674, 0.0499382265843451, 0.03689137432957068, 0.031467157969018444, 0.08296558677102439, 0.016068144723249134, 0.027941670778091066, 0.019010313117178157, 0.036332681847852655, 0.0354005851841066, 0.017454209410061594, 0.027371654978196602, 0.014253955450840294, 0.03765435409150086, 0.04588131712807808, 0.03318610557471402, 0.031159853169810958, 0.023400702921207994, 0.051047934030066244, 0.03361347131431103, 0.03304786943772342, 0.032879891732591204, 0.028615206902031787, 0.07345907579292543, 0.02138088679203065, 0.05367206431401428, 0.043671104867826216, 0.020699428241641726, 0.012289392216189299, 0.09259900500182994, 0.1457252976251766, 0.0627752736909315, 0.01302111086260993, 0.014687175807921449, 0.05261279693513643, 0.02893733610108029, 0.043679687805706635, 0.021407023377832957, 0.08945163834141567, 0.03165567461110186, 0.02465802725055255, 0.03953753526729997, 0.013325435011211084, 0.057599131323513575, 0.06766274658730254, 0.0058667386110755615, 0.03580908552976325, 0.00556025156583928, 0.06465485916123725, 0.034978028561454266, 0.07863369304686785, 0.11243041546549648, 0.024131723948812578, 0.08644295681733638, 0.024580639801570214, 0.006378433199643041, 0.052274002810008824, 0.03291035689471755, 0.02862636694771936, 0.007628368521181983, 0.07033956193481572, 0.05472683427797165, 0.052000684663653374, 0.03268744170782156, 0.04537647488177754, 0.012097935741621768, 0.05858258831722196, 0.030556670790247153, 0.04752464730700012, 0.02807065233355388, 0.02295205238624476, 0.03309379353595432, 0.048985453686327673, 0.009862195456662448, 0.01761466915922938, 0.03180270148732234, 0.03856372248264961, 0.03442845707468223, 0.05633588836644776, 0.030221980741771404, 0.03200803890649695, 0.033937244370463304, 0.06022860135999508, 0.0151364423254563, 0.02488157326297369, 0.12277255504159257, 0.023229817852552515, 0.057100682679447345, 0.041393179053557105, 0.03898582268448081, 0.04663935047574341, 0.059868002936127596, 0.025356219375680666, 0.0469374266685918, 0.07107350145815872, 0.059923155640717596, 0.007044878102533403, 0.04479213006561622, 0.019487849895085674, 0.06858137698145583, 0.043424270261311904, 0.0023948750686031417, 0.005241909175310866, 0.01309896864768234, 0.028773503290722147, 0.08055791127844714, 0.04267213327693753, 0.026002902741311118, 0.006091966979511199, 0.011428095513110748, 0.03730937416548841, 0.033617679291637614, 0.01603417291335063, 0.05439860833575949, 0.037759991391794756, 0.05725170602090657, 0.03172402641212102, 0.04076381927006878, 0.05067288228019606, 0.03586912527680397, 0.06316017374047078, 0.04863464790105354, 0.01188279084090027, 0.0470353604760021, 0.04285356611944735, 0.06779735733289272, 0.04469308303669095, 0.007621163194926339, 0.042016301085823216, 0.005056899644841906, 0.13127915561199188, 0.012767588577844435, 0.03231812304875348, 0.021978916811349336, 0.008387537818634883, 0.01564614285598509, 0.06351417818223126, 0.03271115703682881, 0.03880122458213009, 0.06984058636589907, 0.010630265423969831, 0.03837798889435362, 0.026472854769963305, 0.049779748369473964, 0.027024231530958787, 0.0513571053306805, 0.053136567657929845, 0.012635867569770198, 0.032903933606576174, 0.0403534450015286, 0.011578352587093832, 0.01613831664144527, 0.03689909637614619, 0.09341336364741437, 0.029049389268038794, 0.03146710601868108, 0.037571719658444636, 0.021814158171764575, 0.03541643003700301, 0.0171534132459783, 0.06929159004357643, 0.01366520969895646, 0.029873533130739816, 0.0668929168023169, 0.01075035141184344, 0.03866160805046093, 0.05675728723872453, 0.07185327602201141, 0.02121058430930134, 0.04059238686750177, 0.06542766495840624, 0.04242907991283573, 0.017526932460896205, 0.02764658729574876, 0.018995600039488636, 0.02469190258125309, 0.03839462042378727, 0.0060770994423364755, 0.04796638844709378, 0.036002674751216546, 0.04258244101947639, 0.04861710352997761, 0.036172366817481816, 0.02898636052123038, 0.025481601514911745, 0.02356587901886087, 0.020115161350986455, 0.01777790082996944, 0.02458463812217815, 0.027221357086091302, 0.04292349498427939, 0.05300985707435757, 0.049091595647041686, 0.05280609671899583, 0.04715267918072641, 0.019122702105960343, 0.012625829094758956, 0.015780727626406588, 0.0029073196901663323, 0.031474527495447546, 0.01804947678465396, 0.03775915647565853, 0.017731123261910398, 0.021181377087486908, 0.030352533794939518, 0.08747164771193638, 0.20728292962303385, 0.16772488510468975, 0.15094120055437088, 0.07792515723849647, 0.14688917814055458, 0.1220165885752067, 0.16423591529019177, 0.3111727541545406, 0.1508659022510983, 0.128106607880909, 0.20918634545523673, 0.06306944618700072, 0.1364562739036046, 0.0966711544606369, 0.18275046633789316, 0.162362749397289, 0.1335196994477883, 0.18879938550526276, 0.17407383973477408, 0.06279735258431174, 0.29593195009510964, 0.21449528401717544, 0.14237122057238594, 0.24141437548678368, 0.1375737998750992, 0.1517435660935007, 0.11478783271741122, 0.2146913149044849, 0.12106815353035927, 0.14453180541750044, 0.18746096669929102, 0.2405927883228287, 0.21227783581707627, 0.11644793543382548, 0.13911014946643263, 0.09189775708364323, 0.2547461382346228, 0.13400795840425417, 0.1750917249592021, 0.15751946397358552, 0.1621287502348423, 0.13081074168439955, 0.13039709825534374, 0.12812250468414277, 0.11554818527656607, 0.11049020395148546, 0.0930577190592885, 0.14134962460957468, 0.13090098684187979, 0.10418415287858807, 0.1397225697292015, 0.1796792514505796, 0.1078420651901979, 0.12248882456333376, 0.11739325345843099, 0.1875554717844352, 0.20609653234714642, 0.11828820192022249, 0.11697186942910776, 0.20759543316671625, 0.19957535492721945, 0.1154886872973293, 0.13108444574754685, 0.26792908553034067, 0.14846434205537662, 0.14017750625498593, 0.0938013287668582, 0.12708348309388384, 0.17912926065037027, 0.29300082300323993, 0.08387225374463014, 0.11819846142316237, 0.06696420750813559, 0.0694923558330629, 0.22611586202401668, 0.11658361487207003, 0.11429755511926487, 0.10078208113554865, 0.09787494767806493, 0.09042431192938238, 0.17977081763092428, 0.23626433074241504, 0.18687720817979425, 0.16647659271256998, 0.19094855611911044, 0.14336940919747576, 0.09358327835798264, 0.12011842714855447, 0.19175256922608241, 0.1069568314414937, 0.1805093584698625, 0.10901880712481216, 0.07796955251251347, 0.12946412956807762, 0.1458416218520142, 0.12583283067215234, 0.2043017075629905, 0.0822497927583754, 0.4039016127353534, 0.09829955262830481, 0.2812810643808916, 0.1360604420187883, 0.09229041257640347, 0.10097775579197332, 0.17007587535772473, 0.11881279642693698, 0.19329332717461511, 0.20271029061404988, 0.08302322195959277, 0.13503333932021633, 0.06428297638194636, 0.17618821846554056, 0.10937244049273431, 0.21288675314281136, 0.05842025835590903, 0.1304286246886477, 0.12785735016223043, 0.1058352310792543, 0.24659247341332957, 0.1297112795873545, 0.11881443657330237, 0.17849031602963805, 0.21281106892274693, 0.14136877201963216, 0.09378903880133294, 0.12398134291288443, 0.16929331031860784, 0.10505340818781406, 0.10141753024072386, 0.07432856116793118, 0.187556050659623, 0.10591357960947789, 0.16364978189812973, 0.15497882530326024, 0.19962169462814927, 0.12816041358746588, 0.11375120826414786, 0.16923666960792616, 0.09257052137400024, 0.13152562285540625, 0.15838221064768732, 0.16085528419353068, 0.08537074638297781, 0.10899583765421994, 0.1667557144537568, 0.12577081681229174, 0.14921110589057207, 0.08751038039918058, 0.22211567120393738, 0.13489905511960387, 0.19047647598199546, 0.08485097583616152, 0.08370316281798296, 0.13675871392479166, 0.07612638422870077, 0.14617646404076368, 0.20265072584152222, 0.12827249272959307, 0.13168393779778853, 0.1524796281591989, 0.1312734856037423, 0.1317252012086101, 0.13702398719033226, 0.15627955785021186, 0.18621320865349844, 0.10070502394228242, 0.11867138018715195, 0.14777105738176033, 0.09132497492828406, 0.16439945495221764, 0.06269449833780527, 0.11218368847039528, 0.1014223022502847, 0.22418932087020949, 0.1255514973308891, 0.252637934172526], [0.048030272519099526, 0.006449206721299561, 0.0324611794349039, 0.021636046440107748, 0.06777360860724002, 0.017649410947342403, 0.04868003394221887, 0.06843729643151164, 0.062020015975576825, 0.029607295073219575, 0.03533609997248277, 0.016497684955538716, 0.024307700150529854, 0.032021022780099884, 0.041145082795992494, 0.02207528468716191, 0.0370630701945629, 0.03585438251320738, 0.07092553947586566, 0.05678890272974968, 0.041048514540307224, 0.0420781628054101, 0.053165496574365534, 0.019979611788585316, 0.005548435183300171, 0.007997390785021707, 0.06861348228994757, 0.06274596627918072, 0.00821985140646575, 0.022142183734104037, 0.03235460702853743, 0.06172602159495, 0.09639247058657929, 0.01959184890438337, 0.02957898028398631, 0.013380778818827821, 0.038964589839451946, 0.06089186616009101, 0.03604057252232451, 0.020145639500697143, 0.03766191286558751, 0.05817818091600202, 0.03860983582853805, 0.013347430412977701, 0.041332656910526566, 0.0637855964305345, 0.028377905182424, 0.13601350859971717, 0.026965290162479505, 0.039323711389442906, 0.0430544914706843, 0.036916314202244394, 0.05556703079491854, 0.057841613233904354, 0.02920627001003595, 0.0466008664079709, 0.06337058002827689, 0.04898137929558288, 0.03483984066406265, 0.03037343452888308, 0.08609234399045818, 0.02629301012348151, 0.03930007398594171, 0.04167677223449573, 0.03857407544273883, 0.06310683558695018, 0.06572320300620049, 0.09936639733496122, 0.033160579405375756, 0.0293593453898211, 0.07091325693181716, 0.01997452251089271, 0.03796556258748751, 0.041828808607533574, 0.03353658481501043, 0.020294529167586006, 0.027542449133761693, 0.04073099036759231, 0.03931649400328752, 0.06875797844259068, 0.01887723305117106, 0.044031725556124, 0.0592591524036834, 0.05331225627742242, 0.013909129520470742, 0.027894503582501784, 0.048456183649250306, 0.07519643608247861, 0.032461049559060484, 0.06979455094551668, 0.04902763364952989, 0.05062546275439672, 0.0945851331925951, 0.08652161704958417, 0.08480186050292104, 0.018496782176953275, 0.014830119944235776, 0.023627868758921977, 0.01670469035161659, 0.012985453449800843, 0.015190358426480088, 0.07337359522352926, 0.009879811259452254, 0.039835392526583746, 0.07888557796832174, 0.03228139416023623, 0.12137191457441077, 0.025672433657746296, 0.016744595632189885, 0.045210129901533946, 0.03275074690463953, 0.015699026444053743, 0.06335344383842312, 0.020776656128873583, 0.01676000076258788, 0.013299341098900186, 0.021494721113413107, 0.060946529047214426, 0.04778381269716192, 0.006313769408734515, 0.05291799774568062, 0.03954312363930512, 0.04202289506793022, 0.05790522642200813, 0.06895771264680661, 0.025525291748635937, 0.01064155070707784, 0.03199970829882659, 0.04928997172100935, 0.032363909849664196, 0.008931598858907819, 0.023426685511367396, 0.020728676281578373, 0.06272085942327976, 0.1353232518886216, 0.04459460003999993, 0.0950634473701939, 0.05680153779394459, 0.005730139373554266, 0.0246421694100718, 0.009441148176847491, 0.013560621609940426, 0.030066523067944217, 0.02507142020476749, 0.04540048335911706, 0.06850605641375296, 0.04292368423193693, 0.02332843629119452, 0.14319588022772223, 0.033174464988405816, 0.09161165173281915, 0.048219060045084916, 0.06941598141565919, 0.03292512192274444, 0.030949409774621017, 0.05669106911227573, 0.0433171746408334, 0.034573357697809115, 0.06830445941886865, 0.023966297376318835, 0.019542566587915644, 0.06109090645622928, 0.053765426491736434, 0.05716745741665363, 0.04554937673674431, 0.00940386267757276, 0.025819185939326417, 0.059652739291777834, 0.04216668246954214, 0.036625759676098824, 0.08180961754987948, 0.02778701647912385, 0.045342180237639695, 0.0280231752913096, 0.06340100066154264, 0.03575726877897978, 0.03731821314431727, 0.019297368417028338, 0.028106635363656096, 0.01852645324106561, 0.03216746335965581, 0.03251700378314126, 0.03801383187237661, 0.0541287745727459, 0.035598530812421814, 0.04105260748474393, 0.01705196722468827, 0.02314672699867515, 0.028898657219542656, 0.03369678852322977, 0.028380575058690738, 0.025131255861197133, 0.04858671258261893, 0.01337229792625294, 0.09388292048242874, 0.014467024193436373, 0.05761852364230435, 0.03643124277004972, 0.04021311229735147, 0.032850079660420306, 0.016495998424943537, 0.009025084418681217, 0.06020619592163712, 0.028176577216072474, 0.028343725571176037, 0.04034779725770932, 0.052808671971433796, 0.037393192324088886, 0.0574271831283113, 0.03858995369228069, 0.062034005459281616, 0.02521230766433291, 0.06136353069450706, 0.017218731518369168, 0.09719480643980205, 0.02997039267938817, 0.054704098583897576, 0.02765333527349867, 0.018989095115102828, 0.01790098045603372, 0.013308413854247192, 0.13610022113425657, 0.007920473672129447, 0.11817440099548548, 0.028734898623952176, 0.0630565699248109, 0.0387220337142935, 0.060960563059779815, 0.03471587973763235, 0.054383924943977036, 0.02808184020977933, 0.024609813626739196, 0.04043507011374459, 0.048721341881901026, 0.060620147341978736, 0.03359171896590851, 0.062233739663497545, 0.01829474731493974, 0.027591352954914328, 0.011904827988473698, 0.04432748624822125, 0.03547662192431744, 0.01655440173635725, 0.05369808030081913, 0.014992354354035342, 0.07776640442898497, 0.015500052941206377, 0.06606614944757894, 0.02028494989644969, 0.04891274918918498, 0.03443284316745121, 0.06160026096040383, 0.01795656731701456, 0.04772832973685581, 0.03165742236888036, 0.020173941302346066, 0.011082282526331255, 0.03064116430323338, 0.03256217831221875, 0.023977739438123535, 0.018377825181232765, 0.016542438315809704, 0.08950300980359316, 0.03280786630057264, 0.05234190190094523, 0.05765444730059244, 0.00587076476222137, 0.06512717678560875, 0.07563765771919861, 0.034931815025629476, 0.02510057918698294, 0.008968637594080064, 0.021559174783760682, 0.0399455977458274, 0.08283159200800583, 0.042892762648989446, 0.03058394471736392, 0.06758824238204397, 0.047899632263579406, 0.04978588222002145, 0.023569469158246648, 0.04630047100363299, 0.06115821553976275, 0.032920802623266354, 0.010249169808957959, 0.06860464331111871, 0.11473702528746799, 0.004116686204724829, 0.03162312030326575, 0.07666220742976293, 0.016004234676074702, 0.022772966585762333, 0.02973644917801721, 0.029727964574703947, 0.03627420432167128, 0.007638290107934154, 0.0729161873459816, 0.03467184069450013, 0.03541098638379481, 0.1033249388274271, 0.06487026752438396, 0.024971747916424647, 0.00988319823591155, 0.06604341746424325, 0.059374259508331306, 0.05411717851529829, 0.024966051933006383, 0.06307711257250048, 0.0029947653274575714, 0.03358108027896378, 0.02864447349566035, 0.053271764700184576, 0.09390407169121318, 0.03955195519665722, 0.025678786441858392, 0.05071251667686738, 0.029434827374643646, 0.02272838948556455, 0.05020556302042678, 0.08940782936406322, 0.03699893379234709, 0.016398053485318087, 0.02744196233834373, 0.03600873067625798, 0.026768207280838396, 0.07446029980201274, 0.06601001339731738, 0.02223362746008206, 0.021907845039095264, 0.02467046564561315, 0.052392089637578465, 0.05436063263914548, 0.03437300751102157, 0.05045129553764127, 0.06080634848331101, 0.02279657059261808, 0.014246691680455115, 0.010703130410547601, 0.05065877405286301, 0.008691528928466141, 0.023414282368321437, 0.050741163577185944, 0.05933640255534556, 0.11658679868560284, 0.03431339449889492, 0.04176688009465579, 0.05351182720914949, 0.041160359905916266, 0.028985403150727507, 0.02047975067398511, 0.047166238218778744, 0.0697971113550011, 0.09986287928768434, 0.0833245636022184, 0.12461416481528431, 0.16650731762638316, 0.16537434014026076, 0.10979886370478198, 0.10276818706188351, 0.17232152516953647, 0.15818132611457258, 0.08727735345019028, 0.08474487840430811, 0.16034808562835678, 0.09631449313019402, 0.09750954384799115, 0.07532527291914448, 0.18175120902014896, 0.15986537793651223, 0.1747349597280845, 0.2605009591206908, 0.18702289176872, 0.17674393864581361, 0.15070596942678094, 0.10574514919426292, 0.14787770400289446, 0.16650727309752256, 0.13733098399825394, 0.2331981179304421, 0.118048443691805, 0.11563082342036068, 0.10493083507753909, 0.1618816002155654, 0.19884626904968172, 0.205430232163053, 0.23852682730648667, 0.10291831611539237, 0.06817005647462793, 0.09181005749269389, 0.12112734722904861, 0.14151905692415312, 0.13878817611839622, 0.19649668887723237, 0.11253692107857205, 0.14836237096460536, 0.13606721040559933, 0.13957430346636102, 0.1655422881594859, 0.1608268154086545, 0.21850390563486144, 0.09129237980232574, 0.12712743307929486, 0.17000121530145407, 0.10410568560473621, 0.10489358668564819, 0.1325999409891665, 0.15255347185302526, 0.11199939835933037, 0.10632206511218101, 0.14597697474528104, 0.18626067641889676, 0.1018882893549744, 0.15369330678367987, 0.1471895253052935, 0.11379250878235325, 0.07121051676222123, 0.125976896379143, 0.14099740132223815, 0.15516734565608203, 0.2613869053311646, 0.11005383596057072, 0.16552873654291034, 0.16728977876482531, 0.10831359613803215, 0.09371133593958803, 0.1928657610551454, 0.09904162609018385, 0.15161824703682214, 0.06893167810630985, 0.21477976406458765, 0.08801721531199291, 0.16409996867878363, 0.08060085194301791, 0.13648156629642472, 0.2187199002946727, 0.0975525809917599, 0.16557014838326722, 0.13515598664525896, 0.09756079656654038, 0.11217092353035696, 0.10067737151985057, 0.19278767227660865, 0.14031299273483455, 0.1616029386059381, 0.13488588941982016, 0.18811166693922132, 0.19085623294813558, 0.14550628984579816, 0.15371135581517592, 0.17359082034090534, 0.11418079302529804, 0.12941964523633942, 0.1078595279250294, 0.12995271506952122, 0.12341895082499832, 0.1725685119163245, 0.20073637075256556, 0.12394943798426539, 0.1627763334545307, 0.058480112566030584, 0.0915615790290758, 0.19127088569803163, 0.2571754844393581, 0.11767947755288333, 0.11641075383522548, 0.1575734477955848, 0.15608964225975797, 0.16396302758948877, 0.1552986167371273, 0.15350964007666335, 0.1179222266364377, 0.0962196837645024, 0.18595250701764598, 0.12627041578525677, 0.1832312296028249, 0.15986934100510553, 0.0996224457048811, 0.1305225508986041, 0.14626335469074547, 0.17761415132554248, 0.12800548283848912, 0.1424746314296499, 0.10964784407406114, 0.11182074114913121, 0.12986672983970493, 0.144971928675659, 0.2981933334376663, 0.1415086816996336, 0.30691998079419136, 0.14840597956208512, 0.11485601382446475, 0.12650621094508097, 0.07708175093284808, 0.12635144346859306, 0.11096725647803396, 0.16888625716092065, 0.20492016890784726, 0.23064253240590915, 0.12509645690442994, 0.07851195856346749, 0.1848835323471576, 0.09788395735085942, 0.27363106550183147, 0.1112969036330469, 0.12407474961946718, 0.09148334924248047, 0.10522241005674005, 0.22437010804424062, 0.17132269829744473, 0.14414841192774475, 0.16552057291846722, 0.1541512119001709, 0.1231854414800182, 0.12992316274903715, 0.1925293158274144, 0.10020875721238554, 0.12380672298604622, 0.10299755522282794, 0.27397090976592153, 0.14452594245085493, 0.12069143194821663, 0.17460716189816594, 0.14406646398128942, 0.11230892589082941, 0.12123231659643352, 0.08161630292306654, 0.1571480042184703, 0.10747836829978041], [0.06644312335993163, 0.016451541923743207, 0.057810628568404354, 0.042624791676644236, 0.03748065071704332, 0.027127536632178817, 0.011834996530524222, 0.012577800080180168, 0.07183415087638423, 0.06271904858294874, 0.022136790175864007, 0.027971069102932233, 0.02505087755707791, 0.07381214512861334, 0.05233152667642571, 0.008084885357675375, 0.01918675687193172, 0.011188333573954878, 0.08590890734922141, 0.07182935660239309, 0.019702976242115255, 0.07844083113013767, 0.0813349918462336, 0.003857595029330696, 0.07774949830491096, 0.04702559752331581, 0.055404693412128836, 0.026536284276517108, 0.047285976324928924, 0.041819331381702796, 0.03439955042267684, 0.05434625352791045, 0.05980865338642616, 0.05126352793013211, 0.02525815198168857, 0.0026622727318681427, 0.04357714897196274, 0.039592220418853685, 0.02580959553597495, 0.043408618366811424, 0.0522878624178702, 0.037503278799704276, 0.024157263105735183, 0.011874103074660525, 0.027138082550663967, 0.03430688586377073, 0.0557771587773459, 0.006194160250743153, 0.03419255430344492, 0.0424960810050834, 0.019122891353617888, 0.04550189412839245, 0.05632739819702692, 0.06795953144319355, 0.04196904854325112, 0.010073318844661117, 0.0181230124871945, 0.015386293762276182, 0.01494390138759627, 0.040937374214990996, 0.03336930101795588, 0.02710206241317792, 0.033910656929947436, 0.0434546574979322, 0.0076583345889957855, 0.004616053720383206, 0.04982660757377744, 0.028182490277686156, 0.03729978561750613, 0.05808688933029771, 0.026423242197779473, 0.02740986816206714, 0.03332841610244941, 0.052579775074264035, 0.0480633871484315, 0.030555468511010986, 0.02059373899101047, 0.042416838186909445, 0.05540837817534339, 0.0140949141314195, 0.018546211067587137, 0.04960838647093624, 0.018932931234303396, 0.05644388198561501, 0.04187305174127687, 0.0402735490933992, 0.0583276420366019, 0.07322791163460352, 0.010184782004216686, 0.057779747803579085, 0.033572155953152105, 0.0890290000825189, 0.04233709070831537, 0.013530489486583974, 0.02590378891909495, 0.027601858055277262, 0.03627697253250517, 0.023186597027233802, 0.024443941765639465, 0.053578075021505356, 0.05959822483418975, 0.048839977898751386, 0.020206059598422144, 0.039227866727742366, 0.06079655955545604, 0.03913774031389039, 0.0022726380120730028, 0.018876494614232797, 0.042596927742124535, 0.026857485790969804, 0.01642080031160731, 0.022317924303933978, 0.041731620658538304, 0.0344636311638169, 0.05753537712735124, 0.02040721501543885, 0.04627827336662449, 0.03080052752920892, 0.022415359017031733, 0.004662430528696859, 0.0688848782738205, 0.009274613948946353, 0.06823248593718745, 0.012273462943994673, 0.053695252718171105, 0.03064287124288967, 0.04400559082569089, 0.038407359388656914, 0.0706005010579247, 0.08390576171223074, 0.029662564666068647, 0.049823542503872886, 0.03414416998566594, 0.05850452922459226, 0.02572086621512426, 0.010136172259080922, 0.015961258759489283, 0.018194564800069202, 0.04849627075600438, 0.06264912342885509, 0.0397911827894859, 0.04420397061039694, 0.00674023714964278, 0.047203545982483774, 0.031241233373293653, 0.02252120782941347, 0.012882001774414675, 0.08196333117666654, 0.019567667877709027, 0.08618346488219686, 0.07146690652007237, 0.042785255136550404, 0.07004812054219656, 0.039755244288244285, 0.05039656214648858, 0.0846360795549117, 0.031017989786050748, 0.027022201757063158, 0.03346123827213887, 0.06880784334498458, 0.03307192986540031, 0.030296126860775985, 0.04365630644315388, 0.010066038375953212, 0.06383879357599653, 0.03246950262109749, 0.05463325316668488, 0.08939784005633555, 0.022111336365924217, 0.01359575302558369, 0.015864601446082816, 0.004692156790042645, 0.052171549323247746, 0.05184563146030996, 0.051032211631536484, 0.0925422010186594, 0.03935181281121913, 0.04496680565353017, 0.02277447685628431, 0.04162553064816166, 0.039274135924642906, 0.03355586952238809, 0.020036909299960826, 0.028891666188428644, 0.028387614329403732, 0.07440472036250867, 0.02344004788028542, 0.043335576192475855, 0.045255950099090114, 0.009112762672884855, 0.1115221602958627, 0.013597297620435711, 0.06143225356936455, 0.015201545375020942, 0.03326187885249965, 0.08378514045034535, 0.043005958723369986, 0.09133451894740574, 0.0035247874848209904, 0.018026657598966267, 0.10977409081533551, 0.0434262629278237, 0.048100008425535634, 0.029274530897964723, 0.0658952328376472, 0.03509575173666235, 0.059049885312560946, 0.053811536126886494, 0.05988422628433909, 0.04027233568194788, 0.029473994218278676, 0.029478077885869425, 0.008980374659586232, 0.04184135832474567, 0.04868653886660468, 0.045618262884090655, 0.03572434339730535, 0.0487836711545242, 0.0427166027657222, 0.04724073129182216, 0.048323558148695156, 0.02046341043751454, 0.004184853860351723, 0.006753575862603611, 0.0472044031630503, 0.015037808116176166, 0.05339132098015398, 0.015324347623391077, 0.013796240509691415, 0.0902057123312261, 0.042576637424645014, 0.026499098967178725, 0.017234383412869647, 0.05388770645367913, 0.02352371760935057, 0.03108110759058036, 0.033793178663472645, 0.10424103849800304, 0.053671567075070925, 0.01577226157678524, 0.012330388453847263, 0.045940009877085686, 0.07446033690939657, 0.03378696688741911, 0.02830354012985481, 0.024072862361208536, 0.012845035398640903, 0.05916403133596759, 0.013744235438934993, 0.05694123596185818, 0.0433964285912225, 0.008372802476515062, 0.0345243611081969, 0.10699449543608353, 0.010482253346708603, 0.010780873162730131, 0.011309934470773442, 0.08990923917735927, 0.04080136081029195, 0.022632561522186734, 0.046928621086408384, 0.034480611502658576, 0.04253429047821555, 0.026966254954459146, 0.043108308309456334, 0.034774216255755164, 0.0341151631437242, 0.020411968471307773, 0.03400854991923552, 0.012351020159258042, 0.05245425934845116, 0.02312702483322937, 0.040245143391075544, 0.027031640020140912, 0.00717389676538005, 0.01488620126110618, 0.0794362292799633, 0.017355691161355935, 0.07433294726070017, 0.039484634980908595, 0.05493716635101009, 0.006589438771698042, 0.05625932841212489, 0.024387449484493118, 0.03874578986142296, 0.04656882789277006, 0.01853337191278115, 0.06189897540025413, 0.011808497220044956, 0.041558143639122136, 0.0409285649220692, 0.04289165313821286, 0.0021918944321441813, 0.025978504636441357, 0.0019762564670600113, 0.02970760004245676, 0.04590836841089185, 0.04610668882378377, 0.014122770644462435, 0.03382781469554175, 0.040841425652615726, 0.006762568837075378, 0.04534446976322215, 0.09198211701004766, 0.06354930403176695, 0.02420325399725698, 0.07229750335682184, 0.03975882886152249, 0.08074567464063875, 0.00986441262284643, 0.06617658844334073, 0.01667822722083656, 0.04791665713128168, 0.036953703602193855, 0.04222406161716208, 0.05344640689145308, 0.06883421185193583, 0.05722800182411447, 0.009424894215044333, 0.0704107190540526, 0.053178042580839247, 0.02950376547232736, 0.07793459735694341, 0.09093726213905029, 0.021886098256800324, 0.01841553927079076, 0.037135685633984394, 0.03977698179369327, 0.027500517790031154, 0.04730913875391707, 0.0208388648024993, 0.05358250564313494, 0.06643816581345163, 0.030293130439531524, 0.03323385906696785, 0.017599473685550038, 0.1051695691421628, 0.025389840520801954, 0.008328285675816005, 0.02955745985673275, 0.03403929709747899, 0.01749869559716899, 0.05714162325602956, 0.11322808320983313, 0.039952867082320154, 0.047410809274879284, 0.022855285606055986, 0.04899637438938953, 0.04074067539477255, 0.014933376805856824, 0.04252808983437717, 0.03235240656067617, 0.12742172431899235, 0.07273496230482124, 0.15644798084395006, 0.11133813735796139, 0.12578389345435426, 0.196647047996521, 0.12475633062422276, 0.14015196153195575, 0.132032984693069, 0.1847906451439485, 0.10508932813536376, 0.1271329546580091, 0.1895528583554551, 0.10604191178572364, 0.19491260434733704, 0.1045424172480125, 0.20852590823778883, 0.09523235275992192, 0.21039156359620392, 0.18060983042232692, 0.13986970792757347, 0.20544534228974953, 0.14312746905488893, 0.1247769029578194, 0.2211635105777532, 0.1490362558979541, 0.11717178174876608, 0.11977009271504357, 0.21212148014456034, 0.1594063447555527, 0.09242342770448886, 0.1397084243944846, 0.1635763538070023, 0.17755207809386775, 0.17028053000103682, 0.09166728312266059, 0.13131083047483116, 0.09897215364617296, 0.1477388184866868, 0.1261641105520539, 0.13197509717429057, 0.10132583789527416, 0.07922342585516162, 0.11615898765739985, 0.12471061432734132, 0.15931032568914816, 0.14024634787347168, 0.06214346482011024, 0.15273522381903604, 0.11973497428698465, 0.13774848659522831, 0.13135969347786158, 0.1722980139311403, 0.3139943699352443, 0.20251559559255838, 0.14053675025934353, 0.11732395170838572, 0.14209512679371983, 0.12941501423483714, 0.16774565039668232, 0.06012122001266107, 0.25470024382229894, 0.11139989888761193, 0.1373266795417294, 0.1407214262872003, 0.12815389753086492, 0.10078213308588602, 0.1512465497944504, 0.1887272487510927, 0.11110352221294306, 0.10494052752619609, 0.15432861488079652, 0.13750987127423286, 0.10358931409427896, 0.1671007537515834, 0.15158057562075555, 0.07717190703260712, 0.08874975959770381, 0.1261011022143066, 0.1032083919562865, 0.1153909983986523, 0.17371128575177863, 0.1313700687023811, 0.10080071646370925, 0.16559251671424136, 0.1242290495429188, 0.19580347841838375, 0.19100098143098876, 0.09655916437623091, 0.13929053588071838, 0.09437418513698503, 0.26290664565749466, 0.10148950372240506, 0.13888657005736604, 0.11023947678040713, 0.1384468178730458, 0.1433868645108305, 0.10972484931699, 0.16993262601317838, 0.1311591503326781, 0.20839361299294978, 0.10428894413053058, 0.20862822071649134, 0.12752372509567067, 0.13012898998567834, 0.09466662842896767, 0.20693410537205637, 0.08836667780997232, 0.12450164038455114, 0.10252036168822087, 0.1134859053127002, 0.14654281781986356, 0.1842820513411425, 0.13859745900845155, 0.19037210033275187, 0.12187676053144969, 0.20629245933378115, 0.1710465006181039, 0.11466908908914775, 0.1009796185826417, 0.1617543664178811, 0.12561054260004312, 0.17142095864983276, 0.09001054233522154, 0.11944777797907591, 0.08440452205832116, 0.16436549427453429, 0.15599678474245593, 0.2163856677361764, 0.13578972138930112, 0.08147788495989516, 0.21111561771249399, 0.13680563250090927, 0.15208087221253663, 0.13698126917006448, 0.12743279716232792, 0.11599397112149745, 0.16877435613423586, 0.1269519596826285, 0.13633148919325322, 0.1398081541992724, 0.14063909242395312, 0.05964376301562879, 0.12658462626859546, 0.12080821630661376, 0.11273251409875229, 0.16116256301756948, 0.21669054200174287, 0.1732898349291645, 0.22504911379655823, 0.16499088727869093, 0.13718794245505705, 0.1368320084293373, 0.09608323991415091, 0.23163110279710963, 0.16857455513672903, 0.11868633446283638, 0.10539867012994364, 0.1024376938585192, 0.21991334797348827, 0.18390345212537795, 0.16443933796836063, 0.08029705379158258, 0.10520589727093466, 0.21948460926068947, 0.15536569204414263, 0.15393352514365688, 0.18884060438722372, 0.13933663809439167, 0.07833610667148605, 0.08817242065561004, 0.11343654507072642, 0.17334512493107468, 0.16851007734658197, 0.18730489304289222, 0.14051171019673347], [0.02542038360843435, 0.061228003396536224, 0.011781576740759192, 0.04916704237984959, 0.03615677429479547, 0.045828431684640236, 0.050584978598635644, 0.024110570884658955, 0.056731323202257045, 0.06436033043428324, 0.036079446217627265, 0.04364099964732304, 0.039874340436654165, 0.026812136857188307, 0.11367888597305864, 0.038639662743662484, 0.07204550711321644, 0.035400588894844986, 0.03489501563308295, 0.06015411199769005, 0.06596115781576373, 0.008894732673070394, 0.039744720634189434, 0.046628760028397664, 0.06084220905904658, 0.011132536128570791, 0.021076348348287866, 0.059562553506111726, 0.06124689847638365, 0.019605543384386692, 0.03493165175314061, 0.08009636221686378, 0.026332653796998784, 0.05195400728553068, 0.06796511239372194, 0.026795917219715193, 0.027722160193661693, 0.024371667714149226, 0.03918206137313973, 0.047639695039833896, 0.04866744340688456, 0.11370112071745098, 0.056415624712826684, 0.05796608624223154, 0.03936805100238416, 0.023334050638368353, 0.022231391740206163, 0.06753519366611727, 0.04904535613604821, 0.058195320816594176, 0.007331571605391218, 0.03933433152269572, 0.030649387299490627, 0.03823950784862973, 0.04259030407411046, 0.07854005627450533, 0.03813352916040458, 0.03521847327647265, 0.08195436603273265, 0.014770518064324278, 0.06484352052211761, 0.05567765903833788, 0.04134300987061579, 0.05383919597079512, 0.056962446542456746, 0.08570708028855734, 0.027352129072824027, 0.008371693893423071, 0.014545388494298095, 0.09409850696101785, 0.04566786803479772, 0.03550855282810517, 0.022957937617320567, 0.009557667217450216, 0.09822377935051918, 0.031597890992998146, 0.022498470279970206, 0.037442893953993917, 0.08878075910615735, 0.05550256413698662, 0.05904127268877346, 0.05203093831369188, 0.04425450344569981, 0.02616956684505567, 0.030337542411871254, 0.0607031936669955, 0.038506877681356855, 0.024607462873973418, 0.013936155755800428, 0.07715695275692269, 0.09820920357014984, 0.006326786215140601, 0.04689252302341629, 0.019645300235424656, 0.08605462062405422, 0.04559055480058305, 0.016222930753428955, 0.13749057543464005, 0.010438927693030564, 0.0369570581096923, 0.054043587151682004, 0.01150648393377196, 0.03162332439387683, 0.0646571523975581, 0.03777601807087194, 0.02182664851716254, 0.027223991710343398, 0.026569181827653665, 0.03440399588725995, 0.021081767881696578, 0.01710177275526803, 0.05775070014351513, 0.061498271315940656, 0.07146888063289225, 0.023700957317487337, 0.040829536446835846, 0.024288571294164285, 0.05816133416374214, 0.07426880343700759, 0.008354774781764718, 0.04071808070875704, 0.015963438818289433, 0.037938184759696014, 0.012864159616583493, 0.02042113585048355, 0.027611858495220076, 0.02646068540343549, 0.03756878817512188, 0.05366050165321212, 0.09418752015335485, 0.010749781813501613, 0.02092515060212463, 0.010230717234662734, 0.026561834565654863, 0.03935319691663608, 0.015578844904666767, 0.0606525791954482, 0.03392379294382408, 0.01718679504847387, 0.018056575427181087, 0.02837425567122409, 0.023912025972094852, 0.03594367401092313, 0.02194878561567748, 0.07091993626090698, 0.04732198533019982, 0.019200247261323966, 0.017164448981930036, 0.04003264424682129, 0.053890144408796914, 0.06472377499449067, 0.06393395175109617, 0.017202339331561234, 0.013562478834501235, 0.030188222299329937, 0.019410737040743697, 0.03174848017806653, 0.03391273865418043, 0.08305909737828188, 0.016154458353412338, 0.03918278125638608, 0.057913475393434055, 0.04119521487154998, 0.07954062719363719, 0.05000779179681558, 0.058692585735116154, 0.07650976287550293, 0.08811097082798369, 0.03556171286618337, 0.01565276281326078, 0.06576914194738492, 0.005442378569568973, 0.021957298049528617, 0.038471625666716136, 0.03629315135185607, 0.053581114116241224, 0.04595068567141425, 0.030994400622148532, 0.03019223175215302, 0.03879407770000398, 0.05309265477990266, 0.031177052442217246, 0.03244967985665426, 0.08646402638987638, 0.07466075388947502, 0.06048208560969215, 0.06002406917104963, 0.025537054789310787, 0.05067841870186385, 0.04950578084390145, 0.06872210302390158, 0.022178213148436043, 0.04540432397334371, 0.035989854150102474, 0.02700126020499738, 0.046417344419751316, 0.012379405452520587, 0.04541381604212802, 0.07007416250417009, 0.04159219708526507, 0.04871220975473989, 0.0485431633569533, 0.02538904271204956, 0.14622698945458978, 0.03049344537430443, 0.009196595674438868, 0.026740070607047528, 0.06343981498503126, 0.011509716914588353, 0.04377042278065346, 0.023389746966131497, 0.032033223687903956, 0.024959593392850365, 0.028793294513889123, 0.010218270490440773, 0.061006179166724905, 0.038214041051105596, 0.034995880923816, 0.05217002420977224, 0.025950455165002495, 0.036685480299638584, 0.016974767167994287, 0.030911361718608532, 0.05302714911522344, 0.0688674823322799, 0.023507351397711318, 0.018438451224938035, 0.04726397164631635, 0.04047807386086788, 0.06351088304654695, 0.051719162074732594, 0.025958383157558274, 0.053490056307055056, 0.03634779197454918, 0.12031465099425986, 0.01148168970757979, 0.032920925077633, 0.02144871723430697, 0.017330871887679677, 0.10832890664460137, 0.0037227087614155607, 0.06396265802322887, 0.11566302520805039, 0.04878202729742043, 0.040266109062940814, 0.09384691147715785, 0.01690992015937809, 0.011433891686465358, 0.025356135884067044, 0.029654621830559336, 0.013919798821007134, 0.04090282352990471, 0.024757020473771263, 0.008392358995479299, 0.07645131132449023, 0.011388244038244011, 0.0568074007605901, 0.019367835338925943, 0.009019042408908717, 0.03054575194255449, 0.012878410707344301, 0.08516884510754608, 0.025888736308843363, 0.007108267254807288, 0.020984997390769422, 0.0353684279252775, 0.014040870009921491, 0.036600938547053374, 0.023108556488296017, 0.023812073523004074, 0.03459164050582331, 0.030552540738426615, 0.061904088797746226, 0.11691707666614093, 0.05162947352800984, 0.011522886325110449, 0.06063409229682293, 0.03797406759986188, 0.05681957940396387, 0.06423665152397007, 0.09664331650128588, 0.054255796858342364, 0.07069191138725728, 0.04355216457042843, 0.014646829877165146, 0.005813869402118144, 0.02707751773414202, 0.027862604219990317, 0.07862470563850366, 0.026410377067804802, 0.018329784106754232, 0.03190749273926485, 0.010916131432168186, 0.02487101621227339, 0.07074235516483895, 0.04183605567959603, 0.04430672095622867, 0.004588405008689733, 0.010821078085427871, 0.040168531486415304, 0.015827132265258115, 0.03496489254757762, 0.05239078716840595, 0.012945064845553134, 0.01113834621719434, 0.0911302724853158, 0.022119414643384516, 0.061832029969082214, 0.043505004796315916, 0.02774084932752885, 0.02958732202387182, 0.019649636233225465, 0.10152472605113871, 0.04300100488762837, 0.06546455711941235, 0.015540297754341736, 0.04805067044799216, 0.015418272905662889, 0.05076120527519379, 0.009012960508698598, 0.058156428567599505, 0.0323060334631009, 0.017404884420102462, 0.035341257898835465, 0.03448310511885211, 0.01511427530203946, 0.04641882129362784, 0.04069969028932974, 0.021267993142828345, 0.043241876337560825, 0.0345329032279551, 0.019717722716450226, 0.010265977598464815, 0.09565141386701725, 0.10676571357180364, 0.020967146883776877, 0.04736181639600545, 0.09435367959667929, 0.032807113020680845, 0.04481821284571197, 0.04117386328289285, 0.025838149667833932, 0.008433564889855916, 0.05239192265435122, 0.007731191226412193, 0.0647277751704678, 0.04777915572049096, 0.04191731713945046, 0.058533383926260285, 0.05751662676630076, 0.019029028226213995, 0.010904642986133695, 0.11023910570656881, 0.19182031246600673, 0.07007348714978434, 0.21403199090855196, 0.19152855937136337, 0.2318191630183719, 0.10909273245488293, 0.13679516821866855, 0.14047040225705132, 0.16023989534005523, 0.09524111010250635, 0.17198741028551012, 0.08734180897590704, 0.20222268474753946, 0.20687930518761277, 0.20649481331929564, 0.22704638162394986, 0.11096359026851133, 0.1193986478028819, 0.12356098304735497, 0.2047744407900609, 0.10400843457318842, 0.16704466223018244, 0.1229845940542873, 0.1883600340806879, 0.15956329414620996, 0.1245960860978812, 0.1869204902322963, 0.10258053502184339, 0.19699953845702112, 0.11847385016153567, 0.3431022330187261, 0.06564451308804564, 0.12397720172884874, 0.13061506702797487, 0.1364916149759665, 0.08525267810910009, 0.1011236768681556, 0.08628444891655818, 0.12764521467033774, 0.19327075104229152, 0.18788627668982372, 0.17496799409855157, 0.09567663204506971, 0.1282674609683454, 0.1083950097381603, 0.10073418292449787, 0.19632802839623764, 0.13641996803926304, 0.12141820232500322, 0.1105665709474124, 0.10771148430649191, 0.15258358820574358, 0.1426999326213263, 0.1299598693731241, 0.16691779950633645, 0.12468043860280886, 0.10493896901607513, 0.20167972950730473, 0.12195814444567077, 0.13034905161475763, 0.11796987251727842, 0.11243840839597397, 0.23891991324489936, 0.14767169865081087, 0.14624392526457086, 0.22108319535618648, 0.2960026322398335, 0.09726579286507331, 0.18799273035256192, 0.09938360773958266, 0.14994865225162357, 0.10568376615992747, 0.14416465011890978, 0.16597306035691872, 0.21003644593292847, 0.13653087458806112, 0.08135494819725864, 0.30438973219133914, 0.14964965579565614, 0.19982137688202783, 0.13509275566320866, 0.13342151331016794, 0.1478377913008444, 0.14826344267930835, 0.19622215360868722, 0.07554387251730077, 0.1888880127808079, 0.10868633980862796, 0.17387007566867396, 0.1523786218604073, 0.11181299312738702, 0.12957316590473056, 0.07511798365158029, 0.16226454841671512, 0.1439655022113584, 0.09376722708111629, 0.247488854220137, 0.1303672045469284, 0.14261666365200654, 0.16124660382047296, 0.16085141018265858, 0.14619809022406116, 0.17960534838493913, 0.18551051354734227, 0.18125926901120692, 0.14877844863804057, 0.07842918683309108, 0.17917368561029434, 0.08480164528009482, 0.20838864060351625, 0.1761690858984366, 0.36685015715193003, 0.10569673890131526, 0.12787985207978636, 0.14580485585611314, 0.05886845989152789, 0.14993092976510525, 0.19346001354278997, 0.15088089363416657, 0.14913451625034213, 0.0687560488586314, 0.13258477149065584, 0.1369454085943289, 0.14260625874157995, 0.08359932151506655, 0.15169924503425136, 0.11256032841629349, 0.09047009501955472, 0.28168912685941905, 0.09411207342054695, 0.1878309273160994, 0.10073264667880721, 0.12111849340726621, 0.11542469932464883, 0.08020990338991396, 0.1595261273905635, 0.1111390562437009, 0.1558833845774643, 0.08744196922634728, 0.1668715340201743, 0.1028974617656786, 0.19120578450383618, 0.04628957627573982, 0.19374591851374134, 0.12860629591159523, 0.14091705641476437, 0.07108248144504614, 0.2133255999069661, 0.13909993751440197, 0.13710554921999574, 0.18552465888205916, 0.10445977168274112, 0.09325805440312251, 0.12632181693334132, 0.09315512594184838, 0.128733292222023, 0.1551981150987558, 0.16930545185459778, 0.08156045631039888, 0.0962346899905242, 0.18645988369826227, 0.09409367557964288, 0.19731422391487285, 0.11653731970000081, 0.1563681405968964, 0.10354848855058663, 0.22802083636634052, 0.1132751650584396, 0.1070709663326852, 0.18917814799351618, 0.12159704507212155, 0.12816859205486253, 0.12982230487978086, 0.08995948999654502, 0.1139222361962311], [0.0452799214690458, 0.07249562710057944, 0.0326978132216027, 0.013206938147050096, 0.011687952955981018, 0.041677328845253214, 0.08016819469048642, 0.035904351316276006, 0.008142794213199522, 0.033701935317367315, 0.009957282200048212, 0.04655961412936449, 0.05892314875381999, 0.02083517818391556, 0.03159164582029916, 0.012024766474496573, 0.0206225918373093, 0.015051364371174714, 0.036016363665112294, 0.05666161327098962, 0.008050632459344342, 0.05077654175693169, 0.0225417170804576, 0.04403570717840921, 0.00817812600871548, 0.04732777408207767, 0.028496479972091038, 0.04892643810308073, 0.03790781607676763, 0.03573097819753457, 0.007570250936623779, 0.05678643879946321, 0.024109524456434883, 0.026517005135247018, 0.032531271572224796, 0.0425126791378716, 0.07165051385527477, 0.024282847480208147, 0.03890092470101081, 0.04630290895875078, 0.02900249481172068, 0.007373461667157244, 0.04184559598797932, 0.01804572151741013, 0.04933725023875013, 0.07875271869124845, 0.06758894000086002, 0.06090955524996389, 0.11661218013614416, 0.015653733171347994, 0.018758656406134833, 0.04596693499479443, 0.05582515717833303, 0.05909033978241496, 0.0018779209722197265, 0.03727889044967014, 0.07734646016615443, 0.024647600075695664, 0.041910552463377826, 0.052908164288965054, 0.03681258422147948, 0.04326497197325807, 0.02503558003809303, 0.060651714593404904, 0.02768845370155759, 0.06025319984473754, 0.02807986795232864, 0.029596528365800623, 0.029343769565457478, 0.03449922827712726, 0.02474484183039749, 0.027212692511966452, 0.04901214502751827, 0.02651076552865561, 0.019908135545847472, 0.045883743950980715, 0.04355324439529795, 0.026231658630422316, 0.005935140043220599, 0.10567932811682113, 0.014713433920405805, 0.030656855160486884, 0.03342662450450007, 0.017945156796486117, 0.01551025283333729, 0.09681657087639906, 0.03762336942600086, 0.04210216015053447, 0.02533026647142833, 0.0556533091730671, 0.020529227804217953, 0.050403286004438996, 0.0543796613055747, 0.035019774368265644, 0.016645192372379825, 0.014982026441430207, 0.07617893570568413, 0.03191589014022611, 0.07121461341739632, 0.04130018794967327, 0.011260456412856001, 0.03294603564427234, 0.003883316476276377, 0.09822622101637535, 0.07420651498250663, 0.022749603776901495, 0.06793394961277954, 0.024877495161490515, 0.06318312836810946, 0.02908394922997104, 0.03355364307935815, 0.04060263963765465, 0.02851110213669017, 0.1562188204843551, 0.045686302983085625, 0.042216380388708785, 0.0035687525451066904, 0.009963918855646625, 0.020538046373985708, 0.043785885427496396, 0.029255032823130023, 0.03200479572115, 0.05638066584651824, 0.022852942274766974, 0.049588393012527376, 0.04841319103434216, 0.020994873520976398, 0.04735715199785773, 0.026182734400208574, 0.037039874368929304, 0.04259305744199082, 0.02026827754889382, 0.021385723739513196, 0.08939938372350298, 0.028018865268677473, 0.055230088328244165, 0.04240235888573807, 0.03852035879390314, 0.008262053634098265, 0.048262553609674796, 0.04468680446734652, 0.07993185776285827, 0.024036402501224075, 0.02926976259914227, 0.026965427459799685, 0.03198599712050054, 0.029134795622667298, 0.09693105457699858, 0.013934728049207479, 0.02382309812674066, 0.0044131097274657805, 0.06042024615453556, 0.03107242075202521, 0.12066712661180645, 0.021200092196522746, 0.022974997737037484, 0.059877665698877536, 0.060887966174050234, 0.06099125086620916, 0.02636660705320537, 0.04567093310470227, 0.05041596930823289, 0.044467510961112566, 0.020136130733590107, 0.07658640446607023, 0.017688117659417912, 0.026320640281483065, 0.012790152650268283, 0.02876849379390478, 0.06233999665710144, 0.029599144436360803, 0.041122948241536506, 0.07912452725577168, 0.042004137285402976, 0.025932756798283663, 0.04266046300472226, 0.042273507206118666, 0.04492879284953233, 0.0109239406810957, 0.054748623733757995, 0.09147803546511568, 0.02417010226054117, 0.043489349191077054, 0.05157033177965786, 0.030120866831566673, 0.034011781972367316, 0.020130585035076365, 0.04948745721776504, 0.05182961220270954, 0.018716472732194234, 0.018684777460293844, 0.024848349166859407, 0.03674646628496703, 0.02763502092420822, 0.06082858693844173, 0.037489185415324755, 0.04645618100767024, 0.01787677530955989, 0.0461414955498185, 0.05182344866625499, 0.009575041822245112, 0.05177808488951996, 0.043001379672205076, 0.02822001883032499, 0.039645213473704644, 0.012749959787470289, 0.027172395748493727, 0.09447486489079893, 0.08120411410345696, 0.02384477440500632, 0.02124622780684149, 0.031080261542228982, 0.03374272375367582, 0.04978654644219205, 0.0024248146974059637, 0.03598383904318325, 0.06600090724532492, 0.02093135866743978, 0.00744707993362681, 0.0531140917155426, 0.07879800454247743, 0.03094585488724988, 0.082583232288016, 0.05003130674595013, 0.07968233287101611, 0.010821431533258874, 0.018006066711677704, 0.019921772509405855, 0.043186463881284, 0.0688267829536926, 0.03753089040401392, 0.02142566241673194, 0.07719394139712676, 0.04850632685702294, 0.07461609886377119, 0.035036313129239716, 0.033913514198502526, 0.10615504477755167, 0.05454625119455159, 0.01769700673321495, 0.04375350181362592, 0.06998091164859943, 0.04207242600386962, 0.0184134278606507, 0.05466430462547578, 0.025242999181500636, 0.030537371239915956, 0.07153508020564914, 0.025203223776770756, 0.10808566032210365, 0.019915412303816993, 0.060532139759743586, 0.012354743885225616, 0.06337134444038384, 0.03092434002610389, 0.08583010610891506, 0.03861443343339488, 0.05443059861136135, 0.061000980422249995, 0.036935112802893855, 0.02351717743295012, 0.06731158457114361, 0.02352250048716087, 0.04422127749421634, 0.054552674482692964, 0.05482752887473907, 0.039744434907333925, 0.048222203040495515, 0.03748800540051889, 0.02028539704042487, 0.009894371269183466, 0.015443756401509745, 0.029911874335084576, 0.046973880962468684, 0.07358728922554292, 0.07918086368590593, 0.025117008481174707, 0.10043650749139488, 0.006982037211855641, 0.06269620527746156, 0.021576286853814963, 0.020685151175712235, 0.06954553071409464, 0.027329198564984836, 0.07063161188852973, 0.0634954463748727, 0.09320238590589724, 0.0757161175715737, 0.032053981558419764, 0.15649647277314216, 0.06776247639209032, 0.04425495244504418, 0.036174203632981516, 0.022610931628150865, 0.026552348062978126, 0.036262804933357984, 0.03251475507568102, 0.03235541968024336, 0.04961295810062438, 0.022547140324604698, 0.03990723613242153, 0.017153841836261563, 0.0319645601848606, 0.03132863239443395, 0.05158281470357906, 0.02338687114388449, 0.017401166260242462, 0.03617638554715086, 0.028876207252324093, 0.04487120961130131, 0.030658512005174998, 0.027501285912876483, 0.043069727762485854, 0.029575412409030832, 0.03747070222743787, 0.06510586972581223, 0.006673099687759532, 0.06001297777402215, 0.07996712462045252, 0.037522084821830504, 0.08014457212993875, 0.04455818285350688, 0.03281685370893683, 0.04549672135908622, 0.05259409110294655, 0.050108081923099235, 0.041243409941671416, 0.016930768942984287, 0.056467278191121295, 0.0016474355311402178, 0.04846293348236941, 0.0031479339395446004, 0.07385639939457178, 0.08640818719868548, 0.05095211534353439, 0.03811987364315428, 0.052835867973044515, 0.020190947616356425, 0.06031729171809275, 0.028829502043663524, 0.06739131349604577, 0.04514443498919718, 0.045262421626830474, 0.0176959547388833, 0.04585918257362209, 0.06452890927903354, 0.09277920587919652, 0.04664773303375114, 0.029200959943409543, 0.08154142022249289, 0.011004323623637902, 0.0611105770803988, 0.15610837406711653, 0.13842943677445874, 0.1013416085334029, 0.16022880765376613, 0.14217946445569396, 0.0708409197977744, 0.23253530584042892, 0.1178652816452086, 0.19241309550125152, 0.11062120785936713, 0.1339401854784228, 0.23275827668840066, 0.21400150348199531, 0.11958002869505435, 0.12677558086579666, 0.12952264049090445, 0.10481348668690771, 0.09286982211051509, 0.15493621118366718, 0.1527051965240389, 0.1264626023476012, 0.14230033062631264, 0.114872689882759, 0.1311484634061344, 0.08324973285198212, 0.1976197661133483, 0.18306491430848837, 0.12143780986662023, 0.0929858346353285, 0.13942384044639766, 0.2738894219510257, 0.17662446771282703, 0.13786093681119382, 0.11264197950367816, 0.20675643521826714, 0.13754086336120963, 0.11969128405326046, 0.10137088625924662, 0.161802769289352, 0.16771649883594364, 0.16959005064563826, 0.1155497512081638, 0.13241775857750326, 0.1478896228945814, 0.16471034061396495, 0.1723406428936869, 0.2543135255109519, 0.07345968435402028, 0.1793150944286026, 0.09589422232238576, 0.05843469683895819, 0.21814562642248347, 0.12735816679196432, 0.276057799346745, 0.16130725212860852, 0.11223095585592091, 0.13113839988363907, 0.13152364874258637, 0.15452973690116778, 0.10455046955030411, 0.1519184754579328, 0.16903912473935634, 0.1438283533207141, 0.13209813041612506, 0.14299435744760558, 0.19967469881521538, 0.14490029658190906, 0.12049753102473915, 0.1269799831788987, 0.09082481934456155, 0.13297830271767452, 0.23848079930758104, 0.177937074622605, 0.26774663594551384, 0.19457086018519476, 0.15250414871843532, 0.12588207959197462, 0.14387672650627792, 0.1347853580955416, 0.18174078926676884, 0.13391563523327932, 0.12895553576527163, 0.1668129043537192, 0.10035374318249524, 0.10683055501431227, 0.2016703487606719, 0.1226126444817055, 0.25077229365706444, 0.11995737368124537, 0.1075655929162167, 0.10468729931744747, 0.15834106598049402, 0.14457348443102092, 0.1514928092365153, 0.10084369423566386, 0.10625876733683981, 0.2219261712161824, 0.18898444744991139, 0.3829908597981557, 0.2125839123618789, 0.08840757014695555, 0.11680475261528045, 0.0816365412902087, 0.17079270095564425, 0.20244862418621778, 0.12205567749333568, 0.15924860868835822, 0.1625655041425489, 0.2071426933980547, 0.14622877060901374, 0.1818454172462225, 0.13031543232500553, 0.149788853013888, 0.29336305044125766, 0.23043909488478675, 0.11499642816488631, 0.08386356319533661, 0.19161828502546996, 0.10318468033801764, 0.2377332784817554, 0.18269753636559471, 0.1997810188913718, 0.1654843709548004, 0.14082694484386593, 0.16483147395774722, 0.08803190983599052, 0.11571639304747805, 0.13340626959688962, 0.13296503311721608, 0.13003711210330948, 0.09581922087818384, 0.09486829963861965, 0.1892915926873684, 0.17230588069651276, 0.12335180872469209, 0.15039288700791076, 0.14737354824319482, 0.11176276457263157, 0.09199835520121269, 0.19261874462245032, 0.08859050954924896, 0.13757883163634688, 0.16425435023847967, 0.12478264718083665, 0.22998993226792663, 0.13426867488306016, 0.11324148639687337, 0.14941997593268752, 0.1531436128425412, 0.19368387496797368, 0.07270250818692148, 0.12646686227526516, 0.12126103029004298, 0.17011100862873718, 0.1748925176798366, 0.13245557842310518, 0.16650267178192735, 0.133071813324932, 0.16432857984909788, 0.12172936258139089, 0.08600630681030452, 0.14743102015927434, 0.10250359657220542, 0.11796807651990093, 0.26628988911397755, 0.12594884319696575, 0.13269958173623309, 0.08519833063473925, 0.08259092093794607, 0.16310747974785045, 0.19910605042241514, 0.19611060881288722, 0.11787263632868417, 0.21065726730739698, 0.09229254996171221, 0.11426781726186164], [0.06355474397423677, 0.050984621411771514, 0.01381013815262122, 0.011598726396186976, 0.00808961191069102, 0.03093371520662913, 0.03950714803067967, 0.021068143905722536, 0.03715000166266691, 0.024686868964636233, 0.011319122259010328, 0.08939884937717579, 0.039706715251668356, 0.04514700282015838, 0.025063230605155695, 0.007095925802786951, 0.02753424098045798, 0.0251535945062642, 0.04270207151421346, 0.03719558066222817, 0.032540129104745574, 0.059138764918316156, 0.06667616515187547, 0.05256567426840775, 0.07612379413330927, 0.07635840185685083, 0.0738816917873919, 0.03279068929259665, 0.0025070520814551855, 0.01049325568601489, 0.004238787123540533, 0.0108338198333513, 0.03872182220220566, 0.02017722901655361, 0.003803477620749618, 0.03466598514933139, 0.08881699075573124, 0.05709570657927543, 0.08518400718457997, 0.06231877865502611, 0.028797545164707117, 0.029343398491619155, 0.026680119917728007, 0.04457635433936957, 0.021380406251410022, 0.04529979247308802, 0.11059353317250498, 0.06565942283486947, 0.02265152710606344, 0.01274216909223469, 0.03584193669667002, 0.02726396563957678, 0.051603865722427145, 0.05215133322053589, 0.01119247197493678, 0.039599174342583865, 0.03807035755016841, 0.016244104226643685, 0.030069812637520954, 0.021748112594650593, 0.019291754069854505, 0.06160570461361203, 0.023692003305768594, 0.043437525018816814, 0.11346460567438044, 0.042801515592145734, 0.0159959133452503, 0.027339401240169536, 0.13425074459519237, 0.0424022624065401, 0.09579047007719055, 0.05079199327155948, 0.038045599503675476, 0.018933454448415432, 0.012507755254773656, 0.03171878313878551, 0.03354177613800857, 0.10892702572164126, 0.03926845107343979, 0.04866847870289348, 0.026558173922239803, 0.034423863180563785, 0.0439432652638061, 0.02235024112451356, 0.07299793491256423, 0.04760875119245611, 0.038504732874571346, 0.03360117392730899, 0.05237409255641978, 0.010694236698327586, 0.022723565525666345, 0.02921558767411625, 0.14732893032487482, 0.05613170869764872, 0.019078798504779115, 0.02939428941317601, 0.06910375246661715, 0.03134972052066587, 0.021098369725223165, 0.04858867927396204, 0.026004951068898663, 0.08810260682366788, 0.037780530328745954, 0.03906371850462165, 0.061371519914246164, 0.043483419431140646, 0.048147735942620784, 0.06823208517744206, 0.041074749460676685, 0.01709975411358755, 0.026944920064124744, 0.025474165195191745, 0.0237383244530065, 0.0567404293542495, 0.06228238373296335, 0.06412293223547749, 0.034277259328518994, 0.09853994168224744, 0.05617140246613417, 0.04949607726302929, 0.020227708046149928, 0.008225742203649133, 0.04143286911130417, 0.04629874922102317, 0.11681019255775027, 0.06474558671470731, 0.038660287027596496, 0.021424638252938166, 0.02567977164289914, 0.045177905849413946, 0.022568105996469967, 0.04491763836995233, 0.016912270912143867, 0.03564211343473289, 0.06708698841976002, 0.02507393237465294, 0.08475480834022164, 0.06259335845243186, 0.02702670288272202, 0.01807139426091453, 0.043227667920291424, 0.03747949296666775, 0.06506410165457055, 0.03944028423575219, 0.03336736401251983, 0.013902175596740562, 0.012625746530829929, 0.04482289950828999, 0.10080937732709572, 0.006450219289035886, 0.04933046700898558, 0.05358692884328775, 0.020360559901746456, 0.024715282088436652, 0.04803527088370174, 0.0709664763417095, 0.03127035524812527, 0.012366800074232742, 0.07156564184697345, 0.06345052417600527, 0.03946173230360728, 0.03643982570793014, 0.058958675363101065, 0.03720926215464715, 0.03690599463880062, 0.0658988842042163, 0.046126548695610836, 0.03669575904496014, 0.031799703210708685, 0.018389083561487496, 0.09206491842633113, 0.02922963467426598, 0.022467389135272242, 0.029581830131064635, 0.0409991654305486, 0.012683992135862354, 0.018274440299137495, 0.05869238906598184, 0.04740799282444641, 0.05537007222301327, 0.030921462348487694, 0.043317226591170765, 0.03207703266525641, 0.0541360327770235, 0.028590886722668074, 0.010028284395957598, 0.0348720981128281, 0.06354031662340276, 0.05739503329095896, 0.03538751967425924, 0.0074003436475322815, 0.029813560176989995, 0.01806963722629007, 0.055612505893805064, 0.05141335270309355, 0.09302312755608, 0.0543152132013347, 0.028927417297381908, 0.10576466767815873, 0.04231556842569262, 0.04844364506425336, 0.006103901177993976, 0.042453103233128786, 0.02063639763946412, 0.01825768074922962, 0.031147618865361437, 0.01830904664529953, 0.04843548515054863, 0.022477113125205506, 0.04580042303132359, 0.04748741746880114, 0.048488608081243, 0.08295293315313756, 0.05747777904616669, 0.06909572242875583, 0.023763811659591738, 0.023848807977628894, 0.02073838171781972, 0.05651605955790728, 0.035560811156756245, 0.07307723339181393, 0.032241808003163897, 0.025897668056131806, 0.037976824678480625, 0.04381272148748394, 0.07468316674930975, 0.013017468772886787, 0.033018576868926175, 0.09501105916569941, 0.030696526664542034, 0.03326176753034815, 0.01748521262925351, 0.03616789537773002, 0.028486652081483044, 0.007884479509812081, 0.029528467857744545, 0.03187893860740587, 0.04119180470297579, 0.12761895748553798, 0.06097540601331275, 0.09814488163101487, 0.04527071141637862, 0.039154316182248294, 0.05823240222525783, 0.07765796923195012, 0.03005097692948766, 0.007558086208518944, 0.040815398533595726, 0.05471709358971566, 0.017620472754060756, 0.012046576339344028, 0.043803982698591426, 0.061278361827135086, 0.06065640496672131, 0.031222212128341198, 0.07340534430113621, 0.03982026013545692, 0.0558082547649974, 0.033306860423181206, 0.02698156731639756, 0.06986733336816542, 0.03953385050408542, 0.04169156694842968, 0.010348973828513408, 0.021438338299049065, 0.007659311440875172, 0.013440506863844348, 0.020941912007401697, 0.02913110158260679, 0.18852992652682588, 0.02293224817549344, 0.048418278456665576, 0.08101822095341049, 0.07142036643926986, 0.06608341180253774, 0.024145603965735063, 0.07044141428195871, 0.02522129136195872, 0.0617153977509588, 0.09977299778256565, 0.02734773741394747, 0.05323441240761895, 0.015590242437610868, 0.04349939787061885, 0.03953835534048267, 0.04489439801545814, 0.0686757113726344, 0.045234008503030054, 0.040860005319700576, 0.05162368106539361, 0.006430317671402008, 0.04538601147942245, 0.012713524974969914, 0.03379267771379091, 0.012838151051255409, 0.06947475951164961, 0.010392729927843902, 0.021303399153111968, 0.0575505466258619, 0.022070954255468678, 0.06517292276839726, 0.017238834443560336, 0.02422207671770593, 0.1058215532975737, 0.03165872854879126, 0.0757123326184228, 0.013123881617502775, 0.01173778260636027, 0.057397400742047466, 0.025294114602729678, 0.06744511920260265, 0.05931047933700029, 0.08360048668691888, 0.013637356896651909, 0.011448022178228712, 0.019579449472075794, 0.005353291162464302, 0.05645804216328543, 0.02322346692380961, 0.07847217944799922, 0.032997024900396354, 0.04880939028225839, 0.04534461077128071, 0.018347606783208903, 0.045755170576740056, 0.005964015617792029, 0.022917299465916585, 0.037016248097643256, 0.09925117890816182, 0.034568975315778516, 0.03173622731992509, 0.06913958335644566, 0.015741898459964432, 0.012165825555712217, 0.04064417393237818, 0.07328755062189884, 0.049009658832801506, 0.049668734209262766, 0.07590766588691622, 0.006436344838220975, 0.0572541328438092, 0.0628308011800982, 0.07258103345520794, 0.01518800117992214, 0.028007402797811665, 0.03192145253706258, 0.016165985762199853, 0.04542881484667305, 0.030783500806137454, 0.028386000158207025, 0.005661196637447574, 0.03006272883794736, 0.10179917968343943, 0.15291623363737017, 0.19151183136273175, 0.1139742459054105, 0.15538129198830575, 0.18340685142902657, 0.11936265364056453, 0.10746312458650209, 0.12204245242173783, 0.1059418183285743, 0.1830627175513655, 0.19612438307376578, 0.15867607144173235, 0.10388906754087657, 0.1040913695760537, 0.12773093272699043, 0.18412968842312694, 0.14372026693308726, 0.2399002606398426, 0.1394841176806949, 0.12190693625598215, 0.1138413198350463, 0.12564701173687354, 0.1204623086960055, 0.19644767744466662, 0.15604921005433425, 0.11918439719011076, 0.09714117884868756, 0.07917349415947683, 0.12411106290528551, 0.0944709092436824, 0.1007639207819011, 0.23734664922812954, 0.09048481180798262, 0.09294607036281377, 0.16335198772139847, 0.1383912458550185, 0.13021326827583835, 0.24456054728943855, 0.18648293480509892, 0.09035614566528238, 0.12638825399335474, 0.16736752615543082, 0.19624250329798087, 0.14225166058167815, 0.14589400263503194, 0.20439493615413085, 0.10707133740652353, 0.11688631464494392, 0.13292581803398207, 0.10036008854513057, 0.13935854629380628, 0.13794753060210496, 0.1394393216469325, 0.13855454802978784, 0.12145221495302394, 0.1294572275946848, 0.08634020647150464, 0.07379775488516316, 0.16291760868625715, 0.06821650007623248, 0.127459202776663, 0.28454321902245283, 0.1578604956739582, 0.17145485995570198, 0.1553367037558928, 0.13733012310694903, 0.08822129108011723, 0.22509919392177835, 0.13973114895634353, 0.1502399006858468, 0.17900453531183302, 0.18148605449823663, 0.12247835285961628, 0.0840596089255996, 0.15826107730390504, 0.15854575030971318, 0.23152543581090868, 0.1963765500113368, 0.21110369882080704, 0.0886934157460928, 0.14966957503929734, 0.11862348197610117, 0.1131621359672863, 0.19622706662630662, 0.2223702723858878, 0.14346516109071672, 0.15269850235199556, 0.15056660893606022, 0.0857630827522371, 0.10314302358892746, 0.14527574909152463, 0.18311989260837436, 0.243152589246165, 0.10542938762228005, 0.1048447607900016, 0.19910018745576963, 0.17692477034870535, 0.18628558289492503, 0.12839592673117295, 0.1414252197719179, 0.17103073740145192, 0.15972359804436564, 0.2052881257259287, 0.19016952370293438, 0.12362868917989545, 0.0925978175655473, 0.10800927848322317, 0.13147766527254134, 0.13012100447667763, 0.2040360780665651, 0.18959425535285845, 0.13155192456906661, 0.15270549338310957, 0.10125704080564901, 0.25384998007211834, 0.10421706712804735, 0.15402103919768706, 0.13272205396788195, 0.11827568931039423, 0.12024588359054178, 0.17113548412453383, 0.10928722709650174, 0.15498397580813617, 0.17639232391957194, 0.14096220867941156, 0.06455342241679318, 0.13432576088234782, 0.10935813930700533, 0.15010511182481423, 0.13076192321022972, 0.10613924445351586, 0.0733906720415689, 0.06100468002841808, 0.14422940992517397, 0.13152002706192434, 0.21815827261889353, 0.1577208680100739, 0.11811825752374716, 0.12165710708359256, 0.1074055339267943, 0.12894346844404936, 0.12480296718422323, 0.12095555488485843, 0.1395731754018925, 0.10546883277129382, 0.08720195124624297, 0.1116387294314336, 0.17592788790352643, 0.12430261864210479, 0.15831768832867965, 0.19626528723165393, 0.2335354982642457, 0.10884693314437754, 0.17747344012605026, 0.18974109669215977, 0.09425721524166875, 0.0886102209915407, 0.23207973106764257, 0.1168464167858474, 0.1790819116286002, 0.22698674263665453, 0.11880361606017686, 0.1529271135223098, 0.16681293403962627, 0.189068324980326, 0.15395809023175389, 0.12059090804541484, 0.10044041118817404, 0.11109014871180989, 0.15448277379618958, 0.14981548127252609, 0.1452603717916645, 0.12202464829897508, 0.07780750456731766, 0.1860886614304036], [0.07046639497275464, 0.07203502056654543, 0.03208999056369066, 0.017341265665891115, 0.008684146414452698, 0.057235211788793094, 0.13627409149194136, 0.05973260922473855, 0.07167639254475944, 0.02672636128409067, 0.009195257953251712, 0.04284646376618184, 0.07046953425742686, 0.024686666729394346, 0.003423476673560799, 0.07724269307800569, 0.008364121204067487, 0.06782629367080517, 0.08715118834516034, 0.05315910297213122, 0.08630137730506249, 0.06843837996711954, 0.0644883063796442, 0.03139001171803102, 0.029620052591781132, 0.012117638834752142, 0.07522539468482137, 0.027471071225591004, 0.0392030047805747, 0.03626212215749547, 0.041760493913898245, 0.047295089898398146, 0.036956987605663016, 0.04936880635796115, 0.035943403127021156, 0.02653910814842675, 0.02306575497641461, 0.052735741119249724, 0.07280077596078627, 0.020342045172583312, 0.0277687689231243, 0.07634557012352161, 0.05624846337013878, 0.0446120256674476, 0.043032293833675794, 0.029309588098840322, 0.02565004677308025, 0.017957580348593183, 0.113464746682439, 0.06100083570345305, 0.055623237349209376, 0.052869539213133976, 0.04597099825332407, 0.01120671378885163, 0.034504868599469773, 0.10411922237835824, 0.03775381301238667, 0.006370814589899965, 0.07529344962676987, 0.029165218111302238, 0.03199553371814545, 0.05879227101104334, 0.040904920097091235, 0.028053527275915258, 0.04106357642740477, 0.04602546076057479, 0.03974037535954267, 0.0348937873786781, 0.037154977762838826, 0.027065691610914655, 0.005955095930403331, 0.03204676046152599, 0.08811918640276417, 0.03837525779090356, 0.012269825492694508, 0.030842946835036855, 0.00955329318458098, 0.030302182785817422, 0.010572420578682795, 0.09412722807610407, 0.04126553707465064, 0.054396341074607335, 0.040269233504659496, 0.024644959885335993, 0.027980397899227683, 0.0331625609396724, 0.037838621938135475, 0.03139367050607689, 0.04672087910876144, 0.027824305689136963, 0.015482801718462724, 0.03479132275970187, 0.06127325214038137, 0.03988107171608135, 0.022840713536425028, 0.03911741659976542, 0.025884242604661267, 0.08936328566051088, 0.03486965644697193, 0.05894319045182783, 0.06377088706358336, 0.024246272587333806, 0.003284877116129792, 0.03501721395878121, 0.03910695973900147, 0.019809598743449897, 0.042259424953954294, 0.035080207453574985, 0.03236909004044719, 0.007995835985639133, 0.03457905368122738, 0.05044388890382834, 0.03107917986199027, 0.07368140097241849, 0.047022551007103175, 0.04267000331310555, 0.026425628202559892, 0.06625294059631415, 0.06566277734236792, 0.022013512025296222, 0.05625844525638968, 0.008969823174993508, 0.030661059427075088, 0.022816907294327393, 0.024029274172789883, 0.07621133787324652, 0.045885487998020835, 0.022689872021146584, 0.01523739296317217, 0.040311762277269736, 0.027937731829297263, 0.025890665892802645, 0.04467719736567233, 0.04914434008242097, 0.07038066949462518, 0.01703079560684273, 0.05692212194844615, 0.024183364439522848, 0.028752032958436757, 0.04560671506624203, 0.10552160689258017, 0.039777597776264884, 0.016829976011649705, 0.019168470353179146, 0.023718561060377397, 0.06151497334940359, 0.04431471759744454, 0.04388081724755466, 0.01712656234303722, 0.08066683629294857, 0.02387515050941147, 0.034514739163569175, 0.07227611466078088, 0.011488779073260957, 0.056387660588370636, 0.03345844037539791, 0.06685280372039415, 0.09371149921207689, 0.02736415928666247, 0.09940993171767332, 0.036480295020737685, 0.03752664903004188, 0.015465482774743577, 0.03459938110609073, 0.03283433128672186, 0.014764895367989084, 0.0441018844867358, 0.026798423823493067, 0.011267540212429594, 0.034872001633630134, 0.05160038504982367, 0.04003863337857183, 0.052379614135134034, 0.025911779994203243, 0.00580615060243872, 0.032198967528529465, 0.02965005947771715, 0.059810475358972326, 0.045174577317084186, 0.05853077156643849, 0.028517582941276487, 0.057635923294583336, 0.03807254688581452, 0.0830197412869893, 0.022522089129779488, 0.03965998221246991, 0.044403612046153285, 0.03983808281191159, 0.04296747465559747, 0.05867791718628723, 0.025518194961478002, 0.03175188663590234, 0.022258487551880535, 0.015832609315111768, 0.03307951090391725, 0.061234385866555385, 0.034276903097634204, 0.028643679397646338, 0.03686158452183008, 0.07683634496061131, 0.018261675359099172, 0.07863550388719887, 0.04172546454356052, 0.05980704663670622, 0.03430913086049259, 0.0391515702358447, 0.021342410145734902, 0.022816979653725866, 0.03680353001982439, 0.03142467743600719, 0.026376627902209293, 0.03419441338337492, 0.03178063372615725, 0.05683146860974375, 0.034258991363458335, 0.034489435638533905, 0.06983697952819057, 0.019717041795956902, 0.02915964458225062, 0.03764987151953392, 0.0202055382396793, 0.03518861667544115, 0.0739414495183155, 0.0412675816914998, 0.0473402495845221, 0.028983160009374842, 0.044081694359192625, 0.04792838677531108, 0.03468877279374283, 0.004034768871861161, 0.025719298428157344, 0.08134308125590906, 0.02260846955323359, 0.024938818824011832, 0.017053603660315275, 0.03037731039512437, 0.01045415749103995, 0.02791416864056373, 0.04921666237351019, 0.03311733446025755, 0.03438514904701151, 0.02988836680742679, 0.0602148530742852, 0.08055773316300474, 0.023245928023243323, 0.008456184623355512, 0.0322038063313812, 0.016535274735360872, 0.03985346011177171, 0.08598201631684788, 0.01382269807436387, 0.04301455650420394, 0.023876534614828415, 0.04742376346257515, 0.029500654018193018, 0.01422835413904977, 0.02409609343885677, 0.05672122999385465, 0.07037870280328207, 0.046198763375286944, 0.016516513242095243, 0.04000760418421123, 0.11959835974266753, 0.02442939567117719, 0.018136731086997315, 0.03549313471012283, 0.04463304328965023, 0.05053654975199606, 0.04116116513614543, 0.027003954201063607, 0.04323319692048244, 0.050636576415854506, 0.04021431828732602, 0.02466929676302243, 0.028057922645530198, 0.05371691229811404, 0.09280744459829293, 0.07575425654067658, 0.016036011584219523, 0.03521489241393283, 0.0822708845953457, 0.030371866741916165, 0.06839819267042913, 0.0786986383900512, 0.038186577876331285, 0.057003424226422794, 0.0008949634207056079, 0.021026602189522237, 0.03022053169843275, 0.06505587123683654, 0.04689745088398922, 0.07961860465002246, 0.016609125850663986, 0.017725495927152224, 0.03252371279813815, 0.022796205084887333, 0.019774730790231843, 0.020204052088956814, 0.02891447609727038, 0.025653184202383272, 0.009621530880394857, 0.03896412228641566, 0.04144544109294657, 0.05254000338027254, 0.04361521372629795, 0.052565039732144214, 0.024213751676143147, 0.0705126159300562, 0.028709608086501248, 0.05829230467497837, 0.08094535689451732, 0.006572516876985901, 0.014276152160164202, 0.04810451326193288, 0.02283894722495461, 0.026074588640767615, 0.06297176470980048, 0.08042458444833755, 0.06962697400012985, 0.09053130735992454, 0.035421895954641514, 0.05016932023863774, 0.021433909532788675, 0.03619273877120577, 0.06810506660258397, 0.020683976727013942, 0.015879047350608744, 0.09853404902969487, 0.07333175293751992, 0.0339559910207754, 0.05617490540316794, 0.024737602179811802, 0.07284108200110495, 0.048363103487645276, 0.023872102137829643, 0.08735654060728848, 0.016392442848882638, 0.04027609094919171, 0.0344859178585466, 0.04834203020436689, 0.050304843825870194, 0.040136251773219556, 0.0535324514930835, 0.03851957582810428, 0.0075323888813727535, 0.09585471038008109, 0.007957235957292141, 0.040417510899715126, 0.028966033096367028, 0.0750951848749537, 0.05271519847156014, 0.024331788408744615, 0.1074417655763682, 0.1947439883952029, 0.13935094670159742, 0.1173294658656232, 0.1773278010659851, 0.14627405646024272, 0.1501532772090286, 0.13910033827414736, 0.1375009655021131, 0.14532164350384846, 0.19046800065552816, 0.06687225541099906, 0.15697964059654623, 0.09390069491928443, 0.08365938352653757, 0.16692140634404495, 0.11030539433704689, 0.14850988023681566, 0.15769894496770576, 0.23926373542053625, 0.1525857107480988, 0.17692266264930367, 0.16030710423365235, 0.13282968022394925, 0.12662352964980528, 0.18834741757018492, 0.20561471523251384, 0.11749905403121375, 0.13308063003933057, 0.18041798524791375, 0.11220018641324714, 0.10906810057349503, 0.066780288470909, 0.1443137475871481, 0.1316883461549878, 0.0987574429018423, 0.2024849597364664, 0.15012679737992585, 0.17088956607040018, 0.16122707049362361, 0.10331820012652315, 0.15427060861838982, 0.1533794228453189, 0.20845611667027697, 0.180825513380114, 0.1089178750407882, 0.16053426079452038, 0.12418268757755868, 0.23939347767736763, 0.16354129475075752, 0.09317246251157485, 0.1796727057080716, 0.10715685508330353, 0.05713302918593399, 0.24437879532342777, 0.26161907881032676, 0.11759425673517399, 0.1055338820151519, 0.16402596171246842, 0.09041761775733903, 0.14420984691241756, 0.14863796008285135, 0.10155437485082075, 0.1085659560339991, 0.17028440401190892, 0.08825007156701759, 0.1424948772182688, 0.19222791481297463, 0.1100982609204948, 0.0876568432431668, 0.15345703664934263, 0.09105957549763843, 0.10215647926088423, 0.2901202510111034, 0.17705356265651062, 0.08127445486024953, 0.10100707804667763, 0.18229775625513867, 0.17065782303689048, 0.20289863285142928, 0.14599156536860391, 0.1854235932114534, 0.19092016154900193, 0.14163051266223192, 0.18042939947918057, 0.21114842063980177, 0.17869180912384763, 0.18775215576170012, 0.09031365771079436, 0.08218608680181205, 0.2353797500836663, 0.14714184973854572, 0.14099766849540174, 0.16259278549114242, 0.12106899215723388, 0.17729352868627757, 0.12411641379003413, 0.1824647988541983, 0.2145440728054382, 0.1217848900705576, 0.17338949051918462, 0.160486540698912, 0.10269769045407884, 0.14650140597950667, 0.12136240024119616, 0.12362224733806215, 0.11596065611229278, 0.12265557030332275, 0.15199623769149184, 0.15790342149557546, 0.0722058406972792, 0.13247159396996722, 0.14722367894137278, 0.15360641613369808, 0.0857231106783729, 0.27824814431369305, 0.1804491999791935, 0.15379416465293616, 0.1065727329114452, 0.12398445993312635, 0.1345880061853677, 0.17512103979242966, 0.09734313207445666, 0.08986928936792538, 0.1476411073235795, 0.25495569105260074, 0.2584865328390151, 0.12159976133261807, 0.1857725065201521, 0.1283672353019938, 0.04236004162521567, 0.15044318977743387, 0.12012827544822358, 0.24797313526505604, 0.12447697881725617, 0.0785336663830094, 0.12332731042988598, 0.1840513918432407, 0.08175719223800115, 0.13126619771355763, 0.197230004996527, 0.17124520323704928, 0.1633221682277508, 0.1593072828836739, 0.08961473271483555, 0.16668935160851106, 0.13740689086262137, 0.13246895192423835, 0.18335853761527687, 0.1524602877907455, 0.15253644698532298, 0.15632129623554647, 0.19199108064640313, 0.09126575896516442, 0.15911110356682912, 0.12003077208646573, 0.17802457383368164, 0.1520164092653431, 0.1660375381470658, 0.23589260381413624, 0.09793162549613044, 0.15579894301481545, 0.14247866871301085, 0.10129869013326243, 0.1497333255247213, 0.15762965806061402, 0.18658267945284024, 0.11810183379566297, 0.22820922313258052, 0.17097500211093575, 0.08560772897908464, 0.13164497504476458, 0.18565572216175497, 0.18913635023636743, 0.09046636943821795, 0.10881902839173563], [0.05466791146318428, 0.0412756599689601, 0.05526395623746794, 0.03527645727444906, 0.02528027540392941, 0.01685976210865192, 0.020738615494337864, 0.03826919746643398, 0.010509345447644591, 0.024553751791245304, 0.046056018691160716, 0.004520317133938079, 0.01867034639872145, 0.0220946528861532, 0.0718488528218586, 0.003997138737759087, 0.02767521935311379, 0.026915723974525463, 0.060737428939319216, 0.07036313254502602, 0.043111006016260944, 0.018076516935252585, 0.014898131285008276, 0.0718734401743859, 0.04146872968703974, 0.026793956094479654, 0.06636222184170038, 0.04722752848465461, 0.02039071150647942, 0.05958878842648119, 0.01369148450976354, 0.0274315667047631, 0.07359724142588675, 0.0336621228052536, 0.014725388991791988, 0.04054618446389213, 0.023797820576874074, 0.0653711281483993, 0.05635688743495848, 0.05337627764674835, 0.026762617053464055, 0.0064567311710561626, 0.04683391933212988, 0.0767825021466706, 0.05394540843553841, 0.023163352962001227, 0.034720340045168996, 0.03282939229393378, 0.09137570814345963, 0.05600734330073465, 0.03312311579065863, 0.046563154173782095, 0.08517464870237745, 0.03472273347142618, 0.007929799685371108, 0.030294373536889907, 0.056589643500046805, 0.013004993270442355, 0.027212601598876063, 0.021028494666097686, 0.02532705111661926, 0.013346532414288959, 0.027525409423105884, 0.0512058778986102, 0.10154618154047057, 0.03754599310923368, 0.040590000862721354, 0.01264006348719704, 0.024304696307808626, 0.06513086525956169, 0.032578000900684856, 0.04337095066148322, 0.012194644077681005, 0.028708298195851967, 0.06073378499422688, 0.05068700906122103, 0.06977132172323763, 0.05362429226806853, 0.017307952512055635, 0.02555165468947962, 0.03287605111836456, 0.08021774046937935, 0.03279602533439174, 0.00699387353961356, 0.05533154362638015, 0.0394404809048865, 0.10313722741557285, 0.011620802506513428, 0.09287618973758072, 0.02813358645653352, 0.04021238499262836, 0.07419308210955933, 0.06456568269641139, 0.023878274951130152, 0.05370189122913871, 0.07807478905306198, 0.0338643432041863, 0.043757791427196935, 0.1191768643911928, 0.06366009925841354, 0.03812433023995254, 0.026938324226648547, 0.01263048699911451, 0.014953485297155567, 0.015602690109517425, 0.020998771651647985, 0.032283349719364196, 0.026516669313423336, 0.02587597322417423, 0.01224055797138135, 0.02293299403390847, 0.09750765879289247, 0.028564596141222864, 0.017815900646382943, 0.0774913199711591, 0.05854250121046789, 0.021394950490503106, 0.05742536115576513, 0.051582488158601336, 0.039176257778308354, 0.03979972861998249, 0.00867593269504141, 0.07072288120980375, 0.01948761426319834, 0.06730433378834277, 0.03318800176202785, 0.061264635805855505, 0.03526915083057247, 0.04044155648443848, 0.010698999431042466, 0.0319709129689727, 0.07043515055556782, 0.03906097997969482, 0.05384466930991039, 0.045657763694180176, 0.07660967079573311, 0.029482128156814724, 0.05456585131469183, 0.05656641056702938, 0.07396634857286699, 0.04324893045122735, 0.007251036986417603, 0.05479291510710027, 0.014870418563077692, 0.027954810502706096, 0.05027592975238804, 0.06413823532056995, 0.022557359698112123, 0.052808200707659125, 0.008033794056245824, 0.044962126412428916, 0.028091913009120617, 0.043225144618190825, 0.040306723094545305, 0.07561206104583107, 0.032882979066926055, 0.017509755452920217, 0.017115357768489048, 0.010554327018326148, 0.08016895910259336, 0.05513595802767668, 0.026558658173598815, 0.02498010449926369, 0.04267719101335388, 0.04683771912823431, 0.038673619710607454, 0.01879586954601109, 0.047934208923834376, 0.04116637872357387, 0.002161366187465319, 0.039950881837285124, 0.025295943996752612, 0.03189921779267024, 0.040694729032111354, 0.03505100394249894, 0.03578334413759876, 0.04118245364225004, 0.036609937087632716, 0.08032516634557396, 0.07241124490974471, 0.041011255016201176, 0.02745799458352849, 0.03576371804228984, 0.006058863482394372, 0.04903614979411941, 0.020543139362416696, 0.0542234540625941, 0.026694285661506, 0.040590242060716264, 0.03603888413636014, 0.014913926970621105, 0.02163115939765703, 0.024239337217295542, 0.0622092933190288, 0.02714494741667295, 0.08526742458343506, 0.07850057401810773, 0.007858941280574072, 0.02082925770082511, 0.07136193715268746, 0.0593454456247855, 0.030898761906428263, 0.04299688967876136, 0.04611974691215437, 0.06802941948990338, 0.02955064508569194, 0.01658058841712773, 0.08099897706415504, 0.05401497364800889, 0.05086536199087277, 0.03864165541017428, 0.007591666999360314, 0.057037496226257645, 0.036873592471238226, 0.03002825422299793, 0.04326343572756741, 0.03673601684567984, 0.04566677336697467, 0.030948797502787784, 0.06751522989361547, 0.05767046655819286, 0.050377544612274505, 0.06693969437037595, 0.03306735823571216, 0.14657566527603194, 0.05236356519162655, 0.03730978234671056, 0.02312942382559413, 0.05579264368861914, 0.055903520551510155, 0.045370170337264426, 0.03806593063927721, 0.06045490445103496, 0.03438092993746977, 0.017417098315490875, 0.017187127159559168, 0.04292578079912346, 0.055606078894925304, 0.02523211373045342, 0.0281508321131696, 0.03147907686070539, 0.03095404819760006, 0.07151600701035932, 0.015851725183892995, 0.019070525413553696, 0.01784973886969965, 0.04780093033332378, 0.015236453218676616, 0.009450331326661399, 0.008856327458488522, 0.06282619244302623, 0.05389583297073841, 0.029722489380219486, 0.02464996938215336, 0.03875455462548416, 0.020642011986637954, 0.04295356309739873, 0.03654432381154038, 0.03892328932124656, 0.0370300483336905, 0.05216087352891918, 0.04057778882270213, 0.03194810306013096, 0.0058296868883189745, 0.029734386007476132, 0.06779481176636182, 0.06591060271603055, 0.0312780067906715, 0.03627817852247972, 0.020934889435011428, 0.023740044380247127, 0.06263198723900132, 0.02366078486375045, 0.06653888267464936, 0.07885768805863336, 0.07833840732928365, 0.04027817638416309, 0.008116682674881304, 0.08317790779983625, 0.02389874523942126, 0.027974434742645826, 0.10049874399555847, 0.01641536407987587, 0.0481409378699027, 0.013835713489243062, 0.04322347107517999, 0.10427164466818795, 0.04954530391842127, 0.0373189812671626, 0.0302348180412082, 0.05168070027139038, 0.03449093477684073, 0.04099443794984836, 0.049134859145851806, 0.017781407477741595, 0.03898986367858015, 0.03321541669720318, 0.008903227480914211, 0.02116124076565029, 0.023977739438123535, 0.03258840581111144, 0.07601446835906245, 0.05843824059411418, 0.01909131111460738, 0.07202445980510674, 0.028606382766156457, 0.04118590091820806, 0.057294702346553095, 0.018039023634628393, 0.01380618992698146, 0.01998557123442879, 0.010419611444376642, 0.027924148671445437, 0.08694287491380237, 0.0387108792347135, 0.02576813360064989, 0.060335789748933166, 0.06374241085723042, 0.018492121489543933, 0.028521301101136487, 0.049463697359897196, 0.013024350337218493, 0.016591609310125932, 0.029336928819247987, 0.05321041135175619, 0.0034742275147436885, 0.041496404373901896, 0.02113127469783649, 0.05723315603972878, 0.02042945347056957, 0.032969335370580666, 0.06986727399635129, 0.05462277404149063, 0.06350225186906755, 0.024232832292909734, 0.051569096103776246, 0.06144551203760784, 0.01023965733111254, 0.0102809420786798, 0.06469219661084935, 0.01989999789657304, 0.02454970708640758, 0.0807143040583469, 0.007230357969092438, 0.031566216130158864, 0.04771657411765773, 0.016413428929809015, 0.0796219146286603, 0.039051447092788294, 0.058920747906086035, 0.06383198066032492, 0.02847046584065538, 0.13538210419937968, 0.10643251895089634, 0.13430855789920315, 0.18510172376409173, 0.10422563151223585, 0.09093654225580394, 0.17360894358716905, 0.2260217725415714, 0.08592101919930428, 0.08396278091822751, 0.23809906822862104, 0.09495382473687641, 0.1900267493329011, 0.12075251812348142, 0.08800825758953579, 0.10526561789447442, 0.1928831124678254, 0.12899052060674876, 0.22771262243622914, 0.1722828741185367, 0.148772778629791, 0.10162779552047141, 0.11060475444537587, 0.22179835854331031, 0.1523696121876128, 0.12244702680618502, 0.12389224066282623, 0.1123266112699639, 0.13202039786847308, 0.14991581963840872, 0.07453196158166975, 0.11789434414822608, 0.14178340992657468, 0.1464411584311165, 0.12911098601762205, 0.11707149533322081, 0.1595296006416902, 0.1788018547813408, 0.20460208441363648, 0.195372290618252, 0.09638258517952636, 0.1508074507000856, 0.1182892409269698, 0.26003581064287573, 0.18876827467465773, 0.10307303164154291, 0.12453613540856168, 0.12188084976514801, 0.2365942153846845, 0.09125104959821329, 0.08770691594691016, 0.11302606319077313, 0.16223796468693763, 0.129950592527166, 0.13517730112653226, 0.12708857422694564, 0.14345206960570067, 0.10028861230239272, 0.11439069465268403, 0.09430074962438084, 0.15180630725808442, 0.11721966511686333, 0.07922950404463336, 0.17028222209773958, 0.12872236780822277, 0.21185504912864417, 0.20953650557203218, 0.10110840346897021, 0.08602204034104943, 0.21002804482122883, 0.14064020564546809, 0.08561678318073973, 0.11885456449817866, 0.1955878103035502, 0.2587607712484896, 0.15474861109396443, 0.1374983531422913, 0.1439968653721735, 0.14240136661101133, 0.1723913018940948, 0.0883686964516528, 0.15403438301291317, 0.20378321351017803, 0.16299112583510578, 0.16588744620094076, 0.1169170840876177, 0.22503072337713093, 0.09476756793446839, 0.15364241029601544, 0.27700902486685663, 0.2149258038843982, 0.20067588571691886, 0.10989082322339527, 0.10795124995638616, 0.08216406728024594, 0.16766828892286867, 0.18793698021909222, 0.13179717469029129, 0.1976350840413943, 0.17355251067783684, 0.1213940825255122, 0.10792344168294221, 0.12542234879219905, 0.1426417927723378, 0.05805581189633813, 0.20801467238925397, 0.12595412728842348, 0.10446988715557382, 0.07554434749181382, 0.1692664742586203, 0.1531783156679012, 0.13143905875040218, 0.11135197099065408, 0.1392518699867651, 0.16186019667657092, 0.176069667795673, 0.14506325736874714, 0.12669021904002875, 0.1700993420672603, 0.10988893074681982, 0.15426882746396586, 0.11063709724112414, 0.13688854523934424, 0.0635683030122891, 0.1460862485691905, 0.23462004319299012, 0.18041565490420908, 0.10103156892000698, 0.18028579390374944, 0.10075087382574566, 0.10664123314199969, 0.15538592298980802, 0.18713949801167473, 0.08794257752015255, 0.08976860219263472, 0.11978732538409531, 0.10657743070623837, 0.33385922899469733, 0.13272068841615692, 0.1556233805604279, 0.17537288018502295, 0.13810807198751718, 0.10286514123436064, 0.16964186739642173, 0.08694531657965854, 0.07500911800889298, 0.0765242867055349, 0.09626531100366265, 0.1640732365194708, 0.14491277950583026, 0.08360911786439829, 0.10368837596615776, 0.1642729781451635, 0.16428114176960662, 0.15495991538045928, 0.1499473609146662, 0.11350463712005876, 0.10982060121023096, 0.08644528716104105, 0.15428350714500993, 0.14555080386344343, 0.07732064826996066, 0.09917818868416362, 0.1503295372822322, 0.10377635015174747, 0.1718486286699772, 0.1947759007452987, 0.10925489172223024, 0.15485694981180131, 0.12752903887303546, 0.21108355693286285, 0.09140001347986981, 0.15349957655416802, 0.11092129527241923, 0.1267483292031102, 0.09917379516991787], [0.007844097399356542, 0.043178634223295376, 0.0037557565974566387, 0.05018980722525157, 0.028423458206816576, 0.04497891750361305, 0.028030917746946216, 0.009539004986436339, 0.046747730011702515, 0.03357886125741061, 0.03583589190384373, 0.010124715354322689, 0.023638197599211708, 0.022352603009494487, 0.07758806634228677, 0.03788489855651278, 0.022720418819517363, 0.046966285080998205, 0.012529787763924105, 0.027113656615256332, 0.015541552911599865, 0.014169738387863617, 0.061893999300082214, 0.05247514709481038, 0.007076661504470394, 0.012140787348471349, 0.02878174855140969, 0.05156937440915499, 0.03444587899139151, 0.027617298437689897, 0.034127698017982766, 0.03491655646939762, 0.0471932041546097, 0.08538535184925422, 0.030232812387112062, 0.022671630031254608, 0.01893969591037603, 0.08464176440611482, 0.026065486199513543, 0.050898220579256304, 0.011646244256553473, 0.041319595111417584, 0.044812928754254244, 0.03588645442505367, 0.03661883543827571, 0.018499593061278574, 0.009434032835997641, 0.059171126267756335, 0.03651477520179469, 0.05558578857744578, 0.04891214062809013, 0.013752833219768945, 0.049743015770218335, 0.0266326929704519, 0.043136242748005316, 0.049445804179413244, 0.021358581543609034, 0.045787620983901434, 0.08859964538714848, 0.01974648650502786, 0.008578537872381276, 0.08807665391941555, 0.03866110339004081, 0.03963451541494578, 0.08415055170189589, 0.03972015554609243, 0.04883960311417468, 0.012025873202219373, 0.01573770718096057, 0.01967499356396729, 0.058136093721259385, 0.023722199439362157, 0.02494165011739824, 0.04219830909278244, 0.07174121914431453, 0.14993225078796968, 0.03779589278565254, 0.07563272985862568, 0.011381222393538337, 0.03723788307979703, 0.045224449640954845, 0.07964867647388019, 0.021113413058628794, 0.02869024916435592, 0.042679599282564595, 0.054027118894737214, 0.08677523117512465, 0.00367420685961406, 0.05545478838030249, 0.08076475525740534, 0.03070176622713916, 0.014360704117279965, 0.06838933142716996, 0.0413029487390304, 0.022458112289314158, 0.008431466467300197, 0.022767910704715177, 0.057540330963092856, 0.03118398781225551, 0.03432443023484666, 0.04017967854451854, 0.06603272311622277, 0.015656852046959102, 0.0484434372629039, 0.06914378391229548, 0.07968127902131528, 0.029947506700409576, 0.012936685070599196, 0.02647655623150058, 0.014180110829329351, 0.022402883514587302, 0.029049250115349423, 0.0058227881618222455, 0.03628788952482864, 0.06348173148580827, 0.0416573242546292, 0.028353193520160858, 0.017291599288000725, 0.023205544057418592, 0.05201047730224673, 0.024807783374853898, 0.023711295434623025, 0.005051026009823545, 0.05946353245235514, 0.08268293240689673, 0.038548523298231885, 0.02073660056339577, 0.014886486987961689, 0.05192082957364619, 0.013713152438867837, 0.039023137869662605, 0.007122577717382228, 0.006456980718212435, 0.023104986757971346, 0.04409190631122328, 0.026165008202951867, 0.047338178992504254, 0.06761351993191056, 0.042324299793108366, 0.041680601716507226, 0.07441042005666532, 0.03823557075520512, 0.06490932675660588, 0.05056926362158265, 0.03976878848334309, 0.04117445329029579, 0.07538917925558053, 0.06957741337828338, 0.02673155817319639, 0.03481405474303756, 0.01242577762241126, 0.018892810730903875, 0.042665680302889086, 0.034920259786304086, 0.013291041104821488, 0.05873636873729993, 0.03223355903173797, 0.027008544384443667, 0.011272001447650837, 0.06621306500164792, 0.03899631294189021, 0.017098381140385754, 0.03020184627530398, 0.054504694635397755, 0.007591387302454677, 0.051170058140996844, 0.035660548383020796, 0.029775669827358797, 0.021963597027934156, 0.03768882314034272, 0.06266797397984192, 0.05243771316600032, 0.03565325307135936, 0.03719647123944014, 0.028158030945633072, 0.040678112345631234, 0.04721989178506192, 0.010142511127924081, 0.018516742238716688, 0.05803584812383633, 0.024376105757255573, 0.016592290230619255, 0.06900080916238949, 0.019963579543400556, 0.024519048965885304, 0.03381812224688474, 0.025029295902641024, 0.0330882200069027, 0.03099219273281051, 0.08409987785853446, 0.057862133617163636, 0.011596219792409102, 0.03925294760847464, 0.04787999132531695, 0.02314314613613533, 0.028360512951621786, 0.030448339493887033, 0.09754930812050588, 0.061559780515381135, 0.010402696971141268, 0.022460550244431943, 0.007223989878184511, 0.03767062567931134, 0.06074960016121622, 0.05191991302126553, 0.029705175074923318, 0.027408320784161333, 0.060737061576219276, 0.02088705059577478, 0.018456518810126, 0.05513516392966267, 0.0508337947394466, 0.08506042475346476, 0.034656303832889535, 0.03130257930024527, 0.014482292026514187, 0.044214319859747775, 0.017860334883152973, 0.019813977414742112, 0.0453370000468567, 0.013343439513846533, 0.014966926519264234, 0.11269963695667684, 0.08362670676433481, 0.06600752720260061, 0.1226534551824443, 0.02237723489088239, 0.04181785821856465, 0.02639035948959645, 0.025136205986200366, 0.06419340657885186, 0.044422536811907776, 0.010222003493254306, 0.01749993683915818, 0.041713178288773634, 0.018766209614113905, 0.016471095659653656, 0.05636924419377465, 0.049085294813266955, 0.03728096475242637, 0.05888427505851723, 0.04209615246509202, 0.03186631467542611, 0.008523816541128326, 0.02338262234843569, 0.011585076445044251, 0.028148178935225587, 0.059784607801702805, 0.020376146858325228, 0.057629863658803515, 0.05097152621601708, 0.16267278901068494, 0.04432255096617155, 0.049456639535492286, 0.03481622181425337, 0.0761167956807185, 0.021181807533139363, 0.019425802638579626, 0.038035064717405476, 0.00933676974455011, 0.007205312340374803, 0.03546457315678708, 0.05649103062751237, 0.018175285658799112, 0.06529745514853857, 0.06413183058612049, 0.02773369131318759, 0.011481540350359865, 0.08406450710026547, 0.033990734664257616, 0.015078022315719863, 0.03663421273813583, 0.028735711275658105, 0.021203923533903435, 0.053287576156435534, 0.07747279596515, 0.07534286181908101, 0.07655228051589802, 0.019111159854219295, 0.048151465234695934, 0.0400768391409656, 0.12331473844824359, 0.0335860563791357, 0.019203594347345643, 0.023794952176103834, 0.029363542234932538, 0.02181581687182188, 0.061432238726411015, 0.052578053291654214, 0.03228856701753102, 0.07514288270613179, 0.08009996905457228, 0.026109207974513993, 0.040886043570935726, 0.025434643976041116, 0.02259682340081781, 0.06308721320237964, 0.012176573709439253, 0.09670474406448193, 0.048958016486722045, 0.07949613544042222, 0.02397495638433611, 0.04585937182127964, 0.06915397359989583, 0.002731170243350789, 0.029934443045931403, 0.029761726727883797, 0.05779133272881154, 0.06481147458544001, 0.03643264542915858, 0.015267962953657843, 0.02688348693482112, 0.05285947940137703, 0.03139712891425006, 0.016851450054673478, 0.048187203356064856, 0.04272800586477388, 0.08080472733126953, 0.035052892708336, 0.07235025521367788, 0.07547527580754831, 0.08930356503697112, 0.011368924078851705, 0.08118018726236187, 0.03099746012594551, 0.026152349018957466, 0.07476240585674532, 0.05204297965974547, 0.06317017046967521, 0.017191722909046803, 0.03085727585130371, 0.07139440611354075, 0.0560649636463495, 0.07994247789611109, 0.01997904219024349, 0.10369212381192483, 0.03537826138199307, 0.027489008934935555, 0.027061045766458847, 0.10392726588179357, 0.059414858696982265, 0.036632750707212836, 0.07017469382844865, 0.007053843246467295, 0.027168031920155045, 0.010195830727752764, 0.01892716289148666, 0.06704962870571762, 0.04350224400695879, 0.10779285337775946, 0.026810058843693696, 0.04257465589034837, 0.15803880407474935, 0.16459483274957165, 0.11447596742073074, 0.1496032567229122, 0.15666197170503438, 0.0899652935913764, 0.14467045344645157, 0.14351497404277325, 0.1174188130244147, 0.21757429145509377, 0.16486326756421477, 0.13185421616071835, 0.0915613786492031, 0.19991147360997275, 0.18716609658440575, 0.12925701099447906, 0.08133040537359193, 0.09974941975087859, 0.09497637118329294, 0.17316680168733, 0.0864186069520656, 0.16368331213016063, 0.203449247055687, 0.10151000926271081, 0.16209248889936134, 0.10955138714052737, 0.14685797825222835, 0.15435496112331748, 0.10889524695812725, 0.10642319015460089, 0.175748095207382, 0.1406590561964549, 0.1734463093453087, 0.16503430291777477, 0.08215085705160163, 0.12065151924616657, 0.19025020999833941, 0.18027069862000644, 0.11914502625586465, 0.11387831589672714, 0.12535451649455354, 0.12845761404605582, 0.17909279151353985, 0.1816589749068953, 0.11721528644557111, 0.08131625261739828, 0.15478853863896802, 0.12388838149490766, 0.09966126002836972, 0.29489163716789335, 0.1676623072125949, 0.15992918779375032, 0.10598046937957406, 0.145212369679939, 0.1861179614206776, 0.07684672018513083, 0.13420407834928483, 0.11193583341082558, 0.1627138297772035, 0.10410187838715501, 0.07939819421153516, 0.19437946029938757, 0.2200030439416878, 0.13190725003369153, 0.2062572370050475, 0.1458819946856238, 0.23789757513441145, 0.1309503396623768, 0.08740841672988608, 0.11650103610008955, 0.19177673355443403, 0.13426140183582902, 0.08799763745628297, 0.24358477152418345, 0.10023671391536482, 0.25618813117034733, 0.11038662982173264, 0.1977230136981234, 0.13477545784553513, 0.1515309259411879, 0.13099423027597368, 0.13507157476851717, 0.14487006148556247, 0.1751228654757142, 0.13648003747221082, 0.14296631910838187, 0.0992257083998993, 0.1308682284434326, 0.12295757245738059, 0.16626954835373908, 0.12596579384990036, 0.17608694499358535, 0.18082459311699495, 0.09060677635716274, 0.10487187886610627, 0.1023398268443998, 0.07446642994182184, 0.17218232795130461, 0.16897199006052688, 0.214945545012597, 0.13857799989636987, 0.1560266042361036, 0.06172759494802449, 0.11690264931530692, 0.09807683411054313, 0.2512996637960896, 0.24814267148030922, 0.1303212804486975, 0.10286759032169357, 0.14224115177057683, 0.13818491395795718, 0.12805630511138588, 0.11690284227370284, 0.11137769382912666, 0.20462541753659025, 0.1962994853965938, 0.1339854416437447, 0.14804171863943338, 0.11380731462850235, 0.1356129121268168, 0.20287703635403886, 0.08514120010659099, 0.16660919965943322, 0.2000421064440161, 0.2334160273312591, 0.12365770715405233, 0.11888141540111974, 0.14186068234266713, 0.07594712587888353, 0.110638722544536, 0.11857541307108477, 0.15004618529928848, 0.1367734678206034, 0.12106364127248526, 0.15526072267675772, 0.14042955444892868, 0.13147876365110278, 0.10440324229421094, 0.22168065392179415, 0.08442606660537422, 0.13207383250119165, 0.11775299470173195, 0.15681173710618168, 0.21070040093036368, 0.09468578326050192, 0.25836737360805273, 0.09526499983621761, 0.21297833416610956, 0.15651900437660515, 0.10032419086201116, 0.14803880942054093, 0.11911696565221064, 0.11857231831527315, 0.15593662625178695, 0.13574448006693274, 0.14898905530571938, 0.15073846065206453, 0.1177077904867474, 0.08226699574152008, 0.1812068882281892, 0.1069481557351537, 0.09034261631313711, 0.08227265090681612, 0.14587242098059505, 0.14732535317307338, 0.10532064814469777, 0.11966176884016022, 0.1330103338113986, 0.11099146533524618, 0.19313339435029775, 0.15252917393809184, 0.21063372638309374, 0.11354735514032654, 0.1314689079299569, 0.12861491966759786, 0.07563542385469191], [0.04559468856314197, 0.01794792500732001, 0.03281720251834486, 0.049463226096122526, 0.020195333709125407, 0.09570121939759701, 0.0804871846048627, 0.027101756277261302, 0.12261414362001233, 0.017790463534765877, 0.03414880840864498, 0.026380739400337916, 0.04969224915839732, 0.0484998516185442, 0.03459615276369732, 0.08249229693319649, 0.03944632531784009, 0.015280096140486421, 0.04419776254508179, 0.06574631348485127, 0.022333457454806194, 0.011417645146138966, 0.03311798383947462, 0.03783322281378787, 0.0422355649061501, 0.018109529519279022, 0.031220353048411198, 0.019153914981870912, 0.005345443414626061, 0.039111249352572486, 0.04006348790426273, 0.04480231233173981, 0.10366016693296842, 0.035761673425440677, 0.02457981972838752, 0.017808915181376506, 0.020043494005221874, 0.05382502466090955, 0.014970907213864848, 0.10205687562120147, 0.04411584428453352, 0.008217798440455226, 0.10049618358607404, 0.06736531606293283, 0.027359897503629327, 0.032285357228829525, 0.02329708240722539, 0.016311292711179703, 0.01710925545921782, 0.04211563755234238, 0.04601985383487772, 0.052177824181853794, 0.039620381212444045, 0.03213863092241809, 0.032135105720954016, 0.05815725977299735, 0.0056927564673969755, 0.04797413646883797, 0.06315572827588767, 0.12140752281993628, 0.05341944095562212, 0.013674725887540262, 0.02385599753324641, 0.030385420213860925, 0.039517330296803266, 0.009751648849487538, 0.02609286217193585, 0.07417404602165334, 0.02514264968340285, 0.02034235130849993, 0.02866795133741107, 0.049751736005418934, 0.04308770257921424, 0.04866737290285528, 0.018029353450401686, 0.041252668233937584, 0.07242431413033046, 0.048319431807613, 0.022894337416801136, 0.027808106460724957, 0.012213629142934224, 0.045812698153895326, 0.02083186078380095, 0.02322495864063967, 0.005781990912510082, 0.0167006382253021, 0.010378495535405818, 0.037185157198109664, 0.0349390249903081, 0.05123638016812038, 0.05190607567783445, 0.031627361677237786, 0.03803618536039721, 0.0499809631583048, 0.005726541348849423, 0.03683903436467517, 0.02358522866416024, 0.04045266643515788, 0.03955539134040009, 0.06542768722283654, 0.034080530822393484, 0.05849860317539424, 0.033678798863547854, 0.023578638392791618, 0.06365875597111881, 0.0445076945470646, 0.03726294540683739, 0.06697864228044637, 0.06345883622998372, 0.013570825212809723, 0.00860716900206171, 0.035871129075530916, 0.037655548949260265, 0.0865613367932383, 0.04643858839699533, 0.050951595840160735, 0.08973106436314993, 0.04429236039868556, 0.03059954095078865, 0.01733474404318258, 0.051355635878280737, 0.03564431761333253, 0.00884903771293466, 0.07587030617287382, 0.040724659847910516, 0.054721999185858294, 0.032001411527744494, 0.02041238964011427, 0.019607098183769267, 0.07154450548114255, 0.02207226414611796, 0.03537571210472379, 0.015345714055001736, 0.03617333903093822, 0.04258249668055214, 0.01887694546894636, 0.026412527440697886, 0.043856986885657534, 0.08029673466808163, 0.03850085515296087, 0.029388892144197598, 0.08252156723756343, 0.04519894573604688, 0.025671745315776207, 0.05554987605137285, 0.059010351105825976, 0.02532011945731938, 0.0226433913121582, 0.02904987723013619, 0.014082940506341401, 0.013055700510449242, 0.06464045407483354, 0.029114006210875232, 0.025991013535531238, 0.005720830522477627, 0.03938000700145494, 0.04748384402773809, 0.05749615462264046, 0.07017002571956255, 0.03134582053462509, 0.06450887129176408, 0.03507833353069145, 0.03460639811237343, 0.006244779360713437, 0.015242645513353636, 0.03156362603476737, 0.02813148617860861, 0.03391860162082594, 0.06359389226417989, 0.05230546616076026, 0.04912971977319103, 0.055470392035203986, 0.025472153974988032, 0.031908264572848566, 0.021596810947812628, 0.013152644478395814, 0.036085862084291875, 0.052334606589283794, 0.006863995376988896, 0.027629653341136873, 0.04208308324450627, 0.040395547039224766, 0.04464547055249568, 0.052760933322133496, 0.029121941624907777, 0.05857017218659166, 0.05791852941911202, 0.03381765469384845, 0.013793338712275727, 0.022626685567956883, 0.020747601047332864, 0.060443753682193346, 0.008677173009346006, 0.0032620066758681787, 0.019100215031357948, 0.021754611952928826, 0.04853735605138354, 0.029311723628779873, 0.010100089966726955, 0.02829597764502978, 0.018181725645263214, 0.01131700806581648, 0.04435791059222538, 0.018544737904448994, 0.04796574648935348, 0.04357726400485262, 0.0013242305658422993, 0.03397494918317534, 0.10427137749502435, 0.031564049058943056, 0.03572596498997882, 0.023638307065994013, 0.09164472183329053, 0.0387246015452547, 0.02017093931499403, 0.044645429734373465, 0.08877389424014837, 0.02054176824458409, 0.021843326430825982, 0.0561167952400865, 0.04925081229885109, 0.025422660146432463, 0.04566271752992179, 0.04285617847926915, 0.052202556253178045, 0.11432842104113661, 0.039382912509609014, 0.011530575902725104, 0.04381557504530065, 0.004938950578434742, 0.050862267235061154, 0.01813458071410423, 0.035963392874691635, 0.027375655154173728, 0.04063971733557992, 0.16101324290502816, 0.023515667162428144, 0.032744557393016294, 0.05565438899793662, 0.03570990862499457, 0.03326063204440288, 0.02626218873047037, 0.03560387056495529, 0.029160243866499513, 0.06273423292441294, 0.04305024638597388, 0.017042057697835844, 0.011186409556103172, 0.0738360793911852, 0.053250487326295115, 0.031223069308907725, 0.05361240306228865, 0.06404978616046719, 0.01920531427458627, 0.0026294549616068252, 0.02837605537933996, 0.05682055532815866, 0.018883044067479204, 0.007455150789610343, 0.007336137668971787, 0.04071386902069207, 0.03732069191755727, 0.02257187425129814, 0.06288710792432539, 0.06904820271302015, 0.05504242144525051, 0.07811911011231132, 0.039887376260594465, 0.032788028693175875, 0.059727744446718134, 0.03251445450587198, 0.044735801056958735, 0.03468178918410558, 0.020502558727457654, 0.062827439251123, 0.12430962451617233, 0.03927626588847488, 0.02628375183121534, 0.05762774482718669, 0.030757271451875567, 0.027566503995331004, 0.06241317983949557, 0.031188225475489162, 0.010111512547155144, 0.01875025158369681, 0.031349201017292216, 0.04813530125829857, 0.04391160524392035, 0.030623683014709968, 0.014820789292571135, 0.08420929269050248, 0.02724834714172175, 0.064392784552183, 0.043198130442760885, 0.016677418279869016, 0.025264079886255786, 0.013514238307834603, 0.058719889348139986, 0.0454559811623767, 0.03802217361226212, 0.04051246498420369, 0.038062386884121224, 0.05170419295609463, 0.031929297038004734, 0.02552861100411974, 0.054469683818751946, 0.012355818143987563, 0.03291523280495312, 0.0179439211206045, 0.007623395204063854, 0.026334960020903964, 0.009537737769278465, 0.014212112237146357, 0.029474257680703886, 0.05094690917758271, 0.05934985398198478, 0.027994034862786066, 0.03771820476686116, 0.045414361520670354, 0.03500001097563654, 0.030067738334764726, 0.04618910432327539, 0.052148791364743374, 0.017736798836267553, 0.044295844782027416, 0.04292354693461675, 0.023623816632607486, 0.05558489428949542, 0.04020723077701405, 0.06332509379717521, 0.03954936139052734, 0.021628263166348916, 0.043246741115581244, 0.061633913646801375, 0.02398806271230569, 0.02907569654780673, 0.028477952255343553, 0.024260733334813267, 0.053763649048050866, 0.029054725309833884, 0.036678181277238764, 0.04746441831230186, 0.0315573994157603, 0.018422958892188035, 0.009909698474075412, 0.04793669140781276, 0.03054615641303826, 0.08174525850336067, 0.014090053064137464, 0.04359773243777454, 0.009635595506551908, 0.018469927563273814, 0.09514053424936719, 0.14341432397486642, 0.08965322791482322, 0.19503023475408554, 0.23623777669854462, 0.20424928225111216, 0.17704099067486823, 0.12972873490070924, 0.13315672986209393, 0.11380112511687912, 0.17052999552106485, 0.1104983378900215, 0.13855171302566305, 0.1115757210936863, 0.176910639856942, 0.13252784876385704, 0.1478491016314365, 0.1278639998054132, 0.19173012668034062, 0.2286396687850356, 0.14921478694304824, 0.21683147584553808, 0.11820439118309878, 0.14512558293063194, 0.11737996901501901, 0.08059059546212666, 0.17518198495963588, 0.13330507033970207, 0.06195038396981545, 0.10470744862686843, 0.20374946063384414, 0.14054423110792413, 0.21577045699814335, 0.13316943543031812, 0.18151136173401028, 0.09597879747161642, 0.21121592639246956, 0.183029142790474, 0.07842346487450413, 0.24186892609577626, 0.1903264582506381, 0.08283389266580343, 0.19100286648608744, 0.097866079013329, 0.10969544542604126, 0.0746168929617852, 0.09294643401517533, 0.21602145134238526, 0.22152941906824708, 0.14728765207109973, 0.23983600549399853, 0.16426989081082866, 0.14862718409858644, 0.117126562690828, 0.08718091135961004, 0.146010979951825, 0.1190388471877668, 0.12778176984284073, 0.10556055480265059, 0.2764289325568825, 0.10841248731594533, 0.15794740116689354, 0.12088027884601615, 0.06834800122305751, 0.1147973990009632, 0.09716195898363367, 0.11182443704456091, 0.18950818106532097, 0.21583609253866598, 0.1202710423967801, 0.12478479940909892, 0.17638163699302822, 0.2130594805930741, 0.12254503482836299, 0.07445763549185358, 0.10467779240570962, 0.16632428916636854, 0.19542099034879357, 0.14070913632167503, 0.0978660344844684, 0.21874709258554503, 0.1639479471486993, 0.13485517934896052, 0.07882315592723899, 0.10255211818730459, 0.1491271541453898, 0.14908868120983243, 0.19414706417592242, 0.141919668240007, 0.19806821626843885, 0.14098288491368294, 0.11898881901288405, 0.126469726965297, 0.1790738370618783, 0.125473928055726, 0.1522704612580128, 0.10153121984330937, 0.08989461886812933, 0.201964461884927, 0.20792546623852104, 0.18080212088534608, 0.1248350428068079, 0.18372673192061484, 0.09507103211944923, 0.13992548774695024, 0.19061083439737558, 0.15726340818218887, 0.16125751339131966, 0.14302272233180702, 0.1295559183927253, 0.13946838414995, 0.12155786709627137, 0.1348073553526774, 0.1606773617095314, 0.10940474618109874, 0.15962891484377906, 0.13750115846050903, 0.13907745043979958, 0.09087521859328263, 0.20557757816277444, 0.14190921880071983, 0.15067217202158645, 0.16646923060761765, 0.1370639295782894, 0.14298555557616055, 0.15103696729056537, 0.12382984088617377, 0.1358040003105998, 0.08340182117535733, 0.120054439175874, 0.15220537490677088, 0.08040181535761803, 0.1257017080206424, 0.13441415067063645, 0.1453947598929517, 0.12777317577274516, 0.09561950151692145, 0.0752255431143567, 0.23052971111610532, 0.14163524756440893, 0.14423341752262786, 0.1489462036988698, 0.14908648445270956, 0.10088523966260254, 0.08828955382341519, 0.14323971146950498, 0.1638802484376356, 0.14952576166251674, 0.15388286614324898, 0.12707459216471761, 0.21955171425361186, 0.1604776646126993, 0.12138646809034981, 0.14585147757316008, 0.08054119069129229, 0.10319202017853968, 0.11361011114786379, 0.16093742509838194, 0.14454746473347768, 0.09779321495443583, 0.2110255803563632, 0.1099704482476227, 0.12457511300453916, 0.1033947452378925, 0.11985633769654669, 0.1274998130975291, 0.21782179770525545, 0.09547654903144576, 0.09882540136459284, 0.12909066601423547, 0.07679349335376173, 0.22112383536295965, 0.08906601098715328, 0.08641612075734884, 0.10553709551459178, 0.1358993662870489], [0.03836918702290859, 0.02656063970789546, 0.062376109563047066, 0.01990614659007406, 0.08868488104781136, 0.016136541053128894, 0.07338679803069681, 0.00981735118330107, 0.0315791777393315, 0.06572560014319606, 0.0463021742325509, 0.042314763195463456, 0.04165139820543118, 0.03964480900322087, 0.035179978076484986, 0.0608891907177167, 0.06575087027158588, 0.035026327532250434, 0.047912382360664196, 0.022159811596793588, 0.038927233836147934, 0.03505011336528696, 0.06397681820089929, 0.02215670199802844, 0.031948292307788506, 0.052186499888193794, 0.014595202374039218, 0.010235654372081626, 0.041272717353422195, 0.0459214376314776, 0.04440853248524945, 0.03611908803577535, 0.01987523242860334, 0.08603604466770776, 0.06258510577026755, 0.010356165239500115, 0.05512407995411195, 0.09615628950996324, 0.037283551137079485, 0.017060969476005994, 0.01354950609311345, 0.04985896892321762, 0.0690820075396914, 0.019133539317408577, 0.023483101722376887, 0.0664852699264884, 0.007807084639352979, 0.015082787831488531, 0.07381595234619454, 0.040942513587651774, 0.060201108499313705, 0.057446779537713155, 0.04248466306307819, 0.06640903651714325, 0.04403859784360975, 0.022702748283336405, 0.03163144348945934, 0.014500187990051927, 0.015620945086993743, 0.06733092493959703, 0.006402595208783168, 0.05621068434265908, 0.08641280335723422, 0.0557915898389183, 0.014981227704993216, 0.058583178324624896, 0.03256824165873695, 0.06291139099630527, 0.011221606837352738, 0.1229599844373297, 0.027652381613734178, 0.05780214582046028, 0.0849309645127505, 0.02202038431278197, 0.021561063549597748, 0.0191841278137872, 0.02624391891004052, 0.024696993714314885, 0.04292389945476316, 0.09222451728419401, 0.050676704340730794, 0.004809625779671478, 0.04069685899594333, 0.038021119762561284, 0.08948709073592909, 0.035080723246210255, 0.023585145172546618, 0.03389411445823498, 0.03747943359485362, 0.025516829409752972, 0.028660902789852116, 0.030169460806064308, 0.034179280992248096, 0.06604817463085055, 0.04748351748276036, 0.0342534215451451, 0.02346010627661599, 0.043972123676212505, 0.013302721581567312, 0.03403029855689965, 0.01720141535770381, 0.043276946526020765, 0.04508413920120802, 0.045642994955414906, 0.0380328011669917, 0.0261510354175698, 0.011360894968674984, 0.0541979575791629, 0.062080987117951736, 0.009393654436280485, 0.04428393702255562, 0.03842230624286458, 0.011633137928583892, 0.0725687805970665, 0.032786481315270066, 0.06123794817540329, 0.005234908403508598, 0.013042528316873359, 0.0643693252641242, 0.04344951070379466, 0.017079261560866144, 0.07201925734989345, 0.04598465377057437, 0.017965250444831327, 0.05089185666292906, 0.03217378274712246, 0.016956886975094676, 0.02382791652053129, 0.05525834560103249, 0.021230928432487417, 0.05347779231669847, 0.07221654246677645, 0.05546495951421093, 0.01915742534038145, 0.02568937503383495, 0.04597040453518275, 0.029605998170154635, 0.011267048539593816, 0.02725211910728831, 0.062163243055692874, 0.032283164182445034, 0.07737408290267922, 0.022486545822175685, 0.030316829070216045, 0.04163422490819357, 0.04794472144567408, 0.04268454940756783, 0.026774116631713696, 0.0299414155233535, 0.041256983822677284, 0.016892533494683448, 0.02843794492946472, 0.018553827358118724, 0.018280169679201208, 0.022771428484702483, 0.008043929938139627, 0.034120465788873844, 0.007219908529805252, 0.03098740773566533, 0.030235055528464727, 0.046032399841351435, 0.04762379081512336, 0.0719750253483653, 0.04592231707647443, 0.01666677217144752, 0.0425418937811628, 0.042849625315284356, 0.034850783631554805, 0.0919545981741976, 0.043216825142735615, 0.04563064190733712, 0.04850951809203252, 0.03101889891695464, 0.011707825815392425, 0.014684499437862542, 0.03179692386765964, 0.03454949393926654, 0.030139732225507032, 0.02442728611640632, 0.04392064831336029, 0.06260487658437341, 0.0326867255353136, 0.03745000372873619, 0.027810112114821095, 0.010538676979194861, 0.07358184186159633, 0.03803316853009164, 0.009715138894534903, 0.029652809134859126, 0.03019751027750317, 0.0523776511545293, 0.016806002786324825, 0.09727535914862528, 0.046227191342040896, 0.03824883664492518, 0.06330331176286563, 0.04891316108114552, 0.033481773498351686, 0.028453153390728403, 0.02036840254731942, 0.023293186131922994, 0.026312851441616658, 0.057453985791653395, 0.045847653309465386, 0.03994990220235195, 0.07144425617298111, 0.04459258139831945, 0.0388329588167835, 0.052102785630268045, 0.06373853684635833, 0.006859175591671374, 0.08069463714491576, 0.03277955707744695, 0.04459243667952251, 0.015239026615745388, 0.022472461714642122, 0.005018870142521337, 0.02280628901644377, 0.04170220192463603, 0.025549686142767314, 0.035458216661936603, 0.041541389655321836, 0.059067040056106634, 0.038543532355106436, 0.08710338661330752, 0.041889482890837826, 0.04101865422853734, 0.03079928814258892, 0.058536059368634596, 0.0238706067102612, 0.07600426382850856, 0.04750088002765551, 0.05605880382063333, 0.01948363264091313, 0.07636347072548233, 0.06259371468331665, 0.024503282038494945, 0.05170936943613924, 0.010447237891639816, 0.04732445297122467, 0.08458283788058907, 0.07287101281690411, 0.03859170887153596, 0.09427076685824431, 0.02375915468292078, 0.018883665616158396, 0.036555496844812296, 0.012096531227143714, 0.02157099348551128, 0.017329851434624288, 0.013022520015510963, 0.04248346078384202, 0.05887456034542993, 0.022503314648929518, 0.015888823290879373, 0.033617015069467016, 0.027122504870931152, 0.012340026169113116, 0.10294178282492794, 0.06923634457052685, 0.03699236949614715, 0.02775588152871933, 0.0058335168341727694, 0.0284386796556646, 0.060582472215173766, 0.07089250648277812, 0.02556115603510989, 0.03477920348814223, 0.06213562402990647, 0.0626403364003636, 0.06000398665491957, 0.034533318830654025, 0.02723039830016205, 0.019847223775286693, 0.03812985552940518, 0.021724042890127748, 0.032448692800244316, 0.012157772325736005, 0.07104793447069824, 0.03878269315464422, 0.060422268506954424, 0.03270841851190198, 0.014582766762032406, 0.032496876738150604, 0.029651532640855294, 0.0361209137190599, 0.04838039923924953, 0.04265276322257705, 0.04422925558174029, 0.023857160849729553, 0.021812803752254695, 0.029264754957694095, 0.046916390492697246, 0.05296734314470086, 0.04929659538902342, 0.07239505124744028, 0.09345170299638994, 0.025356009718962014, 0.035717445134650916, 0.06842431626864709, 0.05852392525412142, 0.006973118915993837, 0.051916510274168104, 0.04729813641461078, 0.08798749229754321, 0.04116543619602453, 0.04745457001263276, 0.041727857969817705, 0.09752987869433127, 0.09616686511435546, 0.04807594057638198, 0.0369290605885908, 0.07078015274601057, 0.03395708197786007, 0.03600395124522038, 0.023266598691407125, 0.01735986388666788, 0.04741426026157569, 0.02352717416215455, 0.04343419648648705, 0.035467400739435107, 0.09999863294069655, 0.007889288626756752, 0.08712252660188824, 0.018996249418705702, 0.03812928778643254, 0.008033889607759193, 0.019093144219368696, 0.014112137523625279, 0.023327439957938623, 0.009691659197414992, 0.02504461197531782, 0.0615672242565779, 0.06321064720395952, 0.011666051250358578, 0.058402688009664416, 0.02530145073251333, 0.03589355677831918, 0.06374599543050863, 0.04839129025640432, 0.03951671802497003, 0.007794097055011662, 0.06699757446767762, 0.030531378397427034, 0.03773480289964937, 0.08629037125501782, 0.05091967977932654, 0.04931493756885175, 0.03315627123811282, 0.004392913106130436, 0.011620697678154102, 0.02100772751873592, 0.1179149684321601, 0.11101787837105803, 0.16736596764530987, 0.1234854398353491, 0.1333666982827708, 0.07415149215376005, 0.1761384351993911, 0.17604110995307565, 0.15897960984148085, 0.09039924218086526, 0.08942619751906022, 0.09221893633366562, 0.11082339857239276, 0.1898203432210721, 0.17422648466890678, 0.12946694972924888, 0.20837418356677517, 0.17507201351691037, 0.1422886343789287, 0.10838836009497754, 0.10783871068269946, 0.140775142936036, 0.1810243198997341, 0.09747346804942936, 0.19584434106945992, 0.12082841014489532, 0.10811856715008616, 0.1416055765002966, 0.13482589420164004, 0.15634228417184204, 0.15002387634012848, 0.12922564783366397, 0.18842670862795785, 0.15949029650073498, 0.10450498331920244, 0.18436518672388047, 0.2891002135584131, 0.20118943706620485, 0.06796001383918338, 0.13162147864932194, 0.07983480711118318, 0.16286879021208733, 0.1391087839147076, 0.11760092122131027, 0.1941958232782781, 0.15780936169903725, 0.07601204895763658, 0.09383585347677581, 0.15193466912023723, 0.19457228510873392, 0.1119315586402081, 0.07371339495875873, 0.10835210618097335, 0.1293190396972932, 0.1589913506177254, 0.07862774844397791, 0.11535026933415793, 0.12012409715680405, 0.2905167656717822, 0.22909680206794292, 0.17567686387337744, 0.12113632721593603, 0.22908970713615417, 0.188860330672469, 0.1982669040444307, 0.1862194575369358, 0.15407986182253808, 0.16649320197757334, 0.13621666410472244, 0.1760096280486323, 0.12127947265980765, 0.1569164838292636, 0.1777884372859262, 0.1518686773488298, 0.1472872809972614, 0.08815648674499243, 0.14141808031126857, 0.1481955955387093, 0.09472323945374228, 0.2833484800066799, 0.1734656942426227, 0.1067659213731531, 0.22023597441148013, 0.18730936077190563, 0.2342827370739542, 0.1362615788821131, 0.13480511406669393, 0.14773117436561733, 0.14618829387472942, 0.13653878588229418, 0.161403909442015, 0.19999680574983358, 0.13459784706356004, 0.13679899770068005, 0.1407310296781361, 0.12837266782298684, 0.11118716225610115, 0.18804880703100935, 0.11687886348227039, 0.11556275363545865, 0.16811762965517119, 0.1277999227750115, 0.12283432399271987, 0.24603043013485149, 0.23312042991165072, 0.1263488904805854, 0.14917428052285686, 0.11964475139393471, 0.202380895789247, 0.12878838926553726, 0.20588233368471265, 0.15619216253980994, 0.13619687844766304, 0.1478103021509014, 0.09573604838806204, 0.12457656761398539, 0.12294749409193173, 0.1149697405344341, 0.1369579805759713, 0.14461192768067122, 0.13519621104933321, 0.18700847926083952, 0.17340194375719875, 0.13699636445380747, 0.16196080221561715, 0.11635284405201674, 0.13773512793704867, 0.07708646357059479, 0.1737408380722627, 0.13521221175324172, 0.10739846868091263, 0.11139823647681624, 0.21980011108098552, 0.14701038569910452, 0.1561371100251563, 0.22676874417811632, 0.1324367427150719, 0.10246319405268878, 0.12513221357949078, 0.2194755699019879, 0.05673897103406489, 0.1259691038285382, 0.16006194317014888, 0.11516229817061685, 0.13406847312580794, 0.12602923263330013, 0.10866773416637443, 0.1828515320084989, 0.10765715909656137, 0.14325848780572414, 0.09090016959817149, 0.08934895478887483, 0.07113032028428279, 0.10111839277669787, 0.07120385227608494, 0.08752284848014824, 0.1677932814345695, 0.14611352991778404, 0.09375130059197545, 0.1501115833525546, 0.17041028710082173, 0.1504876889521256, 0.24330796528374776, 0.160025488876272, 0.12213248235639185, 0.13795659964671358, 0.12058226944645867, 0.1698439393658191, 0.19949990819441155, 0.2341212605824694, 0.22321893309708685, 0.16402864828705788, 0.11285543601843528, 0.13200920628150925, 0.10498672621906735, 0.13594079297035933], [0.022359278627845924, 0.04359891616331879, 0.04249291945598088, 0.0076725685175915714, 0.030957187482272275, 0.09632569213863462, 0.032045020125224255, 0.029215053327789064, 0.0038238208162511, 0.06729877510224469, 0.04821842550882138, 0.014759717032575281, 0.055296417776844464, 0.07801091982400976, 0.03807187524216715, 0.024600724173069466, 0.04094729301868938, 0.1047555917466525, 0.026621646102285013, 0.04147921623371076, 0.021214079824858345, 0.012714728181890678, 0.06556855427334085, 0.00950319543335354, 0.02384509723924566, 0.040163436642615125, 0.027461475256131962, 0.03438408406509552, 0.009894923241517972, 0.03850022432743572, 0.03183124448696617, 0.026200429056189023, 0.022312643923214637, 0.007538180416304385, 0.0699993985472247, 0.023963256426213775, 0.03246617779950611, 0.023687652465014253, 0.05515022581676021, 0.05678262787114363, 0.06507866259198636, 0.05857960117282346, 0.13129520084476098, 0.057116724201478064, 0.05366909572330769, 0.028485164075391367, 0.0241476764131221, 0.030032208014745265, 0.013713102343899664, 0.007943826276459731, 0.036192115367157385, 0.031032736260385718, 0.049465623233118095, 0.05049226208939217, 0.05371100480260793, 0.02893983713875059, 0.013606200609501684, 0.0345671422110172, 0.007128519073376083, 0.02169131603295682, 0.01162199272584985, 0.01914805943670217, 0.07999373061466031, 0.1097598861088045, 0.06024971546139568, 0.02813712093484355, 0.02643786065164022, 0.07902914643636905, 0.07652748536202125, 0.0824782183917705, 0.03397750588192139, 0.03372104933077935, 0.05286946128762793, 0.012839915507356636, 0.01901909643493127, 0.04455433110706508, 0.022707303214701824, 0.04776431276695803, 0.009966212091967463, 0.046573711224482395, 0.03263346901803743, 0.05491559211804997, 0.020780552404175978, 0.05253850053122733, 0.03158202758640982, 0.0434491470514331, 0.021195099398028105, 0.08589017554186285, 0.04271920399332885, 0.013074438811599975, 0.11641003395197913, 0.10599090397590771, 0.1648818954708986, 0.05208781651163008, 0.02223211162345251, 0.014696969374199398, 0.057442040924797766, 0.04057744372403249, 0.060339322371874005, 0.04357765363238286, 0.009966108191292733, 0.03232625327655114, 0.06370786388288252, 0.019956579235440586, 0.011765238359657815, 0.011313029226585058, 0.02796615422994364, 0.04527961718849838, 0.011837108868348878, 0.03638295122073032, 0.10629320298903622, 0.02769328322756337, 0.0841987987223547, 0.05008239619201049, 0.02619917482661549, 0.009055527316377265, 0.02842500001861481, 0.03781247607548721, 0.03829925444733817, 0.05372502397221979, 0.06934351069503464, 0.034331699571339414, 0.0599303915805649, 0.022953284351387993, 0.04790337639860809, 0.04669113754061982, 0.013613472729048226, 0.025277427412220277, 0.027474687340145465, 0.027255868808424566, 0.018758027435978875, 0.02781914776278427, 0.05808080743008759, 0.03062976677028928, 0.10861925708013587, 0.04868344411079306, 0.03972083090047818, 0.023404808853229042, 0.024358527989534196, 0.039267215397558175, 0.03757825797947589, 0.020634505162888672, 0.06416062591597438, 0.06264667434152216, 0.021094195144542027, 0.038058657592046075, 0.023276625106518622, 0.025224421369784977, 0.012906214342365274, 0.08566477787098847, 0.02662348106241552, 0.03923141790437512, 0.050384279602440074, 0.028626919847738463, 0.016426362708443776, 0.058782764099305496, 0.05354630739020649, 0.031175835320027545, 0.044519253497128375, 0.02318616843695054, 0.029813177970936522, 0.03137112034892198, 0.030507316114380956, 0.054427589202532545, 0.03958495108236093, 0.022560652978427242, 0.05288448235660326, 0.03846613006317057, 0.05089777157991193, 0.031211918540066108, 0.08180811099009588, 0.03754864628717769, 0.03587789375160355, 0.05845582578331232, 0.0520270828565117, 0.02945023250504164, 0.03204907596227713, 0.03455691541603301, 0.04038401035359129, 0.03239773694076575, 0.029443293424264994, 0.06751358974725008, 0.06269469871767797, 0.053215543302940205, 0.011262675434409175, 0.03641209164925385, 0.026762741363199893, 0.017289797724515665, 0.08765807520831004, 0.048891616534092464, 0.08744789156480692, 0.029934402227809187, 0.12087296126992442, 0.03996856350568123, 0.008887847398000304, 0.09370407773531042, 0.023112567796488293, 0.061846639146097004, 0.023911582538858056, 0.03037064405361889, 0.033649090692051686, 0.044164514329168014, 0.01315323634116794, 0.011983140338998055, 0.04672709459555335, 0.03070724142162362, 0.06043156019586604, 0.11591937785851769, 0.02600734449515585, 0.027119434234919026, 0.05650427796354052, 0.012715239336102968, 0.029384700865193736, 0.0663651162176393, 0.04577415471430868, 0.019288553557998966, 0.036887270252918825, 0.02401978210400557, 0.07680964248720556, 0.015595906879752874, 0.006705151654387009, 0.03581170160032343, 0.008942361855588388, 0.05462106339109596, 0.02946957843960263, 0.03707347881572787, 0.04709459870355204, 0.032987926169880666, 0.07511719697504304, 0.05436764593468979, 0.04967565102560911, 0.03423889400437474, 0.05174133002583403, 0.031930814730003476, 0.02101712681906065, 0.04916142803267576, 0.018485648106434382, 0.06888274830998853, 0.04144937818637118, 0.026313352391298395, 0.08590418728999794, 0.024882185534806922, 0.03575932823878247, 0.0431336118344916, 0.06089371410780586, 0.025837478024186566, 0.07052069791825488, 0.010873674091271823, 0.053439779512700625, 0.06789005899918266, 0.061238861017045565, 0.03497861485811882, 0.03925458775484003, 0.05974340376269538, 0.039601423050044104, 0.036295166282798164, 0.09926741709932685, 0.002691508711905044, 0.026246024754073005, 0.017854889374575578, 0.0512441430328181, 0.05233350821072236, 0.0712203056900762, 0.06449038439313881, 0.046711969625903293, 0.016487962820974644, 0.05485652087372728, 0.056828603919711895, 0.0922037148848176, 0.029861404582334217, 0.03676660817291122, 0.03916574896720704, 0.0216644521424314, 0.07344162790104747, 0.05311748704116326, 0.04144294005527627, 0.009940197960531805, 0.018868481274694204, 0.07075370260281488, 0.013781829857180128, 0.022059059483581223, 0.05033961344452109, 0.05059518683992792, 0.018209925401606597, 0.06183872414112557, 0.05025309386837762, 0.057671234681038186, 0.026734022103482857, 0.04766796715557575, 0.08037393286940642, 0.00400859146793664, 0.06480309573817067, 0.08168126310920343, 0.042862546106334776, 0.049914600313059054, 0.014942096113372827, 0.07486494097975083, 0.02122139740095008, 0.028954190274816938, 0.04384582498460077, 0.051673089546966366, 0.05891199427423999, 0.050960742810275406, 0.030377505208889488, 0.039466834568884224, 0.026097984846273903, 0.026271326423739083, 0.027325012852088548, 0.05284853272314649, 0.038915596960578114, 0.04050551477121189, 0.09894354385323822, 0.00959559838520363, 0.039610351086594164, 0.019529803503246512, 0.00902210284039029, 0.024303709251398686, 0.010337203366361791, 0.052124244830338284, 0.024397108536504675, 0.008197359693440376, 0.019683326027006842, 0.06544129821122624, 0.016821209392219316, 0.09527221351163462, 0.06331576500087976, 0.016608873520453926, 0.02030982112046331, 0.036821044704993255, 0.03750139003386721, 0.026706317730713636, 0.04798684945853893, 0.019885633628291544, 0.044729099463438615, 0.016506002575624734, 0.05968830671918113, 0.047543527543894015, 0.017411621265637223, 0.03632245505286846, 0.05593999339907896, 0.04067827932885848, 0.03359084694238845, 0.04358711601526011, 0.0509659452654887, 0.005228198924669414, 0.03162194770993665, 0.08098572230665013, 0.06798457150580361, 0.014699700477649458, 0.027155626921739895, 0.04144639846344944, 0.04246782002155669, 0.1034950687608216, 0.15068587206769735, 0.1174969389103353, 0.11180982415680774, 0.136024477542378, 0.16561144147999585, 0.1539713004603982, 0.11462617068900727, 0.1266416083672084, 0.09426255128346384, 0.08855132415192202, 0.07880429053329863, 0.24766913673374802, 0.17154644097900018, 0.15021722065284848, 0.15591727104038, 0.22640393406618387, 0.15375149116152897, 0.13200487213907763, 0.1047740934882313, 0.08716603129869327, 0.17808637989219278, 0.21922677231486887, 0.06276345869991928, 0.12976610945770517, 0.19612769305240363, 0.1095761897158809, 0.06838428482296877, 0.0619403464224888, 0.1134921913035214, 0.10171072310185991, 0.15748983743833378, 0.11698268994223326, 0.08713741408428177, 0.08975611184723675, 0.12642723158933222, 0.11265070716035552, 0.1331401354400441, 0.1285258322604932, 0.19676119030918926, 0.164700677851215, 0.14179102436173707, 0.24817093246383592, 0.059855642466573045, 0.1965041845687665, 0.1156413767603226, 0.1510323808179237, 0.1034368621185422, 0.12751222180668265, 0.09301657439209521, 0.14508817868772894, 0.1485601978492923, 0.2298074826830998, 0.2235688705695793, 0.16481029306305572, 0.17825253191404045, 0.1341530482750386, 0.1121980712923687, 0.11300010286504403, 0.09130952341365628, 0.16935850057052448, 0.12906884687254205, 0.28508851944934577, 0.14783047372475266, 0.20710062846774235, 0.13653575791977346, 0.14374541089637205, 0.1966629596427083, 0.11246033885981888, 0.16533335874555632, 0.155429398000706, 0.163459035102278, 0.10672636490198784, 0.15187191311269999, 0.14676618942758068, 0.15173967723967507, 0.16398069070419297, 0.17476540262578055, 0.15573194192256778, 0.19940814905567095, 0.21934783144388348, 0.09142494964180514, 0.10910940109170042, 0.1580851140897721, 0.1459207051084377, 0.1540310581913218, 0.20031109044793993, 0.19477186346193776, 0.1779865610296838, 0.08997130498755723, 0.17529584525618702, 0.20308606966864318, 0.27906412084121257, 0.1329584131599404, 0.11389482126105577, 0.11942877157707699, 0.11073723522713408, 0.17599267739569768, 0.14584034535801038, 0.23231859871884808, 0.08287848831969313, 0.08596737374318764, 0.1289311339496635, 0.09451427293242887, 0.12014463980449364, 0.2946889417944476, 0.09440968206035905, 0.10362449189415202, 0.16701582237146795, 0.13786893716314808, 0.20984403672628105, 0.09799956911592744, 0.13934220420196652, 0.1740928238723427, 0.14253216271754354, 0.15236625768011436, 0.2537269319873303, 0.12787440471583977, 0.14454121585004032, 0.1426098358933814, 0.16545986523851752, 0.1351916987914592, 0.11987354810116813, 0.09774693462532014, 0.11085952632129192, 0.14399023057194427, 0.12866363424109295, 0.13628304179292172, 0.15531838755123317, 0.15196998050669208, 0.14344589493703097, 0.10382933949586004, 0.1317424635635689, 0.09951299376552925, 0.18724544701399282, 0.14838926639640704, 0.09755595776368864, 0.16600255330558866, 0.12330574361840263, 0.19799358589807525, 0.11289200163446367, 0.10804352117702365, 0.2006751880981028, 0.21412324538687244, 0.09841278952080756, 0.2042177112889476, 0.14406153612071648, 0.10339142783777788, 0.1616590894991532, 0.13558916340116411, 0.13683775265235454, 0.09829442438785918, 0.12244951300090179, 0.12006514094537124, 0.15001531195593998, 0.11884718755027279, 0.19376525888219476, 0.1321255008224398, 0.07537593934102915, 0.15998003975255415, 0.11979093222180381, 0.16558292816625908, 0.0735370309848804, 0.17320386454230174, 0.14144990360364318, 0.13736568682361394, 0.15472057275474072, 0.11147773533593863, 0.16400605731178075, 0.11750708406907506, 0.29385672707576305, 0.1538668357534334, 0.08798261638730764, 0.1169789420964662, 0.12556669651530683, 0.16325233213137835], [0.07144427101593465, 0.02894317494792631, 0.03880408185068518, 0.008807945923763327, 0.05659063797793351, 0.02169996947486652, 0.04870121483691037, 0.022265938714554068, 0.0350777027051663, 0.06174223752168473, 0.06903642482939176, 0.06085036526201293, 0.05992078447889071, 0.005224948317845701, 0.050533017129055224, 0.04948265181155875, 0.03856185598124284, 0.024466076320095453, 0.020137505562161095, 0.02673043381946627, 0.016960089342319407, 0.015132867029024055, 0.011752952104870928, 0.029025258336332627, 0.025193638939526863, 0.015383909612864954, 0.06483811026555486, 0.07080894807586446, 0.05102589595480822, 0.04706880536105018, 0.023765147525409702, 0.03754495410248637, 0.03625885670771822, 0.011371048476576107, 0.028912967682117596, 0.007133392664400162, 0.07092446336173452, 0.02920432001701556, 0.01989533906453289, 0.04325146117480472, 0.031920461769914255, 0.029418047415674664, 0.036010983094456606, 0.06570496101630852, 0.05484066117787734, 0.08657416110509075, 0.05367720368667506, 0.05225720058660954, 0.03149446158204228, 0.040641105151735246, 0.056133081670850515, 0.05287529085762799, 0.051911541595472954, 0.05667848599841818, 0.06480449839727953, 0.019898765931429807, 0.04819876601686701, 0.09262739957193844, 0.04210619372315705, 0.058724409027490765, 0.08115306176478043, 0.054690888355253264, 0.05547675224079285, 0.07700250440393575, 0.00787682425652747, 0.058290200686315075, 0.037572925648419186, 0.045760918510495685, 0.01959094348421786, 0.0308641833908041, 0.054107864561956376, 0.06080594030208886, 0.021527978606172837, 0.01907272031530738, 0.013646627248817822, 0.022459921274275985, 0.04004091548267752, 0.058554820861900225, 0.02980008277518209, 0.09975819935789332, 0.013889869860577164, 0.045004413987044245, 0.023649428148928564, 0.01159370391178527, 0.055668589993729256, 0.014251190950744785, 0.07077497997670434, 0.07043706529657356, 0.07251780989463441, 0.02973695383843733, 0.037032656982773915, 0.04725439794128761, 0.1293922748300247, 0.01976124225620879, 0.033032417923095636, 0.05096959292131942, 0.026724073613877408, 0.028801339394703973, 0.09514267163467593, 0.01315646097282297, 0.0708672363543883, 0.0654539666720666, 0.03776156474486925, 0.05161909088201355, 0.057089242473011836, 0.026327894775022287, 0.029625171555380803, 0.04942924315400887, 0.021178978095122147, 0.02655221447639633, 0.04290235861844849, 0.037716690785600804, 0.04052855474583339, 0.026156453095609322, 0.07665817756787874, 0.023644450193387456, 0.013134474847902311, 0.008334919548360631, 0.007544625041191466, 0.017369023844366893, 0.03838231190457009, 0.06704828541842289, 0.028134163476352114, 0.005421992700576084, 0.011856537366838893, 0.061671347575611435, 0.05582536126894411, 0.031418580692843534, 0.09873920091195032, 0.06114916133810766, 0.06918909202795476, 0.048980485007632524, 0.01215085736475885, 0.034198157518403605, 0.030017966200830415, 0.06847960627055727, 0.008846414220897714, 0.13956759445136413, 0.05976722670311574, 0.028941607160959393, 0.029449167523125652, 0.03182322187058162, 0.04286075753043406, 0.015524960344919236, 0.028388156097207684, 0.07777067919960245, 0.09995550673920661, 0.02250724061013898, 0.03143755740893539, 0.039155177073553205, 0.030389587373065297, 0.020748821880260948, 0.053615679644281045, 0.10119452970684506, 0.042918938197544776, 0.012650935950659914, 0.023063547087076586, 0.07991869206307456, 0.014204649942257674, 0.03192806136212312, 0.051776081090793014, 0.02850916142051574, 0.05516473851457704, 0.016610847633273806, 0.03974666877184063, 0.009370920597575605, 0.03540265577612445, 0.025436020659981295, 0.010214808371529216, 0.009486821800237522, 0.0387778729054844, 0.010876241922233021, 0.05501220119185746, 0.023736929215374403, 0.03355298256792594, 0.06916521713719703, 0.03295595815870911, 0.052894004111294635, 0.01839413573179627, 0.0577741445886204, 0.04131389541726094, 0.027982670726487413, 0.04755138317705132, 0.012125764424126828, 0.038963205734035, 0.02701474502828205, 0.013248313807707746, 0.022658291782136075, 0.0949716214381624, 0.029133482021279633, 0.06337171551422216, 0.1005073900159914, 0.059536433618632145, 0.09888682892778888, 0.04345898050814867, 0.037332929932745174, 0.029185363709984813, 0.03421858884394169, 0.027708608577086125, 0.024391520164499525, 0.023364024127658922, 0.049880661899806, 0.024434991464659106, 0.003682513811327226, 0.0574160286487313, 0.04916337245958857, 0.02075168285955442, 0.025423832739761565, 0.07639386909431778, 0.011899290639121318, 0.025989230525738094, 0.045511757271015085, 0.05251324524579104, 0.058499334190855734, 0.06519523914903402, 0.00682234001942561, 0.0745919271139428, 0.030044462728255894, 0.03881714364979416, 0.030076896437094547, 0.04849820405070204, 0.005893347852179431, 0.012032757549604867, 0.041020238713826984, 0.01587871152878506, 0.0066313432125753025, 0.04035499980091117, 0.07326724546146579, 0.05739405365602579, 0.06181532793561928, 0.004231205157338991, 0.04750214910018258, 0.03605871432228014, 0.02787317796901334, 0.08787600687355734, 0.005656536413880531, 0.048798595744301565, 0.04480918090848718, 0.012006719298369717, 0.07144247501855716, 0.05880577438801993, 0.01392059199133655, 0.05541363629163243, 0.06657144811470062, 0.04001956018328201, 0.052123064815532416, 0.0696174448239617, 0.04651321505662054, 0.03892635810188949, 0.02329806946363533, 0.03613934124587104, 0.015995768626453355, 0.04437373318069149, 0.011200787739653606, 0.02254807357530808, 0.07386382087133825, 0.04058960381371435, 0.04537452303338796, 0.1008011914382223, 0.01423289329977706, 0.062269396148622036, 0.014350497731356882, 0.05339368843124248, 0.010140735539607704, 0.05795060133095831, 0.051720549890887924, 0.056730347278062254, 0.027778246148955077, 0.09518009814200923, 0.03631248058809433, 0.0669152257614769, 0.07812031239154749, 0.030987045938672964, 0.10966908434056677, 0.07145717696403153, 0.05691425518307369, 0.028273677962715738, 0.010789585976453964, 0.1191230809490662, 0.050319568035774864, 0.03416535088035744, 0.04750786734803114, 0.029883537281421013, 0.03302756427729037, 0.040392459704889916, 0.03228762448998168, 0.022069325241318438, 0.05712913662136998, 0.024225446068157908, 0.04122017329791561, 0.01303403814745252, 0.040098175886669196, 0.05521077022422105, 0.016329163627233356, 0.07483905486878939, 0.02234576597402338, 0.014895513359078905, 0.032788741154945455, 0.06079483406210784, 0.05255429343378637, 0.02776065539364936, 0.015896144577709492, 0.053547595016425475, 0.032076613351819105, 0.011657252161967335, 0.13492031022906303, 0.08612159203039482, 0.10794710877235048, 0.027432444294390734, 0.006205155168572674, 0.04138923824939411, 0.02570706041296944, 0.009096787944145035, 0.13870775699615479, 0.026972782143275253, 0.013057863870926667, 0.027513243767316453, 0.01347218172668363, 0.026089594866789412, 0.10154649324249476, 0.03189947754435707, 0.046078038212726824, 0.09762460642377846, 0.040975450101541355, 0.06792004918679595, 0.0559817911562277, 0.043554877120186575, 0.007823642881703563, 0.038405774903367274, 0.0523728717234917, 0.08420409023528919, 0.022388671386579517, 0.02986597621202236, 0.06561636342667043, 0.03593219669710379, 0.031648887670598924, 0.05881283592316322, 0.0912889807659667, 0.06390052541974, 0.07618370771524496, 0.027223090000916272, 0.018524898441683035, 0.048248619787045754, 0.015433099160873098, 0.04527081531705335, 0.03165717746014707, 0.008168530966941034, 0.047644363148720004, 0.02921446332038613, 0.02569641244917875, 0.0471078868577024, 0.024344605299120303, 0.1502174136112444, 0.1648783776909113, 0.12780160002876073, 0.11111357089248486, 0.11696112313074991, 0.09767185896635056, 0.1381714068702422, 0.10204908307059668, 0.09249270719010383, 0.16017837129766122, 0.31155026983469725, 0.22631952218944207, 0.2275528380414471, 0.13914495619246736, 0.1640238391701132, 0.24507978348992765, 0.250087499152869, 0.19620374834630638, 0.1111799560021609, 0.15084693295648322, 0.0993160945654381, 0.14963902824092656, 0.1075185630179476, 0.12496753101004288, 0.07210864161606878, 0.11064400663599372, 0.11259723542025313, 0.10815174115123227, 0.19082806102233008, 0.24521105457097292, 0.14681672968436033, 0.12822294695070013, 0.14963338791858405, 0.11804663285147399, 0.17533457052195445, 0.18805803934810683, 0.14185676380293444, 0.17920506361406296, 0.20540348516078666, 0.2719105297001079, 0.18064224743284285, 0.10801800613990054, 0.14650630415417254, 0.15260249812854454, 0.13903109589591622, 0.14062810863833874, 0.19222441187594086, 0.15660642937291414, 0.14635971514508128, 0.1346418118919246, 0.08573025013902225, 0.13405978999799117, 0.159070493245963, 0.10068239585962147, 0.15481354901567101, 0.21703941078158095, 0.1816967799095437, 0.1599059734144248, 0.16313168860506266, 0.19186524208635092, 0.1415726845152676, 0.2094030674197711, 0.11548809357918799, 0.16094282793346792, 0.11675220855977386, 0.12016446256893687, 0.14311044418718666, 0.1318736159009859, 0.08968960799393244, 0.16365451680030674, 0.22190553951077163, 0.15293049771571532, 0.19954492687247694, 0.0797240118845366, 0.20682092785136774, 0.09456701736780815, 0.08673047224874608, 0.13599001220427454, 0.15235634258715436, 0.23797535221092403, 0.06480086187366396, 0.10439211007906124, 0.1329560679732822, 0.12230357708176598, 0.11685071382089518, 0.08529296930646524, 0.1548238203395158, 0.1720302618923597, 0.1562770048622042, 0.1486848489730619, 0.18422205612296239, 0.15182993724010885, 0.1983409110107459, 0.17982250079512596, 0.12323459392064251, 0.13842140673659742, 0.12681074382271618, 0.13324526807991788, 0.23870700591942295, 0.2358495889347978, 0.15329248766647652, 0.08738768112380058, 0.1812747650546953, 0.11722558745532297, 0.1744338110438548, 0.12356724677374586, 0.1615924297948368, 0.11698213333147578, 0.10051444784039631, 0.10230203668470494, 0.18439037521602586, 0.19848280964652076, 0.18156571662984788, 0.10752395843155682, 0.19629363727290183, 0.13429220096440986, 0.12086432267096825, 0.054945752999628894, 0.2015925568412058, 0.15494569583097473, 0.08540525624994189, 0.18184682732680812, 0.11435294902184978, 0.11831201001768932, 0.16133177268784493, 0.12147033819928765, 0.18608313985168934, 0.11309324981993996, 0.21260663692373782, 0.2176366318599321, 0.20125018927501515, 0.18689641496166587, 0.09171567115117796, 0.12632386526092887, 0.17104250786360353, 0.1489772106288001, 0.06915714999195188, 0.30839943734463304, 0.14576497283997014, 0.10194403206696734, 0.19751175394048914, 0.13727089972235262, 0.1851721535786055, 0.07970848615514114, 0.13667568244272843, 0.16994362464174628, 0.19878841121681035, 0.12798617215594277, 0.2409579249797389, 0.17241571855265647, 0.11495284925331362, 0.16978664556518197, 0.10430493741296232, 0.11857165780384094, 0.16800598095869645, 0.07807612491887994, 0.11148357603815384, 0.21584378118859604, 0.16931743011809886, 0.16624942130874842, 0.0981994294852484, 0.19000163505552337, 0.14298217138275504, 0.2500880928710103, 0.18056724598864093, 0.12595896609127522, 0.10263323492836207, 0.07171165198087692, 0.15250509866746143, 0.18576501082861796, 0.08580494730267674, 0.11262713655014522, 0.09311620029620826, 0.11492932317196392, 0.12904147646622732, 0.191740442533046], [0.014727923426107736, 0.015208357363007963, 0.08831893544993363, 0.04914084456686396, 0.08282472714199685, 0.04505357384914532, 0.05842874481459148, 0.04734323301818222, 0.04696742427768186, 0.0370091123477323, 0.045487852694350295, 0.015403501383843832, 0.006531751168949995, 0.011870878443005495, 0.011721703049261123, 0.0912978123233188, 0.029563564021373168, 0.008923322056944016, 0.02230288282589754, 0.09045966784469783, 0.01977616127987858, 0.05087563331471756, 0.04298497820855118, 0.0528493045567302, 0.0320718784496421, 0.04143532190937549, 0.022562914673471823, 0.024425660812994465, 0.02989628366776742, 0.04298918247513939, 0.0507074663619278, 0.05576146977546159, 0.034032035182463005, 0.029546529876824934, 0.07608472005813383, 0.030269400267570745, 0.055134380963863805, 0.01263792331883451, 0.06416496747988276, 0.04416159397806041, 0.042691429116530344, 0.02580352662334917, 0.030821049767837394, 0.06998063705395907, 0.0769645361287985, 0.05187975169974379, 0.03583210695069283, 0.019592533535615075, 0.02504695345123764, 0.03833969036350027, 0.03738069084647577, 0.021734547990490682, 0.012253742224856978, 0.017906375869642943, 0.00848840682010632, 0.07522528336266987, 0.0804079083900433, 0.047986560020945035, 0.04294477606890723, 0.06500957606476732, 0.07497576589230448, 0.017288825511059258, 0.04848960626986809, 0.06756801143637858, 0.0909853310440667, 0.009203368699672865, 0.0314341917692218, 0.08466942425002344, 0.07180637228884734, 0.0851381201937329, 0.044931991506018676, 0.012021655948046828, 0.03380371716048103, 0.056820191675797105, 0.03773957119847182, 0.0435327611194225, 0.015176851338765118, 0.1562841294799, 0.080230876483256, 0.015278560822480358, 0.03513359755743295, 0.028202698958921246, 0.03330631494463887, 0.02245736643089913, 0.0729161873459816, 0.07344373560044914, 0.0033563491842869553, 0.1293303054990247, 0.05863976708496921, 0.07943584336317144, 0.06412406772142276, 0.04728267005702946, 0.030348361069627572, 0.11573133248020895, 0.04361454208265059, 0.10234259505523369, 0.07938398208352737, 0.037825426552444696, 0.0400825722317677, 0.043953005952062085, 0.049133872089441866, 0.03779178128752392, 0.03659326474007685, 0.04141503159189597, 0.007776976635796018, 0.014306159973784816, 0.016877683119673748, 0.024269318128062878, 0.07591260116896592, 0.01822923237341456, 0.09397108020493761, 0.04524515556113329, 0.11439482099376619, 0.009316740106442012, 0.04335517260187771, 0.038204478478292, 0.01869014504336519, 0.036742974480148405, 0.016565665682719555, 0.05283890706778038, 0.06662181767751463, 0.03352297753735911, 0.043721745314542204, 0.027731756163120735, 0.04202103598800022, 0.04210208964650519, 0.039410008321283385, 0.07570216519525275, 0.044768804364139214, 0.03712283905770164, 0.045131276710890234, 0.03392052007257007, 0.024691405342309736, 0.048927091193036176, 0.027407428351580165, 0.0634618493495509, 0.055115493305493146, 0.027130854032293428, 0.06436359588406049, 0.04705864535935689, 0.07148038392188028, 0.058601720884325914, 0.007093011481629219, 0.09814825840294361, 0.019688606407726184, 0.032710418599890545, 0.049975582587649114, 0.10068684874568135, 0.05096029010019265, 0.016539718344574794, 0.04736674796731677, 0.11921224999241531, 0.10580013491562568, 0.008946197831392055, 0.05723557544115465, 0.12291204169741832, 0.04162782759522088, 0.030932217923691496, 0.04570370263536461, 0.053140285817789845, 0.0087252669618465, 0.05915439083764795, 0.02728877563640708, 0.05384620926633943, 0.032693675748305395, 0.060339277843013406, 0.08348881572601385, 0.034591054209158756, 0.02652920789842028, 0.06664040105533786, 0.05398219669586979, 0.05038299939769786, 0.06473800938692875, 0.09058335417648777, 0.037156777470954694, 0.04512654180871323, 0.031154602474998683, 0.053288218114175834, 0.07500010091462173, 0.06290466713835485, 0.05125614727148786, 0.04384773230412975, 0.006156245781312464, 0.028501637898443732, 0.011591790098464116, 0.0399386252684053, 0.025701028607727494, 0.04311702483391855, 0.024171779514290392, 0.04345208224549424, 0.030677718787046615, 0.014862850512145087, 0.04131872679863591, 0.003181894617227954, 0.022239577629079577, 0.03085078020376386, 0.054713646313757636, 0.03542605569236912, 0.044764948906959035, 0.04212455816741567, 0.053677199975936674, 0.028308905857556965, 0.03116671803581994, 0.036950478970538825, 0.10742832528194413, 0.03921276031178422, 0.016231732624873985, 0.008420255398959853, 0.06660623999778181, 0.031106502028706018, 0.0267178117428557, 0.029868382625863887, 0.07732401019893587, 0.02792309853248298, 0.0470631130883703, 0.03457992941548582, 0.037527042368310504, 0.06741437944583595, 0.036381429817993194, 0.022017437986505684, 0.036971537410863675, 0.011791486267611617, 0.026025252518593334, 0.01572663248225581, 0.08558397283195518, 0.002514495358809654, 0.03934410560759716, 0.029099719868099783, 0.06703929058858193, 0.03622604635893367, 0.025706260748847853, 0.027825502402265556, 0.06795697845518589, 0.047930041764630005, 0.03006372517120326, 0.019487911122268997, 0.0423250011226628, 0.011859709120471962, 0.07864691069698893, 0.03543079801602289, 0.040387925182585604, 0.04059697705088183, 0.0643830030458048, 0.0881267934164498, 0.024154936472768895, 0.013388445204327581, 0.1068341989594046, 0.08906230767024681, 0.023671345625189133, 0.03826285210379865, 0.023859836292103864, 0.02481916977558285, 0.04615229008777533, 0.07727299496764317, 0.031252343324013054, 0.045792983000865206, 0.06471089873230085, 0.013996711295476416, 0.005363139925975702, 0.11622697580605745, 0.04127098814933561, 0.016439192586403806, 0.03446815455390606, 0.049697570357238874, 0.02196035384258721, 0.05443391972221434, 0.04747080078232102, 0.05282791214995086, 0.05004961552913301, 0.02089116766001098, 0.0350777694984572, 0.031043345261423383, 0.037960070694680326, 0.06253293278859928, 0.05995888262987137, 0.11497387429699302, 0.03250090288929641, 0.08815983383101411, 0.045909151376690716, 0.009125343003688613, 0.04219655391352717, 0.0332166078442242, 0.04282106747268699, 0.014883793919580057, 0.02278091498737922, 0.055131111803348176, 0.07620678850798868, 0.031899852328933775, 0.06583600945305079, 0.055011210424709134, 0.036807066353503615, 0.018717331768129952, 0.05497280428244267, 0.03551027461071499, 0.0528604813007405, 0.04148207350226585, 0.046215187103371136, 0.07880469871452078, 0.05856704774487298, 0.012274828495719703, 0.01847836949309567, 0.03934740074328147, 0.019460666881059296, 0.006414082263290766, 0.011450253259681631, 0.08556604996556416, 0.053239321714499965, 0.019992220877611544, 0.0008053100680172065, 0.04507001242018305, 0.02227095748821739, 0.017153248118120246, 0.05130796031153295, 0.039216044315253384, 0.056658993489691056, 0.043471151730045676, 0.03253006187151186, 0.006125033833086491, 0.06590702556422912, 0.016547457089473028, 0.03521358252328355, 0.03089126435952494, 0.06339932340779342, 0.060900463940924965, 0.01880404059193097, 0.03315610425488558, 0.003264794136157434, 0.044442066428018734, 0.06819715970777906, 0.0045478322590497555, 0.01311036896368023, 0.04377086435852107, 0.023900084815977607, 0.02367415465414524, 0.013854891512892209, 0.047720206930534914, 0.022411564787034877, 0.08420653190114535, 0.0256249157973798, 0.10160262929275632, 0.04801568189577665, 0.01891424024506705, 0.07248518508276902, 0.05277980613755062, 0.05210836658079643, 0.018655239982763305, 0.04846752366574947, 0.029828822443960235, 0.024533108953619376, 0.06031329154211562, 0.13503813359420747, 0.01287581504584523, 0.07622448130859993, 0.1155408973863814, 0.19995478534838185, 0.17022777814418077, 0.1556060736766085, 0.07756881503155455, 0.16945817100349814, 0.18950362427858636, 0.08770580272539519, 0.2157090516993776, 0.16949422453762963, 0.10050796889117919, 0.17852227290859446, 0.11873265932081267, 0.1420326528022997, 0.1476180859026499, 0.17318841302767396, 0.1201062485051807, 0.09516655394691043, 0.19244203926064074, 0.19612034579040483, 0.22977797489147633, 0.13828197203110904, 0.17271535325562581, 0.13371445384109393, 0.14874580898322165, 0.12274438311578706, 0.09575715506798588, 0.12005091397440992, 0.11364269885234535, 0.10530401661526412, 0.18200064485426992, 0.12012526975013316, 0.2653962839394808, 0.11694580520270392, 0.19686056388309225, 0.19336576078785583, 0.07699753201450221, 0.18569124134955928, 0.169810320076067, 0.11946363767492585, 0.09385169090819545, 0.11391722669941373, 0.24513173382729292, 0.17264640773646533, 0.1321276678936556, 0.133986703294795, 0.1458024958265014, 0.1368080370593816, 0.09916448121657595, 0.14871077961288393, 0.16850200277986005, 0.1169960263359826, 0.060082839845563285, 0.15555994177702814, 0.19531309691956267, 0.16869261598913, 0.14645482879132032, 0.1509072695625946, 0.19673926726682112, 0.1763659479911439, 0.08566298187361099, 0.12875382002675906, 0.21064635773655027, 0.224643619148992, 0.0908676783728879, 0.14367934491019696, 0.25161314697470516, 0.13691184867639095, 0.14940908120479435, 0.23566694639157504, 0.19019763625692576, 0.10848364443518221, 0.1464022253639996, 0.10061717592179775, 0.13356390176340938, 0.10422212115372531, 0.2057986639556475, 0.24259109515696764, 0.13900716905482113, 0.12730189715512097, 0.12459650170058012, 0.11649007457890548, 0.17980353150051087, 0.1996501930989325, 0.1597709025372751, 0.17380923440214247, 0.23476459871744737, 0.14465719868894666, 0.25202307966537774, 0.10674499280867167, 0.12148639827501029, 0.11126302459160797, 0.2451791422208771, 0.10222647862974554, 0.1612044349894859, 0.13884588552173227, 0.21161589946132153, 0.1764023577561602, 0.3026110416976735, 0.14999879174865782, 0.17708407976897433, 0.09471722063608468, 0.2209339791443199, 0.15475885273190215, 0.10370924515882507, 0.1596798113314435, 0.1579343987395987, 0.15201986767351627, 0.16743832704378292, 0.15284843102563173, 0.24229742732131854, 0.1426415701280348, 0.16969818156212568, 0.1921738122473471, 0.0964455415669363, 0.1227638051204849, 0.12042748712701723, 0.1768213594914414, 0.14782394282519817, 0.0954201458080206, 0.18603040283778682, 0.10818441791343503, 0.1759887143271044, 0.1361922177602537, 0.12409543327521533, 0.1535732124466449, 0.08977711462648585, 0.1055477824411355, 0.23925175715703517, 0.14185176172759384, 0.11215617705602199, 0.10539777955273166, 0.12087988550774753, 0.11313266528304666, 0.1851321815047413, 0.11371560001862235, 0.13147321238648146, 0.14092352794250473, 0.1605237668263726, 0.1984779114718549, 0.14117993996478617, 0.19776675588218495, 0.16883338656043634, 0.09189567164867185, 0.18126531009329483, 0.20036860689288005, 0.2340194082353264, 0.1539231202332303, 0.12869826285168529, 0.0842863944126293, 0.22320925549138337, 0.17585650813998654, 0.06822542069130577, 0.11292466355371289, 0.20785806438652799, 0.14806016843067482, 0.12475915078539401, 0.12144965454353951, 0.1080848959099967, 0.145631059713196, 0.11702420568326488, 0.14826149825239554, 0.2852732251631096, 0.11651405337033793, 0.20857153547694907, 0.19665028376039118, 0.10457069307449274, 0.1256313078920357, 0.1696668184013106, 0.14159671525703743, 0.09212040138663724, 0.12544115481432527, 0.14500851655611768, 0.22850925859529525, 0.13511792931240052], [0.03654334046586882, 0.02274841634061886, 0.06142926271422766, 0.05486242094775662, 0.006599698035643087, 0.07035476854071021, 0.05630289248074405, 0.009752793612278765, 0.02981853442179272, 0.082795612688642, 0.03302659577457234, 0.0276849990041228, 0.02534886840294348, 0.05171837539819535, 0.09516210106085055, 0.01477797850384377, 0.04055569879710674, 0.01675977069680812, 0.005113818660902325, 0.023693687980994582, 0.04111818736419082, 0.007267170813065604, 0.06918810497154482, 0.03890820516971871, 0.07768225972540677, 0.023962566228874493, 0.017109338950831443, 0.017964259677683003, 0.017599811362742912, 0.053016072561149485, 0.04245923708367627, 0.031416413621627726, 0.029185089115344454, 0.04963681443769019, 0.014228568434191402, 0.05082211704575457, 0.06974832998821512, 0.05512204275873955, 0.09579553894582205, 0.0674023492319975, 0.03779124694119673, 0.007659177390451077, 0.14899197936756536, 0.039338951391982846, 0.025015683058882132, 0.0341927361296257, 0.016912840510485694, 0.03940694696211722, 0.04270279881893657, 0.052561091506504454, 0.018470272661943454, 0.048293341606040485, 0.025121928920270875, 0.036729307830682956, 0.02123532565747155, 0.10226878846879117, 0.020339366019470617, 0.01184099679448991, 0.014929095541447168, 0.05058604358055163, 0.04410772518895101, 0.04933120173518546, 0.04324110450397711, 0.07348694343818352, 0.02022515134740388, 0.08632749348180369, 0.04963379760738462, 0.050416629819665104, 0.07477413179003634, 0.04842204485612456, 0.08901117369532585, 0.0681361996976193, 0.05667503872246016, 0.041627330356277525, 0.036275350939831696, 0.013789868244202808, 0.04460691969143227, 0.04958052253641654, 0.053743139797006734, 0.012722145020234166, 0.04438023068360053, 0.006804151835240191, 0.03904588469595183, 0.025959292288462166, 0.05640592484269291, 0.026311101828468964, 0.031249348758137785, 0.07751621160423383, 0.03635290537204128, 0.011674547913571587, 0.05153739526576828, 0.023465681661036797, 0.049035467018256895, 0.0856104600825347, 0.08338124142028391, 0.04357233614427969, 0.008464733236905886, 0.01828175601986004, 0.0631952699040994, 0.0359442120679887, 0.023419410608767066, 0.06004339098581113, 0.08332813333254308, 0.045437412627507, 0.019876354926964268, 0.024570769237470813, 0.017832220473792404, 0.038019513012841344, 0.09530594412353821, 0.04005206254078075, 0.008846826112858253, 0.0865949338185601, 0.03350498045620043, 0.014235197668313049, 0.0494697607064154, 0.006645394387305714, 0.030766312665946316, 0.017704602614685427, 0.011295033073110972, 0.034947247986565344, 0.04353688746050466, 0.04055622201121878, 0.033753288225852884, 0.03653256077086553, 0.055263952526729554, 0.07000288664130494, 0.012229444309923565, 0.09057058923644945, 0.015112439414224355, 0.05954914289759472, 0.05488111564773135, 0.02655073389178142, 0.011739450583263533, 0.021154529895284213, 0.07259481513756327, 0.036073271548957564, 0.043666125056915917, 0.10568706871708855, 0.040525675212848, 0.044866830940009095, 0.06099062375142239, 0.05445799128210638, 0.044540746093844064, 0.016463074898638297, 0.03070938437303994, 0.04371695846202783, 0.0605297463334864, 0.054823788450448774, 0.05764675865066238, 0.017864307228592224, 0.010605255047266837, 0.024911511500249617, 0.049500292661832646, 0.023307600495172665, 0.05286982865072787, 0.015691994594817515, 0.044802037737099454, 0.055515099011245184, 0.003177550270265783, 0.047263749002013355, 0.03560053832188714, 0.043393448868300766, 0.06868699201731943, 0.019209427628084086, 0.12278572074137628, 0.07727381133008748, 0.0490792203345336, 0.06799197813961655, 0.06667984620435163, 0.020648643076128792, 0.04394683870486915, 0.04440182718099095, 0.035874984532711096, 0.05141562367498409, 0.015230232165777124, 0.012476914380386006, 0.07755066209938377, 0.047593366471119225, 0.055015125253703445, 0.09290732283261605, 0.08696280157892033, 0.07222275424282998, 0.059712782749556936, 0.02323239496035967, 0.022390547164832242, 0.07795988974976353, 0.04985320243577007, 0.04537759923550766, 0.0058212194471707335, 0.10856644585146569, 0.07379704984487034, 0.11287437562714331, 0.03417311003431678, 0.05177263381483499, 0.0295363791519776, 0.01740184161462821, 0.03842677026113961, 0.01377686952764634, 0.07899723408627324, 0.06777198330382816, 0.07019214914180338, 0.013389524101512507, 0.031995433528209105, 0.028937202514498495, 0.024283697239297908, 0.04021373199066147, 0.0618665138608776, 0.0777328222466167, 0.025692354756756686, 0.05525281660084147, 0.023648405840503983, 0.06080730956455227, 0.028221599604876246, 0.03906900259607937, 0.04437162177055143, 0.06794531931518577, 0.013615535899589304, 0.009652407006797148, 0.12433870186214335, 0.017280147949350066, 0.013035630981903523, 0.039958021297934465, 0.01191140527225798, 0.049603250809013844, 0.012328897664701799, 0.04417540905706119, 0.03268455846409779, 0.04197325280983932, 0.02748717954091262, 0.045692811618209817, 0.035437918922980316, 0.09239605729817413, 0.035324273849255405, 0.02599764833576046, 0.019182836476829834, 0.024754807018325664, 0.04602055516443215, 0.03094674917520024, 0.02776326404273277, 0.09203649417031556, 0.045748031116090715, 0.05677450135408435, 0.04421775971422903, 0.009963489337678766, 0.022012001754774246, 0.03063288750126958, 0.09193635618430562, 0.077601469529327, 0.0155438470756053, 0.03363506781170145, 0.019326861365698278, 0.024780928761174437, 0.07483658351702616, 0.030820995962130837, 0.056367036304436624, 0.03092995066253934, 0.04969624933437444, 0.04278632011846639, 0.0996127309917938, 0.1056728046387434, 0.038907073394511826, 0.04325252244598232, 0.03208014226402156, 0.020236589698470198, 0.03354936830874067, 0.033542503442731686, 0.03964947711210698, 0.039608755469089374, 0.022030622239981312, 0.07522506071836688, 0.02219746445916826, 0.023962156192283146, 0.05433615289803129, 0.11013471521437168, 0.05313907240633853, 0.030403001692320686, 0.031906576186884195, 0.06240257454919629, 0.020800536585738882, 0.051323044463060796, 0.030082379053055774, 0.024439696680929046, 0.07302814032300375, 0.044721262383973226, 0.05405276009696536, 0.03134815087832976, 0.03767176116525661, 0.009524051638436504, 0.05639329719997477, 0.059549562211032026, 0.012057488693244522, 0.045824461194570176, 0.04502238138229586, 0.014369709151651477, 0.04465672893275041, 0.02941298040241236, 0.038652884104521945, 0.051652684196596965, 0.014247487633838318, 0.07614184316480532, 0.09739664092194289, 0.07178200015914626, 0.03563074744306505, 0.04098816309124231, 0.05844398481713142, 0.016606565441179555, 0.023610515490872785, 0.01980684908630792, 0.047667685139458627, 0.032491804158780724, 0.0965744823042769, 0.027853216051880736, 0.04590270582411904, 0.031861431343713775, 0.020507048720901366, 0.01640765131014632, 0.024481681830366142, 0.028432135768525768, 0.0551921905571362, 0.03773657292185817, 0.01959166707820259, 0.03270968758442905, 0.052797940516029485, 0.02669578665518202, 0.027177262381883338, 0.01924225467519136, 0.04252983388141729, 0.06838888613856398, 0.024163625166693237, 0.06841007445473224, 0.057736554808798246, 0.021758395050710533, 0.02035789002547972, 0.022875768881931435, 0.053530139703070745, 0.025909414398483932, 0.029397315520327538, 0.057476272486383095, 0.030475192252197303, 0.040259455709019676, 0.01320117165960255, 0.019195864879293367, 0.01114257089284365, 0.0567479547316907, 0.05139465800311882, 0.06848273813375272, 0.006244663863981259, 0.05081431336293463, 0.03762200758501422, 0.010946883248834638, 0.03809636240475811, 0.054107448959257454, 0.1497377487248741, 0.14511022047372535, 0.13421951502095908, 0.24853572773281485, 0.18816266732756048, 0.15071184723637998, 0.10056316983536817, 0.11740006637410261, 0.08352070581167936, 0.15929061424685642, 0.12153599600424059, 0.1297447207616642, 0.12086418166290969, 0.1968980868696235, 0.1922761692549102, 0.19780022674240172, 0.17484473821241409, 0.11824837827589363, 0.11083150282502174, 0.14117749087745324, 0.19237594358855858, 0.08267509532743134, 0.22996401647105813, 0.12499798875069246, 0.16356916981749237, 0.09290263245929964, 0.12798467301763594, 0.1171749655622989, 0.14703023072797805, 0.19797365181148052, 0.15990429616067559, 0.2256039879284799, 0.11094673609477468, 0.16101720597362146, 0.11937063172808848, 0.12242735247127712, 0.14865590521367267, 0.13577006931882352, 0.15158338093897328, 0.1662192158983089, 0.10289774378179573, 0.09108138721785508, 0.2512239053612575, 0.17589043913176283, 0.11050558867282234, 0.1724056401872076, 0.11637687479378656, 0.18334470398258418, 0.1672994118416682, 0.1080256057321094, 0.11917187715880573, 0.11329705099342391, 0.11957328257267363, 0.11617550044320524, 0.12499884964199737, 0.38616152247413993, 0.1479230640688911, 0.2131546536111273, 0.06912704848218709, 0.13644641818245873, 0.1521603562287055, 0.10748200482339598, 0.17499913461506367, 0.2561101462924853, 0.11527546084835194, 0.14354378421558067, 0.16419580962974578, 0.1410538490745239, 0.2555246511474252, 0.11476209503598511, 0.21602333639748394, 0.16243316436884925, 0.0895273225614801, 0.18382079171715304, 0.04537859000265598, 0.1609315472887829, 0.13236748549388722, 0.11350990636856295, 0.1840570618514903, 0.1246591389644891, 0.22755032958230004, 0.22964217670960352, 0.11657847178867087, 0.2527782891411334, 0.185386233497411, 0.15408707549795508, 0.18925714219221845, 0.16767663066275418, 0.12129903567256406, 0.0879670906579122, 0.13506697345292196, 0.12584905402036384, 0.1450065869721584, 0.16620205744402483, 0.15432987653184682, 0.09456824191147462, 0.07926871912786737, 0.1503678914741613, 0.21885486727114767, 0.27287119533866644, 0.15769032121170312, 0.14360728237079456, 0.16854000074090436, 0.17473353480454534, 0.11022504942957312, 0.11201968125533313, 0.18031947256531566, 0.1275944072403945, 0.1639495205017738, 0.13926104293204844, 0.09787900722585618, 0.20492664043558761, 0.08949610783020034, 0.13143047952326015, 0.10643179906764999, 0.13966558763058856, 0.15145889308769256, 0.09503972833044827, 0.11768600845243782, 0.19161000265739858, 0.23263319511897862, 0.1716320402920246, 0.20662501570768654, 0.15373022120911628, 0.2276028587948531, 0.18149984360206872, 0.10423789179185405, 0.20282462588511407, 0.12644562200875953, 0.22254032810451463, 0.13898177276132628, 0.11576677003176883, 0.16621446615317836, 0.20828747103223577, 0.18645618780283257, 0.09492976430919953, 0.14149860333418474, 0.18138381623430178, 0.1624775299569592, 0.14676476450404152, 0.12268196849618107, 0.10804309815284796, 0.12054499879013747, 0.1496831711847335, 0.08978834332083352, 0.19787714292760938, 0.20947636192431673, 0.16663017275277525, 0.12029985256958753, 0.10905220377026126, 0.1137199490040075, 0.1521339060855098, 0.11411191429942846, 0.18966144940350205, 0.11020572390407324, 0.0712850209674798, 0.12012047547614202, 0.14718888705829158, 0.16158101556356996, 0.15362127393018454, 0.1584772055502981, 0.10205247468547896, 0.10885622483328916, 0.10642618100973777, 0.12726214772555977, 0.19615069963037968, 0.09849544250755571, 0.17457217705668882, 0.1836557826027274, 0.18227507622214034, 0.09100021110498346, 0.2105018764268607, 0.16201362828724086, 0.11320384466671385, 0.05896756629226729, 0.12035589214065112], [0.026797195569088217, 0.033693281875457615, 0.056827765292837285, 0.030286835171864368, 0.0406292085244786, 0.030095281290414277, 0.07118630048353225, 0.03390951031178702, 0.10062041168566793, 0.027073096389358398, 0.02696726984140696, 0.01224290594109334, 0.009549205806251848, 0.01585170848557027, 0.08187012484995648, 0.09137984190601856, 0.04215406966977753, 0.03204789594747126, 0.03075253654969856, 0.042807081699720584, 0.023839820569264702, 0.006686437009193469, 0.013710279399674619, 0.050774697519955225, 0.04455118811165448, 0.023515988141298294, 0.10477027142769657, 0.020575650996761397, 0.01937128447025316, 0.04298120809835382, 0.04024105415737722, 0.014901714002917288, 0.03342193413118366, 0.05605155303783249, 0.019299064224469475, 0.06473164918133989, 0.020320797484600917, 0.010545695840846747, 0.05967969409539364, 0.055872936645755544, 0.05552203809202183, 0.0119258752965834, 0.11476958330604248, 0.039800400263629854, 0.03428255826293025, 0.06801947471103631, 0.03055215667700395, 0.011185173880221555, 0.011829415579995839, 0.0238556672775303, 0.011846486831927905, 0.018583826822577976, 0.03644428972620517, 0.03336588342790492, 0.02206037679570727, 0.07761066473904066, 0.04294083897548262, 0.06327016002614982, 0.025728827604325488, 0.044419564510462806, 0.020973149003111757, 0.05123441347677726, 0.016502449543622788, 0.06233950683963485, 0.05044000005000271, 0.016103574853332248, 0.04850899858865887, 0.045120010909158736, 0.023320640029851347, 0.07840379053959623, 0.16951596946455538, 0.04320043110055849, 0.07043707271805033, 0.027992262985208072, 0.07136359956348315, 0.05471903059515171, 0.0685044533747714, 0.04497467612964101, 0.019992419402115047, 0.043839167919941247, 0.02156335121981101, 0.040013563630054705, 0.036298405757406726, 0.015112447763385717, 0.14926382806152105, 0.04564736249449197, 0.04453825247765053, 0.02708650328713702, 0.06366609581164084, 0.08567461874918081, 0.006008345026202733, 0.021324385234038346, 0.05100566500914283, 0.04908071947284043, 0.03327566424559336, 0.04805304160981905, 0.030343605758389458, 0.0776225836307276, 0.06778466660762206, 0.04303401190554723, 0.08001667039934546, 0.0486635174456751, 0.029603920156660024, 0.03347868245327845, 0.008623370085842907, 0.06525843302370049, 0.01279680600418942, 0.030091253283899277, 0.02766265293757897, 0.03198841281118803, 0.09405086108017713, 0.026599084812914953, 0.039287539111683145, 0.02721607485000277, 0.03641069641162176, 0.07811792267602868, 0.023208505226648413, 0.02343434633075958, 0.08303591268486343, 0.040305966103915125, 0.04592851772031281, 0.013216401457611937, 0.018578670751594473, 0.018580600335553754, 0.03275776020018384, 0.04464802725124173, 0.12264468299690634, 0.040038581428234465, 0.06388976427842863, 0.018766450812108815, 0.0314149590121815, 0.033142548927571625, 0.037685513161704876, 0.03282405625213869, 0.02998959389515221, 0.0302595835091779, 0.014950215208955342, 0.08673322561662644, 0.04695723830081988, 0.014282133870437974, 0.029024043069512118, 0.05405729833000805, 0.0712003196531441, 0.07687090677791275, 0.06682319944957271, 0.0253571192297386, 0.03894951682013925, 0.0513464814866893, 0.07239891783683561, 0.056990926459548064, 0.0534233186772326, 0.057771083229454234, 0.03991789337305818, 0.02584230198408477, 0.03791728588112164, 0.07263352556037717, 0.0170329051616136, 0.02004499499889789, 0.010468033797224052, 0.06810358230723068, 0.07066505306283943, 0.030941214608901646, 0.014364001108333468, 0.017579758532519918, 0.020754018769366667, 0.025522338000882883, 0.04382115599582903, 0.012313628903939389, 0.040943444982985966, 0.02087466600642074, 0.030181518850440625, 0.02543585367675405, 0.07131158243282698, 0.029234456778794993, 0.06369451264617965, 0.05893068897421472, 0.047114540211623535, 0.07346105732722208, 0.09756055165780708, 0.055064596817828715, 0.03284174905274995, 0.015237298339343397, 0.022704948751197662, 0.035217731128796004, 0.009461745557928225, 0.052996424201410264, 0.006503986960524344, 0.06733110305503942, 0.02041783885943005, 0.037332748106564395, 0.0869370267901104, 0.0433798749872949, 0.023018730644253083, 0.027552412466320675, 0.04292703131795861, 0.11056385468691587, 0.031070569093571976, 0.05701349888113327, 0.04329620525822975, 0.020810588976019062, 0.08532196501619183, 0.026542371742834803, 0.04217528767185286, 0.05389744714193512, 0.030372542096301913, 0.00627816023552441, 0.008589128319727024, 0.07381840885500424, 0.05133050675794948, 0.019863003690261394, 0.007320021932173404, 0.03672388644190505, 0.055757699665264226, 0.08687815963639878, 0.02291212855197955, 0.022856727227917872, 0.042014401187771, 0.0180177314177854, 0.03760632229386829, 0.02026368551014457, 0.035676474872161634, 0.04232465973473154, 0.023844553616072517, 0.04136213872698136, 0.019037212259718217, 0.059979547731927596, 0.06454992690123618, 0.044070517615182325, 0.040525337535655126, 0.08399723141337745, 0.05204486100410577, 0.012253105833224254, 0.05349536637368146, 0.021275386789056938, 0.0436437084863428, 0.08970315961050801, 0.04698928794823587, 0.009154758954537101, 0.02922313902672613, 0.02292008066433482, 0.04732044537377078, 0.14237292751204222, 0.04276238214515615, 0.08230465231463313, 0.06480101772467606, 0.02335277502425015, 0.038814130530226976, 0.01857279108662624, 0.037419445798150264, 0.07595597970066592, 0.024577680487709586, 0.039032247732393444, 0.004975255051249405, 0.033219999459106475, 0.04826958916964941, 0.08855419626343064, 0.056049538106890395, 0.04064022199600004, 0.022644385790044907, 0.038185156663530506, 0.04301799264794681, 0.05083100426418241, 0.03954592153604608, 0.019239261964685284, 0.03186888621712569, 0.11332510417560115, 0.11002601284417324, 0.06793538937927224, 0.021994359049131162, 0.025630658165027853, 0.025109377347689588, 0.09630382846808061, 0.04378616744361352, 0.06734725960996002, 0.008261668644991005, 0.06105220345489215, 0.09842671221122146, 0.0462784477713285, 0.05421950583695434, 0.14421174681046978, 0.011588745437620673, 0.029480797857104335, 0.022338316666719038, 0.06905542380991392, 0.0492584452877054, 0.07712177495704964, 0.10952398704830557, 0.040082234554574825, 0.02563096430094447, 0.07080055438564159, 0.015961160424922127, 0.015228373085847124, 0.04511807761446107, 0.05340493567928206, 0.010983145512000192, 0.04443519785127137, 0.031963955334504135, 0.0355043188756099, 0.04328992297814693, 0.014137162743281806, 0.038822450005682185, 0.03505731590848882, 0.057495379078318365, 0.04014747675682884, 0.06020890847139526, 0.08993869501864538, 0.020238786455593072, 0.03372380269865971, 0.020106854863115586, 0.0743542097916361, 0.022924160621187184, 0.08504268000251614, 0.027805432873719838, 0.04932804389682133, 0.0229663183199591, 0.013639953485835576, 0.023281274661712814, 0.013176488755561877, 0.008618196388852084, 0.009350808395538479, 0.02456741472997237, 0.0446677090076264, 0.011234368066652678, 0.059292953519616276, 0.009752370588103076, 0.07262241560965776, 0.03265724371885881, 0.08871422556694597, 0.03779287595534697, 0.04348917478637304, 0.035390992925385945, 0.03460454274318181, 0.062261707498691976, 0.008707719807716785, 0.055486389028374106, 0.04201899137115106, 0.018510860718379263, 0.08243428324931301, 0.06417481577955186, 0.042836300053750165, 0.025375016120960936, 0.052263928155298345, 0.07056541231577285, 0.028553348893183284, 0.04631502080883365, 0.04188944949419238, 0.04777721129357815, 0.04051955620525405, 0.051763011870207265, 0.05483977802214213, 0.022218461672309786, 0.031891440085018985, 0.10822850890690461, 0.1407127728452906, 0.15806751034688205, 0.14682661509141326, 0.07935928340884857, 0.15139066003030166, 0.14605004660552368, 0.07298980839550495, 0.1856555588892661, 0.19915960379876196, 0.09994095322326757, 0.13373777212109417, 0.10475972550921142, 0.1353999602724798, 0.14461869606748223, 0.276770765776746, 0.15092362649738789, 0.17020903149386868, 0.11847241781651974, 0.18401467037620023, 0.16166578367119655, 0.12102337976102717, 0.12128415561164729, 0.12659786618314683, 0.19461587886326015, 0.14290745195467025, 0.16463575477246195, 0.09873273680568673, 0.11808957351604477, 0.1738548171124421, 0.13738277106313035, 0.3181181877152994, 0.17957005184143782, 0.3408046328695491, 0.13764795527094975, 0.13825932168401778, 0.15404478792333975, 0.1707001551403664, 0.1868241000920534, 0.19346618821145967, 0.21549991448409855, 0.0852757811662741, 0.15176655782852322, 0.16418368293670937, 0.14743572537554428, 0.17914992204168811, 0.20410903118317947, 0.11088927902164869, 0.07947992693516426, 0.1507901438162662, 0.1286596414865926, 0.09969336533686146, 0.14223718870198354, 0.10086293070344254, 0.07750524266157299, 0.11921908517251723, 0.11852862066007219, 0.12384633140754886, 0.13474370876792818, 0.27285474934615195, 0.09506792252068408, 0.1230206475884188, 0.08287801334518008, 0.13411436753813177, 0.14503342303214595, 0.23775799199938774, 0.10891833517234772, 0.15451792191015556, 0.14200746431015432, 0.23400596051942557, 0.29186299187131226, 0.1895329836406745, 0.17885384964756668, 0.1351853905362077, 0.1631761877797544, 0.15370993089163676, 0.11237938539125025, 0.15436319896252826, 0.0919595779851079, 0.19873126584570855, 0.20010449137771502, 0.17752642947016284, 0.097644228808349, 0.11348262501996942, 0.21273933292832226, 0.2358352654846385, 0.13288534129969776, 0.14117213257122785, 0.17881763284094632, 0.3329605475300923, 0.2519093529554084, 0.25088266585953534, 0.11074248963268474, 0.12023051371215843, 0.11295768912532367, 0.21435466187540442, 0.14731389441294596, 0.31796667084563524, 0.10854291234863922, 0.2306491375202313, 0.17573666613316163, 0.14499912096653134, 0.10783457692014053, 0.21858980180695653, 0.12684148357948288, 0.21501371869817376, 0.11245639063417912, 0.18510389083530754, 0.161849865980912, 0.1061846267839428, 0.2877517609158531, 0.16286939877318218, 0.1381285849492997, 0.13381758268224075, 0.09115353881497867, 0.1409597002202645, 0.08908766685635783, 0.18758355465251952, 0.17472090345108882, 0.1022390580328647, 0.10576041517197154, 0.1193773333216086, 0.12505378341302276, 0.16911305749090388, 0.10176491472520865, 0.12527803075499833, 0.20951300917658955, 0.11079682226409204, 0.2143206269829534, 0.21256933658150956, 0.14438857091590762, 0.15958411881001666, 0.13324299710802734, 0.3181389975361526, 0.15610108617693186, 0.23245825606863946, 0.1657367605366744, 0.15829989162739366, 0.1122238757670857, 0.11198877080460079, 0.08277793473098427, 0.08870083722285926, 0.14824117824900895, 0.08471412380458787, 0.10095961028127931, 0.09309062588727102, 0.07106016506440938, 0.13800679851556197, 0.09503499342827126, 0.18954191909870133, 0.10959914434351958, 0.30404401011765003, 0.1643899703049101, 0.15936288458760828, 0.23504815850174055, 0.13117736263666302, 0.13219803833635524, 0.10914287195191719, 0.10298836001311429, 0.15801225003087893, 0.09444149793125689, 0.16652260586852208, 0.21234875544905663, 0.09581254154909402, 0.09020705561852083, 0.10226301455986686, 0.07596688927151263, 0.1317348045995459, 0.0884220346051734, 0.15170114493230358, 0.15872431104071438, 0.12139921076595783, 0.26153061480727047, 0.13210665027145296, 0.11193064579856582, 0.15153653657762334], [0.04425610648468137, 0.035708873328985646, 0.061533074331237, 0.07001364036113955, 0.0544392409210559, 0.04429831984452903, 0.018348341509408783, 0.030146838289510924, 0.054016034919186495, 0.049400258576497436, 0.022036830305296462, 0.00640197737084236, 0.004251742702763295, 0.051211084064561874, 0.05891793887712993, 0.0057081620616372675, 0.03540839628840331, 0.022663785530312452, 0.026657755297492258, 0.03297953990113456, 0.0642914442869369, 0.037205480912234634, 0.018854217196349055, 0.04393471572257113, 0.010160674264625413, 0.03263087150116917, 0.05803977037430741, 0.03310343403427396, 0.04264272196451202, 0.034677822404773906, 0.05732157180318609, 0.04021128661406692, 0.05046535923611373, 0.025020623907039408, 0.007442080177497701, 0.03701520538015757, 0.043331524066161364, 0.052384308219188824, 0.009946778027369874, 0.03841306650429033, 0.05287569532811176, 0.013394354555202881, 0.054411017044913024, 0.024791882860881742, 0.05726152834540699, 0.057623874527052976, 0.07854201554437168, 0.032025831897044554, 0.041148689633701, 0.060770454510929994, 0.062477932224282995, 0.011543367745616706, 0.02530734709580429, 0.04087094457645435, 0.03516508688335307, 0.021810714606544934, 0.019698970500030555, 0.01654805822909111, 0.04333767275966238, 0.08077914550085552, 0.02544832732382929, 0.04257966167642735, 0.036151824169792235, 0.026079705748998094, 0.08870992111042142, 0.05457303901494015, 0.033409247116651386, 0.05317265458870679, 0.0456018094700994, 0.02104197206790559, 0.07422266411595047, 0.053303343083825894, 0.04364725966297556, 0.0755785011278931, 0.010199355929216836, 0.014618560544477077, 0.11316300428006798, 0.04685373838583473, 0.05425216404546518, 0.08437050943030044, 0.04369215217593592, 0.07305467952392064, 0.11819820167147554, 0.041128629382001236, 0.0480479616089724, 0.046237562855822034, 0.04145975712162908, 0.08754390320973471, 0.08707363391295075, 0.038510091180796735, 0.02668167286174139, 0.017736052977852523, 0.07025884595350362, 0.08356029939022847, 0.051345936008146964, 0.06745446284185164, 0.04576585750328377, 0.05980480906146113, 0.0756728948908858, 0.07115368309314363, 0.021952707866148558, 0.04527401768427808, 0.029478729120455682, 0.02367959459661506, 0.02918045069236541, 0.006696430027659517, 0.13009032409172505, 0.022875722497701645, 0.0798515573842451, 0.039099371279007755, 0.023146229759731796, 0.03523500090523157, 0.007210313951873104, 0.02953502473246772, 0.031051876248966437, 0.04457076596736442, 0.05186498296097852, 0.06677536061033607, 0.022088266705395654, 0.04513049003435299, 0.021585352187685203, 0.024516215817129705, 0.06961380830034614, 0.07412130900775082, 0.027417202436481602, 0.008820606035442324, 0.011937807175854687, 0.047356999857584015, 0.06090223396313377, 0.05302634759573266, 0.10289025551173836, 0.08856141736032441, 0.016634293933748268, 0.05800507125968579, 0.024233429721789435, 0.06975460855755955, 0.09324773855041713, 0.038309358787955716, 0.07378574693575501, 0.01673346898314776, 0.014152543753880309, 0.07073876317008398, 0.03247833788918797, 0.033494764793431386, 0.024841356280376203, 0.09455902443733066, 0.0486455240752548, 0.035420096246525645, 0.036679008771898225, 0.04679458921600599, 0.0949991328525357, 0.011256976667937124, 0.008166214538505301, 0.04637641126464587, 0.05092860039439984, 0.054589592618867755, 0.022540060235769488, 0.025070611263799947, 0.0032337781613023253, 0.06054134981241077, 0.02488250280293869, 0.019800694826699328, 0.043019476943300106, 0.03045494646357838, 0.0593144609592855, 0.07722810987615958, 0.050572963227750733, 0.06860125169623643, 0.06715504336170852, 0.0209445670407149, 0.021303441826603375, 0.06796150555601344, 0.053275698082870804, 0.03520407190080732, 0.02938528901722748, 0.12269274448044598, 0.018722467430052347, 0.007465594198947656, 0.13630352506879717, 0.02981389785418287, 0.07500228282879107, 0.05186956201214343, 0.041914155590347946, 0.053052623334224336, 0.028657813600148074, 0.04660685553972144, 0.029179376433603466, 0.07004737097304314, 0.016454859323857818, 0.03662909562990535, 0.03493739968689624, 0.033714511009748094, 0.041798974270932376, 0.083384321333142, 0.037378594279289246, 0.016723240332794376, 0.012479070319386665, 0.071818840369815, 0.03655629094282631, 0.02345759410673054, 0.016963859452516772, 0.05181499931495637, 0.051267832386656664, 0.0155496896331897, 0.03470636911515612, 0.02252838996355422, 0.0487403148872545, 0.02568329498899402, 0.06769880012143403, 0.07391517006908543, 0.03930843427951913, 0.022042431664885953, 0.04674806026741862, 0.03982181122410111, 0.028972328364034183, 0.047644088554079644, 0.0832368120609317, 0.034598282727529295, 0.09108779937378131, 0.04789453370904084, 0.03305213678686414, 0.022408926452044398, 0.024933371460065246, 0.03117957203357946, 0.0055828119275247445, 0.04282381712982897, 0.07528717105742544, 0.10403840249637142, 0.02889089064410655, 0.01542498284834437, 0.026309576714993455, 0.04302564047975466, 0.05653307329339441, 0.027043534792028368, 0.024856509080564138, 0.04074310221767519, 0.0729518178559374, 0.06651069590589032, 0.022047836355341133, 0.03989549535617698, 0.043574685041676275, 0.044527906939038076, 0.07058209579554386, 0.07487867813324556, 0.02116097544785589, 0.07461028042598628, 0.024365455938095693, 0.050649897966650315, 0.052484709667623974, 0.0259335453301901, 0.04075229000591207, 0.08033292921027169, 0.02377186025114497, 0.02859014828572981, 0.04559151588182431, 0.08326513241627254, 0.03541858597600367, 0.02273108904773835, 0.10968141141347587, 0.04688379536673892, 0.06604119102121331, 0.045053072899463587, 0.003147930460727366, 0.07574178103823215, 0.06527970297611319, 0.015344010826083831, 0.026034067377622705, 0.052614362866734155, 0.06019593944074586, 0.038196723035071045, 0.09138199413428083, 0.040422661404591054, 0.0121921884965559, 0.059442333003971726, 0.10155089417821728, 0.06558113367646001, 0.08267182245617732, 0.026529920360189863, 0.030070181855990086, 0.06205533107277006, 0.061244723983691074, 0.04943478328641504, 0.06604985188459978, 0.013272019859869033, 0.0653424218762666, 0.034439058654243127, 0.05641396601276938, 0.04823273040528875, 0.02434825109958183, 0.012489843520597788, 0.0330139236029936, 0.04124192564631812, 0.02087381810270017, 0.017495812353445217, 0.03446273687586654, 0.022883344354340807, 0.023973345923877787, 0.029478055621439125, 0.00704534797478118, 0.0058121026268054266, 0.006296311312325997, 0.009686380672064843, 0.0797884599887766, 0.04049568502523471, 0.020949016216036398, 0.026440678957442287, 0.03871371423883829, 0.11727847289876081, 0.027358173865650315, 0.034711170810624026, 0.04439715536136646, 0.17414695612387732, 0.059853931816178374, 0.046810960993752815, 0.02060977309156442, 0.004808714329556096, 0.06278167842538096, 0.03301015720353462, 0.09007430024212226, 0.031729288239148445, 0.05692747283319477, 0.06276702100876719, 0.03132718520646449, 0.01812971222534543, 0.023909133451525122, 0.046530013569281437, 0.019331874573254026, 0.09275983582483605, 0.027338905856595375, 0.03189336595823988, 0.022027503364370205, 0.048467957822140306, 0.037552854264504276, 0.02992243695189245, 0.010915399489022093, 0.04455008231161628, 0.09548943271511234, 0.035199945559725165, 0.050573560656630434, 0.06093882555433083, 0.0201757484319387, 0.04216583271045238, 0.04284766604541801, 0.02457002152368659, 0.02991076667967718, 0.034191225859103724, 0.03480798397504259, 0.039684484218014404, 0.059037294777226634, 0.010765467104647541, 0.022658189736830536, 0.031188826615107246, 0.12423578082234599, 0.14439312770264223, 0.1960741842049174, 0.14464866399066523, 0.14820228971075267, 0.15375266375485808, 0.06626178699661978, 0.19002820394234732, 0.11023868268239312, 0.1948790592723526, 0.17461447947425768, 0.09941730124410242, 0.060107660974608734, 0.0878504102001898, 0.15147308295127004, 0.17181993724079803, 0.06598284337087534, 0.2446933026658371, 0.1542324770707637, 0.1121386475278996, 0.1650505411089398, 0.1897845123312436, 0.09374893314088695, 0.11814232537290081, 0.07654373097466305, 0.1421753826434724, 0.1823609130224213, 0.10475422619492747, 0.1602777003427036, 0.1206864818232134, 0.24749808653723449, 0.14083862624829635, 0.13834639044944197, 0.1804095841362141, 0.09632106855860911, 0.09331896988442168, 0.12471102993004024, 0.194245116726961, 0.07386829602182843, 0.19407930609304458, 0.12338592525338754, 0.1279305704520084, 0.1656443631509319, 0.09091798856388777, 0.13476748717948794, 0.09368571700179018, 0.10267786026815884, 0.10930172124062665, 0.08560075279092416, 0.16579954623011872, 0.17640526697505265, 0.23932481417432427, 0.06637972910539247, 0.0979205007024575, 0.11389692153898068, 0.16880215698620304, 0.18002463213633746, 0.13916255993535742, 0.13517802843125537, 0.1817385628237389, 0.19812798884231597, 0.1374405695241876, 0.09011223140987568, 0.20611288928193972, 0.17182937735924497, 0.10694619646528736, 0.23003499547485262, 0.16692446399247274, 0.08875192666891962, 0.20302671269746497, 0.24157746986020356, 0.22288744541583583, 0.08809039107291028, 0.09677877329522744, 0.1632892168709077, 0.12355284168734215, 0.2358596821432002, 0.10748219778179191, 0.08988375382614322, 0.1926936866948381, 0.20195095479721203, 0.15539045009063557, 0.39586329250596464, 0.18862325901864097, 0.16132755728904158, 0.17391785513609648, 0.09690345410490409, 0.19224765594117343, 0.22966234828345478, 0.1813854044303298, 0.14148390881018713, 0.17756757413735613, 0.23816191329387948, 0.1896435784874484, 0.12284248761716299, 0.12584023730596527, 0.21311254415195435, 0.150046422786545, 0.22753164230380207, 0.20164516026852652, 0.18080103734973818, 0.09665050049079582, 0.12090595715562813, 0.11918850126676261, 0.13591082504717633, 0.19431288965279236, 0.18536582443630323, 0.12814772286219522, 0.26682539319153875, 0.16371293866541237, 0.1616455675684847, 0.22931426618015394, 0.08428317349171266, 0.10731436850619502, 0.14506294566672295, 0.21418687712866813, 0.16796537063783035, 0.23256065760506317, 0.12861586961662397, 0.06897641476825811, 0.17503070557722822, 0.19331159885041416, 0.14183351973770186, 0.11987877282081172, 0.08373704928089865, 0.0852620143268723, 0.11436283442890272, 0.25293422921095043, 0.16161061241291463, 0.2034417662071064, 0.2061397401848808, 0.18691602250328287, 0.13640306191518903, 0.10327951196813956, 0.1275424420600757, 0.24286867323098704, 0.18653050647117198, 0.13438980822684243, 0.15231216995744035, 0.08910999065847136, 0.1611250697169453, 0.12249022722244263, 0.16407570044975728, 0.16515962197445333, 0.1291908262646757, 0.16429589566541836, 0.11668480670778081, 0.10003761053667404, 0.16941474052146077, 0.16582767362706363, 0.2220512824715115, 0.2093851668178104, 0.08217903639888391, 0.16196252399822697, 0.12827514961827546, 0.14326286647701636, 0.11166545416926965, 0.16673198057105765, 0.16214942646911368, 0.11551386094652116, 0.28058481111656874, 0.17301525513175875, 0.24938061833381653, 0.13509697106201202, 0.15636120893759653, 0.25607879797462374, 0.10834386834176257, 0.225141629925929, 0.04399822501000017, 0.09807239606743678, 0.13171417289413512, 0.12289089791011065, 0.3512716758996248, 0.2097092181793414, 0.16755799093516544, 0.24050045030890033], [0.025832770952547435, 0.0214515874904464, 0.03215642391296569, 0.09647362443502061, 0.04757804112159647, 0.01746256042679306, 0.039818497534724884, 0.03994525635789614, 0.011748471388273174, 0.03545355597452726, 0.04752747860038653, 0.022183398905326612, 0.04542222828604281, 0.012228999949002173, 0.07721668822341599, 0.08446174906566739, 0.018343651136092376, 0.011191762296220986, 0.06285110634053126, 0.027360270432836842, 0.01681569523498183, 0.05109569123305846, 0.08300673885969445, 0.05646781253744848, 0.02932923274784116, 0.05324399724486284, 0.06563061266206205, 0.04578467094688676, 0.05666758013830986, 0.006880735909362556, 0.03344712262332905, 0.014454968932113843, 0.03385577510925941, 0.0766842121083755, 0.008913650945032714, 0.005868577745786752, 0.04472165943298023, 0.050435417288099416, 0.03090214609983377, 0.06777753456844948, 0.042358405189588666, 0.025975526768888813, 0.026264296429872047, 0.07320627802982926, 0.0782671092019882, 0.06150941095256712, 0.015311327570088906, 0.07652882122783922, 0.08013901344384067, 0.020143383371760137, 0.09717106513562612, 0.09520791383692995, 0.06483744975412264, 0.042803582473425195, 0.03013043497048784, 0.0187799541890854, 0.03715284779900685, 0.06559616216691211, 0.05495029494340997, 0.029011556434852537, 0.049905327177839354, 0.024975983724289108, 0.03325255376694258, 0.05023374978918582, 0.06570971818291582, 0.025779905918170698, 0.02788140653137816, 0.02854263784684008, 0.03357956258696504, 0.06100849466747604, 0.02902667398302583, 0.021794691638206132, 0.03446311537118163, 0.08014209335669875, 0.08231607396737672, 0.017769195437722374, 0.03224033484002575, 0.007565733112642192, 0.045129373102099635, 0.07204686524346471, 0.05708096010494046, 0.10572117040283047, 0.08592859652708285, 0.03331831547257025, 0.056347836944041774, 0.0675151779432781, 0.020936180771968793, 0.12001359878922813, 0.08004081988474354, 0.05700851164874621, 0.13089729094645008, 0.0703194497327786, 0.08482654433464631, 0.008040663560677785, 0.038824435250717215, 0.049951622349908575, 0.013065812272543553, 0.050332054670434445, 0.08160967554431409, 0.09729764584335499, 0.024739351792959496, 0.06048767769243568, 0.041828637913567945, 0.05951129707682412, 0.042718858894659206, 0.06536416680319235, 0.08914773628930561, 0.029101436084602028, 0.051332807415747084, 0.005389305270000477, 0.05866998733836226, 0.06347810238366947, 0.03627210775448475, 0.16255202674074098, 0.018943772156490013, 0.047696246692794375, 0.055490129452664405, 0.03930450460757129, 0.05917874070291873, 0.028624248116102535, 0.028301814636506606, 0.02656110911630094, 0.06017327425070107, 0.018753687727439683, 0.049371856584912166, 0.1201633270829916, 0.039174446937977336, 0.03531350157572888, 0.06273149439948611, 0.031971781281754375, 0.06279456210904755, 0.055487947538495064, 0.037469525923370384, 0.11342775062075816, 0.06639305065618828, 0.04997252493922133, 0.02514056053769309, 0.021432425237435382, 0.11083561432315037, 0.012388824234221829, 0.03325238678371534, 0.013208961427153554, 0.008206785896618385, 0.02592322947748471, 0.01301937794778496, 0.009772608955245232, 0.03523242936353199, 0.028554634664033074, 0.019232883205404505, 0.05487453279783949, 0.08309544777148403, 0.03261421028582845, 0.052256469571148045, 0.05337070040695835, 0.04153325571678579, 0.003810604325735767, 0.02732940822170349, 0.006502801379610901, 0.06975100914132781, 0.04383247374789789, 0.058282742102164775, 0.05757739010732621, 0.03916502908396069, 0.01547133831991232, 0.06652447016676888, 0.045507935210480355, 0.0986247394757811, 0.05599510528554674, 0.03838223768980242, 0.05526998618734069, 0.016288981896650512, 0.03325848723761737, 0.09037094408995472, 0.035781833867076784, 0.029040550289209932, 0.013012951876589796, 0.11478902015369385, 0.010063829558930593, 0.10065035734442063, 0.04190687141090166, 0.05080124785308726, 0.0505426279414678, 0.023290963399631437, 0.015861386091273744, 0.03287950581579935, 0.041606008453527465, 0.02140002863598056, 0.0556055705237668, 0.024673515872564167, 0.06549517813255079, 0.058703476752270944, 0.12627377029275522, 0.019852871519105975, 0.03544010454788804, 0.028676860820269212, 0.02379343448410509, 0.03807557855907362, 0.030522014349116944, 0.041656938337837346, 0.07086653131409548, 0.02904157074226532, 0.022450455180660356, 0.036765042241313495, 0.011199956534255762, 0.044750673696398735, 0.12318743785726838, 0.04743204211990815, 0.06700552286929451, 0.028491965858847834, 0.04264754963514861, 0.022759298080927692, 0.02669043948117178, 0.03694618935696781, 0.03435532213188708, 0.06379016063874587, 0.011685870304063428, 0.011982398191321408, 0.06163579870190006, 0.024839133548084646, 0.02550551165768411, 0.060372258885763586, 0.013858862002962269, 0.04714102004072629, 0.09396353998454288, 0.02119809953001095, 0.0739125428663101, 0.039035301670082845, 0.0038665587817376945, 0.07267431399668567, 0.08281399568659253, 0.04054173899930902, 0.06240149843506515, 0.02236008942418266, 0.05459322172100656, 0.01980140728846891, 0.011379277038940927, 0.07289462053449824, 0.09831025439780205, 0.03142461064271629, 0.05049606930697337, 0.044219644769327715, 0.011721216014848324, 0.0954016218020115, 0.06726209074258804, 0.022825172964076046, 0.03823432394710835, 0.04374758318590466, 0.11632582245511003, 0.02974765931867296, 0.025955631645047106, 0.03032110384083353, 0.025976563920266926, 0.03020470354385907, 0.06317889812635258, 0.04051436859299429, 0.032547691589570604, 0.02885443263949128, 0.10082378241349943, 0.04647766247217078, 0.04782842690474354, 0.0566965201869607, 0.015506875133723952, 0.008088751019386109, 0.006267887983995024, 0.03893581677402835, 0.04083525469468441, 0.02189887989516137, 0.039299368945648894, 0.041874391317833215, 0.05949695136223454, 0.08389617316424847, 0.017937067386810668, 0.0390717856498668, 0.05667691264534369, 0.06801896262913942, 0.08301202295115218, 0.04379080215585418, 0.012051792709826259, 0.02000896929530427, 0.041933009852073155, 0.04135706243687309, 0.05145288690982852, 0.06535922409966588, 0.0382944675948238, 0.06282314221607521, 0.03414936501940247, 0.10281149137881584, 0.051696611917577684, 0.025722478530951776, 0.021352267722249962, 0.01786334800272016, 0.07374323671683669, 0.022257882701524068, 0.03500976279610768, 0.036237193417036906, 0.06977736280532554, 0.050341108872089535, 0.051732843567151576, 0.03800881495408248, 0.008763379955780692, 0.0486118602566421, 0.12607300450326875, 0.032130971958395094, 0.07326755716348998, 0.06927529990207404, 0.01656104581343243, 0.021764766388514545, 0.015016142970125657, 0.0049141410454467405, 0.016115102262119763, 0.07315060211112723, 0.029176103562349454, 0.07909995474619791, 0.0578263546776725, 0.02046024146693526, 0.038372300332412124, 0.02192750824178802, 0.041469972784398124, 0.012006084762106184, 0.023221223782456946, 0.017546851704537403, 0.02487447276507737, 0.007149197163016652, 0.04610813230101485, 0.06451178051065654, 0.016303132797474973, 0.044531992461998016, 0.02298939540196443, 0.078604578593513, 0.027951661941187922, 0.11653291134280153, 0.03673429506307002, 0.05497524965903722, 0.033161046958412044, 0.06229161605006084, 0.006412378106688266, 0.06045824782631826, 0.04835819789150264, 0.060726285591954365, 0.0955181909375824, 0.08342536209966056, 0.05359666953154374, 0.03254823706811294, 0.010513275119592436, 0.03819205863692332, 0.05622609874990303, 0.02406365230854135, 0.043528734968276694, 0.02562458554166369, 0.05157837294973433, 0.01168569497167482, 0.01384172952384688, 0.16684285743394867, 0.11591201575356536, 0.19179323891876265, 0.1953766989754513, 0.08223057855502702, 0.1784562217653729, 0.12268697799299844, 0.11674869820126332, 0.11329573739203624, 0.15441014722455293, 0.10727898290497251, 0.1510734809562564, 0.10791854350827634, 0.16644895513309166, 0.12683192471740767, 0.17388156411470845, 0.1446879532886669, 0.20617233531083912, 0.1652991902665235, 0.1315589452860877, 0.1991582234040834, 0.11216236656764522, 0.13624915533000603, 0.16897598281502724, 0.10393772274255753, 0.0829207016795408, 0.19950658752350137, 0.0935587206913624, 0.1650672691175714, 0.17061661899788305, 0.08030422293813899, 0.08197041126550175, 0.1323801020043902, 0.13926947372965515, 0.14933029480744153, 0.05847838707268238, 0.1604858282371424, 0.1189372620137874, 0.1387658523162827, 0.15305587614420801, 0.12107722257496789, 0.11942495693801902, 0.13274912751512602, 0.19396057730773464, 0.1985618780599907, 0.15437870984897017, 0.12370124153676443, 0.29062229907140136, 0.22987754142377526, 0.09549324735417031, 0.2185512101277709, 0.2130617218790576, 0.1406821666751057, 0.16448256064904854, 0.1270694416598417, 0.18796953081618994, 0.12571105908136815, 0.1507691855658777, 0.14585422351956367, 0.11943024845095351, 0.1612819152069278, 0.20113828824833035, 0.15223045949824154, 0.17001954634906724, 0.19748889579204842, 0.1625749294180423, 0.2114469718071632, 0.19589186820667237, 0.22658786794636399, 0.15035710064694285, 0.2236957332934253, 0.17591889307368547, 0.13085332611808553, 0.1627315819496289, 0.1589000812964514, 0.13345974875846878, 0.10080034538987093, 0.3566487436182797, 0.20726296585053205, 0.16454651893582195, 0.15541445114649832, 0.2102953812573105, 0.2578075270866975, 0.1842039477196522, 0.1533456551260315, 0.1453693932853639, 0.13941440032795072, 0.14959031366743147, 0.25757876748684794, 0.11492324498249218, 0.29388881754130125, 0.14178671990521252, 0.17048942972905934, 0.17062476777937263, 0.13861666579032317, 0.159031500807032, 0.1563521398929879, 0.15141679847147316, 0.16727380774682388, 0.2567836898379028, 0.29577102279290557, 0.17911887058289722, 0.24179812520742416, 0.19047592679271474, 0.1635096941026859, 0.16476389399031177, 0.11786157832830213, 0.13961492863018066, 0.1392653919174336, 0.10304195791832171, 0.1355847847298719, 0.10226265832898207, 0.11538465303601697, 0.2095931165968068, 0.14070101722609252, 0.12810458923922852, 0.15232181787723675, 0.1782403458491899, 0.10679246057406999, 0.1858629594789818, 0.11783515044953674, 0.0886784763133619, 0.1797446346608922, 0.17834365280577913, 0.12366182607365772, 0.15899906895356253, 0.12339518725639209, 0.11045019477023743, 0.1205526280682534, 0.08162968384567648, 0.16965056536719203, 0.11324671853799373, 0.1299189028213732, 0.15979306306689978, 0.1524740768945776, 0.07803550717653707, 0.137182509934064, 0.14702463493449613, 0.1272154666366987, 0.15591232833685353, 0.09739041430293582, 0.12646699586184695, 0.0973280071048066, 0.1526027949876152, 0.12125760156777687, 0.12603702518390492, 0.11268768095760606, 0.15008119982667267, 0.18042614887235686, 0.16623511270154268, 0.10710293063311838, 0.13913918228354305, 0.20001449855044484, 0.22377037850674242, 0.23984877043403685, 0.12722848390694708, 0.29953816439956427, 0.08660404739202932, 0.11067202271078713, 0.18075008149025962, 0.1413540032808669, 0.23260726447915658, 0.10517588481889106, 0.18135150312446058, 0.1846738310996443, 0.13937141513451934, 0.21438163152197376, 0.13590408634627238, 0.10544023782131262, 0.14475994161330163, 0.21217429137323052, 0.09686268793302588, 0.19020511710550636, 0.13727032084716484, 0.11284011066891253, 0.0688702060142532], [0.04675153722928371, 0.029791401502734516, 0.02485624932887731, 0.024397548259003088, 0.012671447057073237, 0.008835763474053238, 0.01345816348475637, 0.03911194326065015, 0.05318194998835679, 0.013716990270040696, 0.03775103366933763, 0.06625304449698888, 0.09238286191248335, 0.03534723960910924, 0.04249126446666196, 0.06610669297515415, 0.021049818424216937, 0.05878713163838256, 0.021223390067461878, 0.008782181339483941, 0.005374064339775941, 0.039345263357972726, 0.011083614681410836, 0.011730092101061018, 0.029814576919307, 0.01157792585217976, 0.055241209411178716, 0.11193320620805025, 0.012750508049066411, 0.012606408017745707, 0.13309079746250063, 0.03951833219616674, 0.03337815112899989, 0.028332337315077893, 0.027934087884204928, 0.03403028371394612, 0.00638162257928343, 0.009572427607054124, 0.03346146462718025, 0.04633884003851563, 0.03362056253536139, 0.04665391883463599, 0.048618012660881504, 0.02559891465352848, 0.047687478217994794, 0.06851688434835523, 0.024982581417134497, 0.03761717991437763, 0.03482250409433618, 0.026962442170770373, 0.025050155818462372, 0.034694932619458996, 0.0929042354982812, 0.0414069458929589, 0.008655705460114405, 0.047066137340152636, 0.05114976782351732, 0.019742751646845136, 0.04553283426503185, 0.08192473949748091, 0.03869893436785787, 0.036207355369697325, 0.07655132314539514, 0.026341949196648784, 0.04165030724834651, 0.04275143175618723, 0.008316407602251275, 0.03057951595110353, 0.0317495711351512, 0.010944805235340027, 0.053609070819220506, 0.007358795901382109, 0.07279955883859657, 0.08708533758181147, 0.004719406133517623, 0.051551937649492174, 0.09691710962215438, 0.024463298832415603, 0.08444971143035218, 0.05248564477369655, 0.09206321148667485, 0.06793820211896673, 0.09549526599585079, 0.010738146793300984, 0.0671594739833381, 0.13021668215515092, 0.1342804601881653, 0.09686277699074708, 0.022173788092914037, 0.055100687459344044, 0.06609985779505223, 0.03794121272221673, 0.02474361543136183, 0.061072096723364666, 0.03206523251719773, 0.015638756631233264, 0.05444950111268554, 0.09082726843189448, 0.11849339833133854, 0.1538929741946049, 0.10609075994580053, 0.11355441296473145, 0.017024927074089646, 0.07616579227033071, 0.05555584662943147, 0.043995798187097535, 0.060595552567974664, 0.04462108357984107, 0.0306178775645094, 0.05794982207589783, 0.018989779746334534, 0.031969681003829464, 0.04155653317866381, 0.08124335887259804, 0.019941444988944568, 0.0169157163327327, 0.02693954320420744, 0.01847384981374489, 0.01899510094517609, 0.03377224267751444, 0.0320953822665615, 0.025707114218675997, 0.02524134975828929, 0.07724876384600066, 0.038407715619541705, 0.029848101585230324, 0.03956174412451219, 0.03469825001957361, 0.055026257468853146, 0.03591029220842756, 0.04728271458589006, 0.029367063725658227, 0.02411417030089069, 0.023180034586403053, 0.013672017048520502, 0.0634977692971006, 0.024806096844258718, 0.04968506516888738, 0.027037441759603098, 0.03520614991430193, 0.08821634837659076, 0.017693667068670038, 0.027391774601710495, 0.027723915372916963, 0.019047810128540732, 0.052760577091248706, 0.032425441313534975, 0.052830290733254515, 0.06151481007691473, 0.0351013846375281, 0.05230364789895248, 0.06441323814215139, 0.059795832785312086, 0.01879018840554636, 0.0611297875730088, 0.02644918396981666, 0.052111082841292955, 0.00807502221505274, 0.03820231882855296, 0.01816055031667929, 0.07793199984007515, 0.034700060859904625, 0.02971517365949694, 0.0301053466682788, 0.031099245679797605, 0.03875597583828494, 0.02072472620056942, 0.026786968774104025, 0.05578092888754327, 0.04207519050396513, 0.08298958782688715, 0.06647841248195618, 0.025385996195836924, 0.024425751726084854, 0.0327008894237224, 0.016929972989601083, 0.019605786437750794, 0.023815953099983744, 0.0756354683835525, 0.006577045833182638, 0.013340879104362102, 0.021333263175620232, 0.039062891009962186, 0.030676364367536735, 0.039034774745232426, 0.007587339814563165, 0.04222276656946633, 0.01817425036279019, 0.04613214448909275, 0.012794440408470109, 0.03187480484484695, 0.0497696254751645, 0.03577369621780235, 0.02870833715860499, 0.013578039815911325, 0.02308346076461021, 0.05542916573176626, 0.0534277233236935, 0.030509633470501285, 0.06502260817796923, 0.032191026548389345, 0.021621448395308107, 0.06461966651841067, 0.028425914715626277, 0.04001118133601267, 0.033996345300693065, 0.11804940848378465, 0.06127867352915928, 0.010043677466455847, 0.05837125805555843, 0.02969120043417206, 0.06333998127956875, 0.02588682898931438, 0.026860092584684025, 0.035001769865630195, 0.03983919603342656, 0.04459705654880963, 0.05052113534475211, 0.03230452690331731, 0.07312736546737142, 0.04081904990016483, 0.058787640009541065, 0.006538954639836447, 0.021959945661365055, 0.005584935861406848, 0.01707308318145806, 0.013452021285047522, 0.053028800393803976, 0.0873903973842971, 0.01822096670366591, 0.03374415609869175, 0.026251323688484263, 0.11175693871336989, 0.02451129723340273, 0.024388744532188866, 0.04607231625413988, 0.054952076097833924, 0.023545547883259133, 0.0093839796136308, 0.0619863818428712, 0.04207202153338585, 0.03163942899846006, 0.0469124608207494, 0.030703515840286855, 0.04029906041978393, 0.0625894102267921, 0.02714614412980154, 0.07226970250485465, 0.024814113894535694, 0.11237846512813121, 0.04459953532204963, 0.02119606975611532, 0.03326680671307258, 0.03543234910466708, 0.04310715426981915, 0.076469909545267, 0.036238202737877145, 0.0497503927181242, 0.045273772775544785, 0.039020061667542905, 0.047716525878058746, 0.05149661054019816, 0.14858222479233518, 0.06520833063405007, 0.03618559931055643, 0.05631543477647938, 0.09085365920327604, 0.05581870791502297, 0.06961451334063895, 0.04537703891401179, 0.0790430765482597, 0.02440567663143156, 0.025246993791370187, 0.10582760922261514, 0.13824306864989921, 0.16499320277944207, 0.07533290219726041, 0.04217697605781723, 0.039398037479259074, 0.011828505521407351, 0.08823850890621543, 0.028307011525612324, 0.0186985313121113, 0.036189406528137624, 0.026173346232098993, 0.04638288650312461, 0.04196884445264004, 0.06472423512605019, 0.0799443332653027, 0.004596121489157667, 0.03770612631342374, 0.0748372811358422, 0.023380473830911797, 0.036725842001033016, 0.025024638925970066, 0.03262566162447911, 0.02244621566205751, 0.03245634063205216, 0.04571860496071167, 0.07974197185831144, 0.04003973546787165, 0.020266255196474958, 0.031167860943241976, 0.006094086738812621, 0.010988604935846524, 0.05761877226177603, 0.015405290887429146, 0.019084273699263576, 0.034350936039118096, 0.040085355285555124, 0.00961249616011628, 0.0075031176493212115, 0.04708024556748569, 0.05701847869204357, 0.08170435132342391, 0.04501034003624227, 0.07331449058256112, 0.044872764410683885, 0.034982247670996, 0.025422086837352253, 0.05952087820332963, 0.020075996362720616, 0.030272020048869308, 0.03373922452738043, 0.027587382464844268, 0.06470047155744396, 0.053781378956045955, 0.014571313568012556, 0.07457433079252951, 0.0077685110500169685, 0.043613287853077054, 0.01940356789418729, 0.03448947274591774, 0.021710903165512718, 0.016505303101439495, 0.038379807156161405, 0.10955289370031096, 0.052439943319768645, 0.03381995906238444, 0.024614233116153628, 0.10230812229565345, 0.012832026477553882, 0.054147109331097454, 0.029485436280083377, 0.05272666836390272, 0.03587135171983391, 0.01300942760281032, 0.04999749820854049, 0.008817691250442294, 0.06277448701439425, 0.047855793600319885, 0.037282964840414934, 0.09461040332098491, 0.16066228126874194, 0.21032120799645782, 0.09441806090762839, 0.12532653752714396, 0.18063430645270273, 0.096709286008263, 0.18137379724066705, 0.17578207072801888, 0.11037059943191707, 0.0810637888207566, 0.20516403863439336, 0.16403831104980782, 0.11761606103391387, 0.15442736505065113, 0.23895099438959733, 0.16147712973179296, 0.09349735249998048, 0.0897443488065619, 0.08057851329795085, 0.09752062411280349, 0.14554546040017158, 0.12498801428591833, 0.09775115002412349, 0.0909403791592922, 0.12197383344755508, 0.19145170255796984, 0.2385468504508026, 0.11912375630345196, 0.09163642462226562, 0.2056984740193002, 0.11586069624172524, 0.09353825225844048, 0.12735218508169055, 0.10722173363319598, 0.21811013692058623, 0.1979743642732501, 0.17932438611751422, 0.1468973862938583, 0.16936393309151754, 0.17956507945200428, 0.1614321258966811, 0.09913521833368577, 0.17728791804984212, 0.12862517614848912, 0.13863058848073706, 0.1588502386584878, 0.10874852436245419, 0.14474198163952678, 0.1405750005505979, 0.1050218149612192, 0.13467608427163213, 0.2628034574445337, 0.10538123708101921, 0.1311174119473435, 0.1623298870981671, 0.2012533211382106, 0.19789998623309657, 0.12617843400221318, 0.2241914434125647, 0.1743646725662984, 0.1402366257389076, 0.1618750544730574, 0.19545103248674423, 0.2351908734999597, 0.15561604814138263, 0.08112631476251408, 0.19181535491952673, 0.16481657163240016, 0.1276262750616297, 0.14346084179123864, 0.10352845056331716, 0.14970194752095267, 0.18256785348057747, 0.12174926698207855, 0.24790009309072047, 0.18787505541695282, 0.13253190089017153, 0.18540693941758946, 0.2074414523667656, 0.1981471956241876, 0.21965856867609546, 0.23723437712760642, 0.14594899577787146, 0.3466452460270375, 0.18078588269418105, 0.23371238174149767, 0.15870004281168804, 0.09542505140416324, 0.12223335506860167, 0.2794981881743297, 0.15742996096378192, 0.1601283357013017, 0.1925180054968223, 0.279580804053694, 0.1911008745082654, 0.15947291540214792, 0.2709921367932111, 0.2754777070367709, 0.38547067204490304, 0.25508607155643404, 0.11777643914683722, 0.09261850864277221, 0.1492553824209608, 0.1626095877145417, 0.0936203337914776, 0.12603441282408312, 0.1301289306138642, 0.11746933843824081, 0.13154291489627212, 0.11832023301394656, 0.22104772069724277, 0.14599073416320607, 0.16104212729260325, 0.10601688656606711, 0.17468913953052834, 0.10419553000247106, 0.22832832299172878, 0.11411615938413888, 0.0946396662038751, 0.11971753381658345, 0.1296285301214084, 0.17010532377753407, 0.1561604579910636, 0.09882460726657882, 0.12175468466011807, 0.12652927689487115, 0.09351690066978335, 0.15234233083901927, 0.16447126516140997, 0.13024054962443188, 0.10333825295674615, 0.12358580046566203, 0.12364345791866072, 0.10304270006599836, 0.19880586653016508, 0.12495945644332096, 0.2524367824662477, 0.15296552708605304, 0.19788736972259358, 0.1973502477630973, 0.08441678975941613, 0.18640852707903832, 0.13523382309358567, 0.13729970989516005, 0.1722843138850294, 0.11357074763509445, 0.15644958388293162, 0.13042549282545224, 0.1991534885019064, 0.12068994023138657, 0.12147678746259771, 0.2025746408617124, 0.07200077787274495, 0.11987744437647052, 0.08954703400377184, 0.1831539868726395, 0.09818038597586565, 0.10917910360149108, 0.14029671001480892, 0.20313166722189635, 0.08271977261756547, 0.1268148998497054, 0.14483146980637684, 0.18998388288309798, 0.15980260708602145, 0.10284747811965644, 0.09381753727211617, 0.2073702061898075, 0.11404782242607325, 0.16387080831918865, 0.158185571199283, 0.1429908099817112, 0.15723026386694983, 0.1682772656204179, 0.09678550457465462], [0.04764858596900012, 0.03680941154016182, 0.04359122380265035, 0.040552121645305306, 0.03603246084821876, 0.020504135791270528, 0.031069582037162036, 0.05133695973199792, 0.050903029696200974, 0.05861624471435789, 0.016966662915365305, 0.036865146830677986, 0.09167376207187772, 0.035008115228265524, 0.006482597800641088, 0.053990972592146136, 0.027712302617146634, 0.023306513248826377, 0.07782676329952665, 0.07051052307360806, 0.04246106276696082, 0.01998299041588325, 0.034103619036613964, 0.05661314360622782, 0.027987598587060347, 0.07799982471624389, 0.022975225947448052, 0.059784837867482565, 0.013150553477316862, 0.03038011200260371, 0.07454635182511993, 0.04202696945867501, 0.01397480216837721, 0.03781107712711673, 0.05585794526268728, 0.007288300685104332, 0.04714023707492743, 0.05649664126394782, 0.044765579732484184, 0.023520155300502665, 0.11805303758592345, 0.028729410441883374, 0.02522004269849276, 0.029391369062068406, 0.047206106391968206, 0.047542748288833536, 0.03362804709468037, 0.023907033173600212, 0.011402813324821182, 0.04288640615413897, 0.05224065069342032, 0.023549156576336827, 0.038727132268832065, 0.03252222108130809, 0.01615208719158545, 0.04172801011009142, 0.04138809905271046, 0.05406249336374458, 0.08872031117789447, 0.08288176861242391, 0.07563351653516293, 0.03162577348120976, 0.008933237149904016, 0.03771765928831883, 0.02338838512514485, 0.019681255434988998, 0.12936710118083283, 0.0050790309524018085, 0.050164073254563846, 0.0923499847704079, 0.09267120112781413, 0.023464408877771348, 0.01466415624236106, 0.0964455638313666, 0.03852765781630296, 0.04529498335614335, 0.18494790623662993, 0.11343097896315157, 0.09505115740466863, 0.19950666173826903, 0.026922861579805613, 0.17986648046644405, 0.170675411936827, 0.1135276882268954, 0.16312785912305117, 0.1078360686369706, 0.12681096646701917, 0.03390526893781498, 0.1430761718074791, 0.12924443901283666, 0.24678152811247855, 0.07868052256526425, 0.05778605605883058, 0.058559526078170165, 0.02520807185646845, 0.007799929408065509, 0.03828870852885302, 0.06364980567013845, 0.08987823966890574, 0.12820877193007618, 0.1388958320603706, 0.060407091586967, 0.0074827350272244075, 0.019376251293579116, 0.11505198533996008, 0.02706851919356268, 0.03814663548837416, 0.019165002668160014, 0.01416782550222706, 0.030049754241190385, 0.03405045899853576, 0.04524529285845347, 0.007578126514999894, 0.0461252944660373, 0.015172635939961765, 0.03794257827394176, 0.01848510633863043, 0.07121506612747908, 0.06506791629362851, 0.05633543565636501, 0.02265264960442437, 0.03862596640828997, 0.027556609311432112, 0.0972278839617502, 0.06220111114089377, 0.01809599831176456, 0.057981560021289624, 0.02467406877258327, 0.08722895800019614, 0.04771828847879078, 0.05514423297427129, 0.06881477500428446, 0.06465898550231941, 0.021566935793089215, 0.04174152090854477, 0.026174656122748274, 0.019998375137220137, 0.061315543425735086, 0.011712773157341871, 0.029249926847114693, 0.06248546502320096, 0.017702465229376685, 0.060208463182789274, 0.043857320852112025, 0.03820646001258865, 0.054582386364927515, 0.04036698548588902, 0.027527634010766633, 0.0540766312769847, 0.039838787852204405, 0.058554902498144656, 0.025137825723504648, 0.054505681691807695, 0.05655920802382752, 0.019104803359368816, 0.07534222357207909, 0.03798440200625919, 0.005713634009225643, 0.05794667908048723, 0.05976561253191903, 0.04948549794789869, 0.011649507850961527, 0.03646659497462679, 0.04883974041149486, 0.014794766811974114, 0.07923466197098605, 0.06456350820371881, 0.05610352935036644, 0.0731491920305416, 0.05395095970015973, 0.08453073911368847, 0.035908722566091456, 0.07112075400073081, 0.015306894165405538, 0.029309415549505502, 0.015107919734873576, 0.04964811363606714, 0.0049021001632354455, 0.006129564644652419, 0.026066454702231567, 0.11153806452057324, 0.054770669230492786, 0.04006317620223854, 0.04821608032216318, 0.0363656703120796, 0.044043169473297894, 0.01899272236187244, 0.04205692996038124, 0.060136062966194004, 0.04953471347107552, 0.05264944789814763, 0.005771639807790052, 0.01917300673085265, 0.01437979401089251, 0.04359742073575035, 0.033757822748157196, 0.03317360780783929, 0.05187971088162158, 0.020782237079401966, 0.017013243814290036, 0.021369773130572867, 0.014567684465873754, 0.02117176441970514, 0.04777877351443749, 0.0435905929771252, 0.008796833189990139, 0.05124827308463864, 0.036640417092712596, 0.0628865958424285, 0.03604459125199355, 0.025612113749957643, 0.0369719530135626, 0.023051980715536047, 0.0005662082924118295, 0.02224386353191221, 0.06331530486932024, 0.09704251773655415, 0.04246137075824663, 0.025158500102406833, 0.024240146158263087, 0.015849680567043833, 0.02840429595380556, 0.02104376064380631, 0.06527136865770444, 0.015003868775238516, 0.12170527246780694, 0.021023607623646967, 0.09909664149745367, 0.08190970358555205, 0.03332204847538378, 0.020785543347301427, 0.05800876715511549, 0.049985063524218276, 0.020004544239782263, 0.030402400552702602, 0.004412057733134134, 0.07384695185464807, 0.01579829982802039, 0.03648315600003116, 0.047423169744433835, 0.07735011153272353, 0.05712827573006507, 0.15801983478013426, 0.025364652028656565, 0.10060852990136482, 0.039811933238524944, 0.05788055372249801, 0.12298863875912502, 0.044862470822408795, 0.031323526418418624, 0.05915142966841813, 0.03398573258891702, 0.08131145092193037, 0.07947294332552701, 0.0507160307461163, 0.18171083618653938, 0.011187886429979699, 0.07096382687450387, 0.0689457863336429, 0.028980313873034902, 0.10163368817302398, 0.008427651828242233, 0.10082517765113153, 0.13071268913336098, 0.06249033351195976, 0.11082123150117695, 0.06673069816315547, 0.006081005922169425, 0.0639861098898109, 0.04855733837757725, 0.05401722606620751, 0.016605428099865094, 0.0374454209668329, 0.23802678304491565, 0.18454549892339855, 0.14035124302608892, 0.00825878169052885, 0.06149648645077832, 0.038648754052701406, 0.03677281623822637, 0.08727521606488153, 0.02945203221315751, 0.06412161121261306, 0.04660309285100084, 0.057554409504518844, 0.043742792622651905, 0.012933815742144361, 0.017275123609579168, 0.03646445387857966, 0.03300298434623983, 0.007629693254784797, 0.08569483485189267, 0.017996563510678243, 0.15865239693084732, 0.06779962830478325, 0.07422014081384987, 0.033019289330695756, 0.01233632934599882, 0.048895920990617014, 0.08382934276596643, 0.029480237535608467, 0.03399952169274911, 0.013702842152270023, 0.009518196093267761, 0.05108828088850714, 0.045348629500949755, 0.0096947780730261, 0.0737839806242846, 0.050610835023690015, 0.051021702820435166, 0.037592993321595713, 0.02321413627214497, 0.04859628628764767, 0.0440987860201858, 0.03336514128022827, 0.024590810935478657, 0.05814895142975729, 0.0328485100180842, 0.08030978162423708, 0.06391998453182168, 0.07701343623921275, 0.019141098091495223, 0.04398971257614903, 0.03202510088158306, 0.060384882817743346, 0.006571125813934486, 0.035958617154392414, 0.013849457136529963, 0.02577943650976522, 0.031484245919273235, 0.04692463575338479, 0.03143688947602641, 0.023478303737647366, 0.042521165596554056, 0.025566603399056476, 0.023597442559548654, 0.04618452898284886, 0.05771902156993747, 0.018549895830801688, 0.03491389586997684, 0.021330329836928286, 0.02074508145597065, 0.03238947312638629, 0.04458034338313155, 0.008583548296883237, 0.016065014715422876, 0.08140598569298163, 0.11822026572190225, 0.03591517925087828, 0.03082608152908506, 0.013176292086427566, 0.03612231637816876, 0.09024755461723544, 0.12410107359755784, 0.19009465584531426, 0.2233095047995448, 0.16279034520266578, 0.07190497402916662, 0.14345787320053205, 0.13513286132365465, 0.17124550009611994, 0.20207150926580653, 0.10207391533185728, 0.06395013057044707, 0.18384324910584837, 0.1349961428786628, 0.18336653796723112, 0.2072311277152039, 0.09277087898226455, 0.12554612418171018, 0.15537588915321976, 0.10871226302697323, 0.19606717833084986, 0.11367334955139086, 0.13283440028317273, 0.13732886145589873, 0.09105892982915975, 0.12001594397588633, 0.10811772110173479, 0.14731518574990332, 0.10457767668412998, 0.08988211367977783, 0.12781179713783786, 0.15507793170399964, 0.16752812691265717, 0.16546173545066267, 0.13710746396100149, 0.10094486380694434, 0.08713495757547207, 0.0806164370442275, 0.11290905618807301, 0.26394149637781084, 0.2350476835272275, 0.17191886552609503, 0.08901161156245507, 0.15372091467725113, 0.18658944783965126, 0.24774971912847832, 0.1331679362920113, 0.15691572683863342, 0.15587467176374048, 0.256134340306744, 0.1072085382475052, 0.18176919867983088, 0.13696197333047166, 0.06100444254116155, 0.13309287547599524, 0.23272897669812664, 0.13801481371046975, 0.09709069054224528, 0.15912410599412397, 0.25424073566682637, 0.23047387192491442, 0.19667563552502543, 0.10304180948878638, 0.14474456431344151, 0.16494482959387824, 0.1547486407798715, 0.26684670767281204, 0.1203727166284807, 0.2794840873684734, 0.27364448353182524, 0.17159500712295994, 0.2373968332540244, 0.06643360160524026, 0.1252321363426745, 0.1950011870940216, 0.12577964836964384, 0.2536374289775267, 0.3177618974586949, 0.3527690627379343, 0.469676231732592, 0.2725995396031067, 0.3308188874507323, 0.349935928825289, 0.3328114945907146, 0.39347277546767145, 0.1674096059286967, 0.42614579724613577, 0.275553465471603, 0.2462869163719006, 0.30124994285870343, 0.45562016253825277, 0.17302215710515156, 0.16603063617367297, 0.13926171086495742, 0.15675318165449426, 0.15514433907810599, 0.15151900704950094, 0.3086759615689516, 0.2778141957242042, 0.347866375814192, 0.3191884537227452, 0.22625198675086722, 0.12388557617668994, 0.24784328910754994, 0.24517851881682873, 0.09834747310378589, 0.18300410272786394, 0.12540063355118036, 0.15274911682354286, 0.13703880045795813, 0.11183378068380989, 0.07043837889796123, 0.09246598987374455, 0.1674462086521089, 0.11737936045392416, 0.22299364674836397, 0.08796043359325267, 0.2982029219856486, 0.22709951939759776, 0.10766046907519922, 0.22003470396157354, 0.17608103749807924, 0.14115314843365923, 0.16379125008825213, 0.1373635939671658, 0.16264814970782027, 0.0946085924806539, 0.21125573519384488, 0.15798550302861258, 0.13546451227739453, 0.204523446445819, 0.17020391067489982, 0.17286428745137528, 0.14699466701131314, 0.0989781205134932, 0.12278260372113436, 0.15388745261589065, 0.10629047188558616, 0.1402934148791246, 0.14023105963133276, 0.15190367703326046, 0.1753363516763784, 0.1418707161792554, 0.1694421554566361, 0.22491788724437356, 0.16715978417778388, 0.16454037395305932, 0.12853892374550924, 0.16429769166279584, 0.11046860745409504, 0.23678956349613145, 0.12223984886077233, 0.09755714519997127, 0.14430570270633325, 0.13789375458145514, 0.16515405586687848, 0.1447956686024554, 0.14414538396522403, 0.17184698110213503, 0.14840433199424297, 0.13648379273945466, 0.1044197179726325, 0.11405645360355265, 0.06453887632233091, 0.1270213653333485, 0.09840274826274253, 0.15508864831645042, 0.15612511691870168, 0.16291737119900063, 0.1158433745149523, 0.2834637206979096, 0.2280412008985877, 0.11606574422330596, 0.14574279746739194, 0.17794431798392907, 0.16054845065809786], [0.06925032663275488, 0.04834749983274378, 0.017447064383304678, 0.07429511257214472, 0.019477476525935344, 0.057638413200038485, 0.028800758664146997, 0.05676154716638848, 0.030320855221361853, 0.041183607681887224, 0.043032661196775734, 0.018615212247823365, 0.06647292801062576, 0.02955003652459709, 0.030433570755121764, 0.02038373346294975, 0.00392771035876649, 0.02093317136313999, 0.024254514137282968, 0.025198865514539648, 0.02360599952226039, 0.04692049085861072, 0.033228582396986894, 0.09609918124624528, 0.019093589507974684, 0.02622726697154576, 0.11326446328894235, 0.07616199247422628, 0.041866253668558784, 0.07384689248283394, 0.02728876264882274, 0.027440010489954147, 0.026371095191279892, 0.05958891459158622, 0.05802373627375346, 0.0596428316202946, 0.06746181010385044, 0.016926163916650694, 0.06253805360756814, 0.05580971308518201, 0.03190634983184282, 0.043237482823315077, 0.0573150186392013, 0.0628990119730588, 0.011807100127043668, 0.05329075996996835, 0.028500467160483822, 0.04813670391740743, 0.03146778137306683, 0.06986888445680961, 0.04263356015144382, 0.03472081873042043, 0.01841728331783088, 0.04773130203830078, 0.025440048666496295, 0.04843113987590186, 0.06421356330974959, 0.05090104074042756, 0.11796638442319818, 0.09319257471361198, 0.05809015849081334, 0.04478676062717568, 0.04916891630273312, 0.026820192870218307, 0.09920626413077116, 0.04972039139829576, 0.05010425615182612, 0.11219454609090462, 0.011395080146030523, 0.03720746244653128, 0.0728381727822125, 0.06276643471210264, 0.04909460876660887, 0.01321938210821827, 0.1254490957944654, 0.026966126933984924, 0.17833519232226536, 0.11155640298966318, 0.17220203939359635, 0.15551753545878455, 0.01159410652689985, 0.27946963033173233, 0.12902995833428577, 0.09885228195344098, 0.21149561216589063, 0.12256032307050191, 0.10993610907462426, 0.1460661512101069, 0.05493237578775734, 0.17697308416245505, 0.15780986635945737, 0.030251015414251015, 0.03522458857332822, 0.03352839521539863, 0.06171465931402054, 0.039762406013323925, 0.07057154987705871, 0.07975435088155791, 0.16519071796210483, 0.2181619091425091, 0.1091089632245712, 0.08285301781143062, 0.07524797823862173, 0.05139991611940786, 0.04198604743578471, 0.0755093403859064, 0.052409600612008944, 0.008703458024683641, 0.023658265272388235, 0.07764087014948018, 0.0767477993213106, 0.06087421046686359, 0.010573666459094966, 0.046255051565822214, 0.04287043513613753, 0.04370119524537586, 0.06513688407721929, 0.013574498843809124, 0.012322204420343041, 0.04597533981723245, 0.041539608500897884, 0.020329371145635378, 0.02272597936098464, 0.04300301610783208, 0.07302624042495154, 0.029032310594629962, 0.03310298874566797, 0.05118598463013768, 0.06830649290350266, 0.06143118116597179, 0.033628592573222704, 0.025919680156221148, 0.017239600711036474, 0.024148763659468386, 0.03060892726352904, 0.0606790924211964, 0.04896128193649929, 0.058719533117255196, 0.02823065937263891, 0.06389049900462851, 0.011731586600944865, 0.04189295243122615, 0.03875504815368913, 0.044461655415943824, 0.035387838797760196, 0.04746858176076785, 0.016161284256668296, 0.050656451130635105, 0.02056634817563463, 0.05123618720972445, 0.032416442772955634, 0.08460905053652823, 0.01707559535134351, 0.0648949142487254, 0.08364910478121601, 0.03292173030786216, 0.019327017216710374, 0.04544758005067706, 0.04823794028197881, 0.00828412046757876, 0.03708232892677188, 0.03604276185797062, 0.010287670575053198, 0.052727525544469245, 0.018077552231261507, 0.04690841611591168, 0.020980596455046907, 0.08027806965401396, 0.03299511758086737, 0.04465395330043975, 0.08237056987127289, 0.020680982161138672, 0.027266540892014746, 0.056093358216458, 0.014171804341458483, 0.09737951215356588, 0.07515438599511981, 0.12031303311232477, 0.040657799763721414, 0.03552915484760888, 0.03999127322458662, 0.017257341751246713, 0.054245032006292604, 0.0405299462727271, 0.0678462722862605, 0.03768509384826757, 0.008432281902059913, 0.10355200633057393, 0.0143160565130529, 0.03357092027727049, 0.015854441444389522, 0.050797533403965645, 0.039411466641467996, 0.04657567049434874, 0.06110766786150634, 0.09249308568541892, 0.0644608617585618, 0.03912158004823141, 0.038087059583631344, 0.038727900391677395, 0.025512790271022823, 0.04816230801225174, 0.04817610082682222, 0.028355442227621097, 0.04619995452230796, 0.06146119732875377, 0.05180254978768062, 0.06394948490196839, 0.05772129996330477, 0.0367239421029808, 0.03371801023604348, 0.03055021596082952, 0.07906894781626761, 0.03420177919906564, 0.033022031566360965, 0.030516528022417333, 0.04698826749518048, 0.06602131630643271, 0.020433548270375468, 0.03049922113859793, 0.007010143735897145, 0.026857437551370822, 0.06727938278345391, 0.05293069960316643, 0.032587444729870185, 0.09471357669099234, 0.029961036052554846, 0.02041764590103412, 0.04234687963617034, 0.04110376743483357, 0.057330689087393694, 0.03693727987410966, 0.046463762046187185, 0.050368204683763906, 0.03275821291026659, 0.037425806003739126, 0.06905822170665488, 0.007537377505286713, 0.0924456847133115, 0.029178374534239992, 0.011773233145504491, 0.02328279791981913, 0.14337919070385396, 0.03392380036530085, 0.036233300852472894, 0.06738606651197188, 0.07787592316162772, 0.22319481329759583, 0.1317598595051095, 0.02657946799445199, 0.032748884113971144, 0.10423517553135753, 0.09541973020532168, 0.06686058884952217, 0.084691874217242, 0.20192494994262233, 0.03686492047563661, 0.131145361228846, 0.09715968059026636, 0.1520866312785074, 0.15594532422255725, 0.10453553753904998, 0.1005893008550629, 0.14537130802636966, 0.0714732964115683, 0.039051391431712545, 0.20297600916819647, 0.062241647246992216, 0.06366241475916468, 0.06260633861529641, 0.02995151615323266, 0.06809557453379966, 0.05401396432716865, 0.16067995922639966, 0.2855078922584653, 0.3430554480291903, 0.1461668309639208, 0.044677664918708615, 0.014529341406159801, 0.02048609974735882, 0.14091613615164533, 0.03640905626525637, 0.04989671455405187, 0.0705375817778986, 0.030100847397989128, 0.04646553206839599, 0.08871759491739795, 0.01711011635052273, 0.01970885776245268, 0.048389004441560246, 0.07367084763245657, 0.030405775469262153, 0.04154308917350136, 0.019650072244985495, 0.010852758514374727, 0.06786812111386098, 0.013634579408972058, 0.008141840553435031, 0.07682936135097407, 0.02334997712750919, 0.020794480660697445, 0.03290247899712995, 0.04670103036914952, 0.012453882754925871, 0.025001367030199617, 0.022847845575597603, 0.07843810002668761, 0.0073494596836098935, 0.054421822715085, 0.03324026009067893, 0.01621578943741042, 0.13850642717443407, 0.02259541146486299, 0.0379586383496644, 0.018220181882497855, 0.02598665712866932, 0.006778588558518095, 0.039761578518664464, 0.055133635105448775, 0.047629572145524435, 0.027009540717699565, 0.03905323566868901, 0.02371133439737605, 0.06151071342173964, 0.044892616861034185, 0.016773769457358867, 0.010723187879193574, 0.051551099022617564, 0.05227672649198212, 0.04613736178725958, 0.011057025385525776, 0.02679669276403729, 0.045580105361295864, 0.01563225541758584, 0.061495551344705746, 0.04897521575912833, 0.04113365001103375, 0.04131133129703812, 0.013782575715595158, 0.027681136125465855, 0.05357909176382236, 0.09448357770452276, 0.05823363419040106, 0.05169080832274631, 0.07415532905724831, 0.03940493203117512, 0.059639484534272924, 0.024903340454329737, 0.027118098369101062, 0.02006554506806424, 0.027894605627807323, 0.07153585946070962, 0.25358503335155547, 0.26849166315514594, 0.10617972118780017, 0.17713353649014607, 0.1729573676129803, 0.1269949894049205, 0.19015315192518756, 0.1686288951896131, 0.188654369849246, 0.17520396737381816, 0.0723793548240792, 0.15278693666914478, 0.14633779210271314, 0.08973939868155867, 0.12185414729174227, 0.10955448189633898, 0.12139185608248226, 0.14662126282928512, 0.10024112969404086, 0.2204266469925642, 0.09996764827519655, 0.04862926361965947, 0.12727295339573175, 0.19132433517370373, 0.11356556744431145, 0.1291712632519193, 0.1505734070087783, 0.1892451342428103, 0.09872575319604948, 0.19223193725338206, 0.12941344088176265, 0.13007199304411188, 0.12499743956141174, 0.131550291844178, 0.16077568143373355, 0.22977558517595753, 0.14191315218340605, 0.1340427206014283, 0.08827357538393699, 0.20600797928636894, 0.10711746188462712, 0.1659453782485798, 0.12193560542073101, 0.0880067287653219, 0.15525367227382958, 0.09446247844607569, 0.12599534617038444, 0.223783930123318, 0.09482708817813545, 0.20675910694990307, 0.1276867007254623, 0.15910917398286983, 0.13020819198573008, 0.16477299272082746, 0.22746875270968303, 0.08207743638195097, 0.28218556428328156, 0.21277106716297567, 0.29666391550563276, 0.23958759382367134, 0.18910575890913606, 0.06534052197821438, 0.1552999674458988, 0.19707599451066926, 0.27113421354442835, 0.1629949701600708, 0.20019635441713035, 0.15668061445467174, 0.14139314414933324, 0.2376867161365226, 0.3354226372903213, 0.380556823220104, 0.3297155810287222, 0.14844102377537638, 0.14679568237625062, 0.16405938804382458, 0.28487308882176876, 0.3278675739420578, 0.33985438698437065, 0.34784598159603775, 0.18056607339531183, 0.28705705131869763, 0.1990810697316192, 0.19959031662438065, 0.34225354262162, 0.2644277218496427, 0.19618279009591788, 0.19287871895357966, 0.15530676551861688, 0.2107320461072959, 0.22763952089007944, 0.25736200099345297, 0.17309203773038462, 0.1338569461950101, 0.11514166646520607, 0.21797116234665737, 0.20812290720641613, 0.2916171035030857, 0.46298710629343987, 0.6839071924332529, 0.2860835910541937, 0.19265318027464673, 0.15405416866997257, 0.10560274589806795, 0.2262203861027956, 0.18814746814314276, 0.17524714552564546, 0.13807972194626927, 0.1475268611102365, 0.12493410467868671, 0.20081981783732772, 0.11578930163523182, 0.18303466436918825, 0.14284662553109229, 0.12160811049398035, 0.07890508160926402, 0.1451591428485699, 0.15077059564646333, 0.08539387170458212, 0.13568352005677298, 0.11905900391866453, 0.07401380891678855, 0.17832465382525697, 0.1408480663667433, 0.13235139573225752, 0.08521209005266428, 0.17911594652105123, 0.0820738666516263, 0.1371908071450889, 0.20479211874771863, 0.14807067724177614, 0.12355077109532431, 0.08692141200299375, 0.1282263163011521, 0.09789859250304289, 0.2529040089575574, 0.14536268427036703, 0.19558558386052027, 0.09255938173737377, 0.2347656525671482, 0.08403850224567577, 0.11567459529032931, 0.11138143425341696, 0.274127057637088, 0.11875889424118213, 0.14789357112022117, 0.08797863847576082, 0.11330168199492618, 0.1707661320688203, 0.0964542172732763, 0.12275789020350203, 0.09050741762621328, 0.12038728498737328, 0.17325691325822845, 0.16389316180720925, 0.1694455396500416, 0.21472990658367053, 0.09645022451877594, 0.20884716912405565, 0.12676655635004863, 0.1301911671180278, 0.12073878839146346, 0.10001032176660374, 0.11421015980886295, 0.11665855694445781, 0.13454136962536722, 0.1651262995437719, 0.11221969005418941, 0.14808543113758788, 0.18522063066484407, 0.16650402249069884, 0.09205204216414131, 0.11997549692750908, 0.13149448233889416, 0.09815307494136505, 0.2941143116913736], [0.051430010207695886, 0.02412785735941725, 0.018280475815117825, 0.04790583661815617, 0.03027305534487823, 0.03252263297326863, 0.04344727312854957, 0.07538312333053909, 0.02847264589945553, 0.01028075190333766, 0.056147186187445186, 0.04516946020885371, 0.04012620680441614, 0.05425539238785859, 0.038622656429652125, 0.021706782390538137, 0.033658118918538094, 0.04576300023472868, 0.055749435850884765, 0.01671616581006674, 0.008586922285758192, 0.04742633500427473, 0.053619271639036015, 0.020982680034649093, 0.009595349765731953, 0.04562807036563754, 0.019700805460161064, 0.021532746904995292, 0.06906501977937296, 0.0029882471835662727, 0.019735541682166513, 0.05324803823896218, 0.043336429662304, 0.027999484082101844, 0.05645715158607345, 0.033724990134942345, 0.040685986532480456, 0.06705982581479475, 0.027214373476454057, 0.04123072292713914, 0.03951591279474087, 0.05528222791326698, 0.1193375393631868, 0.0013917968499299604, 0.02810363152093487, 0.027166575455339625, 0.033894704465637915, 0.038716103954357095, 0.014769057888770476, 0.05065003155323211, 0.028954487133887596, 0.062107722988002934, 0.06762203978723846, 0.01541212421216187, 0.04793291387613863, 0.026011860463768244, 0.024189761752495542, 0.020697507934528403, 0.10962870408548042, 0.05700384725059848, 0.05277881908114068, 0.05731560493586585, 0.032322089828085154, 0.07645987570867874, 0.1523635711055249, 0.06433799921069294, 0.09014937590109184, 0.04292904995963909, 0.07702226779656485, 0.03940697664802428, 0.06924579953192733, 0.01814738647226477, 0.10511900662095286, 0.1667158759664744, 0.18727971939370036, 0.33616891130805016, 0.6832837290130556, 0.8325596095528454, 0.6212620320729911, 0.7028063095640391, 0.6695441412739456, 0.8903957123402506, 0.7858889701310545, 0.5987276381347328, 0.45166258583776653, 0.18573608191218227, 0.08299957713461481, 0.08914215533877723, 0.10452033093315549, 0.2527792687760666, 0.7085807528346777, 0.05825526408443693, 0.25916918995790184, 0.2564378490205854, 0.12251241743797436, 0.03515641488775145, 0.058838777695200406, 0.016440751096524764, 0.10734072959166951, 0.3050723299384117, 0.20928206766257063, 0.022337799018714577, 0.1066891907248646, 0.17712504632072523, 0.14952616242226213, 0.05573935377469752, 0.04400478930620011, 0.05763209752331022, 0.0865389610407874, 0.030928948763175867, 0.05243961306405254, 0.07734736558631994, 0.043810454226331785, 0.10990131719154306, 0.006339089632092509, 0.0423323706490919, 0.04303125853766687, 0.026667009879020043, 0.04201388539513573, 0.03691038815304637, 0.038443613302661106, 0.04597096114594024, 0.04129314125748351, 0.08123026738758199, 0.035653913582791574, 0.07389493170194328, 0.06601589862839319, 0.04597643819579389, 0.045905867373221554, 0.024097269742924254, 0.12012629391392693, 0.0071698715419188375, 0.018911800434580073, 0.05677356253727339, 0.05540595135244075, 0.01724766414554324, 0.0342999876011163, 0.060139907291159034, 0.03178286016918719, 0.03743916837265715, 0.025188646141032223, 0.05164932968909852, 0.018305469493498094, 0.03436905928538181, 0.08129492329317145, 0.01881660700746579, 0.05648406186082866, 0.033225829029106535, 0.023081987601472065, 0.058306026985519566, 0.06611770644667558, 0.011394979956094176, 0.04677696691942401, 0.01317604996074806, 0.0372130582400132, 0.012084900845366064, 0.03939600399462506, 0.07112898441846482, 0.023077428959368262, 0.05587935622315854, 0.04560916786431335, 0.06145940875285305, 0.008474994356220122, 0.02323287735634949, 0.055982106568990275, 0.06231563937035389, 0.08133610506774858, 0.032500101369805634, 0.008442562502750661, 0.03993689235358033, 0.04367623681901023, 0.022596680537390057, 0.020473561162361875, 0.016925405070651323, 0.037662525137420744, 0.06785177160054445, 0.06321529304841533, 0.020328630853327923, 0.07520767961977981, 0.06720889359712601, 0.017720874202495907, 0.03735606267582625, 0.006722654743498424, 0.05392625731474254, 0.011445842119428562, 0.010642460765666328, 0.10602844922686927, 0.01976815165107837, 0.03594437905121595, 0.0365380341099808, 0.05093445593956858, 0.06452956236898899, 0.08963533473433927, 0.08939959152485244, 0.04152760797296651, 0.08004582196008414, 0.003097009389421146, 0.025604681140976027, 0.03692273377964739, 0.06582691814401187, 0.02942806269857101, 0.09208878589561209, 0.052113632118562236, 0.047974533517844975, 0.0621183097246103, 0.0243893122751615, 0.024581214966019616, 0.06709555280394852, 0.026536557015788276, 0.028449207020457834, 0.016953365484368987, 0.05842089660291094, 0.05802473446237855, 0.03454848090768792, 0.007131489055609563, 0.03380706053576432, 0.05701717993360944, 0.04561474510410335, 0.026758127060020342, 0.010245722532999935, 0.04376127209980041, 0.10086616646731272, 0.019720259006135166, 0.026198100567853544, 0.043200264117331244, 0.042831528044189326, 0.06472444292739965, 0.04542172733636107, 0.044775632122764364, 0.051049436879111454, 0.05393854728026781, 0.044545406781253405, 0.04029828487546183, 0.06721817786456086, 0.03204667511454318, 0.08411140341195278, 0.052224520113668405, 0.0205562846531393, 0.07221161460620351, 0.08267432349384762, 0.13214540522312745, 0.19037551421206445, 0.1305794290965423, 0.09496547645539977, 0.006896709246575483, 0.01865270740381675, 0.1260696499957703, 0.12216813513077796, 0.15588063863106072, 0.05153153972059954, 0.06481673641246744, 0.0788488713442348, 0.4490915487986058, 0.40507138590328395, 0.3523944562766701, 0.8428181090857834, 0.41444830305408686, 0.7072257692925632, 0.5403236439451575, 0.5229097127448767, 0.3974181809462607, 0.11206849972950295, 0.03590255531889852, 0.19245082628913224, 0.14610183367040008, 0.2182814691332169, 0.6854454567655921, 0.27906961273401976, 0.15048114320961758, 0.07770804935717024, 0.047013277871883474, 0.013859002083336236, 0.041931655432563275, 0.042414429917698726, 0.26784578687511384, 0.26730974845122546, 0.1586453613708727, 0.031603215902578086, 0.03203383595973719, 0.1811212592292577, 0.1741750241490081, 0.02304631441802485, 0.047970277300919406, 0.015475500840693712, 0.03309258754597977, 0.03614851048041601, 0.03158403509587515, 0.07003007893217728, 0.025232610969396774, 0.044522374228108674, 0.02196197357989149, 0.034636176787898876, 0.04462107244762592, 0.0459587750810897, 0.03145495335047599, 0.04871350851317402, 0.02965917119581718, 0.05175486679945607, 0.07233427677419968, 0.030454573534370866, 0.02677035765373148, 0.0596372321160743, 0.022665076867269818, 0.07279953657416627, 0.057923319982364774, 0.04699335862824228, 0.1303141558310017, 0.058207150650559925, 0.04105588035599794, 0.032742241892265156, 0.04055769517435692, 0.01913274150865618, 0.01609219401871087, 0.0999870925443247, 0.016000761424947996, 0.051122204458806664, 0.027610205361270346, 0.020191645235172473, 0.038651232825941406, 0.042787793281604536, 0.03201406143489294, 0.027231504100200254, 0.034020398306893185, 0.07465480928658508, 0.05322164004610386, 0.03443582289037295, 0.042680285769165494, 0.010371817134000594, 0.030918792472220957, 0.0688637196435593, 0.07283014274435118, 0.038590135518461466, 0.036711017601192, 0.09013077025883831, 0.052946447976864874, 0.05005945640732534, 0.0784311089955736, 0.017778236651793122, 0.02453416836942779, 0.021711172194045503, 0.033984352194238454, 0.053940629004500806, 0.031953338911989704, 0.04078089237737004, 0.027666961104841903, 0.032570471812505275, 0.058199291306664236, 0.025742041543708183, 0.03698927102959715, 0.02308429939148482, 0.033758097342797555, 0.012588443405547878, 0.15906513493973762, 0.09547077512252145, 0.16600532893789932, 0.10791968641569838, 0.14459454658208415, 0.09618095849873498, 0.2286857709987089, 0.16725517984014004, 0.09346423044917174, 0.07579909710329957, 0.16496154275955632, 0.21689369750674814, 0.11215800273930654, 0.0985044521803502, 0.11353508001775481, 0.20610068837413564, 0.21034037024946883, 0.146920467086602, 0.17571170028531924, 0.1713937069871463, 0.08068975381320342, 0.13672282366314903, 0.17674827278824523, 0.1869480387540534, 0.13810994219966233, 0.14690299693029374, 0.14689245843328536, 0.14658351719845086, 0.14791539026191458, 0.1597711251815781, 0.2164214095682837, 0.09071302964002825, 0.23544691444840282, 0.11694944172631949, 0.15220394998323172, 0.13752889994066209, 0.17846263392129913, 0.10541041832766496, 0.13640942954225466, 0.12550961051601917, 0.1798255881294608, 0.18457353726262227, 0.22707444964908063, 0.11817934369901195, 0.12140232036472298, 0.2560818853089586, 0.10727875283919275, 0.09641969998483546, 0.10664481029380113, 0.11585274784010835, 0.14130643161479384, 0.10183558944845572, 0.17851499986136332, 0.21974116971250623, 0.15361177443992347, 0.17080387769965455, 0.14740802842425182, 0.22825692838523537, 0.26303025777451694, 0.222816317982506, 0.14963429333874956, 0.10873426028410904, 0.15453724743565544, 0.43098560941871256, 0.26550113456323743, 0.3254246909637004, 0.21754791552666575, 0.18465563363861293, 0.15041849110275507, 0.1708488815347664, 0.283037104527466, 0.19432734668953344, 0.2701199648436159, 0.3074109856970608, 0.5134659132454544, 0.5309104803018272, 0.8615079999435693, 1.2126378365792334, 0.911913838936016, 1.260566683486104, 1.1601947131566703, 0.9035166457761079, 0.944187407149002, 0.8617767167743295, 0.5269501428119838, 0.1929863155237399, 0.1496378259616904, 0.2216200204566121, 0.21088010456878692, 0.2052694236044772, 1.0061089438386261, 0.548432586947456, 0.35442553635220975, 0.5349418264813721, 0.406960686086677, 0.21093837800435722, 0.24134670646162704, 0.11478882719529793, 0.32075331662781537, 0.46124537475407124, 0.34311194031033665, 0.13615123636554927, 0.21824194234795868, 0.23923431668663397, 0.2515104931080714, 0.2216493946616538, 0.13990908628329635, 0.12425165536114946, 0.2529015450272709, 0.20349257363704965, 0.2099607023410499, 0.18050943268463016, 0.10616576139000244, 0.15355290728621185, 0.0766792100330349, 0.11079861083999276, 0.1764560744049959, 0.18635445419931784, 0.23835798871004954, 0.17248470860067755, 0.10913190300925635, 0.13262593100080267, 0.13840331317624077, 0.2222217241069302, 0.11956395377637818, 0.1899057495757006, 0.14227392501197755, 0.24487002287060022, 0.07665914978133515, 0.1612409931840375, 0.3846136399079114, 0.10843363852472976, 0.08284040872240439, 0.14125767251243815, 0.13168125122319907, 0.11191051875357516, 0.09252468633349054, 0.20428122428711504, 0.13424995791865513, 0.14334606123156846, 0.18835577415302396, 0.12545372679596767, 0.08297002481413074, 0.13292498682858422, 0.12505062186392024, 0.07755276237730868, 0.20307618426159024, 0.17869556439109147, 0.18531415611505508, 0.14297139539849013, 0.1534515744424425, 0.1511387454229407, 0.11871170107042417, 0.15579836413962767, 0.16264377103652805, 0.11400238814530894, 0.11033772971131839, 0.19128823711071163, 0.1721796116908081, 0.15758846886456013, 0.16833850764669478, 0.19935849937610328, 0.12044465300277807, 0.12082236906280741, 0.11956518574152142, 0.15923136117635295, 0.1973173557780683, 0.07981852439115755, 0.09312805981608108, 0.16163744847290218, 0.17218071006936952, 0.17972180619835854, 0.1014854664390441, 0.1521501294337213, 0.13864189881132916, 0.1762620621593669], [0.07075811838149093, 0.03379187619430013, 0.012697401816694764, 0.06757641996955499, 0.025644348934292793, 0.018957694846903905, 0.048572121959296055, 0.052221777878003195, 0.05081971248728223, 0.016648207347316202, 0.08819205788313411, 0.04988970496924594, 0.05979415182082448, 0.07844725812901743, 0.06102797604398802, 0.030848568603687454, 0.03183196437021252, 0.007924680721771438, 0.11443549068644643, 0.057755705929594114, 0.051788786659017205, 0.011295816038909834, 0.03457189195614774, 0.06308222596999258, 0.04485772849875502, 0.012019564946967876, 0.0880277092801407, 0.015363716702267993, 0.05989557001157664, 0.05126354648382403, 0.017147776634374168, 0.03132305515464395, 0.036062028011656366, 0.03557188028935343, 0.0278170604724437, 0.06881389927002601, 0.057905797875719145, 0.02960616515338188, 0.012464116043702234, 0.05281373341858853, 0.05608054874755908, 0.04423203121405095, 0.11905420222319663, 0.04845481438678689, 0.03739667299669236, 0.02832372840202879, 0.041441066132392734, 0.02468149581545731, 0.066861071245512, 0.05204963672440499, 0.029123559506842867, 0.08294403480249457, 0.06153278118290473, 0.04290242541173939, 0.050583809716044925, 0.014629317047365475, 0.007532805875598569, 0.016414666461059824, 0.07751336917863227, 0.1977251807693392, 0.0573348933539819, 0.07321980738197453, 0.034405179612804204, 0.11261342908255756, 0.14913885039277375, 0.020991125675209332, 0.07532182193244807, 0.020771002818946727, 0.1035384918213822, 0.49922950216569006, 0.5751263326965272, 0.2883557800669223, 0.7912451983429492, 2.942561390809715, 2.9282907815650105, 4.8165488708764315, 13.556995186954737, 17.483215257525444, 24.33858510106802, 23.527254536747932, 18.909679614007473, 21.77942432463169, 24.589303247630596, 33.64908680319786, 54.25065033137798, 59.9129468947649, 59.99070592224598, 67.01258093118668, 69.86732214689255, 64.5373709499836, 42.615176886320114, 14.331123847514391, 4.073931444436312, 4.255340360105038, 3.539283270947635, 0.6425740197300911, 0.5731381487566978, 0.40062793996185064, 0.5873372149653733, 1.0035143955610693, 1.1258256761357188, 0.16417088831076398, 0.09118707646848634, 0.09301002864958718, 0.07082310825353488, 0.15587412257445976, 0.03495601275062654, 0.0073574966791056795, 0.09172681078780442, 0.026679246038838755, 0.013732168117712718, 0.07977661531185731, 0.04529101286607329, 0.015684307800256647, 0.03144565795082599, 0.05885483777092304, 0.02481698786141351, 0.02752182484982768, 0.01878704355476657, 0.02491817042027833, 0.06318214131169952, 0.04558199041639455, 0.008027398598642321, 0.016556427799514495, 0.03210995804693084, 0.023374169286398683, 0.034805134127964266, 0.020134254955337383, 0.020098346140002832, 0.02633093943586573, 0.061157692325650714, 0.016262605968222488, 0.043161349603906274, 0.03847019332170021, 0.03892368637025356, 0.1132326696824748, 0.022039281247998588, 0.07368700418737717, 0.014712780830450356, 0.026609289343468845, 0.03893887442245614, 0.036592778633348644, 0.0252024834844633, 0.012430737024260452, 0.018023833727056626, 0.030231688033381943, 0.04144890692259651, 0.050333546387264505, 0.06917479084222578, 0.03922030795365572, 0.025666626352176536, 0.018066818920488004, 0.02383209295658162, 0.019252641031926032, 0.05634856795950327, 0.0883265573065728, 0.038095241761766374, 0.04628062968549784, 0.0523932548094308, 0.08122820421704091, 0.048941537097562104, 0.0554296444170177, 0.018738809521892108, 0.04377910590847023, 0.03379361653060187, 0.03948775200115051, 0.0445710368512664, 0.060386945988284424, 0.08934640180086717, 0.06644510489422828, 0.019548796917661093, 0.035625604359665886, 0.024567650361859705, 0.01686501836957177, 0.071025855577318, 0.020625525176001247, 0.05480162049934734, 0.050443035434000194, 0.09355780784972012, 0.03506949455186259, 0.10203493031440303, 0.08008039119886234, 0.024828348286973778, 0.041725264163687825, 0.061747866711812094, 0.040527526871301234, 0.06317796302028, 0.044389129034243524, 0.05720728848245926, 0.07700975518673658, 0.02803900344588328, 0.005518349908015807, 0.05986123826005496, 0.03966897704231087, 0.03047579710255377, 0.036116167684667744, 0.03212069692381192, 0.020030829255119897, 0.05844932828040328, 0.05301917844917625, 0.02433852896501776, 0.0231518942018738, 0.013210938323027221, 0.02706817595026223, 0.044979982485529035, 0.03997687184892129, 0.07459249856765382, 0.035673766033141874, 0.037306665326468647, 0.024571921421738807, 0.020300766918808222, 0.011178910153830657, 0.015872418116487097, 0.019262927198724356, 0.04842371468839701, 0.07896118797361851, 0.07188860967289656, 0.016219338758673985, 0.026514019846217707, 0.029874165811634157, 0.05121368158143014, 0.031946329327183776, 0.037270493048708886, 0.04418532786075957, 0.01587072416441515, 0.043774237419711426, 0.03222093509975821, 0.029670848889509216, 0.028836639648943674, 0.0895037519512698, 0.0895312633656431, 0.028389762846927624, 0.05294036978739314, 0.028614757902687415, 0.06617010207264684, 0.0884083345590625, 0.10657223567250185, 0.049308877933071926, 0.0554947790078586, 0.06133806389698293, 0.11694265107507817, 0.12493014161009341, 0.2567371423356235, 0.07315562645089813, 0.024362839867535513, 0.5704278848133981, 0.641865060897544, 0.5579044099431485, 0.18007502396358177, 1.2927249516360462, 1.2457644590176642, 2.756374469026923, 11.685039885342121, 15.172890778630972, 23.001315258443356, 23.778305165469646, 18.263113908469677, 21.1402815207839, 23.754033967852592, 32.50546596944332, 53.327858448028564, 62.564809396862984, 66.72840937972069, 69.45534825325012, 69.82918739318848, 65.54484128952026, 44.674252197146416, 14.341557137668133, 2.5502212811261415, 3.611979545094073, 2.5702127208933234, 0.3797660203417763, 0.15551766904536635, 0.40538074274081737, 0.5595300102140754, 1.1470305570401251, 1.059739503543824, 0.06656944431597367, 0.008753480633458821, 0.0728342097136192, 0.02890946103434544, 0.06849605226307176, 0.11994598171440884, 0.04865248170972336, 0.15744587260996923, 0.17042294814018533, 0.015323828120017424, 0.00893940439709695, 0.005628842709484161, 0.052558545939973556, 0.024371539693675004, 0.06772212582291104, 0.01347442579572089, 0.11141466020490043, 0.05557380289246794, 0.027790408094006125, 0.024745027367316652, 0.10553071304457262, 0.042538802736089565, 0.04775450528541114, 0.06973695286433212, 0.0794413426774554, 0.05855163704836741, 0.04651123352232389, 0.04976305746822618, 0.027862186761922203, 0.03500470505969133, 0.026564684412733186, 0.030932273584767245, 0.09197681065415964, 0.12028658296912909, 0.06321585708064958, 0.02781370782031445, 0.03791691480728332, 0.020897197609883733, 0.06660640327027068, 0.07176395112765022, 0.017211039157700725, 0.05669957783538848, 0.01636528395465575, 0.02549193592130905, 0.04613799632352311, 0.013119225568516413, 0.06318218584056012, 0.06686884153168648, 0.03653572974144481, 0.020881979871774092, 0.03772453528654296, 0.0361463211447699, 0.07887499494245276, 0.04258065244357567, 0.012346200837782817, 0.03307545506686438, 0.033378618682036176, 0.08897454870748334, 0.023035237863950897, 0.02576615948783001, 0.03617010697780643, 0.027189283318875823, 0.01980650398763828, 0.032463105308124796, 0.034839525251300074, 0.047464529634453356, 0.014552821103279712, 0.1299449522048235, 0.06243863550480455, 0.02857168179616565, 0.1006230092025362, 0.033594349879422225, 0.03156870232487563, 0.02466581980115734, 0.040303750793100335, 0.1755928824422881, 0.13279034639708698, 0.2166694204788655, 0.1993854096508585, 0.139042257796973, 0.18066149874357507, 0.15427807462401688, 0.12876484834123403, 0.09809316135942936, 0.13011006521992385, 0.27698405901901424, 0.07718412278336473, 0.0921331366407685, 0.1509636134142056, 0.14565587713150308, 0.10984285079757683, 0.19331470102770254, 0.15122593293199316, 0.21627798210829496, 0.18071885191602632, 0.1280567207140848, 0.08277399392682128, 0.22626010584644973, 0.1700549913221039, 0.08255388034740463, 0.06713011462124996, 0.1432542724069208, 0.112219163129339, 0.26527020789217204, 0.12476341071305797, 0.20812486647628248, 0.06372875533998013, 0.11435222913860343, 0.07934341629152186, 0.0718216308450792, 0.1068626380583737, 0.12448966954252683, 0.11497034909552895, 0.1532187924021855, 0.18632344726938754, 0.2285418685642071, 0.18695462902542204, 0.24165429698769003, 0.12233085100888275, 0.14088192314375192, 0.09726992662763223, 0.18648937664693221, 0.13902140344725922, 0.1643425619113259, 0.15586839319439605, 0.0846450446988456, 0.14347054908284917, 0.145908682316076, 0.13303195999469608, 0.22598843526793644, 0.2350695471977815, 0.31199662713333964, 0.09415526641532779, 0.41046869941055775, 0.46090466959867626, 0.19996299350168556, 0.07542607141658664, 0.25500247604213655, 0.2005222166189924, 0.22199459723196924, 0.20208558038575575, 0.2151569680427201, 0.11034754090360366, 0.22295496601145715, 0.8530792803503573, 0.8751448744442314, 0.5121264851186424, 1.6934035951271653, 4.514177246019244, 4.535337360575795, 7.297495119273663, 19.35551729053259, 24.714833311736584, 40.104336217045784, 39.84698362648487, 33.79031382501125, 31.425970494747162, 36.09246589243412, 49.00988794863224, 75.05636170506477, 86.63027465343475, 92.12613254785538, 94.35310184955597, 99.21365663409233, 90.47930091619492, 63.42155322432518, 27.085463404655457, 5.960021512582898, 9.305921997874975, 6.696373075246811, 1.6412243200466037, 1.065143288578838, 0.4755495290737599, 0.6042561039794236, 1.3577933725900948, 1.6606127796694636, 0.3853843454271555, 0.239114667638205, 0.12961304892087355, 0.21907276182901114, 0.2360041337669827, 0.1692107241251506, 0.14038790512131527, 0.28372851898893714, 0.3019669168861583, 0.0813290843507275, 0.2127823478076607, 0.132526483212132, 0.14593275758670643, 0.15163500473136082, 0.17452549596782774, 0.2247674242244102, 0.1622474641771987, 0.16752564813941717, 0.08417771430686116, 0.10686009991331957, 0.22870747139677405, 0.13579527265392244, 0.26827299676369876, 0.12200330413179472, 0.18295785208465531, 0.15175342181464657, 0.19996542774606496, 0.12381260079564527, 0.12219160926179029, 0.15253508143359795, 0.07431241203448735, 0.12490970286307856, 0.27016226726118475, 0.16076251573394984, 0.24954234715551138, 0.14684004796436056, 0.150714103365317, 0.11819656894658692, 0.13738686771830544, 0.08526614808943123, 0.1383704211912118, 0.14721262094099075, 0.09026285028085113, 0.14668473129859194, 0.14864912198390812, 0.1719088910613209, 0.2500021521700546, 0.3248359897406772, 0.11541424246388488, 0.10437345990794711, 0.09653585351770744, 0.12203179518110119, 0.11203824979020283, 0.15074607508722693, 0.3426030941773206, 0.10939699815935455, 0.09682638206868432, 0.2714389096945524, 0.2213798466254957, 0.11954848741879687, 0.20720923435874283, 0.11294399650068954, 0.21525588148506358, 0.12742132355924696, 0.11552382798981853, 0.0726481236051768, 0.20239119679899886, 0.22384817042620853, 0.14667598879896104, 0.08059547137236223, 0.21270706434734166, 0.07462176887202077, 0.08309237528010271, 0.13306321925483644, 0.11446065691416152], [0.013674018991878256, 0.05456622238853015, 0.04470050451345742, 0.04827051314350683, 0.0295695327440626, 0.033427103189751506, 0.03964882031141315, 0.020631228580896277, 0.03031292351806769, 0.02764580804068828, 0.059456734379637055, 0.029601222449855413, 0.07967649959027767, 0.0643360399408266, 0.02345314122067066, 0.04385302381706424, 0.013542243250412866, 0.01692863712378312, 0.044095546545577236, 0.06544314615894109, 0.049639597491477616, 0.05424665359896608, 0.04348572751041502, 0.014849047493044054, 0.06653175805695355, 0.06990545749431476, 0.026004605970229022, 0.009416683278686833, 0.04869173018960282, 0.04703339749539737, 0.07939495102618821, 0.03427326286328025, 0.0064298951110686176, 0.015529039374087006, 0.07995206644409336, 0.028772365949407686, 0.029799789626849815, 0.01147505212429678, 0.026135218395211268, 0.044322124231257476, 0.07347339182160795, 0.031913530110614374, 0.01552244539198, 0.04425513056048658, 0.005864835002284963, 0.05504469983861782, 0.05062317322881427, 0.03916578607459087, 0.009015607192850439, 0.06776833935873583, 0.036753186432179064, 0.029772129782941192, 0.013403644388745306, 0.021768699771200772, 0.07177917257649824, 0.032380697230109945, 0.021801328293804545, 0.08549082587705925, 0.06751928944140673, 0.12985150096938014, 0.026774461730383337, 0.03987173920904752, 0.1072968686639797, 0.5620777141302824, 0.5240512546151876, 0.3082838701084256, 0.05773068070993759, 0.005804732636534027, 0.10444524043123238, 8.041641488671303, 25.077829733490944, 42.82183639705181, 80.27402892708778, 95.93115717172623, 86.8727396428585, 100.3110833466053, 110.78636884689331, 122.56034106016159, 123.24647024273872, 117.42391347885132, 120.07152020931244, 121.5050844848156, 124.15845170617104, 145.63726276159286, 123.13670933246613, 124.96224537491798, 137.1851482987404, 135.42898893356323, 124.9328501522541, 132.23112612962723, 139.709170460701, 92.08520874381065, 47.724352329969406, 107.11694374680519, 121.42325207591057, 98.76905009150505, 91.30654692649841, 89.34443101286888, 64.4968119263649, 46.90045773983002, 23.372192457318306, 5.221980940550566, 1.202447614632547, 0.41735867969691753, 0.5342573288362473, 0.5312044301535934, 0.16444763517938554, 0.07859613295295276, 0.03378556793904863, 0.04045072571898345, 0.022273647773545235, 0.06769062907551415, 0.09244839355233125, 0.05767701230070088, 0.03539408768119756, 0.08699867699760944, 0.04081125734956004, 0.006800128930990468, 0.055326600922853686, 0.06885050199343823, 0.0519000011991011, 0.06243476891540922, 0.0037555824246737757, 0.09682224088464864, 0.05191993528569583, 0.08696449367562309, 0.06468722422141582, 0.04630603711120784, 0.05116593551065307, 0.013137714322510874, 0.017527529889775906, 0.033548184583196416, 0.06380835067830049, 0.010971895480906824, 0.09359093732200563, 0.03812520968494937, 0.007826658784324536, 0.058856507603195496, 0.004658620528061874, 0.07014054761384614, 0.04117653501452878, 0.06080463412217796, 0.023239731090143323, 0.024089280523185153, 0.027626443552435376, 0.03142245841445401, 0.03854789618344512, 0.04107435612240806, 0.023956096556503326, 0.04806063378055114, 0.02539419507229468, 0.05719903580029495, 0.05971217789920047, 0.028205431917740498, 0.06879406166262925, 0.029302281654963735, 0.0999447084905114, 0.040095110816764645, 0.06662831889116205, 0.01574618807353545, 0.11500468826852739, 0.018712056953518186, 0.011670509702526033, 0.04767021586303599, 0.04771364634507336, 0.07730274024652317, 0.04246406846505124, 0.028596174524864182, 0.020855436960118823, 0.0651886043488048, 0.045979106216691434, 0.036906907480442896, 0.09362863842397928, 0.029830119347025175, 0.018756493045657407, 0.02348000696656527, 0.05910198779019993, 0.015801554145582486, 0.025319462656625547, 0.054941693451837637, 0.033566853308002464, 0.031226260543917306, 0.036078414632356726, 0.04143544065300375, 0.0833929525106214, 0.06015489125275053, 0.052008362181368284, 0.03703204471094068, 0.014317517616291298, 0.06647574075032026, 0.06736850729794241, 0.026138966240978334, 0.02988314394315239, 0.011890448877238669, 0.021486778277903795, 0.04908294591587037, 0.058337263981229626, 0.01498890429502353, 0.02708406904275762, 0.04784890275914222, 0.03132814999844413, 0.024189238538383506, 0.02138877025572583, 0.012054355902364478, 0.050328726138104685, 0.033802062171162106, 0.04936609009746462, 0.009653128745412687, 0.010303907838533632, 0.01448051643819781, 0.04756690519570839, 0.028014022755087353, 0.023390477981592994, 0.05805460961710196, 0.02523559069231851, 0.026688864272728097, 0.03564448459655978, 0.0702498437021859, 0.05495077362866141, 0.03863838253892027, 0.012185902505734703, 0.053011252311989665, 0.030094127250777092, 0.04874913902312983, 0.013393134649959393, 0.009209078598360065, 0.01694104397756746, 0.027375695972295944, 0.02928672438429203, 0.010104615212185308, 0.03023656208824832, 0.06494647866929881, 0.07021838406217285, 0.07333606481552124, 0.029582418283098377, 0.04484035853238311, 0.046824145247228444, 0.05346269332221709, 0.03352602776431013, 0.42182272765785456, 0.37372532417066395, 0.3864210960455239, 0.28000581718515605, 0.0884971919003874, 0.16642940696328878, 8.239017147570848, 24.88117888569832, 51.55806541442871, 90.2710796892643, 108.75168442726135, 101.50595963001251, 115.99776640534401, 128.88045072555542, 141.76359862089157, 144.51305508613586, 137.02561765909195, 147.07746148109436, 143.86847287416458, 146.11352920532227, 170.39573103189468, 148.08966636657715, 150.16458302736282, 162.50358492136002, 159.01505291461945, 151.279519200325, 159.3469575047493, 164.56476151943207, 118.10957908630371, 61.928951516747475, 134.60184931755066, 142.70202666521072, 113.79344388842583, 108.57794255018234, 104.71398308873177, 71.78517803549767, 50.36641135811806, 23.552067205309868, 4.151415936648846, 0.7203341752756387, 0.3661419404670596, 0.5360182968433946, 0.4244810115778819, 0.1386090661981143, 0.04969557769072708, 0.02726852984778816, 0.02675023060874082, 0.04676810567616485, 0.09094223452848382, 0.05064363052952103, 0.08292251994134858, 0.023817398432584014, 0.13519036292564124, 0.022638355840172153, 0.026814224147528876, 0.03743628883967176, 0.06987312954152003, 0.06578000698937103, 0.03466903537628241, 0.07600561453728005, 0.08574113002396189, 0.06173168047098443, 0.035036253757425584, 0.09589256733306684, 0.06179815834912006, 0.03220256323402282, 0.01194313579617301, 0.010828449467226164, 0.05826511238410603, 0.005825575390190352, 0.020587284161592834, 0.03144152789900545, 0.028658568735409062, 0.07215162680950016, 0.038271305165835656, 0.0903442787239328, 0.02506882454326842, 0.07486613583751023, 0.03988470823969692, 0.004147299332544208, 0.02884248962800484, 0.022853537848277483, 0.01193222900838009, 0.05719806729757693, 0.008767819854256231, 0.08655467230710201, 0.049406559410272166, 0.045396780042210594, 0.10714713294873945, 0.025100950260821264, 0.023393175688397605, 0.02201126146246679, 0.0346389153128257, 0.032589956899755634, 0.03800718222919386, 0.02437602412101114, 0.06216374029463623, 0.1013469668396283, 0.026110094840987585, 0.027988561523670796, 0.05210463728872128, 0.0925956504943315, 0.03966738884628285, 0.011582382448978024, 0.061210206695250235, 0.041441192297497764, 0.06009928212733939, 0.02971747802803293, 0.07281073558260687, 0.06677844052319415, 0.015538091720372904, 0.01686403131316183, 0.032550997857470065, 0.11299113029963337, 0.1240196377329994, 0.13657770410645753, 0.16304139891872182, 0.11183835231349804, 0.09549102833261713, 0.1398608021554537, 0.16311914630932733, 0.20815116818994284, 0.1401418831665069, 0.09062747485586442, 0.09949367566150613, 0.14836609654594213, 0.12430769493221305, 0.14018568472238258, 0.12940159620484337, 0.12311148646404035, 0.10588330740574747, 0.081193879886996, 0.13502045563654974, 0.15799433458596468, 0.10979940547258593, 0.18862514407373965, 0.14622060698457062, 0.11570062983082607, 0.20913147105602548, 0.14465755491983145, 0.0572820635716198, 0.11547489077202044, 0.16169558832189068, 0.18157125305151567, 0.1070018055906985, 0.15417570277350023, 0.10241792304441333, 0.17588353715837002, 0.16152042662724853, 0.10492059343960136, 0.11602946804487146, 0.12538117443909869, 0.18051303952233866, 0.2662661107024178, 0.11126490222522989, 0.1322867546696216, 0.15853639924898744, 0.2755591057939455, 0.1827501694788225, 0.092080971080577, 0.17331211420241743, 0.093788051744923, 0.1710559704224579, 0.11157399188959971, 0.13078072923235595, 0.12587136297952384, 0.1609891527914442, 0.12733637733617797, 0.37090872530825436, 0.11447638302342966, 0.2506407554028556, 0.21432424866361544, 0.2526422683149576, 0.13738753565121442, 0.24569327244535089, 0.42221167241223156, 0.7641512271948159, 0.7422987185418606, 0.48406944377347827, 0.2799261995824054, 0.1948115386767313, 0.8842631976585835, 13.255007341504097, 36.178573071956635, 67.51891136169434, 114.23431143164635, 132.157182097435, 124.59594503045082, 138.88645380735397, 150.50060659646988, 161.67293429374695, 163.69641691446304, 155.05037605762482, 163.5896122455597, 161.70953392982483, 165.52113980054855, 184.90046471357346, 159.7508454322815, 162.36443638801575, 173.599171936512, 172.49482959508896, 161.84412270784378, 167.64595538377762, 183.28564256429672, 149.79691475629807, 91.6584612429142, 161.63416117429733, 168.1730479001999, 136.98181360960007, 132.81749546527863, 131.29114776849747, 97.37463891506195, 71.19941666722298, 38.07901829481125, 9.054428692907095, 2.0048574451357126, 0.5284466687589884, 0.5328471295069903, 0.7397650263737887, 0.45009448716882616, 0.1676496016443707, 0.13239319348940626, 0.250868090079166, 0.23200618423288688, 0.25711213471367955, 0.19598061422584578, 0.2275193523382768, 0.15252666547894478, 0.2593087137211114, 0.10610313154757023, 0.19717131595825776, 0.1281872348044999, 0.15365952422143891, 0.189603517355863, 0.13970423868158832, 0.14157958648866042, 0.24932617438025773, 0.10999482037732378, 0.16571691550780088, 0.17143529694294557, 0.13777278451016173, 0.14878928399411961, 0.19672363763675094, 0.11396736619644798, 0.14134570606984198, 0.14563618053216487, 0.13249152805656195, 0.11805950169218704, 0.1372123887995258, 0.13690212654182687, 0.09125959171797149, 0.1812662006705068, 0.14060689805774018, 0.17203401715960354, 0.20521120954072103, 0.12999838683754206, 0.144136136805173, 0.08406900451518595, 0.136567551526241, 0.15261330379871652, 0.1326367663568817, 0.1350479744723998, 0.15107502462342381, 0.1317102840403095, 0.16920480178669095, 0.1056690419500228, 0.1318461267510429, 0.12060417764587328, 0.1294552386389114, 0.27022739814128727, 0.12471923808334395, 0.18345598160522059, 0.11595938703976572, 0.1426327830995433, 0.12431714989361353, 0.06987639499129727, 0.0941647584841121, 0.1420636152033694, 0.17031413444783539, 0.10532588028581813, 0.10742054757429287, 0.1508787414059043, 0.11201179222553037, 0.12649786920519546, 0.17433053377317265, 0.18740410334430635, 0.09124465970671736, 0.14611850230721757, 0.13114642992150038], [0.020812334878428373, 0.037975217928760685, 0.05795260512968525, 0.010392322674306342, 0.04306391303543933, 0.07227622598293237, 0.05048054357757792, 0.07064815436024219, 0.03850280700135045, 0.0413865850714501, 0.036747460762853734, 0.005022213053962332, 0.016749141286709346, 0.05037177441408858, 0.05413450766354799, 0.015917570381134283, 0.06972740884521045, 0.04403761449793819, 0.019961030266131274, 0.08635880469228141, 0.01981083070859313, 0.026443105780344922, 0.03718470448802691, 0.030167321565386374, 0.014384804435394472, 0.01906643246911699, 0.061282042879611254, 0.04207986974506639, 0.03538174205459654, 0.025448767046327703, 0.08123452731524594, 0.07448007061611861, 0.015599398684571497, 0.0160056076492765, 0.03289034488261677, 0.027156760552315973, 0.030185639625415206, 0.04369836766272783, 0.024779687519185245, 0.0389296977664344, 0.028070064181520138, 0.010321075569663662, 0.08383465654333122, 0.013351492743822746, 0.0015861903739278205, 0.018693616439122707, 0.052301395480753854, 0.057146710678352974, 0.05063480268290732, 0.019834950508084148, 0.03846323939797003, 0.02557539970439393, 0.023327950184466317, 0.021955129122943617, 0.036195284337736666, 0.051029803362325765, 0.09783192537724972, 0.027576120373851154, 0.5910930165555328, 0.22158804873470217, 0.18165826244512573, 1.05234652524814, 2.187647349201143, 12.00433200225234, 22.732035107910633, 38.08195173740387, 50.325821936130524, 60.022738203406334, 77.46965020895004, 93.50079998373985, 111.48383662104607, 112.53174439072609, 118.14463600516319, 102.67017155885696, 109.19350951910019, 111.44238844513893, 108.05385947227478, 95.36759421229362, 85.37938937544823, 93.32938358187675, 99.41119283437729, 101.03118270635605, 112.54917025566101, 90.13759285211563, 104.80100601911545, 101.3032329082489, 76.62620946764946, 92.09544539451599, 99.36582326889038, 91.34788110852242, 100.40700539946556, 101.5116137266159, 117.9852269589901, 109.07340556383133, 103.95792245864868, 91.86914473772049, 106.71936348080635, 104.25427615642548, 115.35639882087708, 117.58491843938828, 123.97938251495361, 105.7742477953434, 101.28986522555351, 72.77567848563194, 42.62973390519619, 14.625941477715969, 3.7223189743235707, 0.5146116111427546, 0.19335537072038278, 0.29952272772789, 0.039556552801514044, 0.03215006370737683, 0.0420578687771922, 0.07232373085571453, 0.053454652152140625, 0.026871577319980133, 0.07752519901259802, 0.06788111611967906, 0.03271612942626234, 0.052496758435154334, 0.01485553757447633, 0.053566690476145595, 0.10065135182230733, 0.004647868663596455, 0.011227584836888127, 0.013048099062871188, 0.07343350138398819, 0.04424647711857688, 0.026130041915166657, 0.026921932039840613, 0.020974108228983823, 0.011339824468450388, 0.038984831917332485, 0.0419828190933913, 0.014585024746338604, 0.04612689379428048, 0.033233539943466894, 0.08727912718313746, 0.07484073954401538, 0.07595468094223179, 0.05696731874195393, 0.03308314371679444, 0.027495803296915255, 0.07578677003039047, 0.047654530571890064, 0.028487446179497056, 0.01765272463671863, 0.03691600992169697, 0.02313567641976988, 0.053558359868475236, 0.015755171771161258, 0.10205439684796147, 0.07338258263189346, 0.02146817078028107, 0.06264181327424012, 0.03944030650018249, 0.014742681032657856, 0.010657262901077047, 0.0435471476521343, 0.01606251924386015, 0.050217444804729894, 0.01349855394437327, 0.04736853654321749, 0.04374759431811981, 0.045519675986724906, 0.018697111954679713, 0.04550723759166431, 0.036469574697548524, 0.04285141018044669, 0.014920267694833456, 0.021580305583484005, 0.04460843367269263, 0.05994744613417424, 0.026948337654175702, 0.03451410462730564, 0.029273534564708825, 0.037177090052864514, 0.09404514654306695, 0.06216782952833455, 0.018215628806501627, 0.01865210069809109, 0.0164273312111618, 0.05345232551917434, 0.01962795253348304, 0.1046192592184525, 0.021405158731795382, 0.01624902095500147, 0.022729074116796255, 0.045004332350799814, 0.028926630620844662, 0.020532112903310917, 0.06612748795305379, 0.05126042946358211, 0.02900772880821023, 0.028883368977403734, 0.044617840394494124, 0.08145616229739971, 0.015565612411592156, 0.008064829744398594, 0.03430448872677516, 0.011525577538122889, 0.03212669718777761, 0.050942344969371334, 0.011250730567553546, 0.040942042323877104, 0.012901037862320663, 0.04199875671474729, 0.03451857606705744, 0.04287733339879196, 0.05092353523650672, 0.03571386798284948, 0.021653488765878137, 0.030906925530871376, 0.027639458967314567, 0.033817198273027316, 0.04150927321461495, 0.005191287282286794, 0.038886426846147515, 0.11309570632874966, 0.029144773798179813, 0.023896700622572098, 0.045051050547044724, 0.04197523063339759, 0.04097936121979728, 0.06817669869633391, 0.06369621958583593, 0.027921987166337203, 0.04397473232529592, 0.026228573151456658, 0.05540318685234524, 0.009619455649954034, 0.020980236513423733, 0.051226921495981514, 0.0399492713768268, 0.23431516892742366, 0.16842639277456328, 0.19602955144364387, 0.858456288697198, 0.8563361805863678, 9.846602585166693, 19.89591669291258, 37.46028229594231, 52.66032926738262, 61.520918011665344, 84.11844223737717, 103.21915850043297, 126.62551492452621, 125.76381996273994, 131.73798859119415, 117.84241542220116, 121.91604763269424, 126.93879291415215, 130.9283584356308, 110.37460014224052, 100.07825464010239, 131.32019340991974, 111.36255472898483, 114.65999498963356, 136.4846634864807, 115.92316880822182, 119.59149956703186, 124.9987918138504, 109.70835149288177, 121.62097826600075, 122.89701819419861, 118.85314598679543, 144.03586149215698, 134.01306331157684, 153.23617100715637, 137.70514279603958, 118.87779146432877, 124.33562099933624, 135.07598787546158, 119.84464198350906, 143.80209803581238, 140.8749023079872, 146.68735921382904, 125.962123721838, 112.0692028105259, 79.09711048007011, 41.47577002644539, 14.58366684615612, 3.4893271140754223, 0.5532918137032539, 0.14934841805370525, 0.3882669657468796, 0.03776357596507296, 0.018978601146955043, 0.05294164257065859, 0.20190094888675958, 0.04803243587957695, 0.05079826070868876, 0.06317398510873318, 0.013448763256747043, 0.04979118486517109, 0.06383850413840264, 0.05589046617387794, 0.054226051579462364, 0.0870481930905953, 0.06775060202926397, 0.042559093053569086, 0.05381552517064847, 0.01865443104179576, 0.04466623213374987, 0.0018589510978017643, 0.047827699600020424, 0.03952220249630045, 0.04923094871628564, 0.04563994843920227, 0.038931916787987575, 0.020389570454426575, 0.07918114570202306, 0.03192166033841204, 0.025696577577036805, 0.08665094370371662, 0.05581922370765824, 0.011510315271152649, 0.05390948477725033, 0.019214811909478158, 0.07743334339465946, 0.02802566519676475, 0.022225851607799996, 0.03853589194477536, 0.006785352770748432, 0.015599660291627515, 0.05168523108295631, 0.004407355763760279, 0.07925719357444905, 0.016134474171849433, 0.019843806185235735, 0.04616386017005425, 0.03452508841292001, 0.035525477505871095, 0.052634927778854035, 0.03121707275568042, 0.04627322676242329, 0.08850784171954729, 0.033445185617893, 0.023811802639102098, 0.0688530104525853, 0.01110407476517139, 0.0339212881954154, 0.0463708266033791, 0.06493280088761821, 0.04169319596257992, 0.05382277966418769, 0.03189051611116156, 0.04064764718350489, 0.025918724641087465, 0.0707975635305047, 0.01937564644322265, 0.08085085180937313, 0.15207005169941112, 0.21593316545477137, 0.11556120996829122, 0.12848508835304528, 0.23006037692539394, 0.10830664963577874, 0.15905910870060325, 0.12767218431690708, 0.18276444840012118, 0.08846116805216298, 0.17417474213289097, 0.06226417142897844, 0.14764012768864632, 0.15040306927403435, 0.10705137363402173, 0.1576523677795194, 0.13445988181047142, 0.12321225527557544, 0.15292739553842694, 0.1494904057472013, 0.13518680061679333, 0.09933724577422254, 0.11622074918705039, 0.06032692108419724, 0.10114559991052374, 0.09580517944414169, 0.160729237832129, 0.18665248586330563, 0.12045142881106585, 0.07506863825256005, 0.13623172970255837, 0.12042221787851304, 0.16555327194510028, 0.13281986903166398, 0.12549770646728575, 0.1192671614990104, 0.15315572469262406, 0.22008766361977905, 0.2389635960571468, 0.10791919659823179, 0.16209272638661787, 0.08384060856769793, 0.21147642022697255, 0.15410746971610934, 0.15200719179119915, 0.2052222823840566, 0.1479907034081407, 0.22978842433076352, 0.17466169490944594, 0.19621528132120147, 0.12040459187119268, 0.08816278757876717, 0.1785999906132929, 0.2957882999908179, 0.18027092126430944, 0.12823819066397846, 0.2667767083039507, 0.26079568080604076, 1.0577257303521037, 0.29509673709981143, 0.20586492290021852, 3.9176895283162594, 5.944228610023856, 19.75218180567026, 37.86031723022461, 57.5568263232708, 71.60413295030594, 83.08438092470169, 107.007015645504, 126.55287802219391, 145.29905050992966, 145.3776302933693, 144.01648253202438, 126.00129961967468, 134.83471602201462, 135.74301928281784, 133.8734132051468, 120.78762978315353, 108.42994049191475, 122.17233628034592, 123.98216396570206, 126.37454599142075, 137.79500037431717, 116.81520134210587, 132.699473798275, 130.16314029693604, 105.64309403300285, 121.28227964043617, 126.88552737236023, 118.15883204340935, 131.1197465658188, 133.91068160533905, 158.05335491895676, 137.9988518357277, 130.78417897224426, 122.49776601791382, 137.0111632347107, 130.9105297923088, 150.30891448259354, 155.67913591861725, 164.10674929618835, 149.3739366531372, 138.8668468594551, 108.04651826620102, 62.159473747015, 23.471006155014038, 8.213552813977003, 1.820483619812876, 0.25965963082853705, 0.663396546151489, 0.17832915124017745, 0.14012571919010952, 0.16536617651581764, 0.33042857714463025, 0.10445037609315477, 0.1283643112401478, 0.1353320389171131, 0.18153482844354585, 0.2358934943913482, 0.1680777911678888, 0.14364787784870714, 0.19630753027740866, 0.225861364742741, 0.12113139193388633, 0.14295198081526905, 0.11520209955051541, 0.1528878984390758, 0.11400321192923002, 0.09129987549385987, 0.15964026970323175, 0.08696146571310237, 0.13562725041992962, 0.178529946715571, 0.09799824809306301, 0.10570856131380424, 0.12871276441728696, 0.12646316637983546, 0.12403082189848647, 0.24815885029966012, 0.15109325177036226, 0.17532924190163612, 0.13673609326360747, 0.11976870489888825, 0.14867506746668369, 0.17936961259692907, 0.10531940875807777, 0.15918693621642888, 0.11250191397266462, 0.10149341484066099, 0.1596766646252945, 0.09667386329965666, 0.1470473743393086, 0.09795705147553235, 0.1598456664942205, 0.1923366542905569, 0.13444952142890543, 0.24880101584130898, 0.09662341952207498, 0.11502614375785924, 0.14839696988929063, 0.15915852680336684, 0.10611465710098855, 0.18457145924912766, 0.1798041697475128, 0.2185212422045879, 0.06170606524392497, 0.11132673796964809, 0.10061720560770482, 0.11977857546298765, 0.1250519132008776, 0.1317778491647914, 0.1380196970421821, 0.09727040902362205, 0.1419534656452015, 0.07017872369033284, 0.10309401215636171], [0.042072140277014114, 0.06318890227703378, 0.028940963347849902, 0.027211742562940344, 0.034507395612308756, 0.027287985249131452, 0.008812776377453702, 0.03971090838604141, 0.07040061842417344, 0.058435620812815614, 0.03123730370134581, 0.03108984266873449, 0.010503894372959621, 0.024582760488556232, 0.023077453079167753, 0.026813250078703277, 0.030151460014167242, 0.1280598228913732, 0.041030899665202014, 0.0665112302522175, 0.014824326553934952, 0.08284204144729301, 0.04131258923735004, 0.026278812838427257, 0.07051038948702626, 0.005233715401118388, 0.0589772587409243, 0.027259974740445614, 0.1032234204467386, 0.06447545238188468, 0.05386304859712254, 0.042084994274773635, 0.0367667232058011, 0.01886182235466549, 0.00671640771543025, 0.033435170334996656, 0.053927084809402004, 0.03439529420575127, 0.07447658252203837, 0.03935041015211027, 0.033166716966661625, 0.03980913905252237, 0.04324437366449274, 0.062197051593102515, 0.09548531379550695, 0.05406156196841039, 0.04728366082417779, 0.021333541480998974, 0.024891083885449916, 0.03266089879616629, 0.029200297576608136, 0.04156923503614962, 0.02893904675147496, 0.03266153704316821, 0.03544941107975319, 0.060852736423839815, 0.13134859094861895, 1.1630341107957065, 7.93863614089787, 33.83577838540077, 51.12473286688328, 71.33479580283165, 80.74021071195602, 83.96382853388786, 96.60078763961792, 101.28080651164055, 92.79935002326965, 95.62222614884377, 96.7478397488594, 95.69829046726227, 79.54029589891434, 77.48139157891273, 57.5738076120615, 51.13218046724796, 52.06480622291565, 70.27512386441231, 46.32979676127434, 62.555952072143555, 52.138377875089645, 35.96182510256767, 67.0963816344738, 51.933945044875145, 58.82650539278984, 47.345706447958946, 54.88343797624111, 45.11662445962429, 40.68983919918537, 37.82219007611275, 45.66208899021149, 46.7106769233942, 21.265064924955368, 43.29055644571781, 35.10371334850788, 61.19555667042732, 76.5621829032898, 43.675164207816124, 40.2207999676466, 78.81919339299202, 80.79985231161118, 90.39406388998032, 91.63809433579445, 107.21465170383453, 105.5757312476635, 115.13270482420921, 120.77441409230232, 108.31890285015106, 103.27139049768448, 87.34270602464676, 47.284829914569855, 15.369812361896038, 1.2837955495342612, 0.39071750768925995, 0.19822087604552507, 0.01568068611959461, 0.02347802172153024, 0.06885112539748661, 0.028071939959772862, 0.07215303689008579, 0.0484757281083148, 0.05928623337240424, 0.0162237396943965, 0.05837850512762088, 0.028615457376872655, 0.059299343411112204, 0.018260137258039322, 0.03468241629889235, 0.03378212066309061, 0.024387770463363267, 0.026667646270652767, 0.012721104158117669, 0.08262613584520295, 0.030222429741115775, 0.05950118531472981, 0.06207232996530365, 0.02046177956799511, 0.021757712274848018, 0.05946551769739017, 0.056317713169846684, 0.059635940779116936, 0.03268845845013857, 0.08211301494156942, 0.061221988289617, 0.02207333098340314, 0.0982364997616969, 0.0398891611257568, 0.027383234337321483, 0.08385071661905386, 0.04359861930424813, 0.048946012248052284, 0.03841297002509236, 0.012673304281634046, 0.054189330112421885, 0.04869081363722216, 0.004899070345345535, 0.03209458816854749, 0.04873626647167839, 0.02936281121947104, 0.008171427198249148, 0.025665687535365578, 0.07027277606539428, 0.02136367267667083, 0.04895219062746037, 0.013303225314302836, 0.07365194513113238, 0.03685143936309032, 0.019836275241686963, 0.06845166441053152, 0.04489674320211634, 0.06058810140530113, 0.07111653860192746, 0.041428397671552375, 0.0306045541583444, 0.05487645496032201, 0.0684561840898823, 0.0644485346856527, 0.050104501060559414, 0.0211237029361655, 0.04659768630517647, 0.059811885439557955, 0.025347825685457792, 0.04756404050567653, 0.013270814797579078, 0.05515568802366033, 0.04607659844623413, 0.057790293722064234, 0.02496417615475366, 0.01772441239154432, 0.05291122564813122, 0.015315573582483921, 0.028992262450628914, 0.007325896958718658, 0.008885299976100214, 0.08357307917322032, 0.04681725440605078, 0.021545636154769454, 0.05220159517193679, 0.0630328879924491, 0.03298925461422186, 0.011595768937695539, 0.03569361477275379, 0.018591983025544323, 0.02596171725599561, 0.03460626823653001, 0.025442759360885248, 0.07660299146664329, 0.05136911328008864, 0.021501986739167478, 0.04447630912181921, 0.026303353806724772, 0.045391722305794246, 0.05123846931383014, 0.05081938594230451, 0.03596108850615565, 0.033677158717182465, 0.05898565985262394, 0.053262179862940684, 0.03694069746416062, 0.010368182465754217, 0.02560486667789519, 0.057803893578238785, 0.036247268071747385, 0.054545078601222485, 0.10991375558660366, 0.025720478442963213, 0.053603022315655835, 0.07356483183684759, 0.01512036369604175, 0.06752648085239343, 0.02595975798612926, 0.06726548977894709, 0.018892660445999354, 0.10468508771737106, 0.19252164202043787, 0.3285951755242422, 4.954772153869271, 27.85299751907587, 51.464761421084404, 76.41247093677521, 91.98678642511368, 100.40771216154099, 113.62580448389053, 115.91790989041328, 103.99180144071579, 114.25765737891197, 111.71291872859001, 120.27384415268898, 103.67089346051216, 122.6775723695755, 106.02827936410904, 87.62888386845589, 106.73813447356224, 109.33472514152527, 85.26788055896759, 91.88555225729942, 92.18374505639076, 71.5248692035675, 123.64312335848808, 94.41051676869392, 106.94915235042572, 100.99702253937721, 105.52846938371658, 96.58406093716621, 76.39990881085396, 81.6022552549839, 100.9871506690979, 89.05784279108047, 69.82772827148438, 80.04591196775436, 75.67605525255203, 113.71408894658089, 129.0286123752594, 79.50660690665245, 76.65786936879158, 127.28689983487129, 121.64523616433144, 120.98942175507545, 116.96901708841324, 130.58275938034058, 127.27134346961975, 134.37174886465073, 141.11228317022324, 128.1404784321785, 118.48252907395363, 99.34911176562309, 51.500255316495895, 16.01168531924486, 1.064843935891986, 0.31968735507689416, 0.284746092511341, 0.020807447835977655, 0.05380267117288895, 0.0819846753438469, 0.017888328693516087, 0.035975337741547264, 0.04533074745268095, 0.023625146932317875, 0.029560211369243916, 0.040785352684906684, 0.029080182830512058, 0.07563840728835203, 0.020725336617033463, 0.021286437367962208, 0.05524429303477518, 0.0478912905236939, 0.061344999267021194, 0.06829863355960697, 0.09376619549584575, 0.03634490130934864, 0.0755429374112282, 0.024308696483785752, 0.020420163637027144, 0.034511295598349534, 0.011096219132014085, 0.08413862538873218, 0.07095639797626063, 0.024282237063744105, 0.06147033316665329, 0.042800164883374237, 0.0976317681488581, 0.06712054091622122, 0.014335282776301028, 0.028066605773346964, 0.0836149808310438, 0.029810200103383977, 0.04100519166968297, 0.03793262236285955, 0.04690948851930443, 0.04362843508715741, 0.05546952743316069, 0.05879200754861813, 0.045198192456155084, 0.0686532465624623, 0.008997773384180618, 0.03668247831228655, 0.055170920604723506, 0.04420769248099532, 0.02351426264795009, 0.06178468465805054, 0.040916085708886385, 0.025988258312281687, 0.02856662220438011, 0.08224830846302211, 0.04490142615395598, 0.0032486607733517303, 0.0375817534950329, 0.03455920494161546, 0.03569189670088235, 0.04012447017885279, 0.044329686716082506, 0.11013142750016414, 0.03681123722344637, 0.024939293798524886, 0.1343550905585289, 0.25873865524772555, 0.1722304488066584, 0.10707620589528233, 0.1439617617870681, 0.07874654402257875, 0.18457807920640334, 0.10912279685726389, 0.19643966224975884, 0.15367917629191652, 0.22097887907875702, 0.17941552185220644, 0.1429114892380312, 0.18036570836557075, 0.07668229736736976, 0.14939735527150333, 0.2432112189126201, 0.1544549729442224, 0.07819966282113455, 0.16013890388421714, 0.24544754734961316, 0.15331261471146718, 0.16252839675871655, 0.08654233781271614, 0.13294121017679572, 0.19829480879707262, 0.1296001355512999, 0.11080399883212522, 0.19864866480929777, 0.1556643916410394, 0.1488242985215038, 0.12570654682349414, 0.20513623778242618, 0.1604927598964423, 0.20295942958910018, 0.08850915532093495, 0.20564686506986618, 0.07450039804098196, 0.15614476898917928, 0.11572495743166655, 0.15495598199777305, 0.10104711691383272, 0.1398986962158233, 0.2413540834095329, 0.18229625711683184, 0.24353587883524597, 0.16059572546510026, 0.11591533315367997, 0.17422903765691444, 0.1716310458141379, 0.09221904765581712, 0.21915910328971222, 0.1160368969431147, 0.17592677468201146, 0.1390727303805761, 0.6143934850115329, 0.24079258932033554, 4.603935554623604, 18.859507106244564, 56.58280938863754, 84.4047112762928, 105.0224581360817, 117.68719375133514, 119.75886538624763, 129.6522805094719, 129.2318558692932, 117.30114966630936, 122.1513158082962, 123.28550934791565, 118.63673999905586, 103.75798478722572, 99.5426657795906, 77.21511706709862, 74.35238108038902, 73.88581171631813, 95.50358891487122, 67.49005571007729, 87.91703760623932, 76.05031996965408, 48.568887412548065, 90.46974822878838, 75.68286448717117, 82.1839964389801, 67.99775406718254, 77.64988213777542, 66.64011731743813, 61.406688541173935, 55.368546545505524, 67.11838245391846, 65.52962690591812, 37.89924614131451, 67.71503403782845, 51.54662422835827, 86.3725496828556, 106.98946818709373, 65.2697816491127, 61.77535615861416, 113.54068905115128, 112.8132712841034, 121.47317379713058, 120.12571290135384, 133.8568612933159, 133.59482735395432, 144.62159246206284, 156.31488740444183, 145.30558615922928, 141.6326728463173, 122.0336665213108, 70.80622136592865, 25.148277953267097, 2.1628748159855604, 0.4093059618026018, 0.4045518528437242, 0.0931706368282903, 0.12365932503598742, 0.19490601407596841, 0.1252096047392115, 0.1656337801250629, 0.15920612815534696, 0.22088582860305905, 0.09449226083233953, 0.13840792933478951, 0.1086029372527264, 0.18258241441799328, 0.07893488625995815, 0.1325896251364611, 0.12264069766388275, 0.22062405827455223, 0.15469768492039293, 0.15838682680623606, 0.35133550059981644, 0.14580878923879936, 0.18207539396826178, 0.160263228463009, 0.16981542605208233, 0.0811517184774857, 0.0900133847608231, 0.23344345710938796, 0.15238400985253975, 0.1115309918532148, 0.19941034581279382, 0.21039319632109255, 0.15501177666010335, 0.19223604875151068, 0.11665927682770416, 0.21790359722217545, 0.18628834368428215, 0.1892735288129188, 0.20189161266898736, 0.17201311828102916, 0.1451193488901481, 0.19327723741298541, 0.12056335952365771, 0.11561206934857182, 0.15302733314456418, 0.15170102618867531, 0.1479713778826408, 0.1266148465219885, 0.14814757858403027, 0.0718374534335453, 0.11586992113734595, 0.17240420042071491, 0.12483240076107904, 0.11723534669727087, 0.09269989997847006, 0.1940328476484865, 0.21258631692035124, 0.11529920215252787, 0.16544655110919848, 0.11465976771432906, 0.14676875725854188, 0.14569530001608655, 0.1371043617837131, 0.24818727455567569, 0.21967961598420516, 0.14192444767104462], [0.01350191587334848, 0.016574200381000992, 0.045055481168674305, 0.04853502570767887, 0.01710682121483842, 0.03214788550394587, 0.04570977340335958, 0.03175068435666617, 0.044620656844927, 0.06284324699663557, 0.04749977793835569, 0.030323782993946224, 0.11634385664365254, 0.044028181800968014, 0.043390417195041664, 0.05589472239080351, 0.04611522352206521, 0.04015731763502117, 0.061837952307541855, 0.020936950750183314, 0.051011476025450975, 0.0547044919221662, 0.060731462071998976, 0.08636581798782572, 0.04095670716196764, 0.03275333328929264, 0.04234242675011046, 0.048527448379900306, 0.017957940290216357, 0.05733984347898513, 0.05979085668514017, 0.057696319272508845, 0.1035246359242592, 0.006320992824839777, 0.024927610538725276, 0.034447493162588216, 0.01698014031717321, 0.016886733610590454, 0.06830550584709272, 0.0512962417997187, 0.016037618333939463, 0.09234923520125449, 0.01911169234517729, 0.03684791416162625, 0.03977056221629027, 0.01697102859907318, 0.021079764082969632, 0.0921592973463703, 0.07122341528884135, 0.05122547801875044, 0.05429904180346057, 0.13810410891892388, 0.3950885497033596, 0.05418728178483434, 0.3129913128213957, 4.647697331383824, 27.57058337330818, 65.26654422283173, 86.21328502893448, 78.80701124668121, 83.51765647530556, 83.02074953913689, 83.73951137065887, 84.51628848910332, 84.65412989258766, 64.5111371576786, 73.05392995476723, 84.85092893242836, 90.59383437037468, 37.59029231965542, 38.170889765024185, 33.779381811618805, 35.270478799939156, 36.33225202560425, 31.508923843503, 47.688052877783775, 72.33019039034843, 52.42914207279682, 52.25531280040741, 74.88743036985397, 35.46363763511181, 41.59905441105366, 46.49378836154938, 49.41341869533062, 34.72749933600426, 43.75053696334362, 64.3210257589817, 65.73988482356071, 55.320338532328606, 64.24549341201782, 82.26479530334473, 65.39850354194641, 64.32946130633354, 55.48441372811794, 36.38007625937462, 48.7869007140398, 48.05757164955139, 29.27237145602703, 28.873639851808548, 35.10777913033962, 35.658513978123665, 53.41674327850342, 53.91899652779102, 77.21663698554039, 100.09997427463531, 90.48146679997444, 102.05534934997559, 100.75875252485275, 118.32939729094505, 109.5719464123249, 79.85139280557632, 33.58588859438896, 6.631030356511474, 0.6119109713472426, 0.21968164946883917, 0.09699115369585343, 0.05867983934876975, 0.04952198563842103, 0.008873370879882714, 0.11024404841009527, 0.10485249396879226, 0.02908504946390167, 0.025708125394885428, 0.08697951474459842, 0.001681912349340564, 0.06782658310839906, 0.048117233673110604, 0.0357273639383493, 0.047155198772088625, 0.0511401904077502, 0.00954631050262833, 0.03179878294758964, 0.030069964777794667, 0.07227117195725441, 0.04559140084893443, 0.028804092762584332, 0.034598260463098995, 0.024764347326708958, 0.02716801522183232, 0.0018524444340073387, 0.042436371513758786, 0.010436379343445878, 0.08451422632788308, 0.02316551261174027, 0.021436607239593286, 0.05474122823216021, 0.05381353621487506, 0.12333629783825018, 0.022447330738941673, 0.02862533350707963, 0.015009587023087079, 0.01771227271092357, 0.005460272677737521, 0.0656214397167787, 0.04003839218057692, 0.043347970058675855, 0.004148688540226431, 0.06666049099294469, 0.0031954341739037773, 0.07122213137336075, 0.022330499996314757, 0.03128397736873012, 0.04337587110057939, 0.011669261039060075, 0.08246282624895684, 0.01556413739308482, 0.022105781390564516, 0.023655738259549253, 0.04468332750548143, 0.01317421500061755, 0.017537033090775367, 0.014122201046120608, 0.05088571910164319, 0.041551612739567645, 0.05359484755899757, 0.045588884968310595, 0.056113975078915246, 0.05910560576012358, 0.018721905253187288, 0.04254118131939322, 0.04219473936245777, 0.07755544895189814, 0.04473789762414526, 0.049413157103117555, 0.008692597621120512, 0.06428681328543462, 0.02282896348333452, 0.0038020703232177766, 0.12196610026876442, 0.020278908814361785, 0.03850017237709835, 0.023707645923423115, 0.013656207447638735, 0.026574080002319533, 0.05170690921659116, 0.044754094997188076, 0.03319343799375929, 0.05382019327953458, 0.026654723624233156, 0.0226570023005479, 0.012366755545372143, 0.03468418261036277, 0.045775561084155925, 0.012229229087097337, 0.03254040741012432, 0.07459119238774292, 0.1146682133548893, 0.03413145699596498, 0.021420433986349963, 0.033740367434802465, 0.011887147247762186, 0.042290342826163396, 0.024667331927048508, 0.03676120162708685, 0.03978090033342596, 0.03347901270899456, 0.03269325643486809, 0.08813143183942884, 0.01851905217336025, 0.05390776299464051, 0.039641372859478, 0.03815132215095218, 0.09135177388088778, 0.05319792471709661, 0.04056651559949387, 0.030479346423817333, 0.049723471311153844, 0.1732559929951094, 0.15880254824878648, 0.13039899815339595, 0.38782212242949754, 2.3762188805267215, 21.58936232328415, 62.818362191319466, 94.12626922130585, 98.3194050192833, 100.19544795155525, 101.98404997587204, 96.84318423271179, 95.83917170763016, 104.68882843852043, 100.55566862225533, 113.00666570663452, 118.32924529910088, 114.45973053574562, 65.9820306301117, 64.62308675050735, 42.40780681371689, 33.995039239525795, 35.11656425893307, 27.891725040972233, 46.42524763941765, 52.30078496038914, 49.057484194636345, 48.53867523372173, 26.890094988048077, 31.730607748031616, 33.22498396039009, 31.619148328900337, 36.367331743240356, 22.75306697934866, 30.76964121311903, 41.29480853676796, 37.09019735455513, 32.38305553793907, 32.3247666656971, 29.30622573941946, 43.82331445813179, 35.77014058828354, 46.268190667033195, 42.11359240114689, 39.71975885331631, 34.99801442027092, 44.1933424025774, 44.51497234404087, 70.80802246928215, 72.6784873008728, 101.06099590659142, 101.0500068962574, 117.1536111831665, 119.79658216238022, 108.50646078586578, 118.12501385807991, 118.06280359625816, 137.14704394340515, 126.91316708922386, 92.3460191488266, 38.54942545294762, 7.089534178376198, 0.2835979009978473, 0.14876814762828872, 0.05250525973679032, 0.09076379996258765, 0.04751340005896054, 0.004870987477261224, 0.08113484946079552, 0.06749462045263499, 0.11444567295257002, 0.01488839894591365, 0.039204648637678474, 0.01585650647029979, 0.06502758798887953, 0.09348614607006311, 0.05338181035767775, 0.016721898900868837, 0.029888116332585923, 0.011125227829325013, 0.026537187841313425, 0.04375652606540825, 0.038062056628405116, 0.09504234069027007, 0.015381656266981736, 0.062402581970673054, 0.03362094845215324, 0.06027617673680652, 0.007712288261245703, 0.08821689756587148, 0.015546547565463698, 0.02919488546467619, 0.040769834376988, 0.04338282502430957, 0.036549941869452596, 0.023274504419532605, 0.04016326965938788, 0.0036033769811183447, 0.06864988463348709, 0.08818568283459172, 0.03443904752202798, 0.016897923342185095, 0.027280860631435644, 0.006362878712025122, 0.055585755180800334, 0.032100907556014135, 0.11673229673760943, 0.01895901030366076, 0.025277876411564648, 0.05209823255427182, 0.06105580658186227, 0.028406208839442115, 0.03890922191203572, 0.08436747404630296, 0.0410909913625801, 0.055191437277244404, 0.010876330979954218, 0.09177938452921808, 0.02510533078748267, 0.01749661758367438, 0.013931483008491341, 0.09429720215848647, 0.023313569217862096, 0.07736796760582365, 0.09869185189018026, 0.12215808645123616, 0.26778080442454666, 0.15137682639760897, 0.15415507106808946, 0.22310468688374385, 0.21133768314030021, 0.21137029310921207, 0.16227649699430913, 0.1740114696440287, 0.16642164409859106, 0.14671192358946428, 0.10554709966527298, 0.27834207052364945, 0.0949791245511733, 0.1241260246024467, 0.11620295990724117, 0.06383390282280743, 0.28416068642400205, 0.14815105183515698, 0.10550197708653286, 0.10484102778718807, 0.14125798421446234, 0.11829543043859303, 0.16086316580185667, 0.12139111393480562, 0.19337015430210158, 0.1656902427203022, 0.17095175804570317, 0.13298652571393177, 0.11043849852285348, 0.22108019707957283, 0.1730076110106893, 0.1250036884448491, 0.10100968298502266, 0.11538941762410104, 0.1679816682008095, 0.15646203712094575, 0.20477055193623528, 0.17642766499193385, 0.1110304355097469, 0.10443356644827873, 0.1910798272001557, 0.16911728773266077, 0.2206599188502878, 0.26230010320432484, 0.1104338675213512, 0.15411107655381784, 0.2200638852082193, 0.18844990816432983, 0.09628675165004097, 0.13879481091862544, 0.4082549025770277, 0.6235111551359296, 0.12677921738941222, 0.8311004284769297, 12.798044811934233, 49.58669699728489, 98.37719991803169, 120.44963032007217, 105.44835448265076, 108.64889234304428, 105.67665383219719, 106.01578563451767, 104.23751905560493, 107.53909349441528, 84.4619058072567, 94.02553662657738, 103.78386899828911, 112.29659020900726, 52.283408492803574, 54.00940887629986, 43.80906142294407, 48.47781389951706, 50.33852085471153, 42.39649102091789, 62.53708228468895, 94.45727705955505, 78.05545717477798, 76.53309926390648, 105.43323889374733, 51.116935685276985, 60.790046229958534, 70.61772868037224, 69.37480017542839, 52.08221308887005, 60.353586450219154, 93.39923143386841, 90.47755300998688, 75.55289626121521, 82.38609999418259, 105.36124795675278, 91.13010719418526, 87.43308037519455, 72.09857761859894, 50.66406078636646, 65.47893762588501, 63.14612500369549, 44.2499365657568, 37.74149380624294, 53.32884259521961, 57.78510667383671, 78.09872165322304, 79.38423067331314, 106.84519752860069, 128.40199559926987, 119.305549710989, 129.42347198724747, 126.31811141967773, 150.34908592700958, 146.6575688123703, 114.8166073858738, 58.83990727365017, 13.19783940911293, 0.571924113901332, 0.3453369881026447, 0.3257481782929972, 0.14946033392334357, 0.1779180607991293, 0.22743402019841596, 0.2958015992771834, 0.24052709341049194, 0.20474643213674426, 0.2084763624588959, 0.11771697085350752, 0.07851582515286282, 0.20747429982293397, 0.17478649446275085, 0.11517337101395242, 0.07219228165922686, 0.09987758865463547, 0.12125859604566358, 0.09680686358478852, 0.1747969290590845, 0.07356353307841346, 0.15480557834962383, 0.14984896697569638, 0.1189436370623298, 0.07550845723017119, 0.17952138179680333, 0.10373423327109776, 0.18947969743749127, 0.0693437630252447, 0.21865751536097378, 0.1786488833022304, 0.1094882823235821, 0.18767157336696982, 0.14217144926078618, 0.2874119463376701, 0.07792847463861108, 0.10368953371653333, 0.1930112368427217, 0.14485176012385637, 0.09298239849158563, 0.16198578290641308, 0.11646845581708476, 0.13698023016331717, 0.15813845966476947, 0.18536199495429173, 0.07320459335460328, 0.16286735044559464, 0.11205597969819792, 0.13498168584192172, 0.1941173485829495, 0.11548807873623446, 0.20573752583004534, 0.18853170768124983, 0.2169629101990722, 0.12871380342403427, 0.18752701784251258, 0.0848803723056335, 0.0963773307739757, 0.1833508934942074, 0.17201675480464473, 0.11032566981157288, 0.15072606678586453, 0.1815777987940237], [0.02631130406371085, 0.010946580823656404, 0.03873141075018793, 0.05015855909732636, 0.09768198186066002, 0.07709162149694748, 0.033791790847317316, 0.05410049874626566, 0.043272723705740646, 0.04178682531346567, 0.03238186982343905, 0.015061301728565013, 0.0235486760357162, 0.08151889604050666, 0.020857806266576517, 0.03595971553295385, 0.06621865337365307, 0.030923688791517634, 0.006775023466616403, 0.03531110814947169, 0.03762445667234715, 0.03775262557610404, 0.013711313767998945, 0.04400598045322113, 0.06650308889220469, 0.025049922041944228, 0.053291019721655175, 0.10408829708467238, 0.03857374518702272, 0.01906529698317172, 0.013321355982043315, 0.0549504879018059, 0.040203119278885424, 0.03416124680370558, 0.05421950583695434, 0.044128824447398074, 0.03375192638486624, 0.054236552969086915, 0.05223535175900906, 0.027963209759036545, 0.023804627926438116, 0.02047487661911873, 0.07293458518688567, 0.05290464650897775, 0.025752016008482315, 0.0851901744317729, 0.08449337197816931, 0.04769543404108845, 0.0405603335093474, 0.11618663265835494, 0.07009585548075847, 0.499259663047269, 8.581921197474003, 26.40790656208992, 48.218633607029915, 86.82592615485191, 99.24529373645782, 94.46770370006561, 77.642662525177, 79.48269858956337, 78.08514878153801, 71.28949463367462, 65.78973814845085, 50.866977497935295, 37.08607457578182, 24.57760937511921, 21.185364201664925, 21.692861169576645, 37.53161586821079, 56.68409675359726, 61.89914591610432, 103.97655665874481, 118.49765226244926, 114.83181416988373, 143.39208483695984, 111.9489012658596, 128.22273641824722, 88.56716752052307, 113.20650458335876, 112.38101407885551, 154.12035316228867, 112.40122899413109, 120.8879292011261, 168.22901129722595, 122.87863478064537, 152.59380787611008, 111.6741456091404, 121.62508964538574, 138.67067098617554, 124.70183774828911, 169.36799257993698, 105.12762129306793, 126.60368129611015, 156.8408703804016, 143.3838164806366, 122.94088304042816, 120.18089354038239, 136.0217571258545, 114.87508624792099, 83.92333790659904, 49.57883141934872, 31.16177447140217, 26.787468194961548, 33.75235006213188, 51.94821707904339, 61.24386727809906, 78.04496973752975, 74.28975284099579, 86.55329078435898, 91.0712331533432, 91.28148347139359, 108.99006843566895, 98.54206547141075, 54.713077917695045, 16.391463540494442, 1.9334437209181488, 0.5296287022065371, 0.5845511332154274, 0.3038449661107734, 0.10943480316200294, 0.08444024904747494, 0.0549461723130662, 0.08963350162957795, 0.12180976686067879, 0.15414779802085832, 0.03737588915100787, 0.011010781236109324, 0.060778109764214605, 0.0379072260693647, 0.10144579122425057, 0.042300818240619265, 0.06433621063479222, 0.05317169721820392, 0.038778911912231706, 0.06322836226900108, 0.08744213249883614, 0.047685288882348686, 0.04606567403243389, 0.049428419370087795, 0.027832020314235706, 0.01987758318136912, 0.057892268523573875, 0.07563108971226029, 0.04714730974228587, 0.01006408467219444, 0.0468276296305703, 0.049273050753981806, 0.09353698318591341, 0.09631504231947474, 0.024054854147834703, 0.08893194200936705, 0.03374399653694127, 0.029686916386708617, 0.028204261179780588, 0.025220092793460935, 0.00888848564500222, 0.08502492783009075, 0.08212710832594894, 0.025282002752646804, 0.004995803728888859, 0.03627587044320535, 0.03833399066934362, 0.056136970524676144, 0.06340538675431162, 0.010785070935526164, 0.08559722016798332, 0.04856491199461743, 0.052184826345182955, 0.008592235135438386, 0.0354942479316378, 0.016985457805276383, 0.04090720591193531, 0.014952247765904758, 0.022101502909208648, 0.02552483718318399, 0.034351073336438276, 0.028990624159632716, 0.00973484569840366, 0.06479347008280456, 0.043134175866725855, 0.06051528558600694, 0.07352923843427561, 0.0677297476795502, 0.05432433790701907, 0.019972505724581424, 0.05271886468108278, 0.03659917965705972, 0.049503918053233065, 0.008853614908730378, 0.08942152941017412, 0.11680576935759746, 0.022999714965408202, 0.016832686706038658, 0.04078277372173034, 0.038452838198281825, 0.02167088841815712, 0.07243132742587477, 0.04653144962503575, 0.04349600996647496, 0.0359089786070399, 0.03651137616543565, 0.01985864913876867, 0.05636770794808399, 0.06499787981738336, 0.05185785463254433, 0.06984247142099775, 0.027859834153787233, 0.06430435765651055, 0.009648191607993795, 0.015055617805046495, 0.02101289101119619, 0.06308184747467749, 0.03187435955624096, 0.03720013002748601, 0.01895656307169702, 0.018549365195212886, 0.017401177392457612, 0.06736081864801235, 0.11136050568893552, 0.057723541249288246, 0.06711236244882457, 0.16218402539379895, 0.0409192027291283, 0.04050275398185477, 0.03345669261761941, 0.18337335088290274, 0.0705560167261865, 1.2379774893634021, 1.7514907219447196, 18.635309636592865, 40.57363383471966, 85.14837697148323, 109.03484523296356, 107.10059702396393, 93.53164672851562, 85.78002467751503, 96.97558432817459, 91.51720762252808, 100.11311396956444, 87.24869146943092, 76.93354457616806, 44.200459420681, 40.37510588765144, 47.25557528436184, 55.63682734966278, 34.07992668449879, 36.73165239393711, 61.37752890586853, 71.45494535565376, 86.01112067699432, 87.26420223712921, 82.12887659668922, 103.60821962356567, 82.52373620867729, 81.83265209197998, 95.4256322979927, 89.45435911417007, 85.52243649959564, 91.5073661506176, 104.73650828003883, 85.74891194701195, 86.58080130815506, 82.3367178440094, 87.1225306391716, 79.9583950638771, 90.41699945926666, 105.57816311717033, 87.7592320740223, 96.38757348060608, 86.07712313532829, 81.30198016762733, 83.28958511352539, 89.7506596148014, 78.08541476726532, 55.60662277042866, 45.200964733958244, 30.419218316674232, 26.604709401726723, 30.934493467211723, 54.31339256465435, 88.79599124193192, 98.12965840101242, 114.32698085904121, 105.54588004946709, 107.26081922650337, 102.89407834410667, 106.42317697405815, 125.6548798084259, 114.81612861156464, 62.146881222724915, 20.264914892613888, 1.8863173434510827, 0.28029145498294383, 0.5747795419301838, 0.27498239767737687, 0.1416945896926336, 0.07028669133433141, 0.11502137916977517, 0.0675288557249587, 0.07619854324730113, 0.07349288804107346, 0.033312838422716595, 0.10351927761803381, 0.07420020672725514, 0.053607267400366254, 0.031711131596239284, 0.03978334199928213, 0.031797131669009104, 0.018757301986624952, 0.052766473454539664, 0.04115308685868513, 0.09444084484130144, 0.03165946698572952, 0.02243921349872835, 0.04083345498656854, 0.0395607904647477, 0.027843590396514628, 0.02672504026122624, 0.035695366241270676, 0.02211587274359772, 0.040073718409985304, 0.045025988220004365, 0.053302426531445235, 0.07079121816786937, 0.039101619986467995, 0.012115045028622262, 0.053963245954946615, 0.057720279510249384, 0.02333313965209527, 0.051031213442911394, 0.0390660525590647, 0.0020204135580570437, 0.011684132750815479, 0.03399162153073121, 0.035447982445475645, 0.019438231756794266, 0.017307757698290516, 0.029008250166953076, 0.06328886214760132, 0.035850883286911994, 0.008233781518356409, 0.06099083155277185, 0.0353764839383075, 0.08858015658915974, 0.016284627345157787, 0.052755493379663676, 0.04754095229145605, 0.019248395947215613, 0.10238504590233788, 0.027370007410354447, 0.020129965341766365, 0.01057589661286329, 0.10034838487626985, 0.07936240785056725, 0.2066593326162547, 0.17350507259834558, 0.15114846755750477, 0.1302000432042405, 0.28069942840375006, 0.1547394529916346, 0.160436742589809, 0.13630934350658208, 0.12417053862009197, 0.10468918437254615, 0.09258091886295006, 0.25208022503647953, 0.19841082132188603, 0.1143981383938808, 0.1328845546231605, 0.08141987127601169, 0.15419378149090335, 0.23694731440627947, 0.2184177571325563, 0.1778316154377535, 0.14525618607876822, 0.1510961609892547, 0.24784685141639784, 0.17051357921445742, 0.12722910731099546, 0.18047477438813075, 0.12381795168039389, 0.11756113468436524, 0.14563965378329158, 0.15258934727171436, 0.15402163291582838, 0.16779875848442316, 0.11315273295622319, 0.18983389483764768, 0.12545350415166467, 0.14391911798156798, 0.20265448110876605, 0.13970318483188748, 0.16111018223455176, 0.15624219813616946, 0.23789974220562726, 0.2100996027002111, 0.15943724778480828, 0.33876571571454406, 0.23940744489664212, 0.09789530478883535, 0.16272828681394458, 0.4731112770969048, 0.16607326513621956, 3.9225886529311538, 19.966258518397808, 49.244130179286, 78.55355724692345, 118.05315211415291, 125.1379631459713, 119.92143586277962, 98.02278533577919, 99.39658641815186, 101.23229071497917, 90.00522315502167, 87.82470256090164, 72.31106981635094, 51.229896023869514, 31.529841721057892, 31.81931208819151, 32.632888332009315, 53.50723162293434, 88.05146679282188, 90.43004035949707, 156.56161576509476, 170.8950850367546, 165.99088579416275, 208.11033368110657, 160.07428407669067, 175.369952917099, 125.87450802326202, 164.52907383441925, 159.48137909173965, 225.06125450134277, 168.74972015619278, 180.6846061348915, 249.79484170675278, 180.7535496354103, 227.32082605361938, 169.90903794765472, 177.41703987121582, 207.03558415174484, 182.67161071300507, 249.7002875804901, 153.1881719827652, 180.28539955615997, 212.79783815145493, 203.48186284303665, 180.01147985458374, 176.01143449544907, 191.49672836065292, 166.43492996692657, 118.45915272831917, 70.48223555088043, 47.05919422209263, 37.98109374940395, 45.93729302287102, 73.96095648407936, 84.34267580509186, 104.7524294257164, 96.76911100745201, 109.87889394164085, 111.19789436459541, 114.22110334038734, 139.54389452934265, 135.76600044965744, 84.27414268255234, 31.351471692323685, 4.474294586107135, 0.608321885811165, 0.733287027105689, 0.6835080950986594, 0.42878558684606105, 0.44077896047383547, 0.17547747847856954, 0.20494915719609708, 0.2541955537162721, 0.28204553585965186, 0.12228939463966526, 0.1768448410439305, 0.27020148234441876, 0.14797017560340464, 0.21955221891403198, 0.14579250651877373, 0.13836660655215383, 0.11002492188708857, 0.18823737191269174, 0.1988469369825907, 0.2957196958595887, 0.09769468742888421, 0.11766474592150189, 0.14943207293981686, 0.18644616880919784, 0.23748505976982415, 0.1634529940201901, 0.11552416195627302, 0.10165601939661428, 0.19174234243109822, 0.14015470747835934, 0.1823307224549353, 0.15590493654599413, 0.16022497817175463, 0.10887019205256365, 0.11284353939117864, 0.12099776082322933, 0.17679081269307062, 0.20373699255287647, 0.18269627471454442, 0.17029892042046413, 0.12679708830546588, 0.16255321417702362, 0.13255967205623165, 0.11638831871096045, 0.07946686513605528, 0.24594235204858705, 0.13471280573867261, 0.20017711794935167, 0.15575238066958264, 0.21956410811981186, 0.11788327872636728, 0.2006942019215785, 0.16717060469090939, 0.1340741728199646, 0.18465211585862562, 0.174926953332033, 0.1822714545414783, 0.19627855683211237, 0.08952941541792825, 0.1574273337610066], [0.04410340960021131, 0.04912591626634821, 0.07463320536771789, 0.04590050535625778, 0.046572494102292694, 0.03404714159842115, 0.019408874250075314, 0.003378892383807397, 0.04178215349384118, 0.03229047062632162, 0.018341138966206927, 0.05983806469885167, 0.04665158849093132, 0.027947864000452682, 0.021906614929321222, 0.07007746506133117, 0.0935039427713491, 0.026152734935749322, 0.04736936774861533, 0.013103384426358389, 0.08803622171399184, 0.08140680205542594, 0.035702056702575646, 0.018348104022152256, 0.016658571439620573, 0.007710635127295973, 0.04591883269313257, 0.025615917256800458, 0.08497036513290368, 0.03909288490831386, 0.05137974083481822, 0.060104529111413285, 0.0710642542981077, 0.007418452514684759, 0.023845642717787996, 0.04871126722719055, 0.03172352917317767, 0.00827117555672885, 0.05111397033033427, 0.06702278522425331, 0.0524515059805708, 0.03149309974105563, 0.04580041560984682, 0.011447203960415209, 0.02660339483554708, 0.16986586240818724, 0.027272722982161213, 0.3803488437552005, 0.3607740456936881, 1.4070090441964567, 22.67668727785349, 52.001646012067795, 59.02628347277641, 75.91011509299278, 85.88331833481789, 83.62451434135437, 70.36273196339607, 82.3779684305191, 54.885052889585495, 29.80489958077669, 34.41732197999954, 31.640590578317642, 26.343728005886078, 19.86038289964199, 36.424929052591324, 101.71491801738739, 118.26170012354851, 83.77259239554405, 79.95068907737732, 75.1206086575985, 69.11045596003532, 31.528447195887566, 21.77614890038967, 11.35311059653759, 6.8528372794389725, 1.8928804225288332, 0.6334330164827406, 0.18733353994321078, 0.7024032343178988, 1.0418963734991848, 2.5488426676020026, 1.8525894032791257, 2.206700714305043, 3.748948657885194, 2.4826585315167904, 3.554522590711713, 2.0128966262564063, 1.2285970989614725, 0.533017348498106, 0.8929147990420461, 1.3478001463226974, 2.319221938960254, 3.189012841321528, 4.622113304212689, 5.330044766888022, 8.22326509281993, 9.273344445973635, 24.031400084495544, 51.07571169734001, 95.07619544863701, 131.84234619140625, 137.4539002776146, 144.28800076246262, 93.49893808364868, 47.561781853437424, 32.227385491132736, 23.509414494037628, 20.89845109730959, 51.028928607702255, 75.73509648442268, 80.93871206045151, 89.2013230919838, 86.94758042693138, 93.59055876731873, 102.79560282826424, 77.92785242199898, 38.46438221633434, 22.034609131515026, 14.938990529626608, 5.291001861914992, 2.182191079482436, 0.2566827874397859, 0.2910105907358229, 0.03993840262410231, 0.07445949828252196, 0.028145030373707414, 0.06466920487582684, 0.021887775510549545, 0.029809979314450175, 0.03716471474035643, 0.1081705026444979, 0.012481277281040093, 0.042632628756109625, 0.026804685694514774, 0.03211249248124659, 0.038783958516432904, 0.04599313280778006, 0.019944370906159747, 0.03618264185206499, 0.04530313584837131, 0.05095086853543762, 0.041814429496298544, 0.008192585828510346, 0.017939310528163332, 0.04722768433566671, 0.030540662664861884, 0.07455577710061334, 0.002930240225396119, 0.04106935033632908, 0.0578722565114731, 0.06300217792158946, 0.0592324833269231, 0.024076085137494374, 0.034064878927893005, 0.041263952589361, 0.04486994424951263, 0.010819168910529697, 0.017130423366324976, 0.10154255985980853, 0.02057746740319999, 0.06778512673918158, 0.09495626640273258, 0.03297934694273863, 0.019096387404715642, 0.02894580586144002, 0.023853836028138176, 0.04704170212789904, 0.05727594827476423, 0.00020304340011989552, 0.034030625101877376, 0.05175219877855852, 0.015509025506617036, 0.025705561274662614, 0.024515891127521172, 0.07605332721141167, 0.039399106171913445, 0.03298536947113462, 0.03697231295518577, 0.04405287676490843, 0.015097323721420253, 0.06854593942989595, 0.0532652300898917, 0.03816162687144242, 0.026254123440594412, 0.018365216092206538, 0.01230825482707587, 0.03121232301054988, 0.05054998633568175, 0.032182751601794735, 0.0453202683274867, 0.02696126772207208, 0.012769509812642355, 0.06684330423013307, 0.032727105790399946, 0.021273731799738016, 0.03280169163190294, 0.04041609339765273, 0.024158398591680452, 0.08208138460759073, 0.010500333919480909, 0.011253650918661151, 0.028961634016013704, 0.018855271046049893, 0.027162603109900374, 0.09965324483346194, 0.0512417087884387, 0.03874515532515943, 0.03735746162419673, 0.08444122868240811, 0.09465047187404707, 0.01591019899933599, 0.051163208117941394, 0.03527889522956684, 0.015190910398814594, 0.050742024468490854, 0.07576908465125598, 0.0799902796279639, 0.05409363016951829, 0.028942002354597207, 0.017290040777879767, 0.037498870442504995, 0.1388555037556216, 0.07569855835754424, 0.2402130313566886, 0.2706286625470966, 2.4387613870203495, 9.154686313122511, 40.16895554959774, 63.18202547729015, 85.41458308696747, 97.52259537577629, 100.76956674456596, 84.10837277770042, 97.4438787996769, 87.32179194688797, 62.27774620056152, 64.30237635970116, 63.04697312414646, 47.44409076869488, 34.169149696826935, 29.29483775049448, 61.93774804472923, 50.15295401215553, 28.847945630550385, 57.24860966205597, 75.42252525687218, 67.97409653663635, 45.71528613567352, 30.406589694321156, 17.069556154310703, 11.404271051287651, 4.694379726424813, 2.1517456881701946, 1.5046538296155632, 2.070354768075049, 1.8922158144414425, 5.2392144408077, 2.8782895021140575, 3.611449711024761, 5.178155517205596, 4.069924084469676, 5.088015804067254, 2.8589713387191296, 1.5477376990020275, 1.1549222585745156, 0.9471881180070341, 1.1712637566961348, 2.8917797282338142, 3.9730048226192594, 6.662014368921518, 8.815673254430294, 10.980071313679218, 13.939975686371326, 28.851093761622906, 50.93342453241348, 78.61098736524582, 91.39970272779465, 77.0224218070507, 72.44179040193558, 45.46887315809727, 36.85539275407791, 30.733431056141853, 44.77530777454376, 44.47201564908028, 89.84147474169731, 112.83038556575775, 102.70132228732109, 100.19426241517067, 99.57792788743973, 110.47060579061508, 118.68019446730614, 91.19794875383377, 44.0225263684988, 23.6824382096529, 14.30308610200882, 4.186318488791585, 0.8285952941514552, 0.2608189545571804, 0.19621767103672028, 0.03871193308441434, 0.07619041673024185, 0.014609907102567377, 0.025392443603777792, 0.03639121503510978, 0.05592576642811764, 0.03041204847249901, 0.05361075920518488, 0.0034451696501491824, 0.03239601144741755, 0.03283971927885432, 0.09751162186148576, 0.026074757479364052, 0.03516285301884636, 0.037662283939425834, 0.026750059914775193, 0.03915915498510003, 0.05075293403933756, 0.05387529403378721, 0.031003812910057604, 0.054425926791736856, 0.050053192680934444, 0.014445535307459068, 0.031369843854918145, 0.05194761368329637, 0.010397058504167944, 0.033924872768693604, 0.05969536454358604, 0.036702282523037866, 0.04297628765925765, 0.02444983256282285, 0.017987911924137734, 0.03185788758855779, 0.03805558510066476, 0.03305313868622761, 0.039997462736209854, 0.014058840188226895, 0.04274263730621897, 0.062319439166458324, 0.036147475184407085, 0.048342468071496114, 0.03672566388559062, 0.03486661364149768, 0.03374043051735498, 0.05488640716066584, 0.027119387850689236, 0.02359565954975551, 0.045587601052829996, 0.08077202830463648, 0.04724618236650713, 0.07826026660040952, 0.033795460767578334, 0.017746120211086236, 0.13273285963805392, 0.20249088207492605, 0.13378246425418183, 0.1251785532804206, 0.2140668421634473, 0.11545523128006607, 0.11160819005453959, 0.11411013314500451, 0.09483314410317689, 0.07165158254792914, 0.15759261004859582, 0.2315849412116222, 0.14510377863189206, 0.15403502125991508, 0.129001667664852, 0.13818390463711694, 0.2006279132911004, 0.08994470641482621, 0.11218215222470462, 0.09217068931320682, 0.1488384438562207, 0.267929233959876, 0.17875098797958344, 0.12920908309752122, 0.05382351439038757, 0.1034872984746471, 0.1612875406863168, 0.10724141538958065, 0.17722749238600954, 0.18620008748257533, 0.09879282108158804, 0.14968137518735602, 0.18028827267698944, 0.15611946175340563, 0.14336552034365013, 0.1620705213281326, 0.17969259526580572, 0.08643983979709446, 0.19886500085704029, 0.0954700775037054, 0.11236342179472558, 0.1476757656200789, 0.16569246916333213, 0.24163608468370512, 0.23025850066915154, 0.27981921157334, 0.11465412739198655, 0.44733470713254064, 0.6984817259944975, 11.620013024657965, 43.548972979187965, 85.65329387784004, 88.66956442594528, 104.66328620910645, 106.67957961559296, 107.67458662390709, 89.50944855809212, 103.46634283661842, 74.16735380887985, 46.809817403554916, 48.80918651819229, 45.11264227330685, 35.63267916440964, 26.795147582888603, 52.62401841580868, 125.49545556306839, 153.16315412521362, 117.26334169507027, 116.5715280175209, 108.09233620762825, 105.3449696302414, 49.73733231425285, 34.729752615094185, 17.62656256556511, 10.775822773575783, 4.089224198833108, 2.7122828224673867, 1.2693222449161112, 2.460877150297165, 1.6547894733957946, 4.866811148822308, 3.107980526983738, 4.304608516395092, 7.551776049658656, 4.678009254857898, 7.131195142865181, 4.171400489285588, 2.7327235881239176, 1.8916451325640082, 1.1306968959979713, 1.9962525693699718, 3.4937327401712537, 4.431609101593494, 8.278338387608528, 9.862487632781267, 13.005342688411474, 15.209272876381874, 37.527930065989494, 75.95983162522316, 134.36197578907013, 185.09657979011536, 197.3236244916916, 199.19926464557648, 134.220212996006, 70.32192215323448, 45.89975483715534, 36.29028707742691, 31.401089429855347, 67.91706919670105, 99.56567734479904, 107.95889496803284, 113.15744161605835, 109.45634141564369, 116.69527977705002, 135.7866257429123, 112.5481291115284, 67.65552923083305, 39.31880436837673, 26.665048263967037, 11.695844605565071, 5.125839449465275, 0.41154246835503727, 0.6580821750685573, 0.22641432413365692, 0.17082632024539635, 0.14472425915300846, 0.18627694429596886, 0.10016577944043092, 0.09909123124089092, 0.07720892535871826, 0.18464824184775352, 0.10640545282512903, 0.12904536532005295, 0.1347147798514925, 0.14079252403462306, 0.13813780242344365, 0.10681029438273981, 0.12757609103573486, 0.19421513396082446, 0.1511628058506176, 0.144104135397356, 0.11971368949161842, 0.07788761198753491, 0.06980561636737548, 0.12442934035789222, 0.04569300828734413, 0.14041968388482928, 0.10605333343846723, 0.1495613402221352, 0.12816568283597007, 0.1901464577531442, 0.14175707852700725, 0.1066570112016052, 0.21789003076264635, 0.08995213531306945, 0.08667574627907015, 0.15993392269592732, 0.17495996406069025, 0.2371398571995087, 0.18213540402939543, 0.15499636967433617, 0.1595629082294181, 0.20846769417403266, 0.19329510832903907, 0.12226109654875472, 0.1096008438616991, 0.10104109809617512, 0.1340539418742992, 0.25681955041363835, 0.10153794370125979, 0.12751599191688, 0.19207244971767068, 0.12217652882100083, 0.18628867022925988, 0.12019877205602825, 0.16848785744514316], [0.059060293933725916, 0.040325889058294706, 0.021554883314820472, 0.05603030163911171, 0.07604659593198448, 0.032525152564630844, 0.023296167710213922, 0.051036861186730675, 0.06539230904309079, 0.0560166275681695, 0.021478907801792957, 0.04896888895018492, 0.05788314752862789, 0.02710356897296151, 0.11891928719705902, 0.10256489054881968, 0.05082618401502259, 0.11430580780142918, 0.09472801146330312, 0.009047765379364137, 0.08460665339953266, 0.01976062256289879, 0.0313944868685212, 0.04221446935844142, 0.01786472654202953, 0.0735943544714246, 0.06296854378888384, 0.023713718546787277, 0.030887034117768053, 0.034154389359173365, 0.010335665265301941, 0.03615992100094445, 0.04079884492966812, 0.048861266404855996, 0.025086179666686803, 0.031533810251858085, 0.10048785668914206, 0.01563648009323515, 0.02971181173052173, 0.048853484986466356, 0.033091722943936475, 0.014971359923947603, 0.05776603662525304, 0.0684155069757253, 0.05779478371550795, 0.2342022437369451, 0.7818909909110516, 9.822146147489548, 29.663771353662014, 57.1656297147274, 74.53411012887955, 82.9818320274353, 55.63347592949867, 71.7560563981533, 75.75400426983833, 84.91760775446892, 99.55771297216415, 60.42902000248432, 33.842648416757584, 42.903269827365875, 51.18267595767975, 26.461935862898827, 58.32826852798462, 72.51311257481575, 94.713976085186, 97.78117150068283, 78.71341466903687, 74.69079852104187, 26.696844957768917, 2.7869053557515144, 0.36239626177120954, 0.4121668520383537, 0.49507395015098155, 0.4112282727146521, 0.17578189261257648, 0.0529453792842105, 0.21713973430451006, 0.2302126953145489, 0.09760323257069103, 0.14468780485913157, 0.05196438622078858, 0.1128783164313063, 0.0804488526773639, 0.07457551822881214, 0.03250686604587827, 0.04674953714129515, 0.04658229045162443, 0.3477896674303338, 0.3466336685232818, 0.3710405307356268, 0.3464124194579199, 0.0626760782324709, 0.1725630200235173, 0.25157140858937055, 0.11265700057265349, 0.2839890425093472, 0.1620387870934792, 0.6057184317614883, 0.9503088193014264, 0.7158239954151213, 0.9815443900879472, 11.634610891342163, 32.014984488487244, 83.65413755178452, 112.38902404904366, 114.31777775287628, 88.55370864272118, 56.65709160268307, 38.70463952422142, 30.236176438629627, 41.97659075260162, 79.58135649561882, 68.71268570423126, 78.08277770876884, 79.95978578925133, 81.50111988186836, 98.6299167573452, 92.75167018175125, 101.86595991253853, 93.53313624858856, 77.64836981892586, 48.01677703857422, 8.226564265787601, 0.4954133788123727, 0.006400243528332794, 0.039132055462687276, 0.11529161740327254, 0.0710009787871968, 0.050470899368519895, 0.014582444855477661, 0.0521812974329805, 0.05039412419137079, 0.03412529345951043, 0.024027671133808326, 0.08791644650045782, 0.021706092193198856, 0.08913330151699483, 0.03831497684586793, 0.03782418345508631, 0.09046718580066226, 0.02425309292448219, 0.007599001737617073, 0.06237857349333353, 0.10382935433881357, 0.03830962967185769, 0.06474641792010516, 0.025272746315749828, 0.04446732913493179, 0.07138710338040255, 0.021063034218968824, 0.04772415886691306, 0.011319343975628726, 0.013333975275600096, 0.008383904078073101, 0.04840919456910342, 0.05785854533314705, 0.0382758100022329, 0.03719289037690032, 0.04274037004506681, 0.045735752282780595, 0.06323001725832, 0.08942376327468082, 0.09228739945683628, 0.039308790510403924, 0.03469335555564612, 0.006535908123623813, 0.01683654587395722, 0.022515834680234548, 0.04462272372620646, 0.01567309951497009, 0.03288696439994965, 0.0703280363813974, 0.013944832389825024, 0.013935441438661655, 0.0793579698074609, 0.03321640004287474, 0.04038309751194902, 0.013304376570886234, 0.03824576786428224, 0.035802766142296605, 0.1099864266871009, 0.061694632458966225, 0.018591183361422736, 0.048506768434890546, 0.1069545753125567, 0.0499718458740972, 0.03983126618550159, 0.08226093981647864, 0.014416191716009052, 0.021905356989009306, 0.03304239238786977, 0.06370734437950887, 0.056440687039867043, 0.04555367006105371, 0.06729219225235283, 0.02767239548120415, 0.11176356609212235, 0.03607972452300601, 0.05008466345316265, 0.03077909987041494, 0.04983182858268265, 0.09054570502485149, 0.03294419511803426, 0.01703887388430303, 0.08990353948320262, 0.12262414777069353, 0.02856536983017577, 0.03729267955350224, 0.08565917465602979, 0.010813075878104428, 0.030416373338084668, 0.04400100064231083, 0.15468661207705736, 0.015101580866030417, 0.07687176766921766, 0.043352823704481125, 0.011591812362894416, 0.04058041602547746, 0.03939618582080584, 0.032143354692379944, 0.09590597794158384, 0.07986927244928665, 0.22381265123840421, 1.5107035799883306, 13.956801183521748, 45.52735581994057, 81.75765171647072, 94.18553844094276, 66.28811940550804, 84.03892010450363, 84.41179409623146, 98.6718513071537, 112.06851124763489, 89.98456746339798, 52.40655988454819, 26.707775071263313, 37.11442105472088, 29.32167761027813, 32.91074462234974, 36.406021267175674, 53.27863588929176, 86.68218746781349, 92.64614224433899, 69.29939702153206, 33.915023133158684, 5.1926189661026, 0.7227354682981968, 0.7426117267459631, 0.5576096288859844, 0.7877587666735053, 0.2754456165712327, 0.22106067859567702, 0.11518120067194104, 0.2324886989663355, 0.06089250440709293, 0.026409980018797796, 0.0582266320270719, 0.12398320570355281, 0.09658502080128528, 0.11496804101625457, 0.07240333361551166, 0.014728087626281194, 0.027246230165474117, 0.09435978747205809, 0.1059319477644749, 0.41691362857818604, 0.06540053203934804, 0.09828066496993415, 0.12683657056186348, 0.3292592492653057, 0.2974144939798862, 0.3265962452860549, 0.25519510789308697, 0.8338575961533934, 0.8835510921198875, 0.27349062147550285, 2.1316575910896063, 14.02022073045373, 38.543224185705185, 77.86874279379845, 82.65449479222298, 75.66583380103111, 42.71962568163872, 23.881804011762142, 33.25864635407925, 43.8000825047493, 73.90549466013908, 107.91678562760353, 105.31297534704208, 96.76442205905914, 92.52963289618492, 94.33020427823067, 115.06482526659966, 109.46110635995865, 115.25258079171181, 102.3468317091465, 82.881069034338, 47.642801105976105, 5.803707875311375, 0.43329671665560454, 0.08238434413215145, 0.085187628865242, 0.03518210804031696, 0.10078583640279248, 0.06068638773285784, 0.03822678372671362, 0.013939123418822419, 0.02771614137600409, 0.026684223994379863, 0.04927788955683354, 0.01427775056072278, 0.06702885599224828, 0.10773190821055323, 0.05732580575568136, 0.01189259739476256, 0.021021106585976668, 0.03350781546032522, 0.04209339909721166, 0.09877282762317918, 0.0025266322563766153, 0.012897926408186322, 0.05274570074107032, 0.051655816059792414, 0.03434095786360558, 0.06156780684250407, 0.02565655540820444, 0.00656622717542632, 0.10371108568506315, 0.07517041638493538, 0.017626699373067822, 0.02533012917410815, 0.03276440613262821, 0.02852783571142936, 0.03924152966646943, 0.07213821620098315, 0.03540339421306271, 0.0768045661970973, 0.053586784124490805, 0.02969274966744706, 0.03259157849242911, 0.03421671121031977, 0.05972128034045454, 0.07236788122099824, 0.010771370889415266, 0.041458796040387824, 0.020700858731288463, 0.02773875090497313, 0.044081775995437056, 0.014581827945221448, 0.01510355219579651, 0.10573216903139837, 0.018726998241618276, 0.20045377576025203, 0.09424463583854958, 0.14690909738419577, 0.1928336260607466, 0.2135714585892856, 0.12550143204862252, 0.05241316663159523, 0.1347963121952489, 0.19599685241701081, 0.2128692829865031, 0.10771641958854161, 0.19386331143323332, 0.164663718896918, 0.11679842209559865, 0.26979742746334523, 0.1738740981090814, 0.1897016292787157, 0.22348791710101068, 0.21711033041356131, 0.0775212211010512, 0.2324296091683209, 0.19074721145443618, 0.15473600942641497, 0.19866460614139214, 0.13075865776045248, 0.19608267437433824, 0.1284435874549672, 0.12665832153288648, 0.1560812708339654, 0.2381264980067499, 0.18152231583371758, 0.1627717915107496, 0.18452980992151424, 0.11767102449084632, 0.1054932494298555, 0.08421825783443637, 0.16187300614546984, 0.16819080541608855, 0.2507006615633145, 0.20820096629904583, 0.15727517864434049, 0.10014951156335883, 0.3123414289439097, 0.1532880199374631, 0.21614245109958574, 0.49242513603530824, 1.6621379228308797, 18.368049077689648, 58.56460064649582, 99.67603102326393, 106.90835013985634, 108.3060747385025, 77.57375702261925, 92.97567576169968, 99.9047863483429, 109.75901797413826, 122.12999895215034, 80.35039722919464, 46.401346921920776, 59.05974827706814, 70.87277099490166, 38.90309527516365, 89.39091771841049, 112.98866227269173, 142.56844103336334, 141.20145678520203, 110.69064438343048, 114.63211968541145, 43.72018799185753, 6.640075771138072, 0.6836900697089732, 1.2992235529236495, 0.8240578032564372, 0.8565798425115645, 0.23765597637975588, 0.16371559555409476, 0.41035927715711296, 0.44876441010273993, 0.15955968730850145, 0.20402055233716965, 0.1008474495029077, 0.24631406413391232, 0.21753403736511245, 0.17083457292756066, 0.09421746581210755, 0.19284769718069583, 0.17241300229215994, 0.59736980474554, 0.6167344562709332, 0.754161860095337, 0.7603297010064125, 0.15664168138755485, 0.16810908011393622, 0.3557580179767683, 0.2897440118249506, 0.30308058368973434, 0.300847728503868, 0.8430605242028832, 1.0808164975605905, 0.9610341594088823, 2.4902913719415665, 22.27250676602125, 52.78280809521675, 127.03888714313507, 166.61146849393845, 162.2917690873146, 123.06035622954369, 79.29618939757347, 51.03209003806114, 40.59100270271301, 57.279270216822624, 99.16915342211723, 94.80301290750504, 104.28203746676445, 99.3197925388813, 101.51499554514885, 125.37196978926659, 123.03048983216286, 133.77671599388123, 126.31414443254471, 109.12107020616531, 74.32848036289215, 16.223449856042862, 0.7190957386046648, 0.23513095249654725, 0.28925645048730075, 0.26376014517154545, 0.14139854698441923, 0.1407845236826688, 0.14357289124745876, 0.17115095048211515, 0.12903838913189247, 0.16605907527264208, 0.19254706799983978, 0.12366844603093341, 0.19054205215070397, 0.1907368956017308, 0.18944526178529486, 0.21139001939445734, 0.19172951811924577, 0.169696073862724, 0.13678805844392627, 0.17148248269222677, 0.2646286360686645, 0.14969685638789088, 0.09259997721528634, 0.12965125468326733, 0.09341271055745892, 0.20996675826609135, 0.08595486855483614, 0.1754471246385947, 0.21606623253319412, 0.20016407099319622, 0.14758140896447003, 0.17611945106182247, 0.14377929735928774, 0.1272249364410527, 0.18949752382468432, 0.1783297598012723, 0.11029218410840258, 0.19859307794831693, 0.24478595238178968, 0.19752668595174327, 0.17844339745352045, 0.17666261410340667, 0.0750071661605034, 0.10374328005127609, 0.18528685992350802, 0.10869310077396221, 0.09512378397630528, 0.07104432021151297, 0.18146367132430896, 0.11244623063248582, 0.12444065068848431, 0.22189253708347678, 0.15476805536309257], [0.07612445464474149, 0.02153403082047589, 0.037666451098630205, 0.0293218984734267, 0.05297266434354242, 0.056573564870632254, 0.06572571146534756, 0.033674416481517255, 0.009948417246050667, 0.004569641660054913, 0.02319907067430904, 0.01994261943764286, 0.06494797780760564, 0.03529586443619337, 0.055562841371283866, 0.034592371521284804, 0.013127901274856413, 0.018908512720372528, 0.025819482798397075, 0.11334765804349445, 0.04472627188079059, 0.039928276019054465, 0.04596339123963844, 0.06049178547982592, 0.05918189483054448, 0.02814888026478002, 0.01528789796793717, 0.02235595566162374, 0.036616705474443734, 0.018768883201119024, 0.010630945416778559, 0.0783391494769603, 0.04575217601086479, 0.029617792752105743, 0.07962152129039168, 0.04861966393946204, 0.023557758067909162, 0.04972424314473756, 0.019119512726319954, 0.0033679964963084785, 0.01773681738995947, 0.05008794003515504, 0.09764389484189451, 0.0994784987415187, 0.22014277550624683, 13.461451213806868, 43.13136778771877, 68.97823065519333, 79.31381285190582, 83.47842738032341, 78.0888269841671, 84.02580320835114, 60.03645546734333, 55.87705805897713, 78.08675989508629, 52.012133449316025, 24.165945164859295, 23.98730155080557, 34.74813222885132, 121.53053551912308, 85.27022883296013, 95.52842438220978, 95.58119595050812, 77.65169084072113, 46.558468490839005, 24.711419194936752, 2.8499268740415573, 0.6389041291549802, 0.7378645346034318, 0.12339457869529724, 0.178807346674148, 0.042585602568578906, 0.11765114235458896, 0.09063724894076586, 0.08192643159418367, 0.03842695579805877, 0.2002289643860422, 0.3206137631786987, 0.2192317001754418, 0.32804571907036006, 0.04326538386521861, 0.09551530398312025, 0.25014927552547306, 0.2910766418790445, 0.21838529559317976, 0.05394063642597757, 0.14346053008921444, 0.39790102222468704, 0.053563016845146194, 0.0210666911516455, 0.1565453506191261, 0.16725590714486316, 0.4315440310165286, 0.18104686634615064, 0.07884915336035192, 0.13327010034117848, 0.09730062185553834, 0.3698852442903444, 0.770803838968277, 0.5956610245630145, 0.11454667182988487, 0.4685506015084684, 0.5638186144642532, 0.4382154339691624, 8.442130498588085, 33.63699585199356, 98.77502337098122, 129.15845900774002, 123.49943026900291, 91.26291006803513, 32.13801808655262, 20.25289423763752, 21.88331265002489, 32.63901740312576, 49.62327383458614, 69.550601541996, 73.15670683979988, 74.4487439095974, 70.5045023560524, 79.76609498262405, 82.95628219842911, 87.85396859049797, 83.3498726785183, 23.417159244418144, 0.845336364582181, 0.05674211402947549, 0.04860631270275917, 0.022899476789461914, 0.030326228370540775, 0.06560195091878995, 0.02301612199516967, 0.02867141716706101, 0.012163994306320092, 0.03843328631774057, 0.034686334838625044, 0.06174474969157018, 0.045016451622359455, 0.04839827757677995, 0.023327039198193233, 0.01685848561464809, 0.007993994531716453, 0.05506796616828069, 0.02837910931702936, 0.04879409090790432, 0.05481617401528638, 0.04035504432977177, 0.055452157466788776, 0.009053659887285903, 0.03313453002192546, 0.053155410787439905, 0.012787031919287983, 0.03775697456148919, 0.11774300539400429, 0.07322736986679956, 0.05305945480358787, 0.02685081202798756, 0.035301872121635824, 0.028073105131625198, 0.02873419172829017, 0.019560856817406602, 0.05937434114457574, 0.043272601251374, 0.022601587988901883, 0.05335530084266793, 0.018091398851538543, 0.08092311472864822, 0.03963055234635249, 0.02078494777379092, 0.03762306885619182, 0.050897500696009956, 0.030365278325916734, 0.03171308715536725, 0.04458296316443011, 0.042192015680484474, 0.017362635808240157, 0.049897144999704324, 0.02878790837712586, 0.048312793296645395, 0.08074590470641851, 0.03165951893606689, 0.06113096387707628, 0.009677759699115995, 0.012972302592970664, 0.008271767419500975, 0.007853070892451797, 0.05397148379415739, 0.03571531517081894, 0.041908956845873035, 0.043795937817776576, 0.028000066668028012, 0.0131855800646008, 0.033528146595926955, 0.05310090746206697, 0.02640012800839031, 0.038045621768105775, 0.10511285421671346, 0.040500538671039976, 0.01961195554031292, 0.05910837397095747, 0.07573339476948604, 0.09278728786739521, 0.013611317717732163, 0.013354768398130545, 0.004277169609849807, 0.030827513874100987, 0.03781705141591374, 0.016615667882433627, 0.04739457850519102, 0.0961950296186842, 0.033157870566355996, 0.0362013625272084, 0.04051239448017441, 0.05388588077039458, 0.0026259448350174353, 0.01805274594516959, 0.09094765220652334, 0.02100379413604969, 0.012259039303899044, 0.0884641069569625, 0.07442116635502316, 0.38297699647955596, 0.9861527115572244, 25.24186883121729, 62.59858198463917, 86.52551427483559, 93.0673648416996, 86.82597175240517, 91.62191480398178, 68.60104009509087, 80.63249409198761, 86.27484932541847, 77.43748873472214, 62.21542574465275, 41.323968172073364, 35.55085815489292, 109.86721336841583, 70.20105063915253, 35.89219383895397, 70.50821855664253, 65.10303139686584, 53.399127423763275, 25.088294371962547, 3.6427234578877687, 0.2767851040698588, 1.0454729315824807, 0.07357063543167897, 0.06233414853340946, 0.1339866587659344, 0.10536064248299226, 0.14760679041501135, 0.0705138553166762, 0.11067853876738809, 0.3567091841250658, 0.189288935798686, 0.3055428812513128, 0.3921008115867153, 0.2960398583672941, 0.21484020457137376, 0.6532849324867129, 0.9815283596981317, 0.5803633423056453, 0.646533704129979, 0.4684713698225096, 0.6123228929936886, 0.4146742128068581, 0.10967837602947839, 0.4703949572285637, 0.19244422117481008, 0.5000148131512105, 0.182946897984948, 0.20446101698325947, 0.07313901718589477, 0.159189474361483, 0.5141335492953658, 0.5243931175209582, 0.1981915908982046, 0.10191781941102818, 0.5629196658264846, 0.6855385517701507, 0.20925116463331506, 9.535606373101473, 35.18438681960106, 83.56975167989731, 92.1038581430912, 73.89490082859993, 56.1391793936491, 29.914979673922062, 42.45078630745411, 44.469158202409744, 62.52212628722191, 85.12126922607422, 89.22354429960251, 88.43497261404991, 84.78770032525063, 84.42756325006485, 94.40718054771423, 96.14641562104225, 101.22089132666588, 89.98215079307556, 20.28224766254425, 0.3261112963082269, 0.02106483021634631, 0.03933682142815087, 0.01505872833149624, 0.1075792706978973, 0.06430628724046983, 0.03008761676028371, 0.06316708313534036, 0.031121580614126287, 0.027219843104830943, 0.03822400438366458, 0.07971898012328893, 0.08467055231449194, 0.019976784205937292, 0.07092416650266387, 0.06364973145537078, 0.027546683086256962, 0.059567588978097774, 0.004914349774480797, 0.007443912354574422, 0.02515544245397905, 0.02347200846998021, 0.0261755133033148, 0.0587169430218637, 0.01050286557074287, 0.0338760283193551, 0.07204818626632914, 0.014157710957078962, 0.055365838270518, 0.026089886159752496, 0.02421324887109222, 0.008987862001959002, 0.01843021709646564, 0.05191141171962954, 0.02337244564841967, 0.04435949507751502, 0.04963058039720636, 0.015269856357917888, 0.042253057326888666, 0.07681906034122221, 0.027528758364496753, 0.056253357834066264, 0.05160463755601086, 0.029194928138167597, 0.08286299969768152, 0.0421444699895801, 0.06307772113359533, 0.02072410465189023, 0.029502173565560952, 0.03950591606553644, 0.05530241804081015, 0.05473897581396159, 0.17439542716601864, 0.12784166116034612, 0.16133974335389212, 0.04590014541463461, 0.14623261493397877, 0.12186988082248718, 0.16490698006236926, 0.15205324947601184, 0.12975689198356122, 0.10985953427734785, 0.1540700951591134, 0.12224160775076598, 0.18976958031998947, 0.19435339607298374, 0.12547732709208503, 0.1603905513184145, 0.12453390896553174, 0.12521146010840312, 0.08002467075129971, 0.26224087981972843, 0.10680118823074736, 0.13867529545677826, 0.11043737045838498, 0.14777988893911242, 0.16013385728001595, 0.10856847191462293, 0.089624061511131, 0.12277811372769065, 0.17124987876741216, 0.1465014653513208, 0.10491832988918759, 0.17654033785220236, 0.17245572031242773, 0.10305026997230016, 0.08286431329906918, 0.22233199240872636, 0.1375183169147931, 0.14176280790707096, 0.08970492592197843, 0.2731919812504202, 0.11179173801792786, 0.15624129271600395, 0.18111520330421627, 0.41871835361234844, 0.6158036843407899, 26.0358552262187, 70.8650878071785, 104.64320048689842, 108.96518737077713, 110.41104778647423, 101.96941316127777, 107.2427549958229, 85.6526631116867, 88.50404530763626, 105.40383607149124, 70.33804088830948, 37.31232203543186, 34.352607652544975, 51.634312123060226, 134.84334915876389, 111.61787062883377, 140.7978120446205, 138.85874569416046, 115.44609680771828, 65.87999850511551, 38.579060062766075, 6.622875994071364, 0.7483558903913945, 1.4823079411871731, 0.302239908487536, 0.21472016960615292, 0.2558822475839406, 0.19301451713545248, 0.21584965899819508, 0.3002625599037856, 0.28828486043494195, 0.5829361011274159, 0.4459134943317622, 0.9556359553243965, 0.5354958842508495, 0.391697766026482, 0.5147163430228829, 0.48013525956775993, 0.5475843418389559, 0.4848669556668028, 0.466522786882706, 0.4494367365259677, 0.4733339510858059, 0.22805852262536064, 0.16063776070950553, 0.46970339433755726, 0.4935229505645111, 0.7086441619321704, 0.6289975857362151, 0.6544987298548222, 0.5290720914490521, 0.35658972803503275, 0.6265658349730074, 0.8720612805336714, 0.5165473697707057, 0.16077198553830385, 0.6559596327133477, 0.7125553395599127, 0.814113796222955, 14.359462726861238, 53.39508444070816, 150.06063580513, 178.86720925569534, 170.81928670406342, 121.42737105488777, 48.03220421075821, 33.220105022192, 31.99051760137081, 45.076050236821175, 68.92456233501434, 97.96875223517418, 94.28408995270729, 95.50671994686127, 89.78510856628418, 98.86561810970306, 103.86389270424843, 109.14483413100243, 112.63845786452293, 42.13736392557621, 1.2949049659073353, 0.283835714799352, 0.1469315102440305, 0.11043398626497947, 0.14741029939614236, 0.24857601150870323, 0.10748973800218664, 0.18848826235625893, 0.10377316633821465, 0.14505044789984822, 0.1683614548528567, 0.14691319403937086, 0.12794348382158205, 0.1402612353558652, 0.13875754026230425, 0.1537317648762837, 0.10455567942699417, 0.1580910215852782, 0.12326266936725006, 0.1769603489083238, 0.13821880042087287, 0.1188120617007371, 0.14841593918390572, 0.15126324811717495, 0.14435904828133062, 0.08276791573734954, 0.10884110728511587, 0.14794966264162213, 0.24547607550630346, 0.11289113332168199, 0.17135903384769335, 0.1237419928656891, 0.14900205773301423, 0.15853924909606576, 0.1810518090496771, 0.10090360039612278, 0.1679915387649089, 0.08095031444099732, 0.08052629578742199, 0.1472171925706789, 0.1255589336506091, 0.15182777016889304, 0.1377324413624592, 0.10618470099871047, 0.1438979964586906, 0.09949973158654757, 0.11748299395549111, 0.10875530759221874, 0.12486195308156312, 0.10386590511188842, 0.19026199530344456, 0.12703444197541103], [0.026659645918698516, 0.024238433652499225, 0.029346116607484873, 0.046476237548631616, 0.0273404717881931, 0.026063860896101687, 0.042210150058963336, 0.05663104420818854, 0.04194422370346729, 0.02231646969448775, 0.057481448966427706, 0.03988149845099542, 0.02992447785800323, 0.023417301053996198, 0.00913323574422975, 0.03599313444283325, 0.030158759036567062, 0.01205611479235813, 0.05164147034520283, 0.03417945910769049, 0.01633860189031111, 0.0504583496513078, 0.02354308951908024, 0.0977976233116351, 0.05601729921181686, 0.03268675151048228, 0.04014699436083902, 0.06770560561562888, 0.062215230500441976, 0.043513795535545796, 0.04675082476751413, 0.049190594436367974, 0.03647189761977643, 0.02646899189130636, 0.028641692297242116, 0.021517970744753256, 0.030459848348982632, 0.031124949964578263, 0.08096064513665624, 0.09808352086110972, 0.009977038171200547, 0.06961081002373248, 0.21707911568228155, 3.9336619712412357, 46.623255014419556, 90.64459964632988, 78.99139255285263, 80.01814305782318, 75.88169261813164, 77.9418432712555, 68.14833998680115, 76.07548981904984, 54.28190365433693, 26.824996881186962, 32.53833420574665, 27.814971059560776, 33.54250252246857, 54.54043038189411, 68.2830199599266, 42.2173648327589, 47.98241168260574, 63.42728711664677, 29.14417013525963, 6.748474454507232, 0.08818842878099531, 0.13158156594727188, 0.21193846652749926, 0.3680013766279444, 0.21230634913081303, 0.18756028090137988, 0.2641205914551392, 0.3973715443862602, 0.35349883139133453, 0.30028286506421864, 0.0997789423854556, 0.08959901402704418, 0.025526471763441805, 0.2591606107307598, 0.07042967350571416, 0.1619373948778957, 0.032456310946145095, 0.0965147691022139, 0.11704252188792452, 0.3230782871833071, 0.2347930081305094, 0.0602745217474876, 0.11726616809028201, 0.6628470600116998, 0.19603462773375213, 0.17119687458034605, 0.1907940409728326, 0.0255443334026495, 0.16600236034719273, 0.06872324593132362, 0.0667394555057399, 0.10061677516205236, 0.14446668938035145, 0.16646513395244256, 0.5038594943471253, 0.594498049467802, 0.2132054907269776, 0.39662708120886236, 0.13736199092818424, 0.1901365871890448, 0.4417268018005416, 0.14717995160026476, 1.1473814444616437, 19.324928931891918, 59.60783086717129, 93.53293105959892, 104.61626753211021, 73.27535167336464, 61.172294318675995, 34.05905060470104, 12.94301463291049, 25.88935598731041, 43.16854499280453, 38.75688672065735, 52.78993271291256, 65.73104649782181, 73.11589702963829, 79.23983082175255, 81.6841484606266, 89.29283738136292, 38.3531241863966, 3.5038869827985764, 0.27878442022483796, 0.10315109073417261, 0.069564396108035, 0.09960007737390697, 0.08241869814810343, 0.016939247980189975, 0.024461703214910813, 0.004895248284810805, 0.005307911151248845, 0.029953529228805564, 0.014983037617639638, 0.02618406098918058, 0.012676375845330767, 0.013073161389911547, 0.07518089551012963, 0.024151943762262817, 0.05638798713334836, 0.03951009064621758, 0.013243864632386249, 0.04108627501409501, 0.03966895477788057, 0.02595111382106552, 0.057917594313039444, 0.02849023851013044, 0.023501968971686438, 0.03575609989638906, 0.039313978122663684, 0.015548179362667724, 0.026904816259047948, 0.017056368160410784, 0.0048669562238501385, 0.05898500676266849, 0.040104614017764106, 0.05713721489883028, 0.041906878832378425, 0.03522990235069301, 0.021766818426840473, 0.055283200126723386, 0.05557024429435842, 0.03504723383230157, 0.027741496851376723, 0.01884764733404154, 0.03823226819804404, 0.07253012954606675, 0.03328106708067935, 0.04181502321443986, 0.06599545988137834, 0.018725645677477587, 0.0609665855881758, 0.012702477179118432, 0.030624514220107812, 0.07767368049826473, 0.027320593362674117, 0.049086222497862764, 0.04711416542704683, 0.07610980464960448, 0.017539448781462852, 0.02800824699079385, 0.07491002645110711, 0.07406091302982531, 0.010010346686613047, 0.015653863047191408, 0.010964229095407063, 0.052204289168003015, 0.023962427076185122, 0.02225663403805811, 0.024591736764705274, 0.014520192580675939, 0.026394747437734623, 0.044538074362208135, 0.01993824633245822, 0.06347801332594827, 0.06503989279735833, 0.03789041642448865, 0.025585066177882254, 0.03613032786233816, 0.038576743463636376, 0.03634649692685343, 0.005298199221215327, 0.04642844323825557, 0.008876846914063208, 0.06865119081339799, 0.0659572689619381, 0.07862180384108797, 0.060445750059443526, 0.07263704334036447, 0.03639099610154517, 0.04639581842639018, 0.14168761350447312, 0.01544958040540223, 0.05280567369482014, 0.079837768280413, 0.12006662524072453, 1.3038418488577008, 25.649417862296104, 84.57920551300049, 90.38163855671883, 88.94324854016304, 83.67680713534355, 89.91927176713943, 91.49947017431259, 100.44650048017502, 64.95398059487343, 36.28866456449032, 64.10898953676224, 34.286251813173294, 22.179031781852245, 25.079212859272957, 20.787466652691364, 41.672310680150986, 52.300458177924156, 64.00738298892975, 37.30552799999714, 10.346321370452642, 1.1238755495287478, 0.11800861262599938, 0.03146840477711521, 0.34088659565895796, 0.5087437760084867, 0.11856060722493567, 0.14166586857754737, 0.4877005348680541, 0.7285863230936229, 0.8640842023305595, 0.5661285936366767, 0.9018269833177328, 0.779020719928667, 0.7900802639778703, 0.5662061925977468, 0.4697094205766916, 1.1123740416951478, 0.9037855407223105, 0.55509012658149, 1.7454915563575923, 1.2236508331261575, 1.2517054402269423, 2.426019483245909, 2.9874602565541863, 2.166092530824244, 2.1030356269329786, 1.7824499169364572, 1.5761999529786408, 0.8459769270848483, 0.6755994725972414, 0.7667815173044801, 0.5843352572992444, 0.6281904259230942, 0.8860591950360686, 0.7127748371567577, 0.5199974065180868, 0.16927208489505574, 0.2837566315429285, 0.5685837368946522, 0.02381506437814096, 0.532420661766082, 0.14599437068682164, 1.2394823273643851, 22.104814164340496, 63.43585945665836, 78.33756163716316, 64.09347876906395, 35.14646865427494, 35.70492468774319, 29.335392974317074, 23.36131364107132, 46.35080963373184, 74.14697170257568, 68.78049686551094, 76.63733527064323, 89.87482935190201, 82.94073343276978, 92.19682395458221, 92.54151105880737, 97.18347877264023, 36.823531463742256, 1.5055611496791244, 0.18305398989468813, 0.07510797207942232, 0.024230158705904614, 0.05781906678748783, 0.05826815890031867, 0.08239882343332283, 0.05251992086414248, 0.06247059238376096, 0.025720645426190458, 0.024100794944388326, 0.13602054415969178, 0.008098497273749672, 0.05104314717755187, 0.019432346525718458, 0.061359942410490476, 0.021088352586957626, 0.02114474838890601, 0.015401263808598742, 0.04982935352018103, 0.06124981140601449, 0.027984132757410407, 0.05794953634904232, 0.04034845776914153, 0.018017495785898063, 0.007916165504866512, 0.07906315906438977, 0.03494558928650804, 0.03663542614958715, 0.00419963187596295, 0.012443437026377069, 0.06715470197377726, 0.024473833618685603, 0.10755289476946928, 0.09556840464938432, 0.00377199896320235, 0.009354196299682371, 0.0357588124461472, 0.029677431739401072, 0.0979615340474993, 0.015764374402351677, 0.06348720853566192, 0.05404583214840386, 0.058437491024960764, 0.09532095034956001, 0.016244761027337518, 0.05394380168581847, 0.061095036508049816, 0.015290660612663487, 0.016150287483469583, 0.028479273278207984, 0.1012279411952477, 0.17103725345805287, 0.12160241822130047, 0.09733965882332996, 0.1598904179991223, 0.22961256501730531, 0.0862094400508795, 0.15552108292467892, 0.16970198135823011, 0.2251181038445793, 0.1675906009040773, 0.13821292261127383, 0.10329500801162794, 0.19362922321306542, 0.1646350571536459, 0.10312458864063956, 0.09053148547536694, 0.1085905211220961, 0.11314021292491816, 0.12616584717761725, 0.15133526612771675, 0.16586865502176806, 0.11432097729993984, 0.21942924504401162, 0.1377115276409313, 0.15422659926116467, 0.1815225978498347, 0.1398901763604954, 0.1113524533866439, 0.13290016941027716, 0.23348880233243108, 0.13900733232731, 0.2109653624938801, 0.10608569107716903, 0.1760945891146548, 0.11973815810051747, 0.16904492833418772, 0.1492536161094904, 0.2775673574069515, 0.32079576747491956, 0.13126403064234182, 0.17569235991686583, 0.4869593074545264, 10.931488070636988, 68.21243494749069, 118.79601985216141, 102.90703564882278, 102.17431336641312, 96.53834939002991, 101.24464005231857, 94.18781071901321, 100.23804366588593, 75.88328093290329, 45.04238024353981, 56.329321190714836, 45.06220757961273, 47.708837762475014, 74.93403106927872, 102.11545452475548, 58.00532005727291, 76.08100712299347, 95.73710158467293, 47.838881984353065, 11.583218649029732, 1.4896548469550908, 0.273025591741316, 0.27523211552761495, 0.6289786461275071, 1.126194375101477, 0.32051683869212866, 0.2614101493963972, 0.9057743183802813, 0.598118364578113, 0.5720790149644017, 0.3205818508286029, 0.4668834706535563, 0.4569931357400492, 0.5054001335520297, 0.1956351741682738, 0.30256559257395566, 0.4309262672904879, 0.4325363121461123, 0.20929091406287625, 0.43557677243370563, 0.3397031669737771, 0.356403716141358, 0.6854630308225751, 1.1094024823978543, 0.9883675770834088, 0.9122839628253132, 1.2063207942992449, 0.5770349584054202, 0.2524219098268077, 0.3058533067815006, 0.17464374977862462, 0.3086176287615672, 0.3289488237351179, 0.3200931317405775, 0.7312088354956359, 0.7967946224380285, 0.415833774022758, 0.8083532459568232, 0.5857054400257766, 0.1385333522921428, 0.42187013605143875, 0.20550423912936822, 2.080328045412898, 31.653697974979877, 85.45975506305695, 133.8778817653656, 141.19220048189163, 99.52047497034073, 86.1086842417717, 52.05607049167156, 22.8307918086648, 36.09014041721821, 61.61772921681404, 59.670231118798256, 74.01084780693054, 89.32797029614449, 96.58643200993538, 101.99548736214638, 99.81222331523895, 114.65641558170319, 66.4384925365448, 7.726804157719016, 0.4608543519861996, 0.466361889266409, 0.15005776280304417, 0.1512337996973656, 0.13474514853442088, 0.1836190017638728, 0.14882397197652608, 0.12659773259656504, 0.09904579696012661, 0.15090023400261998, 0.17665096238488331, 0.11900448575033806, 0.12098410530597903, 0.07137546650483273, 0.13395683927228674, 0.12687271315371618, 0.112295559811173, 0.14390307274879888, 0.15022208914160728, 0.2509083738550544, 0.09503935725660995, 0.11420526163419709, 0.18365300697041675, 0.1105577839189209, 0.15997612121282145, 0.14973158889915794, 0.20386185147799551, 0.14707878202898428, 0.16233702655881643, 0.12525374768301845, 0.13863468513591215, 0.13505737006198615, 0.16348593053407967, 0.2761206147260964, 0.10179129807511345, 0.19834407255984843, 0.08864993331371807, 0.17417766619473696, 0.26622116623912007, 0.14632437407271937, 0.15286616835510358, 0.16431238618679345, 0.17705700622173026, 0.18251823348691687, 0.11143731055199169, 0.1795496279373765, 0.15538301377091557, 0.0629859916807618, 0.12063442016369663, 0.06071659685403574], [0.10406010289443657, 0.033022766292560846, 0.02385416071774671, 0.004141527278989088, 0.002360227672397741, 0.03881348486174829, 0.037888323568040505, 0.031524525984423235, 0.0820415312773548, 0.08845680422382429, 0.03395366438780911, 0.06147392145066988, 0.04342267464380711, 0.06863432921818458, 0.03422980269533582, 0.031011299324745778, 0.03618353985075373, 0.02763892276561819, 0.03459712868789211, 0.005140795728948433, 0.06094891134125646, 0.044426403401303105, 0.05930522493144963, 0.02782334831863409, 0.033079729837481864, 0.013197561111155665, 0.020823814047616906, 0.036534642495098524, 0.041457820116193034, 0.04730514599941671, 0.026996159795089625, 0.08281926493509673, 0.05866189421794843, 0.06587984811631031, 0.04710010915005114, 0.021043794040451758, 0.0329258380952524, 0.09034714341396466, 0.06388860652805306, 0.04475783913221676, 0.03319678136904258, 0.08632600918645039, 21.50985538959503, 75.06552681326866, 94.98769819736481, 74.84836846590042, 66.41421183943748, 75.23228466510773, 81.56060948967934, 60.95831640064716, 17.708231583237648, 9.51143017038703, 22.50234503298998, 42.53676049411297, 21.211782284080982, 55.65508536994457, 100.59726119041443, 89.252088367939, 76.29474565386772, 62.73070849478245, 29.69764843583107, 5.1454340480268, 0.07362602191278711, 0.3231669886736199, 0.04508419115154538, 0.21339939907193184, 0.10449086767039262, 0.1031675589911174, 0.1571758941281587, 0.2729831705801189, 0.09383006472489797, 0.1293748788884841, 0.08015220882953145, 0.4483249696204439, 0.10302974958904088, 0.29774754017125815, 0.849423639010638, 0.6030123238451779, 1.0937868640758097, 1.623442699201405, 1.2543218373320997, 0.15077430638484657, 1.9295290997251868, 7.379849050194025, 3.607702637091279, 2.940622544847429, 3.468567878007889, 4.37566707842052, 3.3786046179011464, 1.3048571068793535, 2.286245170980692, 0.5728984053712338, 1.0690212179906666, 0.37299926625564694, 0.26414674473926425, 0.2478672011056915, 0.16870027495315298, 0.3197365446249023, 0.4233678197488189, 0.30951556807849556, 0.20142367371590808, 0.1129178432165645, 0.10470978639204986, 0.12208914835355245, 0.567687638103962, 0.08468555854051374, 0.0816564827982802, 0.29290137521456927, 0.5205123382620513, 10.667547583580017, 52.470358461141586, 95.01489713788033, 88.62297892570496, 95.23466974496841, 106.97492256760597, 48.733042404055595, 12.345528993755579, 17.167701087892056, 13.809540085494518, 19.53472137451172, 38.803643211722374, 50.61546519398689, 82.78635531663895, 79.7450441122055, 89.03853982686996, 59.41492661833763, 18.723065927624702, 2.5003406452015042, 0.39721147797536105, 0.207158159755636, 0.010265065684507135, 0.028769727614417206, 0.004471544116313453, 0.0482468831614824, 0.024806824148981832, 0.0055726356913510244, 0.11946414233534597, 0.03168154216837138, 0.07451927085639909, 0.05371018844016362, 0.046599359848187305, 0.07340951517107897, 0.05719988555938471, 0.012046013234794373, 0.06574750834261067, 0.015319018075388158, 0.07560095109511167, 0.09303402228397317, 0.054508104803971946, 0.00920098176720785, 0.02052383239060873, 0.04573852049361449, 0.06819838425144553, 0.012389243547659134, 0.03193933458533138, 0.01707585881376872, 0.01434685749700293, 0.07672471110709012, 0.06777222079108469, 0.0485945311083924, 0.012208438747620676, 0.009402240157214692, 0.07904021185822785, 0.04832427061046474, 0.07664008400752209, 0.08687258610734716, 0.014928462860552827, 0.026227081434626598, 0.04534694853646215, 0.045585511907120235, 0.012366211922199, 0.005995224319121917, 0.0446360378555255, 0.015405389221996302, 0.08555511813028716, 0.0508827505109366, 0.020479158811212983, 0.026225988622172736, 0.04025695838208776, 0.10108668822795153, 0.039339122085948475, 0.023826753204048146, 0.07063652490614913, 0.07508452021284029, 0.047159558889688924, 0.07841510087018833, 0.044569986712303944, 0.07094398184563033, 0.041361745388712734, 0.05521502644114662, 0.04501434763369616, 0.03703420807141811, 0.03587426464946475, 0.09783119065104984, 0.015942616009851918, 0.011314560833852738, 0.06113430354162119, 0.06154437352961395, 0.01690547840553336, 0.0965881378215272, 0.045857464501750655, 0.021437314135255292, 0.035066503696725704, 0.02886297290388029, 0.04220397910103202, 0.03299445706943516, 0.007412978247884894, 0.03530629532178864, 0.0907685497077182, 0.041246749606216326, 0.03632684485637583, 0.047862023930065334, 0.028528377479233313, 0.0372420279745711, 0.06394390395144, 0.09441584930755198, 0.19441487558651716, 0.15047526540001854, 7.367145381867886, 57.26550355553627, 105.34698352217674, 90.50298124551773, 85.64473673701286, 89.06478121876717, 94.31766495108604, 72.65171393752098, 42.399751245975494, 36.25317446887493, 44.942080825567245, 36.931191086769104, 23.891083113849163, 39.394629299640656, 46.70397788286209, 51.68467082083225, 66.05584546923637, 66.66075021028519, 36.66935093700886, 8.564233146607876, 0.22415469225961715, 0.31550125626381487, 0.22774692450184375, 0.4763933509821072, 0.23970924667082727, 0.26098145521245897, 0.6174655607901514, 0.36326009198091924, 0.2685057045891881, 0.14456931356107816, 0.1457320956978947, 1.0834953538142145, 0.6446716852951795, 1.4327654871158302, 2.6667387038469315, 2.335520926862955, 4.751493511721492, 6.267182305455208, 5.663839755579829, 4.485328244045377, 4.636967657133937, 8.061520121991634, 8.760520163923502, 9.654942769557238, 10.006259568035603, 8.48253658041358, 7.887681350111961, 4.851857526227832, 4.647012418136001, 5.167402094230056, 4.211586657911539, 4.352420400828123, 3.834804338403046, 1.9497314281761646, 1.3523606141097844, 0.9183934412430972, 0.915918170940131, 0.7809811178594828, 0.4303157766116783, 0.5737415445037186, 0.842704352689907, 0.23957862867973745, 0.420330268680118, 0.11007030421751551, 0.05707731987058651, 0.20732261968078092, 0.3988962422590703, 11.12793942913413, 49.80863928794861, 74.04069900512695, 60.0627576559782, 63.541755974292755, 56.043432131409645, 40.27324475347996, 21.102192364633083, 26.206015795469284, 29.170289933681488, 38.97567518055439, 61.10794097185135, 65.27700126171112, 93.56209069490433, 89.28179517388344, 101.22092172503471, 62.33978547155857, 15.543141011148691, 1.4747643959708512, 0.24555328855058178, 0.12227609535329975, 0.04587839306623209, 0.025011187499330845, 0.009065370977623388, 0.039193731645355, 0.05375955981435254, 0.01761715906468453, 0.06630155869061127, 0.06368318005115725, 0.0879472604719922, 0.06573256148840301, 0.030951576845836826, 0.026066300706588663, 0.04808814890566282, 0.025522009600535966, 0.006058971557649784, 0.046450781883322634, 0.04622636013664305, 0.03958110304665752, 0.03381336879101582, 0.030382726217794698, 0.021518156281672418, 0.01526402864328702, 0.04026360060379375, 0.016848212435434107, 0.08446678082691506, 0.04682178892835509, 0.07127509845304303, 0.043403742456575856, 0.06924426328623667, 0.037854804468224756, 0.025714906769280788, 0.0072594237190060085, 0.05991259116854053, 0.0861622543015983, 0.04264792070898693, 0.06750600499799475, 0.029060052074783016, 0.010667326423572376, 0.034691270120674744, 0.1022849821310956, 0.06967996334424242, 0.0391448871960165, 0.04125297251448501, 0.006806136616432923, 0.14779002667637542, 0.008577875505579868, 0.15245921909809113, 0.18779546750010923, 0.12116834346670657, 0.13633061345899478, 0.10496472154045478, 0.16376903018681332, 0.16509634646354243, 0.10822972602909431, 0.1349316057167016, 0.1734225160907954, 0.21921725798165426, 0.1755380822578445, 0.16637472552247345, 0.19713566318387166, 0.12350016404525377, 0.1003204875451047, 0.14006262179464102, 0.2500773762585595, 0.17054854921298102, 0.08570780017180368, 0.20045417651999742, 0.2019463831675239, 0.15009559749159962, 0.19863726542098448, 0.1008199380885344, 0.04337710306572262, 0.1597466491512023, 0.10303989474778064, 0.2028195050661452, 0.16934086714172736, 0.16526788647752255, 0.20981466252123937, 0.14244332764064893, 0.14840744901448488, 0.15749834245070815, 0.20371544058434665, 0.16289020859403536, 0.17594547680346295, 0.29618000553455204, 0.18682061199797317, 0.41963644966017455, 0.6639058969449252, 44.9398959428072, 105.02054303884506, 121.6208566725254, 97.01387867331505, 91.03794693946838, 100.09768679738045, 111.60539969801903, 84.12208244204521, 32.89754793047905, 20.23775205016136, 42.12021924555302, 67.0213432610035, 39.16950657963753, 79.26879286766052, 147.90659219026566, 136.03545159101486, 110.40577366948128, 95.84531217813492, 49.70559261739254, 9.83007537201047, 0.48535077658016235, 0.5993107880931348, 0.4713758686557412, 0.664650360122323, 0.19676718686241657, 0.1688154711155221, 0.547645672922954, 0.49830460804514587, 0.12689379014773294, 0.21378852194175124, 0.06842266127932817, 0.6101868732366711, 0.25420229241717607, 0.9233360853977501, 2.406932869926095, 1.6869345610029995, 4.051719736307859, 4.441727958619595, 4.599710181355476, 4.6551724802702665, 8.80291448906064, 15.71101600304246, 9.7083337046206, 9.496429525315762, 9.520451836287975, 7.785209873691201, 8.15567621961236, 4.193891482427716, 4.364606821909547, 2.8073665453121066, 4.662828594446182, 3.27442679554224, 1.4918906707316637, 1.1264784098602831, 0.608938877703622, 0.39733244804665446, 0.420313585200347, 0.28142002411186695, 0.18887711805291474, 0.2253738627769053, 0.44640841777436435, 0.34819847205653787, 0.7440445467364043, 0.20875135785900056, 0.1375943425227888, 0.21285573136992753, 2.327847476117313, 19.96361006051302, 81.33544117212296, 144.08807069063187, 128.00230264663696, 120.88482096791267, 130.6511253118515, 71.85160607099533, 19.491559490561485, 25.136460587382317, 25.554234869778156, 32.262621000409126, 56.90264202654362, 71.25117748975754, 109.35108706355095, 98.20383042097092, 113.02156090736389, 91.16595447063446, 36.053924560546875, 6.593372477218509, 0.6152116879820824, 0.39289787819143385, 0.10721821585320868, 0.1508842036128044, 0.1336386805633083, 0.13964933459647, 0.20379096153192222, 0.2081558437203057, 0.2909499127417803, 0.09951271174941212, 0.3202756406972185, 0.2758064487716183, 0.2080668750568293, 0.21600319450953975, 0.19027245958568528, 0.15389349369797856, 0.1606489671394229, 0.1247111486736685, 0.18739329767413437, 0.12702860869467258, 0.19296362064778805, 0.1541991249541752, 0.14888459059875458, 0.12085706446669064, 0.2084465281222947, 0.18696911574807018, 0.11302045997581445, 0.1640894598676823, 0.17041316663380712, 0.11882568011060357, 0.1560048889950849, 0.19932802679250017, 0.213830097054597, 0.11554699041880667, 0.16446710913442075, 0.1462922093924135, 0.17226403841050342, 0.15957594034262002, 0.1969158390420489, 0.09954347377060913, 0.1152833276137244, 0.12990318413358182, 0.16039025445934385, 0.07691090111620724, 0.2430671828915365, 0.14175875578075647, 0.3003548237029463, 0.11216213650186546], [0.05631400985294022, 0.0338487840781454, 0.013016702505410649, 0.07395287859253585, 0.033672683566692285, 0.02080369999021059, 0.03634091968706343, 0.09082709031645209, 0.06688367706374265, 0.03458617829892319, 0.047458481130888686, 0.03210682247299701, 0.023084902386472095, 0.029915393970441073, 0.04560963170661125, 0.0599936002981849, 0.011648425243038218, 0.06375509416102432, 0.042580114386510104, 0.025330893586215097, 0.05120971480209846, 0.03779833816224709, 0.04178999057330657, 0.038171601336216554, 0.012029500448988983, 0.027901227440452203, 0.0689879477431532, 0.0122580309107434, 0.03759057020943146, 0.042833234983845614, 0.056914674496511, 0.07448167365510017, 0.04946394597936887, 0.1004926509631332, 0.051490888581611216, 0.018889218736148905, 0.010311044516129186, 0.07832876683096401, 0.034901427789009176, 0.14558051945641637, 0.9016615734435618, 43.78428295254707, 100.56012958288193, 100.4415911436081, 77.53791734576225, 87.50217586755753, 62.80027896165848, 32.56283529102802, 30.92132907360792, 37.05144703388214, 26.14352624863386, 38.23447175323963, 33.80218058824539, 38.14378581941128, 72.21852198243141, 46.935666650533676, 47.28693500161171, 39.360491931438446, 20.986959747970104, 4.30976721458137, 0.576936163706705, 0.14609591133194044, 0.09877678327029571, 0.19069258938543499, 0.07268620320246555, 0.04508630256168544, 0.13955533417174593, 0.03603724770073313, 0.4469138797139749, 0.5791090533602983, 0.8832674729637802, 1.471667205914855, 1.915972970891744, 1.7132429243065417, 0.9604895417578518, 3.420864762738347, 2.2917346889153123, 1.967462939210236, 5.305478135123849, 6.093967650085688, 3.4492708509787917, 4.610601821914315, 3.9771404257044196, 9.828944932669401, 8.589218705892563, 10.846708919852972, 17.130563780665398, 13.245720639824867, 6.517491023987532, 5.879745120182633, 4.252631580457091, 8.642866127192974, 7.476349147036672, 3.457913724705577, 6.223235763609409, 1.5154982102103531, 3.4056178433820605, 3.099803365767002, 2.0299398992210627, 2.2073443047702312, 0.9094898065086454, 0.8160405897069722, 0.34090746485162526, 0.13576135650509968, 0.05105207150336355, 0.0662301566626411, 0.06736902680131607, 0.2218152052955702, 0.037524151703109965, 0.5078099167440087, 0.5300704285036772, 12.46508102864027, 44.19841133058071, 63.34501773118973, 73.87800693511963, 92.82028689980507, 107.3187281191349, 56.85791462659836, 68.88785630464554, 62.92343035340309, 17.07665227353573, 28.579501435160637, 65.58866813778877, 65.46013623476028, 65.58847054839134, 81.69052451848984, 93.77579882740974, 59.91640850901604, 20.75311079621315, 3.4321126341819763, 0.25246453878935426, 0.07685744421905838, 0.01360636295430595, 0.0752676822594367, 0.04445938815479167, 0.037209028378129005, 0.0582347103045322, 0.06342904642224312, 0.02576267139374977, 0.043509364913916215, 0.008799183015071321, 0.031163111198111437, 0.0260473035814357, 0.037758017278974876, 0.05606750550214201, 0.06070874493161682, 0.02746298923739232, 0.02351166698645102, 0.042362668827991, 0.027581111316976603, 0.01206153061502846, 0.017945186482393183, 0.04041591899294872, 0.026360784904682077, 0.0789451204764191, 0.051668039232026786, 0.04741025637486018, 0.026272406248608604, 0.02864837533707032, 0.03298116149380803, 0.01692247729806695, 0.025705559419293422, 0.06324310132185929, 0.01743887292832369, 0.05073559004813433, 0.009077821432583733, 0.09964324068278074, 0.009371944761369377, 0.0262964648209163, 0.015820336047909223, 0.03759625877137296, 0.006500873187178513, 0.049028294160962105, 0.018851096465368755, 0.03541355050401762, 0.0982381399080623, 0.05304863057972398, 0.034832526798709296, 0.059280077257426456, 0.008639465413580183, 0.0422801605600398, 0.03640309310867451, 0.06370142204104923, 0.07822096245945431, 0.05582408848567866, 0.05554748262511566, 0.05695548148651142, 0.013035827651037835, 0.01828495838708477, 0.026736072286439594, 0.06509633312816732, 0.040388889974565245, 0.029299702691787388, 0.015847995891817845, 0.04099483499885537, 0.03453648409049492, 0.06284433053224348, 0.009488970317761414, 0.05354346867534332, 0.01056395638443064, 0.05098730056488421, 0.02407402753306087, 0.010409927344880998, 0.005837001217514626, 0.13209171826019883, 0.07554989875643514, 0.045899982142145745, 0.021781602008559275, 0.03902177973941434, 0.05251516369753517, 0.04569216223899275, 0.06866610798169859, 0.06379029422532767, 0.010587920332909562, 0.05003932194085792, 0.07022788355243392, 1.0813541687093675, 24.774947986006737, 99.91153478622437, 111.23033702373505, 89.76194500923157, 84.29025381803513, 74.54750820994377, 61.08386166393757, 63.566675037145615, 62.3099684715271, 24.64681316167116, 21.06827348470688, 32.422907799482346, 45.744400173425674, 42.99223445355892, 36.214435547590256, 45.88618576526642, 51.597746685147285, 30.542951077222824, 7.043480174615979, 0.4581431677797809, 0.21003895439207554, 0.08825651340885088, 0.20547936233924702, 0.12886178767075762, 0.09165819181362167, 0.26014086906798184, 0.5735493579413742, 2.0345813501626253, 2.080064434558153, 1.352241039276123, 2.1294320980086923, 2.570873172953725, 4.011820452287793, 3.8416964560747147, 3.179121734574437, 2.0911109168082476, 4.739246293902397, 9.38721863552928, 10.654326193034649, 11.460695173591375, 10.929932054132223, 19.235871210694313, 9.727733563631773, 11.161183845251799, 17.816628366708755, 18.145145438611507, 18.447301425039768, 12.567918710410595, 9.528202470391989, 13.091911543160677, 12.996388468891382, 7.665105443447828, 6.8885396886616945, 8.037906289100647, 5.6827988382428885, 3.171272068284452, 3.8727310532703996, 1.8717978475615382, 2.5358155416324735, 3.132851617410779, 3.3281174395233393, 1.4040484093129635, 0.4050708218710497, 0.2041789414943196, 0.4999331769067794, 0.3350881958613172, 0.16519301861990243, 0.05771864678536076, 0.3602353058522567, 0.3201801411341876, 13.150749485939741, 42.45903566479683, 57.089132219552994, 66.30885109305382, 69.46283385157585, 52.911773175001144, 39.12705525755882, 30.15106860548258, 42.079751417040825, 38.10465171933174, 46.101197227835655, 81.09407812356949, 78.87506559491158, 75.64681202173233, 94.9273194372654, 104.45060402154922, 64.87329572439194, 17.315469458699226, 2.0580752519890666, 0.09434995401534252, 0.07824711574357934, 0.058372838830109686, 0.038942922838032246, 0.029014228166488465, 0.036932760194758885, 0.056678972105146386, 0.03377298853592947, 0.022968849043536466, 0.031691097319708206, 0.03443498797423672, 0.043462509420351125, 0.01663426053710282, 0.03520036116242409, 0.05697750842955429, 0.05739280313719064, 0.03129193319182377, 0.01924187617987627, 0.030509538846672513, 0.05670729988196399, 0.017824661699705757, 0.043483957488206215, 0.04108919536520261, 0.05341062795196194, 0.03874799775076099, 0.005873917962162523, 0.022485757290269248, 0.0813639652915299, 0.03494227188639343, 0.013640402485179948, 0.02547786480135983, 0.04629176932212431, 0.05248482098977547, 0.049555775622138754, 0.023590475648234133, 0.038793910716776736, 0.02986691688420251, 0.03900824667653069, 0.06171566492412239, 0.03861896424496081, 0.0036608122536563314, 0.016376640669477638, 0.038096540520200506, 0.020794217198272236, 0.02154443758627167, 0.029106770271027926, 0.15614736650604755, 0.10194637725362554, 0.18609376740641892, 0.1027426720247604, 0.06927488429937512, 0.15100864693522453, 0.2468731685075909, 0.16039310430642217, 0.20113382051931694, 0.1037378326873295, 0.10936906372080557, 0.0698233611183241, 0.22208608919754624, 0.16943123104283586, 0.09084577017347328, 0.1507201444474049, 0.10992735915351659, 0.15735316352220252, 0.18964436516398564, 0.120781959121814, 0.12802391778677702, 0.11099712050054222, 0.14737568562850356, 0.10111355397384614, 0.1144526491407305, 0.09753891805303283, 0.11505850139656104, 0.19254829996498302, 0.29143664287403226, 0.2357962285168469, 0.16484459512867033, 0.15984654222847894, 0.12199211996630765, 0.3156319633126259, 0.2193343243561685, 0.10533775464864448, 0.0959918815351557, 0.2104692516149953, 0.20624438300728798, 0.4290288331685588, 5.846252292394638, 75.0181357562542, 130.48077285289764, 118.39937433600426, 100.06193831562996, 107.51214534044266, 80.52765011787415, 53.85732963681221, 49.55319419503212, 57.08108425140381, 44.18066628277302, 58.02231654524803, 57.13271588087082, 55.48246443271637, 103.24989885091782, 67.69867211580276, 64.78593081235886, 59.12759743630886, 36.16605654358864, 6.940037375316024, 1.3791031041182578, 0.5116385081782937, 0.17310029041254893, 0.38709909247700125, 0.30916853982489556, 0.14696898870170116, 0.4039742541499436, 0.5163554800674319, 2.865375420078635, 2.378262458369136, 3.22745727840811, 4.375694151967764, 5.879993531852961, 8.148992378264666, 8.55524092912674, 12.255758810788393, 8.612076379358768, 11.473662927746773, 14.227700997143984, 20.318311527371407, 15.478987153619528, 13.090422973036766, 21.069130338728428, 25.521495826542377, 22.956696152687073, 28.728662431240082, 38.368874341249466, 37.5414003431797, 23.54375135153532, 20.417668595910072, 23.490227423608303, 22.971844039857388, 17.269685715436935, 16.805656515061855, 20.693148113787174, 12.8017040155828, 12.487230990082026, 9.016596972942352, 5.539034027606249, 5.300946878269315, 2.690937942825258, 2.5332380924373865, 1.0118762031197548, 0.2201097647775896, 0.12182962673250586, 0.2854109974578023, 0.3605031914776191, 0.27772314904723316, 0.1217201525287237, 0.7040655857417732, 1.7289958102628589, 19.595516212284565, 70.05215182900429, 93.7683892250061, 109.1649654507637, 119.2005917429924, 134.11479145288467, 79.28142338991165, 82.05456018447876, 77.86754965782166, 29.515370316803455, 43.73124539852142, 85.46830460429192, 86.43729820847511, 88.24277132749557, 102.2575668990612, 118.04016441106796, 91.39488458633423, 40.42220436036587, 8.42823464423418, 0.41510590526741, 0.12967794231371954, 0.18788157147355378, 0.1613564119907096, 0.20972524856915697, 0.14699178747832775, 0.11645775404758751, 0.13612836337415501, 0.096509967406746, 0.16356450913008302, 0.08778882678598166, 0.11075967777287588, 0.11538463077158667, 0.14935450366465375, 0.1568112472887151, 0.1238549996924121, 0.14873089181492105, 0.09344367295852862, 0.11421045666793361, 0.1104238411062397, 0.1298559835413471, 0.0966341732419096, 0.12451525137294084, 0.1150267968478147, 0.2359969200915657, 0.17715393070830032, 0.12974544806638733, 0.09488386247539893, 0.07996513566467911, 0.08098002261249349, 0.07269500507391058, 0.1257495320169255, 0.12115077683120035, 0.09699316491605714, 0.1356868151924573, 0.12868512683780864, 0.19162138720275834, 0.1680672526708804, 0.10494662798009813, 0.1422129204729572, 0.13437615270959213, 0.10404879998532124, 0.10553334766882472, 0.12764030165271834, 0.1283579584560357, 0.14883275900501758], [0.048905457588261925, 0.08325282018631697, 0.035370301848161034, 0.06256396198295988, 0.02186747035011649, 0.11697097885189578, 0.02056670255115023, 0.04363001215097029, 0.027655789926939178, 0.0482562008255627, 0.04338460246799514, 0.026344774923927616, 0.05212241914705373, 0.05129286873852834, 0.05753209683462046, 0.02694731163501274, 0.06460394783061929, 0.04365176078863442, 0.033827569786808454, 0.03349899503518827, 0.06842058326583356, 0.026791538548422977, 0.09353227054816671, 0.02621273757540621, 0.077292862260947, 0.04694947914686054, 0.009026240313687595, 0.05573044058110099, 0.04744721903989557, 0.023996115014597308, 0.04374337149783969, 0.05301818768202793, 0.07414111692924052, 0.030009578076715115, 0.14113266515778378, 0.0366980263061123, 0.030893533476046287, 0.014387914034159621, 0.22376764740329236, 10.459790881723166, 72.97788083553314, 98.70978087186813, 93.47645848989487, 69.41412806510925, 69.24543991684914, 98.20770621299744, 121.18255779147148, 43.8686878234148, 12.964005656540394, 23.009633012115955, 92.05787301063538, 83.15660744905472, 61.44384294748306, 38.27210113406181, 38.02688889205456, 43.60392563045025, 28.893978260457516, 9.283435754477978, 0.5983434431254864, 0.17461382638430223, 0.07501031286665238, 0.0384402068448253, 0.053808623197255656, 0.16050387726863846, 0.11343851176206954, 0.5820566858164966, 0.30331792251672596, 0.5159157130401582, 1.430698991753161, 1.1890206788666546, 2.297831461764872, 2.840039567090571, 3.6442236648872495, 3.5010098246857524, 3.6859152652323246, 5.569081390276551, 3.2975326431915164, 4.426813758909702, 9.429825749248266, 15.73344049975276, 13.73261321336031, 6.162733035162091, 8.970110267400742, 14.076114781200886, 13.474327772855759, 13.810509983450174, 9.618638567626476, 12.075002510100603, 8.496303241699934, 5.784543128684163, 5.382916079834104, 14.654618538916111, 5.5888959020376205, 9.35275163501501, 12.502870000898838, 7.205092152580619, 8.322280179709196, 5.801020944491029, 3.770118271932006, 3.264172333292663, 7.3858636524528265, 4.249384654685855, 2.7229737862944603, 1.3001597276888788, 0.9183258761186153, 0.37618750298861414, 0.12752664915751666, 0.18289836152689531, 0.08512605287251063, 0.37955542851705104, 0.0314775703009218, 0.2436044829664752, 0.44824333337601274, 18.413880318403244, 55.442558974027634, 65.60005232691765, 93.07934179902077, 70.54569214582443, 115.68660870194435, 126.52644664049149, 38.924666717648506, 23.752914927899837, 25.502759031951427, 41.716574504971504, 50.24658478796482, 62.58461393415928, 80.34329161047935, 88.5240626335144, 88.83265167474747, 70.98233431577682, 17.378872856497765, 1.1773771536536515, 0.045784915855620056, 0.07829672831576318, 0.014367412204592256, 0.07225357563584112, 0.06026824688888155, 0.034791122379829176, 0.033414030258427374, 0.008740203611523611, 0.017204430332640186, 0.03927615827706177, 0.05368211670429446, 0.11098479342763312, 0.030102096061455086, 0.03472079275525175, 0.0037815079622305348, 0.016799763179733418, 0.06452624496887438, 0.09835902834311128, 0.09112294006627053, 0.0494091198197566, 0.04164526435488369, 0.04632392658095341, 0.07126978467567824, 0.03557385069143493, 0.04163801728282124, 0.02867409446480451, 0.0305815809770138, 0.020884566256427206, 0.01805299642001046, 0.02553057398472447, 0.011856835153594147, 0.026038969263026956, 0.034289170798729174, 0.06627560578635894, 0.0359311762440484, 0.03884880366967991, 0.03170438176312018, 0.04418356897076592, 0.01980804208869813, 0.024780741368886083, 0.07764171619783156, 0.06799815280828625, 0.041354242275701836, 0.02774797765596304, 0.03469500312348828, 0.010978264035657048, 0.03609573635912966, 0.011017521792382468, 0.012922053629154107, 0.02711670684220735, 0.040332624048460275, 0.02139132880984107, 0.026049585685541388, 0.01935197378770681, 0.05341020121704787, 0.0659460699534975, 0.05177881219424307, 0.05854876864759717, 0.041147138545056805, 0.042855417777900584, 0.029033152932242956, 0.05777405182016082, 0.08495774862240069, 0.03610173662309535, 0.036240447734599, 0.08955216966569424, 0.04425075931067113, 0.028870069691038225, 0.014847007514617871, 0.04161393087997567, 0.034375642135273665, 0.080868143850239, 0.005299460872265627, 0.06403040868462995, 0.06590862860321067, 0.030938071613491047, 0.12003698386251926, 0.03642569521616679, 0.07520920102251694, 0.06699306963128038, 0.030366740356839728, 0.02102352042129496, 0.11519444058649242, 4.230869673192501, 54.7393649071455, 105.97384348511696, 101.44050434231758, 90.4292879998684, 79.55796495079994, 117.0299582183361, 104.74405467510223, 35.770832151174545, 24.737404100596905, 38.66840086877346, 54.45213831961155, 59.81284886598587, 44.76785637438297, 37.014680206775665, 47.67622411251068, 53.234345465898514, 39.57720950245857, 13.913851138204336, 0.8040547859854996, 0.14317737106466666, 0.053495793108595535, 0.0814159750007093, 0.0848159687302541, 0.5186805396806449, 0.5663343169726431, 1.5810101386159658, 1.6571842948906124, 0.7057412958238274, 1.0846661659888923, 1.562113871332258, 1.591380969621241, 1.2577627901919186, 0.8043588884174824, 3.06194837205112, 2.7344125974923372, 1.6157817165367305, 0.8242350874934345, 0.3704210155410692, 1.2375937099568546, 7.462187306955457, 10.545007959008217, 14.85682848840952, 19.68589436262846, 26.304124630987644, 14.32236721739173, 13.065601754933596, 8.037712499499321, 9.840620756149292, 11.470801681280136, 7.4430781323462725, 7.854584651067853, 2.8790195379406214, 3.461315492168069, 2.2484445618465543, 3.26047180686146, 1.8293764488771558, 3.0710916314274073, 3.8975655706599355, 2.6811503805220127, 3.3077840181067586, 3.2735148444771767, 4.6810823399573565, 1.260980861261487, 0.5523434677161276, 1.8977155443280935, 1.0196045134216547, 0.6333517364691943, 0.24800442421110347, 0.698457146063447, 0.3672207857016474, 0.02852167031960562, 0.3675044939154759, 1.2284769304096699, 19.516976326704025, 51.33084520697594, 61.71275071799755, 78.11673268675804, 51.93055182695389, 95.75042366981506, 107.09257185459137, 36.163909658789635, 30.431218072772026, 48.593969866633415, 60.906532779335976, 62.32175163924694, 76.55450731515884, 90.44071778655052, 100.11783331632614, 96.98872402310371, 74.7056557238102, 14.572832677513361, 0.7997647568117827, 0.051331649665371515, 0.0554957957501756, 0.011010623529728036, 0.10290421530953608, 0.04551999139948748, 0.03885058482410386, 0.013368266208999557, 0.054317031463142484, 0.03790108108660206, 0.08887102652806789, 0.016392771249229554, 0.07400045768008567, 0.021316681741154753, 0.028683219170488883, 0.04037766870169435, 0.05373503183363937, 0.050712705924524926, 0.10061118679004721, 0.014990145537012722, 0.01946027910889825, 0.023896858328953385, 0.017108446518250275, 0.013345832940103719, 0.04750915497425012, 0.0011077726435360091, 0.08738155840546824, 0.06136853276984766, 0.026591234745865222, 0.06536791464895941, 0.02268170654133428, 0.04245096955855843, 0.07666898323805071, 0.03332428233989049, 0.007679263153477223, 0.036907720132148825, 0.015927739659673534, 0.011306872183922678, 0.02464162949763704, 0.030117694150249008, 0.040096750963130035, 0.06846714561106637, 0.08532789477612823, 0.055217579429154284, 0.04348122267401777, 0.06372556410497054, 0.15455603861482814, 0.1673102768836543, 0.10810040679643862, 0.11178572662174702, 0.14358668035129085, 0.18348489567870274, 0.06607763047213666, 0.15591639530612156, 0.07562503378721885, 0.08375803721719421, 0.2117042595637031, 0.11526749018230475, 0.16619873262243345, 0.11155652173329145, 0.1718544916366227, 0.15536699822405353, 0.14015353488503024, 0.12390235613565892, 0.13003138272324577, 0.1311646867543459, 0.1513865336892195, 0.11039728706236929, 0.08913255936931819, 0.14942070323741063, 0.16565185884246603, 0.11394365457817912, 0.19759837741730735, 0.14145330264000222, 0.3322089300490916, 0.19722809025552124, 0.1329883365542628, 0.2545175270643085, 0.16347573342500255, 0.20522536971839145, 0.14631653699325398, 0.17058740806533024, 0.2444808851578273, 0.279674552148208, 22.35119104385376, 109.04521867632866, 120.86850464344025, 110.79593673348427, 94.75996121764183, 89.3128851056099, 117.84812271595001, 132.85748451948166, 63.52805770933628, 27.228786014020443, 38.438820987939835, 130.8213409781456, 125.31396210193634, 85.77640727162361, 59.70584660768509, 58.64447236061096, 68.56409087777138, 49.850372448563576, 18.025467060506344, 1.800509279128164, 0.17492949147708714, 0.16569463623454794, 0.2851620514411479, 0.1965232874499634, 0.28603692480828613, 0.2839798992499709, 1.8362883967347443, 1.7122885817661881, 1.7203302565030754, 5.769048510119319, 7.047072406858206, 10.013031754642725, 14.320144336670637, 18.023905344307423, 17.79141291975975, 14.59585564211011, 14.167364034801722, 11.411421317607164, 17.59746752679348, 25.492748469114304, 35.79101286828518, 34.059138000011444, 21.134232245385647, 21.31110705435276, 27.204296328127384, 30.11933270841837, 32.06872120499611, 28.61634235829115, 32.99225024878979, 26.449894309043884, 23.916636742651463, 23.183211497962475, 38.30326706171036, 23.865856267511845, 26.670525670051575, 37.120823711156845, 27.26387333124876, 23.726432248950005, 25.143721997737885, 17.17333808541298, 21.2084973603487, 22.739146426320076, 19.462272562086582, 9.231142960488796, 6.922772526741028, 3.838791511952877, 1.013899000827223, 0.3249148651957512, 0.2117662734235637, 0.5391560378484428, 0.8004087628796697, 0.16931619815295562, 0.47971369000151753, 2.140713455155492, 31.345331221818924, 77.89183035492897, 100.00206872820854, 132.7070277929306, 99.28685590624809, 132.75227576494217, 133.52623343467712, 55.267901346087456, 36.35609574615955, 41.96517236530781, 61.06024973094463, 71.67061418294907, 88.28488826751709, 99.3976503610611, 109.7789517045021, 108.82465571165085, 97.82774180173874, 33.94867032766342, 3.88735955581069, 0.4943659115815535, 0.29804561636410654, 0.12608274148078635, 0.44533289736136794, 0.13872797309886664, 0.1435227517504245, 0.12181267607957125, 0.16114550846396014, 0.08190369218937121, 0.1792331613251008, 0.09987431578338146, 0.24233561824075878, 0.11464524388429709, 0.08502680546371266, 0.11171109625138342, 0.16769512498285621, 0.25018590793479234, 0.3327543492196128, 0.1905269271810539, 0.12192313733976334, 0.11186383024323732, 0.13836203492246568, 0.08765193764702417, 0.19578971900045872, 0.0772916674031876, 0.14498876058496535, 0.1347791388980113, 0.14550440479069948, 0.15818738203961402, 0.14609592617489398, 0.09339170777820982, 0.09319247081293724, 0.07966528573888354, 0.10540880044572987, 0.10799888099427335, 0.14771765243494883, 0.17278979066759348, 0.14355760300531983, 0.08745827421080321, 0.12333850943832658, 0.14958157116780058, 0.15038825600640848, 0.13522736640879884, 0.12448366556782275], [0.03607878941693343, 0.03168348288454581, 0.07669655402423814, 0.012524111261882354, 0.03306348422484007, 0.04508379781327676, 0.03189138071320485, 0.05198621278395876, 0.011461035737738712, 0.05165400893019978, 0.036239957917132415, 0.004809136426047189, 0.018994587007910013, 0.036199414389557205, 0.08143715589540079, 0.0242669228464365, 0.0502185728691984, 0.06060252504539676, 0.03480715648038313, 0.01964382336154813, 0.06326293150777929, 0.03218046578695066, 0.008886295381671516, 0.022813979521743022, 0.03955497944843955, 0.004320621892475174, 0.06732528461725451, 0.05552061687922105, 0.04585989132465329, 0.019511867649271153, 0.03314935071102809, 0.06278806831687689, 0.07955517328809947, 0.004832824388358858, 0.011950062817049911, 0.08623439847724512, 0.14909022487699986, 0.2547446242533624, 14.520514234900475, 84.9502632021904, 103.03983852267265, 81.68024986982346, 85.1340289413929, 56.4986477047205, 39.25074242055416, 21.56693022698164, 92.09720849990845, 88.70721280574799, 77.58701831102371, 64.9483796954155, 60.68057790398598, 43.346975818276405, 55.35373114049435, 54.385444298386574, 28.4263601526618, 8.376511819660664, 0.9753332077525556, 0.28465602546930313, 0.044350904718157835, 0.10436416079755872, 0.2131129300687462, 0.14832032087724656, 0.15398777613881975, 0.18644596100784838, 0.8656457404140383, 1.1268197977915406, 1.999352965503931, 10.407826770097017, 29.023057334125042, 56.42026551067829, 62.03666813671589, 64.42970752716064, 64.60898950695992, 44.51328903436661, 17.761208340525627, 5.322999469935894, 2.7551357354968786, 2.116443682461977, 4.232496460899711, 5.2494496665894985, 6.795417135581374, 12.877833880484104, 21.84900239109993, 3.152749012224376, 4.5203846879303455, 12.240323089063168, 9.302325490862131, 10.623953472822905, 9.011825378984213, 5.65128237940371, 9.648573361337185, 7.910478701815009, 3.4472317853942513, 1.5344333066605031, 3.9000043272972107, 6.819148762151599, 15.924321357160807, 22.24581129848957, 27.461620420217514, 26.446955166757107, 31.223403364419937, 22.50468570739031, 11.328406222164631, 3.4817944932729006, 7.463733348995447, 0.8769449091050774, 0.4057413968257606, 0.3327297099167481, 0.030622887061326765, 0.3646583278896287, 0.27225993282627314, 0.14318053261376917, 0.048078938852995634, 0.20400581328431144, 0.6583264900837094, 20.432875379920006, 41.570555940270424, 68.41741874814034, 41.54374837875366, 51.8248300999403, 80.28908371925354, 49.152410700917244, 19.115153588354588, 12.87442546337843, 27.23296768963337, 42.348385602235794, 61.14757664501667, 74.66285482048988, 71.20437160134315, 79.85816404223442, 74.30395647883415, 45.88566519320011, 7.903872756287456, 0.6408126361202449, 0.027398416823416483, 0.028890543690067716, 0.027654583936964627, 0.04848010677960701, 0.05003508798836265, 0.0476134898053715, 0.03823715524049476, 0.054754371667513624, 0.05301882963976823, 0.08414661831920967, 0.057604868125054054, 0.031144861786742695, 0.048878465677262284, 0.033133906617877074, 0.029797321985824965, 0.026825100321730133, 0.036820265449932776, 0.013786069375782972, 0.04818475055799354, 0.04588055642670952, 0.015607404602633324, 0.11893287592101842, 0.011567148012545658, 0.021455047753988765, 0.03264624137955252, 0.021950763439235743, 0.05385534881497733, 0.04020618063805159, 0.0329754358244827, 0.03516334283631295, 0.039985243274713866, 0.013299899565026863, 0.14633621874963865, 0.03446619157330133, 0.09737448039231822, 0.05059975475887768, 0.02532229023927357, 0.016357059103029314, 0.10434253461426124, 0.04594563535647467, 0.0644438888411969, 0.05753326942794956, 0.03281984456407372, 0.04409507157106418, 0.03670075740956236, 0.049942004116019234, 0.05462621389597189, 0.03943348245229572, 0.03530412453983445, 0.045582710299640894, 0.021174898138269782, 0.013833990778948646, 0.02139930504199583, 0.01342722056506318, 0.01244257149664918, 0.048867886362131685, 0.0328367358451942, 0.020429306896403432, 0.0253413393147639, 0.08897385108866729, 0.086144880624488, 0.018058974419545848, 0.025904850190272555, 0.08679977399879135, 0.05906280981434975, 0.026126733791898005, 0.01623410193133168, 0.03137443032755982, 0.0647496611054521, 0.02914056025474565, 0.010683600794436643, 0.023428334934578743, 0.03508932473778259, 0.024892169276427012, 0.1780634475289844, 0.011401166684663622, 0.04584924150549341, 0.0880918456823565, 0.18461098603438586, 0.14916200540028512, 5.423113647848368, 82.61316820979118, 115.1441802084446, 100.36893904209137, 96.74768015742302, 78.88869926333427, 66.94663926959038, 53.289545103907585, 99.92191582918167, 66.63745746016502, 26.840648241341114, 35.86723677814007, 55.15402905642986, 40.009409710764885, 49.5271959900856, 58.30721765756607, 36.50351643562317, 12.695348672568798, 1.242738871369511, 0.31923215137794614, 0.1732202066341415, 0.037323244905564934, 0.4923069861251861, 0.544711280381307, 1.3114737393334508, 0.9562790708150715, 0.30496192805003375, 0.9906716784462333, 1.686585454735905, 14.453962706029415, 36.573083102703094, 58.53619337081909, 69.93983745574951, 73.48776787519455, 76.01588621735573, 53.43745596706867, 23.3029430732131, 9.57194097340107, 5.7191353384405375, 3.4788700751960278, 1.4532031654380262, 3.2194577576592565, 2.8357821330428123, 6.13170912489295, 14.761115424335003, 7.579715475440025, 5.356294708326459, 6.785894371569157, 1.5514233824796975, 0.809305866714567, 1.4191917842254043, 2.7950081834569573, 1.0115983430296183, 1.1652531917206943, 1.2000844976864755, 0.9146490390412509, 6.741799162700772, 11.399046331644058, 21.390866674482822, 30.24333905428648, 35.37332408130169, 35.87906934320927, 38.1762208789587, 28.588896431028843, 16.263860687613487, 4.598386902362108, 0.9771278395783156, 1.146830830257386, 0.4799098247895017, 0.48036737367510796, 0.24798342143185437, 1.0929984063841403, 0.1965962999383919, 0.038579715765081346, 0.07755141166853718, 0.13073983689537272, 2.390490439720452, 24.737582691013813, 47.33817145228386, 62.8058722615242, 46.899933367967606, 50.81865929067135, 46.56552851200104, 36.72345623373985, 31.594082973897457, 30.56017365306616, 41.38147048652172, 65.66429167985916, 76.40009120106697, 83.23887303471565, 82.3410952091217, 93.8983878493309, 81.37129604816437, 41.515899673104286, 6.811717785894871, 0.47896325995679945, 0.016553670720895752, 0.08167350766598247, 0.07016110510448925, 0.05223755964834709, 0.11196834690053947, 0.034031667819363065, 0.04353426396846771, 0.0166684587020427, 0.08697900266270153, 0.047762735703145154, 0.0998132889799308, 0.05989753299218137, 0.045755007304251194, 0.04872396166319959, 0.022639034905296285, 0.02267416632093955, 0.008356789712706814, 0.0324610903771827, 0.03457969563896768, 0.06423357903258875, 0.009091051142604556, 0.05629071012663189, 0.02743128097790759, 0.03373388848558534, 0.02820013298332924, 0.003443026234890567, 0.008677910518599674, 0.010495956175873289, 0.006494191075034905, 0.02567653402365977, 0.05545091436943039, 0.02353151015995536, 0.05674653351888992, 0.0671682610118296, 0.026885075130849145, 0.016704519657650962, 0.04611512333212886, 0.038879324492882006, 0.04538511719147209, 0.04410074157931376, 0.05000582881621085, 0.0270432175238966, 0.15039886871818453, 0.10796314658364281, 0.1413490457343869, 0.1620064294547774, 0.13498211628757417, 0.10842503703315742, 0.08974627839052118, 0.17313202464720234, 0.12536140362499282, 0.29092565935570747, 0.17500827787443995, 0.07508195980335586, 0.07045366714010015, 0.15635911608114839, 0.18329699872992933, 0.11477792504592799, 0.1924498614971526, 0.11348704079864547, 0.18956672167405486, 0.20642698102165014, 0.09087630212889053, 0.16777603392256424, 0.08641534150228836, 0.1477624336257577, 0.15467876015463844, 0.1530690715298988, 0.11510865573654883, 0.14288162521552294, 0.17716714093694463, 0.11223330846405588, 0.29797401395626366, 0.17915965901920572, 0.3305147256469354, 0.07692627841606736, 0.25638658145908266, 0.23678505123825744, 0.2193417161470279, 0.6063117936719209, 36.67785108089447, 124.54587891697884, 120.37473633885384, 104.83840361237526, 105.60431331396103, 76.11951425671577, 57.693983763456345, 32.24755480885506, 108.96787762641907, 107.49481067061424, 106.73522382974625, 97.2456282377243, 86.951023042202, 66.33367136120796, 81.17533296346664, 82.78662890195847, 47.661427706480026, 16.54292531311512, 2.311442568898201, 0.993224250851199, 0.3011617163429037, 0.23746307735564187, 0.4177011066349223, 0.33055800769943744, 0.812617092160508, 0.981176522327587, 2.658438286744058, 3.6329344706609845, 8.593740463256836, 20.054107904434204, 37.342902794480324, 64.7929148375988, 70.84177985787392, 70.75341179966927, 75.14964669942856, 52.83544287085533, 24.114608019590378, 10.803755074739456, 9.016066901385784, 9.733368661254644, 16.715610846877098, 21.54664121568203, 25.25255385786295, 34.41549427807331, 44.039146676659584, 9.230205360800028, 21.570236049592495, 44.15369153022766, 36.41191095113754, 33.47953610122204, 27.6211928576231, 25.54772961884737, 25.18714416772127, 22.366348430514336, 14.986230544745922, 8.39137377217412, 14.578726161271334, 14.33208329603076, 21.298719719052315, 28.37313260883093, 32.461323738098145, 31.296805925667286, 41.06573782861233, 37.39912837743759, 23.73711157590151, 17.62898873537779, 20.61787985265255, 7.945486223325133, 2.5788966799154878, 1.1799828638322651, 0.28610030421987176, 0.2934904326684773, 0.38813269638922065, 0.12243227291037329, 0.2337606213404797, 0.3951294271973893, 2.988073923625052, 34.99140277504921, 61.25608742237091, 103.07634696364403, 57.39297151565552, 78.95853951573372, 114.08685654401779, 69.81561452150345, 29.342903271317482, 23.727849572896957, 44.876788929104805, 61.91797010600567, 81.94400891661644, 97.53784015774727, 90.34426376223564, 99.75651830434799, 98.68558377027512, 76.1980864405632, 23.224289193749428, 0.7567746355198324, 0.17317244200967252, 0.11054829927161336, 0.162983333284501, 0.19711439323145896, 0.1311095748678781, 0.21954850817564875, 0.16262478689895943, 0.10430577603983693, 0.22396729997126386, 0.21128939901245758, 0.1392960426164791, 0.1471370703075081, 0.1330238112132065, 0.1573091690079309, 0.10999458289006725, 0.16806697065476328, 0.09018892495078035, 0.1443760286201723, 0.1597907327231951, 0.18320320610655472, 0.11387936232495122, 0.20526661828625947, 0.15601219172822312, 0.1017531962133944, 0.17562086140969768, 0.15314888209104538, 0.15013828582596034, 0.13355468428926542, 0.07183599140262231, 0.12360675129457377, 0.1397494354750961, 0.12084082627552561, 0.2521813352359459, 0.1279312977567315, 0.1981158769922331, 0.2014978142688051, 0.09942687494913116, 0.1422870164969936, 0.18857132352422923, 0.17777763161575422, 0.14279635244747624, 0.13336965203052387], [0.016590514642302878, 0.020791907263628673, 0.05891451015486382, 0.020647852688853163, 0.025734811169968452, 0.05688132609066088, 0.018702381203183904, 0.031718961254227906, 0.032059169170679525, 0.08286928568850271, 0.02665032083314145, 0.00909147509446484, 0.04084012318344321, 0.04350939459982328, 0.010729610239650356, 0.04516036147833802, 0.020702561960206367, 0.020793363728444092, 0.06638539911364205, 0.04251145088346675, 0.03176151971274521, 0.025817451169132255, 0.020344574040791485, 0.041102004834101535, 0.005879006312170532, 0.05069401493528858, 0.04313036122766789, 0.020194691751385108, 0.02165437377698254, 0.015529890060861362, 0.028750719357049093, 0.033611860853852704, 0.04249034420354292, 0.12066008363035508, 0.044615788356168196, 0.050020133712678216, 0.5991430627182126, 47.551123425364494, 106.831746250391, 94.37939643859863, 85.29305040836334, 81.832834482193, 53.15247505903244, 25.054489485919476, 23.02583534270525, 32.03894980251789, 67.72058174014091, 84.84921142458916, 73.90869408845901, 87.57858976721764, 41.79892748594284, 47.1476648747921, 34.86010082066059, 10.337926670908928, 2.215893608517945, 0.14685744390590116, 0.08559424415579997, 0.08513169319485314, 0.003543854418239789, 0.05921414485783316, 0.09391484767547809, 0.20958116801921278, 1.0813675867393613, 2.3932483792304993, 4.933611089363694, 21.817982755601406, 76.02886632084846, 113.47057521343231, 126.33721679449081, 123.19100841879845, 126.46151572465897, 124.76987689733505, 124.88726019859314, 134.09737318754196, 135.66149085760117, 115.43766885995865, 111.21912762522697, 96.3024352490902, 74.27674993872643, 39.37677025794983, 10.640322044491768, 14.174753688275814, 18.551326543092728, 19.684292748570442, 9.226229824125767, 3.304922296665609, 6.936133559793234, 7.437345664948225, 8.413382191210985, 3.0788474902510643, 2.628665459342301, 0.287316803005524, 11.265637390315533, 45.87668627500534, 85.38534745573997, 108.76198947429657, 133.05031657218933, 140.92452764511108, 144.32432681322098, 148.0363780260086, 138.76551389694214, 126.29748612642288, 108.30360487103462, 71.4612378180027, 23.8993913680315, 6.62645255215466, 5.2146549336612225, 3.637456465512514, 2.609882829710841, 12.567727770656347, 10.99045805633068, 0.9102843201253563, 0.10152105984161608, 0.18743889522738755, 0.12065107395756058, 0.2564117847941816, 5.408178074285388, 26.55112847685814, 46.65891610085964, 57.37918205559254, 74.70802679657936, 64.2182032763958, 54.85438093543053, 37.465161234140396, 20.023321956396103, 14.343448486179113, 27.567788623273373, 56.469035893678665, 68.61927911639214, 64.76721301674843, 74.93462383747101, 89.06864941120148, 82.6241572201252, 36.395594626665115, 2.6147574931383133, 0.30725302698556334, 0.018328103142266627, 0.06293210433796048, 0.03366883182025049, 0.03196315752575174, 0.04155778369749896, 0.037608660059049726, 0.0606901801074855, 0.19963152066338807, 0.019615644014265854, 0.08925260917749256, 0.05824872205266729, 0.05155780432687607, 0.04062321568198968, 0.03213702788343653, 0.040142355937859975, 0.02733523964707274, 0.008618934825790348, 0.05035660491557792, 0.0392760840622941, 0.03896201458701398, 0.044266626427997835, 0.03394746374397073, 0.034839124491554685, 0.04888462179224007, 0.04973552378942259, 0.04707223408331629, 0.10067801718832925, 0.018643603107193485, 0.047042392325238325, 0.035943688853876665, 0.07783530541928485, 0.17727323836879805, 0.035068110446445644, 0.05239286147116218, 0.05817133089294657, 0.04667436871386599, 0.033018406174960546, 0.021345146815292537, 0.04536573600489646, 0.14067179145058617, 0.04158721356361639, 0.08675535646034405, 0.03743020322872326, 0.01260498866031412, 0.03625314959208481, 0.009458866952627432, 0.03868576866807416, 0.10130718030268326, 0.022138877466204576, 0.03138667205348611, 0.07957974579767324, 0.04234633786836639, 0.04587544302921742, 0.0410718253988307, 0.018358833622187376, 0.035059906003880315, 0.07261789593030699, 0.03840928526187781, 0.051359558128751814, 0.0642935890937224, 0.007956498448038474, 0.04029929048556369, 0.06105858592491131, 0.0381388800451532, 0.04667143723054323, 0.04225587748805992, 0.04604041503625922, 0.05029504747653846, 0.018413678335491568, 0.025322848705400247, 0.11344589613145217, 0.11619872224400751, 0.06761237702448852, 0.049856052282848395, 0.027141763603140134, 0.11178214946994558, 1.1422961298376322, 34.2501537501812, 107.76873797178268, 107.07114100456238, 103.23777750134468, 90.14394611120224, 80.32423943281174, 46.89243257045746, 39.65038977563381, 25.979819633066654, 61.79389916360378, 85.98495528101921, 58.6836102604866, 60.69745659828186, 41.40312172472477, 50.640068873763084, 44.170733615756035, 16.5275152400136, 2.8435591282323003, 0.05768994422396645, 0.0987794401589781, 0.08533046260708943, 0.25577220192644745, 0.25138495140708983, 0.6513868749607354, 1.3689409056678414, 0.6739093351643533, 0.7319003390148282, 6.2619623355567455, 27.043325565755367, 82.2549994289875, 119.64413434267044, 129.57740932703018, 128.7422901391983, 131.95217549800873, 130.8318132162094, 127.11755812168121, 139.4934180378914, 138.79734098911285, 124.3195478618145, 120.52517786622047, 106.7598009109497, 83.72254148125648, 47.23494239151478, 14.656887017190456, 0.7269628008361906, 0.9946170542389154, 2.4550582375377417, 0.2827918989351019, 1.653931550681591, 4.754603169858456, 4.48595711030066, 4.378307461738586, 1.9959680596366525, 1.8074532877653837, 0.9375116403680295, 15.489021465182304, 57.018653601408005, 101.88877388834953, 125.16781434416771, 138.64661067724228, 152.84246653318405, 153.15424740314484, 156.24114096164703, 144.01421785354614, 137.03108936548233, 119.29237961769104, 82.1857975423336, 33.933794125914574, 11.493116933852434, 2.970567075535655, 1.5286304242908955, 2.86352610681206, 10.527474749833345, 14.342760723084211, 1.5335848834365606, 0.07344917554291897, 0.10626537245116197, 0.23751709086354822, 0.14169059693813324, 7.338644536212087, 32.79766649007797, 54.58457261323929, 58.527484238147736, 56.517323702573776, 46.86532482504845, 27.838277108967304, 23.2361863553524, 38.28643776476383, 32.18398801982403, 53.03666487336159, 81.02604657411575, 84.97360154986382, 77.15179726481438, 86.57349050045013, 102.48028814792633, 90.1892776787281, 32.81119376420975, 2.0388470962643623, 0.3238017327385023, 0.07378688242170028, 0.08839365487801842, 0.056370353704551235, 0.04356094046670478, 0.022843168189865537, 0.019311834730615374, 0.054054363135946915, 0.06367415553540923, 0.013993751053931192, 0.11757918371586129, 0.038890156138222665, 0.01943544684763765, 0.04681905411416665, 0.02581702257884899, 0.02452284134051297, 0.0319758259865921, 0.013533669589378405, 0.029541162293753587, 0.060749121475964785, 0.006106895743869245, 0.04388092114822939, 0.018485638829588424, 0.03153467856463976, 0.03322808515804354, 0.07368990598479286, 0.016989834621199407, 0.05818824443849735, 0.0954004492086824, 0.027868934739672113, 0.04427685322298203, 0.08589386401581578, 0.11490590841276571, 0.03059725699131377, 0.03965228614106309, 0.06340445164823905, 0.035905590702896006, 0.014736433076905087, 0.026027593994513154, 0.04778835835168138, 0.06859177447040565, 0.17835217266110703, 0.10850080288946629, 0.2010282574337907, 0.16701646061846986, 0.08019871180295013, 0.18019899231148884, 0.1795826238230802, 0.22869319247547537, 0.12156913289800286, 0.21163428988074884, 0.1530918851494789, 0.14431316871196032, 0.12282035677344538, 0.1538610173156485, 0.13138918642653152, 0.13668890751432627, 0.1541975961299613, 0.09670190163888037, 0.352786963339895, 0.19900691433576867, 0.11750145858968608, 0.1333606126718223, 0.09494508223724551, 0.24931296415161341, 0.11025573723600246, 0.18008142127655447, 0.15817277657333761, 0.09245047898730263, 0.12176210613688454, 0.16373328835470602, 0.23147304018493742, 0.20170525938738137, 0.15845725662074983, 0.1679672408499755, 0.05410762707469985, 0.17735796194756404, 2.764424099586904, 82.52927631139755, 143.71417075395584, 113.22155177593231, 108.06315377354622, 106.11060574650764, 70.75329780578613, 37.974808886647224, 32.916923090815544, 54.616152718663216, 85.65537616610527, 92.35434830188751, 103.03406283259392, 127.21030354499817, 67.5078995525837, 77.3878937959671, 58.73972944915295, 20.404652394354343, 4.598190737888217, 0.7383291784208268, 0.1972310885321349, 0.354657294228673, 0.3898124734405428, 0.20410569151863456, 0.45520340208895504, 1.0249184095300734, 4.027543058618903, 9.651531502604485, 16.133765168488026, 29.99277099967003, 87.33105584979057, 122.30203852057457, 133.94746363162994, 135.02064764499664, 137.70637392997742, 141.75485908985138, 134.38361942768097, 146.94588214159012, 140.42566001415253, 127.719187438488, 123.88406842947006, 108.13301682472229, 81.79587006568909, 44.06070291996002, 17.27799016982317, 30.47365989536047, 44.64017562568188, 46.711425483226776, 29.3629414960742, 22.59975280612707, 20.161866322159767, 21.12838815897703, 22.50867359340191, 13.042644336819649, 11.091951560229063, 1.3745730347000062, 14.22576880082488, 53.64733010530472, 102.94334650039673, 128.01187813282013, 142.21907258033752, 163.01926285028458, 160.98848462104797, 169.45073693990707, 152.99657106399536, 137.59909808635712, 120.67638695240021, 79.53063681721687, 30.342711322009563, 12.77888623997569, 14.371147099882364, 9.075966887176037, 9.102839045226574, 19.113221392035484, 15.300533529371023, 1.330154724419117, 0.3547480737324804, 0.3409131051739678, 0.3356386913219467, 0.4738979536341503, 11.710191685706377, 43.58045049011707, 75.1802958548069, 88.93290549516678, 110.20974978804588, 92.49856576323509, 76.32231697440147, 50.395821779966354, 31.45289395004511, 23.332444690167904, 44.62694473564625, 75.35337656736374, 91.87855303287506, 84.75366175174713, 97.34333619475365, 107.9430802166462, 110.31632646918297, 59.97539274394512, 6.541735623031855, 0.8031408162787557, 0.18761340383207425, 0.18786509579513222, 0.1518374923034571, 0.130077677895315, 0.17598611681023613, 0.11266698245890439, 0.16410719719715416, 0.38543291157111526, 0.10586835313006304, 0.21722761943237856, 0.1556533930124715, 0.18775220029056072, 0.15972187626175582, 0.10445130377775058, 0.1460196333937347, 0.07990552636329085, 0.09487500865361653, 0.1957483368460089, 0.2698762435466051, 0.257168211392127, 0.17456276662414894, 0.08037814826820977, 0.15420233103213832, 0.08671868694364093, 0.15220800210954621, 0.14259778341511264, 0.18667957425350323, 0.11868445682921447, 0.165415232477244, 0.19508729106746614, 0.19790317746810615, 0.2912934380583465, 0.13471249403664842, 0.1302162220235914, 0.20631608931580558, 0.2071021869778633, 0.06608993528061546, 0.10048231284599751, 0.0897297656047158, 0.21709001041017473], [0.043678481815732084, 0.10585460113361478, 0.041295312039437704, 0.030929356944398023, 0.02505546588508878, 0.035976899962406605, 0.06177597555506509, 0.020560832163027953, 0.009466875653743045, 0.007847718152333982, 0.059906995375058614, 0.04953964875312522, 0.029230510408524424, 0.027233183209318668, 0.04417825519340113, 0.05418859167548362, 0.016132158671098296, 0.03620537754613906, 0.06230101906112395, 0.019839034175674897, 0.042375352131784894, 0.020771470371983014, 0.06685867410851642, 0.041013125228346325, 0.026411158178234473, 0.0320779417961603, 0.031217655341606587, 0.07640278970939107, 0.026795321646204684, 0.012490464141592383, 0.06236755260033533, 0.049158901019836776, 0.14795233437325805, 0.10079544721520506, 0.19679540331708267, 3.6924426024779677, 66.91798880696297, 99.4681441783905, 100.27633801102638, 85.50894722342491, 73.55187803506851, 52.755757346749306, 24.231681637465954, 34.691173285245895, 65.14273926615715, 62.69810624420643, 47.851470708847046, 40.6294946372509, 47.50128909945488, 38.342420160770416, 36.32951237261295, 14.817776083946228, 2.5267012557014823, 0.1374693203251809, 0.19999932905193418, 0.05421917187049985, 0.22195124096469954, 0.04938387937727384, 0.07152496473281644, 0.3732369019417092, 0.5594566266518086, 2.2262376034632325, 6.466234624385834, 31.374221071600914, 92.3147240281105, 123.88731345534325, 120.56000679731369, 105.33504456281662, 106.26632139086723, 103.74095410108566, 104.57362622022629, 94.20869439840317, 95.2533495426178, 103.18208009004593, 108.65492641925812, 105.70649743080139, 115.15124022960663, 118.77525016665459, 133.65582168102264, 140.54950296878815, 129.5108824968338, 35.62379524111748, 4.641521237790585, 3.7662215810269117, 2.6773432223126292, 6.610475359484553, 24.314387999475002, 40.998325645923615, 26.62345379590988, 17.403786219656467, 15.89946499094367, 54.74322929978371, 100.9715487062931, 123.40568169951439, 124.55038547515869, 116.99746996164322, 110.2414932847023, 105.6881596148014, 103.84739398956299, 103.26259776949883, 105.63564643263817, 109.30675864219666, 114.83709588646889, 120.45947179198265, 127.44866475462914, 96.95675253868103, 59.848517552018166, 16.411273777484894, 5.465213963761926, 17.606499642133713, 0.7094690739177167, 0.8703844423871487, 0.2129326475551352, 0.250459760427475, 0.05040794669184834, 0.1224146097956691, 0.1197801562375389, 0.8569317392539233, 14.878598470240831, 39.125428944826126, 50.813563764095306, 66.88600972294807, 77.82058417797089, 78.73390316963196, 35.56004986166954, 33.433193787932396, 13.757183644920588, 11.296657975763083, 15.029571019113064, 41.65382467210293, 75.30847057700157, 61.32731080055237, 75.32523527741432, 87.03036278486252, 58.84346768260002, 8.003948461264372, 0.2947863412555307, 0.05565152801864315, 0.1333928812528029, 0.03544472812791355, 0.022875837530591525, 0.05639220995362848, 0.05491405216162093, 0.04854642138525378, 0.05566251180425752, 0.021487832127604634, 0.13834095792844892, 0.06125407133367844, 0.05157972736924421, 0.08955144236097112, 0.013203600337874377, 0.028511065029306337, 0.04072218849614728, 0.0411095153685892, 0.03722615343576763, 0.039362510869977996, 0.02747801958321361, 0.06353673205012456, 0.05238725454546511, 0.011572831936064176, 0.025609232361603063, 0.03542402962921187, 0.0532726218807511, 0.09066962142242119, 0.02807623885018984, 0.030685095734952483, 0.08210589774535038, 0.046877427739673294, 0.02965447896713158, 0.1334356883307919, 0.018341322647756897, 0.0286434882946196, 0.0657279601728078, 0.043577679607551545, 0.02476632515026722, 0.04978927754564211, 0.07155698098358698, 0.0818532113044057, 0.040729858592385426, 0.02361525966989575, 0.014507722644339083, 0.04611569849657826, 0.04667572684411425, 0.02899280792917125, 0.047202558926073834, 0.07954059008625336, 0.026373577675258275, 0.03829099434369709, 0.04411170681123622, 0.08362622436834499, 0.04465867707040161, 0.023628115523024462, 0.020690155106422026, 0.030251392054196913, 0.04069722264830489, 0.008917353334254585, 0.0423354468512116, 0.023369512309727725, 0.06213927910721395, 0.05920849711401388, 0.025461494878982194, 0.03814347022853326, 0.06412552975234576, 0.057239445741288364, 0.026694597363530193, 0.06272106722462922, 0.05709764358471148, 0.057931342598749325, 0.20045027282321826, 0.02331136132852407, 0.1754365416127257, 1.7874113819561899, 59.000524654984474, 111.5669609606266, 113.17993640899658, 99.54851746559143, 94.33152660727501, 91.80596172809601, 44.85569626092911, 19.378401562571526, 28.45661222934723, 35.938399359583855, 55.422777235507965, 60.58705352246761, 50.34513249993324, 49.163920283317566, 46.77210822701454, 23.700561337172985, 3.58615399338305, 0.15906887536402792, 0.12960825464688241, 0.018331671017222106, 0.20473106967983767, 0.3485970647307113, 0.6419709208421409, 0.8094054332468659, 1.4811115991324186, 0.9145258425269276, 9.695260506123304, 41.01585030555725, 101.90157160162926, 134.10831660032272, 123.55596363544464, 110.68005055189133, 109.7855557501316, 108.85583683848381, 109.01864290237427, 100.3589303791523, 102.42699220776558, 108.71583715081215, 112.95083150267601, 110.42699933052063, 119.40505117177963, 122.78554737567902, 138.1228467822075, 147.0717465877533, 141.28312200307846, 49.114636927843094, 4.802004676312208, 1.1957325437106192, 2.538482523523271, 8.331982009112835, 29.928816631436348, 49.05346781015396, 35.715085342526436, 22.482625991106033, 23.961470536887646, 65.80518051981926, 110.6052477657795, 125.2939523756504, 123.85205134749413, 118.918297290802, 114.53584045171738, 108.63015934824944, 109.83255162835121, 105.15800446271896, 107.50435575842857, 115.42597308754921, 120.55764332413673, 128.79746317863464, 137.04030007123947, 109.18020263314247, 69.4555002450943, 24.70814947038889, 7.741903597488999, 5.839868159964681, 0.35474204749334604, 1.0475321835838258, 0.2784458821406588, 0.09046635459526442, 0.16405400005169213, 0.12412848853273317, 0.21120268647791818, 1.171649198513478, 17.9366772249341, 46.40956208109856, 50.06244286894798, 52.986849546432495, 54.74657692015171, 52.8990438580513, 28.680893294513226, 25.077881030738354, 20.899615734815598, 18.75959526747465, 33.77774029970169, 54.25819672644138, 86.07031390070915, 72.63741910457611, 89.01469230651855, 99.18915554881096, 62.88868121802807, 6.560204531997442, 0.35482178383972496, 0.10884066199650988, 0.09866514941677451, 0.06898718333104625, 0.0702276015363168, 0.045831218449166045, 0.02809927140333457, 0.03158576801070012, 0.07457939223968424, 0.015257106260833098, 0.07469193893484771, 0.060325540689518675, 0.04373148229205981, 0.07373251268290915, 0.04714110909844749, 0.09431976344785653, 0.043727864322136156, 0.024905830359784886, 0.072788263350958, 0.03471367555903271, 0.018141410328098573, 0.0761614803923294, 0.08949607072281651, 0.026307420775992796, 0.016322836818289943, 0.03188436741766054, 0.0462790452002082, 0.06473959016148001, 0.036008686147397384, 0.056386558499070816, 0.042957529876730405, 0.10043240341474302, 0.0316850785020506, 0.08257405934273265, 0.04782795193023048, 0.04121756093809381, 0.039018399256747216, 0.05097673238196876, 0.04626679976354353, 0.013999999937368557, 0.213705935748294, 0.30031973496079445, 0.15156187349930406, 0.08909689917345531, 0.13378243456827477, 0.16274936380796134, 0.15434854896739125, 0.10855696862563491, 0.11703164942446165, 0.22300219628959894, 0.11519542764290236, 0.10835097069502808, 0.1562062039738521, 0.16788429842563346, 0.11523797496920452, 0.15152531530475244, 0.16111131029902026, 0.10485652383067645, 0.11450825084466487, 0.1174298561818432, 0.14199219091096893, 0.12606164964381605, 0.21581614360911772, 0.13105726829962805, 0.07232695177663118, 0.1544436180847697, 0.10568220764980651, 0.2404572573141195, 0.11190151650225744, 0.12069755466654897, 0.1944903371622786, 0.20792674273252487, 0.37029758153948933, 0.17331891227513552, 0.2947299083461985, 13.576131910085678, 110.75299143791199, 128.1216922402382, 117.75717079639435, 112.26835772395134, 95.54407954216003, 75.11802479624748, 39.708583652973175, 52.6993265748024, 99.85937878489494, 90.83496183156967, 68.84146839380264, 66.90277442336082, 69.36604544520378, 61.29282005131245, 58.79375874996185, 27.217263132333755, 5.406471015885472, 0.8987999113742262, 0.30691042193211615, 0.1436575999832712, 0.4258626530645415, 0.22732283163350075, 0.28894691553432494, 0.9020406031049788, 5.252286214381456, 10.885677728801966, 18.5205614939332, 39.288459196686745, 101.6555880010128, 136.1862426996231, 131.11926019191742, 117.51826241612434, 115.35938546061516, 113.40366080403328, 114.07050982117653, 105.14060139656067, 107.3068879544735, 114.47568207979202, 114.46500465273857, 114.15361136198044, 127.22895294427872, 130.88035941123962, 148.25120329856873, 157.54783004522324, 141.0523071885109, 45.17733380198479, 18.244863487780094, 14.552334677428007, 8.416606318205595, 9.654131513088942, 34.51720342040062, 55.23347519338131, 41.44666738808155, 25.541167370975018, 25.244418494403362, 69.38140422105789, 118.74603733420372, 135.22548705339432, 134.14968878030777, 123.96204024553299, 120.98158657550812, 111.99902817606926, 113.33442851901054, 108.38997423648834, 115.25563582777977, 121.66938006877899, 129.84170794487, 137.54860639572144, 145.6722816824913, 108.8207571208477, 68.67975667119026, 20.338159762322903, 11.9380540587008, 32.696010544896126, 1.7736475705169141, 1.3154802680946887, 0.3194001142401248, 0.25491760403383523, 0.3573579102521762, 0.22005408885888755, 0.394390159053728, 2.6562161184847355, 21.76479320973158, 60.33026710152626, 76.09822019934654, 98.36580812931061, 115.82929864525795, 110.71806371212006, 49.44974094629288, 49.17836330831051, 22.78040651232004, 22.767950780689716, 29.002815820276737, 59.48071248829365, 100.78776016831398, 81.72558143734932, 97.09897890686989, 108.677117228508, 90.77158123254776, 19.129380024969578, 0.7851175521500409, 0.22575385723030195, 0.23262703529326245, 0.19122827157843858, 0.12083355322829448, 0.12036805594107136, 0.1949968232656829, 0.11212913319468498, 0.1467250002315268, 0.06549435434862971, 0.21487040998181328, 0.12691877083852887, 0.16717023361707106, 0.17294396442594007, 0.13336616393644363, 0.1915620599174872, 0.1555858427309431, 0.13407313381321728, 0.19122361089102924, 0.17172943975310773, 0.06971366427023895, 0.1466569452895783, 0.09572230381309055, 0.09927136532496661, 0.07884406964876689, 0.10966946283588186, 0.11455160711193457, 0.18457132566254586, 0.2097133593633771, 0.1419991670991294, 0.18815147574059665, 0.19390938396099955, 0.10701947612687945, 0.23880534048657864, 0.20034997898619622, 0.09808099755900912, 0.08342854591319337, 0.14390746626304463, 0.1551077957265079, 0.16749435919336975], [0.05428482225397602, 0.05331864987965673, 0.011565804725250928, 0.08196797702112235, 0.08130327245453373, 0.151672720676288, 0.11465499570476823, 0.04031896482047159, 0.04380278041935526, 0.06819428017479368, 0.022166210765135475, 0.04385396634461358, 0.03350592298374977, 0.06169569001940545, 0.05084658936539199, 0.11812288852524944, 0.11745816911570728, 0.14749830326763913, 0.05797526660899166, 0.11773432968766429, 0.033152957548736595, 0.14151469309581444, 0.2361725122318603, 0.0688453960174229, 0.1572321043931879, 0.093520344235003, 0.1895963482093066, 0.20019672549096867, 0.2532880555372685, 0.07263426028657705, 0.028623615435208194, 0.10314633356756531, 0.0973021135723684, 0.216779391921591, 19.880329929292202, 95.89365318417549, 92.0030951499939, 96.29717633128166, 108.22121009230614, 84.89528015255928, 37.54800818860531, 17.053830698132515, 43.75857353210449, 70.77258557081223, 61.998176202178, 62.56524257361889, 39.99524787068367, 39.89233419299126, 33.79677727818489, 22.59618479758501, 4.63263351470232, 0.3994533873628825, 0.33925505820661783, 0.027388598209654447, 0.1548414389253594, 0.07549803747679107, 0.0777242578624282, 0.06438213473302312, 0.837297064717859, 1.9473183201625943, 5.065172854810953, 41.535647213459015, 102.53633514046669, 125.18282353878021, 113.5321395099163, 97.84962102770805, 96.55280381441116, 103.17623600363731, 112.19360053539276, 115.14416500926018, 108.82692039012909, 95.18227815628052, 98.40969577431679, 116.7882151901722, 122.05562174320221, 110.59212327003479, 102.15621873736382, 101.87903121113777, 96.34528174996376, 95.36790579557419, 109.22513902187347, 139.9081125855446, 49.69899237155914, 18.85572250932455, 54.186414778232574, 111.42856478691101, 135.7110098004341, 157.80560821294785, 145.21320551633835, 113.47342506051064, 72.75786504149437, 87.65031471848488, 98.78860384225845, 99.10031631588936, 108.54501351714134, 117.06925570964813, 115.11788561940193, 108.15227419137955, 108.84996995329857, 113.48459646105766, 113.60568836331367, 112.24618971347809, 113.12170833349228, 112.8122453391552, 113.11098530888557, 119.95172783732414, 122.9049825668335, 124.19885873794556, 106.70733332633972, 59.55212205648422, 50.84712736308575, 22.02527303248644, 4.138980628922582, 0.22319277981296182, 0.11035771574825048, 0.3314210067037493, 0.20575340779032558, 0.17103899008361623, 0.10344305163016543, 2.4726322945207357, 18.884703554213047, 41.907005086541176, 46.80183783173561, 54.66619983315468, 81.91746354103088, 87.04882219433784, 89.10945162177086, 144.7145962715149, 65.35032212734222, 32.792206183075905, 36.94544792175293, 66.12949311733246, 72.94557496905327, 73.40726539492607, 87.90676295757294, 82.19873204827309, 24.463459700345993, 1.4842067705467343, 0.019049084767175373, 0.4480802686884999, 0.2582350338343531, 0.04104805069800932, 0.09596731644705869, 0.10216092472546734, 0.07886340259574354, 0.11546054505743086, 0.2542503835866228, 0.4523826768854633, 0.3000969719141722, 0.22166610782733187, 0.02131421224476071, 0.060077032539993525, 0.03402839123737067, 0.024761759086686652, 0.047635791343054734, 0.013480738689395366, 0.08908400064683519, 0.214942843595054, 0.19744821125641465, 0.14096124388743192, 0.05078493544715457, 0.07876373216276988, 0.03841760102659464, 0.1376457733567804, 0.2746174391359091, 0.022276148811215535, 0.02931465882284101, 0.02132361154508544, 0.05033846682636067, 0.11404290940845385, 0.12985141191165894, 0.021405806255643256, 0.06670153175946325, 0.012672888678935124, 0.04052944903378375, 0.028986499673919752, 0.022678032910334878, 0.05102808900119271, 0.03177832935762126, 0.07927065613330342, 0.07364525838056579, 0.11718125155312009, 0.07825449269148521, 0.06296080318861641, 0.031528414838248864, 0.05602976729278453, 0.036066811153432354, 0.028439386551326606, 0.0409366654639598, 0.031279472532332875, 0.06802640637033619, 0.08839730624458753, 0.09800998886930756, 0.05255652358755469, 0.05118555789522361, 0.15698260918725282, 0.03529389032337349, 0.11241665604757145, 0.24128058110363781, 0.08514512606780045, 0.13496228610165417, 0.06596664228709415, 0.23966744891367853, 0.27907326410058886, 0.2814354607835412, 0.06919234263477847, 0.2427503006765619, 0.09359454415971413, 0.14347400749102235, 0.13492887461325154, 11.822999082505703, 93.16267892718315, 107.26587295532227, 108.46501260995865, 111.65804967284203, 100.62421694397926, 62.91198916733265, 24.338535703718662, 24.872555248439312, 39.74467411637306, 46.33770413696766, 48.290449753403664, 42.42666520178318, 43.04751768708229, 43.31987947225571, 32.74977385997772, 7.749116085469723, 0.43414977088104934, 0.4521619324805215, 0.06047341361409053, 0.1001877173257526, 0.15999081573681906, 0.4821640835143626, 0.524184366222471, 1.1727972119115293, 0.9694656101055443, 8.397250156849623, 47.03297942876816, 110.43387696146965, 130.24941086769104, 113.96926045417786, 101.48437678813934, 100.91904312372208, 106.51155263185501, 114.66472953557968, 120.81311881542206, 113.55895847082138, 98.18744570016861, 100.91069117188454, 122.7576644718647, 124.61426764726639, 116.92968919873238, 106.96394115686417, 107.62977182865143, 101.8519614636898, 102.05860957503319, 109.30540591478348, 143.01815450191498, 59.48445528745651, 26.656111143529415, 67.27596759796143, 124.45292070508003, 152.30584412813187, 169.79881346225739, 155.44374614953995, 127.77387410402298, 84.1796113550663, 93.62468853592873, 104.13660407066345, 103.87327820062637, 118.18192720413208, 121.6909097135067, 122.02663689851761, 115.45612826943398, 117.98242270946503, 120.6321269273758, 120.83491444587708, 119.91264313459396, 117.88965448737144, 117.87522286176682, 121.22184008359909, 126.6291019320488, 133.26837927103043, 135.16146808862686, 119.30882513523102, 74.60587307810783, 64.1793541610241, 32.0988117903471, 8.928086422383785, 0.1020621151837986, 0.07382466515991837, 0.22468774724984542, 0.20180537510896102, 0.2690130070550367, 0.10482664496521465, 3.456586883403361, 25.325815826654434, 51.19728997349739, 48.70733678340912, 49.06083561480045, 55.149742886424065, 45.8126787096262, 32.9534999281168, 92.22762510180473, 43.86795446276665, 44.83943313360214, 57.84088008105755, 70.94061255455017, 82.57741212844849, 82.35251739621162, 100.7593908905983, 89.12951454520226, 27.50876449048519, 1.1748113413341343, 0.05131024983711541, 0.2799407159909606, 0.18541713652666658, 0.0771130176144652, 0.029645016584254336, 0.12339258231804706, 0.06442214391427115, 0.09801430816878565, 0.31213727896101773, 0.5823330022394657, 0.1762782409787178, 0.2586826082551852, 0.09826216322835535, 0.05263133949483745, 0.006623297404075856, 0.055581970227649435, 0.07063185679726303, 0.07237300946144387, 0.08585990333813243, 0.11450904494267888, 0.13089442625641823, 0.1160130591597408, 0.10742535669123754, 0.05297806717862841, 0.03517057135468349, 0.08601855966844596, 0.1614336101920344, 0.09071227264939807, 0.0276608532294631, 0.04141576631809585, 0.06405596825061366, 0.05874930437130388, 0.09816667108680122, 0.020937752269674093, 0.08463726699119434, 0.08637943639769219, 0.028487047275120858, 0.016070590099843685, 0.12015716725727543, 0.12490542809246108, 0.08987366061774082, 0.23781059542670846, 0.2645021741045639, 0.24731928831897676, 0.25908479292411357, 0.10832036452484317, 0.20929523336235434, 0.15759942296426743, 0.1681284056394361, 0.20203518855851144, 0.10049757140222937, 0.14969422918511555, 0.20240019162883982, 0.22982484893873334, 0.3601326222997159, 0.26478252781089395, 0.1500779640628025, 0.2415155153721571, 0.10932627890724689, 0.22928317019250244, 0.4046593455132097, 0.13612757669761777, 0.27346244954969734, 0.23189547064248472, 0.34390375250950456, 0.48241825425066054, 0.41174183890689164, 0.272528026252985, 0.40215441898908466, 0.37783070700243115, 0.3154054004698992, 0.3616395086282864, 40.50350859761238, 139.97137159109116, 125.62398746609688, 120.76809883117676, 133.95758628845215, 103.65224406123161, 54.60287243127823, 24.995913729071617, 68.32028836011887, 108.78535062074661, 91.80213913321495, 98.51710081100464, 56.82345427572727, 61.80458039045334, 55.36576509475708, 46.76935337483883, 10.660992935299873, 1.2761247111484408, 0.7784022437408566, 0.24716667307075113, 0.33952386409509927, 0.1921939244493842, 0.22800204518716782, 0.5991725705098361, 2.5544787151739, 5.373930037021637, 10.520960949361324, 47.229151502251625, 117.00625509023666, 139.89840030670166, 121.54537752270699, 110.37249505519867, 104.40743833780289, 109.0933544933796, 117.90591761469841, 123.91020342707634, 121.35676324367523, 103.75302985310555, 104.1587644815445, 127.55193561315536, 128.45677345991135, 120.46074092388153, 110.59404596686363, 110.14928743243217, 104.29551154375076, 106.38713210821152, 119.49439957737923, 147.54121899604797, 60.261859372258186, 27.477030493319035, 75.59185937047005, 138.74479740858078, 149.67588365077972, 163.449065387249, 152.43683069944382, 144.06138092279434, 101.91160306334496, 103.74807491898537, 106.22296571731567, 108.43630895018578, 120.20976439118385, 127.79591292142868, 126.44469782710075, 120.76113000512123, 122.1146097779274, 126.55412435531616, 127.9949614405632, 123.92448306083679, 121.27910301089287, 121.91939145326614, 123.32603797316551, 130.916867852211, 136.5393653512001, 139.4501155614853, 119.70440670847893, 64.90519121289253, 56.54795005917549, 26.58483076840639, 6.852610716596246, 0.2340565007762052, 0.20619255141355097, 0.5166977585759014, 0.4271343379514292, 0.3510857530636713, 0.30234579811803997, 5.68712443113327, 34.793414399027824, 66.21397778391838, 67.34176486730576, 77.41453036665916, 122.50792667269707, 119.21604931354523, 112.26638942956924, 158.1704342365265, 74.86574113368988, 51.32911629974842, 53.53278525173664, 83.5312369465828, 92.80775517225266, 95.15133261680603, 107.09249585866928, 109.83291640877724, 47.01662130653858, 1.5551635692827404, 0.20204532629577443, 0.46902248868718743, 0.4575935925822705, 0.1668555778451264, 0.21006544906413183, 0.21806905162520707, 0.17512847611214966, 0.3339623281499371, 0.45225790701806545, 0.626469177659601, 0.42742704099509865, 0.2917514322325587, 0.27259060414507985, 0.15862542728427798, 0.11280947481282055, 0.10068737567053176, 0.17176568624563515, 0.1534378743963316, 0.21796917339088395, 0.3314308327389881, 0.3423821716569364, 0.24993767437990755, 0.12672385317273438, 0.19703700207173824, 0.1401774914120324, 0.29634758247993886, 0.30789160053245723, 0.24516952398698777, 0.14937884610844776, 0.14849291474092752, 0.18142968096071854, 0.3269490919774398, 0.23886155075160787, 0.088559651048854, 0.18370178091572598, 0.2044280359405093, 0.16465350694488734, 0.10523495235247537], [0.05008198430004995, 0.03957561115385033, 0.05826617736602202, 0.0664528454944957, 0.02782828545605298, 0.16006228455808014, 0.0563581008464098, 0.02168393722968176, 0.04111186797672417, 0.06409216279280372, 0.03839138837065548, 0.03272758818638977, 0.06383663392625749, 0.01869603212981019, 0.056362999021075666, 0.07611319626448676, 0.046422049636021256, 0.07463981048204005, 0.040907881266321056, 0.021052388110547327, 0.13783742557279766, 0.08019835557206534, 0.10659209554432891, 0.14305726188467816, 0.2430469964747317, 0.1337105649872683, 0.12025627365801483, 0.3100616403389722, 0.10944884459604509, 0.16616353997960687, 0.11487864190712571, 0.10894896360696293, 0.03887288265104871, 21.907473653554916, 114.90448907017708, 105.15099763870239, 97.15229004621506, 86.94486737251282, 70.12120932340622, 37.68975958228111, 24.3994103372097, 70.62806412577629, 60.513960644602776, 46.006236523389816, 47.52712771296501, 47.35906273126602, 42.8067322075367, 28.824628181755543, 10.956122148782015, 0.7928941317368299, 0.18168293143389747, 0.12117505248170346, 0.3540229657664895, 0.1206415744672995, 0.41631142026744783, 0.03240803052904084, 0.390941962832585, 1.8623779155313969, 4.392636967822909, 39.77973863482475, 85.91329872608185, 120.87913647294044, 107.30390891432762, 97.535719871521, 92.95816630125046, 96.83939963579178, 91.84989497065544, 94.1192775964737, 98.99158135056496, 108.54519590735435, 95.60795411467552, 82.41421088576317, 85.62839761376381, 106.46490633487701, 103.48907321691513, 100.12089595198631, 85.78602835536003, 94.87524703145027, 92.94069483876228, 104.63788837194443, 96.77037253975868, 110.25749042630196, 81.05760008096695, 59.688865318894386, 85.11298567056656, 117.10280790925026, 84.09150168299675, 80.41448459029198, 92.87158414721489, 100.49702256917953, 63.06954391300678, 83.78820955753326, 96.73369690775871, 107.91398137807846, 118.3489054441452, 109.28494021296501, 108.61448898911476, 99.6255849301815, 91.94327875971794, 87.04630672931671, 93.55894446372986, 96.92263796925545, 95.19191443920135, 103.93935665488243, 116.76426127552986, 110.86218237876892, 108.85221943259239, 108.11068922281265, 109.77048575878143, 134.98129695653915, 138.75174343585968, 134.14102524518967, 116.25632733106613, 54.20604832470417, 4.292987789958715, 0.5559185415040702, 0.08032003068365157, 0.0665660527010914, 0.1422311327769421, 0.34500364505220205, 0.07107619545422494, 7.374334596097469, 32.4973002076149, 51.34858265519142, 63.008507788181305, 65.58084815740585, 74.44758877158165, 147.19251930713654, 122.48876050114632, 23.220179714262486, 22.888265624642372, 28.156589828431606, 76.79647833108902, 67.45793983340263, 71.97520583868027, 76.08327940106392, 90.12763738632202, 33.19433480501175, 1.4030801737681031, 0.17995341564528644, 0.17248847871087492, 0.07827799650840461, 0.13093552639475092, 0.08992526214569807, 0.23025234084343538, 0.14865154138533399, 0.41321345837786794, 0.4057457309681922, 0.2453813180909492, 0.19820304965833202, 0.18904625350842252, 0.01377785009026411, 0.061431778594851494, 0.038243266826611944, 0.13976760325022042, 0.045466794254025444, 0.06885355964186601, 0.14534331421600655, 0.22235051641473547, 0.16181697399588302, 0.039185415880638175, 0.03503024978272151, 0.01221145001181867, 0.029772441484965384, 0.0072487627676309785, 0.05209612485487014, 0.06954600568860769, 0.037729463147115894, 0.03256752548622899, 0.023078740705386735, 0.11205069560674019, 0.09001310274470598, 0.035485850530676544, 0.08818615780910477, 0.028360290307318792, 0.10850036502233706, 0.04593710807967, 0.046125617300276645, 0.009347836094093509, 0.07108768390025944, 0.0028063607032891014, 0.11667730359476991, 0.07225134919281118, 0.05298686162859667, 0.01962066464329837, 0.038895792749826796, 0.016345661570085213, 0.056460966225131415, 0.0875816414190922, 0.0910099851898849, 0.07064833989716135, 0.10616533836582676, 0.01115704741096124, 0.015229002983687678, 0.03247723579988815, 0.06850581150501966, 0.13872257026378065, 0.1154577694251202, 0.0341306554764742, 0.1330162413069047, 0.3567816177383065, 0.20955226878868416, 0.13357475196244195, 0.37039340764749795, 0.1247696002246812, 0.16937073116423562, 0.04821844777325168, 0.02806871161737945, 0.1797016049386002, 16.110687106847763, 125.23097455501556, 117.76995331048965, 116.96034595370293, 99.14540469646454, 103.80562663078308, 71.5992084145546, 24.06655389815569, 20.219556726515293, 48.61973628401756, 46.42331354320049, 43.49459029734135, 48.65731246769428, 49.1097541898489, 41.067417338490486, 17.25903108716011, 1.5445747249759734, 0.21010556956753135, 0.09372934044222347, 0.1945397790404968, 0.5998673394788057, 1.0645777126774192, 0.9281178913079202, 1.5357462549582124, 1.76326367771253, 5.743523854762316, 45.38608320057392, 96.08457013964653, 124.36295673251152, 112.48131349682808, 101.26629889011383, 98.71701568365097, 103.57948556542397, 97.29618072509766, 98.73673662543297, 104.25787836313248, 113.27861711382866, 99.68317463994026, 86.14497229456902, 91.07818678021431, 111.85981884598732, 107.51114219427109, 103.22428062558174, 88.42858895659447, 96.69538736343384, 95.90301588177681, 110.16075521707535, 104.40764352679253, 117.87027552723885, 87.22730621695518, 65.83583727478981, 103.28446939587593, 123.39318037033081, 93.82017284631729, 86.63535118103027, 97.66206309199333, 104.9318253993988, 72.75192975997925, 87.07235053181648, 101.75389632582664, 109.84778121113777, 120.58444708585739, 114.45179656147957, 111.63608685135841, 101.63539588451385, 96.7518599331379, 90.23674473166466, 97.89847120642662, 101.44368097186089, 99.8740004003048, 110.7265904545784, 122.2741936147213, 120.05800053477287, 115.67187309265137, 112.91072845458984, 113.44074681401253, 136.51738733053207, 141.80506199598312, 139.2236629128456, 127.77203500270844, 68.55717524886131, 9.155734106898308, 0.3655966400401667, 0.05130369667313062, 0.1306217018282041, 0.03918908580089919, 0.5494426202494651, 0.16122993518365547, 10.03014413639903, 40.01956656575203, 55.30402220785618, 51.354236751794815, 57.97953084111214, 72.89622321724892, 162.77373522520065, 120.05340278148651, 35.02078279852867, 39.452709183096886, 48.93054060637951, 87.77629315853119, 74.65486764907837, 84.80689689517021, 86.16926059126854, 102.24395602941513, 37.304950430989265, 1.0701136593706906, 0.07627736675203778, 0.13503307214705274, 0.11042301732231863, 0.036271402714191936, 0.14319409907329828, 0.1645493390969932, 0.25048814015462995, 0.3149783390108496, 0.44365261564962566, 0.39971201098524034, 0.21124691847944632, 0.2570896624820307, 0.09996437540394254, 0.07027863161056302, 0.04460282674699556, 0.025231592371710576, 0.06819606132921763, 0.07852258611819707, 0.13375447044381872, 0.10760710123577155, 0.22436001483583823, 0.027119120677525643, 0.036756080808117986, 0.03068005284148967, 0.053781505121150985, 0.04293642319680657, 0.05282346668536775, 0.08083949694992043, 0.10436936325277202, 0.0346109845850151, 0.050888079131254926, 0.05421360947366338, 0.0693263893481344, 0.0328658169019036, 0.07025417784461752, 0.044509086073958315, 0.06989268513279967, 0.08884848750312813, 0.12751676375046372, 0.1872867252677679, 0.23259936802787706, 0.23827568453270942, 0.25828775600530207, 0.24362073600059375, 0.16184569511096925, 0.06414697039872408, 0.15064223378431052, 0.11896794982021675, 0.21442049037432298, 0.17682030564174056, 0.14498742471914738, 0.16251554276095703, 0.20168729941360652, 0.20486964349402115, 0.15676085546147078, 0.22154890786623582, 0.16477649565786123, 0.35225413099396974, 0.22602849639952183, 0.3515672584762797, 0.25032376928720623, 0.4803522932343185, 0.26969400176312774, 0.22636192850768566, 0.5129893950652331, 0.3842135629383847, 0.36458037269767374, 0.23197498434456065, 0.20691966317826882, 0.22463628672994673, 49.35132622718811, 155.76374977827072, 127.20453545451164, 130.32142460346222, 115.99824517965317, 91.7301557958126, 58.75270575284958, 39.87452834844589, 110.47589510679245, 93.86653035879135, 67.31189846992493, 71.55301809310913, 74.67055320739746, 71.2310765683651, 52.89199523627758, 21.98770634829998, 2.1674934681504965, 0.7202936243265867, 0.26800416118931025, 0.6268320581875741, 0.28491268982179463, 0.365470148390159, 0.3870915819425136, 2.0743015687912703, 7.362686321139336, 12.55948031321168, 47.39145219326019, 93.34509193897247, 129.56880658864975, 119.36354979872704, 107.57287368178368, 104.01960834860802, 106.99073731899261, 102.14020639657974, 101.85283541679382, 107.00799599289894, 115.77347964048386, 104.37430411577225, 88.68113860487938, 94.7884900867939, 115.41905745863914, 111.43162742257118, 108.2688595354557, 93.4268407523632, 101.79734319448471, 103.73471483588219, 116.42363235354424, 109.55937668681145, 122.57480308413506, 96.49551048874855, 86.59476175904274, 122.32343137264252, 122.8306433558464, 102.55222588777542, 93.47442179918289, 106.82052925229073, 111.15443989634514, 85.30206352472305, 88.96255150437355, 105.74322625994682, 111.32220849394798, 126.67282998561859, 117.53478392958641, 119.17228326201439, 107.12335020303726, 99.52508792281151, 93.97353261709213, 101.60495951771736, 105.95522448420525, 106.30833953619003, 115.59868142008781, 129.0098413825035, 122.41841107606888, 118.19816753268242, 116.21095016598701, 116.62838816642761, 145.7391580939293, 151.91891849040985, 143.05663883686066, 127.76352345943451, 61.29767619073391, 7.200321983546019, 0.3703619702719152, 0.21638505917508155, 0.23046207177685574, 0.21788531070342287, 0.8865601744037122, 0.259207128547132, 13.455738220363855, 56.15785539150238, 83.65122690796852, 92.25287854671478, 95.31832605600357, 92.64567866921425, 143.3431738615036, 132.52381682395935, 31.868204064667225, 35.75968734920025, 42.46491014957428, 93.74556005001068, 88.93164396286011, 92.17379719018936, 91.57615765929222, 112.23191007971764, 56.134946420788765, 1.4033719268627465, 0.3697190625825897, 0.3366534149972722, 0.21265311021124944, 0.23859842971432954, 0.2849242673255503, 0.3697199234738946, 0.312233401928097, 0.5949754582252353, 0.6025475019123405, 0.5302391038276255, 0.5215011164546013, 0.5094292829744518, 0.13735158601775765, 0.1981157434056513, 0.17304829554632306, 0.30870864575263113, 0.23380126134725288, 0.1904147886671126, 0.2337894611991942, 0.23921444197185338, 0.48716090444941074, 0.12106375259463675, 0.14330883510410786, 0.17141785647254437, 0.12191107001854107, 0.2069025789387524, 0.1588080104556866, 0.1883667876245454, 0.17356193595333025, 0.12488270353060216, 0.1609314137022011, 0.20507275447016582, 0.154005691583734, 0.16833110101288185, 0.27946431655436754, 0.11471831574453972, 0.1426221407018602], [0.13113991386489943, 0.030472127182292752, 0.03185505629517138, 0.019321525323903188, 0.1264272167463787, 0.13785869552521035, 0.0853760601603426, 0.12853276391979307, 0.03838308002741542, 0.04740850861708168, 0.05070008570328355, 0.09870518086245283, 0.034917973971460015, 0.025556306100043003, 0.1252900090184994, 0.13181834074202925, 0.040865500923246145, 0.06490779793239199, 0.05115714477142319, 0.027413536226958968, 0.08812955420580693, 0.036706824466818944, 0.09655229208874516, 0.17720775125781074, 0.15051943802973256, 0.18263571546413004, 0.21137389994692057, 0.35178402496967465, 0.2114662973326631, 0.11033447168301791, 0.09171707381028682, 0.35726071859244257, 18.249478340148926, 123.48692134022713, 95.80257207155228, 109.04934525489807, 88.04597988724709, 73.1266276538372, 25.868031531572342, 13.82300466299057, 50.77066406607628, 48.39251987636089, 39.412860721349716, 35.445102229714394, 34.014486595988274, 36.69680826365948, 24.178638383746147, 4.26218094304204, 0.4168620047857985, 0.16039896727306768, 0.45706022589001805, 0.1150738267460838, 0.33714955556206405, 0.02664064508280717, 0.5092122196219862, 1.369766767602414, 1.8992828414775431, 11.171421445906162, 63.500740975141525, 112.59773924946785, 104.22124832868576, 97.40536406636238, 102.34660372138023, 111.19366139173508, 110.64225018024445, 104.69793274998665, 100.82598611712456, 95.97314491868019, 101.42582193017006, 110.94383999705315, 102.45675221085548, 84.44217726588249, 82.8007261455059, 101.70847356319427, 104.57391500473022, 88.4854719042778, 84.50683459639549, 97.69465014338493, 104.99094262719154, 95.4221060872078, 105.94824805855751, 119.52832415699959, 95.63158124685287, 37.88932107388973, 81.89550831913948, 104.86209914088249, 90.76225653290749, 83.62087413668633, 93.23630377650261, 92.92910546064377, 67.90642216801643, 92.36931949853897, 93.58593821525574, 95.33915653824806, 102.07061693072319, 112.21186995506287, 114.74118903279305, 112.62442901730537, 109.47637394070625, 100.02237483859062, 97.24457949399948, 96.16679012775421, 90.55094987154007, 88.84113281965256, 93.9653554558754, 107.01016947627068, 113.04057508707047, 117.84914866089821, 113.22993412613869, 104.19705882668495, 96.10540822148323, 97.61623755097389, 104.88806694746017, 126.77528768777847, 111.99972733855247, 27.574960738420486, 0.4573262116173282, 0.3076931502437219, 0.05335679627023637, 0.18905082513811067, 0.0865213201905135, 0.1893007953185588, 2.6417436450719833, 22.697563357651234, 39.29002471268177, 46.579941138625145, 39.303354397416115, 43.10843221843243, 34.26215350627899, 36.3189185410738, 29.511234238743782, 22.066960595548153, 22.568721771240234, 50.43442390859127, 62.673156782984734, 78.01537692546844, 69.07564222812653, 84.36077043414116, 27.85813294351101, 1.0026822402141988, 0.30613119655754417, 0.0123805975272262, 0.1331224723253399, 0.10200004937360063, 0.1421692970325239, 0.2572882315143943, 0.13130950945196673, 0.22785977547755465, 0.08116516619338654, 0.16929901001276448, 0.1664482575142756, 0.14902467839419842, 0.08206374375731684, 0.06942485750187188, 0.012751251124427654, 0.13158340647350997, 0.03755137739062775, 0.11248962400713935, 0.20149563235463575, 0.11858801473863423, 0.03661818976979703, 0.0423367530311225, 0.04520055990724359, 0.03412406520510558, 0.03368000114278402, 0.08429571578744799, 0.038172477070475, 0.024485071589879226, 0.05299996424582787, 0.045602139725815505, 0.025507504324195907, 0.016454178403364494, 0.06362775646266527, 0.039071243882062845, 0.04574605329253245, 0.03222570339858066, 0.052095475475653075, 0.05809880080050789, 0.03799818368861452, 0.05086537312308792, 0.036766682387678884, 0.06594012535060756, 0.09672301574028097, 0.038665107276756316, 0.015152526520978427, 0.04879793523286935, 0.054803338571218774, 0.07110355843906291, 0.012808991141355364, 0.02083664763631532, 0.07462285240762867, 0.11554929107660428, 0.06921823616721667, 0.05109375422762241, 0.008922976958274376, 0.06529646067065187, 0.012987766167498194, 0.08322609544848092, 0.03551090914697852, 0.1936888918862678, 0.3068551467731595, 0.08452552181552164, 0.2915580285480246, 0.3148513723863289, 0.22950847138417885, 0.12438253310392611, 0.11544330496690236, 0.3569286223500967, 17.29848437011242, 134.90191161632538, 110.82658588886261, 121.64079040288925, 110.58216780424118, 95.45899450778961, 42.65710763633251, 19.453211948275566, 22.29605220258236, 55.51014594733715, 46.29386588931084, 41.179982498288155, 41.54823213815689, 45.56135639548302, 34.806098118424416, 6.329524135217071, 0.29068882518913597, 0.31128291855566204, 0.36706166923977435, 0.5922298680525273, 1.199292833916843, 0.10623782392940484, 0.3329644363839179, 1.291181759443134, 1.3408564939163625, 16.22273739427328, 71.16128951311111, 118.63108590245247, 107.78715938329697, 100.5412369966507, 106.98870062828064, 114.78843569755554, 114.0000768005848, 110.33793210983276, 105.20389080047607, 98.29241126775742, 105.2607661485672, 114.98291686177254, 107.5250418484211, 87.59336337447166, 85.02963334321976, 104.62778851389885, 105.5232560634613, 91.34051710367203, 89.05367821455002, 103.03621351718903, 108.62682312726974, 100.26708170771599, 109.92212802171707, 120.84895089268684, 97.78091311454773, 45.93649886548519, 88.19637581706047, 114.733946621418, 104.52945739030838, 89.59008023142815, 102.29216784238815, 100.34072175621986, 75.99136233329773, 95.46037763357162, 97.33658015727997, 100.31191930174828, 105.8460183441639, 114.19806137681007, 120.60129538178444, 117.71804809570312, 115.12975618243217, 108.95586267113686, 103.99866387248039, 102.71726623177528, 94.83905017375946, 91.74716368317604, 98.39102357625961, 109.92426350712776, 119.89034593105316, 124.96229857206345, 121.58973634243011, 110.66763281822205, 101.48847296833992, 102.16102167963982, 105.9070734679699, 130.01838326454163, 124.79422599077225, 40.15500269830227, 1.4005971257574856, 0.2739389083581045, 0.05390814520069398, 0.03268679603934288, 0.1046662891167216, 0.1721093154628761, 2.8673270903527737, 27.94158596545458, 45.98798990249634, 46.672184988856316, 43.714773282408714, 46.570464447140694, 32.80621983110905, 27.08543300628662, 30.157978534698486, 31.817170903086662, 46.15249827504158, 62.75955654680729, 65.28404608368874, 89.85547319054604, 79.1443495452404, 99.10284698009491, 32.47854061424732, 0.7642276980914176, 0.2018480486003682, 0.029111430958437268, 0.15146542398724705, 0.15271842159563676, 0.13631076843012124, 0.24064558470854536, 0.13717594934860244, 0.4241425031796098, 0.14181898848619312, 0.12799947144230828, 0.11012254399247468, 0.0966947028064169, 0.06400276368367486, 0.0453797366208164, 0.05685422656824812, 0.08219898532843217, 0.062083751618047245, 0.1865571495727636, 0.22840460092993453, 0.17649640270974487, 0.048825769481481984, 0.04980173078365624, 0.009229634233633988, 0.03177688588039018, 0.025661084364401177, 0.09116022556554526, 0.03334361899760552, 0.07254831958562136, 0.05803587038826663, 0.05143034417415038, 0.048666612201486714, 0.02561852590588387, 0.024249933230748866, 0.02534902796469396, 0.06640548905124888, 0.07719699904555455, 0.21789003076264635, 0.2120958612067625, 0.09576364886015654, 0.24026655504712835, 0.22572935151401907, 0.275533635285683, 0.24435412633465603, 0.14864150754874572, 0.11662254051771015, 0.14392251701792702, 0.15979154908563942, 0.10923828245722689, 0.13540260231820866, 0.13362459460040554, 0.2899610751774162, 0.2246660171658732, 0.31934486876707524, 0.1586407155264169, 0.16737070254748687, 0.2839333814335987, 0.1468385785119608, 0.16462195082567632, 0.27116882731206715, 0.3333839279366657, 0.4325768630951643, 0.2811529696919024, 0.46575795917306095, 0.5241314065642655, 0.5053341714665294, 0.2658439474180341, 0.20396967069245875, 0.5531912972219288, 45.41992798447609, 165.86020320653915, 116.2155631184578, 141.94626241922379, 120.93504667282104, 102.22247958183289, 45.66138602793217, 22.58919697254896, 81.15742072463036, 68.47465127706528, 61.11987233161926, 56.61025911569595, 61.73109993338585, 59.441726580262184, 41.34983718395233, 7.522401725873351, 0.9356562711764127, 0.42203441786114126, 0.6244071945548058, 0.6408347224351019, 0.5565834464505315, 0.2356485411291942, 1.7505041998811066, 4.592109639197588, 9.299789126962423, 18.00815138965845, 70.53710460662842, 124.75004956126213, 112.86839112639427, 105.98908066749573, 111.04086399078369, 121.09311819076538, 119.38531503081322, 118.06808531284332, 109.66041326522827, 101.89544633030891, 106.90689101815224, 119.21326026320457, 112.36382380127907, 93.25067460536957, 88.72539103031158, 107.50174149870872, 111.39239072799683, 94.1749370098114, 89.60709571838379, 106.36547327041626, 111.9173401594162, 105.1772390305996, 116.64755433797836, 127.94652163982391, 96.35377049446106, 52.456569001078606, 96.72003284096718, 129.17183429002762, 113.0634118616581, 94.20617893338203, 109.42572265863419, 114.80042025446892, 86.56302586197853, 101.1649963259697, 103.43054875731468, 102.32046872377396, 108.99819239974022, 121.1185996234417, 127.9274770617485, 123.50915014743805, 122.17530772089958, 111.29200011491776, 108.37399989366531, 104.3114098906517, 98.70775938034058, 96.21757820248604, 100.85829198360443, 114.79840636253357, 125.21591976284981, 130.75932830572128, 124.33133482933044, 110.13330549001694, 104.44652304053307, 106.7845755815506, 116.76871463656425, 140.75718462467194, 126.07781991362572, 34.57510091364384, 1.2783728842623532, 0.33986056165304035, 0.1730886980658397, 0.20302421908127144, 0.16083423688542098, 0.3929549641907215, 4.470934616401792, 36.49352677166462, 64.66743797063828, 68.05492579936981, 54.541813507676125, 60.67362427711487, 43.69240768253803, 47.73511715233326, 38.0752868950367, 33.83811146020889, 35.86449712514877, 66.68240904808044, 77.8916783630848, 101.18659436702728, 86.77171066403389, 107.34383717179298, 49.972912073135376, 1.1086855083703995, 0.6600446510128677, 0.23870230070315301, 0.26075795001816005, 0.2927540143718943, 0.2154891681857407, 0.4083883704151958, 0.2555890695657581, 0.7802122528664768, 0.23059749888489023, 0.347269659396261, 0.24952530744485557, 0.21113575960043818, 0.14127821516012773, 0.1897122716763988, 0.129847151983995, 0.23052340286085382, 0.12787476094672456, 0.3098471893463284, 0.5025754007510841, 0.3847224684432149, 0.36719299969263375, 0.12761723570292816, 0.09783058951143175, 0.077028872910887, 0.10619929904351011, 0.25980678386986256, 0.09591232330421917, 0.1827973997569643, 0.1467081980081275, 0.19227259210310876, 0.13171708211302757, 0.09939491807017475, 0.152867934666574, 0.173422560619656, 0.22019854048267007, 0.1901326686493121], [0.09929627180099487, 0.0730353020480834, 0.054790785143268295, 0.0869220205640886, 0.019106823856418487, 0.095455026748823, 0.06424873368814588, 0.03495959361316636, 0.050610181933734566, 0.03521445825754199, 0.08538570808013901, 0.03950504775275476, 0.0033173170868394664, 0.035573594650486484, 0.06489111445262097, 0.03972473459725734, 0.10457865631906316, 0.04283123118511867, 0.03551435271219816, 0.04350192488345783, 0.05148241325514391, 0.09839448815910146, 0.10716631746618077, 0.13931124180089682, 0.20588792947819456, 0.12387865936034359, 0.24405502597801387, 0.31922606576699764, 0.06600704480661079, 0.243266390170902, 0.40092565992381424, 13.686704076826572, 104.6873389184475, 99.6110013127327, 109.30551990866661, 80.53205028176308, 54.26804959774017, 17.35216598957777, 48.821691647171974, 84.12880048155785, 59.062411934137344, 35.51956683397293, 39.51351352035999, 28.512552827596664, 33.17313194274902, 11.310703922063112, 0.7285247545223683, 0.8131833211518824, 0.0916385768505279, 0.2876424870919436, 0.06815847897087224, 0.12559332477394491, 1.3894855719991028, 6.754784490913153, 5.938985366374254, 8.255065586417913, 38.14728543162346, 94.68992337584496, 106.40852496027946, 101.00130870938301, 101.23775482177734, 110.15665143728256, 113.3249594271183, 107.82910913228989, 102.81505778431892, 102.28462904691696, 112.12086483836174, 93.76806244254112, 93.02346959710121, 101.50849789381027, 100.87160646915436, 78.53489264845848, 77.68212720751762, 78.9028725028038, 77.2265012562275, 82.93562650680542, 104.90057587623596, 105.37959337234497, 112.86321580410004, 104.76587310433388, 115.27553156018257, 92.7679181098938, 120.80336853861809, 72.73255079984665, 57.56642460823059, 98.31518724560738, 72.97676369547844, 82.15314209461212, 90.81391096115112, 62.94369086623192, 58.706610426306725, 97.7238629758358, 98.73113572597504, 104.74129602313042, 104.41982567310333, 102.04356998205185, 102.05772802233696, 109.34386745095253, 99.80716958642006, 103.40052276849747, 97.48215034604073, 96.9166798889637, 91.45092397928238, 88.83670225739479, 88.71941775083542, 91.79032936692238, 93.95351529121399, 104.62626099586487, 106.67196482419968, 109.95273917913437, 102.36675024032593, 100.71175664663315, 97.69104033708572, 96.17092430591583, 104.08700913190842, 130.04422187805176, 71.09540864825249, 7.560784416273236, 0.19872397795552388, 0.025066659327421803, 0.006526262986881193, 0.11508109237183817, 0.2400887364638038, 1.0458360495977104, 11.694185994565487, 29.53930713236332, 33.32754045724869, 55.654830783605576, 75.9945921599865, 74.85848352313042, 68.49261671304703, 38.63502725958824, 22.327742502093315, 22.357120625674725, 45.12027606368065, 39.94109317660332, 64.00783136487007, 71.78672835230827, 85.44195681810379, 39.10972818732262, 2.0055288216099143, 0.13946305552963167, 0.07483753346605226, 0.2064408443402499, 0.09310402165283449, 0.09631367676774971, 0.19145269703585654, 0.09038036194397137, 0.2033068734453991, 0.12619569635717198, 0.1513094690744765, 0.05033441470004618, 0.06798029673518613, 0.02239600937173236, 0.07824335305485874, 0.030475503954221494, 0.014096724971750518, 0.10880390342208557, 0.21484314347617328, 0.14278636313974857, 0.00559622717446473, 0.06187482962559443, 0.09305305837187916, 0.09666988538810983, 0.034628402790986, 0.1113204519788269, 0.11777873238315806, 0.06387339992215857, 0.02076773551380029, 0.010080012089019874, 0.0671742353006266, 0.06140893528936431, 0.03091864589805482, 0.04303567060560454, 0.0459531755768694, 0.1353246025973931, 0.10259843562380411, 0.08582986120018177, 0.017604416389076505, 0.058293655383749865, 0.02799919093376957, 0.09391401647008024, 0.1076992685557343, 0.034207764620077796, 0.010149997542612255, 0.011571141694730613, 0.056342961033806205, 0.03900448027707171, 0.04973157185304444, 0.04222127114189789, 0.011750926041713683, 0.0614730308734579, 0.0777453719638288, 0.04234557716699783, 0.06014276084897574, 0.032444833632325754, 0.028756823521689512, 0.1187044354446698, 0.09748057782417163, 0.1389779432793148, 0.16677287290804088, 0.18309534236323088, 0.19621332205133513, 0.378178566461429, 0.07344563549850136, 0.2788412687368691, 0.5054560024291277, 14.286114312708378, 121.33944377303123, 117.54277870059013, 123.49295541644096, 101.99941635131836, 87.55179360508919, 54.42597292363644, 43.80465365946293, 21.58971570432186, 49.72426861524582, 39.72724065184593, 43.853074461221695, 37.0417195558548, 42.9451359808445, 17.68595527857542, 1.3555998215451837, 0.5811324447859079, 0.1185505288594868, 0.31266414443962276, 0.4986384557560086, 0.5130251368973404, 2.691175192594528, 3.0324477050453424, 0.8425540232565254, 7.829457549378276, 43.71234141290188, 96.73415288329124, 109.89684417843819, 102.80400797724724, 105.7691864669323, 111.8799577653408, 117.07272112369537, 109.91482481360435, 111.20184615254402, 105.79149886965752, 115.58714523911476, 98.44936564564705, 97.66502693295479, 103.41696828603745, 104.35282766819, 83.15958648920059, 82.45207965373993, 81.94204062223434, 80.03129035234451, 85.18933117389679, 108.67211669683456, 108.55154916644096, 118.46019387245178, 111.57244026660919, 120.54872140288353, 97.8576309978962, 119.90729302167892, 77.2487984597683, 65.25730311870575, 110.76525717973709, 81.26258388161659, 89.99421894550323, 102.03857704997063, 71.29211649298668, 65.04216626286507, 106.24062716960907, 105.17813578248024, 110.65274521708488, 108.22896927595139, 106.90980926156044, 103.92759248614311, 113.61546903848648, 103.97537872195244, 107.52578660845757, 101.39668509364128, 102.12011307477951, 94.85225826501846, 95.16529306769371, 93.99195402860641, 95.59543758630753, 97.14884743094444, 108.29308703541756, 107.43016093969345, 113.53606089949608, 104.8604728281498, 104.16606768965721, 103.29720631241798, 101.1287234723568, 106.31437361240387, 137.35952854156494, 88.04338082671165, 13.781231604516506, 0.09107107878662646, 0.1243184634950012, 0.008222605702030705, 0.050222873614984564, 0.2714215434389189, 0.5852401431184262, 14.868751298636198, 38.72754089534283, 42.12278790771961, 54.21985298395157, 57.95114256441593, 45.525406524538994, 34.03309419751167, 39.929344207048416, 32.465868294239044, 36.735642179846764, 68.97591277956963, 54.800629019737244, 75.10246083140373, 81.31964921951294, 97.56352677941322, 48.20647805929184, 1.724429049063474, 0.19951105525251478, 0.08916984486859292, 0.2401167748030275, 0.16650730278342962, 0.1365796336904168, 0.32015998440328985, 0.1252841905807145, 0.20849956199526787, 0.05973345156235155, 0.06583221707842313, 0.0434560527355643, 0.09285751730203629, 0.08974954384029843, 0.033212837734026834, 0.025934649274859112, 0.0657924305414781, 0.11471760328277014, 0.164650879742112, 0.11492232471937314, 0.0672424238291569, 0.03125713759800419, 0.11398099202779122, 0.06117024204286281, 0.019201345639885403, 0.022967182922002394, 0.07871739246184006, 0.005261742608126951, 0.04746046266518533, 0.04151916233240627, 0.00897358493602951, 0.053805420830030926, 0.013388142779149348, 0.053526800038525835, 0.020713668200187385, 0.02817135249642888, 0.23638846236281097, 0.1647009895532392, 0.13985067926114425, 0.15863133477978408, 0.15673081332352012, 0.1836117435595952, 0.14069736585952342, 0.1034488774894271, 0.10693488613469526, 0.1333191859885119, 0.2010438425350003, 0.17403487698175013, 0.17672620131634176, 0.13483408751199022, 0.26640697033144534, 0.17593145021237433, 0.19684202503412962, 0.1422995439497754, 0.17736665991833434, 0.20788801746675745, 0.12354059625067748, 0.22153219470055774, 0.15887774265138432, 0.25183798803482205, 0.2971724350936711, 0.2867860486730933, 0.273053971468471, 0.449043873231858, 0.1580650167306885, 0.41455146158114076, 0.48906077281571925, 39.94832418859005, 154.39934939146042, 123.26071187853813, 143.3603185415268, 107.58428826928139, 81.50103628635406, 36.71918146312237, 75.37454143166542, 123.38049665093422, 82.23377376794815, 58.84513579308987, 63.60021963715553, 51.45250327885151, 53.641470819711685, 23.104285933077335, 2.2834183601662517, 0.8006961224600673, 0.34673522401135415, 0.5235144146718085, 0.4792237241053954, 0.2650551631813869, 3.604824529029429, 16.876180730760098, 13.275134861469269, 17.24761839956045, 44.34417150914669, 101.10613748431206, 109.11812916398048, 104.45733726024628, 107.4307157099247, 116.03258013725281, 120.90905606746674, 112.43621751666069, 113.32176759839058, 113.20326715707779, 121.53579443693161, 106.29576221108437, 100.29208436608315, 108.26004400849342, 106.48276537656784, 85.20997926592827, 85.01590847969055, 86.85227394104004, 85.04821434617043, 89.02697324752808, 113.4228877723217, 114.78158846497536, 126.15285828709602, 115.61827316880226, 126.09145358204842, 102.78564736247063, 128.38953226804733, 80.83424806594849, 79.13293495774269, 120.63528835773468, 92.0649254322052, 96.95088565349579, 109.23353657126427, 82.12816223502159, 71.76260724663734, 109.3410176038742, 107.47725561261177, 116.66196316480637, 113.20718854665756, 108.96067321300507, 108.2039362192154, 115.98259001970291, 106.52147009968758, 112.62163996696472, 104.7232773900032, 105.14867976307869, 101.28666579723358, 99.7341451048851, 99.98456686735153, 99.87696424126625, 99.28286612033844, 113.0389715731144, 114.90731611847878, 122.04530909657478, 111.09928205609322, 109.7082830965519, 105.23130252957344, 104.9490612745285, 114.05789449810982, 145.50015091896057, 83.72805878520012, 11.479879394173622, 0.25477739749476314, 0.3452278330223635, 0.1012760323646944, 0.18224997678771615, 0.46483621175866574, 2.2138274693861604, 20.58686401695013, 52.07063890993595, 58.622000366449356, 85.90582072734833, 114.77726429700851, 107.34834372997284, 92.20069974660873, 51.069240644574165, 33.12292143702507, 37.11162820458412, 62.52814516425133, 56.400202587246895, 87.18192905187607, 89.15119618177414, 108.24207857251167, 72.14110493659973, 4.097437933087349, 0.8151064929552376, 0.23696199408732355, 0.46436548233032227, 0.38498916663229465, 0.28341654979158193, 0.5314429267309606, 0.36151859792880714, 0.3773868136340752, 0.200377601722721, 0.31698967795819044, 0.2157890997477807, 0.2155765486531891, 0.2827029302716255, 0.1918332852073945, 0.07081889285473153, 0.129355909593869, 0.3938769194064662, 0.3901968168793246, 0.26110037695616484, 0.09866610678727739, 0.21254496445180848, 0.20701364876003936, 0.19079807825619355, 0.24679761787410825, 0.21247861644951627, 0.21565453353105113, 0.23685404128627852, 0.11697192137944512, 0.14456398494075984, 0.21605419489787892, 0.29503234836738557, 0.12057918211212382, 0.16161858307896182, 0.24299184005940333, 0.2652249071979895], [0.06791192266973667, 0.027823467062262353, 0.08660170962684788, 0.014120263112999965, 0.050932582016685046, 0.06775826099328697, 0.15998424030840397, 0.05282470978272613, 0.009185803919535829, 0.0395433499943465, 0.021005083617637865, 0.029395306155493017, 0.030296347649709787, 0.016586254714638926, 0.05530594695301261, 0.09501546752289869, 0.09725365875056013, 0.09056218812474981, 0.028535886158351786, 0.02304586727404967, 0.07287205924512818, 0.06681300976197235, 0.21074504853459075, 0.038381172707886435, 0.24283456412376836, 0.08430811707512476, 0.410039322450757, 0.1391360949492082, 0.3318143746582791, 0.34624101303052157, 25.335549004375935, 105.82468628883362, 104.1230919957161, 91.8076640367508, 70.85270807147026, 53.2105815410614, 27.891977727413177, 20.969313494861126, 37.6166021078825, 57.96742469072342, 33.75739239156246, 37.45689667761326, 27.837135270237923, 23.59588075429201, 5.696090050041676, 0.5436591524630785, 0.13076544099021703, 0.1897826124331914, 0.19143763143802062, 0.15181656373897567, 0.6174238817766309, 1.9629275263287127, 10.06547274067998, 2.765747378580272, 17.972689792513847, 77.9317358136177, 99.20681700110435, 97.78983503580093, 101.76480174064636, 107.01212257146835, 103.86355072259903, 102.13269799947739, 108.83669346570969, 110.87966904044151, 107.00022161006927, 99.43314045667648, 108.57126250863075, 96.42173364758492, 92.54597201943398, 94.57218289375305, 97.37659960985184, 80.67067444324493, 79.3267473578453, 78.88895004987717, 89.27093535661697, 104.87751871347427, 109.19564500451088, 99.80818033218384, 102.84218072891235, 102.38433569669724, 105.01735880970955, 103.75178351998329, 99.9294850230217, 96.16090804338455, 33.77561241388321, 98.00574705004692, 87.40215763449669, 97.85760819911957, 97.35054820775986, 51.18555620312691, 87.5908175110817, 105.37296652793884, 94.40528824925423, 93.66254210472107, 102.5152462720871, 110.41258290410042, 100.23004129529, 102.1400012075901, 104.26265090703964, 105.43651431798935, 100.19477158784866, 96.1367717385292, 90.16434341669083, 90.71798890829086, 89.62659627199173, 87.05671057105064, 84.91615623235703, 85.94727650284767, 85.2108608186245, 79.87061217427254, 77.99722149968147, 78.46111580729485, 82.62855738401413, 93.47420901060104, 98.03301438689232, 96.15206971764565, 115.94267696142197, 109.80730578303337, 30.361203029751778, 0.24654329870827496, 0.020189201713947114, 0.041494534161756746, 0.07283722283318639, 0.11203841306269169, 0.11571995535632595, 6.032208139076829, 22.17420034110546, 28.46625991165638, 32.09941975772381, 55.91463424265385, 65.80103114247322, 59.44069303572178, 37.8093733638525, 20.490810871124268, 11.321057416498661, 29.668882079422474, 45.68604290485382, 69.35864344239235, 71.79216966032982, 93.5148212313652, 66.69287368655205, 3.1474243104457855, 0.3182066517183557, 0.058385058291605674, 0.12661213026149198, 0.16138194187078625, 0.10365727997850627, 0.20368924277136102, 0.0913560189655982, 0.12764517014147714, 0.05394306695961859, 0.07247829053085297, 0.04688265245931689, 0.048808466308400966, 0.05043432262027636, 0.010828697159013245, 0.06170015774841886, 0.10549134953180328, 0.1929140748688951, 0.03642379160737619, 0.04885689886577893, 0.012191550249553984, 0.05452194956887979, 0.034426145284669474, 0.04631865362171084, 0.05537571254535578, 0.09612630674382672, 0.06599770858883858, 0.05087173332867678, 0.06095197270042263, 0.07369144223048352, 0.028040075849276036, 0.02192156549426727, 0.08171961730113253, 0.1368812721921131, 0.06933148790267296, 0.04689971814514138, 0.04365257344034035, 0.0018190191462963412, 0.02590222669823561, 0.030431962150032632, 0.08588129203417338, 0.16757394711021334, 0.08891410820069723, 0.02766382553090807, 0.0496991585532669, 0.042692761271609925, 0.05543235325603746, 0.0642203762254212, 0.05700012909073848, 0.0533792313945014, 0.028789225689251907, 0.045103646552888677, 0.047525864429189824, 0.057318295221193694, 0.06831395890912972, 0.07595978691824712, 0.022786750123486854, 0.1833238051040098, 0.06154966133181006, 0.27424476225860417, 0.10941986372927204, 0.352352510089986, 0.14856426481856033, 0.44558000285178423, 0.3966641885926947, 26.828903071582317, 124.13062199950218, 117.42017447948456, 108.54115292429924, 90.62777414917946, 77.01724648475647, 50.102979093790054, 37.232617512345314, 46.40972167253494, 68.3803403377533, 42.18078039586544, 45.932360887527466, 39.61456909775734, 33.506803438067436, 9.04631707817316, 0.3415817505447194, 0.12291869876207784, 0.09782552806427702, 0.1245463770464994, 0.5423895455896854, 0.8967488526832312, 0.6189629773143679, 3.2823275215923786, 3.0165429459884763, 22.22854882478714, 84.20097380876541, 102.68621429800987, 102.04883649945259, 102.84123837947845, 111.08675792813301, 105.7932847738266, 106.34922534227371, 109.98692974448204, 114.03650164604187, 107.151248306036, 103.94532233476639, 111.58742666244507, 100.48673272132874, 95.54994642734528, 97.89447382092476, 100.87660700082779, 84.75221022963524, 81.52630493044853, 80.86795225739479, 89.55291822552681, 110.06842777132988, 113.08105811476707, 104.3227256834507, 102.44251057505608, 104.20948415994644, 108.84379148483276, 107.4452993273735, 105.84152698516846, 98.68532538414001, 43.31058517098427, 103.09989809989929, 96.53990730643272, 105.15712291002274, 105.92158868908882, 59.96605284512043, 89.76954460144043, 110.33086448907852, 95.42838335037231, 98.53324234485626, 106.15153715014458, 116.10167562961578, 102.88345411419868, 106.3884012401104, 109.22752529382706, 113.21427136659622, 104.39014926552773, 100.74221581220627, 94.94940385222435, 97.31052115559578, 94.4267039000988, 93.96508947014809, 91.3432377576828, 89.7690050303936, 91.98702961206436, 83.40505331754684, 80.49486547708511, 81.2492997944355, 84.17214095592499, 98.70241686701775, 105.65089121460915, 98.96551474928856, 117.81461611390114, 121.96631893515587, 42.49524772167206, 0.7000636879820377, 0.014848514074401464, 0.07726677577011287, 0.022190226663951762, 0.024755389604251832, 0.22971983504248783, 6.4973074570298195, 28.508422449231148, 35.79801209270954, 36.96650639176369, 49.637321680784225, 51.6774246096611, 27.74088643491268, 26.13622684031725, 29.770754612982273, 24.100098498165607, 44.76491533219814, 54.095508456230164, 79.92171183228493, 81.26218870282173, 105.72154462337494, 80.5160303413868, 4.277599090710282, 0.49001716368366033, 0.06472641704021953, 0.04545493473415263, 0.24553975177695975, 0.1686897809850052, 0.3002147952793166, 0.07597513453220017, 0.13334177696378902, 0.04289465141482651, 0.05644033823045902, 0.051552817094489, 0.0498274350684369, 0.02154883295588661, 0.03439481180976145, 0.025440785248065367, 0.14304504613392055, 0.1540924041182734, 0.0639564314042218, 0.02513887215172872, 0.02630848019180121, 0.08693814743310213, 0.04617377897375263, 0.10314506449503824, 0.02793719006149331, 0.006848450630059233, 0.025466428305662703, 0.04206247009278741, 0.1036436393042095, 0.002994056344505225, 0.07007132007856853, 0.03531873371684924, 0.05600999647867866, 0.07638832525117323, 0.043703132250811905, 0.10430835871375166, 0.1511346932966262, 0.19144233665429056, 0.19375889125512913, 0.2687804773449898, 0.1476606703363359, 0.3310918196802959, 0.16775247815530747, 0.1305802454589866, 0.20139628846663982, 0.10411701077828184, 0.14190622052410617, 0.09257033583708107, 0.18345329503063112, 0.1499017930473201, 0.2781560586299747, 0.22694895247695968, 0.19235069572459906, 0.12404319350025617, 0.18220282072434202, 0.16983386100037023, 0.18402274494292215, 0.3584914962993935, 0.159705059195403, 0.3932320524472743, 0.27379695035051554, 0.5674987763632089, 0.32458647969178855, 0.5728922307025641, 0.4188318131491542, 51.86362981796265, 152.43225574493408, 127.01089024543762, 123.5961502790451, 95.20623967051506, 78.5897845029831, 44.84826385974884, 35.00995717942715, 66.8640848994255, 88.44818830490112, 54.06078591942787, 61.65933318436146, 49.25685189664364, 44.336921498179436, 12.252949811518192, 0.8825594640802592, 0.3841787710553035, 0.3928798291599378, 0.3075674007413909, 0.4884929407853633, 1.2771759484894574, 5.849599437788129, 28.816561214625835, 10.779524724930525, 19.246438443660736, 82.89867728948593, 104.08967658877373, 107.790617197752, 104.86607372760773, 116.4260870218277, 109.40230071544647, 110.34195989370346, 115.26952788233757, 120.02282202243805, 114.25875931978226, 106.81318804621696, 117.36418828368187, 105.89203387498856, 96.55337378382683, 102.21094340085983, 106.43382400274277, 89.93206948041916, 85.36429658532143, 84.9757294356823, 94.48654308915138, 115.1208646595478, 115.71298688650131, 105.54107710719109, 107.2845907509327, 109.34017404913902, 114.7413258254528, 111.35736420750618, 110.07596656680107, 101.11363068223, 48.774957954883575, 119.441377222538, 106.93511590361595, 114.8380534350872, 117.61510401964188, 73.67561459541321, 92.96885892748833, 114.6944211423397, 99.70913484692574, 102.85083666443825, 110.95309630036354, 122.12576597929001, 104.08944860100746, 111.3837119936943, 113.7526872754097, 119.10512566566467, 109.91366967558861, 106.4955934882164, 97.85201489925385, 99.06732648611069, 97.61182978749275, 97.15121850371361, 95.19135966897011, 96.99722036719322, 95.63610300421715, 87.47092634439468, 85.11999249458313, 87.03426137566566, 91.55005306005478, 105.10216265916824, 108.64743322134018, 104.56170246005058, 127.26841762661934, 126.04524046182632, 38.580990359187126, 0.9882646857295185, 0.08676875222590752, 0.17783871036954224, 0.1985319546656683, 0.20139980624662712, 0.4766407236456871, 11.075837574899197, 36.91946491599083, 46.02279223501682, 49.08096693456173, 83.87486010789871, 92.54117667675018, 83.62056255340576, 48.101102113723755, 31.25845268368721, 21.211465001106262, 45.41401170194149, 62.00361751019955, 88.80161494016647, 89.8704443871975, 113.48395809531212, 102.59069502353668, 12.331454548984766, 0.8351247094105929, 0.13216574006946757, 0.23409694782458246, 0.4846112709492445, 0.2270795259391889, 0.5704669514670968, 0.23629110743058845, 0.34083954349625856, 0.13512748817447573, 0.16346443793736398, 0.154560714145191, 0.10880966248805635, 0.14394386118510738, 0.13617308519314975, 0.19511253893142566, 0.32375595706980675, 0.3138739935820922, 0.12046189309330657, 0.15458318637683988, 0.15552601078525186, 0.2198742813197896, 0.14772256545256823, 0.20465115521801636, 0.13884993764804676, 0.17732349660946056, 0.15033906645840034, 0.08705661646672525, 0.24775605706963688, 0.1718877101666294, 0.18487836699932814, 0.12981138046598062, 0.20551940862787887, 0.22652493382338434, 0.13369575171964243], [0.033740675426088274, 0.10656838392606005, 0.04365972774394322, 0.05756519291026052, 0.06993670933297835, 0.040388452107436024, 0.020779517108167056, 0.13430891413008794, 0.07602893281728029, 0.02616742203827016, 0.032612829891149886, 0.016580618103034794, 0.05288715779897757, 0.03512701470754109, 0.030602780425397214, 0.06459326832555234, 0.10281837108777836, 0.10764075763290748, 0.10316580010112375, 0.08719520512386225, 0.04996671763365157, 0.17463433934608474, 0.03215573371562641, 0.13697859743842855, 0.01645576659939252, 0.341637916280888, 0.09756923478562385, 0.45597001095302403, 0.026130357327929232, 31.312740370631218, 112.07628563046455, 97.35420361161232, 100.4282234609127, 85.64596027135849, 46.19540557265282, 34.893067851662636, 42.667116299271584, 66.99638620018959, 71.01128876209259, 26.428879536688328, 35.07924646139145, 24.505249857902527, 18.24886467307806, 0.93008998548612, 0.35514438059180975, 0.11144557807710953, 0.042772620072355494, 0.42105579224880785, 0.06439099597628228, 0.636582572478801, 1.8023690418340266, 5.094426060095429, 24.895591512322426, 88.18444445729256, 126.15362584590912, 103.07272955775261, 99.55224886536598, 100.39723232388496, 104.13927912712097, 100.962885171175, 103.53259608149529, 106.09888717532158, 100.3849209845066, 97.36995756626129, 100.41063040494919, 107.42382287979126, 104.1992399096489, 97.23929017782211, 87.80556678771973, 86.389519572258, 84.85434114933014, 78.29717740416527, 73.75738620758057, 84.83496218919754, 97.00802698731422, 98.68055284023285, 101.66000336408615, 103.76453563570976, 100.4830165207386, 101.7520572245121, 95.52232950925827, 93.80249619483948, 92.29949444532394, 108.51709261536598, 72.98168823122978, 54.362592324614525, 84.04520496726036, 75.11253029108047, 77.34446972608566, 43.19456599652767, 100.64066246151924, 95.2311435341835, 98.91242399811745, 88.04581269621849, 98.70756939053535, 102.1074141561985, 105.93381643295288, 87.66797617077827, 97.85318523645401, 103.42146724462509, 100.18184468150139, 91.90795585513115, 93.15776199102402, 90.91942369937897, 89.35344412922859, 82.74233087897301, 82.87429019808769, 78.20720583200455, 86.96733176708221, 89.26577523350716, 92.53293111920357, 86.27946987748146, 83.83352592587471, 72.09359228610992, 79.47027325630188, 95.3859244287014, 97.06641465425491, 95.70649042725563, 109.44260135293007, 43.5131599009037, 0.7488325273152441, 0.048224618731183, 0.09622193989343941, 0.02252608559501823, 0.016991740085359197, 0.2460046627675183, 2.1037661377340555, 18.130694814026356, 28.419974595308304, 27.772324047982693, 45.43184794485569, 94.8066759109497, 75.56141540408134, 37.70954132080078, 41.69731333851814, 19.349580109119415, 40.97161687910557, 47.01638951897621, 62.74231307208538, 78.4225782752037, 93.50253269076347, 82.11029559373856, 17.984433062374592, 1.0961582930758595, 0.16491910675540566, 0.05196200392674655, 0.2068753124331124, 0.21753553650341928, 0.1139776968921069, 0.041716176565387286, 0.088184911001008, 0.02955284740892239, 0.07507463480578735, 0.060600614015129395, 0.04133680180530064, 0.0650275286170654, 0.0558205818379065, 0.02752224787400337, 0.05371238148654811, 0.03588609819416888, 0.009049689397215843, 0.03465529080131091, 0.026489612464501988, 0.019018697530555073, 0.037941650589345954, 0.0431070095510222, 0.03705281742441002, 0.05692288636055309, 0.031852217580308206, 0.08873567363480106, 0.03560057914000936, 0.04134910661377944, 0.06688116118311882, 0.008336848204635317, 0.050786527353920974, 0.113169772666879, 0.015469245463464176, 0.06460768825490959, 0.04116727301152423, 0.02272589030326344, 0.029922924913989846, 0.04512536550464574, 0.06572829413926229, 0.08014868362806737, 0.07935497895232402, 0.012875410575361457, 0.04469327970582526, 0.041516854253131896, 0.00456095992376504, 0.031314312655013055, 0.05607727216556668, 0.07901085991761647, 0.08001198744750582, 0.05558194054174237, 0.15996853646356612, 0.02593460103526013, 0.03174579360347707, 0.1595258156885393, 0.09487450399319641, 0.18388426018645987, 0.043052665787399746, 0.2739363256841898, 0.06004532799124718, 0.46259676630143076, 0.14441855368204415, 37.68955819308758, 131.16447776556015, 109.26238462328911, 120.44890835881233, 98.05762946605682, 69.65737581253052, 59.69310209155083, 48.150195479393005, 33.99612978100777, 60.232369154691696, 36.10420346260071, 41.96763463318348, 34.14052203297615, 24.538306184113026, 1.4343697135336697, 0.293305519153364, 0.11337347736116499, 0.1597899163607508, 0.12684083048952743, 0.17035441822372377, 0.49705818586517125, 0.5966483778320253, 6.69597172178328, 32.31404364109039, 97.16003403067589, 129.19597059488297, 107.06940829753876, 102.70857229828835, 105.57492569088936, 106.76268115639687, 103.7779413163662, 107.9133278131485, 109.2134964466095, 105.5482891201973, 102.53217816352844, 103.75448897480965, 109.0702061355114, 109.28788885474205, 101.699148863554, 92.60072708129883, 88.31750571727753, 88.36408361792564, 80.60230851173401, 78.5419450700283, 88.68950575590134, 103.30593064427376, 104.60377380251884, 102.21015304327011, 108.08993473649025, 105.36181792616844, 107.89373606443405, 101.61233872175217, 98.00416633486748, 96.967194378376, 114.69978645443916, 80.66452637314796, 60.39473444223404, 92.90959730744362, 84.94644820690155, 84.37670677900314, 51.94405250251293, 105.80070197582245, 100.5563297867775, 106.44528418779373, 91.74362227320671, 101.93285152316093, 105.93507796525955, 109.96621325612068, 91.09333276748657, 100.08287519216537, 106.6192464530468, 103.22171196341515, 95.58973029255867, 98.89553010463715, 95.95802932977676, 95.02286151051521, 87.54291728138924, 87.65840068459511, 80.97851872444153, 88.93909156322479, 95.3155218064785, 98.20386841893196, 90.33300876617432, 88.07801216840744, 75.42372599244118, 83.33027333021164, 101.97585761547089, 100.88715523481369, 99.23631861805916, 117.40891188383102, 56.29754349589348, 1.6946359165012836, 0.07763277331832796, 0.10926056915195659, 0.0955320468347054, 0.03537244294420816, 0.3586797049501911, 2.522476357407868, 22.441724985837936, 36.588141694664955, 31.078230254352093, 39.432144686579704, 75.37276312708855, 41.089429557323456, 15.353199653327465, 36.82307928800583, 37.24151663482189, 53.395312428474426, 56.62734679877758, 73.38545456528664, 88.9751972258091, 102.34616294503212, 100.33024191856384, 23.303777128458023, 0.9875931311398745, 0.04355371565907262, 0.10310486977687106, 0.30249434639699757, 0.16710122872609645, 0.1965745401685126, 0.049331127520417795, 0.08156739539117552, 0.07628317034686916, 0.06493870096164756, 0.04771685984451324, 0.037972416321281344, 0.07807703776052222, 0.04591037592035718, 0.012739849880745169, 0.06824988930020481, 0.058847327236435376, 0.03129788521619048, 0.0640954653499648, 0.026040297707368154, 0.08383027045056224, 0.043277989243506454, 0.04371596769487951, 0.04020274449430872, 0.03467827511485666, 0.08149008586769924, 0.05441912871901877, 0.020847670384682715, 0.06512452731840312, 0.056588519146316685, 0.04516214263276197, 0.054617686619167216, 0.06505263547296636, 0.17845764668891206, 0.21970164292724803, 0.17626853368710726, 0.11524601985001937, 0.15331678558140993, 0.20765311288414523, 0.13962300319690257, 0.2176076138857752, 0.29212140769232064, 0.14257082861149684, 0.22291814064374194, 0.1681109206401743, 0.11340973869664595, 0.20675860228948295, 0.19011033000424504, 0.130303246260155, 0.14529698935803026, 0.21742029581218958, 0.47533798730000854, 0.21849566779565066, 0.1531172517570667, 0.3266119788167998, 0.2852270338917151, 0.2578642271691933, 0.0752243037277367, 0.43388369609601796, 0.1457649579970166, 0.6077666999772191, 0.2795754309045151, 64.46768268942833, 155.68384766578674, 119.22256216406822, 135.05055963993073, 109.3528425693512, 69.5048139989376, 52.105980813503265, 60.00153534114361, 101.00063234567642, 103.86272996664047, 46.31566911935806, 59.79490242898464, 45.99851533770561, 32.74305582046509, 3.124057464301586, 0.7267326163128018, 0.2237179531948641, 0.5379396874923259, 0.4036907240515575, 0.2454308490268886, 0.9821141220163554, 4.904335085302591, 10.636592544615269, 30.024383403360844, 96.78310945630074, 135.7013127207756, 108.49191516637802, 107.80877262353897, 109.58372578024864, 112.8769862651825, 105.87934255599976, 110.40670841932297, 112.7594205737114, 110.70083543658257, 104.9367955327034, 112.41622298955917, 114.10501196980476, 113.033317476511, 106.27645924687386, 97.42263033986092, 92.33142793178558, 93.30951824784279, 83.73733028769493, 81.2723721563816, 92.46078819036484, 107.21105709671974, 109.70449849963188, 108.5339181125164, 112.73535266518593, 111.41078934073448, 115.71060821413994, 108.12554642558098, 103.54873761534691, 104.88020896911621, 118.36532056331635, 83.97408798336983, 69.43853795528412, 104.94141608476639, 93.99598941206932, 96.00823983550072, 58.1771544367075, 108.09255659580231, 106.39731556177139, 112.94537499547005, 97.68968001008034, 108.22703137993813, 114.33982416987419, 113.18876713514328, 89.32982459664345, 101.34770572185516, 109.68293085694313, 106.05324402451515, 98.38579505681992, 102.99274384975433, 103.30314919352531, 98.24681371450424, 91.90504521131516, 90.76394364237785, 84.09221604466438, 95.43556496500969, 100.19547834992409, 102.72552698850632, 93.80813509225845, 89.96720999479294, 78.79651620984077, 88.40267434716225, 106.36347457766533, 105.79361155629158, 105.85462868213654, 121.69479310512543, 50.49299776554108, 1.6691499715670943, 0.16502720798598602, 0.2237241723923944, 0.2507213526405394, 0.1561059249797836, 0.5194064788520336, 4.632867202162743, 34.86880995333195, 52.046726793050766, 50.141756013035774, 62.33105354011059, 133.85988593101501, 105.79993441700935, 49.77725677192211, 57.11476944386959, 31.52832370251417, 57.78399333357811, 64.08587917685509, 87.63414278626442, 95.90414822101593, 107.9264523088932, 122.0254285633564, 36.029203087091446, 1.6600082558579743, 0.43949255137704313, 0.1961482802289538, 0.42833994200918823, 0.3599573270184919, 0.32422633026726544, 0.2517208771314472, 0.25722321937792003, 0.1777607254916802, 0.21891794982366264, 0.21089707006467506, 0.17039859085343778, 0.26090866536833346, 0.2352514475933276, 0.1352255407255143, 0.32081411336548626, 0.17123954807175323, 0.08006994175957516, 0.11027575295884162, 0.08864650459145196, 0.2504708926426247, 0.10331750992918387, 0.17093467380618677, 0.0640471515362151, 0.130630221683532, 0.19393098045838997, 0.16198560479097068, 0.11846144145238213, 0.10521523348870687, 0.12042199523421004, 0.08331486373208463, 0.11044388651498593, 0.19818482251139358], [0.07654012413695455, 0.0219452622695826, 0.11751964862924069, 0.06427432294003665, 0.043553062569117174, 0.041104505871771835, 0.038181060008355416, 0.025490841253485996, 0.027019103290513158, 0.015543994577456033, 0.01384785780828679, 0.0422764424001798, 0.06652847776422277, 0.04422256512043532, 0.037567678664345294, 0.04813851475773845, 0.077513473079307, 0.05901631055166945, 0.11274133823462762, 0.01495616908869124, 0.04651192371966317, 0.08847009608871303, 0.0690352002857253, 0.03985793155152351, 0.05618546616460662, 0.030187669399310835, 0.3054579795571044, 0.0750454758235719, 33.37086193263531, 124.7122871875763, 112.84874618053436, 106.61629781126976, 70.7259164750576, 62.31269292533398, 34.95059296488762, 26.785982474684715, 52.748518735170364, 101.06485649943352, 49.56865556538105, 38.80994327366352, 32.93559528887272, 14.104564804583788, 0.5987567896954715, 0.06154946837341413, 0.06253881059819832, 0.09048106396221556, 0.5252013460267335, 0.037897826769039966, 0.5446341563947499, 2.012145691551268, 24.85647641122341, 90.9390914440155, 127.50273585319519, 114.21038791537285, 95.47737792134285, 103.78911271691322, 105.59455543756485, 99.98996257781982, 102.99661204218864, 100.7818552851677, 95.24372845888138, 89.84680205583572, 89.82839584350586, 88.96249070763588, 91.02979257702827, 96.32692113518715, 105.91085806488991, 103.68776455521584, 95.55386781692505, 85.51670640707016, 79.63393047451973, 74.43274676799774, 74.35257866978645, 92.12575256824493, 102.88505762815475, 106.54358491301537, 101.64545774459839, 96.43032878637314, 92.0319052040577, 84.36457023024559, 88.74160096049309, 80.59216305613518, 86.62806317210197, 89.05988708138466, 97.45071843266487, 50.6676933914423, 72.52202689647675, 90.87536126375198, 43.999932780861855, 89.80248123407364, 105.5289101600647, 99.41453665494919, 95.24838700890541, 85.47306194901466, 85.60173064470291, 98.27202156186104, 99.53788563609123, 101.96305230259895, 93.07745710015297, 102.47616156935692, 99.93965327739716, 95.58560371398926, 90.23828744888306, 93.00006285309792, 86.53595611453056, 80.32997712492943, 78.07745799422264, 81.29310384392738, 90.35800382494926, 99.32091727852821, 100.36546602845192, 93.8772913813591, 91.78395330905914, 90.21548107266426, 78.15101444721222, 76.87039956450462, 87.33024269342422, 93.1999397277832, 90.23164540529251, 95.96559092402458, 34.83119197189808, 1.0192880616523325, 0.3445989964529872, 0.06092918505601119, 0.08025803908822127, 0.06455907016061246, 0.08099770057015121, 0.04692951908509713, 6.913647316396236, 24.844626747071743, 27.306820526719093, 38.92911247909069, 60.40978543460369, 76.98831483721733, 43.834732845425606, 30.606219582259655, 18.926119431853294, 42.99619764089584, 53.452601954340935, 70.17741590738297, 71.19567006826401, 82.98851206898689, 89.62326765060425, 41.22181445360184, 2.082754927687347, 0.337060290039517, 0.035060700101894327, 0.14379053347511217, 0.07986278607859276, 0.007191582608356839, 0.05596078095550183, 0.05304320548020769, 0.05728512493078597, 0.03530509304255247, 0.03345724180690013, 0.028078391078452114, 0.04758962233609054, 0.04012603239971213, 0.03179516497766599, 0.016779686229710933, 0.03297735427622683, 0.021435468042909633, 0.06952849100343883, 0.04390071793750394, 0.09428837060113437, 0.034626903652679175, 0.04055017350765411, 0.01305484425756731, 0.08286642099847086, 0.05622606535325758, 0.05499639344634488, 0.043371941428631544, 0.09843149906373583, 0.05376376779167913, 0.032799862237880006, 0.09058838593773544, 0.05806408684293274, 0.0063486415365332505, 0.07653143358766101, 0.03023304987436859, 0.013863813983334694, 0.030999335904198233, 0.06125108790001832, 0.016526203835383058, 0.04471183339774143, 0.03035471756447805, 0.046228887149482034, 0.027129965310450643, 0.022240356884140056, 0.009379744733450934, 0.01672299356869189, 0.06565292904269882, 0.1119426240620669, 0.082257273606956, 0.057800680078798905, 0.031049599710968323, 0.05240789738309104, 0.0457666478905594, 0.13393665285548195, 0.02282357178046368, 0.016866697478690185, 0.02165475598303601, 0.33364281873218715, 0.09482734792982228, 39.15608949959278, 145.77513456344604, 121.44965305924416, 123.79130780696869, 82.74490714073181, 87.46540904045105, 56.12148754298687, 37.89476618170738, 35.410630479454994, 70.89010566473007, 53.65881688892841, 44.232047125697136, 44.36039663851261, 18.346002660691738, 0.06613251971430145, 0.15578763268422335, 0.07425482879625633, 0.15950690576573834, 0.6719169358257204, 0.3041528386529535, 0.20239179051714018, 2.2363405488431454, 33.005959913134575, 104.56426352262497, 135.2349105477333, 116.71265244483948, 98.618084192276, 107.880489975214, 111.02772429585457, 104.55865502357483, 105.84794864058495, 108.2048025727272, 98.17685186862946, 95.30550554394722, 92.18988552689552, 90.45777127146721, 94.10660147666931, 101.98368519544601, 107.58080005645752, 107.6936312019825, 98.84536519646645, 89.28633973002434, 83.75223308801651, 78.14855977892876, 76.17092549800873, 94.23748165369034, 104.08155262470245, 109.82773348689079, 106.45343095064163, 99.89646479487419, 96.09967812895775, 88.50890904664993, 90.80753490328789, 83.22563454508781, 89.09447282552719, 93.2382644712925, 101.02463185787201, 60.88050797581673, 79.03759807348251, 97.96073466539383, 53.10209356248379, 92.05243930220604, 108.25726255774498, 102.46648728847504, 98.7238097190857, 89.77528989315033, 91.52249693870544, 104.36717569828033, 102.93441697955132, 105.4074914753437, 95.40506780147552, 108.77277329564095, 106.2258231639862, 101.5443603694439, 95.21469041705132, 95.67540809512138, 92.4059647321701, 83.67895022034645, 82.57744252681732, 86.45515725016594, 95.75238436460495, 104.24613699316978, 105.62620773911476, 100.80641716718674, 95.46201154589653, 94.11996155977249, 83.01852285861969, 78.86792957782745, 91.13179430365562, 100.43993443250656, 95.49339786171913, 103.4191645681858, 44.55175057053566, 1.7618366167880595, 0.20073482708539814, 0.1747226103907451, 0.20064752083271742, 0.07704413888859563, 0.17862740554846823, 0.10720709848101251, 8.237007055431604, 33.3026821911335, 33.9266125112772, 42.27071397006512, 59.122764095664024, 45.03109484910965, 25.15313409268856, 30.522603169083595, 31.66043311357498, 54.98843394219875, 67.10902735590935, 81.67329624295235, 83.66777122020721, 93.44137877225876, 105.87005585432053, 53.632818683981895, 2.3073276272043586, 0.25856324122287333, 0.08091147043160163, 0.14454874122748151, 0.057003183028427884, 0.06442404381232336, 0.11226352129597217, 0.03623520446126349, 0.041227594774682075, 0.04806123863090761, 0.021703889869968407, 0.015434630768140778, 0.022273282265814487, 0.08521547424606979, 0.033189990717801265, 0.02003017987590283, 0.04217331355903298, 0.05145955139596481, 0.03637912916019559, 0.04836982363485731, 0.11444294927059673, 0.045618871445185505, 0.029732990769844037, 0.022796531629865058, 0.05510338887688704, 0.03405905677936971, 0.12524124991614372, 0.03887854894855991, 0.022844448394607753, 0.09041278637596406, 0.09453742051846348, 0.035632528597489, 0.17440877098124474, 0.07487212496926077, 0.1983198637026362, 0.34722236974630505, 0.17491550941485912, 0.10836124944034964, 0.14996834885096177, 0.14640660403529182, 0.11594435854931362, 0.18026296544121578, 0.15253153396770358, 0.12377466962789185, 0.14704185276059434, 0.14619063906138763, 0.15032808267278597, 0.1495494064874947, 0.1951507298508659, 0.274354214197956, 0.12385531881591305, 0.08404432810493745, 0.3043609665473923, 0.1328126701992005, 0.4132572450907901, 0.14113904762780294, 0.1037243330210913, 0.17711747641442344, 0.44328480726107955, 0.20665066433139145, 68.49853679537773, 163.34244310855865, 135.2952665090561, 141.22652024030685, 94.79009360074997, 88.31236079335213, 53.747648522257805, 43.62005956470966, 80.20833045244217, 143.1253543496132, 77.25652724504471, 69.71969246864319, 56.19305670261383, 24.056429341435432, 1.0914154350757599, 0.1661185806733556, 0.2654145110864192, 0.2459392201853916, 0.7654864399228245, 0.43861138459760696, 1.146340062841773, 6.121245436370373, 29.87563468515873, 107.08997279405594, 144.63884353637695, 124.46111306548119, 101.04447439312935, 112.40961134433746, 116.38116583228111, 111.53492867946625, 109.18910175561905, 112.88131043314934, 105.0161124765873, 101.9786162674427, 98.1198625266552, 97.32102379202843, 101.37712374329567, 109.42896008491516, 113.21351140737534, 114.66016218066216, 102.3215402662754, 95.16383394598961, 87.36238896846771, 82.96945229172707, 80.4147581756115, 99.62541773915291, 108.92402797937393, 114.13196012377739, 109.14350420236588, 108.207196444273, 101.2225404381752, 94.19461235404015, 96.40255987644196, 89.01366636157036, 93.95855382084846, 99.3429408967495, 102.4802577495575, 68.178571164608, 86.88964113593102, 107.21099629998207, 64.16000559926033, 94.19383719563484, 115.04943609237671, 108.85526686906815, 103.10978516936302, 92.44889482855797, 96.00022986531258, 109.60631176829338, 110.54469421505928, 109.01739656925201, 96.85131579637527, 112.20550909638405, 112.07465931773186, 104.87808868288994, 99.18676927685738, 100.55826008319855, 97.5589594244957, 88.80070298910141, 88.13617184758186, 91.73670664429665, 100.75320482254028, 107.56074473261833, 112.01193988323212, 102.56297931075096, 101.3186676800251, 101.83285608887672, 88.2755559682846, 82.45010375976562, 96.81161552667618, 104.2973430454731, 102.40027204155922, 107.98658028244972, 41.38280041515827, 3.0817949445918202, 0.631900392472744, 0.228161888953764, 0.21595951169729233, 0.182008110859897, 0.5050102388486266, 0.28975855791941285, 12.246237471699715, 42.624824568629265, 51.46456763148308, 57.744011878967285, 88.76483291387558, 108.33543956279755, 60.828222781419754, 42.11114153265953, 28.642443157732487, 60.30266918241978, 72.68803238868713, 92.79705494642258, 92.56152078509331, 99.7365389764309, 119.55949768424034, 71.1651349067688, 4.334846818819642, 0.3638312191469595, 0.18584210512926802, 0.3513284947257489, 0.24223047075793147, 0.19910989474738017, 0.1766739392769523, 0.1762498909374699, 0.07899388700025156, 0.13712359825149179, 0.10457619238877669, 0.11706005883752368, 0.11650920714600943, 0.16404944326495752, 0.13005312765017152, 0.15858967060921714, 0.17699990537948906, 0.08067109622061253, 0.22646198485745117, 0.15323215106036514, 0.28182942245621234, 0.11859367732540704, 0.1117877675278578, 0.13086135615594685, 0.19159002404194325, 0.12208929678308778, 0.14211112749762833, 0.2246227499563247, 0.20658568188082427, 0.14102429675403982, 0.2076666645007208, 0.28430392092559487], [0.05463406581839081, 0.05646000514389016, 0.012295708820602158, 0.048866005017771386, 0.024297705276694614, 0.06470259409979917, 0.04629094182746485, 0.04719023185316473, 0.05088374498882331, 0.03420879249460995, 0.019845335009449627, 0.013467961689457297, 0.035696650156751275, 0.04562815200188197, 0.029194429043855052, 0.053041194260003977, 0.08663973727379926, 0.030307721062854398, 0.05260320096567739, 0.0246264340239577, 0.04147839987126645, 0.060119553891127, 0.07727944423095323, 0.15093029098352417, 0.13688922801520675, 0.421021148795262, 0.605737668229267, 20.228547044098377, 120.02770096063614, 108.90697449445724, 108.57515349984169, 81.41292661428452, 73.25752303004265, 28.15100982785225, 36.93294659256935, 69.23882067203522, 82.5160302221775, 50.72568207979202, 34.735068529844284, 28.080227226018906, 9.197967890650034, 0.5841450893785805, 0.020095127074455377, 0.15556151513010263, 0.40888142364565283, 0.065279168629786, 0.9121173061430454, 0.4159699729643762, 0.7496204506605864, 58.20832796394825, 128.8250496983528, 108.5531222820282, 93.88176754117012, 95.43762445449829, 103.61743032932281, 99.88614454865456, 101.87047407031059, 99.34343487024307, 99.22659114003181, 92.07969143986702, 90.30905485153198, 80.79132556915283, 77.9735715687275, 72.82192960381508, 81.71165138483047, 94.20711368322372, 100.88402420282364, 97.74922281503677, 94.04169335961342, 79.66545358300209, 74.30783987045288, 70.06501033902168, 79.52192768454552, 91.21668174862862, 98.77845078706741, 95.81646412611008, 95.92683300375938, 84.07023042440414, 85.93783780932426, 85.34651353955269, 85.62633812427521, 74.37784731388092, 79.03920918703079, 87.0600163936615, 98.72122585773468, 75.47770589590073, 33.42559799551964, 57.773980870842934, 55.08283227682114, 99.07744154334068, 89.67771112918854, 98.92714440822601, 90.17716392874718, 91.56041130423546, 82.59482279419899, 90.99849745631218, 92.9243329167366, 100.17600059509277, 93.66758823394775, 94.50925827026367, 94.8869276046753, 93.90076652169228, 87.15292140841484, 86.1670795083046, 83.45653295516968, 78.09023290872574, 73.89030307531357, 80.4018160700798, 95.3788948059082, 104.51560333371162, 96.33034855127335, 105.0456976890564, 100.30940383672714, 89.2303079366684, 87.6445922255516, 85.83349540829659, 81.17986992001534, 84.19819995760918, 96.73475325107574, 96.96488410234451, 78.4356115758419, 20.228757932782173, 0.9161657514050603, 0.10003360293922015, 0.04612697543052491, 0.07095673936419189, 0.13878828001907095, 0.040228827274404466, 0.18215446238173172, 3.018561350181699, 22.071079574525356, 26.14873766899109, 49.753926023840904, 85.30957192182541, 126.33099272847176, 64.07416820526123, 28.877922222018242, 12.389512583613396, 26.21703900396824, 38.42848554253578, 67.79429018497467, 74.78982880711555, 72.04001516103745, 90.52486807107925, 69.63339909911156, 6.336748022586107, 0.34044023836031556, 0.1004382292740047, 0.06225672768778168, 0.07138650224078447, 0.08538034235243686, 0.05221886494837236, 0.03822075006610248, 0.04474045432289131, 0.07291034664376639, 0.013110152813169407, 0.025094625307247043, 0.11622516496572644, 0.01757997746608453, 0.046337125677382573, 0.014431903910008259, 0.0232232702546753, 0.0696125540707726, 0.03318844705063384, 0.03242933758883737, 0.06655554388999008, 0.014683984572911868, 0.06260612339247018, 0.10491700886632316, 0.010506214512133738, 0.05609854582871776, 0.044272812228882685, 0.08203183140722103, 0.11772847414249554, 0.04859252359892707, 0.02193705782701727, 0.03256482035794761, 0.050114427285734564, 0.04301681634387933, 0.09994426320190541, 0.11071739761973731, 0.010387026522948872, 0.01651825543376617, 0.03437395746004768, 0.05202259657380637, 0.04371323659142945, 0.03213979238353204, 0.05109580255520996, 0.048201029567280784, 0.03610425250371918, 0.05829830493894406, 0.011978142902080435, 0.013051366368017625, 0.02044510536507005, 0.03408226744795684, 0.03777798847295344, 0.032791186531540006, 0.035542290861485526, 0.01406306857461459, 0.10802339413203299, 0.08249171063653193, 0.46364212583284825, 0.7324615807738155, 26.78505152463913, 147.52816289663315, 117.4323034286499, 134.4922176003456, 93.43527629971504, 95.857213139534, 46.99186943471432, 30.964789241552353, 17.21945621073246, 50.07734566926956, 53.432193249464035, 38.22087228298187, 40.647866651415825, 13.751621693372726, 0.5014263780321926, 0.07853443079511635, 0.2093789476202801, 0.26321523066144437, 0.7376806007232517, 2.732590832747519, 0.07478811385226436, 2.200666875578463, 68.2242751121521, 136.78671687841415, 110.54431423544884, 101.3660891354084, 101.35752439498901, 110.68837210536003, 102.23880350589752, 106.91510617733002, 101.760713160038, 102.9337178170681, 94.81359913945198, 92.81270250678062, 83.94789978861809, 83.28810319304466, 76.85153737664223, 86.79125681519508, 97.23604515194893, 104.60851594805717, 104.01891678571701, 100.32176077365875, 83.65380316972733, 79.33084353804588, 73.69723543524742, 84.78912904858589, 96.11476331949234, 102.43520736694336, 97.13393703103065, 100.36189422011375, 86.27472773194313, 89.3147774040699, 90.69548651576042, 90.7758978009224, 79.8607175052166, 82.66593217849731, 90.95606133341789, 103.16788405179977, 82.49498695135117, 42.38420248031616, 64.79337841272354, 60.551510229706764, 103.68220165371895, 92.21026003360748, 101.79586887359619, 94.2600904405117, 95.59256494045258, 85.10591804981232, 93.84371638298035, 97.68902644515038, 103.37596848607063, 97.22930431365967, 95.88938221335411, 101.1015397310257, 99.40488517284393, 91.73447236418724, 92.13965982198715, 87.73425221443176, 82.61863991618156, 77.82281085848808, 84.79995086789131, 99.95213940739632, 105.72823986411095, 98.9297890663147, 108.95441874861717, 107.62287899851799, 94.7492989897728, 91.52419924736023, 92.40833580493927, 85.44776290655136, 86.99538946151733, 100.26107043027878, 104.13709044456482, 84.84293416142464, 25.168787352740765, 1.2698878208175302, 0.44348756200633943, 0.07857242875616066, 0.15589831658871844, 0.11681205534841865, 0.0323544585990021, 0.16454228869406506, 2.9586274037137628, 26.276450715959072, 32.2730628401041, 39.98458184301853, 95.83392038941383, 105.16615882515907, 25.032967440783978, 25.464531183242798, 32.27015219628811, 49.804220125079155, 50.66506013274193, 75.87372064590454, 86.44180476665497, 82.39274203777313, 103.81015598773956, 87.65270099043846, 8.7625977024436, 0.4560382885392755, 0.038240513458731584, 0.14585878030629829, 0.02058189802482957, 0.06569488265085965, 0.03759358703973703, 0.0950472240219824, 0.03341514719068073, 0.06064932116714772, 0.04234667183482088, 0.07904182231868617, 0.07485633948817849, 0.03659459689515643, 0.00487626229187299, 0.02880134867154993, 0.010811587872012751, 0.053664646547986194, 0.041784053391893394, 0.022923746873857453, 0.06859938890556805, 0.09440327732590958, 0.011883572879014537, 0.08905430731829256, 0.07769889867631719, 0.06177802388265263, 0.055868324197945185, 0.13346172287128866, 0.05380638191127218, 0.0322330877679633, 0.04564459799439646, 0.1389336964348331, 0.13696826674276963, 0.08788835621089675, 0.2624602586729452, 0.22445468319347128, 0.10436138516524807, 0.1341330845025368, 0.1288107130676508, 0.10956718746456318, 0.13831312739057466, 0.09064885613042861, 0.16823448822833598, 0.16902046714676544, 0.21799767186166719, 0.14359183085616678, 0.14015534572536126, 0.14416843507206067, 0.11358438088791445, 0.16089216893306002, 0.12024754600133747, 0.1958363110315986, 0.23577933723572642, 0.41028188599739224, 0.1754616410471499, 0.31726658809930086, 0.5915854463819414, 1.1279558180831373, 46.89107224345207, 172.13114351034164, 127.83342450857162, 143.70666235685349, 101.28427952528, 105.27771323919296, 41.19769714772701, 58.762520626187325, 98.15513983368874, 118.3523328602314, 81.4383016526699, 58.5448607057333, 49.86738033592701, 17.457617931067944, 1.0860786214470863, 0.1768497985904105, 0.41902082331944257, 0.4551068338332698, 0.23970752488821745, 2.152103343978524, 1.2547959806397557, 2.876510010100901, 64.64702546596527, 143.8494434952736, 121.56712755560875, 102.55181550979614, 104.66957107186317, 116.31434261798859, 107.24213182926178, 112.5489954650402, 106.61176085472107, 106.63908138871193, 99.25958096981049, 98.62860202789307, 88.15667554736137, 87.91876271367073, 83.67079585790634, 91.31169945001602, 104.27415668964386, 108.87960836291313, 107.87669777870178, 106.54060587286949, 88.67308303713799, 82.76814669370651, 77.54384502768517, 89.96746078133583, 100.30091509222984, 106.0663229227066, 103.02137911319733, 107.17377349734306, 93.00597533583641, 95.33572912216187, 95.61085715889931, 95.60583382844925, 83.26294094324112, 89.59074899554253, 98.32963407039642, 112.38535344600677, 87.13897615671158, 51.516830027103424, 76.19806364178658, 63.3682344853878, 106.93367958068848, 99.82842564582825, 107.85050958395004, 99.34614792466164, 100.42082905769348, 90.58435767889023, 98.96505117416382, 104.20340448617935, 108.05472582578659, 97.2991293668747, 98.5203306376934, 103.99418011307716, 104.8922011256218, 95.51685780286789, 96.74813613295555, 93.42978939414024, 87.2394959628582, 83.1005908548832, 87.2749936580658, 105.71218952536583, 112.40399524569511, 104.69828233122826, 111.26552313566208, 110.05280300974846, 98.31438168883324, 97.66650125384331, 95.95134168863297, 87.71009311079979, 92.91231036186218, 107.32459500432014, 107.75295361876488, 85.76600342988968, 26.126123182475567, 3.903697016648948, 0.8022510702721775, 0.20107682357775047, 0.2378942651557736, 0.2233583974884823, 0.2009808787261136, 0.27669171220622957, 5.450328262522817, 34.9761313945055, 47.007509395480156, 71.51040717959404, 98.58554273843765, 150.94864815473557, 87.97296300530434, 40.34926727414131, 21.59699611365795, 42.27803997695446, 55.50633855164051, 86.95045307278633, 98.31115186214447, 92.21811801195145, 109.96372818946838, 104.13927912712097, 11.574928443878889, 0.8498556877020746, 0.19132863963022828, 0.185173058998771, 0.1323120025335811, 0.22348471102304757, 0.21677418204490095, 0.14670050935819745, 0.12837768474128097, 0.2475346002029255, 0.18900610331911594, 0.13792522164294496, 0.23500751849496737, 0.10313999562640674, 0.18332708539674059, 0.11419015150750056, 0.14084238151554018, 0.1127244766394142, 0.08671460513141938, 0.12494338152464479, 0.15527935058344156, 0.11967753947828896, 0.12347611846053042, 0.1950910611776635, 0.15594752097968012, 0.21711074601626024, 0.41082041803747416, 0.19480684830341488, 0.22845457715447992, 0.18462599226040766, 0.09336805553175509], [0.047174305364023894, 0.0459908432821976, 0.03488035450573079, 0.016152838616108056, 0.05406342475907877, 0.0598932099819649, 0.07013788330368698, 0.03423585119890049, 0.08291962556540966, 0.08318990832776763, 0.05523527222976554, 0.060037728399038315, 0.05706120042304974, 0.05687265409505926, 0.04236792694428004, 0.0078041828419372905, 0.04439709227881394, 0.03255597395764198, 0.03692356127430685, 0.05355793684429955, 0.03337375390401576, 0.07468177151167765, 0.09985336495446973, 0.13320292113348842, 0.11367995466571301, 0.46649001364130527, 14.09814789891243, 108.693927526474, 107.70790323615074, 101.16903930902481, 58.46310429275036, 70.55553361773491, 31.78661484271288, 32.252467945218086, 53.65176446735859, 88.95124331116676, 54.72925364971161, 40.26150718331337, 30.51673248410225, 6.661888975650072, 0.6678177870344371, 0.11050385204725899, 0.13714374013943598, 0.03866019054839853, 0.14475783391389996, 2.3101596627384424, 2.476560571230948, 1.6487344983033836, 70.91856613755226, 133.3392682671547, 95.81112921237946, 100.12460455298424, 102.31191918253899, 95.62512159347534, 86.82404145598412, 95.40822923183441, 92.66051307320595, 93.03278669714928, 90.0394669175148, 87.20924198627472, 77.56552666425705, 74.94872868061066, 74.35008600354195, 73.70400667190552, 71.83161914348602, 84.24550741910934, 95.86389318108559, 101.95030018687248, 95.52300587296486, 77.76839777827263, 70.26453003287315, 71.02828904986382, 83.6133125424385, 97.73975372314453, 98.12515944242477, 96.13901361823082, 86.47048562765121, 75.27028262615204, 79.95531722903252, 94.93347510695457, 91.65251076221466, 86.86760991811752, 73.37840974330902, 82.82048508524895, 85.95140308141708, 106.09619691967964, 46.133791878819466, 22.281462885439396, 84.02771070599556, 97.10177555680275, 93.88967871665955, 85.35170406103134, 85.63523724675179, 80.95434442162514, 83.00210773944855, 80.5483666062355, 91.5548788011074, 95.23482173681259, 97.46794670820236, 89.33897450566292, 93.87422114610672, 94.11872282624245, 89.19349551200867, 85.50993517041206, 81.10474035143852, 75.23245185613632, 72.33226507902145, 83.26843544840813, 93.72691825032234, 93.54290172457695, 93.0812568962574, 96.16366669535637, 97.90469527244568, 103.28513815999031, 97.9769217967987, 93.92241775989532, 95.12362450361252, 91.92399859428406, 89.92578461766243, 103.4035550057888, 90.62769815325737, 50.28980366885662, 4.381275102496147, 0.43967693054582924, 0.10658704894012772, 0.06354409415507689, 0.026098444977833424, 0.03610295745602343, 0.026322018820792437, 0.1166022798861377, 0.9479491459205747, 17.820040583610535, 28.534641042351723, 36.2050424516201, 34.315141662955284, 79.59847077727318, 59.33916628360748, 25.229388400912285, 15.464486181735992, 18.59024215489626, 44.84141282737255, 59.188245981931686, 91.02931380271912, 72.15340867638588, 90.11057630181313, 73.64373430609703, 2.784319594502449, 0.058556449876050465, 0.09684808246674947, 0.0491114443866536, 0.0463378938002279, 0.005777704081992852, 0.023690968009759672, 0.02980814992042724, 0.009449419412703719, 0.013353144022403285, 0.046560400805901736, 0.02953123977931682, 0.05482719490828458, 0.09106293742661364, 0.0167167947802227, 0.05176018428755924, 0.01734776873490773, 0.0413914312957786, 0.044729811925208196, 0.014782589096284937, 0.025419773191970307, 0.022807960704085417, 0.040533712672186084, 0.07880620527430438, 0.05925010933424346, 0.05400048692536075, 0.011986516183242202, 0.07382180789136328, 0.04036434715089854, 0.029447644265019335, 0.01496251445132657, 0.08006742587895133, 0.060756338862120174, 0.030671158201585058, 0.018775577373162378, 0.052262024546507746, 0.06542866685776971, 0.03149377509544138, 0.049701232856023125, 0.015114364359760657, 0.059020711487391964, 0.03187958056514617, 0.176407226244919, 0.06135811301646754, 0.06668047702987678, 0.02629331069329055, 0.02300320120411925, 0.01834616701671621, 0.04433639202034101, 0.03251636553613935, 0.06932281219633296, 0.026720869391283486, 0.1392311937524937, 0.12182719248812646, 0.11082002922194079, 0.4506762122036889, 18.608120195567608, 132.7884802222252, 117.646763920784, 119.93964448571205, 84.55164179205894, 103.03401723504066, 55.6930985301733, 38.975739777088165, 25.454944297671318, 77.25560009479523, 48.76487709581852, 42.58990824222565, 42.91098341345787, 10.225275065749884, 0.6237917463295162, 0.0021465060717673623, 0.03685588111693505, 0.16132813616422936, 0.6482887943275273, 7.163388915359974, 1.223394584376365, 2.8846382489427924, 82.27788180112839, 133.89292895793915, 96.77129209041595, 106.48482486605644, 103.96769553422928, 99.01589244604111, 89.60261195898056, 98.24196517467499, 97.30837047100067, 96.00348249077797, 94.19094175100327, 91.51322543621063, 81.65952578186989, 80.19918814301491, 78.11510637402534, 77.55354210734367, 76.23630478978157, 90.92843681573868, 100.47592610120773, 107.56231024861336, 99.39886629581451, 83.86751130223274, 74.80033904314041, 73.3771938085556, 86.49330720305443, 103.06281208992004, 98.36193233728409, 100.97495332360268, 91.25331178307533, 78.1690862774849, 83.43574047088623, 100.00656768679619, 97.25807636976242, 89.25666332244873, 75.70582285523415, 88.88691276311874, 90.60844078660011, 110.78489452600479, 52.96717420220375, 28.405884951353073, 88.44099909067154, 99.88476902246475, 97.52910062670708, 92.0084984600544, 89.48214322328568, 83.87532368302345, 85.60812190175056, 85.26890650391579, 95.38161545991898, 101.70067638158798, 101.4580138027668, 93.22569474577904, 99.374760389328, 98.80303546786308, 93.93587663769722, 88.80451798439026, 84.62841287255287, 80.08145526051521, 75.25803208351135, 87.80967816710472, 99.2480143904686, 98.30691128969193, 96.51219919323921, 99.99896049499512, 99.8531623184681, 107.74077907204628, 100.92329129576683, 95.51492750644684, 98.9521698653698, 96.7256261408329, 93.77180144190788, 106.62956669926643, 96.90712720155716, 55.12968756258488, 6.292582992464304, 1.1293271882459521, 0.881958621321246, 0.14589505648473278, 0.26989726116880774, 0.08052767618210055, 0.035957092040916905, 0.21798599045723677, 1.3220551027916372, 21.87445342540741, 36.15568310022354, 41.30202814936638, 53.079674765467644, 73.23598578572273, 37.90903441607952, 19.281483963131905, 26.34291484951973, 40.389248728752136, 69.8981460928917, 72.66662433743477, 99.794432669878, 85.11841177940369, 97.06551030278206, 95.74384242296219, 4.900128711014986, 0.05080900329630822, 0.013448149129544618, 0.018570688953332137, 0.020056292341905646, 0.014097671210038243, 0.006555063419000362, 0.07625515427207574, 0.047098554350668564, 0.031098785548238084, 0.01673053193371743, 0.08158009353792295, 0.04141718382015824, 0.041274509640061297, 0.022392074133676942, 0.015352687460108427, 0.014935540166334249, 0.10917270628851838, 0.07780976811773144, 0.06260915877646767, 0.046386025787796825, 0.031827151542529464, 0.06807866840972565, 0.11370979642379098, 0.05031789078202564, 0.043110731421620585, 0.014605764063162496, 0.04888241019216366, 0.019489397272991482, 0.09403840042068623, 0.10410950766527094, 0.24452664598356932, 0.10424295323900878, 0.10286511896993034, 0.11252802272792906, 0.14839094365015626, 0.1389597458182834, 0.11701653187628835, 0.13131555053405464, 0.20413561491295695, 0.14400422747712582, 0.13976730639114976, 0.2560722373891622, 0.1539748182403855, 0.15277206402970478, 0.1611927238991484, 0.18078736698953435, 0.09695533022750169, 0.105397705337964, 0.13032813789322972, 0.2715547144180164, 0.15759897767566144, 0.2887744107283652, 0.25068697636015713, 0.19135390233714134, 0.6574873288627714, 30.053153559565544, 157.76350647211075, 127.54074901342392, 135.59380888938904, 81.59671515226364, 101.36152938008308, 49.25889618694782, 53.02077032625675, 82.70808711647987, 130.07997035980225, 83.84934827685356, 66.72949612140656, 55.41113466024399, 14.207154549658298, 1.0744023229926825, 0.33146307163406163, 0.33155367302242666, 0.1880122339935042, 0.2929354546358809, 4.029873758554459, 4.197582984343171, 3.7314524967223406, 80.74686795473099, 143.4753155708313, 102.68814459443092, 108.30133259296417, 113.17902445793152, 103.18561390042305, 95.36189451813698, 103.98157998919487, 101.68572798371315, 101.04859337210655, 101.56253859400749, 99.19811546802521, 86.29791408777237, 84.99533638358116, 84.79528471827507, 83.4494349360466, 80.37999764084816, 95.93447059392929, 106.50524497032166, 110.49921825528145, 105.64063936471939, 87.86801263689995, 80.72016298770905, 78.31106185913086, 90.83632975816727, 107.85111755132675, 103.50522235035896, 106.49769857525826, 95.97654193639755, 83.2689218223095, 88.6930775642395, 105.24038404226303, 101.20140597224236, 94.05044808983803, 79.0687108039856, 92.23250404000282, 93.99338275194168, 113.36074590682983, 57.58200377225876, 38.72216798365116, 90.8946642279625, 107.16650068759918, 102.72324711084366, 94.98343482613564, 94.24682915210724, 89.33325961232185, 89.80980724096298, 90.41534274816513, 100.25151014328003, 107.93149843811989, 106.3219504058361, 94.04094859957695, 103.0081558227539, 103.36768493056297, 96.77000775933266, 92.20931768417358, 89.25333470106125, 85.97608655691147, 82.08536133170128, 92.77902871370316, 104.23307329416275, 101.80545195937157, 100.67807525396347, 105.33880636096, 107.00216710567474, 112.81523957848549, 107.72677302360535, 101.66322559118271, 105.91202080249786, 101.45983770489693, 99.41854923963547, 116.08454614877701, 99.25991535186768, 57.42199815809727, 6.733908886089921, 2.792361625470221, 1.1446254048496485, 0.20966713840607554, 0.4381223686505109, 0.1367125820252113, 0.1252803165698424, 0.43498436047229916, 2.6934320339933038, 31.152846850454807, 50.09150750935078, 52.23431892693043, 49.31505337357521, 105.98778113722801, 81.9621567428112, 36.04068987071514, 24.161315113306046, 31.38018485158682, 62.015586867928505, 76.9834814965725, 113.44311028718948, 95.03397211432457, 106.84113934636116, 111.93331450223923, 7.426137216389179, 0.38141005556099117, 0.18526682193623856, 0.1799795392435044, 0.1961695947102271, 0.11298307057586499, 0.12377580511383712, 0.09725080148200504, 0.08352480246685445, 0.09784840105567127, 0.15817832783795893, 0.11843264612252824, 0.1309920780477114, 0.2025211468571797, 0.10958421233226545, 0.19427383784204721, 0.11243391098105349, 0.16320231137797236, 0.14402802073163912, 0.11678585753543302, 0.22003816236974671, 0.11552944604773074, 0.15304921165807173, 0.16599562164628878, 0.08871349084074609, 0.15408881212351844, 0.14441923645790666, 0.16165628418093547, 0.12294260333874263, 0.12782459176378325], [0.007631048601979273, 0.0508127474313369, 0.014776856933167437, 0.10674494827981107, 0.01391389503623941, 0.021088428657094482, 0.02191498821048299, 0.09195748512865975, 0.037838232310605235, 0.02450877207593294, 0.10244551609503105, 0.0353933047153987, 0.031177323326119222, 0.028358919189486187, 0.0024880827868400957, 0.04075722157722339, 0.011506837381602963, 0.20040746574522927, 0.03242764178139623, 0.17442109063267708, 0.08143298502545804, 0.07263650157256052, 0.11356239847373217, 0.12207308827782981, 0.2577654621563852, 9.76886635646224, 103.99746313691139, 111.09624221920967, 102.60951161384583, 88.87536898255348, 60.62480449676514, 17.88381066173315, 27.468864731490612, 51.574807316064835, 60.26602774858475, 31.624971516430378, 36.36519245803356, 27.93482232838869, 4.81522511690855, 0.9124677779618651, 0.056144417976611294, 0.37872333254199475, 0.029228701423562597, 0.401509641087614, 1.0827860981225967, 12.284368425607681, 2.346038050018251, 57.1718879789114, 136.76949620246887, 90.98519816994667, 110.99349573254585, 87.35203832387924, 87.90528103709221, 84.25149589776993, 90.20803347229958, 86.08786135911942, 90.57928875088692, 84.27643775939941, 79.72971573472023, 76.3494323194027, 74.50942665338516, 76.57439544796944, 74.86771702766418, 68.05502459406853, 69.51271757483482, 79.08264845609665, 93.62241625785828, 97.41353362798691, 93.29251796007156, 74.03093352913857, 66.92085385322571, 69.24102455377579, 86.84884652495384, 95.14319345355034, 89.52562808990479, 91.84511482715607, 74.0786437690258, 70.5404332280159, 88.80192652344704, 93.8974379003048, 96.69389024376869, 85.77838316559792, 78.24564456939697, 82.57204681634903, 89.62063819169998, 95.6293773651123, 77.03968808054924, 18.323213383555412, 91.76306962966919, 86.0858702659607, 87.8489300608635, 86.85207635164261, 89.34583693742752, 88.52103039622307, 85.82699775695801, 78.03021132946014, 84.299236536026, 89.62747022509575, 94.96976315975189, 92.47227877378464, 87.0119945704937, 93.30900147557259, 92.99203768372536, 85.94876602292061, 80.81300720572472, 72.31083422899246, 71.6447451710701, 76.97022020816803, 90.4725980758667, 93.15112754702568, 95.22178083658218, 97.29856699705124, 96.1075209081173, 90.26967376470566, 96.38781666755676, 95.42209848761559, 92.79867365956306, 89.6745041012764, 96.66428223252296, 93.7061333656311, 94.54089537262917, 77.01596215367317, 22.82053615897894, 0.512658100342378, 0.35706488066352904, 0.14387448522029445, 0.04314101104682777, 0.08463896650937386, 0.06966920962440781, 0.20597032271325588, 0.12481703830417246, 0.6742909178137779, 14.34637812897563, 40.117859691381454, 51.1133486777544, 23.10896348208189, 84.48152795433998, 80.7930962741375, 48.47319334745407, 20.59740275144577, 11.47612614557147, 25.661784298717976, 50.25118634104729, 70.95385104417801, 78.63470569252968, 84.82959687709808, 67.70700886845589, 2.301852833479643, 0.028603479113371577, 0.044334748163237236, 0.0485289549396839, 0.042207578517263755, 0.04353146978246514, 0.020451849632081576, 0.08079770661424845, 0.010663393968570745, 0.042583053291309625, 0.06171308225020766, 0.004688991994044045, 0.01794580432033399, 0.09405518780113198, 0.02505305576050887, 0.023101658225641586, 0.08453554823063314, 0.024464400921715423, 0.0640680429933127, 0.02816627806168981, 0.037176366458879784, 0.09213123674271628, 0.07737742256722413, 0.07724448907538317, 0.031222256657201797, 0.10445382707985118, 0.010962118612951599, 0.04066920286277309, 0.10824325538123958, 0.02410195640550228, 0.008442378821200691, 0.031063566930242814, 0.09624397425795905, 0.046059046653681435, 0.08261300725280307, 0.02442510420223698, 0.11181471490999684, 0.0432644784450531, 0.15900096885161474, 0.11514763333252631, 0.061417963515850715, 0.07121378221199848, 0.05648980237310752, 0.05976509673928376, 0.04482449512579478, 0.06790838262531906, 0.13796293758787215, 0.03583478981454391, 0.07229172944789752, 0.04000797896878794, 0.039624949131393805, 0.07184213638538495, 0.16144135821377859, 0.30906564847100526, 15.014619771391153, 130.81801235675812, 119.99741658568382, 122.32273980975151, 97.97508269548416, 70.47695383429527, 48.48047375679016, 37.15675838291645, 27.31042843312025, 62.251747995615005, 41.54570147395134, 41.97154842317104, 40.815870836377144, 6.825346229597926, 0.3799150139093399, 0.04800248279934749, 0.2561657183105126, 0.1568040781421587, 1.8308969610370696, 3.8176506338641047, 2.089685993269086, 1.905939371790737, 69.28912237286568, 135.9575405716896, 94.79247987270355, 114.77015107870102, 91.75177663564682, 91.80503457784653, 89.34772163629532, 95.6465296447277, 89.42159727215767, 93.19791823625565, 87.09950387477875, 83.10863882303238, 79.24552291631699, 80.84874048829079, 82.59564355015755, 80.02020254731178, 73.10260534286499, 74.14078563451767, 81.24717190861702, 97.09292203187943, 100.65757915377617, 98.2302238047123, 78.27285870909691, 70.75085073709488, 73.2616876065731, 92.0734977722168, 100.71191623806953, 94.7030858695507, 95.11719524860382, 78.23180571198463, 76.18048578500748, 93.56453016400337, 98.09442669153214, 101.87036767601967, 89.14254784584045, 82.24021062254906, 83.63427221775055, 95.84835201501846, 96.71405956149101, 81.17955833673477, 22.30105083435774, 92.48337417840958, 90.227260440588, 90.6141708791256, 91.09058171510696, 96.56837537884712, 93.91114756464958, 89.57388550043106, 80.97037956118584, 88.74261930584908, 91.95643365383148, 99.66770187020302, 95.32106190919876, 92.24966391921043, 97.52777829766273, 97.37341538071632, 90.58079347014427, 84.16738361120224, 75.680311024189, 76.04675576090813, 81.0381755232811, 93.26781168580055, 95.94045907258987, 97.30938881635666, 102.53760427236557, 100.20045608282089, 91.85402914881706, 97.68762812018394, 99.48904305696487, 96.14401414990425, 95.11648088693619, 99.88227635622025, 96.21691703796387, 96.14779114723206, 81.11532658338547, 28.244302421808243, 1.142199116293341, 0.6178670923691243, 0.7782322028651834, 0.39941230206750333, 0.11432547471486032, 0.18480740283848718, 0.09183629983454011, 0.1872165032546036, 0.6285736116115004, 17.427016273140907, 39.36476670205593, 25.91979805380106, 32.873860001564026, 64.38033297657967, 49.21869434416294, 33.181966468691826, 21.26895971596241, 25.178220346570015, 48.15680332481861, 70.1903884112835, 81.81007370352745, 88.41642200946808, 93.17901045084, 90.08900865912437, 2.9045161698013544, 0.02027874183113454, 0.02943887022411218, 0.008400851947953925, 0.03680203459225595, 0.028107227226428222, 0.02586209877335932, 0.10308782264473848, 0.008658779806864914, 0.03794465257669799, 0.01643648931349162, 0.040197163543780334, 0.026510368479648605, 0.02312917149538407, 0.06420678007998504, 0.04400542013172526, 0.023737610135867726, 0.07030398337519728, 0.03233860632462893, 0.056378821609541774, 0.02512850991479354, 0.04370876515167765, 0.05342636890418362, 0.03265316190663725, 0.03573983944079373, 0.040484563942300156, 0.03904766585037578, 0.03881096527038608, 0.05925728961301502, 0.15056168107548729, 0.09801173291634768, 0.13442595081869513, 0.19513800943968818, 0.09908451480441727, 0.16302090079989284, 0.17305792862316594, 0.16436702309874818, 0.17301080224569887, 0.29877312888856977, 0.22200234525371343, 0.20416176819708198, 0.10829575490788557, 0.2010064382920973, 0.1694869960192591, 0.1301900835824199, 0.14276709698606282, 0.2699311327887699, 0.18909781792899594, 0.4227339068893343, 0.15539612009888515, 0.15691207547206432, 0.30632097856141627, 0.2394401587662287, 0.5863089545164257, 20.28789795935154, 152.6323226094246, 134.82573330402374, 136.99670881032944, 110.3912128508091, 79.99985083937645, 28.541368581354618, 45.7437352091074, 82.73644119501114, 87.52686694264412, 50.06576769053936, 62.02654168009758, 49.907680973410606, 10.556160360574722, 1.4002641686238348, 0.32531482342164963, 0.5659507750533521, 0.20874251145869493, 0.9052776731550694, 2.187910247594118, 20.981826223433018, 7.591436421498656, 62.055701315402985, 146.93358600139618, 97.6458303630352, 121.29541173577309, 97.19319105148315, 96.05841234326363, 92.10898786783218, 101.77008345723152, 93.94771680235863, 98.76303881406784, 92.0265094935894, 85.73409274220467, 82.86824852228165, 83.00071701407433, 88.36887896060944, 85.55888414382935, 77.77526780962944, 78.89399617910385, 85.66753551363945, 104.50510829687119, 105.18635094165802, 103.13801765441895, 82.33297124505043, 75.58207869529724, 79.05948489904404, 99.05862495303154, 104.12543267011642, 99.4124011695385, 100.95174416899681, 84.28614243865013, 80.70149078965187, 97.6474566757679, 100.71246340870857, 103.74804452061653, 94.98639106750488, 85.84843620657921, 91.43375650048256, 101.64020642638206, 101.89480036497116, 82.94320330023766, 28.314729742705822, 96.75603210926056, 94.62851867079735, 96.2987494468689, 94.32197391986847, 100.14529064297676, 98.00715297460556, 94.82173830270767, 84.98278945684433, 93.22306528687477, 94.38584849238396, 103.41260612010956, 94.60975527763367, 93.4755465388298, 102.45403155684471, 102.1173544228077, 97.23874300718307, 88.55073720216751, 81.72353714704514, 78.09315115213394, 84.52728509902954, 99.79054927825928, 103.4183058142662, 105.12077406048775, 106.58626422286034, 104.43698555231094, 94.74894180893898, 102.07947805523872, 105.3471127152443, 98.8690835237503, 100.98563075065613, 104.0791891515255, 102.1246500313282, 104.44456994533539, 84.56431791186333, 28.4057804569602, 3.096478544175625, 3.082977393642068, 1.4933458738960326, 0.4694197158096358, 0.12535816786112264, 0.3194010048173368, 0.3178131056483835, 0.41749939089640975, 1.846490018069744, 24.73288804292679, 63.0367174744606, 73.07996615767479, 35.901662930846214, 103.58828589320183, 116.86028972268105, 64.89049360156059, 28.7092986702919, 20.160580091178417, 41.544926315546036, 69.33960646390915, 90.49804911017418, 99.89573523402214, 103.37324023246765, 103.84090393781662, 4.047959838062525, 0.14771178946830332, 0.13252826436655596, 0.17105686099966988, 0.10869346442632377, 0.08327743722475134, 0.11434607673436403, 0.175609061261639, 0.1362283603521064, 0.15273357625119388, 0.18546873063314706, 0.28233319229912013, 0.07826116459909827, 0.2319679339416325, 0.2180008334107697, 0.08877312982804142, 0.14193822193192318, 0.1338322920491919, 0.1628836925374344, 0.12344514121650718, 0.19895898643881083, 0.1613597516552545, 0.21684354316676036, 0.15671176981413737, 0.14806445804424584, 0.23027439747238532, 0.10172322086873464, 0.19127150910208002, 0.22502824460389093], [0.011541293442860479, 0.04410099390952382, 0.04199361734208651, 0.0340223872626666, 0.03473903845588211, 0.06076183446566574, 0.03460821637418121, 0.10711910203099251, 0.08107169269351289, 0.04243297618813813, 0.037230647139949724, 0.029135008990124334, 0.05119097186252475, 0.018062468079733662, 0.028959303672309034, 0.03502977480820846, 0.05402982031228021, 0.027121842504129745, 0.04172697110334411, 0.03542866434145253, 0.03354653330461588, 0.06762923861970194, 0.16141195432282984, 0.06699685458443128, 2.6459319703280926, 99.65178832411766, 103.77647459506989, 114.0000008046627, 78.81658673286438, 74.86460119485855, 94.26311507821083, 41.086537912487984, 49.80441391468048, 84.86629530787468, 46.43855832517147, 45.46185873448849, 28.62353917211294, 1.746905199252069, 1.1073510674759746, 0.18137226841645315, 0.3890781628433615, 0.055645590837229975, 0.5756613914854825, 0.39464902016334236, 13.609717357903719, 1.8156517040915787, 33.75151410698891, 137.83983796834946, 92.95676797628403, 115.68626672029495, 82.1412943303585, 90.66420659422874, 91.68811485171318, 93.27974304556847, 79.16431367397308, 84.85522270202637, 82.73061990737915, 76.95550739765167, 73.87716338038445, 74.10717263817787, 76.91760823130608, 75.88055267930031, 73.92200857400894, 73.72874334454536, 66.78477555513382, 69.55886229872704, 84.68059167265892, 95.9814740717411, 87.31863811612129, 70.01891121268272, 67.57675185799599, 70.84415093064308, 92.1824911236763, 95.0917974114418, 97.10871398448944, 86.99061691761017, 69.33242484927177, 74.33374688029289, 89.61758315563202, 91.08730629086494, 93.90234723687172, 86.43947169184685, 79.72481399774551, 75.37190437316895, 88.89453515410423, 87.59255781769753, 98.30061882734299, 33.60114477574825, 72.60239258408546, 101.73213869333267, 87.77603477239609, 94.58775445818901, 90.72280704975128, 93.17050650715828, 83.82752224802971, 82.35475167632103, 74.98190850019455, 88.42591390013695, 90.4011619091034, 97.49374732375145, 89.46639686822891, 91.14117980003357, 92.97103241086006, 87.37569585442543, 80.44770240783691, 72.3581112921238, 72.485541254282, 77.03612387180328, 80.16929894685745, 80.80296814441681, 82.67135068774223, 87.66051337122917, 93.48819985985756, 93.69598791003227, 94.88040715456009, 87.37268641591072, 91.2960746884346, 89.65259447693825, 84.00297403335571, 90.43934226036072, 91.25950545072556, 87.10182175040245, 56.35533459484577, 7.970453258603811, 0.05057779831986409, 0.21380006975959986, 0.11288466179394163, 0.07361135707469657, 0.10590936421067454, 0.05726258961658459, 0.20966454088920727, 0.0600103765464155, 0.8131136780139059, 10.112901795655489, 50.23624174296856, 57.24055789411068, 40.298581793904305, 83.22594612836838, 101.17050603032112, 82.36950248479843, 33.72992366552353, 13.99803752079606, 21.05540357530117, 56.84439115226269, 73.08733776211739, 77.66780957579613, 92.22529962658882, 38.4206123650074, 0.7599398063030094, 0.128778355428949, 0.11004123429302126, 0.08700284786755219, 0.080323830479756, 0.006922512793607893, 0.054864884878043085, 0.060419871369958855, 0.06836012791609392, 0.06869108125101775, 0.053142133765504695, 0.08182883917470463, 0.04381760110845789, 0.0470712581591215, 0.04375434044050053, 0.007944055414554896, 0.044399481994332746, 0.025634806770540308, 0.08869315599440597, 0.013708947244595038, 0.05134604733029846, 0.030595611278840806, 0.05115002015372738, 0.031586116820108145, 0.03479111866909079, 0.07704289950197563, 0.056568277068436146, 0.08007631680811755, 0.043065460413345136, 0.021732679633714724, 0.04400432175316382, 0.052258143114158884, 0.047427496465388685, 0.005850269426446175, 0.07603214631672017, 0.07330813779844902, 0.029443616258504335, 0.03493374460958876, 0.05423134680313524, 0.038283925387077034, 0.03109458128164988, 0.09160740664810874, 0.09630653730710037, 0.03084871146711521, 0.018701650187722407, 0.011510896929394221, 0.12694438977632672, 0.05214309538132511, 0.07131141173886135, 0.04707393731223419, 0.1898932666517794, 0.07838746329071, 5.316262431442738, 126.39018595218658, 113.79438623785973, 129.62969452142715, 91.63778275251389, 104.2155410349369, 110.09320244193077, 32.868346497416496, 27.07626599818468, 72.13669717311859, 53.624671921133995, 41.832339093089104, 41.06566563248634, 2.3423700593411922, 0.6944402272347361, 0.07071694402839057, 0.2645699173444882, 0.04625296984158922, 0.7233420701231807, 4.138251068070531, 17.026190981268883, 4.321497185155749, 44.962960705161095, 138.12798410654068, 97.06389158964157, 118.88718456029892, 86.60461843013763, 93.23590099811554, 95.66233679652214, 96.17297619581223, 82.21259370446205, 87.710792273283, 88.44222262501717, 81.901785582304, 76.77703097462654, 80.6327448785305, 80.75420916080475, 80.21870389580727, 77.9963019490242, 76.28305748105049, 71.37363731861115, 73.93300518393517, 90.55417969822884, 96.5770997107029, 90.91133013367653, 75.21982133388519, 71.04014441370964, 75.50259456038475, 93.77380773425102, 97.06566229462624, 98.75706553459167, 91.1129929125309, 73.3125288784504, 78.38119849562645, 93.16348448395729, 94.60672304034233, 95.60701936483383, 88.23555171489716, 83.57656091451645, 76.76737949252129, 92.68229350447655, 92.1771714091301, 102.9309743642807, 37.87515923380852, 74.81198161840439, 103.24095413088799, 91.78963780403137, 98.45577970147133, 95.765630453825, 97.571741938591, 88.52181315422058, 85.43874219059944, 80.51283851265907, 91.26920253038406, 94.70825359225273, 101.30069464445114, 93.78152132034302, 94.50835391879082, 96.11388176679611, 89.57318633794785, 84.23660069704056, 75.3116700053215, 76.40554770827293, 81.64914473891258, 83.8321503996849, 85.46001344919205, 88.20558652281761, 91.38074174523354, 96.44132539629936, 96.27348080277443, 95.79124867916107, 87.83497720956802, 95.10893449187279, 91.8712118268013, 88.33405002951622, 91.34367853403091, 94.0740904211998, 89.01173606514931, 64.02482405304909, 11.54166977852583, 0.3988075110828504, 0.6501989043317735, 1.0486569232307374, 0.31196112278848886, 0.3183280670782551, 0.047532246899208985, 0.14079142565606162, 0.1355882579809986, 0.7486234791576862, 15.764519032090902, 44.149116575717926, 32.752057537436485, 48.652353733778, 67.9999427497387, 58.7490351498127, 44.42747063934803, 35.31128481030464, 25.286286547780037, 44.273164719343185, 69.78733643889427, 86.47068321704865, 86.91608011722565, 104.06797215342522, 55.654306411743164, 0.6112244550604373, 0.19206887256586924, 0.036865146830677986, 0.10618341708322987, 0.04549191224214155, 0.018761860628728755, 0.03871331718983129, 0.07171104341978207, 0.01579201198183, 0.029840244096703827, 0.060700944959535263, 0.0923427488305606, 0.01914595915877726, 0.08282948430860415, 0.04294982267310843, 0.024496348523825873, 0.048589176512905397, 0.013106776041240664, 0.048108695264090784, 0.030961274860601407, 0.056824436760507524, 0.0030490225844914676, 0.016745322936913, 0.034452083345968276, 0.10401040126453154, 0.06610141630517319, 0.03569113971025217, 0.07526512927142903, 0.13099489820888266, 0.14976436214055866, 0.14993698569014668, 0.12847539590438828, 0.08911177181289531, 0.12020396708976477, 0.14374388207215816, 0.2317002264317125, 0.132247049768921, 0.12679551495239139, 0.10831082792719826, 0.22766660928027704, 0.06295443556155078, 0.1700833858922124, 0.16685439040884376, 0.14120054198428988, 0.16426073270849884, 0.11175221865414642, 0.2600154164247215, 0.2134097446105443, 0.2327601914294064, 0.17495482839876786, 0.315786597202532, 0.3587201965274289, 8.116931598633528, 145.9912821650505, 130.93579083681107, 143.54515582323074, 107.75858491659164, 100.0449076294899, 116.2478157877922, 56.98615774512291, 78.60374495387077, 118.54025557637215, 65.05434080958366, 78.00405353307724, 49.254207238554955, 4.421055167913437, 1.7829242977313697, 0.3694682166678831, 0.6366810109466314, 0.18049420381430537, 0.7619735284242779, 1.9307580962777138, 24.139568880200386, 11.825288459658623, 37.991170808672905, 150.0231698155403, 97.26161018013954, 125.84502160549164, 89.98423308134079, 99.80039834976196, 100.65465331077576, 102.45751976966858, 86.89170062541962, 94.13177132606506, 90.7617549598217, 86.69777423143387, 81.32997706532478, 86.51469245553017, 85.97331270575523, 85.99101975560188, 83.10825124382973, 83.37707921862602, 75.85302695631981, 80.43488949537277, 96.95238277316093, 102.67416894435883, 93.5684971511364, 79.55418795347214, 75.15683591365814, 80.77802628278732, 100.3342393040657, 102.59704828262329, 104.5556227862835, 98.38396355509758, 77.32894375920296, 83.94973129034042, 96.90538689494133, 98.3547431230545, 97.04628333449364, 96.10588699579239, 86.67947441339493, 83.3512482047081, 99.00854364037514, 99.55824494361877, 104.89150956273079, 42.52151571214199, 81.51405438780785, 109.52457815408707, 96.45701855421066, 102.8224065899849, 100.92874020338058, 102.89106130599976, 91.86053439974785, 90.31717881560326, 84.16628926992416, 97.54523456096649, 100.05601063370705, 107.89496719837189, 95.3114104270935, 95.80599948763847, 99.4158285856247, 93.62866312265396, 90.50806537270546, 80.14240399003029, 84.10906434059143, 85.22433489561081, 87.72239685058594, 90.17249777913094, 92.68490016460419, 95.75082644820213, 102.0429240167141, 100.72478234767914, 99.19842705130577, 89.7990234196186, 98.10764998197556, 96.22893199324608, 92.98038750886917, 96.14314019680023, 100.04746869206429, 93.84671822190285, 65.5309796333313, 11.87304999679327, 3.829123880714178, 3.0551932845264673, 1.6525319195352495, 0.24563648330513388, 0.34758593305014074, 0.30860079685226083, 0.402995094191283, 0.43817182537168264, 4.292658157646656, 22.16712512075901, 79.74416255950928, 80.73677569627762, 58.72505083680153, 98.71203035116196, 135.53764790296555, 109.18315127491951, 45.02765603363514, 21.43241934478283, 35.10290779173374, 74.26547974348068, 99.45867508649826, 96.97179973125458, 115.4414914548397, 66.30888909101486, 1.1849955073557794, 0.3062168403994292, 0.14773294067708775, 0.29035007930360734, 0.18437643768265843, 0.10258665031869896, 0.14102309447480366, 0.21334747842047364, 0.23162483907071874, 0.17277726321481168, 0.1550311318715103, 0.1568260753992945, 0.2746250090422109, 0.174939792486839, 0.12971414427738637, 0.10710588438087143, 0.18622162460815161, 0.054380321817006916, 0.33388781652320176, 0.06861602785647847, 0.2748404099838808, 0.12570627965033054, 0.1517771853832528, 0.14484683226328343, 0.15548531140666455, 0.16818534320918843, 0.17215779254911467, 0.19393819413380697], [0.050934025493916124, 0.02198962971306173, 0.02182495085435221, 0.03635890934674535, 0.02351237017137464, 0.018774781419779174, 0.009584144263499184, 0.023943244414112996, 0.03995342369307764, 0.09123514537350275, 0.07171721808845177, 0.04043938570248429, 0.03282397461589426, 0.031325526506407186, 0.03142455869237892, 0.03388375036593061, 0.05206340727454517, 0.01950135141669307, 0.06701730075292289, 0.023932973090268206, 0.0497945913230069, 0.020005564692837652, 0.07629709303728305, 2.3541691387072206, 94.1228798031807, 110.65170407295227, 114.7873717546463, 89.17822033166885, 85.59253513813019, 45.033997893333435, 13.682922329753637, 100.86976736783981, 145.889493227005, 58.90417702496052, 39.881124794483185, 28.877884224057198, 0.6429181387647986, 0.2891156205441803, 0.14498236327199265, 0.29564509517513216, 0.020072242950845975, 0.4062454932136461, 0.31515283277258277, 16.507617607712746, 5.73639971204102, 7.5258310418576, 128.49477142095566, 96.73716232180595, 115.58915913105011, 88.22333917021751, 87.16045260429382, 86.79217636585236, 87.31257364153862, 85.72189539670944, 89.73566561937332, 74.72728416323662, 77.29741305112839, 75.6516681611538, 72.96357080340385, 73.78636345267296, 80.4212786257267, 75.7189017534256, 77.20383167266846, 66.5335862338543, 68.237224817276, 67.3015022277832, 74.23414662480354, 78.49595993757248, 76.7435547709465, 65.71228310465813, 67.61570736765862, 76.1180779337883, 89.36010897159576, 89.10217881202698, 90.64953938126564, 73.67593377828598, 65.23293882608414, 74.74376007914543, 92.30626568198204, 84.4501568377018, 92.42187067866325, 83.82204294204712, 81.87603056430817, 77.61380687355995, 90.20908981561661, 80.67232355475426, 99.20756936073303, 43.49427871406078, 50.46854607760906, 97.89301469922066, 80.3419616818428, 94.20540377497673, 92.03683733940125, 92.95115187764168, 85.00599101185799, 87.63282805681229, 81.13542750477791, 80.76829880475998, 84.45426061749458, 91.19500771164894, 91.55682429671288, 89.54189121723175, 91.12574502825737, 86.8401525914669, 72.93909251689911, 70.63162073493004, 70.60221791267395, 74.62935581803322, 72.91914358735085, 77.07906156778336, 78.76981884241104, 90.21784454584122, 95.61904951930046, 89.00939539074898, 84.5784379541874, 92.24361464381218, 88.80380362272263, 87.15219184756279, 90.83389788866043, 88.85263860225677, 87.12385296821594, 91.20030462741852, 82.93448656797409, 47.63416036963463, 1.6412116144783795, 0.6216395774390548, 0.775079500162974, 0.21320172061678022, 0.031773182563483715, 0.009502685206825845, 0.03072323655942455, 0.06555656116688624, 0.27560105198062956, 0.09316125608165748, 8.854606915265322, 30.921424068510532, 34.700425788760185, 40.91671362519264, 121.08700811862946, 99.7564347088337, 58.61568510532379, 54.69362296164036, 18.146292977035046, 23.480197861790657, 61.08787424862385, 70.43347656726837, 79.1829326748848, 82.3728159070015, 6.168028051033616, 0.25143191451206803, 0.1867687507183291, 0.12702485342742875, 0.06077371996070724, 0.05695564475900028, 0.021127276377228554, 0.022568382446479518, 0.0097242135052511, 0.04011512653960381, 0.029126069821359124, 0.047143495103227906, 0.0433698708366137, 0.14960408792831004, 0.029668711504200473, 0.06413928917027079, 0.04225810022035148, 0.0316424532502424, 0.03402712958632037, 0.041666816323413514, 0.01886319903860567, 0.056856890878407285, 0.06698423065245152, 0.050534404945210554, 0.021633831129292957, 0.05271673100651242, 0.024005221166589763, 0.015562028765998548, 0.016340290276275482, 0.05549246721784584, 0.042575995466904715, 0.019331308685650583, 0.03569999724277295, 0.046382318760151975, 0.01919331003591651, 0.03982821595855057, 0.03446331946179271, 0.0964270843542181, 0.06361883584759198, 0.03934358981496189, 0.01138640722274431, 0.08665509230922908, 0.034394314570818096, 0.08170886358129792, 0.08236868481617421, 0.09714991392684169, 0.047051205328898504, 0.028846914683526848, 0.03714924467203673, 0.025887560004775878, 0.12812591856345534, 4.483221732079983, 118.88636380434036, 123.44138458371162, 127.54520237445831, 104.10640329122543, 102.39575028419495, 69.48321595788002, 34.471769258379936, 64.79350000619888, 111.14263772964478, 67.85146191716194, 43.89104202389717, 42.069229781627655, 1.819274928420782, 0.318206325173378, 0.13100040494464338, 0.1677774143172428, 0.07866441053920425, 0.2562183217378333, 0.3420428914250806, 4.0140794310718775, 2.9316023038700223, 9.713365584611893, 131.69941306114197, 98.31530123949051, 120.1146250963211, 91.18694454431534, 90.623609572649, 87.60974049568176, 92.42738038301468, 89.47648152709007, 94.81720134615898, 79.82072085142136, 82.32036352157593, 80.09180590510368, 77.86238953471184, 76.05686321854591, 85.23462474346161, 80.87141767144203, 82.62130737304688, 70.32959014177322, 71.63627162575722, 70.66814437508583, 78.22917625308037, 81.38134270906448, 78.22409972548485, 71.01102277636528, 71.1238843202591, 79.78656068444252, 94.51676666736603, 91.7886346578598, 94.60962608456612, 77.20025226473808, 68.68481799960136, 78.54230225086212, 95.79361215233803, 87.74308294057846, 93.9783051609993, 89.39176127314568, 85.88473185896873, 80.87337836623192, 92.9651427268982, 85.48041835427284, 103.1131973862648, 45.3810940682888, 53.92812363803387, 100.45139461755753, 84.79935050010681, 99.22970697283745, 95.04046216607094, 97.38629668951035, 89.60296913981438, 91.55094221234322, 83.37313503026962, 83.55212822556496, 88.6104167997837, 94.90071326494217, 94.0518768131733, 91.6496229171753, 93.89166980981827, 91.07035160064697, 76.67946740984917, 77.12433993816376, 72.82379150390625, 77.10238471627235, 77.13462218642235, 80.07928177714348, 84.10898074507713, 93.73767927289009, 97.8132113814354, 90.72818756103516, 85.14351323246956, 95.22051930427551, 88.94728392362595, 87.8299006819725, 92.71377861499786, 91.70615628361702, 87.79847636818886, 92.55861774086952, 85.85316315293312, 56.68022856116295, 3.196923304349184, 0.07609164429595694, 1.1539825215004385, 0.9993700054474175, 0.32442739291582257, 0.004431039087648969, 0.13675457274075598, 0.10883060589549132, 0.2523768466198817, 0.3943345573497936, 10.730878785252571, 32.7374093234539, 29.93172537535429, 49.20506067574024, 108.59640955924988, 86.94463938474655, 20.491648726165295, 24.959148801863194, 23.238530829548836, 42.44404546916485, 73.06463778018951, 80.70908278226852, 88.53758990764618, 101.94798231124878, 11.765717156231403, 0.47202978981658816, 0.225151767663192, 0.11238755643717013, 0.06898913517943583, 0.06133148475782946, 0.08510752886650153, 0.04433567955857143, 0.03305436322989408, 0.04288551186618861, 0.08784791658399627, 0.013957593619124964, 0.05162993365956936, 0.02931002225523116, 0.008606909250374883, 0.05387050347053446, 0.03805048283538781, 0.03512284754833672, 0.11946226470172405, 0.01975276507437229, 0.05673169798683375, 0.04118535915040411, 0.07585166342323646, 0.1673037459840998, 0.058781821571756154, 0.06598452062462457, 0.025806213197938632, 0.033536410410306416, 0.16297655005473644, 0.21076116798212752, 0.1235822901071515, 0.09136902881436981, 0.15546046430245042, 0.18376107851509005, 0.16911896498641, 0.21865183050977066, 0.177072205406148, 0.21538728615269065, 0.28821851243264973, 0.19992505491245538, 0.19328734546434134, 0.1711741351755336, 0.11300682672299445, 0.20660240988945588, 0.20484769076574594, 0.16180783073650673, 0.21268108917865902, 0.21166287740925327, 0.2678826270857826, 0.1424328188295476, 0.2584195614326745, 5.324180256575346, 138.9712956547737, 140.1762717962265, 142.98965603113174, 115.35648241639137, 108.07167291641235, 64.11300972104073, 21.224906779825687, 149.91162300109863, 178.76619547605515, 74.49430346488953, 67.60756060481071, 50.014793425798416, 2.613967373035848, 0.7397102855611593, 0.19138287578243762, 0.4606198630062863, 0.12873479136032984, 0.6646944140084088, 0.5028769501950592, 36.671277433633804, 14.064162522554398, 6.934625040739775, 144.30292636156082, 99.57272216677666, 125.9760993719101, 93.79175037145615, 97.12050095200539, 93.2343202829361, 97.43798911571503, 94.05347272753716, 102.28263795375824, 81.16305202245712, 88.63351196050644, 82.8166700899601, 83.38339447975159, 81.43261715769768, 92.68467217683792, 85.315051227808, 87.85234227776527, 74.8972262442112, 77.41357281804085, 74.8794735968113, 84.35059458017349, 88.9758811891079, 85.90973451733589, 75.02454221248627, 75.34650653600693, 84.31369855999947, 99.14362639188766, 95.92512309551239, 100.40123730897903, 81.97163343429565, 72.60930821299553, 81.8260708451271, 99.54030230641365, 94.76103276014328, 96.59278526902199, 92.93805778026581, 90.28921231627464, 86.9694596529007, 98.83214190602303, 91.32483914494514, 106.25860020518303, 51.23411759734154, 58.9686481654644, 103.32013428211212, 88.88788551092148, 100.82984670996666, 99.63850423693657, 99.28253933787346, 94.03007358312607, 95.49710646271706, 89.70290377736092, 86.45068868994713, 92.53214076161385, 99.55035656690598, 99.13060069084167, 96.45821928977966, 101.03657081723213, 96.53961092233658, 80.37946566939354, 80.56447014212608, 75.8224917948246, 82.98854246735573, 84.31803032755852, 86.65682762861252, 89.89553824067116, 99.09856840968132, 101.72602102160454, 92.97203555703163, 90.47582790255547, 97.96376690268517, 93.0984015762806, 94.64212954044342, 97.91770577430725, 95.22337675094604, 94.88474652171135, 95.64547330141068, 87.40409553050995, 55.34958556294441, 3.617908414453268, 3.7388003524392843, 3.9321895502507687, 1.4310660283081234, 0.32745238684583455, 0.10641720844432712, 0.3397959057474509, 0.12020640133414418, 0.6752606376539916, 0.88865035912022, 19.208611473441124, 52.938246354460716, 48.43904457986355, 61.70684963464737, 131.82553589344025, 123.19230034947395, 86.148901283741, 76.24693661928177, 26.69963590800762, 37.87944160401821, 78.89041677117348, 94.74688991904259, 94.0956200659275, 115.9411570429802, 14.740307740867138, 0.8905699092429131, 0.4987226449884474, 0.3160023543750867, 0.18461202504113317, 0.24241180712124333, 0.18823094491381198, 0.1944201299920678, 0.10891258352785371, 0.12470025394577533, 0.1855714141856879, 0.17613220115890726, 0.2199221498449333, 0.21756752306828275, 0.09796856960747391, 0.11992010302492417, 0.20294325076974928, 0.13844684755895287, 0.161126064194832, 0.19183839118340984, 0.12903916096547619, 0.13846382789779454, 0.14725098997587338, 0.2742841554572806, 0.12211090812343173, 0.18810464622220024, 0.12450578156858683, 0.09509058771072887], [0.058817949320655316, 0.012676553960773163, 0.06092615338275209, 0.0288619969796855, 0.040541000562370755, 0.05175034712010529, 0.02941944450867595, 0.04934486096317414, 0.08017817657673731, 0.023901667445898056, 0.03350142185809091, 0.04414504408487119, 0.025197735594701953, 0.06295343366218731, 0.04006494993518572, 0.0839953166723717, 0.01512255674242624, 0.13025686203036457, 0.021443436853587627, 0.04274858190910891, 0.035823227153741755, 0.07316231320146471, 0.14076317951548845, 68.13261643052101, 122.82594680786133, 111.53713256120682, 97.96440526843071, 72.55644544959068, 28.28342132270336, 35.79039730131626, 64.62350472807884, 61.86488315463066, 70.4770678281784, 65.99920570850372, 32.235239669680595, 3.0258182482793927, 0.2515584952197969, 0.07631356129422784, 0.2096252961200662, 0.057266749354312196, 0.1740975142456591, 0.05610413420072291, 0.9120046184398234, 5.393180754035711, 0.14446989545831457, 73.07261735200882, 118.02899301052094, 100.10568156838417, 102.10611462593079, 82.07991242408752, 81.7004343867302, 82.0533974468708, 90.65330117940903, 85.62634572386742, 81.60801574587822, 77.98687845468521, 78.01123514771461, 72.53249153494835, 76.86800569295883, 74.58407744765282, 79.8205840587616, 74.96091082692146, 76.9910354912281, 68.11193034052849, 67.03537210822105, 66.61718934774399, 68.92996564507484, 66.10334292054176, 69.74334239959717, 66.60379126667976, 68.60230922698975, 77.00755700469017, 90.0982877612114, 86.85744166374207, 86.19226455688477, 71.61463558673859, 68.1591086089611, 74.77902218699455, 92.38698095083237, 83.4988322854042, 88.9622551202774, 89.3309873342514, 80.90110927820206, 72.39933907985687, 82.36095294356346, 79.45334896445274, 96.51721492409706, 57.10960932075977, 44.33944836258888, 93.52964043617249, 76.53872296214104, 83.08739796280861, 84.86118078231812, 92.9608641564846, 83.17796230316162, 86.72656148672104, 84.81030151247978, 83.20690914988518, 75.10389715433121, 88.1151969730854, 87.08383351564407, 91.05446085333824, 88.50333854556084, 85.09019449353218, 70.0561872124672, 70.06238088011742, 69.01545345783234, 70.89328229427338, 67.33817785978317, 74.85969185829163, 78.45343261957169, 90.11870786547661, 91.93392366170883, 87.07969933748245, 84.1642677783966, 85.34390687942505, 88.3072766661644, 89.92380112409592, 80.80196499824524, 87.25340321660042, 84.2538745701313, 86.41398265957832, 85.62212035059929, 87.39840343594551, 34.108865931630135, 0.7197725179139525, 0.5017516762018204, 0.544774392619729, 0.273879180313088, 0.20495739503530785, 0.1966545733739622, 0.057767238904489204, 0.17560566222527996, 0.07354021479841322, 0.38930626935325563, 5.6278761103749275, 28.44354473054409, 38.247071877121925, 25.73086269199848, 57.35215790569782, 138.1695994734764, 130.05990743637085, 74.35546651482582, 25.96426136791706, 28.52639928460121, 61.42742782831192, 75.60638219118118, 91.74161598086357, 34.868783354759216, 0.7476371352095157, 0.08726441039470956, 0.07487363895052113, 0.06354114040732384, 0.11188493692316115, 0.03614904482674319, 0.036084704333916306, 0.09114831409533508, 0.031701698899269104, 0.002920077672570187, 0.02487410540197743, 0.010589874036668334, 0.018035034590866417, 0.05767192487837747, 0.0221955961023923, 0.0803165500110481, 0.042509836712270044, 0.13366952422074974, 0.005043797955295304, 0.04944748514390085, 0.06505556695628911, 0.04484794699237682, 0.05403793940786272, 0.029309560268302448, 0.009637999137339648, 0.03952495215344243, 0.04291352794098202, 0.052641699876403436, 0.03626186982728541, 0.0548166786757065, 0.04909331371891312, 0.07242639214382507, 0.06942809326574206, 0.0221872747715679, 0.06746969171217643, 0.09385874873260036, 0.023151899767981376, 0.07833572817617096, 0.06102594627009239, 0.019402714424359147, 0.017353956391161773, 0.021492312844202388, 0.03639411683252547, 0.042665680302889086, 0.022993208185653202, 0.015137085210881196, 0.07822441344615072, 0.007488505225410336, 0.10097502468852326, 0.5674177932087332, 91.99148297309875, 136.23758554458618, 121.70195192098618, 111.25694319605827, 86.11858651041985, 53.092100098729134, 46.8148597329855, 29.51852034777403, 71.43807426095009, 95.29309540987015, 58.7925960123539, 42.63556659221649, 3.9400377916172147, 0.42306535004172474, 0.11855256234412082, 0.31767373031470925, 0.017917817931447644, 0.1355205147410743, 0.03811311638855841, 0.3537139651598409, 1.6176662966609001, 1.4365348848514259, 81.5214715898037, 119.80383977293968, 103.97528752684593, 107.61752128601074, 87.58761048316956, 82.762051820755, 86.52906328439713, 95.30563473701477, 89.1937766969204, 87.09271743893623, 81.87843203544617, 82.63363391160965, 75.0859697163105, 79.69604194164276, 78.97453665733337, 84.70652908086777, 78.42369541525841, 80.57356685400009, 72.83630803227425, 71.74126759171486, 71.383455991745, 72.30447337031364, 68.9325875043869, 72.31193616986275, 70.12057095766068, 72.9276779294014, 80.5809460580349, 94.70748603343964, 91.36868879199028, 89.6884037554264, 74.42757904529572, 70.47795698046684, 79.49330762028694, 94.67389583587646, 86.02848574519157, 90.56079894304276, 90.754124969244, 83.36989760398865, 75.14312624931335, 86.55133008956909, 83.18965047597885, 100.17134204506874, 63.004271015524864, 46.67291074991226, 91.64792820811272, 78.61943051218987, 83.98639932274818, 85.85792049765587, 96.0367003083229, 88.44267100095749, 91.73159971833229, 90.00608190894127, 85.60670077800751, 79.60316732525826, 91.18946760892868, 92.1944908797741, 94.4105015695095, 92.73014813661575, 89.48218882083893, 75.17188310623169, 73.81398797035217, 72.87319645285606, 74.15831789374352, 71.66756674647331, 78.46418604254723, 83.47837418317795, 92.82613098621368, 95.2715277671814, 88.13055574893951, 86.72126457095146, 87.86272332072258, 92.79740452766418, 92.14119493961334, 85.95549166202545, 89.49598968029022, 87.94700279831886, 86.64456948637962, 89.43266227841377, 89.85057905316353, 42.72162817418575, 0.9999995841644704, 1.2457622028887272, 0.6995494093280286, 0.2463740445091389, 0.305519993416965, 0.06977417157031596, 0.15693229157477617, 0.17480176786193624, 0.06068485148716718, 0.25873749749735, 6.561596682295203, 35.7262871414423, 38.17047938704491, 41.85563564300537, 67.64494299888611, 98.5831792652607, 91.45345464348793, 30.123383291065693, 37.17625513672829, 46.85493618249893, 71.45595610141754, 83.56619507074356, 105.0977472960949, 51.82538107037544, 0.7329723564907908, 0.07944308672449552, 0.04279907763702795, 0.0672201593988575, 0.0934170966502279, 0.06622246801271103, 0.09215688536642119, 0.04588230047374964, 0.020705729075416457, 0.015984272758942097, 0.05000420722353738, 0.029479510230885353, 0.02117724889103556, 0.06556268388521858, 0.0665623345412314, 0.080981722130673, 0.06529621576191857, 0.05986136071442161, 0.02956282001832733, 0.023936882353154942, 0.07720465800957754, 0.05965682110399939, 0.1485691184643656, 0.10325441995519213, 0.009240437120752176, 0.04857304593315348, 0.03458631930698175, 0.0974334217607975, 0.21775982837425545, 0.12775604700436816, 0.18355266860453412, 0.19296547601697966, 0.14212415961083025, 0.08909228301490657, 0.21075247001135722, 0.1337237752159126, 0.13400012132478878, 0.13733169646002352, 0.20612886029994115, 0.08845036980346777, 0.232701190689113, 0.17514216131530702, 0.3428626974346116, 0.1373229836462997, 0.39381389622576535, 0.11282505991403013, 0.21447546867420897, 0.1994435049709864, 0.30139777867589146, 0.5599857482593507, 105.31558960676193, 150.76710909605026, 137.3526281118393, 123.03405404090881, 100.11237680912018, 45.28121642768383, 54.02831666171551, 88.27741026878357, 85.70648342370987, 92.85136923193932, 93.94079357385635, 57.76783660054207, 6.193025009706616, 0.8194948418531567, 0.5687786545604467, 0.5615215189754963, 0.14924805000191554, 0.3638641705038026, 0.35592028114479035, 2.478589187376201, 16.216823011636734, 2.7821525232866406, 81.95859253406525, 122.8543008863926, 108.0297763645649, 111.54684484004974, 92.35925763845444, 87.65921384096146, 90.31188189983368, 100.65954744815826, 93.09561252593994, 91.1273105442524, 85.14253288507462, 87.19300165772438, 78.31360012292862, 85.89743077754974, 82.04135969281197, 89.39674660563469, 83.80182042717934, 85.31795427203178, 78.0269131064415, 76.29194900393486, 73.73165398836136, 75.79447209835052, 72.91043445467949, 76.91381603479385, 75.95151007175446, 78.47975760698318, 85.01684322953224, 98.83664086461067, 93.56784358620644, 96.67778670787811, 78.16312059760094, 73.35823282599449, 83.15272405743599, 99.80118110775948, 91.63740277290344, 93.47878396511078, 94.28190127015114, 87.77756989002228, 79.99086052179337, 91.55111700296402, 89.18432280421257, 104.02539923787117, 69.70171183347702, 53.95129479467869, 92.7726298570633, 81.10073536634445, 87.26246953010559, 90.56062415242195, 99.20575305819511, 93.68418574333191, 94.42359566688538, 94.686359167099, 90.02038434147835, 85.39014279842377, 96.37537613511086, 94.7387507557869, 98.70645225048065, 97.73048982024193, 95.8571295440197, 77.9465702176094, 77.39768967032433, 77.65645578503609, 79.35565620660782, 75.42858973145485, 83.61660316586494, 87.32920154929161, 97.07089081406593, 102.04270362854004, 92.6571236550808, 88.7186273932457, 90.96100866794586, 98.6318850517273, 97.22450137138367, 89.00634035468102, 94.85328420996666, 91.56806409358978, 92.23466232419014, 91.73540711402893, 91.77404344081879, 41.63132227957249, 2.929551601409912, 6.718694027513266, 3.446306772530079, 1.3090136088430882, 0.6584912468679249, 0.324368110159412, 0.24303262849571183, 0.31241365475580096, 0.19084401719737798, 0.7261523755732924, 14.00983588770032, 46.20690755546093, 58.29688601195812, 36.39469027519226, 77.85925090312958, 164.59406554698944, 163.4476062655449, 92.54835069179535, 38.676661625504494, 45.91106303036213, 82.83962845802307, 96.03025585412979, 116.80319398641586, 59.85167898237705, 0.9595577011350542, 0.3627079341094941, 0.155656777205877, 0.14551702130120248, 0.27662198001053184, 0.13198278582422063, 0.12441679064068012, 0.19532648526364937, 0.11024093138985336, 0.07883420650614426, 0.18827718071406707, 0.09131033235462382, 0.14247403771150857, 0.17947458196431398, 0.17794673738535494, 0.16774999938206747, 0.1540804555406794, 0.20850045257247984, 0.08836866676574573, 0.1085546234389767, 0.160030446422752, 0.1191321574151516, 0.19526589632732794, 0.16375844716094434, 0.11501450688228942, 0.13084404927212745, 0.18178895465098321], [0.014980595024098875, 0.033220975383301266, 0.04720531600469258, 0.03868497457006015, 0.08104409964289516, 0.08192785651772283, 0.035128050003550015, 0.03922441574104596, 0.09552979070576839, 0.028363899000396486, 0.06764339137589559, 0.07717175118159503, 0.13989948289236054, 0.010708858862926718, 0.08489457701216452, 0.05577843156061135, 0.09905653583700769, 0.023927670445118565, 0.1813229007530026, 0.003369905671206652, 0.3816562704741955, 0.6822717958129942, 16.918516159057617, 118.70040938258171, 121.95254847407341, 104.2971758544445, 74.40869405865669, 70.38752183318138, 28.729283697903156, 43.24337437748909, 95.30918374657631, 41.40541300177574, 39.78970929980278, 33.06108355522156, 4.462157087400556, 0.10465097118867561, 0.021986078536428977, 0.05577752242970746, 0.12263084936421365, 0.12935760169057176, 0.15815247141290456, 0.0948986757430248, 0.6511214235797524, 1.780882857274264, 16.648470349609852, 116.79358050227165, 101.39411643147469, 106.08033657073975, 82.93207749724388, 81.93480581045151, 77.67512038350105, 82.83447593450546, 81.29947230219841, 86.80609121918678, 81.79522410035133, 81.55116319656372, 78.53377550840378, 78.14442560076714, 76.087466776371, 81.63757055997849, 76.28556534647942, 79.41857323050499, 73.74136626720428, 66.052266061306, 65.79811289906502, 68.91738072037697, 66.89505323767662, 70.01924559473991, 66.25170215964317, 67.72071853280067, 64.02212619781494, 75.31388908624649, 85.04591926932335, 82.46820598840714, 74.11385267972946, 67.55555659532547, 66.85960114002228, 81.39100939035416, 84.71391588449478, 87.38897994160652, 83.57808083295822, 85.41170284152031, 80.88299185037613, 71.76765337586403, 75.26747077703476, 72.87524074316025, 90.4551874101162, 69.76606518030167, 41.77253030240536, 85.71771562099457, 74.49761688709259, 78.87745186686516, 73.99879485368729, 88.02662372589111, 85.0147533416748, 88.29387098550797, 83.62305521965027, 88.59166860580444, 76.64294376969337, 78.99967610836029, 87.02882006764412, 92.69736349582672, 86.35314792394638, 79.95893463492393, 68.33545714616776, 68.76647561788559, 66.89684674143791, 66.688541918993, 67.46050849556923, 78.62828403711319, 85.00460788607597, 91.96594074368477, 89.92535904049873, 77.1216268837452, 82.65302807092667, 88.00239622592926, 85.36775439977646, 85.34894540905952, 89.55747798085213, 84.0845100581646, 83.81681442260742, 87.44966268539429, 87.42631673812866, 87.62012153863907, 90.05577564239502, 28.7435120344162, 0.9800329024437815, 1.2781003676354885, 0.8898401109036058, 0.2487976019619964, 0.2406611104379408, 0.2962975617265329, 0.17526237439597026, 0.14272356260335073, 0.16477930097607896, 0.08686030356329866, 2.2532950015738606, 31.424530372023582, 26.384423822164536, 62.138031497597694, 114.54621389508247, 131.4888435602188, 131.99860900640488, 38.24124678969383, 27.570921555161476, 47.634209766983986, 74.06738117337227, 79.36324059963226, 77.44899451732635, 3.0038198037073016, 0.3810512716881931, 0.0263667554827407, 0.0692926364718005, 0.012011390190309612, 0.050355877610854805, 0.050887952966149896, 0.028743949114868883, 0.04411174391862005, 0.015608117064402904, 0.06577334250323474, 0.04026904054626357, 0.047066181869013235, 0.06234368513105437, 0.039452629862353206, 0.08403226820519194, 0.02264228922285838, 0.08170421773684211, 0.0221460206375923, 0.02148554260202218, 0.029282646282808855, 0.1573164717410691, 0.04927493951981887, 0.01134174292019452, 0.03841334109893069, 0.08111372051644139, 0.015374469494418008, 0.0051230635017418535, 0.012635687598958611, 0.06331373893772252, 0.027400656254030764, 0.0492627831408754, 0.03463183151325211, 0.12375606398563832, 0.01689085995167261, 0.05574516850174405, 0.048904207069426775, 0.06796819972805679, 0.005439704518721555, 0.05786671637906693, 0.014815702797932317, 0.08456058087176643, 0.053368837616289966, 0.13875308737624437, 0.07351438063778915, 0.35617929068394005, 0.11058611911721528, 0.5348822171799839, 0.8073717704974115, 31.440791599452496, 138.36568415164948, 129.96042877435684, 121.60800576210022, 89.28329229354858, 91.76639825105667, 43.28877054154873, 32.368464320898056, 71.24115362763405, 43.06736022233963, 31.988222524523735, 49.406495466828346, 6.050197798758745, 0.20908183621941134, 0.011459020806796616, 0.13124241930199787, 0.09985073033021763, 0.13162426912458614, 0.14563530479790643, 0.03779912483878434, 0.7840457127895206, 0.8057290711440146, 20.558091960847378, 120.86608037352562, 105.39882034063339, 110.7391069829464, 85.40433883666992, 86.3593415915966, 80.76175555586815, 87.58879601955414, 84.1658028960228, 91.12426310777664, 86.15520894527435, 85.24020284414291, 79.9565863609314, 84.12478789687157, 79.44463223218918, 83.41937094926834, 80.48676431179047, 84.32746142148972, 77.7945251762867, 71.91497907042503, 69.15351524949074, 73.27380895614624, 68.85966941714287, 71.94176763296127, 67.6330192387104, 70.86708649992943, 66.41426503658295, 79.40052419900894, 89.36246484518051, 88.79036754369736, 77.1240283548832, 70.7681930065155, 69.61072191596031, 85.78109622001648, 89.70278218388557, 88.52291509509087, 86.8695630133152, 91.2032000720501, 85.53993836045265, 77.69459813833237, 78.3341646194458, 79.2739985883236, 92.71911352872849, 75.19163444638252, 44.64587911963463, 85.54688438773155, 76.03179216384888, 84.5859083533287, 79.14609745144844, 91.17548435926437, 89.10543903708458, 94.19527351856232, 88.94196420907974, 91.2830413877964, 79.91313949227333, 81.15535363554955, 91.00484311580658, 95.38016393780708, 89.35793548822403, 82.42809534072876, 72.49663665890694, 70.36766409873962, 70.90234860777855, 71.72087788581848, 71.70722901821136, 83.92121762037277, 88.5569916665554, 95.34195318818092, 91.93159818649292, 78.07146951556206, 85.54651200771332, 91.84093505144119, 89.19261395931244, 89.74457234144211, 93.38039204478264, 88.47884505987167, 88.08791443705559, 90.80182760953903, 92.35942482948303, 89.40710484981537, 93.70629295706749, 39.42505806684494, 0.49324799969326705, 0.1688559478498064, 0.49433794745709747, 0.1270425907569006, 0.6586399138905108, 0.1323072231025435, 0.31661792134400457, 0.13814831123454496, 0.19080153666436672, 0.1392441219650209, 2.459968999028206, 37.86552295088768, 22.9951785877347, 62.1580146253109, 118.74039083719254, 128.54470074176788, 102.66305834054947, 29.218022972345352, 33.41559313237667, 54.88143928349018, 82.23512649536133, 87.1307609975338, 101.35497093200684, 6.953110573813319, 0.7234815345145762, 0.06170798740640748, 0.12053489073878154, 0.05086094621219672, 0.11396922898711637, 0.01328122527411324, 0.021952203205728438, 0.05329411447746679, 0.04883237088506576, 0.04299039959732909, 0.04923605840303935, 0.04426044804858975, 0.03541101606970187, 0.07350784973823465, 0.045647492370335385, 0.0372928428259911, 0.08574723789934069, 0.014070740526221925, 0.018071121521643363, 0.034171017177868634, 0.17129421466961503, 0.051767761615337804, 0.01643955438339617, 0.06167062027088832, 0.07358190123341046, 0.03571632820239756, 0.13148317200830206, 0.12871050828834996, 0.08246091892942786, 0.1290790142957121, 0.12602280563442037, 0.19551218545529991, 0.2867544034961611, 0.1890300598461181, 0.20968811149941757, 0.11718050198396668, 0.18109553639078513, 0.13055286020971835, 0.27064445544965565, 0.16136340302182361, 0.18723410699749365, 0.15618089673807845, 0.1996582528227009, 0.2574280818225816, 0.4172963392920792, 0.285124676884152, 0.7879865169525146, 1.1741520767100155, 39.88057762384415, 160.56229948997498, 141.5984746813774, 135.14493137598038, 94.18017312884331, 92.12534978985786, 40.81591263413429, 61.50987200438976, 132.7544340491295, 64.80710327625275, 61.71779304742813, 56.40876352787018, 9.767093751579523, 0.6497151427902281, 0.1257235716911964, 0.46271087892819196, 0.4423603287432343, 0.34680828102864325, 0.3477552020922303, 0.5456179473549128, 2.795827751979232, 4.11022899672389, 18.465076871216297, 125.21094962954521, 109.10454869270325, 114.71196100115776, 89.23529326915741, 90.48713609576225, 85.2818638086319, 92.8350681066513, 87.38066598773003, 95.44751152396202, 88.806873857975, 90.35202294588089, 85.94636455178261, 87.85779118537903, 83.88078019022942, 87.99854323267937, 83.70123982429504, 88.87816563248634, 82.53922417759895, 74.92887854576111, 73.79539176821709, 76.46892830729485, 73.51847782731056, 77.53474831581116, 72.81347885727882, 75.40981113910675, 70.15587866306305, 84.53990802168846, 93.09998229146004, 92.88337111473083, 82.38887384533882, 74.0652684867382, 73.96144285798073, 90.01267835497856, 93.65361258387566, 93.42710673809052, 88.19195285439491, 96.14608883857727, 90.78328460454941, 81.03876829147339, 84.42907556891441, 83.71619582176208, 98.81618276238441, 81.30677551031113, 47.593760937452316, 86.60543158650398, 79.47227954864502, 85.9280875325203, 80.8297111093998, 96.27049416303635, 93.67965638637543, 98.1001415848732, 90.43182626366615, 97.60550692677498, 82.84722045063972, 86.3496521115303, 94.47201266884804, 99.97651889920235, 93.7989091873169, 88.88115987181664, 76.70248657464981, 76.63389265537262, 73.12330663204193, 73.84967565536499, 75.77897652983665, 89.2089530825615, 93.4818086028099, 98.67421478033066, 93.89367610216141, 80.2580089867115, 88.75940680503845, 98.02036106586456, 93.51316452026367, 95.31420707702637, 97.19481736421585, 92.18730926513672, 91.00001737475395, 93.70497062802315, 94.17024806141853, 92.99382358789444, 95.46350866556168, 36.84478372335434, 2.1263122279196978, 4.756211908534169, 2.9268599208444357, 0.6688687275163829, 1.2307373341172934, 0.8527812932152301, 0.5480926833115518, 0.29539947398006916, 0.27578970592003316, 0.3423987660789862, 5.498375259339809, 52.98233538866043, 45.26236183941364, 74.31284800171852, 115.35900548100471, 134.27546203136444, 164.81898307800293, 54.51765440404415, 43.414315804839134, 62.95058749616146, 98.45716282725334, 95.49631610512733, 116.09254091978073, 6.673694467172027, 0.77082141302526, 0.1436318177729845, 0.15367782558314502, 0.1444430000265129, 0.2477047746651806, 0.10633264813804999, 0.0902502634562552, 0.10268148194882087, 0.12288231868296862, 0.21978575794491917, 0.14777037460589781, 0.1214117233757861, 0.23654223536141217, 0.1429900826769881, 0.20424775342689827, 0.1779980494757183, 0.12973679462447762, 0.11884460487635806, 0.2039818122284487, 0.11790396238211542, 0.36173097090795636, 0.20785172644536942, 0.17698415700579062, 0.12232185617904179, 0.19379712670342997, 0.12295148684643209], [0.008748582458792953, 0.05004901067877654, 0.049298732774332166, 0.026445760813658126, 0.029320501380425412, 0.06472510343883187, 0.037179179198574275, 0.016372458667319734, 0.025692826020531356, 0.06021643384883646, 0.02856958337360993, 0.02071570354019059, 0.027092626005469356, 0.03906530670064967, 0.03085345379076898, 0.07962308722198941, 0.0433474505553022, 0.04742662073113024, 0.03687310265377164, 0.04926139903545845, 0.05359082140785176, 1.019692977424711, 75.24708107113838, 118.4214435517788, 109.41497683525085, 82.31791645288467, 125.65838322043419, 91.55506119132042, 54.287918731570244, 85.53539380431175, 32.77636483311653, 70.42487382888794, 55.68467058241367, 8.555247578769922, 0.1282572787022218, 0.04542961636616383, 0.08993439798359759, 0.09054623937117867, 0.06153089241706766, 0.09683539174147882, 0.017665630584815517, 0.09460346424020827, 0.2256640128325671, 3.0053850822150707, 86.67169243097305, 112.93879374861717, 104.57671165466309, 96.91098779439926, 88.56363371014595, 80.55511504411697, 73.6611145734787, 76.2961819767952, 84.0021076798439, 87.50757917761803, 85.74926152825356, 83.5337296128273, 82.01492071151733, 78.63250181078911, 81.92868053913116, 80.73697328567505, 77.38061338663101, 76.7034213244915, 69.37882795929909, 67.3466894030571, 67.76865676045418, 65.11378481984138, 70.12394517660141, 67.62260019779205, 70.53332760930061, 66.59492254257202, 66.86191141605377, 72.00726851820946, 79.43381801247597, 76.6053257882595, 72.13141545653343, 64.68462824821472, 73.56057196855545, 80.40489390492439, 89.17758196592331, 86.89835786819458, 79.52502831816673, 86.99808731675148, 81.53140425682068, 74.36081662774086, 69.45141926407814, 71.83556333184242, 85.16334056854248, 77.71120324730873, 44.21167641878128, 80.42472124099731, 79.561787545681, 83.30035373568535, 80.66402480006218, 75.79152345657349, 79.89051550626755, 81.69311597943306, 86.39082670211792, 85.72688832879066, 84.39672410488129, 75.26573807001114, 77.76690825819969, 85.41482627391815, 85.3902567923069, 74.87473145127296, 66.98975175619125, 64.80333387851715, 65.47727331519127, 66.29938200116158, 66.07905462384224, 80.63066259026527, 83.20691674947739, 85.17111495137215, 80.14306515455246, 81.0069639980793, 87.02115207910538, 83.07396948337555, 84.79123413562775, 84.95479255914688, 86.4469800889492, 83.39175403118134, 84.07510936260223, 83.2799944281578, 84.96521160006523, 87.2094851732254, 88.24407085776329, 94.30720031261444, 31.269451193511486, 0.16906676231883466, 1.0505835385993123, 0.02715215738135157, 0.06924187357071787, 0.21234087384073064, 0.13974924251670018, 0.05735472725064028, 0.12986799149075523, 0.07357024209341034, 0.30479102628305554, 0.8970645326189697, 29.218385852873325, 65.68060800433159, 97.74465546011925, 109.3966694176197, 73.59385818243027, 85.29585465788841, 49.94640089571476, 54.511456936597824, 72.08438158035278, 81.15650117397308, 81.84622496366501, 31.75050538033247, 0.6379829160869122, 0.3036076866555959, 0.15951313980622217, 0.045450830657500774, 0.06238263304112479, 0.024957494970294647, 0.11283660773187876, 0.0663006903778296, 0.01633531974221114, 0.030732908599020448, 0.08374284545425326, 0.009978207981475862, 0.04530566657194868, 0.031129584676818922, 0.10960524479742162, 0.04049617113196291, 0.04795758657564875, 0.02274204871355323, 0.01938277291628765, 0.05039299983764067, 0.05692257094779052, 0.06576621788553894, 0.012485688421293162, 0.029613184015033767, 0.03179733575962018, 0.037310105180949904, 0.010367362392571522, 0.03386402408068534, 0.034525882510934025, 0.047084082470973954, 0.062229724644566886, 0.010510842730582226, 0.10057971230708063, 0.026960260256601032, 0.048087191535159945, 0.07009532113443129, 0.056733686942607164, 0.024597506962891202, 0.026647964514268097, 0.07092343177646399, 0.08441297512035817, 0.07532524323323742, 0.052839196505374275, 0.0790249087731354, 0.041155227954732254, 0.023897513274278026, 0.04925610752252396, 2.4186184303835034, 99.24176752567291, 129.49600249528885, 120.54992973804474, 93.94550532102585, 120.63334286212921, 98.99446159601212, 50.52081227302551, 53.63830178976059, 41.61079578101635, 47.30805426836014, 66.25718146562576, 10.550912842154503, 0.1988568520755507, 0.08173474969225936, 0.11640052704024129, 0.13020697486354038, 0.12666663358686492, 0.050466539250919595, 0.18012896325672045, 0.3986432292731479, 0.27049451193306595, 5.321273887529969, 93.2853515446186, 113.72890055179596, 110.19233912229538, 101.14395305514336, 93.0208857357502, 82.24263489246368, 77.17689871788025, 78.51574927568436, 89.52445775270462, 90.26202097535133, 88.27779784798622, 89.11611646413803, 87.67714887857437, 83.15677464008331, 85.34399807453156, 85.07585406303406, 81.84104204177856, 79.63606595993042, 73.46768975257874, 69.73004311323166, 69.31326627731323, 68.3845429122448, 72.420883923769, 69.7633521258831, 71.77820160984993, 69.57318753004074, 70.84504008293152, 76.17435291409492, 82.75198996067047, 77.75601804256439, 73.94517973065376, 66.42758712172508, 74.83555555343628, 85.90895935893059, 92.0228236913681, 90.58082386851311, 81.48986488580704, 88.75451266765594, 84.266999065876, 75.54458230733871, 71.34754031896591, 76.64633318781853, 89.59350004792213, 82.30520993471146, 47.56478749215603, 80.48462882637978, 79.80945825576782, 84.95698884129524, 83.67843344807625, 79.73558261990547, 82.46056079864502, 83.26955258846283, 87.97316819429398, 90.08634880185127, 90.0496655702591, 79.92773830890656, 80.9391376376152, 88.32061395049095, 88.01062658429146, 76.56248688697815, 68.9447620511055, 68.6181391775608, 68.7906651198864, 70.5236229300499, 71.35243445634842, 84.41240206360817, 87.16876655817032, 87.7645593881607, 83.17223221063614, 82.89357036352158, 89.90564569830894, 86.16260334849358, 87.05076768994331, 91.42216712236404, 88.68589594960213, 87.33354091644287, 88.97564560174942, 87.33832105994225, 87.52809807658195, 91.86491936445236, 90.88541552424431, 100.4861855506897, 40.20919919013977, 0.9606999554671347, 1.2041317555122077, 0.25507499871309847, 0.1358925979002379, 0.27535249188076705, 0.04618147504515946, 0.1014010768267326, 0.1684101248974912, 0.07210758776636794, 0.5106393399182707, 0.9415660228114575, 25.999192893505096, 59.26323115825653, 103.69183793663979, 113.85756924748421, 80.43541386723518, 58.05884398519993, 55.89382655918598, 61.10811196267605, 83.74957323074341, 85.70879369974136, 94.35136154294014, 52.07423731684685, 0.3250368149019778, 0.17394843162037432, 0.11146873308462091, 0.05677531400579028, 0.10719675294240005, 0.04316087091865484, 0.01319494596828008, 0.053925915926811285, 0.08328026480739936, 0.033012576604960486, 0.03960266985814087, 0.011702485135174356, 0.03683950562844984, 0.043419947251095437, 0.06887048803037032, 0.03129096839984413, 0.024168959353119135, 0.0748559609928634, 0.0328546846867539, 0.051678700183401816, 0.0631395642994903, 0.048696587546146475, 0.02078708330373047, 0.04796336048457306, 0.012831733329221606, 0.050096845807274804, 0.07515448247431777, 0.09123999901930802, 0.15562615619273856, 0.17947185086086392, 0.12203327205497772, 0.12306791497394443, 0.19530422083334997, 0.08127279244945385, 0.09481338071054779, 0.1960753567982465, 0.150284607661888, 0.16440895444247872, 0.08494864247040823, 0.15178851055679843, 0.14467634609900415, 0.09293047041865066, 0.20452528697205707, 0.24032472458202392, 0.12793392495950684, 0.23483382625272498, 0.19349723967025056, 2.972089843824506, 113.58179524540901, 144.68755692243576, 137.20097064971924, 106.60394087433815, 140.71491569280624, 106.61458030343056, 74.91716757416725, 114.77266654372215, 54.97220501303673, 100.31491354107857, 86.71922028064728, 16.422849856317043, 0.41583766287658364, 0.230452052783221, 0.30424795229919255, 0.2505342126823962, 0.46152611437719315, 0.19664531137095764, 0.3902762266807258, 1.4985201274976134, 0.8152740402147174, 6.092918431386352, 96.88465520739555, 118.7598229944706, 113.89986097812653, 105.70502310991287, 97.4201300740242, 89.28830802440643, 82.0193512737751, 84.19632285833359, 93.98848861455917, 95.15514761209488, 94.29350584745407, 92.1257221698761, 90.65421313047409, 87.61966556310654, 92.14545831084251, 88.47122266888618, 86.74150228500366, 84.57514733076096, 78.12443867325783, 72.61338919401169, 73.2218885421753, 72.06663653254509, 76.94936692714691, 74.4783291220665, 77.02645719051361, 73.16730067133904, 75.65805941820145, 81.23514175415039, 87.41934031248093, 83.69292587041855, 78.80165353417397, 70.35515516996384, 79.77112591266632, 90.94801336526871, 96.9920526444912, 90.5768720805645, 85.64897730946541, 96.15393161773682, 89.27168011665344, 80.68270459771156, 77.20512360334396, 79.08765658736229, 96.54026448726654, 85.22085428237915, 53.99599939584732, 80.6836849451065, 84.67942133545876, 86.78261607885361, 88.14102798700333, 84.50639382004738, 89.25490781664848, 87.89744585752487, 92.55864813923836, 93.27698439359665, 94.47151109576225, 84.42149877548218, 86.50693327188492, 91.59532383084297, 92.74199590086937, 81.92706942558289, 72.19128504395485, 70.79426720738411, 72.94549897313118, 72.88084924221039, 72.46825978159904, 87.4720586836338, 91.34848147630692, 92.16316536068916, 86.29401549696922, 87.89965733885765, 95.12705951929092, 89.39971044659615, 94.25404876470566, 94.45386484265327, 96.29921302199364, 92.34487161040306, 93.68380576372147, 90.06586790084839, 91.22948706150055, 96.0400441288948, 96.31236031651497, 99.32703495025635, 39.68565948307514, 1.7119074147194624, 2.642586249858141, 0.39605794299859554, 0.7871836319100112, 0.696044156793505, 0.59221395640634, 0.21694716182537377, 0.42332044104114175, 0.18837732612155378, 0.5463370587676764, 1.512844527605921, 54.6415201574564, 85.18464222550392, 106.83515846729279, 113.31285327672958, 91.58864378929138, 103.34736362099648, 67.29074880480766, 69.05271425843239, 96.10053688287735, 98.35872530937195, 110.58880224823952, 54.45646248757839, 0.8385611500125378, 0.43602048768661916, 0.3229394758818671, 0.17376222676830366, 0.25660420884378254, 0.14965298061724752, 0.2766689728014171, 0.173854089807719, 0.13988952327053994, 0.10872502796701156, 0.2618861629161984, 0.1649400798487477, 0.17499956506071612, 0.1743159579928033, 0.19644659390905872, 0.17781464994186535, 0.1849842566298321, 0.2701621485175565, 0.15089162508957088, 0.10889269397011958, 0.12571827275678515, 0.13544091198127717, 0.16926559852436185, 0.10629669108311646, 0.20836078037973493, 0.1609668883611448], [0.032570059920544736, 0.04529047480900772, 0.07303979946300387, 0.07503931599785574, 0.05067899386631325, 0.038024518798920326, 0.08629185555037111, 0.08844544194289483, 0.07523525040596724, 0.08994835035991855, 0.14695414574816823, 0.0523884085851023, 0.009619736738386564, 0.016433594937552698, 0.050446753593860194, 0.06681876140646636, 0.015575726029055659, 0.0897878609248437, 0.10548349760938436, 0.13212121120886877, 0.2621118351817131, 17.989186607301235, 118.75663116574287, 109.14156630635262, 106.15360423922539, 89.87077876925468, 125.73167368769646, 98.6475782096386, 91.41958326101303, 79.86368894577026, 53.984786197543144, 58.53636056184769, 8.914937227964401, 0.2487542456947267, 0.039973387465579435, 0.15814895363291726, 0.1765097613679245, 0.07859537596232258, 0.30889047193340957, 0.1965946820564568, 0.3120857145404443, 0.28769889031536877, 0.29720897844526917, 42.128973975777626, 113.82225394248962, 98.51263985037804, 104.17951136827469, 95.0207944214344, 91.46005108952522, 75.36833256483078, 74.32463496923447, 71.9897210597992, 76.53797820210457, 79.39724117517471, 84.69539567828178, 85.09337112307549, 85.43786063790321, 84.08321052789688, 84.20364126563072, 78.71631011366844, 82.82955899834633, 76.34923473000526, 70.66115275025368, 66.31872296333313, 66.79371267557144, 65.41569381952286, 67.44426056742668, 64.11374688148499, 67.8064115345478, 66.3456255197525, 66.63969933986664, 69.27135452628136, 69.6210877597332, 66.25201374292374, 65.9527114033699, 67.15856909751892, 77.62037292122841, 86.5658301115036, 87.90193721652031, 81.20174154639244, 80.51030784845352, 81.29747360944748, 79.7859451174736, 77.21909165382385, 73.33049431443214, 72.78715386986732, 79.7679340839386, 85.33673286437988, 45.23796334862709, 70.95861598849297, 77.56972923874855, 74.40883845090866, 83.62946927547455, 78.97522822022438, 78.32946807146072, 77.07802802324295, 78.06497186422348, 83.3611960709095, 86.41725048422813, 78.26361000537872, 73.39151903986931, 70.89699849486351, 70.89138999581337, 66.15142554044724, 67.24338814616203, 66.28630310297012, 69.62544992566109, 63.577189072966576, 70.27312517166138, 80.65507248044014, 90.35224333405495, 79.96560707688332, 83.48526701331139, 84.25575166940689, 82.65426680445671, 86.48454487323761, 84.04959753155708, 84.53559145331383, 85.67614585161209, 84.41831454634666, 85.71282148361206, 85.60706555843353, 81.46363109350204, 84.72832471132278, 87.33348771929741, 83.99718314409256, 92.52771779894829, 31.638895869255066, 0.30070755165070295, 0.12450443085981533, 0.18807129410561174, 0.11873444789671339, 0.1502313363016583, 0.11921843950403854, 0.09870954469079152, 0.129395124677103, 0.17206322809215635, 0.36491531878709793, 0.3514743415871635, 14.110139105468988, 45.386900156736374, 61.16949766874313, 38.733772560954094, 57.62315556406975, 25.386462472379208, 29.12541624158621, 58.537139520049095, 72.66595557332039, 77.05897584557533, 77.49033629894257, 3.132655927911401, 0.4299103858647868, 0.04146808772929944, 0.013769419292657403, 0.02619311704620486, 0.05675054853782058, 0.05952029190666508, 0.032624351733829826, 0.055066938293748535, 0.0816352351102978, 0.03000124004756799, 0.07341146701946855, 0.021027631919423584, 0.05159370200999547, 0.050631077101570554, 0.05716273735743016, 0.04518561305303592, 0.034772346043610014, 0.06027113755408209, 0.02144421981938649, 0.04126630890823435, 0.04231903425534256, 0.01989197713555768, 0.041977408836828545, 0.07542958177509718, 0.09694514053990133, 0.013029603815084556, 0.03906567406374961, 0.0874547119019553, 0.0495795577444369, 0.015148269376368262, 0.031037517546792515, 0.041555100833647884, 0.041445645183557644, 0.08318261301610619, 0.03937992536521051, 0.030285041029856075, 0.040829272984410636, 0.020845889230258763, 0.024413394967268687, 0.06129019537183922, 0.007602693458466092, 0.03593804853153415, 0.10546167846769094, 0.03942458039091434, 0.193346910236869, 0.1952969774720259, 27.366572320461273, 138.84430646896362, 114.40881326794624, 122.24936574697495, 99.49788138270378, 136.80282801389694, 83.39239239692688, 50.998127460479736, 88.88034671545029, 54.45118837058544, 60.85088096559048, 13.62906876951456, 0.11417438829084858, 0.03188181814039126, 0.17870921990834177, 0.16036469489336014, 0.09609858752810396, 0.3363801265368238, 0.08745077109779231, 0.4215569794178009, 0.2144627334200777, 0.5346644413657486, 50.27287557721138, 115.15631675720215, 103.61686035990715, 106.33663281798363, 96.90649643540382, 94.1247721016407, 79.25392046570778, 76.52876749634743, 74.91392254829407, 77.92578533291817, 82.53859341144562, 89.78424221277237, 88.63139167428017, 88.27372446656227, 88.6682040989399, 87.3240414261818, 84.86491978168488, 86.14763975143433, 79.34301048517227, 75.42736619710922, 70.35310328006744, 72.25905820727348, 67.67497658729553, 69.15533915162086, 67.94438973069191, 70.37017196416855, 69.49548929929733, 68.72431308031082, 72.29735255241394, 73.43449473381042, 71.88182204961777, 68.76493290066719, 69.83888447284698, 82.36862853169441, 90.84582164883614, 93.31191971898079, 83.77763092517853, 84.18547064065933, 86.65701761841774, 85.11615470051765, 80.8391498029232, 75.37525579333305, 75.12187778949738, 82.56290450692177, 89.9646869301796, 49.51733931899071, 71.45708084106445, 79.06266912817955, 79.80500489473343, 87.11514383554459, 82.69534260034561, 82.03858584165573, 82.1425786614418, 80.70352748036385, 83.96939903497696, 88.6695796251297, 83.98364067077637, 74.63836133480072, 72.89009794592857, 72.11331322789192, 71.37799948453903, 69.01622101664543, 69.41799625754356, 71.33503139019012, 67.81950563192368, 73.09340223670006, 85.33716604113579, 94.41620126366615, 81.270312666893, 85.27628570795059, 86.4191047847271, 85.85193201899529, 89.28006246685982, 88.65735948085785, 87.44351461529732, 88.57273802161217, 87.49864965677261, 88.26531931757927, 88.93580853939056, 87.35100477933884, 86.8287456035614, 89.95744451880455, 88.97790268063545, 98.74588653445244, 42.471525594592094, 0.8805505000054836, 0.22579227079404518, 0.13833862758474424, 0.21607389149721712, 0.4567220143508166, 0.1234681774803903, 0.036256355670047924, 0.15563041612040251, 0.05814147058117669, 0.279146350803785, 0.33743501524440944, 17.174628116190434, 50.54606191813946, 70.6420549750328, 50.707154273986816, 51.20562292635441, 31.115242168307304, 38.05312268435955, 67.97554045915604, 80.97299382090569, 84.32361602783203, 100.7418130338192, 11.116997916251421, 0.5449952557682991, 0.20833240065257996, 0.05483027111040428, 0.06927036462002434, 0.04069578288181219, 0.06065050118195359, 0.029008016390434932, 0.008176702012860915, 0.05454564634419512, 0.05858147138496861, 0.12503042060416192, 0.07433578968630172, 0.03915765213605482, 0.05853366223163903, 0.03270489331043791, 0.05536259137443267, 0.030179886125552002, 0.023032710851111915, 0.043105944569106214, 0.008519606708432548, 0.04360315011581406, 0.04404960018291604, 0.013442140516417567, 0.058951836472260766, 0.07015616240096278, 0.14392131473869085, 0.08679261227371171, 0.2992174675455317, 0.19294684811029583, 0.14931442769011483, 0.1763698665308766, 0.14000872703036293, 0.1362710041576065, 0.18094520695740357, 0.20271054294425994, 0.17500237037893385, 0.2199367107823491, 0.09121634677285329, 0.16558963718125597, 0.1428291850606911, 0.12879116489784792, 0.11403722455725074, 0.17507961310911924, 0.14689556061057374, 0.2231942641083151, 0.3353556658839807, 32.45074510574341, 162.57204204797745, 128.06688398122787, 139.20913249254227, 107.66234368085861, 137.68734455108643, 104.08330053091049, 119.22870263457298, 105.51805794239044, 83.73493641614914, 82.52041518688202, 18.354001231491566, 0.5942565842997283, 0.10315659746993333, 0.3466562298126519, 0.3829875943483785, 0.2682814869331196, 0.683844139566645, 0.7859538041520864, 1.3286270876415074, 0.854643490165472, 1.606009709648788, 50.62139667570591, 119.28498521447182, 109.48521986603737, 113.19198936223984, 100.86335331201553, 99.10979300737381, 85.24192795157433, 81.49851322174072, 79.97314587235451, 83.76075983047485, 89.24552991986275, 93.89687553048134, 93.5152468085289, 94.58336189389229, 93.54604795575142, 91.72092989087105, 88.90104800462723, 91.3542191684246, 85.1721028983593, 79.15787681937218, 73.51492881774902, 75.30593231320381, 70.75868591666222, 73.65780875086784, 71.5535880625248, 74.62452247738838, 74.0561717748642, 72.40870177745819, 75.88512763381004, 75.41828468441963, 72.86333218216896, 71.04183152318001, 74.06206145882607, 84.91391435265541, 91.95005759596825, 95.39790898561478, 89.97154176235199, 88.16374316811562, 88.972028195858, 89.21266168355942, 86.3828395307064, 80.72541430592537, 80.99779888987541, 88.66459429264069, 95.70539608597755, 55.371343195438385, 73.56457695364952, 80.51145538687706, 81.42535954713821, 89.67435210943222, 83.84494051337242, 84.83369305729866, 85.95915466547012, 86.27060875296593, 87.74812906980515, 92.63373970985413, 86.84962928295135, 79.68247666954994, 78.95872950553894, 77.49595999717712, 75.14734402298927, 71.48380100727081, 73.37594747543335, 75.10623782873154, 69.46288704872131, 76.23621359467506, 90.55816188454628, 100.19153416156769, 84.16774079203606, 88.22043612599373, 89.94435042142868, 89.93820235133171, 94.39983174204826, 91.38904049992561, 92.40585833787918, 92.20996364951134, 89.61261302232742, 95.3620009124279, 91.19393616914749, 90.84616363048553, 91.2327016890049, 92.79461547732353, 91.23067259788513, 102.75790125131607, 39.33566406369209, 1.4199430751614273, 1.1688131256960332, 1.0789453354664147, 0.5176212277729064, 1.086652153171599, 0.36318771773949265, 0.29273353109601885, 0.5334547406528145, 0.6406677095219493, 0.46672319644130766, 0.7985041744541377, 25.74811566621065, 61.485313922166824, 74.88464891910553, 58.14407721161842, 75.74902653694153, 35.365705490112305, 41.98782674968243, 76.93001836538315, 95.18579676747322, 94.74892660975456, 117.22959950566292, 9.545897170901299, 0.5970934883225709, 0.30426237965002656, 0.11588869747356512, 0.18138602783437818, 0.14125523826805875, 0.1588290577637963, 0.11467403921415098, 0.14864557451801375, 0.27506008569616824, 0.13038997363764793, 0.23005325230769813, 0.16177210374735296, 0.10815430898219347, 0.11410968785639852, 0.14090666634729132, 0.16081638081232086, 0.18618561560288072, 0.23057483369484544, 0.2196974869002588, 0.1695132235181518, 0.14140950108412653, 0.09137379340245388, 0.1400747336447239, 0.11563638952793553, 0.13009686983423308], [0.04805453332664911, 0.11236104692216031, 0.03958118839364033, 0.035907850542571396, 0.021995750576024875, 0.029511450411519036, 0.04177622373390477, 0.10554070977377705, 0.0042584545008139685, 0.022197954276634846, 0.034359864075668156, 0.0862983196566347, 0.021959099613013677, 0.03998029314971063, 0.06575490755494684, 0.038235084648476914, 0.06932357660843991, 0.013160233866074122, 0.039800274098524824, 0.07261517966981046, 0.08615493672550656, 64.01009604334831, 111.3823364675045, 88.47091868519783, 66.27647683024406, 48.85838247835636, 31.193508468568325, 31.59911960363388, 95.78631654381752, 64.23770383000374, 50.43374374508858, 26.509843692183495, 0.16884447424672544, 0.03619833827542607, 0.12163808583864011, 0.11820556377642788, 0.07346632657572627, 0.029217623014119454, 0.16111551085487008, 0.12530847365269437, 0.5757572175934911, 0.6315851281397045, 20.343487076461315, 118.49460482597351, 101.34690776467323, 106.79553419351578, 90.64460724592209, 96.5002678334713, 87.98591271042824, 82.68757581710815, 70.69057837128639, 71.34747192263603, 70.24265840649605, 75.29131069779396, 79.22120422124863, 84.27852004766464, 82.73043751716614, 84.26206693053246, 81.2616415321827, 86.20818570256233, 78.24331149458885, 70.71381032466888, 64.80535537004471, 66.83621719479561, 65.00083968043327, 65.2788707613945, 64.86112877726555, 65.2352187037468, 65.87251290678978, 64.90204498171806, 66.7826096713543, 68.75613257288933, 65.6220455467701, 64.03044775128365, 63.5439370572567, 78.80104556679726, 86.49864211678505, 85.94485223293304, 72.5660665333271, 76.32796347141266, 81.708505153656, 87.73517936468124, 77.61937737464905, 75.77871814370155, 67.09685280919075, 75.03739312291145, 75.79115107655525, 87.22014740109444, 46.00971333682537, 68.3029156923294, 82.0687486231327, 79.21070918440819, 80.58982998132706, 78.49457681179047, 80.98437801003456, 75.92450872063637, 72.71453976631165, 73.04715111851692, 81.19427114725113, 81.08475342392921, 76.80432111024857, 68.2623490691185, 66.47500857710838, 68.38680759072304, 66.7588609457016, 64.66192066669464, 66.14930525422096, 64.75645959377289, 68.16588744521141, 81.59245178103447, 82.84396782517433, 77.42572456598282, 84.4209136068821, 85.1360884308815, 78.82946044206619, 79.70236480236053, 84.08336251974106, 84.933802485466, 81.41083672642708, 82.92138487100601, 81.88907146453857, 79.5308268070221, 85.53606256842613, 83.29714670777321, 83.13140720129013, 89.55481052398682, 82.49690964818001, 85.36519333720207, 24.900229163467884, 0.2191870377282612, 0.1651657818001695, 0.2584372245473787, 0.05950744161964394, 0.20880891883280128, 0.061402218852890655, 0.1441452800645493, 0.05347956233890727, 0.16309284459566697, 0.07520268496591598, 0.4515571118099615, 20.868105925619602, 22.892369404435158, 38.03571201860905, 37.36535958945751, 52.505935952067375, 25.387222431600094, 42.23953664302826, 70.18078252673149, 75.04556268453598, 81.20184034109116, 56.3972045481205, 1.0230242111720145, 0.033271088905166835, 0.0864669430302456, 0.03912123494956177, 0.028835196171712596, 0.020194630524201784, 0.035532271867850795, 0.03859656622807961, 0.03680722962599248, 0.06520839742734097, 0.0155103836368653, 0.00958204027483589, 0.05098298868688289, 0.05636385620164219, 0.07354852685239166, 0.037692444821004756, 0.06954769778531045, 0.004739177411465789, 0.09968144644517452, 0.050004882577923127, 0.03695056802826002, 0.013909636036260054, 0.07510041701607406, 0.0497443739004666, 0.040160534845199436, 0.052073144252062775, 0.12037397085805424, 0.0008860519085374108, 0.08712933209608309, 0.05864073187694885, 0.04121965008380357, 0.015298582111427095, 0.03106955235125497, 0.04879574218648486, 0.08149083543685265, 0.08414992087637074, 0.0323390998528339, 0.05725698640162591, 0.037958935208735056, 0.007908188345027156, 0.06851964513771236, 0.0033502517453598557, 0.0006902679012910085, 0.005731722467317013, 0.09871626854874194, 0.3761897888034582, 86.15416780114174, 122.269307076931, 99.18405622243881, 79.3432004749775, 70.82099497318268, 63.17832067608833, 41.4171277731657, 75.88109984993935, 66.62739560008049, 50.37233144044876, 32.53377065062523, 0.29793966736178845, 0.030668844556203112, 0.07418956432957202, 0.22320284333545715, 0.38306495582219213, 0.05821152561111376, 0.06946592795429751, 0.35168181639164686, 0.4639570042490959, 0.7896038645412773, 25.744201876223087, 124.77613136172295, 104.73513275384903, 109.21997129917145, 94.258281737566, 97.7113388478756, 90.07308751344681, 84.93163660168648, 73.99575501680374, 75.74293926358223, 71.86391741037369, 79.27809476852417, 80.01281574368477, 88.46432983875275, 87.54059180617332, 89.12765264511108, 85.82177683711052, 90.38468599319458, 81.68339610099792, 73.95657151937485, 67.92651548981667, 69.06186416745186, 68.44695076346397, 69.59267288446426, 67.2076852619648, 67.76459857821465, 70.16019523143768, 66.82718887925148, 68.61219629645348, 71.67978689074516, 69.21310365200043, 66.47585213184357, 66.67583540081978, 83.86343792080879, 89.1999551653862, 90.67119061946869, 75.07640182971954, 78.65020126104355, 83.55915024876595, 89.97328966856003, 79.94848519563675, 77.384033203125, 70.76188534498215, 77.82053098082542, 79.6704389154911, 90.61364650726318, 50.48156797885895, 67.62950822710991, 83.56741860508919, 80.86951777338982, 82.86153808236122, 81.08747407793999, 83.06501716375351, 80.0231359899044, 77.2096149623394, 77.61594995856285, 85.4299646615982, 84.72642481327057, 80.98592072725296, 71.2850184738636, 68.58907833695412, 70.01099243760109, 69.99235823750496, 69.40218910574913, 69.65544551610947, 68.20342943072319, 72.14491993188858, 84.27870243787766, 83.09400960803032, 80.38752883672714, 87.44375020265579, 89.0919953584671, 82.08811238408089, 83.091851323843, 87.92667388916016, 89.50944095849991, 84.9376630783081, 85.96119895577431, 85.05451440811157, 84.68962758779526, 87.77649834752083, 85.20275965332985, 85.31268775463104, 93.26423987746239, 85.28811827301979, 91.2161573767662, 34.23846177756786, 0.46548547223210335, 0.20852008980000392, 0.7512126839719713, 0.020214761279930826, 0.37476747762411833, 0.09061841323273256, 0.0704058283008635, 0.050692415607045405, 0.04909188508463558, 0.12428422822267748, 0.2210105984704569, 25.032399371266365, 25.125216990709305, 39.35807526111603, 34.475249871611595, 43.863793686032295, 37.105970308184624, 56.73004008829594, 79.09157037734985, 83.7426196038723, 88.84676411747932, 83.27478110790253, 2.3174626333639026, 0.0754210322338622, 0.0663824008370284, 0.03923054217011668, 0.028088029721402563, 0.052330476537463255, 0.03426908086112235, 0.05236667850113008, 0.04025967835332267, 0.05691165766620543, 0.051340369900572114, 0.02217383633251302, 0.04947190922393929, 0.021653358890034724, 0.0395657257467974, 0.03240092075429857, 0.03658667075796984, 0.04337007863796316, 0.03231370727007743, 0.03357894660439342, 0.016427511181973387, 0.05024220285122283, 0.04451835549843963, 0.04299874875869136, 0.07051792970742099, 0.1450962235685438, 0.2401919840485789, 0.3050129284383729, 0.19950004178099334, 0.14049046993022785, 0.17358284967485815, 0.08816896224743687, 0.13007405621465296, 0.30504976864904165, 0.15271877782652155, 0.25190166430547833, 0.23442945966962725, 0.1326466814498417, 0.15321521525038406, 0.11915545343072154, 0.09128069097641855, 0.08435916199232452, 0.15833962621400133, 0.1402497320668772, 0.1585633837385103, 0.5579733999911696, 100.42349651455879, 134.98170733451843, 115.54072692990303, 93.86962339282036, 74.35346782207489, 44.92577210068703, 41.88788831233978, 125.1606023311615, 80.00051200389862, 73.92801225185394, 45.01130171120167, 1.1309745186008513, 0.12347409239737317, 0.26717791333794594, 0.5097351071890444, 0.5769279703963548, 0.16415367048466578, 0.5404479091521353, 0.5704340001102537, 2.5974824326112866, 1.1924922675825655, 25.94470001757145, 129.30072337388992, 110.00874817371368, 115.46072602272034, 97.72928908467293, 104.85547229647636, 94.99662011861801, 90.15248045325279, 78.10422375798225, 79.91788163781166, 76.10069006681442, 84.15657699108124, 86.64133965969086, 94.97229382395744, 90.97110852599144, 93.8099817931652, 91.52805984020233, 94.24432888627052, 86.49314001202583, 79.0434117615223, 70.09413197636604, 73.39822947978973, 72.00274676084518, 72.54852667450905, 69.8109483718872, 71.35877251625061, 73.71849909424782, 72.4991825222969, 72.78872698545456, 75.95961883664131, 71.57131031155586, 70.34151390194893, 69.49748039245605, 87.76881515979767, 92.50456184148788, 93.37721541523933, 79.67758253216743, 81.17704287171364, 86.90818414092064, 94.79572489857674, 84.30631175637245, 80.7635946571827, 73.3927957713604, 81.60426914691925, 85.03423869609833, 95.88025510311127, 55.86323440074921, 69.42618101835251, 85.29598385095596, 85.30774801969528, 87.578384578228, 85.6162078678608, 86.79773926734924, 83.086356818676, 80.9718082845211, 83.72021600604057, 89.52758118510246, 91.00583866238594, 83.85467559099197, 74.25010576844215, 70.28314143419266, 72.93434277176857, 72.59480059146881, 72.2914856672287, 74.18181583285332, 72.43217691779137, 75.64004838466644, 88.23497414588928, 88.58815759420395, 82.26088911294937, 93.20386871695518, 94.92358803749084, 84.83708247542381, 85.32445952296257, 90.89834243059158, 92.5426433980465, 88.65059584379196, 93.00668969750404, 87.79932752251625, 88.68187576532364, 90.5131570994854, 88.35744917392731, 91.3902336359024, 96.46940588951111, 89.25854802131653, 93.6051119863987, 31.36857457458973, 0.7004403427708894, 0.8670818258542567, 1.5296338079497218, 0.22597239003516734, 0.5027168244123459, 0.38852826110087335, 0.21924038330325857, 0.18462145031662658, 0.6150211044587195, 0.21698121156077832, 1.5583559917286038, 36.3935237377882, 37.93468303978443, 56.340143010020256, 58.82905125617981, 69.13579300045967, 38.34952957928181, 59.76277895271778, 91.44891008734703, 97.43124067783356, 106.31745904684067, 88.06918904185295, 1.8289292603731155, 0.1606574869947508, 0.22371676575858146, 0.13284265296533704, 0.07563000617665239, 0.12069598131347448, 0.12074551967089064, 0.1626892646891065, 0.16055876651080325, 0.13224201800767332, 0.0831151740567293, 0.17552260105730966, 0.13226889859652147, 0.1210174871084746, 0.24788533919490874, 0.13879507809178904, 0.18156069971155375, 0.1182494247041177, 0.16032881947467104, 0.10433825242216699, 0.1824493770254776, 0.1285135274520144, 0.15759217960294336, 0.09930300308042206, 0.15929733810480684], [0.043223252141615376, 0.04907491216727067, 0.06159404176287353, 0.023779751136316918, 0.018540090204623993, 0.12814055371563882, 0.01743067961797351, 0.09051922519574873, 0.031011926439532544, 0.07501328887883574, 0.01475872812079615, 0.03021249609446386, 0.05673039922839962, 0.04317912404076196, 0.012976184025319526, 0.04071023620781489, 0.056054425149341114, 0.02000375014176825, 0.1155373128131032, 0.13078601332381368, 3.512120428495109, 93.82353946566582, 100.8477209508419, 88.43849882483482, 63.67184579372406, 32.85210236907005, 25.92957492917776, 21.3955195248127, 47.71161541342735, 64.40478086471558, 42.02946871519089, 2.1673303144052625, 0.249454298755154, 0.2734543156111613, 0.0533694053592626, 0.24058974551735446, 0.5562953744083643, 0.08380986138945445, 0.41171764489263296, 0.47505522903520614, 0.9451168728992343, 9.91093598306179, 109.63921040296555, 101.42530515789986, 99.8872084915638, 89.87112835049629, 93.886638879776, 88.06102707982063, 84.0388061106205, 77.71833926439285, 77.019412368536, 69.66682970523834, 67.01248213648796, 69.26175624132156, 71.49865061044693, 76.0720244050026, 77.11523562669754, 84.88675341010094, 85.99871054291725, 81.82059153914452, 73.28724503517151, 66.82766005396843, 63.598232343792915, 62.66121782362461, 64.21267837285995, 65.64156889915466, 62.793226540088654, 63.677028715610504, 61.45530693233013, 63.93075630068779, 69.16826605796814, 69.67637479305267, 65.14129534363747, 63.719442039728165, 73.44349265098572, 84.86884117126465, 83.94546031951904, 72.62792721390724, 73.55621740221977, 80.81163167953491, 78.7750093638897, 74.86330166459084, 72.03938439488411, 69.5085833966732, 65.16401812434196, 70.0903245806694, 75.74610069394112, 87.3040696978569, 46.11788213253021, 61.40940919518471, 82.65643268823624, 74.84101206064224, 83.02189707756042, 77.943644374609, 80.92746466398239, 77.30682894587517, 82.95570462942123, 75.11539533734322, 83.05940106511116, 80.83022788167, 76.15638747811317, 65.91082245111465, 69.83084410429001, 67.5053308904171, 64.61853459477425, 62.93812416493893, 63.629326075315475, 61.85319498181343, 70.74451267719269, 79.62038800120354, 84.38874453306198, 81.60478591918945, 80.79305067658424, 79.74690601229668, 78.44297558069229, 76.37932911515236, 82.35906824469566, 80.16271770000458, 85.06648376584053, 80.19650548696518, 78.95100831985474, 85.52144855260849, 86.68110832571983, 76.16696611046791, 84.30020168423653, 77.60225549340248, 90.78435614705086, 78.53537142276764, 82.28349789977074, 17.256931699812412, 0.27788787614554167, 0.4106511489953846, 0.35637403023429215, 0.0629473703156691, 0.09809362149098888, 0.21784407697850838, 0.06427073836675845, 0.11292599199805409, 0.07849762027035467, 0.10887170603382401, 1.8939708452671766, 27.479682750999928, 38.35028573870659, 56.45799368619919, 48.96186612546444, 29.215608201920986, 23.833157122135162, 45.121704787015915, 58.61187770962715, 75.83884611725807, 80.1040868461132, 21.681518778204918, 0.7235451217275113, 0.2370507994783111, 0.12676064885454252, 0.02997132221935317, 0.12394554913043976, 0.016607710203970782, 0.05997643071168568, 0.016158623657247517, 0.05169871590624098, 0.0779535443871282, 0.01658686884184135, 0.07030505948932841, 0.030557715363102034, 0.07218692335300148, 0.02744452460319735, 0.018392584643152077, 0.02689397348149214, 0.05498141319549177, 0.04378426012408454, 0.020283523117541336, 0.04753745306516066, 0.02116289204423083, 0.0693129119463265, 0.06617989100050181, 0.05447427771287039, 0.0450859574630158, 0.04608403847669251, 0.10329257376724854, 0.022346496989484876, 0.09638901959988289, 0.04064486412971746, 0.06175473528855946, 0.06300128734437749, 0.017785194286261685, 0.06552814433234744, 0.013177763394196518, 0.05239701007667463, 0.0707950402284041, 0.09500603482592851, 0.06829576144809835, 0.13319938851054758, 0.08052665201830678, 0.10373295677709393, 0.36064405110664666, 7.290467396378517, 114.763965010643, 110.25001242756844, 99.96554508805275, 74.53644320368767, 48.02706688642502, 41.6656344383955, 33.83801646530628, 51.30266211926937, 55.493111461400986, 43.12284104526043, 2.7797819254919887, 0.48877376946620643, 0.3543558932142332, 0.49532147124409676, 0.055035794066498056, 0.5681711621582508, 0.675281536532566, 1.0100336582399905, 0.1831132429651916, 1.5347503521479666, 14.88126877695322, 114.43677216768265, 104.29175734519958, 102.52018600702286, 95.46383544802666, 94.91310060024261, 92.00376391410828, 87.21280619502068, 83.08230623602867, 78.53081926703453, 73.89082744717598, 70.64977616071701, 73.4759733080864, 74.4682064652443, 80.13019904494286, 81.63004696369171, 87.78089851140976, 90.19568413496017, 84.854044765234, 77.82969608902931, 70.69391459226608, 66.29903241991997, 64.92292106151581, 67.03664883971214, 69.78855237364769, 67.10532635450363, 67.71166741847992, 65.27322426438332, 67.29448780417442, 71.40430927276611, 73.26050207018852, 67.97272861003876, 67.26893797516823, 78.51448774337769, 87.42827743291855, 87.46076568961143, 75.50815746188164, 76.26870945096016, 85.20942449569702, 82.4619211256504, 77.4082987010479, 73.99686455726624, 73.040531873703, 67.4902381002903, 74.3238978087902, 81.78074687719345, 89.65552031993866, 51.46034225821495, 63.780101984739304, 84.14298132061958, 78.58667626976967, 84.86475259065628, 79.76435467600822, 81.56425729393959, 80.8409433066845, 87.8971266746521, 80.94510331749916, 86.12056240439415, 81.8312917649746, 80.98845899105072, 69.82895940542221, 72.14308843016624, 70.59907168149948, 68.62674191594124, 64.1542299091816, 66.73547700047493, 66.72672986984253, 75.19327595829964, 83.04351791739464, 83.71640861034393, 84.97689217329025, 86.87767177820206, 80.17376750707626, 81.09159305691719, 79.14982125163078, 83.74591782689095, 82.1647846698761, 89.77446913719177, 81.62889942526817, 83.7791508436203, 88.06940943002701, 88.60255882143974, 78.86250346899033, 88.42189371585846, 82.1949702501297, 96.11845672130585, 84.07044321298599, 90.35937935113907, 25.554250068962574, 0.15271279611624777, 0.7132307533174753, 0.8930777746718377, 0.5070679471828043, 0.13845085515640676, 0.3357593942200765, 0.08167583058821037, 0.3361445985501632, 0.1306888513499871, 0.18958938686409965, 1.8654914922080934, 30.818626284599304, 42.44809225201607, 55.498119592666626, 40.56815832853317, 36.48245416581631, 42.51227080821991, 54.68314312398434, 67.48811781406403, 82.71931171417236, 91.58489719033241, 39.00387726724148, 0.5267891264520586, 0.19683518243255094, 0.09164137474726886, 0.09165750903775916, 0.025771671789698303, 0.03230415954021737, 0.012979278781131143, 0.04048186994623393, 0.08083726308541372, 0.02694825416256208, 0.03540565034199972, 0.04827285090868827, 0.03688400851387996, 0.0195884776985622, 0.09953478322131559, 0.0694356334861368, 0.07515921737649478, 0.02705322352994699, 0.018938853572763037, 0.022196241770870984, 0.05797903300845064, 0.03315541034680791, 0.0906020043476019, 0.05419792047177907, 0.2786207618191838, 0.15531467681284994, 0.2959966060006991, 0.20310827472712845, 0.17014222336001694, 0.253959788242355, 0.11160369263961911, 0.30591071932576597, 0.15575788740534335, 0.1892205246258527, 0.147396391548682, 0.1253023583558388, 0.15402440854813904, 0.0656325051386375, 0.20356543769594282, 0.1404117132187821, 0.2869116794317961, 0.17004390363581479, 0.6296041875611991, 0.5459963832981884, 10.51158495247364, 134.08553302288055, 122.03021630644798, 115.56361690163612, 85.6439995765686, 54.2941389977932, 39.5041698217392, 33.735501766204834, 66.18919551372528, 94.56435531377792, 70.10426223278046, 3.587081618607044, 0.6227374810259789, 0.5901683599222451, 0.5678946082480252, 0.521505034994334, 1.116481740027666, 0.5702968512196094, 1.1129626538604498, 0.7164874160662293, 3.580200900323689, 14.47303768247366, 117.75049835443497, 105.67241325974464, 108.0313190817833, 98.054179251194, 101.03361457586288, 98.06722775101662, 92.11330443620682, 86.59372061491013, 83.3795490860939, 77.61978015303612, 75.09983897209167, 77.53442153334618, 78.17527234554291, 83.60360786318779, 85.89432254433632, 92.06196159124374, 94.69164088368416, 90.29905378818512, 79.52100053429604, 74.07026141881943, 68.79276260733604, 69.1219313442707, 71.25512167811394, 75.13808771967888, 72.15251192450523, 71.35957047343254, 69.0082186460495, 70.52286297082901, 75.66772609949112, 75.4946681857109, 69.71171289682388, 71.15774810314178, 81.40014410018921, 89.99569326639175, 90.7948511838913, 79.37488317489624, 78.31945940852165, 86.8456394970417, 86.33762195706367, 81.68241575360298, 79.37413841485977, 77.56936445832253, 72.0165628194809, 77.31135830283165, 84.58294451236725, 95.58971509337425, 58.5215375572443, 65.26313200592995, 85.00964641571045, 81.24719470739365, 89.24872174859047, 85.04814594984055, 86.0932494699955, 83.20671916007996, 91.35526791214943, 83.98323029279709, 89.49025198817253, 84.63265344500542, 85.68004444241524, 73.08223843574524, 75.18063023686409, 73.57164457440376, 71.39085799455643, 68.78039047122002, 68.94352331757545, 69.63054165244102, 80.4169088602066, 89.80521708726883, 89.95251998305321, 85.93042820692062, 89.58583205938339, 86.22612074017525, 86.14712297916412, 82.35162824392319, 88.12424048781395, 88.08854520320892, 93.3822463452816, 85.8578597009182, 88.06676477193832, 92.40199014544487, 88.8856740295887, 82.05240949988365, 91.45362183451653, 87.23305150866508, 101.32008120417595, 88.124460875988, 93.53486895561218, 24.632905907928944, 0.5944159382488579, 1.9913317146711051, 1.3335345243103802, 0.5171163298655301, 0.2941936918068677, 0.591696590417996, 0.3930918755941093, 0.3619720204733312, 0.3667170158587396, 0.3646820766152814, 3.4295135736465454, 48.09463866055012, 58.093543723225594, 82.09298372268677, 71.18899002671242, 39.87241566181183, 39.5698568969965, 60.600611194968224, 82.45169207453728, 94.79387819766998, 107.65449330210686, 40.075944140553474, 0.9998287120833993, 0.3558087215060368, 0.39797669160179794, 0.25281646521762013, 0.2092329820152372, 0.16698134219041094, 0.12097066501155496, 0.13654580659931526, 0.14241294411476701, 0.18459926010109484, 0.09897364536300302, 0.149337270995602, 0.12374167374218814, 0.21965580788673833, 0.13965852238470688, 0.15814884973224252, 0.2824033994693309, 0.1424437580863014, 0.18631550628924742, 0.13933294219896197, 0.2503920765593648, 0.11349418025929481, 0.19877965387422591, 0.15767975302878767], [0.07531689407187514, 0.05942177180259023, 0.002878500472434098, 0.04075374090461992, 0.1044282155635301, 0.06066675792681053, 0.19693546142661944, 0.0356784304312896, 0.030544373403245118, 0.04251369216945022, 0.10754031536635011, 0.05221430445089936, 0.09290822825278156, 0.02667309920070693, 0.038725377089576796, 0.055505057753180154, 0.020825559950026218, 0.09372008586069569, 0.1695446015219204, 0.4797366668935865, 20.363880582153797, 110.61557561159134, 86.2129582464695, 98.32159370183945, 63.204869851469994, 42.527033016085625, 47.39321529865265, 47.39200696349144, 46.816573441028595, 42.97082260251045, 12.332253456115723, 0.5027603439521044, 0.5455137498211116, 0.091923346335534, 0.1296073046978563, 0.14816803217399865, 0.3204534889664501, 0.4802306997589767, 0.11985475692199543, 0.8280991239007562, 4.493216620758176, 96.85724347829819, 108.04652586579323, 103.85929495096207, 93.99567022919655, 86.2810429930687, 83.52563604712486, 84.35496434569359, 81.01426720619202, 80.22904694080353, 75.59288531541824, 72.02292367815971, 68.7074039876461, 69.94170695543289, 65.87685987353325, 69.28960114717484, 76.08132630586624, 80.45032426714897, 83.1717686355114, 79.08393278717995, 69.65642586350441, 63.24191406369209, 62.64752335846424, 62.93557830154896, 60.56416355073452, 63.990967869758606, 61.99830539524555, 63.904530107975006, 61.27790965139866, 64.89240109920502, 69.02268067002296, 71.74453541636467, 63.153933584690094, 72.539391964674, 80.24944424629211, 89.96601685881615, 79.79850724339485, 75.8507090806961, 79.54828307032585, 80.86200177669525, 72.66686752438545, 72.07094550132751, 68.86413037776947, 70.8931303024292, 67.68783509731293, 72.38785609602928, 76.92526862025261, 79.65023159980774, 41.28237560391426, 69.04300197958946, 82.2213864326477, 77.13454619050026, 80.92626392841339, 77.5075113773346, 78.17977130413055, 76.85041263699532, 76.83133006095886, 77.33652055263519, 81.36906176805496, 77.46960461139679, 67.95465677976608, 64.51945871114731, 69.31813761591911, 72.42528408765793, 66.24857872724533, 61.645163744688034, 62.55580388009548, 61.68709449470043, 68.74512076377869, 77.61069104075432, 78.77062439918518, 81.62676393985748, 79.13548842072487, 73.56482774019241, 74.15720835328102, 74.06674280762672, 77.88925409317017, 79.70046490430832, 79.30486053228378, 77.4588967859745, 79.1570408642292, 83.18474873900414, 81.47809311747551, 83.17862346768379, 73.80408570170403, 82.23871350288391, 81.57792136073112, 89.83038693666458, 83.83443027734756, 83.16656291484833, 10.217976607382298, 0.40765584097243845, 1.2875290866941214, 0.5783718335442245, 0.0347895675804466, 0.0359572701563593, 0.14274858782300726, 0.12529947882285342, 0.07245877204695717, 0.11762534530134872, 0.026812712021637708, 7.974876221269369, 25.781407579779625, 43.158338740468025, 57.29671128094196, 37.37327456474304, 21.33065700531006, 21.380447633564472, 52.54971340298653, 67.31954365968704, 83.91452237963676, 60.10628052055836, 1.1013437085784972, 0.06435100163798779, 0.07737604959402233, 0.11068344436353073, 0.03957329194236081, 0.01265999757379177, 0.04009691794635728, 0.03306831560621504, 0.06980031743296422, 0.013294293567014392, 0.019716956448974088, 0.07124409152311273, 0.05897285038372502, 0.11149774363730103, 0.06949766961042769, 0.044835033622803167, 0.01808068780519534, 0.07131351201678626, 0.05656497451127507, 0.05120117639307864, 0.07002406011451967, 0.050687973853200674, 0.03185656285495497, 0.008431949790974613, 0.07526291024987586, 0.032257853235933, 0.03905019286321476, 0.03985232462582644, 0.006213653687154874, 0.02342240888538072, 0.06697087941574864, 0.07790070347255096, 0.11411264160415158, 0.03154393685690593, 0.1412362392875366, 0.019894665565516334, 0.050529094878584146, 0.06043773115379736, 0.05529549380298704, 0.018531648274802137, 0.06651068106293678, 0.08637210397864692, 0.16059968853369355, 0.353725275490433, 32.612555623054504, 129.2231011390686, 94.29346024990082, 112.0943270623684, 72.37169176340103, 53.2923873513937, 47.86274090409279, 42.329367622733116, 47.60228767991066, 53.71782012283802, 13.389047048985958, 0.516634052619338, 0.5861589219421148, 0.46766827697865665, 0.1018078850756865, 0.555579528445378, 1.0028000338934362, 1.068472859915346, 1.4287035050801933, 1.4770663599483669, 7.092980118468404, 106.83938384056091, 109.95881125330925, 110.01798927783966, 96.74949645996094, 91.61287128925323, 87.35934913158417, 87.538942694664, 84.4272668659687, 85.04268184304237, 79.34326887130737, 77.34684079885483, 70.95765084028244, 72.47145920991898, 67.91349738836288, 71.9640876352787, 79.15191113948822, 83.7764909863472, 85.90076699852943, 84.24183681607246, 72.5221560895443, 66.6716480255127, 66.18231028318405, 65.19559442996979, 65.07051274180412, 68.33604231476784, 63.94680663943291, 66.24423176050186, 64.72256541252136, 69.39728736877441, 72.48114109039307, 75.75332790613174, 65.64671382308006, 76.5843053162098, 81.96258991956711, 92.83924788236618, 79.7675085067749, 75.29471531510353, 82.0270648598671, 83.50770860910416, 75.65734505653381, 75.8037967979908, 71.20846018195152, 74.90969717502594, 70.79217731952667, 77.2644916176796, 77.95141875743866, 85.9551040828228, 46.81642144918442, 70.93167543411255, 84.52712550759315, 79.5388975739479, 83.95008087158203, 78.74438300728798, 80.03398820757866, 80.02822011709213, 79.92532923817635, 80.5619090795517, 82.4413414299488, 78.96122977137566, 72.32496947050095, 66.85282990336418, 72.91708409786224, 75.13178005814552, 69.73450407385826, 66.70894682407379, 65.20361199975014, 65.2958482503891, 72.4246609210968, 81.18432328104973, 81.78365752100945, 84.20393005013466, 80.45999854803085, 78.8605047762394, 77.46436849236488, 77.25097954273224, 79.89671677350998, 83.67523401975632, 81.58446460962296, 81.28772333264351, 85.39770439267159, 82.33101055026054, 83.48646014928818, 86.70425668358803, 76.85240373015404, 86.26418709754944, 84.58817303180695, 93.62136751413345, 86.88233032822609, 91.36501058936119, 16.787252202630043, 0.35598787595517933, 0.40512001141905785, 0.7311581319663674, 0.4201925260713324, 0.2548298524925485, 0.3610382799524814, 0.5272099538706243, 0.16054655076004565, 0.12263323907973245, 0.03016313956322847, 7.41037423722446, 30.829945877194405, 38.28014150261879, 31.617176234722137, 28.95402453839779, 29.27630804479122, 37.768035382032394, 65.69417327642441, 78.26534271240234, 92.43879497051239, 83.61401930451393, 4.917656695470214, 0.2612770377891138, 0.12789257249096408, 0.0630480723339133, 0.09726965203299187, 0.06279839159105904, 0.00373038651105162, 0.03530729722115211, 0.1309994253097102, 0.017420630938431714, 0.07392668077955022, 0.04789409213117324, 0.05950354905507993, 0.04013484911411069, 0.058783992353710346, 0.038347983863786794, 0.0885482516605407, 0.017095928342314437, 0.07419858142384328, 0.013895887750550173, 0.02981324661959661, 0.05950877006398514, 0.02034157205343945, 0.03280568809714168, 0.20855575741734356, 0.13752504077274352, 0.10255355795379728, 0.17012478288961574, 0.24797421880066395, 0.07070650943205692, 0.36898276302963495, 0.12214241971378215, 0.22639523609541357, 0.09026475017890334, 0.2239652516436763, 0.09754455095389858, 0.17325758119113743, 0.08517794383806176, 0.12119072664063424, 0.11856767247081734, 0.19790066900895908, 0.18157074839109555, 0.3253394627245143, 0.4912871267879382, 35.977810844779015, 148.4333199262619, 106.37187212705612, 124.84728634357452, 81.0058544576168, 61.730993539094925, 63.283309042453766, 68.97345811128616, 66.42687276005745, 72.0030203461647, 18.51173836737871, 0.5594285437837243, 1.0420966940000653, 0.38653001363854855, 0.38588057504966855, 0.888569732196629, 1.4362831483595073, 1.679516527801752, 3.345219371840358, 3.6975965509191155, 6.315151881426573, 110.22728204727173, 110.50811737775803, 115.32928347587585, 100.3198304772377, 95.79960823059082, 91.2260140478611, 93.23224559426308, 88.17285507917404, 88.46079602837563, 82.42436394095421, 80.30412331223488, 76.57973036170006, 77.37859949469566, 72.69412726163864, 78.56095924973488, 81.48342803120613, 88.37292954325676, 91.269491314888, 87.86907657980919, 76.9863997399807, 70.82473397254944, 70.38854777812958, 69.0528130531311, 69.68933969736099, 72.50842362642288, 67.95180693268776, 71.2698344886303, 68.30074980854988, 73.6706292629242, 78.21147680282593, 77.4907922744751, 69.16630536317825, 82.3900517821312, 86.54066786170006, 94.65313374996185, 81.37831047177315, 77.85478234291077, 84.5406223833561, 90.5593854188919, 80.27874067425728, 80.57859778404236, 74.00345340371132, 78.79338517785072, 73.07330891489983, 81.7316535115242, 83.27446192502975, 91.67945131659508, 53.705056607723236, 71.85919046401978, 87.6890954375267, 83.78132432699203, 88.85132387280464, 84.09774854779243, 83.0017277598381, 84.75628361105919, 84.11180779337883, 85.85590660572052, 88.0266161262989, 85.10760515928268, 74.48247849941254, 70.26588276028633, 75.14945670962334, 77.5884622335434, 70.50396278500557, 70.72009518742561, 68.41959983110428, 68.26193869113922, 75.57316437363625, 86.47139757871628, 81.10599428415298, 88.92707660794258, 87.37780094146729, 83.62841293215752, 80.45321971178055, 81.10236167907715, 83.9982470870018, 87.89092540740967, 85.71584612131119, 87.48407363891602, 88.90277311205864, 84.25146549940109, 87.56049513816833, 90.47630667686462, 80.19152015447617, 89.68680784106255, 87.67924636602402, 98.64309445023537, 87.19509154558182, 94.0085743367672, 14.314308799803257, 1.336915036663413, 4.126406153663993, 2.5406270334497094, 0.30189798620995134, 0.27375075907912105, 0.5355915916152298, 0.8211880666203797, 0.32952327572274953, 0.3564843430649489, 0.14586899225832894, 13.909293282777071, 43.67767207324505, 58.26446995139122, 76.99041232466698, 49.049611017107964, 29.870351068675518, 35.90358562767506, 75.60942202806473, 88.0820931494236, 107.6929472386837, 99.64630901813507, 4.830821854993701, 0.2982350124511868, 0.31264265184290707, 0.22283855272689834, 0.25658749567810446, 0.2036082447739318, 0.14825646649114788, 0.12538674054667354, 0.226483091537375, 0.1350061025004834, 0.17841670982306823, 0.19128215149976313, 0.1697690418222919, 0.1579351705731824, 0.17884454311570153, 0.24954095191787928, 0.12789107335265726, 0.1510759152006358, 0.11679478557198308, 0.13791342149488628, 0.1541350776096806, 0.2128243533661589, 0.11606129133724608, 0.1144204918819014], [0.03088742003455991, 0.0221302407226176, 0.00862231159771909, 0.03526919907017145, 0.020309960273152683, 0.0962458222056739, 0.029440274738590233, 0.017905175445775967, 0.02262287278426811, 0.019709312327904627, 0.018785444226523396, 0.10788939936901443, 0.14213622693205252, 0.09952396270819008, 0.012738484329020139, 0.09453670063521713, 0.019479977563605644, 0.05961688242678065, 0.14367976051289588, 0.10294820240233094, 51.210517063736916, 103.4476326406002, 88.54081973433495, 73.25171694159508, 58.29921528697014, 40.75018756091595, 59.75253850221634, 74.08363670110703, 45.35577982664108, 32.95018270611763, 0.18503515311749652, 0.10249792656395584, 0.08770037020440213, 0.23606193222803995, 0.11896693307789974, 0.058357357629574835, 0.03598364979552571, 1.447832747362554, 3.3182683680206537, 2.2592340828850865, 83.95132720470428, 112.29358837008476, 100.46445071697235, 97.43203863501549, 90.9487733244896, 87.98732623457909, 86.34248569607735, 84.08077105879784, 81.00127190351486, 85.25486245751381, 76.2863177061081, 74.86314207315445, 68.32819193601608, 66.3191257417202, 64.3020723760128, 64.86310467123985, 66.36031553149223, 79.05503153800964, 79.43397760391235, 74.88555327057838, 66.27725958824158, 62.56013564765453, 60.282610058784485, 57.613891661167145, 58.854574486613274, 62.362899631261826, 59.22972455620766, 60.64224936068058, 59.73902262747288, 62.24988229572773, 67.53229424357414, 70.91081455349922, 62.875336334109306, 80.09175270795822, 77.8146792948246, 80.7013387978077, 78.19506168365479, 76.99014633893967, 80.38167715072632, 76.60092562437057, 66.3668055832386, 66.24587327241898, 68.89650464057922, 74.65464726090431, 74.22378838062286, 75.57725295424461, 74.46072086691856, 83.60728606581688, 48.34480583667755, 64.51334103941917, 82.38746032118797, 72.19697713851929, 80.82399621605873, 76.8002325296402, 77.35647708177567, 73.27838391065598, 74.67853277921677, 72.2208246588707, 75.71083098649979, 68.05781364440918, 63.88518154621124, 64.47883889079094, 68.26246306300163, 73.51011827588081, 68.42684984207153, 60.641857981681824, 62.130853682756424, 61.91958501935005, 69.4229207932949, 77.31758996844292, 80.47268986701965, 79.45299938321114, 74.43630337715149, 72.01489090919495, 71.6357472538948, 76.14465370774269, 76.23927623033524, 76.20956182479858, 76.89221799373627, 83.32416325807571, 85.0331823527813, 80.12291863560677, 84.46623757481575, 77.00227528810501, 75.53494602441788, 73.85633289813995, 81.8023145198822, 79.68287944793701, 83.93339976668358, 85.42931869626045, 71.83620929718018, 4.857325907796621, 0.607505701482296, 1.0991372144781053, 0.3925181063823402, 0.1866750471526757, 0.17696723603876308, 0.40617552353069186, 0.1827654874068685, 0.007660676064915606, 0.03153487523377407, 0.1936336315702647, 14.931274093687534, 31.784621849656105, 69.36519429087639, 47.52022348344326, 39.12756063044071, 26.90898187458515, 42.62551613152027, 65.26586025953293, 67.60569870471954, 78.63262340426445, 24.575553685426712, 0.34105230239219964, 0.11422420124290511, 0.03736381069757044, 0.006026023447702755, 0.06368320973706432, 0.04250504985975567, 0.038682503218296915, 0.007668354510315112, 0.03551594832970295, 0.10304493393050507, 0.0295880344856414, 0.01761035542585887, 0.013776382493233541, 0.06668471469311044, 0.05983935603580903, 0.046693312033312395, 0.025702681741677225, 0.02835695064277388, 0.028138556990597863, 0.05038311443058774, 0.0836269739374984, 0.026506882240937557, 0.019084225459664594, 0.08446813153568655, 0.010433180686959531, 0.03039125349459937, 0.0034772814524330897, 0.02754119675955735, 0.04085051696165465, 0.036172170148347504, 0.015826879935048055, 0.0240165222203359, 0.05308347441314254, 0.013452906296151923, 0.05068909078545403, 0.032132144551724195, 0.05164439069631044, 0.025108560985245276, 0.07245811895700172, 0.06909700634423643, 0.106536701641744, 0.10230951753328554, 0.0467897838097997, 70.14514043927193, 116.42160326242447, 98.3500237762928, 87.35467538237572, 69.22192677855492, 46.47237651050091, 28.83971907198429, 51.91664457321167, 52.540734484791756, 38.020368441939354, 0.23587609844980761, 0.06867962249089032, 0.4323481925530359, 0.6345986039377749, 0.4028788738651201, 1.1172948963940144, 1.0761146061122417, 0.9087763947900385, 2.2978020133450627, 4.044807907193899, 97.96309813857079, 111.94721415638924, 104.67519477009773, 99.27864074707031, 94.31090131402016, 91.20407402515411, 88.95981565117836, 86.31541594862938, 84.66910108923912, 87.69038736820221, 81.580900400877, 78.46069023013115, 73.09734642505646, 70.50565749406815, 68.63463029265404, 68.22934404015541, 70.72015598416328, 81.7218804359436, 83.56513872742653, 79.89110067486763, 70.79670667648315, 65.92744275927544, 62.11013339459896, 61.619815304875374, 62.38852545619011, 66.08283922076225, 62.01947785913944, 63.74958962202072, 63.39808188378811, 66.49340718984604, 70.99442526698112, 73.11924085021019, 66.30809873342514, 84.01717007160187, 83.50099056959152, 85.59136480093002, 76.53190612792969, 79.52017217874527, 83.03197413682938, 78.7201327085495, 69.80033174157143, 71.55927255749702, 72.4647107720375, 77.02706515789032, 77.37201824784279, 79.06852081418037, 77.61248454451561, 85.72349891066551, 51.94062888622284, 65.33959150314331, 83.31676885485649, 76.59437477588654, 82.85411328077316, 78.32243084907532, 80.01965537667274, 77.64160618185997, 76.18451356887817, 72.626863270998, 77.84472048282623, 69.40693885087967, 66.11667260527611, 67.44524851441383, 70.58606877923012, 74.26028162240982, 72.14309602975845, 63.69552992284298, 64.74680051207542, 64.43659275770187, 71.58021703362465, 81.5734452009201, 82.30628907680511, 83.0088409781456, 78.70561748743057, 76.11140549182892, 75.05874037742615, 79.20827731490135, 80.0432901084423, 79.39689919352531, 80.57798981666565, 85.32195165753365, 85.82871526479721, 83.58979940414429, 87.60117575526237, 79.02274087071419, 80.1070886850357, 77.17312172055244, 85.99497154355049, 82.70747154951096, 86.97891354560852, 90.13677969574928, 81.69233322143555, 8.202580902725458, 0.44464133447036147, 1.3678065477870405, 1.4347752230241895, 1.0072138532996178, 0.6265905336476862, 0.889582852832973, 0.3619384753983468, 0.2458240685518831, 0.09757573599927127, 0.050192924245493487, 17.756671383976936, 37.99426384270191, 51.410344541072845, 25.737468637526035, 35.061243027448654, 38.73665280640125, 50.25849714875221, 72.98763871192932, 73.4945011138916, 94.99535858631134, 42.70125366747379, 0.2240560163045302, 0.08329366057296284, 0.052444121611188166, 0.018108917247445788, 0.04721400655398611, 0.08110576469334774, 0.03897102054907009, 0.041424609007663094, 0.08791576372459531, 0.03972480139054824, 0.045639722084160894, 0.038702114470652305, 0.012694571450992953, 0.033885924858623184, 0.036202178889652714, 0.04822337563382462, 0.017255712737096474, 0.06254536376218311, 0.01864849571575178, 0.12059134591254406, 0.04638742102542892, 0.0300907393466332, 0.02348956582864048, 0.19826049188850448, 0.07625499842106365, 0.13715855340706185, 0.14934611739590764, 0.09416623535798863, 0.15817685838555917, 0.13848456350388005, 0.1392338951700367, 0.1556892684311606, 0.1302817091345787, 0.15089143213117495, 0.12584026699187234, 0.32071217196062207, 0.1727568096248433, 0.16352784703485668, 0.24026248807786033, 0.2799941209377721, 0.31152764917351305, 0.2560363768134266, 0.2182050427654758, 80.36007151007652, 132.32669860124588, 114.89504277706146, 101.0025854408741, 79.92395371198654, 60.80351270735264, 77.1534463763237, 104.99224975705147, 66.53163313865662, 54.942239820957184, 0.8365820499602705, 0.3263138432521373, 0.4197934584226459, 1.0902069811709225, 1.1714234668761492, 1.447775037959218, 1.1736225988715887, 7.33885352499783, 12.672270610928535, 3.9637668058276176, 99.3679815530777, 114.56342697143555, 108.01441758871078, 104.12616983056068, 98.44482868909836, 95.32912507653236, 93.30460131168365, 91.79700180888176, 88.49638491868973, 92.17055976390839, 85.046306848526, 83.56652185320854, 75.89858651161194, 74.98446956276894, 72.58893370628357, 72.0202486217022, 75.06060227751732, 86.99577704071999, 87.41557851433754, 82.14967668056488, 73.21495771408081, 70.06934970617294, 64.82093453407288, 66.21204748749733, 65.79296037554741, 71.60717278718948, 65.79768732190132, 68.46011325716972, 68.10278803110123, 70.83611816167831, 74.69793453812599, 77.72073313593864, 69.48853567242622, 87.08355993032455, 83.30790013074875, 92.71942511200905, 79.49861213564873, 81.5786737203598, 88.12037989497185, 83.52344736456871, 74.76683244109154, 74.0731492638588, 77.74572059512138, 80.51659271121025, 81.32408738136292, 82.27599710226059, 83.58362853527069, 90.23152381181717, 56.06296308338642, 69.23534005880356, 86.75407961010933, 80.05761533975601, 85.17094016075134, 81.97183102369308, 84.05592799186707, 81.6064502298832, 82.04493150115013, 76.7493000626564, 80.64432665705681, 73.66404801607132, 69.2740447819233, 71.40360251069069, 72.6889519393444, 80.47634527087212, 74.37476187944412, 66.82337388396263, 67.98291206359863, 68.64228308200836, 76.08628883957863, 87.8552833199501, 87.48455241322517, 86.58153086900711, 81.84546500444412, 78.2250040769577, 79.96892049908638, 83.86536821722984, 83.11787232756615, 84.01543736457825, 82.7738843858242, 89.85357329249382, 88.71527597308159, 86.91700726747513, 91.11094862222672, 85.16776353120804, 83.6745348572731, 80.25082737207413, 91.45166873931885, 88.10928449034691, 90.26434645056725, 90.88235288858414, 83.28237310051918, 6.277989400550723, 2.1130431024357677, 5.427550859749317, 1.46047443151474, 0.8048856945242733, 0.7947530632372946, 1.3855413836427033, 0.6795528635848314, 0.27419806632678956, 0.21630086994264275, 0.7982033374719322, 26.979650482535362, 54.02644336223602, 95.97442924976349, 69.88591834902763, 52.1149293333292, 41.203925013542175, 59.39283460378647, 86.21517732739449, 84.68804687261581, 106.0398231446743, 45.97962275147438, 0.6105395418126136, 0.27275167987681925, 0.20913151558488607, 0.07701169219217263, 0.09858961362624541, 0.20259317971067503, 0.08876213862095028, 0.15091148496139795, 0.1609801282756962, 0.21953978051897138, 0.1170658772753086, 0.11727381221135147, 0.15299099759431556, 0.20918919530231506, 0.12755369301885366, 0.09734680570545606, 0.09659373361500911, 0.1672368636354804, 0.16133365774294361, 0.2063305611955002, 0.1707428731606342, 0.1346287500928156, 0.11868937726831064], [0.02235419120552251, 0.06038617415470071, 0.05373935855459422, 0.058628389961086214, 0.033073351078201085, 0.04928465794364456, 0.06059586055926047, 0.052930784950149246, 0.0274023965903325, 0.010856684475584188, 0.015539891428488772, 0.10020284229540266, 0.0895496092562098, 0.012505047343438491, 0.02661957922100555, 0.03534610783390235, 0.07041914243018255, 0.07690674508921802, 0.06455192327848636, 0.8479200478177518, 79.91171836853027, 96.78892314434052, 88.31701174378395, 61.797999143600464, 40.002224296331406, 44.737571999430656, 88.76700639724731, 63.99669796228409, 46.457804292440414, 6.865453077480197, 0.4955973126925528, 0.2127775238477625, 0.6397177011240274, 0.6112196459434927, 0.6472477095667273, 0.4851498920470476, 1.4772880543023348, 3.318073390983045, 1.2782257609069347, 66.70080006122589, 110.75875952839851, 94.57529872655869, 107.10780903697014, 99.6794356405735, 99.7432342171669, 97.5028820335865, 91.15263238549232, 86.61296278238297, 88.9541083574295, 83.99770751595497, 76.08401656150818, 74.31385114789009, 70.47514513134956, 64.60496932268143, 62.248943746089935, 63.5101530700922, 64.6495409309864, 69.94007304310799, 73.91510054469109, 71.28450930118561, 65.50870522856712, 60.52197441458702, 60.72988785803318, 60.685764625668526, 59.65285465121269, 58.299667462706566, 58.14398221671581, 57.68903262913227, 58.354958295822144, 62.03116223216057, 64.47693899273872, 65.08517995476723, 66.9451953470707, 79.59646448493004, 77.71576300263405, 77.98705324530602, 73.91341343522072, 80.37982285022736, 75.72274714708328, 71.1778262257576, 61.939233765006065, 68.45638945698738, 70.83807125687599, 79.30403977632523, 74.48855057358742, 83.43216106295586, 73.32361668348312, 83.8149981200695, 44.62415188550949, 63.80323514342308, 84.31632041931152, 69.71938088536263, 79.29736733436584, 77.05667316913605, 76.6785554587841, 71.85246482491493, 73.90193045139313, 66.62807196378708, 65.28557360172272, 61.58383123576641, 64.14779305458069, 64.03942286968231, 66.05238005518913, 70.67884460091591, 71.52705028653145, 61.28576003015041, 60.30373312532902, 60.258899331092834, 65.00109806656837, 73.1962551176548, 78.71948674321175, 76.28846079111099, 74.30818185210228, 68.71533796191216, 70.64983695745468, 69.66015726327896, 77.76261448860168, 76.50431200861931, 79.50111240148544, 79.2167204618454, 77.9725532233715, 83.26278135180473, 77.78070911765099, 69.8839196562767, 70.30473947525024, 70.05043432116508, 75.26918068528175, 78.38532507419586, 83.88926893472672, 83.66498976945877, 88.28428030014038, 60.24084649980068, 2.0074132829904556, 2.1766184410080314, 2.2160387132316828, 0.7802865270059556, 0.02273320045787841, 0.6696289835963398, 0.07112954102922231, 0.054478782549267635, 0.1818449719576165, 0.23268449236638844, 2.884977380745113, 22.110525257885456, 37.53202244639397, 80.43754935264587, 47.919772043824196, 29.421401359140873, 36.12147733569145, 57.63810396194458, 62.508017644286156, 81.70757040381432, 66.66610792279243, 2.1809364343062043, 0.12433695039362647, 0.015966297942213714, 0.0605979348620167, 0.07557161399745382, 0.06801905168686062, 0.029515595306293108, 0.02763270356808789, 0.053886392852291465, 0.032427920086774975, 0.06644863009569235, 0.0748967271647416, 0.05740124877775088, 0.025844821575446986, 0.034268505696672946, 0.02613977518194588, 0.08408598485402763, 0.04583834306686185, 0.02981622819788754, 0.06803272946854122, 0.026335722577641718, 0.054675280989613384, 0.1192755477677565, 0.010880990739678964, 0.09162763759377412, 0.01907929759909166, 0.04527492681518197, 0.04516636545304209, 0.029821465905115474, 0.021180625662964303, 0.03798799771175254, 0.08595335457357578, 0.02445773086947156, 0.025261705013690516, 0.09855157855781727, 0.0712117858347483, 0.03983024202170782, 0.01084918600099627, 0.051014392665820196, 0.039430287506547756, 0.04398450269945897, 0.044616946106543764, 2.8374547557905316, 103.5229142010212, 106.27141311764717, 101.3554573059082, 76.63779124617577, 54.84204299747944, 36.93203464150429, 57.48104698956013, 60.462226420640945, 54.012072533369064, 7.785902386531234, 0.5892729735933244, 0.19338379497639835, 0.8812510874122381, 0.38131823705043644, 1.4516862155869603, 2.080684988759458, 3.3004359249025583, 2.8557709604501724, 3.1704358756542206, 79.62050959467888, 110.65795853734016, 100.93137726187706, 108.21488723158836, 102.89442032575607, 103.02526250481606, 103.04343312978745, 95.55928632616997, 91.24218598008156, 90.65580144524574, 88.31917762756348, 78.48067715764046, 80.52575021982193, 73.02575826644897, 68.59663993120193, 64.96384486556053, 67.10702106356621, 68.5468702018261, 73.55925723910332, 77.85588428378105, 74.78878006339073, 68.28176602721214, 65.1683346927166, 63.62470552325249, 64.14057344198227, 63.03876556456089, 61.47555224597454, 63.742947578430176, 62.721049413084984, 61.31047010421753, 66.8783113360405, 69.21080097556114, 68.11009123921394, 70.14783829450607, 83.5636568069458, 79.51938942074776, 81.96023404598236, 76.60913318395615, 83.63828480243683, 79.55316960811615, 73.07616636157036, 65.12667372822762, 72.06196278333664, 75.20595967769623, 82.77427956461906, 77.08071827888489, 84.90680113434792, 76.682408452034, 83.99715274572372, 45.6846521794796, 66.12065479159355, 87.31704980134964, 73.8106669485569, 80.11272758245468, 79.1891111433506, 79.90943849086761, 75.60217201709747, 75.38784831762314, 70.02448171377182, 68.498764783144, 66.58978521823883, 67.72400915622711, 67.59208783507347, 69.83646020293236, 71.1905175447464, 72.2016204893589, 62.956336587667465, 64.35058817267418, 62.138932049274445, 68.27925816178322, 78.7705560028553, 81.54610186815262, 79.70556423068047, 78.24143439531326, 72.47393667697906, 73.84193167090416, 74.65354532003403, 81.1073850095272, 79.9901993572712, 82.48003095388412, 80.30364453792572, 80.75002938508987, 84.25950586795807, 80.38392663002014, 73.29599216580391, 73.35203915834427, 75.26430934667587, 77.83060044050217, 81.97371572256088, 86.56753242015839, 87.52381950616837, 90.05782753229141, 71.15456387400627, 3.8311052368953824, 1.0245980392210186, 1.1009493609890342, 1.8955728155560791, 0.926946010440588, 0.2772257319884375, 0.9179231571033597, 0.47893514740280807, 0.23454222158761695, 0.26668806618545204, 2.4773255176842213, 24.967810437083244, 38.440595492720604, 59.39400874078274, 38.11307966709137, 35.17381578683853, 47.91762135922909, 63.04462485015392, 76.36520907282829, 87.2074256837368, 86.04414090514183, 5.3744544088840485, 0.42006846866570413, 0.05976600958092604, 0.09750313911354169, 0.0536916236160323, 0.14014976477483287, 0.05948520316451322, 0.08656067628180608, 0.024908019695430994, 0.02517238197469851, 0.036741093135788105, 0.01833391415857477, 0.12229306827066466, 0.02469029583153315, 0.024949886101239827, 0.07027216750429943, 0.056156103091780096, 0.016470466689497698, 0.027365348578314297, 0.012331198322499404, 0.0567942536144983, 0.07390702870907262, 0.017212072598340455, 0.14898017921950668, 0.2497348899487406, 0.14988527284003794, 0.15455738932359964, 0.1271941521554254, 0.21577119914582, 0.10141613500309177, 0.3209553292253986, 0.2131564644514583, 0.16601116221863776, 0.15217831620248035, 0.24656164459884167, 0.16904060903470963, 0.2149808860849589, 0.11487976255011745, 0.0874881753406953, 0.15499040280701593, 0.09735260930028744, 0.2621278358856216, 3.4730300260707736, 123.07002291083336, 119.91015806794167, 118.14085140824318, 84.72898587584496, 61.821497082710266, 63.315550312399864, 125.70691421627998, 89.26306217908859, 71.65828764438629, 12.32329923659563, 0.9203436865936965, 0.5370608658995479, 1.1252722120843828, 3.142941500991583, 2.692959434352815, 3.5024015000090003, 6.655465420335531, 13.778784535825253, 3.456985861994326, 78.59049886465073, 112.37460002303123, 104.984992146492, 115.01193210482597, 105.40084183216095, 106.68404057621956, 106.40905693173409, 99.80455532670021, 95.32021075487137, 90.42336031794548, 94.99007686972618, 84.60693642497063, 84.24641937017441, 78.11457440257072, 72.86084711551666, 69.29244339466095, 71.73147931694984, 73.35164397954941, 78.33669528365135, 83.72343823313713, 78.95220145583153, 72.75378406047821, 68.54958325624466, 68.01727741956711, 68.5978938639164, 66.54272854328156, 65.48781394958496, 68.58998268842697, 63.94583389163017, 64.84240338206291, 71.45527213811874, 71.65000408887863, 73.46730217337608, 72.30103075504303, 87.59612962603569, 82.97895178198814, 84.20168817043304, 81.08052045106888, 86.41334429383278, 83.86388629674911, 78.47365513443947, 68.44420731067657, 75.7277324795723, 79.83101069927216, 85.61257526278496, 82.28326991200447, 89.09682869911194, 79.39506009221077, 87.39948257803917, 52.88065664470196, 70.32175496220589, 91.12940043210983, 78.09135004878044, 83.84974345564842, 82.43512496352196, 84.77110281586647, 80.10816022753716, 79.13649156689644, 73.40401276946068, 72.24881395697594, 69.49427336454391, 70.4550214111805, 71.02068185806274, 72.08946570754051, 75.88512763381004, 75.45005097985268, 67.37004294991493, 67.64767125248909, 65.80927670001984, 72.80495971441269, 82.81657129526138, 84.32780340313911, 83.55222702026367, 83.63271430134773, 77.64318689703941, 76.21508672833443, 79.55134570598602, 85.70418074727058, 83.92713010311127, 85.50580099225044, 85.87156936526299, 82.37021684646606, 89.73877385258675, 86.22932016849518, 76.04568421840668, 75.98101928830147, 77.52435967326164, 81.79173588752747, 86.09266430139542, 89.62715864181519, 91.35389238595963, 92.75607034564018, 71.31748393177986, 2.5824361899867654, 4.228349458426237, 6.35891318321228, 1.8100815592333674, 1.416371741797775, 1.9987834710627794, 2.6481705252081156, 0.46829714323394, 0.45179207576438785, 0.4349946021102369, 4.973003100603819, 34.17364865541458, 54.7504261136055, 111.50685578584671, 64.44623664021492, 42.12230533361435, 52.98476725816727, 74.51422959566116, 84.69911187887192, 101.00513890385628, 98.53514224290848, 5.258420510217547, 0.5036949750501662, 0.1678976570838131, 0.19666750158648938, 0.21393684757640585, 0.25233320833649486, 0.11710207181749865, 0.1567693307879381, 0.19374807074200362, 0.14980379986809567, 0.2422184924944304, 0.13429557031486183, 0.22843761165859178, 0.10796296846820042, 0.19702241144841537, 0.17778511246433482, 0.17035962810041383, 0.09716040047351271, 0.12267991274711676, 0.12965474277734756, 0.1272005049395375, 0.09973619467928074, 0.15240366192301735], [0.031213373149512336, 0.06917397447978146, 0.03120064160611946, 0.036401961333467625, 0.034553917139419354, 0.0443975449888967, 0.03859068841848057, 0.020014555811940227, 0.08480649892590009, 0.036519335699267685, 0.08230013263528235, 0.034380369615973905, 0.050178704696008936, 0.083040788595099, 0.03832525559118949, 0.02862650238967035, 0.1475491700693965, 0.2042128873290494, 0.27707181056030095, 10.639982912689447, 102.5095845758915, 84.1371676325798, 80.70044964551926, 55.84315247833729, 56.75251968204975, 70.37543088197708, 52.619059681892395, 48.89907069504261, 23.59692569822073, 0.22309092746581882, 0.2037456163088791, 0.0887368610710837, 0.9844904788769782, 0.5653970141429454, 0.3738765144953504, 0.7455916574690491, 0.5078975495416671, 0.40930750546976924, 60.5180986225605, 108.97369891405106, 101.53170704841614, 99.55367758870125, 89.62585911154747, 97.83425465226173, 94.69068333506584, 96.06594353914261, 92.06769168376923, 98.64834576845169, 81.43850684165955, 81.50156065821648, 81.80045261979103, 74.36995893716812, 70.21787613630295, 62.3804584890604, 62.32922203838825, 62.82743230462074, 62.16647297143936, 64.52729389071465, 66.88708886504173, 65.9823726117611, 63.46593864262104, 64.40752431750298, 59.54434007406235, 57.47134231030941, 59.17938105762005, 59.115483686327934, 57.058931440114975, 56.798265427351, 58.54672260582447, 64.72557485103607, 66.00912317633629, 63.171986415982246, 71.46110102534294, 78.4597858786583, 77.85542830824852, 77.69665002822876, 77.29039862751961, 76.68213486671448, 73.99187922477722, 66.67300075292587, 63.708456829190254, 69.60569858551025, 74.34576943516731, 79.0916995704174, 74.90232557058334, 79.91861879825592, 73.29514101147652, 74.4394040107727, 42.06930197775364, 62.89377674460411, 77.72408455610275, 69.2723348736763, 75.11645168066025, 76.58841669559479, 77.90785029530525, 73.39591160416603, 75.59639632701874, 71.37609198689461, 64.79765698313713, 63.64724591374397, 64.20708507299423, 62.40385003387928, 63.158702328801155, 65.10417133569717, 73.08261081576347, 62.208073139190674, 58.747823014855385, 58.651790767908096, 59.40957650542259, 70.38720265030861, 77.91680261492729, 76.96407213807106, 72.62867957353592, 68.0564533174038, 69.79698792099953, 73.28007102012634, 70.8325843513012, 71.77225112915039, 73.42325493693352, 73.54124620556831, 79.85338389873505, 79.18090358376503, 72.19146743416786, 64.938173443079, 64.99058023095131, 69.65828776359558, 71.68009087443352, 77.01302111148834, 80.65706357359886, 87.09446534514427, 82.44220018386841, 88.14574733376503, 45.32323457300663, 0.05946165481873322, 1.0376832308247685, 1.2124764639884233, 0.9965116088278592, 0.5750106170307845, 0.11112249892903492, 0.13144526310497895, 0.35789311747066677, 0.05290942222927697, 0.12865364493336529, 9.391465857625008, 26.430583745241165, 45.21042242646217, 47.763668820261955, 31.619471311569214, 23.676217943429947, 45.349479764699936, 52.502873316407204, 67.61684730648994, 79.26977321505547, 16.157724782824516, 0.4300684930058196, 0.1276251024683006, 0.08388901886064559, 0.01904961911350256, 0.05547619563003536, 0.024687655641173478, 0.050925097457366064, 0.08203491132007912, 0.038412086869357154, 0.012991459279874107, 0.09287143257097341, 0.018926572884083726, 0.0052516429059323855, 0.058268704378861, 0.009725390737003181, 0.05736630846513435, 0.057812877275864594, 0.007337491160797072, 0.0854469055775553, 0.09785221569472924, 0.029221482182038017, 0.022751774558855686, 0.017347265929856803, 0.04717613475804683, 0.06106694992922712, 0.029664854191651102, 0.027799581039289478, 0.03210000584658701, 0.04099088677321561, 0.05432269776065368, 0.048308340410585515, 0.021566026662185322, 0.027570726815611124, 0.05664451418851968, 0.08448389475233853, 0.0821208742854651, 0.036474213120527565, 0.05090785736683756, 0.09071006847079843, 0.24043717479798943, 0.5579774966463447, 18.55636317282915, 124.23418924212456, 92.53323510289192, 91.45700365304947, 69.93097633123398, 68.5891543328762, 53.07404346764088, 51.56498484313488, 54.08109202980995, 25.86797833442688, 0.07679314454435371, 0.18333798012463376, 1.1636165482923388, 1.2218701536767185, 0.9173619747161865, 1.4733912446536124, 1.7634406057186425, 2.0769666507840157, 2.1358473412692547, 72.82727971673012, 110.52007153630257, 104.62610140442848, 104.67220053076744, 96.95172920823097, 101.46377429366112, 100.34711301326752, 99.09832522273064, 94.26287949085236, 98.50802689790726, 87.1323949098587, 87.06120193004608, 85.93720704317093, 78.74290108680725, 72.5463379919529, 66.68660402297974, 66.5319675207138, 65.24068281054497, 65.51008075475693, 67.63412117958069, 72.15800642967224, 70.93329414725304, 67.59521126747131, 66.65885031223297, 65.63351333141327, 62.22692012786865, 64.48184072971344, 61.799724251031876, 61.55976712703705, 60.495763421058655, 61.42688825726509, 66.1576496064663, 68.83855774998665, 66.79074883460999, 72.99797415733337, 81.50153785943985, 80.28691783547401, 81.19852691888809, 81.446273624897, 78.31518083810806, 76.59239128232002, 69.89544823765755, 67.6061698794365, 74.00384858250618, 76.86928242444992, 83.30907806754112, 78.10696721076965, 81.76132991909981, 76.43704041838646, 76.28136277198792, 45.08240349590778, 65.65739884972572, 79.91535097360611, 72.64922127127647, 77.60394260287285, 77.4375419318676, 81.66986122727394, 76.8166172504425, 80.18755316734314, 76.14578604698181, 68.61620128154755, 65.27651488780975, 66.11003816127777, 63.095184937119484, 65.45667082071304, 64.92148473858833, 72.81698986887932, 65.81749945878983, 60.78263662755489, 61.02148801088333, 62.29043371975422, 72.80194267630577, 81.5538838505745, 80.3164878487587, 75.5557233095169, 70.58530122041702, 71.82609423995018, 75.57905405759811, 77.42248713970184, 75.96902713179588, 78.30285429954529, 77.8776191174984, 85.72330132126808, 81.28202363848686, 75.73671519756317, 68.40304791927338, 67.92222172021866, 72.48548045754433, 75.25339633226395, 80.3182053565979, 83.30221563577652, 87.3688942193985, 85.05344286561012, 90.64393848180771, 58.81091482937336, 0.39420111919753253, 0.708429889054969, 0.9933298139367253, 2.0470330445095897, 1.5792171098291874, 0.6052691652439535, 0.5905630637425929, 1.5216783410869539, 0.1391375792445615, 0.06132479429652449, 10.777583979070187, 31.68413434177637, 42.82837964594364, 39.882789105176926, 28.886061385273933, 36.08084611594677, 57.66266964375973, 58.98817911744118, 73.22539955377579, 91.87555879354477, 29.73714541643858, 0.24183723638998345, 0.03456114936852828, 0.039498349869973026, 0.11299110803520307, 0.005239465190243209, 0.01598434326297138, 0.04380154103273526, 0.0030098951674517593, 0.039773078096914105, 0.010486957635293948, 0.03208837268175557, 0.06039664956915658, 0.09111338120419532, 0.0671757641248405, 0.057158622148563154, 0.02291160348249832, 0.005249721671134466, 0.04698130243923515, 0.026255344273522496, 0.08075640609604307, 0.07835943979443982, 0.019286521928734146, 0.12661891349125654, 0.10848494319361635, 0.23711820133030415, 0.18149378767702729, 0.07866354964789934, 0.08829430356854573, 0.1801494020037353, 0.17516254069050774, 0.24661547999130562, 0.14911094564013183, 0.16245741775492206, 0.10775996139273047, 0.15238129359204322, 0.17044399544829503, 0.28372492699418217, 0.22674762265523896, 0.18789874477079138, 0.49445268348790705, 0.7507424592040479, 21.294182762503624, 143.19265633821487, 102.96907112002373, 107.36178740859032, 72.73149445652962, 74.627965092659, 90.13402104377747, 76.03391245007515, 71.48168832063675, 38.07201907038689, 0.31070208409801126, 0.3692171926377341, 1.302730527240783, 4.616402210667729, 3.283691885881126, 1.950690164230764, 5.399028165265918, 7.870237436145544, 4.380263881757855, 72.1434836089611, 111.13414898514748, 110.15570148825645, 105.64080655574799, 102.78718248009682, 105.3645233809948, 104.61892738938332, 104.90931540727615, 99.70249280333519, 100.67438945174217, 92.79795929789543, 90.96390411257744, 92.37262532114983, 82.84271389245987, 79.65708643198013, 70.37616804242134, 70.00281527638435, 69.58004996180534, 68.91461446881294, 71.97530463337898, 74.07404601573944, 72.99421235918999, 71.00980684161186, 69.81670886278152, 67.76827678084373, 65.16883626580238, 70.28876513242722, 65.77960029244423, 67.01626673340797, 63.00662308931351, 66.2928919494152, 69.6360057592392, 72.04991742968559, 70.8468259871006, 79.1153647005558, 83.87760356068611, 83.85398402810097, 83.49634721875191, 85.61208888888359, 82.80806735157967, 80.74809148907661, 73.62538889050484, 73.5304319858551, 78.17516595125198, 83.68138208985329, 87.09496691823006, 82.48512268066406, 86.25931575894356, 79.74033996462822, 76.39483988285065, 49.07090127468109, 69.56394642591476, 84.74193558096886, 76.82582795619965, 81.23949632048607, 82.60856285691261, 85.43943375349045, 81.27890780568123, 84.12861809134483, 79.55385357141495, 71.00231364369392, 67.58184358477592, 71.57285302877426, 68.74287128448486, 70.30768811702728, 70.26557877659798, 76.77074611186981, 68.65696549415588, 64.38553869724274, 65.36737561225891, 67.98655226826668, 77.57061079144478, 87.49605819582939, 85.46637430787086, 80.14574021100998, 75.70697039365768, 78.18517461419106, 81.68626874685287, 80.84535866975784, 81.57909169793129, 81.50766313076019, 81.74694389104843, 89.67477768659592, 84.58383366465569, 80.36555841565132, 72.6411885023117, 71.21441066265106, 76.91899135708809, 80.23308232426643, 83.61372292041779, 89.42220523953438, 94.06976625323296, 88.54907289147377, 95.07877930998802, 57.43270978331566, 0.280347858206369, 6.327524017542601, 6.034348849207163, 2.349531725049019, 1.9654571218416095, 1.1806459282524884, 2.8680595010519028, 0.7491961203049868, 0.19138118368573487, 0.2578632178483531, 19.205235354602337, 44.37841147184372, 62.271693125367165, 72.13561043143272, 40.738051012158394, 37.019756734371185, 62.84770801663399, 72.24990829825401, 82.34179437160492, 107.56962865591049, 29.74956315010786, 0.8942515554372221, 0.3392943029757589, 0.16477937519084662, 0.1617428779718466, 0.08604226386523806, 0.08390014365431853, 0.1476457976968959, 0.15633107774192467, 0.1427176402648911, 0.12059103421051987, 0.20785842061741278, 0.13042896607657894, 0.11608898086706176, 0.15095255541382357, 0.143640382157173, 0.16695110709406435, 0.18787498120218515, 0.1737525936914608, 0.2753490780014545, 0.13723667187150568, 0.14838512521237135, 0.15556586411548778], [0.093239003472263, 0.06779132367228158, 0.031448144145542756, 0.04780327551998198, 0.019482467469060794, 0.041588690437492914, 0.07076081979903392, 0.03007355862791883, 0.07145187802962027, 0.011536720885487739, 0.008340812200913206, 0.0406296946312068, 0.0653289444744587, 0.11255771605647169, 0.06270080659305677, 0.08376545127248392, 0.049353885478922166, 0.2232917377841659, 0.465530387009494, 35.84293708205223, 102.24586352705956, 87.64033645391464, 67.76406660676003, 52.85232536494732, 40.092667043209076, 79.0712870657444, 81.17449700832367, 49.93559047579765, 4.780304990708828, 0.054420301312347874, 0.11565412685740739, 0.0887728478119243, 0.9211968595627695, 0.18341960152611136, 0.7180612441152334, 2.257797522470355, 2.388281333260238, 32.26664498448372, 121.44225105643272, 92.54306137561798, 106.41435384750366, 94.11180719733238, 100.44694125652313, 88.48712101578712, 94.31370556354523, 92.61791735887527, 95.73628842830658, 81.58086240291595, 85.00604420900345, 82.60564461350441, 79.82312232255936, 76.27507030963898, 67.76414260268211, 61.764070764184, 60.3548289835453, 60.50852693617344, 63.700895234942436, 60.17444126307964, 61.181239038705826, 61.12203821539879, 63.96555483341217, 60.906027406454086, 59.902455657720566, 59.93691600859165, 58.2338397949934, 56.35714329779148, 56.7736579477787, 58.24552036821842, 60.99754549562931, 65.06074726581573, 67.25255325436592, 61.62722870707512, 71.73182129859924, 79.61887568235397, 77.70859658718109, 76.84941709041595, 76.31260469555855, 75.58560490608215, 73.44411581754684, 67.04894497990608, 66.60680830478668, 71.78814187645912, 74.21342253684998, 73.72665345668793, 72.5107491016388, 78.30914676189423, 75.3070342540741, 73.21445614099503, 44.52629953622818, 67.55814805626869, 78.62073764204979, 67.74476364254951, 71.76468193531036, 74.0316554903984, 75.88787108659744, 73.899597376585, 75.51262602210045, 72.51308977603912, 65.5380092561245, 57.05722913146019, 61.49660311639309, 60.94870291650295, 65.18400505185127, 60.05562163889408, 66.19197696447372, 67.32910394668579, 56.52433052659035, 56.20020791888237, 56.75505794584751, 57.321717739105225, 63.785505294799805, 64.71756488084793, 66.79198756814003, 63.65920387208462, 67.32762962579727, 68.51110652089119, 72.32267439365387, 71.81686833500862, 72.8714257478714, 73.82312268018723, 75.51860690116882, 73.07949498295784, 67.19017580151558, 60.25340862572193, 63.434951305389404, 68.01579549908638, 76.14400014281273, 74.0139788389206, 81.69780492782593, 78.50730612874031, 86.10680714249611, 80.00155314803123, 84.90168660879135, 28.794856779277325, 0.4442042391747236, 2.2811030969023705, 1.0283448756672442, 0.23095862794434652, 0.3553056938108057, 0.30069434142205864, 0.6232514628209174, 0.17476051929406822, 0.11489307667943649, 0.8417752431705594, 16.38325408101082, 32.814005613327026, 68.16605463624, 50.21880827844143, 26.12995907664299, 45.94684571027756, 65.28645515441895, 67.50681281089783, 79.9448373913765, 60.38379482924938, 0.5618593445979059, 0.14472847455181181, 0.08253071049693972, 0.10460355537361465, 0.034466128490748815, 0.08715072821360081, 0.03160362408380024, 0.042433603302924894, 0.0224441153841326, 0.06580047542229295, 0.05783826985862106, 0.056242960345116444, 0.08166524014086463, 0.024036584327404853, 0.04651936746085994, 0.052607041579904035, 0.03964576266298536, 0.020191669354971964, 0.11909669759916142, 0.031562946969643235, 0.032626299871481024, 0.025843148032436147, 0.022446217517426703, 0.04722775855043437, 0.04655103861296084, 0.015413203109346796, 0.020104030991205946, 0.040753418070380576, 0.07296864976524375, 0.049237980565521866, 0.004305665761421551, 0.05554895949899219, 0.021552629041252658, 0.0584386784612434, 0.016055737869464792, 0.06373005409841426, 0.06349449642584659, 0.13732400781009346, 0.05094422260299325, 0.26098955946508795, 0.2228064474184066, 52.843259051442146, 115.71874737739563, 95.94347611069679, 81.50678917765617, 66.44677609205246, 58.036083206534386, 75.19688576459885, 76.44915416836739, 54.484539180994034, 5.7419702131301165, 0.1165312340890523, 0.2810146036790684, 1.2409552233293653, 0.7068295811768621, 0.3296060103457421, 1.7986035626381636, 1.2874855077825487, 1.8636098806746304, 40.91435395181179, 124.14445325732231, 96.10261157155037, 110.72557970881462, 96.7097581923008, 105.98335057497025, 95.38687437772751, 102.58794397115707, 95.37955597043037, 99.68425378203392, 87.07760944962502, 90.54560735821724, 86.21681123971939, 84.68316793441772, 80.06916671991348, 71.70300364494324, 64.37119826674461, 63.72182831168175, 64.98095154762268, 67.8124076128006, 62.05568991601467, 65.21192595362663, 63.25105257332325, 66.09923154115677, 64.66372936964035, 63.12946669757366, 62.42109350860119, 62.37970232963562, 60.52595280110836, 61.60751536488533, 62.24681206047535, 67.07043662667274, 68.75614017248154, 69.29767951369286, 65.00717014074326, 74.10103976726532, 82.46115356683731, 79.87720102071762, 81.65009468793869, 78.95686000585556, 78.16328018903732, 75.51453351974487, 69.25918757915497, 71.27700090408325, 75.11463537812233, 76.70785948634148, 74.74668592214584, 76.14046633243561, 79.50932756066322, 78.1594879925251, 79.15981471538544, 47.41270065307617, 72.3535743355751, 81.43268555402756, 68.92134010791779, 75.97462803125381, 77.86890998482704, 77.98348143696785, 78.1151519715786, 80.07375687360764, 74.11523580551147, 67.67574414610863, 60.91865412890911, 63.14470387995243, 65.38915604352951, 68.22366714477539, 62.03517861664295, 71.42998069524765, 70.79100698232651, 61.97341673076153, 60.17475664615631, 59.654830545187, 59.68305163085461, 66.4419275522232, 67.58886560797691, 68.58185112476349, 66.82041764259338, 70.00356763601303, 71.94992199540138, 76.3972033560276, 74.91795793175697, 77.5580258667469, 78.05448442697525, 79.28493440151215, 76.05852752923965, 70.87604641914368, 62.7701997756958, 67.23267272114754, 69.81877595186234, 78.54023516178131, 77.64397725462914, 85.6480273604393, 81.88683718442917, 88.23664605617523, 81.84898361563683, 91.4744371175766, 43.589114025235176, 0.23901630338514224, 0.3895815467694774, 1.3571491884067655, 0.9603765571955591, 1.3233839627355337, 0.21440863085445017, 1.5216719289310277, 0.545691509032622, 0.26711866026744246, 0.2781143499305472, 19.155765809118748, 36.73056945204735, 48.45354080200195, 31.26782678067684, 35.67452251911163, 58.28989818692207, 72.35913723707199, 75.59679910540581, 86.87889531254768, 81.0813944041729, 1.834779402706772, 0.09130702237598598, 0.06282625181484036, 0.03432589226576965, 0.026836534962058067, 0.0910051612299867, 0.03301589771581348, 0.05150544209755026, 0.06170630644191988, 0.03287160936451983, 0.021797372646688018, 0.061642704386031255, 0.07835006646928377, 0.04282342750229873, 0.06540663249325007, 0.09577694072504528, 0.010683720465749502, 0.04190277475572657, 0.04222993942676112, 0.07265390493557788, 0.031130675633903593, 0.0784906663466245, 0.17761563562089577, 0.1488091587089002, 0.15162130468524992, 0.1257167587755248, 0.15376544353784993, 0.1164384582079947, 0.25554059247951955, 0.13845336361555383, 0.1407161570386961, 0.19761526869842783, 0.0807415260351263, 0.2162713324651122, 0.18138915969757363, 0.1930110141984187, 0.29052359343040735, 0.2860940701793879, 0.1912550927954726, 0.4608542629284784, 0.6650116376113147, 59.737468510866165, 133.05624425411224, 109.0392529964447, 97.13291108608246, 69.67154905200005, 54.991154596209526, 101.4875078201294, 97.77079045772552, 74.75988641381264, 8.781692627817392, 0.1852644025348127, 0.41024169127922505, 2.1979804197326303, 2.234892351552844, 0.9740901400800794, 3.3348259795457125, 8.974076304584742, 6.155800307169557, 37.122332230210304, 132.4333968758583, 97.48094961047173, 115.51901489496231, 98.0116519331932, 109.64358016848564, 95.39178371429443, 106.86868026852608, 98.31628158688545, 104.10984590649605, 90.83734810352325, 96.00665912032127, 90.94293683767319, 90.48013687133789, 82.21470639109612, 75.3692901134491, 68.30920055508614, 67.76906713843346, 68.11140596866608, 71.8654753267765, 64.62567061185837, 68.06099027395248, 66.92181140184402, 70.33503144979477, 66.96024253964424, 68.7969271838665, 66.6570796072483, 66.95136621594429, 65.33276706933975, 64.35448676347733, 64.54576089978218, 69.53023463487625, 72.96226367354393, 73.32690730690956, 67.77717590332031, 78.60988542437553, 87.63385400176048, 83.80756571888924, 84.42241072654724, 83.03351685404778, 82.60488465428352, 80.05627021193504, 72.56048083305359, 75.22920683026314, 78.87741386890411, 80.88798478245735, 80.59984624385834, 81.46781846880913, 86.30127310752869, 83.67277175188065, 80.86210817098618, 53.500787168741226, 76.74110010266304, 86.9524897634983, 74.08539980649948, 79.85851362347603, 79.35138523578644, 80.79052001237869, 81.79886430501938, 84.0701012313366, 79.56889316439629, 71.38077333569527, 63.4854543954134, 66.81934610009193, 68.89008298516273, 71.46770507097244, 67.7442392706871, 74.42652270197868, 74.44246664643288, 65.41789770126343, 62.01847471296787, 62.71932810544968, 63.18753518164158, 71.49295851588249, 73.32147359848022, 76.33799493312836, 71.17262050509453, 73.62798795104027, 74.58932116627693, 80.50901591777802, 78.07029917836189, 80.9058666229248, 81.01687386631966, 82.425047904253, 80.7449072599411, 74.94075670838356, 66.56182631850243, 72.12737247347832, 73.96018892526627, 84.02489125728607, 80.10144218802452, 88.07149931788445, 84.80335548520088, 91.67529433965683, 84.78013873100281, 96.15938052535057, 42.3556774109602, 1.3930509681813419, 8.950296230614185, 4.3008315190672874, 0.6805294111836702, 1.3779577030800283, 1.9455930939875543, 2.702129054814577, 0.5834960367064923, 0.30174465849995613, 1.0554117732681334, 30.023794434964657, 50.775592401623726, 93.91475737094879, 67.10936933755875, 37.25993424654007, 63.50230649113655, 85.09486064314842, 88.28574702143669, 100.99800288677216, 89.47810783982277, 1.97642523329705, 0.26685478223953396, 0.12593134335475042, 0.10321676338207908, 0.050436816236469895, 0.16380355489673093, 0.1350338736665435, 0.1463090709876269, 0.09995593718485907, 0.15062557999044657, 0.08874850536813028, 0.1893405002192594, 0.16688814328517765, 0.10688750000554137, 0.1347076107049361, 0.13419290160527453, 0.10031003810581751, 0.12689208320807666, 0.2074715241906233, 0.3245221503311768, 0.24768907082034275, 0.22063937620259821], [0.05913387045438867, 0.04597197417751886, 0.05903884957660921, 0.1123588130576536, 0.02045262146566529, 0.048678234234103, 0.01746754951454932, 0.04173595109023154, 0.029402484578895383, 0.02677547476196196, 0.02130667016899679, 0.042506831014179625, 0.09194275349727832, 0.06870735654956661, 0.048094201119965874, 0.015067635958985193, 0.06781168820452876, 0.036475738234003074, 0.8145488135050982, 77.87741392850876, 90.31355381011963, 79.78758662939072, 43.37228246033192, 29.41242814064026, 36.24857671558857, 69.50631111860275, 71.17100939154625, 19.318264089524746, 0.13168926641810685, 0.075470963929547, 0.5817430838942528, 0.8642043708823621, 0.2305031125433743, 0.5446108826436102, 0.8785287709906697, 1.9456161302514374, 5.878516836091876, 107.44912952184677, 98.57279822230339, 103.64771470427513, 96.49672642350197, 103.74698057770729, 96.99930265545845, 99.20970484614372, 92.23060414195061, 92.58987486362457, 85.74614569544792, 86.27781316637993, 84.01331707835197, 78.42808797955513, 76.81005880236626, 72.1494872868061, 60.837809666991234, 63.97283524274826, 62.14202128350735, 62.161875218153, 60.00107556581497, 61.97886183857918, 60.39283074438572, 60.30719853937626, 61.56822547316551, 60.417704209685326, 59.541893005371094, 57.81093008816242, 56.8005833029747, 57.41442896425724, 55.90702325105667, 58.93030822277069, 63.371487110853195, 67.64371946454048, 66.30676880478859, 61.01578451693058, 70.39205119013786, 77.85468354821205, 75.16130447387695, 74.19193089008331, 77.60549291968346, 76.79109022021294, 72.83056274056435, 69.38980177044868, 60.8514129370451, 66.75184652209282, 65.1708197593689, 65.59556856751442, 64.16688323020935, 67.41215988993645, 69.32494685053825, 76.75034880638123, 41.13715119659901, 64.83709886670113, 75.86975365877151, 65.80414697527885, 67.32184633612633, 70.3547751903534, 75.62616392970085, 72.68211990594864, 73.05283561348915, 66.33470490574837, 60.2467779815197, 58.2937777787447, 60.55652976036072, 63.25549453496933, 66.58715575933456, 62.09960795938969, 61.4918951690197, 68.29762637615204, 59.99024614691734, 56.70751869678497, 56.844782531261444, 57.91937626898289, 55.401243790984154, 54.10349562764168, 56.18345081806183, 57.58995674550533, 56.64714373648167, 61.66548125445843, 63.63793261349201, 69.13888603448868, 72.75595754384995, 72.71654605865479, 75.22924482822418, 67.1352307498455, 59.45339575409889, 59.718560725450516, 62.28894419968128, 69.8352138698101, 73.15102234482765, 76.87641844153404, 79.35239598155022, 83.44144776463509, 78.22630360722542, 82.67746075987816, 78.87256532907486, 81.59452646970749, 19.866983145475388, 1.269275697413832, 2.1168134501203895, 1.9355464330874383, 0.44483346166089177, 0.6503312441054732, 1.3763692695647478, 1.3861174089834094, 0.352730174199678, 0.5047019803896546, 6.890731696039438, 25.55224757641554, 54.74870480597019, 71.28327056765556, 31.103941574692726, 24.99702136963606, 46.58476687967777, 59.8091896623373, 66.99543625116348, 80.56005477905273, 14.494360238313675, 0.4866238567046821, 0.14859867078484967, 0.10461455400218256, 0.06687952103675343, 0.09295379612012766, 0.020024869809276424, 0.04761556781886611, 0.017988646650337614, 0.12245863399584778, 0.059011590492445976, 0.06980310790822841, 0.07129760037059896, 0.08534304201020859, 0.015917896926112007, 0.08691470298799686, 0.04924057808239013, 0.019279414009361062, 0.055818496402935125, 0.04223380601615645, 0.059598495718091726, 0.04868810108746402, 0.04227626428473741, 0.06313670703093521, 0.048354335012845695, 0.04731161752715707, 0.06613616365939379, 0.022578249299840536, 0.024930180225055665, 0.0732210541900713, 0.021997863841534127, 0.06716973046422936, 0.025423283550480846, 0.04856022904277779, 0.031176937409327365, 0.09944361780071631, 0.11469388424302451, 0.024200541447498836, 0.046528336315532215, 0.11910932153114118, 2.730892561376095, 101.42063900828362, 97.35326126217842, 89.60714891552925, 53.76935675740242, 42.41418667137623, 36.12205110490322, 61.395866721868515, 73.59765037894249, 20.207821056246758, 0.12261023992323317, 0.21868788404390216, 0.44009615492541343, 2.363057336769998, 0.3096051007742062, 1.8169857887551188, 1.4340767730027437, 1.4992426824755967, 11.297479681670666, 115.29606565833092, 100.20386070013046, 109.14221227169037, 98.73237445950508, 108.74578714370728, 101.1872935295105, 101.3981594145298, 95.53477764129639, 95.57562544941902, 88.28364953398705, 89.2346853017807, 86.87472313642502, 84.59126606583595, 79.34133097529411, 74.17137399315834, 64.61723506450653, 66.60157978534698, 66.84704661369324, 66.19342088699341, 63.08190084993839, 64.78668317198753, 64.58115220069885, 63.939868211746216, 64.69919666647911, 63.29164199531078, 63.28863635659218, 62.29371674358845, 59.463826194405556, 61.36185094714165, 59.363994151353836, 61.905772760510445, 66.03268951177597, 71.01414620876312, 71.6051284968853, 64.88342598080635, 74.08652454614639, 81.95454955101013, 77.8457160294056, 75.31164720654488, 79.27553370594978, 80.67448183894157, 76.7410697042942, 73.41287389397621, 65.52924692630768, 70.4717481136322, 67.71925941109657, 69.64227542281151, 66.50225311517715, 71.54256105422974, 73.21317180991173, 82.97999292612076, 45.40902636945248, 67.4734278023243, 79.30974707007408, 70.54657369852066, 70.64238175749779, 72.21596091985703, 76.9423221051693, 75.25354072451591, 74.93754208087921, 68.10655742883682, 64.59333434700966, 60.76714105904102, 64.36125040054321, 66.09313666820526, 69.39617782831192, 66.51062026619911, 63.73479701578617, 70.73098540306091, 64.00156930088997, 59.66488480567932, 58.9847707003355, 60.02437211573124, 56.197209879755974, 58.15860003232956, 60.05211062729359, 60.1190972328186, 59.716638028621674, 63.68201024830341, 67.06755638122559, 69.87049117684364, 75.72402387857437, 75.77336803078651, 77.4007599055767, 72.4258616566658, 63.30073490738869, 63.78640204668045, 64.86702606081963, 75.41665837168694, 76.61405771970749, 80.80658555030823, 82.00907662510872, 87.1354803442955, 80.77553361654282, 86.78846016526222, 78.42819437384605, 92.58669823408127, 31.388605199754238, 0.2019983483478427, 1.4766517071984708, 1.2221996672451496, 1.7018016194924712, 2.992186015471816, 2.4502298841252923, 1.5951415803283453, 0.10579055378912017, 0.44329062569886446, 6.505003469064832, 29.70155082643032, 48.69238458573818, 51.270037069916725, 33.34636464715004, 40.61065524816513, 53.156947419047356, 67.21913024783134, 73.96260559558868, 91.67582631111145, 30.219290144741535, 0.7271381851751357, 0.0882099881710019, 0.08465908613288775, 0.024540810591133777, 0.05557198091992177, 0.12685763271292672, 0.03732141180080362, 0.08884030903573148, 0.056285400060005486, 0.02539959234127309, 0.03779606347961817, 0.02828582135407487, 0.010247127975162584, 0.023469166044378653, 0.08261481809313409, 0.03829733970633242, 0.013352682035474572, 0.05599730204266962, 0.01025362918881001, 0.024677198780409526, 0.019666551634145435, 0.17524670023703948, 0.19801797287072986, 0.24084930424578488, 0.20005647442303598, 0.11050627887016162, 0.15563031221972778, 0.1966749082203023, 0.10713734402088448, 0.11429686492192559, 0.18884796649217606, 0.10160959063796327, 0.11861191931529902, 0.14003265387145802, 0.22390271828044206, 0.22829099296359345, 0.09554532385664061, 0.21751757652964443, 0.22094873304013163, 3.1417051423341036, 114.13120776414871, 114.62471768260002, 102.73791432380676, 69.13197800517082, 43.72489973902702, 53.41906115412712, 88.60974803566933, 85.45742958784103, 33.90305757522583, 0.27795992384199053, 0.257631074055098, 2.3889137618243694, 4.796630339697003, 0.653810016810894, 2.6557793794199824, 6.345066726207733, 6.310480032116175, 8.629865124821663, 119.9203871190548, 103.70061546564102, 112.62217193841934, 99.77308541536331, 114.27205100655556, 105.44353634119034, 106.30673602223396, 98.56047168374062, 99.97866958379745, 94.55603376030922, 96.21408998966217, 89.54277276992798, 90.83608657121658, 84.46205019950867, 81.59646436572075, 67.80138060450554, 71.72007992863655, 70.62614142894745, 68.76137629151344, 67.24029511213303, 69.54421788454056, 67.96209678053856, 68.61935511231422, 66.47155836224556, 66.61529704928398, 67.19192370772362, 64.89623129367828, 63.44258509576321, 65.02079620957375, 63.21063034236431, 66.94406300783157, 69.35923621058464, 73.22278529405594, 72.18718886375427, 66.9794163107872, 78.15375030040741, 86.27823874354362, 81.99640810489655, 78.6106225848198, 83.52407813072205, 83.63051041960716, 80.21343737840652, 76.7939704656601, 70.05235701799393, 75.70010796189308, 73.48098143935204, 72.62828439474106, 71.52764305472374, 75.1767848432064, 77.73056700825691, 87.06218227744102, 49.875230714678764, 71.75166383385658, 82.71037459373474, 73.65821912884712, 73.5721081495285, 77.13608890771866, 80.76106399297714, 79.04678598046303, 78.09235319495201, 73.06440219283104, 66.37261167168617, 64.45965752005577, 67.14403867721558, 70.28852194547653, 74.20595973730087, 68.90326827764511, 67.13130176067352, 73.93048211932182, 66.38898119330406, 63.57895977795124, 62.43916913866997, 65.51239103078842, 62.09561437368393, 62.09840342402458, 61.00126929581165, 63.62643443048, 62.61154688894749, 68.98144528269768, 70.99554240703583, 75.02935275435448, 80.56981265544891, 80.60472518205643, 81.11392825841904, 76.27609625458717, 66.38066723942757, 69.11366298794746, 67.63946369290352, 77.23394125699997, 81.20469778776169, 85.01093074679375, 85.22436529397964, 92.25705072283745, 83.9447383582592, 93.01203221082687, 80.37415355443954, 96.14910587668419, 28.358784578740597, 2.4707860685884953, 10.144964475184679, 4.7440967336297035, 1.1447296617552638, 3.7485477793961763, 5.172596890479326, 2.472885218448937, 0.8848677214700729, 0.4038997128373012, 11.953687369823456, 42.71663524210453, 74.95827376842499, 97.31443494558334, 39.80201303958893, 38.71112957596779, 62.958772256970406, 80.17824366688728, 82.53050744533539, 108.43171879649162, 26.762457937002182, 0.6724870239850134, 0.28119868598878384, 0.2395677487947978, 0.16162729589268565, 0.19908555230358616, 0.2810932119609788, 0.16547966573853046, 0.1852911346941255, 0.19443633849732578, 0.17332302377326414, 0.15811324148671702, 0.13110142608638853, 0.2385925519047305, 0.205093341646716, 0.22183680179296061, 0.11098945411504246, 0.15477261214982718, 0.16187269444344565, 0.09434737134142779, 0.13775998988421634, 0.14412497490411624], [0.11509010946610942, 0.029446282424032688, 0.032209090422838926, 0.027806902326119598, 0.019065953783865552, 0.03838483891740907, 0.05272489463095553, 0.10000136404414661, 0.038993221896816976, 0.0075826239299203735, 0.041109233352472074, 0.05496977631992195, 0.0886711290513631, 0.10928328629233874, 0.11854660289827734, 0.0762951337674167, 0.349619536427781, 0.4312236013356596, 18.155887462198734, 96.99733436107635, 77.36858323216438, 75.17118394374847, 61.40647195279598, 45.561903566122055, 63.6224028468132, 82.9703414440155, 40.66952928900719, 4.702666606754065, 0.1235561071371194, 0.16259952419204637, 0.09747149393660948, 0.4429279826581478, 0.2775544737232849, 0.23629147850442678, 0.9013505838811398, 0.41484971588943154, 62.747659385204315, 112.7457033097744, 89.29433450102806, 99.90940690040588, 94.11518901586533, 102.05569133162498, 93.22854459285736, 92.88502782583237, 84.52413126826286, 80.73278591036797, 76.9303223490715, 77.96297013759613, 75.5508291721344, 76.73478484153748, 64.13292825222015, 63.69418479502201, 62.79420308768749, 64.37688276171684, 62.09860101342201, 62.78688088059425, 60.390178486704826, 62.10932403802872, 58.83570849895477, 61.965482756495476, 61.6179534047842, 61.97248578071594, 58.65096241235733, 58.07638004422188, 53.74683916568756, 55.52942231297493, 57.6860535889864, 61.76429495215416, 62.91884399950504, 65.52766621112823, 67.46916443109512, 61.4425016194582, 68.80520313978195, 78.95378977060318, 76.66470140218735, 75.48835292458534, 70.49434930086136, 76.00854501128197, 74.09059032797813, 73.16345527768135, 63.52681517601013, 62.11580269038677, 59.78452518582344, 64.98452335596085, 63.057806342840195, 71.5797458589077, 69.89915683865547, 72.37613752484322, 35.39478912949562, 65.79090088605881, 74.41147550940514, 68.34959998726845, 65.18050163984299, 61.51855453848839, 62.666864320635796, 61.69019132852554, 60.88465355336666, 54.78444568812847, 57.16624528169632, 55.25657035410404, 58.92930127680302, 63.18131871521473, 68.45745339989662, 69.51477706432343, 60.77145002782345, 67.32097238302231, 69.27557229995728, 57.01874479651451, 55.647763162851334, 54.21848505735397, 56.65798835456371, 54.70486655831337, 57.50885009765625, 54.73787538707256, 57.623436748981476, 54.26231950521469, 57.30003610253334, 57.834188640117645, 67.58982315659523, 67.34668180346489, 69.41155180335045, 58.53745490312576, 57.69947826862335, 59.262197613716125, 65.37857741117477, 68.6574898660183, 74.28117290139198, 77.53699779510498, 79.43565711379051, 77.60328903794289, 78.97777408361435, 75.24146497249603, 81.0941769182682, 79.32933881878853, 85.663370937109, 13.254676759243011, 1.3516363967210054, 4.193345261737704, 1.4207647810690105, 0.06177616109198425, 1.1815777095034719, 1.1608975566923618, 0.37220926489681005, 0.08886744937626645, 0.037678043445339426, 16.922450847923756, 28.30881915986538, 50.032766461372375, 47.09549367427826, 15.611474644392729, 39.617164358496666, 64.4062627851963, 68.21393206715584, 72.6332925260067, 65.4702740907669, 2.1568901371210814, 0.19526104268152267, 0.023796171153662726, 0.07639119736268185, 0.04310361422540154, 0.0938376494741533, 0.06801632058341056, 0.02335820197913563, 0.06445230479585007, 0.03323866076243576, 0.043889199805562384, 0.037758280741400085, 0.03379559064342175, 0.034989858395420015, 0.03756869169592392, 0.02677359156223247, 0.013520270113076549, 0.06895195358083583, 0.040120024714269675, 0.05971472346573137, 0.049218859130633064, 0.034792565857060254, 0.04736817289085593, 0.023216149347717874, 0.011843839220091468, 0.035007933402084745, 0.007168799602368381, 0.10594227846013382, 0.038324231427395716, 0.06442222555051558, 0.020893575929221697, 0.014711759449710371, 0.12156044234870933, 0.02451227315759752, 0.11048153566662222, 0.0833294766198378, 0.08102941996185109, 0.1635964511660859, 0.24249227077234536, 34.70740221440792, 113.54103103280067, 86.02403998374939, 91.11585795879364, 68.98280560970306, 53.44723284244537, 42.866123020648956, 78.10685321688652, 46.06876976788044, 6.347006522119045, 0.15528519870713353, 0.789378845365718, 1.6099614975973964, 1.1962069245055318, 0.5812292208429426, 1.195832525845617, 0.8333264559041709, 0.6188082543667406, 70.39839684963226, 112.42485612630844, 93.17863807082176, 103.57817083597183, 98.4883363544941, 103.02603006362915, 97.58216097950935, 95.86934968829155, 87.78686419129372, 84.52155500650406, 78.2182328402996, 82.63511583209038, 79.25465002655983, 80.84141448140144, 67.28295922279358, 65.37011906504631, 66.46668702363968, 67.52467185258865, 65.35795971751213, 66.75608709454536, 65.05982771515846, 65.88698253035545, 61.64953351020813, 65.5513921380043, 62.570452094078064, 63.435422480106354, 62.64624662697315, 62.0158376544714, 56.74537606537342, 59.538644179701805, 60.71396291255951, 65.88837325572968, 67.12649881839752, 69.2379467189312, 70.58248937129974, 62.37958453595638, 71.56374871730804, 82.51875087618828, 79.70845207571983, 79.0671756863594, 71.89678564667702, 79.18905794620514, 78.55918854475021, 75.90651288628578, 66.98274493217468, 65.93650907278061, 63.17625738680363, 68.64349901676178, 67.9843407869339, 73.73451143503189, 73.91146034002304, 77.74212598800659, 40.114774256944656, 68.39340403676033, 78.98389935493469, 71.07448697090149, 67.91624084115028, 63.82647469639778, 65.96000701189041, 63.64420227706432, 63.24024975299835, 57.065516486763954, 59.27274204790592, 58.457142412662506, 63.36576081812382, 66.11159607768059, 70.86292192339897, 70.52248299121857, 64.14465442299843, 70.37717118859291, 70.96984818577766, 60.628627091646194, 59.932048469781876, 56.577307283878326, 59.00127321481705, 58.5319983959198, 60.49828268587589, 57.377852126955986, 60.55292755365372, 55.98449729382992, 60.21855689585209, 60.421306416392326, 70.23557558655739, 70.82513675093651, 70.29334008693695, 61.02031767368317, 61.44157066941261, 61.48716062307358, 69.53702107071877, 72.78042823076248, 78.36257949471474, 78.53367671370506, 83.01539942622185, 79.3369460105896, 82.60313674807549, 77.09975525736809, 84.31134268641472, 80.08335515856743, 95.4307696223259, 24.16741568595171, 0.8685049088671803, 0.3120662405854091, 0.9186219633556902, 1.0157073475420475, 3.7764627439901233, 2.541879778727889, 1.1381347593851388, 0.1559986697975546, 0.07576049800263718, 17.1201466396451, 34.12323676049709, 40.42704530060291, 32.55705580115318, 22.90399868041277, 57.61441223323345, 76.456198990345, 74.60688382387161, 79.59516495466232, 84.02111425995827, 5.321643417701125, 0.3432109724963084, 0.03067890622332925, 0.06830194353824481, 0.041239164856961, 0.06290066696237773, 0.016366690324502997, 0.03436947488808073, 0.049593636285862885, 0.004774572289534262, 0.014678927764180116, 0.01758088474161923, 0.04337223457696382, 0.0154449614637997, 0.0545663448428968, 0.04219740367261693, 0.024338913026440423, 0.08424890853348188, 0.06474529727711342, 0.05989707286062185, 0.037927972807665356, 0.17738723225193098, 0.16489989997353405, 0.201897312363144, 0.12377495906548575, 0.10960204614093527, 0.10646945564076304, 0.2240594450267963, 0.20577231771312654, 0.2104322036029771, 0.0968881807057187, 0.22167428629472852, 0.18226956948637962, 0.18980184890097007, 0.1892264321213588, 0.3468918171711266, 0.3215560829266906, 0.6095232744701207, 0.7791353075299412, 37.47091792523861, 134.09983545541763, 99.05666425824165, 100.37856772542, 83.87825712561607, 65.27096718549728, 80.21368816494942, 102.13306277990341, 57.18269839882851, 10.692805778235197, 0.38022591441404074, 1.5129446284845471, 2.5684389285743237, 2.366809635423124, 1.2006222875788808, 1.6897481912747025, 5.5557137075811625, 1.2290928536094725, 73.19476559758186, 119.00657415390015, 98.99683266878128, 109.8416331410408, 101.44804313778877, 108.39108377695084, 101.41782715916634, 100.71035072207451, 91.84296414256096, 88.80375042557716, 82.22580939531326, 87.61721089482307, 83.297830671072, 86.85811042785645, 70.93868225812912, 69.43330183625221, 70.522171407938, 70.44869855046272, 69.18987929821014, 70.2432131767273, 68.30678388476372, 69.70883265137672, 64.61176335811615, 69.27991166710854, 66.32151201367378, 68.21384847164154, 67.1203051507473, 65.91144561767578, 59.92672495543957, 63.690107613801956, 65.48488050699234, 68.79394054412842, 70.501067340374, 70.0835533440113, 73.27424213290215, 66.32278114557266, 74.43858325481415, 85.54328218102455, 82.30391040444374, 82.64835432171822, 73.57908457517624, 82.39028736948967, 82.18859419226646, 79.10326614975929, 71.16508930921555, 67.46613219380379, 64.59966480731964, 71.31948262453079, 70.23154020309448, 78.1182450056076, 78.84342089295387, 82.64407575130463, 45.525440722703934, 72.37261891365051, 83.24363797903061, 75.89223325252533, 72.70760133862495, 67.3010766506195, 68.10197487473488, 67.52181440591812, 66.35911479592323, 61.00976563990116, 61.83414280414581, 61.40984997153282, 66.55311718583107, 69.68372359871864, 74.30996015667915, 73.7596432864666, 67.83957615494728, 74.12693157792091, 74.46628376841545, 65.16118347644806, 64.6542526781559, 60.841533467173576, 63.74694876372814, 62.079248651862144, 66.23163923621178, 61.06561504304409, 63.59934188425541, 59.88260932266712, 63.86450305581093, 64.71010208129883, 75.2442692220211, 74.08152401447296, 76.5434955060482, 65.01667723059654, 64.18935522437096, 65.48366457223892, 75.22983759641647, 74.87206399440765, 80.58411508798599, 82.49206870794296, 87.7225412428379, 83.71819451451302, 87.12363258004189, 81.88155546784401, 90.54881438612938, 84.32235449552536, 102.3955374956131, 21.871466785669327, 3.7799001345410943, 12.906010318547487, 3.6496048886328936, 0.6654616759624332, 4.332618238404393, 4.822075674310327, 0.9239699982572347, 0.29452572867739946, 0.1219952963583637, 29.55885898321867, 44.905215203762054, 70.40285021066666, 62.04507328569889, 23.204942531883717, 57.53200985491276, 87.1910485625267, 87.78801172971725, 90.2944940328598, 94.07483518123627, 3.5094693582504988, 0.3083659219555557, 0.11940733093069866, 0.24160599801689386, 0.1611654573935084, 0.14740146783879027, 0.1297343010082841, 0.16642688366118819, 0.18869074992835522, 0.15963920101057738, 0.08811414722003974, 0.12898640910862014, 0.11911300258361734, 0.11814859652076848, 0.1367805479094386, 0.11048278247471899, 0.15276502846973017, 0.23157789080869406, 0.18855628761230037, 0.21337967278668657, 0.15387473220471293], [0.005577195261139423, 0.019954100462200586, 0.07148117059841752, 0.03898373724950943, 0.04011504119262099, 0.05776255224191118, 0.09574775947839953, 0.014547342198056867, 0.05685781485226471, 0.04174215173406992, 0.041487728667561896, 0.006834735277152504, 0.07057196547975764, 0.034463111660443246, 0.04152930749114603, 0.03920697527064476, 0.15974192909197882, 2.001807396300137, 79.58368197083473, 81.39270409941673, 81.90166398882866, 55.05323566496372, 45.09055405855179, 42.271397933363914, 72.92320936918259, 75.23867592215538, 27.418279945850372, 0.5155631038360298, 0.08107971530989744, 0.8923276711720973, 0.805961808655411, 2.231932310387492, 0.7434653746895492, 0.42432768386788666, 1.2622568802908063, 12.402182053774595, 113.35015207529068, 94.53961104154587, 95.59330970048904, 91.62345752120018, 99.92700755596161, 94.40265119075775, 93.69157254695892, 88.60417753458023, 82.52375900745392, 75.00457048416138, 71.9543905556202, 68.73697400093079, 69.87588688731194, 64.54634606838226, 63.20793628692627, 61.5208800137043, 59.84021119773388, 60.59179946780205, 62.12413564324379, 60.30711114406586, 60.84128648042679, 59.823400899767876, 61.178674176335335, 59.148515313863754, 59.78313446044922, 59.140497744083405, 56.665629744529724, 54.92449477314949, 55.321539267897606, 57.302749156951904, 56.969191655516624, 61.37861184775829, 61.73561409115791, 64.89181593060493, 69.82714310288429, 66.76150560379028, 60.637932792305946, 70.36245077848434, 77.37850829958916, 77.96558439731598, 73.92947137355804, 72.08272486925125, 72.17466473579407, 73.21463853120804, 72.88536339998245, 68.12850505113602, 66.95777267217636, 72.35291317105293, 73.34000900387764, 70.20364210009575, 71.12353473901749, 67.96649694442749, 37.25596345961094, 66.6845141351223, 72.17693701386452, 66.43606066703796, 64.34536725282669, 59.50069561600685, 56.603161096572876, 54.12129767239094, 55.039731189608574, 55.78217335045338, 53.94265405833721, 58.90140317380428, 58.414934277534485, 64.31786432862282, 65.69933339953423, 67.23773404955864, 60.76568193733692, 62.125640362501144, 75.33544152975082, 60.86964815855026, 55.71960970759392, 53.1735373288393, 52.127495259046555, 52.638423442840576, 53.395825400948524, 56.59536011517048, 56.38155318796635, 55.812879502773285, 55.80825135111809, 56.192965507507324, 58.02235834300518, 58.88763651251793, 57.93647915124893, 57.73438319563866, 57.44460314512253, 57.06043615937233, 65.31040146946907, 72.58704900741577, 74.38017278909683, 75.91247096657753, 72.73093968629837, 80.81600144505501, 74.9014288187027, 74.00758758187294, 72.57303535938263, 81.19941607117653, 79.05373960733414, 84.2320865392685, 8.473598510026932, 0.5146184389013797, 4.479217696934938, 1.4535979880020022, 1.3470088387839496, 0.7307945983484387, 0.39087353681679815, 0.15616859192959964, 0.02396396146650659, 1.8762927688658237, 24.676195085048676, 35.29338017106056, 68.55704605579376, 39.02008719742298, 26.235145032405853, 38.88540342450142, 60.694648548960686, 66.22963294386864, 75.27072340250015, 29.083092212677002, 0.4546532331733033, 0.11261883191764355, 0.044265969627304, 0.12893405801150948, 0.0671545609657187, 0.0689346541184932, 0.02813751983921975, 0.013383281711867312, 0.04898124570900109, 0.055747955266269855, 0.048259143441100605, 0.02796575161482906, 0.07363763652392663, 0.03218255122192204, 0.05332938504579943, 0.03156500642944593, 0.111254697694676, 0.07852278649806976, 0.08416928350925446, 0.06942613399587572, 0.04492319334531203, 0.04236910324834753, 0.019148343308188487, 0.0452341754862573, 0.0330171111272648, 0.05854014489159454, 0.022530143287440296, 0.030787721771048382, 0.02565423619671492, 0.03715116312378086, 0.04282933128706645, 0.023774801011313684, 0.03331848616653588, 0.05066317869932391, 0.036832369878538884, 0.1454389770515263, 0.1803443641983904, 5.591428941115737, 103.26556921005249, 87.22778499126434, 90.89137360453606, 69.6441525220871, 69.19231876730919, 44.47653740644455, 55.974625423550606, 81.57561108469963, 28.873979933559895, 0.4642782057635486, 0.28361508913803846, 1.995535595342517, 2.03816550783813, 3.5899837128818035, 2.152515146881342, 0.18909661564975977, 1.2271468830294907, 17.732194997370243, 121.02634817361832, 96.41484841704369, 99.06288832426071, 92.89677679538727, 102.77094975113869, 98.91183882951736, 96.7490328848362, 91.33844241499901, 86.27576887607574, 78.34581479430199, 74.409469217062, 72.39151909947395, 71.93683549761772, 67.02281758189201, 64.87968698143959, 64.51017200946808, 64.17005226016045, 64.08088624477386, 64.59203481674194, 63.69850896298885, 64.30854722857475, 62.24895894527435, 63.624188750982285, 61.899453699588776, 62.869959622621536, 61.84422746300697, 61.258355900645256, 59.70678135752678, 58.11549134552479, 59.59894694387913, 58.40627074241638, 63.7031789124012, 66.74716517329216, 67.83612594008446, 71.08783945441246, 69.75421741604805, 62.330209985375404, 74.36304330825806, 77.53594145178795, 79.17293161153793, 76.79286852478981, 73.90664219856262, 74.12236422300339, 78.09421509504318, 77.06325441598892, 71.33631572127342, 68.35764795541763, 74.79846954345703, 75.89304640889168, 73.22403162717819, 75.80584108829498, 69.4247218966484, 43.17487545311451, 69.79707911610603, 74.05748650431633, 71.79547548294067, 66.41127839684486, 61.58753603696823, 60.70122979581356, 55.66894702613354, 57.56448291242123, 59.28400084376335, 57.11948499083519, 60.876818373799324, 61.550400629639626, 66.05099692940712, 69.73106145858765, 71.06230482459068, 64.90547239780426, 64.64086979627609, 78.94679814577103, 64.87341731786728, 59.539347141981125, 56.30596004426479, 56.822504326701164, 56.6160424053669, 57.1787466108799, 59.387286901474, 57.98015400767326, 56.350379660725594, 56.68348878622055, 57.424346432089806, 59.060337245464325, 62.99571767449379, 59.81477536261082, 60.41422739624977, 60.249251648783684, 60.34995384514332, 67.98660546541214, 76.73421487212181, 77.7795235812664, 78.6819675564766, 77.05163463950157, 84.69827592372894, 76.15867495536804, 78.05148258805275, 74.52999874949455, 86.256785094738, 77.74062886834145, 94.06737998127937, 19.42046720534563, 0.5391649436205626, 2.24964695982635, 1.0001546633429825, 2.516196956858039, 3.3547665970399976, 1.2230892945080996, 0.763293185736984, 0.06905608432134613, 1.4330851449631155, 29.0174051374197, 37.36205756664276, 45.96187390387058, 35.89054852724075, 39.7393923997879, 45.435830131173134, 70.30002012848854, 71.8701034784317, 84.29996609687805, 48.086275309324265, 0.7260431908071041, 0.007025270097074099, 0.04094530777365435, 0.03754070901777595, 0.046924168200348504, 0.033158857622765936, 0.02154031866666628, 0.05520923397853039, 0.023205616416817065, 0.03418475804210175, 0.04255438412656076, 0.03995642939116806, 0.04296063205401879, 0.037714753780164756, 0.02159405757993227, 0.03013193967490224, 0.04896203892712947, 0.0515919245663099, 0.034740170231088996, 0.0642999418778345, 0.1012179593089968, 0.08919213898479939, 0.10531508945859969, 0.17550005461089313, 0.19416640454437584, 0.12885067029856145, 0.1510260280338116, 0.17262117471545935, 0.18146298854844645, 0.14318641042336822, 0.09850729460595176, 0.16272316599497572, 0.26474782498553395, 0.1894743094453588, 0.11341428064042702, 0.2601116878213361, 0.30504917493090034, 5.046603251248598, 114.377730935812, 104.8775415122509, 104.36936438083649, 79.59667727351189, 65.1603627204895, 60.1509091258049, 101.14154398441315, 90.28052598237991, 47.67103359103203, 0.8591191156301647, 0.22840799996629357, 2.404673653654754, 2.1885782992467284, 7.1878686267882586, 3.4706774773076177, 2.9200715851038694, 4.164670100435615, 16.17114756256342, 124.54993709921837, 100.59685841202736, 105.31979218125343, 97.16747403144836, 107.94244185090065, 99.49996367096901, 99.48342695832253, 94.61986273527145, 90.57295829057693, 81.3416500389576, 79.66874420642853, 77.20187857747078, 76.47384524345398, 72.1690334379673, 67.5752167403698, 68.31049248576164, 69.18094977736473, 68.47795709967613, 68.28268557786942, 66.15166872739792, 67.63311043381691, 66.75449877977371, 68.56738150119781, 66.15358382463455, 65.08887335658073, 64.32816177606583, 64.84936460852623, 63.884223997592926, 63.40049475431442, 62.43551753461361, 62.54277437925339, 64.3777035176754, 67.94221624732018, 69.6028259396553, 73.29096123576164, 70.9053884446621, 64.97886165976524, 78.60086470842361, 84.82063695788383, 84.4916658103466, 78.35741937160492, 76.25609412789345, 76.31640449166298, 81.2489578127861, 79.32458147406578, 74.45334926247597, 72.8218612074852, 79.35457706451416, 80.76099559664726, 78.11188414692879, 77.2842201590538, 76.80635780096054, 47.9984962195158, 73.11760693788528, 77.65394032001495, 75.67626044154167, 70.42760968208313, 64.99257892370224, 63.84276822209358, 59.38742749392986, 60.30323535203934, 63.07490922510624, 59.84070897102356, 63.93069550395012, 64.48265388607979, 69.7657535970211, 73.83128464221954, 73.98747906088829, 67.76117876172066, 67.79008761048317, 79.26572263240814, 65.6537814438343, 62.8043295443058, 60.43132647871971, 58.53442646563053, 58.98864269256592, 59.29666556417942, 63.260327875614166, 63.62814053893089, 60.94358079135418, 60.42719230055809, 62.00017109513283, 63.411628156900406, 65.61934769153595, 62.52338781952858, 64.14042145013809, 64.42531496286392, 64.4933009147644, 72.4978905916214, 81.80524036288261, 81.97563081979752, 82.5541877746582, 80.66442757844925, 89.4951993227005, 81.26462817192078, 82.65599951148033, 78.00832450389862, 90.86524620652199, 82.96846434473991, 97.01894000172615, 17.08576038479805, 1.7508218390867114, 16.887405328452587, 4.402960063889623, 2.786142071709037, 4.242651890963316, 1.7648739600554109, 0.6891400460153818, 0.14408573013497517, 3.674794686958194, 42.46829196810722, 50.37518508732319, 97.1993239223957, 51.81777007877827, 36.60055182874203, 53.40496011078358, 82.49026760458946, 82.63009250164032, 101.5221543610096, 47.11043067276478, 0.8286710525862873, 0.23845624906243756, 0.13266539841424674, 0.3077721444424242, 0.13950679771369323, 0.23059366940287873, 0.11717880246578716, 0.16430901683634147, 0.1510890809004195, 0.15531093638855964, 0.16237628617091104, 0.15682577854022384, 0.10420157850603573, 0.144669295696076, 0.11702134099323303, 0.15642169397324324, 0.21370880043832585, 0.10370870339102112, 0.2470087885740213, 0.20263941551093012], [0.021135733150003944, 0.06444541766541079, 0.02525435404095333, 0.009303206115873763, 0.02442052329570288, 0.08502943266648799, 0.046154995216056705, 0.06892998600960709, 0.015521402674494311, 0.11229982716031373, 0.03896335787430871, 0.06213137152371928, 0.08370106996153481, 0.18172109266743064, 0.11463840870419517, 0.33745223307050765, 0.517945101018995, 24.6045708283782, 91.43045827746391, 76.11278101801872, 72.15596973896027, 43.97667042911053, 22.376465387642384, 48.0998519808054, 95.86719140410423, 40.641494393348694, 8.842018190771341, 0.059266833632136695, 0.2497074898565188, 1.9538153777830303, 1.9329284923151135, 1.0619691526517272, 1.1385584366507828, 0.3324169688858092, 0.218535253952723, 67.15878948569298, 111.85471951961517, 85.61633706092834, 86.30692720413208, 83.95177558064461, 98.80439579486847, 92.5491714477539, 100.46837210655212, 89.01690378785133, 85.36822557449341, 72.61538788676262, 71.03327438235283, 65.75652033090591, 62.77989685535431, 59.87645745277405, 62.812084928154945, 59.4416543841362, 59.85979534685612, 61.634771302342415, 62.357230335474014, 59.420512318611145, 60.24105928838253, 57.494019493460655, 60.870541110634804, 60.66798537969589, 58.80300745368004, 57.49604858458042, 58.56935039162636, 55.787702053785324, 57.44163170456886, 58.750669062137604, 60.96948400139809, 66.20823249220848, 62.56896257400513, 61.50178603827953, 68.368249386549, 68.39347243309021, 59.960938319563866, 58.71009483933449, 67.48396083712578, 70.72494372725487, 72.49013140797615, 74.08645614981651, 70.29919177293777, 67.31802374124527, 78.62949997186661, 73.02141889929771, 72.93345361948013, 71.5117447078228, 69.32832106947899, 75.84095120429993, 67.9261963069439, 55.90167313814163, 46.950235068798065, 68.05063962936401, 72.50505700707436, 64.41067814826965, 61.66534066200256, 57.354141399264336, 57.88403056561947, 55.6913848221302, 58.881845623254776, 56.26934140920639, 58.22975121438503, 54.93476562201977, 59.87112633883953, 62.08665445446968, 66.73029407858849, 65.93922972679138, 65.23493751883507, 57.52477504312992, 80.11653497815132, 74.4508945941925, 57.97497108578682, 52.5143601000309, 51.079332903027534, 53.68587143719196, 56.302445232868195, 53.31397399306297, 55.30054919421673, 54.48675826191902, 56.403512209653854, 54.76201929152012, 54.79559049010277, 55.858963429927826, 57.40486487746239, 57.24557362496853, 56.89612157642841, 55.42882651090622, 58.38850289583206, 63.959786742925644, 74.10300806164742, 77.03884452581406, 75.5814403295517, 72.62801080942154, 74.25006777048111, 69.6551339328289, 72.83972024917603, 73.18695321679115, 78.2791967689991, 76.40889152884483, 83.05636122822762, 5.4739463701844215, 0.580803049961105, 3.731401674449444, 3.8794749788939953, 2.171745439991355, 0.9173832298256457, 0.23920148407341912, 0.11259752485784702, 0.07060763309709728, 10.671791955828667, 24.830086827278137, 55.414767265319824, 50.60899414122105, 19.83043670654297, 58.27953614294529, 55.18552556633949, 63.61338593065739, 61.51604287326336, 76.34039640426636, 4.451592229306698, 0.23074327153153718, 0.04280167515389621, 0.01580283063958632, 0.03393544095160905, 0.06362984931911342, 0.06602086359634995, 0.044675553508568555, 0.030225864029489458, 0.032603200525045395, 0.028743093789671548, 0.04115711672056932, 0.13840807776432484, 0.009585973657522118, 0.02359314552450087, 0.02212458370195236, 0.06266673459322192, 0.016120453146868385, 0.010046871484519215, 0.03188724695064593, 0.09616411916795187, 0.0543053426372353, 0.03309972700662911, 0.0403256033314392, 0.02750424337136792, 0.031066173723957036, 0.07257941557327285, 0.03981261601438746, 0.0498558296385454, 0.0543919661140535, 0.018924862233689055, 0.07950647355755791, 0.1222187199164182, 0.1098775387799833, 0.050701009677140974, 0.34735542198177427, 0.4677782632643357, 37.89877496659756, 105.4995909333229, 83.35328489542007, 83.38924616575241, 53.438041135668755, 43.356760293245316, 46.21178649365902, 81.75280317664146, 46.67995557188988, 10.986168086528778, 0.08187882282072678, 1.6015793848782778, 5.26646657846868, 5.114914085716009, 2.4300510669127107, 1.9900382403284311, 0.2609895000932738, 0.8063701679930091, 78.17091017961502, 112.42854192852974, 89.483283162117, 87.42288172245026, 88.3164493739605, 102.46666967868805, 95.09546041488647, 102.05987110733986, 92.8906287252903, 89.79238137602806, 75.62844380736351, 74.78748053312302, 69.0847997367382, 66.13266214728355, 63.38164396584034, 65.05260810256004, 63.039172142744064, 65.1689350605011, 64.40868705511093, 64.289381057024, 63.13290171325207, 64.26379323005676, 60.8393219858408, 63.02520789206028, 61.350485756993294, 62.39590086042881, 60.55340252816677, 61.16265423595905, 59.260198920965195, 61.7778754234314, 63.158204555511475, 64.98738840222359, 65.39400458335876, 65.03056168556213, 64.80694368481636, 71.68104082345963, 70.5336543917656, 60.66518492996693, 59.5183190703392, 70.00090777873993, 72.17070534825325, 74.26633849740028, 75.8002857863903, 73.04819986224174, 71.2838177382946, 80.88524892926216, 76.50789141654968, 75.57824090123177, 74.58118960261345, 73.04527401924133, 78.03578183054924, 70.54851159453392, 60.04126600921154, 49.64734174311161, 72.32734814286232, 74.24262017011642, 68.83940130472183, 63.925504982471466, 62.008013874292374, 61.6526797413826, 59.89126905798912, 62.87663206458092, 60.07560856640339, 59.994733706116676, 57.05537863075733, 63.374169766902924, 64.96024265885353, 70.27883246541023, 68.34653735160828, 68.12562480568886, 59.34314467012882, 84.09062013030052, 76.62829175591469, 62.400870993733406, 55.40268011391163, 56.1685936152935, 56.883620247244835, 59.065808951854706, 56.585427448153496, 57.014006450772285, 56.290517672896385, 58.82412672042847, 56.70844964683056, 57.437714114785194, 58.65798823535442, 59.694359824061394, 59.4486840069294, 58.380701914429665, 58.55364203453064, 62.519945204257965, 66.87262684106827, 77.2017265856266, 79.22140941023827, 80.89799344539642, 76.42960801720619, 79.0021687746048, 71.6191877424717, 75.41874065995216, 75.98954603075981, 83.06225851178169, 75.78621134161949, 94.79984387755394, 16.85863897204399, 1.86840676702559, 1.4936524699442089, 0.676150502404198, 6.127653792500496, 3.863826706074178, 1.4486181177198887, 0.4907257069135085, 0.03115027204330545, 10.321133472025394, 32.77919188141823, 48.220271319150925, 33.92774485051632, 21.707007810473442, 76.11143589019775, 61.41779914498329, 75.55430978536606, 66.13367289304733, 95.08858278393745, 11.339441780000925, 0.8174176595639437, 0.049010597649612464, 0.1044296998588834, 0.024969109581434168, 0.055514549821964465, 0.05167922339751385, 0.0681585977145005, 0.07945918390760198, 0.021458810442709364, 0.04398888137075119, 0.027363303961465135, 0.15012425923487172, 0.03679493223899044, 0.035927944190916605, 0.035610123159131035, 0.015590001239615958, 0.0853822348290123, 0.04028227303933818, 0.05860432211193256, 0.1715039010741748, 0.1745133989606984, 0.08983934370917268, 0.11100215226178989, 0.14571637701010332, 0.1672780973603949, 0.1808073159190826, 0.11753401660826057, 0.15880671911872923, 0.1718436711234972, 0.20041490206494927, 0.20915612520184368, 0.387358576990664, 0.3380489198025316, 0.29611092642880976, 0.8461434650234878, 1.109780443366617, 43.399808183312416, 119.62901875376701, 98.96283209323883, 94.29111957550049, 65.82987159490585, 37.72664800286293, 65.17290204763412, 121.71176299452782, 58.45437616109848, 19.244888126850128, 0.25798083341214806, 4.563317634165287, 7.918456848710775, 6.531566418707371, 6.822735294699669, 6.569948634132743, 4.135649157688022, 0.8791070524603128, 76.67602479457855, 121.64183914661407, 94.25386637449265, 94.1277739405632, 89.09209415316582, 106.64750173687935, 98.49243253469467, 107.69318282604218, 97.19882234930992, 95.50527602434158, 79.11689221858978, 78.60176146030426, 72.3599123954773, 69.23352375626564, 66.06957793235779, 69.52262744307518, 66.81543231010437, 68.38991582393646, 68.15149381756783, 70.14179661870003, 65.2665214240551, 67.68051669001579, 64.2309857904911, 67.40452229976654, 65.93217730522156, 65.1792325079441, 65.05773022770882, 65.81227093935013, 64.78157624602318, 66.35542899370193, 66.9658662378788, 64.39793363213539, 69.3905009329319, 67.0652537047863, 65.19692435860634, 72.3532247543335, 71.61063060164452, 63.85893255472183, 62.8851056098938, 72.71070957183838, 73.50938871502876, 80.15330940485, 80.29494300484657, 76.22445702552795, 73.08381915092468, 83.03506717085838, 77.52021789550781, 80.56863471865654, 76.31772682070732, 77.07905396819115, 79.84903693199158, 78.14699426293373, 63.95080402493477, 55.667993277311325, 76.0517866909504, 79.84015300869942, 72.44055166840553, 69.70327734947205, 66.61471948027611, 65.92879548668861, 62.87074618041515, 67.10411041975021, 61.457412019371986, 64.13221389055252, 60.50972007215023, 67.24802389740944, 67.64747366309166, 73.0014243721962, 73.5159319639206, 72.36186549067497, 61.92659944295883, 85.98136067390442, 78.54935467243195, 64.72026273608208, 57.78957523405552, 57.978979870676994, 61.317343935370445, 61.83076098561287, 59.263345152139664, 60.37578105926514, 60.44831916689873, 63.385291770100594, 61.45670525729656, 60.171458423137665, 62.36315041780472, 63.63860137760639, 64.2892974615097, 64.43146303296089, 61.81350991129875, 67.06237345933914, 71.16348579525948, 82.1364837884903, 84.84189301729202, 83.20317015051842, 79.09977033734322, 82.93628007173538, 76.34959951043129, 80.22980690002441, 78.12804087996483, 89.15603712201118, 81.96499899029732, 98.87906938791275, 14.568509459495544, 3.6240640841424465, 13.143676165491343, 7.139312932267785, 6.980792563408613, 4.941958291456103, 1.6517910780385137, 0.46155995631124824, 0.16718188533559442, 17.81189762055874, 42.95932821929455, 80.06928831338882, 69.02703523635864, 26.47633519023657, 77.42726728320122, 69.86254960298538, 87.54397362470627, 78.39322105050087, 108.09276178479195, 12.662809118628502, 0.8545080630574375, 0.1856839979882352, 0.1519494823878631, 0.08948573260568082, 0.16227079730015248, 0.1501139730680734, 0.11876213000505231, 0.112481690448476, 0.16063575691077858, 0.09353208501124755, 0.12562154122861102, 0.2707699971506372, 0.09443328977795318, 0.06520639362861402, 0.17165801546070725, 0.14445214328588918, 0.14418434671824798, 0.2048505554557778, 0.16590010724030435], [0.046482248944812454, 0.02399117045570165, 0.03222338418709114, 0.007446364688803442, 0.03897642338415608, 0.05068930971901864, 0.032315788994310424, 0.06480390467913821, 0.05180650172405876, 0.037077790693729185, 0.052551454718923196, 0.0031125801115194918, 0.09240248429705389, 0.05657858549966477, 0.08807465754216537, 0.0616001793241594, 0.06923739842022769, 61.83935612440109, 84.60293143987656, 80.66984608769417, 58.84340688586235, 51.440613716840744, 33.04993875324726, 47.8660087287426, 45.599103569984436, 28.45305372029543, 3.045271304436028, 0.2086457354016602, 0.39361393195576966, 1.4760739007033408, 2.6994936587288976, 2.848399830982089, 0.13791814155410975, 1.7172986129298806, 22.868153303861618, 113.05963486433029, 90.58841586112976, 89.39247563481331, 74.08065006136894, 91.17331847548485, 94.07498717308044, 97.61852502822876, 92.81899496912956, 94.5372399687767, 82.3445226252079, 79.17962685227394, 73.47350344061852, 71.26633107662201, 64.5458596944809, 62.940145656466484, 61.70592248439789, 60.80727070569992, 59.692243337631226, 59.699421152472496, 57.923419252038, 59.095340967178345, 59.367543160915375, 59.589014276862144, 61.666431203484535, 59.68957208096981, 56.5278073400259, 55.654701590538025, 54.39470060169697, 56.30531407892704, 57.11697332561016, 60.46624280512333, 65.73808372020721, 63.226361498236656, 59.63564157485962, 62.97263391315937, 69.39747735857964, 67.03921750187874, 58.734899908304214, 55.84225572645664, 57.28035315871239, 67.41826996207237, 68.83285805583, 70.77155962586403, 74.01903256773949, 67.11071446537971, 72.50339269638062, 78.24419304728508, 68.40604215860367, 72.41905242204666, 74.75158765912056, 69.95974078774452, 53.6605229973793, 59.448106437921524, 48.24759565293789, 71.43393248319626, 66.03588134050369, 62.99055375158787, 61.38303101062775, 61.99112758040428, 59.669611752033234, 62.638206258416176, 60.9188175201416, 61.51551470160484, 58.74968111515045, 56.147732734680176, 56.9004837423563, 63.58324974775314, 62.359502613544464, 65.89360937476158, 61.09372593462467, 57.550127282738686, 71.46493881940842, 83.58498886227608, 67.86679789423943, 57.03174389898777, 52.18223512172699, 51.88757233321667, 53.919391706585884, 54.56722654402256, 54.7122647613287, 55.20757958292961, 54.61230352520943, 55.08595950901508, 54.6000187844038, 55.869526863098145, 56.09440639615059, 55.48404514789581, 55.59029124677181, 55.09719170629978, 55.61891511082649, 55.70569485425949, 60.04940517246723, 65.09644255042076, 68.8272875547409, 69.04369354248047, 67.35066398978233, 68.68984892964363, 63.40328760445118, 68.6779023706913, 74.96107801795006, 76.629758477211, 73.59939828515053, 77.14811146259308, 5.0573148764669895, 1.2434506206773221, 4.344913428649306, 3.4332456858828664, 1.3072183239273727, 2.005675588734448, 0.24446519615594298, 0.10616671133902855, 0.6239762145560235, 22.029849886894226, 27.799407094717026, 79.25284892320633, 50.92871278524399, 17.343481555581093, 40.78299880027771, 51.93096600472927, 58.24811942875385, 71.24296993017197, 39.455194249749184, 0.9359433338977396, 0.08066820926615037, 0.08845806587487459, 0.06294679886195809, 0.03952200211642776, 0.01447598377126269, 0.028403234682627954, 0.019504253214108758, 0.04960531397955492, 0.07468819851055741, 0.03521658822137397, 0.08088384027360007, 0.036305207540863194, 0.03839386714389548, 0.048443370469613, 0.00949820449022809, 0.011324245861032978, 0.02967850599816302, 0.011094944493379444, 0.04017763021693099, 0.05489891234901734, 0.05531144626729656, 0.03180574429279659, 0.07268239598488435, 0.039154820842668414, 0.06564832030562684, 0.03800962018431164, 0.06337889208225533, 0.03416259009100031, 0.04920826126181055, 0.06708106608130038, 0.004947719053234323, 0.0328559463378042, 0.03032407428690931, 0.04023883513582405, 0.5187979771289974, 80.10907217860222, 93.08831691741943, 90.38070380687714, 72.15300589799881, 66.41485780477524, 34.429766312241554, 36.63109838962555, 50.006148889660835, 33.53844814002514, 3.202367937192321, 0.8710070746019483, 2.4632855085656047, 4.207940753549337, 5.026593524962664, 3.51198292337358, 0.9281019202899188, 1.2052410584874451, 30.231048613786697, 116.87929630279541, 94.50401455163956, 93.14288198947906, 78.42803478240967, 93.04905742406845, 98.98507609963417, 98.99512276053429, 95.75282514095306, 96.78463697433472, 86.6602398455143, 82.72547498345375, 76.2267293035984, 73.38066682219505, 67.39449083805084, 67.61644452810287, 64.46741670370102, 64.60857152938843, 62.43670307099819, 63.98715287446976, 61.42360523343086, 63.320467248559, 62.64816552400589, 62.69631274044514, 63.18677142262459, 61.33588694036007, 60.84210343658924, 57.49269716441631, 58.09879504144192, 58.481324315071106, 59.437113627791405, 61.950055584311485, 66.58014133572578, 64.5181667804718, 61.75499685108662, 64.29551392793655, 71.30534738302231, 68.071378916502, 60.934917256236076, 58.77975270152092, 58.54182466864586, 70.10571375489235, 72.42618843913078, 74.5721384882927, 75.9953673183918, 68.35431173443794, 76.11064553260803, 80.58872044086456, 72.60984778404236, 74.58392545580864, 77.75610163807869, 70.95009684562683, 61.4899230748415, 62.661897987127304, 51.31694555282593, 75.01181289553642, 68.65941256284714, 66.52643501758575, 65.64827173948288, 66.44973993301392, 65.6155326962471, 66.88146516680717, 64.58844020962715, 64.60319861769676, 59.50916916131973, 57.41329662501812, 59.16213758289814, 65.41820168495178, 65.41839927434921, 69.1903504729271, 63.52899245917797, 60.82039900124073, 72.57959380745888, 85.86018517613411, 69.89439189434052, 60.05084149539471, 54.3365903198719, 53.82924534380436, 55.177690386772156, 58.885926604270935, 56.192984506487846, 57.05734692513943, 56.88292108476162, 56.98150299489498, 57.186992168426514, 58.754742443561554, 58.183918073773384, 59.078576266765594, 58.135288283228874, 58.052657917141914, 58.87896537780762, 58.46524357795715, 60.23493401706219, 67.43140205740929, 70.0423863530159, 72.60683074593544, 69.36027735471725, 72.1632881462574, 65.76738774776459, 72.34055623412132, 75.82373052835464, 83.08411493897438, 71.32021218538284, 93.74637320637703, 18.622291535139084, 0.9342310507781804, 0.7829178858082741, 0.43493810982909054, 7.399296406656504, 5.2558214496821165, 1.567154300864786, 0.24419594497885555, 0.29744539700914174, 25.320944488048553, 34.493378698825836, 56.06067940592766, 36.620367765426636, 22.01427262276411, 50.810200944542885, 57.99992434680462, 67.07455560564995, 76.15113615989685, 65.02584993839264, 1.827377756126225, 0.04505743672780227, 0.06360662751831114, 0.042343209715909325, 0.06623104723985307, 0.031789695349289104, 0.005085951015644241, 0.04420049735927023, 0.06493830762337893, 0.056247665561386384, 0.03483195905573666, 0.07435521169099957, 0.11211798613658175, 0.01942415692610666, 0.05274634269881062, 0.036078897028346546, 0.009483337416895665, 0.020456267266126815, 0.01897238751553232, 0.15679287171224132, 0.20026512182084844, 0.14539131632773206, 0.16666928393533453, 0.1478230077191256, 0.11234481615247205, 0.1316153781954199, 0.17470595659688115, 0.13447892531985417, 0.1495927182259038, 0.09516763006104156, 0.15824593749130145, 0.10629537006025203, 0.1744127192068845, 0.11835135868750513, 0.20428201096365228, 0.9018661687150598, 92.10673838853836, 105.93242570757866, 102.08444058895111, 79.37617510557175, 72.66645714640617, 44.80340726673603, 65.46170175075531, 61.875716373324394, 50.09143151342869, 5.044491039589047, 0.8629723463673145, 2.981297462247312, 8.146343920379877, 9.961905498057604, 8.991291280835867, 4.754558997228742, 3.583102044649422, 28.225550428032875, 121.31071731448174, 97.21009254455566, 97.3420062661171, 80.9536224603653, 96.94365084171295, 102.79683396220207, 98.96710306406021, 96.85602754354477, 101.74188897013664, 88.92559468746185, 87.04456642270088, 80.76671048998833, 81.00637122988701, 71.56686455011368, 71.02706551551819, 68.08096960186958, 69.5569396018982, 66.36486768722534, 67.67607852816582, 64.98830795288086, 64.99480560421944, 65.22300615906715, 65.41846007108688, 67.73169234395027, 66.71814993023872, 63.6074810475111, 61.9589851051569, 61.80501736700535, 63.50418359041214, 65.08426800370216, 65.16926944255829, 67.72009536623955, 67.61771366000175, 63.094576969742775, 63.98327708244324, 72.53407984972, 73.0721689760685, 64.66263502836227, 61.329845264554024, 62.84441739320755, 73.94836395978928, 75.23970946669579, 78.90557795763016, 81.90112441778183, 70.81698998808861, 76.55325338244438, 82.01134130358696, 78.69421809911728, 78.11590433120728, 82.07681179046631, 76.13872602581978, 65.66436007618904, 62.132191210985184, 55.30202731490135, 79.40698385238647, 73.16540837287903, 68.92583906650543, 69.08358380198479, 69.18557032942772, 66.8789193034172, 70.15305921435356, 68.21011707186699, 65.35410672426224, 64.22022476792336, 60.6761359423399, 62.32718914747238, 68.6346834897995, 69.47608754038811, 73.9111639559269, 67.69763857126236, 62.820068299770355, 74.255630671978, 85.46144217252731, 72.2573558986187, 64.76422637701035, 57.78416432440281, 60.12116812169552, 60.10421723127365, 61.273463889956474, 59.08816695213318, 61.9506711512804, 60.25074876844883, 60.9461722522974, 59.362390637397766, 61.889300644397736, 62.43698425590992, 63.597734570503235, 61.784399673342705, 61.01970210671425, 61.95721060037613, 63.13707008957863, 65.12967556715012, 72.49830096960068, 75.06944060325623, 75.97838222980499, 71.27071604132652, 79.1324257850647, 69.93209347128868, 77.47306242585182, 80.35423502326012, 87.08392471075058, 79.23690497875214, 96.52034595608711, 16.37220237404108, 2.6808468718081713, 11.041691657155752, 6.718263700604439, 5.334426406770945, 4.486485281959176, 1.2995096063241363, 0.36017465754412115, 1.091016218997538, 38.58055718243122, 42.50500179827213, 105.14592111110687, 64.25069153308868, 26.33627090603113, 57.46106766164303, 69.44455683231354, 78.59009608626366, 88.79710078239441, 69.79109063744545, 1.67073804885149, 0.15717592381406575, 0.21421929413918406, 0.1976673526223749, 0.1344567647902295, 0.19553213438484818, 0.09935735797625966, 0.13325249659828842, 0.19025855173822492, 0.09550997536280192, 0.14255675749154761, 0.271647393819876, 0.21157076203962788, 0.10981882005580701, 0.14842727920040488, 0.09265894084819593, 0.0924295726872515, 0.09923618752509356, 0.12193654794828035], [0.02349561247683596, 0.02992575249663787, 0.05236925004282966, 0.04195140027150046, 0.034642807877389714, 0.05696006053767633, 0.011357712082826765, 0.028326682149781846, 0.06872896788991056, 0.020928803824062925, 0.07914482499472797, 0.03636260895291343, 0.043222380118095316, 0.09729921919642948, 0.13040539546636865, 0.15393846784718335, 6.215620497241616, 83.66262629628181, 77.13624089956284, 70.97345799207687, 57.55672372877598, 43.79767343401909, 51.441206485033035, 58.32903228700161, 36.996004208922386, 17.430223301053047, 0.06236448010895401, 0.28733292245306075, 0.24055112415226176, 1.518496961798519, 2.6337331999093294, 0.8760378265287727, 1.2227552686817944, 3.4583718376234174, 97.80769407749176, 99.63386848568916, 93.71295019984245, 79.92784470319748, 74.04619351029396, 85.37967056035995, 93.24285462498665, 85.57896986603737, 91.27785846590996, 92.1992938220501, 86.07624918222427, 82.6576866209507, 74.47045594453812, 68.77023741602898, 62.625986114144325, 62.36564688384533, 60.018015056848526, 59.4223590195179, 60.187630355358124, 60.782431438565254, 58.8885560631752, 62.54720114171505, 60.377897545695305, 61.09893545508385, 59.83765013515949, 56.432934030890465, 54.904500246047974, 54.62255537509918, 56.838873848319054, 55.98323196172714, 59.361721873283386, 62.073598355054855, 62.57778190076351, 60.30606999993324, 58.91956239938736, 62.36182428896427, 64.14783865213394, 60.7430275529623, 59.70103606581688, 60.80171160399914, 58.84753726422787, 55.442809760570526, 67.3917093873024, 69.02171552181244, 73.46307680010796, 72.3786985874176, 69.30371358990669, 72.67177686095238, 69.72374305129051, 71.84728190302849, 68.01308244466782, 59.04399052262306, 63.654503524303436, 61.703680604696274, 49.22398366034031, 69.67993140220642, 65.36605328321457, 61.718268021941185, 62.6023855805397, 67.58305191993713, 62.060675248503685, 62.20948666334152, 58.648959919810295, 57.44844853878021, 55.71125775575638, 54.14019785821438, 54.651984795928, 61.35820314288139, 60.888369753956795, 65.70278361439705, 60.08111447095871, 57.24484406411648, 67.76100397109985, 73.09440538287163, 76.33709818124771, 63.077846467494965, 56.90146028995514, 52.325487434864044, 48.56590077280998, 50.502162873744965, 53.067268431186676, 53.701393604278564, 53.031732738018036, 53.068503364920616, 54.265803918242455, 54.50815871357918, 54.987020418047905, 53.55174623429775, 55.78954115509987, 55.41427329182625, 55.713674426078796, 53.84161368012428, 53.727847784757614, 53.62391956150532, 53.229705914855, 56.38344928622246, 57.90538161993027, 56.79155878722668, 60.800621062517166, 59.8119293153286, 65.85205480456352, 73.7275730073452, 77.22603008151054, 73.89851063489914, 80.42890101671219, 4.56829346716404, 0.7712189666926861, 7.71493929438293, 3.8925265660509467, 0.9758091322146356, 1.3368146982975304, 0.16372849408071488, 0.08533574669854715, 7.527074050158262, 25.915679074823856, 39.0826166421175, 60.68735294044018, 27.124874889850616, 33.70965175330639, 40.64336009323597, 60.769671723246574, 61.979887783527374, 81.32996186614037, 18.788684606552124, 0.6306905730161816, 0.048779270218801685, 0.1638342352816835, 0.10036768813733943, 0.0747619457251858, 0.024766536662355065, 0.059447609673952684, 0.030515095677401405, 0.09692151797935367, 0.003039013331544993, 0.04663552841520868, 0.06381471830536611, 0.0233412995658, 0.046533063796232454, 0.06036151258740574, 0.033028963225660846, 0.009665878842497477, 0.043028093277825974, 0.021333838340069633, 0.027044046873925254, 0.011338514577801106, 0.0323564067366533, 0.022867473526275717, 0.06317523191682994, 0.021148036103113554, 0.04508816906309221, 0.07934235502034426, 0.03197517660737503, 0.06776136317057535, 0.0347108887945069, 0.09757919440744445, 0.13375362439546734, 0.17210023157531396, 0.3182331909192726, 12.450217176228762, 100.73678970336914, 82.8778088092804, 82.96087235212326, 64.02456566691399, 63.34611587226391, 51.52668669819832, 44.29365321993828, 46.86752110719681, 21.076650135219097, 0.08958519523730502, 1.1074064020067453, 1.9507020385935903, 3.7214450212195516, 3.670722017996013, 0.4577255464391783, 0.9572679677512497, 6.784279458224773, 105.10124310851097, 100.24397894740105, 98.81127342581749, 81.50241181254387, 77.75759115815163, 88.98980364203453, 94.92239490151405, 89.799365401268, 92.25490003824234, 96.09767183661461, 89.39425393939018, 87.87898644804955, 77.58788466453552, 72.6889443397522, 66.05356559157372, 65.3783418238163, 63.621487095952034, 62.86004975438118, 63.025538474321365, 64.61056262254715, 61.310458704829216, 64.59270358085632, 63.232311978936195, 63.83657455444336, 61.53054669499397, 60.21912306547165, 57.53318019211292, 58.175953701138496, 59.49980266392231, 60.5450239777565, 62.32514105737209, 64.20703187584877, 65.85959360003471, 61.6495069116354, 60.500505566596985, 62.575296834111214, 66.75941571593285, 63.78286823630333, 64.0557087957859, 63.53511393070221, 61.236624866724014, 58.92067193984985, 71.01184353232384, 71.7337515950203, 76.32588118314743, 76.1308528482914, 69.37356144189835, 76.21773898601532, 69.83712136745453, 73.40186208486557, 70.51321908831596, 67.9668541252613, 69.20918986201286, 65.2684973180294, 53.062233701348305, 76.02834194898605, 70.53055375814438, 64.67870816588402, 66.41735047101974, 70.31838074326515, 66.91722884774208, 65.0990492105484, 62.34961934387684, 60.070520639419556, 59.85982954502106, 55.96418358385563, 57.153447568416595, 63.18272843956947, 65.64824894070625, 69.75649729371071, 62.2539708763361, 60.012748539447784, 71.18375390768051, 75.47523602843285, 79.40990209579468, 65.82109406590462, 59.986818730831146, 57.111410424113274, 52.76269197463989, 54.89425599575043, 54.96998593211174, 56.606512516736984, 56.87920108437538, 56.77836589515209, 56.80978260934353, 57.307415306568146, 59.136922135949135, 56.79221235215664, 58.44236120581627, 57.71286875009537, 58.44921983778477, 56.85281150043011, 55.72666592895985, 56.26975938677788, 56.422378197312355, 58.349908366799355, 59.59808439016342, 57.926200702786446, 63.89546379446983, 63.7348236143589, 67.29647889733315, 74.78680416941643, 83.41049462556839, 72.78938055038452, 92.44232878088951, 14.574185404926538, 1.1035215854644775, 0.6915146810933948, 2.417423869483173, 6.348411496728659, 2.552186013199389, 0.9071354765910655, 0.20467905997065827, 7.510742051526904, 32.510493099689484, 42.62857876718044, 44.66602563858032, 26.60010974854231, 55.422469452023506, 49.34656888246536, 69.04047891497612, 66.13581597805023, 93.19551676511765, 33.03518794476986, 0.5919081915635616, 0.08459673830657266, 0.09420484188012779, 0.03212759147572797, 0.04837088119529653, 0.021311303025868256, 0.07255680233356543, 0.013924083796155173, 0.03635204448073637, 0.016880045004654676, 0.060798374106525443, 0.0507738403393887, 0.03412684454815462, 0.051785035102511756, 0.04029349802294746, 0.06508048827527091, 0.03608275990700349, 0.04424740851391107, 0.15146480058319867, 0.1201323201530613, 0.20705060771433637, 0.09377075228258036, 0.12118691200157627, 0.14252775436034426, 0.1055337929574307, 0.1397931479732506, 0.272417149390094, 0.08996046963147819, 0.11338738520862535, 0.12572922685649246, 0.19912772113457322, 0.24556234275223687, 0.3587017022073269, 0.53256303537637, 13.253879752010107, 117.21831411123276, 96.95605337619781, 97.14069306850433, 77.53309160470963, 62.59924694895744, 70.13463780283928, 85.64583107829094, 56.88089959323406, 32.28432543575764, 0.3565412212628871, 1.2101230840198696, 1.8030107324011624, 8.93047934398055, 8.33520708605647, 2.8494879975914955, 4.118515877053142, 5.5990038346499205, 106.98333531618118, 105.77374622225761, 103.64285096526146, 86.64247199892998, 82.72365868091583, 94.40855607390404, 98.94895523786545, 93.46163168549538, 95.15089944005013, 100.22906094789505, 93.68271142244339, 91.58920615911484, 82.41228818893433, 77.40448370575905, 69.72694247961044, 69.10303875803947, 67.40902125835419, 67.27124825119972, 65.17518192529678, 66.71799033880234, 63.96615520119667, 67.87404790520668, 66.99703216552734, 66.42620399594307, 64.22160029411316, 63.840009570121765, 61.63443312048912, 64.00847733020782, 63.901938647031784, 65.26588305830956, 65.8569185435772, 67.44526371359825, 68.38157147169113, 63.25340084731579, 62.2981359064579, 64.65447306632996, 70.08325695991516, 67.38353222608566, 65.59042364358902, 67.84523785114288, 64.97836008667946, 61.72422610223293, 75.80720141530037, 75.80023258924484, 80.90865567326546, 77.10226312279701, 72.66217857599258, 76.45221680402756, 73.71045872569084, 79.06209915876389, 76.6962169110775, 72.41529822349548, 71.44169926643372, 66.90330639481544, 56.29685193300247, 79.4315305352211, 74.76138353347778, 68.06754112243652, 70.58151662349701, 75.47221139073372, 69.64735954999924, 68.22563543915749, 65.50561979413033, 63.335275053977966, 63.47286567091942, 60.15204146504402, 60.284274369478226, 68.52567493915558, 68.77700865268707, 75.44666156172752, 66.6552785038948, 64.32698383927345, 71.92527651786804, 78.6924321949482, 79.98715952038765, 66.86349213123322, 63.45798946917057, 60.38549333810806, 55.76054111123085, 58.304253816604614, 59.6855328977108, 61.05855882167816, 60.04261493682861, 59.41365748643875, 61.42838157713413, 60.70487380027771, 62.78292529284954, 58.85026931762695, 62.6727844029665, 60.57897515594959, 62.38986678421497, 59.76054847240448, 60.078477412462234, 61.54685162007809, 59.06773924827576, 62.89849229156971, 64.58989173173904, 61.000224351882935, 68.7621058523655, 67.42276132106781, 75.74413999915123, 80.13925775885582, 87.29161396622658, 79.7518153488636, 96.76211938261986, 11.951767522841692, 2.9095917474478483, 17.025026343762875, 6.426056055352092, 4.999231668189168, 3.0658673867583275, 1.3204387645237148, 0.3335512080229819, 13.217234518378973, 45.04490710794926, 55.018372535705566, 86.54475644230843, 39.936761409044266, 49.86922703683376, 55.739269852638245, 80.82515895366669, 78.7520281970501, 106.29377871751785, 31.968060806393623, 0.9332338417880237, 0.16807939420687035, 0.18099901266396046, 0.20761070656590164, 0.10103088614414446, 0.08138553210301325, 0.13429617887595668, 0.17242984904441983, 0.20891319058137015, 0.1337727124337107, 0.17370683286571875, 0.18407232040772215, 0.1729648039327003, 0.11921041688765399, 0.08447170126601122, 0.12060313863912597, 0.11664336518151686, 0.12507049657870084], [0.05564081140619237, 0.02421180539386114, 0.03908357095497195, 0.05528113695618231, 0.11644078855169937, 0.020059268354089, 0.032896051998250186, 0.045419044472509995, 0.02362644940149039, 0.02661082002305193, 0.1680045115062967, 0.036208628152962774, 0.05714288490707986, 0.06207678285136353, 0.15225682058371603, 0.22761216532671824, 36.41797162592411, 86.46051496267319, 73.2671745121479, 62.68769860267639, 55.88099464774132, 32.118745520710945, 36.74057811498642, 52.88471482694149, 30.211316272616386, 3.9672334073111415, 0.060590528228203766, 0.5918199056759477, 2.008879529312253, 1.4997387933544815, 1.9707167521119118, 1.9228605763055384, 0.309774904162623, 53.51613074541092, 107.33819827437401, 91.4349040389061, 88.49411264061928, 74.30676072835922, 70.3691004216671, 80.0515964627266, 91.71355828642845, 93.75651866197586, 91.51035279035568, 93.20750132203102, 89.06279012560844, 82.68879175186157, 74.98438596725464, 65.7755497097969, 61.709091514348984, 61.54307082295418, 56.77941083908081, 59.54006150364876, 58.26757438480854, 59.82041426002979, 61.73217907547951, 59.9954404681921, 59.35026168823242, 60.98086059093475, 58.60358655452728, 54.6408361941576, 54.95324403047562, 54.37532924115658, 56.87037795782089, 55.151783376932144, 57.72068493068218, 67.18911945819855, 61.71049363911152, 58.812522143125534, 59.61297199130058, 63.982418328523636, 58.698421865701675, 62.17605225741863, 66.78951010107994, 64.99395444989204, 64.17504519224167, 59.59937632083893, 59.2989644408226, 68.8451161980629, 70.54427102208138, 72.53261312842369, 65.06807327270508, 61.72117866575718, 67.11736410856247, 64.91003215312958, 65.03534182906151, 68.01587909460068, 70.64733669161797, 61.07512593269348, 49.86777551472187, 71.0432830452919, 65.71466937661171, 65.6358540058136, 63.92728328704834, 65.11049419641495, 60.69022178649902, 58.077276796102524, 54.31748114526272, 53.77031050622463, 53.65899547934532, 55.48878349363804, 56.1084770411253, 58.15422646701336, 61.517874374985695, 63.581494241952896, 57.381290942430496, 54.47620242834091, 64.3198250234127, 68.13009336590767, 70.10271191596985, 72.32689216732979, 59.29033890366554, 54.298869743943214, 51.359579265117645, 49.44606654345989, 47.70176254212856, 54.350896552205086, 53.27407993376255, 52.211926728487015, 54.400974065065384, 54.736530259251595, 53.59018117189407, 54.32456016540527, 54.18088607490063, 54.118003249168396, 53.83971378207207, 53.148036897182465, 52.48490408062935, 52.47762367129326, 53.23220618069172, 55.283431112766266, 54.49089244008064, 55.22871024906635, 57.507740557193756, 57.908011078834534, 56.59494213759899, 62.44201138615608, 70.15301361680031, 75.85435688495636, 72.197585105896, 75.9723861515522, 2.750732721760869, 0.6629139720462263, 15.979900024831295, 6.351011982187629, 1.3136460352689028, 0.1690067077288404, 0.1039586438855622, 0.3426339675206691, 19.49899759143591, 22.96371817588806, 61.33619472384453, 43.36859665811062, 10.467632710933685, 25.954402796924114, 45.52253767848015, 59.3330942094326, 68.11782002449036, 62.109065651893616, 3.8335701171308756, 0.17768737161532044, 0.022792164090787992, 0.024831328009895515, 0.02412783509498695, 0.032092918336275034, 0.04948624751705211, 0.016790870395198, 0.028229907948116306, 0.03306304264697246, 0.014805964892730117, 0.05740887063439004, 0.08178966862033121, 0.08675770906847902, 0.04029435520351399, 0.027869131408806425, 0.03347694953845348, 0.04650198265153449, 0.0568786209623795, 0.04286758899979759, 0.03160433283483144, 0.03244988765800372, 0.025594049875508063, 0.05062696560344193, 0.012517490376922069, 0.10961864798446186, 0.08072946613538079, 0.0069136585079832, 0.11869455003761686, 0.024882782963686623, 0.06340017687762156, 0.020062916009919718, 0.17991093511227518, 0.2586403948953375, 53.26107703149319, 98.06253120303154, 80.27047991752625, 73.54141339659691, 66.02510511875153, 50.64192697405815, 30.946090444922447, 54.84499163925648, 39.293493926525116, 3.6293455632403493, 0.1946648457669653, 1.885207921732217, 3.409895463846624, 2.8089460730552673, 1.8006328912451863, 0.4961536859627813, 0.8021991793066263, 60.982395708560944, 108.70201349258423, 95.85964500904083, 92.38895684480667, 77.17224776744843, 73.27107310295105, 81.65058106184006, 92.11796298623085, 98.19787994027138, 93.09208631515503, 94.51660707592964, 92.13937863707542, 86.67154043912888, 76.57859042286873, 69.69635412096977, 65.04069954156876, 64.45635169744492, 61.729424223303795, 62.195632606744766, 61.8955285102129, 63.568236753344536, 66.29355311393738, 62.41843365132809, 61.68254613876343, 63.44477757811546, 61.379041224718094, 57.32533514499664, 58.24116960167885, 59.32718552649021, 60.719609409570694, 59.31452460587025, 59.98100504279137, 67.39123061299324, 62.83614903688431, 60.45345649123192, 60.3979604691267, 64.90403607487679, 60.18523648381233, 63.73789384961128, 72.64870449900627, 67.71425127983093, 67.2431069612503, 62.2110977768898, 61.24208137392998, 71.2911969423294, 75.65318807959557, 75.451700091362, 68.43666091561317, 66.04492485523224, 69.20592963695526, 69.34369504451752, 70.38481637835503, 72.20113411545753, 73.20310235023499, 61.921997889876366, 52.76179142296314, 74.97396692633629, 66.92972257733345, 68.01035419106483, 69.56321686506271, 68.66979360580444, 62.86230683326721, 61.0368087887764, 57.90857344865799, 55.91620735824108, 57.24848046898842, 57.348867282271385, 57.419570088386536, 60.723975375294685, 63.518679812550545, 67.94286981225014, 60.36698453128338, 56.525675654411316, 64.98584568500519, 69.63135480880737, 71.0857267677784, 75.04028856754303, 61.772369518876076, 57.868386805057526, 54.71806325018406, 52.44019567966461, 51.024889424443245, 56.22362606227398, 56.3539894670248, 54.052749350667, 56.889931708574295, 56.03389084339142, 57.1868971735239, 58.57330597937107, 58.35032634437084, 56.39881566166878, 57.53214284777641, 56.704038083553314, 55.804759338498116, 54.91904206573963, 56.729378923773766, 58.46895597875118, 55.27154915034771, 59.530736804008484, 60.27296617627144, 61.931748166680336, 61.28105588257313, 65.00388711690903, 70.5189947783947, 79.75042462348938, 73.46271201968193, 89.7897519171238, 7.724008457735181, 1.3234446407295763, 4.271239656955004, 5.595030197873712, 7.285409392789006, 0.974814654327929, 0.23413254122715443, 0.1628749945666641, 27.084536254405975, 35.15246093273163, 62.10969261825085, 42.32948161661625, 17.874658852815628, 40.1084665954113, 51.76079973578453, 69.0765617787838, 72.43802100419998, 79.778573513031, 11.54235564172268, 0.3224084840621799, 0.04204063239740208, 0.08173153619281948, 0.07612688888912089, 0.03493203766993247, 0.019392135109228548, 0.05520942322618794, 0.06364253262290731, 0.026914955851680133, 0.07698597677517682, 0.0664950514328666, 0.032330743269994855, 0.04529773672402371, 0.08064440116868354, 0.0033093429419750464, 0.023852227423049044, 0.048792877496453, 0.21720967430155724, 0.08621113956905901, 0.1882862052298151, 0.08418897268711589, 0.16867144993739203, 0.13946939347079024, 0.16897651716135442, 0.26237844431307167, 0.235248924291227, 0.16258330084383488, 0.3316745243500918, 0.26395028340630233, 0.19918957172194496, 0.10600566529319622, 0.2666045300429687, 0.3913555172039196, 64.25583645701408, 111.1563777923584, 95.3607925772667, 85.98351895809174, 76.23245179653168, 44.366685301065445, 52.674061730504036, 75.99901512265205, 49.6418472379446, 6.985742272809148, 0.3575606649974361, 3.7484135990962386, 7.017853399738669, 5.72309092618525, 6.587702706456184, 5.876659685745835, 0.974505030317232, 61.81880682706833, 111.89749762415886, 101.81586340069771, 95.22954002022743, 82.52769559621811, 78.2143646478653, 89.02918472886086, 99.10853147506714, 104.06844332814217, 96.64557203650475, 102.01632544398308, 95.66522464156151, 88.76241624355316, 81.41478851437569, 73.71543645858765, 69.00938138365746, 68.12263056635857, 63.92322510480881, 68.0697450041771, 65.97709089517593, 67.36629635095596, 68.69085967540741, 67.80163899064064, 63.582497388124466, 67.72956445813179, 65.95426172018051, 61.871711388230324, 62.40067720413208, 63.790711015462875, 65.98799630999565, 61.472991183400154, 63.64661514759064, 70.97831413149834, 64.14350688457489, 59.65704582631588, 60.38153015077114, 67.44605407118797, 65.19253179430962, 67.93818086385727, 74.20149877667427, 71.0762956738472, 71.23106896877289, 65.60912624001503, 65.54880067706108, 76.38978615403175, 80.19484877586365, 77.70390763878822, 72.31723308563232, 68.17156434059143, 70.88940650224686, 75.17324343323708, 74.2764687538147, 75.10049253702164, 78.00576344132423, 63.90743315219879, 55.956469997763634, 77.85096734762192, 72.00388669967651, 73.46848770976067, 71.82658821344376, 74.43938121199608, 68.16452711820602, 64.32833656668663, 60.355927124619484, 60.378026738762856, 60.217112973332405, 62.074069529771805, 62.113139033317566, 65.92033714056015, 66.86303615570068, 72.41320833563805, 64.09897327423096, 58.91074687242508, 67.11652055382729, 71.34785190224648, 72.25440725684166, 77.96198979020119, 64.9350044131279, 61.02848343551159, 56.585359051823616, 55.38638658821583, 54.7646639496088, 61.57302841544151, 59.65618707239628, 57.717052325606346, 59.44027125835419, 60.11063128709793, 60.04777505993843, 60.98439820110798, 60.55612698197365, 61.456621661782265, 59.74729858338833, 60.03460876643658, 59.87197369337082, 59.743745774030685, 59.657710790634155, 62.75232933461666, 58.176664263010025, 62.23591424524784, 60.729325488209724, 67.00821116566658, 62.48038552701473, 70.59119090437889, 76.29186540842056, 85.55763781070709, 79.3530723452568, 92.14282125234604, 4.8109090235084295, 3.20757650770247, 30.743158534169197, 10.036062318831682, 5.196465784683824, 1.0220165527425706, 0.21708790271077305, 0.6697064638137817, 37.612593322992325, 37.4779437482357, 84.2032764852047, 61.30960375070572, 18.17448366433382, 43.285027742385864, 62.68250808119774, 78.95321980118752, 85.04556968808174, 89.48145166039467, 8.934252541512251, 0.34253772580996156, 0.08528188162017614, 0.19333337346324697, 0.17201323702465743, 0.07149619166739285, 0.13538348459405825, 0.09413792242412455, 0.24971161619760096, 0.13335611525690183, 0.20664551382651553, 0.12626143579836935, 0.14197534415870905, 0.14864886965369806, 0.2730924740899354, 0.15675944538088515, 0.13321160426130518, 0.11700321774696931], [0.03538277363986708, 0.030486003488476854, 0.047833577409619465, 0.11498905863845721, 0.039340431976597756, 0.017000692241708748, 0.06287040960160084, 0.009203588560922071, 0.04948856672854163, 0.00552683683054056, 0.07152087549911812, 0.06044543464668095, 0.0474543176824227, 0.012252795986569254, 0.13404540717601776, 1.2258740700781345, 67.51747503876686, 75.66869884729385, 65.2869339287281, 59.73356992006302, 46.746429204940796, 32.87030719220638, 72.6638200879097, 36.09028100967407, 22.535272166132927, 0.046989948459668085, 0.1594579388620332, 0.7213254470843822, 1.9484622962772846, 0.72543831076473, 2.4818838480859995, 1.30537292920053, 7.8938028216362, 105.7185047864914, 91.91576823592186, 93.56582969427109, 78.2478104531765, 71.14406123757362, 67.47015237808228, 68.09382051229477, 73.27880948781967, 83.64459246397018, 85.12020528316498, 86.44238233566284, 81.61407262086868, 76.28510937094688, 65.00608339905739, 61.390231624245644, 59.59231249988079, 59.00821544229984, 59.88520838320255, 58.98980163037777, 60.26989974081516, 59.6265372633934, 59.567560628056526, 62.485439255833626, 59.98247176408768, 59.188055992126465, 55.17890252172947, 53.51381666958332, 53.819647058844566, 54.57216627895832, 57.407760322093964, 56.69032461941242, 62.05371782183647, 61.29781298339367, 58.85980300605297, 60.02858988940716, 61.51749059557915, 62.06927038729191, 53.28245848417282, 66.27979025244713, 69.43720042705536, 69.14042115211487, 67.33265295624733, 62.251516208052635, 59.48599420487881, 61.04452237486839, 70.65778613090515, 70.26183977723122, 67.88281783461571, 62.30483114719391, 66.29561260342598, 66.40456035733223, 71.49886339902878, 66.13955497741699, 71.04005321860313, 60.45041665434837, 48.14608410000801, 73.4565107524395, 61.080111265182495, 65.88429227471352, 61.98144569993019, 61.76911689341068, 55.55753320455551, 52.68644906580448, 48.50432127714157, 52.719081714749336, 49.699140563607216, 51.74872398376465, 54.455546736717224, 60.87383173406124, 59.79744449257851, 61.57169848680496, 53.72926130890846, 53.16783383488655, 57.711409628391266, 67.64929756522179, 65.140550583601, 71.58238291740417, 67.87642657756805, 53.48748028278351, 51.00970923900604, 51.41928166151047, 49.65885512530804, 48.6973737180233, 50.98642788827419, 53.27768214046955, 53.41687627136707, 52.485759034752846, 54.87911380827427, 54.310189336538315, 53.87651480734348, 52.88431964814663, 52.61853531002998, 54.05042387545109, 50.60087017714977, 53.680110946297646, 52.907855585217476, 56.251638159155846, 59.58912447094917, 62.333116829395294, 62.91907958686352, 65.2672053873539, 61.85469590127468, 61.67732521891594, 60.20042806863785, 69.42641660571098, 70.02925425767899, 80.68501487374306, 57.19928830862045, 0.19868848845362663, 3.18582481238991, 12.67839778214693, 1.388262512627989, 0.4545672034146264, 0.052977399245719425, 0.3057650208938867, 7.464434886351228, 28.956376612186432, 26.237039230763912, 74.64762523770332, 70.93740552663803, 25.896562300622463, 35.63047908246517, 53.74109007418156, 61.986689418554306, 73.01289975643158, 46.35196477174759, 4.270672062411904, 0.08588746670284308, 0.0914997878135182, 0.02357255834795069, 0.06023593377904035, 0.054818237185827456, 0.03361489994858857, 0.014259925101214321, 0.0816017494071275, 0.10828774713445455, 0.023994035145733505, 0.051456144938129, 0.0849040542379953, 0.041976228822022676, 0.042304387970943935, 0.017723503260640427, 0.12159575373516418, 0.04306135633669328, 0.02198826230596751, 0.06612260462134145, 0.022097244836913887, 0.015194641546258936, 0.017348631481581833, 0.06616006823605858, 0.0036837810284851003, 0.028267180459806696, 0.007285511137524736, 0.06425438885344192, 0.03285071419668384, 0.0471990040387027, 0.18803329614456743, 0.06260291731450707, 4.1065384447574615, 85.70537388324738, 83.41877818107605, 76.17898106575012, 69.45494547486305, 66.69674187898636, 32.94067941606045, 44.87761728465557, 43.43059033155441, 26.390368603169918, 0.14291960833361372, 0.1915612880839035, 3.6320227570831776, 4.658086923882365, 2.9093794338405132, 3.0298593314364552, 1.566551320720464, 11.303097680211067, 110.19293189048767, 94.01387885212898, 96.92399829626083, 81.00155308842659, 74.94179785251617, 70.72327941656113, 70.45651093125343, 75.30572712421417, 85.47136723995209, 88.11627611517906, 88.00147667527199, 84.18017372488976, 79.26038771867752, 68.71440321207047, 63.57385665178299, 63.07261414825916, 62.32843168079853, 61.54083654284477, 63.53417158126831, 62.787029072642326, 62.86470450460911, 62.03738629817963, 65.91268435120583, 62.06665612757206, 62.23877169191837, 58.09311434626579, 56.83996059000492, 58.418604880571365, 59.17361296713352, 60.84175385534763, 59.99505288898945, 63.463404178619385, 61.36571153998375, 60.66005900502205, 61.059641763567924, 62.92014732956886, 64.69151347875595, 55.956462398171425, 70.10794803500175, 71.67396560311317, 71.98506250977516, 69.37434419989586, 64.06441032886505, 62.924984470009804, 62.277609407901764, 72.07618921995163, 73.4240984916687, 73.33013713359833, 67.10122257471085, 69.34953913092613, 70.03368481993675, 72.81946733593941, 67.91580766439438, 76.05465173721313, 62.72957235574722, 51.25221602618694, 76.67059868574142, 64.55196216702461, 69.01061251759529, 65.99271565675735, 64.37236860394478, 59.26540084183216, 55.297672748565674, 53.873566165566444, 55.37430323660374, 52.051484137773514, 55.489243268966675, 57.38216869533062, 63.380808010697365, 62.399301677942276, 64.86226871609688, 56.59748040139675, 54.424084424972534, 59.596226289868355, 69.19005408883095, 68.22653979063034, 71.55397564172745, 72.07251861691475, 56.74366995692253, 55.339170321822166, 54.49066065251827, 52.4557064473629, 52.23571725189686, 53.946575447916985, 55.68798400461674, 55.210858806967735, 55.84182254970074, 57.343824952840805, 55.499297529459, 55.659341141581535, 56.16634413599968, 56.695910319685936, 56.481658816337585, 53.28447237610817, 56.213495805859566, 57.435681223869324, 60.82930952310562, 64.14346128702164, 63.602142333984375, 67.18943104147911, 69.20401453971863, 65.39971187710762, 64.21815007925034, 64.0774816274643, 69.00533080101013, 76.59848615527153, 79.31309089064598, 72.3317863047123, 0.42439239914529026, 0.8601889363490045, 2.1212226385250688, 5.186622887849808, 4.405600447207689, 0.44648094044532627, 0.4020321724237874, 7.144360961392522, 42.7807492017746, 31.818897910416126, 67.71805867552757, 51.50628939270973, 33.67642253637314, 47.20530778169632, 60.99827505648136, 67.5193977355957, 80.23696571588516, 63.094037398695946, 9.752129204571247, 0.12289702062844299, 0.023998003780434374, 0.09488844152656384, 0.013261309741210425, 0.04212991647364106, 0.02329388375073904, 0.018358982051722705, 0.008614476373622892, 0.11491822064272128, 0.021635768134729005, 0.03329937957460061, 0.028527900649351068, 0.0508742306556087, 0.02726729046116816, 0.004776995865540812, 0.07719503235421143, 0.11923677797312848, 0.09159434484899975, 0.11933472662349232, 0.2090430515818298, 0.11577606172068045, 0.1567044819239527, 0.19492443418130279, 0.1462857230217196, 0.1292467545135878, 0.11346251281793229, 0.1795026648323983, 0.15413340035593137, 0.06873863807413727, 0.24101256189169362, 0.27986605593468994, 4.724448462948203, 100.81353038549423, 98.79371076822281, 85.78293532133102, 80.52712574601173, 63.66294287145138, 43.778153881430626, 102.7274876832962, 55.28243936598301, 39.97652627527714, 0.34530240402091295, 0.4174415330635384, 3.607146441936493, 10.937904976308346, 4.7837751545012, 9.377371463924646, 2.8301482228562236, 9.56127779558301, 116.39798372983932, 99.8694634437561, 102.6497058570385, 86.2810505926609, 79.64086890220642, 75.15682831406593, 75.94986096024513, 80.57114258408546, 90.49122467637062, 92.73795291781425, 92.54336535930634, 89.64350536465645, 83.50691825151443, 71.45449697971344, 66.2187047302723, 68.35720717906952, 66.0623051226139, 66.39556244015694, 66.75227209925652, 66.21935829520226, 65.8982527256012, 65.20611226558685, 68.67026478052139, 65.91979756951332, 65.92514768242836, 61.92930109798908, 60.27384392917156, 60.60786500573158, 61.23500235378742, 63.77877965569496, 62.61069193482399, 66.37642666697502, 63.54022465646267, 61.73755958676338, 62.53676310181618, 62.42216885089874, 68.89566868543625, 58.67642484605312, 73.89930099248886, 75.7205356657505, 74.71983656287193, 72.59291589260101, 69.53929334878922, 66.42372652888298, 65.07877349853516, 77.30906322598457, 78.78982096910477, 76.55784353613853, 70.38546994328499, 72.18475699424744, 73.25452119112015, 76.59201130270958, 73.3905690908432, 80.52265718579292, 66.80894985795021, 54.76143792271614, 79.75453600287437, 68.67011278867722, 73.92796665430069, 68.43761846423149, 69.9044081568718, 63.01548421382904, 59.61132287979126, 57.08737291395664, 59.971801936626434, 55.552441477775574, 58.18431705236435, 60.41341423988342, 66.4345483481884, 64.9405825138092, 69.4661320745945, 60.47483414411545, 57.88531109690666, 64.35488194227219, 72.29657739400864, 70.37281662225723, 73.54584395885468, 73.58897164463997, 56.9705405831337, 57.8068833053112, 57.936551347374916, 57.36749388277531, 56.5264318138361, 57.6440392434597, 58.505069240927696, 58.11607651412487, 58.97445045411587, 63.02407555282116, 59.222554340958595, 57.82116673886776, 59.27761718630791, 59.2470858246088, 61.32765658199787, 56.48641616106033, 60.970760732889175, 61.81944899260998, 65.14665305614471, 66.7930743098259, 66.4432118833065, 70.92996552586555, 70.53926289081573, 68.49056482315063, 67.41224348545074, 67.09652602672577, 76.23680636286736, 78.16030114889145, 87.95553714036942, 70.22587090730667, 0.24178338615456596, 8.699381444603205, 24.91731494665146, 5.161510035395622, 2.7072314685210586, 0.6102284335065633, 0.7038886577356607, 13.348686564713717, 52.54614159464836, 38.76911826431751, 97.38473877310753, 88.64270746707916, 38.44641678035259, 53.80450867116451, 73.85974511504173, 80.36683514714241, 94.82503652572632, 72.79346153140068, 6.772254528477788, 0.13008072070078924, 0.12828843406168744, 0.19198069057893008, 0.12669229705352336, 0.12608579912921414, 0.3073541074991226, 0.07335622896789573, 0.2319312421604991, 0.2740794117562473, 0.12634808896109462, 0.09762058398337103, 0.11661643264233135, 0.17742528958478943, 0.1638278379687108, 0.11849397720652632, 0.2521830570185557], [0.10465492683579214, 0.06525655539007857, 0.026747961492219474, 0.0794225514982827, 0.04702551959780976, 0.033559992152731866, 0.05287769541610032, 0.081222385779256, 0.023170043423306197, 0.14271008520154282, 0.09118312824284658, 0.09088173464988358, 0.06977488403208554, 0.2693529997486621, 0.42487580445595086, 23.10712818056345, 88.7900559604168, 71.31376013159752, 66.61295637488365, 44.141140803694725, 25.8524751663208, 46.81062676012516, 49.0945778042078, 33.249743431806564, 9.068111758679152, 0.4392982868012041, 0.7230199780315161, 1.136609259992838, 2.0601829513907433, 1.8109369883313775, 0.6786725576967001, 0.4740332323126495, 49.367957934737206, 104.88052815198898, 87.2881181538105, 86.1697469651699, 72.79888764023781, 70.22581771016121, 68.52842599153519, 62.73098208010197, 64.80334147810936, 62.29485288262367, 66.31622269749641, 64.82677862048149, 64.84245657920837, 59.95826706290245, 61.657178699970245, 58.937797620892525, 62.81797841191292, 58.519242480397224, 59.053881391882896, 56.45202800631523, 57.104019820690155, 57.187755927443504, 61.38977564871311, 59.6794456243515, 60.95018483698368, 56.24292902648449, 53.6839297413826, 54.216607958078384, 56.507246643304825, 55.81770904362202, 59.380261078476906, 58.8115493953228, 61.47333316504955, 59.63760606944561, 58.29978905618191, 59.72627431154251, 64.55751746892929, 57.00513392686844, 55.64210146665573, 65.65745204687119, 67.84796610474586, 68.03452089428902, 71.95332661271095, 63.76481920480728, 64.82074454426765, 54.56122666597366, 64.83492538332939, 65.68296387791634, 69.0594930946827, 63.011619821190834, 66.39635279774666, 63.485974967479706, 67.19487234950066, 63.40859591960907, 73.22066500782967, 59.59387041628361, 51.153235137462616, 70.2955287694931, 64.65685933828354, 64.15546104311943, 57.676713690161705, 56.371175944805145, 51.291080340743065, 54.40558321774006, 55.05866937339306, 57.68079087138176, 57.195507511496544, 55.9238563477993, 56.97024039924145, 55.061830803751945, 58.071447908878326, 55.67917987704277, 51.22944384813309, 48.704965710639954, 59.520671144127846, 63.68756555020809, 69.99679639935493, 63.588257879018784, 71.81595638394356, 62.126069739460945, 56.09816439449787, 50.43485328555107, 50.238673612475395, 48.48147690296173, 47.302795350551605, 52.5878481566906, 52.137716710567474, 53.17867085337639, 54.14568476378918, 54.04946252703667, 54.16685342788696, 52.20669820904732, 53.648185059428215, 52.891691252589226, 54.845983386039734, 54.1309529542923, 60.5296728014946, 61.33398324251175, 70.39340391755104, 63.241572082042694, 69.64137107133865, 69.07336995005608, 71.2948751449585, 65.63368812203407, 69.02120634913445, 58.78398187458515, 75.25313794612885, 67.12714478373528, 92.96678423881531, 24.824941903352737, 0.27331137796863914, 5.366982109844685, 14.310577400028706, 1.9653871818445623, 0.4968969617038965, 0.014738350600964623, 2.3110749386250973, 22.51235369592905, 21.56817276030779, 63.70825543999672, 85.4333844780922, 34.003117606043816, 22.26998560130596, 42.34545975923538, 55.9619265049696, 61.772867292165756, 64.32132974267006, 47.83135458827019, 3.8913673907518387, 0.16105569375213236, 0.012707720452453941, 0.04069639886438381, 0.03851837354886811, 0.05895919486647472, 0.03043377484573284, 0.023116074444260448, 0.07445387280313298, 0.03288383624749258, 0.07983554925885983, 0.06037850776920095, 0.05321656004525721, 0.03959213507187087, 0.006560152232850669, 0.011496191273181466, 0.07821306600817479, 0.046903603288228624, 0.048504185760975815, 0.0671247043646872, 0.001721043825000379, 0.0658531382214278, 0.06766201186110266, 0.050020007547573186, 0.038145288490341045, 0.03621578616730403, 0.03704491726239212, 0.06806767720263451, 0.07757566505461, 0.19696232717251405, 0.3222834470216185, 37.236356511712074, 102.93333783745766, 75.74768140912056, 80.7628270983696, 62.379132360219955, 49.80549305677414, 41.99671067297459, 49.535224959254265, 41.47896945476532, 9.457094985991716, 0.6224241165909916, 2.524814181961119, 3.868562914431095, 3.421939630061388, 3.267790926620364, 1.0094999056309462, 0.5900597688741982, 53.64258036017418, 106.69309169054031, 90.77253118157387, 91.70205250382423, 74.39666390419006, 75.17271146178246, 69.82188418507576, 67.1779328584671, 67.88930788636208, 64.87318933010101, 68.50302055478096, 68.30184414982796, 66.91187113523483, 62.90244787931442, 61.986928805708885, 62.62641929090023, 63.02228204905987, 61.42394341528416, 63.23199659585953, 61.097784116864204, 61.395634934306145, 60.544283017516136, 64.33412745594978, 61.95762857794762, 62.962287068367004, 58.83302204310894, 57.70227491855621, 59.53875817358494, 60.11786229908466, 60.103088691830635, 61.39606811106205, 61.08954235911369, 62.70870387554169, 59.89833667874336, 58.722637966275215, 61.00063093006611, 65.64465433359146, 59.01230402290821, 57.422176748514175, 68.72448787093163, 72.68617808818817, 72.38112285733223, 74.5549102127552, 68.43267112970352, 68.34515422582626, 55.92823751270771, 67.59361535310745, 68.89909610152245, 72.8530803322792, 66.3399638235569, 67.480548620224, 66.44448861479759, 68.68393644690514, 66.01677596569061, 74.95950490236282, 61.77990831434727, 52.29525625705719, 73.5476678609848, 68.36783140897751, 66.54213577508926, 61.93473860621452, 58.27938415110111, 54.116304740309715, 57.15295359492302, 60.508162155747414, 61.54791936278343, 62.3061116784811, 61.219047009944916, 59.03631113469601, 57.38374561071396, 59.23340655863285, 59.52882930636406, 53.09418238699436, 53.62402215600014, 60.935251638293266, 66.83326855301857, 72.22225338220596, 66.2319964170456, 72.2082169353962, 64.4421024620533, 57.63441056013107, 54.192426055669785, 52.45672859251499, 51.648109182715416, 49.929092824459076, 56.03534236550331, 54.8056485503912, 55.39857633411884, 55.33003181219101, 57.657935097813606, 56.43194608390331, 55.80231986939907, 56.75803318619728, 56.864123493433, 56.78455576300621, 59.06243473291397, 63.23636636137962, 64.48371782898903, 72.41065487265587, 68.48048776388168, 72.28545919060707, 74.20698568224907, 75.34113362431526, 70.32078221440315, 71.22502729296684, 64.81451287865639, 75.71589231491089, 71.41251683235168, 91.81919261813164, 39.539979100227356, 0.16882718220585957, 1.0831001750193536, 4.808807261288166, 6.092348461970687, 2.5394547963514924, 0.1721010182518512, 0.6638284167274833, 20.593661852180958, 32.10005812346935, 62.7502204477787, 77.74578899145126, 37.53334857523441, 32.295086458325386, 53.13843101263046, 66.05105772614479, 66.88482418656349, 73.83182421326637, 64.62165802717209, 8.538916055113077, 0.19240577792515978, 0.07049611056572758, 0.056278078773175366, 0.05330144318577368, 0.06064612993213814, 0.0668977852910757, 0.0403882146201795, 0.0887406237598043, 0.020255208328308072, 0.01638340349018108, 0.04610349758877419, 0.010329562956030713, 0.03919893038982991, 0.027467529325804207, 0.011875139298354043, 0.317910237936303, 0.19228592107538134, 0.13435129076242447, 0.2050551655702293, 0.1381247554672882, 0.19665267347590998, 0.1214089996938128, 0.18813363451045007, 0.10511354441405274, 0.22599232412176207, 0.2679659554269165, 0.264159242506139, 0.21125373139511794, 0.4340476216748357, 0.7737096142955124, 45.4278239607811, 119.49256047606468, 90.94879612326622, 86.84853494167328, 65.26247844099998, 37.83802382647991, 67.91241824626923, 74.47057753801346, 52.5346814095974, 16.33210502564907, 0.7647794997319579, 2.134319110773504, 5.351881720125675, 7.217292347922921, 6.486535985022783, 4.739241544157267, 1.8453617161139846, 53.601132184267044, 111.97520345449448, 97.20424085855484, 94.85953107476234, 80.00843837857246, 79.34434041380882, 76.93225264549255, 69.13051888346672, 74.601731300354, 68.30518037080765, 73.65049794316292, 71.54864072799683, 71.24879881739616, 65.54445371031761, 67.4459932744503, 64.91156727075577, 68.44811350107193, 64.43396329879761, 66.7365637421608, 63.361128866672516, 64.93644833564758, 63.49961243569851, 67.0780362188816, 65.58798417448997, 66.44292309880257, 62.598509788513184, 60.930748879909515, 63.08476969599724, 66.07735991477966, 60.681501254439354, 66.48836106061935, 61.77311807870865, 65.10800912976265, 61.13467253744602, 59.992845207452774, 60.89452542364597, 69.21764060854912, 62.51318916678429, 60.52861645817757, 73.34266886115074, 76.32384449243546, 75.73114469647408, 78.26652064919472, 71.94200322031975, 72.40250810980797, 59.89352993667126, 71.86944231390953, 72.83481851220131, 74.49183359742165, 67.62908264994621, 70.41453078389168, 70.03982529044151, 74.16958808898926, 68.75167161226273, 79.52910169959068, 64.9129655957222, 59.13237378001213, 75.96145793795586, 72.78161376714706, 71.45910993218422, 62.76066608726978, 61.930023059248924, 57.309961169958115, 60.54660089313984, 62.78569534420967, 64.28343817591667, 64.40978139638901, 63.021636083722115, 64.82116252183914, 59.7538798302412, 63.73311750590801, 63.44897635281086, 56.69955812394619, 54.388275146484375, 65.92991262674332, 66.52337998151779, 77.75278061628342, 68.3640468120575, 75.57773932814598, 67.01125860214233, 60.94423055648804, 55.48307999968529, 57.68411949276924, 53.97369459271431, 52.551685497164726, 58.08066241443157, 58.514971509575844, 59.452685192227364, 58.373155519366264, 59.598000794649124, 61.1018954962492, 57.95821778476238, 61.16417035460472, 59.2488831281662, 61.05057545006275, 60.75325660407543, 68.00839349627495, 68.94516482949257, 78.36267068982124, 72.2048807144165, 74.06118750572205, 76.27790495753288, 78.19810152053833, 72.97091200947762, 75.20317062735558, 66.54324531555176, 81.98867931962013, 73.90039533376694, 99.63823065161705, 36.225838735699654, 0.939310546964407, 14.719531405717134, 23.628382310271263, 5.379036962985992, 2.050133440643549, 0.15777483698911965, 3.80687084980309, 34.97588440775871, 39.842313677072525, 80.69861814379692, 106.1784017086029, 44.46039967238903, 34.08150739967823, 61.9651635736227, 76.93771675229073, 80.95504358410835, 88.09628918766975, 71.94647178053856, 6.46251224912703, 0.23931898089358583, 0.26262041414156556, 0.119967682112474, 0.11477560212370008, 0.22596201481064782, 0.1658854424022138, 0.14749925321666524, 0.19673640257678926, 0.1748038161895238, 0.1536214372026734, 0.16627245757263154, 0.12502714031143114, 0.1146325828449335, 0.14428596157813445, 0.1362614452955313], [0.06436120616854168, 0.041886840845108964, 0.021909765346208587, 0.014001946219650563, 0.04431527791894041, 0.036133392932242714, 0.04486431505938526, 0.09149719029664993, 0.04185408615740016, 0.03477314756310079, 0.12704778579063714, 0.023835345418774523, 0.06595953993382864, 0.0074002323253807845, 0.4365911101922393, 61.349801793694496, 78.1572537124157, 69.32170942425728, 58.5157086700201, 35.181981548666954, 22.982099689543247, 42.544458881020546, 38.248204216361046, 27.12804201990366, 0.374362175934948, 0.12053674610797316, 0.7997367333155125, 3.959132954478264, 0.27578623266890645, 1.1734115914441645, 1.1023210873827338, 0.4539113526698202, 79.85750287771225, 97.42275193333626, 86.61648139357567, 80.16327247023582, 75.56598275899887, 70.14473006129265, 67.1116416156292, 64.58545356988907, 63.29439304769039, 61.769170090556145, 59.960801526904106, 57.97764994204044, 59.30843733251095, 59.55393835902214, 60.8659927546978, 60.08975140750408, 60.229967683553696, 59.445929154753685, 58.5189612954855, 57.74797886610031, 59.035923555493355, 59.12637010216713, 57.99012087285519, 57.41401858627796, 60.30868045985699, 53.41346025466919, 52.10783131420612, 55.65729305148125, 56.53044059872627, 58.86151671409607, 58.286238983273506, 59.39142867922783, 60.03487475216389, 56.69958092272282, 57.58250154554844, 66.29809007048607, 60.084762275218964, 53.32942396402359, 58.52742724120617, 65.09474784135818, 71.0374465584755, 64.230035841465, 70.20798906683922, 67.52528741955757, 63.959649950265884, 57.814080119132996, 55.167818516492844, 60.51268391311169, 62.396736815571785, 62.06216096878052, 61.564634665846825, 58.819939345121384, 62.88955137133598, 62.4632902443409, 70.42396947741508, 59.30202707648277, 45.90852476656437, 72.6560229063034, 62.661521807312965, 61.72324575483799, 52.50017546117306, 53.42278115451336, 55.85224539041519, 61.18289954960346, 64.64690387248993, 65.76057091355324, 63.79369765520096, 60.3919567912817, 54.89268288016319, 55.69621816277504, 57.34727896749973, 53.250733986496925, 48.903945833444595, 51.45273506641388, 59.22327630221844, 65.59584215283394, 66.40541151165962, 65.68468138575554, 69.1368417441845, 70.5448865890503, 51.6057338565588, 54.984808936715126, 49.053916186094284, 52.06472262740135, 47.89478458464146, 49.85973134636879, 50.02441070973873, 52.41477124392986, 54.01282489299774, 55.15052564442158, 52.168666049838066, 53.769455552101135, 53.90205703675747, 53.634695783257484, 56.405176520347595, 62.82029248774052, 63.59839953482151, 68.78208518028259, 68.467036485672, 77.65093848109245, 70.68387553095818, 71.50064170360565, 74.35199350118637, 77.52682194113731, 69.33923408389091, 71.42969191074371, 67.09107711911201, 76.01728454232216, 71.62797287106514, 79.67363074421883, 4.482993744313717, 0.8134722243994474, 10.313719119876623, 6.179271647706628, 0.21425298764370382, 0.16549761086935177, 0.11672912776703015, 14.420323111116886, 23.65444701164961, 19.04795989394188, 46.54244855046272, 34.28699277341366, 25.931419730186462, 30.41748370975256, 38.85874405503273, 49.76032108068466, 61.63843430578709, 63.73311750590801, 39.09485198557377, 0.4097626794828102, 0.10616386149195023, 0.032300010934704915, 0.022401684946089517, 0.05952163148322143, 0.05578621297900099, 0.04606678354321048, 0.04656398908991832, 0.07261181774083525, 0.029023651586612687, 0.06557074360898696, 0.11037163843866438, 0.10330403994885273, 0.05563556442211848, 0.06624327041208744, 0.05789701084722765, 0.013911984005972045, 0.04045206158480141, 0.027658929211611394, 0.0499625282100169, 0.005418360351541196, 0.06738233350915834, 0.07318668533116579, 0.049289185044472106, 0.09026642743265256, 0.0420938109891722, 0.032785883886390366, 0.01968024611414876, 0.026275513992004562, 1.8380352342501283, 78.89040157198906, 85.55700704455376, 78.98697718977928, 67.30119824409485, 48.568819016218185, 27.77664251625538, 27.719959057867527, 43.885532319545746, 33.12052756547928, 0.6943236209917814, 0.309556326828897, 5.87347355671227, 6.4398374408483505, 9.0568776614964, 4.416847368702292, 0.9559772245120257, 1.1644536908715963, 87.04471081495285, 101.77155017852783, 91.60508930683136, 85.7304373383522, 79.30990666151047, 74.09122869372368, 68.7833771109581, 69.94527116417885, 66.30852431058884, 64.77954715490341, 62.99268163740635, 62.00452946126461, 63.283643424510956, 63.39611358940601, 64.2921245098114, 63.160898610949516, 62.91104681789875, 63.21702539920807, 61.71180076897144, 61.58148296177387, 62.23565585911274, 60.481400191783905, 60.457955449819565, 60.94398356974125, 63.04919980466366, 57.571983709931374, 57.404340505599976, 60.31697541475296, 59.9523051828146, 60.503610000014305, 60.789875239133835, 62.40893416106701, 61.7473516613245, 58.90027463436127, 60.78998923301697, 66.20047330856323, 60.91921649873257, 55.09395807981491, 63.53756479918957, 69.13250997662544, 71.90085902810097, 69.36841651797295, 72.07982942461967, 74.07552793622017, 66.91988870501518, 62.25418746471405, 56.11081391572952, 64.0714779496193, 65.70551946759224, 64.71017047762871, 64.66414734721184, 60.751732885837555, 65.3744812309742, 66.35229796171188, 73.66544634103775, 62.72433623671532, 49.904386550188065, 76.81673124432564, 65.27097478508949, 64.86755043268204, 54.17589694261551, 56.11733816564083, 59.357013925909996, 65.01079514622688, 68.46756845712662, 69.88952815532684, 65.93885734677315, 62.73989260196686, 57.8036230802536, 57.0502071082592, 59.40140314400196, 58.036090806126595, 51.87520779669285, 54.34312216937542, 61.47875927388668, 69.9040661752224, 68.46829041838646, 68.40449184179306, 70.00541433691978, 72.93629586696625, 57.64090821146965, 57.21142865717411, 52.62355864048004, 54.79426056146622, 50.93117505311966, 53.4571997076273, 53.51312890648842, 55.48795133829117, 56.29566639661789, 58.50570000708103, 54.14250813424587, 56.24049335718155, 56.21321462094784, 56.095474138855934, 60.933594927191734, 67.46992439031601, 67.89510637521744, 71.35322481393814, 73.2437601685524, 80.74497565627098, 73.6461889743805, 74.46585059165955, 74.90042567253113, 79.84261527657509, 72.38274917006493, 74.72669899463654, 70.64287573099136, 77.96335011720657, 75.53180739283562, 84.47066053748131, 8.16466748714447, 1.0350201674737036, 4.483004193753004, 5.298420963808894, 6.283535677939653, 1.605067360214889, 0.05081760849861894, 6.441619545221329, 29.753298349678516, 25.921844244003296, 47.29160115122795, 31.782642155885696, 45.67810133099556, 48.40345188975334, 46.966125816106796, 57.21940442919731, 70.34105032682419, 73.70831564068794, 56.6697221249342, 1.7205682187341154, 0.0937780030653812, 0.05734981794375926, 0.06723044556565583, 0.07907875158707611, 0.045407845464069396, 0.05135739847901277, 0.05128557713760529, 0.07782162763760425, 0.034792476799339056, 0.02670649584615603, 0.07403935363981873, 0.09264222768251784, 0.046479725642711855, 0.018483926323824562, 0.15515091450652108, 0.19171013322193176, 0.07838732228265144, 0.0625734095228836, 0.2387565516983159, 0.12574941327329725, 0.14812368142884225, 0.1394058804726228, 0.14798892225371674, 0.15545596688752994, 0.16118861240101978, 0.13816112070344388, 0.1724206464132294, 0.18698554689763114, 1.8231916869990528, 91.28883987665176, 97.99866423010826, 90.61629876494408, 78.8133417069912, 50.06722681224346, 31.82030003517866, 58.37852843105793, 53.63697946071625, 47.084060087800026, 1.1612619808875024, 0.30629942659288645, 5.444580120965838, 11.14563887938857, 7.484249398112297, 8.280588816851377, 6.031868057325482, 0.5879968358203769, 92.5524240732193, 105.94653055071831, 95.35741835832596, 87.73229151964188, 84.19724240899086, 77.87860706448555, 74.04851898550987, 72.19370931386948, 71.19031235575676, 69.23848628997803, 66.95878341794014, 65.4910209774971, 64.57382619380951, 65.58790817856789, 66.18596568703651, 66.87429115176201, 66.54768347740173, 65.88583499193192, 65.61772137880325, 65.32891407608986, 65.16186743974686, 62.1797950565815, 63.5786671936512, 62.0419916510582, 65.89974984526634, 60.13991251587868, 58.92403095960617, 62.88839243352413, 63.71357515454292, 64.80736166238785, 63.62988464534283, 65.95308378338814, 63.07474583387375, 57.957997396588326, 60.380128026008606, 68.63493427634239, 64.35910731554031, 57.65788950026035, 65.93554392457008, 72.41253197193146, 76.91673427820206, 72.31331929564476, 75.06893143057823, 76.94267928600311, 69.64950263500214, 66.93521708250046, 60.46631120145321, 69.11691561341286, 70.78589245676994, 68.72994437813759, 68.31952840089798, 64.584541618824, 69.24616947770119, 69.39850330352783, 76.56669706106186, 66.12525254487991, 53.203380927443504, 80.25578990578651, 69.80119049549103, 67.17574417591095, 58.13797853887081, 58.971190229058266, 63.579837530851364, 67.983907610178, 72.33577609062195, 74.25164848566055, 71.21707051992416, 65.49063339829445, 60.835468992590904, 60.212697610259056, 62.1052810549736, 62.157205268740654, 56.669771522283554, 58.14838618040085, 65.69297254085541, 73.42491164803505, 71.43572598695755, 71.12044170498848, 72.5004668533802, 74.89917173981667, 57.459160163998604, 59.5393281430006, 56.51083745062351, 57.36301012337208, 55.5431167781353, 56.845082715153694, 56.67979918420315, 58.51742997765541, 59.13473725318909, 62.23112270236015, 58.726889938116074, 59.715087711811066, 60.20126022398472, 59.785205349326134, 63.05804952979088, 71.33751645684242, 71.7028896510601, 73.37894931435585, 75.61485573649406, 84.25599485635757, 76.74343317747116, 78.23105335235596, 79.90907371044159, 82.83528909087181, 75.47272816300392, 78.79823371767998, 73.45709592103958, 82.90850356221199, 78.7934459745884, 84.92701604962349, 7.016676887869835, 2.47738987673074, 20.71327943354845, 13.673001062124968, 3.8005399145185947, 1.3116986397653818, 0.2870696678292006, 19.627413600683212, 40.19048139452934, 33.242960795760155, 60.88412158191204, 45.13102948665619, 38.716631680727005, 45.764345303177834, 55.93432858586311, 71.8352897465229, 81.69140607118607, 88.95252764225006, 61.04128114879131, 1.5363316610455513, 0.2597709826659411, 0.1292554524843581, 0.16816621064208448, 0.28371519001666456, 0.16234441834967583, 0.14398908766452223, 0.11973596134339459, 0.1408854260807857, 0.14004478056449443, 0.11031313493731432, 0.2613950689556077, 0.19388039567274973, 0.16041188064264134, 0.12831029773224145], [0.048102168075274676, 0.03226895576517563, 0.0210784430601052, 0.07647946840734221, 0.08976967088528909, 0.026968650236085523, 0.09303667917265557, 0.055326370857073925, 0.19508669734932482, 0.041477939739706926, 0.14547942409990355, 0.2169286081334576, 0.33377892861608416, 0.4696794378105551, 22.065206989645958, 85.41348874568939, 76.47003024816513, 69.76731911301613, 51.59233197569847, 31.323132812976837, 62.32085108757019, 61.04938231408596, 43.21314699947834, 10.947828143835068, 0.027882373178726994, 0.3159140091156587, 4.90590107627213, 4.143813019618392, 6.007937416434288, 15.769154783338308, 3.21639820933342, 23.18529948592186, 100.11381313204765, 92.5740373134613, 86.6428291797638, 87.14284434914589, 78.3707794547081, 79.83744755387306, 72.86736756563187, 74.52863842248917, 64.31117668747902, 63.556521981954575, 59.4979103654623, 60.17571039497852, 58.48617285490036, 60.82866735756397, 60.02057611942291, 61.77437201142311, 61.10127612948418, 60.95910295844078, 56.29575379192829, 59.35933940112591, 56.503807827830315, 57.25713640451431, 56.3044211268425, 59.1121968626976, 55.48564866185188, 54.44113790988922, 55.197893902659416, 55.528647154569626, 56.63970373570919, 57.53881148993969, 56.509492322802544, 57.51919314265251, 60.40476210415363, 58.20776179432869, 60.55118724703789, 56.574313044548035, 54.630360156297684, 63.12511593103409, 67.35599890351295, 68.74371483922005, 70.10253712534904, 65.39775118231773, 67.90189281105995, 72.12153598666191, 66.10461205244064, 64.24638256430626, 55.41779190301895, 53.42129923403263, 60.260468646883965, 58.61330263316631, 61.94640018045902, 61.85742035508156, 58.20640906691551, 61.98058694601059, 71.37578040361404, 58.13032194972038, 48.96984189748764, 73.09816718101501, 59.69709187746048, 60.566663816571236, 51.70163311064243, 62.15017944574356, 60.765393152832985, 65.18053203821182, 64.61593553423882, 66.60724148154259, 63.95903438329697, 64.56333875656128, 51.953187212347984, 53.84756036102772, 51.81879222393036, 49.97223950922489, 48.458936512470245, 54.30010087788105, 64.4480149447918, 66.72448799014091, 66.05893850326538, 64.03197526931763, 61.27037085592747, 72.5561186671257, 59.39023174345493, 52.481548860669136, 54.11905199289322, 50.32204873859882, 50.57862237095833, 46.7702691257, 51.751619428396225, 55.23159809410572, 52.83932626247406, 53.62298101186752, 54.33792024850845, 52.3906197398901, 51.831985116004944, 56.95683091878891, 65.31328931450844, 67.27701634168625, 71.10401898622513, 74.13402959704399, 72.15486019849777, 68.81940677762032, 70.3305932879448, 70.19947752356529, 71.56222119927406, 72.93165251612663, 73.20960000157356, 72.81187534332275, 72.49760180711746, 75.6968629360199, 73.31835016608238, 82.55114793777466, 37.267047464847565, 0.30091360153164715, 0.4015226138290018, 12.122912239283323, 3.242725096642971, 1.038889428600669, 0.10504502191906795, 0.24826343375025317, 37.562033236026764, 27.473027408123016, 37.30390548706055, 47.41500712931156, 12.547564152628183, 15.854033678770065, 18.686274401843548, 32.22654953598976, 51.573838368058205, 58.352009654045105, 68.82841229438782, 14.277564771473408, 0.8030299691017717, 0.08296952015371062, 0.031436689096153714, 0.0635695869277697, 0.13006081630010158, 0.04066755900566932, 0.08327747433213517, 0.03372957660758402, 0.07463593647116795, 0.04453251567611005, 0.06152924113848712, 0.026092099615198094, 0.048881864713621326, 0.03399503912078217, 0.007697536220803158, 0.04407743072079029, 0.17318440543022007, 0.12015350846922956, 0.09138522989815101, 0.05167344948858954, 0.07324545600567944, 0.0929882688797079, 0.1406928536016494, 0.10380596184404567, 0.1858395224553533, 0.1360753146582283, 0.4150074964854866, 0.5980397562962025, 33.14538583159447, 98.47764372825623, 83.53418558835983, 79.39301580190659, 71.7238113284111, 43.74043330550194, 25.605934895575047, 48.08538615703583, 49.79718670248985, 15.486352108418941, 0.23615116806467995, 1.6225677961483598, 7.906294651329517, 4.270842578262091, 16.352720819413662, 14.563423432409763, 2.884032418951392, 27.01030533760786, 101.29656806588173, 99.2962110042572, 88.7398910522461, 90.86677372455597, 81.56127825379372, 82.42758616805077, 77.12273642420769, 77.33842045068741, 68.22953402996063, 68.03542524576187, 62.43543393909931, 62.83301040530205, 62.19736531376839, 64.28103670477867, 62.14028477668762, 63.84413614869118, 63.29945057630539, 64.13418218493462, 58.469636142253876, 61.6016560792923, 60.501964688301086, 60.131112188100815, 60.95574013888836, 61.84697851538658, 57.93848164379597, 57.71214298903942, 57.91757516562939, 59.137590900063515, 60.143495723605156, 60.06932370364666, 59.020617976784706, 57.44213707745075, 60.58488003909588, 60.23779906332493, 62.09771566092968, 58.157954066991806, 56.724948361516, 67.02968001365662, 69.94923815131187, 72.89551645517349, 74.72451791167259, 67.9575066268444, 69.28197875618935, 74.25131410360336, 70.53549349308014, 66.64274677634239, 57.64214314520359, 57.16576270759106, 62.024763375520706, 63.59685301780701, 65.1540170609951, 65.04369378089905, 61.8229866027832, 64.29009541869164, 75.79849988222122, 60.308995842933655, 51.47739574313164, 76.61727994680405, 62.98469826579094, 62.32120826840401, 54.91166666150093, 66.57497361302376, 67.70909115672112, 67.63675063848495, 67.95702025294304, 71.14612072706223, 67.08698093891144, 66.97366341948509, 55.398363545536995, 55.34927397966385, 53.396315574645996, 53.80988158285618, 51.09998479485512, 57.39925637841225, 68.70330020785332, 67.48879417777061, 67.7063401043415, 67.83124700188637, 61.373364329338074, 74.25113171339035, 64.20952454209328, 54.46896381676197, 56.433165818452835, 53.37108112871647, 52.29525625705719, 49.48908023536205, 54.413194209337234, 56.9277548789978, 55.71269407868385, 55.49932412803173, 55.950785502791405, 55.18772564828396, 54.12026412785053, 60.4585862159729, 67.91510850191116, 70.64545959234238, 74.75991681218147, 76.78732842206955, 74.16442036628723, 69.85328570008278, 72.2452649474144, 73.33605721592903, 73.23194280266762, 74.67293187975883, 75.88996857404709, 76.16242155432701, 74.79645565152168, 78.04771319031715, 77.3735761642456, 81.59345492720604, 45.74340462684631, 0.5505280557554215, 0.5850527656730264, 2.2000190103426576, 5.473008770495653, 3.5364215495064855, 0.3684018988860771, 0.3980043885530904, 36.113771349191666, 37.27264076471329, 39.69561494886875, 41.222103238105774, 16.157910972833633, 24.78307195007801, 33.86772707104683, 44.05308052897453, 63.74134786427021, 64.72327217459679, 80.93874245882034, 27.7434740960598, 0.5945185327436775, 0.07461280372808687, 0.050179302124888636, 0.0560778436192777, 0.028671632389887236, 0.052015924666193314, 0.07763071756926365, 0.04175646034127567, 0.10001295639085583, 0.06661622930550948, 0.06318255691439845, 0.022853793889225926, 0.0721239298582077, 0.047305921543738805, 0.12415479024639353, 0.17447158636059612, 0.1752547302749008, 0.29365302238147706, 0.24060429161181673, 0.13035923388088122, 0.23188335879240185, 0.23412655951688066, 0.3870495466981083, 0.24503759981598705, 0.28767341980710626, 0.42603690933901817, 0.5344312882516533, 1.2435093987733126, 37.22353979945183, 113.87551948428154, 95.16359835863113, 87.92614191770554, 74.06905308365822, 46.324237659573555, 86.36944904923439, 85.73748975992203, 65.16956582665443, 21.34449776262045, 0.21195571403950453, 1.8656574958004057, 14.711643029004335, 9.345532972365618, 9.944212697446346, 22.810620591044426, 5.898492839187384, 32.44814984500408, 102.37077802419662, 103.78894552588463, 92.28107303380966, 97.66389459371567, 86.4189375936985, 87.33911141753197, 81.38073474168777, 82.88040027022362, 70.2001690864563, 71.16280183196068, 65.21462380886078, 67.21701756119728, 65.20455434918404, 68.36073338985443, 65.02410963177681, 68.00125747919083, 65.86581766605377, 68.59692871570587, 61.58686347305775, 67.3481485247612, 62.4750392138958, 63.12331102788448, 61.667073369026184, 65.26535868644714, 60.231271013617516, 60.50610266625881, 61.08619473874569, 64.28497329354286, 62.658983543515205, 64.18451428413391, 62.55430296063423, 60.53193747997284, 64.23387363553047, 62.469943687319756, 63.391690626740456, 63.73980514705181, 59.01619501411915, 70.24031013250351, 72.02862337231636, 74.45727825164795, 75.20075395703316, 72.10922464728355, 73.65821152925491, 78.16759675741196, 73.58667656779289, 70.66962629556656, 59.95655715465546, 59.99203585088253, 65.60072869062424, 68.65145578980446, 68.26034277677536, 69.65295284986496, 64.0587866306305, 68.92879530787468, 79.83199864625931, 65.1808512210846, 55.477289110422134, 81.18107825517654, 65.68075999617577, 65.53641334176064, 56.460486352443695, 67.07498878240585, 68.70150670409203, 70.00879615545273, 71.28696396946907, 72.49975249171257, 70.38793981075287, 70.20261615514755, 57.16182231903076, 58.49901616573334, 57.62072369456291, 55.95501087605953, 53.55078108608723, 60.58344751596451, 73.354212641716, 71.7660042643547, 71.56441748142242, 73.8380254805088, 65.24648129940033, 76.13133922219276, 64.33500900864601, 57.418635338544846, 58.46164137125015, 56.316610872745514, 54.87321272492409, 53.105410784482956, 56.75989508628845, 60.309759601950645, 58.61684404313564, 58.00551004707813, 59.753632843494415, 57.48947113752365, 57.87030190229416, 62.4615803360939, 72.90345042943954, 75.36480635404587, 76.79549038410187, 81.05967476963997, 78.48154351115227, 75.1594577729702, 75.3059247136116, 76.75403460860252, 77.29091539978981, 78.99406000971794, 79.63212937116623, 78.11659589409828, 79.43558111786842, 82.10491508245468, 80.05795732140541, 86.50127157568932, 46.358306631445885, 0.6407077854964882, 5.563285276293755, 23.307447731494904, 7.279891613870859, 3.0860877642408013, 0.46083003922831267, 0.938647601287812, 49.05372619628906, 45.872008726000786, 59.51011911034584, 63.33201102912426, 18.343433998525143, 22.898259088397026, 32.77433954179287, 54.75855767726898, 74.45245251059532, 76.81891992688179, 94.10013422369957, 31.40897400677204, 0.9132538607809693, 0.28392889886163175, 0.21016798418713734, 0.16945006675086915, 0.19167593505699188, 0.20742037537274882, 0.20732241187943146, 0.16919169545872137, 0.2506467222701758, 0.17981874552788213, 0.16159646707819775, 0.1617266546236351, 0.26424040377605706, 0.14893158338963985], [0.039048326361807995, 0.06460509815951809, 0.07135761043173261, 0.03930048958864063, 0.03095653810305521, 0.043699321322492324, 0.03823244260274805, 0.07732739439234138, 0.007712058659308241, 0.008738685919524869, 0.09129620928433724, 0.07024032194749452, 0.08752193563850597, 0.10321792855393142, 62.33452655375004, 78.10825914144516, 72.09525659680367, 59.12710726261139, 30.66998776048422, 41.82858869433403, 88.01159933209419, 42.01146148145199, 30.204778723418713, 1.4750371500849724, 0.04401712751132436, 0.5718406371306628, 5.073926160112023, 3.6031414568424225, 19.333784356713295, 0.6524981965776533, 2.1814201958477497, 56.73448584973812, 74.21048909425735, 101.82490691542625, 84.35353562235832, 88.54407995939255, 81.23179033398628, 82.28146120905876, 79.60518881678581, 79.55385357141495, 73.48079904913902, 77.0525997877121, 70.72033077478409, 63.18329840898514, 60.982912480831146, 61.21522821485996, 64.77175757288933, 64.01312828063965, 59.71397817134857, 64.06575545668602, 60.007732808589935, 59.876404255628586, 57.84422390162945, 59.778893887996674, 56.88363164663315, 59.56989750266075, 52.8479366004467, 52.72948555648327, 55.123528093099594, 55.623642057180405, 56.68639563024044, 54.904732033610344, 56.73073165118694, 59.53788422048092, 55.95366954803467, 60.69532871246338, 55.68140655755997, 55.37336088716984, 67.66049176454544, 71.23758181929588, 71.19743317365646, 68.92441794276237, 65.43428242206573, 62.49575950205326, 64.82015937566757, 64.65651735663414, 66.61098808050156, 63.130447044968605, 62.978922575712204, 55.33150613307953, 56.09632529318333, 57.67484799027443, 62.4323371052742, 61.044678166508675, 63.205428421497345, 58.559322729706764, 69.29284617304802, 49.91600252687931, 44.11881700158119, 70.86009487509727, 60.54813601076603, 55.73453910648823, 57.2427199780941, 65.96835896372795, 67.13105857372284, 64.5297409594059, 63.28655406832695, 65.19473567605019, 61.38938806951046, 54.49006788432598, 48.732875213027, 51.0931945592165, 48.9091819524765, 49.74334359169006, 50.402870401740074, 59.526758417487144, 64.901133030653, 61.984029561281204, 64.47888448834419, 63.52958902716637, 54.733023047447205, 68.65726187825203, 67.30095505714417, 52.70341895520687, 57.07653969526291, 51.38754956424236, 51.069901809096336, 49.032736122608185, 48.88052009046078, 52.63096824288368, 50.90777210891247, 51.238669753074646, 52.234805300831795, 54.15836848318577, 54.56430070102215, 62.31121100485325, 66.25722706317902, 72.74841874837875, 71.27376347780228, 66.80136546492577, 66.26162722706795, 68.43845441937447, 70.21777734160423, 70.76339766383171, 70.97779735922813, 71.15584820508957, 75.1646938920021, 71.01221591234207, 76.33512988686562, 69.88179937005043, 75.50450205802917, 70.83071485161781, 69.1312712430954, 8.45806684345007, 1.107253935188055, 3.945773346349597, 12.772583328187466, 2.331452532671392, 0.08653649711050093, 0.12969809904461727, 9.336748793721199, 49.39010314643383, 20.03424447029829, 40.720317363739014, 60.91365359723568, 27.886348329484463, 11.85889195650816, 16.766347624361515, 35.57833448052406, 54.20788362622261, 58.59193257987499, 48.34537200629711, 2.1178170712664723, 0.05451964148960542, 0.026623128542269114, 0.049462951501482166, 0.08683831372763962, 0.04444496822543442, 0.036641393016907386, 0.04442311197635718, 0.02122645699273562, 0.04612537239154335, 0.02990205386595335, 0.0455216463888064, 0.028534427838167176, 0.057875273341778666, 0.01900784918689169, 0.04982970604032744, 0.08079628169070929, 0.009035142375068972, 0.042831617101910524, 0.10050137861981057, 0.08564604606362991, 0.008190160860976903, 0.051238558371551335, 0.03501359227811918, 0.005686316017090576, 0.0433586050348822, 0.042670222246670164, 0.6742780341301113, 75.75180038809776, 85.30635729432106, 78.01710203289986, 69.14759516716003, 49.082471653819084, 42.403919622302055, 67.10192933678627, 47.38327503204346, 45.55968448519707, 2.59257594589144, 0.04468370600079652, 2.68669072072953, 5.425555966794491, 3.302947352640331, 5.4641723446547985, 0.7736215658951551, 3.8482047943398356, 69.23062831163406, 82.23365217447281, 104.11382049322128, 89.20318499207497, 93.08934286236763, 84.22032997012138, 86.39075830578804, 84.19715881347656, 82.94831782579422, 77.30419188737869, 82.23248183727264, 73.58767971396446, 67.06346780061722, 63.125207126140594, 65.29755055904388, 66.83592081069946, 68.0433440208435, 64.16074275970459, 67.91766956448555, 63.953159898519516, 61.27771966159344, 59.03938136994839, 61.05540119111538, 58.37038166821003, 61.940031722187996, 56.72634668648243, 57.474648132920265, 57.23295070230961, 59.27011638879776, 56.9569107145071, 58.693755716085434, 57.8209425508976, 58.18054385483265, 56.364993676543236, 62.23264642059803, 55.68118616938591, 57.929954901337624, 72.98989579081535, 73.65033075213432, 74.20890837907791, 72.83241704106331, 68.1290902197361, 66.04625478386879, 68.71805861592293, 68.17011281847954, 69.8503066599369, 66.53048560023308, 66.45879104733467, 59.158333986997604, 57.550659254193306, 62.57615938782692, 65.8136160671711, 64.2270340025425, 67.04774424433708, 62.29832969605923, 73.37446555495262, 55.3771036863327, 49.28000025451183, 73.85315626859665, 62.38682694733143, 59.43953029811382, 62.790243700146675, 70.2605402469635, 68.87930676341057, 66.73060566186905, 66.28455519676208, 68.83863374590874, 63.784904927015305, 56.940541192889214, 50.577471032738686, 52.12583474814892, 52.67509527504444, 53.513083308935165, 53.27241562306881, 61.58798061311245, 67.75596544146538, 66.89870864152908, 66.66465640068054, 65.98158225417137, 56.81389778852463, 69.23771873116493, 68.40879321098328, 54.800758212804794, 58.31451706588268, 55.161491855978966, 52.30638965964317, 52.8346449136734, 52.61291541159153, 56.13716170191765, 53.429730981588364, 53.682493418455124, 54.41471792757511, 56.89329832792282, 57.0375119894743, 66.64074808359146, 69.07981440424919, 75.44337093830109, 73.26234877109528, 68.88990819454193, 70.09362280368805, 70.5956518650055, 73.22834059596062, 73.42013150453568, 74.78979080915451, 72.61256083846092, 75.86233645677567, 74.60501432418823, 78.54423254728317, 72.16161623597145, 78.98320019245148, 71.38546228408813, 73.4475888311863, 12.912421524524689, 0.5798394454177469, 2.4918029783293605, 5.557955112308264, 6.347208386287093, 1.4170064264908433, 0.1933125636423938, 7.454721182584763, 57.01462961733341, 30.511376671493053, 39.137793481349945, 29.124335199594498, 18.977380581200123, 18.495600633323193, 30.521292239427567, 43.14538523554802, 65.21304309368134, 65.11110976338387, 66.50247350335121, 3.219573888927698, 0.04088889341801405, 0.028838190737587865, 0.06373837357386947, 0.057805177493719384, 0.006309344353212509, 0.1220140875375364, 0.07219131686724722, 0.022167956667544786, 0.08056474645854905, 0.07128202269086614, 0.03366741060744971, 0.01973687940335367, 0.024576151663495693, 0.0977283289830666, 0.22735155274858698, 0.23698314529610798, 0.13574529642937705, 0.0900813729094807, 0.25088150810915977, 0.21306224138243124, 0.1404758050921373, 0.15278919279808179, 0.11402473421185277, 0.1741133219911717, 0.1872575588640757, 0.1795720259542577, 0.8084272232372314, 86.29441067576408, 98.97071287035942, 90.92929556965828, 75.4652501642704, 46.87538668513298, 51.401228830218315, 111.72087550163269, 58.7633565813303, 52.25019447505474, 3.4194042161107063, 0.08233107277192175, 2.796874833293259, 13.945571836084127, 12.305323351174593, 32.802195847034454, 1.3878974947147071, 2.9937113961204886, 74.29875075817108, 89.04062211513519, 105.23507192730904, 91.46455004811287, 97.17365249991417, 89.63326871395111, 89.23504248261452, 87.67798483371735, 86.25464200973511, 80.71382492780685, 84.9018158018589, 77.4258841574192, 69.36898648738861, 66.07811227440834, 70.0813190639019, 69.79264095425606, 70.40706038475037, 65.06032168865204, 70.91510832309723, 67.11922600865364, 65.92650040984154, 62.89997801184654, 63.523216769099236, 60.610061287879944, 64.18556302785873, 60.880625769495964, 60.14175161719322, 61.25248521566391, 61.773912236094475, 59.40337523818016, 60.80930359661579, 60.341753885149956, 60.47576129436493, 59.06037524342537, 64.53904286026955, 59.14951466023922, 60.19662447273731, 74.47174027562141, 77.95071959495544, 76.21071696281433, 74.52839523553848, 70.26069223880768, 66.96709737181664, 70.44060498476028, 69.97680947184563, 72.0918519794941, 69.97649788856506, 68.51162329316139, 62.70904205739498, 62.450819313526154, 64.4694609940052, 69.31217193603516, 67.23514258861542, 70.12329921126366, 64.51885834336281, 75.60438349843025, 60.11075668036938, 58.800218403339386, 76.2784293293953, 66.74416333436966, 61.007075384259224, 65.7858319580555, 71.30664691329002, 74.50093790888786, 68.6930863559246, 69.74024936556816, 71.95326581597328, 68.96445259451866, 61.47139146924019, 53.73123720288277, 55.558806136250496, 54.55594874918461, 55.73072791099548, 56.23486965894699, 64.73904892802238, 70.76682507991791, 69.16843324899673, 70.35406842827797, 68.11745524406433, 58.68587113916874, 70.82870095968246, 72.46743142604828, 57.85157270729542, 60.00481456518173, 57.99799405038357, 56.2846127897501, 56.36548385024071, 55.99934309720993, 58.26122872531414, 57.24197141826153, 55.90554513037205, 56.901414692401886, 59.817226231098175, 59.005969762802124, 69.23536285758018, 71.00213885307312, 76.49998024106026, 75.46532616019249, 73.21938827633858, 73.72624307870865, 75.47169461846352, 78.49577754735947, 76.48228839039803, 79.1201600432396, 75.45052215456963, 78.38666260242462, 78.47841247916222, 83.08894827961922, 74.24796268343925, 81.72780051827431, 73.32112401723862, 74.19092014431953, 11.382088791579008, 3.531350721605122, 10.962803140282631, 22.930734045803547, 5.257276296615601, 0.9471377113368362, 0.27865012118127197, 13.326765540987253, 65.01951947808266, 34.820605739951134, 61.50296397507191, 81.19035735726357, 39.56849277019501, 20.244891867041588, 29.757827706635, 51.92451395094395, 78.76167967915535, 75.24736225605011, 78.85010093450546, 3.8581251120194793, 0.10063195208203979, 0.19190680235624313, 0.23352988762781024, 0.16853655717568472, 0.12404671870172024, 0.16933208011323586, 0.17877178295748308, 0.11476762403617613, 0.1994218342588283, 0.23825812531867996, 0.2011653914814815, 0.14924166753189638, 0.13713652646401897], [0.01821159337850986, 0.04773723550897557, 0.056877203460317105, 0.09850600326899439, 0.04426667466759682, 0.024846525338944048, 0.1469511177856475, 0.09247674359357916, 0.11765491988626309, 0.136138501111418, 0.13133367378031835, 0.1944642432499677, 0.4709026752971113, 11.441835835576057, 91.57766997814178, 63.997055143117905, 71.04144394397736, 30.574781969189644, 44.92674104869366, 58.54155868291855, 53.9862909168005, 36.780730560421944, 19.08324670046568, 0.5424779502209276, 0.03254560615459923, 2.1530746668577194, 4.764161081984639, 1.3650178536772728, 6.923268875107169, 0.3486470557982102, 47.41504892706871, 79.7202618420124, 70.13407543301582, 97.30783089995384, 88.28522264957428, 89.59989130496979, 83.11563044786453, 85.26881530880928, 82.18051582574844, 84.38457995653152, 79.67303037643433, 79.70900684595108, 78.00149247050285, 77.66628965735435, 67.24317535758018, 63.888966143131256, 62.93586328625679, 67.6674909889698, 68.8036148250103, 68.34121763706207, 67.37489148974419, 60.997591093182564, 58.90808701515198, 58.41982461512089, 56.83508925139904, 55.15095882117748, 49.82435144484043, 53.68692398071289, 58.958267122507095, 54.23705466091633, 56.35259874165058, 55.29313199222088, 58.146265894174576, 52.68292285501957, 56.26842185854912, 58.91901142895222, 57.8364647179842, 65.47153562307358, 72.99750298261642, 71.69098109006882, 69.4274577498436, 69.86406192183495, 68.15144822001457, 67.53552407026291, 69.6137997508049, 67.76682525873184, 66.61249279975891, 67.68478006124496, 63.21709379553795, 60.46419471502304, 59.29897204041481, 53.602830693125725, 62.6837582141161, 63.24781134724617, 61.16156369447708, 58.18030446767807, 72.0929691195488, 45.28855003416538, 40.20076364278793, 71.6665256023407, 58.90734985470772, 59.86657418310642, 59.2248760163784, 67.9124866425991, 54.188044890761375, 66.58229202032089, 62.827656492590904, 61.95765137672424, 51.93511538207531, 49.48916383087635, 48.903953433036804, 48.60629640519619, 46.93790853023529, 48.88652376830578, 56.69281728565693, 60.8668515086174, 64.46823745965958, 59.356987327337265, 63.68792653083801, 63.36180903017521, 52.69923537969589, 59.68695782124996, 72.15307429432869, 56.27859391272068, 53.124181777238846, 56.012140810489655, 51.14196874201298, 51.0369423776865, 44.14039984345436, 51.54369078576565, 51.458484157919884, 49.853245094418526, 52.29494467377663, 52.202168852090836, 53.46794933080673, 65.62743365764618, 69.81477096676826, 70.06833136081696, 63.694161996245384, 65.73501348495483, 68.79866749048233, 71.98598206043243, 69.26168024539948, 72.04607203602791, 72.67251402139664, 77.19694644212723, 73.69737982749939, 73.19415763020515, 71.21956318616867, 74.14854481816292, 71.90122380852699, 72.44818165898323, 72.0407523214817, 43.099058121442795, 0.6735930615104735, 0.5087368888780475, 8.35473708808422, 5.439367275685072, 0.5349896207917482, 0.3924984246259555, 0.4594399669440463, 42.140145376324654, 53.17175902426243, 25.830730833113194, 63.862717151641846, 81.87369748950005, 62.284718826413155, 17.50589434057474, 28.080914989113808, 44.290058612823486, 55.09076625108719, 61.6675179451704, 17.638245038688183, 0.8217174850869924, 0.04760060241096653, 0.16072566068032756, 0.03331376981805079, 0.0451077803154476, 0.08240059716627002, 0.014261070791690145, 0.09503788038273342, 0.08078639628365636, 0.03267763051553629, 0.07895130998804234, 0.02859404827177059, 0.03497409517876804, 0.05240686208708212, 0.01624049553356599, 0.05022992772865109, 0.10142415761947632, 0.0374622194794938, 0.02031473042734433, 0.025831787606875878, 0.1296445753541775, 0.05868392487172969, 0.18273234309162945, 0.09319584016338922, 0.2624646225012839, 0.5639776715543121, 16.64473135024309, 105.63571482896805, 75.25349512696266, 79.41083684563637, 39.09208573400974, 55.71303606033325, 52.32556343078613, 56.803657338023186, 42.390156760811806, 23.7857261672616, 0.1578532374696806, 0.3011476749088615, 3.559618117287755, 3.46339279320091, 2.525965995155275, 3.5109448665753007, 0.5415265762712806, 59.310835003852844, 91.58393204212189, 79.79602977633476, 93.03090959787369, 92.49614149332047, 93.76793324947357, 88.11641290783882, 87.80232936143875, 87.30501964688301, 87.89629071950912, 84.60840314626694, 83.20704594254494, 82.55370140075684, 82.43493497371674, 69.96197506785393, 67.09531009197235, 68.42839255928993, 70.62734976410866, 73.45439046621323, 71.62658214569092, 69.98135402798653, 60.903804525732994, 59.559250473976135, 60.24818770587444, 58.635094463825226, 58.956431820988655, 54.424384608864784, 56.62609666585922, 58.73072013258934, 56.25639170408249, 58.29402096569538, 56.328918412327766, 60.34662522375584, 54.128730073571205, 60.87330736219883, 59.992579221725464, 59.61997501552105, 70.72575688362122, 74.17247593402863, 73.41408982872963, 69.69272151589394, 71.37654796242714, 70.76846659183502, 70.83535060286522, 73.47573012113571, 70.70145338773727, 71.2093797326088, 72.40977331995964, 67.9413802921772, 63.13244193792343, 60.465133264660835, 58.17778520286083, 67.32520535588264, 66.31170853972435, 64.52126741409302, 62.47714430093765, 73.23977038264275, 60.976274237036705, 58.66337634623051, 70.67102462053299, 64.02436047792435, 60.26913598179817, 65.10172426700592, 68.4476651251316, 56.80168904364109, 69.41513881087303, 66.9018928706646, 66.4166209101677, 55.40495239198208, 52.2727120667696, 52.186441496014595, 50.1817412674427, 49.422709196805954, 51.5866968780756, 59.752329513430595, 66.28735184669495, 68.18280413746834, 61.61604590713978, 66.8305554986, 65.59258192777634, 55.888119265437126, 59.33711439371109, 72.49997287988663, 59.03542958199978, 56.50518715381622, 57.10683926939964, 52.36451134085655, 52.971790954470634, 49.15852077305317, 55.47104224562645, 54.39680188894272, 53.54405164718628, 54.44726698100567, 54.32420298457146, 57.182747796177864, 66.26041889190674, 73.03732484579086, 76.23283937573433, 67.63547390699387, 69.97402042150497, 71.76076054573059, 76.21312603354454, 73.37825015187263, 73.89738589525223, 75.24585753679276, 76.19058564305305, 75.94850063323975, 76.05257704854012, 73.71434971690178, 75.44742152094841, 73.78015458583832, 75.3684389591217, 77.04123839735985, 49.65371400117874, 2.238367502577603, 0.9053088433574885, 3.446192303672433, 5.092882392928004, 3.252583905123174, 0.7743958930950612, 0.35218315199017525, 44.7756003588438, 61.58668868243694, 31.75403919070959, 51.14760383963585, 70.0449626147747, 48.95745076239109, 28.14116645604372, 37.60549910366535, 51.10690802335739, 62.90588289499283, 74.67055320739746, 28.177348114550114, 0.7891869556624442, 0.11644453639746644, 0.12368871408398263, 0.03678970751934685, 0.07864360071835108, 0.0468635273136897, 0.05585436440014746, 0.03985385345004033, 0.011746973177650943, 0.06214487861143425, 0.03949557794840075, 0.026162837420997676, 0.04462169214093592, 0.11063101163017564, 0.09305681363912299, 0.14794629329117015, 0.2892913907999173, 0.1484728915966116, 0.13302312843734398, 0.3118263784563169, 0.14727678702911362, 0.2389932968071662, 0.2578819793416187, 0.22518464480526745, 0.3517565655056387, 0.7821302593220025, 18.83340060710907, 119.60333973169327, 85.18594175577164, 94.06136110424995, 44.648379385471344, 57.21346914768219, 66.99781492352486, 67.80334889888763, 55.7149625569582, 32.68953949213028, 0.8847635239362717, 0.3479834570316598, 8.61582012847066, 11.807586159557104, 9.639284759759903, 12.874863389879465, 0.9540369536262006, 56.56140893697739, 93.42444688081741, 79.07756432890892, 95.39287805557251, 93.51919859647751, 94.94419813156128, 90.43497249484062, 90.96388891339302, 89.98648256063461, 91.12864807248116, 85.72661474347115, 87.4512206017971, 84.83392864465714, 86.70815527439117, 72.68055438995361, 70.66170752048492, 70.87825030088425, 74.74127501249313, 76.30358397960663, 75.47294095158577, 74.06964585185051, 66.28526955842972, 64.65757369995117, 63.620252162218094, 61.67030319571495, 61.69733874499798, 56.276591420173645, 59.52208086848259, 64.48646888136864, 58.14061939716339, 62.26902186870575, 60.04335209727287, 60.09629085659981, 55.86954966187477, 61.77266590297222, 64.17383685708046, 63.968397080898285, 70.85089936852455, 79.64681938290596, 77.2796680033207, 72.88741528987885, 73.51052105426788, 72.77957707643509, 72.65956431627274, 77.03209608793259, 71.74200475215912, 71.30350828170776, 75.12166500091553, 69.02369901537895, 66.21574088931084, 62.545498833060265, 60.56350238621235, 70.83641454577446, 70.76802581548691, 67.11023569107056, 67.7755419909954, 76.65953367948532, 61.920667961239815, 57.78498128056526, 72.9042711853981, 69.01277080178261, 64.73429918289185, 67.57820338010788, 71.728355884552, 60.14049768447876, 70.46066790819168, 70.22364422678947, 70.49478247761726, 58.07865232229233, 54.651164039969444, 56.881724148988724, 54.25419554114342, 53.08163546025753, 53.93507346510887, 63.978086560964584, 68.4739825129509, 69.78603690862656, 63.2576984167099, 70.31291663646698, 69.27773058414459, 58.18246655166149, 62.445761784911156, 73.30324977636337, 60.32403163611889, 59.42403472959995, 59.37815599143505, 57.03837454319, 54.769501090049744, 53.0371056497097, 57.951799929142, 57.21375413239002, 56.90085992217064, 58.51300321519375, 57.209065183997154, 58.35493929684162, 69.55649122595787, 76.42650738358498, 77.5320352613926, 72.91409745812416, 70.81458851695061, 74.92163613438606, 79.53478619456291, 75.5747526884079, 78.62955316901207, 78.91313195228577, 81.01849257946014, 79.42273020744324, 79.55574586987495, 78.7016125023365, 80.38763523101807, 75.84525257349014, 78.61455917358398, 77.82077416777611, 49.77053113281727, 1.9588812184520066, 2.986838989891112, 17.17140018939972, 10.417492501437664, 2.868519276380539, 0.8944865490775555, 1.3339147414080799, 57.38757200539112, 68.84390026330948, 44.50948163866997, 87.02046051621437, 105.76932325959206, 79.36641722917557, 28.524303697049618, 41.965556144714355, 64.81145784258842, 73.72647106647491, 88.87403145432472, 32.05149672925472, 0.8870708313770592, 0.2592869836371392, 0.17644103849306703, 0.14158680016407743, 0.12795682763680816, 0.2309291498386301, 0.13264835870359093, 0.22611160209635273, 0.3438848425867036, 0.17984549253014848, 0.10791263601277024, 0.12091443248209544, 0.1489881201996468], [0.1518591184867546, 0.1664389212965034, 0.08665441695484333, 0.050245661259396, 0.048422237814520486, 0.07690729427849874, 0.06169947868329473, 0.0637902422749903, 0.013275106266519288, 0.15610599919455126, 0.07720048713963479, 0.056628776947036386, 0.021225501477601938, 42.205258682370186, 91.17024064064026, 66.94987669587135, 63.572788909077644, 41.90597154200077, 27.13529583066702, 49.8777461796999, 43.382553309202194, 41.33841119706631, 17.483825124800205, 0.0565036619809689, 0.21795128763187677, 4.528815960511565, 3.067723587155342, 0.6452380330301821, 0.5721071572043002, 30.381127260625362, 116.44365727901459, 90.68021893501282, 104.09278482198715, 85.23944288492203, 87.47738599777222, 89.47508320212364, 93.87297481298447, 82.03046187758446, 88.56867983937263, 78.36395502090454, 83.53940650820732, 80.82604810595512, 80.91896072030067, 71.36285349726677, 73.10309931635857, 67.27732792496681, 72.55521431565285, 71.4692097902298, 74.09309819340706, 68.66622179746628, 73.42485845088959, 65.80211788415909, 59.03001107275486, 53.97393397986889, 58.06289456784725, 54.391387179493904, 53.165804743766785, 49.71393696963787, 55.94138100743294, 55.61014138162136, 53.68532806634903, 53.81489731371403, 60.28913430869579, 52.98534482717514, 60.73995351791382, 55.69771908223629, 62.87522614002228, 69.72239792346954, 72.03138962388039, 62.70659878849983, 68.29385697841644, 69.319589138031, 69.82816144824028, 63.84076192975044, 67.9107615351677, 66.63038223981857, 65.96358641982079, 64.72848549485207, 70.31532570719719, 65.06075486540794, 62.155901938676834, 50.12637443840504, 63.13690669834614, 60.23876041173935, 66.96651980280876, 53.8948792219162, 72.51085549592972, 37.28316240012646, 40.1697801053524, 70.92449381947517, 55.817021280527115, 60.58268755674362, 61.93389505147934, 61.19265362620354, 47.82602347433567, 62.22898721694946, 61.1598651856184, 56.49442993104458, 46.26170061528683, 48.8578999042511, 47.00905591249466, 46.079998165369034, 49.672564789652824, 55.49768641591072, 61.14883057773113, 62.408569380640984, 61.343102753162384, 61.8463059514761, 63.83770689368248, 60.84219083189964, 58.543260991573334, 54.248404651880264, 58.36441598832607, 61.40948139131069, 50.948011949658394, 55.136990770697594, 50.72498291730881, 51.44471749663353, 45.14217048883438, 44.107748195528984, 51.70059956610203, 50.22440157830715, 52.84005582332611, 50.89384965598583, 57.25118972361088, 70.84443971514702, 69.3779008090496, 64.57799836993217, 68.01612228155136, 65.74985548853874, 69.85314890742302, 68.58029320836067, 66.44223913550377, 67.6962098479271, 71.3112522661686, 74.26136836409569, 73.95283252000809, 73.80605399608612, 73.04607957601547, 73.04548680782318, 73.22131097316742, 73.67962718009949, 77.88352400064468, 67.51654028892517, 10.702707096934319, 0.36356787546537817, 1.6181369964033365, 11.866045072674751, 1.8623411050066352, 0.6023664178792387, 0.04604700159688946, 14.43560779094696, 72.97829881310463, 31.052199751138687, 44.432577565312386, 106.56927153468132, 133.14020454883575, 56.52509048581123, 14.30476751178503, 36.90535247325897, 51.58410161733627, 66.77581563591957, 43.49697656929493, 2.4931780295446515, 0.15862743108300492, 0.1132290628447663, 0.03532194721628912, 0.08597308828029782, 0.05811159913719166, 0.023082649968273472, 0.07621131560881622, 0.03405714574910235, 0.010946544643957168, 0.06422353035304695, 0.04710714099928737, 0.05989245299133472, 0.07561148959212005, 0.09733083468745463, 0.027842599629366305, 0.07009912093053572, 0.05799682599899825, 0.05500409322849009, 0.12517684634076431, 0.09592050177161582, 0.03376509950612672, 0.13212274003308266, 0.06201806041644886, 0.15361238300101832, 0.05149187934875954, 52.84843057394028, 101.63873210549355, 74.20633971691132, 75.47864064574242, 52.56683528423309, 39.2987110465765, 49.023080840706825, 46.07886962592602, 48.35781253874302, 12.888327967375517, 0.2670957724330947, 0.3339933499228209, 6.802298566326499, 1.9223415479063988, 0.8932734641712159, 0.5279963929206133, 40.8032251149416, 118.25932905077934, 92.012959420681, 105.11519595980644, 86.53898075222969, 86.38005048036575, 94.20859560370445, 96.70725792646408, 87.78276801109314, 91.63820073008537, 83.8977500796318, 88.44555124640465, 82.92569383978844, 83.7621733546257, 76.24999925494194, 77.99276813864708, 72.78791382908821, 75.44238299131393, 77.63945549726486, 79.94546815752983, 72.9120759665966, 73.19577634334564, 66.14769414067268, 59.736594557762146, 56.45764410495758, 60.153253600001335, 58.36456798017025, 54.404481276869774, 54.233938828110695, 58.17152313888073, 58.06875765323639, 56.04803368449211, 55.177534595131874, 60.16965351998806, 54.85751196742058, 62.76152104139328, 55.54289638996124, 67.44356140494347, 71.30429103970528, 72.67045453190804, 63.75226467847824, 69.27488073706627, 72.47864842414856, 72.45948225259781, 69.00896340608597, 70.08450329303741, 68.5965259373188, 68.1462424993515, 70.32009825110435, 70.5526077747345, 68.23374420404434, 64.68343511223793, 57.24384851753712, 64.37279418110847, 63.271715864539146, 67.01494440436363, 60.884167179465294, 71.19732677936554, 64.7524394094944, 63.8282074034214, 68.18762227892876, 62.687075436115265, 61.96597293019295, 67.24012032151222, 61.777651235461235, 49.861201867461205, 65.37987694144249, 67.90071487426758, 58.90554115176201, 47.471168115735054, 50.700113251805305, 49.62857075035572, 49.61145266890526, 52.916541919112206, 58.283047154545784, 66.27798154950142, 67.31420114636421, 62.7164326608181, 61.419653445482254, 65.55355042219162, 63.90164226293564, 60.1900964230299, 56.14930585026741, 59.39785413444042, 65.02946734428406, 56.91279508173466, 58.57326418161392, 52.29340575635433, 54.02632936835289, 50.53537309169769, 47.53348857164383, 53.229253739118576, 53.53645205497742, 55.608891248703, 52.94768884778023, 60.94876371324062, 70.35352125763893, 73.03408741950989, 69.33513030409813, 69.86298277974129, 69.82750028371811, 72.39898189902306, 73.86479124426842, 72.58967086672783, 70.53706660866737, 71.24640494585037, 76.66894197463989, 76.53485476970673, 71.8554362654686, 73.50388661026955, 75.66870644688606, 72.8002479672432, 73.40410396456718, 79.11661863327026, 69.35042828321457, 16.966131404042244, 0.2594236872391775, 0.5617005249951035, 5.221858872100711, 4.119138568639755, 1.9958160677924752, 0.13859980419510975, 13.207090012729168, 79.31342527270317, 39.304631128907204, 48.567910864949226, 107.86098182201385, 123.09336125850677, 56.343186646699905, 24.940505102276802, 45.063814893364906, 61.09591081738472, 74.64183434844017, 55.91336131095886, 3.1713274028152227, 0.13023205945501104, 0.13629892375320196, 0.09373844659421593, 0.0523739552590996, 0.02282456811371958, 0.06278210887103342, 0.12784696009475738, 0.05845642321219202, 0.046442165548796766, 0.10868633980862796, 0.015831217788218055, 0.13996185298310593, 0.17496265063527972, 0.21460299933096394, 0.2142991343862377, 0.2775197708979249, 0.21725267433794215, 0.22102809831267223, 0.2535854489542544, 0.22542787628481165, 0.08311711848364212, 0.258265640004538, 0.22191972937434912, 0.20131662633502856, 0.2005060823285021, 61.12032450735569, 113.48897382616997, 85.54414853453636, 83.91477316617966, 61.03850729763508, 40.17703391611576, 71.95839554071426, 62.15890757739544, 61.86175972223282, 22.551588490605354, 0.4451965499902144, 0.2638019132427871, 13.63597109913826, 9.40946739166975, 6.784115117043257, 1.5673928568139672, 38.078072145581245, 122.46159955859184, 96.02878153324127, 111.18448868393898, 88.52389544248581, 89.2279140651226, 96.89363032579422, 99.82781007885933, 89.62372362613678, 93.99435549974442, 84.81433689594269, 90.75847193598747, 86.47171676158905, 88.2641413807869, 78.82931604981422, 80.84288120269775, 76.7186889052391, 79.27736520767212, 80.82828238606453, 82.05830678343773, 77.49514684081078, 77.61960536241531, 71.83784320950508, 64.66285541653633, 58.3231046050787, 63.00922594964504, 62.08586789667606, 60.47507353127003, 56.62563309073448, 62.809710055589676, 59.72533576190472, 59.718868508934975, 58.33790101110935, 63.18938188254833, 56.46294482052326, 65.6309674680233, 60.14326013624668, 70.83518341183662, 73.15210148692131, 77.5226041674614, 65.7138866186142, 71.61639109253883, 76.08777076005936, 76.9652196764946, 72.46040940284729, 73.48675712943077, 74.15048271417618, 71.87257334589958, 71.96309968829155, 74.01825740933418, 73.31993848085403, 69.08587127923965, 59.33696240186691, 68.88235419988632, 66.56687244772911, 73.05352717638016, 64.21141684055328, 74.09859269857407, 52.643439173698425, 47.901198640465736, 73.62683281302452, 66.055176705122, 64.72938984632492, 71.03580504655838, 63.35394725203514, 49.98479403555393, 69.21210810542107, 70.51988393068314, 63.64715851843357, 49.906848818063736, 53.229930102825165, 53.94930750131607, 50.955816730856895, 54.35154631733894, 61.89883433282375, 68.92597585916519, 69.10851806402206, 66.47603452205658, 63.056005239486694, 69.81533333659172, 66.91000923514366, 64.03797134757042, 58.9138513058424, 63.19769963622093, 64.4388422369957, 58.096803948283195, 61.56371891498566, 54.78766791522503, 58.54367516934872, 52.663015723228455, 50.42739048600197, 57.25493252277374, 56.031409576535225, 57.501060515642166, 56.27855211496353, 64.83541175723076, 74.01571154594421, 76.27240285277367, 70.60237750411034, 72.1061772108078, 71.83282747864723, 77.56508588790894, 76.57927438616753, 75.62399044632912, 72.77303382754326, 75.73305979371071, 79.20735776424408, 79.16554480791092, 76.706932336092, 77.41787418723106, 79.07430410385132, 78.34089025855064, 77.23502799868584, 83.16446542739868, 71.75411850214005, 15.952834077179432, 1.7217482929117978, 10.431588795036077, 23.008764758706093, 5.210897885262966, 1.973550806287676, 0.2933485637186095, 21.34875923395157, 89.64782193303108, 44.712462946772575, 57.36035406589508, 109.69535619020462, 138.15300196409225, 70.7001842558384, 24.51913621276617, 53.45652714371681, 72.74297744035721, 89.11800116300583, 65.52193611860275, 3.5830863704904914, 0.30325017927680165, 0.2452713466482237, 0.18097055872203782, 0.16953502781689167, 0.12472149421228096, 0.1326446034363471, 0.22962138173170388, 0.15051816153572872, 0.10106538858963177, 0.20655819273088127, 0.15015933313407004, 0.27304358140099794], [0.0439525829278864, 0.02616587280499516, 0.04794859545654617, 0.037029729210189544, 0.1002993066504132, 0.1306269265478477, 0.031009712984086946, 0.05480210660607554, 0.028869611414847896, 0.11100967021775432, 0.07503444008762017, 0.0732334480562713, 1.1255334480665624, 77.60719522833824, 79.10426169633865, 71.09552264213562, 57.94062852859497, 36.58960461616516, 30.41022039949894, 37.733666226267815, 38.46229612827301, 45.45550927519798, 3.012385256588459, 0.5180440144613385, 1.32012658752501, 1.8854788946919143, 0.6349728838540614, 1.4872223837301135, 14.167038202285767, 100.47009721398354, 91.91848888993263, 84.43802788853645, 86.4851376414299, 95.37406906485558, 87.93569460511208, 86.9432182610035, 84.75319817662239, 86.18025720119476, 87.03055277466774, 80.6938835978508, 82.10663259029388, 77.34645321965218, 76.50159135460854, 76.24514311552048, 78.08031544089317, 75.05601212382317, 74.06482011079788, 71.6333457827568, 74.45969492197037, 72.70820170640945, 76.78074717521667, 65.33095836639404, 59.356386959552765, 55.64558207988739, 55.42757257819176, 50.727194398641586, 50.344155952334404, 50.8662935346365, 55.961744114756584, 54.75842848420143, 52.36696220934391, 57.30723291635513, 56.802293211221695, 55.6515933573246, 50.367764085531235, 55.48526868224144, 66.10430046916008, 70.19354984164238, 66.34728983044624, 67.57991328835487, 74.34402912855148, 69.04421031475067, 66.29132643342018, 62.773984372615814, 67.02695176005363, 64.30974796414375, 67.18428611755371, 62.7588801831007, 67.89612472057343, 66.35434225201607, 67.11256116628647, 49.6487058699131, 61.15410089492798, 60.18384575843811, 67.006516456604, 55.48772715032101, 69.92529943585396, 26.864009387791157, 24.501837641000748, 65.84361925721169, 57.07289569079876, 68.33080619573593, 59.977934807538986, 63.3262999355793, 59.79626275599003, 70.14463126659393, 57.07722745835781, 52.80272662639618, 46.324769631028175, 48.78057025372982, 46.386219933629036, 51.20485536754131, 53.113591745495796, 61.92786857485771, 62.57301315665245, 61.45475976169109, 52.769246622920036, 58.93043361604214, 57.32406601309776, 66.32980316877365, 58.79278600215912, 58.660423904657364, 54.876108169555664, 59.29250478744507, 53.41788701713085, 50.72955407202244, 54.36117880046368, 49.12658728659153, 47.38370060920715, 43.61622557044029, 51.55343346297741, 50.31346119940281, 49.61128927767277, 51.17418721318245, 57.743582502007484, 70.17841145396233, 65.22565841674805, 61.01850897073746, 69.2719092965126, 64.42053481936455, 69.95873004198074, 65.6405657529831, 65.08020222187042, 67.7083919942379, 70.0778080523014, 66.57637193799019, 68.58917713165283, 69.14265543222427, 69.9560321867466, 71.95586487650871, 74.056855738163, 71.39858677983284, 72.23182126879692, 71.45707324147224, 40.46032011508942, 2.7406186144798994, 1.2867390853352845, 6.853317953646183, 4.180581271648407, 1.4629177004098892, 0.18532649060944095, 2.150842286646366, 59.02127534151077, 56.84444434940815, 44.08007428050041, 86.20799571275711, 92.58985206484795, 86.305832862854, 20.627265349030495, 32.28328809142113, 53.342084884643555, 57.04707607626915, 59.87793177366257, 10.465245489031076, 0.546053439611569, 0.12696270598098636, 0.020937755980412476, 0.02911096155003179, 0.08755939183174632, 0.037288163584889844, 0.18092361046001315, 0.17051363858627155, 0.050726765912259, 0.021417669486254454, 0.04050972645927686, 0.06218118447577581, 0.027638273386401124, 0.028665687786997296, 0.06945081782760099, 0.05060555093223229, 0.008004145256563788, 0.11517590173752978, 0.022265467450779397, 0.06545929529238492, 0.12964310590177774, 0.04488914732064586, 0.08253819876699708, 0.04403507264214568, 1.8206186313182116, 93.2248891890049, 87.31154769659042, 78.47575262188911, 70.4120609164238, 48.52340765297413, 35.91253414750099, 43.36101606488228, 45.4212237149477, 52.64052093029022, 2.8813884733244777, 0.5425638612359762, 2.927613230422139, 2.007659557275474, 0.6986807996872813, 1.0858667828142643, 21.327324584126472, 110.21085172891617, 92.44140923023224, 90.69625407457352, 89.28798884153366, 99.51164424419403, 89.95875924825668, 87.58209317922592, 88.47151905298233, 92.73084729909897, 87.74983897805214, 83.99814829230309, 82.85642355680466, 77.88470953702927, 78.62318471074104, 77.63581529259682, 80.41949272155762, 77.67527237534523, 77.71936520934105, 78.66901785135269, 78.52749824523926, 76.33465871214867, 78.34063947200775, 68.74108538031578, 61.00503869354725, 58.21009486913681, 58.14147815108299, 53.460087552666664, 52.02834337949753, 53.77441428601742, 60.05137726664543, 58.11522156000137, 54.02300074696541, 58.06544043123722, 56.09736643731594, 59.1278900206089, 52.11472034454346, 57.731252163648605, 69.39113929867744, 72.20799654722214, 66.4381505548954, 70.15008017420769, 73.98767665028572, 71.35811895132065, 68.80305245518684, 66.03413343429565, 65.81011265516281, 65.59488460421562, 68.72636497020721, 65.94094723463058, 69.05260786414146, 69.67992380261421, 70.70579275488853, 52.922131419181824, 61.84486582875252, 62.48984321951866, 71.68465062975883, 59.6128161996603, 74.31918606162071, 42.903801798820496, 37.76611648499966, 68.9772655069828, 60.668528750538826, 70.89008286595345, 64.08225417137146, 62.474659234285355, 63.057696148753166, 73.04526641964912, 63.16413223743439, 55.73646940290928, 48.25739152729511, 51.80858597159386, 49.46491353213787, 52.90603548288345, 57.53110930323601, 64.10787239670753, 66.46093413233757, 63.32636073231697, 55.82562021911144, 61.56261697411537, 59.30723659694195, 69.23694357275963, 64.21876564621925, 60.66522292792797, 56.828918382525444, 61.049351915717125, 56.12608529627323, 54.60815794765949, 56.43271364271641, 52.843540236353874, 48.450618758797646, 47.41921350359917, 53.766909688711166, 50.35542614758015, 53.36961440742016, 54.20609392225742, 61.172887086868286, 74.53250661492348, 68.97695392370224, 68.32399696111679, 70.92156797647476, 68.31445187330246, 73.01479205489159, 69.25191476941109, 68.0076715350151, 69.73257377743721, 71.24933078885078, 72.15271711349487, 69.55282062292099, 70.15084013342857, 72.54987180233002, 75.30336365103722, 74.36003386974335, 71.54496252536774, 76.15447998046875, 71.34218260645866, 47.71077945828438, 4.211450815200806, 0.8586987038142979, 1.5062461816705763, 1.9307917007245123, 3.009391254745424, 0.1574341021478176, 0.9676977549679577, 61.81913360953331, 65.5117754638195, 51.72725133597851, 83.89746889472008, 96.19028806686401, 78.72808948159218, 27.52816814929247, 42.65190191566944, 61.60724177956581, 65.08171454071999, 71.5838648378849, 14.79066738858819, 0.6473471573553979, 0.10853426632820629, 0.0432056966383243, 0.07412062623188831, 0.09498699131654575, 0.1263742719311267, 0.20288202358642593, 0.057949061374529265, 0.04400203222758137, 0.024830869733705185, 0.051400424490566365, 0.08438223536359146, 0.07788234273903072, 0.13422315154457465, 0.19253411010140553, 0.15079587319632992, 0.2549353858921677, 0.24401302041951567, 0.15199430810753256, 0.14666212548036128, 0.22306299302726984, 0.13683793076779693, 0.12505292252171785, 0.3814285498810932, 2.6117114815860987, 105.1916478574276, 97.38568872213364, 92.31590956449509, 78.12551021575928, 52.802285850048065, 44.27515581250191, 55.40330708026886, 55.938557758927345, 62.810188829898834, 4.345602141693234, 0.7712060830090195, 3.590728472918272, 5.413560485467315, 6.620383327826858, 4.941082913428545, 19.894041493535042, 110.84204345941544, 98.97528782486916, 91.78266137838364, 94.6544636785984, 104.26107779145241, 92.99247086048126, 91.54019638895988, 90.31134232878685, 94.03116032481194, 92.71325424313545, 85.46094059944153, 86.41423344612122, 81.02166160941124, 80.59700399637222, 79.52420756220818, 83.6489774286747, 81.24771147966385, 79.89955142140388, 82.27344363927841, 82.13686376810074, 79.59674566984177, 84.63664323091507, 73.18831354379654, 65.42707040905952, 61.912076622247696, 60.26663191616535, 56.660955995321274, 56.42794489860535, 56.901996061205864, 63.41501757502556, 60.18750116229057, 58.6224639415741, 61.23903013765812, 58.10009837150574, 61.44920825958252, 54.97517265379429, 60.47118254005909, 74.56074669957161, 75.74421599507332, 70.13789802789688, 72.23241403698921, 79.74473252892494, 76.0675710439682, 72.22121983766556, 68.30999091267586, 70.40756195783615, 68.8222262263298, 72.65593931078911, 66.55989602208138, 71.35770097374916, 73.4132082760334, 74.20209154486656, 55.639601200819016, 66.8863745033741, 67.20892399549484, 77.53190606832504, 61.481506526470184, 81.02160841226578, 28.37508950382471, 23.315174616873264, 76.73212498426437, 64.1616927087307, 76.59119054675102, 66.17662578821182, 65.59033244848251, 63.97349640727043, 77.71749570965767, 63.659998029470444, 59.72501277923584, 51.53761871159077, 54.91219863295555, 51.70677423477173, 56.41851760447025, 58.53033408522606, 68.8762517273426, 68.75539541244507, 66.44816681742668, 56.40262685716152, 64.22694280743599, 62.10577882826328, 75.15897139906883, 66.86011791229248, 65.5758248269558, 59.597598016262054, 62.151562571525574, 57.77999594807625, 55.687406435608864, 60.55146463215351, 57.49957859516144, 51.21307052671909, 50.87387032806873, 56.46999344229698, 52.2998958081007, 54.84562620520592, 56.77855208516121, 63.62594045698643, 81.4729405939579, 72.57442608475685, 69.32389810681343, 74.76674884557724, 71.35629504919052, 75.97172498703003, 72.9749321937561, 69.81860876083374, 74.85843792557716, 73.97281184792519, 74.60179969668388, 74.45208013057709, 75.20402938127518, 76.60050004720688, 79.01920706033707, 79.40190732479095, 74.97804790735245, 79.56305667757988, 75.70291981101036, 48.280562683939934, 4.027467537671328, 5.3661618288606405, 19.999801218509674, 8.773499317467213, 3.8391486927866936, 0.5639270867686719, 3.5776970721781254, 73.70143800973892, 70.50653144717216, 64.19238746166229, 89.27780538797379, 101.13954529166222, 99.299988001585, 33.22366163134575, 46.000867411494255, 74.74369168281555, 75.05671888589859, 84.36358228325844, 16.38312678784132, 0.7513742940500379, 0.1663829930475913, 0.1373209650046192, 0.17371327470755205, 0.23328373208642006, 0.2343087864574045, 0.5393734574317932, 0.283981739776209, 0.1851824694313109, 0.1684698974713683, 0.1837268506642431, 0.20150844182353467], [0.06459563577664085, 0.03310992782644462, 0.08803064818494022, 0.06176689166750293, 0.13420729927020147, 0.04813006911717821, 0.12319304107222706, 0.03616194335336331, 0.11273277385043912, 0.10876066589844413, 0.2085514974896796, 0.6454851385205984, 13.7892434746027, 82.53708109259605, 72.56918996572495, 58.958875089883804, 28.002021722495556, 33.91492433845997, 66.08902528882027, 42.0527196675539, 38.77830617129803, 30.637826286256313, 0.314677917631343, 0.5154121806845069, 2.0369849586859345, 1.5054775541648269, 1.046574991196394, 0.4748069657944143, 69.34973672032356, 97.1185402572155, 88.02393347024918, 89.60335671901703, 87.89773464202881, 89.11706641316414, 88.21598276495934, 86.17203444242477, 84.3168979883194, 84.0433506667614, 80.35510137677193, 82.7991758286953, 86.13301053643227, 80.26269793510437, 77.83664971590042, 80.5995574593544, 79.21601369976997, 76.85603633522987, 75.8392108976841, 75.92499509453773, 75.82161784172058, 73.0576765537262, 75.87672248482704, 64.18436989188194, 59.15646828711033, 57.02161364257336, 55.72583757340908, 50.49073688685894, 52.05445557832718, 52.51570142805576, 56.573283299803734, 51.9978804141283, 52.7977678924799, 55.249669924378395, 58.154522851109505, 55.8239521086216, 49.60109822452068, 60.7998801022768, 68.17384421825409, 70.46667158603668, 67.91504010558128, 68.68891417980194, 64.78567242622375, 61.671044155955315, 58.624743819236755, 56.11940525472164, 57.50411935150623, 58.67010198533535, 66.66860818862915, 60.70629492402077, 66.90388396382332, 66.67129844427109, 67.98669666051865, 57.20450542867184, 57.618865594267845, 58.93067680299282, 63.417236655950546, 55.42394757270813, 54.41871911287308, 16.903155483305454, 13.425392098724842, 53.695074543356895, 56.243430599570274, 67.75951445102692, 58.81160259246826, 67.71124184131622, 61.58247470855713, 63.26470144093037, 52.761400043964386, 48.771450743079185, 47.387321814894676, 49.07044529914856, 47.782173827290535, 52.78651289641857, 54.09602902829647, 62.81921714544296, 61.58737264573574, 58.53097625076771, 57.59313337504864, 60.81174686551094, 58.46813142299652, 60.219856426119804, 60.944538339972496, 64.1757595539093, 59.490021988749504, 57.61990673840046, 53.79565894603729, 51.77533395588398, 53.601116985082626, 48.81706729531288, 46.26188300549984, 43.871708661317825, 49.32482644915581, 51.251000091433525, 48.940382078289986, 50.29730826616287, 58.355243280529976, 68.25031891465187, 63.78087714314461, 64.48719084262848, 66.95638194680214, 65.35754933953285, 67.14393988251686, 65.63758671283722, 63.367181941866875, 64.33350428938866, 66.19786664843559, 66.31077378988266, 68.2840459048748, 70.67673951387405, 74.81037050485611, 71.70998767018318, 71.41143769025803, 67.27296575903893, 73.1548373401165, 66.56011641025543, 67.68787309527397, 27.061194106936455, 0.7316522835753858, 0.6550099211744964, 7.2360139433294535, 1.3719141273759305, 0.33536020782776177, 0.16609809739748016, 19.079296812415123, 77.011189609766, 34.785852804780006, 53.76246392726898, 83.30735296010971, 53.22285868227482, 25.507313087582588, 23.23301922529936, 42.207272574305534, 53.764884397387505, 60.971456095576286, 35.47693692147732, 0.5665611173026264, 0.019188526894140523, 0.05342488831956871, 0.041500753359287046, 0.029764493083348498, 0.13771002850262448, 0.1594565881532617, 0.034835038968594745, 0.06676974997390062, 0.039325121470028535, 0.026178865955444053, 0.012330996087257518, 0.10757759344414808, 0.051559270068537444, 0.06013825972331688, 0.05868625521543436, 0.1897374601685442, 0.09084807083127089, 0.17757067631464452, 0.09116474524489604, 0.07589945773361251, 0.13324296742212027, 0.28016517113428563, 0.6222603097558022, 18.498689867556095, 96.95080205798149, 78.27708408236504, 69.07360553741455, 40.16802839934826, 46.14393353462219, 37.90444806218147, 39.748724699020386, 53.08773793280125, 35.44029928743839, 0.3418365149991587, 0.5808417603839189, 2.9151009768247604, 1.405356489121914, 1.3957418175414205, 1.6835462115705013, 77.06064775586128, 98.41182366013527, 92.84219652414322, 89.90756839513779, 89.78122517466545, 92.88755849003792, 91.71616494655609, 87.28139251470566, 88.38809832930565, 85.9629088640213, 84.05883863568306, 87.28278324007988, 89.16699573397636, 83.17368373274803, 78.38592544198036, 81.19807094335556, 82.38531723618507, 80.53390458226204, 77.59916245937347, 78.04068356752396, 79.18964311480522, 76.2858085334301, 79.8604667186737, 66.07621997594833, 60.2241387963295, 60.07296770811081, 57.542934268713, 54.244099482893944, 54.72796931862831, 53.212686628103256, 59.76587198674679, 55.587661787867546, 54.91877608001232, 55.96660405397415, 60.559915378689766, 57.96870142221451, 52.52879932522774, 63.907676339149475, 69.99808073043823, 71.59018769860268, 71.29139453172684, 71.75196781754494, 68.61628487706184, 63.59133951365948, 61.390497609972954, 60.27757152915001, 60.38118816912174, 61.632772609591484, 67.1073554456234, 62.41317093372345, 69.54782009124756, 71.0095788538456, 72.41932600736618, 57.824730947613716, 60.598494708538055, 61.38235084712505, 69.07514825463295, 59.42780792713165, 60.30336074531078, 23.4402734041214, 19.020462669432163, 60.598255321383476, 58.35618942975998, 72.28506401181221, 59.70241919159889, 69.44226175546646, 65.31414806842804, 67.30763509869576, 54.04444679617882, 49.53533135354519, 49.54014949500561, 49.70621578395367, 51.83724023401737, 55.75429804623127, 57.85271644592285, 66.46167129278183, 62.107040360569954, 62.09857441484928, 63.6313209682703, 65.01446574926376, 63.42423968017101, 63.45922440290451, 64.32826817035675, 68.39606389403343, 63.08616802096367, 59.48385111987591, 55.30062519013882, 53.59398476779461, 55.100075751543045, 52.90303364396095, 49.224948808550835, 45.51483929157257, 49.54795427620411, 52.51111887395382, 50.2508519589901, 53.0450776219368, 61.09839208424091, 73.16942855715752, 66.20858207345009, 67.30153262615204, 69.7140383720398, 68.17527294158936, 70.9730476140976, 66.22288450598717, 66.231320053339, 67.5129608809948, 69.29910063743591, 69.49646964669228, 72.10435330867767, 72.53813803195953, 78.54861751198769, 75.75044006109238, 72.29827970266342, 68.18111702799797, 73.94733041524887, 70.4063992202282, 69.05144512653351, 38.69216859340668, 1.9870069529861212, 0.4419386404333636, 1.146764096338302, 2.9567358177155256, 1.1607328592799604, 0.321557181305252, 18.534979820251465, 84.24369111657143, 45.241242572665215, 54.96726527810097, 86.90141290426254, 62.19315513968468, 26.888755559921265, 32.39120990037918, 51.10457494854927, 62.164915055036545, 69.64645519852638, 46.25086359679699, 0.5706023785751313, 0.059863078786293045, 0.015585993642162066, 0.02594316170871025, 0.05402701499406248, 0.09273352668969892, 0.06759201249224134, 0.0918466156872455, 0.04677767195971683, 0.0368398247519508, 0.027164517850906122, 0.04113569091714453, 0.23641590698389336, 0.1291191644850187, 0.3672860946971923, 0.19836421444779262, 0.3661516774445772, 0.22661528288153931, 0.2940292318817228, 0.21929325390374288, 0.2768401417415589, 0.24754292709985748, 0.3590516693657264, 1.097460079472512, 21.40641923993826, 113.12571331858635, 86.94435819983482, 79.98661234974861, 43.93706515431404, 48.35962124168873, 81.65475323796272, 61.457180231809616, 62.73559883236885, 44.164061173796654, 0.3334634564816952, 0.9607302350923419, 4.969207104295492, 8.914294112473726, 5.57217774912715, 1.5771432523615658, 75.33751621842384, 102.19306915998459, 95.89784815907478, 94.60528671741486, 93.83939981460571, 97.12794855237007, 94.83937695622444, 88.43475222587585, 91.59152403473854, 90.21922007203102, 87.3520079255104, 88.64152193069458, 93.46621423959732, 85.91319993138313, 80.26636093854904, 82.74990767240524, 85.21629452705383, 81.96406424045563, 83.42732012271881, 81.62258416414261, 82.05007642507553, 80.26303231716156, 83.80340874195099, 69.43542212247849, 64.15767252445221, 63.55841428041458, 59.13805067539215, 56.929901763796806, 60.08920043706894, 59.533028081059456, 62.859848365187645, 57.73241490125656, 57.417297810316086, 58.48633624613285, 62.67884127795696, 61.26804918050766, 56.113260984420776, 68.87953475117683, 72.63064786791801, 76.45084887742996, 75.05465179681778, 75.19927203655243, 73.31466436386108, 68.19667339324951, 65.85438027977943, 62.77543969452381, 63.55185963213444, 64.80151757597923, 72.46353283524513, 64.7364042699337, 74.26373943686485, 73.9900629222393, 79.27861914038658, 60.8503033965826, 65.48293501138687, 64.76306363940239, 74.61808562278748, 58.25459808111191, 70.23543119430542, 22.749725058674812, 17.33850572258234, 70.0361242890358, 58.956302627921104, 77.16393381357193, 60.38024201989174, 75.08223071694374, 67.32022002339363, 71.97007611393929, 57.47464433312416, 53.85804019868374, 54.45669807493687, 54.26795080304146, 51.650510653853416, 58.64321082830429, 59.216653257608414, 70.42564138770103, 65.7185147702694, 66.4105412364006, 65.04627764225006, 68.07014018297195, 65.08707985281944, 69.64374974370003, 67.32477977871895, 71.57611325383186, 65.01488372683525, 64.25284221768379, 55.81157997250557, 56.59670144319534, 58.467569053173065, 54.92689624428749, 51.98213405907154, 48.41457389295101, 55.09965397417545, 54.880645126104355, 53.25788140296936, 54.80695568025112, 63.748031705617905, 76.04114726185799, 69.57768648862839, 68.28021571040154, 69.25762206315994, 69.49257105588913, 75.32037153840065, 68.48048776388168, 67.28140130639076, 69.43983748555183, 74.09649521112442, 73.78002539277077, 73.9801986515522, 78.23106095194817, 82.8464224934578, 80.87133407592773, 76.39778092503548, 69.09040823578835, 77.8531864285469, 74.28630262613297, 69.74256724119186, 42.261332273483276, 2.1411423571407795, 4.1748929768800735, 16.71495348215103, 5.295588215813041, 1.0967296874150634, 0.33678435953333974, 27.507730945944786, 93.27863350510597, 50.5964358150959, 65.50461664795876, 89.82049226760864, 69.99195545911789, 37.98691503703594, 37.39530198276043, 59.878744930028915, 71.98251664638519, 82.54340395331383, 53.29514600336552, 0.6893230299465358, 0.12462651415262371, 0.16163118474651128, 0.1881154815782793, 0.10015834312071092, 0.297552770934999, 0.26678694994188845, 0.18159066763473675, 0.1929857218055986, 0.14022063987795264, 0.16146411246154457, 0.3006738581461832], [0.08103383574052714, 0.07988579265656881, 0.055140269905678, 0.018258025847899262, 0.0390679784322856, 0.029414570453809574, 0.0925559678580612, 0.06399916426744312, 0.163647644512821, 0.08457369462121278, 0.3092507994733751, 0.36574432742781937, 39.60086703300476, 79.00221437215805, 68.20658326148987, 53.02424713969231, 45.44298134744167, 37.88270942866802, 79.09251272678375, 48.0756700783968, 48.80766659975052, 19.66868318617344, 0.6088248244486749, 1.8350797053426504, 2.9623666405677795, 1.2695219716988504, 2.9688996775075793, 25.147785879671574, 102.07469031214714, 88.13557907938957, 90.17281696200371, 72.58824214339256, 80.64608216285706, 85.24141877889633, 87.13894575834274, 84.99428763985634, 83.38170737028122, 85.49371764063835, 82.13701575994492, 78.86107474565506, 81.61335825920105, 80.29666051268578, 79.67110767960548, 80.10338768362999, 81.77738025784492, 79.9433022737503, 77.347501963377, 75.1640023291111, 71.98826193809509, 72.60084226727486, 74.38534811139107, 61.89397059381008, 54.78334754705429, 58.099684193730354, 50.33925421535969, 52.50082142651081, 49.280961602926254, 51.51641204953194, 53.57564315199852, 52.90123254060745, 53.338243290781975, 54.66931566596031, 58.18841703236103, 51.835860908031464, 52.77929708361626, 62.08516873419285, 66.7953085899353, 68.2369664311409, 65.84532156586647, 64.65961799025536, 61.310492902994156, 55.89528188109398, 59.69554916024208, 59.05598647892475, 61.41014635562897, 61.04569651186466, 64.33592855930328, 62.54644878208637, 64.72321137785912, 64.57333981990814, 66.20121046900749, 58.40570077300072, 56.8727870285511, 54.8077954351902, 62.2624634206295, 57.27030649781227, 43.39308634400368, 15.380125008523464, 12.38695627078414, 44.4040334969759, 58.438181430101395, 63.33961442112923, 56.903865560889244, 61.81229777634144, 53.969712406396866, 52.00740270316601, 47.030361369252205, 47.99586296081543, 47.401365861296654, 49.322098195552826, 54.839432537555695, 57.40304857492447, 56.75575710833073, 61.24944157898426, 60.535467490553856, 60.75355678796768, 61.10407657921314, 61.47233381867409, 63.95728647708893, 63.41108098626137, 60.75688160955906, 63.29569637775421, 65.24876117706299, 64.74723368883133, 57.33852043747902, 52.63350650668144, 51.34908802807331, 49.46611426770687, 47.413844391703606, 43.53094294667244, 45.209685266017914, 53.011658415198326, 48.41956302523613, 50.948262736201286, 56.718454509973526, 66.43494352698326, 62.27387800812721, 65.9120611846447, 63.97699981927872, 65.95327377319336, 65.1433016359806, 63.648363053798676, 63.466181829571724, 65.0374773144722, 66.7195862531662, 69.0561492741108, 67.83186256885529, 74.51334044337273, 70.14054268598557, 68.8442574441433, 70.79109817743301, 71.75473406910896, 71.05608075857162, 76.76161140203476, 70.41753262281418, 58.80341023206711, 29.85178716480732, 0.13937307754531503, 1.5914491284638643, 2.0982694951817393, 0.15543523128144443, 0.02011386073718313, 2.7453351113945246, 58.58616068959236, 70.50739780068398, 34.13422957062721, 33.8081044703722, 33.95112119615078, 40.08691795170307, 20.744924135506153, 30.189283154904842, 53.27159866690636, 51.03000394999981, 63.31868514418602, 5.382079649716616, 0.21096934040542692, 0.09810735864448361, 0.039515400712843984, 0.12000496019027196, 0.06964701940887608, 0.11810309544671327, 0.09081552765564993, 0.04863634370849468, 0.025247472476621624, 0.07043982608593069, 0.04654782511352096, 0.10054425249109045, 0.059615683858282864, 0.02473974513122812, 0.05968560159089975, 0.11104570890893228, 0.09065598816960119, 0.11911463530850597, 0.025441892903472763, 0.1561737572774291, 0.05292284025927074, 0.282457071589306, 0.30469143006484956, 47.636128664016724, 88.83042499423027, 73.12141433358192, 63.94025579094887, 59.52571727335453, 43.19445960223675, 54.05694052577019, 48.31436946988106, 55.42269363999367, 19.24885891377926, 0.5681582191027701, 3.4914350509643555, 7.185088125988841, 0.5936886335257441, 2.1855726605281234, 33.02954904735088, 107.75033935904503, 91.54684603214264, 91.93737387657166, 76.42968401312828, 84.46167781949043, 88.33560034632683, 89.74011898040771, 89.40110877156258, 86.18421658873558, 88.22820290923119, 86.3588248193264, 82.81051442027092, 84.95691284537315, 82.18264371156693, 80.66783219575882, 79.71400737762451, 82.85152181982994, 81.47544085979462, 80.39157181978226, 77.40674838423729, 75.75348749756813, 78.65892559289932, 77.03288644552231, 64.79081735014915, 58.11248570680618, 59.932477846741676, 54.744000658392906, 53.64098824560642, 52.5133341550827, 55.08521854877472, 56.58567823469639, 56.50742523372173, 54.10613268613815, 56.21245086193085, 60.81793673336506, 53.43628942966461, 54.56712394952774, 66.54493242502213, 70.04485622048378, 68.65776345133781, 69.16239157319069, 67.90391430258751, 62.83779434859753, 56.80527605116367, 62.65068098902702, 62.91824363172054, 63.24270822107792, 63.707677870988846, 65.9000538289547, 66.24953627586365, 67.50509530305862, 67.21082389354706, 68.89984846115112, 61.11909717321396, 60.0981679558754, 56.45003691315651, 65.05768463015556, 60.60729503631592, 50.84396593272686, 18.95214043557644, 17.078989148139954, 50.50251245498657, 61.31734773516655, 67.23348587751389, 59.96271662414074, 63.71645539999008, 55.456040650606155, 54.94772672653198, 49.647353142499924, 49.32920381426811, 49.94964972138405, 51.42015181481838, 56.06649689376354, 60.9261929243803, 60.26660531759262, 63.49307298660278, 61.97213239967823, 64.55291971564293, 64.88549306988716, 64.80162397027016, 64.56142365932465, 66.4066730439663, 64.52821344137192, 63.68832930922508, 66.6232082247734, 66.90122410655022, 60.23709990084171, 55.00316955149174, 52.27895513176918, 52.22278654575348, 50.04921957850456, 46.409714072942734, 48.838551342487335, 55.56133300065994, 53.76690588891506, 55.77368460595608, 58.47967140376568, 68.96316826343536, 64.89275828003883, 67.4873274564743, 66.89791828393936, 67.74708151817322, 66.97091996669769, 67.05184802412987, 66.03840440511703, 70.34312501549721, 69.72508057951927, 72.09831163287163, 71.29610627889633, 77.34576925635338, 73.49879488348961, 70.53502231836319, 70.88706582784653, 72.5906740128994, 74.58405464887619, 80.50271585583687, 72.95595601201057, 68.0644328892231, 42.569488137960434, 1.6032018978148699, 1.0750475758686662, 1.7113468260504305, 1.3591479999013245, 0.0829501352563966, 2.0466765761375427, 59.89700675010681, 81.90060764551163, 43.238035663962364, 37.630410566926, 35.29417432844639, 40.96978157758713, 30.93540921807289, 38.3363176882267, 63.10848422348499, 57.71741330623627, 75.26554808020592, 7.832398591563106, 0.2512264286633581, 0.12436300719855353, 0.05675123873515986, 0.09743777074618265, 0.08026120063732378, 0.0783455913187936, 0.0091747663282149, 0.08284975236165337, 0.017441507552575786, 0.058195662204525433, 0.04819536326976959, 0.20458675164263695, 0.23802702053217217, 0.141361944261007, 0.15557549719233066, 0.26709954254329205, 0.167351377021987, 0.2754590642871335, 0.16419255902292207, 0.20891863794531673, 0.2460120990872383, 0.5161786114331335, 0.6428808532655239, 51.65908679366112, 100.63145935535431, 85.10010436177254, 71.66717156767845, 61.18052087724209, 49.91152636706829, 108.79798874258995, 67.33775988221169, 66.12158194184303, 25.70957813411951, 0.666470640571788, 5.158558543771505, 12.211534883826971, 7.318185959011316, 6.419888036325574, 34.88984942436218, 111.08372569084167, 96.3414515554905, 97.89774924516678, 80.47203630208969, 85.99822416901588, 93.87982204556465, 92.86428853869438, 90.80611377954483, 90.12425556778908, 92.56741806864738, 90.64717590808868, 83.11288699507713, 89.17403295636177, 86.6809031367302, 83.57020765542984, 84.89112317562103, 86.79200917482376, 85.127082914114, 83.43424335122108, 79.73043009638786, 81.68793305754662, 79.78622630238533, 82.43178114295006, 68.40466663241386, 59.401064962148666, 62.71287985146046, 56.75860695540905, 57.129995226860046, 58.12487684190273, 58.36539253592491, 59.877578392624855, 58.3659853041172, 57.689059227705, 58.55235390365124, 63.46802473068237, 57.9726380109787, 58.68370145559311, 71.36891037225723, 73.74044671654701, 73.12565490603447, 72.3431096971035, 71.87015667557716, 67.58365228772163, 63.161335587501526, 65.65745204687119, 66.150543987751, 65.85119605064392, 66.76321551203728, 70.24702817201614, 68.33236411213875, 72.55220487713814, 69.8280094563961, 73.75416398048401, 64.08242896199226, 63.2719362527132, 59.13547821342945, 70.10364666581154, 62.88660652935505, 59.9812938272953, 20.113472118973732, 17.24304534494877, 57.883023619651794, 62.10230961441994, 73.26204478740692, 61.755509823560715, 69.12361085414886, 59.96509149670601, 60.23252874612808, 53.50255027413368, 54.13205489516258, 53.19804981350899, 53.74319516122341, 62.34717607498169, 63.675554394721985, 62.05637387931347, 67.6233297586441, 65.05013823509216, 67.3119592666626, 66.6915437579155, 67.78200924396515, 69.84108075499535, 72.12287351489067, 66.7838180065155, 67.97429412603378, 67.3926593363285, 71.17883697152138, 63.018953427672386, 57.48554214835167, 55.30354343354702, 56.018418073654175, 53.1249113380909, 49.61950063705444, 52.02884115278721, 58.09871904551983, 56.57750487327576, 58.2590514421463, 63.20406809449196, 73.19006145000458, 68.4889005124569, 71.67482435703278, 69.5188656449318, 72.32900485396385, 70.90886145830154, 71.17732465267181, 67.79630407691002, 73.44983071088791, 73.13523039221764, 74.40145924687386, 74.86220732331276, 81.24148741364479, 77.20033586025238, 73.66530194878578, 72.70004734396935, 75.21900057792664, 78.42699363827705, 85.13048753142357, 75.9608043730259, 71.12678736448288, 38.2115513831377, 1.172112892381847, 7.6983417849987745, 8.318775817751884, 0.8826959005091339, 0.1807627870584838, 3.9001425448805094, 74.45496797561646, 84.70480397343636, 51.84812664985657, 47.80464582145214, 47.89826899766922, 52.96576827764511, 30.37818431854248, 45.04890449345112, 72.30646446347237, 64.92355182766914, 86.05116292834282, 9.105968177318573, 0.44116576784290373, 0.29241666372399777, 0.20674628263805062, 0.1691265794215724, 0.13349884509807453, 0.2540387527551502, 0.14324311050586402, 0.28098557086195797, 0.12860130867920816, 0.2119985211174935, 0.14557369169779122], [0.03783026164455805, 0.0873866346955765, 0.04925937297230121, 0.04378095385618508, 0.07481830441975035, 0.03825267354841344, 0.12774737871950492, 0.06355760124279186, 0.015181355247477768, 0.03219220285245683, 0.11874243340571411, 0.07292633992619812, 63.27281400561333, 69.35923621058464, 57.5552000105381, 36.94058798253536, 28.783058412373066, 51.56807787716389, 52.11924970149994, 36.60157397389412, 63.52938383817673, 4.73841936327517, 0.06573192324140109, 1.4502715039998293, 2.2240643575787544, 0.7030150014907122, 1.4418177888728678, 78.11628431081772, 92.26650461554527, 88.608608096838, 81.60642743110657, 72.2949966788292, 74.61637571454048, 79.32664856314659, 82.014981508255, 80.22174373269081, 79.09651771187782, 78.96809220314026, 76.5345811843872, 74.6829405426979, 78.15989077091217, 77.60742321610451, 75.07283002138138, 74.01556715369225, 76.6039502620697, 78.59272554516792, 76.7134527862072, 77.62088969349861, 73.43314200639725, 72.40650549530983, 71.80632770061493, 58.74375343322754, 55.23325100541115, 58.27586933970451, 52.54286617040634, 49.60652053356171, 51.37025289237499, 50.848670080304146, 56.16762086749077, 55.19596740603447, 51.236002296209335, 55.097066313028336, 56.972261890769005, 49.658057168126106, 56.40799976885319, 64.50651660561562, 64.79808256030083, 66.64501145482063, 66.33222743868828, 59.37713384628296, 54.92060378193855, 62.08110295236111, 65.06722211837769, 63.67695651948452, 63.288700953125954, 62.16370292007923, 64.66941386461258, 63.25993649661541, 64.12239521741867, 65.28836265206337, 65.7650850713253, 63.02709259092808, 56.4886200428009, 53.0852946639061, 58.699261620640755, 59.51350472867489, 43.4614522755146, 21.376410350203514, 19.35966856777668, 46.44034042954445, 60.297847241163254, 62.42902748286724, 53.70674751698971, 52.69541658461094, 47.48564153909683, 45.71737602353096, 43.95195655524731, 45.064525455236435, 47.74941958487034, 50.62557265162468, 53.7980680167675, 57.694755122065544, 58.36913913488388, 60.41773080825806, 58.858511075377464, 59.34697486460209, 57.594812884926796, 59.16508622467518, 61.870734840631485, 62.05424979329109, 57.73842237889767, 61.041737124323845, 59.011004492640495, 66.4544440805912, 63.232232183218, 58.61919991672039, 50.22417739033699, 49.5367980748415, 46.702701151371, 45.52793338894844, 41.87504880130291, 50.19388161599636, 48.298383727669716, 50.29378205537796, 52.51390792429447, 61.89512953162193, 61.62247896194458, 64.29162293672562, 67.98378601670265, 65.70784494280815, 64.32780459523201, 66.28597632050514, 63.78086194396019, 69.10132884979248, 65.48831552267075, 71.31113827228546, 70.88189050555229, 70.3567586839199, 67.43412271142006, 72.87796139717102, 72.87171453237534, 75.22217720746994, 72.49915972352028, 74.721440076828, 71.70665144920349, 72.02806860208511, 75.16306757926941, 42.06707909703255, 0.400871483143419, 1.7325783055275679, 1.3936868403106928, 0.0862204386794474, 0.13536717218812555, 25.956709273159504, 70.399369597435, 70.4738000035286, 26.574046947062016, 38.610051199793816, 32.876747846603394, 22.02859975397587, 21.050262451171875, 43.90683397650719, 60.57087019085884, 58.274687603116035, 24.866969548165798, 0.6689583195839077, 0.1841480194707401, 0.11205684058950283, 0.10158092889469117, 0.11668492545140907, 0.04695884133980144, 0.0313790390646318, 0.012029362223984208, 0.039589095977135, 0.02963113656733185, 0.05145778879523277, 0.05530544600333087, 0.013694217468582792, 0.010585808922769502, 0.04090782931598369, 0.042253962747054175, 0.010357517803640803, 0.11654012501821853, 0.016033948413678445, 0.03391652360733133, 0.028312520116742235, 0.1505315350368619, 0.03842171994620003, 75.18743187189102, 78.24784845113754, 65.92875748872757, 44.73298944532871, 45.90629428625107, 51.74338907003403, 53.411655351519585, 43.80130983889103, 71.4976854622364, 4.115096060559154, 0.040469197774655186, 3.565478827804327, 3.08513259049505, 0.23982557089766487, 4.278265004977584, 90.69370821118355, 90.55016711354256, 93.12743201851845, 80.73748245835304, 74.20316308736801, 75.88296175003052, 81.93067163228989, 83.62529709935188, 83.6855086684227, 81.20804160833359, 81.45903334021568, 79.36514809727669, 78.7916448712349, 79.07654598355293, 81.08303591609001, 76.34542733430862, 78.41301038861275, 78.48082914948463, 81.41783595085144, 77.721037119627, 80.85935711860657, 77.45749846100807, 76.589115858078, 72.82763689756393, 60.82836717367172, 57.624337300658226, 61.064117923378944, 53.976324051618576, 54.26068179309368, 55.2597089856863, 55.27554653584957, 58.717253655195236, 55.98092168569565, 52.30989687144756, 54.836320504546165, 59.24361281096935, 53.12467575073242, 58.632556200027466, 66.00505739450455, 68.5784313082695, 69.79251936078072, 68.37877482175827, 62.68664225935936, 57.659075036644936, 63.207373917102814, 67.90359511971474, 65.76858088374138, 65.85526183247566, 66.05624064803123, 66.54661953449249, 66.19314730167389, 66.71154588460922, 66.9554927945137, 68.31100925803185, 65.85325554013252, 61.883152574300766, 57.18780152499676, 63.852298110723495, 61.868299171328545, 50.58592937886715, 27.041283175349236, 25.12582875788212, 53.006992265582085, 61.8517130613327, 66.10262855887413, 57.48354345560074, 55.63188001513481, 51.58593691885471, 47.04912096261978, 47.142318561673164, 48.93926873803139, 50.48305369913578, 55.379934534430504, 56.32520601153374, 61.664554104208946, 60.621783658862114, 64.46507602930069, 61.94160483777523, 62.70308397710323, 61.91884025931358, 62.58468613028526, 63.9950792491436, 63.82894456386566, 61.62763148546219, 63.480073884129524, 63.673016130924225, 68.79004955291748, 67.27033630013466, 62.560618221759796, 52.555261105298996, 53.733980655670166, 50.298820585012436, 49.44213755428791, 45.520614981651306, 52.528316751122475, 51.32821574807167, 54.28248502314091, 53.83176080882549, 63.106306940317154, 63.65616783499718, 68.15902501344681, 70.48451542854309, 68.72666135430336, 67.3830534517765, 69.74927768111229, 65.91628655791283, 71.2361378967762, 68.31295475363731, 75.07184967398643, 71.17811501026154, 70.70874899625778, 69.33771416544914, 74.98852014541626, 74.52708050608635, 77.60338023304939, 73.67228597402573, 76.67067468166351, 72.40719705820084, 77.45247513055801, 77.90615558624268, 54.44753676652908, 1.484878147020936, 1.1520447442308068, 2.2773201623931527, 0.3435832040850073, 0.30733000254258513, 24.164932519197464, 74.66903328895569, 80.08622020483017, 36.10916219651699, 34.32798497378826, 32.223627492785454, 30.503875873982906, 33.11969920992851, 51.370306089520454, 66.48972898721695, 68.60635980963707, 32.37259849905968, 0.768000598764047, 0.2413694903953001, 0.20927201898302883, 0.1572535079321824, 0.06037024766555987, 0.05047721875598654, 0.08862506394507363, 0.05304452279233374, 0.10149723690119572, 0.024716271000215784, 0.09238483602530323, 0.2267509326338768, 0.12016138265607879, 0.17787378426874056, 0.22935806773602962, 0.20952391874743626, 0.10299074230715632, 0.27227783342823386, 0.17987753846682608, 0.10086259673698805, 0.16917017317609861, 0.33395348174963146, 0.1589306874666363, 82.16372832655907, 88.58920633792877, 76.15823417901993, 55.12083023786545, 41.48444876074791, 68.9860962331295, 72.4142874777317, 54.66645821928978, 82.42121011018753, 6.186074232682586, 0.32264962268527597, 5.396879855543375, 7.7230447344481945, 3.2683414220809937, 4.886519741266966, 94.9908596277237, 93.74442011117935, 97.69648924469948, 85.268914103508, 78.71503338217735, 82.01123490929604, 87.33909621834755, 89.0115536749363, 87.79308825731277, 85.055221170187, 84.95850875973701, 83.52659359574318, 82.90718123316765, 84.62856486439705, 85.12639135122299, 81.00460052490234, 79.60790947079659, 83.22317987680435, 82.89310678839684, 80.18961265683174, 84.76746261119843, 79.52969446778297, 78.84537398815155, 79.49929609894753, 64.3719582259655, 60.604369193315506, 63.41529496014118, 56.76840282976627, 56.0147512704134, 58.47569681704044, 55.92322938144207, 61.93100720643997, 58.98608162999153, 54.98079255223274, 55.965209528803825, 63.380070850253105, 54.822736233472824, 59.36127729713917, 70.45696690678596, 70.84263101220131, 74.37696576118469, 72.7437449991703, 67.79461696743965, 61.31960481405258, 67.3209647834301, 71.61092698574066, 69.24216449260712, 68.71568754315376, 68.47022831439972, 69.7674635052681, 66.88404142856598, 70.43030753731728, 70.67252174019814, 73.74295458197594, 67.8232978284359, 64.63930428028107, 58.98216404020786, 67.00302064418793, 66.21346861124039, 59.3350663036108, 27.70263008773327, 27.4465599283576, 61.14390604197979, 64.82684701681137, 71.87856182456017, 59.513588324189186, 60.01688651740551, 54.93389926850796, 51.61321945488453, 49.51180301606655, 51.624896228313446, 54.547551199793816, 57.46030390262604, 57.982950657606125, 64.10270467400551, 61.943124756217, 67.04753145575523, 65.68227231502533, 66.73812165856361, 64.14782345294952, 65.94169199466705, 69.10071328282356, 67.38583490252495, 65.82007572054863, 69.3114423751831, 64.17049303650856, 70.79429000616074, 68.53299334645271, 63.84369537234306, 54.542448073625565, 56.363029181957245, 52.4231231957674, 52.48665198683739, 49.466752633452415, 55.152049362659454, 53.635733127593994, 57.78243541717529, 56.18249326944351, 66.96994721889496, 64.95842635631561, 71.40157341957092, 72.08999767899513, 69.83682498335838, 71.28914505243301, 71.77820160984993, 69.22480702400208, 75.69939360022545, 71.08180537819862, 78.56643095612526, 75.69888442754745, 74.30799186229706, 70.47713622450829, 76.57999634742737, 79.40566912293434, 82.82022669911385, 79.60651874542236, 82.20006957650185, 76.19823843240738, 78.74885156750679, 79.7170852124691, 48.80496874451637, 1.1338021606206894, 11.841923967003822, 4.5037890784442425, 0.38672813738230616, 0.20708157011540607, 35.51445230841637, 83.72938111424446, 87.36875742673874, 41.344129890203476, 53.785285502672195, 44.86855857074261, 30.48538986593485, 32.28437103331089, 62.161966413259506, 77.98645287752151, 79.77693200111389, 38.91753830015659, 0.9648125222884119, 0.36203287658281624, 0.2677610929822549, 0.24841854261467233, 0.19093387643806636, 0.2514458372024819, 0.1320685335667804, 0.1341119481367059, 0.16783516824943945, 0.17874589684652165, 0.23444314487278461], [0.0462228312244406, 0.0661578046856448, 0.0057277501218777616, 0.0456543943437282, 0.08863937997375615, 0.15190020378213376, 0.04207283789583016, 0.05106058764795307, 0.03667755787319038, 0.2008226083125919, 0.1726692807278596, 2.3453840101137757, 66.29898682236671, 72.38720253109932, 66.12734243273735, 39.66935455799103, 22.772681526839733, 72.69209057092667, 40.59393994510174, 47.816269397735596, 66.39886826276779, 0.19774382351897657, 1.2178788240998983, 2.3602568870410323, 1.1860229959711432, 1.3361340598203242, 31.102370359003544, 103.17457169294357, 88.68752986192703, 88.590597063303, 72.80954986810684, 69.4338946044445, 66.8565309047699, 67.75155007839203, 73.53503733873367, 76.69661208987236, 73.79815801978111, 73.71579363942146, 73.19084420800209, 72.30926111340523, 68.99556532502174, 70.33018290996552, 71.81278735399246, 72.15688169002533, 74.07153815031052, 75.09695112705231, 77.42305710911751, 77.09085613489151, 72.98991098999977, 71.77090600132942, 60.26183657348156, 56.047813296318054, 53.91252547502518, 55.61851233243942, 50.719989985227585, 50.03762640058994, 53.16801242530346, 52.67285719513893, 56.31159894168377, 52.66175799071789, 51.04762360453606, 55.41630998253822, 51.82387635111809, 47.97041192650795, 57.45645470917225, 63.176846355199814, 64.73946690559387, 63.96089628338814, 62.22648695111275, 55.58020658791065, 58.98182585835457, 67.89714306592941, 66.24293223023415, 65.36711722612381, 65.72643354535103, 68.29215466976166, 65.84830820560455, 67.21144706010818, 63.80658656358719, 61.6857835650444, 63.05784434080124, 61.946179792284966, 60.3483085334301, 60.04720889031887, 61.38109691441059, 57.34739676117897, 46.76866181194782, 36.83066748082638, 33.14779110252857, 49.703650921583176, 60.5873841047287, 59.98071625828743, 55.282127782702446, 52.06071384251118, 47.99881920218468, 50.6316789239645, 47.01238073408604, 50.16669787466526, 51.05574756860733, 56.350106075406075, 56.45836606621742, 59.954163283109665, 59.65473175048828, 61.30870319902897, 60.38327805697918, 60.63843436539173, 60.29286190867424, 58.860920146107674, 57.751060500741005, 58.95759075880051, 57.6172810792923, 60.48179917037487, 59.01509307324886, 58.45574028789997, 66.04313135147095, 65.93906253576279, 54.693980142474174, 52.097267881035805, 47.825134322047234, 45.348381623625755, 42.538223415613174, 47.13022381067276, 50.17112843692303, 50.11588700115681, 52.44624875485897, 58.13715398311615, 62.67017014324665, 61.99060320854187, 62.636815533041954, 70.9879732131958, 66.22938975691795, 64.59158644080162, 66.13000229001045, 67.61803284287453, 65.95368415117264, 69.67704355716705, 66.6577559709549, 66.69727385044098, 71.78327053785324, 72.7111579477787, 68.42273846268654, 73.03369984030724, 67.77782946825027, 73.97163391113281, 68.94634276628494, 79.59670767188072, 67.78244242072105, 89.6613036096096, 23.616171665489674, 0.0976332301797811, 4.772870214655995, 0.23562329326523468, 0.040582438377896324, 3.4060144471004605, 60.07363647222519, 66.52540907263756, 57.678112015128136, 38.164570704102516, 53.80344472825527, 21.328331530094147, 12.6880825124681, 30.78164666891098, 53.86472783982754, 58.580700382590294, 52.02381782233715, 1.620967488270253, 0.08327953750267625, 0.06894046513480134, 0.043126683885930106, 0.012028196124447277, 0.06702576865791343, 0.020435806254681665, 0.06493621476693079, 0.04669257359637413, 0.04731461580377072, 0.11030932029825635, 0.02001049626414897, 0.05527275810891297, 0.05215478049649391, 0.021977885226078797, 0.09620221360819414, 0.07128825673134997, 0.052410279677133076, 0.08442893129540607, 0.1345037724240683, 0.1264723838539794, 0.18935596657684073, 3.2005516346544027, 79.68524292111397, 77.43555843830109, 76.30255043506622, 50.95917955040932, 26.707740873098373, 66.22451841831207, 45.059790909290314, 59.25824962556362, 68.4756088256836, 0.23681576130911708, 1.0590105364099145, 5.3926801308989525, 1.3804211583919823, 1.2814330263063312, 43.38309288024902, 104.27632257342339, 92.30847716331482, 89.28426504135132, 76.965052485466, 71.47669538855553, 69.82497721910477, 69.55037355422974, 75.65382644534111, 78.50536823272705, 77.67557635903358, 76.1980864405632, 75.98940923810005, 73.11938524246216, 72.62760803103447, 72.30312824249268, 74.43352192640305, 74.78988200426102, 77.77396827936172, 76.45183682441711, 81.30539238452911, 78.31878304481506, 75.00635638833046, 73.8313302397728, 63.06253708899021, 57.31490470468998, 57.77164399623871, 57.9734967648983, 56.0201545804739, 52.73531824350357, 54.82629284262657, 54.75260719656944, 59.463757798075676, 53.737332075834274, 52.95765571296215, 56.90418854355812, 54.612189531326294, 49.03121620416641, 61.55857399106026, 65.35485908389091, 70.06677344441414, 67.64525458216667, 64.18155044317245, 57.30974838137627, 61.954489946365356, 69.09372925758362, 67.3646928369999, 67.72627383470535, 68.27283650636673, 71.78764030337334, 68.96425500512123, 68.25307756662369, 65.46586632728577, 63.56315262615681, 68.962681889534, 62.79853865504265, 61.380500346422195, 62.639053612947464, 65.54189264774323, 59.50949974358082, 50.5381241440773, 43.86722110211849, 40.43637380003929, 53.7984973937273, 62.34942175447941, 62.837003991007805, 56.83587200939655, 54.40543882548809, 51.55489258468151, 53.57728846371174, 50.467561930418015, 52.59990490972996, 54.325255528092384, 57.84946762025356, 59.90972466766834, 62.53623493015766, 62.393222004175186, 64.48469057679176, 63.62686760723591, 62.47305192053318, 62.467568814754486, 63.33540424704552, 59.22455683350563, 62.43347704410553, 61.19338318705559, 61.953665390610695, 63.29011827707291, 61.05008527636528, 66.23572021722794, 68.79755795001984, 57.80487321317196, 53.46992142498493, 50.318834111094475, 47.76213750243187, 45.81300549209118, 49.194592237472534, 52.85482943058014, 51.73539809882641, 54.029566794633865, 62.064209058880806, 65.90702265501022, 65.89803993701935, 67.04623952507973, 72.21460819244385, 69.41358849406242, 68.64469215273857, 69.68390598893166, 69.81467217206955, 68.34272995591164, 71.14451721310616, 67.58415386080742, 68.76179426908493, 74.15666878223419, 74.92002502083778, 71.23915493488312, 76.00733667612076, 70.78167468309402, 75.77431038022041, 71.88500627875328, 80.5986987054348, 71.02739989757538, 89.93580088019371, 33.21356177330017, 0.1498903491301462, 1.2290321756154299, 1.3646011822856963, 0.1523183743120171, 3.21119106374681, 62.65511155128479, 71.28697916865349, 68.37030127644539, 38.49285028874874, 34.80214633047581, 23.638005293905735, 21.481147930026054, 39.738769233226776, 61.52444042265415, 63.52682277560234, 61.88615821301937, 2.3298483062535524, 0.1482356566702947, 0.15556022379314527, 0.0620574907225091, 0.055325313296634704, 0.033529649444972165, 0.04227733668813016, 0.044278526765992865, 0.05120178124343511, 0.061974789496161975, 0.08939816660131328, 0.10773391200928017, 0.1531811655149795, 0.1699678780278191, 0.13572732161264867, 0.2343616125290282, 0.2162201242754236, 0.16742611129302531, 0.18979806394781917, 0.31795067014172673, 0.3569293348118663, 0.4350145807256922, 3.780551324598491, 92.41509944200516, 86.96589544415474, 88.65390926599503, 54.67630349099636, 34.11670111119747, 82.88391888141632, 58.07520970702171, 66.97254627943039, 76.96015074849129, 0.45796980208251625, 2.1848656609654427, 8.408596348017454, 7.02247585169971, 2.398027810268104, 44.10262607038021, 105.8350445330143, 98.45160752534866, 92.38411590456963, 79.944928586483, 73.72252687811852, 73.36337774991989, 73.75562310218811, 80.3582476079464, 83.36939603090286, 80.51144778728485, 79.32218000292778, 81.07910692691803, 78.1829859316349, 77.31762036681175, 77.77723610401154, 78.15830245614052, 78.74306827783585, 81.54281124472618, 81.22612103819847, 84.48571532964706, 82.76634559035301, 77.24590301513672, 77.91229605674744, 65.9078586101532, 59.49164070188999, 59.02355521917343, 60.79771041870117, 58.853521943092346, 56.170740500092506, 60.61076804995537, 57.88684621453285, 61.26224689185619, 58.004499301314354, 54.26657907664776, 60.0769916921854, 58.000118136405945, 51.414657309651375, 63.96421730518341, 70.08373573422432, 71.93736746907234, 71.50339275598526, 67.94906347990036, 61.68699949979782, 65.19384652376175, 73.76222714781761, 70.72545289993286, 70.38953572511673, 70.93276217579842, 75.41450008749962, 70.50430476665497, 72.68421739339828, 69.08124312758446, 67.29902476072311, 72.08265647292137, 66.76670372486115, 65.8414001762867, 66.61345794796944, 69.1303288936615, 62.47393727302551, 56.846188455820084, 45.296305418014526, 45.523392632603645, 59.49371159076691, 67.78830170631409, 67.77531400322914, 61.32269784808159, 59.88913357257843, 54.17687729001045, 57.10316486656666, 52.953149154782295, 57.081217244267464, 57.968587428331375, 62.29938603937626, 61.953494399785995, 66.76994875073433, 66.37856215238571, 67.84721374511719, 66.6088829934597, 65.84739625453949, 66.96388274431229, 66.44609212875366, 63.93431290984154, 65.68174794316292, 64.90232616662979, 68.84839922189713, 65.88133603334427, 65.61136052012444, 69.65216249227524, 68.36686626076698, 60.49303896725178, 56.14177845418453, 54.00979645550251, 50.630052611231804, 49.88892138004303, 53.786227852106094, 55.66607438027859, 54.94897685945034, 57.80545838177204, 64.22736078500748, 70.00147014856339, 67.72990643978119, 70.80005809664726, 73.12410458922386, 70.4298135638237, 71.37149423360825, 72.63136982917786, 72.6705077290535, 69.48177963495255, 75.77700823545456, 72.50462383031845, 70.28903111815453, 78.19823831319809, 79.45006594061852, 74.28029134869576, 81.8086525797844, 73.42406809329987, 82.04959765076637, 75.75205877423286, 86.26525864005089, 75.80588668584824, 97.69765198230743, 32.64243341982365, 0.8220869558863342, 14.459413513541222, 1.7088061873801053, 0.22697378473822027, 5.071650082245469, 76.2467010319233, 77.2775249183178, 75.800019800663, 53.85343484580517, 69.96583566069603, 28.650118745863438, 24.34376612305641, 46.120929569005966, 71.17144256830215, 71.9409316778183, 74.33250814676285, 2.8502757428213954, 0.3589968988671899, 0.2946621354203671, 0.18429450457915664, 0.13662386569194496, 0.17661146528553218, 0.12865578231867403, 0.1712781545938924, 0.16344960982678458, 0.12887991091702133, 0.15220638422761112], [0.01201042354296078, 0.013322662161954213, 0.03474148012173828, 0.05373745494580362, 0.04683491752075497, 0.10295078507624567, 0.09065820719115436, 0.08871128666214645, 0.11626892941421829, 0.16012927080737427, 0.11505015965667553, 4.916863488033414, 66.70148402452469, 61.4762894064188, 55.34322090446949, 28.097814582288265, 56.970665976405144, 67.51954972743988, 29.860342405736446, 75.22995918989182, 35.59210114181042, 0.1619170600315556, 0.6512667657807469, 2.1343017742037773, 0.4403939936310053, 2.0755234407261014, 89.24568951129913, 93.51802065968513, 90.77879324555397, 75.83383038640022, 73.4013757109642, 76.62783578038216, 77.76103377342224, 67.3821870982647, 65.1128500699997, 65.2618096768856, 70.36676734685898, 65.8143076300621, 68.19647580385208, 65.9795531630516, 69.94630470871925, 63.78171309828758, 65.39305463433266, 65.07808953523636, 68.99073198437691, 67.56540566682816, 71.45619168877602, 65.65660089254379, 67.42779225111008, 57.61511139571667, 53.6771585047245, 53.937056958675385, 54.94652979075909, 53.96702975034714, 50.41719563305378, 52.289617359638214, 53.05107370018959, 55.59358187019825, 55.97361467778683, 52.62315586209297, 51.79639622569084, 52.87294685840607, 51.75570800900459, 48.196628987789154, 58.440856486558914, 60.88278025388718, 64.12652939558029, 63.00983391702175, 57.065877467393875, 51.747838631272316, 58.433929458260536, 66.19207575917244, 63.88800859451294, 61.066561192274094, 62.67131008207798, 63.80844086408615, 66.35089203715324, 60.5635479837656, 62.56460040807724, 62.56668649613857, 64.78911504149437, 62.5908076018095, 58.21064583957195, 56.48998036980629, 64.66000556945801, 53.620830327272415, 48.974439650774, 48.817253485322, 43.55998858809471, 45.157335475087166, 58.22848968207836, 59.75184313952923, 55.65767303109169, 51.85636080801487, 53.980344235897064, 50.719184428453445, 52.11089015007019, 52.916541919112206, 50.99793367087841, 55.572413206100464, 58.601169884204865, 59.15218211710453, 58.6252947896719, 57.90636956691742, 58.8888144493103, 58.027643859386444, 56.66052661836147, 57.440655156970024, 57.94952005147934, 51.69004753232002, 56.43900230526924, 56.527928933501244, 60.09018078446388, 58.31781528890133, 52.86700397729874, 68.25747013092041, 64.39935475587845, 51.34369231760502, 48.61709922552109, 45.738620683550835, 44.36389625072479, 42.37579733133316, 49.99742455780506, 48.18576917052269, 50.18238343298435, 54.02837745845318, 65.0801794230938, 63.6546441167593, 63.820448219776154, 62.62845978140831, 70.2003362774849, 68.27159017324448, 71.10036358237267, 66.77938744425774, 65.5134929716587, 65.49352124333382, 71.6095894575119, 70.75631484389305, 75.0514067709446, 68.69716733694077, 70.00789180397987, 66.85675129294395, 70.99631756544113, 62.97836400568485, 72.2833389043808, 67.43611380457878, 74.73888114094734, 68.3990429341793, 72.44495183229446, 4.9580770265311, 1.4688120153732598, 2.8461358649656177, 0.28197574429214, 0.051108515544910915, 33.72696742415428, 67.05972880125046, 68.83870214223862, 41.564544662833214, 58.992377892136574, 51.81817285716534, 24.57346949726343, 17.71800845861435, 39.73723791539669, 48.11499796807766, 65.52767381072044, 7.887820992618799, 0.36869688774459064, 0.1105036516673863, 0.04639819700969383, 0.09509645067737438, 0.04120482197322417, 0.05968731966277119, 0.01301687505474547, 0.02330594365048455, 0.0683583616046235, 0.015917768905637786, 0.048811149172252044, 0.0984622462419793, 0.028819084145652596, 0.03799894438998308, 0.04581689128826838, 0.16503498569363728, 0.04443291574716568, 0.015890639697317965, 0.06022241555911023, 0.23582198104122654, 0.3299037303077057, 8.875146713107824, 80.01115143299103, 67.64669850468636, 65.90068459510803, 35.396970212459564, 43.90205003321171, 50.82748621702194, 36.5839809179306, 86.36487409472466, 36.41668349504471, 0.23177491617389023, 0.6854947353713214, 2.7047053165733814, 0.9445682179648429, 5.828532418236136, 96.60139560699463, 91.83670967817307, 94.48285728693008, 77.35997289419174, 76.52945905923843, 79.55532029271126, 80.70977434515953, 69.59157854318619, 68.40271353721619, 68.99187952280045, 73.61597299575806, 68.97447645664215, 72.41744890809059, 68.10715019702911, 72.59863078594208, 67.47719720005989, 68.67602527141571, 66.82158797979355, 71.78522363305092, 70.67442163825035, 74.42809581756592, 68.32161068916321, 70.1838831603527, 61.43188498914242, 57.2366289049387, 57.28775896131992, 56.55342936515808, 56.46480292081833, 51.58917434513569, 55.16458109021187, 54.18224640190601, 58.01941730082035, 56.49978764355183, 54.24874663352966, 53.00273269414902, 55.22586040198803, 54.164292365312576, 51.07943169772625, 61.30762405693531, 63.069194331765175, 68.75807046890259, 66.02136611938477, 59.83797311782837, 53.22323486208916, 61.621787399053574, 66.16095542907715, 67.15634241700172, 61.119727939367294, 64.44328039884567, 65.57964742183685, 67.7082172036171, 65.41297316551208, 65.83267584443092, 66.50373503565788, 66.77342176437378, 63.85995090007782, 61.99556574225426, 60.56143909692764, 67.57894054055214, 58.119982704520226, 53.027359172701836, 53.733456283807755, 49.40346322953701, 49.1310216486454, 60.21639101207256, 64.44386556744576, 57.78494328260422, 55.96029259264469, 55.39521351456642, 55.44500984251499, 54.58037003874779, 53.71969722211361, 54.35401998460293, 57.086894139647484, 62.07983002066612, 62.44435966014862, 62.149959057569504, 59.75818119943142, 61.964418813586235, 60.3420502692461, 60.555036440491676, 61.38048894703388, 59.1092786192894, 56.421804428100586, 60.8810855448246, 59.734071493148804, 61.77881017327309, 62.417669892311096, 56.929814368486404, 69.97924894094467, 67.97085151076317, 54.751262068748474, 51.22472830116749, 48.14742922782898, 48.075024113059044, 45.237967148423195, 51.83536313474178, 51.15576960146427, 52.13551662862301, 55.83798475563526, 66.8812295794487, 65.45266583561897, 67.99516260623932, 65.77276825904846, 72.13294297456741, 69.73581120371819, 73.75651985406876, 68.27417403459549, 69.07791450619698, 69.08889591693878, 74.01156216859818, 72.75933176279068, 77.11541041731834, 70.69918870925903, 72.35735893249512, 68.85425850749016, 73.69239449501038, 65.18215075135231, 74.25250723958015, 68.9144092798233, 78.55123177170753, 71.02108463644981, 80.00308066606522, 9.11836501210928, 0.8098663366399705, 1.2413229723460972, 0.4574393149232492, 0.08174355156370439, 32.54991978406906, 75.84800362586975, 74.16192010045052, 53.132944107055664, 47.86851279437542, 30.700103044509888, 26.208516061306, 26.45052507519722, 50.43921545147896, 55.6037425249815, 75.91288894414902, 11.62128310650587, 0.6591062794905156, 0.19696143659530208, 0.07477504463167861, 0.09376763526233844, 0.06346282898448408, 0.17884720000438392, 0.01073407333024079, 0.02657705972524127, 0.07366427220404148, 0.09202631190419197, 0.12648376839933917, 0.1762626410345547, 0.14011580409714952, 0.1539949601283297, 0.1624415654805489, 0.26450820034369826, 0.24780057108728215, 0.25693636445794255, 0.2978420304134488, 0.2876052015926689, 0.5236930644605309, 10.819534678012133, 94.81470867991447, 77.80314311385155, 76.55717477202415, 40.049782544374466, 70.31534850597382, 80.51348447799683, 44.85581025481224, 96.34819239377975, 42.70283818244934, 0.28108908561989665, 1.147771873511374, 7.4820768646895885, 4.684321666136384, 6.623492510989308, 97.16264829039574, 96.83450549840927, 96.9040797650814, 79.89255219697952, 77.67169296741486, 83.56038138270378, 85.4166653752327, 71.06396153569221, 70.75396656990051, 72.64042094349861, 77.34345138072968, 73.804230093956, 76.19227275252342, 71.36387184262276, 77.55671873688698, 70.69365620613098, 72.33398258686066, 71.22521728277206, 75.52572771906853, 73.1032133102417, 80.5940629541874, 72.24233910441399, 75.37431344389915, 64.49357450008392, 58.222550600767136, 58.45689542591572, 59.59360063076019, 59.32290695607662, 57.381074354052544, 58.443060368299484, 58.733417987823486, 60.31514011323452, 60.020800307393074, 56.7126028239727, 54.61448460817337, 58.28132584691048, 58.86896811425686, 53.81602585315704, 63.9093254506588, 67.80106902122498, 72.84019142389297, 69.85228255391121, 63.312343284487724, 56.21888391673565, 64.39487099647522, 70.12961447238922, 70.69334462285042, 65.72428286075592, 67.24881425499916, 70.14847666025162, 71.36923715472221, 66.59892752766609, 70.49394652247429, 68.4993727505207, 69.98253956437111, 70.04886880517006, 64.78218421339989, 63.14059630036354, 70.92267751693726, 62.801973670721054, 58.60372714698315, 56.9531337171793, 55.895749256014824, 54.51399900019169, 66.66368365287781, 67.74996176362038, 62.24421679973602, 58.15986156463623, 59.0297906845808, 56.58906005322933, 57.99736328423023, 58.16555745899677, 57.74254135787487, 60.77404148876667, 64.65578019618988, 64.03446033596992, 64.68275114893913, 63.15030857920647, 64.20306488871574, 62.90598548948765, 63.03246930241585, 63.2816257327795, 63.62515389919281, 60.506980419158936, 65.94968676567078, 62.45139308273792, 67.13982850313187, 63.87423053383827, 59.94074620306492, 71.91622540354729, 66.85431942343712, 57.70564153790474, 52.5172783434391, 52.56871998310089, 51.034476310014725, 47.89297208189964, 54.41979065537453, 53.68972063064575, 55.648321732878685, 59.1032749414444, 72.00002610683441, 67.51651749014854, 71.69677197933197, 69.11018997430801, 76.10168561339378, 71.1228659749031, 76.62905171513557, 70.61788067221642, 73.69819298386574, 71.45140394568443, 76.60078883171082, 75.54764494299889, 80.58654695749283, 75.49447059631348, 74.91490289568901, 72.13937982916832, 78.16750556230545, 68.72459426522255, 78.56746450066566, 72.44887322187424, 82.39055335521698, 73.57086941599846, 81.60374477505684, 7.276373952627182, 4.35825071297586, 6.988187441602349, 0.4956499161198735, 0.35493346222210675, 43.46082530915737, 81.71401485800743, 84.08220738172531, 60.19057519733906, 80.567996352911, 66.36838629841805, 37.52123482525349, 30.747437104582787, 59.098377004265785, 63.07811625301838, 86.11364677548409, 14.75407725200057, 0.7475585269276053, 0.3218132519396022, 0.19100979814538732, 0.1918613532325253, 0.21166476246435195, 0.30233528930693865, 0.1390282905776985, 0.08040237938985229, 0.1553943389444612, 0.16502447688253596], [0.11391226173145697, 0.16626034572254866, 0.0532535672391532, 0.020927345503878314, 0.049495335115352646, 0.0921517274400685, 0.04098973273357842, 0.19187353929737583, 0.07954472384881228, 0.22000709606800228, 0.4603396577294916, 14.621956441551447, 61.981517896056175, 66.23014211654663, 50.58487303555012, 33.6281955242157, 49.3496049195528, 47.45879977941513, 36.96717515587807, 91.40851825475693, 11.905903033912182, 0.10913460442679934, 0.1718221339979209, 2.0951486751437187, 0.6665368401445448, 30.773581601679325, 109.89708736538887, 84.46937620639801, 93.24883550405502, 69.45775732398033, 75.44426769018173, 79.37580272555351, 83.37865993380547, 76.0583147406578, 69.2314338684082, 56.80871866643429, 63.48028667271137, 61.150985062122345, 63.50416839122772, 60.261608585715294, 64.24388989806175, 59.45275738835335, 59.7822605073452, 57.67917975783348, 58.91309514641762, 55.49230210483074, 59.78573352098465, 54.823629185557365, 57.09137789905071, 53.014101684093475, 56.33020654320717, 52.85601116716862, 54.9890723079443, 51.41851410269737, 50.466551184654236, 50.91319441795349, 54.276796728372574, 61.530907675623894, 56.926177963614464, 51.97671554982662, 51.67723461985588, 52.79241397976875, 50.67137539386749, 46.165896356105804, 56.84000998735428, 59.225958958268166, 60.15789695084095, 56.07374310493469, 54.686692133545876, 51.93952314555645, 58.51448133587837, 64.2407588660717, 64.61889937520027, 63.74175064265728, 62.02373743057251, 62.03546740114689, 65.86400136351585, 59.48223240673542, 60.76835319399834, 61.64732202887535, 61.633331179618835, 58.03121566772461, 57.47787795960903, 60.985766127705574, 62.69761607050896, 50.50200328230858, 55.203612595796585, 49.91397723555565, 47.14426785707474, 41.11337207257748, 52.20229044556618, 60.343862771987915, 57.37808011472225, 54.626313373446465, 53.64635355770588, 57.77667112648487, 55.57498946785927, 52.63694912195206, 54.515059143304825, 56.18147872388363, 61.30939096212387, 60.20178459584713, 59.01557184755802, 60.81721857190132, 58.778753355145454, 57.77556538581848, 59.80067431926727, 56.410921812057495, 58.47878985106945, 56.299777776002884, 55.41988179087639, 57.92662627995014, 56.16762846708298, 60.29931016266346, 53.60174775123596, 53.784753531217575, 70.59306800365448, 54.15023311972618, 51.078519746661186, 46.07680253684521, 46.2998353689909, 40.364781841635704, 49.76292014122009, 50.144921243190765, 51.88647799193859, 49.1157578676939, 58.98542046546936, 62.674144729971886, 66.70545861124992, 63.29256534576416, 63.26283574104309, 65.81797063350677, 70.25490894913673, 67.57930532097816, 71.5515285730362, 71.04707524180412, 73.21223706007004, 69.02915552258492, 71.26519873738289, 68.0842374265194, 65.34292012453079, 63.61487165093422, 67.57318764925003, 63.14624659717083, 68.69405150413513, 65.00799849629402, 74.42999571561813, 69.24037098884583, 85.65175116062164, 41.22091010212898, 0.5632066098041832, 1.617650503758341, 0.2399780080304481, 0.0909160367154982, 7.729127733036876, 65.98669677972794, 64.6103498339653, 60.52174262702465, 38.01623046398163, 68.34765449166298, 20.764128305017948, 12.540052905678749, 23.876877576112747, 50.751581490039825, 67.69926488399506, 32.469265311956406, 0.3775891527766362, 0.17665912600932643, 0.07904887272161432, 0.11149175450555049, 0.02002917983190855, 0.10959253922919743, 0.019517834516591392, 0.10909161923336796, 0.011374062523827888, 0.07766051479848102, 0.07309442153200507, 0.09495932405116037, 0.08346408736542799, 0.046226386111811735, 0.020178266167931724, 0.0960821786429733, 0.03259053577494342, 0.146940519916825, 0.09143208168097772, 0.2894002787070349, 0.5208062881138176, 21.794623509049416, 77.6839131116867, 75.09739190340042, 70.57247310876846, 48.85750472545624, 41.25292718410492, 42.74348460137844, 44.906271547079086, 100.94242706894875, 11.755585949867964, 0.04577735708153341, 0.6379451556131244, 0.9435658436268568, 0.9067957510706037, 36.788064166903496, 111.76274925470352, 86.30329459905624, 97.24988400936127, 72.06155240535736, 79.54637557268143, 81.91039592027664, 85.31869903206825, 77.45339468121529, 73.66350844502449, 59.332471042871475, 65.98429530858994, 62.98813708126545, 65.7781183719635, 62.66605116426945, 68.23361501097679, 62.76177562773228, 63.69582250714302, 60.14859884977341, 62.5679100304842, 58.57581004500389, 62.079187855124474, 58.493647053837776, 59.557688757777214, 55.021115988492966, 58.756877928972244, 55.63985578715801, 56.55331917107105, 53.72164651751518, 53.47094736993313, 53.02476391196251, 55.84206573665142, 63.96477207541466, 59.61188904941082, 53.26007008552551, 53.50475795567036, 53.64943139255047, 51.96367844939232, 49.43968668580055, 57.67194114625454, 61.895019337534904, 61.197103187441826, 58.609221652150154, 56.68962925672531, 55.311686396598816, 60.11923782527447, 66.96807771921158, 66.77993461489677, 67.90302515029907, 65.24558454751968, 64.07288387417793, 66.16410925984383, 65.81005945801735, 64.4216899573803, 64.2298686504364, 63.59397657215595, 61.387879550457, 61.79720118641853, 65.04500091075897, 64.90952298045158, 54.248792231082916, 57.99166738986969, 54.19779896736145, 52.27373421192169, 45.728862807154655, 57.09833152592182, 64.14397805929184, 59.94331106543541, 58.03530424833298, 57.066675424575806, 59.47292670607567, 58.71583633124828, 54.89178992807865, 57.37298458814621, 56.55441731214523, 63.39996658265591, 63.184016570448875, 60.96630357205868, 63.758914321660995, 62.14993625879288, 61.59083046019077, 63.98818641901016, 62.17027276754379, 60.768102407455444, 59.58514228463173, 57.588106244802475, 59.27711941301823, 61.02906480431557, 62.53722287714481, 55.36571189761162, 57.81190663576126, 73.18702161312103, 57.06776976585388, 54.68891881406307, 48.30093339085579, 47.88689240813255, 44.67290706932545, 51.227821335196495, 52.86923065781593, 53.81480231881142, 51.4208547770977, 60.5783785879612, 64.80197355151176, 68.62398326396942, 67.80293092131615, 67.2611939907074, 69.7209843993187, 70.95951274037361, 69.96892869472504, 76.1020427942276, 71.69857308268547, 72.320386916399, 70.73501318693161, 73.24275702238083, 68.83639946579933, 68.14025402069092, 66.80707275867462, 69.36293721199036, 66.17165565490723, 69.18122336268425, 69.44296091794968, 76.91559433937073, 74.7362668812275, 87.72097572684288, 49.04484987258911, 1.2681582011282444, 1.0083597293123603, 1.5357749909162521, 0.3008570201927796, 7.356878807768226, 68.4661853313446, 70.9593303501606, 67.19348162412643, 45.55286385118961, 47.44327761232853, 22.856031954288483, 26.408503130078316, 35.877952203154564, 57.332843542099, 74.8645631968975, 40.27060009539127, 0.5792723258491606, 0.22368614474544302, 0.10367305803811178, 0.09964859156752937, 0.031460790341952816, 0.08092261748970486, 0.03867386461934075, 0.030514923128066584, 0.04197449219645932, 0.05550183683226351, 0.21651092742104083, 0.26137512002605945, 0.11316828095004894, 0.18392874451819807, 0.0824955252755899, 0.23936644865898415, 0.16603841388132423, 0.41517065023072064, 0.39690096338745207, 0.4722631210461259, 0.7426623709034175, 25.806892812252045, 92.9988545179367, 82.65815779566765, 73.35563376545906, 50.306606367230415, 62.63140842318535, 67.33800306916237, 54.682421162724495, 111.39660090208054, 15.686433222144842, 0.22479593753814697, 2.7893581241369247, 9.016230292618275, 2.6055090269073844, 39.18284386396408, 115.37050366401672, 90.06009221076965, 102.80537590384483, 75.61858713626862, 81.773162484169, 88.08141678571701, 92.12887600064278, 82.09947377443314, 76.46748438477516, 61.41348257660866, 68.26128512620926, 65.90526714920998, 70.48086762428284, 65.27703166007996, 73.39429289102554, 67.90412709116936, 68.42206209897995, 65.87953492999077, 66.90665021538734, 60.776249170303345, 63.92689570784569, 61.13495372235775, 61.139262691140175, 57.67343446612358, 61.30874119699001, 58.42872753739357, 60.07001906633377, 56.70555420219898, 56.70224837958813, 57.74235516786575, 59.69861939549446, 64.33188557624817, 61.13360099494457, 57.34121449291706, 54.58294250071049, 55.156225338578224, 55.88661074638367, 51.7998768389225, 60.02488508820534, 65.80994546413422, 64.19069275259972, 62.22306713461876, 58.869196102023125, 58.31895902752876, 63.59748758375645, 70.48151358962059, 70.15144810080528, 69.66570496559143, 67.71801307797432, 66.81798577308655, 69.84143033623695, 67.29799121618271, 66.77526846528053, 67.4513889849186, 64.73049938678741, 64.61690068244934, 65.15696570277214, 68.9060041308403, 67.59518086910248, 59.45600241422653, 60.15902169048786, 57.172526344656944, 56.71066492795944, 51.892329677939415, 61.367619037628174, 68.95619943737984, 62.682990655303, 61.70174650847912, 59.790642857551575, 63.09275306761265, 61.06259040534496, 58.0944062769413, 61.82739816606045, 61.13532990217209, 67.0327578485012, 66.39332816004753, 65.03509864211082, 67.77300372719765, 64.09567505121231, 63.66539753973484, 64.7132559120655, 64.5209938287735, 65.18589735031128, 62.6178165525198, 61.28129906952381, 63.82268249988556, 66.45798549056053, 67.35599130392075, 57.02806569635868, 60.78843891620636, 73.78455474972725, 58.77113476395607, 57.4849683791399, 51.60010255873203, 50.21702237427235, 48.12362730503082, 55.14972768723965, 54.872920140624046, 57.873360738158226, 54.3790378421545, 64.30279433727264, 68.88277217745781, 71.2242217361927, 68.4708134829998, 70.43003395199776, 72.37941294908524, 76.84805676341057, 72.48101189732552, 76.19088962674141, 73.90472710132599, 76.92925840616226, 73.87710258364677, 78.30378144979477, 73.6757741868496, 70.32718867063522, 70.3356622159481, 74.11365509033203, 69.0047912299633, 75.1377685368061, 73.51256534457207, 82.7027902007103, 77.33083605766296, 92.17457234859467, 48.11578072607517, 1.266434637364, 6.157025266438723, 1.760650249198079, 0.40066914400085807, 10.968904662877321, 79.93557348847389, 78.45410138368607, 75.80055177211761, 58.07641804218292, 90.53660184144974, 31.180389672517776, 24.01151955127716, 38.94059166312218, 67.38623768091202, 84.2876623570919, 49.6595922857523, 0.8229189924895763, 0.30252323078457266, 0.2764164941618219, 0.23299989028600976, 0.14080248365644366, 0.19159119663527235, 0.19304209534311667, 0.26291344373021275, 0.12105913643608801, 0.19989192544016987], [0.045752977530355565, 0.014315826447273139, 0.01614063214219641, 0.028891254296468105, 0.015914267823973205, 0.0662572450528387, 0.03521115198964253, 0.05293161615554709, 0.00852822211527382, 0.05880379285372328, 0.06651345669524744, 26.07500832527876, 59.32581000030041, 49.78036120533943, 30.4854753613472, 17.118909806013107, 39.6636700630188, 38.62469561398029, 57.12296560406685, 77.69348099827766, 2.116950717754662, 0.0949074627715163, 1.1631876463070512, 2.5562596321105957, 2.298241602256894, 73.06733563542366, 91.91902086138725, 89.62452158331871, 83.51866722106934, 71.09677657485008, 81.49195477366447, 80.79416781663895, 80.12062355875969, 83.94073337316513, 74.27573919296265, 57.88865111768246, 60.04571937024593, 59.486001804471016, 58.96095357835293, 62.402808889746666, 56.86633497476578, 56.4158995449543, 54.904295057058334, 55.72976656258106, 56.06032222509384, 55.295419469475746, 55.8499351143837, 53.25407400727272, 54.99914176762104, 56.29578799009323, 53.50408919155598, 54.41898129880428, 54.47709918022156, 50.38118116557598, 48.57825011014938, 49.55174647271633, 50.32659329473972, 60.09375639259815, 55.05412861704826, 52.22302593290806, 52.70958222448826, 53.27805832028389, 49.540293887257576, 47.42784284055233, 54.00409296154976, 57.61500880122185, 57.58025586605072, 53.6791305989027, 55.788492411375046, 51.230283603072166, 55.44327333569527, 59.34487737715244, 62.25527800619602, 65.19196942448616, 65.10497689247131, 60.75001157820225, 63.471395149827, 60.74295915663242, 61.902839317917824, 60.23712269961834, 57.023969516158104, 59.17901247739792, 54.894837364554405, 60.02806171774864, 59.44577716290951, 44.17543016374111, 45.26091791689396, 48.9081522077322, 52.47470162808895, 47.22629405558109, 45.972878113389015, 56.39472708106041, 55.043523386120796, 57.72413894534111, 60.20955137908459, 57.13089197874069, 52.87377901375294, 47.218432277441025, 48.13050113618374, 48.095486015081406, 51.53948061168194, 55.183177292346954, 58.894552141427994, 58.640471175312996, 60.419417917728424, 61.1582350730896, 60.787173584103584, 57.75053232908249, 59.64878886938095, 59.039225578308105, 56.29163481295109, 58.0655962228775, 59.13145802915096, 56.42186522483826, 52.60616697371006, 52.076653987169266, 63.818441927433014, 59.319186955690384, 50.35502336919308, 46.41075141727924, 45.910390466451645, 43.395776599645615, 42.456064224243164, 49.748746901750565, 48.703183606266975, 51.715551763772964, 48.55431519448757, 62.21082039177418, 64.21711653470993, 67.22596228122711, 66.10203579068184, 66.66040062904358, 64.68104124069214, 67.2509953379631, 68.58711764216423, 65.1877212524414, 66.80638879537582, 66.29656255245209, 65.8054693043232, 66.35165199637413, 63.49878028035164, 66.08171448111534, 64.01130437850952, 63.95235434174538, 60.85761800408363, 65.31446725130081, 68.3075438439846, 73.85956272482872, 72.02965691685677, 82.00484365224838, 7.828448703512549, 0.39633224077988416, 1.5228622150607407, 0.09377162059536204, 0.10351310294936411, 45.259500592947006, 65.15500500798225, 67.32277348637581, 45.783769860863686, 43.35504278540611, 34.12290617823601, 13.056720681488514, 20.46212051063776, 40.64404025673866, 55.108283311128616, 45.89385375380516, 0.8291737537365407, 0.050787562649929896, 0.04052555646921974, 0.02629793612868525, 0.03647368990641553, 0.060474018464447, 0.054307023601722904, 0.02458695733366767, 0.1110150953172706, 0.09630547603592277, 0.02731257631239714, 0.07049559848383069, 0.02338258895179024, 0.026245453300361987, 0.03869929430948105, 0.05155763734364882, 0.0758139623212628, 0.20349019876448438, 0.04651809467759449, 0.06430525565519929, 0.101649132266175, 35.644492730498314, 70.72799876332283, 59.067549258470535, 41.364006623625755, 24.567287229001522, 43.29815223813057, 41.44874207675457, 68.3191180229187, 79.73473906517029, 2.2602844890207052, 0.1076216324872803, 1.473556060809642, 1.2542071309871972, 2.7886162139475346, 80.84719777107239, 94.18534085154533, 93.77060070633888, 83.15645545721054, 76.83116286993027, 83.72558131814003, 84.00524631142616, 84.28469851613045, 86.83875426650047, 77.22751200199127, 63.61949980258942, 62.45421253144741, 62.24839277565479, 62.280140072107315, 64.09780293703079, 58.87173056602478, 59.377396032214165, 59.955364018678665, 59.605581387877464, 59.627722799777985, 59.013751745224, 58.09395030140877, 55.95643199980259, 57.17664152383804, 59.0743774920702, 55.37820562720299, 56.696415692567825, 57.79358021914959, 53.0744044482708, 50.43009594082832, 52.835720255970955, 53.74147765338421, 60.28586648404598, 55.96617087721825, 53.52650038897991, 53.80610078573227, 54.33115281164646, 51.266803443431854, 48.792938590049744, 57.223584204912186, 59.30645003914833, 60.70629872381687, 57.34874568879604, 60.949124693870544, 53.064137399196625, 57.50820033252239, 61.676284074783325, 63.79858419299126, 69.25144359469414, 65.27934953570366, 59.63184177875519, 67.74806186556816, 63.535581305623055, 64.86947312951088, 63.997663110494614, 59.78424020111561, 60.9820157289505, 60.14254577457905, 63.47828038036823, 60.549059361219406, 48.049626275897026, 49.73769709467888, 54.50206384062767, 58.27934995293617, 50.96786968410015, 48.38858708739281, 60.10231353342533, 60.202415362000465, 59.395061284303665, 62.205854058265686, 60.781755074858665, 54.7402236610651, 48.42656224966049, 49.973827823996544, 51.19403354823589, 54.63704779744148, 57.60602608323097, 61.81952878832817, 62.10096828639507, 62.557863369584084, 63.00340846180916, 62.054682970047, 61.9183386862278, 62.72232614457607, 61.951966881752014, 59.56955552101135, 59.21234428882599, 60.595964044332504, 60.46477608382702, 56.93647541105747, 53.50620187819004, 65.72260335087776, 63.10446783900261, 53.82819280028343, 48.62399585545063, 47.910519540309906, 45.9296440333128, 44.80832040309906, 52.82260335981846, 49.71015617251396, 54.65244457125664, 51.32787376642227, 63.14043290913105, 66.46689221262932, 68.07958647608757, 68.73742997646332, 68.53303894400597, 67.71230578422546, 69.67839628458023, 69.39250722527504, 67.96715050935745, 68.42898532748222, 71.71593055129051, 69.00361329317093, 69.53987091779709, 66.22010305523872, 68.25065329670906, 65.6041257083416, 67.36053586006165, 61.784228682518005, 68.32296341657639, 70.81328138709068, 77.4805100262165, 75.35836949944496, 88.20919632911682, 12.091473676264286, 0.4231752175837755, 1.0289834789000452, 0.1013613941904623, 0.15618169825756922, 47.77390547096729, 73.7005640566349, 73.01876664161682, 54.694075137376785, 41.58709265291691, 30.719240717589855, 22.39292610436678, 26.050790324807167, 49.73536781966686, 64.70989689230919, 55.98684936761856, 0.7650744589045644, 0.06884501752210781, 0.04976830074156169, 0.020935256798111368, 0.061352814082056284, 0.036909820410073735, 0.06088394373364281, 0.10047161107650027, 0.03404242896067444, 0.17998231487581506, 0.1684117130935192, 0.20587918697856367, 0.0739969547430519, 0.16000128001905978, 0.10342614550609142, 0.20646499382564798, 0.14400314394151792, 0.30356146569829434, 0.08575255167670548, 0.21963473089272156, 0.31628309399820864, 43.854883164167404, 85.83208188414574, 66.76721289753914, 42.57304474711418, 27.833312675356865, 55.46370483934879, 56.91467598080635, 75.14861315488815, 91.31486847996712, 3.9663789281621575, 0.2738520473940298, 4.091191068291664, 7.8245980851352215, 4.570629866793752, 84.97365474700928, 96.59538432955742, 98.197211176157, 88.60782533884048, 79.72318768501282, 86.89692914485931, 87.77155101299286, 87.18414053320885, 91.01991310715675, 81.22437313199043, 65.72167620062828, 66.63432642817497, 66.1635772883892, 65.3421601653099, 69.9065588414669, 63.730195462703705, 60.91091014444828, 63.237198516726494, 63.15994866192341, 62.439347729086876, 62.645486667752266, 62.21728004515171, 58.407714664936066, 61.952403858304024, 62.87521094083786, 59.64321456849575, 59.138259664177895, 60.27657978236675, 56.12509734928608, 53.77314135432243, 56.048945635557175, 56.29291154444218, 63.66000562906265, 59.12618391215801, 56.16949036717415, 55.08510075509548, 58.6032559722662, 55.69490343332291, 50.46533145010471, 59.84389320015907, 62.36901730298996, 64.43106025457382, 59.8269385099411, 62.46671766042709, 55.86890369653702, 61.78061507642269, 68.07531550526619, 66.69950053095818, 71.45975589752197, 69.57832485437393, 64.97551783919334, 70.67485481500626, 65.49278408288956, 67.67157956957817, 67.65910103917122, 63.85073259472847, 64.7158245742321, 62.638111263513565, 66.14845409989357, 67.04245492815971, 52.5830452144146, 56.11370176076889, 57.90490284562111, 61.973029151558876, 55.94904899597168, 53.176223784685135, 63.61638016998768, 62.78228312730789, 62.8696708381176, 64.01733085513115, 64.76180210709572, 58.93946573138237, 53.49177785217762, 54.3077726662159, 55.089158937335014, 59.38990496098995, 62.003625109791756, 65.31824424862862, 64.82043296098709, 68.07527750730515, 68.25747773051262, 65.49289047718048, 63.10387887060642, 66.88758283853531, 65.53727969527245, 62.83419594168663, 62.79331013560295, 65.29915407299995, 63.49765934050083, 59.034046456217766, 55.91081164777279, 70.54341986775398, 62.83433273434639, 56.42607539892197, 52.40659028291702, 53.468895480036736, 49.14617523550987, 49.59216870367527, 55.928636491298676, 53.89072224497795, 57.28391356766224, 52.31483280658722, 65.50194159150124, 68.98127049207687, 71.91551864147186, 69.63982075452805, 70.80639615654945, 70.31379818916321, 71.41415074467659, 73.26668053865433, 69.66531738638878, 73.04304733872414, 73.84175688028336, 73.43632623553276, 74.28757935762405, 70.89645892381668, 72.95559883117676, 71.22099950909615, 69.91346687078476, 66.20535224676132, 72.26725056767464, 75.0947168469429, 81.23080998659134, 77.70684868097305, 87.56716758012772, 11.207430213689804, 1.5935742831788957, 3.869209117256105, 0.18889754195697606, 0.2895250782603398, 60.83784766495228, 79.42825511097908, 81.07044339179993, 61.39386422932148, 59.96289901435375, 46.10204078257084, 22.117761969566345, 33.25545072555542, 59.13175441324711, 72.36261785030365, 69.34936434030533, 1.1598270828835666, 0.19039806065848097, 0.14863925141980872, 0.26556878874544054, 0.08897841529687867, 0.21149492939002812, 0.14868910890072584, 0.22394536208594218, 0.2743990992894396, 0.26633527886588126], [0.06114747666288167, 0.07372025240329094, 0.11644296304439195, 0.06452908739447594, 0.04573889898892958, 0.019694990733114537, 0.06360750325256959, 0.04773083819600288, 0.10764662802102976, 0.03883925222908147, 0.4131668811896816, 18.425883874297142, 62.56984032690525, 48.533085733652115, 56.33128568530083, 34.659247398376465, 37.967281490564346, 34.23307366669178, 76.66296869516373, 54.486393481492996, 0.16907433222513646, 0.26359523995779455, 0.31215316092129797, 0.6650283210910857, 18.51981483399868, 94.10874456167221, 84.46848705410957, 88.71343687176704, 73.27350497245789, 73.11932444572449, 81.98843613266945, 84.7845084965229, 77.28982105851173, 85.90589672327042, 76.82755306363106, 67.90148243308067, 56.35911539196968, 59.236917570233345, 57.489604130387306, 59.11663502454758, 53.8894797116518, 58.362428694963455, 54.80484299361706, 58.89418736100197, 57.08075746893883, 57.20631793141365, 55.57036891579628, 53.884277790784836, 54.0866207331419, 54.5814073830843, 53.024820908904076, 54.61996391415596, 52.506775707006454, 47.16475635766983, 46.43440134823322, 51.9346784055233, 53.24644781649113, 57.699394673109055, 51.87764346599579, 50.44220209121704, 49.597522616386414, 48.64355340600014, 48.52032981812954, 45.55981747806072, 50.20620055496693, 56.65942847728729, 54.876666739583015, 55.61464414000511, 55.229071229696274, 50.99086605012417, 53.10362108051777, 55.499327927827835, 62.09265433251858, 68.0538010597229, 57.909496799111366, 48.54943625628948, 62.489022463560104, 62.3079089820385, 60.08739173412323, 58.29263783991337, 53.67963597178459, 56.85764104127884, 57.57729582488537, 58.32203306257725, 54.23880636692047, 38.64886611700058, 42.9092925041914, 49.300538152456284, 49.620693773031235, 46.90697059035301, 42.15187914669514, 53.03223431110382, 53.68042632937431, 57.83156298100948, 58.68745185434818, 56.34413659572601, 49.216004088521004, 46.99500806629658, 47.22703121602535, 50.614712834358215, 51.52108959853649, 50.566451624035835, 47.98822917044163, 50.78780494630337, 58.376191556453705, 58.12271475791931, 56.03197194635868, 61.76383137702942, 58.9574159681797, 58.07831414043903, 56.57593935728073, 57.717196717858315, 55.269478261470795, 61.18031568825245, 52.86959923803806, 49.276040866971016, 58.00378113985062, 60.46051651239395, 53.25256168842316, 47.74043306708336, 44.76296603679657, 44.34198662638664, 39.41143199801445, 48.141455948352814, 49.69178795814514, 51.419483050704, 48.617722392082214, 51.563787907361984, 59.893347546458244, 64.93473842740059, 62.89501167833805, 67.42723748087883, 67.39769026637077, 67.906224578619, 67.08933681249619, 69.10772770643234, 64.92194831371307, 64.12268400192261, 63.28987509012222, 65.53428545594215, 59.409154728055, 64.8217324912548, 62.52043537795544, 63.28820317983627, 57.183006182312965, 63.69047999382019, 67.8823846578598, 77.48725846409798, 72.346111536026, 90.89992314577103, 37.40675076842308, 0.10741961988969706, 1.6225339542143047, 0.2836871665203944, 0.4670817428268492, 14.202021025121212, 68.39763700962067, 62.94179476797581, 57.05567501485348, 42.92036511003971, 43.18093232810497, 26.931317076086998, 42.05634847283363, 45.506164357066154, 51.028620824217796, 55.541988238692284, 4.975912319496274, 0.02458327442582231, 0.055893145326990634, 0.10827921985764988, 0.07648884173249826, 0.0159739587616059, 0.03544521423464175, 0.050304903197684325, 0.07417968634399585, 0.014475637744908454, 0.06360431943903677, 0.03471531941613648, 0.026006837979366537, 0.029956464422866702, 0.040765696903690696, 0.032008046327973716, 0.042536483524600044, 0.029220712203823496, 0.06603489018743858, 0.07146511052269489, 0.38881309737917036, 27.493077032268047, 78.12264516949654, 56.58659018576145, 54.95604448020458, 33.234608843922615, 38.18534038960934, 41.37391269207001, 86.50241911411285, 55.02017363905907, 0.19883924833266065, 0.7592975220177323, 0.2848263632040471, 0.8762626082170755, 19.696265906095505, 107.12023437023163, 84.33570697903633, 93.65308061242104, 73.39224860072136, 75.98959922790527, 84.8715390264988, 87.73849278688431, 79.10774990916252, 87.6188676059246, 79.86580163240433, 69.55431014299393, 58.67928609251976, 63.32394786179066, 60.46666078269482, 63.23390409350395, 58.16792853176594, 60.84460370242596, 58.44429150223732, 61.14017464220524, 57.9084100574255, 58.66417810320854, 57.78500787913799, 57.120723724365234, 55.87670087814331, 56.74019314348698, 54.353263825178146, 55.99279224872589, 54.482198506593704, 52.56562314927578, 50.166941061615944, 54.54411618411541, 53.796871080994606, 59.224397242069244, 55.18174096941948, 52.163099348545074, 50.71587860584259, 52.38545581698418, 52.186844274401665, 48.42091955244541, 51.498180627822876, 57.542546689510345, 57.422374337911606, 58.62593695521355, 56.896216571331024, 52.548193484544754, 53.05687598884106, 59.242028295993805, 64.49877262115479, 69.49368059635162, 60.26703469455242, 50.940682142972946, 65.64334720373154, 65.38801610469818, 61.74673229455948, 60.72006918489933, 57.61885039508343, 61.090891286730766, 62.186463698744774, 62.07151986658573, 58.05330388247967, 44.353564605116844, 50.0976137816906, 51.12710393965244, 53.572063744068146, 49.90477792918682, 46.845087110996246, 55.74765980243683, 55.93686304986477, 61.51725880801678, 63.47873255610466, 61.30179896950722, 52.58588366210461, 50.97383916378021, 50.37663660943508, 54.63567607104778, 55.38976840674877, 51.209555715322495, 49.82949636876583, 53.58868405222893, 61.24353289604187, 59.420215934515, 60.31270444393158, 65.12283593416214, 61.368185207247734, 60.724146366119385, 59.641322270035744, 61.66841849684715, 58.424950540065765, 65.67062214016914, 57.6675333827734, 49.62438717484474, 63.268079459667206, 62.55757838487625, 55.20286023616791, 50.67471161484718, 48.13645161688328, 47.54493735730648, 43.345611691474915, 49.81475695967674, 53.12854774296284, 52.288040444254875, 50.696803629398346, 53.01164321601391, 58.86029317975044, 67.97655880451202, 65.0314812362194, 70.55063188076019, 68.73622924089432, 68.84047284722328, 69.48897644877434, 72.4034808576107, 67.64329388737679, 67.2907792031765, 66.06623411178589, 67.82697603106499, 62.852792143821716, 66.90241724252701, 64.75190743803978, 64.51073437929153, 59.04997140169144, 66.7183855175972, 68.77881735563278, 80.11529624462128, 75.93284547328949, 91.72286778688431, 43.407172188162804, 0.2822763141011819, 1.5804943162947893, 0.49618642951827496, 0.25578297791071236, 12.713544946163893, 76.7978386580944, 68.30587193369865, 66.832774579525, 48.56993615627289, 37.53661260008812, 25.186021327972412, 50.985040962696075, 58.34881782531738, 57.16144993901253, 67.40931764245033, 6.513710701838136, 0.34603056963533163, 0.16755028744228184, 0.031780195859028026, 0.07842555773095228, 0.04793893269379623, 0.10560918773990124, 0.04793776010046713, 0.12217143026646227, 0.02298558632901404, 0.33674015721771866, 0.19946179148973897, 0.23702685779426247, 0.1349282660521567, 0.10980381382978521, 0.15106479782843962, 0.1386611204361543, 0.13776514038909227, 0.1267128248582594, 0.13241116830613464, 0.5096356000285596, 41.17138355970383, 90.2853213250637, 66.29870563745499, 71.03094890713692, 45.52234388887882, 54.12243761122227, 53.92949916422367, 92.66025468707085, 66.51012629270554, 0.3408125590067357, 0.87307647918351, 2.6572135649621487, 2.3689154349267483, 22.874134182929993, 108.43210637569427, 90.62683939933777, 95.70193827152252, 78.3989055454731, 78.99526074528694, 87.5763326883316, 90.3357370197773, 84.11398887634277, 90.52132666110992, 84.373499751091, 72.91311711072922, 62.5525626540184, 65.75686991214752, 64.2892974615097, 65.33392980694771, 61.671139150857925, 64.25519809126854, 62.591255977749825, 65.38395792245865, 62.12926156818867, 62.045616656541824, 61.3481754809618, 58.77103976905346, 59.71232146024704, 59.745212495326996, 56.36434391140938, 61.38335779309273, 58.25411170721054, 55.00729613006115, 53.0162637680769, 58.3781598508358, 57.88843832910061, 60.48956215381622, 57.334933429956436, 53.28746661543846, 52.674008533358574, 54.20773163437843, 54.00268703699112, 50.444177985191345, 56.19615353643894, 62.31227494776249, 61.042329892516136, 62.7302411198616, 61.50379233062267, 56.134053468704224, 56.460744738578796, 62.57474206387997, 67.3199388384819, 72.09937557578087, 62.46753841638565, 53.35131078958511, 66.11894488334656, 67.85704001784325, 67.20247194170952, 64.21058848500252, 59.1857685148716, 64.81166303157806, 64.73153293132782, 66.11412674188614, 62.15047962963581, 48.59425865113735, 53.93108747899532, 57.808274030685425, 55.82893744111061, 52.53987953066826, 49.68904830515385, 59.4241601228714, 59.933815374970436, 63.761923760175705, 66.69590592384338, 63.54743666946888, 55.12698590755463, 54.2696987092495, 54.48884055018425, 56.26485764980316, 57.28935867547989, 56.25570014119148, 54.94454629719257, 58.782518953084946, 61.974032297730446, 63.45226317644119, 62.241138964891434, 67.09052234888077, 64.91893887519836, 64.44040775299072, 61.51858493685722, 65.78224495053291, 61.51904471218586, 68.27978253364563, 61.98888190090656, 51.576642617583275, 66.03066802024841, 67.69427955150604, 57.62522265315056, 51.938550397753716, 53.20941120386124, 50.82911252975464, 45.55406078696251, 53.10972735285759, 55.6979850679636, 56.27667501568794, 52.13537223637104, 56.07041448354721, 61.61626249551773, 69.53806221485138, 68.42674344778061, 72.34202295541763, 72.02800780534744, 72.64441832900047, 73.03695246577263, 76.24792456626892, 71.83019801974297, 69.64111268520355, 69.83508467674255, 71.86287626624107, 65.91156721115112, 69.88530278205872, 68.13292801380157, 69.79474604129791, 62.04568885266781, 70.08127346634865, 74.05436307191849, 86.25331968069077, 80.46360075473785, 94.13918852806091, 45.121397003531456, 0.35605603479780257, 7.363477628678083, 1.530131937470287, 0.5897736561018974, 19.22923866659403, 85.06649136543274, 76.91177934408188, 72.4906937777996, 61.748468801379204, 57.936361357569695, 38.13117429614067, 55.056549087166786, 63.4809136390686, 68.07378798723221, 77.96210378408432, 10.010149609297514, 0.5775200261268765, 0.3620416932972148, 0.2221945466590114, 0.3533498081378639, 0.12538395007140934, 0.16212354035815224, 0.21346276364056394, 0.18996089114807546, 0.1135302337934263], [0.04119715187698603, 0.012623739949049195, 0.025917772836692166, 0.146360041690059, 0.09549142909236252, 0.04156920906098094, 0.07213340708403848, 0.040614985264255665, 0.10118340491317213, 0.15764778130687773, 1.0195813584141433, 11.947620045393705, 58.85572202503681, 47.240007519721985, 46.52077071368694, 29.30523209273815, 54.8367764800787, 35.363596603274345, 93.14903765916824, 24.50811680406332, 0.1268721342785284, 0.12209728971356526, 0.5641807825304568, 1.1762569262646139, 49.99775134027004, 93.91465097665787, 87.61468783020973, 84.53382834792137, 67.92012423276901, 73.0757787823677, 82.89189845323563, 93.25341805815697, 77.06225126981735, 84.62035730481148, 81.96651130914688, 70.78267022967339, 57.79231868684292, 57.05872245132923, 57.014872804284096, 58.38379494845867, 54.580495432019234, 55.82709074020386, 53.97731579840183, 55.36319263279438, 55.06295174360275, 56.01633958518505, 53.48055325448513, 54.46087785065174, 51.754963248968124, 54.73178431391716, 55.85017830133438, 57.31254503130913, 53.66605170071125, 49.222703129053116, 49.23264339566231, 50.38379542529583, 54.709631502628326, 56.7419296503067, 51.3935836404562, 48.05190995335579, 48.691932410001755, 50.17167180776596, 48.84264752268791, 47.65378251671791, 47.29085259139538, 51.26456156373024, 51.33538216352463, 53.308376893401146, 51.127818301320076, 50.08499085903168, 50.39310112595558, 52.82984957098961, 58.577451556921005, 64.96080502867699, 63.90054792165756, 58.903903439641, 57.3719472438097, 61.65237955749035, 58.70488531887531, 57.65815168619156, 58.56050826609135, 63.741317465901375, 56.880249828100204, 63.03909234702587, 48.38865548372269, 41.846162751317024, 49.47624832391739, 45.118121579289436, 44.75967921316624, 45.938535556197166, 43.971616700291634, 47.64972813427448, 50.0663148611784, 60.02324357628822, 60.719996988773346, 54.80125978589058, 55.413517132401466, 54.66537147760391, 55.39315402507782, 59.42255660891533, 61.92617006599903, 59.326391369104385, 56.900479942560196, 60.07344648241997, 54.44618783891201, 53.827432841062546, 61.10307723283768, 59.65943589806557, 59.341818541288376, 58.08662049472332, 58.71596172451973, 58.97995635867119, 60.152189657092094, 57.52487003803253, 54.49014388024807, 51.897166818380356, 56.135170608758926, 59.741986468434334, 54.37630198895931, 47.818910256028175, 45.18049903213978, 43.81446473300457, 43.147155940532684, 43.481211215257645, 51.557605639100075, 49.40170772373676, 51.55692167580128, 48.030030727386475, 51.80268868803978, 60.599266067147255, 64.29125815629959, 63.24210025370121, 66.86375811696053, 64.67070579528809, 68.75524342060089, 63.69457237422466, 65.64970806241035, 62.33469754457474, 61.93362146615982, 61.25920705497265, 60.66174231469631, 59.80185225605965, 58.62366087734699, 58.093562722206116, 57.826076075434685, 58.82156565785408, 70.55145263671875, 69.42938044667244, 82.12337449193001, 80.78934207558632, 60.00931732356548, 4.568573227152228, 0.10316006329958327, 0.11778755651903339, 0.046142464052536525, 1.3087330176495016, 53.18885050714016, 65.48079952597618, 63.65502029657364, 46.9890271872282, 47.25398316979408, 31.923147216439247, 13.469600826501846, 39.04012732207775, 50.55680014193058, 52.669600769877434, 12.213886957615614, 0.2843952347757295, 0.10646045338944532, 0.037546379026025534, 0.05752633776864968, 0.1360143843339756, 0.08719020304852165, 0.07932982756756246, 0.028145716860308312, 0.0360472592728911, 0.09526151174213737, 0.045588150242110714, 0.027965621738985647, 0.08643167617265135, 0.0806597487826366, 0.05678487286786549, 0.037730361145804636, 0.03437069201027043, 0.06576054787728935, 0.17374112008837983, 1.053062193095684, 26.072414964437485, 69.40326824784279, 56.06040962040424, 56.397269144654274, 26.39778010547161, 53.1636768579483, 45.32035432755947, 102.49516814947128, 25.285169407725334, 0.154020786867477, 0.7750586012843996, 2.0740754809230566, 0.8509542443789542, 57.580088675022125, 101.7498229444027, 89.58631083369255, 87.30641037225723, 68.97022068500519, 77.85016939043999, 86.58722296357155, 94.29227471351624, 80.28137773275375, 87.18658000230789, 81.37989118695259, 75.40979593992233, 60.1968714594841, 60.83393007516861, 58.28242018818855, 62.151554971933365, 57.300366684794426, 59.709957987070084, 56.675106436014175, 56.786892637610435, 58.2703672349453, 59.22400586307049, 56.89959838986397, 55.561359599232674, 54.07087817788124, 57.4872862547636, 56.91632889211178, 60.04164598882198, 56.7444983124733, 51.229751631617546, 50.215536653995514, 53.63111637532711, 56.489710584282875, 59.83826570212841, 51.30540557205677, 48.75767268240452, 50.88696822524071, 48.93611490726471, 50.52201300859451, 49.54576559364796, 49.97003182768822, 54.43240597844124, 55.07661961019039, 56.6418544203043, 55.34670911729336, 51.40496402978897, 53.49670618772507, 55.90378202497959, 61.760422959923744, 68.97822305560112, 66.83828428387642, 62.430710792541504, 59.10714693367481, 62.490720972418785, 58.79349276423454, 61.1896213889122, 61.56034089624882, 66.50394782423973, 61.315774619579315, 64.3546311557293, 51.400757655501366, 48.54778714478016, 52.659010738134384, 48.12820985913277, 48.64614486694336, 50.47343261539936, 47.43773750960827, 49.0480986982584, 51.50381192564964, 63.25231410562992, 63.11150126159191, 59.336422830820084, 57.987084835767746, 56.989824548363686, 58.7862541526556, 61.875587180256844, 64.97768372297287, 62.72815503180027, 59.96185027062893, 62.981814220547676, 57.257592380046844, 57.92729504406452, 64.27108883857727, 61.45185671746731, 62.67315298318863, 61.748427003622055, 62.5224644690752, 60.80081485211849, 62.907011434435844, 60.70265091955662, 57.00848154723644, 52.78869017958641, 59.84684184193611, 63.51055584847927, 57.953794822096825, 49.626328870654106, 47.660629749298096, 46.49752356112003, 47.00259625911713, 45.47114923596382, 53.32229174673557, 50.87762072682381, 53.20022329688072, 50.3157714754343, 54.22332599759102, 61.51342861354351, 65.40328368544579, 65.00177443027496, 68.1572163105011, 66.12723603844643, 68.84739607572556, 68.14563453197479, 69.43548291921616, 66.32528141140938, 64.28233623504639, 63.692079707980156, 64.73073497414589, 62.13338054716587, 60.327440053224564, 60.94412796199322, 59.12159375846386, 60.865825563669205, 71.69449970126152, 72.87172973155975, 82.17338740825653, 83.45796927809715, 64.46852624416351, 7.6679894886910915, 1.0651345015503466, 1.4280324848368764, 0.09492298850091174, 1.191227885428816, 57.386504262685776, 74.51962530612946, 68.79713237285614, 58.04593227803707, 39.3745169788599, 22.64159996062517, 22.614744901657104, 45.1481019705534, 57.44473993778229, 65.67460432648659, 15.910691488534212, 0.43719970097299665, 0.09574836803949438, 0.10986848457832821, 0.10618270462146029, 0.057921049010474235, 0.06382303035934456, 0.034240834720549174, 0.018915030632342678, 0.018241069628857076, 0.22228836896829307, 0.1871255159494467, 0.1265703176613897, 0.35850351909175515, 0.22915477864444256, 0.1304217375582084, 0.1592265223735012, 0.11151301703648642, 0.18582355143735185, 0.3111276315758005, 1.5756837744265795, 42.72952415049076, 81.03429213166237, 66.9793327152729, 67.64895558357239, 43.11963401734829, 77.68908843398094, 51.220962703228, 109.85187739133835, 30.27686845511198, 0.17610083799809217, 0.9649822663050145, 4.933396400883794, 2.4208111502230167, 63.27423892915249, 103.77840489149094, 95.46570494771004, 92.98785030841827, 76.17419332265854, 80.5654276907444, 90.07902279496193, 92.41154283285141, 85.1043601334095, 90.430838316679, 87.00946390628815, 77.01760366559029, 62.07283839583397, 63.2230518758297, 60.66043898463249, 65.91853603720665, 59.87711101770401, 62.5748560577631, 60.31363919377327, 59.28087741136551, 61.13443695008755, 62.55092114210129, 58.6564265191555, 59.40486095845699, 56.22288130223751, 58.51315140724182, 61.1714393645525, 61.5199376642704, 58.97985756397247, 54.73210729658604, 54.64038401842117, 55.3266803920269, 59.642215222120285, 58.88837367296219, 53.5468976944685, 50.00222370028496, 51.949774995446205, 52.069947347044945, 55.300169214606285, 52.625739723443985, 53.2271334528923, 57.86607272922993, 57.784460708498955, 59.117147997021675, 56.66746884584427, 54.83931474387646, 56.742412224411964, 59.12072740495205, 62.879991084337234, 70.68668738007545, 70.16385063529015, 63.57595033943653, 62.33683302998543, 65.75597316026688, 62.92227141559124, 65.50724610686302, 64.76983487606049, 67.46266677975655, 64.16447415947914, 68.8587574660778, 57.088026478886604, 53.893366903066635, 57.39180877804756, 50.446579456329346, 50.95180034637451, 54.384235963225365, 51.928028762340546, 53.03259529173374, 53.93900625407696, 66.5280157327652, 67.36343130469322, 62.99746558070183, 60.74260197579861, 59.239619225263596, 62.56558455526829, 66.24360099434853, 68.9241823554039, 65.41794329881668, 60.956363305449486, 64.06511709094048, 61.913987919688225, 62.16405630111694, 65.2766440808773, 65.73637381196022, 66.82515978813171, 65.52371442317963, 64.6860645711422, 63.39174002408981, 67.64492020010948, 63.455249816179276, 58.94271455705166, 55.40731966495514, 64.13470655679703, 67.11090445518494, 60.123463198542595, 51.76071994006634, 49.7164486348629, 48.55477496981621, 50.75971685349941, 47.55580857396126, 56.16045445203781, 55.418369472026825, 55.77725261449814, 52.84497655928135, 58.139354065060616, 65.15625894069672, 69.87177550792694, 68.92690300941467, 72.8511880338192, 69.9507124722004, 75.40121600031853, 70.72146311402321, 72.9636999964714, 69.50989052653313, 67.48531356453896, 67.7040222287178, 67.12143748998642, 63.82937774062157, 64.31186825037003, 64.96954455971718, 64.86577212810516, 65.87622910737991, 74.97821509838104, 75.40949955582619, 83.94144773483276, 86.32420867681503, 69.54595059156418, 6.146397236734629, 2.567976303398609, 3.1198608269914985, 0.17264006979530677, 2.7900731982663274, 67.30131983757019, 80.7801465690136, 77.49518483877182, 66.19874060153961, 66.24233946204185, 49.08366858959198, 22.009792663156986, 53.12436416745186, 66.59229308366776, 78.85889366269112, 21.81075744330883, 0.6059173867106438, 0.2122553635854274, 0.2027043534326367, 0.2285978858708404, 0.21781255054520443, 0.17351776332361624, 0.25182718236465007, 0.0938116223551333, 0.10211310815066099], [0.029298368681338616, 0.054426624410552904, 0.05000245204428211, 0.051313849253347144, 0.041793601121753454, 0.05887289051315747, 0.027275780630588997, 0.01417438330463483, 0.014810420561843785, 0.06786174606531858, 0.48294636653736234, 33.59568826854229, 50.76606251299381, 50.70263251662254, 31.13611824810505, 45.38330934941769, 51.34016990661621, 45.29575064778328, 89.51077088713646, 9.840909540653229, 0.12441174403647892, 0.09105576085858047, 1.4482863480225205, 4.700704487040639, 73.88369143009186, 90.18879890441895, 88.49557936191559, 77.20478162169456, 67.73193553090096, 81.08454823493958, 77.11849585175514, 88.42307165265083, 82.58893311023712, 78.9843325316906, 81.33566915988922, 74.7125181555748, 61.69159345328808, 57.97035813331604, 58.54814752936363, 54.95028778910637, 54.440412148833275, 54.86520275473595, 54.77601774036884, 56.809402629733086, 55.35864047706127, 53.00161175429821, 53.089075461030006, 54.68094304203987, 52.4305783957243, 53.928233832120895, 54.49912279844284, 55.52760221064091, 50.5764564871788, 46.948958337306976, 51.18833005428314, 48.986686393618584, 54.61763083934784, 54.74960155785084, 50.64061984419823, 45.39459474384785, 48.671592101454735, 45.898177921772, 49.100729674100876, 46.91472217440605, 47.1465515345335, 47.50719018280506, 51.351056322455406, 51.72592140734196, 54.49047066271305, 49.95653875172138, 51.213503703475, 53.09757560491562, 55.84594912827015, 62.30768099427223, 66.63891658186913, 65.72816625237465, 59.53877717256546, 62.46873535215855, 61.24596856534481, 59.43602308630943, 58.77018481492996, 59.60034906864166, 64.94200363755226, 60.69514252245426, 46.10413447022438, 44.448939487338066, 46.96237161755562, 43.9673875272274, 42.45029613375664, 40.924168825149536, 42.276330068707466, 37.75572404265404, 47.74417966604233, 50.73414422571659, 58.05395744740963, 64.45583492517471, 58.64770978689194, 56.04949280619621, 57.65378192067146, 56.199482157826424, 51.44661359488964, 56.32539980113506, 59.55127850174904, 52.699854746460915, 52.42682799696922, 59.82024326920509, 60.36675654351711, 60.39903201162815, 60.573172867298126, 58.558558970689774, 58.44463348388672, 58.588265776634216, 62.68798738718033, 61.755012050271034, 50.52275776863098, 51.800678595900536, 53.596416637301445, 58.23646925389767, 58.665226846933365, 50.51725946366787, 47.77428925037384, 45.38347274065018, 45.14416918158531, 42.829831168055534, 49.39780913293362, 48.811599388718605, 52.12609313428402, 48.0986512452364, 51.355806067585945, 51.65471702814102, 57.57996328175068, 60.89910417795181, 66.65792316198349, 63.708654418587685, 68.53199020028114, 63.43647502362728, 62.22968637943268, 57.15723976492882, 58.51288162171841, 53.673826083540916, 57.30751410126686, 54.30034026503563, 57.02193282544613, 53.223174065351486, 59.16228197515011, 54.96116280555725, 71.28543645143509, 69.48901444673538, 82.52235308289528, 69.26383852958679, 74.02717173099518, 21.540966220200062, 0.32043238228652626, 0.10048855430795811, 0.5383568932302296, 0.182850893761497, 24.802667498588562, 65.95572084188461, 64.16488453745842, 49.514626264572144, 51.036380007863045, 52.654861360788345, 29.97313365340233, 39.80785332620144, 47.03509971499443, 50.70223353803158, 16.116572991013527, 0.16400115913711488, 0.07008763248450123, 0.04985665342246648, 0.13458741246722639, 0.04130094494030345, 0.04603324588970281, 0.07109160243999213, 0.025574852370482404, 0.06991557296714745, 0.06471288768807426, 0.02773601794615388, 0.00940091913435026, 0.09675712484749965, 0.025881815781758633, 0.021788533667859156, 0.059779178991448134, 0.05972106140688993, 0.03599110095819924, 0.059072309304610826, 0.7734995568171144, 48.40819023549557, 63.278205916285515, 63.03332045674324, 39.17789272964001, 40.30140124261379, 49.91265870630741, 57.293033078312874, 94.01779264211655, 10.745840482413769, 0.4085645265877247, 1.486847153864801, 2.610162114724517, 3.462478704750538, 88.88381972908974, 94.66712459921837, 92.71110355854034, 78.35596784949303, 70.53409516811371, 80.38214072585106, 79.6546621620655, 92.42451533675194, 84.41813975572586, 82.94546037912369, 83.83439227938652, 77.15346157550812, 63.7523178756237, 59.55012336373329, 60.44174171984196, 55.93038059771061, 56.71252682805061, 54.939264580607414, 58.44858907163143, 59.127677232027054, 57.3563376814127, 56.05940267443657, 56.96188844740391, 56.32576838135719, 54.95953269302845, 55.69242596626282, 55.899378061294556, 58.56972277164459, 52.57617898285389, 49.7338593006134, 54.81372691690922, 50.39587117731571, 58.04851233959198, 56.36387273669243, 51.796878799796104, 48.67646723985672, 50.70945315063, 47.718356251716614, 53.09148833155632, 49.03605714440346, 48.234094977378845, 50.73323607444763, 53.32422584295273, 54.772400334477425, 56.21307782828808, 51.87394626438618, 55.33438637852669, 57.3646592348814, 58.58266867697239, 65.75807064771652, 67.43478387594223, 68.22054371237755, 61.11897557973862, 62.98383571207523, 65.87686747312546, 61.25311218202114, 62.771240919828415, 62.357918098568916, 67.19741061329842, 61.12798869609833, 50.6157311797142, 48.62610474228859, 48.9293322712183, 46.84147730469704, 44.31921064853668, 44.0734626352787, 43.71869847178459, 39.59059998393059, 49.27733279764652, 53.03116276860237, 59.846621453762054, 67.44914710521698, 63.479636907577515, 60.83474323153496, 61.26905232667923, 58.9151356369257, 52.254845425486565, 58.406057953834534, 59.09306488931179, 56.29942439496517, 57.28518649935722, 61.63204304873943, 63.06392781436443, 64.27184119820595, 64.30278673768044, 61.213077530264854, 60.66607408225536, 60.627228766679764, 65.42035236954689, 65.73271840810776, 51.44970282912254, 54.83426481485367, 60.046631321311, 60.706849694252014, 60.06585069000721, 52.17868611216545, 49.71022076904774, 48.56570318341255, 47.77290992438793, 45.34807004034519, 50.11040009558201, 50.84358595311642, 53.56890231370926, 50.533317402005196, 54.16518911719322, 52.369865253567696, 61.54533930122852, 61.57020516693592, 68.20818677544594, 66.10022708773613, 71.20880976319313, 64.09065932035446, 64.92685765028, 58.5398905724287, 60.18910847604275, 54.895129948854446, 59.01399493217468, 56.21618986129761, 59.27674703299999, 56.577649265527725, 61.350614950060844, 58.83184030652046, 74.50943425297737, 72.43309646844864, 84.94634941220284, 73.14127206802368, 78.17625269293785, 25.581072829663754, 0.1924377348041162, 1.8125820625573397, 0.628629777347669, 0.1502117287600413, 23.964609168469906, 77.08729192614555, 66.73678413033485, 61.305218786001205, 48.5946424305439, 42.993773370981216, 31.468685902655125, 44.29034739732742, 54.18261498212814, 62.47760407626629, 19.26171362400055, 0.15131908730836585, 0.15572693984722719, 0.06650619106949307, 0.04192661996057723, 0.009242250744136982, 0.024796432226139586, 0.059941330837318674, 0.038148112362250686, 0.025342209482914768, 0.12014132240437903, 0.11785226437496021, 0.1547359797405079, 0.16158475598786026, 0.09207893759594299, 0.2767797012347728, 0.09997990855481476, 0.1216644469241146, 0.17242414935026318, 0.22640869865426794, 1.0703722829930484, 63.05260822176933, 75.17221748828888, 71.03401154279709, 44.72199283540249, 66.08935967087746, 70.98397582769394, 60.01608856022358, 105.92298701405525, 12.953788954764605, 0.4032042610924691, 3.5307059437036514, 6.296977931633592, 8.876323699951172, 91.13842114806175, 97.91034176945686, 97.127545773983, 82.32053831219673, 75.61943829059601, 85.33475697040558, 86.23942002654076, 94.05343472957611, 85.44415310025215, 87.02466309070587, 85.78388527035713, 82.36061096191406, 66.70824006199837, 63.476756662130356, 64.52484682202339, 60.56945666670799, 59.94867257773876, 58.92676681280136, 60.330407693982124, 62.324130311608315, 61.33789323270321, 59.10352572798729, 57.54774481058121, 59.238923862576485, 57.41297364234924, 58.740945383906364, 58.49113538861275, 62.13685356080532, 56.214103773236275, 53.029734045267105, 58.19599002599716, 55.19108086824417, 58.953027203679085, 57.9262501001358, 53.0094051361084, 49.74265582859516, 52.40512356162071, 49.49199467897415, 55.63205100595951, 52.10512585937977, 52.574727460742, 52.689203917980194, 56.93583704531193, 57.448794320225716, 60.948387533426285, 55.43123558163643, 57.65888124704361, 58.637195751070976, 62.43206351995468, 68.73305261135101, 70.55082187056541, 70.11303976178169, 63.01767289638519, 68.57121169567108, 67.44623646140099, 65.16684517264366, 64.78919863700867, 66.40738740563393, 67.5000187754631, 65.54725036025047, 56.23125985264778, 53.69178391993046, 52.89797231554985, 49.858234226703644, 46.44762843847275, 46.75713703036308, 47.16391660273075, 45.92632681131363, 52.41536021232605, 61.663265973329544, 65.90866416692734, 69.04808610677719, 66.5812660753727, 61.556917279958725, 64.03498470783234, 63.036428689956665, 58.48625265061855, 62.936440855264664, 64.05576199293137, 61.68285772204399, 61.640782579779625, 64.62528303265572, 67.1600054204464, 65.49640908837318, 68.08708727359772, 63.506786450743675, 62.72429443895817, 63.344736546278, 69.8472972214222, 68.82088109850883, 53.59143890440464, 56.64022050797939, 63.063285648822784, 62.95692935585976, 64.4429612159729, 55.70848010480404, 54.22944746911526, 51.612144112586975, 51.07464015483856, 48.671516105532646, 52.85321071743965, 54.205820336937904, 57.81597621738911, 51.99196793138981, 56.44361525774002, 56.68226905167103, 63.65188166499138, 64.09011214971542, 72.8274317085743, 69.31836560368538, 74.1664570569992, 67.16007381677628, 68.46047043800354, 62.112238481640816, 63.9228755235672, 59.61891867220402, 64.23676908016205, 60.533734783530235, 63.3213260024786, 59.99049313366413, 65.952278226614, 61.93733386695385, 78.78720670938492, 77.8296808898449, 87.1171273291111, 77.6297128200531, 81.64476737380028, 25.93248937278986, 1.0363514022901654, 2.623968911357224, 0.9742755582556129, 0.2760685159591958, 33.79793621599674, 83.83702173829079, 76.78468376398087, 65.48305660486221, 70.56191727519035, 75.2764230966568, 41.81239016354084, 57.10883416235447, 61.423616632819176, 78.41705337166786, 28.353932239115238, 0.3362244536401704, 0.20439495099708438, 0.16189798683626577, 0.15832499106181785, 0.18208606605185196, 0.13026762317167595, 0.14352091122418642, 0.14016206958331168, 0.11284889769740403], [0.02440341308101779, 0.12021010465105064, 0.004306971941332449, 0.02797865199681837, 0.047863126019365154, 0.0598294483643258, 0.032884964311961085, 0.05444824317237362, 0.08028362834011205, 0.0658776365162339, 0.2602231584023684, 39.703628718853, 51.203913018107414, 50.627130568027496, 38.19365434348583, 39.23408791422844, 43.71895685791969, 69.11087393760681, 66.71011716127396, 1.6403142688795924, 0.27057148749008775, 2.949596238322556, 6.4760589972138405, 9.363733995705843, 102.47884422540665, 80.5410785973072, 92.4712224304676, 67.69567787647247, 72.5478047132492, 72.90626987814903, 80.9950402379036, 76.72626569867134, 84.3451076745987, 74.91693958640099, 82.93731361627579, 67.95790940523148, 62.550404369831085, 54.98032137751579, 59.58124749362469, 56.5540487319231, 61.24259814620018, 55.658406391739845, 57.65738792717457, 56.38947956264019, 58.78177039325237, 52.32533924281597, 55.625237971544266, 52.463461831212044, 54.2932004481554, 54.61095079779625, 55.91412506997585, 50.93136504292488, 50.34109331667423, 49.512673169374466, 50.36757409572601, 49.70985598862171, 54.632624834775925, 52.72106520831585, 50.35355284810066, 44.9412676692009, 48.53215478360653, 45.5513059347868, 49.98395808041096, 46.69980950653553, 46.67598478496075, 44.16233606636524, 48.41243460774422, 49.23273839056492, 53.941259533166885, 49.2941202968359, 49.81450617313385, 49.283621460199356, 55.87484657764435, 60.40046073496342, 65.31563758850098, 63.154165372252464, 58.98540146648884, 56.327056512236595, 64.37953501939774, 58.14407341182232, 64.9382646381855, 51.96842059493065, 60.772646963596344, 47.609332501888275, 40.80838903784752, 47.782010436058044, 44.955638498067856, 42.048460096120834, 42.77953326702118, 40.79616129398346, 44.03737597167492, 38.06816227734089, 37.67801821231842, 47.73560352623463, 66.9981949031353, 58.367607817053795, 49.666006341576576, 55.335378125309944, 50.84150366485119, 48.952739015221596, 45.70989802479744, 54.43934440612793, 54.734865948557854, 55.32509207725525, 59.93423335254192, 59.61685538291931, 60.21223023533821, 60.946715623140335, 58.291999474167824, 60.65498627722263, 58.12466785311699, 58.89484852552414, 59.38526161015034, 55.59694468975067, 54.46511462330818, 51.4835400134325, 54.21361371874809, 58.50057788193226, 55.926637798547745, 51.715441569685936, 49.170668721199036, 45.93937151134014, 43.126283660531044, 42.47002847492695, 47.46372051537037, 50.30975639820099, 48.19628320634365, 48.681916147470474, 50.57632349431515, 49.69522677361965, 51.974564865231514, 54.92635667324066, 57.6444648206234, 58.103449791669846, 54.370868280529976, 53.09594169259071, 51.10227607190609, 51.38051614165306, 52.095554172992706, 48.90545815229416, 49.063495472073555, 51.44868828356266, 50.83640053868294, 51.749407947063446, 54.586936086416245, 60.58251656591892, 70.32016664743423, 71.54919549822807, 77.17466443777084, 69.52329620718956, 66.45254418253899, 45.194611474871635, 0.9247893886640668, 0.4439762810943648, 0.922069150255993, 0.3282428631791845, 4.805522812530398, 60.456910505890846, 63.33639599382877, 62.19001650810242, 39.30657662451267, 38.0851511657238, 30.777421295642853, 31.094791665673256, 47.30688773095608, 45.19527263939381, 15.694712977856398, 0.43894354021176696, 0.02184990928071784, 0.07832673334633, 0.016804327387944795, 0.05288270862365607, 0.01598766066308599, 0.05448926909593865, 0.026595457566145342, 0.12337317515630275, 0.047842505446169525, 0.12374865735182539, 0.06266951022553258, 0.0291164478767314, 0.01703731351881288, 0.07184001384302974, 0.03766256595554296, 0.050457106553949416, 0.09749769917107187, 0.06068401286029257, 0.48231465043500066, 53.86350430548191, 63.00658889114857, 60.96275456249714, 48.30130577087402, 43.69147673249245, 44.81638737022877, 80.9257547557354, 70.2612242102623, 1.835274207405746, 0.61094801989384, 4.754042699933052, 6.939489729702473, 14.58570258691907, 115.7368116080761, 82.41865664720535, 97.60340183973312, 70.61887621879578, 77.10766643285751, 75.26991784572601, 85.76639860868454, 82.06885501742363, 90.54269671440125, 78.06355834007263, 88.78489583730698, 68.99812638759613, 64.86703366041183, 56.57171778380871, 61.58318527042866, 59.38073605298996, 63.3916412293911, 58.98692138493061, 61.875169202685356, 60.180007964372635, 59.87772278487682, 56.12496055662632, 58.370336070656776, 54.82370898127556, 56.43360659480095, 56.15052558481693, 59.34411361813545, 52.94813722372055, 52.96358719468117, 50.44615387916565, 50.45154958963394, 51.07208289206028, 55.18289230763912, 53.438599705696106, 52.03150101006031, 45.97035884857178, 50.17731070518494, 48.383594155311584, 50.72773776948452, 49.967185780406, 49.758892357349396, 47.15121008455753, 52.15483479201794, 53.79298008978367, 56.44178755581379, 51.77367344498634, 52.3929376155138, 54.749160781502724, 58.990808576345444, 62.933587208390236, 68.9126005768776, 66.42311096191406, 61.74811542034149, 58.22198063135147, 67.40086689591408, 62.166989743709564, 67.70563334226608, 55.0468710064888, 63.38285610079765, 51.04111835360527, 46.091044172644615, 51.490634232759476, 47.065938860177994, 45.75723588466644, 45.340269058942795, 44.257900938391685, 43.94350580871105, 43.640985041856766, 41.423861011862755, 50.4887305945158, 65.59195876121521, 58.51989604532719, 50.04845581948757, 56.120978370308876, 52.40923874080181, 51.18686333298683, 51.06964722275734, 59.6794456243515, 57.41035558283329, 59.17814992368221, 61.89323343336582, 60.748252272605896, 64.08493682742119, 62.266548201441765, 61.71486720442772, 61.964016035199165, 59.94050681591034, 62.409697920084, 63.281447142362595, 57.74901241064072, 55.0557055324316, 57.98691384494305, 58.126928731799126, 61.847924664616585, 60.63074357807636, 53.16300429403782, 52.606702744960785, 47.77311131358147, 45.82464426755905, 44.41186487674713, 48.17555531859398, 52.089276909828186, 49.82330270111561, 51.60857990384102, 52.51464128494263, 51.8977177888155, 53.516400530934334, 55.67339278757572, 60.16157515347004, 58.704030364751816, 56.90251663327217, 53.08454230427742, 53.69438678026199, 52.9870243370533, 53.982711508870125, 51.65010027587414, 52.37456940114498, 53.34652304649353, 51.774763986468315, 54.423313066363335, 59.11793455481529, 62.413072139024734, 71.96153417229652, 74.0583148598671, 78.62638413906097, 72.19045668840408, 70.12740299105644, 47.85796456038952, 1.7244548164308071, 1.37343630194664, 1.4502995274960995, 0.3016062034294009, 4.052639286965132, 67.80673831701279, 71.25607922673225, 70.53727939724922, 46.635285168886185, 34.65297773480415, 31.601353883743286, 46.161686182022095, 53.41494217514992, 59.350109696388245, 20.012139156460762, 0.5480646598152816, 0.03643604075477924, 0.06349470422719605, 0.08050386808463372, 0.07780994623317383, 0.017919439524121117, 0.04292795900255442, 0.039755151519784704, 0.030503150810545776, 0.0864361810090486, 0.2790633786935359, 0.1781629101606086, 0.13462042319588363, 0.12175202777143568, 0.2664794336305931, 0.1350327010732144, 0.1301874266937375, 0.146060778060928, 0.21692028123652562, 1.2034873338416219, 70.79260289669037, 71.66752874851227, 71.81632876396179, 50.59664100408554, 57.23002105951309, 62.965459898114204, 84.92355823516846, 81.03488489985466, 2.4646731466054916, 0.45187095121946186, 5.2901393081992865, 9.140726812183857, 20.723922662436962, 116.77898168563843, 87.81942084431648, 100.19560754299164, 73.08416113257408, 82.34608054161072, 79.06312510371208, 87.19959810376167, 81.03857070207596, 89.78458419442177, 83.54227915406227, 89.50702428817749, 74.12696197628975, 68.76284301280975, 60.105300173163414, 64.99012425541878, 62.474051266908646, 66.88927754759789, 61.73453874886036, 64.86473858356476, 62.5079720467329, 65.20759418606758, 57.797778993844986, 60.11440448462963, 58.36448438465595, 60.37718318402767, 59.24848034977913, 60.532070472836494, 55.355083867907524, 56.66725605726242, 55.251315236091614, 53.533587008714676, 53.06106336414814, 57.2863644361496, 55.338045582175255, 52.373919636011124, 46.786414459347725, 52.221213430166245, 50.23838482797146, 53.47716383635998, 54.8881459236145, 52.24941931664944, 51.238232776522636, 53.73995393514633, 56.9298941642046, 59.56360504031181, 55.17044797539711, 55.614184364676476, 57.15952344238758, 62.14819975197315, 65.38429990410805, 72.25891381502151, 69.99808833003044, 64.9336364865303, 63.07632274925709, 70.47830656170845, 63.559284433722496, 70.23510441184044, 59.58602003753185, 63.75284984707832, 56.73676572740078, 52.03389108181, 55.5999731272459, 52.0220585167408, 49.60418365895748, 48.40293511748314, 46.75945870578289, 49.03076022863388, 49.423412159085274, 45.26657581329346, 52.112421467900276, 68.06946381926537, 62.946981489658356, 53.617486506700516, 57.509575858712196, 54.59922082722187, 54.216771349310875, 53.22450779378414, 61.73201188445091, 61.101222932338715, 62.055461928248405, 63.83009970188141, 64.30068165063858, 67.38009721040726, 66.14524707198143, 63.48290853202343, 64.70254808664322, 63.11931364238262, 64.61792662739754, 66.89141303300858, 60.370309352874756, 57.17758387327194, 58.50733011960983, 62.139790803194046, 64.3082432448864, 63.165587559342384, 56.975966691970825, 55.35319536924362, 50.40471710264683, 48.10167968273163, 50.28488673269749, 52.14695401489735, 55.447183325886726, 52.49255307018757, 55.58009259402752, 56.20131365954876, 55.153440088033676, 56.48660995066166, 61.48293524980545, 63.78833994269371, 62.81304247677326, 61.071022152900696, 58.57402794063091, 57.16686464846134, 57.81196743249893, 57.506444826722145, 54.93637673556805, 55.019143894314766, 58.4436721354723, 54.151635244488716, 58.37153300642967, 60.85420958697796, 66.43082454800606, 75.72991356253624, 78.58556672930717, 84.3579737842083, 77.91650623083115, 70.62909007072449, 52.34888657927513, 1.609565131366253, 4.876665445044637, 2.7468778286129236, 0.5765685334336013, 7.119368752464652, 78.47208961844444, 77.49127864837646, 77.99139261245728, 57.31806233525276, 55.383871123194695, 43.73956695199013, 47.78392933309078, 61.927914172410965, 73.30967143177986, 27.55719669163227, 0.9050777682568878, 0.18476792058208957, 0.1312917869654484, 0.163136794581078, 0.1305336831137538, 0.12189998233225197, 0.30296089011244476, 0.0728986355534289, 0.16164271772140637], [0.04760014599014539, 0.07019643133389764, 0.0449832442245679, 0.1024796103592962, 0.05471871518238913, 0.04842817499593366, 0.03799893325776793, 0.00752310971620318, 0.03437271065195091, 0.13696755428100005, 0.5469929985702038, 41.12808108329773, 51.134505942463875, 53.7196060270071, 27.051390632987022, 35.98819948732853, 39.73653495311737, 82.09408566355705, 42.720085456967354, 0.03675661144370679, 0.039138193023973145, 0.8016668516211212, 1.4644847600720823, 33.32671210169792, 102.17295303940773, 80.45853942632675, 90.70107221603394, 66.13995015621185, 72.36272424459457, 75.40129199624062, 84.89239990711212, 77.00031459331512, 78.12472745776176, 77.56813332438469, 78.40646713972092, 73.42669755220413, 69.95535582304001, 62.7157486975193, 64.29088577628136, 67.05858886241913, 66.99773132801056, 64.87562879920006, 63.78154590725899, 60.86451083421707, 59.613652154803276, 56.24948367476463, 55.69607377052307, 54.740466848015785, 55.21683968603611, 52.54580721259117, 53.62777255475521, 53.11201483011246, 49.29768070578575, 48.14156994223595, 50.64155839383602, 49.76785607635975, 53.81301261484623, 53.77842307090759, 51.42935112118721, 47.900564074516296, 48.354875296354294, 46.894761845469475, 46.16262473165989, 43.16569894552231, 43.540089055895805, 45.28918460011482, 47.191685512661934, 48.110320419073105, 50.45901998877525, 50.43954223394394, 48.682079538702965, 51.394685581326485, 53.44192072749138, 58.844782412052155, 64.90604996681213, 61.65076844394207, 57.03686222434044, 58.75410407781601, 57.563753351569176, 62.09735848009586, 63.90684798359871, 59.80804592370987, 54.21793408691883, 44.523689076304436, 40.94310320913792, 44.67840537428856, 45.60688175261021, 49.72806081175804, 52.81295567750931, 42.50081442296505, 42.27113954722881, 42.349476143717766, 38.88962879776955, 43.85220430791378, 40.823402032256126, 44.397254660725594, 51.53656616806984, 54.880234748125076, 58.426253870129585, 55.98656818270683, 57.85822615027428, 59.116874411702156, 60.72692781686783, 58.58154773712158, 56.8787907063961, 60.56452453136444, 57.82136432826519, 59.67796370387077, 56.518231853842735, 58.19758594036102, 57.469845190644264, 59.41665932536125, 55.965080335736275, 57.792983651161194, 52.264158725738525, 52.491667717695236, 58.86492133140564, 61.66152186691761, 53.30884426832199, 51.25102289021015, 51.22276000678539, 47.21504665911198, 47.84214220941067, 40.12355178594589, 43.177949488162994, 49.547186717391014, 45.72909839451313, 48.41249920427799, 47.71902121603489, 48.778104186058044, 49.16333511471748, 47.58883260190487, 49.010834097862244, 49.02159132063389, 47.24640637636185, 48.08214493095875, 47.00444296002388, 50.13213872909546, 47.367581874132156, 50.604669973254204, 49.02680084109306, 52.20201686024666, 51.30587674677372, 55.79686716198921, 57.87091366946697, 64.351636916399, 67.36440405249596, 73.11610221862793, 69.11456733942032, 69.82471883296967, 63.528832867741585, 63.89181599020958, 7.1764996368438005, 2.09863665048033, 1.4683750388212502, 0.35521319252438843, 0.037480658138520084, 40.00821277499199, 67.57381081581116, 64.7327108681202, 42.58405275642872, 42.83995382487774, 31.981394290924072, 24.548998810350895, 45.60309335589409, 49.35201019048691, 10.829608887434006, 0.9930587222333997, 0.1660494421957992, 0.13275211094878614, 0.15463341493159533, 0.01330375316683785, 0.03967273602029309, 0.026224448665743694, 0.018910974795289803, 0.06393234871211462, 0.053896604804322124, 0.08168135958840139, 0.04972331917088013, 0.07692368832067586, 0.0248904679028783, 0.04712019537691958, 0.014224385504348902, 0.09566535882186145, 0.03467151414952241, 0.036011921911267564, 1.1103715491481125, 56.276960000395775, 60.45354388654232, 62.955306842923164, 30.7340295240283, 36.91826418042183, 47.2913009673357, 90.33940762281418, 44.39395263791084, 0.07169327640440315, 0.22416227700887248, 1.0482336021959782, 3.0531746428459883, 48.77436898648739, 101.88593924045563, 84.76697623729706, 90.81007316708565, 69.50479879975319, 74.66255843639374, 79.68625366687775, 84.65948760509491, 79.48205262422562, 82.42308720946312, 78.83685484528542, 79.01095390319824, 75.58210909366608, 74.10274967551231, 66.58680617809296, 66.2043870985508, 68.1028564274311, 69.13721412420273, 67.63715341687202, 67.80247494578362, 64.18430909514427, 60.57665728032589, 59.02966529130936, 58.90062801539898, 55.58070436120033, 56.321250423789024, 55.58176450431347, 55.5143067240715, 54.08001288771629, 51.97630517184734, 50.94522289931774, 53.32571916282177, 52.39496290683746, 55.72486102581024, 56.07753150165081, 51.648040786385536, 46.826802492141724, 48.712170124053955, 47.800249457359314, 46.75659365952015, 48.886409774422646, 46.32177919149399, 48.084003031253815, 47.006137669086456, 51.81308872997761, 51.87578156590462, 52.142964228987694, 52.403694838285446, 54.47710298001766, 57.92558513581753, 62.64069512486458, 66.75439238548279, 63.63181874155998, 59.835697039961815, 64.06323999166489, 60.65158925950527, 66.23784050345421, 66.16209536790848, 60.80473244190216, 55.98230481147766, 46.59672483801842, 45.52888713777065, 48.677671775221825, 49.01237301528454, 52.135102450847626, 54.92740161716938, 45.962622463703156, 45.96259206533432, 44.72039692103863, 43.66585850715637, 44.11879800260067, 40.89470900595188, 43.2888313382864, 54.02813047170639, 58.271617367863655, 60.86509980261326, 60.44494114816189, 60.36802187561989, 61.71444162726402, 62.94948175549507, 60.852568075060844, 59.894745871424675, 62.21953712403774, 59.72100779414177, 61.107560992240906, 59.172682017087936, 60.12851692736149, 59.21305485069752, 61.68565817177296, 59.56867016851902, 58.11448059976101, 55.82025110721588, 58.30052241683006, 60.97722418606281, 62.68748961389065, 55.17634525895119, 55.02998471260071, 53.51639673113823, 50.51106959581375, 50.41470676660538, 43.53924170136452, 46.612467393279076, 50.8398849517107, 48.9540309458971, 51.509112641215324, 48.849715143442154, 50.517692640423775, 51.35636083781719, 50.774023085832596, 50.76432220637798, 50.77816866338253, 49.13098365068436, 50.208556428551674, 50.53593546152115, 51.93256571888924, 49.36826191842556, 52.881279811263084, 51.78802527487278, 55.392747446894646, 54.52952116727829, 58.83534371852875, 60.50804816186428, 68.75201359391212, 69.5920193195343, 75.92904567718506, 72.58959487080574, 71.01547613739967, 65.05849778652191, 67.59122148156166, 9.71674170345068, 0.8243933133780956, 1.266535569448024, 0.13615717354696244, 0.0239998127653962, 40.33062167465687, 78.06325435638428, 68.03649678826332, 54.63828273117542, 37.54856675863266, 23.940913639962673, 33.96292336285114, 48.302525505423546, 65.12718290090561, 16.327701061964035, 1.642571585252881, 0.14865868084598333, 0.18692412675591186, 0.11322619073325768, 0.03239705787564162, 0.047684654346085154, 0.026790150732267648, 0.053521452864515595, 0.07149353477871045, 0.2195729990489781, 0.17499300447525457, 0.1729131949832663, 0.23306754446821287, 0.15326634922530502, 0.07728724420303479, 0.23358122940408066, 0.11401975440094247, 0.12005817217868753, 0.2909523469861597, 2.3989347741007805, 72.94271752238274, 71.2432587146759, 74.54945370554924, 35.14585308730602, 53.749442026019096, 58.215167596936226, 96.17703437805176, 52.361779287457466, 0.1634715625550598, 0.2691417548339814, 3.2544659916311502, 8.637843746691942, 50.658368691802025, 107.21464410424232, 87.9507265985012, 96.89280956983566, 73.17470267415047, 78.43805104494095, 84.0879374742508, 87.87907764315605, 83.24401035904884, 83.84169548749924, 84.71858963370323, 85.90550914406776, 79.26951482892036, 75.6416442990303, 68.95917847752571, 71.70214489102364, 72.05959931015968, 72.78881058096886, 70.28912991285324, 68.68307009339333, 68.17605569958687, 63.23852464556694, 63.74087668955326, 61.05808384716511, 59.17137488722801, 60.41553072631359, 59.04583342373371, 58.06666776537895, 57.9473427683115, 54.64857257902622, 53.48020367324352, 58.220741897821426, 53.61019469797611, 57.659888193011284, 57.66330800950527, 52.703498750925064, 49.30176928639412, 49.59870435297489, 49.212113097310066, 48.87679249048233, 51.26325823366642, 50.641398802399635, 50.7188880443573, 51.05796664953232, 55.40590614080429, 55.22282816469669, 56.57673351466656, 55.62502898275852, 58.003017380833626, 60.63069798052311, 64.49826344847679, 70.64571037888527, 67.83012226223946, 62.4078094214201, 65.6354208290577, 64.90412726998329, 69.38840344548225, 71.46186858415604, 64.37676876783371, 57.30092525482178, 49.91148076951504, 50.72187468409538, 51.63151927292347, 52.759899124503136, 54.93981175124645, 58.46705228090286, 47.98381760716438, 47.43162743747234, 48.82554464042187, 47.447457388043404, 48.43405544757843, 48.597450479865074, 46.60059303045273, 53.92204396426678, 58.4744580835104, 60.72743698954582, 61.28281518816948, 62.65856556594372, 65.29032334685326, 65.39871633052826, 64.6214148402214, 62.791520431637764, 65.82262918353081, 62.30941750109196, 65.24929314851761, 62.12689809501171, 63.213806971907616, 61.820227950811386, 66.89643636345863, 61.183279529213905, 59.904803931713104, 57.8820014744997, 62.112211883068085, 63.40115211904049, 67.55768448114395, 58.4619377553463, 57.32965171337128, 55.9948593378067, 55.41414029896259, 54.07935552299023, 46.16087302565575, 49.287497252225876, 54.85531948506832, 50.49185782670975, 53.57647530734539, 49.59070958197117, 53.68923805654049, 54.769751876592636, 53.13432723283768, 53.4742645919323, 55.091663002967834, 52.18598932027817, 53.43808673322201, 53.02140109241009, 56.945009753108025, 52.68793098628521, 57.629258036613464, 54.68170300126076, 59.434636160731316, 56.86817787587643, 62.4639780074358, 64.4854125380516, 71.77635490894318, 72.8990350663662, 78.88253599405289, 75.03916382789612, 74.70972150564194, 66.51717871427536, 70.4764674603939, 9.401021394878626, 5.81105288118124, 4.267477383837104, 0.5712062492966652, 0.29155850352253765, 51.05402626097202, 82.57392391562462, 77.82775059342384, 59.95252937078476, 61.92737840116024, 46.730812042951584, 42.07606561481953, 60.30702754855156, 77.08496645092964, 27.775183394551277, 2.1999456267803907, 0.32028148882091045, 0.34731976920738816, 0.19455665547866374, 0.17782732582418248, 0.21037404891103506, 0.16901271912502125, 0.1003350484825205, 0.2830526005709544], [0.08921824031858705, 0.09022615107824095, 0.06591878860490397, 0.05874392380064819, 0.04883774403424468, 0.02937294153525727, 0.029471823436324485, 0.05797205682029016, 0.05261692698695697, 0.06722748439642601, 3.4914761362597346, 45.64673401415348, 45.28283514082432, 37.624691873788834, 46.78727701306343, 62.10723415017128, 44.84250336885452, 90.81121310591698, 21.99285127222538, 0.28927907114848495, 0.4022348381113261, 2.417816910892725, 4.6667352598160505, 79.14908409118652, 87.11401909589767, 86.27055555582047, 82.36565709114075, 66.12125515937805, 68.19876328110695, 79.37230691313744, 82.59075701236725, 77.96990856528282, 72.23595544695854, 80.90978801250458, 76.00301250815392, 75.37132680416107, 72.45524168014526, 71.89101755619049, 69.05633926391602, 71.75525084137917, 69.07566502690315, 70.66249027848244, 68.25950682163239, 66.62275984883308, 64.48855116963387, 62.296236008405685, 53.83089065551758, 54.42686587572098, 52.64945425093174, 51.97002410888672, 52.897976115345955, 50.635094940662384, 46.564582362771034, 48.323036804795265, 48.53921480476856, 48.794139325618744, 52.758337408304214, 51.92761838436127, 47.074275612831116, 47.75850109755993, 46.706649139523506, 45.32257340848446, 43.294648826122284, 45.46533554792404, 42.933531403541565, 43.451910987496376, 45.30945271253586, 48.51431854069233, 46.26282915472984, 49.72276009619236, 47.90650315582752, 55.05577392876148, 54.29151713848114, 61.715497970581055, 63.43645982444286, 61.155058443546295, 53.0061487108469, 60.621912851929665, 60.73637790977955, 62.828310057520866, 62.45488129556179, 61.823108196258545, 48.8286566734314, 43.029221668839455, 41.01629488170147, 41.56355671584606, 45.07652521133423, 52.2926039993763, 43.93776431679726, 45.26460751891136, 45.90005502104759, 38.754002675414085, 37.9470057785511, 40.18553026020527, 33.592253252863884, 42.726818695664406, 59.66371446847916, 57.66849473118782, 60.03566510975361, 58.19621041417122, 58.24300870299339, 56.92642115056515, 58.77183012664318, 54.9452568590641, 58.40171858668327, 59.21836316585541, 57.75832571089268, 58.74049700796604, 59.423453360795975, 58.378102853894234, 60.812719613313675, 60.51668889820576, 56.87318600714207, 54.1872089356184, 56.14244341850281, 56.16345629096031, 59.54805627465248, 56.39050550758839, 48.6175362020731, 52.202332243323326, 54.4360613822937, 48.0669267475605, 47.433455139398575, 43.00328806042671, 42.1848613768816, 48.24990592896938, 50.55335372686386, 49.47536677122116, 47.779342979192734, 50.53480312228203, 49.08318221569061, 49.803414568305016, 48.8468386977911, 46.99930943548679, 47.36703850328922, 48.937707021832466, 48.34001049399376, 46.87199346721172, 47.14519880712032, 51.38604484498501, 48.85372772812843, 52.61967144906521, 54.79079894721508, 60.082455798983574, 61.20491176843643, 69.81885954737663, 67.31019616127014, 73.63406762480736, 65.01898750662804, 63.59702780842781, 61.336684897542, 69.20092150568962, 27.974450401961803, 0.49890301655977964, 1.0099454317241907, 1.4433765364810824, 0.6294868688564748, 14.266931042075157, 67.80093222856522, 64.81211140751839, 52.50515699386597, 41.46616034209728, 36.42104186117649, 28.527989499270916, 38.59080143272877, 47.13759161531925, 7.83069153316319, 1.1236063577234745, 0.22017314418917522, 0.09127344019361772, 0.033170872993650846, 0.033587384823476896, 0.11948472209041938, 0.04386718028399628, 0.16571839980315417, 0.01162067355835461, 0.01081158601664356, 0.024247152032330632, 0.007460632014044677, 0.05574182512646075, 0.0733808237418998, 0.06418592573027126, 0.13971357489936054, 0.07575056064524688, 0.07006592466495931, 0.2380951348459348, 5.408634524792433, 61.95765897631645, 53.87828931212425, 49.26654517650604, 31.27228584140539, 53.186110854148865, 56.16394646465778, 95.53531721234322, 23.50758869200945, 0.4153021884849295, 0.1959283818723634, 3.235380803234875, 10.439309980720282, 89.42593663930893, 87.19837456941605, 90.0552436709404, 84.64252531528473, 69.72302868962288, 71.05054825544357, 83.93510207533836, 83.23945820331573, 81.92736580967903, 77.44077175855637, 83.30055892467499, 79.89505246281624, 76.90916508436203, 75.20983546972275, 75.64286783337593, 73.55301797389984, 74.17926236987114, 72.02315926551819, 72.52520352602005, 72.78092980384827, 69.97000023722649, 67.24727913737297, 63.041847199201584, 58.804633766412735, 56.856824085116386, 54.49283793568611, 54.503203779459, 56.45288296043873, 53.30746114253998, 51.58735044300556, 50.17440386116505, 53.67181979119778, 54.26030181348324, 54.47006955742836, 52.93366760015488, 48.226206600666046, 47.057510912418365, 47.22097434103489, 47.34259441494942, 45.29378995299339, 50.34713499248028, 45.74357941746712, 45.26045434176922, 48.75263035297394, 50.92337787151337, 50.030760169029236, 53.62288221716881, 51.569799184799194, 56.695959717035294, 56.93557865917683, 63.738334625959396, 65.74297025799751, 62.766840755939484, 54.45241190493107, 62.21402741968632, 65.30791640281677, 63.204125091433525, 65.74534893035889, 64.73403319716454, 51.23452417552471, 47.82238706946373, 45.401795357465744, 45.90078838169575, 50.191544741392136, 54.42541055381298, 44.41821813583374, 49.5229098200798, 47.618714198470116, 44.23282228410244, 41.39865696430206, 44.505165070295334, 36.78735740482807, 43.46745975315571, 62.02891655266285, 60.97892269492149, 63.40079873800278, 61.69456109404564, 61.17813840508461, 60.29194615781307, 60.464798882603645, 57.530223950743675, 61.308486610651016, 60.665621906518936, 61.98687940835953, 63.342331275343895, 60.06950609385967, 59.867964908480644, 62.637613490223885, 63.340701162815094, 60.49080468714237, 59.844273179769516, 57.678446397185326, 59.32498924434185, 60.897124484181404, 57.38575950264931, 52.270675376057625, 54.425585344433784, 55.92701397836208, 51.09391272068024, 49.85872060060501, 46.40347860753536, 43.980158641934395, 50.55822126567364, 52.107147350907326, 51.132807433605194, 50.535392090678215, 52.00686693191528, 49.97750222682953, 52.49368540942669, 51.25508487224579, 50.12673541903496, 50.464115515351295, 51.372004598379135, 48.895669877529144, 50.97593665122986, 49.47639271616936, 53.691042959690094, 51.9647765904665, 56.012030616402626, 56.18588648736477, 62.99851432442665, 64.19308662414551, 73.14919844269753, 70.41835337877274, 75.89365437626839, 67.23914757370949, 66.11504629254341, 62.87290446460247, 70.84002435207367, 32.6063771545887, 0.6609642610419542, 1.3798268465325236, 1.3365243701264262, 0.761062289820984, 14.093717336654663, 76.96000635623932, 71.1036466062069, 58.670405969023705, 45.832312256097794, 31.336857676506042, 39.17785093188286, 49.436798840761185, 58.37424226105213, 17.22371768206358, 1.5765774389728904, 0.27791397005785257, 0.11511742792208679, 0.20996690669562668, 0.07251706774695776, 0.019641591352410614, 0.12461380858439952, 0.0499489394860575, 0.05550516907533165, 0.1625277436687611, 0.20240384299540892, 0.19151816930389032, 0.28785180242266506, 0.16306645382428542, 0.16795034956885502, 0.17741194576956332, 0.154112946765963, 0.2526364795630798, 0.5969797319266945, 7.5372461043298244, 75.46205073595047, 67.67162516713142, 53.82715925574303, 65.6610618531704, 95.72041288018227, 59.81813058257103, 108.18822786211967, 27.443843074142933, 0.35935004241764545, 0.4376465332461521, 4.922942686825991, 16.026709713041782, 97.12088093161583, 90.70383086800575, 95.57085290551186, 88.72387111186981, 73.02014216780663, 74.74910259246826, 86.1212919652462, 85.47107085585594, 84.33897480368614, 77.22437337040901, 87.10113778710365, 81.32108554244041, 79.98001590371132, 77.61269733309746, 79.23574984073639, 77.1378368139267, 78.69573801755905, 74.85017716884613, 76.28704726696014, 76.51410788297653, 72.47537299990654, 70.25734841823578, 67.82658845186234, 60.33269137144089, 59.59648087620735, 57.69211806356907, 56.976901441812515, 58.17474916577339, 54.1564229875803, 52.7927977591753, 54.04272548854351, 54.9972190707922, 55.76527185738087, 56.07882723212242, 55.098438039422035, 48.375037014484406, 47.987317219376564, 47.00286604464054, 48.03492106497288, 46.65038175880909, 52.27277286350727, 49.105984792113304, 48.00161585211754, 50.5501276999712, 55.15109181404114, 52.199269607663155, 55.82103006541729, 54.53542225062847, 59.49131391942501, 60.614100471138954, 66.30099311470985, 70.46249181032181, 65.85962399840355, 57.95866996049881, 66.0759311914444, 66.33548006415367, 67.46577501296997, 68.70507851243019, 68.39639067649841, 54.498594626784325, 53.03920313715935, 49.264250099658966, 51.22955784201622, 53.843365386128426, 57.19979748129845, 48.21067303419113, 53.53507652878761, 50.47510452568531, 47.68994137644768, 46.58029831945896, 48.01711142063141, 40.51422022283077, 44.75629359483719, 62.71935470402241, 63.574597612023354, 65.15379667282104, 66.28447920084, 64.81738552451134, 64.23065900802612, 65.07094591856003, 60.595382675528526, 63.211466297507286, 64.59687575697899, 64.01302188634872, 67.05560982227325, 63.30203823745251, 63.85012462735176, 65.81880658864975, 63.63211892545223, 60.810352340340614, 62.507185488939285, 62.06927798688412, 61.10231727361679, 65.11253088712692, 63.82762983441353, 55.53501181304455, 56.97880133986473, 55.7072489708662, 53.91891673207283, 51.98365777730942, 49.242108687758446, 46.84925928711891, 53.43519888818264, 56.04761950671673, 54.7997360676527, 52.722330540418625, 56.713009402155876, 52.598282396793365, 55.61293423175812, 54.689709171652794, 52.62930013239384, 52.69957736134529, 55.36527872085571, 53.51928077638149, 55.09966157376766, 53.340705558657646, 59.98754449188709, 55.50869822502136, 58.69246378540993, 58.82393293082714, 66.50593131780624, 68.08241352438927, 74.71222177147865, 72.65650168061256, 78.98422613739967, 71.45040839910507, 71.28886386752129, 62.95809209346771, 71.55748665332794, 32.89323516190052, 1.2893710378557444, 5.9967755153775215, 3.5021960735321045, 0.9226412570569664, 20.489898920059204, 84.59851607680321, 78.52894216775894, 66.32708251476288, 63.06138955056667, 53.71432051062584, 46.58734314143658, 59.7652830183506, 69.97709065675735, 28.847544752061367, 2.272108504548669, 0.4482543468475342, 0.3370771516347304, 0.26444315852131695, 0.24352260923478752, 0.381534380139783, 0.22909932537004352, 0.22166677576024085, 0.1544208638370037], [0.04848874537856318, 0.008983978714240948, 0.06153131173050497, 0.07557928780443035, 0.024238880796474405, 0.06573881779331714, 0.07512982832849957, 0.15622287261066958, 0.1439711870625615, 0.3198996389983222, 7.092894623056054, 50.35828739404678, 51.62584997713566, 28.578169606626034, 35.88169880211353, 54.50090490281582, 49.28690068423748, 85.57759433984756, 7.696956284344196, 0.16152436000993475, 0.18599978182464838, 2.300232220441103, 15.332419518381357, 65.50313472747803, 78.57954025268555, 89.0515199303627, 80.15068754553795, 71.66774913668633, 70.34410536289215, 81.30110621452332, 80.18818393349648, 77.49975219368935, 67.52534061670303, 74.90438506007195, 74.175363779068, 80.06298825144768, 73.61414149403572, 74.7607147693634, 73.54661151766777, 74.40063089132309, 73.64640176296234, 75.99053397774696, 71.19955345988274, 69.10835087299347, 64.87684473395348, 66.30897268652916, 55.82244738936424, 57.14912340044975, 52.93109513819218, 52.32087068259716, 53.43506969511509, 51.37281775474548, 44.30952116847038, 48.70880350470543, 48.94134342670441, 51.764515936374664, 51.23118795454502, 51.9413698464632, 48.861464112997055, 47.26021483540535, 48.42882312834263, 46.21340520679951, 43.54993432760239, 44.66305039823055, 42.09437683224678, 43.47467176616192, 42.245449125766754, 45.134635493159294, 45.97947835922241, 47.65294276177883, 48.73991243541241, 52.69832342863083, 54.233258664608, 59.18736822903156, 61.855839639902115, 66.68465852737427, 57.47573107481003, 53.69550012052059, 60.84692917764187, 64.82484832406044, 60.65044932067394, 66.14052772521973, 50.18804132938385, 42.5900412350893, 38.72493043541908, 43.448848351836205, 48.12724471092224, 44.85027775168419, 42.92126566171646, 46.819309294223785, 47.90647275745869, 40.53793475031853, 39.63101081550121, 44.725625440478325, 43.2557313144207, 48.208043575286865, 62.154720202088356, 55.19009672105312, 58.97195018827915, 57.90560960769653, 57.95856736600399, 55.10156907141209, 55.274657383561134, 54.650985449552536, 57.84866206347942, 58.047273606061935, 57.643020898103714, 56.812275275588036, 59.937759563326836, 60.904499888420105, 60.21503448486328, 56.203015968203545, 55.95306158065796, 58.8454245775938, 59.12945553660393, 56.07771389186382, 52.144784331321716, 45.97633972764015, 47.165428921580315, 59.084982722997665, 58.685969933867455, 50.01605875790119, 46.68077252805233, 42.296704575419426, 42.341089993715286, 46.043865904212, 46.45609438419342, 49.00272153317928, 49.954756647348404, 49.29502844810486, 48.33281747996807, 47.37659879028797, 48.41135546565056, 48.09045508503914, 47.503622174263, 49.4451279938221, 49.53468918800354, 49.98708911240101, 51.485994681715965, 52.10698775947094, 55.880348682403564, 58.24639052152634, 59.707978293299675, 64.59932282567024, 68.36095377802849, 71.08301371335983, 70.67516639828682, 74.41121712327003, 63.531507924199104, 59.14087012410164, 70.23209497332573, 66.26677975058556, 61.92984826862812, 3.3234244538471103, 0.8352132921572775, 0.14642494992585853, 0.15663776284782216, 1.7135011916980147, 57.04459860920906, 66.86729192733765, 57.11187019944191, 37.87755690515041, 33.15574787557125, 38.18296171724796, 34.08366948366165, 39.52186547219753, 13.373864963650703, 0.9181145718321204, 0.08051156415604055, 0.06529390026116744, 0.024964229960460216, 0.04588050076563377, 0.06804789154557511, 0.04335169564001262, 0.03881803793774452, 0.049581747080083005, 0.09492050972767174, 0.01039726537783281, 0.10393366319476627, 0.037173041637288406, 0.10279136433382519, 0.05411749392806087, 0.040528677200200036, 0.09335129041573964, 0.19121117249596864, 0.375610112096183, 11.827109511941671, 67.22187370061874, 60.3311600536108, 32.12046302855015, 29.358985908329487, 58.12303014099598, 57.93573059141636, 89.99652162194252, 7.738867560401559, 0.16245971841271967, 0.24480392719851807, 3.4052630374208093, 24.291237741708755, 73.74826669692993, 82.44023948907852, 92.63833746314049, 83.0857640504837, 74.65611398220062, 69.30104613304138, 84.0364122390747, 82.60167762637138, 82.25208878517151, 69.70323175191879, 75.78915998339653, 79.31790143251419, 83.68094131350517, 77.78516247868538, 79.48180183768272, 75.10628342628479, 77.47066855430603, 77.05301776528358, 78.33002284169197, 73.16141098737717, 72.42855951189995, 66.66442081332207, 68.43533858656883, 58.28840106725693, 59.6230186522007, 55.86282402276993, 55.39531230926514, 56.06495417654514, 54.823226407170296, 47.784438505768776, 52.10162244737148, 52.91347548365593, 52.386192977428436, 54.07506175339222, 54.033940359950066, 50.922363325953484, 48.30638229846954, 47.650256305933, 47.801621183753014, 46.935860440135, 46.94032900035381, 45.77310763299465, 46.03603832423687, 45.56206315755844, 46.32744088768959, 49.058582335710526, 51.02769747376442, 50.886759236454964, 55.44119864702225, 56.975666508078575, 62.54232220351696, 67.51937493681908, 66.8958131968975, 62.30026759207249, 58.7102772295475, 63.46491649746895, 69.36943486332893, 63.727881386876106, 69.20479729771614, 53.69079977273941, 46.40494152903557, 42.553935572505, 46.06163755059242, 52.64572665095329, 45.955178663134575, 44.202860891819, 49.16654974222183, 50.11074587702751, 43.97649943828583, 41.34801708161831, 47.838881984353065, 47.061318308115005, 50.41648507118225, 64.44632783532143, 57.37363815307617, 62.46442258358002, 59.778859689831734, 61.54954947531223, 58.496234714984894, 57.12966464459896, 56.720829382538795, 60.33192381262779, 58.91206540167332, 59.693717658519745, 59.95148062705994, 61.0295245796442, 63.34899991750717, 61.77904196083546, 59.0387050062418, 58.78577537834644, 59.8446037620306, 61.647899597883224, 58.0065131932497, 54.09157186746597, 49.71629284322262, 50.45955955982208, 60.34475192427635, 59.788739159703255, 52.921531051397324, 48.30914855003357, 46.68739557266235, 44.55303110182285, 47.55123741924763, 50.6047497689724, 52.59113498032093, 52.05109655857086, 50.7368990778923, 50.344448536634445, 50.92186935245991, 49.591974914073944, 50.30567541718483, 50.40148347616196, 51.6103658080101, 50.763999223709106, 54.404336884617805, 54.42691147327423, 55.18446542322636, 58.090937063097954, 60.49618519842625, 60.89461661875248, 65.70045813918114, 69.6045358479023, 74.42721426486969, 71.89013600349426, 74.45470958948135, 65.03565341234207, 60.470046401023865, 72.09359228610992, 68.24865460395813, 66.43663823604584, 5.627013081684709, 0.5847622000146657, 0.6382003950420767, 0.11616298783337697, 1.727276046294719, 61.34786769747734, 76.80866047739983, 63.43335919082165, 48.13586264848709, 30.11948850005865, 37.0580168813467, 48.87452021241188, 50.45634873211384, 23.438531197607517, 1.4435236598365009, 0.12234944180818275, 0.03469947085250169, 0.028824863620684482, 0.04837422828131821, 0.09723078575916588, 0.06115225609391928, 0.11750353660318069, 0.0198236735741375, 0.23886388109531254, 0.10032211284851655, 0.24493087898008525, 0.1657668620464392, 0.1762365025933832, 0.14969029580242932, 0.1491427540895529, 0.23950810980750248, 0.39752555487211794, 1.0286227357573807, 14.719552304595709, 80.93875765800476, 74.95995327830315, 41.72842986881733, 59.777780547738075, 79.77937147021294, 61.753005757927895, 103.24150890111923, 9.611792284995317, 0.2117490110686049, 1.0614077327772975, 6.013932544738054, 29.53343264758587, 81.7511996626854, 85.0685964524746, 96.96653321385384, 84.49310213327408, 76.68967366218567, 73.59880551695824, 87.37849250435829, 85.47924801707268, 82.60825887322426, 72.56261631846428, 79.4514262676239, 81.65264815092087, 86.13311693072319, 80.01185819506645, 81.30527079105377, 77.13907554745674, 82.82984018325806, 81.62988737225533, 83.29167500138283, 74.64998871088028, 73.93425911664963, 69.08403977751732, 72.62906715273857, 60.66597528755665, 63.20327013731003, 57.50575706362724, 58.04214768111706, 57.3469939827919, 57.86293409764767, 51.63397394120693, 55.81714667379856, 54.99242752790451, 56.67933940887451, 57.96857222914696, 54.540817961096764, 51.78153522312641, 47.76777260005474, 48.48858252167702, 48.27670969069004, 47.419202104210854, 49.785525128245354, 48.16344156861305, 50.1333774626255, 47.407730519771576, 49.45376493036747, 53.124052584171295, 54.128806069493294, 55.289947763085365, 57.84335374832153, 59.94113378226757, 65.94274833798409, 70.24255201220512, 69.5386853814125, 62.32498146593571, 61.14318408071995, 65.714570581913, 72.40915015339851, 64.97623980045319, 72.23762735724449, 57.40165404975414, 51.454859152436256, 48.393051847815514, 50.469602420926094, 54.748982191085815, 48.998203575611115, 48.34773167967796, 50.112755969166756, 52.44660213589668, 47.05158323049545, 46.29283234477043, 51.97527542710304, 49.26091767847538, 51.86294965445995, 67.12425693869591, 60.653967931866646, 65.5458216369152, 65.57424411177635, 62.380830869078636, 60.866965502500534, 61.19936786592007, 60.05277179181576, 62.73355834186077, 61.594656854867935, 63.838079273700714, 62.50667631626129, 63.51003147661686, 64.43041428923607, 63.09618428349495, 62.7208062261343, 61.636469811201096, 63.55958081781864, 64.45996910333633, 62.09884040057659, 59.81336943805218, 51.297627389431, 53.474880158901215, 63.33594001829624, 62.838770896196365, 55.61581447720528, 49.99401994049549, 47.77719609439373, 48.24604153633118, 50.250574573874474, 51.81686952710152, 54.81470346450806, 55.478147864341736, 53.73510159552097, 52.8876406699419, 53.08681458234787, 53.506600856781006, 53.55361573398113, 54.0711023658514, 55.00070348381996, 54.65261936187744, 55.82860305905342, 57.59168565273285, 57.16011241078377, 61.44158586859703, 64.3050666153431, 63.906148821115494, 70.35202413797379, 71.73619866371155, 78.48443135619164, 76.61550924181938, 79.4219246506691, 67.65945062041283, 63.25413040816784, 74.24053028225899, 68.83146733045578, 66.38848721981049, 5.294463001191616, 4.473784463480115, 2.0168194407597184, 0.27946971938945353, 2.8030231408774853, 72.12825402617455, 82.43691846728325, 72.16486126184464, 55.64650163054466, 50.46424090862274, 52.50822722911835, 55.47429107129574, 64.7277483344078, 36.85926854610443, 1.804104836191982, 0.24169474403606728, 0.12242433935170993, 0.19666802108986303, 0.14198658027453348, 0.13951493165222928, 0.13634285889565945, 0.13040894293226302, 0.09541677645756863], [0.09764359798282385, 0.04942127248796169, 0.07639215473318473, 0.060825996843050234, 0.045577351993415505, 0.0305484719137894, 0.042408173612784594, 0.05660616370732896, 0.030735853069927543, 0.31466829939745367, 11.848413068801165, 55.78283071517944, 45.082893669605255, 39.5569109916687, 31.35609794408083, 46.0304070264101, 62.07470789551735, 73.53141993284225, 1.1863540532067418, 0.026751603581942618, 0.7058916846290231, 2.0833384338766336, 46.6853778809309, 71.663006991148, 84.82788696885109, 85.46371445059776, 80.2374216914177, 66.3415901362896, 74.0221256017685, 76.37149393558502, 83.9228667318821, 78.51894110441208, 67.84599781036377, 74.64289829134941, 70.94057455658913, 75.27524515986443, 77.933020144701, 75.40639892220497, 72.49869614839554, 76.31699725985527, 71.25917226076126, 73.61440747976303, 68.92249524593353, 67.3290203511715, 67.19615668058395, 64.82011377811432, 57.09659121930599, 53.29660892486572, 53.15177969634533, 51.53349973261356, 53.70360888540745, 48.85974660515785, 45.454688519239426, 48.87184135615826, 48.37015047669411, 51.74980692565441, 52.75623232126236, 54.41151089966297, 46.850266233086586, 47.209118977189064, 46.53953790664673, 46.56829476356506, 44.63147409260273, 45.85082106292248, 43.97890090942383, 42.53886938095093, 45.20427815616131, 42.031095027923584, 45.74603408575058, 48.901407569646835, 48.94919000566006, 53.34640525281429, 56.24529629945755, 58.819091990590096, 62.73205742239952, 65.42455494403839, 65.23014977574348, 63.11902865767479, 61.631735265254974, 61.175835728645325, 59.221611991524696, 62.48813711106777, 50.45851841568947, 41.43222436308861, 39.230816289782524, 44.944531694054604, 50.0953035056591, 44.302654936909676, 43.3306784927845, 46.72141134738922, 49.33277182281017, 45.23996204137802, 40.32714106142521, 45.628943368792534, 44.348282888531685, 52.29179844260216, 59.81945291161537, 57.78654299676418, 52.69114561378956, 52.35142484307289, 54.37968000769615, 56.90016455948353, 52.405982315540314, 52.52056896686554, 55.9223098307848, 57.376180216670036, 57.498944029212, 61.474020928144455, 64.26719024777412, 59.22991454601288, 54.004225954413414, 57.69870691001415, 61.02378688752651, 59.40052159130573, 54.17449101805687, 47.258770912885666, 42.669449374079704, 46.31434679031372, 48.212151154875755, 51.24122701585293, 54.386671632528305, 53.42556640505791, 45.354932472109795, 46.34316444396973, 40.92829920351505, 44.32278245687485, 49.36875209212303, 48.98121848702431, 47.617350071668625, 48.90142276883125, 51.0678119212389, 47.67593152821064, 47.83415123820305, 48.6237108707428, 49.587354362010956, 48.047224804759026, 52.85810485482216, 52.905932888388634, 57.13820278644562, 56.44203834235668, 63.069289326667786, 61.79492890834808, 67.15780913829803, 66.16360008716583, 73.25374603271484, 68.02568256855011, 71.34518444538116, 60.02122588455677, 62.811913937330246, 67.5038793683052, 71.65835604071617, 66.87293082475662, 79.8860165476799, 24.53972540795803, 1.2351116118952632, 0.10716227276134305, 0.16586133744567633, 0.10602438225760125, 32.59218871593475, 70.44133454561234, 56.16505980491638, 45.43158195912838, 32.19510242342949, 27.564131319522858, 24.60151009261608, 30.67445632070303, 21.720497086644173, 1.2999041914008558, 0.0798490340821445, 0.11601668826187961, 0.054715171427233145, 0.04560137902444694, 0.08766350772930309, 0.034331046481383964, 0.017192485465784557, 0.046515860813087784, 0.05331651620508637, 0.040251514728879556, 0.12183859187643975, 0.10909472141065635, 0.07255255724885501, 0.094577541021863, 0.03624573553679511, 0.12560784118250012, 0.055594627556274645, 0.3762533760163933, 19.690832197666168, 69.35164421796799, 57.173282504081726, 52.79635436832905, 34.75679576396942, 55.82979619503021, 70.50342321395874, 80.7401879131794, 1.1089735804125667, 0.014786466817895416, 1.15552369505167, 2.862103320658207, 56.8380568921566, 80.16476199030876, 86.36622682213783, 88.28716054558754, 82.15524718165398, 66.6297210752964, 76.30315840244293, 79.34370204806328, 85.22083148360252, 81.6948638856411, 69.31961953639984, 75.69107964634895, 73.71250301599503, 77.82269686460495, 77.60154873132706, 77.2907330095768, 72.37392604351044, 75.77896893024445, 73.54862540960312, 73.75236287713051, 73.11674058437347, 71.10842674970627, 69.76991057395935, 65.79086288809776, 60.925911739468575, 57.068715915083885, 55.91365769505501, 54.73363861441612, 55.89360237121582, 51.488772332668304, 49.36448872089386, 51.040043011307716, 52.01524928212166, 54.065771251916885, 54.108750745654106, 55.323553159832954, 48.198593482375145, 49.80368435382843, 46.291540414094925, 48.2116761803627, 46.29305273294449, 48.403265699744225, 47.158213108778, 46.64896443486214, 46.822945699095726, 46.34709723293781, 49.50050622224808, 50.68090908229351, 51.08314409852028, 55.60713954269886, 57.46050529181957, 62.92762152850628, 64.7187352180481, 66.73498302698135, 65.21774724125862, 68.52159395813942, 63.908618688583374, 62.47106462717056, 62.37638510763645, 64.14695709943771, 52.88468822836876, 47.19855934381485, 43.07643413543701, 48.63054670393467, 53.13472241163254, 47.69338019192219, 46.06129936873913, 47.66606345772743, 51.81496202945709, 48.68196174502373, 43.56630004942417, 50.436673387885094, 49.9955702573061, 54.74223755300045, 61.20962351560593, 59.034988805651665, 54.23553854227066, 54.08929578959942, 56.57560117542744, 57.93852724134922, 56.05798915028572, 55.5511761456728, 57.843433544039726, 59.81619268655777, 58.945944383740425, 62.50825323164463, 64.48579251766205, 61.91488467156887, 57.25568488240242, 59.64667618274689, 62.508454620838165, 61.08280532062054, 56.21641404926777, 48.72859664261341, 46.67566940188408, 47.777655869722366, 49.59787219762802, 49.42578703165054, 55.25218538939953, 56.568791940808296, 48.44722934067249, 48.33668567240238, 44.76581588387489, 47.04461060464382, 52.2051402926445, 50.71873985230923, 49.598681554198265, 50.38431219756603, 53.494107127189636, 50.82561671733856, 51.725970804691315, 51.321300119161606, 54.50020954012871, 51.178051605820656, 54.86603491008282, 55.774991735816, 59.28433522582054, 58.84663671255112, 65.43177455663681, 64.23084139823914, 70.48462942242622, 68.13507869839668, 73.95575076341629, 71.07305824756622, 72.51310497522354, 60.66999927163124, 64.68276634812355, 70.59446632862091, 75.08865997195244, 69.24279525876045, 80.7378776371479, 29.75849077105522, 0.7164213352371007, 0.35067421733401716, 0.4329477885039523, 0.0751930518890731, 34.26191411912441, 80.25439158082008, 62.177032604813576, 55.50028547644615, 33.18132430315018, 29.712366946041584, 39.061242789030075, 42.43372902274132, 29.41148579120636, 2.4253530940040946, 0.04789264865394216, 0.10077597326016985, 0.015394860929518472, 0.005624442237603944, 0.027268997400824446, 0.056722384033491835, 0.061473001187550835, 0.03861706434690859, 0.15530816075624898, 0.2588931703940034, 0.1824701126315631, 0.23790272563928738, 0.11222077358979732, 0.16663269605487585, 0.1632121077273041, 0.14389542862772942, 0.23890792013844475, 0.5921676463913172, 24.183789007365704, 84.36390146613121, 60.41366882622242, 56.89666874706745, 46.409835666418076, 65.51669239997864, 76.11849591135979, 89.49426457285881, 1.7852115374989808, 0.09228769631590694, 1.8749869451858103, 5.079238275066018, 59.010936096310616, 82.3319984972477, 91.0994504392147, 90.9447531402111, 86.91599652171135, 71.40388369560242, 78.02316650748253, 83.53075057268143, 83.42646896839142, 83.19785803556442, 75.23943588137627, 75.6819449365139, 75.97585156559944, 80.74640437960625, 81.66462510824203, 80.18309220671654, 74.21517044305801, 81.92804217338562, 75.96969589591026, 77.15442672371864, 76.9252610206604, 73.26400548219681, 73.82210433483124, 69.53402683138847, 61.10626146197319, 60.24311877787113, 58.09841126203537, 57.11687073111534, 59.63514760136604, 53.562347665429115, 52.072717398405075, 55.54403632879257, 56.10002629458904, 57.01990373432636, 56.92981816828251, 55.72837583720684, 49.093285873532295, 48.17887634038925, 46.55050411820412, 49.04798850417137, 49.01331916451454, 50.31714700162411, 49.03202936053276, 50.582315772771835, 51.069601625204086, 48.099061623215675, 53.0880381166935, 54.31177765130997, 54.903318509459496, 59.815314933657646, 60.60045540332794, 64.87768828868866, 68.91075387597084, 69.81945231556892, 69.78743523359299, 68.3147482573986, 67.9534712433815, 66.16178378462791, 64.78032231330872, 66.97171032428741, 54.3570826202631, 49.9002979695797, 48.43283951282501, 53.9312394708395, 55.45473352074623, 50.22312484681606, 49.252398535609245, 50.11822007596493, 52.68259987235069, 48.99351462721825, 48.14488336443901, 54.53618600964546, 51.656271144747734, 58.23156751692295, 64.2191532254219, 62.53946095705032, 57.683728113770485, 57.659082636237144, 60.38722604513168, 63.75835195183754, 58.54681760072708, 57.609913274645805, 61.23697064816952, 62.05496035516262, 62.297375947237015, 65.29169887304306, 69.0480937063694, 65.06856724619865, 59.42711256444454, 62.95797809958458, 65.79418390989304, 65.5597896873951, 59.86850447952747, 51.53797969222069, 48.16858269274235, 50.659303441643715, 50.014398247003555, 51.12018071115017, 56.627077013254166, 58.38153786957264, 51.47825829684734, 51.655192002654076, 47.543003261089325, 50.66293604671955, 55.42375758290291, 53.56607146561146, 52.96666882932186, 54.45129856467247, 57.60932810604572, 53.55100907385349, 54.45509076118469, 54.313396364450455, 58.003222569823265, 54.632351249456406, 58.610456585884094, 59.6428307890892, 62.84733183681965, 62.39827573299408, 68.71075540781021, 68.24733227491379, 72.17501431703568, 71.2535485625267, 77.80858442187309, 74.37607660889626, 75.70236504077911, 63.391698226332664, 67.85695642232895, 74.69367116689682, 78.66046071052551, 72.68858715891838, 82.81499817967415, 30.548158697783947, 2.0629461156204343, 2.0127854822203517, 0.8828359586186707, 0.1647614745888859, 42.59961672127247, 83.31519573926926, 72.29824930429459, 60.85530012845993, 56.96251541376114, 41.2087469547987, 46.26556880772114, 59.45252940058708, 43.513163700699806, 2.950096861459315, 0.27870607911609113, 0.25895346247125417, 0.07359944560448639, 0.1414751514676027, 0.2020452223950997, 0.14855620509479195, 0.1844467339105904, 0.2744589757639915], [0.06549115569214337, 0.02279041633300949, 0.00729428564227419, 0.06344400811940432, 0.09428217366803437, 0.10373839671956375, 0.09540518411085941, 0.058173609286313877, 0.06503670898382552, 0.1457833929453045, 16.910984963178635, 61.226471811532974, 41.91374972462654, 20.411744713783264, 37.65284076333046, 45.660474076867104, 66.02067455649376, 54.662073254585266, 0.10084545312565751, 0.5254559323657304, 1.1806369037367404, 4.332153238356113, 85.72999656200409, 88.96577373147011, 83.52556765079498, 82.52363741397858, 71.74235433340073, 67.50941947102547, 79.38346311450005, 83.41713666915894, 82.27476596832275, 69.28824082016945, 81.0679279267788, 78.79914566874504, 79.64605942368507, 75.39931610226631, 74.41928029060364, 70.76459839940071, 73.55053290724754, 71.56741932034492, 68.25597301125526, 67.77855902910233, 67.84082248806953, 67.71839305758476, 67.75009855628014, 64.85184967517853, 57.89437361061573, 54.40526023507118, 53.077660873532295, 52.23902687430382, 52.27108955383301, 48.85856866836548, 47.25098513066769, 47.10452578961849, 50.08392691612244, 48.569985553622246, 50.927664041519165, 52.951211258769035, 49.3016666918993, 48.390061408281326, 45.496680065989494, 46.38609454035759, 44.049231335520744, 44.54476274549961, 42.386983931064606, 42.271758913993835, 41.691028475761414, 42.73409150540829, 44.046085104346275, 44.76792857050896, 48.5587115585804, 51.68860360980034, 57.09969945251942, 58.55683006346226, 64.19396057724953, 63.26744109392166, 65.52804619073868, 61.49315670132637, 61.66491508483887, 56.931908056139946, 60.653204172849655, 60.02902306616306, 52.03223057091236, 49.28853079676628, 43.962029814720154, 48.57712157070637, 49.31962072849274, 43.02620843052864, 42.632275968790054, 39.91990551352501, 42.61803053319454, 46.00443162024021, 41.84205137193203, 47.46851205825806, 50.94912528991699, 54.68854263424873, 57.608883529901505, 58.160971105098724, 52.4493607878685, 50.18281660974026, 51.65366068482399, 52.12962694466114, 51.23546652495861, 56.56107075512409, 56.485910788178444, 57.77158319950104, 60.0855678319931, 57.661020532250404, 55.68739503622055, 56.6101261228323, 59.412338957190514, 59.60165619850159, 57.09250643849373, 54.039985835552216, 46.825020387768745, 44.2604885995388, 46.94304205477238, 47.344608306884766, 44.05162140727043, 41.21042646467686, 49.512954354286194, 52.27979488670826, 46.1123002320528, 47.00664684176445, 46.2112545222044, 46.205566227436066, 49.45201322436333, 47.71879702806473, 49.57749769091606, 49.89950381219387, 49.81993228197098, 48.225572034716606, 48.48720319569111, 47.311789467930794, 50.165903717279434, 52.25501261651516, 55.93513794243336, 59.684970527887344, 61.82853050529957, 61.22446931898594, 64.53610181808472, 66.45042389631271, 70.08677557110786, 69.62517634034157, 72.31219455599785, 69.5595234632492, 68.60066771507263, 63.04420307278633, 69.14021596312523, 68.63916724920273, 74.18064549565315, 69.62686344981194, 78.2025396823883, 66.18686243891716, 1.9570373673923314, 0.7450713228899986, 0.7939296355471015, 0.802350933663547, 13.987620379775763, 66.86434328556061, 60.520477294921875, 45.69829344749451, 34.96600113809109, 17.88386955857277, 23.2887090370059, 26.24321009963751, 20.851018242537975, 1.1625296878628433, 0.02787244324281346, 0.07267392807989381, 0.020371988975966815, 0.14595224638469517, 0.020441875167307444, 0.04301253044104669, 0.046920476015657187, 0.058808412723010406, 0.09468806165386923, 0.07744964837911539, 0.04739041134598665, 0.07326768332859501, 0.09545809181872755, 0.04689464927650988, 0.06511664571007714, 0.04219597874907777, 0.0628299848176539, 0.16599084221525118, 23.537675477564335, 72.49371841549873, 54.88376475870609, 27.619834430515766, 39.656283259391785, 56.928750425577164, 74.38755959272385, 58.13394695520401, 0.05080691786133684, 0.29920001223217696, 2.2674207435920835, 8.542242776602507, 90.19557774066925, 88.94463166594505, 85.25719553232193, 85.07121071219444, 72.36587047576904, 69.75406542420387, 80.28782978653908, 84.3630351126194, 84.21749532222748, 73.33601161837578, 81.88380494713783, 80.11898964643478, 81.30903258919716, 78.37673753499985, 75.12962937355042, 74.21947941184044, 76.08344659209251, 73.78589987754822, 71.02486923336983, 71.69392213225365, 71.72627359628677, 72.91577696800232, 70.10766685009003, 67.17148080468178, 61.03170566260815, 56.61953441798687, 54.5056888461113, 54.08062465488911, 54.02651555836201, 52.21762262284756, 50.499351024627686, 50.014493241906166, 52.13784970343113, 50.22125534713268, 52.03411526978016, 55.2947811037302, 49.1173879802227, 48.86825434863567, 44.077273830771446, 47.332053780555725, 45.63533462584019, 46.321425810456276, 45.83118751645088, 44.53933283686638, 44.38634544610977, 44.82676841318607, 47.05835446715355, 47.1639584004879, 52.333626598119736, 54.060394540429115, 60.45082703232765, 60.79335205256939, 64.61648270487785, 64.68145161867142, 65.11089697480202, 64.10015121102333, 64.94928404688835, 60.148040279746056, 63.11887286603451, 62.1227753162384, 53.73317889869213, 53.40755917131901, 47.90713392198086, 49.55914847552776, 50.994772240519524, 44.3907456099987, 43.577201664447784, 40.623392164707184, 43.32940936088562, 47.06381477415562, 45.76890125870705, 51.356345638632774, 53.66461917757988, 57.17139780521393, 60.51207974553108, 60.55201180279255, 56.2917336076498, 52.29309797286987, 55.47793507575989, 55.105125680565834, 52.84094117581844, 59.00258034467697, 58.846275731921196, 59.12020683288574, 61.6513954102993, 59.568502977490425, 57.549739703536034, 58.63865487277508, 62.85131402313709, 61.64567671716213, 58.24434623122215, 54.46079425513744, 48.15700091421604, 46.5841057151556, 49.441275000572205, 46.66732884943485, 42.6013608276844, 42.39029735326767, 50.35800240933895, 55.111300349235535, 49.29964140057564, 48.431444987654686, 48.030862882733345, 47.365058809518814, 50.830636247992516, 51.02678172290325, 51.33643090724945, 53.078964203596115, 51.27165958285332, 51.213526502251625, 49.349984899163246, 51.03664979338646, 53.63884516060352, 54.509982615709305, 58.26400637626648, 61.890147998929024, 64.13662165403366, 65.23267284035683, 65.64960926771164, 69.5088341832161, 71.92330062389374, 71.92443296313286, 74.70927312970161, 72.47412666678429, 70.01800686120987, 65.11783540248871, 70.27678057551384, 73.30762714147568, 74.264035820961, 75.39698302745819, 78.1284436583519, 73.11218842864037, 3.2422605715692043, 0.825914537999779, 1.132926782593131, 0.7409258640836924, 13.10317698866129, 74.73356902599335, 65.71982190012932, 56.885987520217896, 40.04154458642006, 16.81573547422886, 32.1568650752306, 39.0430873632431, 21.3155148178339, 2.3591100610792637, 0.14279535796958953, 0.18350647733313963, 0.052125862712273374, 0.10931710596196353, 0.06829537553130649, 0.09787923729163595, 0.10435417891130783, 0.08071699805441312, 0.13607685832539573, 0.23663899657549337, 0.2770421840250492, 0.20221201266394928, 0.2194265733123757, 0.13651935645611957, 0.22680291265714914, 0.1552318679750897, 0.2146630984498188, 0.31174281262792647, 31.899839267134666, 88.83278846740723, 54.67688485980034, 30.445100627839565, 52.89884626865387, 68.01506593823433, 78.75552400946617, 66.35398507118225, 0.19219138630433008, 0.8961334638297558, 3.726083147339523, 9.119981825351715, 95.741798132658, 92.69363969564438, 89.73619759082794, 88.02502781152725, 78.00085410475731, 72.47718170285225, 86.57373368740082, 86.00207716226578, 83.62630784511566, 78.14826339483261, 81.95445835590363, 83.23790788650513, 84.23821941018105, 81.5176185965538, 79.49108093976974, 75.83162650465965, 80.80150902271271, 78.01843196153641, 73.59555289149284, 74.78889405727386, 74.05517622828484, 75.50508722662926, 74.95740741491318, 69.90470454096794, 63.6207727342844, 59.470206052064896, 59.018824473023415, 56.905161291360855, 57.52161741256714, 55.50715930759907, 54.01295028626919, 53.3966613560915, 55.23820973932743, 53.1567270308733, 54.38082754611969, 54.83072340488434, 49.974925965070724, 49.58758234977722, 45.1514457911253, 46.980789229273796, 46.97644606232643, 47.73390881717205, 49.04502086341381, 48.257915899157524, 45.62026463449001, 48.102002665400505, 48.84622313082218, 50.101565569639206, 53.12934949994087, 57.26553775370121, 65.06646975874901, 64.06760975718498, 69.22932878136635, 69.0193672478199, 67.04516038298607, 67.29973912239075, 65.39543330669403, 62.500547245144844, 67.6806078851223, 65.06176561117172, 57.90748290717602, 59.2821541428566, 49.58526447415352, 53.079195991158485, 53.32273632287979, 44.305964559316635, 44.79655243456364, 39.41933177411556, 45.376576110720634, 48.203901797533035, 47.987507209181786, 58.06018151342869, 57.6736206561327, 59.97993350028992, 63.26501302421093, 64.12445470690727, 59.130774065852165, 54.950876757502556, 58.638001307845116, 58.34964618086815, 55.406544506549835, 62.50609874725342, 61.43800646066666, 61.68747827410698, 62.93370880186558, 61.01457618176937, 62.606819942593575, 62.591411769390106, 65.3838363289833, 63.189830258488655, 61.01726643741131, 60.44147573411465, 50.933736115694046, 48.67416076362133, 52.25997895002365, 48.63003373146057, 43.698472157120705, 42.26854048669338, 51.94185622036457, 56.653736382722855, 53.455930575728416, 52.41254076361656, 52.61847831308842, 52.1544586122036, 54.154542088508606, 53.0563136190176, 54.80551175773144, 55.93096196651459, 54.79292303323746, 54.28907386958599, 52.21144035458565, 53.806970939040184, 54.878946617245674, 57.447988763451576, 60.99254496395588, 64.86995950341225, 67.83034265041351, 66.16635873913765, 67.91519969701767, 72.50840082764626, 75.18076702952385, 75.01409277319908, 76.11176267266273, 75.42655304074287, 73.24939146637917, 68.27269971370697, 73.6177285015583, 76.39258280396461, 80.31603187322617, 77.36425906419754, 83.32597196102142, 72.94702649116516, 3.0353032518178225, 2.6469887886196375, 2.943589948117733, 1.0495904856361449, 18.45880150794983, 82.75648131966591, 73.56381699442863, 64.60231706500053, 54.22710299491882, 31.635061874985695, 45.92075631022453, 58.4026001393795, 33.985015377402306, 4.213738767430186, 0.25813540793024004, 0.2335695331566967, 0.12637447973247617, 0.3010722727049142, 0.2235217293491587, 0.12961842207005247, 0.24507292604539543, 0.20777975296368822], [0.017617702687857673, 0.007979329693625914, 0.10993168587447144, 0.04623496162821539, 0.11748560631531291, 0.12055494356900454, 0.0699198328948114, 0.08095279321423732, 0.10232047905446962, 0.2098482075962238, 19.494861513376236, 55.96463955938816, 36.610343903303146, 51.21395207941532, 57.55260095000267, 42.76064068078995, 76.36009454727173, 36.03734225034714, 0.45911561872344464, 0.543904536170885, 2.8172073047608137, 20.75703028589487, 97.4259665608406, 75.4222820699215, 83.55253100395203, 69.41894620656967, 65.68848878145218, 75.75666412711143, 83.08788433670998, 80.48018306493759, 70.89894399046898, 79.37813580036163, 83.37977707386017, 77.9943336546421, 75.23867592215538, 71.89173191785812, 73.99622619152069, 71.29906252026558, 69.8407007753849, 69.47929456830025, 67.89133697748184, 66.61550223827362, 70.42291313409805, 67.83929497003555, 65.68976551294327, 59.300913736224174, 53.049097806215286, 52.22902961075306, 52.68473155796528, 50.646251142024994, 51.479014456272125, 48.45312662422657, 46.03157736361027, 48.78019027411938, 49.33413974940777, 49.1435381770134, 52.458077520132065, 51.37930780649185, 48.69217559695244, 48.26925069093704, 46.92730709910393, 43.64786647260189, 47.0197257399559, 44.18518424034119, 44.81729932129383, 42.490699365735054, 42.405291348695755, 43.29514279961586, 42.91184216737747, 45.57126626372337, 47.02473007142544, 46.8676882982254, 54.52664852142334, 60.788913890719414, 60.22566631436348, 62.249380722641945, 65.61622425913811, 62.3222342133522, 62.13733613491058, 56.85874678194523, 57.77542859315872, 59.9268389493227, 48.91697533428669, 41.72903783619404, 46.21183209121227, 49.82239454984665, 55.91031387448311, 56.741443276405334, 44.088798612356186, 40.1660069078207, 41.31144404411316, 42.528123557567596, 40.11555701494217, 44.61674988269806, 49.851185604929924, 56.30616143345833, 57.941137701272964, 56.420801281929016, 55.148697942495346, 48.005077466368675, 53.08258920907974, 52.88823343813419, 54.080408066511154, 57.899127155542374, 57.91011996567249, 56.01950481534004, 53.701120018959045, 57.68641836941242, 58.3804739266634, 60.63022680580616, 57.21846587955952, 52.742895036935806, 51.769353076815605, 48.07879351079464, 43.76615032553673, 47.51964591443539, 45.40276050567627, 43.435891047120094, 42.56381884217262, 44.34856407344341, 46.33915185928345, 50.035243928432465, 49.25981193780899, 46.48516662418842, 46.21981166303158, 43.146384581923485, 45.92993661761284, 46.46829552948475, 48.44868466258049, 49.16722610592842, 47.93650634586811, 48.15668173134327, 46.62146531045437, 49.38648194074631, 50.77304653823376, 53.90267260372639, 56.20438389480114, 62.04520247876644, 65.35092249512672, 67.2582757472992, 66.4342899620533, 69.56118777394295, 69.64842349290848, 68.80775660276413, 69.37469378113747, 68.8326908648014, 67.70254790782928, 69.95478585362434, 66.62137672305107, 73.09219390153885, 66.38552337884903, 74.67775762081146, 64.5232281088829, 88.52367505431175, 27.802015654742718, 1.4995268359780312, 0.7538674352690578, 0.1816540618892759, 2.5678566098213196, 55.05280248820782, 61.10047437250614, 52.791901007294655, 40.355958715081215, 36.861578822135925, 23.172302283346653, 21.675156019628048, 11.12440561875701, 3.3247546199709177, 0.1561825443059206, 0.03970174286223482, 0.032293917902279645, 0.06475087080616504, 0.06855701227323152, 0.08939646708313376, 0.024968966718006413, 0.03977454383857548, 0.06951551084057428, 0.037961952039040625, 0.10827292644535191, 0.01924854066601256, 0.13296559714945033, 0.06039135063474532, 0.04643838059564587, 0.014468947283603484, 0.12511168577475473, 0.1396923791617155, 31.01472806185484, 67.58067324757576, 45.38363993167877, 51.44728995859623, 64.1416297852993, 52.790658473968506, 84.22551289200783, 37.45244711637497, 0.6670010683592409, 0.8491238113492727, 2.5720344856381416, 24.60685260593891, 99.11385878920555, 78.52958053350449, 84.84683275222778, 72.34744146466255, 70.25061517953873, 77.4116425216198, 84.41549509763718, 84.56611141562462, 71.8297952413559, 80.15662282705307, 84.6888068318367, 79.08400118350983, 76.36088490486145, 74.19353440403938, 76.98703810572624, 74.48869496583939, 74.28241923451424, 73.07476803660393, 69.95210319757462, 71.49583116173744, 72.22453325986862, 70.69065436720848, 66.99412152171135, 61.41315199434757, 56.52676239609718, 53.67085464298725, 54.779209569096565, 53.95810782909393, 55.09650394320488, 50.771123841404915, 46.78541511297226, 51.3503647595644, 50.621829852461815, 52.57899843156338, 54.588171020150185, 53.428146466612816, 48.54024454951286, 48.344175070524216, 47.29819759726524, 43.90596382319927, 46.13257214426994, 44.61146056652069, 48.5649698227644, 46.275839656591415, 46.48229397833347, 45.93621388077736, 45.87874956429005, 48.78923758864403, 49.801689460873604, 50.10080561041832, 55.92452511191368, 62.998191341757774, 61.89889892935753, 64.09455791115761, 66.28807380795479, 67.13777661323547, 63.64991717040539, 59.850387051701546, 60.284186974167824, 62.25012928247452, 50.74574500322342, 44.82283182442188, 47.373110577464104, 52.353263944387436, 58.056157529354095, 56.06583572924137, 46.24244324862957, 40.77086605131626, 42.69802004098892, 44.08679611980915, 43.40413615107536, 48.54715637862682, 52.888655215501785, 58.533092737197876, 60.44708803296089, 59.85367767512798, 57.835689559578896, 51.485420912504196, 54.656711742281914, 53.58846366405487, 57.673643454909325, 59.298865646123886, 59.97293807566166, 58.47255818545818, 57.708517983555794, 59.72745604813099, 61.34051889181137, 62.13156044483185, 59.24190670251846, 57.75555185973644, 53.69321644306183, 48.62035185098648, 46.60637632012367, 48.97312492132187, 46.546951308846474, 44.64361824095249, 42.0668663084507, 43.895461186766624, 45.892630219459534, 52.735698223114014, 50.07603473961353, 48.806564658880234, 48.95158387720585, 47.33328491449356, 49.731039851903915, 48.84642831981182, 50.43709896504879, 50.477346405386925, 51.620435267686844, 50.586662739515305, 49.196754321455956, 53.3573904633522, 53.71830649673939, 57.63957068324089, 60.778616443276405, 65.97760006785393, 66.75360962748528, 69.72001165151596, 68.79353776574135, 71.52232334017754, 69.64657679200172, 71.3620175421238, 70.54509177803993, 70.3644646704197, 70.05161225795746, 72.68051639199257, 69.2987510561943, 75.60240760445595, 68.32130670547485, 78.10550808906555, 68.67036357522011, 91.07461497187614, 32.80818432569504, 1.3871439476497471, 0.9532070544082671, 0.17869415431050584, 2.534545222297311, 61.45239628851414, 67.8914737701416, 61.518748328089714, 49.39536206424236, 33.16068761050701, 37.28429093956947, 36.68128229677677, 11.389033868908882, 4.115979038178921, 0.10365086040110327, 0.0920204415160697, 0.04484961311391089, 0.07477599458070472, 0.03239787052734755, 0.038820635454612784, 0.07614098969497718, 0.01570314165292075, 0.199517467408441, 0.1438575197244063, 0.3468605875968933, 0.12377838778775185, 0.21933647658443078, 0.17703711666399613, 0.1331597429816611, 0.26071555854287, 0.3331906726816669, 0.28833704825956374, 38.92334058880806, 79.43978369235992, 50.61539299786091, 71.62392988801003, 79.644455909729, 60.98560273647308, 92.5978696346283, 45.65454259514809, 0.6161252420861274, 1.2028066953644156, 6.28491785377264, 24.55532357096672, 104.72897708415985, 82.2728280723095, 87.66237527132034, 75.48535108566284, 71.39354825019836, 82.51509547233582, 87.52754330635071, 85.96677705645561, 77.30678334832191, 83.20826947689056, 88.96723285317421, 80.55012971162796, 79.99424234032631, 76.75753802061081, 81.71476721763611, 77.0347711443901, 76.3806514441967, 76.15276247262955, 71.10449016094208, 72.3973099887371, 74.16360720992088, 73.10476362705231, 68.88188302516937, 65.4156406223774, 58.73746857047081, 56.20269298553467, 57.177355885505676, 54.805363565683365, 57.41628706455231, 55.232844427227974, 49.58472490310669, 56.4116969704628, 56.79024025797844, 54.80989672243595, 56.413418278098106, 54.54287365078926, 48.770318403840065, 48.817781656980515, 46.574435234069824, 44.27508361637592, 45.909379720687866, 44.95098754763603, 49.86243300139904, 51.32411576807499, 48.76154847443104, 50.1019873470068, 47.05958940088749, 53.35231773555279, 51.78363651037216, 53.095489516854286, 59.45062570273876, 67.09198147058487, 65.83790436387062, 67.83932536840439, 69.40506175160408, 67.16651067137718, 66.81431517004967, 63.47938992083073, 62.364039570093155, 66.41738086938858, 57.13896654546261, 51.96543775498867, 49.9727600812912, 54.69943664968014, 57.60513313114643, 55.617923364043236, 46.38528138399124, 40.59534586966038, 41.97717972099781, 46.38346128165722, 46.01941421627998, 53.702784329652786, 56.22133858501911, 60.49677416682243, 64.96222615242004, 63.18525530397892, 60.334386080503464, 55.12892760336399, 57.49270476400852, 56.65955767035484, 62.22290374338627, 62.27010481059551, 63.16309109330177, 61.70275345444679, 59.650722965598106, 62.75054723024368, 63.52809950709343, 65.87530955672264, 62.90931411087513, 59.725951328873634, 55.83028256893158, 52.178963497281075, 48.51540148258209, 50.0953035056591, 47.28410795331001, 45.08589170873165, 42.0311064273119, 44.08864662051201, 47.19102814793587, 53.87671619653702, 53.382955491542816, 51.28288418054581, 52.59546294808388, 50.536319240927696, 53.52102488279343, 51.383221596479416, 52.504340037703514, 51.653691083192825, 52.86565124988556, 52.48012773692608, 51.39343164861202, 56.402208879590034, 56.90023295581341, 59.31721106171608, 61.68952636420727, 70.25379940867424, 71.60248383879662, 72.26452991366386, 72.48199984431267, 74.47899788618088, 73.86641755700111, 73.27092111110687, 74.76857274770737, 73.40027377009392, 73.54188457131386, 75.6957533955574, 73.48010748624802, 80.1664187014103, 71.78435727953911, 80.64609736204147, 71.21840044856071, 91.27286553382874, 30.13107217848301, 2.3168085934594274, 2.6741492561995983, 0.20951612619683146, 3.7141365883871913, 73.94671484827995, 73.66932213306427, 68.44556003808975, 60.54386883974075, 60.949588268995285, 43.211874067783356, 53.308677077293396, 27.341961041092873, 5.23846635594964, 0.23336842597927898, 0.21383750368840992, 0.3811307705473155, 0.19972042995505035, 0.14764477353310212, 0.15006947389338166, 0.11670110427075997, 0.14546838094247505], [0.05528322610189207, 0.16509207169292495, 0.050244002559338696, 0.06287403128226288, 0.10915485021541826, 0.0630341273790691, 0.13429457583697513, 0.05431560282886494, 0.07029976797639392, 0.14047822449356318, 32.97730565071106, 58.8137798756361, 50.79825818538666, 33.14151003956795, 49.008383229374886, 48.65924656391144, 81.40621617436409, 17.859776951372623, 0.33973599958699197, 0.8470598689746112, 0.9458575362805277, 49.77165587246418, 95.15571758151054, 79.6220751106739, 78.48240226507187, 66.29222318530083, 73.37388798594475, 79.30777117609978, 78.21655333042145, 71.507967710495, 78.44277039170265, 79.02005821466446, 76.88639670610428, 74.99530658125877, 74.56326976418495, 70.55614158511162, 69.67192143201828, 71.40573799610138, 72.51995980739594, 73.30217063426971, 68.51263403892517, 71.20096698403358, 67.3487488925457, 62.037264704704285, 55.291182696819305, 53.58890824019909, 50.973660573363304, 49.56227570772171, 52.32480727136135, 50.75605005025864, 52.04759694635868, 48.5340166836977, 46.358641013503075, 47.803285494446754, 47.780262529850006, 48.60741354525089, 54.570308178663254, 52.83834591507912, 49.64248560369015, 46.3547158241272, 48.16917546093464, 46.875048503279686, 44.99287270009518, 43.629965633153915, 44.17588233947754, 44.85917307436466, 41.168130934238434, 40.23218795657158, 40.25267265737057, 44.54060956835747, 46.655351892113686, 47.11077265441418, 47.95515574514866, 52.673339769244194, 58.63531865179539, 61.392051726579666, 61.041197553277016, 60.72736479341984, 59.20843429863453, 56.29098504781723, 60.18476530909538, 60.338246673345566, 54.783480539917946, 54.16881412267685, 40.58472163975239, 51.53717793524265, 58.80598649382591, 68.80995288491249, 64.63416695594788, 43.07755887508392, 41.32886230945587, 42.765595614910126, 42.37875357270241, 42.38812766969204, 47.036836221814156, 52.37560674548149, 56.15960709750652, 55.081065371632576, 52.54728153347969, 48.53266775608063, 55.55914431810379, 55.875777527689934, 54.695576056838036, 55.940127074718475, 57.109164744615555, 56.35723829269409, 55.430426225066185, 59.85939636826515, 59.044765681028366, 54.53460909426212, 50.1553250849247, 49.32095065712929, 46.258903965353966, 46.70036427676678, 46.92349970340729, 43.651936054229736, 43.62114630639553, 44.724717289209366, 43.659197464585304, 41.14008463919163, 46.0005634278059, 51.058057844638824, 45.40157876908779, 45.045762062072754, 44.93675351142883, 45.49752362072468, 45.03591679036617, 49.67398211359978, 46.48262456059456, 48.49120058119297, 49.61249761283398, 49.511248245835304, 48.06447207927704, 48.86684462428093, 49.41056124866009, 54.0431472659111, 59.366198033094406, 61.70088775455952, 64.62731972336769, 66.2194874882698, 65.42313382029533, 65.8207368850708, 69.87922310829163, 68.17175433039665, 69.5647443830967, 69.79185059666634, 70.46962022781372, 67.20016166567802, 70.08902505040169, 67.69928008317947, 69.14435774087906, 72.23065093159676, 72.59217113256454, 71.36739045381546, 80.81549227237701, 1.4356914488598704, 0.6608582229819149, 0.04180463314696681, 0.040916063444456086, 35.12306950986385, 63.74912604689598, 52.16623418033123, 44.12629880011082, 24.034897796809673, 21.554421298205853, 15.403517503291368, 10.943984650075436, 1.7720193578861654, 0.045503541696234606, 0.1200867300212849, 0.06344368899590336, 0.02848565018211957, 0.06235312524950132, 0.03388426986930426, 0.07793269003741443, 0.05876128634554334, 0.0766509490495082, 0.015908941059024073, 0.04176608599664178, 0.03686652722535655, 0.04226002609357238, 0.07127768854843453, 0.11139684866066091, 0.06786530095268972, 0.030039998709980864, 0.04774079781782348, 45.55030658841133, 64.86951872706413, 61.04704163968563, 36.88640668988228, 52.19669334590435, 57.27402649819851, 87.30705633759499, 19.501628950238228, 0.4577431204961613, 1.170953360851854, 0.5637876817490906, 57.23010465502739, 95.23871272802353, 83.02224665880203, 78.1964448094368, 68.69716733694077, 76.42657577991486, 83.59119012951851, 80.5570225417614, 73.5913959145546, 80.26337429881096, 82.9414401948452, 78.88605460524559, 77.8087668120861, 75.71746543049812, 74.6559239923954, 71.73227727413177, 74.91402894258499, 75.13633981347084, 74.07834738492966, 73.75097215175629, 74.12345856428146, 70.04603415727615, 64.78044390678406, 57.653569132089615, 56.026633232831955, 53.57308208942413, 55.34944497048855, 54.627677500247955, 52.94748745858669, 54.64641809463501, 51.555394157767296, 49.81593109667301, 50.27445629239082, 50.17698012292385, 50.079158172011375, 55.72656713426113, 53.42998556792736, 46.81278504431248, 45.890179350972176, 47.77043625712395, 47.35737942159176, 44.917940720915794, 44.6779265999794, 45.70526987314224, 46.96485288441181, 44.20226812362671, 42.97272630035877, 43.487078100442886, 47.273236736655235, 49.54246737062931, 48.29383157193661, 51.597153916954994, 56.35319910943508, 60.63525393605232, 63.88765901327133, 62.65008442103863, 63.71230982244015, 61.15692414343357, 59.802065044641495, 61.211876794695854, 61.98712259531021, 56.992226019501686, 56.66683807969093, 43.659763634204865, 54.3852087110281, 62.26910926401615, 67.42099061608315, 64.72110629081726, 45.19142724573612, 43.73289451003075, 42.6750198751688, 45.642630234360695, 44.60216246545315, 49.246531650424004, 57.883213609457016, 58.42028059065342, 59.92952920496464, 55.225548818707466, 52.13389791548252, 57.13241949677467, 57.15148687362671, 60.2349454164505, 57.88550868630409, 58.63754153251648, 56.97865314781666, 58.335852921009064, 60.50672583281994, 60.16263909637928, 57.16803498566151, 52.80235044658184, 52.92147405445576, 46.77733674645424, 50.0778092443943, 48.30968052148819, 44.04280588030815, 45.037368312478065, 44.380679950118065, 43.79681088030338, 41.29245266318321, 47.51950912177563, 53.1812547147274, 48.80543991923332, 48.610837161540985, 47.986211478710175, 46.68261542916298, 49.660413041710854, 50.594098940491676, 49.317698031663895, 51.436000764369965, 50.35337045788765, 51.377791687846184, 50.294728204607964, 52.751520574092865, 52.80699759721756, 58.05057182908058, 61.8078900128603, 64.3729841709137, 65.09352430701256, 70.16670808196068, 66.81355521082878, 67.6073782145977, 72.24002882838249, 71.77416622638702, 72.04161867499352, 71.77996471524239, 71.88252121210098, 70.93423649668694, 71.4024169743061, 71.64468437433243, 72.76621699333191, 72.67249882221222, 76.03882178664207, 71.61728784441948, 87.50534489750862, 1.968217792455107, 1.0875898716039956, 0.18952002574224025, 0.09504093060968444, 37.362969517707825, 72.74493053555489, 59.762714356184006, 53.956667706370354, 28.678748309612274, 32.923869118094444, 33.205453008413315, 8.740974012762308, 3.201487334445119, 0.040504230855731294, 0.18836969684343785, 0.035882005249732174, 0.08160581637639552, 0.035803063001367263, 0.03617417394707445, 0.04833708007936366, 0.024329779043910094, 0.13910859095631167, 0.22343617456499487, 0.11699066802975722, 0.19517568085575476, 0.17288690811255947, 0.10947181406663731, 0.17133902554633096, 0.09834401469561271, 0.12122825704864226, 0.27285379939712584, 56.977072432637215, 76.5431459248066, 66.00534617900848, 51.169243678450584, 66.18988707661629, 65.80500572919846, 96.73793748021126, 23.074280843138695, 0.39118924643844366, 1.6975345672108233, 1.3975779502652586, 60.62563665211201, 98.52611392736435, 86.9813834130764, 81.37707933783531, 73.1435139477253, 77.65564262866974, 85.07748037576675, 81.14610493183136, 77.6799613237381, 80.38884356617928, 85.34226536750793, 82.3737582564354, 84.60095554590225, 80.37624344229698, 76.1835028231144, 75.83863332867622, 77.42608934640884, 78.53804647922516, 77.82408758997917, 75.56007787585258, 77.98247069120407, 73.73664692044258, 69.17835831642151, 61.3089007884264, 59.36714418232441, 54.35908131301403, 55.87876416742802, 56.5310637652874, 55.54841749370098, 57.97382354736328, 53.47473196685314, 53.65360736846924, 53.00035402178764, 52.938402146101, 52.91508659720421, 59.29794989526272, 55.5345444381237, 49.59972269833088, 47.02580541372299, 47.31834031641483, 47.74405047297478, 44.62108165025711, 44.24782007932663, 47.69335739314556, 49.139206409454346, 46.41081981360912, 45.8906315267086, 47.0645709335804, 50.572231113910675, 53.636804670095444, 50.56329399347305, 54.458453580737114, 59.84061777591705, 64.51655566692352, 67.17186838388443, 66.90833732485771, 66.0225136578083, 64.71473023295403, 62.093406692147255, 65.10106310248375, 67.13989689946175, 61.43209017813206, 58.34795907139778, 46.91335044801235, 61.005908846855164, 65.52819058299065, 69.16271835565567, 65.79581782221794, 46.16567976772785, 43.588753044605255, 42.68404059112072, 49.23929303884506, 49.6288101375103, 53.53931710124016, 59.79687072336674, 60.70514738559723, 62.39464692771435, 58.41925844550133, 53.644370064139366, 60.47068476676941, 59.35205139219761, 61.128030493855476, 62.06166319549084, 62.2376773506403, 60.52813768386841, 62.443599700927734, 62.89907746016979, 61.67647406458855, 58.7865125387907, 56.18532411754131, 55.29982343316078, 50.06411477923393, 49.985835179686546, 51.235572919249535, 44.79647643864155, 44.14750166237354, 46.142854392528534, 45.06138302385807, 41.376937329769135, 47.731978520751, 54.17393624782562, 51.49036064743996, 50.68399831652641, 50.91452434659004, 51.04387320578098, 51.67649745941162, 52.884255051612854, 51.44114948809147, 53.80946360528469, 53.62255923449993, 54.724405109882355, 51.93491019308567, 54.646782875061035, 54.295769110322, 60.4095346480608, 66.59853994846344, 67.47040316462517, 67.90166482329369, 72.0745325088501, 68.29028517007828, 72.30518773198128, 74.08432066440582, 76.25534936785698, 73.51821184158325, 75.79272419214249, 77.07196354866028, 73.65591645240784, 76.55336737632751, 77.2758986055851, 76.67002871632576, 78.99346724152565, 78.54852631688118, 75.24527236819267, 85.11437639594078, 1.211863865610212, 1.5768824913538992, 0.6119825143832713, 0.16467862122226506, 47.246079593896866, 81.65861383080482, 68.8747850060463, 62.788476794958115, 42.67988361418247, 38.56481462717056, 48.86739939451218, 25.571681633591652, 5.429310165345669, 0.22758304345188662, 0.3561253217048943, 0.16934428102103993, 0.13388537045102566, 0.176871202129405, 0.07392251733108424, 0.218388338398654, 0.12664500740356743], [0.049566477391636, 0.1304954179795459, 0.036304888417362235, 0.03454103345575277, 0.04756978843943216, 0.058719670414575376, 0.01902772575704148, 0.029229222782305442, 0.13494641898432747, 0.24731758137932047, 41.850502118468285, 52.99365498125553, 35.532740727066994, 36.010010316967964, 52.67417952418327, 51.077729389071465, 86.94299787282944, 7.101611830294132, 0.1941990590421483, 0.4548520693788305, 1.2067548022605479, 78.5316476225853, 87.62853428721428, 82.33909651637077, 70.53566828370094, 72.00873523950577, 77.15964764356613, 79.46082696318626, 77.1491602063179, 80.58466225862503, 83.07005569338799, 75.35561844706535, 74.9237260222435, 74.17327389121056, 69.76427927613258, 66.80572763085365, 65.35419791936874, 61.872399151325226, 62.22929500043392, 66.19845941662788, 60.792706087231636, 59.46613647043705, 53.958753794431686, 53.73980574309826, 51.59209258854389, 54.144723415374756, 52.89605721831322, 52.07921124994755, 51.20487056672573, 50.4294765740633, 49.84869673848152, 49.78353023529053, 45.977920442819595, 49.82074163854122, 48.787881061434746, 49.21118974685669, 47.914942502975464, 49.80916365981102, 46.398326084017754, 45.95634900033474, 46.49077132344246, 47.4458234757185, 44.245844185352325, 49.1786976903677, 47.915330082178116, 47.48803161084652, 42.91595734655857, 41.74428641796112, 40.44842675328255, 40.57997949421406, 44.25093591213226, 46.32833383977413, 49.37946751713753, 46.044884249567986, 49.68306362628937, 57.638974115252495, 59.8969991505146, 61.121487244963646, 56.02072075009346, 52.11105354130268, 56.19448162615299, 60.3498512506485, 54.21655476093292, 64.52427685260773, 50.19489996135235, 46.653877571225166, 52.60342352092266, 57.49409168958664, 56.00190795958042, 57.64860659837723, 46.34833216667175, 44.01573233306408, 41.40387028455734, 31.670133993029594, 40.52674815058708, 50.32296068966389, 54.992457926273346, 55.34901179373264, 48.24540697038174, 45.3040874004364, 53.198201805353165, 55.81640191376209, 57.66429975628853, 56.44956573843956, 56.1812849342823, 56.74970403313637, 55.05463778972626, 56.42857186496258, 53.115666434168816, 51.650012880563736, 44.77204754948616, 46.267358511686325, 46.6235475987196, 44.58373725414276, 46.56663805246353, 44.59324814379215, 40.81498168408871, 41.346649155020714, 42.954035103321075, 42.013988345861435, 43.56657363474369, 46.02490492165089, 48.34636755287647, 45.87637849152088, 44.42134156823158, 45.23370757699013, 46.50679886341095, 48.2503467053175, 48.61345902085304, 47.54320465028286, 48.8011309504509, 49.429381638765335, 51.10008738934994, 48.10533508658409, 50.28811275959015, 49.279487282037735, 52.61664301156998, 58.57224963605404, 62.72510379552841, 66.36188864707947, 69.15669187903404, 64.38826695084572, 69.69587534666061, 66.8230850994587, 67.49276876449585, 67.55126282572746, 68.01129654049873, 66.11747056245804, 66.29581019282341, 61.64741322398186, 64.09804612398148, 65.69763869047165, 75.50465404987335, 67.9638446867466, 74.58552896976471, 16.406636126339436, 0.9252251184079796, 0.8606083982158452, 0.5040475248824805, 12.32872724533081, 65.06872683763504, 56.3853719830513, 49.39536206424236, 29.353094324469566, 17.984144277870655, 14.6107261441648, 4.659734610468149, 0.4546601796755567, 0.20852412708336487, 0.0776535015029367, 0.005413788721853052, 0.02334865610464476, 0.06981669663218781, 0.11396579284337349, 0.08371623946004547, 0.04623331034963485, 0.03657456261862535, 0.03110762823780533, 0.041003276928677224, 0.0786119926488027, 0.044268990168347955, 0.021026598478783853, 0.03008524374308763, 0.0030039438388484996, 0.13559214683482423, 0.7369869598187506, 57.11876682937145, 58.061507642269135, 39.737971276044846, 32.66457483172417, 58.22076089680195, 58.62475521862507, 95.1532781124115, 7.013220023363829, 0.20458139333641157, 0.39800242928322405, 1.7426335159689188, 86.30418375134468, 89.75268870592117, 85.6542058289051, 73.77725154161453, 74.9658353626728, 79.62057039141655, 83.99904504418373, 77.30621337890625, 83.9110417664051, 83.75794798135757, 76.47639870643616, 77.16331824660301, 75.5403645336628, 72.41203039884567, 68.36938932538033, 66.63192495703697, 66.67747691273689, 65.1903735101223, 68.23732361197472, 62.2267909348011, 62.43972770869732, 57.44993805885315, 55.518372505903244, 53.96670676767826, 56.0271880030632, 54.69834230840206, 53.68694677948952, 54.10245068371296, 52.95797109603882, 52.353134751319885, 52.189906910061836, 49.73407968878746, 51.34614698588848, 50.606763660907745, 49.48410250246525, 48.4924279153347, 50.59250682592392, 47.200672030448914, 45.61645343899727, 44.84401948750019, 46.83950521051884, 45.22600919008255, 48.75947758555412, 48.70938867330551, 51.47972881793976, 46.50316625833511, 44.15668956935406, 43.46040353178978, 42.813332453370094, 46.922941133379936, 49.233122169971466, 50.33224359154701, 48.87162856757641, 52.23264701664448, 60.016103759408, 62.12977834045887, 63.439290672540665, 57.43234500288963, 56.39170244336128, 58.69418889284134, 62.190958857536316, 56.03605292737484, 65.51489129662514, 53.217512369155884, 51.908528208732605, 55.5129311978817, 60.05633980035782, 54.684332460165024, 58.16030994057655, 47.064867317676544, 46.68962985277176, 44.711535796523094, 37.21584901213646, 44.457572624087334, 54.70168612897396, 57.96145521104336, 55.06636396050453, 48.98899286985397, 47.90993817150593, 55.86422234773636, 58.41713435947895, 58.99412959814072, 59.88888658583164, 59.56415221095085, 60.01761607825756, 58.14272068440914, 59.32175561785698, 54.754571691155434, 53.41435320675373, 48.590694442391396, 49.99164126813412, 46.03165715932846, 45.27412600815296, 45.64204126596451, 44.20093819499016, 40.218653082847595, 42.342195734381676, 45.078656896948814, 42.272898852825165, 45.16914904117584, 48.5558845102787, 50.49870125949383, 48.5630851238966, 48.38678598403931, 47.682136595249176, 48.077820762991905, 50.016104355454445, 51.30796283483505, 50.897565856575966, 49.6925213187933, 50.56510269641876, 51.96019783616066, 51.725628823041916, 51.71483740210533, 50.98939552903175, 56.03348806500435, 60.94220906496048, 65.14383360743523, 68.97888422012329, 70.48780605196953, 65.5715462565422, 70.66250547766685, 67.12909787893295, 70.2150870859623, 69.4899719953537, 70.22487536072731, 68.52979391813278, 68.52385863661766, 65.05670428276062, 68.59355449676514, 67.66803815960884, 77.85655304789543, 71.16681441664696, 79.31289330124855, 20.813337564468384, 1.3437839993275702, 0.32036158139817417, 0.5448904051445425, 12.308320440351963, 73.8096410036087, 63.91991928219795, 59.6561224758625, 36.293387711048126, 21.53056237846613, 33.91003780066967, 11.554993763566017, 1.2068145303055644, 0.11403908734791912, 0.04956036209478043, 0.03927285943063907, 0.03411494421015959, 0.04644383538106922, 0.033906901662703604, 0.014440189061133424, 0.057275514118373394, 0.15236223523970693, 0.24584514554589987, 0.16390374483307824, 0.17185762349981815, 0.17815112485550344, 0.1345273430342786, 0.18675340310437605, 0.13589532900368795, 0.2928080427227542, 0.9070673771202564, 68.24376806616783, 68.75824525952339, 46.96514926850796, 52.76714153587818, 73.97992506623268, 66.26212880015373, 104.63933989405632, 9.421227760612965, 0.3389697172679007, 2.143185934983194, 1.6783251729793847, 87.01425924897194, 94.1992937028408, 89.94758024811745, 75.94549119472504, 77.74437546730042, 81.55338987708092, 85.50064846873283, 79.59990710020065, 86.02740660309792, 84.236980676651, 81.13848254084587, 79.9788835644722, 80.16426041722298, 74.54743221402168, 72.88359269499779, 71.8752484023571, 69.17838871479034, 68.58499735593796, 71.81411728262901, 66.07742071151733, 67.1515242755413, 59.50728066265583, 58.34722191095352, 57.139213532209396, 60.30155964195728, 56.38632953166962, 56.51140362024307, 54.636956602334976, 55.54908245801926, 54.15189363062382, 54.971654042601585, 51.63787253201008, 55.746208280324936, 53.09949450194836, 52.82207518815994, 50.82954190671444, 52.052016109228134, 47.29676887392998, 43.98781903088093, 45.293037593364716, 46.391767635941505, 44.42251570522785, 48.105551674962044, 49.75885055959225, 53.20625737309456, 50.28184309601784, 48.27583573758602, 46.94531053304672, 46.43741838634014, 51.25596642494202, 53.641368225216866, 54.676478281617165, 51.86331823468208, 55.99317602813244, 64.12733495235443, 66.57153099775314, 66.65385738015175, 61.04842096567154, 59.16302673518658, 61.54690481722355, 67.2594004869461, 59.77199345827103, 68.46696808934212, 55.79984240233898, 56.37396119534969, 60.59771575033665, 63.07543359696865, 56.19116060435772, 60.993168130517006, 48.39188151061535, 46.85346946120262, 46.02703280746937, 40.766796469688416, 47.376146614551544, 56.97766900062561, 60.39174020290375, 61.54896430671215, 53.40389236807823, 50.44246807694435, 57.436840161681175, 60.041440799832344, 63.40717099606991, 62.827056124806404, 62.8348571062088, 62.142773643136024, 61.20369203388691, 63.38110439479351, 55.677975341677666, 54.86073039472103, 49.780448600649834, 52.10762992501259, 49.327824488282204, 46.7494310438633, 46.142151430249214, 44.51838456094265, 39.81832176446915, 42.08314083516598, 43.78726199269295, 42.56802521646023, 45.39507731795311, 48.194451704621315, 52.747876569628716, 50.60744762420654, 49.64378133416176, 51.85576803982258, 52.09669031202793, 52.08484634757042, 53.075886368751526, 51.788766235113144, 52.848453372716904, 53.20040188729763, 55.41743852198124, 54.1711699962616, 54.8265740275383, 56.073883697390556, 58.423954993486404, 64.5033247768879, 69.0452590584755, 72.3913899064064, 73.30051392316818, 69.13095965981483, 75.5256213247776, 70.97079813480377, 72.4429303407669, 74.26284268498421, 75.17977148294449, 70.52627518773079, 72.93218448758125, 68.77675786614418, 71.15901723504066, 70.82764461636543, 82.22391709685326, 73.86825665831566, 81.78478226065636, 18.32831460982561, 1.4191715978085995, 1.87471822835505, 0.5634562089107931, 18.262984715402126, 82.99659803509712, 71.63537487387657, 69.1092324256897, 52.61703439056873, 41.41810052096844, 46.91912993788719, 36.58963121473789, 3.945081070996821, 0.3728839661926031, 0.19856027502100915, 0.10869957230170257, 0.17813846381613985, 0.24763064895523712, 0.15081364021170884, 0.16647821059450507, 0.1564728724770248], [0.05013473244616762, 0.03452369317528792, 0.04222246971039567, 0.039841864054324105, 0.021264341776259243, 0.017864615219878033, 0.051366248590056784, 0.04412258669617586, 0.178383031161502, 1.895634087268263, 56.18960648775101, 44.844821244478226, 39.69512477517128, 42.280547842383385, 50.25592088699341, 58.04307863116264, 79.04692277312279, 1.8095285701565444, 0.11293698320514522, 0.35116171929985285, 15.947822146117687, 96.28648370504379, 78.33002284169197, 83.34684804081917, 68.63868847489357, 78.98484170436859, 80.7909531891346, 83.55932503938675, 81.33701428771019, 82.43681967258453, 79.70411270856857, 77.18844249844551, 71.17745384573936, 69.8918080329895, 65.84686428308487, 63.615802600979805, 57.119010016322136, 56.274079754948616, 53.60802501440048, 56.777047365903854, 52.250943034887314, 51.468603014945984, 51.09850287437439, 53.58695134520531, 52.55184128880501, 53.328261226415634, 52.85329811275005, 51.51828534901142, 50.517065674066544, 49.38777767121792, 47.45381444692612, 48.98874968290329, 44.615750536322594, 49.167305901646614, 48.28452967107296, 50.045799762010574, 49.49785776436329, 49.93027836084366, 46.748940870165825, 49.362642019987106, 43.71867187321186, 45.260743126273155, 44.56509545445442, 49.29530203342438, 47.756293416023254, 48.964700773358345, 45.1560815423727, 42.40945592522621, 39.65175770223141, 41.58155634999275, 41.84820704162121, 44.69968423247337, 41.97338752448559, 47.34228663146496, 43.97013857960701, 47.968804612755775, 50.95861718058586, 53.61874423921108, 51.6865137219429, 50.103081688284874, 49.26540143787861, 61.33827701210976, 55.610247775912285, 63.032697290182114, 44.05034467577934, 46.42211280763149, 41.41568765044212, 49.951507821679115, 40.502509251236916, 38.01610507071018, 57.41514332592487, 44.31045211851597, 48.89791555702686, 39.72975231707096, 52.89231441915035, 52.48360075056553, 52.42129549384117, 51.06383353471756, 48.238647133111954, 46.30904607474804, 52.08635866641998, 54.36561316251755, 55.404135435819626, 53.12500633299351, 58.363792821764946, 58.59061785042286, 53.29942837357521, 50.04775285720825, 46.900267750024796, 43.66020821034908, 43.82351964712143, 44.61162015795708, 43.37019257247448, 47.63784617185593, 43.3834158629179, 47.28009156882763, 48.54391135275364, 43.065984696149826, 42.403516843914986, 42.11766578257084, 43.54844480752945, 49.71359498798847, 45.969112515449524, 46.23768210411072, 43.08480888605118, 44.14532817900181, 48.733718767762184, 48.303460255265236, 48.677945360541344, 48.15659813582897, 47.137439623475075, 47.87479765713215, 49.482058212161064, 48.68771083652973, 48.56935478746891, 50.04351608455181, 51.24192237854004, 50.99253036081791, 52.34558455646038, 56.088262125849724, 62.48345576226711, 62.47597396373749, 64.91241082549095, 65.13070151209831, 63.10421325266361, 63.589903190732, 62.284323647618294, 61.94441668689251, 65.82586660981178, 61.29454515874386, 63.5202681273222, 64.07624289393425, 74.1309441626072, 72.18997031450272, 79.31658670306206, 37.488442584872246, 0.31000499962829053, 0.3778298757970333, 0.06827956778579392, 1.5286299493163824, 54.566261395812035, 62.352875769138336, 52.028305381536484, 36.96223922073841, 23.00409860908985, 17.489826902747154, 3.925431137904525, 2.1206448320299387, 0.017235851009900216, 0.14722281805006787, 0.017481898939877283, 0.025161053090414498, 0.043059181844000705, 0.08163642254658043, 0.1058824390929658, 0.02093449980748119, 0.018429844167258125, 0.083323368744459, 0.055602453503524885, 0.027411443370510824, 0.06416170203010552, 0.03748306269699242, 0.006052207345419447, 0.016005409124772996, 0.43609119951725006, 3.256084229797125, 70.59260442852974, 52.29904465377331, 47.03368999063969, 36.22791722416878, 58.61254647374153, 66.77475929260254, 85.80941990017891, 1.7660441785119474, 0.20890637766569853, 0.2204753615660593, 20.8378329500556, 103.84216547012329, 80.30057430267334, 86.5792053937912, 68.18725749850273, 81.9717626273632, 83.14294338226318, 85.36987468600273, 83.76166418194771, 83.6660461127758, 82.04262882471085, 80.49316316843033, 71.78552761673927, 74.34613421559334, 66.65036156773567, 65.51629722118378, 59.14374276995659, 58.75254236161709, 55.92992082238197, 58.82997080683708, 55.84395423531532, 54.6867111325264, 52.63461224734783, 55.917043313384056, 54.2075302451849, 54.77395445108414, 54.793709591031075, 53.33737313747406, 51.19981303811073, 50.186578407883644, 50.628612488508224, 52.36252024769783, 47.57146753370762, 50.96818886697292, 48.15452344715595, 51.7359034717083, 50.107174068689346, 50.30034810304642, 45.51687218248844, 47.401856034994125, 45.87616950273514, 44.93383526802063, 45.228087678551674, 50.22986188530922, 49.09520857036114, 49.650457575917244, 46.912085115909576, 46.86699293553829, 42.35596239566803, 45.089949890971184, 44.29184831678867, 45.99280804395676, 45.11130854487419, 49.6906404197216, 46.02669842541218, 50.48172377049923, 51.85918405652046, 56.868090480566025, 53.46276640892029, 53.74766752123833, 49.99554365873337, 61.516981422901154, 58.89177829027176, 63.499240055680275, 46.80024951696396, 51.79325379431248, 44.77375365793705, 56.01431429386139, 43.03377762436867, 37.29489617049694, 58.52177694439888, 43.22235390543938, 48.89809034764767, 43.080921694636345, 58.933450654149055, 57.040236443281174, 55.71454457938671, 54.04961071908474, 52.006422355771065, 50.10445721447468, 54.340777695178986, 55.41378691792488, 55.85806667804718, 56.58796951174736, 58.725005239248276, 58.802927657961845, 55.59322848916054, 51.10787697136402, 49.72017623484135, 45.710331201553345, 45.25268375873566, 45.990645959973335, 46.694550588727, 49.03802543878555, 45.80567568540573, 48.80891673266888, 49.38218057155609, 42.517085149884224, 42.466354072093964, 41.32319301366806, 44.44559946656227, 50.98105497658253, 46.94679245352745, 48.19626420736313, 46.900412142276764, 45.81326387822628, 48.68860758841038, 50.28213948011398, 51.97487644851208, 50.646680518984795, 48.558844551444054, 49.26540523767471, 51.6497240960598, 51.694440096616745, 50.90739592909813, 52.83903367817402, 53.39184321463108, 53.09725642204285, 54.56173583865166, 57.13589631021023, 63.4887982159853, 63.147777915000916, 65.95191344618797, 66.50296747684479, 62.277567610144615, 64.10693764686584, 65.96417918801308, 63.66918593645096, 66.45103186368942, 63.56387838721275, 65.6849017739296, 66.84582307934761, 77.84461408853531, 74.75266680121422, 84.38107654452324, 43.31574909389019, 0.21973875031108037, 0.7384147332049906, 0.21323146589566022, 1.751466616988182, 60.792713686823845, 69.63615775108337, 61.67915292084217, 42.7929313480854, 25.72632573544979, 37.09813892841339, 10.853051729500294, 2.8006214322522283, 0.03532913120579906, 0.0694939291861374, 0.04563778878946323, 0.049825149253592826, 0.0545316197531065, 0.007501923719246406, 0.034399717405904084, 0.05789779381302651, 0.17255357990507036, 0.17213156505022198, 0.09800826708669774, 0.13453011866658926, 0.20106212905375287, 0.18392565718386322, 0.11258528684265912, 0.27055323065724224, 0.5883987830020487, 3.7748953280970454, 85.3677847981453, 58.43962915241718, 56.231476441025734, 60.40186285972595, 70.87084829807281, 72.19468966126442, 96.4605675637722, 2.4282433139160275, 0.3151404537493363, 1.0515191196464002, 20.831688679754734, 105.46173736453056, 84.08698752522469, 89.70409691333771, 71.44010335206985, 84.84510004520416, 87.37057372927666, 89.74538549780846, 84.92276787757874, 86.62299424409866, 87.18775033950806, 82.89942964911461, 77.04424783587456, 79.32972639799118, 72.20543548464775, 69.97047141194344, 62.69247494637966, 62.573043555021286, 59.588071927428246, 61.696453392505646, 58.66737373173237, 55.96697263419628, 55.6678830832243, 57.603970393538475, 56.73450484871864, 58.2272357493639, 58.38662579655647, 56.13161779940128, 53.47241409122944, 53.52173164486885, 53.034707978367805, 54.17492799460888, 50.73980212211609, 54.329518899321556, 51.798714101314545, 52.467295825481415, 52.987259924411774, 52.28410005569458, 46.74808211624622, 49.59713503718376, 45.35668037831783, 45.83801954984665, 45.62569074332714, 50.88154211640358, 50.18300659954548, 50.53902469575405, 51.90973274409771, 49.330081567168236, 45.93610368669033, 48.545013293623924, 47.36894980072975, 50.21695397794247, 47.9551937431097, 51.87847942113876, 48.45243126153946, 53.19748744368553, 54.06819172203541, 59.473352283239365, 56.97807177901268, 56.19765065610409, 55.41917122900486, 65.99211528897285, 61.84415906667709, 66.00066483020782, 52.64197625219822, 56.72362983226776, 50.41903853416443, 63.163881450891495, 44.412940219044685, 42.23771654069424, 61.53943441808224, 51.163619980216026, 51.67726881802082, 46.32041126489639, 58.81025746464729, 57.31605984270573, 57.92492777109146, 56.972235292196274, 54.082611948251724, 52.354403883218765, 57.731784135103226, 60.980518609285355, 60.35996250808239, 58.187410086393356, 63.21011357009411, 62.67323657870293, 59.40660886466503, 53.225043565034866, 52.09453962743282, 50.67106381058693, 47.7493891865015, 48.486317843198776, 47.80046224594116, 49.62364241480827, 48.42893332242966, 50.51880598068237, 49.18481916189194, 43.20957139134407, 42.570346891880035, 42.54929222166538, 44.8045814037323, 52.62926213443279, 50.113337337970734, 49.87497232854366, 50.045423582196236, 49.94936853647232, 53.03015202283859, 53.36201101541519, 55.82362152636051, 54.20206233859062, 50.51050342619419, 52.305500507354736, 53.448194190859795, 54.327649399638176, 54.16157931089401, 57.46908523142338, 55.956857576966286, 55.936395674943924, 56.765412390232086, 61.31776951253414, 68.16770374774933, 68.30043822526932, 69.52269583940506, 70.118108689785, 66.50180473923683, 67.44766518473625, 67.7977479994297, 66.86017110943794, 71.75135225057602, 68.07510271668434, 69.53521996736526, 72.17716500163078, 80.46648859977722, 77.9867872595787, 85.0981056690216, 46.178990453481674, 0.7277082139626145, 2.2585869301110506, 0.27341174602042884, 2.9170203488320112, 69.97227251529694, 76.89735531806946, 69.17857110500336, 59.6914491802454, 45.95604121685028, 48.406560122966766, 37.45012924075127, 3.7680963054299355, 0.13065039325738326, 0.2273660691571422, 0.07737856547464617, 0.22276266070548445, 0.19855120597640052, 0.09969225211534649, 0.23189281375380233, 0.15139855648158118], [0.014889950962242438, 0.06895351209095679, 0.13961552234832197, 0.0892748439218849, 0.026572380484140012, 0.030978553913882934, 0.05774484459834639, 0.13110721483826637, 0.3374047653051093, 3.5335185052827, 54.241158440709114, 47.74880401790142, 35.90237349271774, 42.6004146784544, 53.88824477791786, 64.7447182238102, 66.51539281010628, 0.35608536447398365, 0.09056028080522083, 0.2756125701125711, 50.17356790602207, 93.47661048173904, 78.98120909929276, 75.88990777730942, 70.8901284635067, 81.5017506480217, 82.2869025170803, 83.48855003714561, 79.23304438591003, 79.37470078468323, 75.66083326935768, 73.43192607164383, 64.0750041604042, 65.4038156569004, 59.33552607893944, 56.16129420697689, 53.44205752015114, 54.74492780864239, 54.250771924853325, 52.372950688004494, 52.6700035482645, 52.68831096589565, 54.356341660022736, 53.84071312844753, 51.21267534792423, 50.44284425675869, 49.51061747968197, 52.40097038447857, 50.032466277480125, 50.20065285265446, 50.83017647266388, 46.101831793785095, 46.58801190555096, 47.34372295439243, 49.51940260827541, 49.87267725169659, 48.69541682302952, 51.933268681168556, 46.969667226076126, 45.2195343375206, 44.252626821398735, 46.222167536616325, 46.00212134420872, 50.32980032265186, 47.081590220332146, 44.84884902834892, 45.956816375255585, 44.888477101922035, 42.89703816175461, 43.15979406237602, 40.95605291426182, 39.137132316827774, 40.622989386320114, 43.495240062475204, 46.484250873327255, 45.988271087408066, 45.009591802954674, 47.3232002556324, 46.74508027732372, 47.170136868953705, 44.05635975301266, 52.917339876294136, 57.70055741071701, 60.66347502171993, 47.79679164290428, 38.40512439608574, 29.439592882990837, 42.649211660027504, 52.241793125867844, 25.853033736348152, 41.555276960134506, 33.97073194384575, 35.663514509797096, 49.2080245167017, 60.69826975464821, 55.157179087400436, 50.7152858376503, 46.87950186431408, 46.60862199962139, 46.90562926232815, 47.91825972497463, 49.45823349058628, 51.48092955350876, 50.481883361935616, 47.9024525731802, 47.95126475393772, 45.73295518755913, 44.67502735555172, 43.81645582616329, 41.33492298424244, 42.94800482690334, 45.61111852526665, 47.10448399186134, 52.499632090330124, 44.18095126748085, 45.70664159953594, 49.654033184051514, 44.62260156869888, 41.92901350557804, 43.37982505559921, 44.064692705869675, 48.106505423784256, 46.02579027414322, 47.105266749858856, 46.81904710829258, 43.7140741199255, 45.106448605656624, 50.95735564827919, 48.659903928637505, 48.20259466767311, 47.145422995090485, 47.09163688123226, 48.98699797689915, 48.61836075782776, 47.87307634949684, 46.8530248850584, 49.54749070107937, 48.68083320558071, 50.0704338401556, 49.24831375479698, 52.33355440199375, 50.70908457040787, 52.06376887857914, 52.01895408332348, 54.241819605231285, 57.34953984618187, 58.850998878479004, 58.81776966154575, 61.828811690211296, 57.15453431010246, 57.37306818366051, 60.32833680510521, 68.56302693486214, 71.29748180508614, 78.04376140236855, 61.26541592180729, 0.10832850588485599, 0.4386823042295873, 0.08846931683365256, 0.4967252881033346, 51.77718445658684, 65.79321876168251, 54.02701713144779, 39.63334769010544, 19.55104149878025, 20.394208654761314, 2.5726054050028324, 2.3717080475762486, 0.12350846867775545, 0.094411463214783, 0.0728913773491513, 0.04232307896018028, 0.06058256869437173, 0.01618272490304662, 0.02381589187280042, 0.09799902734812349, 0.08301044959807768, 0.033916108004632406, 0.0916432226949837, 0.06467244806117378, 0.02599234569061082, 0.07858493394451216, 0.08260672868345864, 0.20317082293331623, 0.4024751455290243, 6.75640320405364, 67.26911276578903, 57.910978719592094, 40.57824298739433, 39.58496868610382, 64.65061247348785, 72.18867838382721, 73.21287542581558, 0.2287183958105743, 0.036069037596462294, 0.15935031260596588, 59.346594884991646, 95.45204848051071, 82.72379547357559, 78.73752817511559, 74.57482874393463, 83.75683844089508, 83.28947871923447, 83.44435840845108, 81.58163756132126, 80.82841917872429, 78.392643481493, 74.69643741846085, 67.94632002711296, 67.82528132200241, 61.55486539006233, 57.86440081894398, 55.672298446297646, 58.47970940172672, 56.22913956642151, 55.12620694935322, 54.436604753136635, 54.87743429839611, 54.45472598075867, 55.32463990151882, 53.01803067326546, 52.2261493653059, 53.059087470173836, 54.80146877467632, 52.78850398957729, 52.856584936380386, 51.0678119212389, 48.47629018127918, 49.974112808704376, 50.75066953897476, 51.5590001642704, 51.318830251693726, 52.054254189133644, 52.202066257596016, 47.55090303719044, 44.99757304787636, 45.14880493283272, 46.80323615670204, 45.654857978224754, 51.37185260653496, 48.25742192566395, 44.636007249355316, 48.05302709341049, 47.55204297602177, 45.298627093434334, 43.80997717380524, 43.693764209747314, 41.72745332121849, 44.41519349813461, 45.74662305414677, 48.70683901011944, 48.04377838969231, 46.673727706074715, 50.6049245595932, 48.98786433041096, 47.98282966017723, 48.22195082902908, 54.76737320423126, 60.54247431457043, 63.21430094540119, 52.87964589893818, 44.43120963871479, 32.76749990880489, 49.345558136701584, 56.38203576207161, 27.70757932215929, 43.57654809951782, 38.75532120466232, 36.503512635827065, 52.4220934510231, 63.572591319680214, 56.02831654250622, 52.86337897181511, 49.55634042620659, 50.03683604300022, 49.63794104754925, 50.41273087263107, 51.1121441423893, 53.383992835879326, 52.565961331129074, 51.70746959745884, 50.177413299679756, 47.91365057229996, 46.84493511915207, 44.81765650212765, 43.78052495419979, 46.282280310988426, 47.98130214214325, 49.3355418741703, 52.118869721889496, 46.399192437529564, 44.599449411034584, 51.20933532714844, 45.196788758039474, 43.28107215464115, 43.77373471856117, 46.67946919798851, 49.77325178682804, 47.72427253425121, 48.60871687531471, 48.90693247318268, 45.84164455533028, 48.40202696621418, 51.9103217124939, 51.92757658660412, 49.87671263515949, 49.59181152284145, 49.937520772218704, 50.34905768930912, 50.82286946475506, 51.432561948895454, 50.368064269423485, 52.77914509177208, 50.80393888056278, 51.522130742669106, 52.313164696097374, 53.941422924399376, 53.37039716541767, 54.265241548419, 54.8604454100132, 56.576980501413345, 59.57275874912739, 61.02888621389866, 58.46603013575077, 64.56708535552025, 59.47248212993145, 59.589280262589455, 61.87408626079559, 71.7176328599453, 74.23727005720139, 82.25775048136711, 66.34858936071396, 0.11045062521588989, 1.560788454953581, 0.11237416067160666, 0.3355285566067323, 53.699250519275665, 73.4083141386509, 63.83668854832649, 47.25324220955372, 26.015817001461983, 39.19955536723137, 21.36493306607008, 1.8831263459287584, 0.11074846392148174, 0.042613143668859266, 0.10020538044045679, 0.040750260232016444, 0.06757764451322146, 0.08484450430842116, 0.02766841385891894, 0.027866489363077562, 0.11826214511529543, 0.1250350961345248, 0.2860524505376816, 0.15897573583060876, 0.204294508730527, 0.1892350855632685, 0.15644909406546503, 0.3912030503852293, 0.4465620423434302, 7.614714922383428, 83.54525819420815, 61.38103611767292, 47.30065606534481, 58.75421427190304, 77.01445743441582, 79.03869241476059, 81.86278447508812, 0.6789072544779629, 0.18831645516911522, 0.5044602777343243, 59.52824413776398, 99.32353153824806, 84.48320746421814, 81.86441838741302, 76.30481511354446, 87.31285482645035, 86.59800678491592, 84.6861469745636, 85.50568699836731, 82.48401314020157, 80.78820213675499, 79.93911489844322, 70.41762381792068, 69.74619224667549, 64.41455394029617, 60.70235833525658, 58.14890295267105, 62.19559460878372, 60.89442662894726, 57.90003530681133, 58.89914229512215, 57.771161422133446, 59.36667300760746, 58.580521792173386, 54.597982093691826, 54.74223755300045, 53.38813841342926, 57.786193415522575, 55.0454992800951, 57.0807308703661, 55.95117688179016, 51.740797609090805, 52.668590024113655, 53.59324760735035, 56.4845884591341, 53.94011199474335, 55.11779800057411, 54.72313217818737, 49.16690692305565, 46.875253692269325, 45.26743836700916, 46.76562197506428, 44.83796261250973, 51.48507133126259, 49.06639091670513, 46.60089321434498, 49.86361853778362, 50.12350559234619, 49.361346289515495, 46.22021824121475, 47.07648329436779, 45.76413631439209, 48.34672473371029, 47.78622440993786, 50.93062028288841, 49.20403093099594, 48.704794719815254, 53.11090528964996, 51.38935446739197, 50.44881373643875, 49.89732652902603, 58.59834663569927, 63.153960183262825, 68.41788232326508, 53.79187814891338, 47.13612109422684, 41.12133264541626, 56.134714633226395, 58.82508806884289, 29.380420558154583, 51.90964914858341, 40.27648597955704, 39.69459280371666, 54.609385281801224, 65.81778064370155, 59.7929797321558, 56.08567826449871, 52.54520304501057, 52.58712239563465, 52.30960048735142, 53.36010731756687, 54.568602070212364, 57.18606121838093, 55.878771767020226, 53.81592705845833, 51.667529940605164, 50.60314625501633, 51.22967943549156, 47.46221199631691, 45.897870138287544, 48.90338346362114, 49.28008385002613, 51.080526039004326, 52.32202582061291, 48.96961770951748, 46.582806184887886, 53.94836135208607, 45.123574286699295, 42.32508905231953, 44.13833275437355, 47.0504204928875, 51.14316947758198, 50.34409895539284, 51.770614609122276, 53.50984588265419, 48.03405091166496, 51.08209915459156, 56.67792588472366, 55.47796927392483, 52.890824899077415, 49.80317138135433, 51.56177021563053, 52.35172502696514, 52.99468852579594, 53.65754775702953, 52.67225302755833, 55.88544800877571, 53.608670979738235, 56.27892829477787, 55.021963343024254, 58.004791885614395, 56.67880363762379, 56.8317986279726, 57.481654956936836, 60.5107232183218, 64.19098913669586, 62.47322291135788, 63.6872273683548, 68.89398157596588, 63.22848178446293, 63.32185037434101, 67.44721680879593, 72.89473369717598, 77.09343999624252, 83.63744884729385, 68.81727889180183, 0.19801886344794184, 2.0202432945370674, 0.14007615856826305, 0.872780866920948, 64.59040850400925, 79.6260116994381, 69.31430742144585, 63.32027725875378, 34.65769708156586, 45.0358559936285, 44.79080334305763, 3.7550029205158353, 0.2243196716881357, 0.11316356831230223, 0.17761143506504595, 0.09952634500223212, 0.16423208580818027, 0.17011765827191994, 0.09947476573870517, 0.16577273985603824], [0.041003610895131715, 0.054519133118446916, 0.08610792909166776, 0.06626014685025439, 0.0310848164735944, 0.043051389293395914, 0.10783153411466628, 0.02045871635345975, 0.4939421749440953, 7.112222285941243, 57.71599218249321, 43.64959917962551, 33.89740347862244, 33.71148705482483, 50.855049937963486, 75.06996497511864, 53.344683945178986, 0.02675292646017624, 0.18049637088552117, 2.4913909379392862, 80.75559228658676, 85.96789419651031, 82.32532605528831, 75.8849148452282, 76.81479334831238, 81.95961087942123, 82.2522559762001, 80.20659774541855, 80.50103634595871, 74.67965751886368, 73.12130033969879, 65.1508404314518, 59.90752838551998, 57.46959060430527, 58.60358275473118, 58.483193814754486, 55.05086839199066, 56.50607630610466, 54.19665142893791, 54.55340288579464, 53.52531485259533, 51.758060082793236, 53.25699605047703, 52.81703665852547, 53.827672228217125, 51.521366983652115, 49.779608845710754, 50.313981771469116, 50.24500787258148, 49.07842867076397, 49.350421875715256, 47.834945395588875, 47.053274139761925, 49.63031105697155, 47.39449582993984, 47.80355527997017, 50.54483078420162, 50.85282705724239, 50.74933961033821, 48.840352445840836, 51.77401922643185, 44.4363659620285, 48.21533538401127, 47.71722391247749, 49.094965383410454, 48.25410470366478, 42.34968513250351, 47.84830167889595, 44.15291637182236, 40.02466209232807, 42.07345515489578, 38.77145893871784, 38.66661876440048, 42.76984378695488, 45.12745387852192, 45.94476342201233, 45.028381794691086, 44.42822299897671, 46.8781453371048, 45.67233704030514, 46.03014104068279, 46.91859416663647, 53.363728523254395, 54.65142622590065, 58.92441853880882, 37.648094817996025, 26.95006527006626, 38.997778594493866, 51.019581109285355, 37.58061423897743, 27.484056316316128, 42.82885082066059, 36.25306807458401, 57.819327637553215, 54.73198190331459, 53.85035701096058, 48.10842052102089, 47.678800374269485, 46.82387664914131, 47.10514135658741, 47.27161422371864, 48.03996339440346, 46.59658044576645, 44.260302409529686, 46.23426988720894, 44.41730238497257, 45.6038761138916, 41.33824020624161, 42.11106553673744, 44.51377160847187, 46.959590166807175, 45.62971092760563, 48.969142735004425, 47.43243679404259, 49.62850235402584, 47.44269244372845, 48.175304532051086, 44.46530520915985, 47.84352533519268, 43.8889217376709, 49.6720290184021, 49.771359488368034, 46.44713066518307, 45.8267417550087, 44.96737226843834, 44.3114248663187, 44.10498194396496, 48.5699437558651, 46.283127665519714, 46.43934488296509, 47.905279621481895, 48.77156473696232, 50.42736768722534, 49.011385068297386, 50.64592055976391, 48.597887456417084, 49.89518344402313, 48.22339095175266, 50.981035977602005, 48.519083485007286, 50.6934180110693, 51.22273340821266, 52.45162546634674, 51.554835587739944, 52.958902046084404, 53.594984114170074, 53.6178170889616, 56.5251474827528, 57.06084653735161, 55.27847237884998, 58.03737133741379, 60.38251809775829, 71.18986397981644, 71.66309058666229, 76.07124924659729, 67.29404702782631, 1.1004362697713077, 1.6234664479270577, 0.6109932018443942, 0.17392763664247468, 28.66203300654888, 71.28982901573181, 55.710801780223846, 47.22923509776592, 22.315533757209778, 23.77910692244768, 11.287480518221855, 3.4800871973857284, 0.12660386273637414, 0.11627154919551685, 0.10161107493331656, 0.013837065125699155, 0.04685977204644587, 0.029989881477376912, 0.08506764585035853, 0.02992770248965826, 0.017303772365266923, 0.07579739758512005, 0.0644922026549466, 0.11914380913367495, 0.09180113687762059, 0.04641315870685503, 0.23218348331283778, 0.2552378555992618, 0.7074484135955572, 12.400749530643225, 67.84917443990707, 56.59378319978714, 37.32079938054085, 37.271120846271515, 60.54521016776562, 81.20786681771278, 57.44151011109352, 0.02999372394697275, 0.07197150014690123, 3.6982391914352775, 89.06261533498764, 86.80993661284447, 87.95931413769722, 76.24797776341438, 80.70558696985245, 82.8531101346016, 83.92899200320244, 81.0411773622036, 82.71829336881638, 78.31283256411552, 75.43522417545319, 67.46698334813118, 63.44706505537033, 61.50208622217178, 61.1711011826992, 59.91650730371475, 57.6503849029541, 56.852853298187256, 57.010677829384804, 56.92042887210846, 57.63374179601669, 54.715445190668106, 56.33253961801529, 53.806438967585564, 54.887598752975464, 52.7203394472599, 52.199698984622955, 52.76379771530628, 53.08567464351654, 50.33141903579235, 52.971593365073204, 51.091294661164284, 48.40117961168289, 50.95738984644413, 49.60571877658367, 51.076486855745316, 52.55480132997036, 53.342685252428055, 51.34048528969288, 49.660834819078445, 52.20823712646961, 45.49266368150711, 50.85751600563526, 48.05847980082035, 49.8696868121624, 47.856152057647705, 44.39534716308117, 50.260875821113586, 46.28280848264694, 41.85041092336178, 43.27752314507961, 42.715670093894005, 43.44110816717148, 45.084660574793816, 48.85520964860916, 47.86168076097965, 47.33618415892124, 45.20446054637432, 50.265066996216774, 47.70124576985836, 49.64685536921024, 49.80686478316784, 58.05722527205944, 58.79777513444424, 62.746690437197685, 40.581434816122055, 32.0483922958374, 44.86605830490589, 54.19711880385876, 40.481781363487244, 29.466423243284225, 45.36820895969868, 43.322398737072945, 60.954972580075264, 56.63912236690521, 55.527378022670746, 49.62581969797611, 49.43702682852745, 48.219492360949516, 48.60336676239967, 48.37405286729336, 49.49980705976486, 50.756460428237915, 46.28978870809078, 46.49825692176819, 45.65334565937519, 47.567382752895355, 44.87804666161537, 43.78571927547455, 45.35831809043884, 48.778636157512665, 47.17442683875561, 49.727061465382576, 48.14188912510872, 51.81653894484043, 48.62899638712406, 48.51299241185188, 45.051473155617714, 47.91508689522743, 44.4818951189518, 50.87242640554905, 50.03445737063885, 49.803175181150436, 47.11183659732342, 45.96150152385235, 46.41968093812466, 46.96534305810928, 51.99477218091488, 47.984839752316475, 48.88823367655277, 50.556161776185036, 50.466866567730904, 52.142861634492874, 52.15216353535652, 52.9541826993227, 51.873053312301636, 52.29910925030708, 52.00517222285271, 54.27961237728596, 51.634414717555046, 53.86416167020798, 53.49866308271885, 55.16542464494705, 54.24824506044388, 55.55987007915974, 54.989722073078156, 55.9945173561573, 57.87421189248562, 58.19895386695862, 57.909177616238594, 61.23081497848034, 62.62423820793629, 73.53696003556252, 75.26839792728424, 80.58633416891098, 70.40688559412956, 1.549446894787252, 1.4617688558064401, 0.5664262245409191, 0.2430415787966922, 29.268413968384266, 78.75213459134102, 63.472082912921906, 52.56911136209965, 25.12134499847889, 45.414471477270126, 29.149045273661613, 1.7798465816304088, 0.16009394457796589, 0.04685468833486084, 0.08835381639073603, 0.01532619278805214, 0.01343619498584303, 0.11760466164560057, 0.045661400217795745, 0.040935745200840756, 0.1629552207305096, 0.16028023848775774, 0.1723375407163985, 0.20763889333466068, 0.24796670826617628, 0.2340400844695978, 0.3246178576955572, 0.6070541788358241, 0.9870924486313015, 15.032875891774893, 82.84798040986061, 55.31240835785866, 45.374915599823, 49.42111328244209, 68.75680133700371, 86.05636864900589, 63.89864802360535, 0.26535335811786354, 0.3460797294974327, 3.7905863486230373, 90.68235442042351, 90.98389104008675, 93.47360104322433, 79.62956070899963, 85.38923844695091, 85.0050638616085, 87.48287290334702, 84.32675465941429, 86.61571383476257, 81.07035219669342, 82.09270253777504, 69.05659005045891, 65.98067790269852, 64.12260800600052, 64.35519352555275, 62.627194449305534, 60.54427161812782, 60.41694425046444, 59.8684398829937, 59.3586478382349, 61.13543629646301, 55.06148122251034, 59.811841920018196, 56.82411924004555, 58.063335344195366, 55.528491362929344, 53.283556625247, 53.907661736011505, 55.67218445241451, 53.33862327039242, 54.86206412315369, 53.28781619668007, 50.35606071352959, 54.18582960963249, 51.90461441874504, 52.38632217049599, 56.03062681853771, 55.553763806819916, 53.14337074756622, 50.10987192392349, 52.47536659240723, 47.905579805374146, 51.56050108373165, 49.21203330159187, 51.522301733493805, 49.793303310871124, 43.94102454185486, 52.737233340740204, 49.68002758920193, 44.23422820866108, 47.68706113100052, 45.740661174058914, 45.73710076510906, 48.13301660120487, 50.48577055335045, 49.11536268889904, 49.763505309820175, 47.37460009753704, 50.54041542112827, 51.366688683629036, 51.260244995355606, 53.1456658244133, 61.990177631378174, 62.02819839119911, 66.137335896492, 46.290400475263596, 38.606278002262115, 51.32429055869579, 59.329632595181465, 43.073033317923546, 33.985744938254356, 47.670661211013794, 44.20006804168224, 59.001022428274155, 61.417004987597466, 60.106166526675224, 50.67467361688614, 53.03272448480129, 51.002406030893326, 51.13632224500179, 50.41002921760082, 52.923632338643074, 52.572941556572914, 48.08760903775692, 51.78627356886864, 47.19536371529102, 50.34860551357269, 46.715806648135185, 49.38444525003433, 48.15183699131012, 49.779901430010796, 47.94742316007614, 50.079397559165955, 49.09088060259819, 52.04859249293804, 49.280748814344406, 48.915565609931946, 45.53991034626961, 48.335598930716515, 43.49264860153198, 51.20031461119652, 54.36523698270321, 50.53413815796375, 49.958271458745, 50.46413831412792, 49.02333922684193, 51.085135191679, 54.55304950475693, 48.60222302377224, 51.75560921430588, 51.777731627225876, 54.380892142653465, 54.77999232709408, 53.78043696284294, 55.85909642279148, 53.46626602113247, 56.37209929525852, 52.73672416806221, 56.7500764131546, 53.99412229657173, 56.75831817090511, 55.92300519347191, 59.433872401714325, 56.94977469742298, 57.432759180665016, 57.91260123252869, 58.22143726050854, 60.610996037721634, 63.1287257373333, 62.2309935092926, 66.41048043966293, 66.459239423275, 77.1110026538372, 80.0823064148426, 84.63943228125572, 76.2786953151226, 1.801544011104852, 3.1195349944755435, 1.7268205457367003, 0.24276688025565818, 38.4446194767952, 85.4714584350586, 69.05009999871254, 68.1794223189354, 35.821194648742676, 50.18710657954216, 50.47738820314407, 5.2698170486837626, 0.5926442239433527, 0.1951837257365696, 0.19890779309207574, 0.17964898666832596, 0.12198711789096706, 0.13724197080591694, 0.1541328214807436, 0.13766328804194927], [0.04337944083090406, 0.09971684688935056, 0.00411458778216911, 0.051711198830162175, 0.02108672913891496, 0.07680107810301706, 0.13579617807408795, 0.14445352368056774, 0.44843335286714137, 16.110896095633507, 59.55305300652981, 34.48464296758175, 34.996011927723885, 44.374068304896355, 50.610073283314705, 82.83996284008026, 36.38135679066181, 0.17519863875349984, 0.84848259575665, 10.419722031801939, 102.5649020075798, 79.49423477053642, 81.81242197751999, 75.10211125016212, 80.07860541343689, 80.05193084478378, 80.00493496656418, 78.16281661391258, 77.28110432624817, 75.67785635590553, 66.26228079199791, 64.12286639213562, 66.75160333514214, 69.8010005056858, 66.27268463373184, 61.99293628334999, 57.5657444447279, 53.98246832191944, 53.88813078403473, 51.02497301995754, 50.99073685705662, 51.58620670437813, 51.153345331549644, 50.1631298661232, 51.6288860142231, 51.87451243400574, 48.934002220630646, 50.73187954723835, 50.87274178862572, 48.68355765938759, 49.731374233961105, 46.855384558439255, 45.43432541191578, 50.33901862800121, 46.70822985470295, 49.209692627191544, 49.14574585855007, 52.61199206113815, 48.041958287358284, 46.40320882201195, 52.3340255767107, 47.22342140972614, 46.74074850976467, 46.54188618063927, 46.845326498150826, 44.1461793333292, 42.06564657390118, 43.89991454780102, 47.812040224671364, 44.32475075125694, 41.760815531015396, 42.197043523192406, 42.36389636993408, 43.86017248034477, 42.54949361085892, 42.71651744842529, 47.4830386787653, 48.910120502114296, 52.93208688497543, 49.53360624611378, 50.32493278384209, 48.37439104914665, 55.3863637894392, 56.558011919260025, 56.12264268100262, 34.833848029375076, 29.298787638545036, 38.86646144092083, 46.076422557234764, 41.307032480835915, 30.1407103613019, 40.63823416829109, 55.441042855381966, 53.746269196271896, 53.34034077823162, 47.655519023537636, 47.038500532507896, 45.00967539846897, 45.2984257042408, 44.28133048117161, 45.47106184065342, 46.20263658463955, 44.78353813290596, 45.049459263682365, 43.68895746767521, 41.44384793937206, 41.934899389743805, 41.471711844205856, 40.89436702430248, 47.479067891836166, 42.52541810274124, 46.47891215980053, 49.6340424567461, 47.87516623735428, 47.114158272743225, 45.369098111987114, 51.017669811844826, 41.27612493932247, 43.83154481649399, 46.3584054261446, 46.48598738014698, 46.524699702858925, 47.61332608759403, 43.69514733552933, 44.10792678594589, 43.900701105594635, 43.41696806252003, 48.077117800712585, 48.255335837602615, 47.72727057337761, 48.96305166184902, 47.47756317257881, 47.47708819806576, 48.157981261610985, 48.386622592806816, 47.71758109331131, 49.028218165040016, 50.82022860646248, 49.77905787527561, 49.65733140707016, 50.316466838121414, 48.90770763158798, 52.597913816571236, 53.613215535879135, 52.55733959376812, 53.42920280992985, 54.289119467139244, 56.07288435101509, 59.904822930693626, 55.58400258421898, 57.13579751551151, 61.456313878297806, 70.35876497626305, 71.47245481610298, 74.01649430394173, 62.40795001387596, 2.7692227670922875, 1.2234164332039654, 0.02077066143101547, 0.4189255612436682, 8.18904222920537, 75.64434975385666, 58.89542609453201, 50.319271087646484, 32.64122888445854, 23.754706531763077, 20.35314805805683, 4.61288882419467, 0.023251442180480808, 0.051340165809961036, 0.009211628803313943, 0.09889531167573296, 0.05358061316655949, 0.027836803456011694, 0.14960760570829734, 0.07883649232098833, 0.10104736924404278, 0.03527938875777181, 0.0230626583652338, 0.05131986807100475, 0.06734501090249978, 0.13182626687921584, 0.17781876143999398, 0.2567789994645864, 0.7139280752744526, 27.18027211725712, 68.05901437997818, 41.702245473861694, 32.2470760345459, 49.216433465480804, 59.303744584321976, 89.56601232290268, 39.91164095699787, 0.041302555400761776, 0.6598155945539474, 14.74659925326705, 107.47879832983017, 79.48530524969101, 87.2637614607811, 75.53106263279915, 83.82686868309975, 80.94653964042664, 84.7265312075615, 81.2412442266941, 79.87715542316437, 77.15967044234276, 72.37382724881172, 66.04851946234703, 69.54747810959816, 71.50345355272293, 69.95628297328949, 64.47740256786346, 61.50984160602093, 58.51911708712578, 57.316477820277214, 53.31214629113674, 54.3448206782341, 54.361520782113075, 53.759678676724434, 52.634787037968636, 53.85156914591789, 52.73357793688774, 52.6712878793478, 53.87037813663483, 52.42763735353947, 51.57204486429691, 52.158847376704216, 50.521055459976196, 48.7542262673378, 50.183774158358574, 51.7771502584219, 52.1409085392952, 51.08584575355053, 54.68953438103199, 50.991899594664574, 46.93437471985817, 53.04702691733837, 49.58470590412617, 47.98548571765423, 47.57283166050911, 51.64462476968765, 46.27732917666435, 42.62630648910999, 45.499184131622314, 51.96269430220127, 46.48092605173588, 44.10742901265621, 44.48817238211632, 45.03501623868942, 45.55536411702633, 46.996489986777306, 45.134772285819054, 48.604552298784256, 50.49025051295757, 57.91289001703262, 52.46262967586517, 52.96744778752327, 51.39807499945164, 58.67566488683224, 59.500809609889984, 61.14715866744518, 37.57659025490284, 34.158764854073524, 44.67990629374981, 46.10438525676727, 47.97661319375038, 35.06166860461235, 40.254249572753906, 58.061576038599014, 58.722611367702484, 57.72791974246502, 51.75732672214508, 49.636557921767235, 47.821919694542885, 48.76185245811939, 47.92570732533932, 46.83963820338249, 47.34869688749313, 48.6888811737299, 47.075210362672806, 47.6252194494009, 44.36805322766304, 42.2527789324522, 42.666447535157204, 43.669821694493294, 49.01280619204044, 43.6527606099844, 47.18744874000549, 48.26642744243145, 48.791901245713234, 48.79040792584419, 47.369637563824654, 52.33794316649437, 43.937274143099785, 43.703514486551285, 46.14877067506313, 47.99423284828663, 48.661002069711685, 49.2153163254261, 46.07925720512867, 45.880968645215034, 46.623657792806625, 46.05238884687424, 48.209149315953255, 49.91618491709232, 50.0493373721838, 50.9612200409174, 50.77498063445091, 49.61570464074612, 50.451158210635185, 51.486963629722595, 49.21641066670418, 53.89775186777115, 53.23111943900585, 53.81117731332779, 52.87296965718269, 53.09965409338474, 51.44616521894932, 54.35952968895435, 53.732316344976425, 55.63289076089859, 55.98200082778931, 57.185544446110725, 59.8598675429821, 61.58364124596119, 60.62384694814682, 60.285509303212166, 65.01299142837524, 73.48415046930313, 76.27772256731987, 77.84475848078728, 67.04934775829315, 2.6832274440675974, 2.154120560735464, 0.5839385942090303, 0.20562503108521923, 7.721040342003107, 82.83601865172386, 65.63895463943481, 61.681147813797, 32.23942704498768, 31.46948006004095, 42.35895663499832, 8.251561224460602, 0.05275120747683104, 0.005852181848240434, 0.09341650293208659, 0.05332079468644224, 0.028722098431899212, 0.0023204346416605404, 0.10021598573075607, 0.10498239207663573, 0.1509837107732892, 0.25895147351548076, 0.17613044969039038, 0.19030864670639858, 0.1478374795988202, 0.31021354312542826, 0.30249339644797146, 0.5805206182412803, 0.9543884347658604, 30.533115305006504, 82.34146758913994, 44.59545962512493, 48.90376344323158, 64.01389583945274, 66.92980617284775, 96.95650935173035, 44.34569522738457, 0.38729469291865826, 0.6594111537560821, 12.522355355322361, 114.13209691643715, 80.63304886221886, 92.69070625305176, 76.91103458404541, 89.48525905609131, 82.65808179974556, 86.80035352706909, 81.55627772212029, 86.44408464431763, 79.00162160396576, 74.71092224121094, 65.45550808310509, 75.4016187787056, 70.60289427638054, 70.84551885724068, 68.5136067867279, 64.43081706762314, 59.52686481177807, 60.8423276245594, 54.708343371748924, 56.57947316765785, 55.97388446331024, 57.25033476948738, 54.401669427752495, 56.83791629970074, 56.022552251815796, 54.724355712533, 56.77703216671944, 55.249772518873215, 51.76023356616497, 55.25579899549484, 51.46660812199116, 50.69497972726822, 54.68454144895077, 54.56146605312824, 55.07123529911041, 55.04217065870762, 56.69306047260761, 51.34746931493282, 46.59143552184105, 55.57843968272209, 52.52993546426296, 50.265427976846695, 50.51455780863762, 55.11354602873325, 46.42289936542511, 40.99126182496548, 45.88983736932278, 55.95894746482372, 48.602063432335854, 46.07023648917675, 46.45594239234924, 49.36767674982548, 49.47302609682083, 50.044386237859726, 48.92021656036377, 53.96174043416977, 52.472406551241875, 61.01209871470928, 53.51855121552944, 55.3778750449419, 54.88186106085777, 63.18567328155041, 63.00701826810837, 66.93672940135002, 42.725754752755165, 39.67482626438141, 51.26918211579323, 55.43357625603676, 53.51155959069729, 38.79069350659847, 45.753044709563255, 60.32518297433853, 61.48008160293102, 60.64590856432915, 52.52883732318878, 52.92141705751419, 49.690796211361885, 51.39713265001774, 50.88676683604717, 48.7491649389267, 50.92687368392944, 51.55251011252403, 51.450022011995316, 50.24547144770622, 45.90433359146118, 46.375971883535385, 47.35823057591915, 45.833205208182335, 50.79030141234398, 47.03100733458996, 49.28230673074722, 49.4026842713356, 48.95614743232727, 51.27662971615791, 48.217869848012924, 54.22867991030216, 46.79958455264568, 46.13582856953144, 47.127081379294395, 49.789769500494, 51.16037495434284, 52.69388146698475, 46.70462764799595, 48.7415387481451, 49.6788876503706, 47.875523418188095, 51.774437204003334, 52.62237690389156, 52.306218668818474, 53.2366519421339, 53.29763866961002, 52.37926974892616, 53.02271582186222, 54.881211295723915, 51.446488201618195, 56.0700649023056, 55.75940877199173, 55.259754583239555, 55.565698966383934, 55.71627728641033, 53.68853509426117, 58.52957792580128, 56.90787814557552, 58.301099985837936, 59.38237376511097, 59.3095088750124, 63.23908321559429, 64.29771780967712, 63.457214310765266, 63.45733590424061, 68.50525483489037, 76.6681744158268, 79.37476918101311, 81.47185385227203, 73.89545559883118, 3.862508414313197, 3.3880176628008485, 1.4311514049768448, 0.6731155933812261, 12.544131986796856, 91.7453321814537, 73.62116351723671, 72.00202479958534, 57.00653225183487, 46.278119534254074, 57.03908510506153, 19.715414978563786, 0.506291245110333, 0.218021702603437, 0.11658952236757614, 0.26344137790147215, 0.16274171968689188, 0.12281836781767197, 0.32443531905300915, 0.24780781444860622], [0.04341237363405526, 0.06440530458348803, 0.028344285892671905, 0.12457579578040168, 0.061814485598006286, 0.06743318546796218, 0.058480754523770884, 0.07031862594885752, 0.11114245528005995, 31.720013916492462, 61.378760039806366, 40.62199383974075, 22.516681663691998, 46.67327553033829, 54.9588031321764, 85.22367373108864, 26.00152026861906, 0.4150585562456399, 5.384370451793075, 55.245835930109024, 93.55870127677917, 79.36932027339935, 81.50814950466156, 78.27818602323532, 81.92698583006859, 79.37325686216354, 80.57964652776718, 76.71072453260422, 76.52296140789986, 69.9454003572464, 67.38945990800858, 69.97817739844322, 70.93525484204292, 66.87545388936996, 67.41662085056305, 69.9619522690773, 63.03333945572376, 57.61722028255463, 61.343429535627365, 62.019626051187515, 60.3844939917326, 58.232547864317894, 56.335735246539116, 55.72177179157734, 49.01352435350418, 50.890893414616585, 51.221399679780006, 52.54736892879009, 51.05276472866535, 48.696606159210205, 50.9146611392498, 47.3550121486187, 45.55531471967697, 47.29151375591755, 48.35438132286072, 47.5689634680748, 48.499617129564285, 50.366829335689545, 51.664547100663185, 48.30467239022255, 50.71886904537678, 42.47339129447937, 41.8034378439188, 47.50530928373337, 47.240041717886925, 39.39085230231285, 43.44696745276451, 42.870435789227486, 45.753223299980164, 45.02594232559204, 41.314803063869476, 42.16681994497776, 41.21426805853844, 43.602352514863014, 42.31305509805679, 40.87401531636715, 42.921543046832085, 53.24853390455246, 59.157836213707924, 51.18136502802372, 52.176425233483315, 53.582395389676094, 53.84624943137169, 57.25222326815128, 55.88622696697712, 41.155390217900276, 33.9495062828064, 40.83910658955574, 39.34257589280605, 42.894024923443794, 35.19147343933582, 38.56186978518963, 48.08728985488415, 55.32690837979317, 53.500528782606125, 51.031432673335075, 50.377138182520866, 49.7964571416378, 45.27388282120228, 45.518179312348366, 43.14429469406605, 44.59969639778137, 44.57921929657459, 42.747356593608856, 40.54411701858044, 39.89405930042267, 41.70853413641453, 43.57059761881828, 43.9089884608984, 45.55305004119873, 41.05642832815647, 48.52128356695175, 48.54973264038563, 47.617239877581596, 45.258546844124794, 47.91056513786316, 49.31933954358101, 45.777568593621254, 39.99118588864803, 43.99042189121246, 49.78326044976711, 46.67782008647919, 47.48182654380798, 44.418685510754585, 44.22318980097771, 43.59464652836323, 45.1688526570797, 47.8381410241127, 47.99642153084278, 46.24705620110035, 48.12653414905071, 47.6869585365057, 50.58800406754017, 48.658934980630875, 49.708229675889015, 47.82293803989887, 50.0879281014204, 49.43266086280346, 52.0115102827549, 51.310185715556145, 51.47584542632103, 50.48242673277855, 52.346181124448776, 52.75087080895901, 52.845128551125526, 53.706401735544205, 60.087216943502426, 59.77135129272938, 61.732228472828865, 58.33046481013298, 58.95545147359371, 63.34324322640896, 68.28934282064438, 72.25164860486984, 77.9085722565651, 50.16504876315594, 2.6575541216880083, 0.6900028372183442, 0.343357709934935, 0.16503695980645716, 2.3057839600369334, 61.94368712604046, 65.68776682019234, 48.33899214863777, 23.950004652142525, 28.80899202078581, 20.916500128805637, 6.564946202561259, 0.05212275682424661, 0.04547394855762832, 0.024449589509458747, 0.06759292533388361, 0.04321677690313663, 0.08268938909168355, 0.06688097564619966, 0.043088652528240345, 0.09092782944208011, 0.07514113865909167, 0.022085869568400085, 0.050800171738956124, 0.04741595977975521, 0.08530183797120117, 0.08049904412473552, 0.07466634968295693, 0.062184728230931796, 42.99351878464222, 66.29782408475876, 44.17381905019283, 21.93548195064068, 54.50156606733799, 63.93197223544121, 90.95650970935822, 28.13531666994095, 0.4707532364409417, 11.916979439556599, 63.395669013261795, 95.23198708891869, 80.15320301055908, 84.20675709843636, 80.00851437449455, 83.17790150642395, 78.32911089062691, 82.46454298496246, 79.22403886914253, 79.57946419715881, 71.28482088446617, 70.11125385761261, 69.13345232605934, 72.78192535042763, 70.30587181448936, 73.01020950078964, 73.36362853646278, 67.33035787940025, 61.82290680706501, 63.840875923633575, 64.95483174920082, 63.62125910818577, 60.03323324024677, 57.760442197322845, 57.90242537856102, 52.99653522670269, 52.490466982126236, 54.81009431183338, 52.37469479441643, 53.00103418529034, 51.26374460756779, 51.81699872016907, 50.31908109784126, 47.367726266384125, 50.38004882633686, 50.92441141605377, 48.43236453831196, 50.61736889183521, 51.881618052721024, 54.45558473467827, 48.66822928190231, 51.66790992021561, 43.90033632516861, 43.34744319319725, 49.48858246207237, 50.80368809401989, 40.98801679909229, 45.19398830831051, 42.43193171918392, 48.30057621002197, 47.89131157100201, 45.110985562205315, 45.52201330661774, 44.99567694962025, 47.24517524242401, 46.086678206920624, 44.718250036239624, 45.05681946873665, 53.83629396557808, 61.856405809521675, 54.413760378956795, 56.375412717461586, 56.484128683805466, 56.82255372405052, 60.71502685546875, 57.80656412243843, 43.83484683930874, 39.634407833218575, 44.53373193740845, 40.62153026461601, 45.781976357102394, 41.346436366438866, 41.501304656267166, 50.41877254843712, 57.31722258031368, 58.94469805061817, 53.4781251847744, 52.091283202171326, 52.75436282157898, 48.02349887788296, 46.52175486087799, 45.25600478053093, 47.042855098843575, 45.74718542397022, 44.26072038710117, 41.621442809700966, 42.54015751183033, 45.40928095579147, 44.98496152460575, 44.65643495321274, 46.05729818344116, 44.34185743331909, 49.18949291110039, 49.526341035962105, 48.66085007786751, 46.720712184906006, 50.84195964038372, 50.88588148355484, 48.40635873377323, 42.092279344797134, 46.346850246191025, 51.55491538345814, 47.52702131867409, 49.62531432509422, 46.73438385128975, 47.31340438127518, 45.991056337952614, 47.32332184910774, 50.25757759809494, 49.51804608106613, 48.255096450448036, 50.00699244439602, 49.00872141122818, 52.14601546525955, 51.41197085380554, 52.28043705224991, 49.39914286136627, 52.54335634410381, 52.80787535011768, 53.33399511873722, 53.56800176203251, 53.730549439787865, 52.803520783782005, 55.69574698805809, 55.24659588932991, 56.16131320595741, 55.834678933024406, 63.60721506178379, 64.37631279230118, 65.81958174705505, 61.97252377867699, 61.19429513812065, 66.07297495007515, 71.53976440429688, 77.71730571985245, 81.31381273269653, 58.68851199746132, 4.048858964815736, 1.244871150702238, 1.0658709495328367, 0.1150908887211699, 2.51266504637897, 67.61439263820648, 70.11183142662048, 57.94341377913952, 28.780390955507755, 42.74935528635979, 37.83674329519272, 20.867912136018276, 0.2608113252790645, 0.03272043388278689, 0.058013416710309684, 0.012611715301318327, 0.043478183579281904, 0.014795406914345222, 0.06896054022945464, 0.015054944306029938, 0.1796142986859195, 0.14490943984128535, 0.14286580262705684, 0.16240742668742314, 0.15193944855127484, 0.12230195919983089, 0.17971383553231135, 0.1964085959480144, 0.20460442960029468, 48.137040585279465, 78.0757936835289, 51.3560226559639, 34.54499892890453, 68.4963709115982, 67.81452029943466, 99.51169744133949, 33.3615942299366, 0.5550835363101214, 11.453097481280565, 65.70132449269295, 99.49989527463913, 84.03550788760185, 89.6415750682354, 82.44368210434914, 88.33084300160408, 81.60484671592712, 84.38588708639145, 82.98522144556046, 82.77306362986565, 74.16222408413887, 74.20131638646126, 74.40390631556511, 74.79273185133934, 75.31994596123695, 77.25449815392494, 74.9088004231453, 68.42292845249176, 63.528198301792145, 66.15243628621101, 68.87767285108566, 64.32189971208572, 63.38018864393234, 61.550305634737015, 61.019021943211555, 55.57485267519951, 55.297589153051376, 56.57475382089615, 56.09849117696285, 55.18054023385048, 52.19885163009167, 54.28057752549648, 51.9928190857172, 50.880364179611206, 53.166507706046104, 53.39026629924774, 50.22937931120396, 53.88909213244915, 54.85410735011101, 54.82579126954079, 49.22604314982891, 51.231928914785385, 48.01139272749424, 47.9351232200861, 50.9463020414114, 52.87404499948025, 42.30550870299339, 45.8154259622097, 43.69856335222721, 49.86277878284454, 50.9864316880703, 47.17731088399887, 47.747367694973946, 48.45155730843544, 50.137401446700096, 48.602519407868385, 47.84925542771816, 48.15414346754551, 57.00060836970806, 63.75609487295151, 56.53222270309925, 57.57511854171753, 59.37763921916485, 58.24510999023914, 65.05744904279709, 61.60386376082897, 46.33708856999874, 43.235231414437294, 49.651855900883675, 53.193965032696724, 51.58933013677597, 43.708530217409134, 44.506631791591644, 54.027362912893295, 59.075498431921005, 61.039970219135284, 53.7276653945446, 54.741340801119804, 56.1143933236599, 49.43169191479683, 49.47682589292526, 48.706759214401245, 50.04636213183403, 48.497276455163956, 48.13020095229149, 47.590698301792145, 45.44338412582874, 48.68324227631092, 47.70156875252724, 44.79473993182182, 47.3701087385416, 45.72099342942238, 50.465145260095596, 49.70431208610535, 47.855825275182724, 48.25191222131252, 50.99443405866623, 52.36774116754532, 50.31228706240654, 45.324936881661415, 47.16804318130016, 54.03025455772877, 48.893184810876846, 51.408919617533684, 48.89349639415741, 50.76311767101288, 48.6944554746151, 50.491873025894165, 53.308882266283035, 51.57620184123516, 51.0628379881382, 52.24757641553879, 51.93942055106163, 56.47924214601517, 53.30281399190426, 53.492169231176376, 51.146186515688896, 54.9452568590641, 56.53383381664753, 56.26959979534149, 55.9482092410326, 56.24743938446045, 55.99618546664715, 56.34145013988018, 59.056837633252144, 58.813981264829636, 58.767828941345215, 67.65619799494743, 67.55475863814354, 69.19702291488647, 66.10901221632957, 65.9393361210823, 70.62225803732872, 75.45174568891525, 80.45097783207893, 84.19194549322128, 67.09770396351814, 5.118412747979164, 1.8708653538487852, 1.8477519066073, 0.11983983233221807, 4.9832582753151655, 78.26375439763069, 76.9513276219368, 67.45432242751122, 46.06768302619457, 53.66911053657532, 50.30268497765064, 35.57480826973915, 0.7907854823861271, 0.1204879795841407, 0.15642976853996515, 0.17015503282891586, 0.09061640943400562, 0.1278228106093593, 0.1764583750627935, 0.09844303203863092], [0.023655465520278085, 0.10170690846280195, 0.04412962596688885, 0.05436534898763057, 0.05649309379805345, 0.12378743456793018, 0.04416553849296179, 0.0323142007982824, 0.10847792989807203, 41.21246695518494, 56.475449949502945, 37.19270445406437, 35.033941492438316, 50.09197108447552, 59.07678656280041, 81.00868910551071, 14.194830860942602, 0.5144318332895637, 8.010610453784466, 56.94416239857674, 88.85365694761276, 75.72462424635887, 77.94512629508972, 78.57334658503532, 82.24379003047943, 81.7430528998375, 79.41278234124184, 78.1082971394062, 70.81978663802147, 63.73088702559471, 64.50185805559158, 70.22362142801285, 87.59494408965111, 94.06747877597809, 75.88485404849052, 66.8088510632515, 67.80020266771317, 66.60497680306435, 67.52341032028198, 67.3746407032013, 67.16391921043396, 66.59968748688698, 67.38908752799034, 63.179950788617134, 59.2469984292984, 49.442148953676224, 51.3492476195097, 51.691875234246254, 50.632822662591934, 48.58266167342663, 50.48630632460117, 48.76421973109245, 47.29853577911854, 46.367464140057564, 45.10598883032799, 46.462417244911194, 47.711907997727394, 47.68986538052559, 54.692832604050636, 47.78676398098469, 51.82040333747864, 46.3010361045599, 40.34011356532574, 50.277689918875694, 49.59489315748215, 44.348754063248634, 42.017966732382774, 44.36645731329918, 45.03306694328785, 48.82460229098797, 43.56847733259201, 42.475503981113434, 39.99775193631649, 40.34332059323788, 41.8598648160696, 42.46899113059044, 42.69306890666485, 47.226613238453865, 49.262414798140526, 51.5090898424387, 53.62547367811203, 54.2951725423336, 55.00498965382576, 56.14077530801296, 49.59594950079918, 41.469317972660065, 36.97124473750591, 33.740209713578224, 36.864880844950676, 37.73446798324585, 39.950721859931946, 39.828292429447174, 44.7812582552433, 56.67439207434654, 54.44817513227463, 53.552023619413376, 52.86549165844917, 55.93172952532768, 51.48664064705372, 43.16419802606106, 43.58751431107521, 42.4722171574831, 42.32398331165314, 39.12458539009094, 41.12793669104576, 42.06651672720909, 45.883970484137535, 40.791320353746414, 47.845269441604614, 45.35842828452587, 42.353883907198906, 50.17595037817955, 49.96387615799904, 49.054938331246376, 47.48975671827793, 52.451705262064934, 49.18534733355045, 49.59113135933876, 42.55913749337196, 46.53250828385353, 49.789666905999184, 47.414573952555656, 46.100923642516136, 45.08631348609924, 42.9971019923687, 41.69484347105026, 44.315893426537514, 47.118273451924324, 47.344642505049706, 45.809350088238716, 47.45965473353863, 48.78563158214092, 50.40163166821003, 48.90581913292408, 49.7275098413229, 49.485291838645935, 48.96758861839771, 48.89833353459835, 50.355673134326935, 48.80052298307419, 52.23751835525036, 49.92594659328461, 54.11819323897362, 52.648910880088806, 59.153325855731964, 58.08430261909962, 64.17466521263123, 62.91065163910389, 62.76587560772896, 59.30306442081928, 59.535710737109184, 61.61861076951027, 73.89877662062645, 70.94233006238937, 76.542287170887, 44.87600617110729, 4.4659017864614725, 1.2653774628415704, 0.33531048393342644, 0.10480048425961286, 0.17600425489945337, 52.54190482199192, 68.9685107767582, 51.39266408979893, 30.84926214069128, 15.547088049352169, 22.579820975661278, 17.494654543697834, 1.128108878619969, 0.045736075117019936, 0.01084600311514805, 0.053774024272570387, 0.12253700479050167, 0.026670581464713905, 0.043145308081875555, 0.03449066018220037, 0.01586168109497521, 0.06329212759737857, 0.05293096306559164, 0.0295128085417673, 0.009590354184183525, 0.037985648814355955, 0.06738321666489355, 0.041784947679843754, 0.034995480164070614, 50.44354721903801, 64.10105556249619, 41.933425068855286, 32.67046071588993, 60.44190511107445, 67.00731441378593, 90.03454238176346, 14.769562371075153, 0.45657714712433517, 6.557079674676061, 58.45145411789417, 93.35599735379219, 76.51575699448586, 80.99806487560272, 80.60194373130798, 87.652647793293, 85.39335742592812, 81.37087047100067, 79.51820388436317, 72.71203950047493, 66.14441871643066, 66.42500326037407, 74.01756584644318, 83.8425162434578, 88.82833510637283, 76.99436411261559, 70.03308445215225, 72.57722273468971, 71.55938655138016, 71.71165958046913, 69.81330424547195, 71.05247855186462, 70.06713822484016, 68.79731476306915, 64.55182537436485, 63.05905647575855, 52.65203811228275, 54.55501779913902, 54.08116042613983, 53.029639050364494, 52.40388482809067, 50.82124315202236, 51.18310533463955, 50.396319553256035, 48.42827595770359, 48.557792007923126, 50.688159093260765, 50.14050208032131, 49.559406861662865, 55.553695410490036, 47.400381714105606, 52.397596165537834, 50.776793137192726, 43.98221433162689, 51.15258917212486, 50.84687277674675, 46.301590874791145, 43.27854909002781, 44.90781046450138, 44.82136130332947, 48.92061173915863, 45.67103371024132, 44.52437683939934, 43.45251515507698, 44.04167354106903, 42.63597697019577, 44.04252849519253, 46.755921095609665, 50.11391490697861, 53.109199181199074, 51.97578839957714, 54.2760443687439, 55.73006294667721, 56.73925079405308, 58.58378581702709, 49.87364619970322, 44.16946828365326, 41.596101969480515, 38.31408888101578, 39.50001284480095, 41.61137714982033, 43.48104402422905, 43.97662863135338, 47.896224707365036, 57.901657819747925, 57.926808670163155, 55.801457315683365, 53.97965267300606, 57.978113517165184, 54.26262728869915, 46.16968855261803, 47.49596558511257, 45.13310797512531, 44.629992172122, 41.88873566687107, 44.456098303198814, 43.36876004934311, 46.37995786964893, 39.96184766292572, 47.90014609694481, 46.33083790540695, 42.62912593781948, 48.57285439968109, 49.50623631477356, 48.982510417699814, 49.06797543168068, 51.6284604370594, 49.668628200888634, 51.25565104186535, 44.66716557741165, 48.26744578778744, 49.31174375116825, 47.46242858469486, 46.744894087314606, 46.18299923837185, 46.306511610746384, 44.90806885063648, 47.51458838582039, 50.903926715254784, 50.04133500158787, 49.01451230049133, 49.94098238646984, 49.76831965148449, 50.95726065337658, 50.61009228229523, 53.07546079158783, 50.22636607289314, 51.58801920711994, 52.16195560991764, 52.04247482120991, 51.93478100001812, 53.01532901823521, 54.94769252836704, 56.460110172629356, 57.5267319381237, 62.37329587340355, 62.14152731001377, 67.01250493526459, 66.15736082196236, 65.73905646800995, 63.08819331228733, 62.13193282485008, 65.15783965587616, 76.50699466466904, 75.06663635373116, 79.15190353989601, 56.74799032509327, 5.046256519854069, 0.6338299764320254, 0.8428790839388967, 0.18441488093230873, 0.3086445538792759, 55.03041408956051, 77.24050730466843, 61.072633266448975, 36.864246279001236, 20.06722290068865, 39.29371431469917, 34.83274228870869, 0.9221676480956376, 0.09585153398802504, 0.03733780584298074, 0.029744876264885534, 0.0867348509200383, 0.024275121722894255, 0.04985974446753971, 0.029584264375444036, 0.296148894703947, 0.2505443652626127, 0.1846772152930498, 0.1476889313198626, 0.18783972918754444, 0.1591117714997381, 0.13439369708066806, 0.1957268887781538, 0.20013631467008963, 62.249749302864075, 74.12772193551064, 46.88167154788971, 48.03655117750168, 72.85241916775703, 71.62326112389565, 98.47842648625374, 18.098157159984112, 0.5868659215047956, 13.05433725938201, 66.47932514548302, 95.0197684764862, 80.02249002456665, 83.07455465197563, 83.05307060480118, 87.7670368552208, 87.70921915769577, 84.95579570531845, 83.49186345934868, 75.19589021801949, 67.96099483966827, 70.79167574644089, 76.6834419965744, 89.13372471928596, 85.54271221160889, 76.04091927409172, 72.73597061634064, 75.06899982690811, 72.49322444200516, 74.75755333900452, 72.98457607626915, 74.20842960476875, 73.19880098104477, 72.82515183091164, 67.18583643436432, 66.57660752534866, 53.72145272791386, 57.4481825530529, 56.4884452521801, 54.0656952559948, 53.965433835983276, 52.757763639092445, 52.0460694283247, 52.91997693479061, 50.18000476062298, 50.765481144189835, 53.538541942834854, 52.51240320503712, 51.133065819740295, 57.405685633420944, 48.63565742969513, 52.49822996556759, 54.74730648100376, 48.54956164956093, 51.869485303759575, 54.57178629934788, 50.880063995718956, 44.103796407580376, 46.94173872470856, 47.654428482055664, 52.06023506820202, 49.33220185339451, 46.4846308529377, 45.766549184918404, 47.83465661108494, 47.473303601145744, 47.715004831552505, 49.09289829432964, 54.28913466632366, 56.12941391766071, 56.77947163581848, 60.7124087959528, 58.76084491610527, 61.09004773199558, 63.61147463321686, 55.16558803617954, 47.79805317521095, 47.430650889873505, 45.49442298710346, 52.46266007423401, 50.1061937212944, 48.89041855931282, 46.34601429104805, 48.06179702281952, 61.03516727685928, 60.13827100396156, 58.890873938798904, 58.731119111180305, 61.39444179832935, 54.34566803276539, 45.57507365942001, 49.354065880179405, 47.86718666553497, 47.303456515073776, 44.89188551902771, 46.95343069732189, 46.50805279612541, 49.66755285859108, 43.08194763958454, 48.22612300515175, 47.95729883015156, 45.51107369363308, 49.27177369594574, 50.46607241034508, 50.75870990753174, 50.84094509482384, 53.25953431427479, 49.86675336956978, 51.84513621032238, 46.53954170644283, 49.80360455811024, 50.3982612490654, 49.60401266813278, 48.84699068963528, 49.56753082573414, 47.927523627877235, 47.99179717898369, 50.09720720350742, 52.0019955933094, 52.20503389835358, 50.05592241883278, 52.79874064028263, 52.4014263600111, 55.889456793665886, 53.688797280192375, 54.4614440202713, 54.31238941848278, 53.24864409863949, 54.15964521467686, 55.07040694355965, 53.30462269484997, 57.05311015248299, 57.87572421133518, 59.76070426404476, 58.985785245895386, 64.6266357600689, 63.82864058017731, 68.23942109942436, 68.49399223923683, 67.78954043984413, 65.15934437513351, 64.62620258331299, 70.39800927042961, 80.61836645007133, 78.55972051620483, 85.59560537338257, 63.45958158373833, 7.331998692825437, 1.5792387211695313, 3.072274080477655, 0.20793300645891577, 0.6465798954013735, 65.35371914505959, 80.89292451739311, 74.21006351709366, 50.335864797234535, 26.443651244044304, 52.116665840148926, 55.15978954732418, 1.9757475634105504, 0.21052641182905063, 0.1563189658918418, 0.15150336257647723, 0.271958353696391, 0.1517716934904456, 0.14579108159523457, 0.15216203348245472], [0.011503255591378547, 0.02769462465948891, 0.07741198438452557, 0.028240704341442324, 0.04712808811746072, 0.04043180466396734, 0.12003469804767519, 0.06775109184673056, 0.07852197755710222, 43.37208867073059, 54.48851376771927, 35.2433330565691, 24.699666425585747, 54.041631147265434, 61.09670877456665, 81.70050278306007, 6.571656167507172, 0.19814505823887885, 0.22729654476279393, 44.858625903725624, 94.16972368955612, 77.23333328962326, 77.85131692886353, 76.80663138628006, 80.45381247997284, 79.85252514481544, 78.80609929561615, 72.35831648111343, 67.15125069022179, 63.49604442715645, 65.8450023829937, 72.18058481812477, 62.83242903649807, 65.35693377256393, 86.68602526187897, 86.8628753721714, 70.50110533833504, 68.40262994170189, 68.95464152097702, 66.67512103915215, 68.96690726280212, 69.12065461277962, 71.0881282389164, 64.82122331857681, 67.2606012225151, 56.28218092024326, 48.27269710600376, 51.120716482400894, 49.878908917307854, 49.301089122891426, 48.66536803543568, 45.84477938711643, 48.36684465408325, 46.86339072883129, 49.554185941815376, 47.50548027455807, 47.62107007205486, 48.09231698513031, 50.59668280184269, 48.08674268424511, 43.937942907214165, 53.63790661096573, 48.494985178112984, 47.404702082276344, 44.87871542572975, 44.530000537633896, 45.973383486270905, 46.01073548197746, 47.37080790102482, 46.04760490357876, 44.843156933784485, 42.04287439584732, 42.010815516114235, 41.49581775069237, 39.636269733309746, 41.43244855105877, 41.55985191464424, 41.89055576920509, 42.71067336201668, 46.954718828201294, 45.17626225948334, 47.67093099653721, 47.397509068250656, 45.40795102715492, 40.51116518676281, 40.360374078154564, 33.004432395100594, 29.968193918466568, 32.82802306115627, 35.648858696222305, 37.066441029310226, 41.90030984580517, 44.80980232357979, 44.98973786830902, 50.168065801262856, 49.14164587855339, 51.097674518823624, 51.11604653298855, 51.24898239970207, 43.05453971028328, 42.309145107865334, 38.50220538675785, 38.447172939777374, 39.73065286874771, 43.17196100950241, 46.79487660527229, 42.385627403855324, 41.34879603981972, 42.84276567399502, 47.717885076999664, 44.60931368172169, 44.47274141013622, 45.90637028217316, 50.71939341723919, 50.45798644423485, 51.125090047717094, 52.06511400640011, 44.93936777114868, 45.31015947461128, 45.790191516280174, 47.28422574698925, 44.17142517864704, 45.29312498867512, 44.220024570822716, 42.95736752450466, 42.281919568777084, 45.795021057128906, 48.45458574593067, 47.079481333494186, 48.49451780319214, 49.02544431388378, 48.27799782156944, 52.058183178305626, 53.52122247219086, 52.317770048975945, 52.2794035077095, 53.301267474889755, 51.51310242712498, 52.29502446949482, 53.21745917201042, 57.45482459664345, 59.605968967080116, 60.60118496417999, 62.77402997016907, 64.12855088710785, 64.07570332288742, 66.64457827806473, 66.15590170025826, 65.28657674789429, 62.09891639649868, 59.34641249477863, 63.55766572058201, 73.07771667838097, 72.08960250020027, 73.23111444711685, 55.135543048381805, 3.5823273612186313, 0.9485308709554374, 2.6807407150045037, 0.0626205284788739, 0.1017099067394156, 38.482967019081116, 71.88015013933182, 55.60947261750698, 34.186248779296875, 34.83589231967926, 28.277096562087536, 20.880259573459625, 1.246925771702081, 0.1388118209433742, 0.07679040601942688, 0.10520283962250687, 0.05571701141889207, 0.0205004677263787, 0.03082812614593422, 0.043487226648721844, 0.05908825434744358, 0.06616740065510385, 0.03896221867762506, 0.03718493455380667, 0.06961479535675608, 0.02363478186452994, 0.06339921208564192, 0.03497364617942367, 0.020568576474033762, 51.95293642580509, 60.06106294691563, 42.60783948004246, 28.423077128827572, 60.37978604435921, 68.57558906078339, 91.15973800420761, 7.343607544898987, 0.33756972989067435, 0.0944425369380042, 50.76985850930214, 97.9093386232853, 78.05340528488159, 83.40835154056549, 77.75327458977699, 84.29881855845451, 82.55952268838882, 81.71593755483627, 73.95271852612495, 69.26541924476624, 66.32292553782463, 67.94298380613327, 73.56871873140335, 68.59960377216339, 66.65460973978043, 82.87260308861732, 85.91399028897285, 71.46169379353523, 72.75468841195107, 74.06220585107803, 71.00586265325546, 71.03001415729523, 70.66986948251724, 71.35005578398705, 66.81890532374382, 68.29577207565308, 58.73830832540989, 50.93876704573631, 51.624010875821114, 52.638035863637924, 52.41674713790417, 49.97277908027172, 49.555291682481766, 50.98146915435791, 49.03273992240429, 50.14299474656582, 48.43981213867664, 48.71399782598019, 49.40174952149391, 52.571691423654556, 50.50368279218674, 44.50264200568199, 54.7610579431057, 51.871191412210464, 50.13960912823677, 45.28943158686161, 46.030528619885445, 47.553114518523216, 46.53293766081333, 47.05604039132595, 48.18162739276886, 47.05947920680046, 44.476860389113426, 43.40597525238991, 43.11092108488083, 41.11363805830479, 43.24587844312191, 45.48104390501976, 44.629027023911476, 46.473968625068665, 47.740763649344444, 48.850136920809746, 50.3775941580534, 48.67204807698727, 47.27229818701744, 42.78196893632412, 46.732932329177856, 37.64607332646847, 36.61130145192146, 35.80227546393871, 38.521417155861855, 42.38976538181305, 45.47861583530903, 47.34205484390259, 46.592366471886635, 53.5134556889534, 52.86662399768829, 52.63679713010788, 53.77179242670536, 50.83344429731369, 46.463883966207504, 45.13908505439758, 41.11738845705986, 42.597633227705956, 43.23161780834198, 45.84096819162369, 48.21422204375267, 41.78074546158314, 42.36865371465683, 43.89183238148689, 47.187539935112, 45.80105893313885, 46.310850977897644, 48.131622076034546, 51.0060728341341, 49.33223605155945, 53.58020290732384, 51.80089518427849, 44.110689237713814, 45.861194506287575, 48.40896539390087, 48.54634702205658, 45.56024685502052, 47.88255304098129, 47.640023455023766, 46.709187403321266, 46.54636614024639, 48.92277382314205, 49.515614211559296, 49.99350316822529, 50.271507650613785, 49.79668512940407, 50.03865234553814, 53.11152845621109, 56.051552295684814, 54.84702453017235, 54.411317110061646, 54.769664481282234, 54.82362158596516, 54.67210091650486, 56.20549723505974, 59.28993992507458, 63.03959771990776, 64.23083379864693, 67.3294535279274, 65.4664894938469, 68.64996626973152, 68.02204996347427, 69.10978719592094, 67.68587440252304, 68.22149366140366, 61.7460673302412, 67.43963241577148, 74.98087495565414, 77.86017045378685, 75.73764234781265, 71.9537141919136, 5.625117933377624, 0.9697544539812952, 2.704212055541575, 0.13582682877313346, 0.15442025527590886, 44.1275717318058, 77.5180596113205, 65.72387248277664, 36.84155769646168, 36.387949436903, 48.44462268054485, 34.22594904899597, 2.0712752686813474, 0.18524745188187808, 0.10696975965402089, 0.02708122290641768, 0.10344961963710375, 0.04568867414491251, 0.059345074550947174, 0.010646341270330595, 0.2423642057692632, 0.1316531831980683, 0.282908653607592, 0.12322252659942023, 0.222077866201289, 0.16485888889292255, 0.15116584865609184, 0.11497797837364487, 0.19809101504506543, 65.25032669305801, 70.33030450344086, 46.87657222151756, 35.63777469098568, 74.86855298280716, 74.28313359618187, 99.90672424435616, 8.213915694504976, 0.4032504226779565, 0.2865269797621295, 54.225963056087494, 99.42896828055382, 81.53927743434906, 86.94319546222687, 80.83111703395844, 86.47882997989655, 84.50256362557411, 84.58280012011528, 78.24109241366386, 71.98461413383484, 68.3805987238884, 71.66017234325409, 78.30112159252167, 77.52685233950615, 76.58789232373238, 82.41024389863014, 82.29946464300156, 75.43731406331062, 74.31699737906456, 76.35774627327919, 71.67754501104355, 74.80017185211182, 72.4821974337101, 74.61189955472946, 70.29533118009567, 73.29993635416031, 61.57570727169514, 52.50988394021988, 55.670873522758484, 53.2433395832777, 53.003355860710144, 53.86216677725315, 50.42736388742924, 54.581859558820724, 54.19002078473568, 54.98012758791447, 52.21850797533989, 52.11392238736153, 51.96899436414242, 54.78620119392872, 52.221179232001305, 45.888651832938194, 57.19158612191677, 56.28704085946083, 52.32919603586197, 46.6408708691597, 48.41867387294769, 46.64492905139923, 49.627898186445236, 49.108447059988976, 48.954152539372444, 48.59294772148132, 46.103093326091766, 46.20256818830967, 46.049497202038765, 44.37184542417526, 46.86304874718189, 48.435457572340965, 47.62627199292183, 48.45885291695595, 52.1224719285965, 51.54996804893017, 56.38362407684326, 54.39677529036999, 50.85353381931782, 46.754119992256165, 49.00821603834629, 42.95072928071022, 42.81425200402737, 48.20015899837017, 48.71017903089523, 47.87734352052212, 49.84316423535347, 48.07439714670181, 48.68355005979538, 56.81192569434643, 55.63739351928234, 56.007657051086426, 56.68080992996693, 54.82932887971401, 48.180164471268654, 47.30224058032036, 42.49401658773422, 43.89399066567421, 44.866335690021515, 47.86016084253788, 49.982738345861435, 43.64253915846348, 43.71206022799015, 43.53397138416767, 49.73515123128891, 48.055405765771866, 47.271101251244545, 48.03269438445568, 53.231138437986374, 51.641375944018364, 54.46541480720043, 52.979242354631424, 46.080032363533974, 47.66812674701214, 49.177990928292274, 51.05520039796829, 47.19055317342281, 50.73170855641365, 51.08266532421112, 50.56620083749294, 49.6985287964344, 51.41067132353783, 51.85354135930538, 51.37093685567379, 51.97203800082207, 52.797482907772064, 52.37155996263027, 56.457245126366615, 59.978371784090996, 56.894768849015236, 57.191924303770065, 57.77250275015831, 57.26716406643391, 57.26128198206425, 59.61055152118206, 60.800089091062546, 67.72650942206383, 65.69970577955246, 68.71901616454124, 68.75198319554329, 71.4211043715477, 71.7693404853344, 72.6572236418724, 70.94897970557213, 71.91222801804543, 65.24633690714836, 71.5927791595459, 78.89570608735085, 80.88693603873253, 78.15675213932991, 77.97687739133835, 8.708040229976177, 3.7713669799268246, 6.858949726447463, 0.21107824315549806, 0.30415524321142584, 52.056458070874214, 83.41631591320038, 70.91749459505081, 52.2585654258728, 56.262038201093674, 54.902691543102264, 56.6106390953064, 5.163787063211203, 0.38869586773216724, 0.15102274774108082, 0.21149400912690908, 0.16601049428572878, 0.1771802917937748, 0.15964666701620445, 0.3028322907630354], [0.011309172841720283, 0.047924360624165274, 0.03831254260148853, 0.04446390041266568, 0.07078619382809848, 0.023054995690472424, 0.03616733505623415, 0.026890592998825014, 0.1213324916898273, 40.3181317448616, 53.33171904087067, 36.24079093337059, 34.283113181591034, 57.38876514136791, 67.38942191004753, 70.1024079322815, 2.5142714101821184, 0.1614613813580945, 0.2049556584097445, 47.74457864463329, 89.57621857523918, 75.55510014295578, 74.64872717857361, 71.926439255476, 79.96939927339554, 77.50321000814438, 69.5874747633934, 64.23515796661377, 62.47848182916641, 64.37099307775497, 68.31366151571274, 74.3224310874939, 71.98335260152817, 50.94965346157551, 40.94810374081135, 63.7226452678442, 82.7478177845478, 74.2696139216423, 69.87305223941803, 69.93260264396667, 67.56345257163048, 65.26846691966057, 66.14266321063042, 65.72601556777954, 63.22925694286823, 61.26501314342022, 50.09379118680954, 49.4020839035511, 49.83703516423702, 49.761008843779564, 49.64837148785591, 48.45876932144165, 45.78949615359306, 44.832129925489426, 47.3908556252718, 47.6152677834034, 48.0744731426239, 47.67367444932461, 51.253770142793655, 48.61945889890194, 45.40670469403267, 47.16381400823593, 55.79218201339245, 52.46330223977566, 47.06904709339142, 47.89814740419388, 46.243537589907646, 46.46003097295761, 48.01867313683033, 46.933538764715195, 41.48327462375164, 44.040674194693565, 38.67758497595787, 41.59809306263924, 39.77397434413433, 39.96807172894478, 39.21125113964081, 43.61585699021816, 42.16153062880039, 41.17483377456665, 41.617867201566696, 41.668613478541374, 39.98237036168575, 42.71017178893089, 42.17106431722641, 39.03833381831646, 27.62481976300478, 32.407883405685425, 34.39435601234436, 29.832592494785786, 35.25556840002537, 36.153182834386826, 39.710985124111176, 42.93114893138409, 44.38377298414707, 45.7879838347435, 46.60407744348049, 46.714605912566185, 45.01706600189209, 44.05692212283611, 41.74451820552349, 41.307306066155434, 40.37179246544838, 43.526736572384834, 44.53020192682743, 45.970039665699005, 42.39757016301155, 42.55794435739517, 42.18988470733166, 40.26643171906471, 47.67956033349037, 40.97148768603802, 39.41315710544586, 47.340242341160774, 47.314620316028595, 49.34562273323536, 47.04971753060818, 46.35979615151882, 47.59073629975319, 47.97361895442009, 47.93114483356476, 43.88809718191624, 43.359598740935326, 42.6693619787693, 44.00736518204212, 43.16413722932339, 44.91721875965595, 49.81213890016079, 48.016473054885864, 48.649614080786705, 52.22528301179409, 56.60230614244938, 58.40643793344498, 56.19050703942776, 58.497967422008514, 58.67145851254463, 57.76744142174721, 60.73711887001991, 58.564228266477585, 63.65673780441284, 64.40164223313332, 66.23811408877373, 63.741222470998764, 63.18037636578083, 62.584807723760605, 64.4036865234375, 62.928655073046684, 66.27763956785202, 63.13583515584469, 63.9847058057785, 57.23022244870663, 62.628026604652405, 63.029611855745316, 75.76753914356232, 70.56081533432007, 78.03287118673325, 23.867098800837994, 1.058642549905926, 1.9270872557535768, 0.009471138364460785, 0.2616887219483033, 28.280810862779617, 80.66803738474846, 52.631177231669426, 40.01620754599571, 20.24236310273409, 26.30761854350567, 21.19563315063715, 0.9847233351320028, 0.16214766015764326, 0.013528468061849708, 0.025030982433236204, 0.0306909568462288, 0.07675266038859263, 0.058553269773256034, 0.015459784008271527, 0.048678753737476654, 0.12447125685866922, 0.03380627756996546, 0.054995591926854104, 0.06853135622804984, 0.02262120666273404, 0.09585645442712121, 0.07869756969739683, 0.195749509439338, 52.94709227979183, 60.223158448934555, 40.35427540540695, 38.344133868813515, 67.75490149855614, 72.10074350237846, 77.32758343219757, 2.679049805738032, 0.23499046394135803, 0.19495800894219428, 49.503333270549774, 93.95505800843239, 76.81834235787392, 76.12473517656326, 74.83785063028336, 82.44160741567612, 79.29279237985611, 72.7584958076477, 66.86077907681465, 63.051282092928886, 66.38143479824066, 70.17995417118073, 73.9605613052845, 76.78483575582504, 55.78091561794281, 46.42748571932316, 65.29092371463776, 80.57710066437721, 74.97476488351822, 71.6227139532566, 71.94603860378265, 69.6329203248024, 67.11488664150238, 69.7644616663456, 68.27095940709114, 65.87946653366089, 63.40855032205582, 52.86887727677822, 51.12502925097942, 52.38114304840565, 51.84393547475338, 52.078804671764374, 50.90816728770733, 48.91039788722992, 49.20552045106888, 49.696868285536766, 49.60044085979462, 49.87915590405464, 50.02135947346687, 52.92090408504009, 48.60666498541832, 45.171998888254166, 47.352264896035194, 57.863644659519196, 56.38693369925022, 48.31561580300331, 48.4913981705904, 46.69624909758568, 47.07088239490986, 49.859959334135056, 49.56961691379547, 44.47831571102142, 45.5183807015419, 41.58199332654476, 41.93191654980183, 40.82983508706093, 43.362976759672165, 42.885999754071236, 43.833627104759216, 45.99921450018883, 45.252527967095375, 44.56778571009636, 44.88131448626518, 43.203871697187424, 46.62557668983936, 43.40738497674465, 42.75415442883968, 36.1241789907217, 38.768004924058914, 38.33944492042065, 33.35736505687237, 42.4062716960907, 40.054171308875084, 42.70341195166111, 45.10623961687088, 45.42239025235176, 46.55871547758579, 49.460783153772354, 48.029696345329285, 49.80591103434563, 44.92391400039196, 43.73175457119942, 43.5533731430769, 41.701439917087555, 46.143352165818214, 47.52700611948967, 47.52230957150459, 43.2252037525177, 43.65916706621647, 43.63524354994297, 40.85803337395191, 47.90983937680721, 42.98597998917103, 41.22839570045471, 48.74698385596275, 47.12072432041168, 48.82714815437794, 47.94308379292488, 47.92202532291412, 47.35726922750473, 48.120378479361534, 49.80268880724907, 46.4661980420351, 46.041848212480545, 46.66816860437393, 45.981024876236916, 44.84292894601822, 47.838794589042664, 50.04012666642666, 49.614211320877075, 50.62197804450989, 54.62983198463917, 58.22469748556614, 58.763079196214676, 60.31278043985367, 60.75412675738335, 62.02144995331764, 60.57568833231926, 64.6496245265007, 62.681740522384644, 66.33287340402603, 67.74225577712059, 67.74086505174637, 67.48872578144073, 66.12602770328522, 66.10387489199638, 65.92469170689583, 67.37457230687141, 70.09234607219696, 67.99347549676895, 68.6594657599926, 60.203289315104485, 66.50977671146393, 66.56922832131386, 79.58960205316544, 72.19039589166641, 88.3161149919033, 40.88341221213341, 0.6628308515064418, 2.972605428658426, 0.03911192841769662, 0.3133217169670388, 30.714285783469677, 86.03577375411987, 61.952920630574226, 43.01037847995758, 26.594860330224037, 40.32788582146168, 42.453210577368736, 3.747285772114992, 0.22140579210827127, 0.06296181250945665, 0.09753801263286732, 0.03046519366762368, 0.04126400453969836, 0.03058647915167967, 0.04357759054983035, 0.12029899167828262, 0.19306535425130278, 0.20985724695492536, 0.11055297480197623, 0.4103373392717913, 0.1568533419049345, 0.19498304900480434, 0.2514313207939267, 0.5451243300922215, 67.0674879848957, 68.26546490192413, 44.52032245695591, 45.337935984134674, 79.91147518157959, 76.71935006976128, 84.52689751982689, 3.143338579684496, 0.5747655301820487, 0.8536672394257039, 54.64301347732544, 96.33913367986679, 81.81559100747108, 79.59937512874603, 79.58438113331795, 86.87524750828743, 81.99874877929688, 73.53186830878258, 69.9177910387516, 66.30505129694939, 69.97874736785889, 71.64751902222633, 77.2435699403286, 76.9991746544838, 57.65165023505688, 54.71293732523918, 69.22470822930336, 77.15196445584297, 74.20115679502487, 74.4791878759861, 74.09259662032127, 72.02597111463547, 69.19313192367554, 71.13582327961922, 70.65318077802658, 67.51937493681908, 66.72154694795609, 54.53046731650829, 52.84646227955818, 54.968154430389404, 55.41810728609562, 53.51190537214279, 54.21972379088402, 51.79509289562702, 52.03290693461895, 54.08327691257, 53.01971398293972, 53.027769550681114, 53.13087321817875, 54.82750117778778, 49.99862149357796, 44.778594598174095, 48.123243525624275, 58.28167162835598, 59.73993077874184, 49.32635396718979, 49.78422559797764, 46.86017610132694, 47.75912046432495, 52.823028936982155, 52.00486823916435, 47.961968779563904, 46.96044512093067, 44.550990611314774, 47.43028610944748, 44.64318886399269, 45.99657364189625, 45.927797332406044, 46.98604814708233, 49.51967239379883, 48.649477288126945, 46.535247936844826, 47.73841917514801, 46.99175164103508, 49.90599386394024, 48.308836966753006, 47.353758215904236, 42.302791848778725, 46.08702018857002, 48.67897890508175, 45.274342596530914, 47.578341364860535, 44.08842243254185, 46.721825525164604, 47.15054132044315, 48.454699739813805, 50.264554023742676, 52.27178871631622, 53.61396409571171, 50.89805603027344, 48.144887164235115, 47.23886378109455, 45.15505939722061, 44.540753960609436, 49.85881559550762, 49.10384550690651, 50.67336268723011, 45.34700229763985, 44.337453469634056, 44.18831147253513, 42.18451179563999, 49.578170254826546, 46.54347449541092, 43.57140317559242, 50.583277121186256, 49.365461468696594, 50.78404314815998, 48.23250666260719, 48.51822853088379, 49.95881102979183, 49.67449888586998, 53.106592521071434, 49.24173630774021, 49.457595124840736, 48.62849481403828, 49.62535612285137, 47.672728300094604, 49.30067114531994, 53.80071647465229, 51.982479840517044, 52.81367003917694, 58.81147339940071, 59.62787099182606, 62.49521993100643, 60.16235411167145, 63.588010892271996, 63.199751526117325, 64.14939656853676, 66.0285933315754, 64.93579477071762, 68.66449669003487, 69.94220852851868, 72.02613070607185, 69.74215686321259, 69.75914195179939, 70.58951899409294, 70.59495270252228, 70.03236249089241, 72.39021956920624, 70.03828257322311, 71.28337696194649, 62.725407779216766, 70.92825561761856, 69.5616589486599, 82.9935809969902, 75.34769967198372, 92.35378593206406, 44.50901426374912, 1.010992038063705, 8.120893836021423, 0.19143521203659475, 0.3111147478921339, 37.11828164756298, 93.18573608994484, 69.14235904812813, 62.25667253136635, 35.59823401272297, 45.50077244639397, 64.06830132007599, 7.300542080774903, 0.4879960580728948, 0.18862186378100887, 0.24179098574677482, 0.17207896162290126, 0.09823526779655367, 0.16970077907899395, 0.13945406069979072], [0.05006885199691169, 0.041464466048637405, 0.09533039788948372, 0.06597882835194468, 0.07385659977444448, 0.12574950233101845, 0.032221781148109585, 0.014719411919941194, 0.15008663234766573, 45.916074961423874, 54.45127576589584, 51.80981710553169, 42.40799680352211, 58.04914690554142, 70.06295084953308, 70.70425003767014, 2.2967755934223533, 0.07114257314242423, 0.10255457469611429, 36.63957953453064, 94.74881261587143, 75.34792006015778, 77.52375170588493, 67.03873112797737, 68.36840137839317, 62.45173126459122, 60.17498463392258, 64.14397805929184, 67.18829870223999, 69.30171489715576, 71.57413735985756, 73.66690546274185, 74.25413355231285, 75.49304947257042, 63.11752773821354, 48.377043306827545, 52.98559181392193, 75.86370438337326, 72.90369361639023, 64.92309585213661, 67.51713305711746, 61.546635031700134, 67.21330896019936, 65.79160004854202, 66.63025304675102, 57.33094364404678, 50.34021556377411, 50.65568223595619, 51.30322068929672, 47.1321427077055, 47.77360148727894, 47.41914890706539, 44.20786902308464, 44.09333936870098, 47.11974777281284, 44.593232944607735, 47.14874021708965, 45.469883903861046, 46.881838738918304, 48.53943519294262, 50.27084268629551, 44.95264805853367, 53.302380815148354, 63.06879535317421, 59.887704849243164, 56.97114855051041, 48.723660707473755, 47.959464713931084, 52.30209209024906, 48.641292527318, 44.62664075195789, 41.988510712981224, 42.21380062401295, 40.92050202190876, 41.63221903145313, 42.78067320585251, 42.95482166111469, 41.48489333689213, 41.65823243558407, 40.078106224536896, 40.670752823352814, 40.65809190273285, 39.773248583078384, 40.10767623782158, 40.41007921099663, 36.38169877231121, 28.53750418871641, 31.63550265133381, 32.85530939698219, 33.439015075564384, 33.381303772330284, 36.51506021618843, 40.23287191987038, 38.60438570380211, 42.81743623316288, 42.53866419196129, 45.21323047578335, 43.52128006517887, 44.90513160824776, 42.40360803902149, 42.381873205304146, 40.71590960025787, 41.70495852828026, 38.3670998364687, 41.74902856349945, 42.11091734468937, 46.87999963760376, 42.466236278414726, 45.42399376630783, 42.538762986660004, 44.068629294633865, 44.53153185546398, 46.801978424191475, 48.10016356408596, 46.07964478433132, 46.778628677129745, 43.00114117562771, 45.70572964847088, 46.57972075045109, 43.39665435254574, 45.33302664756775, 44.21010710299015, 43.180119171738625, 44.52617794275284, 41.11053742468357, 43.008546978235245, 47.11743749678135, 47.366259545087814, 48.67661543190479, 54.73945990204811, 57.60001860558987, 60.99876902997494, 60.37556827068329, 63.45556519925594, 62.3555888235569, 64.17145818471909, 63.134425431489944, 61.830415204167366, 63.14775891602039, 62.6915667951107, 61.20373383164406, 68.99554252624512, 69.3074069917202, 68.87536257505417, 66.86748191714287, 66.89204379916191, 65.19836068153381, 67.30634316802025, 65.98823949694633, 63.63271549344063, 58.59372228384018, 61.49782285094261, 64.5158489048481, 74.07462358474731, 74.77567836642265, 77.58245095610619, 74.68698352575302, 7.103412933647633, 2.344079492613673, 0.10861827002372593, 0.15625932690454647, 22.332347854971886, 74.49461504817009, 55.102279633283615, 36.96974001824856, 29.13631595671177, 27.156019918620586, 25.755331479012966, 0.680569427786395, 0.025892469311656896, 0.037544371516560204, 0.041113445040537044, 0.03500417442410253, 0.04741321754409, 0.037435683989315294, 0.05300014607200865, 0.04867392977757845, 0.02987182804645272, 0.06597772255190648, 0.0807810305559542, 0.0192126337060472, 0.05899813535506837, 0.0631523143965751, 0.03263964368670713, 0.5244284437503666, 61.85569904744625, 59.422457814216614, 45.6600446999073, 37.31991782784462, 68.41180264949799, 73.62714439630508, 78.23634266853333, 1.9272333104163408, 0.08643659661174752, 0.05810514616314322, 39.63355287909508, 98.19139748811722, 77.24246799945831, 78.10481652617455, 66.22210934758186, 68.85315656661987, 65.24123758077621, 62.69086383283138, 65.10040953755379, 69.11329820752144, 71.31472527980804, 75.17220228910446, 74.1095969080925, 75.995192527771, 73.97575289011002, 64.78286817669868, 52.15419642627239, 56.96125768125057, 78.53437587618828, 74.02114525437355, 65.58789297938347, 68.00508007407188, 63.66992309689522, 66.79220795631409, 67.5921106338501, 69.23847869038582, 59.823305904865265, 51.50658197700977, 52.6166620105505, 52.237936332821846, 49.85232174396515, 49.909489676356316, 49.05092194676399, 48.019843474030495, 46.940423995256424, 48.69965739548206, 48.22132386267185, 48.81672151386738, 47.20211215317249, 48.43947775661945, 50.80191358923912, 51.08113020658493, 44.78765331208706, 54.32473495602608, 67.37594783306122, 62.57917262613773, 58.06264378130436, 49.754192009568214, 48.35766814649105, 54.41159449517727, 51.898614540696144, 48.835370913147926, 45.77513672411442, 43.889905884861946, 43.215525671839714, 43.19285988807678, 44.742450937628746, 44.36479300260544, 43.489753156900406, 43.36312495172024, 42.76625297963619, 44.02369290590286, 43.147026747465134, 43.07623274624348, 44.81823027133942, 43.32365646958351, 39.70055088400841, 36.845714673399925, 36.30644381046295, 35.104830488562584, 37.01783403754234, 39.632762521505356, 39.88856099545956, 41.27030365169048, 40.72927728295326, 45.692958533763885, 43.461634665727615, 48.469765931367874, 44.046985656023026, 48.76363456249237, 45.39640724658966, 43.714226111769676, 42.33871892094612, 43.6550784856081, 40.354115813970566, 43.8836932182312, 44.055071622133255, 47.792619466781616, 43.943722397089005, 46.047532707452774, 43.71849708259106, 45.25592878460884, 45.46891875565052, 49.08818654716015, 48.7772074341774, 46.27832852303982, 47.840690687298775, 46.898527443408966, 46.62146911025047, 44.480470195412636, 43.608192801475525, 45.63646696507931, 46.96013353765011, 45.44333092868328, 45.199026837944984, 43.54893498122692, 45.854050889611244, 48.947233110666275, 47.60570749640465, 51.00916966795921, 55.61093933880329, 60.145106837153435, 61.82897508144379, 61.00403934717178, 64.70186412334442, 65.66790908575058, 65.76725095510483, 65.61815455555916, 63.952430337667465, 65.98003953695297, 65.36451816558838, 63.22284668684006, 69.50222253799438, 70.50209328532219, 69.94527876377106, 71.88188284635544, 70.80744490027428, 68.187485486269, 70.20047307014465, 67.70940274000168, 66.25625431537628, 62.916488125920296, 62.80078053474426, 68.87034684419632, 75.24269610643387, 79.07447889447212, 78.09448108077049, 88.69006052613258, 16.745957918465137, 2.167715043760836, 0.3315630537690595, 0.28298236371483654, 26.18422206491232, 78.55522155761719, 65.3580205142498, 40.91778516769409, 32.18784101307392, 44.930229261517525, 42.83598683774471, 5.386772872880101, 0.238358641800005, 0.03951118160330225, 0.059394030322437175, 0.04671345763199497, 0.055913446776685305, 0.08078150553046726, 0.09527789094136097, 0.17423452954972163, 0.11121442134026438, 0.16167388792382553, 0.17620678700041026, 0.1717399782501161, 0.22165387723362073, 0.3478888183599338, 0.14351464749779552, 0.785272631328553, 75.14629527926445, 68.24405685067177, 62.888935804367065, 57.41624906659126, 78.27434062957764, 79.99274522066116, 84.2640732228756, 2.640569983050227, 0.3339457930997014, 0.1729895471362397, 42.62385182082653, 102.713253647089, 81.42600551247597, 84.71095964312553, 71.28567963838577, 73.19424882531166, 67.50693440437317, 64.65744450688362, 68.06301176548004, 72.34106540679932, 73.21234345436096, 76.75964310765266, 78.12704533338547, 79.12907436490059, 74.18988659977913, 64.49448645114899, 59.064684212207794, 62.319011986255646, 75.44942021369934, 71.65301352739334, 68.56787547469139, 70.67434564232826, 64.36241313815117, 71.74952834844589, 69.51412349939346, 73.24193626642227, 61.66948243975639, 55.102408826351166, 55.287238508462906, 55.03044068813324, 52.004716247320175, 51.183994486927986, 51.1394152790308, 50.176022574305534, 50.88143192231655, 51.25598542392254, 51.37247957289219, 53.42970058321953, 49.48353253304958, 51.34689934551716, 51.474382504820824, 52.26500228047371, 44.356995820999146, 55.74872374534607, 68.9993879199028, 64.55033585429192, 59.286086931824684, 51.77558474242687, 50.84274239838123, 55.75585596263409, 53.219332471489906, 51.45890973508358, 47.7584782987833, 47.10202932357788, 45.72265774011612, 45.45032635331154, 49.65116813778877, 49.59255248308182, 48.44479367136955, 46.7424052208662, 44.606258645653725, 46.55354395508766, 46.7112734913826, 45.822212398052216, 48.16510587930679, 46.99894845485687, 44.98820275068283, 41.73251464962959, 44.31023173034191, 46.98728688061237, 45.73779232800007, 45.37110820412636, 44.192514047026634, 45.46771042048931, 44.286129623651505, 47.64325328171253, 46.954376846551895, 50.214601904153824, 49.440332651138306, 49.26353193819523, 46.89398668706417, 46.49949565529823, 44.17826861143112, 45.92374674975872, 43.49424831569195, 47.553927674889565, 46.794021651148796, 50.62949024140835, 44.860016629099846, 46.46418035030365, 44.41001437604427, 46.848343536257744, 47.73753762245178, 50.22844836115837, 49.78334404528141, 47.85699561238289, 49.45973061025143, 46.09704405069351, 47.64764964580536, 46.84691481292248, 45.86818993091583, 49.02272745966911, 49.349365532398224, 49.2671949416399, 49.40531373023987, 46.92933239042759, 48.767137974500656, 51.62623755633831, 51.19450852274895, 52.15447001159191, 59.959042221307755, 63.660917580127716, 64.49875742197037, 65.79679057002068, 68.75794127583504, 67.09188267588615, 68.52297708392143, 67.91345939040184, 65.6395398080349, 68.7645073235035, 68.3041924238205, 66.6546705365181, 73.03594172000885, 73.72588589787483, 74.04667228460312, 74.31253641843796, 71.02533280849457, 70.78626483678818, 71.83026641607285, 72.37289249897003, 70.78733637928963, 65.4992513358593, 67.29812800884247, 73.95637392997742, 81.35363459587097, 82.2044925391674, 83.59085574746132, 93.70043367147446, 18.35327737033367, 4.656667225062847, 0.9826979844365269, 0.2638299367390573, 31.66867107152939, 86.58525466918945, 71.23710304498672, 54.41207706928253, 50.45081242918968, 57.56383694708347, 61.68018266558647, 14.125127401202917, 0.6459103000815958, 0.36308613256551325, 0.23028094321489334, 0.17923344334121794, 0.17589674738701433, 0.3669307247037068, 0.1634108548751101], [0.0638859644823242, 0.025854601226455998, 0.04020228065201081, 0.021327815811673645, 0.04922350126435049, 0.05935085217060987, 0.051704667930607684, 0.12753782590152696, 1.1293486808426678, 55.07791914045811, 50.09894751012325, 41.014448180794716, 41.32962986826897, 56.30942925810814, 72.86957904696465, 53.54077622294426, 0.797090531559661, 0.12576686858665198, 0.09237890626536682, 34.35950428247452, 94.40839648246765, 76.16236075758934, 77.37761154770851, 67.16812938451767, 66.1910118162632, 63.12263086438179, 62.12741866707802, 70.91410517692566, 72.17740058898926, 75.33606469631195, 72.02126696705818, 74.6968325972557, 72.55343601107597, 62.95874185860157, 66.21618166565895, 71.34181782603264, 57.15432912111282, 53.33530604839325, 74.68281894922256, 67.82203629612923, 68.66281718015671, 66.33532047271729, 64.6435296535492, 61.50405831634998, 61.99813060462475, 57.242826372385025, 49.36698138713837, 50.051332265138626, 49.32278595864773, 48.71615990996361, 47.76085317134857, 46.93590983748436, 43.85913893580437, 45.28540760278702, 45.10623961687088, 44.88496609032154, 44.915033876895905, 45.250631868839264, 45.78262232244015, 51.57114811241627, 49.543432518839836, 46.91865876317024, 47.26434901356697, 49.121138378977776, 55.743601620197296, 56.45303875207901, 53.505810499191284, 50.72627864778042, 52.227346301078796, 53.55892784893513, 49.887914434075356, 46.312705278396606, 43.45096863806248, 42.67197243869305, 42.36709199845791, 41.32351979613304, 43.20020869374275, 41.29811055958271, 42.58458472788334, 42.1720864623785, 41.77142836153507, 40.95016323029995, 38.52959431707859, 39.9888414144516, 40.40876068174839, 37.970522716641426, 29.166919514536858, 33.753672391176224, 31.882063820958138, 36.84473052620888, 32.506985887885094, 34.191351905465126, 39.22771945595741, 39.23083148896694, 40.910550355911255, 42.28317350149155, 42.70821489393711, 41.69478267431259, 42.10824228823185, 41.625318601727486, 40.68263478577137, 39.57741089165211, 40.92686668038368, 40.41917212307453, 41.17081359028816, 44.290734976530075, 49.0367791056633, 49.79692451655865, 51.6528133302927, 48.68273310363293, 47.58179157972336, 43.56888771057129, 45.88663414120674, 46.452754363417625, 51.006684601306915, 50.37262782454491, 45.42074494063854, 44.12255600094795, 46.908764094114304, 44.78195361793041, 45.55113114416599, 43.31666484475136, 40.33252917230129, 41.91935442388058, 42.72837281227112, 43.51766645908356, 48.540939912199974, 45.68973250687122, 51.34994298219681, 55.82306295633316, 59.50256131589413, 62.38475605845451, 59.68344680964947, 62.25887641310692, 58.61665405333042, 61.369773522019386, 60.20901180803776, 62.33442775905132, 63.885705918073654, 67.74407207965851, 70.72735279798508, 67.91592165827751, 65.94548419117928, 67.63887852430344, 66.80487647652626, 67.88199707865715, 66.1243861913681, 64.56483587622643, 63.279235661029816, 62.418741434812546, 58.95884849131107, 58.866323456168175, 59.430897161364555, 65.64533829689026, 71.2059523165226, 73.04174020886421, 79.63462963700294, 44.44942966103554, 0.481034861295484, 0.061610502598341554, 0.2228368606301956, 23.941198624670506, 74.61386784911156, 57.62656778097153, 40.56193806231022, 29.055406898260117, 29.637011289596558, 26.260879151523113, 1.7831968143582344, 0.04289182754291687, 0.057684649000293575, 0.08838477879180573, 0.04249273391906172, 0.04287565985578112, 0.07136835673009045, 0.05881632030650508, 0.06618063314817846, 0.047527037022518925, 0.03925740049453452, 0.04713474147138186, 0.1018463283253368, 0.10710937247495167, 0.032598187317489646, 0.2545379212824628, 2.531091682612896, 68.24234694242477, 58.61163452267647, 46.52127608656883, 46.088806092739105, 64.1666704416275, 79.10636678338051, 53.35266351699829, 0.3134072123793885, 0.18769780086586252, 0.15215671970508993, 36.97085715830326, 93.16468521952629, 78.93719986081123, 83.1830920279026, 68.13414394855499, 67.90419548749924, 65.55855095386505, 65.64561948180199, 72.48696997761726, 73.90652060508728, 76.87223866581917, 73.55253159999847, 75.16902565956116, 73.20092126727104, 65.27285188436508, 68.06146904826164, 70.78805834054947, 58.14734883606434, 59.507242664694786, 75.07839292287827, 69.62136134505272, 69.19777527451515, 69.31173875927925, 67.19678744673729, 65.93365922570229, 62.7647964656353, 60.665424317121506, 53.2669173181057, 51.76186367869377, 50.971354097127914, 50.80733209848404, 50.29200755059719, 49.350763857364655, 45.66612057387829, 47.227616384625435, 45.91102123260498, 46.10215477645397, 46.318321377038956, 47.154504507780075, 47.13642127811909, 52.25851222872734, 50.46856887638569, 46.769383773207664, 46.888647973537445, 48.84910337626934, 57.76656746864319, 58.572367429733276, 54.581730365753174, 54.22629363834858, 53.119808211922646, 55.34130580723286, 53.05385895073414, 48.50887343287468, 47.20115080475807, 45.4012443870306, 44.71030846238136, 44.226575419306755, 45.77500373125076, 45.31785026192665, 44.83806520700455, 44.64600071310997, 44.56368573009968, 43.59140530228615, 39.872411862015724, 41.95754997432232, 42.537847235798836, 41.28715954720974, 37.17661611735821, 38.1766464561224, 36.35883919894695, 39.13519062101841, 38.76947544515133, 39.33493830263615, 41.28835268318653, 41.391737535595894, 43.981469571590424, 44.107638001441956, 44.83892776072025, 43.77213880419731, 44.54632066190243, 46.07418067753315, 43.37632544338703, 43.59210826456547, 43.3978246897459, 41.90066322684288, 44.01150695979595, 47.790833562612534, 51.157821491360664, 53.56582447886467, 52.941065803170204, 48.61583389341831, 47.37421631813049, 43.743723928928375, 44.50987681746483, 46.558673679828644, 53.15815955400467, 52.08364941179752, 45.97016505897045, 44.69940684735775, 47.667685970664024, 46.400187984108925, 47.817872911691666, 45.623551458120346, 42.92796090245247, 44.06637601554394, 44.114652425050735, 45.58395758271217, 49.64778631925583, 47.90857784450054, 53.24621982872486, 58.721729815006256, 60.230412259697914, 66.67904242873192, 63.71034912765026, 66.03715807199478, 62.227376103401184, 63.59833873808384, 64.3206761777401, 65.3616227209568, 66.61009892821312, 69.47019785642624, 72.79650136828423, 67.24608600139618, 66.60409525036812, 67.87207961082458, 70.35523876547813, 70.16455739736557, 69.12238731980324, 67.3817691206932, 65.34373328089714, 64.93306651711464, 61.48404099047184, 60.031751319766045, 61.64951831102371, 66.1435067653656, 75.07275402545929, 76.87107592821121, 80.4996532201767, 62.44389608502388, 0.29395899502560496, 0.13350598455872387, 0.226046827447135, 27.892946675419807, 80.27315497398376, 66.59702003002167, 47.54679545760155, 27.709093540906906, 46.01711913943291, 42.7810113877058, 8.921491876244545, 0.2722786052618176, 0.03779673883400392, 0.0757883804908488, 0.045931092972750776, 0.08694903473951854, 0.07431522477418184, 0.03559682758350391, 0.09164999108179472, 0.13713547261431813, 0.09581850841641426, 0.15913823648588732, 0.15507080708630383, 0.20105307485209778, 0.1204831778886728, 0.3317585354670882, 3.1568038696423173, 81.88319697976112, 61.96583613753319, 55.81881858408451, 57.0489189773798, 73.9304669201374, 84.86503377556801, 68.47974300384521, 0.9602074068970978, 0.43478448526002467, 0.22136739338748157, 41.01228229701519, 99.9521242082119, 82.84619450569153, 86.19224175810814, 71.49747267365456, 71.2081789970398, 68.89018937945366, 68.11372384428978, 76.25967353582382, 76.51890322566032, 79.38898041844368, 76.19357228279114, 79.12907436490059, 75.52462577819824, 66.20586901903152, 70.58547601103783, 70.97323000431061, 64.3010388314724, 63.57003405690193, 71.89832076430321, 73.17123726010323, 75.0893135368824, 72.15082481503487, 70.43904706835747, 66.4981797337532, 66.04419529438019, 60.89887998998165, 55.13620041310787, 55.133612751960754, 53.83720211684704, 53.326710909605026, 51.765211299061775, 51.72164283692837, 47.934279665350914, 50.74492424726486, 51.04286625981331, 49.25757385790348, 50.01151040196419, 51.64168372750282, 51.58118337392807, 53.63365463912487, 51.6921716183424, 47.826551645994186, 46.38247333467007, 50.551161244511604, 59.452548399567604, 62.56148837506771, 56.28330186009407, 56.26658275723457, 54.74252253770828, 59.61861088871956, 54.75525565445423, 49.85353767871857, 48.36172252893448, 47.302270978689194, 48.69404509663582, 48.641072139143944, 49.49492812156677, 46.53013341128826, 49.17958304286003, 48.01397658884525, 49.01572063565254, 46.70636795461178, 43.23252595961094, 45.414923653006554, 44.37786430120468, 45.5646014213562, 40.814867690205574, 45.47248676419258, 45.81384904682636, 48.942965939641, 43.077809661626816, 41.242409348487854, 44.920615777373314, 45.560592636466026, 46.58352434635162, 47.86949694156647, 46.08421593904495, 46.773681342601776, 45.6910016387701, 47.352454885840416, 44.62441027164459, 44.51123334467411, 45.44157162308693, 44.578227549791336, 46.34218789637089, 50.432926788926125, 51.565459817647934, 53.599023297429085, 54.401369243860245, 49.250270649790764, 48.600744903087616, 45.54181784391403, 47.55528800189495, 47.34193705022335, 55.52415959537029, 54.67734843492508, 47.666443437337875, 45.825461223721504, 50.52479065954685, 48.32261882722378, 50.22997967898846, 46.83147244155407, 44.44103591144085, 46.709214001894, 47.70784221589565, 48.815072402358055, 51.5757192671299, 50.367703288793564, 55.66141963005066, 61.68115921318531, 62.29021333158016, 67.99361988902092, 65.07088512182236, 68.28204721212387, 64.38727900385857, 67.84814849495888, 67.82970428466797, 68.52993071079254, 70.14576360583305, 71.15995198488235, 73.5554726421833, 69.82763707637787, 70.99711552262306, 71.95545449852943, 72.26414233446121, 74.62003871798515, 73.79275470972061, 69.88575115799904, 67.8041772544384, 67.70181074738503, 64.85314160585403, 63.246614411473274, 65.57026952505112, 70.10153397917747, 77.08917662501335, 82.29953303933144, 84.04391303658485, 68.42248007655144, 0.4099411511560902, 0.257042936864309, 0.24982237431686372, 32.609580382704735, 88.94995898008347, 73.48922699689865, 61.14632271230221, 50.49064949154854, 55.31212717294693, 61.00364036858082, 17.388416044414043, 0.5155126971658319, 0.17767208337318152, 0.23409145593177527, 0.11242582157137804, 0.16484184918226674, 0.22243838669965044, 0.12706108507700264], [0.11507554852869362, 0.016215388677665032, 0.041274609829997644, 0.03938454152375925, 0.12553004926303402, 0.10922719477093779, 0.13554987410316244, 0.1842442314955406, 2.288511749356985, 59.1629621386528, 46.89351551234722, 34.793775379657745, 27.226933613419533, 56.16577036678791, 78.58158454298973, 17.392033450305462, 0.5235560343135148, 0.32394867797847837, 0.5632201465778053, 31.485990174114704, 92.31072664260864, 78.4841425716877, 77.81256660819054, 67.538001537323, 63.024630323052406, 65.0433897972107, 73.18054676055908, 73.43839332461357, 73.50999668240547, 75.9843935072422, 73.63397642970085, 71.04750081896782, 70.02707317471504, 71.47703737020493, 69.14029195904732, 63.283214047551155, 68.08437421917915, 57.282332852482796, 57.91665181517601, 74.55067723989487, 64.59320515394211, 66.70210719108582, 59.2886745929718, 62.91398026049137, 60.23830443620682, 58.44835728406906, 50.51387384533882, 49.941594153642654, 46.62604406476021, 47.95846536755562, 49.222049564123154, 46.49502329528332, 44.8994205147028, 45.469952300190926, 42.60313153266907, 42.69059903919697, 46.230314299464226, 46.509675309062004, 48.288846239447594, 51.60536527633667, 52.02680826187134, 49.89655137062073, 51.48718781769276, 61.96371965110302, 55.483178794384, 55.660595074296, 50.81678979098797, 52.02465757727623, 54.13526572287083, 53.84417474269867, 52.47402526438236, 49.64668817818165, 46.260385885834694, 46.12374521791935, 44.84789527952671, 43.48514020442963, 43.3777541667223, 43.4122297167778, 41.552172526717186, 42.54147604107857, 39.01456989347935, 39.38725009560585, 39.78947751224041, 41.01903833448887, 40.63062697649002, 40.00619888305664, 29.685509987175465, 36.8920873850584, 32.75648809969425, 38.592712730169296, 34.136213064193726, 34.3093241751194, 40.656621381640434, 38.941575810313225, 43.416287899017334, 42.48586602509022, 43.74969340860844, 43.37708540260792, 43.964484483003616, 42.54825867712498, 42.63601876795292, 40.214511305093765, 43.168567791581154, 42.023548632860184, 46.14744454622269, 51.75263777375221, 54.13091115653515, 52.00603857636452, 52.690191864967346, 51.64899453520775, 46.791095808148384, 41.983536779880524, 48.78448784351349, 53.1295470893383, 56.06242351233959, 50.10463960468769, 44.76034037768841, 38.897653967142105, 41.839885488152504, 46.117798537015915, 42.6901962608099, 42.79734671115875, 43.53369779884815, 42.913723066449165, 40.30179262161255, 43.231040239334106, 46.86904862523079, 46.64857305586338, 51.680787429213524, 58.40350829064846, 57.27380231022835, 61.231248155236244, 60.75544148683548, 65.21146237850189, 61.77788682281971, 64.22306701540947, 59.89609859883785, 62.10798650979996, 65.96681624650955, 60.007132440805435, 51.166192442178726, 52.42412254214287, 61.12109586596489, 65.83443894982338, 64.53541025519371, 65.47832205891609, 61.19147568941116, 64.2107404768467, 60.68147465586662, 61.7795093357563, 59.436137080192566, 62.61712498962879, 59.37241829931736, 61.26779079437256, 66.80952742695808, 77.434973269701, 74.81917843222618, 78.18227916955948, 1.5001628268510103, 0.30225172347854823, 0.3602017310913652, 19.644856564700603, 74.92924332618713, 59.95665594935417, 42.858113050460815, 29.034093841910362, 30.747965276241302, 26.209190525114536, 2.7301601506769657, 0.24422393878921866, 0.12505733087891713, 0.04061707812070381, 0.04323337874666322, 0.06145035455119796, 0.07832727511413395, 0.0578963132284116, 0.07859701610868797, 0.062044206279097125, 0.01770312388543971, 0.041271637528552674, 0.14730311842868105, 0.04077880323166028, 0.07260164289618842, 0.274366830708459, 4.055336192250252, 71.71358987689018, 54.540399983525276, 42.6172211766243, 34.09051291644573, 63.21521669626236, 85.11055380105972, 19.013452045619488, 0.5767804908100516, 0.4497732559684664, 0.6279162468854338, 34.12970021367073, 93.4009413421154, 81.12033471465111, 81.69721975922585, 69.39927846193314, 66.2204222381115, 67.7897684276104, 74.66373637318611, 75.8507850766182, 76.5498335659504, 76.67345613241196, 77.58301332592964, 72.142533659935, 71.34715273976326, 73.81595626473427, 73.12548011541367, 64.82933968305588, 69.68786537647247, 62.183241471648216, 62.065725177526474, 76.39218002557755, 66.06013923883438, 67.88866952061653, 61.139331087470055, 64.24943760037422, 61.56800128519535, 60.49917943775654, 53.16192515194416, 52.13959380984306, 49.4363846629858, 49.632286950945854, 50.13356365263462, 48.96325305104256, 47.63758398592472, 47.65545442700386, 46.537451818585396, 43.775562420487404, 47.67501197755337, 50.2659447491169, 49.041654244065285, 53.48163619637489, 51.76805354654789, 48.35388734936714, 51.10212408006191, 63.03908854722977, 56.87459573149681, 56.59475214779377, 52.2756303101778, 53.75141032040119, 55.563263297080994, 55.80153331160545, 55.5650720000267, 52.64125049114227, 48.24989452958107, 47.38424398005009, 47.30872683227062, 46.651073321700096, 44.782975763082504, 44.8694933205843, 45.04930727183819, 44.53766092658043, 42.58349798619747, 42.715172320604324, 41.74741365015507, 43.60186994075775, 41.17505416274071, 43.01131322979927, 34.27048645913601, 39.691142588853836, 35.43882496654987, 40.64049884676933, 38.21216695010662, 38.34572598338127, 43.66743162274361, 42.36663982272148, 44.60347719490528, 44.87659893929958, 46.82684428989887, 46.81870512664318, 45.459833443164825, 43.942358270287514, 44.46867562830448, 43.09449836611748, 44.91269700229168, 46.00679129362106, 50.74045568704605, 53.35251912474632, 56.12204611301422, 57.14083984494209, 56.1176535487175, 54.148906990885735, 49.67465087771416, 44.11854721605778, 48.165820240974426, 56.788032576441765, 57.18788892030716, 49.692270532250404, 45.95638319849968, 40.790548995137215, 43.98485518991947, 47.135528326034546, 43.72708082199097, 45.989840403199196, 45.19927002489567, 44.54896531999111, 43.53365980088711, 45.344239845871925, 47.692468240857124, 49.66867379844189, 54.10249628126621, 62.018733099102974, 60.295669957995415, 63.95461902022362, 62.095602974295616, 65.84472879767418, 64.77339908480644, 68.87362226843834, 61.194101348519325, 66.87785536050797, 66.42011672258377, 58.76620262861252, 53.219750449061394, 57.454452216625214, 63.79991412162781, 68.01995247602463, 67.096898406744, 68.1309749186039, 64.16382819414139, 65.3663344681263, 63.608085215091705, 65.51655560731888, 61.50022432208061, 67.04611033201218, 60.846249014139175, 64.94893446564674, 67.61505380272865, 81.69957563281059, 75.17486974596977, 88.86600628495216, 3.526541367173195, 0.3875082830199972, 0.35873955173883587, 20.257248803973198, 83.7399673461914, 64.08249735832214, 52.75954954326153, 24.266772754490376, 36.25079959630966, 43.04293893277645, 11.899677067995071, 0.5208144814241678, 0.12726159853627905, 0.13724577060202137, 0.08440495992545038, 0.05841979080287274, 0.08459034841507673, 0.06570091631147079, 0.14278023299993947, 0.1446784834843129, 0.1903796405531466, 0.13060234661679715, 0.36630645976401865, 0.30080394179094583, 0.3468280518427491, 0.31886181968729943, 5.242533087730408, 84.87109065055847, 62.55553409457207, 45.531383603811264, 40.89666210114956, 73.91396060585976, 91.97635978460312, 25.924040526151657, 0.7574578269850463, 0.684585515409708, 0.8833155047614127, 37.508361116051674, 96.70794948935509, 83.97752299904823, 84.64779183268547, 73.91344383358955, 69.44107621908188, 70.18630743026733, 79.73771810531616, 78.30232992768288, 79.3113049864769, 78.6658488214016, 77.79908493161201, 75.79603761434555, 72.22805947065353, 76.75963550806046, 74.46627616882324, 69.97413441538811, 71.11756905913353, 66.92724511027336, 64.96319890022278, 75.51379635930061, 70.94976246356964, 69.02880594134331, 64.33662012219429, 67.01879739761353, 64.8303884267807, 66.91875636577606, 55.17209328711033, 55.97120940685272, 50.4189283400774, 51.76320120692253, 53.08450810611248, 51.40538580715656, 50.571672543883324, 50.40275640785694, 50.670011267066, 45.52937351167202, 50.92384144663811, 53.46124269068241, 51.2213920801878, 55.8996706455946, 52.283556684851646, 49.2538196593523, 51.49990573525429, 64.68472704291344, 60.468203499913216, 61.381074115633965, 54.310044944286346, 54.36557896435261, 57.99762926995754, 58.01160492002964, 57.50326059758663, 54.6876534819603, 49.8960117995739, 49.469986259937286, 50.326790884137154, 48.801206946372986, 48.46051722764969, 49.733414724469185, 47.14934058487415, 48.208111971616745, 46.37334622442722, 43.9229679107666, 46.32712170481682, 46.27527728676796, 46.04783669114113, 46.063792034983635, 38.24520617723465, 46.77132926881313, 46.80384412407875, 49.63306590914726, 42.72003225982189, 41.64341703057289, 47.03458294272423, 44.07898373901844, 48.71731884777546, 47.46688574552536, 49.07182462513447, 49.83885906636715, 47.27986358106136, 45.76837308704853, 48.98321717977524, 45.29970623552799, 46.97259686887264, 46.66791781783104, 52.30369180440903, 56.05486951768398, 59.866422191262245, 59.31342266499996, 58.588512763381004, 56.34033299982548, 50.27690336108208, 43.65486189723015, 50.51741525530815, 57.56357476115227, 57.86085940897465, 52.090443447232246, 46.73940718173981, 38.79923924803734, 45.62067121267319, 49.32313174009323, 45.43401762843132, 48.3171509206295, 48.334895968437195, 47.627400532364845, 45.57760052382946, 47.948696091771126, 49.11624424159527, 50.05763992667198, 56.23518884181976, 65.1170526444912, 60.30261218547821, 66.29514902830124, 64.80668529868126, 68.87249752879143, 66.63214534521103, 70.74170842766762, 62.71261006593704, 68.33517596125603, 65.6788221001625, 61.81647755205631, 57.562697008252144, 62.55326181650162, 67.4261811375618, 72.97413423657417, 70.9767334163189, 71.75611719489098, 66.79707929491997, 69.80267241597176, 65.41125565767288, 68.6332319676876, 65.45056074857712, 70.1994851231575, 64.35881853103638, 68.0120413005352, 73.10171619057655, 87.57884055376053, 79.91754725575447, 96.84000000357628, 4.533758545294404, 0.4644692939473316, 0.38592213531956077, 24.91213772445917, 93.43502551317215, 72.17152610421181, 63.92975315451622, 48.326749205589294, 56.370404586195946, 61.00660040974617, 21.745231859385967, 0.7960058678872883, 0.2386627739178948, 0.29291523853316903, 0.24897632596548647, 0.1782831529271789, 0.20317294547567144, 0.19834441394777969], [0.0761114596389234, 0.06254882959183306, 0.01010235073408694, 0.051623981635202654, 0.05693321334547363, 0.06117346296377946, 0.03259772347519174, 0.29855683736968786, 2.5439485302194953, 63.57951834797859, 48.210220858454704, 41.21332950890064, 47.362049371004105, 61.02775767445564, 76.04260638356209, 8.679790645837784, 0.17765865050023422, 0.2832315769046545, 0.5080300674308091, 27.375287152826786, 93.53825837373734, 75.62031984329224, 78.79526987671852, 64.61853459477425, 65.15115961432457, 73.32309991121292, 73.94967868924141, 74.19927969574928, 73.78277644515038, 73.01790028810501, 66.91946312785149, 68.4911347925663, 66.32081285119057, 68.24035584926605, 66.58011853694916, 69.92665216326714, 63.64923320710659, 63.77224400639534, 58.362668082118034, 65.7650850713253, 66.33270621299744, 65.05252450704575, 61.04833737015724, 62.19335272908211, 62.3711983859539, 58.559185937047005, 49.67774011194706, 48.00901785492897, 48.98100949823856, 48.747850209474564, 47.97325797379017, 48.438660800457, 45.49993649125099, 42.68996447324753, 41.67320363223553, 43.720716163516045, 44.231378361582756, 44.891349747776985, 46.45465046167374, 52.6585927605629, 59.58092451095581, 51.63389794528484, 57.784753292798996, 65.61380758881569, 63.901133090257645, 53.04638475179672, 50.018008053302765, 49.86815169453621, 50.10364405810833, 54.59019251167774, 55.01901090145111, 54.60788816213608, 48.52406121790409, 46.61728173494339, 43.90517346560955, 44.174145832657814, 45.04059433937073, 42.4256506562233, 40.56579105556011, 44.11126680672169, 40.41479475796223, 41.02027706801891, 41.167059391736984, 39.454156905412674, 37.55807004868984, 37.443661987781525, 32.763076946139336, 40.565612465143204, 31.552176922559738, 38.594031259417534, 39.953575506806374, 32.26862847805023, 40.52384130656719, 41.496931090950966, 41.133146211504936, 43.65706577897072, 44.733943194150925, 45.70504188537598, 45.88332071900368, 45.948696210980415, 42.40646928548813, 43.44645448029041, 48.14169533550739, 50.91623045504093, 51.479949206113815, 53.82841698825359, 50.63300885260105, 50.033195838332176, 49.71155069768429, 50.8922765403986, 49.84120734035969, 45.00631257891655, 46.40166610479355, 53.28502714633942, 51.14472359418869, 52.52211548388004, 44.134434163570404, 43.17391790449619, 44.78055149316788, 41.220389530062675, 43.5653804987669, 41.26046597957611, 39.48823347687721, 41.324766129255295, 40.4831986874342, 43.8032591342926, 45.47540120780468, 45.72494521737099, 52.720734626054764, 61.516229063272476, 59.01183284819126, 57.62751393020153, 55.310785844922066, 61.385215893387794, 62.28796385228634, 65.19739553332329, 67.07721546292305, 69.76724311709404, 52.995399087667465, 50.612071976065636, 53.74743953347206, 63.62222045660019, 64.07368183135986, 67.65955701470375, 63.527271151542664, 67.34830811619759, 63.269029408693314, 65.33550292253494, 59.97063159942627, 60.84615781903267, 57.17107102274895, 61.28265559673309, 59.229937344789505, 69.54395949840546, 60.03241628408432, 79.607924669981, 69.75977271795273, 91.91680938005447, 8.878162801265717, 0.4811679432168603, 0.42170698230620474, 11.445794273167849, 75.40468141436577, 56.11926086246967, 43.033971413969994, 17.18381032347679, 32.08130232989788, 27.474458031356335, 2.306671687401831, 0.28838810801971704, 0.1297169050667435, 0.06578517975867726, 0.04176286507572513, 0.036512036676867865, 0.06318112456938252, 0.04239779096678831, 0.0335197491949657, 0.04528268596914131, 0.015352199498011032, 0.03984791997936554, 0.04905406523903366, 0.04076344448549207, 0.08056059043155983, 0.18364926654612646, 4.187931502237916, 73.98452281951904, 53.81943427026272, 42.414038479328156, 50.52632197737694, 69.80499789118767, 80.43436512351036, 11.081985644996166, 0.4017999692587182, 0.3205070423427969, 0.4473016964038834, 29.007892347872257, 95.7303911447525, 76.88415482640266, 80.7947301864624, 68.40981155633926, 67.63419717550278, 75.83244726061821, 78.92818674445152, 75.73410093784332, 76.63947075605392, 75.08638769388199, 69.15277808904648, 67.59537845849991, 69.21140894293785, 70.44334083795547, 69.40601170063019, 71.06126368045807, 65.77453136444092, 66.78324803709984, 62.71174371242523, 69.43523973226547, 69.01308238506317, 68.08635771274567, 64.5450921356678, 64.54855754971504, 64.03999283909798, 60.0751905888319, 51.8503837287426, 50.07870979607105, 50.92894457280636, 51.3905856013298, 52.02551253139973, 49.710965529084206, 46.46294541656971, 46.18787057697773, 44.17356826364994, 46.55841909348965, 48.03615219891071, 47.40313656628132, 49.73369970917702, 55.14907792210579, 62.15524837374687, 52.90129333734512, 60.09030997753143, 68.12095105648041, 63.75889912247658, 55.240649208426476, 51.25379294157028, 51.60630762577057, 52.76315934956074, 55.499457120895386, 56.71824172139168, 58.189328983426094, 52.31000706553459, 49.09181535243988, 48.146920055150986, 48.067606911063194, 47.48256370425224, 46.450318694114685, 43.14730033278465, 48.02934676408768, 43.50141853094101, 43.0396369099617, 43.34213487803936, 40.81915766000748, 41.22230842709541, 42.02003762125969, 37.72170066833496, 44.5358370244503, 35.38299836218357, 42.34111279249191, 42.51437209546566, 35.98932422697544, 43.92290711402893, 42.21079498529434, 44.498409032821655, 45.544059723615646, 47.29153275489807, 48.7985584884882, 49.85472321510315, 47.108488976955414, 46.08109250664711, 46.71709097921848, 51.51270344853401, 54.421226978302, 57.14759208261967, 54.52283352613449, 53.1700187176466, 53.92003007233143, 52.36324600875378, 53.948007971048355, 50.684024915099144, 45.637443512678146, 46.8333001434803, 53.39394450187683, 52.193585112690926, 52.43404760956764, 44.19407956302166, 44.20017443597317, 47.4590277671814, 42.95037969946861, 44.60287302732468, 42.38060787320137, 42.052955254912376, 43.21665421128273, 41.994411796331406, 46.33758254349232, 46.87993884086609, 48.84517818689346, 56.234375685453415, 63.65182086825371, 60.67340388894081, 61.04431338608265, 56.71190366148949, 62.18493238091469, 65.19763112068176, 68.03434610366821, 68.57081651687622, 71.90865620970726, 54.72505487501621, 50.52756071090698, 55.27847617864609, 65.96030339598656, 64.34827029705048, 69.34989631175995, 66.67299315333366, 69.52011957764626, 63.6612481623888, 68.44124346971512, 60.83530940115452, 64.32764500379562, 59.0093781799078, 65.72094663977623, 61.17038682103157, 71.47692337632179, 60.52460387349129, 82.77708381414413, 70.49855947494507, 100.91997787356377, 12.035088501870632, 0.48121285799425095, 0.33310957078356296, 11.967574674636126, 83.98355707526207, 62.18744404613972, 55.64819633960724, 22.37527035176754, 49.60085503757, 45.578170493245125, 14.512769300490618, 0.379440039396286, 0.015265922047547065, 0.16113773075630888, 0.04651783863664605, 0.09769448704901151, 0.0752252091479022, 0.023892091885500122, 0.1737534545827657, 0.18806853331625462, 0.15600661077769473, 0.10874502142542042, 0.24499786522937939, 0.11637847783276811, 0.13177756714867428, 0.37066553835757077, 5.542939268052578, 90.35669669508934, 60.26472061872482, 54.172017350792885, 61.23375982046127, 77.38522633910179, 84.86895516514778, 13.612456060945988, 0.820583839667961, 0.4670810600509867, 0.771160782314837, 33.59503090381622, 99.6828630566597, 81.52208715677261, 84.68569099903107, 70.98512336611748, 71.02052986621857, 78.67225527763367, 81.89285606145859, 79.34450760483742, 79.97565373778343, 77.45181396603584, 69.75351065397263, 70.60441419482231, 70.60515895485878, 74.65541481971741, 72.42738917469978, 73.02037015557289, 66.93320319056511, 69.66651052236557, 65.72625115513802, 69.88398045301437, 72.61058494448662, 68.11044842004776, 65.73724016547203, 66.92004829645157, 66.77756354212761, 65.37717148661613, 54.50810931622982, 52.769159227609634, 53.05548906326294, 54.048835560679436, 52.05329664051533, 51.53282716870308, 49.90628644824028, 48.824066519737244, 47.587020099163055, 49.89195741713047, 51.41283340752125, 50.46800650656223, 50.21074891090393, 57.21280798316002, 62.1740497648716, 58.058805987238884, 60.28005659580231, 71.74092561006546, 67.80553758144379, 56.88376843929291, 54.14583295583725, 53.74189183115959, 55.57847008109093, 57.28882670402527, 58.69980499148369, 58.04665803909302, 54.02043588459492, 53.30514706671238, 51.5658587962389, 51.16811513900757, 52.012133449316025, 48.68165396153927, 45.228140875697136, 50.94645403325558, 46.33005894720554, 44.627723693847656, 46.460840329527855, 44.145841151475906, 44.65431086719036, 45.91474123299122, 42.264444306492805, 51.274942606687546, 48.6837400496006, 50.16771242022514, 48.37761327624321, 39.09579433500767, 46.88194513320923, 45.15146479010582, 46.7344256490469, 49.514911249279976, 49.19371448457241, 51.70744299888611, 49.65284384787083, 50.87312936782837, 48.23999606072903, 48.236659839749336, 53.41210752725601, 55.38045510649681, 57.841982021927834, 58.47079887986183, 55.86158528923988, 55.825236439704895, 55.406681299209595, 56.16835042834282, 53.21387216448784, 47.395305186510086, 49.13306213915348, 57.03330181539059, 53.886481672525406, 52.92905084788799, 45.912518352270126, 44.49267514050007, 47.19226308166981, 45.45443773269653, 47.22865752875805, 46.54914379119873, 44.72464509308338, 45.44561080634594, 45.084728971123695, 47.90313273668289, 48.545115888118744, 51.819723173975945, 57.03917630016804, 65.85686534643173, 64.50928285717964, 65.84844499826431, 58.81872721016407, 64.34893146157265, 65.79661577939987, 69.72864478826523, 68.95217925310135, 73.63032102584839, 57.52433806657791, 55.754130855202675, 58.02581995725632, 65.48977464437485, 65.9940455853939, 72.07297459244728, 68.62985774874687, 74.48256209492683, 65.71406900882721, 72.9275107383728, 65.31988576054573, 67.13841497898102, 60.86401306092739, 69.35565680265427, 64.45287868380547, 76.93067193031311, 62.040593326091766, 87.6759785413742, 73.22825700044632, 110.43831512331963, 14.557661041617393, 0.45838074409402907, 0.39886851562187076, 15.288565121591091, 94.23498138785362, 69.6211789548397, 65.99260166287422, 34.02534641325474, 61.39376923441887, 59.95289035141468, 27.34505407512188, 0.7016816292889416, 0.4085004347143695, 0.29023768845945597, 0.2504535560728982, 0.21297900209901854, 0.1775773408007808, 0.08198182549676858], [0.07770721073029563, 0.07004435043199919, 0.13936856528744102, 0.042463764184503816, 0.07539223690400831, 0.17734452907461673, 0.027859195906785317, 0.2632258285302669, 2.58354430552572, 58.97765748202801, 40.13696886599064, 57.853252217173576, 49.60978835821152, 58.12585338950157, 79.90265965461731, 9.841679949313402, 0.46446273336187005, 0.7986572349909693, 0.6599336257204413, 22.797978669404984, 93.90431553125381, 74.22992125153542, 79.30319622159004, 62.071770653128624, 67.39995494484901, 73.85128676891327, 73.64680454134941, 77.58729949593544, 68.66482347249985, 66.0514073073864, 65.30124396085739, 69.07306596636772, 66.46112412214279, 71.30946636199951, 67.35047399997711, 66.8442651629448, 65.10202825069427, 63.94934490323067, 60.77659495174885, 59.5449024438858, 64.09425392746925, 64.21130284667015, 63.73268812894821, 60.92183455824852, 63.93521726131439, 58.992472887039185, 49.42956022918224, 47.858158349990845, 50.83003208041191, 46.18684843182564, 46.80269278585911, 47.85670682787895, 44.839315339922905, 41.50651417672634, 41.711919754743576, 44.19713079929352, 44.34055410325527, 44.32141453027725, 46.283591240644455, 50.467698723077774, 55.04156269133091, 55.087794810533524, 58.19171905517578, 52.46774800121784, 53.36501285433769, 53.95460821688175, 48.036068603396416, 47.17179737985134, 43.99189621210098, 46.81107893586159, 47.845322638750076, 52.38459326326847, 52.88754187524319, 47.19015419483185, 45.17335921525955, 45.40993072092533, 44.359944462776184, 41.37317173182964, 41.27185396850109, 41.72544322907925, 41.257023364305496, 43.68572384119034, 38.30986350774765, 40.5679227411747, 40.68151764571667, 37.75652199983597, 37.04954333603382, 48.74061539769173, 26.78351640701294, 40.66120393574238, 44.10869814455509, 35.00827006995678, 36.523408368229866, 41.305231377482414, 41.74660049378872, 41.653881669044495, 44.56579461693764, 45.342932716012, 48.10926407575607, 46.23264737427235, 49.31040242314339, 51.73372998833656, 53.05008575320244, 55.24040602147579, 51.885186061263084, 54.5156367123127, 52.08516173064709, 53.04297253489494, 54.38032977283001, 54.863367453217506, 49.373410642147064, 48.53851564228535, 45.14813616871834, 48.08909095823765, 54.29917752742767, 53.93723174929619, 44.93386186659336, 50.42421765625477, 51.63576364517212, 43.583805710077286, 42.37713485956192, 40.957835018634796, 40.02840869128704, 40.62075890600681, 39.90199327468872, 42.318211421370506, 45.87628349661827, 44.82803374528885, 51.377955079078674, 60.886739641427994, 56.4152991771698, 57.737673819065094, 54.77642811834812, 61.72405891120434, 62.284711226820946, 64.99866619706154, 61.93745546042919, 52.67875447869301, 54.59634818136692, 63.756588846445084, 63.14423270523548, 63.917821794748306, 64.37334895133972, 65.76517626643181, 64.68299433588982, 67.30584919452667, 63.77558022737503, 64.1959896683693, 59.253374487161636, 62.81164035201073, 58.005460649728775, 63.14873926341534, 58.92179287970066, 69.09912496805191, 61.657007709145546, 77.23081022500992, 67.92419001460075, 93.70739489793777, 16.891425512731075, 0.5470391898415983, 0.2352225038339384, 7.689477810636163, 74.6667230129242, 55.91231256723404, 48.91803927719593, 17.78901144862175, 26.06016632169485, 28.579142354428768, 7.597294757142663, 0.5027605220675468, 0.05954758438747376, 0.057358174526598305, 0.07906942279078066, 0.0194180397738819, 0.0016108820909721544, 0.044937119746464305, 0.127278920263052, 0.031208749569486827, 0.023332885466516018, 0.032984493736876175, 0.03647600911790505, 0.16356942214770243, 0.06954327458515763, 0.32353254093322903, 3.503310838714242, 71.20109617710114, 45.607102140784264, 53.288876339793205, 56.22823141515255, 66.67373791337013, 84.6754315495491, 11.393994502723217, 0.6404159136582166, 1.0093650128692389, 0.4661849612602964, 24.479128159582615, 95.70957586169243, 76.55848950147629, 81.04851856827736, 63.76802623271942, 70.26726588606834, 76.9350416958332, 77.13912114501, 77.80915439128876, 68.12620237469673, 66.32319912314415, 67.15438932180405, 70.85228249430656, 71.01178273558617, 73.12142193317413, 69.56251010298729, 67.75185406208038, 68.17204311490059, 65.38478627800941, 63.45491163432598, 65.01752838492393, 66.51844784617424, 66.76456063985825, 66.76639214158058, 65.29133409261703, 65.34445524215698, 61.49070583283901, 52.184340208768845, 50.15371397137642, 51.031174287199974, 48.98562625050545, 48.67420636117458, 49.22214075922966, 48.5379608720541, 43.99027369916439, 43.27070631086826, 46.05595305562019, 45.501680597662926, 47.35404700040817, 47.534643709659576, 53.49768653512001, 58.68507318198681, 60.39175160229206, 59.05462235212326, 53.82081359624863, 55.15209876000881, 53.52876126766205, 51.61265708506107, 51.01352423429489, 45.151495188474655, 46.70106343924999, 51.05018846690655, 53.98954354226589, 54.60358299314976, 50.93454547226429, 49.24917250871658, 47.35610269010067, 48.0556907504797, 44.505955427885056, 44.375911206007004, 45.11516533792019, 43.43618743121624, 44.86157454550266, 41.58378303050995, 43.34616266191006, 42.53526337444782, 42.89300657808781, 40.79042360186577, 48.57804112136364, 31.763567179441452, 42.48858667910099, 48.0777333676815, 38.315483406186104, 39.453377947211266, 43.36601659655571, 41.959005296230316, 42.982727363705635, 46.937482953071594, 48.67363639175892, 50.46029292047024, 46.89484544098377, 51.61665067076683, 54.61354225873947, 55.28197579085827, 57.10599571466446, 55.62947474420071, 55.087794810533524, 55.25756970047951, 55.37543557584286, 55.4741732776165, 55.76660558581352, 51.741492971777916, 49.89435128867626, 46.63816161453724, 51.21395207941532, 55.64095012843609, 55.932683274149895, 45.416527166962624, 50.79881675541401, 54.37126725912094, 46.43835313618183, 44.68069665133953, 42.86915145814419, 43.22082258760929, 42.977856025099754, 42.07779072225094, 45.182596519589424, 46.25815160572529, 47.136539071798325, 53.668593764305115, 64.07175913453102, 59.175254479050636, 59.898579865694046, 57.07618251442909, 64.40484166145325, 62.095439583063126, 68.3467349410057, 65.152048766613, 54.12708476185799, 57.04733446240425, 66.87894210219383, 64.43905502557755, 66.18344262242317, 66.58946603536606, 68.44652518630028, 66.3494785130024, 70.35415962338448, 66.08490630984306, 66.90869450569153, 62.70467609167099, 67.01837942004204, 60.9983966499567, 67.3563864827156, 59.40039619803429, 71.69217422604561, 65.11759981513023, 80.72392478585243, 68.75132203102112, 98.6254557967186, 19.38962236046791, 0.5404510558582842, 0.3916509513510391, 8.873966876417398, 83.29498842358589, 63.67140881717205, 60.35035662353039, 22.341254577040672, 32.81722404062748, 45.86952745914459, 20.28597716242075, 0.4347688111010939, 0.08363117449334823, 0.061938413127791137, 0.03473059652606025, 0.04093248717254028, 0.032907662898651324, 0.03561519202776253, 0.22411535843275487, 0.09094011198612861, 0.15602923143887892, 0.10311379039194435, 0.1909326741588302, 0.32580594706814736, 0.2288659496116452, 0.47663867531809956, 5.635549798607826, 84.86087679862976, 51.30041263997555, 71.2570671737194, 64.16980147361755, 73.75376120209694, 91.90346449613571, 13.88021819293499, 0.6422907568048686, 1.3979252753779292, 0.6280151009559631, 27.716886922717094, 100.09794518351555, 78.00409153103828, 85.14013141393661, 67.2156648337841, 71.35425835847855, 79.11332800984383, 78.46514359116554, 81.92606627941132, 69.06579315662384, 68.9089983701706, 69.39390555024147, 73.86310413479805, 72.8256306052208, 74.71589997410774, 71.95809915661812, 71.73758178949356, 71.62551060318947, 67.27566361427307, 68.02514299750328, 65.24677768349648, 69.45261240005493, 69.17894348502159, 70.22406220436096, 66.23864606022835, 68.4210741519928, 63.1208373606205, 54.23569813370705, 52.93062396347523, 53.896349743008614, 51.385569870471954, 50.38482517004013, 52.64889568090439, 50.02578243613243, 47.08420068025589, 47.08633616566658, 50.67764885723591, 48.824161514639854, 49.88140158355236, 50.44416658580303, 55.0271462649107, 62.41169661283493, 63.372858837246895, 60.50656244158745, 54.98807296156883, 54.9215043336153, 56.587965711951256, 52.4350393563509, 53.69801938533783, 49.01993840932846, 51.01649947464466, 53.34700562059879, 57.182037234306335, 56.39083229005337, 52.37928494811058, 51.23428098857403, 48.924457132816315, 50.22692084312439, 46.44032523036003, 45.9167817234993, 48.42127673327923, 46.05521969497204, 48.954171538352966, 45.33224768936634, 46.371393129229546, 45.52066817879677, 44.31431271135807, 42.480641305446625, 56.16254433989525, 44.15925443172455, 52.11347781121731, 51.85413792729378, 42.3919502645731, 40.42347729206085, 47.04469420015812, 44.008645713329315, 44.984364956617355, 50.24143226444721, 51.93425662815571, 52.87956230342388, 50.72233825922012, 53.51265013217926, 56.95130221545696, 58.31836245954037, 60.601564943790436, 56.67536482214928, 58.62293131649494, 56.191551983356476, 58.115635737776756, 59.55513149499893, 59.29685555398464, 54.852587431669235, 51.670653373003006, 48.3193776011467, 51.0455147176981, 55.81342287361622, 58.076976612210274, 46.47979371249676, 51.473576948046684, 55.95102109014988, 48.47983539104462, 45.79478546977043, 46.55745394527912, 45.51967263221741, 46.49104490876198, 45.65516956150532, 47.36834563314915, 49.11223165690899, 51.054543033242226, 55.366300866007805, 65.52981689572334, 61.57477632164955, 65.55709943175316, 59.247473403811455, 65.54929465055466, 65.0919283926487, 68.79389494657516, 63.83531302213669, 57.22154751420021, 60.46614781022072, 68.20957750082016, 65.29565826058388, 69.28947195410728, 68.53294014930725, 70.13937994837761, 68.36397841572762, 74.32245388627052, 68.53785708546638, 69.2553573846817, 67.34938725829124, 69.33885410428047, 63.66551913321018, 70.48987314105034, 62.664326056838036, 77.21589982509613, 68.93897876143456, 85.91748610138893, 72.24661767482758, 106.1260025203228, 23.00406441092491, 0.5610452976543456, 0.4549859825056046, 11.523693893104792, 92.3400990664959, 70.95851719379425, 71.07635647058487, 31.76311880350113, 40.55728331208229, 62.2281588613987, 36.01148843765259, 0.8481291553471237, 0.31467085238546133, 0.21051487885415554, 0.24053089320659637, 0.16933969454839826, 0.1403460034634918, 0.1871888805180788], [0.028858512596343644, 0.06608430980122648, 0.0125034962547943, 0.03585884282074403, 0.07021425772109069, 0.09696919354610145, 0.011253931079409085, 0.3749374294420704, 3.9714138954877853, 60.01720950007439, 46.98004826903343, 29.64890845119953, 37.68916301429272, 63.94486874341965, 79.70621019601822, 15.216646380722523, 0.28539113758597523, 0.8690533263143152, 0.4402163828490302, 20.99290642887354, 89.2501200735569, 76.00253373384476, 76.14151507616043, 65.01172229647636, 71.46275773644447, 74.39118459820747, 76.98190838098526, 72.8284652531147, 66.5763795375824, 68.62590596079826, 70.19427940249443, 69.02569010853767, 67.41029039025307, 67.92295128107071, 66.15858435630798, 66.6021041572094, 62.356082797050476, 65.40592834353447, 61.672845259308815, 56.58545404672623, 62.21931293606758, 61.83264188468456, 62.72203356027603, 61.7430654913187, 58.74181553721428, 58.909215554594994, 50.05195543169975, 48.579108864068985, 48.96487556397915, 47.4125562608242, 47.15516187250614, 45.10226123034954, 45.277173444628716, 40.90572081506252, 41.75309434533119, 41.06955282390118, 43.431312292814255, 42.430373802781105, 45.31613655388355, 47.18889646232128, 47.03099213540554, 52.19971038401127, 59.9045417457819, 52.74337001144886, 51.638632491230965, 48.094026893377304, 49.926467165350914, 45.04937566816807, 47.64885038137436, 47.91759476065636, 46.97270326316357, 47.18040391802788, 50.64708709716797, 52.230971306562424, 52.896535992622375, 51.68546497821808, 52.83306039869785, 46.66100598871708, 46.37666344642639, 42.66881100833416, 43.59229825437069, 42.26105108857155, 40.76471418142319, 41.95017457008362, 38.61597128212452, 38.96223530173302, 44.68455344438553, 52.93944329023361, 27.38620776683092, 35.127298682928085, 57.86669969558716, 38.874509409070015, 39.511226043105125, 40.011674389243126, 41.55150756239891, 39.96335618197918, 43.28177511692047, 45.793159157037735, 49.15009282529354, 51.319730803370476, 51.00313559174538, 52.87525713443756, 52.37740404903889, 52.65724003314972, 55.63188761472702, 54.576938822865486, 54.62312154471874, 55.90180993080139, 52.46094636619091, 47.42624692618847, 44.159775003790855, 42.49943509697914, 48.55187572538853, 53.969583213329315, 52.716558650135994, 56.55913285911083, 55.44703133404255, 55.114978551864624, 49.014238715171814, 44.35222327709198, 41.02619715034962, 40.68417750298977, 40.09029597043991, 39.99345816671848, 41.051131412386894, 44.059977158904076, 46.410204246640205, 45.65865397453308, 52.142261266708374, 58.76347057521343, 55.448399260640144, 55.05200453102589, 55.44005490839481, 60.46668738126755, 65.82059249281883, 61.689739152789116, 50.789260268211365, 59.68927189707756, 62.32267878949642, 60.46197183430195, 59.418882206082344, 65.01787036657333, 64.82220366597176, 67.53351017832756, 66.13599076867104, 69.7166982293129, 64.68117043375969, 68.35096031427383, 62.48989641666412, 62.77266204357147, 59.23579663038254, 60.66991187632084, 58.89557048678398, 68.2856798171997, 62.85979136824608, 81.68153420090675, 67.60927051305771, 94.77526679635048, 23.06943040341139, 0.6244958366733044, 0.05459900676214602, 7.27611081674695, 70.38066700100899, 51.8113674223423, 55.08589871227741, 31.620134375989437, 37.947283163666725, 28.97716909646988, 12.185749467462301, 0.1552793208975345, 0.09818739184993319, 0.05034710542531684, 0.04979131103027612, 0.08886868134140968, 0.03240691730752587, 0.06304502952843904, 0.05480484142026398, 0.04613661963958293, 0.10998193669365719, 0.00430181726187584, 0.07996182568604127, 0.13856253353878856, 0.15746545046567917, 0.38572635676246136, 6.263984777033329, 71.31853267550468, 50.81565745174885, 30.482376627624035, 43.946997821331024, 71.24758288264275, 85.70637702941895, 17.825234904885292, 0.5151630565524101, 1.0165168228559196, 0.5566630640532821, 23.43032743781805, 92.84386843442917, 77.29445680975914, 79.98687833547592, 67.90308594703674, 75.3169821202755, 75.56345209479332, 77.48720526695251, 74.81600940227509, 66.08949646353722, 69.0634372830391, 71.85212284326553, 70.66241428256035, 69.76876303553581, 71.17252930998802, 70.43533846735954, 68.3201439678669, 65.46215772628784, 66.72381162643433, 65.06306514143944, 62.45379835367203, 64.37488406896591, 62.042599618434906, 65.72223857045174, 64.44784015417099, 62.08142213523388, 59.7532794624567, 52.02535293996334, 50.44643506407738, 51.93944714963436, 49.717523977160454, 50.035445317626, 48.59600655734539, 46.179043650627136, 43.082361817359924, 44.86991889774799, 44.01555374264717, 44.89532433450222, 46.47012323141098, 46.999507024884224, 47.73460038006306, 49.44002106785774, 55.11362582445145, 59.66262012720108, 54.562446400523186, 51.5782917290926, 48.991215750575066, 52.69194357097149, 48.11553753912449, 47.33768127858639, 49.910234436392784, 49.43611867725849, 51.48761719465256, 52.34479799866676, 53.13068322837353, 55.63271977007389, 54.4366579502821, 56.15759700536728, 50.06148152053356, 47.555789574980736, 45.972988307476044, 44.601018726825714, 43.84682759642601, 43.62029515206814, 43.85011442005634, 39.59894813597202, 41.52084320783615, 46.536414474248886, 52.99441114068031, 33.217046186327934, 39.72049981355667, 55.234972313046455, 43.326369524002075, 43.83610837161541, 42.0572642236948, 42.10077568888664, 42.36079953610897, 45.10395213961601, 47.308833226561546, 51.46457523107529, 54.624675661325455, 53.47536653280258, 53.82820799946785, 55.41486606001854, 54.55255173146725, 59.08176809549332, 56.58872187137604, 57.424243837594986, 56.4353659003973, 52.592046931385994, 49.4120317697525, 45.5231836438179, 42.6211653649807, 49.61326517164707, 55.507345497608185, 53.88791799545288, 55.9235979616642, 58.43391805887222, 55.41266217827797, 51.795096695423126, 45.1144053786993, 44.688923209905624, 42.33624525368214, 42.2353682667017, 42.29795090854168, 44.62119944393635, 45.40223613381386, 48.37382487952709, 47.4720648676157, 55.62817521393299, 61.10156491398811, 57.763546630740166, 56.81806616485119, 56.7182607203722, 62.36834853887558, 66.61683976650238, 67.42290571331978, 51.81229077279568, 63.11032712459564, 63.087801933288574, 63.6172579228878, 62.61074513196945, 68.94558280706406, 65.51103830337524, 68.98205325007439, 69.41263854503632, 73.67550060153008, 66.44251272082329, 70.23546159267426, 66.43877372145653, 65.72191938757896, 63.069665506482124, 65.35279959440231, 61.885656639933586, 71.39450579881668, 66.44991472363472, 84.82413277029991, 69.19959917664528, 100.43874129652977, 27.420814409852028, 0.5028409708756953, 0.27096156030893326, 9.61991909891367, 81.16314321756363, 59.58145268261433, 67.03006759285927, 35.28867222368717, 47.52055786550045, 43.46210964024067, 28.256378173828125, 0.37184564222116023, 0.11022133869118989, 0.10650858908775263, 0.025904161848302465, 0.08980611775768921, 0.08821775103569962, 0.026871083791775163, 0.18093560356646776, 0.157674498623237, 0.1443089236272499, 0.14142379484837875, 0.1613845393876545, 0.35940300207585096, 0.2909500908572227, 0.5688196804840118, 8.578125201165676, 83.56092855334282, 56.442752704024315, 43.384175822138786, 54.42496597766876, 76.87342420220375, 92.03853964805603, 19.166739620268345, 0.5139629147015512, 1.2429809896275401, 0.5026230763178319, 26.16633642464876, 94.02262598276138, 81.18852585554123, 82.82052308320999, 71.41714498400688, 77.58281573653221, 79.0243747830391, 82.11267426609993, 76.57305032014847, 66.66474759578705, 72.94840961694717, 73.70162039995193, 74.29149314761162, 72.95806109905243, 75.31141921877861, 72.07592323422432, 71.45255908370018, 65.92075511813164, 69.05454576015472, 67.19949290156364, 62.88597196340561, 67.1926000714302, 66.05564787983894, 68.78042846918106, 67.65378892421722, 64.75472688674927, 64.61546435952187, 54.69322018325329, 53.35837461054325, 54.2507491260767, 52.46192291378975, 51.46683610975742, 50.59550106525421, 49.91675868630409, 45.60346953570843, 49.354632049798965, 47.261643558740616, 48.79154026508331, 48.53649415075779, 51.03622421622276, 51.47785171866417, 49.85954135656357, 55.705364271998405, 62.796486765146255, 56.80846408009529, 53.45143921673298, 52.22266495227814, 56.078006476163864, 49.63854141533375, 50.06979927420616, 52.22836084663868, 51.930909007787704, 53.45390908420086, 55.02684608101845, 57.06061854958534, 58.296099454164505, 55.349133387207985, 58.691304847598076, 51.85939684510231, 52.077888920903206, 48.853541538119316, 47.49552480876446, 47.0619984716177, 46.38426683843136, 45.72635494172573, 41.75340972840786, 43.81014436483383, 50.68537004292011, 59.67759132385254, 39.97275687754154, 46.118672490119934, 61.5644408762455, 44.94390472769737, 45.65657548606396, 43.62102851271629, 43.87279160320759, 44.69686858355999, 47.15713016688824, 48.925992250442505, 54.33996833860874, 57.252876833081245, 56.69130876660347, 55.53931698203087, 58.78894820809364, 56.64224199950695, 59.5328950881958, 57.892044335603714, 59.97728884220123, 59.47483040392399, 54.822428449988365, 51.85796432197094, 49.089254289865494, 44.90857042372227, 52.61844031512737, 58.82310837507248, 56.04561321437359, 58.59814524650574, 59.71295602619648, 58.486469238996506, 54.69172306358814, 48.24088141322136, 46.41827881336212, 45.11060558259487, 44.97549623250961, 44.659535586833954, 46.043622717261314, 47.82014138996601, 51.57576486468315, 48.39232608675957, 56.72210231423378, 63.18166829645634, 59.70385551452637, 63.20422388613224, 61.78450606763363, 66.27035915851593, 68.5498720407486, 65.08735343813896, 56.75491355359554, 66.68638363480568, 65.1750299334526, 67.67342627048492, 65.54611802101135, 68.35254102945328, 68.9624311029911, 72.17450514435768, 72.62260749936104, 74.83382284641266, 68.58953431248665, 75.36521673202515, 69.10867005586624, 70.46791791915894, 64.41874131560326, 68.3005978167057, 64.75943863391876, 75.03253698348999, 70.18659621477127, 87.14380949735641, 74.78493466973305, 106.06831401586533, 29.905679672956467, 0.751283752033487, 0.4494817106751725, 12.757712826132774, 90.10757446289062, 65.96988648176193, 77.54354864358902, 52.922518998384476, 64.47884649038315, 58.93915794789791, 41.03397913277149, 0.5715845664963126, 0.2766125398920849, 0.21362081140978262, 0.16829918866278604, 0.289831644622609, 0.3159917565062642, 0.09935260823112912], [0.11276991834165528, 0.055403268488589674, 0.16943342779995874, 0.015133940360101406, 0.023992291098693386, 0.06581729991012253, 0.04587096787872724, 0.3346718807006255, 4.391205394640565, 61.821607276797295, 52.536968886852264, 37.07793541252613, 40.568184927105904, 61.388552114367485, 77.40837469696999, 20.345512367784977, 0.8713188953697681, 0.9898622625041753, 1.1234584031626582, 17.67322216182947, 87.11140483617783, 75.34513100981712, 73.54553237557411, 62.403694242239, 67.17268154025078, 72.1441599726677, 72.73992240428925, 73.43928247690201, 71.77887037396431, 69.34020683169365, 68.63903045654297, 70.72142511606216, 67.40646779537201, 69.74872291088104, 67.98951610922813, 63.791858553886414, 62.50949576497078, 62.559493482112885, 63.99967700242996, 56.38856001198292, 62.076512798666954, 58.41811090707779, 59.37364183366299, 54.60620865225792, 57.32994809746742, 53.75606507062912, 45.29435232281685, 46.46703399717808, 47.566079422831535, 43.544967994093895, 45.876997858285904, 45.4292830824852, 45.78442722558975, 43.742899373173714, 42.07111448049545, 41.484118178486824, 39.74759615957737, 41.90996512770653, 43.556097596883774, 41.452184692025185, 44.106471464037895, 43.14309775829315, 53.81533049046993, 47.33537100255489, 48.712177723646164, 48.033777326345444, 48.81019726395607, 48.998625352978706, 50.6763531267643, 51.43893800675869, 53.69588389992714, 54.07968230545521, 54.32653985917568, 53.903561756014824, 51.63854129612446, 56.39071449637413, 57.47175268828869, 57.031249925494194, 54.86329145729542, 52.400263622403145, 53.37447814643383, 41.97295814752579, 41.758319064974785, 37.8558486700058, 38.49825359880924, 42.944653406739235, 44.59775850176811, 47.46729992330074, 30.792514085769653, 31.84426724910736, 56.53704844415188, 46.072136387228966, 39.46999065577984, 40.30130624771118, 38.817938044667244, 38.814062252640724, 37.520041689276695, 38.203579410910606, 45.13608321547508, 47.774422243237495, 51.03459790349007, 51.15029029548168, 54.604798927903175, 52.09118440747261, 50.681049674749374, 52.841689735651016, 47.79096655547619, 45.16170524060726, 43.6050009727478, 41.8578889220953, 40.10895676910877, 41.912423595786095, 44.63905468583107, 42.988936230540276, 49.18589070439339, 54.31099109351635, 54.507075771689415, 54.75328356027603, 48.54868769645691, 41.33477859199047, 40.5582370609045, 39.57295373082161, 40.78872889280319, 40.49620158970356, 40.92013344168663, 46.922846138477325, 47.12651140987873, 46.80827088654041, 49.671383053064346, 59.854802414774895, 57.5733782351017, 51.94859325885773, 56.002949103713036, 59.94084119796753, 64.99507158994675, 50.17546780407429, 57.16483935713768, 64.82895970344543, 56.86353452503681, 64.72942784428596, 58.79956103861332, 63.74860927462578, 60.8688236027956, 67.68474206328392, 65.47273635864258, 68.73185187578201, 66.16037786006927, 69.01538506150246, 64.28238943219185, 67.5280536711216, 60.3132364153862, 65.59338748455048, 61.59744970500469, 71.58039182424545, 63.921241611242294, 82.12767586112022, 67.57072538137436, 96.61254420876503, 24.284865483641624, 0.3768289857544005, 0.1582224410958588, 6.2006578501313925, 67.65144065022469, 55.96274346113205, 51.22283600270748, 29.68801785260439, 35.168750658631325, 32.00444385409355, 12.544742804020643, 0.4652706650085747, 0.17911259201355278, 0.06123208520875778, 0.11063427707995288, 0.08557282577385195, 0.04226965545967687, 0.030622786871390417, 0.12168631059466861, 0.06474013935076073, 0.16775534284533933, 0.09951653380994685, 0.11499403102789074, 0.09445403280551545, 0.22093050589319319, 0.4427615040913224, 6.573322853073478, 72.84620270133018, 56.08866490423679, 40.777652487158775, 46.180920749902725, 68.8030980527401, 84.47886049747467, 21.82671468704939, 0.9526406473014504, 1.0390370269306004, 1.4092961652204394, 19.29635066539049, 90.39821326732635, 76.61933183670044, 76.98196917772293, 65.94172239303589, 70.4018546640873, 73.56844514608383, 72.36321821808815, 73.8932441174984, 75.14188751578331, 71.48022159934044, 71.67699784040451, 72.21771642565727, 71.86290666460991, 72.1443347632885, 71.28859028220177, 66.74497649073601, 66.17870047688484, 65.1310282945633, 67.63699382543564, 61.64488635957241, 63.67390528321266, 61.810812056064606, 60.90087488293648, 57.89984151721001, 58.379064202308655, 55.24930514395237, 49.61786292493343, 49.173309579491615, 49.59156833589077, 47.90135443210602, 48.62728647887707, 51.045795902609825, 46.80751092731953, 45.14769159257412, 44.45949912071228, 44.36836861073971, 43.7011244148016, 45.734608098864555, 46.00826181471348, 43.521120473742485, 47.239106968045235, 46.18951968848705, 53.717892318964005, 50.27420170605183, 50.052916780114174, 49.95048567652702, 51.05813004076481, 51.66336916387081, 52.173647582530975, 54.22038495540619, 53.73194016516209, 56.375686302781105, 57.40484207868576, 57.60211229324341, 54.75769132375717, 59.358993619680405, 58.86829175055027, 59.63457003235817, 56.77446350455284, 55.460516810417175, 52.131576240062714, 44.44211505353451, 43.871176689863205, 40.42611815035343, 40.53074553608894, 45.29032453894615, 47.94394634664059, 50.7447874546051, 37.569366842508316, 40.947716161608696, 55.38262479007244, 48.54337178170681, 42.64765374362469, 42.092134952545166, 41.494392827153206, 41.00416213274002, 39.14884328842163, 39.38884600996971, 46.74378074705601, 49.71504271030426, 53.29100042581558, 53.536262065172195, 55.13061851263046, 52.88933917880058, 52.90899932384491, 52.74956747889519, 49.160945042967796, 48.106976598501205, 45.69636695086956, 43.61065126955509, 42.88295231759548, 43.698798939585686, 46.6966138780117, 45.24151995778084, 49.73871164023876, 54.5602273195982, 56.75080217421055, 54.62641216814518, 50.84598362445831, 43.24369356036186, 43.90053391456604, 42.58121430873871, 43.09465415775776, 42.488848865032196, 42.77421735227108, 47.39582575857639, 48.46425622701645, 49.25391465425491, 52.3120703548193, 60.60500755906105, 59.64402012526989, 55.69179520010948, 60.482342541217804, 62.068426832556725, 67.56461530923843, 52.87740021944046, 58.58895733952522, 65.7564215362072, 59.48070868849754, 67.73056000471115, 61.62099704146385, 66.67128324508667, 64.45765122771263, 70.32135218381882, 65.5457304418087, 71.19923427700996, 69.17841151356697, 72.81776502728462, 66.59549251198769, 71.75806269049644, 62.99819894134998, 68.30118298530579, 64.28717717528343, 76.11256062984467, 67.95197412371635, 84.47385236620903, 71.35008618235588, 98.01993548870087, 26.07464164495468, 0.31803129706531763, 0.22193072800291702, 9.270510748028755, 76.1683340370655, 64.60867032408714, 60.12641564011574, 38.61189030110836, 50.017107501626015, 50.59491589665413, 20.252299569547176, 0.776547824498266, 0.21909168659476563, 0.091546572803054, 0.11235191108426079, 0.06509205093607306, 0.05473957324284129, 0.032142530908458866, 0.22806934313848615, 0.168602934863884, 0.38880327134393156, 0.20135285798460245, 0.2313207514816895, 0.16756336408434436, 0.3977023938205093, 0.5657594196964055, 9.378080125898123, 84.48597371578217, 63.91472116112709, 49.371301755309105, 53.562750443816185, 76.93168267607689, 89.24479275941849, 25.516424998641014, 1.095595092047006, 1.2958241603337228, 1.310185727197677, 21.88950251787901, 93.45160022377968, 80.74236899614334, 79.36008676886559, 67.83164218068123, 73.32458943128586, 76.62368640303612, 76.28419741988182, 76.64747312664986, 77.16049879789352, 73.36957141757011, 72.81067460775375, 75.28468385338783, 72.80717119574547, 75.96658006310463, 73.87519508600235, 69.69223514199257, 67.58237555623055, 66.77833870053291, 68.52936834096909, 61.88586562871933, 67.49074727296829, 64.44842532277107, 65.15953436493874, 59.67349894344807, 61.78232878446579, 59.02397319674492, 51.30967654287815, 52.14615985751152, 54.17315348982811, 48.43470521271229, 52.34811522066593, 52.23946385085583, 49.46062356233597, 50.99314972758293, 48.46633851528168, 46.621351316571236, 44.06174026429653, 48.16278800368309, 47.75567784905434, 46.61492586135864, 49.16424326598644, 48.3260652422905, 57.411552518606186, 52.8475072234869, 54.01820160448551, 51.3097183406353, 55.4348149895668, 53.71842809021473, 56.77990861237049, 58.52821759879589, 57.95138195157051, 60.87809130549431, 60.62550365924835, 61.27733588218689, 57.037622183561325, 60.32333627343178, 61.59568279981613, 62.341058403253555, 59.104996249079704, 57.169182524085045, 56.79408185184002, 48.4698761254549, 46.0543305426836, 41.85235261917114, 42.248348370194435, 48.806762248277664, 49.15218271315098, 54.21835206449032, 41.50711074471474, 45.723227709531784, 59.566633477807045, 49.33980904519558, 42.231549471616745, 42.37056881189346, 43.12021538615227, 42.14729659259319, 41.00083731114864, 40.65717235207558, 49.5909071713686, 51.38485550880432, 55.1492565125227, 55.64568467438221, 57.915857657790184, 57.198003977537155, 56.28441520035267, 56.661658957600594, 55.600668489933014, 50.476001277565956, 47.92853057384491, 46.29347451031208, 43.59525069594383, 44.17232193052769, 49.499423280358315, 45.518889874219894, 51.19659461081028, 58.37723650038242, 60.64265213906765, 56.605809554457664, 52.806537821888924, 46.68050654232502, 47.36779846251011, 43.73910337686539, 45.353423953056335, 44.16699841618538, 46.197693049907684, 50.59990502893925, 50.89785844087601, 52.45841570198536, 53.288044184446335, 62.60457046329975, 61.253245174884796, 59.325559213757515, 63.116615787148476, 66.9923584163189, 65.93605309724808, 53.933910727500916, 62.41160921752453, 68.11732605099678, 61.86473876237869, 68.54202926158905, 63.76911297440529, 69.67972621321678, 65.80681443214417, 73.44369783997536, 68.90035763382912, 71.80049121379852, 72.06482023000717, 74.85167428851128, 71.14470720291138, 74.33548718690872, 66.39069110155106, 71.42212271690369, 68.22160765528679, 80.13245612382889, 70.95713406801224, 89.34493258595467, 74.07998129725456, 103.75877514481544, 30.041260197758675, 0.41056595044210553, 0.718771805986762, 13.009152933955193, 86.00040525197983, 73.36462408304214, 71.54740199446678, 49.80965383350849, 55.5921645462513, 60.4049900919199, 38.701497092843056, 0.6817462958861142, 0.31787256652023643, 0.2555392566137016, 0.32792552083265036, 0.21718827076256275, 0.15240087144775316, 0.13173452258342877], [0.08421034654020332, 0.06929791314178146, 0.06378306570695713, 0.08582370879594237, 0.015418511320604011, 0.08992218965431675, 0.0641199413803406, 0.24150810873834416, 4.678479479625821, 58.82499307394028, 48.70169788599014, 31.42284896224737, 37.76979848742485, 61.628657430410385, 77.81201183795929, 25.779762268066406, 0.41459720756392926, 0.8287268620915711, 0.7851619028951973, 13.515343721956015, 87.74891942739487, 72.67855569720268, 71.62884682416916, 64.531891644001, 66.50698006153107, 72.40424081683159, 70.52770391106606, 73.73164638876915, 69.81442898511887, 73.31651106476784, 69.17212665081024, 70.32678589224815, 67.54892215132713, 65.77102795243263, 64.67684626579285, 68.52790161967278, 61.44666999578476, 64.92640927433968, 62.99713119864464, 55.58516912162304, 62.16139644384384, 58.62376727163792, 54.60638724267483, 51.01114176213741, 50.03661945462227, 46.44454300403595, 47.46043749153614, 46.40253625810146, 43.82373623549938, 45.465989112854004, 45.279350727796555, 46.48480944335461, 46.116126626729965, 41.712881103158, 40.348978489637375, 41.31338194012642, 41.41619682312012, 43.747892305254936, 39.05824474990368, 42.13541842997074, 41.661154478788376, 45.01430355012417, 46.225940734148026, 47.376636788249016, 47.87670895457268, 48.37485082447529, 47.8571742027998, 50.05643539130688, 55.53926758468151, 51.72792010009289, 50.63156872987747, 52.28778585791588, 51.442502215504646, 51.58342905342579, 52.515625432133675, 55.35649739205837, 53.52933883666992, 53.65655601024628, 55.415067449212074, 56.73937998712063, 53.011270835995674, 51.29156291484833, 43.21782074868679, 41.356099247932434, 42.7141197770834, 42.8914562612772, 41.38781614601612, 41.21985375881195, 34.10533592104912, 33.999522998929024, 47.54317805171013, 48.04402157664299, 42.338285744190216, 39.66388665139675, 42.7897547185421, 38.9607647806406, 41.44271560013294, 45.169194638729095, 51.177458837628365, 49.97776821255684, 51.310288310050964, 53.06227169930935, 55.1288478076458, 51.88336595892906, 51.62215657532215, 50.641793981194496, 48.23713481426239, 49.60904359817505, 46.67927920818329, 45.19375652074814, 44.93141479790211, 46.13241255283356, 44.33687210083008, 44.84107844531536, 47.77992434799671, 49.20534186065197, 53.65149848163128, 43.604624792933464, 39.34602990746498, 38.41357134282589, 38.969770297408104, 39.47013504803181, 37.407328337430954, 40.32216712832451, 40.87942622601986, 47.40461848676205, 46.19337648153305, 46.85210533440113, 51.48410238325596, 62.35754571855068, 56.123216450214386, 57.544484585523605, 53.260450065135956, 63.21696080267429, 55.841058790683746, 49.63338129222393, 61.01360723376274, 57.47714079916477, 59.90114852786064, 54.53881926834583, 55.627149268984795, 60.48335328698158, 61.32293723523617, 66.56697124242783, 65.83028957247734, 66.41709208488464, 65.0246188044548, 71.14330127835274, 65.51033154129982, 68.08635771274567, 63.08580324053764, 66.39294818043709, 61.103726997971535, 68.17784160375595, 64.66058313846588, 78.80943551659584, 67.8958511352539, 95.30029222369194, 22.84605748951435, 0.4603743308689445, 0.25378336489666253, 5.122339837253094, 65.97966715693474, 54.502838999032974, 56.89072586596012, 21.75748810172081, 19.334536716341972, 35.46698145568371, 13.171429876238108, 0.4467882786411792, 0.09993554296670482, 0.09288482833653688, 0.08923709086957388, 0.042385705091874115, 0.022052667736716103, 0.057899990570149384, 0.08786481528659351, 0.05549854540731758, 0.032014332318794914, 0.10257675749016926, 0.0919758235977497, 0.10480521916178986, 0.124747424852103, 0.3741867025382817, 7.277998365461826, 68.04446116089821, 55.63998878002167, 37.55491241812706, 44.76943328976631, 69.30533230304718, 84.40601840615273, 28.706959895789623, 0.45997345237992704, 0.9892273996956646, 0.95502098207362, 13.803503159433603, 92.41823047399521, 76.55732676386833, 75.609650015831, 66.81764379143715, 69.50099900364876, 74.29170593619347, 73.77369493246078, 75.61135232448578, 72.27915152907372, 73.8854469358921, 71.38353198766708, 70.82308486104012, 70.03169372677803, 69.28188756108284, 66.55360355973244, 70.17920941114426, 63.90690118074417, 65.01626685261726, 65.68037241697311, 59.53789561986923, 64.63466852903366, 61.73054896295071, 57.202438339591026, 52.90380120277405, 52.59747304022312, 49.613808542490005, 49.06397044658661, 48.744943365454674, 47.889449670910835, 48.206945434212685, 48.78919579088688, 50.39839044213295, 46.76175378262997, 44.46368269622326, 43.356965482234955, 42.494909539818764, 44.14985753595829, 46.93131968379021, 43.18393796682358, 45.66893242299557, 45.777792781591415, 47.18580722808838, 49.94968771934509, 48.31672914326191, 51.37115724384785, 52.13903523981571, 52.06240855157375, 52.39065393805504, 55.34953996539116, 55.823325142264366, 52.64940865337849, 55.21359845995903, 54.716987907886505, 54.45931613445282, 54.714381247758865, 56.08273342251778, 57.89118938148022, 57.91626803576946, 57.07992911338806, 59.032708927989006, 56.39270938932896, 51.55563734471798, 43.78852352499962, 43.17069187760353, 43.37207727134228, 45.60941241681576, 46.560869961977005, 44.536843970417976, 36.94073237478733, 39.16970796883106, 49.810436591506004, 47.60691203176975, 42.85453364253044, 39.23360154032707, 43.32589074969292, 40.37073232233524, 41.91267438232899, 48.695097640156746, 53.34133252501488, 53.10356788337231, 53.98777283728123, 55.55967628955841, 57.49167501926422, 53.201040253043175, 54.3401051312685, 51.9128105789423, 51.58984310925007, 51.90709948539734, 49.032736122608185, 49.258709996938705, 48.527443036437035, 48.247325867414474, 46.24115891754627, 46.80012792348862, 49.43874813616276, 49.792421758174896, 53.06971549987793, 46.44234672188759, 41.29090994596481, 41.40744969248772, 40.598199516534805, 42.15271510183811, 40.869527757167816, 43.913331627845764, 43.72764699161053, 48.22990380227566, 47.513186261057854, 47.61200375854969, 54.11851242184639, 62.69226215779781, 57.15630881488323, 60.15789695084095, 56.11660860478878, 65.3131677210331, 58.069544211030006, 54.37413990497589, 62.93571889400482, 60.21438851952553, 63.339933604002, 57.06857532262802, 59.521906077861786, 62.4922788888216, 62.779448479413986, 65.95369175076485, 68.71156096458435, 68.9468215405941, 67.66750618815422, 73.96818369626999, 70.23922339081764, 72.17467233538628, 66.87446594238281, 71.55893057584763, 62.83063933253288, 71.17138937115669, 67.04702988266945, 81.41155868768692, 71.29212409257889, 96.71709179878235, 26.60461250692606, 0.6601063383277506, 0.5398700432851911, 7.0320347137749195, 76.14220663905144, 62.08978548645973, 66.8843986093998, 30.138111300766468, 29.50672958046198, 49.959901571273804, 28.21061722934246, 0.5353359365835786, 0.028978334194107447, 0.08371708550839685, 0.015479540907108458, 0.03279041840869468, 0.08779345036600716, 0.03659191032056697, 0.1333295612130314, 0.12237160233780742, 0.18408949370495975, 0.22862104087835178, 0.16640542075037956, 0.18431820877594873, 0.2763630298431963, 0.4994897881988436, 9.518265053629875, 79.63513121008873, 60.577827617526054, 44.650609865784645, 54.05544340610504, 77.43305817246437, 89.41500842571259, 31.469759345054626, 0.6016883917618543, 1.257878802716732, 1.246402112301439, 18.39652094990015, 95.50689473748207, 78.42528373003006, 77.32170894742012, 69.70258578658104, 71.63469851016998, 78.6321522295475, 75.59477761387825, 79.49062496423721, 73.94026279449463, 77.04198315739632, 73.04348051548004, 74.24258977174759, 71.0350450873375, 71.98214426636696, 68.6883670091629, 75.1522533595562, 67.0574489235878, 67.59295418858528, 65.91244116425514, 63.85612070560455, 68.65864500403404, 65.43029263615608, 60.65609961748123, 54.86659348011017, 54.56551283597946, 52.28487141430378, 51.2699268758297, 51.85194544494152, 47.83722527325153, 51.20765961706638, 51.068400889635086, 52.56059221923351, 50.32928355038166, 47.86640390753746, 45.87818339467049, 45.012114867568016, 47.840561494231224, 49.63590055704117, 44.9599664658308, 48.45090754330158, 47.08851344883442, 51.94398410618305, 53.011992797255516, 51.35675981640816, 53.649446591734886, 54.531687051057816, 56.07000790536404, 55.54928004741669, 60.60666427016258, 57.652224004268646, 56.64934001863003, 59.81428898870945, 57.76456497609615, 57.39383026957512, 60.09678862988949, 59.98268075287342, 62.705367654562, 59.52867731451988, 60.02655699849129, 60.567176789045334, 59.64998960494995, 54.30567517876625, 45.461573749780655, 43.3470556139946, 47.73415580391884, 47.034769132733345, 50.25044158101082, 48.13497729599476, 39.65879872441292, 43.01149182021618, 54.059520587325096, 51.64983429014683, 44.096911177039146, 40.01914098858833, 43.86737309396267, 40.012848526239395, 42.838939279317856, 49.64231841266155, 55.54229222238064, 52.88225255906582, 55.98028711974621, 61.32914610207081, 60.247845724225044, 57.83023305237293, 59.02915231883526, 56.36497087776661, 54.48086857795715, 54.60047475993633, 51.51824735105038, 50.75965605676174, 49.76786747574806, 52.09256373345852, 48.32073412835598, 47.57787398993969, 51.62144981324673, 52.523411214351654, 57.5332485884428, 48.239471688866615, 43.032265305519104, 43.14829207956791, 44.2123793810606, 46.05719178915024, 42.80059173703194, 45.66522382199764, 45.76550804078579, 51.041217148303986, 51.08082242310047, 50.95932014286518, 56.70011669397354, 67.19364121556282, 60.10721907019615, 65.22617518901825, 59.39338557422161, 65.91288954019547, 58.13781134784222, 56.77826330065727, 64.71862122416496, 61.1267651617527, 66.04380011558533, 60.77000230550766, 61.40643395483494, 66.1705993115902, 66.51782467961311, 70.94743698835373, 70.85324004292488, 70.26053264737129, 70.70830821990967, 77.0596294105053, 72.62038081884384, 75.7857857644558, 68.09492245316505, 73.33698436617851, 67.06889390945435, 76.03234693408012, 69.86403912305832, 84.70545753836632, 75.22382631897926, 100.96898004412651, 28.871553763747215, 0.762239039177075, 0.8492565667256713, 9.554431512951851, 86.09861478209496, 69.41572397947311, 78.4832002222538, 39.18016880750656, 33.76022703945637, 64.29931372404099, 40.08868485689163, 0.8571755792945623, 0.16680732340319082, 0.0962436996633187, 0.18712422461248934, 0.19053271593293175, 0.20069961959961802, 0.22402575152227655], [0.022819879595772363, 0.0724961243395228, 0.04797766167030204, 0.014184941283019725, 0.013803729707433376, 0.10806482081534341, 0.04274274491763208, 0.3386171971214935, 4.643803965300322, 58.69035489857197, 53.99298615753651, 40.73499217629433, 43.92409265041351, 54.51176092028618, 75.94208657741547, 35.7720784842968, 0.21392409747932106, 0.5720717122312635, 1.3033932354301214, 7.540447432547808, 84.73447278141975, 74.99611213803291, 73.72096136212349, 68.7163183093071, 64.80722486972809, 65.70627942681313, 67.47171029448509, 69.28320229053497, 72.93654665350914, 68.5658311843872, 70.52104666829109, 67.46471107006073, 64.52156379818916, 68.09971019625664, 66.49814933538437, 65.56715369224548, 58.896216452121735, 63.25750842690468, 58.84993113577366, 54.403128549456596, 57.161902114748955, 51.1226923763752, 51.511582508683205, 49.28695388138294, 47.65147604048252, 45.70192985236645, 45.410637483000755, 45.082422494888306, 45.92174045741558, 44.72702756524086, 44.21884283423424, 43.771344646811485, 43.12234707176685, 43.47544312477112, 41.0478749871254, 40.776759535074234, 42.28220455348492, 43.23510602116585, 40.42618274688721, 41.46449223160744, 42.51281417906284, 42.93968707323074, 47.449319288134575, 46.51041626930237, 48.08809541165829, 51.03481449186802, 50.219275653362274, 50.526971742510796, 52.04396054148674, 50.6855334341526, 51.847644075751305, 51.577011197805405, 52.98606298863888, 52.00886942446232, 51.98912188410759, 54.4827114790678, 53.593243807554245, 54.3217559158802, 56.6272784024477, 57.67273910343647, 54.957032427191734, 55.543078780174255, 47.50658221542835, 39.62654605507851, 43.00637349486351, 39.56006862223148, 36.32372908294201, 37.87078186869621, 39.17980022728443, 37.54235789179802, 37.840014919638634, 40.75766935944557, 42.98924781382084, 39.74459432065487, 42.105339244008064, 41.25484228134155, 50.57787761092186, 53.79452280700207, 55.00280477106571, 53.69610048830509, 55.15966035425663, 56.37683004140854, 54.40956920385361, 51.37375250458717, 52.68347382545471, 51.03885367512703, 48.89578387141228, 47.677375450730324, 49.62070897221565, 47.258102148771286, 47.67072580754757, 47.919737845659256, 46.68925367295742, 44.868334382772446, 45.04787474870682, 46.350657641887665, 42.179275676608086, 38.31211678683758, 38.00939463078976, 37.74835243821144, 38.17471995949745, 39.93939846754074, 38.37263233959675, 40.53058214485645, 41.70622006058693, 44.987203404307365, 44.84600678086281, 47.83451981842518, 51.88670977950096, 61.31382152438164, 58.42142052948475, 55.634387880563736, 53.96274358034134, 60.33387690782547, 47.261206582188606, 55.95358595252037, 60.230936631560326, 58.76033194363117, 57.56696417927742, 54.182736575603485, 54.81070227921009, 55.63367731869221, 58.48387397825718, 61.634737104177475, 63.17738592624664, 66.01793110370636, 64.32930931448936, 68.09867665171623, 66.5763795375824, 70.95687568187714, 68.88850226998329, 72.55178689956665, 66.0496138036251, 71.00275442004204, 64.5554731786251, 74.71943378448486, 68.33665028214455, 105.15007048845291, 21.571583077311516, 0.18876768095651641, 0.17188313853694126, 5.734551111236215, 70.50677463412285, 54.38866272568703, 56.47423781454563, 24.390218630433083, 34.96716007590294, 27.97256950289011, 30.082894563674927, 2.6357147935777903, 0.02529092707845848, 0.16452775744255632, 0.035892265441361815, 0.029792718814860564, 0.082937919505639, 0.014700709798489697, 0.06827348217484541, 0.049586533932597376, 0.015418862913065823, 0.06435772549593821, 0.06318569619907066, 0.15158329188125208, 0.1047234567522537, 0.5464745638892055, 7.529889699071646, 68.17943751811981, 54.39957953989506, 51.711497381329536, 52.676778584718704, 61.34137764573097, 83.87748956680298, 39.7815777361393, 0.21024932357249781, 0.8284517331048846, 1.2263125902973115, 7.802690835669637, 89.36137050390244, 76.78524613380432, 77.92087599635124, 71.05819344520569, 67.64267072081566, 67.57746621966362, 69.54355672001839, 70.5273999273777, 73.16891938447952, 70.63955470919609, 72.54434689879417, 69.628976136446, 66.41510859131813, 67.46153444051743, 67.7552130818367, 67.25598067045212, 61.844341456890106, 65.72950378060341, 62.73277558386326, 56.88784182071686, 59.46782357990742, 54.85891409218311, 53.926843106746674, 51.594573855400085, 50.17332471907139, 48.53640295565128, 47.172211557626724, 47.364621832966805, 47.565984427928925, 47.87627577781677, 46.95105202496052, 48.90064761042595, 47.06770956516266, 45.17433576285839, 44.484148398041725, 42.26239241659641, 44.150032326579094, 47.52732530236244, 42.95993618667126, 44.09717336297035, 45.001566633582115, 46.06655068695545, 49.21269066631794, 48.985402062535286, 48.20705182850361, 56.00115180015564, 51.0153329372406, 53.23812246322632, 54.596728160977364, 53.90209503471851, 54.55739267170429, 54.78180103003979, 57.95941852033138, 54.621107652783394, 55.40048383176327, 55.91566018760204, 58.67765597999096, 56.30646541714668, 58.2842630892992, 60.0881364941597, 57.082281187176704, 59.14913468062878, 48.586716055870056, 39.84952189028263, 44.094087928533554, 41.36527195572853, 39.08753737807274, 42.13694594800472, 42.52044036984444, 39.43833075463772, 41.357223987579346, 43.07365648448467, 42.839855030179024, 40.17532400786877, 42.41877302527428, 41.59539520740509, 51.40355430543423, 56.69646129012108, 58.45083475112915, 56.01877525448799, 56.85069501399994, 56.72369822859764, 56.39340855181217, 52.79873304069042, 54.66300420463085, 54.046912863850594, 51.93658210337162, 51.23377561569214, 51.47334896028042, 49.666040539741516, 51.244149059057236, 49.380090683698654, 49.69016544520855, 46.686909198760986, 46.726670265197754, 48.41477528214455, 42.89595901966095, 41.93535156548023, 40.57967931032181, 41.98745056986809, 42.3790917545557, 42.776922807097435, 40.645894557237625, 43.80946420133114, 45.611338913440704, 48.70056554675102, 45.46983830630779, 48.12615416944027, 53.00714425742626, 63.696658462285995, 60.75270563364029, 57.82492853701115, 56.718085929751396, 59.01376694440842, 50.005453526973724, 57.25604586303234, 63.50696504116058, 61.16268843412399, 60.64556658267975, 59.0616861730814, 57.38966189324856, 58.721608221530914, 60.03470376133919, 65.06557300686836, 66.0843363404274, 69.23189744353294, 66.12208351492882, 70.25059998035431, 69.97963652014732, 73.7956653535366, 71.07084676623344, 75.55317744612694, 68.66282477974892, 75.3927044570446, 67.63350561261177, 78.8111986219883, 68.62015306949615, 103.76910299062729, 23.670284561812878, 0.15481688868021592, 0.48108413990121335, 6.63754653185606, 80.32032564282417, 60.997507497668266, 69.30549949407578, 28.163680247962475, 39.951219633221626, 41.456497460603714, 48.27626891434193, 4.351140344515443, 0.043500618703546934, 0.17207314318511635, 0.0600514098914573, 0.028778197374776937, 0.026573380528134294, 0.050189031680929475, 0.2093390646041371, 0.1421219331678003, 0.16894542117370293, 0.18222536717075855, 0.15993258683010936, 0.20254547445802018, 0.3507836989592761, 0.7441480318084359, 9.781035203486681, 82.69307792186737, 64.44537028670311, 54.82506550848484, 61.12790510058403, 73.33708316087723, 90.02084031701088, 43.96340914070606, 0.3025528573198244, 1.0806288826279342, 1.6512988856993616, 9.982448145747185, 93.74455690383911, 78.56594458222389, 80.36406129598618, 74.76617127656937, 70.30337914824486, 70.65419912338257, 74.13276806473732, 72.96531870961189, 78.28947141766548, 72.54633039236069, 76.7505843937397, 71.9117796421051, 69.29404690861702, 70.29610633850098, 71.23092457652092, 70.19196152687073, 62.39531189203262, 65.1444111764431, 65.07998943328857, 60.20500302314758, 62.032925337553024, 56.021351516246796, 58.48155990242958, 55.07056653499603, 53.63417141139507, 50.8383422344923, 48.75954978168011, 50.86028605699539, 49.856064543128014, 50.66774658858776, 48.90496037900448, 50.47168470919132, 48.98956283926964, 47.40698575973511, 46.561375334858894, 46.62184529006481, 47.55153380334377, 50.13899736106396, 44.82613764703274, 47.51227430999279, 49.9969419836998, 47.54097796976566, 53.37468333542347, 51.699756011366844, 52.38105185329914, 58.62940616905689, 54.02526542544365, 56.40788957476616, 60.287188813090324, 57.34202764928341, 57.695860862731934, 59.056271463632584, 59.8744435608387, 57.812681794166565, 58.77320185303688, 60.02617321908474, 61.96783483028412, 59.32573780417442, 61.45200490951538, 66.17028772830963, 58.69216360151768, 61.795350685715675, 50.93252398073673, 40.53517609834671, 46.784932538867, 43.00047241151333, 41.54624104499817, 45.16397371888161, 44.517677798867226, 42.46124714612961, 44.91918325424194, 44.76836554706097, 44.61462579667568, 40.36675773561001, 43.5424829274416, 44.60657022893429, 53.430589735507965, 59.161909595131874, 60.951997339725494, 58.44546563923359, 60.98998390138149, 62.57903203368187, 59.28388684988022, 57.5770678371191, 58.11357244849205, 58.21425944566727, 56.2967911362648, 54.79479253292084, 55.27914114296436, 53.850189819931984, 54.32207889854908, 52.132727578282356, 51.41713097691536, 50.564555525779724, 49.123076274991035, 50.67959055304527, 45.912662744522095, 46.11491449177265, 44.76816035807133, 44.38584387302399, 44.88718897104263, 45.90320885181427, 41.70804016292095, 46.56050518155098, 46.676102578639984, 49.963564574718475, 48.51030595600605, 53.02417494356632, 56.37783698737621, 67.8252737224102, 64.57231387495995, 62.987540513277054, 58.584576174616814, 62.34575875103474, 54.67614769935608, 59.81213070452213, 65.09552299976349, 64.11697670817375, 63.15449595451355, 60.009970888495445, 60.43647140264511, 62.11919590830803, 63.12608867883682, 69.67941462993622, 67.43915364146233, 72.44571939110756, 68.0058704316616, 71.70595988631248, 72.30655565857887, 78.45133513212204, 74.98189330101013, 79.14474472403526, 72.41989597678185, 78.81252095103264, 71.75950661301613, 83.88332605361938, 72.13106587529182, 104.40957382321358, 27.76930321007967, 0.4963651386788115, 1.098923475947231, 9.577424079179764, 89.97924014925957, 68.28867405653, 76.54307752847672, 41.878689005970955, 55.32084010541439, 52.81419821083546, 67.67834320664406, 5.492191091179848, 0.14733139425516129, 0.3025550243910402, 0.1387680193874985, 0.10779122065287083, 0.1680752678657882, 0.1241710878093727], [0.03347594763909001, 0.025169090549752582, 0.005295074779496645, 0.026710449637903366, 0.02573974274127977, 0.10752351314295083, 0.04189116014458705, 0.3686437796568498, 4.801209568977356, 57.64646731317043, 42.373753041028976, 40.79844877123833, 45.02768263220787, 53.32666151225567, 78.16761955618858, 40.868437215685844, 0.029704332737310324, 0.15451354323886335, 0.2841244399314746, 3.3399376552551985, 72.91605055332184, 74.75082769989967, 73.78989726305008, 69.3269531428814, 66.53975710272789, 66.0114486515522, 63.867535293102264, 66.92339211702347, 68.20902273058891, 71.42903074622154, 69.69382345676422, 65.01546129584312, 62.84263528883457, 66.44339427351952, 68.69670376181602, 66.94072678685188, 62.97776743769646, 60.85848815739155, 52.4119707942009, 58.40583376586437, 55.53998574614525, 52.371776551008224, 48.28420668840408, 46.457340717315674, 45.81725746393204, 46.16350628435612, 44.90247555077076, 46.458009481430054, 44.57601606845856, 47.95663766562939, 45.836754217743874, 45.51828570663929, 45.98073609173298, 43.93075369298458, 40.98626509308815, 40.593749955296516, 41.38761095702648, 43.78856152296066, 41.30818381905556, 41.693498343229294, 41.28018692135811, 43.94861273467541, 45.6403199583292, 47.62237720191479, 48.411009684205055, 49.14872869849205, 48.81463922560215, 48.179864287376404, 49.72784802317619, 50.45684650540352, 50.578268989920616, 50.86923457682133, 48.4071908891201, 51.24442644417286, 53.53565409779549, 52.0121980458498, 52.80924707651138, 54.09183405339718, 53.32595854997635, 54.42290648818016, 53.23384389281273, 56.35135240852833, 53.79671148955822, 41.435583382844925, 42.65222109854221, 40.52911162376404, 36.0318249464035, 39.760960042476654, 44.929526299238205, 42.53074921667576, 35.83812654018402, 35.617935955524445, 39.706584960222244, 40.92733785510063, 38.6391082406044, 43.831636011600494, 54.03178207576275, 53.917085230350494, 55.64469672739506, 50.39669193327427, 51.19063653051853, 51.81333191692829, 53.53047497570515, 52.281292006373405, 50.254169180989265, 46.44672408699989, 47.59962402284145, 45.48419773578644, 46.36277139186859, 46.93689778447151, 48.43734227120876, 45.950136333703995, 48.24112839996815, 44.148292019963264, 42.77232885360718, 44.708758145570755, 41.90349027514458, 38.14580351114273, 37.488313391804695, 39.285442158579826, 39.495369493961334, 39.42048691213131, 40.77095724642277, 40.620150938630104, 42.989570796489716, 44.5004191249609, 46.256263107061386, 45.47975197434425, 50.71776710450649, 56.7500764131546, 58.88727933168411, 58.88629138469696, 56.25952273607254, 55.2501031011343, 44.44004036486149, 58.494684398174286, 59.652026295661926, 60.06354421377182, 58.37128981947899, 57.927777618169785, 55.110665783286095, 56.46041415631771, 54.06825631856918, 58.692642375826836, 60.52018851041794, 64.2939256131649, 66.06145396828651, 68.79114389419556, 67.29123517870903, 70.95543175935745, 68.32348018884659, 72.77608886361122, 68.67380619049072, 77.38884374499321, 69.0796548128128, 73.16486120223999, 77.39167839288712, 110.95701768994331, 14.197956193238497, 0.20322188269346952, 0.48451461363583803, 7.867963733151555, 72.92437970638275, 54.18562442064285, 56.419874131679535, 28.966206684708595, 33.53951968252659, 33.38478438556194, 30.27841117233038, 6.0110703483223915, 0.1715324737597257, 0.14120214502327144, 0.006672794479527511, 0.042970235444954596, 0.04317797742260154, 0.0665113638387993, 0.0948946236167103, 0.062366743659367785, 0.05608651561487932, 0.024151116267603356, 0.0643889328057412, 0.06049735900887754, 0.03097025484748883, 0.5204953579232097, 6.8574701808393, 67.73696646094322, 47.58526839315891, 47.14700371026993, 49.32801067829132, 60.84986262023449, 84.32081177830696, 45.48086531460285, 0.0881480188400019, 0.25027992320246994, 0.3192179318284616, 4.254973204806447, 74.44181308150291, 76.85147657990456, 76.20121747255325, 72.19859585165977, 68.5830594599247, 68.21061864495277, 67.29082480072975, 70.96386730670929, 68.7990702688694, 73.50232109427452, 71.81664794683456, 67.01723948121071, 66.00528538227081, 67.10640549659729, 67.78344556689262, 70.1023243367672, 64.85104411840439, 63.82135257124901, 54.929936081171036, 61.98914788663387, 57.69160509109497, 54.29737642407417, 50.94364978373051, 50.32279349863529, 48.0195052921772, 49.68432515859604, 47.627271339297295, 47.956732660532, 47.6491429656744, 50.95189534127712, 46.135661378502846, 48.53997476398945, 47.43908643722534, 45.41510224342346, 45.06393648684025, 44.01502937078476, 43.35058942437172, 46.58476307988167, 43.72292384505272, 44.52024646103382, 44.257479161024094, 45.96027798950672, 46.800572499632835, 49.20397773385048, 49.69825141131878, 51.453004851937294, 50.56718498468399, 51.30274951457977, 54.1139754652977, 54.68529760837555, 54.706937447190285, 53.12460735440254, 52.89843209087849, 55.38053870201111, 55.853997096419334, 56.047969087958336, 57.325715124607086, 57.662323862314224, 55.08201152086258, 56.821561977267265, 57.4372923374176, 58.45241166651249, 54.97846707701683, 43.14189702272415, 42.404254004359245, 42.36290082335472, 38.49737964570522, 40.75901448726654, 44.75018352270126, 45.250426679849625, 40.112638771533966, 38.40136639773846, 39.81469675898552, 40.45681290328503, 38.88921082019806, 45.27622729539871, 57.25617125630379, 55.60248099267483, 57.43639558553696, 55.28583638370037, 54.84439507126808, 55.10993242263794, 55.99909231066704, 54.43458326160908, 52.410682663321495, 49.12034422159195, 50.461911633610725, 51.164030358195305, 50.52455507218838, 50.08975200355053, 49.92858745157719, 47.959525510668755, 51.105274111032486, 45.04697039723396, 46.7093013972044, 46.526432409882545, 43.830727860331535, 40.69172389805317, 40.011442601680756, 40.93891203403473, 40.433341562747955, 40.22568270564079, 41.47845268249512, 43.41750003397465, 45.44009730219841, 47.778590619564056, 47.48043201863766, 46.821186393499374, 52.50742927193642, 59.98010829091072, 59.944781586527824, 60.658778473734856, 59.82887260615826, 57.540278211236, 46.36374033987522, 59.41986635327339, 61.5313408523798, 61.5825355052948, 60.468503683805466, 60.0280237197876, 58.85552063584328, 58.26766178011894, 56.51864983141422, 60.43512247502804, 63.63565653562546, 68.85187223553658, 68.42128694057465, 70.25084316730499, 68.35210785269737, 73.30527126789093, 71.36986792087555, 75.78377947211266, 69.83959883451462, 78.66400972008705, 74.04599592089653, 78.38262721896172, 74.85810354351997, 115.33049181103706, 14.48915546759963, 0.2165874873753637, 0.8580636628903449, 10.197707545012236, 83.54597255587578, 61.91867306828499, 65.52593350410461, 35.994446352124214, 36.11921265721321, 48.22869546711445, 40.137257650494576, 6.992441788315773, 0.14094300189753994, 0.18099913140758872, 0.026542705709289294, 0.033066430551116355, 0.025057300845219288, 0.15358763979747891, 0.1902225278900005, 0.18356426095124334, 0.20061537099536508, 0.13293341762619093, 0.2176056249300018, 0.19952349364757538, 0.22484258894110098, 0.9049094491638243, 9.885658789426088, 81.36707827448845, 54.084945023059845, 53.68405133485794, 60.73275290429592, 68.25013652443886, 92.58086174726486, 51.92089654505253, 0.34545783943030983, 0.8497172326315194, 0.5756427487358451, 5.873910533264279, 78.89911070466042, 79.35288995504379, 79.6248109638691, 75.5868436396122, 71.37911662459373, 71.04135274887085, 67.81809210777283, 73.38616132736206, 72.63824746012688, 77.93777748942375, 74.53009754419327, 70.28344541788101, 67.08008050918579, 70.62447711825371, 72.75697588920593, 72.28176578879356, 65.62858879566193, 65.82156524062157, 57.85443015396595, 63.86528581380844, 60.50421416759491, 58.0653340369463, 53.98958534002304, 54.612345322966576, 50.316759422421455, 52.92595021426678, 50.068541541695595, 51.739665269851685, 50.16968451440334, 54.43391069769859, 49.26583081483841, 50.68476967513561, 51.86514973640442, 49.46597747504711, 46.96894906461239, 46.29449665546417, 45.97267672419548, 51.19006276130676, 46.23853325843811, 48.03281597793102, 48.03122766315937, 48.55679266154766, 50.802981331944466, 52.893036380410194, 52.54545383155346, 53.48778046667576, 53.562218472361565, 54.85087372362614, 56.69429920613766, 58.44053730368614, 58.312271386384964, 56.980948224663734, 54.924335181713104, 60.7875307649374, 60.2633260935545, 59.364343732595444, 59.575190618634224, 61.41241483390331, 59.06455501914024, 60.33408209681511, 59.58226963877678, 61.267342418432236, 57.94556826353073, 43.855707719922066, 45.6561841070652, 44.92356821894646, 41.31655476987362, 42.257566675543785, 47.53730356693268, 45.97596734762192, 43.43081831932068, 39.662499725818634, 42.17421054840088, 41.554881781339645, 38.66248458623886, 46.217501387000084, 59.19805705547333, 58.76064732670784, 60.038921535015106, 56.99358634650707, 55.866817608475685, 57.733387649059296, 58.78958277404308, 58.47048729658127, 56.331027299165726, 52.59183034300804, 54.823089614510536, 53.090447187423706, 53.593536391854286, 54.92164492607117, 53.01629796624184, 50.83266153931618, 53.066238686442375, 47.309072613716125, 48.62632513046265, 48.91481705009937, 46.125721111893654, 42.647969126701355, 42.97208413481712, 43.2937216758728, 45.02831719815731, 41.703643798828125, 46.17604561150074, 45.56579455733299, 49.08502511680126, 49.809167459607124, 50.183861553668976, 49.126944467425346, 56.09922833740711, 61.08257353305817, 63.45920540392399, 63.337383940815926, 62.889543771743774, 60.64058504998684, 52.97725886106491, 62.34965354204178, 66.36725395917892, 65.52239209413528, 62.92422451078892, 62.97304809093475, 61.832360699772835, 61.97036549448967, 61.101428121328354, 63.04612956941128, 66.36859148740768, 71.13789036870003, 71.30635812878609, 74.68957498669624, 70.55122464895248, 74.6669054031372, 72.06625655293465, 79.00252595543861, 72.34310209751129, 83.11935424804688, 75.90202912688255, 82.2529399394989, 76.4591172337532, 118.87146860361099, 18.278125002980232, 0.27007623750250787, 2.5364961801096797, 13.596482668071985, 92.91225716471672, 68.27071622014046, 75.26693120598793, 48.1718011200428, 51.92899391055107, 61.576786413788795, 59.77010875940323, 8.98223826661706, 0.26621264638379216, 0.2814397355541587, 0.18460795807186514, 0.14549416315276176, 0.22347225778503343, 0.23441473545972258], [0.0434918613609625, 0.021997917647240683, 0.057031176838791, 0.05105346303025726, 0.03626487923611421, 0.18941462592920288, 0.07897102885181084, 0.3003203880507499, 3.8370488304644823, 52.11665064096451, 49.42273959517479, 29.24385018646717, 35.805638283491135, 51.709627881646156, 70.34411296248436, 48.72323513031006, 0.2627458667848259, 0.14959917491069064, 0.06610695272684097, 1.3231633370742202, 60.07608734071255, 80.83877742290497, 72.5680424273014, 74.10150334239006, 66.01287737488747, 62.89467729628086, 62.68395200371742, 67.47949987649918, 70.57889476418495, 69.6378980576992, 68.02821323275566, 66.13440245389938, 66.92214578390121, 69.11366298794746, 66.82297110557556, 61.099353432655334, 60.41589170694351, 55.27500696480274, 56.06225252151489, 56.020751148462296, 51.870214864611626, 47.97711096704006, 44.115560576319695, 45.27675926685333, 43.51609334349632, 46.020880937576294, 44.8178730905056, 47.3210571706295, 47.160549983382225, 47.03209027647972, 45.277010053396225, 44.22325819730759, 45.59077821671963, 43.37622284889221, 41.93003185093403, 42.34696827828884, 39.66535337269306, 43.93675737082958, 40.49841307103634, 39.928743839263916, 39.960152953863144, 42.38473445177078, 43.58961179852486, 43.89719769358635, 45.77746219933033, 47.4456562846899, 49.209058061242104, 49.565076157450676, 50.224241986870766, 51.876807510852814, 51.564954444766045, 50.49848087131977, 52.891364470124245, 52.98898123204708, 51.2590404599905, 53.593741580843925, 53.73417444527149, 54.28831771016121, 55.541406869888306, 55.763930529356, 53.68771433830261, 55.946746319532394, 56.320574060082436, 44.457899406552315, 43.667971193790436, 42.93963007628918, 39.627461805939674, 43.012354373931885, 43.473923206329346, 42.28302910923958, 42.25828483700752, 37.154121324419975, 38.50534401834011, 41.75465606153011, 39.77398194372654, 47.69668221473694, 54.2975702136755, 52.85867102444172, 52.473246306180954, 54.385273307561874, 54.35598827898502, 53.1535580009222, 51.79975904524326, 50.33785969018936, 50.038914531469345, 46.47771142423153, 49.23291318118572, 47.86451540887356, 47.660869136452675, 47.97941744327545, 45.189500749111176, 46.004967391490936, 46.855145171284676, 44.749567955732346, 41.26360081136227, 42.28190816938877, 40.470351576805115, 38.82581502199173, 37.12117709219456, 37.88578346371651, 37.96130821108818, 38.70910428464413, 39.93127830326557, 40.411397740244865, 43.097059428691864, 45.12164779007435, 45.81759184598923, 47.534487918019295, 46.388157829642296, 53.00808660686016, 56.49064913392067, 57.78470769524574, 61.71588934957981, 53.97191248834133, 46.69081538915634, 57.57069557905197, 57.426557913422585, 61.082083359360695, 57.00318843126297, 59.94564414024353, 55.880048498511314, 57.52790227532387, 52.5882775336504, 54.244821444153786, 57.05102026462555, 66.42664477229118, 62.03987516462803, 69.80093970894814, 67.04166457056999, 69.52995344996452, 67.93810486793518, 71.55895337462425, 70.43095350265503, 75.13068571686745, 73.03239271044731, 79.59508895874023, 83.69683966040611, 82.11270466446877, 5.441659977659583, 0.07844768115319312, 0.31129707873333246, 9.688523467630148, 74.9665117263794, 53.07386867702007, 56.12320125102997, 23.771480731666088, 29.982591345906258, 33.10947395861149, 22.261025682091713, 8.493316601961851, 0.060456065912148915, 0.1548769581131637, 0.06809945596614853, 0.17651762813329697, 0.012884498173661996, 0.024935635010479018, 0.09061266158823855, 0.04382926024845801, 0.05644553697493393, 0.008654051398480078, 0.11212010125746019, 0.06838890840299428, 0.07129437202820554, 0.4057102859951556, 5.5193420592695475, 63.97542670369148, 54.745843559503555, 34.44418653845787, 48.07874411344528, 57.96331711113453, 77.7591110765934, 54.04030881822109, 0.15608536748914048, 0.16329951788065955, 0.43906287755817175, 0.7870857277885079, 63.45487363636494, 83.19207474589348, 76.25272750854492, 75.14956310391426, 67.66450434923172, 65.56488901376724, 65.45176148414612, 69.50537636876106, 72.75560036301613, 72.15276271104813, 70.93637198209763, 68.15812066197395, 67.56406053900719, 73.17702054977417, 68.73515009880066, 64.98029038310051, 64.07070279121399, 57.36559398472309, 57.32138715684414, 59.14943106472492, 55.276697874069214, 49.08383198082447, 48.04043836891651, 47.742367163300514, 46.65040075778961, 47.73247629404068, 48.485793471336365, 49.46493253111839, 51.60537667572498, 50.912426859140396, 45.92516407370567, 45.97405984997749, 47.54768081009388, 46.082091853022575, 45.18100440502167, 44.50821250677109, 44.39727745950222, 46.33801952004433, 44.0882970392704, 44.07636567950249, 43.74855346977711, 44.44391615688801, 46.07790447771549, 46.314814165234566, 47.917910143733025, 49.69636671245098, 51.83757461607456, 52.908395156264305, 52.22080685198307, 56.170216128230095, 55.59973753988743, 54.762418270111084, 56.84385538101196, 54.95467275381088, 55.138620883226395, 56.37624107301235, 57.49192200601101, 57.264093831181526, 57.42275431752205, 58.442813381552696, 55.736568197607994, 57.844478487968445, 58.70043955743313, 46.14053651690483, 43.313978388905525, 43.17319214344025, 39.844559356570244, 45.90201951563358, 43.506886437535286, 41.32748298346996, 43.317322209477425, 37.76740461587906, 40.30628018081188, 40.65824769437313, 40.11653356254101, 52.60903961956501, 55.104388520121574, 53.0139496922493, 55.322352424263954, 57.27053448557854, 58.07249665260315, 56.19460701942444, 54.80481639504433, 51.58038541674614, 53.74817669391632, 50.47746039927006, 51.63968503475189, 51.3732623308897, 50.98619610071182, 51.018741354346275, 48.266199454665184, 49.718717113137245, 49.19847562909126, 45.64465552568436, 43.89107622206211, 42.936677634716034, 43.6111756414175, 40.899223163723946, 39.46487233042717, 40.59196025133133, 41.59957118332386, 42.103994116187096, 43.809426203370094, 42.90673524141312, 44.95148532092571, 48.47869925200939, 46.836184188723564, 48.26623745262623, 49.068313613533974, 55.875142961740494, 58.90182875096798, 62.140474766492844, 62.57225699722767, 57.55476303398609, 49.96927186846733, 60.301688835024834, 59.612561613321304, 62.031192630529404, 58.75647135078907, 63.45524601638317, 58.92260983586311, 60.056833773851395, 54.46505382657051, 57.959179133176804, 60.20963877439499, 68.29268664121628, 65.71957871317863, 71.38850212097168, 69.91576954722404, 72.15752005577087, 70.10047763586044, 73.88140395283699, 72.56908357143402, 77.49011591076851, 75.61543330550194, 80.83148181438446, 82.92158246040344, 88.18081185221672, 4.791387096047401, 0.07971693179570138, 0.3087202232563868, 11.542410738766193, 84.93618115782738, 59.451381862163544, 64.1532875597477, 34.882356226444244, 36.97374500334263, 45.14399819076061, 42.43216350674629, 8.656769581139088, 0.04664765510824509, 0.07377097077551298, 0.07444032118655741, 0.16670845448970795, 0.023950437680468895, 0.054910604885662906, 0.25468590552918613, 0.1604110049083829, 0.19265031558461487, 0.13281966123031452, 0.23844231152907014, 0.22735842503607273, 0.6808654556516558, 0.5810147104784846, 8.51694943383336, 78.92443254590034, 63.68436612188816, 40.753702372312546, 49.725860729813576, 67.43529304862022, 83.4827895462513, 59.468636736273766, 0.4139631165890023, 0.4309573781210929, 1.0895928391255438, 2.5797777576372027, 64.34656798839569, 84.07677367329597, 80.42163580656052, 79.79289874434471, 69.88515838980675, 67.36213937401772, 68.91544282436371, 74.0214416384697, 75.3538629412651, 74.28421273827553, 72.08652466535568, 70.26120141148567, 70.08093148469925, 74.5822611451149, 71.66727796196938, 68.11942353844643, 67.71346092224121, 63.01362231373787, 59.770910516381264, 61.704246774315834, 58.36434379220009, 53.19743424654007, 50.3345462679863, 50.84070570766926, 49.207549542188644, 51.68695069849491, 50.225887298583984, 52.83971384167671, 54.86296467483044, 54.24073286354542, 49.7953400015831, 49.31289128959179, 51.679905876517296, 48.68138037621975, 47.09599144756794, 47.42218114435673, 47.12676219642162, 46.319468915462494, 45.22792428731918, 47.77654252946377, 47.90958859026432, 48.786311745643616, 47.15899206697941, 49.88835521042347, 52.18053661286831, 53.334128111600876, 55.42832873761654, 55.42063035070896, 56.71687759459019, 58.482521250844, 58.338786363601685, 55.12229695916176, 62.09389306604862, 60.596632808446884, 59.99081991612911, 61.591784209012985, 61.26144513487816, 61.05661332607269, 61.064022928476334, 62.08711422979832, 59.23765853047371, 61.20149955153465, 59.61634621024132, 46.069229543209076, 46.062583699822426, 44.11353148519993, 40.18613822758198, 47.78071090579033, 46.264383271336555, 43.285920694470406, 43.81990224123001, 40.828014984726906, 40.34742057323456, 42.02730283141136, 40.46806789934635, 52.54718653857708, 56.62034757435322, 58.551460951566696, 58.26095513999462, 59.85890619456768, 60.85886813700199, 60.90030871331692, 57.87377491593361, 57.16607429087162, 59.669664949178696, 53.836487755179405, 57.244369089603424, 56.23697094619274, 55.41244938969612, 55.60815788805485, 50.96763789653778, 52.88811184465885, 52.686760649085045, 48.90135057270527, 46.48536041378975, 45.42627364397049, 46.767069697380066, 44.853241592645645, 42.99784675240517, 42.753846645355225, 43.150989934802055, 44.41817253828049, 46.32115222513676, 46.125208139419556, 47.38859474658966, 51.31481006741524, 50.24823769927025, 51.887982711195946, 51.33274130523205, 59.547056928277016, 61.37343652546406, 63.93585562705994, 65.144152790308, 60.47880493104458, 53.07564698159695, 59.19832304120064, 61.817773282527924, 65.61858773231506, 61.04282386600971, 64.77941796183586, 60.40997542440891, 63.03653508424759, 57.40269139409065, 59.44649912416935, 63.244744911789894, 72.04227983951569, 68.64580929279327, 75.27867257595062, 72.838663905859, 74.64449420571327, 73.25886815786362, 77.43444889783859, 74.28654581308365, 80.07136300206184, 78.54848831892014, 85.83272024989128, 80.32195195555687, 99.38083246350288, 7.226217593997717, 0.14763662475161254, 1.0193368652835488, 13.412940166890621, 96.46135032176971, 65.45341059565544, 77.33321473002434, 40.510937198996544, 50.46898305416107, 61.81562639772892, 60.59554226696491, 10.488886870443821, 0.27594086655881256, 0.2903891756432131, 0.23821796028641984, 0.2985983085818589, 0.16775088995927945, 0.12185819941805676], [0.07791993251885287, 0.039392003818647936, 0.016806670719233807, 0.0384959347138647, 0.15597832010826096, 0.1934582769172266, 0.03856026036373805, 0.25873892242088914, 2.3429321916773915, 49.94037821888924, 45.45614764094353, 33.519699946045876, 26.630454920232296, 52.16476745903492, 63.27574744820595, 65.6138987839222, 2.1510272892192006, 0.144027516071219, 0.2927677589468658, 0.17685284139588475, 43.0224846303463, 81.25483229756355, 67.49713093042374, 72.53760606050491, 66.39753833413124, 67.73999109864235, 67.01134979724884, 67.94245183467865, 69.3292786180973, 69.69578415155411, 68.9183534681797, 70.52838787436485, 68.24328169226646, 64.45018842816353, 62.14391738176346, 62.17028796672821, 56.27489671111107, 56.35574497282505, 53.196571692824364, 54.4256005436182, 47.56209723651409, 47.462413385510445, 45.48652321100235, 45.08846037089825, 45.70706717669964, 45.637443512678146, 47.61745646595955, 48.05796302855015, 47.41027258336544, 45.36499433219433, 42.48803570866585, 43.85603450238705, 45.465844720602036, 43.01566019654274, 44.19906489551067, 42.88481041789055, 40.83042025566101, 41.41391694545746, 41.01415179669857, 39.7481395304203, 40.11440947651863, 40.122704431414604, 42.85701870918274, 46.03637270629406, 44.46810565888882, 46.333858743309975, 47.0029154419899, 50.338505655527115, 50.63397780060768, 51.71731486916542, 51.64590910077095, 51.76409035921097, 52.40968331694603, 53.190252631902695, 52.008018270134926, 53.102013766765594, 52.80501030385494, 53.583356738090515, 54.69401814043522, 55.24283789098263, 53.722136691212654, 56.31773181259632, 56.65920048952103, 45.85964418947697, 39.74538467824459, 45.66869683563709, 40.173332914710045, 45.6266862899065, 43.15852873027325, 42.640361934900284, 45.721058025956154, 39.81971628963947, 37.297780215740204, 39.68105413019657, 41.3480930775404, 50.38047820329666, 51.91191762685776, 52.86940924823284, 52.53781244158745, 54.77909177541733, 52.62899614870548, 53.55174623429775, 50.294515416026115, 49.828299432992935, 48.686624094843864, 48.25758911669254, 48.249829933047295, 45.63351832330227, 46.912727281451225, 47.26544715464115, 46.5432845056057, 47.35815837979317, 45.235094502568245, 42.30434596538544, 40.325362756848335, 40.95504976809025, 39.69075880944729, 39.02136392891407, 35.11745721101761, 40.20831383764744, 40.46680636703968, 39.19770486652851, 39.79387387633324, 40.91707080602646, 43.038542568683624, 45.91836243867874, 46.073207929730415, 45.04683740437031, 43.879931420087814, 49.33570146560669, 52.615784257650375, 54.458343386650085, 56.26078046858311, 58.13471831381321, 57.00479954481125, 61.872364953160286, 57.687672302126884, 58.75399008393288, 58.960349410772324, 57.02024191617966, 56.81187629699707, 57.56947584450245, 53.80688734352589, 57.23739266395569, 54.20966953039169, 58.99619288742542, 60.49090348184109, 63.9257937669754, 67.00235947966576, 70.1609855890274, 66.97281986474991, 71.79107531905174, 68.689826130867, 74.83416482806206, 71.88635900616646, 80.29404625296593, 80.18768236041069, 56.5882582962513, 0.3983173373853788, 0.1587681274395436, 0.23199692222988233, 13.545591998845339, 76.70096665620804, 53.75708721578121, 64.66613084077835, 26.260468773543835, 31.4082957431674, 38.406081944704056, 30.194832757115364, 8.28555230051279, 0.13994184468174353, 0.14071223849896342, 0.07775101970764808, 0.021286179471644573, 0.0444451945804758, 0.007078078078848193, 0.04576230261591263, 0.12102651162422262, 0.049094567948486656, 0.05955095373792574, 0.1114989904453978, 0.09914582362398505, 0.13222396897617728, 0.29204357124399394, 4.625820480287075, 60.819741636514664, 53.405283093452454, 37.94032573699951, 34.32079575955868, 59.29426409304142, 68.33085179328918, 70.35767063498497, 2.7275808015838265, 0.07134900151868351, 0.143915525986813, 0.651324950158596, 45.19160583615303, 81.01281568408012, 72.19282776117325, 74.51184332370758, 68.3595934510231, 71.01211711764336, 67.97204464673996, 70.27810290455818, 72.62126997113228, 71.0809238255024, 70.75975745916367, 72.15375825762749, 69.61199104785919, 68.45480874180794, 65.77250987291336, 63.777890503406525, 58.961234763264656, 58.433078303933144, 55.71168713271618, 56.03342346847057, 51.251763850450516, 49.9404314160347, 48.384726494550705, 47.299922704696655, 47.86445841193199, 49.58383955061436, 50.748131275177, 51.83390021324158, 50.31166389584541, 48.24540317058563, 46.96993701159954, 48.06762970983982, 47.459540739655495, 44.914038330316544, 43.9853947609663, 44.19969566166401, 44.04054120182991, 42.77214266359806, 43.017457500100136, 43.087833523750305, 42.75689408183098, 41.03979282081127, 43.96787390112877, 45.91970756649971, 47.14844383299351, 46.950098276138306, 49.54141102731228, 51.203700229525566, 53.82245510816574, 53.7608490139246, 53.705664575099945, 55.46960972249508, 55.6942992657423, 55.52095636725426, 54.896038100123405, 55.16784131526947, 55.94288192689419, 56.98451243340969, 57.422150149941444, 57.50538848340511, 56.29704192280769, 57.966383546590805, 58.09532582759857, 47.68270656466484, 41.101683899760246, 45.97423084080219, 41.474455296993256, 47.57492154836655, 43.44282567501068, 44.01143476366997, 46.808856055140495, 42.46559411287308, 38.89659382402897, 38.960551992058754, 40.86417004466057, 52.767213732004166, 54.77027244865894, 55.823169350624084, 53.44540894031525, 55.360452979803085, 56.55771553516388, 54.73320923745632, 52.782648503780365, 53.27112749218941, 50.08929222822189, 52.7558371424675, 50.43421871960163, 48.83407138288021, 50.129596665501595, 50.55473305284977, 48.26514311134815, 50.08585721254349, 48.40187497437, 44.39392223954201, 41.48007519543171, 43.604187816381454, 40.3039813041687, 40.333612114191055, 36.94549731910229, 42.58091792464256, 42.43760861456394, 42.2727582603693, 42.28108361363411, 43.50321963429451, 45.24262949824333, 48.018445149064064, 46.61380872130394, 46.8300399184227, 48.50303314626217, 51.11507758498192, 54.66053433716297, 56.59522332251072, 58.260571360588074, 61.23964190483093, 59.5090551674366, 63.55896145105362, 61.702343076467514, 61.82497389614582, 62.94736906886101, 60.12844853103161, 58.54758135974407, 60.43155446648598, 57.807502672076225, 59.49725680053234, 57.89309687912464, 63.64196799695492, 63.269922360777855, 68.65310490131378, 69.49881792068481, 72.37498238682747, 68.99042040109634, 73.12747120857239, 71.47089689970016, 75.80958008766174, 74.6093612909317, 81.3518638908863, 85.44193401932716, 57.620244920253754, 0.3131632535951212, 0.10875231673708186, 0.31938818050548434, 15.337530244141817, 85.44956400990486, 62.15802222490311, 77.23155498504639, 32.63456404209137, 42.99254983663559, 52.80096732079983, 47.749210596084595, 10.64636467024684, 0.15103313780855387, 0.08927442831918597, 0.0698394508799538, 0.10802474484080449, 0.02873980236472562, 0.008795041831035633, 0.28733108192682266, 0.21455351292388514, 0.14877550973324105, 0.18167815200285986, 0.40630670555401593, 0.3234677069121972, 0.41529429203365, 0.5465274641755968, 7.40960905328393, 77.34001636505127, 60.5446819961071, 45.05983270704746, 33.96114505827427, 71.18902042508125, 74.07054260373116, 77.92001724243164, 2.9164121439680457, 0.3199663432314992, 0.6158008938655257, 1.5841380832716823, 46.95468842983246, 82.10008934140205, 74.59069669246674, 76.35137021541595, 70.86358308792114, 73.18230226635933, 71.69376254081726, 72.60781869292259, 74.61886078119278, 73.6955027282238, 71.82256802916527, 75.26161909103394, 71.95502892136574, 72.06377148628235, 68.38045433163643, 66.40332162380219, 62.23822832107544, 61.57237485051155, 58.33812139928341, 59.822131767868996, 52.43181712925434, 53.082463815808296, 52.31210455298424, 49.69826281070709, 52.953491136431694, 52.22299553453922, 53.1922323256731, 53.9627093821764, 52.17203266918659, 51.149872317910194, 48.939823508262634, 50.97803793847561, 49.72087919712067, 47.276546359062195, 45.535559579730034, 47.89547994732857, 45.28711371123791, 44.95544470846653, 45.13179324567318, 45.95442250370979, 46.529210060834885, 44.45244289934635, 45.84875017404556, 51.06830969452858, 48.454673141241074, 51.23785279691219, 51.11315108835697, 55.18092781305313, 56.49313420057297, 57.19755560159683, 57.624705880880356, 57.91789434850216, 61.382274851202965, 61.70341081917286, 58.473321944475174, 58.45316022634506, 59.88935396075249, 59.85853001475334, 60.694184973835945, 60.87322376668453, 58.33413541316986, 62.161810621619225, 59.64629240334034, 50.03408499062061, 41.708249151706696, 45.36570109426975, 42.2100730240345, 49.43077236413956, 44.849897772073746, 44.47544686496258, 47.23198615014553, 42.68747940659523, 38.26038636267185, 39.13405828177929, 44.92287665605545, 54.89439278841019, 57.1248123049736, 58.620833829045296, 58.588600158691406, 60.14165282249451, 59.529194086790085, 60.09738899767399, 55.677238181233406, 56.60192996263504, 55.257858484983444, 56.34822517633438, 56.318917348980904, 51.241549998521805, 53.01529102027416, 53.555565029382706, 51.969473138451576, 53.41287888586521, 49.35201399028301, 48.839717879891396, 45.542327016592026, 47.06788055598736, 43.298817202448845, 45.461034178733826, 40.13723865151405, 45.817914828658104, 45.677291974425316, 44.42987211048603, 42.95213520526886, 46.33879467844963, 49.1368543356657, 50.8494034409523, 51.472908183932304, 49.389563575387, 50.001543536782265, 52.46102996170521, 58.321284502744675, 58.94301854074001, 61.356181651353836, 63.35905037820339, 63.25184293091297, 67.39538758993149, 62.80752897262573, 64.9738459289074, 65.81213414669037, 63.88400360941887, 61.77397683262825, 63.22072260081768, 60.41996888816357, 62.27032519876957, 59.545316621661186, 66.74097150564194, 66.4114759862423, 69.0807643532753, 73.42363491654396, 75.5878771841526, 73.2791818678379, 76.48109525442123, 75.50064146518707, 79.79020848870277, 79.09191235899925, 83.6527544260025, 84.28479731082916, 69.18870896100998, 0.8338394877500832, 0.4414568084757775, 0.7391279668081552, 17.325371727347374, 94.84901323914528, 66.96707457304001, 89.16311994194984, 40.31566947698593, 49.37059499323368, 68.95948246121407, 67.28069454431534, 13.540335930883884, 0.3202043945202604, 0.25196721078827977, 0.1738659047987312, 0.23286746145458892, 0.10598821740131825, 0.09449935576412827], [0.03351955623656977, 0.06165884238725994, 0.045827362991985865, 0.0331142025970621, 0.0555299234110862, 0.044994098134338856, 0.05052553256973624, 0.15266068250639364, 2.468440644443035, 53.11217062175274, 51.88702896237373, 43.94890911877155, 38.649025708436966, 47.485413551330566, 57.04637311398983, 71.54503092169762, 5.617853673174977, 0.23726259358227253, 0.2592758514219895, 0.90420440887101, 28.047442585229874, 74.50872749090195, 69.94030863046646, 73.14830929040909, 68.24094861745834, 67.96259835362434, 67.47785836458206, 70.93392491340637, 69.02501374483109, 68.36455598473549, 67.05164283514023, 65.55309444665909, 66.48298054933548, 67.94782474637032, 62.62346304953098, 56.36437430977821, 56.2793842703104, 56.33616462349892, 49.237640127539635, 49.66844581067562, 43.04704271256924, 46.92334771156311, 44.44301180541515, 45.9175568819046, 47.57171452045441, 47.73243069648743, 48.09724912047386, 48.811891973018646, 45.46446919441223, 44.18491445481777, 45.11237248778343, 42.81210131943226, 42.70638719201088, 44.097697734832764, 43.97009298205376, 44.59069088101387, 42.22801186144352, 42.62397721409798, 43.34047056734562, 39.53779801726341, 40.803232714533806, 40.31175568699837, 40.98498076200485, 42.33619965612888, 43.91620047390461, 44.756787568330765, 48.15638914704323, 48.9819860458374, 49.901616498827934, 49.95571419596672, 51.465981155633926, 50.96189260482788, 52.714654952287674, 51.94864645600319, 52.3456871509552, 52.81711645424366, 54.664379730820656, 53.82689327001572, 54.61539275944233, 54.653428718447685, 58.264466151595116, 56.110437735915184, 55.7113603502512, 48.17611388862133, 39.09543335437775, 43.75557169318199, 42.79912121593952, 51.06741674244404, 42.33948267996311, 40.692388862371445, 43.052332028746605, 46.9759064912796, 39.431836903095245, 37.900154292583466, 40.39394147694111, 53.20655755698681, 53.9094590395689, 52.392743825912476, 52.582957819104195, 52.62331545352936, 54.040996581315994, 54.72749434411526, 51.805701926350594, 52.534286230802536, 50.48732087016106, 49.49799835681915, 46.233452931046486, 47.735858112573624, 47.63441875576973, 47.34844230115414, 46.54519960284233, 46.58675417304039, 44.22171548008919, 41.307332664728165, 39.008307829499245, 40.719040632247925, 38.99760000407696, 37.024859860539436, 38.33283707499504, 40.18633961677551, 40.01564897596836, 40.23703269660473, 42.38400489091873, 42.92883485555649, 43.2343802601099, 44.38117392361164, 45.25957278907299, 43.994780257344246, 44.42657768726349, 45.16107067465782, 47.84853346645832, 48.50080646574497, 52.521895095705986, 55.38281477987766, 56.779638826847076, 59.49249945580959, 57.22760818898678, 56.42905443906784, 58.59855942428112, 58.50333273410797, 58.35544466972351, 57.82994046807289, 56.55424252152443, 55.04913568496704, 56.70654594898224, 57.72674560546875, 57.929346933960915, 60.875739231705666, 64.35004100203514, 65.80904871225357, 69.3845808506012, 68.81100922822952, 68.47780510783195, 71.03038653731346, 75.4455292224884, 74.36742067337036, 73.7745612859726, 27.373913526535034, 0.5463403242174536, 0.8871705166529864, 0.4241444624494761, 14.382623434066772, 74.61650490760803, 55.69428026676178, 55.73367275297642, 31.49020414799452, 33.936814963817596, 39.65425796806812, 36.85351185500622, 6.68023344129324, 0.21719339158153161, 0.05604176039923914, 0.03226593522413168, 0.08003837821888737, 0.053158119626459666, 0.010734874849731568, 0.024374580643780064, 0.0045558497731690295, 0.06333164696116, 0.02721711942285765, 0.09471268611378036, 0.0700663699535653, 0.1557452857377939, 0.43033441936131567, 6.615881994366646, 67.37400233745575, 59.148207530379295, 43.12596067786217, 45.49311585724354, 57.914512529969215, 60.59781074523926, 79.62513774633408, 5.905792247503996, 0.1871206919895485, 0.17952604248421267, 1.0662901145406067, 30.188291408121586, 78.43574836850166, 71.36608332395554, 75.51908567547798, 68.65600034594536, 70.56810334324837, 69.51884284615517, 72.75716587901115, 68.54828372597694, 69.10672456026077, 68.7336453795433, 68.4192730486393, 66.61444589495659, 69.08999785780907, 64.78719994425774, 58.734789714217186, 58.76125909388065, 57.91293181478977, 50.12268103659153, 52.21627749502659, 45.50481542944908, 48.59665632247925, 47.05143503844738, 49.15442459285259, 48.737347573041916, 51.11704967916012, 49.854487627744675, 50.89104540646076, 47.398177832365036, 46.89326472580433, 46.71657420694828, 45.04883989691734, 45.44801987707615, 45.844722390174866, 46.14905185997486, 46.664543598890305, 45.52016660571098, 45.217155665159225, 44.313237369060516, 43.47577750682831, 43.29811044037342, 42.37219512462616, 44.078542962670326, 45.305804908275604, 44.80148836970329, 45.85436627268791, 51.77100598812103, 51.56079366803169, 52.55215287208557, 53.90909045934677, 55.43613351881504, 53.70910719037056, 55.42857192456722, 55.32433971762657, 56.213298216462135, 56.312788277864456, 57.232639119029045, 54.95610527694225, 58.1108707934618, 57.0432572811842, 59.70655336976051, 56.61794610321522, 58.36120896041393, 49.048702865839005, 41.90051503479481, 44.79114152491093, 43.416983261704445, 53.695845901966095, 43.44376042485237, 41.909018978476524, 43.50326143205166, 49.52384456992149, 40.35307087004185, 38.62917557358742, 42.285426780581474, 55.58703102171421, 54.1813800483942, 57.93607637286186, 55.99618926644325, 55.10145507752895, 56.73216037452221, 56.15391120314598, 55.9490679949522, 55.32457150518894, 54.10464696586132, 54.298440366983414, 50.457674860954285, 49.20379914343357, 50.09707421064377, 49.91584673523903, 49.081795290112495, 49.595303535461426, 46.716570407152176, 43.29523779451847, 42.39499770104885, 42.76495724916458, 42.16559261083603, 39.5777452737093, 40.584349259734154, 41.847055703401566, 40.964112281799316, 42.54189021885395, 43.524217307567596, 45.93451917171478, 46.14209823310375, 47.52341151237488, 46.497679352760315, 46.232894361019135, 45.43480798602104, 48.301598355174065, 50.07213614881039, 53.555994406342506, 55.72146400809288, 58.35397034883499, 60.356417298316956, 59.829685762524605, 59.16119143366814, 58.99044759571552, 60.14536902308464, 61.99873097240925, 61.00528568029404, 60.35368524491787, 58.55416640639305, 58.64877752959728, 60.29926836490631, 60.96531942486763, 60.29255412518978, 64.79260325431824, 66.45174622535706, 69.14577886462212, 70.43739035725594, 70.65200284123421, 71.24569058418274, 73.57532277703285, 78.04056957364082, 80.10857820510864, 82.08121195435524, 26.30727656185627, 0.5999238614458591, 0.8714619220700115, 0.3590057452674955, 15.905096288770437, 86.18896633386612, 61.44911706447601, 65.30757442116737, 34.57101993262768, 39.536072909832, 55.989125445485115, 57.38563030958176, 10.18974982202053, 0.08306622941745445, 0.1542683524894528, 0.11470103854662739, 0.006630979560213746, 0.004849387269132421, 0.09835625271080062, 0.2248467894969508, 0.2001635218039155, 0.1566427797661163, 0.19554239086573943, 0.15332062990637496, 0.11463219692814164, 0.356895849108696, 0.5685302428901196, 9.771928992122412, 84.90766748785973, 64.38278764486313, 56.88105158507824, 48.65648791193962, 66.0741300880909, 66.90869450569153, 87.6739950478077, 7.122608553618193, 0.3841953061055392, 0.301375929848291, 1.8616113066673279, 33.402837216854095, 79.11966606974602, 75.95753654837608, 80.47088116407394, 72.92705476284027, 74.39047783613205, 72.06457704305649, 76.60637453198433, 69.55727398395538, 70.6735172867775, 70.66658645868301, 71.45766600966454, 70.11428609490395, 72.30714842677116, 65.90012222528458, 62.664721235632896, 60.55686414241791, 61.179848313331604, 52.23310299217701, 56.731582805514336, 47.51602850854397, 50.823785215616226, 49.83163945376873, 51.27332389354706, 51.7814402282238, 54.6928896009922, 53.36127385497093, 54.55799303948879, 50.21562024950981, 50.863496884703636, 48.94930399954319, 47.81497746706009, 49.59695264697075, 47.34846130013466, 48.34155701100826, 48.780239671468735, 46.75752080976963, 49.017213955521584, 47.34130248427391, 46.967976316809654, 46.01666696369648, 46.13305851817131, 47.3653019964695, 46.829523146152496, 47.749871760606766, 48.26339900493622, 53.26421566307545, 52.671804651618004, 54.740174263715744, 56.533522233366966, 58.78813125193119, 54.89759601652622, 58.93650949001312, 57.79964469373226, 59.82529319822788, 58.200640976428986, 62.16069348156452, 60.376191437244415, 61.58603511750698, 58.73141549527645, 64.08294573426247, 60.586164370179176, 59.9042833596468, 50.781413689255714, 42.367578372359276, 47.426113933324814, 45.05328945815563, 55.10851509869099, 44.11098562180996, 42.082513868808746, 43.7316557765007, 50.690955743193626, 40.4822601377964, 38.662632778286934, 43.46788913011551, 57.338809221982956, 58.76510828733444, 59.78133715689182, 57.81728334724903, 58.71251530945301, 61.27167418599129, 60.71894444525242, 61.34244158864021, 59.52987805008888, 56.796350330114365, 56.85127258300781, 52.96539209783077, 54.376526176929474, 55.76803430914879, 55.18790423870087, 51.91115766763687, 52.40366443991661, 50.00546492636204, 47.55775786936283, 43.98298569023609, 46.245277896523476, 43.76880258321762, 43.121526315808296, 42.81809359788895, 45.54792791604996, 45.288664028048515, 45.67623183131218, 45.967098623514175, 48.257117941975594, 48.72064366936684, 48.875766545534134, 50.144484266638756, 48.734490126371384, 49.88976493477821, 50.20289093255997, 53.3870592713356, 56.27797074615955, 57.32260689139366, 61.108328551054, 63.17080467939377, 64.26963731646538, 61.559387147426605, 61.220855712890625, 64.98218268156052, 65.16273379325867, 62.85131022334099, 64.7493539750576, 61.68023966252804, 61.7483814060688, 64.10309985280037, 64.7387145459652, 63.6583299189806, 67.58035406470299, 70.18252283334732, 73.00922155380249, 75.48905208706856, 77.42444783449173, 74.7242671251297, 77.08234459161758, 82.38654837012291, 79.61458951234818, 83.41818541288376, 34.586694091558456, 0.7506694318726659, 1.7186435032635927, 0.43126308359205723, 17.2220191732049, 95.97549319267273, 68.66044610738754, 76.50247290730476, 46.56997807323933, 52.731883227825165, 68.06243419647217, 73.93084689974785, 15.922144073992968, 0.3411052323644981, 0.285407257033512, 0.22737807710655034, 0.21686058287741616, 0.20598526956746355, 0.1731641447986476], [0.030521107073582243, 0.07654958651983179, 0.0835341980564408, 0.039920631897985004, 0.0752155612281058, 0.06279661043663509, 0.14037243876373395, 0.238090934290085, 4.777372498065233, 54.19781416654587, 45.82748271524906, 45.37589214742184, 31.287040449678898, 52.693501487374306, 57.14878901839256, 74.41741839051247, 8.338495809584856, 0.11733841616660357, 0.2142776714754291, 0.05992481063003652, 19.172954186797142, 53.167313262820244, 72.9447466135025, 67.84871846437454, 73.46056133508682, 69.35391649603844, 71.52901858091354, 69.26057830452919, 69.93590086698532, 67.12766915559769, 66.76774486899376, 64.33073043823242, 63.75155791640282, 58.11649449169636, 58.33299547433853, 52.38430827856064, 51.55632510781288, 49.778476506471634, 47.78577983379364, 47.64886558055878, 45.597336664795876, 45.695299208164215, 47.02237419784069, 47.79818996787071, 47.88219206035137, 50.38615129888058, 48.091256842017174, 47.549846693873405, 45.21195374429226, 44.4039499014616, 44.20555494725704, 42.10258439183235, 43.681612461805344, 45.04693619906902, 43.342404663562775, 44.73707042634487, 43.59201326966286, 41.93204194307327, 42.76059128344059, 40.454255640506744, 41.02246195077896, 41.34549781680107, 39.63919557631016, 40.783595368266106, 42.0507437735796, 43.31953749060631, 43.93434830009937, 48.05218353867531, 47.38669864833355, 49.046035408973694, 49.325681403279305, 50.99524721503258, 50.9408987313509, 50.7388711720705, 51.877932250499725, 53.34381379187107, 52.15636231005192, 55.86218565702438, 52.57552921772003, 54.95112754404545, 55.44521503150463, 56.85346506536007, 57.11885802447796, 50.631743520498276, 38.67518350481987, 40.14481544494629, 46.88975751399994, 53.67275074124336, 44.90590676665306, 45.81311948597431, 43.6438462883234, 48.03169123828411, 43.05486649274826, 37.41613246500492, 41.85158126056194, 53.791475370526314, 52.26805351674557, 52.686118483543396, 52.70461209118366, 52.72612653672695, 49.87390838563442, 50.53149349987507, 52.173149809241295, 49.04784791171551, 48.89822714030743, 47.52393588423729, 48.623855262994766, 46.35584816336632, 46.71482250094414, 46.858796775341034, 49.25689749419689, 45.27834378182888, 43.52883405983448, 41.015048548579216, 39.53335225582123, 40.43137326836586, 38.365899100899696, 37.8488190472126, 37.93065905570984, 40.636984035372734, 40.79295426607132, 42.31865219771862, 41.992177516222, 42.20133729279041, 44.52913038432598, 43.12105894088745, 43.929583355784416, 43.5131599009037, 42.08897352218628, 44.32679884135723, 44.277340695261955, 45.84762163460255, 47.78536945581436, 52.509560957551, 51.85626581311226, 52.086506858468056, 53.07175599038601, 52.047961726784706, 54.43088985979557, 55.87706185877323, 59.06509838998318, 54.84473705291748, 54.606600031256676, 56.91228970885277, 57.6238015294075, 58.25820028781891, 57.70131357014179, 60.55881343781948, 62.96813115477562, 59.5587944984436, 63.21710519492626, 61.06225982308388, 67.35658407211304, 67.5795105099678, 72.9771588742733, 73.31543952226639, 67.70122557878494, 6.830781362950802, 0.6501067592762411, 1.7279864894226193, 0.5660221399739385, 15.701414868235588, 77.02879026532173, 52.97125518321991, 56.92285694181919, 34.60791975259781, 42.811386957764626, 42.44648493826389, 55.37149518728256, 10.934089981019497, 0.1703963050385937, 0.17799267632653937, 0.02674443443538621, 0.08057624232606031, 0.030381917276827153, 0.023126434825826436, 0.026184984963038005, 0.002157672379325959, 0.0554537233983865, 0.01761611449182965, 0.04627891532436479, 0.1125459604372736, 0.17422644014004618, 0.4927754891104996, 7.117874957621098, 69.08437415957451, 50.76573573052883, 50.98215691745281, 34.20823059976101, 59.842301085591316, 62.788381800055504, 82.93153792619705, 9.141718558967113, 0.41598558775149286, 0.22186375659657642, 0.29362841276451945, 21.123347729444504, 58.00948843359947, 73.66606950759888, 70.40201425552368, 74.99629452824593, 72.20440953969955, 72.98429489135742, 70.60471817851067, 72.82746210694313, 68.80322724580765, 70.01268714666367, 67.06111192703247, 65.81680029630661, 60.81996962428093, 60.020450726151466, 58.04826155304909, 55.70915646851063, 53.563362210989, 50.65017633140087, 49.7003298997879, 48.334303200244904, 48.30903075635433, 48.94277594983578, 49.92618218064308, 51.130166575312614, 53.41006323695183, 50.73883317410946, 49.81593109667301, 48.84652331471443, 45.85422568023205, 44.5124226808548, 44.61585313081741, 46.10824204981327, 46.489901170134544, 45.38439989089966, 46.75774499773979, 45.28158500790596, 44.352417066693306, 44.42457519471645, 43.975108712911606, 44.512772262096405, 45.07236063480377, 42.14321941137314, 44.94978301227093, 46.18684843182564, 46.1149562895298, 44.72990781068802, 50.16874976456165, 49.200200736522675, 50.761897936463356, 50.96495904028416, 53.09163652360439, 53.31868574023247, 54.00679461658001, 53.870932906866074, 55.11966370046139, 55.79400211572647, 57.51895755529404, 56.12375222146511, 57.78165265917778, 56.69361524283886, 58.50503124296665, 58.63137446343899, 51.26794718205929, 39.39571604132652, 39.95732210576534, 48.6327163875103, 54.76866893470287, 42.951040863990784, 47.10220791399479, 43.0436646938324, 49.276075065135956, 42.822972536087036, 39.518419057130814, 43.368714451789856, 54.11519519984722, 55.187843441963196, 53.66228990256786, 55.473911091685295, 56.6306222230196, 51.767859756946564, 53.56837034225464, 54.12837289273739, 52.813681438565254, 52.922537997365, 50.01912899315357, 50.514390617609024, 50.5449827760458, 48.17496635019779, 50.42699530720711, 50.69442115724087, 49.494244158267975, 45.32976262271404, 44.16045896708965, 41.65463022887707, 42.08841495215893, 41.009181663393974, 38.96259628236294, 40.515664145350456, 43.23012828826904, 43.7163919955492, 43.88152353465557, 44.98090334236622, 43.536308258771896, 45.37778064608574, 45.80949068069458, 46.852375119924545, 45.29936045408249, 45.18628992140293, 45.974987000226974, 47.1194513887167, 49.149496257305145, 51.73226706683636, 54.94390793144703, 54.30284433066845, 55.145156532526016, 57.95184552669525, 53.0475664883852, 54.57504652440548, 57.323860824108124, 61.89723461866379, 57.06470713019371, 57.0119621604681, 60.825608521699905, 61.2224630266428, 61.95016197860241, 60.75395196676254, 63.340066596865654, 63.463765159249306, 63.71900126338005, 64.73647266626358, 67.20076963305473, 69.14566487073898, 72.39750757813454, 72.36328661441803, 78.7289634346962, 75.67427694797516, 5.898777823895216, 0.7285747455898672, 2.3083690088242292, 0.22801948565756902, 17.463602609932423, 87.04458922147751, 57.32096917927265, 67.92395442724228, 37.42093160748482, 39.03984993696213, 55.587977170944214, 71.08252733945847, 15.692762732505798, 0.17016864381730556, 0.16147474001627415, 0.04224471558700316, 0.06279407229158096, 0.06485188452643342, 0.055231798978638835, 0.2813292446080595, 0.17811729776440188, 0.26523687061853707, 0.16727407491998747, 0.25474337744526565, 0.19424777361564338, 0.4049056791700423, 0.5618521012365818, 10.614847261458635, 85.51128029823303, 58.71663808822632, 56.924027279019356, 39.577692076563835, 71.69003874063492, 67.61009886860847, 90.71155965328217, 9.723111111670732, 0.7066055713221431, 0.2367403294192627, 0.5008312349673361, 23.834190666675568, 61.316519379615784, 74.38859313726425, 75.2461539208889, 78.25464248657227, 75.1209506392479, 74.1903805732727, 75.71476757526398, 73.58619779348373, 71.22182786464691, 72.46283367276192, 70.94685181975365, 68.64092275500298, 62.89619721472263, 63.80014210939407, 58.546829000115395, 57.839496955275536, 56.84626825153828, 53.00163455307484, 52.78119318187237, 48.980135545134544, 51.148698180913925, 51.707534193992615, 53.544287234544754, 52.89601922035217, 57.26551495492458, 52.42137148976326, 52.39328719675541, 49.069643542170525, 48.986978977918625, 46.562910452485085, 46.57585255801678, 49.4179480522871, 51.046806648373604, 47.65861585736275, 49.99274700880051, 47.011358588933945, 46.77420951426029, 46.617414727807045, 46.83611959218979, 47.78181664645672, 48.52623090147972, 44.161712899804115, 47.66634464263916, 49.11251664161682, 49.101311042904854, 46.67775548994541, 51.82680979371071, 50.816580802202225, 53.097989782691, 53.28625448048115, 58.15782867372036, 57.434807270765305, 57.328260987997055, 56.54417306184769, 59.354517459869385, 56.150312796235085, 62.673852145671844, 56.627909168601036, 60.37298060953617, 59.14849631488323, 60.77549301087856, 61.053193509578705, 53.856501281261444, 40.438418090343475, 41.701998487114906, 48.49378064274788, 56.63608253002167, 45.596143528819084, 47.01159417629242, 43.55041690170765, 50.21587483584881, 45.285567194223404, 37.78436690568924, 44.38119292259216, 59.02602508664131, 57.3581387847662, 57.70611651241779, 59.28017444908619, 58.93320746719837, 54.046931862831116, 57.59990841150284, 57.807434275746346, 56.32486402988434, 56.54592476785183, 53.0209831148386, 55.28922960162163, 54.77124519646168, 50.906396582722664, 51.599513590335846, 55.988593474030495, 51.006023436784744, 47.82457955181599, 47.349658235907555, 44.70463536679745, 45.47259695827961, 42.691822573542595, 44.048520773649216, 43.59909228980541, 46.60330228507519, 45.640331357717514, 45.79307556152344, 46.05274982750416, 47.14926078915596, 47.92354144155979, 48.34252595901489, 48.984011337161064, 48.5186655074358, 47.13224910199642, 49.38674412667751, 50.486120134592056, 51.59886382520199, 55.353601947426796, 59.19041946530342, 56.31314165890217, 56.807662323117256, 59.97894935309887, 55.79953841865063, 59.19239155948162, 61.49404585361481, 64.55792784690857, 60.171295031905174, 58.97607296705246, 63.96400451660156, 65.0287301838398, 65.12924239039421, 63.77326235175133, 67.93929040431976, 68.15646395087242, 66.82456701993942, 68.62039625644684, 69.89161044359207, 75.23511171340942, 74.87422227859497, 79.52270284295082, 77.44639545679092, 75.51818132400513, 9.133901428431273, 1.0339103895239532, 5.05690117366612, 0.6255543767474592, 20.330942049622536, 96.78482696413994, 64.71938878297806, 80.37384197115898, 51.01340264081955, 63.34153711795807, 64.81524243950844, 79.05690103769302, 20.535903051495552, 0.38462785945739597, 0.38331933435983956, 0.2029328903881833, 0.30064129270613194, 0.11460089313914068, 0.18759300961392], [0.010202377397945384, 0.04078702251717914, 0.02032161570241442, 0.062490177660947666, 0.03659192887425888, 0.07422574402880855, 0.13271525589516386, 0.362476235604845, 4.3603206519037485, 50.403907746076584, 40.92226892709732, 42.56549075245857, 52.19003610312939, 49.85181637108326, 56.49254523217678, 77.1822564303875, 11.306419651955366, 0.5215179780498147, 0.4141237470321357, 0.08273624087451026, 11.429130267351866, 42.599468529224396, 59.1132266074419, 66.82959794998169, 68.23792397975922, 63.216721415519714, 61.02728649973869, 66.69374763965607, 69.85051184892654, 62.31130599975586, 65.30749082565308, 59.734690859913826, 57.63467274606228, 52.347894832491875, 50.8361991494894, 47.437030747532845, 49.26881365478039, 48.51491130888462, 47.06813134253025, 45.43651029467583, 46.27515949308872, 46.437695771455765, 47.17410385608673, 48.53371649980545, 49.556826800107956, 48.93752083182335, 47.466281577944756, 45.68946652114391, 43.561329916119576, 43.64577658474445, 42.36217886209488, 38.91466945409775, 44.638013541698456, 49.69319388270378, 49.95939999818802, 46.82289630174637, 45.68883955478668, 39.690386429429054, 41.882591396570206, 40.36691352725029, 42.69901178777218, 41.608021929860115, 41.62381008267403, 41.00948944687843, 42.06900179386139, 40.97868449985981, 41.47686056792736, 43.31405818462372, 48.733984753489494, 46.859621331095695, 48.00393372774124, 48.76046173274517, 51.764884516596794, 49.48756791651249, 51.96813941001892, 50.50093933939934, 56.388848796486855, 53.81609424948692, 56.580521911382675, 49.857481867074966, 57.00492113828659, 53.899507373571396, 55.12222856283188, 55.155643969774246, 44.71225015819073, 46.377412006258965, 49.22589875757694, 54.478090927004814, 39.56995189189911, 32.71952748298645, 43.575400561094284, 48.97681452333927, 44.70860995352268, 47.06584386527538, 43.30857887864113, 53.09738181531429, 50.79501315951347, 54.0221381932497, 52.90433317422867, 53.646984323859215, 51.60655461251736, 51.94563701748848, 49.51181821525097, 51.219305992126465, 50.174206271767616, 49.990292340517044, 48.92813913524151, 48.9764953404665, 50.00447317957878, 46.28625109791756, 45.75031265616417, 44.28809031844139, 39.44515898823738, 40.22515453398228, 40.42541518807411, 38.23807016015053, 39.801059290766716, 37.65318654477596, 37.40021511912346, 42.25531719624996, 41.05543278157711, 43.07176038622856, 41.400055289268494, 42.05517053604126, 43.19653049111366, 42.327129542827606, 41.68122120201588, 41.79085671901703, 43.60421821475029, 42.0953343808651, 44.63269762694836, 44.6707221865654, 46.380482241511345, 47.6881592720747, 47.45737865567207, 48.919012024998665, 47.07883536815643, 49.27730239927769, 47.3347782343626, 51.194094344973564, 53.880968168377876, 53.307339549064636, 53.010260090231895, 53.22874076664448, 56.444295421242714, 55.932983458042145, 59.14784274995327, 59.76463705301285, 59.9403016269207, 55.4910633713007, 58.77718783915043, 58.22241760790348, 61.29760779440403, 67.41430297493935, 72.83987984061241, 71.86403900384903, 48.69824007153511, 0.5623951752204448, 0.18655943538760766, 1.1773511487990618, 0.0960106281854678, 23.04727379232645, 77.66080275177956, 55.37182576954365, 56.24118871986866, 41.055539175868034, 49.52939607203007, 39.45058889687061, 57.7997662872076, 16.1793627217412, 0.11071630666265264, 0.07770338124828413, 0.04419464552483987, 0.05221137296757661, 0.05313482732162811, 0.02505625998310279, 0.03340982599183917, 0.023830528880353086, 0.05178580693609547, 0.03657327499240637, 0.051942904756288044, 0.027167529115104116, 0.17370194953400642, 0.3387632517842576, 8.034014347940683, 64.63942587375641, 45.412309393286705, 41.97463385760784, 51.137978956103325, 58.99912253022194, 61.301289796829224, 84.22287583351135, 11.143506243824959, 0.5421740259043872, 0.28237507911399007, 0.0761663043522276, 11.706420388072729, 45.301799923181534, 63.13929297029972, 67.53724157810211, 68.47360253334045, 65.4935896396637, 62.22213998436928, 67.55362629890442, 69.91465240716934, 64.56612020730972, 65.90489476919174, 60.91567508876324, 59.64170604944229, 55.19200801849365, 53.08200404047966, 51.813882887363434, 51.52759864926338, 51.41654200851917, 49.92123864591122, 47.89537735283375, 48.312325179576874, 49.851888567209244, 49.36276361346245, 51.475404649972916, 52.43967890739441, 52.77155689895153, 51.747819632291794, 47.34507568180561, 45.97198136150837, 45.606083795428276, 43.22532154619694, 42.99786955118179, 48.25873665511608, 51.68924957513809, 52.97992251813412, 48.57685178518295, 47.858295142650604, 42.682672664523125, 44.17410783469677, 41.92215107381344, 44.87975277006626, 43.70724208652973, 43.43744896352291, 43.17378111183643, 41.885076463222504, 45.016059055924416, 42.47982054948807, 45.05785681307316, 50.8314798027277, 49.318693578243256, 51.4621851593256, 52.75938235223293, 55.215942934155464, 53.498556688427925, 55.768399089574814, 55.47358810901642, 58.097499310970306, 55.485865250229836, 56.4477114379406, 50.60024321079254, 57.83175677061081, 58.69614578783512, 57.68180921673775, 55.39489433169365, 47.647851034998894, 45.5259270966053, 51.30550816655159, 55.931079760193825, 40.347975343465805, 35.10560184717178, 44.58661749958992, 50.24875447154045, 47.34927825629711, 48.87088380753994, 45.703480169177055, 54.63213466107845, 53.81172828376293, 55.428917706012726, 53.73408704996109, 57.070851400494576, 54.13012459874153, 55.2282352745533, 53.045374006032944, 53.93009953200817, 53.48896220326424, 53.38531896471977, 51.59820646047592, 51.943737119436264, 52.01664760708809, 49.65864613652229, 47.65807628631592, 45.83835773169994, 40.28601586818695, 42.68444336950779, 43.8860946893692, 41.94468766450882, 42.27829076349735, 40.57426080107689, 40.51365785300732, 43.54228153824806, 42.77076333761215, 44.5947490632534, 44.080351665616035, 44.47637781500816, 45.44725611805916, 44.44450132548809, 44.942225217819214, 45.14349661767483, 45.99042557179928, 43.525972813367844, 47.22483113408089, 47.421937957406044, 49.40698564052582, 49.45661477744579, 51.00007675588131, 50.805682986974716, 50.148538649082184, 50.307145938277245, 48.748401179909706, 52.910694032907486, 55.87065540254116, 56.32905900478363, 56.09100557863712, 57.631849497556686, 58.73769275844097, 58.114640191197395, 60.50110973417759, 63.51687490940094, 62.41712272167206, 58.5850815474987, 62.970924004912376, 61.33429102599621, 61.94343253970146, 70.43399333953857, 72.67993122339249, 79.38698172569275, 56.556134819984436, 0.3838985657785088, 0.09610018314560875, 1.5666336100548506, 0.060280796606093645, 24.705219827592373, 87.87018612027168, 60.76954632997513, 67.06909909844398, 45.242333114147186, 51.20352543890476, 47.5245476514101, 66.60500720143318, 23.9421371743083, 0.12999528466025367, 0.034607233028509654, 0.017385262035531923, 0.06431839166907594, 0.08748985259444453, 0.02803912775561912, 0.09340309232356958, 0.09579354256857187, 0.19397396565182135, 0.09950559455319308, 0.21774437685962766, 0.12723483669105917, 0.35177185374777764, 0.48683854518458247, 12.86463813856244, 80.42690232396126, 54.91158686578274, 56.34350962936878, 62.65157014131546, 72.56558775901794, 67.11123883724213, 94.39811423420906, 12.681756801903248, 1.565447598695755, 0.7067190308589488, 0.1907850758288987, 15.757643301039934, 48.64804856479168, 66.05681821703911, 68.19432511925697, 69.05114874243736, 68.70724439620972, 64.09698218107224, 72.91076883673668, 72.36667603254318, 68.86658504605293, 71.59014970064163, 64.27561059594154, 63.87927666306496, 56.95514000952244, 55.28512962162495, 53.49857948720455, 53.37934948503971, 54.192623645067215, 52.80998423695564, 51.05730928480625, 51.849950551986694, 51.503393948078156, 50.868641808629036, 55.05230851471424, 55.519976019859314, 54.61950033903122, 54.40221659839153, 51.94077327847481, 47.843418940901756, 47.558840811252594, 45.83219826221466, 43.58149543404579, 51.039157658815384, 55.0574154406786, 57.93150521814823, 51.567690297961235, 51.48447096347809, 45.24362504482269, 47.64702267944813, 46.25688247382641, 47.606760039925575, 46.142675802111626, 47.00987286865711, 45.26788294315338, 45.592860504984856, 48.12950178980827, 45.99744379520416, 46.95544458925724, 55.152471140027046, 50.774228274822235, 54.39280830323696, 55.89705638587475, 57.51384682953358, 56.005365774035454, 58.83030518889427, 57.19128593802452, 62.50861041247845, 58.027868047356606, 63.330213725566864, 53.47620628774166, 61.161772683262825, 60.06763279438019, 57.21569202840328, 58.57299439609051, 49.35478404164314, 48.10985304415226, 52.92107507586479, 57.45052322745323, 41.822683811187744, 39.24756959080696, 45.59384845197201, 51.9974510371685, 45.378248021006584, 50.85460916161537, 44.50301818549633, 58.688371405005455, 55.897972136735916, 59.66733567416668, 57.18120127916336, 61.46846942603588, 56.95871941745281, 56.34714983403683, 55.59528797864914, 57.94484630227089, 57.439036443829536, 56.866091787815094, 56.17194123566151, 56.054177954792976, 56.26004330813885, 52.939051911234856, 51.2345165759325, 49.901487305760384, 42.74398237466812, 44.06313478946686, 45.87484337389469, 44.76999565958977, 44.759325832128525, 41.653076112270355, 42.327779307961464, 47.339641973376274, 43.88569191098213, 46.867372915148735, 47.11726650595665, 46.59081615507603, 48.34810025990009, 47.31759935617447, 48.361152559518814, 47.837422862648964, 48.842685520648956, 45.66655375063419, 48.8726507127285, 51.23360462486744, 51.14407762885094, 51.70358620584011, 54.406111389398575, 53.50958749651909, 53.200078904628754, 54.772658720612526, 52.5375122576952, 57.135105952620506, 58.634098917245865, 60.422309562563896, 60.42332410812378, 59.17664520442486, 62.103852331638336, 63.461964055895805, 65.65551415085793, 66.70896962285042, 65.64186528325081, 62.60663755238056, 65.43325647711754, 64.75680157542229, 67.23073482513428, 74.4581750035286, 80.79233631491661, 80.61831325292587, 54.13787618279457, 1.2905917223542929, 0.35534808528609574, 4.574164152145386, 0.17483268573414534, 29.01481367647648, 96.24015659093857, 68.52713406085968, 79.42069351673126, 58.879349157214165, 68.82965862751007, 60.08412390947342, 84.38502073287964, 29.90466322749853, 0.1886255745193921, 0.20489340706262738, 0.15295902587240562, 0.09568317778757773, 0.21283511450747028, 0.1364077819744125], [0.024198511673603207, 0.06406724147382192, 0.07493980883737095, 0.024139030392689165, 0.01680185418081237, 0.08082017884589732, 0.12693034834228456, 0.2352467126911506, 4.563367031514645, 48.58600169420242, 46.318123787641525, 41.46288491785526, 29.960896410048008, 53.23314853012562, 49.61276359856129, 78.91833767294884, 12.553260046988726, 0.3012106387177482, 0.6891573825851083, 0.13362278376007453, 3.614672888070345, 30.85367940366268, 52.577049136161804, 52.35685855150223, 62.22608037292957, 57.74650074541569, 61.6755735129118, 67.69555628299713, 64.14667591452599, 63.4285182505846, 54.36680629849434, 52.646775394678116, 51.982935816049576, 48.255704417824745, 49.540506675839424, 47.02496185898781, 45.795621424913406, 44.81555141508579, 45.1754605025053, 45.19970320165157, 47.57144473493099, 47.68885463476181, 48.66606719791889, 50.742028802633286, 51.632313430309296, 48.395179733633995, 46.99336655437946, 45.44859364628792, 44.74033445119858, 43.06872434914112, 44.44072052836418, 51.62037067115307, 54.31437291204929, 56.47336386144161, 59.000695645809174, 54.61549535393715, 48.299060091376305, 42.35384210944176, 42.77827933430672, 41.701515913009644, 45.3993558883667, 43.113926723599434, 40.714659467339516, 41.204601377248764, 40.9042426943779, 41.9899470359087, 44.27118502557278, 41.73794075846672, 47.166036888957024, 45.63727632164955, 47.236963883042336, 47.62664817273617, 46.750107407569885, 49.84187990427017, 52.031599804759026, 52.481514662504196, 51.37914441525936, 51.07546091079712, 52.40412421524525, 50.18570825457573, 50.50840213894844, 53.56129892170429, 55.193185955286026, 56.36535465717316, 52.875105142593384, 48.78040686249733, 51.390141025185585, 48.65339867770672, 24.474583603441715, 17.99568235874176, 30.725586377084255, 51.305306777358055, 50.71361392736435, 41.58339165151119, 47.22770377993584, 54.559505358338356, 52.264759093523026, 51.07000820338726, 50.832205563783646, 53.342719450592995, 53.107287883758545, 53.347693383693695, 51.92827954888344, 48.81891019642353, 49.24018979072571, 48.38230982422829, 45.47277934849262, 45.040119364857674, 44.88054312765598, 45.12301191687584, 45.252691358327866, 42.892345413565636, 42.2712117433548, 42.14899890124798, 40.98924793303013, 40.07450021803379, 40.52337393164635, 39.37551252543926, 40.65469108521938, 41.989035084843636, 40.72191707789898, 42.45850749313831, 41.52919515967369, 43.639423325657845, 44.65996116399765, 43.454396054148674, 42.34509117901325, 41.55257150530815, 42.35757730901241, 43.760762214660645, 42.86027513444424, 43.55202801525593, 44.886634200811386, 45.67971244454384, 47.12612763047218, 45.02028442919254, 46.58320136368275, 46.745768040418625, 49.33592185378075, 45.129783153533936, 47.89792701601982, 48.12908761203289, 48.97408626973629, 50.003283843398094, 53.996261581778526, 52.54296496510506, 53.75567369163036, 52.268429696559906, 54.854388535022736, 53.41404162347317, 56.35877341032028, 53.780516758561134, 59.00025486946106, 65.135238468647, 68.80681425333023, 71.34111106395721, 46.25300668179989, 0.47442778770346195, 0.18964153015986085, 0.8052518998738378, 0.03747193048184272, 32.59318046271801, 76.62722781300545, 53.76311369240284, 52.301510721445084, 38.48969265818596, 27.91439462453127, 47.60383419692516, 67.50821113586426, 23.898243829607964, 0.051799458742607385, 0.07838762656319886, 0.023662925959797576, 0.045136122935218737, 0.03314131696242839, 0.06150499888462946, 0.0624813609465491, 0.06963070700294338, 0.02572203509771498, 0.05032648485212121, 0.12369980177027173, 0.04108097236894537, 0.14246862003346905, 0.24872662295820192, 6.800220077857375, 61.57514110207558, 52.1995659917593, 47.88501150906086, 36.197739243507385, 60.80578878521919, 54.63264763355255, 90.24577304720879, 12.891579642891884, 0.5702168180141598, 1.06415985384956, 0.13102893310133368, 4.681069990620017, 31.460632234811783, 55.21186575293541, 55.68514555692673, 63.787169605493546, 58.00366714596748, 63.51214416325092, 68.59186738729477, 66.85186475515366, 64.33786645531654, 57.95417860150337, 54.633791372179985, 54.8768263310194, 49.53647509217262, 50.95343425869942, 49.430213794112206, 47.443403005599976, 49.59192931652069, 47.87977539002895, 48.6526121199131, 50.34853331744671, 50.861463993787766, 50.888997316360474, 51.56872384250164, 54.22470152378082, 51.328793317079544, 48.77380661666393, 46.19527257978916, 46.00540056824684, 45.56845061480999, 48.77865135669708, 53.18628564476967, 57.21438869833946, 59.98405247926712, 62.17203967273235, 56.49112790822983, 50.652418211102486, 44.77997772395611, 44.59451347589493, 44.83980551362038, 48.89018677175045, 45.28569258749485, 43.34556609392166, 43.907305151224136, 44.97455008327961, 44.48058798909187, 47.09162928164005, 42.615442872047424, 48.73328939080238, 48.238073363900185, 48.789423778653145, 48.76385875046253, 49.95322532951832, 52.65695884823799, 53.07161919772625, 53.944964334368706, 54.44677300751209, 52.801643684506416, 53.032572492957115, 50.41927792131901, 52.06247694790363, 55.27327425777912, 57.038488537073135, 58.12394589185715, 54.590838477015495, 52.03099563717842, 53.82475398480892, 51.97990357875824, 28.692391477525234, 21.494363620877266, 33.11879485845566, 50.56094191968441, 52.337046414613724, 44.39397543668747, 49.4596242159605, 55.68422220647335, 53.01713392138481, 53.397231325507164, 53.93905185163021, 54.036607816815376, 53.61516863107681, 53.76610033214092, 54.56512525677681, 51.64327584207058, 52.68859975039959, 50.027131363749504, 50.96875883638859, 47.11753249168396, 46.2621907889843, 47.532481625676155, 46.8281552195549, 43.441028371453285, 45.28283134102821, 44.84818026423454, 42.91952535510063, 42.18678407371044, 40.386410281062126, 41.59327492117882, 42.49628126621246, 44.56840507686138, 42.34631471335888, 44.91634480655193, 44.619284346699715, 46.92684732377529, 47.428207620978355, 45.054277405142784, 44.74216975271702, 44.2899826169014, 44.64001603424549, 44.97346714138985, 46.24737158417702, 46.0358065366745, 46.58641219139099, 48.67397077381611, 49.331392496824265, 48.252136409282684, 48.716235905885696, 48.71518716216087, 51.452035903930664, 48.466456308960915, 50.47562509775162, 49.975731521844864, 52.10774391889572, 52.87977509200573, 56.11157767474651, 55.03155402839184, 54.86620210111141, 55.282959938049316, 57.90910542011261, 56.64677135646343, 57.87646897137165, 56.36685937643051, 61.033324375748634, 69.506356716156, 70.52520364522934, 78.28942582011223, 53.47599729895592, 0.8080956316553056, 0.2616877423133701, 1.9085170584730804, 0.008005153649719432, 36.4595527946949, 88.01758781075478, 61.516597643494606, 63.27564865350723, 45.33998027443886, 37.21437469124794, 58.08426842093468, 77.5639459490776, 32.029210925102234, 0.07877480500610545, 0.0826642822357826, 0.01572463796037482, 0.024184329231502488, 0.03381103844731115, 0.08450635956251062, 0.23095899901818484, 0.14750723872566596, 0.0794137644697912, 0.10174170776735991, 0.197955617622938, 0.2629856101702899, 0.29686925292480737, 0.424394536530599, 9.806887116283178, 79.43732142448425, 57.54972070455551, 57.777404487133026, 38.493222668766975, 72.1313926577568, 60.196909457445145, 98.62376868724823, 14.014618881046772, 1.1019998858682811, 1.8135302304290235, 0.2157821977743879, 7.974344249814749, 36.49045653641224, 59.25275132060051, 59.453080371022224, 65.67625343799591, 61.22591704130173, 66.04118585586548, 73.5653369128704, 69.70510125160217, 69.16945919394493, 59.57148961722851, 56.021214723587036, 57.01239913702011, 53.57058182358742, 54.39925655722618, 52.01944425702095, 49.94015783071518, 50.87966501712799, 48.86278264224529, 50.60459017753601, 53.21341998875141, 52.532226741313934, 51.9148700684309, 53.757364600896835, 57.21324875950813, 53.46400894224644, 52.42836691439152, 48.22155945003033, 50.08135825395584, 47.81056210398674, 50.20873121917248, 56.8751884996891, 58.80130514502525, 61.90722808241844, 64.54096555709839, 58.838075771927834, 53.60007964074612, 47.98744261264801, 47.379577830433846, 48.88298235833645, 51.830810979008675, 48.308399990200996, 45.24713225662708, 48.64018298685551, 46.13075204193592, 48.77764441072941, 49.670721888542175, 47.3706217110157, 52.59263589978218, 50.628973469138145, 52.04584524035454, 52.60996297001839, 53.14090467989445, 55.820296704769135, 56.5652809292078, 57.4357458204031, 56.6610623896122, 55.04067353904247, 58.22744473814964, 54.37827788293362, 53.418567180633545, 58.85818049311638, 60.69444715976715, 61.63429252803326, 57.366764321923256, 53.45042087137699, 56.33087910711765, 53.382594510912895, 30.96003569662571, 27.873917296528816, 37.67827659845352, 51.69648438692093, 55.51420412957668, 44.570019990205765, 50.183329582214355, 59.514523074030876, 59.426120817661285, 55.23538649082184, 57.01009266078472, 57.49924421310425, 56.90160848200321, 57.87343293428421, 58.00348475575447, 53.4529173374176, 54.172222539782524, 54.20544795691967, 52.84231670200825, 49.639335572719574, 48.757034316658974, 50.16316406428814, 50.97667761147022, 47.09360517561436, 47.75690138339996, 48.24002645909786, 46.46956466138363, 45.82738012075424, 44.53106068074703, 44.923720210790634, 46.53106436133385, 47.48723365366459, 44.59675535559654, 46.345581114292145, 44.52344208955765, 49.57986116409302, 50.30108526349068, 47.06956006586552, 47.66390137374401, 46.19319409132004, 48.23228247463703, 47.397319078445435, 48.85149724781513, 49.08281363546848, 49.80186425149441, 51.07552170753479, 53.019349202513695, 50.46455629169941, 53.444086611270905, 51.28400132060051, 55.386272594332695, 51.04072317481041, 54.27110843360424, 52.860700115561485, 55.19508205354214, 56.105653792619705, 59.616805985569954, 58.55534814298153, 59.490458965301514, 57.97120928764343, 61.878691613674164, 59.9126885086298, 64.47162687778473, 60.33660136163235, 66.27980545163155, 72.79920682311058, 74.65350732207298, 77.98701524734497, 50.12245684862137, 1.1035453341901302, 0.34922711842227727, 4.703570958226919, 0.12066326002241112, 39.83795911073685, 95.03565162420273, 69.58076432347298, 72.785504758358, 54.429461136460304, 41.18513502180576, 68.23245987296104, 90.03735423088074, 38.40201236307621, 0.2804993453901261, 0.2019943407503888, 0.14059566194191575, 0.1585242577129975, 0.13826367066940293, 0.1757536019431427], [0.04792894338606857, 0.07350323357968591, 0.025730714514793362, 0.07624448218848556, 0.0776440094341524, 0.005958960200587171, 0.06082300969865173, 0.11943240810069256, 2.2062822617590427, 44.37284477055073, 44.9367269128561, 41.24522499740124, 27.461629919707775, 48.54839511215687, 43.167952224612236, 79.47393625974655, 16.235793493688107, 0.179530703171622, 1.5388671937398612, 0.02943192743259715, 0.29969045310281217, 12.33189532533288, 50.992534160614014, 65.98304137587547, 68.06625679135323, 68.09445887804031, 70.1362869143486, 63.332505002617836, 64.97116327285767, 55.83654843270779, 51.993328258395195, 48.962401896715164, 47.61139199137688, 45.96901372075081, 47.73389741778374, 47.45784603059292, 47.375211864709854, 47.49208599328995, 47.595740631222725, 48.08873377740383, 48.172568678855896, 50.68311296403408, 53.16870018839836, 50.80184519290924, 52.315756157040596, 48.36385801434517, 44.938471019268036, 42.74671822786331, 44.40971419215202, 46.51771567761898, 53.44299606978893, 54.49710890650749, 56.14639900624752, 57.79356122016907, 57.78701797127724, 54.48836177587509, 51.36964872479439, 45.65114177763462, 45.448574647307396, 40.708819180727005, 43.9566683024168, 41.70212768018246, 40.92342406511307, 40.529195219278336, 40.98163694143295, 42.10080988705158, 44.099259451031685, 43.60426381230354, 44.65535581111908, 47.14720509946346, 44.54013079404831, 45.94437584280968, 47.22841814160347, 47.326715067029, 50.28689302504063, 48.25818568468094, 51.56267836689949, 50.52605979144573, 49.88398164510727, 50.38227170705795, 52.04845190048218, 52.95605219900608, 55.35324476659298, 54.13921371102333, 47.748070657253265, 43.51699009537697, 53.13802823424339, 49.7574408352375, 38.486250042915344, 42.43657507002354, 39.48528103530407, 54.08011548221111, 50.2364469319582, 49.94996130466461, 52.53572255373001, 54.8816292732954, 52.26409412920475, 49.09519337117672, 48.848199024796486, 51.05273813009262, 48.69819067418575, 49.0473273396492, 49.8093194514513, 48.3097755163908, 47.60605327785015, 47.322843074798584, 45.01680001616478, 42.49976187944412, 44.12492707371712, 44.87509422004223, 44.04844477772713, 43.223775029182434, 42.56107158958912, 40.84144726395607, 40.34875430166721, 38.833125829696655, 38.58006700873375, 39.784062802791595, 44.04992289841175, 43.124440759420395, 41.98841191828251, 43.37812654674053, 42.68820516765118, 44.44935366511345, 45.257311910390854, 41.33345626294613, 41.09707094728947, 40.704650804400444, 41.08667850494385, 39.47760924696922, 41.053282096982, 42.070457115769386, 43.80886763334274, 45.23214966058731, 45.70106349885464, 45.54280199110508, 46.17162644863129, 45.39866432547569, 46.47428780794144, 44.37761731445789, 47.16306544840336, 45.25854304432869, 46.7792784422636, 48.32699619233608, 50.88517092168331, 48.56215797364712, 50.40325038135052, 50.58591417968273, 53.38117718696594, 49.712964221835136, 51.69900745153427, 57.898184806108475, 66.53978750109673, 67.0868669450283, 73.95062863826752, 65.94141840934753, 42.7449095249176, 0.43345013342332095, 0.5204438825603575, 0.7877873838879168, 0.19311528594698757, 40.444702953100204, 72.0739321410656, 51.42340064048767, 49.329059422016144, 39.31932874023914, 26.06899704784155, 39.160938039422035, 61.48003600537777, 30.73293138295412, 0.16815320821478963, 0.03544354811310768, 0.013920609617343871, 0.019037798556382768, 0.035869232888217084, 0.0463484953797888, 0.01900251128972741, 0.02373381590587087, 0.08224036748288199, 0.09406493962160312, 0.03434236423345283, 0.009543679589114618, 0.01892680666060187, 0.1361655895016156, 3.6844212329015136, 58.30006264150143, 51.80317126214504, 45.74045978486538, 29.527698755264282, 58.26690562069416, 47.04960733652115, 90.41560873389244, 18.054651394486427, 0.33635305298957974, 1.7505495599471033, 0.06720950215822086, 0.6722924031782895, 12.154376450926065, 53.3906576782465, 69.37733843922615, 70.44726222753525, 71.0151569545269, 71.81242257356644, 64.75735634565353, 65.45041635632515, 58.35271641612053, 53.631291165947914, 52.71346561610699, 49.740128964185715, 48.030897080898285, 50.5947221070528, 49.32071506977081, 49.74895969033241, 48.575970232486725, 51.33773423731327, 50.77669434249401, 50.49051649868488, 53.45719590783119, 54.69160906970501, 54.40026730298996, 53.99144344031811, 52.653763219714165, 45.60333654284477, 44.49706390500069, 45.88017448782921, 49.35957558453083, 54.09645080566406, 58.58264207839966, 59.44143019616604, 59.05300743877888, 60.28936609625816, 57.1120335906744, 54.089026004076004, 49.08100113272667, 47.638632729649544, 44.07889634370804, 47.03886531293392, 44.85403575003147, 44.29530993103981, 42.39819712936878, 42.95027330517769, 44.61700066924095, 45.737324953079224, 45.66903501749039, 46.75507374107838, 46.65783315896988, 48.09054248034954, 50.06161831319332, 49.27767477929592, 48.719560727477074, 52.59155675768852, 50.89267551898956, 51.18174880743027, 52.991033121943474, 53.53073336184025, 52.527503594756126, 54.26881715655327, 53.7017697840929, 57.553539499640465, 54.71146680414677, 48.76817151904106, 46.532846465706825, 56.281470358371735, 51.118136420845985, 41.224641501903534, 44.704452976584435, 40.92266030609608, 55.01349739730358, 52.96905130147934, 51.04718662798405, 53.41860517859459, 55.84095999598503, 53.30580063164234, 49.859469160437584, 52.20065653324127, 52.99595385789871, 50.806556940078735, 52.788754776120186, 50.78949585556984, 51.13836273550987, 51.25247821211815, 48.7055204808712, 47.908057272434235, 44.44358177483082, 47.43841007351875, 46.95740148425102, 46.24355658888817, 44.7260358184576, 45.46801820397377, 44.877716079354286, 44.151130467653275, 40.6298404186964, 42.744320556521416, 42.47632093727589, 45.44836565852165, 46.02756857872009, 44.19366538524628, 43.70452903211117, 45.298509299755096, 44.35334801673889, 46.80200882256031, 43.3413141220808, 43.39649096131325, 43.98758724331856, 44.36022184789181, 42.234129533171654, 44.18741472065449, 44.391193985939026, 46.15878313779831, 48.035802617669106, 48.97938318550587, 47.25809834897518, 48.42114754021168, 48.41037131845951, 48.532724753022194, 49.18892294168472, 47.89395622909069, 46.9012138992548, 49.13574479520321, 51.85901306569576, 53.382963091135025, 51.586202904582024, 54.28090050816536, 52.32456788420677, 55.96516013145447, 51.754115894436836, 54.394415616989136, 60.94410136342049, 69.19979676604271, 69.97414201498032, 76.81648805737495, 69.82427805662155, 48.56593877077103, 0.42435336217749864, 0.4995126463472843, 1.7012544488534331, 0.08143328930600546, 45.05132496356964, 79.68946069478989, 58.18957217037678, 61.70015059411526, 48.97926539182663, 30.480129048228264, 51.81797906756401, 71.87407806515694, 36.487219110131264, 0.2768574486253783, 0.03249487293942366, 0.04860222717979923, 0.054997970510157757, 0.06803503012633882, 0.04686806183599401, 0.153078407747671, 0.20622872369131073, 0.17180030001327395, 0.1657245447859168, 0.21578216808848083, 0.1840351684950292, 0.20736824691994116, 0.31319071305915713, 6.392921358346939, 73.84182527661324, 61.992073729634285, 54.20686528086662, 35.27607209980488, 69.47678670287132, 52.974184826016426, 99.26967322826385, 18.609499521553516, 0.8933860925026238, 3.228027722798288, 0.177416754886508, 1.9076438178308308, 15.822771806269884, 58.942163586616516, 72.8506788611412, 74.41689401865005, 72.9571795463562, 76.1826440691948, 66.78891733288765, 71.44719377160072, 61.26545391976833, 56.40614926815033, 54.86977010965347, 53.58895763754845, 52.29168064892292, 52.168578654527664, 52.3106150329113, 51.53955660760403, 52.218633368611336, 52.34873078763485, 51.991166174411774, 53.14410790801048, 58.13298940658569, 58.484934121370316, 56.18392579257488, 56.55748374760151, 54.31738615036011, 48.46188895404339, 46.507224440574646, 49.14942406117916, 51.90415844321251, 57.85350300371647, 61.80492617189884, 62.156673297286034, 62.98396110534668, 65.05611911416054, 59.59656447172165, 56.95504501461983, 51.12789049744606, 51.0475742071867, 47.48954772949219, 48.72531361877918, 45.91029167175293, 48.42381879687309, 44.257129579782486, 45.85148222744465, 47.46195361018181, 48.00094708800316, 49.239802211523056, 49.21398639678955, 50.57323046028614, 50.749453604221344, 52.21802920103073, 51.45044758915901, 52.2514484077692, 55.94796225428581, 54.91902306675911, 54.071113765239716, 57.611680179834366, 55.07265642285347, 54.11035045981407, 57.40559443831444, 56.37012340128422, 60.829879492521286, 57.58828103542328, 51.45030319690704, 49.20946843922138, 57.26505517959595, 54.112292155623436, 43.92530098557472, 48.54186326265335, 42.946283519268036, 57.08693213760853, 54.976396188139915, 53.205284625291824, 56.7344668507576, 60.49246519804001, 54.97101567685604, 54.43207539618015, 53.749107643961906, 56.26500964164734, 54.2257958650589, 54.035175293684006, 54.197928160429, 52.96645604074001, 54.691312685608864, 52.090580239892006, 50.58384709060192, 47.10707165300846, 48.098066076636314, 52.93491393327713, 49.51217159628868, 46.80051550269127, 47.901567220687866, 47.6083217561245, 48.45280364155769, 44.21104945242405, 46.054436936974525, 44.78155083954334, 49.450063928961754, 49.197293892502785, 47.0882398635149, 45.959510430693626, 48.32476571202278, 48.43884319067001, 51.58674247562885, 45.52572190761566, 44.32396039366722, 46.746771186590195, 48.45968887209892, 45.10374315083027, 46.853986233472824, 45.964328572154045, 48.730941116809845, 50.87439849972725, 51.28705255687237, 50.23733228445053, 52.24988289177418, 51.81973837316036, 52.47861921787262, 51.94605119526386, 51.08354687690735, 50.13329766690731, 52.723497077822685, 55.022814497351646, 57.88257524371147, 53.761608973145485, 57.08366431295872, 56.55311778187752, 61.241891384124756, 55.98670117557049, 57.3786348849535, 64.62369471788406, 73.37591707706451, 72.27469816803932, 80.02319678664207, 71.71225994825363, 49.96479570865631, 0.7570823596324772, 0.7621815078891814, 4.746983628720045, 0.2369488135445863, 49.902509450912476, 87.82931551337242, 67.80711829662323, 70.02816751599312, 57.130534797906876, 38.815057799220085, 60.86532399058342, 85.10166227817535, 47.664266154170036, 0.37625474156811833, 0.21957087650662288, 0.12433761832653545, 0.1945535681443289, 0.15181178430793807, 0.1578968163812533], [0.06365704160998575, 0.04097707169421483, 0.04398255085106939, 0.05199306280701421, 0.07216264770249836, 0.03426349619985558, 0.10437876626383513, 0.10531111154705286, 5.486233485862613, 46.12015821039677, 38.238849118351936, 43.94219487905502, 28.512165248394012, 48.67683582007885, 44.636007249355316, 75.81103160977364, 30.52293185144663, 0.081549806491239, 1.7626078566536307, 0.049050488087232225, 0.23362498643109575, 2.447098377160728, 48.19320537149906, 70.66740721464157, 64.84154462814331, 65.4867272078991, 61.58929534256458, 57.20433823764324, 50.936840549111366, 51.182527765631676, 47.70030342042446, 48.13228704035282, 47.053479328751564, 48.4310308098793, 48.652118146419525, 51.40019528567791, 50.487868040800095, 52.19360031187534, 52.02643968164921, 53.75117853283882, 54.271549209952354, 53.74838948249817, 51.822364032268524, 51.06860227882862, 47.879999577999115, 45.00374771654606, 42.84850336611271, 43.16391684114933, 44.77483280003071, 52.127856239676476, 55.3671520203352, 58.07695001363754, 57.32143275439739, 55.443554520606995, 55.21930195391178, 58.04123193025589, 52.49123074114323, 47.717208713293076, 44.734809547662735, 41.487222611904144, 42.919871136546135, 45.16961641609669, 42.43444338440895, 40.40249101817608, 38.86379778385162, 41.9283751398325, 43.77530783414841, 45.469093546271324, 43.2175699621439, 46.880569607019424, 44.21715572476387, 44.524091854691505, 44.88251902163029, 46.124102398753166, 47.94958904385567, 47.49117024242878, 49.15846757590771, 49.88669469952583, 51.2374272197485, 51.571524292230606, 49.796878919005394, 50.76901875436306, 53.056496009230614, 54.597818702459335, 54.63924027979374, 53.148268684744835, 55.08131615817547, 48.73645082116127, 46.645738407969475, 47.17010647058487, 47.63960927724838, 53.49071390926838, 51.385767459869385, 46.09502635896206, 50.293151289224625, 51.756866946816444, 51.54927268624306, 47.810087129473686, 48.578113317489624, 50.85086636245251, 50.419190526008606, 47.85968206822872, 47.08438687026501, 48.729903772473335, 45.1778581738472, 44.343172162771225, 41.62278413772583, 43.57400223612785, 41.33015803992748, 43.74219261109829, 42.933094426989555, 42.769900783896446, 39.8053340613842, 38.76145027577877, 37.7412886172533, 39.82082962989807, 39.25673469901085, 39.62248407304287, 44.072444289922714, 42.925574630498886, 41.39502435922623, 41.797722950577736, 45.73997721076012, 49.36719037592411, 50.909501016139984, 47.17088922858238, 43.26086103916168, 41.250145733356476, 39.925536811351776, 41.01585030555725, 40.993739292025566, 42.318390011787415, 42.666979506611824, 43.66091877222061, 43.98081600666046, 44.09694917500019, 44.287904128432274, 46.00134618580341, 42.66916058957577, 42.78301388025284, 44.70657326281071, 46.38287611305714, 45.6694757938385, 45.62856338918209, 45.86998723447323, 46.29118323326111, 47.654162496328354, 48.376469537615776, 49.138450250029564, 51.68131560087204, 55.69274514913559, 62.22535461187363, 69.60029527544975, 69.7921621799469, 75.07128730416298, 70.42212277650833, 54.49655033648014, 1.4602564182132483, 0.7189344253856689, 1.1357385129667819, 0.22679587709717453, 47.862102538347244, 69.44868341088295, 59.03711289167404, 50.44299244880676, 27.767574302852154, 36.568394154310226, 49.032162353396416, 65.40037304162979, 26.496760994195938, 0.4325232800329104, 0.11226442671613768, 0.0472831932711415, 0.056405275463475846, 0.01705923099507345, 0.057626809721114114, 0.03404225455597043, 0.09579976918757893, 0.02195497141656233, 0.0764600389811676, 0.10395295903435908, 0.04308463008783292, 0.16114608733914793, 0.2142817829735577, 7.83795484341681, 61.17500737309456, 45.68502075970173, 56.83614939451218, 35.32189764082432, 55.7858781516552, 52.992629036307335, 84.18260559439659, 31.964948773384094, 0.019516793654474895, 1.9256683881394565, 0.04991942427295726, 0.21629387891152874, 2.4894057819619775, 53.42981457710266, 74.68766748905182, 67.46116206049919, 66.08856931328773, 62.02382102608681, 60.48228934407234, 52.79202260077, 53.75036157667637, 51.102367267012596, 51.69326215982437, 49.76778008043766, 51.65806844830513, 51.28865607082844, 51.528054624795914, 51.94112665951252, 53.81813853979111, 55.9835397452116, 55.315759778022766, 56.514287665486336, 56.76659792661667, 54.19764697551727, 54.87312152981758, 51.160599142313, 47.39896439015865, 45.639115422964096, 45.108378902077675, 46.51410587131977, 53.503272235393524, 57.77599096298218, 60.3341580927372, 58.589850291609764, 57.91539028286934, 58.82682077586651, 60.04041485488415, 56.68540768325329, 49.20119248330593, 46.294086277484894, 43.849362060427666, 46.47598631680012, 48.17553251981735, 44.224842712283134, 41.930054649710655, 42.936540842056274, 42.84727603197098, 46.344904750585556, 46.04807607829571, 45.58019198477268, 49.38898980617523, 47.04635851085186, 47.816972360014915, 48.84077042341232, 47.88953706622124, 49.59450177848339, 50.90750232338905, 50.887515395879745, 52.732783779501915, 53.98739665746689, 52.064863219857216, 51.361087784171104, 52.8789771348238, 54.355216920375824, 58.515229895710945, 56.917157247662544, 56.50001563131809, 54.96764525771141, 48.77424739301205, 44.77517478168011, 44.68632414937019, 46.140418723225594, 52.869747430086136, 53.93134206533432, 48.58072757720947, 53.343661800026894, 55.85637576878071, 53.55972200632095, 49.99615542590618, 51.575305089354515, 52.92696475982666, 51.73619605600834, 51.167073994874954, 49.80952464044094, 52.183869034051895, 49.70096066594124, 46.77414111793041, 44.26997669041157, 45.72390027344227, 45.904603376984596, 46.112345829606056, 44.539655819535255, 43.8881503790617, 43.17528963088989, 41.035271063447, 39.67715933918953, 41.269783079624176, 42.01766274869442, 43.86806845664978, 49.461736902594566, 44.75877866148949, 43.60717825591564, 44.55310709774494, 47.15455770492554, 51.752014607191086, 55.302346497774124, 50.63450217247009, 45.272207111120224, 42.97800041735172, 42.489962205290794, 43.451557606458664, 43.22209171950817, 44.912795796990395, 45.63471145927906, 47.06652782857418, 46.265413016080856, 47.77474142611027, 47.65609659254551, 46.430947333574295, 46.46284282207489, 46.12239629030228, 47.679735124111176, 48.41938443481922, 47.13784620165825, 46.744369715452194, 49.72421921789646, 49.70274277031422, 51.48741200566292, 50.314821526408195, 52.17215046286583, 55.056986063718796, 60.679118782281876, 65.69649115204811, 72.73673057556152, 72.97823801636696, 78.428665548563, 73.15290704369545, 62.62987710535526, 1.7974465247243643, 0.6180794653482735, 2.412510495632887, 0.08717126343981363, 53.744449093937874, 74.90058526396751, 66.57806664705276, 61.80195093154907, 37.215081453323364, 48.38781572878361, 62.58552968502045, 74.30835664272308, 37.60900631546974, 0.36308559821918607, 0.010947117953037377, 0.07231917406897992, 0.05396713851951063, 0.03354173531988636, 0.04603009176207706, 0.20680402172729373, 0.19851855147862807, 0.1313524946453981, 0.218057073361706, 0.16771480673924088, 0.2825067361118272, 0.3920185816241428, 0.4130533622810617, 10.850374773144722, 73.55639979243279, 52.71774798631668, 60.1369334757328, 38.712558299303055, 70.30266478657722, 57.8398959338665, 92.25731670856476, 35.056390687823296, 0.1697029609931633, 3.318009269423783, 0.2288664988009259, 0.3246235573897138, 4.558133762329817, 58.71171735227108, 78.35673540830612, 71.83771401643753, 70.9600143134594, 65.20157530903816, 62.34260872006416, 55.39134532213211, 56.73928119242191, 51.637758538126945, 54.75196123123169, 52.8463900834322, 52.52596467733383, 53.77506785094738, 55.68864516913891, 53.644970431923866, 55.11758141219616, 57.237715646624565, 57.96645574271679, 59.3474156409502, 60.39407707750797, 58.0398716032505, 56.03690028190613, 52.60592758655548, 48.48948687314987, 46.81391358375549, 47.29924634099007, 48.251794427633286, 57.1368994563818, 60.96016310155392, 63.33196923136711, 60.84881007671356, 60.501664504408836, 61.49544037878513, 62.47844383120537, 57.58792765438557, 51.537899896502495, 49.33277942240238, 47.90410928428173, 48.97669292986393, 48.67986045777798, 48.9950155466795, 45.20916469395161, 45.420490354299545, 46.64617918431759, 48.20128753781319, 47.42854580283165, 48.585712909698486, 52.247204035520554, 50.20087704062462, 48.77901993691921, 51.67364001274109, 51.80711545050144, 53.12638185918331, 54.032070860266685, 55.548128709197044, 56.17522805929184, 57.25687801837921, 54.7350787371397, 54.131712913513184, 55.844915583729744, 57.63259045779705, 60.67727588117123, 57.974743098020554, 59.84496474266052, 61.0955536365509, 49.37269248068333, 44.100889563560486, 44.77080501616001, 46.37319043278694, 55.97521059215069, 58.177496418356895, 50.641793981194496, 55.89082472026348, 58.324920907616615, 58.18997494876385, 51.754096895456314, 54.062837809324265, 56.50142155587673, 56.60955235362053, 52.80382476747036, 53.26291233301163, 54.77524258196354, 49.96409274637699, 50.71956820785999, 48.35655860602856, 48.5196952521801, 48.71068820357323, 50.877259746193886, 46.270599737763405, 47.59303517639637, 44.864792972803116, 42.125200778245926, 42.298486679792404, 45.11981628835201, 43.96720893681049, 45.90485796332359, 51.83272607624531, 48.401886373758316, 46.18516132235527, 46.34792558848858, 50.908900648355484, 54.43931020796299, 56.86720512807369, 51.46797224879265, 48.532143384218216, 45.63709773123264, 44.78874385356903, 47.68977798521519, 46.51816785335541, 48.170467391610146, 46.95545218884945, 49.0389221906662, 49.56626549363136, 50.47122873365879, 51.157418712973595, 51.68646052479744, 47.838179022073746, 48.88887584209442, 50.6234485656023, 53.16468380391598, 50.60008741915226, 50.195146948099136, 52.88570657372475, 53.13483640551567, 54.70063358545303, 53.86866822838783, 56.17349915206432, 58.979036808013916, 62.963522002100945, 68.90365585684776, 76.47348046302795, 78.25163304805756, 83.14000234007835, 72.90588229894638, 63.267760276794434, 2.402912210673094, 1.1353286099620163, 4.337253514677286, 0.3271961084101349, 58.36558632552624, 84.72694918513298, 73.03105518221855, 71.70173451304436, 42.059779688715935, 47.87127144634724, 66.67806968092918, 85.85539743304253, 46.565885692834854, 0.6777974765282124, 0.1912980928318575, 0.14260054420446977, 0.24805655266391113, 0.14872727013425902, 0.13583573454525322], [0.09728846547659487, 0.027721885599021334, 0.1424648053944111, 0.044810346080339514, 0.10358965548221022, 0.04444636346306652, 0.08830321676214226, 0.35718044789973646, 7.347218776121736, 50.807867869734764, 48.09586599469185, 34.111996963620186, 28.639441318809986, 48.16547065973282, 42.110586762428284, 69.37499016523361, 51.24093063175678, 0.7820046879351139, 0.35198292054701596, 0.166614513436798, 0.1884054535184987, 0.7830436946824193, 53.1181401014328, 73.54091182351112, 63.611102253198624, 59.031208008527756, 50.03646366298199, 52.63349510729313, 50.40722116827965, 51.04086756706238, 51.14633850753307, 52.12951295077801, 51.204403191804886, 54.94162045419216, 53.190123438835144, 55.787994638085365, 54.15082968771458, 55.5198772251606, 55.02201274037361, 55.3403140604496, 52.30956628918648, 53.48608575761318, 51.28112107515335, 50.16130216419697, 46.25739544630051, 45.35608761012554, 41.09063409268856, 45.56850381195545, 52.19112664461136, 57.68550641834736, 57.30543941259384, 53.189979046583176, 51.25882387161255, 57.42372326552868, 57.24260598421097, 60.142241790890694, 54.383859783411026, 49.61396053433418, 43.44288267195225, 43.71546484529972, 45.149830877780914, 48.26870732009411, 40.26087261736393, 40.07368706166744, 39.58417072892189, 40.47276824712753, 40.298445001244545, 41.78592078387737, 42.86567844450474, 43.701318204402924, 45.33477455377579, 44.35074895620346, 45.68437099456787, 45.252159386873245, 45.685343742370605, 49.699243158102036, 50.76573193073273, 49.00125481188297, 48.97206097841263, 49.175391867756844, 49.057081416249275, 53.277298361063, 55.06265535950661, 53.78943867981434, 54.04157035052776, 54.89355683326721, 57.79841735959053, 48.29057514667511, 38.37871961295605, 32.86580063402653, 37.35904052853584, 50.096796825528145, 54.24485184252262, 50.28882712125778, 54.98696342110634, 52.85427466034889, 49.912096336483955, 50.10399743914604, 47.885908260941505, 48.48241165280342, 49.58178386092186, 48.08000944554806, 49.12349425256252, 47.64206014573574, 45.63610218465328, 43.78391437232494, 44.167594984173775, 42.40159794688225, 43.34199048578739, 41.489255502820015, 40.285453498363495, 41.10999405384064, 39.6002172678709, 40.376804396510124, 39.1111721098423, 37.953397035598755, 38.54960024356842, 43.03673006594181, 45.0843907892704, 41.08070522546768, 43.501654118299484, 46.5340282022953, 53.3048202842474, 54.51874874532223, 58.07508431375027, 57.01205715537071, 53.355916142463684, 45.252235382795334, 41.73066034913063, 39.5520206540823, 42.082863450050354, 40.6035952270031, 41.96014903485775, 44.37074728310108, 44.3183670938015, 43.25972110033035, 45.143055841326714, 44.592203199863434, 43.97618405520916, 46.14450730383396, 46.9650162756443, 44.67170633375645, 48.79502087831497, 44.77775104343891, 47.24122725427151, 43.95517498254776, 47.75515727698803, 45.641995668411255, 50.74676714837551, 49.86766152083874, 60.57924494147301, 63.10778886079788, 73.8739563524723, 72.75112420320511, 76.62332162261009, 71.00691139698029, 79.42387774586678, 2.5267307041212916, 0.36826469062361866, 0.7952654419932514, 0.6540699466131628, 54.93690870702267, 72.23696619272232, 58.0964657664299, 42.99063853919506, 19.386018253862858, 25.54177913814783, 47.79756300151348, 63.55435609817505, 29.30103711783886, 0.7326137507334352, 0.08740745935938321, 0.035226833570050076, 0.03884497047693003, 0.052296096546342596, 0.0647810242662672, 0.0929003614874091, 0.03399061220989097, 0.11323355283821002, 0.05275102193991188, 0.05961076712992508, 0.15632309223292395, 0.1251224469160661, 0.4815494961803779, 9.940475597977638, 62.00937420129776, 54.52268913388252, 38.79423871636391, 29.960316941142082, 53.59906509518623, 50.72612285614014, 78.45667764544487, 56.98566757142544, 0.8834371576085687, 0.632965344702825, 0.3116176271578297, 0.24658143025590107, 1.2189384922385216, 57.124462723731995, 75.63056409358978, 64.54778999090195, 62.15401344001293, 52.94681869447231, 55.447285920381546, 51.86462536454201, 53.739733546972275, 50.780900716781616, 54.74672511219978, 53.57930235564709, 56.01826228201389, 55.34500680863857, 57.011243999004364, 57.8396375477314, 58.37229296565056, 57.18818910419941, 60.08084088563919, 54.40806068480015, 55.50943538546562, 52.26070091128349, 53.05437192320824, 47.07527495920658, 46.374231576919556, 44.71507340669632, 48.851010873913765, 55.66245697438717, 57.92459338903427, 60.67079342901707, 56.74556985497475, 52.92760692536831, 59.05531011521816, 58.077064007520676, 61.05511240661144, 56.191088408231735, 51.63776993751526, 47.52088084816933, 45.26072412729263, 49.47277911007404, 50.49976520240307, 45.22500604391098, 42.52268984913826, 40.70913076400757, 44.50334116816521, 43.2415808737278, 44.8839857429266, 44.84050467610359, 45.929761826992035, 48.53196859359741, 47.90544681251049, 46.97844095528126, 47.97855868935585, 49.67558182775974, 51.16483971476555, 52.0242054015398, 51.22575044631958, 51.11638471484184, 50.62740795314312, 51.463252902030945, 53.41421261429787, 57.069145292043686, 56.57592795789242, 57.42954455316067, 57.66353979706764, 59.42924425005913, 47.99505740404129, 38.19781892001629, 33.35318148136139, 36.41320288181305, 51.99848458170891, 54.23743464052677, 53.470559790730476, 55.514755100011826, 56.00063502788544, 52.148272544145584, 51.87793605029583, 51.01954311132431, 53.08185584843159, 51.48784138262272, 51.40478543937206, 49.45110127329826, 50.60401640832424, 48.93662787973881, 46.8692272156477, 46.6433597356081, 46.50009982287884, 46.31967030465603, 43.17171782255173, 42.4698992818594, 42.27682784199715, 40.80826364457607, 42.37715765833855, 39.87355180084705, 40.3634063154459, 41.52675949037075, 46.29148341715336, 48.02811563014984, 43.65703158080578, 45.436688885092735, 49.497553780674934, 56.04120545089245, 56.148709282279015, 59.771210700273514, 60.24869307875633, 55.44443607330322, 48.52323666214943, 45.0498316437006, 42.18103878200054, 44.838878363370895, 44.207914620637894, 45.24101838469505, 44.924784153699875, 45.78380785882473, 46.80048130452633, 47.76523433625698, 47.102367505431175, 47.51368023455143, 48.66157203912735, 48.9464807510376, 50.30278377234936, 50.96365571022034, 48.63015912473202, 50.605597123503685, 46.643690317869186, 52.6407603174448, 49.38061885535717, 53.678678423166275, 53.22614550590515, 63.55552263557911, 66.53782680630684, 78.82008254528046, 73.24416294693947, 81.72043651342392, 71.91184803843498, 85.11476397514343, 2.5492829689756036, 0.3468488616636023, 1.0533616645261645, 0.69743363535963, 62.238182723522186, 78.56684133410454, 65.69645315408707, 53.974462151527405, 26.519987247884274, 28.763164579868317, 56.09531834721565, 69.3534605205059, 41.91608279943466, 0.794040720211342, 0.09876775133307092, 0.043016526906285435, 0.056097632987075485, 0.04479427487240173, 0.09221627944498323, 0.17502899863757193, 0.170660984585993, 0.2918451506411657, 0.13388364866841584, 0.3108085674466565, 0.2779082703636959, 0.3232871275395155, 0.624044492142275, 13.551694471389055, 73.98548036813736, 66.54224216938019, 43.25735382735729, 37.23085440695286, 66.44055962562561, 55.39781637489796, 82.53584995865822, 62.06675872206688, 1.1820745328441262, 1.956456711050123, 0.8178657980170101, 0.4283373593352735, 1.6456040600314736, 61.37283615767956, 78.41535106301308, 69.55993384122849, 64.58083301782608, 55.78204795718193, 58.43628153204918, 55.39071075618267, 56.11561305820942, 53.57795722782612, 57.58242554962635, 56.17011733353138, 58.57585184276104, 57.88562647998333, 60.28162591159344, 58.841172605752945, 60.963951498270035, 60.3842394053936, 61.616129502654076, 57.422305941581726, 58.69360372424126, 57.070817202329636, 56.88343025743961, 50.33725552260876, 47.761962711811066, 46.54673472046852, 49.85300950706005, 57.65469767153263, 61.36861078441143, 62.98148363828659, 59.262258410453796, 55.80344840884209, 61.06983281672001, 61.44629381597042, 62.71107494831085, 60.39962098002434, 56.61511145532131, 48.55448238551617, 48.286798149347305, 52.230621725320816, 53.824260011315346, 47.50752456486225, 45.90978629887104, 42.98617757856846, 47.94250622391701, 45.636387169361115, 47.278792038559914, 47.46703393757343, 49.484098702669144, 50.279586017131805, 50.75353838503361, 49.190777242183685, 50.78454092144966, 52.484736889600754, 54.82128091156483, 54.9058947712183, 53.06299366056919, 54.199166893959045, 54.45708565413952, 54.17937375605106, 58.51548448204994, 60.830092281103134, 57.92133316397667, 58.438044637441635, 59.57907021045685, 64.13431897759438, 49.72982011735439, 38.83904591202736, 33.94748479127884, 36.650861129164696, 53.04055966436863, 57.40659758448601, 55.95123007893562, 59.60812345147133, 59.41932678222656, 54.8802537471056, 55.59084601700306, 53.03381122648716, 54.84856724739075, 54.07534293830395, 54.70444098114967, 53.16203914582729, 53.14003832638264, 51.417469158768654, 49.9424035102129, 51.61643028259277, 47.32923433184624, 49.380778446793556, 46.87727138400078, 45.37913337349892, 44.94750313460827, 42.47732028365135, 45.671390891075134, 43.434758707880974, 43.421391025185585, 43.22205372154713, 49.62298505008221, 50.99968917667866, 46.61218240857124, 49.70691114664078, 51.801723539829254, 56.89231038093567, 57.40768812596798, 62.41176500916481, 61.89322583377361, 58.19689057767391, 51.51694402098656, 48.93600471317768, 45.36896511912346, 48.370139077305794, 46.99295237660408, 47.39126220345497, 49.45298217236996, 49.331821873784065, 49.25362966954708, 50.64251974225044, 51.9514849036932, 49.690632820129395, 51.97074607014656, 53.30242641270161, 52.49004140496254, 54.05376389622688, 50.13362064957619, 53.67572978138924, 48.759633377194405, 54.768456146121025, 51.05039745569229, 59.104414880275726, 56.07001930475235, 67.09314420819283, 66.86318054795265, 80.63830778002739, 78.91432508826256, 83.52063551545143, 74.59149464964867, 88.44530805945396, 2.963703931309283, 0.6611045566387475, 2.6453826623037457, 1.0339095583185554, 68.31874564290047, 88.1749677658081, 72.53755286335945, 64.20089900493622, 30.886353850364685, 35.84061920642853, 68.0865629017353, 82.29963183403015, 56.1112204939127, 0.8256789506413043, 0.20000643882667646, 0.23879354033851996, 0.22018015006324276, 0.17392495006788522, 0.21871767385164276], [0.03805031214142218, 0.14542569260811433, 0.07775956924888305, 0.059536615444812924, 0.13849545823177323, 0.050163898849859834, 0.32481506117619574, 0.14412240707315505, 9.873046316206455, 62.280611246824265, 46.22758984565735, 51.0577804595232, 38.24171416461468, 37.29984350502491, 40.97308740019798, 58.084473609924316, 67.10943013429642, 2.802553866058588, 0.19347006222233176, 0.7869104028213769, 0.08885779403499328, 0.8346731273923069, 39.67337094247341, 75.17620727419853, 60.416932851076126, 65.5121174454689, 56.68992944061756, 66.10024228692055, 56.1875393986702, 62.05176092684269, 56.89527042210102, 58.06385971605778, 57.71417587995529, 59.10742051899433, 60.016324147582054, 61.21410347521305, 57.127190977334976, 61.37407869100571, 58.23565989732742, 56.22667729854584, 52.83547706902027, 52.180369421839714, 49.65804196894169, 45.18826201558113, 42.96972446143627, 44.10862594842911, 42.94867739081383, 53.71577963232994, 51.47220902144909, 55.73757514357567, 52.75438942015171, 79.6807211637497, 71.34031310677528, 54.92965869605541, 59.95810367166996, 53.46668019890785, 52.752516120672226, 46.94956250488758, 46.33537866175175, 42.946180924773216, 48.29344019293785, 49.55867350101471, 42.57349692285061, 40.09909249842167, 40.37322498857975, 39.95376169681549, 40.55794447660446, 41.172960475087166, 41.90627172589302, 42.69507519900799, 42.38117404282093, 45.84652729332447, 43.36459927260876, 46.66362024843693, 45.91963917016983, 47.181319668889046, 50.68180203437805, 52.45533026754856, 48.8152851909399, 46.91838517785072, 49.85549837350845, 49.549709782004356, 52.148135751485825, 53.20472985506058, 55.13207383453846, 56.87980905175209, 54.47616823017597, 46.220666617155075, 36.73582836985588, 33.893611282110214, 32.78526395559311, 47.86834180355072, 57.334238067269325, 56.26727432012558, 55.585138723254204, 52.15950474143028, 49.70998518168926, 49.558403715491295, 47.98998087644577, 47.19833515584469, 49.05137412250042, 50.84783412516117, 47.31725737452507, 46.17341995239258, 46.736652329564095, 42.49432057142258, 42.63937398791313, 43.47033239901066, 42.14228846132755, 40.31746298074722, 43.32181356847286, 43.93185183405876, 41.92953407764435, 42.08720661699772, 38.26801635324955, 39.59254547953606, 41.627290695905685, 44.1695860773325, 46.1652085930109, 42.05987848341465, 41.8404820561409, 47.18373253941536, 53.71221922338009, 58.970684856176376, 57.65435568988323, 54.70664106309414, 55.56151159107685, 52.77217626571655, 45.366388857364655, 39.82823923230171, 42.60164961218834, 41.257502138614655, 41.887641325592995, 43.07312831282616, 44.426763877272606, 44.648200795054436, 45.11379361152649, 43.163141682744026, 46.13655053079128, 44.69594903290272, 46.8318410217762, 46.49814672768116, 50.16032561659813, 47.5656196475029, 48.83154831826687, 45.470750257372856, 49.76091764867306, 47.2681450098753, 50.05863547325134, 51.90350487828255, 61.25980742275715, 62.5757110118866, 74.636370241642, 68.55174914002419, 75.33046379685402, 66.11227244138718, 83.76852661371231, 3.23986551258713, 0.3202162985689938, 0.3971535013988614, 1.919509987346828, 65.04739478230476, 66.55217483639717, 59.26823928952217, 45.83220586180687, 29.460797645151615, 44.954281970858574, 56.16599455475807, 56.292884945869446, 25.63354231417179, 0.680829951306805, 0.23224759002914652, 0.11577471843338571, 0.10944721187115647, 0.06324729445623234, 0.079426291922573, 0.06152598682092503, 0.12749236193485558, 0.025303725415142253, 0.15388740808703005, 0.19103549129795283, 0.04398709650558885, 0.42011296784039587, 0.3625583468237892, 14.62143111974001, 70.17176941037178, 57.13523894548416, 43.439132273197174, 37.42994472384453, 46.06027342379093, 45.64499370753765, 67.32006803154945, 70.86715489625931, 3.897590506821871, 0.24338155664736405, 1.0431550559587777, 0.14185587322572246, 0.8691350813023746, 42.72300750017166, 77.54731804132462, 63.44014182686806, 66.44996792078018, 60.19382782280445, 68.09986218810081, 59.34191353619099, 63.65028955042362, 56.58598221838474, 61.58655188977718, 59.96206305921078, 63.103126510977745, 62.089728489518166, 62.18443460762501, 57.53825671970844, 63.57971213757992, 59.42645139992237, 60.22197671234608, 55.14860674738884, 54.32840555906296, 51.777731627225876, 48.70199427008629, 44.618930965662, 47.416329458355904, 44.757148548960686, 57.551867589354515, 55.720069482922554, 57.13221810758114, 57.167647406458855, 75.22052809596062, 64.79811295866966, 59.09746125340462, 60.17918720841408, 59.44399505853653, 54.37803849577904, 49.84783038496971, 47.08745710551739, 45.76262019574642, 50.2891843020916, 53.18638063967228, 43.461266085505486, 41.98265142738819, 41.603253185749054, 41.7703378200531, 42.22026027739048, 42.96166129410267, 44.27191838622093, 45.12997694313526, 44.05981756746769, 48.54372896254063, 44.76800076663494, 47.489828914403915, 46.57869480550289, 51.248161643743515, 52.605106830596924, 53.5481858253479, 48.31490524113178, 50.830609649419785, 51.73733979463577, 53.156947419047356, 53.85130316019058, 55.03414548933506, 58.020348250865936, 56.7702267318964, 56.42354093492031, 47.666211649775505, 36.16769805550575, 33.162294924259186, 32.92050249874592, 47.23880298435688, 59.17235903441906, 60.019094198942184, 55.044841915369034, 55.19116446375847, 51.54272943735123, 51.78964778780937, 49.187072440981865, 51.54729299247265, 50.80017328262329, 52.49773599207401, 49.93821233510971, 47.767483815550804, 48.113998621702194, 48.637796714901924, 46.23016990721226, 44.72835369408131, 45.21745964884758, 42.582582235336304, 45.39514571428299, 45.72691351175308, 42.47293911874294, 44.09848429262638, 41.12856365740299, 41.298570334911346, 45.30238129198551, 46.821581572294235, 47.14753948152065, 43.80875363945961, 44.48402300477028, 48.84022705256939, 58.09531442821026, 60.96406929194927, 57.8523288667202, 56.930878311395645, 56.12744942307472, 55.55879473686218, 47.60244347155094, 43.305455446243286, 44.08073924481869, 44.00452673435211, 44.93348188698292, 44.88528147339821, 48.37525360286236, 47.12954744696617, 48.164729699492455, 45.35185843706131, 47.70209312438965, 48.67981106042862, 50.56382216513157, 49.34255629777908, 53.761867359280586, 50.895061790943146, 52.12119519710541, 49.67131085693836, 54.83545795083046, 50.02366214990616, 54.08682972192764, 54.756330996751785, 64.55480441451073, 64.39281910657883, 76.2082014977932, 70.56374117732048, 78.69401291012764, 67.32022762298584, 88.41345056891441, 2.9859790485352278, 0.339957308024168, 0.34681148710660636, 2.1428769640624523, 73.03328186273575, 73.75034138560295, 67.05390751361847, 53.79689387977123, 30.83289261907339, 36.77708275616169, 59.033746272325516, 67.22039937973022, 34.836367294192314, 0.7019528397358954, 0.0893066894786898, 0.1907889498397708, 0.06317052670056, 0.09503587658400647, 0.11979503629845567, 0.21271092351526022, 0.2826797455782071, 0.18035217159194872, 0.18928575940662995, 0.38905839202925563, 0.20962519221939147, 0.5727202305570245, 0.5741486570332199, 18.395939581096172, 84.58724588155746, 60.59059493243694, 68.79076391458511, 51.63764834403992, 53.06755721569061, 53.80620718002319, 71.60034075379372, 79.95069667696953, 4.3595269694924355, 0.5928085651248693, 1.6223508515395224, 0.1547231405857019, 1.3960441388189793, 46.64565101265907, 82.92625620961189, 67.78407633304596, 70.75963586568832, 61.6471092402935, 69.97433960437775, 62.2199323028326, 66.21312662959099, 59.64847348630428, 61.80464878678322, 61.30580395460129, 66.31272688508034, 65.50630375742912, 64.001424908638, 61.46882280707359, 67.52789407968521, 63.51156659424305, 64.23864617943764, 58.48800055682659, 57.04637311398983, 53.33992280066013, 49.55509029328823, 46.39348894357681, 48.297114595770836, 46.82200714945793, 59.42283779382706, 58.95376056432724, 60.0931978225708, 58.139122277498245, 72.5376744568348, 62.20687620341778, 62.43435099720955, 62.910545244812965, 61.685768365859985, 56.91807299852371, 52.68279746174812, 49.54369470477104, 49.65793937444687, 52.38229438662529, 56.56314164400101, 45.45470751821995, 44.18771870434284, 45.499123334884644, 44.17807102203369, 44.55915257334709, 43.3545146137476, 47.94219844043255, 47.35043339431286, 47.949596643447876, 52.354430481791496, 48.02735187113285, 50.39803706109524, 49.28721606731415, 54.73652645945549, 55.942372754216194, 58.613116443157196, 52.53089301288128, 54.11161199212074, 53.5839419066906, 54.37649577856064, 55.73842249810696, 58.11440460383892, 59.902736842632294, 60.9481443464756, 58.586362078785896, 48.81052404642105, 35.72674311697483, 34.694372713565826, 33.01533401012421, 48.02382946014404, 62.297505140304565, 61.96160316467285, 59.35054287314415, 56.258823573589325, 54.408847242593765, 55.240056440234184, 52.638301849365234, 54.16308403015137, 53.9319272339344, 55.986628979444504, 53.29012647271156, 51.42234809696674, 51.575099900364876, 50.13271629810333, 49.54172261059284, 47.80490420758724, 47.86848619580269, 45.07588304579258, 48.04714120924473, 48.761632069945335, 44.35753919184208, 47.80192896723747, 41.39662027359009, 42.77270883321762, 45.76515465974808, 49.95576739311218, 50.53049795329571, 44.81314234435558, 46.80941842496395, 51.12793609499931, 60.26632413268089, 62.71585889160633, 62.32751213014126, 61.183252930641174, 59.83994521200657, 59.2164708673954, 48.338232189416885, 44.71894919872284, 48.036649972200394, 46.79020665585995, 48.16894367337227, 47.38556630909443, 51.24884560704231, 49.823633283376694, 51.122878566384315, 47.858082354068756, 51.66514366865158, 51.32435515522957, 54.05399948358536, 52.52045497298241, 56.953456699848175, 53.988817781209946, 54.31542545557022, 51.51874512434006, 58.3332234621048, 53.352070748806, 57.10494317114353, 57.75796093046665, 68.0721464753151, 66.75596550107002, 80.24525687098503, 73.20375591516495, 83.64933460950851, 70.39351031184196, 94.1855688393116, 4.013584507629275, 0.6082194100599736, 0.8086585951969028, 2.4251970648765564, 79.56868037581444, 81.15759551525116, 74.76967468857765, 65.65390303730965, 42.94119939208031, 58.57379235327244, 78.12667295336723, 76.78523853421211, 46.452283188700676, 0.9472490334883332, 0.2586499834433198, 0.3236506611574441, 0.19120798126095906, 0.22692573809763417, 0.27939247665926814], [0.03848183019727003, 0.01738715265673818, 0.06952185620320961, 0.04636061465134844, 0.24192896584281698, 0.06553413346409798, 0.29473691422026604, 0.23935436649480835, 15.139313880354166, 59.408558160066605, 44.19912189245224, 37.11748369038105, 29.11513589322567, 45.120838433504105, 45.17539210617542, 57.58844442665577, 76.46040916442871, 15.928494483232498, 0.03193289645423647, 1.5253849234431982, 0.04741231583466288, 0.1524676795816049, 25.303552821278572, 78.33825320005417, 62.888274639844894, 72.2216834127903, 63.01834546029568, 68.56813386082649, 61.945511028170586, 68.77925053238869, 60.887666791677475, 63.69559831917286, 60.40347397327423, 64.38464194536209, 61.90147139132023, 62.734496891498566, 57.686608359217644, 61.72698475420475, 55.458886697888374, 56.354152858257294, 48.10598485171795, 49.3563761562109, 44.7127403318882, 46.33770413696766, 42.174712121486664, 45.98973400890827, 50.291376784443855, 57.092590034008026, 54.10612888634205, 56.56025379896164, 53.52606721222401, 63.04082125425339, 67.57397800683975, 57.79207170009613, 57.308897227048874, 54.304744228720665, 49.60585556924343, 51.62850223481655, 46.412784308195114, 45.87365783751011, 52.21356064081192, 55.02548575401306, 44.00482691824436, 40.11751390993595, 39.44881819188595, 44.508759677410126, 41.8595190346241, 40.141236037015915, 38.46088260412216, 42.510268315672874, 42.18731604516506, 46.71622842550278, 44.842146188020706, 45.40514297783375, 46.03815481066704, 51.00700378417969, 48.447909504175186, 48.52522395551205, 45.30896253883839, 46.829264760017395, 47.757315561175346, 49.24921430647373, 54.341788440942764, 55.37986993789673, 56.449630334973335, 52.065797969698906, 55.33462196588516, 50.10892577469349, 33.06744061410427, 34.699920415878296, 33.97014297544956, 47.47922368347645, 57.900886461138725, 54.56827528774738, 55.53612135350704, 53.60039882361889, 51.62291653454304, 48.70276942849159, 47.959654703736305, 45.535928159952164, 46.125208139419556, 48.497774228453636, 46.535179540514946, 46.13658852875233, 47.67313487827778, 45.32367914915085, 42.233555763959885, 42.9726655036211, 42.543102353811264, 41.106775626540184, 40.68181402981281, 39.09302808344364, 41.04619547724724, 42.1359807997942, 41.357668563723564, 39.98517081141472, 43.102455139160156, 47.29587212204933, 44.13003019988537, 41.728357672691345, 44.53330636024475, 49.293079152703285, 56.177393943071365, 56.15953870117664, 53.68209823966026, 55.18328368663788, 53.955656960606575, 54.023787304759026, 51.365951523184776, 44.552981704473495, 43.54852840304375, 40.813032388687134, 42.143884375691414, 43.5468602925539, 45.86271062493324, 45.2070178091526, 46.00589074194431, 45.6178517639637, 46.08197405934334, 44.153634533286095, 47.13735222816467, 46.95559658110142, 50.663847997784615, 47.312184646725655, 52.08749860525131, 47.509310469031334, 50.77823705971241, 46.48783028125763, 53.987358659505844, 49.086279049515724, 58.93415741622448, 58.502701967954636, 70.4778353869915, 63.39628078043461, 75.02255871891975, 63.13182257115841, 81.88147947192192, 2.40189909003675, 0.38179154915269464, 0.5267082620412111, 6.5793930273503065, 72.98601239919662, 61.45955130457878, 59.348677173256874, 39.3575394898653, 43.80555801093578, 33.31123933196068, 56.56926691532135, 55.7202784717083, 34.48484055697918, 1.132358475588262, 0.04849298304179683, 0.31006247154437006, 0.04593072189891245, 0.033635168001637794, 0.09281922990339808, 0.07188601957750507, 0.06793367501813918, 0.08118643614579923, 0.029839952803740744, 0.23772685148287565, 0.07820025653927587, 0.48324432398658246, 0.26083038363140076, 20.172370858490467, 67.84736573696136, 53.26273754239082, 44.99811261892319, 38.145970702171326, 49.68606926500797, 50.796164497733116, 62.20107391476631, 83.95081803202629, 17.566514387726784, 0.04027997609227896, 2.012101993896067, 0.08324020367581397, 0.07483260560547933, 27.52031397074461, 78.86081635951996, 64.96253773570061, 74.52226996421814, 65.37215575575829, 70.37830352783203, 66.05245605111122, 72.80665442347527, 64.3762519955635, 66.88917115330696, 64.21446427702904, 66.89533442258835, 64.02172341942787, 65.31073585152626, 60.66169671714306, 63.57994392514229, 58.07264484465122, 58.14542233943939, 51.034632101655006, 50.54171875119209, 47.30710431933403, 48.46036523580551, 44.37749572098255, 48.93465578556061, 53.765545561909676, 57.179609164595604, 57.24144704639912, 57.072154730558395, 57.29203753173351, 60.02325877547264, 64.51033920049667, 62.96972706913948, 57.614560425281525, 57.174361646175385, 49.778039529919624, 53.20683114230633, 47.442107275128365, 48.861293122172356, 54.33025225996971, 55.90793900191784, 46.66355565190315, 43.12947168946266, 41.89578428864479, 45.88352210819721, 42.56330206990242, 41.73976086080074, 39.551940858364105, 42.8379475325346, 42.48767092823982, 49.763246923685074, 45.985413640737534, 47.51646168529987, 47.2587139159441, 51.15398749709129, 52.177052199840546, 51.903056502342224, 48.28972019255161, 49.85178217291832, 48.745406940579414, 53.203407526016235, 53.71270939707756, 56.97664685547352, 56.34765900671482, 57.327428832650185, 57.4913976341486, 53.47643807530403, 34.22567926347256, 36.823197081685066, 32.24815897643566, 48.88246938586235, 60.30146844685078, 54.21803668141365, 56.739702969789505, 54.64413441717625, 52.286110147833824, 51.63208544254303, 49.7655837982893, 49.45334695279598, 49.95316453278065, 50.50880491733551, 49.12722945213318, 48.70043635368347, 50.288846120238304, 49.531280770897865, 45.166819766163826, 45.82178682088852, 46.56392879784107, 43.145689219236374, 40.97823232412338, 41.81636855006218, 44.68506641685963, 43.67031566798687, 43.47747981548309, 43.168594390153885, 44.716072753071785, 49.346014112234116, 47.1352319419384, 43.05457390844822, 45.274034813046455, 52.62929633259773, 58.67645904421806, 57.99792565405369, 55.866585820913315, 58.39226849377155, 57.497963681817055, 56.72030121088028, 54.353537410497665, 46.459510400891304, 46.33385494351387, 43.62111210823059, 45.03174841403961, 47.36240655183792, 47.23159097135067, 47.84433849155903, 49.58440192043781, 47.570924162864685, 49.664718210697174, 47.33266934752464, 50.68247079849243, 48.97755928337574, 53.74448709189892, 49.852652326226234, 54.37559522688389, 51.39737583696842, 53.030068427324295, 49.154272601008415, 58.89475353062153, 52.47420385479927, 63.52363094687462, 59.350710064172745, 72.80486851930618, 65.10990142822266, 78.58777821063995, 65.90582951903343, 86.85401424765587, 2.3199607618153095, 0.21161729469895363, 0.6524642952717841, 7.405725186690688, 79.7731702029705, 68.94856944680214, 66.24445974826813, 49.21923391520977, 46.45615518093109, 42.34548635780811, 65.95203503966331, 62.060409262776375, 48.25348913669586, 1.1586611391976476, 0.05456904626043979, 0.17594286444364116, 0.07175629216362722, 0.0593242424656637, 0.10172509850235656, 0.1860824867617339, 0.14391062781214714, 0.19217284745536745, 0.11648979998426512, 0.3921167826047167, 0.3688611398683861, 0.7075523736421019, 0.46241778996773064, 25.611338205635548, 78.51730719208717, 59.62686404585838, 50.94291262328625, 39.75610010325909, 60.597369968891144, 58.92321020364761, 69.52627524733543, 92.58078575134277, 19.68278232961893, 0.15923974744509906, 3.562918002717197, 0.13970757834613323, 0.45691800070926547, 30.134191811084747, 83.23207139968872, 67.37763494253159, 78.94766449928284, 68.40916559100151, 74.98661264777184, 68.66379752755165, 76.26688554883003, 64.989113509655, 69.46607127785683, 65.97877040505409, 69.97528955340385, 66.4276859164238, 69.61591243743896, 64.08973976969719, 68.06850627064705, 61.3808461278677, 62.59762063622475, 53.97793136537075, 54.8657651245594, 48.64293783903122, 52.79061667621136, 46.735709980130196, 52.9241681098938, 55.770500376820564, 63.19511577486992, 59.61949624121189, 62.39662662148476, 56.180996149778366, 64.61910456418991, 70.93822628259659, 62.70866587758064, 62.12087921798229, 58.592722937464714, 52.718618139624596, 57.23969914019108, 51.062199622392654, 50.154899507761, 58.25630038976669, 61.127772107720375, 50.36860004067421, 45.76793231070042, 45.25715991854668, 49.32341672480106, 45.46645648777485, 43.2331795245409, 41.99644088745117, 48.12889002263546, 46.44742704927921, 52.30596408247948, 48.90546955168247, 50.249658823013306, 49.68563988804817, 57.29324586689472, 56.23130924999714, 55.216748490929604, 48.41303117573261, 52.61956125497818, 52.25790426135063, 55.436410903930664, 59.39049392938614, 60.095781683921814, 59.9414187669754, 59.10281516611576, 61.46262153983116, 55.2624524384737, 33.26030686497688, 35.91349929571152, 32.88866400718689, 51.154717057943344, 62.37424202263355, 58.0145687609911, 60.16061380505562, 57.86649830639362, 54.38086174428463, 54.28205564618111, 51.715920343995094, 51.61089397966862, 52.086609452962875, 55.70636361837387, 52.14568488299847, 50.86251273751259, 55.692414566874504, 51.99659988284111, 46.771948635578156, 49.163851886987686, 48.68422642350197, 47.052441984415054, 43.514774814248085, 42.99244724214077, 47.75766894221306, 47.481408566236496, 46.1560320854187, 44.39876697957516, 47.542402893304825, 50.92792622745037, 50.99474184215069, 45.522594675421715, 48.69322054088116, 55.78674450516701, 61.6187209635973, 61.32002279162407, 56.63569115102291, 60.866767913103104, 60.14232538640499, 59.85395886003971, 56.3131682574749, 49.47769604623318, 49.79798845946789, 44.476643800735474, 48.53957958519459, 50.58856263756752, 51.43250495195389, 49.62578170001507, 51.07343561947346, 50.53587086498737, 51.40759728848934, 48.72651815414429, 52.623140662908554, 52.7909966558218, 57.90477365255356, 53.07859182357788, 58.09682294726372, 53.544177040457726, 56.79913558065891, 51.69573962688446, 60.491982623934746, 55.326023027300835, 66.78624987602234, 64.2735967040062, 76.78447097539902, 67.9886345565319, 83.64102065563202, 69.27737340331078, 94.59559723734856, 3.1201952090486884, 1.0260344808921218, 0.8829281630460173, 8.468201849609613, 89.38232257962227, 75.07729858160019, 75.5203016102314, 56.998811066150665, 62.69479662179947, 41.65426544845104, 73.27002435922623, 75.68161815404892, 61.11926816403866, 1.4258028357289732, 0.26445767492987216, 0.3547169629018754, 0.264192609465681, 0.15605001157382503, 0.1387875378713943], [0.12959762709215283, 0.08171055567800067, 0.11765411836677231, 0.038434603629866615, 0.12635816732654348, 0.060926134829060175, 0.06360336949001066, 0.14135631878161803, 24.642418697476387, 61.410720124840736, 52.277560606598854, 46.445371359586716, 23.218842186033726, 43.01844164729118, 43.044717237353325, 55.97263053059578, 72.01609924435616, 39.991178289055824, 0.16007203637855127, 0.5319431342650205, 0.0623984333651606, 0.08753221438382752, 9.263215139508247, 69.80119809508324, 60.68524785339832, 71.06976002454758, 63.057540357112885, 69.13258597254753, 64.84689474105835, 65.70613503456116, 61.958304941654205, 64.49111983180046, 61.01915493607521, 60.60336224734783, 58.34571719169617, 59.47784744203091, 57.36631214618683, 56.793169900774956, 52.7760786563158, 47.41811156272888, 44.419019892811775, 46.12389340996742, 45.41793689131737, 44.46079485118389, 42.91003726422787, 54.45862457156181, 54.854483529925346, 57.00871713459492, 58.242290541529655, 54.01366464793682, 50.38708984851837, 31.908833384513855, 35.10157026350498, 64.37201902270317, 56.138085052371025, 57.20589615404606, 49.59512114524841, 51.688086837530136, 42.90816776454449, 51.23275347054005, 52.26193204522133, 52.11588688194752, 43.27033393085003, 41.47985480725765, 39.88527037203312, 41.053601279854774, 38.84910397231579, 41.42971269786358, 36.91989429295063, 39.19123761355877, 40.662085488438606, 41.44612401723862, 45.48383295536041, 45.559167712926865, 43.435093089938164, 47.98873834311962, 48.33517335355282, 47.86565914750099, 46.379384100437164, 47.29972131550312, 49.214856550097466, 51.043128445744514, 53.11815910041332, 53.40605065226555, 54.89805579185486, 56.04117505252361, 55.11815898120403, 54.28378075361252, 38.89231525361538, 39.33428093791008, 37.915923446416855, 49.8297281563282, 57.95417100191116, 52.06633374094963, 54.376716166734695, 53.266092762351036, 51.49845041334629, 49.62938390672207, 48.3867821842432, 49.60069924592972, 47.61843681335449, 44.80463460087776, 44.87668253481388, 45.56916877627373, 44.64274808764458, 43.78373198211193, 43.20420987904072, 45.12643553316593, 40.54433360695839, 43.44993509352207, 37.26174294948578, 39.70450647175312, 38.907104060053825, 40.35246670246124, 38.49388763308525, 40.67566975951195, 44.16692242026329, 50.74599578976631, 47.40270718932152, 42.32027471065521, 44.46083664894104, 48.41129466891289, 55.96950329840183, 57.02730193734169, 56.391223669052124, 55.639179423451424, 56.935654655098915, 55.27444839477539, 53.57997491955757, 50.83001308143139, 47.83768504858017, 43.73061843216419, 41.073212027549744, 43.01630236208439, 44.67083238065243, 45.50679512321949, 47.08723671734333, 47.109689712524414, 47.41510592401028, 46.075339615345, 46.750605180859566, 45.803183019161224, 47.8046078234911, 49.391402676701546, 50.74388690292835, 48.06398570537567, 49.670197516679764, 50.45208156108856, 49.67338174581528, 47.91785694658756, 56.49625763297081, 51.34042449295521, 58.07361379265785, 58.82563903927803, 72.23268002271652, 67.95503675937653, 76.99694037437439, 1.0297727677971125, 0.18568591272924095, 0.3257629321888089, 12.092683911323547, 76.91884696483612, 54.11067724227905, 55.47022148966789, 37.989593893289566, 54.380455166101456, 32.16024689376354, 45.65999150276184, 69.46199029684067, 36.115587651729584, 0.4221128480276093, 0.009307838045060635, 0.05661840914399363, 0.04463335499167442, 0.1908986541093327, 0.1068145246244967, 0.07088625017786399, 0.05063252057880163, 0.1394710410386324, 0.041625400772318244, 0.13137717847712338, 0.06834987143520266, 0.10411390117951669, 0.07615301248733886, 32.24719002842903, 68.49548935890198, 57.67349526286125, 54.73566770553589, 26.616992242634296, 49.965639263391495, 48.92036095261574, 63.162114545702934, 76.18724182248116, 43.57371345162392, 0.13566233916208148, 1.2429608032107353, 0.0470861530629918, 0.08125112173729576, 9.510216135531664, 73.2640890777111, 61.27192497253418, 73.33692356944084, 66.84775337576866, 72.27592930197716, 66.47110238671303, 68.49677368998528, 62.382236793637276, 66.46666422486305, 63.30147206783295, 64.1900771856308, 61.02170839905739, 61.89511053264141, 59.308931306004524, 60.668270364403725, 55.67735977470875, 50.583995282649994, 45.340903624892235, 47.51035541296005, 46.8297815322876, 46.48857124149799, 45.968067571520805, 56.360095739364624, 56.63816101849079, 59.866182804107666, 58.448805660009384, 55.7791943103075, 52.221369221806526, 34.97439108788967, 38.12428526580334, 63.66671986877918, 56.29692792892456, 58.90871398150921, 52.75419183075428, 54.54966388642788, 45.854411870241165, 54.51154813170433, 55.92487849295139, 56.361098885536194, 47.26935714483261, 43.286467865109444, 42.31783904135227, 43.13887618482113, 41.65135480463505, 42.76103965938091, 37.91149288415909, 42.58209966123104, 42.49565050005913, 44.53753553330898, 45.92112489044666, 49.26845647394657, 45.9257872402668, 49.91937294602394, 51.20332784950733, 51.20517075061798, 47.029384821653366, 50.730538219213486, 51.142884492874146, 52.68484555184841, 54.4393178075552, 54.88944925367832, 56.94501355290413, 56.93269461393356, 56.89685873687267, 55.10868988931179, 38.35048332810402, 38.00571642816067, 36.056873202323914, 50.919034704566, 58.47750931978226, 55.39986066520214, 55.73163606226444, 55.039799585938454, 52.380865663290024, 50.525007247924805, 51.785627603530884, 49.69311788678169, 49.26431089639664, 50.0498503446579, 48.74758042395115, 47.83890478312969, 47.690720334649086, 45.732799395918846, 44.068389907479286, 49.1226164996624, 42.50417344272137, 43.4063134342432, 39.56195332109928, 40.80491982400417, 42.595471143722534, 41.669719219207764, 41.83143854141235, 43.88697624206543, 45.26559166610241, 53.41081939637661, 49.113386794924736, 46.514915227890015, 46.706364154815674, 51.49971194565296, 58.73100131750107, 58.107652366161346, 57.66537509858608, 57.92886435985565, 57.758101522922516, 60.143271535634995, 57.48899236321449, 53.19049961864948, 50.20917199552059, 46.201192662119865, 44.16540250182152, 45.076608806848526, 49.012498408555984, 50.59657260775566, 51.37544721364975, 48.67506891489029, 50.05552724003792, 48.89558628201485, 49.492332860827446, 48.69705453515053, 50.70221833884716, 52.842768877744675, 53.898169845342636, 51.46930977702141, 53.953126296401024, 53.739235773682594, 52.87695184350014, 51.754457876086235, 60.49998879432678, 54.234212413430214, 62.21657708287239, 60.483623072505, 75.29774755239487, 71.86060398817062, 84.62240159511566, 1.3293091510422528, 0.26027297135442495, 0.38044143409933895, 14.114535469561815, 85.74216350913048, 59.636032953858376, 59.14495870471001, 46.211851090192795, 60.44837236404419, 32.82985456287861, 58.69944781064987, 74.39493879675865, 48.72615337371826, 0.5879276082850993, 0.021410249864857178, 0.12998729915125296, 0.020631304651033133, 0.09676063520601019, 0.034987999315490015, 0.28038927004672587, 0.11298177923890762, 0.24636089365230873, 0.16502658458193764, 0.15767546341521665, 0.20744881447171792, 0.2514458372024819, 0.29497784504201263, 39.343529641628265, 79.6818459033966, 66.19108021259308, 57.86969393491745, 33.88147473335266, 57.002481669187546, 55.91444805264473, 67.01610714197159, 84.71331551671028, 48.552012518048286, 0.3276053286390379, 1.718716649338603, 0.19598249928094447, 0.223761398519855, 11.135415527969599, 73.84849011898041, 64.27817925810814, 76.20608121156693, 68.40459063649178, 75.55379301309586, 69.33761537075043, 70.01317352056503, 65.06100565195084, 67.06771597266197, 65.8701342344284, 65.47993317246437, 64.35676664113998, 65.90018302202225, 60.8728551864624, 61.8704878538847, 58.37784066796303, 54.93042625486851, 48.780403062701225, 51.32233366370201, 48.35667259991169, 49.537368044257164, 47.59145446121693, 59.501428976655006, 58.52939173579216, 62.35497325658798, 62.00108304619789, 58.27054962515831, 50.361684411764145, 39.30610924959183, 44.65427666902542, 65.51919266581535, 61.105999276041985, 60.55973678827286, 56.655564084649086, 57.54469737410545, 48.34289073944092, 57.26331487298012, 59.31178875267506, 59.27852153778076, 51.97365291416645, 46.67581759393215, 44.76939529180527, 45.709286257624626, 44.010557010769844, 46.135866567492485, 39.76778827607632, 44.467288702726364, 45.819742530584335, 45.73188364505768, 49.43085215985775, 52.35201381146908, 48.76077711582184, 54.520496651530266, 53.370435163378716, 52.10486747324467, 50.92115119099617, 52.18305587768555, 54.56844627857208, 55.40182135999203, 57.54775620996952, 56.73736609518528, 59.53314207494259, 60.94655983150005, 61.760654747486115, 56.575608775019646, 39.15231630206108, 39.27517510950565, 36.63619011640549, 53.84077772498131, 64.94233042001724, 56.99805870652199, 57.34274201095104, 58.8503947108984, 55.27818739414215, 53.83979357779026, 53.71897146105766, 53.142549991607666, 52.355946600437164, 50.8189632743597, 50.42118921875954, 51.196119636297226, 52.11351200938225, 48.57424512505531, 48.234524354338646, 50.48029884696007, 45.27639448642731, 48.192958384752274, 42.732058614492416, 43.79182554781437, 44.50809471309185, 44.50970962643623, 44.48794439435005, 46.32712170481682, 48.1058594584465, 56.937926933169365, 52.64725796878338, 48.44679616391659, 49.73319433629513, 53.09681944549084, 62.19311714172363, 61.282735392451286, 59.50034603476524, 60.15995644032955, 59.46443796157837, 63.08514967560768, 60.15943206846714, 56.753500029444695, 52.085271924734116, 48.95168647170067, 46.76343709230423, 48.05667869746685, 49.80947144329548, 53.62762436270714, 53.005859926342964, 52.63131022453308, 52.70849168300629, 51.335629150271416, 52.073652148246765, 52.63281874358654, 53.78126911818981, 54.92240488529205, 56.893397122621536, 55.23354358971119, 55.329925417900085, 57.78394013643265, 55.71924492716789, 54.5328763872385, 63.48500221967697, 55.8762601017952, 64.64448720216751, 65.14134854078293, 77.94970124959946, 73.70597496628761, 86.4908829331398, 2.298123096115887, 0.8444817073177546, 0.5299433134496212, 14.714074898511171, 95.5510787665844, 66.00689649581909, 70.95388144254684, 54.908497631549835, 73.05555626749992, 39.63073343038559, 61.12700454890728, 85.64319401979446, 62.243627831339836, 1.0738941002637148, 0.09889617256703787, 0.13222603214671835, 0.1317348045995459, 0.2866271400125697, 0.25568355980794877], [0.033634010251262225, 0.08230468942201696, 0.056970305886352435, 0.09991195751354098, 0.019031152623938397, 0.028681009425781667, 0.13784882496111095, 0.09641221913625486, 30.172964930534363, 63.690252006053925, 38.89423795044422, 36.427896693348885, 30.346093140542507, 53.76328468322754, 38.2178058475256, 51.83835357427597, 66.29389509558678, 58.61068457365036, 2.0206814585253596, 0.22900069394381717, 0.3140193357830867, 0.059284173912601545, 2.1855524741113186, 52.75459460914135, 68.78695651888847, 63.85666027665138, 66.88247591257095, 64.37163144350052, 64.56058770418167, 65.18706768751144, 64.3786458671093, 65.3464387357235, 62.964893728494644, 60.29854640364647, 59.67555843293667, 57.41711162030697, 54.95558090507984, 49.27820675075054, 44.74493980407715, 43.24134148657322, 44.52731028199196, 45.09932778775692, 43.072980120778084, 42.4372324347496, 49.987849071621895, 54.67258349061012, 56.47817440330982, 53.93701136112213, 55.10016314685345, 50.058244094252586, 46.00706487894058, 41.645522117614746, 40.84975741803646, 61.403481513261795, 58.63099828362465, 58.40250514447689, 50.202434957027435, 49.42562364041805, 45.93070797622204, 52.24563471972942, 50.946108251810074, 53.652995601296425, 43.889005333185196, 41.98610544204712, 37.712717950344086, 38.379437774419785, 40.22230848670006, 39.49180148541927, 38.003691136837006, 40.47012358903885, 40.953727439045906, 41.0676035284996, 44.89723943173885, 45.53533159196377, 43.303996324539185, 44.66498449444771, 45.31482942402363, 47.39547997713089, 44.12297397851944, 46.02672882378101, 48.740767389535904, 49.43070396780968, 54.00103032588959, 52.610612735152245, 53.1574147939682, 55.54810591042042, 55.50304792821407, 54.432687163352966, 42.110271379351616, 36.364877074956894, 42.09133319556713, 55.82948461174965, 52.62027561664581, 53.194265216588974, 56.26948960125446, 53.47464457154274, 51.5896113216877, 49.40301105380058, 48.496573492884636, 47.22900710999966, 46.95485562086105, 47.28208266198635, 46.025246903300285, 44.01251770555973, 45.20798675715923, 42.18587212264538, 42.50225454568863, 41.65266953408718, 41.49688169360161, 38.78752067685127, 38.24028544127941, 38.07719439268112, 38.444395288825035, 37.15189844369888, 38.859184831380844, 40.896855890750885, 45.21124318242073, 52.44844503700733, 52.519132643938065, 44.70001861453056, 44.88752715289593, 46.679902374744415, 54.094258323311806, 56.325794979929924, 58.31471085548401, 59.945115968585014, 56.21813915669918, 56.27806194126606, 54.375010058283806, 51.28088928759098, 51.53863325715065, 48.1914346665144, 45.01667462289333, 43.42490963637829, 44.67872075736523, 45.44038228690624, 46.443672850728035, 48.0013232678175, 48.59994314610958, 46.43641144037247, 46.80273078382015, 44.31781992316246, 44.8228470236063, 47.91072092950344, 51.66139706969261, 47.087479904294014, 49.32716332376003, 48.10761496424675, 49.069343358278275, 48.47929202020168, 51.35127671062946, 50.35408101975918, 56.03767544031143, 58.65238733589649, 69.72308188676834, 72.23693579435349, 68.24578955769539, 0.13688300881767645, 0.17326636821962893, 0.40839798864908516, 22.64793422073126, 76.42135486006737, 57.69183307886124, 54.92626927793026, 42.85545699298382, 44.76206548511982, 68.84364187717438, 46.24291442334652, 58.61508473753929, 39.824340641498566, 2.5968495290726423, 0.1453278775443323, 0.0923845317447558, 0.04443214762432035, 0.03335048757435288, 0.02369020730839111, 0.03555050272552762, 0.06644977300311439, 0.08992478717118502, 0.03469548923021648, 0.030678989714942873, 0.0273488153834478, 0.13745910837315023, 0.06567505988641642, 39.34273548424244, 72.49138534069061, 51.15957699716091, 39.43160891532898, 16.255043260753155, 57.1058589220047, 44.814635664224625, 59.890311509370804, 74.0798369050026, 66.35507941246033, 2.1453437441959977, 0.3194286720827222, 0.6453857501037419, 0.15033529634820297, 2.71520652808249, 54.68948118388653, 69.76443886756897, 68.32886829972267, 68.26263785362244, 65.55902972817421, 66.83866426348686, 66.24278783798218, 65.99947169423103, 68.61106395721436, 64.6272437274456, 62.22537741065025, 61.523209288716316, 60.559296011924744, 56.88189893960953, 51.34423948824406, 47.416451051831245, 44.28868688642979, 47.44431495666504, 46.35925658047199, 45.8946593105793, 45.52331663668156, 51.52569115161896, 56.87612324953079, 60.69393418729305, 55.59039004147053, 56.28786161541939, 49.85347308218479, 45.70925585925579, 41.789105013012886, 41.91376492381096, 62.751504778862, 60.974104553461075, 61.04497455060482, 51.85764513909817, 53.47013421356678, 48.65096680819988, 54.80220593512058, 52.90766939520836, 55.98678097128868, 49.00141440331936, 43.03113296627998, 39.50516156852245, 41.700539365410805, 42.740752547979355, 42.6395183801651, 40.57948552072048, 42.163384929299355, 43.06263327598572, 44.74951855838299, 47.035703882575035, 48.3847226947546, 46.51536740362644, 45.98755292594433, 47.38781958818436, 50.39970137178898, 48.10728058218956, 49.08235386013985, 49.771420285105705, 49.74690020084381, 55.909128338098526, 55.426326245069504, 55.88340751826763, 57.58439764380455, 58.098912835121155, 56.777484342455864, 44.29442837834358, 38.16101409494877, 41.11671969294548, 57.91036695241928, 55.27124896645546, 55.988129898905754, 57.68627777695656, 54.56840068101883, 53.29036965966225, 50.07562056183815, 51.00638821721077, 46.9953728467226, 48.70681621134281, 48.67729179561138, 48.28747831285, 45.62844559550285, 47.88876570761204, 44.505818635225296, 45.16500346362591, 43.02843511104584, 43.395408019423485, 40.553472116589546, 38.37685391306877, 39.94391642510891, 40.451675578951836, 39.70262177288532, 40.64771085977554, 42.10687816143036, 49.3547498434782, 53.303832337260246, 53.262756541371346, 47.64127358794212, 48.15681092441082, 49.90666642785072, 55.5747576802969, 57.6954884827137, 59.40918892621994, 60.57653948664665, 57.5242430716753, 59.795343205332756, 57.318442314863205, 57.261221185326576, 54.21406589448452, 50.21968983113766, 46.17384932935238, 46.02198667824268, 46.969933211803436, 48.37450124323368, 49.735227227211, 51.48273065686226, 52.15028643608093, 50.31647823750973, 48.80221389234066, 47.58549638092518, 48.99969309568405, 52.09198236465454, 53.94996866583824, 49.59054239094257, 52.26639300584793, 52.27801278233528, 53.153181821107864, 51.824921295046806, 53.526306599378586, 54.20207753777504, 59.42967362701893, 63.4327208250761, 73.43195647001266, 75.89702859520912, 70.24730935692787, 0.16256725561106578, 0.7426380284596235, 0.43511388008482754, 26.831029057502747, 82.78710007667542, 65.62212154269218, 63.006999269127846, 56.82564675807953, 49.17837850749493, 45.25912821292877, 57.59859748184681, 67.32906594872475, 56.211455315351486, 2.8781147114932537, 0.09278092766180634, 0.02613848013425013, 0.05839598270540591, 0.05190579737245571, 0.043884542828891426, 0.11406843186705373, 0.13878547470085323, 0.20304648351157084, 0.1367069862317294, 0.12773419817676768, 0.13146715646144003, 0.26233557786326855, 0.16651524376356974, 47.91968084871769, 80.36976099014282, 57.44644984602928, 48.55052299797535, 37.99119360744953, 68.97130742669106, 50.91966167092323, 65.34594476222992, 78.8197709619999, 71.84842944145203, 2.589373430237174, 0.6785723974462599, 1.0602309834212065, 0.2939423709176481, 3.4295285353437066, 57.27756030857563, 70.94085574150085, 71.50884926319122, 71.65378108620644, 69.47981894016266, 68.67793276906013, 70.36492824554443, 70.24285599589348, 71.19707599282265, 67.47158110141754, 66.78558871150017, 65.24477139115334, 61.86394080519676, 59.40608449280262, 54.55041244626045, 49.89864505827427, 46.587187349796295, 50.279791206121445, 47.750274538993835, 48.073815777897835, 47.3763670027256, 55.125260800123215, 58.74023102223873, 64.24336552619934, 58.73675800859928, 59.09576274454594, 52.358682453632355, 47.563772946596146, 44.60901349782944, 46.376074478030205, 65.58067336678505, 63.84710758924484, 63.023771569132805, 55.999012514948845, 55.89439272880554, 49.63569536805153, 57.576520666480064, 57.70391643047333, 59.73315194249153, 50.130170434713364, 46.89737990498543, 42.624326795339584, 42.39408954977989, 45.55324383080006, 43.92860300838947, 42.907753586769104, 45.01357778906822, 44.3886861205101, 47.719891369342804, 50.76365724205971, 50.857493206858635, 48.64555969834328, 49.489767998456955, 50.56707099080086, 53.304516300559044, 49.96638782322407, 52.24333584308624, 53.616354167461395, 52.59834699332714, 59.73408289253712, 58.871202394366264, 57.44360759854317, 61.11189655959606, 59.23839949071407, 58.62098202109337, 44.906355142593384, 38.016279861330986, 43.663229048252106, 61.60764455795288, 56.964776292443275, 58.87279070913792, 61.64109796285629, 58.506877943873405, 56.342852264642715, 53.73999573290348, 54.4912002235651, 49.15181793272495, 51.327284798026085, 53.4771828353405, 51.72692835330963, 49.558076933026314, 52.64663100242615, 46.129984483122826, 48.6076795309782, 45.514603704214096, 48.26039336621761, 43.30511726438999, 40.55467665195465, 41.66351415216923, 42.984889447689056, 43.17690074443817, 43.62924367189407, 45.71947731077671, 51.52526177465916, 55.56073643267155, 57.539202868938446, 50.13245411217213, 48.990691378712654, 51.810204684734344, 59.88753005862236, 61.165819466114044, 61.27050004899502, 65.59876799583435, 60.61067685484886, 62.06658773124218, 61.30565196275711, 58.81466522812843, 56.004225835204124, 52.83931486308575, 49.914968982338905, 49.473508670926094, 51.15098185837269, 51.45311124622822, 52.802396044135094, 54.37093287706375, 52.79049888253212, 52.842297703027725, 52.06728368997574, 48.71908575296402, 51.091081872582436, 53.85795280337334, 57.692980617284775, 52.180927991867065, 56.21329061686993, 55.878874361515045, 56.731392815709114, 54.90899160504341, 57.8691353648901, 57.591742649674416, 62.514002323150635, 66.03804722428322, 76.68632984161377, 80.08231401443481, 77.89970353245735, 0.5819310550577939, 1.5001422842033207, 0.41018977062776685, 28.285064734518528, 93.40907290577888, 72.04902067780495, 71.34396851062775, 59.798025861382484, 65.51828071475029, 86.17886647582054, 64.39166396856308, 77.67322808504105, 70.6729245185852, 3.8054288271814585, 0.36942460807040334, 0.19000170927029103, 0.11317867101752199, 0.17682737088762224, 0.13853016105713323], [0.033853678542072885, 0.101384126173798, 0.04095953474461567, 0.04772684544150252, 0.05373388892621733, 0.0189045348088257, 0.11982326759607531, 0.13716140325414017, 23.055217266082764, 57.84388191998005, 49.43624787032604, 45.80428496003151, 48.56209717690945, 82.6034939289093, 34.253014996647835, 63.13757926225662, 53.3892859518528, 73.7842507660389, 7.159601468592882, 0.059128608627361245, 0.4766072379425168, 0.043503464839886874, 0.3479512478224933, 41.56257636845112, 74.71068665385246, 58.904602602124214, 62.8623828291893, 57.530858516693115, 58.43340888619423, 58.42841975390911, 61.26596689224243, 59.20331597328186, 55.82107946276665, 53.96047130227089, 51.64366342127323, 49.310991391539574, 46.26145742833614, 42.254454642534256, 45.5766923725605, 44.851714074611664, 45.07790453732014, 45.34026525914669, 43.746072202920914, 48.39574210345745, 53.159459084272385, 54.54681783914566, 58.2740568369627, 55.70457011461258, 54.179924726486206, 46.104943826794624, 49.30589586496353, 47.19982087612152, 51.21237516403198, 57.886223047971725, 56.28800220787525, 54.984440356492996, 50.51731266081333, 48.3680035918951, 47.78980381786823, 52.21820779144764, 52.61617183685303, 49.992127642035484, 47.76608169078827, 40.4186325520277, 38.07578466832638, 39.86294277012348, 39.81273606419563, 39.81603428721428, 40.74115164577961, 41.14374004304409, 40.869200974702835, 40.337050929665565, 44.160253778100014, 45.52028439939022, 44.57089014351368, 45.332327485084534, 44.29574690759182, 46.19272291660309, 45.18481560051441, 46.76931157708168, 46.74555525183678, 48.6970279365778, 52.300233989953995, 51.60320319235325, 54.1942385584116, 53.62899988889694, 54.52891319990158, 54.82179008424282, 46.35869041085243, 36.205114647746086, 46.75571970641613, 57.300613671541214, 52.493107840418816, 51.813582703471184, 53.01658675074577, 52.463112249970436, 53.577448055148125, 46.86436727643013, 47.02679716050625, 43.94036717712879, 45.62489278614521, 46.34609788656235, 45.45273922383785, 43.639218136668205, 43.17711353302002, 40.970431342720985, 43.282310888171196, 39.70272436738014, 40.48279210925102, 37.690420746803284, 39.10701893270016, 38.18500600755215, 38.594753220677376, 38.735763654112816, 39.928306862711906, 38.52389842271805, 46.002444326877594, 52.605091631412506, 52.33246386051178, 49.937915951013565, 45.07685199379921, 46.48895502090454, 49.389533177018166, 54.57033857703209, 53.969720005989075, 57.54535473883152, 53.55300776660442, 52.07911625504494, 56.443516463041306, 57.61744827032089, 53.9527653157711, 51.491534784436226, 47.118873819708824, 43.77473026514053, 44.924183785915375, 44.93374027311802, 48.209939673542976, 50.30967280268669, 50.65738454461098, 52.489969208836555, 47.173978462815285, 48.60479548573494, 45.30243828892708, 49.27104413509369, 48.32896448671818, 47.46893763542175, 47.799212113022804, 47.99690030515194, 47.98584669828415, 50.61301812529564, 48.046734631061554, 53.708966597914696, 55.85161082446575, 67.0400458574295, 71.08448043465614, 79.17038574814796, 47.54513494670391, 0.5042533669620752, 0.4809982585720718, 0.09598483855370432, 39.23352934420109, 74.24560680985451, 61.72893404960632, 52.94034764170647, 37.41982586681843, 76.662687510252, 74.51032340526581, 45.86956545710564, 59.40493695437908, 47.73783020675182, 2.4295972287654877, 0.07866524916607887, 0.12390127260005102, 0.014815932863712078, 0.11020080346497707, 0.026389634040242527, 0.024607657687738538, 0.08724972329218872, 0.08835467728204094, 0.012426612538547488, 0.051808112184517086, 0.09604461854905821, 0.06421771933673881, 0.23177645984105766, 30.834389738738537, 66.12840637564659, 56.326763927936554, 33.248903676867485, 39.60739128291607, 87.16028541326523, 37.87380650639534, 68.80003541707993, 59.37334544956684, 81.05547979474068, 7.92344693094492, 0.10393095435574651, 0.8544333139434457, 0.0503943653893657, 0.27557739231269807, 44.09435771405697, 78.39500695466995, 63.2454364746809, 66.79527059197426, 58.23077715933323, 60.64627334475517, 58.911316841840744, 63.45343351364136, 61.95916369557381, 59.108305871486664, 56.14603042602539, 53.258348777890205, 51.360650807619095, 48.184769824147224, 44.110020473599434, 45.676269829273224, 47.73255988955498, 47.120614126324654, 47.62493446469307, 45.94035945832729, 49.987548887729645, 54.642838686704636, 58.303072080016136, 60.853624418377876, 58.33438619971275, 55.41137404739857, 47.4434220045805, 49.94173854589462, 50.67965894937515, 54.32264506816864, 59.670067727565765, 58.56272354722023, 59.72244031727314, 55.021894946694374, 50.11198081076145, 50.38558892905712, 54.6802818775177, 55.4716844111681, 53.44737723469734, 50.680441707372665, 44.12162885069847, 43.11170004308224, 41.146418899297714, 44.32014919817448, 40.440724566578865, 42.49042958021164, 42.54068948328495, 42.34643630683422, 42.38997437059879, 46.20799049735069, 46.471567153930664, 46.05635963380337, 46.88549414277077, 48.01884412765503, 49.28461700677872, 47.53012575209141, 49.2679663002491, 47.85672962665558, 50.61119042336941, 55.073355585336685, 54.62475165724754, 56.561845913529396, 56.23385511338711, 57.2292573004961, 58.61579529941082, 46.79766945540905, 36.479999497532845, 48.46105299890041, 57.05690994858742, 54.66349437832832, 56.723299250006676, 57.338182255625725, 54.27520841360092, 54.616821482777596, 49.53196093440056, 49.4591074436903, 47.09015876054764, 49.457834511995316, 48.051229789853096, 47.675353959202766, 45.098191648721695, 45.77471114695072, 44.27040986716747, 46.67601898312569, 42.41808906197548, 44.400780871510506, 37.72189445793629, 43.07915098965168, 39.38386827707291, 40.41620448231697, 39.60546478629112, 41.775383949279785, 41.7652802914381, 50.95669828355312, 56.078694239258766, 54.85528528690338, 53.96720074117184, 47.121883258223534, 50.26223994791508, 52.55551569163799, 57.862048745155334, 57.61628933250904, 61.19456112384796, 55.851227045059204, 53.62770415842533, 58.40947777032852, 58.60244281589985, 56.97294965386391, 55.28876222670078, 51.84113882482052, 44.66070972383022, 47.0593424141407, 46.44662149250507, 53.192122131586075, 52.67922185361385, 54.44273002445698, 54.141960963606834, 50.536068454384804, 51.180855855345726, 47.24801369011402, 51.58905655145645, 48.370173275470734, 50.57829558849335, 51.8117094039917, 50.091112330555916, 52.190609872341156, 53.736184537410736, 52.48202383518219, 55.87382823228836, 57.63695262372494, 70.29520198702812, 72.39411816000938, 82.283034324646, 48.466558903455734, 0.6318315211683512, 0.9450764406938106, 0.09138569002971053, 43.38164135813713, 79.74062874913216, 66.5106962621212, 58.89703340828419, 51.41130208969116, 87.82987028360367, 59.68747079372406, 53.3589331805706, 70.29674470424652, 60.93935161828995, 4.0292292181402445, 0.07844161038519815, 0.12248862418346107, 0.041804284337558784, 0.11464747032732703, 0.028440414425858762, 0.11180100744240917, 0.1601272076368332, 0.1586601894814521, 0.15629429690307006, 0.1557132398011163, 0.16328661935403943, 0.17603069019969553, 0.48357395629864186, 41.44702076911926, 77.08029270172119, 67.01992973685265, 58.11527095735073, 55.66588819026947, 95.59519439935684, 46.17424450814724, 78.41079130768776, 66.77430331707001, 88.64660605788231, 9.10269845277071, 0.4245688521768898, 1.541292176116258, 0.14669862430309877, 0.7440718577709049, 46.32991835474968, 80.78038975596428, 64.27449345588684, 68.39077457785606, 62.195947989821434, 62.50747047364712, 63.43676760792732, 66.85032203793526, 66.14311918616295, 61.59157142043114, 60.86837522685528, 55.593878254294395, 54.69655640423298, 51.5560819208622, 45.58021858334541, 49.99454811215401, 50.23769326508045, 49.50290769338608, 51.605730056762695, 49.4575609266758, 54.49620075523853, 58.98166626691818, 60.62573544681072, 65.18294870853424, 60.965444818139076, 59.47196915745735, 48.52096438407898, 49.01942163705826, 53.02898168563843, 58.23027938604355, 61.813992485404015, 58.09145763516426, 61.79724678397179, 55.826197788119316, 53.626051247119904, 52.82465144991875, 58.130211755633354, 62.489725425839424, 57.12979003787041, 54.08281333744526, 46.674020290374756, 44.82024796307087, 44.09159526228905, 45.49568071961403, 44.738214164972305, 43.424487859010696, 46.379908472299576, 45.155576169490814, 45.293972343206406, 49.936688616871834, 50.07742166519165, 50.179734975099564, 51.93789303302765, 49.73324753344059, 51.02833203971386, 49.79744888842106, 52.605372816324234, 51.188778430223465, 52.90261186659336, 57.48812980949879, 56.64075627923012, 58.553733229637146, 58.995938301086426, 58.369701504707336, 60.660260394215584, 47.66665622591972, 35.284671038389206, 48.78133021295071, 61.02816805243492, 57.61041484773159, 58.32050934433937, 60.58248616755009, 56.117281168699265, 57.901513427495956, 51.94492645561695, 53.397086933255196, 48.35293360054493, 50.908250883221626, 51.12994998693466, 51.5313870459795, 48.74427080154419, 49.153242856264114, 46.49679020047188, 49.27408777177334, 46.92821905016899, 47.02243119478226, 39.06994052231312, 44.20512177050114, 43.52970041334629, 42.800496742129326, 43.10963295400143, 44.67332124710083, 43.04232336580753, 52.118672132492065, 59.38045486807823, 56.1384916305542, 55.85029989480972, 50.30619598925114, 52.234299927949905, 56.53504975140095, 60.09807676076889, 58.555002361536026, 63.89791086316109, 57.77173139154911, 55.383133962750435, 61.132917031645775, 61.488881930708885, 59.63438004255295, 57.52453565597534, 54.53438490629196, 47.6578027009964, 49.510313495993614, 49.53726924955845, 55.93910112977028, 57.107622027397156, 57.47118651866913, 58.10897469520569, 53.40896889567375, 54.53713595867157, 50.40528327226639, 55.70237763226032, 52.196457758545876, 52.39687420427799, 54.07915033400059, 53.960828483104706, 55.41036710143089, 57.59033292531967, 55.472505167126656, 60.8773123472929, 62.58926868438721, 73.68739396333694, 75.67919388413429, 84.90741670131683, 55.34686490893364, 0.620521962409839, 1.6387342661619186, 0.16580518655246124, 47.48691447079182, 88.22713136672974, 75.89629903435707, 66.20952442288399, 52.26828150451183, 95.80527752637863, 98.62501502037048, 64.18792650103569, 77.81575083732605, 77.63822436332703, 6.141185341402888, 0.2227434390806593, 0.2688915323233232, 0.2020831312984228, 0.24387428333284333, 0.09802178159588948], [0.03463892273430247, 0.09562702689436264, 0.0635760955628939, 0.02570507516793441, 0.0403360045311274, 0.05679757843608968, 0.10701477091060951, 0.3123395884176716, 34.96665470302105, 54.960000067949295, 46.32271774113178, 38.15007448196411, 69.23452690243721, 87.70737245678902, 37.23006024956703, 65.8293928205967, 53.991964012384415, 75.53040906786919, 14.812121987342834, 0.028304692314122804, 0.7979769527446479, 0.03893374989274889, 0.05210407325648703, 24.89362321794033, 82.9732520878315, 58.18861462175846, 63.30893486738205, 49.21956069767475, 53.27333137392998, 46.89287334680557, 50.57441599667072, 46.795864552259445, 48.37295852601528, 44.690690115094185, 47.046096324920654, 44.3467553704977, 45.3471314907074, 43.7027545273304, 46.51602476835251, 48.145358338952065, 48.76160927116871, 43.60984571278095, 44.49174419045448, 48.689283952116966, 54.525580778717995, 53.274049535393715, 55.62448941171169, 53.042562156915665, 50.16779221594334, 53.95992413163185, 57.918224930763245, 56.74426652491093, 57.49116204679012, 55.231370106339455, 58.23114953935146, 52.124444022774696, 49.3115271627903, 47.18317776918411, 50.11191241443157, 52.62582331895828, 48.93082179129124, 48.67037616670132, 47.64326088130474, 44.7280915081501, 42.934158369898796, 38.53455685079098, 41.579432263970375, 39.11740377545357, 37.54529133439064, 39.23796750605106, 38.09579819440842, 41.63540706038475, 41.036638990044594, 41.75264596939087, 46.43885850906372, 43.594874516129494, 43.644929230213165, 43.20295974612236, 46.47972151637077, 47.23545156419277, 46.83438688516617, 49.41429644823074, 52.00048327445984, 50.83929218351841, 53.92915338277817, 55.33063217997551, 53.89080584049225, 57.961341217160225, 46.51782587170601, 37.057496309280396, 51.55244551599026, 56.37211449444294, 54.450101628899574, 53.74471887946129, 53.263493701815605, 54.22698140144348, 50.28349220752716, 47.522602155804634, 44.589657336473465, 46.79421164095402, 46.539636701345444, 43.49380373954773, 44.05343770980835, 44.49974276125431, 44.0561393648386, 44.284621104598045, 41.84067204594612, 42.978046014904976, 37.19338841736317, 37.63621285557747, 39.02572609484196, 36.78944729268551, 40.8068273216486, 39.12561133503914, 39.1080866754055, 42.0459408313036, 48.36603529751301, 51.200740188360214, 50.48568695783615, 53.16171996295452, 45.18063582479954, 47.48530715703964, 47.45649330317974, 54.721703454852104, 54.591507241129875, 57.551909387111664, 54.328318163752556, 53.625967651605606, 36.26198619604111, 43.66932012140751, 59.530421420931816, 53.1411212682724, 55.48434533178806, 45.6732489913702, 43.71342435479164, 45.152293145656586, 49.0637082606554, 51.066443994641304, 53.20524662733078, 51.79468251764774, 51.83536693453789, 48.7237823009491, 45.93415439128876, 48.334458991885185, 45.51129028201103, 49.01579663157463, 47.706531286239624, 50.26646912097931, 47.040145844221115, 50.50665803253651, 49.65569369494915, 55.34192897379398, 63.7586635351181, 74.57941889762878, 65.21754965186119, 89.00469124317169, 21.417706534266472, 0.9250048489775509, 0.953786582686007, 0.1630274168564938, 53.909926414489746, 67.10433080792427, 65.66777989268303, 62.9165755212307, 31.224064528942108, 49.52234365046024, 55.83245985209942, 45.51633261144161, 57.03326001763344, 56.39858387410641, 6.479508262127638, 0.10832846877747215, 0.140762526425533, 0.061872024307376705, 0.04480362964386586, 0.028954850786249153, 0.07330556254601106, 0.05431453413621057, 0.055862516892375425, 0.05520782018720638, 0.0390996941132471, 0.028165231633465737, 0.04497789705055766, 0.5932242271956056, 42.742261067032814, 65.14084696769714, 51.07189290225506, 46.65798135101795, 70.9007678925991, 92.70870208740234, 41.697700917720795, 69.04348835349083, 60.15374377369881, 81.46581217646599, 17.026132084429264, 0.04302735113014933, 1.0710191982798278, 0.0425362942769425, 0.14357048668898642, 26.76554337143898, 83.3649730682373, 61.55910976231098, 64.6941277384758, 51.598122864961624, 56.52391254901886, 48.27103279531002, 51.099597215652466, 49.08110752701759, 51.02470703423023, 47.4345076829195, 49.33230444788933, 45.72184078395367, 46.4903761446476, 45.52658066153526, 49.45029951632023, 50.76461859047413, 49.778392910957336, 46.44455820322037, 47.0265007764101, 52.002922743558884, 56.23892784118652, 54.42509137094021, 58.97929139435291, 54.897805005311966, 52.60087765753269, 54.634821116924286, 59.36152048408985, 58.30537095665932, 59.33879770338535, 59.577618688344955, 61.643560230731964, 53.56747359037399, 50.79885855317116, 50.669593289494514, 54.766879230737686, 54.53606441617012, 53.65103490650654, 53.19744944572449, 53.109586760401726, 47.46221959590912, 44.29404079914093, 39.094950780272484, 42.48737454414368, 40.60323424637318, 40.85284285247326, 40.92209033668041, 39.558054730296135, 43.71633879840374, 44.29406359791756, 44.37334634363651, 48.246254324913025, 45.50700031220913, 46.75940550863743, 46.63243152201176, 47.06738658249378, 49.67273958027363, 49.26494546234608, 49.95315693318844, 54.4683900475502, 52.82233737409115, 56.509648114442825, 55.22280916571617, 57.58056364953518, 58.89355659484863, 47.918647304177284, 37.94496148824692, 52.19474785029888, 58.011095747351646, 56.72465577721596, 57.40612640976906, 57.14699171483517, 55.85887983441353, 53.106782510876656, 49.6601128578186, 47.10208632051945, 48.20083536207676, 47.838718593120575, 44.40315194427967, 47.28984944522381, 46.92266754806042, 46.665402352809906, 46.443999633193016, 46.591739505529404, 44.03552167117596, 40.41886433959007, 40.683934316039085, 42.188330590724945, 38.70853811502457, 42.43896894156933, 41.32033936679363, 42.74400897324085, 46.21802195906639, 51.91402651369572, 53.67064945399761, 53.83090205490589, 53.101181611418724, 49.2514181882143, 49.86074969172478, 48.66413310170174, 57.360323667526245, 56.73986256122589, 59.00179758667946, 57.37930364906788, 55.83264224231243, 37.54660986363888, 46.53429798781872, 62.94866859912872, 55.94318211078644, 57.68539622426033, 48.87768164277077, 46.38286851346493, 47.69668601453304, 51.603757962584496, 54.303235709667206, 56.20286397635937, 55.05885936319828, 53.66774260997772, 52.73613899946213, 50.051168873906136, 49.17794533073902, 48.76718357205391, 51.54532089829445, 49.960870519280434, 52.59647749364376, 49.764432460069656, 53.43812093138695, 52.13219180703163, 59.42881487309933, 66.79199516773224, 76.64668276906013, 66.75027340650558, 94.01791423559189, 20.51069900393486, 0.7254859269596636, 2.0073254127055407, 0.2941122930496931, 59.4810126721859, 74.4301325082779, 72.22033828496933, 71.67017340660095, 40.41617028415203, 59.11438934504986, 61.08270652592182, 47.71528221666813, 70.88778778910637, 67.24527284502983, 7.991696018725634, 0.2489982490078546, 0.14239228272344917, 0.04896945298241917, 0.02926058223238215, 0.0561752022622386, 0.15903590916423127, 0.22539253521244973, 0.1924245394184254, 0.1946744936867617, 0.13945152255473658, 0.12185203217086382, 0.299176144762896, 0.8038437785580754, 52.845307141542435, 74.15175184607506, 64.75901305675507, 53.7322061508894, 78.06870326399803, 99.1392870247364, 49.83806490898132, 79.54088106751442, 63.404389545321465, 89.82638955116272, 18.749873489141464, 0.24610994383692741, 1.9109901320189238, 0.2069661216228269, 0.21269370568916202, 28.406316228210926, 88.94397810101509, 63.854843974113464, 69.14041355252266, 55.22834166884422, 59.38776567578316, 50.369196608662605, 55.14938570559025, 51.56055428087711, 53.828565180301666, 48.71155455708504, 51.65393427014351, 48.64290364086628, 51.41582764685154, 48.691297844052315, 51.21303632855415, 54.71653573215008, 53.36581461131573, 47.762528881430626, 49.257277473807335, 54.1674879938364, 59.499593675136566, 57.62699335813522, 59.99385595321655, 57.01173797249794, 53.10277372598648, 56.81750759482384, 62.182074934244156, 61.448543295264244, 62.65284687280655, 61.63147307932377, 63.0327694863081, 53.39341253042221, 53.92333209514618, 51.15414708852768, 57.63691082596779, 60.27711175382137, 59.54113304615021, 57.35820718109608, 55.33940210938454, 50.303262546658516, 47.44450494647026, 41.54508210718632, 47.03831434249878, 44.35761138796806, 42.530471831560135, 44.16116952896118, 42.026542872190475, 46.685708463191986, 46.660736203193665, 48.30260910093784, 50.116175785660744, 47.47516170144081, 48.92069913446903, 48.53609137237072, 52.460144609212875, 53.00327606499195, 52.429712042212486, 52.6413568854332, 56.796958297491074, 55.37470601499081, 60.01089803874493, 59.54100765287876, 59.589341059327126, 63.95245313644409, 50.050207525491714, 38.18697050213814, 53.572534918785095, 59.77228224277496, 57.922169119119644, 59.46793757379055, 59.170930311083794, 59.82104882597923, 55.59032544493675, 52.57270596921444, 50.88305063545704, 51.661115884780884, 49.69127878546715, 47.60563910007477, 49.119766652584076, 49.33847911655903, 50.230656042695045, 50.56440353393555, 48.56432005763054, 47.07590192556381, 42.42645241320133, 42.69709289073944, 43.217721953988075, 40.42261853814125, 46.15846015512943, 42.96952307224274, 44.68905620276928, 48.02316449582577, 56.04264557361603, 59.38408747315407, 57.69521489739418, 57.83397205173969, 51.56352572143078, 53.34173150360584, 52.4620521068573, 61.184092685580254, 59.56400781869888, 62.45788313448429, 58.47787410020828, 58.124363869428635, 41.637922525405884, 51.36337526142597, 66.35935038328171, 57.795746102929115, 60.79647168517113, 51.780938655138016, 48.70485171675682, 51.001813262701035, 54.67590071260929, 56.23958520591259, 59.37329225242138, 58.287120535969734, 57.17832863330841, 55.84400363266468, 51.64255388081074, 53.296483531594276, 53.00647549331188, 56.3216608017683, 54.86861877143383, 57.16461896896362, 54.64052841067314, 56.13479822874069, 56.41482040286064, 62.00444586575031, 71.55346646904945, 80.5546286702156, 72.15704128146172, 97.72880271077156, 25.71224559098482, 0.7882314256858081, 3.534001079387963, 0.4486157727660611, 63.83244037628174, 81.28656059503555, 80.89009746909142, 76.94680586457253, 47.887538373470306, 65.21486699581146, 63.889110535383224, 61.39689266681671, 75.6488487124443, 83.96200463175774, 10.317337475717068, 0.48319430323317647, 0.30426977144088596, 0.12693028897047043, 0.1411977960378863, 0.1872868588543497], [0.08827743455185555, 0.04263521885150112, 0.0555974477174459, 0.023922814943944104, 0.06586998497368768, 0.08708629495231435, 0.13661616219906136, 0.16422580723883584, 21.231543123722076, 55.95852568745613, 48.617087826132774, 25.218002311885357, 43.712595999240875, 57.53525108098984, 27.741585597395897, 63.83358031511307, 54.45088818669319, 77.063839584589, 29.344001412391663, 0.017197611850860994, 0.7140238420106471, 0.37132646539248526, 0.4969317832728848, 10.370074845850468, 84.0757705271244, 62.11748220026493, 64.66018036007881, 55.42754217982292, 54.984611347317696, 49.383119121193886, 50.84758713841438, 47.67711706459522, 46.93522967398167, 44.85780894756317, 47.08441726863384, 44.556591510772705, 47.97789752483368, 46.992348209023476, 50.31001478433609, 49.8901791125536, 48.08704286813736, 45.10912746191025, 47.490170896053314, 48.22996459901333, 54.505848437547684, 55.95518946647644, 52.07293398678303, 48.51792074739933, 56.42378032207489, 58.2822871953249, 56.43668822944164, 54.607139602303505, 56.773908734321594, 55.806560441851616, 55.69127842783928, 50.61673432588577, 48.744909167289734, 48.23890931904316, 51.91460408270359, 52.64201045036316, 48.78543399274349, 47.68419988453388, 48.11630129814148, 43.35930995643139, 46.28946952521801, 41.336461901664734, 38.5916867852211, 38.559183329343796, 40.261263996362686, 38.54328118264675, 38.929416462779045, 40.3519993275404, 41.976438760757446, 44.23181153833866, 47.502983808517456, 45.19712693989277, 45.655184760689735, 45.343031510710716, 44.93038885295391, 46.38661891222, 46.32834903895855, 50.0208654999733, 51.565813198685646, 50.86709909141064, 54.27077405154705, 52.873323038220406, 51.98302701115608, 57.63538330793381, 49.68156270682812, 41.231545731425285, 56.56791418790817, 55.54376274347305, 54.63844992220402, 56.254305616021156, 51.75020970404148, 52.42794893682003, 50.209225192666054, 46.972486674785614, 45.058069601655006, 47.49933980405331, 44.21495944261551, 41.73328600823879, 44.04386982321739, 44.05895881354809, 42.15518116950989, 43.237195909023285, 39.29995737969875, 39.063085690140724, 38.54521527886391, 38.733388781547546, 37.576894238591194, 38.51118430495262, 38.69417108595371, 37.795561105012894, 39.36176486313343, 46.46873630583286, 47.498918026685715, 48.19937244057655, 50.911602303385735, 53.57426002621651, 49.77485150098801, 47.33645774424076, 49.471540376544, 49.71778616309166, 54.869815707206726, 55.070612132549286, 59.37437139451504, 47.51616530120373, 13.493743781000376, 46.802776381373405, 57.03153870999813, 55.01393437385559, 53.688136115670204, 53.494886085391045, 44.44452412426472, 45.15937216579914, 46.794021651148796, 52.955326437950134, 55.34756027162075, 56.70423947274685, 53.71366694569588, 53.6033246666193, 48.60335536301136, 49.4507022947073, 46.11380875110626, 47.42251172661781, 45.41045509278774, 50.076080337166786, 47.57979668676853, 53.30170825123787, 50.74136383831501, 62.09092162549496, 65.51343977451324, 72.94492900371552, 69.93638724088669, 76.50399282574654, 1.6949478560127318, 0.3726827848004177, 0.06632046119193546, 0.8477779116947204, 62.5126875936985, 59.768870025873184, 71.80834919214249, 52.4667676538229, 35.512297824025154, 39.4444028288126, 21.806123591959476, 40.789770036935806, 61.673050448298454, 61.02940298616886, 6.49928430095315, 0.2507399657042697, 0.17287742346525192, 0.02484922675648704, 0.07597042931593023, 0.041840872218017466, 0.06527700155857019, 0.11132068204460666, 0.03045450859644916, 0.05281438279780559, 0.04944777458149474, 0.032744312484283, 0.1181008986895904, 0.2330950039322488, 30.85709922015667, 66.49288281798363, 51.549211889505386, 36.958914399147034, 65.81879898905754, 67.8024597465992, 36.39174163341522, 73.05885449051857, 60.17031468451023, 82.07988202571869, 30.309079326689243, 0.06988793538766913, 0.7788661157246679, 0.3025361738400534, 0.5246560752857476, 11.351410187780857, 85.03578141331673, 63.52143466472626, 68.49740445613861, 54.79667343199253, 57.88584686815739, 51.89417637884617, 54.04584512114525, 50.21843209862709, 51.209890097379684, 46.490425541996956, 50.106417909264565, 47.46944300830364, 49.79304492473602, 49.57097344100475, 53.49998161196709, 52.186707481741905, 50.141550824046135, 48.35718937218189, 49.21201430261135, 51.44907586276531, 56.69351264834404, 57.19218268990517, 55.915755182504654, 51.79685220122337, 58.66854786872864, 59.720000848174095, 59.821831583976746, 59.19542379677296, 57.548394575715065, 56.4438546448946, 60.60366243124008, 53.9877500385046, 50.41121855378151, 51.6145683825016, 55.4264098405838, 56.621134132146835, 52.21772521734238, 51.99213892221451, 51.82389535009861, 46.54267653822899, 47.98205070197582, 44.699281454086304, 41.58445179462433, 40.78980043530464, 42.490220591425896, 39.428835064172745, 41.20845437049866, 42.99424834549427, 41.88166804611683, 46.65948987007141, 48.78729589283466, 46.49964764714241, 47.87232778966427, 47.463914304971695, 48.3116640150547, 47.945599257946014, 50.76820179820061, 51.86092056334019, 53.78641024231911, 52.76713013648987, 58.21045584976673, 56.054554134607315, 54.407175332307816, 59.394837096333504, 50.992518961429596, 39.45561982691288, 56.554633900523186, 55.59309929609299, 56.72475457191467, 57.16030240058899, 51.660979092121124, 54.2483514547348, 53.68285819888115, 49.122373312711716, 47.515124157071114, 49.275269508361816, 46.79891958832741, 44.083292707800865, 46.838148683309555, 45.97182556986809, 43.920653834939, 44.27275434136391, 43.58436807990074, 40.660481974482536, 40.5188749730587, 40.092237666249275, 41.27572976052761, 41.44271939992905, 42.22453124821186, 38.05439941585064, 42.36969105899334, 49.030327051877975, 52.560584619641304, 52.65257008373737, 54.07448038458824, 57.25878931581974, 52.60822646319866, 49.79181759059429, 51.30556136369705, 51.73012018203735, 57.064805924892426, 56.55921645462513, 63.12507413327694, 47.65095926821232, 19.112035855650902, 52.577805295586586, 56.45653076469898, 60.462002232670784, 55.128665417432785, 56.115198880434036, 47.59993940591812, 46.39569662511349, 48.97317431867123, 56.061807945370674, 57.871301248669624, 58.23144592344761, 58.86378899216652, 56.06900855898857, 52.408873960375786, 52.08114914596081, 48.781174421310425, 50.28628505766392, 48.56867842376232, 51.52057282626629, 51.14903636276722, 57.714787647128105, 53.91095615923405, 65.73965683579445, 68.7269577383995, 76.13770008087158, 74.15596961975098, 80.37787735462189, 1.787621439434588, 0.7735125592444092, 0.131507484766189, 1.308127543888986, 70.43045952916145, 67.38823637366295, 80.74107706546783, 58.94382409751415, 40.57543873786926, 43.698810338974, 31.539227217435837, 49.95623096823692, 62.676853984594345, 76.4953900873661, 10.666892118752003, 0.30521016160491854, 0.1297320003504865, 0.10263114207191393, 0.026317118790757377, 0.11312078349874355, 0.16862031596247107, 0.21245238895062357, 0.29459810291882604, 0.16358119260985404, 0.16280818643281236, 0.20331053965492174, 0.27124633721541613, 0.4720240901224315, 43.98502618074417, 77.92029082775116, 65.81777304410934, 38.23824495077133, 55.21550975739956, 73.06480497121811, 42.152794897556305, 79.42488089203835, 64.83760043978691, 88.74869138002396, 35.16356013715267, 0.178589437273331, 1.5718911029398441, 0.8095960761420429, 0.7731382199563086, 12.943493407219648, 88.46559897065163, 65.89198306202888, 71.76912009716034, 59.491583704948425, 60.47863394021988, 54.38551649451256, 56.40608087182045, 53.43603864312172, 53.38220693171024, 48.41993920505047, 52.07677558064461, 48.80383640527725, 52.99935847520828, 51.63044773042202, 57.31888689100742, 56.566724851727486, 53.24242003262043, 52.22442805767059, 52.95076668262482, 52.738171890378, 60.00163413584232, 61.31034471094608, 58.12796987593174, 53.86852763593197, 60.99920980632305, 62.89884567260742, 61.307825446128845, 59.838672280311584, 59.49270084500313, 57.539476454257965, 63.4084515273571, 55.410351902246475, 52.80169688165188, 52.70573303103447, 59.03296731412411, 61.774151623249054, 58.2389847189188, 55.83574667572975, 55.529228523373604, 49.41419005393982, 52.31291010975838, 47.329078540205956, 45.85245117545128, 41.93247511982918, 45.01048095524311, 41.42775200307369, 42.532212138175964, 44.237226247787476, 44.52967755496502, 48.291213512420654, 53.6750990152359, 50.39596237242222, 52.84218370914459, 50.56413374841213, 50.7244623452425, 49.139685183763504, 51.85821890830994, 52.82351151108742, 58.20825196802616, 54.649621322751045, 61.60639062523842, 59.15183633565903, 55.01862332224846, 63.359798938035965, 52.673434764146805, 41.92932888865471, 58.043663799762726, 57.57116295397282, 61.286223605275154, 60.742651373147964, 53.67735989391804, 55.67943446338177, 56.82267911732197, 51.97684854269028, 51.83101236820221, 52.34857499599457, 50.35649009048939, 45.71560151875019, 49.331597685813904, 50.01152940094471, 46.84762917459011, 48.293238803744316, 46.35127700865269, 43.22427660226822, 44.00641903281212, 42.782626301050186, 43.199885711073875, 45.521865114569664, 43.564734533429146, 42.462375685572624, 45.3158325701952, 54.41992744803429, 55.472402572631836, 56.52275741100311, 59.38816465437412, 59.34390842914581, 54.611813351511955, 53.93386512994766, 54.432599768042564, 54.90090183913708, 60.31567208468914, 60.53669102489948, 65.99329322576523, 51.2137620896101, 18.26936647295952, 49.89239439368248, 60.67947216331959, 62.087722197175026, 58.68158496916294, 59.62103895843029, 51.37590318918228, 49.17837470769882, 50.923195481300354, 57.87803068757057, 60.81053473055363, 60.768436789512634, 59.634600430727005, 58.104323744773865, 55.68073399364948, 55.47603897750378, 52.29774512350559, 53.702586740255356, 53.14084008336067, 56.19919717311859, 52.94983193278313, 61.13651163876057, 57.278764843940735, 69.91151377558708, 72.21528455615044, 79.04364734888077, 74.37187403440475, 86.83514446020126, 3.304308867082, 1.093427783343941, 0.8036782499402761, 1.3685650820843875, 77.14381769299507, 72.38081887364388, 85.62782004475594, 67.46556982398033, 51.80163234472275, 59.310371428728104, 33.22801999747753, 55.77836215496063, 75.89190647006035, 90.81305980682373, 15.19368041306734, 0.6657379330135882, 0.4255611333064735, 0.21433823072584346, 0.21452593471622095, 0.28332007059361786], [0.0924145441967994, 0.02195322551415302, 0.052948618758819066, 0.03602492062782403, 0.02796322645735927, 0.051275213045300916, 0.2771494095213711, 0.6899606832303107, 27.8020004555583, 57.57435478270054, 59.07908543944359, 47.77921758592129, 15.138512123376131, 28.231424912810326, 31.717701740562916, 56.75800658762455, 65.19992619752884, 63.21652002632618, 54.53634560108185, 0.38214822532609105, 0.011130620459880447, 0.3144271607743576, 0.11560141952941194, 1.2268195068463683, 64.89832118153572, 68.98136168718338, 60.776241570711136, 61.04939751327038, 60.38497656583786, 58.320022970438, 54.78518284857273, 52.56816901266575, 48.385969027876854, 46.49675600230694, 45.364956334233284, 47.384361773729324, 49.67647098004818, 51.890604570508, 50.85129573941231, 50.335674807429314, 48.02737466990948, 43.82810980081558, 44.143071100115776, 51.6141352057457, 56.62471354007721, 56.437231600284576, 52.23764754831791, 54.96601514518261, 56.79651752114296, 57.751068100333214, 56.824579015374184, 54.52879160642624, 54.03489790856838, 54.561177268624306, 52.926128804683685, 48.31133723258972, 49.977019652724266, 50.84171645343304, 53.03948052227497, 50.41163273155689, 47.68157422542572, 48.47055248916149, 48.370705246925354, 44.10498574376106, 46.51715710759163, 45.96442736685276, 37.920958176255226, 38.30659568309784, 36.44194453954697, 37.64511197805405, 38.29665921628475, 42.62749582529068, 38.588175773620605, 44.53853867948055, 45.95368534326553, 43.21573846042156, 43.358276411890984, 45.20482912659645, 46.0566446185112, 45.85175581276417, 48.95245403051376, 51.80406801402569, 48.1940983235836, 50.070806220173836, 51.643013656139374, 54.66723717749119, 52.51507066190243, 53.951754570007324, 51.27167098224163, 41.62679672241211, 58.6903814971447, 59.16497603058815, 53.97975906729698, 54.06351797282696, 50.82164593040943, 53.69536712765694, 51.63177765905857, 49.10456366837025, 48.4872829914093, 44.689686968922615, 45.2678981423378, 45.687855407595634, 43.020767122507095, 43.86732369661331, 43.23716551065445, 42.67547585070133, 39.94976431131363, 38.302545100450516, 40.7658389210701, 39.52700659632683, 38.5701647400856, 38.60787771642208, 37.91659601032734, 39.30467292666435, 42.87200890481472, 45.855741798877716, 50.22476635873318, 48.71858038008213, 49.08536709845066, 51.80326245725155, 51.94334574043751, 43.79864618182182, 51.54635064303875, 46.1722382158041, 57.06719979643822, 52.19991937279701, 61.16598665714264, 48.34104023873806, 30.39199087768793, 49.71704140305519, 50.1139111071825, 58.71009103953838, 54.42513696849346, 52.04685978591442, 49.49475713074207, 47.99258753657341, 43.58885183930397, 53.347153812646866, 50.00393360853195, 58.19683738052845, 57.921963930130005, 54.81967359781265, 51.99034541845322, 50.56472271680832, 50.975488275289536, 48.23622666299343, 47.6151005923748, 47.671949341893196, 49.170778915286064, 52.19743050634861, 56.90153248608112, 63.91791298985481, 70.5386321246624, 71.26756221055984, 80.91661244630814, 35.09074084460735, 0.9412006486672908, 0.4221504007000476, 0.44084943481720984, 7.244781497865915, 70.15011057257652, 60.44982008635998, 74.40922603011131, 52.01757475733757, 35.073052793741226, 49.98984396457672, 27.691565081477165, 33.177437111735344, 57.45155677199364, 57.98912912607193, 17.602914534509182, 0.24203395005315542, 0.18211178889032453, 0.00932582584937336, 0.05602685807389207, 0.05795068296720274, 0.0735596961749252, 0.03247225969971623, 0.0908152901683934, 0.08888319032848813, 0.03189013761584647, 0.039037687674863264, 0.30039237637538463, 0.7520063663832843, 38.60573083162308, 65.0058402121067, 68.81952077150345, 44.909315183758736, 19.428971149027348, 39.98998135328293, 36.96890786290169, 61.365912929177284, 69.10029530525208, 69.63473662734032, 57.177070900797844, 0.33955544990021735, 0.4565984319197014, 0.45823655964341015, 0.12509203370427713, 1.2622638861648738, 66.14079371094704, 70.77150642871857, 65.54345816373825, 63.474423587322235, 61.81564539670944, 59.34062160551548, 57.698452323675156, 53.77233199775219, 51.524832397699356, 49.95871603488922, 47.84558102488518, 51.36841379106045, 51.77296668291092, 54.79540430009365, 52.64054372906685, 52.93711021542549, 50.40878288447857, 46.55420891940594, 46.75022520124912, 55.191590040922165, 58.97983096539974, 58.24660710990429, 54.72056731581688, 57.16680385172367, 57.2821656614542, 59.310029447078705, 58.74506056308746, 56.13276153802872, 56.71668000519276, 56.833250150084496, 54.37133185565472, 51.6998890042305, 50.234102457761765, 53.067568615078926, 57.109130546450615, 55.900913178920746, 52.65157453715801, 51.9971888512373, 50.778913423419, 47.548775151371956, 48.272537514567375, 49.698376804590225, 39.13673333823681, 41.74131877720356, 39.9676613509655, 36.99514925479889, 41.17964431643486, 44.945861622691154, 40.75745277106762, 47.248025089502335, 46.88487857580185, 45.644568130373955, 45.08201591670513, 46.212922632694244, 47.81578682363033, 47.34073631465435, 50.67560836672783, 53.95417504012585, 50.95346845686436, 52.879341915249825, 54.01314787566662, 56.76579996943474, 55.6539112329483, 57.80160918831825, 50.590340942144394, 41.61061719059944, 58.36608029901981, 59.06427003443241, 57.41334222257137, 56.47144116461277, 53.63935433328152, 55.31045526266098, 55.03866724669933, 51.84324011206627, 50.50568528473377, 46.318895146250725, 48.851181864738464, 48.22982020676136, 45.76231621205807, 46.10702991485596, 44.898227378726006, 42.96337120234966, 42.97278329730034, 41.6081815212965, 40.88216207921505, 41.464610025286674, 40.3867294639349, 40.33274196088314, 39.715495482087135, 42.42060832679272, 47.27482125163078, 48.53396348655224, 54.50514927506447, 50.90845227241516, 52.141429111361504, 56.867729499936104, 52.374041229486465, 47.73576691746712, 52.32554443180561, 48.906157314777374, 59.6965941041708, 54.34420131146908, 61.11771784722805, 56.53359442949295, 41.49819262325764, 50.00485695898533, 51.00156627595425, 62.598562985658646, 58.18022847175598, 56.39218121767044, 54.00467813014984, 51.22109189629555, 47.191875502467155, 55.496884658932686, 54.139646887779236, 62.14342340826988, 59.76857744157314, 58.02929677069187, 55.158558413386345, 54.82383817434311, 54.20658029615879, 51.334067434072495, 49.93793115019798, 51.08810283243656, 53.94014999270439, 54.299367517232895, 59.26065109670162, 67.92849138379097, 73.58270958065987, 73.63833099603653, 81.0933181643486, 35.44015869498253, 1.0010839509777725, 1.8773980345577002, 0.5730967072304338, 8.587969522923231, 76.29545241594315, 68.92099812626839, 80.08355274796486, 57.023395746946335, 32.11675822734833, 61.40721671283245, 30.293502062559128, 40.07205314934254, 63.79827260971069, 71.19564726948738, 19.97639637440443, 0.2685715479310602, 0.2456707408418879, 0.012427230376488296, 0.11642668032436632, 0.025356941114296205, 0.11161111411638558, 0.087555525242351, 0.1539199735270813, 0.19518368120770901, 0.17269059520913288, 0.16779770463472232, 0.37456139805726707, 0.7647688721772283, 50.25537371635437, 78.85118767619133, 77.60032519698143, 65.70459231734276, 24.988247640430927, 42.49673344194889, 47.841386049985886, 67.81003654003143, 76.27120971679688, 74.10602509975433, 64.43182021379471, 0.7252538425382227, 0.8289020683150738, 1.064190489705652, 0.3920501080574468, 1.4390851417556405, 70.44769540429115, 71.99102059006691, 68.02459582686424, 66.4919100701809, 64.28750395774841, 62.85208158195019, 61.265970692038536, 56.619838401675224, 53.73102821409702, 51.73209607601166, 49.798011258244514, 53.632396906614304, 55.108290910720825, 57.045803144574165, 55.17902411520481, 54.228220134973526, 53.606801480054855, 48.33285167813301, 48.98452430963516, 57.46495105326176, 63.4274847060442, 61.90338268876076, 56.036581099033356, 57.57734142243862, 60.93129605054855, 63.463628366589546, 62.26433292031288, 57.84955881536007, 58.95213425159454, 59.43319983780384, 57.27365791797638, 52.539970725774765, 51.588801965117455, 57.67145857214928, 60.98305307328701, 61.45274966955185, 58.706207647919655, 56.68755076825619, 55.24422861635685, 50.688622668385506, 53.01314413547516, 53.18715579807758, 42.11381658911705, 43.47647666931152, 41.60235643386841, 39.440789222717285, 43.4011647105217, 49.25488360226154, 41.37487404048443, 49.85410764813423, 49.91354025900364, 48.8441826403141, 49.25609193742275, 49.0630166977644, 51.295058727264404, 49.70904663205147, 53.29349689185619, 58.36336724460125, 54.38141651451588, 55.206793025135994, 57.601800709962845, 59.37990389764309, 57.51424580812454, 59.06740866601467, 54.523403495550156, 42.69742727279663, 62.768436670303345, 63.3786953240633, 62.34318248927593, 60.86080223321915, 56.56958609819412, 58.89540709555149, 58.18246655166149, 53.74418690800667, 53.20329733192921, 47.18321196734905, 52.238802686333656, 51.18085965514183, 47.69631363451481, 48.81135620176792, 46.4353246986866, 46.56833656132221, 44.43379729986191, 46.33515067398548, 45.921607464551926, 43.74163404107094, 42.12292470037937, 43.34613986313343, 41.283055767416954, 44.821239709854126, 50.69428436458111, 51.40552639961243, 57.87605859339237, 55.79286217689514, 56.696860268712044, 59.15663167834282, 57.29779802262783, 48.80271166563034, 55.52933111786842, 51.25637300312519, 64.74777325987816, 57.841545045375824, 66.84290483593941, 54.64909315109253, 31.12007360905409, 51.20266668498516, 54.55681890249252, 65.27153715491295, 58.52061800658703, 58.66141565144062, 55.38291357457638, 55.36662004888058, 50.8892785012722, 58.539419397711754, 55.150008872151375, 65.34149140119553, 63.29185478389263, 61.889942809939384, 57.56284140050411, 57.41937629878521, 57.77863182127476, 54.4085356593132, 52.52289444208145, 54.13479834794998, 55.373178496956825, 60.04302531480789, 62.163501530885696, 70.4348672926426, 76.81748360395432, 76.60126760601997, 84.98170271515846, 42.12640531361103, 0.9552254586014897, 3.265326996333897, 0.6733179918956012, 9.634906444698572, 82.49426499009132, 73.73876720666885, 85.00521585345268, 69.56932693719864, 47.01047703623772, 73.70257794857025, 37.96677611768246, 47.25848212838173, 73.52345556020737, 86.8520687520504, 25.101954638957977, 0.8486747229471803, 0.342298605828546, 0.1198767838650383, 0.3389739623526111, 0.11055456299800426], [0.05333661727490835, 0.06179747557325754, 0.060973290892434306, 0.0623685990285594, 0.08196163907996379, 0.05705150426365435, 0.21429190586786717, 0.5076714023016393, 31.94336973130703, 64.67728704214096, 41.106160059571266, 51.21738329529762, 36.74723535776138, 28.384404703974724, 41.00399874150753, 59.5030514895916, 70.61199858784676, 52.86847069859505, 70.86606055498123, 3.676983369514346, 0.1490397291490808, 1.4098499855026603, 0.0839060808357317, 0.06748879459337331, 29.205838926136494, 80.2193270623684, 62.55319721996784, 67.06367298960686, 60.88856354355812, 63.57107140123844, 55.232031270861626, 55.29761575162411, 48.39742161333561, 47.00486473739147, 47.754895091056824, 53.37013877928257, 52.52430036664009, 53.2702611386776, 52.75005005300045, 49.165421202778816, 48.10563147068024, 44.89850856363773, 45.29938705265522, 54.24273155629635, 55.75331769883633, 55.94918578863144, 57.394392639398575, 59.35242377221584, 51.752117201685905, 55.51407493650913, 54.997713044285774, 54.19016897678375, 49.433694407343864, 54.35196429491043, 50.273179560899734, 51.825400069355965, 47.44684562087059, 48.388507291674614, 51.869390308856964, 48.373631089925766, 47.78268679976463, 47.70767502486706, 48.6880262196064, 46.21323801577091, 43.22397641837597, 47.865404561161995, 41.845357194542885, 35.76585441827774, 38.23860593140125, 35.43735824525356, 39.67205621302128, 41.85006134212017, 38.982317224144936, 42.11168870329857, 46.82098500430584, 40.28579168021679, 42.19316393136978, 45.11240668594837, 42.274399772286415, 45.6523273140192, 49.850741028785706, 51.053083911538124, 49.666621908545494, 51.128418669104576, 52.15102359652519, 51.96151256561279, 53.90674598515034, 54.927363619208336, 53.77412170171738, 43.98535676300526, 56.81546710431576, 54.72010374069214, 52.92472667992115, 53.7061433494091, 50.877875313162804, 51.58757843077183, 49.35091584920883, 48.55686865746975, 48.01099754869938, 45.346185341477394, 45.75818583369255, 45.064852237701416, 41.46329529583454, 42.03009948134422, 42.04412452876568, 40.698460936546326, 40.961813405156136, 40.05410671234131, 40.093677788972855, 42.4656131118536, 38.48660722374916, 37.42995232343674, 39.55239303410053, 44.863926619291306, 42.40269988775253, 45.71606509387493, 50.55457346141338, 49.496147856116295, 46.84867411851883, 52.295484244823456, 51.78603798151016, 46.68676480650902, 51.22586823999882, 49.29019130766392, 52.814342603087425, 55.40135398507118, 56.3310918956995, 62.7326425909996, 48.008026108145714, 46.52190305292606, 46.3483739644289, 55.793971717357635, 54.92482155561447, 55.289544984698296, 50.554334074258804, 49.00503560900688, 44.54333022236824, 47.22104653716087, 52.34509438276291, 57.11687833070755, 60.19686006009579, 57.26803421974182, 54.815653413534164, 55.76543524861336, 54.73820976912975, 52.905891090631485, 51.97968699038029, 48.03441569209099, 50.4202164709568, 50.31643643975258, 58.37304152548313, 65.51793113350868, 68.75477224588394, 68.56430366635323, 66.10125303268433, 6.632839059457183, 1.1256605037488043, 1.4514134614728391, 0.9027125139255077, 12.971515003591776, 71.69377774000168, 53.79597432911396, 72.11727261543274, 46.83488845825195, 38.886843547225, 43.55590000748634, 28.565495386719704, 51.91891685128212, 53.09244208037853, 75.28406828641891, 26.94407869130373, 0.509110753191635, 0.2686560043366626, 0.08917836472392082, 0.06877717780298553, 0.055873786404845305, 0.08821769908536226, 0.02369728739722632, 0.13029088207986206, 0.03145703878544737, 0.020104858485865407, 0.02447016926453216, 0.3698948922101408, 0.5084267305210233, 40.326639488339424, 75.17252147197723, 53.24957124888897, 47.5492425262928, 39.7826112806797, 34.7775312513113, 43.27527366578579, 62.1371765434742, 75.73649480938911, 58.89836713671684, 76.16017207503319, 3.8954837573692203, 0.14318522298708558, 2.118197288364172, 0.20358703419333324, 0.15746507939184085, 31.02860301733017, 84.54030320048332, 68.80218610167503, 72.8278648853302, 59.727786630392075, 67.61920318007469, 55.6610244512558, 55.91255195438862, 49.275953471660614, 48.12213398516178, 51.3711192458868, 57.337445095181465, 55.64158469438553, 57.8499311953783, 55.24807780981064, 54.57104533910751, 48.99250768125057, 47.330955639481544, 48.94532561302185, 57.37372174859047, 57.69562527537346, 57.80304171144962, 55.442277789115906, 62.33426816761494, 58.61288845539093, 59.80891987681389, 56.28004163503647, 58.18262614309788, 52.62405261397362, 58.4119438380003, 52.66240395605564, 54.75619040429592, 48.29553388059139, 52.827573493123055, 54.107025638222694, 51.24192997813225, 52.21862956881523, 52.08729341626167, 51.86887353658676, 48.36155153810978, 46.12680785357952, 51.22750975191593, 44.61165055632591, 40.543490052223206, 41.9632762670517, 39.35720890760422, 41.8109006434679, 43.49094249308109, 42.601414024829865, 43.686039224267006, 47.18631640076637, 43.683679550886154, 42.9181270301342, 45.58755598962307, 45.65239571034908, 47.77067184448242, 49.10465866327286, 51.49728387594223, 51.06621980667114, 53.25103797018528, 51.80653788149357, 54.67102937400341, 56.71707138419151, 57.322147116065025, 54.27781127393246, 45.190804079174995, 56.354540437459946, 56.38651952147484, 55.49267068505287, 56.0772655159235, 54.265727922320366, 53.43320779502392, 51.8217408657074, 52.080461382865906, 51.169080287218094, 47.609298303723335, 48.96274387836456, 47.22816735506058, 43.98415982723236, 44.93327669799328, 43.88787679374218, 41.879931539297104, 44.036008045077324, 42.113820388913155, 42.500871419906616, 42.88408845663071, 40.287820771336555, 39.04847927391529, 39.672250002622604, 48.06509144604206, 44.96945835649967, 48.029122576117516, 52.66420505940914, 54.6091078966856, 52.33298443257809, 55.276922062039375, 54.70612049102783, 49.225043803453445, 54.87491883337498, 52.0769427716732, 55.47269135713577, 58.56336951255798, 57.605144530534744, 65.0294141471386, 56.62636265158653, 45.73060691356659, 44.56844687461853, 57.974401116371155, 57.92871616780758, 58.73523809015751, 55.96636846661568, 50.592563822865486, 46.6400159150362, 49.27702881395817, 56.12430319190025, 58.674513548612595, 62.47875161468983, 59.63756047189236, 60.175995379686356, 59.59109656512737, 57.551696598529816, 54.55558776855469, 55.19738852977753, 51.67006440460682, 53.91766279935837, 54.13145832717419, 59.92911122739315, 68.41331496834755, 73.5836823284626, 70.50316482782364, 71.76584467291832, 6.40281175263226, 1.0783459176309407, 2.333809593692422, 0.7116341858636588, 14.504053518176079, 78.62974315881729, 62.51879766583443, 77.72517889738083, 51.19003616273403, 38.79392333328724, 55.238479524850845, 33.148900642991066, 50.3535870462656, 59.688101559877396, 86.97765961289406, 33.061064556241035, 0.611713738180697, 0.24307279352797195, 0.05617129114398267, 0.1642990275286138, 0.023023164976621047, 0.1360251009464264, 0.19455387984635308, 0.29247502621728927, 0.20114950952120125, 0.1299945721984841, 0.12337045147432946, 0.33966712828259915, 0.7942587335128337, 52.22129322588444, 85.23426756262779, 60.14466606080532, 68.98947805166245, 48.13614383339882, 44.37142364680767, 56.14077910780907, 70.92076241970062, 84.00498032569885, 63.02044674754143, 85.46518117189407, 4.2005036026239395, 0.3352446109056473, 3.391286674886942, 0.3829051268985495, 0.21027071226853877, 33.673709481954575, 86.4328296482563, 67.68211260437965, 73.77937942743301, 64.6277604997158, 69.53399643301964, 59.74400036036968, 59.35330152511597, 54.00440454483032, 51.992891281843185, 52.44233876466751, 58.37148740887642, 59.85916078090668, 59.660575836896896, 58.47981199622154, 56.81798256933689, 52.3606963455677, 49.55040134489536, 52.302042692899704, 60.31611666083336, 61.51955388486385, 61.24867022037506, 54.30635914206505, 64.52392727136612, 57.987255826592445, 60.8932600915432, 60.45561857521534, 60.73555335402489, 53.44861596822739, 59.18646767735481, 54.955523908138275, 58.31493504345417, 50.82622468471527, 56.37185610830784, 58.340629264712334, 55.65246731042862, 55.69706171751022, 55.84037482738495, 57.77083843946457, 53.047194108366966, 49.29776430130005, 55.43652109801769, 48.395890295505524, 42.28497840464115, 42.74023197591305, 39.469052106142044, 43.59680101275444, 46.95149280130863, 44.554516822099686, 46.900902315974236, 50.95036022365093, 45.80867372453213, 46.385756358504295, 48.7303901463747, 47.68422648310661, 49.0040248632431, 53.41430380940437, 54.69735436141491, 54.29603889584541, 57.67502278089523, 53.53320702910423, 58.50025109946728, 60.657782927155495, 59.70717653632164, 56.85755744576454, 45.92525526881218, 58.20103995501995, 58.23181830346584, 57.555811777710915, 58.02819103002548, 56.61183223128319, 57.076140716671944, 54.402193799614906, 55.37880219519138, 55.332402884960175, 50.59029534459114, 52.576973140239716, 50.26653751730919, 46.64392210543156, 47.87005931138992, 46.14961422979832, 43.57435941696167, 45.28310112655163, 45.058308988809586, 44.834470599889755, 47.10824579000473, 43.68918165564537, 42.30675123631954, 43.38241271674633, 51.44320897758007, 46.88435800373554, 50.82782439887524, 55.21725006401539, 56.65917009115219, 54.03073713183403, 59.59693305194378, 57.728877291083336, 51.02719210088253, 57.01428383588791, 55.78868620097637, 57.75378115475178, 61.6621146351099, 60.41626788675785, 66.04355692863464, 45.61247505247593, 45.965973883867264, 45.687118247151375, 61.6858671605587, 60.55512383580208, 60.980245023965836, 57.90898762643337, 53.68179425597191, 51.4416890591383, 51.51774197816849, 59.26972880959511, 62.247484624385834, 65.54173305630684, 62.19863064587116, 61.655643582344055, 62.35418289899826, 61.126708164811134, 58.03590841591358, 57.91597545146942, 52.64500468969345, 58.127734288573265, 56.87343679368496, 65.33969789743423, 73.425382822752, 77.73654028773308, 74.41396817564964, 77.18270480632782, 9.437852818518877, 1.2128191580995917, 3.9922030549496412, 1.0726824402809143, 16.849158480763435, 84.17906418442726, 68.09469446539879, 82.28019967675209, 64.35365080833435, 51.569328010082245, 62.81881056725979, 40.249651819467545, 67.08203360438347, 70.86302071809769, 97.49513044953346, 37.75670439004898, 0.7390181289520115, 0.42978935642167926, 0.19893056218279526, 0.2888961823191494, 0.1675468438770622], [0.21604717418085784, 0.005140979410498403, 0.07229828261188231, 0.06661380990408361, 0.02838541942765005, 0.04071412135090213, 0.3716513776453212, 0.6932079058606178, 37.04876057803631, 61.583071276545525, 51.34401910007, 44.87483963370323, 20.131464153528214, 34.566095396876335, 43.881253749132156, 52.938690930604935, 72.56939515471458, 49.98793266713619, 73.40339720249176, 18.90055440366268, 0.3015214204788208, 1.4414049172773957, 0.36082715378142893, 0.07921689495560713, 4.6719609294086695, 68.38911026716232, 65.26672661304474, 63.91373321413994, 62.67614342272282, 61.57128430902958, 57.56927065551281, 55.23499131202698, 46.50526374578476, 46.31774760782719, 50.32031983137131, 53.61386530101299, 51.808464378118515, 55.5563210695982, 51.6895991563797, 50.17874702811241, 45.27133695781231, 44.33541677892208, 46.48711211979389, 57.33786307275295, 53.57842840254307, 65.61790376901627, 65.8122481405735, 57.66621485352516, 56.93520247936249, 56.26551501452923, 53.107116892933846, 55.09284853935242, 51.864279583096504, 52.65820138156414, 49.327011331915855, 53.172819167375565, 48.702317252755165, 50.070848017930984, 52.38913781940937, 50.16220271587372, 49.50400583446026, 48.07971306145191, 46.26950539648533, 46.82432882487774, 42.994088754057884, 45.732370018959045, 46.294508054852486, 39.53258849680424, 40.6024818867445, 39.46253925561905, 39.38316911458969, 41.133564189076424, 41.93594813346863, 41.86026379466057, 42.929458022117615, 41.54881350696087, 41.919601410627365, 43.81197966635227, 44.06077891588211, 46.401764899492264, 46.05802774429321, 49.68618705868721, 50.073789060115814, 50.09797856211662, 51.06582462787628, 56.01480446755886, 52.99351438879967, 56.82687409222126, 53.50679464638233, 48.497884422540665, 57.731696739792824, 54.67917613685131, 50.66245347261429, 51.23694844543934, 51.64777860045433, 50.619549974799156, 51.369124352931976, 48.926550820469856, 46.033796444535255, 43.95601473748684, 44.80808101594448, 44.71425645053387, 43.327209278941154, 40.97663640975952, 42.87688784301281, 41.03058211505413, 39.86730873584747, 41.11599013209343, 41.202389895915985, 40.2277497947216, 36.518065854907036, 38.60399432480335, 42.32828088104725, 43.73033344745636, 42.20716618001461, 47.424776405096054, 48.95136348903179, 46.167568266391754, 48.1696542352438, 50.620450526475906, 54.554326236248016, 45.82679495215416, 50.881948694586754, 46.9658712297678, 53.50688964128494, 56.721874326467514, 56.08150988817215, 56.8953388184309, 58.07987205684185, 58.46440002322197, 53.35875079035759, 54.28816571831703, 57.67532296478748, 56.36984221637249, 53.94671604037285, 48.88014771044254, 44.28728096187115, 43.62611263990402, 50.98503716289997, 55.04890389740467, 59.305511489510536, 58.61957989633083, 59.88570235669613, 59.80089470744133, 56.746451407670975, 57.01970994472504, 58.623980060219765, 53.438170328736305, 51.391280964016914, 55.36229208111763, 55.525842905044556, 63.519853949546814, 62.51787431538105, 73.56508612632751, 56.32467783987522, 0.744895285461098, 0.9603206883184612, 1.3356993393972516, 0.48389497969765216, 19.58331886678934, 69.70102027058601, 48.51310260593891, 69.49712321162224, 54.25566226243973, 44.01582732796669, 42.60783188045025, 23.501317128539085, 32.356741949915886, 57.37941764295101, 74.9478243291378, 22.19293523579836, 0.7075040449853987, 0.28470236517023295, 0.08870155710610561, 0.11256202793447301, 0.08820477829431184, 0.13865231856470928, 0.03138189633318689, 0.09945505429641344, 0.12045140654663555, 0.03029912884812802, 0.018641385941009503, 0.3209760499885306, 0.5605962092522532, 45.72568617761135, 75.06272256374359, 53.10366287827492, 52.56697587668896, 34.41400855779648, 38.286152780056, 48.761236891150475, 58.08144137263298, 80.05270600318909, 56.15464836359024, 81.67630568146706, 19.653390906751156, 0.12116219106246717, 1.8718605441972613, 0.4583767068106681, 0.06605929942452349, 5.037815272808075, 68.8963982462883, 73.52743774652481, 73.7866522371769, 62.79106065630913, 64.3042154610157, 58.40453423559666, 56.40699282288551, 48.44463028013706, 49.880444034934044, 51.845808774232864, 56.97369821369648, 55.641934275627136, 59.367938339710236, 54.666781201958656, 53.22957672178745, 47.21334435045719, 48.0917052179575, 49.058817923069, 60.45407585799694, 55.814680606126785, 62.84446679055691, 64.92887914180756, 62.62944392859936, 57.651372849941254, 58.433541879057884, 55.02634830772877, 58.24189156293869, 55.08553013205528, 56.455007046461105, 50.75823873281479, 55.19664376974106, 51.75626277923584, 53.469659239053726, 53.767027482390404, 52.502660527825356, 52.68024779856205, 52.74536490440369, 50.25335982441902, 49.18231129646301, 43.99107165634632, 48.678006157279015, 49.03636872768402, 42.962128669023514, 42.20188066363335, 41.70435056090355, 41.13476112484932, 43.631595745682716, 42.524684742093086, 44.27220717072487, 43.28875154256821, 43.86004328727722, 42.37731344997883, 42.88970835506916, 45.86382396519184, 49.52629163861275, 48.92658121883869, 52.87069357931614, 52.334226965904236, 52.468564957380295, 51.50801070034504, 56.71290680766106, 55.82699574530125, 58.837023228406906, 54.507436752319336, 49.49041396379471, 60.02344496548176, 55.51720976829529, 54.422002136707306, 52.9627550393343, 55.16953602433205, 53.406844809651375, 52.270770370960236, 52.341488376259804, 47.53496669232845, 47.48779982328415, 47.674590200185776, 47.45895177125931, 44.4499958306551, 42.50723987817764, 45.77477194368839, 42.58357398211956, 42.599244341254234, 41.837107837200165, 42.98159122467041, 41.80821418762207, 40.39425306022167, 40.06346181035042, 41.99116297066212, 48.03416110575199, 44.49086643755436, 48.745612129569054, 52.30661764740944, 51.16195946931839, 51.64271727204323, 53.47384661436081, 57.54182852804661, 48.460977002978325, 53.48737008869648, 49.401665925979614, 55.706367418169975, 58.88107046484947, 58.20585809648037, 58.02339568734169, 60.11658176779747, 62.284540235996246, 55.47990716993809, 55.09003669023514, 60.52580840885639, 57.512019127607346, 55.27084618806839, 53.294819220900536, 47.76670105755329, 46.17740973830223, 53.14655497670174, 57.81397372484207, 60.30588760972023, 63.21754977107048, 64.60584327578545, 63.74561503529549, 62.33247846364975, 61.40358030796051, 61.64546772837639, 58.38675118982792, 55.455132499337196, 57.57964789867401, 58.91349412500858, 66.8602243065834, 66.03344187140465, 78.0906280875206, 59.74882610142231, 0.6903958786278963, 1.2195107177831233, 2.504677874967456, 0.5947030009701848, 23.410378508269787, 78.66625919938087, 53.77137444913387, 76.35121062397957, 56.95589616894722, 50.30161343514919, 50.75478471815586, 31.15199189633131, 38.619714081287384, 62.39488631486893, 83.75087276101112, 27.717874869704247, 0.7602752570528537, 0.3306377143599093, 0.05857475123775657, 0.12386272544972599, 0.025053098434000276, 0.29224976955447346, 0.09532303578453138, 0.23086146597051993, 0.2356046950444579, 0.19143534562317654, 0.17372571310261264, 0.6054502492770553, 0.9179071860853583, 56.6554918885231, 77.87913143634796, 69.96445253491402, 59.47399444878101, 27.897747717797756, 51.08056403696537, 56.47571213543415, 64.64297488331795, 85.16226902604103, 61.25998221337795, 86.59937471151352, 22.66868870705366, 0.6751525809522718, 3.1521609937772155, 1.1267276527360082, 0.2562003320781514, 5.811810940504074, 72.68420219421387, 65.78961655497551, 72.68295586109161, 68.20457696914673, 66.09710365533829, 62.377699837088585, 59.25753526389599, 51.496189534664154, 52.11723580956459, 55.59385545551777, 58.647424802184105, 58.3506303280592, 61.51325762271881, 58.2703710347414, 54.18438948690891, 49.02911491692066, 48.95340397953987, 52.895342856645584, 62.97020964324474, 59.760476276278496, 61.59455046057701, 67.05618739128113, 68.16021054983139, 59.42561164498329, 60.843041986227036, 58.027009293437004, 59.971399158239365, 58.54086712002754, 60.49710854887962, 52.27313384413719, 57.026268392801285, 53.91335003077984, 57.283111810684204, 59.955398216843605, 58.52564133703709, 58.00052851438522, 58.70227485895157, 54.53987181186676, 53.991766422986984, 50.97172647714615, 50.63575230538845, 51.82204484939575, 45.68605050444603, 47.57210589945316, 45.042460039258, 42.48572923243046, 46.42222300171852, 45.982104018330574, 46.98848381638527, 46.21139131486416, 45.56161478161812, 45.29376335442066, 48.421907499432564, 48.90461079776287, 51.80788680911064, 51.514428555965424, 53.27945664525032, 55.51846370100975, 55.482905209064484, 53.35100680589676, 61.80912494659424, 56.88219532370567, 60.46331316232681, 56.880808398127556, 48.8406640291214, 61.03183105587959, 58.16208444535732, 57.615358382463455, 55.76548084616661, 57.51594431698322, 55.258322060108185, 53.99407669901848, 56.14425592124462, 49.42678637802601, 51.22605063021183, 50.07714807987213, 49.21203330159187, 47.18943603336811, 46.0381244122982, 48.84493499994278, 44.894659370183945, 45.10413832962513, 45.05375303328037, 45.82299515604973, 44.68772627413273, 40.681491047143936, 42.20460131764412, 45.35688176751137, 50.63170552253723, 47.8046116232872, 52.846747264266014, 55.894001349806786, 55.27349844574928, 57.575988695025444, 57.9957939684391, 61.065113469958305, 51.461888775229454, 57.28545628488064, 51.18420347571373, 57.30333812534809, 62.43229150772095, 61.283153370022774, 62.139000445604324, 59.845154732465744, 63.40439714491367, 57.3273566365242, 57.649788334965706, 63.501082956790924, 61.005361676216125, 57.17818424105644, 54.473306983709335, 50.558836832642555, 49.108222872018814, 55.011441707611084, 62.48693637549877, 64.87268015742302, 65.8569261431694, 66.75049379467964, 64.89573732018471, 64.27991196513176, 64.63796675205231, 66.80837228894234, 60.301012471318245, 57.65183262526989, 61.92321002483368, 62.28313811123371, 70.68906605243683, 69.97878536581993, 79.92502525448799, 63.72971288859844, 1.3036456843838096, 1.6763226804323494, 4.066409273073077, 0.8498439914546907, 26.75865814089775, 83.05898308753967, 65.3236323595047, 83.01044449210167, 65.95569804310799, 57.440373972058296, 65.4330512881279, 36.89236856997013, 46.36772632598877, 76.56602069735527, 94.2644602060318, 36.55351795256138, 1.1523154797032475, 0.512513411231339, 0.13931139023043215, 0.18444588786223903, 0.13113396184053272], [0.1141864036617335, 0.12321547619649209, 0.03473701610346325, 0.0729705867706798, 0.09177111700410023, 0.035560684991651215, 0.35611178493127227, 0.6420380703639239, 40.144701451063156, 61.00178226828575, 48.861901089549065, 47.926718071103096, 26.83860395103693, 36.042639166116714, 43.66998888552189, 47.468029484152794, 68.39047059416771, 54.26469437777996, 67.09781035780907, 46.384521424770355, 0.281691798591055, 0.2695152926025912, 0.4232004506047815, 0.18551894434494898, 0.1589037771918811, 34.00247544050217, 64.69277501106262, 58.719799518585205, 62.06339210271835, 58.46746265888214, 55.853962898254395, 51.59185700118542, 48.57695437967777, 47.5119399279356, 53.03865596652031, 55.97858101129532, 58.6960431933403, 55.124816223978996, 54.335305988788605, 47.59148485958576, 44.89842116832733, 43.32184016704559, 51.86351582407951, 52.39555947482586, 61.53517484664917, 65.44733092188835, 47.2575967758894, 57.037458792328835, 55.111136958003044, 56.80321276187897, 51.38826012611389, 52.6940942555666, 51.99526235461235, 50.88865913450718, 48.685791939496994, 51.79217845201492, 47.044785395264626, 49.61068890988827, 49.42209742963314, 46.66812300682068, 48.161017298698425, 47.232255935668945, 48.70237424969673, 47.987070232629776, 46.290297880768776, 41.059141382575035, 46.17946542799473, 41.909250766038895, 41.627564281225204, 39.769999757409096, 38.76677758991718, 39.87112753093243, 38.839247301220894, 41.71438582241535, 41.998466178774834, 44.34965081512928, 42.831632271409035, 42.57413908839226, 43.79702366888523, 46.82318888604641, 48.28918442130089, 50.22259667515755, 51.94109246134758, 48.0868186801672, 49.549356400966644, 52.87100896239281, 50.94337999820709, 56.23310275375843, 54.870621263980865, 54.378087893128395, 58.192767798900604, 52.85880021750927, 52.3353973031044, 52.821820601820946, 51.00988782942295, 48.90822820365429, 51.22544266283512, 50.241356268525124, 45.51274560391903, 43.54847140610218, 44.05393548309803, 45.31232915818691, 43.67998994886875, 39.21915851533413, 38.21486100554466, 39.541297629475594, 38.57572004199028, 36.723509430885315, 38.60812850296497, 40.622723400592804, 38.45104493200779, 41.77471898496151, 43.89534719288349, 42.42180146276951, 41.560953855514526, 45.64656302332878, 50.11220879852772, 46.86007350683212, 46.55089549720287, 46.4412409812212, 52.6490780711174, 48.95860590040684, 50.64480721950531, 46.68879009783268, 50.04520319402218, 58.06159883737564, 54.95436117053032, 56.643875911831856, 56.43255405128002, 56.151171550154686, 61.944070905447006, 59.383236318826675, 55.03912702202797, 55.08308686316013, 53.982384726405144, 49.590990766882896, 45.068184658885, 43.46657820045948, 45.94027206301689, 51.34403429925442, 56.7433849722147, 58.33978570997715, 59.508458599448204, 60.5200707167387, 60.52336893975735, 63.0453772097826, 57.433709129691124, 60.02283699810505, 55.41497625410557, 57.444838732481, 54.290107414126396, 62.50169098377228, 60.137362852692604, 75.83573788404465, 44.652984738349915, 0.2603663335321471, 1.8130699801258743, 0.275882474379614, 0.20191877527395263, 28.557360023260117, 73.2645146548748, 56.35700270533562, 62.897861525416374, 63.19659769535065, 35.81293009221554, 42.25851282477379, 33.845350071787834, 34.42078359425068, 53.70035246014595, 78.70707660913467, 25.558384247124195, 0.5185974785126746, 0.16860608157003298, 0.08883921065717004, 0.1347750422428362, 0.06659614678937942, 0.041692168088047765, 0.05080032758996822, 0.013473586241161684, 0.0204090629631537, 0.11973901899182238, 0.02931894843641203, 0.3052210563328117, 0.5636106943711638, 51.31510645151138, 71.80042281746864, 57.130481600761414, 56.28541834652424, 26.146495789289474, 41.62804305553436, 51.00473910570145, 52.24327124655247, 77.45701968669891, 60.1557082682848, 73.70278313755989, 49.76806126534939, 0.24997665197588503, 0.5429287604056299, 0.9066023770719767, 0.06529845704790205, 0.29406458779703826, 36.19675889611244, 72.28315651416779, 71.1809116601944, 65.89025795459747, 59.92993198335171, 56.28993630409241, 53.12269985675812, 50.217056572437286, 52.59843438863754, 54.127734526991844, 57.75535427033901, 60.673441886901855, 60.72069615125656, 58.21824163198471, 50.27751512825489, 47.10392542183399, 46.14562824368477, 54.470297545194626, 54.87975597381592, 60.256266072392464, 67.04265251755714, 51.82157747447491, 59.72613371908665, 57.37722896039486, 57.68978498876095, 54.94454629719257, 54.56943802535534, 53.45401167869568, 52.23639741539955, 50.853754207491875, 55.280034095048904, 49.49591986835003, 52.08896912634373, 53.42934340238571, 52.52551630139351, 51.162529438734055, 50.74789948761463, 51.718192622065544, 51.23935751616955, 49.00602735579014, 44.50432911515236, 49.95541401207447, 46.231161653995514, 43.397980481386185, 42.165547013282776, 40.949654057621956, 41.71095460653305, 43.44371482729912, 44.131553918123245, 43.505058735609055, 44.19930428266525, 44.197411984205246, 46.62803515791893, 44.8500307649374, 46.82709887623787, 51.3603962212801, 50.60926012694836, 53.38772803544998, 49.49756897985935, 51.97791248559952, 53.59468773007393, 54.58485759794712, 58.61247047781944, 57.21432030200958, 52.674506306648254, 59.892800375819206, 53.57744425535202, 54.37206141650677, 52.627651020884514, 52.94223994016647, 52.565892934799194, 52.694067656993866, 51.61489516496658, 49.07190442085266, 47.20746606588364, 46.416686698794365, 47.24691554903984, 45.71525953710079, 41.66986741125584, 41.35042615234852, 41.02078624069691, 41.928717121481895, 39.998253509402275, 41.47812969982624, 40.83380967378616, 41.21880121529102, 44.07471276819706, 46.2538768351078, 45.638412460684776, 43.86354669928551, 49.90394577383995, 53.32076042890549, 50.370104759931564, 51.00671499967575, 51.89732261002064, 56.192889511585236, 51.51830814778805, 52.76322774589062, 50.45644752681255, 50.648147240281105, 59.83308658003807, 56.77745394408703, 58.56495022773743, 58.48425775766373, 58.0245204269886, 63.28674405813217, 60.030303597450256, 59.173692762851715, 58.29111032187939, 56.28431640565395, 52.228683829307556, 47.52328231930733, 45.26238463819027, 48.916542157530785, 55.27129836380482, 59.58011895418167, 60.93245878815651, 62.78465420007706, 62.751234993338585, 62.87205331027508, 65.15904799103737, 63.5779794305563, 64.55163538455963, 58.35837051272392, 61.18527062237263, 58.63482087850571, 68.09888944029808, 63.73964935541153, 78.4822578728199, 48.24473820626736, 0.249219483230263, 2.7044521551579237, 0.8489519893191755, 0.3804957593092695, 33.144390285015106, 81.07748821377754, 61.68951116502285, 70.4848650097847, 73.22020143270493, 49.00637313723564, 55.737160965800285, 32.55599185824394, 34.32980127632618, 59.39781993627548, 83.96901145577431, 31.20634987950325, 0.7880928518716246, 0.1577480009291321, 0.10726111941039562, 0.20190029579680413, 0.07774914949550293, 0.2146009510033764, 0.23880850203568116, 0.18512526468839496, 0.1686813947162591, 0.2079023706028238, 0.14613241015467793, 0.5730153084732592, 0.9155343321617693, 61.65429085493088, 80.4943411052227, 66.60359367728233, 61.17783062160015, 33.15346419811249, 55.07443092763424, 60.8611062169075, 61.25628501176834, 79.82783406972885, 65.79910844564438, 80.41541934013367, 56.84735119342804, 0.4875926562817767, 1.0607160511426628, 2.129217409528792, 0.5735263216774911, 0.3510224330238998, 42.04137347638607, 65.05475878715515, 62.33456455171108, 70.7485480606556, 64.36447262763977, 61.2162921577692, 57.80817523598671, 53.34173530340195, 53.80057208240032, 57.59707756340504, 61.925014927983284, 62.87630908191204, 60.9570586681366, 59.83704976737499, 53.95978353917599, 47.40431450307369, 48.70464652776718, 57.01171897351742, 59.73473645746708, 58.729618191719055, 63.79267930984497, 59.652394875884056, 60.70352107286453, 60.43587103486061, 61.11951135098934, 56.846549436450005, 57.764918357133865, 58.47876325249672, 54.90036226809025, 53.91920551657677, 55.277127251029015, 53.45258295536041, 54.465699791908264, 58.68032343685627, 57.26216733455658, 57.14669533073902, 54.67349924147129, 58.13240423798561, 56.13620415329933, 53.03235970437527, 47.55334250628948, 52.86987282335758, 49.88881878554821, 45.282747745513916, 42.34886817634106, 44.162613451480865, 41.790613532066345, 45.608853846788406, 46.632773503661156, 45.69191738963127, 47.25673422217369, 48.504135087132454, 48.61561730504036, 46.98857121169567, 51.40106923878193, 53.20229798555374, 53.89516040682793, 55.69790907204151, 52.377119064331055, 53.84758695960045, 55.73647320270538, 57.048949375748634, 62.20901928842068, 58.436570316553116, 55.23636303842068, 64.47576105594635, 54.95647005736828, 56.36081010103226, 56.74493528902531, 57.392428144812584, 54.629581198096275, 55.73808051645756, 54.106227681040764, 51.74932815134525, 48.24240133166313, 47.67582893371582, 50.41961990296841, 50.706219524145126, 44.80528436601162, 42.692362144589424, 42.69639752805233, 43.90810690820217, 40.909171029925346, 43.44425819814205, 44.20197553932667, 42.8607577085495, 48.121244832873344, 48.7285016477108, 50.04234194755554, 47.96640694141388, 51.00105330348015, 58.023494482040405, 56.43177129328251, 55.45109711587429, 54.910899102687836, 60.020963698625565, 55.79712174832821, 55.21326407790184, 52.08241067826748, 54.505609050393105, 63.64080525934696, 59.39052052795887, 59.70569461584091, 60.168088003993034, 61.11293010413647, 65.9221838414669, 62.32380352914333, 59.91591073572636, 60.22754721343517, 59.67853747308254, 55.10810852050781, 51.803954020142555, 49.66659530997276, 51.44533306360245, 57.12735816836357, 63.6019903421402, 63.93905505537987, 63.73252473771572, 64.3649286031723, 65.02144977450371, 69.37042281031609, 64.65229958295822, 66.99497267603874, 62.78387524187565, 64.63785275816917, 60.90030111372471, 70.71497306227684, 68.02718728780746, 80.89543238282204, 51.69155605137348, 0.4016152338590473, 3.2995170867070556, 1.9207748444750905, 0.5083650432061404, 37.2423791885376, 88.0204376578331, 70.68691536784172, 77.63396099209785, 76.74813732504845, 49.1060645878315, 65.67566066980362, 48.44461128115654, 44.44350577890873, 70.45964196324348, 93.69721904397011, 42.942639514803886, 1.209284991491586, 0.37362982460763305, 0.1990198128623888, 0.27158107550349087, 0.17079801473300904], [0.12153888295870274, 0.04073244126630016, 0.0207016027343343, 0.024222473766712938, 0.04563639726256952, 0.09900345743517391, 0.17536814528284594, 0.6359984131995589, 53.2243862003088, 59.50023964047432, 48.25812488794327, 33.385882526636124, 28.286119177937508, 30.629449635744095, 53.593654185533524, 34.468277245759964, 57.59028732776642, 65.3552694618702, 57.010104060173035, 69.39911887049675, 2.9133549705147743, 0.28670610452536494, 0.2847410459071398, 0.39404019189532846, 0.12346849660389125, 19.27602745592594, 60.074138045310974, 49.20108608901501, 68.34999516606331, 55.245862528681755, 58.05737726390362, 49.066539108753204, 54.130060002207756, 49.429586827754974, 54.400632083415985, 52.478049248456955, 59.08820115029812, 56.26967579126358, 52.978866174817085, 43.6861228197813, 44.620279893279076, 43.57027843594551, 56.06283389031887, 55.4330974817276, 72.83236384391785, 40.02699516713619, 50.993221923708916, 53.90864208340645, 56.02469153702259, 53.90968702733517, 49.860430508852005, 51.211425215005875, 47.805249989032745, 48.91472205519676, 49.19563718140125, 51.58676527440548, 46.67667634785175, 51.446780785918236, 49.42889906466007, 45.32628960907459, 50.3290593624115, 48.70807774364948, 49.31493178009987, 45.175901278853416, 46.416078731417656, 42.78806000947952, 42.19688393175602, 46.090436205267906, 43.902304619550705, 38.789416775107384, 40.96806786954403, 40.24115547537804, 40.26092201471329, 41.816262155771255, 43.00478138029575, 41.71341307461262, 43.68417352437973, 41.366689279675484, 42.23353296518326, 43.633248656988144, 43.45574118196964, 49.830906093120575, 48.946674540638924, 40.76442539691925, 48.66282217204571, 53.40800754725933, 50.55755630135536, 56.37801177799702, 56.84498392045498, 56.78347282111645, 56.40461415052414, 51.70828655362129, 53.795533552765846, 52.89473868906498, 49.70774330198765, 49.676337987184525, 53.35329808294773, 49.44179557263851, 49.32259976863861, 45.162548795342445, 44.6238175034523, 41.91661477088928, 43.05996961891651, 39.559460654854774, 40.0506678968668, 40.91180808842182, 40.44153392314911, 37.11787506937981, 39.70261797308922, 37.92906314134598, 39.338498711586, 44.69354756176472, 43.70162978768349, 41.467011496424675, 42.61675380170345, 44.83619190752506, 47.42949575185776, 46.32088623940945, 46.52464270591736, 46.290529668331146, 51.05612374842167, 46.97725161910057, 47.471624091267586, 51.69789411127567, 45.75400985777378, 52.87372961640358, 56.89449906349182, 53.50845895707607, 55.40744125843048, 57.57362522184849, 55.211459174752235, 57.612082958221436, 56.82802923023701, 56.65054455399513, 55.81429302692413, 55.502029582858086, 48.21584455668926, 47.47492991387844, 41.822752207517624, 45.35825729370117, 52.645909041166306, 56.300739124417305, 58.892469853162766, 58.31532642245293, 57.934457659721375, 63.27061392366886, 61.04469336569309, 61.40616036951542, 56.85020484030247, 61.04949630796909, 56.00736826658249, 64.67107057571411, 57.97071911394596, 76.21213808655739, 34.37593460083008, 0.10039099157438613, 1.6228862665593624, 0.060237499710638076, 0.1993759992183186, 37.24842846393585, 72.62174114584923, 54.78758051991463, 67.7777686715126, 51.565117835998535, 20.87814498692751, 49.40323144197464, 46.36703856289387, 49.442680925130844, 51.038849875330925, 72.18577533960342, 24.471169486641884, 0.49043080711271614, 0.2644591295393184, 0.01031038214932778, 0.06955755350645632, 0.07923919649329036, 0.05751169148425106, 0.03341537725646049, 0.0118302653390856, 0.021353236224967986, 0.08631243530544452, 0.02050965736998478, 0.048810644511831924, 1.079211796168238, 63.28671745955944, 66.04983419179916, 54.83330726623535, 46.2218901515007, 27.799021415412426, 41.041339337825775, 70.81281781196594, 40.103496462106705, 63.333618342876434, 70.59346318244934, 63.44727784395218, 74.39454361796379, 3.282811283133924, 0.3369189554359764, 0.885109780356288, 0.33540301490575075, 0.11538888327777386, 21.221982836723328, 65.55617988109589, 64.17916417121887, 70.66586449742317, 54.75918084383011, 60.205022022128105, 49.370496198534966, 55.85084706544876, 52.126081734895706, 57.27527663111687, 55.67190706729889, 62.114818543195724, 57.165169939398766, 56.449527740478516, 45.79423449933529, 48.66112746298313, 45.865860655903816, 60.9126390516758, 56.88105918467045, 72.30864554643631, 45.51718756556511, 53.57649810612202, 58.350679725408554, 58.066508173942566, 56.18960648775101, 56.65635824203491, 53.232992738485336, 50.739026963710785, 52.02020041644573, 53.81399676203728, 53.94908331334591, 49.21772539615631, 52.78814300894737, 53.18842872977257, 51.2499475479126, 52.57709093391895, 53.067181035876274, 52.1808709949255, 49.75269868969917, 48.761134296655655, 43.96688595414162, 47.338931411504745, 47.72818252444267, 46.6061407327652, 41.04560650885105, 42.39179827272892, 41.56243197619915, 43.76234292984009, 44.205668941140175, 44.55876499414444, 44.179685935378075, 45.96511512994766, 44.101394936442375, 45.584618747234344, 43.581601828336716, 46.511510610580444, 50.94602085649967, 49.683850184082985, 41.918906047940254, 51.565486416220665, 54.9519445002079, 52.97402523458004, 56.08723998069763, 58.68007265031338, 56.98713429272175, 57.468473464250565, 55.192319601774216, 54.24670234322548, 55.04193127155304, 53.35883438587189, 52.29676857590675, 55.273354053497314, 52.85620115697384, 51.95061095058918, 45.94562977552414, 46.31392501294613, 43.178112879395485, 44.55499179661274, 42.14592486619949, 43.913099840283394, 42.048999667167664, 41.4159232378006, 42.13507644832134, 41.931521371006966, 41.33432261645794, 44.451192766427994, 46.84374578297138, 45.36660924553871, 43.143504336476326, 45.650940388441086, 49.30471032857895, 50.598187521100044, 48.64615246653557, 50.343513786792755, 52.212116718292236, 54.97042290866375, 49.79235716164112, 50.946796014904976, 54.23529915511608, 48.684591203927994, 54.84071686863899, 56.885729134082794, 55.46811640262604, 59.21884573996067, 59.12470959126949, 58.95760215818882, 58.77765901386738, 59.44822423160076, 59.09882918000221, 57.64618992805481, 57.10918754339218, 51.26073896884918, 50.60267128050327, 44.98338080942631, 48.00162345170975, 54.53561224043369, 58.607344552874565, 59.88287530839443, 62.33295723795891, 62.062046974897385, 64.07978430390358, 63.533909395337105, 66.47449180483818, 58.74145835638046, 64.74724888801575, 57.332463562488556, 68.06043550372124, 61.70836955308914, 80.76094999909401, 37.59047091007233, 0.08256684566731565, 3.5375740751624107, 0.3312327980529517, 0.0771728866675403, 44.30483601987362, 77.34674960374832, 62.937641590833664, 71.69009193778038, 64.14018586277962, 25.95058400183916, 53.63454759120941, 43.06754261255264, 40.71835286915302, 60.92184215784073, 78.59255075454712, 35.20196467638016, 0.7392777025233954, 0.27581232658121735, 0.11551897434401326, 0.1388745175790973, 0.03035126286704326, 0.17162700853077695, 0.1988113287370652, 0.11309320529107936, 0.10441527250804938, 0.19418023817706853, 0.2051322301849723, 0.28230282361619174, 1.0738393594510853, 76.72972351312637, 74.21765550971031, 65.25385290384293, 46.69952072203159, 35.748717337846756, 46.92876622080803, 66.50061160326004, 49.3286794424057, 68.86439636349678, 75.64485132694244, 70.4236350953579, 80.61922520399094, 3.786335326731205, 0.4624078451888636, 2.151523162610829, 0.9149608004372567, 0.14928821503417566, 25.055143050849438, 62.072807997465134, 50.81310398876667, 75.21814942359924, 58.146307691931725, 63.44226211309433, 52.88251094520092, 60.253317430615425, 51.881671249866486, 59.27136652171612, 56.45513243973255, 64.82142090797424, 61.34127505123615, 60.044682025909424, 46.436316445469856, 49.843597412109375, 47.90676534175873, 64.30282473564148, 57.796312272548676, 70.59093251824379, 52.78056621551514, 55.19497565925121, 58.59316371381283, 61.552733704447746, 60.65242521464825, 57.586297541856766, 56.22427202761173, 52.78881937265396, 55.054181814193726, 56.006935089826584, 55.686437487602234, 52.88860581815243, 56.37221708893776, 56.76273733377457, 54.922268092632294, 55.562355145812035, 55.986579582095146, 57.64483340084553, 52.43039980530739, 56.05833113193512, 48.988008722662926, 50.118896439671516, 52.19735451042652, 50.37477470934391, 43.641019240021706, 44.62890163064003, 44.13538411259651, 47.261119186878204, 47.41717301309109, 48.01901511847973, 45.97345948219299, 50.541498363018036, 45.5402447283268, 48.604499101638794, 48.475537821650505, 48.21467041969299, 53.81235145032406, 52.92687736451626, 44.21821966767311, 56.54415026307106, 58.02890919148922, 53.556362986564636, 58.47448468208313, 59.69025984406471, 59.161275029182434, 60.8369205147028, 56.72619849443436, 57.925197556614876, 58.29879730939865, 54.827805161476135, 54.522947520017624, 59.05154071748257, 55.295769050717354, 55.7117935270071, 49.546837136149406, 47.562443017959595, 44.82978165149689, 48.72662074863911, 45.32000854611397, 45.91894380748272, 45.20848833024502, 45.38044050335884, 43.04233476519585, 44.52574476599693, 43.71864527463913, 45.431072786450386, 49.7062461823225, 49.4831183552742, 48.37936118245125, 48.9189550280571, 52.78532736003399, 55.534837022423744, 52.77919448912144, 56.037078872323036, 55.09792506694794, 58.25894124805927, 52.481598258018494, 52.61281281709671, 57.344201132655144, 51.19737736880779, 59.6376858651638, 61.26828856766224, 57.634995728731155, 59.27264705300331, 61.666860580444336, 61.94683335721493, 61.72576881945133, 61.32251165807247, 61.067017167806625, 61.4067455381155, 61.022255569696426, 54.217003136873245, 52.690902426838875, 48.069073632359505, 50.90184062719345, 58.28103706240654, 63.12099315226078, 65.14511033892632, 64.71472263336182, 64.22580286860466, 67.51590192317963, 67.09576606750488, 69.79308933019638, 60.46221502125263, 68.6795362830162, 60.48803463578224, 71.64949491620064, 66.52388155460358, 82.28717610239983, 40.763528645038605, 0.19990773318568245, 5.439536366611719, 0.8085642533842474, 0.28047331084962934, 47.77406886219978, 83.21749538183212, 70.92302709817886, 79.17964205145836, 65.68093478679657, 32.67553724348545, 68.63089129328728, 67.67069801688194, 58.80720242857933, 70.1482866704464, 90.95561295747757, 47.277139127254486, 0.7525044365320355, 0.329171497724019, 0.23802961804904044, 0.2822826075134799, 0.23816813249140978], [0.04775506560690701, 0.11220852815313265, 0.038651496288366616, 0.10750541216111742, 0.03624603610660415, 0.03380989553988911, 0.06495894675026648, 0.6675491889473051, 50.22534392774105, 62.30514653027058, 53.57752405107021, 40.214511305093765, 44.283994138240814, 39.582639411091805, 31.614200994372368, 32.416364550590515, 50.79218991100788, 65.61023578047752, 54.61741425096989, 71.80856198072433, 14.68064809218049, 0.2091078707599081, 0.77164709684439, 0.6943690998014063, 0.08332799974596128, 7.454519318416715, 50.26904538273811, 45.11276766657829, 66.11358717083931, 61.14500418305397, 55.03140203654766, 50.91346800327301, 55.98798170685768, 54.2794793844223, 55.57161144912243, 56.80482767522335, 59.39810872077942, 55.861782878637314, 47.99995914101601, 43.04713010787964, 43.64020608365536, 51.01484276354313, 52.070737704634666, 68.6550883948803, 50.608633160591125, 37.14132361114025, 60.56805834174156, 53.612390980124474, 57.238692194223404, 51.4088474214077, 52.46725782752037, 45.67152388393879, 51.923320814967155, 46.861756816506386, 51.35308161377907, 50.76856657862663, 47.589429169893265, 49.2999529838562, 47.59903505444527, 45.50377428531647, 49.854917004704475, 47.174981608986855, 50.812568217515945, 47.245118245482445, 47.17421405017376, 41.97432607412338, 43.55133645236492, 43.3922465890646, 48.11010003089905, 42.35128104686737, 44.426231905817986, 39.5660874992609, 40.18970623612404, 39.826525524258614, 42.27686583995819, 44.05893221497536, 44.338627606630325, 44.162613451480865, 42.82301813364029, 44.42055881023407, 47.35976189374924, 49.05951328575611, 49.30886350572109, 42.18801900744438, 49.69060242176056, 51.279794946312904, 53.12228187918663, 55.38649298250675, 56.35693810880184, 56.22572734951973, 56.202183812856674, 53.82188893854618, 52.95770511031151, 53.42716991901398, 47.868516594171524, 43.60741004347801, 50.816485807299614, 48.37439104914665, 49.49886471033096, 45.581149533391, 43.08961562812328, 42.69350588321686, 40.67174457013607, 42.27446436882019, 39.873817786574364, 38.61422337591648, 38.541913256049156, 39.471145793795586, 38.33981730043888, 39.156005904078484, 44.36120979487896, 44.781843423843384, 43.94821755588055, 39.80974942445755, 40.95769442617893, 42.87240408360958, 48.32845911383629, 46.43510051071644, 46.6579357534647, 47.394978404045105, 51.67065717279911, 44.31319937109947, 46.6415586322546, 52.12506718933582, 46.11022934317589, 46.970670372247696, 47.240178510546684, 49.85477641224861, 52.42168687283993, 53.294424042105675, 57.16556131839752, 60.09120672941208, 59.67306576669216, 56.79747886955738, 56.53921812772751, 54.670037627220154, 50.92878878116608, 46.6537369787693, 45.74082836508751, 47.30328932404518, 44.9520742893219, 52.30650745332241, 54.17114719748497, 59.33028995990753, 56.98326610028744, 61.94576181471348, 57.57056638598442, 63.20477485656738, 60.409386456012726, 64.54321503639221, 59.59830857813358, 65.5893748998642, 57.85119652748108, 76.23548403382301, 25.153386779129505, 0.22414675127947703, 2.46382056735456, 0.05784562825283501, 0.0444229078857461, 41.02448344230652, 71.07143953442574, 54.42183114588261, 70.26689350605011, 42.32805669307709, 30.09468723088503, 63.15475054085255, 33.2479727268219, 45.96511512994766, 49.39460590481758, 78.13310980796814, 18.583839498460293, 0.4811222566058859, 0.3691642329795286, 0.07696723012486473, 0.03189549963281024, 0.05795153643703088, 0.03227071836590767, 0.039847738153184764, 0.040133394504664466, 0.044202968711033463, 0.015152310370467603, 0.039438510502805, 0.08325828239321709, 0.7194803492166102, 63.26789326965809, 67.21200942993164, 60.71704834699631, 38.107699155807495, 30.326875671744347, 45.79349733889103, 48.924962505698204, 40.77157661318779, 56.25319227576256, 73.11780452728271, 61.3241645693779, 79.86212342977524, 16.185102313756943, 0.18641366274096072, 0.750482885632664, 0.7052117586135864, 0.1199139209347777, 7.718872083351016, 55.790137723088264, 58.3657269179821, 73.70160520076752, 60.44690944254398, 60.1277569681406, 50.84382154047489, 58.36768001317978, 55.687767416238785, 60.026545599102974, 59.342095926404, 62.45675839483738, 58.64628106355667, 51.87512420117855, 46.578235030174255, 45.02297468483448, 55.21276630461216, 55.8349297195673, 68.88416290283203, 56.42003372311592, 39.373859614133835, 60.16782581806183, 56.287850216031075, 60.70144638419151, 54.063669964671135, 54.78091187775135, 48.90678808093071, 53.88717703521252, 49.24393638968468, 53.065364733338356, 54.02564540505409, 52.395616471767426, 50.903858318924904, 53.02982144057751, 49.92504604160786, 52.119272500276566, 51.63401573896408, 53.282101303339005, 51.106189861893654, 50.249864012002945, 45.47855503857136, 47.389704287052155, 48.14018301665783, 50.025254264473915, 45.95465809106827, 45.69705091416836, 41.60657800734043, 42.99450293183327, 41.56576059758663, 43.65687198936939, 46.011913418769836, 45.31108662486076, 46.28124676644802, 44.60476912558079, 44.27157640457153, 50.316485837101936, 49.93368297815323, 48.860761150717735, 42.53046043217182, 51.9018367677927, 53.58544282615185, 53.540533035993576, 56.319339126348495, 56.94260448217392, 57.926405891776085, 56.41689509153366, 55.549895614385605, 52.77900069952011, 53.23410987854004, 48.33026021718979, 45.29179885983467, 52.52431556582451, 51.73861272633076, 49.982833340764046, 47.57293425500393, 44.274604842066765, 43.79307568073273, 45.27691885828972, 44.60787355899811, 42.63286493718624, 40.12489311397076, 40.48823721706867, 41.41585864126682, 40.28832234442234, 40.55089205503464, 44.94944863021374, 47.24986419081688, 46.054934710264206, 42.80379876494408, 44.02922920882702, 47.872084602713585, 53.376085460186005, 49.57995995879173, 50.80327771604061, 51.842335760593414, 54.116502329707146, 47.980747371912, 49.618250504136086, 54.15178343653679, 48.682881295681, 48.68212893605232, 49.80249121785164, 53.5855720192194, 53.59856732189655, 56.06748104095459, 60.94114512205124, 61.39595031738281, 61.259093061089516, 60.3920441865921, 58.049416691064835, 56.87344439327717, 53.6138691008091, 51.264394372701645, 47.72911727428436, 48.60119707882404, 47.680213898420334, 53.959300965070724, 56.55798152089119, 61.83332584798336, 59.99078951776028, 64.65950399637222, 61.18079446256161, 66.8396446108818, 62.371148988604546, 67.50302821397781, 60.71074068546295, 67.75221884250641, 61.94831147789955, 80.7961057126522, 27.82315392047167, 0.12560880597447976, 4.2590399365872145, 0.17214299412444234, 0.06404122177627869, 46.12654186785221, 76.87838673591614, 62.81721465289593, 76.50537595152855, 45.626937076449394, 23.724209368228912, 69.84137713909149, 43.24609123170376, 48.9066968858242, 57.05588400363922, 86.00978314876556, 30.956004112958908, 0.948713676771149, 0.3514351858757436, 0.06074558143154718, 0.11311224880046211, 0.09927382925525308, 0.2083321483223699, 0.16125053720315918, 0.13260212290333584, 0.26766651368234307, 0.09558977850247175, 0.1637998886872083, 0.23233831016113982, 1.066173508297652, 72.15470060706139, 79.50557336211205, 71.29780098795891, 51.86629347503185, 55.61110273003578, 58.82185064256191, 41.99992150068283, 47.182698994874954, 64.52486962080002, 76.63697808980942, 66.69770702719688, 86.09137237071991, 18.12195908278227, 0.33241952187381685, 1.7209125752560794, 1.2159585021436214, 0.17647643893724307, 9.122735727578402, 56.42829068005085, 45.32745994627476, 72.74770438671112, 66.46894410252571, 63.1497348099947, 53.15387338399887, 60.702932104468346, 58.639072850346565, 63.41802701354027, 61.37022189795971, 65.89755356311798, 62.40095838904381, 55.31203217804432, 47.26964592933655, 48.954289332032204, 56.22529037296772, 58.12113784253597, 66.25908136367798, 59.9012017250061, 41.956714019179344, 64.1019295156002, 57.80141159892082, 62.79125064611435, 56.02173529565334, 56.724549382925034, 52.822686955332756, 57.03806675970554, 51.7457677423954, 56.15416578948498, 56.229162365198135, 54.81640197336674, 55.46715505421162, 54.04429480433464, 53.70222195982933, 55.468842163681984, 54.41118411719799, 59.81368102133274, 53.94026778638363, 54.97199982404709, 49.936209842562675, 51.3780652731657, 51.22956544160843, 56.76663972437382, 46.95102162659168, 49.275250509381294, 43.378213942050934, 45.29888927936554, 45.05662187933922, 47.475739270448685, 48.44236180186272, 49.27900850772858, 49.593312442302704, 48.53930599987507, 46.88555493950844, 53.01567479968071, 53.02899308502674, 53.061659932136536, 46.80072449147701, 54.53684337437153, 54.663418382406235, 57.130234614014626, 59.54882763326168, 57.896615490317345, 60.142063200473785, 58.77829357981682, 59.10741671919823, 54.84666354954243, 57.191985100507736, 51.35345779359341, 49.301602095365524, 54.72969442605972, 54.41667482256889, 55.00714033842087, 50.193832218647, 46.3079821318388, 47.52349130809307, 47.71252356469631, 46.506133899092674, 45.71573831140995, 42.95132964849472, 42.575320824980736, 43.34297463297844, 41.075149923563, 42.71214008331299, 48.08564834296703, 50.05367673933506, 51.461907774209976, 46.37352101504803, 47.383480221033096, 48.978402838110924, 56.44736185669899, 53.50983448326588, 55.64252324402332, 56.964837089180946, 57.99389787018299, 49.36832271516323, 53.995163440704346, 59.0968456864357, 51.20329365134239, 50.836544930934906, 53.51204216480255, 56.34031020104885, 55.27097538113594, 58.46943095326424, 62.58812874555588, 65.53600296378136, 63.184719532728195, 62.77707360684872, 62.240720987319946, 58.108902499079704, 56.92384108901024, 53.80558781325817, 51.7315337061882, 51.46983414888382, 52.20697559416294, 58.41325096786022, 59.317636638879776, 67.74657994508743, 62.28560037910938, 67.87102326750755, 63.36812809109688, 68.95490750670433, 67.34200805425644, 71.22248142957687, 65.04947707056999, 73.97841274738312, 64.24682334065437, 83.90425533056259, 30.357283540070057, 0.6482607708312571, 6.859860252588987, 0.18264540791278705, 0.18533149268478155, 50.5914580821991, 83.90989422798157, 69.4659648835659, 84.50600624084473, 56.183507815003395, 43.61441686749458, 81.87955677509308, 51.276527121663094, 54.11014527082443, 66.65045276284218, 96.00747987627983, 44.22341398894787, 1.1598883545957506, 0.6030689051840454, 0.1525653462158516, 0.3812114568427205, 0.1949247607262805], [0.10183734091697261, 0.025793119857553393, 0.05367671757994685, 0.04788202480995096, 0.020839588396484032, 0.05605273305263836, 0.36489643855020404, 0.6313976913224906, 49.50638830661774, 63.20569060742855, 58.3964254707098, 60.955557748675346, 89.41649034619331, 71.91672697663307, 28.7284629419446, 19.19064413756132, 55.33271826803684, 66.12556412816048, 53.221285566687584, 68.87616813182831, 31.801308654248714, 0.3548291162587702, 0.9553179598879069, 0.3229491534875706, 0.09655785077484325, 0.7114731101319194, 40.758588910102844, 39.62584689259529, 60.83220116794109, 62.58789695799351, 57.18472369015217, 52.730777487158775, 58.78490522503853, 57.5216706097126, 59.583903551101685, 58.88987459242344, 56.69927693903446, 50.95245771110058, 45.944151654839516, 42.388097271323204, 50.851405933499336, 49.14283521473408, 59.04603861272335, 62.908949330449104, 37.20672570168972, 50.433766543865204, 57.17711269855499, 55.18659330904484, 55.41284076869488, 53.232263177633286, 50.33233478665352, 52.958218082785606, 51.13104812800884, 52.667697072029114, 52.69602455198765, 51.134874522686005, 45.492067113518715, 47.37623021006584, 48.6660747975111, 47.571361139416695, 49.078759253025055, 46.08154468238354, 46.95460103452206, 47.36903719604015, 43.8520485162735, 44.65515822172165, 43.43016095459461, 43.93492206931114, 41.92705661058426, 45.39471633732319, 44.11831542849541, 43.97864252328873, 43.415379747748375, 42.36992284655571, 43.87797072529793, 45.24383023381233, 42.81542994081974, 46.28367103636265, 45.314688831567764, 43.601847141981125, 43.402688428759575, 48.296643421053886, 49.04436729848385, 51.07856534421444, 51.32850833237171, 52.52807356417179, 50.3837726265192, 56.58093608915806, 57.648287415504456, 56.41404144465923, 56.844603940844536, 56.402140483260155, 51.94057188928127, 50.859970673918724, 47.05184921622276, 45.563282892107964, 51.894499361515045, 47.67291069030762, 46.62897750735283, 44.61176075041294, 44.10131514072418, 42.78920754790306, 40.581727400422096, 41.166527420282364, 38.54098990559578, 38.38291838765144, 38.886968940496445, 40.582635551691055, 44.817295521497726, 41.608322113752365, 44.087776467204094, 44.177713841199875, 41.89850114285946, 38.43402944505215, 40.99984176456928, 45.812769904732704, 49.07604619860649, 45.07004275918007, 44.50181744992733, 47.88652382791042, 51.164710521698, 47.787611335515976, 46.4635343849659, 49.88843500614166, 47.32951931655407, 47.86317028105259, 45.95290258526802, 47.38704822957516, 48.698414862155914, 49.811637327075005, 52.80167028307915, 57.350839376449585, 56.847647577524185, 55.969146117568016, 68.19303318858147, 63.44308666884899, 50.996204763650894, 54.84976038336754, 45.528974533081055, 48.77208150923252, 44.08352829515934, 47.08588398993015, 47.15621441602707, 53.42627316713333, 54.075126349925995, 59.77862410247326, 56.53613269329071, 64.2870631814003, 58.48882131278515, 64.43694993853569, 58.35004135966301, 66.3903871178627, 55.041832476854324, 78.31147223711014, 13.867076598107815, 0.19414019188843668, 2.2726409509778023, 0.3240511834155768, 0.042036186932818964, 44.94842268526554, 63.517950251698494, 58.157988265156746, 57.15213663876057, 43.73884879052639, 30.244251005351543, 45.33577010035515, 30.377870835363865, 27.650521583855152, 54.62596759200096, 66.17464229464531, 14.902223702520132, 0.6103649886790663, 0.2867586782667786, 0.13284706132253632, 0.1526853663381189, 0.031574409440509044, 0.18198538629803807, 0.09469673736020923, 0.07557319477200508, 0.018721189080679324, 0.05038350776885636, 0.000284776094758854, 0.26436306594405323, 0.6493401504121721, 60.96188060939312, 68.24531838297844, 67.78990522027016, 57.27614298462868, 72.8855761885643, 74.07721504569054, 23.08640979230404, 27.20737226307392, 58.98389294743538, 71.69820070266724, 59.06881459057331, 75.90671807527542, 33.967684507369995, 0.2999241108773276, 1.4391757431440055, 0.7204818329773843, 0.04914978373562917, 0.7831339398398995, 42.055577114224434, 49.51530642807484, 72.74513572454453, 64.7072446346283, 59.45255979895592, 54.666659608483315, 63.00642929971218, 61.176162511110306, 62.50654712319374, 60.76641529798508, 58.61992187798023, 55.16384772956371, 48.830704763531685, 44.9139129370451, 50.525736808776855, 54.950549975037575, 61.19626343250275, 65.95987781882286, 39.15510155260563, 51.15652956068516, 60.15926867723465, 56.87679201364517, 59.82646353542805, 56.491538286209106, 52.016317024827, 55.701256692409515, 54.901190623641014, 55.9206835180521, 54.52750347554684, 53.49710516631603, 49.125758931040764, 50.05069389939308, 52.775941863656044, 49.65083375573158, 51.76613464951515, 51.68284311890602, 50.576281696558, 50.445986688137054, 47.99439623951912, 46.16293251514435, 49.090249836444855, 47.578212171792984, 46.61888524889946, 48.44119906425476, 46.57138779759407, 45.29005095362663, 44.95025418698788, 44.27783086895943, 46.62742719054222, 46.23176962137222, 45.239160284399986, 47.41274245083332, 46.79241053760052, 45.13859108090401, 45.896403416991234, 49.40667025744915, 50.093323811888695, 54.712143167853355, 54.05538260936737, 53.244129940867424, 51.633882746100426, 57.04781323671341, 59.167913272976875, 58.74747723340988, 59.95211519300938, 56.66433021426201, 53.06206651031971, 52.02139735221863, 48.03711734712124, 48.285168036818504, 53.48744608461857, 49.40761640667915, 48.05631771683693, 45.7528281211853, 46.21658943593502, 44.39507357776165, 43.826354295015335, 42.601277232170105, 40.63048638403416, 40.922983288764954, 41.044375374913216, 42.532280534505844, 46.164961606264114, 44.73476395010948, 45.935370326042175, 47.664642333984375, 45.73675498366356, 44.14044164121151, 42.09031865000725, 48.35593543946743, 52.37925834953785, 50.03173291683197, 49.76450465619564, 52.54697374999523, 54.91382114589214, 49.51580420136452, 48.87357406318188, 52.90807597339153, 48.7381911277771, 49.563875421881676, 48.55882175266743, 48.64719741046429, 49.70233999192715, 52.17297121882439, 56.62548489868641, 60.1948993653059, 59.856500923633575, 59.116445034742355, 64.06163647770882, 65.60616239905357, 54.66340698301792, 58.038484677672386, 49.71799895167351, 50.68131946027279, 47.16727562248707, 50.08272998034954, 49.68174509704113, 56.95876121520996, 56.92078225314617, 64.11021307110786, 59.29734952747822, 69.29570361971855, 60.929282158613205, 68.48550349473953, 61.495903953909874, 71.29854574799538, 59.357424303889275, 84.38502073287964, 14.541828241199255, 0.10215620466624387, 2.9283501533791423, 0.15766753727803007, 0.009040960812853882, 50.643705278635025, 70.84455370903015, 65.33579170703888, 66.4119927585125, 45.436620488762856, 29.78799618780613, 53.82377363741398, 39.80472229421139, 31.26514032483101, 59.11715939640999, 77.82344162464142, 20.08622758090496, 0.677491711685434, 0.26351069449447095, 0.06493408480309881, 0.24127497046720237, 0.005949076185061131, 0.2775560470763594, 0.22033090994227678, 0.1232684803835582, 0.12322300899541005, 0.14312653394881636, 0.153790706244763, 0.39660282782278955, 1.0536015266552567, 71.65175199508667, 79.12763804197311, 72.48367175459862, 72.7868726849556, 96.56212851405144, 91.11202016472816, 40.90376392006874, 31.166110038757324, 68.58146354556084, 79.07245740294456, 62.862945199012756, 81.12740233540535, 38.11556853353977, 0.6203258573077619, 2.4153848038986325, 0.9683286992367357, 0.18184526881668717, 1.038753823377192, 47.5201740860939, 40.98974570631981, 63.86617496609688, 70.25589689612389, 62.68222689628601, 59.208935871720314, 64.15649458765984, 61.79877050220966, 64.6924102306366, 66.30054473876953, 61.455550119280815, 56.970023810863495, 50.98987430334091, 48.47432568669319, 53.5320670902729, 56.238783448934555, 62.55880571901798, 65.99980607628822, 42.67873227596283, 51.576505824923515, 61.92193329334259, 58.815979957580566, 61.54728479683399, 59.336305037140846, 56.00801043212414, 57.95939192175865, 57.62693636119366, 59.533943831920624, 58.48654143512249, 56.421743631362915, 51.45482875406742, 53.8776471465826, 55.41227079927921, 52.31170177459717, 56.93853110074997, 55.85197560489178, 54.46831025183201, 55.581281930208206, 52.71322622895241, 51.848339438438416, 53.09384040534496, 52.40576192736626, 50.20587757229805, 51.119371354579926, 50.40772274136543, 48.856748566031456, 47.596975564956665, 46.51417426764965, 49.979899898171425, 49.358283653855324, 46.988510414958, 50.706268921494484, 51.91612780094147, 47.23767824470997, 48.92688900232315, 53.30142326653004, 53.91789458692074, 58.15746009349823, 57.16352082788944, 55.80004379153252, 54.53327536582947, 59.93351139128208, 62.748825922608376, 59.08276364207268, 61.45693324506283, 60.0037582218647, 53.5141434520483, 52.874945551157, 50.65399892628193, 49.54702712595463, 57.539852634072304, 53.54730427265167, 52.35658876597881, 48.05857099592686, 48.95871989428997, 48.33976350724697, 45.084873363375664, 45.92606462538242, 42.89653278887272, 43.379680663347244, 43.3859883248806, 44.47955444455147, 50.2456234395504, 47.80387066304684, 50.97186326980591, 52.760431095957756, 49.10331733524799, 47.76759780943394, 47.26355105638504, 54.45879936218262, 57.333079129457474, 54.21946160495281, 52.48825170099735, 56.670056506991386, 58.40655952692032, 53.45509082078934, 51.18639975786209, 55.48330798745155, 51.15242198109627, 52.690157666802406, 49.850011467933655, 51.43462523818016, 52.51635119318962, 55.268604308366776, 59.99958984553814, 62.07108289003372, 61.23083397746086, 61.3815338909626, 63.278008326888084, 67.60800138115883, 58.372676745057106, 61.07395939528942, 50.698722526431084, 54.24531161785126, 50.37222884595394, 53.60615931451321, 53.68228442966938, 60.827690809965134, 58.76680679619312, 66.94509655237198, 62.230951711535454, 71.87643393874168, 63.35858300328255, 72.21041321754456, 63.70164379477501, 75.08533895015717, 60.53712420165539, 89.87272426486015, 17.394548915326595, 0.2950005844468251, 4.1607387363910675, 0.34334625117480755, 0.23791016195900738, 56.097731217741966, 76.61229461431503, 74.92427319288254, 70.79500436782837, 60.013348907232285, 42.03038066625595, 62.670439928770065, 45.12496501207352, 38.02597314119339, 73.95554557442665, 89.43897753953934, 31.45914651453495, 1.0983603936620057, 0.5994737043511122, 0.30425899545662105, 0.35087715019471943, 0.11854172698804177], [0.036522066802717745, 0.0962087074003648, 0.11480285378638655, 0.09141635557170957, 0.028615036208066158, 0.035024386816076, 0.28879183635581285, 0.9454866405576468, 57.76934131979942, 61.43285773694515, 31.682439632713795, 33.71973641216755, 109.69433024525642, 63.805279433727264, 58.73198166489601, 17.316951379179955, 50.41986308991909, 66.15459457039833, 48.90128217637539, 62.92542524635792, 47.50098891556263, 0.7658715848810971, 0.4680067556910217, 0.40237439156044275, 0.5252278852276504, 0.35447353846393526, 25.140893049538136, 37.91550166904926, 49.93312060832977, 67.30894222855568, 53.95168997347355, 60.873964726924896, 60.03202110528946, 61.325498297810555, 57.82327562570572, 58.4998445212841, 54.71735268831253, 47.600885555148125, 43.09684284031391, 47.76798538863659, 50.485785752534866, 51.94138504564762, 62.304321974515915, 50.240182131528854, 41.188532039523125, 51.98838472366333, 55.784023851156235, 58.03091548383236, 54.11805644631386, 54.4836500287056, 51.92444175481796, 56.361117884516716, 53.748590871691704, 55.5108755081892, 49.9396638572216, 49.24694582819939, 48.305561542510986, 48.64919990301132, 50.980477407574654, 45.69795906543732, 47.6987075060606, 45.78769125044346, 45.64039595425129, 46.84718459844589, 44.868034198880196, 44.47651460766792, 41.35516829788685, 43.87336157262325, 42.22855523228645, 42.483069375157356, 46.23824067413807, 42.32170723378658, 44.076988846063614, 41.94148063659668, 40.07521837949753, 44.4199850410223, 42.968698516488075, 44.37684215605259, 43.41726064682007, 45.67387595772743, 46.53804838657379, 49.294675067067146, 49.31899756193161, 48.66137444972992, 48.69690254330635, 49.657206013798714, 52.0666491240263, 57.32139855623245, 54.78117026388645, 58.38121488690376, 57.554413452744484, 55.24390183389187, 52.37108498811722, 50.96068426966667, 47.426767498254776, 48.03577221930027, 47.95191831886768, 48.96995209157467, 45.93958429992199, 43.41912254691124, 43.044512048363686, 41.38039134442806, 43.19209612905979, 40.817671939730644, 38.55439558625221, 40.556276366114616, 40.73920235037804, 41.10706441104412, 43.39658595621586, 47.21782810986042, 44.981404915452, 41.78321532905102, 41.07211008667946, 40.357486233115196, 41.56967058777809, 46.85869798064232, 47.49467745423317, 49.65173430740833, 45.77922910451889, 48.31674814224243, 49.95001070201397, 47.342917397618294, 47.81236320734024, 49.0175711363554, 45.911222621798515, 52.575514018535614, 49.34662587940693, 54.253902956843376, 50.57043381035328, 50.62445931136608, 53.64094264805317, 56.95808485150337, 53.68351936340332, 66.29238277673721, 77.23061263561249, 55.02684608101845, 55.04586026072502, 54.217576906085014, 54.19440574944019, 54.79161970317364, 50.386269092559814, 46.218702122569084, 43.551587238907814, 47.61044584214687, 48.88036049902439, 52.73889385163784, 53.65037754178047, 61.70205049216747, 57.587745264172554, 63.830327689647675, 59.48082648217678, 63.96942302584648, 62.37417742609978, 68.94710272550583, 4.947202010080218, 0.10636472376063466, 2.285235137678683, 0.1726331381360069, 0.5594815034419298, 55.99179670214653, 60.504518151283264, 61.58975891768932, 54.27567198872566, 56.35342329740524, 27.730195708572865, 41.638773679733276, 33.833722695708275, 42.22210317850113, 56.83135025203228, 70.42396947741508, 15.665060319006443, 1.089912853203714, 0.22070352744776756, 0.14583647134713829, 0.07473631936591119, 0.05624558012641501, 0.07341672884649597, 0.06549468089360744, 0.11209699077880941, 0.07142010668758303, 0.07710714722634293, 0.061224389137350954, 0.08223919488955289, 1.3095307373441756, 70.67676231265068, 68.9455372095108, 45.34109741449356, 39.142372235655785, 97.86121800541878, 71.94639578461647, 49.67491686344147, 20.15007935464382, 61.364336013793945, 71.25622361898422, 56.03530056774616, 67.17534139752388, 51.724865064024925, 0.7665333431214094, 0.8404159848578274, 0.8446066849865019, 0.36343108280561864, 0.4213261418044567, 24.13669053465128, 45.24839758872986, 61.76344759762287, 69.06852900981903, 56.82934395968914, 62.605045437812805, 61.06917165219784, 65.60577481985092, 59.584332928061485, 60.78507609665394, 56.795871555805206, 51.41012415289879, 45.87385542690754, 51.06876567006111, 53.68459090590477, 55.577413737773895, 65.54683238267899, 54.101082757115364, 42.395696863532066, 53.818256333470345, 59.48749512434006, 58.33479277789593, 56.40765018761158, 56.932208240032196, 55.27186453342438, 57.54867196083069, 55.963640213012695, 57.55614995956421, 53.06489355862141, 51.80625669658184, 50.10853819549084, 51.88587382435799, 52.92572222650051, 51.26594088971615, 51.45045518875122, 49.77494269609451, 50.273874923586845, 50.674901604652405, 48.83240707218647, 49.0180841088295, 43.89033146202564, 48.37502561509609, 44.35074895620346, 47.587251886725426, 47.91226364672184, 46.74007214605808, 45.950573310256004, 44.719116389751434, 42.22248315811157, 44.82162348926067, 45.118763744831085, 45.85491344332695, 46.91822938621044, 47.24698394536972, 48.772659078240395, 50.11860005557537, 50.877464935183525, 50.51960773766041, 50.184674710035324, 51.51583828032017, 55.52182652056217, 59.18535813689232, 57.57655866444111, 60.16154855489731, 57.75167606770992, 55.85680894553661, 55.11811338365078, 51.162134259939194, 48.37174639105797, 49.968785494565964, 50.477939173579216, 49.341708943247795, 48.972813338041306, 46.7191656678915, 45.47601297497749, 44.48849156498909, 45.35975061357021, 41.059570759534836, 42.221069633960724, 41.58254809677601, 44.14641112089157, 42.61292360723019, 47.869314551353455, 48.86208347976208, 48.81831742823124, 47.10877776145935, 46.16259053349495, 44.66530367732048, 45.561044812202454, 49.65416617691517, 51.915569230914116, 53.4550566226244, 49.255039393901825, 51.89794197678566, 52.436270490288734, 49.78140614926815, 51.38248063623905, 50.9420994669199, 50.37585385143757, 57.31300860643387, 51.647808998823166, 56.01539723575115, 52.086050882935524, 53.65336038172245, 55.56141659617424, 61.178571581840515, 56.423586532473564, 61.879960745573044, 77.61743187904358, 60.93210160732269, 57.8888601064682, 58.2250090688467, 56.67869724333286, 56.78011380136013, 54.4878564029932, 49.92675594985485, 45.400758013129234, 50.486933290958405, 50.296616703271866, 56.46702580153942, 56.08178347349167, 63.90379294753075, 59.10002991557121, 67.96059966087341, 62.02084578573704, 67.86464720964432, 64.09513548016548, 76.72209352254868, 5.248386673629284, 0.12492426380049437, 3.3136758394539356, 0.125352468166966, 1.0519866133108735, 62.96325981616974, 69.35158342123032, 65.38744613528252, 58.70328560471535, 64.082200974226, 32.65394300222397, 48.00953842699528, 41.42361782491207, 37.130308002233505, 64.18370112776756, 77.67243772745132, 22.823682390153408, 0.8282129990402609, 0.33050650265067816, 0.1549410351435654, 0.2686228748643771, 0.07227475653053261, 0.13413762644631788, 0.2597288286779076, 0.46563428768422455, 0.15658024640288204, 0.1956822708598338, 0.15268168528564274, 0.34767211123835295, 1.645041808951646, 80.23573458194733, 81.50550484657288, 43.87186445295811, 46.03398263454437, 116.89655497670174, 75.30068099498749, 72.75734826922417, 27.635620683431625, 65.60068309307098, 74.90870162844658, 60.60772441327572, 72.38308355212212, 59.567971006035805, 0.8188742876518518, 1.0232568299397826, 1.5088053443469107, 1.273405363317579, 0.6263019272591919, 29.497273787856102, 42.86002054810524, 49.88789163529873, 73.42685714364052, 59.85655032098293, 67.54262208938599, 64.21706333756447, 66.95130541920662, 62.08554111421108, 62.64676719903946, 59.276526644825935, 53.440769389271736, 47.6783861964941, 52.70789511501789, 55.345667973160744, 57.398637011647224, 64.00266364216805, 55.71223050355911, 42.91568376123905, 55.06817266345024, 60.973701775074005, 61.96333967149258, 59.881419986486435, 60.282815247774124, 58.23309123516083, 63.087965324521065, 58.613595217466354, 60.87022952735424, 55.69516561925411, 53.244395926594734, 53.195336759090424, 55.26093252003193, 57.75460571050644, 54.557035490870476, 56.97623647749424, 52.815345749258995, 54.90019127726555, 55.60004532337189, 52.36777916550636, 53.87129008769989, 47.13530793786049, 52.18238331377506, 48.322060257196426, 50.8512881398201, 54.93100382387638, 48.18796165287495, 48.50487984716892, 47.15384714305401, 44.80940714478493, 49.90717560052872, 48.706991001963615, 47.51844897866249, 48.32643382251263, 51.95218786597252, 49.072918966412544, 52.588190138339996, 55.989494025707245, 54.86643768846989, 51.96663089096546, 54.931615591049194, 55.96233308315277, 61.010145619511604, 57.37067811191082, 62.1266283094883, 61.057943254709244, 56.96215823292732, 57.289286479353905, 53.03689286112785, 49.92811247706413, 52.58291222155094, 55.65401382744312, 52.53661930561066, 52.12205395102501, 47.080902457237244, 48.05379465222359, 46.911226361989975, 48.38460110127926, 44.892653077840805, 43.786600828170776, 45.46483017504215, 46.43271803855896, 44.011989533901215, 50.39266414940357, 52.766081392765045, 53.29481162130833, 51.27554677426815, 49.950599670410156, 48.151198625564575, 49.814209789037704, 55.21118178963661, 56.79724708199501, 59.30269584059715, 54.4851091504097, 56.6451146453619, 56.28205932676792, 51.95363558828831, 54.070391803979874, 53.7919807434082, 52.989695593714714, 58.63223321735859, 53.08650299906731, 58.61684784293175, 56.693782433867455, 55.768452286720276, 59.16815645992756, 61.550640016794205, 62.75121219456196, 60.71413770318031, 78.60448971390724, 65.50166040658951, 61.5123076736927, 61.68168358504772, 60.79170674085617, 60.05684897303581, 56.01838007569313, 53.196427300572395, 48.211695179343224, 53.668654561042786, 54.41193647682667, 61.69541224837303, 58.18463243544102, 68.44959542155266, 63.34016539156437, 73.64132523536682, 64.06561866402626, 72.21980631351471, 65.98613440990448, 81.51257246732712, 7.524691103026271, 0.18680735724046826, 4.363866336643696, 0.17951056128367782, 1.444638662505895, 68.80842536687851, 75.82774311304092, 74.05053287744522, 67.54319965839386, 71.50707095861435, 38.634575083851814, 60.790270417928696, 48.31179320812225, 53.607341051101685, 76.77871808409691, 90.22750362753868, 31.862329579889774, 1.5401065209880471, 0.4520027566468343, 0.2196534923859872, 0.3203313908306882, 0.1441496142069809], [0.11180148983839899, 0.054260702454485, 0.1133618553285487, 0.13196737883845344, 0.058510087910690345, 0.09591059410013258, 0.2866521058604121, 0.5212994897738099, 55.619234293699265, 62.20445193350315, 48.599046394228935, 59.849615693092346, 98.6783641576767, 57.38058798015118, 56.20792530477047, 27.875925488770008, 30.562143847346306, 67.42890179157257, 48.01919370889664, 58.47784750163555, 53.187706768512726, 2.0231059659272432, 0.1152906303468626, 0.9627329057548195, 0.24581747828051448, 0.35975596751086414, 6.37922546826303, 36.17251239717007, 38.46999071538448, 69.39270481467247, 53.56449455022812, 62.47663512825966, 61.469244584441185, 66.90816253423691, 54.20361265540123, 56.782545670866966, 46.86947040259838, 47.17396326363087, 43.540757820010185, 52.20620043575764, 51.40795826911926, 56.422051414847374, 54.54629726707935, 47.039959654212, 46.343050450086594, 53.658699095249176, 57.05053009092808, 58.026462122797966, 52.28331349790096, 56.5376678109169, 53.453373312950134, 58.1210732460022, 55.60467727482319, 54.37899984419346, 50.86688630282879, 50.371734872460365, 45.8599291741848, 47.78168745338917, 47.57210969924927, 48.37204657495022, 48.53991016745567, 48.453062027692795, 46.86716012656689, 49.66384805738926, 45.42318440973759, 48.0611776560545, 41.80023841559887, 43.18809874355793, 40.63007600605488, 40.16272008419037, 42.249112129211426, 41.14101938903332, 43.07114861905575, 43.75733479857445, 42.68946290016174, 41.547206193208694, 43.35840940475464, 44.48751121759415, 43.788382932543755, 45.04637002944946, 47.40431450307369, 46.07078365981579, 45.20025037229061, 50.228752344846725, 48.06374631822109, 52.73773871362209, 54.19013857841492, 61.15475445985794, 51.10295623540878, 52.55364999175072, 57.47844032943249, 56.259853318333626, 49.34881456196308, 50.154508128762245, 49.601964578032494, 47.60169871151447, 48.374102264642715, 48.660538494586945, 47.78869807720184, 44.79138471186161, 45.58862753212452, 44.5757120847702, 41.474721282720566, 40.971559882164, 38.846349120140076, 40.761564150452614, 40.87690696120262, 41.97490744292736, 43.30741994082928, 45.81172116100788, 42.28588655591011, 43.65466430783272, 40.92839039862156, 41.40583477914333, 41.36980891227722, 49.3673499673605, 45.375272780656815, 44.34845007956028, 44.69950944185257, 47.841051667928696, 47.736758664250374, 47.29808360338211, 46.400522366166115, 48.382127434015274, 53.864416256546974, 57.60672524571419, 57.59136646986008, 56.29380449652672, 52.197023928165436, 52.492085695266724, 53.911966904997826, 57.84964621067047, 57.29986131191254, 69.96996223926544, 44.3861136585474, 53.10151979327202, 59.03178557753563, 58.071147724986076, 56.32694251835346, 56.526944786310196, 56.6402281075716, 53.24956364929676, 46.488537043333054, 47.15593323111534, 43.174708262085915, 46.79765045642853, 48.127058520913124, 51.130063980817795, 52.95533023774624, 55.50292253494263, 60.25666885077953, 61.21728390455246, 62.742016687989235, 57.03447215259075, 0.36353709117975086, 0.5369379068724811, 1.0933659179136157, 0.1614865253213793, 2.8276743181049824, 68.80914732813835, 54.70181152224541, 63.2467208057642, 58.51366437971592, 73.6459381878376, 27.622009813785553, 39.345604330301285, 38.38847368955612, 44.66241203248501, 55.38365073502064, 62.95784890651703, 13.154154103249311, 0.871898423647508, 0.24227035377407447, 0.06866109848488122, 0.08022126567084342, 0.0768800351943355, 0.14172164839692414, 0.12705428700428456, 0.1169270437094383, 0.08010385790839791, 0.08551358012482524, 0.1424534060060978, 0.29451450740452856, 0.5873658321797848, 60.375085696578026, 71.36376544833183, 45.915330201387405, 54.80845659971237, 105.02995133399963, 60.907372534275055, 67.01558277010918, 28.596703112125397, 39.19876880943775, 73.55857327580452, 54.28525507450104, 63.64766389131546, 60.35310387611389, 2.052937690168619, 0.015985105819709133, 2.192316586151719, 0.2825776260579005, 0.4542696912540123, 7.930714040994644, 38.413259759545326, 50.72993025183678, 74.52354669570923, 55.86359158158302, 66.72210171818733, 63.280778378248215, 68.24781864881516, 56.96618601679802, 59.28848460316658, 49.162195175886154, 48.67169849574566, 46.25108778476715, 53.76809902489185, 53.906350806355476, 59.417366087436676, 58.47818948328495, 48.58387380838394, 45.47457665205002, 54.163441210985184, 59.55315940082073, 60.406726598739624, 54.85284201800823, 58.64322602748871, 55.267430171370506, 61.18201419711113, 58.19318577647209, 57.036892622709274, 53.73026065528393, 52.406043112277985, 49.058084562420845, 50.0519098341465, 50.72711460292339, 51.2309979647398, 50.58959238231182, 51.20977610349655, 50.37850610911846, 52.76499845087528, 49.658304154872894, 51.09164424240589, 44.45758402347565, 47.05895483493805, 43.82824279367924, 42.750837206840515, 45.466574281454086, 44.01536375284195, 46.227988824248314, 45.53951516747475, 41.98599524796009, 41.8937323987484, 44.060083553195, 45.901977717876434, 46.55176185071468, 47.49860644340515, 47.29388102889061, 50.00366002321243, 47.493404522538185, 52.666754722595215, 48.760568127036095, 54.82980005443096, 55.82117445766926, 62.921933233737946, 53.6025533080101, 51.67419098317623, 58.93524035811424, 58.70508670806885, 51.88530385494232, 51.705725491046906, 50.7593634724617, 49.661366790533066, 50.25263026356697, 50.57071499526501, 49.40084896981716, 46.23658016324043, 48.188679814338684, 45.89426413178444, 41.9661109149456, 42.907077223062515, 42.357672303915024, 42.690211459994316, 43.41197893023491, 44.4662893563509, 45.97199276089668, 47.11591757833958, 44.49743628501892, 48.62374886870384, 45.662970542907715, 43.93882445991039, 44.57533210515976, 51.98646202683449, 52.03949958086014, 48.891459703445435, 48.3426171541214, 53.58998738229275, 50.98139315843582, 49.68226946890354, 50.66991627216339, 49.369527250528336, 55.95036752521992, 58.80008541047573, 59.46471154689789, 57.347890734672546, 56.8558057397604, 55.46916514635086, 55.47596298158169, 61.46617814898491, 60.39525881409645, 68.02312910556793, 49.74315360188484, 56.19467541575432, 61.40335991978645, 61.30621053278446, 61.503837928175926, 59.3143992125988, 59.297372326254845, 56.5248890966177, 49.824062660336494, 49.13626916706562, 48.902273923158646, 50.81631101667881, 53.19347485899925, 52.55600966513157, 54.98892791569233, 59.02938410639763, 62.97349266707897, 66.07068747282028, 68.80297645926476, 62.55987726151943, 0.46923278365284204, 0.8773592649959028, 2.3683867882937193, 0.08629269417724572, 2.9965016338974237, 75.764871686697, 61.402136385440826, 69.32655036449432, 65.99436476826668, 80.81385836005211, 31.91327914595604, 47.86044202744961, 43.82005423307419, 43.71350035071373, 65.07136389613152, 72.12532058358192, 18.382381908595562, 0.9317474684212357, 0.36516334454063326, 0.13637287134770304, 0.22836899268440902, 0.16984658141154796, 0.20693861762993038, 0.270155172329396, 0.34393394307699054, 0.2716632460942492, 0.18219792254967615, 0.24665019765961915, 0.6421825813595206, 0.8996801578905433, 74.50012475252151, 81.21304973959923, 60.7726963609457, 75.4842035472393, 107.41454377770424, 66.64225280284882, 70.32498478889465, 37.557207494974136, 46.30524627864361, 78.1373655796051, 62.11809776723385, 68.74176934361458, 66.00680530071259, 2.4170802254229784, 0.16675578866852447, 3.088908875361085, 0.7938621297944337, 0.5447368696331978, 9.007646553218365, 40.22686444222927, 40.293163284659386, 75.11430099606514, 58.51177588105202, 67.25688502192497, 64.82475712895393, 71.20453879237175, 59.817062839865685, 61.436315551400185, 52.62517735362053, 50.73469899594784, 47.92753502726555, 58.00288438796997, 56.46157689392567, 62.37279810011387, 59.26038511097431, 49.96862210333347, 47.14464023709297, 57.19394579529762, 61.919904202222824, 62.626928463578224, 56.5672492235899, 61.05313651263714, 57.59900785982609, 63.630002439022064, 60.911179929971695, 58.976205959916115, 55.71477256715298, 54.80746865272522, 50.8976836502552, 53.5358364880085, 55.17351061105728, 56.03614032268524, 55.683488845825195, 53.14664617180824, 56.21899411082268, 56.48413248360157, 52.98521563410759, 57.36554838716984, 48.75167280435562, 51.89375080168247, 48.50063167512417, 47.53943145275116, 49.65001679956913, 46.53941631317139, 48.249195367097855, 49.76596757769585, 46.02466933429241, 45.91342270374298, 46.89843624830246, 48.015872687101364, 47.30686493217945, 49.332464039325714, 49.47137698531151, 52.36929528415203, 50.55681154131889, 56.03014424443245, 50.956588089466095, 58.10233265161514, 57.030068188905716, 67.03716561198235, 51.07906311750412, 53.16698268055916, 61.82008735835552, 61.82536527514458, 51.82829551398754, 54.100208804011345, 54.06621962785721, 55.044629126787186, 51.57699219882488, 53.22291187942028, 54.18198421597481, 49.33269962668419, 50.77358990907669, 47.89821960031986, 44.84266296029091, 45.4591266810894, 43.947351202368736, 45.197286531329155, 45.1089982688427, 47.03649044036865, 48.45027297735214, 52.843730226159096, 50.58824345469475, 52.028297781944275, 48.86232286691666, 47.091184705495834, 49.93539288640022, 55.54563224315643, 56.67589299380779, 51.45228669047356, 54.41712699830532, 56.3662476092577, 55.53067624568939, 54.06034894287586, 52.42876969277859, 54.00573447346687, 58.37109982967377, 62.1227715164423, 62.025671526789665, 60.57733364403248, 60.16495317220688, 57.69212186336517, 58.60211983323097, 64.7552664577961, 61.21341571211815, 66.54197618365288, 60.736693292856216, 59.33001257479191, 64.67093378305435, 64.13365021348, 63.402915224432945, 63.54989133775234, 62.48021453619003, 58.92190307378769, 52.90856994688511, 52.042163237929344, 51.32587507367134, 53.01964558660984, 55.92812351882458, 57.3863560706377, 59.03923697769642, 64.19386178255081, 66.51190459728241, 69.57355231046677, 67.65515685081482, 69.71546709537506, 1.1884613963775337, 1.2038512830622494, 4.271628186106682, 0.24624718178529292, 4.040211103856564, 79.5192602276802, 68.18580597639084, 79.08930569887161, 71.9082610309124, 86.54347971081734, 38.66398170590401, 56.65058255195618, 54.65724751353264, 58.455983474850655, 73.53884473443031, 86.01231381297112, 25.835541374981403, 1.3644342287443578, 0.5902570020407438, 0.32907908549532294, 0.4694644524715841, 0.26196961000096053], [0.05951193532382604, 0.03361168273841031, 0.10691294824937358, 0.11316523814457469, 0.10385637593572028, 0.04658617188397329, 0.45802495849784464, 0.6919226248282939, 57.54643388092518, 65.14198690652847, 65.11364802718163, 44.00952346622944, 76.29820346832275, 52.0347498357296, 41.67110234498978, 27.427578046917915, 41.77871637046337, 63.02236944437027, 57.00737580657005, 50.810835510492325, 61.7217106372118, 7.1077394764870405, 0.06965147971641272, 1.481294701807201, 0.1296507054939866, 0.023241566050273832, 0.7152344333007932, 30.2199874073267, 34.84546020627022, 63.24834331870079, 58.36514554917812, 62.929460629820824, 63.23295034468174, 60.366938933730125, 57.07151636481285, 57.40791991353035, 45.61575807631016, 47.3335774987936, 47.30930060148239, 55.463397055864334, 56.051947474479675, 59.10016670823097, 50.03049798309803, 45.98188363015652, 49.69081901013851, 51.9114388525486, 54.033887162804604, 56.37136213481426, 55.901718735694885, 54.76596347987652, 55.9409174323082, 55.843414664268494, 52.54375532269478, 55.60243159532547, 55.14472335577011, 50.04009246826172, 49.17856089770794, 46.173108369112015, 52.538040429353714, 49.3097260594368, 51.22447371482849, 52.64643721282482, 49.031759575009346, 50.91241545975208, 47.55798205733299, 48.72116804122925, 42.898603677749634, 42.113656997680664, 41.31718933582306, 40.271185263991356, 41.639879420399666, 41.271257400512695, 42.64369435608387, 43.193984627723694, 41.550344824790955, 44.769805669784546, 41.50751732289791, 41.45281545817852, 44.472460225224495, 46.484611853957176, 46.10502742230892, 46.35021686553955, 49.15144555270672, 48.724929839372635, 46.272461637854576, 51.95751518011093, 57.11359150707722, 53.93171064555645, 40.85857294499874, 44.12177324295044, 56.61117106676102, 56.13183058798313, 54.20388624072075, 47.41760239005089, 47.25020617246628, 43.31786938011646, 46.46883890032768, 46.8802884221077, 47.13979549705982, 46.38982594013214, 43.720073997974396, 42.300587967038155, 40.765405744314194, 40.71322314441204, 39.466567039489746, 41.87334269285202, 42.99508050084114, 42.89140686392784, 41.35259583592415, 42.6239088177681, 41.73964686691761, 41.14951953291893, 42.27200970053673, 42.11305283010006, 43.146247789263725, 45.564217641949654, 48.99436578154564, 49.83466029167175, 45.2928514033556, 46.729242727160454, 48.99839736521244, 46.255970522761345, 50.24507626891136, 48.58447417616844, 53.619329407811165, 54.76215988397598, 53.73067483305931, 56.401095539331436, 58.04208688437939, 53.011768609285355, 59.67279218137264, 53.2786662876606, 64.40430209040642, 51.468424424529076, 41.79828152060509, 62.95408710837364, 51.49740166962147, 57.11616396903992, 56.59368820488453, 62.0307594537735, 60.00627748668194, 61.03908106684685, 52.662749737501144, 49.22389626502991, 48.395308926701546, 46.54401406645775, 46.63363225758076, 49.92131844162941, 48.65639291703701, 55.4486196488142, 58.55502516031265, 58.19032832980156, 65.39395898580551, 31.439588963985443, 0.08555559310480021, 0.8380259724799544, 0.44321842957288027, 0.23601204506121576, 8.880890104919672, 76.55889987945557, 49.49199087917805, 68.04965928196907, 51.67061537504196, 78.47922563552856, 28.892399445176125, 39.49641443789005, 39.42865267395973, 33.3952110260725, 52.71937429904938, 59.27497632801533, 6.451967814937234, 0.7072449463885278, 0.10813807079102844, 0.08027361676795408, 0.10152631424716674, 0.03573376496206038, 0.062089855782687664, 0.02297128885402344, 0.11757977001252584, 0.08233029351686127, 0.1381256608874537, 0.03822148479230236, 0.3129332175012678, 0.7016984315123409, 63.69757421314716, 75.53654953837395, 63.5972785949707, 53.48972976207733, 85.15184238553047, 59.37524154782295, 46.41339987516403, 29.52781654894352, 42.57750950753689, 68.83504673838615, 59.133072942495346, 57.37431451678276, 67.00779318809509, 8.057132307440042, 0.14412242191610858, 1.561699218582362, 0.3620365576352924, 0.015314146803575568, 0.7697848998941481, 31.9277373701334, 44.49628494679928, 70.37291541695595, 60.945473089814186, 66.51800706982613, 62.533005103468895, 64.27307993173599, 58.61297585070133, 59.15193893015385, 47.826088070869446, 48.6388036608696, 50.73550075292587, 59.175904244184494, 57.52167820930481, 61.04005381464958, 52.67872788012028, 49.30118791759014, 51.11346647143364, 54.23405662178993, 56.92815765738487, 58.85006792843342, 56.38344548642635, 57.27922081947327, 59.494954124093056, 57.09472931921482, 55.550864562392235, 57.35365882515907, 56.09703965485096, 52.26050332188606, 52.704118117690086, 50.151867270469666, 55.025633946061134, 53.309851214289665, 55.63021570444107, 53.65218624472618, 51.56340792775154, 54.524372443556786, 51.63099870085716, 52.26506307721138, 44.62548941373825, 44.91355575621128, 44.97559882700443, 44.825928658246994, 44.45529654622078, 42.85408906638622, 44.37667116522789, 44.31582123041153, 43.54718707501888, 46.48981377482414, 44.50911305844784, 42.520326375961304, 45.760393515229225, 47.72440932691097, 46.50450378656387, 47.980724573135376, 49.56706345081329, 48.94052267074585, 47.73004822432995, 53.4390214830637, 58.628216832876205, 56.79665431380272, 41.67432077229023, 45.29069311916828, 58.1721007078886, 59.24077056348324, 55.00927582383156, 50.489676743745804, 48.69672015309334, 47.570213600993156, 49.04424570500851, 49.36099290847778, 49.012790992856026, 48.64161550998688, 44.99332867562771, 45.283082127571106, 43.061926513910294, 41.10153950750828, 41.12323634326458, 43.101835772395134, 44.23697166144848, 45.001293048262596, 44.3785634636879, 45.51604002714157, 45.49742102622986, 46.413411274552345, 46.80298537015915, 48.14456418156624, 45.644910112023354, 50.5837444961071, 53.84302340447903, 53.7430127710104, 49.869956597685814, 50.54684467613697, 51.426755860447884, 47.88889490067959, 50.39574198424816, 50.06987527012825, 56.5103966742754, 55.93527093529701, 55.704839900135994, 58.934480398893356, 59.930273965001106, 55.60950681567192, 61.39311566948891, 57.70976431667805, 65.29191166162491, 52.90068916976452, 45.04209145903587, 65.4114380478859, 55.003123953938484, 56.80648438632488, 59.46439616382122, 65.22463247179985, 62.24833957850933, 61.77954353392124, 53.053991943597794, 51.96036122739315, 51.41976423561573, 48.854757472872734, 51.189884170889854, 51.0121601074934, 52.77357459068298, 59.858370423316956, 62.48834989964962, 63.206663355231285, 70.77524542808533, 34.673200249671936, 0.06132534719654359, 1.4944528019987047, 1.4080918673425913, 0.11417694870033301, 10.733743831515312, 82.69479542970657, 60.27435690164566, 81.30901739001274, 57.31851451098919, 86.19768306612968, 33.35171855986118, 49.612239226698875, 46.3353368639946, 32.4852130562067, 63.135933950543404, 67.79681324958801, 9.671621974557638, 0.7507828914094716, 0.2702726097777486, 0.10072760007460602, 0.2551254350692034, 0.04228057245200034, 0.15023792657302693, 0.11591718852287158, 0.19750878534978256, 0.33301798976026475, 0.24046680133324116, 0.13960005599074066, 0.6431456515565515, 0.8074795897118747, 71.52523398399353, 87.81895726919174, 77.79081657528877, 59.34874936938286, 84.35567870736122, 65.43675228953362, 56.47468239068985, 37.12951384484768, 55.18350787460804, 75.34395307302475, 67.10197493433952, 62.16117225587368, 75.44203341007233, 9.459616150707006, 0.26110192062333226, 2.85297027323395, 0.4313064250163734, 0.1880515381344594, 0.9991793031804264, 35.18697828054428, 40.41200190782547, 68.06456208229065, 65.15134200453758, 68.71302008628845, 67.50407695770264, 66.76209077239037, 61.22818171977997, 62.097282484173775, 51.044021397829056, 52.20841571688652, 54.205022379755974, 62.92510986328125, 61.70251786708832, 63.19771483540535, 53.41728284955025, 49.794291257858276, 51.94438308477402, 57.747245505452156, 59.49741639196873, 61.169756054878235, 60.6830819696188, 59.0555115044117, 60.85191830992699, 58.119184747338295, 57.542957067489624, 59.94122117757797, 59.071056470274925, 55.10256461799145, 54.88521248102188, 52.69814483821392, 58.91186021268368, 55.707712545990944, 59.5674542337656, 59.038686007261276, 52.56193734705448, 57.47781716287136, 55.44336833059788, 58.43249313533306, 48.666352182626724, 48.15980136394501, 50.3853115439415, 48.629668951034546, 49.46744039654732, 47.78118208050728, 48.90038542449474, 49.865507036447525, 45.56175157427788, 48.49606432020664, 44.330917820334435, 44.678162187337875, 50.53587466478348, 50.57676047086716, 49.59127955138683, 50.39712131023407, 53.69399920105934, 52.012372836470604, 50.06754219532013, 56.602226346731186, 61.759112030267715, 57.24480226635933, 40.72085313498974, 44.82796534895897, 58.37951637804508, 60.91626025736332, 59.776785001158714, 51.01223610341549, 51.9534607976675, 48.80915991961956, 50.12124091386795, 51.59618876874447, 51.53623938560486, 51.43526740372181, 47.425247579813, 45.76344475150108, 47.06278122961521, 45.24598091840744, 44.21888083219528, 47.485584542155266, 46.12262427806854, 49.485402032732964, 47.39674910902977, 49.74161088466644, 48.08495678007603, 50.435594245791435, 51.86614528298378, 52.346583902835846, 50.42602635920048, 54.21843186020851, 60.0821366161108, 58.3075862377882, 53.72899532318115, 55.849984511733055, 55.39363659918308, 51.80542454123497, 56.01635858416557, 54.295689314603806, 58.02422024309635, 59.58774134516716, 59.60353709757328, 61.59322813153267, 62.15146377682686, 58.64329442381859, 64.59736213088036, 59.06328208744526, 65.88052287697792, 55.340051874518394, 48.97311732172966, 66.88729405403137, 57.35553592443466, 60.44480435550213, 63.82463559508324, 64.7507219016552, 64.96969655156136, 67.19634667038918, 56.57929837703705, 54.877335503697395, 54.74398925900459, 50.81636801362038, 53.57152797281742, 54.85761076211929, 54.76442836225033, 62.903975397348404, 67.5446891784668, 66.71128749847412, 75.2115073800087, 42.40334965288639, 0.23725376202492043, 2.4714275216683745, 2.22727851010859, 0.4761960287578404, 11.38352606445551, 90.27491748332977, 62.025998309254646, 84.51356023550034, 63.51068124175072, 91.85513868927956, 39.83779951930046, 60.92283010482788, 52.25806005299091, 49.197354689240456, 70.89772045612335, 81.75053849816322, 13.603332750499249, 1.4962757541798055, 0.4964270634809509, 0.1534715827438049, 0.4108782164985314, 0.16428480797912925], [0.004689751303885714, 0.027467319669085555, 0.21846095012733713, 0.050220213015563786, 0.245002644660417, 0.03863722849928308, 0.5963665398303419, 0.34744617179967463, 28.233296312391758, 76.23687475919724, 41.63335137069225, 32.83097170293331, 31.699052341282368, 42.355016246438026, 41.920209378004074, 31.17418460547924, 60.38138195872307, 65.0356762111187, 63.318346962332726, 51.10943868756294, 64.97047930955887, 16.278529800474644, 0.5798754247371107, 1.7562895081937313, 0.2666543726809323, 0.6431379332207143, 0.6728301336988807, 16.960110627114773, 33.007168248295784, 52.99091912806034, 64.69606563448906, 59.98567119240761, 64.06624183058739, 60.621605068445206, 60.2226834744215, 54.18946981430054, 48.11364144086838, 44.702370688319206, 51.61098897457123, 52.281804978847504, 59.67843487858772, 54.26187872886658, 41.02997034788132, 51.77273489534855, 53.00021342933178, 55.61719000339508, 55.24164095520973, 51.62971056997776, 56.28036081790924, 54.08419646322727, 52.30793237686157, 57.2394597530365, 52.14265264570713, 56.90265342593193, 53.084367513656616, 49.89654757082462, 48.91187980771065, 46.522856801748276, 51.63579024374485, 49.50244411826134, 50.903489738702774, 48.55437599122524, 52.640498131513596, 53.089922815561295, 49.938542917370796, 47.00760439038277, 45.06534621119499, 39.8726512491703, 42.34317988157272, 43.34462374448776, 40.49248158931732, 40.34592725336552, 43.75399477779865, 38.38397853076458, 40.208397433161736, 41.27358667552471, 42.23318338394165, 44.37868885695934, 42.72678069770336, 45.33527232706547, 46.05969965457916, 45.204601138830185, 51.04145273566246, 50.49629218876362, 52.37592592835426, 53.96702215075493, 57.530592530965805, 52.28076383471489, 46.06816940009594, 44.72739614546299, 49.894894659519196, 56.294727846980095, 50.602500289678574, 50.48982113599777, 47.53189645707607, 47.61239513754845, 48.78797985613346, 52.173313200473785, 47.91203185915947, 47.59296678006649, 42.32587940990925, 43.63170973956585, 42.030445262789726, 40.96115604043007, 41.31421409547329, 43.51535618305206, 41.096238791942596, 37.48087719082832, 38.94557699561119, 41.835736110806465, 40.22141173481941, 43.70590455830097, 42.773810774087906, 41.12654596567154, 42.53140278160572, 45.98154544830322, 47.13178552687168, 46.65754437446594, 45.37378326058388, 49.996432811021805, 45.57388052344322, 48.218891993165016, 47.92973890900612, 49.37094837427139, 53.93389172852039, 48.96203711628914, 52.862645611166954, 52.65657886862755, 58.34865443408489, 55.044936910271645, 55.72305612266064, 56.21383398771286, 61.236153692007065, 38.58421638607979, 43.58225159347057, 53.62991563975811, 54.3719170242548, 52.46607229113579, 44.68497522175312, 46.64675295352936, 60.98472498357296, 60.02431891858578, 56.74583584070206, 51.52168236672878, 46.21682122349739, 48.74793000519276, 50.04413545131683, 49.23705115914345, 55.173214226961136, 57.98832356929779, 62.25677512586117, 56.85822620987892, 54.33378987014294, 15.153241083025932, 0.4722121503436938, 2.1996188443154097, 0.2651467442046851, 0.039783234387869015, 21.740516312420368, 76.75319865345955, 44.91876147687435, 51.80038221180439, 61.13445594906807, 71.29451036453247, 22.83781573176384, 39.242436066269875, 36.302571818232536, 35.7242314517498, 58.04635025560856, 48.613033443689346, 1.8642900441773236, 0.4807857074774802, 0.20346535166027024, 0.08497967166476883, 0.12959722633240744, 0.06388381967553869, 0.021201663694228046, 0.06303585658315569, 0.10211887463810854, 0.08390555391088128, 0.11734361120034009, 0.05492045318533201, 0.4469809995498508, 0.3715795377502218, 33.61600957810879, 88.36003303527832, 45.20377658307552, 44.8398245126009, 46.25190854072571, 54.355467706918716, 51.36848218739033, 38.041711896657944, 65.10195225477219, 69.90377739071846, 67.07487478852272, 55.71003042161465, 68.82572963833809, 17.249223813414574, 0.4180250392528251, 2.630632328800857, 0.15244617214193568, 0.21414723159978166, 0.40775012341327965, 17.27528091520071, 39.98297452926636, 58.25669936835766, 66.22389525175095, 62.18050941824913, 65.35749614238739, 62.87157453596592, 63.90724316239357, 55.87266929447651, 49.14037674665451, 48.07402856647968, 52.868041321635246, 57.600626572966576, 61.587745025753975, 57.36771047115326, 44.012814089655876, 54.108021184802055, 55.46811640262604, 55.86502030491829, 57.650225311517715, 53.73347908258438, 56.149533838033676, 56.556347608566284, 56.97418458759785, 58.75575318932533, 55.86315840482712, 59.477064684033394, 55.276097506284714, 52.63223737478256, 50.97266122698784, 50.410751178860664, 54.44281741976738, 52.75897957384586, 53.22077639400959, 50.60339704155922, 56.07731111347675, 54.35716241598129, 53.99883024394512, 49.73695233464241, 48.93428720533848, 45.56682050228119, 46.83161683380604, 46.96937844157219, 45.900074020028114, 44.38990965485573, 46.27889849245548, 40.57611130177975, 42.92115926742554, 43.91321763396263, 44.138328954577446, 44.92065377533436, 44.05234716832638, 48.042258471250534, 46.79413944482803, 48.5116358846426, 51.00865289568901, 48.20726841688156, 52.75076441466808, 54.539712220430374, 59.17958624660969, 52.97417722642422, 45.96068076789379, 46.25934474170208, 49.74982984364033, 56.31452478468418, 51.990592405200005, 51.800720393657684, 50.295491963624954, 49.89017531275749, 51.351390704512596, 52.010537534952164, 49.30706240236759, 49.20425131917, 43.98320987820625, 44.73505653440952, 42.408156394958496, 42.44127921760082, 43.746338188648224, 46.858462393283844, 44.14901778101921, 41.075974479317665, 43.461969047784805, 43.61926160752773, 43.46041113138199, 46.26978278160095, 47.4032049626112, 46.49172507226467, 47.931338623166084, 50.48316389322281, 50.230363458395004, 51.141090989112854, 50.36827325820923, 54.479816034436226, 50.62128648161888, 50.71342013776302, 51.10600747168064, 49.85151618719101, 57.4956002086401, 53.04617576301098, 55.47923840582371, 52.32961781322956, 60.25688923895359, 56.426778361201286, 61.66381314396858, 61.78857944905758, 60.956268310546875, 40.242124423384666, 46.941685527563095, 55.06611317396164, 56.43275924026966, 58.8064880669117, 51.82501249015331, 48.800545781850815, 63.498012721538544, 62.43279308080673, 58.316542357206345, 53.68596263229847, 50.01950517296791, 50.89952275156975, 53.875640854239464, 53.281991109251976, 58.309159353375435, 62.105265855789185, 64.47767615318298, 61.36132277548313, 57.74222977459431, 19.129283130168915, 0.33060776127967983, 3.425204842351377, 0.22229476628126577, 0.03841036508674733, 23.950016051530838, 85.5523332953453, 52.24437318742275, 58.94405208528042, 65.32795652747154, 82.31423065066338, 27.531720958650112, 50.946271643042564, 33.094191178679466, 33.752361461520195, 68.96967351436615, 57.48187154531479, 3.9123479649424553, 0.3250622854102403, 0.19253063685027882, 0.11496376624563709, 0.09677111433120444, 0.020896179012197535, 0.06784179713577032, 0.1205684283922892, 0.3519832174060866, 0.20090874197194353, 0.38505803793668747, 0.15238620660966262, 0.6280172383412719, 0.6195467209909111, 38.18041205406189, 98.54394257068634, 55.17255686223507, 46.433158814907074, 44.783978909254074, 60.23101642727852, 55.35327136516571, 40.52240498363972, 72.4518370628357, 76.25437662005424, 74.34116408228874, 61.548736318945885, 76.78481295704842, 20.965331308543682, 0.7126194017473608, 5.931316902860999, 0.7811251538805664, 1.6935449000447989, 0.7343944301828742, 21.44773632287979, 35.5430343747139, 53.423035740852356, 70.22061958909035, 63.43335919082165, 68.16322758793831, 63.86629655957222, 66.79524019360542, 59.1003642976284, 53.69783699512482, 50.44125214219093, 56.7544499784708, 59.27056476473808, 67.4773719906807, 58.45032177865505, 45.85998997092247, 56.45477905869484, 56.34034059941769, 60.54498217999935, 59.226832911372185, 57.13789500296116, 53.81872370839119, 57.40631639957428, 57.08128184080124, 60.96623137593269, 57.90602758526802, 63.53309623897076, 57.776469737291336, 53.56003358960152, 53.301077485084534, 53.492974787950516, 59.44113381206989, 56.51484243571758, 59.28112059831619, 57.024699077010155, 58.880154713988304, 56.582725793123245, 55.420014783740044, 54.575506299734116, 52.25295692682266, 47.330260276794434, 51.27263233065605, 50.53012557327747, 49.86444689333439, 48.71296428143978, 51.76527589559555, 42.720317244529724, 46.21557869017124, 45.97501739859581, 45.9172111004591, 48.62287111580372, 46.034336015582085, 49.641839638352394, 51.23620368540287, 51.72233060002327, 56.014534682035446, 51.999065950512886, 54.62545841932297, 57.74261735379696, 59.634231850504875, 55.108488500118256, 45.9695228934288, 46.31705604493618, 51.35119691491127, 59.536679685115814, 53.45997355878353, 54.490105882287025, 54.07884255051613, 52.307780385017395, 54.33318950235844, 56.11318498849869, 52.48000994324684, 52.87702023983002, 45.94280652701855, 48.64097714424133, 45.395537093281746, 46.145590245723724, 46.47526815533638, 47.99366667866707, 48.48102852702141, 45.728741213679314, 47.51555733382702, 48.300363421440125, 46.684690117836, 52.11642265319824, 52.72345528006554, 50.73176935315132, 50.745767802000046, 53.13879579305649, 54.550389647483826, 54.40280556678772, 53.864005878567696, 58.31117324531078, 52.31339268386364, 53.65064352750778, 54.569358229637146, 52.68709123134613, 60.7122416049242, 55.14902852475643, 60.127673372626305, 56.19899578392506, 63.41380164027214, 61.05677291750908, 61.70719921588898, 64.67441439628601, 60.29845140874386, 44.72703896462917, 49.52789515256882, 56.87249444425106, 57.668764516711235, 59.71409596502781, 54.4836538285017, 55.54776392877102, 68.66129726171494, 64.71357509493828, 62.05745682120323, 55.39687402546406, 52.487328350543976, 52.79726251959801, 56.126370280981064, 55.60936622321606, 60.430539920926094, 65.28051987290382, 67.6373890042305, 65.21235153079033, 62.70050011575222, 26.088957376778126, 0.37208856199868023, 4.586818898096681, 0.7337323750834912, 0.13321530015673488, 25.989467315375805, 92.16283857822418, 54.991701766848564, 68.29488292336464, 72.75924816727638, 85.37826463580132, 32.57711872458458, 59.9504204839468, 46.74390234053135, 52.06563837826252, 77.77311712503433, 75.89225605130196, 5.708504933863878, 0.7504644803702831, 0.4532552050659433, 0.26240308361593634, 0.24439543427433819, 0.14504940889310092], [0.09338086500065401, 0.06167442006699275, 0.07417222033836879, 0.10690530412830412, 0.02797113404085394, 0.0624429622257594, 0.369377585593611, 0.0883992580929771, 13.73693073168397, 74.8366878926754, 51.77768602967262, 51.45063377916813, 20.156875289976597, 34.79333460330963, 30.55589508265257, 29.400983154773712, 70.47215089201927, 59.78919133543968, 65.63805028796196, 51.69055290520191, 64.74705129861832, 28.421139232814312, 0.6027118430938572, 1.7169039091095328, 0.24027722713071853, 0.4406498861499131, 0.2230050609796308, 5.465816706418991, 32.47387446463108, 48.79451170563698, 57.92374223470688, 61.398241594433784, 63.78171309828758, 58.439218774437904, 58.606246411800385, 52.590333223342896, 50.860126465559006, 51.268167570233345, 56.673012748360634, 55.614397153258324, 58.7570983171463, 54.798322543501854, 48.260454162955284, 53.8406865298748, 54.81970399618149, 55.1522621512413, 52.962538450956345, 57.86435902118683, 60.34555748105049, 47.60612167418003, 58.53904701769352, 56.0111490637064, 56.01076528429985, 55.03817707300186, 52.83097431063652, 47.10249289870262, 51.862668469548225, 46.23327054083347, 51.22343637049198, 51.8113674223423, 47.61204555630684, 48.97895760834217, 49.38917979598045, 48.209544494748116, 48.0990806221962, 48.43806803226471, 45.338931530714035, 43.81688140332699, 41.71573854982853, 43.576095923781395, 36.64642296731472, 35.81507317721844, 32.66087003052235, 35.582160875201225, 43.27624261379242, 45.943285301327705, 39.117745757102966, 42.90455415844917, 42.84414120018482, 43.81888009607792, 43.19536775350571, 41.67571909725666, 47.117057517170906, 50.287330001592636, 49.20892886817455, 54.235268756747246, 53.74640218913555, 51.344494074583054, 49.747846350073814, 46.557035967707634, 49.5896190404892, 53.1559594720602, 55.1260207593441, 49.874185770750046, 52.43026301264763, 50.95327466726303, 48.288230672478676, 45.725328996777534, 45.94026826322079, 45.02803601324558, 41.90088741481304, 40.6890070438385, 46.28049820661545, 42.59470358490944, 37.22541309893131, 39.65917110443115, 42.87343382835388, 39.84202869236469, 33.267564475536346, 34.05338890850544, 40.662366673350334, 40.827654004096985, 42.61453852057457, 44.07929912209511, 46.64107985794544, 47.2241585701704, 47.91191026568413, 49.403166845440865, 49.27344560623169, 49.4550758600235, 48.45883011817932, 45.71010321378708, 51.28762252628803, 45.4956541210413, 55.753051713109016, 52.05990828573704, 58.17923292517662, 54.98620726168156, 58.72846305370331, 55.98539784550667, 61.46377667784691, 54.64963652193546, 39.327536299824715, 34.33438383042812, 50.123972967267036, 50.755825862288475, 59.45246480405331, 61.04171432554722, 62.81721845269203, 44.86952751874924, 44.400693476200104, 57.7043230086565, 58.0239200592041, 54.597879499197006, 50.86926877498627, 47.66078554093838, 51.45467296242714, 52.6096285879612, 57.24936202168465, 55.64489431679249, 62.13567182421684, 57.66317501664162, 60.967827290296555, 6.036349916830659, 0.19743779150303453, 3.6216678377240896, 0.6293113064020872, 0.020066231554665137, 40.882097482681274, 67.71410688757896, 45.41699834167957, 62.21963211894035, 63.04316192865372, 53.85584771633148, 20.60611378401518, 45.29792033135891, 39.52073313295841, 46.33057951927185, 54.03479151427746, 41.38328678905964, 0.5407603236380965, 0.15316464530769736, 0.034814199461834505, 0.06067891059501562, 0.04533364925009664, 0.08749744476517662, 0.12559580354718491, 0.029342376183194574, 0.15174197789747268, 0.05612885142909363, 0.10758390169939958, 0.045997010529390536, 0.43999195739161223, 0.10095407385961153, 16.593992672860622, 86.11497670412064, 57.89782002568245, 50.81486329436302, 29.852655418217182, 45.417427718639374, 39.56895634531975, 37.295192554593086, 76.59901052713394, 67.55064725875854, 71.41294240951538, 58.92161428928375, 70.34034356474876, 31.59786757081747, 0.47800799715332687, 2.8311107587069273, 0.8266787719912827, 0.30448695353697985, 0.14276239176979288, 5.406782599166036, 38.686670288443565, 53.210763931274414, 60.79648308455944, 63.89066085219383, 65.55239528417587, 61.54882371425629, 61.506178602576256, 55.502740144729614, 51.80259749293327, 53.55000592768192, 59.27729420363903, 57.57933251559734, 60.43068811297417, 56.897322311997414, 50.24880766868591, 56.685191094875336, 57.132902070879936, 57.71737530827522, 53.87791693210602, 54.58290450274944, 59.93751257658005, 53.28437738120556, 60.4994036257267, 57.34838470816612, 56.80390052497387, 57.515457943081856, 52.68075317144394, 50.482054352760315, 52.22648374736309, 50.01622214913368, 56.336704194545746, 54.206454902887344, 50.39867922663689, 52.285141199827194, 53.2570568472147, 53.19335326552391, 52.640232145786285, 49.26537483930588, 48.98819111287594, 47.01597914099693, 45.51840730011463, 48.47713753581047, 41.15096725523472, 39.62352901697159, 37.05474905669689, 39.94246110320091, 45.34847281873226, 46.630733013153076, 41.171201169490814, 44.16354060173035, 45.30961990356445, 46.30825191736221, 43.61394189298153, 45.785312578082085, 48.28230679035187, 51.11085221171379, 51.24770946800709, 57.83700428903103, 55.121848583221436, 53.971023336052895, 51.71908937394619, 45.89544966816902, 48.94499123096466, 54.34932343661785, 55.83477012813091, 52.875834703445435, 53.72035078704357, 52.000479474663734, 48.54306019842625, 47.88525469601154, 48.53696532547474, 46.91539093852043, 45.340440049767494, 44.17611412703991, 46.9072175770998, 42.8827091306448, 41.84711650013924, 41.762863621115685, 45.35821169614792, 43.288732543587685, 38.51079672574997, 40.12667901813984, 44.78387251496315, 46.07993356883526, 47.25810594856739, 48.48001778125763, 50.33417388796806, 50.31887210905552, 51.6046205163002, 53.408851101994514, 52.383525520563126, 51.62058345973492, 49.286269918084145, 49.495007917284966, 54.01432581245899, 48.50959539413452, 58.34404908120632, 55.708947479724884, 59.165804386138916, 57.13883355259895, 60.2166797965765, 55.23753337562084, 60.73926195502281, 57.178864404559135, 42.9047517478466, 36.782987639307976, 53.11184763908386, 55.24368144571781, 61.61105677485466, 59.01463709771633, 65.50197958946228, 55.59042803943157, 48.85586701333523, 58.907562643289566, 60.78842371702194, 56.37942150235176, 55.431060791015625, 49.03050184249878, 55.38434609770775, 55.42770937085152, 63.32271672785282, 59.84152212738991, 64.74993154406548, 62.11101494729519, 69.25642132759094, 8.591742720454931, 0.17848914343630895, 4.874984035268426, 0.31748837151098996, 0.08447607993730344, 46.66043221950531, 77.61378407478333, 48.656225726008415, 65.62233433127403, 71.050745844841, 63.83608818054199, 22.6276471093297, 55.67452892661095, 44.71135340631008, 49.75062780082226, 65.07755756378174, 50.43674558401108, 1.1651832517236471, 0.0687387865036726, 0.05392495855630841, 0.01816152438550489, 0.014270145402406342, 0.054402011082856916, 0.2630354231223464, 0.2228638154338114, 0.16140482970513403, 0.2019922627368942, 0.13070991350105032, 0.15913914190605283, 0.4901814158074558, 0.33680226013530046, 19.501583352684975, 98.72466087341309, 69.85406845808029, 70.11591240763664, 29.475728943943977, 49.990052953362465, 43.29559497535229, 38.63980360329151, 83.45150962471962, 74.66280162334442, 73.87988403439522, 63.6789096146822, 76.20860427618027, 34.557177275419235, 0.778092322871089, 5.1022089924663305, 1.4106770348735154, 0.944862999022007, 0.23549586650915444, 6.710712555795908, 37.47166268527508, 50.44702023267746, 62.07581743597984, 64.07146275043488, 70.09578868746758, 63.986636102199554, 65.31597197055817, 57.729827240109444, 55.61651363968849, 56.15947410464287, 64.28900107741356, 59.77580085396767, 63.26923839747906, 57.30170801281929, 55.711975917220116, 58.88286396861076, 59.15243290364742, 59.59615409374237, 58.90502817928791, 53.24785374104977, 61.05294652283192, 54.46873962879181, 62.62998349964619, 62.130819484591484, 59.22192357480526, 59.14436213672161, 56.12324684858322, 52.48419351875782, 55.8044895529747, 51.38635642826557, 60.72857692837715, 58.54657061398029, 53.92531178891659, 56.65732339024544, 55.812681913375854, 55.976741909980774, 56.11729636788368, 54.75846268236637, 52.84555792808533, 50.81308498978615, 49.128958359360695, 55.746987238526344, 45.77283024787903, 45.09207397699356, 42.63127662241459, 45.22934541106224, 48.40938337147236, 51.14111378788948, 43.453917279839516, 46.20388671755791, 48.779073134064674, 49.142960608005524, 45.567546263337135, 46.99167184531689, 51.45362801849842, 53.68567764759064, 52.81225271522999, 59.98260855674744, 56.042436584830284, 53.07352289557457, 51.42683565616608, 47.28454872965813, 49.94554214179516, 55.48853650689125, 58.88874225318432, 51.4346594363451, 57.14138701558113, 54.649347737431526, 50.99340811371803, 50.800150483846664, 48.91672074794769, 48.071201518177986, 48.01760919392109, 45.288930013775826, 48.78091983497143, 44.882560819387436, 46.09431579709053, 44.54838775098324, 49.40986208617687, 47.965863570570946, 42.87026099860668, 44.05866622924805, 50.53485631942749, 49.40114535391331, 50.35174414515495, 50.40567085146904, 54.431752413511276, 52.92774751782417, 55.62262751162052, 57.19705402851105, 57.51985810697079, 56.28282688558102, 51.356216445565224, 50.031641721725464, 57.23846420645714, 49.063905850052834, 63.69196951389313, 58.01652565598488, 63.267589285969734, 58.684727400541306, 66.65302142500877, 55.87478958070278, 62.645520865917206, 57.434267699718475, 45.712972059845924, 41.13031916320324, 56.49797134101391, 57.190225794911385, 61.25457510352135, 59.936300441622734, 64.46365490555763, 49.30309161543846, 54.505814239382744, 62.795027643442154, 64.4240154325962, 60.65154746174812, 57.40529425442219, 49.81897473335266, 56.233543530106544, 57.663817182183266, 67.57374241948128, 61.43190398812294, 69.82779666781425, 65.19291177392006, 74.34520706534386, 12.160409577190876, 0.5663768865633756, 6.871058251708746, 0.742914997972548, 0.191071619046852, 50.38664907217026, 82.83393636345863, 58.388008922338486, 76.72867476940155, 75.75879961252213, 69.18899774551392, 32.38875903189182, 71.53977200388908, 50.96348091959953, 61.88355155289173, 72.49458476901054, 67.48579233884811, 1.8679032940417528, 0.3080909117124975, 0.15612376620993018, 0.12491523928474635, 0.22974233696004376, 0.16199400590267032], [0.10253164975438267, 0.06198848212079611, 0.03142069952446036, 0.12177340904599987, 0.1768871583044529, 0.01951137226569699, 0.12069331700331531, 0.14484603074379265, 1.9501688797026873, 55.88016249239445, 55.979675352573395, 52.12628312408924, 30.135073363780975, 32.4660886824131, 35.1154775172472, 24.435172118246555, 58.359126672148705, 61.43499322235584, 60.74444107711315, 54.01719845831394, 61.50130346417427, 37.68886283040047, 0.2883847535122186, 0.12125682973419316, 0.9137582243420184, 0.16322325478540733, 0.1303690450731665, 0.9258785645943135, 28.41795690357685, 50.31495451927185, 58.54962944984436, 61.69951222836971, 63.599562272429466, 61.20089918375015, 57.317268177866936, 49.74261783063412, 52.25248955190182, 53.40100832283497, 56.256722286343575, 56.53074078261852, 57.96402767300606, 55.90380862355232, 57.64199875295162, 52.445515394210815, 57.366676926612854, 55.17914950847626, 59.032982513308525, 56.31552413105965, 45.169939398765564, 57.65057489275932, 57.03943848609924, 54.703757017850876, 55.68568892776966, 54.115172401070595, 48.82861107587814, 50.291452780365944, 52.880740240216255, 45.29869928956032, 53.15242186188698, 49.945933520793915, 49.5971654355526, 51.561059653759, 50.413384437561035, 49.42318797111511, 47.599118649959564, 47.74310052394867, 43.22994589805603, 45.06330192089081, 45.29521867632866, 38.6030937731266, 36.279503256082535, 31.10392067581415, 29.54149581491947, 36.61472886800766, 41.98018155992031, 45.034469068050385, 43.248078525066376, 37.56572663784027, 43.98852959275246, 42.94871158897877, 43.21536608040333, 41.96914315223694, 44.17018264532089, 45.96968628466129, 44.90807265043259, 50.463777333498, 43.20204019546509, 37.51071318984032, 40.01787185668945, 48.76686818897724, 43.839448392391205, 49.12636309862137, 55.17726480960846, 51.507733315229416, 51.422101110219955, 46.835181042551994, 46.24856851994991, 45.588923916220665, 45.94440624117851, 44.773244485259056, 43.23996216058731, 41.35757356882095, 42.076236605644226, 40.434071123600006, 43.50465215742588, 38.368881940841675, 38.66708233952522, 36.08141988515854, 34.562785774469376, 38.48263643682003, 39.27493192255497, 43.58026050031185, 44.82416175305843, 46.999491825699806, 50.91524250805378, 52.95715793967247, 46.7503771930933, 44.40860465168953, 47.350038215518, 49.498781114816666, 49.154701977968216, 48.72021809220314, 51.11418463289738, 44.53570783138275, 49.82788525521755, 52.58435994386673, 54.38107073307037, 56.50886535644531, 54.48117636144161, 56.15399859845638, 49.692810103297234, 51.38468451797962, 47.106509283185005, 49.64111007750034, 55.90385042130947, 54.92072917521, 57.54426419734955, 55.984656885266304, 54.40117545425892, 63.663474842906, 48.19404512643814, 47.52641335129738, 63.02570566534996, 55.236575827002525, 52.972091138362885, 49.469933062791824, 52.1241020411253, 49.73837345838547, 59.68055136501789, 61.89910791814327, 59.04782451689243, 69.98789727687836, 63.81854072213173, 3.690608013421297, 0.0889264426950831, 2.290812050923705, 0.256278109154664, 0.8594008348882198, 60.952666103839874, 47.45531536638737, 60.72300262749195, 62.28766366839409, 72.33987987041473, 38.66767130792141, 32.61930786073208, 52.301305532455444, 21.010792069137096, 40.001023560762405, 58.97758148610592, 28.137163370847702, 0.46947309107054025, 0.041735179256647825, 0.06760512624168769, 0.06470934022217989, 0.015418778493767604, 0.05052543980127666, 0.1427312957821414, 0.044375933648552746, 0.0454617142531788, 0.07202961773145944, 0.07784248940879479, 0.0662834057584405, 0.1275204893318005, 0.2392218486056663, 2.3222886119037867, 67.92933493852615, 63.77346754074097, 52.678313702344894, 33.96874465048313, 42.806276232004166, 37.96152479946613, 25.747217014431953, 67.23999872803688, 67.02502906322479, 69.12225052714348, 60.09257085621357, 67.46135205030441, 42.51568302512169, 0.2577938715694472, 0.3654468449531123, 2.1123919123783708, 0.2515045856125653, 0.1492835840326734, 0.6753625196870416, 35.361837297677994, 53.02427373826504, 59.987863674759865, 65.68511456251144, 64.06241163611412, 62.46633008122444, 60.28626166284084, 52.90708042681217, 53.47168453037739, 55.34127540886402, 58.901216983795166, 59.21995148062706, 58.75573419034481, 58.63414451479912, 59.5275753736496, 54.408444464206696, 59.70526523888111, 57.893347665667534, 55.47206439077854, 54.66606684029102, 49.624862149357796, 60.482627525925636, 61.33643791079521, 57.1290984749794, 57.095143496990204, 56.79242514073849, 49.66640152037144, 51.329522877931595, 55.16054950654507, 49.22426484525204, 55.49576751887798, 51.500118523836136, 51.55912555754185, 55.29850110411644, 54.450667798519135, 52.74342700839043, 51.03996701538563, 50.47870293259621, 45.50093583762646, 48.6657290160656, 48.28080967068672, 43.29134300351143, 41.10187008976936, 37.50098191201687, 33.800554275512695, 41.088133826851845, 45.45862890779972, 46.852736100554466, 44.91070970892906, 40.4886057972908, 46.40550769865513, 44.59906183183193, 43.418286591768265, 45.49078658223152, 45.305592119693756, 48.320034965872765, 46.692190915346146, 51.58340245485306, 43.9832478761673, 37.09169827401638, 40.19847236573696, 48.7719789147377, 43.845288679003716, 49.014223515987396, 57.512585297226906, 53.42331312596798, 53.176216185092926, 49.09233972430229, 48.95070232450962, 49.17486749589443, 47.362452149391174, 46.60745166242123, 45.55129073560238, 43.191172778606415, 43.10160018503666, 41.98686920106411, 44.960551634430885, 45.70442631840706, 42.962523847818375, 39.45433929562569, 39.79374088346958, 44.00063194334507, 42.50353507697582, 48.10349218547344, 49.48798589408398, 50.77495023608208, 53.19294288754463, 53.61958399415016, 50.978368520736694, 48.206079080700874, 50.67851901054382, 52.70522765815258, 52.78014063835144, 51.31808169186115, 55.18546096980572, 48.42914991080761, 54.25757735967636, 57.0736176520586, 57.229603081941605, 57.97312058508396, 57.630014196038246, 59.872862845659256, 49.387595281004906, 50.26660591363907, 49.64973941445351, 55.764815881848335, 58.33609990775585, 58.90842519700527, 60.208392441272736, 61.18560880422592, 50.45981414616108, 63.30080330371857, 55.98321296274662, 48.77845376729965, 65.61190009117126, 56.67762190103531, 56.548166647553444, 51.88713155686855, 58.15500542521477, 50.807294100522995, 64.30917799472809, 66.08618304133415, 63.14329795539379, 70.04662692546844, 72.1747787296772, 4.701131964102387, 0.01951124424522277, 3.1126958364620805, 0.14581260387785733, 1.0335295787081122, 68.46800923347473, 54.316193014383316, 63.080916702747345, 68.35441052913666, 80.50995826721191, 44.49858762323856, 34.87004868686199, 61.61308206617832, 25.128784999251366, 45.71613349020481, 71.15196481347084, 32.67500527203083, 0.65543157979846, 0.020157747640041634, 0.03135874132567551, 0.04063678585225716, 0.014254445268306881, 0.01682715770584764, 0.21964374056551605, 0.1662356173619628, 0.2429483798914589, 0.2036008529830724, 0.3093581140274182, 0.15189178782748058, 0.32361420686356723, 0.2529419178608805, 2.5461638113483787, 81.56677275896072, 74.07657667994499, 70.6505361199379, 38.00018772482872, 52.04027093946934, 46.86918921768665, 33.06896813213825, 72.18315348029137, 74.12715956568718, 72.9713223874569, 65.91689452528954, 73.01067307591438, 47.68816687166691, 0.6417527294252068, 0.6265752750914544, 3.2516204193234444, 0.866691218689084, 0.19462163792923093, 1.3321442739106715, 35.26401914656162, 52.693930864334106, 59.235340654850006, 68.24410244822502, 67.19786658883095, 66.0964272916317, 60.15565127134323, 53.05609703063965, 57.05326594412327, 58.584029003977776, 61.53172843158245, 62.518144100904465, 61.57948046922684, 60.20847223699093, 63.10343809425831, 58.00424091517925, 63.91567870974541, 61.395900920033455, 54.65658634901047, 58.375180810689926, 54.937892854213715, 63.76066982746124, 63.910883367061615, 58.81510220468044, 59.86592061817646, 60.35320267081261, 52.7998311817646, 52.86190465092659, 58.149336129426956, 51.3772065192461, 59.57978457212448, 55.44601298868656, 56.00815102458, 60.115438029170036, 59.20442931354046, 58.412737995386124, 54.670501202344894, 54.37446668744087, 48.78667652606964, 53.286003693938255, 52.43532054126263, 48.67172509431839, 48.64831455051899, 43.68812531232834, 40.704213827848434, 48.05164396762848, 49.39531646668911, 49.75334085524082, 47.29540474712849, 42.65820577740669, 48.924080953001976, 46.82627812027931, 46.77364334464073, 47.000468373298645, 50.067409202456474, 49.89651337265968, 51.09943002462387, 54.77839261293411, 43.49381893873215, 36.034477204084396, 40.86851321160793, 48.27826760709286, 41.99082478880882, 49.081392511725426, 58.549564853310585, 53.06929752230644, 53.99789169430733, 51.248796209692955, 53.34378719329834, 51.30735486745834, 52.04823151230812, 46.26239597797394, 47.44900770485401, 45.484459921717644, 45.594900995492935, 46.70473404228687, 48.4848815202713, 48.434899002313614, 48.289841786026955, 42.746969014406204, 46.63149677217007, 48.004640489816666, 47.16330483555794, 53.0648023635149, 55.157255083322525, 55.441514030098915, 58.4631384909153, 58.97386908531189, 55.48247963190079, 50.970343351364136, 52.51763932406902, 55.16928143799305, 57.47322700917721, 54.840796664357185, 58.14063839614391, 48.82372073829174, 56.12798519432545, 58.20831276476383, 60.79817779362202, 60.9576590359211, 60.28949148952961, 62.75806322693825, 51.97811007499695, 52.826125770807266, 52.54760831594467, 57.0327964425087, 61.05551518499851, 60.84930785000324, 63.381039798259735, 62.68455237150192, 54.7960464656353, 61.81847244501114, 49.12597171962261, 53.132446333765984, 69.79323372244835, 64.16063636541367, 60.029186457395554, 53.79166916012764, 59.83630120754242, 56.65419615805149, 67.14425906538963, 67.45185256004333, 68.88324335217476, 71.2256808578968, 65.34286692738533, 6.920251837000251, 0.18252715410199016, 5.179557641968131, 0.258339557913132, 0.990120826754719, 72.98232659697533, 60.8402681350708, 69.29280057549477, 73.13971415162086, 86.04732513427734, 53.365119248628616, 47.24556282162666, 75.47126904129982, 27.753372564911842, 55.52238889038563, 78.57415214180946, 46.19836561381817, 0.975058019394055, 0.1852550366311334, 0.1719907796359621, 0.12685570312896743, 0.15988949773600325, 0.10348614072427154], [0.16839108138810843, 0.04850808945775498, 0.0902748062799219, 0.0073748921568039805, 0.09824333494179882, 0.09673757667769678, 0.1390658729360439, 0.5047288758214563, 0.2902244485449046, 30.73268249630928, 63.487646877765656, 42.30689562857151, 31.98361337184906, 33.741805627942085, 37.061869874596596, 33.085375651717186, 54.059159606695175, 66.64156883955002, 63.02786394953728, 52.40693226456642, 56.37834616005421, 47.75961063802242, 0.38366671884432435, 0.2032524740207009, 2.023556004278362, 0.20155319332843646, 0.03920850038412027, 0.29938988329377025, 16.928429827094078, 55.053444653749466, 63.950287252664566, 59.70475226640701, 58.33197332918644, 55.50499342381954, 52.945602759718895, 50.59945285320282, 56.50987230241299, 54.82204467058182, 58.55898454785347, 58.24609413743019, 58.202252089977264, 56.971551328897476, 59.32891823351383, 56.33655220270157, 55.117619410157204, 56.757763400673866, 50.375318080186844, 41.5544980019331, 55.835758075118065, 58.585408329963684, 56.36153966188431, 50.51551915705204, 51.28187343478203, 47.1658430993557, 45.9766399115324, 50.06319522857666, 55.9198247641325, 45.64204126596451, 53.8118726760149, 50.58772288262844, 49.50958013534546, 50.017913058400154, 49.325768798589706, 49.5963104814291, 49.75086338818073, 50.62145747244358, 47.09714278578758, 40.61444364488125, 41.033724546432495, 40.409228056669235, 32.14641183614731, 21.36505275964737, 18.559393510222435, 25.88651943951845, 37.021101862192154, 46.32419966161251, 43.3136972039938, 42.39012636244297, 45.89509628713131, 46.44436441361904, 42.22360409796238, 45.01361958682537, 44.94323216378689, 50.872080624103546, 55.75471982359886, 51.063024178147316, 41.45114354789257, 43.241774663329124, 40.15995763242245, 41.49110600352287, 44.19406436383724, 43.19676607847214, 51.38300120830536, 46.89989157021046, 45.29183305799961, 48.759154602885246, 46.71152427792549, 45.54604321718216, 44.456029906868935, 46.01151444017887, 41.62948317825794, 43.88861395418644, 46.71365596354008, 40.28544209897518, 35.897874534130096, 33.36664795875549, 31.93014644086361, 31.97108544409275, 39.61798131465912, 41.20585151016712, 38.06626997888088, 40.57431399822235, 43.41095298528671, 44.80095639824867, 48.14269848167896, 49.294048100709915, 47.569028064608574, 47.182296216487885, 48.94794747233391, 49.513752311468124, 50.18601603806019, 46.50011882185936, 51.98145389556885, 42.75636211037636, 45.374509021639824, 46.651441901922226, 53.27291339635849, 53.532754853367805, 55.636238381266594, 55.44610418379307, 47.7338670194149, 45.60149364173412, 48.064958453178406, 54.75821189582348, 53.46840910613537, 54.99275051057339, 58.978649228811264, 54.879015013575554, 53.89726549386978, 53.91418598592281, 60.655537247657776, 47.24329434335232, 57.81207002699375, 58.904697597026825, 56.809205040335655, 52.259826958179474, 52.68016420304775, 52.74075575172901, 61.60583205521107, 60.572982877492905, 65.56782245635986, 45.69471783936024, 30.09299822151661, 4.765668651089072, 0.2816621126839891, 1.666639968752861, 0.06348962051561102, 4.541441733017564, 64.24338832497597, 50.36898382008076, 67.41464495658875, 60.324723199009895, 57.38604448735714, 20.88998895138502, 55.646889209747314, 40.34295201301575, 44.05361630022526, 41.769133284687996, 57.69548088312149, 12.758532632142305, 1.2734059570357203, 0.10627328374539502, 0.18281777913216501, 0.04944992680975702, 0.02472456450050231, 0.04408204687933903, 0.12180996724055149, 0.048834812550921924, 0.10061664899694733, 0.017564236513862852, 0.08772103159571998, 0.040366636676480994, 0.10193034686380997, 0.3913268999895081, 0.3279067890252918, 38.554011806845665, 74.38381299376488, 46.35452203452587, 35.426281839609146, 43.399792984128, 42.43392661213875, 36.23271256685257, 59.68558229506016, 70.41689425706863, 68.60374554991722, 58.196111619472504, 63.73667411506176, 50.20707070827484, 0.7376370811834931, 0.22265999199589714, 2.714215968735516, 0.2994271391071379, 0.11805983565864153, 0.24305887083755806, 20.722630731761456, 59.417559877038, 62.872163504362106, 62.779129296541214, 61.48779898881912, 60.376096442341805, 55.44842965900898, 53.381857350468636, 58.17369282245636, 58.677310198545456, 60.14787308871746, 60.72242125868797, 60.84906846284866, 58.53475704789162, 61.333515867590904, 59.30488832294941, 58.18229176104069, 56.505506336688995, 52.10793770849705, 47.94640101492405, 56.59509412944317, 60.80319732427597, 57.789442241191864, 53.921853974461555, 50.28598107397556, 48.76221343874931, 47.801203206181526, 52.46109075844288, 58.14175933599472, 48.4216795116663, 55.34470662474632, 54.58899937570095, 53.076460137963295, 54.33445103466511, 51.54565908014774, 54.213271737098694, 52.46774040162563, 53.489338383078575, 48.14377382397652, 44.04058679938316, 46.372825652360916, 42.59091518819332, 36.57662071287632, 25.867887139320374, 25.3902280703187, 31.022743731737137, 42.76056468486786, 49.13735210895538, 45.78765705227852, 44.93429124355316, 46.25299148261547, 47.404230907559395, 45.264713913202286, 47.912294045090675, 48.66319455206394, 50.63393980264664, 55.76438270509243, 52.511107474565506, 44.33973714709282, 42.485109865665436, 38.792859390378, 41.7601315677166, 44.0770648419857, 41.84420585632324, 52.451397478580475, 49.618318900465965, 46.308700293302536, 50.200702250003815, 48.059049770236015, 45.70835530757904, 46.18416577577591, 48.78606475889683, 43.1945013999939, 46.204536482691765, 48.531524017453194, 42.429978623986244, 39.33146148920059, 37.99001947045326, 37.19605587422848, 36.23856045305729, 45.18307149410248, 45.7908146828413, 41.62217237055302, 44.75717514753342, 46.16474501788616, 47.493567913770676, 51.206477880477905, 52.54663556814194, 50.72632424533367, 51.18980437517166, 53.22864577174187, 51.9952167570591, 52.312351539731026, 48.76617282629013, 54.61077220737934, 46.46526329219341, 49.12513956427574, 48.875698149204254, 54.71366308629513, 54.597518518567085, 56.196731105446815, 58.7729624658823, 53.80581200122833, 46.29540100693703, 51.74060761928558, 55.631659626960754, 57.56475269794464, 55.58920070528984, 62.13467247784138, 58.30304928123951, 59.45590361952782, 52.89258800446987, 63.11268299818039, 53.01321253180504, 60.52433408796787, 63.91492635011673, 59.334150552749634, 55.23040495812893, 57.40486867725849, 55.802118480205536, 63.93324136734009, 62.72834122180939, 68.23948189616203, 51.357014402747154, 38.686164915561676, 4.776364602148533, 0.17061250749975443, 2.735973601229489, 0.05439146145363338, 6.136351050809026, 70.67058384418488, 55.22981218993664, 70.17473325133324, 69.99644681811333, 62.35688075423241, 25.399852953851223, 59.78460878133774, 52.46697664260864, 33.80547881126404, 45.61091333627701, 70.2528266608715, 16.784254163503647, 1.0334193846210837, 0.138712135667447, 0.22905801743036136, 0.053899120684945956, 0.007250814342114609, 0.02893756431149086, 0.33083292888477445, 0.1551808082149364, 0.20807073422474787, 0.15964442573022097, 0.11976900917943567, 0.22678318637190387, 0.24670609622262418, 0.9867618069984019, 0.31646877934690565, 49.04908664524555, 83.07891681790352, 61.43621675670147, 38.14039260149002, 50.63990168273449, 51.883943527936935, 39.876922219991684, 68.9053201675415, 74.87394869327545, 76.26942381262779, 63.4462670981884, 67.52018049359322, 55.67048594355583, 1.1554520926438272, 0.5345212365500629, 4.31869768537581, 0.44039429049007595, 0.12357929925201461, 0.4847919393796474, 21.47367373108864, 54.992089346051216, 63.618382662534714, 65.0397115945816, 64.39857959747314, 61.74673229455948, 56.63240812718868, 54.70428138971329, 61.04696564376354, 59.49621185660362, 63.82569193840027, 62.490223199129105, 63.93738314509392, 59.78280007839203, 64.66011196374893, 61.981012523174286, 60.169383734464645, 58.71153876185417, 56.86034269630909, 54.637195989489555, 59.459916204214096, 62.890144139528275, 60.685833021998405, 56.13613575696945, 54.09795932471752, 53.53874333202839, 49.53027382493019, 55.811971351504326, 61.94323115050793, 51.56390570104122, 61.081919968128204, 58.34702052175999, 57.858936712145805, 57.2541231662035, 56.156985238194466, 59.509830325841904, 54.19917069375515, 57.51559093594551, 52.329621613025665, 48.79063591361046, 51.557332053780556, 47.71662354469299, 45.18088661134243, 33.617293909192085, 32.726245522499084, 37.90049247443676, 46.41425862908363, 52.614454329013824, 48.19517366588116, 46.40947088599205, 49.393074586987495, 49.736177176237106, 46.560064405202866, 50.136774480342865, 49.93454933166504, 52.76006631553173, 60.11869825422764, 53.14145565032959, 45.05791760981083, 45.17686262726784, 41.765892058610916, 39.793501496315, 44.47161667048931, 41.83291666209698, 53.787728771567345, 51.645536720752716, 48.29676881432533, 52.224652245640755, 52.158117815852165, 48.201055750250816, 49.55646961927414, 50.4637735337019, 45.62328927218914, 48.09868544340134, 52.11804136633873, 46.008474603295326, 45.02948373556137, 42.85712510347366, 42.838004529476166, 41.90725587308407, 50.067899376153946, 51.55772723257542, 47.41979867219925, 49.932497441768646, 50.97711078822613, 49.939390271902084, 53.989581540226936, 54.754571691155434, 52.63404607772827, 51.799306869506836, 56.00324548780918, 57.68612198531628, 57.16346003115177, 51.806268095970154, 58.08688648045063, 46.07549160718918, 51.63144327700138, 51.51388518512249, 56.244331151247025, 58.73888969421387, 58.6600287258625, 60.990979447960854, 56.16998814046383, 52.59003683924675, 53.2291055470705, 61.244642436504364, 59.824970215559006, 58.41171585023403, 65.33644527196884, 61.730666756629944, 59.94305267930031, 56.30095571279526, 60.61528980731964, 46.68174147605896, 66.74235463142395, 64.9375806748867, 64.44766536355019, 56.16873800754547, 61.099912002682686, 56.25899836421013, 69.60692971944809, 67.06007838249207, 74.12492528557777, 50.214997082948685, 40.80542899668217, 8.560877926647663, 0.3851909120567143, 3.3214514097198844, 0.11151066442835145, 6.370095033198595, 75.826435983181, 60.00225730240345, 77.6254266500473, 76.21128693223, 73.29870522022247, 33.76785323023796, 68.17760601639748, 60.53212746977806, 56.83104246854782, 62.06716910004616, 79.96281802654266, 27.329064533114433, 1.6367659717798233, 0.3030679968651384, 0.2673296973807737, 0.24964464479126036, 0.16273342247586697, 0.18010684725595638], [0.08328068041009828, 0.02315434699994512, 0.10681186031433754, 0.17451629333663732, 0.04725432372651994, 0.1596274899202399, 0.1452357621747069, 0.5514194641727954, 0.4502570768818259, 16.256658174097538, 60.48025265336037, 47.43809849023819, 40.54763562977314, 40.68591021001339, 29.990177638828754, 35.57370252907276, 67.97777473926544, 61.995520144701004, 65.51242142915726, 62.98349753022194, 53.083079382777214, 57.75513768196106, 3.8877834705635905, 0.4682238190434873, 1.1804991611279547, 0.07492646502214484, 0.20054014690686017, 0.17683678132016212, 8.76798391342163, 49.39901366829872, 66.5477442741394, 61.382540836930275, 59.916594699025154, 58.5799328237772, 56.64099186658859, 55.54614141583443, 57.27694854140282, 56.34588450193405, 60.283503010869026, 56.70601397752762, 57.16318264603615, 57.228402346372604, 57.509024888277054, 56.998374089598656, 55.7448061555624, 55.20385578274727, 47.33938738703728, 56.73133201897144, 59.66758266091347, 52.549325823783875, 53.821455761790276, 46.55082330107689, 48.4466365724802, 50.02962023019791, 49.67131085693836, 46.426205188035965, 52.29872167110443, 46.92297153174877, 49.76522661745548, 50.92359445989132, 49.56957131624222, 47.577877789735794, 50.2547125518322, 49.107785895466805, 54.061021506786346, 49.85835202038288, 51.2691593170166, 48.64275544881821, 42.80178487300873, 38.930943980813026, 35.522519275546074, 24.098529182374477, 23.6012726649642, 24.56260208040476, 34.69553165137768, 39.002965316176414, 43.2314620167017, 39.50841799378395, 42.172561436891556, 44.22389276325703, 44.40400689840317, 42.79671594500542, 45.871955528855324, 59.2254763841629, 57.99535699188709, 44.77665290236473, 43.95421363413334, 40.8141153305769, 43.632040321826935, 47.8183326870203, 45.28575338423252, 42.585036903619766, 41.16322919726372, 54.492412358522415, 48.87194775044918, 47.66979865729809, 43.96487206220627, 45.4634128510952, 46.695568934082985, 44.58244912326336, 41.62126421928406, 44.71704550087452, 42.42520608007908, 37.17277072370052, 28.273963630199432, 24.286064319312572, 22.398230619728565, 25.77996175736189, 30.502219162881374, 35.6122362613678, 41.630429327487946, 40.15027575194836, 44.798505529761314, 47.855988666415215, 48.16208504140377, 48.832771852612495, 49.49329040944576, 51.361327171325684, 47.65715293586254, 51.77224472165108, 50.6980499625206, 48.11511196196079, 51.247553676366806, 44.603693783283234, 46.821950152516365, 46.05117291212082, 49.361756667494774, 49.267859905958176, 53.435974046587944, 58.104418739676476, 57.96923719346523, 55.06210818886757, 53.70518200099468, 54.96836341917515, 55.51809512078762, 53.592369854450226, 58.404310047626495, 52.0115102827549, 57.751763463020325, 57.404272109270096, 59.20047752559185, 55.29016435146332, 53.8607494533062, 60.32482959330082, 57.34637841582298, 55.264496728777885, 55.332171097397804, 52.986009791493416, 58.93998630344868, 59.73335713148117, 68.67346420884132, 35.57101987302303, 20.336096473038197, 1.5677228453569114, 0.4100796359125525, 2.0991669595241547, 0.6329175503924489, 10.998992398381233, 56.919353529810905, 53.931148275732994, 64.80176836252213, 64.2904981970787, 47.241645231842995, 25.274889059364796, 61.00449152290821, 39.68130111694336, 39.47048842906952, 40.22805377840996, 50.277895107865334, 5.160548686981201, 0.8895913430023938, 0.10998869765899144, 0.1587916980497539, 0.05761432308645453, 0.03245159088692162, 0.1734476600540802, 0.04901772226730827, 0.12323547707637772, 0.036599023806047626, 0.14124297798844054, 0.016411029937444255, 0.162042987649329, 0.09548411151627079, 0.6610078399535269, 0.44837127963546664, 20.14469124376774, 69.87163111567497, 53.94835375249386, 34.59831386804581, 44.39825780689716, 35.18046922981739, 38.79394993185997, 78.03219482302666, 66.32465824484825, 73.62399816513062, 65.46008303761482, 57.938557639718056, 64.07256469130516, 5.13326995074749, 0.3117451578145847, 1.878759074024856, 0.04705280465714168, 0.41354543587658554, 0.131723138038069, 9.456045292317867, 58.71369704604149, 66.32354110479355, 61.00546807050705, 62.33744479715824, 59.960467144846916, 59.77139309048653, 57.920318618416786, 60.96271276473999, 57.66062915325165, 61.5978828817606, 58.11865657567978, 61.22755095362663, 58.943611308932304, 59.59533333778381, 58.008606880903244, 57.86855399608612, 57.7390493452549, 52.18028582632542, 61.47499367594719, 59.1069645434618, 53.10857981443405, 55.89001156389713, 49.30627204477787, 51.246265545487404, 52.54963740706444, 52.133867517113686, 48.09583559632301, 55.869724452495575, 47.96547219157219, 52.57015250623226, 53.483566492795944, 53.268509432673454, 52.46387220919132, 52.867919728159904, 53.52833949029446, 53.888316974043846, 54.43737991154194, 54.2458625882864, 50.59067912399769, 46.50473177433014, 42.40660987794399, 39.89012271165848, 29.606565423309803, 26.467491164803505, 30.424838215112686, 40.39703071117401, 43.010245487093925, 45.45674420893192, 40.543634444475174, 44.57324981689453, 45.46155855059624, 46.72988869249821, 45.84594212472439, 48.12452785670757, 60.43392553925514, 57.10779681801796, 45.54075390100479, 46.37265846133232, 43.145605623722076, 47.219127640128136, 46.82269871234894, 46.55266620218754, 43.86464864015579, 43.1638940423727, 54.59960080683231, 50.25739520788193, 47.283450588583946, 47.00457215309143, 45.91731369495392, 46.76790565252304, 47.341572269797325, 44.308236837387085, 46.4827461540699, 44.785403832793236, 39.52318400144577, 33.65255981683731, 29.664721302688122, 29.439459890127182, 32.887296080589294, 36.10217437148094, 40.681335255503654, 45.598750188946724, 44.84552800655365, 49.2853769659996, 50.6417141854763, 52.09578976035118, 52.698688209056854, 50.466551184654236, 53.92997793853283, 51.99518255889416, 53.66214171051979, 51.914239302277565, 51.06912285089493, 54.82017517089844, 47.60196469724178, 49.03589755296707, 49.874014779925346, 53.48220996558666, 53.081502467393875, 56.23755991458893, 59.05948229134083, 60.83565138280392, 58.362025916576385, 57.03183129429817, 57.9758108407259, 57.491515427827835, 56.74873128533363, 60.1679702103138, 54.666462019085884, 58.16315218806267, 61.85578264296055, 59.20747675001621, 59.72504697740078, 57.96156920492649, 61.90855421125889, 61.31575182080269, 59.66333068907261, 58.36568892002106, 57.09247224032879, 64.05855104327202, 63.22050221264362, 71.87505081295967, 44.345436841249466, 25.632651261985302, 2.1552317636087537, 0.588024384342134, 3.284225994721055, 0.6778037105686963, 12.266809567809105, 64.53018173575401, 57.09281802177429, 72.18363985419273, 72.44603857398033, 52.42102190852165, 30.60697004199028, 66.29713252186775, 49.12269629538059, 39.47630971670151, 47.425042390823364, 64.1608339548111, 8.666836190968752, 0.7031417009420693, 0.024566891515860334, 0.09706732773338445, 0.06632292512222193, 0.0631121419428382, 0.1496993500040844, 0.2443364038481377, 0.18647221819264814, 0.17100957134971395, 0.23434715549228713, 0.14364139147801325, 0.29672661214135587, 0.27474488073494285, 0.9125264373142272, 0.7486884912941605, 25.013791769742966, 83.70044946670532, 67.08714812994003, 57.00897552073002, 57.03467354178429, 47.613713666796684, 44.25818972289562, 84.35425758361816, 72.1423588693142, 79.03509020805359, 70.91935649514198, 66.43734499812126, 68.83032739162445, 6.617419486865401, 0.6302191608119756, 3.0506188049912453, 0.5047325568739325, 0.8638090139720589, 0.25435478892177343, 12.652745358645916, 55.58765798807144, 63.24415594339371, 64.0270583331585, 64.15225401520729, 63.16229693591595, 61.17328606545925, 61.44767314195633, 64.56494987010956, 59.80314038693905, 66.37125134468079, 61.99055381119251, 62.20046974718571, 60.38061439990997, 61.73281744122505, 60.656179413199425, 60.05518466234207, 61.17350645363331, 55.489174872636795, 61.382077261805534, 61.06849528849125, 56.548717617988586, 60.9370831400156, 50.465255454182625, 52.67036832869053, 55.44670835137367, 56.14189624786377, 50.877662524580956, 58.29272523522377, 50.97019135951996, 56.035346165299416, 55.187809243798256, 56.645726412534714, 56.78615927696228, 56.976703852415085, 57.364362850785255, 58.854627683758736, 56.181543320417404, 59.35900121927261, 54.87428806722164, 49.52932387590408, 45.59432342648506, 46.64761170744896, 36.21467873454094, 36.25222831964493, 37.265546545386314, 45.765040665864944, 46.58999539911747, 49.78323005139828, 44.70023140311241, 48.12090665102005, 46.84294782578945, 50.22385820746422, 49.184165596961975, 51.30553096532822, 62.4905613809824, 58.626715913414955, 47.41407997906208, 48.911233842372894, 44.64693546295166, 47.90486924350262, 49.28071081638336, 49.1780099272728, 44.64448839426041, 42.41713531315327, 55.7930863648653, 53.5266637802124, 50.844193920493126, 49.35292214155197, 48.28140243887901, 50.669065117836, 48.28614078462124, 43.90505567193031, 49.35353770852089, 49.37749162316322, 43.910751566290855, 39.074542075395584, 35.12713149189949, 37.35374741256237, 38.88384930789471, 41.85753174126148, 46.95074424147606, 49.988749623298645, 48.51877570152283, 51.67886093258858, 55.26264622807503, 55.503306314349174, 57.44390018284321, 54.68719370663166, 55.795548632740974, 56.88996970653534, 56.720305010676384, 54.68567758798599, 52.54494845867157, 59.09542076289654, 48.38457450270653, 50.533720180392265, 51.44615761935711, 55.34272313117981, 54.73750680685043, 58.694451078772545, 60.28817296028137, 65.6858441233635, 59.51993018388748, 59.619534239172935, 60.83034686744213, 61.38636723160744, 59.138415455818176, 66.42010152339935, 57.46106006205082, 62.30277165770531, 62.75736026465893, 61.4916405826807, 56.057058200240135, 58.26101593673229, 66.45408689975739, 61.70763619244099, 60.35691887140274, 62.231407687067986, 59.81699824333191, 64.68181639909744, 65.41054889559746, 74.77787464857101, 38.73003736138344, 29.38698660582304, 4.38714056275785, 0.6339590507559478, 4.633319852873683, 0.7013209455180913, 13.434513509273529, 71.99198573827744, 62.68088936805725, 76.5827701985836, 78.08186575770378, 59.88703988492489, 34.87193338572979, 77.76304006576538, 58.06603319942951, 54.21217739582062, 59.05700862407684, 79.16822746396065, 17.210729978978634, 1.4962454745545983, 0.19080640515312552, 0.2626777969999239, 0.2515533595578745, 0.21973744413116947, 0.2706294640665874], [0.15315496770199388, 0.057127696854877286, 0.004413032729644328, 0.19657787983305752, 0.06323071487713605, 0.11680944298859686, 0.11765955830924213, 0.28636192611884326, 0.18517978285672143, 5.445495871827006, 60.66562570631504, 49.44000206887722, 51.04203410446644, 37.10425280034542, 34.516941234469414, 25.147411599755287, 55.89038774371147, 67.59692877531052, 62.658519968390465, 62.50307410955429, 51.81348770856857, 62.39075593650341, 8.50997680798173, 0.5490254738833755, 1.1615097988396883, 0.1404067111434415, 0.4337595496326685, 0.10722816805355251, 7.012988710775971, 41.599172204732895, 62.111482322216034, 71.74594134092331, 57.67403483390808, 59.33247484266758, 59.67831328511238, 59.60911899805069, 61.581399366259575, 60.482730120420456, 57.22624406218529, 57.02326275408268, 57.16960810124874, 57.87404090166092, 55.38719594478607, 54.949710220098495, 54.57432456314564, 54.64914254844189, 61.356413438916206, 55.678678303956985, 55.65584912896156, 56.39351114630699, 55.196905955672264, 54.41130191087723, 57.58962996304035, 55.622331127524376, 53.99677075445652, 50.344748720526695, 52.69141919910908, 49.3657236546278, 47.459533140063286, 51.44300378859043, 50.29336407780647, 51.5144969522953, 49.54559080302715, 50.056921765208244, 50.209791362285614, 50.90764291584492, 51.91944122314453, 46.3826709240675, 45.76949402689934, 42.94155657291412, 38.30362804234028, 39.36751015484333, 34.19916808605194, 27.10909243673086, 30.781445279717445, 39.6138509362936, 42.681962102651596, 42.226035967469215, 42.534321025013924, 43.42447265982628, 44.41470332443714, 44.374995455145836, 50.19045799970627, 59.480134919285774, 57.82486014068127, 56.78674444556236, 46.76148019731045, 42.50181756913662, 46.99100308120251, 46.3393684476614, 42.53854259848595, 45.86237244307995, 44.794690534472466, 52.177154794335365, 62.302520871162415, 51.302126348018646, 46.93758174777031, 44.784510880708694, 46.132366955280304, 46.24506890773773, 43.23668673634529, 42.43310585618019, 40.579941496253014, 33.58001410961151, 20.24031311273575, 11.489467229694128, 11.406393237411976, 12.205220572650433, 20.859337896108627, 38.74744422733784, 40.92665769159794, 43.07819724082947, 45.77233627438545, 48.49255330860615, 51.036304011940956, 47.841161862015724, 47.61962614953518, 49.504560604691505, 45.89545726776123, 52.67661139369011, 45.83845652639866, 49.29207220673561, 46.76060624420643, 46.120344400405884, 47.609932869672775, 51.659580767154694, 54.01532515883446, 60.604635179042816, 57.273551523685455, 58.8104322552681, 52.80298501253128, 55.21438121795654, 55.57014472782612, 53.132841512560844, 52.02400021255016, 52.35982999205589, 51.939314156770706, 56.01138845086098, 56.75838656723499, 57.46529683470726, 56.2305872887373, 62.7581924200058, 55.39144031703472, 55.03045588731766, 59.88666370511055, 58.142861276865005, 55.81455521285534, 61.98967985808849, 56.27680040895939, 68.85061830282211, 60.1407066732645, 38.30723024904728, 29.733951687812805, 0.22934405598789454, 0.6503668078221381, 2.4991729203611612, 0.14721498097060248, 25.01794494688511, 60.21780073642731, 57.5504844635725, 61.55555695295334, 69.30481553077698, 40.03565490245819, 22.66247984021902, 67.14175879955292, 29.122608192265034, 37.17741787433624, 44.26047720015049, 41.82936005294323, 1.3300034450367093, 0.5753841251134872, 0.11835722165415064, 0.03413837752304971, 0.045542315201601014, 0.061013281519990414, 0.04951395188982133, 0.12705937813734636, 0.03324955177959055, 0.05449261989269871, 0.17228943470399827, 0.07541764061897993, 0.16849962790729478, 0.023844663082854822, 0.3975062590325251, 0.12723431718768552, 7.8411229234188795, 70.11927142739296, 61.08230374753475, 46.55620381236076, 45.92703357338905, 40.6406394392252, 24.414936304092407, 67.40508466959, 69.52851712703705, 70.85525393486023, 67.888213545084, 57.49195620417595, 66.58740654587746, 9.991893488913774, 0.5373343918472528, 1.661218253429979, 0.480955540551804, 1.9754664972424507, 0.10050693730590865, 7.991609573364258, 44.96859960258007, 71.78110465407372, 66.61468908190727, 60.45723728835583, 63.28037939965725, 62.6252755522728, 60.75079433619976, 63.51162739098072, 61.55065141618252, 60.09228967130184, 58.30702006816864, 58.406240344047546, 60.98295047879219, 58.12633216381073, 57.12776094675064, 57.21349194645882, 58.771199360489845, 64.23956573009491, 57.59412132203579, 57.69085273146629, 57.34065592288971, 58.91943700611591, 56.41095221042633, 60.49724914133549, 56.28850378096104, 57.33842924237251, 53.36551442742348, 53.77778850495815, 50.08823208510876, 49.7847955673933, 54.276488944888115, 56.36678718030453, 54.358743131160736, 54.09670539200306, 52.69135840237141, 54.991052001714706, 54.425611943006516, 56.688268929719925, 50.0885246694088, 48.58746841549873, 46.40518091619015, 44.16563808917999, 42.549645602703094, 39.122468903660774, 31.32315371185541, 35.88116303086281, 41.95085473358631, 44.610639810562134, 43.800010308623314, 44.63526248931885, 45.821140855550766, 47.631010338664055, 45.151305198669434, 52.71052457392216, 61.14035703241825, 56.55562944710255, 57.159888222813606, 48.433857858181, 42.62591511011124, 48.20047818124294, 48.71971271932125, 43.7491500377655, 45.51971822977066, 43.46777893602848, 52.979998514056206, 64.07248869538307, 52.71709822118282, 48.90740744769573, 46.92802906036377, 47.93862663209438, 48.64735700190067, 44.4317340105772, 43.9893389493227, 45.49326404929161, 38.08631770312786, 24.513430818915367, 15.027180947363377, 14.941797628998756, 17.414419949054718, 24.51981257647276, 39.79553058743477, 45.03965958952904, 47.6801872998476, 49.41193297505379, 51.28521725535393, 54.697574749588966, 51.0688416659832, 50.26480861008167, 53.80477465689182, 52.37588033080101, 55.07849670946598, 48.6815969645977, 52.649594843387604, 50.294576212763786, 49.44894298911095, 52.23756015300751, 54.28595423698425, 56.66897356510162, 62.239459455013275, 58.86141411960125, 60.37693239748478, 55.034681260585785, 57.15033933520317, 59.74810414016247, 55.58049917221069, 52.06018187105656, 55.123881474137306, 54.40114505589008, 56.56883753836155, 58.41076210141182, 62.52143852412701, 58.94397608935833, 63.63171614706516, 59.13515143096447, 56.76318570971489, 62.02220991253853, 63.36542643606663, 59.33526769280434, 63.15500132739544, 60.75732618570328, 68.40582937002182, 66.78108215332031, 41.965229362249374, 32.159160152077675, 0.2006857265951112, 2.0369818713515997, 2.430927869863808, 0.25200618838425726, 27.65804138034582, 66.4818862080574, 62.27587290108204, 69.37285467982292, 77.02963382005692, 45.000768676400185, 25.974726006388664, 71.88932284712791, 40.150693729519844, 36.00133918225765, 48.663582131266594, 54.33636613190174, 2.269477383233607, 0.41240926715545356, 0.06867998614325188, 0.04598520295985509, 0.04909312818199396, 0.04016796374344267, 0.07271977796335705, 0.32665787322912365, 0.1318048039684072, 0.2137322968337685, 0.2850984048563987, 0.09861630867817439, 0.2516466623637825, 0.2331503978348337, 0.6351461308076978, 0.37544090242590755, 10.154364220798016, 87.62012913823128, 69.94927614927292, 69.56916734576225, 51.875754967331886, 51.76964946091175, 32.36749157309532, 71.50957122445107, 75.12337490916252, 76.97987169027328, 72.25550159811974, 62.90080636739731, 72.50959396362305, 11.921056620776653, 0.5533266649581492, 2.471047304570675, 0.7813710719347, 3.014866285957396, 0.18861024174839258, 9.133017025887966, 49.02757219970226, 68.70455414056778, 63.99581640958786, 61.13644704222679, 67.43323355913162, 67.95232370495796, 61.631503477692604, 66.66929975152016, 63.74076269567013, 61.25233702361584, 60.293397679924965, 61.54538109898567, 64.1951385140419, 60.93118205666542, 60.04039965569973, 59.75432060658932, 58.51497530937195, 63.468385711312294, 61.16383217275143, 60.99222578108311, 60.22921912372112, 60.88092215359211, 61.174441203475, 61.61437399685383, 60.914356559515, 59.69512738287449, 54.152714386582375, 57.88730598986149, 52.957686111330986, 53.601219579577446, 57.87648417055607, 59.655035734176636, 58.62065903842449, 58.40967535972595, 57.38184571266174, 59.38979096710682, 57.123691365122795, 59.410898834466934, 51.484596356749535, 52.2291512042284, 52.410108894109726, 48.99317264556885, 49.03625853359699, 44.51785258948803, 40.16045540571213, 41.881090477108955, 47.05375671386719, 47.74414926767349, 47.03962527215481, 44.746463522315025, 46.97119474411011, 50.77785708010197, 48.83043497800827, 55.30495695769787, 64.44078013300896, 60.08098907768726, 59.12818640470505, 53.123357221484184, 46.17227241396904, 50.129228085279465, 49.7860798984766, 47.535350471735, 49.09080080688, 45.05312606692314, 53.76157857477665, 66.50276228785515, 54.637708961963654, 52.58517690002918, 48.36930312216282, 51.061720848083496, 52.01402574777603, 47.88980685174465, 47.152464017271996, 51.29760079085827, 43.44556912779808, 30.93136813491583, 22.175866551697254, 20.887891463935375, 24.217599593102932, 33.029868230223656, 45.82628957927227, 49.74760316312313, 50.096033066511154, 53.2252449542284, 54.81531523168087, 59.85724188387394, 53.45742009580135, 52.899005860090256, 58.45822535455227, 54.39221553504467, 57.213560342788696, 51.629208996891975, 54.87475164234638, 52.7724726498127, 51.07416518032551, 55.14146313071251, 56.02414436638355, 58.859350830316544, 67.04298689961433, 62.45105490088463, 63.951290398836136, 57.623410150408745, 59.58115629851818, 62.504689022898674, 58.02267372608185, 55.475822389125824, 55.56110121309757, 58.239493891596794, 60.6857418268919, 60.21194905042648, 64.1675291955471, 62.89499267935753, 62.97918476164341, 58.67270864546299, 60.67106321454048, 65.1857453584671, 66.70910641551018, 62.654438987374306, 64.51221629977226, 64.79446515440941, 70.41243329644203, 62.512622997164726, 42.39377036690712, 40.973038002848625, 0.4905877268174663, 3.89208460226655, 3.8462820975109935, 0.25803901778999716, 30.683843716979027, 76.01724654436111, 67.63254806399345, 76.93362057209015, 83.0627828836441, 52.73429609835148, 32.64774553477764, 87.04100221395493, 46.70487083494663, 49.42990981042385, 62.75371626019478, 74.04890656471252, 7.549416376277804, 0.657498431392014, 0.19806796393822879, 0.10969173468765803, 0.17534778075059876, 0.1155769063916523, 0.1330162858357653], [0.08383707594475709, 0.15760736394440755, 0.05468061332067009, 0.22244779713219032, 0.025533216030453332, 0.10928998788585886, 0.08977045014034957, 0.2433698603999801, 0.09281672886572778, 2.890552869066596, 49.342206716537476, 60.23713789880276, 35.93645766377449, 39.499169290065765, 36.16673290729523, 18.89418214559555, 52.84782260656357, 64.51844796538353, 61.538256481289864, 64.7353707253933, 53.565220311284065, 62.26840630173683, 16.025218293070793, 0.8230606536380947, 1.1210109782405198, 0.14032753882929683, 0.5378435645252466, 0.5962955905124545, 2.4115025997161865, 49.63520519435406, 44.073747619986534, 65.31012788414955, 75.37622854113579, 67.74915620684624, 61.68117821216583, 57.31128349900246, 57.764078602194786, 57.013447880744934, 58.27958934009075, 58.532062992453575, 59.211732521653175, 55.66699393093586, 55.560675635933876, 53.38087700307369, 57.05076187849045, 57.63181149959564, 52.44165100157261, 56.69198893010616, 58.058403208851814, 56.862386986613274, 57.01469801366329, 60.516704097390175, 59.70312215387821, 57.50351898372173, 57.127027586102486, 52.17360578477383, 50.197924599051476, 50.46841688454151, 46.89642235636711, 54.11999434232712, 49.45341154932976, 50.256741642951965, 51.23531833291054, 48.86271044611931, 50.42916879057884, 52.63830944895744, 48.176478669047356, 50.952111929655075, 44.58616532385349, 40.03421097993851, 35.02374283969402, 34.6246312558651, 31.920570954680443, 26.98291450738907, 34.882382825016975, 38.66121545433998, 42.92689695954323, 42.72167757153511, 42.004709243774414, 41.301526576280594, 42.6127640157938, 43.806743547320366, 51.951644495129585, 63.42055007815361, 57.75163806974888, 55.60071788728237, 59.80718336999416, 49.45686176419258, 48.479413613677025, 47.8955065459013, 44.73830536007881, 47.19052277505398, 52.198574244976044, 56.58333756029606, 56.08793914318085, 61.27323590219021, 48.85219641029835, 44.27616275846958, 43.06520953774452, 44.86373282968998, 43.04046146571636, 40.88888771831989, 37.26423941552639, 26.995020657777786, 17.5663984939456, 12.727457899600267, 12.029574047774076, 21.342487670481205, 31.18823055177927, 41.23846136033535, 41.96879357099533, 45.85277795791626, 46.97291985154152, 52.182067930698395, 49.62354362010956, 48.599551767110825, 48.396319672465324, 50.05630239844322, 48.021215200424194, 51.93052142858505, 45.9841825067997, 49.9863101541996, 46.93658620119095, 48.26250225305557, 52.79934100806713, 55.055526942014694, 53.2098937779665, 47.39661231637001, 47.44039736688137, 53.093293234705925, 57.07723505795002, 56.986412331461906, 53.203715309500694, 55.05711905658245, 46.35424084961414, 49.13407288491726, 48.450079187750816, 49.760974645614624, 55.669638589024544, 57.846974954009056, 55.902851074934006, 58.774208799004555, 62.58636184036732, 55.548352897167206, 57.45980612933636, 63.803736716508865, 56.915587931871414, 59.45156805217266, 68.954968303442, 77.2551441192627, 41.756742149591446, 59.429320245981216, 21.26387558877468, 0.36392796551808715, 0.9273230808321387, 0.4078312253113836, 0.19606199814006686, 34.46328431367874, 63.410503417253494, 52.8872986882925, 55.9886010736227, 68.7423849105835, 32.29288637638092, 40.714290887117386, 61.90063163638115, 31.15454725921154, 38.97106982767582, 39.20688897371292, 28.292402140796185, 0.33705779642332345, 0.10758132644696161, 0.13490012381225824, 0.08646905815112405, 0.14327959448564798, 0.008981978626252385, 0.0689162414346356, 0.09228395589161664, 0.07648743165191263, 0.07223172680824064, 0.09310633715358563, 0.04630061943316832, 0.10062218541861512, 0.051302123320056126, 0.4307850217446685, 0.07053735171211883, 3.2395510794594884, 61.1120979487896, 67.46418669819832, 41.41235902905464, 47.09346078336239, 45.095577389001846, 20.39478812366724, 62.118994519114494, 69.70364212989807, 69.53725665807724, 70.26651352643967, 58.32059293985367, 69.97483357787132, 18.521405048668385, 1.1215135012753308, 1.5103643294423819, 0.1789715839549899, 1.4574151206761599, 1.0150958178564906, 3.251655804924667, 49.493746384978294, 49.9471190571785, 71.78694114089012, 70.09258925914764, 64.95145753026009, 65.4810731112957, 60.99259816110134, 61.428066194057465, 60.295274779200554, 61.01958431303501, 62.672514617443085, 59.60378788411617, 59.09876078367233, 59.51137684285641, 55.799082443118095, 58.40082563459873, 58.98653380572796, 55.87416261434555, 58.17894794046879, 61.34276457130909, 57.137678414583206, 58.066147193312645, 61.43476143479347, 59.88762125372887, 58.86330261826515, 59.59124095737934, 53.49598042666912, 52.39669941365719, 51.99707105755806, 48.491667956113815, 56.362634003162384, 53.76722127199173, 54.335366785526276, 56.695309951901436, 51.594034284353256, 53.542539328336716, 56.98258973658085, 50.55642396211624, 53.51986214518547, 46.40363059937954, 45.936734452843666, 41.48482874035835, 39.67140644788742, 36.02108672261238, 32.56192333996296, 39.73522402346134, 44.033067002892494, 45.0767569988966, 42.47053764760494, 42.30665624141693, 43.69520053267479, 44.674765169620514, 47.09724918007851, 53.66539053618908, 62.5028271228075, 57.82324902713299, 54.81599539518356, 60.52676975727081, 50.622867196798325, 49.42174784839153, 48.37899260222912, 44.41900469362736, 46.583182364702225, 50.68194642663002, 55.48510529100895, 59.761023446917534, 62.050746381282806, 50.66065616905689, 46.67427867650986, 46.493571773171425, 46.04219779372215, 44.336484521627426, 42.04375594854355, 41.40954717993736, 33.0031518638134, 23.567027002573013, 16.02661281824112, 16.331432461738586, 26.723527126014233, 38.82995679974556, 44.646844267845154, 44.60130751132965, 50.14710992574692, 49.36685599386692, 52.64988362789154, 52.807472571730614, 52.07828029990196, 51.46027386188507, 52.75737226009369, 52.16779589653015, 52.52029538154602, 48.32491770386696, 51.28728814423084, 48.96664246916771, 50.537671968340874, 54.90971736609936, 54.202134534716606, 55.00147104263306, 50.08154824376106, 49.743225798010826, 54.170721620321274, 57.64445722103119, 58.66318255662918, 54.54159691929817, 55.72103463113308, 50.12299261987209, 50.747173726558685, 50.704141035676, 50.12618824839592, 56.244665533304214, 61.738334745168686, 58.39234448969364, 60.722071677446365, 65.42249545454979, 57.9873052239418, 58.324449732899666, 66.25224173069, 60.754666328430176, 62.68689304590225, 66.60569876432419, 80.4428842663765, 45.30317924916744, 63.837866485118866, 24.178224205970764, 0.2805315249133855, 2.1769326366484165, 0.9326669003348798, 0.1770567984203808, 37.67301768064499, 70.37472411990166, 59.49220307171345, 64.21279236674309, 73.43869730830193, 37.52566538751125, 45.48728697001934, 69.44316610693932, 38.19203943014145, 41.88488267362118, 48.35711717605591, 39.11491870880127, 0.656330706551671, 0.09028130749356933, 0.0962098354648333, 0.02613611453853082, 0.06639293933403678, 0.03062826206587488, 0.055088835360947996, 0.18640499445609748, 0.24566805426729843, 0.2558028674684465, 0.2706744085298851, 0.09329630469437689, 0.20491141156526282, 0.1557445287471637, 0.5265644635073841, 0.347068656119518, 3.8519946159794927, 70.85266247391701, 79.57903102040291, 49.881910756230354, 48.37173879146576, 54.66564126312733, 26.778137795627117, 69.68176290392876, 74.6478608250618, 77.03012779355049, 73.21757197380066, 65.12035846710205, 73.09591770172119, 22.360996417701244, 1.425759494304657, 3.3430739119648933, 0.4451590566895902, 1.8672556662932038, 0.810354194836691, 4.599750079214573, 53.42416428029537, 52.757436856627464, 71.87408566474915, 63.7967374920845, 62.24862456321716, 66.69541954994202, 65.45759797096252, 62.611356899142265, 62.18144416809082, 63.102533742785454, 63.535376116633415, 63.99428129196167, 61.65252394974232, 62.203349992632866, 58.058900982141495, 59.29807908833027, 61.23459957540035, 58.029900938272476, 59.750235825777054, 62.427203580737114, 60.67170538008213, 63.17699834704399, 64.52727869153023, 63.22170674800873, 62.29688197374344, 60.26577316224575, 54.30493801832199, 56.62609666585922, 55.58820515871048, 51.40117943286896, 61.255620047450066, 57.850816547870636, 56.64664216339588, 58.81839282810688, 54.630857929587364, 58.98505188524723, 62.06059165298939, 54.908163249492645, 58.96227590739727, 50.647820457816124, 47.12440252304077, 46.44646190106869, 44.97545063495636, 43.234520852565765, 40.191469341516495, 44.6088957041502, 48.27373445034027, 48.54676119983196, 46.63165636360645, 45.316163152456284, 45.62819100916386, 47.37201623618603, 48.538299053907394, 56.20219141244888, 65.99290564656258, 60.79671107232571, 53.82407382130623, 63.06941092014313, 53.86149801313877, 52.020846381783485, 51.71572655439377, 48.93949292600155, 48.54685999453068, 55.78183136880398, 58.5566932708025, 60.805602595210075, 65.09971797466278, 55.70114269852638, 48.45207408070564, 46.958226040005684, 49.13298234343529, 47.09205865859985, 47.006213665008545, 46.69084958732128, 38.28867964446545, 31.503894813358784, 23.14389120787382, 23.55957180261612, 34.33569855988026, 45.05755662918091, 47.194998934865, 46.231617629528046, 54.36362586915493, 53.43648701906204, 57.07606852054596, 55.992891043424606, 56.58809490501881, 54.5854427665472, 56.139190793037415, 54.59566041827202, 55.25935560464859, 50.79457998275757, 54.769390895962715, 51.75873264670372, 51.54247485101223, 59.91736225783825, 59.06746946275234, 58.55164334177971, 54.77818742394447, 51.258390694856644, 54.83379364013672, 59.05575469136238, 58.324654921889305, 57.14778587222099, 58.580616787075996, 50.78840151429176, 52.59927414357662, 53.80236558616161, 55.08006602525711, 58.9684733748436, 65.25227218866348, 60.005331337451935, 63.09700503945351, 66.18855714797974, 57.807571068406105, 61.52710787951946, 70.258047580719, 63.75721201300621, 66.65058955550194, 65.31174659729004, 77.688799649477, 48.12252156436443, 65.88343352079391, 30.59841100126505, 0.3321505675558001, 3.5396278649568558, 1.5210074395872653, 0.2727222314570099, 40.77924080193043, 77.83891439437866, 62.69320450723171, 70.3817917406559, 79.71181869506836, 44.9685388058424, 51.68512299656868, 81.54816895723343, 45.51078110933304, 52.88775086402893, 60.291159600019455, 62.374261021614075, 1.7518400656990707, 0.3499142581131309, 0.3026810707524419, 0.14108132338151336, 0.13075027149170637, 0.06477448594523594, 0.10760294520878233], [0.0880560593213886, 0.07996977408765815, 0.013630501307488885, 0.12977638078154996, 0.07676708031794988, 0.07545521555584855, 0.06439502583816648, 0.1906100774067454, 0.380102094495669, 0.8191335049923509, 50.63876174390316, 57.58245974779129, 41.45933210849762, 36.14462569355965, 37.93029807507992, 21.614192090928555, 32.39443592727184, 65.11683225631714, 58.26307162642479, 65.32484829425812, 51.95342279970646, 63.33365634083748, 29.991832450032234, 0.09780949767446145, 0.9299319377169013, 0.7128474488854408, 1.8047386896796525, 0.2403399089234881, 0.10967112524667755, 51.24962456524372, 56.17799811065197, 40.685598626732826, 53.19457300007343, 69.88110020756721, 75.92627182602882, 70.82766741514206, 64.93570357561111, 62.46818818151951, 59.4619794934988, 60.00153914093971, 56.614625081419945, 57.14501582086086, 51.822098046541214, 54.94392313063145, 52.25339010357857, 54.25239063799381, 55.55222488939762, 53.94806116819382, 50.39282374083996, 48.08903396129608, 46.547502279281616, 67.8875295817852, 68.02451983094215, 52.355080246925354, 56.42343074083328, 53.94812576472759, 47.96816624701023, 50.2125234156847, 45.981420055031776, 49.574499651789665, 51.11715227365494, 49.97165434062481, 50.89908577501774, 50.21948464214802, 52.16138944029808, 53.532317876815796, 47.27374970912933, 52.53379225730896, 46.48621916770935, 40.750666335225105, 40.74522502720356, 42.17289201915264, 39.15193252265453, 36.18801176548004, 39.759109541773796, 37.73239329457283, 39.50075380504131, 40.8621409535408, 38.98682378232479, 44.046822264790535, 41.62624575197697, 51.74669489264488, 58.22454549372196, 61.062446013092995, 52.767418920993805, 53.5940607637167, 61.61077179014683, 57.546722665429115, 55.87715305387974, 53.75118613243103, 56.20330095291138, 60.63911072909832, 55.54661639034748, 53.139084577560425, 56.72717124223709, 59.46928270161152, 55.804519951343536, 40.262643322348595, 40.77816925942898, 41.608090326189995, 44.05609376728535, 42.875941693782806, 40.02268999814987, 28.625779151916504, 24.241785295307636, 21.261373423039913, 22.423972338438034, 28.22182472795248, 39.05807375907898, 43.89923058450222, 46.94669745862484, 48.501760214567184, 46.36756293475628, 50.465563237667084, 48.93571972846985, 53.3065339922905, 51.85838609933853, 51.369732320308685, 48.93446959555149, 51.68019846081734, 44.40067067742348, 46.94621108472347, 46.7562934756279, 53.33602041006088, 53.428591042757034, 55.27309566736221, 50.81399314105511, 53.56971926987171, 47.83172696828842, 44.512240290641785, 49.72618751227856, 55.23232005536556, 52.468625754117966, 52.110095992684364, 46.47004343569279, 47.62917883694172, 46.59286044538021, 47.12386675179005, 48.40887799859047, 51.607728749513626, 54.75972801446915, 58.82234461605549, 58.429753482341766, 65.15474662184715, 49.647277146577835, 56.37912131845951, 57.37542025744915, 82.87954151630402, 75.38803070783615, 48.967581018805504, 47.07571193575859, 68.33513036370277, 11.493947189301252, 0.1999525143764913, 1.8279282515868545, 0.3587763325776905, 0.5749840184580535, 48.00609961152077, 56.229306757450104, 58.131678476929665, 57.290813997387886, 65.72867542505264, 34.46397207677364, 24.696434698998928, 47.978433296084404, 35.54051510989666, 40.68893864750862, 39.528735503554344, 24.315864220261574, 1.3340831198729575, 0.03254332405049354, 0.08209762279875576, 0.07015771348960698, 0.10269423946738243, 0.015679474563512485, 0.01916726992931217, 0.06729530185111798, 0.02491454317350872, 0.01971912908629747, 0.05120175897900481, 0.06770942767616361, 0.10615088875056244, 0.0981214594503399, 0.1116264468873851, 0.26856412645429373, 1.0493513359688222, 57.727478966116905, 70.78267022967339, 43.66014741361141, 39.22964595258236, 52.25286193192005, 21.95052344352007, 40.245373249053955, 73.97939309477806, 63.27494949102402, 71.83388382196426, 57.66293942928314, 69.88454282283783, 32.05171711742878, 0.07308225773158483, 1.2430459423922002, 1.0875921277329326, 5.236904639750719, 1.4579948270693421, 0.8341961936093867, 52.161925211548805, 56.356470733881, 45.622521713376045, 61.77122198045254, 69.11846593022346, 71.57479092478752, 65.3828863799572, 64.89756882190704, 62.98197381198406, 63.98833081126213, 63.31562250852585, 60.25205209851265, 57.856432646512985, 54.19825114309788, 58.44696655869484, 54.97894585132599, 55.070653930306435, 57.644077241420746, 54.89096537232399, 52.81824879348278, 50.66750340163708, 51.50258459150791, 66.11579105257988, 64.13301184773445, 55.448767840862274, 57.726905196905136, 56.33808732032776, 50.284567549824715, 52.41979457437992, 48.232388868927956, 53.647413700819016, 54.58330728113651, 53.09059537947178, 55.68587891757488, 53.61160822212696, 55.6022834032774, 56.65388077497482, 51.619500517845154, 53.7978096306324, 49.787660613656044, 44.308039247989655, 45.32069630920887, 47.444550544023514, 42.618205323815346, 40.66819176077843, 42.349422946572304, 42.611232697963715, 43.893728479743004, 43.44966530799866, 39.75464478135109, 46.23788729310036, 44.812534376978874, 52.72146798670292, 59.32971619069576, 59.14862170815468, 52.83459171652794, 55.186555311083794, 62.649438455700874, 57.9077222943306, 56.75799898803234, 54.452632293105125, 54.48310285806656, 62.204866111278534, 55.56420564651489, 54.72150206565857, 56.57761126756668, 61.428366377949715, 56.66581593453884, 42.70959421992302, 44.61970992386341, 45.96659705042839, 45.390468165278435, 44.293478429317474, 40.47279104590416, 33.37607525289059, 31.173916719853878, 27.53815021365881, 27.12122518569231, 33.874342516064644, 44.87908400595188, 48.272640109062195, 49.529274478554726, 52.96658903360367, 50.77996976673603, 53.12778018414974, 52.51313656568527, 56.23731292784214, 53.96015591919422, 54.185214042663574, 52.87672005593777, 52.87682645022869, 46.58199682831764, 50.90480826795101, 50.03642186522484, 55.69530241191387, 56.26980118453503, 55.37666670978069, 54.0608125180006, 56.007227674126625, 48.80050018429756, 43.554315492510796, 52.405716329813, 57.62622579932213, 56.4165835082531, 55.53922198712826, 47.135904505848885, 49.05709661543369, 48.67280423641205, 48.34383308887482, 51.41366936266422, 54.76638525724411, 57.18970142304897, 62.80592925846577, 59.28570315241814, 67.01112940907478, 53.30445930361748, 58.32430154085159, 60.165910720825195, 74.45467919111252, 73.78147691488266, 53.84337678551674, 48.83147232234478, 70.15974685549736, 12.320540584623814, 0.3671431867405772, 1.5253076213411987, 0.8009853819385171, 0.700009778374806, 53.48672792315483, 62.38255217671394, 65.10784193873405, 62.29160025715828, 73.88948991894722, 37.76903472840786, 29.050254374742508, 56.94663226604462, 45.51732435822487, 42.42675259709358, 46.90306819975376, 37.33750328421593, 1.7984312656335533, 0.09735416038893163, 0.15570307237794623, 0.09195810853270814, 0.10368552611907944, 0.020263060250726994, 0.02912517182267038, 0.18134785175789148, 0.2134930729516782, 0.1066250097937882, 0.3396102203987539, 0.21397389558842406, 0.16141548694577068, 0.16180192324100062, 0.19047255744226277, 0.43335896800272167, 1.3099387404508889, 69.63044285774231, 78.85903805494308, 59.45469528436661, 45.425369292497635, 59.78996269404888, 30.98582111299038, 44.799295887351036, 75.67467972636223, 70.75493931770325, 75.83599627017975, 63.244129344820976, 75.44660076498985, 37.8899822384119, 0.12480500066885725, 1.461675523314625, 1.375603610649705, 6.6932054702192545, 1.3720430829562247, 0.9703456191346049, 57.24636398255825, 60.026306211948395, 52.75091640651226, 67.5079071521759, 68.79818871617317, 69.6515317261219, 64.52019587159157, 66.83233380317688, 64.79097694158554, 65.66476285457611, 66.10344931483269, 60.512098744511604, 60.183275789022446, 56.01228520274162, 62.2611752897501, 57.09418214857578, 59.79680612683296, 61.07984147965908, 56.63202054798603, 57.14978836476803, 55.7620420306921, 53.58627498149872, 67.32312306761742, 63.48980136215687, 57.19235748052597, 59.75427120923996, 59.50047142803669, 53.25112156569958, 53.663851618766785, 49.841317534446716, 57.06530749797821, 56.951955780386925, 56.605604365468025, 60.5686055123806, 57.640904411673546, 58.56301233172417, 61.99046641588211, 54.608545526862144, 58.98937605321407, 55.19260838627815, 48.80343742668629, 50.01864641904831, 53.168145418167114, 50.6402512639761, 44.415778666734695, 46.39946222305298, 46.667545437812805, 47.19765119254589, 47.150754109025, 41.74106039106846, 48.677303194999695, 48.038048297166824, 55.60889504849911, 62.64767915010452, 61.070531979203224, 54.05191719532013, 55.82204461097717, 65.25686234235764, 61.60290241241455, 61.60575985908508, 57.56989762187004, 59.00533899664879, 64.23490718007088, 59.064513221383095, 53.65588344633579, 58.65415804088116, 64.66026395559311, 60.358320996165276, 45.915106013417244, 46.15399159491062, 47.14096583425999, 49.411340206861496, 46.502026319503784, 45.56251913309097, 40.16688086092472, 38.48151929676533, 34.399573132395744, 34.41277362406254, 40.309506207704544, 50.249503031373024, 53.78101073205471, 54.13964308798313, 54.88729476928711, 53.3365523815155, 57.41244167089462, 56.36034272611141, 60.17465405166149, 56.771062687039375, 58.897751569747925, 57.158558294177055, 57.57042579352856, 49.3098134547472, 52.89432071149349, 52.92521685361862, 58.06343413889408, 59.48856666684151, 58.55124816298485, 54.98182989656925, 54.87911380827427, 47.56209723651409, 45.657088458538055, 53.944561555981636, 59.45770092308521, 58.28564241528511, 59.422716200351715, 50.89633472263813, 53.773563131690025, 51.597625091671944, 51.30379065871239, 54.73621487617493, 56.55474789440632, 58.34898881614208, 63.743855729699135, 64.56330835819244, 68.81003648042679, 55.06711632013321, 63.2847111672163, 60.99538341164589, 74.19548749923706, 74.7439956665039, 61.61809019744396, 49.59685765206814, 73.2375057041645, 15.612648781388998, 0.43951333151198924, 4.4187724404037, 1.5122489095665514, 0.7239343039691448, 56.672070398926735, 69.8930923640728, 69.84547331929207, 67.64017805457115, 77.72448733448982, 44.0499646961689, 35.25110363960266, 67.92630270123482, 50.27249939739704, 56.08593665063381, 61.78544081747532, 54.63593065738678, 2.873080694116652, 0.24892903631553054, 0.18263476551510394, 0.20968187745893374, 0.15863163163885474, 0.15195138228591532, 0.18147778697311878], [0.08101980172796175, 0.11946251703193411, 0.12353429541690275, 0.08314203980262391, 0.0843534103478305, 0.10814056440722197, 0.06993920294917189, 0.13939838478108868, 0.5215542542282492, 0.4476498527219519, 31.239683590829372, 63.15207168459892, 46.27816133201122, 31.17090728133917, 32.68847554922104, 44.1425771266222, 13.57905300334096, 42.002034187316895, 60.20101323723793, 64.1484846174717, 50.939052030444145, 62.513333559036255, 41.776550486683846, 0.7111621799413115, 0.553769578691572, 0.7945458556059748, 3.7504728510975838, 1.418690092395991, 0.2288281000801362, 34.5398274064064, 73.06934952735901, 53.334530889987946, 46.82250112295151, 43.48093003034592, 48.99360962212086, 52.262023240327835, 49.39054772257805, 49.90336440503597, 54.88516308367252, 59.94214452803135, 59.46633405983448, 55.95317557454109, 50.97843311727047, 53.42038728296757, 57.13626869022846, 57.7921286970377, 40.02124987542629, 40.43617621064186, 50.10272830724716, 56.80335335433483, 53.167837634682655, 39.821570590138435, 51.34402669966221, 48.29097032546997, 57.89522476494312, 55.52773520350456, 51.92620486021042, 49.92530442774296, 46.20543323457241, 49.32530142366886, 55.22551842033863, 50.28324902057648, 50.12763597071171, 48.693999499082565, 52.1829304844141, 53.29049505293369, 52.41266615688801, 50.98981350660324, 51.8159119784832, 49.4483046233654, 43.89173358678818, 42.44993895292282, 43.158236145973206, 41.0603991150856, 40.72850592434406, 40.221020355820656, 41.25291958451271, 39.289420545101166, 40.421121418476105, 41.89667724072933, 41.65795885026455, 51.620720252394676, 61.075034737586975, 57.89813540875912, 47.15839169919491, 47.98395819962025, 60.281546115875244, 57.70008623600006, 56.14353395998478, 52.2818011790514, 59.467796981334686, 56.71809732913971, 51.99341185390949, 46.54104262590408, 57.3000854998827, 59.71743978559971, 62.08241768181324, 45.16840048134327, 40.62026493251324, 40.183075591921806, 42.5266682356596, 39.9498251080513, 36.81385338306427, 36.19860179722309, 29.455420933663845, 26.711086593568325, 27.514918260276318, 36.391787230968475, 42.526991218328476, 41.11813321709633, 46.532211899757385, 47.90472865104675, 50.66015459597111, 50.36853164434433, 51.94836147129536, 50.16873076558113, 48.87203134596348, 48.43427203595638, 51.5993881970644, 49.85143639147282, 45.699775367975235, 53.5149148106575, 48.120534271001816, 52.522461265325546, 52.95323275029659, 53.335963413119316, 53.73989313840866, 47.43758171796799, 49.56637568771839, 50.27519725263119, 51.718390211462975, 52.137279734015465, 53.94966468214989, 49.52261723577976, 44.12476748228073, 44.582350328564644, 40.674457624554634, 42.52150051295757, 44.815460219979286, 47.067302986979485, 46.872122660279274, 57.11325712502003, 53.83553400635719, 61.23399920761585, 61.54057815670967, 48.640825152397156, 60.29103800654411, 60.85134074091911, 39.0787560492754, 56.00845880806446, 60.98300367593765, 58.25334794819355, 2.33777919318527, 0.23861440073233098, 1.7257251357659698, 0.16177863464690745, 2.0477825542911887, 52.72404424846172, 54.51484635472298, 64.30270314216614, 55.62508977949619, 66.5049509704113, 26.676778234541416, 43.20495463907719, 27.086124569177628, 32.54344493150711, 50.389802902936935, 40.5035237967968, 21.022605635225773, 1.112788813188672, 0.05395100422902033, 0.1293229137081653, 0.029015799664193764, 0.15382937213871628, 0.02562531655712519, 0.0970132474321872, 0.09293339448049664, 0.08776629518251866, 0.09870083187706769, 0.03174710349412635, 0.024733884019951802, 0.13429620856186375, 0.017651327543717343, 0.13046182837570086, 0.357080643880181, 0.4567466536536813, 36.804794669151306, 74.69478830695152, 50.18828831613064, 34.48543332517147, 44.279844760894775, 47.96448044478893, 16.740220226347446, 52.89041452109814, 68.95277202129364, 70.26063904166222, 56.9439572095871, 68.11243191361427, 48.08224752545357, 0.6999006529804319, 0.5656417447607964, 1.1067966534756124, 5.619477611035109, 2.84431338775903, 0.17310394177911803, 38.06626617908478, 73.00207793712616, 53.1988325715065, 49.72120597958565, 52.02684625983238, 53.371643498539925, 54.06258702278137, 49.0362623333931, 50.49997419118881, 56.74968883395195, 60.68798750638962, 63.27137768268585, 58.19707676768303, 52.8784641623497, 57.01952375471592, 61.62067025899887, 60.09365379810333, 41.031862646341324, 43.56189988553524, 51.679107919335365, 57.930942848324776, 52.39960625767708, 39.64807190001011, 50.01781806349754, 50.95660328865051, 57.59154126048088, 57.02468387782574, 51.11533597111702, 54.58320088684559, 49.899978786706924, 52.15878278017044, 55.51133148372173, 54.10229109227657, 54.22906368970871, 53.64033468067646, 54.48068618774414, 54.928837940096855, 55.121248215436935, 53.975191712379456, 52.77990125119686, 50.794610381126404, 46.95551298558712, 45.67885749042034, 47.22808375954628, 45.633290335536, 43.826320096850395, 43.94451655447483, 43.60932134091854, 41.183782294392586, 43.83209578692913, 42.6776759326458, 43.524620085954666, 53.81682761013508, 63.47847796976566, 58.11080239713192, 48.403121307492256, 49.16545920073986, 60.235876366496086, 56.665629744529724, 55.261855870485306, 52.34715387225151, 59.9128632992506, 57.78234422206879, 54.10163752734661, 49.502801299095154, 55.31190678477287, 63.11638019979, 60.981145575642586, 45.02216912806034, 44.27522040903568, 42.41679713129997, 42.596801072359085, 41.61746062338352, 41.39004282653332, 38.424062579870224, 35.1518339663744, 30.8465775847435, 32.306577041745186, 40.54517336189747, 47.35548712313175, 44.94143486022949, 48.93408201634884, 51.30475200712681, 51.422674879431725, 55.2645081281662, 55.759382173419, 52.998545318841934, 52.49885693192482, 53.09982508420944, 53.63667547702789, 53.46360996365547, 47.93931059539318, 54.50411573052406, 49.970552399754524, 53.83890062570572, 55.34222915768623, 57.400396317243576, 55.97054824233055, 45.994590148329735, 48.86711820960045, 51.565444618463516, 54.21819627285004, 55.285771787166595, 55.801825895905495, 53.64828385412693, 45.89663900434971, 47.45086960494518, 45.659299939870834, 45.465981513261795, 47.15511627495289, 49.940093234181404, 48.29239904880524, 58.180600851774216, 58.304185420274734, 64.51540052890778, 64.49225977063179, 52.046658396720886, 55.467573031783104, 58.87153297662735, 44.81726512312889, 56.31159894168377, 61.8890118598938, 59.52138930559158, 3.548933328129351, 0.8755342941731215, 1.7035364639014006, 0.2151908990344964, 2.2404360165819526, 58.48588027060032, 59.72706086933613, 69.0630117058754, 63.278076723217964, 72.9161037504673, 30.39381667971611, 46.895559802651405, 38.62719587981701, 40.210669711232185, 49.971255362033844, 52.101143673062325, 31.518050953745842, 1.4019204047508538, 0.035358264212845825, 0.08716825032024644, 0.06800638322602026, 0.08412129624048248, 0.009762795907590771, 0.06223881595360581, 0.2344952881685458, 0.2707477327203378, 0.1977443281793967, 0.2449688917840831, 0.16375412786146626, 0.23571859986986965, 0.20450842537684366, 0.2435627594240941, 0.6894106627441943, 0.78716867021285, 45.80459274351597, 83.91538113355637, 63.95152598619461, 38.61000940203667, 51.235094144940376, 57.11318492889404, 21.808542162179947, 55.43381184339523, 72.46725663542747, 75.64414456486702, 63.28357122838497, 74.7260682284832, 53.61696973443031, 0.8363080490380526, 0.9210622636601329, 1.6162334172986448, 9.32817455381155, 3.548998637124896, 0.4862915229750797, 42.435423731803894, 72.73052170872688, 55.60280777513981, 53.5039371997118, 61.42327085137367, 61.01780980825424, 60.227326825261116, 50.448053777217865, 54.64761883020401, 59.90604266524315, 65.86579486727715, 64.02664795517921, 62.94613793492317, 53.82009543478489, 58.981977850198746, 63.76174136996269, 61.461424604058266, 43.465449661016464, 48.30258630216122, 52.58557587862015, 56.667886823415756, 51.37566760182381, 46.16944536566734, 53.94703522324562, 50.81077091395855, 61.676926240324974, 57.71631896495819, 55.93356862664223, 55.81981033086777, 52.908265963196754, 55.377647057175636, 59.362861812114716, 57.94061712920666, 58.35541047155857, 56.65914349257946, 58.15654814243317, 59.07158464193344, 59.672366604208946, 60.974009558558464, 58.06817628443241, 57.995273396372795, 51.05998434126377, 50.82427158951759, 54.26714524626732, 48.276113122701645, 48.69772329926491, 47.49749310314655, 47.56267100572586, 43.073436096310616, 43.43907527625561, 45.1617394387722, 48.289697393774986, 53.844778910279274, 66.73195838928223, 61.03504568338394, 48.820053935050964, 49.78658527135849, 62.746682837605476, 60.962211191654205, 57.981708124279976, 54.04621750116348, 62.97244392335415, 58.7993710488081, 54.601386711001396, 49.936407431960106, 58.96970830857754, 67.10130617022514, 64.03317600488663, 48.4113934636116, 46.81549429893494, 44.47459191083908, 45.14242507517338, 44.96808283030987, 45.83822853863239, 45.880136489868164, 40.40816031396389, 37.95329064130783, 37.252452448010445, 43.69781479239464, 49.71560887992382, 47.18220882117748, 50.40138088166714, 53.74525465071201, 56.03425182402134, 58.047239407896996, 60.26626333594322, 56.74771673977375, 55.27332365512848, 55.412118807435036, 58.920466750860214, 56.11220844089985, 51.39642208814621, 57.924828976392746, 52.88709729909897, 57.39388346672058, 58.048953115940094, 58.43653991818428, 58.41688737273216, 47.18709155917168, 50.29375545680523, 54.760917350649834, 56.57682090997696, 58.818579018116, 60.40212504565716, 56.072629764676094, 47.650484293699265, 50.682618990540504, 47.81372353434563, 50.576809868216515, 49.55784894526005, 52.20375336706638, 50.66122233867645, 63.600512221455574, 60.71954481303692, 66.99925884604454, 63.366239592432976, 55.68283908069134, 57.614484429359436, 67.71020069718361, 59.269888401031494, 58.78438085317612, 60.488938987255096, 64.04004603624344, 4.97969881631434, 0.8375488012097776, 5.032922560349107, 0.42559464869555086, 2.5017256708815694, 66.1116948723793, 66.85184955596924, 72.2233173251152, 69.34724405407906, 80.51471561193466, 39.064818397164345, 52.59290188550949, 47.099065482616425, 46.63859099149704, 64.59680736064911, 63.205470219254494, 45.644397139549255, 2.5209911121055484, 0.2031432744115591, 0.21837316890014336, 0.1570522374822758, 0.29789573221933097, 0.07505879737436771, 0.2022087323712185], [0.12298870555241592, 0.07228132453747094, 0.05586859508184716, 0.08218096598284319, 0.09237234567990527, 0.03936429573514033, 0.052975770231569186, 0.4369543172651902, 0.34317499317694455, 0.4417375777848065, 15.338711030781269, 67.9711326956749, 39.73912641406059, 51.0509218275547, 25.944582223892212, 61.12485006451607, 50.35827599465847, 19.31330155581236, 62.855132818222046, 49.13562700152397, 66.89775109291077, 49.95865523815155, 61.58743344247341, 5.200361050665379, 0.5854818457737565, 1.1979144578799605, 6.650773622095585, 3.136276896111667, 0.28721619746647775, 24.88712176680565, 77.2147598862648, 56.5390395373106, 59.48036290705204, 51.32810935378075, 49.04530584812164, 49.85767185688019, 50.34157209098339, 46.00780963897705, 53.43677580356598, 57.407608330249786, 56.84208087623119, 52.3136168718338, 54.19349379837513, 55.95751494169235, 56.81752659380436, 33.71920444071293, 41.81548699736595, 56.35769426822662, 58.62336069345474, 57.10905075073242, 51.589128747582436, 45.45362837612629, 38.43792803585529, 52.419334799051285, 56.03508397936821, 55.59438742697239, 48.56794886291027, 51.04373641312122, 47.711410224437714, 49.01621460914612, 52.4799719452858, 50.5840864777565, 52.53530837595463, 47.4650314450264, 52.02941112220287, 52.444151267409325, 53.05190585553646, 52.30629466474056, 52.186673283576965, 50.75913928449154, 46.47611550986767, 41.09389431774616, 44.27121922373772, 42.906279265880585, 40.5073007941246, 40.35733804106712, 40.42751267552376, 40.71905963122845, 39.98297072947025, 40.86712248623371, 47.62140445411205, 52.3636069893837, 60.877274349331856, 52.46987588703632, 46.28378123044968, 46.44773483276367, 55.86475811898708, 57.43937462568283, 52.89513386785984, 51.366551890969276, 56.81988626718521, 55.06528101861477, 51.25804491341114, 45.48930086195469, 48.72374430298805, 54.755293652415276, 59.1108251363039, 53.38014744222164, 41.419308856129646, 41.82762734591961, 41.06490187346935, 39.84090395271778, 37.25015737116337, 35.38141004741192, 34.45160374045372, 33.13244752585888, 39.57061305642128, 44.460403472185135, 42.965464890003204, 43.86204198002815, 48.42061936855316, 50.73510177433491, 48.95112410187721, 47.33664773404598, 51.331966146826744, 48.3550538867712, 49.71543028950691, 48.926995396614075, 50.76158255338669, 47.16053478419781, 41.6640917211771, 49.671793431043625, 46.005248576402664, 50.21473869681358, 53.3380912989378, 54.46332111954689, 55.191555842757225, 51.719317361712456, 47.93844424188137, 47.2753532230854, 53.284373581409454, 54.685552194714546, 49.72748704254627, 45.817607045173645, 43.09346862137318, 40.53437814116478, 42.309137508273125, 46.92430526018143, 50.23939557373524, 46.39032371342182, 44.95415657758713, 47.45835900306702, 55.697681084275246, 56.3979797065258, 66.6136783361435, 57.56396234035492, 28.75622995197773, 34.368069022893906, 56.74319878220558, 59.37709964811802, 63.358168825507164, 40.03678344190121, 0.18234684190247208, 0.24641967174829915, 1.0856431885622442, 0.15476366184884682, 9.566730502992868, 66.10465005040169, 45.68804919719696, 67.87990719079971, 50.8736727386713, 61.20478257536888, 16.247299276292324, 29.60682950913906, 40.15214145183563, 31.15675874054432, 39.232351407408714, 45.466289296746254, 17.26227231323719, 0.9727440029382706, 0.0510724211926572, 0.0823357111949008, 0.039455279329558834, 0.06056918777176179, 0.03460688792984001, 0.06675093653029762, 0.0312982785544591, 0.09289774170611054, 0.04226270524668507, 0.05686867247277405, 0.03842348996840883, 0.03985251758422237, 0.0737736647715792, 0.25846400123555213, 0.45235907658934593, 0.4015066724969074, 18.994179479777813, 79.48082149028778, 43.91607128083706, 47.03647144138813, 36.10481522977352, 64.48827758431435, 48.995965495705605, 24.18559581041336, 70.23847863078117, 62.110410779714584, 74.40882325172424, 56.892428174614906, 67.70300388336182, 5.9205069579184055, 0.6390444841235876, 1.9026032695546746, 6.21261628344655, 5.7281432300806046, 0.23868834832683206, 29.944984763860703, 77.80527859926224, 59.70298916101456, 61.157338321208954, 51.90584175288677, 54.71817724406719, 53.149306029081345, 55.50519101321697, 49.811105355620384, 56.23051889240742, 59.14104491472244, 57.84102447330952, 55.69933779537678, 55.17383359372616, 59.82448384165764, 60.001060366630554, 38.28309014439583, 44.48900833725929, 57.47348539531231, 56.8568354845047, 56.14633820950985, 52.087639197707176, 48.03197242319584, 39.122153520584106, 54.97695095837116, 56.92206658422947, 57.36498981714249, 50.04193156957626, 52.93606527149677, 51.467497274279594, 50.681608244776726, 55.62151037156582, 54.16944108903408, 56.5567921847105, 51.92213527858257, 54.35410737991333, 54.74773585796356, 54.6551538258791, 55.111102759838104, 53.88584330677986, 53.14992159605026, 50.4033187776804, 44.096945375204086, 48.60113248229027, 45.633985698223114, 42.75827720761299, 42.33806915581226, 42.62312985956669, 41.688946187496185, 41.964047625660896, 42.611901462078094, 48.82391072809696, 55.4345528036356, 64.23926934599876, 53.1069079041481, 45.1450165361166, 46.44756384193897, 56.00306309759617, 58.00006873905659, 53.088927268981934, 51.287899911403656, 56.62863492965698, 55.68234510719776, 53.28786179423332, 44.185062646865845, 52.273274436593056, 57.320148423314095, 62.85778507590294, 53.90899546444416, 43.51989693939686, 42.96447314321995, 44.201519563794136, 41.6088692843914, 39.727362245321274, 39.561603739857674, 39.04719494283199, 38.54768894612789, 45.521515533328056, 46.690929383039474, 46.65857031941414, 45.95498487353325, 51.79221265017986, 51.48904971778393, 50.597784742712975, 51.05018466711044, 55.63818767666817, 51.67117014527321, 52.95365072786808, 52.6210355758667, 52.08959989249706, 49.936244040727615, 44.310843497514725, 51.35012537240982, 48.802878856658936, 52.979971915483475, 55.026526898145676, 56.58993400633335, 56.6188732534647, 55.26575066149235, 48.56373868882656, 46.55240021646023, 55.51048032939434, 55.91326251626015, 54.903086721897125, 49.960957914590836, 44.59242358803749, 42.64510788023472, 44.354921132326126, 47.977498546242714, 53.53962868452072, 49.10603418946266, 46.73381008207798, 49.384327456355095, 58.92579786479473, 58.958540707826614, 65.23325800895691, 60.50524391233921, 33.76935414969921, 37.05388270318508, 61.12544283270836, 59.84676964581013, 63.84317100048065, 41.35398656129837, 0.2623427618527785, 0.3509522555395961, 1.7833442939445376, 0.2688901370856911, 12.36409479752183, 74.57609787583351, 53.086913377046585, 73.44945833086967, 58.78010228276253, 72.34486520290375, 23.70282031595707, 38.00648778676987, 49.6306948363781, 33.853094056248665, 40.34299001097679, 59.15147915482521, 24.383118711411953, 1.0509219579398632, 0.03513269955874421, 0.027720002399291843, 0.02959444849693682, 0.08895053280866705, 0.024843358223733958, 0.029094946003169753, 0.26701535331085324, 0.14822149649262428, 0.24915556947235018, 0.1710589390131645, 0.19631140428828076, 0.11106703081168234, 0.1790596471983008, 0.5753626918885857, 0.7996664370875806, 0.5785497708711773, 23.802291378378868, 92.63486444950104, 57.837996035814285, 62.20224045217037, 44.24927160143852, 78.30536216497421, 62.43682086467743, 30.592394024133682, 75.90926393866539, 64.28596124053001, 78.32703620195389, 60.46782732009888, 74.8355707526207, 6.962019670754671, 0.6002778362017125, 3.5923714097589254, 16.015348322689533, 7.450449261814356, 0.2922561520244926, 35.11464536190033, 78.15878883004189, 62.68281206488609, 62.04644501209259, 56.16392366588116, 56.73214517533779, 58.417008966207504, 57.86331407725811, 53.743704333901405, 57.353411838412285, 62.80871070921421, 60.240591913461685, 57.429422959685326, 57.82722361385822, 62.61421054601669, 61.628665030002594, 42.99023196101189, 48.960395604372025, 57.509788647294044, 58.02425064146519, 59.0772919356823, 54.10269767045975, 48.37826304137707, 43.41322526335716, 56.037052273750305, 59.981689006090164, 59.21967029571533, 52.408581376075745, 56.39052830636501, 53.78831014037132, 54.253146797418594, 59.42529246211052, 58.285980597138405, 61.686813309788704, 53.30118007957935, 57.400772497057915, 59.56806220114231, 58.2467857003212, 59.11864511668682, 58.61610308289528, 54.54931050539017, 52.89153166115284, 47.32616789638996, 52.744901329278946, 50.48439882695675, 46.84577867388725, 46.05262443423271, 46.23811908066273, 45.76394632458687, 44.73259426653385, 46.436582431197166, 52.6420446485281, 57.329005748033524, 65.35097569227219, 54.81477566063404, 46.27648562192917, 45.989772006869316, 55.63943400979042, 60.49253359436989, 55.17469994723797, 51.01312905550003, 57.64513358473778, 58.01443196833134, 53.041114434599876, 45.27309626340866, 50.40406733751297, 59.06529597938061, 63.39881144464016, 56.983273699879646, 46.12202391028404, 46.46282382309437, 45.14373980462551, 45.86080692708492, 44.50041152536869, 43.063590824604034, 43.112486600875854, 43.64968657493591, 50.603830218315125, 51.366293504834175, 51.383863762021065, 49.14580665528774, 54.76336821913719, 56.29086725413799, 54.26463358104229, 56.1409766972065, 58.103286400437355, 56.22891157865524, 55.07273621857166, 55.850379690527916, 55.031432434916496, 50.871085077524185, 46.85289569199085, 55.25840185582638, 50.84339216351509, 55.725575387477875, 58.736237436532974, 58.70117671787739, 60.08878245949745, 55.92583604156971, 50.55428847670555, 50.279217436909676, 57.95744262635708, 60.65866827964783, 56.73753708600998, 51.55864678323269, 48.33193592727184, 44.79987345635891, 48.118638172745705, 49.94173474609852, 56.11631982028484, 52.78605692088604, 49.17153887450695, 51.36748664081097, 60.97421854734421, 61.36289209127426, 69.89773571491241, 59.94853958487511, 41.783975288271904, 45.461041778326035, 57.00503133237362, 62.11350001394749, 66.75360202789307, 46.85224212706089, 0.9827305201906711, 0.5341982538811862, 2.899996074847877, 0.6307328457478434, 11.340379379689693, 79.75070580840111, 56.33525647222996, 81.0173374414444, 62.307563200592995, 75.955750644207, 26.304856091737747, 40.915729478001595, 56.744110733270645, 43.880961164832115, 54.584500417113304, 69.06012386083603, 35.69393567740917, 1.4858529134653509, 0.23113088042009622, 0.11580280872294679, 0.14473733579507098, 0.2530477778054774, 0.1295021126861684, 0.12373295350698754], [0.10316969637642615, 0.0993881793692708, 0.05870902430615388, 0.09942781005520374, 0.06027916388120502, 0.09086503632715903, 0.19948882050812244, 0.1373625549604185, 0.14165828382829204, 0.1515783491777256, 2.0486883306875825, 53.27583163976669, 55.08276008069515, 44.01106238365173, 25.35543903708458, 55.41200861334801, 82.15327888727188, 22.773825265467167, 65.19177183508873, 40.45599214732647, 53.292793929576874, 52.092681527137756, 58.11337485909462, 40.17142541706562, 0.23023709713015705, 2.632849272340536, 2.393472329713404, 5.894169146195054, 0.30134662985801697, 15.830908119678497, 70.40148988366127, 51.3628850877285, 39.60683651268482, 51.925319507718086, 54.88875389099121, 56.055127903819084, 56.984542831778526, 58.19686397910118, 55.37540137767792, 56.76702730357647, 50.3089090436697, 50.3351466357708, 51.78067646920681, 59.287587851285934, 49.6910659968853, 59.91797022521496, 69.79197978973389, 59.84268106520176, 55.200610756874084, 58.26472833752632, 57.48387023806572, 49.461239129304886, 42.404991164803505, 53.19273769855499, 56.63995072245598, 53.193718045949936, 50.030604377388954, 48.72154422104359, 50.05961962044239, 45.18293850123882, 54.50434751808643, 50.71769870817661, 54.391318783164024, 53.17617058753967, 52.16725632548332, 52.463781014084816, 52.39360257983208, 50.368767231702805, 50.47923110425472, 51.54685601592064, 49.48012791574001, 44.64068099856377, 43.110419511795044, 41.01327784359455, 41.52673289179802, 39.47237692773342, 41.365070566534996, 41.282440200448036, 42.15277589857578, 39.87468034029007, 47.897167056798935, 53.16109299659729, 56.38769745826721, 56.02138191461563, 42.08365000784397, 45.40665149688721, 50.99074065685272, 55.1627229899168, 54.12801951169968, 53.12420457601547, 53.72583009302616, 50.760104432702065, 44.5397812128067, 42.25189357995987, 45.43660908937454, 53.47099296748638, 62.35861346125603, 53.679176196455956, 44.08566378057003, 39.91193354129791, 40.838715210556984, 40.618745014071465, 39.59564231336117, 38.09663034975529, 39.70764510333538, 39.56279307603836, 44.534879475831985, 42.57029369473457, 43.53744439780712, 49.03870180249214, 49.74657341837883, 50.98513975739479, 50.4479093849659, 50.26159778237343, 50.456439927220345, 48.39337483048439, 52.75106459856033, 48.36434818804264, 52.34273470938206, 45.34275412559509, 45.3645383566618, 49.25479620695114, 46.22906036674976, 49.06056962907314, 50.036539658904076, 56.129364520311356, 55.73097489774227, 55.370647832751274, 55.986552983522415, 53.22415441274643, 54.47892688214779, 53.180939331650734, 53.44181813299656, 46.73231676220894, 44.19912949204445, 41.006875187158585, 49.338665306568146, 57.943763360381126, 56.40426456928253, 58.80044639110565, 51.335268169641495, 47.3337484896183, 50.5028772354126, 56.200804486870766, 57.615400180220604, 64.73242208361626, 64.25011396408081, 52.294830679893494, 59.72732685506344, 54.84021529555321, 61.17491997778416, 24.256851486861706, 0.13307157583767548, 0.3190372633980587, 1.623507533222437, 0.7996284984983504, 29.957765378057957, 52.10828348994255, 53.45938839018345, 63.116984367370605, 55.711535140872, 44.571247324347496, 11.98186095803976, 29.971936717629433, 33.579383343458176, 28.730189949274063, 34.27187718451023, 47.282515838742256, 12.050415929406881, 1.0229954752139747, 0.14410640636924654, 0.18816504220012575, 0.0681919053022284, 0.14069369965000078, 0.1459301749127917, 0.11151067184982821, 0.027262672447250225, 0.09875261152046733, 0.04731967354018707, 0.0781782963895239, 0.06730782188242301, 0.1418765346170403, 0.1698438503080979, 0.07184140908066183, 0.2292780642164871, 0.16900767252082005, 4.138391185551882, 64.92137834429741, 60.60298606753349, 46.59893251955509, 36.374163776636124, 66.81596428155899, 85.69102585315704, 25.460233613848686, 68.3090029656887, 46.06755003333092, 62.52144992351532, 58.36931772530079, 65.55856615304947, 44.20515596866608, 0.27137704426422715, 2.766679753549397, 1.4715320756658912, 5.466284556314349, 0.46480097458697855, 18.717371933162212, 73.47205951809883, 54.90841783583164, 46.878992691636086, 57.84385532140732, 59.4775814563036, 56.756802052259445, 59.91942934691906, 59.49658423662186, 59.3131110817194, 56.782716661691666, 52.491641119122505, 53.754560351371765, 54.69105049967766, 61.49380266666412, 51.702260076999664, 59.73554961383343, 66.53941512107849, 59.37380142509937, 59.580156952142715, 61.17017403244972, 58.772844672203064, 49.57592077553272, 44.18952740728855, 54.75431330502033, 56.93331018090248, 56.207423731684685, 52.024448588490486, 50.93703433871269, 52.47468262910843, 48.03498946130276, 57.03275464475155, 54.78314235806465, 58.30030582845211, 55.960262194275856, 55.527822598814964, 55.62413603067398, 54.828584119677544, 54.848590046167374, 55.22350832819939, 54.25765335559845, 53.091150149703026, 48.10875490307808, 46.04552261531353, 45.376146733760834, 43.88191491365433, 41.31800629198551, 43.09397779405117, 42.65347123146057, 44.02496583759785, 42.453210577368736, 50.219294652342796, 55.80420836806297, 60.34257084131241, 54.813449531793594, 43.169924318790436, 45.02416402101517, 51.73130951821804, 56.582923382520676, 56.245300099253654, 52.42845430970192, 53.473542630672455, 51.148774176836014, 46.363478153944016, 42.02851876616478, 46.52084290981293, 53.49052011966705, 64.7323688864708, 55.50522521138191, 46.607869639992714, 42.868969067931175, 43.6509595066309, 43.231040239334106, 40.84272399544716, 40.1483416557312, 44.23697926104069, 42.13477246463299, 47.15706177055836, 46.340667977929115, 45.42281962931156, 52.38369271159172, 53.0565682053566, 52.49148532748222, 54.10879634320736, 51.87011606991291, 53.868387043476105, 52.586328238248825, 55.601869225502014, 52.2661118209362, 54.90850143134594, 48.06998938322067, 47.73748442530632, 53.04942458868027, 49.58722896873951, 50.8662099391222, 51.581821739673615, 57.22671143710613, 58.728588446974754, 55.705440267920494, 56.95854842662811, 55.42259484529495, 55.347906053066254, 54.45939213037491, 54.09312978386879, 48.8536973297596, 44.35136452317238, 43.64998675882816, 52.97557935118675, 59.694215431809425, 59.63714249432087, 64.24692213535309, 52.60455206036568, 49.72488038241863, 50.696811228990555, 59.211071357131004, 60.883927792310715, 63.03681626915932, 70.45952796936035, 56.785752698779106, 59.54116724431515, 55.50240196287632, 62.11055517196655, 26.0851613804698, 0.13511420373106375, 0.3376009891508147, 1.9464308302849531, 1.4044846734032035, 37.30650074779987, 58.51291581988335, 58.855228051543236, 70.56191727519035, 65.77137753367424, 49.86929923295975, 13.374586924910545, 30.466656871140003, 43.95725727081299, 31.38293780386448, 40.49852706491947, 61.56388610601425, 16.008275002241135, 0.7501091400627047, 0.05802170649985783, 0.12043642258504406, 0.029567935271188617, 0.15772787388414145, 0.03419264336116612, 0.12444148931535892, 0.19795224827248603, 0.21449755498906597, 0.18947283999295905, 0.20798050391022116, 0.3000717982649803, 0.20057389978319407, 0.25046501483302563, 0.1705029368167743, 0.41785894660279155, 0.25998831319157034, 5.936474176123738, 79.83985662460327, 73.33991020917892, 57.12929226458073, 41.41545206308365, 74.38510492444038, 86.49883970618248, 33.60378943383694, 77.48271390795708, 52.69371047616005, 64.50570344924927, 65.4714672267437, 70.98877876996994, 50.64314290881157, 1.0643529309891164, 4.63818121701479, 6.569263720884919, 12.043933477252722, 0.4108225554227829, 23.057233057916164, 78.08340087532997, 56.90118670463562, 49.30945247411728, 56.990500912070274, 58.82893726229668, 58.046449050307274, 61.94111466407776, 61.459562703967094, 62.235412672162056, 61.45343363285065, 55.07273621857166, 54.21735651791096, 58.43460202217102, 63.955439776182175, 58.31303894519806, 63.673692494630814, 64.38065215945244, 61.920291781425476, 60.645589381456375, 64.2948679625988, 59.833432361483574, 51.52666009962559, 46.36129327118397, 55.05440220236778, 59.92666035890579, 60.23269213736057, 56.15421138703823, 53.408018946647644, 57.23806902766228, 50.332984551787376, 60.36685153841972, 56.1324917525053, 63.05748336017132, 57.731689140200615, 58.88472206890583, 60.422925129532814, 59.10214260220528, 57.03309282660484, 58.658136427402496, 59.05896171927452, 57.552631348371506, 51.76963046193123, 49.556560814380646, 49.27739359438419, 48.43584895133972, 44.92663845419884, 46.38824142515659, 46.67927160859108, 47.07464039325714, 44.90313671529293, 54.65648375451565, 58.17648567259312, 61.66328877210617, 57.40627460181713, 42.34158396720886, 45.382047817111015, 53.48693311214447, 58.932823687791824, 58.81019286811352, 57.3097787797451, 55.58634325861931, 50.517118871212006, 46.47433340549469, 41.99964411556721, 44.941925033926964, 53.80399189889431, 69.05577689409256, 57.7335624396801, 48.54477010667324, 44.7180562466383, 47.85918049514294, 46.07603117823601, 43.768582195043564, 43.80412168800831, 47.79350861907005, 48.626271933317184, 49.18902173638344, 51.12321674823761, 49.28632311522961, 56.84621125459671, 56.268247067928314, 57.530155554413795, 56.1719374358654, 55.67555107176304, 55.78520558774471, 53.85527014732361, 58.27024944126606, 54.35028858482838, 55.85684314370155, 51.016898453235626, 51.49118900299072, 57.06664502620697, 51.90768085420132, 54.58822801709175, 52.08228528499603, 62.0955915749073, 60.747598707675934, 58.70758697390556, 59.211876913905144, 57.7548298984766, 57.51030921936035, 57.02802389860153, 57.979538440704346, 54.40966419875622, 47.22857393324375, 46.947901993989944, 57.01163537800312, 63.409705460071564, 61.87501721084118, 67.2503037750721, 53.224511593580246, 53.285730108618736, 54.655940383672714, 62.09899619221687, 63.11383433640003, 67.84786731004715, 66.46160289645195, 62.478690817952156, 65.05526795983315, 57.5620586425066, 61.92153811454773, 31.225975826382637, 0.19932867988245562, 1.5034386073239148, 3.5353120090439916, 2.4357612105086446, 36.59720040857792, 64.84233498573303, 61.76433674991131, 73.80444288253784, 65.91844484210014, 56.724009811878204, 17.73143693804741, 44.14531297981739, 54.45958971977234, 41.90337248146534, 54.54269126057625, 74.09499809145927, 24.945129454135895, 1.347019406966865, 0.31221529352478683, 0.3011976362904534, 0.22262750077061355, 0.15564758941764012, 0.2037160936743021, 0.20010127045679837], [0.02867199233151041, 0.10998611498507671, 0.10064668371342123, 0.03608966559113469, 0.01800386995455483, 0.09069037187146023, 0.1327315831440501, 0.07010369998170063, 0.09262544772354886, 0.06861567162559368, 1.223371191881597, 49.27001819014549, 55.94694010913372, 42.54762411117554, 24.576235748827457, 39.859807938337326, 43.281752318143845, 24.34283137321472, 55.773639008402824, 61.53879605233669, 51.16450913250446, 60.65606161952019, 50.65002053976059, 66.7387144267559, 16.99823398143053, 1.6230977489612997, 4.827046282589436, 7.158559374511242, 0.29814604378771037, 9.986560475081205, 59.73793588578701, 40.45881539583206, 59.479792937636375, 59.65920031070709, 59.43522892892361, 57.651528641581535, 55.571068078279495, 51.99759542942047, 54.72176805138588, 50.85938550531864, 51.460482850670815, 49.673826321959496, 53.185141906142235, 52.85127282142639, 73.57485920190811, 69.50902417302132, 54.76175710558891, 55.23034416139126, 56.535604521632195, 59.00773286819458, 55.021184384822845, 51.109913662075996, 46.6014289855957, 55.7484045624733, 59.02962729334831, 55.39430536329746, 52.48496487736702, 49.76239196956158, 50.78443452715874, 44.05332751572132, 52.99548268318176, 51.816972121596336, 52.2803458571434, 51.31927102804184, 50.618315041065216, 53.032511696219444, 53.57285790145397, 51.92737139761448, 53.25458697974682, 53.699660897254944, 50.13438820838928, 45.618577525019646, 41.671546921133995, 39.687772169709206, 38.00855487585068, 40.82413159310818, 38.48585486412048, 41.0471948236227, 40.635414719581604, 44.35587488114834, 50.46815849840641, 52.78086259961128, 54.50159266591072, 60.036364272236824, 46.76177278161049, 42.55537949502468, 50.549078956246376, 55.65261550247669, 51.264599561691284, 51.87918238341808, 52.667054906487465, 49.04349334537983, 43.995654210448265, 43.15302662551403, 43.384912982583046, 48.80364641547203, 59.937337785959244, 54.966987892985344, 48.97507801651955, 40.95868617296219, 41.31350353360176, 39.37389761209488, 41.21245935559273, 40.95770962536335, 40.31155809760094, 41.002323031425476, 41.491064205765724, 42.08849094808102, 47.36062064766884, 51.9085244089365, 49.62362341582775, 50.35649009048939, 50.102504119277, 49.74842771887779, 49.938584715127945, 51.077516600489616, 50.08005492389202, 48.85534644126892, 52.24540673196316, 44.01953972876072, 45.573367550969124, 49.0305170416832, 48.55980210006237, 47.01661370694637, 47.51332305371761, 51.58974811434746, 55.20747698843479, 52.426239028573036, 55.98750673234463, 55.75848542153835, 54.163794592022896, 53.838630840182304, 52.63908840715885, 47.32639208436012, 43.2259751111269, 42.10778251290321, 52.986625358462334, 60.167753621935844, 56.65114492177963, 55.44105425477028, 57.61370167136192, 53.25077958405018, 45.81922955811024, 51.043823808431625, 58.18489082157612, 59.00717429816723, 73.45739230513573, 67.41633206605911, 50.26095561683178, 56.14704117178917, 51.730473563075066, 11.133903209120035, 0.17697042727377266, 1.7039321176707745, 0.29959471605252475, 9.45405324921012, 56.00036904215813, 53.423867896199226, 61.98133550584316, 52.585222497582436, 36.98344208300114, 32.37417161464691, 24.022060185670853, 51.33905276656151, 31.194084137678146, 27.133515626192093, 37.79961168766022, 47.20556616783142, 5.474573336541653, 0.6992758240085095, 0.1909818933927454, 0.22558855125680566, 0.06543447787407786, 0.02956517448183149, 0.10109799113706686, 0.13078240648610517, 0.021092898241477087, 0.03497431411233265, 0.03885645892296452, 0.01903242911794223, 0.07137286898796447, 0.15287626156350598, 0.1559681526850909, 0.065496283932589, 0.27661283675115556, 0.0225365164806135, 1.959066221024841, 60.252956449985504, 65.26244044303894, 44.997569248080254, 34.56473886966705, 52.675536051392555, 51.51873752474785, 26.378813423216343, 60.3815795481205, 63.52136246860027, 52.30553850531578, 69.04734134674072, 54.55646552145481, 76.61836668848991, 21.138104237616062, 2.187204910442233, 1.3689755788072944, 10.17190407961607, 0.07430930985719897, 11.011715065687895, 65.33224269747734, 44.61583033204079, 65.68693086504936, 60.495375841856, 61.570946127176285, 58.05233113467693, 58.57961744070053, 55.75538098812103, 58.77934232354164, 54.19247545301914, 52.95573681592941, 51.04036219418049, 54.74042125046253, 56.482369378209114, 70.79977691173553, 64.82994765043259, 57.03744359314442, 58.14682826399803, 57.808137238025665, 60.175702795386314, 57.95353263616562, 51.56941920518875, 49.080526158213615, 57.36127361655235, 61.18920721113682, 57.439317628741264, 52.13616259396076, 50.744095891714096, 52.02570252120495, 45.688079595565796, 55.0842572003603, 54.408520460128784, 54.495379999279976, 56.32682852447033, 54.06830191612244, 55.0205460190773, 56.56358242034912, 53.94587628543377, 56.02080054581165, 55.405446365475655, 52.65187472105026, 45.780407041311264, 45.425411090254784, 43.982723504304886, 41.937996223568916, 42.36129350960255, 40.60353063046932, 43.34042116999626, 43.476640060544014, 47.079196348786354, 52.73078888654709, 53.05789053440094, 55.68858817219734, 62.111011147499084, 45.7650900632143, 44.96917337179184, 52.07167625427246, 55.8225803822279, 52.3136130720377, 54.150879085063934, 53.71168725192547, 51.01222090423107, 43.97924289107323, 43.420285284519196, 42.25006967782974, 51.066941767930984, 63.02705079317093, 58.226392194628716, 49.03723128139973, 42.284389436244965, 41.85801811516285, 42.911880165338516, 42.48837389051914, 42.695622369647026, 42.436111494898796, 45.17539590597153, 44.244438260793686, 46.15158632397652, 50.67425183951855, 51.715544164180756, 52.71049037575722, 52.44154080748558, 53.3534424751997, 52.063962668180466, 51.88920244574547, 54.72431391477585, 54.503705352544785, 49.688052758574486, 53.83410908281803, 46.922390162944794, 49.40413199365139, 50.09263604879379, 50.429016798734665, 47.627427130937576, 50.43714456260204, 53.23004029691219, 56.80416651070118, 54.843239933252335, 56.73656053841114, 57.4028167873621, 55.8315023034811, 54.20973412692547, 54.39921475946903, 49.64785471558571, 44.88018974661827, 43.413476049900055, 55.923069790005684, 60.95230132341385, 59.067188277840614, 58.069886192679405, 60.58985397219658, 53.83984297513962, 49.04447369277477, 53.18492911756039, 61.82558946311474, 63.06008622050285, 68.64055037498474, 72.39089593291283, 54.5653722435236, 55.96807457506657, 56.08453832566738, 12.78933472931385, 0.1871630092500709, 2.6647993829101324, 0.36857024766504765, 14.952995628118515, 61.861584931612015, 58.453513607382774, 68.67648884654045, 59.3141408264637, 38.90814520418644, 32.186514884233475, 23.079984337091446, 54.18722793459892, 44.88794893026352, 31.12280186265707, 45.40418162941933, 59.14418734610081, 7.423379989340901, 0.7647575321607292, 0.20298357907449827, 0.19963434082455933, 0.07925803962280042, 0.065751374932006, 0.03745711721421685, 0.07277575816260651, 0.1496360299643129, 0.17455213906941935, 0.27239761606324464, 0.1572933464194648, 0.25258230278268456, 0.23941565304994583, 0.3966695617418736, 0.17261106666410342, 0.4604339104844257, 0.1400342717533931, 2.798543181270361, 73.62896829843521, 76.30488350987434, 52.95170143246651, 35.10777533054352, 60.839774161577225, 54.786258190870285, 32.90554650127888, 67.93315753340721, 74.4855335354805, 60.09198948740959, 75.38017272949219, 58.42023119330406, 80.10784104466438, 25.124700218439102, 2.5092922523617744, 7.50973510555923, 17.076638974249363, 0.26447343814652413, 12.712249215692282, 73.17868486046791, 46.790487840771675, 61.92780777812004, 60.205527395009995, 64.18885365128517, 61.64837457239628, 60.961842611432076, 60.04027806222439, 61.2533363699913, 56.897185519337654, 56.00774824619293, 54.18659336864948, 57.98273786902428, 61.09902665019035, 73.39395090937614, 64.46653515100479, 58.51302221417427, 61.6946978867054, 59.71834413707256, 62.80572406947613, 60.071497187018394, 53.26395347714424, 50.471369326114655, 60.268683806061745, 65.23527950048447, 60.6578703224659, 56.343365237116814, 54.063001200556755, 55.78106380999088, 47.64826521277428, 56.275949254631996, 57.32403181493282, 60.1554536819458, 59.04855027794838, 56.4472820609808, 57.554979622364044, 62.19872944056988, 58.069962188601494, 59.36672620475292, 59.66185636818409, 56.530596390366554, 50.65765433013439, 49.492906630039215, 46.258938163518906, 44.90480862557888, 46.146430000662804, 42.91694529354572, 47.136345282197, 47.005237117409706, 52.11096614599228, 58.987688943743706, 57.487666234374046, 56.823165491223335, 64.19254705309868, 49.234896674752235, 43.03322285413742, 52.07645259797573, 58.12383569777012, 53.00531655550003, 53.572732508182526, 56.64406590163708, 49.09004084765911, 43.05287539958954, 42.50624433159828, 43.1403961032629, 49.94975991547108, 65.75632274150848, 58.79236422479153, 52.97556795179844, 44.71271373331547, 43.96294556558132, 45.27032621204853, 46.05684220790863, 46.19235433638096, 46.39962941408157, 49.10659655928612, 48.63490127027035, 48.24893318116665, 57.47469753026962, 55.329701229929924, 56.736093163490295, 55.945203602313995, 57.99143560230732, 54.55678470432758, 55.9818222373724, 58.281880617141724, 56.553630754351616, 53.06646667420864, 57.573879808187485, 48.401456996798515, 50.86423024535179, 51.809330731630325, 53.33204202353954, 50.51715686917305, 53.78987565636635, 55.50893761217594, 59.66591835021973, 56.46968945860863, 61.64948031306267, 59.90371719002724, 57.548352777957916, 57.51662068068981, 58.80293905735016, 53.41771602630615, 48.99385280907154, 47.41599127650261, 58.754237070679665, 63.323157504200935, 61.354285553097725, 59.16988916695118, 64.01559054851532, 57.88284882903099, 52.0938328653574, 55.72628974914551, 65.84956973791122, 64.92855235934258, 73.2639142870903, 72.39895910024643, 61.65987655520439, 58.19551885128021, 56.91690646111965, 16.085547655820847, 0.28244074434041977, 6.136413272470236, 0.7165933947544545, 15.902473479509354, 65.76877847313881, 68.18857982754707, 70.77210679650307, 65.55272966623306, 48.04776057600975, 45.10626241564751, 30.053379647433758, 70.55082187056541, 48.18535499274731, 38.113607838749886, 55.723603293299675, 71.21301993727684, 12.235138267278671, 1.1168677755631506, 0.37411299243103713, 0.42278119653929025, 0.21270385826937854, 0.19025821035029367, 0.2858393354108557, 0.220967598434072], [0.06530929240398109, 0.06470412292401306, 0.022525013191625476, 0.13901721773436293, 0.07045167076284997, 0.16083024413092062, 0.06550147154484876, 0.030558117978216615, 0.17654722498264164, 0.24791143310721964, 1.1940957815386355, 44.969401359558105, 61.70583128929138, 45.11926531791687, 23.97628214210272, 39.83212262392044, 43.4967789798975, 30.16659077256918, 57.51685246825218, 60.993149131536484, 60.22956870496273, 51.306986287236214, 52.98301935195923, 49.26724053919315, 43.95178556442261, 0.8892270969226956, 0.5462870677001774, 1.521670266520232, 0.24310852051712573, 3.62870411016047, 48.87191355228424, 47.13337764143944, 62.532841712236404, 52.4234613776207, 60.5026600509882, 53.41699406504631, 55.220453292131424, 49.2026212066412, 49.36107650399208, 45.136197209358215, 47.805284187197685, 42.8708765655756, 50.900548696517944, 55.05967251956463, 59.62303005158901, 51.227847933769226, 58.83188210427761, 52.08210289478302, 54.016472697257996, 55.76383553445339, 55.381435453891754, 53.97928029298782, 51.62214897572994, 58.19883607327938, 58.73183727264404, 53.81726458668709, 52.894058525562286, 50.447316616773605, 53.0348751693964, 44.40814107656479, 50.888579338788986, 55.3905625641346, 52.18157775700092, 51.445724442601204, 50.61051785945892, 51.67924091219902, 50.98418980836868, 51.41160227358341, 50.97213305532932, 53.26891981065273, 50.605201944708824, 45.85336312651634, 42.23286800086498, 39.312169924378395, 41.797369569540024, 39.260941073298454, 41.23313784599304, 40.91044396162033, 43.17324534058571, 48.23601387441158, 50.067735984921455, 55.628350004553795, 54.261517748236656, 57.161328345537186, 55.41246458888054, 45.14794997870922, 51.50178663432598, 55.39978086948395, 48.905043974518776, 50.81649720668793, 54.408965036273, 47.47752517461777, 42.33786016702652, 43.51988933980465, 42.53780923783779, 50.443079844117165, 58.2363248616457, 52.74789176881313, 49.85831782221794, 42.00210638344288, 40.877716317772865, 40.80302752554417, 40.820365995168686, 41.90264672040939, 40.77438086271286, 40.78593984246254, 38.860814943909645, 41.726693361997604, 48.96625109016895, 53.75487953424454, 50.44551931321621, 50.73490038514137, 52.04674579203129, 51.071889102458954, 51.49323709309101, 51.44053392112255, 51.843726485967636, 49.97732363641262, 49.594744965434074, 42.78120897710323, 48.162130638957024, 45.75426444411278, 46.76815643906593, 48.207443207502365, 48.52926693856716, 52.77536429464817, 49.236568585038185, 52.28693850338459, 56.68915808200836, 54.502136036753654, 55.31170919537544, 55.35623520612717, 55.01503251492977, 51.24592736363411, 46.19489260017872, 39.53217051923275, 49.60659272968769, 58.81747707724571, 57.74467684328556, 59.81564551591873, 57.225529700517654, 56.887119859457016, 54.91524986922741, 51.65026746690273, 52.13608659803867, 57.55529120564461, 59.30361159145832, 77.97125369310379, 63.466132432222366, 48.07126231491566, 52.83682219684124, 5.792267639189959, 2.3158743185922503, 0.7351286220364273, 0.2324532243073918, 31.743281967937946, 65.11651307344437, 62.08582229912281, 56.4959916472435, 45.26310279965401, 44.828185737133026, 60.12397237122059, 30.738338492810726, 44.315483048558235, 22.94446650892496, 24.957081712782383, 38.045409098267555, 44.563203155994415, 2.3832197673618793, 0.41687586810439825, 0.12453468079911545, 0.06848981080111116, 0.09023486389196478, 0.030639954602520447, 0.047701994626550004, 0.012510645919974195, 0.08271202459582128, 0.02382828573900042, 0.01824737602873938, 0.10376584134064615, 0.08917023078538477, 0.044317842039163224, 0.08582123744417913, 0.06750291024218313, 0.2557845215778798, 0.1704872032860294, 1.6183960950002074, 49.497185200452805, 72.78306528925896, 46.90369516611099, 27.138833440840244, 52.64690838754177, 42.70295977592468, 34.01532255113125, 64.91612702608109, 68.53540241718292, 61.76934488117695, 59.21237848699093, 59.01051811873913, 55.80155611038208, 52.982449382543564, 1.7045958945527673, 1.1573162488639355, 3.606813959777355, 0.2724702871637419, 4.573586108162999, 50.730735808610916, 52.834048345685005, 62.512227818369865, 54.73293945193291, 63.2148253172636, 55.783651471138, 58.994615972042084, 52.47074984014034, 52.257117703557014, 48.70640203356743, 48.87785263359547, 46.44076220691204, 53.57168756425381, 56.905024498701096, 57.93527461588383, 55.558513551950455, 60.73364205658436, 54.967607259750366, 55.32454490661621, 54.84637476503849, 59.437740594148636, 54.97918523848057, 54.10279646515846, 58.86459454894066, 59.37499836087227, 55.673711970448494, 55.507235303521156, 50.40536306798458, 54.75354194641113, 45.94467982649803, 53.91745761036873, 59.38563399016857, 54.99438062310219, 53.91137793660164, 53.142815977334976, 53.97456094622612, 54.786816760897636, 54.84251797199249, 53.97464834153652, 56.15973249077797, 53.94776478409767, 45.871605947613716, 42.8205406665802, 42.18851298093796, 42.628236785531044, 41.49351127445698, 43.098320960998535, 42.88012906908989, 44.3940020352602, 51.69360414147377, 53.94448556005955, 58.57663840055466, 55.74982948601246, 59.024896547198296, 55.076425820589066, 43.423321321606636, 50.5417225509882, 56.40201508998871, 47.319791838526726, 51.23011641204357, 57.165967896580696, 49.31654289364815, 42.389453798532486, 43.520957082509995, 42.82819725573063, 50.07376626133919, 60.72432495653629, 56.85234032571316, 52.458772882819176, 42.71320402622223, 42.906252667307854, 43.280122205615044, 41.76011636853218, 44.17009525001049, 42.864021733403206, 44.67547573149204, 44.48861315846443, 42.29444369673729, 49.77830931544304, 54.31639440357685, 51.47658258676529, 53.73260132968426, 55.13983681797981, 53.39637257158756, 51.59966178238392, 54.02781128883362, 54.5429078489542, 53.990052714943886, 50.981594547629356, 45.336427465081215, 49.940249025821686, 48.99170972406864, 47.99684710800648, 51.32201828062534, 48.95483270287514, 53.33839148283005, 53.3146845549345, 54.37864646315575, 57.61321149766445, 54.45994310081005, 57.55887061357498, 56.011301055550575, 57.57275126874447, 53.221251368522644, 48.783119916915894, 44.3315713852644, 50.88776238262653, 60.251584723591805, 59.900559559464455, 61.33464440703392, 59.98193979263306, 60.59456951916218, 58.075604885816574, 56.4607485383749, 55.27301587164402, 62.58595526218414, 60.51633171737194, 71.69852748513222, 69.21141654253006, 50.24740554392338, 56.99745453894138, 7.458445932716131, 5.209108181297779, 0.6451875669881701, 0.5824585142545402, 40.37270821630955, 69.79967057704926, 68.38078111410141, 63.12856234610081, 51.61428339779377, 47.3181427270174, 61.38472951948643, 34.32578109204769, 49.103549122810364, 32.99305960536003, 27.746559530496597, 46.361418664455414, 56.25532016158104, 2.9891670774668455, 0.3492838778765872, 0.16628094774205238, 0.1174696724046953, 0.04912181218969636, 0.07521803257986903, 0.03632334934081882, 0.03572440276911948, 0.11463243441539817, 0.22941660834476352, 0.07695545224123634, 0.23519390146248043, 0.1412691461155191, 0.19831199693726376, 0.13368874584557489, 0.21890488802455366, 0.38138538657221943, 0.43449121818412095, 2.0679803704842925, 60.19492596387863, 82.87193432450294, 61.826444417238235, 31.52358915656805, 61.69582262635231, 52.9774222522974, 39.34212751686573, 70.22725403308868, 74.72596183419228, 67.02664017677307, 65.85138604044914, 64.38454315066338, 61.78691513836384, 57.63783797621727, 3.6938680009916425, 2.7203873125836253, 5.150207066908479, 0.2967682317830622, 5.9548780135810375, 61.45250268280506, 51.48826315999031, 67.75181606411934, 57.6422381401062, 66.86538442969322, 56.487901881337166, 61.360836401581764, 53.93683277070522, 55.7291129976511, 49.603199511766434, 53.034468591213226, 48.26927728950977, 57.55681872367859, 59.60382208228111, 62.73620679974556, 58.929677456617355, 65.04196107387543, 54.588292613625526, 59.488376677036285, 59.85508359968662, 59.60712410509586, 58.311526626348495, 57.078868970274925, 61.04472756385803, 63.72744061052799, 58.01659405231476, 57.84211881458759, 53.07562418282032, 55.811971351504326, 50.05682297050953, 56.58064730465412, 61.3140457123518, 59.63672451674938, 56.50198392570019, 58.444200307130814, 57.73618429899216, 58.41619201004505, 57.54034660756588, 56.34385921061039, 59.0753198415041, 57.941969856619835, 50.32244771718979, 47.39872120320797, 45.02897076308727, 46.937482953071594, 44.966931492090225, 45.896069034934044, 45.34239314496517, 48.82447689771652, 55.22421509027481, 58.793914541602135, 60.27778431773186, 58.436707109212875, 62.53542177379131, 58.190924897789955, 45.05189873278141, 51.78576819598675, 58.57805572450161, 48.796411603689194, 53.01611937582493, 58.22434410452843, 49.61794652044773, 42.518544271588326, 42.79093265533447, 43.730800822377205, 52.32814349234104, 63.252325505018234, 59.55878309905529, 57.0286812633276, 46.80509805679321, 45.088965743780136, 47.13093817234039, 43.430077359080315, 46.29583038389683, 46.40177249908447, 47.87353992462158, 45.99280044436455, 44.944714084267616, 53.11292678117752, 59.539476335048676, 56.012030616402626, 57.14500442147255, 57.25322641432285, 56.48133963346481, 56.94473996758461, 56.51762768626213, 58.75224217772484, 56.42063409090042, 55.10005295276642, 47.74387568235397, 53.71097669005394, 49.90874111652374, 51.63053132593632, 52.788754776120186, 52.24116235971451, 56.344258189201355, 55.148697942495346, 57.70382523536682, 60.829510912299156, 56.53582111001015, 59.57330211997032, 59.55722138285637, 59.93126191198826, 55.10613262653351, 51.61298766732216, 46.71074911952019, 54.41480912268162, 64.37442809343338, 62.50243954360485, 64.50730696320534, 60.48654891550541, 62.32788071036339, 61.337745040655136, 57.742450162768364, 56.81012459099293, 63.89762967824936, 62.62798100709915, 74.16872933506966, 68.20393100380898, 55.77340342104435, 56.01717934012413, 8.351956587284803, 5.169700970873237, 2.091892962343991, 0.8022245904430747, 44.01700906455517, 77.03782618045807, 72.72020906209946, 66.87453433871269, 61.401285231113434, 53.87079991400242, 74.50691878795624, 38.15304212272167, 60.93028910458088, 35.94545938074589, 37.98897832632065, 58.425448313355446, 71.24802365899086, 5.064067114144564, 0.6860071734990925, 0.3501140739535913, 0.2195850366842933, 0.17799934081267565, 0.09361137606902048, 0.19570153701351956, 0.1113712668302469], [0.0526076019013999, 0.06217566660779994, 0.1124818017706275, 0.07829548892914318, 0.044155103896628134, 0.13675587892066687, 0.10474949129275046, 0.11473373757326044, 0.09537832578644156, 0.5119962233584374, 0.6488009949680418, 24.44204404950142, 65.43387204408646, 45.93764640390873, 36.00870318710804, 35.94947576522827, 48.43158558011055, 23.461409769952297, 58.64588588476181, 63.235621601343155, 60.827888399362564, 60.05844488739967, 58.093802109360695, 53.50245147943497, 58.21587435901165, 7.943307990208268, 0.30407782236579806, 4.778245976194739, 0.15849952935241163, 0.7780906010884792, 41.85872867703438, 55.69303773343563, 58.08372884988785, 58.980081751942635, 57.9079844802618, 53.46092350780964, 51.07771418988705, 49.85051304101944, 51.44513167440891, 48.535194620490074, 49.57511521875858, 45.4663310945034, 47.16982528567314, 48.398025780916214, 50.396517142653465, 53.08745674788952, 52.18342445790768, 50.63186511397362, 53.875906839966774, 57.090188562870026, 55.069582387804985, 52.542877569794655, 52.63584718108177, 56.18885412812233, 55.57410031557083, 55.92050492763519, 51.18548020720482, 48.444881066679955, 53.59816834330559, 45.61826214194298, 46.574066653847694, 53.631959930062294, 51.66369214653969, 51.682041361927986, 52.66393147408962, 53.74826028943062, 51.882252618670464, 52.17359438538551, 52.996736615896225, 54.06292140483856, 48.27762544155121, 43.915254324674606, 41.090596094727516, 40.264771208167076, 41.394439190626144, 40.391965582966805, 41.83780699968338, 44.50842909514904, 49.18314345180988, 53.56480233371258, 52.525968477129936, 52.165090441703796, 57.669501677155495, 55.2512164413929, 55.466072112321854, 49.46806736290455, 49.38103683292866, 54.213803708553314, 47.40806110203266, 50.36654435098171, 53.154580146074295, 50.11215940117836, 41.863056644797325, 41.458803936839104, 43.81070293486118, 51.90832681953907, 56.453745514154434, 53.37160550057888, 51.23489275574684, 46.781440526247025, 40.604621171951294, 42.01313339173794, 40.70242412388325, 40.728825107216835, 40.65511666238308, 41.38783894479275, 40.740547478199005, 42.381641417741776, 49.327018931508064, 53.321478590369225, 52.49724581837654, 53.57771784067154, 50.07243633270264, 52.2469874471426, 49.09728325903416, 50.27436129748821, 50.500285774469376, 50.80436445772648, 45.82542322576046, 45.986048206686974, 49.23448629677296, 45.367847979068756, 51.618865951895714, 52.0275492221117, 53.30647699534893, 52.94733926653862, 54.84656475484371, 54.436741545796394, 53.388579189777374, 54.189314022660255, 52.975856736302376, 55.063073337078094, 55.34460783004761, 51.79765395820141, 50.79800359904766, 42.097819447517395, 42.787512838840485, 53.98324728012085, 58.608955666422844, 56.604274436831474, 56.82365946471691, 58.204592764377594, 56.40625186264515, 57.533423379063606, 56.247093603014946, 56.34709283709526, 59.2470858246088, 63.189169093966484, 71.67144253849983, 53.69091376662254, 45.62611252069473, 8.191941473633051, 11.598023604601622, 0.2959629421820864, 0.9569743147585541, 45.396350249648094, 67.84100487828255, 57.326083704829216, 56.89188100397587, 62.03466184437275, 60.26302970945835, 56.89081706106663, 33.299744948744774, 36.72583110630512, 24.985268600285053, 28.06499384343624, 42.137899696826935, 31.647048331797123, 0.7311101595405489, 0.07643876160727814, 0.08521577110514045, 0.15579552913550287, 0.084426868124865, 0.14215209404937923, 0.04581399691232946, 0.029886095835536253, 0.06586268966202624, 0.02299250500072958, 0.07094630476785824, 0.029469127584889065, 0.06414347488316707, 0.0928013664088212, 0.05451930752315093, 0.14902788447216153, 0.0692234312009532, 0.41717792220879346, 0.6468366191256791, 31.469278670847416, 75.20205348730087, 51.20650067925453, 40.75206845998764, 48.946974724531174, 52.55067855119705, 26.617702804505825, 66.81502193212509, 67.20533698797226, 68.97056266665459, 63.15692402422428, 64.78814229369164, 55.7143621891737, 68.5238966345787, 9.372725263237953, 0.4224662884371355, 5.413023289293051, 1.2738362839445472, 2.2200356237590313, 47.05053448677063, 61.54838673770428, 58.31167481839657, 63.989029973745346, 58.73527608811855, 58.099737390875816, 53.47363002598286, 52.90366820991039, 52.510814890265465, 51.65817104279995, 50.29668889939785, 49.25718627870083, 49.38503421843052, 52.17870511114597, 53.41129817068577, 54.450796991586685, 53.83990377187729, 53.647748082876205, 56.235952600836754, 58.59549678862095, 56.67606018483639, 54.587392061948776, 53.00977751612663, 58.439313769340515, 56.76898419857025, 57.15388834476471, 52.30370320379734, 50.458199232816696, 54.981807097792625, 47.23561495542526, 47.36211396753788, 58.644818142056465, 54.01192434132099, 54.5624615997076, 53.34534130990505, 56.070289090275764, 54.10479135811329, 55.762209221720695, 55.888066068291664, 57.12605483829975, 53.166500106453896, 46.21479593217373, 43.60423721373081, 43.682068437337875, 42.175080701708794, 43.137800842523575, 45.522157698869705, 45.00689394772053, 51.324438750743866, 55.70006735622883, 56.557479947805405, 54.65195059776306, 57.28908509016037, 59.15218211710453, 56.88302367925644, 50.27579762041569, 50.01080743968487, 55.710167214274406, 48.0031281709671, 50.68699635565281, 54.91322837769985, 49.71519850194454, 42.939105704426765, 43.114287704229355, 45.25240637362003, 54.146729707717896, 59.53224152326584, 56.19693249464035, 54.50853869318962, 47.88265943527222, 43.0314027518034, 42.68789358437061, 43.101269602775574, 43.440823182463646, 43.28989528119564, 43.8369557261467, 42.537923231720924, 44.60110232234001, 51.5046326816082, 55.9184530377388, 54.30512420833111, 55.50867922604084, 53.37954327464104, 54.72979322075844, 54.76195469498634, 52.230226546525955, 53.325707763433456, 53.57833720743656, 47.79125913977623, 46.32579177618027, 49.892234802246094, 46.39568902552128, 55.09984776377678, 55.10184645652771, 55.01433715224266, 53.97271044552326, 57.95533373951912, 55.824978053569794, 55.86145609617233, 56.45058408379555, 54.20458160340786, 57.87155203521252, 57.72457592189312, 54.968713000416756, 53.437193781137466, 44.657985270023346, 44.318614080548286, 53.74733693897724, 61.74390524625778, 58.17901253700256, 59.02539812028408, 61.05961136519909, 60.48352807760239, 59.3605325371027, 59.928104281425476, 58.09304594993591, 63.433442786335945, 61.57401256263256, 72.07209303975105, 59.30092893540859, 45.36847114562988, 14.42872541025281, 14.743716157972813, 0.17304351611528546, 3.7391929188743234, 54.839953109622, 70.27026012539864, 66.73494502902031, 61.44483469426632, 67.88242265582085, 62.207491770386696, 65.78004866838455, 36.051154509186745, 44.050561264157295, 30.968554839491844, 28.481597788631916, 53.129927068948746, 39.39532846212387, 0.8927487360779196, 0.10027977332356386, 0.10091952688526362, 0.09340303295175545, 0.08243627962656319, 0.11671170213958248, 0.04979095479939133, 0.06401482358342037, 0.21631059207720682, 0.16515228955540806, 0.18601233896333724, 0.10091488846228458, 0.12121000763727352, 0.14064905204577371, 0.14948945579817519, 0.2659749810118228, 0.21385509258834645, 0.6667444633785635, 0.9463589312508702, 38.79690997302532, 86.9890134036541, 62.76720553636551, 44.58655670285225, 57.81046651303768, 61.03283040225506, 31.712530218064785, 70.12168049812317, 74.61000725626945, 72.6109953224659, 70.43323338031769, 68.36427479982376, 63.968655467033386, 72.25066065788269, 14.470742605626583, 0.40396481403149664, 11.863988433033228, 1.7720645992085338, 2.9738294379785657, 53.75008799135685, 59.89927142858505, 62.93796457350254, 64.39490139484406, 63.17555442452431, 61.55510477721691, 57.2574669867754, 56.0375614464283, 56.94249428808689, 53.60937014222145, 54.74985234439373, 51.65402166545391, 53.041654005646706, 55.687501430511475, 56.232943162322044, 56.231373846530914, 58.61719362437725, 57.060595750808716, 59.25040304660797, 60.009362921118736, 59.12534415721893, 56.02525390684605, 55.31791806221008, 59.66830462217331, 58.012836053967476, 61.77726745605469, 53.68561305105686, 51.93397544324398, 57.87873364984989, 49.390802308917046, 50.53711339831352, 61.53038330376148, 56.927534490823746, 56.00948475301266, 56.12352803349495, 59.44859281182289, 57.064805924892426, 58.80754441022873, 59.22388046979904, 61.802809685468674, 55.665584206581116, 48.27490858733654, 46.28816619515419, 45.00716753304005, 45.774414762854576, 45.08496455848217, 47.8756982088089, 49.14031594991684, 57.32025481760502, 60.58725491166115, 58.96915353834629, 58.8229563832283, 62.42363557219505, 59.60241235792637, 59.09405283629894, 50.89961774647236, 50.02406492829323, 57.62114927172661, 48.97051066160202, 52.66644313931465, 56.74126848578453, 49.84419398009777, 42.2101604193449, 41.59277714788914, 45.17823815345764, 56.72438219189644, 61.722083017230034, 60.373919159173965, 55.92380695044994, 52.996109649538994, 46.1780709028244, 46.29556439816952, 44.255662858486176, 47.44930788874626, 45.406358912587166, 46.014459282159805, 44.572265669703484, 47.11240276694298, 53.81436534225941, 60.77275335788727, 58.73721398413181, 58.98101270198822, 56.71548306941986, 57.34113469719887, 55.74397400021553, 55.15910558402538, 56.06562674045563, 56.747591346502304, 49.029221311211586, 51.37850604951382, 52.92600721120834, 50.29236473143101, 57.96941578388214, 56.759906485676765, 58.35305459797382, 57.041026800870895, 57.459091767668724, 58.52687247097492, 57.97271020710468, 58.522605299949646, 55.75614094734192, 59.68085914850235, 61.241572201251984, 58.18359889090061, 55.31112402677536, 48.05866599082947, 47.60542631149292, 57.30850584805012, 62.66901880502701, 59.82287272810936, 59.29320015013218, 63.34262765944004, 63.36213581264019, 62.43452958762646, 63.144312500953674, 62.01949305832386, 65.99754139780998, 66.15226909518242, 69.89606380462646, 55.05979411303997, 50.795776918530464, 14.922345522791147, 19.3193394318223, 0.6930113257840276, 3.503994564525783, 56.6197320073843, 75.01397117972374, 69.61175546050072, 67.25984886288643, 71.08799904584885, 70.13222873210907, 71.63838431239128, 42.45987921953201, 54.703654423356056, 39.62203949689865, 43.62588085234165, 63.01573120057583, 54.67562332749367, 1.031746524386108, 0.23403002094710246, 0.26151695929002017, 0.3866722685052082, 0.2646292297868058, 0.24489872914273292, 0.13760643952991813, 0.13440968294162303], [0.13833809323841706, 0.04565879156871233, 0.01710908105451381, 0.06370960050844587, 0.058631904030335136, 0.14782389829633757, 0.17075966054107994, 0.0784199990448542, 0.14043482369743288, 0.2986562851583585, 0.08419037534622476, 10.480451323091984, 60.03142833709717, 43.42167600989342, 35.294402316212654, 30.368500538170338, 49.32142563164234, 23.3566227927804, 43.32558676600456, 60.36282755434513, 60.355326756834984, 53.26965697109699, 57.886796817183495, 50.922785103321075, 65.69507002830505, 17.728364802896976, 0.42592968384269625, 2.856140728108585, 0.719011549372226, 2.583012809045613, 38.994237184524536, 61.13967306911945, 54.887522757053375, 58.53132963180542, 55.97338669002056, 58.010141998529434, 57.036318853497505, 58.63848768174648, 55.35673297941685, 57.11002729833126, 49.785509929060936, 46.40872232615948, 44.7653941065073, 46.37971468269825, 45.79285517334938, 46.98254473507404, 49.142918810248375, 52.8887540102005, 57.022597789764404, 55.91426186263561, 54.099076464772224, 50.89552916586399, 49.93628963828087, 57.98342943191528, 56.267141327261925, 56.16328909993172, 54.73784878849983, 53.43381956219673, 51.08238033950329, 47.839277163147926, 44.114625826478004, 50.20474523305893, 53.93808290362358, 52.23948284983635, 51.131967678666115, 51.77102118730545, 52.64998622238636, 52.227764278650284, 52.387899085879326, 53.0718319863081, 48.299926444888115, 45.512434020638466, 42.44738548994064, 39.14603143930435, 41.484916135668755, 42.48236261308193, 45.890152752399445, 48.279019966721535, 51.39109097421169, 52.750525027513504, 53.36762331426144, 55.147326216101646, 55.60790330171585, 54.29014541208744, 56.46156549453735, 50.58335691690445, 52.34108179807663, 52.40660548210144, 45.42832933366299, 48.76704677939415, 54.2711578309536, 46.473805233836174, 43.01410607993603, 45.05443699657917, 50.753614380955696, 55.03377690911293, 55.42674422264099, 50.98501816391945, 50.25091655552387, 48.25649857521057, 46.74004554748535, 40.32287389039993, 40.058031901717186, 40.96863403916359, 41.18561379611492, 42.28380806744099, 39.72406402230263, 40.64909778535366, 47.700888589024544, 51.73858992755413, 51.86833776533604, 53.39235998690128, 52.457165569067, 51.516480445861816, 50.88415637612343, 50.18370196223259, 50.64732268452644, 49.71034236252308, 42.73476406931877, 44.03835251927376, 45.67584425210953, 50.64439684152603, 55.478687435388565, 54.65671934187412, 54.59938421845436, 62.86862209439278, 64.67099457979202, 53.89552518725395, 58.328420519828796, 49.55798573791981, 48.43897998332977, 53.3791670948267, 58.520769998431206, 57.189986407756805, 55.009872391819954, 48.21237534284592, 41.13316521048546, 46.136903911828995, 56.95281833410263, 57.003648206591606, 61.1101296544075, 56.52690678834915, 61.807434037327766, 58.613291233778, 63.0314851552248, 57.1375036239624, 61.655404195189476, 61.58739544451237, 69.75740164518356, 68.9019763469696, 26.54217805713415, 23.609864003956318, 7.388676451519132, 0.17497047287179157, 9.375994987785816, 53.46793033182621, 55.31598396599293, 48.57342816889286, 64.25813153386116, 53.79997931420803, 59.81295146048069, 53.33304136991501, 35.44640935957432, 31.39623139053583, 25.820564478635788, 29.426538683474064, 36.48586258292198, 18.44764530658722, 0.9627383679617196, 0.036253888029023074, 0.09385792494867928, 0.15687752107623965, 0.18445057823555544, 0.01860802083683666, 0.060224898043088615, 0.048333643935620785, 0.11278502104687504, 0.04081343184225261, 0.04687907159677707, 0.07266379034263082, 0.022936441309866495, 0.08371684059966356, 0.11567392735742033, 0.021458697265188675, 0.10433345814817585, 0.3633264102973044, 0.06956321609322913, 12.504462115466595, 74.77419644594193, 44.51762080192566, 37.08012409508228, 45.66155321896076, 58.66486966609955, 28.032653778791428, 49.248366951942444, 68.80645707249641, 64.46481764316559, 61.01526774466038, 64.562419205904, 56.61156624555588, 71.35111212730408, 22.489146441221237, 0.49976432346738875, 5.99254634231329, 1.231051767244935, 3.9217911707237363, 43.15577007830143, 63.587676510214806, 55.073948353528976, 62.026667073369026, 58.23218688368797, 60.554341077804565, 59.5539877563715, 60.911240726709366, 56.699459329247475, 59.01431791484356, 53.48016567528248, 50.12175388634205, 47.187604531645775, 49.42888006567955, 47.47740738093853, 49.31701026856899, 50.54034322500229, 54.51077297329903, 58.6914948374033, 58.96794140338898, 55.997048020362854, 53.541239798069, 50.519425347447395, 60.52985519170761, 57.27670915424824, 58.64797197282314, 57.94671580195427, 55.022898092865944, 52.51551903784275, 49.01664778590202, 42.863463163375854, 52.87939891219139, 55.720035284757614, 55.47576539218426, 51.288876459002495, 55.33829636871815, 57.350573390722275, 54.32061217725277, 57.550632655620575, 57.02424690127373, 49.595501124858856, 49.45184983313084, 44.21851605176926, 41.648394763469696, 44.50964502990246, 45.548079907894135, 48.05396944284439, 50.312195867300034, 52.35041029751301, 55.94815984368324, 56.604984998703, 57.984861955046654, 55.47181360423565, 56.6289085149765, 58.62426124513149, 51.23926632106304, 50.171478018164635, 54.550397247076035, 46.2903206795454, 49.222676530480385, 55.50568878650665, 48.559669107198715, 44.320498779416084, 43.61138463020325, 49.141786471009254, 57.57743641734123, 57.357048243284225, 55.85588939487934, 52.88788765668869, 49.84625346958637, 48.9223026484251, 43.27158026397228, 43.0479546636343, 42.03688591718674, 44.10072237253189, 42.97078460454941, 41.96093939244747, 42.774984911084175, 49.400370195508, 53.81699100136757, 55.135182067751884, 54.758603274822235, 55.70398114621639, 54.184571877121925, 53.78404676914215, 53.69787499308586, 53.19011203944683, 52.46760740876198, 43.52093048393726, 46.93773373961449, 47.86265730857849, 51.400199085474014, 56.63200534880161, 58.157121911644936, 55.73315978050232, 60.86334049701691, 65.91011568903923, 55.84973372519016, 58.78391347825527, 50.804489850997925, 48.042380064725876, 54.28700678050518, 60.55062107741833, 60.22069238126278, 56.61867566406727, 50.29477380216122, 43.72827775776386, 47.156510800123215, 59.3912348896265, 57.82398238778114, 62.555773481726646, 60.80200418829918, 65.79551383852959, 61.44401013851166, 63.975814282894135, 60.226734057068825, 64.57608327269554, 63.94812136888504, 65.53765967488289, 71.7148970067501, 31.505467928946018, 27.539284452795982, 6.330984206870198, 0.19943655846873298, 17.512621879577637, 55.97190856933594, 62.108963057398796, 56.20375692844391, 68.44393372535706, 59.592855870723724, 66.60365447402, 60.203315913677216, 38.402171954512596, 41.35774075984955, 35.63665755093098, 32.367073595523834, 46.97266146540642, 25.06271604448557, 1.1528884177096188, 0.0682305266673211, 0.16041057446273044, 0.11848300826386549, 0.09516371152130887, 0.08726834377739578, 0.07051476073684171, 0.08820092654787004, 0.34367154934443533, 0.1326766048441641, 0.14131130010355264, 0.18577497045043856, 0.08142849503201433, 0.35181751067284495, 0.390943773672916, 0.13903718150686473, 0.27853134786710143, 0.7650863926392049, 0.3082711051683873, 17.98216838389635, 84.02783989906311, 60.8452382683754, 43.44068259000778, 45.71146734058857, 67.33898341655731, 30.470420569181442, 56.70855984091759, 73.50229069590569, 71.22071072459221, 65.70533707737923, 71.958167552948, 60.698900520801544, 78.17478597164154, 28.87931104749441, 1.0274795908480883, 10.418464299291372, 1.6468401812016964, 5.220662411302328, 46.82767264544964, 60.295343175530434, 60.66498354077339, 64.11143660545349, 60.45017346739769, 63.032157719135284, 63.24813432991505, 62.46214650571346, 58.90856958925724, 62.176732420921326, 55.717550218105316, 52.233406975865364, 51.00648321211338, 52.16801628470421, 49.357641488313675, 54.064699709415436, 52.81178154051304, 58.03920663893223, 60.55341772735119, 60.586308762431145, 58.064448684453964, 53.77314515411854, 53.10643672943115, 63.1510229408741, 59.76646475493908, 61.553512662649155, 59.345599338412285, 57.48217552900314, 55.55265426635742, 51.75523303449154, 46.27921387553215, 56.7310394346714, 59.37913253903389, 58.8818646222353, 55.18239453434944, 59.70134384930134, 59.313004687428474, 59.919398948550224, 60.39771728217602, 59.345443546772, 53.47997948527336, 50.71457527577877, 46.78466655313969, 43.02451752126217, 46.26380190253258, 48.77936191856861, 53.02385576069355, 54.914318919181824, 52.788257002830505, 60.331410840153694, 58.98810692131519, 62.1869158744812, 59.54209439456463, 59.11679461598396, 60.69968327879906, 52.31989413499832, 51.68180577456951, 56.136519536376, 48.272237330675125, 50.30747652053833, 57.56755314767361, 48.07993724942207, 45.192544385790825, 44.02015909552574, 50.50728499889374, 59.65538911521435, 59.352313578128815, 58.130067363381386, 56.187607795000076, 52.12929256260395, 54.3317835777998, 48.22053350508213, 44.17475000023842, 44.20735985040665, 46.07365630567074, 45.65591052174568, 44.38009478151798, 46.23341493308544, 52.343984842300415, 56.052977219223976, 59.30754438042641, 58.46036083996296, 58.90582233667374, 59.22216676175594, 57.54494436085224, 56.21139071881771, 54.50816251337528, 53.82900595664978, 45.39218947291374, 48.12021888792515, 50.14557480812073, 53.815588876605034, 60.036330074071884, 60.09455814957619, 58.469765335321426, 60.04656292498112, 68.49238872528076, 58.19424971938133, 60.19890435039997, 52.57506564259529, 48.78133401274681, 56.949425116181374, 61.544362753629684, 63.008739575743675, 57.35355623066425, 51.557168662548065, 44.81975018978119, 51.14463999867439, 61.34081527590752, 60.3404201567173, 63.74092608690262, 61.607055589556694, 68.46450582146645, 64.00717779994011, 66.4143106341362, 63.03677447140217, 65.7826629281044, 67.51050621271133, 69.38414767384529, 68.20384740829468, 40.37460811436176, 31.47862046957016, 10.446147713810205, 0.44353381264954805, 15.535681061446667, 63.449006751179695, 66.6655607521534, 59.550263956189156, 73.6908745765686, 65.47529742121696, 73.64050447940826, 67.07808181643486, 46.70907720923424, 48.238331750035286, 38.85329134762287, 45.289606377482414, 61.37638136744499, 39.81980748474598, 1.358987339772284, 0.1441347860964015, 0.3470539319096133, 0.34569811716210097, 0.2815502561861649, 0.15736211382318288, 0.18250249995617196, 0.16302815900417045], [0.06767950428184122, 0.06338177903671749, 0.09097374611883424, 0.04584949012496509, 0.12732720439089462, 0.08334954429301433, 0.046745952568016946, 0.1010454841889441, 0.05955969252681825, 0.122640022309497, 0.10383627857663669, 2.2272763727232814, 51.13554708659649, 52.92420610785484, 44.23392042517662, 27.037585973739624, 46.877028197050095, 20.181203484535217, 34.46181759238243, 63.44044201076031, 58.02499160170555, 62.788906171917915, 57.412631660699844, 54.30015787482262, 59.98413607478142, 35.46953871846199, 0.04629776216461323, 4.659466724842787, 0.7600438257213682, 12.790214382112026, 43.32628212869167, 53.51613074541092, 55.238950699567795, 61.428529769182205, 63.063946813344955, 62.18268670141697, 60.87869927287102, 58.53210859000683, 59.26061689853668, 58.45925509929657, 53.72936390340328, 48.75271774828434, 44.480367600917816, 43.17629277706146, 44.615716338157654, 48.8777120411396, 48.2608987390995, 53.8560377061367, 56.84435315430164, 59.43424478173256, 54.3899242579937, 43.90267699956894, 48.43170717358589, 50.749780386686325, 54.821759685873985, 56.833462938666344, 59.422845393419266, 54.0307979285717, 49.86161224544048, 52.390881925821304, 44.302559942007065, 45.33296585083008, 53.80554981529713, 52.514648884534836, 53.40028256177902, 51.44774593412876, 54.175532162189484, 52.05100156366825, 54.694675505161285, 49.010484516620636, 48.885277435183525, 43.10786984860897, 41.578695103526115, 43.00459139049053, 43.503428623080254, 45.21716706454754, 49.37615409493446, 49.736621752381325, 53.57847020030022, 52.93414257466793, 54.924331381917, 53.663190454244614, 57.20426224172115, 54.564528688788414, 55.2877476811409, 53.70620794594288, 51.77041321992874, 53.56951028108597, 44.63088512420654, 48.87670889496803, 52.234961092472076, 47.28559747338295, 47.413673400878906, 46.95277713239193, 51.387629359960556, 59.687337800860405, 53.770542293787, 54.586860090494156, 53.00414241850376, 51.93615272641182, 49.66056503355503, 45.11827737092972, 41.515838876366615, 40.94333499670029, 42.59411841630936, 40.44151492416859, 39.773943945765495, 40.55726431310177, 46.42124645411968, 50.61588317155838, 52.91111581027508, 52.616316229104996, 52.26876027882099, 50.47298423945904, 51.970491483807564, 49.61956523358822, 53.540711626410484, 45.01898489892483, 43.560455963015556, 45.98968841135502, 47.61722467839718, 52.6436747610569, 60.049956142902374, 52.68978528678417, 56.8525455147028, 60.26773765683174, 42.15178795158863, 55.87204232811928, 51.207986399531364, 52.21481457352638, 49.33136589825153, 48.50241757929325, 48.190952092409134, 50.23319810628891, 56.507102251052856, 54.43445786833763, 47.92121596634388, 41.92789636552334, 49.402634873986244, 54.52692590653896, 59.62082237005234, 58.04807536303997, 60.11183962225914, 59.058604538440704, 62.1971183270216, 59.99846510589123, 63.947087824344635, 59.880451038479805, 58.98337237536907, 51.25863388180733, 8.902946971356869, 12.564811427146196, 0.9393367893062532, 0.522452846635133, 41.59818425774574, 69.8850367963314, 46.64514563977718, 61.52042783796787, 56.1118246614933, 55.2001965790987, 61.140626817941666, 48.16987842321396, 35.19508704543114, 34.86763581633568, 16.981136798858643, 22.561870738863945, 39.58081930875778, 8.38035436347127, 0.782210233155638, 0.08677589910803363, 0.18985696078743786, 0.013163117109797895, 0.09625572987715714, 0.052142249332973734, 0.07109437065082602, 0.008956445035437355, 0.01910984439746244, 0.056846575025701895, 0.14070563338464126, 0.08700554928509519, 0.03501049752230756, 0.054514565199497156, 0.04830017307540402, 0.13347141531994566, 0.017006217531161383, 0.2144301382941194, 0.04915629979223013, 3.422459727153182, 60.482593327760696, 61.82582505047321, 37.009098306298256, 39.37323644757271, 58.73918607831001, 24.10219218581915, 43.40611584484577, 67.23638892173767, 68.17354783415794, 69.7581996023655, 63.28920252621174, 59.993232786655426, 67.2418986260891, 41.18691712617874, 0.25254751089960337, 4.63845195248723, 0.8415383496321738, 14.625999424606562, 46.62564888596535, 56.86791189014912, 57.633794993162155, 61.620415672659874, 65.22976219654083, 66.03521257638931, 62.75997072458267, 61.67083136737347, 62.51211002469063, 62.396178245544434, 56.95229776203632, 51.0230503231287, 45.95115467905998, 46.38093061745167, 46.94003261625767, 50.43895706534386, 49.555154889822006, 57.96136021614075, 59.19621415436268, 60.96189200878143, 54.722569808363914, 47.882940620183945, 48.55518534779549, 49.35448385775089, 57.92182333767414, 59.498959109187126, 59.67396631836891, 56.84845693409443, 51.18643395602703, 52.863169983029366, 47.158380299806595, 48.63707095384598, 55.84783382713795, 54.282260835170746, 55.41907623410225, 53.85273948311806, 58.22913184762001, 54.975925013422966, 57.6706188172102, 52.70752273499966, 51.15578480064869, 45.26849091053009, 43.80108185112476, 43.75029377639294, 44.85986463725567, 45.672447234392166, 50.42240135371685, 54.192528650164604, 55.80049976706505, 56.212732046842575, 60.08847467601299, 55.16165144741535, 59.28190715610981, 58.042592257261276, 57.317173182964325, 53.55018071830273, 52.891125082969666, 54.26732383668423, 46.02554328739643, 50.03514513373375, 52.47545778751373, 50.15899948775768, 47.58406385779381, 47.81669117510319, 54.18251998722553, 58.00013333559036, 57.44861572980881, 56.4243920892477, 54.48435679078102, 53.584755063056946, 52.81562693417072, 46.67048268020153, 43.41100238263607, 41.510401368141174, 42.48939983546734, 41.28837928175926, 40.64219355583191, 41.18744909763336, 49.12931554019451, 54.27620775997639, 56.482456773519516, 52.97182135283947, 55.40476620197296, 53.14778231084347, 54.41907249391079, 52.528780326247215, 54.99699488282204, 47.043292075395584, 45.67937806248665, 48.598153442144394, 50.65545044839382, 55.457609966397285, 59.91392344236374, 54.54396799206734, 57.51758582890034, 60.21014794707298, 45.48031434416771, 55.66790208220482, 52.87703923881054, 52.9874537140131, 49.939861446619034, 47.911686077713966, 47.69220985472202, 51.986055448651314, 57.875940799713135, 57.1838953346014, 50.37306100130081, 44.290632382035255, 49.71341259777546, 56.10913820564747, 60.11642597615719, 60.879649221897125, 59.66439463198185, 59.86530885100365, 63.23269955813885, 63.1757178157568, 64.11711350083351, 64.60490852594376, 59.55941006541252, 51.47961102426052, 10.954953711479902, 10.791257545351982, 1.39480504905805, 1.9571895967237651, 46.444470807909966, 70.06539791822433, 53.13549757003784, 62.99736678600311, 63.64107504487038, 62.353020161390305, 67.90361791849136, 55.79584501683712, 41.06603801250458, 47.266024723649025, 20.42636252939701, 23.858980536460876, 56.031048595905304, 10.957243088632822, 1.1085279355756938, 0.0762479034892749, 0.10445186780998483, 0.04883101275481749, 0.04677588709455449, 0.042874951104749925, 0.029468884531524964, 0.005120950236232602, 0.12081103646778502, 0.1306329676299356, 0.21534581494051963, 0.18907384655904025, 0.21618396684061736, 0.23143875296227634, 0.16803814563900232, 0.1571035644155927, 0.1643014172441326, 0.5931417003739625, 0.15504495066124946, 4.219082230702043, 72.93826416134834, 75.47446087002754, 55.74630327522755, 42.208929285407066, 67.00838595628738, 26.474376395344734, 48.57117868959904, 74.08682093024254, 72.02358484268188, 74.31442111730576, 69.32929381728172, 66.17448270320892, 72.90388360619545, 44.18350473046303, 0.5603613937273622, 9.818487893790007, 1.4353773719631135, 16.71991791576147, 50.97818613052368, 56.783883199095726, 59.94410902261734, 63.49074371159077, 69.03564557433128, 68.48012298345566, 67.38632127642632, 63.70418965816498, 67.12028995156288, 65.41870325803757, 59.72392223775387, 53.11609201133251, 48.16517047584057, 48.74154254794121, 51.04087516665459, 53.62295061349869, 53.05799312889576, 60.95857858657837, 59.85826402902603, 65.18316149711609, 57.71330952644348, 46.78413838148117, 49.22304131090641, 51.37664034962654, 61.527119278907776, 61.564292684197426, 62.01419994235039, 57.56093390285969, 53.681870251894, 56.64718933403492, 48.441278859972954, 49.775672256946564, 58.28418329358101, 58.51889289915562, 59.53430861234665, 55.99639065563679, 62.56269671022892, 57.50994063913822, 61.029285192489624, 55.98220981657505, 53.876492008566856, 47.907046526670456, 44.904246255755424, 47.711934596300125, 47.4197568744421, 49.99178186058998, 53.01418527960777, 55.71582891047001, 61.4361597597599, 59.01209883391857, 64.02096346020699, 58.14295247197151, 62.01076492667198, 60.11178642511368, 59.88050043582916, 56.969860419631004, 54.29330684244633, 54.611171185970306, 45.59053882956505, 52.48651139438152, 54.17599193751812, 51.23087257146835, 50.0270439684391, 47.617513462901115, 55.434609800577164, 61.320877745747566, 60.168046206235886, 60.81721477210522, 58.88784170150757, 58.26057896018028, 57.21412271261215, 51.16698659956455, 46.51292033493519, 43.50659765303135, 46.434678733348846, 44.19569827616215, 42.218196988105774, 44.605779871344566, 51.40520341694355, 58.19673478603363, 58.37574318051338, 56.75040699541569, 58.273513466119766, 57.39894479513168, 56.80947482585907, 54.92343083024025, 57.87689074873924, 49.516419768333435, 45.847070664167404, 49.22205336391926, 51.502964571118355, 57.16824397444725, 61.0124596953392, 60.245573446154594, 58.026063144207, 64.17223334312439, 48.90987731516361, 56.18343181908131, 53.98091420531273, 52.2650820761919, 50.3468120098114, 50.55758289992809, 49.50919255614281, 55.26706539094448, 61.68397106230259, 58.79189305007458, 50.836142152547836, 45.2409727871418, 52.91171237826347, 59.81736682355404, 63.72878573834896, 62.43297167122364, 62.36297942698002, 63.94289284944534, 66.47533535957336, 66.58445030450821, 68.629280179739, 68.87524098157883, 61.59073546528816, 60.1578551530838, 24.840616062283516, 18.075683265924454, 1.898854176979512, 1.3898167479783297, 55.151372998952866, 75.93204751610756, 59.672374203801155, 69.25897479057312, 70.20812585949898, 65.87525635957718, 74.91558685898781, 60.24702496826649, 48.647178411483765, 55.37034384906292, 25.645986646413803, 39.2716109007597, 66.15214750170708, 20.98939161747694, 1.4415908697992563, 0.2853855863213539, 0.2436234671040438, 0.18104397197021171, 0.12822026037611067, 0.17449408827815205, 0.0918221619213, 0.06078330108721275], [0.052627892218879424, 0.030789697739237454, 0.01832365396694513, 0.04555719526251778, 0.10961377949570306, 0.022524013147631194, 0.13779675588011742, 0.02281834891618928, 0.13199474924476817, 0.034808436685125344, 0.4471939959330484, 0.5395867803599685, 42.26633280515671, 54.313164576888084, 42.731663435697556, 28.31791777163744, 40.21961823105812, 30.740608870983124, 21.555574536323547, 67.81724095344543, 52.91115760803223, 48.09036009013653, 51.94718733429909, 52.94480860233307, 49.8431908339262, 38.82736153900623, 2.421709564514458, 4.518714677542448, 1.279795195441693, 18.889846578240395, 48.042543455958366, 48.66630658507347, 59.26996439695358, 51.68467462062836, 61.30645751953125, 57.42927856743336, 61.43520601093769, 58.286820352077484, 59.34977911412716, 57.837756648659706, 54.541178941726685, 44.6492001414299, 43.802274987101555, 45.482419431209564, 45.22495664656162, 45.79632818698883, 49.308943301439285, 52.22717151045799, 57.32062339782715, 56.05897709727287, 55.88472604751587, 42.220856845378876, 48.03709074854851, 53.13660331070423, 53.106850907206535, 59.55528348684311, 57.2088485956192, 54.609670266509056, 48.995691910386086, 51.45997367799282, 48.534259870648384, 43.20581719279289, 50.05994640290737, 57.37524926662445, 52.449261993169785, 52.52957448363304, 52.132237404584885, 53.78527030348778, 54.391284584999084, 48.87838840484619, 48.38333576917648, 42.219424322247505, 45.12801244854927, 46.02283023297787, 46.8763442337513, 47.41069056093693, 52.17763736844063, 50.76545834541321, 53.57525937259197, 55.47796167433262, 55.79692795872688, 52.95260578393936, 56.010107919573784, 54.81029950082302, 58.057202473282814, 53.30292418599129, 51.38703279197216, 53.77221800386906, 46.197487860918045, 48.38557384908199, 50.97372516989708, 48.080469220876694, 45.629133358597755, 44.10986468195915, 54.29760441184044, 56.37296944856644, 55.68711005151272, 52.705292254686356, 53.88395480811596, 53.329727947711945, 51.702294275164604, 49.659307301044464, 44.08300772309303, 42.62970730662346, 40.063716396689415, 39.61823970079422, 40.01447103917599, 37.50238783657551, 42.93932989239693, 49.6836069971323, 51.76790155470371, 51.60655461251736, 52.35612899065018, 51.046156883239746, 52.75981552898884, 50.57090498507023, 53.7750830501318, 44.87227477133274, 40.23523919284344, 45.456421226263046, 46.37411758303642, 55.67346878349781, 51.90483100712299, 46.75445057451725, 51.00323058664799, 40.03207169473171, 50.49502685666084, 51.09146945178509, 53.18424895405769, 53.94752539694309, 59.98818665742874, 49.861091673374176, 43.1745220720768, 58.51905629038811, 58.42480234801769, 56.09897755086422, 51.15722492337227, 44.19520430266857, 41.57437853515148, 49.62893933057785, 56.115206480026245, 59.29585240781307, 55.43126218020916, 57.34697498381138, 59.56074379384518, 65.54013714194298, 62.183997631073, 60.639502108097076, 55.883950889110565, 30.489385351538658, 6.3170351553708315, 4.119885228574276, 0.24922708282247186, 13.446105737239122, 47.35334783792496, 58.88554282486439, 66.56370341777802, 59.460919350385666, 56.98396906256676, 54.975795820355415, 61.44183285534382, 47.236097529530525, 39.91649329662323, 24.41460572183132, 33.257863596081734, 36.33698657155037, 28.62085461616516, 2.1180144231766462, 0.5646868085023016, 0.3151273919502273, 0.33162978768814355, 0.13979055045638233, 0.03927768710127566, 0.06091758899856359, 0.0849632330937311, 0.01843221347371582, 0.023549763282062486, 0.05316944108926691, 0.17306735389865935, 0.038253860984696075, 0.11484239541459829, 0.05307822000759188, 0.09114243628573604, 0.07836760341888294, 0.1026952636311762, 0.08615347469458356, 0.4078994138399139, 0.7408960594329983, 47.052270993590355, 65.06730571389198, 39.67774450778961, 34.073030054569244, 54.12294678390026, 27.537394054234028, 26.0062263160944, 72.87300646305084, 59.55425374209881, 60.373189598321915, 62.925018668174744, 57.91867330670357, 55.71243189275265, 48.297148793935776, 4.029022604227066, 1.9125047069974244, 1.4547441015020013, 20.1905794814229, 52.721722573041916, 50.86870260536671, 61.10522411763668, 53.692612275481224, 64.05324652791023, 61.44441291689873, 63.74901585280895, 61.91820949316025, 61.281242072582245, 57.609081119298935, 56.67809687554836, 48.3640556037426, 46.44704706966877, 46.539252921938896, 48.47114145755768, 47.80586175620556, 51.519121304154396, 55.51660560071468, 57.889000698924065, 57.37591803073883, 60.151916071772575, 44.5142275840044, 49.693136885762215, 51.46645613014698, 56.80630959570408, 61.834120005369186, 59.38616596162319, 56.61522164940834, 53.62418174743652, 53.492218628525734, 49.74556267261505, 45.77911131083965, 53.4355940669775, 58.40386167168617, 53.355479165911674, 53.9882630109787, 54.961903765797615, 56.04383870959282, 55.695587396621704, 51.22695118188858, 51.16431154310703, 45.01265063881874, 45.82104966044426, 47.05301575362682, 49.54865723848343, 50.288804322481155, 53.74780811369419, 55.08888155221939, 56.43540009856224, 57.72209845483303, 59.413858875632286, 57.54657067358494, 57.39652432501316, 57.1709456294775, 59.032074362039566, 55.61661623418331, 51.07159651815891, 54.91094470024109, 45.32207563519478, 51.88761793076992, 53.43394495546818, 47.20978394150734, 46.47963412106037, 46.080229952931404, 54.74872000515461, 61.79610304534435, 56.731092631816864, 55.19679956138134, 56.03899396955967, 55.269273072481155, 52.114169374108315, 52.955018654465675, 47.6498307287693, 42.98724912106991, 43.65099370479584, 41.89128153026104, 42.18785561621189, 40.13763003051281, 43.92097681760788, 50.82600049674511, 53.34988206624985, 55.067678689956665, 53.66921693086624, 53.837566897273064, 53.388005420565605, 53.77686895430088, 55.588003769516945, 46.56717002391815, 41.56321853399277, 46.946530267596245, 48.57133828103542, 58.87438282370567, 53.744209706783295, 51.36282429099083, 51.635623052716255, 42.06089302897453, 49.65306043624878, 52.67218463122845, 53.98923955857754, 56.81821055710316, 60.15061654150486, 51.886952966451645, 42.72318609058857, 59.41303052008152, 60.16121797263622, 59.944439604878426, 52.37150676548481, 46.6118860244751, 44.08848702907562, 51.541802287101746, 56.56458176672459, 61.633939146995544, 58.700754940509796, 61.668034717440605, 59.94977831840515, 66.13719910383224, 64.60277304053307, 64.11734148859978, 52.86505468189716, 36.038018614053726, 1.6052334825508296, 3.5744097735732794, 0.14293513406300917, 17.08767358213663, 50.490166917443275, 63.35216134786606, 69.25829842686653, 63.00749324262142, 64.82400476932526, 59.36897948384285, 68.25444549322128, 53.967455327510834, 45.667138919234276, 37.25152149796486, 27.932947129011154, 40.66674783825874, 42.32467867434025, 3.3868088526651263, 0.43921483971644193, 0.1138884165266063, 0.1839874780853279, 0.10041091081802733, 0.04028046962048393, 0.027222609460295644, 0.08231384010287002, 0.052174966913298704, 0.10482498997589573, 0.17256652296055108, 0.22650930419331416, 0.15390637738164514, 0.21668678673449904, 0.18936246779048815, 0.21411221707239747, 0.2095472370274365, 0.2207602869020775, 0.4387184022925794, 0.44034976162947714, 1.1306768283247948, 57.65994518995285, 77.42979794740677, 57.74023488163948, 35.7335789501667, 61.26931071281433, 38.8847840577364, 32.36512430012226, 79.18403461575508, 67.56600603461266, 63.67107443511486, 66.91855117678642, 64.50424432754517, 64.06852170825005, 50.472604259848595, 4.89706227555871, 8.728468883782625, 2.077635177411139, 23.66510733962059, 56.369013860821724, 52.96726539731026, 63.25986050069332, 55.390817150473595, 67.02119126915932, 66.28893256187439, 65.61483353376389, 64.6954196691513, 63.699797093868256, 60.02428472042084, 59.919767528772354, 50.60159593820572, 49.778100326657295, 49.87434536218643, 50.39125822484493, 52.443816885352135, 52.688835337758064, 58.28668735921383, 60.787766352295876, 59.15859617292881, 62.03570678830147, 45.03920741379261, 52.12910637259483, 52.89897546172142, 55.81420183181763, 65.55969849228859, 63.8012820482254, 58.70782256126404, 55.487510561943054, 56.2510833889246, 52.236408814787865, 46.52179665863514, 54.47389975190163, 61.44974783062935, 59.57175940275192, 56.780786365270615, 57.328637167811394, 58.40789705514908, 60.02121828496456, 55.82302115857601, 52.348958775401115, 47.56499648094177, 49.123007878661156, 50.544412806630135, 52.30399198830128, 53.451959788799286, 56.93535827100277, 56.8793036788702, 60.68511866033077, 60.22133834660053, 61.61127336323261, 59.20366935431957, 58.23981687426567, 60.81312619149685, 60.84488108754158, 56.61505065858364, 53.77207361161709, 57.152786403894424, 46.7877633869648, 50.3825718909502, 54.987689182162285, 50.21718196570873, 47.4982188642025, 46.214020773768425, 56.17466188967228, 61.35439194738865, 59.511194452643394, 56.95470683276653, 58.907064869999886, 59.97312046587467, 57.80417785048485, 55.54897226393223, 50.44957369565964, 45.974515825510025, 46.413350477814674, 45.2777624130249, 47.07076460123062, 43.14892664551735, 45.42341999709606, 53.412871286273, 57.19266526401043, 58.21004167199135, 56.289214342832565, 55.721065029501915, 56.33964903652668, 56.367634534835815, 58.22092428803444, 49.79098163545132, 44.309247583150864, 48.38028833270073, 50.47899551689625, 58.59973356127739, 56.89498543739319, 54.11348909139633, 53.61115224659443, 44.988848716020584, 50.8124428242445, 53.09214949607849, 54.879015013575554, 59.04074169695377, 64.03961285948753, 53.60815800726414, 45.001859217882156, 62.294545099139214, 63.03299367427826, 60.702776312828064, 55.99562309682369, 48.52696046233177, 45.95193363726139, 53.230693861842155, 59.84919011592865, 64.1045893728733, 60.702407732605934, 63.51969055831432, 61.80865757167339, 66.9379985332489, 66.54123902320862, 65.0153549015522, 56.684153750538826, 45.90110756456852, 12.827475182712078, 4.871795531362295, 0.32910265610553324, 15.938907824456692, 61.94568581879139, 65.55179491639137, 77.76183933019638, 69.01727735996246, 71.01552173495293, 65.96131414175034, 77.09632024168968, 57.76095896959305, 55.763185769319534, 39.743762165308, 46.38160698115826, 55.70214204490185, 57.998153641819954, 8.07301925495267, 0.9801680920645595, 0.3231772006256506, 0.5876888742204756, 0.23849323770264164, 0.14899058412993327, 0.10258043854264542, 0.29158720979467034, 0.120680106774671], [0.025468391286267433, 0.11382258060621098, 0.023732849258522037, 0.0595729175984161, 0.06287397933192551, 0.07160559907788411, 0.17615323362406343, 0.0451405350031564, 0.07871544061345048, 0.059362771062296815, 0.5501164903398603, 0.4659201926551759, 18.46113458275795, 59.826205149292946, 40.947545170784, 35.66332831978798, 33.56993705034256, 53.81229445338249, 22.166484855115414, 60.2974596619606, 60.069988667964935, 48.04920069873333, 47.748180851340294, 54.52497661113739, 53.1984031945467, 50.40187105536461, 11.376078464090824, 1.4372151670977473, 1.1960328463464975, 6.159366890788078, 38.6830984801054, 33.65748055279255, 51.97166562080383, 56.57069943845272, 57.41958908736706, 59.020754769444466, 58.478793650865555, 59.62524153292179, 60.059679821133614, 56.451526433229446, 50.01275293529034, 43.984429612755775, 45.555865690112114, 45.74360601603985, 48.86525630950928, 49.58367615938187, 49.417564272880554, 51.63865149021149, 56.3104248046875, 54.23455819487572, 61.72263018786907, 56.101588010787964, 49.00022506713867, 54.95311863720417, 54.12601321935654, 58.10142070055008, 55.31480222940445, 56.96438491344452, 49.854385033249855, 52.140589356422424, 46.99377693235874, 43.436894193291664, 44.740091264247894, 53.49002994596958, 53.41875337064266, 52.92763352394104, 52.644187733531, 50.172944739460945, 51.81516721844673, 49.18215170502663, 45.931931510567665, 41.98901608586311, 45.33874914050102, 43.44694845378399, 50.279225036501884, 52.495912089943886, 51.861296743154526, 52.40954652428627, 52.32032351195812, 55.149777084589005, 54.24328252673149, 54.05414767563343, 55.06049707531929, 56.54604256153107, 53.61540801823139, 52.891235277056694, 52.00058966875076, 53.34883712232113, 43.254234194755554, 48.22049930691719, 51.51327721774578, 44.550116658210754, 42.398071736097336, 46.0203717648983, 52.72712588310242, 56.918281987309456, 53.601424768567085, 53.336632177233696, 54.408915638923645, 54.55741547048092, 53.88728342950344, 49.39326457679272, 44.205539748072624, 43.77249598503113, 41.03660859167576, 40.04404865205288, 40.24624340236187, 39.72894296050072, 42.02022761106491, 48.215958550572395, 48.78650553524494, 50.58209538459778, 49.54049527645111, 51.23872295022011, 52.88981795310974, 51.540061980485916, 49.44622613489628, 41.93467140197754, 42.226206958293915, 47.52167500555515, 46.20592340826988, 58.19235362112522, 53.71247760951519, 56.468496322631836, 46.81902430951595, 43.13058502972126, 51.08391925692558, 52.209928035736084, 53.24886068701744, 52.465118542313576, 52.748682126402855, 54.42760303616524, 56.704125478863716, 61.03459730744362, 54.14515659213066, 55.83137311041355, 50.733152478933334, 46.91462717950344, 39.487112537026405, 43.681160286068916, 49.00863781571388, 58.005631640553474, 60.21667219698429, 60.63958190381527, 51.924050375819206, 59.44818623363972, 57.58919678628445, 59.461785703897476, 45.315528586506844, 26.90097950398922, 2.047326103784144, 0.7504767109639943, 1.555601020809263, 33.41478377580643, 67.02120646834373, 53.69975969195366, 57.90511943399906, 52.482757195830345, 53.92374627292156, 58.58117915689945, 55.098514035344124, 45.37782624363899, 41.03717476129532, 25.738057605922222, 33.694828748703, 25.77581997960806, 27.98685483634472, 1.0143585386686027, 0.1239499871735461, 0.12131597148254514, 0.026791043164848816, 0.10778382886201143, 0.04770667386765126, 0.05990525874949526, 0.023776394773449283, 0.06721068217302673, 0.12107125570764765, 0.0870757490338292, 0.06279708541114815, 0.0820230518002063, 0.09139133777352981, 0.06863030677777715, 0.02527571119571803, 0.10079116502311081, 0.07304644910618663, 0.03348951038788073, 0.5526881210971624, 0.367754211765714, 23.33217680454254, 73.08753535151482, 43.13565395772457, 34.72996920347214, 51.78077906370163, 54.10185031592846, 24.545765183866024, 67.72771775722504, 66.978390365839, 50.07544957101345, 54.0112479776144, 61.90757006406784, 58.26690562069416, 54.567427933216095, 15.527904778718948, 0.9865684329997748, 1.0410522250458598, 6.133320238441229, 44.92466256022453, 39.771808460354805, 58.52459639310837, 57.207556664943695, 62.82769829034805, 61.94218620657921, 63.237190917134285, 61.5906822681427, 61.8661180883646, 59.236624985933304, 52.35535383224487, 47.05795168876648, 46.927253901958466, 48.13761815428734, 51.88525825738907, 51.34567581117153, 52.19186380505562, 55.198707059025764, 58.26069675385952, 55.9851698577404, 62.069061398506165, 58.86461354792118, 53.267593681812286, 57.943881154060364, 57.03406557440758, 61.10505312681198, 57.92598031461239, 56.51853583753109, 51.97382390499115, 54.62115325033665, 49.4476168602705, 44.660101756453514, 47.041053995490074, 55.89387595653534, 56.48188680410385, 55.870985984802246, 54.10180851817131, 54.269242733716965, 53.15643824636936, 52.28231035172939, 48.19654539227486, 45.35096928477287, 46.24158829450607, 47.02747732400894, 51.900202855467796, 53.72559450566769, 54.06518988311291, 55.486165434122086, 54.5164954662323, 57.11674913764, 57.2519800812006, 56.79726228117943, 55.68227671086788, 58.95577445626259, 55.61764217913151, 55.492123514413834, 51.34159862995148, 54.500019550323486, 44.102637469768524, 49.24133352935314, 51.742838099598885, 47.751817256212234, 44.73963528871536, 45.20575247704983, 52.77245745062828, 59.72812481224537, 56.618269085884094, 56.42683915793896, 55.547718331217766, 58.79195764660835, 55.150867626070976, 52.185335755348206, 47.068211138248444, 46.94507494568825, 43.56479912996292, 43.15026797354221, 41.84969276189804, 40.83612374961376, 44.058476239442825, 51.7203851044178, 53.65397594869137, 54.229892045259476, 54.143496081233025, 55.628615990281105, 53.929312974214554, 54.55348268151283, 50.45838162302971, 45.110506787896156, 43.72314803302288, 49.80860888957977, 48.37549299001694, 58.66023011505604, 54.183602929115295, 59.14441913366318, 47.381318137049675, 43.58996897935867, 50.140342488884926, 54.47955384850502, 54.72345136106014, 54.37785230576992, 53.439568653702736, 56.91627949476242, 58.96413780748844, 61.51541590690613, 57.08508923649788, 58.736271634697914, 51.48821756243706, 49.86092068254948, 41.80061839520931, 46.502763479948044, 52.32183963060379, 60.06170891225338, 60.94969846308231, 63.39628838002682, 54.152516797184944, 60.492522194981575, 55.65839119255543, 61.377103328704834, 46.19817942380905, 33.68660219013691, 1.4007440116256475, 4.025653135031462, 2.69610732793808, 40.53633503615856, 67.72484511137009, 56.87883250415325, 64.257652759552, 58.42657685279846, 60.32083980739117, 64.67806220054626, 62.659093737602234, 50.34152269363403, 47.21921503543854, 36.44278809428215, 28.801031447947025, 33.18269602954388, 39.98501881957054, 1.6177734034135938, 0.08232799285906367, 0.10226944898022339, 0.025649928029451985, 0.0889647968870122, 0.10377797545515932, 0.1055006412207149, 0.02343876210943563, 0.02355679142056033, 0.17939226294402033, 0.16463430016301572, 0.19824435759801418, 0.21420036937342957, 0.22810789028881118, 0.1355901875649579, 0.1768689014716074, 0.16998876206343994, 0.14880007482133806, 0.21701224817661569, 0.8075571293011308, 0.7621175644453615, 29.31528825312853, 85.18512859940529, 58.00742134451866, 43.411332964897156, 57.71147422492504, 65.25867864489555, 29.761025235056877, 71.52496039867401, 72.31293171644211, 58.86844754219055, 62.14805155992508, 68.45660224556923, 63.09249848127365, 62.96385258436203, 18.59303120523691, 3.4520964743569493, 1.8016011267900467, 8.052474707365036, 53.545780554413795, 44.78112906217575, 59.955835193395615, 58.52237731218338, 64.53477188944817, 64.03189167380333, 66.26155883073807, 64.4335225224495, 65.92365816235542, 62.48669698834419, 56.29171460866928, 48.336130902171135, 50.123619586229324, 50.31848452985287, 53.95263612270355, 53.79402883350849, 54.88770894706249, 56.85650870203972, 62.0467983931303, 57.53083571791649, 66.09288588166237, 57.183272168040276, 53.80949780344963, 61.084389835596085, 56.93937465548515, 62.25269414484501, 59.89915743470192, 59.57539580762386, 54.39743645489216, 58.337775617837906, 53.376609832048416, 47.63460494577885, 49.37896214425564, 60.206796526908875, 58.72655175626278, 58.99894393980503, 56.64138704538345, 57.00752779841423, 57.170444056391716, 56.072853952646255, 50.19363462924957, 47.023278549313545, 49.172511622309685, 49.12471018731594, 55.71090057492256, 55.868660509586334, 56.28013662993908, 59.50799502432346, 57.95520454645157, 59.426523596048355, 59.278996512293816, 59.50503118336201, 59.10877704620361, 62.24001802504063, 58.653265088796616, 57.85965107381344, 53.9190611243248, 56.95400387048721, 45.464138612151146, 52.034411653876305, 53.617630898952484, 47.83570535480976, 43.72193969786167, 47.786752581596375, 53.31230968236923, 61.16229705512524, 58.65495979785919, 58.49887177348137, 58.89435835182667, 62.91162818670273, 57.615719363093376, 53.86425666511059, 47.95255288481712, 48.10235604643822, 44.86328825354576, 44.629137217998505, 44.86173793673515, 43.81351098418236, 47.53566965460777, 54.69396874308586, 54.92516353726387, 54.99708607792854, 55.24584732949734, 57.68165722489357, 57.08993777632713, 57.16763220727444, 53.082376420497894, 46.50996409356594, 47.50275582075119, 52.75599293410778, 49.894807264208794, 61.379728987812996, 58.690275102853775, 59.122429713606834, 50.70381045341492, 45.510488525033, 51.355866864323616, 54.454106613993645, 56.02727919816971, 56.19825102388859, 55.6442179530859, 59.24892872571945, 61.28722295165062, 63.60747344791889, 58.713822439312935, 60.763094276189804, 54.594087302684784, 52.46609129011631, 43.23666773736477, 49.15024861693382, 53.657103180885315, 64.11459803581238, 63.13171997666359, 65.77030599117279, 53.08239921927452, 62.80465632677078, 57.82635346055031, 64.25145149230957, 47.07056701183319, 45.390794947743416, 3.520114724524319, 3.719113846309483, 2.5805840268731117, 44.06438112258911, 76.03252932429314, 63.698622956871986, 70.25623127818108, 62.700408920645714, 64.90958377718925, 68.14050480723381, 65.47650575637817, 56.58901825547218, 55.936464071273804, 40.853363424539566, 48.49059261381626, 43.595159500837326, 59.84960809350014, 2.4628865299746394, 0.2256045668036677, 0.2216734699322842, 0.11201541390619241, 0.2016784975421615, 0.2850750123616308, 0.23268674849532545, 0.09766062285052612, 0.2448508160887286], [0.03869618842145428, 0.05668362537107896, 0.032395970629295334, 0.018022360563918483, 0.01295804593610228, 0.07006729763816111, 0.060800440987804905, 0.03176741236529779, 0.059144123224541545, 0.07221898413263261, 0.28526325069833547, 0.1201361273706425, 4.521830510348082, 49.42968562245369, 50.86141839623451, 38.26069034636021, 25.686627365648746, 50.800218880176544, 24.57631554454565, 44.258201122283936, 59.400779977440834, 60.82806698977947, 56.92870482802391, 55.72404786944389, 51.4302858710289, 57.857393994927406, 27.045081071555614, 0.4339358542347327, 0.3867185488343239, 0.13147488964023069, 15.875920504331589, 36.82352766394615, 51.90075382590294, 60.900563299655914, 61.192095056176186, 59.36946965754032, 54.254115745425224, 55.355418249964714, 50.35194933414459, 46.22520737349987, 46.07028588652611, 45.82006551325321, 44.751334860920906, 46.67987957596779, 46.02089613676071, 45.61331860721111, 48.038109093904495, 53.96649017930031, 54.15519945323467, 55.35188063979149, 56.261422634124756, 59.71328280866146, 62.401805743575096, 60.08931443095207, 59.37443219125271, 59.91170056164265, 53.95856760442257, 53.88393960893154, 49.8179791867733, 49.26827788352966, 50.03535412251949, 46.867448911070824, 43.12308423221111, 47.18258120119572, 55.41033670306206, 55.29573105275631, 54.0710985660553, 52.67191104590893, 49.33900348842144, 47.39563196897507, 42.407871410250664, 44.01066340506077, 46.777872517704964, 45.28864502906799, 52.4395839124918, 53.28676365315914, 54.51978228986263, 54.15820509195328, 52.029456719756126, 56.245900467038155, 54.521370604634285, 58.17160293459892, 55.90528294444084, 53.9576480537653, 55.54606541991234, 47.59096808731556, 49.955676198005676, 52.188018411397934, 45.04696659743786, 48.531698808074, 51.23532593250275, 47.479151487350464, 43.53525571525097, 45.24519056081772, 50.89534677565098, 56.57490961253643, 55.28394788503647, 53.92548657953739, 52.56978012621403, 53.452313169837, 53.22092078626156, 53.41860517859459, 51.1456735432148, 49.92263317108154, 44.27037946879864, 41.18430286645889, 39.93196226656437, 39.74674880504608, 41.17927573621273, 47.77007907629013, 50.53489811718464, 49.65563289821148, 52.970058247447014, 51.92814655601978, 51.00890748202801, 52.53201775252819, 46.46324560046196, 39.28232632577419, 45.93088276684284, 47.01313689351082, 44.81402009725571, 52.501193806529045, 51.93292669951916, 55.33845596015453, 46.288709565997124, 49.53048661351204, 54.25106830894947, 53.01975958049297, 53.01472865045071, 51.225153878331184, 52.514561489224434, 50.367619693279266, 53.17102566361427, 49.47991132736206, 48.7191541492939, 47.45953693985939, 48.084432408213615, 45.97658671438694, 44.155564829707146, 43.467250764369965, 47.5591865926981, 51.970449686050415, 54.709080532193184, 61.54119372367859, 61.887381747365, 60.97570426762104, 55.267342776060104, 58.76128189265728, 39.42136466503143, 19.15243148803711, 0.6748145178426057, 1.0683960327878594, 7.602215018123388, 62.80379757285118, 56.38564556837082, 53.80523443222046, 52.238133922219276, 57.89251171052456, 52.696047350764275, 57.799089923501015, 33.99571940302849, 54.92410719394684, 33.011329025030136, 22.329091429710388, 37.303141728043556, 35.213880836963654, 20.19550211727619, 0.5182413663715124, 0.14516628230921924, 0.07203381086583249, 0.05543933315493632, 0.07000877187238075, 0.21633264870615676, 0.034731264458969235, 0.06242397066671401, 0.036376932403072715, 0.07057003589579836, 0.028841838393418584, 0.0498912412149366, 0.040966017404571176, 0.05612761204247363, 0.0595033783611143, 0.06512743653729558, 0.04894151854387019, 0.09600630146451294, 0.07693918436416425, 0.4627031012205407, 0.09426335280295461, 6.686253743246198, 63.54644872248173, 54.48490396142006, 35.04672780632973, 43.462577015161514, 56.57604955136776, 25.57105466723442, 52.55615405738354, 66.46116971969604, 66.2945182621479, 64.17276531457901, 62.55661703646183, 57.679715529084206, 63.208240270614624, 30.311224311590195, 0.2908767369808629, 1.9932604674249887, 0.2784676419105381, 19.456162489950657, 42.501274198293686, 54.62579280138016, 61.01773381233215, 64.14658471941948, 62.37337186932564, 58.61204870045185, 57.23389685153961, 53.25733043253422, 48.90178754925728, 48.33118736743927, 47.04464100301266, 46.6191778331995, 49.701583832502365, 47.88233645260334, 48.26541669666767, 51.572466641664505, 53.402832224965096, 56.72641508281231, 58.10307361185551, 58.01494874060154, 59.51130084693432, 64.43593919277191, 61.39624670147896, 61.44810251891613, 61.173153072595596, 58.103913366794586, 55.75172558426857, 52.48485088348389, 51.48057617247105, 50.96884623169899, 47.59579382836819, 45.00625558197498, 50.258550345897675, 57.71652415394783, 56.60912297666073, 55.32440431416035, 55.77505253255367, 51.595345214009285, 50.49292556941509, 44.97919723391533, 45.04526048898697, 49.91149976849556, 47.592909783124924, 55.083250254392624, 53.5565909743309, 57.27038249373436, 55.676835402846336, 56.15479275584221, 57.97128148376942, 56.21783137321472, 59.68249686062336, 56.2210687994957, 56.53557792305946, 56.88291348516941, 49.5199915766716, 50.914235562086105, 54.16650764644146, 46.21326081454754, 47.97579623758793, 52.24490515887737, 48.44224400818348, 45.01972205936909, 46.43645703792572, 54.45375323295593, 59.378535971045494, 56.881743147969246, 55.578124299645424, 57.77910679578781, 57.800659239292145, 56.29000090062618, 57.0469468832016, 53.269831761717796, 53.4957904368639, 46.494343131780624, 44.195173904299736, 45.366449654102325, 41.44511327147484, 43.09266686439514, 48.74534614384174, 53.1839145720005, 52.91401505470276, 55.59575915336609, 54.81883764266968, 53.00557114183903, 54.35721181333065, 47.49167941510677, 41.51114232838154, 47.644507214426994, 49.75284308195114, 46.4465568959713, 55.63012830913067, 55.100109949707985, 56.33502848446369, 47.88980305194855, 48.907882422208786, 54.12309877574444, 54.52664852142334, 56.287071257829666, 55.13559244573116, 55.00609539449215, 52.69439063966274, 54.50099229812622, 51.74297109246254, 50.66547051072121, 48.97713750600815, 48.7446241825819, 47.9560486972332, 46.94450497627258, 45.181661769747734, 49.29958440363407, 53.87184485793114, 58.3289410918951, 61.55623331665993, 63.33483807742596, 59.268284887075424, 58.694888055324554, 58.529619723558426, 42.97084920108318, 23.122642748057842, 1.2256595003418624, 1.5563102765008807, 10.645197182893753, 71.50569543242455, 57.80092142522335, 60.15282802283764, 57.32577972114086, 64.26761582493782, 57.980636581778526, 63.70578937232494, 39.34367783367634, 60.342928022146225, 41.220267936587334, 29.574880823493004, 39.4334252178669, 45.580134987831116, 29.462650045752525, 0.40850218618288636, 0.11989510749117471, 0.10184431710513309, 0.04464201585506089, 0.06908309849677607, 0.08027140516787767, 0.06374034768668935, 0.056530049041612074, 0.0362944055814296, 0.1508582432870753, 0.1760691186063923, 0.14856922236504033, 0.0739808204525616, 0.21731795364758, 0.07888163716415875, 0.1739244899363257, 0.18045957520371303, 0.2153695933520794, 0.2981399284908548, 0.7729536923579872, 0.36797525302972645, 9.878225438296795, 75.91529041528702, 71.95690602064133, 47.05472566187382, 42.64701917767525, 68.23447376489639, 31.28803789615631, 55.90350463986397, 77.05747112631798, 70.77219799160957, 70.09162411093712, 68.0582620203495, 63.23040448129177, 68.84108081459999, 36.9469640403986, 0.7451211952138692, 2.4441993702203035, 0.265224669710733, 28.064938746392727, 51.4034479111433, 54.73656065762043, 66.13871142268181, 66.53308466076851, 65.98027512431145, 60.78952945768833, 61.18641436100006, 54.93807904422283, 52.4166027456522, 51.062302216887474, 52.35029250383377, 47.61608473956585, 53.322489336133, 50.89828781783581, 51.88487447798252, 53.333390951156616, 56.365791633725166, 58.462165743112564, 59.77421633899212, 61.58385023474693, 63.569418489933014, 64.18820768594742, 60.851960107684135, 61.78120404481888, 63.07755388319492, 60.247803926467896, 57.978269308805466, 55.03813907504082, 54.65008869767189, 53.455915376544, 50.87646558880806, 47.562811598181725, 51.872760728001595, 60.77532202005386, 62.14091174304485, 59.09305348992348, 58.678594529628754, 54.70862455666065, 53.2830398529768, 47.30692192912102, 49.646171405911446, 53.12387399375439, 50.61187818646431, 57.715258821845055, 56.25366345047951, 60.173217728734016, 60.05995340645313, 59.35433126986027, 60.614066272974014, 59.4550334662199, 62.23914787173271, 60.19432559609413, 58.31288315355778, 58.80559131503105, 50.470932349562645, 53.99745091795921, 57.58939817547798, 48.43283571302891, 48.188638016581535, 53.69308724999428, 49.14762295782566, 45.738457292318344, 49.63351048529148, 55.645278096199036, 59.787477627396584, 58.92812334001064, 59.0463387966156, 60.102754309773445, 59.529802054166794, 60.32560095191002, 59.11456033587456, 56.23309135437012, 56.07260316610336, 49.17239762842655, 46.56264826655388, 47.60317303240299, 43.90522286295891, 47.093209996819496, 52.384589463472366, 56.641105860471725, 54.81389790773392, 60.10626532137394, 58.5740165412426, 55.050237625837326, 56.767323687672615, 49.23420511186123, 42.89847828447819, 50.80529920756817, 51.849015802145004, 49.000141471624374, 58.153812289237976, 57.7319361269474, 58.36253508925438, 51.435639783740044, 51.07500873506069, 55.77947549521923, 57.48147256672382, 58.45848374068737, 56.38148099184036, 56.70433446764946, 54.164075776934624, 57.493753507733345, 53.48434545099735, 54.510377794504166, 51.390201821923256, 51.98753736913204, 49.622202292084694, 49.07033130526543, 46.97279065847397, 52.97138437628746, 55.516332015395164, 60.2536366134882, 65.27151435613632, 65.97906678915024, 59.11120131611824, 56.741048097610474, 57.146277353167534, 48.395840898156166, 30.036227367818356, 2.343199602328241, 4.531322875991464, 10.469697900116444, 74.14906919002533, 66.1381946504116, 65.83417296409607, 63.10999274253845, 70.55460646748543, 61.46044045686722, 70.90088948607445, 43.283561021089554, 68.87063562870026, 46.1582587659359, 36.08777314424515, 48.54497529566288, 57.77342990040779, 43.69422398507595, 0.5763816309627146, 0.17353699979139492, 0.17786585813155398, 0.1733839392545633, 0.17259043495869264, 0.2543076773872599, 0.1024861412588507, 0.14771306596230716, 0.08847859367961064], [0.01891481540951645, 0.059440199329401366, 0.04572226374875754, 0.037883080294704996, 0.07722801339696161, 0.019576996674004477, 0.03890408253937494, 0.13271219824673608, 0.03193301890860312, 0.04376792174298316, 0.08007117372471839, 0.26138548040762544, 0.7180529914330691, 32.41276614367962, 53.49967762827873, 43.487625271081924, 26.68767984956503, 47.372134029865265, 39.75852057337761, 32.203013598918915, 64.04529735445976, 48.541696071624756, 56.32033087313175, 54.21328693628311, 58.69896903634071, 47.90143422782421, 52.28204816579819, 2.176188351586461, 1.553977676667273, 0.20034413086250424, 2.1397829800844193, 26.805557124316692, 55.58341361582279, 62.49684624373913, 60.495094656944275, 56.320273876190186, 50.962796956300735, 49.18983109295368, 50.371168702840805, 51.74375385046005, 50.95763683319092, 51.33985452353954, 49.93616044521332, 51.33190535008907, 51.056678518652916, 46.65497571229935, 50.300431698560715, 51.76201947033405, 54.9391695857048, 53.9227469265461, 59.29494425654411, 58.23621466755867, 56.73684932291508, 59.449428766965866, 56.79017946124077, 54.66359317302704, 54.76860053837299, 52.369599267840385, 51.25891126692295, 49.339873641729355, 50.113398134708405, 46.85525916516781, 43.269592970609665, 45.271222963929176, 50.227525010704994, 54.54492174088955, 53.2292765378952, 49.52816113829613, 51.263030245900154, 45.69224797189236, 40.888811722397804, 44.09102149307728, 45.477445498108864, 49.980241879820824, 53.286011293530464, 53.234603852033615, 52.963507398962975, 55.58361500501633, 53.0724361538887, 53.9356130361557, 57.49558500945568, 54.30696330964565, 53.77247639000416, 57.37208403646946, 51.19705818593502, 44.03691619634628, 47.84444488584995, 51.46267533302307, 45.170668959617615, 49.829378575086594, 49.90807235240936, 46.522788405418396, 42.61863850057125, 44.12308797240257, 48.986849784851074, 58.32018256187439, 55.551689118146896, 54.667328372597694, 56.04385010898113, 54.42506097257137, 54.68663513660431, 53.9248064160347, 54.53648619353771, 51.96077160537243, 49.857618659734726, 43.384278416633606, 43.50985787808895, 41.91908463835716, 40.360871851444244, 41.26176930963993, 46.32277473807335, 53.51383186876774, 49.92463566362858, 51.23830497264862, 51.0263067483902, 51.49255312979221, 43.942616656422615, 40.744799450039864, 45.41979119181633, 49.75758142769337, 45.97495660185814, 51.76202706992626, 52.05367662012577, 53.9564511179924, 53.19747984409332, 48.015325516462326, 51.61387301981449, 53.2087766379118, 51.667324751615524, 46.372669860720634, 45.356649979949, 41.71850100159645, 44.14987653493881, 43.25590990483761, 44.4376464933157, 42.64594383537769, 44.335599169135094, 46.553657948970795, 47.11323872208595, 46.7301394790411, 46.73998475074768, 46.06034941971302, 56.21167190372944, 56.00379265844822, 61.36540375649929, 60.65633900463581, 57.26288169622421, 53.31281125545502, 29.88692007958889, 19.646684266626835, 0.5360402050428092, 0.49171323829796165, 16.356429420411587, 55.97755506634712, 54.502067640423775, 55.482589825987816, 52.981309443712234, 57.812374010682106, 52.71966688334942, 54.172651916742325, 45.02175115048885, 57.16976009309292, 21.843998059630394, 46.6317817568779, 45.96833735704422, 36.28434419631958, 11.236416958272457, 0.7864451059140265, 0.17219464760273695, 0.2685591095359996, 0.18343943171203136, 0.15322982071666047, 0.0437645709462231, 0.06731467932695523, 0.0337026032502763, 0.08521295094396919, 0.08754284936003387, 0.0308220665101544, 0.01955242045369232, 0.06254841398913413, 0.05115343774377834, 0.04214181681163609, 0.020694767554232385, 0.07066948368446901, 0.0359063217183575, 0.06037870072759688, 0.22851596761029214, 0.21391124348156154, 1.1547857034020126, 41.08976773917675, 62.878714352846146, 39.32689793407917, 34.064951688051224, 59.61758874356747, 38.11232350766659, 34.16918769478798, 71.54289543628693, 58.9332340657711, 64.37279418110847, 58.37213337421417, 65.36375820636749, 54.980667158961296, 58.58909793198109, 3.7241253023967147, 2.0745630422607064, 0.9578325343318284, 3.250508029013872, 33.7129195779562, 56.59586548805237, 65.19181743264198, 63.9033217728138, 59.9785465747118, 54.99680869281292, 51.092126816511154, 54.01187114417553, 53.01449306309223, 53.96917283535004, 52.335271909832954, 52.0031925290823, 53.440416008234024, 53.70951756834984, 50.89441202580929, 51.3155510276556, 52.714312970638275, 56.51424206793308, 57.846682369709015, 60.658691078424454, 59.00216616690159, 56.86994098126888, 60.8730261772871, 60.55610038340092, 56.75092376768589, 54.640205428004265, 55.70457771420479, 52.67701417207718, 51.76748737692833, 53.66225950419903, 48.157578483223915, 45.76152205467224, 46.27257563173771, 52.19461865723133, 56.37015759944916, 56.5362124890089, 54.549633488059044, 53.90156686306, 47.49449886381626, 43.15779156982899, 46.55494228005409, 49.223550483584404, 50.54011143743992, 56.24341160058975, 55.866490826010704, 55.26190906763077, 57.61484540998936, 55.71138694882393, 56.90740317106247, 57.8889475017786, 55.61657823622227, 56.85240872204304, 58.27993892133236, 55.13871967792511, 44.5830836892128, 49.00434024631977, 52.56678968667984, 47.204604819417, 48.66499945521355, 51.03896006941795, 47.72947445511818, 44.1682181507349, 46.308905482292175, 49.71803694963455, 59.71577167510986, 58.17636787891388, 56.1566736549139, 58.5927951335907, 57.167408019304276, 57.16083437204361, 56.310394406318665, 58.63851048052311, 52.95299336314201, 51.52121119201183, 44.596071392297745, 45.46149015426636, 43.27867068350315, 42.442806735634804, 42.890612706542015, 49.5319951325655, 55.51541246473789, 53.8057816028595, 53.07324931025505, 55.134737491607666, 54.23004783689976, 46.20005652308464, 42.514068111777306, 48.09206239879131, 51.36358045041561, 48.51193606853485, 52.103013172745705, 55.11609569191933, 56.88458539545536, 56.944245994091034, 49.25442762672901, 54.52580876648426, 54.23371843993664, 52.795408219099045, 48.667784705758095, 46.52301639318466, 44.09947983920574, 46.173408553004265, 44.77850340306759, 47.67134137451649, 44.936772510409355, 47.488430589437485, 47.064954712986946, 49.47324648499489, 48.59448663890362, 49.053445011377335, 48.883065953850746, 59.58531327545643, 58.5907356441021, 62.56811901926994, 62.01884709298611, 57.29695066809654, 53.5394386947155, 33.018058463931084, 23.775261528789997, 0.31742454681079835, 0.8776956063229591, 20.836618915200233, 61.44134268164635, 60.10351046919823, 60.25244727730751, 60.71465067565441, 64.77403745055199, 58.20561870932579, 58.61329883337021, 50.064099580049515, 64.66640442609787, 31.06030661612749, 51.51812955737114, 50.4051198810339, 47.221373319625854, 15.767347030341625, 0.7231023861095309, 0.14656241051852703, 0.19721036776900291, 0.024595488321210723, 0.14451446884777397, 0.06587379961274564, 0.021363630003179424, 0.005185627478567767, 0.06818625013693236, 0.17488226119894534, 0.14597795438021421, 0.1691543060587719, 0.13889455556636676, 0.12034585830406286, 0.1327613284229301, 0.15463393443496898, 0.20295188936870545, 0.13625601277453825, 0.172388689534273, 0.3956804273184389, 0.2532995736692101, 1.8730273190885782, 51.43301412463188, 78.39431539177895, 54.140821024775505, 36.44864358007908, 67.41354301571846, 46.8093728274107, 41.63081310689449, 80.46485468745232, 60.295867547392845, 70.66328063607216, 64.24500703811646, 72.87188932299614, 60.20314872264862, 69.4839759171009, 4.753746315836906, 6.053692661225796, 0.6815583840943873, 4.05649465508759, 43.42043727636337, 58.301757350564, 66.99098289012909, 65.83879351615906, 62.98889324069023, 56.672397181391716, 53.9146039634943, 55.52185691893101, 56.40914350748062, 55.39006479084492, 56.247006207704544, 53.820950388908386, 57.65977039933205, 58.15079525113106, 51.76509730517864, 52.9415787756443, 57.51898415386677, 59.02083836495876, 60.66387020051479, 63.169360756874084, 63.76417323946953, 59.82912339270115, 65.28149262070656, 61.74093000590801, 58.74459698796272, 56.6891922801733, 58.02454702556133, 54.80302669107914, 54.383969977498055, 55.314730033278465, 50.5051951110363, 47.71616756916046, 49.45700615644455, 52.67131067812443, 58.74259449541569, 57.72221624851227, 57.17530019581318, 56.846386045217514, 50.079792737960815, 45.61612665653229, 49.7450041025877, 50.94494171440601, 53.2401629537344, 58.411385267972946, 59.248674139380455, 58.122957944869995, 60.18965184688568, 57.23543956875801, 60.11800669133663, 63.66641208529472, 59.074666276574135, 61.638871282339096, 61.43021307885647, 56.01846747100353, 43.71949262917042, 51.77882596850395, 54.3071722984314, 48.61549571156502, 51.22710317373276, 53.415667936205864, 48.14981169998646, 45.91963157057762, 44.954350367188454, 50.995672792196274, 62.88320951163769, 59.54752430319786, 59.09259371459484, 61.69694356620312, 59.36003856360912, 59.60222236812115, 59.28706347942352, 61.52116119861603, 54.621571227908134, 54.691939651966095, 47.878232672810555, 50.70013985037804, 46.725727915763855, 46.95503041148186, 44.36806842684746, 51.86998687684536, 58.59566017985344, 55.304113402962685, 54.40900303423405, 57.028996646404266, 55.48578165471554, 48.00858847796917, 45.7793240994215, 50.712800770998, 54.149180576205254, 50.130102038383484, 55.13465389609337, 56.02029137313366, 59.00806725025177, 58.93311247229576, 51.222908198833466, 56.87101632356644, 54.727004170417786, 54.947703927755356, 50.12380197644234, 49.37665566802025, 45.69762468338013, 50.40987342596054, 47.394902408123016, 49.837654531002045, 47.619527354836464, 48.892128467559814, 50.38628429174423, 52.503705471754074, 50.33175341784954, 51.46674491465092, 51.512783244252205, 61.719563752412796, 61.89341962337494, 66.05684101581573, 63.35070602595806, 56.25630050897598, 54.25122790038586, 40.50019137561321, 28.902353011071682, 1.4286074414849281, 2.5071425177156925, 20.094216652214527, 71.35517030954361, 62.20083832740784, 68.42903092503548, 63.77359673380852, 69.81809958815575, 64.75656598806381, 66.12757802009583, 53.548448011279106, 75.12699991464615, 36.33505627512932, 61.38653062283993, 56.86271756887436, 60.20457364618778, 25.89201394468546, 0.9241789870429784, 0.3709149593487382, 0.30659869022201747, 0.32858671504072845, 0.40405838401056826, 0.10979510843753815, 0.09436427004402503, 0.21980103134410456, 0.20360778464237228], [0.01335589831796824, 0.10283149225870147, 0.03260081823100336, 0.1206344275851734, 0.03863879814161919, 0.07398534755338915, 0.044651878997683525, 0.037455447381944396, 0.055688338543404825, 0.06236541521502659, 0.0935761611617636, 0.48267664038576186, 0.09538642261759378, 16.166829094290733, 50.25264926254749, 49.54895742237568, 36.011906415224075, 29.61309727281332, 50.517795234918594, 36.061197370290756, 54.044032618403435, 49.81185771524906, 57.113143131136894, 56.31043240427971, 56.78424797952175, 51.41079671680927, 55.36287724971771, 28.370812833309174, 1.4375362498685718, 1.1084082419984043, 1.0369693441316485, 21.750006303191185, 45.362839847803116, 61.072435677051544, 61.09191343188286, 58.93236391246319, 56.80424630641937, 55.40481939911842, 56.49061493575573, 57.478892505168915, 55.949181988835335, 53.214529529213905, 55.85574120283127, 54.208563789725304, 53.99294055998325, 52.658634558320045, 56.69650688767433, 54.31737095117569, 56.52444452047348, 56.52828611433506, 55.55823236703873, 56.37280985713005, 59.605281203985214, 59.28776264190674, 57.64576055109501, 55.76810270547867, 57.89914235472679, 52.33388118445873, 51.218131855130196, 49.78278927505016, 51.470172330737114, 47.96624734997749, 46.21379658579826, 44.437148720026016, 46.453191339969635, 54.01572413742542, 52.437334433197975, 49.771025106310844, 46.99353374540806, 43.87196324765682, 42.67678678035736, 47.05560341477394, 46.06741704046726, 51.54766917228699, 54.62609678506851, 53.62867310643196, 53.211322501301765, 52.78093099594116, 53.59671302139759, 55.65464459359646, 54.6807948499918, 54.342920780181885, 57.37392693758011, 57.50728078186512, 46.431084126234055, 44.129460230469704, 44.081833586096764, 46.617243736982346, 47.774851620197296, 48.52929353713989, 49.151468351483345, 44.76499892771244, 40.366309359669685, 42.68435217440128, 42.282246351242065, 53.29327270388603, 55.014314353466034, 55.41647717356682, 54.07063879072666, 53.55909124016762, 53.801560029387474, 56.138256043195724, 55.342126563191414, 53.5552154481411, 55.27714245021343, 46.1334802955389, 41.6365621984005, 42.546560168266296, 40.22788658738136, 39.209560230374336, 44.1293728351593, 53.63347604870796, 54.95778478682041, 48.169240057468414, 52.37481638789177, 47.263022884726524, 42.68969088792801, 41.633336171507835, 46.66458919644356, 47.270766869187355, 45.71343183517456, 50.34200146794319, 52.23167806863785, 52.87645027041435, 54.98285584151745, 49.580374136567116, 54.109693095088005, 53.6991099268198, 51.54271803796291, 49.034529626369476, 40.7120718061924, 43.496672585606575, 46.76164738833904, 50.2240139991045, 50.65528705716133, 52.64940105378628, 53.717679530382156, 53.769250363111496, 55.10527767241001, 53.89315411448479, 54.55377146601677, 55.43547235429287, 54.03415694832802, 58.769725039601326, 61.985830664634705, 57.335351407527924, 52.655305936932564, 42.189067751169205, 20.744635351002216, 12.7830964140594, 0.12678942934144288, 0.8894093683920801, 29.509205147624016, 60.46239361166954, 51.04070797562599, 57.11530901491642, 50.8090990036726, 44.33906838297844, 56.31517454981804, 55.36309763789177, 60.03349542617798, 50.96042588353157, 27.94246941804886, 46.41298949718475, 40.659554824233055, 51.59101344645023, 6.6888604033738375, 0.6165805051568896, 0.20765511668287218, 0.24906268226914108, 0.11565328823053278, 0.06552349848789163, 0.09630993634345941, 0.09310744295362383, 0.029927695068181492, 0.025910201075021178, 0.02153033492504619, 0.04621910564310383, 0.04116484989935998, 0.027874396946572233, 0.050216862218803726, 0.12552872824016958, 0.054269378160825, 0.012753033206536202, 0.04515496235399041, 0.08990415546577424, 0.04371707349491771, 0.504913047188893, 0.3012244723504409, 22.989136911928654, 65.15714049339294, 50.15833832323551, 41.92750498652458, 46.605289578437805, 52.55848713219166, 38.661055862903595, 61.11062742769718, 61.65003888309002, 66.87017977237701, 64.25193026661873, 62.4097853153944, 56.8432892113924, 61.71684689819813, 31.222236827015877, 0.4435400170041248, 3.033871678635478, 0.8338480966631323, 27.03591976314783, 48.89079853892326, 63.6231742054224, 63.18125031888485, 61.96844659745693, 60.3696595877409, 59.6572358161211, 58.301973938941956, 61.34305715560913, 56.970848366618156, 55.78813523054123, 59.361258298158646, 57.1084313839674, 55.98683416843414, 56.8200496584177, 58.02322469651699, 56.50609910488129, 57.69787855446339, 59.64328296482563, 57.32728064060211, 59.508887976408005, 61.098555475473404, 59.67820689082146, 60.09544350206852, 58.62279072403908, 58.57687018811703, 54.55080382525921, 53.96178983151913, 53.19987751543522, 53.39063107967377, 50.743134543299675, 47.84698694944382, 47.203639671206474, 48.7092100828886, 56.61311276257038, 56.656172052025795, 53.13115820288658, 47.72127829492092, 45.66878043115139, 45.358698070049286, 47.121833860874176, 48.339999094605446, 53.43631982803345, 55.81841580569744, 55.34361228346825, 55.378916189074516, 54.63604085147381, 56.757710203528404, 58.16179946064949, 57.073594853281975, 55.28598077595234, 58.87702748179436, 60.598528906702995, 48.4776771068573, 42.444995418190956, 45.212713703513145, 50.00863015651703, 50.51390044391155, 49.79993015527725, 50.870218724012375, 46.94007061421871, 41.661359667778015, 42.79688313603401, 43.89450363814831, 55.387378334999084, 59.045810624957085, 57.84980960190296, 57.79602348804474, 56.42943061888218, 56.290551871061325, 57.36014507710934, 58.902683705091476, 56.29932560026646, 57.041824758052826, 47.751182690262794, 42.253056317567825, 42.78853498399258, 41.998089998960495, 39.647528529167175, 47.24569961428642, 54.92343083024025, 57.79269486665726, 52.284962609410286, 55.1887059956789, 47.70483277738094, 43.44201631844044, 43.40849071741104, 47.815574035048485, 48.950535133481026, 48.1242922693491, 51.47102728486061, 53.75761918723583, 54.07928712666035, 56.94087937474251, 51.757562309503555, 56.096211299300194, 55.12481242418289, 53.58868405222893, 52.031041234731674, 45.261772871017456, 44.85009916126728, 49.2438717931509, 53.180072978138924, 52.71457515656948, 54.733650013804436, 56.12841077148914, 57.30849824845791, 57.66855552792549, 55.887629091739655, 57.39816963672638, 56.64251558482647, 57.15698517858982, 61.13479793071747, 64.75328296422958, 59.01273339986801, 54.614883586764336, 45.28935179114342, 24.871599599719048, 13.640392161905766, 0.2784429135499522, 1.684999514836818, 33.899683356285095, 64.34697076678276, 56.48609697818756, 63.360509499907494, 57.25974686443806, 50.67188456654549, 62.70765893161297, 60.261642783880234, 64.24737051129341, 56.30187526345253, 33.687540739774704, 51.67307764291763, 44.31506127119064, 63.22374723851681, 8.074028100818396, 0.8874447550624609, 0.2619571122340858, 0.18193395546404645, 0.06676660326775163, 0.02384821797022596, 0.1131597017229069, 0.13155915308743715, 0.04520873466390185, 0.05959185720712412, 0.13310379988979548, 0.261481722118333, 0.11827730719232932, 0.1958780939457938, 0.17887419933686033, 0.20058636786416173, 0.12408109498210251, 0.20116185885854065, 0.2584561344701797, 0.209317393891979, 0.27103835775051266, 0.5867787636816502, 0.6964689027518034, 32.50648811459541, 76.33644461631775, 65.92579364776611, 47.81740553677082, 50.99403887987137, 62.08016440272331, 45.44264696538448, 66.68320700526237, 65.88671654462814, 72.04604923725128, 68.38919386267662, 68.12025189399719, 63.12990367412567, 67.13257849216461, 37.29190193116665, 2.3958042170852423, 2.7683568885549903, 1.5575207490473986, 35.87909214198589, 54.25772175192833, 64.30748328566551, 67.02534064650536, 66.07796788215637, 63.540521040558815, 62.42299720644951, 61.05160139501095, 62.60593459010124, 62.79079847037792, 57.46351093053818, 61.761779487133026, 60.46781212091446, 58.464396223425865, 58.636268600821495, 61.54726579785347, 60.703996047377586, 62.20531828701496, 61.536603569984436, 60.3466784209013, 60.31457394361496, 63.35539497435093, 63.27063292264938, 62.457012981176376, 60.018854811787605, 62.34396144747734, 56.89297154545784, 55.35957522690296, 56.84792876243591, 55.63871584832668, 52.87145733833313, 51.22049532830715, 49.93218965828419, 51.03367455303669, 61.11558996140957, 59.94449660181999, 54.47269141674042, 50.080761685967445, 48.751539811491966, 48.32037314772606, 50.194124802947044, 50.692874640226364, 56.12216770648956, 59.93945047259331, 58.04069235920906, 59.15912054479122, 57.67454020678997, 59.18957971036434, 59.700089916586876, 60.617831870913506, 56.195222586393356, 62.96029217541218, 62.58321560919285, 48.96077178418636, 43.93418110907078, 45.44555000960827, 53.72078016400337, 51.319867596030235, 50.656301602721214, 52.05379821360111, 48.25396031141281, 42.880725637078285, 43.91039438545704, 43.304520696401596, 57.186942771077156, 61.1492295563221, 61.56849525868893, 61.36422961950302, 57.729956433176994, 58.24260212481022, 60.88076636195183, 60.78446052968502, 58.392279893159866, 58.93491357564926, 50.79211391508579, 46.290434673428535, 46.20912283658981, 44.03768755495548, 43.68322737514973, 49.603423699736595, 58.96079778671265, 60.393632501363754, 53.313932195305824, 56.233604326844215, 49.929563999176025, 46.11951604485512, 44.79848273098469, 48.380413725972176, 50.74184641242027, 48.33247929811478, 54.70522753894329, 55.50133801996708, 57.12859310209751, 59.977068454027176, 51.638605892658234, 56.910838186740875, 57.08831526339054, 55.653071478009224, 53.33070449531078, 47.29106917977333, 47.10166834294796, 50.07192336022854, 56.614564284682274, 55.323990136384964, 57.01325409114361, 59.50610652565956, 59.66046944260597, 59.047440737485886, 56.65325380861759, 59.642542004585266, 61.60521648824215, 61.257660537958145, 63.690707981586456, 66.57134100794792, 60.19382022321224, 55.049302875995636, 46.299926564097404, 34.81000430881977, 17.617743238806725, 0.33641159359831363, 3.4535724576562643, 37.31566585600376, 74.22808215022087, 62.11048297584057, 68.83041098713875, 61.37490324676037, 60.17881102859974, 67.75582864880562, 68.07494312524796, 70.78331619501114, 63.938538283109665, 40.53368657827377, 60.63616968691349, 51.33030563592911, 78.54496970772743, 12.383733093738556, 1.1510002752766013, 0.3657464648131281, 0.2773098321631551, 0.2175148157402873, 0.14176653348840773, 0.16550117317819968, 0.2390760908019729, 0.14270981802837923, 0.14183843275532126], [0.020605591089406516, 0.00322383987622743, 0.05181506981898565, 0.06983821891481057, 0.08979984660982154, 0.05833325267303735, 0.052427835180424154, 0.016120477266667876, 0.020288697742216755, 0.07338800773140974, 0.025737772339198273, 0.28967594204004854, 0.14491846435703337, 8.382185865193605, 50.224542170763016, 39.22891639173031, 30.41834246367216, 25.619798451662064, 51.72116406261921, 45.10258041322231, 49.7467178106308, 45.96818916499615, 38.6591711640358, 60.75454093515873, 55.35201743245125, 53.794142827391624, 45.262707620859146, 44.284723699092865, 0.6495779345277697, 2.1526502771303058, 0.19496465858537704, 10.053581278771162, 41.9768263399601, 64.52430725097656, 58.1516046077013, 65.10202065110207, 60.27333855628967, 62.11684003472328, 61.090066730976105, 60.096469447016716, 61.05797365307808, 60.935061648488045, 58.75712871551514, 58.682686910033226, 60.27558423578739, 57.19480074942112, 56.094873771071434, 56.919627115130424, 56.63272351026535, 56.19569756090641, 60.07448382675648, 58.23503293097019, 54.771860763430595, 56.45288676023483, 55.973819866776466, 55.75307071208954, 55.316804721951485, 56.234846860170364, 52.00321152806282, 50.13873137533665, 50.176847130060196, 50.899606347084045, 47.107888609170914, 42.63289153575897, 43.04140381515026, 47.95037180185318, 51.95761777460575, 47.543843016028404, 44.938649609684944, 44.72310997545719, 45.07900647819042, 46.40483893454075, 53.43809053301811, 50.33638536930084, 53.9789155125618, 53.71674098074436, 54.447065591812134, 53.38086940348148, 53.34605187177658, 53.11495587229729, 55.661374032497406, 54.84549701213837, 55.46689286828041, 47.832346335053444, 42.14302182197571, 44.20962832868099, 44.96131919324398, 43.16472239792347, 46.68880149722099, 44.16347600519657, 45.285996571183205, 47.111061438918114, 43.96225020289421, 43.689690828323364, 43.69045838713646, 49.17490929365158, 56.518532037734985, 53.895775973796844, 55.81985592842102, 54.43066947162151, 56.673544719815254, 53.31095315515995, 54.40962240099907, 53.90003174543381, 52.80456952750683, 51.21261455118656, 43.05241942405701, 42.14886210858822, 40.90208441019058, 38.367251828312874, 42.65893533825874, 45.28687812387943, 53.341055139899254, 50.54302588105202, 52.72619113326073, 42.68086776137352, 41.58398061990738, 41.21797285974026, 48.780247271060944, 46.93633921444416, 46.095151752233505, 50.74971579015255, 52.325206249952316, 53.93118627369404, 52.67040252685547, 48.819917142391205, 51.91873826086521, 52.07884266972542, 53.37283283472061, 46.801233664155006, 43.60106818377972, 51.81303173303604, 58.09841126203537, 54.50218163430691, 56.070410683751106, 53.31717722117901, 58.23148392140865, 56.768353432416916, 58.527716025710106, 56.18358761072159, 58.75592038035393, 54.02491584420204, 59.72542695701122, 55.48466831445694, 61.87350869178772, 54.743331894278526, 57.015609964728355, 33.35960693657398, 14.853224381804466, 1.3430449389852583, 0.5632886616513133, 3.0270386952906847, 50.01411326229572, 54.55150678753853, 54.672062918543816, 54.176957085728645, 50.045499578118324, 51.96363665163517, 57.07039922475815, 60.50028517842293, 62.997815161943436, 36.104226261377335, 31.44549384713173, 38.98276560008526, 37.82264985144138, 29.734654650092125, 1.8248064815998077, 0.10625690454617143, 0.2002804694348015, 0.0394862046232447, 0.149687668599654, 0.07510097362683155, 0.036660028345067985, 0.0564477782609174, 0.03699157910887152, 0.027843011521326844, 0.07437648164341226, 0.029520949901780114, 0.021970079687889665, 0.03197089441528078, 0.011034625513275387, 0.02640959224663675, 0.07554972064099275, 0.03169765790516976, 0.03664397569082212, 0.08232852720539086, 0.004516591552601312, 0.35673177510034293, 0.18618573434650898, 11.496504452079535, 63.24421674013138, 46.3908214867115, 34.344563484191895, 37.363474890589714, 60.74695274233818, 48.21746326982975, 55.88167101144791, 51.356509029865265, 48.141182363033295, 65.19494086503983, 62.36104913055897, 59.4412250071764, 52.11051017045975, 48.63276578485966, 1.4763550856150687, 4.318045545369387, 0.32057460746727884, 14.033939894288778, 44.747561663389206, 63.23044627904892, 60.954262018203735, 68.00555124878883, 64.78726834058762, 64.29881975054741, 62.43693865835667, 62.84672386944294, 62.39637963473797, 64.19408217072487, 60.313061624765396, 60.9500290453434, 61.2850608676672, 60.039487704634666, 58.91893923282623, 59.85878840088844, 57.50432454049587, 59.31984432041645, 62.005373015999794, 59.233805537223816, 57.23649971187115, 59.054618552327156, 59.91081140935421, 57.74653114378452, 57.27640897035599, 55.59631772339344, 54.1237523406744, 51.65162779390812, 52.20594584941864, 53.461014702916145, 47.18947783112526, 46.22348986566067, 43.70320290327072, 51.39894515275955, 54.280186146497726, 48.84968474507332, 47.76114575564861, 46.34677805006504, 47.447012811899185, 49.02205489575863, 54.14573036134243, 54.40008491277695, 56.55025273561478, 56.14524766802788, 56.150742173194885, 55.25176741182804, 56.501425355672836, 56.99242740869522, 59.273532405495644, 55.58684483170509, 58.737525567412376, 48.29346299171448, 42.05488555133343, 43.88350322842598, 48.27586993575096, 46.56730301678181, 47.8030689060688, 46.32304832339287, 48.22842188179493, 48.02715428173542, 44.33055683970451, 44.2224982380867, 44.20405402779579, 51.26079596579075, 59.266236796975136, 55.94567097723484, 58.65317389369011, 57.33076125383377, 59.22569677233696, 53.84861670434475, 58.15043807029724, 55.9528411924839, 56.110137552022934, 52.72595554590225, 47.14773327112198, 43.04588757455349, 43.439869433641434, 39.89684455096722, 43.970811143517494, 48.730348348617554, 54.55048464238644, 53.4699784219265, 54.64766062796116, 44.47574704885483, 43.50633166730404, 43.503310829401016, 51.127924695611, 48.74807819724083, 49.348784163594246, 50.201895385980606, 54.7811284661293, 54.66292820870876, 55.35211242735386, 51.19083032011986, 53.118238896131516, 53.88164073228836, 53.169285356998444, 48.45676302909851, 46.5448272228241, 53.56405757367611, 61.50322236120701, 55.09027607738972, 59.54761929810047, 56.116251423954964, 59.7179489582777, 57.11156241595745, 60.98795101046562, 57.308589443564415, 61.38919807970524, 57.057662308216095, 62.56491959095001, 59.447893649339676, 65.47468945384026, 56.319981291890144, 57.36960656940937, 34.073630422353745, 20.14277994632721, 0.8715257467702031, 2.3021040949970484, 5.172063494101167, 55.064239874482155, 58.81243474781513, 61.35828673839569, 58.275493159890175, 54.80360426008701, 56.00018285214901, 63.551069274544716, 66.84566348791122, 68.83472755551338, 41.75171501934528, 42.35114045441151, 36.306728795170784, 42.20334358513355, 37.77265213429928, 2.243608608841896, 0.06743388308677822, 0.26704091287683696, 0.030888963701727334, 0.16095632017822936, 0.04865927236096468, 0.09048951702425256, 0.04803386080311611, 0.09446307216421701, 0.049634283714112826, 0.15806561044882983, 0.11595223273616284, 0.08380753104574978, 0.19864418223733082, 0.14051236328668892, 0.14543252036673948, 0.13540420535719022, 0.12204963641124777, 0.0829814984172117, 0.22833434923086315, 0.1721940390416421, 0.7637793815229088, 0.4260403825901449, 14.607278779149055, 79.12866398692131, 59.91730526089668, 39.473817050457, 41.91917963325977, 65.04405856132507, 54.350391179323196, 62.518178299069405, 59.24661085009575, 54.09386694431305, 72.54953742027283, 67.46381431818008, 66.26069247722626, 57.60418698191643, 54.8246855288744, 1.8774785427376628, 9.383770320564508, 0.465760244987905, 17.739161923527718, 52.65425719320774, 61.850196942687035, 63.004385009408, 70.5075041949749, 66.69233411550522, 65.30799999833107, 65.40606513619423, 67.64763325452805, 66.7935074865818, 66.91814839839935, 63.64741310477257, 64.50617462396622, 65.64223766326904, 63.29854242503643, 61.98052994906902, 61.424027010798454, 60.53909249603748, 62.61412315070629, 63.57210874557495, 60.32694607973099, 59.075825214385986, 60.762889087200165, 58.919285014271736, 59.23400692641735, 58.496227115392685, 60.24168245494366, 55.459392070770264, 55.29796153306961, 54.88566845655441, 56.323712691664696, 51.25595882534981, 48.17263327538967, 47.246379777789116, 53.903193175792694, 55.89315019547939, 51.8154826015234, 50.41521213948727, 49.698213413357735, 50.13188034296036, 50.78813932836056, 58.77200871706009, 57.61835262179375, 57.83041164278984, 59.1290907561779, 58.02548557519913, 58.853856325149536, 59.170227348804474, 60.70013165473938, 60.666427463293076, 58.22356894612312, 60.10625772178173, 48.32597404718399, 43.23069825768471, 45.30532233417034, 49.9201975017786, 48.536148369312286, 51.04092836380005, 49.944922775030136, 50.82235649228096, 50.754993706941605, 45.41660696268082, 43.65834631025791, 42.92511485517025, 52.516415789723396, 60.599995627999306, 56.76136180758476, 60.567332580685616, 59.47446942329407, 60.121954679489136, 55.6951580196619, 60.19813299179077, 58.30521896481514, 59.03265193104744, 55.92905826866627, 49.24284964799881, 47.29182153940201, 46.60091981291771, 42.08626426756382, 47.02492006123066, 49.39092390239239, 56.01180262863636, 54.68077205121517, 58.580160811543465, 47.700922787189484, 45.65390422940254, 45.812735706567764, 53.81628803908825, 51.22873328626156, 50.48113480210304, 54.25671860575676, 55.770234391093254, 57.921063378453255, 55.207078009843826, 51.80282548069954, 53.57397124171257, 56.66147656738758, 54.71796065568924, 51.805952712893486, 48.27526196837425, 56.45021170377731, 61.37419268488884, 58.37624855339527, 60.03902792930603, 58.45103994011879, 61.897078827023506, 60.415637120604515, 62.17569127678871, 60.327390655875206, 63.41319367289543, 58.679221495985985, 62.35883764922619, 60.89499279856682, 65.23022577166557, 58.96131835877895, 55.91097503900528, 41.476837769150734, 26.024434939026833, 2.590760118328035, 1.884778426028788, 4.408020442351699, 61.15858465433121, 65.15515699982643, 66.40492513775826, 65.16623720526695, 61.10151171684265, 60.44311724603176, 70.39976477622986, 70.51090121269226, 74.93672132492065, 48.98376815021038, 48.34834344685078, 48.76603603363037, 51.86897233128548, 56.039058566093445, 2.401132006198168, 0.18007037811912596, 0.35182098392397165, 0.11689314240356907, 0.23238559981109574, 0.14530225860653445, 0.19121451216051355, 0.1940017071319744, 0.19914364762371406, 0.12160815502284095], [0.04990448855096474, 0.03722709967405535, 0.034195129555882886, 0.088593908585608, 0.04995294337277301, 0.0654740195022896, 0.056907579564722255, 0.056386191135970876, 0.0717634909960907, 0.05325048361555673, 0.08776602800935507, 0.1501459744758904, 0.030802048931946047, 1.8583760177716613, 46.81579828262329, 44.144914001226425, 46.84419795870781, 34.48093056678772, 40.12191027402878, 55.558034777641296, 44.7514184564352, 61.59803867340088, 48.69869604706764, 56.65687881410122, 59.80768494307995, 54.98433776199818, 50.979227274656296, 58.777320832014084, 8.874214813113213, 3.9890045765787363, 0.2111065635108389, 4.723598258569837, 33.145693615078926, 58.977475091814995, 50.97855471074581, 56.78872033953667, 49.4901517778635, 56.269318610429764, 58.24417144060135, 61.075399518013, 59.33770336210728, 57.87477046251297, 57.901513427495956, 60.356546491384506, 57.33959577977657, 59.179745838046074, 57.729580253362656, 56.97799578309059, 57.23125219345093, 58.36047179996967, 53.158250749111176, 55.901992321014404, 53.36797669529915, 56.311302557587624, 54.22054074704647, 54.7580599039793, 54.88007515668869, 55.995007529854774, 52.4058873206377, 52.11624026298523, 49.92780089378357, 52.674472108483315, 49.374903962016106, 44.524399638175964, 43.37529569864273, 43.00906755030155, 42.781159579753876, 44.11089062690735, 41.88227601349354, 45.44752970337868, 47.35062338411808, 48.25906343758106, 49.34172034263611, 52.00160801410675, 53.606911674141884, 54.59404170513153, 53.71987201273441, 55.4601064324379, 55.32731115818024, 56.21726140379906, 54.48331564664841, 58.41312937438488, 50.73589973151684, 42.13180862367153, 43.54405604302883, 40.69242686033249, 41.58789061009884, 41.643994599580765, 44.51853655278683, 42.80960105359554, 42.9522567987442, 41.793212592601776, 43.84380675852299, 42.50184416770935, 42.81540334224701, 42.81407721340656, 54.649347737431526, 56.580727100372314, 54.40942861139774, 56.54018707573414, 52.10474967956543, 52.81384103000164, 52.4163443595171, 53.05686838924885, 53.645741790533066, 54.66333858668804, 48.931498154997826, 45.1590795814991, 44.708457961678505, 41.38869009912014, 41.02311931550503, 45.229410007596016, 49.046764969825745, 51.757862493395805, 44.665368273854256, 41.477472335100174, 40.26087261736393, 44.0462750941515, 47.92456358671188, 45.927694737911224, 45.04549227654934, 48.68004284799099, 52.91535258293152, 53.403998762369156, 54.85218845307827, 45.91788366436958, 51.64084777235985, 54.94874507188797, 52.71452195942402, 47.852842435240746, 44.62163642048836, 53.01716431975365, 51.30194395780563, 52.937224209308624, 52.132423594594, 58.599121794104576, 57.11101524531841, 58.6993034183979, 57.256144657731056, 57.05559141933918, 59.12413962185383, 58.62913258373737, 59.52236585319042, 60.26974014937878, 61.29104934632778, 50.192418694496155, 46.47144556045532, 21.81694731116295, 8.983605243265629, 0.44327195326332003, 0.44543100928422064, 9.482538420706987, 53.30803491175175, 56.2369367480278, 54.55460362136364, 51.515260711312294, 55.668293461203575, 57.0676139742136, 60.72041116654873, 49.39792312681675, 59.65239867568016, 32.26344175636768, 47.98556171357632, 44.21884663403034, 55.497492626309395, 12.133498471230268, 1.2686061020940542, 0.09876319454633631, 0.14596619876101613, 0.04083340674696956, 0.11570074857445434, 0.09184539114357904, 0.10802023258293048, 0.09188076190184802, 0.05040278134401888, 0.0526834271295229, 0.08456918978481553, 0.08006790827494115, 0.06299639659118839, 0.039579470321768895, 0.05656365719914902, 0.056095625477610156, 0.03471465519396588, 0.0867383464355953, 0.12076913480996154, 0.1145516219548881, 0.02572992041677935, 0.21435777889564633, 0.051730041959672235, 3.483367608860135, 59.95381750166416, 49.23261679708958, 37.12131388485432, 49.147660955786705, 49.80960063636303, 59.1807945817709, 50.787656754255295, 61.796517223119736, 47.93522581458092, 65.17043218016624, 64.69432532787323, 60.49981780350208, 55.147060230374336, 64.0857195854187, 11.451108288019896, 2.135268347337842, 0.4856359987752512, 6.366632468998432, 37.49136082828045, 62.82386429607868, 53.12575489282608, 57.02247239649296, 49.99477609992027, 57.643089294433594, 59.574521854519844, 62.44326151907444, 61.7048205435276, 60.97802974283695, 58.253290951251984, 62.45696738362312, 58.8156645745039, 62.111379727721214, 59.089793264865875, 58.59283313155174, 59.41245295107365, 59.40939411520958, 53.6245883256197, 56.57411925494671, 55.67101031541824, 58.09149943292141, 55.66366910934448, 58.396170884370804, 55.76366074383259, 57.66281023621559, 53.50329503417015, 55.079735442996025, 49.3505434691906, 52.963233813643456, 50.91574788093567, 47.135399132966995, 45.51561065018177, 43.87070931494236, 45.27015522122383, 46.38347648084164, 46.89104184508324, 47.28453733026981, 50.86819723248482, 51.98243044316769, 53.089839220047, 55.09653054177761, 56.39207862317562, 56.99930503964424, 55.37736587226391, 59.43122014403343, 58.024702817201614, 58.89914229512215, 56.39503866434097, 60.27489647269249, 51.92025437951088, 43.263137117028236, 45.99548690021038, 43.540191650390625, 44.780608490109444, 45.35611040890217, 45.26319779455662, 45.843316465616226, 44.50957663357258, 45.07816292345524, 44.5132852345705, 44.383210614323616, 43.95424783229828, 45.71568511426449, 56.61521404981613, 57.670531421899796, 57.780087143182755, 59.69854719936848, 56.38328589498997, 56.412551924586296, 56.40196569263935, 56.7639684677124, 54.961937963962555, 57.40908645093441, 50.951587557792664, 47.62193642556667, 47.160945162177086, 42.848704755306244, 42.42411553859711, 45.846907272934914, 52.530950009822845, 54.31679718196392, 47.20435783267021, 42.583004012703896, 44.26255188882351, 44.94723714888096, 50.834417045116425, 48.51320520043373, 48.3806075155735, 49.937349781394005, 55.40194295346737, 55.59152618050575, 57.30609677731991, 49.337437972426414, 53.07679072022438, 56.758268773555756, 54.228725507855415, 50.901707634329796, 46.367198154330254, 55.72412386536598, 53.245752453804016, 55.6598237156868, 53.64522121846676, 61.33877098560333, 58.397003039717674, 59.5576773583889, 60.49715034663677, 57.90732331573963, 61.31365813314915, 61.53323695063591, 61.24460443854332, 62.73361913859844, 62.780956998467445, 51.02339990437031, 48.076559230685234, 24.998288601636887, 10.195891242474318, 0.6257086840923876, 0.5206657550297678, 11.502514779567719, 59.042877182364464, 61.05637773871422, 60.05347475409508, 56.43880091607571, 61.926515847444534, 62.79278576374054, 70.12241005897522, 52.91390486061573, 65.47447666525841, 38.480196967720985, 60.80314792692661, 41.32349319756031, 63.710748106241226, 17.73413859307766, 1.472566332668066, 0.029504709855245892, 0.18517068412620574, 0.03612811255152337, 0.18112862133421004, 0.00896105841093231, 0.09148233992164023, 0.05239698781224433, 0.06289981349254958, 0.08764675745624118, 0.2687519195023924, 0.1096293720183894, 0.23602771922014654, 0.2646807348355651, 0.18859894626075402, 0.15765892836498097, 0.13116710615577176, 0.2939072228036821, 0.3494559967657551, 0.24116746295476332, 0.1890174433356151, 0.39656732347793877, 0.2014367503579706, 3.885797127149999, 68.59716430306435, 68.18627715110779, 60.333641320466995, 51.417161375284195, 53.96652437746525, 62.863116189837456, 57.70592652261257, 72.10541725158691, 59.102245196700096, 71.32327482104301, 70.1769295334816, 66.20511665940285, 61.293196231126785, 73.43108251690865, 13.057421743869781, 8.341852929443121, 0.6789744039997458, 8.812052048742771, 48.36361102759838, 66.14406153559685, 56.52125649154186, 57.806275337934494, 54.93953436613083, 57.842172011733055, 62.242693081498146, 65.36482974886894, 65.04937067627907, 63.758184760808945, 61.19635462760925, 63.70869241654873, 60.4591865837574, 62.879212126135826, 61.253313571214676, 59.56294767558575, 61.43319211900234, 60.07139079272747, 54.11514960229397, 58.45328561961651, 57.37790532410145, 58.75914640724659, 58.11461739242077, 59.30602066218853, 58.106090649962425, 59.517429918050766, 54.772829711437225, 56.68793074786663, 52.02718444168568, 55.323245376348495, 54.10907372832298, 49.703316539525986, 47.68969438970089, 46.70450985431671, 46.468154937028885, 46.75841376185417, 46.87971085309982, 48.08157876133919, 53.204403072595596, 52.82699212431908, 56.34348303079605, 58.43763425946236, 56.95791006088257, 59.58498649299145, 57.46690034866333, 62.27083437144756, 60.20308032631874, 60.68995960056782, 57.79019460082054, 61.59113824367523, 52.095269188284874, 44.87580478191376, 45.946499928832054, 45.37983253598213, 47.19977527856827, 47.37980581820011, 48.71873617172241, 49.731013253331184, 47.36567057669163, 46.993024572730064, 46.96392573416233, 45.85720852017403, 45.10272480547428, 45.53219676017761, 56.70803166925907, 60.25589369237423, 60.07649011909962, 61.68418765068054, 57.423153296113014, 59.12228912115097, 57.747526690363884, 56.81179650127888, 55.64109832048416, 60.16766242682934, 55.038386061787605, 51.72678016126156, 48.90490338206291, 45.63016690313816, 45.02268210053444, 48.38174745440483, 51.84325151145458, 55.42352959513664, 49.55982863903046, 46.02192588150501, 44.05661813914776, 48.47795829176903, 52.46544532477856, 49.09954413771629, 48.16332757472992, 52.16184161603451, 56.42156884074211, 59.11072634160519, 59.01780232787132, 47.1071020513773, 55.722729340195656, 58.366399481892586, 57.201313599944115, 53.80928501486778, 50.387633219361305, 56.21299423277378, 54.79962207376957, 58.07047516107559, 56.412061750888824, 63.3203000575304, 59.07007612287998, 62.90689744055271, 61.55282869935036, 59.085377901792526, 62.88864701986313, 64.66473251581192, 62.20725618302822, 65.3213980793953, 63.45948278903961, 52.91444443166256, 48.73949445784092, 33.18998023867607, 13.826581221073866, 0.75638058478944, 1.5483706025406718, 13.068252112716436, 66.93423673510551, 66.61512985825539, 65.41942521929741, 62.10610181093216, 67.83150538802147, 67.64063403010368, 72.50358268618584, 60.46229861676693, 73.24680760502815, 45.48479810357094, 63.38364265859127, 52.662354558706284, 74.60274204611778, 28.771702721714973, 1.631470718421042, 0.17002990673063323, 0.24854933872120455, 0.15457514149602503, 0.3021210461156443, 0.14742962492164224, 0.15909249050309882, 0.2923917869338766, 0.13011249946430326, 0.14456723554758355], [0.18130848824512213, 0.016930793062783778, 0.07438442262355238, 0.10376283564255573, 0.08744753533392213, 0.027418143108661752, 0.08360291350982152, 0.07240604245453142, 0.053597077712765895, 0.05969068530248478, 0.13500852190190926, 0.03949185607780237, 0.3024241095408797, 0.11281779428827576, 14.702040944248438, 52.833850756287575, 39.751065373420715, 33.27772133052349, 38.091124445199966, 52.9349709302187, 47.23286010324955, 56.23023010790348, 65.767912119627, 54.01799261569977, 59.51201140880585, 53.66045840084553, 53.004283010959625, 56.557479947805405, 31.920069381594658, 0.7286299020051956, 0.7568385789636523, 1.7052837763912976, 19.012572392821312, 49.79487642645836, 58.14164154231548, 58.926436230540276, 60.423996672034264, 56.63333907723427, 58.23144972324371, 60.29423363506794, 60.09982846677303, 55.87034001946449, 56.73680752515793, 61.60933166742325, 56.679214015603065, 58.32224205136299, 57.37731255590916, 58.57728436589241, 57.168943136930466, 54.63977985084057, 55.649959444999695, 59.60623115301132, 57.97588303685188, 60.7724379748106, 60.109707936644554, 61.2331822514534, 56.55233882367611, 55.46802520751953, 55.13594202697277, 54.14739087224007, 50.441803112626076, 51.17410361766815, 50.96665754914284, 45.33350542187691, 42.39826552569866, 43.1817302852869, 40.43012693524361, 42.26990841329098, 43.09359781444073, 48.78623574972153, 51.33888177573681, 54.32105675339699, 52.1281374245882, 52.28216215968132, 56.39899805188179, 55.433257073163986, 54.163828790187836, 56.231229454278946, 56.29640355706215, 54.089060202240944, 55.48314079642296, 49.43169191479683, 44.79794695973396, 45.093620494008064, 40.06675623357296, 40.85412718355656, 41.83316744863987, 40.68182162940502, 39.60994854569435, 41.037224158644676, 39.13628876209259, 41.06319196522236, 43.272765800356865, 44.50848989188671, 44.0702860057354, 43.18364538252354, 46.052730828523636, 56.960041746497154, 55.86806774139404, 55.21234832704067, 55.575741827487946, 53.4656086564064, 53.91234688460827, 55.01461073756218, 54.49790686368942, 52.48858608305454, 52.30979807674885, 49.32210959494114, 42.98534922301769, 42.551412507891655, 41.779654920101166, 42.8321148455143, 46.40468694269657, 45.93559071421623, 40.53184747695923, 42.60003089904785, 40.259694680571556, 45.666641145944595, 47.62147285044193, 44.067873135209084, 47.69498750567436, 52.66885980963707, 52.95991279184818, 53.79021763801575, 55.44343292713165, 40.74530482292175, 45.29936045408249, 59.36681739985943, 50.58483503758907, 51.31764091551304, 41.757745295763016, 46.20044410228729, 52.07687437534332, 54.608682319521904, 58.25674496591091, 59.49073255062103, 53.720996752381325, 57.04590953886509, 56.86530143022537, 57.68431708216667, 56.85807801783085, 60.29954195022583, 60.2820248901844, 62.892648205161095, 60.100850611925125, 60.45898899435997, 42.225880175828934, 18.63639447838068, 1.3717062072828412, 0.2920105605153367, 1.5240104659460485, 13.067163471132517, 59.50823441147804, 52.920178323984146, 52.71995946764946, 58.32129970192909, 52.307411804795265, 60.84700517356396, 44.3307164311409, 45.611057728528976, 53.505510315299034, 31.68458841741085, 49.56373102962971, 29.93294321000576, 48.50590579211712, 3.2940620044246316, 0.523434440838173, 0.1683263512677513, 0.27054242498707026, 0.1395614049397409, 0.08604341419413686, 0.026371076637587976, 0.07734654180239886, 0.04037563892779872, 0.042046985181514174, 0.09019472112413496, 0.12731118884403259, 0.03698898901348002, 0.07970224469318055, 0.03910615079803392, 0.15897208446403965, 0.07420608453685418, 0.051939015902462415, 0.06655153629253618, 0.08784652134636417, 0.025697323435451835, 0.10287981349392794, 0.038817021195427515, 0.4001470282673836, 0.11730445548892021, 23.433580063283443, 63.87704238295555, 41.43938697874546, 51.56961679458618, 47.62911804020405, 56.77911065518856, 52.852819338440895, 64.52643513679504, 71.71419784426689, 62.02811099588871, 65.53262114524841, 59.155085161328316, 57.80755966901779, 63.708209842443466, 34.818067476153374, 0.7104953750967979, 1.3393431063741446, 1.8285197135992348, 23.282973244786263, 54.55485820770264, 59.66921657323837, 64.12171125411987, 62.249570712447166, 61.020051687955856, 59.9692826718092, 61.34092167019844, 59.818597957491875, 58.1181588023901, 58.49727965891361, 63.35566855967045, 60.673844665288925, 61.319376826286316, 58.334500193595886, 60.52289016544819, 57.7058657258749, 57.19166211783886, 58.13486270606518, 60.431159287691116, 58.08172255754471, 60.41662506759167, 60.32924875617027, 61.032743006944656, 57.01494500041008, 57.34428472816944, 56.34528033435345, 56.025398299098015, 52.07587882876396, 53.006726279854774, 52.33275644481182, 47.2715800255537, 44.053407311439514, 46.147596538066864, 41.90846800804138, 46.354225650429726, 46.0321169346571, 49.78414200246334, 51.615275144577026, 56.438447535037994, 53.388047218322754, 55.60549423098564, 58.91754850745201, 56.59834675490856, 56.736305952072144, 60.19619509577751, 58.473888114094734, 56.57847002148628, 57.73483917117119, 53.07199537754059, 46.0883729159832, 47.32805259525776, 43.91849175095558, 43.1332790851593, 43.144146502017975, 41.99503496289253, 42.84337364137173, 44.091481268405914, 41.77229851484299, 45.03449186682701, 45.32950423657894, 47.51678466796875, 44.694831892848015, 44.10964049398899, 48.369531109929085, 59.13823686540127, 57.91194386780262, 58.75478804111481, 57.677108868956566, 56.16735868155956, 55.635801404714584, 55.762140825390816, 56.2659215927124, 54.49431985616684, 54.16528791189194, 51.18644155561924, 44.52295571565628, 46.247113198041916, 43.12336161732674, 44.56014811992645, 47.30623796582222, 49.314293414354324, 42.089809477329254, 43.535191118717194, 42.00338311493397, 48.45158010721207, 47.8750142455101, 44.80839639902115, 48.702256456017494, 54.00973565876484, 53.69692124426365, 55.46734504401684, 55.62986992299557, 44.30047005414963, 47.6828433573246, 59.776921793818474, 52.80508249998093, 52.07646019756794, 42.235227674245834, 49.18811358511448, 52.76472866535187, 58.6972401291132, 58.24312649667263, 61.62262715399265, 54.466102570295334, 58.566131964325905, 58.08246731758118, 59.12535175681114, 57.5323898345232, 63.74790631234646, 61.942714378237724, 64.76878613233566, 57.60033018887043, 64.45492297410965, 42.850061282515526, 21.2009509652853, 1.3988120527938008, 0.865157525986433, 0.4164028528612107, 15.331971142441034, 66.40356481075287, 58.96944612264633, 58.11525955796242, 65.0731573998928, 56.81549370288849, 64.93896380066872, 48.201158344745636, 51.981613487005234, 58.354479521512985, 40.87455488741398, 60.91097854077816, 30.233533680438995, 58.50833706557751, 5.151109518483281, 0.3574766538804397, 0.11569009133381769, 0.23323626432102174, 0.12058425098075531, 0.05268239925499074, 0.08327539631864056, 0.034232953112223186, 0.0744654651498422, 0.0212969517451711, 0.14513720496324822, 0.19745244149817154, 0.13058643497060984, 0.19809567573247477, 0.185176428349223, 0.21521617658436298, 0.17463430966017768, 0.14181333332089707, 0.16084620030596852, 0.18049217032967135, 0.11930935259442776, 0.2252040000166744, 0.1817693025805056, 0.42358797043561935, 0.3895658429246396, 31.01279776543379, 79.86229062080383, 54.82789635658264, 47.35813558101654, 55.881705209612846, 63.82212772965431, 56.568902134895325, 67.44086354970932, 77.09772616624832, 68.49463060498238, 69.52512010931969, 63.62852431833744, 63.57610613107681, 69.69782844185829, 39.20888766646385, 2.2755325958132744, 2.3177461931481957, 3.8511230377480388, 31.364440396428108, 56.283279061317444, 63.36790390312672, 64.60001438856125, 67.94092431664467, 62.50176697969437, 63.33481527864933, 63.486419543623924, 63.40411216020584, 60.56325539946556, 61.539039239287376, 65.54580643773079, 62.94217474758625, 62.13431529700756, 60.748328268527985, 60.543082281947136, 60.08065849542618, 58.73071253299713, 59.61001195013523, 63.56704741716385, 61.254092529416084, 62.02289007604122, 62.785835936665535, 64.50202524662018, 59.159998297691345, 59.74770896136761, 58.70554268360138, 59.17735576629639, 55.34856341779232, 56.17958642542362, 55.87141916155815, 51.57014116644859, 47.60946549475193, 47.40607000887394, 43.57909396290779, 48.686829283833504, 48.38356755673885, 53.8355378061533, 56.82525537908077, 61.16404876112938, 55.70781894028187, 58.78946118056774, 61.99700586497784, 59.51962240040302, 60.10585494339466, 62.081889510154724, 60.51111459732056, 57.987016439437866, 58.640417978167534, 52.16259777545929, 44.98764418065548, 48.636227399110794, 47.33851723372936, 46.23657636344433, 46.14289619028568, 45.47751769423485, 44.03606504201889, 45.87672047317028, 44.44448232650757, 45.63161842525005, 47.47709579765797, 50.50715960562229, 46.074142679572105, 43.245943039655685, 47.31971204280853, 61.07732601463795, 60.78180827200413, 61.14544875919819, 60.17649695277214, 57.073089480400085, 58.49089600145817, 57.29054041206837, 59.596587270498276, 56.44533656537533, 57.90071167051792, 54.503644555807114, 47.542729675769806, 48.75402867794037, 46.98345668613911, 46.09276548027992, 48.17245848476887, 51.42364762723446, 43.51428464055061, 46.49824172258377, 43.94366540014744, 52.39333279430866, 51.06642119586468, 47.50911667943001, 50.14158122241497, 57.78127267956734, 56.262364983558655, 58.78297492861748, 56.223493069410324, 42.29167364537716, 48.943733498454094, 62.848726361989975, 54.486237689852715, 53.94576609134674, 44.83649969100952, 52.39076033234596, 56.42679736018181, 59.400437995791435, 62.03754208981991, 63.989303559064865, 57.95550473034382, 59.13661055266857, 61.22341677546501, 60.64719669520855, 60.682557597756386, 64.68535780906677, 62.13491566479206, 68.51635783910751, 61.277237087488174, 62.26144887506962, 46.94828577339649, 28.399757780134678, 2.338306652382016, 0.7412961067166179, 3.0024875001981854, 17.69274551421404, 72.05797299742699, 63.87856990098953, 64.18792650103569, 67.83095821738243, 63.19210633635521, 71.50859847664833, 54.323849603533745, 56.436733826994896, 66.2482899427414, 46.619360223412514, 62.786436304450035, 40.13990990817547, 73.59786316752434, 11.631254721432924, 0.6557008309755474, 0.21547144569922239, 0.3433230664813891, 0.15299877530196682, 0.1349355687852949, 0.23698118602624163, 0.15170010592555627, 0.10664128509233706, 0.1918276894139126, 0.2615175233222544], [0.024333454530278686, 0.1155210672004614, 0.08044304908253253, 0.020989192380511668, 0.041294532784377225, 0.05728597468987573, 0.036156080386717804, 0.05308076557412278, 0.0621883795975009, 0.033634032515692525, 0.06788254104321823, 0.020324144570622593, 0.3535804379498586, 0.1891682477435097, 6.113387458026409, 44.39188174903393, 35.92013753950596, 31.81134771555662, 28.545069582760334, 53.698589354753494, 50.48130199313164, 46.83412089943886, 56.85552455484867, 54.360627830028534, 58.03207442164421, 52.326080203056335, 54.74112421274185, 54.915204271674156, 42.62369982898235, 0.756583814509213, 0.7030972908250988, 0.5339587479829788, 7.01772753149271, 50.87094068527222, 61.384512931108475, 62.92597621679306, 57.910499945282936, 63.93188863992691, 59.64473448693752, 61.55781403183937, 59.46501933038235, 59.56998489797115, 59.04799930751324, 60.39143241941929, 55.85427828133106, 57.96242795884609, 56.71233683824539, 57.34341837465763, 57.75717817246914, 58.671838492155075, 59.58788573741913, 59.66608174145222, 61.09651878476143, 56.7218629270792, 57.56504528224468, 58.086924478411674, 56.318411976099014, 57.293625846505165, 56.815755888819695, 55.7561257481575, 50.85436597466469, 48.69345232844353, 51.573074609041214, 48.748040199279785, 43.44445578753948, 44.105646908283234, 41.101391315460205, 40.202617943286896, 40.53283542394638, 46.86158962547779, 52.492309883236885, 54.82362158596516, 51.63547106087208, 52.93179050087929, 54.360183253884315, 52.19296954572201, 53.37437555193901, 56.29313573241234, 57.22096614539623, 54.58164297044277, 45.08991189301014, 40.990403071045876, 42.84039460122585, 40.30461587011814, 38.07304501533508, 40.466844365000725, 38.15374128520489, 41.529103964567184, 39.23835128545761, 39.644587486982346, 40.09820334613323, 37.94555805623531, 40.12120731174946, 40.95454439520836, 43.25548432767391, 43.682744801044464, 45.23421674966812, 46.98196716606617, 55.30256308615208, 54.10354122519493, 55.11491395533085, 52.31298230588436, 55.04921928048134, 56.48523062467575, 54.68464024364948, 52.607071325182915, 51.21528960764408, 52.2210918366909, 48.92236344516277, 44.0349555015564, 43.29208396375179, 40.794417187571526, 40.832833126187325, 42.0149040967226, 40.94650022685528, 40.78726217150688, 41.81477643549442, 47.011160999536514, 46.56457856297493, 48.32085572183132, 53.6955951154232, 50.965548008680344, 53.14830668270588, 51.241610795259476, 57.97605782747269, 38.53418827056885, 39.08941827714443, 57.90183261036873, 51.74978792667389, 54.836217910051346, 47.876655757427216, 43.638720363378525, 41.93187475204468, 47.285095900297165, 46.4340403676033, 53.807305321097374, 53.00470478832722, 56.5401566773653, 54.46652054786682, 58.40915858745575, 55.27646988630295, 60.19071578979492, 54.3352185934782, 61.445970833301544, 56.799325570464134, 58.28578680753708, 32.13886544108391, 3.4997501922771335, 0.4873691510874778, 0.4041566146770492, 0.47621790727134794, 20.228005573153496, 56.125667318701744, 56.26435987651348, 54.66003656387329, 57.37762413918972, 54.590811878442764, 62.12691709399223, 51.835492327809334, 64.08104583621025, 35.328592881560326, 35.054057613015175, 45.071410685777664, 36.95396326482296, 30.78518807888031, 1.0681490460410714, 0.11936125840293244, 0.1100137822504621, 0.2314529725117609, 0.1306385188945569, 0.06548778634169139, 0.13374232890782878, 0.03154892037855461, 0.01941731617989717, 0.06290514953434467, 0.07629572006408125, 0.05334987574315164, 0.10377827231422998, 0.012852947620558552, 0.04852495105296839, 0.08715751886484213, 0.04697288648458198, 0.06364564964314923, 0.004862063151449547, 0.04770046580233611, 0.02288400301040383, 0.08706812717719004, 0.04402027421747334, 0.5199813167564571, 0.15062918682815507, 9.199150577187538, 59.56130996346474, 34.649831503629684, 32.84051299095154, 44.621986001729965, 56.539651304483414, 54.12544324994087, 52.1369681507349, 65.35817250609398, 58.19447010755539, 63.508424162864685, 57.13335804641247, 60.64129561185837, 59.728884771466255, 46.97947829961777, 1.3918636506423354, 3.6368558602407575, 0.999226444400847, 10.549451820552349, 51.56724572181702, 64.06802773475647, 65.8599279820919, 62.863450571894646, 67.39592716097832, 64.0282666683197, 64.1911107301712, 62.81343385577202, 62.639775574207306, 62.741211131215096, 63.53301264345646, 57.79514953494072, 59.245493710041046, 60.02674698829651, 57.753271982073784, 59.80595223605633, 59.42746214568615, 62.77963846921921, 60.51682569086552, 62.40156255662441, 59.83113348484039, 59.84296225011349, 58.58451537787914, 59.189549311995506, 58.71963992714882, 57.863678857684135, 57.5629173964262, 54.1789747774601, 50.50216667354107, 53.536235466599464, 50.03719322383404, 45.3727725148201, 45.20164489746094, 43.22475917637348, 41.877283081412315, 43.09309624135494, 48.09878423810005, 54.92466576397419, 55.02414062619209, 54.415971860289574, 55.62299609184265, 55.31350649893284, 57.27042429149151, 55.30559912323952, 59.03310790657997, 59.26038511097431, 58.50732631981373, 46.570114865899086, 41.788915023207664, 46.34572550654411, 44.16357100009918, 41.743226274847984, 44.59386371076107, 42.67994821071625, 42.76088386774063, 42.36033596098423, 42.533283680677414, 42.28700749576092, 42.60269455611706, 43.54174956679344, 44.220195561647415, 45.51691398024559, 45.30406080186367, 44.64270628988743, 50.21614462137222, 59.150814190506935, 58.333238661289215, 56.73422746360302, 55.77589228749275, 57.42126479744911, 57.5317058712244, 58.007003366947174, 54.80998791754246, 54.28600363433361, 54.04318526387215, 50.71703374385834, 46.28750883042812, 44.00226965546608, 44.69782613217831, 44.09233242273331, 43.756954818964005, 42.64728896319866, 43.08385893702507, 44.31904345750809, 47.638549134135246, 48.018969520926476, 49.49398957192898, 54.32731881737709, 53.56535330414772, 54.37426529824734, 51.82485669851303, 60.83286613225937, 43.36453467607498, 42.625656723976135, 61.168091744184494, 54.39346946775913, 55.33044219017029, 49.81467716395855, 45.415577217936516, 42.621609941124916, 50.24227201938629, 48.561170026659966, 55.97636952996254, 55.4277815669775, 59.84992727637291, 56.746683195233345, 60.971102714538574, 56.18568889796734, 61.51391498744488, 56.53016321361065, 61.46305471658707, 58.319080621004105, 58.239596486091614, 33.25860075652599, 3.642314742319286, 0.8995656296610832, 2.1818680968135595, 0.1517485681688413, 23.49096268415451, 61.25343136489391, 60.29360666871071, 59.40034680068493, 62.16936081647873, 60.329560339450836, 70.0988133251667, 54.65328052639961, 70.29077902436256, 40.00125154852867, 48.38176265358925, 44.596561565995216, 39.91411082446575, 39.56270568072796, 1.1446989071555436, 0.11167326898430474, 0.13248854462290183, 0.10551739891525358, 0.15688601124566048, 0.04639100188796874, 0.0906478839169722, 0.0594347259902861, 0.03798360419750679, 0.05126954674778972, 0.04520280490396544, 0.15898545796517283, 0.24574842886067927, 0.18398724059807137, 0.08295672552776523, 0.17038826015777886, 0.1551818472216837, 0.1686663439613767, 0.10970034360070713, 0.08194425055989996, 0.2195412796572782, 0.14967242488637567, 0.1340442048967816, 1.1519725481048226, 0.2678657654905692, 11.877893786877394, 74.23749044537544, 53.465061485767365, 42.62164033949375, 43.41676287353039, 67.23540097475052, 60.375256687402725, 57.76475116610527, 70.25978788733482, 64.46536481380463, 67.97826111316681, 63.5972747951746, 66.70806527137756, 65.83630844950676, 53.32119360566139, 1.7665959801524878, 3.056715577840805, 0.8226366795133799, 13.441969659179449, 57.25204847753048, 62.98703134059906, 69.60755288600922, 63.73181417584419, 71.51170670986176, 65.90036541223526, 66.68345779180527, 64.96906578540802, 66.7795318365097, 64.43818867206573, 67.13660627603531, 60.70641651749611, 62.907011434435844, 60.74001431465149, 60.40758915245533, 61.51255466043949, 62.533879056572914, 65.18423303961754, 63.53199049830437, 65.96020460128784, 61.3059863448143, 60.71341574192047, 59.799990355968475, 58.89585167169571, 61.92118473351002, 59.65671144425869, 59.86609160900116, 55.911765396595, 53.13438042998314, 56.241485103964806, 54.11951556801796, 48.09715412557125, 48.3816334605217, 43.366210386157036, 43.918845131993294, 44.319685623049736, 50.4374485462904, 58.45536790788174, 58.86268325150013, 58.38694117963314, 60.67390166223049, 58.84217955172062, 58.00901725888252, 57.391075417399406, 60.00416859984398, 62.827253714203835, 58.63151505589485, 45.37585034966469, 41.7855142056942, 49.80483189225197, 45.21308608353138, 42.79755190014839, 46.26079246401787, 44.056443348526955, 46.78095415234566, 46.38500019907951, 44.01569813489914, 46.02608285844326, 45.05297027528286, 46.64420709013939, 46.05335399508476, 48.242146745324135, 45.130493715405464, 45.372358337044716, 48.73643182218075, 61.73186369240284, 59.475514367222786, 58.94845224916935, 56.11073412001133, 58.53206679224968, 58.89737159013748, 60.36386489868164, 56.89582139253616, 55.49790680408478, 56.63767084479332, 53.02220284938812, 46.8209508061409, 47.1389215439558, 43.71479228138924, 45.9070048481226, 45.98004072904587, 45.99166430532932, 44.30928938090801, 47.556465938687325, 49.16080445051193, 51.16593785583973, 50.49823388457298, 58.142568692564964, 57.0828777551651, 57.78911545872688, 53.578812181949615, 62.87994548678398, 41.28505066037178, 42.63693451881409, 63.95085722208023, 56.09569072723389, 57.95956291258335, 52.869223058223724, 48.43734987080097, 44.97095927596092, 52.76149123907089, 51.79357297718525, 57.687467113137245, 57.33193539083004, 61.68514519929886, 60.06067156791687, 63.266544342041016, 59.56598371267319, 66.48938700556755, 59.549124017357826, 64.79192689061165, 61.44441291689873, 60.38990870118141, 39.64934483170509, 6.5111353900283575, 1.375899757258594, 4.118597097694874, 1.2697790516540408, 25.861368589103222, 67.36766427755356, 64.461739808321, 65.59439823031425, 66.27071633934975, 67.15242862701416, 72.59825840592384, 61.49771265685558, 75.18962815403938, 49.16056506335735, 49.183960407972336, 55.88805466890335, 52.98092186450958, 53.586597964167595, 1.133221979252994, 0.27458439872134477, 0.14335242885863408, 0.32126569538377225, 0.22959163645282388, 0.20163175708148628, 0.2605075197061524, 0.18578975403215736, 0.10417512836284004, 0.14843924262095243, 0.19515996216796339], [0.05892904882784933, 0.042915657904814, 0.11607542182900943, 0.028515213634818792, 0.07056708956952207, 0.10175214236369357, 0.05739847314544022, 0.027741242665797472, 0.05757536033343058, 0.04644382053811569, 0.024557184224249795, 0.022493371725431643, 0.011290697075310163, 0.22770208393922076, 0.35526258987374604, 30.51112398505211, 45.86718678474426, 43.78796495497227, 31.024541035294533, 43.025243282318115, 65.49612030386925, 45.75380086898804, 56.925399005413055, 58.770906776189804, 58.47479246556759, 59.01429511606693, 53.98344486951828, 56.538374572992325, 48.94046187400818, 3.3106656884774566, 1.1107663717120886, 0.33694647427182645, 3.399414913728833, 47.212310805916786, 61.42364323139191, 62.00337812304497, 54.94331896305084, 53.45321752130985, 56.69730484485626, 59.33265343308449, 57.33174540102482, 57.377867326140404, 57.48544715344906, 57.94570505619049, 57.41298124194145, 56.76240675151348, 53.91330063343048, 55.92468850314617, 54.76022578775883, 56.8730416148901, 56.4430832862854, 56.0165523737669, 54.28708657622337, 54.01051081717014, 57.822808250784874, 58.29139530658722, 57.5565717369318, 57.13653847575188, 56.34504474699497, 55.6273240596056, 55.63060708343983, 52.32067309319973, 47.647448256611824, 48.4557218849659, 43.592362850904465, 41.28359913825989, 39.78915832936764, 40.156157836318016, 40.23619294166565, 44.4795810431242, 52.29930683970451, 52.78712846338749, 50.90853966772556, 55.66489264369011, 54.08840283751488, 53.251566141843796, 54.15073849260807, 56.025459095835686, 54.13658045232296, 45.27336224913597, 42.330944538116455, 42.726294323801994, 37.690637335181236, 37.45493218302727, 38.51684220135212, 39.805311262607574, 38.52648228406906, 39.09420982003212, 39.951364025473595, 39.220492243766785, 38.441917821764946, 40.1916479319334, 38.5449492931366, 36.99979640543461, 40.29796622693539, 41.996178701519966, 42.44727909564972, 44.99277390539646, 48.596610724925995, 55.89053973555565, 57.52605937421322, 54.700352400541306, 54.76135052740574, 52.29713335633278, 52.1683506667614, 51.298189759254456, 54.73798178136349, 53.62074293196201, 52.84889794886112, 47.00573869049549, 44.31260660290718, 40.17504662275314, 38.37032586336136, 39.785468727350235, 41.069921404123306, 39.14911687374115, 42.587848752737045, 46.05100952088833, 47.69293561577797, 53.47999468445778, 52.65398360788822, 53.700382858514786, 54.67346504330635, 50.16006343066692, 59.79326851665974, 43.65673899650574, 35.411926209926605, 59.51858505606651, 51.34528823196888, 54.6711927652359, 49.9445465952158, 54.55610454082489, 47.996603921055794, 46.71236403286457, 43.10682110488415, 45.85028529167175, 43.14643777906895, 47.476229444146156, 48.93861897289753, 51.376575753092766, 50.33815987408161, 52.92444929480553, 54.46635715663433, 58.72810207307339, 59.38482083380222, 56.21985666453838, 25.930515378713608, 2.5731786992400885, 0.7977587613277137, 2.4374597193673253, 0.5086389253847301, 27.066582217812538, 62.87413939833641, 54.95257146656513, 54.97916243970394, 58.550928980112076, 56.06625750660896, 61.61527834832668, 56.89844325184822, 59.292588382959366, 26.024446338415146, 47.07409702241421, 45.87406821548939, 37.209157571196556, 10.973074939101934, 0.8648322871886194, 0.1336778511176817, 0.2646329998970032, 0.07483758541638963, 0.07799562416039407, 0.12409930728608742, 0.05202673404710367, 0.05262852675514296, 0.03074124106206, 0.04696312353189569, 0.117589870642405, 0.14160599210299551, 0.08936828031437472, 0.07483098030206747, 0.009721778333187103, 0.0650136727199424, 0.04833686114579905, 0.035623136718641035, 0.05256303593341727, 0.03961563517805189, 0.06432656271499582, 0.05727552153985016, 0.03404362010769546, 0.06810098479036242, 0.22573451686184853, 1.1323315207846463, 42.65964210033417, 51.148500591516495, 32.444517239928246, 45.95471888780594, 53.5603641718626, 66.85402303934097, 51.334006637334824, 64.6255262196064, 64.0519317984581, 65.19779071211815, 63.24824072420597, 58.575357869267464, 62.169930785894394, 55.10777033865452, 3.667405270971358, 4.125535525381565, 1.7837412538938224, 5.651309452950954, 51.113455072045326, 65.20429596304893, 65.66488444805145, 57.61816643178463, 57.320877984166145, 60.69813676178455, 61.16982825100422, 59.707309529185295, 59.70939181745052, 60.80645754933357, 59.50413063168526, 59.90538530051708, 58.65284711122513, 55.35803250968456, 61.81527681648731, 56.79902158677578, 58.02561476826668, 59.507208466529846, 58.24525058269501, 54.97340574860573, 57.940073758363724, 59.671447053551674, 59.62326563894749, 58.76959964632988, 60.29117859899998, 59.923232942819595, 56.68304800987244, 58.83457995951176, 55.53151220083237, 50.93502424657345, 52.18185894191265, 44.39763464033604, 43.19186434149742, 42.37323246896267, 40.8957539498806, 42.65064038336277, 48.09393189847469, 55.62225133180618, 55.48579305410385, 54.78090047836304, 59.48097087442875, 56.14583283662796, 56.060170233249664, 56.986229941248894, 57.6060488820076, 55.58260805904865, 46.43998704850674, 42.75466740131378, 46.27703279256821, 40.8529644459486, 40.970963314175606, 41.12905003130436, 44.62263956665993, 42.70669497549534, 41.7227453738451, 41.63517527282238, 42.18913234770298, 42.87963129580021, 41.57235324382782, 41.59981057047844, 40.0805950909853, 43.60107198357582, 43.407654762268066, 44.81114745140076, 45.30060298740864, 51.72552242875099, 59.07026991248131, 60.154769718647, 57.36833743751049, 57.43327595293522, 55.431790351867676, 55.134376510977745, 52.85226836800575, 56.82495519518852, 54.051947593688965, 53.975928872823715, 50.804087072610855, 46.11861169338226, 41.915569826960564, 41.2871253490448, 41.48879952728748, 42.85858802497387, 40.51041282713413, 43.807651698589325, 48.1317512691021, 49.235633835196495, 56.18052117526531, 55.96753120422363, 54.945173263549805, 56.67205519974232, 52.47699290513992, 60.854703560471535, 47.637785375118256, 38.07111091911793, 60.370841324329376, 54.89133395254612, 56.943189650774, 51.36601231992245, 56.60715848207474, 51.56373851001263, 47.074522599577904, 45.16140505671501, 48.434625416994095, 45.55040158331394, 49.66723367571831, 50.929275155067444, 53.8752418756485, 52.86466330289841, 55.01970246434212, 55.42696461081505, 60.22620588541031, 59.74348358809948, 58.82520206272602, 29.31403812021017, 3.974923244677484, 0.5401249264832586, 2.181731779128313, 0.49590690701734275, 30.626343302428722, 66.26173362135887, 60.63853695988655, 60.73158256709576, 63.63319046795368, 62.49605968594551, 66.72751262784004, 63.64517502486706, 66.10670953989029, 34.66264821588993, 59.49170529842377, 40.9462608397007, 45.34372307360172, 14.846523441374302, 0.8756488224025816, 0.08951106210588478, 0.27561916038393974, 0.01728929863020312, 0.14601129165384918, 0.06260272435611114, 0.08993784154881723, 0.04091650131158531, 0.11608832035562955, 0.04911928888759576, 0.01261940766198677, 0.21758624003268778, 0.13318246754352003, 0.12651054508751258, 0.08586730997194536, 0.20568363106576726, 0.1591401660698466, 0.11994798551313579, 0.246601230755914, 0.14407692826353014, 0.09002610517200083, 0.09228786700987257, 0.1404658009414561, 0.29354048310779035, 0.31983566586859524, 1.7403727560304105, 56.86823107302189, 71.04784280061722, 57.558711022138596, 49.49805535376072, 58.144403994083405, 77.33097285032272, 55.930718779563904, 72.74869993329048, 71.03341117501259, 73.4968113899231, 69.66290831565857, 65.96889093518257, 66.12421900033951, 58.6068581789732, 4.879866298288107, 3.857443523593247, 1.2534658145159483, 8.46378268674016, 54.76212188601494, 64.39632251858711, 69.64064911007881, 60.93041829764843, 60.48925057053566, 62.508420422673225, 64.56418991088867, 62.42617003619671, 63.6404936760664, 62.12889298796654, 62.15454921126366, 63.81659522652626, 61.422279104590416, 56.21982626616955, 64.0934331715107, 59.26709935069084, 60.67315690219402, 63.64897862076759, 60.785699263215065, 58.281344845891, 57.97836430370808, 61.9038500636816, 61.70762859284878, 61.35161429643631, 62.051327750086784, 61.08848221600056, 59.507577046751976, 61.710155457258224, 58.44000533223152, 52.83174566924572, 54.75774072110653, 47.19466455280781, 44.028309658169746, 43.5909379273653, 41.99307046830654, 45.30578590929508, 49.368128925561905, 56.99802830815315, 56.881819143891335, 56.943679824471474, 61.70576669275761, 59.367242977023125, 58.44343274831772, 60.453437492251396, 58.50300595164299, 55.272172316908836, 44.259933829307556, 45.01334600150585, 48.4197948127985, 44.24884222447872, 43.821680545806885, 43.21852371096611, 46.213154420256615, 43.587776497006416, 44.38317261636257, 45.60140244662762, 44.70359802246094, 43.85783180594444, 45.043577179312706, 44.37081567943096, 41.787045523524284, 45.74916511774063, 44.488229379057884, 44.06346917152405, 44.17557455599308, 50.26014246046543, 59.705200642347336, 62.13756412267685, 58.32483351230621, 60.24355575442314, 57.76067018508911, 56.85962833464146, 54.68579538166523, 60.51812902092934, 58.818233236670494, 56.66110038757324, 50.98135136067867, 48.779228925704956, 44.62932340800762, 42.34995111823082, 42.82876342535019, 46.18418477475643, 41.43098562955856, 47.34059192240238, 49.92052808403969, 50.726696625351906, 58.110961988568306, 57.56217263638973, 56.77171245217323, 59.316048324108124, 53.47135774791241, 63.5793549567461, 48.094783052802086, 35.242402106523514, 63.159637078642845, 56.899226009845734, 61.49908058345318, 52.99736738204956, 60.1330690830946, 53.82728464901447, 50.546213909983635, 47.18046851456165, 53.39395210146904, 46.33973702788353, 51.720928475260735, 53.97497892379761, 56.11953064799309, 55.05067840218544, 56.617353335022926, 57.499722987413406, 61.681394800543785, 62.26399853825569, 61.47012613713741, 31.87206845730543, 5.771037703379989, 2.1448554703965783, 9.98284237459302, 0.5981037591118366, 33.553468734025955, 71.1616238951683, 66.02120652794838, 66.1531126499176, 68.08778643608093, 64.56744253635406, 73.05932566523552, 68.35598364472389, 73.71967703104019, 39.4514362514019, 59.77870389819145, 56.33524127304554, 58.74971531331539, 26.003726050257683, 0.9128555352799594, 0.25385701563209295, 0.2987771068001166, 0.19943587569287047, 0.15646695013856515, 0.19640519691165537, 0.15193101775366813, 0.26575759111437947, 0.22610241430811584, 0.18678774969885126, 0.1625080915982835], [0.038437379262177274, 0.09384685952682048, 0.06254542313399725, 0.05576461277087219, 0.029727825422014575, 0.06447524458053522, 0.020663530558522325, 0.04987691776477732, 0.023135989977163263, 0.09963316973880865, 0.025258005407522433, 0.03188884998962749, 0.030885460764693562, 0.48149083682801574, 0.2631265885429457, 15.835106894373894, 47.91539467871189, 35.92386893928051, 28.421414718031883, 28.654410615563393, 52.935354709625244, 59.72116358578205, 49.58775334060192, 60.16669347882271, 55.997211411595345, 59.345857724547386, 52.251235619187355, 56.87103532254696, 49.30889770388603, 3.5166162997484207, 5.411389851942658, 2.419744119979441, 0.6996263551991433, 31.715623252093792, 66.68354898691177, 64.775929749012, 59.064676612615585, 52.381751015782356, 51.37136623263359, 53.14763031899929, 52.79289275407791, 53.40662822127342, 53.09909552335739, 53.40759336948395, 54.497051909565926, 52.78278909623623, 53.77569101750851, 53.49389813840389, 58.872961699962616, 57.99786105751991, 58.157429695129395, 58.34391228854656, 58.873896449804306, 56.283279061317444, 53.946936428546906, 53.70330110192299, 54.89479556679726, 56.552274227142334, 59.93256524205208, 55.69375589489937, 57.932177782058716, 54.873991683125496, 51.094801872968674, 47.63523191213608, 45.040206760168076, 41.069499626755714, 40.86714528501034, 40.41813097894192, 42.36180268228054, 41.94231279194355, 53.79382364451885, 52.90644586086273, 53.43700759112835, 54.81283396482468, 53.99359032511711, 54.352302476763725, 54.293519631028175, 50.09192928671837, 45.12613154947758, 43.32766145467758, 44.469914361834526, 39.3532495200634, 37.999214977025986, 39.84273925423622, 38.0175755918026, 37.59847328066826, 38.956797793507576, 42.12626092135906, 37.101391553878784, 42.0197868347168, 39.79403346776962, 39.291852414608, 37.55678951740265, 36.29253275692463, 37.43784449994564, 39.90384757518768, 41.38260282576084, 42.18052200973034, 44.91862088441849, 48.32706078886986, 55.28493583202362, 56.97988048195839, 55.414486080408096, 53.32587495446205, 53.81811574101448, 54.32806357741356, 55.920155346393585, 52.47470922768116, 52.68820457160473, 49.281029999256134, 46.66911855340004, 37.92855016887188, 38.49022462964058, 38.887166529893875, 40.875341445207596, 40.62908425927162, 41.874608024954796, 42.822482362389565, 49.38514441251755, 53.46049413084984, 55.05121037364006, 52.134441286325455, 54.47548046708107, 49.288302809000015, 57.31830172240734, 43.164684399962425, 38.21425683796406, 60.914728939533234, 51.47355034947395, 57.14178219437599, 52.695576176047325, 57.21522465348244, 53.44883635640144, 53.98962713778019, 47.215130254626274, 45.7673205435276, 43.30214202404022, 46.55335396528244, 48.20070616900921, 47.84536823630333, 49.72775682806969, 52.80026435852051, 54.339740350842476, 56.430019587278366, 51.48025318980217, 45.87817199528217, 35.3948575258255, 3.3768460247665644, 0.4045804700581357, 1.5582290547899902, 0.7671121589373797, 33.10272932052612, 56.90638102591038, 55.30894294381142, 56.660887598991394, 54.09209243953228, 51.372141391038895, 59.43075276911259, 58.842502534389496, 45.07589444518089, 25.817249156534672, 45.385984405875206, 31.994560584425926, 37.33513601124287, 2.6367108151316643, 0.5171298666391522, 0.14103151042945683, 0.10888884222367778, 0.1827580956160091, 0.09224227687809616, 0.026768812131194863, 0.023222977106343023, 0.15319663187256083, 0.031683360430179164, 0.07249177535413764, 0.022612547654716764, 0.0564126338576898, 0.015054394189064624, 0.03440310531004798, 0.02081837781588547, 0.012625239087356022, 0.04724695420009084, 0.019726606224139687, 0.06786175348679535, 0.06996615033131093, 0.05897312126762699, 0.009247856742149452, 0.035888283819076605, 0.07402841438306496, 0.44042682624422014, 0.34939291421324015, 23.08909434825182, 62.03356750309467, 34.45409260690212, 41.274540424346924, 44.741687178611755, 56.06498457491398, 63.65371696650982, 55.05991570651531, 67.33522161841393, 62.02075079083443, 66.4015357196331, 58.18987235426903, 60.75698800384998, 55.04913188517094, 4.49442258104682, 5.511758616194129, 2.387909428216517, 1.525890533812344, 35.973995849490166, 66.46359398961067, 67.0249454677105, 61.53851106762886, 58.201070353388786, 54.659208208322525, 53.981297984719276, 55.09879142045975, 55.892337039113045, 56.578052043914795, 55.30416280031204, 55.22502064704895, 56.514390259981155, 56.42954081296921, 55.14321103692055, 58.6154343187809, 58.95864710211754, 59.68902111053467, 60.2009866386652, 60.9329679608345, 58.35599564015865, 53.54974374175072, 52.463762015104294, 56.05879470705986, 57.80732408165932, 61.09012372791767, 57.584462240338326, 59.133612513542175, 57.927067056298256, 53.28304745256901, 49.26604360342026, 48.32486070692539, 42.81151995062828, 42.68770359456539, 40.27889505028725, 44.369694739580154, 44.020128697156906, 55.84009364247322, 54.90859642624855, 56.35992854833603, 57.07838259637356, 55.53821124136448, 58.12337212264538, 56.34817957878113, 52.01979383826256, 45.47669313848019, 43.57460260391235, 46.4107970148325, 42.06196077167988, 39.96112950146198, 40.81362135708332, 41.24899059534073, 41.34428948163986, 42.195371612906456, 43.204567059874535, 41.61459177732468, 42.644169330596924, 42.75651030242443, 40.305322632193565, 39.49924148619175, 38.34086984395981, 41.31689295172691, 43.418715968728065, 45.19391991198063, 42.29051850736141, 45.92791132628918, 49.83917444944382, 58.961413353681564, 59.460197389125824, 57.209331169724464, 55.45669041574001, 57.643955647945404, 56.14617481827736, 57.29891896247864, 55.717394426465034, 57.48251751065254, 51.8996936827898, 48.033332750201225, 40.56258782744408, 41.005632653832436, 41.174544990062714, 43.396950736641884, 41.576723009347916, 44.13105234503746, 46.21080994606018, 50.91029517352581, 53.93302537500858, 56.39602281153202, 55.81713907420635, 57.16701664030552, 52.05968029797077, 57.33442045748234, 50.126347839832306, 45.09370028972626, 60.19257768988609, 54.17111299932003, 59.09448221325874, 57.893146276474, 56.97361081838608, 57.685229033231735, 57.74922139942646, 49.55811873078346, 48.401483595371246, 47.461573630571365, 46.971373334527016, 49.25846301019192, 50.829135328531265, 52.127966433763504, 54.23305347561836, 56.84982106089592, 58.8892438262701, 55.12166999280453, 44.852641224861145, 37.71240636706352, 3.7122951122000813, 0.617353644920513, 2.0865651732310653, 0.33299842674750835, 36.84741698205471, 61.86755821108818, 59.52486611902714, 60.74299335479736, 59.81943391263485, 57.682022005319595, 64.38319802284241, 64.7643555700779, 49.26055669784546, 38.07017616927624, 47.90043868124485, 33.536696434020996, 49.82153199613094, 3.58866352122277, 0.33424069290049374, 0.15369542932603508, 0.12355798477074131, 0.150815287779551, 0.06685528249363415, 0.039476430538343266, 0.058247786946594715, 0.1951976484269835, 0.056887036917032674, 0.09771744909812696, 0.05432066056528129, 0.12742818100377917, 0.20313539280323312, 0.14592790394090116, 0.16375115927075967, 0.11886563734151423, 0.1037427902338095, 0.12424815242411569, 0.15395716996863484, 0.19847697636578232, 0.2814091293839738, 0.10617154272040352, 0.18168937327573076, 0.16599875350948423, 0.6719648488797247, 0.4476795089431107, 31.383327282965183, 77.0406000316143, 49.784377589821815, 42.27719262242317, 42.74023957550526, 65.17398878931999, 68.7288348376751, 66.106116771698, 72.24179953336716, 68.91874104738235, 71.62250876426697, 64.89328265190125, 64.39775884151459, 62.49677784740925, 4.232593355700374, 8.126840516924858, 3.589770686812699, 3.513366999104619, 40.09168289601803, 68.97585198283195, 71.48586049675941, 64.95710402727127, 59.41021867096424, 57.49704033136368, 57.460463494062424, 58.70214946568012, 57.3255555331707, 60.484033450484276, 57.7291014790535, 57.62340635061264, 58.023889660835266, 58.64084355533123, 58.595895767211914, 61.765320897102356, 62.11253486573696, 62.1564757078886, 60.61794586479664, 63.64694572985172, 61.36623211205006, 53.63843098282814, 53.81361298263073, 56.928545236587524, 60.2909430116415, 63.32881920039654, 57.35244669020176, 63.862055987119675, 60.38842298090458, 53.98326627910137, 52.52434976398945, 49.94614630937576, 44.906081557273865, 45.45129530131817, 44.01710405945778, 46.721920520067215, 45.62013544142246, 60.051115080714226, 56.67118884623051, 59.14557807147503, 58.978668227791786, 59.41519260406494, 61.58012643456459, 57.93026648461819, 51.32219687104225, 44.82863791286945, 45.33180691301823, 50.900404304265976, 43.20279635488987, 41.921033933758736, 44.504515305161476, 42.529563680291176, 43.00195813179016, 44.01410982012749, 46.16379126906395, 43.34643244743347, 46.89763829112053, 46.74264460802078, 44.7067404538393, 41.04262746870518, 41.17123916745186, 44.28051732480526, 45.488491505384445, 46.6236387938261, 43.808879032731056, 44.58588793873787, 48.602614402770996, 59.33087132871151, 62.50425584614277, 61.03945344686508, 59.1285739839077, 58.91455426812172, 57.99067564308643, 60.32199874520302, 57.73970291018486, 61.06872707605362, 53.64695392549038, 49.446085542440414, 42.8213994204998, 42.505560368299484, 44.72408652305603, 46.75636947154999, 43.70657332241535, 45.00074587762356, 48.17877754569054, 55.275155156850815, 57.0393130928278, 58.2895752042532, 56.586875170469284, 58.964475989341736, 51.98988564312458, 58.21021266281605, 47.642793506383896, 38.46989192068577, 63.726380467414856, 56.3802270591259, 62.67035633325577, 58.47697734832764, 61.10269345343113, 57.77118422091007, 61.7885984480381, 52.46639907360077, 51.34430788457394, 49.5161347836256, 50.36337152123451, 51.260150000452995, 52.13400810956955, 54.045199155807495, 57.702628299593925, 58.770986571908, 60.256231874227524, 56.219453886151314, 51.296533048152924, 42.61560246348381, 5.376382330432534, 2.177871661260724, 5.493657337501645, 0.6061704887542874, 40.391118228435516, 67.93591618537903, 64.39941555261612, 66.07498124241829, 65.67846491932869, 61.85794472694397, 70.65669938921928, 69.12000864744186, 59.73928861320019, 38.482161462306976, 54.21780489385128, 43.10010306537151, 63.46800193190575, 6.124620605260134, 0.8223224245011806, 0.24091338127618656, 0.2423426092718728, 0.24214965087594464, 0.14586053177481517, 0.15218921093037352, 0.14375952654518187, 0.2923256467329338, 0.09809373281314038, 0.13217991509009153, 0.11122585041448474], [0.04397089913254604, 0.019513491097313818, 0.07140164947486483, 0.02055315278994385, 0.03295304522907827, 0.035613095460576005, 0.05717256339266896, 0.05720959656173363, 0.02760029397904873, 0.06784066907130182, 0.0495533970388351, 0.07411109705572017, 0.05804172593343537, 0.307384030893445, 0.19658540521049872, 3.4268857771530747, 47.93943218886852, 37.41787277162075, 32.701463252305984, 31.17051400244236, 43.10877040028572, 67.03307703137398, 62.01041154563427, 55.227433517575264, 57.994372844696045, 58.96031901240349, 54.21381130814552, 54.45760242640972, 46.88115857541561, 4.68125713057816, 4.430163279175758, 4.712028354406357, 0.43953592248726636, 27.81151134520769, 63.154602348804474, 62.87834197282791, 58.45209628343582, 58.52979451417923, 53.134882003068924, 48.63055810332298, 53.88862855732441, 50.69656424224377, 53.44060219824314, 53.53157691657543, 55.3919342905283, 53.917146027088165, 57.17783086001873, 55.7999411970377, 58.10362458229065, 59.37113776803017, 59.74272362887859, 58.00962142646313, 60.73091380298138, 58.94262716174126, 58.49909596145153, 58.17324824631214, 55.60688875615597, 54.30111922323704, 58.06526184082031, 56.79619073867798, 57.683462128043175, 56.2405389547348, 53.19818280637264, 49.44062143564224, 45.5442763119936, 40.960776060819626, 41.40684552490711, 39.15122576057911, 40.260800421237946, 42.31326028704643, 44.54472854733467, 49.29740712046623, 51.47165425121784, 51.772389113903046, 52.255377396941185, 48.7325294315815, 46.49044834077358, 45.51475569605827, 47.384266778826714, 43.53713281452656, 39.36704657971859, 36.0294196754694, 38.532007187604904, 37.60144852101803, 40.19407220184803, 39.734893441200256, 38.96030880510807, 37.23669849336147, 40.31754657626152, 38.038402274250984, 37.351342141628265, 38.83501052856445, 38.59860621392727, 36.70074865221977, 35.49792319536209, 35.371321588754654, 39.631303399801254, 40.90620718896389, 44.15917843580246, 43.490053340792656, 47.52208538353443, 50.62566764652729, 54.84937280416489, 53.65644961595535, 53.5337769985199, 54.92851495742798, 53.3328627794981, 54.34947922825813, 53.88029560446739, 50.963644310832024, 42.79297694563866, 37.13412679731846, 37.627214938402176, 37.965043410658836, 39.10130403935909, 39.24260325729847, 42.883203104138374, 44.427071660757065, 48.93008083105087, 51.19664780795574, 55.010294169187546, 50.95840819180012, 54.889905229210854, 49.75576512515545, 54.91191744804382, 55.87573952972889, 55.86990684270859, 57.138947546482086, 53.39694634079933, 55.46086259186268, 53.16614292562008, 53.27499948441982, 50.82562431693077, 55.05759783089161, 57.83744506537914, 54.27215717732906, 52.67770953476429, 50.07314309477806, 49.75359924137592, 47.94718377292156, 53.12621846795082, 53.765682354569435, 58.11570033431053, 56.92602977156639, 55.27941852807999, 36.90281040966511, 28.62608503550291, 2.7300010342150927, 0.4088738834252581, 1.7426662892103195, 1.168123462703079, 33.41945372521877, 62.55934529006481, 53.389240354299545, 52.20783814787865, 46.582221016287804, 58.03803250193596, 58.51661302149296, 64.14888739585876, 35.8080093562603, 32.03076884150505, 47.46750891208649, 42.25208356976509, 26.762484535574913, 0.7106023631058633, 0.06549251382239163, 0.22434803657233715, 0.12772034970112145, 0.1803872306481935, 0.1400117253069766, 0.09147514108917676, 0.03136357270705048, 0.015512652753386647, 0.1446662232046947, 0.08052737190155312, 0.039017916860757396, 0.007888119744166033, 0.06580539586138912, 0.0643407080497127, 0.06518432215671055, 0.03905285717337392, 0.03671970443974715, 0.006433308990381192, 0.07680880386033095, 0.02392607111687539, 0.1051148580154404, 0.016540031901968177, 0.11175621883012354, 0.19608371338108554, 0.3731473989319056, 0.2661761920899153, 7.2294393461197615, 60.3742041438818, 40.039302706718445, 26.41372974961996, 40.06985306739807, 49.744741916656494, 71.37018710374832, 67.01653271913528, 62.59935714304447, 63.464407324790955, 64.59760531783104, 58.39597329497337, 60.37904128432274, 52.56597273051739, 4.26883771084249, 3.2522834837436676, 5.034979674965143, 1.0003488091751933, 31.093459837138653, 66.88623771071434, 66.67614698410034, 61.303280889987946, 60.49263618886471, 55.89489430189133, 50.06152331829071, 55.133741945028305, 51.47297278046608, 55.02424322068691, 56.019326224923134, 57.12570905685425, 55.787994638085365, 58.827348947525024, 57.7750676125288, 58.952563628554344, 61.05144560337067, 60.040164068341255, 61.402417570352554, 62.97970153391361, 60.801734402775764, 59.43534292280674, 58.72757390141487, 56.25716686248779, 56.566337272524834, 59.386770129203796, 57.405111864209175, 58.88224460184574, 58.4102301299572, 56.26332253217697, 53.34746539592743, 47.88806274533272, 42.88822643458843, 44.44438733160496, 40.630965158343315, 44.191013127565384, 44.67906653881073, 47.87157163023949, 51.24177798628807, 56.5847434848547, 53.732977509498596, 55.920162945985794, 52.0979518443346, 46.925110816955566, 45.378384813666344, 46.754849553108215, 45.801074132323265, 42.454890087246895, 40.063089430332184, 41.007638946175575, 38.90411742031574, 41.88136026263237, 41.657818257808685, 43.53371299803257, 41.27028085291386, 41.306929886341095, 41.70889511704445, 39.63793024420738, 42.73617759346962, 40.4216305911541, 40.98498456180096, 38.60212862491608, 38.65993872284889, 42.33200088143349, 43.977191001176834, 45.39355739951134, 42.89871007204056, 49.43821996450424, 55.449873581528664, 58.57156567275524, 56.20639018714428, 54.95517432689667, 57.713681906461716, 55.35868227481842, 56.5770260989666, 57.071485966444016, 51.7246712744236, 45.51401473581791, 38.432775512337685, 39.07439388334751, 40.95291428267956, 41.85644879937172, 41.63552485406399, 44.57825414836407, 46.12042039632797, 51.67580209672451, 54.38641704618931, 56.537242233753204, 53.34012798964977, 56.64064608514309, 52.0410080999136, 55.93206010758877, 59.141732677817345, 59.94735024869442, 57.590602710843086, 55.48912927508354, 56.11926466226578, 55.44503644108772, 55.97576916217804, 53.49289879202843, 56.60241633653641, 61.53437688946724, 56.94108456373215, 54.38146211206913, 51.28568463027477, 51.984771117568016, 48.864576146006584, 55.3075560182333, 56.22894957661629, 60.85562691092491, 59.9457011371851, 59.91019584238529, 44.286053627729416, 31.840513050556183, 3.9929886627942324, 0.1520233557675965, 2.055709878914058, 1.0633848141878843, 36.867058128118515, 66.83373212814331, 59.12768863141537, 57.45773144066334, 52.99320660531521, 61.71093821525574, 62.84376002848148, 67.85916030406952, 42.847823202610016, 41.45058877766132, 36.50505915284157, 49.729272946715355, 31.184991225600243, 0.7409753208048642, 0.042072051219292916, 0.23554003913886845, 0.058947290817741305, 0.1282079258817248, 0.10899288390646689, 0.06094056217989419, 0.030894561350578442, 0.005246066129984683, 0.06404650586773641, 0.07884622929850593, 0.08803327538771555, 0.2748014620738104, 0.15035526012070477, 0.23555589141324162, 0.18652985338121653, 0.14015785418450832, 0.12227937564603053, 0.12359532222035341, 0.18036334833595902, 0.19323674583574757, 0.21269795077387244, 0.1329323637764901, 0.31883204472251236, 0.3555179777322337, 0.772422730224207, 0.42686755070462823, 8.778507448732853, 77.36286833882332, 55.21431282162666, 45.112212896347046, 44.61513876914978, 56.873774975538254, 81.25628381967545, 76.62134572863579, 68.89678582549095, 69.51258838176727, 70.95626771450043, 65.37717148661613, 65.04072993993759, 57.86866798996925, 5.72910220362246, 12.779338415712118, 12.83952433615923, 2.3442139104008675, 32.747288793325424, 68.85644719004631, 69.1672933101654, 66.23775690793991, 63.94706502556801, 60.400244146585464, 52.56279610097408, 59.0406809002161, 55.53876221179962, 56.013014763593674, 59.738642647862434, 61.32895991206169, 56.153990998864174, 62.650673389434814, 60.47587528824806, 61.207522228360176, 62.510187327861786, 63.38819481432438, 63.83123204112053, 64.5371961593628, 62.09221735596657, 62.838280722498894, 61.39551714062691, 56.55649200081825, 57.41518132388592, 61.188029274344444, 61.77419722080231, 63.41728985309601, 60.0215944647789, 59.258424416184425, 56.61368653178215, 50.300758481025696, 45.129319578409195, 46.79341368377209, 44.654056280851364, 45.44371850788593, 46.05512090027332, 49.25049863755703, 53.43839451670647, 55.97456082701683, 54.750585705041885, 57.164098396897316, 51.880641505122185, 46.11884728074074, 46.69725984334946, 48.7208716571331, 47.69779555499554, 44.75774511694908, 41.99135676026344, 43.30352894961834, 41.65836542844772, 44.513965398073196, 45.51568664610386, 45.54657518863678, 41.91231720149517, 44.36687529087067, 44.9212921410799, 42.022545486688614, 45.424031764268875, 43.82391482591629, 42.969530671834946, 40.76631389558315, 42.080344185233116, 46.74965523183346, 45.59506058692932, 46.11173406243324, 42.21641108393669, 47.52789527177811, 54.306340143084526, 60.194827169179916, 57.777309492230415, 59.51053708791733, 59.851424396038055, 56.50864116847515, 58.449193239212036, 58.574673905968666, 53.643477112054825, 47.92237110435963, 39.71713699400425, 40.53367517888546, 43.34538370370865, 43.66908833384514, 42.89713695645332, 45.93025200068951, 46.9248828291893, 53.55854406952858, 55.34026086330414, 59.709908589720726, 53.6252760887146, 58.75299833714962, 52.936118468642235, 59.85444903373718, 56.71748176217079, 54.67450238764286, 58.89284983277321, 54.75232221186161, 56.819118708372116, 56.70761749148369, 57.78564244508743, 56.99299357831478, 58.23014639317989, 62.66722910106182, 59.23887826502323, 55.220677480101585, 53.67845803499222, 56.30436792969704, 50.43585263192654, 57.91596405208111, 58.215482980012894, 64.02990058064461, 61.28767512738705, 59.30566728115082, 39.749796241521835, 35.67491389811039, 5.4999355506151915, 1.0891162022016943, 6.03512923233211, 1.5307760029099882, 41.80883355438709, 71.27496421337128, 63.67763668298721, 62.03947998583317, 60.765161365270615, 68.58574971556664, 70.15870571136475, 73.79650890827179, 46.28484897315502, 42.956170588731766, 57.06656143069267, 59.04068470001221, 45.509268790483475, 0.6581788917537779, 0.14810756198130548, 0.3428840119158849, 0.16718188533559442, 0.29679488972760737, 0.2769080037251115, 0.19012736971490085, 0.2501430711708963, 0.21882825385546312, 0.19876185717293993, 0.29879871814046055, 0.2041942297364585], [0.06578111278940924, 0.04536267093499191, 0.014821680797467707, 0.14328612538520247, 0.028546350440592505, 0.11568323388928548, 0.05474400386447087, 0.04197288544673938, 0.044081156302127056, 0.08135223193676211, 0.03585724720323924, 0.09021184989251196, 0.10649324889527634, 0.07460209453711286, 0.2842856344068423, 0.4563090833835304, 30.985686220228672, 50.35450279712677, 47.56722696125507, 33.68851348757744, 35.1388006657362, 54.54314723610878, 61.75333634018898, 55.94271093606949, 61.36449560523033, 59.13751110434532, 55.905731320381165, 54.82388377189636, 42.186153307557106, 6.271652765572071, 5.218542600050569, 2.627594154328108, 1.090838578529656, 31.285991705954075, 68.1542220711708, 65.3821188211441, 59.61383834481239, 59.87558729946613, 51.97085626423359, 47.75434412062168, 50.872464403510094, 54.26391541957855, 54.392777904868126, 54.809170961380005, 55.48260882496834, 56.7420968413353, 55.8697472512722, 56.83032810688019, 58.39000001549721, 58.366502076387405, 61.67110115289688, 61.34966500103474, 60.28426297008991, 58.913376331329346, 58.13473731279373, 59.49284143745899, 57.42420583963394, 57.934047281742096, 56.72321945428848, 56.17754213511944, 58.97366389632225, 58.23429957032204, 57.67609812319279, 48.21985334157944, 43.971008732914925, 43.65644261240959, 41.44215703010559, 40.317755565047264, 40.311067923903465, 41.45404279232025, 42.39457592368126, 47.54490315914154, 51.18481904268265, 52.86919645965099, 51.05920538306236, 44.782812371850014, 46.393397748470306, 48.456398248672485, 45.668647438287735, 40.758015140891075, 40.49047909677029, 38.15304212272167, 38.99886153638363, 39.613296166062355, 37.94002555310726, 38.69428128004074, 39.18228529393673, 38.40383246541023, 38.32404814660549, 38.04692901670933, 37.91288360953331, 37.02796809375286, 38.8348813354969, 36.14465229213238, 37.86342166364193, 39.0128143876791, 36.19712747633457, 34.81687813997269, 41.11908316612244, 44.163118824362755, 43.033424243330956, 42.827422097325325, 47.92571112513542, 54.385128915309906, 57.052559182047844, 54.51257027685642, 54.69162426888943, 52.42452912032604, 53.57214353978634, 46.62828974425793, 42.37523876130581, 38.86934168636799, 38.33343364298344, 36.192130744457245, 39.12879556417465, 39.56228770315647, 42.41158381104469, 43.10138359665871, 47.005271315574646, 49.16118822991848, 54.47818212211132, 52.69643113017082, 53.54331448674202, 50.87990440428257, 48.10565426945686, 55.935213938355446, 51.78096145391464, 53.76152537763119, 54.6378343552351, 54.701853320002556, 53.372844234108925, 49.79822404682636, 46.60915397107601, 44.14424143731594, 48.76027174293995, 54.204387813806534, 55.43228052556515, 53.2003752887249, 53.6764707416296, 53.918380960822105, 52.052977457642555, 55.730051547288895, 58.45066376030445, 58.25023211538792, 60.24839289486408, 63.04990656673908, 31.14153865724802, 3.9676421228796244, 0.35991294658742845, 0.7459767430555075, 0.5698026996105909, 43.109347969293594, 58.87761265039444, 53.72883193194866, 55.65435580909252, 59.015207067131996, 62.84650728106499, 54.41211126744747, 53.24311539530754, 31.313236244022846, 46.6263822466135, 37.2194018214941, 42.71992206573486, 8.814035542309284, 0.584979560226202, 0.17876618716400117, 0.31162855157162994, 0.09658588911406696, 0.23226724209962413, 0.03632701926107984, 0.05954360276518855, 0.04005942835647147, 0.02661537866515573, 0.06625047666602768, 0.12872641993453726, 0.034566344402264804, 0.010955771394947078, 0.022725472845195327, 0.09873315982986242, 0.07979834539582953, 0.019907052010239568, 0.010901887762884144, 0.036659557081293315, 0.05487937531142961, 0.015361394707724685, 0.06009184580761939, 0.07853195202187635, 0.04435683447809424, 0.034095737428287975, 0.03517946970532648, 0.3220093570416793, 0.49872490111738443, 40.75657121837139, 59.328800439834595, 43.52904684841633, 43.988605588674545, 45.89840590953827, 58.80165092647076, 70.247423350811, 61.59898862242699, 66.74026474356651, 66.46320641040802, 62.23303399980068, 59.90611486136913, 47.38370060920715, 5.474247504025698, 3.283570767380297, 3.4021538542583585, 1.5386798162944615, 33.53701941668987, 71.44943565130234, 67.75319159030914, 63.76844421029091, 61.27508260309696, 55.73396533727646, 52.1060986071825, 53.57552915811539, 56.98651872575283, 57.87340633571148, 56.37886293232441, 57.34834671020508, 58.42812716960907, 59.272745847702026, 59.77384775876999, 62.499604895710945, 59.906726628541946, 60.720202177762985, 63.591122925281525, 61.91265419125557, 61.24549359083176, 59.64940823614597, 60.17666034400463, 59.60710130631924, 58.565900176763535, 57.68100365996361, 59.294929057359695, 59.592555686831474, 61.52363486588001, 58.03884945809841, 51.47621400654316, 46.790221855044365, 44.312937185168266, 44.3673312664032, 43.05885627865791, 42.352819964289665, 43.84118489921093, 43.87642040848732, 49.687323197722435, 51.665892228484154, 55.063468515872955, 53.173693120479584, 47.17029646039009, 45.30528053641319, 49.87932309508324, 48.9839543402195, 44.011225774884224, 41.26529932022095, 40.239198580384254, 40.90816408395767, 40.625029876828194, 40.59257201850414, 39.77615922689438, 41.06791131198406, 39.11413215100765, 41.46748647093773, 40.53624764084816, 40.157202780246735, 39.81457896530628, 40.735136568546295, 38.80327083170414, 40.46345494687557, 40.38104496896267, 39.60897959768772, 41.16532288491726, 44.93645712733269, 45.04111111164093, 44.0042569488287, 44.917845726013184, 49.177071377635, 57.13700205087662, 57.508150935173035, 55.677621960639954, 57.11532421410084, 56.052418649196625, 56.460159569978714, 48.148762956261635, 44.43144902586937, 40.05378372967243, 39.19652312994003, 39.89042669534683, 39.082757234573364, 41.7674195766449, 44.77620832622051, 47.096948996186256, 49.52336199581623, 51.42940811812878, 57.955732718110085, 54.70010161399841, 55.48724077641964, 53.48696731030941, 50.972125455737114, 56.9965235888958, 54.19592946767807, 56.968310102820396, 57.38365441560745, 56.068172603845596, 55.42861372232437, 51.3177815079689, 46.38808563351631, 47.87830866873264, 50.79353503882885, 56.09825558960438, 57.75721997022629, 54.4550109654665, 55.54714076220989, 54.52329330146313, 55.189446955919266, 60.028399899601936, 60.58362990617752, 59.94958072900772, 59.9319002777338, 62.286546528339386, 37.15149186551571, 4.828489255160093, 0.35262974677607417, 0.8058935904409736, 0.823688629316166, 46.866730749607086, 63.90710636973381, 57.95212671160698, 60.925208777189255, 65.10243862867355, 66.54682472348213, 62.313711270689964, 58.87608513236046, 36.6039602458477, 51.338801980018616, 34.71565157175064, 51.72722093760967, 10.745528899133205, 0.5946897016838193, 0.12574947264511138, 0.21983473969157785, 0.07557251941761933, 0.05682663722836878, 0.009063434899871936, 0.018697479317779653, 0.01978536762180738, 0.019060768026974984, 0.020540736659313552, 0.13183279777877033, 0.03889408952090889, 0.10360344458604231, 0.11696236993884668, 0.16691895725671202, 0.29069030948448926, 0.22664059011731297, 0.23204027849715203, 0.1145369719597511, 0.2815213124267757, 0.0917292079248, 0.19267280265921727, 0.1997539898729883, 0.16054591251304373, 0.20215611410094425, 0.17370758985634893, 0.46578004548791796, 0.5412569688633084, 49.86749432981014, 74.0220496058464, 60.121396109461784, 51.06746233999729, 48.280596882104874, 65.38527265191078, 77.49760910868645, 68.93209353089333, 74.0427964925766, 74.5186297595501, 66.68713599443436, 66.40494033694267, 53.82179394364357, 9.657093454152346, 11.70410631224513, 8.566026650369167, 3.781811431981623, 37.8290943056345, 73.22691947221756, 71.08352288603783, 68.04528191685677, 65.87943613529205, 58.76839131116867, 53.13628792762756, 56.71930946409702, 59.00074504315853, 62.644996494054794, 58.72521422803402, 59.776579812169075, 60.28227187693119, 60.83461403846741, 63.01033928990364, 62.937128618359566, 60.54189294576645, 64.28015515208244, 63.31151492893696, 64.72454130649567, 63.065120950341225, 62.01730817556381, 62.8624664247036, 62.31457382440567, 60.3654608130455, 60.03071017563343, 60.11772930622101, 62.56877638399601, 62.37606592476368, 62.634577453136444, 53.125682696700096, 49.365932643413544, 46.090402007102966, 46.91268168389797, 45.86547687649727, 45.38233660161495, 44.43372890353203, 46.17171384394169, 51.737282797694206, 53.987446054816246, 57.48389683663845, 54.05567139387131, 46.59512512385845, 47.22937569022179, 52.20873109996319, 47.93391488492489, 44.318218901753426, 45.11758200824261, 42.69213795661926, 43.850809782743454, 43.638917952775955, 41.86394579708576, 43.3060672134161, 44.99059282243252, 42.21591331064701, 43.53402838110924, 42.1294679492712, 40.703906044363976, 41.052092760801315, 44.31899406015873, 40.66941149532795, 42.93802656233311, 43.49089689552784, 42.6127640157938, 43.97541269659996, 46.297114714980125, 46.03978492319584, 42.56796441972256, 43.41070979833603, 48.08712646365166, 58.91820207238197, 59.99319098889828, 58.662817776203156, 59.61532786488533, 57.211234867572784, 58.431801572442055, 49.46720860898495, 44.93765026330948, 42.364302948117256, 42.71895311772823, 42.15643510222435, 43.31422157585621, 43.86505141854286, 47.09834352135658, 47.88665682077408, 52.787759229540825, 53.37138131260872, 59.93019416928291, 57.024091109633446, 56.74335837364197, 55.619492679834366, 51.4527540653944, 58.4412706643343, 57.5853855907917, 58.47163863480091, 59.55255143344402, 59.523517191410065, 56.34923592209816, 52.50215135514736, 50.81080511212349, 53.75905551016331, 53.92835162580013, 56.6409994661808, 59.97997909784317, 56.508405581116676, 58.45493093132973, 57.930737659335136, 57.43953041732311, 61.5442069619894, 63.86431306600571, 61.83056719601154, 61.41210325062275, 61.8234995752573, 33.753706589341164, 5.842934120446444, 0.7149726629722863, 5.076083494350314, 1.7081382544711232, 52.21604950726032, 70.26385366916656, 63.636804074048996, 65.60641318559647, 70.84317818284035, 71.54649764299393, 65.73211804032326, 68.44881266355515, 42.78403602540493, 63.65668460726738, 49.176155626773834, 64.25994023680687, 19.64908953756094, 0.7619637914467603, 0.2780296263517812, 0.4577705205883831, 0.18085974123096094, 0.2577059715986252, 0.15247094503138214, 0.09508318107691593, 0.0907024614571128, 0.08368720664293505, 0.14780500321649015, 0.3360555408289656, 0.11730914586223662], [0.068050882400712, 0.07342357144807465, 0.011639931362878997, 0.04400364268803969, 0.02617189718876034, 0.0774246380024124, 0.09712372353533283, 0.03692659294756595, 0.01106279001760413, 0.0431499465048546, 0.07077958871377632, 0.028822568528994452, 0.08548458441509865, 0.08402098756050691, 0.13725486933253706, 0.17522140784421936, 7.764063533395529, 49.3593779951334, 28.788693509995937, 20.307318717241287, 34.72972221672535, 53.215403482317924, 64.11588996648788, 57.28188067674637, 60.66063657402992, 58.189507573843, 59.789879098534584, 54.396619498729706, 55.54739534854889, 5.201460616663098, 1.1234562657773495, 2.053214362822473, 1.237834997009486, 37.33005568385124, 64.74644333124161, 64.46934700012207, 61.18496283888817, 55.25796487927437, 52.23703198134899, 49.82494421303272, 50.43630100786686, 54.62933421134949, 53.89826484024525, 56.05100892484188, 56.437847167253494, 56.84181489050388, 58.54895308613777, 57.530121356248856, 57.798181772232056, 60.42678952217102, 60.12682221829891, 61.1434880644083, 61.622216776013374, 59.616627395153046, 57.97581844031811, 57.42866300046444, 55.08892334997654, 58.52012023329735, 58.14657747745514, 58.61807897686958, 59.01944383978844, 55.82946941256523, 55.155514776706696, 51.09611660242081, 45.91604836285114, 42.25437484681606, 40.31342379748821, 41.09595000743866, 39.76246476173401, 44.27937738597393, 46.44091039896011, 46.83410570025444, 55.87468698620796, 57.303144335746765, 45.70744715631008, 47.21958741545677, 50.42883820831776, 45.679872035980225, 40.67334808409214, 38.3525276184082, 38.49604971706867, 38.410687297582626, 37.22866952419281, 38.00918184220791, 37.628465071320534, 37.74249315261841, 36.67369410395622, 39.03423763811588, 37.359462305903435, 37.28996403515339, 38.13777074217796, 39.50309827923775, 38.81597355008125, 39.7433327883482, 38.55154573917389, 36.97177290916443, 38.30324426293373, 37.541814520955086, 36.652035266160965, 40.101961344480515, 45.26037074625492, 43.570992797613144, 41.70716241002083, 46.35316550731659, 48.67232546210289, 52.331320121884346, 50.863109305500984, 48.203628212213516, 46.01638197898865, 42.12822161614895, 41.04168511927128, 38.11904914677143, 36.60363346338272, 37.413031831383705, 37.83468760550022, 39.524183347821236, 39.858914986252785, 45.49011781811714, 44.449908435344696, 46.416359916329384, 48.542577624320984, 50.72224706411362, 50.11354252696037, 52.74629965424538, 51.633316576480865, 49.56863656640053, 50.89692369103432, 50.99862903356552, 50.87336115539074, 56.19692109525204, 53.55951301753521, 54.696450009942055, 53.15198488533497, 57.50371277332306, 54.40983138978481, 55.748788341879845, 55.28122343122959, 55.99056176841259, 50.08862726390362, 55.29790073633194, 54.12077710032463, 58.720099702477455, 57.169406712055206, 62.92412951588631, 55.05770042538643, 55.105410665273666, 42.612501829862595, 6.792376348748803, 0.18523823440773413, 0.9349652426317334, 0.2796786488033831, 32.54357412457466, 60.89466981589794, 52.11772598326206, 59.97524835169315, 51.48946389555931, 45.6459778547287, 65.29470071196556, 43.70629593729973, 48.19027952849865, 59.30680721998215, 32.59305126965046, 32.858774811029434, 1.282058923970908, 0.025495325680822134, 0.25420119403861463, 0.014559585779352346, 0.06630009665968828, 0.01739952240313869, 0.10831684674485587, 0.016787059466878418, 0.01724244128126884, 0.03069862137635937, 0.1607934187632054, 0.051015721110161394, 0.07111539569450542, 0.007848064178688219, 0.018229015295219142, 0.045869179302826524, 0.038841155837872066, 0.03909233942977153, 0.035264623729744926, 0.060801016152254306, 0.06522396026412025, 0.05383610863646027, 0.04059906619659159, 0.056471616044291295, 0.0677136133890599, 0.04173269677266944, 0.048929247132036835, 0.34007180656772107, 0.23310110438615084, 11.831784211099148, 62.042975798249245, 31.823731251060963, 28.48411325365305, 50.18224284052849, 58.827478140592575, 71.903807669878, 60.59466451406479, 69.4406658411026, 65.91499462723732, 65.29383435845375, 58.277567848563194, 62.54060849547386, 5.101944906637073, 1.508582818787545, 3.4966918313875794, 1.9902041251771152, 42.487845718860626, 69.29170623421669, 65.1675595343113, 63.468172922730446, 59.956374764442444, 56.924893632531166, 51.75393730401993, 52.124546617269516, 55.92197544872761, 54.844243079423904, 57.95896254479885, 59.456655979156494, 58.96627329289913, 61.05070844292641, 60.13628751039505, 58.88607479631901, 62.62172654271126, 64.29690465331078, 62.06373788416386, 64.50205564498901, 61.85543306171894, 61.050089076161385, 58.66722173988819, 58.033879324793816, 59.60142441093922, 61.88225582242012, 59.9933847784996, 61.15127004683018, 59.26442429423332, 58.54375496506691, 53.51713389158249, 47.798611745238304, 45.55915631353855, 42.32468247413635, 43.78394857048988, 43.84953685104847, 44.28972043097019, 49.05377559363842, 51.54179848730564, 57.844976261258125, 60.33651776611805, 46.75190471112728, 47.19445936381817, 48.70628044009209, 48.099962174892426, 43.8970685005188, 40.531399101018906, 40.06433576345444, 42.39973604679108, 39.65073935687542, 40.630167201161385, 41.40452764928341, 41.46845921874046, 41.7117715626955, 41.05809643864632, 40.51509037613869, 41.0194943100214, 41.4070089161396, 39.935138896107674, 42.081955298781395, 41.60457171499729, 39.56551373004913, 41.2803503125906, 40.03158912062645, 40.85202969610691, 38.930180221796036, 44.66141268610954, 46.84895150363445, 42.62544013559818, 42.70493946969509, 49.717577174305916, 51.5303611010313, 55.71446858346462, 51.72337934374809, 50.976259633898735, 46.91003702580929, 46.15156352519989, 42.115347906947136, 41.148459389805794, 39.526729211211205, 39.59957890212536, 39.32670034468174, 39.21041138470173, 41.79864630103111, 48.27551655471325, 47.70139396190643, 48.413357958197594, 50.551324635744095, 52.530425637960434, 52.88038685917854, 53.631978929042816, 53.63691866397858, 52.75908976793289, 52.568199411034584, 54.29153613746166, 52.874987348914146, 58.45581628382206, 54.42719645798206, 54.97000873088837, 54.218735843896866, 57.163505628705025, 57.061272114515305, 57.689910382032394, 57.62498326599598, 57.79780179262161, 53.859073743224144, 57.18611441552639, 56.182512268424034, 60.65024793148041, 60.20616956055164, 65.00646337866783, 59.67656917870045, 55.90252049267292, 42.75906376540661, 8.763330113142729, 0.14767425163881853, 0.7695393974427134, 0.4393997829174623, 36.0193882137537, 67.02253639698029, 56.401866897940636, 67.04988732933998, 58.94458785653114, 50.82775600254536, 70.27532905340195, 48.429788276553154, 58.78726489841938, 55.86809813976288, 38.19616600871086, 41.12161383032799, 1.5876243961974978, 0.04599719977704808, 0.23316378617892042, 0.05242795392405242, 0.09361602191347629, 0.07216756072011776, 0.074960336642107, 0.0677064442425035, 0.10317248685169034, 0.017544109468872193, 0.14966341521358117, 0.05219162812863942, 0.09300366102252156, 0.08525950586772524, 0.130287705687806, 0.12307705081184395, 0.12293786101508886, 0.19096610049018636, 0.15393097215564921, 0.1477499061729759, 0.11825928042526357, 0.2813493716530502, 0.16096522595034912, 0.17656488809734583, 0.15591485163895413, 0.13357280753552914, 0.2432090073125437, 0.4060729290358722, 0.4056960961315781, 14.351182971149683, 76.94410040974617, 42.16596879065037, 32.03066244721413, 49.161663204431534, 67.85732880234718, 76.64326295256615, 70.24908766150475, 74.2826396226883, 71.84073105454445, 69.19616416096687, 64.93352249264717, 67.27621078491211, 7.548656417056918, 3.256273507140577, 7.554004630073905, 3.3622930431738496, 44.98908810317516, 71.04419499635696, 68.46621572971344, 67.29290708899498, 64.1045893728733, 59.579119607806206, 53.726810440421104, 54.98836934566498, 59.450781494379044, 57.51922354102135, 61.438614428043365, 60.30550763010979, 61.59115344285965, 63.560827150940895, 60.86358368396759, 62.858982011675835, 67.166867852211, 65.26361837983131, 63.025409281253815, 68.25894445180893, 64.57742840051651, 63.66743043065071, 62.13937662541866, 60.26713348925114, 61.45385921001434, 64.52553078532219, 61.23578891158104, 65.05421921610832, 58.039119243621826, 59.935521483421326, 57.14218117296696, 50.66999986767769, 47.66396977007389, 43.67172919213772, 45.65353564918041, 46.27979904413223, 46.289404928684235, 51.400028094649315, 52.502858117222786, 60.0792221724987, 60.135227367281914, 46.63124978542328, 49.35282714664936, 50.3636185079813, 48.36218610405922, 44.39713306725025, 44.70963969826698, 41.739377081394196, 46.208739057183266, 42.93718680739403, 44.533078372478485, 43.8926987349987, 43.80272336304188, 43.81106771528721, 45.5767797678709, 42.680761367082596, 44.258030131459236, 41.90120279788971, 42.73777350783348, 43.791160583496094, 42.6074443012476, 44.242713153362274, 42.03021727502346, 43.504648357629776, 43.59761416912079, 40.959187746047974, 45.795089453458786, 49.40055638551712, 42.586005851626396, 41.06945022940636, 48.03218521177769, 53.21631543338299, 56.81851454079151, 54.18723553419113, 51.456633657217026, 48.09793308377266, 46.55404552817345, 44.244343265891075, 43.687479346990585, 40.86460702121258, 41.38810873031616, 41.405185014009476, 42.48392812907696, 44.062317833304405, 51.600832119584084, 50.60880795121193, 50.06859853863716, 52.056689858436584, 54.80035923421383, 53.45586597919464, 56.03086240589619, 56.806229799985886, 56.55672758817673, 54.26602050662041, 57.14354149997234, 56.83033190667629, 60.366338565945625, 56.511225029826164, 55.86748257279396, 57.04693928360939, 57.45329707860947, 59.524520337581635, 60.313130021095276, 59.343593046069145, 59.06246893107891, 55.063502714037895, 59.7879184037447, 59.232133626937866, 63.0608955770731, 64.10933151841164, 68.65324169397354, 60.87786331772804, 59.656012281775475, 46.75563231110573, 8.63516204059124, 1.259044271428138, 4.786729970946908, 0.6497063557617366, 40.66917970776558, 69.57783848047256, 63.74287158250809, 71.45610049366951, 63.9808452129364, 58.62766966223717, 75.52037000656128, 55.96489034593105, 60.950564816594124, 69.60569098591805, 45.625823736190796, 55.526477470993996, 1.6241438803263009, 0.14106965682003647, 0.2913351764436811, 0.12264189994311891, 0.1779863829142414, 0.16279696515994146, 0.18606470490340143, 0.1461393863428384, 0.16458102880278602, 0.12571362691232935, 0.24693485582247376, 0.17972925736103207, 0.1543491129996255], [0.019224743700760882, 0.04282735346350819, 0.06594333885004744, 0.07921610085759312, 0.021047176378488075, 0.15506626514252275, 0.12053864600602537, 0.020180346036795527, 0.03711586286954116, 0.02442588345729746, 0.06767055398086086, 0.08245482589700259, 0.09767939918674529, 0.017196532025991473, 0.07416154825477861, 0.23522008443251252, 0.2894996077520773, 29.128091298043728, 53.651065304875374, 30.487455055117607, 26.14772692322731, 37.20708668231964, 59.62144173681736, 60.63073217868805, 52.118071764707565, 58.48163589835167, 59.35435026884079, 52.827505096793175, 55.110099613666534, 6.993428310379386, 1.4847105997614563, 1.689082751981914, 3.581938832066953, 46.930331736803055, 65.08083298802376, 60.346359238028526, 58.511380702257156, 55.51401413977146, 53.88119995594025, 50.814008340239525, 52.3616386950016, 53.73368427157402, 54.51192431151867, 56.70601397752762, 56.771807447075844, 58.57904367148876, 60.221786722540855, 54.1886680573225, 57.28840492665768, 61.6514828056097, 61.00875489413738, 60.09809955954552, 58.02468381822109, 57.73186393082142, 54.60237465798855, 55.08119836449623, 55.164106115698814, 58.270948603749275, 58.87095920741558, 56.940070018172264, 59.000061079859734, 58.1449169665575, 57.169509306550026, 47.193555012345314, 46.0499569773674, 40.19084997475147, 41.87537178397179, 39.20725755393505, 41.69835068285465, 42.29996100068092, 46.012357994914055, 48.03291857242584, 55.989186242222786, 55.9322614967823, 47.698110938072205, 49.529411271214485, 49.219906479120255, 41.964799985289574, 37.58892819285393, 38.64533610641956, 38.18526439368725, 37.459621131420135, 37.15312957763672, 38.59745107591152, 39.30229805409908, 36.863455921411514, 39.04478207230568, 38.1641299277544, 38.036000803112984, 38.05957853794098, 40.382317900657654, 37.42696188390255, 38.92104171216488, 37.67734944820404, 40.152589827775955, 38.0854931473732, 39.088297337293625, 39.50069680809975, 39.53301027417183, 34.543216824531555, 38.233609199523926, 44.087400287389755, 46.20665676891804, 45.64413495361805, 47.22575068473816, 52.47176058590412, 52.78873197734356, 47.23708167672157, 46.51592597365379, 42.76333473622799, 39.4553804397583, 39.6114494651556, 36.63034602999687, 38.14134635031223, 37.53030113875866, 40.63326023519039, 41.56049408018589, 42.68843695521355, 45.350414514541626, 44.31068390607834, 46.334820091724396, 48.67925629019737, 47.113462910056114, 46.25808320939541, 47.96568118035793, 48.651244193315506, 48.505901992321014, 51.52260571718216, 53.613857701420784, 55.233178809285164, 55.37343308329582, 53.57085920870304, 57.797554805874825, 58.01108434796333, 62.34216794371605, 57.23140798509121, 54.54760059714317, 53.16903457045555, 52.9282832890749, 52.34042063355446, 50.577505230903625, 56.61326475441456, 53.17648597061634, 59.83226582407951, 55.22434048354626, 58.76980863511562, 41.041631922125816, 13.786389827728271, 0.14430438168346882, 0.5910202267114073, 0.5474794318433851, 35.58768577873707, 61.753476932644844, 63.02969925105572, 50.48285610973835, 47.26693667471409, 61.20700545608997, 63.85285288095474, 30.532131157815456, 45.27481757104397, 31.491908356547356, 47.24302835762501, 13.672037813812494, 1.1253586574457586, 0.2532510075252503, 0.2776359021663666, 0.025695345611893572, 0.1642818987602368, 0.006832026438132743, 0.021640516024490353, 0.057546642929082736, 0.14575759589206427, 0.02075403546768939, 0.05711933285056148, 0.09912050154525787, 0.035564347490435466, 0.06173254507302772, 0.1682765531586483, 0.013182537259126548, 0.011152883962495252, 0.05103800038341433, 0.039954039675649256, 0.1274729473516345, 0.028789440912078135, 0.01867575294454582, 0.06143753766082227, 0.040017994251684286, 0.01706485461909324, 0.047874280498945154, 0.04663807398173958, 0.08212048094719648, 0.1615575043251738, 0.12317865825025365, 38.05317588150501, 58.186653926968575, 29.369214959442616, 39.71517629921436, 44.73037138581276, 66.83119386434555, 64.34930384159088, 57.28351078927517, 64.47482630610466, 64.88342598080635, 57.954402789473534, 63.4256836026907, 6.973688844591379, 1.0065529262647033, 2.274681441485882, 4.790138863027096, 50.05213022232056, 70.91389998793602, 64.31720316410065, 59.487339332699776, 60.20044706761837, 55.79160824418068, 52.305952683091164, 53.7081154435873, 57.82644085586071, 56.66837699711323, 58.76641921699047, 59.95944879949093, 60.81461191177368, 62.04562045633793, 57.65602380037308, 62.64215424656868, 60.707203075289726, 61.59525342285633, 61.91146105527878, 60.83210997283459, 58.46591614186764, 57.087521106004715, 56.48768149316311, 57.37676538527012, 57.56346456706524, 59.78587791323662, 58.66097867488861, 61.29892252385616, 59.5888888835907, 59.287253469228745, 51.56381830573082, 48.049394488334656, 44.0471376478672, 43.09021979570389, 41.131318509578705, 42.91865520179272, 42.38514102995396, 49.07038830220699, 51.24469242990017, 58.94245617091656, 55.15907138586044, 47.014892399311066, 50.192916467785835, 49.45291377604008, 43.53174850344658, 40.93107685446739, 40.817071571946144, 39.731523022055626, 40.11525683104992, 40.2755094319582, 40.95453679561615, 40.87379492819309, 41.25629760324955, 41.87053084373474, 41.007980927824974, 39.65235807001591, 41.055026203393936, 42.17188887298107, 40.80859422683716, 41.2553970515728, 41.50678016245365, 41.25343255698681, 40.18932245671749, 41.13566167652607, 41.1454613506794, 40.06471574306488, 38.64100433886051, 40.73869697749615, 48.605228662490845, 46.55624561011791, 44.671755731105804, 48.73355157673359, 52.17235945165157, 53.57098840177059, 50.14304034411907, 48.33967611193657, 43.26275713741779, 42.08894692361355, 40.76345644891262, 39.714131355285645, 41.09419830143452, 38.94013188779354, 41.55213072896004, 43.129407092928886, 45.35782031714916, 47.89073780179024, 45.28258815407753, 49.301594495773315, 51.108317747712135, 49.49007958173752, 47.88025036454201, 50.29748685657978, 52.241356149315834, 51.35643683373928, 54.1853242367506, 55.197206139564514, 56.80208042263985, 55.97347788512707, 53.87888588011265, 60.04039965569973, 58.30265410244465, 62.908709943294525, 59.442661330103874, 56.91055320203304, 54.95953269302845, 53.57563555240631, 54.480021223425865, 52.931178733706474, 58.612326085567474, 55.47243297100067, 61.16049975156784, 58.87254372239113, 61.800461411476135, 47.146057561039925, 17.72023893892765, 0.10901853995164856, 0.6436771480366588, 0.21501250157598406, 40.73072500526905, 65.64080134034157, 67.6577179133892, 55.60456708073616, 52.86847069859505, 65.37511959671974, 69.19259235262871, 38.6969905346632, 57.76103116571903, 29.731964394450188, 54.135771095752716, 17.246212475001812, 1.142980211880058, 0.25422414124477655, 0.2568723022704944, 0.034659747398109175, 0.11512841170770116, 0.06706877611577511, 0.06243073905352503, 0.015104850026546046, 0.12263926531886682, 0.09220740335877053, 0.09742617839947343, 0.03372264494828414, 0.0874291300715413, 0.12706010544206947, 0.21299463172908872, 0.12764965271344408, 0.13127442070981488, 0.09808265254832804, 0.19698815391166136, 0.250284910434857, 0.12002512434264645, 0.15911016846075654, 0.0835776433814317, 0.1821021706564352, 0.13365200953558087, 0.1753435208229348, 0.14083475223742425, 0.2204907388659194, 0.32368610613048077, 0.28913087910041213, 50.40633961558342, 75.13556465506554, 42.47707709670067, 43.02881509065628, 50.15500210225582, 74.31715697050095, 70.93792229890823, 65.11279687285423, 71.15403950214386, 71.14431962370872, 63.0581559240818, 68.59062105417252, 8.331053908914328, 2.9433256248012185, 5.6245883367955685, 6.171895768493414, 53.119378834962845, 73.54181617498398, 67.62567803263664, 63.669448122382164, 63.87011915445328, 57.89776682853699, 56.01754032075405, 57.69975945353508, 62.04498589038849, 60.235488787293434, 61.21848464012146, 60.499073043465614, 64.74184557795525, 66.50875076651573, 61.336456909775734, 63.76779064536095, 63.12521852552891, 61.14874318242073, 65.04494771361351, 63.730161264538765, 62.49265506863594, 60.153211802244186, 59.28398184478283, 58.497864827513695, 61.548333540558815, 62.6907954365015, 61.21198698878288, 62.43759982287884, 63.56532610952854, 62.21325226128101, 52.9829965531826, 50.29147557914257, 45.96699982881546, 45.202389657497406, 43.16398523747921, 45.31289152801037, 45.00675715506077, 50.43902926146984, 53.477616012096405, 61.519135907292366, 57.7745508402586, 49.10275116562843, 51.45317584276199, 52.10072189569473, 45.824492275714874, 41.896715238690376, 43.20544481277466, 42.349107563495636, 42.590284422039986, 43.79795461893082, 43.82503196597099, 44.39497098326683, 44.095581248402596, 43.332707583904266, 44.5660188049078, 42.711022943258286, 45.56958295404911, 45.23715779185295, 42.34259471297264, 44.92904372513294, 43.04141141474247, 43.80596078932285, 42.93892711400986, 45.507262498140335, 45.97555696964264, 43.96993339061737, 40.74783928692341, 41.820848509669304, 50.372874811291695, 48.673529997467995, 45.250403881073, 48.88960160315037, 53.395293429493904, 55.9977737814188, 49.02186490595341, 50.17706751823425, 45.193042159080505, 45.63686974346638, 43.719086050987244, 40.57841017842293, 43.37635584175587, 40.661390125751495, 45.66709332168102, 45.16966201364994, 46.55482068657875, 49.73191760480404, 48.64881992340088, 51.81682772934437, 53.383692651987076, 51.19820572435856, 50.52525043487549, 51.58912114799023, 54.54561710357666, 53.872821405529976, 57.27520823478699, 57.88132891058922, 59.89640258252621, 58.26499052345753, 54.02134783565998, 59.77255202829838, 60.83122842013836, 62.98725172877312, 61.04152053594589, 59.52739678323269, 57.20632553100586, 56.769972145557404, 57.557920664548874, 53.26656773686409, 62.03481003642082, 60.15117131173611, 61.972538977861404, 62.79707573354244, 64.99159097671509, 49.22973655164242, 19.350554756820202, 0.30629369721282274, 3.619530452415347, 0.8981190947815776, 45.449224412441254, 71.46825224161148, 72.19516083598137, 61.538085490465164, 61.739938259124756, 71.15868285298347, 72.55566269159317, 41.24986454844475, 56.11188165843487, 40.90924322605133, 66.52528747916222, 27.280468940734863, 1.3103442499414086, 0.4361313348636031, 0.2636248664930463, 0.11271763403783552, 0.297661391668953, 0.16222806443693116, 0.1745108311297372, 0.13919736666139215, 0.14855570043437183, 0.1663900286075659, 0.13281560910400003, 0.23010319884633645, 0.18188414251198992], [0.02646500099217519, 0.04851732177485246, 0.08612766279838979, 0.03366705437656492, 0.04854441387578845, 0.03087989094638033, 0.02477496374922339, 0.08957985919550993, 0.06405134467058815, 0.1315122641972266, 0.01802477996534435, 0.06061190208129119, 0.04356818011729047, 0.032529846648685634, 0.11266953544691205, 0.1866590019199066, 0.3025673737283796, 10.07360240444541, 44.91582043468952, 34.93296191096306, 43.44133995473385, 37.29180693626404, 51.401472017169, 63.846226036548615, 62.94675350189209, 58.14669527113438, 61.13695241510868, 52.983779311180115, 64.84398409724236, 9.019285328686237, 1.3347673206590116, 0.6001373624894768, 5.062040872871876, 58.07501591742039, 65.87123617529869, 61.45710043609142, 52.571657225489616, 52.70122267305851, 52.092928513884544, 51.85438871383667, 51.11090920865536, 51.433918476104736, 53.841666877269745, 57.03275464475155, 57.28468872606754, 59.46611747145653, 59.59279887378216, 59.51922722160816, 62.08951190114021, 55.32708317041397, 59.35728371143341, 59.48711894452572, 63.89917239546776, 58.50650176405907, 56.93184345960617, 52.51205362379551, 52.275254130363464, 51.80100917816162, 55.327755734324455, 55.77819496393204, 56.095576733350754, 55.30889354646206, 49.24808196723461, 46.026120856404305, 44.24863323569298, 39.86649177968502, 41.478399485349655, 41.38898268342018, 43.621476888656616, 44.04803439974785, 45.0116740912199, 48.70539128780365, 53.31023119390011, 57.21726894378662, 54.11905959248543, 47.491630017757416, 43.654010742902756, 39.33684580028057, 39.77939285337925, 37.338780015707016, 40.275938808918, 37.69029915332794, 36.66333205997944, 37.17364847660065, 38.826214000582695, 38.38938944041729, 38.795359656214714, 37.54640467464924, 38.03001992404461, 37.410732954740524, 37.82239906489849, 37.28443533182144, 39.51929301023483, 38.299440667033195, 37.48318746685982, 38.24076421558857, 39.21476595103741, 37.595125660300255, 37.19462335109711, 40.060619562864304, 38.19871187210083, 38.389997407794, 44.645696729421616, 51.70397758483887, 53.04488383233547, 59.99130629003048, 57.766153290867805, 49.81418319046497, 45.95453269779682, 42.84570291638374, 39.99350756406784, 39.462474659085274, 38.61513912677765, 37.25803814828396, 38.000320717692375, 37.71180219948292, 37.97826670110226, 41.35587505996227, 43.40655282139778, 43.98671709001064, 43.668134585022926, 44.348472878336906, 45.217163264751434, 47.509880438447, 47.67394803464413, 46.16154558956623, 48.64869832992554, 49.9524349719286, 52.8435630351305, 54.92348022758961, 53.91934230923653, 53.97462174296379, 55.8591116219759, 55.646684020757675, 52.103621140122414, 52.742644250392914, 52.68705703318119, 50.99025048315525, 49.030463844537735, 52.27563410997391, 50.13761803507805, 53.87928865849972, 51.361346170306206, 55.574248507618904, 53.82386103272438, 52.99687720835209, 47.87353992462158, 25.812383517622948, 1.2661346909590065, 0.2555622038198635, 0.6132328847888857, 38.801724314689636, 62.205063700675964, 56.7679126560688, 46.03899456560612, 54.169916063547134, 60.992541164159775, 52.48465709388256, 26.499399952590466, 24.768539629876614, 28.31205278635025, 45.15394225716591, 3.0892418324947357, 0.076379211677704, 0.16333681822288781, 0.14577742607798427, 0.06666593093541451, 0.01587890634255018, 0.06628208473557606, 0.04891115728241857, 0.04269768171070609, 0.04364827269455418, 0.03391959980945103, 0.011571744689717889, 0.03467314687441103, 0.039304682723013684, 0.053352528921095654, 0.02765433531749295, 0.05024506011977792, 0.01605822591955075, 0.04389862879179418, 0.09202866451232694, 0.0463974956801394, 0.05054433488112409, 0.04440886645170394, 0.02045500004896894, 0.03525725049257744, 0.09082979173399508, 0.09867115339147858, 0.05834215473441873, 0.12472907896153629, 0.2329777297563851, 0.5438826279714704, 14.93861149996519, 60.54526336491108, 30.845031067728996, 43.93395312130451, 48.765971437096596, 59.11936707794666, 72.31235414743423, 69.62042659521103, 67.08515703678131, 66.22859939932823, 59.30243745446205, 68.91441687941551, 12.338827103376389, 1.3641883106902242, 0.8743944740854204, 5.913605103269219, 60.62824331223965, 67.81067490577698, 65.759506970644, 55.90565152466297, 54.97755892574787, 54.55013886094093, 54.33307930827141, 54.07805219292641, 54.51424978673458, 57.607504203915596, 59.89702194929123, 59.404089599847794, 61.99890956282616, 62.26968303322792, 63.17794069647789, 60.75057774782181, 57.338482439517975, 60.87933003902435, 62.602206990122795, 62.49930091202259, 59.55466791987419, 59.397101774811745, 53.99127624928951, 52.21809759736061, 54.386698231101036, 58.18729989230633, 58.22486087679863, 59.36874769628048, 58.53063426911831, 53.15058276057243, 48.05236592888832, 45.824655666947365, 42.75806441903114, 44.122027829289436, 42.89196163415909, 46.0581037402153, 45.48874989151955, 48.053133487701416, 51.45314924418926, 57.07326427102089, 60.40589064359665, 54.922294691205025, 50.466433390975, 47.444516345858574, 41.6676939278841, 41.27934716641903, 39.691381976008415, 41.634046733379364, 39.88041803240776, 40.65751813352108, 38.862179070711136, 41.70248106122017, 41.390795186161995, 41.75496384501457, 40.42492501437664, 40.5385123193264, 38.80310744047165, 40.56816592812538, 39.75104637444019, 40.98125696182251, 40.820639580488205, 40.676061138510704, 39.68310222029686, 44.12145406007767, 41.837434619665146, 41.47922784090042, 42.29485787451267, 40.91276943683624, 43.553209751844406, 46.41032204031944, 51.416253224015236, 52.62915574014187, 58.26969087123871, 60.377376973629, 50.49640618264675, 49.743472784757614, 43.20818446576595, 41.59003369510174, 41.220602318644524, 40.61170779168606, 40.670274049043655, 40.35674527287483, 41.3062497228384, 41.671888902783394, 42.88529299199581, 45.64309000968933, 45.03367871046066, 45.7834392786026, 45.349513962864876, 46.70592337846756, 48.01680363714695, 49.75008822977543, 47.99288772046566, 51.78156182169914, 51.6173080354929, 54.994832798838615, 55.327121168375015, 56.27741597592831, 55.6273240596056, 56.43315441906452, 59.588835686445236, 53.142660185694695, 55.76490327715874, 51.460775434970856, 51.68246313929558, 50.95725305378437, 51.689690351486206, 52.37160935997963, 54.90775287151337, 53.99545222520828, 57.366866916418076, 58.01212549209595, 56.125025153160095, 51.04671165347099, 30.33653475344181, 1.573251192457974, 0.2429108420619741, 0.354037155630067, 42.03972056508064, 66.93878889083862, 60.78618563711643, 52.12977133691311, 59.28921416401863, 64.63392376899719, 57.49433107674122, 34.40009370446205, 29.30259883403778, 34.193768575787544, 51.619819700717926, 3.844011244364083, 0.07216573503683321, 0.10133436517207883, 0.15958812640747055, 0.07168430383899249, 0.05520910781342536, 0.04614383702573832, 0.08469613414490595, 0.02852682267985074, 0.02001507531531388, 0.028173100254207384, 0.00133000575033293, 0.0379591244563926, 0.010198829932051012, 0.14138107682811096, 0.1818972043110989, 0.20296452072216198, 0.0952406573924236, 0.0935040540935006, 0.14180557045619935, 0.19001713109901175, 0.2266590399085544, 0.15648194152163342, 0.1836896245367825, 0.1364087319234386, 0.18454054137691855, 0.17042225052136928, 0.17934374132892117, 0.18531124689616263, 0.5358463560696691, 0.563162318430841, 18.56083933264017, 75.39095655083656, 45.732096433639526, 60.00711344182491, 52.92663797736168, 67.09762796759605, 77.04173997044563, 74.36301290988922, 70.81211104989052, 72.65074878931046, 62.62305647134781, 80.58511063456535, 12.491701450198889, 3.973335404880345, 1.440221993252635, 7.356721591204405, 67.48954653739929, 70.85970729589462, 67.84291997551918, 58.5994827747345, 57.726278230547905, 58.51549208164215, 57.54661247134209, 57.3502542078495, 57.49401569366455, 58.950523138046265, 63.61798368394375, 61.826873794198036, 63.395900800824165, 65.3858046233654, 65.28292134404182, 61.25072970986366, 57.65791989862919, 62.53794863820076, 64.62598219513893, 65.43940454721451, 65.00013291835785, 62.58753977715969, 56.56992428004742, 54.99744325876236, 56.320213079452515, 60.55418908596039, 61.20518535375595, 61.264108791947365, 60.512623116374016, 53.50176751613617, 50.58920860290527, 47.672865092754364, 42.8100798279047, 44.397889226675034, 46.76662512123585, 49.142892211675644, 49.28090460598469, 47.95746222138405, 54.11078363656998, 59.52223666012287, 62.678199112415314, 60.63936151564121, 50.61750188469887, 49.44679990410805, 43.13957914710045, 44.42818120121956, 40.98091118037701, 46.79825842380524, 41.45140953361988, 43.21248583495617, 41.55670568346977, 45.02165615558624, 43.4501326829195, 43.56832914054394, 43.34659583866596, 42.81830258667469, 40.78978143632412, 42.64305219054222, 42.17295281589031, 43.476168885827065, 42.95289896428585, 42.9631432145834, 42.68917791545391, 45.63550181686878, 44.40990798175335, 42.98639036715031, 44.53752413392067, 43.59030336141586, 45.94045825302601, 49.99722316861153, 54.54174131155014, 56.53885334730148, 60.426895916461945, 59.311503767967224, 52.2107107937336, 49.720689207315445, 47.54409000277519, 43.14064309000969, 44.276276752352715, 43.37808474898338, 41.78300254046917, 42.31698788702488, 42.76585400104523, 42.53366366028786, 46.6749132424593, 48.540168553590775, 48.49106378853321, 48.065539821982384, 47.764147594571114, 48.39052498340607, 52.79478885233402, 52.441168427467346, 51.820528730750084, 54.422739297151566, 54.428716376423836, 57.2857640683651, 59.23201583325863, 57.93823845684528, 57.663216814398766, 60.30677296221256, 60.72522930800915, 56.29684433341026, 58.132271245121956, 53.88089597225189, 53.88950631022453, 52.55391977727413, 55.341055020689964, 53.39060828089714, 56.84526510536671, 55.83704240620136, 60.150483548641205, 60.0094199180603, 61.46287612617016, 55.67330539226532, 31.767807751893997, 1.6716206702403724, 0.789826390100643, 0.5189928354229778, 47.773016318678856, 71.46817624568939, 66.83164224028587, 60.62923885881901, 65.4159066081047, 69.37050640583038, 65.20159050822258, 36.08904607594013, 37.40654177963734, 41.37378349900246, 62.32589341700077, 7.1324951481074095, 0.40220895200036466, 0.24787239613942802, 0.2985099039506167, 0.09278202604036778, 0.1392033335287124, 0.14270518702687696, 0.1306653252686374, 0.18395448219962418, 0.1868676344747655, 0.1819712112774141, 0.14154724369291216, 0.19642700121039525, 0.08236156761995517], [0.023657268939132337, 0.027434663315943908, 0.0890055853233207, 0.06376486082444899, 0.033582531177671626, 0.07268430330441333, 0.018082966198562644, 0.0944858932052739, 0.047489246862824075, 0.019999603391624987, 0.03963426308473572, 0.055752408152329735, 0.03144331647490617, 0.031376397018902935, 0.0627155604888685, 0.07553017247118987, 0.2499098883708939, 0.32483391172718257, 31.64709582924843, 53.44487316906452, 33.50682243704796, 28.911451622843742, 42.819214537739754, 56.362326219677925, 51.18856944143772, 51.122810170054436, 65.0308808684349, 53.353001698851585, 63.13507899641991, 11.982163991779089, 0.5709605093579739, 0.3035994339734316, 7.51515693962574, 58.57048653066158, 66.41399905085564, 60.595063492655754, 55.27621150016785, 54.62672755122185, 52.62328125536442, 50.44127494096756, 51.01695545017719, 50.538838505744934, 53.60817700624466, 53.35671029984951, 55.574267506599426, 58.433602675795555, 58.87576974928379, 62.11003839969635, 60.385136157274246, 60.78614003956318, 60.733269676566124, 60.02281799912453, 62.18353405594826, 57.22815915942192, 56.03890277445316, 50.64866781234741, 49.23641659319401, 46.82620592415333, 51.662350818514824, 50.20518980920315, 51.29120573401451, 47.34818011522293, 45.38646697998047, 45.73993161320686, 43.22872996330261, 40.888101160526276, 41.72352433204651, 41.5435241907835, 45.298592895269394, 43.25800359249115, 45.16184963285923, 48.689025565981865, 49.60743248462677, 48.90710726380348, 45.34595735371113, 41.0608284920454, 40.00343643128872, 39.36432592570782, 40.26536777615547, 39.16215397417545, 38.91257956624031, 38.31002689898014, 38.74693125486374, 38.033223152160645, 38.69159862399101, 37.55370408296585, 38.18039685487747, 38.34797166287899, 38.05114299058914, 37.55173958837986, 37.173295095562935, 36.77815429866314, 37.55380667746067, 36.42108365893364, 38.66435408592224, 39.037053287029266, 37.880216762423515, 38.30336965620518, 39.43897292017937, 37.96313591301441, 39.62535671889782, 39.57786686718464, 37.941264286637306, 39.85950015485287, 48.37915979325771, 52.86267600953579, 52.53995552659035, 50.212322026491165, 46.9615014642477, 43.60757723450661, 42.14119032025337, 40.14282815158367, 39.38417226076126, 36.695588529109955, 36.604043841362, 36.71795792877674, 39.94413681328297, 41.64649486541748, 43.11714515089989, 44.425023570656776, 42.759918719530106, 42.91467301547527, 44.523567482829094, 45.65589152276516, 46.73987835645676, 46.76441363990307, 50.780866518616676, 52.131705433130264, 55.28069905936718, 54.951708912849426, 55.760913491249084, 53.96672956645489, 56.3916302472353, 55.060424879193306, 54.92641746997833, 49.848100170493126, 52.55695581436157, 48.40355448424816, 53.457746878266335, 55.78625813126564, 58.805576115846634, 56.64015211164951, 59.8918504267931, 54.01676528155804, 55.51502488553524, 51.06453649699688, 45.11209510266781, 32.00743809342384, 6.437917118892074, 0.10894111168454401, 2.30994853656739, 43.49546045064926, 63.84076192975044, 49.88001845777035, 53.873626962304115, 55.116110891103745, 61.31187602877617, 41.72667436301708, 26.821305379271507, 34.1559986025095, 44.007049798965454, 24.42692656069994, 0.5492890847381204, 0.06685698201181367, 0.11168290948262438, 0.04031881639093626, 0.13647542131366208, 0.04545959542156197, 0.043109788894071244, 0.02864226931706071, 0.03724155671079643, 0.030950315194786526, 0.027649878720694687, 0.02766915044048801, 0.019784258111030795, 0.04933119060297031, 0.046216871778597124, 0.022570260080101434, 0.04593372759700287, 0.041171892880811356, 0.05451273580547422, 0.08939808496506885, 0.00764525794693327, 0.02989933389471844, 0.07568473956780508, 0.01570978758536512, 0.03316697671834845, 0.03291210836323444, 0.07727250515017658, 0.02299870378919877, 0.08608198360889219, 0.07425813135341741, 0.37750769464764744, 0.9331561240833253, 44.78247418999672, 53.65565165877342, 37.45970092713833, 46.83111906051636, 46.38175517320633, 65.14571830630302, 60.70336528122425, 59.806001633405685, 69.89336594939232, 58.23476694524288, 68.86991366744041, 14.865503422915936, 0.7182442280463874, 0.32543249835725874, 7.427677558735013, 63.02782975137234, 69.66827362775803, 64.25338178873062, 58.666796162724495, 58.57803292572498, 56.03560835123062, 53.284434378147125, 53.40949706733227, 52.18136876821518, 55.44787108898163, 58.25171783566475, 57.47400976717472, 60.421340614557266, 61.891743913292885, 64.09365355968475, 61.31703235208988, 61.55765064060688, 61.49400405585766, 62.09745727479458, 64.21872764825821, 58.25688175857067, 57.98820957541466, 52.18695446848869, 52.49241627752781, 49.71062354743481, 53.223181664943695, 52.30835795402527, 55.663053542375565, 49.57858823239803, 49.44027565419674, 47.660793140530586, 45.989137440919876, 42.63884201645851, 44.9016509950161, 45.593156889081, 47.036235854029655, 45.33940650522709, 48.08109998703003, 50.98947152495384, 53.846135437488556, 54.63909588754177, 51.354031562805176, 44.1904279589653, 42.99415335059166, 41.65228195488453, 42.72971034049988, 40.514163225889206, 41.315677016973495, 40.400971099734306, 42.326829358935356, 40.382139310240746, 40.95678247511387, 41.8755541741848, 39.74445752799511, 40.97562186419964, 39.71510410308838, 40.35558633506298, 40.37671320140362, 38.284613862633705, 40.68144164979458, 39.15226690471172, 39.984935224056244, 42.086328864097595, 41.306287720799446, 40.00051438808441, 43.22535574436188, 40.508452132344246, 41.32174909114838, 42.04724036157131, 41.15162841975689, 46.16507939994335, 53.26341010630131, 54.44466792047024, 54.98837694525719, 51.40888161957264, 48.86704981327057, 44.78029690682888, 44.31957922875881, 41.792714819312096, 41.886508986353874, 38.622142150998116, 39.3872956931591, 39.579869359731674, 42.4737598747015, 44.50233802199364, 44.32254686951637, 45.16143925487995, 44.681901186704636, 45.45409955084324, 46.01057969033718, 47.401658445596695, 49.09250691533089, 49.92506504058838, 52.65903353691101, 55.08913613855839, 55.67275442183018, 59.001235216856, 58.83180990815163, 57.1469347178936, 58.74652348458767, 56.2631743401289, 57.394985407590866, 51.803980618715286, 52.94508598744869, 49.67481806874275, 55.706796795129776, 57.41381339728832, 59.92950260639191, 59.26436349749565, 61.04200690984726, 58.417738527059555, 60.0698746740818, 56.87319740653038, 50.60709424316883, 35.91921418905258, 7.590934373438358, 0.058607105165719986, 2.018362870439887, 47.51760542392731, 67.4013988673687, 55.981734842062, 58.59200477600098, 59.37548853456974, 66.87263444066048, 48.02597634494305, 32.20150128006935, 32.20264881849289, 50.47264985740185, 28.12568038702011, 0.4748368891887367, 0.12799972377251834, 0.09893132068100385, 0.03995062579633668, 0.14056910789804533, 0.0455253645486664, 0.07420710127917118, 0.04121562764339615, 0.058533142728265375, 0.06273776554735377, 0.053722589727840386, 0.025180642078339588, 0.03216820921807084, 0.030424188153119758, 0.12488859618315473, 0.09580476384144276, 0.26526281610131264, 0.1873741502640769, 0.1595862116664648, 0.21326838032109663, 0.04188451050140429, 0.16647553886286914, 0.1640675961971283, 0.1378074279637076, 0.11594864816288464, 0.21204377728281543, 0.21237018867395818, 0.1144119274977129, 0.1899558148579672, 0.14841810625512153, 0.4823427926748991, 1.2918138317763805, 57.09088392555714, 70.2147451043129, 44.962599724531174, 43.06170232594013, 56.91954351961613, 68.32493931055069, 66.09922394156456, 62.97925315797329, 78.19356456398964, 63.95046964287758, 76.98201477527618, 15.918949395418167, 1.8567580170929432, 1.0499661904759705, 8.864288795739412, 69.26740273833275, 71.28496527671814, 66.6211411356926, 62.84125216305256, 62.09268473088741, 58.765849247574806, 57.10243530571461, 57.22952328622341, 54.93723548948765, 58.53579819202423, 59.42812331020832, 60.31151510775089, 65.67781135439873, 64.16818276047707, 65.36115154623985, 63.57272431254387, 64.46446046233177, 64.4500820338726, 64.32489395141602, 65.55681824684143, 61.75555162131786, 62.27409079670906, 53.01492244005203, 54.801514372229576, 50.72011157870293, 56.34394280612469, 54.68793086707592, 57.62244500219822, 51.99601851403713, 51.99284948408604, 49.39083270728588, 46.94745361804962, 45.35375073552132, 47.56001494824886, 48.15362669527531, 49.176748394966125, 47.08021469414234, 50.0805526971817, 52.11197309195995, 54.52349089086056, 58.20354402065277, 53.37409056723118, 46.04499824345112, 45.288508236408234, 44.720522314310074, 46.33170805871487, 43.002569898962975, 43.16937334835529, 44.17060822248459, 46.93212144076824, 42.92171023786068, 45.063856691122055, 43.71625900268555, 43.09712402522564, 43.194603994488716, 43.0962348729372, 42.976742684841156, 44.185796007514, 39.88163776695728, 44.160151183605194, 40.63307024538517, 43.93392272293568, 44.57990325987339, 43.842279240489006, 43.16095679998398, 45.8101936429739, 42.94109299778938, 44.331388995051384, 42.54062868654728, 43.85286167263985, 46.872115060687065, 54.22960326075554, 57.146775126457214, 56.88956692814827, 54.65468645095825, 49.55958165228367, 46.09894774854183, 46.37355141341686, 43.89495961368084, 44.62256357073784, 41.759383007884026, 41.12447887659073, 42.80406475067139, 44.39426802098751, 45.818199813365936, 47.15087570250034, 48.17739062011242, 47.16075897216797, 48.08664008975029, 50.829796493053436, 48.627997040748596, 50.378285720944405, 50.88677063584328, 56.19003966450691, 57.03549049794674, 59.3182598054409, 62.21674047410488, 60.28590828180313, 58.584173396229744, 60.31068675220013, 56.6180182993412, 59.24645125865936, 53.73757906258106, 56.72487236559391, 52.70174324512482, 57.43762291967869, 60.28835915029049, 62.13317535817623, 61.02425046265125, 62.85030707716942, 60.32182775437832, 63.21123071014881, 60.94792775809765, 54.0128742903471, 39.76784527301788, 8.042599987238646, 0.21534614148549736, 3.1908122822642326, 52.0687960088253, 72.03949078917503, 61.78691513836384, 64.70386281609535, 64.95436817407608, 72.19215139746666, 52.346564903855324, 39.84210088849068, 46.20151184499264, 58.75415347516537, 42.23711617290974, 0.6086134014185518, 0.1754258101573214, 0.15786898584337905, 0.2031410628114827, 0.23545737873064354, 0.10291449405485764, 0.24520352919353172, 0.18798602133756503, 0.22987969365203753, 0.12518591538537294, 0.36144396755844355, 0.056413364873151295, 0.15905952430330217, 0.1155657073832117], [0.08731705835089087, 0.014654622427769937, 0.033808221996878274, 0.059929753333562985, 0.030184251809259877, 0.07160989611293189, 0.015063560640555806, 0.05906934442464262, 0.04341789892350789, 0.024322055141965393, 0.0692050853103865, 0.018118297994078603, 0.05313765119353775, 0.014035690746823093, 0.1133355610363651, 0.13830916432198137, 0.21526892844121903, 0.26654150686226785, 7.998469155281782, 42.44388207793236, 24.145701751112938, 27.48003613203764, 37.70153135061264, 54.76918190717697, 57.395619973540306, 54.891535341739655, 60.79439699649811, 58.80227409303188, 59.01956923305988, 16.76540907472372, 0.13110102532664314, 0.05688812045264058, 9.82993857935071, 65.39160311222076, 67.27763950824738, 63.729184716939926, 55.220103710889816, 53.54399085044861, 52.21510335803032, 48.355836644768715, 51.975226029753685, 53.352066949009895, 55.31199797987938, 52.95517824590206, 54.58227373659611, 53.399169221520424, 56.505601331591606, 59.50129598379135, 59.05846394598484, 59.340883791446686, 58.7546968460083, 62.87005461752415, 60.822770074009895, 56.87936447560787, 52.833284586668015, 49.146931394934654, 47.67237111926079, 45.98528444766998, 45.885007828474045, 45.97656771540642, 46.31300926208496, 45.212284326553345, 47.41486273705959, 41.32790096104145, 41.99727304279804, 40.46078749001026, 42.78378903865814, 44.70796398818493, 44.823751375079155, 46.51202358305454, 44.03619423508644, 46.326741725206375, 49.14164587855339, 45.02698726952076, 41.929754465818405, 39.451869428157806, 39.642444401979446, 36.74496687948704, 39.586036428809166, 41.3128499686718, 39.10835266113281, 37.59051650762558, 36.79127499461174, 38.31172540783882, 38.07886250317097, 38.8461135327816, 37.70789220929146, 37.16208189725876, 38.4979572147131, 38.43602813780308, 38.596964702010155, 37.52243176102638, 39.45453688502312, 38.58158692717552, 36.35106481611729, 37.194638550281525, 38.22303056716919, 39.28761564195156, 38.07009257376194, 39.95292194187641, 39.40855175256729, 38.91854524612427, 39.91559274494648, 38.660455495119095, 41.86213709414005, 45.53237535059452, 50.66445976495743, 47.46760010719299, 46.28000043332577, 41.803331449627876, 43.70732568204403, 41.48506432771683, 39.69791762530804, 37.46575780212879, 37.781232073903084, 38.00752893090248, 39.56790380179882, 40.46963721513748, 42.930822148919106, 41.16839312016964, 43.222669288516045, 41.51209607720375, 41.38766035437584, 43.05425472557545, 47.02378772199154, 48.10441553592682, 52.35253818333149, 50.94914048910141, 55.810314640402794, 55.131538063287735, 57.3000892996788, 55.56957095861435, 56.467998549342155, 55.22380851209164, 53.137241676449776, 50.209491178393364, 54.8359215259552, 53.86258855462074, 59.89840127527714, 58.96553993225098, 60.54938994348049, 60.981118977069855, 61.50513745844364, 62.54891484975815, 53.44578891992569, 44.47748355567455, 44.35568869113922, 36.47577792406082, 10.629535373300314, 0.08505212754243985, 2.571886293590069, 45.08926972746849, 59.276834428310394, 50.40925785899162, 60.1691709458828, 54.35457095503807, 61.197764351964, 32.86767013370991, 31.92445434629917, 35.9854332357645, 39.79964576661587, 2.649574549868703, 0.2370862741372548, 0.16544702608371153, 0.14146565197734162, 0.11263520369539037, 0.03629847997217439, 0.038052976451581344, 0.08912956109270453, 0.034208005818072706, 0.03768663380469661, 0.055240359652088955, 0.06898721301695332, 0.02569221003795974, 0.02521100890589878, 0.0319924241193803, 0.07472613709978759, 0.061206933823996224, 0.02879599778680131, 0.007094760167092318, 0.02761739491688786, 0.03975298073783051, 0.024033547088038176, 0.013811602038913406, 0.009968167651095428, 0.0313806755002588, 0.041959964655688964, 0.03103468996414449, 0.09937364069628529, 0.05405202908150386, 0.05246588138106745, 0.07472238925402053, 0.40595834143459797, 0.33174538461025804, 13.111866172403097, 56.547482684254646, 23.221792727708817, 31.393170654773712, 47.57492154836655, 58.62412445247173, 60.82525134086609, 59.741515293717384, 68.44101548194885, 63.76981973648071, 66.56036719679832, 20.065361000597477, 0.17626535729505122, 0.0785799021832645, 10.826314464211464, 70.26963695883751, 68.81726369261742, 65.93793779611588, 60.43404333293438, 57.196332067251205, 54.420706406235695, 52.25980035960674, 54.4872560352087, 55.201226323843, 56.32794946432114, 56.10630355775356, 57.21394792199135, 56.854696199297905, 59.88605573773384, 59.76216718554497, 60.536280646920204, 61.75913862884045, 62.29621700942516, 64.51940551400185, 64.01869878172874, 60.389688313007355, 55.09314492344856, 51.99496977031231, 49.15668547153473, 47.79759339988232, 48.85529324412346, 48.187334686517715, 48.66432309150696, 48.83009299635887, 50.1533567905426, 46.17867887020111, 45.0309656560421, 43.03263768553734, 44.53689716756344, 46.49368196725845, 48.53612557053566, 48.21394845843315, 47.74645954370499, 48.173142448067665, 51.1187481880188, 50.95543295145035, 44.395704343914986, 42.177079394459724, 42.0941374450922, 40.24508826434612, 40.45212775468826, 41.54728598892689, 42.59695686399937, 39.275460094213486, 40.1215834915638, 40.55904261767864, 40.80977976322174, 41.208503767848015, 42.96927988529205, 40.41900493204594, 39.870663955807686, 40.84283038973808, 40.76033681631088, 39.78490635752678, 41.9356669485569, 40.24499326944351, 39.61828529834747, 40.28162710368633, 41.65473662316799, 42.28211335837841, 40.536038652062416, 41.17038041353226, 41.53157763183117, 40.58805786073208, 40.7383967936039, 40.20077884197235, 43.577072471380234, 49.790183678269386, 53.341089338064194, 49.21258047223091, 49.168533235788345, 45.458229929208755, 46.978695541620255, 41.82826571166515, 41.667739525437355, 40.08029870688915, 40.691746696829796, 39.62780378758907, 43.17031189799309, 43.46876688301563, 44.82670001685619, 42.893409356474876, 44.345581233501434, 44.08438324928284, 44.062485024333, 46.28075659275055, 51.35631904006004, 52.08054877817631, 54.78930562734604, 54.26583431661129, 57.916724011301994, 56.81716941297054, 59.255354180932045, 58.44013072550297, 58.248765394091606, 57.63617746531963, 54.67343084514141, 52.85494342446327, 58.349866569042206, 57.20588855445385, 60.753336399793625, 60.85387900471687, 62.35578641295433, 62.70638979971409, 62.349444553256035, 65.30092477798462, 56.13550879061222, 51.41113489866257, 47.63118892908096, 41.43567457795143, 13.287099469453096, 0.05621101830911357, 2.99437731038779, 49.38189938664436, 65.32012894749641, 56.12559512257576, 64.5974837243557, 61.865950897336006, 66.73496782779694, 38.975910767912865, 36.021485701203346, 38.14304105937481, 49.13806267082691, 2.7975780330598354, 0.2131519521935843, 0.12003423791611567, 0.1304506219457835, 0.09218467137543485, 0.024433499747829046, 0.00755090964048577, 0.026061114949698094, 0.04455286907614209, 0.05141372748767026, 0.0033320440797979245, 0.05123547845869325, 0.11410902734496631, 0.013712917734665098, 0.01529083037894452, 0.24082901392830536, 0.18120543361874297, 0.1789817216922529, 0.14595289947465062, 0.11809977062512189, 0.19827088195597753, 0.18483321473468095, 0.14036627893801779, 0.1059755044116173, 0.11474261365947314, 0.12100532330805436, 0.11054945702198893, 0.19871360273100436, 0.11749823766876943, 0.2092256347532384, 0.23517322522820905, 0.6673222698736936, 0.40525621036067605, 17.733792811632156, 69.87889632582664, 35.437875017523766, 41.89294584095478, 49.75968651473522, 64.91786733269691, 71.89674004912376, 68.5002239048481, 75.0756798684597, 68.19922685623169, 73.73325750231743, 22.906951121985912, 0.2813433750998229, 0.36354926240164787, 12.95605743303895, 76.93386375904083, 71.33092761039734, 69.02600929141045, 62.443155124783516, 61.71341188251972, 59.21172112226486, 56.802095621824265, 57.14731089770794, 59.739045426249504, 59.31525036692619, 60.53667202591896, 58.948946222662926, 59.606086760759354, 62.281204015016556, 63.440415412187576, 64.10265147686005, 64.90652114152908, 63.34299623966217, 66.75641387701035, 66.23899564146996, 62.49988228082657, 56.81926690042019, 54.42131817340851, 49.93400976061821, 49.65194329619408, 49.650423377752304, 50.32420702278614, 51.86168432235718, 49.9439462274313, 52.08589889109135, 47.52000689506531, 46.60503879189491, 44.65146861970425, 46.59386359155178, 49.81816917657852, 48.773027658462524, 50.33424228429794, 48.5130076110363, 51.41279920935631, 54.79790456593037, 50.432052835822105, 47.674787789583206, 46.6690843552351, 44.1503781080246, 42.33091413974762, 44.06686618924141, 45.780201852321625, 45.39909370243549, 42.52908110618591, 43.10052864253521, 42.67046011984348, 43.59987124800682, 43.79782922565937, 45.14298364520073, 42.03731149435043, 42.662890926003456, 43.051868453621864, 43.86000908911228, 40.27106747031212, 44.50386554002762, 42.724227234721184, 40.886197462677956, 41.70663803815842, 44.344467893242836, 45.209738463163376, 42.422724813222885, 43.67696911096573, 43.968375474214554, 42.84427039325237, 44.71688210964203, 42.37839639186859, 45.335416719317436, 48.629703149199486, 55.86656682193279, 51.701249331235886, 51.33660949766636, 46.156936436891556, 48.65674249827862, 45.11051058769226, 43.40921267867088, 39.50919695198536, 42.97685667872429, 42.57828086614609, 46.45584359765053, 46.10071085393429, 47.118600234389305, 45.104871690273285, 47.53560125827789, 46.31769821047783, 45.84050841629505, 47.10172154009342, 52.96553649008274, 53.58783669769764, 55.42777016758919, 54.95397359132767, 61.770663410425186, 60.30152924358845, 61.76986925303936, 61.67849175632, 60.165010169148445, 60.34492291510105, 58.17625768482685, 53.99685434997082, 59.97267968952656, 58.94954279065132, 65.58864533901215, 63.297132700681686, 63.271088898181915, 62.97364845871925, 64.27038967609406, 67.44096994400024, 60.675740763545036, 57.13010922074318, 54.33749467134476, 44.74622793495655, 14.562067855149508, 0.18315417983103544, 3.6610738607123494, 53.91621507704258, 71.15676775574684, 61.6042323410511, 71.5729670226574, 66.03402704000473, 73.25854137539864, 43.307666927576065, 49.48023051023483, 46.755655109882355, 61.29934810101986, 5.900449259206653, 0.4107867839047685, 0.37649460369721055, 0.25517616828437895, 0.1734559572651051, 0.12899353372631595, 0.22788206959376112, 0.15257316845236346, 0.09192264871671796, 0.1400955583085306, 0.10890300982282497, 0.22674434236250818, 0.2633454924216494, 0.10746359956101514, 0.08853426959831268], [0.05101925002236385, 0.14087806397583336, 0.008807653703115648, 0.018243526137666777, 0.015434858978551347, 0.017682792749837972, 0.016697296705388, 0.030626683146692812, 0.028668383638432715, 0.06913640696438961, 0.09678408707259223, 0.07200928288511932, 0.04230309663398657, 0.029432803166855592, 0.007736242005194072, 0.01863409619545564, 0.19955494586611167, 0.24209097668062896, 0.40597018611151725, 37.079808712005615, 46.79716408252716, 43.52164104580879, 33.19764442741871, 45.820806473493576, 70.46118468046188, 52.17579446732998, 53.501634523272514, 54.060231149196625, 57.767293229699135, 28.40324029326439, 0.2296228808700107, 0.0928309558366891, 15.905838198959827, 74.55303311347961, 69.70746472477913, 62.610414549708366, 59.90334860980511, 56.09033301472664, 55.09479023516178, 52.18625150620937, 52.031067833304405, 51.99640989303589, 53.96278537809849, 51.21246635913849, 54.77167457342148, 54.42380703985691, 52.34788343310356, 52.538067027926445, 56.32316932082176, 54.61266450583935, 57.35330544412136, 55.17173990607262, 56.90385416150093, 49.05623786151409, 48.53708691895008, 43.663392439484596, 47.373266369104385, 43.483073115348816, 44.02602218091488, 43.95259492099285, 44.8108396679163, 44.52491641044617, 44.75836828351021, 41.3328292965889, 42.141201719641685, 41.47153705358505, 43.14866445958614, 41.85508467257023, 48.99652026593685, 46.50707624852657, 40.77799066901207, 44.90726709365845, 45.273563638329506, 41.873278096318245, 41.05411425232887, 37.63167589902878, 38.87099839746952, 39.62754540145397, 38.1678157299757, 38.354389518499374, 37.5550340116024, 37.409995794296265, 38.31726171076298, 39.91393223404884, 38.50026749074459, 39.14832651615143, 39.16984476149082, 38.298581913113594, 39.30233985185623, 39.94043581187725, 41.74183174967766, 37.66808934509754, 39.44434583187103, 37.899527326226234, 38.838639333844185, 39.00159738957882, 37.46085986495018, 39.13083225488663, 37.44222566485405, 38.47081147134304, 39.16383348405361, 38.00110727548599, 36.115074679255486, 39.56454858183861, 39.825746566057205, 41.21556758880615, 47.49411128461361, 46.71839810907841, 42.47146479785442, 42.39277862012386, 48.152631148695946, 43.8976688683033, 39.973881617188454, 38.02574135363102, 36.65615804493427, 37.60223127901554, 39.50606971979141, 39.43211428821087, 39.71164248883724, 41.740490421652794, 42.677554339170456, 41.80008642375469, 42.363710179924965, 41.74609512090683, 48.47826227545738, 50.15216365456581, 50.70119999349117, 53.38766723871231, 52.73911044001579, 56.116468012332916, 55.90115636587143, 54.56765592098236, 55.77654205262661, 54.91606682538986, 54.932584539055824, 54.50845509767532, 55.1825313270092, 56.68897949159145, 58.51034715771675, 63.87713357806206, 63.39985638856888, 61.342658177018166, 61.8558244407177, 63.636408895254135, 57.98925831913948, 45.246258303523064, 34.662093445658684, 36.865652203559875, 16.421898007392883, 0.42062867141794413, 2.0004696305841208, 48.16241182386875, 57.764420583844185, 61.1563465744257, 55.528981536626816, 58.81201297044754, 45.05324766039848, 25.933401323854923, 32.532258331775665, 38.65594133734703, 22.53434121608734, 0.44169699714984745, 0.026849971545743756, 0.14743324660230428, 0.05805854671052657, 0.10285052834660746, 0.01827467407565564, 0.038628645561402664, 0.030950654727348592, 0.08085471097729169, 0.03938565474527422, 0.06596761450055055, 0.07422725801006891, 0.10168114109546877, 0.04786309633345809, 0.08430413916357793, 0.05234574622591026, 0.09485226182732731, 0.04599798274284694, 0.017392824520356953, 0.04690364781708922, 0.03786067114560865, 0.04589898024278227, 0.025230939281755127, 0.03935809509130195, 0.021173534441913944, 0.028101284478907473, 0.05050317537097726, 0.07673943531699479, 0.024973302715807222, 0.01672784721449716, 0.048434861746500246, 0.06661609571892768, 0.08607217983808368, 0.7066243328154087, 47.20615513622761, 48.13761055469513, 40.064993128180504, 44.186761155724525, 49.241371527314186, 77.74360790848732, 58.82088549435139, 60.252580270171165, 58.60435411334038, 65.74300065636635, 32.60317012667656, 0.21532254118938, 0.09021107063745148, 17.49190729111433, 77.76077538728714, 71.05260014533997, 66.61045610904694, 61.66284419596195, 61.19972504675388, 58.29307861626148, 55.00998258590698, 55.256923735141754, 53.65277521312237, 55.86375877261162, 52.47562117874622, 56.516225561499596, 55.36883533000946, 56.2303327023983, 55.24639070034027, 57.85758018493652, 57.418069168925285, 58.02307650446892, 58.396205082535744, 60.005502328276634, 52.520899549126625, 50.70995852351189, 48.19507107138634, 48.85256119072437, 44.6298211812973, 45.84377244114876, 45.92217743396759, 47.28644102811813, 45.302050709724426, 47.02349133789539, 44.108074977993965, 44.2681185901165, 43.003101870417595, 46.20973840355873, 45.780194252729416, 49.14642982184887, 48.01635906100273, 41.91554702818394, 47.58872240781784, 49.924221485853195, 45.15172317624092, 43.33040490746498, 42.567276656627655, 42.77296721935272, 42.63732209801674, 40.56664980947971, 42.21874415874481, 40.619079396128654, 39.71984624862671, 41.01521573960781, 41.995654329657555, 42.304155975580215, 41.177649423480034, 40.63714362680912, 39.888747185468674, 42.940819412469864, 42.81291447579861, 43.92864480614662, 41.71855419874191, 42.39586405456066, 40.746163576841354, 41.92609146237373, 41.50440149009228, 40.11865384876728, 41.33593752980232, 40.40146887302399, 41.65790565311909, 42.00503222644329, 42.100030928850174, 38.93050700426102, 42.923944517970085, 41.85492128133774, 43.90592582523823, 49.74878489971161, 48.871050998568535, 45.27603730559349, 44.82793115079403, 50.33393070101738, 45.32922305166721, 41.9101969152689, 40.98657667636871, 38.41063030064106, 39.51376810669899, 42.797031328082085, 42.02289506793022, 41.29699721932411, 42.683299630880356, 44.70212750136852, 44.70954470336437, 45.144891142845154, 45.79836867749691, 49.532052129507065, 52.3187579959631, 54.35529671609402, 56.24211207032204, 54.71091203391552, 57.024433091282845, 57.257797569036484, 57.50577226281166, 57.68100745975971, 58.496998474001884, 55.22961840033531, 54.904466047883034, 56.62236526608467, 58.95303100347519, 60.2995191514492, 63.99866625666618, 64.01973232626915, 64.23950493335724, 61.33092820644379, 63.68042193353176, 61.12126685678959, 52.07002334296703, 41.31142884492874, 40.96045307815075, 17.966222539544106, 0.2609634061809629, 2.216451703570783, 53.898375034332275, 62.95844167470932, 69.48025971651077, 62.30579249560833, 64.96306210756302, 49.48041670024395, 35.42777895927429, 36.0114960372448, 44.70175512135029, 26.411256082355976, 0.5110512021929026, 0.03426737763220444, 0.19559523178031668, 0.019261433626525104, 0.08788711682427675, 0.04671171358495485, 0.14864052791381255, 0.022941784773138352, 0.055331005569314584, 0.043991278507746756, 0.025478582829236984, 0.05320286742062308, 0.029657595987373497, 0.035176074379705824, 0.033737565827323124, 0.12188177744974382, 0.22255341958953068, 0.14281615294748917, 0.11646996237686835, 0.10739011951955035, 0.14686473179608583, 0.15796773601323366, 0.10371609518188052, 0.15044179453980178, 0.20877599716186523, 0.18065320153255016, 0.18114515638444573, 0.1561394106829539, 0.10767765721539035, 0.09946916994522326, 0.19654503237688914, 0.2590398781467229, 0.20154822093900293, 0.7831424300093204, 62.502203956246376, 60.596959590911865, 58.10527749359608, 50.73412522673607, 59.98762808740139, 81.33515998721123, 64.95724081993103, 66.59332662820816, 63.89101043343544, 71.73201888799667, 36.76928177475929, 0.6728275213390589, 0.20768944843439385, 18.374978005886078, 80.92185616493225, 72.76092007756233, 71.90514519810677, 65.52243769168854, 65.89141309261322, 60.80625995993614, 58.28489385545254, 59.80745315551758, 59.520636945962906, 61.03731036186218, 56.84172749519348, 59.31385584175587, 59.47457581758499, 57.23048083484173, 58.83337542414665, 61.561667025089264, 60.47286584973335, 61.408060267567635, 59.39280040562153, 61.539073437452316, 54.488680958747864, 51.593878492712975, 51.06827549636364, 52.72646851837635, 47.49615557491779, 47.456060126423836, 47.46043749153614, 49.41166698932648, 47.84056909382343, 48.4630136936903, 43.89436684548855, 47.166827246546745, 45.95084309577942, 48.760773316025734, 46.82440862059593, 51.1282704770565, 49.07631978392601, 44.840242490172386, 48.91129083931446, 51.826232224702835, 47.90067046880722, 47.410918548703194, 45.747941583395004, 46.15321263670921, 44.186092391610146, 43.378643319010735, 44.563374146819115, 43.609366938471794, 41.43346309661865, 45.1187789440155, 45.56025445461273, 43.97099353373051, 45.36950848996639, 44.879129603505135, 43.61877143383026, 45.63494324684143, 45.7376479357481, 48.32880489528179, 42.79235377907753, 43.88783499598503, 43.710794895887375, 44.67414580285549, 43.14554862678051, 42.65382081270218, 44.218687042593956, 43.55025351047516, 45.2444875985384, 43.54301489889622, 43.785175904631615, 42.10563562810421, 44.83713045716286, 42.794097885489464, 46.354594230651855, 52.31416404247284, 50.62767393887043, 46.47614970803261, 47.39953055977821, 52.27593049407005, 47.65987738966942, 44.69762474298477, 42.23883368074894, 41.893447414040565, 42.00405567884445, 44.84326712787151, 43.58692154288292, 42.763486728072166, 46.36685997247696, 46.82434402406216, 47.17986814677715, 46.98824442923069, 46.4899467676878, 51.08795464038849, 55.47780968248844, 58.03019732236862, 59.26797330379486, 57.44266904890537, 59.47805643081665, 59.603514298796654, 58.2139440625906, 58.70996944606304, 61.28011733293533, 58.7089055031538, 58.024231642484665, 60.64111702144146, 60.53775496780872, 61.0188015550375, 66.38754487037659, 65.33235669136047, 66.1120292544365, 64.33738008141518, 66.79632693529129, 64.31897386908531, 56.13863982260227, 47.5821715593338, 45.17926789820194, 20.289892852306366, 0.4933822393650189, 3.123515280894935, 59.31556575000286, 68.30587953329086, 71.43549039959908, 67.77799665927887, 70.56532189249992, 55.90741463005543, 38.57000894844532, 48.57717476785183, 54.613511860370636, 40.666740238666534, 0.527966053923592, 0.11518766477820463, 0.30640902696177363, 0.1762304615112953, 0.1908520472352393, 0.14884785428876057, 0.26851051370613277, 0.17496826127171516, 0.14769930654438213, 0.15080359153216705, 0.09460389468586072, 0.1685437114792876, 0.19684628496179357, 0.1660781484679319, 0.13979785318952054], [0.04955936019541696, 0.028999416754231788, 0.01732590691972291, 0.030689478116983082, 0.05197764839977026, 0.03834259958239272, 0.07760602631606162, 0.02293523160915356, 0.048539107519900426, 0.01983180751267355, 0.06890816686791368, 0.08431787631707266, 0.02310746924194973, 0.008889407763490453, 0.028833429860242177, 0.013777957701677224, 0.11798876017564908, 0.21592268632957712, 0.29466646956279874, 7.509681433439255, 42.45770953595638, 31.80589310824871, 39.303859770298004, 34.614793583750725, 54.16540190577507, 61.91570162773132, 63.53138253092766, 58.05966854095459, 54.75427910685539, 42.330036386847496, 0.19161096744937822, 0.19512865837896243, 25.70409692823887, 82.45598584413528, 67.46030330657959, 63.09101656079292, 58.866813629865646, 58.584671169519424, 57.614381834864616, 53.846682608127594, 50.2975058555603, 52.29381613433361, 51.36936753988266, 53.74161824584007, 51.03095769882202, 50.234661027789116, 47.69551947712898, 47.60393679141998, 49.5588368922472, 48.393739610910416, 47.963591292500496, 46.088179126381874, 46.764539033174515, 44.716296941041946, 47.4984772503376, 44.65846784412861, 44.67534653842449, 44.161473512649536, 44.402289390563965, 43.35885778069496, 42.53448821604252, 43.39410088956356, 44.73454736173153, 41.91150784492493, 40.373194590210915, 41.41951024532318, 45.16210041940212, 46.355665773153305, 48.985683247447014, 45.60611039400101, 43.046997115015984, 41.51533730328083, 42.58054554462433, 41.29364959895611, 38.1906259059906, 36.8416602909565, 39.09859098494053, 37.78243660926819, 40.38268268108368, 40.70113979279995, 39.78296086192131, 38.754063472151756, 40.10672628879547, 39.986770525574684, 37.174207046628, 39.525323286652565, 40.88384538888931, 40.70209354162216, 40.62076650559902, 38.41783091425896, 40.92841699719429, 40.4097144305706, 40.62240421772003, 38.77137154340744, 38.12044367194176, 39.46523331105709, 40.37440672516823, 39.17287319898605, 37.780665904283524, 40.60518354177475, 39.1338074952364, 38.678325936198235, 39.20727655291557, 38.5124534368515, 38.13516788184643, 38.59865181148052, 42.06432804465294, 42.507087886333466, 41.86765059828758, 39.718470722436905, 46.95393607020378, 45.29700078070164, 40.01794785261154, 40.16127996146679, 39.28643770515919, 38.08640889823437, 39.34686206281185, 38.15525360405445, 41.60086691379547, 40.602033510804176, 39.66295950114727, 40.403843745589256, 41.20621249079704, 42.972505912184715, 43.08376394212246, 47.29938693344593, 52.7055848389864, 53.97628225386143, 56.44207254052162, 55.51401033997536, 52.90891952812672, 54.30535979568958, 54.487833604216576, 54.29888114333153, 52.92332075536251, 55.89021675288677, 57.029433622956276, 60.89737147092819, 60.25042958557606, 59.2931317538023, 59.70990099012852, 62.977748438715935, 58.89642924070358, 61.49942636489868, 59.30558368563652, 57.23055303096771, 42.65045039355755, 40.47006659209728, 16.372054181993008, 0.07987778488313779, 3.5602018609642982, 52.41270035505295, 57.79034659266472, 49.29564781486988, 49.616654589772224, 43.33183743059635, 32.305642291903496, 27.4945380538702, 27.50294890254736, 37.13022820651531, 3.7590366415679455, 0.3365928557468578, 0.020055611421412323, 0.05542809332837351, 0.03015741574927233, 0.058682340386440046, 0.012620975448953686, 0.01136318634962663, 0.08274290536064655, 0.033813079353421926, 0.04609045805409551, 0.04379031975986436, 0.06168110681755934, 0.02239290904981317, 0.06479022689745761, 0.07104235352016985, 0.0033375672819602187, 0.018122394649253692, 0.06404337400454096, 0.04780516057508066, 0.012791936587746022, 0.04748566228954587, 0.0184973740397254, 0.024710832913115155, 0.034054366406053305, 0.06805648561567068, 0.048532955115661025, 0.031082389650691766, 0.08929546078434214, 0.04358121965196915, 0.07572100090328604, 0.008022426209208788, 0.08286947122542188, 0.14211727248039097, 0.3676935634575784, 13.287984821945429, 54.21608738601208, 34.00881730020046, 47.28215105831623, 43.37369218468666, 60.86314670741558, 69.44702669978142, 66.51380449533463, 64.75642919540405, 60.25557450950146, 48.149902895092964, 0.2410856040660292, 0.15497076557949185, 28.986434899270535, 83.87286901473999, 69.38059106469154, 65.69302573800087, 61.55991151928902, 61.246264949440956, 59.83915105462074, 55.6367589533329, 53.43954585492611, 55.9885098785162, 54.95208889245987, 56.7479295283556, 53.510054871439934, 53.01919721066952, 51.83947451412678, 50.87636299431324, 51.02220676839352, 49.86107647418976, 49.62087236344814, 48.73944126069546, 48.93926873803139, 48.30361224710941, 48.760929107666016, 47.27393589913845, 47.231218591332436, 46.29476644098759, 47.038758918643, 45.481819063425064, 45.045781061053276, 46.03467799723148, 45.22712633013725, 46.07512302696705, 44.94457729160786, 43.71635399758816, 46.61962240934372, 45.94770826399326, 49.7812769562006, 47.47885510325432, 45.447886884212494, 45.09506441652775, 47.84469947218895, 44.27884541451931, 42.280384451150894, 40.406963378190994, 41.93065121769905, 40.194212794303894, 41.52499258518219, 42.69042044878006, 41.67842835187912, 41.05933137238026, 40.68493366241455, 43.173397332429886, 41.776721477508545, 41.58084578812122, 42.97181434929371, 44.16516311466694, 44.36622552573681, 40.81018254160881, 42.69184537231922, 43.744563683867455, 44.30138200521469, 40.779529586434364, 40.87819889187813, 40.60020960867405, 41.882504001259804, 41.13543748855591, 39.88428242504597, 42.61954665184021, 41.29301503300667, 41.995946913957596, 40.162134915590286, 40.979676246643066, 39.9261561781168, 38.97630214691162, 45.54160885512829, 45.98485507071018, 43.30998860299587, 42.72083401679993, 49.88850340247154, 47.17009127140045, 40.7257054746151, 40.16677066683769, 41.12414449453354, 40.796218290925026, 41.84053145349026, 41.80143915116787, 43.604127019643784, 43.08931924402714, 41.96192353963852, 42.431274354457855, 43.19768562912941, 45.051404759287834, 47.28952266275883, 49.622502475976944, 55.52418999373913, 58.392390087246895, 57.94715657830238, 57.12912507355213, 55.602640584111214, 56.753329038619995, 56.36210963129997, 57.50179387629032, 56.35064944624901, 57.569111064076424, 59.5485008507967, 61.138183549046516, 61.792656630277634, 61.45393140614033, 61.58343605697155, 65.17772018909454, 61.153781712055206, 61.80306427180767, 59.37561012804508, 61.748822182416916, 49.62952829897404, 44.89354982972145, 17.360643334686756, 0.06521376315504313, 3.959419601596892, 55.011673495173454, 66.78095296025276, 57.68147103488445, 54.791258722543716, 49.33794714510441, 38.53650614619255, 33.90852928161621, 32.095574364066124, 46.16015486419201, 4.969991762191057, 0.36018760059960186, 0.15251542936312035, 0.08980965780210681, 0.023521658149547875, 0.056376962529611774, 0.013697733393200906, 0.014592474981327541, 0.02742277596553322, 0.0665643457614351, 0.007037316545392969, 0.07593388596433215, 0.056648974496056326, 0.026668215868994594, 0.03427572679356672, 0.04882579545665067, 0.09383562341099605, 0.15642835845937952, 0.1691368210595101, 0.09648811857914552, 0.10089663905091584, 0.13441171642625704, 0.15591715229675174, 0.13043577899225056, 0.13256197271402925, 0.1505103096133098, 0.10436465061502531, 0.14329415542306378, 0.18114251433871686, 0.12080775617505424, 0.18428910174407065, 0.10967276539304294, 0.16092976613435894, 0.4080169106600806, 0.4377484746510163, 16.64385549724102, 67.15350776910782, 43.25255088508129, 56.84236966073513, 48.127161115407944, 69.31711167097092, 74.14874240756035, 74.14405345916748, 69.17306140065193, 69.40278947353363, 54.00900989770889, 0.5275878554675728, 0.27060289517976344, 31.262305676937103, 85.25573641061783, 73.16837221384048, 70.37977024912834, 64.65626657009125, 64.28402334451675, 65.42726799845695, 60.760480016469955, 56.563362032175064, 60.54546855390072, 58.44404071569443, 62.40354984998703, 56.79790824651718, 58.01756680011749, 54.37593720853329, 53.496782183647156, 53.26858542859554, 53.40600125491619, 53.18628564476967, 51.94584220647812, 51.935856342315674, 49.39913146197796, 52.69172318279743, 48.60422171652317, 48.4317983686924, 47.919042482972145, 48.63148905336857, 49.01344835758209, 46.53185471892357, 48.88138264417648, 48.49392503499985, 48.100057169795036, 46.304273530840874, 46.095527932047844, 48.328679502010345, 49.60958316922188, 53.25266048312187, 50.619986951351166, 48.81910398602486, 47.46947720646858, 50.58930739760399, 48.31713952124119, 44.579496681690216, 42.9111772030592, 45.074712708592415, 42.585937455296516, 44.36637371778488, 45.92309318482876, 44.67620529234409, 44.92114394903183, 46.009861528873444, 46.22635871171951, 43.40925067663193, 44.56809729337692, 46.04619137942791, 46.07608437538147, 47.103705033659935, 42.872168496251106, 46.02352939546108, 45.13799451291561, 47.19630986452103, 42.64644540846348, 43.577270060777664, 42.84704424440861, 44.63515989482403, 43.25647607445717, 41.981720477342606, 45.63008710741997, 44.400720074772835, 44.52709749341011, 43.09115834534168, 43.38419482111931, 43.76237332820892, 40.18594063818455, 46.366187408566475, 49.11956146359444, 48.208472952246666, 45.86697019636631, 51.3512197136879, 49.53412301838398, 42.42502748966217, 44.72026012837887, 44.42635349929333, 42.56625831127167, 45.16373053193092, 43.80089186131954, 45.31784266233444, 44.29889313876629, 42.588791102170944, 44.48126055300236, 44.83752563595772, 47.78529345989227, 48.987073972821236, 50.89962914586067, 58.40300291776657, 61.44496388733387, 61.563597321510315, 60.710759684443474, 57.13619649410248, 59.906434044241905, 58.886029198765755, 57.88566827774048, 57.477931156754494, 60.54709106683731, 59.9181754142046, 63.96310776472092, 64.24274235963821, 63.72499354183674, 63.97366359829903, 67.7964636683464, 63.02305720746517, 66.38730928301811, 63.338558077812195, 69.17899668216705, 55.20887531340122, 47.879167422652245, 19.439076706767082, 0.317271159728989, 4.984534056857228, 61.803505048155785, 71.78938060998917, 59.01558704674244, 61.907376274466515, 57.074290215969086, 44.228752702474594, 43.63660387694836, 41.42243608832359, 57.191392332315445, 10.330179836601019, 0.5691248516086489, 0.34372798225376755, 0.31768043932970613, 0.12910709716379642, 0.154184385901317, 0.17852311895694584, 0.14290127728600055, 0.15796718682395294, 0.1995783532038331, 0.10893696307903156, 0.2651690976927057, 0.1346025671227835, 0.1302272206521593, 0.2186743769561872, 0.19656012766063213], [0.051297533136676066, 0.0698492546507623, 0.03941260583815165, 0.01715426114969887, 0.025209407722286414, 0.02721666114666732, 0.01980321256269235, 0.02020992247707909, 0.05296568815538194, 0.015240628727042349, 0.03428358984820079, 0.02786666933388915, 0.01590354564541485, 0.029559673312178347, 0.09073910128790885, 0.06954068448976614, 0.04161231670877896, 0.030490756944345776, 0.32925764622632414, 0.3729889652458951, 29.535530135035515, 40.17539620399475, 32.62224890291691, 28.234753534197807, 39.388317838311195, 63.92593055963516, 64.60224106907845, 53.605205565690994, 55.23304581642151, 46.31577171385288, 2.2935970639809966, 0.6236960389651358, 32.469436302781105, 79.8995590209961, 67.9354678094387, 61.74152657389641, 57.57733382284641, 56.817925572395325, 56.420311108231544, 52.84555032849312, 52.16358192265034, 51.85938164591789, 50.163502246141434, 48.1102330237627, 47.720183953642845, 48.74374262988567, 45.400184243917465, 45.19211120903492, 45.82306735217571, 45.208784714341164, 44.59998518228531, 43.31800997257233, 43.84336978197098, 45.15529118478298, 44.937502071261406, 41.60950385034084, 45.08999928832054, 42.14939787983894, 43.12783017754555, 42.63683572411537, 43.23096044361591, 43.514079451560974, 43.977757170796394, 43.68173025548458, 41.40114203095436, 41.829458847641945, 42.55903869867325, 42.724861800670624, 46.53403200209141, 45.86163528263569, 41.63037613034248, 43.47011961042881, 40.38550592958927, 40.25600507855415, 41.04685664176941, 39.55185726284981, 39.855046793818474, 40.12840032577515, 39.1415286809206, 39.64577302336693, 40.51993131637573, 37.54710763692856, 39.305892661213875, 41.421717926859856, 40.358892157673836, 42.35548362135887, 44.05385568737984, 43.998553454875946, 43.50632406771183, 41.21923819184303, 43.67322251200676, 42.44790606200695, 41.584584787487984, 39.691442772746086, 40.25013439357281, 38.7342931330204, 40.03227688372135, 38.93727444112301, 40.02231761813164, 38.08881416916847, 37.63185828924179, 37.17174477875233, 38.826624378561974, 38.81721988320351, 39.802233427762985, 39.61811810731888, 40.03519892692566, 39.37852196395397, 41.82908646762371, 42.19432666897774, 44.48376081883907, 43.45100283622742, 39.080389961600304, 40.82433678209782, 38.923397585749626, 38.932596892118454, 38.056892082095146, 40.9141905605793, 41.17498956620693, 39.65515851974487, 39.419985339045525, 39.66473400592804, 41.798072531819344, 41.729353219270706, 42.03118622303009, 42.99376957118511, 46.66289448738098, 53.96417610347271, 56.31537973880768, 54.492875933647156, 54.68384988605976, 54.461147636175156, 54.9647232145071, 55.324978083372116, 57.06736698746681, 54.42443400621414, 57.218788862228394, 57.039123103022575, 58.46864439547062, 60.49658037722111, 61.450036615133286, 57.86071501672268, 56.48588038980961, 54.73841115832329, 62.3386075347662, 63.48910979926586, 57.895251363515854, 52.73108907043934, 13.36930425837636, 0.1090706980903633, 4.302688194438815, 50.808057859539986, 45.20288743078709, 36.94804698228836, 58.27653810381889, 54.49870482087135, 31.358869895339012, 28.762037940323353, 33.01894761621952, 33.358178213238716, 0.44003918766975403, 0.03673653263831511, 0.03143780973914545, 0.06517308604088612, 0.03575053749955259, 0.0062018971402721945, 0.02242011803900823, 0.08247248159023002, 0.03137782565318048, 0.05660189264744986, 0.10908301032031886, 0.03151822886138689, 0.024638206341478508, 0.02757115726126358, 0.05714433209504932, 0.027841007722599898, 0.024617661838419735, 0.04051479532790836, 0.01594286091858521, 0.010208348903688602, 0.024246228058473207, 0.011676510894176317, 0.13537533581256866, 0.03525715772411786, 0.016828072402859107, 0.018253576672577765, 0.051336640608496964, 0.05349214545276482, 0.09539462334942073, 0.06612817815039307, 0.13334008486708626, 0.05726122406485956, 0.04550317804387305, 0.08935132223996334, 0.41246243461500853, 0.8439997269306332, 41.0820921510458, 46.81730680167675, 36.18193969130516, 39.56542253494263, 46.13732188940048, 72.46923252940178, 70.4963555932045, 59.227991849184036, 61.166841611266136, 56.15419618785381, 2.285128030925989, 0.4545779200270772, 32.810034826397896, 80.12627005577087, 69.53436121344566, 67.16584950685501, 60.14371611177921, 61.90083682537079, 60.44914372265339, 56.29291154444218, 55.43703407049179, 54.276196360588074, 53.247739747166634, 51.55789062380791, 51.49774745106697, 50.79999089241028, 47.653254345059395, 47.52235896885395, 49.00823883712292, 47.571668922901154, 45.97018025815487, 46.30404554307461, 47.32729643583298, 47.8169609606266, 46.904888302087784, 46.12272307276726, 47.85053215920925, 44.4120092689991, 44.088361635804176, 44.14313569664955, 46.093753427267075, 44.40756730735302, 45.769148245453835, 46.39155864715576, 45.31091943383217, 43.38370464742184, 46.17231421172619, 44.4307004660368, 48.57891507446766, 47.999073788523674, 45.25765389204025, 45.55734001100063, 44.0991036593914, 44.52678591012955, 44.18651036918163, 41.3627564907074, 42.800177559256554, 42.751703560352325, 42.66338109970093, 42.400112226605415, 41.97171941399574, 40.159243270754814, 42.20700278878212, 44.71708729863167, 42.073637545108795, 44.33360427618027, 46.87797054648399, 44.66647781431675, 44.38801735639572, 43.28897953033447, 46.57230354845524, 45.774859338998795, 44.091405272483826, 40.67807503044605, 41.45040638744831, 40.71475066244602, 41.41554705798626, 41.40290133655071, 42.97030583024025, 39.51124124228954, 39.62312623858452, 40.19019640982151, 42.0489426702261, 41.38988323509693, 41.315084248781204, 40.84917984902859, 42.58429974317551, 42.78014123439789, 43.35649810731411, 44.810151904821396, 47.515211552381516, 45.96186250448227, 40.00028260052204, 43.86741489171982, 41.05577476322651, 42.153653651475906, 40.98491996526718, 43.44193272292614, 43.63571472465992, 41.77877716720104, 40.96968278288841, 42.328543066978455, 43.6485580354929, 43.18749077618122, 43.88408459722996, 46.29376709461212, 48.703947365283966, 55.630261301994324, 59.49560388922691, 57.186581790447235, 58.47329914569855, 56.373987793922424, 57.091552689671516, 55.35464309155941, 58.941278234124184, 57.828743532299995, 57.61046044528484, 58.53742830455303, 59.36014875769615, 62.692528143525124, 63.84079992771149, 59.257299676537514, 58.133418783545494, 54.569795206189156, 61.84386648237705, 63.843619376420975, 62.12518818676472, 52.68039219081402, 14.288655426353216, 0.0581275033619022, 5.002914145588875, 56.24311521649361, 52.04262301325798, 39.977271035313606, 67.27583840489388, 59.55649182200432, 40.81889167428017, 34.04847577214241, 39.93457272648811, 39.57252435386181, 0.5682157503906637, 0.019103734666714445, 0.018225521635031328, 0.12991410854738206, 0.04192202977719717, 0.06286629810347222, 0.05004839098546654, 0.04868968186201528, 0.05288902801112272, 0.110334850178333, 0.03586537372029852, 0.021112817485118285, 0.054220555975916795, 0.033458900506957434, 0.05259698176814709, 0.05720580418710597, 0.07022934558335692, 0.10344852868001908, 0.20942835981259122, 0.0910485174972564, 0.10375297992140986, 0.0958977326808963, 0.30420324532315135, 0.08311736339237541, 0.22517689678352326, 0.12902206188300624, 0.137402675463818, 0.13803884445223957, 0.1344051558407955, 0.11611022855504416, 0.21544100280152634, 0.1910866252728738, 0.1530301384627819, 0.09410045880940743, 0.39383040159009397, 0.8667108113877475, 52.403736636042595, 56.377931982278824, 48.75115983188152, 44.17272090911865, 51.30162097513676, 80.37095412611961, 76.15065738558769, 66.07328653335571, 70.52677676081657, 64.64200973510742, 2.571440292522311, 0.6479154049884528, 36.05833612382412, 82.791887819767, 74.98576149344444, 69.42244961857796, 64.55809503793716, 64.54880073666573, 62.7304957062006, 58.164143934845924, 59.269554018974304, 58.18859562277794, 58.172146305441856, 53.95922116935253, 54.15529444813728, 55.03940440714359, 50.462287813425064, 49.464446157217026, 51.976263374090195, 49.32726211845875, 49.22554537653923, 48.31861764192581, 49.01010453701019, 50.09596087038517, 48.76421973109245, 47.39673770964146, 50.40253221988678, 45.91602936387062, 46.32746368646622, 46.194691210985184, 47.976480200886726, 46.59261345863342, 48.17221149802208, 47.939177602529526, 48.22497546672821, 46.25034682452679, 48.178655952215195, 46.99971601366997, 50.26155598461628, 50.817154571413994, 46.05482831597328, 48.06127265095711, 45.76158665120602, 46.60807102918625, 48.76249462366104, 44.98893991112709, 46.325130611658096, 45.50557538866997, 44.34816889464855, 43.35600793361664, 43.578934371471405, 42.56324127316475, 45.34010946750641, 48.39606128633022, 44.40857045352459, 47.340398132801056, 50.10620892047882, 49.494605138897896, 47.36103482544422, 45.98558843135834, 49.739384204149246, 47.93250896036625, 46.54969096183777, 44.23491217195988, 45.77336601912975, 43.326635509729385, 43.96872505545616, 44.476636201143265, 45.29792793095112, 42.34416402876377, 41.90739266574383, 42.52267844974995, 44.122601598501205, 43.926049545407295, 44.211475029587746, 43.844749107956886, 45.829656198620796, 44.28220823407173, 45.62525376677513, 46.481043845415115, 47.93733850121498, 47.429252564907074, 43.80888283252716, 46.622327864170074, 43.412431105971336, 44.0148089826107, 42.616514414548874, 47.699345871806145, 46.130018681287766, 43.803639113903046, 42.497911378741264, 44.09433871507645, 46.65743038058281, 45.75912058353424, 46.1124674230814, 47.626758366823196, 51.00829191505909, 57.925942316651344, 62.83164247870445, 58.133806362748146, 60.75101852416992, 59.221045821905136, 59.38100963830948, 59.289312958717346, 61.95051535964012, 58.91147643327713, 60.80568619072437, 60.75835973024368, 62.301517724990845, 66.0333126783371, 66.11600384116173, 61.22319258749485, 61.01236090064049, 57.54244789481163, 65.69524481892586, 68.62292692065239, 64.7146238386631, 56.57690830528736, 16.806135289371014, 0.1328901801025495, 5.710435230284929, 63.40254284441471, 54.93730768561363, 47.26844899356365, 72.52274125814438, 63.55788990855217, 45.934374779462814, 44.3789966404438, 48.59192177653313, 52.61342838406563, 0.9229583025444299, 0.1582952606258914, 0.1896930203656666, 0.21441018936457112, 0.1635655332938768, 0.20103621325688437, 0.13568130845669657, 0.22211872885236517, 0.11099758063210174, 0.13797289720969275, 0.08518504619132727, 0.1722488837549463, 0.16307485493598506, 0.15725174162071198, 0.09391594605403952, 0.20174830395262688], [0.027359734231140465, 0.016597019566688687, 0.04469551728107035, 0.05858714139321819, 0.09105420976993628, 0.042355718614999205, 0.034282391279703006, 0.058341267867945135, 0.03446231385169085, 0.0703464045363944, 0.03518675017403439, 0.05376162298489362, 0.08060734573518857, 0.1284352011862211, 0.06331065160338767, 0.03170028139720671, 0.07044124358799309, 0.10275277265463956, 0.16580301948124543, 0.3777223831275478, 8.625160027295351, 44.672458693385124, 35.8839862793684, 31.587349735200405, 23.543118685483932, 49.44919757544994, 65.34587636590004, 58.48545849323273, 57.645224779844284, 51.03663459420204, 10.508638210594654, 1.0346360318362713, 20.136350691318512, 79.34130817651749, 67.02317476272583, 64.30436745285988, 53.81780415773392, 52.77016617357731, 50.97918167710304, 52.64699578285217, 51.00772574543953, 49.781204760074615, 47.44880631566048, 48.095888793468475, 47.70485557615757, 46.045021042227745, 45.66208519041538, 44.84667554497719, 46.778928861021996, 44.24362130463123, 45.28851963579655, 45.61859272420406, 43.64765748381615, 44.633537381887436, 44.9440111219883, 43.183428794145584, 43.77721533179283, 44.539028853178024, 44.17952634394169, 43.71000073850155, 44.571194127202034, 43.59688840806484, 43.96625138819218, 42.53631591796875, 42.73992419242859, 44.27056185901165, 43.75967927277088, 42.784142419695854, 43.8802620023489, 44.39129278063774, 40.28968647122383, 40.00715643167496, 42.21426799893379, 41.8662940710783, 40.951667949557304, 39.236922562122345, 39.77289140224457, 40.970910117030144, 40.75858511030674, 39.748534709215164, 42.327805906534195, 42.46970169246197, 43.89773726463318, 44.12143886089325, 48.36543872952461, 53.38014744222164, 54.9503979831934, 56.29388429224491, 54.047102853655815, 42.19616197049618, 45.859917774796486, 51.7596597969532, 51.69773831963539, 54.03829112648964, 48.71129997074604, 46.58490367233753, 40.998093858361244, 40.39600096642971, 39.25590634346008, 39.089737460017204, 39.89961460232735, 40.37239283323288, 40.84704056382179, 39.67656657099724, 40.197909995913506, 39.33684200048447, 41.073033437132835, 39.41643252968788, 38.4212127327919, 42.47625634074211, 42.49375820159912, 40.685838013887405, 39.71240244805813, 41.19980603456497, 40.217786729335785, 37.82936789095402, 39.54007409512997, 39.67789649963379, 41.085029393434525, 40.514668598771095, 42.08562210202217, 40.05764812231064, 40.084261894226074, 40.110716074705124, 41.68135419487953, 39.769699573516846, 41.77078619599342, 43.93101207911968, 49.33076553046703, 53.019220009446144, 54.59899663925171, 55.61005778610706, 53.72662805020809, 53.171052262187004, 54.63487811386585, 55.68806380033493, 56.52308039367199, 57.026895359158516, 60.425026416778564, 58.00639159977436, 55.60823008418083, 48.79188984632492, 50.07282391190529, 55.348156839609146, 63.91393080353737, 62.76542343199253, 61.84195138514042, 52.73510165512562, 6.884423084557056, 0.11808753260993399, 9.916812367737293, 47.97283999621868, 53.043489307165146, 61.30387365818024, 59.762680158019066, 31.722272895276546, 28.023568466305733, 29.72980421036482, 40.56711718440056, 14.378303065896034, 0.5893864925019443, 0.049570488699828275, 0.0853202877624426, 0.022126541116449516, 0.03865401216899045, 0.033077930129365996, 0.02399520031758584, 0.04840454501390923, 0.08179912358173169, 0.025486102640570607, 0.028070528023818042, 0.028158422428532504, 0.03121314679447096, 0.028610767003556248, 0.0062249283018900314, 0.022961420145293232, 0.014315975804493064, 0.029418527956295293, 0.008058324820012785, 0.038620429986622185, 0.009295717845816398, 0.04611156473401934, 0.048690231051295996, 0.024879387638065964, 0.024956459674285725, 0.024245341191999614, 0.044703862731694244, 0.02019465835473966, 0.09965769029804505, 0.11291093382169493, 0.10630109201883897, 0.021127480467839632, 0.048412942414870486, 0.09520034393062815, 0.18985471950145438, 0.43748394353315234, 13.657559640705585, 54.00893770158291, 42.0031513273716, 40.643124505877495, 33.12404237687588, 59.134779050946236, 71.96809262037277, 64.89754602313042, 64.37717914581299, 58.429153114557266, 11.960483305156231, 1.1414683680050075, 20.069945454597473, 80.58901682496071, 69.01360675692558, 66.70340672135353, 57.7312483638525, 54.514983147382736, 52.959263026714325, 53.98309528827667, 53.147428929805756, 53.011563420295715, 49.77007135748863, 50.0615157186985, 48.6742177605629, 47.878901436924934, 47.01862759888172, 47.05052688717842, 47.886086851358414, 47.884870916604996, 47.09068313241005, 47.39387646317482, 45.36383159458637, 47.06298641860485, 47.115419805049896, 45.86359217762947, 44.91310738027096, 46.263919696211815, 46.19526498019695, 47.636250257492065, 45.63189581036568, 45.88010989129543, 46.84180408716202, 45.01597926020622, 44.1484060138464, 47.84763291478157, 46.621051132678986, 46.005651354789734, 47.733954414725304, 46.62828974425793, 42.894146516919136, 42.854940220713615, 44.98265504837036, 43.73855620622635, 43.97251345217228, 43.22564072906971, 43.18423435091972, 42.10267938673496, 43.069697096943855, 41.2646571546793, 43.56027737259865, 45.187893435359, 44.734467566013336, 45.5178639292717, 49.28247392177582, 54.01274509727955, 58.100311160087585, 57.345633655786514, 53.23941819369793, 42.00423426926136, 49.90297682583332, 51.61505475640297, 52.24738262593746, 52.99783855676651, 49.73129063844681, 45.64497850835323, 43.12076635658741, 40.8377880603075, 41.7583342641592, 41.088099628686905, 41.353013813495636, 41.34694553911686, 43.13802883028984, 40.83925858139992, 42.28893779218197, 40.79724423587322, 43.977662175893784, 40.45197956264019, 42.948726788163185, 43.75483453273773, 46.24444954097271, 42.34666809439659, 41.75839506089687, 43.163878843188286, 43.219496458768845, 39.706619158387184, 41.12337313592434, 41.73538349568844, 42.925152853131294, 43.21249343454838, 44.24215838313103, 41.10088974237442, 41.47870346903801, 43.36279436945915, 44.921611323952675, 43.25274847447872, 44.268867149949074, 47.46856905519962, 52.57101505994797, 56.37206509709358, 56.65978565812111, 55.52294746041298, 58.133186995983124, 55.8257532119751, 57.980241402983665, 58.48275303840637, 58.19229282438755, 59.645688235759735, 63.096085488796234, 60.128007754683495, 58.77055339515209, 52.04734615981579, 53.093825206160545, 57.59227842092514, 65.11343523859978, 61.82736396789551, 65.3495241701603, 51.99665687978268, 6.466595130041242, 0.19674400216899812, 11.09823452308774, 54.18920002877712, 56.566527262330055, 62.267387956380844, 66.99717655777931, 36.57920077443123, 37.20995172858238, 33.5224623978138, 48.06374631822109, 16.211953572928905, 0.6867578707169741, 0.15606188593665138, 0.14013262116350234, 0.10423429237562232, 0.012400045507092727, 0.01819802877434995, 0.05627776336041279, 0.06237032823264599, 0.06281430323724635, 0.045056078597554006, 0.08678633370436728, 0.05166260671103373, 0.034932928247144446, 0.023149910812207963, 0.030039635057619307, 0.012430521801434224, 0.13074984104605392, 0.12727014807751402, 0.13519022933905944, 0.14803376281633973, 0.3648153960239142, 0.10248365506413393, 0.18767927685985342, 0.17156549933133647, 0.12283972682780586, 0.11472483180114068, 0.17725927114952356, 0.13261393789434806, 0.41120286157820374, 0.16200813639443368, 0.17309019720414653, 0.11991340143140405, 0.16543576028198004, 0.20000030868686736, 0.465102672460489, 0.7439348276238889, 19.202077724039555, 68.25320675969124, 47.87560701370239, 50.4606918990612, 37.18511626124382, 66.112812012434, 77.18310758471489, 72.45974823832512, 70.52106186747551, 67.86002665758133, 12.961930017918348, 1.1677190219052136, 23.183752968907356, 83.63735765218735, 74.77706909179688, 72.3203033208847, 61.16762436926365, 58.66717614233494, 55.23930408060551, 57.80461482703686, 56.484007090330124, 56.37581929564476, 51.63564585149288, 53.12715321779251, 52.06490121781826, 52.42959424853325, 51.97784788906574, 50.19407160580158, 50.89631572365761, 50.11070027947426, 50.32869078218937, 51.35939307510853, 47.651324048638344, 49.49147030711174, 49.912928491830826, 48.02743926644325, 48.07244785130024, 50.242507606744766, 49.488061890006065, 50.46945422887802, 49.75955732166767, 49.361578077077866, 49.19048085808754, 48.36552992463112, 46.63486339151859, 51.3530246168375, 47.77724929153919, 47.54535533487797, 48.799918815493584, 48.6355472356081, 45.9222686290741, 46.77199423313141, 47.04222813248634, 47.09400035440922, 47.70955212414265, 45.770253986120224, 45.30736282467842, 45.17327181994915, 45.83262003958225, 44.3933142721653, 47.98485115170479, 48.00530545413494, 49.484794065356255, 48.50978158414364, 51.88544064760208, 59.7554187476635, 61.949899792671204, 61.88015453517437, 56.69225871562958, 43.32800343632698, 53.273939341306686, 54.44287821650505, 54.87877182662487, 59.2647510766983, 55.65163895487785, 51.31815008819103, 45.008185878396034, 44.124512895941734, 43.148630261421204, 43.36119085550308, 44.967436864972115, 43.49044091999531, 46.34268566966057, 43.44619609415531, 44.35935549438, 43.50212909281254, 48.62231254577637, 45.02055421471596, 45.46913154423237, 47.083493918180466, 48.02813842892647, 44.03586745262146, 42.625649124383926, 44.70411479473114, 45.172340869903564, 42.435545325279236, 45.8618176728487, 43.80493864417076, 44.7015917301178, 45.17763018608093, 46.74208223819733, 43.19278009235859, 42.20656581223011, 46.772161424160004, 47.05823667347431, 43.95757645368576, 45.435529947280884, 48.559110537171364, 54.45954032242298, 56.725544929504395, 59.9296697974205, 59.212967455387115, 60.36714792251587, 57.002645060420036, 60.33419229090214, 61.078800335526466, 60.9248173981905, 61.83493696153164, 66.22254252433777, 63.32937777042389, 60.61752028763294, 54.24971178174019, 54.383874982595444, 60.206222757697105, 68.17037120461464, 65.90505436062813, 68.46346467733383, 55.06921000778675, 9.057858008891344, 0.2426374942297116, 13.362322133034468, 59.593422040343285, 64.77817162871361, 70.90095028281212, 73.71027633547783, 42.40131676197052, 43.387493044137955, 43.00341345369816, 58.8249284774065, 25.242862477898598, 0.8188640756998211, 0.25908874114975333, 0.2596013870788738, 0.24207619309891015, 0.19756995316129178, 0.11689756560372189, 0.19724250276340172, 0.11951467517064884, 0.17763977026334032, 0.1288090951857157, 0.18429999647196382, 0.0899044300604146, 0.17956895346287638, 0.14512886322336271, 0.11348757514497265, 0.15841183718293905], [0.059349345610826276, 0.03194033277395647, 0.006600130800507031, 0.0899737021245528, 0.07700346177443862, 0.05238893179921433, 0.0917217048117891, 0.10684729044442065, 0.06240120899747126, 0.012564254029712174, 0.085523947927868, 0.05042993652750738, 0.04985574429156259, 0.05132602418598253, 0.08341230772202834, 0.03548643311660271, 0.05323586330632679, 0.12740797974402085, 0.06484096011263318, 0.11877465745783411, 0.7692770927678794, 39.21048358082771, 45.35619780421257, 45.98524644970894, 26.925759874284267, 27.778276428580284, 58.291562497615814, 58.93279328942299, 56.96512207388878, 51.37711152434349, 11.359408758580685, 0.11047422551200725, 2.7779506612569094, 65.82714334130287, 66.03823721408844, 63.17825607955456, 59.961052313447, 54.308319836854935, 48.19786012172699, 48.981138691306114, 46.55647359788418, 47.901780009269714, 49.32717852294445, 45.82831107079983, 45.56596174836159, 45.36615327000618, 43.677987456321716, 44.159148037433624, 47.62406051158905, 45.98274998366833, 46.60495899617672, 45.28058186173439, 45.87076619267464, 43.98162916302681, 44.00884710252285, 45.65222091972828, 45.7553131878376, 44.757258743047714, 43.818568512797356, 44.73922111093998, 47.03267924487591, 46.37972228229046, 44.94317516684532, 43.21142949163914, 45.391710698604584, 45.060923248529434, 44.00323860347271, 44.41795974969864, 44.24075245857239, 43.68293099105358, 41.355730667710304, 41.05976074934006, 43.006213903427124, 40.89131958782673, 42.426976785063744, 40.94380997121334, 41.68477401137352, 42.25662812590599, 43.39620217680931, 41.61952771246433, 42.234824895858765, 43.636877462267876, 46.26345232129097, 43.46661999821663, 50.46131506562233, 53.655765652656555, 60.45051544904709, 56.97847455739975, 63.422620967030525, 49.13384489715099, 46.87453553080559, 63.43780495226383, 60.26987314224243, 61.209235936403275, 56.59182630479336, 50.43901406228542, 45.41480965912342, 44.07779060304165, 41.86775699257851, 41.01141594350338, 39.68076914548874, 40.14481924474239, 39.03008446097374, 39.86198142170906, 40.78300639986992, 40.72760157287121, 40.8996145427227, 39.71269503235817, 39.87802796065807, 38.74976970255375, 40.005104541778564, 41.02439984679222, 39.827125892043114, 39.94106277823448, 42.35345833003521, 38.592720329761505, 39.75686006247997, 40.42921118438244, 41.88107527792454, 41.71625532209873, 42.480333521962166, 40.063176825642586, 42.27829076349735, 39.505275562405586, 41.38045214116573, 40.323329865932465, 40.80363929271698, 41.93817861378193, 42.26251780986786, 43.59708599746227, 49.08621445298195, 49.63762566447258, 51.442707404494286, 52.247299030423164, 58.64023178815842, 55.48408694565296, 58.65618713200092, 57.559379786252975, 57.112774550914764, 50.331533029675484, 48.608469888567924, 44.55527298152447, 55.77343761920929, 59.963552579283714, 65.10254502296448, 59.99849930405617, 65.82516744732857, 32.217703610658646, 0.24194879602873698, 0.051605784174171276, 9.954446498304605, 62.36386097967625, 56.72616809606552, 58.80322024226189, 49.460304379463196, 27.070644199848175, 35.966586247086525, 27.867999114096165, 34.769737869501114, 1.5234537958167493, 0.2140860489453189, 0.12033321952912956, 0.06717684023897164, 0.06391308255842887, 0.07731560166575946, 0.07959879672853276, 0.03119142413197551, 0.03368679550476372, 0.0880226849403698, 0.07513244068832137, 0.03916641690011602, 0.011520478983584326, 0.033955835169763304, 0.05370258142647799, 0.03986071089457255, 0.04799769594683312, 0.09039093012688681, 0.025709451983857434, 0.027413866482675076, 0.08431565729551949, 0.06072031501389574, 0.042493772925809026, 0.009762734680407448, 0.056795222117216326, 0.03835627365333494, 0.030201805457181763, 0.0566919596894877, 0.0369495104678208, 0.014722159721713979, 0.03918257345503662, 0.01955728708708193, 0.02999638454639353, 0.03159674066409934, 0.04143672456848435, 0.1305084500927478, 0.19402903300942853, 1.675179535523057, 48.42788837850094, 48.920322954654694, 49.00994874536991, 38.401537388563156, 38.799167051911354, 71.37684434652328, 65.5152940750122, 63.07986415922642, 56.77062191069126, 14.608980137854815, 0.14584605989512056, 2.865823321044445, 69.79812026023865, 67.9789374768734, 67.40532025694847, 62.8737860172987, 58.35617423057556, 52.0859444886446, 50.48801623284817, 49.90073874592781, 50.81719636917114, 50.844098925590515, 47.62346774339676, 48.174206390976906, 46.574701219797134, 45.05577452480793, 46.36440150439739, 49.396308213472366, 47.42931716144085, 48.381477668881416, 47.79756300151348, 47.970803305506706, 47.935970574617386, 46.292767748236656, 45.591086000204086, 47.01154477894306, 45.43016463518143, 47.004275768995285, 46.64413869380951, 49.06487099826336, 46.53652086853981, 45.488499104976654, 46.01252518594265, 47.04697027802467, 47.754157930612564, 46.121347546577454, 45.25922700762749, 47.01744586229324, 46.21084414422512, 44.251281693577766, 45.46093538403511, 46.96663498878479, 42.750366032123566, 44.387686774134636, 44.622894152998924, 44.604354947805405, 44.75934103131294, 45.11214070022106, 44.11724008619785, 44.64726224541664, 45.17193429172039, 47.84073248505592, 46.37523092329502, 54.619523137807846, 57.20469921827316, 63.298538625240326, 60.980811193585396, 65.74308425188065, 50.689169839024544, 50.227148830890656, 62.9597944021225, 61.75175942480564, 60.040373057127, 58.10563087463379, 52.54956901073456, 48.0430868268013, 44.053243920207024, 43.58749531209469, 42.76098646223545, 41.97739250957966, 42.0280209928751, 41.79172307252884, 42.04686418175697, 41.802746281027794, 41.32019117474556, 42.875143736600876, 43.95030364394188, 41.53288096189499, 42.5896954536438, 41.14440120756626, 41.93560615181923, 42.13648237287998, 42.21257708966732, 44.14940916001797, 41.20588190853596, 41.51993125677109, 40.964085683226585, 45.143546015024185, 43.74643698334694, 42.213454842567444, 42.11864612996578, 45.10575704276562, 41.086838096380234, 42.67049051821232, 42.262977585196495, 43.64141061902046, 45.192783772945404, 44.296822249889374, 46.8348428606987, 50.41843056678772, 52.22456865012646, 53.155283108353615, 53.69702763855457, 59.198117852211, 57.10008703172207, 60.68389132618904, 59.13030669093132, 59.2332773655653, 51.78076386451721, 49.90633964538574, 46.989885941147804, 59.43019039928913, 60.69694742560387, 66.12501695752144, 61.42682746052742, 66.14536106586456, 29.64353933930397, 0.09247698108083569, 0.07666576231713407, 12.785237599164248, 68.42470675706863, 59.848312363028526, 66.55518427491188, 54.07160773873329, 36.280703991651535, 44.18198101222515, 31.806214191019535, 44.87149581313133, 2.075777077116072, 0.17405326740117744, 0.12208344123791903, 0.0533868013008032, 0.11572020026505925, 0.03136976964015048, 0.03116074003628455, 0.010110794519277988, 0.061622666398761794, 0.02682182745047612, 0.031365539398393594, 0.05238781857769936, 0.015525066100963159, 0.07658447488211095, 0.07026041188510135, 0.017101724515669048, 0.04059516249981243, 0.14448638597968966, 0.13161191978724673, 0.08034391299588606, 0.1925423479406163, 0.15157530637225136, 0.20513614872470498, 0.17350590380374342, 0.17451955878641456, 0.17328662885120139, 0.10289030746207573, 0.20005798840429634, 0.10172198890359141, 0.15209519566269591, 0.2857236791169271, 0.16686917399056256, 0.10991354036377743, 0.0886968889972195, 0.15822782908799127, 0.32257867336738855, 0.19729771855054423, 1.7341627017594874, 62.39925988018513, 60.985424146056175, 57.86901377141476, 43.265375196933746, 43.123076632618904, 75.66447347402573, 73.1656439602375, 70.4674543440342, 64.28771674633026, 17.47953325510025, 0.31858645321335644, 3.8794832909479737, 75.2575609087944, 71.48462176322937, 71.79727658629417, 66.49608984589577, 62.27865055203438, 52.28916138410568, 53.44226270914078, 52.19674274325371, 54.81444887816906, 55.724804028868675, 50.62599442899227, 51.240273267030716, 52.112626656889915, 47.929932698607445, 49.39690098166466, 53.0120649933815, 50.7648503780365, 50.94619944691658, 50.745330825448036, 50.763714239001274, 49.77670960128307, 49.13169801235199, 48.69592219591141, 50.43497867882252, 48.31117384135723, 48.04991126060486, 49.67881925404072, 52.656035497784615, 50.125557482242584, 47.645666152238846, 48.76369155943394, 50.488897785544395, 51.345181837677956, 49.80531066656113, 48.59071344137192, 49.29299175739288, 49.68503192067146, 46.48580878973007, 47.11571238934994, 51.196400821208954, 45.70271261036396, 47.96743668615818, 48.07304061949253, 47.69653782248497, 48.00890386104584, 49.4475332647562, 45.449106618762016, 46.715213879942894, 48.628297224640846, 50.00567391514778, 47.69398435950279, 57.58467122912407, 58.40096242725849, 67.90883883833885, 62.09134720265865, 68.48666623234749, 50.77151522040367, 50.829040333628654, 67.34288200736046, 65.07084712386131, 63.36731493473053, 60.56544408202171, 54.54152852296829, 48.99777039885521, 48.25016811490059, 45.1976703107357, 45.530783236026764, 43.46388414502144, 44.14850480854511, 44.10361401736736, 44.63392116129398, 45.772742852568626, 45.75653292238712, 45.97432963550091, 45.83228185772896, 43.866639733314514, 44.535856023430824, 42.70936623215675, 42.742055878043175, 43.69354002177715, 43.85168753564358, 47.8136133402586, 43.81956405937672, 44.608067348599434, 43.70682030916214, 47.9606806486845, 45.989274233579636, 45.17954148352146, 43.09981048107147, 48.778499364852905, 42.48650819063187, 45.18777184188366, 44.63328279554844, 46.497352570295334, 47.233319878578186, 45.81471540033817, 48.64173710346222, 52.812936678528786, 54.86803360283375, 56.33131988346577, 56.1493818461895, 63.03914554417133, 60.36147862672806, 64.70692545175552, 62.69306771457195, 62.93022818863392, 54.32777099311352, 50.3924285620451, 48.5678880661726, 62.39037595689297, 63.90677198767662, 72.54350334405899, 66.04744791984558, 69.23120588064194, 36.1551321297884, 1.2187629891559482, 0.22203801287105307, 14.927850477397442, 74.99178037047386, 67.69202247262001, 70.96815347671509, 60.161768943071365, 39.932224452495575, 50.629444643855095, 41.779894307255745, 61.12786330282688, 5.3929883893579245, 0.4863310942891985, 0.21970749105094, 0.17543670488521457, 0.2925162302562967, 0.2818273741286248, 0.1506454250193201, 0.16970569209661335, 0.17601875646505505, 0.1956502249231562, 0.16280690993880853, 0.14477788674412295, 0.10971542404149659, 0.2403052060981281, 0.2202654822031036, 0.13482933776685968, 0.15383323130663484], [0.03785415508900769, 0.017923434133990668, 0.0839495484251529, 0.017427206366846804, 0.05131963058374822, 0.07458387481165119, 0.006691090275126044, 0.05742163186368998, 0.008382026444451185, 0.1480358705157414, 0.11504856403917074, 0.011236856116738636, 0.02432256722386228, 0.04459727177163586, 0.03416698731598444, 0.10982135077938437, 0.01898446040286217, 0.05294701571983751, 0.10004617492086254, 0.2457011688966304, 0.6288261199370027, 6.340029621496797, 45.425042510032654, 51.27033345401287, 34.67422999441624, 20.615012906491756, 38.79845269024372, 67.21525445580482, 53.876628801226616, 55.906932055950165, 16.512967720627785, 0.15295751189114526, 0.0381884777743835, 28.922239243984222, 74.6174168586731, 59.783062264323235, 67.4772883951664, 57.22055956721306, 56.3786805421114, 47.54617229104042, 49.746577218174934, 50.4479093849659, 57.633521407842636, 57.077299654483795, 57.62965701520443, 53.63578252494335, 50.16208492219448, 45.94770826399326, 47.366715520620346, 46.429541409015656, 47.34500348567963, 45.73838509619236, 43.46415013074875, 43.24356056749821, 46.69697105884552, 43.82098898291588, 44.60832953453064, 46.356497928500175, 45.867942944169044, 43.58697474002838, 48.78193058073521, 43.46930645406246, 45.654379203915596, 45.84854118525982, 43.608356192708015, 45.16654998064041, 45.71007661521435, 45.80790996551514, 44.541285932064056, 43.16905416548252, 41.0602243244648, 40.786870792508125, 42.72255912423134, 42.04232722520828, 44.039009883999825, 42.11864612996578, 43.31383779644966, 42.936362251639366, 47.41009019315243, 44.37903843820095, 40.389583110809326, 41.29181049764156, 43.43764275312424, 46.69992350041866, 52.08852834999561, 54.422078132629395, 57.51839138567448, 57.91562967002392, 63.446099907159805, 42.967695370316505, 34.885966032743454, 61.289381235837936, 57.996474131941795, 60.034247785806656, 51.54345899820328, 47.96902120113373, 45.23887149989605, 46.426212787628174, 43.88338923454285, 44.41382937133312, 43.453514501452446, 40.57705745100975, 39.89716753363609, 40.56164547801018, 40.738480389118195, 41.701276525855064, 40.946462228894234, 40.63956789672375, 40.199042335152626, 40.93714512884617, 41.64068877696991, 43.16933915019035, 41.577589362859726, 41.77797541022301, 41.93404823541641, 38.761385679244995, 38.955878242850304, 41.06360614299774, 40.24782411754131, 42.26188324391842, 42.09656171500683, 39.92533162236214, 39.785700514912605, 40.25362640619278, 41.062621995806694, 41.07631266117096, 39.76424306631088, 40.954008623957634, 40.065456703305244, 41.59364730119705, 39.97402980923653, 39.59363602101803, 43.65346357226372, 43.70578296482563, 47.05284856259823, 49.62739281356335, 48.936950862407684, 47.30678133666515, 48.102071061730385, 43.85866396129131, 45.75055964291096, 51.76869951188564, 61.883984729647636, 59.79119762778282, 66.4792263507843, 59.810375198721886, 58.784369453787804, 2.579195676371455, 0.2430007013026625, 0.007800755975040374, 17.052846550941467, 63.125978484749794, 48.044789135456085, 62.32534624636173, 43.239950761199, 28.671165816485882, 19.97674785554409, 32.74755857884884, 16.032259315252304, 0.32734376611188054, 0.042579561486491, 0.042078956903424114, 0.04383969113405328, 0.05346548750821967, 0.016247028288489673, 0.025002940383274108, 0.06208647901075892, 0.03397689732082654, 0.03191302916093264, 0.11190892313607037, 0.022041218253434636, 0.009366838785354048, 0.04460729818674736, 0.021141976467333734, 0.0479214773804415, 0.0607691038021585, 0.10254415494273417, 0.012131831481383415, 0.043523343265405856, 0.01940558653586777, 0.05629416853480507, 0.07265328895300627, 0.059001686531701125, 0.09371358464704826, 0.046696169301867485, 0.10602670517982915, 0.08537635701941326, 0.06382100429618731, 0.05510934832273051, 0.0396939577331068, 0.014498067303065909, 0.00925144038774306, 0.07443439884809777, 0.023982218299352098, 0.05044781857577618, 0.44779828225728124, 0.5729210854042321, 10.515205208212137, 61.231514140963554, 49.55107010900974, 41.3938008248806, 27.326569966971874, 47.307803481817245, 76.47822260856628, 60.08904084563255, 65.32959043979645, 21.725841499865055, 0.2646203537005931, 0.0918679746973794, 33.196037113666534, 78.83483335375786, 63.53127233684063, 70.41407480835915, 59.38662953674793, 57.677108868956566, 50.89175596833229, 53.46150107681751, 53.574738800525665, 58.56752648949623, 60.71295216679573, 58.91801208257675, 53.47697004675865, 51.413490772247314, 48.35824951529503, 47.6900439709425, 50.047524869441986, 49.25440102815628, 47.967379689216614, 45.614348351955414, 45.65867677330971, 48.683204278349876, 44.175038784742355, 46.908327117562294, 47.58801944553852, 46.82252772152424, 45.44067867100239, 48.48015837371349, 45.82423768937588, 48.666241988539696, 47.341564670205116, 46.48110844194889, 48.25156643986702, 47.29697026312351, 47.32632748782635, 45.7615752518177, 45.963344424963, 43.494461104273796, 43.99153143167496, 45.518152713775635, 45.33082276582718, 45.540833696722984, 45.17899431288242, 46.64217419922352, 43.83890502154827, 49.34354804456234, 47.142018377780914, 44.170862808823586, 44.016328901052475, 45.912199169397354, 50.03431677818298, 55.22988058626652, 57.85246565937996, 61.08501300215721, 61.28863267600536, 64.79204848408699, 48.01196649670601, 38.06596599519253, 63.78754198551178, 61.12460307776928, 60.90425290167332, 53.05920526385307, 50.44592969119549, 47.52828285098076, 47.31694959104061, 44.85125809907913, 47.03750878572464, 43.54065142571926, 42.296582981944084, 41.840995028615, 41.63512967526913, 42.05327443778515, 43.254636973142624, 42.90806896984577, 43.49579483270645, 42.33099393546581, 42.61844091117382, 42.74575687944889, 43.802233189344406, 43.18768836557865, 42.64751315116882, 43.82801480591297, 42.53506198525429, 42.057036235928535, 42.329341024160385, 43.389902114868164, 44.13998946547508, 42.62433059513569, 40.74044108390808, 41.73101752996445, 42.161181047558784, 44.06092330813408, 43.76534476876259, 42.239627838134766, 43.198624178767204, 43.34880352020264, 42.59194493293762, 42.40721024572849, 41.20089277625084, 46.69588811695576, 47.18370594084263, 50.28839014470577, 51.931004002690315, 51.18131943047047, 51.47353135049343, 49.14801813662052, 46.561341136693954, 48.907358050346375, 55.3476020693779, 64.75146666169167, 63.55828508734703, 66.48261576890945, 60.81272341310978, 58.48917469382286, 2.6822995813563466, 0.48046034993603826, 0.04455885078641586, 20.182787999510765, 69.48969081044197, 53.198030814528465, 68.2245334982872, 47.34855629503727, 39.13924120366573, 23.466005623340607, 41.37137822806835, 22.18034651130438, 0.44732140784617513, 0.05033968023781199, 0.15955600625602528, 0.03990930301370099, 0.07261624094098806, 0.03649622893135529, 0.08767739331233315, 0.012174541152489837, 0.034013667027466, 0.027795092901214957, 0.06393465679138899, 0.025005829193105455, 0.03848626081889961, 0.05560142933973111, 0.0578193376713898, 0.02439997137116734, 0.06260054986341856, 0.17207821947522461, 0.12355914994259365, 0.15790359961101785, 0.09941086682374589, 0.12583332048961893, 0.2820264478214085, 0.15870483708567917, 0.27694751566741616, 0.14747983863344416, 0.23719165910733864, 0.31873298285063356, 0.10770146531285718, 0.2501219051191583, 0.22165984410094097, 0.12775428069289774, 0.1545748594799079, 0.09173183512757532, 0.18718629784416407, 0.19286487047793344, 0.8532215352170169, 0.8345026709139347, 13.58776118606329, 75.8073154091835, 61.10702522099018, 49.240280985832214, 32.58003696799278, 56.31258688867092, 80.4910808801651, 66.87188968062401, 72.5214721262455, 28.6199863627553, 0.45708789315540344, 0.2909990132320672, 37.300550267100334, 82.23742917180061, 69.18100297451019, 74.42700907588005, 63.99186462163925, 62.24563792347908, 52.96663083136082, 55.04641883075237, 55.645046308636665, 63.17061848938465, 63.973344415426254, 63.567112013697624, 58.75467784702778, 55.63094146549702, 52.00818546116352, 52.46272847056389, 53.5998098552227, 51.826737597584724, 51.498188227415085, 46.66020803153515, 47.35972389578819, 51.38664521276951, 46.71054773032665, 49.90471713244915, 50.31270124018192, 49.78843957185745, 48.439530953764915, 54.4246581941843, 47.60156571865082, 51.17772862315178, 49.67213921248913, 48.163555562496185, 50.80106243491173, 49.90404076874256, 49.49179328978062, 48.452385663986206, 49.40223589539528, 47.29980871081352, 48.26984725892544, 48.425536304712296, 46.38592354953289, 49.883008897304535, 47.04894237220287, 48.574229925870895, 46.177489534020424, 54.207819029688835, 49.15124796330929, 46.42465107142925, 47.28033095598221, 50.26116080582142, 51.04408599436283, 59.794374257326126, 60.50239406526089, 63.84407535195351, 63.1117482483387, 67.93627336621284, 45.76589561998844, 36.24768376350403, 66.23938322067261, 62.17839293181896, 65.64481392502785, 54.479626044631004, 53.262095376849174, 48.86290803551674, 50.00488355755806, 45.54224342107773, 48.00052911043167, 45.139343440532684, 44.301420003175735, 43.01483944058418, 44.37855586409569, 44.400689676404, 47.355996295809746, 47.01510898768902, 46.27841591835022, 45.66656515002251, 45.29181405901909, 45.1278642565012, 45.863090604543686, 46.21834874153137, 43.996262177824974, 46.44208453595638, 44.48752261698246, 44.405127838253975, 44.782375395298004, 45.6521525233984, 45.707063376903534, 46.199554949998856, 42.940203845500946, 42.40864656865597, 44.07602749764919, 45.604218095541, 47.02502265572548, 43.02234783768654, 45.74881173670292, 45.60637257993221, 45.693137124180794, 43.30765172839165, 43.25260788202286, 48.93128536641598, 48.81773225963116, 52.86957263946533, 57.95261688530445, 51.89221948385239, 54.48627948760986, 52.94253632426262, 47.02356733381748, 50.67976914346218, 56.72883175313473, 65.88389709591866, 64.5637871325016, 70.5394072830677, 63.084929287433624, 64.45260509848595, 4.681143136695027, 0.6091367639601231, 0.15860816492931917, 21.81934878230095, 76.50640189647675, 59.16045807301998, 72.66101583838463, 55.47686353325844, 42.53355346620083, 33.45305532217026, 53.515853360295296, 33.9326997846365, 0.522637611720711, 0.1729592971969396, 0.3222158522112295, 0.1360954120173119, 0.16553278866922483, 0.10687581117963418, 0.1812587643507868, 0.20581337332259864, 0.050882513023680076, 0.11006619271938689, 0.22357498586643487, 0.12420364582794718, 0.16222131089307368, 0.1458952049142681, 0.18294091627467424, 0.09010995301650837, 0.18319407769013196], [0.041163354471791536, 0.03281138408055995, 0.11536137186340056, 0.05130236822878942, 0.0070483508898178115, 0.08572489925427362, 0.008485048601869494, 0.039304189194808714, 0.05265748535748571, 0.013887883687857538, 0.014437215832003858, 0.026432559861859772, 0.08630157768493518, 0.0352185066731181, 0.005389693506003823, 0.04846348267165013, 0.06823357689427212, 0.03717368730576709, 0.018414860205666628, 0.03783326734264847, 0.0952606434293557, 0.13445728429360315, 19.322664253413677, 39.05828654766083, 39.324697852134705, 28.015987873077393, 32.67231121659279, 62.70949803292751, 48.15942898392677, 61.1312223225832, 32.9135412722826, 0.5606922134757042, 0.1580025427392684, 2.874728380702436, 61.97243258357048, 67.72413074970245, 63.43096911907196, 63.12261186540127, 58.910845667123795, 51.88278079032898, 56.64157323539257, 59.450302720069885, 63.946753442287445, 64.64392483234406, 63.733402490615845, 60.9331351518631, 61.003321185708046, 58.13216105103493, 56.314802169799805, 53.10530439019203, 50.62558405101299, 50.16812279820442, 50.14866404235363, 45.969344303011894, 47.10066519677639, 47.2043464332819, 45.436088517308235, 44.93048384785652, 44.75119426846504, 46.33724436163902, 48.16101349890232, 44.73301984369755, 45.28639554977417, 45.00269137322903, 46.82793863117695, 46.1434243619442, 45.08493036031723, 44.30154159665108, 45.00085987150669, 45.08111536502838, 42.159140557050705, 43.41302767395973, 41.993047669529915, 41.816262155771255, 40.83690270781517, 42.71201469004154, 42.52340041100979, 45.89229203760624, 44.45066459476948, 45.327972918748856, 42.45107889175415, 45.95634140074253, 47.142618745565414, 52.590941190719604, 58.058695793151855, 58.75761888921261, 58.810481652617455, 58.00914645195007, 65.20621106028557, 43.78955326974392, 18.049390576779842, 52.07798391580582, 61.95004418492317, 58.14725764095783, 54.200907200574875, 51.12323954701424, 50.01249834895134, 48.25913943350315, 46.60026244819164, 45.278906151652336, 43.22233110666275, 44.46187399327755, 42.105707824230194, 41.85672618448734, 41.41767494380474, 42.317626252770424, 41.3425187766552, 40.39146400988102, 39.45190742611885, 42.42758475244045, 42.09676690399647, 43.34502272307873, 41.33656069636345, 43.315486907958984, 40.35942032933235, 39.82009246945381, 39.80682358145714, 43.80550101399422, 41.543254405260086, 43.10409665107727, 41.903171092271805, 40.98095677793026, 39.602447748184204, 41.702477261424065, 39.89638477563858, 40.710225105285645, 40.11016130447388, 42.68242947757244, 39.77636441588402, 42.02801339328289, 38.81342388689518, 40.64881280064583, 42.03922279179096, 41.36964172124863, 39.42606121301651, 40.91900110244751, 41.78098484873772, 46.869971975684166, 43.20990577340126, 48.31460505723953, 46.77773952484131, 60.00686265528202, 58.900685012340546, 69.50337007641792, 59.36698459088802, 65.87719425559044, 16.774148605763912, 0.7101954880636185, 0.6076739612035453, 0.12484204868087545, 29.77807492017746, 62.66745708882809, 51.44013114273548, 56.82984933257103, 32.05046318471432, 20.958379581570625, 29.498723410069942, 31.19937915354967, 2.3095552576705813, 0.09327320905867964, 0.2937486703740433, 0.05194772871618625, 0.06836262895376422, 0.040403595630778, 0.11889425455592573, 0.06314064783509821, 0.012214637536089867, 0.009570036963850725, 0.01612076670426177, 0.014255712485464755, 0.03257753334764857, 0.0246090380824171, 0.05258785706246272, 0.09729791301651858, 0.05362601405067835, 0.01583167235367, 0.037693751000915654, 0.047779456290300004, 0.0600029402266955, 0.019290952550363727, 0.06774596360628493, 0.0802615494467318, 0.036312807133072056, 0.014499778881145176, 0.03569634587620385, 0.06259963702177629, 0.03857838732074015, 0.05096728113130666, 0.08392638599616475, 0.03732295175723266, 0.020563166217471007, 0.023313077545026317, 0.08619720203569159, 0.0312815913639497, 0.03647789046226535, 0.03613692184444517, 0.21493430889677256, 0.20015792601043358, 27.851300910115242, 46.81185029447079, 39.69460420310497, 39.54120643436909, 37.526216357946396, 75.38616120815277, 57.84141205251217, 67.05152124166489, 37.685773596167564, 0.40826178970746696, 0.33091599005274475, 3.685477338731289, 68.07029217481613, 70.51194235682487, 67.30135783553123, 67.29510337114334, 62.0214119553566, 55.88699072599411, 58.818396627902985, 62.33323462307453, 68.98708418011665, 66.37680664658546, 66.20419710874557, 64.07893314957619, 63.795187175273895, 59.723466262221336, 58.17003361880779, 54.370834082365036, 52.15043842792511, 53.29896479845047, 52.135341838002205, 48.485014513134956, 48.01133573055267, 48.83001700043678, 48.305808529257774, 46.82866059243679, 46.208214685320854, 47.4998489767313, 49.70997758209705, 47.46802568435669, 48.19804251194, 47.02233999967575, 47.81808950006962, 47.01022244989872, 48.924696519970894, 45.557700991630554, 47.526831328868866, 46.00704587996006, 46.22112639248371, 46.3518051803112, 44.694524109363556, 44.29211050271988, 44.46202598512173, 45.664874240756035, 45.77002599835396, 46.93442791700363, 45.96431337296963, 45.86919687688351, 45.3490199893713, 46.36132746934891, 47.82865293323994, 54.77097921073437, 60.742206797003746, 61.86627008020878, 61.71640232205391, 62.06648513674736, 67.68196821212769, 49.76782947778702, 21.293111220002174, 54.59908403456211, 62.65968270599842, 59.07829508185387, 56.27119570970535, 51.714609414339066, 51.85273200273514, 47.95892894268036, 47.14158520102501, 47.01694808900356, 45.24272069334984, 44.0728584676981, 42.91239693760872, 44.488727152347565, 43.07836443185806, 44.44178067147732, 43.227301239967346, 43.49599242210388, 42.36657902598381, 44.174248427152634, 42.850095480680466, 45.6320858001709, 43.202397376298904, 44.59795609116554, 42.12424322962761, 42.874277383089066, 42.14706100523472, 45.64071133732796, 43.932866379618645, 43.983631655573845, 42.99087032675743, 44.86317805945873, 42.16670975089073, 43.76057982444763, 43.861589804291725, 43.762624114751816, 43.256308883428574, 45.88501162827015, 43.57937894761562, 44.63806673884392, 41.144473403692245, 43.12928929924965, 42.756624296307564, 42.86534026265144, 42.762935757637024, 43.03778260946274, 44.64392602443695, 47.382492274045944, 44.81706753373146, 50.13721905648708, 50.73093719780445, 61.661920845508575, 61.09085328876972, 70.25085836648941, 59.820391461253166, 68.11801001429558, 16.781639903783798, 0.9083305718377233, 0.7651802594773471, 0.48643891350366175, 32.95811288058758, 69.20912146568298, 57.784133926033974, 61.592821553349495, 40.29227793216705, 31.0547399148345, 29.833914823830128, 42.30197109282017, 3.4203553525730968, 0.33616917848121375, 0.04196957546810154, 0.04206847406749148, 0.04973557202902157, 0.08477297611534595, 0.05606129372608848, 0.05476009362610057, 0.045339322969084606, 0.022485286026494578, 0.07203923596534878, 0.035432363947620615, 0.0023831164344301214, 0.030553295873687603, 0.01575805501488503, 0.01908979713334702, 0.04766562567965593, 0.0423564051016001, 0.15523045789450407, 0.15665978979086503, 0.14516880561131984, 0.14285161276347935, 0.19209420948754996, 0.25492924090940505, 0.14551209344062954, 0.1377175241941586, 0.13248498231405392, 0.09562704915879294, 0.09529352799290791, 0.15643766499124467, 0.21566780313150957, 0.1563664633431472, 0.15007128473371267, 0.04668599445722066, 0.1720951998140663, 0.15635834424756467, 0.10364023284637369, 0.14188827539328486, 0.3041696111904457, 0.3551603219239041, 41.24191537499428, 60.017361491918564, 53.02400775253773, 45.02954453229904, 44.63396675884724, 82.50650033354759, 60.71081668138504, 78.0285394191742, 46.152201890945435, 1.4274395979009569, 0.608410231070593, 5.219224663451314, 73.35557296872139, 76.53784140944481, 72.18874678015709, 69.09994572401047, 65.94819724559784, 56.51842564344406, 63.261243626475334, 65.93989089131355, 71.95574328303337, 69.97014462947845, 68.82533445954323, 67.34602823853493, 69.02882874011993, 63.781690299510956, 64.29118975996971, 58.580107614398, 56.196867898106575, 55.76783671975136, 55.47632776200771, 51.64402440190315, 51.81203618645668, 52.64677159488201, 50.4427644610405, 49.67432789504528, 49.05441775918007, 51.00700758397579, 53.070053681731224, 49.28415723145008, 50.387367233633995, 50.1301134377718, 51.745410561561584, 50.795298144221306, 50.875568836927414, 48.34235116839409, 48.65836501121521, 49.43358041346073, 50.364625453948975, 50.16437999904156, 47.215989008545876, 46.76747627556324, 46.1376790702343, 48.93165774643421, 46.99647478759289, 49.20408792793751, 46.67638756334782, 48.92703339457512, 46.741462871432304, 49.865138456225395, 51.16084612905979, 57.74626135826111, 63.95559936761856, 65.15687450766563, 64.23091739416122, 64.26671907305717, 72.58422955870628, 46.578903794288635, 16.7822402715683, 57.84449368715286, 65.47804087400436, 62.78746224939823, 60.22918112576008, 55.56761406362057, 54.1555680334568, 51.975321024656296, 50.99533461034298, 49.664984196424484, 45.922318026423454, 47.555136010050774, 45.60425229370594, 48.22146065533161, 45.48259802162647, 46.2315758317709, 45.91175839304924, 45.34443363547325, 44.118501618504524, 47.36697010695934, 45.34334309399128, 48.28551761806011, 45.56067243218422, 47.368163242936134, 44.89052899181843, 45.915793776512146, 43.46078731119633, 49.17233683168888, 46.813708394765854, 47.03445374965668, 44.852382838726044, 45.80015078186989, 45.0553223490715, 46.45577900111675, 43.74276638031006, 47.342849001288414, 47.262722700834274, 48.75650994479656, 44.65208798646927, 46.093221455812454, 44.045218750834465, 45.905838310718536, 45.92196844518185, 46.66267789900303, 43.815490677952766, 45.93366041779518, 48.606797978281975, 53.02795194089413, 47.07053281366825, 52.81064920127392, 51.1057148873806, 65.55864214897156, 63.51005807518959, 73.73337149620056, 61.13251805305481, 69.4458943605423, 19.452818669378757, 0.7144713867455721, 0.8264791045803577, 0.9499361424241215, 36.72403760254383, 76.63628652691841, 61.625784784555435, 69.02655646204948, 42.25992634892464, 37.356623858213425, 43.70499640703201, 57.362493351101875, 8.311331067234278, 0.41673747240565717, 0.40635678567923605, 0.25430640089325607, 0.15712045569671318, 0.20994020422222093, 0.24843650258844718, 0.2012774854665622, 0.11266019180766307, 0.14522013254463673, 0.11706177319865674, 0.11356501083355397, 0.0859254646638874, 0.1110449964471627, 0.12024267751257867, 0.16151533549418673, 0.0833174167200923, 0.13495326158590615], [0.04366406559711322, 0.09621989898732863, 0.04662860788812395, 0.07627470244187862, 0.0670405151322484, 0.040451375098200515, 0.07464844908099622, 0.0839309798902832, 0.06224416312761605, 0.015712583626736887, 0.06100482103647664, 0.05822455772431567, 0.0355184159707278, 0.03186806985468138, 0.04002333771495614, 0.03416791500058025, 0.062170289747882634, 0.03284169710241258, 0.03396056636120193, 0.094078068214003, 0.09002001213957556, 0.10163500919588841, 2.0285966712981462, 48.35211664438248, 35.14250546693802, 30.69219756871462, 29.033656865358353, 43.51963855326176, 63.0348289757967, 51.604529321193695, 59.248905926942825, 3.0074877943843603, 0.050465366657590494, 0.08153335307724774, 17.34244231134653, 78.30304428935051, 61.45171232521534, 66.67583540081978, 60.46948783099651, 62.802642434835434, 61.426120698451996, 65.38574382662773, 67.02612340450287, 68.01381960511208, 65.05872577428818, 62.626347094774246, 63.56650024652481, 61.7440914362669, 61.3855616748333, 60.95584273338318, 61.145969331264496, 57.563453167676926, 52.73102067410946, 50.617680475115776, 48.07616405189037, 46.754180788993835, 44.69498388469219, 46.46229185163975, 46.144784688949585, 44.67530854046345, 44.19225566089153, 44.53522905707359, 44.77215014398098, 44.74753886461258, 44.54700082540512, 41.64656326174736, 46.784115582704544, 45.62870018184185, 44.914862886071205, 44.05254475772381, 43.03888075053692, 40.97800433635712, 42.99393676221371, 43.52786511182785, 43.41027282178402, 43.41850697994232, 44.591002464294434, 45.02758003771305, 44.89231489598751, 43.749640211462975, 45.72376728057861, 47.828599736094475, 51.03065751492977, 53.83573159575462, 59.07231040298939, 59.801901653409004, 62.59227432310581, 60.67769765853882, 64.36349228024483, 54.418597519397736, 10.497815441340208, 33.91278125345707, 65.02839580178261, 57.946009039878845, 61.01270288228989, 54.72469389438629, 56.85631491243839, 54.91310678422451, 56.08666241168976, 52.55730539560318, 43.85363683104515, 44.890244007110596, 44.50733855366707, 41.13662302494049, 40.10602332651615, 39.55157607793808, 44.07995268702507, 40.109541937708855, 40.32812140882015, 40.38903973996639, 41.70469634234905, 41.59401588141918, 44.33190956711769, 43.378301337361336, 40.09683541953564, 40.89641511440277, 39.822813123464584, 41.06252320110798, 42.09060363471508, 42.505028396844864, 42.12758705019951, 40.653311759233475, 41.07543110847473, 41.567117124795914, 42.95186161994934, 39.962151646614075, 40.88063456118107, 41.50285117328167, 42.11461454629898, 40.84666058421135, 40.45897498726845, 39.85141418874264, 41.26904971897602, 39.13905881345272, 39.79551538825035, 41.00116029381752, 42.44203917682171, 42.08879113197327, 47.30103224515915, 44.936274737119675, 53.46795693039894, 60.421640798449516, 61.06834329664707, 65.003522336483, 66.79568096995354, 51.21342770755291, 0.02760378392849816, 0.057105410160147585, 0.16581582895014435, 0.1794016288476996, 41.53441607952118, 51.72740712761879, 49.1501422226429, 46.90559506416321, 17.537565641105175, 28.635789714753628, 30.580158680677414, 25.88624395430088, 0.27284317184239626, 0.08299357315991074, 0.02134741036570631, 0.02870007519959472, 0.05833770555909723, 0.032005177927203476, 0.03235630283597857, 0.07187622322817333, 0.04611926822690293, 0.07322054210817441, 0.048811724336701445, 0.04441544188011903, 0.0844264673651196, 0.05060864939878229, 0.07195988553576171, 0.061735521085211076, 0.01553366388179711, 0.030662742246931884, 0.03416727304283995, 0.09621378369047306, 0.03316286893095821, 0.07026764782494865, 0.07169533215346746, 0.017374372873746324, 0.019467379606794566, 0.03822880607913248, 0.10925969341769814, 0.04616167083440814, 0.04646136861993, 0.06181540586112533, 0.03568552165233996, 0.03663228686491493, 0.06078666672692634, 0.05160261891433038, 0.016714217672415543, 0.02920902337791631, 0.03717719766427763, 0.08639339619548991, 0.04605004811310209, 0.2113271743291989, 3.9626273419708014, 60.51436722278595, 39.96279001235962, 37.111597806215286, 36.49904027581215, 50.35571873188019, 68.13009336590767, 59.61549885571003, 67.56634041666985, 3.508769958280027, 0.12608268210897222, 0.09236905796569772, 20.838936790823936, 83.9812695980072, 65.9353919327259, 71.5337835252285, 63.96617040038109, 66.47387623786926, 62.9499377310276, 67.70198553800583, 67.759590446949, 71.40514522790909, 67.18283459544182, 65.56618854403496, 66.9962266087532, 65.7451893389225, 64.53584343194962, 62.54238300025463, 63.00515256822109, 58.94010029733181, 54.82663482427597, 53.28852295875549, 50.41521213948727, 48.946169167757034, 46.866745948791504, 48.273377269506454, 48.555527329444885, 45.916359946131706, 46.871556490659714, 47.665979862213135, 46.99959821999073, 48.36537793278694, 46.903911754488945, 44.07368302345276, 48.247462660074234, 48.415725231170654, 47.58084163069725, 46.82282790541649, 46.796704307198524, 45.55851794779301, 45.920372530817986, 45.66615477204323, 46.38160318136215, 45.2355694770813, 47.33313672244549, 47.40815229713917, 45.96658185124397, 47.28926047682762, 48.771621733903885, 48.978592827916145, 52.70168624818325, 56.68611064553261, 62.15872518718243, 64.37748312950134, 64.08217057585716, 61.908869594335556, 65.00751212239265, 60.39995156228542, 14.234292693436146, 37.58459262549877, 67.26225793361664, 59.85142059624195, 62.88713090121746, 55.83700820803642, 57.63310343027115, 55.00950761139393, 57.13612049818039, 51.122373193502426, 45.47701612114906, 46.52945704758167, 45.84681987762451, 42.440253272652626, 43.17054368555546, 44.13834035396576, 46.90476290881634, 44.18929561972618, 43.48303511738777, 43.326703906059265, 43.09146232903004, 42.75556035339832, 45.43508157134056, 45.08097857236862, 43.01603637635708, 43.317512199282646, 43.62949065864086, 44.27769787609577, 43.695572912693024, 45.484418123960495, 43.922850117087364, 42.831263691186905, 43.378001153469086, 44.31837849318981, 46.28581412136555, 43.554254695773125, 42.39402875304222, 43.16859059035778, 44.35954928398132, 43.46070371568203, 43.00789341330528, 42.89142206311226, 44.39589813351631, 41.307591050863266, 41.82232663035393, 43.228019401431084, 45.18624432384968, 44.327368810772896, 49.6172359585762, 45.66296674311161, 54.7955296933651, 61.48024119436741, 63.66479717195034, 66.3361944258213, 66.15120515227318, 52.26721756160259, 0.27762506681028754, 0.6776317697949708, 1.3454060372896492, 0.19103535771137103, 46.71773314476013, 56.9990998506546, 56.6370552778244, 54.63710859417915, 27.84218329936266, 30.42614534497261, 36.28202252089977, 34.704996943473816, 0.4774800332961604, 0.11652692963252775, 0.0699794793035835, 0.05388874917116482, 0.06567163858562708, 0.014057251992198871, 0.046820475326967426, 0.0571989801392192, 0.025307901851192582, 0.032013438030844554, 0.016147125934367068, 0.0241023497437709, 0.04412441609019879, 0.03425430099014193, 0.0816143436532002, 0.03759396182431374, 0.04555463485303335, 0.04027959759696387, 0.12674032885115594, 0.20972858823370188, 0.1672988329664804, 0.1472887207637541, 0.14951710822060704, 0.09327191030024551, 0.23580120090628043, 0.1345654300530441, 0.23429551685694605, 0.11036798707209527, 0.14819798525422812, 0.12247815990122035, 0.21448394400067627, 0.23590765456901863, 0.1315405548666604, 0.2625673357397318, 0.135340558772441, 0.13373505586059764, 0.09696272201836109, 0.27142094972077757, 0.374144043889828, 0.5274855578318238, 6.009526681154966, 75.51817372441292, 50.90824708342552, 47.588331028819084, 44.20400843024254, 56.43912769854069, 78.21469902992249, 62.49311864376068, 76.0223838686943, 4.468673737719655, 0.378282674937509, 0.16082619200460613, 25.29969222843647, 88.82005915045738, 70.28425097465515, 75.15681311488152, 65.9928372502327, 69.50606033205986, 67.11296394467354, 70.94993725419044, 71.6167938709259, 72.53718808293343, 70.38864657282829, 68.82965862751007, 71.88111528754234, 69.85882580280304, 67.63308763504028, 67.29423701763153, 67.33010709285736, 61.72066569328308, 57.7892142534256, 58.056355118751526, 53.20095665752888, 52.88917578756809, 47.916872799396515, 50.77324792742729, 51.16906888782978, 51.20723024010658, 48.829477429389954, 50.329929515719414, 47.75070011615753, 49.68093194067478, 51.12228199839592, 45.67211665213108, 48.42726521193981, 50.45177757740021, 47.80490800738335, 49.497853964567184, 50.4858161509037, 48.557431027293205, 49.548421651124954, 50.054410099983215, 49.67997819185257, 48.018676936626434, 48.33508215844631, 48.89735318720341, 48.47625598311424, 49.21193070709705, 53.78618985414505, 54.119116589426994, 57.82397098839283, 59.098103418946266, 66.47968232631683, 66.6289459168911, 66.12068518996239, 65.62544256448746, 65.77840715646744, 58.19585703313351, 8.134142775088549, 36.27457872033119, 71.02660953998566, 61.004795506596565, 68.77991169691086, 58.844584822654724, 59.705569222569466, 56.889494732022285, 60.12400656938553, 56.373353227972984, 46.50242529809475, 48.33033621311188, 47.394636422395706, 44.614671394228935, 45.02192594110966, 45.88864803314209, 49.24555890262127, 46.70159921050072, 45.39804495871067, 44.29321624338627, 45.09659193456173, 44.532212018966675, 47.02966220676899, 47.94999562203884, 43.66766341030598, 46.64091266691685, 46.45116224884987, 45.33051498234272, 45.10802932083607, 46.82955354452133, 48.21996733546257, 44.69170466065407, 44.97609660029411, 45.93372501432896, 48.472004011273384, 44.90847922861576, 46.50197692215443, 45.30510954558849, 47.421664372086525, 45.59628412127495, 44.83866937458515, 45.28473883867264, 46.479402333498, 44.044781774282455, 45.383651331067085, 45.39929509162903, 47.7020513266325, 48.12078505754471, 52.97942474484444, 47.46342793107033, 57.68034249544144, 65.5952037870884, 63.23588378727436, 69.51901763677597, 66.81625306606293, 58.22417311370373, 0.9099957137368619, 0.4331639315932989, 0.4974364140070975, 1.154975218232721, 50.57024762034416, 61.01840637624264, 61.29495933651924, 58.08690927922726, 28.067579604685307, 41.96796901524067, 48.10552127659321, 48.08792442083359, 0.6705303664784878, 0.2264766942244023, 0.21023807261371985, 0.2115579228848219, 0.1610594490193762, 0.17038532125297934, 0.09826047855312936, 0.19595909194322303, 0.08032327386899851, 0.15692859567934647, 0.16890976839931682, 0.07628621315234341, 0.17760085203917697, 0.24188587674871087, 0.22935693967156112, 0.24775179714197293, 0.17351429007248953, 0.09821813902817667], [0.07696700005908497, 0.05995780280500185, 0.07341958611505106, 0.061746237697661854, 0.03752296426682733, 0.03431152428674977, 0.01882189666503109, 0.08020757304620929, 0.06211416854057461, 0.06719066645018756, 0.06823883129982278, 0.02350352006033063, 0.05021902557928115, 0.018182323074142914, 0.07349961932050064, 0.029646506445715204, 0.07712743754382245, 0.07846248699934222, 0.0700108201999683, 0.06793343010940589, 0.018509402398194652, 0.1721132340026088, 0.11817671649623662, 24.17112808674574, 42.794683054089546, 41.19760975241661, 51.706770434975624, 31.27776514738798, 74.80951935052872, 54.14822682738304, 62.016931995749474, 19.550330936908722, 0.2893134474288672, 0.372828483232297, 0.3005518490681425, 46.81682422757149, 73.71224462985992, 62.43115156888962, 64.15021732449532, 63.12630146741867, 65.52100896835327, 64.5301665365696, 72.73409351706505, 66.14148527383804, 69.09004345536232, 67.36429005861282, 65.73084890842438, 64.72648680210114, 63.04836764931679, 61.89066857099533, 62.024136409163475, 61.35249964892864, 54.6876534819603, 52.849388122558594, 45.388290882110596, 46.50491036474705, 46.24694600701332, 46.24069154262543, 47.742359563708305, 46.33968003094196, 46.68806053698063, 45.13015553355217, 42.92960621416569, 46.00963354110718, 45.07265321910381, 46.07738770544529, 44.35837894678116, 46.73111982643604, 47.138142585754395, 44.8554340749979, 43.46919246017933, 43.085063472390175, 41.907468661665916, 45.78349247574806, 43.74020531773567, 45.51645800471306, 42.33393117785454, 45.27796000242233, 44.115347787737846, 45.74463576078415, 44.650317281484604, 48.494240418076515, 46.52841590344906, 56.576509326696396, 57.69632823765278, 58.041338324546814, 59.31561894714832, 63.79800662398338, 57.9192166775465, 64.38127532601357, 18.893351890146732, 23.65168645977974, 68.73710319399834, 56.55965343117714, 63.4573283046484, 56.04274436831474, 59.59127515554428, 59.890011325478554, 60.805173218250275, 60.77676594257355, 52.392614632844925, 43.51683050394058, 45.67771755158901, 44.00462552905083, 41.00244462490082, 40.58432646095753, 42.11798496544361, 40.373555570840836, 42.69968435168266, 40.95648609101772, 42.76877984404564, 41.54514290392399, 44.83442880213261, 42.92494386434555, 41.34120784699917, 43.01998816430569, 39.78212110698223, 40.9272276610136, 43.95896717905998, 43.837837278842926, 42.58773475885391, 39.68275643885136, 42.43703484535217, 39.07908283174038, 41.23713903129101, 41.76409475505352, 42.951299250125885, 41.174605786800385, 43.67275893688202, 40.773689299821854, 42.169833183288574, 38.59450623393059, 41.03429451584816, 39.685534089803696, 43.90465289354324, 38.13263341784477, 44.31449890136719, 43.79128597676754, 46.22331127524376, 42.36341379582882, 55.90247489511967, 57.369849756360054, 65.27880236506462, 57.20497280359268, 73.72965529561043, 11.68286070227623, 1.077567315660417, 0.5229159467853606, 0.8806266740430146, 1.1608581338077784, 44.47342537343502, 48.4480918943882, 57.03029617667198, 26.301742158830166, 22.394670210778713, 30.714183188974857, 42.098317220807076, 10.184871833771467, 0.34435456269420683, 0.15530128846876323, 0.013994213040859904, 0.10973733966238797, 0.037749972398160025, 0.06695300849969499, 0.034111619388568215, 0.06164496051496826, 0.0328565215022536, 0.04066235283971764, 0.04427769184985664, 0.01917405130370753, 0.09406888042576611, 0.07082702679326758, 0.034544035443104804, 0.05669359983585309, 0.10425600019516423, 0.038211447244975716, 0.10895181345404126, 0.013553904245782178, 0.023854296159697697, 0.10649324147379957, 0.01631525949051138, 0.01838136337028118, 0.0828856648877263, 0.028084740151825827, 0.04870529293839354, 0.06673751850030385, 0.018964301816595253, 0.02882893430069089, 0.04823668234166689, 0.04442039942659903, 0.04786541925568599, 0.0029320821431610966, 0.055911198069225065, 0.07835840820916928, 0.06304822818492539, 0.07017533949692734, 0.042198947339784354, 0.3150725323939696, 0.3398838057182729, 31.764589324593544, 49.74115490913391, 45.28383448719978, 66.96841210126877, 40.21297238767147, 79.35019969940186, 58.6609672755003, 70.43194144964218, 24.673337638378143, 0.4376453161239624, 0.3666735260048881, 0.31735226162709296, 51.570399552583694, 76.96892067790031, 66.38405665755272, 67.67107039690018, 65.2594918012619, 67.72989124059677, 68.16388115286827, 74.57359001040459, 67.32185393571854, 72.12016806006432, 69.67225581407547, 67.00061157345772, 67.79115155339241, 64.35315683484077, 64.77557256817818, 64.69866469502449, 62.392553240060806, 57.07100339233875, 53.671895787119865, 48.14130775630474, 49.65307183563709, 48.55458877980709, 47.63425536453724, 48.91625717282295, 48.10891829431057, 48.94869223237038, 48.567010313272476, 46.49878889322281, 49.937539771199226, 49.01072010397911, 45.59214234352112, 47.555094212293625, 47.79645346105099, 48.41125287115574, 47.2701209038496, 47.954509779810905, 45.95703676342964, 45.469427928328514, 46.63980692625046, 45.996357053518295, 47.88876950740814, 45.93542732298374, 47.68315114080906, 46.21675282716751, 49.156947657465935, 48.31262916326523, 51.622107177972794, 50.36683313548565, 59.15092058479786, 58.3851058781147, 63.62239524722099, 60.72367899119854, 63.54389525949955, 56.880918592214584, 68.43837842345238, 25.645346380770206, 25.49795798957348, 67.50978425145149, 57.3230666667223, 64.73332643508911, 60.164968371391296, 59.978010803461075, 60.66064037382603, 62.374219223856926, 60.35099498927593, 54.85801734030247, 45.76271899044514, 48.90830039978027, 46.15241467952728, 44.84347231686115, 41.77318386733532, 46.29380129277706, 42.135927602648735, 43.70351068675518, 43.22350524365902, 43.59849952161312, 44.679526314139366, 46.84075154364109, 44.53922264277935, 42.9956428706646, 43.908091709017754, 43.18271063268185, 44.432079792022705, 43.75368319451809, 44.20368544757366, 46.165459379553795, 42.21183992922306, 45.358971655368805, 41.56531602144241, 44.18314374983311, 43.82807560265064, 45.48660680651665, 42.788850367069244, 46.28013722598553, 43.30390892922878, 44.35261085629463, 41.67291484773159, 43.382887691259384, 41.95031136274338, 45.56515619158745, 41.397482827305794, 46.41795203089714, 45.5125480145216, 46.789914071559906, 45.63332073390484, 58.2393267005682, 59.15792740881443, 68.91159743070602, 57.49745070934296, 76.08989864587784, 12.281050253659487, 1.4010408706963062, 2.8342368034645915, 2.736760633997619, 0.8671038527972996, 50.00744841992855, 53.337840512394905, 62.03897841274738, 32.00046546757221, 27.56783042103052, 30.757384970784187, 51.365700736641884, 10.928625874221325, 0.7645024708472192, 0.17956374358618632, 0.08091472845990211, 0.1111096004024148, 0.05632447042444255, 0.05634269014990423, 0.048910574696492404, 0.08922117922338657, 0.10746678337454796, 0.055874005338409916, 0.036982291130698286, 0.020769913717231248, 0.0753717239422258, 0.0734518027456943, 0.040436765921185724, 0.09014160561491735, 0.025597011044737883, 0.10251556741422974, 0.200248705514241, 0.15688102401327342, 0.20260493532987311, 0.28745128016453236, 0.15525989147135988, 0.11839287442853674, 0.23674629628658295, 0.1932875977945514, 0.2343875283258967, 0.11441005728556775, 0.12859124515671283, 0.08778097486356273, 0.18796993157593533, 0.1460047162254341, 0.1849877298809588, 0.20164740155451, 0.19126895611407235, 0.18595514906337485, 0.15866296511376277, 0.27393968019168824, 0.12665090005612, 0.7257674681022763, 0.303184989024885, 42.88609094917774, 63.10374967753887, 54.52716909348965, 67.86211654543877, 46.532075107097626, 86.98765307664871, 65.56204676628113, 75.20071595907211, 23.98626420646906, 0.30663086974527687, 0.5896236828994006, 0.7129754545167089, 57.3470775783062, 80.99455386400223, 71.18148922920227, 68.95397275686264, 67.6449353992939, 69.92582380771637, 69.5144958794117, 76.80628180503845, 71.90544158220291, 73.25992450118065, 73.19122418761253, 70.43044432997704, 70.7115076482296, 68.8760693371296, 69.05802637338638, 67.925945520401, 65.36366701126099, 61.13860532641411, 58.94777208566666, 50.596207827329636, 50.231298208236694, 51.861912310123444, 49.68839854001999, 52.470160871744156, 50.01784846186638, 52.1534326672554, 50.39368249475956, 48.51520389318466, 51.46503120660782, 52.185848727822304, 48.55551213026047, 48.14705304801464, 49.24194909632206, 50.73316007852554, 52.1246188133955, 48.320791125297546, 47.14896820485592, 49.01915565133095, 50.789921432733536, 50.159858241677284, 51.62144601345062, 48.28069947659969, 48.97009648382664, 46.8733461946249, 50.28492093086243, 49.18220870196819, 53.32788124680519, 52.35798329114914, 62.35553562641144, 59.639840349555016, 65.96620067954063, 61.38768196105957, 68.28339233994484, 57.80169278383255, 70.94114452600479, 14.659737814217806, 18.379471264779568, 75.99114954471588, 58.686494305729866, 68.68872418999672, 60.03851115703583, 64.18616339564323, 61.22305579483509, 64.65661615133286, 63.93964022397995, 57.64889158308506, 46.31353743374348, 48.92546407878399, 47.70867437124252, 46.57863400876522, 45.05561113357544, 47.796195074915886, 44.986679032444954, 46.194657012820244, 45.588760524988174, 47.21456028521061, 45.918503031134605, 51.48110814392567, 48.54745276272297, 47.685985788702965, 45.09953297674656, 44.748838394880295, 45.09696051478386, 48.245148584246635, 47.58254773914814, 47.48523876070976, 44.43583019077778, 48.943433314561844, 42.742014080286026, 47.347925528883934, 45.22178761661053, 49.013254567980766, 47.91395455598831, 49.80824790894985, 46.538918539881706, 46.65654122829437, 44.87196318805218, 45.660166293382645, 44.27778907120228, 48.58713783323765, 43.06016340851784, 49.347796216607094, 49.33626763522625, 50.529905185103416, 47.127757743000984, 62.255023419857025, 63.37948188185692, 69.08690482378006, 58.09515483677387, 75.97643673419952, 16.342303678393364, 1.2993588019162416, 1.7321556969545782, 4.538815123960376, 2.1476858435198665, 55.3688695281744, 56.41254812479019, 69.76227298378944, 35.788497403264046, 36.65803134441376, 45.291141495108604, 61.40146382153034, 19.72420010715723, 0.896718098083511, 0.279559608316049, 0.19807845790637657, 0.2272543907747604, 0.17591144191101193, 0.3298364917282015, 0.1434979640180245, 0.1432191242929548, 0.11799703512224369, 0.11938912604819052, 0.22176721802679822, 0.14019188907695934, 0.24533085204893723, 0.16123101871926337, 0.16801000339910388, 0.18884125747717917, 0.231664172897581, 0.17906925058923662], [0.018214671435998753, 0.04408444030559622, 0.05288390348141547, 0.08385465742321685, 0.07559542951639742, 0.06143743004940916, 0.03436833569139708, 0.0158301008559647, 0.15582327061565593, 0.03958840577979572, 0.06353906981530599, 0.04574116253934335, 0.04459956871869508, 0.06336583770462312, 0.02011684231547406, 0.10187856722041033, 0.05069903556432109, 0.07078880618792027, 0.11565886918106116, 0.1069642454967834, 0.16254079062491655, 0.1646425825310871, 0.13948106003226712, 4.538992289453745, 52.39789254963398, 36.376933827996254, 33.623115196824074, 24.624187275767326, 52.38090366125107, 62.4502569437027, 64.1604083776474, 37.34424792230129, 0.055160478586913086, 0.4792876972351223, 0.1620108971837908, 3.5664123902097344, 72.41294994950294, 69.27865773439407, 69.92058008909225, 68.00292178988457, 71.43473044037819, 69.40119355916977, 68.45560669898987, 69.8845200240612, 65.09701251983643, 67.71985217928886, 67.31956645846367, 65.61856493353844, 62.73358874022961, 62.83340558409691, 64.78750392794609, 60.061473324894905, 54.926839247345924, 49.2024540156126, 45.9413930028677, 48.129330798983574, 46.744130328297615, 47.0977583527565, 48.13147768378258, 48.45292903482914, 48.074039965867996, 44.60275523364544, 44.735014736652374, 47.25158549845219, 46.334219723939896, 44.52848061919212, 45.591830760240555, 47.85821154713631, 45.486948788166046, 47.69026815891266, 44.72273759543896, 43.50051037967205, 43.32620993256569, 47.43755131959915, 44.190268367528915, 45.56823022663593, 46.159147918224335, 48.00256200134754, 49.939390271902084, 48.11610370874405, 46.241702288389206, 46.13538019359112, 45.858785435557365, 49.38774347305298, 54.692274034023285, 62.738904654979706, 57.85930149257183, 65.67005217075348, 54.201378375291824, 70.66138833761215, 38.521778136491776, 21.119053959846497, 55.23656822741032, 64.90179419517517, 63.207537308335304, 61.10985226929188, 62.07187704741955, 61.243692487478256, 63.026644214987755, 61.58250130712986, 57.906529158353806, 46.7045858502388, 47.361954376101494, 42.86651819944382, 40.48519738018513, 39.80161406099796, 40.49048289656639, 40.222494676709175, 41.07165031135082, 41.1965724080801, 41.13126911222935, 43.12159091234207, 42.49530851840973, 40.97529888153076, 40.69949448108673, 41.39449618756771, 41.50027871131897, 41.34101025760174, 42.84117355942726, 43.42668794095516, 42.57634676992893, 40.464142709970474, 41.74973152577877, 41.45757660269737, 41.381835266947746, 41.78798787295818, 39.11558747291565, 40.79857036471367, 42.740581557154655, 41.753747910261154, 39.44661810994148, 40.934226885437965, 43.38849239051342, 42.836074233055115, 43.580864667892456, 49.52301241457462, 52.00197659432888, 52.945199981331825, 52.36573867499828, 46.31036080420017, 49.83410932123661, 64.6435372531414, 59.12995330989361, 67.9309156537056, 48.092886954545975, 0.23334397963481024, 0.452293767593801, 3.5018270183354616, 4.892715783789754, 1.1325344536453485, 50.05543604493141, 57.8334666788578, 44.23968851566315, 20.528326258063316, 32.17085972428322, 33.54292809963226, 42.99842432141304, 0.3004811966093257, 0.059536199842114, 0.06889327196404338, 0.05943385396676604, 0.09451333040487953, 0.03827599182841368, 0.03616104535467457, 0.09685591954621486, 0.0787447628681548, 0.09014136070618406, 0.057057107478613034, 0.1152209797874093, 0.03785991786571685, 0.03427592346270103, 0.04273552753147669, 0.062280261190608144, 0.0880314942332916, 0.03123069487628527, 0.10571421647910029, 0.03977224318077788, 0.013944896400062134, 0.0521911234682193, 0.046719958845642395, 0.04653133459214587, 0.02817152319039451, 0.044338028455968015, 0.0252605138666695, 0.10822848664247431, 0.10996362791047432, 0.03283368932898156, 0.0439823282067664, 0.0506523136573378, 0.010241837389912689, 0.10808179373270832, 0.03696007865073625, 0.04303001544030849, 0.031316527965827845, 0.04253083578078076, 0.0954799258033745, 0.10584412200842053, 0.192320920759812, 0.294434474199079, 7.555458527058363, 64.09433752298355, 39.66551296412945, 45.07016435265541, 35.159361362457275, 61.81993156671524, 70.5371730029583, 65.79725414514542, 42.88688510656357, 0.1307177951093763, 1.4606986194849014, 0.11948978353757411, 4.635689975693822, 74.97152745723724, 70.5199447274208, 73.89016628265381, 68.78909960389137, 73.43630343675613, 70.48201516270638, 69.69891518354416, 71.73578068614006, 66.76824644207954, 70.62468990683556, 69.97675627470016, 69.47112500667572, 63.28432738780975, 66.51625156402588, 65.52298486232758, 64.21839326620102, 57.6653902977705, 53.337661921978, 47.97832690179348, 47.87118025124073, 48.00786271691322, 47.574594765901566, 49.06697228550911, 50.60161113739014, 49.20942664146423, 48.664467483758926, 46.22378624975681, 48.69914062321186, 48.73460032045841, 46.83091767132282, 47.83075422048569, 49.15676526725292, 47.73194432258606, 49.92483705282211, 47.10528954863548, 46.650738939642906, 45.52244268357754, 49.21932131052017, 46.46956466138363, 48.565182611346245, 49.02234748005867, 49.17843550443649, 49.289913922548294, 51.20856776833534, 48.32132309675217, 50.97503609955311, 49.126222506165504, 53.52426990866661, 57.290753200650215, 63.68010655045509, 62.59757503867149, 66.0819424688816, 55.35635679960251, 70.17123743891716, 50.49178183078766, 26.102066673338413, 60.361433029174805, 65.38798570632935, 65.0043734908104, 63.772608786821365, 63.55331875383854, 62.99020417034626, 63.15870612859726, 64.20314848423004, 59.645483046770096, 48.288565054535866, 47.955547124147415, 45.42647123336792, 41.76461912691593, 41.9962926954031, 43.414015620946884, 44.37182642519474, 41.57150208950043, 43.18708799779415, 43.15440975129604, 45.18778704106808, 43.06769460439682, 43.08755233883858, 43.5797893255949, 45.39464794099331, 43.623464182019234, 44.26938012242317, 44.75944742560387, 46.64919622242451, 45.28447665274143, 42.86926545202732, 43.88023540377617, 45.71902133524418, 42.98555441200733, 43.821114376187325, 42.06632673740387, 42.684971541166306, 45.408467799425125, 44.786612167954445, 44.232423305511475, 42.66852602362633, 46.22809901833534, 45.30163273215294, 44.94008593261242, 51.941586434841156, 54.38865892589092, 56.42853766679764, 54.38455894589424, 48.82046051323414, 52.295484244823456, 67.40503147244453, 60.15817053616047, 68.6601573228836, 48.12777288258076, 0.4995131806936115, 0.871779858134687, 6.686818487942219, 3.0301082180812955, 1.9909813022240996, 56.3666807860136, 63.58104586601257, 50.853617414832115, 30.218277499079704, 34.98191848397255, 37.60551430284977, 50.319803059101105, 0.5621910549234599, 0.07576793432235718, 0.09877785196295008, 0.045647778097190894, 0.02222283848823281, 0.06393262330675498, 0.028017111944791395, 0.021033209159213584, 0.05393315928813536, 0.021543984876188915, 0.03038630893570371, 0.03696767453220673, 0.04722699413832743, 0.030426653938775416, 0.029313864724827, 0.03256366260757204, 0.040024925910984166, 0.026736717954918277, 0.03862966230371967, 0.14349098782986403, 0.14241053955629468, 0.3174048353685066, 0.12921724672196433, 0.13143227552063763, 0.20293412235332653, 0.15107549959793687, 0.12574792897794396, 0.31545785546768457, 0.26024165272247046, 0.1519457864924334, 0.08601914596511051, 0.0963808040251024, 0.13194132945500314, 0.1535152507130988, 0.1597180764656514, 0.12378123763483018, 0.16267627710476518, 0.14431935822358355, 0.3226877690758556, 0.34997484704945236, 0.309507641941309, 0.4896293469937518, 10.283799525350332, 82.2186353802681, 51.94688715040684, 51.30648471415043, 37.18166224658489, 68.62434804439545, 70.04006087779999, 72.63083785772324, 46.62306882441044, 0.2973690745420754, 1.0075241304002702, 0.26219991326797754, 5.371962217614055, 82.11807757616043, 74.94024753570557, 73.23644936084747, 71.79829493165016, 75.35599082708359, 69.7946548461914, 72.5165019929409, 76.72015562653542, 69.12995651364326, 72.58953407406807, 74.32061478495598, 73.37834894657135, 66.10167101025581, 70.04038766026497, 70.8554059267044, 67.62326896190643, 62.34355866909027, 57.835450172424316, 52.047061175107956, 51.604795306921005, 51.760229766368866, 48.52590411901474, 51.865985691547394, 54.02460426092148, 53.3759942650795, 51.32956847548485, 47.78614081442356, 51.18005409836769, 51.997306644916534, 49.8250088095665, 50.771716609597206, 53.6766417324543, 50.85045978426933, 54.33711089193821, 49.84134793281555, 48.70072513818741, 48.69276076555252, 52.8133774548769, 48.20297084748745, 53.945074528455734, 50.15968345105648, 51.78642176091671, 54.62892383337021, 54.16629105806351, 51.83229669928551, 51.47538565099239, 49.659162908792496, 56.58209502696991, 58.04541550576687, 70.02966463565826, 62.53140538930893, 70.91215208172798, 56.355319395661354, 73.85136276483536, 33.367145732045174, 15.064587090164423, 61.393233463168144, 66.16009667515755, 67.646394520998, 65.96180811524391, 65.9382113814354, 63.877148777246475, 65.60436889529228, 65.90764582157135, 63.438629508018494, 48.2760751247406, 50.39855383336544, 46.96847788989544, 45.398614928126335, 43.48154939711094, 45.205174908041954, 46.29894241690636, 45.36392278969288, 46.168939992785454, 45.15673130750656, 47.56402753293514, 45.644267946481705, 44.634206146001816, 45.36623306572437, 47.762768268585205, 46.49462431669235, 45.154504626989365, 46.85183174908161, 48.17613288760185, 48.815972954034805, 45.13938523828983, 46.37567549943924, 47.76986248791218, 44.56253059208393, 47.29263089597225, 44.17030043900013, 47.051275447010994, 50.43603502213955, 48.40500980615616, 47.94348657131195, 45.68021781742573, 48.836689442396164, 47.56091549992561, 48.8773662596941, 55.41885584592819, 56.78728401660919, 59.10663776099682, 58.852921575307846, 49.45855267345905, 54.76744160056114, 69.66560617089272, 61.90823882818222, 69.44846302270889, 54.82973165810108, 1.250356393866241, 1.1584379011765122, 10.246575772762299, 12.647627033293247, 1.8493499583564699, 61.65145620703697, 66.53578251600266, 54.68818925321102, 31.42054818570614, 48.43504719436169, 46.486420556902885, 63.793720453977585, 1.8291621166281402, 0.3121974819805473, 0.2182783224270679, 0.30361154582351446, 0.19730384869035333, 0.13539029750972986, 0.12331434510997497, 0.22485798108391464, 0.17345355270663276, 0.10717583922087215, 0.13101892895065248, 0.16805257298983634, 0.07684369964408688, 0.10999200021615252, 0.2256625285372138, 0.11802845765487291, 0.17420546704670414, 0.1397596622700803, 0.1490250791539438], [0.022665694705210626, 0.02765856741461903, 0.1489918160950765, 0.008824085780361202, 0.021131944486114662, 0.010607741241983604, 0.05041601754783187, 0.016996296872093808, 0.09991715254727751, 0.049413338929298334, 0.06638949576881714, 0.01625884327950189, 0.019647949702630285, 0.08435206706053577, 0.011847230834973743, 0.06431175686884671, 0.020821606158278883, 0.06986266525927931, 0.01332156934950035, 0.059902256762143224, 0.04542047310678754, 0.03645321776275523, 0.14250229869503528, 0.47662119031883776, 28.264439441263676, 52.61585645377636, 33.42936359345913, 26.122226491570473, 22.876740843057632, 60.27395412325859, 64.77179557085037, 66.19766145944595, 3.2464990066364408, 1.0885699815116823, 0.6713070091791451, 0.3728445729939267, 19.409290105104446, 81.02926880121231, 67.58994475007057, 71.95980906486511, 69.70541283488274, 72.03873082995415, 67.33941659331322, 64.62526023387909, 67.23501339554787, 65.87733864784241, 64.12740334868431, 62.41143062710762, 61.22111029922962, 58.34353990852833, 52.60248877108097, 55.70243842899799, 52.573636919260025, 46.42612539231777, 49.584154933691025, 46.32948897778988, 48.26300382614136, 46.89810186624527, 48.015428110957146, 52.58430294692516, 47.858724519610405, 45.506669729948044, 45.38148544728756, 45.3441296517849, 46.88693426549435, 46.63616292178631, 43.90391953289509, 44.59839686751366, 46.40815615653992, 44.91651199758053, 45.72004348039627, 44.976921156048775, 47.130957171320915, 44.70924451947212, 45.43393403291702, 43.8081456720829, 52.87370681762695, 60.14541082084179, 60.40011115372181, 61.378904432058334, 54.78376932442188, 57.09683820605278, 50.98849877715111, 48.11112977564335, 47.17369727790356, 56.591575518250465, 57.16021880507469, 62.62590251863003, 61.14333987236023, 67.33747869729996, 58.07481832802296, 21.365248449146748, 10.786147769540548, 52.24289506673813, 68.14381822943687, 59.22192357480526, 62.45562985539436, 59.14201386272907, 63.7959623336792, 59.88587714731693, 57.243194952607155, 45.744536966085434, 45.2155065536499, 40.87015852332115, 43.05631801486015, 41.41213484108448, 41.396574676036835, 38.924605920910835, 43.08793991804123, 42.37447500228882, 43.98042842745781, 42.837635949254036, 41.09370432794094, 42.28547617793083, 42.350410893559456, 42.12601773440838, 43.5677819699049, 42.57694713771343, 41.81715130805969, 43.76611612737179, 42.47001327574253, 42.95615538954735, 40.65208822488785, 42.48677037656307, 40.91754578053951, 42.24515654146671, 41.4846995472908, 41.827589347958565, 41.81826464831829, 41.725580021739006, 43.25219750404358, 45.51999181509018, 43.739677146077156, 47.022651582956314, 47.79707282781601, 58.4193230420351, 56.87734678387642, 61.589477732777596, 52.5348562002182, 58.09605918824673, 46.838285475969315, 63.762934505939484, 56.36426791548729, 79.34918895363808, 22.288899086415768, 0.5187145003583282, 0.42046525049954653, 4.647157285362482, 2.5332632660865784, 5.143248215317726, 57.52469524741173, 53.540343046188354, 32.82090224325657, 23.851398043334484, 30.02014473080635, 43.06412659585476, 20.650292113423347, 0.26552651601377875, 0.29400726431049407, 0.11147570185130462, 0.12900822825031355, 0.03230206297303084, 0.2206831332296133, 0.08429066176177002, 0.05029901054513175, 0.03568632688256912, 0.06948345006094314, 0.03291704735602252, 0.023331067204708233, 0.09010772657347843, 0.034076330266543664, 0.021286422525008675, 0.05441929570224602, 0.03276222792919725, 0.014248037750803633, 0.016389177399105392, 0.033190666072187014, 0.08498423587298021, 0.04800948496267665, 0.01662276281422237, 0.019857860606862232, 0.04420253084390424, 0.06763847093679942, 0.050948475109180436, 0.06726156381773762, 0.07072662905557081, 0.05512854397238698, 0.064043500169646, 0.05580120436206926, 0.12725131236948073, 0.08769714928348549, 0.045798204009770416, 0.019938470832130406, 0.07767421484459192, 0.0494386647187639, 0.08102062551188283, 0.012244054414622951, 0.023059430022840388, 0.19332926196511835, 0.841283822664991, 41.47626779973507, 56.435772478580475, 31.156642846763134, 34.72593382000923, 34.32609647512436, 65.14301285147667, 73.11381474137306, 68.61054718494415, 4.541020430624485, 1.106204716488719, 1.0784777230583131, 0.36962365207728, 20.443877689540386, 83.97152692079544, 70.14516323804855, 74.57216888666153, 72.15040683746338, 74.22962486743927, 70.59601664543152, 68.0107493698597, 69.9272221326828, 68.45232367515564, 67.30022549629211, 65.19437089562416, 62.678259909152985, 60.51109179854393, 55.52456997334957, 58.19256640970707, 56.41621872782707, 48.39985728263855, 50.91965787112713, 48.834075182676315, 52.07571543753147, 50.28281204402447, 48.746812865138054, 52.52742759883404, 51.18047587573528, 47.09092631936073, 48.36956150829792, 48.27495418488979, 51.380451545119286, 47.857462987303734, 46.303555369377136, 46.52060732245445, 47.376952171325684, 46.364344507455826, 48.37662912905216, 46.40434116125107, 48.733821362257004, 47.7116534113884, 50.052016228437424, 48.8109078258276, 54.66271921992302, 61.01362243294716, 62.6447419077158, 62.47781686484814, 56.08252823352814, 59.750125631690025, 53.526006415486336, 50.0489953905344, 51.877803057432175, 58.828412890434265, 60.08743353188038, 63.45198579132557, 61.935631558299065, 69.64028432965279, 67.5229999423027, 24.567357525229454, 13.095163218677044, 56.478683575987816, 67.97769114375114, 61.29477694630623, 65.58884292840958, 61.32235586643219, 64.32495474815369, 59.99051213264465, 58.73939886689186, 48.17141354084015, 45.5507093667984, 44.37294356524944, 44.243948087096214, 42.5000886619091, 43.98328207433224, 43.24033074080944, 43.716821372509, 45.14867193996906, 45.32719016075134, 45.261772871017456, 43.42347711324692, 44.114694222807884, 44.44667100906372, 43.86749468743801, 46.39815889298916, 45.96265286207199, 42.671087086200714, 44.72050331532955, 44.51304204761982, 45.84035262465477, 42.5493948161602, 44.84618537127972, 42.19816446304321, 44.392029941082, 44.28558625280857, 44.79073494672775, 44.55450922250748, 44.19689521193504, 46.231146454811096, 50.18775254487991, 45.672815814614296, 48.97842563688755, 50.858769938349724, 60.716189593076706, 57.03964367508888, 64.04706805944443, 55.6526193022728, 60.5858413875103, 49.22238774597645, 67.47277423739433, 57.4542698264122, 79.90845814347267, 23.43636341392994, 0.6172289047390223, 3.6631573364138603, 7.880903463810682, 1.7039626347832382, 6.672993879765272, 63.550210520625114, 59.34399962425232, 39.601744785904884, 30.243869125843048, 30.65620020031929, 48.644374161958694, 23.971526697278023, 0.4063376976409927, 0.4728263814467937, 0.05686157754098531, 0.07130848767701536, 0.0854308380803559, 0.18537006952101365, 0.06068023903935682, 0.04196428766590543, 0.04819151523406617, 0.021906010078964755, 0.07359258815995418, 0.05386042139434721, 0.0416816036158707, 0.08146213658619672, 0.034396607807138935, 0.05641223680868279, 0.02153286935936194, 0.07103906580596231, 0.0683792085328605, 0.2584089932497591, 0.14354948390973732, 0.20240191341144964, 0.14729378221090883, 0.17838837462477386, 0.14787031221203506, 0.17699646181426942, 0.14733783609699458, 0.19539989851182327, 0.23015673737972975, 0.3755243791965768, 0.14154632342979312, 0.15919575293082744, 0.13574949698522687, 0.14348956290632486, 0.16292522312141955, 0.1108726326492615, 0.10974277960485779, 0.1769584193243645, 0.24921161646489054, 0.1489284069975838, 0.14084389549680054, 0.2566723676864058, 0.607251530745998, 54.73445177078247, 70.31926989555359, 45.003607124090195, 40.99323771893978, 35.16458988189697, 71.07324063777924, 74.24532562494278, 78.09552982449532, 3.465178459882736, 1.7116970010101795, 0.8854966470971704, 0.3486490447539836, 25.2718473225832, 85.46892777085304, 71.9934144616127, 77.39477902650833, 74.50995862483978, 76.329794973135, 75.36210849881172, 70.3115639090538, 71.75584360957146, 71.15080207586288, 68.54088172316551, 69.5486256480217, 65.41406750679016, 65.74427738785744, 60.20499162375927, 62.425087094306946, 58.04647944867611, 55.18585614860058, 55.05069740116596, 51.176079511642456, 54.03843931853771, 52.52021558582783, 52.40018002688885, 55.79693555831909, 53.92495460808277, 50.554155483841896, 51.504123508930206, 50.71980379521847, 53.15014958381653, 51.46129600703716, 46.74707517027855, 50.356281101703644, 48.82032372057438, 51.64172552525997, 50.88226027786732, 50.08608900010586, 51.7379629611969, 50.403341576457024, 52.0759092271328, 50.32131917774677, 59.76366050541401, 66.16990774869919, 64.12960723042488, 65.13776153326035, 61.39114357531071, 64.39538776874542, 53.773905113339424, 52.45069071650505, 53.51698189973831, 61.68829903006554, 61.067378148436546, 65.51882028579712, 68.8339675962925, 68.97401288151741, 66.02160930633545, 24.11509819328785, 9.756861850619316, 60.54445020854473, 68.99489656090736, 64.4224651157856, 65.81208854913712, 64.59095567464828, 64.66542407870293, 64.11304011940956, 59.92346093058586, 49.20223742723465, 48.242249339818954, 45.22706173360348, 47.01958894729614, 45.5607408285141, 45.13194903731346, 46.07373610138893, 47.29720205068588, 46.68692819774151, 48.857983499765396, 49.40472476184368, 46.37165151536465, 49.3128152936697, 46.50097377598286, 45.375812351703644, 47.097651958465576, 48.03288817405701, 45.247744023799896, 49.1261351108551, 45.022275522351265, 47.53136068582535, 45.60973159968853, 46.819788068532944, 43.5313381254673, 47.80562996864319, 47.12643541395664, 46.90348997712135, 48.01768518984318, 47.917815148830414, 51.00230723619461, 50.75057454407215, 49.06305469572544, 50.87963841855526, 51.9986517727375, 62.22373969852924, 62.030987441539764, 67.86052823066711, 58.008606880903244, 63.23887042701244, 50.50504311919212, 70.0742058455944, 59.589770436286926, 80.51296770572662, 26.382702514529228, 0.4763799626380205, 4.674689183011651, 18.004349693655968, 6.210360629484057, 5.435876213014126, 69.08392578363419, 64.71540659666061, 41.40407547354698, 36.463895961642265, 43.700178265571594, 56.628353744745255, 34.77479159832001, 0.5889688711613417, 0.49355127091985196, 0.33855352085083723, 0.1668976724613458, 0.156259119103197, 0.3084110445342958, 0.1239180080301594, 0.20226498716510832, 0.17517714615678415, 0.13577440346125513, 0.18681752466363832, 0.18291694490471855, 0.3685055917594582, 0.18720819120062515, 0.14395347941899672, 0.26369100669398904, 0.12982411572011188, 0.19102468562778085, 0.22850746259791777], [0.04081255610799417, 0.044473741290858015, 0.04384121624752879, 0.028226349350006785, 0.012444938947737683, 0.08401513943681493, 0.10241962256259285, 0.04350097864517011, 0.06545338037540205, 0.017071261208911892, 0.18236028961837292, 0.02510263122530887, 0.10528021593927406, 0.03765882924199104, 0.04719877026218455, 0.05045563339081127, 0.07017600742983632, 0.017987531573453452, 0.021540997731790412, 0.04403614133480005, 0.11406032019294798, 0.13058097276370972, 0.16914951178478077, 0.41695127030834556, 8.134954031556845, 61.02785266935825, 41.224968284368515, 37.022336795926094, 19.527629055082798, 54.954699352383614, 46.35444223880768, 65.98053351044655, 19.949989691376686, 0.7680868660099804, 1.1499653058126569, 0.19052933173952624, 0.20789555768715218, 36.728654354810715, 77.3547975718975, 64.21461626887321, 70.33304795622826, 66.26369431614876, 67.20893919467926, 63.0076490342617, 64.47375476360321, 61.47435910999775, 61.631161496043205, 60.862686932086945, 55.581426322460175, 54.31245021522045, 49.75033521652222, 52.20392055809498, 50.02162925899029, 51.429252326488495, 48.915212228894234, 48.991762921214104, 49.18878994882107, 51.309209167957306, 49.15112257003784, 48.73616963624954, 48.09437647461891, 49.22613814473152, 47.745900973677635, 46.03768363595009, 45.52203230559826, 48.089379742741585, 47.853252813220024, 47.34243482351303, 45.76198183000088, 45.55867753922939, 46.04191280901432, 47.71771788597107, 41.75853945314884, 45.35849668085575, 47.4463402479887, 49.00392226874828, 58.62912878394127, 60.94173789024353, 59.19203817844391, 59.69769224524498, 61.601295098662376, 61.88771232962608, 55.77144652605057, 53.52077789604664, 52.0127984136343, 46.14647559821606, 48.65294650197029, 55.01355439424515, 60.10881498456001, 59.78544473648071, 62.626738473773, 62.707913517951965, 21.178395375609398, 44.82902929186821, 64.47882369160652, 59.68557849526405, 62.87341743707657, 62.15858459472656, 60.338691249489784, 59.882088750600815, 52.926824167370796, 45.5983018130064, 43.99187721312046, 45.02886816859245, 45.103439167141914, 41.053403690457344, 39.67740252614021, 39.400811567902565, 42.473414093256, 40.849734619259834, 42.084219977259636, 41.86907172203064, 41.34452506899834, 43.602884486317635, 43.23520101606846, 43.73759105801582, 42.06761486828327, 41.639210656285286, 42.63063445687294, 42.283644676208496, 42.993951961398125, 43.14477726817131, 41.36355444788933, 42.08588808774948, 41.72166243195534, 41.645761504769325, 39.39778313040733, 44.943049773573875, 41.13607585430145, 47.061755284667015, 47.3929189145565, 50.972923412919044, 52.027887403964996, 54.77248013019562, 54.759838208556175, 61.32443815469742, 56.13052725791931, 62.00156182050705, 57.770732045173645, 59.22751687467098, 50.5223435908556, 61.70201629400253, 55.556378066539764, 77.30989918112755, 13.503260370343924, 0.5446118919644505, 1.3663836428895593, 2.782285278663039, 0.7994822063483298, 14.026913121342659, 68.32927867770195, 41.15662895143032, 22.068309523165226, 31.6159849986434, 32.74726219475269, 52.53882698714733, 3.7249059230089188, 0.09115350170759484, 0.10846500910702161, 0.07677366316784173, 0.03747047587239649, 0.07719602683209814, 0.14670292875962332, 0.0661652410053648, 0.03806633882049937, 0.04318412240536418, 0.026166770803683903, 0.07363698343397118, 0.0463199894875288, 0.10073817567899823, 0.06127089211076964, 0.00785522126534488, 0.09070019048522227, 0.01837291772972094, 0.10657165679731406, 0.01565577222208958, 0.06463690660893917, 0.08506232465151697, 0.03575752110918984, 0.04988461754692253, 0.061760524040437303, 0.1324162445962429, 0.1261601474834606, 0.03846293140668422, 0.04341937579738442, 0.11960097210248932, 0.15935544826788828, 0.08592881917138584, 0.032796348168631084, 0.09386176927364431, 0.09048427746165544, 0.07963369251228869, 0.02330753741262015, 0.09430297606741078, 0.017131950335169677, 0.06775935195037164, 0.04772988824697677, 0.09193250443786383, 0.17499986191978678, 0.48635769286192954, 13.373931460082531, 73.6233825981617, 41.662731394171715, 39.13146302103996, 27.480872087180614, 64.61152017116547, 57.74733290076256, 72.62052521109581, 19.163840375840664, 1.9080690387636423, 3.7050135154277086, 0.3740621404722333, 0.20770769042428583, 40.06446495652199, 81.2539355456829, 66.62608847022057, 71.63851350545883, 67.98718303442001, 68.47292616963387, 66.06347545981407, 67.13889375329018, 65.95179945230484, 65.07127270102501, 63.72982308268547, 58.91501784324646, 56.89520962536335, 53.34694102406502, 52.964305356144905, 52.204167544841766, 54.89790380001068, 50.63604488968849, 50.49086607992649, 51.506540179252625, 54.18871745467186, 52.739558815956116, 51.609906032681465, 50.659227445721626, 50.8118462562561, 50.50093933939934, 49.38260994851589, 45.5916977673769, 50.04199616611004, 50.093031227588654, 50.44600188732147, 48.72178740799427, 47.01585374772549, 47.96341650187969, 48.95075552165508, 46.52851849794388, 48.54348957538605, 49.19967256486416, 52.040483728051186, 61.83561712503433, 63.99779990315437, 62.567332461476326, 64.04028922319412, 62.39756137132645, 63.58230359852314, 56.3631621748209, 53.30686457455158, 50.872498601675034, 49.13809686899185, 54.171690568327904, 61.28545604646206, 60.61728470027447, 62.56351366639137, 62.595466151833534, 62.06435725092888, 21.108539924025536, 43.86119082570076, 68.07418316602707, 60.218477100133896, 65.30761241912842, 63.2130242139101, 61.99288308620453, 62.243730425834656, 56.19142659008503, 47.16486655175686, 45.58691382408142, 45.51284059882164, 46.49122729897499, 43.000837191939354, 42.999260276556015, 41.811117231845856, 43.13864439725876, 44.58507478237152, 44.5409819483757, 44.98818755149841, 43.544299229979515, 45.26410974562168, 46.60680949687958, 47.05716513097286, 43.301553055644035, 44.02248837053776, 44.12238501012325, 46.35387606918812, 42.9124653339386, 44.35013338923454, 44.555588364601135, 44.21777129173279, 45.02351425588131, 43.21359917521477, 42.4924548715353, 45.45743577182293, 46.25358805060387, 49.43487994372845, 50.90649917721748, 52.76388891041279, 54.65520702302456, 58.59795145690441, 56.47528275847435, 63.32213535904884, 58.95947925746441, 65.10503008961678, 60.699493288993835, 62.68435098230839, 53.66339944303036, 64.10674765706062, 57.44314402341843, 80.74874505400658, 14.722447749227285, 0.44539663300383836, 5.348142245784402, 4.7665962763130665, 1.0335993999615312, 17.524007968604565, 74.33245494961739, 47.05187201499939, 29.655909575521946, 34.26270827651024, 35.38929082453251, 58.6113191395998, 4.677995005622506, 0.06306210634647869, 0.18380997120402753, 0.043704304844141006, 0.09795058736926876, 0.021059009923192207, 0.037016763890278526, 0.024357945403608028, 0.06938046222785488, 0.0103275962646876, 0.06880040702526458, 0.07761829401715659, 0.04264928626071196, 0.04611284864949994, 0.08091690295259468, 0.017527425989101175, 0.04990092995285522, 0.01462324535168591, 0.02326893274585018, 0.04143434969591908, 0.09865980595350266, 0.1260608629672788, 0.07618001181981526, 0.1024918483744841, 0.21313170640496537, 0.2550494094612077, 0.1613772811833769, 0.15821595472516492, 0.24203917477279902, 0.2592825307510793, 0.4569439758779481, 0.22327931423205882, 0.3755832463502884, 0.11741484253434464, 0.14364431553985924, 0.14297065325081348, 0.15454073552973568, 0.16655184648698196, 0.10978633625200018, 0.11024779625586234, 0.3045729239238426, 0.2863594621885568, 0.25221057585440576, 0.5102823371998966, 14.918589424341917, 92.43782982230186, 53.43308240175247, 53.49289119243622, 34.784830659627914, 68.2563453912735, 60.03395140171051, 77.3374705016613, 25.399115793406963, 8.570382166653872, 3.2036076206713915, 0.854083257727325, 0.7405158423352987, 42.357037737965584, 82.23761156201363, 67.82649725675583, 71.52312129735947, 69.10064488649368, 71.16708800196648, 65.87223172187805, 71.36788442730904, 69.12216693162918, 69.57665294408798, 67.03926309943199, 63.70949797332287, 62.11804457008839, 56.56008280813694, 56.46046355366707, 54.88433092832565, 58.06140124797821, 54.21076387166977, 54.57525551319122, 53.84175807237625, 56.5151160210371, 54.184081703424454, 54.39077541232109, 55.17552450299263, 53.81303921341896, 53.22372503578663, 51.761137917637825, 49.13318373262882, 52.7170754224062, 53.40330719947815, 52.37472519278526, 50.5480720102787, 50.736093521118164, 50.189245864748955, 54.40294235944748, 48.18452663719654, 50.6881020963192, 50.61856582760811, 54.2402008920908, 64.06662940979004, 65.4787628352642, 62.73147225379944, 64.35890212655067, 65.21727606654167, 65.53965076804161, 59.24963168799877, 56.95423185825348, 56.634099036455154, 52.28286512196064, 54.563989117741585, 62.06881821155548, 63.436520621180534, 64.94352355599403, 64.00517150759697, 67.08648696541786, 17.032287754118443, 42.06972375512123, 71.44097730517387, 62.73939102888107, 67.18563124537468, 65.81673189997673, 63.899666368961334, 64.65452626347542, 56.86459466814995, 49.616586193442345, 47.09917187690735, 47.64470100402832, 48.39593969285488, 46.50036580860615, 43.69531072676182, 43.19765903055668, 46.01394630968571, 48.83179530501366, 47.736781463027, 46.246520429849625, 44.358196556568146, 47.57288105785847, 48.68212893605232, 48.3336116373539, 45.63765250146389, 46.67514503002167, 45.28853863477707, 48.23878772556782, 44.65660214424133, 45.78295290470123, 47.144659236073494, 46.45239718258381, 48.66078928112984, 46.12950190901756, 43.48841942846775, 50.104719400405884, 47.734642177820206, 54.94720235466957, 52.601668015122414, 56.798527613282204, 57.83541977405548, 61.694747284054756, 58.86601187288761, 67.06103593111038, 61.50591641664505, 65.89938506484032, 61.28679737448692, 65.48897668719292, 56.38899318873882, 66.59947469830513, 58.95279921591282, 84.68785688281059, 14.711818769574165, 0.5445578636135906, 6.178322173655033, 10.827829632908106, 4.3007878214120865, 18.678819201886654, 79.28349047899246, 50.34247264266014, 31.112952791154385, 43.80322873592377, 44.50734615325928, 71.08972415328026, 9.006272926926613, 0.5708111892454326, 0.4553273704368621, 0.17986640625167638, 0.15076583105837926, 0.19876442500390112, 0.4546052310615778, 0.2247795509174466, 0.09688442543847486, 0.31790471635758877, 0.1544190084678121, 0.1414287820807658, 0.11914683709619567, 0.17894326359964907, 0.15962652512826025, 0.09191590259433724, 0.14135548757622018, 0.21559645305387676, 0.21569509932305664, 0.15319663187256083], [0.06434418130083941, 0.036645742002292536, 0.03305014040961396, 0.0045371230680757435, 0.02714313657634193, 0.035093933474854566, 0.03873827190545853, 0.09493034318438731, 0.029620753921335563, 0.08533276326488703, 0.04988349319319241, 0.0659186698612757, 0.02814046059938846, 0.027635310361802112, 0.01877951817732537, 0.017067090338969138, 0.03631036546721589, 0.11706853416399099, 0.07075489003909752, 0.005355140501706046, 0.01794804004020989, 0.15004207380115986, 0.10976430188748054, 0.12315536223468371, 0.5126397544518113, 30.086325779557228, 48.59029546380043, 34.51119214296341, 32.85124361515045, 27.636667527258396, 48.94463025033474, 76.06437921524048, 38.768365904688835, 0.7908228866290301, 2.6764645194634795, 0.26937704533338547, 0.06524287018692121, 4.655804671347141, 66.84604346752167, 74.29577931761742, 74.36168298125267, 67.94675320386887, 68.25775131583214, 61.93831421434879, 57.82283864915371, 56.62846773862839, 55.142059698700905, 51.5775241702795, 52.68874034285545, 49.37748022377491, 52.13795609772205, 51.7183256149292, 53.18993724882603, 60.69661684334278, 57.91246823966503, 53.848354518413544, 51.56526982784271, 48.79414692521095, 50.49941562116146, 49.18748281896114, 49.856759905815125, 48.586921244859695, 46.38780064880848, 46.32325351238251, 44.21754330396652, 49.94185633957386, 48.82189683616161, 47.188273295760155, 45.18815562129021, 46.268654242157936, 43.61081466078758, 47.385889291763306, 43.70978035032749, 45.724857822060585, 47.20678970217705, 49.54165041446686, 57.798592150211334, 62.74597607553005, 61.76734618842602, 61.7133928835392, 59.50876638293266, 59.42499987781048, 59.84805017709732, 63.00805561244488, 60.21962843835354, 59.02972228825092, 50.493183955550194, 55.23026816546917, 55.90757042169571, 64.97363314032555, 55.97564376890659, 71.62089765071869, 54.2533253878355, 51.202678084373474, 59.25278551876545, 59.011380672454834, 61.88674718141556, 60.12628264725208, 59.935700073838234, 51.71399004757404, 44.89384241402149, 43.5508918762207, 43.22887435555458, 45.04966825246811, 44.66062232851982, 43.30206982791424, 41.90169297158718, 41.85609541833401, 43.392200991511345, 41.283587738871574, 40.363881289958954, 43.88581730425358, 43.52074809372425, 44.32388439774513, 40.77323332428932, 43.46371315419674, 42.5286441296339, 44.008508920669556, 43.03288087248802, 43.290860429406166, 44.20866318047047, 43.6531025916338, 43.281284943223, 41.02338530123234, 42.50185936689377, 43.673879876732826, 39.44369986653328, 42.89745233952999, 41.25958442687988, 45.884441658854485, 53.1829684227705, 55.133449360728264, 53.75968627631664, 56.14945784211159, 57.315945848822594, 60.846678391098976, 61.69361114501953, 61.48466795682907, 60.41892774403095, 62.88821384310722, 56.90165787935257, 63.98167356848717, 56.56676284968853, 73.61859485507011, 11.018890030682087, 0.8890670898836106, 3.6922841984778643, 2.133822049945593, 0.408721950952895, 29.995238967239857, 61.28511406481266, 16.918421164155006, 22.670664601027966, 26.0536914691329, 44.374360889196396, 28.245554454624653, 0.15096555784111843, 0.18189588328823447, 0.0438317204680061, 0.09973695909138769, 0.030076208095124457, 0.05079976355773397, 0.05736243445426226, 0.06278156710322946, 0.0069757386972924, 0.029491321511159185, 0.013963454730401281, 0.06540314439916983, 0.0840485435037408, 0.04331695941800717, 0.03861179880914278, 0.044728342472808436, 0.025286717245762702, 0.01668135722866282, 0.08447268832242116, 0.05710153986001387, 0.04714550632343162, 0.04043156346597243, 0.047479194472543895, 0.019527927724993788, 0.058645307217375375, 0.049108301391243, 0.047401124247699045, 0.050519810611149296, 0.015064596864249324, 0.014436279798246687, 0.1187700338778086, 0.03429888922255486, 0.028097273170715198, 0.008380607087019598, 0.0331998538604239, 0.01593246342963539, 0.02646162607561564, 0.09890269604511559, 0.06301211527897976, 0.07267713415785693, 0.06039145453542005, 0.03405450741411187, 0.11435286738560535, 0.12147079090937041, 0.9354564850218594, 40.47746479511261, 56.20058789849281, 36.13537698984146, 41.142235323786736, 35.63073366880417, 54.652733355760574, 82.74476274847984, 42.503493279218674, 0.5818127864040434, 4.972207518294454, 0.7359374442603439, 0.1811791319050826, 5.847619269043207, 67.8287847340107, 78.08189615607262, 76.76757708191872, 71.8646089732647, 70.8016312122345, 64.86166834831238, 60.72592847049236, 58.504742458462715, 58.47806788980961, 54.92805898189545, 55.34861661493778, 52.49703302979469, 54.11953076720238, 55.39958707988262, 56.83112606406212, 63.23318213224411, 58.7609589099884, 55.126598328351974, 52.54125885665417, 48.677344992756844, 50.998940616846085, 50.65430290997028, 50.67356787621975, 52.120754420757294, 48.69535222649574, 49.55190226435661, 46.555869430303574, 50.23016206920147, 50.15750616788864, 49.38147000968456, 46.68380856513977, 49.362725615501404, 44.71617914736271, 49.28961753845215, 46.975986286997795, 47.13016681373119, 49.3159007281065, 53.14687415957451, 60.263402089476585, 64.95229348540306, 62.74797476828098, 64.70731303095818, 63.40160429477692, 63.56119953095913, 63.332204818725586, 65.16299977898598, 59.925075843930244, 58.48289743065834, 51.43897980451584, 57.430467903614044, 59.94023323059082, 68.52248311042786, 57.95235089957714, 74.12149786949158, 60.57333625853062, 53.69725562632084, 59.66801963746548, 59.38355550169945, 63.28482896089554, 61.944378688931465, 63.471258357167244, 55.436232313513756, 48.1766876578331, 44.9350968003273, 45.9997046738863, 47.95806638896465, 46.2449549138546, 44.20438081026077, 43.1718660145998, 44.81527782976627, 46.214362755417824, 42.481112480163574, 43.634168207645416, 44.87129062414169, 44.47751775383949, 46.54013827443123, 43.198058009147644, 45.117939189076424, 44.75001633167267, 47.19786778092384, 45.5706012994051, 44.30085003376007, 45.95560044050217, 46.13968536257744, 45.65657548606396, 44.41652722656727, 42.9309893399477, 46.06962092220783, 43.38232532143593, 45.33777639269829, 44.42709445953369, 48.240680024027824, 56.63406103849411, 57.30262756347656, 56.632058545947075, 58.36129255592823, 59.930657744407654, 62.66178019344807, 63.20768550038338, 63.68499308824539, 61.8916717171669, 65.02706587314606, 59.8010390996933, 66.56830877065659, 59.085643887519836, 76.09420001506805, 10.972488820552826, 0.36398448748514056, 9.519148506224155, 0.20298501884099096, 0.15813808859093115, 32.90955908596516, 68.89210447669029, 24.909320175647736, 29.386836513876915, 28.19876566529274, 51.26147612929344, 32.60561339557171, 0.3152998967561871, 0.16087637603050098, 0.01247148000402376, 0.08450953595456667, 0.007548783387392177, 0.03575625203666277, 0.05364021875720937, 0.08475507551338524, 0.03891955260769464, 0.036283418085076846, 0.048895909858401865, 0.05369197613617871, 0.07002703612670302, 0.09654674824560061, 0.03958577857702039, 0.039589352018083446, 0.035036658227909356, 0.05147375610249583, 0.14079617540119216, 0.031409010698553175, 0.16665740957250819, 0.18526020197896287, 0.2154821326257661, 0.07760378503007814, 0.09557883924571797, 0.1756028420641087, 0.14849042112473398, 0.17724460631143302, 0.06621446023928002, 0.1268806986627169, 0.2408012724481523, 0.11627879255684093, 0.12724739382974803, 0.07489358045859262, 0.13576392433606088, 0.14901473361533135, 0.136610135959927, 0.23862519155954942, 0.12990129907848313, 0.14804728474700823, 0.19649176101665944, 0.19069275265792385, 0.17998883093241602, 0.19382267142646015, 0.6971437821630388, 49.88890238106251, 68.46221074461937, 49.58548866212368, 52.372042536735535, 41.07908271253109, 61.985967457294464, 91.66277781128883, 46.68219365179539, 3.5801700269803405, 9.404380414634943, 0.5863369186408818, 0.2007844767649658, 7.3486807476729155, 71.44633501768112, 80.64084604382515, 78.8876049220562, 74.51145574450493, 75.83218887448311, 67.55475863814354, 62.34871879220009, 63.25891435146332, 61.99479058384895, 55.65898396074772, 58.26201908290386, 54.92508374154568, 57.86240592598915, 58.354787304997444, 60.14749690890312, 66.14460870623589, 63.95347148180008, 60.40596663951874, 57.378562688827515, 53.2794376462698, 55.31147360801697, 52.668685019016266, 54.60800215601921, 54.44263502955437, 53.04812125861645, 50.51655650138855, 49.648109301924706, 53.485291600227356, 52.5297074764967, 51.97922341525555, 49.19481262564659, 50.63145853579044, 48.5871834307909, 52.85920299589634, 49.78378102183342, 50.959631726145744, 52.30896212160587, 54.56042870879173, 62.3109146207571, 68.19827690720558, 65.04087433218956, 64.26028221845627, 64.30254355072975, 65.72814345359802, 64.38982486724854, 66.65255025029182, 63.28733682632446, 63.338523879647255, 55.56791804730892, 61.72014132142067, 61.11997112631798, 71.37018710374832, 60.614092871546745, 73.76805603504181, 55.8450485765934, 54.8757129907608, 60.50201788544655, 61.858385503292084, 66.54083624482155, 62.99072854220867, 64.48059439659119, 56.35800585150719, 49.61827710270882, 47.197347208857536, 47.95383341610432, 49.386223554611206, 48.30732844769955, 48.21657411754131, 45.7291553914547, 46.70532301068306, 48.76227043569088, 45.4075862467289, 45.38375772535801, 48.443912118673325, 47.27996237576008, 49.83787111938, 46.199064776301384, 47.81619340181351, 45.93313604593277, 50.21751254796982, 48.03475767374039, 46.81215427815914, 47.512217313051224, 48.257247135043144, 47.193813398480415, 46.9901405274868, 46.179644018411636, 48.93947392702103, 45.19422389566898, 49.46179769933224, 45.390023589134216, 51.73666723072529, 59.476988688111305, 59.32804428040981, 60.161065980792046, 62.49127574265003, 62.85532280802727, 65.36552891135216, 67.45543196797371, 64.85976085066795, 65.74768960475922, 66.25576794147491, 62.22634635865688, 69.55090552568436, 59.42563824355602, 77.35149934887886, 12.36976694315672, 0.8811193413566798, 9.13979111239314, 9.471090584993362, 1.6553028021007776, 35.68829298019409, 76.33157327771187, 23.305684626102448, 36.2187597155571, 38.15008208155632, 56.354411244392395, 45.91247655451298, 0.4556842247257009, 0.23229244543472305, 0.15478764806175604, 0.3145800728816539, 0.17028392903739586, 0.11205485905520618, 0.12022085094940849, 0.16910556179936975, 0.08088173999567516, 0.18840404343791306, 0.13300478254677728, 0.22632229782175273, 0.17306622583419085, 0.1924620772479102, 0.10079545463668182, 0.1504690313595347, 0.12250269530341029, 0.13685415411600843, 0.25199731229804456, 0.1519053097581491], [0.021458285373228136, 0.0312537719582906, 0.007905597321951063, 0.02841749505023472, 0.08823607466183603, 0.0316120660136221, 0.03750314892386086, 0.0226388104056241, 0.012666711227211636, 0.02228950004791841, 0.024648128855915274, 0.033962848465307616, 0.06058974897314329, 0.03774302218516823, 0.020488953305175528, 0.010849361333384877, 0.03589862935768906, 0.08538278401829302, 0.01514966183094657, 0.03392840539163444, 0.03406348740099929, 0.028448383236536756, 0.023530554644821677, 0.06842767077614553, 0.048910619225353, 1.198138645850122, 47.04298809170723, 39.38596956431866, 29.184957146644592, 26.631347872316837, 37.19469554722309, 71.02895021438599, 55.30551552772522, 1.7857892252504826, 2.568073673173785, 0.7970955781638622, 0.17289312731008977, 0.06761511554941535, 27.34040692448616, 80.44584050774574, 68.95698219537735, 72.24255189299583, 61.36373944580555, 61.93478420376778, 58.16733576357365, 56.998681873083115, 50.669714882969856, 53.41756023466587, 56.69814079999924, 59.57104504108429, 61.51337541639805, 62.19602778553963, 61.62122122943401, 67.63959288597107, 70.53651183843613, 67.21767872571945, 55.602857172489166, 49.69979792833328, 49.70849946141243, 49.48537163436413, 46.17508426308632, 47.274471670389175, 49.24411877989769, 48.176607862114906, 47.508238926529884, 46.96558624505997, 48.25946621596813, 49.039210975170135, 48.80789078772068, 47.58878320455551, 46.44987411797047, 44.53903265297413, 44.27919879555702, 43.66023100912571, 44.96218554675579, 45.93563251197338, 56.63124158978462, 59.75266009569168, 62.80396856367588, 63.54191556572914, 60.83429105579853, 60.56100971996784, 62.06696771085262, 59.34674687683582, 60.19190892577171, 61.478291898965836, 57.86974333226681, 56.26157082617283, 59.20934624969959, 59.32885743677616, 65.42209267616272, 58.946081176400185, 54.24750789999962, 58.27116899192333, 61.63452431559563, 62.08669625222683, 60.86275152862072, 59.05220948159695, 51.791958063840866, 46.00284330546856, 45.49516774713993, 46.9091060757637, 46.44519276916981, 45.634783655405045, 43.59608665108681, 43.25147934257984, 44.18471686542034, 42.733301147818565, 43.19131717085838, 41.878225430846214, 42.97389663755894, 45.92837870121002, 44.727931916713715, 44.35533531010151, 43.26703570783138, 42.89706476032734, 44.71175618469715, 44.27749268710613, 43.02709758281708, 42.810281217098236, 44.22502510249615, 43.08667078614235, 43.784001767635345, 41.64029359817505, 44.13788057863712, 41.10795356333256, 42.79630936682224, 41.72650717198849, 42.86889307200909, 45.91415986418724, 52.333326414227486, 57.469176426529884, 60.9291947633028, 57.2830244153738, 57.328055799007416, 61.641975715756416, 62.46798299252987, 59.165853783488274, 64.27941799163818, 61.58722445368767, 62.94491820037365, 61.759153828024864, 59.92085047066212, 65.84138497710228, 1.7212812742218375, 0.26020965131465346, 3.125379793345928, 2.7841269923374057, 1.027974751777947, 50.19025281071663, 42.455566450953484, 14.791523292660713, 29.443742260336876, 27.413486503064632, 55.05127876996994, 6.204120889306068, 0.18125600356142968, 0.05175665908609517, 0.029171127462177537, 0.0017108024189838034, 0.021260209869069513, 0.07618865041877143, 0.07071532614645548, 0.05500447914528195, 0.06990388414124027, 0.0212904227009858, 0.005406633026723284, 0.09002427948871627, 0.07276938311406411, 0.0036484568863670575, 0.01616152916540159, 0.044015157109242864, 0.026386548561276868, 0.03611422325775493, 0.0782375865674112, 0.056118921493180096, 0.024806755500321742, 0.041094935877481475, 0.0611991709592985, 0.041302291938336566, 0.008707823708391516, 0.07273433890077285, 0.07239525162731297, 0.04411386646097526, 0.053459691334865056, 0.023746655060676858, 0.05070346989668906, 0.0714485086791683, 0.019220385438529775, 0.024169399075617548, 0.04194482113234699, 0.02095920961437514, 0.04569413635181263, 0.03507975474349223, 0.02262118439830374, 0.054898737944313325, 0.12520623538875952, 0.02981663081300212, 0.010222607415926177, 0.08138455988955684, 0.04628434413461946, 2.2694465098902583, 63.39544862508774, 40.37162907421589, 38.76913346350193, 34.28511567413807, 46.94243788719177, 79.82412546873093, 60.72526730597019, 1.9967116322368383, 3.260600524954498, 3.4315497893840075, 0.23190787935163826, 0.1615304604638368, 28.77173501998186, 84.96240735054016, 74.00302022695541, 75.45220926404, 62.877555415034294, 65.44767290353775, 58.69343273341656, 60.16374483704567, 52.678853273391724, 56.36000454425812, 58.336179703474045, 60.89065723121166, 61.787435710430145, 63.65758515894413, 65.89897468686104, 69.53666388988495, 72.7325052022934, 67.89234012365341, 57.80111901462078, 49.49854552745819, 50.456827506423, 50.859757885336876, 48.85809749364853, 50.72595566511154, 50.87500646710396, 50.23377187550068, 49.75415401160717, 50.32762683928013, 51.701617911458015, 50.93055948615074, 50.780307948589325, 49.59523133933544, 48.49280409514904, 46.389768943190575, 46.19561456143856, 48.51171188056469, 48.149500116705894, 49.57705691456795, 59.78943832218647, 62.90318883955479, 65.85801288485527, 65.82108646631241, 61.47613741457462, 63.125412315130234, 63.875955641269684, 62.866767793893814, 62.420078963041306, 62.493722811341286, 62.535946145653725, 59.37551133334637, 60.79457178711891, 61.43067665398121, 66.03227153420448, 59.68026638031006, 54.94789011776447, 57.49350652098656, 61.57878130674362, 63.18927928805351, 63.42224858701229, 63.2233102619648, 56.269216015934944, 49.07899484038353, 48.11869136989117, 47.9634203016758, 48.46380405128002, 46.45792208611965, 46.04560241103172, 45.86856611073017, 46.88007563352585, 45.19038610160351, 44.97065149247646, 43.380083441734314, 43.93671557307243, 48.07473912835121, 47.41219907999039, 46.3278778642416, 46.7091304063797, 46.72251708805561, 45.36890812218189, 45.26194766163826, 44.40437167882919, 46.299953162670135, 46.31262548267841, 45.43586812913418, 46.23073607683182, 43.13295230269432, 44.840884655714035, 44.91283379495144, 46.42338953912258, 44.86698925495148, 45.51036313176155, 48.332365304231644, 53.99074427783489, 59.3087413161993, 63.4324586391449, 61.81180380284786, 60.85153453052044, 63.484645038843155, 64.29103776812553, 61.83815538883209, 65.59897318482399, 64.07702565193176, 64.95854794979095, 64.09997642040253, 61.80190533399582, 67.64497339725494, 1.7732634348794818, 0.17446466954424977, 8.681700993329287, 1.3847795245237648, 1.5867116139270365, 57.19377860426903, 50.79112596809864, 19.92188259959221, 33.85018341243267, 26.488703526556492, 63.79233732819557, 7.946387249976397, 0.19813655322650447, 0.023725203282083385, 0.020984004768251907, 0.025965292552427854, 0.07613574271090329, 0.02286885392095428, 0.019562788256735075, 0.05698527871572878, 0.03312007669592276, 0.027522002965270076, 0.0238615543639753, 0.04751686588861048, 0.07402455521514639, 0.041853859802358784, 0.03159638443321455, 0.053615290016750805, 0.02946930384496227, 0.0485475902678445, 0.054066734737716615, 0.03696289139043074, 0.17700630269246176, 0.17940513178473338, 0.1732221362181008, 0.13816218939609826, 0.21566530951531604, 0.18133949517505243, 0.11441997237852775, 0.18439316569129005, 0.12004657241050154, 0.1576130636385642, 0.12482955091400072, 0.1509110545157455, 0.22101000475231558, 0.28464993985835463, 0.17514434322947636, 0.10226934507954866, 0.11738053304725327, 0.20495500531978905, 0.21000236651161686, 0.18794389703543857, 0.17652343172812834, 0.08078617363935336, 0.144850246142596, 0.12014287349302322, 0.17788717261282727, 3.5197048215195537, 80.60952812433243, 53.478318974375725, 49.7385710477829, 40.813351571559906, 51.72703854739666, 85.21323949098587, 68.54949966073036, 2.6310085086151958, 10.190913509577513, 3.6489157006144524, 0.5506078514736146, 0.37211812916211784, 32.371773943305016, 86.6029617190361, 76.4050841331482, 78.8686591386795, 65.31775787472725, 69.5891846716404, 62.256402745842934, 63.02576646208763, 54.94914785027504, 59.47043403983116, 61.251580864191055, 65.75386047363281, 66.58626660704613, 67.07757264375687, 68.0077475309372, 74.20019924640656, 75.98468989133835, 72.68416419625282, 60.236225947737694, 53.06243509054184, 52.64385715126991, 53.87168146669865, 50.120936930179596, 53.307913318276405, 54.152877777814865, 54.38933148980141, 53.08456890285015, 52.34293229877949, 52.433956414461136, 53.7077696621418, 53.53495493531227, 52.63362430036068, 52.17327140271664, 50.998735427856445, 49.10351112484932, 51.02875381708145, 49.07657437026501, 51.39155834913254, 61.886625587940216, 65.16400292515755, 69.12462159991264, 69.25637573003769, 64.51825797557831, 64.77421224117279, 67.77241095900536, 63.80243718624115, 64.32898253202438, 64.36211675405502, 65.03777369856834, 60.717192739248276, 62.157266065478325, 61.927674785256386, 71.29199489951134, 61.11160397529602, 55.42360559105873, 62.05686405301094, 62.55697801709175, 64.91546586155891, 65.74575930833817, 65.63995018601418, 56.752496883273125, 51.34302355349064, 49.989084005355835, 51.92750059068203, 48.7345015257597, 49.37459997832775, 47.59850688278675, 48.79717156291008, 47.9827194660902, 47.36464463174343, 47.28016756474972, 47.37471789121628, 45.253462716937065, 51.561078652739525, 47.89603851735592, 48.05768184363842, 48.005438446998596, 48.18962976336479, 48.69757130742073, 49.053874388337135, 46.23714633285999, 49.758470579981804, 48.3637972176075, 48.537132516503334, 47.79902592301369, 46.51219457387924, 49.97572012245655, 45.825392827391624, 48.7643451243639, 46.84238165616989, 48.89293782413006, 53.11148285865784, 55.43635010719299, 61.008010134100914, 65.22196501493454, 64.26298007369041, 63.977205008268356, 66.9753885269165, 67.3828786611557, 63.66966091096401, 69.03670951724052, 66.39662638306618, 67.37951204180717, 65.42928948998451, 63.26469764113426, 69.9496865272522, 2.805953021161258, 0.42374141688924283, 9.299419596791267, 11.740414313971996, 1.8687404366210103, 63.487149104475975, 54.69015754759312, 23.571514561772346, 48.40949356555939, 37.225603088736534, 74.87483784556389, 13.626067880541086, 0.3862933279015124, 0.2251721767242998, 0.11467353455373086, 0.14776366559090093, 0.17153927183244377, 0.1673298398964107, 0.24479217157931998, 0.19987113046227023, 0.1472826796816662, 0.14955777791328728, 0.10080266089062206, 0.25415455747861415, 0.22460514621343464, 0.25238557427655905, 0.14534948888467625, 0.1489414242678322, 0.10635991464368999, 0.18659721070434898, 0.22134585626190528, 0.1067985907138791], [0.013520091997634154, 0.06481363423517905, 0.03705290648213122, 0.038549762684851885, 0.025162657984765247, 0.09600854275049642, 0.10995602831826545, 0.017375350653310306, 0.045011471811449155, 0.02665063253516564, 0.10220184674835764, 0.05503757522092201, 0.019850826902256813, 0.05348386308469344, 0.06361599342199042, 0.019940213023801334, 0.04874716862104833, 0.07504243301809765, 0.10042157548014075, 0.04851856858294923, 0.08438177523203194, 0.0966276423423551, 0.0683088084042538, 0.04432381261722185, 0.014840569383522961, 0.40372370509430766, 7.714028293266892, 49.96687799692154, 30.34640472382307, 29.768489934504032, 22.713771387934685, 54.3208933621645, 77.57399260997772, 11.91757695749402, 1.6970776417292655, 3.294043242931366, 0.29065041162539274, 0.23005099617876112, 3.491067895665765, 66.61821529269218, 74.97481808066368, 69.34551134705544, 67.9608428478241, 59.462967440485954, 59.977136850357056, 59.05078835785389, 59.79732669889927, 65.44543862342834, 66.18795678019524, 67.83315449953079, 66.61006852984428, 66.38333469629288, 69.64087709784508, 69.4891208410263, 68.32973465323448, 65.64620465040207, 61.7482104152441, 52.730484902858734, 51.170942187309265, 47.48624950647354, 50.55147662758827, 50.03554031252861, 47.71970137953758, 46.57774865627289, 47.99292951822281, 49.06053923070431, 46.90249063074589, 45.92316158115864, 49.223440289497375, 47.127491757273674, 47.009078711271286, 46.5307679772377, 45.57563602924347, 45.86105391383171, 46.07398308813572, 46.36138066649437, 50.9733147919178, 61.23649947345257, 62.810781598091125, 60.83184018731117, 63.993103355169296, 64.5512706041336, 62.942334339022636, 62.77668982744217, 60.63135914504528, 62.08086356520653, 60.608054995536804, 60.60705564916134, 61.88587702810764, 64.40825387835503, 60.135554149746895, 57.473215609788895, 61.000345945358276, 60.49028791487217, 61.27637833356857, 61.52047723531723, 59.775044694542885, 53.29267993569374, 45.49303226172924, 44.858515709638596, 45.5436759442091, 45.271272361278534, 47.27879583835602, 47.421698570251465, 44.97251719236374, 43.95365886390209, 43.362668976187706, 42.96384997665882, 42.47030965983868, 43.424639850854874, 43.3512581884861, 43.802438378334045, 44.821923673152924, 43.798072412610054, 43.872575014829636, 43.69686484336853, 45.733046382665634, 46.07553340494633, 47.41670943796635, 45.3227785974741, 44.44876849651337, 43.68789732456207, 44.677527621388435, 43.08838449418545, 42.77977265417576, 41.66953682899475, 44.133484214544296, 43.41382183134556, 42.32161223888397, 42.338095754384995, 53.265602588653564, 56.53404280543327, 60.90011492371559, 61.3958515226841, 60.849026665091515, 57.65731193125248, 61.24222196638584, 63.06606709957123, 60.25109075009823, 61.02264314889908, 65.50381109118462, 58.915424421429634, 72.14672863483429, 32.57614217698574, 0.21268491866067052, 0.7207905070390552, 13.47636541351676, 0.33716695150360465, 4.015098251402378, 68.98525267839432, 20.195228531956673, 21.77080448716879, 24.4424145296216, 33.82684126496315, 34.86523434519768, 0.3166681795846671, 0.08731511392397806, 0.03691311183501966, 0.07115404674550518, 0.013571506133303046, 0.015581859879603144, 0.06134001203463413, 0.03207007874152623, 0.054020372772356495, 0.03049445840588305, 0.036301203654147685, 0.0601404453482246, 0.0609766342677176, 0.011378013532521436, 0.08120482656522654, 0.024848761058819946, 0.019233091006753966, 0.07477513368939981, 0.03293585708888713, 0.03570981585653499, 0.03695398561831098, 0.01604891753231641, 0.12315909523749724, 0.05530944989004638, 0.050430778865120374, 0.037177390622673556, 0.05704995317501016, 0.06047865317668766, 0.06116918819316197, 0.017201823538925964, 0.023299922977457754, 0.02407622800092213, 0.011440006983320927, 0.019172932516084984, 0.06710339730489068, 0.032148382742889225, 0.07112551116733812, 0.0652578986773733, 0.09648428167565726, 0.055788383760955185, 0.016058149849413894, 0.09578216544468887, 0.06646644163993187, 0.034568812043289654, 0.07755967919365503, 0.1419142950908281, 0.6396371335722506, 13.608782608062029, 60.31304642558098, 33.49365994334221, 38.85899864137173, 29.881454072892666, 65.69053307175636, 85.03100886940956, 13.98828249424696, 1.0866369539871812, 6.537008676677942, 1.028484518174082, 0.19989110907772556, 3.8470085710287094, 70.58134943246841, 78.99595990777016, 73.98567795753479, 71.52965694665909, 61.97830326855183, 64.09168526530266, 59.79929879307747, 60.88935770094395, 67.10312247276306, 69.40426379442215, 67.36134141683578, 68.36218491196632, 69.88679990172386, 71.77260830998421, 69.64692637324333, 69.99739676713943, 68.35978344082832, 64.99716147780418, 54.54694703221321, 52.47667372226715, 50.38264408707619, 51.003158390522, 51.430460661649704, 50.59653840959072, 48.79929944872856, 50.557704493403435, 51.272533535957336, 49.60851542651653, 49.86023671925068, 51.54731199145317, 48.59391286969185, 49.08981665968895, 47.42014065384865, 47.788948863744736, 47.78443090617657, 48.36063198745251, 49.63947996497154, 55.85484445095062, 65.31481683254242, 64.08552959561348, 63.195875734090805, 67.25989446043968, 64.28974583745003, 64.1011543571949, 62.97692768275738, 62.59550414979458, 63.660951778292656, 62.49830536544323, 63.5276435315609, 63.7150114774704, 65.17212688922882, 63.63571733236313, 60.05996100604534, 61.557836830616, 62.760951071977615, 62.47719369828701, 62.204850912094116, 60.18673740327358, 57.07629270851612, 48.34998495876789, 47.083767503499985, 46.64840206503868, 47.342172637581825, 49.56212751567364, 47.312082052230835, 48.62886719405651, 44.431213438510895, 45.00787049531937, 43.8748624920845, 44.833235666155815, 45.980998277664185, 45.83412475883961, 45.61675362288952, 48.353606164455414, 46.78535811603069, 44.81622017920017, 45.785373374819756, 46.90486550331116, 48.62351328134537, 49.16577458381653, 46.73446744680405, 45.94586156308651, 47.16717682778835, 47.1017025411129, 44.997234866023064, 45.309741497039795, 43.78809034824371, 47.11617976427078, 46.07244037091732, 46.174540892243385, 44.91381794214249, 54.63203206658363, 59.70612399280071, 62.56678149104118, 63.1457906216383, 65.04552528262138, 58.50573420524597, 62.12939836084843, 65.38789451122284, 63.37107673287392, 64.18031170964241, 67.25748538970947, 61.71767145395279, 74.15495127439499, 32.26699456572533, 0.25200713833328336, 1.5539950132369995, 6.743467273190618, 0.9967774758115411, 5.197643246501684, 74.38603967428207, 25.10302998125553, 28.662766367197037, 29.983427301049232, 38.57898406684399, 39.21516112983227, 0.717996172606945, 0.09901202924083918, 0.03666585049359128, 0.007934079094411572, 0.10658809536835179, 0.05731806144467555, 0.03167659946484491, 0.06348755734506994, 0.012669780935539166, 0.04925756584270857, 0.009381981381011428, 0.015094036007212708, 0.03437400941038504, 0.02880710773752071, 0.021528524084715173, 0.03312711967737414, 0.020669083678512834, 0.057035570353036746, 0.02049238759354921, 0.04047096779686399, 0.09244503904483281, 0.11775887251133099, 0.19207719946280122, 0.15175503969658166, 0.1022094908694271, 0.09970865357900038, 0.10526545462198555, 0.13802361558191478, 0.12369417629088275, 0.15845891903154552, 0.12339630789938383, 0.22681676113279536, 0.10057306266389787, 0.15965144644724205, 0.24680656817508861, 0.08130417787469923, 0.23457972973119467, 0.1268671322031878, 0.18546268955105916, 0.15793757513165474, 0.13725941127631813, 0.14999825740233064, 0.13922996178735048, 0.12200031327665783, 0.2119942315039225, 0.2943670575041324, 0.6471113918814808, 24.211941696703434, 83.11852589249611, 46.83985859155655, 49.97090198099613, 33.47139693796635, 67.48733505606651, 94.42082941532135, 14.307793099433184, 4.639156339690089, 8.064614105969667, 1.3156202668324113, 0.40502860851120204, 5.135170323774219, 76.78333103656769, 80.06451576948166, 80.47326743602753, 74.82229426503181, 67.75634542107582, 65.09816005825996, 65.67112371325493, 64.93248134851456, 71.7058002948761, 72.38953560590744, 72.47968956828117, 71.20255529880524, 73.26978877186775, 74.18738633394241, 74.95806857943535, 71.394262611866, 71.21876522898674, 67.93620496988297, 57.96887621283531, 56.41815662384033, 52.67253801226616, 54.03487130999565, 56.0995589196682, 52.93587528169155, 51.87032885849476, 52.42496609687805, 54.7612327337265, 51.19645021855831, 50.864834412932396, 53.43615263700485, 52.56744705140591, 53.79458360373974, 49.86699655652046, 50.68101167678833, 52.06692650914192, 52.301476523280144, 52.95405350625515, 57.75007255375385, 67.86364406347275, 66.26151323318481, 64.29726183414459, 69.65275526046753, 67.5910846889019, 66.31221011281013, 65.57868227362633, 65.00010251998901, 66.47389903664589, 64.72403213381767, 65.28229057788849, 67.62696996331215, 68.35827872157097, 65.08329525589943, 62.01227344572544, 64.10282626748085, 62.397808358073235, 63.744695484638214, 63.79582554101944, 62.28008687496185, 57.75485649704933, 50.6386249512434, 50.17756149172783, 49.12162475287914, 49.69301909208298, 51.63681618869305, 49.93625544011593, 48.816349133849144, 46.8349302560091, 47.147797867655754, 47.355205938220024, 46.20370052754879, 48.7829565256834, 47.15108089148998, 47.63398937880993, 50.535623878240585, 48.30046981573105, 47.36232675611973, 46.818518936634064, 49.491166323423386, 50.858351960778236, 54.677964001894, 50.50815895199776, 48.46677169203758, 49.19165879487991, 49.48400750756264, 47.03532390296459, 46.17761492729187, 47.02523544430733, 51.62321291863918, 49.08297702670097, 48.45622345805168, 46.13445684313774, 58.69388870894909, 61.39260269701481, 65.11732622981071, 66.42392411828041, 66.79867520928383, 62.469909489154816, 65.7348994910717, 68.50397810339928, 64.59653377532959, 65.85416749119759, 68.2265929877758, 63.750904351472855, 72.94663891196251, 35.6725200265646, 0.2661133767105639, 1.587282414548099, 33.90942223370075, 3.457223824225366, 5.281038796529174, 82.46572092175484, 27.739695198833942, 37.25886270403862, 39.572452157735825, 44.660135954618454, 55.34190237522125, 1.3127856189385056, 0.12338064116192982, 0.15212977974442765, 0.12631832883926108, 0.17511643847683445, 0.12368921132292598, 0.17535147664602846, 0.2057466097176075, 0.11688652986777015, 0.13211956364102662, 0.12086562142940238, 0.17035302298609167, 0.19478884380077943, 0.1241859604488127, 0.1739627550705336, 0.1905745136900805, 0.10722306949901395, 0.17194795771501958, 0.14681404310977086, 0.15138781018322334, 0.22036883368855342], [0.05639118950057309, 0.03250521476729773, 0.06271470701904036, 0.04539825691608712, 0.14765212079510093, 0.03846587031148374, 0.03779675367695745, 0.018286090162291657, 0.02764329401543364, 0.04619615101546515, 0.045967884943820536, 0.0728915554645937, 0.05942074021731969, 0.017630640177230816, 0.039060386261553504, 0.04521623035543598, 0.05097588633361738, 0.025627609793446027, 0.062471586861647666, 0.034725813384284265, 0.03841201265458949, 0.036444627403398044, 0.09731001744512469, 0.02292094155563973, 0.055079146623029374, 0.0759949572966434, 0.8506059099454433, 18.041479401290417, 36.62834353744984, 33.46041552722454, 28.297708556056023, 24.747087880969048, 77.61641353368759, 30.11256717145443, 0.4534098686417565, 5.481149358674884, 0.840852486435324, 0.42997002485208213, 0.15091599721927196, 35.52452176809311, 84.74713370203972, 68.71878817677498, 70.00533074140549, 66.19300290942192, 62.554751336574554, 65.89790314435959, 76.85010865330696, 69.087885171175, 73.25303167104721, 68.52184474468231, 70.47651305794716, 71.3397279381752, 67.62685596942902, 70.46060711145401, 70.70402204990387, 67.1529757976532, 56.9487601518631, 49.91345666348934, 50.2060067653656, 50.894605815410614, 49.453020170331, 49.50132317841053, 51.96553274989128, 52.22733870148659, 48.29375557601452, 48.37645813822746, 48.081635758280754, 48.150024488568306, 48.08917075395584, 47.50391095876694, 46.32769927382469, 46.48037128150463, 43.56693461537361, 45.505890771746635, 44.75146785378456, 44.626933336257935, 46.8928999453783, 53.27210783958435, 58.02920937538147, 60.95469519495964, 59.78449858725071, 60.460045337677, 61.18858024477959, 63.01280155777931, 60.375720262527466, 62.21164874732494, 61.15312434732914, 61.79480351507664, 61.530539095401764, 60.532028675079346, 58.04950408637524, 59.2554871737957, 62.65481896698475, 65.39311543107033, 62.76922322809696, 60.931212455034256, 55.26918947696686, 44.5259727537632, 45.63986778259277, 45.71034260094166, 49.291536435484886, 51.58289708197117, 51.59498803317547, 52.05906093120575, 48.87257091701031, 45.32966002821922, 44.45841237902641, 43.05906526744366, 41.94366931915283, 42.57234178483486, 43.765606954693794, 42.90705822408199, 45.64827673137188, 48.46046023070812, 47.439337223768234, 47.14717850089073, 48.12150701880455, 50.27656517922878, 48.210882022976875, 46.78827255964279, 48.41243840754032, 46.226438507437706, 45.578333884477615, 43.79323527216911, 43.300584107637405, 43.11798870563507, 44.06979963183403, 42.61428393423557, 45.78205235302448, 43.140475898981094, 44.031026512384415, 52.6617655903101, 61.55768483877182, 57.18360275030136, 63.0718769878149, 61.91957361996174, 62.23346337676048, 58.87247912585735, 66.09063640236855, 56.81122273206711, 68.83055537939072, 58.553801625967026, 67.68048629164696, 1.7981973406858742, 0.02400623790890677, 0.3424862801330164, 7.564081689342856, 0.3560861956793815, 17.961134612560272, 55.36012999713421, 13.994809594005346, 34.15472947061062, 14.976854547858238, 50.88981047272682, 13.527741506695747, 0.45650174492038786, 0.16580861527472734, 0.10844306380022317, 0.08977203833637759, 0.06900633074110374, 0.055204532472998835, 0.008747999872866785, 0.02284895694174338, 0.050239330739714205, 0.054540970813832246, 0.049016646153177135, 0.060333711735438555, 0.0710417672235053, 0.031324457813752815, 0.08320361579535529, 0.08055101672653109, 0.08776380156632513, 0.10588324803393334, 0.0923672916542273, 0.007046181035548216, 0.0430902555672219, 0.0860753859160468, 0.028876576470793225, 0.034520338667789474, 0.019689192704390734, 0.06599937842111103, 0.0058027395061799325, 0.06080020721128676, 0.01367561832012143, 0.03682994676637463, 0.024949138387455605, 0.09008870532852598, 0.08817513691610657, 0.053148490260355175, 0.060567803666344844, 0.05958771602308843, 0.08952212010626681, 0.08016832085559145, 0.0515081323828781, 0.035410158889135346, 0.03689018318254966, 0.006417293907361454, 0.02266271683765808, 0.09904785270919092, 0.03795340991928242, 0.06939025115570985, 0.040728192470851354, 1.2165851122699678, 28.14665526151657, 44.1323746740818, 40.45733727514744, 37.664832919836044, 34.93775725364685, 87.1353055536747, 32.37488217651844, 0.25266693730372936, 5.6189570389688015, 3.6077620089054108, 1.4099145820364356, 0.14492305082967505, 39.329569190740585, 87.35681086778641, 72.1701429784298, 72.38292396068573, 71.13233506679535, 63.655882850289345, 68.0303107202053, 76.56010821461678, 71.100302785635, 75.71732863783836, 71.55981972813606, 72.34900698065758, 71.08117461204529, 70.51905557513237, 71.41045734286308, 72.7954526245594, 70.87227702140808, 62.25641034543514, 54.43618297576904, 51.79692819714546, 52.29717515408993, 52.10881546139717, 51.310520097613335, 53.81229445338249, 53.14246639609337, 50.4196161031723, 51.621696799993515, 51.7154947668314, 51.19714938104153, 51.279582157731056, 50.038675144314766, 47.81937003135681, 47.995935156941414, 47.1088195592165, 47.77467302978039, 46.71029694378376, 47.61798843741417, 50.34232825040817, 57.038898915052414, 62.77838073670864, 64.04522135853767, 63.34234267473221, 64.51204150915146, 65.09299233555794, 63.394092097878456, 63.23951259255409, 64.32262927293777, 63.452221378684044, 66.02993085980415, 62.84329645335674, 63.70556898415089, 61.576615422964096, 59.52808454632759, 63.979811668395996, 64.4797432422638, 64.7559504210949, 62.22752049565315, 58.0663637816906, 49.188409969210625, 48.44145745038986, 48.58489975333214, 50.16902334988117, 51.85878127813339, 52.65711463987827, 53.01133543252945, 49.0374668687582, 47.27295935153961, 46.70927859842777, 44.368657395243645, 44.514641761779785, 44.23271209001541, 44.28900606930256, 45.680043026804924, 49.05839614570141, 49.331160709261894, 49.99793753027916, 47.551552802324295, 51.06598421931267, 50.61176419258118, 52.01221704483032, 49.82022486627102, 50.93830727040768, 48.483110815286636, 48.25531303882599, 46.03995591402054, 44.73667524755001, 45.6417752802372, 46.03758104145527, 44.55824062228203, 47.658425867557526, 45.76364614069462, 49.0646468102932, 55.93057818710804, 64.24388989806175, 60.205561593174934, 64.49676632881165, 63.82670268416405, 64.92738962173462, 60.09022258222103, 67.96495422720909, 58.69677275419235, 70.26902139186859, 59.87462595105171, 67.9514117538929, 2.060139966197312, 0.23558346962090582, 2.4918317142874002, 6.305863754823804, 0.4825705726398155, 19.90975745022297, 62.9913517087698, 17.91701328009367, 35.155553966760635, 16.45027108490467, 58.43014486134052, 17.060451842844486, 0.44452437199652195, 0.24875984148820862, 0.059394293784862384, 0.07474201163859107, 0.05627546270261519, 0.007225126291814377, 0.03519623111060355, 0.03553034970536828, 0.07264154817676172, 0.02477701764291851, 0.03627854588557966, 0.011349613396305358, 0.024559063713240903, 0.030215119586500805, 0.07348548140726052, 0.04879933418123983, 0.03208217574865557, 0.023307073570322245, 0.09837433142820373, 0.046984738582978025, 0.02472186493832851, 0.22937190136872232, 0.17052861512638628, 0.17544184054713696, 0.12384435729472898, 0.24019799544475973, 0.15883679094258696, 0.12246476413565688, 0.1223923008365091, 0.18159777740947902, 0.10282855335390195, 0.16734787408495322, 0.16709578136214986, 0.14209702669177204, 0.11332764232065529, 0.08580807174439542, 0.18557083531050012, 0.2431861194781959, 0.09794968937058002, 0.08759330798056908, 0.12250753410626203, 0.11603847029618919, 0.17102873360272497, 0.33547755621839315, 0.14190343004884198, 0.22682192648062482, 0.20706884970422834, 1.0496173216961324, 44.71197657287121, 63.185661882162094, 53.203939497470856, 47.35701844096184, 35.9333760291338, 96.24603867530823, 37.99191936850548, 0.5657185125164688, 23.49787451326847, 5.26770768687129, 1.2948946352116764, 0.17154519417090341, 42.2823603451252, 90.38983091711998, 75.8933199942112, 76.23931422829628, 72.93269366025925, 69.74192127585411, 70.7433195412159, 81.85715317726135, 73.94052118062973, 79.23296079039574, 73.8921269774437, 76.03124499320984, 75.64228266477585, 72.97740966081619, 75.13872608542442, 75.96879154443741, 72.61337399482727, 61.63080811500549, 54.05992716550827, 54.8986029624939, 54.5487367361784, 55.836100056767464, 54.107865393161774, 58.277396857738495, 57.41061016917229, 54.78299416601658, 52.64062352478504, 54.82936687767506, 54.29668106138706, 54.54288884997368, 52.229325994849205, 51.43263794481754, 50.65203443169594, 49.64402452111244, 49.374782368540764, 49.750282019376755, 49.9958286434412, 53.79838339984417, 59.52727518975735, 64.67133656144142, 67.90272876620293, 65.21826401352882, 65.19081428647041, 67.29606851935387, 65.48189386725426, 65.36662325263023, 67.08375871181488, 65.44346272945404, 66.8710233271122, 64.94511187076569, 65.38311436772346, 62.99267403781414, 60.744159892201424, 65.65769523382187, 68.48734259605408, 66.55001655220985, 64.3891105055809, 60.035353526473045, 49.92392510175705, 50.84809251129627, 50.853009447455406, 55.056427493691444, 56.37794718146324, 55.97190856933594, 56.5129729360342, 52.788283601403236, 47.69809953868389, 49.26480866968632, 46.838524863123894, 45.707082375884056, 46.73727169632912, 47.31368936598301, 45.68989209830761, 49.934674724936485, 51.8613613396883, 52.8926146030426, 51.66990481317043, 54.24328252673149, 54.046331495046616, 53.812013268470764, 52.740561962127686, 55.88540621101856, 51.8364042788744, 51.24356009066105, 48.11407461762428, 49.217626601457596, 48.42421017587185, 49.155199751257896, 47.58172318339348, 51.357907354831696, 48.65307189524174, 50.551453828811646, 57.26752504706383, 68.76797273755074, 61.7999142408371, 67.851682305336, 66.64245799183846, 69.19921919703484, 63.85112017393112, 70.09757459163666, 59.863883927464485, 74.66828092932701, 59.79560539126396, 70.6982159614563, 3.1405215058475733, 0.1815614418592304, 3.0026627657935023, 19.673655219376087, 0.5434866179712117, 21.86890572309494, 72.85857483744621, 20.739045850932598, 53.462865203619, 24.146712496876717, 68.00999701023102, 26.199896223843098, 0.6302566837985069, 0.3260350035270676, 0.32079472846817225, 0.12891912600025535, 0.14703771157655865, 0.18318258924409747, 0.1271982042817399, 0.13338100688997656, 0.15670378430513665, 0.14600891678128392, 0.091404043341754, 0.12285949022043496, 0.14705406851135194, 0.17498592438641936, 0.20495916134677827, 0.21581363514997065, 0.16915859567234293, 0.22213964257389307, 0.2900260576279834, 0.14447218127315864, 0.1372342079412192], [0.06751509630703367, 0.014796881932852557, 0.0174785314447945, 0.03298095369245857, 0.07712498103501275, 0.03776606958126649, 0.003361510821378033, 0.048453059207531624, 0.052361275666044094, 0.042193221670459025, 0.04992859350750223, 0.039445271468139254, 0.05383255745982751, 0.028566156506713014, 0.054614424880128354, 0.10205306840362027, 0.019346615481481422, 0.033202187914866954, 0.08959377446444705, 0.052775872754864395, 0.02046587993390858, 0.0900953846576158, 0.03179641549650114, 0.06738968819263391, 0.024221124913310632, 0.015388743777293712, 0.3734563698526472, 4.270318681374192, 41.676615849137306, 20.926316902041435, 33.81827272474766, 21.66124116629362, 52.574727460742, 61.53857946395874, 1.1976010934449732, 2.273028055205941, 2.219647094607353, 1.742670563980937, 0.3125725931022316, 5.943203615024686, 75.69354951381683, 76.13744929432869, 72.71728321909904, 68.34354311227798, 70.32826021313667, 72.58357599377632, 72.87359923124313, 77.57299706339836, 72.63254016637802, 71.970866471529, 69.59033221006393, 71.87929898500443, 68.69609579443932, 68.12984257936478, 61.73885531723499, 61.796251237392426, 53.87801192700863, 51.21029667556286, 51.009789034724236, 50.525087043643, 52.0807121694088, 60.67988634109497, 63.77330794930458, 64.27216038107872, 61.81654594838619, 54.79645684361458, 47.03402057290077, 47.30288654565811, 48.55585791170597, 49.26901124417782, 47.00128152966499, 47.33295813202858, 43.818036541342735, 44.224379137158394, 45.306526869535446, 45.24983771145344, 46.65341779589653, 48.519391268491745, 54.1758893430233, 56.53326764702797, 58.088364601135254, 61.33201874792576, 62.60845385491848, 61.805005967617035, 62.07631900906563, 61.89447596669197, 61.926337257027626, 61.15944340825081, 61.465874165296555, 57.21125766634941, 58.37717570364475, 63.783225417137146, 63.36332514882088, 61.976243779063225, 60.27467988431454, 52.23045073449612, 46.660306826233864, 45.243651643395424, 47.849130034446716, 49.828428626060486, 52.935183718800545, 59.34262029826641, 57.93330252170563, 57.95547053217888, 54.770025461912155, 46.32673792541027, 43.835367411375046, 42.76491545140743, 42.753683254122734, 44.56159204244614, 43.740756288170815, 45.6091046333313, 52.09688790142536, 57.925205156207085, 57.61870980262756, 53.43565106391907, 50.60093857347965, 51.183367520570755, 49.7579500079155, 50.00546112656593, 48.90633210539818, 50.50014518201351, 48.456698432564735, 45.840979591012, 43.18831533193588, 44.485117346048355, 43.977251797914505, 43.961490243673325, 42.36669681966305, 43.72075416147709, 43.80051948130131, 46.080461740493774, 53.44563312828541, 61.60262502729893, 61.247336491942406, 62.17742398381233, 59.37722884118557, 65.1632733643055, 59.512095004320145, 64.52503681182861, 57.71480664610863, 69.04153525829315, 21.321556493639946, 0.510909006698057, 0.16614599560853094, 0.8133598929271102, 2.5873875617980957, 0.2664997387910262, 32.590767592191696, 28.597396574914455, 17.79438056051731, 44.11397606134415, 29.348891749978065, 48.05159077048302, 4.023533798754215, 0.05970184720354155, 0.08067772359936498, 0.08662010004627518, 0.05801710518426262, 0.014817433857388096, 0.019207770783395972, 0.04527917189989239, 0.014347174765134696, 0.02047844449407421, 0.015694176508986857, 0.06521394127048552, 0.05862231548235286, 0.023300242100958712, 0.03836861185845919, 0.02358830486627994, 0.06881668232381344, 0.02830984096362954, 0.03648842153779697, 0.07543669154983945, 0.027591750003921334, 0.041644704033387825, 0.022433226222347002, 0.06492266315035522, 0.07582189587992616, 0.026470344455447048, 0.03317326270916965, 0.03869878964906093, 0.06940704595763236, 0.038034868048271164, 0.040784287702990696, 0.08597054271376692, 0.07437534615746699, 0.03215479118807707, 0.018728579016169533, 0.05609985571936704, 0.03254425173508935, 0.054101355926832184, 0.01745404242683435, 0.11923481870326214, 0.03300555588793941, 0.08560140588087961, 0.03600331299821846, 0.12250929299625568, 0.03860274831822608, 0.04321760068705771, 0.026496332611714024, 0.09140533467871137, 0.40337635029572994, 7.446174016222358, 54.533735141158104, 29.743633568286896, 49.518220871686935, 28.60889095813036, 64.71302032470703, 66.89176261425018, 1.2890479364432395, 0.5881674704141915, 4.272008640691638, 3.2331788213923573, 0.2228971230215393, 7.009528046473861, 81.48917332291603, 77.95122876763344, 76.76317691802979, 69.98516142368317, 74.81489226222038, 74.1744290292263, 75.7006399333477, 79.40259888768196, 72.35039010643959, 72.9606981575489, 71.58559754490852, 75.70275261998177, 71.93680509924889, 70.68095728754997, 64.61547955870628, 65.76110288500786, 56.06321007013321, 55.30443258583546, 52.39012956619263, 53.38746204972267, 54.92608688771725, 60.032959654927254, 62.50707149505615, 66.19708389043808, 60.602241307497025, 57.06117331981659, 50.92192254960537, 50.34691080451012, 50.42182758450508, 51.039860621094704, 48.99669885635376, 50.17449885606766, 46.03405103087425, 46.22968353331089, 48.46810542047024, 48.43536637723446, 49.090523421764374, 52.22603157162666, 57.113967686891556, 59.76580359041691, 62.26107269525528, 63.82981091737747, 63.728352561593056, 64.29190412163734, 65.58075696229935, 63.20331193506718, 64.7779968380928, 63.32975775003433, 62.61017136275768, 58.96730303764343, 60.30854366719723, 67.16223210096359, 66.07337772846222, 64.26315486431122, 63.13480921089649, 55.880075097084045, 49.18393760919571, 48.376435339450836, 49.939458668231964, 52.845299541950226, 57.095633670687675, 60.33319294452667, 59.98663254082203, 59.386538341641426, 54.56572562456131, 48.205102533102036, 44.341363459825516, 45.571688041090965, 44.38924089074135, 46.676429361104965, 46.22706927359104, 46.4121725410223, 54.577049016952515, 61.9067607074976, 58.66531804203987, 55.42097233235836, 51.21851943433285, 52.38826006650925, 53.28406199812889, 50.97644962370396, 50.668848529458046, 52.61934086680412, 51.074590757489204, 48.892052471637726, 44.992880299687386, 46.97375200688839, 45.85883863270283, 47.383780404925346, 45.157806649804115, 47.92484097182751, 46.04205720126629, 50.10014824569225, 55.89414954185486, 64.22782436013222, 63.69495615363121, 63.70752967894077, 62.378866374492645, 66.72817379236221, 62.20046974718571, 67.62471288442612, 58.5134781897068, 69.20748755335808, 22.01843149960041, 0.8714161464013159, 0.6638505030423403, 3.110792376101017, 2.895060614682734, 0.3390849876450375, 33.42824645340443, 37.15235821902752, 22.32205990701914, 55.564061254262924, 31.596165262162685, 58.282241597771645, 6.586232660338283, 0.045402038158499636, 0.10673729673726484, 0.0019271820679023222, 0.024532487404940184, 0.045570249640149996, 0.05625870871881489, 0.029219059069873765, 0.08726573141757399, 0.05039431343902834, 0.09008581095258705, 0.1079424555064179, 0.02049067508778535, 0.02666317297553178, 0.025268163553846534, 0.02144721624063095, 0.07217588761704974, 0.028595638323167805, 0.08254228800069541, 0.01280915812458261, 0.02836209001543466, 0.03127166513877455, 0.12902899354230613, 0.15107273880857974, 0.18129312578821555, 0.0682043882261496, 0.1582642536959611, 0.12238893890753388, 0.14423616346903145, 0.18383619870292023, 0.18883460783399642, 0.23238782625412568, 0.1710387525963597, 0.16265249869320542, 0.14246125792851672, 0.19773033127421513, 0.14230033062631264, 0.2360672311624512, 0.06951594128622673, 0.18475349323125556, 0.2261708996957168, 0.15178235073108226, 0.1624707764131017, 0.22139258187962696, 0.08184904043446295, 0.2019705474958755, 0.1256367700989358, 0.24126931530190632, 0.47999018453992903, 15.503169056028128, 80.82727164030075, 37.10391461849213, 57.14666113257408, 32.15023063123226, 70.15007257461548, 77.0957350730896, 1.5711528738029301, 8.999884519726038, 7.267325213178992, 3.2155575044453144, 0.3362651530187577, 8.199746254831553, 87.79702484607697, 80.72253406047821, 81.46970316767693, 74.83567714691162, 78.6175686120987, 77.61604115366936, 78.70944768190384, 81.80989891290665, 75.71466878056526, 75.0800496339798, 74.7703966498375, 76.22568055987358, 77.04473420977592, 74.52947437763214, 68.53880703449249, 67.09026396274567, 59.7732587903738, 57.95597970485687, 56.11529767513275, 56.59941449761391, 58.58057118952274, 65.77776119112968, 67.80543118715286, 69.1705459356308, 66.51226937770844, 61.11157737672329, 54.11398686468601, 51.87819063663483, 53.58783669769764, 53.70670571923256, 51.988593712449074, 51.70355200767517, 47.83594474196434, 48.53518322110176, 50.378490909934044, 51.5910704433918, 53.50358761847019, 55.03212779760361, 59.70876105129719, 63.18653583526611, 64.1176226735115, 66.98984295129776, 67.14506462216377, 65.66239178180695, 69.12139177322388, 65.35506427288055, 64.91203084588051, 67.20824763178825, 65.6012986600399, 60.78811973333359, 62.5873763859272, 68.1803722679615, 68.52979391813278, 66.80154785513878, 64.63258624076843, 56.035577952861786, 51.71148598194122, 51.6033323854208, 53.50524812936783, 56.64106026291847, 58.1256178021431, 65.63051149249077, 64.53573703765869, 62.284281849861145, 58.96484836935997, 50.90819388628006, 47.56935104727745, 47.410344779491425, 47.079333141446114, 50.87558403611183, 47.79733121395111, 50.868254229426384, 57.722239047288895, 65.88458105921745, 61.86090476810932, 57.9716082662344, 54.902383759617805, 55.916074365377426, 56.09147675335407, 55.04342459142208, 53.96558202803135, 56.605467572808266, 54.507280960679054, 49.13366250693798, 47.202199548482895, 50.56646682322025, 49.71933268010616, 49.78884235024452, 47.980690374970436, 50.42462423443794, 50.521895214915276, 53.56955587863922, 59.244102984666824, 68.70988145470619, 66.81806176900864, 67.53018915653229, 64.62607339024544, 69.59603190422058, 63.734166249632835, 69.72009524703026, 58.02192136645317, 72.46604830026627, 26.76514819264412, 0.5661114351823926, 0.5370725027751178, 4.773092502728105, 9.440196342766285, 0.3708808799274266, 38.85076068341732, 40.47544710338116, 28.573687747120857, 63.24005976319313, 39.31930974125862, 68.3124227821827, 11.443335805088282, 0.5362398724537343, 0.21840318135218695, 0.2499038918176666, 0.11387623046175577, 0.10579186739050783, 0.2717511757509783, 0.10679768529371358, 0.1513235253514722, 0.194772650138475, 0.176285543711856, 0.15028129768325016, 0.17354675161186606, 0.18846875871531665, 0.1344910668558441, 0.13817332161124796, 0.13344873528694734, 0.09523742162855342, 0.10478365235030651, 0.13079254422336817, 0.08672873562318273, 0.12163417472038418], [0.05984826922940556, 0.012462463837437099, 0.03150581273075659, 0.05058598791947588, 0.0014367792323355388, 0.05499841208802536, 0.09153901773970574, 0.10608057025820017, 0.06641785323154181, 0.027540256087377202, 0.07045277656288818, 0.02621902727696579, 0.02465624795149779, 0.018804621322487947, 0.022248960231081583, 0.002148003354704997, 0.038141225231811404, 0.0244206958450377, 0.06855582483694889, 0.02047705667791888, 0.05298032330756541, 0.05968881509033963, 0.05878255258721765, 0.06237720052013174, 0.05196114303544164, 0.03488175345410127, 0.18506001506466419, 0.693840334424749, 15.72713378816843, 31.598395742475986, 25.773030929267406, 26.736495830118656, 25.010377652943134, 80.28384760022163, 9.31668872013688, 1.213263615500182, 3.0445521930232644, 1.2663455796428025, 0.18445911293383688, 0.44483729114290327, 18.72944388538599, 86.78868055343628, 71.94621339440346, 79.3422657251358, 71.50203242897987, 72.74663284420967, 73.42225939035416, 74.29995149374008, 73.84296521544456, 73.87302920222282, 71.60017356276512, 71.24092563986778, 63.67245756089687, 63.13840761780739, 59.02084596455097, 51.0058980435133, 52.09203936159611, 51.825837045907974, 51.18207938969135, 53.356740698218346, 59.99731756746769, 65.94375148415565, 65.76966002583504, 66.50195673108101, 64.11700710654259, 59.30510491132736, 57.33357310295105, 52.66366928815842, 49.25338268280029, 48.07740658521652, 48.72116804122925, 45.6214539706707, 46.206774562597275, 44.22698199748993, 45.64369797706604, 45.58880992233753, 46.41267031431198, 46.7252491414547, 49.785319939255714, 52.93419577181339, 53.47764641046524, 54.56910364329815, 57.70188353955746, 58.68008404970169, 62.240128219127655, 60.94627104699612, 63.04647155106068, 60.52292436361313, 65.88790968060493, 57.89618991315365, 60.90237580239773, 62.175102308392525, 61.5277386456728, 61.26135013997555, 55.74903152883053, 49.23482067883015, 45.95813870429993, 49.7234820574522, 52.50370167195797, 59.613393768668175, 58.06485526263714, 62.58191607892513, 60.805575996637344, 61.796498224139214, 61.608754098415375, 54.10028859972954, 45.300086215138435, 42.87753380835056, 41.49286910891533, 42.40941412746906, 43.501353934407234, 48.0568914860487, 63.307004570961, 61.19908668100834, 63.17963920533657, 55.44240318238735, 52.32866406440735, 50.74177421629429, 51.34257897734642, 51.61253549158573, 50.341385900974274, 48.461379781365395, 50.46888045966625, 49.097393453121185, 46.765910759568214, 45.33463396131992, 45.79580381512642, 45.21400563418865, 46.60717807710171, 45.14192350208759, 44.03646022081375, 43.17626237869263, 49.029418900609016, 55.14672964811325, 60.62762774527073, 60.6272591650486, 63.76510038971901, 62.80302621424198, 69.81148034334183, 55.68901754915714, 73.65805953741074, 24.35268994420767, 0.29526475933380425, 0.2948314935201779, 0.14052806713152677, 2.1621948899701238, 2.0626644557341933, 0.19133272144244984, 37.658213675022125, 21.892249770462513, 33.32457281649113, 62.34909497201443, 44.660101756453514, 37.05582819879055, 1.720945229753852, 0.10140049053006805, 0.1050829234009143, 0.02951523165393155, 0.0998901977436617, 0.05941996838373598, 0.043291796901030466, 0.13547537731938064, 0.034662111138459295, 0.09113368636462837, 0.014364585549628828, 0.027067997834819835, 0.12372031473205425, 0.0338945745897945, 0.07357610506005585, 0.05184134184673894, 0.062030150002101436, 0.0972449459368363, 0.005239673919277266, 0.0521311245393008, 0.01523730668850476, 0.03281206685642246, 0.029744186067546252, 0.0431505661981646, 0.016870552935870364, 0.03717388026416302, 0.008696475342730992, 0.08803208052995615, 0.016731674841139466, 0.054807839696877636, 0.08283747723908164, 0.07807204310665838, 0.0335394235298736, 0.03762853106309194, 0.06371774928993545, 0.07199900413979776, 0.042274379229638726, 0.06542783565237187, 0.06846009520813823, 0.02386854168435093, 0.021068318310426548, 0.031620025547454134, 0.07404320538626052, 0.028888753258797806, 0.062060203272267245, 0.07060968142468482, 0.05497961719811428, 0.06289794328040443, 0.20406944502610713, 1.2300248723477125, 35.650359615683556, 35.16620099544525, 30.312314853072166, 31.502137407660484, 36.06738343834877, 87.64506340026855, 9.999245144426823, 0.8588681509718299, 4.1343961749225855, 3.693996244110167, 1.6495055006816983, 0.5586619942914695, 22.92899563908577, 88.80828738212585, 74.76767599582672, 83.91333684325218, 74.88877549767494, 77.84643799066544, 73.68534207344055, 73.16842541098595, 75.33275127410889, 75.62632352113724, 73.37391078472137, 73.3845654129982, 67.64977633953094, 67.66295403242111, 61.80719085037708, 54.071455746889114, 54.98980946838856, 54.498628824949265, 54.47906367480755, 55.39316162467003, 61.62726670503616, 69.52832713723183, 67.78823330998421, 67.6402160525322, 66.61310076713562, 62.19429507851601, 60.34329280257225, 54.66902308166027, 53.94923910498619, 51.0344535112381, 51.37212239205837, 46.70777007937431, 47.84818388521671, 45.998724326491356, 47.648075222969055, 48.526664078235626, 49.29833047091961, 49.845330119132996, 53.965578228235245, 57.141554206609726, 58.20901572704315, 59.96514089405537, 60.53829073905945, 61.39411881566048, 62.900665774941444, 62.44755528867245, 64.99618113040924, 64.53895926475525, 66.38118401169777, 60.046939104795456, 62.73751012980938, 65.33763840794563, 62.02283687889576, 62.250049486756325, 58.772312700748444, 52.01173447072506, 47.343570962548256, 51.07046037912369, 53.15244846045971, 60.637906193733215, 60.37199266254902, 62.7032245695591, 62.636500149965286, 64.29999768733978, 63.45216438174248, 55.209794864058495, 46.11978203058243, 44.0893229842186, 44.07642647624016, 43.908479288220406, 45.29654860496521, 49.77826751768589, 63.274896293878555, 64.67384442687035, 65.31160220503807, 59.58120949566364, 55.65979331731796, 54.5200102776289, 53.81784975528717, 54.2814476788044, 52.29353114962578, 52.53478780388832, 51.89998246729374, 50.88951028883457, 49.640407115221024, 48.25889624655247, 47.992446944117546, 46.262452974915504, 48.572455421090126, 46.733000725507736, 49.0867730230093, 45.48838511109352, 53.159219697117805, 57.242294400930405, 62.367246598005295, 62.0979056507349, 66.65245905518532, 62.90060497820377, 72.77151390910149, 59.47215914726257, 73.98598194122314, 25.659221336245537, 0.48518759314902127, 0.7087975193280727, 0.6147471629083157, 4.943534256890416, 0.5998619960155338, 0.16956272476818413, 45.66550500690937, 28.29985924065113, 41.00339837372303, 75.73335617780685, 48.160424530506134, 47.884810119867325, 2.555108293890953, 0.15522775647696108, 0.06009134114719927, 0.09331850975286216, 0.10100910410983488, 0.035171094568795525, 0.057368226916878484, 0.06422421312890947, 0.042545700998743996, 0.02456310099660186, 0.04117547745408956, 0.010794137197081, 0.05483625653141644, 0.01835308754380094, 0.03193089636624791, 0.01576861021021614, 0.01674016129982192, 0.04898455568763893, 0.03737564795301296, 0.05691156860848423, 0.02721971322898753, 0.03232714385376312, 0.13084093225188553, 0.14554125984432176, 0.08236821726313792, 0.11602765720454045, 0.06013669750245754, 0.17340927617624402, 0.22965847427258268, 0.1846675673732534, 0.19827245530905202, 0.13448331883409992, 0.16388495365390554, 0.11893401140696369, 0.22760689607821405, 0.1339596149045974, 0.12094987745513208, 0.1472837632172741, 0.13027784996666014, 0.1609936502063647, 0.09428383607883006, 0.11403333570342511, 0.12183687009382993, 0.19605272129410878, 0.11582187449675985, 0.10509600004297681, 0.2375664288410917, 0.31605973723344505, 0.25284576520789415, 1.5134743438102305, 60.476958230137825, 52.9183354228735, 43.7958799302578, 41.643899604678154, 38.61494533717632, 98.44242721796036, 12.075277045369148, 2.7339188614860177, 12.42071270942688, 6.369417244568467, 2.3814690113067627, 0.544935290236026, 23.724836334586143, 90.4396690428257, 77.20921218395233, 87.94810473918915, 79.34913575649261, 81.29711642861366, 77.39594176411629, 75.2723877131939, 77.97715097665787, 77.29928255081177, 77.10463419556618, 76.03346407413483, 68.62089782953262, 70.58679834008217, 64.6665108203888, 56.51709571480751, 57.20722608268261, 58.40399466454983, 56.3152277469635, 59.08989205956459, 66.54176339507103, 71.44472390413284, 68.77658307552338, 71.71438783407211, 68.60585823655128, 66.64847686886787, 62.54005752503872, 58.98196265101433, 56.06722265481949, 54.12876807153225, 53.74930903315544, 49.105034843087196, 51.844395250082016, 48.99350322782993, 50.933340936899185, 52.73189462721348, 52.18317747116089, 52.244718968868256, 56.26584939658642, 58.854095712304115, 61.17213472723961, 61.436315551400185, 60.64023166894913, 65.28371930122375, 68.6177060008049, 66.27994984388351, 69.4438348710537, 68.1830245256424, 69.95115324854851, 62.649491652846336, 61.56893603503704, 65.95883667469025, 63.550974279642105, 63.98694768548012, 59.9733180552721, 54.08237636089325, 49.63723048567772, 54.49487082660198, 55.50569258630276, 64.73032459616661, 63.062609285116196, 66.49624183773994, 65.61773657798767, 65.75829103589058, 65.0559975206852, 57.613393887877464, 48.57666179537773, 46.29086025059223, 45.600904673337936, 48.01567129790783, 49.84917551279068, 53.509773686528206, 65.96173971891403, 65.80831155180931, 67.5796777009964, 61.357348188757896, 59.35153841972351, 56.20219141244888, 55.215008184313774, 57.58252814412117, 55.21701067686081, 55.46664588153362, 56.297927275300026, 52.549120634794235, 51.451591327786446, 50.417020842432976, 49.24376159906387, 50.65161645412445, 53.90823930501938, 50.49553602933884, 52.105182856321335, 49.17853429913521, 55.54015673696995, 61.33956894278526, 66.1621105670929, 65.66387370228767, 68.18908900022507, 66.3846418261528, 75.41862666606903, 59.85854521393776, 76.35754868388176, 30.270218811929226, 0.22805619228165597, 0.615069551859051, 0.4786025465000421, 9.644584525376558, 7.056620344519615, 0.26648994244169444, 49.950865656137466, 32.33401916921139, 47.327475026249886, 71.39219552278519, 54.34381753206253, 61.62439785897732, 4.467728063464165, 0.4779641213826835, 0.33700266969390213, 0.22736121551133692, 0.2890808880329132, 0.19098119577392936, 0.19706679187947884, 0.2016398316482082, 0.15770737576531246, 0.1678262179484591, 0.1768986022216268, 0.15606601227773353, 0.19700405071489513, 0.21485850593307987, 0.22116364416433498, 0.09074448928004131, 0.11017276512575336, 0.20353817119030282, 0.12909749377286062, 0.15691093256464228, 0.1222892981604673, 0.16654111503157765], [0.03897302063705865, 0.01829737451771507, 0.017990147644013632, 0.03161167638609186, 0.037415913175209425, 0.04915270779747516, 0.044578914748854004, 0.07720959329162724, 0.08738141739740968, 0.024178724161174614, 0.03305472317151725, 0.01721920278214384, 0.06643597647780553, 0.09423195995623246, 0.020336148809292354, 0.03462677377683576, 0.08466510495054536, 0.03988577693235129, 0.06851416066638194, 0.034578304112073965, 0.054937010499997996, 0.06993237519054674, 0.04063942047650926, 0.06735407252563164, 0.09490753698628396, 0.0050877405192295555, 0.11797077793744393, 0.26758199790492654, 8.058944810181856, 20.70665828883648, 24.710699133574963, 68.7719701230526, 23.294562622904778, 49.535867124795914, 38.6709239333868, 0.3695755609078333, 3.897000113502145, 1.8976732715964317, 0.3055481653427705, 0.1464198439498432, 0.24561130965594202, 36.380194053053856, 91.53793171048164, 69.68164891004562, 79.11689221858978, 75.56108862161636, 77.83193036913872, 73.56868833303452, 78.09363752603531, 71.3635602593422, 68.27537477016449, 65.94050645828247, 61.71495079994202, 55.209160298109055, 51.58573932945728, 53.014675453305244, 53.69429178535938, 54.64034982025623, 52.959905192255974, 56.903291791677475, 63.96629959344864, 70.02727836370468, 69.52174589037895, 66.1639192700386, 65.74354782700539, 66.90499350428581, 62.424923703074455, 58.2454139739275, 53.62589545547962, 48.473033756017685, 45.673663169145584, 48.33191692829132, 46.47329606115818, 45.65604731440544, 45.00567801296711, 45.72244115173817, 43.737146481871605, 46.977589800953865, 49.694166630506516, 54.374690875411034, 54.02757950127125, 57.655697017908096, 53.27953264117241, 54.12784092128277, 56.34006321430206, 57.67567254602909, 59.22939017415047, 62.50250793993473, 61.20517395436764, 63.389520943164825, 62.796023190021515, 64.31745395064354, 59.438006579875946, 58.30352805554867, 51.26108855009079, 52.59621150791645, 53.443376049399376, 57.89535015821457, 58.88779990375042, 58.58467496931553, 62.15457201004028, 63.411498963832855, 58.75785067677498, 62.36966326832771, 62.52045437693596, 59.476756900548935, 45.395647287368774, 43.65210324525833, 42.848355174064636, 45.07044553756714, 43.166485503315926, 52.45171666145325, 61.581399366259575, 63.024938106536865, 62.217325642704964, 60.87041951715946, 56.53501555323601, 54.45821039378643, 51.81993216276169, 52.60562740266323, 50.15367977321148, 51.026131957769394, 48.537493497133255, 49.396042227745056, 48.18695850670338, 49.29362632334232, 46.80419750511646, 49.55988563597202, 43.6508759111166, 45.53640313446522, 45.529669895768166, 49.563343450427055, 44.49584797024727, 48.09841945767403, 51.2852780520916, 58.877969831228256, 60.07096141576767, 68.14457058906555, 59.25391785800457, 72.66961857676506, 48.62452022731304, 0.2561772661283612, 0.01824393060815055, 0.23990830552065745, 0.8794765232596546, 4.726621471345425, 1.7450847406871617, 4.646462872624397, 30.909566804766655, 24.755531027913094, 34.422786086797714, 25.857382602989674, 53.253150656819344, 22.952326387166977, 0.1523592963349074, 0.08223808166803792, 0.1033137620834168, 0.008698936489963671, 0.034105400191037916, 0.07250166076119058, 0.15411855740239844, 0.015867961519688834, 0.01686622064880794, 0.03354173903062474, 0.03597733040805906, 0.052934146879124455, 0.021777779948024545, 0.08568742821807973, 0.011833386070065899, 0.0635932688601315, 0.05089901096653193, 0.020309835963416845, 0.07815986144123599, 0.013396438134805067, 0.07347207822022028, 0.10540081493672915, 0.019490005834086332, 0.08410303940763697, 0.03560826036846265, 0.04133394824748393, 0.07380213355645537, 0.01013503955618944, 0.06985617888858542, 0.01801472571969498, 0.03159412088280078, 0.11570139424293302, 0.01583625140483491, 0.029291492683114484, 0.10550712016993202, 0.1041370710299816, 0.05275127798086032, 0.057603343011578545, 0.03751558360818308, 0.04813303028640803, 0.06965965818380937, 0.06622939225053415, 0.03276884417573456, 0.024732822748774197, 0.059314297686796635, 0.05161279004823882, 0.08977692908956669, 0.06453984111431055, 0.0068532263503584545, 0.2827947784680873, 3.915807204321027, 37.77866341173649, 27.391939759254456, 63.87723997235298, 32.10786670446396, 71.9304670393467, 39.54715311527252, 0.26677373971324414, 1.9498840137384832, 2.5313158705830574, 2.267468716017902, 0.34194412641227245, 0.11847805071738549, 43.54511618614197, 93.6096565425396, 71.58038422465324, 82.87454098463058, 76.17666319012642, 77.04167917370796, 74.17747646570206, 79.66750547289848, 70.90872466564178, 71.44552186131477, 68.12260016798973, 64.57775518298149, 57.49874264001846, 55.06876543164253, 56.60151578485966, 57.43555963039398, 56.14037252962589, 55.06089985370636, 59.59250248968601, 66.69944733381271, 70.25310784578323, 71.66100829839706, 68.72672975063324, 67.70358145236969, 67.26777523756027, 65.45044675469398, 59.72226932644844, 54.36645671725273, 50.968105271458626, 49.7712454944849, 50.212553814053535, 48.352929800748825, 47.84634858369827, 47.946970984339714, 47.60677523910999, 48.29475872218609, 49.79459524154663, 52.5042450428009, 56.79588295519352, 55.23447073996067, 57.91519269347191, 56.00530117750168, 58.423081040382385, 58.53399708867073, 61.580825597047806, 59.542383179068565, 63.06906133890152, 63.655111491680145, 65.98790511488914, 65.32409593462944, 66.204394698143, 63.41081500053406, 62.14571848511696, 52.482388615608215, 53.37004758417606, 52.387940883636475, 57.77543619275093, 61.46154999732971, 61.72015652060509, 62.08813637495041, 64.80684489011765, 61.1694672703743, 65.55956169962883, 62.92683497071266, 60.13980612158775, 45.98927043378353, 45.12586176395416, 46.51535980403423, 47.5753091275692, 45.177280604839325, 54.17307749390602, 63.80027890205383, 66.24986305832863, 62.916085347533226, 62.72187016904354, 58.32581005990505, 55.40003165602684, 55.01546189188957, 54.622676968574524, 53.10101442039013, 53.08602422475815, 51.72131985425949, 52.015496268868446, 50.663008242845535, 51.58210672438145, 49.977551624178886, 52.90345162153244, 47.46536582708359, 48.725271821022034, 47.60691203176975, 52.77511350810528, 46.87271162867546, 51.312328800559044, 55.621593967080116, 60.16660988330841, 62.68532752990723, 72.27336823940277, 62.397139593958855, 72.84531354904175, 52.35398210585117, 0.16359763860236853, 0.9358004853129387, 3.3856240287423134, 1.0719672474078834, 3.433886426500976, 1.407131825108081, 4.762449748814106, 39.36398774385452, 31.85206063091755, 43.55958200991154, 22.91820041835308, 60.907201543450356, 29.35623485594988, 0.28089992702007294, 0.11076034570578486, 0.05452609075291548, 0.016443916356365662, 0.04780468560056761, 0.07739771288470365, 0.03527846478391439, 0.009467338568356354, 0.02758878326858394, 0.02313729430170497, 0.03465251145826187, 0.022985558498476166, 0.01474432674513082, 0.041020112548721954, 0.021918921593169216, 0.027733891693060286, 0.040298414751305245, 0.019959518140240107, 0.1301168484496884, 0.09433266939595342, 0.020466698151722085, 0.011580729315028293, 0.1464294028119184, 0.16670564917149022, 0.15472161176148802, 0.11681989984936081, 0.2242189325625077, 0.1717188418842852, 0.11423040559748188, 0.15757898421725258, 0.13257452985271811, 0.18455762561643496, 0.12514579488197342, 0.11736933403881267, 0.19393127731746063, 0.17705190024571493, 0.2324267296353355, 0.13211907382356003, 0.12343172318651341, 0.14719725848408416, 0.16644341871142387, 0.16618826834019274, 0.16236917639616877, 0.1570218984852545, 0.1599884408642538, 0.22796302306232974, 0.20645072974730283, 0.14498804812319577, 0.16587744205025956, 0.4215714958263561, 16.7279601842165, 64.99435722827911, 42.918575406074524, 88.47148105502129, 36.74856148660183, 69.10998478531837, 46.64328753948212, 0.27304331422783434, 13.785258438438177, 9.646078795194626, 3.067498211748898, 0.22072772146202624, 0.2609982871217653, 47.07861877977848, 96.99225783348083, 75.052440315485, 86.13624036312103, 79.61707457900047, 79.46916371583939, 77.2493988275528, 80.85793599486351, 76.38894259929657, 74.65907022356987, 71.0124970972538, 66.34864255785942, 61.33204534649849, 58.39609868824482, 61.16676941514015, 58.730826526880264, 61.120028123259544, 57.723910957574844, 63.11750873923302, 68.67975667119026, 73.68265941739082, 74.33175578713417, 72.41691693663597, 70.67690670490265, 73.49893927574158, 69.62672665715218, 62.607025131583214, 57.67970032989979, 54.98502932488918, 52.28268273174763, 53.11749033629894, 50.80383628606796, 51.9173589348793, 51.04811757802963, 48.88511784374714, 49.81462016701698, 53.4909874945879, 56.079321205616, 59.438614547252655, 57.618333622813225, 63.388783782720566, 56.84410236775875, 60.69202668964863, 62.024668380618095, 63.92917558550835, 64.46933180093765, 67.75861009955406, 67.87744492292404, 69.34972912073135, 65.21632611751556, 69.42767813801765, 64.02602478861809, 64.84675034880638, 56.18998646736145, 58.570874109864235, 57.40296497941017, 60.94418115913868, 64.34684157371521, 64.63372617959976, 65.22703394293785, 68.33333685994148, 63.32586295902729, 65.43463200330734, 64.84669715166092, 63.36673356592655, 47.25281283259392, 47.971840649843216, 48.19120667874813, 51.53374291956425, 48.10302101075649, 56.52719557285309, 66.94543093442917, 69.15711745619774, 66.0168519616127, 64.48278307914734, 60.55149123072624, 58.90106879174709, 58.72229978442192, 58.15576918423176, 56.44724406301975, 55.80492652952671, 54.97244819998741, 53.94322022795677, 52.10932083427906, 55.27521215379238, 54.03290681540966, 55.8821801841259, 50.00339783728123, 52.259595170617104, 52.25071124732494, 57.33312852680683, 50.0730898976326, 54.52365808188915, 57.749715372920036, 63.07657353579998, 66.35893240571022, 74.76633846759796, 64.17469561100006, 75.78684210777283, 54.60257224738598, 0.9917292091995478, 0.5958016763906926, 1.7697410238906741, 3.2948317006230354, 15.336116719990969, 3.4668230591341853, 5.3291636891663074, 42.18586452305317, 37.49103404581547, 47.608029171824455, 34.416132643818855, 72.39693760871887, 40.86166597902775, 0.40873818914406, 0.25218786613550037, 0.15199620800558478, 0.09846793851465918, 0.15326152526540682, 0.12774188682669774, 0.1892115149530582, 0.09566267966874875, 0.21742037002695724, 0.13321417209226638, 0.10814115070388652, 0.0865042804798577, 0.12529417988844216, 0.19664390129037201, 0.10234410903649405, 0.2552020247094333, 0.17724416102282703, 0.13619885256048292, 0.1620077356346883, 0.25810453458689153, 0.18894607841502875, 0.22181818872923031], [0.05686710283043794, 0.10420143749797717, 0.057587175324442796, 0.049010645889211446, 0.009598274755262537, 0.08286282900371589, 0.017145130877906922, 0.0375452583830338, 0.04863520080107264, 0.01584005862241611, 0.01443141223717248, 0.015477219840249745, 0.05960250331554562, 0.028138972593296785, 0.021516180313483346, 0.038971784961177036, 0.07827793713659048, 0.0684894248843193, 0.06067678434192203, 0.029285069394973107, 0.05294759830576368, 0.05320524600392673, 0.08853505627484992, 0.05449477212096099, 0.06362120329868048, 0.02795417225570418, 0.05153737300133798, 0.16036482847994193, 2.7375395921990275, 2.8166033746674657, 25.629225745797157, 34.91211622953415, 47.45219573378563, 20.875808112323284, 58.06114286184311, 2.286703046411276, 1.2435236480087042, 1.6577518894337118, 0.505759451771155, 0.09665633377153426, 0.10324450486223213, 0.2651392633561045, 55.90173773467541, 87.08456307649612, 72.24931553006172, 74.7965620458126, 79.15356025099754, 78.72415289282799, 72.18209713697433, 71.3597984611988, 65.11626228690147, 58.078211545944214, 53.10352608561516, 55.12736588716507, 53.57471600174904, 53.90874847769737, 51.86802238225937, 53.222908079624176, 53.73833902180195, 61.618967950344086, 66.5465435385704, 69.63076964020729, 69.37968671321869, 69.89687696099281, 63.50536152720451, 64.39387544989586, 64.55873340368271, 63.81381377577782, 57.780953496694565, 49.53233331441879, 48.27977992594242, 47.12128669023514, 45.597173273563385, 47.115127220749855, 45.87419740855694, 45.02182714641094, 45.27564972639084, 46.257232055068016, 47.205064594745636, 48.75604636967182, 51.31156504154205, 52.03194558620453, 52.23655320703983, 52.24559672176838, 50.826426073908806, 51.69803850352764, 57.804424837231636, 59.3787145614624, 62.98947460949421, 64.11774426698685, 64.55724388360977, 63.73622573912144, 58.26603926718235, 58.29284682869911, 54.359221905469894, 59.49762538075447, 59.145179092884064, 61.05265013873577, 61.585275158286095, 63.457932472229004, 61.50403551757336, 66.23280957341194, 59.742906019091606, 54.286547005176544, 66.2893657386303, 61.17901995778084, 48.117224648594856, 42.006236761808395, 41.805113554000854, 43.12824435532093, 44.04944412410259, 51.94680355489254, 63.618272468447685, 65.69436326622963, 66.07460126280785, 60.32930575311184, 59.16411727666855, 53.86321172118187, 55.07901348173618, 53.54018725454807, 51.80884815752506, 52.6623697578907, 49.28636111319065, 52.16669775545597, 49.74047474563122, 50.152201652526855, 48.0145313590765, 48.57267960906029, 47.95696064829826, 49.86375913023949, 46.50450758635998, 47.78412312269211, 50.17631895840168, 49.342978075146675, 49.5307943969965, 58.47260758280754, 57.592289820313454, 66.8882592022419, 60.3090376406908, 75.5258721113205, 23.364927247166634, 0.07116778389899991, 0.6731103686615825, 0.6225364480633289, 1.0338149196468294, 2.0315018529072404, 0.14183530089212582, 3.988700592890382, 20.711979903280735, 32.96162769198418, 30.70210173726082, 33.256157487630844, 49.88827161490917, 3.492982992902398, 0.07765420654322952, 0.04109482455532998, 0.05276907468214631, 0.031046158001117874, 0.03542001089954283, 0.04321589745813981, 0.01267131161512225, 0.05536043914617039, 0.07414191102725454, 0.019168603939760942, 0.010751127883850131, 0.057696582734934054, 0.0497467190871248, 0.019246622214268427, 0.059138315918971784, 0.02283245157741476, 0.05668767378665507, 0.005495926379808225, 0.06790524334064685, 0.02835133629560005, 0.06347182381432503, 0.02299986339494353, 0.08284304334665649, 0.006421471734938677, 0.08859105873852968, 0.03719288666616194, 0.02096910244290484, 0.06091428644140251, 0.11344941391143948, 0.04636947960534599, 0.02546568059187848, 0.00729787531781767, 0.09240274404874071, 0.1062355974863749, 0.030031269197934307, 0.05390283513406757, 0.01298726243476267, 0.01497283679782413, 0.051671571854967624, 0.11129098129458725, 0.11623533981037326, 0.03577838288038038, 0.04969449044438079, 0.04016488754132297, 0.04243761832185555, 0.039766376503393985, 0.039916731911944225, 0.08379993887501769, 0.13714608532609418, 0.10405510081909597, 4.561492307111621, 26.07735849916935, 37.00315162539482, 52.3784451931715, 50.57723544538021, 31.628509126603603, 66.50421380996704, 2.3077002447098494, 1.350737032480538, 2.831642492674291, 3.149278135970235, 1.8905807146802545, 0.14229500200599432, 0.9928801911883056, 60.108499601483345, 88.27115580439568, 72.10100948810577, 75.22071808576584, 80.53067475557327, 81.31691336631775, 71.82410314679146, 77.24411711096764, 68.09725552797318, 60.293602868914604, 55.506779327988625, 59.2018948495388, 56.0842115432024, 56.1177409440279, 52.71376959979534, 56.189792677760124, 56.764709427952766, 64.00792255997658, 68.622767329216, 72.900919765234, 69.87184390425682, 71.28146946430206, 65.79533904790878, 69.23993021249771, 67.41149872541428, 65.62688648700714, 61.68782025575638, 52.44129002094269, 51.40984296798706, 49.159580916166306, 47.406563982367516, 47.526675537228584, 46.90341018140316, 48.17109815776348, 48.947438299655914, 48.36103856563568, 49.74230244755745, 53.240083158016205, 55.13721875846386, 56.670767068862915, 55.44670455157757, 57.14080184698105, 53.72165031731129, 56.497652158141136, 59.00193817913532, 62.459087669849396, 63.51465202867985, 65.44443547725677, 66.30213305354118, 66.79123520851135, 60.31780757009983, 59.35750029981136, 56.48078106343746, 61.4774065464735, 61.17249570786953, 63.64894062280655, 62.96490132808685, 64.87142622470856, 65.0526537001133, 69.46560770273209, 62.59717985987663, 57.07975052297115, 66.94068878889084, 62.998989298939705, 49.27844613790512, 44.08501401543617, 45.4104170948267, 45.356904566287994, 45.41697934269905, 55.618101954460144, 64.93979975581169, 68.16565945744514, 65.91750249266624, 63.69446977972984, 61.96770943701267, 55.49157254397869, 56.90033555030823, 56.923590302467346, 54.09291319549084, 53.85196812450886, 52.403238862752914, 52.357603311538696, 52.2532495111227, 54.377084746956825, 50.93342073261738, 51.05239994823933, 49.345523938536644, 53.721160143613815, 48.70642103254795, 49.687965363264084, 53.38818781077862, 52.40071199834347, 50.87866947054863, 60.43623201549053, 60.60258328914642, 70.44163852930069, 63.73369127511978, 77.22071036696434, 25.237301476299763, 0.032525453134439886, 2.9625364439561963, 5.301516847684979, 4.82844365760684, 0.24883539212169126, 0.45970547769684345, 5.3857179544866085, 28.58184400945902, 42.19325132668018, 33.37000697851181, 31.479114443063736, 60.495387241244316, 4.124385137110949, 0.16733543568989262, 0.03378878885996528, 0.06234633459826, 0.04670429952966515, 0.07368891150690615, 0.03608018836530391, 0.03489831076876726, 0.03444023495831061, 0.058897129056276754, 0.08497386806993745, 0.0527837951813126, 0.07123206130927429, 0.05904582576476969, 0.011769728353101527, 0.06640014558797702, 0.027034744052798487, 0.01004430087050423, 0.01946512533322675, 0.0630641398311127, 0.009554418465995695, 0.005281721687424579, 0.014435287175729172, 0.21471261454280466, 0.13844295870512724, 0.1519691789872013, 0.09645268102758564, 0.1306139538064599, 0.18505657149944454, 0.22973632556386292, 0.09009571120259352, 0.16809506836580113, 0.18364963761996478, 0.2923920244211331, 0.22741165186744183, 0.13821091881254688, 0.1410484907682985, 0.18425267713610083, 0.14930099481716752, 0.13943274621851742, 0.1794536830857396, 0.22145744558656588, 0.06524870346765965, 0.1408831254229881, 0.14725330547662452, 0.26627718354575336, 0.09728127406560816, 0.11128934114822187, 0.2960832294775173, 0.22525629174197093, 0.3144367493223399, 5.140673378482461, 56.140015348792076, 48.06490905582905, 56.373987793922424, 60.514929592609406, 32.85204157233238, 74.08980756998062, 2.528126654215157, 3.1174536561593413, 8.499208185821772, 3.054315294139087, 1.3122437917627394, 0.13549728551879525, 1.1476679728366435, 64.62533622980118, 89.69037964940071, 74.41206067800522, 74.26916554570198, 83.82130578160286, 83.44159975647926, 76.49930387735367, 77.80831083655357, 70.09201169013977, 63.537709191441536, 59.20687258243561, 61.39701046049595, 59.14284601807594, 61.26145273447037, 57.01108820736408, 56.93944305181503, 58.705880865454674, 67.06097513437271, 72.88375988602638, 73.69133055210114, 73.21517050266266, 74.31506708264351, 69.9902455508709, 71.67332723736763, 69.28257152438164, 68.11813920736313, 65.62099680304527, 55.14484874904156, 54.972588792443275, 53.17416809499264, 50.89638032019138, 50.171675607562065, 49.92484085261822, 49.57669973373413, 51.05324350297451, 51.97574280202389, 53.828409388661385, 54.87581178545952, 57.659082636237144, 58.377099707722664, 56.9726000726223, 59.30394597351551, 56.21302843093872, 57.2615821659565, 63.71664918959141, 64.72192704677582, 68.048055768013, 68.48145291209221, 68.29517170786858, 68.70184868574142, 60.968701243400574, 61.17317207157612, 59.60827924311161, 64.82778936624527, 62.93142892420292, 66.36469289660454, 65.82539543509483, 67.5844806432724, 67.40017533302307, 70.00906214118004, 62.29951523244381, 58.005118668079376, 68.74413281679153, 65.8600951731205, 52.791524827480316, 47.0050585269928, 47.81918004155159, 48.09998497366905, 49.19795125722885, 56.768885403871536, 66.3909874856472, 68.50701794028282, 67.22830295562744, 66.01018711924553, 64.23318207263947, 59.0802975744009, 59.80812571942806, 59.91463780403137, 58.31788748502731, 58.594660833477974, 56.05703540146351, 56.88811160624027, 55.327550545334816, 56.374580562114716, 52.33876012265682, 55.378418415784836, 53.17175902426243, 57.063168212771416, 52.62799300253391, 53.88195611536503, 57.724940702319145, 54.35889892280102, 53.473310843110085, 64.51157793402672, 64.28653880953789, 73.27762395143509, 64.79134932160378, 79.15791481733322, 28.952571116387844, 0.22512178489705548, 2.0451514329761267, 6.0132998786866665, 8.636548966169357, 7.244905466213822, 0.719067002646625, 5.667724097147584, 33.43254402279854, 46.802354604005814, 44.93539318442345, 46.87937267124653, 72.65417620539665, 8.18586464971304, 0.4893815884133801, 0.18227626365842298, 0.17679358832538128, 0.1195275662757922, 0.1188432912749704, 0.17083817976526916, 0.13461853814078495, 0.1834503561258316, 0.15541670727543533, 0.19625577289843932, 0.11282266277703457, 0.08705205967999063, 0.17582173109985888, 0.06274464525631629, 0.13081823737593368, 0.08414066629484296, 0.15192950377240777, 0.08445233121165074, 0.20986590039683506, 0.08944268061895855, 0.11978121750871651, 0.09336000322946347], [0.014148611298878677, 0.0292769484440214, 0.07193383615231141, 0.0087748869555071, 0.005531600490940036, 0.06809918137150817, 0.05093868247058708, 0.0315667393442709, 0.04774434899445623, 0.044425416344893165, 0.03665377946163062, 0.04290286327886861, 0.09799315696000122, 0.034429473816999234, 0.08470168540952727, 0.08673125892528333, 0.02472707852575695, 0.04213846601487603, 0.02284568407048937, 0.03999378910521045, 0.04892341385129839, 0.04908214810711797, 0.02171106643800158, 0.1039905339712277, 0.03419445420149714, 0.08470668748486787, 0.020951099795638584, 0.03027338745596353, 0.7427634217310697, 9.569782689213753, 35.83363898098469, 42.221191227436066, 52.6504497975111, 28.820298314094543, 37.790237590670586, 18.25736291706562, 0.917793964035809, 2.9706015111878514, 2.846954958513379, 0.9993684617802501, 0.34079979406669736, 0.019731725187739357, 0.9285357501357794, 61.26441277563572, 81.92859694361687, 78.94268676638603, 77.5570759177208, 74.99214515089989, 71.79032295942307, 60.371156707406044, 53.52680817246437, 58.703198209404945, 67.22919970750809, 64.24895882606506, 61.67186111211777, 63.6797683686018, 66.35461583733559, 59.9812938272953, 61.87540479004383, 64.89622369408607, 68.41803431510925, 70.77845245599747, 71.01064279675484, 69.3951366841793, 67.36068785190582, 65.97077563405037, 65.7012788951397, 62.8124725073576, 60.53219586610794, 50.53234465420246, 47.28975065052509, 48.18101182579994, 47.59110867977142, 46.42670676112175, 48.19840349256992, 47.557871863245964, 49.797798469662666, 48.1814032047987, 47.958693355321884, 48.053741455078125, 50.92116639018059, 51.25497467815876, 52.62874536216259, 51.732050478458405, 54.57308202981949, 57.0469506829977, 56.82224214076996, 58.89492452144623, 62.2458279132843, 63.06803159415722, 67.40620940923691, 62.45868109166622, 58.914892449975014, 62.02112317085266, 61.83060519397259, 61.64677485823631, 59.928309470415115, 61.88297398388386, 61.04612588882446, 64.8257602751255, 65.05323886871338, 65.12980476021767, 50.322367921471596, 61.41999542713165, 64.63775396347046, 58.835229724645615, 46.853002086281776, 42.965894266963005, 44.92315784096718, 45.161777436733246, 44.988711923360825, 51.66251040995121, 61.664303317666054, 62.329962998628616, 63.488794416189194, 62.57079407572746, 61.88679277896881, 56.2760366499424, 55.42453654110432, 53.665059953927994, 51.82183966040611, 51.530843675136566, 50.00486075878143, 50.9634543210268, 50.59758335351944, 52.147561982274055, 53.20576339960098, 51.93243272602558, 49.57672633230686, 49.969378262758255, 49.93352718651295, 51.08291611075401, 49.572371765971184, 54.185814410448074, 53.882852867245674, 56.02894350886345, 63.02397295832634, 67.23659411072731, 61.28080889582634, 73.16986933350563, 5.999830076470971, 0.09914175665471703, 5.46857725828886, 6.145825842395425, 2.7113642217591405, 0.5403570702765137, 0.15397493698401377, 8.435722142457962, 35.95282718539238, 34.003315195441246, 29.540141187608242, 50.294952392578125, 24.949050843715668, 0.09630607717554085, 0.045290515627129935, 0.048663491470506415, 0.06671894254395738, 0.04026163762318902, 0.03958019762649201, 0.024257850091089495, 0.06058288039639592, 0.017406225852028, 0.032358180469600484, 0.0655816902872175, 0.040013875332078896, 0.014529365525959292, 0.02642506417032564, 0.04766293910506647, 0.02201572548074182, 0.036162748583592474, 0.04765564750414342, 0.04571071593090892, 0.02070888691378059, 0.05406031516031362, 0.07959049209603108, 0.03958227563998662, 0.06552093065693043, 0.022970164500293322, 0.027230207197135314, 0.05856741139723454, 0.04897968719888013, 0.04028788738651201, 0.0487686871929327, 0.036582670581992716, 0.07944036304252222, 0.0625607930123806, 0.019191365609003697, 0.002233508043900656, 0.06857368833152577, 0.059709372580982745, 0.07100586211890914, 0.053685567690990865, 0.040135138551704586, 0.00384611655590561, 0.05175949780095834, 0.04810295104107354, 0.017255783241125755, 0.05757376471592579, 0.040715694703976624, 0.009210240059474017, 0.06715870957123116, 0.0730524976097513, 0.0814146242919378, 0.06655022269114852, 1.4568553632125258, 22.53127858042717, 46.29559859633446, 43.41330125927925, 62.17957466840744, 30.328855365514755, 52.564684599637985, 17.65327513217926, 0.8047332870773971, 3.133954983204603, 4.00489104911685, 3.5070662247017026, 1.1032830295152962, 0.33395009755622596, 2.2223026771098375, 66.68436974287033, 81.51567310094833, 81.0498408973217, 78.68053123354912, 77.90383771061897, 76.3467800617218, 63.85482877492905, 57.13610149919987, 59.82626214623451, 68.51894930005074, 65.05662828683853, 63.352560326457024, 67.30908662080765, 68.2377415895462, 62.97398664057255, 62.60827526450157, 66.4608733355999, 71.69789671897888, 72.6486437022686, 72.29514107108116, 72.0314048230648, 69.29998978972435, 69.34523016214371, 68.29213947057724, 64.92742002010345, 60.5936461687088, 55.08333384990692, 50.329177156090736, 50.82469716668129, 48.79397213459015, 49.18585650622845, 49.40642707049847, 49.85011786222458, 52.455497458577156, 50.49478366971016, 49.03941236436367, 51.95606745779514, 53.61295334994793, 54.958122968673706, 54.72107648849487, 54.212621971964836, 55.95689557492733, 58.984094336628914, 59.55247163772583, 61.815295815467834, 66.08079493045807, 66.13631755113602, 67.90851205587387, 66.186383664608, 61.44125908613205, 62.9802031069994, 63.20556901395321, 63.24121870100498, 60.82151994109154, 65.82610979676247, 62.55494512617588, 68.23123633861542, 64.79118213057518, 67.52252876758575, 52.03753508627415, 64.15315076708794, 64.38021898269653, 59.287751242518425, 50.325506553053856, 46.58640079200268, 46.409113705158234, 47.003633603453636, 47.283294796943665, 53.622707426548004, 63.87128189206123, 65.87726265192032, 65.09212598204613, 63.43536928296089, 63.33706855773926, 59.351979196071625, 58.29495571553707, 57.08967559039593, 53.57308968901634, 54.75021332502365, 53.30606661736965, 53.35056222975254, 53.832372575998306, 55.64834073185921, 56.069844514131546, 54.46681693196297, 52.401471957564354, 53.220916986465454, 52.42815412580967, 53.055451065301895, 51.197027787566185, 57.26204954087734, 56.06274649500847, 58.231168538331985, 63.727615401148796, 70.38445919752121, 63.5215562582016, 79.59948152303696, 6.566765354946256, 0.17286048765527084, 4.596340712159872, 2.11715804412961, 1.0790754784829915, 0.2564691676525399, 0.13987505139084533, 12.59952636435628, 40.653638541698456, 42.11049936711788, 30.79567551612854, 54.433097541332245, 30.876576974987984, 0.14834654837613925, 0.02970447931147646, 0.03829522829619236, 0.05521358296391554, 0.009050910230143927, 0.020362786344776396, 0.02792481660435442, 0.019295010242785793, 0.014053420654818183, 0.07553700765129179, 0.050174251809949055, 0.05026875689509325, 0.02657942346559139, 0.04060294391820207, 0.0789515623182524, 0.024115214873745572, 0.046537182715837844, 0.02727561179199256, 0.07452224686858244, 0.024977968969324138, 0.0394102049904177, 0.03886835555022117, 0.021690527501050383, 0.1380287215579301, 0.09826364752370864, 0.12745093525154516, 0.1257342883036472, 0.15982781042112038, 0.1138624562008772, 0.26294728566426784, 0.1364495203597471, 0.15239411790389568, 0.20168364804703742, 0.12976213154615834, 0.13921400561230257, 0.2651882154168561, 0.1524969350430183, 0.1319291433901526, 0.24231883086031303, 0.10012518396251835, 0.11021019905456342, 0.08112548355711624, 0.22349565027980134, 0.22897075570654124, 0.13581223814981058, 0.14738401252543554, 0.15087565407156944, 0.1756800847942941, 0.3021090233232826, 0.12225638391100802, 0.09378139468026347, 1.9930612156167626, 43.31923350691795, 64.9877379834652, 60.16398802399635, 74.45334926247597, 40.05263239145279, 52.81365863978863, 21.573416478931904, 0.878945798613131, 8.962790910154581, 8.616155460476875, 4.766020607203245, 0.3682202805066481, 0.2995188091881573, 2.6368514075875282, 68.35578605532646, 80.87036892771721, 85.27856558561325, 83.16635772585869, 81.42724424600601, 76.94192692637444, 66.30822792649269, 60.39364770054817, 65.50732970237732, 75.41263818740845, 71.20975211262703, 67.13872656226158, 69.99422773718834, 74.92264688014984, 65.90660467743874, 65.96637547016144, 69.02512773871422, 75.26674881577492, 77.03446716070175, 75.29001116752625, 75.44360652565956, 73.6141262948513, 73.43253403902054, 74.09742996096611, 67.74862423539162, 62.951191663742065, 57.72495210170746, 54.24043647944927, 53.82394462823868, 52.05706983804703, 52.033245116472244, 54.82729218900204, 54.506475403904915, 56.53603009879589, 53.14494006335735, 53.33932243287563, 53.966083601117134, 55.35713955760002, 56.43084414303303, 58.21654312312603, 56.16389326751232, 61.3433763384819, 63.96737113595009, 61.130602955818176, 63.443371653556824, 68.82516726851463, 68.83051738142967, 70.37018716335297, 67.80393406748772, 61.716029942035675, 67.01954215765, 65.45365378260612, 66.37971729040146, 63.68203304708004, 68.66530984640121, 65.95529526472092, 71.7332424223423, 66.34601309895515, 67.45136618614197, 53.97915869951248, 64.73809137940407, 65.87274849414825, 60.31854473054409, 51.56730271875858, 49.225712567567825, 50.49429729580879, 50.06234407424927, 50.132340118288994, 57.188253700733185, 68.40576097369194, 69.81307625770569, 67.02034011483192, 65.81789463758469, 65.62713727355003, 61.30157098174095, 59.988669231534004, 58.71444180607796, 56.10824145376682, 56.65512330830097, 56.87420055270195, 57.56511747837067, 56.69160135090351, 60.62643080949783, 61.31570242345333, 60.1055433601141, 56.080898120999336, 56.14963263273239, 57.41434916853905, 56.12895414233208, 53.70067924261093, 60.46352215111256, 57.98917472362518, 61.06195583939552, 68.57435792684555, 73.78903850913048, 63.09200830757618, 81.92860454320908, 7.928237998858094, 0.15892023802734911, 13.308415375649929, 16.342315077781677, 8.699179105460644, 1.9204563740640879, 0.3494645463069901, 15.482345223426819, 51.333930641412735, 48.95303539931774, 41.99185073375702, 65.00178202986717, 44.456786066293716, 0.34667965199332684, 0.2099300071131438, 0.10824337412486784, 0.15397624316392466, 0.08379810577025637, 0.08411316230194643, 0.11772641097195446, 0.15101808705367148, 0.11102449090685695, 0.2161824083304964, 0.21273697289871052, 0.15321880724513903, 0.16483113256981596, 0.11520985499373637, 0.20296404574764892, 0.11067666113376617, 0.18323171942029148, 0.15235395287163556, 0.1705738267628476, 0.11176157713634893, 0.11884037463460118, 0.20556491712341085, 0.12627081654500216], [0.10766565668745898, 0.06895346014061943, 0.020592900364135858, 0.062027715757722035, 0.002060572560367291, 0.062030869885347784, 0.043489831587066874, 0.022532529292220715, 0.03324273886391893, 0.03481178377114702, 0.04648521382478066, 0.05055620553321205, 0.02168942355638137, 0.069221086014295, 0.05289144741254859, 0.030732788000022992, 0.030955499096307904, 0.05408569661085494, 0.08937956095905975, 0.06031192227965221, 0.08761678211158141, 0.04009875476185698, 0.041042710945475847, 0.0006695627348562994, 0.03010983480635332, 0.04503075280808844, 0.0448021824558964, 0.14292367530288175, 0.37664882198441774, 5.655019003897905, 37.737112641334534, 62.62215971946716, 52.24790699779987, 56.2164406478405, 23.431927151978016, 26.57838251441717, 0.2809292863821611, 2.6416436629369855, 2.6529703801497817, 2.227382529526949, 1.309131165035069, 0.46539335686247796, 0.4475949931656942, 9.64577006176114, 87.10876017808914, 77.13418900966644, 80.00883355736732, 72.52382799983025, 65.5918599665165, 61.69199623167515, 69.9128969013691, 72.54421770572662, 73.31731662154198, 74.43522423505783, 74.90169480443001, 71.18578299880028, 69.64943423867226, 70.76073780655861, 73.97807076573372, 71.57275423407555, 70.77056407928467, 71.28710836172104, 70.38565993309021, 71.77158236503601, 65.65518736839294, 64.91456910967827, 63.758253157138824, 63.773216754198074, 61.246941313147545, 53.35883058607578, 48.295313492417336, 48.49612511694431, 48.01910251379013, 47.650921270251274, 47.955573722720146, 45.92611402273178, 47.708624973893166, 48.43317769467831, 49.106155782938, 48.93099658191204, 49.35016728937626, 49.66366566717625, 51.5130378305912, 54.5001183450222, 58.88009771704674, 60.10097600519657, 60.51193155348301, 60.18960624933243, 65.76128527522087, 57.13534913957119, 58.94502863287926, 63.79156216979027, 64.5229621231556, 63.24571006000042, 63.14007952809334, 63.42367731034756, 66.92526921629906, 66.11660420894623, 64.39634531736374, 64.24142763018608, 60.71497745811939, 57.38083116710186, 66.18334382772446, 68.2134760916233, 63.21775496006012, 60.04225015640259, 44.2364738881588, 45.15740767121315, 44.2310743778944, 46.28297947347164, 44.42983791232109, 51.91335014998913, 60.87938703596592, 66.05181768536568, 65.85446387529373, 63.204717859625816, 62.36471973359585, 60.640813037753105, 60.1137775182724, 53.518828600645065, 54.37726333737373, 50.06898231804371, 49.15986970067024, 49.93118271231651, 53.51273372769356, 51.60244323313236, 51.82604603469372, 51.7359908670187, 52.3883930593729, 52.085218727588654, 52.39760756492615, 50.13606011867523, 56.03348046541214, 52.78205953538418, 57.05870725214481, 61.6984710842371, 69.34440180659294, 60.726479440927505, 79.61952924728394, 28.13738565891981, 0.16553770168684423, 0.9537070838268846, 2.355154473334551, 4.385255388915539, 2.0464934734627604, 0.11914372007595375, 0.1452331943437457, 19.56938311457634, 46.71081371605396, 23.55824377387762, 30.933448523283005, 45.90676166117191, 3.241161718033254, 0.11943369943764992, 0.0853623378498014, 0.0388980488787638, 0.06054506426153239, 0.07791962081682868, 0.04566721123410389, 0.07456699837348424, 0.022819951955170836, 0.06911806849529967, 0.05652786341670435, 0.0229207931261044, 0.0272493546071928, 0.046418754500336945, 0.027075090911239386, 0.052340347101562656, 0.026762108682305552, 0.03940243099350482, 0.038755500863771886, 0.08200809752452187, 0.012824344321415992, 0.017971764646063093, 0.04968088316672947, 0.04989917477359995, 0.02210626935266191, 0.02022431457589846, 0.013425146262306953, 0.024682592338649556, 0.052834687958238646, 0.028180146946397144, 0.07179004503996111, 0.0036198041880197707, 0.026326093211537227, 0.02169267972931266, 0.04194457993435208, 0.10914303522440605, 0.021575722821580712, 0.0410766493587289, 0.04393012924992945, 0.02237250369944377, 0.03270723107561935, 0.043922217955696397, 0.07503711924073286, 0.04273671125702094, 0.0302927593656932, 0.02784922886348795, 0.02467425430950243, 0.06426345047657378, 0.04585089649481233, 0.06851737416582182, 0.14800294884480536, 0.2607001515571028, 0.29027625045273453, 13.096524495631456, 59.33687500655651, 67.82411098480225, 68.15465524792671, 55.62535956501961, 34.51393559575081, 32.123282477259636, 0.19764936296269298, 2.5799380615353584, 1.1524083372205496, 5.566939255222678, 2.9574950644746423, 1.9984139408916235, 0.8164174226112664, 13.197482228279114, 86.04366973042488, 78.5347330570221, 83.74985441565514, 75.35175785422325, 68.17459657788277, 66.47047162055969, 71.41536667943001, 75.01091614365578, 76.17125228047371, 77.32498437166214, 75.12598916888237, 71.75426289439201, 72.74552330374718, 74.75846529006958, 76.9572477042675, 72.7164776623249, 72.08205610513687, 74.13726702332497, 72.39189147949219, 72.82197520136833, 69.85374927520752, 69.10917162895203, 69.98893082141876, 67.721858471632, 63.09977129101753, 54.77706268429756, 52.090443447232246, 50.76031342148781, 50.07661230862141, 49.24182750284672, 51.09366953372955, 48.5966981202364, 50.49142464995384, 50.49393631517887, 50.5479846149683, 51.22069291770458, 53.21320720016956, 52.31175497174263, 54.062366634607315, 55.87685666978359, 59.66969534754753, 62.46066078543663, 63.05033974349499, 62.868656292557716, 65.77541291713715, 62.833120599389076, 62.067682072520256, 64.88873049616814, 63.28701764345169, 63.86424466967583, 65.14142453670502, 66.28295928239822, 66.644806265831, 65.95866948366165, 66.1098861694336, 65.77830076217651, 62.80219405889511, 56.62699721753597, 66.82355627417564, 69.89921763539314, 65.04618644714355, 61.68809004127979, 47.277378514409065, 46.0222602635622, 45.290746316313744, 48.37798945605755, 46.05658382177353, 54.877704083919525, 65.05331486463547, 66.45198181271553, 66.38253673911095, 64.22196507453918, 65.2803298830986, 62.59874537587166, 60.8760280162096, 58.19329597055912, 56.850546821951866, 51.86039239168167, 52.44809165596962, 51.05855941772461, 55.18803723156452, 55.664725452661514, 54.85171727836132, 54.044838175177574, 55.507869869470596, 55.44676534831524, 55.66330432891846, 53.886648863554, 60.12706160545349, 53.15944008529186, 60.37949725985527, 63.88176932930946, 72.01147109270096, 63.11256520450115, 80.69354921579361, 28.254379481077194, 0.1604605803731829, 2.0392978470772505, 6.447686394676566, 2.455837670713663, 1.7592229507863522, 0.14844866789644584, 0.35677977721206844, 25.23198176175356, 53.97524490952492, 29.18680004775524, 29.589709527790546, 59.14377696812153, 4.510214533656836, 0.1725523330969736, 0.059678525212802924, 0.02389364854025189, 0.006536456385219935, 0.06668451431323774, 0.06719028053339571, 0.0406329712131992, 0.02331172683625482, 0.03441643428232055, 0.011535806188476272, 0.041794680946622975, 0.07606260405736975, 0.05800768361950759, 0.04407605403685011, 0.06019707492669113, 0.02262366502691293, 0.022741236061847303, 0.06527258577989414, 0.01598474773345515, 0.008862195991241606, 0.0148684249688813, 0.010279185971739935, 0.014676627106382512, 0.17483093426562846, 0.1608609690447338, 0.11229180454392917, 0.15809336677193642, 0.1081171199621167, 0.12615342362551019, 0.1123046140128281, 0.045539298371295445, 0.19624340871814638, 0.16176560253370553, 0.1504546930664219, 0.26270783913787454, 0.1681051912601106, 0.1446597813628614, 0.11111550047644414, 0.11248612849158235, 0.1595072471536696, 0.22359012567903847, 0.13853734504664317, 0.1754429389256984, 0.1503691531252116, 0.11647655264823698, 0.10040316279628314, 0.23208940867334604, 0.1183384378964547, 0.16983452893327922, 0.2955064916750416, 0.5399548262357712, 0.8671954635065049, 21.570040360093117, 80.89670151472092, 73.41897636651993, 72.95482367277145, 72.94007286429405, 37.2802859544754, 34.78870265185833, 0.16907831013668329, 7.507694140076637, 11.224275659769773, 11.11006423830986, 1.922139327507466, 0.5786921444814652, 0.4369680618401617, 11.579452101141214, 90.59115171432495, 78.03244560956955, 87.70863398909569, 77.13590651750565, 73.75874653458595, 67.55747929215431, 76.10946759581566, 78.88504385948181, 79.95551481842995, 81.9655005633831, 80.70036605000496, 77.42662891745567, 75.31825125217438, 77.80440464615822, 81.02078005671501, 77.68301635980606, 76.97320684790611, 74.97291058301926, 73.66307526826859, 78.60808432102203, 72.97909677028656, 71.78200900554657, 68.97439286112785, 70.49497246742249, 66.45300015807152, 59.368907287716866, 53.94883632659912, 55.172150284051895, 52.916279733181, 52.606197372078896, 54.80409063398838, 49.79849383234978, 53.9297841489315, 53.5556448251009, 54.68084804713726, 55.605437234044075, 54.79658603668213, 55.79903684556484, 56.67394369840622, 60.71268618106842, 62.50965155661106, 64.74901959300041, 65.92118829488754, 67.16496795415878, 69.90790396928787, 61.611782535910606, 61.559884920716286, 68.18897500634193, 66.46782696247101, 66.18228748440742, 67.96143561601639, 68.72046008706093, 71.56303435564041, 68.83064657449722, 68.61012160778046, 66.33092030882835, 61.82110570371151, 61.3154212385416, 68.90092000365257, 71.58476158976555, 67.14034527540207, 63.57907377183437, 49.11147929728031, 49.471973553299904, 48.440971076488495, 51.237115636467934, 48.35490569472313, 58.37180279195309, 66.15498214960098, 70.17691433429718, 68.00791472196579, 66.63061782717705, 67.68164902925491, 64.98034358024597, 64.12231162190437, 58.84136259555817, 59.424749091267586, 55.624576807022095, 54.09647740423679, 55.49317605793476, 59.12375204265118, 59.56280328333378, 56.32529720664024, 58.59897740185261, 58.462465927004814, 57.15409353375435, 57.90910542011261, 57.112706154584885, 61.589416936039925, 57.81237781047821, 62.822845950722694, 69.55898389220238, 74.50356736779213, 67.45803102850914, 81.16644904017448, 32.419563978910446, 0.11299770572804846, 2.4277353286743164, 11.109606362879276, 13.337454367429018, 5.183742642402649, 1.5188997401855886, 0.629301747540012, 32.48552843928337, 63.76028224825859, 35.886064767837524, 43.744727075099945, 70.53285643458366, 7.988725528120995, 0.5944506113883108, 0.3494093008339405, 0.10542865289608017, 0.1702424429822713, 0.14348283904837444, 0.2355406031711027, 0.22424321563448757, 0.11551246570888907, 0.1627083824132569, 0.15684914134908468, 0.08247440375271253, 0.13733365572988987, 0.23228260455653071, 0.12482008110964671, 0.17605543340323493, 0.17921114922501147, 0.1176521071465686, 0.12330379919148982, 0.23850855563068762, 0.09122917108470574, 0.1306753294193186, 0.14707456663018093, 0.145517036144156], [0.04407567554153502, 0.013422344654827612, 0.0089285708963871, 0.07846506967325695, 0.09759179607499391, 0.07507122834795155, 0.029471123962139245, 0.049573713331483305, 0.03533513146976475, 0.05033964684116654, 0.03826845531875733, 0.035076329731964506, 0.03267559703090228, 0.04628655944543425, 0.053483881638385355, 0.023375764903903473, 0.06535288615850732, 0.03234526338928845, 0.006851024490970303, 0.05352281099476386, 0.07350705564022064, 0.05295686401950661, 0.06395507327397354, 0.0048678370603738585, 0.050003654323518276, 0.05274296592688188, 0.16242608428001404, 0.07077348083839752, 0.006547665598191088, 0.30261873034760356, 39.78558652102947, 54.459620118141174, 42.09813483059406, 53.72616067528725, 39.58268120884895, 20.95382172614336, 5.234147887676954, 1.1814611032605171, 2.217635102570057, 2.4254400143399835, 8.191693536937237, 1.0059924563392997, 0.2286721154814586, 0.454506614478305, 46.30731716752052, 89.20860350131989, 77.29526236653328, 75.44180542230606, 72.1626877784729, 69.36824172735214, 69.62836816906929, 73.82968872785568, 78.37441205978394, 74.77805703878403, 70.56480512022972, 72.04045593738556, 77.0297022163868, 75.16407072544098, 73.42653796076775, 72.5699271261692, 71.82239323854446, 72.8818827867508, 72.72827222943306, 69.57294434309006, 69.12017583847046, 69.3286706507206, 63.27461510896683, 61.49349868297577, 61.32308542728424, 53.86492162942886, 48.67620125412941, 48.38925585150719, 49.53421801328659, 49.166466146707535, 49.93440493941307, 48.504393473267555, 46.84927448630333, 48.77366982400417, 49.72875237464905, 50.66422417759895, 54.028810635209084, 57.594220116734505, 60.44350482523441, 62.878877744078636, 66.31728664040565, 63.04543420672417, 60.88309943675995, 60.98744563758373, 69.38580438494682, 46.420752480626106, 48.723094537854195, 66.34129375219345, 63.70371088385582, 65.55440157651901, 63.95626053214073, 67.85242706537247, 63.53029578924179, 63.68631161749363, 61.508124098181725, 56.98024906218052, 54.69373315572739, 70.28443336486816, 65.43446481227875, 62.664592042565346, 61.20304986834526, 53.15597087144852, 44.014637991786, 47.04143017530441, 46.43200747668743, 48.98191384971142, 44.021774008870125, 49.39664639532566, 61.766160652041435, 62.64695718884468, 63.88285607099533, 64.43085506558418, 63.62507410347462, 63.79063501954079, 58.79233382642269, 55.4501623660326, 53.96268278360367, 51.27653852105141, 50.84477908909321, 51.73259384930134, 55.4288113117218, 54.18289616703987, 55.08098177611828, 55.34794025123119, 53.30248720943928, 52.21492096781731, 54.72228862345219, 56.23319774866104, 54.497059509158134, 57.782549411058426, 61.50627739727497, 63.006630688905716, 68.73047634959221, 69.98590618371964, 56.54922679066658, 0.7567665609531105, 0.15160463604843244, 0.6548489048145711, 2.5833096681162715, 0.26741839887108654, 0.5169350677169859, 0.20945451309671625, 1.1414981726557016, 45.20569548010826, 31.897848173975945, 20.915194898843765, 55.73921665549278, 24.605285190045834, 0.09397936999448575, 0.03901347139617428, 0.016556553964619525, 0.08406543478486128, 0.10161992875509895, 0.011158646739204414, 0.0211029432102805, 0.05283988299197517, 0.021637499194184784, 0.056934949971036986, 0.07671239887713455, 0.012088712701370241, 0.038225700191105716, 0.0352505971386563, 0.05796238663606346, 0.05661053866788279, 0.01649763300520135, 0.0031279008226192673, 0.061468893400160596, 0.013482068989105755, 0.046111791089060716, 0.0008193292376290628, 0.02240959438495338, 0.025865444004011806, 0.04078189056599513, 0.067185567895649, 0.04483734541281592, 0.12561558920424432, 0.06808061283663847, 0.04117420096008573, 0.034133286389987916, 0.04201388539513573, 0.10022771908552386, 0.034059565150528215, 0.015293830510927364, 0.0329407997924136, 0.1062292224378325, 0.04887373077508528, 0.12033457765937783, 0.07116352397133596, 0.05247738095931709, 0.07013549358816817, 0.053412320048664697, 0.04412929942191113, 0.060967138488194905, 0.035300599338370375, 0.04615597856172826, 0.013779822347714799, 0.03900245050317608, 0.042852527112700045, 0.2147103287279606, 0.10836271147127263, 0.06251788945519365, 1.86670137103647, 54.242085590958595, 59.13618117570877, 45.47888942062855, 74.43158403038979, 39.63491700589657, 34.572045877575874, 6.19237856939435, 1.2911426927894354, 1.3636779505759478, 2.57185613270849, 7.090436629951, 5.34582294523716, 1.4013371360488236, 0.520795660559088, 52.174650728702545, 92.69620835781097, 78.77102717757225, 78.58239769935608, 73.89175459742546, 72.35959321260452, 73.51964816451073, 76.84022918343544, 79.84671145677567, 74.35069397091866, 76.30326479673386, 77.19319224357605, 79.46705862879753, 74.90922600030899, 76.44002705812454, 75.63378632068634, 75.48897609114647, 74.41554889082909, 73.06155994534492, 70.92387065291405, 72.99357399344444, 70.33332914113998, 67.9671049118042, 64.85690340399742, 64.5252799987793, 56.432128474116325, 52.29721315205097, 51.37365750968456, 51.27396985888481, 51.052776128053665, 51.08846001327038, 50.51543556153774, 49.89184342324734, 52.32284277677536, 52.3943093419075, 53.293249905109406, 54.82040695846081, 56.12771160900593, 61.9959457218647, 63.86253476142883, 65.92430412769318, 64.00270164012909, 63.277168571949005, 64.39249992370605, 71.60096392035484, 50.43270640075207, 52.710813358426094, 68.31370711326599, 67.58112922310829, 66.31088778376579, 64.18120086193085, 68.31946760416031, 64.60728719830513, 65.30961871147156, 63.283050656318665, 61.22665420174599, 56.17000333964825, 70.51497459411621, 67.50671401619911, 65.6525807082653, 62.51525245606899, 55.60204781591892, 46.636710092425346, 48.38155746459961, 49.68248225748539, 49.98388968408108, 47.359682098031044, 55.28713971376419, 62.43663087487221, 66.74260541796684, 62.93314643204212, 66.38297751545906, 65.30447378754616, 65.40134578943253, 61.071219742298126, 56.60304710268974, 56.38516679406166, 53.23698632419109, 53.61779049038887, 55.006460174918175, 57.23639711737633, 56.90000876784325, 57.51267649233341, 58.73594485223293, 56.80793210864067, 55.81731766462326, 59.15922313928604, 58.936555087566376, 56.044442877173424, 59.85124200582504, 65.94166159629822, 65.24600252509117, 70.45360028743744, 72.61769816279411, 60.2325439453125, 0.5311181035358459, 1.153335606213659, 2.2761825984343886, 1.750171361491084, 1.4338897517882288, 0.3149339882656932, 0.23245206655701622, 2.599914539605379, 48.50197300314903, 45.24668388068676, 21.303393468260765, 59.78808179497719, 30.564706809818745, 0.11800664593465626, 0.06351997435558587, 0.016248267675109673, 0.014928310720279114, 0.08410626032855362, 0.03143730507872533, 0.044976620556553826, 0.0690029762336053, 0.09213645404088311, 0.029104400964570232, 0.021891009419050533, 0.013530903233913705, 0.014473689607257256, 0.024073801178019494, 0.02457694019540213, 0.03840992721961811, 0.020852446104981937, 0.0029250489023979753, 0.06679163590888493, 0.020277992261981126, 0.0677646508847829, 0.033237384268431924, 0.021754211193183437, 0.00991650675132405, 0.11005426640622318, 0.09664054086897522, 0.12488973909057677, 0.16243303078226745, 0.14485762309050187, 0.1343278685817495, 0.18393647769698873, 0.14976549020502716, 0.2137339295586571, 0.18081243673805147, 0.09589331690222025, 0.10049967168015428, 0.16916024324018508, 0.13013345771469176, 0.15843309229239821, 0.13302324718097225, 0.25382047228049487, 0.1070192237966694, 0.19522708200383931, 0.20487748057348654, 0.18426863331114873, 0.23234378721099347, 0.17099662829423323, 0.24994218663778156, 0.1980161471874453, 0.30780836124904454, 0.4972159961471334, 0.24693858140381053, 0.2251311211148277, 3.1904299277812243, 74.3116244673729, 74.34865728020668, 56.995079666376114, 75.78896999359131, 53.291741386055946, 37.25543148815632, 6.1254385113716125, 2.7256790036335588, 8.480081912130117, 7.477901838719845, 18.785878457129, 2.1902775205671787, 0.5671284149866551, 0.5010719283018261, 51.91472947597504, 94.00877192616463, 82.35134705901146, 80.84179446101189, 78.44118967652321, 77.81885907053947, 77.09672302007675, 79.46930050849915, 84.49969857931137, 81.33396685123444, 77.42660611867905, 80.05248561501503, 85.11502996087074, 81.6070581972599, 80.57665228843689, 77.34187066555023, 77.53160208463669, 77.18563824892044, 76.680006980896, 74.42214533686638, 74.39290210604668, 76.10443666577339, 68.73875230550766, 68.06570962071419, 66.90405875444412, 59.61305558681488, 54.897409826517105, 53.48360829055309, 55.918346643447876, 55.59225954115391, 54.926326274871826, 54.56577502191067, 52.563647255301476, 55.70116929709911, 54.50978122651577, 54.60880011320114, 59.439591094851494, 61.81865103542805, 65.38226321339607, 66.5346197783947, 68.83934810757637, 69.94139537215233, 66.2765908241272, 68.70849072933197, 74.71935018897057, 53.11541944742203, 50.66065236926079, 69.92974519729614, 68.19874048233032, 69.36755776405334, 66.32699891924858, 71.79908528923988, 66.52740776538849, 67.67840400338173, 64.65568900108337, 62.207936346530914, 59.87945929169655, 71.85323998332024, 69.14707839488983, 67.53672480583191, 64.3548059463501, 57.19445876777172, 49.569825902581215, 51.714385226368904, 52.72220514714718, 52.867121770977974, 51.04214809834957, 55.78245833516121, 67.84814089536667, 69.09479320049286, 64.7485864162445, 68.14450219273567, 69.1116414964199, 69.95227798819542, 65.73914006352425, 60.65603122115135, 60.26374787092209, 55.70242702960968, 58.041999489068985, 57.91271522641182, 60.60816138982773, 60.06716541945934, 62.598802372813225, 59.7927251458168, 60.15928387641907, 58.073701187968254, 61.65108002722263, 61.459855288267136, 59.85151179134846, 63.90027433633804, 68.44617560505867, 68.12041908502579, 74.29380342364311, 73.85578572750092, 61.08059003949165, 1.5852685226127505, 1.1798987933434546, 2.006664485670626, 9.066672585904598, 5.719753280282021, 1.387463842984289, 0.6689256650861353, 3.551312000490725, 61.913121566176414, 46.38202115893364, 31.95065014064312, 74.41806435585022, 41.029324382543564, 0.17942377453437075, 0.1808507612440735, 0.11272371964878403, 0.13455128471832722, 0.2068114877329208, 0.10725362371886149, 0.11839049955597147, 0.22838621051050723, 0.11738856308511458, 0.19915049022529274, 0.1304952398641035, 0.09586432861397043, 0.12084049230907112, 0.11697903857566416, 0.23213129548821598, 0.10717397643020377, 0.0772273083566688, 0.1134522414940875, 0.15712962864199653, 0.10563883653958328, 0.13271651754621416, 0.09180594599456526, 0.08693454059539363, 0.1383712820825167], [0.016669267643010244, 0.04166353231994435, 0.04440872544364538, 0.02814364812365966, 0.018677984953683335, 0.05567207066633273, 0.036472788196988404, 0.025899642168951686, 0.04302142137021292, 0.06128173117758706, 0.04411555113620125, 0.07375361936283298, 0.01800663631001953, 0.03624216580647044, 0.015431542506121332, 0.07327964674914256, 0.057173439126927406, 0.018454333185218275, 0.09042769612278789, 0.047021586215123534, 0.07828906935174018, 0.07132717495551333, 0.032871583389351144, 0.062478459149133414, 0.07459716667653993, 0.051402179669821635, 0.1314073838875629, 0.17154917208245024, 0.19036528741708025, 0.4749964509392157, 14.09513371065259, 70.1710094511509, 38.82584162056446, 29.243202321231365, 61.132290065288544, 33.662560880184174, 5.1811127085238695, 0.9798477217555046, 1.385657039936632, 1.3716690405271947, 9.397143702954054, 24.54192738980055, 0.8023262943606824, 0.22513889882247895, 8.447539508342743, 88.72313395142555, 81.15780830383301, 86.16620555520058, 69.82002228498459, 73.82750764489174, 75.18135979771614, 78.68792563676834, 72.12926477193832, 80.84354236721992, 75.41517645120621, 73.75554710626602, 72.15572655200958, 75.70770755410194, 75.21638631820679, 75.22731453180313, 71.98954626917839, 72.97566175460815, 71.66926145553589, 73.21980625391006, 68.7514740228653, 65.13567924499512, 66.44524857401848, 61.546019464731216, 62.417308911681175, 55.296620205044746, 51.04155533015728, 48.19955103099346, 49.45708975195885, 48.76030594110489, 48.843464478850365, 48.02213475108147, 49.261856228113174, 46.48951359093189, 48.91945660114288, 47.08284415304661, 60.045267194509506, 64.62939441204071, 66.86041429638863, 63.581536039710045, 65.56903839111328, 63.890972435474396, 62.540559098124504, 60.48770025372505, 69.90367859601974, 45.14306724071503, 54.34789851307869, 67.92166694998741, 63.11879687011242, 67.46158003807068, 63.68595823645592, 65.73137328028679, 64.8052641749382, 64.98027518391609, 60.3178645670414, 60.57033061981201, 70.49494966864586, 66.00367426872253, 64.85515549778938, 65.59871479868889, 59.9023150652647, 47.847260534763336, 47.13650107383728, 48.204038590192795, 47.66340360045433, 46.25389203429222, 47.57635027170181, 52.47492581605911, 62.43066519498825, 64.00455594062805, 66.72114416956902, 61.68075643479824, 67.2498781979084, 61.85498088598251, 59.45845328271389, 58.2429289072752, 53.318537548184395, 49.48411390185356, 52.288640812039375, 56.429255828261375, 56.7021419852972, 57.67188794910908, 56.51532121002674, 55.78739807009697, 59.19607736170292, 57.60705962777138, 53.898736014962196, 57.924597188830376, 61.043982803821564, 58.613192439079285, 64.64715465903282, 69.36332479119301, 63.845762461423874, 74.54743221402168, 12.76113074272871, 0.661170162493363, 0.26053103094454855, 2.469551134854555, 4.270068844780326, 0.5068849038798362, 0.6813044508453459, 0.11938290685066022, 12.498660776764154, 52.85364769399166, 22.044650092720985, 41.63007974624634, 41.77776262164116, 3.22562743909657, 0.2007513027638197, 0.11452999577159062, 0.037988817784935236, 0.09925002115778625, 0.02655362641235115, 0.05398073095420841, 0.07173701116698794, 0.058610433698049746, 0.0486349670245545, 0.11942550612729974, 0.018770825772662647, 0.05556750205869321, 0.0749912322498858, 0.016857450318639167, 0.031150494687608443, 0.019276400889793877, 0.03595325142669026, 0.006901397764522699, 0.04314346384489909, 0.012684326102316845, 0.03275325165304821, 0.04803377916687168, 0.10590799865894951, 0.019010565447388217, 0.03312994726002216, 0.10383745859144256, 0.04076925550180022, 0.036324076645541936, 0.03500753635307774, 0.03328985781990923, 0.03280533928773366, 0.02706588271394139, 0.03168768344039563, 0.035045274562435225, 0.10146075292141177, 0.027243922086199746, 0.022657629415334668, 0.01972998485143762, 0.019048810172535013, 0.06363039108691737, 0.0633526497404091, 0.05132674406922888, 0.044317485808278434, 0.01063372939825058, 0.11131825522170402, 0.03239329147618264, 0.10581866634311154, 0.018536244024289772, 0.09019384538987651, 0.030720865397597663, 0.126916796725709, 0.032072538961074315, 0.11876771837705746, 0.5373039341066033, 21.6497752815485, 84.78192463517189, 33.92037324607372, 43.55574041604996, 72.79201000928879, 36.58454708755016, 8.441693522036076, 1.0334894433617592, 2.2428728733211756, 2.1201475337147713, 5.529121309518814, 9.175098817795515, 3.652941584587097, 0.4117608378874138, 11.750824805349112, 90.44207811355591, 86.71635523438454, 86.84362560510635, 75.41992619633675, 77.91094332933426, 78.94348472356796, 78.4833750128746, 75.68142056465149, 81.96863159537315, 79.44685131311417, 74.59292337298393, 75.21205455064774, 79.03185278177261, 77.76987209916115, 77.68869325518608, 74.61931675672531, 75.24034783244133, 75.5611190199852, 75.43989032506943, 70.39267435669899, 67.79520213603973, 69.13789808750153, 64.92490455508232, 66.85561135411263, 58.743544444441795, 53.067462220788, 50.48074722290039, 52.044994086027145, 52.24379561841488, 50.07981933653355, 50.681444853544235, 50.690131187438965, 48.11173394322395, 51.8006481975317, 50.03461696207523, 59.519231021404266, 64.75833669304848, 69.65125814080238, 66.8808875977993, 65.36442697048187, 67.62785911560059, 66.7572346329689, 63.99810388684273, 71.2588682770729, 48.6414635181427, 53.80784869194031, 66.80233061313629, 64.24466505646706, 67.44100034236908, 67.8439611196518, 69.02063637971878, 65.29562026262283, 66.48336052894592, 63.45202758908272, 60.48428803682327, 70.41475117206573, 67.91303381323814, 66.28640949726105, 67.3933357000351, 61.1682703346014, 51.37148402631283, 48.47377471625805, 48.88025030493736, 48.99106375873089, 48.078060150146484, 48.48774656653404, 54.338915795087814, 63.8232296705246, 67.26954594254494, 66.51419967412949, 64.148750603199, 67.91959226131439, 64.76424157619476, 61.30595214664936, 60.53440734744072, 54.71345029771328, 53.19006644189358, 52.812902480363846, 59.040734097361565, 59.081019535660744, 59.763519912958145, 58.672267869114876, 57.44176849722862, 59.356428757309914, 61.03618562221527, 55.13260580599308, 59.58411633968353, 63.34611587226391, 63.45866583287716, 65.3839199244976, 73.1450566649437, 66.03655770421028, 76.7049640417099, 12.102144453674555, 0.6488455238286406, 1.405768054537475, 2.004903992637992, 2.565875491127372, 0.5680945725180209, 0.6375417835079134, 0.04782916163094342, 14.995128717273474, 69.528988301754, 29.624034985899925, 38.50172281265259, 57.08889663219452, 4.906757455319166, 0.270098828477785, 0.025425072126381565, 0.06337588638416491, 0.05301265868183691, 0.05121981543197762, 0.08137629978591576, 0.06929714872967452, 0.04538942906947341, 0.062058377588982694, 0.061106580615160055, 0.03421458866796456, 0.046669177390867844, 0.0038200994094950147, 0.05267649547022302, 0.013234078487585066, 0.017204231808136683, 0.05382708040997386, 0.06851669881143607, 0.07395175794954412, 0.0094979809182405, 0.019776589870161843, 0.03536383774189744, 0.03790872520767152, 0.009391021667397581, 0.09837093239184469, 0.19036987388972193, 0.15038613346405327, 0.12138720281654969, 0.06795737921493128, 0.20419636712176725, 0.1369321093079634, 0.09491727396380156, 0.12669998570345342, 0.1413623450207524, 0.18416752311168239, 0.19713575224159285, 0.13139567279722542, 0.08484615187626332, 0.09066432248800993, 0.14788343338295817, 0.17740740382578224, 0.11662144956062548, 0.26174500642810017, 0.12220511634950526, 0.22679618879919872, 0.10978370162774809, 0.15092876215931028, 0.14241384953493252, 0.2008552776533179, 0.10935928221442737, 0.3895814873976633, 0.35265872022137046, 0.30586001579649746, 1.2252903264015913, 28.218298517167568, 98.7269939482212, 53.839162811636925, 45.19215300679207, 79.48654398322105, 50.283993780612946, 10.234986394643784, 1.666696253232658, 6.349389469251037, 5.272428933531046, 23.75410996377468, 43.292608335614204, 4.314455213025212, 0.2740685467142612, 11.199482940137386, 93.96909445524216, 85.73058933019638, 92.13342815637589, 76.10302314162254, 81.06866508722305, 82.29590803384781, 83.5264340043068, 76.69333666563034, 85.60094028711319, 83.36726054549217, 77.89164796471596, 78.28505605459213, 80.171138048172, 80.77821627259254, 79.77823913097382, 76.90408855676651, 78.08753505349159, 77.505451887846, 78.147913813591, 74.08954918384552, 71.29459396004677, 71.81578919291496, 66.42778471112251, 68.88084188103676, 61.53870105743408, 58.52056480944157, 53.97532470524311, 56.611178666353226, 54.457819014787674, 53.859503120183945, 53.48254054784775, 53.596416637301445, 52.16647356748581, 55.253503918647766, 53.07413086295128, 64.89503815770149, 69.44930657744408, 72.87565112113953, 70.00428199768066, 69.94461759924889, 68.77147614955902, 69.80961844325066, 67.22447276115417, 73.5352349281311, 50.68601980805397, 54.92979168891907, 67.95487716794014, 64.81081187725067, 68.73506650328636, 67.58480742573738, 69.9119621515274, 66.35251834988594, 68.14292147755623, 65.46948373317719, 64.1488341987133, 72.274249792099, 69.12815541028976, 70.1239375770092, 69.61273580789566, 63.4734508395195, 53.25025141239166, 50.55662915110588, 52.25934058427811, 52.93357640504837, 51.642413288354874, 53.499423041939735, 57.14589737355709, 66.26783609390259, 69.89268958568573, 69.00417566299438, 64.59910243749619, 72.85639375448227, 66.4709047973156, 63.07088144123554, 64.96575996279716, 57.891839146614075, 57.06394337117672, 57.92702525854111, 63.1325863301754, 62.912148758769035, 63.23146842420101, 60.77366150915623, 61.95834293961525, 64.19649884104729, 64.06836971640587, 59.1721348464489, 63.41262750327587, 67.92675867676735, 64.88324359059334, 70.44030100107193, 76.19296431541443, 67.70431101322174, 77.41542711853981, 15.343802757561207, 0.7476567279081792, 0.9363754419609904, 4.691296191886067, 11.490062847733498, 1.9694574759341776, 2.0537413470447063, 0.48698468890506774, 22.731451839208603, 70.41939452290535, 32.663294300436974, 55.95590002834797, 66.35216116905212, 8.667443208396435, 0.7301163941156119, 0.2586666075512767, 0.3092713124351576, 0.16396327991969883, 0.20611817337339744, 0.15442868607351556, 0.17298184364335611, 0.17377313633915037, 0.1854788832133636, 0.28376313275657594, 0.12380488988128491, 0.21299293963238597, 0.09234310506144539, 0.1642661207006313, 0.16691425204044208, 0.07748538278974593, 0.11657018199912272, 0.1887424776214175, 0.13130100443959236, 0.084100686799502, 0.08660760227940045, 0.15127010556170717, 0.24607237632153556, 0.1203417096985504], [0.03629532584454864, 0.036729411731357686, 0.003796916107603465, 0.034815494509530254, 0.045402646719594486, 0.041180486950906925, 0.06538283923873678, 0.047651903369114734, 0.048928512405836955, 0.01768254969647387, 0.06046969174349215, 0.055806440213928, 0.040209353319369256, 0.026996668166248128, 0.03988180644228123, 0.03868288542435039, 0.05195918747631367, 0.00829686407087138, 0.0575065038719913, 0.14553472894476727, 0.05328103041392751, 0.026456846644578036, 0.11403408527257852, 0.058320060998084955, 0.02633090418385109, 0.051411760796327144, 0.08384797809412703, 0.04184649769740645, 0.051805978509946726, 0.03226693341275677, 0.41500366700347513, 38.760192543268204, 62.55648024380207, 35.01511350274086, 40.887774378061295, 54.51974429190159, 7.077267486602068, 0.06221639196155593, 0.9570262650959194, 0.9548733837436885, 0.2708909078501165, 6.993864336982369, 6.249406384304166, 0.6794010498560965, 0.22050803090678528, 38.47563721239567, 92.23046734929085, 73.01256537437439, 87.33746230602264, 72.08505034446716, 74.11462023854256, 72.61960566043854, 79.3387471139431, 73.53517413139343, 73.32547098398209, 78.3340810239315, 78.79296720027924, 74.98433277010918, 74.23720926046371, 74.1664570569992, 72.94747486710548, 75.43144717812538, 75.4872889816761, 72.50476822257042, 70.28006359934807, 66.34500235319138, 66.24696761369705, 59.41534459590912, 59.412699937820435, 55.939218923449516, 50.60860276222229, 51.89705282449722, 49.2426710575819, 52.7202520519495, 50.60799479484558, 49.81262527406216, 49.692323729395866, 52.207150384783745, 50.5853746086359, 53.87806512415409, 63.84429574012756, 65.86837872862816, 67.64138638973236, 66.25239372253418, 67.10077419877052, 67.46427789330482, 66.26757010817528, 62.114054784178734, 66.95005148649216, 42.987674698233604, 59.90005798637867, 69.38486203551292, 66.06415182352066, 67.58441984653473, 67.33120903372765, 66.36375814676285, 67.25681662559509, 63.10099482536316, 60.7299030572176, 72.2567631304264, 62.50143259763718, 64.83643010258675, 63.677982464432716, 62.209308072924614, 51.46797224879265, 45.02206653356552, 47.29908674955368, 47.43686355650425, 47.054972648620605, 49.25048343837261, 47.20853380858898, 50.131739750504494, 61.698056906461716, 63.51042665541172, 65.08755102753639, 65.69886222481728, 66.97321504354477, 66.61185443401337, 63.16743426024914, 60.146736949682236, 53.747606724500656, 51.804827973246574, 54.75654758512974, 61.509932801127434, 62.15641491115093, 58.43171037733555, 62.799325212836266, 60.734272822737694, 59.98374469578266, 56.15344762802124, 63.40839073061943, 56.609951332211494, 59.376351088285446, 66.45043149590492, 72.21773162484169, 60.170215889811516, 81.8345519900322, 35.764262303709984, 0.048954929152387194, 0.28639027616009116, 2.228382113389671, 4.449937418103218, 0.40393984818365425, 0.6168248201720417, 0.17585880879778415, 0.1903702598065138, 41.697659119963646, 36.66666068136692, 19.939948730170727, 53.558901250362396, 18.974937312304974, 0.04390288500871975, 0.07047343795420602, 0.07004956773016602, 0.09391236148076132, 0.03410880293813534, 0.06587921729078516, 0.050688801347860135, 0.0386891899688635, 0.0483714415167924, 0.039362050738418475, 0.05677546614606399, 0.06125441643234808, 0.03901887423126027, 0.01707028342934791, 0.04022047811304219, 0.015212328780762618, 0.06301751069258898, 0.015251816603267798, 0.06996959389653057, 0.02056757457467029, 0.05427806871011853, 0.0448214597417973, 0.04721284509287216, 0.018819145152519923, 0.047366536455228925, 0.03683831819216721, 0.08012495716684498, 0.027602010195550974, 0.026509958443057258, 0.08905131646315567, 0.013325714244274423, 0.061157462259870954, 0.05341289892385248, 0.04623578912287485, 0.03133372723823413, 0.028192243953526486, 0.020076365581189748, 0.08231297179008834, 0.026507763541303575, 0.08251802719314583, 0.04011493358120788, 0.04007491697848309, 0.034826281626010314, 0.07845508778700605, 0.0486578956770245, 0.025139810968539678, 0.05143930931808427, 0.04300769534893334, 0.019573746067180764, 0.04240815505909268, 0.06201219373906497, 0.02987944804772269, 0.028605488478206098, 0.0781345170980785, 0.026270986891177017, 0.8327594550792128, 54.851762875914574, 64.56165924668312, 28.812086954712868, 62.85425506532192, 61.499601155519485, 10.297124460339546, 0.12178981793113053, 0.6758122018072754, 1.2858030293136835, 2.2400379879400134, 6.034453343600035, 5.856083789840341, 1.0098319128155708, 0.3171278955414891, 44.90511640906334, 94.57174211740494, 79.41598936915398, 89.1178871691227, 73.97924110293388, 79.85302671790123, 75.80040737986565, 81.32803156971931, 74.17233914136887, 76.82908818125725, 79.9995544552803, 80.64936518669128, 77.82225608825684, 77.46706634759903, 76.47311568260193, 76.16955757141113, 77.18725696206093, 76.66379705071449, 75.3868679702282, 73.74385133385658, 68.83116334676743, 66.9203294813633, 62.90082536637783, 62.35443748533726, 58.287481516599655, 53.541080206632614, 55.59032164514065, 52.36994504928589, 53.14739853143692, 52.857922464609146, 51.59344531595707, 50.8732395619154, 53.66205431520939, 52.10546024143696, 54.81648176908493, 67.71893262863159, 67.59392693638802, 68.47753152251244, 68.81772726774216, 69.66709569096565, 68.25053930282593, 69.18128415942192, 63.58539283275604, 69.84811037778854, 44.82742577791214, 58.42799037694931, 68.76298740506172, 65.74129834771156, 69.50860619544983, 67.5163958966732, 67.18652039766312, 68.60476389527321, 66.31602510809898, 61.992012932896614, 72.54433169960976, 64.57082435488701, 67.06280663609505, 67.85555809736252, 64.21705573797226, 54.67208191752434, 45.69754868745804, 49.18174512684345, 49.52768616378307, 49.87322062253952, 51.0774140059948, 51.74931675195694, 51.117570251226425, 63.67413707077503, 66.20502546429634, 64.88531067967415, 65.72633475065231, 67.73116797208786, 70.36707133054733, 65.16863107681274, 60.89009866118431, 56.611657440662384, 52.99180068075657, 57.66635924577713, 62.998886704444885, 63.871813863515854, 60.65322317183018, 64.10093396902084, 64.48614209890366, 62.515689432621, 58.81910338997841, 65.56135520339012, 59.83874827623367, 61.77627190947533, 67.06308022141457, 76.59258887171745, 63.54548737406731, 83.9289540052414, 38.15012387931347, 0.038139633325045, 0.9496651694644243, 2.2956689028069377, 1.1641215649433434, 0.7918829109985381, 0.5697640485595912, 0.17091935587814078, 0.761909110005945, 50.253078639507294, 54.439811781048775, 16.451893597841263, 55.937744602561, 28.56346059590578, 0.13639679818879813, 0.016247273197222967, 0.06047787392162718, 0.057293774661957286, 0.04334986995672807, 0.03431514967815019, 0.020312212691351306, 0.05647279976983555, 0.06321308144833893, 0.02060944098047912, 0.032615056334179826, 0.04557258740533143, 0.02564282938692486, 0.03912364692951087, 0.03212059302313719, 0.08482396166073158, 0.04050718831422273, 0.0417354724049801, 0.0225659964416991, 0.09387964018969797, 0.0486999902932439, 0.031322472568717785, 0.06098334699345287, 0.09387959566083737, 0.05258771234366577, 0.13060902594588697, 0.23350527801085263, 0.11971751897362992, 0.1405341230565682, 0.14689827687107027, 0.10079929154017009, 0.16937343258177862, 0.125342553074006, 0.08793888162472285, 0.12673559394897893, 0.16332941158907488, 0.1921978429891169, 0.16152695752680302, 0.09551446535624564, 0.14071216428419575, 0.15385892445920035, 0.1575835855328478, 0.1003826127271168, 0.17847796669229865, 0.16109703137772158, 0.12003339928924106, 0.10399637467344292, 0.12169667839771137, 0.09254401185899042, 0.17161155701614916, 0.17042993917129934, 0.19192164530977607, 0.14654498489107937, 0.16559584153583273, 0.21158371993806213, 1.0977175156585872, 69.43541452288628, 82.20729678869247, 51.43816664814949, 60.325836539268494, 72.47649773955345, 15.390395857393742, 0.26743039197754115, 1.8840214353986084, 5.198762761428952, 6.991303749382496, 25.652368403971195, 13.882532268762589, 0.8359195198863745, 0.2609756664605811, 43.905435651540756, 98.35050255060196, 81.46689891815186, 93.28576192259789, 77.7906645834446, 85.1412333548069, 77.6695042848587, 87.50062555074692, 78.79469990730286, 79.8057496547699, 83.49545806646347, 83.82625311613083, 81.83925613760948, 80.88619887828827, 79.34135377407074, 77.80673012137413, 79.94305908679962, 80.64580097794533, 77.86951795220375, 75.3436566889286, 71.47182404994965, 70.12886971235275, 66.96467310190201, 64.51693564653397, 61.858807280659676, 55.915386602282524, 59.14886109530926, 55.583766996860504, 57.40531325340271, 56.57084763050079, 54.72550705075264, 54.71191518008709, 58.19837249815464, 54.95053857564926, 58.438439816236496, 70.17280295491219, 71.58124297857285, 71.26476556062698, 70.62097370624542, 73.35641652345657, 71.74873039126396, 71.01021721959114, 66.26635417342186, 73.40028136968613, 49.10602658987045, 61.11406244337559, 73.22899416089058, 68.23618367314339, 71.98996424674988, 70.33452227711678, 69.14630323648453, 73.60712707042694, 70.4725992679596, 65.75921818614006, 72.15787723660469, 66.74604043364525, 70.08052870631218, 71.10199749469757, 66.40595108270645, 56.68054774403572, 49.03975434601307, 51.775501146912575, 52.04731196165085, 51.87018446624279, 54.75253500044346, 53.881636932492256, 55.608670860528946, 68.35045874118805, 70.88029459118843, 68.1268559396267, 66.54797986149788, 69.09664750099182, 71.90484881401062, 68.72347712516785, 66.18819236755371, 59.922932758927345, 58.247401267290115, 60.56785695254803, 66.34830817580223, 68.61781239509583, 63.4268881380558, 68.77262368798256, 68.07236686348915, 65.90424120426178, 62.038602232933044, 69.78773921728134, 62.36164949834347, 64.26206052303314, 72.53563016653061, 79.94696527719498, 63.83294954895973, 85.2420723438263, 41.281889230012894, 0.18955127015942708, 0.6146911752875894, 7.068250570446253, 13.247078116983175, 2.1249718498438597, 2.286409749649465, 0.9000913077034056, 1.4985710685141385, 59.39733736217022, 51.87590315937996, 30.25631345808506, 69.8820349574089, 39.16239336133003, 0.1933401863789186, 0.14533231558743864, 0.18317617708817124, 0.13686132326256484, 0.15554161072941497, 0.19337929756147787, 0.15197749104117975, 0.12018745430395938, 0.1214139349758625, 0.09352285269415006, 0.15549150091828778, 0.15642354934243485, 0.1840699158492498, 0.19066432840190828, 0.12867115961853415, 0.12027163611492142, 0.1485929117188789, 0.12766546045895666, 0.19878358725691214, 0.15086798026459292, 0.14437395060667768, 0.10720361780840904, 0.1376245924620889, 0.14360330445924774, 0.13756747677689418], [0.02420438948320225, 0.04142853867961094, 0.05223081723670475, 0.03345167569932528, 0.040708328888285905, 0.06364803935866803, 0.046829217826598324, 0.09695281434687786, 0.10079091269290075, 0.020004034013254568, 0.09095047978917137, 0.1282696280395612, 0.038179820621735416, 0.04164268910244573, 0.02076865577691933, 0.07361307885730639, 0.06849539917311631, 0.023557613349112216, 0.0401451389916474, 0.06307698640739545, 0.05600328746368177, 0.04358409918495454, 0.03361554932780564, 0.017841964872786775, 0.0330784162360942, 0.05435753417259548, 0.08045927985222079, 0.058566617299220525, 0.07239719605422579, 0.06228409809409641, 0.33380713022779673, 7.905382225289941, 68.46508339047432, 54.10501554608345, 29.43202368915081, 58.508310467004776, 37.37275779247284, 0.49553699092939496, 0.4156558960676193, 0.7242262945510447, 1.1007548589259386, 1.4679480367340147, 3.3971184119582176, 0.3195041633443907, 0.06709186432999559, 0.39067689736839384, 60.01733109354973, 91.57761678099632, 76.44932135939598, 86.39642000198364, 74.71026107668877, 76.36677458882332, 71.44248202443123, 76.026411652565, 79.0647742152214, 78.91674935817719, 77.88678422570229, 76.56996488571167, 77.4985058605671, 76.2387366592884, 74.27695512771606, 74.27731230854988, 75.63447788357735, 76.06582313776016, 69.6868622303009, 65.61987206339836, 65.29865249991417, 66.50591611862183, 58.844421431422234, 51.221167892217636, 51.076194271445274, 52.00920380651951, 50.17234057188034, 51.1521065980196, 50.06889872252941, 48.83927330374718, 49.075913205742836, 51.05908378958702, 48.9905621856451, 56.91531054675579, 61.49902358651161, 67.42667511105537, 68.19922685623169, 64.9403165280819, 67.36663073301315, 68.36174413561821, 66.47326067090034, 61.60055033862591, 64.97883126139641, 38.621036410331726, 57.00337082147598, 69.18215811252594, 65.19643798470497, 68.97987216711044, 63.417571038007736, 67.29915395379066, 64.98953148722649, 64.21852245926857, 73.33278939127922, 69.2304003238678, 67.6030920445919, 66.1113452911377, 60.700640827417374, 57.76854336261749, 46.4858315885067, 49.05064836144447, 47.26146496832371, 50.59064872562885, 47.63145871460438, 48.57641100883484, 46.568879932165146, 50.2266738563776, 61.86515673995018, 67.57190331816673, 65.32567664980888, 67.0860005915165, 67.39476442337036, 68.54171007871628, 62.525998279452324, 65.2038399875164, 54.18382711708546, 51.21683232486248, 58.02771985530853, 66.03250712156296, 63.078515231609344, 67.16332644224167, 60.08011132478714, 61.42287567257881, 63.30806851387024, 67.47405096888542, 56.91925473511219, 60.707252472639084, 63.801198452711105, 67.32360944151878, 65.80046877264977, 78.90479519963264, 50.21557845175266, 0.4683786607347429, 0.07861063451855443, 0.11119497707113624, 2.0528455451130867, 0.9157267562113702, 0.8333574479911476, 0.10488277359399945, 0.5489297665189952, 20.3193336725235, 61.819661781191826, 15.455983188003302, 37.18198522925377, 55.52573271095753, 7.062820661813021, 0.4038357693934813, 0.07202057837275788, 0.07076070105540566, 0.1454828676651232, 0.05480177263962105, 0.06288733799010515, 0.04937879566568881, 0.06633146724198014, 0.03726347233168781, 0.07231682146084495, 0.06920478845131584, 0.02547162519476842, 0.023959170903253835, 0.014244147041608812, 0.11417857400374487, 0.07447610012604855, 0.010553491174505325, 0.07399276160867885, 0.07708100878517143, 0.06232499043107964, 0.023525556280219462, 0.03547340471413918, 0.058447016490390524, 0.03022142413101392, 0.0328299192187842, 0.020426778028195258, 0.06510958788567223, 0.06728530512191355, 0.06319277628790587, 0.0360917436046293, 0.041284458129666746, 0.061733914335491136, 0.032543654306209646, 0.10966805275529623, 0.05513914555194788, 0.0025901116259774426, 0.08038961444981396, 0.0368789322237717, 0.05375887703849003, 0.029888643257436343, 0.0431586222111946, 0.023490142848459072, 0.02633080028317636, 0.06965484164538793, 0.05606934973911848, 0.06176704751851503, 0.041540721722412854, 0.05442583773401566, 0.03801632919930853, 0.023817711989977397, 0.08651937576360069, 0.02605125366244465, 0.07818470112397335, 0.016448248643428087, 0.1373668445739895, 0.4662983911111951, 11.648773681372404, 86.27252385020256, 45.117889791727066, 34.05132941901684, 77.23415404558182, 39.42090108990669, 0.527902526082471, 0.20948976511135697, 0.9331251913681626, 0.413696626201272, 2.124459589831531, 2.3051919043064117, 1.0985187976621091, 0.5656016687862575, 0.8302055764943361, 68.56303453445435, 96.19256794452667, 80.50888672471046, 87.77345851063728, 78.74781802296638, 79.87631186842918, 74.3335872888565, 80.96818327903748, 81.68752267956734, 80.03821358084679, 79.96214926242828, 79.96830493211746, 80.20353510975838, 77.41515353322029, 76.10111564397812, 77.1309743821621, 79.49564829468727, 76.24414756894112, 72.71999627351761, 67.13778421282768, 70.00432759523392, 69.09880578517914, 63.64621616899967, 56.41770824790001, 53.68063151836395, 53.2065499573946, 53.35295990109444, 54.48926232755184, 54.9395951628685, 52.60220758616924, 51.52796342968941, 52.73889385163784, 50.652847588062286, 58.87735426425934, 65.49073979258537, 70.41727423667908, 70.65569624304771, 66.31497636437416, 69.27365720272064, 69.62223529815674, 70.04623174667358, 66.19040384888649, 68.41393053531647, 41.207466423511505, 59.21782359480858, 72.03083485364914, 66.60322889685631, 70.22058919072151, 67.82671004533768, 69.92171242833138, 68.9349889755249, 66.53994709253311, 75.558892339468, 69.34276029467583, 68.80589470267296, 69.24110814929008, 61.62179879844189, 61.64561592042446, 51.20319485664368, 51.906453520059586, 50.26158258318901, 51.632184237241745, 48.16798992455006, 50.00138774514198, 49.10858765244484, 53.9375851303339, 64.97248560190201, 68.45744580030441, 67.10013583302498, 67.3360575735569, 67.10745424032211, 70.37291541695595, 64.59796249866486, 66.9981949031353, 57.62853227555752, 53.63138236105442, 59.120689406991005, 68.8391201198101, 65.93008741736412, 69.58243623375893, 62.32328675687313, 63.6809691041708, 64.57669883966446, 69.06331568956375, 59.81240049004555, 61.062514409422874, 68.29909309744835, 69.15274009108543, 67.76039600372314, 79.59845557808876, 53.03114376962185, 0.3208666277350858, 0.19452857261057943, 1.4050810039043427, 0.8368254743982106, 0.703506600111723, 0.6081156281288713, 0.08179162789019756, 0.600485815666616, 21.38432152569294, 83.3535660803318, 22.933452799916267, 27.85272393375635, 68.53265896439552, 8.226066492497921, 0.2535768994130194, 0.09165138631942682, 0.09499671345110983, 0.11803806846728548, 0.029164409170334693, 0.0695123863988556, 0.027574431987886783, 0.051121310170856304, 0.052658405620604753, 0.03270331995736342, 0.024327183382411022, 0.07693673527683131, 0.03685942116135266, 0.029097085243847687, 0.06660705636022612, 0.048242641787510365, 0.04056853795191273, 0.06413815368432552, 0.03857157440506853, 0.047465067691518925, 0.0634915946284309, 0.016236209630733356, 0.07734296465059742, 0.07129952995455824, 0.024785058812994976, 0.12481920537538826, 0.1416131018777378, 0.21228481200523674, 0.09662591313826852, 0.16826142818899825, 0.23101371014490724, 0.15666321851313114, 0.22503124288050458, 0.17847907991381362, 0.13300822611199692, 0.18380679481197149, 0.1538644460379146, 0.15895951248239726, 0.20028965722303838, 0.14083371323067695, 0.1723454223247245, 0.15526367642451078, 0.18154210149077699, 0.16057941305916756, 0.12257551483344287, 0.1570547162555158, 0.14749677444342524, 0.13098318711854517, 0.12303226219955832, 0.14032327890163288, 0.24524807289708406, 0.19388018787140027, 0.30125264427624643, 0.26651386928278953, 0.6717078876681626, 1.167747164145112, 16.561449319124222, 96.02385699748993, 69.00353729724884, 42.25172258913517, 77.1557566523552, 55.81765964627266, 1.9623132655397058, 2.4375770380720496, 4.768563145771623, 5.757799688726664, 8.72389867901802, 10.018166229128838, 0.8412508713081479, 0.5687931412830949, 1.5374552132561803, 68.34891602396965, 97.6165871322155, 83.53005900979042, 92.58262485265732, 80.49361914396286, 83.55020552873611, 76.90484091639519, 83.4773026406765, 84.1429129242897, 82.23096951842308, 85.0669777393341, 80.37353798747063, 82.38295376300812, 81.12302497029305, 79.246396869421, 79.56288948655128, 79.55581426620483, 77.95108437538147, 75.5280151963234, 71.03005215525627, 71.67170092463493, 73.60942214727402, 66.45455807447433, 57.07946173846722, 56.722303703427315, 57.67073281109333, 56.758097782731056, 58.04142951965332, 57.64160357415676, 54.8753672093153, 53.62963445484638, 56.89552500844002, 55.63402310013771, 63.77931162714958, 68.4434625506401, 74.47429373860359, 71.88386633992195, 69.95840325951576, 72.65156954526901, 72.37306728959084, 72.2634507715702, 69.67325896024704, 68.91461446881294, 44.785050451755524, 60.19278287887573, 73.1741327047348, 69.94899496436119, 72.38952800631523, 70.49861267209053, 72.5461708009243, 71.16261184215546, 68.41117188334465, 74.04894456267357, 72.84314766526222, 71.90840542316437, 72.78020024299622, 65.37638872861862, 63.336209803819656, 53.619390204548836, 55.24287588894367, 52.760336101055145, 55.41636697947979, 51.87444783747196, 53.459016010165215, 51.16850271821022, 56.07575319707394, 66.96754574775696, 72.27568611502647, 70.21194845438004, 70.45100882649422, 68.32697600126266, 72.80716359615326, 65.703946352005, 72.19675675034523, 61.66982062160969, 56.83749072253704, 62.67292499542236, 72.1012906730175, 69.51623618602753, 73.59456494450569, 63.41018423438072, 66.57344609498978, 69.32271257042885, 73.89357849955559, 62.692813128232956, 66.10480964183807, 70.0513006746769, 73.67181479930878, 70.8943310379982, 82.33639106154442, 54.37653757631779, 1.3315379689447582, 0.4853112646378577, 1.3039166573435068, 7.371461950242519, 3.160832365974784, 2.280389447696507, 2.288785809651017, 1.1631269683130085, 33.08005593717098, 76.583112180233, 24.61527105420828, 47.199429497122765, 80.48845142126083, 12.176899742335081, 0.9441235824488103, 0.39819618919864297, 0.27810357394628227, 0.2514752559363842, 0.22842940350528806, 0.17186376848258078, 0.11471000369056128, 0.21864246460609138, 0.14621858834289014, 0.138342353166081, 0.1160554432135541, 0.17027315305313095, 0.10335806087823585, 0.12142069594119675, 0.37441243417561054, 0.15486818592762575, 0.08517485650372691, 0.13994790060678497, 0.0848134008992929, 0.17450382525566965, 0.13994294306030497, 0.15177429100731388, 0.16728844289900735, 0.21793825551867485, 0.11134259766549803], [0.05830652422446292, 0.0673061000998132, 0.08583498201915063, 0.02302993892953964, 0.014341933347168379, 0.019118907875963487, 0.10201423181570135, 0.040025786802289076, 0.03490805516776163, 0.034808919081115164, 0.03896117596013937, 0.03990794488345273, 0.04758368886541575, 0.09945443831384182, 0.026725300012913067, 0.01193613548821304, 0.02408865897450596, 0.013976244717923691, 0.0460100983036682, 0.08482376128085889, 0.03939610789529979, 0.06334381076158024, 0.04027876268082764, 0.05042024036811199, 0.03989882017776836, 0.04274556507880334, 0.026879041470238008, 0.029869824247725774, 0.02619776474602986, 0.07730889265076257, 0.02627375510201091, 0.12101119369617663, 29.162038676440716, 75.65653949975967, 40.29718726873398, 38.65701287984848, 68.23752120137215, 11.644068583846092, 0.29320161847863346, 0.5127509578596801, 0.6770444044377655, 1.1601845012046397, 3.0284636188298464, 0.9740220999810845, 0.10626535018673167, 0.04777227601152845, 1.3440864393487573, 63.17192181944847, 100.82381263375282, 78.9214839041233, 80.15299782156944, 73.80967140197754, 78.4139071404934, 75.54994001984596, 76.82914137840271, 78.24981674551964, 80.06311744451523, 76.45287796854973, 73.8781513273716, 72.5104071199894, 74.2846231162548, 76.58862188458443, 76.30014896392822, 72.23295360803604, 70.89963555335999, 69.7731252014637, 67.5471818447113, 61.0620242357254, 57.55455404520035, 50.89362546801567, 53.42880763113499, 53.28879654407501, 53.66373002529144, 52.01561786234379, 53.47038500010967, 52.44619935750961, 51.89247027039528, 51.19641222059727, 52.763216346502304, 57.22720921039581, 61.62445105612278, 62.985868602991104, 65.27170434594154, 68.53787988424301, 70.66279426217079, 68.9419350028038, 68.89392837882042, 62.06118442118168, 66.26352712512016, 30.103481858968735, 56.000042259693146, 69.01632741093636, 64.68605697154999, 65.03091886639595, 63.608119413256645, 65.93835577368736, 63.56420136988163, 67.22849294543266, 65.80009639263153, 67.16868415474892, 64.24827486276627, 61.708852127194405, 58.08964513242245, 50.16902714967728, 47.079686522483826, 48.186270743608475, 50.34025736153126, 50.00928372144699, 49.36273701488972, 50.059999600052834, 50.3105391561985, 46.81211248040199, 60.70011265575886, 68.10886010527611, 65.89077472686768, 66.72777101397514, 67.09762036800385, 69.89102527499199, 68.46113160252571, 63.98833841085434, 60.005091950297356, 53.53189989924431, 62.413064539432526, 68.31831246614456, 70.19797280430794, 66.04979619383812, 68.73880550265312, 66.39298617839813, 65.3295448422432, 63.317556604743004, 65.74667885899544, 62.661153227090836, 60.89022405445576, 71.88404873013496, 74.62118625640869, 70.07806643843651, 3.018313175998628, 0.15214708662824705, 0.23375876597128808, 1.3276405655778944, 0.8465612644795328, 0.37706985720433295, 0.07464819675078616, 0.16956561914412305, 7.929779291152954, 57.083550319075584, 25.400971993803978, 29.752766378223896, 52.63082765042782, 38.222821578383446, 0.4089678096352145, 0.2577555470634252, 0.0391496888914844, 0.08066290291026235, 0.01445705436708522, 0.010747550732048694, 0.036420678297872655, 0.04955499265633989, 0.05222265732300002, 0.013816218197462149, 0.038541361573152244, 0.0916559282632079, 0.05973273538984358, 0.04234133579302579, 0.007870748850109521, 0.013690648665942717, 0.06548538178321905, 0.0802331994054839, 0.05885640741325915, 0.030978386930655688, 0.028992696607019752, 0.07869997425586917, 0.05414111648860853, 0.028059987671440467, 0.03715105922310613, 0.026642029188224114, 0.027863379764312413, 0.03124189388472587, 0.08130641916068271, 0.054233832997852005, 0.04354141085059382, 0.02344158783671446, 0.010071141568914754, 0.030695231616846286, 0.03839238655928057, 0.06719644035911188, 0.014374271504493663, 0.04527413642790634, 0.05362360207072925, 0.13788722368190065, 0.025321275352325756, 0.013033918476139661, 0.032497244101250544, 0.07597976553370245, 0.04588989635522012, 0.07266513362992555, 0.030207785312086344, 0.05916868460190017, 0.06792894753743894, 0.013832034292136086, 0.04148926862399094, 0.06917353661265224, 0.06777581278583966, 0.043161676148884, 0.04858721724303905, 0.05362549825804308, 0.02873821973480517, 0.3059324197238311, 40.93580760061741, 81.54362440109253, 30.76154574751854, 56.87768876552582, 82.7533882856369, 13.218467552214861, 0.20877475035376847, 0.24202882923418656, 0.7599353534169495, 0.8980555669404566, 3.24475537519902, 1.2498228787444532, 0.31841786694712937, 0.12305239666602574, 1.8398174573667347, 75.03866985440254, 102.99668043851852, 80.93533024191856, 80.86703270673752, 79.15741324424744, 82.83611744642258, 76.14986702799797, 78.89306142926216, 83.15913811326027, 84.00676622986794, 76.72051280736923, 76.16973236203194, 76.82515159249306, 77.23692789673805, 77.1633942425251, 78.48135352134705, 74.08530101180077, 73.79586294293404, 71.42893195152283, 69.33726578950882, 64.39609453082085, 63.093513026833534, 54.16057236492634, 55.766753777861595, 57.01044604182243, 55.53471922874451, 53.80447827279568, 54.826931208372116, 52.247891798615456, 55.05687586963177, 53.83172281086445, 53.59665982425213, 59.906160458922386, 65.05529835820198, 65.98252460360527, 68.07124972343445, 72.19614118337631, 72.38895803689957, 69.84405219554901, 68.44584122300148, 63.06738942861557, 66.12851276993752, 32.91151978075504, 56.33727416396141, 70.78991264104843, 66.22869059443474, 67.2289489209652, 64.48187872767448, 71.71681210398674, 61.83390721678734, 69.07628059387207, 67.55700051784515, 69.30413916707039, 66.39401212334633, 62.720878422260284, 61.39094218611717, 51.42422899603844, 48.87416683137417, 50.26670090854168, 51.21043346822262, 52.1787279099226, 51.15767329931259, 52.070220932364464, 51.635186076164246, 48.730074763298035, 61.208122596144676, 69.87027078866959, 68.04962888360023, 69.90007638931274, 66.12329944968224, 71.58666908740997, 70.38467198610306, 66.34162053465843, 61.27694070339203, 56.339455246925354, 66.15300625562668, 70.8620023727417, 71.08146339654922, 69.45004373788834, 69.69101160764694, 70.1107294857502, 66.61832928657532, 65.00693455338478, 67.55466744303703, 68.15768748521805, 63.215855062007904, 75.14343023300171, 73.3062744140625, 73.74996900558472, 2.832450424320996, 0.1594254921656102, 0.9271187824197114, 0.250009098672308, 0.5599972663912922, 0.2495364990318194, 0.23217770940391347, 0.28220515698194504, 10.622401256114244, 71.11522078514099, 40.71906343102455, 16.655545569956303, 56.81937709450722, 45.70602983236313, 0.907550782430917, 0.15763436327688396, 0.04979512938007247, 0.050780708916136064, 0.04201173687761184, 0.0274303495825734, 0.032592446805210784, 0.015501333145948593, 0.04615595629729796, 0.011770917644753354, 0.053733261811430566, 0.006122532795416191, 0.040439704825985245, 0.008358383474842412, 0.055704116603010334, 0.013392662458500126, 0.053200384936644696, 0.045318127231439576, 0.083006308414042, 0.010316737716493662, 0.060207743299542926, 0.023422371777996887, 0.03956197419029195, 0.01579809388204012, 0.05462170534883626, 0.026236156045342796, 0.16137591563165188, 0.18683606351260096, 0.1261230549425818, 0.12132043179008178, 0.15951253124512732, 0.1137052099511493, 0.2541038242634386, 0.11309568406431936, 0.11775057530030608, 0.11196891835425049, 0.06373530108248815, 0.18913179344963282, 0.15472278435481712, 0.1896459236741066, 0.19585360307246447, 0.18476183497114107, 0.20332091487944126, 0.11404124699765816, 0.1423441618680954, 0.1372828334569931, 0.06619480816880241, 0.17464535281760618, 0.1477905610227026, 0.09853257957729511, 0.16686250950442627, 0.20972636179067194, 0.128362144168932, 0.16064767580246553, 0.1342916369321756, 0.12889261648524553, 0.06356273690471426, 0.6350591510999948, 54.938994795084, 98.90393525362015, 56.20463468134403, 55.51891967654228, 87.04848021268845, 21.43279742449522, 0.5282097158487886, 2.6210862910375, 3.940476905554533, 3.3507608994841576, 12.038440871983767, 4.080307502299547, 0.28932594519574195, 0.20230709662428126, 2.830600873567164, 73.41858878731728, 109.40518856048584, 85.56282073259354, 86.21327742934227, 81.78667455911636, 85.56615695357323, 83.01777809858322, 81.86371922492981, 85.53479343652725, 85.25858625769615, 80.513636469841, 79.32973399758339, 78.14623430371284, 77.53654941916466, 78.54321420192719, 80.47887593507767, 77.74413987994194, 74.84481185674667, 76.28667488694191, 73.55294957756996, 67.47345060110092, 64.37223941087723, 56.71321839094162, 60.649206787347794, 60.01466363668442, 59.48182962834835, 58.2262060046196, 59.78030361235142, 55.66426947712898, 58.248233422636986, 57.32161894440651, 57.032184675335884, 63.248107731342316, 67.41101235151291, 69.45645779371262, 71.10741600394249, 76.12961411476135, 74.6340523660183, 74.0591736137867, 70.68017452955246, 68.49176555871964, 71.61776661872864, 36.394257098436356, 59.59732823073864, 74.81057569384575, 72.14843854308128, 71.33221954107285, 70.417889803648, 72.22147822380066, 68.40179398655891, 67.88776516914368, 71.22875109314919, 70.59312120079994, 69.68946889042854, 64.17178496718407, 63.848293125629425, 53.38558495044708, 52.20630683004856, 51.74477219581604, 54.99124199151993, 54.22577306628227, 56.156240478158, 54.35205169022083, 56.81196749210358, 51.21005728840828, 67.34678819775581, 75.39797097444534, 72.36824914813042, 70.9914918243885, 66.11021295189857, 75.1771268248558, 76.13218277692795, 70.35943374037743, 65.23447394371033, 61.14702947437763, 69.72190394997597, 74.26796481013298, 74.92866575717926, 72.66091704368591, 73.51020187139511, 72.55520671606064, 70.71597620844841, 69.11920309066772, 72.52545431256294, 70.09909451007843, 67.00318783521652, 77.16468617320061, 77.0562855899334, 73.58765691518784, 4.692201018333435, 0.35347638884559274, 1.0513898078352213, 6.993582202121615, 2.6532636769115925, 0.973640161100775, 0.9936135518364608, 0.6527250562794507, 16.358032934367657, 73.77810269594193, 36.981124207377434, 40.707489252090454, 67.22404718399048, 56.32470063865185, 1.2209890759550035, 0.3347274230327457, 0.13827517395839095, 0.213121167907957, 0.12468843895476311, 0.18143330264138058, 0.20530310226604342, 0.1366249640705064, 0.18192889401689172, 0.12407541755237617, 0.11893713584868237, 0.20232011389452964, 0.11901411882718094, 0.12238775147125125, 0.10887924625421874, 0.15123759949347004, 0.17122764402301982, 0.26681114395614713, 0.21535874315304682, 0.08418356243055314, 0.12293265855987556, 0.138615018222481, 0.12188407068606466, 0.10103936889208853, 0.09755406528711319, 0.1703386550070718], [0.08125322943669744, 0.051354337119846605, 0.03008017116371775, 0.05541504637221806, 0.034609299909789115, 0.042622175606084056, 0.06593801765120588, 0.039615742789465, 0.08339876352692954, 0.0804106766008772, 0.06851898462628014, 0.03570957465854008, 0.1339376176474616, 0.050672229190240614, 0.048386685230070725, 0.01682047837675782, 0.06672240837360732, 0.009971562976716086, 0.10383870539953932, 0.07049826279398985, 0.06825604170444421, 0.09571256683557294, 0.029685651024919935, 0.07573110895464197, 0.05413514591054991, 0.05825829575769603, 0.044266214536037296, 0.0483472734777024, 0.08794609530013986, 0.2848178136628121, 0.06699017525534146, 0.26804696826729923, 3.166846730746329, 64.05000150203705, 72.14068695902824, 29.56759851425886, 45.83004377782345, 56.558372899889946, 2.483944525010884, 0.09561835860949941, 0.3025795746361837, 1.1385802854783833, 0.9412117511965334, 1.3636274845339358, 0.44983158877585083, 0.04016558516013902, 0.03125419869320467, 2.04024494625628, 59.37772661447525, 97.16452538967133, 81.4094004034996, 84.99466761946678, 72.7757240831852, 80.98918855190277, 84.82803896069527, 77.23042264580727, 71.14632591605186, 78.72475326061249, 77.27022171020508, 77.98656687140465, 77.47755378484726, 76.38350889086723, 75.80634266138077, 72.40218132734299, 72.27722123265266, 64.37403291463852, 65.63506364822388, 62.37835340201855, 56.98978275060654, 52.38159142434597, 52.94905677437782, 51.20649307966232, 54.67221111059189, 50.32336346805096, 54.66464191675186, 48.25041890144348, 52.98366151750088, 48.912856355309486, 55.14376200735569, 57.84433029592037, 59.37114916741848, 58.74355584383011, 63.913163244724274, 62.45048873126507, 69.52711880207062, 66.15839436650276, 76.32309213280678, 57.86419562995434, 77.22099155187607, 30.411778315901756, 52.767247930169106, 70.92805802822113, 65.80719441175461, 62.782587110996246, 55.999373495578766, 60.18766835331917, 62.416674345731735, 63.406483232975006, 64.67689946293831, 64.23530235886574, 60.76176054775715, 58.58654826879501, 53.35718147456646, 47.99802124500275, 49.08412076532841, 50.20553559064865, 52.79461786150932, 49.03058163821697, 48.860263377428055, 47.30652295053005, 49.72084879875183, 46.06537654995918, 56.5611619502306, 66.58631220459938, 67.02684536576271, 69.6420094370842, 67.28514790534973, 70.43405413627625, 65.96696823835373, 69.81852516531944, 61.712549328804016, 57.08843685686588, 63.096419870853424, 69.40312385559082, 71.5727998316288, 71.5455324947834, 67.79098436236382, 64.42376464605331, 71.07236668467522, 68.02614614367485, 63.15598547458649, 62.0958461612463, 76.5512166917324, 63.19963373243809, 89.06963735818863, 17.208370305597782, 0.189727678662166, 0.7299467688426375, 0.7024576782714576, 1.7145652533508837, 0.22280187578871846, 0.16556749149458483, 0.08902718182071112, 3.0052174162119627, 43.22919353842735, 51.92752718925476, 70.78189507126808, 46.94961570203304, 61.7519798129797, 13.11501620337367, 0.5543280299752951, 0.31816470553167164, 0.07895133225247264, 0.06630514326388948, 0.04314463643822819, 0.12309061727137305, 0.02003582390898373, 0.08950973366154358, 0.03312808446935378, 0.043973626525257714, 0.02967497523059137, 0.022231987313716672, 0.05291518129524775, 0.03593234512663912, 0.0011762756571442878, 0.054579885327257216, 0.033679856423987076, 0.08014895080123097, 0.084764998027822, 0.03475611156318337, 0.05812451992824208, 0.014966939506848576, 0.025923817629518453, 0.04863469614065252, 0.04293948084523436, 0.09546156506985426, 0.04949201029376127, 0.04649104339478072, 0.0394849429721944, 0.11862062470754609, 0.029741582984570414, 0.05163617512152996, 0.020433303361642174, 0.08310805686051026, 0.017457133471907582, 0.0647733207733836, 0.037527847598539665, 0.02945186151919188, 0.01794167241314426, 0.052313147389213555, 0.023730138564133085, 0.04743133336887695, 0.030739124085812364, 0.038689078646712005, 0.05692578815796878, 0.06552801816724241, 0.03305722049844917, 0.044990929163759574, 0.03247418186219875, 0.03804184423643164, 0.040872169120120816, 0.03431947268836666, 0.04587435207213275, 0.09559054291457869, 0.04029826261103153, 0.19494410109473392, 0.37641700473614037, 0.5868640809785575, 5.797751694917679, 80.54372325539589, 64.47718977928162, 27.45466109365225, 79.46404919028282, 61.7706748098135, 3.717808141373098, 0.4246799665270373, 0.042272197315469384, 0.36548288364429027, 0.5943571007810533, 0.9552313364110887, 0.925518237054348, 0.423893379047513, 0.09868885361356661, 3.222986343316734, 74.45648789405823, 100.37032216787338, 85.24521857500076, 85.94220757484436, 75.62597393989563, 85.71231991052628, 87.51283049583435, 78.9507195353508, 76.00925177335739, 80.62640681862831, 80.11809289455414, 77.9050612449646, 76.57775446772575, 80.91703042387962, 77.97738656401634, 74.77250173687935, 73.28890934586525, 68.76130789518356, 69.56314846873283, 64.22079473733902, 59.549636989831924, 55.13366214931011, 57.0930802077055, 53.152703046798706, 56.209335029125214, 53.86005029082298, 57.42623873054981, 50.76977491378784, 54.535433650016785, 50.74957139790058, 55.44393070042133, 59.33583006262779, 63.49738575518131, 61.58833399415016, 66.14946484565735, 67.20755606889725, 70.36383390426636, 67.775017619133, 75.6081148982048, 61.36827640235424, 74.65795308351517, 30.9415040910244, 55.976228937506676, 72.1456190943718, 68.38037833571434, 64.24464985728264, 59.44921977818012, 63.42633716762066, 67.51256570219994, 68.37616816163063, 67.40671098232269, 65.72484523057938, 65.09386628866196, 61.99711985886097, 56.308946684002876, 51.92283824086189, 52.759177163243294, 53.2451368868351, 54.14985314011574, 50.16555413603783, 50.91702841222286, 47.99586296081543, 51.81278474628925, 48.96538093686104, 60.234599635005, 68.32047834992409, 70.7285763323307, 69.6326695382595, 68.76395255327225, 69.12374004721642, 67.78490468859673, 70.70695549249649, 64.04823079705238, 58.52150335907936, 64.98670443892479, 69.0712420642376, 72.12921157479286, 73.12013760209084, 71.38651862740517, 65.14070257544518, 72.33414217829704, 72.23501309752464, 68.48345160484314, 62.38815687596798, 78.1371907889843, 64.27582338452339, 88.4723474085331, 20.645255483686924, 0.1179619983304292, 1.7060652282088995, 1.1031570425257087, 0.7781016442459077, 0.26002257072832435, 0.05364529504731763, 0.17904624401126057, 6.681049922481179, 45.36141872406006, 62.72481881082058, 51.99686586856842, 42.0566638559103, 71.4211955666542, 16.056353822350502, 0.6908817181829363, 0.333240277832374, 0.16859643365023658, 0.047122881951509044, 0.06966540240682662, 0.08271302649518475, 0.03103910574282054, 0.07622546836500987, 0.03801716411544476, 0.04381027240015101, 0.02079658464936074, 0.07337903516599908, 0.059846128133358434, 0.0667705069645308, 0.025735341805557255, 0.013508191659639124, 0.02491220355295809, 0.019809322293440346, 0.03258273209212348, 0.036640335456468165, 0.04773274551553186, 0.04309793308493681, 0.057038023151108064, 0.03501253842841834, 0.049430059516453184, 0.012062381301802816, 0.1233491963648703, 0.12511529261246324, 0.23481577722122893, 0.15535604412434623, 0.12720955914119259, 0.16593439446296543, 0.15829401381779462, 0.23226641089422628, 0.19797803048277274, 0.25375465862452984, 0.0934125398634933, 0.1314219002961181, 0.1650098417303525, 0.1383026037365198, 0.12143074462073855, 0.150498450093437, 0.2042753910063766, 0.17098107287893072, 0.1610755833098665, 0.11507618677569553, 0.13321338541572914, 0.23258710774825886, 0.10031069861724973, 0.18007923936238512, 0.23834353167330846, 0.2248516579857096, 0.21159071096917614, 0.1874304941156879, 0.2633118286030367, 0.3741157235344872, 0.6007793499156833, 0.9118769690394402, 7.816885923966765, 94.37852248549461, 88.39099377393723, 42.87439897656441, 67.17496901750565, 79.25932377576828, 6.5240290481597185, 2.595321061089635, 0.39291429449804127, 7.965006725862622, 1.4615149819292128, 8.153204452246428, 2.814638880081475, 0.19922960316762328, 0.20215008786180988, 4.881389066576958, 74.05586019158363, 103.81720080971718, 86.55664220452309, 92.20749378204346, 80.05164965987206, 88.85982781648636, 91.11328929662704, 82.86468431353569, 77.6724149286747, 82.67421573400497, 80.50096794962883, 81.51112094521523, 81.14284470677376, 82.059226334095, 79.99336078763008, 78.19868668913841, 77.55101904273033, 72.21365824341774, 73.27032834291458, 69.50564235448837, 61.740477830171585, 58.44442069530487, 59.20090310275555, 58.26321981847286, 59.87208388745785, 56.59149572253227, 61.10188029706478, 55.01436375081539, 58.48858192563057, 52.813939824700356, 59.308391734957695, 63.482045978307724, 68.42474475502968, 65.41640818119049, 70.5602453649044, 69.8962689936161, 73.16667750477791, 70.95690608024597, 79.85519260168076, 63.73428404331207, 78.3084399998188, 33.78188207745552, 57.52103604376316, 75.7485781610012, 71.48003920912743, 65.30268028378487, 61.18902862071991, 67.9707907140255, 67.15819671750069, 70.44852375984192, 70.20921260118484, 68.6360514163971, 68.14309626817703, 63.98878678679466, 58.800628781318665, 52.50171057879925, 56.09178453683853, 56.903531178832054, 58.74796740710735, 53.59943747520447, 55.5110464990139, 51.3177815079689, 55.74011720716953, 51.62424646317959, 63.42669814825058, 70.76214373111725, 75.21978333592415, 74.09307539463043, 70.98140716552734, 70.22731482982635, 69.84866514801979, 74.9386440217495, 68.2968208193779, 62.04417273402214, 66.58640339970589, 73.21458533406258, 76.97340443730354, 75.01651704311371, 74.73906353116035, 68.69696214795113, 75.62669590115547, 74.692113250494, 70.17525762319565, 67.88099393248558, 80.66349282860756, 67.87784770131111, 90.35162016749382, 21.255457140505314, 0.3097700950456783, 3.2893369579687715, 1.7862093402072787, 5.125524066388607, 0.9856977453455329, 0.27555494976695627, 0.3014684608206153, 7.582583846524358, 59.568529576063156, 63.551738038659096, 76.99586123228073, 55.74526593089104, 83.59746739268303, 19.6040353551507, 0.8777512377128005, 0.5169719969853759, 0.18438798550050706, 0.2030636864947155, 0.15547941875411198, 0.2780759066808969, 0.08936807251302525, 0.18031739455182105, 0.07387324614683166, 0.2046616343432106, 0.10025998024502769, 0.19490832957671955, 0.10970432893373072, 0.12868021382018924, 0.14070922537939623, 0.09948842867743224, 0.09267871908377856, 0.1462648983579129, 0.18644561961991712, 0.09686136691016145, 0.12565158336656168, 0.10353605015552603, 0.10240809700917453, 0.11086366750532761, 0.13166195538360626, 0.20719099236885086], [0.04525525990175083, 0.015669561325921677, 0.039126763949752785, 0.028149256904725917, 0.020999601001676638, 0.012672197553911246, 0.04334036675572861, 0.03692580256029032, 0.024985622367239557, 0.04618199454853311, 0.03683791001094505, 0.041680739013827406, 0.015937114840198774, 0.032920368466875516, 0.026555272124824114, 0.08535106462659314, 0.04286215276806615, 0.03218141202523839, 0.02227313569164835, 0.08985438704257831, 0.05880293196241837, 0.08411349626840092, 0.06015459439367987, 0.042384487969684415, 0.027656096062855795, 0.026600303790473845, 0.05395376501837745, 0.08925387825001962, 0.11054266637074761, 0.07696656961343251, 0.12848409387515858, 0.202661665098276, 0.5481866095215082, 25.595711544156075, 69.04164925217628, 53.67897480726242, 22.051449827849865, 64.08372089266777, 42.44167059659958, 0.8018640847876668, 0.46244047000072896, 0.32295770302880555, 1.6855782712809741, 0.4186184308491647, 1.964045378845185, 0.39488401380367577, 0.2147703684750013, 0.07324602745939046, 3.7790665542706847, 68.54053974151611, 94.29691806435585, 75.56748747825623, 87.13913574814796, 77.09973245859146, 78.55850458145142, 83.41022863984108, 81.4883753657341, 77.03256726264954, 78.46577435731888, 73.84158968925476, 79.50239673256874, 80.12507691979408, 78.80850076675415, 72.64317959547043, 69.43470016121864, 67.39988654851913, 56.95254094898701, 57.25085534155369, 54.53595422208309, 58.1659260392189, 59.747287184000015, 57.78769813477993, 57.22534731030464, 57.33336791396141, 55.21045982837677, 53.83461445569992, 54.11585636436939, 54.07482996582985, 52.419608384370804, 58.62423084676266, 61.33336387574673, 57.4713347107172, 58.95215705037117, 63.43343898653984, 69.00758028030396, 70.7030189037323, 70.32318368554115, 72.77175709605217, 60.637210831046104, 25.579627007246017, 54.50824610888958, 76.11030355095863, 66.66649550199509, 64.22865271568298, 57.176025956869125, 61.61610670387745, 58.32673721015453, 60.8786004781723, 59.22747127711773, 59.93545688688755, 54.55171197652817, 50.786011442542076, 46.258542984724045, 50.51516577601433, 50.030372589826584, 51.920182183384895, 51.181661412119865, 51.74452520906925, 51.88102148473263, 55.51905646920204, 54.43853884935379, 52.5917087495327, 49.832980781793594, 66.80824309587479, 66.98887020349503, 68.08831840753555, 68.20226669311523, 71.8655513226986, 68.53867784142494, 71.30608454346657, 66.83703795075417, 62.57783889770508, 62.25218877196312, 73.22791501879692, 68.45676943659782, 70.32137498259544, 72.25715070962906, 78.77208352088928, 66.44899517297745, 66.45501405000687, 68.03612440824509, 71.24598696827888, 58.36111776530743, 90.85808739066124, 22.82878741621971, 0.27151342132128775, 0.08901765264454298, 0.6349898048210889, 0.5408808484207839, 0.27756999945268035, 0.11290656257187948, 0.02963590857689269, 5.098060090094805, 53.11193883419037, 52.95858286321163, 78.93278449773788, 65.23999124765396, 47.46756970882416, 57.071786150336266, 1.0075685405172408, 0.32959030650090426, 0.056428456446155906, 0.22243470564717427, 0.01581212789460551, 0.03799717436777428, 0.1352440202026628, 0.09168866439722478, 0.022431246543419547, 0.05045321770012379, 0.0768676635925658, 0.04247850323736202, 0.04626323003321886, 0.0273047726295772, 0.09720440240926109, 0.03506196546368301, 0.06618611761950888, 0.041872702931868844, 0.042386922214063816, 0.1126663145259954, 0.04420508383191191, 0.026631939690560102, 0.08918739666114561, 0.029373158613452688, 0.06988325243582949, 0.03506673005176708, 0.03744003297470044, 0.01056983883245266, 0.03999046799435746, 0.03220244077965617, 0.041248686611652374, 0.02916795292549068, 0.045169630902819335, 0.022871226938150357, 0.01431876071364968, 0.05732924189942423, 0.03545996070897672, 0.026731125872174744, 0.07730622091912664, 0.07375565284746699, 0.023751388107484672, 0.04856095263676252, 0.015308636357076466, 0.013686795991816325, 0.06495981506304815, 0.037914569620625116, 0.04160589713137597, 0.06940109393326566, 0.05470122276165057, 0.034893631527666, 0.06695886404486373, 0.03999728462076746, 0.021668292756658047, 0.06153527108835988, 0.06924717250512913, 0.043222413514740765, 0.09867841901723295, 0.03146475341054611, 0.1523043922497891, 0.6874957436230034, 32.0333831012249, 85.73399394750595, 35.41827566921711, 28.1812809035182, 105.86088314652443, 39.80751134455204, 1.9669523416087031, 0.9945974021684378, 0.20138775376835838, 0.5303564225323498, 0.5503981502261013, 0.46185921994037926, 1.099480502307415, 0.49663584446534514, 0.08081015985226259, 5.000145044177771, 78.33440780639648, 96.37776240706444, 81.71792104840279, 88.87020885944366, 79.60728630423546, 79.98713672161102, 85.07044315338135, 82.07214564085007, 75.33582910895348, 76.31179913878441, 74.38437536358833, 79.90636065602303, 79.94641810655594, 79.30998265743256, 76.31789401173592, 74.0457147359848, 70.30625939369202, 59.71736378967762, 60.78264802694321, 58.41428451240063, 59.88056503236294, 60.13750724494457, 59.63067144155502, 57.67768643796444, 56.75171032547951, 55.9264250099659, 55.01200407743454, 56.598297357559204, 55.7032135874033, 55.58254346251488, 60.69272205233574, 63.99596080183983, 60.09607806801796, 62.21365883946419, 65.11626228690147, 70.96419408917427, 72.16255098581314, 72.66796186566353, 69.8708027601242, 65.17886012792587, 28.973925970494747, 54.252238646149635, 77.96051546931267, 68.06569442152977, 65.95439091324806, 59.20430392026901, 63.06065618991852, 61.324331760406494, 61.8471647053957, 60.75799494981766, 60.689906403422356, 57.85739779472351, 54.28953744471073, 49.540259689092636, 52.900575175881386, 51.12650357186794, 54.157080352306366, 53.669794499874115, 53.13233993947506, 52.87325084209442, 55.48528768122196, 54.65782128274441, 52.101048678159714, 52.37212993204594, 68.88743832707405, 70.86934357881546, 72.7237656712532, 67.44592487812042, 73.08072611689568, 69.03390526771545, 73.26560139656067, 67.88980945944786, 63.4265461564064, 63.64887982606888, 74.61371585726738, 71.43342331051826, 69.91332247853279, 71.83670327067375, 81.26178592443466, 69.97454479336739, 68.19162726402283, 69.15815100073814, 74.31683778762817, 58.61969769001007, 90.38283929228783, 27.679192945361137, 0.2836175530683249, 0.18310659332200885, 1.0165131418034434, 0.46667371003422886, 0.46733098570257425, 0.08345468435436487, 0.2832012082217261, 9.80590296909213, 51.87011606991291, 71.0586266219616, 73.63884016871452, 62.48530626296997, 49.5466623455286, 63.01517263054848, 1.5818425314500928, 0.24131923215463758, 0.038448604245786555, 0.05918436618230771, 0.026939550625684205, 0.046886311247362755, 0.11484209113405086, 0.07374242035439238, 0.024764505033090245, 0.05408379300206434, 0.033033037616405636, 0.017459137270634528, 0.05548287866986357, 0.03832550049992278, 0.06020051849191077, 0.01502889677794883, 0.03810220310697332, 0.028264955872145947, 0.03269387241743971, 0.07239580823807046, 0.03911623658495955, 0.04987004547729157, 0.0718809878162574, 0.02976788284286158, 0.053785727941431105, 0.02721230102906702, 0.054829391665407456, 0.10760026605566964, 0.1617942049051635, 0.1743487163912505, 0.12505776132456958, 0.11355347785865888, 0.20496229320997372, 0.08577428918215446, 0.2085168837220408, 0.11285036714980379, 0.14820304670138285, 0.11635000904789194, 0.15499298548093066, 0.12008457779302262, 0.18070326681481674, 0.1911534630926326, 0.16819209675304592, 0.11018271732609719, 0.1565193012356758, 0.12246629295987077, 0.17909464688273147, 0.1935554834199138, 0.2144292031880468, 0.12947808194439858, 0.15154624386923388, 0.1359592130756937, 0.20032609667396173, 0.11302820057608187, 0.19808326702332124, 0.2275315235601738, 0.24362858792301267, 0.33878076646942645, 0.44290690566413105, 1.086878003552556, 40.511290580034256, 97.3155064880848, 67.48649910092354, 33.91950309276581, 85.04024237394333, 61.40345871448517, 3.2511751307174563, 1.2979692639783025, 0.8951868989970535, 6.417684629559517, 1.0071899858303368, 8.335319180041552, 2.1878492133691907, 0.25575427163857967, 0.21140711847692728, 5.813202615827322, 78.62025126814842, 96.4145140349865, 83.27264562249184, 92.12844282388687, 85.12532740831375, 82.94884979724884, 86.9987940788269, 83.33493947982788, 79.41975876688957, 80.49501746892929, 77.47996285557747, 79.79712411761284, 83.81972506642342, 86.1598750948906, 78.73828053474426, 77.20345169305801, 72.76858046650887, 64.12307158112526, 64.3046410381794, 61.65652133524418, 66.81851014494896, 66.01190462708473, 65.52661746740341, 62.51735754311085, 62.12082602083683, 60.84250621497631, 59.36659321188927, 60.446404069662094, 62.06698291003704, 57.95121096074581, 63.922442346811295, 69.39467310905457, 65.44650256633759, 64.86989110708237, 70.74231639504433, 73.99250999093056, 76.64015471935272, 74.3081970512867, 76.17138907313347, 63.09679225087166, 31.696751564741135, 59.95286375284195, 82.26967424154282, 73.95581915974617, 69.2128224670887, 63.75687763094902, 66.68853431940079, 64.96098741889, 64.85104411840439, 63.213445991277695, 63.522718995809555, 60.0422615557909, 56.34871914982796, 51.62586897611618, 57.582463547587395, 55.96433937549591, 57.94618383049965, 55.613154619932175, 57.93252356350422, 57.657403126358986, 60.98817139863968, 60.8285191655159, 57.36679472029209, 56.44567474722862, 73.6016857624054, 74.45086419582367, 75.63722893595695, 69.82973456382751, 73.64078566431999, 73.36918383836746, 75.55984228849411, 71.03214964270592, 68.23289304971695, 66.8397206068039, 77.79330164194107, 73.90446111559868, 72.98578441143036, 74.71807345747948, 84.04284909367561, 73.079464584589, 71.21273875236511, 77.92361184954643, 75.43684288859367, 64.89576771855354, 92.60711833834648, 27.82478403300047, 0.3189504618057981, 0.3182958281831816, 1.323719413485378, 1.4153862884268165, 0.8601298613939434, 0.15144425793550909, 0.30471081496216357, 9.804171212017536, 70.14499604701996, 68.28089967370033, 83.39939162135124, 74.74306851625443, 62.58632384240627, 75.154829621315, 1.576018393971026, 0.35667572810780257, 0.19290751428343356, 0.2606689219828695, 0.16229479835601524, 0.11579341313336045, 0.24357752816285938, 0.149228204973042, 0.16220823425101116, 0.1434779557166621, 0.17823923262767494, 0.17715529626002535, 0.2135546415229328, 0.1595153217203915, 0.25298517022747546, 0.13181584712583572, 0.14573671185644343, 0.10686690540751442, 0.12798473238945007, 0.14960356842493638, 0.1133879715052899, 0.14877699402859434, 0.22456336329923943, 0.13417834066785872, 0.166216098878067, 0.10473294882103801, 0.16644062823615968], [0.05273486538499128, 0.00740207470698806, 0.067063091264572, 0.04704371705884114, 0.04124477178265806, 0.00769297897022625, 0.026254527911078185, 0.06091142546210904, 0.09195395250571892, 0.008782137738307938, 0.07910309403087012, 0.04658697340346407, 0.0768406197312288, 0.04517920460784808, 0.051076785020995885, 0.07293042915989645, 0.07539847094449215, 0.022949324993533082, 0.10446556043461896, 0.04733142915938515, 0.11070131527958438, 0.03451911412412301, 0.1197295640304219, 0.041904411191353574, 0.041626985257607885, 0.027427462628111243, 0.018175966579292435, 0.03829311317531392, 0.053886656314716674, 0.12128418529755436, 0.024439273656753357, 0.09094840919715352, 0.11014093441190198, 0.7740916719194502, 57.9529132694006, 75.62675669789314, 47.21865266561508, 19.556876085698605, 74.36724588274956, 48.67341600358486, 1.8794944533146918, 0.19996597693534568, 0.6155464262701571, 0.3426756465341896, 0.3301192499930039, 3.1878056935966015, 0.4530776833416894, 0.14680147112812847, 0.1320554272388108, 4.244590261951089, 80.73968634009361, 94.89700466394424, 77.48579174280167, 86.45636558532715, 88.97329732775688, 79.60433006286621, 72.10222542285919, 79.00832444429398, 80.06596729159355, 83.64077746868134, 78.29263284802437, 78.73429834842682, 75.06526842713356, 73.61277356743813, 66.15589410066605, 59.173521772027016, 63.22197653353214, 65.29586344957352, 70.6227596104145, 71.86683565378189, 73.2725702226162, 73.44628930091858, 69.40633088350296, 65.69921180605888, 60.57540714740753, 55.81065282225609, 51.06166385114193, 51.046156883239746, 51.82036533951759, 56.17860987782478, 55.58533251285553, 61.287287548184395, 58.58008101582527, 59.83821250498295, 63.95141199231148, 69.18411120772362, 68.25031891465187, 76.30542308092117, 69.00257214903831, 26.212644539773464, 57.48200833797455, 77.61259853839874, 69.99627962708473, 64.80988472700119, 61.95415936410427, 60.06135173141956, 57.597221955657005, 55.25196500122547, 53.54119040071964, 50.42359448969364, 51.234159395098686, 50.81169046461582, 49.82568897306919, 51.57502390444279, 51.56194120645523, 55.34936897456646, 51.599460393190384, 52.70309217274189, 56.69454239308834, 58.46850760281086, 56.63217633962631, 53.99303935468197, 48.37475202977657, 60.139068961143494, 70.64595356583595, 70.48420384526253, 69.51400950551033, 69.47808623313904, 77.47932448983192, 71.45297706127167, 71.19320780038834, 67.61021286249161, 66.46117731928825, 70.34184828400612, 73.47063839435577, 76.34927272796631, 69.81690645217896, 66.99539065361023, 78.8150592148304, 77.7792651951313, 62.13262818753719, 64.83206033706665, 79.79245036840439, 21.923801377415657, 0.13364112965064123, 0.5455629690550268, 0.23001584806479514, 0.26298468990717083, 0.5942021997179836, 0.18427372444421053, 0.4205086512956768, 6.144550060853362, 52.18367524445057, 61.486841440200806, 9.039148762822151, 23.677580170333385, 28.95027793943882, 71.96259811520576, 6.924976408481598, 0.08168806118192151, 0.0342845175327966, 0.05884802114451304, 0.013069192755210679, 0.07182033950812183, 0.046920027016312815, 0.018244082748424262, 0.024180971013265662, 0.04458809140487574, 0.029349179822020233, 0.030152575091051403, 0.020268188491172623, 0.04676840624597389, 0.030059981036174577, 0.0849422525789123, 0.07014362010522746, 0.0056134533497242955, 0.023949947863002308, 0.04286310271709226, 0.03160422893415671, 0.04022730216092896, 0.04317599959904328, 0.02162100496207131, 0.029046955023659393, 0.017606507390155457, 0.029188833250373136, 0.037943580173305236, 0.06495870926300995, 0.013349349792406429, 0.002723267994042544, 0.023980411169759464, 0.03038001923414413, 0.057454995112493634, 0.03557830728823319, 0.032848335613380186, 0.04608417577401269, 0.05029632768128067, 0.0477504865557421, 0.039097523331292905, 0.008419917721766979, 0.03240024539991282, 0.04455470589164179, 0.013363645412027836, 0.05315307673299685, 0.007238408416014863, 0.05998446446028538, 0.07389768506982364, 0.05903004028368741, 0.0425157998688519, 0.04074555130500812, 0.024913481902331114, 0.02490453902282752, 0.043384669261286035, 0.04023137655167375, 0.08248738391557708, 0.04311687640438322, 0.04468553168408107, 0.0670478178653866, 0.09934733898262493, 0.23638163460418582, 1.7744247475638986, 68.9001752436161, 81.33112460374832, 26.198495998978615, 34.90420505404472, 110.97043856978416, 44.414672926068306, 5.1064476650208235, 0.0738270251895301, 0.3615401202114299, 0.6852541014086455, 0.42480847681872547, 0.9615929669234902, 0.5129996070172638, 0.6608620227780193, 0.1630672108149156, 7.224165229126811, 92.97460421919823, 91.25439092516899, 80.14817968010902, 90.26749268174171, 88.32059875130653, 78.85889366269112, 75.67295461893082, 80.12808635830879, 83.08405414223671, 80.84819331765175, 78.34818586707115, 81.91367134451866, 80.86457803845406, 75.516357421875, 68.59554558992386, 63.54593575000763, 63.273026794195175, 63.26529420912266, 68.80784779787064, 73.66802260279655, 72.19384610652924, 73.16994532942772, 67.84488067030907, 68.38119149208069, 60.25881193578243, 58.2930064201355, 53.382001742720604, 53.095531314611435, 54.27873082458973, 59.12192054092884, 58.64504612982273, 64.73379001021385, 60.61710610985756, 62.34400324523449, 67.55799606442451, 72.09692850708961, 68.15162301063538, 77.00276926159859, 65.5231748521328, 26.587965600192547, 59.717796966433525, 78.96380603313446, 71.8213900923729, 67.8292179107666, 66.039057970047, 64.48450058698654, 62.28881120681763, 59.112003073096275, 57.65014171600342, 53.59237365424633, 53.16838100552559, 53.55874925851822, 51.98136270046234, 54.50027033686638, 54.075399935245514, 57.21011012792587, 54.57684002816677, 54.67702925205231, 57.48579293489456, 57.26332247257233, 56.87901109457016, 55.97209095954895, 51.62398047745228, 62.21777021884918, 72.89222583174706, 73.20804968476295, 71.14846140146255, 69.99404534697533, 75.14190271496773, 71.76529750227928, 71.41881689429283, 68.13417434692383, 69.69453781843185, 70.58590158820152, 73.4781239926815, 76.89350992441177, 72.94396385550499, 69.28286790847778, 77.76756942272186, 80.77435567975044, 64.33297991752625, 64.91619542241096, 85.67133530974388, 26.226019822061062, 0.1395217890967615, 0.1297021660138853, 0.1410268497420475, 0.5112232617102563, 0.7165246421936899, 0.28299607860390097, 0.4969459434505552, 13.151971120387316, 48.559376522898674, 90.01775488257408, 20.73972601443529, 29.39419861882925, 34.28302578628063, 79.24144193530083, 11.342843547463417, 0.30310180911328644, 0.037773943768115714, 0.05617158058157656, 0.03121887617453467, 0.03899114759406075, 0.08712332069990225, 0.04663714258640539, 0.027730791371141095, 0.10513517059735022, 0.012362120833131485, 0.03808255845797248, 0.054470392569783144, 0.10345722665078938, 0.014783776532567572, 0.027818030830530915, 0.02040401264821412, 0.06244870644877665, 0.05341650947229937, 0.05483723616634961, 0.05391874678025488, 0.035338192828930914, 0.026949074235744774, 0.046225421319832094, 0.016008529855753295, 0.014216686649888288, 0.07098208370734937, 0.052628111152444035, 0.1287073764251545, 0.09981201248592697, 0.12385060617816634, 0.1527192973298952, 0.14478554570814595, 0.13079327152809128, 0.09083120923605748, 0.1386515615740791, 0.1369328811415471, 0.11561310835531913, 0.1943653149646707, 0.12442057559383102, 0.18113182741217315, 0.08562366288970225, 0.11243190718232654, 0.19442533986875787, 0.1896246537216939, 0.1828578402637504, 0.11727445045835339, 0.1540294403093867, 0.1758977715508081, 0.1885336817940697, 0.23666117194807157, 0.1548520813230425, 0.1073162312968634, 0.15097038180101663, 0.12883425399195403, 0.10899331435211934, 0.0921653829573188, 0.25005612114910036, 0.13186908880015835, 0.1574131884262897, 0.22044062905479223, 2.251191339455545, 85.62672570347786, 99.21763122081757, 62.866323217749596, 32.1325121819973, 91.76190689206123, 69.2905966937542, 5.795573936775327, 0.335686604375951, 1.0284048411995173, 1.348186181858182, 1.1743090557865798, 7.351084593683481, 3.336470816284418, 0.559416253818199, 0.2314337805728428, 7.2700420673936605, 91.5657614171505, 96.95205599069595, 82.87899434566498, 91.93462282419205, 94.05633017420769, 79.29517105221748, 74.57909971475601, 81.96597173810005, 82.79679715633392, 83.29888701438904, 78.6829175055027, 85.83597287535667, 84.34734955430031, 79.19443845748901, 73.56880992650986, 67.14074805378914, 69.0961991250515, 72.49440997838974, 76.8502302467823, 81.13345921039581, 78.5078077018261, 80.9866426885128, 75.43573334813118, 73.84687900543213, 65.73711097240448, 62.98030190169811, 55.07292240858078, 55.39851173758507, 59.22414265573025, 63.3529707044363, 60.91682642698288, 68.62154379487038, 64.80614572763443, 63.683298379182816, 69.56331565976143, 75.2690514922142, 73.83188501000404, 81.61198273301125, 67.36447244882584, 29.536791667342186, 61.33337527513504, 83.42861205339432, 76.59816697239876, 70.58593198657036, 69.14683520793915, 66.3890191912651, 65.28862103819847, 61.953133419156075, 59.17341157793999, 54.95163291692734, 57.23980933427811, 58.02594915032387, 56.215365305542946, 57.24680855870247, 57.25219286978245, 63.08175265789032, 58.62043485045433, 57.38236628472805, 61.59492664039135, 62.18153536319733, 59.65455316007137, 61.31832808256149, 53.35221894085407, 65.46938493847847, 78.76522868871689, 78.14366564154625, 77.3584833741188, 71.14624232053757, 75.5905370414257, 77.36143961548805, 77.88002818822861, 72.27203831076622, 71.55948534607887, 78.11402723193169, 77.27926522493362, 78.47290277481079, 72.42750316858292, 70.68240880966187, 78.65484461188316, 83.06285127997398, 67.21535325050354, 70.91556429862976, 84.68226358294487, 25.48567894846201, 0.3152034472441301, 1.0331294126808643, 1.008726409636438, 0.962463595205918, 0.9639448625966907, 0.3831612865906209, 0.6735526293050498, 13.261387199163437, 69.69108760356903, 73.32135200500488, 20.157072879374027, 34.53093968331814, 41.37782268226147, 90.55018991231918, 13.530746195465326, 0.736516616307199, 0.2243823089520447, 0.18809004075592384, 0.1092577564122621, 0.16263819008599967, 0.17088796303141862, 0.18112713703885674, 0.14796683593885973, 0.18206617649411783, 0.18663413997273892, 0.17076298536267132, 0.13947133789770305, 0.13400773575995117, 0.2787433349294588, 0.1814699053647928, 0.11154844716656953, 0.12383825684082694, 0.09869985224213451, 0.15093380876351148, 0.07343836245127022, 0.1118940208107233, 0.13651174202095717, 0.33599331916775554, 0.2879566530464217, 0.10101548657985404, 0.08268964142189361, 0.1253893825924024], [0.09063245466677472, 0.032011764487833716, 0.048934111910057254, 0.02852399138646433, 0.0317508995794924, 0.020171412434137892, 0.003838412599179719, 0.055757421359885484, 0.12680419808020815, 0.03298341762274504, 0.024212506723415572, 0.02325192828720901, 0.021830845362273976, 0.07295736912055872, 0.03036025955225341, 0.07556638185633346, 0.06954151569516398, 0.06416035132133402, 0.045232286720420234, 0.01912244792038109, 0.03549612556525972, 0.04512164363404736, 0.027774156915256754, 0.030324818289955147, 0.007525135779360426, 0.048143260792130604, 0.035088894292130135, 0.03378865527338348, 0.05227415866102092, 0.04864790265855845, 0.0811280365451239, 0.11890982481418177, 0.21918475191341713, 0.464617753168568, 5.158008998259902, 65.16021832823753, 61.540023386478424, 50.60837097465992, 17.339968644082546, 63.26460264623165, 57.357451021671295, 6.129646310582757, 0.6044885446317494, 0.5080798803828657, 0.1549186371266842, 0.7002474437467754, 0.6002958258613944, 0.3099424811080098, 0.11429805235820822, 0.11869880254380405, 4.8529209941625595, 62.59916715323925, 97.02337056398392, 79.40840497612953, 74.11718890070915, 81.6605593264103, 86.80611401796341, 80.11984840035439, 80.47103315591812, 77.54591971635818, 78.02839502692223, 81.89101696014404, 76.8106059730053, 71.6329126060009, 67.07204014062881, 69.37799960374832, 72.83785834908485, 72.21673607826233, 70.88933050632477, 76.37815117835999, 74.76569250226021, 73.46815332770348, 76.34405180811882, 76.08366698026657, 74.559196382761, 68.9528252184391, 61.292869448661804, 54.972486197948456, 54.137116223573685, 52.95721493661404, 56.76521860063076, 56.46585926413536, 60.639878287911415, 60.18286541104317, 64.41401436924934, 66.1103193461895, 72.52568989992142, 67.88424655795097, 83.23175221681595, 30.026699379086494, 49.03511479496956, 78.84427964687347, 70.02099350094795, 69.42973762750626, 60.675885155797005, 61.369317546486855, 57.57022060453892, 55.33903732895851, 50.347279384732246, 53.461846858263016, 50.87862007319927, 50.8934810757637, 50.60512214899063, 52.71650165319443, 56.065170764923096, 56.84527650475502, 55.505339205265045, 57.75444231927395, 65.4043248295784, 64.14042145013809, 62.43167594075203, 57.784426510334015, 55.163239762187004, 53.28869394958019, 69.1707207262516, 72.05932572484016, 72.36435055732727, 72.88236916065216, 70.1286493241787, 73.80878984928131, 72.13796630501747, 70.59115290641785, 73.2012252509594, 74.81013491749763, 74.86204013228416, 69.21614348888397, 78.28557282686234, 81.76145151257515, 64.10953670740128, 53.62943686544895, 69.47510719299316, 63.637849017977715, 7.299745548516512, 0.1681086645112373, 0.23598201776621863, 0.34053930023219436, 0.5275769904255867, 0.35765794571489096, 0.6218927388545126, 1.674284446053207, 13.84600767865777, 53.963872119784355, 59.36851590871811, 10.425648763775826, 23.851192854344845, 35.00255137681961, 68.23106914758682, 15.109533928334713, 0.138213902246207, 0.0713914968946483, 0.07029611660982482, 0.03649993595900014, 0.054481662082253024, 0.016197591976379044, 0.04490648389037233, 0.016516203395440243, 0.03130234181298874, 0.03636301713413559, 0.036405965220183134, 0.0156596629312844, 0.02070864571578568, 0.0476668724877527, 0.05570965302467812, 0.11228634233702905, 0.026511631986068096, 0.031276763693313114, 0.028527941467473283, 0.044494443500298075, 0.05352664789825212, 0.010946789552690461, 0.03607366859796457, 0.030057648837100714, 0.06288995034992695, 0.026983821589965373, 0.09567873232299462, 0.040061083345790394, 0.05437601364974398, 0.08539502203348093, 0.05528741552552674, 0.01907465917611262, 0.05327747552655637, 0.015384918933705194, 0.038485062250401825, 0.012623476486623986, 0.03649944243079517, 0.011231745502300328, 0.0778135604923591, 0.08318501757457852, 0.05512730829650536, 0.03137710205919575, 0.042397145298309624, 0.05611242027953267, 0.03424496477236971, 0.03604022742365487, 0.03432452671404462, 0.041604561265558004, 0.09931902604876086, 0.04026548194815405, 0.03279385455243755, 0.019613892545748968, 0.05938866459473502, 0.12462390179280192, 0.027615136932581663, 0.07662310366868041, 0.008828925510897534, 0.05717157633625902, 0.08189828935428523, 0.14445435488596559, 0.2785930351819843, 0.5395585193764418, 11.023561879992485, 80.00730603933334, 61.32291443645954, 23.159312680363655, 40.54021082818508, 105.03293037414551, 48.96101877093315, 12.640218380838633, 0.5174608645029366, 0.5076078150887042, 0.41811020812019706, 0.7009647146333009, 1.1309160967357457, 0.23600502434419468, 0.1462342476588674, 0.132517236052081, 7.524604182690382, 77.4280196428299, 98.91104087233543, 77.52296134829521, 74.51441958546638, 84.0951418876648, 85.42529091238976, 79.88805323839188, 77.5985848903656, 79.04756113886833, 79.49576988816261, 83.91076058149338, 79.0198378264904, 75.64851433038712, 70.39744690060616, 69.86710175871849, 74.7304379940033, 74.34943243861198, 76.15296006202698, 77.6008115708828, 77.56855130195618, 79.26507666707039, 76.5312297642231, 76.8236468732357, 75.6012524664402, 68.3307757973671, 61.33810982108116, 55.064832642674446, 57.81165584921837, 55.712105110287666, 61.68164558708668, 60.14458626508713, 64.26436319947243, 61.83863416314125, 67.10811540484428, 67.09434494376183, 74.43681254982948, 67.51772582530975, 83.59502032399178, 31.6001208499074, 52.14938208460808, 80.05542665719986, 71.66081070899963, 70.63528373837471, 61.84551939368248, 61.76259644329548, 57.215566635131836, 54.456105306744576, 50.316235050559044, 53.99245038628578, 52.0351792126894, 53.35911937057972, 53.13540257513523, 53.855566531419754, 56.1332593113184, 56.8813631683588, 55.996911227703094, 58.709304481744766, 65.53851842880249, 66.9221305847168, 63.50670665502548, 57.48278349637985, 54.555112794041634, 54.86288107931614, 71.79427474737167, 74.77349728345871, 75.68069860339165, 70.29341608285904, 70.09696662425995, 74.99651491641998, 72.6554149389267, 71.30862280726433, 73.59408617019653, 74.18959021568298, 76.61408051848412, 70.502450466156, 76.36023133993149, 82.46682286262512, 69.04816210269928, 54.26111876964569, 71.45759001374245, 73.32890599966049, 10.370606817305088, 0.3339504834730178, 0.12343976806732826, 0.13566389767220244, 0.2470563750830479, 0.6397230445872992, 0.8329367986880243, 2.603667313233018, 26.070526465773582, 44.53408531844616, 94.2182394862175, 18.005417436361313, 12.074174154549837, 32.803552374243736, 71.5261459350586, 21.604616604745388, 0.3618106181966141, 0.17782135895686224, 0.0513234637764981, 0.048325187162845396, 0.007396821229121997, 0.005871452640349162, 0.020011845117551275, 0.020684288429038133, 0.02780699694994837, 0.04860935550823342, 0.0182479697468807, 0.08336595317814499, 0.014332817918329965, 0.0395291415770771, 0.058676154585555196, 0.055972547706915066, 0.02419212178210728, 0.02943077895906754, 0.06867442003567703, 0.014848919472569833, 0.037561058707069606, 0.0314861569495406, 0.06002939036989119, 0.03641008042905014, 0.014948483221814968, 0.005721420529880561, 0.09143066417891532, 0.05601858312729746, 0.25046543043572456, 0.26872615213505924, 0.16829598258482292, 0.14723104104632512, 0.11994336935458705, 0.062274902884382755, 0.07753529222100042, 0.18825243751052767, 0.2461609590682201, 0.13251872034743428, 0.11142467177705839, 0.20579962874762714, 0.14252266322728246, 0.1908816589275375, 0.2709894650615752, 0.21380921301897615, 0.2029336176929064, 0.08088030022918247, 0.11935889095184393, 0.08152534530381672, 0.1814647697028704, 0.10013855746365152, 0.06865925795864314, 0.14105174137512222, 0.1633543922798708, 0.175945951777976, 0.13173091574572027, 0.19183894037269056, 0.1489475544076413, 0.12382732500554994, 0.15575238066958264, 0.16260387317743152, 0.36864746070932597, 0.838225461775437, 12.316359858959913, 99.60900261998177, 80.62218144536018, 68.06368812918663, 36.28292687237263, 78.26086655259132, 77.77845203876495, 14.485723301768303, 0.5203468690160662, 0.6983462395146489, 0.5629912088625133, 1.623819472733885, 3.978893319144845, 1.0276270704343915, 0.42677133867982775, 0.2410811511799693, 7.659389125183225, 71.41919687390327, 102.06286534667015, 83.26262176036835, 75.17520412802696, 84.30567339062691, 89.8318612575531, 82.16001212596893, 81.44802913069725, 78.60405653715134, 77.92952433228493, 86.19336649775505, 86.31116017699242, 80.09906351566315, 74.9510845541954, 75.14485135674477, 80.53306102752686, 82.60977879166603, 79.8349928855896, 80.26364028453827, 82.66563579440117, 83.13881680369377, 80.46463429927826, 82.64163628220558, 80.92452362179756, 74.8667062819004, 69.33931767940521, 62.24552392959595, 63.146413788199425, 59.12723645567894, 65.91398388147354, 64.01675328612328, 70.08914664387703, 68.12297254800797, 70.56866571307182, 71.47980362176895, 78.10277223587036, 71.81998416781425, 89.06173378229141, 36.662564501166344, 54.39843960106373, 82.9066264629364, 77.50389397144318, 76.86555862426758, 67.07859098911285, 66.304382532835, 61.10094554722309, 59.08296123147011, 55.05818299949169, 56.90461032092571, 55.78283831477165, 58.1106124073267, 57.770295068621635, 57.732547894120216, 61.25491328537464, 61.652238965034485, 60.93175582587719, 62.96433515846729, 74.69436272978783, 72.70650699734688, 71.16909429430962, 63.922442346811295, 60.88796317577362, 59.097176268696785, 76.62525951862335, 79.72415283322334, 79.68877673149109, 78.14651548862457, 73.55972081422806, 74.51756581664085, 75.35585403442383, 75.47589719295502, 79.55959886312485, 79.07074749469757, 78.14977571368217, 71.41393035650253, 79.06611174345016, 82.25984796881676, 70.32449081540108, 59.6454868465662, 76.34161993861198, 69.28510218858719, 9.713343735784292, 0.3315976675366983, 0.4965883766999468, 0.5448369111400098, 1.3290036236867309, 0.8790537959430367, 0.6750810379162431, 2.432295083999634, 27.932555750012398, 69.0688481926918, 75.86384117603302, 19.580905996263027, 35.02211272716522, 48.14767241477966, 83.08546006679535, 26.187037713825703, 0.3379655914613977, 0.2904449851484969, 0.12673118559177965, 0.13657423085533082, 0.1710463225026615, 0.17150185274658725, 0.13261141459224746, 0.16709242685465142, 0.171397180238273, 0.1763672986999154, 0.08885225761332549, 0.19148618273902684, 0.15289356844732538, 0.1359470418537967, 0.1778716765693389, 0.207096190424636, 0.11053387934225611, 0.1071402606612537, 0.1273951109033078, 0.07429641133057885, 0.13027235807385296, 0.06875214516185224, 0.16520502656931058, 0.10221251141047105, 0.1152929310046602, 0.1030512570287101, 0.2959356311475858, 0.1281581277726218], [0.024221564635809045, 0.06649915550951846, 0.03158524850732647, 0.043874030307051726, 0.03607979502703529, 0.07466193390428089, 0.06487724371254444, 0.03330929466756061, 0.04987571919627953, 0.055637820551055484, 0.02500171398423845, 0.04339368635555729, 0.09208704927004874, 0.08465541992336512, 0.10654726982465945, 0.04502977317315526, 0.05237433375441469, 0.027937195627600886, 0.0049166824373969575, 0.0395811067573959, 0.05931027895712759, 0.035342623450560495, 0.04577287822030485, 0.01604130866326159, 0.015574252865917515, 0.09721766458824277, 0.05076701258076355, 0.0226639302491094, 0.02653510611708043, 0.06991126108914614, 0.02345251039514551, 0.0636477350781206, 0.2324512947234325, 0.1348748165764846, 0.5591449839994311, 13.704888001084328, 79.82996195554733, 57.529289200901985, 43.21858070790768, 18.415375538170338, 73.58507305383682, 74.95469436049461, 17.734573669731617, 2.856419300660491, 0.07290626483154483, 0.19690424669533968, 0.24013089045183733, 0.4699499061098322, 0.14277865964686498, 0.06650206472841091, 0.08602907590102404, 0.9605488542001694, 33.75629045069218, 86.70478105545044, 93.73319551348686, 77.85649225115776, 73.04202139377594, 78.99355083703995, 85.88542342185974, 83.37507292628288, 80.00042080879211, 79.9361814558506, 79.07757192850113, 77.08738312125206, 75.11129915714264, 73.38706567883492, 75.73721677064896, 79.18697565793991, 78.67179930210114, 77.04588934779167, 77.20207616686821, 76.96462690830231, 75.15485242009163, 74.3833190202713, 75.46847999095917, 73.04616317152977, 75.48041135072708, 68.14965471625328, 61.5735337883234, 53.152942433953285, 53.37969906628132, 54.83209893107414, 58.26699681580067, 61.36962912976742, 65.46750783920288, 67.0810304582119, 72.09708049893379, 67.4285826086998, 78.4549829363823, 25.633975490927696, 45.796134397387505, 82.09434404969215, 69.10762131214142, 70.70228174328804, 63.273687958717346, 63.26008468866348, 57.57479935884476, 57.27691434323788, 54.11739528179169, 53.16842660307884, 51.74262911081314, 52.5215645134449, 57.14728429913521, 63.96274298429489, 66.67091086506844, 66.46990925073624, 56.562830060720444, 60.513763055205345, 65.42489692568779, 67.38230109214783, 65.78681990504265, 64.14759546518326, 59.18079078197479, 55.61844393610954, 59.77809973061085, 73.858263194561, 78.98468971252441, 74.96893599629402, 76.06005504727364, 73.2701687514782, 78.45199629664421, 75.64288303256035, 76.21074736118317, 73.38434502482414, 76.9689130783081, 82.59204134345055, 68.35878029465675, 55.02762123942375, 65.89033395051956, 76.1009256541729, 39.20620121061802, 1.9645553827285767, 0.18696028419071808, 0.15950798930134624, 0.17108930769609287, 0.49593466334044933, 0.06350214054691605, 0.3145323973149061, 5.2104514092206955, 18.49511805921793, 58.50660815834999, 60.58640755712986, 7.775916522368789, 31.61300975829363, 44.94946002960205, 61.499772146344185, 23.08040801435709, 0.2417669104761444, 0.07652171887457371, 0.08921346088754945, 0.03460487299889792, 0.04958391044056043, 0.0014875813280923467, 0.030652290952275507, 0.04133118003665004, 0.0413897058024304, 0.044746506537194364, 0.037206263878033496, 0.06978289922699332, 0.051878434387617745, 0.0829230691306293, 0.04391685222799424, 0.04545391428109724, 0.041876101968227886, 0.0757560896454379, 0.02842581452568993, 0.03606778336688876, 0.20972208702005446, 0.022818070610810537, 0.028454695202526636, 0.0795627135084942, 0.01919576654472621, 0.04991739449906163, 0.0723745085997507, 0.029562931340478826, 0.05439598113298416, 0.038861835782881826, 0.043895456110476516, 0.06619003615924157, 0.008217444064939627, 0.07241341198096052, 0.060125873278593644, 0.02368603272770997, 0.028228223272890318, 0.02315604651812464, 0.0099577274886542, 0.014857261212455342, 0.014563654603989562, 0.03617557660618331, 0.02515639611374354, 0.02096220418025041, 0.04235762964526657, 0.05321260810887907, 0.03798453930357937, 0.038908346177777275, 0.025478621791990008, 0.13289562746649608, 0.04237622044456657, 0.02057916506601032, 0.05484202301886398, 0.06825453514466062, 0.035211741997045465, 0.07772444339934736, 0.015664932179788593, 0.06242706542252563, 0.035100208333460614, 0.059245604497846216, 0.09298481047153473, 0.23909059236757457, 0.21097020129673183, 0.9029611037112772, 23.53702951222658, 90.59883490204811, 53.512209355831146, 20.667704679071903, 34.863672628998756, 119.06066805124283, 65.47611817717552, 22.440045475959778, 4.216621862724423, 0.1651742125977762, 0.2212685690028593, 0.60983752948232, 0.4251091059995815, 0.21987242595059797, 0.014965445934649324, 0.15751042461488396, 1.547348576132208, 45.73583543300629, 94.31929886341095, 92.72292852401733, 72.85191759467125, 74.44648683071136, 81.01398602128029, 87.68612399697304, 80.32904997467995, 75.43658450245857, 82.25562259554863, 82.58083954453468, 78.85359674692154, 77.03051537275314, 77.17112302780151, 77.40704476833344, 82.71629467606544, 80.41931793093681, 78.71469140052795, 80.23309752345085, 75.08568093180656, 75.27519196271896, 75.45737698674202, 77.42091402411461, 74.28335398435593, 75.28323233127594, 67.64882639050484, 59.27768558263779, 55.07822312414646, 55.90774901211262, 57.420805022120476, 59.751102179288864, 63.04812826216221, 66.24524250626564, 68.44537004828453, 74.46661055088043, 69.73680675029755, 80.15406176447868, 27.849247120320797, 48.00858087837696, 84.17598634958267, 72.90937051177025, 75.51367476582527, 65.8795577287674, 67.33604237437248, 59.38796706497669, 60.194131806492805, 55.594676211476326, 55.27654968202114, 54.059228003025055, 55.9310607612133, 58.80754441022873, 65.00751972198486, 68.25493186712265, 65.93743622303009, 57.71079786121845, 59.827652871608734, 64.81959700584412, 66.765898168087, 66.27211466431618, 65.71281507611275, 63.443132266402245, 57.79106855392456, 63.43523629009724, 72.51074150204659, 75.14286786317825, 74.19724300503731, 72.41741850972176, 72.51562803983688, 80.48272132873535, 75.80829575657845, 76.56483516097069, 75.52549973130226, 76.91336005926132, 81.13073095679283, 71.4917653799057, 57.61862240731716, 64.80534017086029, 82.36987486481667, 46.81174010038376, 2.965245461091399, 0.3918820561375469, 0.09754743048688397, 0.385659949388355, 0.44550258200615644, 0.07803454238455743, 0.37766737514175475, 9.309418760240078, 34.35932569205761, 50.35050541162491, 97.0464201271534, 17.97371193766594, 15.240338109433651, 41.64995647966862, 67.73868396878242, 31.510035283863544, 0.33489784982521087, 0.10757055788417347, 0.0345132288930472, 0.024570964051235933, 0.04476212132431101, 0.06544600342749618, 0.044688303605653346, 0.032725324635975994, 0.017270943462790456, 0.03729512864083517, 0.04597034516336862, 0.08635219957795925, 0.03978642933361698, 0.036086055042687804, 0.03342554467963055, 0.08087106791208498, 0.04899238163488917, 0.051767268087132834, 0.06494733956060372, 0.02000175376451807, 0.10126499662874267, 0.03430980992561672, 0.010911260160355596, 0.04221621711621992, 0.05435734863567632, 0.030697007205162663, 0.036605714267352596, 0.005908419479965232, 0.03900816504028626, 0.14049336430616677, 0.1372356477077119, 0.123838509171037, 0.12134434378822334, 0.12164954459876753, 0.2113038263632916, 0.08345273992745206, 0.1596917599090375, 0.1094425140763633, 0.13142093550413847, 0.13722570292884484, 0.06663867185125127, 0.13653638132382184, 0.14379961736267433, 0.1718980705481954, 0.11711050261510536, 0.2189859899226576, 0.11588964742259122, 0.1560487350798212, 0.20445460482733324, 0.23649720184039325, 0.18824035534635186, 0.16831236920552328, 0.13556918478570879, 0.12696117715677246, 0.1349050665157847, 0.14312571758637205, 0.17097075702622533, 0.17115451279096305, 0.18217058182926849, 0.15784412389621139, 0.14040317852050066, 0.3447700466495007, 0.2827882475685328, 1.0042504873126745, 27.03032646328211, 112.97615334391594, 77.6819296181202, 59.66466061770916, 33.08162905275822, 90.31758919358253, 91.46390408277512, 34.497330486774445, 4.269835632294416, 0.22710137476678938, 0.32373413792811334, 0.9347281116060913, 2.2674879524856806, 0.2584200067212805, 0.15792630932992324, 0.812781552085653, 1.7056178022176027, 40.902437791228294, 90.56070774793625, 97.28733479976654, 78.38099330663681, 73.70402187108994, 80.42353570461273, 86.25585794448853, 81.84772208333015, 80.2710422873497, 84.27398309111595, 84.68661814928055, 81.84700772166252, 84.608805924654, 82.71019980311394, 83.14156025648117, 85.0275282561779, 85.31024068593979, 82.1539780497551, 80.69820016622543, 78.21070924401283, 79.62159633636475, 81.5302187204361, 81.8179240822792, 79.5286837220192, 81.60201206803322, 73.8446219265461, 66.70057207345963, 60.290756821632385, 58.44772271811962, 60.69333761930466, 62.079970613121986, 66.35859042406082, 70.42184919118881, 73.97424057126045, 80.40480270981789, 75.8670862019062, 82.26045593619347, 30.81233572214842, 51.90875619649887, 85.8787053823471, 75.51055133342743, 76.77385434508324, 67.76436299085617, 71.9810651242733, 64.6381263434887, 64.57811236381531, 60.89846961200237, 60.13819880783558, 58.79141807556152, 60.878019109368324, 67.03841954469681, 72.15584814548492, 72.73163884878159, 73.76654371619225, 62.40204893052578, 66.46330520510674, 69.75997790694237, 71.09666258096695, 70.15401676297188, 71.38720259070396, 69.27988886833191, 63.189290687441826, 69.3148697912693, 77.72546008229256, 85.58452516794205, 78.13561767339706, 75.61298623681068, 76.80324196815491, 85.53388148546219, 81.89024940133095, 79.01910826563835, 76.55968263745308, 78.88246759772301, 79.99934166669846, 74.53668639063835, 66.96139007806778, 74.02169242501259, 80.55373951792717, 43.64688232541084, 2.711631157435477, 0.34022638108581305, 0.5091416265349835, 0.4168079764349386, 0.8122020831797272, 0.12608915363671258, 0.37920240371022373, 7.4255577474832535, 32.628172785043716, 76.10908761620522, 71.94872125983238, 17.524625435471535, 47.627761512994766, 57.1760905534029, 77.75368496775627, 38.17941650748253, 0.3486702108057216, 0.1805281051201746, 0.23551412334199995, 0.05799062906589825, 0.18990678858244792, 0.171371724572964, 0.1067485254316125, 0.1433134957915172, 0.13338991266209632, 0.13565285451477394, 0.25389973365236074, 0.15309501701267436, 0.09826306864852086, 0.10854481224669144, 0.1573627075413242, 0.2727911324473098, 0.14673344587208703, 0.16773646260844544, 0.13277682446641847, 0.11604891973547637, 0.22825027874205261, 0.11956978705711663, 0.12963390327058733, 0.145175410725642, 0.1337676213006489, 0.11859595571877435, 0.12103631539503112, 0.17201816488523036, 0.15186039498075843], [0.031736138262203895, 0.0688303897914011, 0.05934567569056526, 0.043568361943471245, 0.05866654377314262, 0.0627440441166982, 0.02881221371353604, 0.019143632525810972, 0.08109737842460163, 0.04017942621430848, 0.06817771543865092, 0.0463175329787191, 0.0190022032984416, 0.10118608406628482, 0.05680296271748375, 0.047319417499238625, 0.055945841522770934, 0.00945052150200354, 0.06490490355645306, 0.06581750028999522, 0.06790946616092697, 0.027735188596125226, 0.04858922846324276, 0.04954226111294702, 0.06006554780469742, 0.07457825675373897, 0.03223427520424593, 0.011620918467087904, 0.07175649254349992, 0.009772008743311744, 0.05532868635782506, 0.05715306346246507, 0.057167171689798124, 0.08379861785215326, 0.041190171978087164, 0.13492112659150735, 21.726451367139816, 82.79587760567665, 65.86849272251129, 54.34357814490795, 15.501866675913334, 53.436205834150314, 97.1485510468483, 41.931331381201744, 9.357113800942898, 1.64119926514104, 0.1608161730109714, 0.09012130787596107, 0.13366091530770063, 0.1439861042308621, 0.1200318185146898, 0.04045340858283453, 0.04777976057084743, 5.515670506283641, 29.152734875679016, 83.0980221927166, 98.40832784771919, 84.71323952078819, 81.26424059271812, 73.72582510113716, 78.20984289050102, 84.95408579707146, 85.16153946518898, 80.2881109714508, 78.76624703407288, 80.12931749224663, 80.30135706067085, 70.81542447209358, 75.54840490221977, 78.0733010172844, 79.17211085557938, 78.56928840279579, 80.48177137970924, 77.55209058523178, 75.93909993767738, 74.6429742872715, 77.033821195364, 73.83355692029, 72.05510035157204, 61.79778255522251, 56.02825194597244, 53.160059452056885, 57.99662232398987, 62.633361518383026, 66.68248504400253, 67.77825504541397, 73.69012981653214, 69.02138113975525, 81.20673447847366, 26.25842448323965, 43.22679966688156, 81.25639021396637, 71.50014013051987, 74.4341678917408, 64.79889571666718, 63.16245652735233, 60.14665715396404, 58.66005912423134, 58.19909445941448, 55.238513723015785, 54.52286772429943, 55.76741114258766, 69.61869388818741, 73.97421017289162, 72.79505744576454, 73.53632166981697, 64.13694843649864, 60.81423193216324, 66.8626257777214, 69.14066433906555, 70.07479101419449, 66.80220901966095, 67.3098161816597, 64.16951268911362, 60.087817311286926, 67.41288185119629, 74.55801084637642, 77.94232204556465, 81.2015363574028, 78.28350573778152, 77.04893678426743, 73.98341327905655, 74.22250404953957, 83.94599989056587, 79.43403840065002, 62.44805306196213, 66.93157687783241, 82.80047535896301, 52.19764709472656, 11.91830936819315, 0.19789663172559813, 0.14849773870082572, 0.028364082681946456, 0.18024058226728812, 0.1761208611424081, 0.21838321757968515, 0.01633553682040656, 9.999134000390768, 19.363996535539627, 59.190096482634544, 54.01562534272671, 6.239421470090747, 39.546058773994446, 38.09598058462143, 62.88573257625103, 30.97474280744791, 0.2932590607088059, 0.040360521379625425, 0.024525487096980214, 0.020557273564918432, 0.06795324545237236, 0.04907452625047881, 0.027822621013910975, 0.03190486924722791, 0.02421473131107632, 0.05510705508640967, 0.04473167471587658, 0.046315829749801196, 0.03604122561227996, 0.033591848841751926, 0.05728985612222459, 0.03966503623814788, 0.03789359652728308, 0.1201831350044813, 0.04783293174114078, 0.024342774049728177, 0.05274667295452673, 0.05079394511994906, 0.05955187400104478, 0.0014832390684205166, 0.08450400695437565, 0.08166461673681624, 0.025293869693996385, 0.023907806862553116, 0.019039576000068337, 0.0603241194767179, 0.16190618014661595, 0.04167729173786938, 0.023836377004045062, 0.014757424723939039, 0.060731539997505024, 0.04043725202791393, 0.04284550639567897, 0.053568846415146254, 0.07072123364196159, 0.04861284360231366, 0.05776681216957513, 0.011640146585705224, 0.061107486035325564, 0.04707274987595156, 0.00983938369245152, 0.028160292640677653, 0.030557156896975357, 0.00293451151719637, 0.018870796775445342, 0.003431994209677214, 0.048383048706455156, 0.04566817602608353, 0.007829875066818204, 0.07299334843992256, 0.011172633439855417, 0.02685096416826127, 0.05749701180320699, 0.014654726328444667, 0.06540645437780768, 0.10871705730096437, 0.07670183811569586, 0.034272888078703545, 0.14103502820944414, 0.10079099432914518, 0.07152226331527345, 0.16155621298821643, 34.194422140717506, 89.77349638938904, 57.482794895768166, 23.54087870568037, 29.9407821893692, 101.76447495818138, 92.37748146057129, 39.12787601351738, 16.503380835056305, 1.4485282287932932, 0.3392787475604564, 0.15092031651875004, 0.301082544028759, 0.21529782767174765, 0.04922476291540079, 0.06438120704842731, 0.08258321002358571, 9.464784823358059, 43.950102254748344, 90.69193750619888, 91.42193913459778, 77.53037855029106, 74.9168635904789, 73.03035601973534, 80.18154948949814, 84.84861105680466, 84.54413339495659, 82.53451243042946, 84.75124508142471, 80.53701281547546, 82.17993825674057, 75.01700341701508, 80.59761196374893, 81.63735017180443, 80.7624015212059, 82.7030561864376, 82.97472640872002, 78.31138104200363, 77.10643529891968, 77.59736895561218, 76.35081544518471, 77.11709752678871, 75.83649024367332, 63.07314611971378, 59.50165696442127, 57.67544835805893, 61.60232484340668, 63.59846793115139, 69.09708827733994, 69.3865567445755, 74.63442474603653, 67.09905669093132, 85.27386903762817, 27.765892893075943, 46.33433371782303, 83.55671837925911, 71.95703521370888, 74.04782742261887, 63.59391577541828, 63.294404447078705, 60.32557815313339, 58.98552305996418, 57.75481849908829, 57.205223590135574, 55.03773249685764, 57.09479011595249, 68.32209706306458, 73.19202974438667, 72.07543686032295, 71.18167161941528, 63.78235146403313, 61.9849719107151, 69.74503710865974, 74.89426240324974, 72.00058087706566, 67.01693549752235, 65.70536747574806, 61.564934849739075, 62.81335026025772, 71.98134630918503, 77.45499819517136, 76.3175368309021, 77.234997600317, 76.09962612390518, 73.97348061203957, 73.78922089934349, 73.50571051239967, 80.24358496069908, 81.88635841012001, 61.92008279263973, 64.58636552095413, 89.6222873032093, 62.87400260567665, 15.573850013315678, 0.36066587024834007, 0.0988229745416902, 0.09316777955973521, 0.31941166205797344, 0.5149541865102947, 0.3344795753946528, 0.20753387943841517, 20.86186856031418, 29.497604370117188, 45.27386002242565, 89.30099934339523, 15.28069669380784, 15.096386633813381, 38.14793139696121, 65.66978618502617, 38.3899138122797, 0.36465749668423086, 0.13543306005885825, 0.06466505627031438, 0.01166312718851259, 0.0206229462128249, 0.057065645887632854, 0.019698708892974537, 0.022473979406640865, 0.08872869744664058, 0.0872653974511195, 0.039969817735254765, 0.01753778265992878, 0.0528737175045535, 0.028956123569514602, 0.035236930489190854, 0.048993235104717314, 0.027770394226536155, 0.04447598628757987, 0.0657475454499945, 0.012803152294509346, 0.0444433577649761, 0.07498566614231095, 0.056958027053042315, 0.0057207739337172825, 0.001591310265212087, 0.016697443279554136, 0.05505720131623093, 0.08918085091863759, 0.012139666705479613, 0.04603624787705485, 0.37510162219405174, 0.09415561522473581, 0.11126426397822797, 0.09611238405341282, 0.11412205945816822, 0.11112163061625324, 0.17719693074468523, 0.14012042025569826, 0.1759002503240481, 0.12693337630480528, 0.14976719714468345, 0.12852283398387954, 0.10064816800877452, 0.22109115117928013, 0.10362916000303812, 0.16333089588442817, 0.19533837446942925, 0.0810685014585033, 0.1322636441909708, 0.11036924130166881, 0.12048695542034693, 0.10343363377614878, 0.14293448097305372, 0.18810298381140456, 0.1416928827529773, 0.17355442541884258, 0.19605767884058878, 0.13689653074834496, 0.16952002159086987, 0.21722573437727988, 0.15887274057604373, 0.1077405022806488, 0.3321634215535596, 0.18884495337260887, 0.1461929248762317, 0.38092501752544194, 41.64187051355839, 112.8543470799923, 82.23097711801529, 71.07442617416382, 29.423650838434696, 69.19323831796646, 114.44133952260017, 65.50270915031433, 17.56892155855894, 1.6595767415128648, 0.2618562098359689, 0.36389534070622176, 0.7097151700872928, 0.5846822261810303, 0.4086069477489218, 0.25312947342172265, 0.14446164277615026, 7.53999525681138, 36.064943969249725, 89.13765370845795, 100.61682254076004, 83.26576799154282, 81.4026291668415, 74.32563811540604, 78.46434563398361, 87.19469636678696, 91.49670392274857, 88.82331937551498, 87.12640643119812, 86.09735324978828, 87.01024666428566, 78.72070267796516, 79.98889982700348, 85.8492873609066, 86.05531990528107, 87.7996239066124, 87.83496960997581, 82.95502066612244, 81.2811952829361, 82.83981084823608, 82.92645379900932, 81.98507711291313, 82.75460422039032, 70.13453900814056, 64.64205533266068, 63.03561933338642, 67.14098364114761, 70.4103510081768, 73.34200769662857, 76.25264391303062, 77.88325801491737, 73.97062316536903, 88.22457030415535, 34.602307453751564, 52.77835473418236, 84.54364702105522, 78.24758246541023, 80.09656324982643, 70.21089971065521, 66.97389900684357, 64.7899129986763, 62.6264800876379, 63.091575130820274, 61.203224658966064, 58.64273965358734, 62.471444606781006, 75.38299977779388, 78.58458638191223, 76.59316644072533, 76.42417430877686, 70.06437197327614, 66.31426960229874, 75.28304234147072, 79.10211861133575, 79.52545389533043, 72.95058310031891, 71.09280958771706, 69.47961375117302, 67.10233211517334, 74.93157640099525, 82.97670230269432, 84.25515130162239, 82.61597245931625, 79.68275785446167, 76.15310445427895, 77.31468692421913, 78.62730368971825, 81.45426839590073, 82.15085461735725, 68.84388506412506, 74.42558035254478, 87.01384127140045, 57.2387719899416, 13.968685995787382, 0.4280999314505607, 0.3862423571990803, 0.24750258395215496, 0.5044932290911674, 0.44524565048050135, 0.49128558312077075, 0.2892049157526344, 15.416560303419828, 35.12248434126377, 76.70497924089432, 67.20369547605515, 15.013033356517553, 59.317917823791504, 51.54271423816681, 76.98807924985886, 47.796434462070465, 0.48157912271562964, 0.3472980094375089, 0.1661360211437568, 0.20319886127253994, 0.11996157423709519, 0.15411677624797449, 0.16682553570717573, 0.1931559111108072, 0.21580376458587125, 0.1968220909475349, 0.1580038489191793, 0.13615798990940675, 0.17627041874220595, 0.1444621177506633, 0.16721663268981501, 0.10609747638227418, 0.12086288290447555, 0.16706937574781477, 0.2511518873507157, 0.05822715524118394, 0.14040372770978138, 0.1603606724529527, 0.16865276265889406, 0.16764161613537, 0.16804901068098843, 0.12086013695807196, 0.09701788585516624, 0.17271550168516114, 0.19705058337422088, 0.11627514119027182], [0.09906734892865643, 0.04276322819350753, 0.03511887334752828, 0.1304581473232247, 0.021187796664889902, 0.08802468873909675, 0.10107378227985464, 0.016828870211611502, 0.0663925385742914, 0.056108754070010036, 0.06303996065980755, 0.02471560121193761, 0.06272327882470563, 0.05389283840486314, 0.052629224373959005, 0.020366708595247474, 0.06441817342420109, 0.0031697772010375047, 0.011023117585864384, 0.062045044905971736, 0.03909961618774105, 0.051823571120621637, 0.06340477077174, 0.03110357982222922, 0.06625831374549307, 0.016215874784393236, 0.04511058563366532, 0.027960367333434988, 0.052236869451007806, 0.02758450478722807, 0.03080308422795497, 0.031750999769428745, 0.042936701502185315, 0.006056131451259716, 0.05821288003062364, 0.017487123659520876, 0.14258607232477516, 20.029637217521667, 78.16641122102737, 61.73334181308746, 61.091662645339966, 12.606157958507538, 30.405210368335247, 93.88124316930771, 64.79834094643593, 21.2650915235281, 5.329527519643307, 0.22229259921004996, 0.23836533597204834, 0.14051784033654258, 0.0842184730572626, 0.18340566399274394, 0.04176226393610705, 0.04796371671545785, 0.5723027279600501, 2.1460994286462665, 32.48180843889713, 63.73818643391132, 88.31747531890869, 91.82554587721825, 79.2352482676506, 70.52224740386009, 73.68721917271614, 81.53067469596863, 82.84452259540558, 77.44279325008392, 76.6108886897564, 80.87479948997498, 80.38530215620995, 76.15767940878868, 80.90617820620537, 81.3690921664238, 77.81234622001648, 79.62418019771576, 79.22108262777328, 77.81192064285278, 74.80208694934845, 75.88086426258087, 73.82240071892738, 74.92615029215813, 66.41161277890205, 64.11165699362755, 62.866194024682045, 66.62532851099968, 69.32534962892532, 72.55719020962715, 69.87832635641098, 76.73847824335098, 69.84618008136749, 40.10626271367073, 43.374896720051765, 75.81822842359543, 77.76521354913712, 71.25658839941025, 67.85671323537827, 65.32598823308945, 67.17164799571037, 64.77364987134933, 63.34797777235508, 59.25650551915169, 59.10839706659317, 63.36290717124939, 72.50598415732384, 74.2660041153431, 78.57703998684883, 75.47135263681412, 66.49548187851906, 60.696096271276474, 70.13976752758026, 70.56046575307846, 72.75803983211517, 69.10010531544685, 68.26968267560005, 65.06726771593094, 64.55002427101135, 68.4731237590313, 76.38763546943665, 77.54547894001007, 82.33162611722946, 78.71148437261581, 83.2646356523037, 84.13915872573853, 84.6403594315052, 74.91779074072838, 69.21026140451431, 86.87928289175034, 66.36840149760246, 14.730638209730387, 0.3932725143386051, 0.23370982875349, 0.057315864687552676, 0.08079284554696642, 0.11701512921717949, 0.07125163174350746, 0.6755709741264582, 2.1491081546992064, 13.539507575333118, 26.19499448686838, 77.19713643193245, 56.08227364718914, 6.488116700202227, 48.69338773190975, 50.48803523182869, 65.38518145680428, 30.77580828219652, 0.018875399946409743, 0.059910965865128674, 0.05872029752936214, 0.03862194767862093, 0.013100090218358673, 0.046232490276452154, 0.042839008892769925, 0.02827676715241978, 0.03798615718551446, 0.05488561677339021, 0.03848075037240051, 0.014585077624360565, 0.06971550479647703, 0.03502652049064636, 0.07791616240865551, 0.03452781951637007, 0.062376762653002515, 0.06599000509595498, 0.07021993515081704, 0.0076060270930611296, 0.05445685579616111, 0.0670626682403963, 0.05360254734114278, 0.06330808377242647, 0.05674876367265824, 0.03806174121564254, 0.06441836638259701, 0.10298827837686986, 0.04603830733685754, 0.03003490943228826, 0.05918245886277873, 0.05924644312472083, 0.024415278166998178, 0.04495158420468215, 0.04072232579346746, 0.014114411278569605, 0.0927332669380121, 0.07688706333283335, 0.03725362032128032, 0.0865156130748801, 0.023754968970024493, 0.04888945688435342, 0.018238466545881238, 0.030306292428576853, 0.04211808292893693, 0.01338624102572794, 0.026685294542403426, 0.025160008517559618, 0.0796570850070566, 0.07665296769118868, 0.033788106084102765, 0.01722816792607773, 0.032788960088510066, 0.05481007356138434, 0.04316554273827933, 0.05516624507436063, 0.06192932924022898, 0.07293408794794232, 0.06878502972540446, 0.014608926539949607, 0.028289405927353073, 0.019645010797830764, 0.0302809406639426, 0.07017162133706734, 0.037557236646534875, 0.027576090687944088, 0.030188747368811164, 0.20871668471954763, 35.86815632879734, 86.817597001791, 52.42335118353367, 19.662840999662876, 15.546163748949766, 77.23463281989098, 109.34946075081825, 56.69263869524002, 34.664221331477165, 12.59677816182375, 0.05298403404594865, 0.1595625965273939, 0.29079652565997094, 0.09580016252584755, 0.20602826960384846, 0.06207840815477539, 0.24144879629602656, 0.25556840817444026, 6.0000276658684015, 48.63862507045269, 79.78441759943962, 98.7989316880703, 91.04476377367973, 75.41807189583778, 73.46563026309013, 80.80289974808693, 85.27951553463936, 82.85797387361526, 82.85035148262978, 79.7006244957447, 81.18210420012474, 80.24337977170944, 77.09483072161674, 83.78013119101524, 79.48770672082901, 79.18726444244385, 80.71023032069206, 78.94345432519913, 77.2394509613514, 76.96087270975113, 75.43630331754684, 73.40126931667328, 73.89183819293976, 63.96675556898117, 63.28150033950806, 62.6050416380167, 66.61933243274689, 69.79277774691582, 72.79834806919098, 72.74936869740486, 80.63444718718529, 74.33222696185112, 39.16110523045063, 48.39508853852749, 78.33638370037079, 78.84405165910721, 75.12330651283264, 69.41870301961899, 67.07548275589943, 69.95965719223022, 67.01364487409592, 65.95226302742958, 63.005034774541855, 60.900494903326035, 64.83111038804054, 76.89977198839188, 76.93583965301514, 79.89652678370476, 78.47450628876686, 67.34751015901566, 63.56250286102295, 70.8522292971611, 71.73465594649315, 70.87516486644745, 74.22068014740944, 71.01114436984062, 69.88233134150505, 63.215444684028625, 66.98639273643494, 71.3433301448822, 77.40908905863762, 81.46910279989243, 76.56820178031921, 80.13117179274559, 79.72507998347282, 81.78742691874504, 75.15658512711525, 66.96118488907814, 85.98551765084267, 80.74565201997757, 21.539347507059574, 0.9298986895009875, 0.2848908706801012, 0.04407986125443131, 0.12834973545977846, 0.15791301004355773, 0.20843340695137158, 1.0467849299311638, 3.3281658869236708, 25.77456794679165, 26.68406244367361, 61.47557884454727, 91.53014972805977, 13.133070934563875, 20.326788872480392, 48.740793988108635, 69.6451024711132, 39.802628606557846, 0.16737757483497262, 0.2068570556002669, 0.040170412830775604, 0.02349775913899066, 0.0073399949815211585, 0.0266066213225713, 0.029173326074669603, 0.07131397214834578, 0.052695060294354334, 0.06981255544815212, 0.09052601584699005, 0.029844487326045055, 0.019164188161084894, 0.06764083096641116, 0.054627108183922246, 0.04671391405281611, 0.025600443477742374, 0.020626601290132385, 0.016729318522266112, 0.03854537288134452, 0.042847191070904955, 0.021898800114286132, 0.06876311410451308, 0.13058125477982685, 0.03666778007755056, 0.08305010254844092, 0.09040494929649867, 0.025495075205981266, 0.0685454421909526, 0.055460877701989375, 0.012753242863254854, 0.24100030161207542, 0.16524850158020854, 0.11738192828488536, 0.21827300864970312, 0.09075559923076071, 0.1688445039326325, 0.14324554475024343, 0.1855426633846946, 0.10656587546691298, 0.30256072408519685, 0.1382574366289191, 0.1341952319489792, 0.11631476445472799, 0.13751897000474855, 0.18864816549466923, 0.0689841850544326, 0.13047382148215547, 0.1389176066732034, 0.16837435337947682, 0.12471298919990659, 0.13481139263603836, 0.17656810901826248, 0.15522391215199605, 0.20926061959471554, 0.19723027216969058, 0.10887865253607742, 0.178581110376399, 0.1404982921667397, 0.08782578574027866, 0.10257764064590447, 0.08786285601672716, 0.0735582786728628, 0.13592540082754567, 0.10055095408461057, 0.25182703393511474, 0.16267400613287464, 0.46483882411848754, 37.042240127921104, 107.86931097507477, 78.58115896582603, 81.09100788831711, 24.09386683255434, 44.978182688355446, 102.38315775990486, 85.37981495261192, 37.96657092869282, 8.46784371882677, 0.2257011499023065, 0.27643941168207675, 0.2890330640366301, 0.2459093413199298, 0.39477539306972176, 0.34179355949163437, 0.1722984146908857, 0.3165887400973588, 3.8142510037869215, 39.172755405306816, 71.1265441775322, 94.80859100818634, 94.95789259672165, 84.24490705132484, 78.58571112155914, 79.75907295942307, 87.80341610312462, 88.9952601492405, 85.69503083825111, 81.22808173298836, 86.20323836803436, 88.05977314710617, 81.23954191803932, 88.0305527150631, 84.70451518893242, 85.5255675315857, 88.26772078871727, 85.38763493299484, 83.13219755887985, 81.84156641364098, 79.95299935340881, 76.88043862581253, 81.84941679239273, 69.86497387290001, 70.57783082127571, 67.94886589050293, 71.48017600178719, 75.05817040801048, 80.72676703333855, 77.44885012507439, 86.20154365897179, 75.5925889313221, 48.31059627234936, 55.850824266672134, 80.81087931990623, 84.36558857560158, 80.24862349033356, 75.92364996671677, 71.73865333199501, 76.5236833691597, 73.54823023080826, 73.03201273083687, 68.57698738574982, 69.7423392534256, 71.58451080322266, 82.29679718613625, 83.63668128848076, 84.96397286653519, 84.37869027256966, 73.38914036750793, 68.0924753844738, 75.16587942838669, 77.68666416406631, 75.59920817613602, 80.42535960674286, 77.23330289125443, 78.1917254626751, 70.87688237428665, 73.31149533390999, 78.49620312452316, 81.30248174071312, 86.28497198224068, 80.27594402432442, 87.69165650010109, 82.6200458407402, 80.56089833378792, 76.68630704283714, 74.66381996870041, 89.9136708676815, 73.91301065683365, 18.201766200363636, 1.0920116468332708, 0.35773658368270844, 0.280722375609912, 0.5062540189828724, 0.5639571289066225, 0.3567646670853719, 0.9099920920561999, 3.1885768147185445, 23.46139647066593, 39.96705338358879, 93.03562134504318, 72.3852950334549, 15.9276176802814, 68.66657137870789, 64.6234667301178, 80.62577605247498, 48.88770550489426, 0.1687056035734713, 0.3443716617766768, 0.26721540663857013, 0.14607747638365254, 0.10178860407904722, 0.12237278235261329, 0.12623980961507186, 0.15016889199614525, 0.08069437739322893, 0.1329928042832762, 0.15175563341472298, 0.11272055809968151, 0.10058674044557847, 0.23988096480024979, 0.23074858530890197, 0.1142455379886087, 0.1349291269434616, 0.15490432851947844, 0.11534844365087338, 0.09510085903457366, 0.13752272527199239, 0.15891732880845666, 0.10972033705911599, 0.15254009835189208, 0.12194279683171771, 0.1582617749227211, 0.13175073108868673, 0.21354907541535795, 0.1392812145058997, 0.24765890993876383, 0.11072011388023384], [0.03056885314435931, 0.0723620256758295, 0.008421872353210347, 0.05007154599297792, 0.07028647611150518, 0.049503276095492765, 0.005759487139584962, 0.03265325467509683, 0.0807438044284936, 0.058990498655475676, 0.0549765372852562, 0.011585435458982829, 0.058906138729071245, 0.06377639379934408, 0.06243697309400886, 0.05948291734966915, 0.015088201798789669, 0.04734417554573156, 0.021710992223233916, 0.0896552020276431, 0.05150200966454577, 0.02958465771371266, 0.0232236023657606, 0.03896146168699488, 0.04200458628474735, 0.02785094879072858, 0.021897783371969126, 0.13565107336034998, 0.01917766741826199, 0.09095024972339161, 0.08116474316921085, 0.04705064871814102, 0.022466396512754727, 0.0654587015742436, 0.08119802849250846, 0.07690107508096844, 0.0528877478063805, 0.5723375792149454, 14.223604816943407, 88.97145822644234, 73.3115029335022, 64.64333966374397, 31.057154685258865, 33.33285257220268, 79.35989677906036, 76.50504156947136, 26.946373768150806, 11.00028907880187, 2.1214159531518817, 0.2104490206693299, 0.06467514947871678, 0.13425895274849609, 0.18997365608811378, 0.2361633096006699, 0.3914352832362056, 0.10986691864673048, 0.6645550683606416, 0.22942459385376424, 4.44115181453526, 24.53788060694933, 62.69157439470291, 81.50075510144234, 75.84502458572388, 66.01777911186218, 73.63659828901291, 81.54722660779953, 86.11945286393166, 76.48572340607643, 75.95490708947182, 82.78981313109398, 84.08266335725784, 80.3221495449543, 78.46440643072128, 82.57272318005562, 79.29748132824898, 81.22653141617775, 76.9677123427391, 82.0177173614502, 77.64374926686287, 78.00707057118416, 69.73265737295151, 64.67689946293831, 62.104422301054, 65.3712210059166, 70.40513768792152, 76.28073960542679, 73.1220830976963, 78.04220348596573, 78.39870035648346, 38.76189485192299, 40.0414077937603, 72.1245226264, 79.4276775419712, 75.11098757386208, 72.98424929380417, 71.11482560634613, 72.0477743446827, 70.07929757237434, 67.7603580057621, 65.9764601290226, 62.050051018595695, 68.03138226270676, 74.0573801100254, 79.42301899194717, 79.7646814584732, 75.29916107654572, 69.91345167160034, 67.39090383052826, 72.50952556729317, 74.26105678081512, 78.42852115631104, 76.06625631451607, 79.65215429663658, 77.57794439792633, 76.94041460752487, 74.64498057961464, 74.27567839622498, 82.58962467312813, 80.20171880722046, 82.64767795801163, 80.09008079767227, 72.65935152769089, 71.46001428365707, 73.64474505186081, 81.72242000699043, 34.0429812669754, 1.846769421827048, 0.13966738362796605, 0.5343413993250579, 0.17895365366712213, 0.07718079796177335, 0.05575274582952261, 0.04979528152034618, 0.1732825767248869, 4.72022688947618, 20.894109830260277, 39.90795515477657, 73.6822110414505, 49.829063192009926, 12.384284064173698, 51.38830192387104, 54.72578823566437, 59.737175926566124, 20.20059574395418, 0.07084323529852554, 0.07381878735031933, 0.0716815356281586, 0.07430749159539118, 0.00532706969352148, 0.0440416183846537, 0.03261463702074252, 0.017271514916501474, 0.027421519880590495, 0.031199272343656048, 0.046164487284841016, 0.024340484524145722, 0.037192307790974155, 0.038132033732836135, 0.04388266890600789, 0.024694086350791622, 0.061924171313876286, 0.026924783742288128, 0.04670885631639976, 0.0342998985433951, 0.09497306862613186, 0.03508138375764247, 0.041563090053386986, 0.08166598971001804, 0.030533480530721135, 0.0790335399506148, 0.013650171931658406, 0.05176662241865415, 0.07315228678635322, 0.043453522011986934, 0.0479767191427527, 0.0632758968276903, 0.04731864195491653, 0.04780247028975282, 0.020317303824413102, 0.0028037420815962832, 0.02700826236832654, 0.029187927830207627, 0.03043923705263296, 0.07869176610256545, 0.01851949746196624, 0.04118914410355501, 0.042069052942679264, 0.002875836162274936, 0.02822473703417927, 0.05885755403141957, 0.018084756629832555, 0.04450304128113203, 0.013116687423462281, 0.05754754463850986, 0.038993748821667396, 0.016182843646674883, 0.03514272968459409, 0.018268091225763783, 0.016905712182051502, 0.026383954755146988, 0.024201875457947608, 0.0716778397327289, 0.051536285754991695, 0.05461484419356566, 0.06880290806293488, 0.0863230628601741, 0.05154663129360415, 0.03285625061835162, 0.016252833738690242, 0.0732481203158386, 0.035468064961605705, 0.07502736742026173, 0.030438083012995776, 0.9023423900362104, 28.535965271294117, 92.90399640798569, 73.52089449763298, 27.792998738586903, 8.598743844777346, 62.269515842199326, 103.43234986066818, 65.73530226945877, 30.357486829161644, 22.37265609204769, 1.5367573569528759, 0.3823318029753864, 0.09538943573716097, 0.27641548484098166, 0.11060320335673168, 0.16472410003188998, 0.13938159740064293, 0.2033756853779778, 0.49581446510273963, 0.5720353766810149, 10.114325769245625, 39.51993137598038, 79.47512939572334, 86.86015471816063, 74.654381275177, 70.28050437569618, 81.75135925412178, 82.044817507267, 83.3335791528225, 79.61754575371742, 81.95874452590942, 83.51189598441124, 81.98263004422188, 84.68465745449066, 80.10212615132332, 84.10928472876549, 82.55455255508423, 81.71475201845169, 79.593006670475, 82.92322397232056, 81.11371546983719, 80.49114927649498, 73.49948644638062, 67.49308034777641, 64.77092161774635, 67.35151514410973, 72.40992531180382, 78.15719291567802, 74.87846285104752, 77.05395251512527, 76.04392871260643, 46.513748690485954, 44.6683207154274, 71.36465460062027, 80.73565855622292, 74.20725166797638, 73.21176588535309, 71.07100635766983, 70.68974241614342, 70.4908686876297, 67.56440252065659, 66.35738208889961, 62.533031702041626, 65.46116217970848, 74.06636282801628, 77.25348740816116, 77.54146635532379, 74.35786798596382, 72.29147046804428, 67.28813454508781, 74.82272744178772, 77.68248438835144, 79.44594696164131, 72.81516596674919, 75.2772818505764, 73.51828023791313, 75.42053416371346, 72.20352798700333, 77.53498390316963, 80.34613385796547, 79.75160256028175, 79.21221390366554, 76.43808156251907, 72.92777672410011, 67.2618855535984, 74.01988372206688, 90.44720023870468, 46.82696208357811, 3.8284335052594543, 0.15860351908486336, 0.1771618568454869, 0.03241874714149162, 0.2723363146651536, 0.10979464830597863, 0.01891460760816699, 0.32054242794401944, 10.175701975822449, 34.92041118443012, 32.36288242042065, 73.67651894688606, 88.5568168759346, 14.640530794858932, 26.942135095596313, 51.00739896297455, 69.93729159235954, 28.377304784953594, 0.225308598310221, 0.10856506545678712, 0.005805928421978024, 0.024220321538450662, 0.021355813332775142, 0.03788194109802134, 0.027479268246679567, 0.05214691744185984, 0.018399781620246358, 0.038749281666241586, 0.05401608315878548, 0.042154366528848186, 0.01957717293407768, 0.04765750658407342, 0.03784069253015332, 0.017539291075081564, 0.014447174526139861, 0.04457209070096724, 0.03604325909691397, 0.03253144968766719, 0.06990299356402829, 0.0445213945931755, 0.10384206732851453, 0.059248231700621545, 0.03237878991058096, 0.11433625069912523, 0.07037829462205991, 0.055477620553574525, 0.07421859714668244, 0.06664142521913163, 0.006256635169847868, 0.08245226548751816, 0.09285426669521257, 0.143703019421082, 0.0861201596853789, 0.13814261154038832, 0.12264629345736466, 0.09165862225927413, 0.08742233942029998, 0.18179324426455423, 0.17041205341229215, 0.12831800122512504, 0.08752171299420297, 0.04830344594665803, 0.11909327629837207, 0.27094956720247865, 0.12467619351809844, 0.22540218313224614, 0.1702784074586816, 0.12877137924078852, 0.11336474228301086, 0.12195487899589352, 0.21097827586345375, 0.09878188182483427, 0.06642017615376972, 0.1316008172580041, 0.1394435518886894, 0.16952223319094628, 0.17166203790111467, 0.2183197342674248, 0.08692018003785051, 0.15985280595486984, 0.11757500542444177, 0.1630580675555393, 0.10248105754726566, 0.19603409338742495, 0.21945038140984252, 0.22433022502809763, 0.1571962289744988, 0.7001871219836175, 27.24957089871168, 114.29988071322441, 96.94518595933914, 78.40180858969688, 43.58653396368027, 55.30015781521797, 92.18270391225815, 92.96993806958199, 41.62860542535782, 18.858323469758034, 2.60966956615448, 0.40284823800902814, 0.22916766232810915, 0.3190096851903945, 0.45975680463016033, 0.9167563228402287, 0.853799341712147, 0.1347056365921162, 0.6372391653712839, 0.3326190705411136, 6.99810728430748, 32.20286540687084, 73.04706752300262, 91.79124891757965, 84.71474424004555, 78.62798765301704, 81.98861092329025, 85.57555004954338, 90.20343571901321, 83.94399359822273, 80.41674166917801, 84.94225323200226, 92.22216859459877, 92.34188497066498, 83.57392385601997, 90.41019022464752, 85.73409274220467, 87.94777035713196, 85.40974974632263, 93.30880388617516, 87.83655032515526, 88.07525351643562, 79.83663439750671, 74.66502070426941, 71.2803067266941, 74.23772603273392, 78.76550987362862, 83.98371666669846, 81.22252643108368, 83.07355910539627, 81.34112566709518, 51.6058212518692, 49.4574811309576, 74.81275677680969, 84.87175181508064, 80.23966357111931, 80.4655234515667, 76.60433024168015, 77.06594467163086, 75.54275080561638, 73.07977616786957, 72.28227496147156, 66.50093078613281, 70.79053580760956, 78.79483669996262, 80.76563134789467, 79.34690907597542, 80.39864704012871, 76.9280044734478, 75.05905196070671, 82.2092954814434, 85.58033779263496, 88.55327546596527, 80.44248908758163, 81.83407321572304, 81.87815845012665, 79.69246253371239, 80.28963088989258, 84.55862581729889, 93.47241550683975, 84.95237588882446, 84.40258339047432, 78.25597241520882, 80.68653479218483, 80.75284123420715, 81.44881188869476, 85.62797963619232, 38.9591308683157, 2.972727259621024, 0.1509333634749055, 0.9583306044805795, 0.5240931117441505, 0.5902443558443338, 0.14589422527933493, 0.10934401623671874, 0.3645976498955861, 7.093554837629199, 36.811774894595146, 55.56465022265911, 84.60910230875015, 65.5020859837532, 22.126982174813747, 72.85643175244331, 67.9893185198307, 82.41515323519707, 35.23823373019695, 0.31480607169214636, 0.3565897874068469, 0.20657094282796606, 0.2073522165301256, 0.1817482998012565, 0.1792457333067432, 0.09834448967012577, 0.09008671637275256, 0.10027379161329009, 0.22422912967158481, 0.12060608496540226, 0.1913252702797763, 0.14616469357861206, 0.26751760917250067, 0.21007019880926237, 0.1638346360414289, 0.1432010010466911, 0.10649757561623119, 0.13865035929484293, 0.14426967885810882, 0.22260005614953116, 0.203487319231499, 0.14220564742572606, 0.17562093562446535, 0.23269706434803084, 0.25208289676811546, 0.14785782928811386, 0.10085183559567668, 0.15408308274345472, 0.17359623801894486, 0.1216543982445728, 0.19307057897094637], [0.01888302736915648, 0.009051592078321846, 0.0877278667758219, 0.07033561370917596, 0.07946662022732198, 0.03906579651811626, 0.05827775858051609, 0.05018684234528337, 0.04310411888582166, 0.0677841248398181, 0.020703532318293583, 0.009182929952658014, 0.012845900000684196, 0.06763461919035763, 0.02613977518194588, 0.06023066081979778, 0.018470695686119143, 0.02844928309059469, 0.011857943736686138, 0.05437930507468991, 0.06943319182028063, 0.06700492172967643, 0.044467117622843944, 0.056133701364160515, 0.024507623602403328, 0.036675472438219, 0.008311454694194254, 0.03543782986525912, 0.08964244450908154, 0.06452231158618815, 0.019420336720941123, 0.06319889158476144, 0.045355089896474965, 0.004114433322683908, 0.022526287830260117, 0.11661307071335614, 0.09940510775777511, 0.06326927687041461, 0.43413923238404095, 6.988186491653323, 57.86590553820133, 75.10287880897522, 88.66291478276253, 51.62778027355671, 38.62252973020077, 74.78802010416985, 92.93298125267029, 62.90151312947273, 35.709674432873726, 7.804684303700924, 0.31124673143494874, 0.19442159944446757, 0.14894136489601806, 0.1174349250504747, 0.40079961356241256, 0.11960601128521375, 0.23514092696132138, 0.12127061141654849, 0.5540606193244457, 0.3778670128667727, 2.440193435177207, 17.934195958077908, 48.308168202638626, 69.85329329967499, 74.74619954824448, 77.4154195189476, 72.43346124887466, 88.06886225938797, 79.69251573085785, 78.73673781752586, 83.56814056634903, 89.70781311392784, 88.07769298553467, 86.34187012910843, 89.95484545826912, 86.16497442126274, 85.10074272751808, 82.36423596739769, 87.63057857751846, 85.69159582257271, 81.43819525837898, 75.54069131612778, 71.00873529911041, 70.4356424510479, 78.01076397299767, 77.53217205405235, 75.6664189696312, 75.15346169471741, 66.26112565398216, 52.546213790774345, 40.09265564382076, 80.78697860240936, 80.54718106985092, 76.81845635175705, 75.44251218438148, 75.67338779568672, 73.7964329123497, 74.96586576104164, 69.6400335431099, 68.98594424128532, 64.35104414820671, 70.32420203089714, 75.74731662869453, 81.1694584786892, 79.60939139127731, 82.10569024085999, 74.18881505727768, 67.73318186402321, 72.94517979025841, 78.97908881306648, 80.67152559757233, 84.90330532193184, 76.91468238830566, 79.9548688530922, 80.72302803397179, 83.98102641105652, 77.61679351329803, 84.86344546079636, 73.95776465535164, 87.6529061794281, 93.2326103746891, 82.17033997178078, 67.98822417855263, 35.776877626776695, 6.088854074478149, 0.2527176111470908, 0.23312178062042221, 2.697476204484701, 3.7569873640313745, 0.23020171152893454, 0.13099810428684577, 0.4902241931995377, 0.5694185046013445, 8.534465543925762, 23.889274410903454, 57.81664498150349, 63.75775918364525, 27.611045502126217, 19.504816979169846, 56.30122169852257, 53.5463011264801, 62.65584111213684, 13.615499697625637, 0.4896441602613777, 0.3098572825547308, 0.042979553109034896, 0.0880785686604213, 0.029174077499192208, 0.02955911299068248, 0.006457379158746335, 0.014610657599405386, 0.04349809169070795, 0.053242798676365055, 0.0378384178475244, 0.06911140400916338, 0.04730074135295581, 0.03043338336283341, 0.014434888271352975, 0.13988046906888485, 0.048578088826616295, 0.06353445365675725, 0.11824854154838249, 0.06667828769423068, 0.059048278562841006, 0.08509828170645051, 0.047505392285529524, 0.16744779684813693, 0.03688266522658523, 0.06484460405772552, 0.08233341795857996, 0.08972949101007544, 0.07085677949362434, 0.059168933221371844, 0.0031868484529695706, 0.03536600852385163, 0.04673424147767946, 0.04500472568906844, 0.04112662558327429, 0.04569184311549179, 0.031723206338938326, 0.08476038929075003, 0.031060329311003443, 0.045975365792401135, 0.01777126788510941, 0.040393227827735245, 0.06130012159701437, 0.016715401397959795, 0.05412483005784452, 0.05490778843523003, 0.04459413619770203, 0.07160813722293824, 0.09520803258055821, 0.014902478415024234, 0.08851688107824884, 0.00690194185153814, 0.019829017037409358, 0.05172074284928385, 0.05628411985526327, 0.019707635074155405, 0.024034999842115212, 0.024516904159099795, 0.01115213439334184, 0.015268364641087828, 0.05422759895736817, 0.046193991365726106, 0.046350254269782454, 0.031795766117284074, 0.056822336482582614, 0.022504368498630356, 0.022968674638832454, 0.041850635170703754, 0.06012641133565921, 0.117494660516968, 0.034416942653479055, 0.6539863510988653, 17.60862372815609, 75.88651075959206, 80.11610940098763, 67.15616002678871, 33.09922970831394, 46.95816524326801, 101.15483567118645, 78.25916424393654, 44.95108634233475, 45.72286292910576, 11.228139102458954, 0.2698593819513917, 0.3689781320281327, 0.11592314054723829, 0.18872609100071713, 0.600922554731369, 0.040228964571724646, 0.6156948558054864, 0.5992858519311994, 1.637866843957454, 0.4322819336084649, 4.619810627773404, 32.80940406024456, 71.24502182006836, 79.99128609895706, 75.14546692371368, 82.8647755086422, 79.17009696364403, 89.47207376360893, 78.65584015846252, 80.97753077745438, 88.04692223668098, 82.99130111932755, 87.06848993897438, 83.98456782102585, 86.87478393316269, 86.58853769302368, 84.3111602962017, 82.32919424772263, 81.53163984417915, 78.99006262421608, 76.4290152490139, 72.60831266641617, 68.73048394918442, 70.01388028264046, 74.98602747917175, 79.36320260167122, 73.98232653737068, 80.4012992978096, 71.54531970620155, 50.48842281103134, 44.430742263793945, 75.43064162135124, 82.74262726306915, 79.69803303480148, 78.22670638561249, 77.52857744693756, 77.16267228126526, 75.67872270941734, 70.1852510869503, 69.94631230831146, 65.75797945261002, 72.27329984307289, 78.26088935136795, 82.97114700078964, 78.7311141192913, 82.0246633887291, 74.72808212041855, 69.76370170712471, 74.95920851826668, 77.57270827889442, 77.26405844092369, 81.01706385612488, 76.77413552999496, 80.19930213689804, 79.66844782233238, 79.25905779004097, 75.59257373213768, 84.35035899281502, 74.25920248031616, 81.78995758295059, 87.61678531765938, 85.35592943429947, 80.53137391805649, 51.774703189730644, 12.541969902813435, 0.2727738849353045, 0.424423391232267, 3.0946444300934672, 4.107913970947266, 0.20914790220558643, 0.2453440029057674, 0.6726084393449128, 0.6275606690905988, 17.658577747642994, 26.845589876174927, 51.324248760938644, 88.65843862295151, 51.63209684193134, 13.942986074835062, 37.88504250347614, 57.53980703651905, 69.59001302719116, 19.442525021731853, 0.7372598920483142, 0.4041321238037199, 0.11300860045594163, 0.10154563235118985, 0.03677939166664146, 0.026489161609788425, 0.01651073747780174, 0.08650265517644584, 0.061340409083641134, 0.014138121041469276, 0.06122356164269149, 0.06434155409806408, 0.02641257939103525, 0.037341928473324515, 0.004380001591925975, 0.03986393923696596, 0.05054128465417307, 0.04567583127936814, 0.015864428896747995, 0.05106847296701744, 0.0724091001029592, 0.03719209627888631, 0.03750535681319889, 0.0721064671233762, 0.01824965813284507, 0.06017102554324083, 0.05255182579276152, 0.09068697283510119, 0.009521117372059962, 0.06765707657905295, 0.015007855035946704, 0.02936271659564227, 0.036489968915702775, 0.15495354775339365, 0.12841243209550157, 0.24261137063149363, 0.09830747134401463, 0.2010213999892585, 0.06564209368661977, 0.130768810340669, 0.13483080721925944, 0.11405505094444379, 0.1177239915705286, 0.11544007662450895, 0.10735140909673646, 0.07052239001495764, 0.19478111062198877, 0.18087082891725004, 0.17836849990999326, 0.035662303562276065, 0.22663705749437213, 0.14537199080223218, 0.17350438982248306, 0.17150744854006916, 0.18825436709448695, 0.15490134508581832, 0.14463624043855816, 0.09809720606426708, 0.10460639037773944, 0.13514246471459046, 0.15272946475306526, 0.12084166490240023, 0.19810002471785992, 0.19825654366286471, 0.29729198024142534, 0.1518173355725594, 0.09081421405426227, 0.10625993250869215, 0.16033270832849666, 0.3113808820489794, 0.23844997049309313, 0.6410861620679498, 15.049974024295807, 89.5291619002819, 100.22912174463272, 108.95102173089981, 70.48085242509842, 59.35929760336876, 97.04740047454834, 102.49165713787079, 77.44729220867157, 53.216862604022026, 10.452093444764614, 0.359874443965964, 0.4382189369061962, 0.430307078640908, 0.24481252126861364, 0.7746942364610732, 0.43269528017845005, 0.7940996764227748, 0.389919372391887, 0.6885909161064774, 0.3360577079001814, 3.17507138941437, 25.455715656280518, 65.05637750029564, 85.21908357739449, 88.02553698420525, 94.73438858985901, 80.25510594248772, 91.94956362247467, 82.78089880943298, 84.34748634696007, 90.78845992684364, 91.06817811727524, 96.34270548820496, 94.543836414814, 98.08640152215958, 97.04760566353798, 91.4228966832161, 85.19801750779152, 88.61318305134773, 85.23919969797134, 82.91791185736656, 79.08642545342445, 75.52006602287292, 77.30312034487724, 85.40357127785683, 85.92270702123642, 80.94006478786469, 81.03928506374359, 73.2384480535984, 66.17082729935646, 52.373638451099396, 80.76586693525314, 87.2662465274334, 86.21048837900162, 83.61623078584671, 84.37068030238152, 81.80657029151917, 82.3438310623169, 78.92872631549835, 77.90297135710716, 74.24676954746246, 79.48440089821815, 84.5781871676445, 90.30902445316315, 84.86628770828247, 89.83423992991447, 80.80135703086853, 75.99507093429565, 80.69615587592125, 81.25774294137955, 82.07313358783722, 89.00773867964745, 83.3387316763401, 89.6112222969532, 91.78047269582748, 91.25042393803596, 83.84495571255684, 91.80248871445656, 80.47613248229027, 93.33889827132225, 99.38939720392227, 91.15289077162743, 73.2234388589859, 45.65811060369015, 7.770636230707169, 0.2939443301875144, 0.5344143672846258, 5.415034806355834, 6.660187616944313, 0.8070521720219404, 0.6496182479895651, 0.6980636296793818, 1.1255663400515914, 16.928570419549942, 41.047726795077324, 73.86197179555893, 76.64350613951683, 39.947993606328964, 33.662082105875015, 76.42876446247101, 70.78510969877243, 82.22153842449188, 23.75578947365284, 0.6577496335376054, 0.6710774183738977, 0.21105749270645902, 0.2935459156287834, 0.15110465115867555, 0.13056602590950206, 0.09909968430292793, 0.22977562970481813, 0.13733770785620436, 0.11231060314457864, 0.1572760395356454, 0.16097502229968086, 0.13512569217709824, 0.13176015636418015, 0.1278533722506836, 0.2613970579113811, 0.16559340729145333, 0.20230497408192605, 0.20226918772095814, 0.16011386382160708, 0.22155193582875654, 0.21891526324907318, 0.12520966411102563, 0.221991109137889, 0.10864325071452186, 0.20831642963457853, 0.14355720224557444, 0.2381372739910148, 0.1397333011846058, 0.20543529361020774, 0.10391093121143058, 0.13526135677238926, 0.19037754769669846], [0.11545537228812464, 0.031900791145744734, 0.030329786968650296, 0.04078233214386273, 0.048847837242647074, 0.052136583035462536, 0.12899711087811738, 0.06667643974651583, 0.08381266670767218, 0.026856990407395642, 0.02821131158270873, 0.021328021757653914, 0.0442821707110852, 0.03336985762871336, 0.09213975659804419, 0.09824770619161427, 0.07397089793812484, 0.09325569437351078, 0.012318013141339179, 0.04079738660948351, 0.04667865090596024, 0.03987796953879297, 0.089134503796231, 0.0242089815219515, 0.08113978474284522, 0.018635699234437197, 0.05480508632899728, 0.043114449581480585, 0.044091379386372864, 0.036709269843413495, 0.05337208080163691, 0.08760150871239603, 0.0708264479180798, 0.04443699013791047, 0.045781082662870176, 0.05904638979700394, 0.06807019308325835, 0.15966508712153882, 0.057996410396299325, 0.029442087434290443, 0.2690051106037572, 35.17407797276974, 70.33391430974007, 63.82734104990959, 63.37383158504963, 46.02020837366581, 44.48968090116978, 89.35991898179054, 77.44439676404, 47.60419897735119, 17.841944508254528, 2.6687573455274105, 0.0933069693564903, 0.31671656761318445, 0.1250975701259449, 0.19756952271563932, 1.1091076419688761, 0.3407218091888353, 0.4724023776361719, 0.3716263227397576, 0.08474328278680332, 0.5497919640038162, 2.04325913451612, 13.05253615602851, 37.455049976706505, 65.9150630235672, 75.65752744674683, 64.22194227576256, 68.24559196829796, 79.39999982714653, 82.8953106701374, 82.64899268746376, 69.19141441583633, 76.34590610861778, 74.58630412817001, 81.79097592830658, 78.29402357339859, 84.5735590159893, 83.45877483487129, 86.47404223680496, 82.10556864738464, 84.30734530091286, 71.51546090841293, 76.29544481635094, 73.93669858574867, 73.14938843250275, 73.8595475256443, 73.74062910676003, 71.43352210521698, 68.53338092565536, 10.730560552328825, 58.02353248000145, 90.73786184191704, 78.30482259392738, 80.77542722225189, 77.44901731610298, 76.74926966428757, 77.59495988488197, 77.2016429901123, 77.88014978170395, 74.1160337626934, 76.95908680558205, 82.98507705330849, 87.83369287848473, 82.03087985515594, 79.54015910625458, 76.83475747704506, 73.89509081840515, 77.23258852958679, 77.98444658517838, 84.55671831965446, 82.1551787853241, 82.89747655391693, 88.4426862001419, 86.48357972502708, 92.8872849047184, 89.38858464360237, 86.88607692718506, 74.25046294927597, 52.10876226425171, 32.203655764460564, 13.297193627804518, 3.156771808862686, 0.15990089712431654, 0.11593576447921805, 0.2547746663913131, 0.05393479572376236, 0.14955798571463674, 0.06368681657477282, 0.1706011377973482, 0.08266652352176607, 2.3586291493847966, 19.599175415933132, 44.00120951235294, 77.88085654377937, 47.66205847263336, 17.731784619390965, 29.954769238829613, 63.97511512041092, 59.15861897170544, 51.71668790280819, 7.2744745295494795, 0.18357493303483352, 0.26737850101199, 0.1548634361824952, 0.054816708361613564, 0.06733723319484852, 0.020429032301763073, 0.10585989264654927, 0.1662747433874756, 0.05606982471363153, 0.028801294865843374, 0.04699125463957898, 0.0452675943961367, 0.14080042048590258, 0.009020359721034765, 0.05600695738394279, 0.05260068879579194, 0.14481484569841996, 0.055962320911930874, 0.005047254971941584, 0.04054567980347201, 0.05694078325177543, 0.043309489701641724, 0.10283973751938902, 0.08795137197012082, 0.031113086733967066, 0.06472534092608839, 0.07026752165984362, 0.0600704645330552, 0.08369335904717445, 0.021670836467819754, 0.11770937126129866, 0.07480594766093418, 0.1658973316079937, 0.08706861699465662, 0.1259224969544448, 0.08794124165433459, 0.07829560767277144, 0.022215214776224457, 0.038094325209385715, 0.041434605736867525, 0.03533716495439876, 0.03643000338342972, 0.06109151872806251, 0.05602053497568704, 0.015337761942646466, 0.04126472442294471, 0.07174552360083908, 0.06919285471667536, 0.12958128500031307, 0.019165672456438188, 0.068638351658592, 0.03768806614971254, 0.026626410690369084, 0.09549448674079031, 0.007440303661496728, 0.04931415831379127, 0.029228998282633256, 0.028775724167644512, 0.024751766068220604, 0.03775675191718619, 0.03813542534771841, 0.018282091841683723, 0.05722951209463645, 0.05545002379221842, 0.02231680180557305, 0.11983535718172789, 0.0379970815993147, 0.02785213066090364, 0.03307444574602414, 0.03618175127485301, 0.021189490616961848, 0.29868703975807875, 0.04282196176063735, 0.3893989190692082, 4.453126871958375, 51.55967652797699, 81.85450851917267, 65.71036040782928, 51.36284328997135, 47.96685911715031, 73.13189417123795, 117.91711181402206, 74.95067417621613, 46.65751777589321, 26.29438005387783, 4.998312117531896, 0.16004286997485906, 0.05051802203524858, 0.07278496079379693, 0.5973473621997982, 0.5746852001175284, 1.6896237479522824, 1.040381204802543, 1.348836065735668, 0.593349679838866, 0.6888668169267476, 3.059679181315005, 23.42253975570202, 60.803725495934486, 79.83391374349594, 79.58014816045761, 70.94700381159782, 79.81971010565758, 83.70388448238373, 92.47245356440544, 86.64228960871696, 74.98260766267776, 82.06813305616379, 82.19707533717155, 84.93582397699356, 81.60341039299965, 83.88271048665047, 85.71419700980186, 84.89327386021614, 79.02401760220528, 79.70272958278656, 70.35513237118721, 75.72599217295647, 76.79185017943382, 80.3394766151905, 79.34368684887886, 72.33760759234428, 66.0436861217022, 70.86026206612587, 22.663864865899086, 66.0989959537983, 86.68433055281639, 78.89360100030899, 81.45406320691109, 78.40056985616684, 75.66717132925987, 76.57002568244934, 76.41956895589828, 74.47702199220657, 70.10776564478874, 72.5662337243557, 78.16347017884254, 82.4484546482563, 80.75603306293488, 84.67210292816162, 75.58617487549782, 72.48538166284561, 75.72339311242104, 76.6839511692524, 80.37553668022156, 80.6453450024128, 78.28226700425148, 79.69174057245255, 78.65815803408623, 85.11974170804024, 86.04727953672409, 89.34328347444534, 84.33238595724106, 71.53816848993301, 52.056621462106705, 26.876383423805237, 8.124808575958014, 0.4666124383220449, 0.10283662792062387, 0.2859379519941285, 0.24238376878201962, 0.36342048493679613, 0.24103512318106368, 0.38234958483371884, 0.3373065049527213, 3.6829367000609636, 27.43403200060129, 44.22307200729847, 78.15446466207504, 78.23042258620262, 28.656498603522778, 10.712377578020096, 49.777792543172836, 64.8387935757637, 60.881929099559784, 10.813767537474632, 0.23748921579681337, 0.35566320118959993, 0.25589536875486374, 0.02935512256954098, 0.0593888464209158, 0.004134822438572883, 0.04197834394290112, 0.0844229941139929, 0.037692363184760325, 0.08762185098021291, 0.012232764493091963, 0.01860584077803651, 0.12906960386317223, 0.09750381446792744, 0.04388818677398376, 0.07251666698721237, 0.10858871028176509, 0.02824008093739394, 0.05864735554496292, 0.10807018654304557, 0.02661556049133651, 0.04923041065922007, 0.07250244001625106, 0.04246814285579603, 0.06536759552545846, 0.03790548202232458, 0.03708184653078206, 0.05365900622564368, 0.032791850753710605, 0.055779778558644466, 0.04803551950317342, 0.033655161460046656, 0.10499540192540735, 0.06435414834413677, 0.18700785585679114, 0.10662719170795754, 0.11276946563157253, 0.09247833921108395, 0.11176252708537504, 0.10405694134533405, 0.19638548546936363, 0.21189475402934477, 0.1591905578970909, 0.1360918051796034, 0.2023946848930791, 0.14312527229776606, 0.16292911197524518, 0.1638550599454902, 0.21459425683133304, 0.17404684040229768, 0.207837566267699, 0.1830973313190043, 0.1270168085466139, 0.18434186844388023, 0.10396138983196579, 0.20954428327968344, 0.13810210512019694, 0.11512231125379913, 0.21659940626705065, 0.19158856943249702, 0.19762389245443046, 0.10617226260364987, 0.13250068615889177, 0.1546483172569424, 0.1336339011322707, 0.24707245000172406, 0.11353650494129397, 0.14866251032799482, 0.18872781278332695, 0.0796184413775336, 0.19193723041098565, 0.3822895302437246, 0.11144577103550546, 0.37763676897156984, 4.067457066848874, 59.18615609407425, 97.66643285751343, 81.42630949616432, 75.3067834675312, 67.80415445566177, 64.11351889371872, 106.70126125216484, 94.91844311356544, 64.14715468883514, 31.92538909614086, 3.9496849989518523, 0.29078016872517765, 0.6477957707829773, 0.16370183613616973, 0.9212938137352467, 3.8802282884716988, 5.046744318678975, 1.4628006191924214, 0.6322680227458477, 0.26663884695153683, 0.562475030310452, 1.9492869707755744, 17.3846048489213, 52.455497458577156, 80.49058690667152, 95.14760121703148, 81.5531998872757, 84.43947941064835, 83.92642334103584, 107.55335032939911, 88.55569213628769, 70.00129535794258, 79.9125163257122, 80.87934404611588, 90.29512479901314, 87.0030726492405, 96.2794616818428, 94.76998507976532, 93.9133894443512, 88.03657159209251, 89.73666116595268, 79.4659186899662, 86.84436276555061, 83.82367685437202, 87.36554279923439, 85.35719856619835, 76.57790645956993, 72.34209135174751, 82.10719496011734, 20.863580368459225, 61.8054923415184, 93.65109711885452, 83.6608175933361, 89.29305016994476, 84.23847779631615, 80.48160418868065, 82.56263092160225, 80.55601939558983, 78.65644812583923, 76.3618728518486, 78.19063112139702, 84.43196341395378, 90.21760895848274, 82.74727821350098, 89.2914466559887, 84.69465091824532, 82.20635443925858, 83.52045312523842, 84.77484181523323, 89.3699200451374, 83.32670912146568, 83.65476831793785, 85.28711512684822, 86.4808438718319, 96.9508096575737, 104.0644383430481, 104.36942517757416, 89.23626601696014, 62.86042593419552, 38.15137781202793, 15.784678850322962, 3.715404770337045, 0.2837702870601788, 0.17060570942703635, 0.928459397982806, 1.1407467629760504, 0.38219334790483117, 0.24695351341506466, 0.43395642656832933, 0.4907583020394668, 3.8138684118166566, 34.029503390192986, 64.217519313097, 92.80567288398743, 61.42845757305622, 31.753075942397118, 43.91621567308903, 81.77130818367004, 76.4373292028904, 72.29729175567627, 13.316542189568281, 0.257786123547703, 0.5178033804986626, 0.3524110506987199, 0.18226557673187926, 0.14940652821678668, 0.10263204749207944, 0.21034028119174764, 0.36775878339540213, 0.11039096396416426, 0.14772937836823985, 0.17327876208582893, 0.17832057201303542, 0.2754922828171402, 0.22226475382922217, 0.13816855702316388, 0.30263238586485386, 0.33344852447044104, 0.16088825039332733, 0.11103876240667887, 0.2197918138699606, 0.11443661875091493, 0.1580386853311211, 0.19622359337517992, 0.15117586764972657, 0.2075851321569644, 0.12792901194188744, 0.19369395333342254, 0.10682711887056939, 0.08854156490997411, 0.10902278503635898, 0.17523108544992283, 0.11813550503575243, 0.4546168085653335, 0.23517421970609576], [0.011789749642048264, 0.09725317635457031, 0.057002563335117884, 0.0477305227832403, 0.10714705131249502, 0.021445513011713047, 0.10339629632653669, 0.01659775614825776, 0.055095663119573146, 0.04805055541510228, 0.04010033924714662, 0.03113818987912964, 0.09651111031416804, 0.06707491367706098, 0.006505141927846125, 0.01975372801098274, 0.05288001091685146, 0.06894607577123679, 0.10118047342984937, 0.0811528465419542, 0.011706094755936647, 0.0433827508095419, 0.11102391203166917, 0.08105442291707732, 0.12234570138389245, 0.025695041331346147, 0.011288882524240762, 0.035920519003411755, 0.05121976348164026, 0.04692578979302198, 0.09179493252304383, 0.0307752128719585, 0.1264425940462388, 0.04898918297840282, 0.036598437509383075, 0.02537169129936956, 0.03897886133927386, 0.04680887555878144, 0.14964416390284896, 0.030529202049365267, 0.17096905008656904, 0.9575781261082739, 30.378222316503525, 74.8876279592514, 66.84733539819717, 58.56171280145645, 37.717726081609726, 28.51648561656475, 57.10387542843819, 82.37172156572342, 78.08175936341286, 51.28709815442562, 13.669147118926048, 0.8519217080902308, 0.43642172240652144, 0.09267849643947557, 0.1947233418468386, 1.4998379442840815, 3.4081083722412586, 2.494928785599768, 0.707468125037849, 0.38161776785273105, 0.03432948426052462, 0.1976883108727634, 1.5507086645811796, 12.893433943390846, 34.18477825820446, 61.60695679485798, 74.12877827882767, 66.95639714598656, 70.54198354482651, 73.79667609930038, 87.87075608968735, 91.50489628314972, 85.33059999346733, 86.39654159545898, 87.8660899400711, 86.8303719162941, 89.68531832098961, 88.99692445993423, 89.68727141618729, 84.49592158198357, 82.05659687519073, 78.20924252271652, 81.8134631216526, 76.89295515418053, 76.08821913599968, 67.33354970812798, 64.57071796059608, 31.392161808907986, 0.5727198743261397, 20.87848886847496, 93.48419487476349, 76.48779809474945, 84.7159069776535, 87.66000419855118, 83.53334963321686, 83.50546672940254, 82.9655385017395, 78.87287691235542, 81.76053956151009, 82.60553061962128, 87.24147945642471, 88.52306708693504, 89.35201540589333, 84.08996656537056, 83.23639556765556, 78.82656499743462, 76.18329763412476, 76.42566382884979, 77.76565432548523, 79.93074774742126, 83.01496624946594, 93.03526416420937, 90.50934970378876, 84.921795129776, 59.655548706650734, 28.656185120344162, 4.963045734912157, 0.6899187667295337, 0.4387265065452084, 0.1518746739020571, 0.6984408781863749, 0.32503797265235335, 0.28033102629706264, 0.26400636008474976, 0.6553557026199996, 0.05403793940786272, 0.11984814438619651, 1.0657216887921095, 9.79422239586711, 37.50764675438404, 60.33392630517483, 57.633297219872475, 31.28077458590269, 24.66979432851076, 53.768213018774986, 65.72018668055534, 59.698125422000885, 40.93015730381012, 1.203379633370787, 0.21188060869462788, 0.0706725635973271, 0.056547459826106206, 0.027303214119456243, 0.04944614185660612, 0.13862135616363958, 0.15542696375632659, 0.07663442884222604, 0.08913496392779052, 0.0889439054299146, 0.027390431314415764, 0.11245239787967876, 0.06557825414347462, 0.10406866727862507, 0.03625211800681427, 0.08112365045235492, 0.098853870149469, 0.04664863845391665, 0.047537560676573776, 0.10059132691822015, 0.11953871333389543, 0.02286134895257419, 0.03148758187307976, 0.019122173325740732, 0.020761575688084122, 0.07373341068159789, 0.047435129454243, 0.09043956306413747, 0.029255047666083556, 0.07144438975956291, 0.06467247774708085, 0.08245229517342523, 0.12056448016664945, 0.14727784087881446, 0.033675551967462525, 0.04604799236403778, 0.12837067886721343, 0.05720738125091884, 0.08701631784788333, 0.0421748349617701, 0.08720417026779614, 0.08681984909344465, 0.025383159336342942, 0.056516163458582014, 0.0548265715042362, 0.03715068072779104, 0.019028100541618187, 0.03299705458630342, 0.09553229174343869, 0.017639061697991565, 0.016627816839900333, 0.013908794626331655, 0.04063789907377213, 0.0787208805559203, 0.01776827331923414, 0.04129812106839381, 0.03789576730923727, 0.04017318846308626, 0.02858787731383927, 0.064365518046543, 0.04846650692343246, 0.031478152886847965, 0.0352786169241881, 0.06885036098537967, 0.024307199200848117, 0.03814116585999727, 0.008435486124653835, 0.04524558229604736, 0.056700063942116685, 0.0859264591417741, 0.0431931691855425, 0.11428963640355505, 0.1424659779877402, 0.11848569483845495, 0.1009019157208968, 0.22421991219744086, 2.19632632099092, 46.10349230468273, 85.67914009094238, 76.35385528206825, 55.78601114451885, 22.111431509256363, 38.568530827760696, 85.29562667012215, 96.18214130401611, 74.92362722754478, 48.63232880830765, 15.989424213767052, 1.9366528862155974, 0.6275100249331445, 0.23782713047694415, 0.3765269019640982, 1.2119419989176095, 1.824368555098772, 1.6892254818230867, 1.2629153137095273, 1.1931226775050163, 0.1398360144230537, 0.815340121043846, 2.912029316648841, 24.087376780807972, 58.4886085242033, 76.51063486933708, 75.52530214190483, 72.90570750832558, 80.2041506767273, 80.1381254196167, 80.19803300499916, 85.15230596065521, 77.9716108739376, 84.95247468352318, 84.65957880020142, 87.47590407729149, 85.5555023252964, 88.56040388345718, 87.94876590371132, 87.35804200172424, 82.36740499734879, 80.40316119790077, 80.22503435611725, 76.57647773623466, 71.56573981046677, 72.49431878328323, 77.10327386856079, 53.87949384748936, 1.5170177724212408, 27.914801202714443, 89.06877100467682, 75.51887288689613, 84.62465107440948, 82.12715908885002, 82.99987345933914, 79.20747935771942, 81.07317164540291, 77.36867442727089, 75.66467866301537, 79.55060854554176, 83.87026995420456, 84.82252165675163, 82.94756546616554, 79.11105573177338, 80.70051804184914, 80.21032154560089, 81.40621617436409, 80.20311713218689, 80.05766853690147, 71.59631296992302, 79.60103943943977, 91.30262553691864, 88.64639326930046, 92.03100845217705, 75.34763127565384, 52.2831729054451, 17.22426675260067, 3.083008504472673, 1.3368021114729345, 0.35299054929055274, 0.5414274253416806, 0.42130809277296066, 0.34624050837010145, 0.13174988504033536, 0.5893207679037005, 0.26101565337739885, 0.5227031582035124, 1.962060579098761, 15.502339750528336, 37.91814252734184, 67.57841616868973, 79.846650660038, 51.00797273218632, 18.29900298267603, 28.778209872543812, 60.57910434901714, 66.7174431681633, 50.09160250425339, 3.426925200037658, 0.2065382883301936, 0.1701095688622445, 0.05936110865150113, 0.044890401550219394, 0.059467532628332265, 0.050412648197379895, 0.1115185089292936, 0.09577792778145522, 0.09979213777114637, 0.0770254441886209, 0.0450973123224685, 0.0678762847383041, 0.0170865086329286, 0.11092338812886737, 0.05837230819452088, 0.0697513653722126, 0.10273382562445477, 0.057478680755593814, 0.04844703296839725, 0.06606335155083798, 0.12665754969930276, 0.04906279660644941, 0.050509643187979236, 0.03794463773374446, 0.027375226563890465, 0.058507241774350405, 0.03331987027195282, 0.02566873219620902, 0.019107076186628547, 0.059784481636597775, 0.08109841000987217, 0.06641046144068241, 0.0714869296643883, 0.13491716352291405, 0.03811459697317332, 0.10848290970898233, 0.31434867123607546, 0.11536859296029434, 0.18695710779866204, 0.16237839387031272, 0.16272980079520494, 0.16704222798580304, 0.07904287616838701, 0.1659685480990447, 0.2540830144425854, 0.12534290930489078, 0.16982927452772856, 0.16021645831642672, 0.22228177869692445, 0.09469414726481773, 0.2745773334754631, 0.16272899927571416, 0.15330087393522263, 0.1679306974983774, 0.3334129904396832, 0.09849857437075116, 0.09176443025353365, 0.2730168047128245, 0.20410573604749516, 0.16783666738774627, 0.10197672367212363, 0.1238993281731382, 0.08885728937457316, 0.2466786961304024, 0.11172143436851911, 0.10839344380656257, 0.1698366811615415, 0.14201533107552677, 0.08476448594592512, 0.1644381060032174, 0.12138945152400993, 0.10241470212349668, 0.1979051812668331, 0.28458053420763463, 0.17214373627211899, 0.19640731945401058, 1.8941198685206473, 47.017928436398506, 104.66108232736588, 89.2547482252121, 75.51218524575233, 51.56904682517052, 44.58074301481247, 74.4768775999546, 93.19069102406502, 94.945497661829, 68.4843635559082, 23.75907439738512, 1.7643839051015675, 1.0998114407993853, 0.3482725383946672, 1.227539568208158, 5.095715615898371, 11.276964582502842, 9.28671782836318, 2.2111350763589144, 0.8207833883352578, 0.08473372392472811, 0.6979666161350906, 2.2302874736487865, 16.831415332853794, 51.397919207811356, 83.36187243461609, 91.76460474729538, 84.24005851149559, 87.3316790163517, 78.44587102532387, 98.62673252820969, 101.66379556059837, 96.72984391450882, 96.5213643014431, 100.13161137700081, 95.22122606635094, 94.13805618882179, 96.29411369562149, 97.62999281287193, 93.04081186652184, 90.59475392103195, 90.46727076172829, 90.63918873667717, 88.47598001360893, 80.77991098165512, 78.70944008231163, 91.02748230099678, 49.888814985752106, 0.7742112467531115, 22.335228100419044, 95.09649395942688, 83.51439625024796, 88.23942750692368, 86.52314320206642, 92.26460471749306, 90.37463173270226, 91.96286290884018, 83.9493741095066, 88.5818499326706, 86.03721007704735, 92.88717851042747, 90.5471196770668, 89.83936965465546, 86.3468174636364, 85.77123194932938, 85.42792037129402, 85.49669668078423, 83.03578913211823, 81.05496302247047, 78.74399542808533, 87.41582170128822, 101.56131505966187, 99.07117947936058, 96.15181893110275, 68.19051012396812, 36.713656559586525, 7.272971710190177, 0.7390339812263846, 0.5633225629571825, 0.3752613620599732, 0.8266893995460123, 1.2313400767743587, 1.646832819096744, 0.9621046332176775, 1.6115545621141791, 0.3154829697450623, 0.6241754069924355, 1.5649322513490915, 16.842254251241684, 56.265127435326576, 76.17778033018112, 67.41985827684402, 43.42330612242222, 36.18781037628651, 68.73607724905014, 78.06693255901337, 77.79449477791786, 57.37146086990833, 4.532171655446291, 0.23465146572561935, 0.2269963757134974, 0.16444034728920087, 0.35897641559131444, 0.099619016982615, 0.1727170601952821, 0.19632731593446806, 0.19644362531835213, 0.2962345682317391, 0.18726147740380839, 0.10715839875047095, 0.12141118160798214, 0.18238104006741196, 0.19846222246997058, 0.13174041523598135, 0.21554681821726263, 0.23249889607541263, 0.14210576919140294, 0.12272577747353353, 0.26723051676526666, 0.15966630424372852, 0.08217737398808822, 0.267140093492344, 0.20424905960680917, 0.13675700698513538, 0.24263788014650345, 0.11916543531697243, 0.19093034381512552, 0.12501349963713437, 0.1473171153338626, 0.17414493748219684, 0.17296017293119803, 0.19019397004740313, 0.31190409616101533, 0.09312351045082323], [0.08765975246205926, 0.0436575421190355, 0.002036896194113069, 0.02195461518567754, 0.056762972089927644, 0.0364927297050599, 0.05350495863240212, 0.06927748181624338, 0.058016860275529325, 0.021135668212082237, 0.07905067614046857, 0.040989840344991535, 0.06812606196035631, 0.04061787221871782, 0.035420497006271034, 0.01412807236192748, 0.0390996495843865, 0.06507199810585007, 0.03225282518542372, 0.0475367814215133, 0.07449878015904687, 0.007785076250002021, 0.03672074344649445, 0.11000268714269623, 0.033070126446546055, 0.02919661652413197, 0.12867954588728026, 0.08063933230005205, 0.057343817679793574, 0.0009750359367899364, 0.018291760170541238, 0.04573450918542221, 0.02398516833636677, 0.02857884537661448, 0.06328146293526515, 0.04941106053593103, 0.0643472166848369, 0.06325214068056084, 0.0466975608287612, 0.08237903035478666, 0.15481709648156539, 0.10258636088110507, 0.6994645076338202, 9.59216633811593, 53.61278995871544, 77.49305695295334, 80.23933678865433, 66.83383852243423, 31.521482169628143, 38.76570224761963, 56.22119039297104, 84.0278322994709, 83.8685904443264, 40.58532580733299, 9.700554572045803, 0.8564093266613781, 0.37730945216026157, 0.18693341844482347, 0.2828535862499848, 2.1495166327804327, 2.7220955584198236, 1.7739000194706023, 0.9357620717491955, 0.07946947749587707, 0.07526990870246664, 0.11960210016695783, 1.351315313950181, 7.597132790833712, 29.23060979694128, 58.65988813340664, 79.91164237260818, 81.7879892885685, 79.78805020451546, 75.27358084917068, 69.08065035939217, 71.40160381793976, 76.87081754207611, 86.99554145336151, 88.20033520460129, 96.12841978669167, 103.12716543674469, 98.14755544066429, 97.05315336585045, 89.55235585570335, 84.5838488638401, 73.06267708539963, 71.13276824355125, 47.95743562281132, 8.770531676709652, 0.23779517359798774, 0.3323979105334729, 3.820849349722266, 73.6513338983059, 91.94670617580414, 74.6364614367485, 78.66252779960632, 87.40303158760071, 86.53968751430511, 89.43788319826126, 86.53987750411034, 84.88160088658333, 84.44344639778137, 86.35775327682495, 89.23473849892616, 89.76989418268204, 88.40644374489784, 83.64193260669708, 78.69881585240364, 72.25344210863113, 71.3655437529087, 64.10452857613564, 51.438204646110535, 43.886174485087395, 29.675280936062336, 14.296206571161747, 3.3981320075690746, 0.2787579403957352, 0.16648359858663753, 0.28016505239065737, 0.1351036800770089, 0.30225789814721793, 0.5680235638283193, 1.0046687023714185, 1.0524115967564285, 0.731270641554147, 0.08521312163793482, 0.22324670426314697, 0.3024581592762843, 6.732650203630328, 19.59901202470064, 53.93276318907738, 64.50071811676025, 31.737783662974834, 17.84235868602991, 25.980366803705692, 62.81045861542225, 67.35227510333061, 49.8960991948843, 15.033150427043438, 0.28334554110188037, 0.025206466962117702, 0.0212352477319655, 0.05327640312316362, 0.03909724131517578, 0.12396575781167485, 0.0982984245638363, 0.04151057197304908, 0.10506849605008028, 0.0212436358560808, 0.10415602548164316, 0.039463416978833266, 0.14307777484646067, 0.07618080591782928, 0.06905698974151164, 0.11287508066743612, 0.046421886363532394, 0.03304406964161899, 0.026262582068738993, 0.04872363882896025, 0.035982844565296546, 0.025487377279205248, 0.01641776121687144, 0.09126232282142155, 0.04425020269991364, 0.11331014989991672, 0.041779348175623454, 0.10017721593612805, 0.051522949361242354, 0.04780837407452054, 0.11685975317959674, 0.0714782539580483, 0.02146308521332685, 0.04644046974135563, 0.02958330329420278, 0.23657255951547995, 0.07848253240808845, 0.01941943872225238, 0.03897945505741518, 0.0361489112401614, 0.05378804344218224, 0.06083953732741065, 0.11111308107501827, 0.03303336045064498, 0.060788666814914905, 0.07234241071273573, 0.07388573649222963, 0.08014582635951228, 0.018700210421229713, 0.046135855227475986, 0.07627987521118484, 0.019914293516194448, 0.006001706979077426, 0.04237493281834759, 0.0516612188948784, 0.03809274443483446, 0.01603405788046075, 0.055263484973693267, 0.02436599399516126, 0.006284108085310436, 0.00908609916223213, 0.07433955237502232, 0.0635314331157133, 0.04050198956974782, 0.09352443346870132, 0.06746353930793703, 0.0761786982184276, 0.06900321372086182, 0.026483528708922677, 0.1217996068589855, 0.07345482328673825, 0.006352197815431282, 0.06477669754531235, 0.017332591814920306, 0.012854067335865693, 0.04300096406950615, 0.0691959643154405, 0.0872094024089165, 0.10997193254297599, 0.3623603715095669, 19.98936887830496, 66.46520510315895, 86.14278361201286, 76.29530802369118, 39.960076957941055, 24.025679491460323, 52.28829503059387, 85.42216747999191, 107.93149843811989, 89.21934932470322, 41.076772436499596, 12.62851595878601, 1.1770764947868884, 0.3799048316432163, 0.10185528604779392, 0.20597038208507001, 0.4185666883131489, 1.485546911135316, 1.2163205514661968, 1.7305879248306155, 1.87453156337142, 0.16988839401165023, 0.35887126810848713, 2.911253208294511, 22.689407095313072, 56.59255966544151, 79.9962866306305, 80.36498084664345, 74.14348348975182, 84.65738251805305, 89.52690482139587, 80.12129232287407, 80.29086202383041, 82.83341959118843, 87.89058342576027, 86.0692347586155, 86.06151357293129, 85.62587454915047, 85.87473079562187, 82.79430449008942, 79.49213728308678, 80.5620002746582, 74.22337040305138, 79.19608756899834, 63.75196069478989, 27.21581730991602, 1.929581940639764, 0.625733679626137, 6.420391984283924, 76.65818855166435, 82.52868354320526, 75.58443456888199, 81.95106133818626, 87.52998277544975, 88.2628646492958, 87.57077738642693, 85.76608702540398, 83.02014917135239, 84.69793394207954, 84.35713782906532, 87.03151792287827, 84.26763743162155, 83.66126596927643, 81.0451291501522, 77.73148655891418, 74.32728722691536, 74.97306257486343, 75.3711824119091, 79.05922651290894, 69.52314421534538, 53.77413310110569, 33.76735545694828, 14.357765167951584, 3.673739768564701, 1.2598120677284896, 0.1380029393476434, 0.44101998035330325, 0.21069850103231147, 0.8741791325155646, 1.5121984435245395, 0.7222542003728449, 0.45450308185536414, 0.0869877080549486, 0.11853020885610022, 0.45184729155153036, 11.103422194719315, 26.034935675561428, 52.27346822619438, 89.47980254888535, 55.30231609940529, 21.129205115139484, 12.593825720250607, 46.050055772066116, 72.06034407019615, 56.750285401940346, 21.425289027392864, 0.38045419903937727, 0.03168399867718108, 0.11228946677874774, 0.12104760346119292, 0.09138502209680155, 0.0460479218600085, 0.07686704018851742, 0.05325189369614236, 0.03855826398648787, 0.04890762465947773, 0.0885121758619789, 0.037738851315225475, 0.11770797602366656, 0.0528741145535605, 0.06280857385718264, 0.11614930263021961, 0.07778702871291898, 0.018794958559738006, 0.02868999868951505, 0.07571829948574305, 0.03614622837631032, 0.013937023140897509, 0.07248212743434124, 0.041157432133331895, 0.06214134598849341, 0.03598186121962499, 0.07271076086908579, 0.12083773894119076, 0.03789440917898901, 0.05742524612287525, 0.08527477184543386, 0.046538422102457844, 0.06769859232008457, 0.10183570077060722, 0.055986581719480455, 0.10153694922337309, 0.048748894114396535, 0.09378094197018072, 0.19811520905932412, 0.16081580193713307, 0.1639014738611877, 0.0943653164722491, 0.15067784202983603, 0.15468187717488036, 0.16084716509794816, 0.16260663396678865, 0.1805780071299523, 0.15608800953486934, 0.11829276612843387, 0.12893002072814852, 0.14609794481657445, 0.11594873722060584, 0.1388778127147816, 0.09352847075206228, 0.1366788291488774, 0.12077093080733903, 0.10476306517375633, 0.22345426812535152, 0.09637917130021378, 0.09108167665544897, 0.18566829414339736, 0.1238880401069764, 0.1292852422920987, 0.20378217450343072, 0.16006363526685163, 0.23000535409664735, 0.09163790891761892, 0.13025433872826397, 0.17285385285504162, 0.20815036667045206, 0.19921305327443406, 0.23861088295234367, 0.15924612991511822, 0.12110786585253663, 0.13383857061853632, 0.19221238908357918, 0.1924357606912963, 0.23969553178176284, 0.196126282971818, 0.6263558962382376, 18.026073127985, 76.64205461740494, 103.86054128408432, 95.45497432351112, 80.1509839296341, 46.3812156021595, 55.190123319625854, 71.27027526497841, 98.94026130437851, 104.25708800554276, 63.238821029663086, 18.67030195891857, 1.5143973380327225, 0.46136791817843914, 0.33776099618989974, 0.8368787309154868, 6.441530724987388, 15.943007804453373, 5.601519299671054, 2.6017047185450792, 1.006299052387476, 0.1526198792271316, 0.4681962705217302, 1.607217094860971, 13.809768073260784, 43.340193182229996, 83.06478917598724, 92.66636475920677, 105.03657817840576, 89.53971773386002, 89.27057817578316, 80.78506350517273, 85.24004325270653, 88.16785454750061, 100.0157555937767, 93.24148669838905, 97.9719440639019, 99.5002068579197, 100.78361839056015, 95.15258654952049, 98.90657231211662, 94.58031445741653, 88.18864703178406, 91.81579560041428, 72.77978226542473, 16.632195822894573, 0.4415763833094388, 0.6016544310841709, 4.146354608237743, 77.13485017418861, 89.56266850233078, 79.99322399497032, 82.67556086182594, 92.083620429039, 93.01435008645058, 97.41985648870468, 96.67945101857185, 91.66378855705261, 93.08428153395653, 91.7520198225975, 91.81473165750504, 89.72313389182091, 90.50178050994873, 87.95822739601135, 83.54182317852974, 82.62843579053879, 86.32642015814781, 83.89101684093475, 82.51832529902458, 66.09338745474815, 41.386148035526276, 18.57461169362068, 4.420091919600964, 0.6093341752421111, 0.3549432585714385, 0.40326847170945257, 0.5616144358646125, 0.418949814629741, 1.2659676186740398, 5.096725411713123, 4.738120604306459, 1.5570191759616137, 0.4619058861862868, 0.5150545248761773, 0.2582284138770774, 9.33351231738925, 30.98295796662569, 70.46381413936615, 77.0255908370018, 41.84077464044094, 28.460442423820496, 39.27445314824581, 74.75118488073349, 81.68376848101616, 67.7162803709507, 25.72999443858862, 0.6230748316738755, 0.33936994266696274, 0.28184307797346264, 0.25355564430356026, 0.19675373914651573, 0.2081263656145893, 0.13598040881333873, 0.15154685243032873, 0.1403821905842051, 0.11716887995135039, 0.1361848704982549, 0.19403385696932673, 0.1882794962148182, 0.11919440876226872, 0.18520071142120287, 0.21217389061348513, 0.19106664665741846, 0.11147855911985971, 0.16131943819345906, 0.12888118741102517, 0.1282368102692999, 0.13746740558417514, 0.1307551548234187, 0.18970795237692073, 0.0781122971966397, 0.19516156520694494, 0.13261475425679237, 0.16663603571942076, 0.14177857112372294, 0.16829391941428185, 0.11725074626156129, 0.1639353157952428, 0.09868241919321008, 0.15485337265999988, 0.13822061126120389, 0.19192998704966158, 0.16411648888606578], [0.10099143357365392, 0.01864886307885172, 0.0996397971175611, 0.034597147241584025, 0.05157305917236954, 0.039674914223724045, 0.08233922155341133, 0.050611328551894985, 0.024963061077869497, 0.0702920719049871, 0.1862679494661279, 0.08985681386548094, 0.029445972577377688, 0.030370120839506853, 0.08591491132392548, 0.0949691649293527, 0.0699037208687514, 0.10985922999680042, 0.02836098978150403, 0.10019342444138601, 0.06702333441353403, 0.030758084103581496, 0.06636629623244517, 0.09116854504100047, 0.07328248175326735, 0.08271331593277864, 0.024949114267656114, 0.017168254344142042, 0.06813158353907056, 0.06416657051886432, 0.040267144358949736, 0.05021951910748612, 0.09367989856400527, 0.03886687867634464, 0.006014486762069282, 0.09224649227689952, 0.16679630993166938, 0.03028253257070901, 0.024001755336939823, 0.056731838994892314, 0.03326676960568875, 0.12364686437649652, 0.06577291205758229, 0.8491868048440665, 0.27488428575452417, 25.222085192799568, 66.57035306096077, 81.62921860814095, 74.31719496846199, 54.38524670898914, 29.9906013160944, 28.923707865178585, 53.297125697135925, 79.76615577936172, 77.87688195705414, 51.069651022553444, 12.455986216664314, 1.0290373885072768, 0.2932869060896337, 0.27540518436580896, 0.1840742351487279, 1.5419721021316946, 1.3166586798615754, 2.8954429691657424, 0.584098007529974, 0.2851575391832739, 0.0972982395614963, 0.06530144048156217, 0.4107837856281549, 2.1467691427096725, 13.436417207121849, 41.38287641108036, 69.66489180922508, 76.49317100644112, 76.17791712284088, 72.24190592765808, 67.59277179837227, 71.42342984676361, 74.92839977145195, 87.12918788194656, 93.05867090821266, 98.63728076219559, 88.24867621064186, 74.65011790394783, 49.928807839751244, 44.98259425163269, 19.164501540362835, 1.0260658292099833, 0.3985488280886784, 0.36287165188696235, 1.2038566265255213, 0.4571094154380262, 23.23574747890234, 97.82083377242088, 101.60348519682884, 93.43672022223473, 93.02704140543938, 95.9199021756649, 100.68616881966591, 101.4342574775219, 100.36808788776398, 98.95746678113937, 99.54817548394203, 101.88216224312782, 98.03230002522469, 93.88143315911293, 85.20529791712761, 72.94867560267448, 42.41505682468414, 19.716089442372322, 12.152636144310236, 4.163436591625214, 0.43760482454672456, 0.2712705312296748, 0.26403082127217203, 0.10187479711021297, 0.04187381244264543, 0.19082855083979666, 0.036994120964664035, 0.7444302260410041, 0.15825153328478336, 0.33404604240786284, 0.8705482492223382, 0.46072637604083866, 0.1483805090538226, 0.1013986425823532, 2.4349701404571533, 23.533197417855263, 49.119781851768494, 65.0315648317337, 55.16634799540043, 21.059619449079037, 27.77895849198103, 55.72859242558479, 70.84543526172638, 58.49562294781208, 32.00304172933102, 2.9234788147732615, 0.3655640152283013, 0.03203427382686641, 0.09210407413775101, 0.038532515172846615, 0.056666222008061595, 0.03903910888766404, 0.1111023644625675, 0.037721856133430265, 0.07744690985418856, 0.04177132184850052, 0.069971137563698, 0.036842262707068585, 0.01930664155224804, 0.058654064559959807, 0.07086681333021261, 0.046189709173631854, 0.05099485562823247, 0.04035294034110848, 0.06406898552086204, 0.02240610629087314, 0.04679266334278509, 0.05578235010034405, 0.05859311939275358, 0.031172940944088623, 0.0400925318535883, 0.04719233213108964, 0.07154806036851369, 0.027440086560091004, 0.04343221866292879, 0.167051000171341, 0.1442450692411512, 0.06902927052578889, 0.05729765609430615, 0.18130056210793555, 0.1482332669547759, 0.06106666049163323, 0.05896719521842897, 0.08342827874002978, 0.0529881381226005, 0.06255924934521317, 0.13001615385292098, 0.03306438222352881, 0.0472565241943812, 0.005288454358378658, 0.017259859487239737, 0.058484992187004536, 0.07497912039980292, 0.043263187108095735, 0.10754146569524892, 0.04231606195389759, 0.0344231952476548, 0.014825990820099832, 0.11752762671676464, 0.09078224975382909, 0.06867579300887883, 0.08348758376087062, 0.0505854535731487, 0.05679654685081914, 0.02727029986999696, 0.031501437770202756, 0.027394997377996333, 0.05527287314180285, 0.033341585512971506, 0.10322912756237201, 0.05366981560655404, 0.05344895245798398, 0.05113251660077367, 0.010537861544435145, 0.08487963015795685, 0.023046919268381316, 0.04225748052704148, 0.042881927292910405, 0.02950855232484173, 0.058489467337494716, 0.09818309481488541, 0.05226075547398068, 0.07301513047423214, 0.01449843652153504, 0.04495971072174143, 0.042112249648198485, 0.06483739038230851, 0.9909632534254342, 2.2169373650103807, 33.82061719894409, 77.79005661606789, 91.63335219025612, 64.67138215899467, 29.894572868943214, 20.01991543918848, 42.363968566060066, 92.15625733137131, 104.19214189052582, 79.35448586940765, 49.25240233540535, 11.756161618977785, 0.7916180533356965, 0.43545897875446826, 0.2081971219740808, 0.4373085591942072, 0.6016981287393719, 1.6354391304776073, 1.7568329977802932, 3.2071791915223002, 2.1492758207023144, 0.2618469775188714, 0.4263231111690402, 1.2034506420604885, 10.17381727695465, 38.274958580732346, 74.99320149421692, 83.22359785437584, 80.54268211126328, 79.55311641097069, 80.73828801512718, 83.55397492647171, 87.57922813296318, 94.18500646948814, 99.9258904159069, 103.75892713665962, 103.49318459630013, 96.62303924560547, 91.25695198774338, 80.32293990254402, 69.82496961951256, 41.057142689824104, 5.565233621746302, 0.28325407882221043, 0.5106581014115363, 1.6707445797510445, 0.9869927039835602, 37.910504937171936, 99.97748404741287, 83.0398853123188, 76.51353791356087, 79.70969080924988, 81.80864498019218, 85.11555433273315, 85.15740528702736, 85.30521735548973, 83.57037484645844, 88.51533830165863, 84.0352874994278, 81.93442583084106, 81.68702110648155, 80.04398927092552, 82.00413689017296, 73.41515377163887, 61.067815124988556, 37.604712545871735, 13.84826760739088, 3.9357390347868204, 1.4799898280762136, 0.7437909697182477, 0.08931110525736585, 0.17144726036349311, 0.8918275823816657, 0.23382886924082413, 0.3728422278072685, 1.2349972617812455, 1.8683709064498544, 0.2910537243587896, 0.2600861282553524, 0.1282452410669066, 0.11963179349550046, 3.3103890158236027, 24.574018567800522, 43.58543582260609, 63.00957553088665, 78.95713359117508, 38.12664493918419, 14.346892051398754, 34.286605194211006, 66.55302599072456, 67.8071790933609, 37.70633429288864, 5.620048055425286, 0.31599962327163666, 0.09266937544452958, 0.007120539594325237, 0.09363151795696467, 0.11787602794356644, 0.09742631198605523, 0.0380631661391817, 0.04401088233862538, 0.020568101499520708, 0.0629944002139382, 0.10401768173323944, 0.109009500592947, 0.0788089215348009, 0.01982799843972316, 0.07105430209776387, 0.025717580356285907, 0.028608260399778374, 0.029240852236398496, 0.030028191140445415, 0.03939913214708213, 0.05490995921718422, 0.026803450018633157, 0.0766088766977191, 0.03637207133579068, 0.0182841327477945, 0.05209331582591403, 0.01670584810199216, 0.01906664954731241, 0.06260015652514994, 0.09100055991439149, 0.07016909061348997, 0.04144668419030495, 0.02997317016706802, 0.0028210772597958567, 0.015903343410172965, 0.060596265029744245, 0.06710079236654565, 0.06973309369641356, 0.11386565485736355, 0.19328289257828146, 0.40164607751648873, 0.08728298635105602, 0.08135379044688307, 0.10054061596747488, 0.17909433518070728, 0.17099912191042677, 0.130330067477189, 0.24717933411011472, 0.33346511889249086, 0.09613486370653845, 0.11944854981265962, 0.06913727527717128, 0.1671252743108198, 0.16087042400613427, 0.14751918730325997, 0.24024023849051446, 0.24357113084988669, 0.2418350099469535, 0.17707791994325817, 0.1422173882019706, 0.13768086209893227, 0.2347371244104579, 0.18813746399246156, 0.24459382519125938, 0.13543699344154447, 0.145442895591259, 0.12296528337174095, 0.14155589713482186, 0.15928823937429115, 0.09089509330806322, 0.1739960626582615, 0.1907072839094326, 0.15677016199333593, 0.11862596817081794, 0.4021397838369012, 0.16043853858718649, 0.1487045455724001, 0.10006390482885763, 0.14102165470831096, 0.20321671734564006, 0.16594007931416854, 0.8169235079549253, 2.376264240592718, 35.036924332380295, 91.05171740055084, 104.0776464343071, 87.97742396593094, 67.87722453474998, 42.526561841368675, 48.4797327965498, 75.96959710121155, 94.96324270963669, 99.42033514380455, 70.50147771835327, 19.79981604963541, 0.8678952197078615, 0.909364769468084, 0.5738018662668765, 1.1074480810202658, 8.730973899364471, 14.515977278351784, 11.766020189970732, 3.583392729051411, 1.7587554571218789, 0.28765436145476997, 0.3177135391160846, 0.4365187359508127, 4.170577358454466, 23.58168851584196, 58.085887134075165, 85.19056990742683, 95.01826375722885, 102.1864803135395, 97.92981952428818, 101.62073627114296, 107.09973067045212, 107.22278326749802, 115.00859588384628, 118.4350012242794, 118.56423228979111, 111.315186470747, 103.37961629033089, 85.83184629678726, 71.63444012403488, 28.86835053563118, 1.2920274515636265, 0.2635451598325744, 1.057272960897535, 2.540097199380398, 0.5651217070408165, 26.479713208973408, 102.2874864935875, 100.56938588619232, 90.13166517019272, 86.69036462903023, 90.08117347955704, 96.34066879749298, 96.97933092713356, 97.36660614609718, 98.43801185488701, 99.90225568413734, 94.5057624578476, 87.22061097621918, 87.39911779761314, 86.95416167378426, 88.5716512799263, 77.96378329396248, 58.58419619500637, 29.986269548535347, 7.232610750943422, 0.8337977493647486, 0.3397244220832363, 0.21456384361954406, 0.18897340429248288, 0.1682221982628107, 0.8249463024549186, 0.33203324885107577, 1.9406784139573574, 1.061866795644164, 4.564696010202169, 2.71414733491838, 1.3965508178807795, 0.47716750006657094, 0.1292632450349629, 5.063876649364829, 34.98638704419136, 63.572249338030815, 76.0136291384697, 67.6771728694439, 36.29330791532993, 42.31055103242397, 72.78274610638618, 84.90132182836533, 75.53794786334038, 45.85179761052132, 6.356022013351321, 0.4917803581338376, 0.39376170840114355, 0.1173619125620462, 0.3042515442939475, 0.24659055867232382, 0.22834954841528088, 0.23146683583036065, 0.11993438194622286, 0.21234945306787267, 0.11715828950400464, 0.20239366072928533, 0.22587760293390602, 0.10573321545962244, 0.1271456156973727, 0.23566492774989456, 0.12728766276268288, 0.17015111428918317, 0.10526446014409885, 0.13960896176286042, 0.11297933757305145, 0.1284424148616381, 0.08547285106033087, 0.1199551323952619, 0.17748997517628595, 0.25520766503177583, 0.12756651733070612, 0.08898822648916394, 0.16551465058000758, 0.17635523137869313, 0.31615452433470637, 0.3026641794713214, 0.09230833544279449, 0.1913811539998278, 0.2715073653962463, 0.21666300832293928, 0.13383880810579285, 0.16639136447338387, 0.41203379980288446], [0.1012696795805823, 0.050968602154171094, 0.004289693815735518, 0.028462430236686487, 0.014982392876845552, 0.06133420843980275, 0.02259745422634296, 0.05615710870188195, 0.035723044638871215, 0.18614111642818898, 0.03801425118581392, 0.0779203035926912, 0.005071614577900618, 0.05512514493602794, 0.09251581766875461, 0.07512690426665358, 0.009786677292140666, 0.044146313157398254, 0.05300475480908062, 0.03011214288562769, 0.011984222019236768, 0.06711632551741786, 0.10759486322058365, 0.013333318474906264, 0.015539520354650449, 0.04888610608759336, 0.044314550614217296, 0.02470060240739258, 0.026774216821650043, 0.06556288426509127, 0.020786829118151218, 0.03288336498371791, 0.0625506330106873, 0.020386731739563402, 0.11870887348777615, 0.0362528861296596, 0.03788459798670374, 0.11971003070357256, 0.054152630909811705, 0.03578741481760517, 0.128175790887326, 0.03952908591600135, 0.44811687141191214, 0.037051488980068825, 0.09959113449440338, 0.3622557583730668, 2.7263779286295176, 30.57155404239893, 60.62362655997276, 85.53769648075104, 81.6840648651123, 67.17105522751808, 28.917789682745934, 33.49036172032356, 57.91832372546196, 78.86134833097458, 74.40187722444534, 44.433459118008614, 13.217556551098824, 1.0746180801652372, 0.18574181129224598, 0.08033512596739456, 0.23162271652836353, 2.181666945107281, 2.5708541739732027, 1.2259845016524196, 6.281318971887231, 28.05729165673256, 4.177218452095985, 0.3253727999981493, 0.05748573486926034, 0.49572825722862035, 1.618645575363189, 3.47874135710299, 6.617737244814634, 9.607251528650522, 17.577510997653008, 20.357232838869095, 11.342443618923426, 18.086632378399372, 27.14969325810671, 37.41530790925026, 33.382367715239525, 20.37738125771284, 10.089030526578426, 1.4762197178788483, 0.6597336020786315, 0.3489079949213192, 0.4049166332697496, 0.6720897078048438, 0.3993074514437467, 0.06424641818739474, 0.5287950031924993, 13.750702142715454, 63.37544649839401, 98.16614404320717, 99.58746537566185, 99.48071390390396, 95.65400764346123, 97.68965721130371, 94.54412519931793, 97.31166869401932, 96.96580365300179, 104.3167220056057, 111.11695110797882, 104.08643156290054, 65.7129518687725, 25.976268723607063, 3.2437536539509892, 1.1343951663002372, 0.036814009145018645, 0.6799342681188136, 0.18107014009729028, 0.3062499698717147, 0.4779301310190931, 0.5524625675752759, 0.19331136136315763, 0.08857338078087196, 0.5230767256580293, 0.9470016311388463, 1.4426734554581344, 1.049280920997262, 0.3089212265331298, 0.23202398093417287, 1.5082084201276302, 28.312940038740635, 61.545837074518204, 69.4348293542862, 60.287720784544945, 38.546355217695236, 23.599414564669132, 51.287470534443855, 73.77347454428673, 68.38192105293274, 42.56732605397701, 11.348928920924664, 0.0627095194067806, 0.4525615047896281, 0.202153516584076, 0.05037153321609367, 0.04111034286324866, 0.0563189488457283, 0.028595961157407146, 0.05702039343304932, 0.04222430652589537, 0.07862072030548006, 0.025668665402918123, 0.0182507361023454, 0.04125748106162064, 0.05351421692466829, 0.06033318852132652, 0.08131047870847397, 0.08691986091434956, 0.034656062634894624, 0.09771727098268457, 0.015330495389207499, 0.017766315904736985, 0.015557297574559925, 0.03782418345508631, 0.023674228868912905, 0.03849230932246428, 0.03365158430824522, 0.009388298913108883, 0.07676452732994221, 0.01587499151355587, 0.09507678376394324, 0.02317804377526045, 0.1053072969079949, 0.022956926441111136, 0.06462456469307654, 0.03735563594091218, 0.07509232760639861, 0.02296706417837413, 0.037915682842140086, 0.05959222085948568, 0.02359197478654096, 0.08426255662925541, 0.08068925657426007, 0.050761316597345285, 0.08767542662099004, 0.06163301564811263, 0.007672330102650449, 0.04215186549117789, 0.0499830226181075, 0.05699030305549968, 0.09129115525865927, 0.045723736911895685, 0.03413493024709169, 0.08421318896580487, 0.05237430035776924, 0.017087089363485575, 0.05648153855872806, 0.03451672069786582, 0.042745561368064955, 0.05312188055540901, 0.031043220951687545, 0.019884553803422023, 0.0943061376165133, 0.04077942663570866, 0.013636410658364184, 0.024341933567484375, 0.08749055763473734, 0.042831216342165135, 0.022137489650049247, 0.005996088457322912, 0.004345511206338415, 0.023273344813787844, 0.05121719936141744, 0.04508713376708329, 0.03720551430888008, 0.08115379649098031, 0.009375068275403464, 0.06447727806516923, 0.09025798921356909, 0.05709788849344477, 0.10056403072667308, 0.04530908787273802, 0.07426204247167334, 0.29355963051784784, 0.13988556020194665, 0.5061292788013816, 0.39661455375608057, 6.777739534154534, 38.991740718483925, 76.72899395227432, 95.93510895967484, 69.62129294872284, 40.97996883094311, 18.99806097149849, 46.85615971684456, 86.89619958400726, 103.01191002130508, 74.43567261099815, 38.547590151429176, 9.045826904475689, 0.10345971284550615, 0.41905825724825263, 0.2543702255934477, 0.26266497268807143, 0.5968522606417537, 2.591777751222253, 1.354712094180286, 9.879856500774622, 17.668088637292385, 4.631545823067427, 0.7040810817852616, 0.12387044378556311, 2.462292336858809, 11.408248487859964, 18.17817896604538, 25.66239796578884, 29.71457652747631, 42.64141067862511, 48.5669457167387, 37.02142484486103, 47.12060272693634, 56.18703402578831, 65.34553438425064, 60.66230468451977, 44.86214451491833, 25.540008433163166, 7.47204065322876, 1.9621347938664258, 0.31052978709340096, 0.1747020974289626, 2.121700937859714, 3.0624556448310614, 0.1795788388699293, 1.86872405000031, 34.71814043819904, 88.32383617758751, 100.50354301929474, 101.2535771727562, 100.07104262709618, 98.49042624235153, 102.0720000565052, 102.54067450761795, 103.60887318849564, 101.49847403168678, 101.15906864404678, 107.98597991466522, 103.72244909405708, 87.9517449438572, 63.38037483394146, 24.73979987204075, 3.3972314558923244, 2.056642728857696, 1.5626000077463686, 0.06159376345749479, 0.4048766760388389, 0.2137735899304971, 1.0423968778923154, 1.4539866358973086, 0.09873195012914948, 2.296558767557144, 0.8696270955260843, 0.5842951219528913, 1.088741566054523, 0.33384827489499, 0.15502041525905952, 0.21906162961386144, 19.83521495014429, 59.69373665750027, 77.59411633014679, 76.24740019440651, 57.20328949391842, 24.62547540664673, 23.75124491751194, 64.38211888074875, 76.453288346529, 49.26953561604023, 14.199704099446535, 0.21314093872206286, 0.38101686572190374, 0.42275171843357384, 0.06878532658447511, 0.04047723523399327, 0.07178220796049573, 0.03735894220881164, 0.05239720303507056, 0.01735715319227893, 0.11103663986432366, 0.003816419284703443, 0.022081221868575085, 0.059459109252202325, 0.02314502933586482, 0.016162544052349404, 0.05086094621219672, 0.024604121354059316, 0.032354614450014196, 0.07056251051835716, 0.01187465504699503, 0.059104681786266156, 0.03853924274153542, 0.04002530811703764, 0.04001274355687201, 0.07865986859542318, 0.04549749690340832, 0.03856498413369991, 0.07839181969757192, 0.09128662073635496, 0.046928301962907426, 0.0312314629991306, 0.052269171428633854, 0.02993268415593775, 0.07489293479011394, 0.07405495358398184, 0.11076505834353156, 0.06142931466456503, 0.02645065342221642, 0.06812723455368541, 0.020442854802240618, 0.25602260255254805, 0.31988975359126925, 0.1448012050241232, 0.14235585811547935, 0.1201397564727813, 0.12431699404260144, 0.2065654657781124, 0.11188194606802426, 0.0933615914254915, 0.1811746196472086, 0.12555461435113102, 0.1844843607977964, 0.10215155882178806, 0.09506841233815067, 0.11903655395144597, 0.257110976963304, 0.13917642325395718, 0.09921764867613092, 0.16745361528592184, 0.09762255067471415, 0.29445077176205814, 0.19007098133442923, 0.11821660693385638, 0.07555472271633334, 0.13447370060021058, 0.2428327384404838, 0.21274014929076657, 0.1481634605443105, 0.11198358319234103, 0.15031744027510285, 0.1369597765733488, 0.1317473765811883, 0.15658247284591198, 0.11206055132788606, 0.16337538021616638, 0.1751589635387063, 0.15827035414986312, 0.15801233908860013, 0.12164174462668598, 0.3046442294726148, 0.19840570050291717, 0.17658367927651852, 0.5626698292326182, 0.14989781513577327, 0.31198513868730515, 0.5553485720884055, 5.8252854924649, 45.62558054924011, 88.68487000465393, 109.16283756494522, 98.992820084095, 87.66321882605553, 44.55170877277851, 52.43063159286976, 73.9837096631527, 92.68643528223038, 88.48921090364456, 60.04068844020367, 18.48011266440153, 1.5339583321474493, 0.6883658969309181, 0.8444680518005043, 0.9284510859288275, 8.208699524402618, 14.04599854722619, 5.329729858785868, 17.38673273473978, 67.49797448515892, 13.195726722478867, 0.31155401025898755, 0.18282877776073292, 0.6700911337975413, 3.5834366641938686, 5.688480483368039, 10.352227203547955, 14.350035432726145, 27.800742723047733, 34.64502856135368, 20.352386198937893, 27.967658266425133, 38.39740701019764, 47.44390457868576, 45.86878649890423, 31.42299335449934, 14.817814081907272, 1.8881082348525524, 0.6733539118431509, 0.5679743445944041, 0.8036979020107538, 1.482053236104548, 1.1967823561280966, 0.2933060534996912, 0.7564142486080527, 17.95092076063156, 72.42178067564964, 106.22154459357262, 116.63087323307991, 113.06700646877289, 112.2186715900898, 120.52073210477829, 118.71399745345116, 118.22874069213867, 118.38146969676018, 114.70537215471268, 120.6160993874073, 116.08108073472977, 95.00089108943939, 65.40647551417351, 21.679620780050755, 1.3233853876590729, 0.812482793116942, 1.4318732474930584, 0.42057027923874557, 1.900409481022507, 0.536548012169078, 1.0897368751466274, 1.1480915313586593, 0.14576947025489062, 2.0548337884247303, 1.7618585843592882, 6.963456468656659, 2.969486746005714, 0.5718624859582633, 0.25796334841288626, 4.343786314129829, 42.02382981777191, 83.35994213819504, 82.41099625825882, 70.06201609969139, 53.044492453336716, 37.692909613251686, 66.58063530921936, 89.53471720218658, 88.28166604042053, 59.22343209385872, 18.610705956816673, 0.4025563067989424, 0.6205420894548297, 0.5190187809057534, 0.23886830429546535, 0.1339162141084671, 0.14313217427115887, 0.1765686582075432, 0.28889544017147273, 0.10721289465436712, 0.15584292268613353, 0.14187899854732677, 0.1315328068449162, 0.14120404492132366, 0.14221010031178594, 0.11067942934460007, 0.2305141111719422, 0.2135057043051347, 0.11292865630821325, 0.15325459360610694, 0.14953140198485926, 0.16964381182333454, 0.10548603575443849, 0.101431000221055, 0.19359309546416625, 0.17676945368293673, 0.17486820492194965, 0.1690210757078603, 0.210291774419602, 0.15627462998963892, 0.18074721680022776, 0.0694612375809811, 0.19506682263454422, 0.14080635766731575, 0.2025311510078609, 0.12317462838836946, 0.20406254305271432, 0.12231740329298191, 0.12182879552710801, 0.11257767982897349, 0.16230441658990458], [0.02557006366259884, 0.027392520460125525, 0.02107942826114595, 0.04011126366094686, 0.01799894766008947, 0.02553807895310456, 0.01565995793498587, 0.03633846317825373, 0.011507971012179041, 0.004518169544098782, 0.04689188477641437, 0.03498156860587187, 0.018808504610206, 0.05995976949634496, 0.04353824559075292, 0.04449453255801927, 0.0346166954113869, 0.04677571268985048, 0.05757928629464004, 0.04067428657435812, 0.03105227144260425, 0.06848733202787116, 0.01419969981725444, 0.05114331856020726, 0.04033627912576776, 0.021334543380362447, 0.07081589457811788, 0.025451878500462044, 0.020153832811047323, 0.06266168056754395, 0.018330168168176897, 0.08226266902056523, 0.024135276980814524, 0.061858001427026466, 0.027958977661910467, 0.06751157852704637, 0.026077215843542945, 0.05741013970691711, 0.06341898289974779, 0.019839960004901513, 0.06351954390993342, 0.13706755125895143, 0.08417572535108775, 0.16324443568009883, 0.10177632153499871, 0.13784119568299502, 0.40736646275036037, 0.32363332458771765, 5.590818598866463, 26.48611206561327, 59.6733583509922, 78.99225130677223, 83.95926877856255, 63.24702098965645, 35.35202622413635, 30.53245984017849, 55.133734345436096, 82.45338678359985, 83.68727937340736, 49.20337736606598, 12.431351188570261, 0.5451082997024059, 0.2240202299435623, 0.07359378301771358, 0.06232547282706946, 2.4014925118535757, 1.6481171501800418, 7.369576301425695, 4.6121027413755655, 2.06035275477916, 0.15395495836855844, 0.3598177438834682, 0.2010254075867124, 0.04027072893222794, 0.15385519887786359, 0.115022655663779, 0.22108386328909546, 0.19478070986224338, 0.12621303292689845, 0.797300529666245, 1.28231588518247, 1.287615413311869, 1.116295550018549, 0.709911750163883, 1.074588750489056, 0.2746189234312624, 0.01669026300078258, 0.3693711437517777, 0.2069107722491026, 1.3854630128480494, 3.902216046117246, 0.7240608253050596, 0.16206314438022673, 0.13275122037157416, 1.1550443270243704, 9.56275686621666, 22.37394992262125, 23.54760244488716, 25.70266630500555, 20.35968940705061, 14.958795066922903, 12.268791161477566, 8.821277003735304, 7.979921400547028, 9.831886924803257, 8.431994542479515, 3.2331004505977035, 0.4315551038598642, 0.15003135718870908, 0.034914048010250553, 0.36924969870597124, 0.44666205416433513, 0.15663333964766935, 0.11651064691250212, 0.2398879558313638, 0.5332377960439771, 1.315967591945082, 0.22864192491397262, 1.8281891313381493, 0.17008047667331994, 1.218966159503907, 0.21889366675168276, 2.507446501404047, 27.187457531690598, 66.34016901254654, 63.55293497443199, 35.01993544399738, 25.7418555021286, 26.87406174838543, 37.20041424036026, 65.0811217725277, 70.43177425861359, 46.27035275101662, 20.33530991524458, 1.1194543680176139, 0.29137011675629765, 0.10542848220211454, 0.146712027490139, 0.34935717238113284, 0.10780270909890532, 0.04674021576647647, 0.062305301253218204, 0.09844437532592565, 0.03788628637266811, 0.00916895902264514, 0.0305747866150341, 0.04465096615604125, 0.056814926138031296, 0.020101552217965946, 0.029088053306622896, 0.007252936884469818, 0.05916782371059526, 0.05623814751743339, 0.04757938069815282, 0.06357831458444707, 0.07711088022915646, 0.03934101085178554, 0.06745193211827427, 0.06325323163764551, 0.04316868944442831, 0.033774391195038334, 0.006552369886776432, 0.06358043712680228, 0.016569639883527998, 0.01914264361403184, 0.04290629942261148, 0.057690352405188605, 0.031211432433337905, 0.054252353293122724, 0.07913853900390677, 0.028581682236108463, 0.06982181002967991, 0.04992375099391211, 0.03042001171706943, 0.07875519004301168, 0.06388971974956803, 0.013331208920135396, 0.008793158631306142, 0.026918236144410912, 0.054426887872978114, 0.031126729263633024, 0.07011931476881728, 0.05120791138324421, 0.10387225047452375, 0.04557692525850143, 0.05283307749778032, 0.021861418135813437, 0.029023065289948136, 0.03082028906646883, 0.044236547182663344, 0.05800577258924022, 0.0363663790631108, 0.01384427230732399, 0.04367943176475819, 0.009991667757276446, 0.0379281397908926, 0.012318049321038416, 0.046162947328411974, 0.024760625456110574, 0.05932512562139891, 0.036206828444846906, 0.03014137051650323, 0.11078164534410462, 0.026399443377158605, 0.05240917387709487, 0.025292249956692103, 0.06199233015649952, 0.05610652391624171, 0.022979968271101825, 0.05341745199984871, 0.028021128819091246, 0.02470638744853204, 0.046321622212417424, 0.046928621086408384, 0.051218294029240496, 0.0427797446900513, 0.07920917661977, 0.11376842609024607, 0.05974038693238981, 0.2355696656741202, 0.0925608586112503, 0.11881939411978237, 0.9079453675076365, 0.3673161962069571, 8.237451631575823, 36.78064316511154, 75.62605753540993, 96.59838616847992, 66.6492748260498, 38.74465137720108, 24.967922531068325, 39.111244305968285, 81.75256758928299, 103.635593354702, 103.628388941288, 46.336689591407776, 8.675159644335508, 0.41843203303869814, 0.0433890145359328, 0.23601728462381288, 0.30100832926109433, 0.9834696399047971, 2.0798302721232176, 16.88969660550356, 3.4942951099947095, 6.836783615872264, 1.1111531197093427, 0.33720765088219196, 0.22661687107756734, 0.12083206151146442, 0.5486885388381779, 0.5837161280214787, 1.6722060763277113, 0.9884536068420857, 0.5004668107721955, 2.902171933092177, 4.311244860291481, 5.02953409217298, 4.020638829097152, 2.9811521200463176, 2.767340443097055, 0.06449634383898228, 0.03816197939158883, 0.9215899009723216, 0.6824790628161281, 3.420734857209027, 5.403592670336366, 2.875482402741909, 0.31276261259336025, 0.23573479353217408, 6.210500746965408, 29.37271647155285, 49.744544327259064, 53.421998396515846, 55.44076547026634, 46.276770606637, 38.51705498993397, 33.73209334909916, 29.41857051104307, 28.32658890634775, 30.78865349292755, 27.012085542082787, 15.492281690239906, 3.9978918246924877, 1.480055849533528, 0.7340048917103559, 0.16216029151109979, 0.3868351847631857, 0.4130171157885343, 0.46814437955617905, 0.1767483024741523, 0.7513702567666769, 0.7848281739279628, 0.6054262036923319, 0.47133591142483056, 0.7157139200717211, 0.27554399566724896, 0.48892395047005266, 0.7678309141192585, 12.509560491889715, 62.47413106262684, 87.76211991906166, 59.23934943974018, 40.88044077157974, 28.883960098028183, 25.161866024136543, 53.25888454914093, 81.11968874931335, 56.39888785779476, 24.962792806327343, 1.610587751492858, 0.5565041850786656, 0.14025972137460485, 0.205085682682693, 0.1695815011044033, 0.08922421460738406, 0.06778110429877415, 0.016365514020435512, 0.06903891102410853, 0.035339892347110435, 0.11070632477640174, 0.03914006694685668, 0.011213044308533426, 0.049608898552833125, 0.028017969125357922, 0.07900615470134653, 0.038779620663262904, 0.05237373261479661, 0.009874850929918466, 0.09786696216906421, 0.021695761497539934, 0.06291811485425569, 0.0054266849292616826, 0.1084843568969518, 0.04615942954842467, 0.03433846424741205, 0.026019870092568453, 0.05773029108240735, 0.055143895297078416, 0.07808991402271204, 0.01327949235928827, 0.08190902080968954, 0.038856637038406916, 0.030133605796436314, 0.03227149762096815, 0.06789552862755954, 0.036466706296778284, 0.10185698556597345, 0.05614939778752159, 0.028188169562781695, 0.015280838288163068, 0.027508642451721244, 0.17637884651776403, 0.10012837519752793, 0.08957033744081855, 0.07448740303516388, 0.13559431390604004, 0.20741713960887864, 0.21875570149859414, 0.148879365879111, 0.1072283016401343, 0.12553931126603857, 0.13378699135500938, 0.11705175420502201, 0.11927306157303974, 0.14607710530981421, 0.20839205448282883, 0.1454490257310681, 0.09664157245424576, 0.11501697823405266, 0.14563678909325972, 0.11054314134526066, 0.10594826759188436, 0.1902003525174223, 0.07060295014525764, 0.20399012428242713, 0.12110549097997136, 0.12150707450928167, 0.2587538247462362, 0.1232050935504958, 0.07639167975867167, 0.13497061299858615, 0.21644714724970981, 0.1601017519715242, 0.11525187539518811, 0.14736884302692488, 0.07248340392834507, 0.12875168264145032, 0.18121095519745722, 0.1586303106159903, 0.20301232987549156, 0.12841378280427307, 0.183960716240108, 0.17589406081242487, 0.14719494298333302, 0.24999618530273438, 0.20029592094942927, 0.3196370671503246, 0.9378038684371859, 0.5716530815698206, 8.839403931051493, 44.73548211157322, 84.5053830742836, 111.03841692209244, 95.8684453368187, 82.06804946064949, 50.69467954337597, 43.12028758227825, 72.38853245973587, 94.94789153337479, 110.6125357747078, 64.45929273962975, 19.086727313697338, 0.8353079902008176, 0.35423489345703274, 0.6114650890231133, 0.3285532887093723, 6.486829994246364, 5.3432390838861465, 8.46554009243846, 8.909222334623337, 4.967110091820359, 1.5503121796064079, 0.6106569792609662, 0.6343146285507828, 0.2788610989227891, 0.44379656261298805, 0.21537477354286239, 0.36562614783179015, 0.16567016020417213, 0.19664115534396842, 0.8852924080565572, 1.1045282939448953, 1.1720306030474603, 0.7826702459715307, 0.7346739526838064, 1.1612301575951278, 0.24465097056236118, 0.16514544695382938, 1.0015873052179813, 0.9184006252326071, 5.20162733271718, 9.985127951949835, 2.7754620322957635, 0.3353130369214341, 0.22571292036445811, 1.6409113118425012, 12.874855790287256, 31.50334384292364, 33.7353839725256, 35.89160867035389, 25.650386810302734, 18.975442685186863, 15.41151037439704, 11.547722853720188, 10.210280120372772, 11.869024112820625, 9.982292354106903, 5.294377980753779, 1.1795239197090268, 1.0233112145215273, 0.6091728620231152, 0.5364106851629913, 0.46966512920334935, 0.5322224192786962, 0.2903428953140974, 0.3723344800528139, 4.399908352643251, 4.255743138492107, 4.922639653086662, 4.306920217350125, 2.422511796467006, 2.4082927219569683, 0.6196915288455784, 4.762415550649166, 41.36858157813549, 91.29372641444206, 82.2026078402996, 41.99442319571972, 36.77847348153591, 40.73748864233494, 49.0860016644001, 79.59727764129639, 88.79577085375786, 68.37199598550797, 31.931692957878113, 1.9217312056571245, 0.8837214298546314, 0.2888588671339676, 0.2905335678951815, 0.474755015457049, 0.14440702070714906, 0.10361860666307621, 0.14280947361839935, 0.20287035702494904, 0.12480834033340216, 0.17415336827980354, 0.1115829570335336, 0.10899452405283228, 0.18042038980638608, 0.15883220446994528, 0.16441824613139033, 0.12520552292698994, 0.10849886588403024, 0.16038687026593834, 0.19060158723732457, 0.13376134273130447, 0.26786448899656534, 0.10967514768708497, 0.3197768877726048, 0.14335642161313444, 0.12276171968551353, 0.09827596717514098, 0.1549290568800643, 0.14154157368466258, 0.22928069141926244, 0.13708272075746208, 0.15076605370268226, 0.17182458308525383, 0.17229376884642988, 0.11785982685978524, 0.19568191462894902, 0.10328472184482962, 0.2029936425969936, 0.17521386762382463, 0.10245704906992614, 0.10629516225890256, 0.148846696538385], [0.020007414495921694, 0.012454136940505123, 0.028855579257651698, 0.023890019438113086, 0.0627553767117206, 0.019601279745984357, 0.061300911984289996, 0.1372914868989028, 0.02572210374637507, 0.05536250231671147, 0.0650856907304842, 0.05369344558857847, 0.026991050108335912, 0.015907924316707067, 0.020307770937506575, 0.049462354072602466, 0.03266982683271635, 0.06602583598578349, 0.03625440382165834, 0.03013585264852736, 0.04439637610630598, 0.04551442900265101, 0.014812236968282377, 0.06565879200934432, 0.023289963355637155, 0.06872740195831284, 0.04362425308499951, 0.097291003621649, 0.013035318352194736, 0.03978995082434267, 0.05102314258692786, 0.05506546141987201, 0.028788136587536428, 0.026796772544912528, 0.031819314463064075, 0.05835642252350226, 0.019719706106116064, 0.05626188140013255, 0.0708545307861641, 0.0639378183404915, 0.026685604389058426, 0.06730836365022697, 0.04958349854859989, 0.011418455014791107, 0.03165524045471102, 0.16568644292419776, 0.09326875617261976, 0.04858405198319815, 0.4395953833591193, 0.17955951334442943, 3.8251184206455946, 31.328633017838, 59.412794932723045, 77.75976464152336, 75.92665940523148, 66.48611158132553, 35.969466492533684, 25.15925746411085, 36.883340254426, 70.29435083270073, 79.02675345540047, 49.46199148893356, 17.802719213068485, 2.263112962245941, 0.06213337532244623, 0.028589899666258134, 0.7273943151813, 2.1214496763423085, 4.333831323310733, 5.06584731861949, 2.8975152829661965, 1.4139158860780299, 0.7200903352349997, 0.15375999617390335, 0.2930879214545712, 0.35516934643965214, 0.2752913092263043, 0.29480554803740233, 0.3737642423948273, 0.9003444691188633, 0.47067403444088995, 1.2395242438651621, 0.3792648628586903, 0.3593280154746026, 0.557958735153079, 0.0929363927571103, 0.7865723397117108, 0.5463885341305286, 0.8096752187702805, 1.0575520084239542, 2.8979574842378497, 2.8512848261743784, 0.30859174265060574, 0.17018534214003012, 0.11602197235333733, 0.4963720851810649, 0.9210089477710426, 0.6938311317935586, 0.7360177743248641, 0.6888770288787782, 0.6409262144006789, 0.2673895738553256, 0.06137659991509281, 0.19558222935302183, 0.14073667000047863, 0.06957805904676206, 0.05614422872895375, 0.3062555508222431, 0.4274471680400893, 0.11227258291910402, 0.28659145755227655, 0.3671094635501504, 0.3490927896928042, 0.7023207074962556, 0.9132802218664438, 1.3745389552786946, 1.389051207806915, 0.5851312552113086, 0.7237089285627007, 0.31482554564718157, 6.4875685796141624, 26.488329246640205, 60.14646336436272, 63.06288667023182, 34.73664544522762, 22.96271312981844, 48.042893037199974, 62.17784196138382, 62.463134452700615, 77.20173418521881, 58.36759641766548, 22.267834916710854, 2.992978747934103, 0.3138214198406786, 0.08134410541970283, 0.21564292634138837, 0.015786976509843953, 0.09056091163074598, 0.14760542486328632, 0.027356097707524896, 0.02840846496837912, 0.05941730036283843, 0.012486451905715512, 0.043490692478371784, 0.03889974097546656, 0.09616109862690791, 0.020578825533448253, 0.02418990832666168, 0.03314792578748893, 0.0302224241750082, 0.032934265182120726, 0.012010955106234178, 0.01768335121596465, 0.02150269920093706, 0.038885773756192066, 0.04497192276176065, 0.030845266046526376, 0.05185391753911972, 0.0724699858983513, 0.015018840676930267, 0.024299315737152938, 0.07294616269064136, 0.059842814443982206, 0.05421551308245398, 0.06132229325885419, 0.02757821694103768, 0.061273745668586344, 0.030323408209369518, 0.062109136779326946, 0.04608931514667347, 0.06620870117330924, 0.03561055360478349, 0.049354824295733124, 0.010695292403397616, 0.017525839648442343, 0.051486754819052294, 0.020974557228328194, 0.06572659462108277, 0.060065395664423704, 0.05029580817790702, 0.02562333131209016, 0.04838438457227312, 0.08472573099425063, 0.045217621882329695, 0.05439764354377985, 0.05060401468654163, 0.029073857876937836, 0.06927512920810841, 0.02906182395236101, 0.014577129222743679, 0.021181501397222746, 0.019450037470960524, 0.03857307354337536, 0.023726856416033115, 0.060343303994159214, 0.019066619861405343, 0.04538704306469299, 0.04908096438157372, 0.023897934443084523, 0.10276056520524435, 0.01207077499202569, 0.03460052401351277, 0.027459447337605525, 0.02390830595686566, 0.022790089788031764, 0.040434001421090215, 0.09508502160315402, 0.04500156042922754, 0.02795220927509945, 0.035600334231276065, 0.04066486129886471, 0.07659828625037335, 0.019352849521965254, 0.09604416583897546, 0.027311253434163518, 0.036362531027407385, 0.05958038360404316, 0.06450519023928791, 0.1028824778040871, 0.09858491583145224, 0.1173730893060565, 0.1489308857708238, 0.07737280640867539, 0.08315862680319697, 0.5277344444766641, 0.29110650590155274, 6.561728250235319, 41.87068663537502, 76.19657412171364, 90.68074330687523, 63.7662099301815, 40.03089375793934, 27.53031313419342, 39.15117256343365, 60.25705263018608, 101.21279776096344, 93.2663069665432, 44.358306750655174, 11.213820520788431, 0.9316301497165114, 0.20477215497521684, 0.004640781617126777, 0.5289995390921831, 0.7869849144481122, 1.4417744474485517, 1.445074095390737, 1.0679400572553277, 3.082626862451434, 0.4746160557260737, 0.08387258771108463, 0.5113043042365462, 0.856079338118434, 0.61356833553873, 0.567081036278978, 0.15196635882603005, 0.3939234372228384, 0.49926554085686803, 1.406734271440655, 0.44603989692404866, 0.20776367804501206, 0.3381138131953776, 0.17580396408447996, 0.2710644813487306, 0.6131732754874974, 1.2481992971152067, 4.366135289892554, 6.819143537431955, 4.700533971190453, 3.2491678884252906, 0.7466401043348014, 0.12427156718331389, 0.9409344848245382, 2.3698273859918118, 2.6382694439962506, 2.818203801289201, 2.6561890449374914, 1.7444242886267602, 0.9040351992007345, 0.1574812878970988, 0.46913286088965833, 0.4006130376365036, 0.1792917019338347, 0.1051796623505652, 0.4279580625006929, 0.5030373728368431, 0.2850987610872835, 0.27282049180939794, 0.2950788661837578, 0.2799294056603685, 0.368268460733816, 0.9348978556226939, 1.3965017767623067, 0.5324340204242617, 0.20549840584862977, 0.2343997886055149, 0.678206963930279, 0.09602328180335462, 15.843353401869535, 57.58750967681408, 91.10011160373688, 66.90674901008606, 35.64523369073868, 31.736324541270733, 39.36217904090881, 48.52645508944988, 77.50986725091934, 71.17252171039581, 28.25603239238262, 4.218018762767315, 0.07300877769012004, 0.11812236160039902, 0.17298074526479468, 0.07950261438963935, 0.1508479125914164, 0.20990366087062284, 0.023945975517563056, 0.026397346809972078, 0.10211197266471572, 0.07302681930013932, 0.04785039447597228, 0.007546192828158382, 0.0586766629567137, 0.032817625542520545, 0.029478100150299724, 0.04112776106921956, 0.028947034115844872, 0.04027734888950363, 0.010627335796016268, 0.013070161257928703, 0.07150734614697285, 0.0122895026106562, 0.027118940706714056, 0.025568314049451146, 0.014477994063781807, 0.05939587455941364, 0.01998990908759879, 0.004285104096197756, 0.022318261981126852, 0.05366034951293841, 0.004696738624261343, 0.03625254103098996, 0.03956238608225249, 0.02445887748763198, 0.0036405073251444264, 0.052685007904074155, 0.029627305229951162, 0.031395767073263414, 0.018575473950477317, 0.02487072863004869, 0.04555939573037904, 0.08376555517315865, 0.023069089074851945, 0.12088284667697735, 0.20560971315717325, 0.15131467895116657, 0.14728043839568272, 0.17422704870114103, 0.14179700607201084, 0.1902719252393581, 0.15870479255681857, 0.23771790118189529, 0.2550146769499406, 0.15538835723418742, 0.13097695307806134, 0.1677862013457343, 0.048756983524071984, 0.12465005507692695, 0.12980234110727906, 0.10150573449209332, 0.18535926385084167, 0.10608855576720089, 0.09350993932457641, 0.15423494100105017, 0.19189054932212457, 0.11690508355968632, 0.18530599249061197, 0.08739714350667782, 0.17556580889504403, 0.15054196963319555, 0.2209210064029321, 0.11297502569505014, 0.1872759938123636, 0.30127820384223014, 0.13757400767644867, 0.06953303294721991, 0.10241277996101417, 0.09033811147673987, 0.23609326570294797, 0.08669856732012704, 0.15574629505863413, 0.1210769554018043, 0.13334134651813656, 0.15134706627577543, 0.1459664065623656, 0.14848043181700632, 0.13947049184935167, 0.21968598361127079, 0.28189176286105067, 0.14987243368523195, 0.1457420998485759, 0.8693364704959095, 0.3605435643112287, 7.887431513518095, 48.38195264339447, 88.26737880706787, 106.30184188485146, 92.84745544195175, 83.07564899325371, 51.97143763303757, 40.480899810791016, 49.964533522725105, 91.41447633504868, 99.10561323165894, 66.67704373598099, 23.8372191041708, 3.593447939492762, 0.21251775731798261, 0.18957451422465965, 1.256300462409854, 4.770554713904858, 11.609130408614874, 17.13170561939478, 8.028215859085321, 6.612787060439587, 4.3166866432875395, 0.4490475245984271, 0.6010166590567678, 1.0173189360648394, 1.033429834060371, 1.1023231060244143, 0.8360496629029512, 0.906373558100313, 0.6272874993737787, 1.4651984092779458, 0.4120466241147369, 0.3128072008257732, 0.45020358287729323, 0.2227350973407738, 0.9489275934174657, 1.255231888499111, 3.1816889718174934, 10.48964872956276, 19.325415305793285, 11.38478759676218, 5.051187705248594, 0.8445815113373101, 0.12652399280341342, 0.8555943891406059, 0.7849484612233937, 0.8120138151571155, 0.7703863957431167, 0.813969582086429, 0.48727403744123876, 0.31654507212806493, 0.12081777516868897, 0.21460124786244705, 0.18988608266226947, 0.162447027687449, 0.15683210163842887, 0.44849023106507957, 0.6129627430345863, 0.3896600066218525, 0.6079999124631286, 0.4687699506757781, 0.5691696773283184, 0.7608741405420005, 1.5365098952315748, 4.416716750711203, 2.596471686847508, 1.246740056667477, 1.108069228939712, 0.6233510293532163, 10.511526055634022, 43.048695623874664, 86.78902253508568, 84.46840345859528, 47.488970160484314, 32.967251390218735, 62.426861599087715, 79.40813139081001, 76.30987644195557, 92.58581668138504, 77.84315496683121, 34.49280872941017, 5.31637785024941, 0.32050751731731, 0.19163066404871643, 0.38744585355743766, 0.1560675707878545, 0.22843209007987753, 0.3215073386672884, 0.18610298488056287, 0.11324007631628774, 0.22217590390937403, 0.24009795393794775, 0.2176318969577551, 0.19104870152659714, 0.2529586013406515, 0.09179787884932011, 0.09938161136233248, 0.17706276528770104, 0.14831260254140943, 0.11180649933521636, 0.14284828794188797, 0.0840819401491899, 0.1444919075584039, 0.2624167688190937, 0.16224258084548637, 0.10203918282059021, 0.10921182489255443, 0.16607926168944687, 0.09536360899801366, 0.18330868013435975, 0.19408392225159332, 0.23836199630750343, 0.12707456247881055, 0.09352383975056, 0.11878243516548537, 0.11312974864267744, 0.1451370120048523, 0.1836005222867243, 0.16670377895934507, 0.19059441809076816, 0.10373851546319202, 0.10660739862942137, 0.108391046669567, 0.16823632875457406, 0.16193543560802937], [0.04307429197069723, 0.021370082977227867, 0.07489277893910185, 0.035473011375870556, 0.0968012455268763, 0.05445064773084596, 0.008605357234046096, 0.04136415365792345, 0.05037125119997654, 0.06092791969422251, 0.02819211036694469, 0.026619330601533875, 0.03464787303528283, 0.06411361086065881, 0.03473277472949121, 0.003098843653788208, 0.0757892413821537, 0.005308875479386188, 0.04494632979913149, 0.04200352501356974, 0.030031384230824187, 0.018878561495512258, 0.05373093888920266, 0.012888787787233014, 0.03366610071680043, 0.04663781794079114, 0.04523660601989832, 0.02287808252731338, 0.07562538259662688, 0.029037351632723585, 0.030210434779291973, 0.016189641719392966, 0.07968052945216186, 0.05792396936158184, 0.02867745639377972, 0.05710984820325393, 0.029292826693563256, 0.06672234900179319, 0.10609000295517035, 0.0029584191088360967, 0.09949081839295104, 0.017089300963561982, 0.01804167124646483, 0.02443747580400668, 0.038135922586661763, 0.09451129692024551, 0.12998302438063547, 0.15852361946599558, 0.03065936176426476, 0.017182190022140276, 0.4770321323303506, 0.19292462820885703, 4.2122691962867975, 40.31671442091465, 73.82330507040024, 77.21792131662369, 77.00501874089241, 55.136272609233856, 49.89955700933933, 34.57197368144989, 40.73756083846092, 60.741321444511414, 85.29058814048767, 56.65989205241203, 25.396271646022797, 5.2910560090094805, 0.4490040347445756, 0.26617037365213037, 0.4036570602329448, 0.466653048642911, 0.819009121041745, 0.4529680236009881, 0.16850068175699562, 0.5974904482718557, 0.7119292044080794, 1.2433689250610769, 0.32520644017495215, 0.3298985352739692, 0.32353488611988723, 2.116298102773726, 0.2173387337825261, 0.15316455624997616, 0.12984948232769966, 0.2309862061520107, 0.6917242635972798, 0.3067934000864625, 0.2866707486100495, 0.7097850507125258, 1.5649765427224338, 2.0584884798154235, 2.1374358935281634, 2.626163768582046, 2.2899654088541865, 0.26681981224101037, 0.9027391124982387, 0.2873751654988155, 0.684999693185091, 0.38496369612403214, 0.7296164834406227, 0.593874289188534, 0.4189112229505554, 0.35455971665214747, 0.1999746897490695, 0.2820080128731206, 0.9202116436790675, 1.2428548838943243, 0.7168445375282317, 0.6089398276526481, 0.2647626382531598, 0.5985383607912809, 0.36011457326821983, 1.1848729639314115, 0.3071608522441238, 0.2784896094817668, 1.1673567350953817, 0.38134207483381033, 0.2294834313215688, 3.4557837015017867, 13.604390043765306, 39.2488881200552, 62.02169694006443, 49.528940096497536, 32.77909688651562, 27.44083173573017, 38.808035776019096, 64.36018645763397, 69.2389802634716, 66.6402617096901, 58.609221652150154, 29.282752498984337, 5.14746218919754, 0.07002466867561452, 0.16642908041831106, 0.21105235704453662, 0.06032178542227484, 0.29102935222908854, 0.08408130932366475, 0.08433524257270619, 0.04106724634766579, 0.0946073308296036, 0.011170916295668576, 0.023096034601621795, 0.05842541628226172, 0.031125334026000928, 0.06724109538481571, 0.063727233937243, 0.05699008412193507, 0.09065435544471256, 0.028421146416803822, 0.0214974670598167, 0.05392844293965027, 0.023933199445309583, 0.0113731747296697, 0.09774773614481091, 0.05053668333857786, 0.04765439698530827, 0.04651915223803371, 0.07531989234848879, 0.008418683901254553, 0.030533575154549908, 0.06674544463749044, 0.030222798959584907, 0.04006232644314878, 0.05300452474330086, 0.06274008104810491, 0.04431076937180478, 0.034266531583853066, 0.005406844074968831, 0.025132380214927252, 0.012031148016831139, 0.025799114555411506, 0.03887320919602644, 0.020354956686787773, 0.1286181851173751, 0.015294429795176256, 0.025348883245897014, 0.03831704372714739, 0.04652671101212036, 0.05553582348511554, 0.05358553731639404, 0.12353528247331269, 0.00440174280811334, 0.04031456759548746, 0.07199045459856279, 0.03435624239500612, 0.010454531347932061, 0.020431785669643432, 0.06064256762329023, 0.035068926808889955, 0.07455571030732244, 0.04182169141131453, 0.03606025427870918, 0.007297478732652962, 0.0198553447262384, 0.07508688024245203, 0.010804246176121524, 0.06068370486900676, 0.02732244502112735, 0.009931124277500203, 0.012660640459216665, 0.07749558732029982, 0.010675259054551134, 0.07237674988573417, 0.06779973220545799, 0.044599813627428375, 0.011035929837817093, 0.07305818246095441, 0.05071842788311187, 0.05891446191526484, 0.018758001460810192, 0.02246681211545365, 0.07650769970496185, 0.0750406963925343, 0.023910411800898146, 0.0848999798472505, 0.03665038413600996, 0.005493050557561219, 0.07555157601018436, 0.03612515880377032, 0.07700735062826425, 0.08369617920834571, 0.048566221885266714, 0.1724297896726057, 0.043062361946795136, 0.07321177734411322, 0.14878471236443147, 0.33471694390755147, 0.34824564296286553, 8.422052375972271, 47.08323173224926, 88.66049811244011, 90.20312413573265, 73.66131216287613, 32.679614424705505, 33.267667070031166, 35.86562566459179, 70.05063191056252, 101.44353657960892, 104.91471871733665, 61.97426028549671, 22.17355627566576, 3.9615327632054687, 0.18051133258268237, 0.3247312578605488, 0.21976659569190815, 0.14947654242860153, 0.2700468187686056, 0.4165502730756998, 0.7230263308156282, 0.06608344890992157, 0.40952952636871487, 0.2292986068641767, 0.1436677822493948, 0.3818384825717658, 0.8212384139187634, 1.6747182165272534, 0.07178721003583632, 0.669485303806141, 0.10161136437091045, 0.3549155913060531, 1.5561187430284917, 0.3273758862633258, 0.3452432993799448, 2.0495413849130273, 0.2541198249673471, 2.384033161215484, 3.4644488990306854, 3.4032828686758876, 2.968494286760688, 2.2338098846375942, 2.7036052756011486, 1.3300493988208473, 0.6437286827713251, 1.0162395564839244, 1.5093681891448796, 0.6570855004247278, 0.4474333830876276, 0.5064975621644408, 0.21926101500866935, 0.11393897162633948, 0.10830621919012628, 1.2758562318049371, 0.39327379083260894, 0.29797368741128594, 0.4454053903464228, 0.38305450638290495, 0.2515399712137878, 0.6066567439120263, 0.28064777492545545, 0.21624808839987963, 0.6680536712519825, 0.13817584491334856, 0.4978501464938745, 1.4994218666106462, 1.2067777197808027, 22.684571854770184, 54.69176486134529, 65.7077993452549, 60.00871315598488, 38.99312004446983, 28.461164385080338, 38.830861151218414, 62.74672083556652, 76.18189170956612, 75.13809531927109, 38.69359731674194, 7.984025180339813, 0.10202390942140482, 0.30700114206410944, 0.05519070626178291, 0.05947969271801412, 0.21130657230969518, 0.0198448322043987, 0.08680021928739734, 0.12024252908304334, 0.08673673597513698, 0.06162984667753335, 0.04843488772166893, 0.07028419771813788, 0.033054875311790965, 0.013020009700994706, 0.03243582395953126, 0.11762147871195339, 0.048377998391515575, 0.03846453815640416, 0.04020431784738321, 0.04605587397236377, 0.030968848477641586, 0.05073634703876451, 0.02934574367827736, 0.046982834974187426, 0.05563488906773273, 0.029083014123898465, 0.06481847303803079, 0.04904580884613097, 0.014957260973460507, 0.018726265370787587, 0.029752954542345833, 0.016212809714488685, 0.033036744644050486, 0.025590762161300518, 0.022229924143175595, 0.046476226416416466, 0.04073706855706405, 0.04694822862802539, 0.018900154282164294, 0.052386868628673255, 0.061240686700330116, 0.023938420454214793, 0.08123080915538594, 0.032262680906569585, 0.017366814099659678, 0.20530572946881875, 0.10971390263875946, 0.2321068343007937, 0.154724535823334, 0.23165287740994245, 0.20265206170734018, 0.09742430076585151, 0.14442352607147768, 0.13391746091656387, 0.22629347280599177, 0.10458112024934962, 0.13713551714317873, 0.10175422037718818, 0.17943561921129003, 0.14452986099058762, 0.12261988784302957, 0.1185964529577177, 0.18489086476620287, 0.2344463806366548, 0.12424789267242886, 0.13533254357753322, 0.1216853606456425, 0.21138826792594045, 0.09557866113027558, 0.16058419249020517, 0.14044565905351192, 0.16857635113410652, 0.15608593152137473, 0.13542054744902998, 0.13574684009654447, 0.1546019478701055, 0.1667052335687913, 0.09489034884609282, 0.15366347244707868, 0.08563491384848021, 0.13041778933256865, 0.28829756600316614, 0.12589070334797725, 0.2528045908547938, 0.17877015023259446, 0.1566832565004006, 0.1503838476492092, 0.13834542565746233, 0.11116374007542618, 0.18738302635028958, 0.1737620634958148, 0.17258155887247995, 0.32128484279382974, 0.1963800232624635, 0.11362830860889517, 0.6521858414635062, 0.40694141993299127, 10.024641081690788, 56.28650888800621, 98.3500237762928, 105.93853577971458, 93.98047104477882, 71.95004358887672, 71.18003010749817, 48.627636060118675, 56.45521603524685, 82.26101830601692, 105.9793683886528, 75.7226711511612, 36.095916107296944, 9.906300231814384, 2.438918841071427, 0.3353067731950432, 0.40740238269791007, 1.3459733943454921, 2.537772199138999, 3.487335783429444, 4.067051438614726, 2.6770112151280046, 3.176797921769321, 1.8292496306821704, 0.736966417171061, 0.9202935767825693, 0.7904497347772121, 5.710538774728775, 0.3148394386516884, 0.6241192412562668, 0.1956232701195404, 0.5315898719709367, 1.1742538399994373, 0.4139181721257046, 0.258815927663818, 4.810382276773453, 3.3914766646921635, 6.374196438118815, 4.8475803807377815, 9.404542855918407, 8.817723244428635, 3.908730559051037, 3.203278463333845, 1.2709145969711244, 1.1656420771032572, 0.8286870236042887, 1.4531031833030283, 0.6467492238152772, 0.57768834521994, 0.40570045995991677, 0.17543064896017313, 0.3947643795982003, 1.3176497141830623, 2.9755614325404167, 1.4745012600906193, 0.8860856748651713, 0.9426476585213095, 0.7681897573638707, 1.282473576720804, 2.506352635100484, 0.35420295142102987, 0.26252354902680963, 0.9159268392249942, 0.23007934622000903, 0.567734541837126, 5.894692093133926, 21.563231125473976, 61.73863872885704, 89.24467116594315, 64.47696179151535, 44.11587215960026, 38.306386694312096, 54.80349786579609, 83.732420951128, 86.5557910501957, 85.06576180458069, 80.98337486386299, 44.76159431040287, 9.493770617991686, 0.1639163019717671, 0.34091453009750694, 0.381332901888527, 0.19395422452362254, 0.5442613014020026, 0.1580171482055448, 0.21175502246478572, 0.22420643479563296, 0.2140093405614607, 0.10945058122160845, 0.12064116628607735, 0.27525993122253567, 0.12910313409520313, 0.16671347140800208, 0.1279060053639114, 0.23896885046269745, 0.15755291999084875, 0.14577989000827074, 0.19913282711058855, 0.10077682672999799, 0.13712263345951214, 0.21102771774167195, 0.12958581210114062, 0.14509123633615673, 0.2217383633251302, 0.15990279702236876, 0.2660840767202899, 0.16680263302987441, 0.05891147848160472, 0.21119064884260297, 0.11183193273609504, 0.1946077894535847, 0.18169205985032022, 0.15338665136368945, 0.2606858726358041, 0.18240009841974825, 0.18066654534777626, 0.12198095064377412, 0.10964049681206234, 0.09304118400905281, 0.15503209666348994, 0.10751013222034089, 0.23061489482643083, 0.10235481822746806, 0.13885836844565347], [0.04869210497417953, 0.005803752073916257, 0.041773874836508185, 0.08853898223605938, 0.08196237380616367, 0.05079276510514319, 0.02944659598142607, 0.04762644399306737, 0.026852081100514624, 0.0267888334201416, 0.07599326519994065, 0.03164833105984144, 0.019836186183965765, 0.00757459296437446, 0.022289795051619876, 0.08796710550086573, 0.05144889044458978, 0.01618815371330129, 0.0823655010026414, 0.04785834658832755, 0.03338747992529534, 0.03852473746519536, 0.023947363333718386, 0.047436264940188266, 0.025374016076966655, 0.02543934177083429, 0.05050622559792828, 0.00040173314744151867, 0.04400458150485065, 0.03746472422790248, 0.0374305928562535, 0.02939627280284185, 0.03603303230192978, 0.019714475820364896, 0.07619161900947802, 0.08225658340961672, 0.07128905825084075, 0.034742200004984625, 0.03376361521077342, 0.04556138097541407, 0.03450600037467666, 0.04129358283535112, 0.032379172116634436, 0.022093871775723528, 0.11493154219351709, 0.012266819794604089, 0.023859381726651918, 0.07191036944277585, 0.23584357753861696, 0.0345895179634681, 0.0745447858935222, 0.09588913118932396, 0.5838342779316008, 0.22788932779803872, 9.625332858413458, 39.371427744627, 65.34785985946655, 77.33744010329247, 61.08529418706894, 73.48116382956505, 40.10084420442581, 20.516138412058353, 30.67731946706772, 46.92760348320007, 70.58498203754425, 76.85424283146858, 51.381196305155754, 34.065270870923996, 17.711033932864666, 7.695217402651906, 3.3431301964446902, 0.5473052943125367, 0.1764423298300244, 0.12063457601470873, 0.22574701462872326, 0.5191008921246976, 0.13447957840980962, 0.19087533582933247, 0.05327471844793763, 0.6010566756594926, 0.1815767597872764, 1.3833646941930056, 0.7591377524659038, 0.8526735927443951, 1.157159151043743, 1.2612253543920815, 0.5210790422279388, 1.870841842610389, 0.7353580347262323, 1.8463127338327467, 2.199024176225066, 0.7477175840176642, 0.6979632319416851, 1.1513551999814808, 0.7957920699846, 1.2600987148471177, 1.8292293255217373, 1.6921725799329579, 1.722921954933554, 0.9082073159515858, 0.3449039300903678, 0.3545863745966926, 0.5024610506370664, 0.030026929489395116, 0.6844573316629976, 0.7940698717720807, 0.25859001791104674, 0.6553232262376696, 0.26440985093358904, 0.1357481165905483, 0.13915170973632485, 0.6506143289152533, 0.7468539022374898, 3.108816957101226, 11.315520163625479, 21.118588484823704, 35.728418827056885, 51.004009544849396, 65.35678178071976, 55.18638052046299, 32.41731069982052, 26.19023334234953, 48.95892508327961, 77.30439707636833, 68.75237837433815, 66.41193196177483, 58.316774144768715, 39.792106971144676, 8.322471119463444, 0.25694871379528195, 0.2860289392992854, 0.03653587817098014, 0.045460960973287, 0.09784059366211295, 0.06568675613380037, 0.050013684449368156, 0.12522771314252168, 0.03992780104454141, 0.09581402584444731, 0.07126668991986662, 0.03753103141207248, 0.008351904525625287, 0.01024942863296019, 0.05840597572387196, 0.03156857244903222, 0.07643453878699802, 0.04581821973260958, 0.04679537218180485, 0.082423351414036, 0.018764144588203635, 0.03366339558851905, 0.01966157553397352, 0.1202759331499692, 0.019214743260818068, 0.05510369686817285, 0.011204107922822004, 0.0247580965879024, 0.022778259954066016, 0.06187633247463964, 0.01672883241553791, 0.08048195246374235, 0.014712226075062063, 0.06367959547787905, 0.03690170131449122, 0.02623721546115121, 0.08532268489943817, 0.023578794243803713, 0.01303064746025484, 0.023715620300208684, 0.029088025476085022, 0.0835355932940729, 0.05667149125656579, 0.06750111424480565, 0.04174151719780639, 0.08245621371315792, 0.05008851148886606, 0.03748199771507643, 0.07394973930786364, 0.032427415426354855, 0.0800756859825924, 0.038038712373236194, 0.06642138585448265, 0.03294372385425959, 0.02360761740419548, 0.05137713589647319, 0.10274983374984004, 0.07200455540441908, 0.02927622670540586, 0.011740207573893713, 0.006634859137193416, 0.09892724629025906, 0.01780831033102004, 0.043599402270046994, 0.1010391759336926, 0.06565994233824313, 0.03482485670247115, 0.04568333810311742, 0.034560399799374864, 0.031505764491157606, 0.0653387259808369, 0.03482311265543103, 0.035215404495829716, 0.06132604852609802, 0.023242484458023682, 0.05041482640081085, 0.03511593815346714, 0.05100976166431792, 0.06572155543835834, 0.01678747321420815, 0.032475970438099466, 0.044985236891079694, 0.15206352079985663, 0.042732135916594416, 0.02826795600412879, 0.12280331706278957, 0.0797128574049566, 0.03772745934838895, 0.03493065727525391, 0.02715450813411735, 0.009094388024095679, 0.06174478308821563, 0.015395881382573862, 0.002264222753183276, 0.029390472918748856, 0.06290624049142934, 0.025079299957724288, 0.08364748689928092, 0.11672754699247889, 0.7018475735094398, 0.40353558550123125, 14.61085058748722, 49.16084624826908, 81.82423934340477, 83.37025478482246, 66.98564037680626, 63.17661456763744, 20.166743360459805, 26.77844747900963, 50.72170749306679, 77.57164433598518, 91.78618758916855, 73.97647485136986, 53.07684771716595, 23.78086432814598, 6.471436070278287, 1.5649259579367936, 1.267125487793237, 0.6412790610920638, 0.04904083274595905, 0.10613170423312113, 0.1237429428147152, 0.2742408140329644, 0.1498263017856516, 0.31484424776863307, 0.1035607785161119, 1.1757222237065434, 0.9572939132340252, 1.370755189564079, 0.29823139077052474, 1.4123251964338124, 2.280902420170605, 0.9382016002200544, 0.4077984223840758, 0.5769239331129938, 1.0804431675933301, 3.0754592595621943, 2.374301408417523, 3.4751747734844685, 3.383218045346439, 2.3222651006653905, 1.6841303114779294, 2.4911373015493155, 0.6898554170038551, 1.571893715299666, 2.293280493468046, 0.6838988210074604, 0.12111806296161376, 0.2730082254856825, 0.09588038868969306, 0.8721015346236527, 1.3823173753917217, 0.8030889846850187, 0.364672873984091, 0.12488593929447234, 0.27010817953851074, 0.26830327638890594, 0.08718641809537075, 0.21810857841046527, 0.9281931153964251, 1.8727318849414587, 5.356175489723682, 2.3020722717046738, 14.238255880773067, 36.33723735809326, 61.86936691403389, 80.58624297380447, 63.49121108651161, 37.87562280893326, 32.39145688712597, 52.53003805875778, 58.266480043530464, 75.47336652874947, 71.16052195429802, 49.30840753018856, 12.625761106610298, 0.6653463758993894, 0.14894178049871698, 0.10695419681724161, 0.04532081751676742, 0.10139944410184398, 0.21692664886359125, 0.11875975513248704, 0.03537211268849205, 0.026359495423093904, 0.109540403354913, 0.04589978918374982, 0.042147375497734174, 0.07530800314270891, 0.026544048996584024, 0.06311336648650467, 0.010962856122205267, 0.0149751671415288, 0.05330306106770877, 0.04937526675348636, 0.08036556886509061, 0.04145095525018405, 0.026355573172622826, 0.06229183869436383, 0.03778876445721835, 0.055555334547534585, 0.05950849918008316, 0.07503105589421466, 0.0407266116963001, 0.05850020250363741, 0.015061562407936435, 0.07006686719250865, 0.013110277122905245, 0.022554897623194847, 0.08874058665242046, 0.0070815972503623925, 0.05470793919812422, 0.02588114599348046, 0.05878945827134885, 0.021056208315712865, 0.05694863517419435, 0.053887483809376135, 0.013909375356888631, 0.05126277465024032, 0.022184341432875954, 0.013293580177560216, 0.1192771433852613, 0.03189544768247288, 0.17508958757389337, 0.1818815598380752, 0.121204367314931, 0.17081500991480425, 0.196624516393058, 0.2273640950443223, 0.1376080425688997, 0.2181437413673848, 0.12115765654016286, 0.16874415072379634, 0.1890654454473406, 0.12331459001870826, 0.12271615923964418, 0.10423044062918052, 0.12446416192688048, 0.15612906514434144, 0.17560416308697313, 0.21838047163328156, 0.17883679509395733, 0.17863389191916212, 0.12718592915916815, 0.08548573474399745, 0.15786539384862408, 0.18936885026050732, 0.09564166946802288, 0.05788112888694741, 0.15706523990957066, 0.10875892927288078, 0.16757700475864112, 0.2093346117180772, 0.13692513311980292, 0.13950274558737874, 0.21425668353913352, 0.1610620168503374, 0.21517141023650765, 0.2585884148720652, 0.15588749607559294, 0.12031447287881747, 0.1711118096136488, 0.18588952836580575, 0.11917599607841112, 0.15777641034219414, 0.1881299979868345, 0.17526912793982774, 0.20906561287119985, 0.16384661430492997, 0.13577115285443142, 0.19898985978215933, 0.29955419478937984, 0.145790369133465, 0.2406913455342874, 0.26652256725355983, 1.0882091196253896, 0.33778343873564154, 17.34677977859974, 58.661677837371826, 92.80355259776115, 93.14983561635017, 81.78991958498955, 100.00244110822678, 56.30120649933815, 38.277607038617134, 45.65018802881241, 70.28166711330414, 97.14393049478531, 100.02834051847458, 74.14610534906387, 46.16216495633125, 26.147327944636345, 14.49947476387024, 5.8230512123554945, 1.8545828713104129, 0.34107821818906814, 0.2818577131256461, 0.6325604883022606, 1.8462043209001422, 1.2441050168126822, 1.2940517929382622, 0.1725792433717288, 1.8120294297114015, 2.1809031860902905, 3.863038723357022, 3.3051754580810666, 2.045292262919247, 4.824465746060014, 2.3438804782927036, 1.229426998179406, 6.2185667641460896, 5.359973385930061, 8.884057234972715, 12.287546955049038, 6.904681697487831, 7.05060669220984, 10.83488680422306, 14.240930937230587, 11.568288300186396, 4.318073568865657, 6.505691707134247, 6.151553560048342, 2.362676882185042, 1.0618130047805607, 0.3627602109918371, 0.4484808206325397, 1.2533069355413318, 2.313329167664051, 3.440345129929483, 1.3573273038491607, 1.0116782574914396, 0.36023613705765456, 0.31267085345461965, 0.12572204286698252, 0.379545483738184, 0.6980221881531179, 3.381321709603071, 15.452482625842094, 31.65284112095833, 52.29644179344177, 76.61643639206886, 93.82603973150253, 76.05746358633041, 46.36570483446121, 36.95961736142635, 66.05268403887749, 100.46726256608963, 84.36042085289955, 84.16571170091629, 80.34351199865341, 59.374162405729294, 13.873711992055178, 0.8121125504840165, 0.452961670816876, 0.1964066960499622, 0.1138069287117105, 0.3691184869967401, 0.4530881327809766, 0.30383255740161985, 0.291916960850358, 0.13947403931524605, 0.39871343644335866, 0.21450212661875412, 0.20686155301518738, 0.16261110169580206, 0.2049461886053905, 0.16501907404744998, 0.09017666467116214, 0.19516080821631476, 0.15585380257107317, 0.13794324098853394, 0.2054171555209905, 0.11702504431013949, 0.20047739089932293, 0.1329720241483301, 0.18986637121997774, 0.2292411497910507, 0.12708593218121678, 0.14946928422432393, 0.25272111408412457, 0.12685067136771977, 0.14839802373899147, 0.19521894806530327, 0.1194654188293498, 0.17081321391742676, 0.22759589744964615, 0.1726944395340979, 0.1465909238322638, 0.1848015101859346, 0.2507870178669691, 0.12611644982825965, 0.19895842240657657, 0.1996937274816446, 0.1687931621563621, 0.13038801436778158, 0.24672675761394203, 0.10090187861351296, 0.2047376154223457, 0.11514637910295278], [0.08156128751579672, 0.05677669068973046, 0.05579043208854273, 0.07054802379570901, 0.08865138050168753, 0.016343360912287608, 0.03221135768399108, 0.05447500130685512, 0.08712524286238477, 0.02385435738688102, 0.12452003080397844, 0.019853535741276573, 0.04872475205047522, 0.03724146765307523, 0.0422728578269016, 0.07378963578958064, 0.06978532604989596, 0.03140175249427557, 0.146572993544396, 0.025237844965886325, 0.0973763877118472, 0.06378847596351989, 0.08504581186571158, 0.03511174501909409, 0.03211631083104294, 0.014151360956020653, 0.023931390460347757, 0.07911065651569515, 0.06971597977099009, 0.07777032296871766, 0.02015473452047445, 0.04490974191867281, 0.07650945117347874, 0.07013360111159272, 0.07817039993824437, 0.059841311594937, 0.08157132877386175, 0.07258858109707944, 0.019803249670076184, 0.04902498047158588, 0.07761577071505599, 0.02899098410125589, 0.05075917550129816, 0.13639774813782424, 0.06787533478927799, 0.018054451029456686, 0.04910577066766564, 0.07123200935893692, 0.07278015167685226, 0.05385516327805817, 0.119705948891351, 0.06466438091592863, 0.03983177826739848, 0.11278144389507361, 0.7000834587961435, 0.1877637777943164, 12.464069332927465, 54.47302579879761, 80.97195267677307, 67.26560175418854, 81.26797199249268, 64.29603829979897, 49.04013052582741, 33.11979800462723, 24.99662809073925, 33.18661741912365, 34.67813238501549, 68.01253527402878, 94.86040502786636, 77.75780394673347, 67.95250609517097, 54.586875289678574, 34.461999982595444, 23.059547133743763, 10.616731960326433, 2.843632511794567, 1.565880300477147, 1.0761699406430125, 0.21764703677035868, 0.13141149538569152, 0.29657895443961024, 0.46215023088734597, 0.2565383358160034, 0.7685289485380054, 0.4250752046937123, 0.1834074451471679, 0.1702692938852124, 0.06861081055831164, 0.7444660272449255, 1.8491471442393959, 1.4268467109650373, 4.947422873228788, 2.2226565331220627, 1.9222841947339475, 1.834772634319961, 0.5802630039397627, 0.4914739402011037, 1.3789416127838194, 1.030577018391341, 0.14567060134140775, 0.4639040742767975, 0.06385639731888659, 0.7719849818386137, 1.3996477704495192, 0.8204083365853876, 0.3632168099284172, 0.061603021749760956, 0.30539002851583064, 1.5268425014801323, 4.604957224801183, 8.264385536313057, 19.283900633454323, 28.85737482458353, 43.397672697901726, 40.75295381247997, 49.95987497270107, 69.49807316064835, 40.37899307906628, 18.62820401787758, 17.93377038091421, 46.502045318484306, 67.82531931996346, 72.36236706376076, 58.05488079786301, 58.656540513038635, 33.32975193858147, 11.922956518828869, 0.5772422847803682, 0.18347348144743592, 0.04367137204098981, 0.044898732157889754, 0.07361529787885956, 0.18504796258639544, 0.10883962298976257, 0.06442155019612983, 0.03372211431269534, 0.04389787922264077, 0.004518619471127749, 0.04652503746910952, 0.10963864144287072, 0.03377587920113001, 0.06866808209451847, 0.0969053762673866, 0.0722011280595325, 0.11279848360572942, 0.052160955165163614, 0.09339647236629389, 0.04151005246967543, 0.03051892144867452, 0.05157302206498571, 0.017594330602150876, 0.04332457385316957, 0.014187539727572585, 0.034093084250343964, 0.03662776718556415, 0.04034473589854315, 0.05987395124975592, 0.11531553682289086, 0.03766613939660601, 0.03734278565389104, 0.16228467546170577, 0.07081391304382123, 0.03218989848392084, 0.08109465474262834, 0.044605813891394064, 0.057657211800687946, 0.015153097974689445, 0.023040709347696975, 0.0322819322173018, 0.05323486140696332, 0.07379204776952974, 0.05118284905620385, 0.032969966196105815, 0.06399421414243989, 0.11722026625648141, 0.08591246223659255, 0.036034794902661815, 0.036483530784607865, 0.06040614163794089, 0.0015066080231918022, 0.04488857215619646, 0.05897703980735969, 0.03595808280806523, 0.1015648317115847, 0.04279511827917304, 0.05120482775964774, 0.0844391506689135, 0.0350685854209587, 0.04022194756544195, 0.05463667446747422, 0.042761339427670464, 0.04345858716988005, 0.023855626459408086, 0.031717031670268625, 0.050321612652624026, 0.05478035796841141, 0.05901880416786298, 0.05084207710751798, 0.02648189227329567, 0.05049690051237121, 0.015057647578942124, 0.0075349112557887565, 0.027303386668791063, 0.09659315473982133, 0.03539629928127397, 0.006930710742381052, 0.05676359920471441, 0.04307658149627969, 0.0245365117007168, 0.031163226231001318, 0.03709258911840152, 0.01968146509170765, 0.0674879337020684, 0.052624404124799185, 0.07423904331517406, 0.01721800977975363, 0.09299413926783018, 0.029733849805779755, 0.024876769712136593, 0.17772731400327757, 0.05119957335409708, 0.016523984813829884, 0.19399881275603548, 0.04851676516409498, 0.06095059972722083, 0.042852686674450524, 0.09237215272150934, 0.028714986801787745, 0.13575175311416388, 0.15578816703055054, 0.8398108079563826, 1.1708299862220883, 16.945893689990044, 67.11253836750984, 87.9488343000412, 79.62065398693085, 72.55901411175728, 40.565133690834045, 28.353440165519714, 21.25343944877386, 44.675015956163406, 71.95106953382492, 75.21306529641151, 100.20846605300903, 96.94121897220612, 73.68277341127396, 52.7119342982769, 34.09705236554146, 16.882438994944096, 5.914641972631216, 4.44377557374537, 1.7968760803341866, 0.8429659449029714, 0.5966854258440435, 0.2323347923811525, 0.14891685917973518, 0.10735634437878616, 0.31878561596386135, 0.5077936488669366, 0.4283285129349679, 0.3540881263324991, 0.22584646241739392, 0.10995006145094521, 0.2666254882933572, 0.10777049246826209, 0.4254885809496045, 0.46131703653372824, 0.7554770645219833, 1.1653559049591422, 0.1265621985658072, 0.4556949116522446, 0.6161934009287506, 0.702646718127653, 0.7942227541934699, 0.7840958819724619, 0.5124955996870995, 0.5572424735873938, 0.06579176260856912, 0.26971392100676894, 0.92947798082605, 0.3140176140004769, 0.22764018882298842, 0.10629901400534436, 0.24492354656103998, 0.9806475788354874, 0.6172503379639238, 2.928727283142507, 4.473620597273111, 11.60687617957592, 24.074335880577564, 41.62554658949375, 44.07540813088417, 74.22954127192497, 61.96563854813576, 50.614576041698456, 29.544927030801773, 30.22158522158861, 40.869903936982155, 66.47959113121033, 67.88994625210762, 72.8222867846489, 46.67220398783684, 19.220187552273273, 1.6108493437059224, 0.07747076990199275, 0.16916230641072616, 0.06347374597680755, 0.00872316019012942, 0.11635981281870045, 0.11646627390291542, 0.016893709798750933, 0.06718400196405128, 0.036636650693253614, 0.09798717524972744, 0.05419321154477075, 0.07621941243996844, 0.07516007084632292, 0.010001103237300413, 0.03883361932821572, 0.07605053673614748, 0.052388772237463854, 0.030921289799152873, 0.048508282416150905, 0.028566481196321547, 0.018633530307852197, 0.06298528664046898, 0.04923966895148624, 0.020280495155020617, 0.10583921641227789, 0.037608726852340624, 0.03572910798538942, 0.04409858192957472, 0.009620412092772312, 0.0790719832002651, 0.11736125205061398, 0.02054780190519523, 0.10177351621678099, 0.0892883435881231, 0.04127921856706962, 0.08801161209703423, 0.03568971478671301, 0.009321257930423599, 0.03399536195502151, 0.01801229333068477, 0.02524932599044405, 0.009544749209453585, 0.0374297505186405, 0.11697668596752919, 0.057779506605584174, 0.027265407261438668, 0.07771480290102772, 0.12558226677356288, 0.19044622604269534, 0.1718942855950445, 0.27656771417241544, 0.10273424122715369, 0.1799559686332941, 0.08650339732412249, 0.16795042378362268, 0.13613296468975022, 0.23025268223136663, 0.1052154932403937, 0.222313572303392, 0.19896971789421514, 0.22259149176534265, 0.11419063390349038, 0.09983108568121679, 0.11301294201985002, 0.0894545104529243, 0.062478518520947546, 0.29589454585220665, 0.15299515362130478, 0.17024697008309886, 0.12120496103307232, 0.13375767652178183, 0.12182679172838107, 0.06964828105992638, 0.09286159169278108, 0.08663995991810225, 0.1966601246385835, 0.17091822781367227, 0.12602032686118037, 0.14269665232859552, 0.19934420561185107, 0.22535125695867464, 0.13924562110332772, 0.2119342956575565, 0.06868530734209344, 0.28034031798597425, 0.24483037734171376, 0.15207929885946214, 0.14532210363540798, 0.2163300957181491, 0.1013961415446829, 0.2966911671683192, 0.2176116660120897, 0.13172303413739428, 0.12659543193876743, 0.21695585979614407, 0.1937855195137672, 0.14506560255540535, 0.1793006670777686, 0.170610741188284, 0.16684328787960112, 0.27488954016007483, 0.16326171287801117, 0.9492639941163361, 1.730195595882833, 22.346228510141373, 83.55458289384842, 99.98739391565323, 88.02710250020027, 96.04245319962502, 84.00273844599724, 80.29518619179726, 48.68942454457283, 43.455023020505905, 46.66590012609959, 55.409861728549004, 97.53923088312149, 123.91641229391098, 108.43031287193298, 97.52688154578209, 84.22997385263443, 65.80382779240608, 54.07510355114937, 37.713223323225975, 21.988198421895504, 9.588945060968399, 3.0702340649440885, 0.7696790993213654, 0.32022217637859285, 0.6505735998507589, 0.7984144636429846, 1.3355386792682111, 0.598760589491576, 0.4421218321658671, 0.31104866706300527, 0.302029435406439, 1.3587949750944972, 3.0850029224529862, 4.4615657441318035, 5.272942380979657, 12.633590586483479, 11.10348204150796, 6.188876582309604, 5.359600055962801, 4.610670218244195, 2.7467208495363593, 1.6647166782058775, 1.63287058705464, 2.068033805117011, 2.481377525255084, 1.535707307048142, 2.884569615125656, 3.271842934191227, 2.7832625387236476, 0.9572245669551194, 0.2060252713272348, 0.5105695780366659, 1.9423909345641732, 6.176816504448652, 13.905274998396635, 33.165114372968674, 46.937919929623604, 69.73199620842934, 67.21165984869003, 74.39156457781792, 86.04456648230553, 55.55043138563633, 29.10746220499277, 25.777721777558327, 69.27543550729752, 93.4005081653595, 93.56396019458771, 76.87343180179596, 84.98863354325294, 57.21667617559433, 18.23832593858242, 0.8080366754438728, 0.3405986720463261, 0.19274358870461583, 0.24416192492935807, 0.11995793771347962, 0.2604242804227397, 0.26838111283723265, 0.14348519907798618, 0.17401181103195995, 0.24387505516642705, 0.12619729939615354, 0.11238718536333181, 0.271618093829602, 0.08926917391363531, 0.14598828507587314, 0.2936462836805731, 0.2258003898896277, 0.172063970239833, 0.16122284025186673, 0.14690047362819314, 0.1326619103201665, 0.23610748525243253, 0.261464593349956, 0.16287857171846554, 0.14475989708444104, 0.32086736988276243, 0.1058489311253652, 0.22228137793717906, 0.09444868192076683, 0.16078501765150577, 0.21975700714392588, 0.15111162734683603, 0.13650240580318496, 0.200062797521241, 0.19251963822171092, 0.09075812995433807, 0.213607007462997, 0.12346973599051125, 0.1446506826323457, 0.17853488941909745, 0.14825694146566093, 0.18289895524503663, 0.1317028031917289, 0.19721366290468723, 0.21961390622891486, 0.15608174580847844, 0.14353097474668175, 0.2914583432720974, 0.355639808694832], [0.04524619085714221, 0.08389150505536236, 0.08866634962032549, 0.14962135028326884, 0.14563310804078355, 0.07235081182443537, 0.06293441983871162, 0.06980203179409727, 0.07734406302915886, 0.03922187759599183, 0.09303080878453329, 0.1253377291141078, 0.016494502997375093, 0.17084577935747802, 0.014551789518009173, 0.06944473963812925, 0.15253520017722622, 0.09046043967828155, 0.19316273886943236, 0.06768057297449559, 0.08887757227057591, 0.07924818390165456, 0.05109943165734876, 0.16445930174086243, 0.1830923737725243, 0.08056391525315121, 0.0627890627947636, 0.02176553080062149, 0.013499380511348136, 0.18737533770035952, 0.10418716599815525, 0.07335326779866591, 0.059502751246327534, 0.05205993773415685, 0.09162417176412418, 0.13475098181515932, 0.09224387249560095, 0.1143422992026899, 0.053141985335969366, 0.11976500158198178, 0.0851840442919638, 0.07360685965977609, 0.13064692000625655, 0.17617373174289241, 0.040285104332724586, 0.013495609473466175, 0.05856722214957699, 0.02078801469906466, 0.0648463109973818, 0.028265616383578163, 0.08340120519278571, 0.06333906843792647, 0.13147551304427907, 0.03390383659279905, 0.3249646187759936, 0.12344627670245245, 0.5367213184945285, 0.9826380189042538, 27.277218215167522, 74.29147034883499, 68.12853544950485, 66.60643592476845, 58.30439440906048, 55.988183096051216, 36.74887306988239, 25.838433019816875, 38.891266509890556, 23.887634798884392, 25.310039073228836, 40.11519603431225, 39.58466850221157, 44.31271679699421, 44.38287243247032, 42.597606629133224, 33.593773171305656, 32.71146811544895, 22.580375745892525, 12.293837517499924, 10.381603427231312, 5.410653641447425, 5.878149205818772, 7.870323406532407, 4.724468886852264, 4.661237904801965, 3.656034618616104, 2.015006225556135, 0.7133354851976037, 0.3629423934035003, 0.16934977291384712, 0.25605157599784434, 0.33205144631210715, 0.6889859167858958, 0.26823274267371744, 0.31545776640996337, 0.2877035510027781, 0.023667792593187187, 0.2569972205674276, 0.2563436556374654, 0.43176005536224693, 0.11967940969043411, 0.24183670204365626, 0.5359966261312366, 0.5279899807646871, 1.051823222078383, 3.368502859957516, 10.38252392783761, 25.759402960538864, 44.06045973300934, 45.75296111404896, 49.6590831130743, 41.458735540509224, 44.74347688257694, 32.87007160484791, 38.68591792881489, 40.17207518219948, 22.999717444181442, 40.907841101288795, 31.34060237556696, 40.940177366137505, 85.0332735478878, 73.17865446209908, 65.29232203960419, 65.44055208563805, 53.84669780731201, 14.340307004749775, 0.6778249656781554, 0.6005172827281058, 0.08037750259973109, 0.07082603973685764, 0.06397828023182228, 0.1954780169762671, 0.12734563933918253, 0.1383965596323833, 0.037094900908414274, 0.14940845780074596, 0.16257184208370745, 0.07328389183385298, 0.1252713068970479, 0.08248194397310726, 0.1317654552985914, 0.09145325515419245, 0.05865120358066633, 0.10478189346031286, 0.0928531980025582, 0.010089806582982419, 0.049673840185278095, 0.05161577348189894, 0.18782982893753797, 0.2582610386889428, 0.11354000045685098, 0.044040301072527654, 0.07770427924697287, 0.0698580194148235, 0.11818066472187638, 0.08726303742150776, 0.1031306000368204, 0.05203774380788673, 0.13096721610054374, 0.038659897400066257, 0.054951664205873385, 0.07079069866449572, 0.10489531588973477, 0.039965123651199974, 0.10319181979866698, 0.09725693904329091, 0.051123915109201334, 0.04312327000661753, 0.02576797218353022, 0.0741443972219713, 0.059744765603682026, 0.1378510959330015, 0.16496330907102674, 0.13523832050850615, 0.08091409763437696, 0.056512252340326086, 0.12092923090676777, 0.08528403384843841, 0.014461074024438858, 0.03435815713601187, 0.0767562301189173, 0.10507751314435154, 0.02533206803491339, 0.09497039689449593, 0.10027891985373572, 0.025980857244576328, 0.04056235957250465, 0.03411525962292217, 0.03293512978416402, 0.11342714205966331, 0.03317916278319899, 0.107036174449604, 0.06555328829563223, 0.20844318845774978, 0.021874511476198677, 0.22232955816434696, 0.06726947511197068, 0.05861485689820256, 0.1497810159344226, 0.013653995847562328, 0.0657873394084163, 0.0814243390050251, 0.04477605143620167, 0.03759850005735643, 0.11465106974355876, 0.03064124222873943, 0.010669216117094038, 0.057210676386603154, 0.05409800141933374, 0.02540841462177923, 0.08339387277374044, 0.04457747498236131, 0.12465492356568575, 0.07109697558917105, 0.07406031189020723, 0.10266698780469596, 0.07382739626336843, 0.08291688704048283, 0.08444070175755769, 0.06481432443251833, 0.07477610590285622, 0.08671831586980261, 0.023461859600502066, 0.12372949509881437, 0.0616602895752294, 0.10811119762365706, 0.036057126126252115, 0.126797370321583, 0.1523073756834492, 0.11534669960383326, 0.0116751202949672, 0.10890865756664425, 0.3307274548569694, 0.6576364114880562, 2.0671686390414834, 38.722281977534294, 86.53792440891266, 81.18204340338707, 80.38018003106117, 65.64664542675018, 54.63332399725914, 22.327313125133514, 18.85509744286537, 23.711852431297302, 46.352834925055504, 66.98033586144447, 80.48016026616096, 81.55787363648415, 79.69815462827682, 72.72399365901947, 56.17799811065197, 42.606577947735786, 26.927087903022766, 15.492313038557768, 12.652314081788063, 6.980972103774548, 3.7064624251797795, 2.5575909856706858, 4.624501476064324, 2.865889105014503, 3.3800739515572786, 1.982784429565072, 0.5281574092805386, 0.24153199105057865, 0.36893891694489866, 0.19890274648787454, 0.2374908039928414, 0.06792371539631858, 0.41480221843812615, 0.4603981686523184, 0.3577658243011683, 0.06500667426735163, 0.1926689880201593, 0.29464295832440257, 0.15421991993207484, 0.18131688935682178, 0.15599114442011341, 0.06341327578411438, 0.30439979571383446, 0.7572315016295761, 1.4663059310987592, 1.8756351666525006, 1.794036088977009, 1.6896219667978585, 5.6441449373960495, 17.28411164134741, 24.574503041803837, 34.761541709303856, 45.64904808998108, 49.87043537199497, 57.7373356372118, 63.14556263387203, 44.48827877640724, 79.2020532488823, 29.73792627453804, 18.332218900322914, 38.94767068326473, 62.35012471675873, 74.32055398821831, 79.89542484283447, 67.34902247786522, 24.535526633262634, 1.5448962827213109, 0.6933383457362652, 0.2079806078108959, 0.04688966946559958, 0.0746702533797361, 0.11521526525029913, 0.12413883407134563, 0.14482876838883385, 0.06789645631215535, 0.13539201929233968, 0.057904076093109325, 0.04804855532711372, 0.031864874908933416, 0.04057685371662956, 0.027093110256828368, 0.06329269162961282, 0.08521629802999087, 0.04793492138560396, 0.03614419489167631, 0.050786872452590615, 0.07048069615848362, 0.08310216420795768, 0.1485392841277644, 0.1502423349302262, 0.030898659861122724, 0.07037223127554171, 0.06379876955179498, 0.07480807762476616, 0.061176583694759756, 0.04025818663649261, 0.05328628481947817, 0.028949447951163165, 0.08385803419514559, 0.02623792792292079, 0.07720696608885191, 0.08645577370771207, 0.04952563700499013, 0.07012319620116614, 0.1043985816068016, 0.04743416837300174, 0.07421328336931765, 0.08006361123989336, 0.10453246504766867, 0.03793519761529751, 0.0338835536967963, 0.08412798299104907, 0.14462987281149253, 0.13080009928671643, 0.06854818071587943, 0.039854647548054345, 0.041234997697756626, 0.21029637573519722, 0.19924900290789083, 0.17208176694111899, 0.23667187371756881, 0.24177918559871614, 0.22389188292436302, 0.1746373376226984, 0.23563012102385983, 0.13929785345681012, 0.08920498556108214, 0.22414743405533955, 0.22157512052217498, 0.2294771230663173, 0.27732550632208586, 0.17265197384404019, 0.18957243621116504, 0.20802782324608415, 0.138674731424544, 0.3666033485205844, 0.22949532052734867, 0.2333369292318821, 0.3966427850537002, 0.2050687320297584, 0.15740348113467917, 0.19735899026272818, 0.09560403515934013, 0.20436501275980845, 0.1741762412711978, 0.1264180734870024, 0.3678508393932134, 0.17074385279556736, 0.22198211430804804, 0.18375108920736238, 0.12654649472096935, 0.12403485918184742, 0.21685610030544922, 0.15384911326691508, 0.1738155129714869, 0.24219820217695087, 0.3456792369252071, 0.30489486758597195, 0.21815138548845425, 0.13939038442913443, 0.36015788500662893, 0.09952866050298326, 0.21947320987237617, 0.16094544029328972, 0.15752655890537426, 0.3592915611807257, 0.12803291261661798, 0.2983176877023652, 0.2351765797357075, 0.2564871869981289, 0.1055932612507604, 0.5363025097176433, 0.238745107781142, 1.249544306192547, 2.591638108715415, 44.25494849681854, 99.7518901526928, 91.28533646464348, 91.0520213842392, 78.05121660232544, 80.82796320319176, 58.680593222379684, 48.87246452271938, 51.55146136879921, 41.05142779648304, 46.776854172348976, 64.73962649703026, 66.48015350103378, 73.05229604244232, 81.30470082163811, 82.97079741954803, 80.41532814502716, 83.65979164838791, 78.74574333429337, 65.25291815400124, 53.043702095746994, 41.6954742372036, 33.42000849545002, 27.21400860697031, 17.842896357178688, 11.941354181617498, 7.428136859089136, 3.928989884443581, 1.1496166745200753, 1.0042817168869078, 0.37674684484954923, 0.2887888380791992, 0.5248968279920518, 0.9389230271335691, 0.44699115213006735, 0.6835080950986594, 0.7047912874259055, 0.37103405920788646, 0.6282977701630443, 0.5600083689205348, 0.9119423374067992, 0.6238059361930937, 0.8475044451188296, 1.3976499089039862, 2.72450961638242, 5.384858725592494, 10.858392342925072, 23.525514230132103, 36.893949285149574, 62.98765450716019, 68.50224539637566, 82.92754054069519, 74.20196995139122, 67.87173762917519, 52.50822722911835, 49.95808146893978, 61.23636268079281, 31.783067733049393, 61.617064252495766, 40.561052709817886, 62.91570536792278, 112.79420390725136, 89.51170563697815, 84.12660419940948, 88.50534483790398, 85.3410342335701, 29.562653079628944, 1.5872250613756478, 0.9654676308855414, 0.3094432532088831, 0.23589214368257672, 0.11108197024441324, 0.2288483310258016, 0.15517650375841185, 0.29080382839310914, 0.22587929503060877, 0.23375158198177814, 0.37533608148805797, 0.17774996435036883, 0.2511951100314036, 0.17323172476608306, 0.21216255059698597, 0.20595390640664846, 0.1387468830216676, 0.14233565685572103, 0.17232462734682485, 0.09934503832482733, 0.17819670756580308, 0.14759546524146572, 0.313846860663034, 0.47028752393089235, 0.23373382980935276, 0.2665301371598616, 0.19211769104003906, 0.23008952848613262, 0.24550757225370035, 0.24611487169750035, 0.14691543532535434, 0.24639443872729316, 0.23803913238225505, 0.20821125246584415, 0.2227747131837532, 0.1617433232604526, 0.16731159790651873, 0.13797794381389394, 0.14056576823350042, 0.13352672016480938, 0.14959840307710692, 0.1868476707022637, 0.19090687710558996, 0.16565703903324902, 0.12679861712967977, 0.20836573792621493, 0.27002449496649206, 0.19823223090497777, 0.18187431647675112, 0.21852217731066048, 0.19508932455210015], [0.026845950960705522, 0.1121447331388481, 0.1437784661538899, 0.05164667280041613, 0.08635467835119925, 0.06649352260865271, 0.08448500055237673, 0.077129263227107, 0.07115476662875153, 0.0839272394659929, 0.035617960238596424, 0.03739742256584577, 0.07614311223733239, 0.08723015285795555, 0.004413928872963879, 0.14235864859074354, 0.17424011050025, 0.02176137477363227, 0.07181553039117716, 0.059891814744332805, 0.07460121880285442, 0.100871814211132, 0.07049587307847105, 0.2007012374815531, 0.1845904582296498, 0.08885131508577615, 0.15944539656629786, 0.09475307379034348, 0.03383656090591103, 0.1959127077134326, 0.04894514764600899, 0.09340782722574659, 0.08603530994150788, 0.05897726987313945, 0.03808285160630476, 0.06804634045693092, 0.14656914921943098, 0.08027504169149324, 0.04268127653631382, 0.08800107360002585, 0.12020297261187807, 0.09924489291734062, 0.024260054269689135, 0.09529833710985258, 0.01759583901730366, 0.023784808872733265, 0.029253567081468645, 0.06757684299373068, 0.07275850322912447, 0.06335768892313354, 0.17180745431687683, 0.017361168211209588, 0.04730089349322952, 0.12117282603867352, 0.13114770641550422, 0.06646773297688924, 0.6497263046912849, 0.07500030871597119, 0.11537107173353434, 2.446374516002834, 40.5985376983881, 66.79842442274094, 66.2675017118454, 59.30005118250847, 62.80041575431824, 72.90738701820374, 68.13691020011902, 52.6537062227726, 36.808043494820595, 28.802190385758877, 32.510519698262215, 22.245095036923885, 16.56769048422575, 16.726955138146877, 24.625196121633053, 19.719262272119522, 17.819407917559147, 14.007050637155771, 17.588152326643467, 13.629281558096409, 21.069417223334312, 26.88754342496395, 31.42459686845541, 40.0227127969265, 45.48672839999199, 42.7431920170784, 42.89648339152336, 26.409430280327797, 19.577651470899582, 15.15000555664301, 12.810988817363977, 14.830595646053553, 14.421001374721527, 11.87666930258274, 13.599396161735058, 13.681982830166817, 14.32574713602662, 14.537639915943146, 10.374778043478727, 12.113376650959253, 14.549538977444172, 19.723430648446083, 24.26188051700592, 36.67001970112324, 52.73927003145218, 70.3620707988739, 78.73552948236465, 70.55224299430847, 70.28625726699829, 38.17327603697777, 38.672375455498695, 21.362347304821014, 18.62459611147642, 23.761069290339947, 22.548983730375767, 35.034610256552696, 47.08208419382572, 71.93618193268776, 77.49586120247841, 71.47699177265167, 74.96830523014069, 54.59651917219162, 16.522552706301212, 1.2015050277113914, 0.4916937940288335, 0.07867342021199875, 0.19367927365237847, 0.11108640086604282, 0.07725787741946988, 0.12018018125672825, 0.026395747481728904, 0.12374565165373497, 0.07949238759465516, 0.061239458445925266, 0.14313932857476175, 0.2600463788257912, 0.2552416257094592, 0.13209977798396721, 0.11622698322753422, 0.06025602742738556, 0.02629965605592588, 0.05548423680011183, 0.044496718182927, 0.0928657031909097, 0.08280739057227038, 0.048424464257550426, 0.018446670510456897, 0.05558467535593081, 0.09888986431178637, 0.0544063081179047, 0.10448355009430088, 0.08782826451351866, 0.1242179395921994, 0.19840176712023094, 0.03887857492372859, 0.038842487992951646, 0.14393771620234475, 0.05027673869335558, 0.08006540723727085, 0.09281823542551138, 0.062189901000238024, 0.018769896232697647, 0.045914520815131254, 0.06010413577314466, 0.1180446810030844, 0.013315780597622506, 0.06021739493007772, 0.026376559253549203, 0.10905759918387048, 0.04695263327448629, 0.020185644971206784, 0.06949831527890638, 0.10822542157256976, 0.04477976959606167, 0.08041226479690522, 0.08692017261637375, 0.03416451967495959, 0.04369322457932867, 0.09675355511717498, 0.04228036465065088, 0.06608918571146205, 0.00886076550159487, 0.03685882744321134, 0.06670182861853391, 0.027401300067140255, 0.10614926344715059, 0.06141944781120401, 0.0454481032647891, 0.0458185017487267, 0.06262711875024252, 0.06241336537641473, 0.07039261807221919, 0.06384649706888013, 0.024872721296560485, 0.10532519008847885, 0.00755334202949598, 0.028560119135363493, 0.05492062016855925, 0.07533424548455514, 0.06416753531084396, 0.11181641442817636, 0.08119382051518187, 0.12558676418848336, 0.06433573566027917, 0.055332233823719434, 0.08939902749261819, 0.0918283811188303, 0.08845134201692417, 0.034314337026444264, 0.019754880195250735, 0.05196749210881535, 0.06967746972804889, 0.11299910096568055, 0.16996550315525383, 0.05628339997201692, 0.06159693613881245, 0.0775298522785306, 0.048799193173181266, 0.04730248539999593, 0.073450318450341, 0.06981219179579057, 0.033353875478496775, 0.21780517359729856, 0.08086592482868582, 0.05116743835969828, 0.04711996531113982, 0.07128138444386423, 0.1091944363724906, 0.084678240964422, 0.11378729890566319, 0.15056653472129256, 0.01463709753807052, 0.17187322344398126, 0.2602789975935593, 0.15161901887040585, 5.609048595651984, 50.74629597365856, 84.93998095393181, 83.5616885125637, 75.79223021864891, 61.11837141215801, 50.093616396188736, 42.374524399638176, 25.434917472302914, 16.762447133660316, 24.59332723170519, 25.881942585110664, 28.19341365247965, 29.51869323849678, 28.55398390442133, 35.52660785615444, 35.13752393424511, 19.28731855005026, 18.47323313355446, 12.074441090226173, 15.729458313435316, 13.929956573992968, 17.480308413505554, 17.116020061075687, 17.801577374339104, 19.10111904144287, 11.541860718280077, 8.914719689637423, 4.707925524562597, 2.3821703111752868, 0.5997110728640109, 0.8117673033848405, 1.7235021363012493, 2.0114059187471867, 1.4852789067663252, 1.0985221224837005, 1.7358635854907334, 2.0303476648405194, 0.8489725913386792, 1.4503699424676597, 3.201925023458898, 3.906862959265709, 3.3458178397268057, 4.57573251798749, 12.141155060380697, 26.11789282411337, 43.2813723385334, 65.31459644436836, 80.59057474136353, 73.79670649766922, 65.25002270936966, 59.10202480852604, 43.429271802306175, 38.97169679403305, 41.03301778435707, 36.71043813228607, 20.209557563066483, 36.60265691578388, 35.0784333050251, 55.6118892878294, 75.64767077565193, 82.54768252372742, 72.72343888878822, 31.183372512459755, 3.820522092282772, 0.23060337669448927, 0.20465259498450905, 0.061185912491055205, 0.05314272748364601, 0.03440366934228223, 0.023408150373143144, 0.04962160412105732, 0.06249405909329653, 0.09948329301550984, 0.0696933368453756, 0.14420192077523097, 0.16857032489497215, 0.10495096954400651, 0.0895919710455928, 0.09185378483380191, 0.05507777364982758, 0.030485439456242602, 0.07814356387825683, 0.044228045881027356, 0.10752603644505143, 0.00811254705695319, 0.0837487232638523, 0.0801182036229875, 0.07466931827366352, 0.1549044472631067, 0.09955203073332086, 0.07010860557784326, 0.03289166219474282, 0.04764455239637755, 0.07910076368716545, 0.029259559923957568, 0.010323882743250579, 0.06508277409011498, 0.022770870018575806, 0.016286252648569643, 0.05144725029822439, 0.047197946478263475, 0.022779786922910716, 0.04736659953778144, 0.06065178880817257, 0.0070086900541355135, 0.018390129989711568, 0.0033267861954300315, 0.04034340374346357, 0.05835703850607388, 0.06209709543327335, 0.028205224116391037, 0.07140199086279608, 0.08517294918419793, 0.1146893274562899, 0.041384525611647405, 0.09739299697685055, 0.09832894167630002, 0.11798770632594824, 0.20918532129144296, 0.16719926643418148, 0.2562856790609658, 0.11422023075283505, 0.13676692207809538, 0.15623688435880467, 0.06842243863502517, 0.19258420506957918, 0.136362035991624, 0.07421877526212484, 0.17307452304521576, 0.2995906490832567, 0.16133416240336373, 0.19104154722299427, 0.20966115669580176, 0.0910831535293255, 0.22558927856152877, 0.15217885054880753, 0.15931816276861355, 0.14641356538049877, 0.1501734636258334, 0.35151545656844974, 0.2560693578561768, 0.23923636501422152, 0.2678725041914731, 0.19408800406381488, 0.1237210791441612, 0.2945281926076859, 0.2307510343962349, 0.27152125840075314, 0.1647406944539398, 0.13424661825411022, 0.22743694426026195, 0.18088547891238704, 0.23887241579359397, 0.34975837741512805, 0.11328093896736391, 0.13974498258903623, 0.17054253781680018, 0.12414767305017449, 0.15778258501086384, 0.34613829979207367, 0.12404228065861389, 0.15371240966487676, 0.34990057290997356, 0.15146258898312226, 0.22327978920657188, 0.20982527523301542, 0.3765095950802788, 0.23129234206862748, 0.31295856926590204, 0.21758337534265593, 0.265877255005762, 0.14287212572526187, 0.7469823234714568, 0.3019080200465396, 0.45733654231298715, 6.64399953559041, 58.41171585023403, 99.74149391055107, 96.92849725484848, 89.37302067875862, 87.155292481184, 98.07718321681023, 102.17543050646782, 78.69856506586075, 56.20954021811485, 52.708601877093315, 54.50395993888378, 40.85384599864483, 32.85406306385994, 31.483239121735096, 51.100170984864235, 50.888921320438385, 43.42185840010643, 45.05359724164009, 45.73130987584591, 40.08032910525799, 53.38120378553867, 67.00152352452278, 71.01307466626167, 79.29599180817604, 78.2961818575859, 71.50751173496246, 65.50956398248672, 42.98406109213829, 32.10847467184067, 23.08075189590454, 18.73480349779129, 20.487729236483574, 20.126579515635967, 20.411309637129307, 24.504791982471943, 28.98600932210684, 36.16239354014397, 41.729258224368095, 43.03425259888172, 48.2385141402483, 54.77163277566433, 63.06729443371296, 78.86892512440681, 91.45005002617836, 102.56330609321594, 110.47141134738922, 109.54599380493164, 93.62684682011604, 88.96760523319244, 50.757170990109444, 54.418760910630226, 30.24737823754549, 27.105366736650467, 37.72854410111904, 41.56104505062103, 63.49134407937527, 79.73799169063568, 94.14959236979485, 99.59451019763947, 82.57031410932541, 88.56180220842361, 82.8872399032116, 35.50227016210556, 2.6235067611560225, 0.3708635730436072, 0.17579991195816547, 0.3364882426103577, 0.18897675879998133, 0.26410524384118617, 0.17965415201615542, 0.19766002020332962, 0.15914338699076325, 0.25574925472028553, 0.21974891773425043, 0.29531973763369024, 0.5302879668306559, 0.2478492262889631, 0.1709858819958754, 0.25998020893894136, 0.12383947396301664, 0.16153194475919008, 0.3722204564837739, 0.16272233478957787, 0.1590877556009218, 0.17084839171729982, 0.24502827844116837, 0.18529373221099377, 0.1345262594986707, 0.22651582024991512, 0.09487863033427857, 0.19843765738187358, 0.15844987967284396, 0.18807648913934827, 0.2185999692301266, 0.11844485445180908, 0.10940801163087599, 0.12099665502319112, 0.23960197664564475, 0.1601181979640387, 0.25081489293370396, 0.1277680549537763, 0.09677090652985498, 0.14204820821760222, 0.24260660604340956, 0.11435098233050667, 0.09480622640694492, 0.060585604078369215, 0.13160863949451596, 0.19889244547812268, 0.16512848145794123, 0.16127594833960757, 0.19052887160796672, 0.21482637093868107, 0.22655058244708925, 0.0996388249041047, 0.25623387715313584], [0.013646945444634184, 0.038822535352665, 0.09885618565022014, 0.006148667525849305, 0.11058432311983779, 0.10026974690845236, 0.09401487433933653, 0.005097862022012123, 0.02932396535470616, 0.059052052383776754, 0.04908408140181564, 0.06601477798540145, 0.08693025840329938, 0.05636333298753016, 0.1048473731498234, 0.09098383190575987, 0.08448162378044799, 0.0774206081405282, 0.04225662334647495, 0.039776347257429734, 0.12870688660768792, 0.0839236548927147, 0.040836386469891295, 0.0331811740034027, 0.11286577413557097, 0.09344489008071832, 0.038916999619686976, 0.06728253691107966, 0.010104889806825668, 0.0744521213346161, 0.1544629139243625, 0.09702408278826624, 0.044705859108944423, 0.10266966695780866, 0.07858223994844593, 0.050685643509496, 0.12117054022382945, 0.07326025443035178, 0.021937681231065653, 0.09744640192366205, 0.05485720364958979, 0.06821010276325978, 0.10575064850854687, 0.017555345584696624, 0.016912131759454496, 0.05087609344627708, 0.0906259089242667, 0.03826769461738877, 0.11485320108477026, 0.10075488142319955, 0.12478324089897797, 0.048585020485916175, 0.13569618109613657, 0.05823517785756849, 0.0948936291388236, 0.023215407200041227, 0.16769663896411657, 0.057327397662447765, 0.10621372639434412, 0.11733777791960165, 0.13512772566173226, 3.488303543999791, 21.09527863562107, 72.79588580131531, 84.65765610337257, 66.66784062981606, 71.81369170546532, 74.02398750185966, 79.07984420657158, 67.73181393742561, 71.0322180390358, 68.64275425672531, 66.257553845644, 65.25849625468254, 37.56581023335457, 20.99201537668705, 20.516096614301205, 11.02754881605506, 14.975119940936565, 15.7949591986835, 7.163616428151727, 2.9416302032768726, 13.891154956072569, 21.05107370764017, 27.428395003080368, 30.457638055086136, 52.90954649448395, 51.97590999305248, 55.073997750878334, 60.46847328543663, 64.1711238026619, 44.36556056141853, 42.356969341635704, 49.691936150193214, 53.15209127962589, 42.844213396310806, 30.635888390243053, 22.173284590244293, 21.742288917303085, 27.511716932058334, 31.34688913822174, 34.68953177332878, 21.901905052363873, 28.63713674247265, 30.05019921809435, 25.19453477114439, 23.94623525440693, 39.61344435811043, 26.151222735643387, 26.453591510653496, 36.62611685693264, 37.07477018237114, 66.96050092577934, 64.54369381070137, 72.84242570400238, 75.00074788928032, 72.22995176911354, 79.87522512674332, 78.17480117082596, 60.2699339389801, 26.868270859122276, 2.089268253184855, 0.23343309672782198, 0.16612764971796423, 0.14993174612754956, 0.04803555289981887, 0.2703717607073486, 0.02957408025395125, 0.10836694913450629, 0.02642649651534157, 0.11016309494152665, 0.04524944146396592, 0.15688284969655797, 0.06735528964782134, 0.16372853860957548, 0.09038186108227819, 0.09407131467014551, 0.030347414831339847, 0.10724580148234963, 0.03504842869006097, 0.07103569645551033, 0.006551026599481702, 0.04179859948635567, 0.07830956747056916, 0.08969665839686058, 0.19584998139180243, 0.05229281625361182, 0.035594263463281095, 0.10170889741857536, 0.015056095562613336, 0.06680106860585511, 0.08830623730318621, 0.03148597512335982, 0.036365217601996846, 0.07012779751676135, 0.03449411487963516, 0.0508480922144372, 0.06961391962249763, 0.020990593184251338, 0.03376531843969133, 0.12180584089946933, 0.10636148057528771, 0.02481583196640713, 0.07842960985726677, 0.034523541035014205, 0.12413173171808012, 0.04948982095811516, 0.06819103698944673, 0.052323934505693614, 0.08808544836938381, 0.040922534972196445, 0.10566622178885154, 0.10739410485257395, 0.11009400841430761, 0.02309518113179365, 0.033087177289417014, 0.0758835460874252, 0.06538932560943067, 0.05297724710544571, 0.05050689724157564, 0.045052542263874784, 0.030276608376880176, 0.0177664012517198, 0.07027394123724662, 0.027456862808321603, 0.04008566327684093, 0.043927231163252145, 0.13001107756281272, 0.1149768206232693, 0.0422900979174301, 0.0865873639122583, 0.08013884274987504, 0.029643513735209126, 0.017078333876270335, 0.046553814245271496, 0.0627180615265388, 0.012074894839315675, 0.052797595417359844, 0.07006708241533488, 0.04331039512180723, 0.04560790992400143, 0.03984073227911722, 0.05353603235562332, 0.10306589960237034, 0.040002019522944465, 0.037619814538629726, 0.1281037283479236, 0.03453740064287558, 0.048208695952780545, 0.13372189016081393, 0.08160969780874439, 0.055683874525129795, 0.09816688630962744, 0.038945494379731826, 0.07099567985278554, 0.03338858572533354, 0.07203335073427297, 0.0746751886617858, 0.08744378748815507, 0.2069630491314456, 0.059475429079611786, 0.04808377394510899, 0.09127603028900921, 0.06365231412928551, 0.10012069396907464, 0.08261216862592846, 0.11025573723600246, 0.006443313604904688, 0.07763885892927647, 0.06125755942775868, 0.01649491303396644, 0.07658305738004856, 0.21695433097193018, 0.0447085419727955, 0.08767779407207854, 0.27173208771273494, 0.056277251278515905, 7.706346530467272, 34.52689290046692, 88.1127119064331, 99.42482650279999, 80.69227248430252, 72.5887893140316, 68.91108065843582, 58.75281974673271, 41.580503806471825, 43.5058718919754, 35.60852386057377, 24.094212613999844, 23.207178711891174, 26.122631169855595, 31.02732628583908, 16.166126132011414, 12.247342262417078, 14.062665402889252, 6.3437738455832005, 7.621486159041524, 13.620686419308186, 21.953931860625744, 40.606859251856804, 46.638697385787964, 53.04634675383568, 60.333109349012375, 57.59296618402004, 58.64543750882149, 59.842601269483566, 53.197472244501114, 51.52131378650665, 56.73194378614426, 48.6469504237175, 45.114253386855125, 43.91954809427261, 36.11559525132179, 31.284165903925896, 24.697555638849735, 29.458861649036407, 25.59620551764965, 30.8150202780962, 33.51518198847771, 45.845782533288, 56.95814944803715, 55.101284086704254, 54.10610988736153, 67.65963301062584, 57.49600678682327, 47.69537888467312, 48.931676745414734, 27.72080261260271, 22.531120888888836, 29.50358334928751, 25.17993975430727, 39.67470467090607, 60.68061210215092, 79.3433752655983, 91.12838968634605, 76.05543449521065, 43.44820998609066, 5.226859403774142, 0.13036439922871068, 0.35201144870370626, 0.13861841725884005, 0.06257867134991102, 0.1769952743779868, 0.08267275014077313, 0.0633724799263291, 0.034622658567968756, 0.06037894192559179, 0.047022825601743534, 0.08535024084267206, 0.12261195428436622, 0.15747541008749977, 0.09520909385173582, 0.048742927247076295, 0.020517418379313312, 0.07437787688104436, 0.0559977918601362, 0.09338628267869353, 0.03819937992375344, 0.08135603915434331, 0.14157707802951336, 0.08904463713406585, 0.11487923562526703, 0.08506784623023123, 0.04690797082730569, 0.021574852653429843, 0.058413311853655614, 0.08059042476816103, 0.019731170432351064, 0.05807670335343573, 0.04181400276138447, 0.050023217336274683, 0.064246759575326, 0.008144618968799477, 0.035019637070945464, 0.06172697525471449, 0.016444437715108506, 0.02882816617784556, 0.12329647419392131, 0.01492299787059892, 0.08033778285607696, 0.022959258640185, 0.050812072076951154, 0.03447820323344786, 0.09370265281177126, 0.015042028153402498, 0.05984575705952011, 0.07738688495010138, 0.049619032579357736, 0.18930226477095857, 0.11411382161895745, 0.0703389459522441, 0.061345678332145326, 0.15062394726555794, 0.12634725775569677, 0.17586479050805792, 0.1530611899215728, 0.13227663177531213, 0.16165693727089092, 0.1325649709906429, 0.16842256329255179, 0.09729761615744792, 0.09657321323174983, 0.128185928624589, 0.22905317862750962, 0.17795067076804116, 0.2371282351668924, 0.1741224800935015, 0.16226662643020973, 0.20730669319164008, 0.16165675915544853, 0.19746672041947022, 0.18571846332633868, 0.17063702805899084, 0.11842885374790058, 0.2103206588071771, 0.10061506822239608, 0.21555256244027987, 0.18502747931052, 0.11629781380179338, 0.15155514964135364, 0.11153472485602833, 0.15995817608200014, 0.2847648540046066, 0.22033278015442193, 0.10308716213330626, 0.18153677287045866, 0.19404782418860123, 0.10667333845049143, 0.15896708238869905, 0.0841713541012723, 0.12248386701685376, 0.30712297302670777, 0.14638245454989374, 0.17726026562741026, 0.16741076367907226, 0.22469882009318098, 0.09060334021341987, 0.1857614633627236, 0.16448643465992063, 0.0720263300172519, 0.3471098007867113, 0.12430195813067257, 0.1508696872042492, 0.08530873252311721, 0.20880574244074523, 0.09182253299513832, 0.21801684895763174, 0.13897288183216006, 0.24515058437827975, 0.1337738850270398, 0.14533034147461876, 0.43768283911049366, 0.30076739843934774, 8.265311736613512, 39.365481063723564, 98.29659104347229, 114.91386696696281, 97.29095220565796, 92.12401986122131, 100.83844184875488, 107.49472707509995, 94.76206630468369, 99.66682031750679, 99.64022934436798, 103.17669957876205, 106.96863770484924, 66.2619236111641, 45.97457282245159, 36.569971069693565, 34.24340531229973, 38.27297888696194, 41.01330824196339, 23.326237723231316, 16.456820033490658, 32.47403785586357, 43.03257688879967, 49.17162626981735, 52.06531919538975, 73.15798357129097, 78.55822339653969, 81.37242078781128, 88.72075527906418, 89.40820679068565, 70.32884538173676, 72.34750986099243, 80.23508861660957, 87.64130160212517, 77.7837185561657, 60.804873034358025, 58.92053134739399, 58.169212862849236, 64.69134628772736, 68.31015810370445, 70.60306146740913, 44.58159796893597, 52.35944241285324, 50.88080495595932, 35.83677761256695, 31.650686636567116, 54.16974127292633, 39.9343067407608, 50.383396446704865, 64.60087314248085, 69.83877807855606, 112.43884697556496, 110.96689715981483, 106.63374647498131, 99.97075840830803, 96.87797516584396, 95.59026226401329, 97.59685099124908, 83.7475137412548, 45.06050147116184, 4.241803111508489, 0.22788815520470962, 0.35385473573114723, 0.3420884592924267, 0.15492366888793185, 0.2881459007039666, 0.12512964574852958, 0.18533020134782419, 0.1623148808721453, 0.1702518534148112, 0.09762216475792229, 0.4200807586312294, 0.17846490489318967, 0.24893944122595713, 0.3977954888250679, 0.24182316527003422, 0.10803448181832209, 0.25756718998309225, 0.14423096843529493, 0.15936197916744277, 0.11243328015552834, 0.21373234136262909, 0.2834520541364327, 0.17275330668780953, 0.2930933242896572, 0.17937430297024548, 0.13798052648780867, 0.1271201451891102, 0.17209085082868114, 0.15157907648244873, 0.14041552785784006, 0.07015250361291692, 0.21129370346898213, 0.13329064298886806, 0.10301397895091213, 0.19077136093983427, 0.14077506872126833, 0.10611683159368113, 0.17625176114961505, 0.2293567467131652, 0.25621054403018206, 0.1246692321728915, 0.2189938715309836, 0.14509010827168822, 0.13687926839338616, 0.09859912795946002, 0.15293126954929903, 0.1825335217290558, 0.11885932166478597, 0.19253011734690517, 0.09896914794808254, 0.22167523624375463, 0.21505798038560897, 0.12055097307893448, 0.06579622291610576], [0.04127271364268381, 0.08934856887208298, 0.04223116397042759, 0.07184062240412459, 0.08703478990355507, 0.05184393565286882, 0.07502497770474292, 0.01866606606199639, 0.04144717771850992, 0.14793177688261494, 0.04774698732944671, 0.04493586551689077, 0.03885086684022099, 0.0694550183834508, 0.11359581738361157, 0.12548207683721557, 0.043637504131766036, 0.12497162766521797, 0.12221529861562885, 0.1376156124752015, 0.09162171525531448, 0.14851813291897997, 0.10427941495436244, 0.05727987052523531, 0.05761094260378741, 0.10658543105819263, 0.029157984026824124, 0.09387368816533126, 0.053721855001640506, 0.010671726431610296, 0.010160335659747943, 0.05439423337520566, 0.035072448299615644, 0.07452615798683837, 0.03562242796760984, 0.04663575477025006, 0.03477497324638534, 0.08302353366161697, 0.04533463630650658, 0.03748843213543296, 0.03678732151456643, 0.03838857934169937, 0.23311167256906629, 0.1215777566540055, 0.02863620040443493, 0.029930702621641103, 0.19155861635226756, 0.13708450191188604, 0.08069451097981073, 0.045239734172355384, 0.03896772541338578, 0.1268329785671085, 0.21603001572657377, 0.1700929892831482, 0.08384728789678775, 0.0870645500253886, 0.052272236498538405, 0.08291073463624343, 0.24692100734682754, 0.035483271567500196, 0.41767106449697167, 0.15054685296490788, 0.07654080691281706, 2.6063991291448474, 17.437845692038536, 36.02645963430405, 58.31152282655239, 68.83548751473427, 73.21131750941277, 70.55157423019409, 65.05352765321732, 68.87716367840767, 71.98505491018295, 60.441954508423805, 60.25375820696354, 52.525117322802544, 41.794660314917564, 48.76493789255619, 39.74658161401749, 35.835721269249916, 50.64183197915554, 32.69860960543156, 38.819807544350624, 28.379628360271454, 39.79181818664074, 25.606951341032982, 42.85033106803894, 35.9921208769083, 23.900852389633656, 29.17697187513113, 56.565387323498726, 74.73252028226852, 61.756702959537506, 42.76626817882061, 30.18427312374115, 19.649439118802547, 27.621683031320572, 11.372797340154648, 45.93428358435631, 77.20693230628967, 26.012807562947273, 20.82794778048992, 33.09535011649132, 35.9982917457819, 41.180514469742775, 50.93774490058422, 57.25861452519894, 61.963989436626434, 76.22267112135887, 69.16757449507713, 64.77681130170822, 65.88611617684364, 71.98390737175941, 81.01710945367813, 82.87913113832474, 79.2385084927082, 66.38064444065094, 43.1024057418108, 16.572721414268017, 1.1454104189760983, 0.3134666435653344, 0.08144913415890187, 0.23238019697600976, 0.11666994148981757, 0.31307867844589055, 0.08426482760114595, 0.07238480218802579, 0.042706175590865314, 0.029740978134213947, 0.039111249352572486, 0.1733507652534172, 0.13238112616818398, 0.2104044472798705, 0.03857373034406919, 0.1437524167704396, 0.11639209624263458, 0.07205219386378303, 0.1958809734787792, 0.1099628783413209, 0.07634928086190484, 0.12774121889378875, 0.06334940655506216, 0.014513975238514831, 0.12404408407746814, 0.0349080625892384, 0.08602820758824237, 0.04848488621064462, 0.279019235749729, 0.04069380876899231, 0.09971850930014625, 0.09985925018554553, 0.0891409011092037, 0.049983835269813426, 0.06417269323719665, 0.03882619414071087, 0.054306671081576496, 0.12469542998587713, 0.03786801840760745, 0.06385725078871474, 0.1056715207232628, 0.05652546627970878, 0.09738285923958756, 0.051382245583226904, 0.06029391035553999, 0.11072518274886534, 0.07547388799139298, 0.06889899392263032, 0.01382646725687664, 0.07337137620197609, 0.17319120350293815, 0.06777260670787655, 0.1056640621391125, 0.3504428453743458, 0.11091673106420785, 0.0694589591876138, 0.036703588702948764, 0.07331621236517094, 0.10864993746508844, 0.029042767455393914, 0.05654932632751297, 0.03809321940934751, 0.15788096410688013, 0.1002597353362944, 0.051742632495006546, 0.08002399539691396, 0.07064067351166159, 0.06726432460709475, 0.03732466240762733, 0.056275369934155606, 0.034595826218719594, 0.033131416712421924, 0.02947716504422715, 0.08326284660142846, 0.08482373159495182, 0.08408050780417398, 0.12904995179269463, 0.04940251470543444, 0.09841701234108768, 0.11710695514921099, 0.09076831964193843, 0.03801687838858925, 0.04677532677305862, 0.054521025595022365, 0.0874017522437498, 0.055632061485084705, 0.04175464950094465, 0.060671088358503766, 0.08307284937473014, 0.1103308648453094, 0.10228476690826938, 0.041019641284947284, 0.03733332698175218, 0.05066307479864918, 0.08564654330257326, 0.0372556612273911, 0.04723653073597234, 0.04526912693108898, 0.11031403293600306, 0.178249622695148, 0.027248985388723668, 0.05746984177676495, 0.045530990028055385, 0.24493329838151112, 0.1251367703662254, 0.1131525103119202, 0.09140373163972981, 0.0026396017437946284, 0.026868686654779594, 0.1037178466503974, 0.06127048392954748, 0.08879708635504358, 0.03746436057554092, 0.053121409291634336, 0.07903775534941815, 0.3157444135285914, 0.027863196082762443, 0.33063958457205445, 0.04138864082051441, 0.10631039855070412, 5.606496082618833, 32.39118330180645, 56.924832835793495, 84.51587811112404, 88.88280138373375, 93.12468856573105, 84.52599316835403, 72.69531279802322, 74.22659263014793, 69.55276742577553, 57.1063756942749, 43.41388262808323, 29.399537332355976, 18.33385281264782, 10.065270401537418, 13.151458147913218, 14.130904041230679, 9.458430614322424, 1.0149985668249428, 13.60267348587513, 27.11627595126629, 28.955116979777813, 30.88599856942892, 50.39159640669823, 48.160477727651596, 46.90609663724899, 53.47841016948223, 73.083066791296, 66.38173878192902, 55.24010583758354, 61.33590213954449, 58.36167633533478, 39.88698787987232, 36.405276507139206, 22.92237639427185, 26.072585955262184, 57.41701662540436, 33.41090798377991, 30.984455086290836, 27.989871874451637, 40.331279039382935, 38.63398611545563, 33.09889532625675, 26.68364066630602, 37.84908503293991, 25.406168214976788, 32.46012680232525, 43.60260710120201, 47.20678590238094, 61.08441263437271, 69.45803090929985, 81.95372119545937, 86.52877449989319, 84.64254811406136, 61.736328452825546, 27.416319251060486, 2.665015021339059, 0.25272176717408, 0.11491936355014332, 0.2832126372959465, 0.13184646813897416, 0.19903870794223621, 0.11243526168982498, 0.035689547803485766, 0.1170940269366838, 0.05360138588002883, 0.03647766039648559, 0.2557807811535895, 0.17886946443468332, 0.2586846862686798, 0.1602261804509908, 0.19066628767177463, 0.09024341343319975, 0.02821574962581508, 0.12414322758559138, 0.09144646450295113, 0.07746550065348856, 0.09996963723096997, 0.043895237176911905, 0.1069570986146573, 0.1816020967089571, 0.14877745416015387, 0.05666608100000303, 0.08468241925584152, 0.250352505245246, 0.08915567726944573, 0.01712068638880737, 0.055389590706909075, 0.07705949392402545, 0.05049507482908666, 0.0705285275762435, 0.08594720959081315, 0.011309598648949759, 0.13202814589021727, 0.025281537054979708, 0.0167440167570021, 0.11238647290156223, 0.06158757023513317, 0.09721059934236109, 0.11638238152954727, 0.09539641934679821, 0.11888987588463351, 0.05224599786743056, 0.058788697569980286, 0.06194691814016551, 0.037272786285029724, 0.11484591319458559, 0.12332393365795724, 0.14680264372145757, 0.1235967842512764, 0.04216171750158537, 0.09986452685552649, 0.047026143001858145, 0.1786245111725293, 0.1192819896095898, 0.12727709457976744, 0.12704750377452, 0.11199519780348055, 0.22786455490859225, 0.2724862581817433, 0.1593380671693012, 0.1414592398214154, 0.1675917734974064, 0.10910949014942162, 0.2366179641103372, 0.1444324615295045, 0.13822960609104484, 0.12174796822364442, 0.14869890525005758, 0.10792804299853742, 0.22646309807896614, 0.2516976330662146, 0.1471280012628995, 0.13164172443794087, 0.3332672326359898, 0.17013322853017598, 0.11059563345042989, 0.12145896107540466, 0.13536102720536292, 0.16200552403461188, 0.16288792277919129, 0.11028393884771504, 0.14818502735579386, 0.19907860580133274, 0.3651185188209638, 0.11181832174770534, 0.13930824352428317, 0.04963237268384546, 0.104284513508901, 0.12241518867085688, 0.1267068283050321, 0.09759247142937966, 0.11647549137705937, 0.1060693415638525, 0.176781298359856, 0.20181045139906928, 0.18852226756280288, 0.10004937357734889, 0.11170228695846163, 0.27345024864189327, 0.2573735488113016, 0.21594716235995293, 0.17028271191520616, 0.1423899523797445, 0.18360781017690897, 0.17365143896313384, 0.23376587574603036, 0.1903123129159212, 0.1589442539261654, 0.23528917838120833, 0.16554049216210842, 0.3492864308645949, 0.13097410323098302, 0.35432700882665813, 0.3434517845744267, 0.19211034377804026, 5.786662939935923, 32.84666486084461, 69.76208299398422, 103.91002982854843, 104.40018072724342, 108.34739372134209, 105.67655503749847, 95.1155461370945, 101.63805574178696, 93.83549362421036, 86.514722853899, 88.29634085297585, 93.16869780421257, 91.3708470761776, 91.19579046964645, 86.9504302740097, 85.81611514091492, 103.30898568034172, 79.16761949658394, 71.53799369931221, 55.544982478022575, 55.93634247779846, 39.522116258740425, 57.93543420732021, 52.139449417591095, 35.235421881079674, 41.62670932710171, 70.20433366298676, 90.4070895910263, 74.75537985563278, 61.888407692313194, 45.33789038658142, 29.729777611792088, 40.63713602721691, 21.13253563642502, 65.30546173453331, 105.4367271065712, 44.85973544418812, 37.550861835479736, 56.53780460357666, 61.93012185394764, 63.44338685274124, 75.62998652458191, 90.06835296750069, 96.07251718640327, 105.5452112853527, 110.575320571661, 87.83731028437614, 86.22335448861122, 84.77886959910393, 93.17868366837502, 98.39617609977722, 99.01241943240166, 93.82556855678558, 68.58217030763626, 26.42391700297594, 1.8729660473763943, 0.48230883199721575, 0.21650046313880011, 0.4013692861190066, 0.2844921889482066, 0.3486582770710811, 0.1640590318129398, 0.3474043443566188, 0.17466314951889217, 0.129462719487492, 0.11158376597450115, 0.4404654772952199, 0.2648171118926257, 0.2502878790255636, 0.19585679430747405, 0.26510322466492653, 0.23943857057020068, 0.1029594978899695, 0.1895619125571102, 0.22824330255389214, 0.11774184022215195, 0.16224437684286386, 0.14380874577909708, 0.1994190289406106, 0.1849201795994304, 0.2890072076115757, 0.10812011823873036, 0.11939436561078764, 0.30253795499447733, 0.1448161667212844, 0.19777460780460387, 0.18885157332988456, 0.1743073045508936, 0.1310381802613847, 0.1887035445543006, 0.10488432468264364, 0.1400823926087469, 0.18030053295660764, 0.16868080099811777, 0.24590289947809651, 0.19539936416549608, 0.10702720930567011, 0.1182505305041559, 0.12183267695945688, 0.11458571621915326, 0.2381787303602323, 0.19483689044136554, 0.18780750513542444, 0.18047370569547638, 0.11532809396157973, 0.23372286086669192, 0.1305421584402211, 0.150242691161111, 0.32298528123646975, 0.2367466822033748, 0.11518614337546751, 0.1565714890602976], [0.1186931251140777, 0.07634552559466101, 0.09685119206551462, 0.1023568665550556, 0.08703680854523554, 0.03222077553800773, 0.02090219782985514, 0.031222631441778503, 0.057981181525974534, 0.10173204500460997, 0.23511057312134653, 0.03289437103376258, 0.10413735304609872, 0.11287785629974678, 0.049920236924663186, 0.03778047095693182, 0.04241402173647657, 0.05444704460387584, 0.009402856139786309, 0.0113734400474641, 0.09410846658283845, 0.1582324897754006, 0.0904261227697134, 0.03333869113703258, 0.05813761141325813, 0.07299838020117022, 0.10386989044491202, 0.06251561848330311, 0.016513064110768028, 0.04043841348902788, 0.04278448330296669, 0.09519057726720348, 0.09414943313458934, 0.018278087954968214, 0.038288712239591405, 0.07488540199119598, 0.11952643078984693, 0.021553844308073167, 0.06945264351088554, 0.073628790123621, 0.027011672536900733, 0.06024015288858209, 0.024689546262379736, 0.03271551715442911, 0.03295475587947294, 0.058977856169804, 0.025260829279432073, 0.024513505122740753, 0.11660612421110272, 0.1132154963852372, 0.04941162456816528, 0.08151189016643912, 0.02877196890040068, 0.06746240382199176, 0.1595831837039441, 0.060603564052144065, 0.16570542706176639, 0.12082236906280741, 0.06949218513909727, 0.06793460270273499, 0.15971512271789834, 0.10845320153748617, 0.26959265407640487, 0.25982242834288627, 0.25511857762467116, 0.17608302645385265, 2.874042992480099, 13.925700802356005, 31.14309087395668, 39.52310800552368, 56.792782321572304, 74.31855529546738, 78.98572325706482, 62.72625133395195, 62.12040804326534, 62.11373180150986, 52.57819667458534, 50.48313729465008, 49.69917096197605, 53.55297736823559, 43.47804978489876, 54.73230108618736, 62.60679714381695, 66.86397850513458, 76.35700151324272, 70.26656672358513, 61.50059290230274, 67.54573032259941, 76.72868996858597, 57.77020767331123, 47.365480586886406, 46.21089734137058, 76.6782134771347, 78.48250105977058, 70.80711051821709, 80.22219970822334, 71.68432384729385, 67.85610526800156, 60.31128711998463, 41.0423918813467, 50.60484856367111, 60.53932808339596, 74.56333816051483, 76.4471934735775, 81.94396331906319, 90.63392221927643, 79.71437215805054, 77.11584359407425, 84.01765644550323, 85.43968454003334, 76.42203122377396, 72.97695368528366, 70.00403881072998, 70.44033899903297, 51.15075007081032, 25.428625009953976, 5.5965805146843195, 0.2294757278286852, 0.4535458597820252, 0.1484938498470001, 0.04081522041815333, 0.06759300697012804, 0.04516769760812167, 0.029487083847925533, 0.22356311150360852, 0.14275244699092582, 0.1769536844221875, 0.03844083767035045, 0.020535515650408342, 0.018176341363869142, 0.03023913177457871, 0.05860233315615915, 0.08190490931156091, 0.013293581105244812, 0.07644389726920053, 0.06178787589306012, 0.19425497244810686, 0.12171896509244107, 0.05618207454972435, 0.06466037331847474, 0.037049470338388346, 0.046593107254011557, 0.008921911976358388, 0.0810500442457851, 0.06412770424503833, 0.10483546910108998, 0.024001679266802967, 0.1712271393625997, 0.14603796444134787, 0.05790954572148621, 0.035338411762495525, 0.08628441923065111, 0.07131503341952339, 0.07393790205242112, 0.0713926472235471, 0.07858093376853503, 0.014702067001053365, 0.048787545165396295, 0.08368510636501014, 0.02166530190152116, 0.07168198091676459, 0.048347162155550905, 0.05440613371320069, 0.03747964139620308, 0.00897523157618707, 0.03552389673131984, 0.11497831976157613, 0.06142076141259167, 0.06484017343609594, 0.06311928882496431, 0.0987127581902314, 0.1349475173628889, 0.05954948799626436, 0.25826673838309944, 0.09673694585217163, 0.11431874343543313, 0.13764124625595286, 0.12965928472112864, 0.12108980939956382, 0.11514295038068667, 0.15492582111619413, 0.04656722114305012, 0.03749753086594865, 0.055030973817338236, 0.0830609527474735, 0.061298121509025805, 0.22660944960080087, 0.10932006713119335, 0.054167102789506316, 0.05782396125141531, 0.030940685828682035, 0.019537553380359896, 0.025550250175001565, 0.08693132709595375, 0.023528432102466468, 0.10154836345463991, 0.07129616060410626, 0.13542789471102878, 0.14124487788649276, 0.1100160383793991, 0.03214756266970653, 0.02722724046179792, 0.1625128265004605, 0.09937048656865954, 0.02015205165662337, 0.05930653482209891, 0.03806028289545793, 0.10179706456256099, 0.07942407290101983, 0.03302404649730306, 0.02459725092194276, 0.09594027258572169, 0.1141144969733432, 0.1736111255013384, 0.09069992331205867, 0.09174095612252131, 0.038962478429311886, 0.07322312478208914, 0.045440459143719636, 0.05049562401836738, 0.05267527463729493, 0.09367888924316503, 0.025902234119712375, 0.1081645283557009, 0.07456810417352244, 0.07170590033638291, 0.08829035534290597, 0.03429909331316594, 0.04916823352687061, 0.03790296985243913, 0.14456863078521565, 0.031116940335778054, 0.14741439605131745, 0.1046575243526604, 0.08822352494462393, 0.16021282179281116, 0.2701472758781165, 0.15353432390838861, 0.2098099424620159, 0.1775672475923784, 0.2248988882638514, 1.2141592986881733, 6.413051253184676, 25.48981312662363, 45.19880644977093, 59.71967026591301, 79.68519732356071, 94.906747341156, 96.05765998363495, 76.63095161318779, 78.22479128837585, 73.1620341539383, 56.81073255836964, 56.713522374629974, 56.07283115386963, 53.017669692635536, 46.808555871248245, 37.57856994867325, 38.93947832286358, 33.09042178094387, 30.918570421636105, 26.67546160519123, 34.257559552788734, 38.963348641991615, 29.360355734825134, 35.23967005312443, 46.93844050168991, 55.0340086966753, 64.14635673165321, 50.6361398845911, 31.50055479258299, 35.95049411058426, 31.46177787333727, 16.24812763184309, 48.310182094573975, 67.37686738371849, 25.906544364988804, 28.24757594615221, 34.212695360183716, 36.05830192565918, 43.507486805319786, 45.808054357767105, 49.494339153170586, 57.7261908352375, 76.8500554561615, 81.77274450659752, 84.88853931427002, 94.12306219339371, 98.7443970143795, 94.25100892782211, 76.40984147787094, 41.30793683230877, 13.8001773878932, 0.5295358446892351, 0.03855682421999518, 0.2596246311441064, 0.08806282770819962, 0.04982979138731025, 0.06134731105703395, 0.04337828308052849, 0.17786281532607973, 0.12932221608934924, 0.04721173558209557, 0.05445262184366584, 0.009123458876274526, 0.044652569195022807, 0.09880252837319858, 0.05479529369040392, 0.23832134145777673, 0.14389562158612534, 0.13821090396959335, 0.06203329670825042, 0.06871492645586841, 0.061272933016880415, 0.044748918517143466, 0.05209642542467918, 0.03455821417446714, 0.03669172176159918, 0.05402426904765889, 0.056531830196036026, 0.23780593473929912, 0.15343037870479748, 0.11494004720589146, 0.1967249289737083, 0.10553288011578843, 0.08970046561444178, 0.07612343048094772, 0.08760320080909878, 0.06396990138455294, 0.06097981437051203, 0.024900093558244407, 0.039607196958968416, 0.07428801021887921, 0.019837516483676154, 0.005311703062034212, 0.08197582152206451, 0.029482803511200473, 0.042708620967459865, 0.07721098852925934, 0.044034794336766936, 0.054506898813997395, 0.04266501979145687, 0.11020835852832533, 0.04857323889154941, 0.0851631083060056, 0.13609610963612795, 0.22280951990978792, 0.11028876280761324, 0.22161874396260828, 0.2217435435159132, 0.03094967694778461, 0.01808848221116932, 0.25348852446768433, 0.16594508138950914, 0.15205835545202717, 0.17564965673955157, 0.24420572648523375, 0.1441205813898705, 0.10856438268092461, 0.22471142176073045, 0.18271747045218945, 0.14363388094352558, 0.25688530469778925, 0.11662147924653254, 0.24276171490782872, 0.19350457208929583, 0.1176048768684268, 0.11101683936431073, 0.0976712281408254, 0.10763957761810161, 0.08695202559465542, 0.20159073115792125, 0.1363855175441131, 0.24911665124818683, 0.1835012822994031, 0.2423213393194601, 0.09747291143867187, 0.1639955336577259, 0.2429829491302371, 0.14512251043925062, 0.14388628536835313, 0.22800283186370507, 0.1026964362245053, 0.14469969406491145, 0.29211443150416017, 0.08783120341831818, 0.13321430567884818, 0.15957689029164612, 0.18806750915246084, 0.2169159916229546, 0.13202704751165584, 0.14873248001094908, 0.12673375342274085, 0.3403432248160243, 0.11011140435584821, 0.10502413788344711, 0.20525388303212821, 0.1589085566229187, 0.1458519822335802, 0.2536337182391435, 0.1710553767043166, 0.1701076392782852, 0.2137860728544183, 0.15410683146910742, 0.1630634703906253, 0.09573591480148025, 0.2090624810080044, 0.08955231809522957, 0.2270731731550768, 0.20552463334752247, 0.2150912137585692, 0.2539876929949969, 0.3240277315489948, 0.19776821049163118, 0.31887796882074326, 0.530643129022792, 0.45315376832149923, 1.0015499009750783, 5.7067798264324665, 21.534873247146606, 44.467642083764076, 61.253860741853714, 87.21233502030373, 103.76352488994598, 113.28836739063263, 105.55981770157814, 103.86383190751076, 104.64959174394608, 83.81697401404381, 83.54518979787827, 76.78982868790627, 84.13102716207504, 78.78234297037125, 99.8072911798954, 107.43313238024712, 119.71671044826508, 130.24032175540924, 111.14408925175667, 87.0197993516922, 93.9876526594162, 99.43504795432091, 81.91890746355057, 69.59331884980202, 69.1938690841198, 103.51598337292671, 106.97964951395988, 104.92391422390938, 118.23600590229034, 112.32172206044197, 111.57217428088188, 94.76330503821373, 67.20664411783218, 71.86147794127464, 97.05578282475471, 121.86544954776764, 115.4318019747734, 116.44469082355499, 119.8711721599102, 99.09660771489143, 97.69682362675667, 97.96944379806519, 102.723368704319, 104.48765963315964, 110.10210156440735, 112.85082086920738, 101.04619190096855, 78.80957990884781, 39.80618141591549, 12.475387025624514, 0.40947656671050936, 0.35922313516493887, 0.28175773099064827, 0.3990720125148073, 0.12069120930391364, 0.17280239233514294, 0.19631900388048962, 0.34969817439559847, 0.24698126973817125, 0.22372179751982912, 0.12274367807549424, 0.1618426968343556, 0.1232868485385552, 0.23268219170859084, 0.23978806275408715, 0.34935776609927416, 0.22566010913578793, 0.26720216672401875, 0.2941638871561736, 0.15582058404106647, 0.15485067124245688, 0.18613816268043593, 0.10654078345396556, 0.11562183601199649, 0.1768406553310342, 0.13734682142967358, 0.19112163980025798, 0.3407884540501982, 0.3812368382932618, 0.16415367048466578, 0.2518401254201308, 0.15284822322428226, 0.15239659667713568, 0.1900302225840278, 0.20896218717098236, 0.15325500920880586, 0.09965207224013284, 0.15377118776086718, 0.09355178903206252, 0.17018877086229622, 0.09546188419335522, 0.1698303283774294, 0.15600021346472204, 0.11693791617290117, 0.1427843890269287, 0.21464757272042334, 0.1383587991585955, 0.11211243487196043, 0.1298357080668211, 0.23751695727696642, 0.1724873506464064, 0.16552517423406243, 0.3131260274676606, 0.21133380912942812, 0.21278145723044872, 0.26455875544343144, 0.395656589535065, 0.1532126622623764, 0.19783565687248483], [0.054853088440722786, 0.00833691592561081, 0.008429381960013416, 0.07188837218564004, 0.07453077414538711, 0.018814556824509054, 0.022383300092769787, 0.045993841558811255, 0.040030043019214645, 0.049518286032252945, 0.0899129721801728, 0.022114893108664546, 0.0965520620229654, 0.03668434110295493, 0.10558995869359933, 0.0682849483564496, 0.023468156723538414, 0.09004916370031424, 0.0055477166915807175, 0.022766756665077992, 0.010279274101776537, 0.040952176350401714, 0.026639019779395312, 0.06719488184899092, 0.0654453577590175, 0.10818802475114353, 0.11588727255002595, 0.023600257154612336, 0.028477230516728014, 0.0618894647777779, 0.048444980930071324, 0.07247022338560782, 0.10565339747699909, 0.08107178917271085, 0.06738038166076876, 0.19099844328593463, 0.0589752660744125, 0.03011372551554814, 0.013040053254371742, 0.0065596805052337, 0.037803536906722, 0.03540619582054205, 0.09234973244019784, 0.03639882204879541, 0.029715982600464486, 0.06679916128632613, 0.06415656636818312, 0.059400846948847175, 0.012879535988759017, 0.05392513296101242, 0.17542595858685672, 0.09108933561947197, 0.05856195661181118, 0.04022410721518099, 0.02164727142371703, 0.06818343739723787, 0.1321808947250247, 0.032885034815990366, 0.013909371646150248, 0.03915270572178997, 0.042271176862413995, 0.008040090251597576, 0.11707310579367913, 0.10663047200068831, 0.09716765125631355, 0.20526538632111624, 0.1429332490079105, 0.2904885937459767, 0.1391662855166942, 0.096319324511569, 0.9305566479451954, 2.5145782437175512, 9.701385777443647, 23.059370443224907, 33.320541232824326, 52.44611196219921, 49.172538220882416, 54.4364033639431, 62.26643420755863, 56.96751594543457, 48.75410087406635, 41.66885286569595, 52.63941518962383, 70.29198735952377, 71.18618577718735, 79.45277139544487, 84.11300092935562, 81.52454942464828, 83.50069418549538, 89.97286409139633, 85.86942628026009, 79.54093426465988, 68.71115058660507, 78.98095071315765, 87.08163723349571, 74.4978828728199, 71.92967668175697, 81.11196756362915, 74.99560296535492, 80.67885920405388, 85.27402102947235, 88.49560976028442, 88.11126038432121, 87.68388211727142, 85.87788462638855, 86.57593756914139, 91.05841264128685, 82.98522904515266, 73.96941483020782, 49.25077222287655, 19.28172904998064, 9.840201828628778, 7.2006121929734945, 3.6137794610112906, 0.2202851788024418, 0.1818259432911873, 0.4368855943903327, 0.061997822049306706, 0.21689141169190407, 0.06736717143212445, 0.2435276409960352, 0.05097483248391654, 0.05308269144734368, 0.06921151230926625, 0.03888382561854087, 0.1138006872497499, 0.3494561748811975, 0.06365984692820348, 0.01710807358904276, 0.017663793769315816, 0.04245950054610148, 0.05517869460163638, 0.004156631375735742, 0.017868865870696027, 0.0483448837621836, 0.09592396760126576, 0.06273642968153581, 0.12869982136180624, 0.03571036133507732, 0.026929578016279265, 0.052890812876285054, 0.016888284699234646, 0.03472607313597109, 0.09680637376732193, 0.05717412190278992, 0.09980435352190398, 0.07295581061043777, 0.033519448625156656, 0.009513002914900426, 0.11298933430225588, 0.14009027421707287, 0.08018300795811228, 0.038222508956096135, 0.05197067963308655, 0.033874369619297795, 0.018581828589958604, 0.045199765809229575, 0.028435967105906457, 0.028823533320974093, 0.053542867535725236, 0.039329036299022846, 0.06598268009838648, 0.02942081006040098, 0.0674321835685987, 0.07933709319331683, 0.046924331472837366, 0.06383381376508623, 0.11105701923952438, 0.07979202971910127, 0.030207456911739428, 0.06053943136066664, 0.006268842107601813, 0.08435364783508703, 0.043082258926006034, 0.04997391275537666, 0.08264519419753924, 0.01580528900376521, 0.07881762692704797, 0.012874804797320394, 0.03962497881730087, 0.03787407433264889, 0.0336263364442857, 0.04130018423893489, 0.08222379532526247, 0.04855760184000246, 0.0321077538683312, 0.12137338402681053, 0.03341863528476097, 0.10818275550263934, 0.09272470255382359, 0.09034961476572789, 0.055788717727409676, 0.023911051903269254, 0.0380615297035547, 0.02578477255156031, 0.07275647716596723, 0.057243382834712975, 0.025710895461088512, 0.07163663569372147, 0.04647065659810323, 0.09024224083987065, 0.0855546208913438, 0.11925807018997148, 0.04974998824764043, 0.03976891464844812, 0.037950626865494996, 0.1058055748580955, 0.05446955394290853, 0.058464965331950225, 0.04699426775914617, 0.09367257356643677, 0.11018613862688653, 0.012483640093705617, 0.00650116819087998, 0.07217888589366339, 0.01912031239044154, 0.04762373886478599, 0.002749016111920355, 0.033188257802976295, 0.03065333923586877, 0.05481848580529913, 0.005063952830823837, 0.042891233824775554, 0.0631570492987521, 0.04431555251358077, 0.01818365893996088, 0.10568779602181166, 0.05461035048938356, 0.0290572449011961, 0.10429099987959489, 0.08170532353688031, 0.11365329672116786, 0.20501345687080175, 0.04684298466600012, 0.05917458838666789, 0.05616958791506477, 0.05896623413718771, 0.052942284528398886, 0.15669882675865665, 0.10565885226242244, 0.27578154229559004, 0.2901084953919053, 0.06025630202202592, 0.07444886330631562, 0.11830046962131746, 0.5425490182824433, 2.6736761815845966, 9.462158214300871, 21.33355624973774, 37.15645059943199, 52.46628127992153, 73.70006248354912, 72.80871391296387, 73.54096502065659, 82.0930977165699, 76.58070310950279, 69.74326640367508, 66.89446046948433, 74.62448447942734, 76.5346647799015, 73.34639266133308, 77.54769802093506, 77.09801495075226, 77.21242681145668, 74.8725275695324, 74.88958105444908, 68.97281214594841, 62.529627084732056, 63.79139497876167, 71.05244055390358, 64.77934956550598, 59.96575266122818, 59.87018778920174, 57.16599069535732, 63.10820683836937, 63.868508040905, 70.53070574998856, 75.72007969021797, 79.92371052503586, 81.51685863733292, 90.3752700984478, 98.34620878100395, 105.00221282243729, 102.29911386966705, 101.89716383814812, 78.70147570967674, 42.07871787250042, 23.886171877384186, 16.8556010350585, 8.662472125142813, 1.1783168907277286, 0.14625594805693254, 0.2299515187041834, 0.21206871344475076, 0.10723129249527119, 0.0496513085818151, 0.10782308105262928, 0.054763726438977756, 0.12418593076290563, 0.046716815850231797, 0.05429850745713338, 0.13606250518932939, 0.2753507997840643, 0.10766628009150736, 0.057526226446498185, 0.08297831460367888, 0.058510076778475195, 0.025049805153685156, 0.05010728782508522, 0.012585759614012204, 0.09800201078178361, 0.027041592220484745, 0.14770347741432488, 0.1766092685284093, 0.0445950935682049, 0.027478861920826603, 0.06369107650243677, 0.025000251953315455, 0.029529592211474665, 0.030986934616521467, 0.08660309744300321, 0.02766248224361334, 0.03422266323468648, 0.05957003806543071, 0.058997946107410826, 0.07407580793369561, 0.12376885861158371, 0.01735707341140369, 0.029250078987388406, 0.03888066406943835, 0.04784800847119186, 0.009093836979445769, 0.032765318974270485, 0.11334840761264786, 0.05682321221684106, 0.051229641467216425, 0.01802405451599043, 0.03258364864450414, 0.04262083974026609, 0.0430729709478328, 0.08364767985767685, 0.023922458713059314, 0.03789293230511248, 0.07916815069620498, 0.05469267693115398, 0.05618884664727375, 0.014267077549448004, 0.08102527135633864, 0.09913738540490158, 0.09352042587124743, 0.039667054879828356, 0.09279176301788539, 0.11118443115265109, 0.15488670993363485, 0.19357342855073512, 0.11421089453506283, 0.12597009830642492, 0.14116745704086497, 0.1234282499353867, 0.2607982634799555, 0.21249650220852345, 0.16260856355074793, 0.22611986962147057, 0.12787375162588432, 0.21288365096552297, 0.1588455482851714, 0.27753434667829424, 0.15703861165093258, 0.13307628105394542, 0.17679615615634248, 0.12837483489420265, 0.23081137100234628, 0.062295994721353054, 0.11019082900020294, 0.2152765280334279, 0.1763613912044093, 0.13739632267970592, 0.22575774608412758, 0.1794341200729832, 0.15918424964183941, 0.19430793210631236, 0.11842678315588273, 0.19743966171517968, 0.20939773879945278, 0.20260640478227288, 0.15375330200186, 0.1760226601618342, 0.3429009922547266, 0.15454324398888275, 0.17868029099190608, 0.11770523749873973, 0.13270078401546925, 0.10694863813114353, 0.0799727278354112, 0.1280618118471466, 0.1736525967135094, 0.15555461315670982, 0.11459424349595793, 0.13353945541894063, 0.17716611677315086, 0.10117654746863991, 0.17520562978461385, 0.2668869320768863, 0.22386130644008517, 0.1287680395762436, 0.17096876807045192, 0.12953270401339978, 0.1614880986744538, 0.3021287644514814, 0.18478052224963903, 0.15836292965104803, 0.08660968029289506, 0.14286584715591744, 0.12971457472303882, 0.22943474643398076, 0.16990489937597886, 0.40020304557401687, 0.5234171636402607, 0.2802373969461769, 0.5445619008969516, 0.22232819261262193, 0.23546076292404905, 1.2361068022437394, 5.302232634276152, 14.679286815226078, 29.19074423611164, 52.000616267323494, 75.82745432853699, 85.56646853685379, 97.26737827062607, 106.94446340203285, 106.35748609900475, 109.67688918113708, 101.85206785798073, 102.77354881167412, 111.0075169801712, 100.68467929959297, 118.79925727844238, 115.40017247200012, 119.52985927462578, 114.25063535571098, 116.69179916381836, 108.49688529968262, 90.8238360285759, 83.13624054193497, 97.117939889431, 107.40812972187996, 96.69376105070114, 96.75782561302185, 110.37082314491272, 101.90164759755135, 110.01200079917908, 120.1180525124073, 115.79551845788956, 111.99963614344597, 109.42332118749619, 112.96187371015549, 112.40674629807472, 121.48208051919937, 110.33904924988747, 104.94180366396904, 79.2943274974823, 40.467915907502174, 22.22092643380165, 13.244631998240948, 6.237297859042883, 0.4938291903818026, 0.23280975205125287, 0.4712773411301896, 0.2010881932801567, 0.3794976894278079, 0.14755252457689494, 0.34300679282750934, 0.1815791940316558, 0.3649990330450237, 0.13198884174926206, 0.16001351061277092, 0.1990388860576786, 0.6120718689635396, 0.11599162593483925, 0.17344317748211324, 0.14851831103442237, 0.24432690435787663, 0.11310995556414127, 0.1406164569198154, 0.1177550430293195, 0.20898608432617038, 0.14512203546473756, 0.13920621306169778, 0.2484047386678867, 0.1270822511287406, 0.13266499765450135, 0.1457955047953874, 0.07523853069869801, 0.11688433311064728, 0.27125423366669565, 0.252209329046309, 0.1413043832872063, 0.26841676561161876, 0.16870909166755155, 0.10327046518796124, 0.19965179613791406, 0.35495599382556975, 0.15391566907055676, 0.11337510266457684, 0.10724692954681814, 0.12694185163127258, 0.1807598926825449, 0.14844212215393782, 0.2111167903058231, 0.20180115971015766, 0.10888763994444162, 0.16879277623957023, 0.15790119505254552, 0.12300904039875604, 0.16128032701089978, 0.12888360681245103, 0.10614161932608113, 0.12922765163239092, 0.14410930074518546, 0.19656305172247812, 0.1758394535863772, 0.27146559732500464, 0.14807211700826883, 0.12136787729104981, 0.1344822798273526, 0.12149394591688178, 0.17648869921686128], [0.023226166485983413, 0.017303523745795246, 0.00885465484316228, 0.08410121372435242, 0.03706281044287607, 0.038593831413891166, 0.01017744865748682, 0.05278729811834637, 0.04307957977289334, 0.05937612600973807, 0.034054114075843245, 0.036978725111112, 0.012932516056025634, 0.014432615444093244, 0.04210104321828112, 0.04666178188927006, 0.04498540387430694, 0.053230679404805414, 0.06758257979527116, 0.013731989074585726, 0.08562410817830823, 0.02542810936574824, 0.06628495684708469, 0.07151959158363752, 0.061201646021800116, 0.04292476405680645, 0.03462256208877079, 0.01796025022485992, 0.04413115108036436, 0.08280638125143014, 0.027493920097185764, 0.0234128518786747, 0.02266595260152826, 0.0247374036553083, 0.07299203483853489, 0.03409876910154708, 0.006668625464953948, 0.014475743500952376, 0.05210701587202493, 0.07196361111709848, 0.027938368220929988, 0.0051630977304739645, 0.08689942958881147, 0.058197614052915014, 0.020036033565702382, 0.00947869528317824, 0.0335140383685939, 0.041367864396306686, 0.04279555243556388, 0.03721872824826278, 0.012029919762426289, 0.029320243484107777, 0.050175031065009534, 0.016207048793148715, 0.03232064264011569, 0.05301716722897254, 0.06187017264892347, 0.017365099738526624, 0.08908209332730621, 0.009139779631368583, 0.10684553897590376, 0.048073558282339945, 0.07198151914053597, 0.10341341025196016, 0.12744161387672648, 0.08871033671312034, 0.019132088418700732, 0.10053588848677464, 0.13337109179701656, 0.06645242989179678, 0.08021115019801073, 0.08558544228435494, 0.27678593527525663, 0.4844879260053858, 0.1585331783280708, 0.1372702169464901, 0.24110207974445075, 1.6998366499319673, 4.787618173286319, 10.29765073210001, 10.885909516364336, 5.240414701402187, 2.4372041830793023, 19.930891916155815, 35.63801787793636, 50.26423864066601, 54.12231981754303, 47.06976905465126, 52.89585582911968, 63.567909970879555, 85.99332243204117, 91.32723301649094, 96.90075114369392, 83.69053959846497, 84.81241419911385, 76.62103414535522, 70.44085577130318, 68.79807472229004, 68.80647987127304, 64.75530445575714, 68.08432102203369, 43.34852613508701, 34.46465604007244, 37.06576086580753, 29.613982625305653, 20.51020123064518, 18.98276299238205, 7.544497540220618, 1.3173302938230336, 0.4107611649669707, 0.11053203881601803, 0.1910871299332939, 0.22149575524963439, 0.02063993211777415, 0.08569490906666033, 0.08682899235282093, 0.23821034585125744, 0.06373775759129785, 0.05668103898642585, 0.18944679060950875, 0.14180917729390785, 0.06546355522004887, 0.0168921011936618, 0.08091481009614654, 0.041693362945807166, 0.07614942049258389, 0.09388989667058922, 0.06419690209440887, 0.08007317752344534, 0.04551470359729137, 0.012341944620857248, 0.02709843887714669, 0.04738073745102156, 0.053508713899645954, 0.04230440652463585, 0.049987427264568396, 0.0758044257236179, 0.006971297871132265, 0.05149163072928786, 0.0742549252754543, 0.05726591814891435, 0.04806681587069761, 0.00890565986992442, 0.02031074694968993, 0.08371272168005817, 0.05102695351524744, 0.022490926348837093, 0.022696634841850027, 0.032692057866370305, 0.0284161053787102, 0.019922345818486065, 0.06589475044165738, 0.05692280101357028, 0.09512134231044911, 0.01263807360373903, 0.012909143970318837, 0.07442941903718747, 0.021417853167804424, 0.05366084304114338, 0.028064960060874, 0.024038445262704045, 0.11323677375912666, 0.045319733981159516, 0.023314381869568024, 0.07110484977602027, 0.010835911762114847, 0.07227744310512207, 0.05672468840202782, 0.0481658369244542, 0.014146920129860519, 0.0371731752238702, 0.03757351565582212, 0.04700877674622461, 0.009750631179485936, 0.054995892496663146, 0.038803376810392365, 0.04671603659517132, 0.054367248885682784, 0.05672198698448483, 0.07920365504105575, 0.060912445915164426, 0.01761506064212881, 0.022877809788042214, 0.030326953819894698, 0.047549494411214255, 0.14142965781502426, 0.025738865151652135, 0.0974234398745466, 0.013484692481142702, 0.010289958245266462, 0.026928416555165313, 0.06387851331965066, 0.011974130666203564, 0.04800180744496174, 0.027131883762194775, 0.046392211588681675, 0.0341555545310257, 0.0027756807821788243, 0.06024512527801562, 0.026986691846104804, 0.03825948646408506, 0.04496066438150592, 0.02260076977108838, 0.03536005278874654, 0.03651105333119631, 0.12129712835303508, 0.014247377239371417, 0.03047223850444425, 0.06857610031147487, 0.061233617743710056, 0.07531209237640724, 0.030567899484594818, 0.014917843654984608, 0.05243677805992775, 0.033997595819528215, 0.04628693051927257, 0.0642022307147272, 0.01321538285992574, 0.08936174199334346, 0.05938661997788586, 0.048649939853930846, 0.0631990103283897, 0.0025647004895290593, 0.038375079675461166, 0.04125108374864794, 0.06392234456143342, 0.028348126506898552, 0.040007778588915244, 0.0036865446008960134, 0.06507815051008947, 0.022942387768125627, 0.06926670583197847, 0.07727171847363934, 0.018071273661917076, 0.08336504775797948, 0.01130723027017666, 0.08024410155485384, 0.012125166995247127, 0.046076479702605866, 0.04435226655914448, 0.06954877389944158, 0.032976552756736055, 0.0661716828471981, 0.07600138429552317, 0.06311250559519976, 0.15315541299059987, 0.09152542901574634, 0.4291137645486742, 0.3216695721494034, 0.21801604743814096, 0.38236463558860123, 1.1013238783925772, 3.0425701243802905, 6.934194238856435, 14.79770366102457, 24.891278743743896, 25.782579816877842, 22.86360304802656, 24.555448964238167, 55.51564805209637, 71.84301093220711, 78.38145688176155, 84.1022627055645, 78.3394767343998, 85.28782188892365, 97.19012081623077, 106.89684435725212, 113.7268790602684, 110.86617976427078, 105.23219928145409, 106.66853740811348, 103.02205547690392, 95.67835673689842, 94.75639700889587, 94.06824633479118, 90.21613463759422, 90.35010784864426, 80.06168112158775, 71.96307688951492, 70.0050039589405, 57.98873394727707, 43.98454740643501, 37.486573085188866, 18.887409009039402, 6.483878027647734, 0.8509094186592847, 0.42207888734992594, 0.20404483540914953, 0.05231514747720212, 0.02855990947864484, 0.17732156702550128, 0.05692134269338567, 0.07355971101787873, 0.069240916200215, 0.06271723032114096, 0.07118552864994854, 0.1472680296865292, 0.09095387882553041, 0.06319977474049665, 0.052619884445448406, 0.033922568400157616, 0.06794589819037355, 0.05978500485070981, 0.012253572458575945, 0.08675427292473614, 0.09566604901920073, 0.007277681479536113, 0.02935525986686116, 0.05991767488012556, 0.09859345795121044, 0.05998525484756101, 0.10817986112670042, 0.03425315808271989, 0.028179710934637114, 0.1146967415115796, 0.03348851219925564, 0.0450074345280882, 0.029118188213033136, 0.055361967970384285, 0.05622081094770692, 0.028605050611076877, 0.048371122393291444, 0.03500904291286133, 0.0480461025290424, 0.012848277656303253, 0.02149023668607697, 0.1152945488865953, 0.057772827276494354, 0.07018587799393572, 0.10422624749480747, 0.010062714482046431, 0.0420144902454922, 0.023851874902902637, 0.05061924355686642, 0.02443875971948728, 0.04103962732187938, 0.04940675979014486, 0.030248935545387212, 0.04924909422697965, 0.04454830486793071, 0.046531022890121676, 0.0207772275825846, 0.07734339509624988, 0.024057472073764075, 0.036076900651096366, 0.01743569468089845, 0.0412428607523907, 0.03530463662173133, 0.035983831621706486, 0.006661700299446238, 0.016022923809941858, 0.02853594738553511, 0.15084712591487914, 0.1893107104115188, 0.08158889540936798, 0.13714296830585226, 0.13451632956275716, 0.1003017854236532, 0.11637674862868153, 0.1207991324190516, 0.1444825713406317, 0.20291316410293803, 0.14994878583820537, 0.12574386200867593, 0.1427312067244202, 0.11872703384142369, 0.11240352745517157, 0.17020199593389407, 0.16977346502244473, 0.17770617763744667, 0.16445817367639393, 0.11180707078892738, 0.16839618736412376, 0.12308557808864862, 0.1602275756886229, 0.1231508945056703, 0.17783131857868284, 0.2341923286439851, 0.14065776485949755, 0.12568091304274276, 0.13115352485328913, 0.22054438129998744, 0.14604066585889086, 0.143293576547876, 0.09270729919080622, 0.15769467019708827, 0.21698830649256706, 0.17664037935901433, 0.12463629565900192, 0.17504499934148043, 0.18707280862145126, 0.15928203501971439, 0.12001584749668837, 0.06177413873956539, 0.1764422853011638, 0.18706700502661988, 0.10328996882890351, 0.15712075255578384, 0.13142463139956817, 0.11124979209853336, 0.1427295443136245, 0.12919054424855858, 0.06394096504664049, 0.10600038120173849, 0.17984828300541267, 0.12560565926833078, 0.15354768256656826, 0.19786483811913058, 0.18625255732331425, 0.07917969109257683, 0.1433860629913397, 0.1041307405102998, 0.2216220836271532, 0.1646068852278404, 0.17481451795902103, 0.1677938603097573, 0.19396068120840937, 0.19629712536698207, 0.20257774303900078, 0.1852603058796376, 0.36806502321269363, 0.20777638361323625, 0.26557442906778306, 0.4363831604132429, 0.5451359669677913, 0.49463914067018777, 0.23976947937626392, 0.4551078728400171, 1.1484914598986506, 3.383527253754437, 8.415053151547909, 17.928243577480316, 20.148700028657913, 20.66993895918131, 20.4522942379117, 49.586248621344566, 69.09592553973198, 73.9355206489563, 82.94316530227661, 79.91745606064796, 88.98501589894295, 99.68649566173553, 115.50621718168259, 127.6977413892746, 132.00889885425568, 119.74093034863472, 114.1468021273613, 115.50103425979614, 111.05609357357025, 100.02813532948494, 101.97663277387619, 93.83033350110054, 90.06945490837097, 72.49630987644196, 66.19252413511276, 62.726084142923355, 49.14773315191269, 33.33723373711109, 25.572158508002758, 11.04333221912384, 2.7132615074515343, 0.308490899624303, 0.28821103158406913, 0.2693986863596365, 0.18392985773971304, 0.11522224885993637, 0.22542566468473524, 0.33041979011613876, 0.21766465535620227, 0.13439167843898758, 0.1549168856581673, 0.37339880887884647, 0.5318767565768212, 0.18153950397390872, 0.1891400758177042, 0.1486692193429917, 0.2563536597881466, 0.2420847723260522, 0.2629737654933706, 0.11878132936544716, 0.17441255593439564, 0.21748959756223485, 0.0585799462714931, 0.11624586346442811, 0.11301729842671193, 0.16935755062149838, 0.13725117343710735, 0.22831959533505142, 0.12128261194447987, 0.07403273368254304, 0.1771325568552129, 0.21626386645948514, 0.1943090304848738, 0.15095003211172298, 0.13906352774938568, 0.13734927051700652, 0.1598240848397836, 0.15747962548630312, 0.13428878708509728, 0.13318346202140674, 0.15131087915506214, 0.13279230566695333, 0.1303484133677557, 0.16106975002912804, 0.18728535971604288, 0.2318595803808421, 0.13919755961978808, 0.11687752019497566, 0.1546293924911879, 0.18531748093664646, 0.1715533874812536, 0.08485966638545506, 0.18493361247237772, 0.22214436263311654, 0.10552649764576927, 0.1062316789466422, 0.11319900586386211, 0.04954009404173121, 0.20544022147078067, 0.0983867772447411, 0.15651404683012515, 0.14613180159358308, 0.1290741012780927, 0.18630020320415497, 0.13051895890384912, 0.07945568097056821, 0.14686600829008967, 0.06337469152640551], [0.02255047071230365, 0.039522491933894344, 0.01969931003259262, 0.036745523757417686, 0.011380096184439026, 0.018624470540089533, 0.03710489021614194, 0.022977871703915298, 0.023211822626763023, 0.010140297672478482, 0.13662946148542687, 0.013477135562425246, 0.015942888749123085, 0.036904484368278645, 0.023626315814908594, 0.038074780750321224, 0.02970407669636188, 0.015619982150383294, 0.09099718314246275, 0.07739972410490736, 0.027723149105440825, 0.037590985812130384, 0.014566157497029053, 0.03031743206520332, 0.042823434923775494, 0.0478873497195309, 0.019963074882980436, 0.08790599706117064, 0.06587989264517091, 0.07419993955409154, 0.02499588626960758, 0.04742254634038545, 0.05900151954847388, 0.04380416823551059, 0.029651970507984515, 0.06603336136322469, 0.050213485446874984, 0.026889563268923666, 0.07041730190394446, 0.017381347206537612, 0.01168289985798765, 0.02502307113900315, 0.05069903556432109, 0.11926725797820836, 0.05063313656137325, 0.15928868466289714, 0.014968062005209504, 0.012455543310352368, 0.07867733133025467, 0.08403983069001697, 0.08185367143596523, 0.05141884459590074, 0.06617140083108097, 0.0176008318157983, 0.02901267522247508, 0.05739643966080621, 0.06919522958924063, 0.028461311449063942, 0.10993392716045491, 0.03235714517359156, 0.038607245733146556, 0.05657025860273279, 0.0435005815961631, 0.0026103785194209195, 0.01152922241089982, 0.004873044617852429, 0.0633725021907594, 0.11288129986496642, 0.11135701759485528, 0.008193762132577831, 0.038145919315866195, 0.030533168828696944, 0.09966698940843344, 0.13214197650086135, 0.07374357810476795, 0.0694194546667859, 0.0430903668893734, 0.05499169565155171, 0.34148856648243964, 0.3231534222140908, 0.19329349044710398, 0.19926006090827286, 1.0438359319232404, 0.4772386868717149, 0.10270348662743345, 0.14868320140521973, 0.357090113684535, 0.5208498670253903, 1.5603412664495409, 2.450190461240709, 5.9300335217267275, 6.6525946743786335, 6.965875988826156, 5.790448011830449, 5.217465832829475, 2.304872958920896, 3.192967241629958, 2.2801980329677463, 1.8019596138037741, 2.4248690949752927, 1.3382272724993527, 0.43026896193623543, 0.32604254374746233, 0.44460535515099764, 0.020790519447473343, 0.07583482409245335, 0.17062881990568712, 0.1670767823816277, 0.10119935366674326, 0.09626416067476384, 0.048554369786870666, 0.2594363928074017, 0.2302627160679549, 0.16637527471175417, 0.05370366867282428, 0.07776935817673802, 0.030895802592567634, 0.04380767859402113, 0.047917614501784556, 0.04347232432337478, 0.05662190837028902, 0.03112882397545036, 0.024599930075055454, 0.010871250979107572, 0.05177530554647092, 0.028659912022703793, 0.04321568223531358, 0.0210840202998952, 0.07179203399573453, 0.06437840173020959, 0.04977041215170175, 0.0806597487826366, 0.08250970029621385, 0.08712461203685962, 0.08425384381553158, 0.04510137929173652, 0.02477252022799803, 0.042342397064203396, 0.07534814591053873, 0.04603332381520886, 0.012561788244056515, 0.008547904799343087, 0.032993306740536354, 0.040200629373430274, 0.08270078105852008, 0.032282845058944076, 0.05627294311125297, 0.0702175973856356, 0.01733718756440794, 0.042602334287948906, 0.07931685482617468, 0.08812979169306345, 0.07945501303765923, 0.049981671909336, 0.007057897691993276, 0.05593180008872878, 0.031187479617074132, 0.016659157736285124, 0.05830148504173849, 0.06278314045630395, 0.061036521874484606, 0.04106469335965812, 0.051591115625342354, 0.12311544211115688, 0.07448738819221035, 0.014633921146014472, 0.07773010598612018, 0.007044506101010484, 0.03051883239095332, 0.0025134684119620943, 0.05656472218106501, 0.01699322438071249, 0.022066601559345145, 0.02731729266088223, 0.015462343490071362, 0.05104529198433738, 0.024789341005089227, 0.020850748442171607, 0.006663113163085654, 0.026622670266078785, 0.03936622531909961, 0.0194019054833916, 0.04668333385779988, 0.03231321374187246, 0.029667097333003767, 0.00653469146527641, 0.03902763899532147, 0.012303561670705676, 0.03314482361020055, 0.01883906254079193, 0.027315533770888578, 0.12321285641519353, 0.048904793366091326, 0.04663448198698461, 0.028326982719590887, 0.02616193571157055, 0.013884403942938661, 0.05582589561527129, 0.014872381543682422, 0.06166100574773736, 0.03346488963870797, 0.014930479646864114, 0.09894180722767487, 0.08071744334301911, 0.05719511354982387, 0.018332580148126, 0.01687740852503339, 0.020064990312675945, 0.05938024492934346, 0.017848425268311985, 0.06906392882228829, 0.07650064188055694, 0.03095523006777512, 0.029587989956780802, 0.03261051439039875, 0.031791669462108985, 0.027926729489990976, 0.016277680842904374, 0.05895939524634741, 0.026921683420368936, 0.04123261911445297, 0.04155968359555118, 0.07551823873654939, 0.03604157442168798, 0.059158754665986635, 0.06464081030571833, 0.048408040529466234, 0.05623917910270393, 0.02853964142559562, 0.03424050075409468, 0.025575713261787314, 0.010477559262653813, 0.11859196296427399, 0.04244354066031519, 0.13205140479840338, 0.04426425897690933, 0.06633670680457726, 0.05748699280957226, 0.0342938351968769, 0.0574234204395907, 0.06183351426443551, 0.06214161687239539, 0.026837531295313966, 0.0512986537796678, 0.03318223527458031, 0.04250034464348573, 0.13888110785046592, 0.05053030457929708, 0.03144214759231545, 0.05867998406756669, 0.0691067730076611, 0.13573591568274423, 0.12161154663772322, 0.06661610314040445, 0.33348993631079793, 0.11803567133028992, 0.2605484862579033, 1.3400200637988746, 2.0894382940605283, 0.7330348156392574, 0.7131944771390408, 2.1737769059836864, 3.7325033778324723, 2.8892649756744504, 6.361469496041536, 8.41836467385292, 17.264272905886173, 18.8303816691041, 19.95160460472107, 16.923229806125164, 17.204948589205742, 12.143006511032581, 11.29092313349247, 11.062089912593365, 7.899387096986175, 8.987547531723976, 6.753479260951281, 1.8629917013458908, 1.0718039749190211, 1.2353564612567425, 0.5825802858453244, 0.28661354386713356, 0.28064002690371126, 0.06362291023833677, 0.057992117071989924, 0.2641432418022305, 0.14914024563040584, 0.07397653083899058, 0.056833112466847524, 0.10142715589608997, 0.05996749896439724, 0.08013440470676869, 0.03543760351021774, 0.05416605265054386, 0.04425273713422939, 0.03401019006560091, 0.09578402823535725, 0.01630914233828662, 0.06180681179102976, 0.01839326741901459, 0.028348957712296396, 0.027241934985795524, 0.0540295123209944, 0.04257999564288184, 0.0627158499264624, 0.055163198558148, 0.08515649577020667, 0.020983795111533254, 0.032474337713210844, 0.041823242499958724, 0.04360991108114831, 0.03761978485272266, 0.08714962241356261, 0.04223015464958735, 0.02692851674510166, 0.05330876818334218, 0.013120743260515155, 0.03733812125574332, 0.05874056929314975, 0.027153047958563548, 0.08029586635529995, 0.035072381506324746, 0.024775075071374886, 0.019496113709465135, 0.030463354996754788, 0.018642779323272407, 0.060303402424324304, 0.029277915091370232, 0.06592516365344636, 0.03311180917080492, 0.03418252046685666, 0.05372803709178697, 0.09923242483637296, 0.015270212588802679, 0.04434231435880065, 0.06522144438349642, 0.06332957636914216, 0.014847672664473066, 0.03846015206363518, 0.038099683515611105, 0.017066778636944946, 0.01837761366914492, 0.058768878516275436, 0.03426380419114139, 0.043502169792191125, 0.020749265313497745, 0.04154769048909657, 0.0244850548915565, 0.045788678544340655, 0.0058155888655164745, 0.023202484553621616, 0.023223131101985928, 0.09840501923463307, 0.11592576775001362, 0.12430349437636323, 0.08916383347241208, 0.20685022784164175, 0.18929928133729845, 0.13287000852869824, 0.20279753749491647, 0.14739290345460176, 0.05683599199983291, 0.19765292527154088, 0.10642669309163466, 0.1299227768322453, 0.1912867825012654, 0.11172005397384055, 0.15397916722577065, 0.1072147574450355, 0.08783691795542836, 0.19541793270036578, 0.11134218948427588, 0.10999923615599982, 0.10380154606536962, 0.1317666278919205, 0.11191340570803732, 0.17612663505133241, 0.16978189582005143, 0.1561060140375048, 0.24001247336855158, 0.11740586996893398, 0.23159878968726844, 0.15451134648174047, 0.12043370632454753, 0.1572489956743084, 0.1680356965516694, 0.12813276116503403, 0.17642039194470271, 0.17858449456980452, 0.14910238125594333, 0.1585385514772497, 0.07605668914038688, 0.09871099930023775, 0.16666420764522627, 0.1388906518695876, 0.14812117296969518, 0.15913183917291462, 0.25658446771558374, 0.18198077013948932, 0.10886864838539623, 0.12870078615378588, 0.29507708502933383, 0.13548800867283717, 0.14544648758601397, 0.2084177773213014, 0.09754545637406409, 0.12937183608300984, 0.18473636446287856, 0.2840379945700988, 0.2245332024176605, 0.20895099558401853, 0.07418998735374771, 0.2613074955297634, 0.16186521359486505, 0.14708817761857063, 0.2521192916901782, 0.18165174638852477, 0.2214482132694684, 0.18023544660536572, 0.19459279807051644, 0.2886814047815278, 0.27705162414349616, 0.261457854649052, 0.1418876223033294, 0.19332805968588218, 0.335823159548454, 0.13261249812785536, 0.11481205641757697, 0.19838413369143382, 0.10013366671046242, 0.40880302316509187, 0.3567598876543343, 0.3274677344597876, 0.6578585808165371, 1.016262355260551, 0.4303303227061406, 0.26337310031522065, 0.594872566871345, 1.3020340958610177, 1.0496749123558402, 2.790987524203956, 3.937867870554328, 9.00336418300867, 9.240950234234333, 9.447358958423138, 8.353611398488283, 8.662450276315212, 5.611521312966943, 4.816218288615346, 4.633872248232365, 2.6148847863078117, 3.4638791671022773, 2.3859824566170573, 0.5569519673008472, 0.44633729034103453, 0.33805643033701926, 0.22381839546142146, 0.22021762852091342, 0.2328240012866445, 0.25951978052034974, 0.20321360032539815, 0.2665045182220638, 0.3811808506725356, 0.22721760993590578, 0.23246300581377, 0.22869840235216543, 0.1455754431663081, 0.22616690694121644, 0.26393297652248293, 0.19670592999318615, 0.18113521160557866, 0.2503050968516618, 0.27314715553075075, 0.08745616651140153, 0.21064022759674117, 0.0888592041155789, 0.08276522916276008, 0.10444857267430052, 0.24981536844279617, 0.09855520765995607, 0.2038565673865378, 0.12511079519754276, 0.30718682741280645, 0.16441668762126938, 0.2405135566368699, 0.18163583474233747, 0.1544145555817522, 0.09853421230218373, 0.15678320894949138, 0.13991169864311814, 0.13850394840119407, 0.2912234980612993, 0.1097111047420185, 0.13364874408580363, 0.1838326660799794, 0.14455902739427984, 0.19350065354956314, 0.16995965503156185, 0.09727835742523894, 0.13888141955249012, 0.18454034841852263, 0.10180227443925105, 0.1526248813024722, 0.13190978817874566, 0.1787401526235044, 0.17800944886403158, 0.08145366125972942, 0.1698551161098294, 0.15638331009540707, 0.08933570003136992, 0.11670935695292428, 0.18856546055758372, 0.18100833403877914, 0.199710589076858, 0.13935289112851024, 0.1557496198802255, 0.20093660219572484, 0.09283986903028563, 0.18423496949253604, 0.13623011182062328, 0.15101900731679052, 0.08823272757581435, 0.1375945651670918, 0.1691501500317827, 0.11005582491634414, 0.0984400263405405, 0.08982168801594526, 0.09150225916528143], [0.004749634736072039, 0.1010481856064871, 0.007001379899520543, 0.029950703501526732, 0.05188274255488068, 0.04091331378731411, 0.049205986579181626, 0.05643742530082818, 0.039836412979639135, 0.011669486466416856, 0.04539658337307628, 0.036605198474717326, 0.03863931764499284, 0.012827492882934166, 0.04700598627096042, 0.020283268931962084, 0.04203127391519956, 0.0733785453485325, 0.06590458389837295, 0.058043046956299804, 0.0738517683930695, 0.07467774164979346, 0.07029718530247919, 0.01949672783666756, 0.0184794697270263, 0.04659621314203832, 0.04410643385199364, 0.05294537557347212, 0.05390277576225344, 0.04562096430163365, 0.013872023064323002, 0.014938130261725746, 0.051952222420368344, 0.056936029795906506, 0.01862214761786163, 0.03298771094705444, 0.02416173454548698, 0.005783894521300681, 0.025219024100806564, 0.01415956818163977, 0.03659742076706607, 0.07536711520515382, 0.024267648295790423, 0.056678949840716086, 0.013308969537320081, 0.03145911679894198, 0.04627416557923425, 0.07124597657821141, 0.14376546372659504, 0.03613539673096966, 0.007851498467061901, 0.018420465275994502, 0.053661848651245236, 0.03713518839504104, 0.08573533385060728, 0.04202815689495765, 0.021441392236738466, 0.028771985598723404, 0.01901035022456199, 0.04389918911329005, 0.028360125179460738, 0.04719694086816162, 0.06869637276395224, 0.07774321231408976, 0.023648576534469612, 0.08404430584050715, 0.04701498481153976, 0.08524608783773147, 0.13264809153042734, 0.14724891196237877, 0.015717069909442216, 0.09559535945300013, 0.10656149679562077, 0.032277290083584376, 0.059153006732231006, 0.04647231900889892, 0.05970948390313424, 0.1306540149380453, 0.08242249794420786, 0.12187198110041209, 0.08433903494733386, 0.10465996601851657, 0.10308777811587788, 0.17883005639305338, 0.13383692305069417, 0.05563974642427638, 0.1602363627171144, 0.08998285280540586, 0.15132741420529783, 0.11450947538833134, 0.2694920188514516, 0.20956791326170787, 0.16317103727487847, 0.2587793843122199, 0.19206059019779786, 0.031005222990643233, 0.0273389002904878, 0.052573062348528765, 0.08955396566307172, 0.16496868222020566, 0.0184415793773951, 0.058675156396930106, 0.031773824521224014, 0.05314841233484913, 0.06241710580070503, 0.09632101660827175, 0.09142461567535065, 0.11134527681861073, 0.04463577068236191, 0.08023882488487288, 0.055652934388490394, 0.018923266616184264, 0.05949573424004484, 0.07354005894740112, 0.03554217953933403, 0.008200884894904448, 0.02419398271740647, 0.09282837316277437, 0.04194553730485495, 0.07078751485096291, 0.008029035961953923, 0.07864434286602773, 0.0296676650759764, 0.01167584203358274, 0.07660581162781455, 0.011317046100884909, 0.059983436585753225, 0.031153593154158443, 0.027417950150265824, 0.013381355838646414, 0.07143599606934004, 0.07903472738689743, 0.04753414308652282, 0.039581351666129194, 0.0331346747407224, 0.008597917203587713, 0.05733998819778208, 0.07954890956170857, 0.12391388911055401, 0.008555201966373716, 0.007340917100009392, 0.04490913706831634, 0.02341731589694973, 0.05459560030431021, 0.02339438724447973, 0.06424235863960348, 0.03081601800658973, 0.022920809824427124, 0.021337751313694753, 0.0377856103295926, 0.039617720613023266, 0.020236381897120737, 0.03871925437124446, 0.0501563586294651, 0.08496030161040835, 0.11016804506652988, 0.10954346100334078, 0.04827412369195372, 0.10300759648089297, 0.03828430759313051, 0.03554022769094445, 0.04362897314422298, 0.06785576435504481, 0.03480599130853079, 0.04533482184342574, 0.05254644151136745, 0.03107630032900488, 0.01077146087482106, 0.06978835401241668, 0.036329709546407685, 0.02502333460142836, 0.07172187877586111, 0.04016586346551776, 0.0675858229806181, 0.026403803494758904, 0.00990938677205122, 0.10428488458273932, 0.06291072306339629, 0.028986722318222746, 0.008761752796999644, 0.011047750394936884, 0.07603235411806963, 0.03203123473213054, 0.06048667579307221, 0.0640854389348533, 0.08769924213993363, 0.03162437824357767, 0.04491036532272119, 0.09696884473669343, 0.03971240010287147, 0.027785129568655975, 0.06538878384162672, 0.0355079034488881, 0.03921196250303183, 0.06737853371305391, 0.05671590508427471, 0.07652839820366353, 0.07342832119320519, 0.06807839381508529, 0.01635653959965566, 0.05731649922381621, 0.017908481713675428, 0.07309386492124759, 0.018082645219692495, 0.007054322859403328, 0.028950546329724602, 0.05692374354111962, 0.05388776582549326, 0.04654344273149036, 0.04257173182850238, 0.03738056468137074, 0.02952664774056757, 0.026520936662564054, 0.03135273735097144, 0.06705659005092457, 0.03404933835554402, 0.04709657281637192, 0.025226807374565396, 0.020658667635871097, 0.010434994310344337, 0.07309270717087202, 0.07779720355756581, 0.024563494334870484, 0.024718658860365395, 0.03498779893561732, 0.026944554556393996, 0.035386632807785645, 0.0067548964216257446, 0.03262450758484192, 0.040844271788955666, 0.03209812079148833, 0.007737006417301018, 0.10254875625832938, 0.0018760180591925746, 0.04037454054923728, 0.02703945112443762, 0.013329685662029078, 0.030591201066272333, 0.13392183958785608, 0.025743258665897883, 0.01203843590701581, 0.04658256875700317, 0.006569352080987301, 0.06142331440059934, 0.125226050731726, 0.10566752796876244, 0.04719833239505533, 0.09750238212291151, 0.12522621400421485, 0.04712853711680509, 0.09013074799440801, 0.03788994516071398, 0.06076574558392167, 0.14430999231990427, 0.0678995213820599, 0.049188657430931926, 0.058822769569815136, 0.07892728666774929, 0.15338724508183077, 0.029126021581760142, 0.11748705350328237, 0.18014490458881482, 0.19099787925370038, 0.018382298476353753, 0.04872932368016336, 0.0789291420369409, 0.14022515213582665, 0.11792161807534285, 0.08610199191025458, 0.05567059008171782, 0.023100843718566466, 0.03682710805151146, 0.009583911414665636, 0.09205705166095868, 0.06332605116767809, 0.18420470471028239, 0.07013383117737249, 0.02085613457893487, 0.031817718845559284, 0.07405199983622879, 0.11643701102002524, 0.08181770695955493, 0.03442985602305271, 0.0440441416867543, 0.09505448964773677, 0.09932298911735415, 0.02958909946755739, 0.1051249734882731, 0.07549647154519334, 0.0636329514964018, 0.09518972379737534, 0.037916428700555116, 0.06269047589739785, 0.08707848013727926, 0.03945260017644614, 0.05503413165570237, 0.023078879858076107, 0.034690294196479954, 0.040662070823600516, 0.0103711074552848, 0.0240444529481465, 0.028238004779268522, 0.04927319176204037, 0.02043419393885415, 0.02103720933519071, 0.055159113035188057, 0.04676217220549006, 0.04314564946980681, 0.09218789229635149, 0.02857857820345089, 0.027659031256916933, 0.06542451083078049, 0.0211946355557302, 0.04388626461150125, 0.009887256856018212, 0.02834102044289466, 0.034510713012423366, 0.05404333111073356, 0.05155644248588942, 0.026489204283279832, 0.023440190743713174, 0.047252216027118266, 0.04095337862963788, 0.038193361106095836, 0.04237001980072819, 0.027894496161025017, 0.0636394378670957, 0.043008541397284716, 0.046165863968781196, 0.07101854542270303, 0.02381202157266671, 0.060699546011164784, 0.013815958445775323, 0.058257060081814416, 0.04019710046122782, 0.0506641546235187, 0.03565982107829768, 0.039858952004578896, 0.03220798091206234, 0.018985352835443337, 0.020827608277613763, 0.06072933581890538, 0.034485201686038636, 0.08002290443982929, 0.09225089321262203, 0.05499697603227105, 0.08890425990102813, 0.010428041314298753, 0.0026508429618843365, 0.05842763159307651, 0.03474228906270582, 0.01599775016075, 0.21476217516465113, 0.14891512255417183, 0.09832027339143679, 0.12215948168886825, 0.09428060773643665, 0.14351969410199672, 0.17018902319250628, 0.10275388587615453, 0.274213146767579, 0.1246592725510709, 0.12970963201951236, 0.12558535410789773, 0.21742590644862503, 0.10530843981541693, 0.10471892222994938, 0.15035603195428848, 0.10398205122328363, 0.11492179037304595, 0.11561883031390607, 0.15633876639185473, 0.20072822197107598, 0.13002690015127882, 0.17735249974066392, 0.14272172207711264, 0.1270438969368115, 0.14775272633414716, 0.13409976207185537, 0.05734800339268986, 0.08941572581534274, 0.1484311680542305, 0.14444582018768415, 0.13277784863021225, 0.0849943068169523, 0.13889451103750616, 0.10914671627688222, 0.1185640953190159, 0.19124222395475954, 0.20304603822296485, 0.14268007274949923, 0.1546476047951728, 0.09640055999625474, 0.15382805111585185, 0.1498351333430037, 0.09171531492029317, 0.2059858335996978, 0.1501364601426758, 0.1692623330745846, 0.10051944991573691, 0.25195738475304097, 0.14880463160807267, 0.08566166827222332, 0.12142298917751759, 0.14124012814136222, 0.14806595718255267, 0.15787876734975725, 0.13930707093095407, 0.22309413354378194, 0.08096192163066007, 0.07890567532740533, 0.12882104376330972, 0.12518168514361605, 0.14486712258076295, 0.19790071353781968, 0.12069961783709005, 0.10318940039724112, 0.17932921007741243, 0.16321578877978027, 0.17044160573277622, 0.22855590999824926, 0.263089778018184, 0.104679877840681, 0.208665699174162, 0.18198140838649124, 0.1567981409607455, 0.199966125364881, 0.15743557160021737, 0.1364453198038973, 0.31506246887147427, 0.17022016370901838, 0.26988369470927864, 0.21148746338440105, 0.2160332366474904, 0.33329276251606643, 0.3120660624699667, 0.15353588241850957, 0.2890890813432634, 0.27590061246883124, 0.18200024409452453, 0.10510269421502016, 0.24811549403239042, 0.45193777419626713, 0.2868482703343034, 0.18012654385529459, 0.32984159770421684, 0.4850624967366457, 0.1164532195252832, 0.11560609505977482, 0.1379420980811119, 0.20859267184277996, 0.23385537875583395, 0.1362536082160659, 0.15530630538705736, 0.1382399071007967, 0.13445069402223453, 0.30333044996950775, 0.25265188654884696, 0.18242043326608837, 0.15064349543536082, 0.1208425777440425, 0.23877479368820786, 0.30927612155210227, 0.1760407240362838, 0.11483887763461098, 0.18019498471403494, 0.2722253487445414, 0.22492242918815464, 0.1997373509220779, 0.20424953458132222, 0.12868140125647187, 0.1399243893683888, 0.13180971698602661, 0.11410147970309481, 0.16848865896463394, 0.20453693869058043, 0.16834201058372855, 0.11361550656147301, 0.14155653538182378, 0.1425773001392372, 0.17496711836429313, 0.10722153325332329, 0.1678488534525968, 0.16734774049837142, 0.1532075711293146, 0.15820853324839845, 0.11839404702186584, 0.11898006167029962, 0.1612384253530763, 0.1618745201267302, 0.27527845522854477, 0.11523642388056032, 0.1322948292363435, 0.19210393162211403, 0.11606207801378332, 0.1261984571465291, 0.08452024514554068, 0.13318352139322087, 0.10070820775581524, 0.09553707859595306, 0.18478954676538706, 0.2005177192040719, 0.15990830375812948, 0.0975623624981381, 0.12015661064651795, 0.15440122660947964, 0.14005442848429084, 0.18474816461093724, 0.22236538905417547, 0.15761015441967174, 0.19682982412632555, 0.19163922843290493, 0.1400051944074221, 0.1088562842051033, 0.2180419335491024, 0.07690074111451395, 0.18907086312538013, 0.19234330393373966, 0.08490366832120344, 0.17187368357554078, 0.15133499895455316, 0.10220909010968171, 0.26884670660365373, 0.22092498431447893, 0.1263304110034369, 0.18780277023324743, 0.14801658951910213, 0.10916558909229934], [0.014953623522160342, 0.03597681090468541, 0.04837551219679881, 0.0453061267035082, 0.049296001670882106, 0.03576216324290726, 0.023415516188833863, 0.09604734223103151, 0.07801333922543563, 0.012234873120178236, 0.06408791028661653, 0.057052884658332914, 0.00782841303589521, 0.015864696069911588, 0.03090965106821386, 0.0279698816666496, 0.05131086953042541, 0.009777842951734783, 0.019926963832404, 0.11885864631040022, 0.008692150477145333, 0.06826743367128074, 0.024293940732604824, 0.03451712145761121, 0.08195693386369385, 0.009333219495601952, 0.036804839910473675, 0.02822981889039511, 0.033075692554120906, 0.037071916594868526, 0.026749273238237947, 0.07080149691319093, 0.026358107606938574, 0.05053965935076121, 0.011586056079977425, 0.08449461878626607, 0.02242456906969892, 0.09398532944032922, 0.03205091648851521, 0.029920570450485684, 0.011308248867862858, 0.07347696897340938, 0.0442531119188061, 0.05679250956745818, 0.06351715419441462, 0.016337857887265272, 0.03198818645614665, 0.026207446062471718, 0.04622741398634389, 0.04242949180479627, 0.005945859902567463, 0.004440784878170234, 0.035003640077775344, 0.12134638469433412, 0.02568313171650516, 0.020769314432982355, 0.06251136597711593, 0.07833782845409587, 0.053173749256529845, 0.05886824837944005, 0.03822989332547877, 0.007225016825032071, 0.024508516034984495, 0.02133928755938541, 0.05074428059742786, 0.006534191907121567, 0.02083141549519496, 0.03643764750449918, 0.06901474669575691, 0.03378208355570678, 0.031880723472568206, 0.12292716666706838, 0.05970970283669885, 0.10490842221770436, 0.05678021960193291, 0.01490351742177154, 0.06511120576760732, 0.03633662636275403, 0.06142484322481323, 0.1383056613849476, 0.06285267227212898, 0.05787976704596076, 0.19401349243707955, 0.20957000611815602, 0.05731788703997154, 0.05123532631841954, 0.050825282305595465, 0.014448497404373484, 0.06146605097455904, 0.0172749176635989, 0.0677508840453811, 0.050569638406159356, 0.07450403456459753, 0.05027093138778582, 0.06406632863217965, 0.007266482007253217, 0.015397762726934161, 0.057571063298382796, 0.008245169774454553, 0.05245269712759182, 0.04262824266334064, 0.04772168009367306, 0.022684801297145896, 0.0505841696576681, 0.07391859136987478, 0.067500594741432, 0.08417781820753589, 0.019602869797381572, 0.0411003312910907, 0.0873558281455189, 0.06814059321186505, 0.020897542708553374, 0.009021127843880095, 0.056333435568376444, 0.0346388707839651, 0.01948953085957328, 0.00591800524489372, 0.027842048584716395, 0.025534147425787523, 0.06817463552579284, 0.012457058219297323, 0.029276543973537628, 0.01637162931729108, 0.016560355616093148, 0.024389110039919615, 0.049310748145217076, 0.06562667927937582, 0.054133030789671466, 0.0397446835268056, 0.04169960811850615, 0.027612762060016394, 0.09599799683201127, 0.045100971110514365, 0.03528127010213211, 0.025908238094416447, 0.060124852825538255, 0.022686903430439997, 0.0409701289026998, 0.044164766659378074, 0.051887143490603194, 0.030154799678712152, 0.048954161029541865, 0.024482707849529106, 0.012448268407752039, 0.05955551052466035, 0.040693801347515546, 0.0341771547391545, 0.05757431761594489, 0.05378974667110015, 0.04150223023316357, 0.03201445477316156, 0.07171058328822255, 0.07999127410585061, 0.09577316319337115, 0.035998451930936426, 0.039680413538008, 0.05023108547902666, 0.018629513433552347, 0.03640715265646577, 0.062163209659047425, 0.03056391786230961, 0.04197306727292016, 0.04112468486709986, 0.0190740654579713, 0.046577819011872634, 0.00045517934722738573, 0.01208163075716584, 0.017909602356667165, 0.03576606322894804, 0.017957533964363392, 0.05025343154557049, 0.08545114324078895, 0.01438480258002528, 0.021001688292017207, 0.02605768993817037, 0.038619832557742484, 0.034970313936355524, 0.02169292463804595, 0.018202118008048274, 0.039174547127913684, 0.029177849464758765, 0.030174102939781733, 0.01759317656251369, 0.0325707092997618, 0.03891227213898674, 0.06577057429240085, 0.06363767897710204, 0.03328761653392576, 0.005597477229457581, 0.043001116209779866, 0.07638934199349023, 0.026045683844131418, 0.026696508393797558, 0.02167957711208146, 0.03006755836395314, 0.039633339110878296, 0.05664497803081758, 0.011020453275705222, 0.09098359441850334, 0.1151441378169693, 0.04616145190084353, 0.050224962760694325, 0.014391289878403768, 0.036860304317087866, 0.04030726857308764, 0.04507019795710221, 0.026706249082053546, 0.021000335727876518, 0.03984669172496069, 0.057310276315547526, 0.002730273868110089, 0.057391960799577646, 0.05279084558424074, 0.05087861674837768, 0.005072513504273957, 0.020654188774642535, 0.05301855504512787, 0.004776634532390744, 0.031380241343867965, 0.015912366070551798, 0.06052170145267155, 0.03590090404031798, 0.066926313447766, 0.02568195170169929, 0.013821906759403646, 0.0413400412799092, 0.042237290399498306, 0.05675634842191357, 0.059785939956782386, 0.039948692501639016, 0.025172673267661594, 0.07558673896710388, 0.036623559208237566, 0.003424798160267528, 0.06373927157255821, 0.08186660706996918, 0.009116542059928179, 0.006798086169510498, 0.014441701187024591, 0.03690428027766757, 0.00856853093864629, 0.04755578782351222, 0.010223167737422045, 0.09806918998947367, 0.0349210761487484, 0.01585566784342518, 0.03486330737359822, 0.038665207466692664, 0.046782833596807905, 0.09011304035084322, 0.030615643700002693, 0.04717231640825048, 0.05739777552662417, 0.04770891886437312, 0.04426491948834155, 0.06324881585896946, 0.004126541925870697, 0.12448522407794371, 0.1266300753923133, 0.1320772315375507, 0.04526624739810359, 0.05949674727162346, 0.03107694414211437, 0.017835792059486266, 0.08727971347980201, 0.005711734575015726, 0.019859816165990196, 0.0323005452810321, 0.026455310398887377, 0.05070565552159678, 0.07819842343451455, 0.030901114514563233, 0.029818116963724606, 0.07087901423801668, 0.08775410911766812, 0.09833250398514792, 0.055863262750790454, 0.023112400813261047, 0.11326368403388187, 0.032575028599239886, 0.08412791619775817, 0.08290270459838212, 0.046565907541662455, 0.027871676975337323, 0.09140091890003532, 0.0977530053933151, 0.06635842204559594, 0.014226106359274127, 0.0281842287586187, 0.026081052747031208, 0.05505300076038111, 0.0638076604809612, 0.017667164975136984, 0.05882232428120915, 0.00977805817456101, 0.04004906055342872, 0.07608368105138652, 0.04504223383264616, 0.07279607074451633, 0.013765586099907523, 0.00984440524916863, 0.02730644802795723, 0.09851755850831978, 0.014854790788376704, 0.10734081122791395, 0.0722999672871083, 0.017030470917234197, 0.052654539031209424, 0.030259106679295655, 0.03653207095339894, 0.03501326202240307, 0.020010871048725676, 0.028354588757792953, 0.03329727187519893, 0.06209274273714982, 0.04012742392660584, 0.04694950512202922, 0.02486486566340318, 0.0596838427009061, 0.08421513339271769, 0.06946497058379464, 0.04040175139380153, 0.020021877098770346, 0.09580496422131546, 0.09754646569490433, 0.04620056308340281, 0.025486562772130128, 0.05121745911310427, 0.012863519514212385, 0.04997998723411001, 0.04234477564750705, 0.06362231652019545, 0.03999043088697363, 0.01922500345244771, 0.07917019902379252, 0.03715126331371721, 0.010104917637363542, 0.013776580090052448, 0.02596396967419423, 0.0274405967866187, 0.023032401004456915, 0.03533196992066223, 0.023097502198652364, 0.05009904256439768, 0.00844358759422903, 0.04168943327385932, 0.05318795396306086, 0.0620489040738903, 0.021256174441077746, 0.07075221830746159, 0.03771317671635188, 0.058039985597133636, 0.09261845669243485, 0.10227655875496566, 0.15858869097428396, 0.12061757341143675, 0.13171075901482254, 0.24102891882648692, 0.22514209005748853, 0.11824301254819147, 0.16014476685086265, 0.07654934903257526, 0.15506911498960108, 0.09887443506158888, 0.06320971209788695, 0.10293244660715573, 0.13460736139677465, 0.11132801446365193, 0.11382667726138607, 0.12738215300487354, 0.13724203017773107, 0.27532405278179795, 0.15930676338030025, 0.11424203505157493, 0.14838074654107913, 0.15269596420694143, 0.13768999051535502, 0.11214978716452606, 0.09148602839559317, 0.146000842214562, 0.13878774567274377, 0.11032235241145827, 0.06670282309642062, 0.18897668458521366, 0.15876311052124947, 0.08410733644268475, 0.05361160154279787, 0.18174916069256142, 0.16199874080484733, 0.18057352455798537, 0.09467994255828671, 0.21903029613895342, 0.16043672774685547, 0.14412481163162738, 0.10315333202015609, 0.14085752132814378, 0.14510417939163744, 0.1459780434379354, 0.17816126259276643, 0.12080460204742849, 0.08582521535572596, 0.0950434835976921, 0.13688441889826208, 0.06427233398426324, 0.14397651568287984, 0.17670767731033266, 0.08771068605710752, 0.13521050481358543, 0.137680743355304, 0.12067930525518022, 0.10200824268395081, 0.19964332081144676, 0.12862698698882014, 0.14548605890013278, 0.11160611946252175, 0.07264479878358543, 0.15943672828143463, 0.2176721510477364, 0.11041103905881755, 0.2526097622467205, 0.17493495368398726, 0.105732117081061, 0.16361828515073285, 0.13474212057190016, 0.13083116558846086, 0.2570368809392676, 0.10652972545358352, 0.18985059316037223, 0.1784956149640493, 0.10773420886835083, 0.28729047160595655, 0.2084933131118305, 0.11970249048317783, 0.30327217653393745, 0.33759902988094836, 0.44058997998945415, 0.2006762716337107, 0.23353220312856138, 0.11356857314240187, 0.10289873825968243, 0.2475660969503224, 0.09185276067000814, 0.1594774128170684, 0.17214551742654294, 0.15820011729374528, 0.1077651118976064, 0.21172903245314956, 0.11545966932317242, 0.11460021778475493, 0.17860732303233817, 0.21954739495413378, 0.18728549330262467, 0.10056632396299392, 0.13926239364081994, 0.2541011228458956, 0.20247461419785395, 0.18790229223668575, 0.32194948056712747, 0.20896678848657757, 0.14643225265899673, 0.14252900116844103, 0.188632283534389, 0.2308360845199786, 0.08325752540258691, 0.14860353927360848, 0.16602141869952902, 0.15885945613263175, 0.1864585033035837, 0.105030846898444, 0.17920396523550153, 0.1749814418144524, 0.22208659385796636, 0.20060466922586784, 0.09510411706287414, 0.16396998893469572, 0.10414859658339992, 0.14011141058290377, 0.07463009576895274, 0.14621746027842164, 0.10673063967260532, 0.29040235618595034, 0.11480905071948655, 0.13849731360096484, 0.18824327940819785, 0.11064572841860354, 0.09268834473914467, 0.16536332666873932, 0.1302596673485823, 0.12870393285993487, 0.1583306907559745, 0.09590369212673977, 0.11522702829097398, 0.16995220386888832, 0.16235479357419536, 0.13429732178337872, 0.162803971034009, 0.14395628473721445, 0.14582526491722092, 0.1206948458275292, 0.27103209402412176, 0.19233138504205272, 0.19525060808518901, 0.09929227904649451, 0.23649320908589289, 0.10785652964841574, 0.16030904866056517, 0.14162413019221276, 0.16812577843666077, 0.10422145322081633, 0.1801103205070831, 0.34419120114762336, 0.11758808206650428, 0.07178105763159692, 0.0952603094629012, 0.1593919619335793, 0.10622539295582101, 0.1715667312964797, 0.0726259259681683, 0.091283822839614, 0.22463950765086338, 0.09944334320607595, 0.1069843651202973, 0.24728259653784335, 0.15653978451155126, 0.07163718488300219, 0.1686759028234519, 0.20906479650875553, 0.13168607518309727], [0.08844069219776429, 0.03702211848576553, 0.07442162648658268, 0.023106066582840867, 0.03715258433658164, 0.027214625806664117, 0.005560135605264804, 0.04708898064563982, 0.03396936823264696, 0.057902320913854055, 0.08626587296021171, 0.03676549495139625, 0.08544795200577937, 0.0711807566403877, 0.021163537712709513, 0.029486939129128587, 0.04384693078463897, 0.02218969602836296, 0.06982779916143045, 0.048299341870006174, 0.026104818171006627, 0.024360067945963237, 0.016279532501357608, 0.03134204300295096, 0.041992593178292736, 0.01492651008447865, 0.04278466141840909, 0.07258170880959369, 0.009095947461901233, 0.09172795369522646, 0.02711374752834672, 0.035522286270861514, 0.09150655620032921, 0.05312955065164715, 0.09022212863783352, 0.03337916416057851, 0.03200865117833018, 0.018670066237973515, 0.02116688665410038, 0.034698431845754385, 0.07651852763956413, 0.07010413784882985, 0.029317085645743646, 0.024925783000071533, 0.07562700047856197, 0.0775112614792306, 0.040592457371531054, 0.0380954569845926, 0.06046076741768047, 0.05378022491640877, 0.06574244689545594, 0.016475466909469105, 0.04428162152180448, 0.017313874850515276, 0.021652466457453556, 0.05328280043613631, 0.05778234903118573, 0.04404423445521388, 0.05119509449286852, 0.06498859554994851, 0.0403694679698674, 0.040062612170004286, 0.06045525326044299, 0.043763724897871725, 0.07564625178929418, 0.009683365697128465, 0.09428819990716875, 0.05279584394884296, 0.07228390721138567, 0.042365945409983397, 0.05948047568381298, 0.07086400059051812, 0.01463392392906826, 0.09864189793006517, 0.01081911974324612, 0.06480708849267103, 0.024676074426679406, 0.010070932839880697, 0.02564866081229411, 0.052586844030884095, 0.019004112473339774, 0.10120457096491009, 0.06436995608964935, 0.09493686666246504, 0.09002161517855711, 0.07535851371358149, 0.03384672090760432, 0.05323530669556931, 0.01091859814550844, 0.07620549717103131, 0.0878812390146777, 0.053015771991340443, 0.010583048133412376, 0.05950564191152807, 0.00204145298084768, 0.05015338632802013, 0.04166195525613148, 0.010083003871841356, 0.0392067006760044, 0.07588675216538832, 0.042639905514079146, 0.029148710891604424, 0.06747900566551834, 0.03210023962310515, 0.0492653509718366, 0.01484787768276874, 0.06386392269632779, 0.08252299958257936, 0.06548137418576516, 0.02362503932090476, 0.021661461287294514, 0.02838656604581047, 0.030142337163852062, 0.07229276103316806, 0.05345417717762757, 0.06970215355977416, 0.023926789144752547, 0.02702968817175133, 0.031019418420328293, 0.03231631220842246, 0.0553485091222683, 0.046322828202391975, 0.08795164656476118, 0.02479503698850749, 0.05746102877310477, 0.03860133081616368, 0.020630172875826247, 0.02907968188083032, 0.038258588465396315, 0.02974520652060164, 0.05170931006432511, 0.03909572733391542, 0.014335466457850998, 0.03831731461104937, 0.02705285431147786, 0.04763793614984024, 0.04182527969533112, 0.013715878903894918, 0.025379869766766205, 0.03441628214204684, 0.04346992718637921, 0.06294921826338395, 0.058902995733660646, 0.012346802905085497, 0.02422308603854617, 0.06904150111950003, 0.018790680078382138, 0.010866172833630117, 0.07533490599598736, 0.025000149908009917, 0.04315117846999783, 0.045076480237185024, 0.023976433258212637, 0.03929436315956991, 0.043463678302941844, 0.04626488502253778, 0.03867406499921344, 0.053092339367140085, 0.03174755249347072, 0.031866021527093835, 0.05441558867460117, 0.04253610131854657, 0.03225729291443713, 0.02007799830607837, 0.09052247580257244, 0.06581426452612504, 0.04027148592285812, 0.044730086519848555, 0.025051447155419737, 0.08222497534006834, 0.0196508459339384, 0.05736602273827884, 0.04420112076331861, 0.03327310383610893, 0.06652476702583954, 0.07834188800188713, 0.029212767512944993, 0.016260821103060152, 0.10374464560300112, 0.05384292897360865, 0.015952067260514013, 0.01587265003763605, 0.031006497629277874, 0.052972222765674815, 0.010820065981533844, 0.039490557319368236, 0.05931873572990298, 0.02593853627331555, 0.03747582304640673, 0.046413693053182214, 0.05791594674519729, 0.04516936001891736, 0.010049289030575892, 0.08678063401021063, 0.06929587965714745, 0.057073163843597285, 0.019152003951603547, 0.0314129663456697, 0.09017993754241616, 0.03630726700066589, 0.024105030752252787, 0.050037444307236, 0.029439577119774185, 0.026230185467284173, 0.04354732947831508, 0.04933071933919564, 0.010649615069269203, 0.029369449730438646, 0.04954133342835121, 0.02682895392354112, 0.03061488485400332, 0.02357135235797614, 0.016570005391258746, 0.014120453288342105, 0.048797482522786595, 0.037114144797669724, 0.0666563052800484, 0.007506192459914018, 0.05706640658900142, 0.06915626683621667, 0.036054855154361576, 0.034139242125093006, 0.047650344858993776, 0.0036097304609938874, 0.023619762650923803, 0.030256143654696643, 0.04142701356613543, 0.00973790427451604, 0.162737266800832, 0.04957625518727582, 0.025652761178207584, 0.02369579568039626, 0.004183388582532643, 0.0760671756870579, 0.02404079230473144, 0.03241181548219174, 0.027521706106199417, 0.048984214299707673, 0.07099568727426231, 0.002473018348609912, 0.08548934158170596, 0.019103001795883756, 0.08908040123060346, 0.022584526013815776, 0.10336751583963633, 0.06767220897017978, 0.052281427997513674, 0.06156150600872934, 0.11264261775068007, 0.07425900708767585, 0.08378928163438104, 0.019497872599458788, 0.02067462010018062, 0.010761232224467676, 0.04848129792662803, 0.029818675429851282, 0.03406154297408648, 0.07522726489696652, 0.06272637358051725, 0.09635381953557953, 0.05553687733481638, 0.07687337070819922, 0.08358225211850367, 0.06126384912931826, 0.034659402299439535, 0.08139951416524127, 0.09152182217803784, 0.023740189099044073, 0.05200670719204936, 0.04382854407595005, 0.05309779415256344, 0.03416992993152235, 0.03610388514061924, 0.04539168148767203, 0.09691210012533702, 0.10169189481530339, 0.09857914192252792, 0.052920702873962, 0.012036687221552711, 0.07268005079822615, 0.119295489275828, 0.012253216227691155, 0.017575196179677732, 0.059654427677742206, 0.09867124987067655, 0.13691008236492053, 0.013253654487925814, 0.009855740627244813, 0.019210112259315792, 0.037174796816543676, 0.07533400799729861, 0.07523047097492963, 0.016971941440715455, 0.019415208480495494, 0.03934804641176015, 0.045749281634925865, 0.06720361692714505, 0.08204964295146056, 0.08931496442528442, 0.007172546056608553, 0.0367680071212817, 0.052574669098248705, 0.0808319344650954, 0.09294529110775329, 0.03134586877422407, 0.022362089512171224, 0.06970434289542027, 0.012937622959725559, 0.0287829415537999, 0.04551141588308383, 0.053254376180120744, 0.013610166461148765, 0.025242054798582103, 0.017871010677481536, 0.07968730526044965, 0.021433200781757478, 0.01905043733131606, 0.08425980326137505, 0.030690398380102124, 0.043829078422277234, 0.047963412434910424, 0.06339887069771066, 0.008928739734983537, 0.021249426463327836, 0.029829802078893408, 0.08137031807564199, 0.03536597883794457, 0.047924108293955214, 0.05643371456244495, 0.07659978538868017, 0.05623106742859818, 0.04990554240066558, 0.033058237240766175, 0.028015931929985527, 0.07591013723867945, 0.06590690682060085, 0.06007325500831939, 0.039454099314752966, 0.012903601054858882, 0.0319465668144403, 0.010963682689180132, 0.03382638235052582, 0.06665631270152517, 0.048838059447007254, 0.030723806157766376, 0.02580176958872471, 0.029018842469668016, 0.029177214928495232, 0.0018342303906138113, 0.014223532962205354, 0.0386509470990859, 0.025461320474278182, 0.1804080998408608, 0.131663647480309, 0.18186288740253076, 0.1385793654480949, 0.24868574546417221, 0.10459844197612256, 0.12318435052293353, 0.10380242922110483, 0.12008560195681639, 0.10130838258191943, 0.2694693685043603, 0.12231748492922634, 0.12050216944771819, 0.12780447956174612, 0.10493092413526028, 0.20745473681017756, 0.09215133410179988, 0.14086348819546402, 0.17669657478109002, 0.11279581929557025, 0.10055479098809883, 0.18214573472505435, 0.11406955251004547, 0.13449793914332986, 0.11404949967982247, 0.14696529280627146, 0.16480941732879728, 0.12493532180087641, 0.1064674518420361, 0.14682665962027386, 0.13721633702516556, 0.1385354154626839, 0.1597120799124241, 0.13712616608245298, 0.19942673243349418, 0.11439770052675158, 0.11080530501203611, 0.12533081229776144, 0.1729040071950294, 0.09416261367732659, 0.1828575730905868, 0.14727436762768775, 0.14595791639294475, 0.15130954328924417, 0.1720232263323851, 0.13023263833019882, 0.1012349767552223, 0.10260582741466351, 0.11951099411817268, 0.1862031006021425, 0.12629242788534611, 0.11369309067958966, 0.1811425291816704, 0.13181314570829272, 0.1350439223460853, 0.14698032871820033, 0.19442096119746566, 0.12345531606115401, 0.14665713824797422, 0.16124789515743032, 0.11861431645229459, 0.12986655172426254, 0.14681751636089757, 0.09461884896154515, 0.15862937550991774, 0.10461877682246268, 0.1718842814443633, 0.16408286959631369, 0.1863289243192412, 0.16865096666151658, 0.13133796339388937, 0.16203997452976182, 0.15189480094704777, 0.28932193759828806, 0.21961853723041713, 0.1641219956218265, 0.0799839268438518, 0.1005199619976338, 0.14224468439351767, 0.21780269482405856, 0.13695597677724436, 0.29337697313167155, 0.2657876629382372, 0.3077813470736146, 0.12140827981056646, 0.21703290956793353, 0.16153049014974385, 0.20926248980686069, 0.17541902692755684, 0.14547121594659984, 0.1996057532960549, 0.08187442188500427, 0.18873383902246132, 0.0646566848445218, 0.17116849485319108, 0.1347046421142295, 0.06851728510810062, 0.12217845098348334, 0.15045580628793687, 0.25251500483136624, 0.11439034584327601, 0.15308599249692634, 0.1376906139194034, 0.12476471689296886, 0.22545538027770817, 0.12646975665120408, 0.17023126623826101, 0.15325812622904778, 0.19763183343457058, 0.254812486236915, 0.13795585749903694, 0.17391599976690486, 0.10382292733993381, 0.11045815801480785, 0.1988325541606173, 0.2549792022909969, 0.10578509900369681, 0.1436712109716609, 0.1544715228374116, 0.1051445142365992, 0.1930833439109847, 0.13939179450972006, 0.21333327371394262, 0.1637910571298562, 0.21014999452745542, 0.10632692617946304, 0.1466303170309402, 0.17542192130349576, 0.11358657022356056, 0.14183773513650522, 0.1421112462412566, 0.1942494953982532, 0.1536622701678425, 0.10302513343049213, 0.12740717822453007, 0.14069855329580605, 0.14828720624791458, 0.1004245960211847, 0.1875876958365552, 0.10371141965151764, 0.15196955006103963, 0.14592975931009278, 0.17515218030894175, 0.18238296965137124, 0.17065486928913742, 0.12868621037341654, 0.10748581946245395, 0.07387127945548855, 0.15553916164208204, 0.16277676390018314, 0.10654762605554424, 0.10566026976448484, 0.10956697966321371, 0.24145035480614752, 0.16565717261983082, 0.12238921350217424, 0.12617745436728, 0.1469817981706001, 0.2226107133901678, 0.27924146445002407, 0.1828576176194474, 0.11070006105001085, 0.13918442360591143, 0.09671441424870864, 0.14346562122227624, 0.14287861209595576, 0.133245772740338, 0.2009992691455409, 0.10323363239876926, 0.17965061939321458, 0.0821383592847269, 0.12146593726356514, 0.0896355944860261, 0.10473958362126723, 0.1498129579704255, 0.1652274394291453], [0.0140921477759548, 0.05300045777403284, 0.03404914168640971, 0.010931913202512078, 0.037379948698799126, 0.03352785344759468, 0.013314469779288629, 0.06064003689971287, 0.024860935991455335, 0.05690847014193423, 0.04166887949395459, 0.006123082912381506, 0.05705016097635962, 0.03289011481683701, 0.07583947735838592, 0.04586776551150251, 0.08808541868347675, 0.03481434418063145, 0.02718525160162244, 0.028400562950992025, 0.046060527238296345, 0.017452146239520516, 0.02124699778505601, 0.03369906320585869, 0.032768165110610425, 0.0027867823837368633, 0.04782821168191731, 0.019805420452030376, 0.037027061189292, 0.02435388585581677, 0.018750203344097827, 0.06291745434282348, 0.04223991389153525, 0.056178512240876444, 0.0171757667339989, 0.045504276422434486, 0.06736102644936182, 0.005802362866234034, 0.0317105081921909, 0.0394633872929262, 0.020562104946293402, 0.04513177394983359, 0.04373397219751496, 0.005123586252011592, 0.03862548772303853, 0.03900262861861847, 0.03228090063203126, 0.017019624428940006, 0.0137349604483461, 0.05141635469044559, 0.06860583074740134, 0.04392732022097334, 0.032516168867005035, 0.04235455715388525, 0.034192097882623784, 0.02685468232812127, 0.028992952647968195, 0.04051580835948698, 0.026787803690240253, 0.04303057576180436, 0.021577873194473796, 0.09238085069227964, 0.03676166175864637, 0.0606133158726152, 0.04334786244726274, 0.05855190051079262, 0.03700047003803775, 0.04996212002879474, 0.05364091266528703, 0.057625102781457826, 0.03083874071307946, 0.11195676939678378, 0.023518719244748354, 0.07086405254085548, 0.05292514091706835, 0.022157642670208588, 0.015161182745941915, 0.03312443681352306, 0.06659034319454804, 0.007206325835795724, 0.04501639225054532, 0.060197345810593106, 0.07621746059157886, 0.04882679364527576, 0.04929201633785851, 0.021817696360812988, 0.0708176608895883, 0.03463670742348768, 0.05943829943134915, 0.04136828370974399, 0.04802380099135917, 0.1082969646085985, 0.02465189896611264, 0.07052357745124027, 0.07517915888456628, 0.011769527045544237, 0.06035680366039742, 0.01602633583388524, 0.030484033086395357, 0.005867901927558705, 0.03278708245488815, 0.03802453364187386, 0.055676345436950214, 0.04837512256926857, 0.05764280300354585, 0.10421622850117274, 0.046089597162790596, 0.04167847917415202, 0.08550583952455781, 0.08861160880769603, 0.10996025856002234, 0.030351403875101823, 0.04415737115778029, 0.07863447230192833, 0.054551824723603204, 0.06854495237348601, 0.042420304016559385, 0.016995834885165095, 0.007888984346209327, 0.026506936046644114, 0.019206327306164894, 0.009783986079128226, 0.04543914183159359, 0.045280875128810294, 0.028188510950712953, 0.02053843785688514, 0.11606208543526009, 0.0391164035681868, 0.020058667214470915, 0.08158100637956522, 0.03244956853450276, 0.032686859121895395, 0.010760460390883964, 0.08114668671623804, 0.006359849821819807, 0.013705714263778646, 0.12174689953099005, 0.08393340671318583, 0.075888414576184, 0.07480451531591825, 0.09692559979157522, 0.059986063788528554, 0.10170907553401776, 0.03388299708603881, 0.04587593655742239, 0.0243317475906224, 0.041778661689022556, 0.020165996611467563, 0.034280565596418455, 0.03299224546935875, 0.019947352484450676, 0.03344065109558869, 0.06189268940943293, 0.022091827158874366, 0.07327914208872244, 0.005922117670706939, 0.07650788524188101, 0.04817338085558731, 0.0888889939233195, 0.025658191843831446, 0.02082200320728589, 0.05656037319567986, 0.029696235906158108, 0.04316084865422454, 0.06572252765181474, 0.05285504877974745, 0.05497007317899261, 0.07910365806310438, 0.10276107728714123, 0.03715738232131116, 0.028379730865708552, 0.01080529817045317, 0.05240044622041751, 0.026795850426424295, 0.026623232442943845, 0.031225603743223473, 0.031924628929118626, 0.05711613790481351, 0.054957241445663385, 0.10722936291131191, 0.040589243872091174, 0.0696274267102126, 0.015120715288503561, 0.0165317050050362, 0.03571469547750894, 0.057374160387553275, 0.028824073233408853, 0.07020110686426051, 0.09341502605821006, 0.011239100185775897, 0.03262726837419905, 0.04016369268356357, 0.06119913014117628, 0.046332398196682334, 0.007378253621936892, 0.03128116462903563, 0.023792937245161738, 0.015558954419248039, 0.03463468136033043, 0.07176880477345549, 0.029995751865499187, 0.028224121051607653, 0.013302890420163749, 0.024905008431233, 0.014963482954044593, 0.02817488697473891, 0.07055828769807704, 0.03556340867362451, 0.0046986723828013055, 0.012211583598400466, 0.05488569840963464, 0.013728719914070098, 0.05317505172570236, 0.014639272030763095, 0.05033653353166301, 0.028431306418497115, 0.07474577432731166, 0.03902102274878416, 0.051623925974126905, 0.012289599089854164, 0.024750996090006083, 0.05869273416465148, 0.02981193487357814, 0.07985467440448701, 0.03911129759217147, 0.028601549529412296, 0.0852148063131608, 0.0632662489078939, 0.021903073029534426, 0.046847281701047905, 0.039309836938627996, 0.04100566293345764, 0.0018890645515057258, 0.06186493679706473, 0.03423076748731546, 0.04314557525503915, 0.05272439739201218, 0.037990413402440026, 0.043829698115587234, 0.03505609878629912, 0.03237403274397366, 0.03650538332294673, 0.028138089437561575, 0.03416463099711109, 0.05117078544571996, 0.03876985028909985, 0.018340107380936388, 0.06869685515994206, 0.028913542846566997, 0.0473352252447512, 0.03800016893364955, 0.04991339061234612, 0.00900694911251776, 0.02618445061671082, 0.019700323064171243, 0.06786152342101559, 0.012248881157574942, 0.04937920755764935, 0.0863491790369153, 0.03685894247610122, 0.03692338315886445, 0.013432754203677177, 0.06075613848224748, 0.02202699313784251, 0.03995454062533099, 0.05116361258842517, 0.059486995451152325, 0.018259704957017675, 0.014737345918547362, 0.10769648550194688, 0.10653771838406101, 0.055847577459644526, 0.02901866249885643, 0.04071425493748393, 0.007239822671181173, 0.1296085663489066, 0.019376893251319416, 0.02328876293177018, 0.10274141779518686, 0.08750687004067004, 0.12752936541801319, 0.02507427747332258, 0.02273482947202865, 0.012175607989775017, 0.02457829275954282, 0.06087135690904688, 0.041235327953472733, 0.010871579379454488, 0.09614512760890648, 0.017973829671973363, 0.03737653481948655, 0.027378449340176303, 0.059962125815218315, 0.013013693096581846, 0.04811456936295144, 0.030492259793390986, 0.01851222255936591, 0.01166741401902982, 0.016447604830318596, 0.03639814298367128, 0.05137707652465906, 0.033787809225032106, 0.033561632299097255, 0.05638948627165519, 0.06367007372318767, 0.03188294620485976, 0.030927672269172035, 0.03755566700419877, 0.004581080938805826, 0.08467698673484847, 0.06936921869055368, 0.02542946007451974, 0.031078179817995988, 0.028057059898856096, 0.12488510808907449, 0.02282616558659356, 0.06155851144285407, 0.04460940217541065, 0.03228864123229869, 0.10612426791340113, 0.04097853372513782, 0.016831950124469586, 0.02775518390990328, 0.025713812101457734, 0.04695174269727431, 0.05628826103929896, 0.017747543279256206, 0.06324094909359701, 0.02491160797944758, 0.024482709704898298, 0.03716546802024823, 0.07062699572998099, 0.037044234486529604, 0.031874652704573236, 0.018835362934623845, 0.04238088855345268, 0.05807656605611555, 0.016168054498848505, 0.06495257912320085, 0.045543543456005864, 0.011522487420734251, 0.04208332815323956, 0.11093089124187827, 0.06589026786969043, 0.055959831006475724, 0.03829364381090272, 0.02069652829959523, 0.052100455286563374, 0.10774910377222113, 0.06271359379752539, 0.07272476519574411, 0.019630520364444237, 0.13114789937390015, 0.25024314236361533, 0.11068509193137288, 0.24798242695396766, 0.13702266616746783, 0.1444375081337057, 0.12030325160594657, 0.13530931435525417, 0.09780717475223355, 0.16911758459173143, 0.14500982273602858, 0.08700308535480872, 0.18821956036845222, 0.08841434595524333, 0.13584409112809226, 0.1477303876890801, 0.2031556682777591, 0.14563554228516296, 0.12695883197011426, 0.14711305440869182, 0.08648830946185626, 0.08519323208020069, 0.07037222385406494, 0.22103698924183846, 0.15307140187360346, 0.07590130568132736, 0.09414854255737737, 0.08287649194244295, 0.15120271855266765, 0.2004822445451282, 0.14486784988548607, 0.11755217696190812, 0.1050320194917731, 0.10170336841838434, 0.0829245979548432, 0.12488392065279186, 0.17292751843342558, 0.11709220125339925, 0.11183021837496199, 0.17738724709488451, 0.09453842983930372, 0.15173186984611675, 0.17995056579820812, 0.07123165312805213, 0.12301716691581532, 0.26272191025782377, 0.14269031438743696, 0.21040401683421806, 0.08302197515149601, 0.13050283945631236, 0.15589647606248036, 0.18206856620963663, 0.08328230571351014, 0.12091228025383316, 0.24597798998001963, 0.0947569849085994, 0.17513285478344187, 0.10053182893898338, 0.08717266609892249, 0.10809967207023874, 0.11628393564024009, 0.20071366103366017, 0.20245816820533946, 0.24320713710039854, 0.12644205969991162, 0.16841521603055298, 0.15207984804874286, 0.11699832699378021, 0.21917014644714072, 0.16457124729640782, 0.07002937389188446, 0.2901505306363106, 0.14137249760096893, 0.14687960443552583, 0.1781452025170438, 0.10578949251794256, 0.11036416501156054, 0.16278185503324494, 0.24434033723082393, 0.14772839873330668, 0.17329553462332115, 0.14136893529212102, 0.12921193294459954, 0.11082957324106246, 0.19185623241355643, 0.11149717218359001, 0.12722950807074085, 0.19363756495295092, 0.17872905009426177, 0.18337010027607903, 0.15009715600172058, 0.29530468687880784, 0.10506758320843801, 0.1676874066470191, 0.17591614712728187, 0.21202126052230597, 0.13325859705219045, 0.08969066926511005, 0.09702562645543367, 0.12815854337532073, 0.144793011713773, 0.07115874454029836, 0.26064460922498256, 0.23446601786417887, 0.26208577095530927, 0.14095993770752102, 0.11609712222707458, 0.09004338236991316, 0.2557527576573193, 0.18613028107210994, 0.21272618207149208, 0.13523508474463597, 0.2014388729003258, 0.1575730025069788, 0.08679578866576776, 0.29810380074195564, 0.1537205436034128, 0.09682230025646277, 0.10429478483274579, 0.10656513331923634, 0.14377879269886762, 0.06778619543183595, 0.14279856404755265, 0.10535715438891202, 0.10336797597119585, 0.20820485515287146, 0.3329574305098504, 0.19709073356352746, 0.10689753384212963, 0.14600747701479122, 0.07727045682258904, 0.11366851817001589, 0.07259265548782423, 0.20023625227622688, 0.1428520432091318, 0.22744865535059944, 0.18057725013932213, 0.2512220648350194, 0.23798770154826343, 0.19532624777639285, 0.20926995581248775, 0.11720596507075243, 0.15166282042628154, 0.22870971268275753, 0.09802708053030074, 0.12982279469724745, 0.13604028528789058, 0.1348921679891646, 0.15120740892598405, 0.07938813811051659, 0.09235553603502922, 0.1318116465699859, 0.25344040361233056, 0.10441319449455477, 0.15213179838610813, 0.1563249624450691, 0.1254154319758527, 0.1987050086609088, 0.1352281976141967, 0.11985281249508262, 0.12048256932757795, 0.11574590826057829, 0.14981793035985902, 0.12784934981027618, 0.10653382953023538, 0.13262181950267404, 0.2583470387617126, 0.2325982548063621, 0.1508903782814741, 0.12486842460930347, 0.09088077727938071, 0.1822645525680855, 0.17700450669508427, 0.17306472669588402, 0.09702325900434516, 0.16223409067606553], [0.04725552600575611, 0.01740068200888345, 0.017669378430582583, 0.018353735067648813, 0.043232536409050226, 0.008420959511568071, 0.010364831668994157, 0.028519156294350978, 0.05500485021912027, 0.013920346154918661, 0.01913253370730672, 0.04752840999572072, 0.10888740245718509, 0.020808305016544182, 0.03373901672603097, 0.03146521354210563, 0.015767445038363803, 0.035635701278806664, 0.08066666559898295, 0.07745732218609191, 0.008291646772704553, 0.03469560426310636, 0.12809451087377965, 0.015584934226353653, 0.03984553026384674, 0.047076211994863115, 0.07578651027870364, 0.014665813087049173, 0.0472267121222103, 0.05994532359181903, 0.02201246374170296, 0.02313862460141536, 0.03444292895437684, 0.03690433222800493, 0.04459611402126029, 0.023367903704638593, 0.018596530535432976, 0.006294171143963467, 0.05573478585574776, 0.05484006745973602, 0.06450881934142672, 0.0692817714298144, 0.05293235088174697, 0.06699933335767128, 0.02236786713183392, 0.005689579147656332, 0.011701757830451243, 0.014390000396815594, 0.039612544132978655, 0.014565528526873095, 0.031463784907828085, 0.15062314574606717, 0.02855857732356526, 0.03281287950812839, 0.048830660234671086, 0.05409658762800973, 0.06078791724576149, 0.016873285894689616, 0.07762302149785683, 0.017085289655369706, 0.038736646602046676, 0.0402801653399365, 0.08120068538119085, 0.03661665352410637, 0.03425970011448953, 0.028922237106598914, 0.021216159693722147, 0.018930762307718396, 0.04107037450012285, 0.0715624654549174, 0.05232104755123146, 0.06045792128134053, 0.05110235942993313, 0.03811296795902308, 0.07595942326588556, 0.05025528691476211, 0.04666868757340126, 0.015502850837947335, 0.17012194788549095, 0.08363292596186511, 0.15648523665731773, 0.029976272344356403, 0.06812812513089739, 0.0685031471948605, 0.037888987790211104, 0.0408150274597574, 0.017065362990251742, 0.04353922893642448, 0.04729147934995126, 0.016950895987974945, 0.01984820526558906, 0.13330717803910375, 0.007702039201831212, 0.03373720588569995, 0.016249167529167607, 0.007833810304873623, 0.009108271751756547, 0.04853281410760246, 0.03967530756199267, 0.04021106396976393, 0.05068471211416181, 0.03813625284237787, 0.06836228014435619, 0.06004083428706508, 0.0897504566819407, 0.015309530645026825, 0.05747861025156453, 0.020093366329092532, 0.02264216305775335, 0.011125592409371166, 0.03897285365383141, 0.02882528478949098, 0.029062148641969543, 0.04309625212044921, 0.05682444047124591, 0.02692190606467193, 0.01710041833575815, 0.030535319201590028, 0.04908692011667881, 0.011328175532980822, 0.005229516236795462, 0.028645761121879332, 0.0289423140566214, 0.026989345024048816, 0.04187522252323106, 0.11588060806388967, 0.054412935496657155, 0.053171741747064516, 0.06704878265736625, 0.027020201669074595, 0.027915437713090796, 0.0328267539589433, 0.035001539799850434, 0.08226690668379888, 0.02620430492243031, 0.05179301319003571, 0.024097967361740302, 0.04343179192801472, 0.01988186537346337, 0.050315345215494744, 0.0493265224940842, 0.008878366461431142, 0.05638062873913441, 0.1097670107265003, 0.05176945371204056, 0.046318995009642094, 0.04120382378459908, 0.027655650774249807, 0.012813820667361142, 0.050001691342913546, 0.06857451211544685, 0.014238565163395833, 0.012410136860125931, 0.0700998779211659, 0.04737417315482162, 0.0034191552867923747, 0.010568677371338708, 0.025637124126660638, 0.034661272511584684, 0.03485777466266882, 0.021834904910065234, 0.042952204967150465, 0.04023758832772728, 0.044225715537322685, 0.05750809948949609, 0.019427457627898548, 0.031126102148846257, 0.011229680476390058, 0.036938990524504334, 0.020627699668693822, 0.07862594502512366, 0.05555029907554854, 0.03133894453640096, 0.08347050694283098, 0.03674046973173972, 0.03801115271926392, 0.005309528569341637, 0.02274360907904338, 0.03887487531756051, 0.048314147716155276, 0.006565092153323349, 0.06361859836033545, 0.05366478013456799, 0.03965664996940177, 0.053366507272585295, 0.03436393846641295, 0.04329033487010747, 0.03878705327224452, 0.056041021962300874, 0.04610698939359281, 0.03572596498997882, 0.019896754711226095, 0.03529027606418822, 0.05078131376649253, 0.05734546524763573, 0.0511884596926393, 0.07905011210823432, 0.012886184704257175, 0.06958541373023763, 0.08650404299260117, 0.02859324675227981, 0.0467966449650703, 0.015205970430542948, 0.05476177830132656, 0.03163575536746066, 0.030454354600806255, 0.056262207945110276, 0.031064348040672485, 0.011449699431977933, 0.02895662451919634, 0.05318243980582338, 0.06697545104543678, 0.05879708012798801, 0.037838610805920325, 0.0632502259395551, 0.020835953728237655, 0.020081172842765227, 0.05292449895932805, 0.015250318392645568, 0.02925257445895113, 0.03206002635124605, 0.07915048758150078, 0.04996247254894115, 0.025128461675194558, 0.05139069493452553, 0.0275158004660625, 0.02799422411044361, 0.09381378200487234, 0.05533382201974746, 0.01784346215572441, 0.05529800968361087, 0.03343847660289612, 0.02354665739403572, 0.013443248171824962, 0.02447984501486644, 0.028100941235607024, 0.02125994269590592, 0.05116687432746403, 0.02445222042297246, 0.04150805609242525, 0.012797654835594585, 0.015802032830833923, 0.06072363983548712, 0.04120026518648956, 0.097010902245529, 0.02483209242200246, 0.06164342055853922, 0.01717203929729294, 0.028751274112437386, 0.029884355499234516, 0.043582269790931605, 0.0709438556805253, 0.0839408504543826, 0.033021011113305576, 0.09168955497443676, 0.042063843065989204, 0.022870751963637304, 0.025765087084437255, 0.09115335327805951, 0.007678978818148607, 0.06132499467639718, 0.04023548804980237, 0.028591563932423014, 0.06732730325893499, 0.04354066128144041, 0.047833896533120424, 0.013112461820128374, 0.027088427304988727, 0.0354522646375699, 0.05122980845044367, 0.03508838221023325, 0.013593669445981504, 0.03090087146119913, 0.04175240821496118, 0.08534307911759242, 0.0276846891574678, 0.012083289457223145, 0.02843197620677529, 0.06875982639030553, 0.02018823321122909, 0.12062514331773855, 0.030213204845495056, 0.04613624856574461, 0.025257736378989648, 0.1216374030627776, 0.03587372659239918, 0.04313523713790346, 0.019180151757609565, 0.07928331717266701, 0.030981938107288443, 0.049224577378481627, 0.04690855712397024, 0.02933234049123712, 0.047361912875203416, 0.03518957775668241, 0.06195167530677281, 0.11385953213903122, 0.027883812945219688, 0.02471774601872312, 0.039962841547094285, 0.01684704540821258, 0.026923859768430702, 0.06487815655418672, 0.029837763468094636, 0.007370458752120612, 0.026415256688778754, 0.01321724193985574, 0.013622204096463975, 0.06928878472535871, 0.028495763799583074, 0.0424928266875213, 0.08467326857498847, 0.008459279379167128, 0.042537366680335253, 0.06901580054545775, 0.043516708465176634, 0.02679315828572726, 0.027933785459026694, 0.0410016887326492, 0.04655355820432305, 0.04922289270325564, 0.03319533047033474, 0.008746816147322534, 0.04664834530558437, 0.04625141875294503, 0.062403168267337605, 0.03061434308619937, 0.007910753392934566, 0.02140660406439565, 0.01778352445398923, 0.04921101462969091, 0.03217838777345605, 0.008762704601394944, 0.02772427902527852, 0.020240365374775138, 0.06373840325977653, 0.03338035901833791, 0.03232083559851162, 0.040362484360230155, 0.003757579497687402, 0.026527295012783725, 0.04223714939143974, 0.06547412340296432, 0.012981796517124167, 0.04405989748192951, 0.003756244559554034, 0.07469608754036017, 0.030425594522967003, 0.05456427054014057, 0.00316303247018368, 0.059815295608132146, 0.01782924260623986, 0.18441007181536406, 0.11472662779851817, 0.11765943956561387, 0.10241041993140243, 0.08450368040939793, 0.11084873549407348, 0.14618725486798212, 0.09952950655133463, 0.12522567965788767, 0.16678038344252855, 0.10268804253428243, 0.1049838837934658, 0.2737015101592988, 0.10115040160599165, 0.12858576810685918, 0.15036759461509064, 0.17007995716994628, 0.1401710940990597, 0.2125296465237625, 0.214967631327454, 0.1630529764224775, 0.1663817759254016, 0.24218899954576045, 0.11816148020443507, 0.16071834310423583, 0.21070402261102572, 0.2530641941120848, 0.13397883652942255, 0.12257253139978275, 0.17976407893002033, 0.13565920729888603, 0.11074977752286941, 0.16085287963505834, 0.16093647514935583, 0.20457367500057444, 0.12196843803394586, 0.11187050957232714, 0.1604874015902169, 0.17028826317982748, 0.14114262477960438, 0.13125304685672745, 0.16100545035442337, 0.14991740783443674, 0.14639729750342667, 0.12975497724255547, 0.15867994545260444, 0.11976124631473795, 0.07129260571673512, 0.14157657336909324, 0.21377842873334885, 0.0901424145558849, 0.20115911291213706, 0.12675873411353678, 0.09495498248725198, 0.1459532111766748, 0.11617768977885135, 0.2672837139107287, 0.06196744965563994, 0.15698375209467486, 0.11332800597301684, 0.11937360031879507, 0.1001987382187508, 0.13854702265234664, 0.14016629982506856, 0.14583541749743745, 0.17512797145172954, 0.17784397961804643, 0.1356022252002731, 0.20138310792390257, 0.15666672145016491, 0.1820856801350601, 0.2030818839557469, 0.1807880200794898, 0.13490079174516723, 0.20653511193813756, 0.2590324269840494, 0.14974916295614094, 0.1265119106392376, 0.2852562448242679, 0.15860104031162336, 0.25599686487112194, 0.1182852333295159, 0.18488206289475784, 0.2120759419631213, 0.17450094572268426, 0.10644833411788568, 0.12449834524886683, 0.10878624030738138, 0.09211501339450479, 0.2794466237537563, 0.12079400417860597, 0.19584174355259165, 0.19370472931768745, 0.1230080978712067, 0.12565481913043186, 0.10007228367612697, 0.14472560986177996, 0.2005411562277004, 0.1531122051528655, 0.07228677190141752, 0.17135817295638844, 0.10014247600338422, 0.16784309438662603, 0.18353712803218514, 0.19085342762991786, 0.09181734538287856, 0.18793114693835378, 0.07515794830396771, 0.18228552566142753, 0.08587016724050045, 0.1677505040424876, 0.12501550343586132, 0.14995960635133088, 0.14811105007538572, 0.16595026158029214, 0.14491136942524463, 0.12250535961356945, 0.20125382579863071, 0.11382847325876355, 0.14153922849800438, 0.30156678054481745, 0.11594607291044667, 0.14090604294324294, 0.11044544502510689, 0.10478840951691382, 0.2743071026634425, 0.11654846675810404, 0.11794456528150477, 0.12761190708260983, 0.11353863490512595, 0.08830348393530585, 0.11672916487441398, 0.17830336902989075, 0.1565150561509654, 0.14714560500578955, 0.17974956252146512, 0.09275883392547257, 0.15496343316044658, 0.28212737990543246, 0.1287941334885545, 0.1588757536956109, 0.14901883027050644, 0.18055688560707495, 0.21225028729531914, 0.12872618244728073, 0.15657281008316204, 0.13631191133754328, 0.11993784035439603, 0.0838773968280293, 0.31565114040859044, 0.08578385546570644, 0.10026641466538422, 0.06033524427039083, 0.2125323479413055, 0.12630406476091594, 0.12980174738913774, 0.08505191231961362, 0.13185188581701368, 0.1114093093201518, 0.13115753245074302, 0.1616900073713623, 0.13778063643258065, 0.05901094482396729, 0.10365074165747501, 0.13088780629914254, 0.15487124357605353, 0.12123653941671364, 0.16870089835720137, 0.19000775035237893, 0.08223993703722954, 0.23365395987639204, 0.11494196936837398, 0.18787412031088024, 0.230427265050821, 0.17300584469921887, 0.08222749864216894], [0.038628304173471406, 0.06297036205069162, 0.019925685483030975, 0.0975155107153114, 0.12744939158437774, 0.03623354947194457, 0.05139864333614241, 0.011511037937452784, 0.02520864516554866, 0.02070610942610074, 0.012874263029516442, 0.0733822412439622, 0.12297538400162011, 0.06413095485186204, 0.017355392446916085, 0.06328600487904623, 0.0297228400449967, 0.07761367785860784, 0.012189018598292023, 0.05031711523770355, 0.018259281932841986, 0.07317577576031908, 0.03776316407311242, 0.004638258315026178, 0.030339997065311763, 0.011543046766746556, 0.0638461037306115, 0.022244770807446912, 0.04163518598943483, 0.06204918237926904, 0.05573598071350716, 0.02157717743102694, 0.040469242303515784, 0.02778801652311813, 0.08556226501241326, 0.0768753893498797, 0.033483079678262584, 0.0181211979361251, 0.05764576046203729, 0.030333156319102272, 0.07901701232185587, 0.035069212535745464, 0.0860891972843092, 0.030599789570260327, 0.022656052351521794, 0.07904103564214893, 0.049842348525999114, 0.025993111958086956, 0.05729973781853914, 0.007928324666863773, 0.030245406633184757, 0.048642388501320966, 0.03218587604351342, 0.03157339269819204, 0.05999898457957897, 0.016623434457869735, 0.015429459854203742, 0.03063389682210982, 0.004900928961433237, 0.022041804550099187, 0.011481113615445793, 0.021764584562333766, 0.03388093762623612, 0.028580318539752625, 0.060018989170202985, 0.025121214603132103, 0.0230323156574741, 0.06205272984516341, 0.025547428158461116, 0.03511876944685355, 0.025823846626735758, 0.0386979324684944, 0.023808505648048595, 0.07976485969265923, 0.04011318953416776, 0.013382322485995246, 0.04813380211999174, 0.03687256830744445, 0.060657785361399874, 0.02503986037481809, 0.051949539556517266, 0.033220849218196236, 0.022743139670637902, 0.023484522935177665, 0.0032341496989829466, 0.06327393755782396, 0.005994398679831647, 0.009733593324199319, 0.03575129449018277, 0.021173120694584213, 0.024748149953666143, 0.02734701196459355, 0.030366712526301853, 0.024251207869383506, 0.09885444160318002, 0.05574569171585608, 0.06356148267514072, 0.04770810621266719, 0.0052747454992641, 0.011416928045946406, 0.02980013843625784, 0.057918421807698905, 0.029029640718363225, 0.02084030827973038, 0.09689956525107846, 0.032248828720184974, 0.02786908131383825, 0.049579657934373245, 0.01799799585569417, 0.010220420863333857, 0.0543666032172041, 0.04273172402463388, 0.051732131105381995, 0.04644179076422006, 0.06584299306268804, 0.023727598563709762, 0.04735143003927078, 0.016230940382229164, 0.06924331333721057, 0.0117234563731472, 0.11802190449088812, 0.020451792115636636, 0.03978729022492189, 0.02931524140876718, 0.021622754575219005, 0.0355946382478578, 0.031895744541543536, 0.003433819429119467, 0.057970394409494475, 0.031653388796257786, 0.029395766287052538, 0.04016104692709632, 0.049366657840437256, 0.024055535068328027, 0.028056499577360228, 0.0026762371680888464, 0.011470860845292918, 0.030592503535444848, 0.08814813016215339, 0.020518763521977235, 0.0277971857576631, 0.07025440791039728, 0.043371343999751844, 0.05500721024873201, 0.018088333781633992, 0.005089663145554368, 0.027240938652539626, 0.023195298708742484, 0.04592069177306257, 0.04528783276327886, 0.06012713121890556, 0.043664770637406036, 0.013784553539153421, 0.030205005969037302, 0.02639032794832019, 0.061084568515070714, 0.07882650301326066, 0.033526803308632225, 0.03548591732396744, 0.012307940341997892, 0.018690143187996, 0.06262191629502922, 0.04052139302075375, 0.018644786832737736, 0.02915795434091706, 0.027888063596037682, 0.06856700158095919, 0.026519385573919863, 0.06810122227761894, 0.0104766102413123, 0.06216570327524096, 0.025524707307340577, 0.035867915576091036, 0.08190594089683145, 0.04435483439010568, 0.006234455158846686, 0.021998264601279516, 0.024397546403633896, 0.01429412141078501, 0.08292998594697565, 0.01205468059197301, 0.0419605546630919, 0.05867362015123945, 0.04814909407286905, 0.01985824652365409, 0.046933211269788444, 0.026530063223617617, 0.020121636589465197, 0.06101088809373323, 0.04051056508615147, 0.04772904219862539, 0.043732866397476755, 0.0630740549240727, 0.030196870175132062, 0.03220471175154671, 0.07910474159871228, 0.061311995959840715, 0.021368483648984693, 0.02933204177679727, 0.02983290425618179, 0.028803324639739003, 0.008762044089962728, 0.05636727379169315, 0.052843742159893736, 0.013286192097439198, 0.034640503508853726, 0.01864443616796052, 0.02313736295036506, 0.06465448808739893, 0.011110820887552109, 0.036422767443582416, 0.057897478400263935, 0.07171720324549824, 0.026740053908724803, 0.0078076301178953145, 0.0269688543266966, 0.07984207273693755, 0.04619876708602533, 0.043873225076822564, 0.029411061950668227, 0.019350517322891392, 0.06797456735512242, 0.05364610027754679, 0.03579106989491265, 0.06256858556298539, 0.015765988573548384, 0.04730329063022509, 0.031032263141241856, 0.066718319139909, 0.049266130226897076, 0.07019643133389764, 0.0487303552654339, 0.08550814760383219, 0.02703592777834274, 0.026804236695170403, 0.020487075671553612, 0.03562779369531199, 0.012765933588525513, 0.017707127772155218, 0.10325559254852124, 0.03932128085580189, 0.03690413184813224, 0.04871597244346049, 0.023190561951196287, 0.08961874031228945, 0.05179885389225092, 0.02179291048378218, 0.07782621411024593, 0.01360926660709083, 0.05191687021579128, 0.04621415922883898, 0.048073602811200544, 0.05365244564018212, 0.028098256516386755, 0.004956093725922983, 0.037495668075280264, 0.030709883467352483, 0.07411158687318675, 0.03128953234408982, 0.0032850577827048255, 0.09071441003470682, 0.018651375248737168, 0.05798418351332657, 0.04481259478779975, 0.038354733696905896, 0.06456108880229294, 0.025330980788567103, 0.04237934488628525, 0.04256783926393837, 0.019929071531805675, 0.03620661322202068, 0.06093587180657778, 0.025402926439710427, 0.051304520457051694, 0.02140255193808116, 0.04337882113759406, 0.14427380519919097, 0.04633691416529473, 0.0323792463314021, 0.0398247352859471, 0.05985393923765514, 0.053855786682106555, 0.037140565254958346, 0.025481857555860188, 0.04549351528112311, 0.07247460205690004, 0.05721020883356687, 0.0610242838592967, 0.034500727415434085, 0.045736646570730954, 0.07018472766503692, 0.05065590936283115, 0.050154317723354325, 0.011214422847842798, 0.028834392796852626, 0.034952550631714985, 0.11297035758616403, 0.00979093907517381, 0.06127537468273658, 0.08886527488357387, 0.01793406354408944, 0.020542805395962205, 0.06002687820000574, 0.03771837546082679, 0.06715043462463655, 0.046708047375432216, 0.03237989199988078, 0.019980342804046813, 0.06817604560637847, 0.04090572903805878, 0.046492119508911856, 0.017896167628350668, 0.010541398805798963, 0.011935622478631558, 0.10420104415970854, 0.01622009018319659, 0.030013593095645774, 0.03345519719005097, 0.01753862128680339, 0.016010939980333205, 0.053982801546226256, 0.03825319305178709, 0.02455361078318674, 0.09008962559164502, 0.040107849781634286, 0.027724362516892143, 0.05946129858784843, 0.09660873984103091, 0.010565968532318948, 0.031191234884317964, 0.028091361964470707, 0.0277178650139831, 0.08088979229796678, 0.045360552103375085, 0.030134490807540715, 0.06554397434229031, 0.034257477382197976, 0.05601318771368824, 0.019441957338131033, 0.08965339118731208, 0.03295935348432977, 0.0177623287163442, 0.04522783012362197, 0.04520558795775287, 0.06821022150688805, 0.004171306882199133, 0.0677357664972078, 0.011318364340695553, 0.03378171248186845, 0.0320508088771021, 0.04190794381429441, 0.04034131830849219, 0.1265980739844963, 0.15475938707822934, 0.13927809748565778, 0.1599383310531266, 0.13267492759041488, 0.24599430238595232, 0.12340949586359784, 0.15341520920628682, 0.13670351298060268, 0.13437273883027956, 0.11293591451249085, 0.18962123984238133, 0.18462856009136885, 0.105899879563367, 0.079385614808416, 0.12822408985812217, 0.14069700962863863, 0.17483589181210846, 0.1310614391695708, 0.14461961633060127, 0.25465247919782996, 0.2851762413047254, 0.14194835966918617, 0.11195956729352474, 0.08965814835391939, 0.13259749190183356, 0.20764799206517637, 0.12664420588407665, 0.1663828149321489, 0.1333957162569277, 0.18640894268173724, 0.14263097225921229, 0.1571436700760387, 0.11291269271168858, 0.16352955397451296, 0.18060128088109195, 0.0748374592512846, 0.07355292778811418, 0.11382392389350571, 0.12194867464131676, 0.3043032274581492, 0.1044925746100489, 0.15833953715628013, 0.12556075933389366, 0.08627831135527231, 0.25743680947925895, 0.11916705319890752, 0.11997925219475292, 0.12679058709181845, 0.19751363899558783, 0.18551505549112335, 0.16716296056983992, 0.14536553411744535, 0.09473887650528923, 0.2509279071819037, 0.078206735488493, 0.13271764561068267, 0.2569408470299095, 0.10783312231069431, 0.11443057766882703, 0.10660132043994963, 0.10959797917166725, 0.1069904284668155, 0.2128143046866171, 0.09776295759365894, 0.11036550829885527, 0.17584384710062295, 0.18125869013601914, 0.14265339996200055, 0.1175242722092662, 0.16154171142261475, 0.17105792969232425, 0.11874868971062824, 0.16996685386402532, 0.09238442042260431, 0.11989795733825304, 0.15672880952479318, 0.10538944523432292, 0.23432327318005264, 0.24227547459304333, 0.17129981046309695, 0.19525811861967668, 0.08553084990126081, 0.094805810804246, 0.13689908373635262, 0.096243276639143, 0.18509342655306682, 0.14944494178052992, 0.13367048901272938, 0.1322379065095447, 0.1437238886137493, 0.11977575530181639, 0.1467202208004892, 0.0909405795391649, 0.3266220720252022, 0.2064637915464118, 0.1826477234135382, 0.1272898743627593, 0.10680142571800388, 0.16066991054685786, 0.21425671322504058, 0.17783550429157913, 0.2613798400852829, 0.08553914711228572, 0.14303189527709037, 0.14026346179889515, 0.18824327940819785, 0.09089841070817783, 0.11084244208177552, 0.1469934350461699, 0.16224997263634577, 0.19670693931402639, 0.1255012390902266, 0.1278672058833763, 0.09349260275484994, 0.1685026558698155, 0.13279025733936578, 0.2016056631691754, 0.21976453252136707, 0.1185643402277492, 0.21288129093591124, 0.15988329338142648, 0.16882299649296328, 0.1842404465423897, 0.1473369455197826, 0.13780863024294376, 0.21069345442811027, 0.13391308224527165, 0.1275350502692163, 0.1117738893663045, 0.22880617703776807, 0.22937690344406292, 0.18352544662775472, 0.09801129504921846, 0.11353949579643086, 0.1767604736960493, 0.06932150601642206, 0.23533057537861168, 0.289527423446998, 0.09079892581212334, 0.17605961911613122, 0.1481254625832662, 0.16157317848410457, 0.17003677901811898, 0.10587521057459526, 0.13059819058980793, 0.13430958206299692, 0.13244046829640865, 0.08780361778917722, 0.12542979995487258, 0.16833147208672017, 0.12634203303605318, 0.08506266603944823, 0.1378143299371004, 0.1642629294656217, 0.133287911885418, 0.15783584152814, 0.12577216752106324, 0.1362346686073579, 0.11402166172047146, 0.11434800631832331, 0.15324093808885664, 0.14566358062438667, 0.17488793120719492, 0.13673459412530065, 0.08641205378808081, 0.24625743826618418, 0.09951879736036062, 0.09940622840076685, 0.09302024060161784, 0.17321806924883276, 0.06988962006289512, 0.17587743670446798, 0.1122299391136039, 0.19575949874706566, 0.10877478154725395], [0.019916250930691604, 0.08755588147323579, 0.05728372227167711, 0.0873013396630995, 0.07291149697266519, 0.036211901024216786, 0.026630407155607827, 0.02212205854448257, 0.00616036980318313, 0.009359849609609228, 0.07199009094620124, 0.03709604010509793, 0.02739089886745205, 0.03178967679559719, 0.006732111560268095, 0.06441131597966887, 0.034636347481864505, 0.04073990727192722, 0.02201604645961197, 0.04351454510469921, 0.05111676822707523, 0.057873815021594055, 0.016590108316449914, 0.03254013281548396, 0.026398020308988634, 0.05272542897728272, 0.05211364696151577, 0.029694220975216012, 0.028547072179208044, 0.05073000538686756, 0.05663962343533058, 0.040485183635610156, 0.10141640217625536, 0.03709612545208074, 0.10586451622657478, 0.06335532147204503, 0.01333399011855363, 0.09988388206693344, 0.026745796276372857, 0.06736987284966744, 0.04083476487721782, 0.06645790694165044, 0.015179491529124789, 0.056498077319702134, 0.05429842582088895, 0.0474363243120024, 0.02515199146728264, 0.0066622698977880646, 0.058077990979654714, 0.07863088772865012, 0.022951555147301406, 0.09099873423110694, 0.02193138781876769, 0.02122126752510667, 0.061994734714971855, 0.05073547130450606, 0.009549107471684692, 0.028362151242617983, 0.02237691205664305, 0.025546403994667344, 0.03166495145705994, 0.04804976502782665, 0.015833674297027756, 0.02383786686550593, 0.02762317624728894, 0.009211484084516997, 0.010053497935587075, 0.04468417726457119, 0.010947816499538021, 0.04026685863209423, 0.03303929392131977, 0.031768488479428925, 0.00789897829235997, 0.03780127706704661, 0.03411448407860007, 0.07914815723779611, 0.08041881796089001, 0.039053996370057575, 0.057991809080704115, 0.039566111663589254, 0.06527944322442636, 0.04022593660920393, 0.028524650042527355, 0.07843096056603827, 0.059664146101567894, 0.01777483576006489, 0.008394284868700197, 0.06630072748521343, 0.04036639918922447, 0.06366809961036779, 0.07131773483706638, 0.02331743951799581, 0.04337086160376202, 0.11884637118782848, 0.01661690912442282, 0.03377673638169654, 0.019545368195394985, 0.07817016245098785, 0.007992414684849791, 0.05506224049895536, 0.04914710087177809, 0.02780820108455373, 0.05087901750812307, 0.04817871318664402, 0.030162030052451883, 0.0679267433588393, 0.03839444230834488, 0.07273924449691549, 0.03797347759245895, 0.05392995321017224, 0.06115810050687287, 0.041899924908648245, 0.02456460199027788, 0.07864825398428366, 0.13128292572218925, 0.04978730343282223, 0.03360045775480103, 0.07446867122780532, 0.0443645899213152, 0.03983640926890075, 0.09703752308269031, 0.03752046322915703, 0.056954331157612614, 0.0810503114189487, 0.07239809405291453, 0.02278929197927937, 0.06617728606215678, 0.0885520366136916, 0.0365838468860602, 0.01953021539520705, 0.03537863616656978, 0.056582355609862134, 0.053383250124170445, 0.023907532267912757, 0.021785008466395084, 0.04786077712196857, 0.08763210746110417, 0.03166745991620701, 0.04047283800900914, 0.03448681585723534, 0.04900150634057354, 0.03751208438188769, 0.03683533475850709, 0.03495911863865331, 0.08315984392538667, 0.008250121754826978, 0.07659592622076161, 0.035353959756321274, 0.04645300090487581, 0.03647434299637098, 0.013427896847133525, 0.02555199978814926, 0.017989097505051177, 0.049423164964537136, 0.029743961567874067, 0.022436376639234368, 0.06652093754382804, 0.027371922151360195, 0.047466362739214674, 0.03349271275510546, 0.07370647814241238, 0.016217973206948955, 0.024258044904854614, 0.009683845310064498, 0.05404469295172021, 0.03616260386479553, 0.033512401932966895, 0.059848918608622625, 0.059191390610067174, 0.023653157441003714, 0.0015297627987820306, 0.019836286373902112, 0.03680936701130122, 0.06822734285378829, 0.013621989801322343, 0.02671397855010582, 0.0648030437878333, 0.04622870903403964, 0.01958069442480337, 0.05183193141419906, 0.0724189929314889, 0.04959582562150899, 0.029858612251700833, 0.025865581301331986, 0.022403837174351793, 0.010718736848502886, 0.011866294753417606, 0.028832576390414033, 0.031398041755892336, 0.019006734110007528, 0.012132061547163175, 0.016143986649694853, 0.032304786655004136, 0.03237110868212767, 0.04134928101848345, 0.027366048052499536, 0.03959394962294027, 0.01038109119690489, 0.011938137431570794, 0.024658643233124167, 0.07757752042380162, 0.04261142930772621, 0.03487995003524702, 0.037117347164894454, 0.07862316197133623, 0.04204264361760579, 0.053832160410820507, 0.019487332247081213, 0.07286500884220004, 0.03845281964458991, 0.06885350769152865, 0.032243195819319226, 0.05993067730742041, 0.06666089175269008, 0.02821539525029948, 0.0544639173313044, 0.03293428373581264, 0.08368382987100631, 0.02493103740562219, 0.019520496971381363, 0.032932061003521085, 0.06973163908696733, 0.026166121424466837, 0.07215253965114243, 0.04811016100575216, 0.07174934566137381, 0.035663105081766844, 0.07200339765404351, 0.028352148947305977, 0.12020693568047136, 0.075359419133747, 0.06811011320678517, 0.02838221706042532, 0.048223379344563, 0.028913192181789782, 0.07760031177895144, 0.030470051024167333, 0.02997168030560715, 0.034805534887709655, 0.04459278548893053, 0.08952441334258765, 0.01479209415265359, 0.021867301511520054, 0.020335208137112204, 0.02776482255285373, 0.05165250979189295, 0.0513693210814381, 0.039194859709823504, 0.010645932161423843, 0.06156371018732898, 0.021762393371318467, 0.0256828793862951, 0.03479983890429139, 0.07824518615962006, 0.019565738293749746, 0.03860160541080404, 0.04543335679045413, 0.106478673114907, 0.09345825616037473, 0.032789947144920006, 0.040484667842974886, 0.06262471419177018, 0.05004606064176187, 0.03258201220887713, 0.08807655744021758, 0.036827560761594214, 0.06754736488801427, 0.036218279783497564, 0.06311629054835066, 0.10781145902001299, 0.034744003423838876, 0.0093022904911777, 0.04739043361041695, 0.028150928592367563, 0.01332444888248574, 0.04558058033580892, 0.07293747214134783, 0.013330440797290066, 0.052634604944614694, 0.06079272636270616, 0.03651723913208116, 0.06411078327801079, 0.06310446071438491, 0.04937506637361366, 0.03234419098589569, 0.02680604568013223, 0.0944509677356109, 0.08880059671355411, 0.04717704017821234, 0.04695375762821641, 0.061831332350266166, 0.05440775159513578, 0.07084838580340147, 0.06530755577841774, 0.03907689904735889, 0.044549640733748674, 0.017949335087905638, 0.050212787828058936, 0.03912275635229889, 0.05030734486354049, 0.031294619766413234, 0.04092046066944022, 0.09462627785978839, 0.04744694073451683, 0.02645490221766522, 0.06175609341880772, 0.04716867988463491, 0.04592609831888694, 0.04799702059244737, 0.05793142794573214, 0.05494952682056464, 0.02375664251303533, 0.021060624094388913, 0.058340566538390703, 0.03337562782689929, 0.024249612251878716, 0.031853879991103895, 0.030737309534742963, 0.06828773141023703, 0.056410563265671954, 0.042400922829983756, 0.03573049951228313, 0.04801034214324318, 0.009120216618612176, 0.016867042577359825, 0.048248527018586174, 0.012832584943680558, 0.10653253077180125, 0.037183724853093736, 0.03216367469576653, 0.03182555592502467, 0.028100401323172264, 0.05832103321154136, 0.0174255254023592, 0.01639537062146701, 0.03578493975510355, 0.06506279547465965, 0.03974040133471135, 0.05959437679848634, 0.060286269945208915, 0.023613003540958744, 0.011984248922090046, 0.043357699614716694, 0.03489362781692762, 0.019097541444352828, 0.03929328333470039, 0.08173106121830642, 0.04735934504424222, 0.02666801734449109, 0.02800121143081924, 0.041908177590812556, 0.08698585268575698, 0.16787546686828136, 0.21330750634660944, 0.1270681800087914, 0.1431561159552075, 0.14009584032464772, 0.12629867676878348, 0.1674512552563101, 0.09632601126213558, 0.10533094915444963, 0.07119897636584938, 0.1769283920293674, 0.05214169643295463, 0.1429088768782094, 0.08841078364639543, 0.10199001553701237, 0.1742978347465396, 0.11902721031219698, 0.1353328107506968, 0.21275928185787052, 0.14286320511018857, 0.17522964568343014, 0.10938063380308449, 0.1610458825598471, 0.08218886243412271, 0.2222728729248047, 0.13247232127469033, 0.13849063427187502, 0.11933393994695507, 0.16209049994358793, 0.15739951806608588, 0.22983301256317645, 0.10986321532982402, 0.2712853148113936, 0.23084803309757262, 0.15548382711131126, 0.08475312366499566, 0.1308757983497344, 0.2238259802106768, 0.10756830175523646, 0.15922405844321474, 0.19079714315012097, 0.16973898484138772, 0.08733708891668357, 0.11735768232028931, 0.11719602771336213, 0.2002764618373476, 0.16124461486469954, 0.21222515817498788, 0.10839296883204952, 0.22682557784719393, 0.14526236074743792, 0.19967843923950568, 0.12153689400292933, 0.20526520820567384, 0.14757429918972775, 0.18729873321717605, 0.1814378148992546, 0.1441802055342123, 0.06283941009314731, 0.21382632694439963, 0.18566458340501413, 0.18796541931806132, 0.0772977530141361, 0.24277210497530177, 0.08771161374170333, 0.1991894975071773, 0.13853039854438975, 0.12607625511009246, 0.16317228408297524, 0.11182160946191289, 0.15661457815440372, 0.1200553000671789, 0.1296283965348266, 0.14379891974385828, 0.11399311129935086, 0.14883440657285973, 0.11194473176146857, 0.22356578323524445, 0.20599185983883217, 0.19444107339950278, 0.122101905872114, 0.17401378514477983, 0.16108650772366673, 0.1567314812564291, 0.13746462995186448, 0.09489394084084779, 0.16308773861965165, 0.1392672472866252, 0.12375667254673317, 0.14128542883554474, 0.2217729325639084, 0.1926513694343157, 0.12198574491776526, 0.20938861038303003, 0.10328142670914531, 0.1667251528124325, 0.13282323838211596, 0.15916397416731343, 0.12782331526977941, 0.10368305476731621, 0.17501612979685888, 0.07475483595044352, 0.12567941390443593, 0.12919559085275978, 0.12950000498676673, 0.1748917458462529, 0.09866972846793942, 0.2315360336797312, 0.1562795281643048, 0.10896334642893635, 0.2199890321935527, 0.14271563646616414, 0.1146289092139341, 0.26711676036939025, 0.25890017626807094, 0.11136161148897372, 0.14803894300712273, 0.13029123831074685, 0.14643078320659697, 0.10041877758339979, 0.14516038965666667, 0.15255054779117927, 0.14821205637417734, 0.16239860997302458, 0.19161561329383403, 0.11348648418788798, 0.15221536421449855, 0.14026932476554066, 0.10323168055037968, 0.1104413261055015, 0.17965553241083398, 0.15460536174941808, 0.2189679557341151, 0.11535089273820631, 0.2617572370218113, 0.15231429249979556, 0.1823916082503274, 0.22041358519345522, 0.10421227285405621, 0.08390890099690296, 0.15224537666654214, 0.13197310821851715, 0.2023145032580942, 0.11152827559271827, 0.11786545233917423, 0.10467194428201765, 0.2003665585652925, 0.14066845178604126, 0.08520462404703721, 0.26150184916332364, 0.12816666247090325, 0.25946411944460124, 0.1745184455648996, 0.12194561699288897, 0.1352476715692319, 0.1811401394661516, 0.08867314027156681, 0.10955285659292713, 0.10859091446036473, 0.17708850296912715, 0.12667907198192552, 0.108729399216827, 0.16580405848799273, 0.14600669033825397, 0.19735870824661106, 0.11970424937317148, 0.21020678366767243, 0.2414158746250905, 0.1639017855632119, 0.10921019216766581, 0.16791263362392783, 0.17418283154256642, 0.1141962742258329, 0.18961988913360983, 0.09665076024248265, 0.14941678469767794], [0.04706359177362174, 0.07538036254118197, 0.04758797847898677, 0.004835560130231897, 0.024587573316239286, 0.027366574977349956, 0.07063198296236806, 0.04684593099227641, 0.04128098858927842, 0.08381933861528523, 0.03711984078108799, 0.03136351704597473, 0.03921608142263722, 0.04777927817485761, 0.013568133999797283, 0.07468712239642628, 0.03563871439837385, 0.01633191142900614, 0.05194927238335367, 0.061969223388587125, 0.05171523240278475, 0.03674095212772954, 0.04880935688561294, 0.011788756091846153, 0.023632470074517187, 0.02935390359198209, 0.03461960834101774, 0.0428782759263413, 0.03272710950113833, 0.08054639314650558, 0.02990553082781844, 0.054928587123868056, 0.06755464535672218, 0.013880173701181775, 0.03652357707323972, 0.023816118227841798, 0.04219576723698992, 0.08462794561637565, 0.009444871902815066, 0.030964957768446766, 0.04267233736754861, 0.028993143750994932, 0.0305571476201294, 0.017581040592631325, 0.07188403062173165, 0.018612124913488515, 0.03243739360186737, 0.07207500006188639, 0.014225545110093663, 0.006190078902363894, 0.012427043911884539, 0.06746829647454433, 0.034186338816653006, 0.023420147190336138, 0.06821085975388996, 0.07901819233666174, 0.05996758060064167, 0.14199428376741707, 0.05943990618106909, 0.04412690599565394, 0.02567222029028926, 0.08328175652422942, 0.08108561538392678, 0.0207695482095005, 0.0948972582409624, 0.08092999443761073, 0.04454707290278748, 0.08510700936312787, 0.07264884348842315, 0.02558867487095995, 0.03513275893055834, 0.04636544232198503, 0.029153074719943106, 0.05216936369834002, 0.011494316422613338, 0.029005634096392896, 0.021659053018083796, 0.08905751339625567, 0.048014501880970784, 0.043297730371705256, 0.05083390977233648, 0.10691374976886436, 0.05799389080493711, 0.06306632174528204, 0.05180360363738146, 0.08149891000357457, 0.07061283555231057, 0.03568737331079319, 0.016177383295143954, 0.019301637621538248, 0.0531290756771341, 0.0711435082484968, 0.022330199426505715, 0.10900999041041359, 0.032420806601294316, 0.01933868192281807, 0.04233197360008489, 0.05589496358879842, 0.05836231888679322, 0.027802134027297143, 0.009143240822595544, 0.06271003148867749, 0.04743305886222515, 0.02786429631669307, 0.028559774036693852, 0.0605012404412264, 0.026088541017088573, 0.0313995112082921, 0.06111046204750892, 0.017803844457375817, 0.06125020103354473, 0.035851480715791695, 0.021965098021610174, 0.0674953700217884, 0.06686688226182014, 0.028297337630647235, 0.04843772272579372, 0.004916985790259787, 0.014818784566159593, 0.04445759957889095, 0.023096082841220777, 0.0394000672531547, 0.08371298143174499, 0.025261610389861744, 0.02675418625585735, 0.024625764235679526, 0.009574238447385142, 0.033689470947138034, 0.07866659987485036, 0.08872279737261124, 0.055089993111323565, 0.02369508507399587, 0.03793943898926955, 0.028005454660160467, 0.046130574846756645, 0.04819984584173653, 0.04474125955312047, 0.041348720696987584, 0.029844671007595025, 0.04143444988585543, 0.03305399586679414, 0.03351351886522025, 0.006005237282806775, 0.07459977161488496, 0.008866607131494675, 0.052202478327672, 0.03379637360922061, 0.04587152448948473, 0.019255539118603338, 0.013303467439982342, 0.026826970533875283, 0.022006799299560953, 0.007838337405701168, 0.020366536045912653, 0.0298648611351382, 0.05380359143600799, 0.022810391237726435, 0.010754565882962197, 0.027239213159191422, 0.043037217983510345, 0.017347863358736504, 0.05332734785042703, 0.020541840603982564, 0.029778996504319366, 0.021032617296441458, 0.03788561843975913, 0.07185602196841501, 0.040725346334511414, 0.05232636132859625, 0.011254057244514115, 0.03684726849314757, 0.04464215315238107, 0.04969362213159911, 0.04421552213898394, 0.038612444477621466, 0.010074695528601296, 0.030832861048111226, 0.09270669062971137, 0.046767868188908324, 0.016748989146435633, 0.05598038849711884, 0.02230456935649272, 0.05237396639131475, 0.08284289491712116, 0.06967087945668027, 0.058004937673103996, 0.04765440811752342, 0.01964721126569202, 0.07357747803325765, 0.018827499879989773, 0.02524827214074321, 0.011538448234205134, 0.0577531418093713, 0.013580512095359154, 0.016065113049990032, 0.04072590665600728, 0.0038586822756769834, 0.054754590601078235, 0.019243328933953308, 0.03190527742845006, 0.05632369859085884, 0.01720310374366818, 0.0526603871549014, 0.026605535931594204, 0.049314017305732705, 0.006924643685124465, 0.027036864739784505, 0.023848028722568415, 0.03419285116251558, 0.02911105617386056, 0.012884016705356771, 0.051295180528541096, 0.022778799866500776, 0.04577673738822341, 0.023035740669001825, 0.025011601246660575, 0.03446254391747061, 0.01717402454232797, 0.020152283577772323, 0.007139750086935237, 0.0397553296352271, 0.03500204074953217, 0.018426413589622825, 0.05420507106464356, 0.011783316149376333, 0.026996697852155194, 0.10644233756465837, 0.07460843247827142, 0.07237518395413645, 0.039848094384069555, 0.09645129321143031, 0.0711782110738568, 0.03630174171121325, 0.04971835791366175, 0.034405932892696, 0.051564205350587144, 0.03494999393296894, 0.05411743826698512, 0.09324788697995245, 0.02063177220406942, 0.07161847534007393, 0.053286095571820624, 0.012548735721793491, 0.012142759605922038, 0.012227552761032712, 0.028776091530744452, 0.04849322423979174, 0.08871369864209555, 0.1133669687260408, 0.022072739120631013, 0.023262477916432545, 0.027483741541800555, 0.05116163847560529, 0.06380038743373007, 0.019301390857435763, 0.11730810685548931, 0.050229942571604624, 0.010038224536401685, 0.04189834413409699, 0.030811190335953142, 0.046960006511653773, 0.028836031087848824, 0.05996438936563209, 0.02976519441290293, 0.02337429174076533, 0.030520682194037363, 0.03945512718928512, 0.04597285733325407, 0.04883796296780929, 0.021358134399633855, 0.02289513522555353, 0.06231265593669377, 0.01887998827442061, 0.035325431599630974, 0.04638771788449958, 0.032614195442874916, 0.030885178748576436, 0.03319278119306546, 0.04303688030631747, 0.08269036130513996, 0.08117661011056043, 0.03980760651757009, 0.03816556025412865, 0.04324618450482376, 0.02702437439438654, 0.01944617644767277, 0.009097478141484316, 0.01995113372686319, 0.007689715839660494, 0.16911397775402293, 0.022926630117581226, 0.0664839860110078, 0.03308459461550228, 0.05667274177540094, 0.05522310471860692, 0.0200025886806543, 0.0217527361746761, 0.022994015271251556, 0.07347015605773777, 0.007473742516594939, 0.07779371546348557, 0.04083504689333495, 0.041156537845381536, 0.045326754698180594, 0.010385864134150324, 0.0497896115120966, 0.029895665829826612, 0.028439175039238762, 0.057340192288393155, 0.03654753731098026, 0.05389623744122218, 0.027188721142010763, 0.02621790477860486, 0.05914102846872993, 0.03368439094629139, 0.07410808393615298, 0.04626569396350533, 0.020768663198396098, 0.04428355110576376, 0.09767227456904948, 0.04315025820687879, 0.03220110491383821, 0.07460895198164508, 0.03390058969671372, 0.007550550626547192, 0.028844098233093973, 0.0542487724305829, 0.01818871111026965, 0.03516609620419331, 0.041264030514867045, 0.03961563517805189, 0.008701921778992983, 0.020353103172965348, 0.03301990531326737, 0.037813904709764756, 0.1011943219054956, 0.019318000122439116, 0.043292976915836334, 0.008615451370133087, 0.061448465785360895, 0.060898237497895025, 0.05050897154433187, 0.015902296981948894, 0.02407983483863063, 0.01822878522943938, 0.0191373632333125, 0.013404919955064543, 0.03127280804619659, 0.09187688046949916, 0.07669583414099179, 0.029496362549252808, 0.00660745672576013, 0.13076855801045895, 0.1507693636813201, 0.1021847476658877, 0.09537001373246312, 0.23176820715889335, 0.10301107715349644, 0.21642084553604946, 0.13598069082945585, 0.1088822667952627, 0.2152713478426449, 0.0775137847813312, 0.1408876822097227, 0.1388331947964616, 0.14286108256783336, 0.09312115784268826, 0.13606298016384244, 0.15407582453917712, 0.12719210382783785, 0.1298272327403538, 0.14080310706049204, 0.12316228647250682, 0.16897779365535825, 0.12797002302249894, 0.08917633123928681, 0.09030427696416155, 0.1745484580169432, 0.10709150155889802, 0.14799036202020943, 0.1427012388012372, 0.16767327615525573, 0.11254469878622331, 0.08294957864563912, 0.16576580819673836, 0.1755424015573226, 0.08629105403088033, 0.10343472473323345, 0.11681465286528692, 0.2578679082216695, 0.10958348502754234, 0.10830206316313706, 0.17123007826739922, 0.11080046620918438, 0.09179455402772874, 0.06752941975719295, 0.21670544432708994, 0.0836658402113244, 0.09419705675099976, 0.17128165753092617, 0.0893140812695492, 0.07983158619026653, 0.26702847448177636, 0.18462563602952287, 0.18994267884409055, 0.08756677620112896, 0.20034021232277155, 0.27730644796974957, 0.11168885408551432, 0.22571879817405716, 0.13478228560416028, 0.13022457860643044, 0.09577164179063402, 0.10190426779445261, 0.2899609267478809, 0.18559776042820886, 0.16149733099155128, 0.1931037232861854, 0.12116459562093951, 0.2184287557611242, 0.12273590778931975, 0.11144096934003755, 0.1296237506903708, 0.12724921951303259, 0.20314888504799455, 0.0896475653280504, 0.12034458181005903, 0.12828960665501654, 0.09160392597550526, 0.16387949144700542, 0.13979641342302784, 0.23161605204222724, 0.22450443677371368, 0.23965217551449314, 0.14655083301477134, 0.278383779223077, 0.18416746373986825, 0.16045640950324014, 0.1915818901034072, 0.12869084137491882, 0.17603756248718128, 0.14087147370446473, 0.1664556047762744, 0.13549119990784675, 0.18979701009811834, 0.15884317341260612, 0.10906735100434162, 0.2062251465395093, 0.14875496708555147, 0.1786102619371377, 0.08466203245916404, 0.13319926976691931, 0.12822321412386373, 0.12574607360875234, 0.2094959100941196, 0.1259655860485509, 0.11414244625484571, 0.20056766574271023, 0.08092925228993408, 0.13576022844063118, 0.1596984243951738, 0.10295373140252195, 0.0923563598189503, 0.10211690052528866, 0.09496566199231893, 0.25485698541160673, 0.12693624099483714, 0.09139145651715808, 0.1731520626344718, 0.17330598406260833, 0.17288140137679875, 0.20693373429821804, 0.1002596908074338, 0.09105202785576694, 0.19870368763804436, 0.06197506038006395, 0.14581995113985613, 0.1751514826901257, 0.15417016635183245, 0.21125626954017207, 0.15391788067063317, 0.18755278520984575, 0.13007175555685535, 0.10401283550891094, 0.16476531891385093, 0.07670238730497658, 0.14322785194963217, 0.0932162937533576, 0.10486309183761477, 0.20695856655947864, 0.16553940862650052, 0.1397669204743579, 0.15986147423973307, 0.11159738438436761, 0.11534377554198727, 0.17349294590530917, 0.23874795762822032, 0.25175163173116744, 0.17024385306285694, 0.10053399601019919, 0.166535415337421, 0.09561753482557833, 0.1055289467331022, 0.0562457137129968, 0.12223393394378945, 0.19099514815025032, 0.14057554973987862, 0.1408228333457373, 0.10955885314615443, 0.1322117235395126, 0.11300747239147313, 0.15366804407676682, 0.11665460129734129, 0.1418673319858499, 0.09852167742792517, 0.16940706671448424, 0.07487018054234795, 0.11329534405376762, 0.1362221856834367, 0.06389872200088575, 0.19178353162715212, 0.09641876487876289, 0.1339989190455526, 0.10777123461593874, 0.1494940125849098, 0.12414793280186132, 0.19031070987693965, 0.0918106289464049], [0.04499032431340311, 0.022230380563996732, 0.00027860194791173853, 0.04205829922284465, 0.04715990027762018, 0.0939859751088079, 0.025239498099836055, 0.006405088361134403, 0.03846487212285865, 0.05936343157372903, 0.054669199089403264, 0.00864867732161656, 0.019297258950246032, 0.03645540709840134, 0.007688947252972866, 0.041566852742107585, 0.0034852180260713794, 0.05425594157713931, 0.0324469487532042, 0.08632956407382153, 0.03384716248547193, 0.02855948459909996, 0.028059382821084, 0.05292481066135224, 0.05057825102994684, 0.015737406611151528, 0.031137288169702515, 0.03938258596463129, 0.018542567122494802, 0.03755868754524272, 0.047290132351918146, 0.034719293616944924, 0.019744458586501423, 0.016369415861845482, 0.03871684610203374, 0.06081309089495335, 0.042821598108275793, 0.07090881888871081, 0.02565372040407965, 0.04812541214050725, 0.030569487680622842, 0.017049755624611862, 0.040714800416026264, 0.03757499624043703, 0.0314390602579806, 0.05350940038624685, 0.06567634380189702, 0.0416835517535219, 0.014069830467633437, 0.027183457459614147, 0.08675638804561459, 0.044644695008173585, 0.027999576850561425, 0.042905579539365135, 0.07064585370244458, 0.010804216490214458, 0.04526140859525185, 0.04534100393357221, 0.005124565423102467, 0.03388940553122666, 0.010290286645613378, 0.027382883672544267, 0.02045831559371436, 0.06307306786766276, 0.05758198400144465, 0.04286394134396687, 0.04798210342414677, 0.03973894301452674, 0.0253865323975333, 0.038215291569940746, 0.03819782883510925, 0.024705762189114466, 0.027432961942395195, 0.037850303342565894, 0.053183745985734276, 0.0235724229059997, 0.05798580881673843, 0.19421940873144194, 0.04774387773068156, 0.024404888099525124, 0.02256131534522865, 0.01406543880875688, 0.078065000125207, 0.04715649381978437, 0.07007667096331716, 0.031238238807418384, 0.024393459025304765, 0.011211732562514953, 0.029717242396145593, 0.022935454253456555, 0.023586998686369043, 0.07168926138547249, 0.026710199163062498, 0.08280362788354978, 0.049616483302088454, 0.03209246562619228, 0.05507655281689949, 0.0979219849978108, 0.011052845238737063, 0.021350861352402717, 0.058348281163489446, 0.0905441539362073, 0.051281591804581694, 0.018851818203984294, 0.036421665354282595, 0.053702458972111344, 0.018255734466947615, 0.061449348941096105, 0.06547328477608971, 0.053922461229376495, 0.03733960555109661, 0.0548296699707862, 0.005419410954345949, 0.0032601281145616667, 0.04119381221244112, 0.0026967992971549393, 0.03870409229421057, 0.027022348331229296, 0.018589723185868934, 0.038009839117876254, 0.09117131325183436, 0.03005722024681745, 0.04649247945053503, 0.029037581698503345, 0.03997033723862842, 0.010014191939262673, 0.041018060510396026, 0.03373209619894624, 0.04305597576603759, 0.045325047758524306, 0.04813256273337174, 0.027236417117819656, 0.07209909017547034, 0.03733353107236326, 0.009165007086266996, 0.040841585214366205, 0.04806766191904899, 0.07119809321011417, 0.056430107724736445, 0.06627865601330996, 0.02063200226984918, 0.05933885906415526, 0.03935374981665518, 0.028776612889487296, 0.05643027099722531, 0.007761101633150247, 0.05244863386906218, 0.03598016170144547, 0.027168905799044296, 0.029628051088366192, 0.0477790147124324, 0.07633665692992508, 0.025640773637860548, 0.004798607205884764, 0.05066949066531379, 0.09574210431310348, 0.041289048313046806, 0.014336549065774307, 0.04001875495305285, 0.021631144554703496, 0.03697656546137296, 0.057694230126799084, 0.042495160741964355, 0.032588201720500365, 0.027657092396111693, 0.04948634399625007, 0.042234180800733157, 0.01630689363082638, 0.050338032669969834, 0.010184094589931192, 0.028934079928149004, 0.015142148513405118, 0.03731994976988062, 0.05775288576842286, 0.030210863369575236, 0.028907620508107357, 0.0550340574409347, 0.03427991621720139, 0.03791360111790709, 0.03012346805917332, 0.01889256396680139, 0.02343942818697542, 0.0321048112527933, 0.01738864437356824, 0.03857983450870961, 0.013032443457632326, 0.04318851963034831, 0.017295990946877282, 0.008865834370226366, 0.037920169124845415, 0.06812531981267966, 0.02626009772939142, 0.015427487596753053, 0.04971711110556498, 0.038442544610006735, 0.04053200202179141, 0.03265653496782761, 0.08201166725484654, 0.02472775202477351, 0.026123876523342915, 0.047403179996763356, 0.02032365846389439, 0.07140093701309524, 0.03275685849075671, 0.020533237257041037, 0.048135423712665215, 0.02994163445691811, 0.033857808593893424, 0.058243794192094356, 0.04706392574007623, 0.04437490577402059, 0.06260000809561461, 0.013666547420143615, 0.10139353660633788, 0.02421755332761677, 0.03251144880778156, 0.08862934613716789, 0.04256239932146855, 0.04162035787885543, 0.05503964581293985, 0.02093266484735068, 0.08025648799957708, 0.017126740458479617, 0.0460131299769273, 0.01860369782662019, 0.06944347056560218, 0.04715139526524581, 0.021519210131373256, 0.019784180185524747, 0.05568013781157788, 0.017291714320890605, 0.019888173628714867, 0.04879519299720414, 0.07209122341009788, 0.06691198257612996, 0.018802265003614593, 0.04812249921087641, 0.05699540161003824, 0.028376465415931307, 0.024380156028200872, 0.05763209381257184, 0.05171110235096421, 0.015543368390353862, 0.05310615073540248, 0.08762636323808692, 0.03274572256486863, 0.035166767847840674, 0.09062000885023735, 0.01984318092581816, 0.06359059712849557, 0.048832942338776775, 0.017344987536489498, 0.07577066542580724, 0.16163352993316948, 0.100243667839095, 0.052273130786488764, 0.018228557019028813, 0.02228624387498712, 0.027237140711804386, 0.06813211788539775, 0.03974725506850518, 0.021817451452079695, 0.03358247551659588, 0.01180512323117, 0.03703592985402793, 0.009083732638828224, 0.010410324393888004, 0.040079206592054106, 0.011877143097080989, 0.031164346873993054, 0.032500205270480365, 0.02828598277119454, 0.06873227044707164, 0.041342605400132015, 0.013661032335221535, 0.06845159761724062, 0.011968832659476902, 0.08279566463897936, 0.009796690719667822, 0.011850339506054297, 0.03172874647134449, 0.0314074558991706, 0.07576354080811143, 0.014872356496198336, 0.005914256471442059, 0.01489873242462636, 0.034435670750099234, 0.06854448482044972, 0.017501204056316055, 0.038866607792442665, 0.032535230930079706, 0.029136832818039693, 0.021099961631989572, 0.02654302297742106, 0.026289412562618963, 0.020216241864545736, 0.011994578690064372, 0.04278925160178915, 0.033782046448322944, 0.05367979749280494, 0.059368326037656516, 0.048188568907789886, 0.022418759908759966, 0.042898592218989506, 0.04444074169441592, 0.06628159491810948, 0.03410074321436696, 0.027660190862661693, 0.06166118757391814, 0.0232811447858694, 0.03481841857137624, 0.0328967347741127, 0.031141418221523054, 0.07619871394126676, 0.009326495637651533, 0.07802858293871395, 0.02491057453880785, 0.004805507323908387, 0.018916975059255492, 0.04157847106398549, 0.024896132345020305, 0.05640953910187818, 0.11613688649958931, 0.036103925958741456, 0.021492186679097358, 0.009106049947149586, 0.056185492139775306, 0.026841581566259265, 0.03225057647796348, 0.01188149857625831, 0.05605191669019405, 0.010458417418703903, 0.03553108072082978, 0.05704430543119088, 0.04454678717593197, 0.09383303331560455, 0.038761638425057754, 0.02484453081706306, 0.06893101759487763, 0.05967497774690855, 0.040308374373125844, 0.008360653519048356, 0.03493438656732906, 0.004916499683531583, 0.026505028727115132, 0.06329472511424683, 0.05190759708057158, 0.007519574310208554, 0.027305342227919027, 0.03053286640351871, 0.026901608325715642, 0.022932571009732783, 0.170990884071216, 0.09133947649388574, 0.12288148747757077, 0.0547094494686462, 0.12591782142408192, 0.1590582329663448, 0.10339001033571549, 0.07544449894339778, 0.07157330081099644, 0.12801113800378516, 0.1444574719062075, 0.08171222551027313, 0.06486394442617893, 0.15950626751873642, 0.20483881467953324, 0.1342658547218889, 0.12617248197784647, 0.14245000696973875, 0.13721157243708149, 0.18086201220285147, 0.16930364101426676, 0.2247296934365295, 0.16633132472634315, 0.11276758799795061, 0.11146246193675324, 0.18246951891342178, 0.1216706661216449, 0.15368877968285233, 0.08772453453275375, 0.13421782292425632, 0.1618588756537065, 0.1472033144091256, 0.1091054231801536, 0.1270951348124072, 0.15564773784717545, 0.12389978830469772, 0.09981043913285248, 0.2063110427116044, 0.1446426080656238, 0.22454840160207823, 0.2550134598277509, 0.2059078190359287, 0.21212891646428034, 0.1693960532429628, 0.05775340898253489, 0.1383385682129301, 0.09511269629001617, 0.20362546260003, 0.0897730550786946, 0.09497287566773593, 0.17191717342939228, 0.1808286304003559, 0.15532892604824156, 0.15439070295542479, 0.1646472729044035, 0.16680261818692088, 0.1341123043675907, 0.11475550476461649, 0.12560194852994755, 0.11574489893973805, 0.10778416282846592, 0.170941308606416, 0.1584312814520672, 0.14648981363279745, 0.2198942005634308, 0.16393393540056422, 0.09796003490919247, 0.15056807838845998, 0.15684983896790072, 0.24701260321307927, 0.1960917137330398, 0.11685452845995314, 0.10050134151242673, 0.20910999330226332, 0.1983698399271816, 0.07315896611544304, 0.1580608161748387, 0.39885512727778405, 0.1910375544684939, 0.13891937298467383, 0.11061627257731743, 0.23468581232009456, 0.19347907189512625, 0.17208782286616042, 0.16641937312670052, 0.07351911553996615, 0.1070637081284076, 0.08335732942214236, 0.11737746055587195, 0.08731931447982788, 0.12278989161131904, 0.10942314402200282, 0.09393734959303401, 0.2144200005568564, 0.1489545454387553, 0.1143980493361596, 0.14880979695590213, 0.20259252662071958, 0.08650903022498824, 0.2789770223898813, 0.08442905003903434, 0.16393580561270937, 0.16934146085986868, 0.11265324530540965, 0.15277587866876274, 0.16760292055550963, 0.13348515989491716, 0.15944719256367534, 0.1198163878871128, 0.07582681631902233, 0.14434856915613636, 0.12276787208975293, 0.10423311978229322, 0.07846447595511563, 0.2036589483032003, 0.08161585763446055, 0.17379295168211684, 0.08214888293878175, 0.16221945552388206, 0.15916713571641594, 0.14130763389403, 0.13847596943378448, 0.09704487034468912, 0.12644603761145845, 0.16072068829089403, 0.10978134901961312, 0.12809756852220744, 0.1418227140675299, 0.16794030088931322, 0.18538074160460383, 0.11349795036949217, 0.1474295210209675, 0.103653665719321, 0.1468754929373972, 0.0792529113823548, 0.10001736474805512, 0.09378578819450922, 0.12966400478035212, 0.19487626879708841, 0.17204195813974366, 0.07916217640740797, 0.17937048833118752, 0.16043472394812852, 0.12602734757820144, 0.11433944193413481, 0.105645805306267, 0.16473996714921668, 0.1262543853954412, 0.1326316306949593, 0.148630820622202, 0.18638270033989102, 0.20004759833682328, 0.10721277591073886, 0.10638301027938724, 0.15719606570200995, 0.19978849973995239, 0.17235596082173288, 0.17122152872616425, 0.18555545801064, 0.19436623522778973, 0.11701651703333482, 0.1566538674524054, 0.15670057822717354, 0.11601444697589613, 0.11917697571334429, 0.10091818359796889, 0.20679009903687984, 0.04731276785605587, 0.159536725259386, 0.13556137739215046, 0.16267354600131512, 0.06442876387154683, 0.11607575579546392, 0.13012530893320218, 0.1580007022130303, 0.09696917870314792], [0.018587804734124802, 0.011274640710325912, 0.01322259560765815, 0.0694864928664174, 0.05306964449118823, 0.04704296006821096, 0.03155305785185192, 0.033438302198192105, 0.013220962882769527, 0.05449621188745368, 0.035919728616136126, 0.06349486749968491, 0.058616571259335615, 0.013080133867333643, 0.03416403356823139, 0.06263291492359713, 0.027142370308865793, 0.032589912370895036, 0.07962380710523576, 0.06385327287716791, 0.04929575305141043, 0.022514120319101494, 0.05012946690840181, 0.06169718544697389, 0.031952351855579764, 0.011782607398345135, 0.034220603774883784, 0.02753195516561391, 0.0412782277999213, 0.10999567384715192, 0.015127671067602932, 0.023256336644408293, 0.01646780609007692, 0.03929127582523506, 0.024401815608143806, 0.043973474384984, 0.026531979819992557, 0.027612817721092142, 0.08886597250238992, 0.029118761522113346, 0.03245173560571857, 0.04659130754589569, 0.03951227256038692, 0.01600355561095057, 0.05515316101082135, 0.054558689589612186, 0.013222186498751398, 0.030752874226891436, 0.059264722221996635, 0.0567267293081386, 0.07241525992867537, 0.055601444182684645, 0.009346519709652057, 0.03770667179196607, 0.046671118107042275, 0.050763576437020674, 0.05092700106615666, 0.05321609991369769, 0.08348796967766248, 0.05905546626308933, 0.02630502549436642, 0.060643075994448736, 0.0306507213099394, 0.006906029229867272, 0.051339108249521814, 0.06931139054358937, 0.0626093294704333, 0.04506730358116329, 0.05237392928393092, 0.07934865585411899, 0.07917793220258318, 0.028265391883905977, 0.04605761059792712, 0.05283324819174595, 0.026244178661727346, 0.09029775348608382, 0.0736414734274149, 0.0630679247842636, 0.02904713313910179, 0.023981054982868955, 0.02902544758399017, 0.03102994949585991, 0.033301030853181146, 0.05597250688879285, 0.02875467500416562, 0.007530356324423337, 0.08960457271314226, 0.02053040410828544, 0.054288410537992604, 0.054699426764273085, 0.01564130034239497, 0.057186797785107046, 0.02916468005423667, 0.02776303397695301, 0.05941818351857364, 0.014968044379202183, 0.0565333627309883, 0.010584440587990684, 0.030607008811784908, 0.09274580181227066, 0.030085926518950146, 0.02663594357727561, 0.07451653233147226, 0.04079954625922255, 0.021114194169058464, 0.04108709137653932, 0.08141396378050558, 0.09331266905064695, 0.029030423684162088, 0.04243649396812543, 0.03615168316173367, 0.030220641165215056, 0.028703544739983045, 0.037978524196660146, 0.008064083885983564, 0.029782620040350594, 0.03832119233265985, 0.07577391603263095, 0.055372447095578536, 0.007600413673571893, 0.06171912704303395, 0.07872188987676054, 0.059983562750858255, 0.061985840075067244, 0.03623518590757158, 0.0988006655825302, 0.014852466938464204, 0.07886050821980461, 0.032651158107910305, 0.008640840242151171, 0.09213073208229616, 0.06812693769461475, 0.04224735763273202, 0.06198968811077066, 0.04912754528049845, 0.032486445852555335, 0.02309026811417425, 0.03882835379044991, 0.045390835439320654, 0.017487298064224888, 0.042889478645520285, 0.021047259870101698, 0.010215810270892689, 0.010124255222763168, 0.05043625220423564, 0.05455568760226015, 0.08709539368283004, 0.004345177703726222, 0.04963776809745468, 0.06422004225896671, 0.08331928693223745, 0.02979091168526793, 0.052774117575609125, 0.06794108165195212, 0.10294508538208902, 0.04591920005623251, 0.034817758059944026, 0.013553586049965816, 0.06765582234947942, 0.026990309816028457, 0.052498331788228825, 0.023483112854592036, 0.03251452500990126, 0.024885749699024018, 0.032387053724960424, 0.030634223367087543, 0.016378872678615153, 0.022762329754186794, 0.020230231348250527, 0.056666897362447344, 0.014586533161491388, 0.05267520042252727, 0.031504821963608265, 0.027522587406565435, 0.052872567175654694, 0.025588968019292224, 0.03276105162512977, 0.0394663521728944, 0.03470956777164247, 0.06221742354682647, 0.02032258977124002, 0.05342818345525302, 0.017554391924932133, 0.033788770306273364, 0.03822993785433937, 0.024834957112034317, 0.03804543623118661, 0.06512930674944073, 0.055371011039824225, 0.036966130865039304, 0.023760742878948804, 0.0802567700156942, 0.01820035911805462, 0.04849640805332456, 0.08988145316834562, 0.0033894744819917833, 0.0445871711417567, 0.01666165320784785, 0.012622249159903731, 0.016948975680861622, 0.0522084748808993, 0.032174821753869765, 0.02193641586927697, 0.04335226338298526, 0.021189954459259752, 0.04031928023323417, 0.06119192017649766, 0.07803143278579228, 0.03645594515546691, 0.05501832019945141, 0.01377919801598182, 0.012562567499116994, 0.02415125913103111, 0.00777650258896756, 0.08949733237386681, 0.08492797365761362, 0.015864356537349522, 0.0028118175760027952, 0.02556739935243968, 0.028806378577428404, 0.014824241206952138, 0.05968243262032047, 0.053489722340600565, 0.0317105749854818, 0.031645262279198505, 0.015434724464284955, 0.03828622975561302, 0.0239015691113309, 0.03735592166776769, 0.02852072964742547, 0.016448415626655333, 0.05213309865212068, 0.04225018150464166, 0.0015671836240471748, 0.018463029300619382, 0.03669529520266224, 0.04165083417319693, 0.015328231838793727, 0.04647711328289006, 0.03992394187662285, 0.02965411160403164, 0.0163049195180065, 0.05154877981112804, 0.03943777577660512, 0.05308337051246781, 0.04091343995241914, 0.01841253357270034, 0.026887186540989205, 0.062467215611832216, 0.03240524747525342, 0.05151735356776044, 0.06296245075645857, 0.046553090651286766, 0.04418603661179077, 0.03261253303207923, 0.056399649984086864, 0.059806527133332565, 0.05035509464505594, 0.04547460535832215, 0.04110973430215381, 0.062122517701936886, 0.054619326765532605, 0.05113216036988888, 0.035001896030735224, 0.028919288924953435, 0.07911075299489312, 0.013488054410117911, 0.05742843364714645, 0.05129448662046343, 0.05783697110018693, 0.009049712589330738, 0.030964495781518053, 0.05836253039888106, 0.04812833620235324, 0.05883498532057274, 0.019671403424581513, 0.046678472790517844, 0.011493907313706586, 0.0279422385210637, 0.06690523645374924, 0.08186022459995002, 0.017999402225541417, 0.04870044671406504, 0.052207146436558105, 0.05149823584361002, 0.0745968846604228, 0.07162744048400782, 0.1158581580966711, 0.04248731995176058, 0.016457046804134734, 0.06407893029972911, 0.04538690947811119, 0.038272670717560686, 0.052133473436697386, 0.06862355323391967, 0.04524589399807155, 0.02631086990732001, 0.022743865119991824, 0.054722563218092546, 0.08133549650665373, 0.022255446601775475, 0.032478493740200065, 0.06646649359026924, 0.06895507802255452, 0.028050714536220767, 0.005415089335656376, 0.014766982658329653, 0.09076739937881939, 0.04197859627311118, 0.04134162576519884, 0.05918773924349807, 0.034286083464394324, 0.008825336299196351, 0.07596093724714592, 0.057377752382308245, 0.010106114350492135, 0.01751608040649444, 0.03286454411863815, 0.06874528029584326, 0.011413525298848981, 0.04386306136439089, 0.020404554416018073, 0.03233952658774797, 0.02627782763738651, 0.01981845998670906, 0.06852170830825344, 0.0091837741456402, 0.01817585896787932, 0.03569120650354307, 0.03922149167919997, 0.02813099265040364, 0.058625076271709986, 0.0716839253436774, 0.0550888130965177, 0.004828699438803596, 0.05807811343402136, 0.019002210719918367, 0.017293862838414498, 0.03925482524209656, 0.02836682862835005, 0.03549451139406301, 0.01709265918179881, 0.00929008494495065, 0.027530164734343998, 0.02729717303736834, 0.012446712680684868, 0.0218073582436773, 0.028360696633171756, 0.03177604354277719, 0.059827229342772625, 0.03129625249130186, 0.04464354467927478, 0.20855241775279865, 0.10620575572829694, 0.08869597615557723, 0.13405091391177848, 0.26362350094132125, 0.202616156602744, 0.1068501996633131, 0.14834225876256824, 0.12459056451916695, 0.11591540736844763, 0.16243239253526554, 0.21707335661631078, 0.14114105142652988, 0.1086715265410021, 0.11881505997735076, 0.16988462390145287, 0.13895035022869706, 0.21562388283200562, 0.20280887751141563, 0.16808841872261837, 0.269724756362848, 0.16409784613642842, 0.09627115170587786, 0.16929906938457862, 0.15739408554509282, 0.21082561608636752, 0.14137463498627767, 0.08758360811043531, 0.07794846809701994, 0.12995363533264026, 0.16273201239528134, 0.19724999845493585, 0.1395464877714403, 0.1535854727262631, 0.18855695554520935, 0.11262150364927948, 0.12758109311107546, 0.08626452225144021, 0.24877615389414132, 0.15109424624824896, 0.12293570136534981, 0.17044516804162413, 0.10960386440274306, 0.09945299854734913, 0.10071107986732386, 0.18003049510298297, 0.166892358683981, 0.10668671937310137, 0.12850373110268265, 0.06773912842618302, 0.17389924207236618, 0.16373842401662841, 0.20171841024421155, 0.11961028605583124, 0.14222602680092677, 0.16469108930323273, 0.12177772834547795, 0.0874551794549916, 0.17861410626210272, 0.1304191251983866, 0.05660818605974782, 0.1279430979047902, 0.20404774462804198, 0.16389684285968542, 0.1708247172064148, 0.12892430619103834, 0.1872991191339679, 0.11960383679252118, 0.27643219800665975, 0.22885354090249166, 0.19574596197344363, 0.10613524427753873, 0.14446228102315217, 0.1769176754169166, 0.17192000843351707, 0.20907913480186835, 0.21974743343889713, 0.22536406642757356, 0.12243832883541472, 0.12867075885878876, 0.11360706092091277, 0.10901252113399096, 0.11040364726795815, 0.11630380293354392, 0.111507532565156, 0.16445551678771153, 0.15965451893862337, 0.1452107072691433, 0.11719650268787518, 0.2138732306775637, 0.1137087277311366, 0.15895090356934816, 0.07781843640259467, 0.11360815929947421, 0.1261331036221236, 0.13388540013693273, 0.14847770071355626, 0.1470544098992832, 0.15698312869062647, 0.1533058611676097, 0.19397460389882326, 0.06858620094135404, 0.15291952877305448, 0.13405636127572507, 0.23410059919115156, 0.1645175603334792, 0.16523592959856614, 0.15636407362762839, 0.12749031360726804, 0.1726134415366687, 0.1619094901252538, 0.29533668828662485, 0.17780077178031206, 0.09963455755496398, 0.16190632857615128, 0.1569213523180224, 0.1705996535019949, 0.17278176062973216, 0.19964677921961993, 0.14169393660267815, 0.19872998935170472, 0.29177203425206244, 0.19710268214112148, 0.307652183691971, 0.09615041912184097, 0.12012765204417519, 0.17151270294561982, 0.11754416176700033, 0.11423042786191218, 0.08337121500517242, 0.11978972252109088, 0.1340968528529629, 0.11435547232395038, 0.28037876123562455, 0.10650501935742795, 0.10566632568952627, 0.06225498735147994, 0.1166007733263541, 0.1184032867604401, 0.10576396263786592, 0.10909833566984162, 0.10814575201948173, 0.0697698893782217, 0.10641944230883382, 0.10068078539916314, 0.1610078994417563, 0.16390136996051297, 0.0973217433784157, 0.11268599628238007, 0.24310163338668644, 0.14588048070436344, 0.11812340060714632, 0.10217011251370423, 0.13005015905946493, 0.15280112653272226, 0.10440348720294423, 0.12576743261888623, 0.1612224691780284, 0.16059008514275774, 0.23581071523949504, 0.15720335359219462, 0.1296964514767751, 0.17636461212532595, 0.13385899452259764, 0.14272141037508845, 0.0834315738757141, 0.17938893812242895, 0.06956699362490326, 0.12445882588508539, 0.10758937132777646, 0.08940912812249735, 0.11025230109225959, 0.10447525288327597, 0.14483535866020247, 0.1720934483455494, 0.13331814698176458], [0.04952515089826193, 0.020036632849951275, 0.021307425304257777, 0.019810550547845196, 0.03802399187406991, 0.03941096940252464, 0.01352588909867336, 0.02279901411384344, 0.04683305473008659, 0.016256108465313446, 0.06891238226671703, 0.041264568571932614, 0.03595830174162984, 0.04866056740866043, 0.03427771574934013, 0.045210530661279336, 0.02399343029537704, 0.022778636594011914, 0.02230571597465314, 0.03134233986202162, 0.050304123942623846, 0.014976580932852812, 0.06461564407800324, 0.041663832889753394, 0.03617264883359894, 0.024148442680598237, 0.02903655567934038, 0.03618995200667996, 0.025174120455631055, 0.07673347587115131, 0.04927158872305881, 0.05899251358641777, 0.048801293451106176, 0.028015026509820018, 0.004783998492712271, 0.04687021777499467, 0.024858379292709287, 0.06976882068556733, 0.0015459350083801837, 0.03346999190398492, 0.052985648217145354, 0.04833885752304923, 0.017149439045169856, 0.03011316519405227, 0.03043868600798305, 0.02056046108918963, 0.07749571348540485, 0.04804989861440845, 0.07015117516857572, 0.034522372152423486, 0.015359411318058847, 0.031498936732532457, 0.05326440259523224, 0.059087100307806395, 0.10320281100575812, 0.008681488598085707, 0.06329584575723857, 0.027012501886929385, 0.0881874120386783, 0.04416740499436855, 0.08390162052819505, 0.047538477228954434, 0.028912646703247447, 0.04337063895945903, 0.024849939218256623, 0.008604101149103371, 0.0393895992601756, 0.11094376750406809, 0.03428206473472528, 0.020725145514006726, 0.041647720863693394, 0.05104403775476385, 0.048231038308585994, 0.04929249502310995, 0.03034380242752377, 0.010269101112498902, 0.010511613636481343, 0.017610613322176505, 0.050107773931813426, 0.024856976633600425, 0.017533912359795067, 0.049620843419688754, 0.04454857946257107, 0.038313444310915656, 0.05003689511795528, 0.05240283593593631, 0.08543133531929925, 0.08858140339725651, 0.015416035330417799, 0.026878816970565822, 0.03994951999629848, 0.025583598580851685, 0.04259088666003663, 0.039838743323343806, 0.019462652126094326, 0.01255861556273885, 0.009079427254619077, 0.038132653426146135, 0.01289796444325475, 0.08215044144890271, 0.009425012030988, 0.023425238323397934, 0.1193353945564013, 0.025011738543980755, 0.05437579471617937, 0.05075426619441714, 0.029511452266888227, 0.029140033329895232, 0.05550685746129602, 0.03921846000594087, 0.06475931644672528, 0.04795107051904779, 0.04266670817742124, 0.020897971298836637, 0.0066237468672625255, 0.035711099772015586, 0.027980880295217503, 0.05821115082653705, 0.0638351273664739, 0.01117525971494615, 0.03432799254369456, 0.009820358736760681, 0.01919024311064277, 0.028436857683118433, 0.031481010155403055, 0.04358373553259298, 0.04726799037598539, 0.020523247949313372, 0.023614947967871558, 0.029136378252587747, 0.05573783979343716, 0.033779211444198154, 0.03284916681877803, 0.008244818181992741, 0.004686878264692496, 0.018432877695886418, 0.06364924905938096, 0.04132390327868052, 0.0557517736160662, 0.03303699326352216, 0.10439440331538208, 0.007623699020768981, 0.026341631928517018, 0.06165349892398808, 0.05733222162234597, 0.029618124863191042, 0.04979541139618959, 0.028876585747639183, 0.018630977319844533, 0.05849078836035915, 0.02761554696917301, 0.026195349055342376, 0.044210119303897955, 0.031354284728877246, 0.00803106851890334, 0.06674560048850253, 0.06499049544800073, 0.032986939113470726, 0.051826231720042415, 0.030476064275717363, 0.009216968555847416, 0.08375431905733421, 0.0262852658124757, 0.0505010639608372, 0.016511273679498117, 0.03578645744710229, 0.02883345583541086, 0.0437126725591952, 0.05409154102380853, 0.04710373825218994, 0.029119193823134992, 0.08241299103247002, 0.012755865427607205, 0.01595849982550135, 0.023697033211647067, 0.07451124824001454, 0.031201231613522395, 0.03326488455059007, 0.022779465944040567, 0.02809620633343002, 0.04375642216473352, 0.013377325976762222, 0.06139575103588868, 0.04325526097090915, 0.024880224409571383, 0.01679947745287791, 0.08027879695873708, 0.025755633978405967, 0.010349542499170639, 0.03739164494618308, 0.01973528378584888, 0.015277888251148397, 0.03806234977673739, 0.027239838418608997, 0.03426355186093133, 0.05018354349886067, 0.04730422573629767, 0.04288353033189196, 0.04060631697939243, 0.0466131044231588, 0.07155934101319872, 0.0470673618838191, 0.023992266978893895, 0.04038785096781794, 0.005545106187128113, 0.04116461241210345, 0.042266263844794594, 0.05834500458149705, 0.05066773548605852, 0.023123648061300628, 0.027850726146425586, 0.035433592202025466, 0.03810843714745715, 0.07086020079441369, 0.015294591212295927, 0.019426481703703757, 0.013271355637698434, 0.05864408638444729, 0.0605452164018061, 0.005537995948543539, 0.011152952611155342, 0.05771557800471783, 0.03266229774453677, 0.026111081897397526, 0.04031977747217752, 0.05338736162229907, 0.041825780645012856, 0.03390356570889708, 0.04725082078948617, 0.029994165524840355, 0.10470041306689382, 0.014018082365510054, 0.03155171827529557, 0.01213483810715843, 0.059882623245357536, 0.062163461989257485, 0.11745644733309746, 0.07013521157205105, 0.03733710451342631, 0.026918698131339625, 0.013373073470575036, 0.04533797226031311, 0.006014916280037141, 0.03421840701776091, 0.0351316828164272, 0.02397645923338132, 0.004392708087834762, 0.027302742855681572, 0.024993160732265096, 0.0442623405251652, 0.04485547979129478, 0.003986433721365756, 0.055500478702015243, 0.0110801701885066, 0.012834024710173253, 0.030567528410756495, 0.014192866492521716, 0.025910321674018633, 0.046308415694511496, 0.04149013322603423, 0.05441080924356356, 0.023305537324631587, 0.0412018942006398, 0.03394025749003049, 0.03709574695676565, 0.009309037541243015, 0.02266621606395347, 0.03960925641877111, 0.0568060945806792, 0.030159644047671463, 0.022495596313092392, 0.027178362615813967, 0.027132162067573518, 0.05709195502276998, 0.027484713755256962, 0.0515930303663481, 0.015421411262650508, 0.08447282190900296, 0.07488373215892352, 0.045300534620764665, 0.0727079703938216, 0.008479657826683251, 0.07496316422475502, 0.041173451390932314, 0.09471395518630743, 0.034239550805068575, 0.07574379967991263, 0.04023816349217668, 0.02171825970435748, 0.08242162220994942, 0.044103706459281966, 0.006785875057175872, 0.029757246011286043, 0.02719419262575684, 0.032159559486899525, 0.032635506213409826, 0.028493134741438553, 0.046823722223052755, 0.044328573494567536, 0.062135564658092335, 0.040430465087410994, 0.048477698510396294, 0.03856117691611871, 0.032757986555225216, 0.10335821672924794, 0.050650024131755345, 0.029578052599390503, 0.06025011993187945, 0.01670785746682668, 0.006189434161569807, 0.06308875686954707, 0.04143040147027932, 0.1449771533953026, 0.06838273373432457, 0.05423448979854584, 0.046354350924957544, 0.05789053189801052, 0.03198705097020138, 0.0903317735355813, 0.06336456121061929, 0.013299808651936473, 0.01898088325106073, 0.053727384001831524, 0.05359111455618404, 0.061706039268756285, 0.044416785167413764, 0.07562880389741622, 0.033957274936256, 0.0041922377658920595, 0.017960923723876476, 0.0165840913541615, 0.01582299664733, 0.05248584886430763, 0.06641459520324133, 0.0324659143370809, 0.01930656362674199, 0.03833363072772045, 0.03628771512012463, 0.01572499419125961, 0.022059384173189756, 0.04023846035124734, 0.06499491864815354, 0.01780481296009384, 0.023416174844896886, 0.041341699979966506, 0.011873791372636333, 0.038974434428382665, 0.013340256627998315, 0.04463161465537269, 0.025390360024175607, 0.02242567115899874, 0.039508895788458176, 0.14021709241205826, 0.09281536331400275, 0.10290502425050363, 0.08902989065973088, 0.08777153474511579, 0.12611501006176695, 0.14336704916786402, 0.11567013498279266, 0.1327192783355713, 0.10670153264072724, 0.20365992793813348, 0.1408892555627972, 0.1334167190361768, 0.11559445076272823, 0.07118155815987848, 0.14613935665693134, 0.11683406002703123, 0.104150659753941, 0.1365712919505313, 0.18282963865203783, 0.17005473899189383, 0.13894822768634185, 0.17984950012760237, 0.1467113447142765, 0.15816185215953737, 0.10426274631754495, 0.18106552393874153, 0.13780380628304556, 0.07871584879467264, 0.17552999284816906, 0.11987140329438262, 0.1375174114946276, 0.12293279956793413, 0.12013529616524465, 0.11215768361580558, 0.16594235028605908, 0.10670272749848664, 0.22250316134886816, 0.07632009219378233, 0.13137695583282039, 0.12689551193034276, 0.0757252163020894, 0.1260137662757188, 0.14580675575416535, 0.2323276677634567, 0.13863091502571478, 0.07385990975308232, 0.12796868715668097, 0.16993770230328664, 0.13643273297930136, 0.08631239077658392, 0.10883220151299611, 0.1348785124719143, 0.12576465698657557, 0.26000597630627453, 0.14183175342623144, 0.1565441334969364, 0.1156287602498196, 0.15120406926143914, 0.13392958760960028, 0.2630677807610482, 0.1348935632267967, 0.31902155955322087, 0.12237938746693544, 0.10271982129779644, 0.12750367226544768, 0.16004824312403798, 0.17535034858155996, 0.11474596816697158, 0.06751943787094206, 0.1676496461732313, 0.08433959155809134, 0.093424466176657, 0.16990754142170772, 0.15336221986217424, 0.09207366092596203, 0.2460231867735274, 0.11620208417298272, 0.13269802322611213, 0.17637096490943804, 0.08352168544661254, 0.09356787879369222, 0.10923864610958844, 0.1375093517708592, 0.2116741135250777, 0.1742977011599578, 0.2122143525048159, 0.1319107084418647, 0.13067038671579212, 0.07194568825070746, 0.14109444455243647, 0.1644703300553374, 0.11712088526110165, 0.13540589745389298, 0.08428987508523278, 0.1527473801979795, 0.09159392182482406, 0.19827057025395334, 0.1962579696555622, 0.16577944887103513, 0.10992665411322378, 0.20043099182657897, 0.27927503921091557, 0.1355143846012652, 0.22961538517847657, 0.19171068241121247, 0.11607142907450907, 0.08173743626684882, 0.2641515538562089, 0.13315025833435357, 0.18439460545778275, 0.1211313102976419, 0.13788713462417945, 0.15283712069503963, 0.17859918909380212, 0.1502189869643189, 0.17773586354451254, 0.1699395279865712, 0.08437535565462895, 0.12406192530761473, 0.14751779206562787, 0.15028088208055124, 0.10847496130736545, 0.08434817820671014, 0.2296837221365422, 0.19908780843252316, 0.17487221251940355, 0.0693089043488726, 0.13431844330625609, 0.10535659035667777, 0.1115916550043039, 0.17093434726120904, 0.13469066005200148, 0.07434712228132412, 0.11938149677007459, 0.10194703034358099, 0.23168464133050293, 0.11775082763051614, 0.09656640773755498, 0.16682353190844879, 0.24164974020095542, 0.10343218658817932, 0.24237052886746824, 0.10635889047989622, 0.11910324334166944, 0.14709457493154332, 0.16907474782783538, 0.20454612647881731, 0.13389230211032555, 0.12616642605280504, 0.10269837322994135, 0.10752901245723478, 0.2085853394237347, 0.09433507395442575, 0.0964863522676751, 0.12069237447576597, 0.14735022996319458, 0.09227838236256503, 0.13493671169271693, 0.14862569980323315, 0.09071718566701747, 0.1439651459804736, 0.11531872063642368, 0.1241820641735103, 0.1189744436123874, 0.19105546991340816, 0.09353564732009545, 0.1172889668669086, 0.16304545104503632, 0.1175927279109601, 0.09254802687792107, 0.11770516328397207, 0.12244795449078083, 0.12677768856519833, 0.07796188612701371, 0.1554557294002734], [0.03216031276679132, 0.05172373370442074, 0.0287030011168099, 0.024113301988109015, 0.06160721488413401, 0.0056227881759696174, 0.03470282164926175, 0.0415936516947113, 0.04654165786632802, 0.021504792057385202, 0.06281025111093186, 0.03850753819278907, 0.04235740329022519, 0.08193051340640523, 0.04823847091756761, 0.030392394546652213, 0.049156240420416, 0.036884368455503136, 0.06060285530111287, 0.010740039269876434, 0.021816579428559635, 0.005209346518313396, 0.053397881565615535, 0.020402296431711875, 0.009298130753450096, 0.05968345307337586, 0.0571272738307016, 0.09702268012915738, 0.025824269650911447, 0.028732692589983344, 0.017759714501153212, 0.024855653755366802, 0.017685560960671864, 0.03590589127270505, 0.027584271010709926, 0.016636032414680813, 0.010537755788391223, 0.04476965783396736, 0.09185018541757017, 0.03833677001239266, 0.05483497261593584, 0.04250095320458058, 0.04313156350690406, 0.042918478065985255, 0.035222540245740674, 0.04887878480076324, 0.063093907374423, 0.019126824736304116, 0.04974015108018648, 0.007913756307971198, 0.09380180374137126, 0.054733624929212965, 0.06637258222326636, 0.027754521543101873, 0.013025314201513538, 0.04620839645212982, 0.07223535591037944, 0.0419814461201895, 0.061779344905517064, 0.04156596587563399, 0.014163114719849546, 0.07561564561910927, 0.05340058298315853, 0.00857912324136123, 0.011507206600072095, 0.03795222619373817, 0.06676510412944481, 0.021907522204855923, 0.035030516955885105, 0.02144632195268059, 0.09961679053958505, 0.0315259509079624, 0.08285711446660571, 0.03847997482807841, 0.025010456483869348, 0.10093172037159093, 0.04550795005343389, 0.009932029697665712, 0.05375523309339769, 0.03194275588612072, 0.028728690558637027, 0.007869635628594551, 0.03723463989445008, 0.07696115193539299, 0.033502097212476656, 0.05960791357210837, 0.03615766116126906, 0.0657291772949975, 0.00703480205629603, 0.03434732177993283, 0.03822160724666901, 0.02300735537573928, 0.03778606675041374, 0.06249565471080132, 0.06019101529091131, 0.05680584225046914, 0.057509253529133275, 0.04604504974849988, 0.044000503403367475, 0.053314041142584756, 0.005274888826534152, 0.042171751338173635, 0.056685272938921116, 0.0786079405224882, 0.0271266553318128, 0.04732325811346527, 0.025380144361406565, 0.0622155125165591, 0.06741969322320074, 0.040269827222800814, 0.018709505820879713, 0.043194401150685735, 0.025723842227307614, 0.03898911782016512, 0.02324682045582449, 0.015161913761403412, 0.021795739921799395, 0.04356129669758957, 0.026639427960617468, 0.031065377770573832, 0.046096057558315806, 0.04624632390914485, 0.006503170134237735, 0.008083694210654357, 0.03978245884354692, 0.033118403152911924, 0.05214860582782421, 0.024236095887317788, 0.015676810253353324, 0.020016208945889957, 0.032584368527750485, 0.03623202064773068, 0.04252652761351783, 0.01787940251233522, 0.1514562955708243, 0.09245277222362347, 0.03284964921476785, 0.11462211856269278, 0.01854492900747573, 0.07379077869700268, 0.061815988447051495, 0.022729118645656854, 0.04855022860283498, 0.02809720823279349, 0.027816145775432233, 0.011548239017429296, 0.09522435240796767, 0.04681060105212964, 0.04816212247533258, 0.050566343270475045, 0.016062624999904074, 0.03472311938821804, 0.038185913654160686, 0.05398288689320907, 0.03702566224092152, 0.07108593243174255, 0.035073231265414506, 0.01595175184775144, 0.0574525237607304, 0.026255056691297796, 0.04945658758515492, 0.006473968478530878, 0.08093262906186283, 0.04370595983345993, 0.08306777308462188, 0.028267377128941007, 0.020104121904296335, 0.02427618299407186, 0.05047239479608834, 0.07724419963778928, 0.05307993807946332, 0.07147523341700435, 0.0327549140638439, 0.023800540548108984, 0.04798180285433773, 0.00935112473598565, 0.04531340346147772, 0.05183818771911319, 0.043730283723562025, 0.03279522010416258, 0.02621963769342983, 0.02286785573232919, 0.00934532392420806, 0.03967254677263554, 0.0547292351257056, 0.06894378253491595, 0.028751732388627715, 0.026485313574085012, 0.03426405652135145, 0.03736879792995751, 0.03413845544855576, 0.058565986473695375, 0.06685034721158445, 0.006015077697156812, 0.01377302984110429, 0.043514459757716395, 0.040455954149365425, 0.016187572982744314, 0.035702917593880557, 0.026718756125774235, 0.013242846034700051, 0.04905134155706037, 0.044123558909632266, 0.02416494804492686, 0.06567288539372385, 0.02649577785632573, 0.05266268410196062, 0.0342348752747057, 0.04740400749142282, 0.0341858081810642, 0.07572690097731538, 0.04900576997897588, 0.06091900650062598, 0.019576627455535345, 0.04548624223389197, 0.019689988657773938, 0.08501705364324152, 0.03501580758893397, 0.029429741807689425, 0.04042458727781195, 0.06372729330905713, 0.051103981022606604, 0.045369732470135204, 0.004568506174109643, 0.0462443201104179, 0.045561136066680774, 0.005193874130782206, 0.025005378338391893, 0.019556786137400195, 0.06231600302271545, 0.010956872556562303, 0.04217883513774723, 0.0207471501926193, 0.02260744724480901, 0.03839289121970069, 0.043250711605651304, 0.015061307294672588, 0.049444427495473064, 0.09763645852217451, 0.03255159899708815, 0.01204217169288313, 0.013530226024158765, 0.0628175909514539, 0.05738540021411609, 0.012309201065363595, 0.02685329080122756, 0.014818728905083844, 0.09787701827008277, 0.09322863566922024, 0.05430404387880117, 0.0347293682716554, 0.10257133981212974, 0.05162151770491619, 0.006726993060510722, 0.02538469372666441, 0.03675816253235098, 0.01864668302005157, 0.04182963239145465, 0.040503956261090934, 0.02581957000074908, 0.045795083278790116, 0.027797692273452412, 0.016418570157838985, 0.04000209744845051, 0.01694722792308312, 0.03270558350777719, 0.024968122525024228, 0.028846330242231488, 0.027082549495389685, 0.01601908134034602, 0.07649192164535634, 0.05216580138949212, 0.03985737494076602, 0.11292148716165684, 0.03398742097488139, 0.049720903480192646, 0.03992849124188069, 0.08624030597275123, 0.059375699274824, 0.03868952393531799, 0.08182071265764534, 0.04468457802431658, 0.039229941030498594, 0.04887296636297833, 0.06297273692325689, 0.057738562318263575, 0.050996306526940316, 0.0656846261699684, 0.034893360643764026, 0.03687292082759086, 0.07562353464891203, 0.022266671585384756, 0.04376871955173556, 0.0640147048397921, 0.06368084970745258, 0.058665308097261004, 0.030362951692950446, 0.0826257721928414, 0.013276560875965515, 0.02615063280245522, 0.04794320004293695, 0.026130303522222675, 0.08297582840896212, 0.04535759835562203, 0.04798768066393677, 0.007147410442485125, 0.007022918416623725, 0.007612825165779213, 0.08122093116980977, 0.02451051983371144, 0.13010727474465966, 0.04583259142236784, 0.0711856473935768, 0.05776484547823202, 0.030463204711850267, 0.026335340371588245, 0.07164310722146183, 0.029075188176648226, 0.04572417848976329, 0.04787601712450851, 0.0632152114121709, 0.1017766777658835, 0.07658120201085694, 0.0619163119699806, 0.028911592853546608, 0.0819908945413772, 0.015895554570306558, 0.022028798412065953, 0.02313785647857003, 0.007609732265336788, 0.03143005058518611, 0.017424224788555875, 0.07143218885175884, 0.02209942675108323, 0.03601384407375008, 0.02764024378848262, 0.03902419543010183, 0.06024177448125556, 0.04045234360091854, 0.003614777529037383, 0.042882376292254776, 0.04672427072364371, 0.0624939551926218, 0.02013895831623813, 0.020809985981031787, 0.0807069567963481, 0.05237162120465655, 0.032396096794400364, 0.048882462142501026, 0.06194038724061102, 0.024809135938994586, 0.04298231018765364, 0.08030185548705049, 0.20308151288190857, 0.10673516677343287, 0.055169851912069134, 0.15220343047985807, 0.15622077975422144, 0.19540151639375836, 0.11504166206577793, 0.12059794360538945, 0.15855067817028612, 0.17114139162003994, 0.17250461300136521, 0.09737612053868361, 0.13121148658683524, 0.10520501411519945, 0.11217191800824367, 0.2197804590105079, 0.1423878298373893, 0.11678017268422991, 0.1224665304471273, 0.18317662237677723, 0.119326696585631, 0.21079276863019913, 0.13189582095947117, 0.09688951657153666, 0.11017632743460126, 0.20250449306331575, 0.1717123406706378, 0.1766088677686639, 0.12430375412805006, 0.09705522330477834, 0.10695134697016329, 0.14629921526648104, 0.1602504338370636, 0.1461757515789941, 0.09166610310785472, 0.07982479553902522, 0.18319689785130322, 0.16476978664286435, 0.15495575935347006, 0.14062148868106306, 0.14730546361533925, 0.0714125219383277, 0.10219165706075728, 0.15618689329130575, 0.1449841889552772, 0.11386785903596319, 0.21988437452819198, 0.1591219092370011, 0.1716886810027063, 0.21937379176961258, 0.13709032034967095, 0.1309497162583284, 0.1345083292108029, 0.08193587171263061, 0.11437551031121984, 0.1390133288805373, 0.12209955326397903, 0.15292117634089664, 0.1546602658345364, 0.14207090309355408, 0.14602794544771314, 0.19069536501774564, 0.08099796032183804, 0.1328656150144525, 0.15072921349201351, 0.1725238494691439, 0.15717464732006192, 0.12746065738610923, 0.09746024297783151, 0.1860511236009188, 0.13250015181256458, 0.18649803008884192, 0.13719987618969753, 0.1260712233488448, 0.23968092631548643, 0.13992814463563263, 0.16974150814348832, 0.11247266593272798, 0.09956385314580984, 0.12864655000157654, 0.1332171109970659, 0.10137603676412255, 0.1538219951908104, 0.1432240818394348, 0.20640142145566642, 0.17067119653802365, 0.17471352650318295, 0.1043425197713077, 0.12323444549110718, 0.12086804083082825, 0.10410074290120974, 0.12864246818935499, 0.17981781042180955, 0.128156405990012, 0.1744275473174639, 0.22276812291238457, 0.1594771901727654, 0.24018463678658009, 0.1768387999618426, 0.06460071948822588, 0.17332986637484282, 0.20414132945006713, 0.14056852902285755, 0.2282016383833252, 0.2622796793002635, 0.22505334403831512, 0.20477163547184318, 0.18364098417805508, 0.16383790149120614, 0.18200065969722345, 0.17988812149269506, 0.16550921805901453, 0.12763621984049678, 0.22895625414093956, 0.05631684856780339, 0.08173656795406714, 0.1940198303782381, 0.19635029282653704, 0.15783152222866192, 0.13918227137764916, 0.16062588634667918, 0.12891642458271235, 0.09317528267274611, 0.1274679007474333, 0.16827471263241023, 0.20944856107234955, 0.14252437016693875, 0.1360432241926901, 0.14067011419683695, 0.09513854529359378, 0.1520597210037522, 0.1763933480833657, 0.09423580428119749, 0.26845381362363696, 0.19872414122801274, 0.12439411802915856, 0.2483034206670709, 0.12936092651216313, 0.15696133923484012, 0.14961996988859028, 0.1301822910318151, 0.15996193134924397, 0.09287073495215736, 0.13222108944319189, 0.13377358816796914, 0.22769653267459944, 0.1921758902608417, 0.2765042753890157, 0.23526982316980138, 0.15411929955007508, 0.16045678057707846, 0.13974685280118138, 0.1851201438694261, 0.10564472177065909, 0.12962287495611235, 0.12717144243652, 0.14543626079102978, 0.0866057543316856, 0.11519093764945865, 0.12375026039080694, 0.11090082683949731, 0.17401865363353863, 0.18672157981200144, 0.12988553586183116, 0.11671315674902871, 0.12394993522320874, 0.1090632617706433, 0.11596159863984212, 0.24389254016568884, 0.30549802584573627, 0.16217229946050793, 0.13644698221469298, 0.17359665362164378, 0.08690249465871602, 0.09794200072064996], [0.011469721648609266, 0.015168269328569295, 0.05897919945709873, 0.026105252327397466, 0.020801583013962954, 0.04100827900401782, 0.07740857792668976, 0.009821221483434783, 0.0503802905586781, 0.03949727746658027, 0.09663540520705283, 0.0867398084665183, 0.01816766194679076, 0.016849474086484406, 0.06556903666933067, 0.0517083378508687, 0.04975370269676205, 0.013615719581139274, 0.028306877939030528, 0.027933766905334778, 0.015410886680911062, 0.05198455408390146, 0.0789380849164445, 0.027548736979952082, 0.04065818568051327, 0.024401654191024136, 0.062197166625992395, 0.04399420999106951, 0.04687375039793551, 0.03826246989774518, 0.04042895481688902, 0.018224796185677405, 0.0684325689508114, 0.051253787241876125, 0.056483813241356984, 0.049287726724287495, 0.048469905959791504, 0.07512198382755741, 0.08082279120571911, 0.009073774872376816, 0.034294785145903006, 0.024752331955824047, 0.016956128129095305, 0.003196412881152355, 0.039560604927828535, 0.04216858607833274, 0.020324445140431635, 0.051365524996072054, 0.01689876567979809, 0.05421917558123823, 0.03638290669186972, 0.031463083578273654, 0.07248502923175693, 0.09087812781217508, 0.13844148925272748, 0.11417751273256727, 0.009170516605081502, 0.06223163567483425, 0.02039498071098933, 0.022252069829846732, 0.045908976971986704, 0.03305318321508821, 0.10837453388376161, 0.03399940665985923, 0.018888552658609115, 0.026369913321104832, 0.050451481074560434, 0.018300639967492316, 0.086558613111265, 0.017215688712894917, 0.024976005988719407, 0.020485246277530678, 0.044609717588173226, 0.035708620998775586, 0.025552404258633032, 0.05058489696239121, 0.03937454479455482, 0.029313445411389694, 0.05098732654005289, 0.01933715680934256, 0.040186343030654825, 0.03430442564422265, 0.09985257827793248, 0.04648528803954832, 0.04097982506209519, 0.010662039549060864, 0.02320104107639054, 0.0657463283278048, 0.06627578390180133, 0.02700851284316741, 0.006998240614848328, 0.06733367830747738, 0.007710777526881429, 0.021158880736038554, 0.028175990919407923, 0.014314346790342825, 0.12499427801230922, 0.02769006972812349, 0.021384577121352777, 0.03571333363652229, 0.03325318088172935, 0.035919279616791755, 0.02041695755906403, 0.05249107358395122, 0.04942616324115079, 0.07795580793754198, 0.09305653162300587, 0.019714564878086094, 0.04154349364398513, 0.014343087386805564, 0.0034958458127221093, 0.008936285521485843, 0.058232788142049685, 0.021849339682376012, 0.020299837378843222, 0.03531117494276259, 0.09703385687316768, 0.07341908887610771, 0.06899858271935955, 0.01393961230860441, 0.02052292511507403, 0.038913808384677395, 0.03642207353550475, 0.07342351207626052, 0.05015162743802648, 0.0757795934623573, 0.0245194701346918, 0.017090646106225904, 0.03074970154557377, 0.08127557550324127, 0.04253060200426262, 0.08197378061595373, 0.03749266608792823, 0.047725145923323, 0.020653303763538133, 0.020587380640790798, 0.042800023875315674, 0.08318544059875421, 0.05005496641388163, 0.028019575875077862, 0.029427129447867628, 0.004661546909119352, 0.016254733636742458, 0.04451309738215059, 0.062210903779487126, 0.04449491847481113, 0.08664558539749123, 0.04336801546742208, 0.03378930836333893, 0.05256357770122122, 0.03719282729434781, 0.043525373039301485, 0.05279374367091805, 0.029357671846810263, 0.06484375800937414, 0.011181396348547423, 0.040067721856758, 0.11470673824078403, 0.019007257324119564, 0.03489034752419684, 0.052598332476918586, 0.04769871062308084, 0.008169476277544163, 0.02088514513161499, 0.07245883884024806, 0.035605373414000496, 0.031333534279838204, 0.010271252413076581, 0.01817102758650435, 0.048808796564117074, 0.05708940945623908, 0.027497087212395854, 0.05576947012741584, 0.046315978179336525, 0.09624984464608133, 0.012269704893697053, 0.07358584203757346, 0.012817256811104016, 0.043631889784592204, 0.06721096418914385, 0.01899295428302139, 0.04337665406637825, 0.039302938675973564, 0.05928044833126478, 0.07929142884677276, 0.04305246169678867, 0.09842899802606553, 0.02763838470855262, 0.03594941081246361, 0.028259193095436785, 0.03483694999886211, 0.043603788362815976, 0.0549108720588265, 0.023530688231403474, 0.007774400455673458, 0.05099229521874804, 0.04240011388901621, 0.01793837913282914, 0.0693732633953914, 0.027745734514610376, 0.10623251015204005, 0.029555255678133108, 0.0405387555656489, 0.029613916885864455, 0.044804542485508136, 0.08055907645029947, 0.04189194682112429, 0.04128399428736884, 0.037098997563589364, 0.1081906222680118, 0.08532269232091494, 0.03203776192094665, 0.009900534805638017, 0.09478138672420755, 0.022182703141879756, 0.014582658222934697, 0.04182102718914393, 0.016241582779912278, 0.039268903783522546, 0.029539075003413018, 0.008209568022721214, 0.04196768670226447, 0.015309181835618801, 0.012774265123880468, 0.08850943733705208, 0.05758068524301052, 0.026905463782895822, 0.06809236845583655, 0.025686087319627404, 0.02995704886416206, 0.038222887451411225, 0.07925458863610402, 0.08959966711699963, 0.04128353044507094, 0.026840273530979175, 0.04854970538872294, 0.029978888414916582, 0.08661255982588045, 0.11315526367980056, 0.010500027783564292, 0.04424735285283532, 0.031111869611777365, 0.020403717644512653, 0.04275497551134322, 0.029566669909399934, 0.03468815681117121, 0.040820411741151474, 0.015153813219512813, 0.030225687769416254, 0.0802270470012445, 0.017405749022145756, 0.025180905540764797, 0.07609513239003718, 0.038733811597921886, 0.03618439703132026, 0.025373808275617193, 0.03698223546962254, 0.02650881368026603, 0.08765601203776896, 0.0450871968496358, 0.046316664665937424, 0.03486181565676816, 0.028631146378756966, 0.042677669698605314, 0.08123195206280798, 0.03676596621517092, 0.021382857194112148, 0.034761811257340014, 0.028707377932732925, 0.025372756281285547, 0.017478468362241983, 0.01729135252389824, 0.0346433199592866, 0.05215734832745511, 0.030546588714059908, 0.033182049737661146, 0.06364215412759222, 0.03478735226963181, 0.05459699925268069, 0.00963274009336601, 0.04170168984273914, 0.09141927963355556, 0.023909482260933146, 0.05320187294273637, 0.034610813891049474, 0.0049991081414191285, 0.03630246901593637, 0.017188038145832252, 0.05049204315582756, 0.02118517688359134, 0.023544551550003234, 0.01596882866579108, 0.01786502525646938, 0.062066585742286406, 0.04108389272005297, 0.02281769397086464, 0.0465686423558509, 0.01020184490698739, 0.022860612371005118, 0.006958834892429877, 0.034037853620247915, 0.0671905477065593, 0.03749470699403901, 0.033402074259356596, 0.010936406906694174, 0.05759288244007621, 0.027982188330497593, 0.06816207838710397, 0.036352478637127206, 0.04447148887265939, 0.03960992435168009, 0.03648806901765056, 0.06103874089603778, 0.008458349839202128, 0.01531304193122196, 0.026832262046809774, 0.058695123880170286, 0.009088349725061562, 0.027212455024709925, 0.060437645806814544, 0.07189511830802076, 0.0427407708048122, 0.04998561642423738, 0.03446556816925295, 0.033834353016573004, 0.061729186854790896, 0.04300959895772394, 0.0440640831948258, 0.018947926328110043, 0.05230972608842421, 0.024270850663015153, 0.05022413155529648, 0.027347262439434417, 0.03987157964729704, 0.024351731772185303, 0.04176316564553417, 0.03516994052915834, 0.025309130105597433, 0.038863487061462365, 0.022985500982031226, 0.030154547348502092, 0.07476838756701909, 0.05472138320328668, 0.03474839322734624, 0.04867431569437031, 0.08162275960785337, 0.03705300667206757, 0.006323602865450084, 0.03275494003901258, 0.029057402607577387, 0.09182334935758263, 0.0427823125210125, 0.1201025748741813, 0.08476242277538404, 0.16547690494917333, 0.13090999651467428, 0.07080802039126866, 0.10998474201187491, 0.2820583898574114, 0.10416899822303094, 0.14905195974279195, 0.14824146026512608, 0.16039196139900014, 0.14136078651063144, 0.057973619041149504, 0.16187958157388493, 0.11906190571608022, 0.1920686796074733, 0.1523923664353788, 0.1599218850606121, 0.22131890145828947, 0.11147190947667696, 0.101831544743618, 0.18065001029754058, 0.15812072233529761, 0.19869454437866807, 0.224246570141986, 0.11324087783577852, 0.13417488225968555, 0.1282636760151945, 0.12458989658625796, 0.1756696353550069, 0.13142501731636003, 0.1243381600943394, 0.2779097843449563, 0.12835141271352768, 0.13456765649607405, 0.15122440410777926, 0.0832766282837838, 0.24916560330893844, 0.149305714876391, 0.1328129373723641, 0.28482588822953403, 0.07711313635809347, 0.14548310515237972, 0.13432320789434016, 0.11474170081783086, 0.12241776392329484, 0.08976395634817891, 0.07090199113008566, 0.14200698933564126, 0.10130685375770554, 0.11779114851378836, 0.17491255566710606, 0.14309911901364103, 0.1190181561105419, 0.18962674657814205, 0.17961291829124093, 0.10253727523377165, 0.22955794294830412, 0.0822090933797881, 0.0976674877165351, 0.1639848912600428, 0.10535453460761346, 0.21090612426633015, 0.15764426352689043, 0.11552336785825901, 0.11395073466701433, 0.16976789891486987, 0.08440879682893865, 0.1469713487313129, 0.06009398690366652, 0.10779798903968185, 0.0974683027015999, 0.10714608652051538, 0.19675703428220004, 0.05140451372426469, 0.12698492588242516, 0.22519086400279775, 0.07723468530457467, 0.15755225205793977, 0.07650597050087526, 0.09302657112129964, 0.09153469101875089, 0.28711870894767344, 0.15794325998285785, 0.15748977806651965, 0.09407595309312455, 0.10462249498232268, 0.15355133393313736, 0.2440964081324637, 0.23876968771219254, 0.10714024581830017, 0.15439923765370622, 0.0593738847237546, 0.10311857724445872, 0.1476796841598116, 0.1754291943507269, 0.22780034429160878, 0.16655000596074387, 0.16333606123225763, 0.18774794036289677, 0.1716785877943039, 0.12431013659806922, 0.15105887548997998, 0.14009088277816772, 0.14977956132497638, 0.19999769632704556, 0.22745781345292926, 0.18980287306476384, 0.10175685500144027, 0.0879013363737613, 0.15016838733572513, 0.09683764787041582, 0.19124863611068577, 0.12800491880625486, 0.1558504777494818, 0.21503647294593975, 0.20353710249764845, 0.12509877240518108, 0.13726923731155694, 0.12316079475567676, 0.08887095231330022, 0.18043181888060644, 0.1363308509462513, 0.13543473731260747, 0.233793884399347, 0.16358088090782985, 0.20465268404223025, 0.07153279439080507, 0.07133727558539249, 0.15212973521556705, 0.16840491502080113, 0.2452300683944486, 0.07948026090161875, 0.10240808216622099, 0.17354669224005193, 0.14053436054382473, 0.12321428876020946, 0.1844570942921564, 0.10586408578092232, 0.14116916398052126, 0.11939542688196525, 0.12794244481483474, 0.16361188783776015, 0.1338131446391344, 0.1885759990545921, 0.17071801121346653, 0.1409255911130458, 0.06034764926880598, 0.1260248094331473, 0.15045939828269184, 0.07562660714029334, 0.1578979444457218, 0.14764993888093159, 0.12765079562086612, 0.1253471098607406, 0.22765854955650866, 0.13317696080775931, 0.2191177211352624, 0.12093749101040885, 0.1423917038482614, 0.10062358807772398, 0.19296704937005416, 0.1515141237177886, 0.10723023122409359, 0.164940896211192, 0.2600997540866956, 0.16400308872107416, 0.07982969371369109, 0.15203612070763484, 0.21491137653356418, 0.1712359263910912, 0.2317058519111015, 0.13083780038869008, 0.16535618720808998, 0.26085597288329154, 0.15483146446058527], [0.07235471552121453, 0.04109396366402507, 0.039922171854414046, 0.04635854777006898, 0.06326163274934515, 0.06533798383316025, 0.04875743623415474, 0.03068373946007341, 0.053009222538094036, 0.0268567343664472, 0.021401731864898466, 0.07200476320576854, 0.05986876363749616, 0.03548648877767846, 0.012892121885670349, 0.02068535341095412, 0.05193079290620517, 0.026855131327465642, 0.00813912985904608, 0.014018196470715338, 0.052578042159439065, 0.07691767692449503, 0.07014847375103272, 0.06914418467204086, 0.08323765810928307, 0.020905184974253643, 0.02368754670897033, 0.06315650010947138, 0.06734537455486134, 0.0362368854257511, 0.02132635378075065, 0.045421638278639875, 0.0427550460153725, 0.07019474665867165, 0.03167627663060557, 0.05075338303868193, 0.041692134691402316, 0.05208160844631493, 0.011252372569288127, 0.023172563014668413, 0.07134988467441872, 0.03601218537369277, 0.029342558009375352, 0.0029159323139538174, 0.012619416938832728, 0.020394242274051066, 0.03211022150935605, 0.01688224361714674, 0.007229652928799624, 0.058509560985839926, 0.05716857805964537, 0.028402112184267025, 0.026958484668284655, 0.025811974119278602, 0.05127647098561283, 0.024186060290958267, 0.0314885466650594, 0.09745495888637379, 0.03818644800048787, 0.010269959220750025, 0.050428567265043966, 0.04180447358521633, 0.013036583713983418, 0.04329177092586178, 0.03941146293072961, 0.07605205071740784, 0.03631590931036044, 0.0344995956402272, 0.04968587039911654, 0.0203285918905749, 0.014346427051350474, 0.040935388969955966, 0.01257972502571647, 0.09140934227616526, 0.042093911179108545, 0.031058097301865928, 0.03594003748730756, 0.041086857600021176, 0.02031883821473457, 0.018106609168171417, 0.07031237706542015, 0.015379290671262424, 0.036996117341914214, 0.03853661924949847, 0.04284843787900172, 0.032467409764649346, 0.022448538584285416, 0.042266048621968366, 0.03480807674350217, 0.012989410024601966, 0.028147594493930228, 0.045436451546265744, 0.05668618206982501, 0.07271254202350974, 0.0717548598186113, 0.0747223966754973, 0.020654793624999, 0.04764114964928012, 0.028607163876586128, 0.033656857267487794, 0.08491791013511829, 0.02421831217361614, 0.021055219403933734, 0.023455916852981318, 0.03702866793901194, 0.04999199889425654, 0.06521277609863319, 0.02541298439609818, 0.01914545635372633, 0.02582756849733414, 0.05089664351544343, 0.02927562742115697, 0.02763527510978747, 0.03009829255461227, 0.033757065757527016, 0.022148332427605055, 0.05940566348726861, 0.051958593758172356, 0.049009117064997554, 0.038362719205906615, 0.0273026927607134, 0.053884615408605896, 0.05139498083735816, 0.04548824603261892, 0.026955881585308816, 0.022590411244891584, 0.032006851470214315, 0.04275902763765771, 0.0749600472045131, 0.026179474516538903, 0.039798552315915, 0.010048731492133811, 0.028864060150226578, 0.04344183318607975, 0.030373885383596644, 0.10812961772899143, 0.033363894472131506, 0.028853764706582297, 0.04716925133834593, 0.039789902584743686, 0.049820280764834024, 0.09393282249220647, 0.030171813414199278, 0.03070406131882919, 0.04752528555400204, 0.032730133752920665, 0.09449603836401366, 0.04215037377434783, 0.0485889761330327, 0.03739631676580757, 0.022096474858699366, 0.025505302000965457, 0.04587326111504808, 0.021023212430009153, 0.05253525734588038, 0.055349815302179195, 0.018169174072681926, 0.029969147726660594, 0.07232407966512255, 0.01456792195313028, 0.03861278957629111, 0.0635972319287248, 0.04348416157881729, 0.07467428324162029, 0.073117146093864, 0.019677453783515375, 0.07754898484563455, 0.044914925820194185, 0.04058018224895932, 0.031371406075777486, 0.043933658162131906, 0.07514583645388484, 0.02401233279670123, 0.02662701554072555, 0.04072205862030387, 0.049936434297706, 0.06388493289705366, 0.03759109713428188, 0.038423241348937154, 0.02413467584119644, 0.08143933038809337, 0.03167248054523952, 0.08100268038106151, 0.05865064696990885, 0.06482859593234025, 0.0537040397466626, 0.03848886946798302, 0.023858574641053565, 0.012702209078270243, 0.031465105930692516, 0.026325330654799473, 0.019150233929394744, 0.023167345716501586, 0.013139730181137566, 0.011561069823073922, 0.04141103141591884, 0.044287146811257116, 0.013065418006590335, 0.04977679462172091, 0.047054237002157606, 0.025367334892507643, 0.060427263160818256, 0.024076014633465093, 0.01985758230148349, 0.005356935571398935, 0.01384623343255953, 0.018277479393873364, 0.03708358315634541, 0.03722727778949775, 0.0638053375587333, 0.004602189010256552, 0.047139146117842756, 0.036748863421962596, 0.0696436723228544, 0.00912673360289773, 0.016377106367144734, 0.02962562612083275, 0.05298579664668068, 0.015094866284925956, 0.017341931743430905, 0.07860325757064857, 0.033915313906618394, 0.007484769439543015, 0.022166383314470295, 0.02615275534481043, 0.05980890571663622, 0.04028093346278183, 0.02536595449782908, 0.055728585211909376, 0.01864542136900127, 0.03512930423312355, 0.05986253701848909, 0.044744855258613825, 0.040920367900980636, 0.06552554681547917, 0.016022036943468265, 0.12224099176819436, 0.02923617485066643, 0.017892985670187045, 0.03186224770615809, 0.015798808199178893, 0.06254019841435365, 0.05504230270162225, 0.023802375508239493, 0.02228160730737727, 0.0509633996989578, 0.02214245090726763, 0.029666655755136162, 0.01809323195629986, 0.06875336228404194, 0.01931279395648744, 0.012525903548521455, 0.019214405583625194, 0.03444803493039217, 0.02612514559586998, 0.019234272876929026, 0.02028509090450825, 0.020865264850726817, 0.0241501551863621, 0.05279806297039613, 0.040058148151729256, 0.018938102148240432, 0.013235486712801503, 0.04800503949809354, 0.032529401360079646, 0.027549132173589896, 0.02313888991920976, 0.04181623662589118, 0.04896715603535995, 0.03675285988720134, 0.0235684616927756, 0.05490291252499446, 0.04630812996765599, 0.0509616742056096, 0.004333948545536259, 0.07413245606585406, 0.01615272729395656, 0.03984350048995111, 0.030578577134292573, 0.05507275302079506, 0.01738387050863821, 0.02359032536332961, 0.06343430082779378, 0.044404083309927955, 0.056821419930201955, 0.035238937998656183, 0.03483663829683792, 0.01592616259586066, 0.05683514224074315, 0.014478413377219113, 0.008839058609737549, 0.04982710481272079, 0.005950777094767545, 0.01644971995119704, 0.02424407583021093, 0.07936209614854306, 0.030947216728236526, 0.04725738879642449, 0.05508379988896195, 0.1084033292136155, 0.033517819611006416, 0.014215388819138752, 0.11013229581294581, 0.04697602576925419, 0.021645831657224335, 0.024643735341669526, 0.014096420691203093, 0.010091150797961745, 0.0657603623403702, 0.06183680940011982, 0.024652561332914047, 0.06334641569992527, 0.04911526644718833, 0.009577016862749588, 0.030048043590795714, 0.04212818355881609, 0.013959513926238287, 0.03589357904274948, 0.07001617108471692, 0.05424520270025823, 0.011402273412386421, 0.01769224771123845, 0.05029825355450157, 0.05793607379018795, 0.0898412436072249, 0.037790126298204996, 0.042802183525054716, 0.03825092950137332, 0.04731379944132641, 0.08281250396976247, 0.09226167661836371, 0.03912525367923081, 0.019121880177408457, 0.019978324162366334, 0.04111519279831555, 0.05830252033774741, 0.060997295659035444, 0.011069260617659893, 0.03178296406986192, 0.04415033559780568, 0.02228315654065227, 0.005710465966330958, 0.03590205807995517, 0.012105680052627577, 0.017596887300896924, 0.03692461512400769, 0.0496972994733369, 0.027065691610914655, 0.030610880967287812, 0.006360496881825384, 0.16330478712916374, 0.03371736085682642, 0.15679892763728276, 0.16188752255402505, 0.1787962144589983, 0.30535939265973866, 0.2083447203040123, 0.16778387100202963, 0.2070007799193263, 0.11193506899871863, 0.19690856599481776, 0.15645555075025186, 0.09347735162009485, 0.17727320868289098, 0.13935091701569036, 0.1152547771926038, 0.13629813707666472, 0.1128807952045463, 0.13235118793090805, 0.1135303673800081, 0.13470492413034663, 0.09961572926840745, 0.1580694696167484, 0.16876718698767945, 0.1964357733959332, 0.2695329854032025, 0.17211500031407923, 0.16032919054850936, 0.1110738585703075, 0.1606892657582648, 0.13598554447526112, 0.12116915982915089, 0.14739673293661326, 0.14287681609857827, 0.09979329552152194, 0.11231731215957552, 0.165382117847912, 0.10018811808549799, 0.1515705417841673, 0.15645577339455485, 0.15199435263639316, 0.15057928481837735, 0.07451971614500508, 0.1916837424505502, 0.08762473793467507, 0.0808270659763366, 0.26029951055534184, 0.12438485602615401, 0.2416576218092814, 0.12923735892400146, 0.10946412541670725, 0.17429749335860834, 0.18292929424205795, 0.12102737251552753, 0.104124632634921, 0.1183153348392807, 0.11490872857393697, 0.09774497535545379, 0.14997916936408728, 0.21486922254553065, 0.11958905321080238, 0.10222680517472327, 0.2067803026875481, 0.12177064825664274, 0.17673109949100763, 0.12550529121654108, 0.14145579625619575, 0.19374672003323212, 0.11589908754103817, 0.14620091038523242, 0.1213583629578352, 0.15805848583113402, 0.0890165616874583, 0.1505188739974983, 0.08929488190915436, 0.2406534960027784, 0.11613788839895278, 0.14668145100586116, 0.11003117077052593, 0.11933037763810717, 0.16541446064366028, 0.09394837048603222, 0.25688120804261416, 0.12098532242816873, 0.148687832406722, 0.12304527204832993, 0.11855903387186117, 0.0904870085651055, 0.12981029693037271, 0.15199974062852561, 0.12600842281244695, 0.19035497156437486, 0.19640639919089153, 0.13060206460068002, 0.1646240139962174, 0.1947538144304417, 0.16408411640441045, 0.3157454525353387, 0.09153351100394502, 0.1641192496754229, 0.14965813112212345, 0.2535153605276719, 0.15388599800644442, 0.15261290303897113, 0.17787446704460308, 0.11101131778559648, 0.13265313813462853, 0.1348615766619332, 0.18907006160588935, 0.0929935158637818, 0.061874699749751016, 0.08378263199119829, 0.14995075995102525, 0.15893214207608253, 0.12198020107462071, 0.11562419604160823, 0.07665478595299646, 0.14782328973524272, 0.11798668216215447, 0.17608050315175205, 0.13044284423813224, 0.15886404260527343, 0.15878075879300013, 0.14558687224052846, 0.14635294675827026, 0.15482249931665137, 0.14249895903049037, 0.09240937884896994, 0.20496263459790498, 0.13040906167589128, 0.19951576046878472, 0.05057346417743247, 0.17706150363665074, 0.12367609015200287, 0.11284033331321552, 0.204121885180939, 0.1751801444333978, 0.25829960068222135, 0.09049161730217747, 0.08577247834182344, 0.131148730579298, 0.11986042693024501, 0.13914219540311024, 0.11844652428408153, 0.17569187009939924, 0.08994304400403053, 0.1099209395761136, 0.07195449754362926, 0.12070194818079472, 0.20507385284872726, 0.21371647424530238, 0.08090925883152522, 0.17448916041757911, 0.10362875182181597, 0.1698838669108227, 0.23470815096516162, 0.14402813947526738, 0.08632698882138357, 0.07035126560367644, 0.12217865136335604, 0.13332629576325417, 0.13881815888453275, 0.15090387052623555, 0.13178233173675835, 0.09568562687491067, 0.19437386450590566, 0.2417907927883789, 0.18277510564075783, 0.2725017542252317, 0.13560151273850352, 0.05887648250791244, 0.11904009399586357, 0.16715703823138028, 0.3154127032030374, 0.17100014607422054, 0.1625451396103017, 0.29455591924488544, 0.1444127649301663], [0.01417080244209501, 0.016320782924594823, 0.02702352463529678, 0.04770358653331641, 0.020016594862681814, 0.02915516572102206, 0.020374135638121516, 0.0445009447139455, 0.06898785126395524, 0.006922073534951778, 0.017625723448873032, 0.01810673904401483, 0.011473592876427574, 0.04491383115237113, 0.03977921936893836, 0.003938113877666183, 0.03926709665392991, 0.05661769668222405, 0.07545442145783454, 0.05459671723656356, 0.05605344922514632, 0.05823926338052843, 0.04682952581788413, 0.0029986616027599666, 0.08811354608042166, 0.04203191587293986, 0.057946879460359924, 0.08585169518482871, 0.050897853216156363, 0.045638115334440954, 0.013108616567478748, 0.028639020565606188, 0.08129293433739804, 0.03833089962427039, 0.01792675153410528, 0.011939363830606453, 0.0671719569072593, 0.022947252546146046, 0.013711155133933062, 0.0665719601965975, 0.017869806542876177, 0.020400348294060677, 0.03651904255093541, 0.04383698229503352, 0.02450493888318306, 0.02264957525767386, 0.027082640408480074, 0.053362169419415295, 0.06707104708766565, 0.03527276137901936, 0.04571827841573395, 0.046648738643852994, 0.04182880118605681, 0.01771174393070396, 0.04624311412044335, 0.041664155723992735, 0.02622961957968073, 0.08813167674816214, 0.050411557240295224, 0.022206845205801073, 0.040613504679640755, 0.029365798363869544, 0.0169128609195468, 0.078107584558893, 0.030937045594328083, 0.03410885117773432, 0.034953708382090554, 0.05043318342359271, 0.03592829671106301, 0.0516675939434208, 0.03820432633801829, 0.05152982907020487, 0.0701083309832029, 0.0336713959404733, 0.02982467569381697, 0.05036150680098217, 0.08136397271300666, 0.03439605490711983, 0.07520756829762831, 0.04822802889975719, 0.0713528532651253, 0.04511308296059724, 0.019035457080462947, 0.018334402120672166, 0.0117160645822878, 0.07444803210091777, 0.04920383435091935, 0.028809091127186548, 0.02781284878437873, 0.024632961212773807, 0.04112544556846842, 0.015536642677034251, 0.03498010657494888, 0.006336824226309545, 0.035460157378111035, 0.02866257262212457, 0.06243206749786623, 0.032249047653749585, 0.0694848081911914, 0.025875969513435848, 0.03205076063750312, 0.07949755294248462, 0.007857707460061647, 0.02532994363718899, 0.03846066043479368, 0.02667896402272163, 0.00796218515461078, 0.0485333373217145, 0.04069282913405914, 0.05500300227140542, 0.042754615569720045, 0.0041779022558330325, 0.015197414395515807, 0.06536346176289953, 0.05408923294453416, 0.07670637263800018, 0.020930850296281278, 0.03284969374362845, 0.021477907757798675, 0.07195164769655094, 0.05292476613249164, 0.004469314426387427, 0.019521244685165584, 0.021647390167345293, 0.06319921812973917, 0.07095175213180482, 0.04876269435044378, 0.014227104547899216, 0.015205435156531166, 0.03467876864306163, 0.03212548377632629, 0.03445151560299564, 0.037330944687710144, 0.03242207567382138, 0.017783149669412524, 0.011870733724208549, 0.10395134857390076, 0.038804534560767934, 0.015436924932146212, 0.02970902311062673, 0.04887686263828073, 0.041494062897982076, 0.03508242647512816, 0.02702106627111789, 0.06080720937461592, 0.011116683854197618, 0.0262819020281313, 0.026937930888379924, 0.02623257889354136, 0.041193155411747284, 0.036856411752523854, 0.03442912500759121, 0.016361332018277608, 0.03815129988652188, 0.041074819964705966, 0.046541694973711856, 0.06213152737473138, 0.04767317332152743, 0.07339249772485346, 0.06242303556064144, 0.02092045466270065, 0.043441725574666634, 0.04511108287260868, 0.037354596934164874, 0.017080131729017012, 0.041394462969037704, 0.0929476362944115, 0.07962204079376534, 0.049810239506768994, 0.016004303324734792, 0.04135889183089603, 0.039724912712699734, 0.025063575703825336, 0.013477412940119393, 0.08246556477388367, 0.02659433135704603, 0.036523536255117506, 0.04487048601731658, 0.014486672553175595, 0.03935690023354255, 0.06095628828916233, 0.08248377707786858, 0.042999965880881064, 0.035659386921906844, 0.031251975960913114, 0.05274115508655086, 0.021562748224823736, 0.017033856966008898, 0.1128599482763093, 0.058519509475445375, 0.031990487113944255, 0.023523710187873803, 0.017677736868790817, 0.01582103181135608, 0.02425345101073617, 0.027206465892959386, 0.06265086005441844, 0.03526969259837642, 0.09313709175330587, 0.0336757783225039, 0.04280248409486376, 0.030210675977286883, 0.034102283170796, 0.05497661521076225, 0.03923125463188626, 0.03335426139528863, 0.014785739513172302, 0.02807541506626876, 0.0851209914253559, 0.07435962746967562, 0.025985410320572555, 0.017060889695130754, 0.03588003484765068, 0.018702464694797527, 0.062227141970652156, 0.03292739660537336, 0.032111338441609405, 0.07976026579854079, 0.021807820230606012, 0.001634342886518425, 0.001041466966853477, 0.04247272932843771, 0.040495028224540874, 0.008206412039726274, 0.024912298176786862, 0.1022749779804144, 0.025324238376924768, 0.05085990720544942, 0.008967245139501756, 0.03764651330129709, 0.002553073122726346, 0.026974344364134595, 0.00950469828239875, 0.01703462694422342, 0.05383803822041955, 0.10296930908225477, 0.16390263161156327, 0.03297404429758899, 0.1113525424443651, 0.018665433381102048, 0.09500633168499917, 0.05206401583564002, 0.03049471073609311, 0.020750462026626337, 0.042061468193423934, 0.05861837096745148, 0.0107208361987432, 0.03211756506061647, 0.09318573211203329, 0.047024766317917965, 0.027381057989259716, 0.025301797686552163, 0.09403698291862383, 0.09454061175347306, 0.029777643940178677, 0.042551508304313757, 0.04154820257099345, 0.0411367150809383, 0.034090687113348395, 0.01883920354885049, 0.036873351273243316, 0.05511360453965608, 0.01511189579105121, 0.03412312638829462, 0.020546824125631247, 0.07343784294789657, 0.014069096669118153, 0.06707885448122397, 0.0153059729746019, 0.08811776890070178, 0.03547928252373822, 0.015255221205734415, 0.07731117846560664, 0.07547520159278065, 0.05477362297824584, 0.047506850605714135, 0.05389430414652452, 0.042434649731148966, 0.04660868122300599, 0.057605283727752976, 0.04353004114818759, 0.06877815001644194, 0.01088003986296826, 0.0524936673900811, 0.02623665513965534, 0.041440205241087824, 0.009710696213005576, 0.015352411937783472, 0.021581570945272688, 0.045388015278149396, 0.018755387245619204, 0.061833855652366765, 0.07245329499710351, 0.05432433790701907, 0.00225293677431182, 0.018745423913060222, 0.09880297366180457, 0.04346683243056759, 0.013655308521265397, 0.07490659030736424, 0.04978034950909205, 0.11058769989176653, 0.025678630590846296, 0.025240459181077313, 0.0355989315721672, 0.09281137055950239, 0.05479666666360572, 0.03651756567705888, 0.03295983588031959, 0.021031979049439542, 0.007362835040112259, 0.01777639612555504, 0.07968067046022043, 0.044647737813647836, 0.04209584447380621, 0.05783621782029513, 0.011660556574497605, 0.025287572570960037, 0.03346869685628917, 0.01540137049232726, 0.0947090495901648, 0.019622453219199087, 0.014281294315878768, 0.04557318854494952, 0.007229899692902109, 0.03768196940654889, 0.0195913331117481, 0.0272149170996272, 0.02248401509859832, 0.03662958915811032, 0.009883888433250831, 0.050799451855709776, 0.04212586434732657, 0.04439032018126454, 0.14627714379457757, 0.09607351035811007, 0.06581338137038983, 0.06241757335374132, 0.03288118306954857, 0.05675667867762968, 0.035443392262095585, 0.030097919625404757, 0.0345820816437481, 0.03662331058876589, 0.04747908686113078, 0.03929828912077937, 0.00925429765629815, 0.025291897436545696, 0.05731495555664878, 0.039642612246098, 0.052784882427658886, 0.04745500045828521, 0.14756428019609302, 0.1384878734825179, 0.16974833590211347, 0.18344912416068837, 0.12651856028242037, 0.1304328252444975, 0.10464336417498998, 0.16414247889770195, 0.11813604680355638, 0.11570367263630033, 0.14587043202482164, 0.14200428791809827, 0.27496440801769495, 0.16918333887588233, 0.09365278790937737, 0.10148899906198494, 0.10150570480618626, 0.12632200989173725, 0.0975029164692387, 0.21703721402445808, 0.237574681523256, 0.2397890275460668, 0.12217523748404346, 0.1611975923879072, 0.15713157306890935, 0.1397470902884379, 0.11339222401147708, 0.16712101438315585, 0.07604687052662484, 0.12843040691222996, 0.06224293858394958, 0.2324434873298742, 0.18847300380002707, 0.14125608431641012, 0.09333505222457461, 0.06896782069816254, 0.14454324933467433, 0.13796482264297083, 0.1378918398404494, 0.22335338057018816, 0.1099840815004427, 0.20105699339183047, 0.19985091435955837, 0.16022088151657954, 0.08269410915090702, 0.10898352542426437, 0.1489232268068008, 0.1412966352654621, 0.13870971626602113, 0.22240843361942098, 0.10632454388542101, 0.18488192930817604, 0.1334984294953756, 0.09795893653063104, 0.12118476719479077, 0.11422529219998978, 0.11034820141503587, 0.13004674518015236, 0.14373629732290283, 0.19358619349077344, 0.25879728491418064, 0.1180001744069159, 0.17947581392945722, 0.11737256980268285, 0.14990234223660082, 0.06958472353289835, 0.1796854706481099, 0.18102362228091806, 0.12593906169058755, 0.11626071383943781, 0.11118492839159444, 0.11111165615147911, 0.23940385290188715, 0.10674597244360484, 0.11831940180854872, 0.15407925326144323, 0.2520238811848685, 0.21747566002886742, 0.15951831999700516, 0.11858193654916249, 0.1434872325626202, 0.17021200008457527, 0.09358201670693234, 0.09624536949559115, 0.19983111385954544, 0.23532730992883444, 0.138830671494361, 0.1030808909854386, 0.08895676684915088, 0.19455661094980314, 0.18268046696903184, 0.15589003422064707, 0.15747030411148444, 0.17735652218107134, 0.1781536778435111, 0.12150011316407472, 0.14589239959605038, 0.2566506079165265, 0.16929881705436856, 0.18608245707582682, 0.1346950387232937, 0.1637449994450435, 0.08272780265542679, 0.15636797732440755, 0.1239997852826491, 0.18465857254341245, 0.12492665351601318, 0.1644999417476356, 0.16343142720870674, 0.15508144948398694, 0.12064642069162801, 0.14186721324222162, 0.10274463129462674, 0.16029840626288205, 0.12862948060501367, 0.21812214486999437, 0.22123848233604804, 0.13082788529573008, 0.065419219317846, 0.1254163819248788, 0.21638713718857616, 0.09112608677241951, 0.21635598182911053, 0.18929573387140408, 0.2180452732136473, 0.17377024196321145, 0.11064794744015671, 0.22648258687695488, 0.100342596124392, 0.15710259962361306, 0.13302906561875716, 0.1747850695392117, 0.12226123755681328, 0.1493986466084607, 0.08495113608660176, 0.05738643179938663, 0.249774283147417, 0.13485718314768746, 0.090476759505691, 0.12036451589665376, 0.13636619201861322, 0.13607620523544028, 0.13371108449064195, 0.13681991142220795, 0.225172043137718, 0.17164177726954222, 0.05286657062242739, 0.13612021459266543, 0.07994511252036318, 0.10098297309014015, 0.12392511038342491, 0.15276109508704394, 0.2228057201136835, 0.14232945250114426, 0.14205818268237635, 0.10940142878098413, 0.24815597076667473, 0.11534601682797074, 0.32911838963627815, 0.22676393506117165, 0.13496319152181968, 0.13502018846338615, 0.1683934562606737, 0.18417105573462322, 0.10675584300770424, 0.14119763276539743, 0.2808068023296073, 0.1972793132881634, 0.09328046726295725, 0.1541239899233915, 0.09247819078154862, 0.15060588339110836, 0.27484239893965423, 0.22680202207993716, 0.15608971647452563, 0.16942578367888927], [0.022078513029555324, 0.055683121245238, 0.09209896816173568, 0.008471165801893221, 0.011896201449417276, 0.08896512343198992, 0.03362161267432384, 0.02869449795980472, 0.0863912736531347, 0.010709743874031119, 0.03842854028334841, 0.004437859424797352, 0.07803244210663252, 0.05006568302633241, 0.03930562153982464, 0.03290476481197402, 0.06155254457553383, 0.056465649176971056, 0.0170180325221736, 0.031146735709626228, 0.026469346266821958, 0.06208052327565383, 0.028008781337121036, 0.041282803140347824, 0.05617851595161483, 0.04074620810570195, 0.018986501308972947, 0.0961170150549151, 0.031713050047983415, 0.0962149043334648, 0.003868217945637298, 0.015828247342142276, 0.018486098961147945, 0.01588425166119123, 0.028484141766966786, 0.0453933476092061, 0.03137161387712695, 0.025492937820672523, 0.031213454785756767, 0.0347845209762454, 0.017114034890255425, 0.10915839768131264, 0.013386109294515336, 0.07347977429162711, 0.05052677937783301, 0.015929990222502965, 0.09764603222720325, 0.03994892627815716, 0.025234783606720157, 0.03447685252467636, 0.052698722793138586, 0.048662931149010547, 0.025938885082723573, 0.09401232135132886, 0.04343413711467292, 0.09369969164254144, 0.041859255215968005, 0.06840111673227511, 0.009553613235766534, 0.020768208632944152, 0.03602089447667822, 0.021483023010659963, 0.03341633091622498, 0.09431369267986156, 0.0151342956633016, 0.04948061461618636, 0.05071869876701385, 0.04267909091140609, 0.013374541067605605, 0.07953126871143468, 0.017686431128822733, 0.041199719707947224, 0.040359786653425545, 0.047959375151549466, 0.1373238890664652, 0.06798917282139882, 0.057053838318097405, 0.005548998287849827, 0.036950790672563016, 0.07842788065318018, 0.030807540824753232, 0.021953014002065174, 0.05193669298023451, 0.05774598379503004, 0.04096598771866411, 0.07205866539152339, 0.045841834871680476, 0.02287854080350371, 0.07774249985232018, 0.02476492249115836, 0.017011490490403958, 0.020319123941590078, 0.013802491248497972, 0.0562656106922077, 0.07054532237816602, 0.026160533052461687, 0.08425618900218979, 0.05862312813405879, 0.06737511983374134, 0.082823895936599, 0.048083948349813, 0.04869754491664935, 0.0278911138229887, 0.020611277795978822, 0.04779065158800222, 0.025756832546903752, 0.0181524256549892, 0.07786528076394461, 0.015412360771733802, 0.02146578292013146, 0.07674914260860533, 0.05996169536956586, 0.08481123382807709, 0.04919650193187408, 0.031423575346707366, 0.04222844399919268, 0.04675254283938557, 0.04651463626942132, 0.045331634319154546, 0.013609529141831445, 0.013494773629645351, 0.06468128704000264, 0.03939374044421129, 0.03327803911815863, 0.04632937765563838, 0.0681117014028132, 0.015978827250364702, 0.08696992619661614, 0.03615822148276493, 0.022413373771996703, 0.1342952437698841, 0.04359752834716346, 0.0025780853547985316, 0.01283867519305204, 0.013517026000045007, 0.05406346928793937, 0.04155685230216477, 0.008208004874177277, 0.025913768949976657, 0.07711064274189994, 0.043597439289442264, 0.08027122705243528, 0.03876095935993362, 0.031362418667413294, 0.009433808336325455, 0.05513245880138129, 0.007309582233574474, 0.014276815454650205, 0.00883768192579737, 0.011717002471414162, 0.028187137977511156, 0.02902166077547008, 0.040424360922770575, 0.0212941408608458, 0.07750277873128653, 0.03512572708132211, 0.03694489802001044, 0.10052061508758925, 0.008363382767129224, 0.012158944919065107, 0.030344874830916524, 0.009479547825321788, 0.014959187774366, 0.08773637920967303, 0.04525887045019772, 0.01667118980549276, 0.08336417202372104, 0.059038281833636574, 0.09270990412915125, 0.0792480206291657, 0.0136438877962064, 0.07043167730444111, 0.02742469256190816, 0.039083775045583025, 0.01610248575161677, 0.08978487006970681, 0.03842367179458961, 0.03934740445401985, 0.0525834783911705, 0.010786802922666539, 0.04458944211364724, 0.026571612361294683, 0.028349839012662414, 0.007167629328250769, 0.03980717607191764, 0.05052216693002265, 0.04764750243339222, 0.009973158594220877, 0.09709032688988373, 0.006584542916243663, 0.013580148442997597, 0.02812236332829343, 0.03955641921493225, 0.027745387560571544, 0.04031657881569117, 0.020431872871995438, 0.037251568282954395, 0.04374164971522987, 0.0072470293889637105, 0.027930186042794958, 0.03572473673557397, 0.0052334728115965845, 0.06920555286342278, 0.04704294151451904, 0.02269151773361955, 0.08367004076717421, 0.03990311721281614, 0.015489427241845988, 0.01618097157916054, 0.029931852950539906, 0.025057581005967222, 0.02620062201458495, 0.02416607425402617, 0.04447518476808909, 0.04183293123787735, 0.009800059142435202, 0.09417983892490156, 0.02895060199080035, 0.040425555780529976, 0.06046445960237179, 0.018948045071738306, 0.02983355734613724, 0.015067635958985193, 0.007311466360988561, 0.04963169732945971, 0.038161203847266734, 0.06027870003890712, 0.07125419957446866, 0.022558530436072033, 0.0199089036686928, 0.04227341814839747, 0.020343392170616426, 0.0256140934288851, 0.03785299733863212, 0.06370581555529498, 0.023199695933726616, 0.03587085819162894, 0.018206368658866268, 0.039761923617334105, 0.08243798656621948, 0.011434022489993367, 0.043938511807937175, 0.022704570255882572, 0.009757520165294409, 0.03234747127862647, 0.03577571114874445, 0.05326035417965613, 0.03363978416018654, 0.09489098709309474, 0.03143084097246174, 0.06863000249722973, 0.053050218775752, 0.03225100321287755, 0.024027337167353835, 0.013914322698838077, 0.05218930520641152, 0.015897216981102247, 0.047627323438064195, 0.039635565553908236, 0.023606533868587576, 0.04824114635994192, 0.056297745686606504, 0.02520150570489932, 0.015464300904568518, 0.07343142337049358, 0.04850972589338198, 0.03289144326117821, 0.01705369086266728, 0.09259222919354215, 0.015786165713507216, 0.04109979694476351, 0.02634710712300148, 0.06118106255598832, 0.034208681172458455, 0.018335971763008274, 0.04931894887704402, 0.058233660165569745, 0.02204904976679245, 0.015472001614398323, 0.07103292824467644, 0.027689054841175675, 0.01323297083217767, 0.06781712072552182, 0.042533522355370224, 0.021769876075268257, 0.04397369331854861, 0.03425995244469959, 0.006082639110900345, 0.10031522571807727, 0.04060474362631794, 0.13342454127268866, 0.05210517905652523, 0.024528010399080813, 0.016720935964258388, 0.051950905108242296, 0.05662635754561052, 0.05278731667203829, 0.0821696556522511, 0.06426111271139234, 0.07239116239361465, 0.024436080566374585, 0.06606620881939307, 0.04686122294515371, 0.034915795768029056, 0.08327675444888882, 0.03688485456223134, 0.03807364155363757, 0.048561731891823, 0.0770662103604991, 0.08649376424727961, 0.009727588421810651, 0.05195568082854152, 0.01683710619545309, 0.06523705917061307, 0.05867032872629352, 0.04050123257911764, 0.04806037031812593, 0.009424152067367686, 0.03791172719502356, 0.028061536904715467, 0.04234028936480172, 0.037449948067660443, 0.008812794003461022, 0.0292295641702367, 0.06621183303650469, 0.029234915054985322, 0.007505980020141578, 0.016914944499148987, 0.0062906844414101215, 0.053013259821454994, 0.017112303830799647, 0.03061840448935982, 0.04495350265642628, 0.03986041403550189, 0.09352688255603425, 0.026291275353287347, 0.03221251543436665, 0.05345700104953721, 0.03900607960531488, 0.013694807475985726, 0.03107801097939955, 0.03760385465284344, 0.019601005151343998, 0.032020336293498985, 0.0732794389477931, 0.02321996584214503, 0.03071745522902347, 0.05442685818707105, 0.032184577285079286, 0.04425034741871059, 0.041870387431117706, 0.008052194680203684, 0.12590513069881126, 0.12299484311370179, 0.17347436252748594, 0.06754170230124146, 0.11197846237337217, 0.19392915477510542, 0.12050615478074178, 0.09825327972066589, 0.3775938134640455, 0.11434894142439589, 0.10117886296939105, 0.14809329790296033, 0.17069733497919515, 0.17356052587274462, 0.0990995358733926, 0.11321009355015121, 0.13750025304034352, 0.09490527343587019, 0.11462410751846619, 0.13497080595698208, 0.16896706219995394, 0.16020704788388684, 0.11124790704343468, 0.08300640489323996, 0.11131526436656713, 0.10671570023987442, 0.1395851981942542, 0.16255747410468757, 0.10667707887478173, 0.368673613993451, 0.08015066516236402, 0.1810573009424843, 0.06521459436044097, 0.1806586340535432, 0.09475792001467198, 0.1435202284483239, 0.17407035164069384, 0.11191192141268402, 0.10559913906035945, 0.08963002095697448, 0.18810871319146827, 0.21132056921487674, 0.12341475769062527, 0.20601091819116846, 0.09952622625860386, 0.22141889843624085, 0.28768793621566147, 0.15040379657875746, 0.14986663009040058, 0.16666434123180807, 0.1769737817812711, 0.10490124564967118, 0.19762865704251453, 0.13128392020007595, 0.16253195906756446, 0.24981085618492216, 0.12803677178453654, 0.14796989358728752, 0.1144327744259499, 0.1305592426797375, 0.15052156057208776, 0.1601102718268521, 0.13321978272870183, 0.11651405337033793, 0.12068228126736358, 0.17623868450755253, 0.11951595908612944, 0.09497807070147246, 0.10355360936955549, 0.2205640185275115, 0.12508608167991042, 0.1456536803743802, 0.23574225953780115, 0.11147294848342426, 0.22881382115883753, 0.19965860905358568, 0.11370384439942427, 0.06703164646751247, 0.08150247231242247, 0.13621011836221442, 0.09012374212034047, 0.09502581306151114, 0.12994655524380505, 0.10637685045367107, 0.10312838843674399, 0.1641949635813944, 0.20668581244535744, 0.12973192613571882, 0.146778731723316, 0.13256351638119668, 0.19935523392632604, 0.1193107181461528, 0.24592972069513053, 0.15193553001154214, 0.22827160806627944, 0.10989639675244689, 0.16061180038377643, 0.15662300895201042, 0.197152272448875, 0.10501170690986328, 0.12420137485605665, 0.12598700443049893, 0.12622898910194635, 0.15377197443740442, 0.19350201910128817, 0.14561498479451984, 0.09934635192621499, 0.18173231394030154, 0.10799116265843622, 0.16434664372354746, 0.13940029952209443, 0.10909074349910952, 0.1686052355216816, 0.1980996981728822, 0.26264754706062376, 0.21097637596540153, 0.10299571469658986, 0.11027585685951635, 0.1639642150257714, 0.17830077151302248, 0.12727740628179163, 0.10841232404345647, 0.11207360570551828, 0.15705694269854575, 0.09391416489961557, 0.14923789742169902, 0.08569404075387865, 0.21500148810446262, 0.19052790681598708, 0.160644736897666, 0.16013452521292493, 0.239573463331908, 0.1626805221894756, 0.150029739306774, 0.11631606321316212, 0.1404046331299469, 0.10519705087062903, 0.14408641291083768, 0.11035166724468581, 0.14218215103028342, 0.24505471374141052, 0.17385943327099085, 0.1775312831159681, 0.16183680418180302, 0.10539334893110208, 0.11843067943118513, 0.18036498106084764, 0.09018756682053208, 0.12779690965544432, 0.1550736717763357, 0.10185125618590973, 0.119424608128611, 0.0703241178416647, 0.11066364386351779, 0.13038219592999667, 0.08125415712129325, 0.09722338654682972, 0.2176938217598945, 0.16100412933155894, 0.10756348521681502, 0.14257485105190426, 0.13669995067175478, 0.14205625309841707, 0.13227496936451644, 0.18316842906642705, 0.13013782154303044, 0.12354821068583988, 0.15414781286381185, 0.1428266172297299, 0.1839961315272376, 0.1447179657407105, 0.12794001057045534, 0.1055970907327719, 0.18378883483819664, 0.16499346995260566, 0.13567508925916627], [0.1308994580176659, 0.04174475296167657, 0.02522782226151321, 0.04000949666078668, 0.046188529158825986, 0.019332115771248937, 0.056859748146962374, 0.025923507782863453, 0.011427370991441421, 0.018932632519863546, 0.04129530832869932, 0.047296351549448445, 0.04915781377349049, 0.04385356187412981, 0.004061772378918249, 0.02547422827774426, 0.014944087852200028, 0.010646945193002466, 0.007072120488373912, 0.020995970044168644, 0.02328728420252446, 0.017514872561150696, 0.07011130699538626, 0.052813076617894694, 0.01734603396471357, 0.021583656380244065, 0.07378669688478112, 0.03204133907274809, 0.026995736770913936, 0.02792656250676373, 0.039076179164112546, 0.020298082199587952, 0.05794483113277238, 0.0216864735193667, 0.004778925913342391, 0.06879439562908374, 0.011656892220344162, 0.09559542624629103, 0.06309190357569605, 0.033112106029875576, 0.06735832503181882, 0.03057318172068335, 0.029332012090890203, 0.09183945396216586, 0.07332994951866567, 0.054801780061097816, 0.03572921188606415, 0.05923212709603831, 0.01956508705916349, 0.0408379783766577, 0.03537497737852391, 0.01760910305165453, 0.01775512246240396, 0.05873334448551759, 0.019317963015055284, 0.05421451118309051, 0.07563308608951047, 0.02200730024924269, 0.039382110990118235, 0.01973794624063885, 0.07242867795866914, 0.062227772796177305, 0.0442158189980546, 0.04513597450568341, 0.010113577573065413, 0.08237737536546774, 0.021265915129333735, 0.06066100628231652, 0.011463929185993038, 0.05198338520131074, 0.0115802849541069, 0.041629979823483154, 0.027735470612242352, 0.014964995079935761, 0.01869122115749633, 0.022662559131276794, 0.053134467380004935, 0.012709852271655109, 0.02444602534524165, 0.0328044895286439, 0.09351446642540395, 0.055332786723738536, 0.05206024201470427, 0.03257653515902348, 0.06270942292758264, 0.036667486929218285, 0.0336864021664951, 0.046877349814167246, 0.0279162559309043, 0.04169114021351561, 0.052687831775983796, 0.017371645481034648, 0.02702218134800205, 0.06282711270614527, 0.03873352216032799, 0.06099399681261275, 0.07429382865666412, 0.02761735966487322, 0.020012910099467263, 0.04518994719546754, 0.04620122359483503, 0.027007223361579236, 0.03390062309335917, 0.055165595695143566, 0.00974301674432354, 0.07732877478701994, 0.028788147719751578, 0.04525698168436065, 0.03735305697773583, 0.012014160256512696, 0.011283556686976226, 0.059115617332281545, 0.03197505044227, 0.04152128858549986, 0.02599723644379992, 0.024340901982213836, 0.011971797539445106, 0.020125020782870706, 0.05734667865908705, 0.009751058842084603, 0.0487378806428751, 0.019747937403735705, 0.015149413211474894, 0.050191911213914864, 0.034351611393503845, 0.08821508672554046, 0.005241928656687378, 0.03448749121162109, 0.03145816684991587, 0.04243115421559196, 0.04104977619135752, 0.07397852721624076, 0.03477457619737834, 0.03323903554701246, 0.011181382433278486, 0.005242083580014878, 0.14087715855566785, 0.08614139995188452, 0.043855127805727534, 0.04304522204620298, 0.022598790092160925, 0.030411191291932482, 0.022490482915600296, 0.02258286731375847, 0.06591987214051187, 0.03609634120948613, 0.010793618621391943, 0.03757818376470823, 0.015449176862603053, 0.09404520591488108, 0.030381462711375207, 0.03447933871939313, 0.030986865967861377, 0.0906457168457564, 0.041226151297451, 0.05495765704836231, 0.04656000746763311, 0.08768393905484118, 0.05700307912775315, 0.02016148435359355, 0.1304992029326968, 0.040108491739374585, 0.013882145958632464, 0.03791045070101973, 0.04198769500362687, 0.031454983036383055, 0.0574922063970007, 0.03835940922726877, 0.06424316758057103, 0.06207197373441886, 0.031647833820898086, 0.044456697869463824, 0.019534239690983668, 0.026681038325477857, 0.04182021082669962, 0.048763751910883, 0.01669883480644785, 0.07434174171066843, 0.015291618910850957, 0.035944215778727084, 0.007957121852086857, 0.03380963949894067, 0.015498108514293563, 0.018661574213183485, 0.005466722868732177, 0.05038771574618295, 0.050115232515963726, 0.029444762876664754, 0.026808982729562558, 0.03834710812952835, 0.03305853038909845, 0.02208933910878841, 0.049271900425083004, 0.048077495375764556, 0.0424475000181701, 0.019702772151504178, 0.02432998313452117, 0.028844792141171638, 0.12606850708834827, 0.05969074096356053, 0.03840471734292805, 0.0691998828551732, 0.06173846741148736, 0.034124473386327736, 0.0902699155267328, 0.03871224478643853, 0.0317533560883021, 0.019291869102744386, 0.07154658349463716, 0.010218973675364396, 0.01770351351296995, 0.03616202870034613, 0.0197127707360778, 0.015935200099193025, 0.017462955620430876, 0.02154939698812086, 0.043143241200596094, 0.029495254893845413, 0.022401555070246104, 0.02545644270867342, 0.07078948154230602, 0.020519923127721995, 0.030211221455829218, 0.009803207703953376, 0.025274521904066205, 0.017935386422323063, 0.008483687688567443, 0.07327098588575609, 0.010163814476982225, 0.04964966472471133, 0.06361127336276695, 0.013077373077976517, 0.024100644659483805, 0.05781587184173986, 0.05192381671804469, 0.025213287299266085, 0.009279694877477596, 0.051794111568597145, 0.0680422289588023, 0.09684218239272013, 0.020543929749692325, 0.06553613726282492, 0.011192381989530986, 0.0227816942424397, 0.037734754660050385, 0.0585172236606013, 0.028153733910585288, 0.03970960220613051, 0.044885306706419215, 0.04891764736385085, 0.02951083442894742, 0.026806591158674564, 0.08315404775203206, 0.07732314188615419, 0.027734318427974358, 0.018812491798598785, 0.04134364069614094, 0.03784031774557661, 0.017863370267150458, 0.05496464065799955, 0.0633786768594291, 0.04334285666118376, 0.01843964051658986, 0.06895996877574362, 0.07139223162084818, 0.04592879973642994, 0.011994082378805615, 0.03359621638082899, 0.0335662039287854, 0.04474042092624586, 0.05416689869889524, 0.08410857582930475, 0.023293482990993652, 0.017911029135575518, 0.023725993669359013, 0.05870097200386226, 0.03868461833917536, 0.013872763356630458, 0.07544328182120807, 0.02346788955037482, 0.018543491096352227, 0.03982391150202602, 0.020485589520831127, 0.06676374599919654, 0.015398820287373383, 0.006665244054602226, 0.017758573449100368, 0.03828168410109356, 0.05190216455957852, 0.057749486732063815, 0.027798556875495706, 0.03935079977964051, 0.00875400106451707, 0.048802647870616056, 0.011991681531071663, 0.031537962568108924, 0.020449921903491486, 0.018304630866623484, 0.032036147749749944, 0.04873472651524935, 0.03676522035675589, 0.013079757227387745, 0.04851253121159971, 0.012743140378006501, 0.040975253432407044, 0.022163780231494457, 0.0494474740116857, 0.06428554421290755, 0.010065434453281341, 0.1349906955147162, 0.003494796137601952, 0.03308278748590965, 0.07967009485582821, 0.06943639047676697, 0.02644362157298019, 0.01078185186997871, 0.03223472049285192, 0.013659253036166774, 0.0428330828435719, 0.023952552801347338, 0.040854461476556025, 0.01317135773206246, 0.013897103945055278, 0.05510260962182656, 0.020715571808977984, 0.10033010577899404, 0.05293752736179158, 0.0384030475106556, 0.03828539112873841, 0.04575746752379928, 0.004773412219947204, 0.06388917798176408, 0.08139435623888858, 0.026335134425607976, 0.09104717420996167, 0.022446358525485266, 0.05588053252722602, 0.03533704992150888, 0.10238386588753201, 0.05361203569918871, 0.05203624095884152, 0.031058768945513293, 0.046293954947032034, 0.021189349608903285, 0.03662202667328529, 0.05084660049760714, 0.017456348650739528, 0.05091074432129972, 0.008846022737998283, 0.030219229229260236, 0.04321689935750328, 0.012048096814396558, 0.1826462836470455, 0.09355912887258455, 0.10474535753019154, 0.124284688354237, 0.16866753139765933, 0.08677765057655051, 0.11008868721546605, 0.06883597816340625, 0.07630034364410676, 0.09595442534191534, 0.18798535340465605, 0.12461553036700934, 0.09472643068875186, 0.1154233337729238, 0.10005321790231392, 0.08213933891966008, 0.16726824163924903, 0.11159224130096845, 0.10979072234476916, 0.06461893179221079, 0.1586513579241, 0.16807837004307657, 0.16393047699239105, 0.12498400668846443, 0.08383883483475074, 0.10860865921131335, 0.19936713797505945, 0.13296268793055788, 0.13181978050852194, 0.1902593532577157, 0.1459427468944341, 0.12890523299574852, 0.19278881518403068, 0.15903283667284995, 0.09740614783368073, 0.20385549869388342, 0.08352865421329625, 0.14002555893966928, 0.19463165692286566, 0.14424480206798762, 0.1566178139182739, 0.1382438256405294, 0.11122546449769288, 0.14205721789039671, 0.13259173283586279, 0.13187167147407308, 0.14426481036935002, 0.09347807892481796, 0.07930660576676019, 0.16531597764696926, 0.1973917635041289, 0.2270338690141216, 0.07442853588145226, 0.1972505624871701, 0.16260182484984398, 0.141873239481356, 0.09890069966786541, 0.12228957275510766, 0.18689141288632527, 0.1464598160237074, 0.2106540760723874, 0.11607583743170835, 0.17682838020846248, 0.0868027945398353, 0.19768715312238783, 0.22077691101003438, 0.11171325590112247, 0.10224218989606015, 0.05799285921966657, 0.15760159003548324, 0.1122364922775887, 0.08130094953230582, 0.14299061702331528, 0.19632860727142543, 0.10257259404170327, 0.10064170390251093, 0.19697675452334806, 0.10553659085417166, 0.0954797699523624, 0.09019081000587903, 0.13312527764355764, 0.10163715400267392, 0.13075246824882925, 0.16889730031834915, 0.17071087175281718, 0.17566555354278535, 0.0658989064686466, 0.1841705510742031, 0.19459820090560243, 0.1423175781383179, 0.16034183674491942, 0.14812065346632153, 0.18050011130981147, 0.1353438539081253, 0.1313304973882623, 0.17169867031043395, 0.11883299026521854, 0.1263625459978357, 0.16483891027746722, 0.2817029011202976, 0.2190657559549436, 0.1464731153100729, 0.10299584086169489, 0.09740412177052349, 0.06549922283738852, 0.14813349262112752, 0.1585137637448497, 0.17908424197230488, 0.18179797916673124, 0.08274283114587888, 0.16618935187580064, 0.09059018935658969, 0.13897160533815622, 0.10037882035248913, 0.14806257298914716, 0.11249624396441504, 0.1882918900810182, 0.1394361155689694, 0.14449558861088008, 0.13283968437463045, 0.1857619234942831, 0.11214562371606007, 0.1297561646788381, 0.15960789722157642, 0.16919942863751203, 0.17617432546103373, 0.1453821879113093, 0.14632278587669134, 0.15881930594332516, 0.12020249021588825, 0.09294223345932551, 0.2973523020045832, 0.1322128070751205, 0.2196158654987812, 0.09944407051079907, 0.11347587147611193, 0.1888006619992666, 0.22855972463730723, 0.0955454797076527, 0.11608731103478931, 0.10636257895384915, 0.09696332315797918, 0.1241523856879212, 0.15570172166917473, 0.18209578818641603, 0.08895353850675747, 0.08327080242452212, 0.09225625151884742, 0.14099613967118785, 0.15361662808572873, 0.12696361140115187, 0.11059302851208486, 0.15613121737260371, 0.20263807964511216, 0.13371001579798758, 0.1473713366431184, 0.10235367532004602, 0.16592113970546052, 0.2804457029560581, 0.08773779671173543, 0.14782182028284296, 0.14940553373889998, 0.16308760503306985, 0.22739876818377525, 0.13186016818508506, 0.16906652483157814, 0.1824994126218371, 0.11499922606162727, 0.1622853582375683, 0.17910837661474943, 0.1296746323350817, 0.13039165089139715, 0.08698395278770477, 0.1193315650743898, 0.1473396914661862, 0.11652240253170021], [0.029655768448719755, 0.032332153350580484, 0.018524074657761957, 0.07771935968776233, 0.027396752557251602, 0.08764445679844357, 0.030684067860420328, 0.041866806568577886, 0.046661340311402455, 0.0314042906393297, 0.05207026842981577, 0.0612735118920682, 0.05534490970603656, 0.015249262687575538, 0.055394800583599135, 0.022426524628826883, 0.025083817781705875, 0.030574194752261974, 0.021469859166245442, 0.039738798295729794, 0.03812854934949428, 0.015997269620129373, 0.03263000318838749, 0.02207294321124209, 0.058528849403955974, 0.05892830668017268, 0.0013157590660739515, 0.01647604764002608, 0.025135643809335306, 0.03939149544748943, 0.01135008002165705, 0.005707544687538757, 0.019495297347020824, 0.018777280602080282, 0.03575639675545972, 0.0431491041672416, 0.047361397082568146, 0.06567276665009558, 0.05979005516564939, 0.012075816030119313, 0.04884895788563881, 0.006859892691863934, 0.04589373696944676, 0.033474956871941686, 0.035670693541760556, 0.039916420209920034, 0.029112033953424543, 0.011356904997228412, 0.018089773548126686, 0.07930506209959276, 0.05030002357671037, 0.09715975480503403, 0.027436529817350674, 0.03517711338645313, 0.047890841524349526, 0.007436909263560665, 0.05164850961591583, 0.02064883417915553, 0.08113960662740283, 0.03310889624117408, 0.06009455835737754, 0.00892727863174514, 0.03377000510226935, 0.09182853696984239, 0.05922339572862256, 0.06309269767371006, 0.03778374753892422, 0.04603209556080401, 0.03911531632184051, 0.07594997572596185, 0.016955575229076203, 0.07465787435648963, 0.0661047782341484, 0.026521029431023635, 0.05202363558055367, 0.046736701697227545, 0.016486664062540513, 0.044662584477919154, 0.028385651348799, 0.03825361607596278, 0.028861787322966848, 0.05405168398283422, 0.03036475696717389, 0.021877780636714306, 0.03629379702033475, 0.0389637586340541, 0.030948962630645838, 0.03514022864692379, 0.018065991425828543, 0.011898349966941169, 0.0678288986091502, 0.03689078803290613, 0.008713493716641096, 0.06404026440577582, 0.06245754542760551, 0.0408703805442201, 0.05926017285673879, 0.041997903244919144, 0.02678307249880163, 0.010602418187772855, 0.024382703450100962, 0.039256773379747756, 0.054175537297851406, 0.029884455689170863, 0.07502937121898867, 0.03616056295868475, 0.05654668057104573, 0.025670960494608153, 0.03775885590584949, 0.04467304876015987, 0.039884574653115124, 0.028822902495448943, 0.056810172682162374, 0.07018521006102674, 0.03258631666540168, 0.019212418483220972, 0.022980074027145747, 0.031570669016218744, 0.05582461912126746, 0.015494668659812305, 0.027336701677995734, 0.030762963724555448, 0.011035790685127722, 0.013705422970815562, 0.07384082913631573, 0.02939425230579218, 0.018167166563216597, 0.08650374613353051, 0.06276495041674934, 0.02143495781638194, 0.02439747218886623, 0.040704473431105725, 0.06683713698294014, 0.018837832431017887, 0.011015280506398994, 0.030500536595354788, 0.09984550561057404, 0.02215621032519266, 0.07858485230826773, 0.004730492892122129, 0.016941715621214826, 0.047831143165240064, 0.05000737619411666, 0.03140357817756012, 0.0401742423127871, 0.020545677507470828, 0.015699993091402575, 0.017935857686097734, 0.06530152953928337, 0.014815599824942183, 0.02975214745674748, 0.019229643730795942, 0.06888215459184721, 0.020027931168442592, 0.021620869520120323, 0.02251902777061332, 0.09728810924571007, 0.01353467983790324, 0.06564773400896229, 0.029595873420475982, 0.026705905838753097, 0.02432829289318761, 0.07101402574335225, 0.028669875355262775, 0.047660304480814375, 0.029120538965798914, 0.032373490976169705, 0.055030042422004044, 0.019116826151730493, 0.05601804507023189, 0.0067263469281897414, 0.05250669579254463, 0.007945918205223279, 0.030916779396648053, 0.08529732571332715, 0.0076922920197830535, 0.030856498451612424, 0.018710440926952288, 0.04239382418745663, 0.0792442579404451, 0.042925569287035614, 0.042377007121103816, 0.035880995928891934, 0.038636738681816496, 0.029213617272034753, 0.07527468071202748, 0.08122038940200582, 0.057526719974703155, 0.02460852228978183, 0.015003009739302797, 0.029309348756214604, 0.028390096813382115, 0.023664230284339283, 0.02413843852991704, 0.05126979907799978, 0.03357139525178354, 0.022533891133207362, 0.04679844838392455, 0.02715390142839169, 0.03228767272958066, 0.018289344479853753, 0.042503996010054834, 0.07675713553908281, 0.04010430973721668, 0.0687452060810756, 0.036154462504782714, 0.018510860718379263, 0.016251457054750063, 0.039470864430768415, 0.014391070017154561, 0.035788594832411036, 0.03482741711195558, 0.04457007577002514, 0.010917446888925042, 0.03783159008889925, 0.04684103652834892, 0.00827961655886611, 0.08941362553741783, 0.044892501828144304, 0.033964191752602346, 0.028185783558001276, 0.03829490175121464, 0.03273482412623707, 0.022423242480726913, 0.027098698628833517, 0.020421302833710797, 0.04708209351520054, 0.09959674513083883, 0.01610710191016551, 0.009577614291629288, 0.07553881107014604, 0.014567780017387122, 0.041686316253617406, 0.02082424078253098, 0.019916056116926484, 0.030058014344831463, 0.04371911440102849, 0.05053376669820864, 0.013080126445856877, 0.08641440639621578, 0.08244189768447541, 0.054548648331547156, 0.04335312798502855, 0.007666533929295838, 0.02155887421395164, 0.03824235398496967, 0.007704217869104468, 0.047256334946723655, 0.012913665505038807, 0.055166512247524224, 0.002898393740906613, 0.015017012210591929, 0.027655979174596723, 0.048989539209287614, 0.0234782963161706, 0.05221520987106487, 0.020196521145408042, 0.10748878805316053, 0.06424494873499498, 0.07446150208124891, 0.013690057730855187, 0.016351426202163566, 0.0839347871078644, 0.023930932184157427, 0.02948378685687203, 0.047373171255458146, 0.022437087245634757, 0.016707529066479765, 0.05358090631489176, 0.08222716467571445, 0.03174635021423455, 0.01883129410998663, 0.01053852020049817, 0.05611116976069752, 0.026524205823079683, 0.04028031005873345, 0.017666302228462882, 0.05905941819946747, 0.006929572009539697, 0.028585387408384122, 0.022016187467670534, 0.07425320349284448, 0.06920698520843871, 0.035937974316766486, 0.014637694966950221, 0.02930141334218206, 0.011221802578802453, 0.023792555039108265, 0.04698597054812126, 0.032409455452580005, 0.031142145526246168, 0.08188464867998846, 0.011983876920567127, 0.04715541399491485, 0.01997532403038349, 0.0387160148966359, 0.004204580145596992, 0.08082737767836079, 0.02963602360978257, 0.009287723059969721, 0.07559177814982831, 0.021815889231220353, 0.05041098207584582, 0.03524344283505343, 0.07974137814017013, 0.049990971019724384, 0.009435109877813375, 0.029055510131001938, 0.04740179218060803, 0.05763449094956741, 0.022289498192549217, 0.022857018520880956, 0.08384781482163817, 0.016251314191322308, 0.0285060054375208, 0.023679911864746828, 0.03918232112482656, 0.030830219002382364, 0.02477643320162315, 0.02051052011665888, 0.10575032938504592, 0.06329645431833342, 0.04469917235837784, 0.04342403277405538, 0.031482902631978504, 0.03476019708614331, 0.05604498503089417, 0.046933029443607666, 0.038929026122787036, 0.01388758682878688, 0.03215556302166078, 0.04382405037176795, 0.09085153666092083, 0.012815335576306097, 0.10039538508863188, 0.004684310433731298, 0.022611824060732033, 0.03383727336768061, 0.031000235758256167, 0.03587719984352589, 0.02008103740081424, 0.012449864952941425, 0.02251901663839817, 0.05484286535647698, 0.03674871870316565, 0.03821670536126476, 0.01810052912333049, 0.07719966335571371, 0.030018456018297, 0.04582998277328443, 0.040177407572628, 0.04691194502811413, 0.1929196112905629, 0.09516648715361953, 0.1712023516301997, 0.1476081708096899, 0.19095271214609966, 0.22456692560808733, 0.12012737744953483, 0.10201091441558674, 0.1372657046886161, 0.13570009963586926, 0.1887327851727605, 0.15395071328384802, 0.13141421164618805, 0.07386937213595957, 0.1246540923602879, 0.1561897579813376, 0.11201597051694989, 0.10250832405290566, 0.1026582378835883, 0.13978379691252485, 0.09848154208157212, 0.11935690199607052, 0.12461927079129964, 0.17669632245087996, 0.14491828624159098, 0.11382865137420595, 0.23161528020864353, 0.10169559071073309, 0.17635252996115014, 0.1655463402858004, 0.13922788377385587, 0.12947564770001918, 0.10728928391472436, 0.08771119813900441, 0.08858495828462765, 0.08923538392991759, 0.13871174975065514, 0.1811063865898177, 0.1214564303518273, 0.17432173190172762, 0.1522458516410552, 0.20729014329845086, 0.12180588542832993, 0.21957982680760324, 0.12926245835842565, 0.19776494504185393, 0.11351138324243948, 0.10610984798404388, 0.10965280162054114, 0.1292530627688393, 0.16462656698422506, 0.26137042965274304, 0.08332929108291864, 0.08811624749796465, 0.21810252248542383, 0.11668269158690237, 0.11104638426331803, 0.16156112600583583, 0.2403199896798469, 0.10245306373690255, 0.2075492122094147, 0.10051449979073368, 0.09913147790939547, 0.2761251269839704, 0.16761767445132136, 0.1639827390317805, 0.12974770419532433, 0.1734488771762699, 0.16601845010882244, 0.09442528942599893, 0.10434609692310914, 0.18811533314874396, 0.1631301300949417, 0.1807654439471662, 0.09115856315474957, 0.21565337578067556, 0.09493703735643066, 0.12795068265404552, 0.1504783082054928, 0.1284959533950314, 0.13595418131444603, 0.2188206245773472, 0.138974440342281, 0.18559663236374035, 0.17794638115447015, 0.11413595246267505, 0.1506328530376777, 0.13896425807615742, 0.0801923664403148, 0.10330468561733142, 0.1552339459885843, 0.057105065061477944, 0.09233390243025497, 0.3208675776841119, 0.09771163066034205, 0.1249702027416788, 0.1573584772995673, 0.15945430233841762, 0.1704793216777034, 0.10394644297775812, 0.05572112662775908, 0.12390597781632096, 0.11231390570173971, 0.09210904652718455, 0.09042530640726909, 0.15133654262172058, 0.24973607738502324, 0.12210854067234322, 0.1632916511152871, 0.1126392484002281, 0.09464418588322587, 0.13752288854448125, 0.12068654119502753, 0.09917585834045894, 0.1156242702563759, 0.19192045787349343, 0.09802031956496648, 0.12412535666953772, 0.11021911966963671, 0.10304698225809261, 0.1450498987105675, 0.16492554859723896, 0.15677878574933857, 0.09341963479528204, 0.2822016243590042, 0.1254349949886091, 0.10087588118040003, 0.24875436443835497, 0.16205017163883895, 0.13676070288056508, 0.16554288187762722, 0.14807342318817973, 0.15080914279678836, 0.10967485082801431, 0.23724196187686175, 0.12029488760163076, 0.1970924108172767, 0.13159885798813775, 0.18562303797807544, 0.1388620791840367, 0.1830666806199588, 0.13477286032866687, 0.12423933570971712, 0.1282572341733612, 0.17816544830566272, 0.11469109376776032, 0.1677833218127489, 0.12394062126986682, 0.20953724771970883, 0.09463291266001761, 0.20917447109241039, 0.11029931614757515, 0.13184821960749105, 0.0996771345671732, 0.14739340811502188, 0.15705689816968516, 0.15833958168514073, 0.09881323014269583, 0.20614705776097253, 0.1250587112735957, 0.10339635569835082, 0.12801913835573941, 0.11979425704339519, 0.1647467800648883, 0.09551548209856264, 0.11197127838386223, 0.09488553972914815, 0.18967627751408145, 0.1146061772305984, 0.13045930507360026, 0.11128232043120079, 0.171334542974364, 0.09041913173859939, 0.09700453461846337, 0.18842629302525893, 0.14851752435788512], [0.0566667749080807, 0.05896315793506801, 0.02450171425152803, 0.03911720879841596, 0.03213645642972551, 0.08365314948605374, 0.024143652117345482, 0.028709847429126967, 0.05588710053416435, 0.04499206836044323, 0.1049685436009895, 0.05041292650275864, 0.0482475696480833, 0.01595724002982024, 0.06791438660002314, 0.05369376471207943, 0.06089473085012287, 0.08720516474568285, 0.05018615585868247, 0.03829447130556218, 0.0253261790930992, 0.07847334461985156, 0.017916428259923123, 0.09106785786570981, 0.05165873641090002, 0.02919451810157625, 0.048795129914651625, 0.018076296146318782, 0.0405342395970365, 0.08961033177911304, 0.07290036475751549, 0.0685888875159435, 0.03886805869115051, 0.04606677241099533, 0.021665116364602, 0.0176210163772339, 0.03750597650650889, 0.02311051204742398, 0.01733384604449384, 0.022174025580170564, 0.025806712292251177, 0.044750695960829034, 0.02559164717240492, 0.06452009256463498, 0.014653830185125116, 0.025821629460551776, 0.07650744737475179, 0.008653268432681216, 0.06092632407671772, 0.05885465594474226, 0.11965994315687567, 0.030003562969795894, 0.033380236563971266, 0.05960227696050424, 0.04587808878568467, 0.05520074751984794, 0.030339724326040596, 0.02603544962767046, 0.017279964267800096, 0.0006381730190696544, 0.008958061062003253, 0.04631718045857269, 0.042719226257759146, 0.07061379292281345, 0.07355809313594364, 0.07513186923461035, 0.024796443358354736, 0.02553362792241387, 0.06400297148502432, 0.04435531307535712, 0.04517799861787353, 0.07834927237126976, 0.045596425188705325, 0.050101610395358875, 0.04765949553984683, 0.07517550009652041, 0.0011986224194515671, 0.024150734061549883, 0.006986398257140536, 0.04096860378922429, 0.0754212326137349, 0.04876169245108031, 0.016155100311152637, 0.048220102762570605, 0.03487316680548247, 0.058653077503549866, 0.01697266874543857, 0.15721947303973138, 0.02561647015681956, 0.05009895350667648, 0.04232052597217262, 0.07277902361238375, 0.04135246483201627, 0.058385577794979326, 0.040641205341671593, 0.06254620981053449, 0.018528624023019802, 0.046695605269633234, 0.030400843897950836, 0.032381947748945095, 0.02471942141710315, 0.029689597395190503, 0.019049823204113636, 0.04304193804273382, 0.031007827928988263, 0.03976287356636021, 0.03070007969654398, 0.040552028876845725, 0.07870682427892461, 0.03899267641827464, 0.015805027396709193, 0.02505234515410848, 0.02887314032705035, 0.062076441463432275, 0.04181902339041699, 0.051786441472359, 0.014137983744149096, 0.03265831612225156, 0.02855467733752448, 0.027620970213320106, 0.03546574946085457, 0.03014700527273817, 0.0326110561582027, 0.023648823298572097, 0.030931822730053682, 0.01821037625632016, 0.048035538056865335, 0.031001979805296287, 0.08815310255158693, 0.022126312906038947, 0.03625147233833559, 0.05932848755037412, 0.011582571696635569, 0.05053612301708199, 0.061467479608836584, 0.024397236556978896, 0.011525703703227919, 0.08152115216944367, 0.04339078826887999, 0.02343106418265961, 0.03615418419940397, 0.0372910728037823, 0.03744129091501236, 0.030794143203820568, 0.011785001752286917, 0.016679266227583867, 0.1488671501283534, 0.008774337766226381, 0.052024852702743374, 0.05349252023734152, 0.02183781412895769, 0.03380717185791582, 0.03021462234755745, 0.01038747644997784, 0.0718180908006616, 0.05738271363952663, 0.036471593339229, 0.02586477050499525, 0.02685161540284753, 0.0440082885324955, 0.027126302811666392, 0.013647825817315606, 0.04783597083587665, 0.07733060789178126, 0.044061886437702924, 0.0491363211767748, 0.039100002104532905, 0.02625561330205528, 0.03768909773498308, 0.031790682405699044, 0.0862985868297983, 0.0557134416885674, 0.03583712015824858, 0.05325422403984703, 0.045023806305835024, 0.026767771269078366, 0.035262979872641154, 0.025341727086924948, 0.05069243416073732, 0.04904606117634103, 0.019448532766546123, 0.07683841555262916, 0.010535066430747975, 0.015731836792838294, 0.04344964800111484, 0.0355288839637069, 0.05058583206846379, 0.08504922574502416, 0.03472986179986037, 0.06959754042327404, 0.04716138828371186, 0.03196246732841246, 0.03025164067366859, 0.07148802804294974, 0.037221329475869425, 0.03381154310773127, 0.022292895373539068, 0.035070659723714925, 0.013843684155290248, 0.08813295324216597, 0.08441658195806667, 0.03591798085835762, 0.020168215633020736, 0.030897010437911376, 0.03420579792873468, 0.09445755058550276, 0.059313804158591665, 0.029645634422195144, 0.024502385895175394, 0.06541043971083127, 0.03184045825037174, 0.03105838673945982, 0.024804579152259976, 0.03766510410059709, 0.05325637255737092, 0.07752605990390293, 0.018487959896447137, 0.05372845640522428, 0.05737421604862902, 0.08495630143443123, 0.05276686679280829, 0.02418103595118737, 0.034258234372828156, 0.0662772088253405, 0.017902913750731386, 0.01261598821656662, 0.020503898304014, 0.02982130077725742, 0.05607073013379704, 0.019183317017450463, 0.06436122843297198, 0.03327393875224516, 0.049957503870246, 0.040251652026199736, 0.09329516178695485, 0.04352464573457837, 0.09288079847465269, 0.04367900502984412, 0.03353971667820588, 0.012880719714303268, 0.012642022757063387, 0.061403217041515745, 0.006434069227907457, 0.06376527642714791, 0.034428750223014504, 0.05154896163730882, 0.10710920920246281, 0.05789130744233262, 0.007768585264784633, 0.024941613010014407, 0.05774583536549471, 0.05609060484857764, 0.04005422590125818, 0.028628159234358463, 0.022350155777530745, 0.04029628849821165, 0.050782545731635764, 0.062155350315151736, 0.002163704648410203, 0.04649234215321485, 0.07435610226821154, 0.015523236706940224, 0.03828381035418715, 0.014638501124863978, 0.062308091728482395, 0.028223488370713312, 0.08911157143302262, 0.10591943515464664, 0.009080087766051292, 0.019851370525429957, 0.03412687423406169, 0.02810947407851927, 0.03755303237994667, 0.03551128022081684, 0.09055939764948562, 0.04151534398260992, 0.02192708521761233, 0.08005431212950498, 0.013077733947284287, 0.01566488394018961, 0.026569892434054054, 0.05474822668475099, 0.05851637390151154, 0.015951599707477726, 0.07974398307851516, 0.037441469030454755, 0.026459852342668455, 0.03375686537765432, 0.08341447479324415, 0.03349516184243839, 0.027875020350620616, 0.009388506714458345, 0.014773846596654039, 0.04959825244441163, 0.023303019588638563, 0.024561043392168358, 0.027893746591871604, 0.015151672123465687, 0.040456596107105725, 0.008380748095078161, 0.11153418308822438, 0.07719587098108605, 0.03262764686951414, 0.04038458922877908, 0.030111677187960595, 0.017631742266530637, 0.007753630989100202, 0.018770458409562707, 0.04456200491404161, 0.022235341821215115, 0.06076692559872754, 0.05019568503485061, 0.02760008803306846, 0.05801050006994046, 0.032688647697796114, 0.033207238229806535, 0.07323908095713705, 0.03688404933200218, 0.03241433878429234, 0.030389904641197063, 0.020779413207492325, 0.024747418938204646, 0.047508676288998686, 0.04483683704165742, 0.05620555610221345, 0.023025983282423113, 0.05752110562752932, 0.034217690845252946, 0.02849445019819541, 0.042988963541574776, 0.03135057399049401, 0.04736836584925186, 0.024273080816783477, 0.042416608121129684, 0.024508467795385513, 0.03372311250132043, 0.048780301804072224, 0.09566256834659725, 0.00785133704994223, 0.0627155159600079, 0.05356532121368218, 0.03599425879656337, 0.058762451517395675, 0.02595190791907953, 0.03116190891887527, 0.038296768252621405, 0.09622517565730959, 0.0698492769151926, 0.03383753683010582, 0.013896340460632928, 0.031271082552848384, 0.066973632783629, 0.17135931586381048, 0.10983090964145958, 0.12017018452752382, 0.14507057494483888, 0.14454780612140894, 0.15871317882556468, 0.1575597922783345, 0.07629494823049754, 0.2352826326387003, 0.1403919275617227, 0.17078228120226413, 0.19149966014083475, 0.20561225130222738, 0.15997616574168205, 0.13053899689111859, 0.1561059695086442, 0.1338315795874223, 0.17944076971616596, 0.14221839752281085, 0.11105298937764019, 0.10339501241105609, 0.12621548201423138, 0.1136494375532493, 0.2247815250302665, 0.22351127990987152, 0.09991936414735392, 0.14493462833343074, 0.12799837306374684, 0.16450301423901692, 0.24141333648003638, 0.1011965780344326, 0.18733938806690276, 0.11075323593104258, 0.15859400475164875, 0.09093116910662502, 0.08717832126421854, 0.12958132952917367, 0.1187391382700298, 0.09574480573064648, 0.13325773616088554, 0.056405631694360636, 0.1433786266716197, 0.13013976596994326, 0.1670102562638931, 0.05336437730875332, 0.0912369710567873, 0.15901446109637618, 0.2400661603314802, 0.15943499165587127, 0.14880601200275123, 0.15007312525995076, 0.09524738867185079, 0.09587448119418696, 0.07611863620695658, 0.13194259110605344, 0.14739720791112632, 0.0899438677879516, 0.12733777257381007, 0.21081494400277734, 0.06567147531313822, 0.23306595627218485, 0.12466160289477557, 0.10955226287478581, 0.1279337765299715, 0.1027113979216665, 0.18931283295387402, 0.1613891258602962, 0.21693646005587652, 0.09530989234917797, 0.11270528470049612, 0.16594138549407944, 0.19538642111001536, 0.14930532895959914, 0.1817691689939238, 0.13182962138671428, 0.15905018808552995, 0.12321681948378682, 0.06620917614782229, 0.11006436703610234, 0.17845558351837099, 0.14129106915788725, 0.21457818191265687, 0.14161702041747048, 0.18004976125666872, 0.15222671907395124, 0.0923923020309303, 0.05785749890492298, 0.2555005165049806, 0.15578763268422335, 0.14434791606618091, 0.19918370875529945, 0.12688734830589965, 0.12694192584604025, 0.18851364380680025, 0.125902533181943, 0.19007481081644073, 0.10632289631757885, 0.15090666100149974, 0.09785303205717355, 0.1614328977302648, 0.09337883151602, 0.18729511153651401, 0.08148552908096462, 0.10604041264741682, 0.07145244206185453, 0.11850079754367471, 0.1727237246814184, 0.11931831031688489, 0.14752448623767123, 0.13709143357118592, 0.12030554484226741, 0.10962745727738366, 0.16615429281955585, 0.15623174869688228, 0.12339499429799616, 0.13618862576549873, 0.12289322083233856, 0.23908349743578583, 0.09620924174669199, 0.11675475412630476, 0.07991055812453851, 0.16760526574216783, 0.2432373573537916, 0.11113018015748821, 0.19726276339497417, 0.14029420155566186, 0.1959263632306829, 0.08641933425678872, 0.16517661715624854, 0.07743343245238066, 0.1394736088695936, 0.22551421774551272, 0.13009391608648002, 0.21963594801491126, 0.11562035913811997, 0.14649698277935386, 0.12106594193028286, 0.1408241395256482, 0.121383284276817, 0.12983781576622277, 0.09446885349461809, 0.1837195924599655, 0.15016509220004082, 0.1072496161214076, 0.06531498467666097, 0.08254699321696535, 0.4160291963489726, 0.09414135114639066, 0.13971687003504485, 0.1661970405257307, 0.12751609581755474, 0.1688418915728107, 0.17704091646010056, 0.1349697817931883, 0.1616878848290071, 0.21820136171299964, 0.12544903642265126, 0.09229011571733281, 0.17351437913021073, 0.15410509484354407, 0.16935870837187394, 0.25278158427681774, 0.08729626337299123, 0.15654640446882695, 0.17103538324590772, 0.1388767737080343, 0.17076538992114365, 0.08536525449017063, 0.08299886467284523, 0.15230253688059747, 0.2352955163223669, 0.13367602543439716, 0.15081760328030214, 0.11041184057830833, 0.17780997441150248, 0.18296827183803543], [0.05104068695800379, 0.050353513870504685, 0.07823220599675551, 0.03431150944379624, 0.04423781625519041, 0.03584234858863056, 0.03622426149377134, 0.03690317076689098, 0.02263634461996844, 0.04299070016713813, 0.046801654461887665, 0.01945664444065187, 0.0384028916596435, 0.04627278518455569, 0.05360680726880673, 0.022159303225635085, 0.03959616493375506, 0.030577990837628022, 0.024986286589410156, 0.01366524958939408, 0.015384142461698502, 0.08152513750246726, 0.06339256244245917, 0.06712567657814361, 0.06292973688687198, 0.024844183863024227, 0.017435191875847522, 0.050298936330364086, 0.03299355164926965, 0.02070755846943939, 0.013891573089495068, 0.019975609757239, 0.045558872516267, 0.019735775458684657, 0.04952048278937582, 0.02493637344741728, 0.03936051078198943, 0.053517745836870745, 0.016285460405924823, 0.07983992793015204, 0.06281094130827114, 0.02158989227609709, 0.06456079936469905, 0.043965696677332744, 0.00339643791448907, 0.049500095992698334, 0.061658701379201375, 0.029920028682681732, 0.05086341385322157, 0.08072105018072762, 0.032998702154145576, 0.05235870412434451, 0.01526309260952985, 0.02663987881533103, 0.027696372417267412, 0.03034683224541368, 0.04695034745964222, 0.009892753387248376, 0.01102426049328642, 0.04237737819494214, 0.033282198855886236, 0.052105872964602895, 0.031340295245172456, 0.05786552523204591, 0.023561671041534282, 0.05038600509578828, 0.024486277579853777, 0.08368761482415721, 0.1126542991551105, 0.05297242685628589, 0.018731185809883755, 0.10218925992376171, 0.04259221881511621, 0.025568243545421865, 0.0375526501738932, 0.1551300601568073, 0.05634911714878399, 0.01717432140139863, 0.05590785098320339, 0.011323362705297768, 0.02161954849725589, 0.07661704774363898, 0.0035059589663433144, 0.00760064002861327, 0.055761176627129316, 0.054178554128156975, 0.04759549272421282, 0.03546524851117283, 0.013037791559327161, 0.02434186862956267, 0.0582136184675619, 0.0565434114105301, 0.006549394802277675, 0.1354384925798513, 0.05098847686895169, 0.026194953861704562, 0.023011121775198262, 0.06988482578890398, 0.034471420003683306, 0.033490323039586656, 0.05138638676726259, 0.04530198923021089, 0.02553095433540875, 0.030808796909695957, 0.0035752818212131388, 0.03174398276314605, 0.026881043413595762, 0.014214059447112959, 0.05049016181146726, 0.05482651584316045, 0.058091178943868726, 0.031633328544558026, 0.04908596274617594, 0.020921662508044392, 0.06687290107947774, 0.1370092629804276, 0.04258451532223262, 0.058210709248669446, 0.05919011040532496, 0.03011696127941832, 0.06301185552729294, 0.023381861647067126, 0.009347319373773644, 0.043743664646171965, 0.04704930543084629, 0.02017134007473942, 0.019284295485704206, 0.07778922547004186, 0.021630818009725772, 0.02127528659912059, 0.052034300242667086, 0.012375149235595018, 0.04337716985901352, 0.010970788753184024, 0.0553055276395753, 0.03029098006663844, 0.07584428647533059, 0.01763209107593866, 0.009985385477193631, 0.05322509474353865, 0.028122777075623162, 0.008967234007286606, 0.052714029588969424, 0.0022036781138012884, 0.04734307345643174, 0.035689421638380736, 0.04920178231259342, 0.03155343634716701, 0.048499732874915935, 0.06598197505809367, 0.01825723360525444, 0.07352739790803753, 0.008855199394020019, 0.00042228944948874414, 0.035564896679716185, 0.0278892324786284, 0.05461453620227985, 0.025165671104332432, 0.04666349253966473, 0.04818719964532647, 0.002621478033688618, 0.035001161304535344, 0.048644199341651984, 0.07165043221903034, 0.023904843837954104, 0.03131217155896593, 0.026918651747109834, 0.0402269162441371, 0.07903434889158234, 0.027017593019991182, 0.015679565476602875, 0.007836085915187141, 0.043222023887210526, 0.05221992250881158, 0.0163532778606168, 0.024720655237615574, 0.055606631794944406, 0.024464078087476082, 0.06912732307682745, 0.029728823610639665, 0.10018935005064122, 0.08956236677477136, 0.006724015656800475, 0.05132364560267888, 0.053023969012429006, 0.034990478088730015, 0.02526874242903432, 0.054473446507472545, 0.02913401822297601, 0.018621949093358126, 0.010577293705864577, 0.07380103517789394, 0.08111141985864379, 0.04022028144390788, 0.055357997480314225, 0.03210657014278695, 0.02072692852379987, 0.011930625041713938, 0.04155593574978411, 0.034773655934259295, 0.02232251819805242, 0.015195422656688606, 0.038239953137235716, 0.02321103966096416, 0.025899131942423992, 0.0076454949703474995, 0.021251925645628944, 0.02556113377067959, 0.022042205309844576, 0.017771651946532074, 0.032322034167009406, 0.05350815728888847, 0.00832224273835891, 0.0377198560454417, 0.03586885068216361, 0.03726216244103853, 0.026629793028405402, 0.04625872148608323, 0.011788625288318144, 0.03661268674477469, 0.07074658540659584, 0.048305631571565755, 0.02395442486886168, 0.03956965541874524, 0.030742524977540597, 0.06945807603187859, 0.00575878163544985, 0.09678937116404995, 0.03441070490225684, 0.04440041710040532, 0.042740099161164835, 0.03544558901921846, 0.05455876009364147, 0.08491762811900117, 0.04661794322601054, 0.03773057265789248, 0.01447421560442308, 0.06498677728814073, 0.029122077066858765, 0.021538376095122658, 0.1177324223681353, 0.04911858384730294, 0.01224095409270376, 0.018149310490116477, 0.03048613521968946, 0.05551631984417327, 0.011038474476663396, 0.048505655213375576, 0.07458964129909873, 0.03783254374866374, 0.05298962612869218, 0.04926435649394989, 0.09040031087351963, 0.03051098232390359, 0.026935966052406002, 0.020077925946679898, 0.008379983682971215, 0.04632473181118257, 0.039434888822142966, 0.027490881002449896, 0.06827767530921847, 0.12267254322068766, 0.09435738291358575, 0.026166611241933424, 0.04516122608038131, 0.013634340994030936, 0.018936599299195223, 0.09271043105400167, 0.06277926644543186, 0.030687350008520298, 0.02498577636288246, 0.027625627189991064, 0.05055882160377223, 0.10776323426398449, 0.03283763013314456, 0.03659089357824996, 0.07437732027028687, 0.04407688895298634, 0.08874851278960705, 0.06561874572071247, 0.06276535117649473, 0.19054334348766133, 0.033230315311811864, 0.06019900451065041, 0.0362757479888387, 0.12272395179024898, 0.07459335203748196, 0.027004295588994864, 0.0466372279333882, 0.05943119336734526, 0.030617458251072094, 0.03763746652111877, 0.03792441792029422, 0.03259771976445336, 0.03530487039824948, 0.03582480421755463, 0.029137582387193106, 0.04435755065060221, 0.0067489801131159766, 0.0783748913090676, 0.018548379994172137, 0.0316497782478109, 0.044409616020857356, 0.03474962148175109, 0.058934184489771724, 0.022358488240570296, 0.05231613453361206, 0.021185646291996818, 0.04695243660535198, 0.03893363114912063, 0.046030919256736524, 0.06920221319887787, 0.046177716067177244, 0.03130291326669976, 0.03208292902854737, 0.019811906822724268, 0.053567332433885895, 0.03337245885632001, 0.015195524701994145, 0.06397027987986803, 0.04908427807094995, 0.027766193670686334, 0.0407562456530286, 0.026486063143238425, 0.008277077486127382, 0.044165089493617415, 0.009241453863069182, 0.0513384254736593, 0.02090184345433954, 0.04102245773538016, 0.021136942850716878, 0.010862589188036509, 0.05140400906384457, 0.02778502010187367, 0.05570119996264111, 0.0807587438612245, 0.0547719049063744, 0.0450148931122385, 0.03351726300024893, 0.04780245915753767, 0.04911457253911067, 0.06453606358263642, 0.09355354792205617, 0.02799967332975939, 0.06245520766242407, 0.031036736436362844, 0.034664508275454864, 0.016191474824154284, 0.048292272913386114, 0.08095158351352438, 0.0664442588458769, 0.023453827707271557, 0.14228220738004893, 0.1278958230977878, 0.16152444906765595, 0.15129704552236944, 0.18093748862156644, 0.24972999177407473, 0.09348378604045138, 0.11453130195150152, 0.15741554845590144, 0.08864204428391531, 0.11574387477594428, 0.10618625950883143, 0.11865822933032177, 0.15283887216355652, 0.11126331402920187, 0.1908274376182817, 0.270326430327259, 0.12429612484993413, 0.18788134882925078, 0.09633339563151821, 0.1031737113953568, 0.20499972713878378, 0.14804090227698907, 0.11991576146101579, 0.20399856992298737, 0.08223312412155792, 0.20048349135322496, 0.22834019735455513, 0.11390529296477325, 0.10939728017547168, 0.12134802484069951, 0.10032408696133643, 0.08415664473432116, 0.14308225741842762, 0.12289622653042898, 0.08153552756994031, 0.3219282254576683, 0.09504496047156863, 0.18878316215705127, 0.15532126708421856, 0.11914258459000848, 0.11314583840430714, 0.10235043955617584, 0.07396994056762196, 0.13453801511786878, 0.14444763102801517, 0.10269489255733788, 0.15430091792950407, 0.1242375248693861, 0.2977971750078723, 0.08645597408758476, 0.2868032961850986, 0.09591029724106193, 0.13770279998425394, 0.14187868684530258, 0.14676118735224009, 0.2802426216658205, 0.1734470366500318, 0.1042363110173028, 0.09546636676532216, 0.12127814421546645, 0.17624264757614583, 0.1430109073407948, 0.12447685265215114, 0.20088499324629083, 0.15949783672112972, 0.10911455159657635, 0.17849142925115302, 0.3336105204652995, 0.1459143523243256, 0.13604969572043046, 0.19360139267519116, 0.19225902564357966, 0.20040715404320508, 0.13271090690977871, 0.2432874820078723, 0.1557166239945218, 0.16628329292871058, 0.16730448813177645, 0.11953825320233591, 0.13425948709482327, 0.13448320009047166, 0.05472159471537452, 0.10999504302162677, 0.23352349031483755, 0.3780590509995818, 0.1876833735150285, 0.13102305529173464, 0.17700673313811421, 0.11385358011466451, 0.13944537757197395, 0.16177718003746122, 0.11006950269802473, 0.2722883422393352, 0.19044586981181055, 0.10426357010146603, 0.09715357271488756, 0.1832956777070649, 0.1259411100181751, 0.12119409599108621, 0.1929169098730199, 0.08276743334135972, 0.12949668016517535, 0.1875753910280764, 0.1945979188894853, 0.37179283099249005, 0.16434613906312734, 0.14954645273974165, 0.19079761812463403, 0.16395554674090818, 0.15844532288610935, 0.1037947776785586, 0.23871922167018056, 0.14117942046141252, 0.16558833100134507, 0.18803948565619066, 0.2297531723161228, 0.18530642293626443, 0.17920162004884332, 0.1762651198077947, 0.18702449480770156, 0.06759062467608601, 0.09891263340250589, 0.17973262671148404, 0.13718926347792149, 0.09167613694444299, 0.09651660962845199, 0.22137261810712516, 0.13328149972949177, 0.06697189615806565, 0.11445715397712775, 0.09094373366679065, 0.12548534228699282, 0.13932167639723048, 0.17587914364412427, 0.13125755911460146, 0.16343574650818482, 0.15653788461349905, 0.1443829305935651, 0.17690060602035373, 0.11054945702198893, 0.10198428615694866, 0.18199687474407256, 0.10508109771762975, 0.12154959957115352, 0.15097712050192058, 0.1216336849029176, 0.1043044550169725, 0.1152322233247105, 0.12389429641189054, 0.07469196862075478, 0.11448518489487469, 0.07609368520206772, 0.13767792319413275, 0.07219135397463106, 0.13598198216641322, 0.0810537401412148, 0.1991067035123706, 0.1623119568102993, 0.16604967968305573, 0.121353538997937, 0.16199514881009236, 0.1223546962137334, 0.13959996693301946, 0.10426625667605549, 0.16925973555771634, 0.13661751290783286, 0.18051764083793387, 0.14349756325827911, 0.11593296658247709, 0.2707787248073146, 0.19406305305892602, 0.15842426073504612, 0.16851567314006388, 0.13679887895705178, 0.1532622377271764], [0.03862337260216009, 0.028323535443632863, 0.05685912103217561, 0.008415449992753565, 0.037700615866924636, 0.02521643771615345, 0.038948351648286916, 0.0245154198637465, 0.007649727067473577, 0.012815670470445184, 0.055669046414550394, 0.06230344588402659, 0.022671351725875866, 0.0398134694842156, 0.038287758579826914, 0.05334781999408733, 0.036144525147392415, 0.07106134507921524, 0.07360229545156471, 0.036937728873454034, 0.01922968640428735, 0.014633548216806957, 0.03540216595865786, 0.028564228778122924, 0.06765839760191739, 0.05960603593848646, 0.012653395242523402, 0.08076439902652055, 0.05143359849171247, 0.03388077806448564, 0.0412204627355095, 0.036343457832117565, 0.022415214298234787, 0.026719557645265013, 0.033270996136707254, 0.027489892090670764, 0.04900351385003887, 0.046025297488085926, 0.05200515610340517, 0.042558221030049026, 0.04124977385799866, 0.02301917593285907, 0.07145156632759608, 0.024450953205814585, 0.10351783785154112, 0.07171571895014495, 0.04842634189117234, 0.03997277148300782, 0.006543931667692959, 0.05330826352292206, 0.0508134784467984, 0.03948407837015111, 0.06478174414951354, 0.04286437921109609, 0.04204484408546705, 0.015199066601780942, 0.03284918537246995, 0.07212641605292447, 0.014069536391616566, 0.1002771758066956, 0.04702596488641575, 0.02118055144819664, 0.004947636025462998, 0.017348907931591384, 0.0031774479930390953, 0.04948734960635193, 0.13277626043418422, 0.06058311788365245, 0.0707940234860871, 0.05430572113255039, 0.02221957860456314, 0.021413433678389993, 0.05212496100284625, 0.02217589208157733, 0.05051319436461199, 0.06639608604018576, 0.017289324605371803, 0.03435659491515253, 0.027516909976839088, 0.018224167215521447, 0.08301695081172511, 0.019876603546435945, 0.03600109768740367, 0.126691228360869, 0.01855320209870115, 0.020463195214688312, 0.01827001524361549, 0.016399624983023386, 0.04156730916292872, 0.03435917758906726, 0.03592782544728834, 0.06018999483785592, 0.018582344382593874, 0.06610779135371558, 0.04102916303963866, 0.024801215367915574, 0.016169926566362847, 0.0464465182449203, 0.061802481359336525, 0.004613718738255557, 0.06043461042281706, 0.04681123187765479, 0.10407562120235525, 0.02842937312379945, 0.027651817581499927, 0.03232272436434869, 0.012654020501940977, 0.017126063248724677, 0.011748167107725749, 0.05020211203373037, 0.06731250483426265, 0.012570359122037189, 0.03216127384803258, 0.024694284875295125, 0.03043488435650943, 0.06774804161977954, 0.03934580512577668, 0.05471125288750045, 0.03217907054931857, 0.03186768764862791, 0.005317456098055118, 0.011238011084060417, 0.029291542778082658, 0.036172893742332235, 0.004420998293426237, 0.011563565294636646, 0.03639515212853439, 0.008001849237189163, 0.042087524998351, 0.012618985565495677, 0.023585781564179342, 0.0826402886013966, 0.025077656100620516, 0.04649445727409329, 0.06507578305900097, 0.11045698542147875, 0.0366539835522417, 0.07580848527140915, 0.04468956896744203, 0.050293589156353846, 0.0342043989803642, 0.02859687214368023, 0.031726820598123595, 0.08842740033287555, 0.03647881072538439, 0.024310557419084944, 0.028534552147903014, 0.02845557093678508, 0.015142084503168007, 0.05792835174361244, 0.035453247983241454, 0.01679783916188171, 0.03757860678888392, 0.03636425652075559, 0.021233841362118255, 0.04951357710524462, 0.05194536497583613, 0.017332623356196564, 0.03872485016472638, 0.01473639689720585, 0.0704754565958865, 0.03142755325825419, 0.0605117752274964, 0.03530317459080834, 0.019919807673431933, 0.03423873815336265, 0.039084509771782905, 0.015133807701204205, 0.037411668090499006, 0.03721563349245116, 0.018316130444873124, 0.017736694935592823, 0.09567623128532432, 0.02753936922090361, 0.04632908821804449, 0.02834747156157391, 0.07028263920801692, 0.09746568292030133, 0.027435394331405405, 0.05445719347335398, 0.027610121869656723, 0.017848182214947883, 0.10393781922175549, 0.0794350789510645, 0.03391748839931097, 0.030852537238388322, 0.029559266986325383, 0.005131074058226659, 0.08437621654593386, 0.03446223221544642, 0.030159887101035565, 0.05296342831570655, 0.05734480102546513, 0.025491112137387972, 0.048328170596505515, 0.03943439158319961, 0.0020431197981451987, 0.035745205168495886, 0.04140267112234142, 0.04728502266516443, 0.03799167876422871, 0.020084198949916754, 0.011062405956181465, 0.03709045544383116, 0.031715699515189044, 0.03688345190312248, 0.0060679051603074186, 0.022683226088702213, 0.026091765648743603, 0.023746079896227457, 0.004260341411281843, 0.0802120407752227, 0.013197072221373674, 0.023688329674769193, 0.09103712553041987, 0.00849144777021138, 0.03643581811047625, 0.035653546219691634, 0.009590265126462327, 0.012074072910763789, 0.0422982429881813, 0.07072987224091776, 0.030578027945011854, 0.02046047338808421, 0.03314942121505737, 0.0782982051896397, 0.022278260221355595, 0.06097496072470676, 0.012468262793845497, 0.05957944849797059, 0.019690916342369746, 0.033649973847786896, 0.015888971720414702, 0.016830296990519855, 0.05898239811358508, 0.023043807814246975, 0.01835254948673537, 0.06044014313374646, 0.05862428959517274, 0.034186772973043844, 0.02972632628370775, 0.03248123226512689, 0.03127823685645126, 0.06794350105337799, 0.025758233350643422, 0.07495786529034376, 0.06456022048951127, 0.027399387181503698, 0.013757856631855248, 0.06458718271460384, 0.0699808522767853, 0.00580145419917244, 0.02724438778386684, 0.06086191307986155, 0.02274321945151314, 0.014210590834409231, 0.028238412960490678, 0.016076386273198295, 0.03418951149797067, 0.027175253017048817, 0.021669218585884664, 0.005036365810155985, 0.03280401826486923, 0.059844762581633404, 0.08511759238899685, 0.017390486755175516, 0.018239715209347196, 0.031940740955178626, 0.05948323647317011, 0.0849334878148511, 0.06881936147692613, 0.06167434585222509, 0.030197263513400685, 0.04343012951721903, 0.059135161791346036, 0.02406082843663171, 0.08780856791418046, 0.07307390857022256, 0.03593326167901978, 0.007074579316395102, 0.04794320746441372, 0.05325687350705266, 0.04590427546645515, 0.05306123595801182, 0.05844278995937202, 0.03236694523366168, 0.05000135366572067, 0.040472099572070874, 0.03788441616052296, 0.02349927497562021, 0.03181722160661593, 0.015235056125675328, 0.0238662688570912, 0.03657676679722499, 0.04721967285149731, 0.005511922909136047, 0.03486731126031373, 0.03466010733973235, 0.026397779110993724, 0.11418702706578188, 0.03637002671894152, 0.04981162732292432, 0.05153214457095601, 0.04534906736807898, 0.03957046435971279, 0.037119414046173915, 0.039598187286173925, 0.019493315812724177, 0.01937188189913286, 0.14556235168129206, 0.06101974562625401, 0.09764536429429427, 0.015222201200231211, 0.0659310637274757, 0.024835586082190275, 0.03918812843039632, 0.04883096451521851, 0.0065660611198836705, 0.023512279258284252, 0.06508914913865738, 0.026619100535754114, 0.05526422712136991, 0.023513898995588534, 0.044241345167392865, 0.04889855190413073, 0.028166534102638252, 0.014640079116361449, 0.04362249790574424, 0.038902813466847874, 0.025937580758181866, 0.0466740347474115, 0.0635435598087497, 0.025363364402437583, 0.0556627158948686, 0.01676244613918243, 0.050699807397904806, 0.040843147435225546, 0.06319394888123497, 0.024764701702224556, 0.07350402025622316, 0.039175226193037815, 0.020474871053011157, 0.027137807956023607, 0.039494112206739374, 0.009353174918942386, 0.05918222879699897, 0.042933614167850465, 0.013064132235740544, 0.07603877369547263, 0.003639400365500478, 0.06534538304549642, 0.044570688041858375, 0.13195949723012745, 0.21961789898341522, 0.1832332630874589, 0.16604188713245094, 0.12326540789217688, 0.11239645478781313, 0.18371136946370825, 0.17465370940044522, 0.14381293149199337, 0.12502494355430827, 0.10661672000424005, 0.13731651211855933, 0.1707649594754912, 0.1435092743486166, 0.1553889806382358, 0.16224623221205547, 0.16501754522323608, 0.3490609664004296, 0.13942260848125443, 0.23848850280046463, 0.14314842730527744, 0.09168023359961808, 0.11413967062253505, 0.16309976141201332, 0.10464857405168004, 0.12012629391392693, 0.14577583788195625, 0.17130061198258772, 0.142614170035813, 0.0661122368182987, 0.13630310946609825, 0.15690085419919342, 0.14607704593800008, 0.045656349902856164, 0.09654078137828037, 0.21518583758734167, 0.10291783371940255, 0.1054582349024713, 0.20318499795394018, 0.14407194103114307, 0.21423713536933064, 0.07540161765064113, 0.1139803092519287, 0.12197790783829987, 0.15473307052161545, 0.14614504150813445, 0.09363144374219701, 0.07175168342655525, 0.08355749407201074, 0.13030389935011044, 0.12296199565753341, 0.1835063289036043, 0.18639160611201078, 0.16170738846994936, 0.16670624288963154, 0.17526535782963037, 0.08459863078314811, 0.19658653327496722, 0.21880204119952396, 0.1510863794828765, 0.13120541581884027, 0.17878009501146153, 0.19868664792738855, 0.10779245261801407, 0.1762947760289535, 0.12282826806767844, 0.1841368872555904, 0.27250804763752967, 0.10638457621098496, 0.2481257208273746, 0.20465501438593492, 0.07052962595480494, 0.11824852670542896, 0.14451532973907888, 0.1073114963946864, 0.1690927820163779, 0.1442688624956645, 0.25870282435789704, 0.10862535011256114, 0.12013709216262214, 0.15860239102039486, 0.11739366163965315, 0.12526602280559018, 0.30335897812619805, 0.1240455980587285, 0.07946042329422198, 0.12428165297023952, 0.1049885073734913, 0.11587352797505446, 0.08856023734551854, 0.15741988259833306, 0.18477013218216598, 0.19176579429768026, 0.21011457924032584, 0.21719444543123245, 0.18254541093483567, 0.15409289393574, 0.12942227243911475, 0.14393001270946115, 0.07655055131181143, 0.16166333458386362, 0.22777665493777022, 0.2028492058161646, 0.07206519629107788, 0.1390022857231088, 0.22671345417620614, 0.09384199845953844, 0.1291809111717157, 0.11927439001738094, 0.1855243620229885, 0.1880779882776551, 0.1355070373392664, 0.11582368533709086, 0.11341237332089804, 0.12326915573794395, 0.18306999059859663, 0.12426949659129605, 0.13263548986287788, 0.160910410922952, 0.11371491724275984, 0.1860948806279339, 0.1113229752809275, 0.11630800348939374, 0.20484105596551672, 0.10113860887940973, 0.12942326691700146, 0.12887280114227906, 0.10627234863932244, 0.10864407449844293, 0.1545939178322442, 0.07352632179390639, 0.11738609173335135, 0.1190351290279068, 0.17722146614687517, 0.12762940692482516, 0.20961049769539386, 0.07262321712914854, 0.28501938097178936, 0.10856209686608054, 0.12080095810233615, 0.11905441744602285, 0.1613940388779156, 0.11043719234294258, 0.1878890671650879, 0.16525383020052686, 0.11460704554338008, 0.12601810041815042, 0.1144488641875796, 0.12508585903560743, 0.09429655649000779, 0.12680041312705725, 0.15119646966923028, 0.11632873909547925, 0.101754480128875, 0.17885297391330823, 0.14786403364269063, 0.19064706604694948, 0.25213849847204983, 0.11929053915082477, 0.14863666874589399, 0.14219316450180486, 0.09342755351099186, 0.19778357294853777, 0.12414336859364994, 0.08771289765718393, 0.1376180912484415, 0.1646826881915331, 0.08989657071651891, 0.10567785866442136, 0.12573008774779737, 0.17552251199958846, 0.0806524460494984, 0.13530331780202687, 0.10767022089567035, 0.12801942037185654, 0.12999810482142493], [0.023260175403265748, 0.017985826489166357, 0.013919847060606116, 0.020346676174085587, 0.019247653799538966, 0.02736301266850205, 0.06125164822151419, 0.01675110797805246, 0.09581948805134743, 0.008358199793292442, 0.05395342734118458, 0.023808314545021858, 0.07948990882141516, 0.04094788302609231, 0.07179598964285105, 0.08265317970653996, 0.023215000874188263, 0.023227904966915958, 0.027086792724730913, 0.017746923585946206, 0.06127043940068688, 0.03263499042077456, 0.06104846303060185, 0.07155609782785177, 0.0456053940433776, 0.03196792211383581, 0.07973630185006186, 0.07075261164573021, 0.018304387813259382, 0.041653275839053094, 0.05206675807130523, 0.05391802689700853, 0.02145234448107658, 0.011052469526475761, 0.026112252635357436, 0.016719071318220813, 0.05222142535785679, 0.006603182882827241, 0.08853649604134262, 0.013084549646009691, 0.012844035354646621, 0.03784252192417625, 0.03419874010432977, 0.0388583662424935, 0.04190789557469543, 0.04467740516702179, 0.03295678936410695, 0.04451291555596981, 0.05506933172000572, 0.06158339194371365, 0.020564411170198582, 0.0262204855971504, 0.055314492783509195, 0.026252622446918394, 0.05728310257836711, 0.06467741302913055, 0.0808631417748984, 0.05408093202277087, 0.023030367519822903, 0.0548898247507168, 0.05471131968079135, 0.024738249703659676, 0.007342430617427453, 0.03352352672663983, 0.06987482905969955, 0.022193100630829576, 0.019677247837535106, 0.043753327408921905, 0.11192286809091456, 0.047993606713134795, 0.06340893422020599, 0.0768021764815785, 0.00414881934375444, 0.018468944217602257, 0.07130180834792554, 0.011263142059760867, 0.08560475296690129, 0.03796455326664727, 0.017239381777471863, 0.05496888203197159, 0.023726314648229163, 0.04897508588328492, 0.07968697129399516, 0.03165368194459006, 0.023836555119487457, 0.06236920758965425, 0.032755047650425695, 0.01050790939189028, 0.05343843993614428, 0.021999147757014725, 0.019675065923365764, 0.05059049646661151, 0.04731677174277138, 0.051020289029111154, 0.027742764068534598, 0.062050106353126466, 0.008464771271974314, 0.08216870570322499, 0.011656148217298323, 0.046185315659386106, 0.0014651482911176572, 0.012055549832439283, 0.0524173560552299, 0.021913309101364575, 0.024081423034658656, 0.019753583292185795, 0.04380528145702556, 0.07650801882846281, 0.06631487281993032, 0.021710517248720862, 0.025441035722906236, 0.05312350585882086, 0.08357937258551829, 0.05654738561133854, 0.016929755911405664, 0.05465603338961955, 0.07053161491057836, 0.09029456225107424, 0.09064692654646933, 0.04502095274801832, 0.018083045979437884, 0.02750058272795286, 0.12935289647430182, 0.016755861433921382, 0.014708374328620266, 0.04285574432287831, 0.03411626894376241, 0.02938983467174694, 0.0488350834348239, 0.015059997404023306, 0.04421672441822011, 0.015820284097571857, 0.024841244958224706, 0.03884044708684087, 0.027843974457937293, 0.05273798982670996, 0.01125274364312645, 0.06521362214698456, 0.059479766932781786, 0.039652271298109554, 0.05094431537145283, 0.01449706447601784, 0.01877346781839151, 0.036900996274198405, 0.06024115107720718, 0.07772582379402593, 0.04548421988147311, 0.035311946776346304, 0.0070183101433940465, 0.017892202704388183, 0.030925195351301227, 0.068793274986092, 0.06931588053703308, 0.024751354176260065, 0.028930846019648015, 0.0582037924323231, 0.03114457977062557, 0.05185874892049469, 0.07449700642609969, 0.018421398526697885, 0.03521961989463307, 0.021971695714455564, 0.06661303064902313, 0.05288798529363703, 0.016330595972249284, 0.03273830108810216, 0.0468430329055991, 0.0336218204756733, 0.041475011967122555, 0.00749420770262077, 0.08082223459496163, 0.03697019783430733, 0.052515234201564454, 0.01801404850994004, 0.0669659515551757, 0.05401398659159895, 0.04758557763125282, 0.03765628738619853, 0.05661083552695345, 0.03165904025081545, 0.036826781506533735, 0.030203785136109218, 0.05871168861631304, 0.03668944707897026, 0.006792799758841284, 0.022728014700987842, 0.036126279446762055, 0.03169887502735946, 0.052224898608983494, 0.06513996399007738, 0.07103598589310423, 0.0679766973189544, 0.03312566135718953, 0.05120169589645229, 0.01546964529552497, 0.024743439171288628, 0.06563646078575402, 0.044704081665258855, 0.018387834898021538, 0.035851710781571455, 0.04170730047917459, 0.015311718125303742, 0.014815687027294189, 0.035856404865626246, 0.01513344126578886, 0.054533475122298114, 0.012350461693131365, 0.05324787496647332, 0.029137615783838555, 0.03480113395198714, 0.0537865257501835, 0.035063601899310015, 0.0507886684499681, 0.011560490020201541, 0.002736286423896672, 0.02628206530062016, 0.02634271175338654, 0.03891441323503386, 0.04330105148255825, 0.013356645104067866, 0.05578735959716141, 0.021060510916868225, 0.0206762175730546, 0.047952625318430364, 0.04258329820004292, 0.04327010392444208, 0.058071371022379026, 0.028817488528147805, 0.027475360839162022, 0.029698549551540054, 0.05502590865944512, 0.039804901389288716, 0.003840436806967773, 0.07002765210927464, 0.018491273585823365, 0.09292272239690647, 0.035120060783810914, 0.07180151864304207, 0.021064743013994303, 0.03371940918441396, 0.08591485195211135, 0.03463129345618654, 0.020462529137148522, 0.02426981536700623, 0.06697378121316433, 0.023194025925477035, 0.037390598517959006, 0.02836845764250029, 0.04629297531209886, 0.04430333305208478, 0.017939074896275997, 0.0388757844484644, 0.06522422743728384, 0.023251175007317215, 0.07473332108929753, 0.02535124327550875, 0.056238507459056564, 0.02893810236855643, 0.043811381910927594, 0.07193563957116567, 0.05238547710177954, 0.1046587414748501, 0.03514477801218163, 0.0014421877494896762, 0.006491224803539808, 0.026916004135273397, 0.021800098184030503, 0.07048960193060338, 0.005654428250636556, 0.0073335559227416525, 0.030349533662956674, 0.0155530979463947, 0.04198787682980765, 0.03813750336121302, 0.00892327938345261, 0.07755455837468617, 0.07162340320064686, 0.07433810518705286, 0.006157111311040353, 0.031067535564943682, 0.015669802523916587, 0.021320635532902088, 0.03636154768173583, 0.023573456346639432, 0.07639259260031395, 0.020053596490470227, 0.005744523123212275, 0.023365081688098144, 0.03181168147420976, 0.03406426665605977, 0.07074038105201907, 0.03562903679267038, 0.11135970416944474, 0.02158335024432745, 0.021087076092953794, 0.04514133652264718, 0.03716605802765116, 0.03411183090065606, 0.020842876110691577, 0.052019839495187625, 0.04910328447294887, 0.011293607221887214, 0.010370325417170534, 0.05411463665950578, 0.0210943342972314, 0.09629738662624732, 0.02779316702799406, 0.009974410040740622, 0.05710159552108962, 0.0668085939832963, 0.04465257661649957, 0.03148591204080731, 0.020966987322026398, 0.02076631430099951, 0.10480790573637933, 0.04540617563179694, 0.018184274922532495, 0.01815232175431447, 0.026064762605528813, 0.005771141641162103, 0.011554605716810329, 0.026203154593531508, 0.045135503241908737, 0.034388195563224144, 0.0325845429324545, 0.04128892956941854, 0.026142983115278184, 0.052158097896608524, 0.0671633702586405, 0.061080290033714846, 0.013056560474069556, 0.1237097688135691, 0.015419880583067425, 0.02229412548331311, 0.06465483689680696, 0.01605158184247557, 0.02240085002995329, 0.10668277856893837, 0.05821172228024807, 0.08932084965636022, 0.06463197874836624, 0.08068196126259863, 0.012348803920758655, 0.03285972015873995, 0.05121307673107367, 0.08223669385188259, 0.02969995406601811, 0.008915393136703642, 0.031003824042272754, 0.025796184927457944, 0.010595638668746687, 0.0796839284885209, 0.12869018828496337, 0.13493001752067357, 0.0918838863435667, 0.17967441264772788, 0.2843739796662703, 0.07826668617781252, 0.1571891934145242, 0.08653076773043722, 0.17338474077405408, 0.09463114634854719, 0.1353269032551907, 0.07594003094709478, 0.22052882588468492, 0.22996698506176472, 0.19265025621280074, 0.21520115551538765, 0.16751064191339538, 0.13450810656649992, 0.11836141478852369, 0.11311446782201529, 0.1432811381528154, 0.12697550060693175, 0.17794151266571134, 0.1586653696722351, 0.09350684456876479, 0.1801199238980189, 0.15618585428455845, 0.14414327626582235, 0.0803808867931366, 0.1513983338372782, 0.14428934577153996, 0.17458449670812115, 0.19182834250386804, 0.15391130524221808, 0.14549186249496415, 0.1119674785877578, 0.1275500564952381, 0.12593456427566707, 0.1822988991625607, 0.11053107402403839, 0.1260125936823897, 0.18001970427576452, 0.21752449334599078, 0.13067886204225942, 0.14865706296404824, 0.21192380168940872, 0.23662746360059828, 0.10903024362050928, 0.15385153266834095, 0.13544388057198375, 0.13901145866839215, 0.1788871720782481, 0.15688883140683174, 0.1689647466992028, 0.26394036831334233, 0.12957729224581271, 0.18233078182674944, 0.1485334211611189, 0.12438447010936216, 0.1990071963518858, 0.18139116349630058, 0.14274395682150498, 0.11933281188248657, 0.08518835616996512, 0.20512350252829492, 0.15862713422393426, 0.16407822375185788, 0.1262176936143078, 0.24594726506620646, 0.1495606277603656, 0.1700844248989597, 0.20777647267095745, 0.12220104938023724, 0.0817938543332275, 0.2052406282746233, 0.09679717855760828, 0.2699180709896609, 0.09037726718815975, 0.08438123346422799, 0.12046281335642561, 0.15131549531361088, 0.11908962493180297, 0.2860375482123345, 0.13649217900820076, 0.13373970170505345, 0.16482549224747345, 0.09104617973207496, 0.1017993874847889, 0.14465093496255577, 0.12997297570109367, 0.10214840469416231, 0.12379378735204227, 0.13284305372508243, 0.16517197131179273, 0.14096014550887048, 0.17777700821170583, 0.12287363555515185, 0.13811424665618688, 0.14992362703196704, 0.1491544206510298, 0.1769754887209274, 0.12363940579234622, 0.07951418447191827, 0.1504639847553335, 0.21621222782414407, 0.13809529220452532, 0.20911397121381015, 0.12332700614933856, 0.12348007410764694, 0.15095461858436465, 0.10707007575547323, 0.12425043823895976, 0.2179638744564727, 0.18533411988755688, 0.10641890796250664, 0.16935723891947418, 0.17816780833527446, 0.13908064167480916, 0.18602814670884982, 0.09904905498842709, 0.06782103926525451, 0.191313870891463, 0.1266625220887363, 0.08391442999709398, 0.1638979560812004, 0.1209692846168764, 0.11897330070496537, 0.1572832086822018, 0.10007925986428745, 0.14289660175563768, 0.21295544633176178, 0.2277657898957841, 0.15778564265929163, 0.12240303971339017, 0.14408906979952008, 0.1883553437073715, 0.08942348868004046, 0.17467481608036906, 0.1848249026807025, 0.13885755208320916, 0.06555364452651702, 0.10702978455810808, 0.07725314251729287, 0.161681754689198, 0.21180654235649854, 0.129123350197915, 0.17271625867579132, 0.11907436637557112, 0.09310857101809233, 0.23427568667102605, 0.14738288446096703, 0.22670564678264782, 0.2203685516724363, 0.12141363069531508, 0.09843729523709044, 0.20059594156919047, 0.15451103477971628, 0.11654250731226057, 0.16659615270327777, 0.09936094254953787, 0.10518036739085801, 0.11860199680086225, 0.17794860759750009, 0.14251791348215193, 0.1666559698060155, 0.1250114809954539, 0.06538387824548408, 0.10668622955563478, 0.10463467362569645, 0.26599190197885036, 0.2531572594307363, 0.18244026345200837, 0.12669079791521654, 0.1631797055597417, 0.13902756327297539, 0.22031342494301498], [0.060258613812038675, 0.025620308915677015, 0.013383800287556369, 0.017193583844345994, 0.060139072375022806, 0.017240190718439408, 0.09109252685448155, 0.010471613732079277, 0.026800386804097798, 0.011305798852845328, 0.03558671953214798, 0.05342556738469284, 0.11369100524461828, 0.06979814294027165, 0.08754958806093782, 0.029364514448388945, 0.05188073504541535, 0.03753125776711386, 0.0888282194500789, 0.010414938697067555, 0.028921663797518704, 0.020459237712202594, 0.06235597509657964, 0.022539412711921614, 0.08441884550848044, 0.016195460157177877, 0.03718622960150242, 0.03030740193935344, 0.013809875617880607, 0.04160997152212076, 0.023160035561886616, 0.0775249837897718, 0.03543036014889367, 0.04676296630350407, 0.012120356022933265, 0.10307453077984974, 0.05157462139322888, 0.0066790071832656395, 0.021376714066718705, 0.0136082554308814, 0.059457561874296516, 0.03978023240051698, 0.06215010704181623, 0.03497158300888259, 0.021685972569684964, 0.03189497641869821, 0.05872634232218843, 0.024010766865103506, 0.037338176916819066, 0.020993333564547356, 0.007428832841469557, 0.04335036348493304, 0.0764192950737197, 0.04691280591941904, 0.03992348545580171, 0.02975525705551263, 0.02401058874966111, 0.047201434572343715, 0.01265390268599731, 0.04650845789001323, 0.044026048126397654, 0.012994736789551098, 0.06038645617081784, 0.02836997347912984, 0.028762150286638644, 0.030324395265779458, 0.039732994700898416, 0.0765540542488452, 0.025670988325146027, 0.09135185551713221, 0.055302087785094045, 0.03524707193719223, 0.04591632794472389, 0.0352171336999163, 0.021306013368302956, 0.10821526899235323, 0.04987519969290588, 0.060755604135920294, 0.03589053623727523, 0.02549330332840327, 0.034989687701454386, 0.02166435937397182, 0.04340904139098711, 0.018472790397936478, 0.020603262601071037, 0.05256084288703278, 0.032713068067096174, 0.012691190968325827, 0.0295486839604564, 0.01107418569517904, 0.005363043446777738, 0.01977652864297852, 0.0487550539401127, 0.07229934388305992, 0.03471194635494612, 0.048639345695846714, 0.06316402548691258, 0.10574681160505861, 0.028715847693092655, 0.04875225233263336, 0.0722073027282022, 0.05605160127743147, 0.037619766299030744, 0.04308642979594879, 0.01380912697641179, 0.024875979324860964, 0.0570180742215598, 0.016492003815073986, 0.03423050031415187, 0.035439110070001334, 0.09598108328646049, 0.030266932626545895, 0.0860255210136529, 0.029291010287124664, 0.010961705793306464, 0.07313238238566555, 0.06610548327444121, 0.02802011393214343, 0.05767895301687531, 0.017491160942881834, 0.0303968678417732, 0.005501510577232693, 0.029281007991812658, 0.041105596828856505, 0.03566616273019463, 0.061231803192640655, 0.051809373835567385, 0.10728797773481347, 0.023377419893222395, 0.04018181592982728, 0.028386998346832115, 0.07361842232057825, 0.013653422538482118, 0.10195562441367656, 0.07140480360249057, 0.015580819017486647, 0.028950908126716968, 0.02705185797822196, 0.13496054947609082, 0.07907367529696785, 0.02659900132130133, 0.04366458881122526, 0.040725027211010456, 0.04909971103188582, 0.04686849228164647, 0.038953030889388174, 0.059474223089637235, 0.007182714871305507, 0.013638997970701894, 0.010172814872930758, 0.023575536215503234, 0.05238195932179224, 0.09798996572499163, 0.027052230907429475, 0.028173580794828013, 0.09175289727863856, 0.06605451257200912, 0.041343948687426746, 0.020452148346521426, 0.04279690685507376, 0.08474478934658691, 0.043859788493136875, 0.04799521717359312, 0.045465476941899396, 0.04260310612153262, 0.05889775617106352, 0.011816283276857575, 0.01689589913439704, 0.01852489102020627, 0.13267739152070135, 0.030042176913411822, 0.06820397262345068, 0.041316578281112015, 0.024343330660485663, 0.02634340009535663, 0.013959353436803212, 0.02035216435615439, 0.006233398989934358, 0.008235661007347517, 0.01652728551562177, 0.0923773403337691, 0.017308763308392372, 0.04565298426314257, 0.031867019715718925, 0.047537260106764734, 0.0372333522682311, 0.06636080433963798, 0.027260414462944027, 0.04653379481169395, 0.008427142529399134, 0.0515039281162899, 0.02894640143495053, 0.02328844195290003, 0.028696817171294242, 0.12596552667673677, 0.018877092043112498, 0.037246106076054275, 0.01007553786621429, 0.055922571482369676, 0.033984352194238454, 0.0336145400069654, 0.036601754909497686, 0.011126068311568815, 0.032625680178171024, 0.019017211379832588, 0.10918950851191767, 0.02696383926377166, 0.024166569637600332, 0.0298263956210576, 0.028577388911799062, 0.03843544596747961, 0.04732488341687713, 0.11249595452682115, 0.010242737243970623, 0.025464643440500367, 0.050598589587025344, 0.013105831658322131, 0.05970157631963957, 0.01764786913554417, 0.014136373283690773, 0.041341777905472554, 0.020134781880187802, 0.052215328614693135, 0.016195885036722757, 0.030514949103235267, 0.03712292811542284, 0.06819333022576757, 0.03275706258136779, 0.04920870283967815, 0.07031594679574482, 0.03540011020959355, 0.009530427614663495, 0.032703531469451264, 0.042424927596584894, 0.06308860101853497, 0.006893128384035663, 0.033619620007812046, 0.017068695233319886, 0.03864526966935955, 0.08145723099005409, 0.06147159110696521, 0.04266412179276813, 0.06118942656030413, 0.07320621123653837, 0.025997709562943783, 0.04067948160809465, 0.03589654392271768, 0.04258832996129058, 0.08797123184194788, 0.03337601745442953, 0.049081921752076596, 0.058984672796214, 0.06807058642152697, 0.061377316087600775, 0.034168126512668096, 0.042374873446533456, 0.011236475766054355, 0.0625171918363776, 0.021092508613946848, 0.04923139400489163, 0.04455236812646035, 0.026464342336112168, 0.01723127752484288, 0.054077844688436016, 0.02220939077233197, 0.03872879096888937, 0.034159254137193784, 0.060263812556513585, 0.026778617757372558, 0.03205646775313653, 0.03951466969738249, 0.042692761271609925, 0.02099827070196625, 0.11798498264397494, 0.059890345291933045, 0.026713559236668516, 0.09266763881896622, 0.023275339335668832, 0.0661778352514375, 0.07977659304742701, 0.032578698519500904, 0.02050078684987966, 0.021092675597174093, 0.021411598718259484, 0.05326641752617434, 0.04738830364658497, 0.06335391881293617, 0.046289067904581316, 0.02696289673622232, 0.03967490680224728, 0.04723213722172659, 0.01991991714021424, 0.02675450909009669, 0.013983266362629365, 0.04764365810842719, 0.038468527200166136, 0.012350453343970003, 0.022427958829212002, 0.05107077733555343, 0.033977962302742526, 0.03575551731046289, 0.010556373490544502, 0.03964683506637812, 0.0771381393133197, 0.03340457158628851, 0.09092851221794263, 0.044631336349993944, 0.07591684625367634, 0.0819460762431845, 0.009068553863471607, 0.08177372728823684, 0.054649869853165, 0.024692371989658568, 0.037516014053835534, 0.08040017521125264, 0.017712643784761894, 0.03195297525962815, 0.05789260991150513, 0.024947127167251892, 0.060559369157999754, 0.08197806280804798, 0.03106655593001051, 0.046798659896012396, 0.04978372628102079, 0.0626613391796127, 0.048359556021750905, 0.05198741135245655, 0.0365062739001587, 0.05184680034290068, 0.035940464222221635, 0.02564869420893956, 0.009868430424830876, 0.03148858748318162, 0.015492945021833293, 0.027111997915199026, 0.01710435542918276, 0.02401688772806665, 0.023876599552750122, 0.02780800627078861, 0.059558063512668014, 0.05879400021512993, 0.06432435111491941, 0.04911422744044103, 0.04930888535454869, 0.039817729411879554, 0.08071992953773588, 0.03569076492567547, 0.014654432252427796, 0.03439260020968504, 0.01866012145910645, 0.026488493676879443, 0.02420862529106671, 0.1301145477918908, 0.1339374840608798, 0.1043737048166804, 0.09314870636444539, 0.2203278968227096, 0.11177862426848151, 0.1475116322399117, 0.11193882426596247, 0.15106396662304178, 0.07128042707336135, 0.12250678453710862, 0.1671270257793367, 0.22708752629114315, 0.1476211880799383, 0.20930351573042572, 0.15640340745449066, 0.2542042813729495, 0.09460695975576527, 0.22826483967946842, 0.1309161860262975, 0.2152113674674183, 0.13392929075052962, 0.13727144891163334, 0.12922542518936098, 0.18399709631921723, 0.10704675005399622, 0.12439998099580407, 0.08381311199627817, 0.11684596407576464, 0.1500382591621019, 0.09953178494470194, 0.14506502368021756, 0.09986150631448254, 0.24360320647247136, 0.10265329518006183, 0.2174517183448188, 0.27394793287385255, 0.2816293097566813, 0.1445813215104863, 0.18852400418836623, 0.11621411438682117, 0.10011836362536997, 0.0819290810613893, 0.19275224214652553, 0.1079908806423191, 0.15921938291285187, 0.1042598148342222, 0.06463304001954384, 0.17769206198863685, 0.14094313548412174, 0.12592801853315905, 0.17597658763406798, 0.12076014740159735, 0.1456579106161371, 0.12801073724403977, 0.20879325951682404, 0.12590021768119186, 0.13774848659522831, 0.1652872416889295, 0.12479219119995832, 0.19627146190032363, 0.09674231157987379, 0.11052256901166402, 0.1913040893850848, 0.16815546434372663, 0.11107647093012929, 0.16124025103636086, 0.15059921890497208, 0.0768193720432464, 0.16776708362158388, 0.13120783522026613, 0.10722502134740353, 0.24011678964598104, 0.15405108133563772, 0.13754858169704676, 0.3016632894286886, 0.1991387939779088, 0.17512148508103564, 0.1527724796324037, 0.14433417149120942, 0.13883785548387095, 0.21888281655265018, 0.1566924442886375, 0.1498519058804959, 0.12608628894668072, 0.18558679148554802, 0.18153236451325938, 0.09622156881960109, 0.09680034010671079, 0.11492052872199565, 0.12947187758982182, 0.13483018381521106, 0.06309326912742108, 0.13373302237596363, 0.11560116719920188, 0.12181201556813903, 0.24505734094418585, 0.194748085050378, 0.1230215084797237, 0.1039287872845307, 0.23132729722419754, 0.155932366324123, 0.1292404462583363, 0.12153817791840993, 0.1047580037266016, 0.15736955014290288, 0.13392945402301848, 0.06443513892008923, 0.19408288324484602, 0.14193455572240055, 0.10427385626826435, 0.12179611134342849, 0.11879031677381136, 0.11576383854844607, 0.1327203173423186, 0.1608049517381005, 0.15418782946653664, 0.08990045957034454, 0.16953750659013167, 0.17164400371257216, 0.18477918638382107, 0.1736798186902888, 0.2313609461998567, 0.10013691731728613, 0.10283379291649908, 0.27169216016773134, 0.13034914067247882, 0.20202493207762018, 0.1680684252642095, 0.21962597355013713, 0.22217249003006145, 0.21947185916360468, 0.18899583199527115, 0.1715441106352955, 0.22984283859841526, 0.15168365993304178, 0.12688513670582324, 0.0722663702617865, 0.2196989266667515, 0.2272369503043592, 0.14906580821843818, 0.15939767647068948, 0.12499916134402156, 0.17046844179276377, 0.19731066160602495, 0.11999538648524322, 0.1559654067386873, 0.12801182077964768, 0.1557648932794109, 0.1246888842433691, 0.13065425242530182, 0.16810964414617047, 0.12954206991707906, 0.11967886792263016, 0.06551791753736325, 0.1520824752515182, 0.20137089217314497, 0.16966647701337934, 0.07990016063558869, 0.16212312475545332, 0.17313612130237743, 0.15295976802008227, 0.10550019593210891, 0.09683515425422229, 0.12875916349003091, 0.13226667215349153, 0.1539973498438485, 0.1857487132656388, 0.1607970701297745, 0.1940306805772707, 0.1399967636098154, 0.14964288740884513, 0.1757414752501063, 0.10355290432926267, 0.11667351122014225, 0.10627079755067825], [0.04488762220717035, 0.03621092138928361, 0.016441541483800393, 0.0337353802024154, 0.05119139859743882, 0.07693536230362952, 0.008801203512120992, 0.021865692906430922, 0.010899505468842108, 0.047854658114374615, 0.04636372425011359, 0.04506763012614101, 0.06314583544735797, 0.03832167472864967, 0.05906194150156807, 0.04292533551051747, 0.11441206108429469, 0.027245955570833758, 0.014307764868135564, 0.0353177689248696, 0.05399994886829518, 0.005274575269140769, 0.037070447142468765, 0.04858644169871695, 0.06429801971535198, 0.03783553831453901, 0.030117026217340026, 0.009825928555073915, 0.02048241312877508, 0.022058501017454546, 0.07579500786960125, 0.05880574470211286, 0.027060977117798757, 0.038906772824702784, 0.010226771792076761, 0.027351657809049357, 0.04097419216122944, 0.03267964544647839, 0.039602651304448955, 0.030129679835226852, 0.026588839464238845, 0.061118447556509636, 0.05785217399534304, 0.0392674974136753, 0.03215317330614198, 0.013727677196584409, 0.03366187789652031, 0.03567448591638822, 0.0642104611324612, 0.05061509495135397, 0.06810842853155918, 0.08646467205835506, 0.04140962133533321, 0.014782025064050686, 0.060202166059752926, 0.017549423246236984, 0.08602359142969362, 0.009234486024070065, 0.007118753801478306, 0.022213364973140415, 0.029837373840564396, 0.054670234385412186, 0.04905839938146528, 0.017501471229479648, 0.041920708754332736, 0.035750700772041455, 0.028463942362577654, 0.044253590604057536, 0.0059209919254499255, 0.019349732501723338, 0.06069078495784197, 0.05463915324071422, 0.07079474336933345, 0.024179585052479524, 0.0801268793293275, 0.03813175171671901, 0.028394976434356067, 0.03773866206756793, 0.10656077691237442, 0.03734289697604254, 0.004658077368731028, 0.05058845927123912, 0.02070973852823954, 0.05664584634359926, 0.0686555472202599, 0.042902009809040464, 0.014555825873685535, 0.023791911225998774, 0.07619123309268616, 0.02301371187058976, 0.07874808768974617, 0.032879145874176174, 0.052120400505373254, 0.054183177708182484, 0.042475753580220044, 0.032779961547930725, 0.05190187141124625, 0.015063282335177064, 0.049983156204689294, 0.043842644881806336, 0.04435962866409682, 0.037952508209855296, 0.03030334981303895, 0.045539572965935804, 0.029787128587486222, 0.03532486385665834, 0.023428028798662126, 0.041837725511868484, 0.01049375385264284, 0.035030550352530554, 0.03133536367386114, 0.012868670946772909, 0.09357709626783617, 0.06679212572635151, 0.029237111812108196, 0.06537598921568133, 0.029335733961488586, 0.04967732456861995, 0.023667414097872097, 0.06516060311696492, 0.01520413732578163, 0.01629607126233168, 0.03436022401729133, 0.049459678630228154, 0.04975726129487157, 0.07206212379969656, 0.05556075964705087, 0.03633898639236577, 0.021355199205572717, 0.049910459129023366, 0.007582055259263143, 0.037597379414364696, 0.043599932905635796, 0.05996041887556203, 0.09348731866339222, 0.0393482133949874, 0.10832417174242437, 0.02115197690727655, 0.020696441097243223, 0.025011827601701953, 0.015466541262867395, 0.02105063664203044, 0.05035449350543786, 0.017297336089541204, 0.054157187696546316, 0.018112112193193752, 0.04760679563332815, 0.12872385210357606, 0.020909845661662985, 0.03898440518241841, 0.03340094619488809, 0.012980106275790604, 0.02402139813057147, 0.03362739400472492, 0.054817123964312486, 0.03318873277748935, 0.01887809394247597, 0.015356609710579505, 0.028539316735987086, 0.013519580843421863, 0.03914321365300566, 0.03086435408476973, 0.01340704064205056, 0.028763528825948015, 0.07909218446002342, 0.05065874807769433, 0.023130114022933412, 0.02089336070639547, 0.03801379476499278, 0.03313557645014953, 0.047895004972815514, 0.04917878315609414, 0.050052216756739654, 0.020545781408145558, 0.03807221291936003, 0.03266229403379839, 0.05724293754610699, 0.044812561391154304, 0.046253218461060897, 0.014373624908330385, 0.017168536360259168, 0.041486830668873154, 0.03856045332213398, 0.01769882313965354, 0.022755696809326764, 0.044712252711178735, 0.01541111303595244, 0.056688263794058, 0.01048066515068058, 0.05392865074099973, 0.06050761177903041, 0.03177841841534246, 0.018894762579293456, 0.0669613057107199, 0.021483154741872568, 0.03852180969261099, 0.02169743132981239, 0.024959359616332222, 0.02274060152558377, 0.057539447807357647, 0.012864732925663702, 0.012202356847410556, 0.031684878122177906, 0.03561740362783894, 0.03636490961071104, 0.07825947250239551, 0.057101933198282495, 0.024659953123773448, 0.02488914873538306, 0.020907825164613314, 0.04325399931985885, 0.02920857623394113, 0.08570025995140895, 0.05557509794016369, 0.020906045865558553, 0.021968988730804995, 0.03246868996939156, 0.12972454918781295, 0.06575205770786852, 0.04981467754987534, 0.09473441619775258, 0.05843028848175891, 0.05642198862915393, 0.06483226214186288, 0.02208945414167829, 0.06063136490411125, 0.0684869015822187, 0.042403264305903576, 0.06634398727328517, 0.013304983276611893, 0.060595897666644305, 0.022211066170712, 0.0605057118809782, 0.04029717165394686, 0.03581728997232858, 0.009044959133461816, 0.08732927410164848, 0.019073506991844624, 0.027179384924238548, 0.08362218708498403, 0.10707456574891694, 0.04185368539765477, 0.0030299245736387093, 0.06136525989859365, 0.05477723723743111, 0.045079901537974365, 0.07115167187293991, 0.061711638772976585, 0.053779415975441225, 0.05337727954611182, 0.07226407702546567, 0.04878383442701306, 0.04877949657384306, 0.05241548213234637, 0.028745216332026757, 0.04412811198562849, 0.04271304787835106, 0.0035196497356082546, 0.021659420381183736, 0.08253796127974056, 0.029118063903297298, 0.06199615221703425, 0.029162010177969933, 0.05407885029853787, 0.016611135215498507, 0.022078269976191223, 0.01299064848353737, 0.017515774270577822, 0.065548115526326, 0.04133667935093399, 0.006341628240988939, 0.0341419880714966, 0.05946090896031819, 0.1135129269096069, 0.0343624430388445, 0.024304154540004674, 0.04984486069588456, 0.02243508344690781, 0.04537414453807287, 0.07923453580588102, 0.06300450084381737, 0.05069938437372912, 0.034479438909329474, 0.059197324080741964, 0.01908386551804142, 0.05920054129092023, 0.04278661326679867, 0.03725827729795128, 0.004046443318657111, 0.06350789219141006, 0.0809384771855548, 0.0406788062537089, 0.02377179902396165, 0.07036859475192614, 0.0044334668382362, 0.020298408744565677, 0.02687962776690256, 0.06209255720023066, 0.03074974792980356, 0.005042378597863717, 0.036279688793001696, 0.03957542561693117, 0.03651924664154649, 0.016667107993271202, 0.037510421971092, 0.05747539675212465, 0.07612840287038125, 0.051344306993996724, 0.02639606474986067, 0.031514967122348025, 0.0505116432759678, 0.05255553282040637, 0.0647041600313969, 0.011561967821762664, 0.040092309209285304, 0.02770886647340376, 0.04659674006688874, 0.011824839311884716, 0.030748111494176555, 0.030863099855196197, 0.08255005086539313, 0.04857374355196953, 0.02871090870030457, 0.09403647825820372, 0.056639115064172074, 0.016362656751880422, 0.01126507999288151, 0.004527153705566889, 0.03148072813928593, 0.026162019203184173, 0.007248635674841353, 0.014108852592471521, 0.023970358779479284, 0.051431041792966425, 0.04097207332961261, 0.0202051615997334, 0.025218888658855576, 0.03744100147741847, 0.03631985011452343, 0.12192047302960418, 0.010005247204389889, 0.02517335604352411, 0.031079003601917066, 0.0256066125803045, 0.04083207830262836, 0.06173907226184383, 0.05528194960788824, 0.032775612562545575, 0.0826109886111226, 0.05970536127279047, 0.02421223955025198, 0.027756106028391514, 0.10995242148055695, 0.15210205310722813, 0.11473226812086068, 0.13141801144229248, 0.15394082787679508, 0.10934541147435084, 0.1563771947985515, 0.09892506437608972, 0.05928158381721005, 0.12239220435731113, 0.11490135904750787, 0.13143162243068218, 0.13848088245140389, 0.1673111377749592, 0.15930474473861977, 0.1455246060504578, 0.16115484468173236, 0.2077642866061069, 0.14639355707913637, 0.1388511250843294, 0.09388738821144216, 0.1257024798542261, 0.1978898633387871, 0.10702681596740149, 0.09413363281055354, 0.10329350145184435, 0.08399525730055757, 0.10742785772890784, 0.23856675485149026, 0.1402792547014542, 0.23389872018015012, 0.18169652757933363, 0.1383021881338209, 0.22019420634023845, 0.1875350924092345, 0.12970017705811188, 0.12069523174432106, 0.13313443574588746, 0.12673047313001007, 0.08289313089335337, 0.09423375595360994, 0.3816820081556216, 0.15775662468513474, 0.20298700779676437, 0.2810304856393486, 0.11954573405091651, 0.20004028076073155, 0.16099875618238002, 0.18910976650658995, 0.1757792357238941, 0.17365614417940378, 0.1300540182273835, 0.15582003485178575, 0.09116884190007113, 0.11369608895620331, 0.13071789901005104, 0.21250433928798884, 0.14621961250668392, 0.21324721426935866, 0.11658538860501722, 0.1965486689005047, 0.09782684908714145, 0.20451503049116582, 0.15095763170393184, 0.15698321774834767, 0.13709695514990017, 0.07576829797471873, 0.19274819002021104, 0.1515057374490425, 0.11745051757316105, 0.1909473241539672, 0.1519541282323189, 0.2962574263801798, 0.18403129448415712, 0.2244942099787295, 0.11221743392525241, 0.09957914138794877, 0.14623038849094883, 0.14102708722930402, 0.08671366260387003, 0.07936537644127384, 0.13298553123604506, 0.10378546372521669, 0.13138074078597128, 0.12332915095612407, 0.10016923042712733, 0.06835746360593475, 0.14708474889630452, 0.19238737266277894, 0.09139536021393724, 0.27755120827350765, 0.08322852969286032, 0.15611569164320827, 0.15170711179962382, 0.16391596058383584, 0.07460906330379657, 0.1607080124085769, 0.16135642683366314, 0.11967061524046585, 0.16962420428171754, 0.09958613984053954, 0.1265868527116254, 0.12625367293367162, 0.19103396247373894, 0.08533349799108692, 0.149620741722174, 0.11322099569952115, 0.1951508634374477, 0.09021959791425616, 0.16507164778886363, 0.14508397813187912, 0.1139951596269384, 0.17175734450574964, 0.15869469934841618, 0.14411667769309133, 0.11950455227633938, 0.08594553233706392, 0.14861102012218907, 0.133652068907395, 0.1198521742480807, 0.16680448839906603, 0.19190315098967403, 0.10712532864999957, 0.13563342508859932, 0.160523722297512, 0.16025662334868684, 0.24909124011173844, 0.1660509264911525, 0.1657628099201247, 0.1392931630834937, 0.13228366733528674, 0.16026137309381738, 0.1372571848332882, 0.16872396430699155, 0.1914346925332211, 0.10263774718623608, 0.1915475880377926, 0.09397602290846407, 0.12300534450332634, 0.15889840404270217, 0.12614019855391234, 0.14461039885645732, 0.1740264758700505, 0.07505596979171969, 0.2079925563884899, 0.18061409034999087, 0.16777483164332807, 0.23455841524992138, 0.12516611488536, 0.1647543499711901, 0.11326726860716008, 0.074285665032221, 0.09722131595481187, 0.14793047070270404, 0.1318397294380702, 0.07643464268767275, 0.11703029871569015, 0.14542722143232822, 0.11382218726794235, 0.12132207935792394, 0.07995609630597755, 0.17191692109918222, 0.11305194930173457, 0.2552724693669006, 0.21722221659729257, 0.12375944817904383, 0.1936095711425878, 0.12409135146299377, 0.08113489398965612, 0.11209353237063624, 0.09063528967089951, 0.1116983090469148, 0.09830698894802481, 0.2884839044418186, 0.11657040464342572, 0.15551919786958024], [0.050124550180044025, 0.008224064949899912, 0.05812005962070543, 0.0688392213487532, 0.042450587352504954, 0.040218507710960694, 0.048211130197159946, 0.024538144425605424, 0.033627583252382465, 0.031035235442686826, 0.025983577215811238, 0.04365804677945562, 0.03712169243954122, 0.05637778260279447, 0.02581577948149061, 0.0430984229024034, 0.033920041387318633, 0.014867722711642273, 0.04083715830347501, 0.03442090572207235, 0.03878065967001021, 0.03994767575932201, 0.012411756597430212, 0.007822675306670135, 0.020488099835347384, 0.040429307337035425, 0.03543541046383325, 0.022092103608883917, 0.05244543150183745, 0.07250523049151525, 0.07851091955672018, 0.040527311648475006, 0.033196068907273, 0.05302376863255631, 0.018566083926998544, 0.07520897837821394, 0.0443442068353761, 0.10397157209808938, 0.04671238151786383, 0.011594506358960643, 0.04144316269957926, 0.04587759896821808, 0.04707826032245066, 0.0165584631395177, 0.019495881788316183, 0.021796784494654275, 0.027714540192391723, 0.026476697239559144, 0.0506565624527866, 0.09397934773005545, 0.019358231947990134, 0.03440077125560492, 0.039412717160303146, 0.06687387329293415, 0.03897535469150171, 0.04392317532619927, 0.024055037829384673, 0.011055918657802977, 0.07130483631044626, 0.0217416930172476, 0.04076144439750351, 0.1555726325022988, 0.05592522466031369, 0.03409172240935732, 0.016895900989766233, 0.030861953237035777, 0.03901552714523859, 0.07335324553423561, 0.040623096938361414, 0.019987218802270945, 0.06125858359155245, 0.04390510774101131, 0.043637630296871066, 0.0022423896962209255, 0.034941039921250194, 0.028720085356326308, 0.051330020651221275, 0.028270841103221755, 0.030065612081671134, 0.018062805756926537, 0.005198322378419107, 0.0029991372730364674, 0.034448810474714264, 0.021726658960687928, 0.06701625432469882, 0.006099041502238833, 0.04923691558360588, 0.039113794919103384, 0.01684596558334306, 0.016170028611668386, 0.03241748177970294, 0.013066283536318224, 0.036410740940482356, 0.03297063783975318, 0.06805889017414302, 0.04579248205118347, 0.10753051159554161, 0.04312908473366406, 0.048220677927020006, 0.05634323191770818, 0.027238079528615344, 0.02549081156757893, 0.01872684239060618, 0.03245940570195671, 0.003727218931999232, 0.026786267444549594, 0.020449946023290977, 0.043566695821937174, 0.06488315120805055, 0.006252428584048175, 0.029397129983408377, 0.07965065058670007, 0.04879338957834989, 0.03188672002579551, 0.02624350516271079, 0.029563975913333707, 0.038366689695976675, 0.00939443925744854, 0.028955585512449034, 0.025263560382882133, 0.03216833167243749, 0.02632097795867594, 0.055345926448353566, 0.0641214256756939, 0.011706541899911826, 0.024343171098735183, 0.017649422079557553, 0.1399910490727052, 0.07387029982055537, 0.02955925214337185, 0.09806009868043475, 0.07846637585316785, 0.058733440964715555, 0.045591927773784846, 0.010643300320225535, 0.015770152022014372, 0.04087002431333531, 0.02562229044997366, 0.020284007368900348, 0.05921446027059574, 0.05142919013451319, 0.06843340015620925, 0.05794479773612693, 0.03980211462476291, 0.0633976238896139, 0.01954007297172211, 0.09372908811201341, 0.021769766608485952, 0.11625183033174835, 0.04400121957587544, 0.04273359052604064, 0.13863706000847742, 0.028105781893827952, 0.05001185505534522, 0.05495524135767482, 0.022871136025059968, 0.029974956887599546, 0.01017736238281941, 0.026185756796621718, 0.043374835804570466, 0.06727840314852074, 0.059918736151303165, 0.02570136814028956, 0.03335504807182588, 0.01139244923251681, 0.04757128015626222, 0.03291112501756288, 0.03710835604579188, 0.022687601049256045, 0.05818085264763795, 0.0413736160408007, 0.013589025456894888, 0.045373636166914366, 0.055412485962733626, 0.028461246511142235, 0.01776647175574908, 0.012679937226494076, 0.020403084963618312, 0.04726009392470587, 0.09350987253128551, 0.04106320164282806, 0.08787916842265986, 0.026965683500748128, 0.027693954871210735, 0.020407652882568073, 0.050027993056573905, 0.07575818250188604, 0.014862674252071884, 0.09295263094827533, 0.03565211016393732, 0.0293857046199264, 0.042262512288289145, 0.02424347654596204, 0.01443096973162028, 0.008115799519146094, 0.027924386158701964, 0.04767599719343707, 0.03509051959554199, 0.023762629789416678, 0.04443940211785957, 0.039932728905114345, 0.03331976637127809, 0.12507690873462707, 0.07015784707618877, 0.010058194802695652, 0.015792345948284492, 0.03638786052761134, 0.04059806429722812, 0.044718115677824244, 0.07675079017644748, 0.05703504342818633, 0.04582628687785473, 0.02823404356604442, 0.038550233948626556, 0.0600765946728643, 0.007216377762233606, 0.006407619084711769, 0.05319858893926721, 0.01171631691249786, 0.02997497358592227, 0.04712089299573563, 0.025063781649805605, 0.09345768470666371, 0.03127263735223096, 0.07418134133331478, 0.004856093964917818, 0.04461119075131137, 0.06726656589307822, 0.06782223412301391, 0.01988603067729855, 0.023581974346598145, 0.02263063935970422, 0.06034905192791484, 0.061075113553670235, 0.008510719490004703, 0.008077715283434372, 0.08942117317928933, 0.03779630838835146, 0.03656548615253996, 0.047209056428982876, 0.01713332145300228, 0.01219289446453331, 0.059618414961732924, 0.03691684112709481, 0.02634448177559534, 0.06484059646027163, 0.03943504096241668, 0.049630264984443784, 0.015278024620783981, 0.1281186455162242, 0.038373539719032124, 0.043845969703397714, 0.02602583324915031, 0.05305171049258206, 0.014529197615047451, 0.04748250816192012, 0.04048540627991315, 0.0408906077791471, 0.012053081263729837, 0.016845227146404795, 0.05395945729105733, 0.03191973446519114, 0.07191828815848567, 0.047310226000263356, 0.02399517805315554, 0.026189037089352496, 0.04120141551538836, 0.03427767122047953, 0.04512974788667634, 0.032415181121905334, 0.029895047991885804, 0.003986963429269963, 0.06371764538926072, 0.032656746479915455, 0.03278924210462719, 0.0321411727782106, 0.07376278488663957, 0.041732655954547226, 0.04283335743821226, 0.0546152560855262, 0.00871127098434954, 0.05901139011257328, 0.019411469911574386, 0.04510891580139287, 0.04180944597464986, 0.0476650134078227, 0.02195225144532742, 0.053856658705626614, 0.026103849668288603, 0.04503559161094017, 0.029393009208433796, 0.010369105511927046, 0.07682069306611083, 0.01614935608813539, 0.032765133437351324, 0.03649197271442972, 0.03651765473478008, 0.03241955979319755, 0.025989521818701178, 0.02291203949425835, 0.11028592038201168, 0.01982507066713879, 0.09478228472289629, 0.02616482823214028, 0.016930924793996383, 0.0336943468573736, 0.08766086568357423, 0.03437551968090702, 0.03332391868752893, 0.03994333419541363, 0.0306327502039494, 0.06384704625816084, 0.06090705421229359, 0.023310917895287275, 0.03127409567241557, 0.015996436559362337, 0.01606584406545153, 0.02665846775926184, 0.11685622797813267, 0.009414928099431563, 0.04084813466761261, 0.01010686113659176, 0.018066421871480998, 0.0714781203714665, 0.03916058733011596, 0.024597610863565933, 0.02473447773809312, 0.0110535233761766, 0.05844665283802897, 0.032449943319079466, 0.0613870048255194, 0.028945037738594692, 0.05406676442362368, 0.037620445364154875, 0.06538747766171582, 0.016710043091734406, 0.03755158148123883, 0.041856717070913874, 0.08771362496190704, 0.0032882858931770897, 0.014859113798593171, 0.04107198867131956, 0.051206345451646484, 0.0757747917668894, 0.004975856654709787, 0.04615270940121263, 0.03199692895577755, 0.011992590661975555, 0.0241423867555568, 0.012667062819673447, 0.0423255985515425, 0.023862431953602936, 0.18034532899037004, 0.10292955965269357, 0.20952328050043434, 0.13712334592128173, 0.14049287448870018, 0.16615092346910387, 0.09382341508171521, 0.1322938347584568, 0.15417249669553712, 0.11366649952833541, 0.15274706849595532, 0.09354261608677916, 0.23056998004904017, 0.17044978420017287, 0.09818675360293128, 0.1304353040177375, 0.16248787549557164, 0.07919262672658078, 0.10826534169609658, 0.14173994975863025, 0.173437655903399, 0.16360684123355895, 0.08577302753110416, 0.10581446578726172, 0.16439893544884399, 0.08557403547456488, 0.2205344513640739, 0.20202732179313898, 0.06550659978529438, 0.15663378493627533, 0.18939771980512887, 0.20636199857108295, 0.11635569389909506, 0.16355852741980925, 0.10366077549406327, 0.16494956449605525, 0.18252348789246753, 0.21694089809898287, 0.12937864899868146, 0.1006325012713205, 0.11546110166818835, 0.255414160201326, 0.11804265493992716, 0.17246556119062006, 0.1528718086774461, 0.08458316442556679, 0.24555741489166394, 0.12359658387140371, 0.13181523856474087, 0.13644111924804747, 0.08670131326653063, 0.17018670769175515, 0.2701074967626482, 0.08603136171586812, 0.1431338960537687, 0.11436817789217457, 0.09618397903977893, 0.18692176672630012, 0.09305697691161186, 0.12178689386928454, 0.15566410962492228, 0.2576100267469883, 0.106425156845944, 0.11585130807361566, 0.09934192872606218, 0.12716618803096935, 0.12574743916047737, 0.11092808592366055, 0.12587050208821893, 0.11852243114844896, 0.155307047534734, 0.10634299367666245, 0.11241997344768606, 0.19466193654807284, 0.15625530446413904, 0.2046196287847124, 0.11309177294606343, 0.11288950801827013, 0.11787834344431758, 0.12466406682506204, 0.12025083371554501, 0.10285535230650567, 0.16487816988956183, 0.10825808349181898, 0.2074740029638633, 0.10309679521014914, 0.1841717681963928, 0.13074688729830086, 0.11448473218479194, 0.12386838061502203, 0.11994941043667495, 0.12792369816452265, 0.09010445370222442, 0.12022593466099352, 0.12254872330231592, 0.09209423325955868, 0.13053595408564433, 0.10741276244516484, 0.11136714048916474, 0.14725470071425661, 0.1960009045433253, 0.14348898403113708, 0.23144918755861, 0.12977280362974852, 0.1487292442470789, 0.10304077790351585, 0.0942144452710636, 0.10157879150938243, 0.15234463149681687, 0.1471538280020468, 0.09066513142897747, 0.24161963869119063, 0.09012049151351675, 0.10474383612745441, 0.1176343772385735, 0.1790376944700256, 0.13184732903027907, 0.0852735027729068, 0.16628063604002818, 0.07378509384579957, 0.13134773005731404, 0.1281187345739454, 0.15390008396934718, 0.08373925345949829, 0.1308158625033684, 0.15230593591695651, 0.14696653961436823, 0.19930806301999837, 0.14111323573160917, 0.1261499206884764, 0.12844955432228744, 0.1285540487151593, 0.20995224185753614, 0.2186047931900248, 0.07788140763295814, 0.17311928939307109, 0.19565028429497033, 0.2265673252986744, 0.12867414305219427, 0.15447308134753257, 0.15548703318927437, 0.1136233436409384, 0.18535344541305676, 0.08963470390881412, 0.11736099972040392, 0.08359363666386344, 0.12174875490018167, 0.18136159633286297, 0.12299076130148023, 0.10433336909045465, 0.13204557151766494, 0.20257980620954186, 0.13385422993451357, 0.1332245918456465, 0.12116049154428765, 0.10881295762374066, 0.24233178875874728, 0.12740425416268408, 0.14215625007636845, 0.11796754959505051, 0.18077763001201674, 0.26009832916315645, 0.1155225514958147, 0.13417850394034758, 0.0883363610773813, 0.15452998923137784, 0.133669197675772, 0.15948401793139055, 0.09147765696980059, 0.16991126700304449, 0.13668273284565657, 0.09151152858976275, 0.1427186792716384, 0.1056640621391125, 0.09570307476678863, 0.09926605896907859]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.049263376859016716, 0.06583750116988085, 0.015271601332642604, 0.0966722379962448, 0.04842029338760767, 0.014211181769496761, 0.040143847654690035, 0.05566537278355099, 0.04873081539699342, 0.10177113392273895, 0.03521610953612253, 0.07808339054463431, 0.0366930687596323, 0.06862059206468984, 0.022744466259609908, 0.03365774784469977, 0.02084923817164963, 0.0745199758966919, 0.0627555102983024, 0.037240688398014754, 0.008231209048972232, 0.01632828418223653, 0.0752562606066931, 0.012380193984427024, 0.026776317099574953, 0.04941660808981396, 0.01145238044045982, 0.006554077754117316, 0.0504130229819566, 0.007707147033215733, 0.057452609107713215, 0.07575166644528508, 0.04826651296752971, 0.051350058638490736, 0.04362171865068376, 0.02484005381120369, 0.016693944053258747, 0.058434381426195614, 0.010377999224147061, 0.04856581741478294, 0.04016607868834399, 0.04851600075198803, 0.020971709236619063, 0.03345280376379378, 0.024241535829787608, 0.015956852257659193, 0.018698115709412377, 0.009062719655048568, 0.024861930469342042, 0.03150130418362096, 0.03745133217307739, 0.029725459826295264, 0.009635691985749872, 0.031006627505121287, 0.03935344182536937, 0.048361864101025276, 0.059630946125253104, 0.029668921160919126, 0.029675767473236192, 0.01780410235369345, 0.023280462010006886, 0.021436258430185262, 0.01682246362179285, 0.015288142876670463, 0.06022300927725155, 0.07194474572315812, 0.04768194550706539, 0.045892085690866224, 0.06407510081771761, 0.03610637133533601, 0.03652532112027984, 0.05911389926041011, 0.03125082192127593, 0.046941694017732516, 0.013346330179047072, 0.07182712273788638, 0.02361567527259467, 0.022089854901423678, 0.027204085454286542, 0.030377442126336973, 0.0270714358339319, 0.05094243402709253, 0.02370179965510033, 0.032211717625614256, 0.018825423721864354, 0.05838025659613777, 0.032441163712064736, 0.03553103990270756, 0.025603118920116685, 0.008803601576801157, 0.035061535018030554, 0.0721922742377501, 0.025080940104089677, 0.04620671177690383, 0.013687663376913406, 0.009008427841763478, 0.017737179186951835, 0.03384972660569474, 0.006182191264088033, 0.048818622599355876, 0.027682227082550526, 0.05764508881838992, 0.018685740396904293, 0.012055085062456783, 0.030429192083829548, 0.0384582002152456, 0.05984659197565634, 0.05509298396646045, 0.04508966077992227, 0.030657001734653022, 0.012253745007910766, 0.03602761833462864, 0.03309911102405749, 0.036348634312162176, 0.06692298120469786, 0.05318724150129128, 0.07681336806854233, 0.06451307926909067, 0.06544802206917666, 0.033492308284621686, 0.013724344953516265, 0.04261798989318777, 0.00444226639046974, 0.008123250681819627, 0.025743729929672554, 0.06081715415348299, 0.028895478972117417, 0.037550902416114695, 0.051701398770092055, 0.04904714471194893, 0.04159109870670363, 0.054815962503198534, 0.05625182900985237, 0.02715010163228726, 0.08365196947124787, 0.033680554042803124, 0.0776278751436621, 0.03391207072127145, 0.026058751209347975, 0.019544841270544566, 0.007984440308064222, 0.13142831245204434, 0.03693514991027769, 0.005778035265393555, 0.03573739406419918, 0.015837290411582217, 0.0474014656356303, 0.06760833974112757, 0.014187903379934141, 0.05677920657035429, 0.02937538876722101, 0.04786761972354725, 0.0897317768249195, 0.06320474712993018, 0.04813625491806306, 0.02729910076595843, 0.027330955599609297, 0.02409532531601144, 0.04015251965029165, 0.058735025450005196, 0.035091406462015584, 0.08054213321884163, 0.030475099483737722, 0.1359243766637519, 0.031739685728098266, 0.01662850147113204, 0.04547940334305167, 0.03135324572212994, 0.05047773454862181, 0.02375937361648539, 0.04028611736430321, 0.05862517275090795, 0.0967159504943993, 0.05090195358206984, 0.04279566004697699, 0.019413831796555314, 0.04593025063513778, 0.027739259276131634, 0.032042081220424734, 0.08146220337948762, 0.016535977920284495, 0.028893055859953165, 0.029855955363018438, 0.02758364204055397, 0.03316255722893402, 0.08100720006041229, 0.055072697359719314, 0.03725989517988637, 0.03229393274523318, 0.046032229147385806, 0.08869944198522717, 0.05769428578787483, 0.009204136822518194, 0.026166208626818843, 0.035599072580225766, 0.016546982114959974, 0.056455986414221115, 0.015723610085842665, 0.0462858618266182, 0.05639929004246369, 0.014768774944968754, 0.04753401692141779, 0.07327801402425393, 0.021497988418559544, 0.03095884618232958, 0.052648657510872, 0.07668260906939395, 0.05218207668804098, 0.09751165154739283, 0.029867013363400474, 0.10321812893380411, 0.09595863331924193, 0.04960766287695151, 0.055664916362729855, 0.011316725122014759, 0.07353885666816495, 0.050915861429530196, 0.05481834108650219, 0.10089584495290183, 0.04040388135763351, 0.06656986734014936, 0.026954150525853038, 0.021321997373888735, 0.07903549922048114, 0.035082741887890734, 0.03802418854320422, 0.02735234986175783, 0.03341033436299767, 0.015484045743505703, 0.06820795795647427, 0.06351308722514659, 0.03508572161081247, 0.0509912191046169, 0.021045807116024662, 0.030665562408103142, 0.046938480518292636, 0.02252925271022832, 0.008058749699557666, 0.021776586945634335, 0.010011029462475562, 0.029492334542737808, 0.050982476604986005, 0.06739875723724253, 0.027444795487099327, 0.06286355215706863, 0.08440373538178392, 0.03465778812824283, 0.026341056764067616, 0.06507859579869546, 0.05875544564332813, 0.02750310788542265, 0.05776773614343256, 0.042279010231141, 0.03601148033339996, 0.023068044501997065, 0.025870997124002315, 0.034284113062312827, 0.05575639348535333, 0.06981902697589248, 0.03654642408946529, 0.036216947628417984, 0.037934076972305775, 0.009725702439027373, 0.06936889956705272, 0.09588950226316229, 0.04023089786642231, 0.10742571292212233, 0.03966808275436051, 0.024890126514947042, 0.05935007662628777, 0.05133234728418756, 0.026926568607450463, 0.009721007427287987, 0.020547130261547863, 0.021243079245323315, 0.03108991131739458, 0.015534060930804117, 0.02464243287249701, 0.008090601750154747, 0.01679142143984791, 0.0038571750201299437, 0.03442693196120672, 0.0398816134838853, 0.051257483137305826, 0.057091995840892196, 0.021586973780358676, 0.03904635967046488, 0.011043136091757333, 0.03738081330084242, 0.02090961188514484, 0.04094317409908399, 0.030364461963472422, 0.04043235385324806, 0.010156405060115503, 0.02935351396445185, 0.028249402312212624, 0.0202591417109943, 0.02391240261204075, 0.03663302159111481, 0.07105545242666267, 0.04874713522440288, 0.02647862125741085, 0.045034274298814125, 0.027395266406529117, 0.0369545125431614, 0.06134951523563359, 0.023072144867910538, 0.08385319539229386, 0.0220471350257867, 0.04893409706710372, 0.05739255822845735, 0.006860401063022437, 0.10213513509370387, 0.03956572945753578, 0.048309327466995455, 0.023569469158246648, 0.03480983192275744, 0.05156219041964505, 0.07963533265865408, 0.01936128031957196, 0.03176029145834036, 0.03835203970083967, 0.07063582728733309, 0.049266497589997016, 0.058895143811241724, 0.10881659414735623, 0.017449003244109917, 0.046675433695781976, 0.08524326767656021, 0.027268845260550734, 0.041047345657716505, 0.0753543057362549, 0.009473402842559153, 0.02809173303830903, 0.021715764232794754, 0.039546533807879314, 0.05087208584882319, 0.051547989423852414, 0.012967463790118927, 0.04880308944848366, 0.02405049959634198, 0.028863080515293404, 0.06445485036238097, 0.023463215875381138, 0.04892583696346264, 0.03425273134780582, 0.025320067506982014, 0.06155897157441359, 0.01398722479279968, 0.030851017691020388, 0.03452780838415492, 0.04181743519438896, 0.13968906918307766, 0.12777872703736648, 0.0628833229711745, 0.12654067628318444, 0.07520632891100831, 0.11695626948494464, 0.10707628011004999, 0.15840677573578432, 0.18099990324117243, 0.15456648805411533, 0.28055272065103054, 0.1417034212499857, 0.17842135566752404, 0.17747387057170272, 0.18844434205675498, 0.13651426532305777, 0.08452685025986284, 0.14366476912982762, 0.15102947159903124, 0.10052858575363643, 0.1046127951121889, 0.15226373740006238, 0.11052359317545779, 0.14385575341293588, 0.12906929216114804, 0.18556613009423018, 0.10809075145516545, 0.10668001777958125, 0.17129295301856473, 0.1018509964342229, 0.16270312800770625, 0.1566896983422339, 0.16346026706742123, 0.13810594944516197, 0.212657414667774, 0.16434040968306363, 0.14117570972302929, 0.15915425203274935, 0.10774232796393335, 0.1549070150940679, 0.14886916877003387, 0.16641193680698052, 0.16911555110709742, 0.11974652210483328, 0.15517369844019413, 0.12286225843126886, 0.14776547643123195, 0.1700815008371137, 0.13871731585823, 0.09093547356314957, 0.11958606977714226, 0.10546367484494112, 0.09021428413689137, 0.167053478944581, 0.14001300180098042, 0.1212654980190564, 0.15191866841632873, 0.11601356382016093, 0.07782803979353048, 0.08552294602850452, 0.10170177280087955, 0.05797168203571346, 0.10727832239354029, 0.20697075262432918, 0.1309191100881435, 0.2108898712322116, 0.08844347525155172, 0.10926229835604317, 0.134235248551704, 0.18324779433896765, 0.20172326389001682, 0.09815041063120589, 0.09997367451433092, 0.18445776222506538, 0.13078772026346996, 0.23154485039412975, 0.15435061213793233, 0.16257185692666098, 0.08581582718761638, 0.14450606773607433, 0.13363957114052027, 0.1733451397740282, 0.12977550504729152, 0.1459454928408377, 0.07361301948549226, 0.1217497196921613, 0.19773787149460986, 0.12832837644964457, 0.09014701587148011, 0.1287269839667715, 0.16015744273317978, 0.16153206350281835, 0.09509738578344695, 0.208046005864162, 0.06297380561591126, 0.12064771945006214, 0.09100418159505352, 0.12749414308927953, 0.16295856039505452, 0.09064387631951831, 0.08258647547336295, 0.15123611519811675, 0.11234840814722702, 0.12782386445906013, 0.07702704722760245, 0.2069684668094851, 0.14221075340174139, 0.1949251614860259, 0.17137740942416713, 0.1436149116489105, 0.10333295402233489, 0.09713755716802552, 0.13188022101530805, 0.14601127681089565, 0.15480176371056587, 0.11911747773410752, 0.2230734276236035, 0.12259746756171808, 0.18190532340668142, 0.1078976372082252, 0.15253383462550119, 0.14684522815514356, 0.12488141219364479, 0.1818141431431286, 0.08463417965685949, 0.14223773789126426, 0.15817216801224276, 0.11055235139792785, 0.33590440987609327, 0.13422755990177393, 0.10075966827571392, 0.14839698473224416, 0.12493449059547856, 0.08290511657833122, 0.20604137593181804, 0.14720907347509637, 0.2256293990649283, 0.10883042778004892, 0.14463817002251744, 0.09328595173428766, 0.1385982456849888, 0.22955147142056376, 0.16192448150832206, 0.06825918098911643, 0.12452043156372383, 0.16356888780137524, 0.16981655411655083, 0.17709206527797505, 0.12713947071461007, 0.2104985961341299, 0.11596447075135075, 0.23453947564121336, 0.15301446430385113, 0.19051275216042995, 0.14050376921659335, 0.1648930276860483, 0.11908478612895124, 0.13929745269706473, 0.12773188267601654, 0.09943457102053799, 0.15723100601462647, 0.150510398671031, 0.09982084404327907, 0.261079715564847, 0.21713384165195748, 0.16020155599107966, 0.135130308335647, 0.16349792364053428, 0.13560192834120244, 0.13090638967696577, 0.13282248139148578, 0.16103584872325882, 0.24284672050271183, 0.17983814526814967, 0.13759365974692628, 0.1779579883441329], [0.07004048384260386, 0.013428877409751294, 0.038475837354781106, 0.03150985743559431, 0.03365220400155522, 0.07032048131804913, 0.02364757463510614, 0.04725580060039647, 0.03799721147515811, 0.01016260941469227, 0.026617688599799294, 0.02522738624975318, 0.05160410320968367, 0.042599773878464475, 0.035410478012636304, 0.05143561342265457, 0.061314864360610954, 0.005142252193763852, 0.02150224278011592, 0.04610218027664814, 0.02879163766920101, 0.016189595335163176, 0.05253650786471553, 0.04357302634161897, 0.012552630141726695, 0.07471271906979382, 0.03761575870157685, 0.056767966743791476, 0.09436966545763426, 0.038491582017741166, 0.025579075190762524, 0.01063667294147308, 0.04612143158738036, 0.03268476255470887, 0.043592173751676455, 0.07538698991993442, 0.029183677179389633, 0.030541224841726944, 0.006700971507598297, 0.022549880704900716, 0.03196549529093318, 0.013743794788751984, 0.05911336491408292, 0.00851573084219126, 0.035139638639520854, 0.031064390714163892, 0.04280913002730813, 0.010094148146890802, 0.015844815789023414, 0.0417589539574692, 0.026091346335306298, 0.022111757534730714, 0.07054785310174339, 0.019464329379843548, 0.0412991860503098, 0.058893125169561245, 0.062174182312446646, 0.04638312027964275, 0.011375243466318352, 0.03386843243788462, 0.07234681906993501, 0.05309790176397655, 0.013257957089081174, 0.04016703234810848, 0.007059907056827797, 0.001706715620457544, 0.033231703127967194, 0.02919780024967622, 0.0431782297528116, 0.09442738970392384, 0.04139308999583591, 0.07760984837659635, 0.03217087723896839, 0.01691280340310186, 0.04184638266451657, 0.07077966292854398, 0.016069753328338265, 0.052299799863249063, 0.0301272567230626, 0.015620373633282725, 0.032298589721904136, 0.06302743320702575, 0.042225286160828546, 0.04456475828192197, 0.05047071383160073, 0.028901959776703734, 0.06931156865903176, 0.027970152550551575, 0.10298261579009704, 0.004570144465105841, 0.03803465653618332, 0.021597211707558017, 0.0783614584361203, 0.021765489982499275, 0.013014195901632775, 0.0631321279797703, 0.0014624610207647493, 0.02261279441881925, 0.03962186550779734, 0.056746826667222194, 0.03199165970727336, 0.022132945850898977, 0.02719312207773328, 0.05487328970048111, 0.031649485099478625, 0.04284866794478148, 0.017364847408316564, 0.04151358880335465, 0.03893161621817853, 0.06616462502279319, 0.02836739080521511, 0.05748451774707064, 0.034732559506664984, 0.02750997089606244, 0.10839831229532138, 0.027400865910749417, 0.04107916152861435, 0.07154584134696051, 0.03912777698133141, 0.06445163686294109, 0.01978304841031786, 0.05601569988357369, 0.03172054945025593, 0.04161667311564088, 0.041310206943308, 0.04173849294602405, 0.03934532644052524, 0.055600779960514046, 0.01720330041280249, 0.03930589242372662, 0.027951021838816814, 0.09487092684139498, 0.021674062954843976, 0.039220118705998175, 0.03731155607965775, 0.02439443123876117, 0.011221015902265208, 0.07637466973392293, 0.004762428898175131, 0.05728995631216094, 0.027968898320978042, 0.03437428029428702, 0.03215306940546725, 0.04658121062675491, 0.035991119511891156, 0.027287899902148638, 0.039819599624024704, 0.02849317741492996, 0.048357377818319947, 0.02607726779388031, 0.03433149919146672, 0.018687085539568216, 0.02909304796048673, 0.03477698817732744, 0.016350474397768266, 0.020145455819147173, 0.019253390601079445, 0.025796585687203333, 0.019348968089616392, 0.012752257662214106, 0.0398301789391553, 0.02275585451570805, 0.02594449386378983, 0.05126945397933014, 0.00998782899841899, 0.06995694027864374, 0.0680965393257793, 0.018554517555458006, 0.007269018296938157, 0.082847666926682, 0.021004053887736518, 0.029955455102026463, 0.01299753839703044, 0.029786419836455025, 0.09224926790921018, 0.02155217447580071, 0.08704092004336417, 0.048724117514211684, 0.035027463018195704, 0.06138192482467275, 0.027188094027223997, 0.07471081175026484, 0.09891539419186302, 0.0322310728370212, 0.020253718466847204, 0.032254454199573956, 0.04974671537638642, 0.018699447864491958, 0.03086191056354437, 0.04482159703911748, 0.03526172193232924, 0.023861604458943475, 0.04398537101224065, 0.026669067483453546, 0.027631929879134987, 0.036759246067958884, 0.03591151304135565, 0.04900573658233043, 0.06256758366362192, 0.04757867565786, 0.0424805664079031, 0.03824763436568901, 0.097325706447009, 0.02039439441432478, 0.04986666128388606, 0.02625609384267591, 0.05738533342082519, 0.013039452114753658, 0.07945951787405647, 0.04169851716142148, 0.02156910100893583, 0.007036098031676374, 0.03904090859577991, 0.053300775252864696, 0.024524123400624376, 0.030448617799265776, 0.02088320441544056, 0.04168358886090573, 0.058181561398669146, 0.023758273382554762, 0.030384717028937303, 0.049537541053723544, 0.05105427197122481, 0.1118271161976736, 0.05583477541222237, 0.13299099344294518, 0.03427536314120516, 0.06864309398224577, 0.06065929563192185, 0.011790294192906003, 0.04407551597978454, 0.03298015217296779, 0.0352723977266578, 0.00360649863978324, 0.03270551300374791, 0.05893971348996274, 0.032705679986975156, 0.06984886873397045, 0.050724639659165405, 0.05652095402183477, 0.028925116639584303, 0.03188414477335755, 0.019708438449015375, 0.08631773423985578, 0.04728621381218545, 0.10258840178721584, 0.07346964397584088, 0.08878686698153615, 0.01593372508068569, 0.03429929740377702, 0.026629024905560073, 0.0858259352389723, 0.01738341223244788, 0.049464361582067795, 0.03203482301614713, 0.06917306163813919, 0.043625073158182204, 0.0711024303745944, 0.03498466707242187, 0.06810708524426445, 0.010674521545297466, 0.028744676419591997, 0.09355281319585629, 0.005825965481562889, 0.041197793834726326, 0.02013017685385421, 0.05520906699530315, 0.04579284941428341, 0.03810518282989506, 0.058770655959961005, 0.02021395233896328, 0.005221842429818935, 0.027608324016910046, 0.02276721494126832, 0.0690870318794623, 0.019126976876577828, 0.034199293004348874, 0.08738941774936393, 0.02462906308210222, 0.06641018684604205, 0.04512278283073101, 0.01926231307152193, 0.06594569145818241, 0.02095494040986523, 0.01094652423489606, 0.04953381918312516, 0.014367642270372016, 0.08155822244589217, 0.019064283951593097, 0.06327764087473042, 0.0455087218870176, 0.08037853418500163, 0.02716800223424798, 0.09816418489208445, 0.04281651810742915, 0.006732779957019375, 0.028486058363341726, 0.02336371057026554, 0.041100832240772434, 0.04102003833395429, 0.04953593801474199, 0.031484865612583235, 0.04345195608038921, 0.016306593061017338, 0.024312429486599285, 0.00703397873621725, 0.015892966330284253, 0.032547461523790844, 0.025932209464372136, 0.0410685488168383, 0.08046024464420043, 0.04454613408597652, 0.013716924404434394, 0.03011116510606371, 0.04098772151337471, 0.05092012506793253, 0.037030567837064154, 0.061831091152271256, 0.10866626471397467, 0.015580184481223114, 0.05654957865772303, 0.044912205848959275, 0.038156365044415, 0.02877624923712574, 0.03824068044195883, 0.05993180166115053, 0.04122255188121926, 0.011050039920519339, 0.02088431949232472, 0.04342661915870849, 0.042536279433988966, 0.005113997704029316, 0.046821955911582336, 0.04074352153111249, 0.04935782628308516, 0.032441174844279885, 0.02805992273351876, 0.06912555676535703, 0.027181943478353787, 0.03865719227178488, 0.023397225959342904, 0.06929929353646003, 0.04342706815805286, 0.0456028930057073, 0.010570344420557376, 0.06083855027100071, 0.04043036118673626, 0.01164454288300476, 0.015662768819311168, 0.0016418867016909644, 0.0493831149651669, 0.06507392768980935, 0.268144664587453, 0.1322858640924096, 0.09437044471269473, 0.06848965495009907, 0.13773321319604293, 0.16987092385534197, 0.13337103242520243, 0.09489282761933282, 0.1528259291080758, 0.115353794535622, 0.192320698115509, 0.08162215104675852, 0.20526885957224295, 0.13274945406010374, 0.21424961829325184, 0.1571579193114303, 0.11223972061998211, 0.10729628978879191, 0.057336073368787766, 0.16839364921906963, 0.1503942080307752, 0.08115600066957995, 0.2021866905852221, 0.10638565974659286, 0.17463095515267923, 0.1665441578370519, 0.13405640580458567, 0.05723805050365627, 0.15510574739892036, 0.13330032059457153, 0.1271220450871624, 0.09552792049362324, 0.16934146085986868, 0.11502368724904954, 0.34178679110482335, 0.1300987697322853, 0.1279617554973811, 0.15855894569540396, 0.07516886529629119, 0.11235494646825828, 0.07029375658021308, 0.16468077345052734, 0.14937792584532872, 0.1379301049746573, 0.19145174708683044, 0.11322650243528187, 0.11938874013139866, 0.1882376687717624, 0.1721375170745887, 0.20868618245003745, 0.0728442138643004, 0.14274456538259983, 0.1779905686271377, 0.10434985219035298, 0.07920264572021551, 0.11771061064791866, 0.10334442762541585, 0.1141041811206378, 0.146271473786328, 0.15961159311700612, 0.11652826549834572, 0.18507540720747784, 0.13937340409029275, 0.20869948173640296, 0.1252367821871303, 0.09221033484209329, 0.08494346227962524, 0.12077490871888585, 0.12166265834821388, 0.19763316930038854, 0.20149505347944796, 0.1630584683152847, 0.10344834314309992, 0.09487137213000096, 0.09643291763495654, 0.18571589549537748, 0.17121228156611323, 0.16977005114313215, 0.09364234589156695, 0.17799500667024404, 0.13472114747855812, 0.2372136415215209, 0.12378589090076275, 0.17028090107487515, 0.13297900033649057, 0.1083912915783003, 0.20774739532498643, 0.08924045279854909, 0.18072973180096596, 0.05514334981853608, 0.06837148277554661, 0.14844506105873734, 0.20928640180500224, 0.15081003337400034, 0.18708088318817317, 0.12164627914899029, 0.1284928066888824, 0.07846532942494377, 0.12935276288772002, 0.17064821964595467, 0.14544662117259577, 0.1603549876017496, 0.13971928943647072, 0.20199873426463455, 0.1321656213258393, 0.08699984216946177, 0.13402948068687692, 0.1516718152561225, 0.10175765652093105, 0.14252095628762618, 0.1511387454229407, 0.24929108563810587, 0.07466158509487286, 0.14828582585323602, 0.2747558051487431, 0.20254281756933779, 0.09831558301812038, 0.25738925265613943, 0.19314452656544745, 0.16711975273210555, 0.11612080415943637, 0.2340753810130991, 0.13248594710603356, 0.2004953211871907, 0.17756600078428164, 0.13071908644633368, 0.1323303929530084, 0.16352648148313165, 0.11519480423885398, 0.12029860576149076, 0.12714837648672983, 0.13131406623870134, 0.06504680961370468, 0.20306496298871934, 0.13785721122985706, 0.07713292943662964, 0.1378508732886985, 0.21426728140795603, 0.10559267495409586, 0.1492525771027431, 0.13036549760727212, 0.15515648061409593, 0.20223124913172796, 0.1369014586089179, 0.13895842479541898, 0.08870332341757603, 0.1127729908330366, 0.09412645624252036, 0.1376092151622288, 0.12949152966029942, 0.09150018115178682, 0.09786867653019726, 0.12023389790556394, 0.1725860859733075, 0.12207950043375604, 0.18188437999924645, 0.15089296095538884, 0.10341186658479273, 0.11622427438851446, 0.09586959044099785, 0.19295186502858996, 0.14306595985544845, 0.11584891093662009, 0.10008486307924613, 0.18547331710578874, 0.1667729768087156, 0.1273574394872412, 0.12250072861206718, 0.09980319577152841, 0.15536998165771365, 0.06791098014218733, 0.08448238077107817, 0.08162647776771337, 0.06113208452006802, 0.13100139942253008, 0.11716245295247063], [0.03704038645082619, 0.07171076882514171, 0.03218102610844653, 0.042828852601815015, 0.057348248301423155, 0.011294416162854759, 0.03683783950691577, 0.03574018453946337, 0.018365314426773693, 0.0569480043486692, 0.05145333219843451, 0.10327010895707645, 0.033504034217912704, 0.028805712499888614, 0.013673743469553301, 0.04053912292874884, 0.014332717728393618, 0.016193233714147937, 0.09161825684714131, 0.01656703865592135, 0.0494244117726339, 0.052786132946494035, 0.03154987032758072, 0.04511801453190856, 0.044220642957952805, 0.036723719458677806, 0.040286169314640574, 0.044286879638093524, 0.03621699215727858, 0.031470015237573534, 0.005289681221256615, 0.024841059421305545, 0.04077104778843932, 0.011616557421803009, 0.0071511304577143164, 0.06047070106433239, 0.05386576485761907, 0.03406460062251426, 0.034975868911715224, 0.05614821406197734, 0.015670359134674072, 0.015535251150140539, 0.04026499213068746, 0.05283291051455308, 0.03399723216716666, 0.059508684717002325, 0.041277570999227464, 0.059710129571612924, 0.07508140319259837, 0.024919198294810485, 0.027187092127860524, 0.02346535326068988, 0.06013042264385149, 0.05079950380604714, 0.01644672538532177, 0.08105392567813396, 0.03739683255844284, 0.049441421797382645, 0.031477648226427846, 0.05711586702091154, 0.023006698575045448, 0.03878333511238452, 0.04791695770109072, 0.05683872310328297, 0.032899046564125456, 0.03157819439365994, 0.10845251134014688, 0.08307756943395361, 0.04676974582253024, 0.015821701599634252, 0.0580333322432125, 0.04840231114940252, 0.05249165988061577, 0.032590372502454557, 0.07872864342061803, 0.07290615350939333, 0.03249525143473875, 0.05880816410353873, 0.02277884996146895, 0.003179104373884911, 0.017523802453069948, 0.026207581504422706, 0.05759089719504118, 0.0571704742469592, 0.02170778243453242, 0.06281785812461749, 0.03156294325890485, 0.009091779375012266, 0.019558964340831153, 0.027883818511327263, 0.0328267762233736, 0.008966944569692714, 0.04586652241414413, 0.06677084835246205, 0.06326779999653809, 0.0417906251095701, 0.01622085830604192, 0.02209000704169739, 0.035098486550850794, 0.04148537977016531, 0.1041306514525786, 0.020718878076877445, 0.021118509757798165, 0.00885738130818936, 0.04562435220577754, 0.03720033782883547, 0.055922686515259556, 0.10535978901316412, 0.012666679685935378, 0.055068348374334164, 0.026828350928553846, 0.06444863116485067, 0.10442876475281082, 0.010517786449781852, 0.03399855690076947, 0.026080356983584352, 0.07199492974905297, 0.03698159722262062, 0.041651980791357346, 0.04374919364636298, 0.04834259052586276, 0.037651648963219486, 0.02897400190704502, 0.058528597073745914, 0.034948569009429775, 0.03341757401358336, 0.03253126786148641, 0.020134878359385766, 0.05631791726045776, 0.03559532844519708, 0.08407981018535793, 0.13366478931857273, 0.016260793272522278, 0.048429351300001144, 0.05817743505758699, 0.016560964177187998, 0.02394563598500099, 0.070812681078678, 0.030100439216766972, 0.03763315835385583, 0.006860452085675206, 0.03882454657286871, 0.02734560373937711, 0.031593115272698924, 0.04345021574408747, 0.03723276226082817, 0.04354391188826412, 0.013158701331121847, 0.03771448660700116, 0.056209200047305785, 0.06698169250739738, 0.06346657683025114, 0.016740261489758268, 0.01170056111732265, 0.049142224961542524, 0.011853707001137082, 0.03121980385913048, 0.06074895449273754, 0.050624791110749356, 0.04971808702975977, 0.07372719890554436, 0.03339988863444887, 0.08612736593931913, 0.019751980253204238, 0.041651657957118005, 0.03436263599724043, 0.08890940298442729, 0.037533480499405414, 0.012465508498280542, 0.05545233558223117, 0.03228765417588875, 0.034430208543199115, 0.03246272310207132, 0.013628490087285172, 0.038588480529142544, 0.052611438804888166, 0.01024212497213739, 0.015618008037563413, 0.04870077325904276, 0.04482122967601754, 0.02288946336193476, 0.019204954332963098, 0.03323808930872474, 0.038437104667536914, 0.021985453277011402, 0.03628802311141044, 0.04628191360097844, 0.044283829411142506, 0.04613620403688401, 0.029820549352734815, 0.05645830191497225, 0.0758837019384373, 0.03953241073759273, 0.05744120600866154, 0.035484863474266604, 0.01291179900363204, 0.02912754483986646, 0.04783502088685054, 0.04756174355861731, 0.054435541314887814, 0.025621539025451057, 0.010091651747643482, 0.04078415782714728, 0.030152278231980745, 0.052138304818072356, 0.03273828995588701, 0.028254237404325977, 0.013992325202707434, 0.0185922093805857, 0.05414659724920057, 0.03784232525504194, 0.036314091048552655, 0.025015859318955336, 0.005071931846032385, 0.05346253376046661, 0.03201586856448557, 0.05599556541710626, 0.042644792556529865, 0.010693417552829487, 0.029667935959878378, 0.01614110155060189, 0.06840495363576338, 0.024849714718584437, 0.06273889361182228, 0.021936970624665264, 0.031428462389158085, 0.0187966859084554, 0.05028331041103229, 0.04463268705876544, 0.009198612460750155, 0.014308187892311253, 0.014956003960833186, 0.03561278004781343, 0.010025398369180039, 0.048799835130921565, 0.03210439936083276, 0.05750633317802567, 0.09262713982025161, 0.02732980155997211, 0.01576342445332557, 0.005341668202163419, 0.08252361556515098, 0.08924366629798897, 0.11588985522394069, 0.002776897904368525, 0.07414369960315526, 0.04620129780960269, 0.058533049959805794, 0.04252299127983861, 0.036489404883468524, 0.04534583531494718, 0.022977111002546735, 0.015150541275943397, 0.06713939888868481, 0.01703470672509866, 0.036698931726277806, 0.013503804639185546, 0.05678987865394447, 0.0480622368195327, 0.04731254892249126, 0.06278197528445162, 0.04325611444073729, 0.012934001279063523, 0.022690111363772303, 0.08611049692262895, 0.009708545840112492, 0.06444487589760683, 0.017678989242995158, 0.04146184626733884, 0.04475913417991251, 0.030389288658625446, 0.0732894430984743, 0.03457010338024702, 0.050233304500579834, 0.03240648686187342, 0.024482282969984226, 0.029437866469379514, 0.02346914934605593, 0.021729228647018317, 0.035765907377935946, 0.02023324075707933, 0.03918631387932692, 0.06289589495281689, 0.07625648271641694, 0.04533025392447598, 0.08121277496684343, 0.05812896168208681, 0.03482100124529097, 0.02111547437380068, 0.012456272470444674, 0.11403730619349517, 0.04484889694140293, 0.03244659994379617, 0.03359858012117911, 0.03638089547166601, 0.021925645451119635, 0.050407334420015104, 0.07318561663851142, 0.014334987772599561, 0.0541640525625553, 0.04324050336435903, 0.0143134228164854, 0.05454303027363494, 0.01084980105588329, 0.048506538369110785, 0.03601658630941529, 0.01103600126953097, 0.03767770576814655, 0.044968241709284484, 0.045825032648281194, 0.11794667298090644, 0.027787834696937352, 0.05910279673116747, 0.07838600125978701, 0.020021481905132532, 0.02364907933952054, 0.04344007800682448, 0.012805110636691097, 0.0762614476843737, 0.0391900357499253, 0.021616227386402898, 0.02373750994593138, 0.054646214775857516, 0.029310450845514424, 0.031781513171154074, 0.056793615367496386, 0.011065162107115611, 0.025026451621670276, 0.028686942896456458, 0.0313876702421112, 0.023943578380567487, 0.01823770213377429, 0.027089505274489056, 0.034916010990855284, 0.008400692386203445, 0.017954023605852854, 0.12284409065614454, 0.027301779919071123, 0.04266220705176238, 0.05209888935496565, 0.039038619070197456, 0.034979301344719715, 0.05128099066496361, 0.05150469623913523, 0.026371210224169772, 0.10520146664930508, 0.03527880246110726, 0.036066376997041516, 0.039256257587112486, 0.03140267275739461, 0.034734845321509056, 0.0815780229459051, 0.12199437609524466, 0.1698465517256409, 0.09214636171236634, 0.13098118331981823, 0.12041843292536214, 0.13464233139529824, 0.1718713087029755, 0.23582373250974342, 0.09312071997555904, 0.11546919849934056, 0.12174787174444646, 0.2081140608061105, 0.11604970641201362, 0.12427411274984479, 0.10632822493789718, 0.19103075639577582, 0.09176935811410658, 0.1725879858713597, 0.16181784973014146, 0.17072657559765503, 0.1169727228989359, 0.10756223840871826, 0.1252930221380666, 0.14569206425221637, 0.15074585244292393, 0.11491425757412799, 0.09701473914901726, 0.11742916598450392, 0.14278680842835456, 0.19011482741916552, 0.1210434919630643, 0.08637322462163866, 0.11231596145080402, 0.11743311421014369, 0.1274358993396163, 0.09256301083951257, 0.14574919478036463, 0.10484404832823202, 0.10411398281576112, 0.13483684830134735, 0.09686525576398708, 0.11586165361222811, 0.12978080398170277, 0.12579728179844096, 0.2459724832442589, 0.1591986621497199, 0.10080835316330194, 0.15818999439943582, 0.1446547347586602, 0.14327953511383384, 0.08164811137248762, 0.14994246274000034, 0.2080568709061481, 0.07175108970841393, 0.08848539917380549, 0.16021899646148086, 0.06378748890710995, 0.06560374691616744, 0.12138635676819831, 0.17474190623033792, 0.16825354658067226, 0.18383751972578466, 0.13312952272826806, 0.1701768668135628, 0.1443063112674281, 0.16033782914746553, 0.22537010750966147, 0.25691947317682207, 0.0924493583443109, 0.13008834997890517, 0.14497357624350116, 0.22979295143159106, 0.12131636482081376, 0.10329892655136064, 0.22316012531518936, 0.18666758114704862, 0.12676372134592384, 0.12975920748431236, 0.15052142698550597, 0.14246171806007624, 0.1769648166373372, 0.07529317503212951, 0.10223497622064315, 0.21607314934954047, 0.1564840492210351, 0.09660401236033067, 0.08685651118867099, 0.12064889946486801, 0.14293638087110594, 0.08763268633629195, 0.1830786737264134, 0.16509576758835465, 0.05589604712440632, 0.22734476951882243, 0.1416866190265864, 0.156504962942563, 0.1121509300719481, 0.15642173850210384, 0.14201040321495384, 0.10521264339331537, 0.149494324286934, 0.06536772169056349, 0.10667839989764616, 0.08995192009024322, 0.10184617989580147, 0.15075694012921304, 0.1817332045175135, 0.1998623285908252, 0.08915047481423244, 0.15684370882809162, 0.15992843080312014, 0.15835810569114983, 0.12916056148242205, 0.11942202545469627, 0.13450213969917968, 0.10463239523232915, 0.18369302357314155, 0.09459768290980719, 0.11496568098664284, 0.06768763822037727, 0.19166992366081104, 0.13649689906742424, 0.1305975968716666, 0.13306142325745896, 0.13108732528053224, 0.09896759685943834, 0.18943309056339785, 0.16212796355830505, 0.1573431890574284, 0.14528058789437637, 0.1563875106512569, 0.15221054025460035, 0.1850871034548618, 0.1907108016894199, 0.17155120556708425, 0.09240159371984191, 0.09833619245910086, 0.24064543627901003, 0.14464150968706235, 0.15949740627547726, 0.18371263111475855, 0.13884539570426568, 0.21081326674902812, 0.08639378953375854, 0.10186313797021285, 0.07976388747920282, 0.15639257209841162, 0.09446549156564288, 0.10864397801924497, 0.12947661249199882, 0.17354209092445672, 0.13865536137018353, 0.09353054134408012, 0.09956453592167236, 0.1281968381954357, 0.10632869249093346, 0.15914929448626935, 0.15576291916659102, 0.1268466340843588, 0.13606608234113082, 0.20935634180204943, 0.09627317034755833, 0.2504758205031976, 0.12581236223923042, 0.1000589769682847, 0.13819879211951047, 0.23896070168120787, 0.24723891372559592, 0.08205287871533073, 0.18475766410119832, 0.08356953912880272, 0.12816305563319474, 0.09156713771517389, 0.051307021494721994, 0.13243858324130997, 0.1961469295201823], [0.020970839068468194, 0.012247521171957487, 0.008637721366540063, 0.02888681810873095, 0.03559516517270822, 0.04286947405489627, 0.01466667676140787, 0.03386798343854025, 0.09235054138116539, 0.017588673581485637, 0.0317352068668697, 0.01825312396249501, 0.05677067929354962, 0.014373996909853304, 0.03665409116365481, 0.009602661775716115, 0.04554256011033431, 0.08584439245169051, 0.051650502282427624, 0.04760308118420653, 0.008961045423347969, 0.046773768262937665, 0.06731037487043068, 0.04436366965819616, 0.030946767728892155, 0.07324339283513837, 0.049613581504672766, 0.07405056749121286, 0.033911940845428035, 0.09234271914465353, 0.038538482040166855, 0.01349917363768327, 0.03296192502602935, 0.02005020302021876, 0.04259352870576549, 0.03682995789858978, 0.06465263271820731, 0.009029954762809211, 0.032362818892579526, 0.0029721949931627023, 0.022525272943312302, 0.01361871043627616, 0.01168294624221744, 0.06008401986036915, 0.02767438258160837, 0.046661915475851856, 0.04803693329449743, 0.024799206003081053, 0.0494790783704957, 0.07874908958910964, 0.07256777869770303, 0.08011599944438785, 0.024044577257882338, 0.04673456060118042, 0.0469838146091206, 0.07251100440043956, 0.05155891383765265, 0.028989924685447477, 0.11197129322681576, 0.024734344151511323, 0.06621101667406037, 0.03650216240203008, 0.028619689473998733, 0.06615355217945762, 0.0018246111130792997, 0.06567324162460864, 0.028476707302615978, 0.012339805380179314, 0.10029090553871356, 0.0315673367731506, 0.06407887834939174, 0.04617524842615239, 0.02492776638973737, 0.04020068503450602, 0.012162469192844583, 0.05970914622594137, 0.07281947808223777, 0.07782075190334581, 0.013829516556143062, 0.06957682708161883, 0.010534090506553184, 0.022519179910887033, 0.05774483717686962, 0.03843713806418236, 0.06179497824632563, 0.017598379017726984, 0.02299395033332985, 0.05451166711281985, 0.045140579532017, 0.021003675392421428, 0.021482351367012598, 0.03684658571728505, 0.05132659192895517, 0.0336858715309063, 0.04394099800265394, 0.06324218848021701, 0.06380619845003821, 0.01719445030175848, 0.12710629671346396, 0.05398513560066931, 0.04101924794667866, 0.046153789226082154, 0.04451582477486227, 0.034251555043738335, 0.039782707463018596, 0.04783778167620767, 0.035134718200424686, 0.041709690194693394, 0.015648669868824072, 0.038452196240541525, 0.050762567116180435, 0.05653635358612519, 0.052627754921559244, 0.026776109298225492, 0.027607516931311693, 0.04418027754581999, 0.0739013438578695, 0.022980291105341166, 0.026958620110235643, 0.06817836852860637, 0.03659522029920481, 0.015911494047031738, 0.042522564544924535, 0.030869376569171436, 0.0581684476492228, 0.026632936023816, 0.03112731184955919, 0.02916036446549697, 0.025966646971937735, 0.055204762538778596, 0.03444956004386768, 0.045481381166609935, 0.048168727589654736, 0.010749497942015296, 0.042735197275760584, 0.061112224648240954, 0.05975166757707484, 0.05238660145550966, 0.06935619399882853, 0.02814354422298493, 0.049987471793428995, 0.01048611622536555, 0.019352048002474476, 0.03566903484170325, 0.01392442518408643, 0.026781860942719504, 0.0988924469857011, 0.060893350455444306, 0.02315411693416536, 0.04963420949934516, 0.031052815065777395, 0.05040124509832822, 0.039831006433814764, 0.040360729180974886, 0.034544621739769354, 0.0359305565507384, 0.0601412208925467, 0.03561443503713235, 0.02897784437664086, 0.024677469664311502, 0.12178609234979376, 0.020093848725082353, 0.06537552908412181, 0.04836931897443719, 0.013129151793691562, 0.05362663003324997, 0.04045464796945453, 0.03340936586027965, 0.06055389952962287, 0.03463021363131702, 0.009299007415393135, 0.030175748652254697, 0.06334691293886863, 0.019373047070985194, 0.05794103504740633, 0.03196151737938635, 0.035915401895181276, 0.05222347368544433, 0.030834864846838173, 0.02615265329950489, 0.07894150621723384, 0.013581898056145292, 0.04520406284427736, 0.02032691834756406, 0.06423180529964156, 0.02262497306219302, 0.019206648285035044, 0.08814582208287902, 0.03804207059147302, 0.010680258346837945, 0.02686496478418121, 0.051696990412892774, 0.10649008734617382, 0.06027258474205155, 0.018105341951013543, 0.05706830277631525, 0.0005979605589345738, 0.04391062189824879, 0.05730531505832914, 0.0118590588135703, 0.017474317901360337, 0.017958123971766327, 0.04559956076263916, 0.021310789088602178, 0.062137709464877844, 0.06640419029281475, 0.03284973085101228, 0.006828471086919308, 0.03001288991072215, 0.026215810066787526, 0.02145621107047191, 0.03697103646118194, 0.12855367764132097, 0.04077086967299692, 0.031113277836993802, 0.06355550096486695, 0.007801314441167051, 0.0228404983135988, 0.07037423507426865, 0.039925812088768, 0.0275046459864825, 0.03251755297242198, 0.003763530594369513, 0.014511222798319068, 0.038106566935312, 0.0040503256786905695, 0.07406903212540783, 0.06117447599535808, 0.02925265423982637, 0.00833387497550575, 0.04056619276525453, 0.08003645605640486, 0.0593094588839449, 0.052900431110174395, 0.03717538311320823, 0.02540106921514962, 0.0071363348160957685, 0.029731153954344336, 0.061017919942969456, 0.025381565574207343, 0.03904943587258458, 0.10189783337409608, 0.015388236333819805, 0.07658814851311035, 0.03606577214668505, 0.01447228323741001, 0.04446804530743975, 0.004415965604493977, 0.015866711000853684, 0.005506138795681181, 0.0540394496783847, 0.014109731109783752, 0.12123199747293256, 0.12527866900200024, 0.018976077844854444, 0.0405981348012574, 0.027596906074904837, 0.009557784105709288, 0.0615697698231088, 0.0069090673969185445, 0.11032561786123551, 0.029914638835180085, 0.028426705102901906, 0.03880545111314859, 0.047702836964163, 0.026324633035983425, 0.02720663102081744, 0.03422189882257953, 0.007937967020552605, 0.04041844229504932, 0.07122239854652435, 0.06792582309572026, 0.012508748804975767, 0.02616612513520522, 0.054186209381441586, 0.0550664150796365, 0.04148215513851028, 0.04082083105458878, 0.009949538816727, 0.05391095794038847, 0.022042802738724276, 0.01166949017715524, 0.03663672490802128, 0.03814327355939895, 0.016636756008665543, 0.10743254810222425, 0.044545763012138195, 0.07247295448905788, 0.07934177614515647, 0.012483853461162653, 0.11779896332882345, 0.04955325603077654, 0.026563524806988426, 0.04040319116029423, 0.02651315153343603, 0.0683322454278823, 0.021405761726782657, 0.004753803286803304, 0.051616571290651336, 0.021510039041459095, 0.07370159481070004, 0.044093698597862385, 0.046152423674357124, 0.06435430419514887, 0.03148115116346162, 0.11254737051785924, 0.03413842205191031, 0.037721132539445534, 0.060553276125574484, 0.03041316354938317, 0.14133935328572989, 0.029135467266314663, 0.046444699983112514, 0.0020909400836899295, 0.05136466781550553, 0.06591888508410193, 0.034251610704814084, 0.031307622193708085, 0.03130786710244138, 0.07439907261868939, 0.06119834346463904, 0.13764293835265562, 0.015394332149298862, 0.03605768644774798, 0.04309558047680184, 0.015071132402226795, 0.023766733866068535, 0.024400425936619285, 0.07225269990158267, 0.09551014605676755, 0.053389365421026014, 0.0395600371848559, 0.029195048737165052, 0.01692722704319749, 0.023165302955021616, 0.02061329458229011, 0.06413321840227582, 0.00930491769395303, 0.021774776105303317, 0.04264315983164124, 0.02543615053582471, 0.03830506175290793, 0.034959148324560374, 0.01811780261050444, 0.05065825454948936, 0.017521679910714738, 0.04895350051810965, 0.03345449214975815, 0.04273814360203687, 0.01684743689111201, 0.007819050842954312, 0.038279669170151465, 0.11668112565530464, 0.14020438684383407, 0.10023294380516745, 0.15161891496973112, 0.1598133533843793, 0.11472381505882367, 0.15336080978158861, 0.08905717942980118, 0.13777851389022544, 0.09408244688529521, 0.09825359884416685, 0.14169659349136055, 0.16190533409826458, 0.1133421587292105, 0.1867697451962158, 0.11003065868862905, 0.13527618488296866, 0.14660768152680248, 0.18764917535008863, 0.12573375395732, 0.1515394012676552, 0.20740810025017709, 0.2428532810881734, 0.10720613368903287, 0.07391890307189897, 0.07187536233686842, 0.17626262619160116, 0.19019943225430325, 0.09549724010867067, 0.20242683473043144, 0.10246312725939788, 0.08148435648763552, 0.11386224097805098, 0.08543235948309302, 0.13681176264071837, 0.1004442480916623, 0.3434709319844842, 0.19900158571545035, 0.11717674671672285, 0.11589580724830739, 0.11133152482216246, 0.21076916833408177, 0.2047410441446118, 0.2338870833045803, 0.08927261747885495, 0.061186394887045026, 0.11560530838323757, 0.12361133034573868, 0.11700974122504704, 0.13227036804892123, 0.10693380259908736, 0.1814449395169504, 0.12841657327953726, 0.13988818740472198, 0.15313601325033233, 0.13350594002986327, 0.13962104392703623, 0.10202738267253153, 0.14378731255419552, 0.07425913325278088, 0.10591956874122843, 0.18328316509723663, 0.0789588873158209, 0.10241544427117333, 0.09440847978112288, 0.1837294184952043, 0.15186505566816777, 0.12409256858518347, 0.20539064600598067, 0.15069028042489663, 0.13463835348375142, 0.09398023830726743, 0.10700970946345478, 0.10087913178722374, 0.1523967005778104, 0.22326319478452206, 0.20815753581700847, 0.24526910536224023, 0.10982120234984905, 0.17233608610695228, 0.09582308746757917, 0.07169283111579716, 0.1771399041172117, 0.0923105247784406, 0.17682674748357385, 0.19173643493559211, 0.18483086954802275, 0.16614871186902747, 0.13374930509598926, 0.12503107369411737, 0.11120330396806821, 0.12113363321986981, 0.1819964888272807, 0.19818660366581753, 0.24875170754967257, 0.1413336832774803, 0.15695250767748803, 0.06483681150712073, 0.16147558606462553, 0.23822622781153768, 0.1258935680380091, 0.14244564314140007, 0.08174422691809013, 0.12731745257042348, 0.11349060310749337, 0.12420650309650227, 0.09037997602717951, 0.12271698302356526, 0.06721891259076074, 0.20221927086822689, 0.18004841054789722, 0.1963758227066137, 0.15626241423888132, 0.19557746476493776, 0.1668290386442095, 0.12804670172045007, 0.18124078953405842, 0.11344575512339361, 0.24404843570664525, 0.2200444706249982, 0.09827060886891559, 0.15143553027883172, 0.1922641761484556, 0.11666501362924464, 0.13822166511090472, 0.15163021045736969, 0.1746196299791336, 0.13934937334852293, 0.09226103094988503, 0.19808823941275477, 0.06620164334890433, 0.1728638866916299, 0.19393510679947212, 0.14466381864622235, 0.2232482034014538, 0.18959593260660768, 0.15194381237961352, 0.1252293903962709, 0.20152013807091862, 0.17786398791940883, 0.2802956406958401, 0.08169809501850978, 0.1284845985355787, 0.1377094941562973, 0.15687400329625234, 0.15328070236137137, 0.37114740000106394, 0.13640218618093058, 0.10997814431902952, 0.12186758016468957, 0.19649320078315213, 0.10213728732196614, 0.17898921738378704, 0.16531217785086483, 0.13180918263969943, 0.08905617010896094, 0.12512206099927425, 0.18451201322022825, 0.15419765550177544, 0.13572175550507382, 0.16313876869389787, 0.07249725982546806, 0.15809486591024324, 0.13514127727830783, 0.13747436692938209, 0.14216571988072246, 0.0864261991227977, 0.10066139308037236, 0.14200323406839743, 0.1071430288720876, 0.084608835313702, 0.26341127639170736, 0.1271336225909181, 0.0899516380741261, 0.23212357715237886, 0.22660557558992878], [0.04159884301770944, 0.052244339167373255, 0.030348500222316943, 0.038424859230872244, 0.04737555354950018, 0.04321034990425687, 0.07970514649059623, 0.021197591158852447, 0.05271961425023619, 0.039546385378343984, 0.017393924754287582, 0.07310052940738387, 0.03861710887576919, 0.06412940376321785, 0.040799238267936744, 0.08071123156696558, 0.011243206117796944, 0.04059402330312878, 0.012268070313439239, 0.018370379584666807, 0.05035876827605534, 0.0276856854907237, 0.02182289696065709, 0.04678888581111096, 0.04086934153747279, 0.007268519202625612, 0.03443732945015654, 0.01366421800412354, 0.015002572799858171, 0.017794571322156116, 0.04849949538765941, 0.04854738617723342, 0.06878684056573547, 0.04705396240751725, 0.02878347961086547, 0.024111270358844195, 0.026048871368402615, 0.08604998962255195, 0.13276739919092506, 0.018679036948014982, 0.057433124020462856, 0.01687560696154833, 0.054011652537155896, 0.046924079142627306, 0.017928469605976716, 0.04018010527943261, 0.03865245736960787, 0.02754452343651792, 0.037692582118324935, 0.09475091414060444, 0.011243323933740612, 0.03225662869226653, 0.04600178996042814, 0.014916516138328006, 0.05094761050713714, 0.025914275465765968, 0.04549291043076664, 0.0823121851135511, 0.04621562497050036, 0.02628524169267621, 0.05245390682830475, 0.040176027177949436, 0.008489690735586919, 0.04175653084530495, 0.03925004210032057, 0.045627662184415385, 0.04772170606884174, 0.0591463014279725, 0.03636898400145583, 0.08130570669891313, 0.016141899359354284, 0.07354523913818412, 0.034482307310099714, 0.03508932102704421, 0.025896326624206267, 0.026111462248081807, 0.04826502867217641, 0.02726937960687792, 0.04365142682217993, 0.020728071431221906, 0.04719672193459701, 0.019818068503809627, 0.06562716167536564, 0.02250032193842344, 0.027126573695568368, 0.020436127233551815, 0.03977101863711141, 0.02496476245141821, 0.036637890079873614, 0.04169757092313375, 0.021034667479398195, 0.01780120983312372, 0.11890986192156561, 0.03275224233220797, 0.033939047789317556, 0.01674274211836746, 0.04180891904979944, 0.05856105861312244, 0.03138427120575216, 0.020466879977902863, 0.03507869718305301, 0.02490441285772249, 0.012297367520659463, 0.07050519445328973, 0.03678523607959505, 0.049648317726678215, 0.07755517435725778, 0.011838747159345075, 0.08624837311799638, 0.022658039451926015, 0.061103252082830295, 0.027775618946179748, 0.03722543355252128, 0.011829243030661019, 0.061207842954900116, 0.025055493715626653, 0.038312891410896555, 0.02871067677915562, 0.01374326229779399, 0.0454511794669088, 0.046430677102762274, 0.043443885224405676, 0.020596306821971666, 0.036486261888057925, 0.1249284643563442, 0.07721676985966042, 0.036563504618243314, 0.01874794535979163, 0.04879384970990941, 0.05055811285274103, 0.01908576912683202, 0.01939574009156786, 0.03655218315543607, 0.030529831019521225, 0.03713315862114541, 0.05467719573061913, 0.017639900324866176, 0.04015158454421908, 0.053426031226990744, 0.030708326812600717, 0.04129915265366435, 0.034590616342029534, 0.08378009384614415, 0.04201779651339166, 0.039343827302218415, 0.032609237896394916, 0.04311429373046849, 0.05428519332781434, 0.08641518565127626, 0.052144969304208644, 0.07002981175901368, 0.04865278970100917, 0.025953529511753004, 0.059629009119817056, 0.051939071563538164, 0.03448072282481007, 0.06180442949698772, 0.02780379458272364, 0.038419385891756974, 0.0710517268453259, 0.03586576334782876, 0.05073442487628199, 0.04869418669841252, 0.06414895935449749, 0.05858395386894699, 0.0515782913134899, 0.015405881822516676, 0.05003061654861085, 0.026770578442665283, 0.018945820484077558, 0.03366276105225552, 0.03992029422079213, 0.0869381103257183, 0.025612447716412134, 0.07718226741417311, 0.0602885743137449, 0.008114613938232651, 0.029668564930034336, 0.0048268788577843225, 0.0254048801434692, 0.038073715768405236, 0.044819185059168376, 0.06724226797814481, 0.009237588201358449, 0.029125724722689483, 0.018470057439117227, 0.025101762912527192, 0.09172853999189101, 0.05091609891678672, 0.10065482507343404, 0.05645863959216513, 0.04338183796789963, 0.04408247732499149, 0.024987796859932132, 0.020986982635804452, 0.031543703080387786, 0.04285595212422777, 0.01675243827776285, 0.042876053194049746, 0.03967165248468518, 0.07382798256003298, 0.01753557848132914, 0.02922137271525571, 0.068730288912775, 0.025315878083347343, 0.027975664852419868, 0.03390331337868702, 0.03186127920344006, 0.06325789232505485, 0.023798601687303744, 0.03599722738726996, 0.059542560047702864, 0.07243258907692507, 0.03887708320689853, 0.11277080891886726, 0.0347804057673784, 0.0360117141099181, 0.0249447133319336, 0.07504989160224795, 0.016067571414168924, 0.016186572938750032, 0.011347856361680897, 0.03721052380569745, 0.01722726992738899, 0.0436804485070752, 0.0488264745217748, 0.003036273647012422, 0.0526007852749899, 0.022784367829444818, 0.02039515140495496, 0.05564421786402818, 0.01022640257360763, 0.0944362732116133, 0.026281848222424742, 0.022478606697404757, 0.042153813628829084, 0.03661298360384535, 0.0844454811885953, 0.03051421994314296, 0.03669283127237577, 0.045944084267830476, 0.031750977504998446, 0.026098810485564172, 0.017979700060095638, 0.026448512326169293, 0.02855239152268041, 0.08795773959718645, 0.030629978282377124, 0.04698017808550503, 0.015043533785501495, 0.018170777111663483, 0.040931693074526265, 0.048117255937540904, 0.06978627599892206, 0.038784763746662065, 0.04611144227965269, 0.04772454107296653, 0.0573414873360889, 0.051178941648686305, 0.048687544476706535, 0.040727275918470696, 0.021511677332455292, 0.03991021585534327, 0.030980837873357814, 0.015677593219152186, 0.01409570637406432, 0.049641868463368155, 0.052903459072695114, 0.02021834399783984, 0.02827620497555472, 0.021349685048335232, 0.014052247133804485, 0.029300912392500322, 0.031289502658182755, 0.019686127634486184, 0.018150321666325908, 0.012573131043609465, 0.039312887165579014, 0.014645387327618664, 0.09544557178742252, 0.012985361609025858, 0.03192628762917593, 0.06597800456802361, 0.020141787754255347, 0.05422379545052536, 0.07469536023563705, 0.04576437691866886, 0.05962465271295514, 0.011088170540460851, 0.014635213410656434, 0.029178389377193525, 0.03408420816413127, 0.054662441834807396, 0.053015475132269785, 0.05597087416390423, 0.016759653808549047, 0.06563344766618684, 0.10751910478575155, 0.041848078471957706, 0.04159570744377561, 0.059510784994927235, 0.06009374941640999, 0.0685862306272611, 0.036818220833083615, 0.02079259375022957, 0.022166396302054636, 0.04211270235828124, 0.028394744513207115, 0.04558448774332646, 0.04507091041887179, 0.04473351524211466, 0.05502048727066722, 0.12088667615898885, 0.020348648431536276, 0.09044203441590071, 0.03787870904488955, 0.010889869608945446, 0.10416660108603537, 0.026732574915513396, 0.041523244144627824, 0.031348384654847905, 0.08307028154376894, 0.03853022935800254, 0.01841222187067615, 0.051436492867651395, 0.042521369687165134, 0.055471033992944285, 0.04707858315669, 0.025359915271110367, 0.0049256151123699965, 0.033687660106807016, 0.03265086867031641, 0.0774728850228712, 0.06078281126974616, 0.021156552247703075, 0.04224621472530998, 0.03873647590808105, 0.029094888486724813, 0.03126277049886994, 0.10113936587003991, 0.06622298009460792, 0.05443589383503422, 0.07024299367913045, 0.041823164574452676, 0.020838332311541308, 0.07005664781900123, 0.02535979281674372, 0.05025580641813576, 0.015793798702361528, 0.014304059695859905, 0.013328707882465096, 0.01921424231113633, 0.23968485969817266, 0.12339539505774155, 0.11948141211178154, 0.16778792312834412, 0.16611056547844782, 0.10827657039044425, 0.12515943555627018, 0.06698884681100026, 0.15198569919448346, 0.13828140799887478, 0.09142336144577712, 0.16229119151830673, 0.19424781814450398, 0.24433120881440118, 0.17493725434178486, 0.2880602568620816, 0.19017045880900696, 0.12486128514865413, 0.148363335756585, 0.10921297522145323, 0.21919867460383102, 0.13200856803450733, 0.08425740612437949, 0.11567678462597542, 0.13748184777796268, 0.13757644192082807, 0.1176717814814765, 0.12717255565803498, 0.09107481921091676, 0.07994565428816713, 0.10718093777541071, 0.16185372514883056, 0.1689591063768603, 0.0884306212537922, 0.07283457336598076, 0.11121664778329432, 0.16927757678786293, 0.13767949654720724, 0.2356661151861772, 0.16831239889143035, 0.15853690390940756, 0.08662275693495758, 0.11810757059720345, 0.10312113765394315, 0.188778531155549, 0.08407715329667553, 0.10007013886934146, 0.09783105706446804, 0.20986207091482356, 0.17153691180283204, 0.07719020839431323, 0.22879881493281573, 0.13195704814279452, 0.10799383439007215, 0.16649167315335944, 0.1317915937397629, 0.2397156588267535, 0.24884806800400838, 0.18158851540647447, 0.1173237142211292, 0.21307188930222765, 0.16159483435330912, 0.10197831186815165, 0.1099060446722433, 0.12390064177452587, 0.21099617646541446, 0.08673024960444309, 0.09901427052682266, 0.10084342706250027, 0.10406667090137489, 0.19814111001323909, 0.19457224057987332, 0.10291364800650626, 0.10548557562287897, 0.09116199187701568, 0.107360893744044, 0.199180576892104, 0.21927524940110743, 0.17657232441706583, 0.15982211072696373, 0.16858791379490867, 0.15905904932878911, 0.16461674094898626, 0.19959963799919933, 0.11093164823250845, 0.14684113149996847, 0.14480723126325756, 0.11857105666422285, 0.12059184315148741, 0.11231136755668558, 0.18560291093308479, 0.19995031761936843, 0.21099003148265183, 0.2173984915134497, 0.13257071521366015, 0.09735706960782409, 0.25273598672356457, 0.1571365603012964, 0.09557129160384648, 0.07642992262844928, 0.14497100841253996, 0.14605071453843266, 0.12181270576547831, 0.21482067124452442, 0.07652986023458652, 0.15349147230153903, 0.21159724186873063, 0.09429107944015414, 0.15635677089449018, 0.15084340033354238, 0.1651864728773944, 0.24790228984784335, 0.09150730576948263, 0.09240614308509976, 0.13913610979216173, 0.10785854086861946, 0.11940145312109962, 0.10333037134842016, 0.09252268253476359, 0.14794210757827386, 0.10622704052366316, 0.18641452363226563, 0.09228298367816024, 0.05844481602252927, 0.19533332786522806, 0.13088149804389104, 0.1543107142788358, 0.0968212538282387, 0.09622476747608744, 0.15025271015474573, 0.08905162816517986, 0.13297747151227668, 0.13843549269950017, 0.14924606104614213, 0.10008196870330721, 0.15260242391377687, 0.18464997847331688, 0.09779904823517427, 0.1543636294081807, 0.1366443044389598, 0.11061196812079288, 0.1656541891861707, 0.1404887778335251, 0.08760909346165136, 0.14145345106953755, 0.17309862800175324, 0.13343331345822662, 0.141424804169219, 0.13977364433230832, 0.18911353661678731, 0.14531673048622906, 0.17588683229405433, 0.055405264865839854, 0.15854033263167366, 0.10584057454252616, 0.18648199969902635, 0.19413404690567404, 0.13931752037024125, 0.1053688877436798, 0.1205585578281898, 0.13036582415224984, 0.11345161066856235, 0.15185318130534142, 0.20582129945978522, 0.3332633734680712, 0.1556568217347376, 0.17421168624423444, 0.13702903379453346, 0.13806480477796867, 0.14830326632363722, 0.10049135962617584, 0.17425174737581983, 0.1944950720644556, 0.24741607921896502, 0.17183570045745, 0.12519884359790012], [0.04620638894266449, 0.08661609987029806, 0.020899129049212206, 0.04653908632462844, 0.03495911121717654, 0.038613728393102065, 0.019834648082905915, 0.03870645603456069, 0.03648020596301649, 0.04435910544998478, 0.05479370920511428, 0.010806621048686793, 0.10411859897430986, 0.03644733995315619, 0.04165368402027525, 0.01820353551011067, 0.0999805171159096, 0.04424111139087472, 0.06365368710248731, 0.06169961598061491, 0.04813863350136671, 0.02318104019650491, 0.04003907866717782, 0.049655353286652826, 0.029293307234183885, 0.0609085347969085, 0.017389087806805037, 0.023509852435381617, 0.031819648429518566, 0.0539167949318653, 0.014156588458718034, 0.02216645752923796, 0.03960426547564566, 0.047716169647173956, 0.03503205691231415, 0.009338887648482341, 0.029509760170185473, 0.06518878988572396, 0.0608267352799885, 0.023624501263839193, 0.04735160444397479, 0.05898571551369969, 0.018289025356352795, 0.014327869648695923, 0.03464593974058516, 0.1130384644784499, 0.012995406577829272, 0.0076907042875973275, 0.03503549305605702, 0.03674334555398673, 0.027409884860389866, 0.023478385373891797, 0.038926246779737994, 0.046178165066521615, 0.03545440573361702, 0.04091853479621932, 0.029214548667368945, 0.030673366090923082, 0.02059437167190481, 0.02011950662563322, 0.03947043398511596, 0.010229814597551012, 0.04524210162344389, 0.049998177273664623, 0.028315746603766456, 0.01772681138390908, 0.05796245714009274, 0.02786190660117427, 0.02096157335472526, 0.03594161826185882, 0.056342972166021354, 0.033890837876242585, 0.035507035136106424, 0.030763305112486705, 0.043687398720066994, 0.0367380837269593, 0.06233681284356862, 0.022100911046436522, 0.03184615423379, 0.010553767624514876, 0.0385856789216632, 0.01769999202224426, 0.029524304409278557, 0.009619684788049199, 0.061312396719586104, 0.015456051005457994, 0.04068769718287513, 0.029808060862706043, 0.03857579722534865, 0.06460001444793306, 0.017935985706571955, 0.03424197762797121, 0.05231925897533074, 0.06826726297731511, 0.029402154323179275, 0.03093309551331913, 0.0028160573265267885, 0.04880246604443528, 0.05172278375539463, 0.04097909404663369, 0.022356078115990385, 0.010550900151429232, 0.004685360108851455, 0.0370580903836526, 0.04063442211190704, 0.11127282836241648, 0.04310380718379747, 0.007017405187070835, 0.08216935879318044, 0.023425952640536707, 0.02166101043258095, 0.030306991902762093, 0.05301841032633092, 0.018116991814167704, 0.004990269162590266, 0.02567563973570941, 0.008844960539136082, 0.0713220021862071, 0.0575462087726919, 0.06220354538527317, 0.02174042208935134, 0.04686689666414168, 0.02050977240287466, 0.14621147856814787, 0.020314218345447443, 0.037271019973559305, 0.02636145283759106, 0.02444292502332246, 0.038831066340208054, 0.039065885575837456, 0.013052080685156398, 0.02495624816219788, 0.03634478256572038, 0.011109272581961704, 0.05698328975995537, 0.07679007205297239, 0.04828491080843378, 0.05908905957767274, 0.08042442859732546, 0.07821245744707994, 0.021630255832860712, 0.029236720329208765, 0.03507613677356858, 0.059082038860651664, 0.017483895317127462, 0.04797517918632366, 0.007158622902352363, 0.03791130417084787, 0.04426278952450957, 0.05016304166929331, 0.036001387124997564, 0.06199837494932581, 0.01704416539723752, 0.009540924365865067, 0.0450880169228185, 0.039360503360512666, 0.06890113130793907, 0.054599244249402545, 0.06127918190031778, 0.06035947910277173, 0.08292778918985277, 0.07968779507791623, 0.043907193175982684, 0.076380451064324, 0.04288184936740436, 0.03481521249341313, 0.03324714722111821, 0.020822116384806577, 0.03949406025640201, 0.08518001443007961, 0.017175616449094377, 0.01587726248544641, 0.03645699529442936, 0.01419440830431995, 0.016480110898555722, 0.040433311223750934, 0.04009713687992189, 0.06726250634528697, 0.035291452368255705, 0.057709343964233994, 0.0897629618702922, 0.019780584480031393, 0.023914217163110152, 0.020843115453317296, 0.049150188206112944, 0.024473891135130543, 0.03967533353716135, 0.020958476743544452, 0.02395068629994057, 0.03340080518682953, 0.051000277017010376, 0.04055729441461153, 0.023650953262404073, 0.06497805705294013, 0.032969851163215935, 0.04840624453208875, 0.01169794968518545, 0.021403819155239034, 0.023958013152878266, 0.025219508352165576, 0.031184915496851318, 0.021576739563897718, 0.005616440030280501, 0.02255494771816302, 0.05423158057965338, 0.05038477684138343, 0.026494553312659264, 0.022397092907340266, 0.031172595845418982, 0.018587151644169353, 0.06386316570569761, 0.016778875433374196, 0.0254721391320345, 0.018352657098148484, 0.023486194622819312, 0.037591275249724276, 0.02398399945377605, 0.03509496134938672, 0.054607608253718354, 0.028799116662412416, 0.011122719370177947, 0.04299573934986256, 0.030193755010259338, 0.03389511264686007, 0.056447299575665966, 0.030461135975201614, 0.03810784714005422, 0.015632209033356048, 0.0484112354752142, 0.014705136709380895, 0.055798139292164706, 0.010532470769248903, 0.027760436460084748, 0.04807637473277282, 0.07475465041352436, 0.10272963991155848, 0.05932226835284382, 0.018942707174574025, 0.018441035754221957, 0.06525428441818804, 0.024924040808400605, 0.03253982853493653, 0.06804263714002445, 0.01986892231798265, 0.017392310583090875, 0.0169551113867783, 0.04131568770390004, 0.054562704608542845, 0.010512609042052645, 0.04940262602758594, 0.05822546314448118, 0.05639494847855531, 0.040192721789935604, 0.036874772486044094, 0.01577807815920096, 0.02286659408127889, 0.07773397257551551, 0.07306086161406711, 0.09651759668486193, 0.022992992962826975, 0.0456605467479676, 0.025315158200100996, 0.023532471241196617, 0.11087404272984713, 0.024439075132249855, 0.03803914281888865, 0.05315734037139919, 0.06150561115646269, 0.030732420636923052, 0.043346303937141784, 0.02530961992306402, 0.03820998150331434, 0.04705041865236126, 0.022356374975061044, 0.03861704208247829, 0.011615195580816362, 0.08696227465406992, 0.049799348489614204, 0.027509928222571034, 0.0717544367944356, 0.06239105641725473, 0.047191371049848385, 0.03260202422097791, 0.06604792972211726, 0.05442502508230973, 0.060596873590839095, 0.020799174744752236, 0.021653588955814485, 0.04634497017832473, 0.014532227432937361, 0.014621927111875266, 0.019733693734451663, 0.09514630073681474, 0.05154463120561559, 0.06686962820822373, 0.05976085907605011, 0.04832643397094216, 0.010940448828478111, 0.04731951397843659, 0.04399539000587538, 0.004243861094437307, 0.013335715611901833, 0.056826514774002135, 0.08291580350487493, 0.03918577582226135, 0.04211119579849765, 0.04708981927251443, 0.019191601240891032, 0.030372614455700386, 0.04670075206377078, 0.012327001477387967, 0.05943897849647328, 0.03701438159623649, 0.07610832777572796, 0.05677117653249297, 0.06295771585428156, 0.02229048895969754, 0.046803765872027725, 0.12761227815644816, 0.0454696812084876, 0.024214872319134884, 0.01693603819148848, 0.002940707986454072, 0.036794616826227866, 0.0121106988262909, 0.07215040968731046, 0.03812372167885769, 0.04971504422428552, 0.05400152222136967, 0.020690932506113313, 0.10992800482199527, 0.06092003808589652, 0.05797549296403304, 0.036536527550197206, 0.03229627793189138, 0.023206570076581556, 0.08603663838584907, 0.06427671265555546, 0.09547651934553869, 0.014408174665732076, 0.09726654985570349, 0.05246634151262697, 0.07816141995135695, 0.011706277509802021, 0.043854886607732624, 0.05161282344488427, 0.02198536978539778, 0.07853926217649132, 0.061197994655231014, 0.0069132071894273395, 0.012645546103158267, 0.03203307896910701, 0.1938797574257478, 0.249705322785303, 0.13966554310172796, 0.11978804526734166, 0.08825519980746321, 0.15255296719260514, 0.10340178821934387, 0.21446015074616298, 0.13298686710186303, 0.12326495518209413, 0.12249045728822239, 0.07216459955088794, 0.16495732736075297, 0.15606918866978958, 0.09986958830268122, 0.08205602542147972, 0.16905723314266652, 0.12282385971047916, 0.2235903186374344, 0.21632015093928203, 0.19315368466777727, 0.11981352319708094, 0.12399973333231173, 0.22911122941877693, 0.16377282998291776, 0.18478917569154873, 0.06620605170610361, 0.1397518251906149, 0.13097491959342733, 0.2633881807560101, 0.10367895811214112, 0.12246377707924694, 0.13027568289544433, 0.2168881313991733, 0.15692714106990024, 0.1449488033540547, 0.09938607166986912, 0.11725826421752572, 0.2274820816819556, 0.17737805930664763, 0.1994717659545131, 0.07879548124037683, 0.11827381167677231, 0.15277366706868634, 0.1332442884449847, 0.21840441331733018, 0.1389984117122367, 0.12010323538561352, 0.14428967231651768, 0.14090798737015575, 0.12027703152853064, 0.1009400250040926, 0.07760481661534868, 0.1112919238221366, 0.10969740469590761, 0.14866593905026093, 0.10737431177403778, 0.10633007288561203, 0.14186025189701468, 0.09718472807435319, 0.14172679890180007, 0.08341930617461912, 0.10861841845326126, 0.17132217879407108, 0.1010357472114265, 0.16586582001764327, 0.12484684295486659, 0.08327348899911158, 0.14565265621058643, 0.10941422340692952, 0.1250792242353782, 0.12207673222292215, 0.0535621967719635, 0.20496998185990378, 0.10156682066735812, 0.1783653235179372, 0.16490883543156087, 0.14415553654544055, 0.1614282073569484, 0.10792796878376976, 0.12051697529386729, 0.17705590784316882, 0.21727790735894814, 0.11091484600910917, 0.15311971568735316, 0.10246674151858315, 0.12511695502325892, 0.24712891259696335, 0.16184762469492853, 0.1715789470472373, 0.14963744004489854, 0.1704028359381482, 0.10220241820206866, 0.24671630817465484, 0.18725525820627809, 0.16235664894338697, 0.06504536984721199, 0.13967487931950018, 0.12298877234570682, 0.11173237362527288, 0.22242531005758792, 0.1343549569719471, 0.07706788019277155, 0.1283764379331842, 0.2577692619524896, 0.20159410050837323, 0.1565918981214054, 0.11687960562994704, 0.1518677719286643, 0.20684059476479888, 0.09226713882526383, 0.12095641577616334, 0.12171336929895915, 0.12162059341790155, 0.09973750085919164, 0.08241454954259098, 0.1679270461318083, 0.14510616834741086, 0.21098568249726668, 0.224338952684775, 0.22882265271618962, 0.13849753624526784, 0.11865086722536944, 0.20173490076558664, 0.1353336122701876, 0.08569752142648213, 0.1737336689257063, 0.13334615563508123, 0.09792789991479367, 0.1229459726891946, 0.08232773310737684, 0.1452674815664068, 0.1510879083070904, 0.11151011523907073, 0.1010467458399944, 0.16304243792546913, 0.11410099730710499, 0.16100314969662577, 0.2859206451103091, 0.13354172639083117, 0.09059439733391628, 0.14353389880852774, 0.16817314230138436, 0.13204154907725751, 0.09228706549038179, 0.0925754418130964, 0.08663290209369734, 0.20124469738220796, 0.16837303235661238, 0.17728460807120427, 0.09462921676458791, 0.08833295461954549, 0.16379543580114841, 0.09276976576074958, 0.13327243068488315, 0.10833082880708389, 0.09164359376882203, 0.1056949577468913, 0.09536052166367881, 0.20094957493711263, 0.23839932633563876, 0.11840498627861962, 0.2057391288690269, 0.15645327977836132, 0.1881121122278273, 0.1216468728671316, 0.12016191700240597, 0.10086984009831212, 0.13692816108232364, 0.18328349164221436, 0.13897996192099527, 0.18002755619818345, 0.14155806420603767, 0.10383866829215549, 0.209417212754488, 0.16313102067215368], [0.048050240002339706, 0.0639848927676212, 0.07961272684042342, 0.03211085975635797, 0.07065939789754339, 0.019701495657500345, 0.17494480940513313, 0.011553997155715479, 0.0350698025431484, 0.03811945432971697, 0.02983991384098772, 0.03640870003437158, 0.019717104878509417, 0.04889831812761258, 0.03685719471832272, 0.11316609161440283, 0.011451527898316272, 0.010494104517420055, 0.0309884764283197, 0.019398812582949176, 0.03044596091058338, 0.03932060550141614, 0.032967806546366774, 0.04618104831024539, 0.019460036055534147, 0.012681995758612175, 0.026620384451234713, 0.02826205778546864, 0.07115924177924171, 0.03523077808495145, 0.0858337277895771, 0.13677852926775813, 0.02756460595264798, 0.027655409576254897, 0.024572550391894765, 0.0649904806050472, 0.12269153477973305, 0.04109925517695956, 0.02185647543228697, 0.01943892380950274, 0.08008594988496043, 0.04932604751957115, 0.031243819757946767, 0.05322224118572194, 0.015914345749479253, 0.027333354591974057, 0.021474926179507747, 0.016575675399508327, 0.05368599813664332, 0.02634568405483151, 0.04716404888313264, 0.013747833927482134, 0.09337109833722934, 0.0348701277107466, 0.06912738244864158, 0.02939892227004748, 0.025485147125436924, 0.046359367843251675, 0.01594808007212123, 0.057325872548972256, 0.02634096956171561, 0.03535700627253391, 0.02478194179275306, 0.048484125509276055, 0.040294822756550275, 0.03316180394904222, 0.03392735896341037, 0.024869943808880635, 0.06099292069848161, 0.017170280407299288, 0.037460690655279905, 0.0612251312850276, 0.01627153771551093, 0.047995406421250664, 0.027114237345813308, 0.05085042997961864, 0.05178508705284912, 0.014941960671421839, 0.04978787117579486, 0.03427456533245277, 0.02341289826290449, 0.016673236277711112, 0.029580433038063347, 0.04880640313785989, 0.03555782401235774, 0.025008126140164677, 0.05804535874631256, 0.0952317367773503, 0.024188375791709404, 0.05764355628343765, 0.009112493644352071, 0.009862112892733421, 0.015733480649942067, 0.044446163083193824, 0.03234369374695234, 0.0634766997245606, 0.019939893900300376, 0.09435140862478875, 0.008582093687437009, 0.01057936244251323, 0.024216512465500273, 0.03958669512940105, 0.026227138951071538, 0.0349501794698881, 0.022445488357334398, 0.006111065686127404, 0.06210644278326072, 0.01585798334417632, 0.01479927164837136, 0.02607867972983513, 0.03475761441222858, 0.015095602866495028, 0.038831240744912066, 0.0225563689309638, 0.03430707882216666, 0.018464916211087257, 0.04478069728065748, 0.03366146971529815, 0.005551324456973816, 0.014332688042486552, 0.016561778684263118, 0.04455814945686143, 0.06213507855136413, 0.04599979358317796, 0.0555255632934859, 0.04488398939429317, 0.054417251085396856, 0.07325448052142747, 0.021439614793052897, 0.02577333420049399, 0.024663715812494047, 0.0857020188414026, 0.04774597800860647, 0.024674022388353478, 0.019770546932704747, 0.038619086699327454, 0.013518839623429812, 0.061203976365504786, 0.02740971602179343, 0.08321338245877996, 0.04737637733342126, 0.0057159471907652915, 0.0351863271498587, 0.03773124801227823, 0.012089821284462232, 0.06186966798850335, 0.06393970339559019, 0.014496568164759083, 0.040323662615264766, 0.01828020493121585, 0.015781462352606468, 0.0874972295423504, 0.03899899951647967, 0.037026619611424394, 0.056879118201322854, 0.02918622274592053, 0.04147720872424543, 0.07805212386301719, 0.04807249330042396, 0.06309093136223964, 0.035571186381275766, 0.04457481067220215, 0.04293420788599178, 0.054139617350301705, 0.0703921727836132, 0.01549274000353762, 0.011734869676729431, 0.13709012739127502, 0.04767759652168024, 0.04058286882354878, 0.0991057773353532, 0.03145914648484904, 0.09198129322612658, 0.031782192236278206, 0.03625435558205936, 0.012837898721045349, 0.029002602423133794, 0.11882398059242405, 0.05382771494623739, 0.02649676305736648, 0.04680081212427467, 0.016582399257458746, 0.11874673786223866, 0.03969193538068794, 0.05681309674400836, 0.030579443591705058, 0.016200382451643236, 0.036115952461841516, 0.016904912517929915, 0.09541285791783594, 0.036019784965901636, 0.01553832271383726, 0.057577408661018126, 0.056196861842181534, 0.032968726809485815, 0.03819294179265853, 0.05133245118486229, 0.053240928464219905, 0.029633021622430533, 0.031074966318556108, 0.040000494409468956, 0.013410239298536908, 0.04941047795000486, 0.05247046414297074, 0.02115228860930074, 0.02222433206043206, 0.09111913284868933, 0.006773593904654263, 0.051198634537286125, 0.06408508270396851, 0.03314914290967863, 0.0388040558755165, 0.018280154836247675, 0.08534053355106153, 0.054482764171552844, 0.032604762745904736, 0.07101572526153177, 0.012053241753164912, 0.010577335451671388, 0.040266639698529616, 0.0359385902993381, 0.029007470911892597, 0.019281944732938427, 0.0334329030738445, 0.04950211463437881, 0.053598053636960685, 0.05938307993346825, 0.03534460127411876, 0.043768040486611426, 0.04784492113685701, 0.046271957689896226, 0.03779568869504146, 0.06471410481026396, 0.06413307739421725, 0.04107011845917441, 0.010840539980563335, 0.01752976004354423, 0.04466743441298604, 0.03499731326883193, 0.02711388297029771, 0.003295638489362318, 0.02942312556115212, 0.028679282077064272, 0.02009648334933445, 0.02039296021393966, 0.05276069583487697, 0.0057207641930290265, 0.0734256197756622, 0.08734615796129219, 0.02991915480379248, 0.05158962019777391, 0.03071812872804003, 0.04421442747116089, 0.10416717253974639, 0.008068971856118878, 0.019092246220679954, 0.01852738092566142, 0.017158454284071922, 0.023681180937273894, 0.0665956866578199, 0.034194094259873964, 0.05906694357690867, 0.026066386053571478, 0.020352344326965977, 0.05038988281739876, 0.03487806498014834, 0.04900961801467929, 0.03306515034637414, 0.0516575675283093, 0.0396387382352259, 0.025199162373610307, 0.028459480199671816, 0.018836006747733336, 0.06703391001792625, 0.10181847552303225, 0.03920286748325452, 0.016706694150343537, 0.019477361493045464, 0.02933926287369104, 0.05732113393605687, 0.07877617055783048, 0.0515181810624199, 0.0533372703648638, 0.011583913128561107, 0.007253136800500215, 0.03854220762150362, 0.030008637404534966, 0.039050749473972246, 0.07552837647381239, 0.06357566511724144, 0.12105447574867867, 0.05822795304993633, 0.009893149508570787, 0.09431424929061905, 0.033191953698405996, 0.06075233868614305, 0.04575554536131676, 0.03359809772518929, 0.05164157053513918, 0.05851213994901627, 0.037757074751425534, 0.008782455006439704, 0.006788749024053686, 0.043615376998786815, 0.005255063742879429, 0.018576722613943275, 0.030116644011286553, 0.0849932232813444, 0.03996688625193201, 0.04404528830491472, 0.03561902522051241, 0.01877350307040615, 0.020680802190327086, 0.021927237357886042, 0.020549289911286905, 0.03492175892461091, 0.08416237411438487, 0.019027601447305642, 0.03494982323900331, 0.01127233726947452, 0.032354005888919346, 0.06516331937746145, 0.023217175366880838, 0.01916844066727208, 0.026857797492993996, 0.05316584538377356, 0.053132827233639546, 0.07542883220594376, 0.01860071068222169, 0.004729327256427496, 0.08732453177799471, 0.044663504741038196, 0.03599455565563403, 0.06550799502292648, 0.025171662091452163, 0.04029677831567824, 0.078379010228673, 0.023590499768033624, 0.06709334862534888, 0.03162963635986671, 0.020409905300766695, 0.03370842168806121, 0.020079028035979718, 0.010255450233671581, 0.036368301225593314, 0.040930349787231535, 0.050317916757194325, 0.015714887995272875, 0.04666943714255467, 0.025471792177995667, 0.020027955288242083, 0.028123851334385108, 0.1317547683720477, 0.17139563657110557, 0.12302089991862886, 0.09502437329501845, 0.12131043506087735, 0.08516215835697949, 0.2460548171075061, 0.14126726106042042, 0.24250209680758417, 0.08490565727697685, 0.21552979334956035, 0.0986841632402502, 0.05967655852145981, 0.2114755444927141, 0.1915518776513636, 0.1614108559442684, 0.18010408646659926, 0.1502032979624346, 0.1906304419389926, 0.08984192638308741, 0.11620710109127685, 0.17385270941304043, 0.12381116102915257, 0.1792917019338347, 0.1115212326112669, 0.12056798310368322, 0.14118647086434066, 0.10930817792541347, 0.16960995504632592, 0.1223895771545358, 0.20556748495437205, 0.24061986187007278, 0.08821315714158118, 0.17236508923815563, 0.1694942096946761, 0.10636266059009358, 0.17359601537464187, 0.23643339198315516, 0.2088650400401093, 0.12683285982348025, 0.17888506437884644, 0.16292878543026745, 0.14439222228247672, 0.15701907832408324, 0.09265218730433844, 0.1348491827957332, 0.08834917796775699, 0.1299208027194254, 0.12478144490160048, 0.14547344238962978, 0.1101054523314815, 0.10258103226078674, 0.1814498970634304, 0.11091334687080234, 0.18135040474589914, 0.15477497217943892, 0.20988581964047626, 0.15573304030112922, 0.11520704225404188, 0.15668010979425162, 0.08641624692245387, 0.1253318809904158, 0.08853325285599567, 0.14936815918190405, 0.1452996610896662, 0.0758265565673355, 0.09401361268828623, 0.14040231762919575, 0.12636135856155306, 0.11750024146749638, 0.08393154392251745, 0.12780026416294277, 0.10453972325194627, 0.14164323307340965, 0.13611052214400843, 0.13545072317356244, 0.11959842653595842, 0.18761298822937533, 0.1504037668928504, 0.21467525482876226, 0.10696186320274137, 0.16219254524912685, 0.1304717137827538, 0.2713562047574669, 0.22293132118647918, 0.08396830249694176, 0.12791094806743786, 0.19289653049781919, 0.1842677130480297, 0.11697460053255782, 0.17319574544671923, 0.20196848432533443, 0.16417832463048398, 0.1366107742069289, 0.13256608421215788, 0.15226017509121448, 0.21473925764439628, 0.1778919668868184, 0.31237642862834036, 0.1345882288296707, 0.1013652014080435, 0.13675853580934927, 0.09297314391005784, 0.16331142192939296, 0.2569191169459373, 0.13285170716699213, 0.12240026408107951, 0.15584893408231437, 0.09554521995596588, 0.18225796229671687, 0.11528893825015984, 0.1336914621060714, 0.12378327854094096, 0.18340302194701508, 0.21710345812607557, 0.14682038105092943, 0.10464609527844004, 0.2370898364461027, 0.15931344270939007, 0.17220781330252066, 0.08530500694178045, 0.20489683578489348, 0.140145311888773, 0.142691234650556, 0.1146090344991535, 0.11984999233391136, 0.19232663529692218, 0.15256715705618262, 0.09165397641481832, 0.12486058752983809, 0.13747772143688053, 0.17208433477208018, 0.19733929366338998, 0.1724773910245858, 0.16290371568175033, 0.11864774278365076, 0.1263095863396302, 0.11520919448230416, 0.08023915142985061, 0.1243123778840527, 0.1398869851254858, 0.1313527618185617, 0.09662693730206229, 0.10814388180733658, 0.14541827113134786, 0.11362528806785122, 0.17050213529728353, 0.11705298617016524, 0.23313662357395515, 0.14440048980759457, 0.13843127730069682, 0.1823375205276534, 0.10750517467386089, 0.13025402702623978, 0.1983356269192882, 0.10711013688705862, 0.15891673509031534, 0.24065355537459254, 0.09469792479649186, 0.15569732815492898, 0.13516688137315214, 0.18520295270718634, 0.22405194933526218, 0.20192076422972605, 0.15915839321678504, 0.11343650796334259, 0.07702200804487802, 0.30237806669902056, 0.2106336670112796, 0.24012867885176092, 0.13017193065024912, 0.10648055074852891, 0.277907854760997, 0.1516453205840662, 0.09213209021254443, 0.08007780110347085], [0.011138471454614773, 0.045515980091295205, 0.0543201707478147, 0.05154248639883008, 0.018577420232759323, 0.0601522863144055, 0.03306496852019336, 0.020201634542900138, 0.05483351429575123, 0.02044049477262888, 0.05405577692727093, 0.04140089367865585, 0.03832878079265356, 0.026103671552846208, 0.07457731422618963, 0.08916839025914669, 0.05296929128235206, 0.04073286800121423, 0.01872657707281178, 0.07174437327194028, 0.025900946493493393, 0.04229537458741106, 0.019011576623597648, 0.030411656989599578, 0.019281469758425374, 0.043151067147846334, 0.004783907579621882, 0.07118664929294027, 0.014890388829371659, 0.05604713354841806, 0.07061229378450662, 0.02607755352073582, 0.04970436100848019, 0.013023140636505559, 0.06392615920049138, 0.06824589654570445, 0.011039625733246794, 0.06235754844965413, 0.09468573131016456, 0.04504972581344191, 0.031217722134897485, 0.06568797325599007, 0.03286345316155348, 0.06014077560394071, 0.038145874787005596, 0.022072676038078498, 0.017728191778587643, 0.026093095948453993, 0.014622018024965655, 0.02068505469651427, 0.10376713267760351, 0.06837215812993236, 0.06474396141129546, 0.02992151668877341, 0.005498652844835306, 0.010135798402188811, 0.03064536114834482, 0.07794216726324521, 0.025865050665743183, 0.010036742096417584, 0.022288681830104906, 0.05424738090368919, 0.05659588125126902, 0.030774951264902484, 0.040396578624495305, 0.04338366365118418, 0.010460043649800355, 0.09324902246589772, 0.04840737259655725, 0.0522798731981311, 0.05471879310789518, 0.03241471727960743, 0.041349570456077345, 0.08039112843107432, 0.05067118276201654, 0.00812325439255801, 0.04289814693038352, 0.04705837447545491, 0.03365169191965833, 0.013830593597958796, 0.03318468436191324, 0.05061581112386193, 0.02928254980361089, 0.06289063312578946, 0.019742586518987082, 0.1026346227445174, 0.03911678206350189, 0.029891597005189396, 0.048218451483990066, 0.0025833926383711514, 0.016492118847963866, 0.04200661234790459, 0.05616725014988333, 0.07371766230789945, 0.022694499311910477, 0.03103920036664931, 0.049410897263442166, 0.031512796340393834, 0.04723872378235683, 0.0586841660697246, 0.08330144570209086, 0.026215880570816807, 0.04497109155636281, 0.03164486894092988, 0.07499806742998771, 0.03197778154572006, 0.02400243996817153, 0.06791661304305308, 0.03312588400149252, 0.029730960995948408, 0.020324144570622593, 0.05200235449592583, 0.06924905756022781, 0.06990794368903153, 0.09420519068953581, 0.029194707349233795, 0.03375105436134618, 0.09197367879096419, 0.0229301107901847, 0.023743367346469313, 0.01681727786490228, 0.06452476809499785, 0.016001026742742397, 0.09908533116686158, 0.03171648619172629, 0.04210513987345621, 0.07750677148578689, 0.017950349974853452, 0.04129727873078082, 0.03757943799428176, 0.12402192354784347, 0.03795873482886236, 0.005902430348214693, 0.035618156907730736, 0.04406252839544322, 0.07827499823179096, 0.04143614569329657, 0.051821882734657265, 0.04118735552765429, 0.016339260546374135, 0.03298871284641791, 0.03834458111668937, 0.0686493948160205, 0.011776081137213623, 0.07072440261254087, 0.005963419580439222, 0.03236451470002066, 0.021754372610303108, 0.03659307178168092, 0.0021397513683041325, 0.10437838034704328, 0.026707167489803396, 0.03233640585676767, 0.019774528554989956, 0.08418741417699493, 0.039662394192419015, 0.03282490972196683, 0.0360154767986387, 0.045728820623480715, 0.033108948191511445, 0.02323394419363467, 0.029145707048883196, 0.04032144359371159, 0.06243239404284395, 0.035735861529246904, 0.05416328443970997, 0.027972295501967892, 0.04102514430996962, 0.02281213157402817, 0.045583537794300355, 0.020149383635725826, 0.07095553708495572, 0.04713863774668425, 0.03278309712186456, 0.02153388981241733, 0.07469656251487322, 0.031221302997437306, 0.027361431893950794, 0.04317717219237238, 0.014668231560790446, 0.017258043080801144, 0.04137666255701333, 0.07960679708048701, 0.025150078581646085, 0.05844326122314669, 0.03228544257581234, 0.005268188624540926, 0.04161962315265555, 0.03911491185135674, 0.023676928431086708, 0.04379280595458113, 0.08171623310772702, 0.05174151185201481, 0.03933314779715147, 0.09587769469362684, 0.068720373819815, 0.04250233730999753, 0.016020667681004852, 0.04534000203420874, 0.07430384765029885, 0.021739002731919754, 0.023745664293528534, 0.039620232782908715, 0.02264690352603793, 0.015592058844049461, 0.011944876132474747, 0.07750505712465383, 0.05238631201791577, 0.01977173251361819, 0.08055226353462785, 0.05683065966877621, 0.033251076893066056, 0.06681515456875786, 0.04293107602279633, 0.011772010457207216, 0.025966956818592735, 0.04403962200740352, 0.016261320197372697, 0.03219258876924869, 0.02093132156005595, 0.018688610653043725, 0.06543693438288756, 0.03714671765919775, 0.04279093256627675, 0.02149119220121065, 0.03573680034605786, 0.03987621807027608, 0.037324495424400084, 0.03508061563479714, 0.04258750246663112, 0.13783801929093897, 0.038682458689436316, 0.024606700317235664, 0.03203599189873785, 0.030358007134054787, 0.04819344852876384, 0.08256567307398655, 0.06021194014465436, 0.05960405069345143, 0.03229956564609893, 0.03473028111329768, 0.012900313340651337, 0.014549828392773634, 0.07735035644145682, 0.005081636354589136, 0.015860465828154702, 0.10114067947142757, 0.040351834541070275, 0.030769342483836226, 0.032867431073100306, 0.025339437561342493, 0.0257123370829504, 0.025688415807962883, 0.037678811568184756, 0.04189160172245465, 0.018241045509057585, 0.018336257489863783, 0.05528170469915494, 0.009811287836782867, 0.017927825792867225, 0.027827580415760167, 0.026732597179943696, 0.017850724070740398, 0.05653523294313345, 0.009566469088895246, 0.02464859455358237, 0.01670439163717674, 0.06798322821850888, 0.022149950309540145, 0.13697576243430376, 0.029114711251168046, 0.0370610552636208, 0.011380855958122993, 0.059370021845097654, 0.04460137213754933, 0.040592308941995725, 0.020427625931915827, 0.01400543709678459, 0.07594141876325011, 0.0780232617398724, 0.05675324995536357, 0.06736604336765595, 0.041720915178302675, 0.10558128298725933, 0.06675493670627475, 0.018918680143542588, 0.0060811664116044994, 0.07092809246387333, 0.029588672732643317, 0.03405233292141929, 0.05952365383564029, 0.03422476722334977, 0.09016755851916969, 0.06561911679455079, 0.03847812316962518, 0.0025356709193147253, 0.020699094275187235, 0.023391273934976198, 0.031758859113324434, 0.03838869808532763, 0.0340024680190254, 0.038543313421541825, 0.11183347640326247, 0.06225560333405156, 0.07426322990795597, 0.03138978536298964, 0.02770396829873789, 0.033741836887202226, 0.03299628646345809, 0.03327091078972444, 0.006026332366673159, 0.03644156975497026, 0.049547400485607795, 0.03096620086580515, 0.08688852001796477, 0.027666102068906184, 0.0590715411817655, 0.03716532330145128, 0.02168701343180146, 0.015357792508439161, 0.05207740417972673, 0.016700187370588537, 0.04293731748475693, 0.008706422904651845, 0.0475695806380827, 0.02577902276243549, 0.09016461961437017, 0.0663600473490078, 0.0249112276287633, 0.02555228551500477, 0.026013361457444262, 0.013222687448433135, 0.07417256914777681, 0.05275559356960002, 0.07932659922516905, 0.042365036279079504, 0.03552444220986217, 0.08769051448325627, 0.028698208698187955, 0.0371509553224314, 0.018787268054438755, 0.033956673796637915, 0.06001277739414945, 0.019526191099430434, 0.062292989023262635, 0.07218808852485381, 0.059504439632291906, 0.02658967252500588, 0.04219989357807208, 0.008269458412542008, 0.03099732282862533, 0.039578702198923565, 0.080872656108113, 0.11336504656355828, 0.12690118193859234, 0.28769274533260614, 0.07649193648830988, 0.1291444420348853, 0.19236893771449104, 0.11439905865699984, 0.12877645553089678, 0.16285209188936278, 0.11226863469346426, 0.17194671090692282, 0.147148959513288, 0.07323604557313956, 0.13304690684890375, 0.1527687392081134, 0.12355491970083676, 0.1612235081847757, 0.1537589423242025, 0.12939257168909535, 0.1899349011364393, 0.14551853528246284, 0.11553280055522919, 0.13665136968484148, 0.13223698624642566, 0.10573779451078735, 0.08904189118766226, 0.10424080843222328, 0.10195607712375931, 0.10172870534006506, 0.25702735176309943, 0.1553392270579934, 0.15764286828925833, 0.16805714461952448, 0.12218712668982334, 0.11142407063744031, 0.1823435170808807, 0.21080256497953087, 0.13523921108571813, 0.11757204425521195, 0.19466909085167572, 0.11024690567865036, 0.12809366482542828, 0.14502131118206307, 0.14582510164473206, 0.16562000586418435, 0.15566422836855054, 0.14849046565359458, 0.09018741096951999, 0.10461871745064855, 0.1399787442642264, 0.11905797975487076, 0.13598492107121274, 0.14171499875374138, 0.21379073354182765, 0.11405715864384547, 0.07539066355093382, 0.24950621940661222, 0.14816099661402404, 0.14344353490741923, 0.16772685921750963, 0.1689273424562998, 0.10982818595948629, 0.08641291467938572, 0.09865023966995068, 0.10977264362736605, 0.12930158438393846, 0.251334099448286, 0.08852946790284477, 0.11532928881933913, 0.195764382078778, 0.11040419645723887, 0.2629179263021797, 0.1336715873912908, 0.08571141443098895, 0.11390823186957277, 0.09691740648122504, 0.09463669761316851, 0.16566178877837956, 0.15081038960488513, 0.08285786403575912, 0.1961501207551919, 0.09949580562533811, 0.08956038524047472, 0.17317544028628618, 0.13675820926437154, 0.25229853519704193, 0.1833900046767667, 0.20799659367185086, 0.046174424642231315, 0.08622216788353398, 0.15252178214723244, 0.12006272154394537, 0.16143407032359391, 0.0876522641920019, 0.11961696538492106, 0.09258742007659748, 0.12577901012264192, 0.14305246761068702, 0.17343946674373, 0.1669795165071264, 0.12899435008876026, 0.17198105750139803, 0.23605801368830726, 0.15965269325533882, 0.1650698814773932, 0.1148120489961002, 0.15251783392159268, 0.16738566424464807, 0.09338296527857892, 0.09828126610955223, 0.25888034608215094, 0.16681093024089932, 0.1155088069208432, 0.21517948480322957, 0.12792847759556025, 0.12363810703391209, 0.3318426356418058, 0.1011769704928156, 0.10914287195191719, 0.16456927318358794, 0.11839792103273794, 0.13612499402370304, 0.14086868322920054, 0.10389683782705106, 0.11380214928067289, 0.18418134190142155, 0.106326228560647, 0.14972366276197135, 0.19626899797003716, 0.23932030191645026, 0.14009481616085395, 0.09589344306732528, 0.09569065863615833, 0.13798307947581634, 0.20879744522972032, 0.13222251436673105, 0.09878346259938553, 0.30705843586474657, 0.1445694619906135, 0.16616524691926315, 0.13587897206889465, 0.16133533499669284, 0.1141947899304796, 0.23416476527927443, 0.13852394185960293, 0.2573939133435488, 0.12230934356921352, 0.08933071279898286, 0.1397766129230149, 0.19396477786358446, 0.14293721207650378, 0.16409309639129788, 0.09576532611390576, 0.1660568785155192, 0.08782421238720417, 0.1938719500321895, 0.13139402522938326, 0.16739504499128088, 0.18387631920631975, 0.12628996395505965, 0.16733856755308807, 0.09685882134363055, 0.13437919551506639, 0.10697728503146209, 0.18840806587832049, 0.19001987704541534, 0.14682214736239985, 0.1315139711368829, 0.09797509308555163, 0.15049067238578573, 0.09621137171052396, 0.2534577698679641, 0.13492740516085178, 0.12601528025697917, 0.12101776170311496], [0.0264622550457716, 0.04042077634949237, 0.0664294084708672, 0.026674013897718396, 0.029083336958137807, 0.012320300811552443, 0.029010330035816878, 0.060365130557329394, 0.03834813600406051, 0.041896896946127526, 0.03972935075580608, 0.020458560502447654, 0.03277887801232282, 0.020990370539948344, 0.036489898411673494, 0.06859929242637008, 0.019471133018669207, 0.021186054473218974, 0.018756476347334683, 0.017422376840841025, 0.05576138813921716, 0.026442244889040012, 0.0689295407210011, 0.07009829714661464, 0.036447302845772356, 0.059838417218998075, 0.04681177364545874, 0.06534496002132073, 0.05674690459272824, 0.01864559391833609, 0.03642081188445445, 0.06556658758199774, 0.06012764330080245, 0.015906169137451798, 0.05504417662450578, 0.06641830594162457, 0.03052108109841356, 0.033684056979836896, 0.04280984248907771, 0.04724976693978533, 0.039489878254244104, 0.04047844864544459, 0.04283623326045927, 0.031244584170053713, 0.05807858469779603, 0.025754700727702584, 0.014229004445951432, 0.03783863678108901, 0.07040922733722255, 0.04843527734919917, 0.013438028090604348, 0.06612022232729942, 0.04901805994450115, 0.027285901669529267, 0.00977301899183658, 0.014429321236093529, 0.005932364874752238, 0.007286836334969848, 0.014927529609849444, 0.026248047106491867, 0.02621827028633561, 0.003112951881121262, 0.022585696751775686, 0.04701144847786054, 0.023160558775998652, 0.01711688844807213, 0.04294207836210262, 0.037034334236523136, 0.0006457506947299407, 0.05246747699857224, 0.0272620583200478, 0.041813787538558245, 0.04633308097254485, 0.015132751996134175, 0.11980249488260597, 0.031917088708723895, 0.07731803591013886, 0.03942816496419255, 0.03279955795733258, 0.04490869920118712, 0.09330377812148072, 0.022821623642812483, 0.03614472923800349, 0.047282269297284074, 0.023589683405589312, 0.03707439907884691, 0.09050403343280777, 0.02693393256777199, 0.055538279993925244, 0.048086286114994437, 0.053761812232551165, 0.0978178765217308, 0.0031786247609488782, 0.0276676253270125, 0.04045927526021842, 0.03450447526120115, 0.009409522481291788, 0.03766410220123362, 0.060702945047523826, 0.02667969874892151, 0.05090715974802151, 0.043434404287836514, 0.034254594138474204, 0.1085165809490718, 0.06819544534664601, 0.06462748875492252, 0.01834017788496567, 0.05613646215351764, 0.041961801471188664, 0.1087395146896597, 0.046526295409421436, 0.07593746311613359, 0.07055868103634566, 0.03778513535507955, 0.01978012249310268, 0.016764372012403328, 0.05326612066710368, 0.11400180927012116, 0.044347416624077596, 0.03182489541359246, 0.023894320183899254, 0.012563041545945453, 0.05793474534584675, 0.009304874092777027, 0.023497803667851258, 0.027332274767104536, 0.052863167875329964, 0.03158392006298527, 0.03236169082811102, 0.06969956346438266, 0.03287996965809725, 0.031080070439202245, 0.04909205948933959, 0.003962632117691101, 0.05784933156974148, 0.04700241654063575, 0.04353382610133849, 0.022425068164011464, 0.10621383771649562, 0.0198772770454525, 0.06028980256814975, 0.05759304571256507, 0.02980300869239727, 0.019071119131695013, 0.005160554019312258, 0.026145523115701508, 0.018105163835571148, 0.025188176732626744, 0.013845815974491416, 0.013312579158082372, 0.014451512379309861, 0.04197809532342944, 0.03690144527354278, 0.09692079809610732, 0.02293751185789006, 0.036877217862638645, 0.06568745375261642, 0.026463119647814892, 0.00811375119155855, 0.064840203122003, 0.025452141962887254, 0.018803140737873036, 0.057578072883188725, 0.052432347438298166, 0.028423948024283163, 0.04632732932805084, 0.08504464669385925, 0.00564458087865205, 0.026716958273027558, 0.014013700911164051, 0.02897503163694637, 0.05106709257233888, 0.0679777363257017, 0.014683803674415685, 0.04327904309320729, 0.04078345278685447, 0.04842162183194887, 0.009622901998227462, 0.031840695737628266, 0.0364678529149387, 0.021924764150753617, 0.05750753545726184, 0.05665415097610094, 0.025170964472636115, 0.007145798590499908, 0.03624813267379068, 0.050226191015099175, 0.04524138545093592, 0.021421966521302238, 0.0596373211737955, 0.03426401941396762, 0.03840503275569063, 0.01896476936963154, 0.03427868054131977, 0.07160518347518519, 0.048829739971552044, 0.01301909685935243, 0.06411784852389246, 0.04115122777875513, 0.036378446384333074, 0.02613475084217498, 0.012886841504951008, 0.06097285673604347, 0.08007204945897684, 0.023003434980637394, 0.08371727104531601, 0.03949898440623656, 0.04002376073913183, 0.04320205269323196, 0.015646801512048114, 0.057684604471432976, 0.03519096928357612, 0.02594864803540986, 0.019958057964686304, 0.050993827753700316, 0.019151143060298637, 0.03729398573341314, 0.006199785730132135, 0.024816468358039856, 0.041510679584462196, 0.03212168769096024, 0.028178508655400947, 0.023725884202576708, 0.02072506758850068, 0.07007301959674805, 0.02383515802648617, 0.021904312416154426, 0.052368919787113555, 0.03465711277385708, 0.025441139623580966, 0.026558737954474054, 0.04770771658513695, 0.019749865132325795, 0.025957616890082136, 0.05389053403632715, 0.04777132977324072, 0.013004750217078254, 0.022302428260445595, 0.058381881899549626, 0.03711234880029224, 0.035251791996415704, 0.05914536632189993, 0.021445004640554544, 0.04728515254100785, 0.0914078060304746, 0.028969207633053884, 0.024896405084291473, 0.01544804879813455, 0.04352652707893867, 0.05902437027543783, 0.03467970745987259, 0.025123595041804947, 0.13002964609768242, 0.020778619109478313, 0.027213158209633548, 0.04230619510053657, 0.032959568707155995, 0.05212562893575523, 0.019397139039938338, 0.03204417778761126, 0.03113075355940964, 0.028598759054148104, 0.07357519963989034, 0.030094522444414906, 0.035434749952401035, 0.039640133472858, 0.04771844804054126, 0.027399316677474417, 0.04901908410829492, 0.0995776496711187, 0.0318417941161897, 0.015345898664236302, 0.09408815400092863, 0.008984189298644196, 0.02704661470488645, 0.03328657381644007, 0.047625200895708986, 0.10159287005080841, 0.028468719938246068, 0.03802367646130733, 0.036101491714362055, 0.038114578419481404, 0.05718114633054938, 0.04745467391330749, 0.020844835380557925, 0.01677278425631812, 0.06484683792223223, 0.01898214490211103, 0.034344256710028276, 0.0765418607625179, 0.0459829208557494, 0.02566742416092893, 0.10399797771242447, 0.045521946958615445, 0.06156608877063263, 0.0813699618447572, 0.018767816363833845, 0.01949995246832259, 0.03466023350483738, 0.01864186648163013, 0.034460206152289174, 0.04982737569662277, 0.07370829640422016, 0.017988338659051806, 0.02266765026433859, 0.04699296900071204, 0.06169635795231443, 0.03361100367328618, 0.0389421584259253, 0.06987327054957859, 0.01920365928526735, 0.01814070528780576, 0.02269403175887419, 0.05147607902472373, 0.07170408949605189, 0.02668350967724109, 0.01015998685033992, 0.06636041842284612, 0.08612555509898812, 0.015242808785842499, 0.052530155080603436, 0.0361971805250505, 0.06360409679473378, 0.043637203561956994, 0.03818776531261392, 0.033028903853846714, 0.03364794407389127, 0.012901122281618882, 0.04715637507615611, 0.05035218542616349, 0.036104141181567684, 0.02758933431323385, 0.06555419371579774, 0.005161954359209631, 0.0618392918840982, 0.038923400643398054, 0.0549444022908574, 0.01619011483853683, 0.04016475024400279, 0.039874477733974345, 0.05003326972655486, 0.059336480480851606, 0.05750443699071184, 0.028512269163911697, 0.023953788477228954, 0.03762863496376667, 0.024699767491256353, 0.03842658472422045, 0.05511193841812201, 0.07352325672400184, 0.06390158669091761, 0.030415382570936345, 0.1569375311373733, 0.14412208052817732, 0.11725396718247794, 0.12040718938806094, 0.057140825447277166, 0.0828340559382923, 0.12046978212310933, 0.1458314692717977, 0.1347509224433452, 0.10996344237355515, 0.1969900241238065, 0.16759270860347897, 0.12302247327170335, 0.13377685361774638, 0.12854330241680145, 0.19160096329869702, 0.10268851750879548, 0.1235486930818297, 0.2184186625527218, 0.10071196302305907, 0.14469630987150595, 0.12483424128731713, 0.16948053933447227, 0.12684022192843258, 0.11664677906082943, 0.12284120370168239, 0.17231670120963827, 0.20430332544492558, 0.15876224962994456, 0.10816978276125155, 0.12521373108029366, 0.1989968359703198, 0.1213843678124249, 0.16130633186548948, 0.09055438073119149, 0.15806133567821234, 0.18237485055578873, 0.17745616292813793, 0.1867035307805054, 0.13123551732860506, 0.13999615504872054, 0.09440078370971605, 0.1592732925200835, 0.11308694156468846, 0.15641261008568108, 0.13837926759151742, 0.08716245414689183, 0.09467619471251965, 0.19051460752962157, 0.10714155941968784, 0.20163880748441443, 0.1989799298462458, 0.1551031944109127, 0.07577795331599191, 0.08886383511708118, 0.1587934495182708, 0.14216846582712606, 0.08848611163557507, 0.1440610017743893, 0.1864592157653533, 0.13577723846537992, 0.07134695319109596, 0.16548619663808495, 0.1555217953864485, 0.1345418594428338, 0.10639496627845801, 0.09044258360518143, 0.1110315858386457, 0.22158669802593067, 0.09614791808417067, 0.0754187983693555, 0.15968920692102984, 0.09065416248631664, 0.21543686161749065, 0.2639123151311651, 0.0768060950213112, 0.19524851522874087, 0.23934161639772356, 0.08985694745206274, 0.10095911304233596, 0.1920662898919545, 0.13414133718470111, 0.0732483429601416, 0.15914923511445522, 0.11265918248682283, 0.16569039114983752, 0.22155027341796085, 0.16615718719549477, 0.16073876700829715, 0.15043665887787938, 0.2086434792727232, 0.22848644497571513, 0.12629609409486875, 0.12980946572497487, 0.238774853060022, 0.11848160560475662, 0.15759887377498671, 0.18159451195970178, 0.10514015782973729, 0.09340315911686048, 0.14030181599082425, 0.2771807578392327, 0.15379236865555868, 0.2646864642156288, 0.25063547131139785, 0.12572688166983426, 0.1868621722678654, 0.239823151496239, 0.14665115653770044, 0.2457844527089037, 0.09665050791227259, 0.13403574441326782, 0.09733031518408097, 0.1736720558255911, 0.14671232434920967, 0.16688075149431825, 0.14963493158575147, 0.23777443799190223, 0.1284004983608611, 0.15108357416465878, 0.14663831738289446, 0.11868872417835519, 0.16005599114578217, 0.08427078704698943, 0.07690875630942173, 0.19699355674674734, 0.15131138381548226, 0.07957314068335108, 0.08703812956809998, 0.1019564778835047, 0.07548612600658089, 0.2390398146235384, 0.15801648027263582, 0.16641705762594938, 0.11941909397137351, 0.11674302819301374, 0.15804635913809761, 0.08589945238782093, 0.25809809274505824, 0.08605850947787985, 0.08722328799194656, 0.20222807273967192, 0.08907801893656142, 0.15105357655556872, 0.09961149902665056, 0.15957252646330744, 0.22661954280920327, 0.17398390627931803, 0.11419200687669218, 0.10219330462859944, 0.13021111604757607, 0.08248701284173876, 0.10677844140445814, 0.15884220862062648, 0.11660038740956225, 0.10732968643424101, 0.1892092588241212, 0.07039854041067883, 0.1528086222242564, 0.13783506554318592, 0.13533990568248555, 0.07306051280465908, 0.20219132158672437, 0.1101004502561409, 0.19742707489058375, 0.22689097590046003, 0.3086689853807911, 0.15763817791594192, 0.13779058121144772, 0.14518734446028247, 0.11773416641517542, 0.12527341459644958, 0.1691741807735525, 0.18052924802759662, 0.19869810668751597, 0.15916862001176924], [0.0649346636782866, 0.025462647063250188, 0.04286589319235645, 0.06576183179276995, 0.03500957725918852, 0.04640128434402868, 0.01858245384937618, 0.010242382868455024, 0.027075534344476182, 0.05394757550675422, 0.03823161510808859, 0.04879780164628755, 0.07324665086343884, 0.025478660754743032, 0.005473954170156503, 0.018164236935263034, 0.014040714158909395, 0.026110185754077975, 0.050401471453369595, 0.07554570562206209, 0.034061116239172406, 0.0908627430908382, 0.008163089169102022, 0.04079880782228429, 0.030053268310439307, 0.03129137658106629, 0.061994630814297125, 0.050972884346265346, 0.02548534750530962, 0.027497447154019028, 0.03977959044277668, 0.09126411139732227, 0.0360563320282381, 0.08659834769787267, 0.046668030772707425, 0.020768039794347715, 0.03816079937678296, 0.022891444896231405, 0.03963601826399099, 0.05564312690694351, 0.016636813525110483, 0.045307154578040354, 0.03943326351873111, 0.028135920510976575, 0.007139129929782939, 0.07037211995339021, 0.023221600422402844, 0.018754650664050132, 0.046065944916335866, 0.025595061051717494, 0.03948697274609003, 0.018726163325482048, 0.09691312428913079, 0.044916992701473646, 0.0216645189357223, 0.03966021598898806, 0.07477731560356915, 0.010024033745139604, 0.07704579387791455, 0.01867006067186594, 0.028385551158862654, 0.014837585022178246, 0.023712365982646588, 0.011229876217839774, 0.01158906270575244, 0.012929072490805993, 0.049077420626417734, 0.041918181741493754, 0.035403204965405166, 0.047110454688663594, 0.05086173288873397, 0.02057953242911026, 0.026942702897940762, 0.03909436178219039, 0.02475327448337339, 0.023493647640862036, 0.07901442964794114, 0.033655079823802225, 0.03412088510231115, 0.037369996498455293, 0.026274564042978454, 0.005647484995279228, 0.05586915540334303, 0.08118426165310666, 0.07541592625784688, 0.022745097085135058, 0.05374270192987751, 0.055455597321270034, 0.04809430873137899, 0.07130304031306878, 0.031554512461298145, 0.02295597649208503, 0.021710461587645113, 0.037036100547993556, 0.07265779378940351, 0.0329780259198742, 0.060694647836498916, 0.0533290139719611, 0.039486390160163864, 0.0015430787834702642, 0.05307972285663709, 0.025277297536376864, 0.04113373164727818, 0.005214170942053897, 0.042090501010534354, 0.03583935773349367, 0.0338388021918945, 0.0035581987413024763, 0.026492937286093365, 0.05897195609577466, 0.026390125713078305, 0.023330321346293204, 0.028062151031917892, 0.01975446088181343, 0.02799654146656394, 0.023006377596175298, 0.08212034736061469, 0.022493037758977152, 0.07265119609655812, 0.01757242611347465, 0.03558311269443948, 0.030624759128841106, 0.04989034692698624, 0.03294706722954288, 0.018096888888976537, 0.043102801573695615, 0.03909363818820566, 0.04990413974155672, 0.0529689944232814, 0.07599846023367718, 0.028969567574677058, 0.08615259153884836, 0.06321720778942108, 0.1209305519296322, 0.05802978477731813, 0.09680126036982983, 0.027891920908587053, 0.080629736330593, 0.02607343645649962, 0.03704541450133547, 0.03982382986578159, 0.009384200402564602, 0.0539513641706435, 0.04000341476057656, 0.049329739704262465, 0.09022537182318047, 0.1076338927668985, 0.027720553443941753, 0.022084515148890205, 0.04633284348528832, 0.04495667904848233, 0.08929373158025555, 0.05082361618406139, 0.02064951324427966, 0.034116127935703844, 0.032366214218200184, 0.04588340627378784, 0.02858720010408433, 0.04103146740817465, 0.012721384318865603, 0.11199628876056522, 0.019491072671371512, 0.029899395121901762, 0.04821975395316258, 0.03627052326919511, 0.03106713109445991, 0.012655634673137683, 0.05669219346600585, 0.10664555986295454, 0.009085246620088583, 0.034635200863704085, 0.0464445478428388, 0.01741401469189441, 0.03762443069717847, 0.006894210064274375, 0.05558041542826686, 0.0753516711120028, 0.022336021575029008, 0.01067940951543278, 0.04970797155692708, 0.07932599808555096, 0.05295550588925835, 0.07440598943503574, 0.029816244896210264, 0.03128897944407072, 0.070241101202555, 0.00825419336251798, 0.013936807918071281, 0.015074583388923202, 0.04364584958238993, 0.0794946363021154, 0.025367850685142912, 0.04031322801893111, 0.047286848348448984, 0.04022458961117081, 0.0288669545261655, 0.07910250031272881, 0.00807753438493819, 0.056924014425021596, 0.03338174312375486, 0.03807647284702398, 0.023676074961258564, 0.04307752402382903, 0.014995853580330731, 0.1445417947252281, 0.05660000388161279, 0.016119788924697787, 0.07610409753397107, 0.013276919889904093, 0.04891279371804558, 0.04669773523346521, 0.022391986931324936, 0.019668121276481543, 0.020586456666933373, 0.03660367336124182, 0.04593080353515688, 0.031138857812038623, 0.06256661145016551, 0.04513237508945167, 0.02488387021003291, 0.03475810051895678, 0.01523448467196431, 0.036600938547053374, 0.046382122091017663, 0.01354273585093324, 0.036643845814978704, 0.06337127764709294, 0.007585155117340037, 0.0306878583796788, 0.01569676103827078, 0.031132423391682096, 0.04559377201076131, 0.0761167511518579, 0.06182135046401527, 0.00092584140247709, 0.022598196374019608, 0.011433635645516915, 0.028173235696158372, 0.05865790146344807, 0.05273629030853044, 0.03673789819004014, 0.050356003775959834, 0.025354384415550157, 0.030703252377861645, 0.05481250409502536, 0.01725420432194369, 0.04558493303193245, 0.04654324606235605, 0.0185510665687616, 0.012579103477037279, 0.009725994659675052, 0.019992669876955915, 0.061429047491401434, 0.046916286592022516, 0.06999034434556961, 0.017016166020766832, 0.023630837349628564, 0.010663712164387107, 0.040329503317479976, 0.026083093653141987, 0.00863098081026692, 0.08429862500634044, 0.04292402561986819, 0.07565009611425921, 0.07024884922429919, 0.01861336986621609, 0.037914476852165535, 0.018419250009173993, 0.031451023678528145, 0.024832246417645365, 0.006659821274297428, 0.04537615575827658, 0.01861905100668082, 0.07265990148880519, 0.04238106666889507, 0.013836432444804814, 0.03301141143310815, 0.025056725680769887, 0.05023563113354612, 0.04835251675103791, 0.021981300960760564, 0.023257212378666736, 0.039472285643569194, 0.008711725549801486, 0.02603290406113956, 0.04040850493765902, 0.044661597421509214, 0.028143562776676845, 0.053742486707051285, 0.013291555969772162, 0.01064144680640311, 0.016302971380355302, 0.10736919095506892, 0.029155147167330142, 0.043886227504117414, 0.018837591233022977, 0.033076828040066175, 0.010468344571563648, 0.03705069117131643, 0.04695333460404072, 0.04613671982951928, 0.021663012375938706, 0.033000409093801863, 0.05771545926108956, 0.00997126333459164, 0.025738059921422973, 0.061727416832582094, 0.03157807936077006, 0.025820666523941327, 0.009647950409998884, 0.049613626033533365, 0.0673505621671211, 0.01812121092370944, 0.014059559143788647, 0.04480499519559089, 0.028102781761845108, 0.024785717469058, 0.02805233612889424, 0.02949287445517257, 0.0315797083749203, 0.013233921708888374, 0.09881056583253667, 0.0036578587378244265, 0.03241396771045402, 0.023708297158009373, 0.0422684531804407, 0.04785274337336887, 0.11090046318713576, 0.10043854097602889, 0.03267476582550444, 0.021070839757157955, 0.04588895753840916, 0.023182274017017335, 0.022348318962031044, 0.03495916316751391, 0.0601684651337564, 0.09008106862893328, 0.07263580395374447, 0.11885020809131674, 0.050975006888620555, 0.05610266103758477, 0.05285881517920643, 0.023459768599423114, 0.05925649922573939, 0.05056533766037319, 0.008320290889969328, 0.0340315713401651, 0.08015056868316606, 0.07176230355980806, 0.02159162519092206, 0.028281583690841217, 0.05483806366100907, 0.23268760938663036, 0.09217907558195293, 0.1428347363253124, 0.15519945096457377, 0.09529842616757378, 0.14279840077506378, 0.21224478055955842, 0.1364796218695119, 0.21865258750040084, 0.2142756973626092, 0.14807919709710404, 0.12994570919545367, 0.1812083725235425, 0.1485633000265807, 0.20260475721443072, 0.12436528559192084, 0.10617872670991346, 0.08225185592891648, 0.10515419926377945, 0.10336597959394567, 0.18255449482239783, 0.20101669477298856, 0.06034117403032724, 0.09427300072275102, 0.13191848614951596, 0.12252418790012598, 0.15966784791089594, 0.1404427201487124, 0.20219099504174665, 0.1252687835949473, 0.16894364001927897, 0.19254994753282517, 0.11832553936983459, 0.13147704186849296, 0.15103900077519938, 0.10416950288345106, 0.15031515446025878, 0.08187765764887445, 0.14714674791321158, 0.17785330099286512, 0.1031889402656816, 0.25058669736608863, 0.14341166708618402, 0.1371173345251009, 0.13514758553355932, 0.10739619770902209, 0.08288683005957864, 0.09763303722138517, 0.15601204329868779, 0.11267464142292738, 0.10500480493647046, 0.17259266140172258, 0.20536112337140366, 0.059893614452448674, 0.12716921599349007, 0.1188838570669759, 0.20052612031577155, 0.1166999019915238, 0.15465707459952682, 0.09645654761698097, 0.10583180977846496, 0.09465460563660599, 0.10248881299048662, 0.1707512149005197, 0.1377346381195821, 0.102638608077541, 0.16783680097432807, 0.09219044528435916, 0.14478735654847696, 0.16623659699689597, 0.09832612151512876, 0.11005328677129, 0.15722224867204204, 0.12647403142182156, 0.12447357235942036, 0.12050700082909316, 0.24261916318209842, 0.17327926674624905, 0.20344001473858953, 0.11573555530048907, 0.12978179845958948, 0.10948253810056485, 0.16731516021536663, 0.11876673132064752, 0.1616902300156653, 0.1506232051178813, 0.1543675479479134, 0.13918808981543407, 0.1767578168073669, 0.15652419941034168, 0.18926975870272145, 0.1442086446331814, 0.10800730437040329, 0.16826270468300208, 0.11553622185601853, 0.20803594234166667, 0.1382807400659658, 0.18345519492868334, 0.1760605096933432, 0.11890881549334154, 0.1750523762893863, 0.13369698368478566, 0.08054470104980282, 0.12037066830089316, 0.11545647808816284, 0.13378047529840842, 0.13841610780218616, 0.13632725895149633, 0.08133588984492235, 0.18177287973230705, 0.22259851248236373, 0.13628531276481226, 0.14300994254881516, 0.1563023417838849, 0.1118989115639124, 0.11534114091773517, 0.2117914767586626, 0.0992320834484417, 0.16967841074801981, 0.10772683934192173, 0.062106520708766766, 0.12422922023688443, 0.1273167846375145, 0.1797924141283147, 0.1334325416246429, 0.13200166606111452, 0.10866090640774928, 0.11657902839942835, 0.10334827937185764, 0.1780598406912759, 0.11982567215454765, 0.15384777740109712, 0.17559634085046127, 0.190260614908766, 0.12007158278720453, 0.2503354358486831, 0.06961169317946769, 0.16189486981602386, 0.18657375883776695, 0.13418665272183716, 0.12884578696684912, 0.09340816861367784, 0.21345416957046837, 0.08805969584500417, 0.11637851494015194, 0.2893440832849592, 0.1760228382772766, 0.13486108684446663, 0.1723503353423439, 0.08861825845087878, 0.14228020358132198, 0.19615335651906207, 0.18606970697874203, 0.09318052965682, 0.17491785460151732, 0.15721577714430168, 0.082563624746399, 0.2057854537270032, 0.09616294657462277, 0.10334691382013261, 0.170985703880433, 0.14644515118561685, 0.170385395467747, 0.10726503795012832, 0.14021041308296844, 0.18019317387370393, 0.15702534205047414, 0.12694341014139354, 0.18955404579173774, 0.11064520891522989, 0.1002285057620611, 0.20790694223251194, 0.1988077218993567, 0.11445076408563182, 0.1592942062416114, 0.11762048423406668], [0.04914624740194995, 0.0788622819527518, 0.11811731499619782, 0.07542406761785969, 0.01879069492133567, 0.04012826997495722, 0.023603023510077037, 0.02400728433713084, 0.014433912347158184, 0.020031580679642502, 0.028599267425306607, 0.028250209397810977, 0.019029161812795792, 0.025610243537812494, 0.05617046736006159, 0.023951793955347966, 0.023476440946978983, 0.0340340723778354, 0.05617860872007441, 0.018280507356394082, 0.03506504166580271, 0.03866615741571877, 0.04289469594368711, 0.03491525028948672, 0.05142924579558894, 0.03239443809434306, 0.017312895215582103, 0.09245821958757006, 0.11390435043722391, 0.023647366833756678, 0.007433349737766548, 0.06078498947317712, 0.07904570375103503, 0.04968667191860732, 0.05341624600987416, 0.03363093033840414, 0.033438417231081985, 0.06818679190473631, 0.05477507758769207, 0.05252789895166643, 0.04913184602628462, 0.08598164524300955, 0.06190360269101802, 0.0199269193035434, 0.017293584533035755, 0.06830638158135116, 0.021667613691533916, 0.051662680925801396, 0.02778671962005319, 0.013285639197420096, 0.033515441027702764, 0.05244932406640146, 0.02724634705373319, 0.047972744941944256, 0.03560453849786427, 0.01702338155155303, 0.03351816470967606, 0.028332444926491007, 0.07917603972600773, 0.010510811189305969, 0.026675357185013127, 0.031315863743657246, 0.03910267012543045, 0.016499404882779345, 0.021396106385509484, 0.024554490228183568, 0.018026646466751117, 0.04595292324665934, 0.04059488419443369, 0.046968407623353414, 0.04405760053487029, 0.06970437258132733, 0.03146294999169186, 0.05038980489189271, 0.0313844159245491, 0.02454028552165255, 0.033792032045312226, 0.025213643530150875, 0.05505026965693105, 0.04487411511945538, 0.05236638906353619, 0.033379891465301625, 0.004202657519272179, 0.034577179758343846, 0.045884857172495686, 0.019800390546151903, 0.05795044547994621, 0.03258891047153156, 0.014828010389464907, 0.06208584447449539, 0.02580470849352423, 0.02886875423428137, 0.06518660797155462, 0.04077519268321339, 0.07390241255052388, 0.041934995097108185, 0.02226946391601814, 0.04267658987373579, 0.03791923401877284, 0.03825225794571452, 0.01609083959920099, 0.03767123424040619, 0.05378536428906955, 0.025879914028337225, 0.04846101131988689, 0.017564401641720906, 0.056901234202086926, 0.0899142338312231, 0.0656511627312284, 0.0326972825860139, 0.009899738852254814, 0.055316789730568416, 0.034821543013094924, 0.03628236794611439, 0.09706003242172301, 0.018733994838839862, 0.04632597861927934, 0.01593951012182515, 0.021872754441574216, 0.01787862511264393, 0.07169663833337836, 0.024520423794456292, 0.06564501774846576, 0.05673412852047477, 0.01470833351049805, 0.03819418117927853, 0.04569671902572736, 0.023945157299749553, 0.016664196919009555, 0.05502709980646614, 0.014079635166126536, 0.02659037014382193, 0.03808079956797883, 0.08872648584656417, 0.09683430820587091, 0.02153211236873176, 0.03734272257133853, 0.036286078684497625, 0.00487922809952579, 0.033679396292427555, 0.11982064781477675, 0.036757550260517746, 0.04305310736526735, 0.019983567435701843, 0.0473346278158715, 0.016224168284679763, 0.019777554662141483, 0.06293472411925904, 0.06653288612142205, 0.02542726888350444, 0.006749352578481194, 0.05664155673002824, 0.05782196116342675, 0.044204991063452326, 0.0527848787169205, 0.02280792916280916, 0.011537295122252544, 0.019990532491647173, 0.03435482118220534, 0.1272736955434084, 0.04453503526747227, 0.046220166914281435, 0.057870200762408786, 0.05652329920849297, 0.05475909914821386, 0.03873941852361895, 0.06338212784612551, 0.028108282931498252, 0.05986735726764891, 0.06067726673791185, 0.010576291806501104, 0.010372554643254261, 0.0508606641960796, 0.0758107117144391, 0.06803792450227775, 0.045282871506060474, 0.062480366468662396, 0.11184357703314163, 0.038612373973592184, 0.05973682091280352, 0.04422836129378993, 0.01199778384034289, 0.015731250496173743, 0.06735873321304098, 0.06218443508259952, 0.006835213498561643, 0.08920871856389567, 0.020293011475587264, 0.031237953080562875, 0.022686678930767812, 0.06852202001027763, 0.03356805558723863, 0.04391681883134879, 0.0169594047110877, 0.034667068684939295, 0.08297622174723074, 0.021649265945598017, 0.022928082871658262, 0.024761547574598808, 0.005412244590843329, 0.04147894534980878, 0.016024552824092098, 0.042369121802039444, 0.038790867911302485, 0.0545624040387338, 0.004306393529986963, 0.003312181888759369, 0.052072580219828524, 0.050418949031154625, 0.029691363706660923, 0.05209884111536667, 0.058593917201505974, 0.031173749885056168, 0.012921054512844421, 0.07528714879299514, 0.08747296131332405, 0.04090876071131788, 0.030840080289635807, 0.01279928477742942, 0.01224719091624138, 0.029525404643209185, 0.052364604198373854, 0.027527737911441363, 0.06506269899546169, 0.026969709651893936, 0.08685661508934572, 0.01855943613918498, 0.006760355845472077, 0.061470177315641195, 0.03555662915459834, 0.023774433648213744, 0.035696880222531036, 0.06554414503625594, 0.04959659374435432, 0.06074083168641664, 0.03208773072401527, 0.04654136842873413, 0.03601031145080924, 0.050438675316399895, 0.04188586492091417, 0.022036705995560624, 0.041415016748942435, 0.053456155001185834, 0.059222490308457054, 0.07514504235587083, 0.08505044286721386, 0.02245594521809835, 0.05605227663181722, 0.018441449501551688, 0.02903757613239577, 0.054715368096367456, 0.04855546445469372, 0.034608635687618516, 0.025292793579865247, 0.05605647718766704, 0.005323481873347191, 0.030541857522621285, 0.020559757904266007, 0.04425934224855155, 0.06598109932383522, 0.04071797309734393, 0.01701992870948743, 0.047677826587460004, 0.004656157989302301, 0.0284024053325993, 0.035779930258286186, 0.004444360638444778, 0.02754423585429322, 0.049633641756372526, 0.09819529572268948, 0.09662447337177582, 0.10987814734107815, 0.12143483385443687, 0.025233299311366864, 0.0370033347280696, 0.04755128669785336, 0.03097573931881925, 0.05110002537549008, 0.042973998133675195, 0.04568033982650377, 0.0451821212482173, 0.0612579750304576, 0.035709400253836066, 0.04360801860457286, 0.03298696508863941, 0.030231322525651194, 0.03680341498693451, 0.07287842687219381, 0.028876311152998824, 0.005339460776667693, 0.036641838305513375, 0.027575535932555795, 0.06905202477355488, 0.07036959665128961, 0.04639730272174347, 0.022846060710435268, 0.040719116004765965, 0.028030563371430617, 0.020857038143731188, 0.056777065474307165, 0.008082499352894956, 0.05267584238026757, 0.12731506285490468, 0.017495695465186145, 0.047554863849654794, 0.02224157957243733, 0.04101018261280842, 0.02391857728071045, 0.031700151521363296, 0.037973622311255895, 0.02104099799907999, 0.045152761886129156, 0.033670869015622884, 0.020296434631745797, 0.026622497716743965, 0.049179900088347495, 0.042268434626748785, 0.0185925192272407, 0.058276522904634476, 0.02623890199174639, 0.033229317123186775, 0.05736686507589184, 0.04048801492899656, 0.03377476226887666, 0.03488691509119235, 0.02950366528239101, 0.04229966420098208, 0.024649021288496442, 0.04668224661145359, 0.03465783265710343, 0.029680834486498497, 0.04797565416083671, 0.06746164683136158, 0.00799759394794819, 0.009216860016749706, 0.039405911666108295, 0.067237844777992, 0.03771534749830607, 0.038198444817680866, 0.024657537433085963, 0.13516254723072052, 0.030241076201491524, 0.025947429057850968, 0.08612402627477422, 0.027634818688966334, 0.046889524746802635, 0.012940034011990065, 0.042741063953144476, 0.11461995149147697, 0.01896727040730184, 0.014978534636611585, 0.037249790839268826, 0.1499845870421268, 0.189209392410703, 0.15720228489954025, 0.20881363889202476, 0.1394142518984154, 0.10630038697854616, 0.06851486570667475, 0.17855605547083542, 0.13902411970775574, 0.12672587181441486, 0.1464854646474123, 0.053716711918241344, 0.0960587638837751, 0.09768728821654804, 0.11564657179405913, 0.14045174466446042, 0.07768485724227503, 0.14596548629924655, 0.147800876875408, 0.19184075121302158, 0.16821443539811298, 0.11957137525314465, 0.1373298410908319, 0.09571071146638133, 0.12068454481777735, 0.14882897405186668, 0.159832367207855, 0.11751180412829854, 0.23871056822827086, 0.07868205881095491, 0.10581527472822927, 0.10377381200669333, 0.21147241262951866, 0.1137808125349693, 0.14577325520804152, 0.2219080034410581, 0.12160044410848059, 0.16441104729892686, 0.15637609641999006, 0.19050098169827834, 0.08917245722841471, 0.17489040998043492, 0.1668535592034459, 0.08070030715316534, 0.12373481629765593, 0.14059134264243767, 0.08436124000581913, 0.19077035161899403, 0.06649732982623391, 0.16447169560706243, 0.08775471767876297, 0.08544568103388883, 0.23848486627684906, 0.15787444805027917, 0.12854083848651499, 0.18374328181380406, 0.11766405572416261, 0.15006684669060633, 0.204424295516219, 0.09840090773650445, 0.11479402965051122, 0.11238245788263157, 0.09922055047354661, 0.060282024860498495, 0.1550615153973922, 0.10407143548945896, 0.16538980649784207, 0.1621538496692665, 0.16485388681758195, 0.18991870747413486, 0.11779116335674189, 0.10273272724589333, 0.16801074554678053, 0.17857846833067015, 0.15860954532399774, 0.20362259790999815, 0.13955101487226784, 0.10602042661048472, 0.14088153722696006, 0.1292129125795327, 0.1561939436942339, 0.08107940360787325, 0.16892093030037358, 0.12182650971226394, 0.2560078486567363, 0.1016291907581035, 0.13378903968259692, 0.10075312995468266, 0.10274247906636447, 0.1528572922688909, 0.190143889922183, 0.06906823327881284, 0.18384311551926658, 0.1747713694931008, 0.33585973258595914, 0.1773779999348335, 0.19359395635547116, 0.13732463121414185, 0.17400235607055947, 0.1125278371910099, 0.11226442671613768, 0.18861067219404504, 0.19481646653730422, 0.2802358235931024, 0.12112342868931592, 0.21909484814386815, 0.1597813519765623, 0.1556136881117709, 0.11117584450403228, 0.15505446499446407, 0.16063925984781235, 0.15233916928991675, 0.06763303841580637, 0.12634320562938228, 0.1213432676740922, 0.09925119375111535, 0.17038496502209455, 0.14746930013643578, 0.11367954648449086, 0.15265143534634262, 0.15723856107797474, 0.09474717371631414, 0.1561243153992109, 0.13376815564697608, 0.14626801537815481, 0.12189895074698143, 0.29328720294870436, 0.10913180653005838, 0.1506959504331462, 0.1646862059715204, 0.11699493537889794, 0.20058163296198472, 0.08852879254845902, 0.19839293556287885, 0.17224907671334222, 0.1338992189266719, 0.2036174770910293, 0.12822515855077654, 0.07947893987875432, 0.11547435642569326, 0.19790663587627932, 0.1563935072044842, 0.116144523199182, 0.09344605525257066, 0.15614012314472347, 0.12995948345633224, 0.1368074433412403, 0.13582728890469298, 0.14510962675558403, 0.11579965459532104, 0.1273446300183423, 0.12440286795026623, 0.1740646519465372, 0.12186097505036741, 0.1431167227565311, 0.11627095547737554, 0.1299711351748556, 0.18225358362542465, 0.12102256339858286, 0.282124915975146, 0.1729999520466663, 0.15501358750043437, 0.14855521061690524, 0.11792255318141542, 0.2481113825342618, 0.1699085655855015, 0.18054303713142872, 0.1492096809670329, 0.2060640708077699, 0.17335029027890414, 0.07250755341374315, 0.11654013986117207, 0.1715299949864857, 0.12244336059666239, 0.22915865265531465, 0.16827189247123897], [0.07828365909517743, 0.0807255698600784, 0.045899329052190296, 0.019130555883748457, 0.055492723258794285, 0.029082014079904184, 0.04153362307988573, 0.03801247374212835, 0.04348840295278933, 0.015241299443005119, 0.06602400288102217, 0.02657604854903184, 0.007516039831898524, 0.05737932944612112, 0.021213552900007926, 0.049198205160791986, 0.032919782170210965, 0.03212019597413018, 0.03571496265067253, 0.032932198300841264, 0.011119751707155956, 0.06951060524443164, 0.02707122988795163, 0.039647718222113326, 0.00893070457095746, 0.0066500355933385435, 0.06264665949856862, 0.028236759826540947, 0.021325474335753825, 0.014296864574134815, 0.029215591384854633, 0.08264945412520319, 0.014067274696571985, 0.05923675067606382, 0.01759997092449339, 0.012065344326401828, 0.02990736764331814, 0.0266137032667757, 0.06255243642954156, 0.030694240849697962, 0.06995965653914027, 0.03364326483279001, 0.05007504893001169, 0.023610328098584432, 0.02180469764425652, 0.002228188468507142, 0.02705073176912265, 0.0471504453162197, 0.010501754204597091, 0.039346502744592726, 0.015336324031522963, 0.07512171665439382, 0.0806920396280475, 0.019692038840730675, 0.01818422297219513, 0.03274339593190234, 0.040238144938484766, 0.05491327290656045, 0.06702271843096241, 0.047832497584749945, 0.0018958774671773426, 0.03272165842645336, 0.11775627499446273, 0.04981654405128211, 0.06361088002449833, 0.02499632042599842, 0.023038583094603382, 0.023968362402229104, 0.03221618535462767, 0.01945031948707765, 0.06519016285892576, 0.0010731332486102474, 0.08646281668916345, 0.0842369302699808, 0.05883170502784196, 0.1036151779408101, 0.0627725054800976, 0.028573847012012266, 0.007597546200486249, 0.04890379146672785, 0.008805339130049106, 0.029648493546119425, 0.035228967244620435, 0.009204936486639781, 0.023191856998892035, 0.054142771477927454, 0.06280427682213485, 0.018216580610896926, 0.026566621418169234, 0.0810325815109536, 0.09702800132799894, 0.053364911655080505, 0.044745040795532987, 0.07346720230998471, 0.038051280644140206, 0.03300382297311444, 0.07622303412063047, 0.03708439580805134, 0.05251839946140535, 0.05797440571768675, 0.061235302418936044, 0.04505418983171694, 0.02313100831088377, 0.057660744423628785, 0.03721118802786805, 0.06399172794772312, 0.031654821141273715, 0.03736718004802242, 0.0591921809973428, 0.026205282701994292, 0.07525926630478352, 0.04831806625588797, 0.025463123893132433, 0.02043032734945882, 0.05063755605078768, 0.09586046944605187, 0.051606756387627684, 0.08302266534883529, 0.03323764030938037, 0.05133190570631996, 0.027115515695186332, 0.06981327533139847, 0.0422015040385304, 0.03743919434782583, 0.05586270614003297, 0.025914499965438154, 0.03134352729830425, 0.07021882192930207, 0.10870516067370772, 0.017348392138956115, 0.0388832430326147, 0.07007319771219045, 0.0507707864016993, 0.008253747146227397, 0.04605843067110982, 0.029164719016989693, 0.009838657315413002, 0.048003017145674676, 0.020689411103376187, 0.03632108579040505, 0.030052784059080295, 0.009523253829684108, 0.023558177381346468, 0.056108765202225186, 0.04459948708245065, 0.057911890908144414, 0.03810829985013697, 0.03945606600609608, 0.025133207709586713, 0.054004720877856016, 0.04665407839638647, 0.023713731534371618, 0.045762328591081314, 0.04621822248736862, 0.045811206437065266, 0.04073537274962291, 0.04116495380003471, 0.0738915846159216, 0.025290474368375726, 0.04630470495612826, 0.02536631072871387, 0.052555217407643795, 0.07003793827607296, 0.0901896003051661, 0.025991943075496238, 0.068710236082552, 0.04482195327000227, 0.0355165568907978, 0.032917143835220486, 0.05855994539160747, 0.03002349334565224, 0.020760468032676727, 0.033093982783611864, 0.02258060561871389, 0.05905365171201993, 0.012982559073861921, 0.03712664998602122, 0.031294092841562815, 0.07447942494763993, 0.03547216532751918, 0.009715695505292388, 0.020020752745040227, 0.012081032400601543, 0.03779156606469769, 0.042937781327054836, 0.05320226999174338, 0.03232516231946647, 0.02614771801745519, 0.023471498243452515, 0.06475441827205941, 0.03394596089492552, 0.062352687382372096, 0.013891004418837838, 0.04478366216062568, 0.012204956219648011, 0.10399293852970004, 0.06393640825990587, 0.04546008523902856, 0.034250727549078874, 0.043480859021656215, 0.015683734491176438, 0.045883870116085745, 0.05207918533415068, 0.0286953440081561, 0.03528298817400355, 0.02660214617208112, 0.05664914890076034, 0.023385819149552844, 0.030097984563326463, 0.02813266619341448, 0.08226740392274223, 0.026464741240488365, 0.050583030460984446, 0.026479073967493605, 0.05841507445438765, 0.037492580740945414, 0.01292479493713472, 0.025671583898656536, 0.025840439193416387, 0.035321427712915465, 0.038165233709150925, 0.04957647412084043, 0.039749711577314883, 0.05271960311802104, 0.02058130059594987, 0.019881193729816005, 0.013851815310772508, 0.02929832600784721, 0.07114315201761201, 0.01513187440650654, 0.02642663381266175, 0.03506020286295097, 0.031074506186996587, 0.02447376311465632, 0.0479766968783224, 0.02008136951189954, 0.01824922212108504, 0.018122583896911237, 0.10040691806352697, 0.02978426946356194, 0.04657813813537359, 0.0016014256220842071, 0.056580726595711894, 0.02995475191710284, 0.0036026364568897407, 0.05167687821085565, 0.05720028260839172, 0.0167393690571771, 0.0036781989183509722, 0.03653516941994894, 0.03387868149729911, 0.06311814591754228, 0.111997312924359, 0.047641494747949764, 0.03192533025867306, 0.02952695758722257, 0.012152916824561544, 0.019987367231806275, 0.01490455735620344, 0.05261884172796272, 0.11652176428469829, 0.026524406202952377, 0.06693763862131163, 0.034984270023414865, 0.02406693260127213, 0.061066025955369696, 0.011062341945944354, 0.040139302000170574, 0.07132174985599704, 0.06630639749346301, 0.05379844835260883, 0.07556224809377454, 0.042115541073144414, 0.028732163809763733, 0.029576343804365024, 0.05775680430815555, 0.04369064190541394, 0.030251477401179727, 0.009219249732268509, 0.010051419922092464, 0.07006485597230494, 0.0312537496938603, 0.04930989096465055, 0.026059498923132196, 0.04951487215294037, 0.004609850293491036, 0.04219119931804016, 0.028972808904654812, 0.04980490717571229, 0.02501060862414306, 0.02074480686133029, 0.07398482062853873, 0.03454662182775792, 0.02957911758130649, 0.03699609136674553, 0.023394871495838743, 0.02646472454216564, 0.07448942909832112, 0.030248998627939727, 0.06376880162861198, 0.02682977956283139, 0.0050308150093769655, 0.015290813680621795, 0.025060052357730456, 0.10640824330039322, 0.05838547760504298, 0.058620875715860166, 0.02762814678135328, 0.04373892232251819, 0.022646450815955177, 0.04392767645185813, 0.0733873546414543, 0.05932440944889095, 0.03941404560464434, 0.046790329288342036, 0.014627150903834263, 0.04740388132631779, 0.020356804634502623, 0.043980443151667714, 0.0372414082812611, 0.022130346478661522, 0.07095168533851393, 0.02980677138111787, 0.029871490369259845, 0.030354045920830686, 0.0014250792742132035, 0.030218826614145655, 0.003001220156875206, 0.017177085901494138, 0.09823206171859056, 0.024656921450514346, 0.029521109463530593, 0.05488743874593638, 0.047988511869334616, 0.037912962870905176, 0.0374775336968014, 0.020975742809241638, 0.029136918165022507, 0.027252000363660045, 0.03680098816403188, 0.06305989474640228, 0.02792087208945304, 0.06535415523103438, 0.034281689950148575, 0.04118253527849447, 0.06751821332727559, 0.03885727528540883, 0.060384675016393885, 0.06788718688767403, 0.014083663172641536, 0.02363646653975593, 0.020010787557112053, 0.17681842058664188, 0.10840585993719287, 0.1614035977399908, 0.10079541010782123, 0.20549549662973732, 0.15092560061020777, 0.12375798614812084, 0.1295083764125593, 0.06802805393817835, 0.1187652989756316, 0.12376724815112539, 0.09955473957234062, 0.09587854816345498, 0.1998797690612264, 0.11283765416010283, 0.18758211488602683, 0.06779033661587164, 0.08066814989433624, 0.10284110307111405, 0.13640929595567286, 0.09892315705656074, 0.22313642111839727, 0.16979069769149646, 0.14851025131065398, 0.09662413940532133, 0.11999285576166585, 0.11948130078963004, 0.13436174020171165, 0.16363833798095584, 0.1197395681811031, 0.1259116764413193, 0.16783705330453813, 0.0952975801192224, 0.20125578506849706, 0.15851750416914, 0.17063733976101503, 0.2640762407099828, 0.08138941353536211, 0.13121234747814015, 0.12495921895606443, 0.17797292035538703, 0.11230390897253528, 0.11162537819473073, 0.16161948849912733, 0.13564875785959885, 0.1334550732281059, 0.07449235316016711, 0.09816522389883175, 0.08695048934896477, 0.07711383397690952, 0.09957586109521799, 0.12181513258838095, 0.13910038280300796, 0.11056324612582102, 0.08184799400623888, 0.24658805021317676, 0.07886386272730306, 0.16561993164941669, 0.11051547407987528, 0.10777231073006988, 0.07970352860866114, 0.1370490569388494, 0.22635110799456015, 0.12107203496270813, 0.176875714387279, 0.10293562299921177, 0.1410384866176173, 0.18001534044742584, 0.14743450825335458, 0.17689487664029002, 0.11774958082241938, 0.10272283441736363, 0.09473216006881557, 0.169240647519473, 0.15916906530037522, 0.17538494750624523, 0.1489495878922753, 0.16160822269739583, 0.15916087199002504, 0.12926256225910038, 0.14392226468771696, 0.0919223518576473, 0.0946879132243339, 0.12955418176716194, 0.1920452871127054, 0.10288343517458998, 0.18559361924417317, 0.14377741230418906, 0.12353167563560419, 0.17545275011798367, 0.31967598537448794, 0.12556234752992168, 0.12908889970276505, 0.1602816188824363, 0.13404617900960147, 0.24183422327041626, 0.1831323903752491, 0.11115492336102761, 0.19583715707994998, 0.13961924792965874, 0.11496236358652823, 0.1352670119376853, 0.1887208069092594, 0.12944450718350708, 0.09409323771251366, 0.12215656504849903, 0.08865336945746094, 0.1374566592858173, 0.19176808011252433, 0.09276002136175521, 0.10291293554473668, 0.13811694807372987, 0.10356843748013489, 0.11656213711830787, 0.09062290322617628, 0.3544131573289633, 0.11673195534967817, 0.16603615775238723, 0.2003862996934913, 0.07332837616559118, 0.08248061552876607, 0.18172505573602393, 0.14894550608005375, 0.1182817155495286, 0.16214711096836254, 0.09628588333725929, 0.12169622568762861, 0.10380540523328818, 0.2972057129954919, 0.09775414830073714, 0.10686680150683969, 0.10884097369853407, 0.1298364799004048, 0.11256790574407205, 0.0887528840394225, 0.17417080875020474, 0.21844751725438982, 0.17318200087174773, 0.16827459388878196, 0.2142586131230928, 0.14792114932788536, 0.08242119176429696, 0.13996232795761898, 0.13813063327688724, 0.10299753295839764, 0.11655812952085398, 0.11273298165178858, 0.09338199306512251, 0.10652168799424544, 0.10552406340138987, 0.15625448810169473, 0.08109563437756151, 0.09066373619134538, 0.1362369692651555, 0.10204766556853428, 0.11457889588200487, 0.1579015512834303, 0.24411432357737795, 0.1813161323661916, 0.16177682380657643, 0.09419749461812899, 0.14536400529323146, 0.07684153257287107, 0.1882424036739394, 0.17183243500767276, 0.19652598886750638, 0.14483617502264678, 0.12781359313521534, 0.12845969205955043, 0.16545815829886124, 0.11144474687171169, 0.13478868291713297, 0.11980716299149208, 0.09524701759801246, 0.11157377666677348, 0.10838870890438557], [0.034386588813504204, 0.026971429579134565, 0.01539860599223175, 0.021796684304717928, 0.03840829820546787, 0.03438035477302037, 0.056124613765859976, 0.020036222813359927, 0.06015608239977155, 0.011643215366348159, 0.08179473748896271, 0.027436566924734507, 0.007276435135281645, 0.04445250473509077, 0.0196601635980187, 0.05947675752395298, 0.03965160336520057, 0.08052168705035001, 0.028178543907415587, 0.019559801112336572, 0.10193911904934794, 0.0777986433240585, 0.010185623414145084, 0.02168789658753667, 0.057459507370367646, 0.004733750920422608, 0.0336802497622557, 0.011612506223173114, 0.062209538227762096, 0.06954887780011632, 0.026174841659667436, 0.02131216762791155, 0.05060949915787205, 0.09289872876252048, 0.05139683991728816, 0.0445934348681476, 0.04802654693776276, 0.08236958281486295, 0.026622186014719773, 0.026973795174853876, 0.04652802090276964, 0.08432583214016631, 0.0476654549856903, 0.06594640391995199, 0.028922745477757417, 0.05689104080374818, 0.036917995166732, 0.020675399355241098, 0.005407233238656772, 0.008419703426625347, 0.039024937577778473, 0.018535110393713694, 0.0390753924875753, 0.008903724719857564, 0.06106900196755305, 0.0989236542955041, 0.056393994818790816, 0.01850459328124998, 0.026955436296702828, 0.01070269903721055, 0.028628138825297356, 0.06257111628656276, 0.04143438309256453, 0.037651533930329606, 0.03276092546002474, 0.03924093223758973, 0.010186426789005054, 0.04078318932442926, 0.07018794858595356, 0.04189265557215549, 0.039712808284093626, 0.07846066873753443, 0.034629426954779774, 0.05526954832021147, 0.0030683657359986682, 0.044408673493308015, 0.029955265854368918, 0.06296890744124539, 0.011746158670575824, 0.07215084013296291, 0.05039756775659043, 0.05748069939727429, 0.04089637797733303, 0.02358568694035057, 0.03447143484663684, 0.00839623393403599, 0.03362129726156127, 0.07124464813387021, 0.04846041389100719, 0.012568623424158432, 0.08014417879167013, 0.04984870131011121, 0.015828173127374612, 0.052619390917243436, 0.014668525636807317, 0.05261464488285128, 0.06693246585200541, 0.03696700659929775, 0.0556236084230477, 0.036401490069692954, 0.08830133170704357, 0.04365768683783244, 0.025583975220797583, 0.007946353289298713, 0.033378800508216955, 0.10607883363263682, 0.03599818104703445, 0.03519873214827385, 0.07283797982381657, 0.01146402380982181, 0.023145645318436436, 0.00903029151231749, 0.05143021800904535, 0.07157080719480291, 0.028861026621598285, 0.026786122725752648, 0.03242624654376414, 0.05829990055644885, 0.04217961810354609, 0.02130986325937556, 0.03548248489096295, 0.01393569284118712, 0.09115843698964454, 0.0481032033712836, 0.016799733493826352, 0.016422726184828207, 0.022101604954514187, 0.05527158922632225, 0.07047163453535177, 0.03964673858718015, 0.0041936997968150536, 0.032379917975049466, 0.05114425366627984, 0.020795675518456846, 0.015362670274043921, 0.015016527031548321, 0.04795809494680725, 0.09673132037278265, 0.06964542379137129, 0.05031738612160552, 0.06156512026791461, 0.03327218357298989, 0.02061140210571466, 0.06483710094471462, 0.029613649712700862, 0.02915848312113667, 0.039511211289209314, 0.028352108129183762, 0.039184176494018175, 0.026301444631826598, 0.036144053883617744, 0.07393215782940388, 0.03516892378684133, 0.01797879649529932, 0.030542371459887363, 0.0381055056641344, 0.04811717059055809, 0.048928638570941985, 0.05214611592236906, 0.01881606523966184, 0.05303852623910643, 0.01467720969230868, 0.013890267837268766, 0.06764196645235643, 0.015382269466499565, 0.01534357295895461, 0.0946455291705206, 0.0019427044344411115, 0.024331766144314315, 0.027089080394944176, 0.051739901391556486, 0.0394237714499468, 0.02026905865932349, 0.03716481493029278, 0.03878288982377853, 0.013014233936701203, 0.03715599079441745, 0.05093204395961948, 0.031184284671326168, 0.030164256495481823, 0.05551955560804345, 0.033724760069162585, 0.012969587260158733, 0.020940334943588823, 0.07566383326775394, 0.06100837963458616, 0.02032004234933993, 0.10729539921157993, 0.06575340099516325, 0.050191740519949235, 0.013993994107295293, 0.04943223771988414, 0.06360745872370899, 0.03393189348571468, 0.007619920097567956, 0.05051051892223768, 0.047969305087463, 0.0480764229723718, 0.19083732302533463, 0.053156063877395354, 0.04975954710971564, 0.0354527284798678, 0.09046307430253364, 0.0987719815748278, 0.09300536054070108, 0.005647889001920703, 0.05504235094122123, 0.015892591545707546, 0.05785444867797196, 0.03581396886147559, 0.018406935923849232, 0.034067461601807736, 0.02193701329815667, 0.10062625238788314, 0.02073691041005077, 0.017718864837661386, 0.03955154330469668, 0.08452774083707482, 0.04198500842903741, 0.05852320908161346, 0.06749206004315056, 0.04582820532959886, 0.04365082939330023, 0.02964864939713152, 0.04331413183535915, 0.056503680534660816, 0.02097231594234472, 0.025956466561183333, 0.024375211469305214, 0.03007380353665212, 0.05291627225233242, 0.027070305914094206, 0.08095504192169756, 0.03425386683375109, 0.014156061533867614, 0.04483433600398712, 0.028988464509893674, 0.04754821791721042, 0.05986909760395065, 0.07463588452083059, 0.03187975496985018, 0.005924655815761071, 0.024848727662174497, 0.06503789642010815, 0.015463206236745464, 0.02933609390311176, 0.045503137225750834, 0.03506729408400133, 0.044198081668582745, 0.008338273128174478, 0.016268146100628655, 0.0706690012884792, 0.01665264539042255, 0.05434373022580985, 0.07662819480174221, 0.013301160288392566, 0.0670579778670799, 0.0348491026670672, 0.023488037004426587, 0.034453549087629654, 0.03311054009827785, 0.02115245002642041, 0.04668748617405072, 0.04310616721340921, 0.05166046932572499, 0.10424761392641813, 0.09633885783841833, 0.10157861339394003, 0.06680425984086469, 0.022558662167284638, 0.040491079998901114, 0.07393692241748795, 0.038896698169992305, 0.041076274574152194, 0.06428658321965486, 0.08320590161019936, 0.04790336897713132, 0.03887251528794877, 0.04943836414895486, 0.05490779956744518, 0.022743488480045926, 0.052372534046298824, 0.062292714428622276, 0.02759343096840894, 0.1076476596063003, 0.028378951610648073, 0.03425653114391025, 0.021763241275039036, 0.06317038569250144, 0.050969199583050795, 0.0323872355511412, 0.11238432809477672, 0.04477325353946071, 0.02885974641685607, 0.042904592482955195, 0.020552983951347414, 0.032012992742238566, 0.012666414368140977, 0.02875081954698544, 0.031042063201311976, 0.003242712923565705, 0.03374929176061414, 0.050253216322744265, 0.03966006755945273, 0.09767314288183115, 0.07278873090399429, 0.02977581083541736, 0.016204649800783955, 0.028183083995827474, 0.03512163784762379, 0.007680991429879214, 0.058224995591444895, 0.0879063161846716, 0.034966046587214805, 0.10704707659897394, 0.026341674602008425, 0.00648478388939111, 0.029664293870155234, 0.027767735482484568, 0.037085434814798646, 0.03233749310311396, 0.055092059992603026, 0.023426663246937096, 0.06291630401392467, 0.05570963076024782, 0.1153342092584353, 0.05264830499072559, 0.021737485039921012, 0.02039641676674364, 0.0366446436237311, 0.05155263526830822, 0.04345254608779214, 0.04188171631540172, 0.040516739754821174, 0.051547944894991815, 0.05463772831717506, 0.050738996505970135, 0.03134443271846976, 0.05764128531154711, 0.026721431568148546, 0.020551271445583552, 0.05457359933643602, 0.04852044992730953, 0.01397179647028679, 0.06205864476214629, 0.003707518853843794, 0.03132023870421108, 0.022120791327324696, 0.06834644271293655, 0.0661334399774205, 0.06235527005628683, 0.03944517869967967, 0.08726485568331555, 0.14733918680576608, 0.08483916826662607, 0.06374070391757414, 0.0903607247164473, 0.19474473054287955, 0.1477249848539941, 0.19893081451300532, 0.19297467864817008, 0.16977650782791898, 0.1043366568046622, 0.22648306185146794, 0.12374848665785976, 0.11446683158283122, 0.16301613621180877, 0.15459277492482215, 0.16346252319635823, 0.11801636064774357, 0.1576987371663563, 0.11223094843444414, 0.18250888242619112, 0.17870028445031494, 0.28236908256076276, 0.1882385741919279, 0.19096155854640529, 0.1028156399843283, 0.12885387637652457, 0.09458680302486755, 0.21428672567708418, 0.15020265971543267, 0.13616070616990328, 0.09587241802364588, 0.16133769502630457, 0.2585673378780484, 0.0988203176530078, 0.12103774031857029, 0.12732983159366995, 0.15691866574343294, 0.21428769046906382, 0.1553684231475927, 0.23169641179265454, 0.23502861033193767, 0.08451352128759027, 0.1593795235385187, 0.11235260870307684, 0.23633180680917576, 0.2000772545579821, 0.1890127529622987, 0.15281533123925328, 0.11111228697700426, 0.2881768037332222, 0.1457570615457371, 0.12197672040201724, 0.06462408971856348, 0.18484363448806107, 0.170816702011507, 0.17340572871034965, 0.1116561921662651, 0.07315951530472375, 0.079386854195036, 0.08591749399784021, 0.19989173248177394, 0.20815896074054763, 0.13491274032276124, 0.09949668135959655, 0.07794681310770102, 0.10108571601449512, 0.2587995113572106, 0.1836402271874249, 0.13715243811020628, 0.17489045450929552, 0.16655410261591896, 0.1273074038908817, 0.09463166585192084, 0.1027773525856901, 0.13235642749350518, 0.08974267897428945, 0.16897825378691778, 0.10370146002969705, 0.1288945015403442, 0.26323491241782904, 0.14188710279995576, 0.2350028429646045, 0.1589488997706212, 0.16148478869581595, 0.11896737094502896, 0.1803995354566723, 0.14322341390652582, 0.17832693964010105, 0.18951003643451259, 0.15801578265381977, 0.07572083020932041, 0.17416895338101313, 0.1503664517076686, 0.14580565737560391, 0.20386827847687528, 0.17061290825949982, 0.20563748432323337, 0.15952024958096445, 0.16698692314093933, 0.13623600447317585, 0.15123100922210142, 0.17135403177235276, 0.07433245744323358, 0.09506190370302647, 0.1431348460027948, 0.15470642742002383, 0.1316425111144781, 0.3321575140580535, 0.128141533350572, 0.10917133331531659, 0.08462321071419865, 0.11635854374617338, 0.16976837388938293, 0.15620825230143964, 0.31582219060510397, 0.24830316833686084, 0.17676123068667948, 0.10075694459374063, 0.1273015557671897, 0.19958771910751238, 0.07949477731017396, 0.11438890607678331, 0.15146358346100897, 0.16002985270461068, 0.09722775779664516, 0.20792795985471457, 0.1624903839547187, 0.18557757401140407, 0.14769587782211602, 0.10131653878488578, 0.0954662034928333, 0.18368649267358705, 0.15524062531767413, 0.12403341941535473, 0.1708921042154543, 0.1308647551923059, 0.1788704440696165, 0.19221512018702924, 0.15350079367635772, 0.17876108118798584, 0.09457673208089545, 0.12354338672594167, 0.15751867729704827, 0.09387295343913138, 0.14594289532396942, 0.18890420644311234, 0.15038859739433974, 0.17839696869486943, 0.23676324693951756, 0.1114888972369954, 0.19296471902634948, 0.11068315492593683, 0.06439284392399713, 0.13741640519583598, 0.14609577774535865, 0.16438790713436902, 0.1607830880675465, 0.11651010514469817, 0.2598920714808628, 0.22008463565725833, 0.11432389394030906, 0.10483718346222304, 0.15726127079688013, 0.15856120182434097, 0.08505962323397398, 0.2029558375943452, 0.09971193387173116, 0.12722322950139642, 0.1128732920915354, 0.09122324132476933, 0.12440241524018347, 0.0939773439313285, 0.1648878029664047, 0.1950078218942508, 0.12711950694210827], [0.03047060949029401, 0.017012705757224467, 0.03579391603125259, 0.11326919076964259, 0.01625754637643695, 0.016436975420219824, 0.018218337645521387, 0.021236160573607776, 0.04689199609856587, 0.00700569409673335, 0.0813860293419566, 0.03261392084823456, 0.05218985810643062, 0.04096540142199956, 0.056827891457942314, 0.03842966092634015, 0.031272184642148204, 0.06498188653495163, 0.0303890994109679, 0.03906069054210093, 0.029014834872214124, 0.03875776441418566, 0.05278883807477541, 0.041623118668212555, 0.02655600128491642, 0.035138009625370614, 0.06678964695311151, 0.016252410714514554, 0.11885926229297183, 0.016850542779138777, 0.037560921409749426, 0.021375877295213286, 0.0554666479001753, 0.034011574171017855, 0.05211181014601607, 0.02508172306988854, 0.1135950158641208, 0.03422945017518941, 0.029872152736061253, 0.07121588248992339, 0.0128387948643649, 0.004531822278295294, 0.04228461715683807, 0.055914686163305305, 0.007770602978780516, 0.06105614054831676, 0.05241091421339661, 0.026948547310894355, 0.023931316245580092, 0.10293140017893165, 0.027917113111470826, 0.008193274170480436, 0.04946155626385007, 0.04100727710465435, 0.01787704990420025, 0.03807504050200805, 0.0590740199550055, 0.01632238410820719, 0.018207880784757435, 0.01203311099743587, 0.0409317524463404, 0.02850165830750484, 0.05678124747646507, 0.02625118453579489, 0.020065858625457622, 0.07956215689773671, 0.05266761938401032, 0.06563669827301055, 0.011119778610009234, 0.04652952746255323, 0.0654350864351727, 0.08462721089017577, 0.10985004220856354, 0.11054776492528617, 0.04146069593844004, 0.019882594533555675, 0.030358977492142003, 0.029895522966398858, 0.0326246671465924, 0.008891046982171247, 0.026461572269909084, 0.0978029593534302, 0.0697218650020659, 0.01548312362501747, 0.01160690764663741, 0.028482451525633223, 0.058489489601925015, 0.013335199819266563, 0.023702090948063415, 0.038922691892366856, 0.07175703431130387, 0.032985503057716414, 0.09376263318699785, 0.03827796594123356, 0.07174917496740818, 0.04546050084172748, 0.05820656806463376, 0.09823109692661092, 0.04149917258473579, 0.07848089226172306, 0.030021233505976852, 0.0255975602340186, 0.04817275745153893, 0.04037247366795782, 0.034136062022298574, 0.02387874435953563, 0.05694390398275573, 0.01095442532459856, 0.0063225995745597174, 0.008339106188941514, 0.007953235781315016, 0.0374378287961008, 0.05581751676800195, 0.08156646770657972, 0.008420976209890796, 0.04116832686122507, 0.061166586965555325, 0.04641224215447437, 0.033614191197557375, 0.02631488307088148, 0.01007011554975179, 0.04260354027792346, 0.04551734935375862, 0.04552828489977401, 0.02917077308666194, 0.01574366291606566, 0.0789453431207221, 0.028591951704584062, 0.0455347267416073, 0.031926198571454734, 0.052536660004989244, 0.031340662608272396, 0.053482252624235116, 0.01689906624960713, 0.11664974765153602, 0.009081933858396951, 0.04827599761483725, 0.012018363595416304, 0.04475364970858209, 0.03192897420376539, 0.01659934248891659, 0.02848785436071921, 0.044756826100638136, 0.0692930149671156, 0.05757328603067435, 0.01876237085525645, 0.030062012665439397, 0.031680814863648266, 0.03245687868911773, 0.07089539343724027, 0.018752607902570162, 0.08239725008024834, 0.01713849422230851, 0.02075148619042011, 0.006066082260076655, 0.030927648149372544, 0.07140645117033273, 0.024471176730003208, 0.03857519979646895, 0.04957046272465959, 0.03524170249875169, 0.04485407342144754, 0.012562254869408207, 0.09659101735451259, 0.011235217825742438, 0.00827951265819138, 0.013548304741561878, 0.058198842307319865, 0.03620312512794044, 0.05312787339789793, 0.021710741748393048, 0.036841390683548525, 0.03435774895478971, 0.05208680719078984, 0.030186455987859517, 0.03259465469454881, 0.05219620717980433, 0.018792743248923216, 0.04712859277788084, 0.09106103010708466, 0.05541127255128231, 0.02928734593297122, 0.028875437274109572, 0.018431541830068454, 0.041436991741647944, 0.028683681157417595, 0.05791190575109795, 0.0382628855004441, 0.05504548651515506, 0.0610911662079161, 0.009619191259844229, 0.021788071680930443, 0.03926292949472554, 0.08164642669726163, 0.05732328245358076, 0.02263047979795374, 0.03267504413088318, 0.07152042278903536, 0.023156352654041257, 0.06334803358186036, 0.024791493233351503, 0.07280770762008615, 0.07706411008257419, 0.04739419629913755, 0.06810057660914026, 0.012854583128500963, 0.019497158282320015, 0.02187911650253227, 0.09447279429878108, 0.07149342345655896, 0.03771479088754859, 0.03260679994127713, 0.03568489453755319, 0.00978836289505125, 0.05574467868427746, 0.02956901880679652, 0.016759653808549047, 0.02266538856929401, 0.0811084735323675, 0.018061820555885788, 0.052823911973973736, 0.040823591843945906, 0.04345243847637903, 0.04236749649862759, 0.01160473872005241, 0.026079535055032466, 0.04893161458312534, 0.03210200222383719, 0.02603411932796007, 0.01895957062515663, 0.03534610783390235, 0.028817226921091788, 0.011750034536817111, 0.03530666268488858, 0.019562509951356333, 0.08581532994867302, 0.07773770557832904, 0.009745049301272957, 0.08402929219300859, 0.023605956848768983, 0.01696284642093815, 0.01750312621879857, 0.058736539431265555, 0.03454831021372229, 0.025815799890551716, 0.013363886610022746, 0.04445673126610927, 0.04397576019982807, 0.054068352619651705, 0.03897971851984039, 0.05439955086330883, 0.03898484676028602, 0.02095849715260556, 0.02624787826789543, 0.009992001723730937, 0.015470805828954326, 0.03177160178893246, 0.06573694015969522, 0.07748911579255946, 0.0635288207558915, 0.012960111889697146, 0.018877194088418037, 0.013355924293136923, 0.03640456998255104, 0.036908799957018346, 0.05145941409864463, 0.030569420887331944, 0.02023363223997876, 0.05868527929123957, 0.04204489232506603, 0.002877720521610172, 0.06773964792955667, 0.0587981896387646, 0.06665892506134696, 0.09730485951877199, 0.025849695630313363, 0.04308380259317346, 0.07326672595809214, 0.0679329625563696, 0.06811359387938865, 0.10717556462623179, 0.05871224893780891, 0.033374106424162164, 0.04373406867671292, 0.02525045034417417, 0.022478491664514877, 0.036012808777741157, 0.030132275496725924, 0.04583263224049006, 0.012114925357309403, 0.10892258767853491, 0.023673095238336828, 0.01782974726665998, 0.011353604295436526, 0.0560499351558974, 0.03310436542960815, 0.046700162056367844, 0.04005576214694884, 0.026952335974783637, 0.03632059597293846, 0.03567325395124499, 0.0341829323588172, 0.03459106905211229, 0.0464632722287206, 0.053465220335056074, 0.07976230670465156, 0.06886643590405583, 0.03880152515193913, 0.04970619411324151, 0.038703940153936855, 0.061387884270516224, 0.04989525623386726, 0.04575646191369742, 0.027693014199030586, 0.027359801024431363, 0.0228802032142994, 0.009975025095627643, 0.041937266068998724, 0.03968764576711692, 0.07299700722796842, 0.032106495928019285, 0.049173944353242405, 0.05997786305670161, 0.04657623823732138, 0.09420355796464719, 0.03223493942641653, 0.042702149439719506, 0.04546176249277778, 0.07009959590504877, 0.023185405880212784, 0.0353059056942584, 0.03501016355585307, 0.05698090004443657, 0.040497852096450515, 0.038052586824051104, 0.012882774535682984, 0.024243012703664135, 0.055489520891569555, 0.028829284965468105, 0.07963180745719001, 0.05049933104601223, 0.036694178270408884, 0.01857238847151166, 0.046174962699296884, 0.0254343601045548, 0.04377742123324424, 0.022602920143981464, 0.021019091655034572, 0.027073701239714865, 0.06110415379225742, 0.04675450953072868, 0.07361908283201046, 0.21460328134708107, 0.08656279882416129, 0.1898032589815557, 0.2139577761408873, 0.09953597065759823, 0.117621077952208, 0.10279949085088447, 0.15533039550064132, 0.09360589159769006, 0.12218213945743628, 0.21655699994880706, 0.05686656106263399, 0.13922543468652293, 0.1521220020367764, 0.2276495101978071, 0.0731877466023434, 0.1279444931424223, 0.14421983622014523, 0.21696279145544395, 0.12634048936888576, 0.20000342570710927, 0.11173835533554666, 0.15366071165772155, 0.16564281948376447, 0.08319522952660918, 0.19634398457128555, 0.17143603909062222, 0.1429680854198523, 0.18393012491287664, 0.10283038645866327, 0.09243516105925664, 0.11169892502948642, 0.22142173344036564, 0.15471960796276107, 0.13659244315931574, 0.06813713480369188, 0.26301710691768676, 0.2193175963475369, 0.16231624642387033, 0.2048096779617481, 0.1162662947899662, 0.0949370521993842, 0.15256113081704825, 0.21591094555333257, 0.12996173958526924, 0.15378966723801568, 0.12501538469223306, 0.1337032177252695, 0.2042078852537088, 0.20889267761958763, 0.18394513113889843, 0.09294045972637832, 0.12744715029839426, 0.1014410043717362, 0.1985632732976228, 0.08207221908378415, 0.14906551135936752, 0.1490760498563759, 0.1234418831882067, 0.17864484601886943, 0.17202018352691084, 0.0995752376911696, 0.2786216523963958, 0.10563777526840568, 0.10609843375277705, 0.19722310302313417, 0.15988020604709163, 0.17609448521398008, 0.08362159336684272, 0.14615834079449996, 0.12769140594173223, 0.14529170526657254, 0.26820385828614235, 0.23150756489485502, 0.1282229321077466, 0.12396965408697724, 0.12867746787378564, 0.10404462911537848, 0.10053208869067021, 0.15772481623571366, 0.10643320914823562, 0.3211424098117277, 0.21835802908753976, 0.197707740298938, 0.08631482502096333, 0.10635643397108652, 0.0836034033272881, 0.10121243030880578, 0.11145823169499636, 0.07527368623414077, 0.18598391470732167, 0.16618044610368088, 0.13394426729064435, 0.11619826953392476, 0.17809789802413434, 0.1773373005562462, 0.19307786686113104, 0.17902302963193506, 0.16149464441696182, 0.11995344772003591, 0.16795771167380735, 0.1968344402848743, 0.11648815241642296, 0.17761698632966727, 0.32604877778794616, 0.19790810532867908, 0.1086404973466415, 0.23805531120160595, 0.13409536855760962, 0.07180358923505992, 0.06258077162783593, 0.10797496157465503, 0.10543693526415154, 0.11624860198935494, 0.14896735490765423, 0.12668389594182372, 0.13087830680888146, 0.0814815734338481, 0.18886879115598276, 0.1113625020661857, 0.16647764656227082, 0.17470159276854247, 0.21386653650552034, 0.16782927559688687, 0.17203826224431396, 0.12472654081648216, 0.18643576389877126, 0.13744193507591262, 0.10565422868239693, 0.16260791046079248, 0.10123178552021272, 0.15228585340082645, 0.10563715186435729, 0.09882345693768002, 0.23991584574105218, 0.11313990864437073, 0.18149815150536597, 0.07187637165770866, 0.14690106734633446, 0.07676702094613574, 0.10694573633372784, 0.12306992619414814, 0.1731897340505384, 0.11961789306951687, 0.14067866373807192, 0.11305005682515912, 0.11947003498789854, 0.14006092969793826, 0.17317287245532498, 0.20214881136780605, 0.0659782494767569, 0.1648661174112931, 0.19418565585510805, 0.15745445183711126, 0.13459361682180315, 0.13474437670083717, 0.1263837268925272, 0.1057870285876561, 0.20743121072882786, 0.14900588721502572, 0.17185780161526054, 0.1420590584166348, 0.14257011614972726, 0.21490208484465256, 0.22221544553758577, 0.12497063318733126, 0.086796575342305, 0.1026926735357847, 0.11329216024023481, 0.20185858709737659, 0.12917929328978062, 0.16383643203880638, 0.12066734925610945, 0.22213778720470145, 0.19176995032466948, 0.14386494120117277], [0.09025695020682178, 0.03826370186288841, 0.03965988944401033, 0.030888206711097155, 0.029883227434766013, 0.0505015723319957, 0.029752002737950534, 0.0020130894881731365, 0.016558140305278357, 0.03866964550979901, 0.010843389827641658, 0.0886351868393831, 0.040252293983940035, 0.03186775073118042, 0.018270482796651777, 0.02327169910131488, 0.04581107656122185, 0.051164332471671514, 0.06875980412587523, 0.08689186710398644, 0.10342579669668339, 0.055308778246399015, 0.016977884188236203, 0.01619822836801177, 0.019898880964319687, 0.03784376873227302, 0.023975088115548715, 0.051648060616571456, 0.031113843724597245, 0.07220048981253058, 0.052389863194548525, 0.02776061086478876, 0.033079065615311265, 0.09621391727705486, 0.05741932378441561, 0.001452021206205245, 0.020654830732382834, 0.027851334707520436, 0.02466787183948327, 0.027791704997071065, 0.030013068026164547, 0.010798386920214398, 0.03676198088214733, 0.03418957829126157, 0.024223377331509255, 0.041392548228031956, 0.013654070990014588, 0.05580848483077716, 0.015983074190444313, 0.05844909821462352, 0.01837877141952049, 0.025732586582307704, 0.016328692363458686, 0.027089156465081032, 0.017760107839421835, 0.09004010207718238, 0.020340152696007863, 0.054450655152322724, 0.02410012330074096, 0.020509340101853013, 0.02177981714339694, 0.07762169305351563, 0.005377732868510066, 0.031140501669142395, 0.02168035822251113, 0.09006303444039077, 0.015451987746928353, 0.04306061047827825, 0.004905223677269532, 0.07060585936415009, 0.0077836791570007335, 0.06268197088502347, 0.04503437448875047, 0.04695253308454994, 0.015501020516239805, 0.04179620977083687, 0.05035485344706103, 0.022039598516130354, 0.040510476028430276, 0.041165180155076087, 0.02573142512119375, 0.016918373221415095, 0.06599453219678253, 0.04207520163618028, 0.08380329338251613, 0.05441302084363997, 0.03174758217937779, 0.05356838257284835, 0.015898306082817726, 0.05403695977292955, 0.06651813964708708, 0.054365207979572006, 0.04645401764719281, 0.03276121489761863, 0.056644005817361176, 0.029803607976646163, 0.05632848173263483, 0.05429612145235296, 0.030772884383623023, 0.025912872806657106, 0.028527390422823373, 0.014370611788763199, 0.08358464925549924, 0.018143091292586178, 0.05760356565588154, 0.025585687726561446, 0.007980644222698174, 0.041450120334047824, 0.05072771957202349, 0.05368984988308512, 0.03209108152077533, 0.053154160268604755, 0.024797324658720754, 0.046670888041262515, 0.06125662803242449, 0.01192419989820337, 0.0706043528043665, 0.04088472996954806, 0.034972243520314805, 0.04057304649904836, 0.08531093670171686, 0.051879421444027685, 0.030710824139532633, 0.018684194874367677, 0.025983020605053753, 0.028599599536391906, 0.07809474540408701, 0.026879471915890463, 0.023783875622029882, 0.048360405780840665, 0.006082002719267621, 0.04320424945035484, 0.022694864819641225, 0.029064009577268735, 0.02637039200635627, 0.020279541495256126, 0.05037162598455325, 0.014445410070038633, 0.018723691973718815, 0.033594865672057495, 0.0519037193589611, 0.04301158791349735, 0.024293927745020483, 0.006054917575966101, 0.0587913062190637, 0.021863952570129186, 0.03690487770654727, 0.012944070367666427, 0.0330709353875136, 0.022333605884341523, 0.04916910926112905, 0.03225131120416336, 0.03383289098565001, 0.04796632536454126, 0.04656611163227353, 0.05656477413140237, 0.04315077399951406, 0.038456901456811465, 0.056394692437606864, 0.04103363819012884, 0.05542162551137153, 0.06439312594011426, 0.06681115439278074, 0.06968926245463081, 0.012251609477971215, 0.03414721279114019, 0.02102643520629499, 0.04697046708315611, 0.02406376734143123, 0.0540220537368441, 0.023800935741746798, 0.04236141459841747, 0.016738871818233747, 0.06120896359789185, 0.025962973340938333, 0.020906875215587206, 0.06508157923235558, 0.03920072267646901, 0.027160857207491063, 0.07143684953916818, 0.04619785424438305, 0.07510823183110915, 0.022160520347824786, 0.01643741885345662, 0.008816276531433687, 0.05437559804704506, 0.027835068685817532, 0.035149060204275884, 0.010178277079830877, 0.028860408783657476, 0.020072285624337383, 0.05881808290723711, 0.033472581999376416, 0.07535619821283035, 0.05576957031735219, 0.0628198025515303, 0.1025394348835107, 0.0572908951289719, 0.023160137607192155, 0.012435396783985198, 0.060661425595753826, 0.019945914573327173, 0.03295613998488989, 0.10574950560112484, 0.08020621491596103, 0.04818725159566384, 0.0321072900260333, 0.03792287054238841, 0.00981757475528866, 0.05535750766284764, 0.020867888342763763, 0.0064516432848904515, 0.06406399086699821, 0.020289467720431276, 0.006918089593455079, 0.042423873746884055, 0.019922555475204717, 0.013137903570168419, 0.028096395581087563, 0.03698892964166589, 0.010513729685044382, 0.0682650513772387, 0.020433073295862414, 0.09182331967167556, 0.03692636659252457, 0.03597872193495277, 0.059305473550921306, 0.012184359766251873, 0.031643863330828026, 0.02220620881416835, 0.05516885001270566, 0.03548053675331175, 0.09111284685786813, 0.07491922908229753, 0.013195009050832596, 0.006322130629996536, 0.0185581930418266, 0.03430905293498654, 0.05230181479419116, 0.05011053472117055, 0.06066221227229107, 0.024929157916631084, 0.015166308203333756, 0.085143233591225, 0.010540883940848289, 0.01545057210023515, 0.01916603054269217, 0.05686442738806363, 0.0160554929607315, 0.061793586719431914, 0.07481727283447981, 0.018219150297227316, 0.018284205107192975, 0.024302963392983656, 0.03761068241146859, 0.01868191462563118, 0.01119631629990181, 0.055742218464729376, 0.026405558674014173, 0.028312521972111426, 0.1670349994674325, 0.042656396035454236, 0.03032919510587817, 0.027286643817205913, 0.03739627223694697, 0.028475556973717175, 0.025912433084158693, 0.05006302242691163, 0.045749188866466284, 0.022630374041909818, 0.040408764689345844, 0.07274883304489776, 0.06677273340756074, 0.05327420265530236, 0.11573618612601422, 0.03387333432328887, 0.045735681778751314, 0.01694230562861776, 0.050889396443380974, 0.027655628509819508, 0.06543436655192636, 0.03118272616120521, 0.007541258937635575, 0.020349967599031515, 0.05008470056054648, 0.0487402703583939, 0.060601567674893886, 0.030599004749092273, 0.04022195498691872, 0.0270918634487316, 0.054615723638562486, 0.06066773385100532, 0.08271205428172834, 0.0012795702059520409, 0.11003468855051324, 0.021733436624344904, 0.025689807334856596, 0.049571464624023065, 0.02707373092562193, 0.01718878214887809, 0.03539577235642355, 0.027827680605696514, 0.03543657934642397, 0.054163703753147274, 0.04619072591594886, 0.038292567696771584, 0.010932332515949383, 0.06931725351023488, 0.03596755632315762, 0.03947267527109943, 0.05944494536379352, 0.02748692535533337, 0.07033654139377177, 0.058451102013350464, 0.010053311470983317, 0.015796709776623175, 0.04186380458122585, 0.03778071215492673, 0.06831485690781847, 0.04088753899850417, 0.03467526941676624, 0.05119991103128996, 0.04011714889202267, 0.060720901310560293, 0.011424074000387918, 0.09637840688810684, 0.01687158266577171, 0.011351375997037394, 0.07253378091263585, 0.05709450430003926, 0.040967553650261834, 0.028084957230021246, 0.004323080256654066, 0.024567843320255633, 0.04050181887578219, 0.022140758810564876, 0.06585769500816241, 0.02583512912678998, 0.09658147333539091, 0.04980964578862768, 0.025880452085402794, 0.06350755080347881, 0.028452728511183523, 0.09583360370015725, 0.04231769467878621, 0.004609005636666552, 0.05941457668086514, 0.027670185736496933, 0.019651606635306962, 0.01808990527933929, 0.04949486756231636, 0.027054535275965463, 0.25921404536347836, 0.07883111175033264, 0.14569525548722595, 0.20514888397883624, 0.18649071251275018, 0.1790465705562383, 0.1833699963754043, 0.10691435832995921, 0.11148197299917229, 0.1915512394043617, 0.12133054726291448, 0.19266647956101224, 0.15144134871661663, 0.13391780230449513, 0.07952830012072809, 0.1384173397673294, 0.16750480863265693, 0.17866967828013003, 0.15915790339931846, 0.11463149188784882, 0.16260601056274027, 0.14074600621825084, 0.15872110496275127, 0.13836391997756436, 0.11867487570270896, 0.15861744177527726, 0.1693644080660306, 0.15210071724141017, 0.23240412381710485, 0.1643524770042859, 0.15291756950318813, 0.11489932556287386, 0.08210678832256235, 0.2655818505445495, 0.1371956756338477, 0.13145854754839092, 0.19001117907464504, 0.12738332559820265, 0.07465321366908029, 0.0845830753678456, 0.10835126013262197, 0.1218019520456437, 0.12229237065184861, 0.1063705125125125, 0.08511138061294332, 0.21124135237187147, 0.08523215030436404, 0.12273233063751832, 0.09467949726968072, 0.15403772267745808, 0.13174642663216218, 0.12253906053956598, 0.10082603112095967, 0.11097246635472402, 0.195303107611835, 0.23505509016104043, 0.15235782688250765, 0.14520186086883768, 0.1446239504730329, 0.10976454679621384, 0.11308224376989529, 0.15129841107409447, 0.07895752918557264, 0.1423578173853457, 0.2320772671373561, 0.2581070875748992, 0.06927286565769464, 0.14648819575086236, 0.08626484137494117, 0.13917848642449826, 0.24372781306738034, 0.10602563648717478, 0.09463232636335306, 0.2316134693683125, 0.18291934946319088, 0.20829628774663433, 0.09063842895557173, 0.17368433094816282, 0.15544067864539102, 0.11490363744087517, 0.13118696602759883, 0.13679732044693083, 0.1142545699258335, 0.19070185138843954, 0.29361282766330987, 0.1711827886174433, 0.16194267896935344, 0.1829647837439552, 0.18891967280069366, 0.12821413023630157, 0.11884830819326453, 0.18557509523816407, 0.11679879316943698, 0.14099992462433875, 0.13372617977438495, 0.2219459568732418, 0.15143039461690933, 0.20316942769568413, 0.20526596519630402, 0.15452204825123772, 0.14430835959501565, 0.1681558947893791, 0.26495770434848964, 0.19300935178762302, 0.1494634064147249, 0.13209680939326063, 0.1773198155569844, 0.11975395842455328, 0.1306549648870714, 0.14425041270442307, 0.11180358269484714, 0.181819501449354, 0.1400832980289124, 0.19926455832319334, 0.16999769752146676, 0.15306228830013424, 0.17770914622815326, 0.13298161269631237, 0.23229438986163586, 0.09840349783189595, 0.1456813921686262, 0.08181407043593936, 0.11727140765287913, 0.11689279359416105, 0.11931998014915735, 0.10906989657087252, 0.11861735183629207, 0.15032306575449184, 0.14366139977937564, 0.11644504847936332, 0.07309495587833226, 0.11769732620450668, 0.16754798678448424, 0.10193513371632434, 0.09966689292923547, 0.07741293433355168, 0.13912698137573898, 0.09475730403210036, 0.11172582788276486, 0.14109526091488078, 0.21426475810585544, 0.15907573280856013, 0.11348043568432331, 0.13173559127608314, 0.13841367355780676, 0.21510054997634143, 0.09928194092935883, 0.16906327422475442, 0.13373275520280004, 0.28076346090529114, 0.06866601150250062, 0.08071088275755756, 0.13752838043728843, 0.10518697992665693, 0.2153491842909716, 0.13871376839233562, 0.09544718224788085, 0.187920430325903, 0.1573654980165884, 0.08647380789625458, 0.15451673447387293, 0.13601588347228244, 0.18753020907752216, 0.09051774090039544, 0.16301432537147775, 0.1460096292430535, 0.0630677911976818, 0.25020876608323306, 0.21370194299379364, 0.15324401058023795, 0.09095327768591233, 0.090539174125297, 0.1150957349454984, 0.15637251926818863, 0.28885010979138315, 0.13177139248000458], [0.07126706099370494, 0.0291390889469767, 0.09781910848687403, 0.02174529614421772, 0.0805108888016548, 0.051167742640245706, 0.028184601687826216, 0.08032377852941863, 0.04509795056947041, 0.03168351628119126, 0.020003434729005676, 0.07682249648496509, 0.013955382019048557, 0.04649352216802072, 0.039484475419158116, 0.012157713881606469, 0.13890936883399263, 0.04157762130489573, 0.024924330245994497, 0.010530145991651807, 0.01980089335120283, 0.07920513191493228, 0.037171353251324035, 0.030836864934826735, 0.04857945066760294, 0.012615838859346695, 0.10246395846479572, 0.043676863933796994, 0.019223380004405044, 0.056238986144308, 0.059273479564581066, 0.019144690086250193, 0.011819054270745255, 0.03370225815160666, 0.07699013280216604, 0.05245956941507757, 0.04479495022678748, 0.04052616503031459, 0.0734180498693604, 0.05396062246290967, 0.009054028178070439, 0.03677700937259942, 0.01940142123203259, 0.04887888870143797, 0.05736042694479693, 0.06701571997837164, 0.02560692428232869, 0.07248583817272447, 0.022717346328136045, 0.051993318847962655, 0.05805470980703831, 0.027201899829378817, 0.03654265026852954, 0.023023313406156376, 0.026825328532140702, 0.05261479331238661, 0.020987144052924123, 0.04179239884251729, 0.03894179477356374, 0.007697678620388615, 0.012872377974417759, 0.054036403162172064, 0.03930241917259991, 0.03581453660444822, 0.007224553446576465, 0.08828003949020058, 0.08802426571492106, 0.04335969599196687, 0.0174326296109939, 0.04639794467948377, 0.01587819202541141, 0.014988943257776555, 0.032348873937735334, 0.07396519824396819, 0.023499338058172725, 0.015793208694958594, 0.05190953037526924, 0.030565275992557872, 0.06565645424416289, 0.019972713525930885, 0.0277383371576434, 0.061914415782666765, 0.03847629006486386, 0.028962574688193854, 0.01928613786731148, 0.0920945152756758, 0.042273310536984354, 0.07300704848603345, 0.05243253668595571, 0.02555383474827977, 0.03198062768206, 0.031167664274107665, 0.01876694990642136, 0.04054190969327465, 0.07788933377014473, 0.018322694741073065, 0.02371293001488084, 0.030096405644144397, 0.035212317161494866, 0.038035866236896254, 0.03418420885282103, 0.013046370786469197, 0.03159521926136222, 0.01758174563292414, 0.03766783520404715, 0.013348330267035635, 0.030935084469092544, 0.05806891080283094, 0.04873629615758546, 0.11307393913739361, 0.029072720535623375, 0.07335011367104016, 0.04751521461002994, 0.024976508793770336, 0.0700549483008217, 0.02351441107748542, 0.023584961490996648, 0.02809977791912388, 0.056165019996115007, 0.030791532699367963, 0.027417156052251812, 0.041207742324331775, 0.044903908637934364, 0.026834547861653846, 0.04334562116127927, 0.017709649218886625, 0.02806943521136418, 0.06059128892957233, 0.05988655662804376, 0.04732739929750096, 0.016290519997710362, 0.032648931664880365, 0.03797982666583266, 0.030846251247567125, 0.0261280845006695, 0.027956545272900257, 0.016531859000679106, 0.03997083447757177, 0.01818305223423522, 0.01570232900121482, 0.02120232235029107, 0.03738108047400601, 0.03188496113580186, 0.03297936178569216, 0.047169945246423595, 0.0366278228466399, 0.029490549677575473, 0.03907767830241937, 0.020408654781931546, 0.021999021591909695, 0.03276502582593821, 0.009459992234042147, 0.018084793737216387, 0.06520127280964516, 0.013254023706394946, 0.015591509654768743, 0.08101870334940031, 0.029917895008111373, 0.062401780451182276, 0.07131691847462207, 0.017076849580917042, 0.029876117660023738, 0.029353280187933706, 0.027790990679932293, 0.09740855981362984, 0.03974533290602267, 0.03381856753549073, 0.04503073425439652, 0.07159235916333273, 0.045762651425320655, 0.05139459120982792, 0.0503801124432357, 0.013518603991542477, 0.012035931158607127, 0.052572821150533855, 0.03947473473090213, 0.02743448334513232, 0.03144817012071144, 0.1014820154523477, 0.04125182589632459, 0.012887539123767056, 0.019823462062049657, 0.01731230706354836, 0.038123313497635536, 0.02058929909253493, 0.020878859140793793, 0.03258089527662378, 0.03511355214868672, 0.008849125842971262, 0.03953522347728722, 0.07129569305106997, 0.01457329139157082, 0.05175504491489846, 0.060098539979662746, 0.0662175624165684, 0.013598675232060486, 0.0672351656248793, 0.028741930473188404, 0.02430294483929174, 0.04177137750957627, 0.1302092309924774, 0.020142244175076485, 0.06521549978060648, 0.018966520838148426, 0.060412023158278316, 0.020907088583044242, 0.00957194150032592, 0.01469557691962109, 0.04884125439275522, 0.018247079169668723, 0.045853067276766524, 0.12516188464360312, 0.06797058944357559, 0.015276398389687529, 0.058649574566516094, 0.017569045630807523, 0.055442988232243806, 0.028520130363176577, 0.03086736163822934, 0.045305755629669875, 0.0334725189168239, 0.03137936189887114, 0.05610441992757842, 0.04760976793477312, 0.010215796355623752, 0.06405476597137749, 0.04287111049052328, 0.012774566621374106, 0.043313645728630945, 0.05576745519647375, 0.08080552885076031, 0.057869280499289744, 0.009688709160400322, 0.01574016368977027, 0.022725294729752932, 0.020620105642592534, 0.021019121340941638, 0.07052662767819129, 0.022228499219636433, 0.06976097618462518, 0.013346954510780051, 0.040400100115220994, 0.1266539131756872, 0.01572472887346521, 0.011199436103197513, 0.003971558762714267, 0.039863842757768, 0.0498539037653245, 0.05357296533475164, 0.056941926159197465, 0.027692516960087232, 0.05496725301782135, 0.043285069332341664, 0.04143634607316926, 0.007747561148789828, 0.03327478851133492, 0.04153492925979663, 0.04411761059600394, 0.03370087404618971, 0.011342579691699939, 0.0574153644265607, 0.023862281668698415, 0.008860940833983477, 0.051803258538711816, 0.04032784832816105, 0.04491136351134628, 0.032583622669335455, 0.01637489847780671, 0.05933799817285035, 0.044869153862237, 0.05664241391059477, 0.03125049908703659, 0.015885797183727846, 0.06522996423882432, 0.06233973690541461, 0.016361272646463476, 0.0245390350028174, 0.13631100591737777, 0.050540512820589356, 0.009703314626676729, 0.11206248833332211, 0.012469115335989045, 0.048576274275546893, 0.047265307512134314, 0.019406417741265614, 0.027250735001871362, 0.0467167935858015, 0.02518440847779857, 0.08422510043601505, 0.009447828433621908, 0.026757223495224025, 0.03875746013363823, 0.01032754524203483, 0.02791696839267388, 0.013290748884173809, 0.03244282241212204, 0.021950236514385324, 0.010011176964326296, 0.02239662906504236, 0.03115719257039018, 0.02532628299377393, 0.007388836647805874, 0.043133188810315914, 0.02044415541604394, 0.019921048915421125, 0.046849426507833414, 0.028685746183327865, 0.03179438201186713, 0.05186457477975637, 0.021725935366703197, 0.04077486984897405, 0.014243263885873603, 0.013849257684341865, 0.02375857951847138, 0.059083059313707054, 0.0316528321855003, 0.028637298782996368, 0.026163763250224292, 0.08308473115903325, 0.042949555499944836, 0.0866355218749959, 0.04050337367516477, 0.04326247835706454, 0.05090145634312648, 0.04656198900192976, 0.017563473957125098, 0.02403154328931123, 0.07743878333712928, 0.03090526497544488, 0.09192253739456646, 0.006163655662021483, 0.029811908898409456, 0.030807793154963292, 0.04273920116247609, 0.07144669783883728, 0.06210476924024988, 0.034156775363953784, 0.03072697698371485, 0.013880965943826595, 0.03900245050317608, 0.07135621519410051, 0.022056777379475534, 0.03390746198419947, 0.06090698741900269, 0.0293819419312058, 0.09612369438400492, 0.05300706659909338, 0.027921935215999838, 0.03563353049685247, 0.03429884840443265, 0.04549469529592898, 0.09082904958631843, 0.0842458731494844, 0.08456819530692883, 0.2835311373928562, 0.12124974964535795, 0.17838592553744093, 0.1358864232315682, 0.10159433208173141, 0.18096619489369914, 0.1173347351141274, 0.18242904217913747, 0.13246062502730638, 0.15371609071735293, 0.10780444572446868, 0.09306695879786275, 0.14421006955672055, 0.07512438838602975, 0.21685427462216467, 0.18677801272133365, 0.13448760844767094, 0.11207746487343684, 0.12480909732403234, 0.2231559544452466, 0.1285115978680551, 0.0894306726695504, 0.15402234537759796, 0.11578268167795613, 0.1768848131177947, 0.15385856822831556, 0.1263038272736594, 0.16311726125422865, 0.19063735875533894, 0.11287179295322858, 0.15721377334557474, 0.10530453611863777, 0.20073889405466616, 0.212994305184111, 0.1503631120431237, 0.0957488504354842, 0.131101188599132, 0.10249883198412135, 0.06868163371109404, 0.1555756901507266, 0.1262585711083375, 0.17219973873579875, 0.14170030422974378, 0.1264111715136096, 0.16697255516191944, 0.1753832257236354, 0.08742982026888058, 0.14734605909325182, 0.13235804537544027, 0.08566615084419027, 0.16895679087610915, 0.10889490557019599, 0.12195136863738298, 0.09128366698860191, 0.1001131537486799, 0.0720605652895756, 0.09963130694814026, 0.0623710555373691, 0.12471338995965198, 0.11158459717989899, 0.09564388106809929, 0.10022025307989679, 0.09938109185895883, 0.14182557875756174, 0.25037082144990563, 0.12903202150482684, 0.16129184514284134, 0.15438215341418982, 0.16341925598680973, 0.14186051907017827, 0.1780197795596905, 0.15497694024816155, 0.11281235434580594, 0.14277264825068414, 0.24155323131708428, 0.14928538003005087, 0.14849082188447937, 0.09982932679122314, 0.11668222403386608, 0.12388871546136215, 0.13005437445826828, 0.1025331043638289, 0.1311147550586611, 0.1706506687332876, 0.10223863500868902, 0.11298709301627241, 0.15498074004426599, 0.11221723354537971, 0.23461760894861072, 0.1866208406863734, 0.1628635061206296, 0.1861147998715751, 0.2335851182579063, 0.17477576300734654, 0.2217012707842514, 0.14352065889397636, 0.24115592997986823, 0.1807222212664783, 0.12410490307956934, 0.2060552837792784, 0.13693478103959933, 0.10989155052811839, 0.11640594471828081, 0.08904970600269735, 0.10239867173368111, 0.10975130688166246, 0.1711039725341834, 0.20158409635769203, 0.147319326933939, 0.11853110685478896, 0.11889502638950944, 0.19850494049023837, 0.1901327577070333, 0.08332930592587218, 0.1332516802358441, 0.15866511734202504, 0.11205352318938822, 0.1728361303685233, 0.11459711560746655, 0.09001697675557807, 0.20689134282292798, 0.09800517975236289, 0.12525110563728958, 0.07244300140882842, 0.14527937077218667, 0.1520711649209261, 0.08494044173858128, 0.15320250968215987, 0.12969398754648864, 0.13934768125182018, 0.2267314586788416, 0.10071667566080578, 0.0911771465325728, 0.1638725004158914, 0.1327615065383725, 0.07179170002928004, 0.12688960443483666, 0.1377953012706712, 0.10093563148984686, 0.06318541418295354, 0.2475082836463116, 0.13902640552259982, 0.1890324495616369, 0.18669998331461102, 0.12076806611730717, 0.13369946245802566, 0.0875493060448207, 0.06470105043263175, 0.09990606486098841, 0.1699878418003209, 0.13112014305079356, 0.23261575464857742, 0.0997490857844241, 0.1625194019288756, 0.19748720369534567, 0.08185960119590163, 0.13360179582377896, 0.19527260534232482, 0.09773850382771343, 0.14543308439897373, 0.1577659757458605, 0.11629778411588632, 0.17313983204076067, 0.1135564167634584, 0.11939902629819699, 0.2259316312847659, 0.11829044320620596, 0.19578857609303668, 0.08240246737841517, 0.12047561540384777, 0.13542173488531262, 0.14899496280122548, 0.13690122112166137, 0.2574478823225945], [0.10394552271463908, 0.033578122820472345, 0.008190504104277352, 0.003839298074126418, 0.02256025964015862, 0.033008398313540965, 0.05035752888943534, 0.05425626441137865, 0.021723669960920233, 0.09645875179558061, 0.016866836631379556, 0.020280020180507563, 0.02762769778200891, 0.06847418117104098, 0.06317032632068731, 0.03098058183240937, 0.08591813224484213, 0.03331799263833091, 0.016304303535434883, 0.0158028343503247, 0.013838716404279694, 0.056822280821506865, 0.026902311510639265, 0.060730942568625323, 0.060946699741180055, 0.11254081735387444, 0.006478875466200407, 0.02227832330390811, 0.04339534876635298, 0.027252091276750434, 0.017461701390857343, 0.05471077420224901, 0.054460959872812964, 0.015927773056318983, 0.028698243950202595, 0.06896225459058769, 0.023000349501671735, 0.04830059981031809, 0.02456694532156689, 0.015604855325364042, 0.018175923905801028, 0.09858671925030649, 0.07995121297426522, 0.04577644795062952, 0.023100244434317574, 0.010380082803749247, 0.04417937954713125, 0.020649964098993223, 0.0075251028465572745, 0.058853294103755616, 0.040969000838231295, 0.04414224989886861, 0.04643100735847838, 0.050206245796289295, 0.02958886940177763, 0.012156975444668205, 0.02545188406656962, 0.031447453948203474, 0.03452727774856612, 0.08308260861667804, 0.04191389583866112, 0.022657957815681584, 0.0417498366732616, 0.016222492886299733, 0.027481802680995315, 0.07256957469508052, 0.018610033912409563, 0.04184922137937974, 0.015092849498614669, 0.04094648036698345, 0.07716772131971084, 0.01580991258379072, 0.03503050211293157, 0.03474024444585666, 0.08035695253056474, 0.03645707693067379, 0.06550792822963558, 0.05970645594061352, 0.05899152281926945, 0.04577429572236724, 0.04958428522513714, 0.06548952296725474, 0.048381141386926174, 0.034457968577044085, 0.05169792551896535, 0.04835270970943384, 0.043100920229335316, 0.02820901463564951, 0.0584269710816443, 0.05047122591349762, 0.012682934575423133, 0.059079274360556155, 0.07167690462665632, 0.040466911959811114, 0.07083434436935931, 0.013237090679467656, 0.03978719745646231, 0.04524212759861257, 0.01598963663127506, 0.026561929189483635, 0.05289470915158745, 0.07515135803259909, 0.013294742566358764, 0.03249589339247905, 0.049444245669292286, 0.06598495107027702, 0.04159052354225423, 0.03127693067654036, 0.01781635521183489, 0.022361456831276882, 0.017708892228256445, 0.017177453264594078, 0.04120616154978052, 0.00970110580965411, 0.03730650576471817, 0.024226984169217758, 0.014034693485882599, 0.05458749976241961, 0.04920181570923887, 0.01086875921828323, 0.012620555207831785, 0.017471581231802702, 0.024514699980500154, 0.004925980156258447, 0.04925805566017516, 0.04045841807965189, 0.04550300734990742, 0.009741829308040906, 0.0016055088258326577, 0.07063489218126051, 0.03537484379194211, 0.048630176461301744, 0.022490492192446254, 0.04886800881649833, 0.06803932716138661, 0.03861437777231913, 0.028026153158862144, 0.027191073750145733, 0.007813047795934835, 0.03874232032103464, 0.04793070227606222, 0.01477906946092844, 0.058378794565214776, 0.028174146682431456, 0.029606885036628228, 0.06760215022950433, 0.0212051926064305, 0.010508681225473993, 0.03708481883222703, 0.03053618380363332, 0.014470637524937047, 0.025876995532598812, 0.0243460228011827, 0.029973988384881523, 0.042623678455129266, 0.0367946316691814, 0.01295958867558511, 0.020333978027338162, 0.09194388898322359, 0.017382840778736863, 0.010240418032481102, 0.0018892735124609317, 0.04196581277938094, 0.037782163053634576, 0.017018858161463868, 0.02601104224595474, 0.103307654208038, 0.038396319941966794, 0.06579932509339415, 0.09967489328118972, 0.052223110033082776, 0.0818114061257802, 0.05745201910031028, 0.06909736999659799, 0.010345654573029606, 0.01205933293022099, 0.02254576549603371, 0.004799924518010812, 0.01045932747729239, 0.025190241758537013, 0.03461955267994199, 0.03690312623803038, 0.07424034949508496, 0.05449743643112015, 0.031108555922401138, 0.06305118935415521, 0.02853658006642945, 0.04336558864451945, 0.03152860408590641, 0.029969114330015145, 0.05561755249800626, 0.02481648320099339, 0.045830186863895506, 0.040485951758455485, 0.04372447270725388, 0.003493493900350586, 0.02931030798208667, 0.05180042724532541, 0.029181476711528376, 0.024117923712765332, 0.02922425039287191, 0.11235440470045432, 0.04173826288024429, 0.03475970726867672, 0.03360282149515115, 0.03391751437447965, 0.025434566050535068, 0.056753665558062494, 0.0790879839041736, 0.03378774243174121, 0.0548809709289344, 0.06489760082331486, 0.030380425559997093, 0.04984037812391762, 0.01617052770598093, 0.022037533490220085, 0.039213932905113325, 0.02800526170176454, 0.04646805908123497, 0.099292835657252, 0.0674171773425769, 0.025411750575585756, 0.017654132861935068, 0.014313574956759112, 0.050950493750860915, 0.016980721047730185, 0.011517201473907335, 0.09879054268822074, 0.01800942307454534, 0.02637706020323094, 0.04928102142002899, 0.022522955587191973, 0.053534340258920565, 0.012919864293507999, 0.03753340999537613, 0.0693376551498659, 0.023849303361203056, 0.05757677041401621, 0.04455506212252658, 0.008128996760206064, 0.07069552564644255, 0.01975813451281283, 0.051269372343085706, 0.02160912688850658, 0.028639979791478254, 0.02672047048690729, 0.062493769655702636, 0.038213510415516794, 0.07969481579493731, 0.04890683798294049, 0.043092578489449807, 0.08742938240175135, 0.03854312788462266, 0.026350823427492287, 0.14021477691130713, 0.00759669829676568, 0.04440544144017622, 0.0614055956248194, 0.006592225072381552, 0.0712165430013556, 0.04600807595124934, 0.03358516580192372, 0.009105540648306487, 0.0665496735018678, 0.03075773529417347, 0.08011817393708043, 0.042477831593714654, 0.06817605302785523, 0.07812089868821204, 0.012364394588075811, 0.05195855665078852, 0.04288242453185376, 0.0332141290709842, 0.0376307315309532, 0.032284908229485154, 0.038856303071952425, 0.07487301554647274, 0.04618657359969802, 0.03116477731964551, 0.010366120222897734, 0.0732249059365131, 0.01929446661961265, 0.06287875134148635, 0.011384716981410747, 0.027300017318339087, 0.07358557486440986, 0.011542209067556541, 0.039766216941643506, 0.08125886233756319, 0.0035283604620417464, 0.02977700569317676, 0.04097301956790034, 0.027341635104676243, 0.03455704158113804, 0.04895851743640378, 0.02045815603196388, 0.073454036610201, 0.052312126936158165, 0.033117579368990846, 0.012304599749768386, 0.04178339288046118, 0.025910080476023722, 0.018793225644913036, 0.02337744772376027, 0.026967392295773607, 0.04556426421913784, 0.024099690999719314, 0.023347342503257096, 0.025923739704012405, 0.023894928744994104, 0.04264254013833124, 0.020857103081652895, 0.006953355987207033, 0.026610183631419204, 0.006537416074934299, 0.037377837288659066, 0.009374381788802566, 0.014162621191644575, 0.015843498476897366, 0.06149870176159311, 0.03522558676195331, 0.018992670411535073, 0.016945962561294436, 0.016256817216344643, 0.04809099504200276, 0.045445242285495624, 0.0074113478422077606, 0.00876850170243415, 0.03525847503624391, 0.059560705558396876, 0.06257001048652455, 0.013733567066083197, 0.021699954631912988, 0.016697740138624795, 0.11680620722472668, 0.05401871407229919, 0.005981507574688294, 0.012267506281204987, 0.04806376564374659, 0.008379352857446065, 0.015915407020656858, 0.02114316390361637, 0.05261540187348146, 0.057241961621912196, 0.03854061200399883, 0.04344421919086017, 0.04133801892749034, 0.04085359687451273, 0.05708129778213333, 0.02655122927535558, 0.058834599403780885, 0.013901233996875817, 0.2419953583739698, 0.15689090942032635, 0.11112552689155564, 0.08684051790623926, 0.13487077929312363, 0.11642352619674057, 0.18656523898243904, 0.21194333501625806, 0.08948991831857711, 0.19407284940825775, 0.09752974510774948, 0.1491665918729268, 0.11615509880357422, 0.17394334048731253, 0.18383554561296478, 0.15949960303260013, 0.13950037071481347, 0.1212691493856255, 0.08983218198409304, 0.09436429230845533, 0.13980030227685347, 0.20778410194907337, 0.08825315147987567, 0.126346456236206, 0.14977737941080704, 0.16887131030671299, 0.13204671442508698, 0.12941271357703954, 0.0929586571874097, 0.11689522783854045, 0.1215355284512043, 0.0942504988051951, 0.21552722551859915, 0.06662622603471391, 0.14787476509809494, 0.19661638245452195, 0.10675130848539993, 0.12485424958867952, 0.11566567467525601, 0.12505068123573437, 0.1318986262776889, 0.21222089824732393, 0.20053079584613442, 0.14613742707297206, 0.11822295229649171, 0.10575100473943166, 0.07237016703584231, 0.14313926920294762, 0.09356098424177617, 0.14491543639451265, 0.10199583397479728, 0.1333780976710841, 0.1282928721047938, 0.1023222750518471, 0.1417070280876942, 0.17516579129733145, 0.10952284414088354, 0.11883174345712177, 0.10309766352293082, 0.1460879109799862, 0.07886849372880533, 0.131507930054795, 0.19468653132207692, 0.09321970763267018, 0.12066720082657412, 0.16705318208551034, 0.17292251635808498, 0.16158356855157763, 0.12090645439457148, 0.09514518751529977, 0.13446038647089154, 0.10756244621006772, 0.22150173695990816, 0.23762364842696115, 0.25058266008272767, 0.2072871895506978, 0.17865422676550224, 0.12517301685875282, 0.2897278923774138, 0.09644805002608337, 0.14830665051704273, 0.17512507707579061, 0.12612243153853342, 0.23477264359826222, 0.195777221233584, 0.15690523287048563, 0.15167689154623076, 0.2267917655990459, 0.13711516745388508, 0.20374520070618019, 0.15035465155960992, 0.21021399734308943, 0.13656030816491693, 0.20000741846160963, 0.19588793482398614, 0.14825799531536177, 0.14486318919807673, 0.1549803392845206, 0.15568272268865258, 0.09114588727243245, 0.19306018890347332, 0.17980109725613147, 0.07768812269205227, 0.13233950652647763, 0.13937065814388916, 0.12937836698256433, 0.1681173624820076, 0.26299101300537586, 0.19343917403602973, 0.14033727580681443, 0.10482608835445717, 0.08029709832044318, 0.1409734893240966, 0.11948174607823603, 0.10856464243261144, 0.098236655612709, 0.145678379049059, 0.1295892259804532, 0.21434237190987915, 0.1586194455740042, 0.17076029878808185, 0.11588589215534739, 0.1489592803409323, 0.09840196900768206, 0.14620205329265445, 0.07688312252867036, 0.11905573104741052, 0.09120721093495376, 0.15230077056912705, 0.14005033182911575, 0.11900296434760094, 0.11772472629672848, 0.16916459222557023, 0.1665436680195853, 0.1446656443295069, 0.09646560924011283, 0.15114567708224058, 0.10419422382256016, 0.13756492378888652, 0.11019130397471599, 0.10695947348722257, 0.09528074078843929, 0.14211307192454115, 0.11333599148201756, 0.100397351779975, 0.12685984431300312, 0.1478116528596729, 0.12743471190333366, 0.10528037179028615, 0.21617206279188395, 0.11032716152840294, 0.08111696370178834, 0.11568969799554907, 0.1398293796228245, 0.15056801901664585, 0.12778709846315905, 0.1419138943310827, 0.12690849951468408, 0.1909936044830829, 0.12920032575493678, 0.10178999931667931, 0.18669575307285413, 0.23583775910083205, 0.13398217619396746, 0.09604587277863175, 0.05450737749924883, 0.16757891949964687, 0.08916004109778441, 0.2395864063873887, 0.1850086436024867, 0.1983886756352149, 0.12821712851291522, 0.2621596591779962, 0.24267528438940644, 0.10015501829911955, 0.06982387320022099], [0.015527503128396347, 0.05175091857381631, 0.03636715089669451, 0.025233037704310846, 0.028083083307137713, 0.038923805113881826, 0.03890628671797458, 0.03458886858425103, 0.06419974452001043, 0.02689633722184226, 0.04839205095777288, 0.04562822621664964, 0.02027262467890978, 0.013516851595340995, 0.008542006580682937, 0.03131276898784563, 0.04867582596489228, 0.102846602385398, 0.04956342716468498, 0.01864694648247678, 0.03751280797587242, 0.04346896239439957, 0.060478879531729035, 0.06459544281824492, 0.054632455357932486, 0.03698167514812667, 0.06896197257447056, 0.03321570242405869, 0.02051477633358445, 0.03631856990978122, 0.053621004553860985, 0.03611794512835331, 0.049356694507878274, 0.04705878636741545, 0.027907027324545197, 0.0505642504140269, 0.03464092282229103, 0.020805646272492595, 0.011875628188136034, 0.034155799439758994, 0.023782730859238654, 0.010906631941907108, 0.012247354188730242, 0.04145584229263477, 0.013916357111156685, 0.03954605141188949, 0.049838470804388635, 0.012004357413388789, 0.03904474921000656, 0.06879793567350134, 0.0403671005187789, 0.04377633398689795, 0.023516836045018863, 0.04794309243152384, 0.07262408544193022, 0.04165263017057441, 0.02171551932406146, 0.025378259306307882, 0.02343705145904096, 0.09580934289260767, 0.04500249553530011, 0.033237432508030906, 0.027397229387133848, 0.03443479130510241, 0.022198874539753888, 0.05402176429925021, 0.07353569511906244, 0.08741064317291602, 0.012768785290973028, 0.09622274141293019, 0.02550111628806917, 0.08541559436707757, 0.05244318650511559, 0.027441715574241243, 0.11661837706924416, 0.04977422308002133, 0.02385983072599629, 0.05714559003536124, 0.0315042171132518, 0.04825254203751683, 0.08416221084189601, 0.0370815719361417, 0.06070983588870149, 0.007316894707400934, 0.13521898014005274, 0.06100052400142886, 0.04085310334630776, 0.057227122379117645, 0.031105995512916707, 0.017114261245296802, 0.050323137766099535, 0.03930465303710662, 0.01394793178405962, 0.060072386695537716, 0.007676600234844955, 0.04151701752562076, 0.02658712510310579, 0.03386883319763001, 0.014790824152441928, 0.010503508456167765, 0.03844655962893739, 0.12214838658110239, 0.0049625211886450415, 0.041348835729877464, 0.0816525865229778, 0.02160265350539703, 0.031404524415847845, 0.013892156603105832, 0.019683400241774507, 0.05079696195025463, 0.040904608395067044, 0.016009631945053115, 0.03869048501655925, 0.022784911452617962, 0.029872727900510654, 0.03548457403667271, 0.07756160135613754, 0.008461856486974284, 0.01982388879696373, 0.05928544298512861, 0.026836002471100073, 0.020004353136755526, 0.04826320298889186, 0.02616432357172016, 0.05275802039250266, 0.058221210638293996, 0.02312020635145018, 0.027217553579248488, 0.03369815036421642, 0.017322763924312312, 0.0670371086744126, 0.05588836960669141, 0.04136036128329579, 0.07080048017087393, 0.056093707025866024, 0.04091029324627016, 0.03425096132559702, 0.03220322745619342, 0.05046096572186798, 0.05925562720221933, 0.021740078846050892, 0.00804641242211801, 0.06214070032001473, 0.03676655993331224, 0.04466109647182748, 0.06571212274138816, 0.041988633820437826, 0.015218736298265867, 0.055888291681185365, 0.05375230161007494, 0.03612046471971553, 0.04491896310355514, 0.03482129439362325, 0.014234528807719471, 0.027649132862279657, 0.05463662622787524, 0.024844425061019138, 0.03503660256683361, 0.048409109222120605, 0.039729940763209015, 0.011882144244736992, 0.01653988718317123, 0.0798787348321639, 0.030044692794035655, 0.05121952228364535, 0.05919914605328813, 0.029131684168532956, 0.06935109544428997, 0.039231076516443864, 0.05835736134031322, 0.027466000501590315, 0.037328135658754036, 0.044218542680027895, 0.0041240223345084814, 0.05321146149071865, 0.008505821315338835, 0.02326638532395009, 0.033114558827946894, 0.048945945454761386, 0.04094088086276315, 0.035087792202830315, 0.008119924004859058, 0.030266554131230805, 0.036475085144047625, 0.008073033259279327, 0.035958528096671216, 0.033213605856872164, 0.03052855081477901, 0.02689073957299115, 0.038770061801187694, 0.045151578160584904, 0.032589441107120365, 0.04804371652426198, 0.03625209203164559, 0.07634536232217215, 0.06459665251895785, 0.05650920211337507, 0.1425611213198863, 0.03135038474283647, 0.02423441306746099, 0.04788005811860785, 0.00948568445892306, 0.04249061879818328, 0.020510065551206935, 0.03570357439457439, 0.012150782222306589, 0.04944677639286965, 0.08484345045872033, 0.08123103179968894, 0.0422499514388619, 0.04283835209207609, 0.03996727587946225, 0.047074364047148265, 0.021168383937038016, 0.0248358680983074, 0.04593983176164329, 0.023563105241919402, 0.011163658091390971, 0.02854840062354924, 0.030964614525146317, 0.03115252075076569, 0.05081179006083403, 0.021854369588254485, 0.04304115136619657, 0.04412162190419622, 0.018436031823512167, 0.006278005776039208, 0.04550230602035299, 0.07573698676424101, 0.03535683928930666, 0.058807102832361124, 0.05630582767480519, 0.00919448148124502, 0.029605907257064246, 0.047567454384989105, 0.028983998636249453, 0.007161645298765507, 0.03468482827884145, 0.01395866787788691, 0.009730494857649319, 0.01996584309381433, 0.0397243672341574, 0.09800287909456529, 0.04803380885277875, 0.02990790941112209, 0.05237783298071008, 0.004811694516320131, 0.053037887992104515, 0.022025080252205953, 0.09670624320278876, 0.10144508618395776, 0.03275518865848426, 0.04840861198317725, 0.024529537367925514, 0.04889240692136809, 0.03546513347828295, 0.07368373873759992, 0.04407466622069478, 0.027812030566565227, 0.017973479007196147, 0.07147869924665429, 0.039475833109463565, 0.032793939899420366, 0.06557999819051474, 0.01743990451359423, 0.03737481303687673, 0.017713341403577942, 0.008874924751580693, 0.0251160362677183, 0.0708622342790477, 0.05516898731002584, 0.0641558613278903, 0.03949606776586734, 0.03714377133292146, 0.011196114064659923, 0.0035807245467367466, 0.04280860310245771, 0.06288053991738707, 0.03477743346593343, 0.02482079878973309, 0.03495262484648265, 0.004862375781158335, 0.020021576528961305, 0.055061520615709014, 0.06053699711628724, 0.0297628993212129, 0.04503654155996628, 0.016706369460735004, 0.05622018012218177, 0.018457123660482466, 0.03989688688307069, 0.05576408584602177, 0.04079528262082022, 0.02120455992553616, 0.01916054607136175, 0.0348323264188366, 0.01790537397027947, 0.009013287981360918, 0.0425431776966434, 0.04449485168152023, 0.05013023874198552, 0.11641052376944572, 0.006968619645704166, 0.034033411866403185, 0.02658418434293708, 0.04130255911150016, 0.033835751964943483, 0.0430030791903846, 0.03993527447164524, 0.05950761973508634, 0.038325010682456195, 0.029440269172482658, 0.05855043476913124, 0.061435715688276105, 0.07417173794237897, 0.014686469839944039, 0.03281645665992983, 0.031028042176330928, 0.028392378917487804, 0.03888094979629386, 0.051930522022303194, 0.05756602782639675, 0.07541776678408496, 0.01169568335171789, 0.005772280837845756, 0.04230903752613813, 0.06363725595292635, 0.024297760937770363, 0.03789752248849254, 0.06005088296660688, 0.05352736778149847, 0.07144566625356674, 0.09176825231406838, 0.05991815727611538, 0.03280929864558857, 0.02336040615773527, 0.021448231127578765, 0.0055387455176969524, 0.05494403863849584, 0.00758937932914705, 0.04347541536844801, 0.06337558210361749, 0.005136197660249309, 0.04089891612238716, 0.0056714879065111745, 0.07586189763969742, 0.07105970493284985, 0.04901869819150306, 0.075540146935964, 0.12534439360024408, 0.04150703192863148, 0.03650666352768894, 0.10932544770184904, 0.13447370060021058, 0.13559250306570902, 0.2281204325845465, 0.11948756451602094, 0.15929423592751846, 0.10359185966080986, 0.10720996317104436, 0.11655348367639817, 0.13327964436030015, 0.14480455953162163, 0.18751974479528144, 0.1488875295035541, 0.0930232166138012, 0.1655851842951961, 0.10738753684563562, 0.13671851920662448, 0.16590304614510387, 0.09491132193943486, 0.13548555958550423, 0.18253801914397627, 0.25833047402556986, 0.12702992971753702, 0.13782709487713873, 0.10229305669781752, 0.15259963343851268, 0.22138691187137738, 0.09335434064269066, 0.10664172295946628, 0.10509066400118172, 0.16372049372876063, 0.11875657131895423, 0.1323677081381902, 0.1551916732569225, 0.11591073183808476, 0.11952905057114549, 0.13309260830283165, 0.07279328026925214, 0.08695363605511375, 0.1428321239654906, 0.1243220703327097, 0.1322402071673423, 0.09591794878360815, 0.11972171952947974, 0.14895304630044848, 0.14577981579350308, 0.11899331642780453, 0.07408768229652196, 0.13951433793408796, 0.139614409126807, 0.07919011084595695, 0.13525812100851908, 0.17283863882767037, 0.10924320289632306, 0.14539646683260798, 0.17859040206531063, 0.0686917343409732, 0.12476522155338898, 0.11056653384002857, 0.19296376907732338, 0.11496122810058296, 0.10521440228330903, 0.10137030738405883, 0.12451364833395928, 0.11957023976719938, 0.145802540355362, 0.17406166851287708, 0.15662949532270432, 0.15216204832540825, 0.22920868825167418, 0.07816628101863898, 0.1316229481017217, 0.16353008832084015, 0.1678063877625391, 0.2095322753302753, 0.16757615871028975, 0.18876725051086396, 0.10691530085750856, 0.07316561575862579, 0.10809690385940485, 0.16085675364593044, 0.13388718129135668, 0.1075173458957579, 0.10362451415858231, 0.2432425820734352, 0.14393793884664774, 0.13078018004307523, 0.17442766606109217, 0.14815453992923722, 0.14567967038601637, 0.13530227879527956, 0.11567056542844512, 0.1033201816608198, 0.1459618646185845, 0.13477127213263884, 0.16605279670329764, 0.07639280040166341, 0.15432687825523317, 0.1420056534698233, 0.07922939272248186, 0.12425183347659186, 0.18699330976232886, 0.1895850378787145, 0.1527380885090679, 0.28438445879146457, 0.10408480156911537, 0.08542719413526356, 0.1346329358057119, 0.09270395952626131, 0.191768376971595, 0.10513837667531334, 0.11276748409727588, 0.1417055437923409, 0.1445224098279141, 0.12923934787977487, 0.15327587840147316, 0.13070621760562062, 0.14770945912459865, 0.10587620505248196, 0.2005690461373888, 0.10353110745199956, 0.13339582015760243, 0.14461884449701756, 0.181970929261297, 0.16745379340136424, 0.25186607090290636, 0.07871838693972677, 0.1299011951778084, 0.22364030970493332, 0.13442411029245704, 0.2555183874210343, 0.12930234137456864, 0.14479213597951457, 0.17218896275153384, 0.13743292540311813, 0.11042609723517671, 0.11399794268072583, 0.12780575605574995, 0.16994276375044137, 0.09299182376707904, 0.13983703858684748, 0.13808285380946472, 0.12054577062372118, 0.17745982913766056, 0.15486132848309353, 0.18384942377451807, 0.11689778824802488, 0.15037338336696848, 0.10384421213530004, 0.15475723484996706, 0.1487387585802935, 0.09955519228242338, 0.156455610122066, 0.1626278890762478, 0.16909907542867586, 0.11719547852408141, 0.24312278459547088, 0.0988874003814999, 0.12402016465784982, 0.1390366768464446, 0.07000486817560159, 0.2386729116551578, 0.17595638637430966, 0.06210414212546311, 0.10541119016124867, 0.1257372717373073, 0.10966740708681755, 0.24241036735475063, 0.06935246841749176, 0.16893381398404017, 0.09978601505281404, 0.09447399657801725, 0.14879657188430429, 0.2545337949413806, 0.22510795126436278, 0.225665319012478], [0.011616383017098997, 0.017454970111430157, 0.02764405286143301, 0.04882117187662516, 0.06080889033910353, 0.03702938040078152, 0.03477252786979079, 0.03744470108358655, 0.00887330965269939, 0.03484700609988067, 0.022039804462110624, 0.046303250346682034, 0.0454497397004161, 0.024195986516133416, 0.03955073065299075, 0.032899755315156654, 0.015683927449572366, 0.07500217150663957, 0.0192157099081669, 0.015073061986186076, 0.022136487750685774, 0.04351323892478831, 0.026270179805578664, 0.054964184237178415, 0.03228356123145204, 0.0017284066257161612, 0.04624880268238485, 0.03472325668553822, 0.11155623229569755, 0.019983148122264538, 0.025019785280164797, 0.05879877964616753, 0.05536416843824554, 0.04897939405054785, 0.019183895892638247, 0.01726532726024743, 0.06763584373402409, 0.03978267777711153, 0.07998119574040174, 0.04301927285268903, 0.05213519150856882, 0.030918091142666526, 0.012293164181755856, 0.09550738526741043, 0.021938978134130593, 0.04804976131708827, 0.07336781389312819, 0.027433997238404118, 0.04085166729055345, 0.020682692811533343, 0.09747953881742433, 0.013840153387718601, 0.12490643741330132, 0.05377911540563218, 0.016043831965362187, 0.03353586493176408, 0.03970553523686249, 0.030145097953209188, 0.035316997091285884, 0.03142500398098491, 0.01883247783553088, 0.02232989700132748, 0.020905758283333853, 0.07443874783348292, 0.02924752599938074, 0.021616041849483736, 0.013056317420705454, 0.030962430755607784, 0.061788595776306465, 0.0161859161380562, 0.032564801804255694, 0.08474880436551757, 0.06447997206123546, 0.03582954283047002, 0.06424695995519869, 0.06118217948824167, 0.06603123882086948, 0.02791647486446891, 0.011348531716066645, 0.11753098864573985, 0.018107924624928273, 0.07999102919711731, 0.030873450959916227, 0.00993341565845185, 0.04521764043602161, 0.04392569862829987, 0.050930927027366124, 0.032525831629754975, 0.042694197327364236, 0.057766288955463096, 0.010166014944843482, 0.03587517006963026, 0.0637051253579557, 0.10593329105176963, 0.02982007437822176, 0.03502382278384175, 0.01471691644837847, 0.010558595295151463, 0.023094309108273592, 0.04680907593865413, 0.06547601587953977, 0.02569427506387001, 0.03357728048285935, 0.02917354129749583, 0.0010553522020018136, 0.03684251132654026, 0.046015289626666345, 0.022355617984430864, 0.05047059879871085, 0.0447099149459973, 0.027375890786061063, 0.02572598517872393, 0.020226247870596126, 0.027478093797981273, 0.08595690203947015, 0.08114657539408654, 0.06383828149409965, 0.06280953122768551, 0.006300784607446985, 0.02842019275703933, 0.009970948849513661, 0.05350000850739889, 0.06510906096082181, 0.04932538700813893, 0.02835264618624933, 0.08485028563882224, 0.019108417618554085, 0.011975866364082322, 0.05140309993294068, 0.013521113378374139, 0.053248294279910624, 0.0248805750743486, 0.05986945754557382, 0.004440126685949508, 0.0030359459424289525, 0.04089094545633998, 0.04869899581535719, 0.05786321344203316, 0.04842707661737222, 0.007756240565868211, 0.025620021333452314, 0.017604908061912283, 0.02651604219863657, 0.07014641058049165, 0.031730137998238206, 0.03415051534830127, 0.07336048889555968, 0.016207894841500092, 0.04741915101476479, 0.0055522192087664735, 0.006079914037400158, 0.04078933059645351, 0.05057813599705696, 0.019613280273915734, 0.023298926644201856, 0.051765101015917026, 0.07254709504195489, 0.043701837203116156, 0.032153125066543, 0.026487452814762946, 0.020768316244357266, 0.036221125919837505, 0.016157219142769463, 0.06653589181951247, 0.10145175809157081, 0.028981582945561968, 0.02955977906822227, 0.054085841329651885, 0.06892962235724553, 0.015512409700022545, 0.11796796519774944, 0.05339876101061236, 0.041096909990301356, 0.02060798080492532, 0.025958234728022944, 0.06572058322490193, 0.038507957506226376, 0.024411257581959944, 0.04560259243589826, 0.07439286084263586, 0.05298804164340254, 0.014070765573706012, 0.03458296479948331, 0.013182565089664422, 0.01838845644670073, 0.018120275817636866, 0.027073287492385134, 0.0389755550713744, 0.026015877338068094, 0.03517702061799355, 0.048876276341616176, 0.017427757411496714, 0.11257845908403397, 0.0037134435115149245, 0.007988842171471333, 0.07848700013710186, 0.03366589291545097, 0.054776691758888774, 0.017945340478036087, 0.09239383085514419, 0.0012697979764197953, 0.02574181889940519, 0.03592058579670265, 0.05054092100181151, 0.06626413960475475, 0.05609230436675716, 0.03245020307076629, 0.020053457337780856, 0.016452454765385482, 0.01065961272615823, 0.07179820866440423, 0.04718116651929449, 0.00828734509923379, 0.05696366737538483, 0.06579320237506181, 0.07375358225544915, 0.05009722059185151, 0.0927242795296479, 0.013841731379216071, 0.028399349539540708, 0.05829729561810382, 0.05640730894810986, 0.05686093929398339, 0.05511743402166758, 0.10574891188298352, 0.06057620848878287, 0.015882522457104642, 0.056124279799405485, 0.06423205020837486, 0.09683292781119235, 0.05175598373170942, 0.04253406783391256, 0.014991353382356465, 0.03390814847080037, 0.018631496823218185, 0.03943401308788452, 0.01573441390064545, 0.03565693783457391, 0.0040210201223089825, 0.04019734536996111, 0.041890124848578125, 0.08122435247059911, 0.029679710132768378, 0.017627254128456116, 0.020714183992822655, 0.0378172592172632, 0.028018204757245257, 0.06447879204642959, 0.006001855872455053, 0.044935902624274604, 0.0289103553222958, 0.06900931417476386, 0.0439202475536149, 0.035872802618541755, 0.02919567770732101, 0.09650714724557474, 0.013887348413845757, 0.028456641484808642, 0.042934085431625135, 0.05421430709247943, 0.07631675995071419, 0.050799173550331034, 0.02660056354216067, 0.04174388464889489, 0.027943793320446275, 0.04900965512206312, 0.00824764483695617, 0.07113268773537129, 0.03466353977273684, 0.12092729390133172, 0.0550712835683953, 0.07578722274047323, 0.07648694183444604, 0.02237797889392823, 0.03836159114143811, 0.042385267224744894, 0.03028277376870392, 0.01683786689682165, 0.01392210133417393, 0.023290768585866317, 0.04718910749943461, 0.046071132528595626, 0.05294480040902272, 0.028480319706432056, 0.028670161082118284, 0.06280559784499928, 0.08716270647710189, 0.011128850437671645, 0.02712872035772307, 0.0519316055579111, 0.013746366330451565, 0.01734992652927758, 0.05087518802611157, 0.023572085228806827, 0.03227514156606048, 0.017027199901349377, 0.04750331427203491, 0.07771189368213527, 0.034010208619292825, 0.02494919961463893, 0.05198645027121529, 0.023464922815037426, 0.009816251877055038, 0.05176666694751475, 0.037961388006806374, 0.021394011673692148, 0.08976846118457615, 0.04337843151006382, 0.020191545045236126, 0.008278810400952352, 0.06392405150108971, 0.06019743857905269, 0.07008243002928793, 0.014048015964363003, 0.024980087800940964, 0.007360452282227925, 0.07087837599101476, 0.034526238741818815, 0.07062625358230434, 0.07024072270723991, 0.07879957789555192, 0.02991265730088344, 0.021311796554073226, 0.09517009399132803, 0.030825857029412873, 0.020823732411372475, 0.010136302134924335, 0.02735287864197744, 0.04464814599486999, 0.028185768715047743, 0.03730343698407523, 0.0026400748629384907, 0.03613258770201355, 0.04230291109706741, 0.05232294373854529, 0.01272835865165689, 0.02953466108010616, 0.012286460732866544, 0.02102584705426125, 0.01789930134691531, 0.06789953622501343, 0.05501534047652967, 0.026173706173722167, 0.055749172388459556, 0.09064665195182897, 0.060475896098068915, 0.049217218984267674, 0.018187262066930998, 0.024813310519675724, 0.00899540036698454, 0.04070371272973716, 0.06055742473108694, 0.11336345836753026, 0.09691757717519067, 0.08523677388438955, 0.1721019236720167, 0.112035511265276, 0.191684098681435, 0.14220720593584701, 0.06167002284200862, 0.14162228966597468, 0.10035247410996817, 0.1605376004590653, 0.10743155362433754, 0.11318258955725469, 0.06781850854167715, 0.2253085537813604, 0.10410771908937022, 0.15868413116550073, 0.14084539463510737, 0.09921638702508062, 0.19608019560109824, 0.09049414060427807, 0.17152922315290198, 0.12702445266768336, 0.22998349042609334, 0.10723184168455191, 0.08570152160245925, 0.10924928850727156, 0.17075914103770629, 0.23105555243091658, 0.12480218050768599, 0.0880274866358377, 0.1452162882196717, 0.10032672158558853, 0.16615473810816184, 0.16350872931070626, 0.0947795165120624, 0.15385864244308323, 0.13452370651066303, 0.2179156942293048, 0.26469902135431767, 0.13331949769053608, 0.1491329725831747, 0.08302470625494607, 0.21148387138964608, 0.14077576634008437, 0.27881627320311964, 0.26939776609651744, 0.2189405111130327, 0.11828956747194752, 0.13333215872989967, 0.2265732327941805, 0.11070977576309815, 0.18097520456649363, 0.21933735231868923, 0.20509755704551935, 0.15488843171624467, 0.11760253910324536, 0.07687434292165563, 0.104211389698321, 0.1019230144447647, 0.1464255288010463, 0.1404164481209591, 0.10708989851991646, 0.16039674083003774, 0.11072393594076857, 0.17099974531447515, 0.11743292125174776, 0.1164518242876511, 0.21676287171430886, 0.0984112532751169, 0.08945254376158118, 0.14460461010457948, 0.18075334694003686, 0.13846865185769275, 0.12285805787541904, 0.1308411845820956, 0.1260781253222376, 0.12727470486424863, 0.09254027885617688, 0.29668460658285767, 0.08303646187414415, 0.1672303327359259, 0.13679570256499574, 0.15432889689691365, 0.1601141013088636, 0.15704955090768635, 0.09434366802452132, 0.12477745214710012, 0.15392966597573832, 0.2610214421292767, 0.06734088456141762, 0.14127861591987312, 0.12201566089061089, 0.28693961387034506, 0.19100644363788888, 0.16463464155094698, 0.2616107667563483, 0.10793750538141467, 0.12954705714946613, 0.16711087664589286, 0.22548718872712925, 0.1854508597170934, 0.1747062979848124, 0.0995011861959938, 0.17139433039119467, 0.16256715171039104, 0.20445893896976486, 0.14764116669539362, 0.17618695681449026, 0.1363765524001792, 0.262519214884378, 0.17116088041802868, 0.1126713611301966, 0.15318910649511963, 0.0983953638933599, 0.2174753780127503, 0.21752841188572347, 0.18567004561191425, 0.10868822486372665, 0.08647290989756584, 0.156358270032797, 0.17268404946662486, 0.14281975978519768, 0.12806283601094037, 0.20711670338641852, 0.130957419751212, 0.06933273471076973, 0.06892950361361727, 0.16863508470123634, 0.10645188158378005, 0.20034147397382185, 0.16526564519153908, 0.15440498187672347, 0.19964191073086113, 0.11582916238694452, 0.166983628005255, 0.2276253013405949, 0.16490819718455896, 0.17856306134490296, 0.14435288845561445, 0.11726561890100129, 0.07455023325746879, 0.18257168296258897, 0.10154795527341776, 0.11241501590120606, 0.21238774788798764, 0.12021856513456441, 0.23080311832018197, 0.13964002806460485, 0.2131381185608916, 0.10307850869139656, 0.11878783800057136, 0.13561320898588747, 0.0974484947801102, 0.12614943087100983, 0.14215084724128246, 0.1530292330426164, 0.1402314455481246, 0.11047683787182905, 0.1495494955452159, 0.18164462177082896, 0.16211798909353092, 0.14581162424292415, 0.19166731130098924, 0.21079827536595985, 0.14129357761703432, 0.06616246537305415, 0.14120008185273036, 0.17505911499029025, 0.1607028767466545, 0.2003955320105888, 0.0989506981568411, 0.13872650364646688, 0.11134169224533252, 0.18189554190030321, 0.2311876992462203], [0.024868914078979287, 0.04092460927495267, 0.03544920698914211, 0.030605767569795717, 0.006516912389997742, 0.021276527841109782, 0.026589468434394803, 0.046554122236557305, 0.04659561571315862, 0.06658115540631115, 0.05761756627180148, 0.07160912427934818, 0.007848474215279566, 0.014041510112292599, 0.08469765554764308, 0.09797436578082852, 0.00864955583892879, 0.035633808802231215, 0.01758144877385348, 0.04952465737005696, 0.016822163051983807, 0.031424295229953714, 0.054419740990852006, 0.004297095811125473, 0.008183991758414777, 0.013468494180415291, 0.012676086407736875, 0.021921676816418767, 0.01670012057729764, 0.04563285350741353, 0.04827399752684869, 0.07425773801514879, 0.05589105989201926, 0.017869791699922644, 0.04466410588065628, 0.035300517702125944, 0.023163336263678502, 0.020381330759846605, 0.03297801849839743, 0.0558448389347177, 0.044838165485998616, 0.0316094091249397, 0.05050567640864756, 0.07258458092110232, 0.011130811562907184, 0.012889436238765484, 0.036843490961473435, 0.08443611528491601, 0.006448826834457577, 0.02453949513437692, 0.06540794609463774, 0.01946212891198229, 0.02129931548552122, 0.024558421755500603, 0.0250274201243883, 0.0028122085950599285, 0.03344626915350091, 0.05912876076763496, 0.02931307248218218, 0.06462989331339486, 0.025534279157000128, 0.006160156899568392, 0.029310912832443137, 0.02899912175053032, 0.01012562912364956, 0.0192906705342466, 0.041019103227881715, 0.07217842576210387, 0.02624187614856055, 0.01640545826376183, 0.013987547627039021, 0.05247103930742014, 0.02624061449751025, 0.026155536543228664, 0.02581949764135061, 0.031769590568728745, 0.08392830815864727, 0.05053311731899157, 0.06023643843946047, 0.05481905725901015, 0.021372628543758765, 0.021425712511700112, 0.042490685591474175, 0.06689675370580517, 0.014926887652109144, 0.02571514054579893, 0.07450862845871598, 0.03868972802592907, 0.039278199183172546, 0.11186029019881971, 0.04414260241901502, 0.03471098898444325, 0.04079157930391375, 0.009184115533571457, 0.06308707219432108, 0.07178495390689932, 0.058721310560940765, 0.14904231182299554, 0.03992698839283548, 0.05320340918842703, 0.03191177864209749, 0.04655682736483868, 0.06560774709214456, 0.012928370233566966, 0.013687463924725307, 0.0075910236500931205, 0.0703143363352865, 0.021233694787952118, 0.06614763726247475, 0.020591505126503762, 0.018079155270243064, 0.014855202680337243, 0.041797319281613454, 0.03708560921950266, 0.011980160616076319, 0.043629158681142144, 0.11003157153027132, 0.00980961614914122, 0.030724824755452573, 0.05594675436441321, 0.04127653570321854, 0.038371027549146675, 0.07015726820100099, 0.05420222492830362, 0.05744507630879525, 0.05000053359253798, 0.05072337058663834, 0.016012834312277846, 0.06841590031399392, 0.06678769510472193, 0.024124918454617728, 0.04824377356271725, 0.0054624151653115405, 0.03955676431360189, 0.02126655152096646, 0.039753982637193985, 0.03181992673489731, 0.02930666960310191, 0.08112422190606594, 0.017561601889610756, 0.05143669324752409, 0.021523477480513975, 0.025020887369464617, 0.03663368581328541, 0.016199326746573206, 0.02602388140076073, 0.004210189390505548, 0.04217689813231118, 0.02811516635119915, 0.052122341221547686, 0.040567866308265366, 0.03853013658954296, 0.044152844056952745, 0.05783284475910477, 0.07312404064578004, 0.005598621528406511, 0.015336782307713293, 0.049252244643867016, 0.04852583049796522, 0.051181134695070796, 0.02576483104348881, 0.02815684536471963, 0.021943559040664695, 0.02677759915968636, 0.011288465066172648, 0.03497258490824606, 0.03338499373057857, 0.07334739741054364, 0.02928392648755107, 0.04035242454847321, 0.029277495777932927, 0.00720509618986398, 0.0309041758737294, 0.026136314918403514, 0.019694962902576663, 0.02681071564438753, 0.03988159864093177, 0.013928605330875143, 0.03830863890470937, 0.02065095857687993, 0.06745560574927367, 0.008492699216731125, 0.05557038530241698, 0.06286067262408324, 0.044744844126398675, 0.06306698967819102, 0.06213088541699108, 0.059359030638006516, 0.0535975638194941, 0.02400672216026578, 0.04099574784049764, 0.04239673711708747, 0.07330184438615106, 0.05871401896001771, 0.0218801276787417, 0.10707770503358915, 0.03265936626121402, 0.029915110098954756, 0.05354068933229428, 0.13576880766777322, 0.03470632087555714, 0.045928922190796584, 0.03277466632425785, 0.018828477659553755, 0.0443212113896152, 0.027448181535874028, 0.06099478719988838, 0.06836669592303224, 0.07337608141824603, 0.04405933716043364, 0.06338071034406312, 0.026914844529528636, 0.0667577346030157, 0.0676899314566981, 0.05014910413592588, 0.06331989876343869, 0.03416803003347013, 0.01572168606799096, 0.0370060584100429, 0.022219862476049457, 0.027700866121449508, 0.03913316126272548, 0.07004513710853644, 0.06877130741486326, 0.006308719557637232, 0.04428230800840538, 0.01485114220486139, 0.0197322910753428, 0.004554721244858229, 0.009884115715976804, 0.013297867008077446, 0.02543828606576426, 0.04370184462459292, 0.0014110983715909242, 0.009146987740678014, 0.0303296979109291, 0.0514462743740296, 0.029394719858828466, 0.030885455198585987, 0.06927319962414913, 0.012671071344811935, 0.14145882421871647, 0.021906826441409066, 0.040222455936600454, 0.01344566757325083, 0.01980998280487256, 0.01854438909504097, 0.029555771470768377, 0.03853412934404332, 0.022706570343871135, 0.024285292856802698, 0.062098854323267005, 0.28844534244854003, 0.021559801898547448, 0.03250052439398132, 0.0794437546574045, 0.03667550212412607, 0.03291549626737833, 0.026109326718142256, 0.09732736885780469, 0.048329135388485156, 0.06528386642457917, 0.041971200771513395, 0.04698518387158401, 0.021022173423261847, 0.028383348835632205, 0.06846082993433811, 0.020154721532890107, 0.07979605215950869, 0.09122270697844215, 0.06807020050473511, 0.0331353166984627, 0.0690439205209259, 0.10198065705480985, 0.0683010381180793, 0.008843723007885274, 0.028501435663201846, 0.04771150153828785, 0.09234515338903293, 0.01133614341597422, 0.01882555730844615, 0.03184181266988162, 0.08086242931312881, 0.01676095627772156, 0.03485083187115379, 0.05254504256299697, 0.0393530818837462, 0.09799372099223547, 0.02553705850004917, 0.07984625844983384, 0.02523928473237902, 0.022451408840424847, 0.058437676561879925, 0.05434665428765584, 0.041298069118056446, 0.06346992391627282, 0.01798323639377486, 0.011595602882152889, 0.034494990613893606, 0.05778342885605525, 0.06421836500521749, 0.04414964911120478, 0.03514165728120133, 0.05923787502979394, 0.047313691829913296, 0.009812104199227178, 0.035207853143219836, 0.0614934584882576, 0.046511500695487484, 0.0184018967411248, 0.12507270817877725, 0.018627754543558694, 0.03056138342799386, 0.007423408669637865, 0.03714583450346254, 0.04384338702948298, 0.04376414050057065, 0.04011914526927285, 0.04844384915486444, 0.05029703643231187, 0.05402726361353416, 0.02157317354431143, 0.02703246380406199, 0.04918325830658432, 0.07428650365909562, 0.04489514387387317, 0.04412878734001424, 0.012295656870264793, 0.02134474976628553, 0.016910892372834496, 0.0663970508321654, 0.04964032850693911, 0.03496373108646367, 0.03247993721743114, 0.04197041409497615, 0.09416533735929988, 0.04482375668885652, 0.02918174574006116, 0.03969417295593303, 0.031990464849513955, 0.04356904100859538, 0.061943678665556945, 0.02148513071006164, 0.014301700593932765, 0.046633465244667605, 0.020768065769516397, 0.029155931988498196, 0.012585283711814554, 0.02313085802597925, 0.029431749317154754, 0.03166767884977162, 0.06780794778023846, 0.20920402341289446, 0.10821756222867407, 0.11387538441340439, 0.11665592974168248, 0.13599633530247957, 0.23380748054478317, 0.1333807100309059, 0.14687488437630236, 0.18457816826412454, 0.15929235087241977, 0.15049393783556297, 0.22469898336566985, 0.2190331756719388, 0.07167993258917704, 0.13495061954017729, 0.23217517125885934, 0.15955300797941163, 0.09941359050571918, 0.1107972527097445, 0.17206920980243012, 0.08380048064282164, 0.18942724243970588, 0.11430511018261313, 0.20769642462255433, 0.17539222055347636, 0.13267659000121057, 0.17522099224152043, 0.06800076516810805, 0.12528791616205126, 0.1204150116245728, 0.1984484778949991, 0.11849200309370644, 0.16402783192461357, 0.12328130469541065, 0.18715934304054826, 0.1107365227653645, 0.17038486112141982, 0.1448703880305402, 0.17117453593527898, 0.10996511962730438, 0.10589124096441083, 0.15147817408433184, 0.1595516869565472, 0.21962129801977426, 0.0889448999078013, 0.19902764994185418, 0.18676689534913749, 0.24446325172903016, 0.1307060691760853, 0.12555844383314252, 0.1883024285780266, 0.15937458083499223, 0.081207513139816, 0.17786195443477482, 0.05331583342922386, 0.11559767910512164, 0.12701453757472336, 0.13092242006678134, 0.14823987206909806, 0.17316033015958965, 0.1313058432424441, 0.11274877455434762, 0.1467552056419663, 0.14294755761511624, 0.0747566987411119, 0.19695760711329058, 0.19157915899995714, 0.13776742620393634, 0.11615719908149913, 0.05904029305384029, 0.105619555542944, 0.1281525319791399, 0.13541137450374663, 0.11121796880615875, 0.1913858889020048, 0.18101577035849914, 0.521786279277876, 0.13922574638854712, 0.16778866527602077, 0.1521555767976679, 0.10772276495117694, 0.2075161866378039, 0.09789370917133056, 0.243827038211748, 0.13817121391184628, 0.1736277644522488, 0.16015278204577044, 0.13368687563342974, 0.15813385834917426, 0.19031499949051067, 0.1465217408258468, 0.07657060414203443, 0.17513689206680283, 0.1415653817821294, 0.19083959399722517, 0.10703233012463897, 0.20447474671527743, 0.2425491638132371, 0.22749688010662794, 0.108334034885047, 0.10846742850844748, 0.1724514752277173, 0.11393824432161637, 0.20907963946228847, 0.17332735791569576, 0.1220498738985043, 0.2323326253099367, 0.18438123195664957, 0.12751470057992265, 0.08587033793446608, 0.2373007548158057, 0.1468811629456468, 0.12140416089096107, 0.20992751349695027, 0.12350454271654598, 0.11263248001341708, 0.3084335464518517, 0.1695203481358476, 0.15423848846694455, 0.11281810599029996, 0.16686494374880567, 0.06645664529060014, 0.2043964501353912, 0.17085236962884665, 0.22162800596561283, 0.24994530365802348, 0.18181145656853914, 0.14799785771174356, 0.20622881274903193, 0.10298905763193034, 0.14668848656583577, 0.1883682273910381, 0.0764660355343949, 0.1430523191811517, 0.20146247319644317, 0.1541647338308394, 0.09757568404893391, 0.09936339905834757, 0.12772840942488983, 0.07399279871606268, 0.16024433338316157, 0.116823707066942, 0.0900554125837516, 0.09186602284898981, 0.08348025876330212, 0.0742983483360149, 0.17461919953348115, 0.11177690990734845, 0.14841041760519147, 0.15394479094538838, 0.13812598743243143, 0.11452302700490691, 0.13101885473588482, 0.14196424162946641, 0.1417428589775227, 0.11164792464114726, 0.14315709559014067, 0.10423708285088651, 0.08607481446233578, 0.232561711454764, 0.08640087704407051, 0.1007280230987817, 0.17198497604113072, 0.08139281257172115, 0.11356632443494163, 0.12190674329758622, 0.14327119337394834, 0.07609079824760556, 0.1251058079651557, 0.09850139453192241, 0.1887656474718824, 0.0799727946287021, 0.07920817472040653, 0.10727832239354029, 0.11231571654207073, 0.09877785938442685], [0.039586194179719314, 0.032942447360255755, 0.021898015293118078, 0.03475277560937684, 0.13362964120460674, 0.0739203576813452, 0.013291271170601249, 0.017059802448784467, 0.10470324064954184, 0.029195820570748765, 0.04486927260586526, 0.014317733766802121, 0.038287127754301764, 0.041069643484661356, 0.06556494743563235, 0.0883414744748734, 0.021593879464489873, 0.02700135111808777, 0.0422572987008607, 0.017391577712260187, 0.02917755631642649, 0.07877084935898893, 0.04059253158629872, 0.03478772705420852, 0.007190426713350462, 0.002586600339782308, 0.085391110915225, 0.009664260032877792, 0.026042982426588424, 0.015291484396584565, 0.06640171151957475, 0.014024846113898093, 0.00996592729279655, 0.022063482683734037, 0.030145172167976853, 0.0481730505998712, 0.0738061114680022, 0.03535280942742247, 0.023596839564561378, 0.03900365649315063, 0.024650735649629496, 0.05145948460267391, 0.04590969685523305, 0.045893005953985266, 0.06412340720999055, 0.04514724401815329, 0.06979397949180566, 0.0513545597641496, 0.027409469257690944, 0.020551852176140528, 0.06434398092096671, 0.03426701769058127, 0.012201596146041993, 0.020935267930326518, 0.02970343473862158, 0.10922791465418413, 0.034652470640139654, 0.06638624516199343, 0.02756709585810313, 0.04443245932634454, 0.04361900610092562, 0.03074265485338401, 0.10664144836482592, 0.04189005063381046, 0.057486094810883515, 0.035435670215520076, 0.06200146228366066, 0.01508959147031419, 0.03791974610066973, 0.004855489578403649, 0.03381748028914444, 0.046830275387037545, 0.02753888868028298, 0.021179286086407956, 0.04184844954579603, 0.10151736394618638, 0.07290792724234052, 0.04194423483568244, 0.02365759548411006, 0.013886960641684709, 0.01746836587699363, 0.004241348924551858, 0.019019009232579265, 0.03774516699195374, 0.011524950423336122, 0.13421469106106088, 0.032370689368690364, 0.012091841781511903, 0.07129574500140734, 0.03555769413651433, 0.029405197128653526, 0.06558836219483055, 0.019355443328095134, 0.07813557836925611, 0.01817742861021543, 0.046260161252575926, 0.0483578082639724, 0.013670695097971475, 0.02442808949126629, 0.07222276166430674, 0.03596754890168086, 0.04599876941938419, 0.035013291708310135, 0.050593735941220075, 0.021216990899119992, 0.09409855891135521, 0.06438365613576025, 0.07591551780933514, 0.0266773108887719, 0.05175550875719637, 0.044868645491078496, 0.03404860362934414, 0.03677419663290493, 0.0199399105986231, 0.04772585838509258, 0.026705367781687528, 0.032464597024954855, 0.03850925997539889, 0.02334313452593051, 0.05682697861630004, 0.014437060908676358, 0.025964110682252795, 0.10515806585317478, 0.03685306837724056, 0.030014201656740624, 0.034238908847328275, 0.02304467427165946, 0.02536611405957956, 0.05094778862257954, 0.0436239228292834, 0.026218494786007795, 0.03739542618859559, 0.06258475696085952, 0.04600625026796479, 0.07934684501378797, 0.014939225857233396, 0.004137113819524529, 0.022301875360426493, 0.01434451138266013, 0.017084577193600126, 0.003274855107520125, 0.12402406093315221, 0.03516736156598199, 0.012667487699218327, 0.02740059317147825, 0.059366856585256755, 0.0889981044747401, 0.043501858090166934, 0.03871551394695416, 0.04213600208458956, 0.03608705694205128, 0.06600680731935427, 0.030602910301240627, 0.03029376868653344, 0.056429213436786085, 0.05834093019075226, 0.04460134616238065, 0.07048464438412338, 0.013312189530552132, 0.021837582207808737, 0.0184251352402498, 0.006448139420172083, 0.07188621995737776, 0.0314718817389803, 0.027193500573048368, 0.030827354312350508, 0.0574941990635125, 0.0734568048210349, 0.033885820957948454, 0.028005363747070078, 0.025213665794581175, 0.06046691611118149, 0.07583664235426113, 0.04802174895303324, 0.061513040054705925, 0.04016139202576596, 0.043413794846856035, 0.03884226163791027, 0.05242202787485439, 0.016082620313682128, 0.034307234673178755, 0.030942255471018143, 0.008365786397916963, 0.06381636587320827, 0.09004694467876107, 0.027532131425687112, 0.033285044992226176, 0.019340054896019865, 0.05140590154042002, 0.07914130721474066, 0.06573669525096193, 0.03788922156672925, 0.04154358641244471, 0.0047390864983754, 0.06200564428581856, 0.0415147280000383, 0.032433727392344736, 0.019895630357495975, 0.04492218773521017, 0.03749717463506386, 0.009598555843695067, 0.04168518447841052, 0.01980368011572864, 0.048308017576346174, 0.042516779503785074, 0.02186325680668233, 0.03874407550028991, 0.005510696973942686, 0.013068833741272101, 0.0035198719160689507, 0.03574405855033547, 0.017433304965379648, 0.026310953398933634, 0.024548436158511322, 0.09100303126615472, 0.04292436329706106, 0.0566405919380486, 0.03552384107024409, 0.022303129590000026, 0.03771228984987829, 0.028998986308579333, 0.03297392184322234, 0.04442247001861688, 0.06116182979894802, 0.026316439725633245, 0.0298413127893582, 0.02012779270444298, 0.02873087618354475, 0.04270824618288316, 0.07336356880841777, 0.03766429144889116, 0.04819328154553659, 0.037872063112445176, 0.021125140847289003, 0.10247350990539417, 0.028632328248932026, 0.058126601652475074, 0.08691904455190524, 0.02362716186325997, 0.025624310947023332, 0.05288799642585218, 0.03503404957882594, 0.04358870421128813, 0.05787332891486585, 0.027747602871386334, 0.016705519701645244, 0.081070163869299, 0.08393840136704966, 0.020552946843963582, 0.03915819390385877, 0.12078929896233603, 0.1597095120814629, 0.059554645922617055, 0.039895662339404225, 0.05539851132198237, 0.00497815777634969, 0.022470396688731853, 0.03728377378138248, 0.0310065143276006, 0.017384278689860366, 0.030926568324503023, 0.06899232641444542, 0.045062012068228796, 0.011650002306851093, 0.04809948892216198, 0.06797261550673284, 0.07047850682283752, 0.037473463016794994, 0.015700534859206527, 0.08977534831501544, 0.03750107833184302, 0.03252131566114258, 0.08921205822844058, 0.03693319064041134, 0.050364991184324026, 0.020469852279347833, 0.0775792050990276, 0.0889214406197425, 0.07205122165032662, 0.038158498718985356, 0.0629883146029897, 0.07647859267308377, 0.05836394047946669, 0.06578941742191091, 0.0338953278696863, 0.08510695741279051, 0.1269177466747351, 0.04003523805295117, 0.043101551054860465, 0.019164117657055613, 0.01937298398843268, 0.030575068631151225, 0.02845537612301996, 0.0321982068271609, 0.05314495021593757, 0.049955522335949354, 0.005084394360892475, 0.04727311490569264, 0.03669997815450188, 0.03718779553310014, 0.020289217245590407, 0.05727206313167699, 0.08288260723929852, 0.06527125733555295, 0.02644091087859124, 0.04330049116106238, 0.04304819434764795, 0.049576010278542526, 0.054806540938443504, 0.05703368900867645, 0.05332796754373703, 0.027201116863579955, 0.0799865392036736, 0.03153471196128521, 0.030665645899716765, 0.00427377382038685, 0.04484019897063263, 0.08436193762463517, 0.07381866860669106, 0.04813557956367731, 0.06457401701482013, 0.029613735059683677, 0.0031818630759516964, 0.04624002307537012, 0.017611889816180337, 0.0353058389009675, 0.00808741608125274, 0.051882048646803014, 0.0633877755899448, 0.02845692721166415, 0.021912784031883348, 0.0241476541486918, 0.03775498189497739, 0.021039151906734332, 0.058067192730959505, 0.037863465331611224, 0.10916693980107084, 0.022418674561777152, 0.014322640290629352, 0.051909407920902595, 0.02941372626082739, 0.023700690144323744, 0.014902050752425566, 0.03858193478663452, 0.006268158404054702, 0.04538829358352814, 0.037625655240844935, 0.06077927493606694, 0.08215498339268379, 0.05132027254148852, 0.0766732134798076, 0.018638871915754862, 0.1350322409416549, 0.10710537229897454, 0.11337631236528978, 0.11969313200097531, 0.260070632211864, 0.15879668528214097, 0.08278601671918295, 0.25586701871361583, 0.16134047065861523, 0.12399704675772227, 0.13475044746883214, 0.07770332187647, 0.1955023594200611, 0.17078729812055826, 0.11885624175192788, 0.10123341082362458, 0.10655472840880975, 0.08442670485237613, 0.16971431585261598, 0.1583947381004691, 0.10336844352423213, 0.25708274566568434, 0.17172247840790078, 0.184799209528137, 0.16702858731150627, 0.10802122706081718, 0.2290328437811695, 0.2234994649188593, 0.17404301092028618, 0.08399430735153146, 0.11010868809535168, 0.05305418555508368, 0.0919667916605249, 0.08270531558082439, 0.14019797468790784, 0.12461514445021749, 0.1859555349801667, 0.11831225492642261, 0.1921242367825471, 0.09465925890253857, 0.1827877518371679, 0.08668761322041973, 0.12148218287620693, 0.18351560574956238, 0.10795297173899598, 0.12008635894744657, 0.2752635529031977, 0.11125402234029025, 0.08927751565352082, 0.06896635124576278, 0.11257065169047564, 0.07411198021145537, 0.1196749864902813, 0.10424894237075932, 0.21031918935477734, 0.2406992865144275, 0.149540530401282, 0.13534256257116795, 0.2114904616610147, 0.1336310215992853, 0.16743933636462316, 0.19464612880256027, 0.12690478877630085, 0.08997988421469927, 0.12246412588865496, 0.13151015649782494, 0.135830910585355, 0.1898003349197097, 0.17601244820980355, 0.10324797811335884, 0.14062427915632725, 0.22827804990811273, 0.1366194276488386, 0.08969619826530106, 0.2297202209592797, 0.30122010852210224, 0.15277421625796705, 0.20100811554584652, 0.10877216176595539, 0.07283800950972363, 0.1370701933046803, 0.17377395270159468, 0.11490115866763517, 0.1295666943769902, 0.08835569402435794, 0.23986901622265577, 0.13582749670604244, 0.08309987839311361, 0.13833346223691478, 0.1436786472913809, 0.14563591335900128, 0.16397041938034818, 0.0936141368583776, 0.16628396086161956, 0.17424989200662822, 0.23396647826302797, 0.22773625241825357, 0.20155976875685155, 0.18611876294016838, 0.14746330358320847, 0.14257532602641732, 0.20150526543147862, 0.15508811397012323, 0.20590468717273325, 0.1470865003648214, 0.17922633356647566, 0.15594698663335294, 0.2187537422287278, 0.1462999574141577, 0.1648876693798229, 0.233317959937267, 0.10278853675117716, 0.19225406809709966, 0.17830699071055278, 0.09891170571791008, 0.08910862510674633, 0.1216766404104419, 0.21663730032742023, 0.11817120233899914, 0.18753233161987737, 0.08501533928210847, 0.0877413219131995, 0.16318219917593524, 0.14429886010475457, 0.10255136861815117, 0.10474670081748627, 0.196818083350081, 0.11506602677400224, 0.16179738129721954, 0.10820081937708892, 0.14593330677598715, 0.10517405913560651, 0.18087097734678537, 0.18719260609941557, 0.175443428743165, 0.11720108916051686, 0.22949428152060136, 0.17215883155586198, 0.0760000484297052, 0.13827003829646856, 0.11119468021206558, 0.29061012784950435, 0.20447958551812917, 0.2445166715187952, 0.1450291185756214, 0.19498165376717225, 0.1805886346846819, 0.09901318699121475, 0.11862306637340225, 0.08524953882442787, 0.08887884134310298, 0.2136678042006679, 0.24032721819821745, 0.1150080501975026, 0.12714885146124288, 0.1321141904918477, 0.1574527597404085, 0.24245347129181027, 0.10490990651305765, 0.06853006489109248, 0.18193828960647807, 0.1001205678039696, 0.1614378998056054, 0.09333840673207305, 0.20013275236124173, 0.17630121787078679, 0.13258196617243811, 0.1696693862322718, 0.08683521155035123, 0.11486356146633625, 0.14139455422991887, 0.17705103935441002, 0.2894348924746737, 0.11760827590478584, 0.15093014255398884, 0.12354995473288], [0.03255338757298887, 0.07981952629052103, 0.04003367583209183, 0.029633496596943587, 0.06763680110452697, 0.08038732121349312, 0.053025586894364096, 0.038514154439326376, 0.031132608928601258, 0.023070844254107215, 0.007121376365830656, 0.026264546904712915, 0.040085162327159196, 0.07058012910420075, 0.043119911788380705, 0.005231892964729923, 0.021899421662965324, 0.02490663930075243, 0.04150906541326549, 0.05478524872160051, 0.05348149934434332, 0.05513113035704009, 0.025950590606953483, 0.05013149668229744, 0.01146969845649437, 0.036903968575643376, 0.041167232193402015, 0.0956593919545412, 0.08033301084651612, 0.05922828277107328, 0.03216619057639036, 0.03272998903412372, 0.033841318072518334, 0.0782697883551009, 0.023064129673002753, 0.017231782185263, 0.05289337699650787, 0.04812262537598144, 0.013708042752114125, 0.0287578885036055, 0.013328738496056758, 0.009910330227285158, 0.053564178306260146, 0.02429953652608674, 0.10275645370711572, 0.07038407595246099, 0.06101936713093892, 0.0726768076128792, 0.10485685779713094, 0.024363081065530423, 0.072477177309338, 0.07735736231552437, 0.06905484493472613, 0.01597712773218518, 0.04601143788022455, 0.09208593604853377, 0.06424044389859773, 0.032295661949319765, 0.05348525461158715, 0.013312940955074737, 0.02165363162930589, 0.03648126723419409, 0.026707095130404923, 0.05459573760163039, 0.017089258290070575, 0.10801379074109718, 0.011180251585756196, 0.0726741507241968, 0.10685941713745706, 0.07135669016861357, 0.029731367321801372, 0.017448990256525576, 0.04348625814600382, 0.05887775158043951, 0.11213602032512426, 0.07487533104722388, 0.02698142074223142, 0.05336374648322817, 0.06767121449229307, 0.011806412712758174, 0.019626291978056543, 0.010969048416882288, 0.025862872462312225, 0.0704119807051029, 0.023283803529920988, 0.06923665627255104, 0.02381256148510147, 0.0038069223455750034, 0.04057796693814453, 0.06029936143022496, 0.041601485063438304, 0.030747501077712514, 0.05313735433446709, 0.09190385753754526, 0.081149261968676, 0.0589692695211852, 0.08515253270161338, 0.06591061013750732, 0.058067641730303876, 0.1255689378012903, 0.01196306988276774, 0.03235857751860749, 0.08372248092200607, 0.09836423821980134, 0.04047758033266291, 0.031664391135564074, 0.03939828609873075, 0.029438714373100083, 0.012947027826157864, 0.013307206936588045, 0.022494735421787482, 0.0226690863200929, 0.0329141307156533, 0.04930085160594899, 0.04909896517347079, 0.0346742378314957, 0.04001774563221261, 0.07478815838112496, 0.14890617225319147, 0.03400417495868169, 0.012514005065895617, 0.05079782655229792, 0.06786489277146757, 0.010647848757798783, 0.022716774874425028, 0.04104481864487752, 0.013232888268248644, 0.019775281834881753, 0.10419449841720052, 0.04010235417808872, 0.04645908280508593, 0.041370925755472854, 0.050253030785825104, 0.028710476399282925, 0.05602873941825237, 0.05365490957046859, 0.055606078894925304, 0.02170872310671257, 0.046929700911277905, 0.04747850056446623, 0.010462506652402226, 0.029841975156159606, 0.05279179182252847, 0.03940656846680213, 0.04537359534879215, 0.023450591943401378, 0.04392422917590011, 0.026570098380034324, 0.02198870944994269, 0.01910652885271702, 0.03624756864155643, 0.045993244129931554, 0.05990788224153221, 0.03815768977801781, 0.05750508265919052, 0.028211879325681366, 0.014846935155219398, 0.03095556217886042, 0.031047504999150988, 0.039988913194974884, 0.0650115947064478, 0.027130058078910224, 0.04513455700362101, 0.05159729400475044, 0.04823240014957264, 0.010035079685621895, 0.010579201025393559, 0.09612714537070133, 0.06967433044337668, 0.023289352939173114, 0.008085549579845974, 0.036255691447877325, 0.010736165259004338, 0.04585238450090401, 0.03465400317509193, 0.0473215697275009, 0.031771531284903176, 0.052296141075203195, 0.050105647678719833, 0.007626808619534131, 0.09316101117292419, 0.06100676917412784, 0.010396009292890085, 0.07061066848109476, 0.052871212756144814, 0.05988771066768095, 0.04380440201202873, 0.0492273715644842, 0.06254767184145749, 0.07291232817806304, 0.04741841257782653, 0.02340029473998584, 0.02931648079538718, 0.06432163485442288, 0.04072063369676471, 0.036351858943817206, 0.08135338968713768, 0.05316078393661883, 0.02105841806042008, 0.03451622716966085, 0.03275895134720486, 0.03641270763182547, 0.011449780140537769, 0.03798495490627829, 0.019682780548464507, 0.021684265630028676, 0.02444527948682662, 0.06680010381387547, 0.04550311125058215, 0.07878020041971467, 0.09737953441799618, 0.024620676813356113, 0.05289293541864026, 0.024837511955411173, 0.07398716581519693, 0.06037135717633646, 0.028913767346239183, 0.049356753879692405, 0.045904653961770236, 0.06811659957747906, 0.10067440292914398, 0.0827956794819329, 0.024996064385049976, 0.012749863308272325, 0.05158974636287894, 0.0534611422335729, 0.019463761636870913, 0.04901746993709821, 0.06340710111544468, 0.03692923499329481, 0.015108036623132648, 0.04635667384718545, 0.05763690664025489, 0.024148900956788566, 0.007451366300301743, 0.059165845887036994, 0.033815784481703304, 0.04100844969798345, 0.04639443432097323, 0.060482059634523466, 0.05793572869151831, 0.023899947518657427, 0.13656446419190615, 0.09697625137050636, 0.07329768835916184, 0.07223212756798603, 0.06455873619415797, 0.014213841441232944, 0.00260165619692998, 0.03246203290473204, 0.011948674073209986, 0.0982253452821169, 0.11984240016317926, 0.026999473484465852, 0.010665846766642062, 0.03421351626457181, 0.07841557584470138, 0.03548142733052373, 0.016479762089147698, 0.06186337828694377, 0.05864020495209843, 0.03229595509765204, 0.03558549127774313, 0.03738770785275847, 0.05574368420639075, 0.07461323417373933, 0.05520170117961243, 0.051249048628960736, 0.06092126262956299, 0.07310368353500962, 0.030451714410446584, 0.07632036678842269, 0.054869096566108055, 0.05861760655534454, 0.046066757568041794, 0.07005006496910937, 0.032284232875099406, 0.0708857603603974, 0.024161751243809704, 0.014237272898753872, 0.005187844644751749, 0.03783873326028697, 0.027136976750625763, 0.02717575025599217, 0.07293256654520519, 0.03213475691154599, 0.03583519428502768, 0.034370981447864324, 0.09539730250253342, 0.005773504917669925, 0.04601920074492227, 0.0142280155341723, 0.030347377723956015, 0.05545995001739357, 0.06744451806298457, 0.07505768415285274, 0.02777475991024403, 0.05743618909036741, 0.019159805779054295, 0.03333442749863025, 0.03475480909401085, 0.018888196427724324, 0.014069483513594605, 0.05704214949219022, 0.02086951364617562, 0.04955313357640989, 0.031884831259958446, 0.037237396973068826, 0.035679005595739, 0.019688849461090285, 0.006954536465855199, 0.03485428656858858, 0.05575725808739662, 0.009396848454343854, 0.02810171863529831, 0.051989348357892595, 0.01873178694950184, 0.024135195344570093, 0.019192335967090912, 0.016536887051188387, 0.027875660452991724, 0.06560278954566456, 0.02109799679601565, 0.028676107540377416, 0.05158479994861409, 0.03287616615125444, 0.022484465953311883, 0.08408922061789781, 0.037154484234633856, 0.0207630191653152, 0.023882349341874942, 0.020091958103876095, 0.02733369226916693, 0.05029569314501714, 0.012775575942214346, 0.03297152841696516, 0.061653617667616345, 0.019271200289949775, 0.00952341710217297, 0.054428943622042425, 0.04333120123192202, 0.024671033388585784, 0.07481481632567011, 0.08828619931591675, 0.014210888621164486, 0.05863194484845735, 0.014918782471795566, 0.06474290756159462, 0.030905498751963023, 0.010980356892105192, 0.011158202378283022, 0.0354284713830566, 0.08831369588733651, 0.14453233976382762, 0.11451402475358918, 0.13827656919602305, 0.21585713984677568, 0.20567753061186522, 0.08308374410262331, 0.14420969848288223, 0.1476998408907093, 0.12543834949610755, 0.08066036476520821, 0.09428178032976575, 0.12659921689191833, 0.12961552769411355, 0.20098107168450952, 0.06266520576900803, 0.1183435067650862, 0.19363260740647092, 0.15524292597547174, 0.1266436418518424, 0.22247141227126122, 0.15091688779648393, 0.10178473006817512, 0.09916567607433535, 0.09558598612784408, 0.15999077120795846, 0.13065842329524457, 0.2630364027572796, 0.21656149736372754, 0.1903760782442987, 0.13942848629085347, 0.17458804417401552, 0.1346578571246937, 0.21823030547238886, 0.2859546057879925, 0.09588810702553019, 0.16934171319007874, 0.12709388800431043, 0.13097497896524146, 0.14016481552971527, 0.15474383166292682, 0.16134597739437595, 0.16079055407317355, 0.17094687471399084, 0.19061740982579067, 0.2120359253603965, 0.13627217675093561, 0.11242624459555373, 0.18718467996222898, 0.10359497668105178, 0.17263960966374725, 0.2067999102291651, 0.1446605086675845, 0.20052422041771933, 0.148160298995208, 0.24083061696728691, 0.20998154184781015, 0.11940693017095327, 0.10333267942769453, 0.22189540177350864, 0.09119530688622035, 0.11965590587351471, 0.23550092795630917, 0.10667045149602927, 0.22000662109348923, 0.17049027577741072, 0.21610967785818502, 0.18045435048406944, 0.17054846015525982, 0.11704171294695698, 0.10983206739183515, 0.11996662084129639, 0.1640660673729144, 0.1630209750146605, 0.24345689947949722, 0.23058930557454005, 0.10958002661936916, 0.12694517645286396, 0.17629033798584715, 0.1082956806931179, 0.12346460775006562, 0.14930705074220896, 0.12374026366160251, 0.2723962801974267, 0.1759192641475238, 0.197417723829858, 0.10012106504291296, 0.10382050793850794, 0.15033839852549136, 0.1919827240635641, 0.14406667178263888, 0.07571170921437442, 0.13363108097109944, 0.24316749157151207, 0.3250072180526331, 0.1747860194882378, 0.17735762055963278, 0.2568926371168345, 0.20812985370866954, 0.22243929211981595, 0.15472811297513545, 0.19931698363507167, 0.16830511100124568, 0.16396663442719728, 0.13094594614813104, 0.13226593000581488, 0.16751000366639346, 0.13728574267588556, 0.15279225044650957, 0.15081792982527986, 0.13409343897365034, 0.17126843245932832, 0.16344365780241787, 0.11816457496024668, 0.16641405934933573, 0.09114582790061831, 0.12855036766268313, 0.15154815861023962, 0.15804537950316444, 0.23342784232227132, 0.13580297614680603, 0.12094079356756993, 0.1989404030609876, 0.08603814494563267, 0.09085852769203484, 0.07933873333968222, 0.12233573434059508, 0.2284482095274143, 0.17984678386710584, 0.193900344602298, 0.15457784291356802, 0.1256157673196867, 0.18840558710508049, 0.10293393832398579, 0.12019494257401675, 0.15630038251401857, 0.1274411685881205, 0.08810307437670417, 0.2364041662076488, 0.16460537124658003, 0.07278665289049968, 0.10755255338153802, 0.1503107015741989, 0.12443944840924814, 0.12992010510060936, 0.1106608311238233, 0.1840682385955006, 0.12493336253101006, 0.07826687913620844, 0.0957463493978139, 0.12005213109659962, 0.10728852692409419, 0.21927334950305521, 0.22212165291421115, 0.15104885649634525, 0.15266605565557256, 0.09861541810096242, 0.15513715508859605, 0.1334435847820714, 0.12205410414026119, 0.14233169378712773, 0.0761104651610367, 0.17537702136905864, 0.09631632623495534, 0.23043535446049646, 0.08401414495892823, 0.1407299906713888, 0.2499481535051018, 0.19695875002071261, 0.17949367000255734, 0.11135460561490618, 0.14608703524572775, 0.22367357276380062, 0.08687622263096273, 0.1348869877983816, 0.12029320292640477], [0.03804977037361823, 0.005800007475045277, 0.03352174928295426, 0.0930046258145012, 0.06817748537287116, 0.029670514923054725, 0.05177910534257535, 0.021565789174928796, 0.02360543549002614, 0.0208469876088202, 0.00880388173754909, 0.08665772693348117, 0.03648733800218906, 0.018986356590176, 0.03329245162603911, 0.027429633410065435, 0.02668533536052564, 0.03209576076187659, 0.008129717571137007, 0.02254325147077907, 0.10494935908354819, 0.026974554020853247, 0.016382835747208446, 0.009916208964568796, 0.05464245950861368, 0.04255628402461298, 0.02203851683589164, 0.01764823649864411, 0.00737054549063032, 0.02677438566024648, 0.026015259500127286, 0.006749675876562833, 0.00493553391606838, 0.03661095011921134, 0.013956929396954365, 0.08124889529426582, 0.019296732025395613, 0.023064363449520897, 0.04674175943364389, 0.02104818198858993, 0.06772257111151703, 0.034147320402553305, 0.07014477043412626, 0.029825896526745055, 0.10298920606146567, 0.07721532267169096, 0.027118168873130344, 0.05106225376948714, 0.04137009455007501, 0.02033940312685445, 0.058103261108044535, 0.039484301014454104, 0.03497973921184894, 0.04526854805590119, 0.03819981779088266, 0.008016482534003444, 0.04598136976710521, 0.00640413516521221, 0.014126216065051267, 0.036509305573417805, 0.024929981700552162, 0.0621022422274109, 0.04808971854799893, 0.04023509471153375, 0.07787014925270341, 0.07073206899804063, 0.042387334106024355, 0.04370565184217412, 0.04483540840737987, 0.062265870947157964, 0.05622305965516716, 0.06320771572063677, 0.020075833090231754, 0.06320620173937641, 0.14709800365380943, 0.1506738195894286, 0.02984712195029715, 0.07463160232873634, 0.05911410706175957, 0.03284336693468504, 0.020360457856440917, 0.04217849374981597, 0.07192844816017896, 0.01035397312080022, 0.028583040366356727, 0.041277066338807344, 0.048933733414742164, 0.07827675712178461, 0.022823293475084938, 0.009789105970412493, 0.01178458707727259, 0.08805933219264261, 0.0380391316866735, 0.09938368195435032, 0.04583800538966898, 0.02582888580946019, 0.11281211685854942, 0.04855240309552755, 0.021717242962040473, 0.04574653197778389, 0.04729292653792072, 0.061810285042156465, 0.05815649907162879, 0.029222100019978825, 0.030717778063262813, 0.028800270702049602, 0.046612039441242814, 0.055013770834193565, 0.09656490117777139, 0.04072401789017022, 0.03852699730487075, 0.07266194239491597, 0.07871500274632126, 0.006219372398845735, 0.03553513284714427, 0.01612081308849156, 0.06419418583391234, 0.0038383393120966502, 0.0340259273070842, 0.028659774725383613, 0.062291979702422395, 0.01992329391214298, 0.008055525067902636, 0.03260400575527456, 0.0376698390027741, 0.05794906508526765, 0.04034403456898872, 0.015738445617898833, 0.017665869927441236, 0.03168809904309455, 0.041344683413626626, 0.09276474884245545, 0.03644476841145661, 0.08916222301195376, 0.051431305255391635, 0.022219446873350535, 0.04160706601396669, 0.055735490896040574, 0.013105560774420155, 0.023015383558231406, 0.01783728748705471, 0.02527145126805408, 0.04426227002113592, 0.03087883895204868, 0.07338268653256819, 0.04585297450830694, 0.02066643792204559, 0.03796907294599805, 0.0593923642009031, 0.03296633709396701, 0.016678015708748717, 0.037215407137409784, 0.025856397223833483, 0.04268351782229729, 0.02383735107287066, 0.0139836791822745, 0.02618405171233462, 0.012662558910960797, 0.035121749169775285, 0.08212199492845684, 0.04058967431774363, 0.02977824322442757, 0.009436951331736054, 0.03415913539356552, 0.07373876156634651, 0.016371033743780572, 0.02499227015505312, 0.04174186600721441, 0.028812130221922416, 0.022598090617975686, 0.05693233761121519, 0.09778646141057834, 0.06714622664730996, 0.01280745396798011, 0.08970954950200394, 0.04786871810210869, 0.0318734652682906, 0.02102850950905122, 0.032449126956635155, 0.04352883144747466, 0.00632881135061325, 0.05528842855710536, 0.06629482741118409, 0.0010314479732187465, 0.0461043139512185, 0.016246811210294254, 0.0614755319111282, 0.0341134821792366, 0.04034431287436746, 0.0837352235976141, 0.04457347480638418, 0.011214262358407723, 0.033675459199002944, 0.012396207675919868, 0.016496195094077848, 0.03768394723010715, 0.08963522341218777, 0.03715585720783565, 0.04574247242999263, 0.018335177664994262, 0.01846978655521525, 0.03606652913731523, 0.05015886708861217, 0.005385999465943314, 0.047957619972294196, 0.04467413971724454, 0.023784406257618684, 0.04167048624367453, 0.057974249866674654, 0.031319466870627366, 0.035195767268305644, 0.02028403334406903, 0.011751970614568563, 0.043919186282437295, 0.019117738993372768, 0.03097288205026416, 0.026724622803158127, 0.0264774375318666, 0.015551791766483802, 0.07093243402778171, 0.021888669798499905, 0.07025957325822674, 0.03876193157339003, 0.06158494303235784, 0.039826509018894285, 0.017245738272322342, 0.023098361234588083, 0.016145367044373415, 0.032006703040678985, 0.01873632147180615, 0.07264683226821944, 0.031395629775943235, 0.07334268477279693, 0.0653003049956169, 0.03193790224031545, 0.01183704856885015, 0.07883595055318438, 0.032731028040871024, 0.017040315506164916, 0.045347045015660115, 0.04981443264114205, 0.014074024529691087, 0.05451247234304901, 0.03618911709054373, 0.04935883931466378, 0.004035894153275876, 0.05872834241017699, 0.0210769383556908, 0.03947121324017644, 0.1111233004485257, 0.05231979703239631, 0.15892872819676995, 0.1106089995300863, 0.023195504654722754, 0.04264429531758651, 0.0346073109540157, 0.01929192105308175, 0.07141370195313357, 0.0922137412999291, 0.04202025302220136, 0.025832498213276267, 0.03434063131862786, 0.030270019960880745, 0.04122729420487303, 0.05653733322105836, 0.06320561544271186, 0.05434310682176147, 0.093554601771757, 0.03201078114216216, 0.18464825669070706, 0.0696919193433132, 0.08461998237180524, 0.10644588503055274, 0.09109095350140706, 0.047696109395474195, 0.026689791957323905, 0.06856263033114374, 0.02976622970891185, 0.04864507878664881, 0.06277188949752599, 0.013900605026719859, 0.015099021384230582, 0.08218280650908127, 0.029303020091902, 0.05204260116443038, 0.010652552118699532, 0.03379406552994624, 0.06177090297569521, 0.014453962394327391, 0.02584487352578435, 0.16832390218041837, 0.002883013194150408, 0.011280015714874025, 0.020698303887911607, 0.06310797849437222, 0.027747970234486274, 0.05419793902547099, 0.05117165746924002, 0.07188299903646111, 0.035989464522572234, 0.07022438803687692, 0.04565790841297712, 0.06313549733022228, 0.03418342588702217, 0.025254702850361355, 0.046067136063356884, 0.010358503004681552, 0.025033242272911593, 0.037771398201584816, 0.018945436422654893, 0.09749856006237678, 0.03329144972667564, 0.05418753040430602, 0.006167483288663789, 0.04362671330454759, 0.03465057074208744, 0.049298343146801926, 0.0914899617782794, 0.00875132098371978, 0.030620410143455956, 0.037210954251349904, 0.07874030998209491, 0.026286466236342676, 0.045765716495225206, 0.024458838524878956, 0.025342331937281415, 0.021213137297309004, 0.06302142181084491, 0.036061441714991815, 0.07843231127480976, 0.050314072432229295, 0.04086969776835758, 0.08818270682240836, 0.028395132285368163, 0.05925982775806915, 0.07055618742015213, 0.07102388146449812, 0.01463943715862115, 0.030390272004297003, 0.046741072947042994, 0.06031109849573113, 0.010631856403051643, 0.030032783179194666, 0.08267315832199529, 0.036674670918728225, 0.04259351015207358, 0.018186017114203423, 0.015608465873810928, 0.0777741672936827, 0.022371045379259158, 0.0720248679863289, 0.0115747299787472, 0.13482730428222567, 0.1034193325904198, 0.17408368061296642, 0.1642656754120253, 0.13078605785267428, 0.16760395956225693, 0.19490089325699955, 0.16758387704612687, 0.09101048985030502, 0.19342387095093727, 0.1672937863622792, 0.20844658749410883, 0.16636791260680184, 0.13866398512618616, 0.11922040619538166, 0.18731175048742443, 0.1480433068354614, 0.09375543435453437, 0.08725686275283806, 0.10398841885034926, 0.2200340508716181, 0.15158468711888418, 0.17862918670289218, 0.10727486398536712, 0.1966074321535416, 0.10599383545923047, 0.10608516415231861, 0.12500175886088982, 0.15287148213246837, 0.117712792562088, 0.15502280497457832, 0.06941981831914745, 0.13019646605243906, 0.2368369570467621, 0.10455610987264663, 0.06202183794812299, 0.14117660030024126, 0.12974121782463044, 0.10368087285314687, 0.1463469205191359, 0.1738949673017487, 0.14902049268130213, 0.2999891230138019, 0.15388182713650167, 0.2548961411230266, 0.20561723853461444, 0.21091924543725327, 0.22372810577508062, 0.11339086588122882, 0.04505576318479143, 0.19384918094146997, 0.2012825320707634, 0.22828737128293142, 0.16398986364947632, 0.20345282420748845, 0.1150538184447214, 0.1003293191024568, 0.13999869319377467, 0.10638147403369658, 0.29388445371296257, 0.10068684132420458, 0.19117826566798612, 0.13806827802909538, 0.14184675965225324, 0.13778549007838592, 0.12796276481822133, 0.13589461654191837, 0.19765705161262304, 0.23632490483578295, 0.15302420128136873, 0.13410651561571285, 0.12125793553423136, 0.13026734115555882, 0.263789682649076, 0.26096684974618256, 0.3703202912583947, 0.19612304720794782, 0.09636809103540145, 0.10921792534645647, 0.07575085008284077, 0.17929146444657817, 0.11720826572855003, 0.1970780873671174, 0.18470313108991832, 0.15142347780056298, 0.10170445937546901, 0.10729674249887466, 0.2142758754780516, 0.13129779836162925, 0.10490661137737334, 0.06696086784359068, 0.3272732620825991, 0.11883903134730645, 0.23890183452749625, 0.233953193819616, 0.16920741414651275, 0.3529679880011827, 0.2554203348699957, 0.17665339662926272, 0.15056585194543004, 0.15539040556177497, 0.10297431857907213, 0.1064440148184076, 0.22579057869734243, 0.12205310966237448, 0.0740405113901943, 0.252723103039898, 0.23650269373320043, 0.23787468730006367, 0.11560094455489889, 0.22333096771035343, 0.1456497173057869, 0.11854201642563567, 0.14697379781864583, 0.2821027406025678, 0.11745266237994656, 0.21049969451269135, 0.11548755181138404, 0.18423398985760286, 0.08515138237271458, 0.18270948494318873, 0.19014219782548025, 0.20024028955958784, 0.20878168201306835, 0.1379426324274391, 0.11837571597425267, 0.19983022328233346, 0.14950499637052417, 0.10082960085128434, 0.16005680750822648, 0.15887171641224995, 0.23022704845061526, 0.1449383984436281, 0.1804670857382007, 0.1731582373031415, 0.09192515717586502, 0.15931532776448876, 0.18544084072345868, 0.16125677124364302, 0.15426860481966287, 0.1267204392934218, 0.2786342689068988, 0.21831002697581425, 0.17944157123565674, 0.15193603467196226, 0.1769666571635753, 0.09694010877865367, 0.13097101589664817, 0.14306987839518115, 0.15574482560623437, 0.06513273547170684, 0.14021456910995767, 0.08424144252785482, 0.1965760689927265, 0.10674882971215993, 0.14114370831521228, 0.14529212086927146, 0.1265974951093085, 0.11792751814937219, 0.19295858888654038, 0.20548369648167863, 0.10638352236128412, 0.14200627687387168, 0.12216432049171999, 0.18304719182197005, 0.16492452443344519, 0.08351778174983338, 0.18348925950704142, 0.11029468514607288, 0.11452160208136775, 0.0805851406767033, 0.193005507462658, 0.16214584931731224, 0.13549286231864244, 0.20796110416995361, 0.11019853249308653], [0.04305737100366969, 0.025413722833036445, 0.030130197483231314, 0.07854684692574665, 0.01207002913361066, 0.014181225906213513, 0.05257006036117673, 0.014810913162364159, 0.05329293075192254, 0.08032704397919588, 0.04501706760493107, 0.05522890089196153, 0.010145599389943527, 0.04832601094676647, 0.07997550346772186, 0.06450025495723821, 0.02958890650916146, 0.004771684871229809, 0.06350826326524839, 0.01858757466834504, 0.028968018341402058, 0.02848926258593565, 0.10696906945668161, 0.05271576992527116, 0.08285153351607732, 0.06614837198867463, 0.0384779413434444, 0.04145628015976399, 0.04993928785552271, 0.04016436432721093, 0.07269575464306399, 0.06473558256402612, 0.004432950581758632, 0.0590571991779143, 0.07290781592018902, 0.05736106890253723, 0.014614551091653993, 0.07229712486150675, 0.003840239210148866, 0.03068771922698943, 0.08610607372247614, 0.01488241445258609, 0.04280721528630238, 0.03622011288825888, 0.023764726356603205, 0.033016662127920426, 0.03329792867589276, 0.02013216395425843, 0.1017520236200653, 0.03179134291713126, 0.04169318483036477, 0.026096955116372555, 0.025041487533599138, 0.010021910275099799, 0.043915386486332864, 0.07412138322251849, 0.0380286414292641, 0.04720672237453982, 0.05353118613129482, 0.015219372689898591, 0.06655785939074121, 0.07819676844519563, 0.0452912540640682, 0.02774080294329906, 0.030223465037124697, 0.05696577136404812, 0.06840697227744386, 0.11944265716010705, 0.01870307511126157, 0.012752605543937534, 0.07371088649961166, 0.11436189932283014, 0.0492199352447642, 0.033428457609261386, 0.11713641841197386, 0.12607011012732983, 0.03818449244135991, 0.042180356540484354, 0.026932754408335313, 0.05302323057549074, 0.05459433865325991, 0.021365223765315022, 0.01772068124409998, 0.03673223560326733, 0.06650459545198828, 0.06716521078487858, 0.12791973509592935, 0.1366810259060003, 0.11654169094981626, 0.14666706818388775, 0.046437642158707604, 0.06492520871688612, 0.006888582729516202, 0.07482547356630675, 0.08430689995293505, 0.07892648514825851, 0.06755018504918553, 0.09774455975275487, 0.15878635458648205, 0.03290373322670348, 0.01946344807947753, 0.06666083238087595, 0.07141827358282171, 0.013389601099333959, 0.016127787421282846, 0.05035891670559067, 0.047745143092470244, 0.009954594697774155, 0.06693829913274385, 0.11317522003082559, 0.002003767881433305, 0.01888094935566187, 0.009542144271108555, 0.051125236132065766, 0.04491649546253029, 0.11315527110127732, 0.025497865681245457, 0.050734395190374926, 0.045980861395946704, 0.030324940744321793, 0.03378754205186851, 0.0667652822448872, 0.04579359527269844, 0.06273156861425377, 0.02365777916566003, 0.042189206651528366, 0.08193920395569876, 0.02907113048422616, 0.034629816582310013, 0.016906693672353867, 0.02401801208179677, 0.05334375673555769, 0.05916565663937945, 0.025309935335826594, 0.06497796057374217, 0.029888320423197, 0.05887839353817981, 0.025076464953599498, 0.028851339739048854, 0.0592114137543831, 0.030508657546306495, 0.029618336375278886, 0.033823461999418214, 0.033855355795822106, 0.04357698569947388, 0.008072105574683519, 0.09071930078789592, 0.03832590125966817, 0.04400810670631472, 0.09637518596719019, 0.06733822025125846, 0.023533922139904462, 0.05495528217579704, 0.025261085320380516, 0.08332159501151182, 0.03822616032266524, 0.035677636333275586, 0.09946728489012457, 0.03447253693593666, 0.029907302705396432, 0.06007912910718005, 0.029190517925599124, 0.016103261295938864, 0.052124040739727207, 0.024630063126096502, 0.048233769412036054, 0.04925955850922037, 0.05385501484852284, 0.007093126514519099, 0.04026674730994273, 0.029425839966279455, 0.05936460416705813, 0.003471973705018172, 0.014665634971606778, 0.04784773016581312, 0.08963863729150034, 0.07725775867584161, 0.02979497679916676, 0.06175748865643982, 0.009483208468736848, 0.07149491517338902, 0.04820725989702623, 0.03503550418827217, 0.04273712314898148, 0.05603648743999656, 0.053616117511410266, 0.10977665864629671, 0.022756388862035237, 0.006703091730742017, 0.02203142375947209, 0.10945194677333347, 0.07621875935001299, 0.022724656482751016, 0.038611902709817514, 0.05679669899109285, 0.03350118437083438, 0.0935323818703182, 0.004402073991514044, 0.04485895675315987, 0.06452464935136959, 0.044625072623603046, 0.03270382832852192, 0.03352666230057366, 0.04220096227072645, 0.012965541627636412, 0.006424280300052487, 0.029468005086528137, 0.048858268128242344, 0.04773979220772162, 0.020465083980525378, 0.012657094848691486, 0.04373546391434502, 0.05850762769114226, 0.02554677692387486, 0.048300985727109946, 0.051742758660111576, 0.061085292109055445, 0.02536104333557887, 0.029422652442008257, 0.028188492397021037, 0.013696622027055128, 0.07702973380219191, 0.03497069985314738, 0.037802438528160565, 0.03989050441305153, 0.013204162514739437, 0.0112902684850269, 0.022460689397121314, 0.04556440151645802, 0.03257890261011198, 0.026897597017523367, 0.0354080215038266, 0.06235366701730527, 0.038955120035097934, 0.0404425249871565, 0.01236074971529888, 0.0405225322174374, 0.06145051040221006, 0.0578096452227328, 0.029303517330845352, 0.0571589004539419, 0.09609619781258516, 0.07472490513464436, 0.048704528526286595, 0.008162464837369043, 0.010944664227281464, 0.018736393831204623, 0.032039891884778626, 0.07309493361390196, 0.059535457694437355, 0.04357236211944837, 0.23199468094389886, 0.033696610407787375, 0.07115196873201057, 0.0341710023349151, 0.0099186868101242, 0.013968052335258108, 0.025768705054360908, 0.004817799144802848, 0.040904771667555906, 0.010174950402870309, 0.025461355726292823, 0.08228413193137385, 0.06730785156833008, 0.06342519467580132, 0.14685912115965039, 0.04575459170155227, 0.04091817114385776, 0.0312890054192394, 0.18077860964694992, 0.1413476059678942, 0.07232547490275465, 0.09063053992576897, 0.09015118674142286, 0.05653970809362363, 0.04291816636396106, 0.02993248934217263, 0.06008566000673454, 0.037169894931139424, 0.060897205912624486, 0.02870210682885954, 0.051033566051046364, 0.037275034992489964, 0.020777943755092565, 0.09676003406639211, 0.06064967739803251, 0.03800705977482721, 0.017376345131197013, 0.020110396762902383, 0.03946001052099746, 0.06373648851877078, 0.07287252679816447, 0.054082984061096795, 0.031757931428728625, 0.02777255758701358, 0.01424205604052986, 0.061272313323570415, 0.08975079806987196, 0.04688200308009982, 0.058890820801025257, 0.07423838280374184, 0.0447451261425158, 0.0100578302226495, 0.03909863284206949, 0.02176905229134718, 0.029572076455224305, 0.029718229452555533, 0.06834350380813703, 0.060876819115947, 0.01998935989831807, 0.0637125616776757, 0.027415705153543968, 0.00942787579333526, 0.04971976799424738, 0.06493391410913318, 0.09962182230083272, 0.022094328196544666, 0.03519925907312427, 0.027728141903935466, 0.023751989247102756, 0.022175092417455744, 0.042717341202660464, 0.04240329028107226, 0.02904540207964601, 0.013998688191350084, 0.01638902711420087, 0.04639612641767599, 0.018239264354633633, 0.01828330339776585, 0.02727874365518801, 0.05928245584073011, 0.0665471947286278, 0.007967107449076138, 0.05139217551914044, 0.029718526311626192, 0.027305130715831183, 0.04451807719306089, 0.026403309966553934, 0.043031822569901124, 0.026202440276392736, 0.07380499824648723, 0.023019988584565, 0.053708793202531524, 0.03442157365498133, 0.02986438059451757, 0.0034413698540447513, 0.030838232341920957, 0.05413323859102093, 0.013872750369046116, 0.03452937431575265, 0.016222567101067398, 0.037348262703744695, 0.2741352509474382, 0.14013952313689515, 0.1447322595049627, 0.16030395752750337, 0.2044063652283512, 0.07666361751034856, 0.13991674524731934, 0.12073541904101148, 0.14729591959621757, 0.20578172814566642, 0.22249697183724493, 0.11388186336262152, 0.12677146936766803, 0.12375676902593113, 0.16355754778487608, 0.2346898941323161, 0.05908311126404442, 0.1367959548952058, 0.25956448749639094, 0.09512972857919522, 0.12925159331643954, 0.13793460238957778, 0.19452104723313823, 0.15257983293849975, 0.15631844638846815, 0.11709114740369841, 0.37203583982773125, 0.13968924729852006, 0.10453523325850256, 0.0778966439247597, 0.19316098740091547, 0.12375029749819078, 0.11404308010241948, 0.14055750070838258, 0.1459693899960257, 0.12324518436798826, 0.08841079848934896, 0.0967108148324769, 0.07863085804274306, 0.13669218780705705, 0.2400740419398062, 0.1053403818514198, 0.19246056326664984, 0.14757437340449542, 0.07802410778822377, 0.1429003570228815, 0.18838381249224767, 0.11656271599349566, 0.2931162714958191, 0.207408293208573, 0.14994804369052872, 0.10968593851430342, 0.13589099486125633, 0.18002782337134704, 0.12289435631828383, 0.1769885653629899, 0.1441008847905323, 0.17590030969586223, 0.12448698296793737, 0.09895376322674565, 0.09880229830741882, 0.1336228134459816, 0.18542099569458514, 0.14373516925843433, 0.12378128958516754, 0.2326399486628361, 0.15348923101555556, 0.19456913840258494, 0.10337703017285094, 0.15872189163928851, 0.22435195511206985, 0.22796711971750483, 0.2593077637720853, 0.12932744080899283, 0.15065017476445064, 0.30095367750618607, 0.22925364755792543, 0.14232648391043767, 0.13973477063700557, 0.09008196662762202, 0.18319934693863615, 0.12193544214824215, 0.12235142334247939, 0.1012527734565083, 0.3022832499118522, 0.21024429181125015, 0.19863238208927214, 0.20762810250744224, 0.30966631311457604, 0.35426211543381214, 0.15694283007178456, 0.13668426166987047, 0.202140454784967, 0.2567627019016072, 0.28523029934149235, 0.24574130424298346, 0.19087186257820576, 0.18445654510287568, 0.21663298102794215, 0.17399184725945815, 0.23252739454619586, 0.3198264929233119, 0.21613393124425784, 0.14046145195607096, 0.13719635840971023, 0.28553339245263487, 0.10516178401303478, 0.11556752564501949, 0.2011884277453646, 0.1866005948977545, 0.17753355408785865, 0.08895140854292549, 0.09573101662681438, 0.15491647005546838, 0.10242409771308303, 0.17440436262404546, 0.162774671043735, 0.16146285081049427, 0.09891733861877583, 0.09878552576992661, 0.12446635868400335, 0.1847221003845334, 0.10704959990107454, 0.19398307922529057, 0.16883046249859035, 0.14050123107153922, 0.1112469051440712, 0.1966411850298755, 0.1069719267252367, 0.16975608392385766, 0.0896922945685219, 0.18106193194398656, 0.13715080538531765, 0.1332606899086386, 0.11411414816393517, 0.0787779813981615, 0.1454017509240657, 0.07725196992396377, 0.16441463929368183, 0.27253693202510476, 0.09292560935136862, 0.09215972779202275, 0.12249663937836885, 0.14498255623038858, 0.13217645668191835, 0.08989592504804023, 0.18521096790209413, 0.12748829496558756, 0.13943592261057347, 0.08149191155098379, 0.1665488036815077, 0.08481358643621206, 0.07677107307245024, 0.1499313156818971, 0.1673213645699434, 0.1645832700887695, 0.17295350844506174, 0.1863292360212654, 0.06849645302281715, 0.09279573350795545, 0.14886330580338836, 0.14146899164188653, 0.09474332196987234, 0.09707974386401474, 0.13483643269864842, 0.14145472756354138, 0.10477448682649992, 0.11393802909879014, 0.060526113520609215, 0.18585470679681748, 0.0763731038023252, 0.15893606061581522, 0.061092190371709876, 0.11793774494435638, 0.1555406310944818, 0.21861420362256467], [0.059908145703957416, 0.04544816634734161, 0.01304866958889761, 0.06156940246000886, 0.07951226973091252, 0.038553009580937214, 0.00553128322280827, 0.036436378431972116, 0.04404493578476831, 0.010834046188392676, 0.10180807061260566, 0.08610558390500955, 0.07249588685226627, 0.03575388829631265, 0.01953315244463738, 0.06756274960935116, 0.026510943644098006, 0.022689172546961345, 0.009921729615598451, 0.01327607291386812, 0.06940115330507979, 0.06117163356975652, 0.02069782520266017, 0.031510009575868025, 0.024504133652953897, 0.012078381078026723, 0.020076315486221574, 0.023239454640133772, 0.10223198536550626, 0.02898554415878607, 0.027593779777816962, 0.047862187202554196, 0.033891056809807196, 0.03683644055854529, 0.03244282983359881, 0.048511815039091744, 0.015591049523209222, 0.004529612533588079, 0.04168549618043471, 0.029422824991343077, 0.02346382629184518, 0.05236646698904224, 0.016554062203795183, 0.04988563428923953, 0.03959153393225279, 0.028313726106716786, 0.019447516024229117, 0.09551355251460336, 0.040338179023819976, 0.018091949896188453, 0.04616535188688431, 0.02676376923773205, 0.026474402147869114, 0.07939311792142689, 0.044135492644272745, 0.05157950101420283, 0.029668698516616132, 0.021621706291625742, 0.029603829243569635, 0.03542354723322205, 0.04214346809021663, 0.0464105982973706, 0.10455375726451166, 0.05922971882682759, 0.050640854897210374, 0.11113907108665444, 0.0341833962011151, 0.06088849309890065, 0.08371116316993721, 0.03431770266615786, 0.02641050137754064, 0.14831318141659722, 0.08141967831761576, 0.10245216573821381, 0.1485973794478923, 0.2564127347432077, 0.0434882099943934, 0.09314377850387245, 0.04305110727727879, 0.032749229212640785, 0.04655527627619449, 0.07538319754530676, 0.03934199790819548, 0.015690844265918713, 0.041992912301793694, 0.040108514003804885, 0.1286734305904247, 0.054046915684011765, 0.07215023899334483, 0.13266464142361656, 0.11656992966891266, 0.04316655205911957, 0.1555669031222351, 0.1624743387219496, 0.1267082235426642, 0.1364310408825986, 0.14957622770452872, 0.28649901563767344, 0.08735252558835782, 0.06188120096339844, 0.04721293786133174, 0.013298258490976878, 0.023416117328451946, 0.05196796337259002, 0.02028721344686346, 0.030052303518459667, 0.04714148759376258, 0.03282773730461486, 0.06569983277586289, 0.05552406044444069, 0.008658966271468671, 0.06257087879930623, 0.014951965749787632, 0.047963839169824496, 0.03915771892934572, 0.02857447041606065, 0.13389353407546878, 0.03339363232953474, 0.062402856565313414, 0.022727708565071225, 0.03807567874900997, 0.0530495322891511, 0.046598246626672335, 0.02833727816323517, 0.06877901090774685, 0.03046107474801829, 0.024008560831134673, 0.07025370287010446, 0.033085537143051624, 0.05998916596581694, 0.01920388935104711, 0.035073379694949836, 0.01828607160859974, 0.03108566437731497, 0.11058468677219935, 0.03892166030709632, 0.051640865494846366, 0.01205595337523846, 0.03998254927864764, 0.08908577437978238, 0.10918466970906593, 0.10548564983764663, 0.017397693009115756, 0.00723831611139758, 0.0962520191387739, 0.02433857720461674, 0.037321122363209724, 0.05180300991924014, 0.03734457051905338, 0.034664096383494325, 0.019821176247205585, 0.027485018035804387, 0.0034842096329157357, 0.056972061065607704, 0.00739559668545553, 0.038528396253241226, 0.04826459080504719, 0.07683394040213898, 0.05081497016362846, 0.03145237067656126, 0.046858918576617725, 0.0400068805902265, 0.11384301193174906, 0.03374436390004121, 0.02273301492095925, 0.02202004849095829, 0.06258451205212623, 0.03843699334538542, 0.012976086618436966, 0.06799709895858541, 0.034216681524412706, 0.020896794994769152, 0.07162043460994028, 0.059437984018586576, 0.01412277157214703, 0.024245235435955692, 0.028966784520889632, 0.02825856783601921, 0.040356803219765425, 0.023541020782431588, 0.04617229838913772, 0.022822772116342094, 0.015623290273651946, 0.03518547739076894, 0.024810995018924586, 0.024803187625366263, 0.041455434111412615, 0.028283003048272803, 0.009469615106354468, 0.013099879633955425, 0.026265062697348185, 0.011232545166421914, 0.04448282517842017, 0.018381740010227077, 0.08566926044295542, 0.05565305684285704, 0.05146952586073894, 0.03519405290717259, 0.03732099248736631, 0.026586247513478156, 0.017472848448960576, 0.053934743773425, 0.026483558394829743, 0.04472550375794526, 0.07981997157912701, 0.02620345516334055, 0.06710074041620828, 0.061214670713525265, 0.008223601107602008, 0.016388656040362548, 0.007612773679284146, 0.03477698075585067, 0.09206995760905556, 0.024980568341561593, 0.03463220258709043, 0.07399157417239621, 0.02397679134446662, 0.06423057333449833, 0.015122775675990852, 0.06378941106959246, 0.053956807823851705, 0.07767190676531754, 0.01747632912156405, 0.09046528590261005, 0.01973877373529831, 0.03175847319653258, 0.03679023444419727, 0.058451287550269626, 0.041256698095821775, 0.0610062904888764, 0.09079952695174143, 0.038947386856307276, 0.026705538475653157, 0.04129718967305962, 0.01175359127955744, 0.09392260311869904, 0.0633874638879206, 0.038486093835672364, 0.026574794319458306, 0.04338035738328472, 0.06537995228427462, 0.04197569076495711, 0.03633611057011876, 0.08326256458531134, 0.02414242200757144, 0.01496349037552136, 0.017613850941415876, 0.0931591929111164, 0.09783676418010145, 0.08968807174824178, 0.18100549903465435, 0.27189209475181997, 0.13801540742861107, 0.01229619956575334, 0.06976708406000398, 0.054198718280531466, 0.10274657572153956, 0.03231868708098773, 0.027997372671961784, 0.009410929778823629, 0.05617896866169758, 0.06074609722418245, 0.09346546983579174, 0.09061894757905975, 0.07524941058363765, 0.11147922705276869, 0.0491982459789142, 0.06407876702724025, 0.18382799054961652, 0.18835675378795713, 0.30711317667737603, 0.10125533386599272, 0.16596356086665764, 0.14080487337196246, 0.12095417449017987, 0.019127015839330852, 0.08741776779061183, 0.04242918381351046, 0.07794851262588054, 0.08161080360878259, 0.05737830157158896, 0.052901544331689365, 0.04697607771959156, 0.12153702016803436, 0.03952229526476003, 0.07827457520761527, 0.08071289397776127, 0.010747785436251434, 0.037588544146274216, 0.052928580771549605, 0.09385882294736803, 0.058470416406635195, 0.0759516010293737, 0.025482373348495457, 0.04080257422174327, 0.016675961815053597, 0.03918176080333069, 0.025254461652366444, 0.05846465362992603, 0.06778519353247248, 0.026654599314497318, 0.04159455711487681, 0.04983822218491696, 0.06976099102757871, 0.04086260654730722, 0.04297943436540663, 0.044234803135623224, 0.015315661712520523, 0.020785285450983793, 0.021138623815204483, 0.1099642290500924, 0.012120926548959687, 0.06716327377944253, 0.05994120096147526, 0.08832855368382297, 0.008817886064207414, 0.0439022764476249, 0.05023358651669696, 0.010369253941462375, 0.027124942826048937, 0.08553643827326596, 0.029009222380409483, 0.00632577271971968, 0.05268195025564637, 0.016223734128288925, 0.050832763154176064, 0.07139355264371261, 0.025190152700815815, 0.03880526186549105, 0.03527649809257127, 0.03287645558884833, 0.03916307723557111, 0.04867454947088845, 0.019586232701840345, 0.041601659468142316, 0.0187586860920419, 0.011725616950570839, 0.016139023537107278, 0.07002807513345033, 0.07393500025500543, 0.006215021094249096, 0.016128850547829643, 0.04900564752460923, 0.029371327364060562, 0.012965072219230933, 0.005236853758106008, 0.060577674230444245, 0.03138063839287497, 0.0507756771548884, 0.04252968916262034, 0.024902974946598988, 0.02081070029817056, 0.14647963136667386, 0.1422300492413342, 0.11029779474483803, 0.10274904707330279, 0.14513325673760846, 0.153827219910454, 0.1303566957358271, 0.2829283947357908, 0.15205491188680753, 0.12614177190698683, 0.1931327412603423, 0.19824178976705298, 0.16483891027746722, 0.17467851197579876, 0.12395677040331066, 0.15260980086168274, 0.09486968003329821, 0.09639820738811977, 0.22189275972777978, 0.08863227019901387, 0.24116143671562895, 0.17688942927634344, 0.11690787403495051, 0.07919184005004354, 0.11681983305606991, 0.15544060443062335, 0.12720639759209007, 0.17524304887047037, 0.20234678668202832, 0.1265162744675763, 0.1538954084389843, 0.1593405014136806, 0.1309586814022623, 0.11137691457406618, 0.1652449244284071, 0.11469098986708559, 0.13878348574507982, 0.11654590634861961, 0.13685776095371693, 0.2233636222081259, 0.1336546367383562, 0.13875010394258425, 0.07073469620081596, 0.18433947872836143, 0.11128551166621037, 0.2703186229337007, 0.13397180096944794, 0.20771695242729038, 0.21748039493104443, 0.1173678868508432, 0.15538268722593784, 0.15121250005904585, 0.12253682667505927, 0.1688773513888009, 0.2619865903398022, 0.12290129539906047, 0.18511707137804478, 0.09053616100572981, 0.14701828215038404, 0.12613178259925917, 0.16426794638391584, 0.16421155800344422, 0.20077236491488293, 0.11536280420841649, 0.15693564608227462, 0.19089420122327283, 0.14399459440028295, 0.2126297474023886, 0.13194695493439212, 0.12122994172386825, 0.13290515664266422, 0.2960344555322081, 0.2685751102399081, 0.2519050188129768, 0.32084385864436626, 0.36846153787337244, 0.12854024476837367, 0.16949607990682125, 0.11439806417911313, 0.16684817121131346, 0.18885351775679737, 0.20491179748205468, 0.10834248794708401, 0.10562875817413442, 0.2559609152376652, 0.14475039759417996, 0.2036355112795718, 0.19499860442010686, 0.17297807353315875, 0.33071949903387576, 0.22619467810727656, 0.07387851539533585, 0.2813380613224581, 0.3318265458801761, 0.3605213592527434, 0.36330836126580834, 0.3559445048449561, 0.5681741307489574, 0.33984245324973017, 0.11029346060240641, 0.1989247734309174, 0.1389310840750113, 0.203253423969727, 0.20335358422016725, 0.13358944648643956, 0.10634043326717801, 0.1246443999116309, 0.19590942742070183, 0.21075254422612488, 0.2213627178571187, 0.1325550113688223, 0.08826561956084333, 0.1573390924022533, 0.19691208377480507, 0.22099913971032947, 0.2189214082318358, 0.2745249675353989, 0.0789788510883227, 0.1873367460211739, 0.09678353788331151, 0.1420870076981373, 0.12025921998429112, 0.1815840625204146, 0.256914040655829, 0.1446090333047323, 0.12440918362699449, 0.14154771866742522, 0.170511590258684, 0.15433226624736562, 0.14926360541721806, 0.1211313548265025, 0.05636675799905788, 0.09085313227842562, 0.09850398462731391, 0.16615993314189836, 0.14190671034157276, 0.19573101511923596, 0.2165777949267067, 0.10824704775586724, 0.14647020609118044, 0.16906444681808352, 0.24921152740716934, 0.08812248153844848, 0.12105004512704909, 0.21967258042423055, 0.09381364099681377, 0.10882304341066629, 0.1932534738443792, 0.07623472294653766, 0.10683275919291191, 0.14961026259697974, 0.12171447509899735, 0.16508653527125716, 0.09547197740175761, 0.11827180787804537, 0.12188810054794885, 0.1638232811819762, 0.13609325978904963, 0.16590264538535848, 0.14378795080119744, 0.09190469616441987, 0.13195268431445584, 0.2611845958745107, 0.20478870486840606, 0.09453869701246731, 0.12189039378426969, 0.146221453032922, 0.08330750904860906, 0.0779228046303615, 0.1331823636428453, 0.11216997358133085, 0.12101091168005951, 0.2449477108893916, 0.10546354125835933, 0.1190724442130886, 0.09471745070186444], [0.010615705414238619, 0.038590536278206855, 0.0694378005573526, 0.05246258253464475, 0.0449489829770755, 0.07354840068728663, 0.08545616758055985, 0.0903369759907946, 0.019146640079270583, 0.03590478176192846, 0.01212383391248295, 0.017250519558729138, 0.02291790060553467, 0.011278190031589475, 0.07433260587276891, 0.05666797347657848, 0.01668255208642222, 0.009901288085529814, 0.02077118835586589, 0.005261670248728478, 0.023384611304209102, 0.067665433161892, 0.03938525027479045, 0.06966006636503153, 0.033073109880206175, 0.03140902554150671, 0.04064255605044309, 0.040000884036999196, 0.02606385347462492, 0.03045898560230853, 0.031041486181493383, 0.023824927520763595, 0.04087576853635255, 0.03404503018828109, 0.06471211585449055, 0.015317518937081331, 0.06686703069135547, 0.04698644181189593, 0.04642942287318874, 0.04191411477222573, 0.012590677270054584, 0.0037905670342297526, 0.04917988153465558, 0.040379616839345545, 0.06747289779013954, 0.029667453563888557, 0.026085498211614322, 0.055988429667195305, 0.03465645597316325, 0.04256806932971813, 0.07184356130892411, 0.02639870494022034, 0.022498789403471164, 0.016183730513148475, 0.056969560027937405, 0.08341184016899206, 0.02700006905797636, 0.07573760274681263, 0.03470968280453235, 0.06197626265930012, 0.07110174017725512, 0.08492619250318967, 0.026133105129702017, 0.004615177986124763, 0.07211515025119297, 0.051646795254782774, 0.05822254650411196, 0.11486181741929613, 0.08392977761104703, 0.05615476722596213, 0.06925368114025332, 0.10668142043869011, 0.1232970975979697, 0.13743153016548604, 0.13451903098030016, 0.220702369697392, 0.06622401910135522, 0.03738049417734146, 0.13215370243415236, 0.13889507506974041, 0.04133597431064118, 0.06595473081688397, 0.07725706847850233, 0.18553334200987592, 0.21406163228675723, 0.35510854970198125, 0.4956529143964872, 0.3243632713565603, 0.7783748139627278, 0.35339270427357405, 0.17163043725304306, 0.10429384230519645, 0.03471368669124786, 0.11418798443628475, 0.08537526606232859, 0.07890305554610677, 0.1801693657762371, 0.220446833409369, 0.16220695775700733, 0.09637006514822133, 0.06643500426434912, 0.04151787841692567, 0.06355963472742587, 0.03752635217097122, 0.026620946628099773, 0.04282611407688819, 0.019722071701835375, 0.08480662509100512, 0.028621181190828793, 0.10392089083325118, 0.021929946196905803, 0.026966366276610643, 0.018342695620958693, 0.019082388644164894, 0.07925965750473551, 0.04957847420882899, 0.0405907652748283, 0.02839416563801933, 0.011086064696428366, 0.04208582548017148, 0.029152432762202807, 0.041135353239951655, 0.01569817482959479, 0.03927938661945518, 0.051218453590990975, 0.02104587576468475, 0.06643536049523391, 0.05607358369161375, 0.04649232731026132, 0.050695595709839836, 0.0064312170616176445, 0.04428887230460532, 0.03166209418850485, 0.018580212563392706, 0.029182912767282687, 0.037785640015499666, 0.04912165633868426, 0.09230033509084024, 0.022611766544287093, 0.04914822151476983, 0.01538926420835196, 0.022272888927545864, 0.02454479777952656, 0.01666220610786695, 0.07676613036892377, 0.020465562665776815, 0.014313705760287121, 0.007868175453040749, 0.079855119693093, 0.03890689527906943, 0.03459441984887235, 0.008544246011297219, 0.019761138355534058, 0.09089498198591173, 0.04665122112783138, 0.03276422430644743, 0.0348713448329363, 0.05909519342822023, 0.015042186787468381, 0.04461639320652466, 0.05898983814404346, 0.049898269353434443, 0.06039270134351682, 0.037380772482720204, 0.01412887109836447, 0.05345959114492871, 0.0363296390423784, 0.01014880361253745, 0.03941242401197087, 0.051858834267477505, 0.016562246237299405, 0.06553381434059702, 0.04091340284503531, 0.007187385763245402, 0.06991878646658733, 0.014992998167144833, 0.06231209932593629, 0.030486291070701554, 0.04022278248157818, 0.03817574994172901, 0.053754090185975656, 0.0294427164044464, 0.07203459012089297, 0.04886058362899348, 0.04664063439122401, 0.03008172039699275, 0.0314110627368791, 0.02803312563628424, 0.04565579329209868, 0.03608501974667888, 0.08352118078619242, 0.012616614403668791, 0.03517899844155181, 0.03418552616494708, 0.028988017365918495, 0.04153515190409962, 0.11979948176303878, 0.0437275674630655, 0.054695248472853564, 0.03202910105756018, 0.037579842464765534, 0.04720677803561557, 0.011019823377864668, 0.030153048210195266, 0.020453281977097504, 0.07962244897498749, 0.017270550124521833, 0.05096798617159948, 0.012333906233834568, 0.008510148036293685, 0.05329582512786146, 0.035035864129895344, 0.0430908752605319, 0.061381000850815326, 0.030438515314017422, 0.02618279933813028, 0.0312190468685003, 0.032084609993034974, 0.04253836857969873, 0.03993124089902267, 0.04800159964361228, 0.027402205487305764, 0.03130228244117461, 0.03618274575273972, 0.05729182652430609, 0.04287750038201921, 0.06451305700466037, 0.019760839641094208, 0.02442175155010773, 0.01819026034354465, 0.0035832265120916418, 0.0504390501009766, 0.052259601434343494, 0.020942813716828823, 0.04173248897131998, 0.07117678615031764, 0.10160024699871428, 0.05516470882866997, 0.058268960419809446, 0.05179476094781421, 0.018276618502568454, 0.06572614191100001, 0.0593093030329328, 0.20607778569683433, 0.08222900520195253, 0.06722033009282313, 0.03129648626782, 0.09429779587662779, 0.10409683920443058, 0.08540149356122129, 0.11975013636401854, 0.23946966655785218, 0.1458037129486911, 0.024671892424521502, 0.07706630683969706, 0.06944116248632781, 0.007706657215749146, 0.043436148334876634, 0.09544442888000049, 0.14334381994558498, 0.15803835878614336, 0.3934345400193706, 0.4103392391698435, 0.3150962514337152, 0.5275465920567513, 0.3478743613231927, 0.13468690478475764, 0.06272137150517665, 0.0455658672581194, 0.18053922249237075, 0.1923971838550642, 0.18450043571647257, 0.10560773313045502, 0.09449981589568779, 0.05708701231924351, 0.11101539217634127, 0.11040864934329875, 0.14955987076973543, 0.1300597030785866, 0.06868840951938182, 0.02861246837710496, 0.06079142760427203, 0.04307369083107915, 0.022646059333055746, 0.021730659136665054, 0.040580293571110815, 0.024828214700391982, 0.007119655510905432, 0.0541310752305435, 0.04500149734667502, 0.021355425560614094, 0.02399723194685066, 0.05368769765482284, 0.024098715075524524, 0.021114583796588704, 0.08041584194870666, 0.03594227135181427, 0.04910038267553318, 0.02857525152649032, 0.020154979429207742, 0.004953004536218941, 0.08755211136303842, 0.025752544788701925, 0.017283715824305546, 0.03634257096564397, 0.03364701638929546, 0.04980504818377085, 0.008865296313160798, 0.06230805462109856, 0.02167138380173128, 0.05508330636075698, 0.016865181642060634, 0.05260081867163535, 0.12969104864168912, 0.021253419217828196, 0.1124137913575396, 0.03213487194443587, 0.03946968441596255, 0.020069203856110107, 0.04089690490218345, 0.05891645829251502, 0.022372422063199338, 0.09524761873763055, 0.03239960344217252, 0.045101316209184006, 0.05510027185664512, 0.02328986502107, 0.04743887730001006, 0.018911260522145312, 0.10233552980935201, 0.09169455704977736, 0.06792294356273487, 0.04182134631264489, 0.0249725104731624, 0.04810841324797366, 0.03470005343842786, 0.0049037755616154755, 0.038377625241992064, 0.01564356018207036, 0.026817621328518726, 0.07371004787273705, 0.03083699481067015, 0.06150194494694006, 0.037091230988153256, 0.04581312859954778, 0.04433823996805586, 0.040809405691106804, 0.008037797942961333, 0.08031300996663049, 0.017382933547196444, 0.020181552026770078, 0.022798455647716764, 0.11746484102332033, 0.09859644880634733, 0.13958974013803527, 0.08943703287513927, 0.16713904857169837, 0.33057712542358786, 0.16062193812103942, 0.22773938428144902, 0.1556666032411158, 0.12031555641442537, 0.11236821606871672, 0.08509106060955673, 0.16341887007001787, 0.06610891199670732, 0.18404662725515664, 0.16569419094594195, 0.1578872575191781, 0.1468993307207711, 0.06345367088215426, 0.0736798498837743, 0.17052242561476305, 0.10350436044973321, 0.13402995566138998, 0.20007502811495215, 0.23801631876267493, 0.10391651958343573, 0.0946789035515394, 0.10523770572035573, 0.14210265217116103, 0.1355951005825773, 0.12659553583944216, 0.14128692797385156, 0.12815725203836337, 0.11333421774907038, 0.20694203150924295, 0.13133984844898805, 0.13738606619881466, 0.18033872387604788, 0.14111850498011336, 0.20021483389427885, 0.08669922041008249, 0.18815779883880168, 0.18023721291683614, 0.16318947222316638, 0.13599810161394998, 0.135340558772441, 0.09916692288243212, 0.09862360398983583, 0.18652681057574227, 0.16656109364703298, 0.18349544901866466, 0.0866367389971856, 0.09571526083163917, 0.13375479698879644, 0.21043383632786572, 0.21430153894471005, 0.07914069865364581, 0.12924831302370876, 0.11793958547059447, 0.11538968479726464, 0.24279223202029243, 0.2417654707096517, 0.16928384051425382, 0.16773790237493813, 0.17753428139258176, 0.22089838574174792, 0.17214962892467156, 0.3042084106709808, 0.19278225459856912, 0.13420223782304674, 0.11385078963940032, 0.19143904151860625, 0.17314603639533743, 0.19674104842124507, 0.2251886820886284, 0.27196117385756224, 0.22136513725854456, 0.19475271605188027, 0.3575772000476718, 0.4205612844089046, 0.18842633755411953, 0.11150465303217061, 0.2071583378710784, 0.2562781982123852, 0.534885423257947, 0.7370504876598716, 0.6537970143835992, 0.4934647958725691, 0.9195200214162469, 0.5848719191271812, 0.5006550787948072, 0.2683265501400456, 0.15910639835055918, 0.24186934169847518, 0.2616850705817342, 0.45655853406060487, 0.22220573824597523, 0.4210633324692026, 0.2751419000560418, 0.2249116828897968, 0.13517166080418974, 0.2902126929257065, 0.26824063912499696, 0.20523144048638642, 0.2116173243848607, 0.13111217238474637, 0.11902666112291627, 0.19509618199663237, 0.17415886017261073, 0.13763651135377586, 0.14008368394570425, 0.1140089042019099, 0.15355314477346838, 0.14340176683617756, 0.1406446288456209, 0.17039388563716784, 0.14084444468608126, 0.0845122967439238, 0.08678456739289686, 0.1152561279013753, 0.07519884064095095, 0.15516222483711317, 0.11045938997995108, 0.08999641926493496, 0.11820166750112548, 0.19560603745048866, 0.2145767124602571, 0.17810750141507015, 0.13573009724495932, 0.12487422820413485, 0.09082611810299568, 0.09599116165190935, 0.1635096050449647, 0.07188927018432878, 0.17736557638272643, 0.12708054418908432, 0.1149957008601632, 0.2643137576524168, 0.11490008255350403, 0.2772303036181256, 0.08976071316283196, 0.12476768548367545, 0.16161521372850984, 0.10361425767769106, 0.20204081403790042, 0.053720856813015416, 0.1582923365640454, 0.23392233531922102, 0.16090089658973739, 0.15335374453570694, 0.12201830293633975, 0.09427534590940922, 0.14786507264943793, 0.20338047965196893, 0.16368018026696518, 0.15950181463267654, 0.08957885729614645, 0.15052467759232968, 0.12404146429616958, 0.14890385675244033, 0.10286466625984758, 0.1005410315701738, 0.10097157370182686, 0.1723107640282251, 0.13108456449117512, 0.11027358588762581, 0.10430219146655872, 0.11136653934954666, 0.09116616274695843, 0.18864276265958324, 0.22320113639580086, 0.22004876023856923, 0.17527436750242487, 0.09832349431235343, 0.14942981681087986, 0.08133076902595349], [0.035176337842131034, 0.040799249400151893, 0.02934595333499601, 0.019110701578028966, 0.02595537189336028, 0.02348788115341449, 0.013696921669179574, 0.03653955180197954, 0.039642886840738356, 0.03238412224163767, 0.06478572948253714, 0.017280788051721174, 0.02204431115387706, 0.04648311354685575, 0.04556571882858407, 0.012824402765545528, 0.03951681821490638, 0.02118215819791658, 0.09235670120688155, 0.06509910876047798, 0.01779596470441902, 0.05879943273612298, 0.02827120290021412, 0.02189667386119254, 0.09601228317478672, 0.018840673001250252, 0.07545505228335969, 0.020410521283338312, 0.02109673514496535, 0.06828033961937763, 0.04165695318079088, 0.03403315211471636, 0.023833315644878894, 0.04351577706984244, 0.044299433066044, 0.07753192287054844, 0.036290223579271697, 0.005113093211548403, 0.06021202549163718, 0.013935802307969425, 0.03703334346937481, 0.015332631846831646, 0.05148205702425912, 0.08209969339077361, 0.0563114457327174, 0.020960972215107176, 0.0469944607175421, 0.06718830642057583, 0.0393423912464641, 0.05659369191562291, 0.052164962762617506, 0.061280391601030715, 0.04118100645428058, 0.021639200567733496, 0.07493100696592592, 0.006002164791425457, 0.011664155990729341, 0.02283809746586485, 0.021113747025083285, 0.0365584617247805, 0.04328602670284454, 0.12767761683790013, 0.08886030991561711, 0.09749902761541307, 0.10439454432344064, 0.1385694503551349, 0.08813002175884321, 0.12585380376549438, 0.06547736658831127, 0.03230723574233707, 0.23088040557922795, 0.7072065921965986, 0.38900296844076365, 0.22825201536761597, 0.5223970965016633, 0.40697736956644803, 0.14201285230228677, 0.6983340089209378, 1.4880585763603449, 2.716129166074097, 2.392876474186778, 2.0262992195785046, 1.8487193109467626, 6.265122815966606, 13.392368070781231, 18.595905750989914, 24.39076580107212, 20.72309050709009, 26.72421868890524, 17.73272506892681, 8.427734971046448, 4.306852295994759, 0.8100599481258541, 0.11792695411713794, 0.36437580711208284, 0.272164314519614, 0.3693646128522232, 0.5209905782248825, 0.7688576309010386, 0.3287439909763634, 0.12526713602710515, 0.04035701844259165, 0.09156491127214395, 0.15088919084519148, 0.06519687929539941, 0.006651863595834584, 0.12605795374838635, 0.01890833274956094, 0.043530950279091485, 0.1122723899607081, 0.0819365841744002, 0.06413635768694803, 0.02613586220832076, 0.013003645344724646, 0.012308094337640796, 0.0764648629410658, 0.03792483352299314, 0.04848574710194953, 0.027486394719744567, 0.027448650944279507, 0.030646251725556795, 0.017797343243728392, 0.03775962031795643, 0.04714406284620054, 0.02541991234465968, 0.018532577814767137, 0.06861204252345487, 0.01754382930812426, 0.03684788818645757, 0.025935515732271597, 0.04185500270978082, 0.07387199191725813, 0.009963396569219185, 0.020114014732826035, 0.058640464703785256, 0.01766246718034381, 0.06272836995776743, 0.11773004007409327, 0.02509765326976776, 0.05416956671979278, 0.01411394558090251, 0.03565070379409008, 0.02240303008875344, 0.08432897142483853, 0.005729922295358847, 0.09139677029452287, 0.041713857353897765, 0.023886458984634373, 0.029764786231680773, 0.004864252950937953, 0.0044062977394787595, 0.05490824485605117, 0.0483325789537048, 0.03539199482474942, 0.058836020616581663, 0.08506518934154883, 0.014171960192470578, 0.05999978609906975, 0.031987537076929584, 0.06555758533068001, 0.016422529515693896, 0.03073261173994979, 0.04467147540708538, 0.027886551470146514, 0.03243441758968402, 0.02337244564841967, 0.020985090159229003, 0.032992330816341564, 0.03458887971646618, 0.01966729192645289, 0.05358135160349775, 0.03885830315994099, 0.021481032199517358, 0.036607803413062356, 0.09619563817977905, 0.039016606970108114, 0.00989896516330191, 0.034530439297668636, 0.04508878133492544, 0.04891581425908953, 0.040126095482264645, 0.048988381458912045, 0.023341282867477275, 0.06609376476262696, 0.04346054272900801, 0.014614027877541957, 0.04419132812472526, 0.022411113932321314, 0.05886303108127322, 0.0034541199511295417, 0.013538028779294109, 0.056478261976735666, 0.0671444900217466, 0.11019275116268545, 0.06046927243005484, 0.09610370834707282, 0.016154881377588026, 0.06056206315406598, 0.014367690509970998, 0.02358757941692602, 0.007662179377803113, 0.08883436443284154, 0.04265229195880238, 0.041671710787341, 0.055361852937494405, 0.03150620606902521, 0.04278839442122262, 0.03125275521597359, 0.14167490793624893, 0.046835737593937665, 0.0108237052882032, 0.027578576882660855, 0.04970044989022426, 0.0918366560654249, 0.021050562427262776, 0.04087619156052824, 0.02930870123236673, 0.04610696341842413, 0.0072570757492940174, 0.0479847751557827, 0.03845532439299859, 0.04728829924715683, 0.03531745351210702, 0.017318327736575156, 0.04358969868917484, 0.020662539791374, 0.06276692452956922, 0.034500745969126, 0.0391671961551765, 0.03613984590629116, 0.06184874684549868, 0.058582695928635076, 0.06392426672391593, 0.06121625890955329, 0.05730158576625399, 0.01373837339997408, 0.04921065097732935, 0.1657729921862483, 0.02121471807186026, 0.11470958066638559, 0.052964682545280084, 0.04367752444522921, 0.09255458004190587, 0.10137700897757895, 0.05914095054322388, 0.03227685592719354, 0.03271860819950234, 0.4569926904514432, 0.28911470028106123, 0.3326943243155256, 0.364198760362342, 0.6033978844061494, 0.2164964406983927, 0.2972619974752888, 0.9604027401655912, 2.1477516274899244, 0.9443319181445986, 1.131286695599556, 1.0643352381885052, 5.511103626340628, 11.983745656907558, 16.43130250275135, 21.245537772774696, 18.836486041545868, 25.032868646085262, 17.989520989358425, 6.599531946703792, 2.0941728400066495, 0.5843349010683596, 0.08860184956574813, 0.4514355183346197, 0.2722327702213079, 0.3230398439336568, 0.3970995621057227, 0.6592586275655776, 0.30709958053193986, 0.13561699393903837, 0.03875937487464398, 0.11098982518888079, 0.0998702785000205, 0.022245826512516942, 0.07026216335361823, 0.04987230902770534, 0.06274010331253521, 0.06406235814210959, 0.015396630024042679, 0.06777674047043547, 0.023708722037554253, 0.01878996019513579, 0.04045672969368752, 0.011292751896689879, 0.02434326943330234, 0.02268753796670353, 0.040321688502444886, 0.02924747961515095, 0.06251426777453162, 0.04813756109797396, 0.05369132304622326, 0.0303278388309991, 0.03303509707620833, 0.04257611421053298, 0.036562094537657686, 0.036188924132147804, 0.023660653132537846, 0.0899650041537825, 0.03809839588939212, 0.040708224987611175, 0.048190806483034976, 0.012845179189753253, 0.08411342205363326, 0.06896075545228086, 0.05411179423390422, 0.06711743873893283, 0.05477178616274614, 0.009509142819297267, 0.0254699702054495, 0.02376625889155548, 0.06247086697840132, 0.02536549436626956, 0.030733643325220328, 0.04108609689865261, 0.04822503433388192, 0.02564717837231001, 0.08755003334954381, 0.07444677044986747, 0.06366317917127162, 0.027239925620961003, 0.024641232448630035, 0.049177042819792405, 0.01392238706102944, 0.03402650618227199, 0.026085041790793184, 0.07719905479461886, 0.03142996894894168, 0.008046328002819791, 0.020856290429946966, 0.03255022602388635, 0.05924348566622939, 0.02652053219208028, 0.041393891515326686, 0.035457964331726544, 0.05162564404599834, 0.013397616294241743, 0.013940710687165847, 0.05439821870822925, 0.03703858674271032, 0.04947070323396474, 0.01398794838678441, 0.003991900566688855, 0.012693835797108477, 0.025806821759033483, 0.01575416245032102, 0.08203275909181684, 0.16791328671388328, 0.12263965865713544, 0.12872582621639594, 0.23757675953675061, 0.15447713347384706, 0.17375559196807444, 0.10642423658282496, 0.14071652811253443, 0.10636025603162125, 0.13627931621158496, 0.10029720637248829, 0.0880274421069771, 0.15753614745335653, 0.12564993579871953, 0.16417976439697668, 0.12319603934884071, 0.19947060820413753, 0.23248155950568616, 0.12919769855216146, 0.1701758278068155, 0.1985099574085325, 0.15845419897232205, 0.11736045795259997, 0.19884289969922975, 0.11341176475980319, 0.11669727478874847, 0.13709599035792053, 0.11767169984523207, 0.16181718179723248, 0.1550193762523122, 0.0972068143892102, 0.22944893629755825, 0.09793551434995607, 0.149704352079425, 0.14812923269346356, 0.16469520080136135, 0.19735164300072938, 0.09231379022821784, 0.1368172693764791, 0.1119797166029457, 0.11583834275370464, 0.13477432978106663, 0.1682431565131992, 0.12570335558848456, 0.11304551488137804, 0.15743413183372468, 0.22272809146670625, 0.17841619031969458, 0.16341507027391344, 0.08343684312421829, 0.12175775715149939, 0.11629220316535793, 0.10774625392514281, 0.11385441874153912, 0.07646485551958904, 0.09383335243910551, 0.14773878880077973, 0.20472596370382234, 0.16579424729570746, 0.1800346066011116, 0.3071419720072299, 0.1756649449816905, 0.24382832954870537, 0.15669260756112635, 0.26061183598358184, 0.16129521449329332, 0.2407237031729892, 0.1889301964547485, 0.16685158509062603, 0.4628451482858509, 0.9739927109330893, 0.4252925352193415, 0.5686255940236151, 0.7169639936182648, 0.5264523101504892, 0.645154615631327, 1.6175859072245657, 3.576848767697811, 5.46671868301928, 4.06886869110167, 3.0990063585340977, 3.589217341504991, 10.481842998415232, 20.976525507867336, 27.527579180896282, 34.67817798256874, 32.53116779029369, 40.04607014358044, 30.676529109477997, 13.950331080704927, 7.128752348944545, 0.7262327650096267, 0.13683013821719214, 0.42170095606707036, 0.26794651115778834, 0.27938446146436036, 0.5669828352984041, 1.1322513688355684, 0.8757124096155167, 0.5424797313753515, 0.12045468683936633, 0.14032798411790282, 0.2965065208263695, 0.15037232951726764, 0.1101226033642888, 0.3364131966372952, 0.2887003740761429, 0.24889752472518012, 0.1970668215653859, 0.2902693930082023, 0.15193293249467388, 0.1772423947113566, 0.12218321557156742, 0.14498322416329756, 0.20061372342752293, 0.1681699213804677, 0.13704028475331143, 0.1338539776043035, 0.17723632394336164, 0.12715573859168217, 0.1375181833282113, 0.12362724199192598, 0.09127470926614478, 0.08142392340232618, 0.11504590715048835, 0.11408790582208894, 0.09400873677805066, 0.2464188405429013, 0.10379091108916327, 0.12019646397675388, 0.2349022077396512, 0.18119744810974225, 0.10137804056284949, 0.13854942721081898, 0.08825263197650202, 0.17848814895842224, 0.1615674194181338, 0.12444922991562635, 0.13171035825507715, 0.09432131453650072, 0.13424704869976267, 0.11600489553529769, 0.12075418795575388, 0.1359004498226568, 0.15548698866041377, 0.12816225411370397, 0.13630545465275645, 0.17506776843219995, 0.12079162188456394, 0.1270606546313502, 0.20062288152985275, 0.09284865605877712, 0.07442403846653178, 0.13197526044677943, 0.1681327843107283, 0.09737150438013487, 0.13573278381954879, 0.12591673788847402, 0.10898915090365335, 0.08796849331702106, 0.27187229425180703, 0.1730820632656105, 0.10839762951945886, 0.14202742808265612, 0.13466648088069633, 0.1831281156046316, 0.09653380519011989, 0.21865586779313162, 0.12430146089172922, 0.14954982209019363, 0.08564361181925051, 0.07458649459294975, 0.07923115903395228, 0.2063229022314772, 0.0940099910076242], [0.00821190393253346, 0.03953418447053991, 0.017392026711604558, 0.047123950644163415, 0.03203952823241707, 0.010060855402116431, 0.0216957689190167, 0.016763987950980663, 0.02702571397094289, 0.021582270419457927, 0.021477045011124574, 0.044864890223834664, 0.08763467529206537, 0.03174288438458461, 0.022223782871151343, 0.0255207850568695, 0.0635264978336636, 0.08221587660955265, 0.027290514117339626, 0.010610873105179053, 0.013208682194090215, 0.039702767026028596, 0.0494727923796745, 0.005365497172533651, 0.04769000152009539, 0.0028235908212081995, 0.055385620216839015, 0.027303518400003668, 0.01499181908002356, 0.05588799853285309, 0.01405492628691718, 0.07270819303812459, 0.04756430767884012, 0.02391616715613054, 0.09802276123082265, 0.04433209127455484, 0.007538162326454767, 0.021628860595228616, 0.08369111033971421, 0.02166325914004119, 0.017139451592811383, 0.0038616828715021256, 0.04792419735167641, 0.023343477769230958, 0.12533479020930827, 0.06550711928866804, 0.06508340491564013, 0.04457251001440454, 0.024843664359650575, 0.02187882892030757, 0.021676016658602748, 0.037260188328218646, 0.030246035603340715, 0.027243495351285674, 0.02666055876034079, 0.0314688055368606, 0.010024939165305113, 0.11304181156447157, 0.04287713672965765, 0.0693178694928065, 0.04293929159757681, 0.036509602432488464, 0.0708586719701998, 0.025173456233460456, 0.4552411031909287, 0.32072410569526255, 0.25429657485801727, 0.350388401420787, 0.195792093873024, 1.2832557410001755, 4.400626039132476, 22.224418446421623, 36.68228544294834, 45.80643564462662, 46.67704872786999, 50.97901828587055, 81.48003101348877, 92.03618377447128, 111.15359634160995, 113.45415249466896, 112.83362299203873, 106.61815211176872, 101.105225533247, 127.61853843927383, 128.9816164970398, 131.00856453180313, 141.96415185928345, 134.48493719100952, 126.22103422880173, 129.80719059705734, 127.58063167333603, 100.25486916303635, 69.84883233904839, 66.0687343776226, 68.763397783041, 52.442821338772774, 51.06387533247471, 48.4370306879282, 28.126294054090977, 12.189345974475145, 3.806600826792419, 0.6742526823654771, 0.35106046067085117, 0.4725252772914246, 0.26420831331051886, 0.025931910749932285, 0.031208779255393893, 0.04458468494703993, 0.06440592798753642, 0.06057097634766251, 0.2196788293076679, 0.03880188138282392, 0.030143038493406493, 0.017630423099035397, 0.02959098081191769, 0.019995380571344867, 0.02255966406664811, 0.07622704913956113, 0.07097829875419848, 0.05411504484072793, 0.06680023740045726, 0.03349197060742881, 0.05868428110261448, 0.06248613295610994, 0.027524645010998938, 0.08177122625056654, 0.021792672996525653, 0.036761312949238345, 0.03426179297093768, 0.0807649630587548, 0.04777730777277611, 0.06820492999395356, 0.11496715786051936, 0.04052094773214776, 0.039905944795464166, 0.10175150411669165, 0.011945819587708684, 0.028312531248957384, 0.04446290593477897, 0.006578724942301051, 0.06575685198185965, 0.051339338315301575, 0.018742848660622258, 0.033480419078841805, 0.025498620816506445, 0.08705577041837387, 0.02048193073278526, 0.040012899407884106, 0.028673317065113224, 0.017574246230651625, 0.020721334585687146, 0.0357836447074078, 0.04231173523294274, 0.0024516607300029136, 0.04833424878597725, 0.009923915240506176, 0.03167221337207593, 0.08103540909360163, 0.03179458239173982, 0.04395974836370442, 0.01673918352025794, 0.06494109809864312, 0.027030092642235104, 0.03322503493109252, 0.06850826801382937, 0.007336881208175328, 0.03707568670506589, 0.07161234520026483, 0.06741716992110014, 0.04789606624399312, 0.07394814369035885, 0.03543718790751882, 0.1176160090835765, 0.03949784149881452, 0.052839816198684275, 0.06285294686676934, 0.04554522813123185, 0.03807990156929009, 0.024770618474576622, 0.036009662071592174, 0.0726556267181877, 0.0354887820139993, 0.023435507791873533, 0.05165111455426086, 0.056404974893666804, 0.03737808219739236, 0.035736403297050856, 0.021137247131264303, 0.0344387321092654, 0.036088719352846965, 0.012076324401277816, 0.05987865646602586, 0.04635747907741461, 0.030395756475627422, 0.03350006743858103, 0.04007683171948884, 0.028500793705461547, 0.11085165955591947, 0.03928143865778111, 0.03594688379962463, 0.05435680315713398, 0.024380747890972998, 0.003987842410424491, 0.03277053256169893, 0.01824518298235489, 0.025803407879720908, 0.03525012587488163, 0.029971819458296522, 0.0120818608229456, 0.020729329371533822, 0.08294595696497709, 0.013433285766950576, 0.03334144450491294, 0.04007328796433285, 0.030217388703022152, 0.013509436612366699, 0.02089534780679969, 0.013358994001464453, 0.04971516667865217, 0.06555503234267235, 0.03526594846334774, 0.019464668912405614, 0.01599494855327066, 0.021188820828683674, 0.0547911153989844, 0.056438197134411894, 0.02746703765296843, 0.05237148390733637, 0.06448737127357163, 0.029845151548215654, 0.007060107436700491, 0.02824939674610505, 0.049319375611958094, 0.053830356991966255, 0.08154713475960307, 0.05856751529790927, 0.02244407827674877, 0.03807731518463697, 0.12932009354699403, 0.09803435357753187, 0.3662051120772958, 0.1814413772081025, 0.3036354429787025, 0.48160382139030844, 0.23198979761218652, 0.833418897818774, 2.6957475347444415, 19.73112143576145, 34.57073874771595, 44.05620016157627, 46.111779659986496, 55.5804193764925, 91.25683799386024, 105.02029985189438, 125.77384382486343, 125.46618953347206, 128.55588734149933, 116.49572968482971, 116.01981282234192, 144.27869886159897, 151.99755907058716, 149.94805544614792, 163.58752995729446, 159.83380258083344, 152.0138069987297, 153.06312829256058, 150.20324975252151, 115.98677739501, 72.90930971503258, 75.73363736271858, 76.77301079034805, 54.139080718159676, 53.12417797744274, 47.97086410224438, 26.88408751040697, 9.402976389974356, 2.1217543724924326, 0.43555091600865126, 0.2860277221770957, 0.38813236984424293, 0.25709283887408674, 0.11131508625112474, 0.02229617937700823, 0.07207471062429249, 0.04937561556289438, 0.11800550302723423, 0.2467452667769976, 0.036435057409107685, 0.036710119602503255, 0.020637844827433582, 0.0903134944383055, 0.02136270974006038, 0.03115837629593443, 0.0411224621348083, 0.09846798304351978, 0.0077065166715328814, 0.059435308576212265, 0.03984456918260548, 0.07225224719149992, 0.07741639274172485, 0.025494008368696086, 0.04521273112914059, 0.057852619283949025, 0.021589901552943047, 0.017937833654286806, 0.06494593690149486, 0.0685910545871593, 0.04092370014404878, 0.043462854519020766, 0.05817494144139346, 0.03675753541756421, 0.08799589340924285, 0.0504340702900663, 0.032755288848420605, 0.06117564858868718, 0.015313810981751885, 0.012739106805383926, 0.016203744380618446, 0.03611374086176511, 0.03626827085099649, 0.043586273677647114, 0.04843326983973384, 0.02782752661005361, 0.0604796179686673, 0.022393168801499996, 0.02393044236669084, 0.022429886557802092, 0.0741060652944725, 0.03038882110558916, 0.07002713260590099, 0.01386336127325194, 0.022864020684210118, 0.00772049548686482, 0.04003929760074243, 0.02107769534632098, 0.04980314086424187, 0.038145815415191464, 0.057071672126767226, 0.07093133564922027, 0.04138182048336603, 0.10223028584732674, 0.03113758131803479, 0.043128186734975316, 0.03547242878994439, 0.052534251735778525, 0.0516452849842608, 0.02506949989765417, 0.019611042698670644, 0.052229982320568524, 0.09268756548408419, 0.007952799769554986, 0.04052679956657812, 0.13050999375991523, 0.12217291456181556, 0.06583688518730924, 0.14431760675506666, 0.13358619587961584, 0.18154573801439255, 0.095778729300946, 0.11744918170734309, 0.21704387851059437, 0.13044559018453583, 0.08454524067929015, 0.11219249034184031, 0.19619249738752842, 0.12412474810844287, 0.09614061535103247, 0.30585865024477243, 0.15094888920430094, 0.27831259241793305, 0.1382431131787598, 0.05996596271870658, 0.10648526338627562, 0.19686706509673968, 0.13363431673496962, 0.09438956243684515, 0.1678790440200828, 0.09806628819205798, 0.10594333230983466, 0.1909818488638848, 0.10131634582648985, 0.15928595355944708, 0.21700942801544443, 0.13973837747471407, 0.12837560672778636, 0.17527470889035612, 0.13643372745718807, 0.13366136059630662, 0.14360002416651696, 0.1706343563273549, 0.19745046738535166, 0.16937430831603706, 0.12298115791054443, 0.12667979928664863, 0.134465774463024, 0.157095133617986, 0.1863267572480254, 0.13037803990300745, 0.1188567241479177, 0.09030667410115711, 0.14012856903718784, 0.09711840233649127, 0.13625308871269226, 0.22317599243251607, 0.10720425605541095, 0.12088666131603532, 0.0955767538107466, 0.17090342938899994, 0.2370867639547214, 0.1362263862392865, 0.1790169143350795, 0.19902769447071478, 0.18557165167294443, 0.14883737516356632, 0.208879318961408, 0.245844982273411, 0.8450807095505297, 0.706930038286373, 0.5381931457668543, 0.6786231009755284, 0.235921339772176, 2.502912157215178, 7.103039128705859, 33.632550090551376, 53.02500709891319, 65.33744841814041, 66.89021989703178, 77.47117772698402, 115.96816599369049, 128.83606910705566, 150.37413418293, 152.5437569618225, 157.1547183394432, 142.6234620809555, 142.5552025437355, 172.02370047569275, 171.5844440460205, 176.01596385240555, 188.21736752986908, 184.3300697207451, 178.1697642803192, 182.8717839717865, 176.99833273887634, 147.58877724409103, 106.01784512400627, 101.9160184264183, 108.07215169072151, 78.45760479569435, 79.48944702744484, 73.00052762031555, 42.97576613724232, 19.030083753168583, 6.266600461676717, 0.7380967971403152, 0.374208491994068, 0.601300218841061, 0.7686783873941749, 0.23722024663584307, 0.10142796483705752, 0.11502819950692356, 0.18656794039998204, 0.22654777712887153, 0.5049575760494918, 0.11507681017974392, 0.2053791724028997, 0.09706673401524313, 0.10386530397227034, 0.14313842315459624, 0.09869138433714397, 0.1516276426264085, 0.20784059423021972, 0.11869331807247363, 0.19452502514468506, 0.12447493048966862, 0.19262389512732625, 0.178566460381262, 0.08383629668969661, 0.16632933577056974, 0.11845231303595938, 0.16649008495733142, 0.09343460391392, 0.16378874162910506, 0.09481630477239378, 0.1743854972301051, 0.21395298186689615, 0.18211904709460214, 0.10729652727604844, 0.15907261578831822, 0.07158416585298255, 0.08377639795071445, 0.1534739279304631, 0.06738351352396421, 0.1680720766307786, 0.07401420225505717, 0.13291720912093297, 0.12701073777861893, 0.11921868441277184, 0.16131234326167032, 0.10696073513827287, 0.1707414779230021, 0.12213118359795772, 0.09691121696960181, 0.2773652854375541, 0.15062949853017926, 0.16359732690034434, 0.11509402800584212, 0.1841866408358328, 0.0697404112725053, 0.16572200664086267, 0.18571476743090898, 0.17141306219855323, 0.15445742203155532, 0.1070390317181591, 0.12670881726080552, 0.20169515133602545, 0.1685864443425089, 0.13925991486757994, 0.1790897487080656, 0.1568751610466279, 0.307205113931559, 0.14893536834279075, 0.13501301931682974, 0.1330644660629332, 0.16894741012947634, 0.17983118392294273, 0.22748136922018602, 0.09248271788237616, 0.1385786381433718], [0.008994081199489301, 0.010532346459513064, 0.02977141546580242, 0.01353876999928616, 0.05477160433656536, 0.006060543983039679, 0.05157535611942876, 0.026409723977849353, 0.05740262917242944, 0.039532084192615, 0.0302071971600526, 0.10347204733989201, 0.03898866882082075, 0.025553959058015607, 0.05253101226116996, 0.054484508218592964, 0.10849948928807862, 0.009389922361151548, 0.037516622614930384, 0.006805182028983836, 0.03184832872648258, 0.06628530565649271, 0.03013937599462224, 0.046739915196667425, 0.0304247763051535, 0.02971717931359308, 0.058839902048930526, 0.015443839893123368, 0.042439206517883576, 0.02357319102884503, 0.027484455858939327, 0.04836508502194192, 0.034861077219829895, 0.058161682973150164, 0.019384739607630763, 0.040810886275721714, 0.03810345362580847, 0.04661799888708629, 0.0446558903058758, 0.006580184654012555, 0.04918028600513935, 0.055316433499683626, 0.07111798578989692, 0.028380786570778582, 0.029012278173468076, 0.0361742518725805, 0.059889506665058434, 0.05304219987010583, 0.04553626298729796, 0.08607371608377434, 0.04893865014309995, 0.029925594790256582, 0.04433831789356191, 0.02505591488443315, 0.09425302210729569, 0.0236208035130403, 0.06970071379328147, 0.03900507770595141, 0.10931346943834797, 0.15292549564037472, 0.0626052328152582, 0.17600355728063732, 0.7723234605509788, 2.2858735034242272, 8.160304371267557, 10.660316571593285, 11.681219190359116, 36.24925307929516, 55.3819864243269, 83.66948112845421, 95.63889965415001, 106.58824771642685, 122.10240483283997, 111.23225212097168, 120.61725452542305, 111.54541611671448, 110.60478419065475, 110.24382635951042, 106.86168864369392, 97.72713840007782, 108.81231397390366, 106.76713451743126, 101.09859108924866, 97.38020941615105, 90.65892487764359, 104.40040871500969, 93.20532783865929, 97.7884367108345, 98.81520241498947, 93.45327213406563, 76.77041932940483, 103.19263592362404, 110.40847912430763, 106.5695071220398, 122.39706382155418, 125.78871622681618, 124.56615462899208, 115.21323770284653, 120.57334408164024, 115.57029694318771, 114.66644704341888, 66.06337666511536, 46.74767553806305, 26.37027148157358, 8.165872972458601, 0.771615511039272, 0.5326459184288979, 0.37775459233671427, 0.23363770684227347, 0.04193347740510944, 0.09159041146631353, 0.088639988534851, 0.129040882748086, 0.1285857384209521, 0.07902432247647084, 0.04681079401052557, 0.024440314518869855, 0.04199163580778986, 0.024995548592414707, 0.03956240092520602, 0.12663950066780671, 0.023591742865392007, 0.05107669967401307, 0.05086986311653163, 0.03698943059134763, 0.012783658858097624, 0.04962005674315151, 0.04658657264371868, 0.029654076352017, 0.021168647399463225, 0.19053681258810684, 0.050482454607845284, 0.03173072429490276, 0.03721454253536649, 0.025604872244002763, 0.025354360295750666, 0.028080752963433042, 0.10630079515976831, 0.044342915498418733, 0.05284445462166332, 0.020846245461143553, 0.06367209978634492, 0.06284896895522252, 0.061933488977956586, 0.04151498033024836, 0.03347731690155342, 0.05255522482912056, 0.015944391598168295, 0.05171761840756517, 0.04177849470579531, 0.05688823919626884, 0.05689325611456297, 0.034185719123343006, 0.03666734592115972, 0.04602383545716293, 0.011852321040350944, 0.03712374447786715, 0.027174444076081272, 0.02719088450248819, 0.049206064504687674, 0.05401874004746787, 0.05487290007295087, 0.028182557070977055, 0.037568116531474516, 0.008802017091511516, 0.05161224828043487, 0.02103683269524481, 0.03583658952265978, 0.035607599857030436, 0.0016070012384261645, 0.038183638971531764, 0.03897937713190913, 0.029872110062569845, 0.05339647519576829, 0.09046497420058586, 0.014859357779641869, 0.032031167938839644, 0.016400758613599464, 0.04666190805437509, 0.06375572498654947, 0.06188126775668934, 0.00705198741343338, 0.036584600165952, 0.016901311246328987, 0.04183017044852022, 0.029756615185760893, 0.022442870431405026, 0.06554692809004337, 0.07676158100366592, 0.09607048981706612, 0.04295558173907921, 0.02717899900744669, 0.06763987359590828, 0.0322497081651818, 0.0465449826879194, 0.054985346578177996, 0.01303635550357285, 0.032325166030204855, 0.021833377941220533, 0.08257720604888164, 0.07448370713973418, 0.06185718135384377, 0.05145516901393421, 0.03880325435602572, 0.05420824003522284, 0.02677910386410076, 0.04818560402782168, 0.07426421696436591, 0.014094899288465967, 0.053960091827320866, 0.03638198642875068, 0.020664782932726666, 0.031008462465251796, 0.013187435433792416, 0.060992980070295744, 0.021975130002829246, 0.11271092502283864, 0.11846818757476285, 0.03936207671358716, 0.039687549287918955, 0.017267737384827342, 0.021782292205898557, 0.06827306657214649, 0.05412460370280314, 0.016160594059329014, 0.008793223569227848, 0.09390119957970455, 0.029540824616560712, 0.01403118312737206, 0.041933974644052796, 0.10189706896198913, 0.057386131229577586, 0.06875020073493943, 0.06641186409979127, 0.1170174744038377, 0.2557651366805658, 0.06257508677663282, 0.18652738945093006, 0.24496838712366298, 1.4431021199561656, 6.535681122913957, 7.741793878376484, 11.688007526099682, 34.49961796402931, 57.34661020338535, 90.19121557474136, 111.87296614050865, 126.39428213238716, 141.51448398828506, 132.78939217329025, 138.69073390960693, 126.88401505351067, 124.15844410657883, 124.50529709458351, 121.35436937212944, 120.74357494711876, 125.87927296757698, 126.32167562842369, 122.58510053157806, 117.37077713012695, 112.21012204885483, 129.86072212457657, 115.256517380476, 111.42959833145142, 114.00597408413887, 115.49860998988152, 101.02922961115837, 124.12385076284409, 134.65550243854523, 133.03447902202606, 144.83275473117828, 150.39904564619064, 145.82399994134903, 140.15718162059784, 143.41096222400665, 134.18990582227707, 126.4713191986084, 71.34668156504631, 47.88580946624279, 27.235564850270748, 6.966063128784299, 0.40525742748286575, 0.29900651948992163, 0.3428721078671515, 0.3075125114992261, 0.03552017114998307, 0.0674945091304835, 0.07788491056999192, 0.1309938295162283, 0.1021313427190762, 0.06285918090725318, 0.031662821493227966, 0.012026775839331094, 0.03923477983335033, 0.06652061099885032, 0.024046467879088596, 0.04251562546414789, 0.04789720172993839, 0.04808833444258198, 0.11910783723578788, 0.07252985495142639, 0.05815436910779681, 0.037319756811484694, 0.09512454096693546, 0.039114908140618354, 0.04667388631787617, 0.01703516871202737, 0.04880858505202923, 0.008308390551974298, 0.0539291887980653, 0.020150942145846784, 0.056572177054476924, 0.034382250960334204, 0.04645863751647994, 0.038844907394377515, 0.05004484351957217, 0.04648022659239359, 0.0744058632699307, 0.027791725406132173, 0.03736364742508158, 0.04634782744687982, 0.027382373446016572, 0.011540772084117634, 0.011467136191640748, 0.04739641532069072, 0.07153614147682674, 0.015151314037211705, 0.03369811696757097, 0.03855704686429817, 0.017872248208732344, 0.020013442590425257, 0.012912169149785768, 0.06332458171527833, 0.014948107509553665, 0.014346073603519471, 0.017159124072350096, 0.012771159235853702, 0.020429679825610947, 0.011497986342874356, 0.0219857853880967, 0.05609239713521674, 0.033717461046762764, 0.053749589060316794, 0.03945286734960973, 0.039994319740799256, 0.06362273212289438, 0.00645835183604504, 0.005330150070221862, 0.052343798088259064, 0.08230140170780942, 0.007949343216751004, 0.009813933593250113, 0.21513268497074023, 0.05975950094580185, 0.13044429884757847, 0.09452077414607629, 0.17757579713361338, 0.11803069894085638, 0.18573364766780287, 0.14932346704881638, 0.16640788468066603, 0.128133651742246, 0.10033966464106925, 0.16895264969207346, 0.13903526676585898, 0.14471158327069134, 0.14792655216297135, 0.15429550025146455, 0.12479849945520982, 0.2075805902131833, 0.14530648884829134, 0.19317905127536505, 0.08059461790253408, 0.21193849621340632, 0.1529800138087012, 0.1653602096484974, 0.17422872595489025, 0.16840056603541598, 0.207190383807756, 0.14925507071893662, 0.16163706255611032, 0.10910321158007719, 0.18633980420418084, 0.17905011802213266, 0.08881306479452178, 0.1866520702606067, 0.10262318624882028, 0.10884476607316174, 0.07720632784185, 0.17196235537994653, 0.1907581655541435, 0.17012838972732425, 0.22222981351660565, 0.17135640664491802, 0.14214388589607552, 0.13025978609221056, 0.11235687605221756, 0.0882419673143886, 0.18821304431185126, 0.1865341726806946, 0.1935407888959162, 0.27381660242099315, 0.190550631377846, 0.09892739471979439, 0.19073909235885367, 0.2001813630340621, 0.2349072098149918, 0.19548051059246063, 0.2188315341481939, 0.18386825948255137, 0.7575765112414956, 0.5049885681364685, 0.2093707543099299, 0.4321461502695456, 1.6519788117147982, 6.034255279228091, 14.719241671264172, 17.93075144290924, 21.15143772214651, 50.591670870780945, 78.94195720553398, 117.37273782491684, 131.38419717550278, 144.8419350385666, 159.50771927833557, 142.89833933115005, 151.21843367815018, 138.59304875135422, 139.04607564210892, 139.0051594376564, 133.66807222366333, 125.93946933746338, 135.93382984399796, 133.6146166920662, 129.05145674943924, 124.75872829556465, 117.9057428240776, 133.29929441213608, 118.72430250048637, 125.93393683433533, 123.76386567950249, 120.64057007431984, 105.76392754912376, 135.36419481039047, 147.52568542957306, 142.31788247823715, 153.02582949399948, 164.43523406982422, 160.3697258234024, 152.43868499994278, 160.18824756145477, 154.15856391191483, 156.69588536024094, 101.14787444472313, 67.25686982274055, 45.01746878027916, 13.706587459892035, 1.1816236632876098, 0.35670817480422556, 0.5142103764228523, 0.7082621636800468, 0.18353236344410107, 0.20624417520593852, 0.23472327593481168, 0.2616375434445217, 0.24473189434502274, 0.20736805396154523, 0.20018036855617538, 0.08201658027246594, 0.08998771387268789, 0.1083018776262179, 0.14415638259379193, 0.2662902156589553, 0.15097701660124585, 0.1546347953262739, 0.20092118036700413, 0.1782030306640081, 0.18179067643359303, 0.14087456103879958, 0.17074210132705048, 0.12493414920754731, 0.156877224217169, 0.24454046477330849, 0.18798588775098324, 0.10239042647299357, 0.17038312449585646, 0.14737066871020943, 0.19631279952591285, 0.17034658114425838, 0.19517737295245752, 0.10812499414896592, 0.13773272337857634, 0.07439387758495286, 0.20594308589352295, 0.19504826894262806, 0.10472544570802711, 0.11876049728016369, 0.0992372413747944, 0.10605895891785622, 0.17005537723889574, 0.10921976587269455, 0.09385548328282312, 0.1719929912360385, 0.12251922293216921, 0.11216365048312582, 0.18840051081497222, 0.10766199789941311, 0.19524688250385225, 0.11756558757042512, 0.09528278911602683, 0.08021179586648941, 0.15484065224882215, 0.14489642257103696, 0.1540716239833273, 0.11804565321654081, 0.13348717853659764, 0.09144954441580921, 0.11640283511951566, 0.12869968777522445, 0.13094846945023164, 0.1299420281429775, 0.16837413073517382, 0.09820185630815104, 0.155371495638974, 0.11066221151850186, 0.17544518021168187, 0.07816231795004569, 0.14197918848367408], [0.0468834688217612, 0.039078554036677815, 0.041234871532651596, 0.013844221284671221, 0.1464900659630075, 0.04700945952208713, 0.007972858165885555, 0.04546067153569311, 0.03133538593829144, 0.02012478515098337, 0.04136079915042501, 0.024370105493289884, 0.03771031573705841, 0.06650754919974133, 0.011590848498599371, 0.05765765337855555, 0.0577431821875507, 0.047577966906828806, 0.05839329613081645, 0.03110521996859461, 0.008961692019511247, 0.03041177202248946, 0.06346332622342743, 0.07414133957354352, 0.0438917416613549, 0.035019214046769775, 0.057327579488628544, 0.054341474096872844, 0.06457006878918037, 0.0674397534749005, 0.048413447075290605, 0.04525832868239377, 0.01687572199443821, 0.0016953662111518497, 0.039647465891903266, 0.04094924857781734, 0.02931190174422227, 0.04189649989712052, 0.029796429553243797, 0.013692190477740951, 0.020230995760357473, 0.02424864003842231, 0.1177526310493704, 0.09844018961302936, 0.026996894521289505, 0.032415377791039646, 0.02136834078555694, 0.02600258176244097, 0.023191549007606227, 0.03176150858053006, 0.04591644297761377, 0.03078773104789434, 0.029806229613313917, 0.05063308461103588, 0.01151253707575961, 0.03018317755049793, 0.131797946523875, 0.5906879820395261, 4.687453173100948, 12.814942505210638, 30.148955918848515, 63.89321431517601, 75.34275233745575, 92.00968399643898, 100.80080106854439, 92.93700143694878, 102.9644125699997, 96.48741692304611, 96.75664767622948, 96.73071786761284, 92.43938773870468, 102.04382836818695, 97.53302961587906, 90.23496642708778, 96.54508262872696, 105.74324905872345, 89.674162119627, 94.25154089927673, 100.35732686519623, 65.13339936733246, 92.1548818051815, 86.07154503464699, 63.46174366772175, 78.19630041718483, 84.29099097847939, 71.370939463377, 55.43340906500816, 75.55437058210373, 67.45317488908768, 60.189321264624596, 52.0694799721241, 60.226741656661034, 65.23815214633942, 64.22519490122795, 88.94068747758865, 70.63520774245262, 85.14223650097847, 100.47557651996613, 95.07156729698181, 102.72187918424606, 97.65033692121506, 104.2642392218113, 113.50058600306511, 114.95453998446465, 98.47892805933952, 69.44604635238647, 51.56507983803749, 31.006442606449127, 7.778410613536835, 0.7232650648802519, 0.46100200968794525, 0.07810223367414437, 0.04639015955035575, 0.20522649778285995, 0.1924523847992532, 0.051373339811107144, 0.027513438581081573, 0.06544494215631858, 0.026285881795047317, 0.04186388621747028, 0.012022761748085031, 0.03428261021326762, 0.038531940008397214, 0.015310814560507424, 0.047870977941784076, 0.03940454240364488, 0.051635859708767384, 0.03721312874404248, 0.05139037952176295, 0.05446268907689955, 0.026708692603278905, 0.04218782254611142, 0.05269677836622577, 0.06060638421331532, 0.0417942987405695, 0.04341340150858741, 0.03034553719771793, 0.0520413358026417, 0.028377589769661427, 0.019413568334130105, 0.016428772833023686, 0.005224244205237483, 0.06124113941041287, 0.020986470553907566, 0.016934327541093808, 0.02155240083084209, 0.01766097360814456, 0.052607754041673616, 0.032306987122865394, 0.03646865443442948, 0.04483322278247215, 0.0660127964511048, 0.0639179658901412, 0.06198538736498449, 0.02325515106349485, 0.0892795565596316, 0.06229702630662359, 0.03470996853138786, 0.05358084323233925, 0.04323202061641496, 0.0427631910861237, 0.03371565391717013, 0.0608080554229673, 0.017886640307551716, 0.10656760467099957, 0.07125935007934459, 0.05810625196318142, 0.04103013896383345, 0.06289743119850755, 0.0270758182159625, 0.08937700797105208, 0.016645561590848956, 0.05122932234371547, 0.06278688088059425, 0.06296838051639497, 0.01219049547216855, 0.026550026996119414, 0.02089758538204478, 0.04117339944059495, 0.04498423128097784, 0.04928308830130845, 0.051207814904046245, 0.032227681222138926, 0.007559445730294101, 0.02156908802135149, 0.005890170532438788, 0.019773702915699687, 0.04002058434707578, 0.10619168460834771, 0.02429998552543111, 0.059549250509007834, 0.0601665392605355, 0.025490620464552194, 0.04180427691608202, 0.01707843221083749, 0.06335673897410743, 0.05260527155769523, 0.018770057649817318, 0.040321859196410514, 0.04143832760746591, 0.07021864381385967, 0.0825130548037123, 0.05012000823626295, 0.020798415898752864, 0.04195370464003645, 0.02542336889746366, 0.044303269969532266, 0.012801167977158912, 0.016984975409286562, 0.027262086150585674, 0.06243937023100443, 0.041339299132232554, 0.025707251515996177, 0.026602277903293725, 0.0362825423508184, 0.05036734750319738, 0.011765006438508863, 0.05043401091825217, 0.12464616622310132, 0.016153662400029134, 0.02202474443038227, 0.03807817607594188, 0.06487589300377294, 0.05231714756519068, 0.05497858190210536, 0.020839742392126936, 0.11803886998677626, 0.028543984844873194, 0.07987871998921037, 0.03722475448739715, 0.0197310516887228, 0.023275754938367754, 0.035892265441361815, 0.7899067201651633, 2.945152376778424, 9.243201613426208, 26.151169538497925, 58.042368069291115, 73.98539677262306, 95.9955333173275, 106.89619839191437, 110.26857063174248, 112.72005468606949, 118.14197614789009, 111.81849226355553, 115.78837484121323, 104.42667290568352, 118.8790225982666, 117.1085000038147, 113.85611772537231, 122.3125259578228, 141.29143595695496, 124.90373611450195, 138.96533757448196, 153.7994223833084, 96.36099770665169, 140.19226133823395, 134.29792642593384, 108.23664486408234, 127.01983496546745, 134.75501149892807, 116.21177092194557, 106.81071817874908, 128.4959265589714, 129.53895539045334, 96.96229264140129, 92.18037843704224, 106.97860077023506, 100.81631183624268, 110.31906992197037, 134.124336540699, 102.15649992227554, 107.88647085428238, 124.34611603617668, 119.63044747710228, 119.84674707055092, 117.18369036912918, 121.71984136104584, 133.9692896604538, 133.74303460121155, 115.72501704096794, 79.0561106801033, 59.58135008811951, 33.226363286376, 7.403817214071751, 0.25669282127637416, 0.4024166049202904, 0.12674760189838707, 0.03335760848131031, 0.06613861274672672, 0.1994222795474343, 0.10778037787531503, 0.04319990417570807, 0.02318743194337003, 0.06873890524730086, 0.04275244478776585, 0.04370710645162035, 0.0571643441071501, 0.022575575712835416, 0.015467680459551048, 0.031564357050228864, 0.031479551835218444, 0.061569443278131075, 0.06471711792983115, 0.06545295735122636, 0.08026521565625444, 0.03422393601795193, 0.03511732596962247, 0.03864708050969057, 0.056399961686111055, 0.054965572053333744, 0.0703987482120283, 0.03791355287830811, 0.07347708771703765, 0.046789720727247186, 0.04381594611913897, 0.0543901292985538, 0.04107730244868435, 0.039868180610938, 0.021522234383155592, 0.01744994577165926, 0.08388178292079829, 0.03646476186986547, 0.046987744281068444, 0.06309862743364647, 0.10655029778718017, 0.06425257059163414, 0.0013289452908793464, 0.018259753196616657, 0.011819619230664102, 0.07307973442948423, 0.06308083815383725, 0.006581361421922338, 0.04826539974601474, 0.061397847603075206, 0.01637090572330635, 0.01985368046007352, 0.03659359128505457, 0.01733681834593881, 0.012976646012248239, 0.09557569253956899, 0.04764824087033048, 0.03511093236738816, 0.07491205251426436, 0.0480381801025942, 0.016290340026898775, 0.09080694100703113, 0.040907847869675606, 0.056162767577916384, 0.010707652872952167, 0.0741159358585719, 0.038345608991221525, 0.14896493550622836, 0.15066258347360417, 0.09139048430370167, 0.15205648523988202, 0.21547750162426382, 0.17240093497093767, 0.1330031201359816, 0.13999778777360916, 0.11288468405837193, 0.12516770308138803, 0.17108013475080952, 0.09901785510010086, 0.1912271583569236, 0.1310409707366489, 0.19185035460395738, 0.13690467952983454, 0.11976847483310848, 0.11698704634909518, 0.17863286775536835, 0.16756290395278484, 0.11288252440863289, 0.1998501573689282, 0.14458146994002163, 0.1955675199860707, 0.19651312002679333, 0.22167961491504684, 0.1556429881020449, 0.12885878939414397, 0.1259605394443497, 0.12503166741225868, 0.143403087859042, 0.09049584754393436, 0.12293832856812514, 0.10389573202701285, 0.15375711664091796, 0.13110807572957128, 0.10448246655869298, 0.176923033723142, 0.14828659768681973, 0.14888033067109063, 0.10132313647773117, 0.12579290312714875, 0.22094943065894768, 0.11483641370432451, 0.10334611230064183, 0.15823467168956995, 0.18647447432158515, 0.1869410031940788, 0.0913546459923964, 0.1118322741240263, 0.20731556927785277, 0.14307424222351983, 0.17630543326959014, 0.11005152788129635, 0.10623314839904197, 0.4573632893152535, 0.20279433141695336, 2.4831375433132052, 15.392500944435596, 30.736195407807827, 53.50225009024143, 87.83748507499695, 107.28161171078682, 125.95761716365814, 132.1373775601387, 127.97623604536057, 136.6351506114006, 128.82369697093964, 123.82577955722809, 121.02317914366722, 113.87178048491478, 124.15289640426636, 118.38947966694832, 115.19410952925682, 123.64662677049637, 134.27985459566116, 118.14028143882751, 123.10406908392906, 127.2737829387188, 91.38648703694344, 122.7379435300827, 118.3153684437275, 90.99132344126701, 106.31914615631104, 111.43323853611946, 98.02128821611404, 85.68828240036964, 103.4636601805687, 101.88959464430809, 91.94342315196991, 77.56487309932709, 90.37900149822235, 93.21891590952873, 92.28133141994476, 121.7037758231163, 101.50496408343315, 114.54860016703606, 130.42693734169006, 123.87171149253845, 131.7646935582161, 123.9296355843544, 133.6929228901863, 147.5017163157463, 153.7633091211319, 137.05425292253494, 99.06045645475388, 80.9408551454544, 49.736921936273575, 14.963176231831312, 1.2361387442797422, 0.5901106505189091, 0.26795399200636894, 0.10921867491560988, 0.30967961240094155, 0.334877633722499, 0.14038177498150617, 0.12221662705997005, 0.1325984121649526, 0.22275920229731128, 0.147334644861985, 0.13614586321637034, 0.14792276720982045, 0.1022380858194083, 0.13735289219766855, 0.17064410814782605, 0.0880996827618219, 0.23020367079880089, 0.10517325019463897, 0.15198737644823268, 0.16716733924113214, 0.08023008980671875, 0.15148160280659795, 0.14372976642334834, 0.23090880014933646, 0.13280133018270135, 0.1287324758595787, 0.07180926666478626, 0.17444209341192618, 0.17965967359486967, 0.1725160123896785, 0.17457426991313696, 0.10499310868908651, 0.14463227736996487, 0.08682202358613722, 0.08090423449175432, 0.14358492888277397, 0.13781652669422328, 0.2386788636795245, 0.11589365502004512, 0.19162656739354134, 0.15788270073244348, 0.150792533531785, 0.1499867541133426, 0.19833777914755046, 0.11303990424494259, 0.16569825791520998, 0.18511015456169844, 0.12739598663756624, 0.16750630777096376, 0.11114324937807396, 0.13534233992686495, 0.15333833754993975, 0.1698139269137755, 0.09813086246140301, 0.157781753805466, 0.27939229854382575, 0.12927304138429463, 0.12499211094109342, 0.11600131096201949, 0.10582645147223957, 0.18941516027553007, 0.17845963564468548, 0.22781848238082603, 0.18244436010718346, 0.17408575862646103, 0.10013175196945667], [0.03629951526818331, 0.029219055359135382, 0.016853377783263568, 0.03697717773320619, 0.08367136179003865, 0.02876717091567116, 0.045007178487139754, 0.0725663018238265, 0.028920446675329003, 0.05831118120113388, 0.03845415179966949, 0.10318692162400112, 0.04345659450336825, 0.004323409584685578, 0.008666899830132024, 0.029274694170453586, 0.026876939336943906, 0.005056046175013762, 0.057852136887959205, 0.016803854268800933, 0.03186824054864701, 0.11463531394838355, 0.0708804911118932, 0.047220507767633535, 0.024915930989664048, 0.044557707878993824, 0.04386901709949598, 0.030677280919917393, 0.05908103696128819, 0.05734506077715196, 0.02324864613910904, 0.10547723388299346, 0.02881795237044571, 0.03001454118930269, 0.044675809549517, 0.06929987983312458, 0.036842997433268465, 0.1269746248726733, 0.06698762226733379, 0.03429440293984953, 0.07978770299814641, 0.028624546830542386, 0.060063800046918914, 0.049742993505788036, 0.015004242632130627, 0.07455141327227466, 0.0956831406801939, 0.04759820156323258, 0.01626963039598195, 0.08413008326897398, 0.030858114478178322, 0.04389381596411113, 0.05256417141936254, 0.07723801012616605, 0.02600245559733594, 2.0244767423719168, 17.79541790485382, 49.40467916429043, 81.42707705497742, 97.32334926724434, 99.65475976467133, 95.23781597614288, 93.85323867201805, 80.09194269776344, 96.83715015649796, 93.72647747397423, 69.80628222227097, 75.56041985750198, 83.8959413766861, 52.6873230189085, 68.168456107378, 40.3521703183651, 43.88301685452461, 31.213729083538055, 32.67573483288288, 29.719113484025, 33.27697657048702, 30.824622362852097, 21.548693105578423, 34.24969397485256, 23.33703674376011, 27.355710603296757, 21.197645142674446, 15.660149082541466, 28.601441457867622, 28.211196698248386, 26.58293467015028, 24.32940099388361, 14.9584929831326, 37.29985490441322, 22.61157777160406, 22.609161101281643, 28.733452074229717, 21.82512067258358, 33.32640431821346, 48.92351098358631, 55.2363820374012, 43.611939400434494, 42.6317173987627, 65.79805210232735, 80.48301011323929, 76.42752572894096, 67.54347324371338, 99.56853479146957, 102.04149529337883, 98.51404577493668, 105.86344420909882, 117.23881781101227, 95.12414127588272, 67.99959316849709, 30.243798829615116, 8.201333619654179, 0.29605606687255204, 0.4038330086041242, 0.040349070040974766, 0.13388023478910327, 0.07335259986575693, 0.01234680661582388, 0.03408633070648648, 0.02999422860739287, 0.1279755000723526, 0.04365823231637478, 0.01664307725150138, 0.016459712969663087, 0.05674947613442782, 0.06549329307745211, 0.04631078685633838, 0.012719576261588372, 0.019653090930660255, 0.08053996614762582, 0.0258136124102748, 0.00845022703288123, 0.029215086724434514, 0.026533054078754503, 0.027728563072741963, 0.07609586711623706, 0.05726880510337651, 0.020075491702300496, 0.023742588091408834, 0.02253515278425766, 0.0643667129043024, 0.02235194064269308, 0.03879128351400141, 0.021943421743344516, 0.04279960827261675, 0.020191647090541665, 0.03457106446148828, 0.04687113061663695, 0.02979092281748308, 0.04364147091109771, 0.06554482781211846, 0.019514084815455135, 0.025445223291171715, 0.01797308195818914, 0.026567667846393306, 0.023112638300517574, 0.09017570730065927, 0.014280047507782001, 0.029340543078433257, 0.0579342258424731, 0.03557438503776211, 0.06739393327734433, 0.056441662964061834, 0.030703402662766166, 0.0160477690587868, 0.033281430733040906, 0.03953155726776458, 0.0228628740660497, 0.03082408700720407, 0.02751411393546732, 0.04390446949400939, 0.014711467229062691, 0.0772508121735882, 0.04530523241555784, 0.04545628544292413, 0.08261668830527924, 0.03061989620618988, 0.07110231163096614, 0.04539599707641173, 0.05955641594482586, 0.023345309018623084, 0.02838836760929553, 0.024007677675399464, 0.022750624229956884, 0.025074164295801893, 0.036073100854991935, 0.036176875364617445, 0.05533069386729039, 0.052765211803489365, 0.004642136036636657, 0.02835385217622388, 0.008913102683436591, 0.007169457794589107, 0.06810700360802002, 0.07947440535645, 0.029245774530863855, 0.0632105655677151, 0.034209530931548215, 0.054576749753323384, 0.0328838548011845, 0.06205952049640473, 0.0346196825557854, 0.04162380144407507, 0.07725700168521143, 0.027752964888350107, 0.03258904776885174, 0.024863720900611952, 0.026791894779307768, 0.026247501627949532, 0.023848776436352637, 0.020184570712444838, 0.0417886769719189, 0.031134456876316108, 0.03431815166550223, 0.03855063099763356, 0.07581540950923227, 0.04220658403937705, 0.024971551247290336, 0.02553714941313956, 0.06465480721089989, 0.013530595242627896, 0.039455290461773984, 0.04489134778850712, 0.04782266041729599, 0.08843862902722321, 0.05413562088506296, 0.047991747633204795, 0.04566532988974359, 0.027147272194270045, 0.12290626036701724, 0.055185700475703925, 0.07777329898090102, 10.879311170428991, 40.40384754538536, 85.98644480109215, 104.95103716850281, 113.58353555202484, 114.88232105970383, 109.00945499539375, 97.50001698732376, 114.59754914045334, 107.08808809518814, 102.24413082003593, 103.75167712569237, 111.42012163996696, 90.24682939052582, 116.44423484802246, 89.52241346240044, 75.29938146471977, 68.19222003221512, 59.19835343956947, 56.27243064343929, 51.33448161184788, 53.30947123467922, 44.1567275673151, 49.00125101208687, 44.25894968211651, 45.54540865123272, 35.39922349154949, 34.22033295035362, 41.55560754239559, 38.97857442498207, 32.06069603562355, 33.237215504050255, 26.35128580033779, 50.36047227680683, 28.44227559864521, 34.03974764049053, 36.73386387526989, 31.44020263105631, 52.240018621087074, 62.16446287930012, 78.11735585331917, 76.74527987837791, 78.83319184184074, 105.65138518810272, 110.29535159468651, 108.77013623714447, 91.26984849572182, 121.17607533931732, 116.85191497206688, 116.69375985860825, 118.9609158039093, 134.53000277280807, 112.73456990718842, 78.82876127958298, 32.47643552720547, 9.107432998716831, 0.13105250371154398, 0.36304098030086607, 0.07813324060407467, 0.0716243902570568, 0.07646179787116125, 0.02186912162869703, 0.043764574656961486, 0.04617544138454832, 0.08442245976766571, 0.06259455331019126, 0.002993968678310921, 0.016674412581778597, 0.023655819895793684, 0.0622050667880103, 0.011248246228205971, 0.03249783781939186, 0.01898957008961588, 0.02325990266399458, 0.028299321020313073, 0.03272808542533312, 0.05311782100761775, 0.030062270561757032, 0.03980692374170758, 0.06892605262692086, 0.04556228268484119, 0.05297058633004781, 0.018328195910726208, 0.019541959882189985, 0.007212323780549923, 0.04969233450538013, 0.023610467251273803, 0.031719213584437966, 0.011764995306293713, 0.038311366297421046, 0.023350993869826198, 0.05378369445679709, 0.043108241516165435, 0.07402264047414064, 0.052187980472808704, 0.056312629458261654, 0.03916997920896392, 0.0039768859915056964, 0.02334828688617563, 0.005255788264548755, 0.0513143242278602, 0.021944726067886222, 0.023107925662770867, 0.055032591699273326, 0.06985761865507811, 0.03418398249777965, 0.01829145403462462, 0.021167031372897327, 0.006676873044852982, 0.10385625719209202, 0.04533219092991203, 0.03876265145663638, 0.039938421177794226, 0.023023573157843202, 0.04399775745696388, 0.061742783000227064, 0.08268671736004762, 0.03420004628424067, 0.03318607217806857, 0.04571865691104904, 0.07846376349334605, 0.1356265676440671, 0.1355498592602089, 0.17254883015993983, 0.09923291465383954, 0.1270765217486769, 0.17781224538339302, 0.08893560821888968, 0.12633165781153366, 0.116167054802645, 0.1769415132002905, 0.32984290388412774, 0.2375959514756687, 0.16934080776991323, 0.16623496427200735, 0.10166132575250231, 0.1121323615370784, 0.1496411210973747, 0.19249241624493152, 0.12077844876330346, 0.15399172436445951, 0.21578133688308299, 0.16705123765859753, 0.13176121021388099, 0.15707991959061474, 0.1347961340798065, 0.10529396051424555, 0.2027596879634075, 0.18735196004854515, 0.12082427638233639, 0.14370931283337995, 0.16705045098206028, 0.12096630118321627, 0.12682307831710204, 0.09457075779209845, 0.23694041243288666, 0.20060489187017083, 0.2102245803689584, 0.13915053714299574, 0.1917619351297617, 0.1788840105291456, 0.12416923244018108, 0.18591407861094922, 0.20705091941636056, 0.10035668950877152, 0.21538961649639532, 0.2627626690082252, 0.1153465140669141, 0.22800195612944663, 0.24698199704289436, 0.14881977142067626, 0.17551140947034582, 0.32563445158302784, 0.2216188923921436, 0.12511909240856767, 5.963238989934325, 39.89212900400162, 83.26109424233437, 122.93676406145096, 128.23778361082077, 132.5344866514206, 117.40084871649742, 115.55695965886116, 98.07668164372444, 118.32366719841957, 114.419065117836, 91.17556795477867, 95.53994536399841, 108.37880283594131, 76.1861702799797, 92.96515792608261, 57.70549714565277, 64.51826557517052, 44.717170894145966, 46.52282640337944, 38.68913635611534, 47.65460327267647, 41.12859405577183, 28.850464895367622, 50.06024658679962, 31.721780821681023, 39.80906166136265, 30.85949119180441, 21.965158358216286, 44.30638633668423, 41.980998516082764, 36.9682352989912, 34.935617968440056, 22.204553112387657, 52.603503316640854, 29.86290156841278, 34.6659692376852, 47.21754312515259, 31.504373587667942, 44.506768584251404, 67.79784679412842, 77.89740085601807, 60.583736300468445, 63.17759871482849, 92.70962923765182, 110.25798439979553, 108.76480132341385, 94.52380388975143, 130.46999663114548, 128.6275514960289, 132.89115071296692, 135.5269780755043, 150.2257141470909, 131.0349503159523, 102.31274753808975, 49.922591373324394, 14.463968519121408, 0.47344637161586434, 0.7470796338748187, 0.16613447747658938, 0.14194267481798306, 0.20412154379300773, 0.08210663989302702, 0.10419343714602292, 0.1745183119783178, 0.2217260585166514, 0.11729998033843003, 0.14421223662793636, 0.2032328664790839, 0.19145192520227283, 0.14733635180164129, 0.16883988777408376, 0.16664639610098675, 0.09112444662605412, 0.2079755612066947, 0.12618683511391282, 0.1893131891847588, 0.16298458009259775, 0.10805916565004736, 0.08392350646317936, 0.26004902087152004, 0.25308963493444026, 0.10772905094199814, 0.12867231736890972, 0.13852183416020125, 0.12407943999278359, 0.12363100468064658, 0.133790657564532, 0.1260612191981636, 0.17528867610963061, 0.18074920575600117, 0.18739824037766084, 0.12740391277475283, 0.10697142206481658, 0.15633747505489737, 0.19759422139031813, 0.23267702636076137, 0.12377374194329605, 0.11442267379607074, 0.12746715859975666, 0.10003323186538182, 0.16451506671728566, 0.12703463493380696, 0.1267069618916139, 0.16735577053623274, 0.11048526866943575, 0.16548739891732112, 0.19830469420412555, 0.09884363593300804, 0.09424232775927521, 0.1716410499648191, 0.17223831557203084, 0.12223209341755137, 0.16421194392023608, 0.09239866965799592, 0.12409693983499892, 0.08955395824159496, 0.17853843688499182, 0.1054668438155204, 0.10376865408034064, 0.1503701476030983], [0.053905269378446974, 0.037144546877243556, 0.01238304754224373, 0.004076487311976962, 0.06074551463825628, 0.035610891281976365, 0.0379622006585123, 0.04352839729108382, 0.04596704260620754, 0.026824732958630193, 0.02782049290544819, 0.06315235892543569, 0.027705914581019897, 0.044220275594852865, 0.03751701966393739, 0.06593159065232612, 0.027860322115884628, 0.04886275070020929, 0.05529510788619518, 0.07068034130497836, 0.09003134473459795, 0.01575493428390473, 0.03922067902749404, 0.029050936645944603, 0.12340799672529101, 0.051020322425756603, 0.039347007405012846, 0.042300209679524414, 0.029234723951958586, 0.009223970719176577, 0.06743447680491954, 0.02269331929710461, 0.09147098506218754, 0.017937382799573243, 0.02148939991457155, 0.03479944556602277, 0.05811501672724262, 0.03925013115804177, 0.04220789021928795, 0.026389494887553155, 0.02721477794693783, 0.0066624443024920765, 0.07053797511616722, 0.034576856924104504, 0.03288533909653779, 0.11236108402954414, 0.004095618023711722, 0.05325879938027356, 0.011401213068893412, 0.009040098993864376, 0.05981635316857137, 0.15319629048462957, 1.288176120724529, 2.4762701243162155, 23.88448476791382, 58.64054337143898, 90.21745696663857, 96.28188595175743, 81.87641814351082, 74.77746427059174, 68.5971187055111, 71.4068703353405, 74.3996961414814, 78.45097035169601, 52.777066603302956, 51.96275129914284, 29.278525225818157, 34.1255584359169, 33.425510600209236, 27.31187805533409, 32.18292027711868, 45.95393992960453, 58.83949689567089, 70.52532523870468, 72.97356426715851, 93.75331923365593, 108.2800005376339, 135.4594025015831, 185.55918216705322, 113.09717684984207, 121.60501152276993, 122.05846399068832, 127.44909033179283, 138.10539811849594, 138.9618417620659, 123.87975186109543, 133.4843596816063, 146.3703042268753, 163.13287675380707, 136.68181210756302, 134.40222322940826, 135.56441366672516, 95.23025438189507, 124.39953356981277, 121.13256767392159, 87.80291453003883, 65.71640968322754, 62.42395855486393, 49.99981842935085, 33.70595455169678, 32.59071059525013, 19.006013944745064, 27.663385793566704, 34.30150419473648, 57.93194979429245, 71.92955508828163, 92.49298006296158, 97.93257057666779, 101.34835168719292, 102.62708947062492, 106.0110130906105, 101.4821121096611, 56.84523470699787, 9.412449281662703, 1.1294459318742156, 0.41579521202947944, 0.0615958637354197, 0.0889708157046698, 0.051338752018637024, 0.01662782611674629, 0.024905533500714228, 0.04297537110687699, 0.08161570920492522, 0.009236843270628015, 0.034805935647455044, 0.07564081926830113, 0.01152888380602235, 0.06074182616430335, 0.036566547423717566, 0.01931820977915777, 0.0158984007066465, 0.018003636178036686, 0.03771235664316919, 0.021863698384549934, 0.010912989364442183, 0.07093506123055704, 0.0670902464480605, 0.013838202467013616, 0.09258096339181066, 0.0969819955935236, 0.027589649725996424, 0.033548102946951985, 0.06954127078643069, 0.020385471943882294, 0.017506541953480337, 0.09541863924823701, 0.025849044395727105, 0.0197960972218425, 0.06430251713027246, 0.01867359515017597, 0.04571759192913305, 0.0639541084819939, 0.052051581151317805, 0.03609375482483301, 0.05082538991700858, 0.05213496886426583, 0.08562301722122356, 0.03541233338182792, 0.0464632054354297, 0.039907629470690154, 0.03689216842758469, 0.04394077906908933, 0.042693577634054236, 0.035251632434665225, 0.015627270040567964, 0.0488127967400942, 0.03768522372411098, 0.030268147893366404, 0.053214764047879726, 0.034953148060594685, 0.017385633109370247, 0.04312213080993388, 0.02917521484050667, 0.09824626642512158, 0.017503209710412193, 0.027028220574720763, 0.053566542046610266, 0.047425440716324374, 0.03153474535793066, 0.03630768260336481, 0.030657934985356405, 0.025650868701632135, 0.02094617193506565, 0.030338230753841344, 0.07193278972408734, 0.009904116595862433, 0.06802158983191475, 0.05643683900416363, 0.022867215629958082, 0.05296466770232655, 0.03668823737825733, 0.05600801494438201, 0.03146956252749078, 0.0358283071545884, 0.05096208238683175, 0.0455613735539373, 0.03556864081474487, 0.024419656838290393, 0.0319070622936124, 0.011059134012612049, 0.043392725274316035, 0.08277746717794798, 0.05677405606547836, 0.0574544718983816, 0.036898484104312956, 0.03778206286369823, 0.07165962742874399, 0.03847503583529033, 0.021096636810398195, 0.08116993820294738, 0.057343335283803754, 0.04491669955314137, 0.054130151256686077, 0.022996473635430448, 0.03904978839273099, 0.12556957604829222, 0.04862573099671863, 0.0730497516633477, 0.10715135576901957, 0.05381962182582356, 0.04600981257681269, 0.058696522828540765, 0.010325614730390953, 0.022424884482461493, 0.02659289715666091, 0.10021928828791715, 0.08031868739635684, 0.08389816212002188, 0.7149422052316368, 0.4473318869713694, 15.760611891746521, 52.7223951369524, 94.70706045627594, 108.46157759428024, 96.20782792568207, 84.58989053964615, 76.85376405715942, 85.31011909246445, 98.34499284625053, 94.24586400389671, 87.01768666505814, 96.53443560004234, 48.17315764725208, 58.81914138793945, 62.57620118558407, 35.050747990608215, 33.89762006700039, 32.115682885050774, 44.72784452140331, 42.08784878253937, 44.02336232364178, 44.260173216462135, 66.7044098675251, 77.98928752541542, 82.20674201846123, 70.3319688141346, 55.848278403282166, 59.51778709888458, 56.88023462891579, 52.194364070892334, 66.68944627046585, 68.75196799635887, 67.92283728718758, 80.96767410635948, 75.58909311890602, 96.74917727708817, 66.88419342041016, 68.51875931024551, 60.9094662219286, 50.82733802497387, 60.76042301952839, 69.47987213730812, 55.72744108736515, 34.481302946805954, 30.73837459087372, 33.38761903345585, 42.78791181743145, 37.61301130056381, 50.3586445748806, 73.22165295481682, 95.38108348846436, 99.57737311720848, 115.99781200289726, 107.51000225543976, 112.43741065263748, 117.73713827133179, 122.75662332773209, 115.19309878349304, 65.11402040719986, 10.783663652837276, 0.3817916085245088, 0.41758209583349526, 0.07889878077548929, 0.11121272924356163, 0.03076372442592401, 0.017688959997030906, 0.053842038396396674, 0.044919790598214604, 0.04454829373571556, 0.04700628684076946, 0.028122183357481845, 0.08895411738194525, 0.0675004388904199, 0.07687559715122916, 0.010063539193652105, 0.026464314505574293, 0.004856616251345258, 0.07364712117123418, 0.009385181892866967, 0.05486770503921434, 0.028953696746611968, 0.05001230034395121, 0.11735492895240895, 0.02431103424896719, 0.03620573377702385, 0.0553167266480159, 0.06941382918739691, 0.08888075608410873, 0.04036783524497878, 0.058583245117915794, 0.04612703480233904, 0.043519049941096455, 0.03235173491702881, 0.0413251909048995, 0.07033017376670614, 0.06914379875524901, 0.01941691542015178, 0.1668998395325616, 0.04248109333275352, 0.04621590698661748, 0.071552594890818, 0.03211331626516767, 0.07482680943212472, 0.009050990011019167, 0.012636682076845318, 0.020551460693241097, 0.058231251896359026, 0.01178042641186039, 0.07326378705329262, 0.03746017115190625, 0.04093082847248297, 0.06458535703131929, 0.042947752081090584, 0.01974327115021879, 0.006988057884882437, 0.02950398626126116, 0.06085834334953688, 0.053782514441991225, 0.03999962980742566, 0.09837879915721714, 0.02632088519021636, 0.005512073194040568, 0.16893699037609622, 0.20990803954191506, 0.1636659904033877, 0.18152252363506705, 0.09093554777791724, 0.06830976577475667, 0.16556317219510674, 0.10019717228715308, 0.1409999097813852, 0.125565642665606, 0.14263009652495384, 0.10408546208054759, 0.1394011900993064, 0.13049998960923404, 0.16456688346806914, 0.16843768826220185, 0.1326940453145653, 0.14928290125681087, 0.16674072307068855, 0.08889622244169004, 0.14907008298905566, 0.0670543932938017, 0.16041265247622505, 0.07367100348346867, 0.18489150301320478, 0.1995973670273088, 0.19958158896770328, 0.17995467729633674, 0.12237261165864766, 0.08016269537620246, 0.22065080527681857, 0.14976215054048225, 0.2193172846455127, 0.13495560677256435, 0.16188225330552086, 0.20041454583406448, 0.1855655512190424, 0.14239998621633276, 0.09189183474518359, 0.29481145553290844, 0.15601422521285713, 0.23276980966329575, 0.25047742354217917, 0.11477202497189865, 0.09573120958521031, 0.3126722783781588, 0.07552663242677227, 0.1534960587741807, 0.20396259060362354, 0.2525827183853835, 0.1633755286457017, 0.156440069549717, 2.863805629312992, 11.352761015295982, 45.5719730257988, 92.28483483195305, 116.0805031657219, 120.99299356341362, 103.10254275798798, 94.17814403772354, 87.87444189190865, 93.46451193094254, 94.62034910917282, 100.8236226439476, 70.53909569978714, 69.73555281758308, 40.31631924211979, 44.27298612892628, 47.52863623201847, 43.26030246913433, 42.47394226491451, 63.866106569767, 86.79048165678978, 96.46309062838554, 103.30146208405495, 144.19694244861603, 150.78364580869675, 183.11998665332794, 242.33037024736404, 154.21887427568436, 173.20297479629517, 173.37043941020966, 182.19145327806473, 184.63291347026825, 189.618321955204, 173.73994678258896, 191.3559079170227, 212.37741351127625, 226.054445207119, 192.13044315576553, 192.68069922924042, 196.70044273138046, 137.31517732143402, 188.24177742004395, 174.76458460092545, 128.01748663187027, 96.80021613836288, 90.41566953063011, 72.480738312006, 49.40177612006664, 43.95566515624523, 33.631923124194145, 45.81639111042023, 54.6055056899786, 83.31410899758339, 93.15193310379982, 120.54378926753998, 123.74814972281456, 126.4764641225338, 127.44826957583427, 135.4994371533394, 138.38077694177628, 87.36970737576485, 19.41974524408579, 1.6220412869006395, 0.3116799972485751, 0.22727761999703944, 0.3473551251227036, 0.21498769900063053, 0.0665903728804551, 0.06584740141988732, 0.10804300909512676, 0.12610724719706923, 0.1057471901003737, 0.12150601323810406, 0.25497201830148697, 0.08934319572290406, 0.1320089984801598, 0.185559747624211, 0.1537866986473091, 0.11257531237788498, 0.15531788289081305, 0.12468285800423473, 0.08219964583986439, 0.15996828413335606, 0.2144321272498928, 0.23844079754780978, 0.11167145814397372, 0.2965242729987949, 0.22050230152672157, 0.1937216948135756, 0.10116741905221716, 0.10621143315802328, 0.19769369886489585, 0.12616464489838108, 0.14200706355040893, 0.15123326535103843, 0.1282342869671993, 0.1541907386854291, 0.22538487624842674, 0.14636516250902787, 0.25686651351861656, 0.13567556423367932, 0.08203279619920067, 0.1326579917804338, 0.12294446612941101, 0.16241012810496613, 0.13529234885936603, 0.11760556706576608, 0.1717452474986203, 0.17109232081566006, 0.118022416572785, 0.16384033573558554, 0.17331799201201648, 0.12637130334042013, 0.11805423986515962, 0.1388845662586391, 0.13478816341375932, 0.07825291191693395, 0.1456585043342784, 0.12632917903829366, 0.12210852582938969, 0.13525999122066423, 0.3118017391534522, 0.1303526881383732, 0.0992071398650296], [0.06255367581616156, 0.043503431443241425, 0.03903567274392117, 0.11475152685306966, 0.08821712021017447, 0.06136920812423341, 0.022312675464490894, 0.020992585850763135, 0.060069859682698734, 0.04869933720328845, 0.016953376616584137, 0.03909946775820572, 0.005406468826549826, 0.016288503211399075, 0.01874917546956567, 0.07068485356285237, 0.026605081366142258, 0.018434410230838694, 0.05732844780141022, 0.028104340271966066, 0.0882370988256298, 0.024741409397393, 0.004589619347825646, 0.056008820174611174, 0.009090072435355978, 0.019041574232687708, 0.0676727804238908, 0.0641236595402006, 0.03136212551908102, 0.07048405066598207, 0.02326649107999401, 0.03329908642626833, 0.04938526348269079, 0.05129772238433361, 0.09607179599697702, 0.01890105413622223, 0.034949199834954925, 0.03486988651275169, 0.03078966063185362, 0.023432296147802845, 0.053709988060290925, 0.04349952774646226, 0.038194288790691644, 0.031025585667521227, 0.06803529729950242, 0.0858832809899468, 0.098168266704306, 0.056748756251181476, 0.16909307887544855, 1.2757479376159608, 3.7138102808967233, 15.796921793371439, 46.72551892697811, 70.589230209589, 66.7430005967617, 75.29632642865181, 78.66029351949692, 66.48078426718712, 71.02503642439842, 74.37683656811714, 72.77756318449974, 28.910002000629902, 34.08273473381996, 21.009845919907093, 25.405280962586403, 26.566605046391487, 67.16608509421349, 83.73092383146286, 79.13666635751724, 101.75352394580841, 121.35180830955505, 143.16742569208145, 81.48326084017754, 119.75687429308891, 61.062480211257935, 45.41653096675873, 29.268035888671875, 39.234908670187, 53.164364621043205, 40.06781257688999, 48.31536881625652, 44.229755848646164, 41.205023154616356, 57.27086506783962, 36.1351528018713, 44.339379966259, 32.02065758407116, 24.341281056404114, 35.2595429867506, 30.547336041927338, 24.509524628520012, 33.14057908952236, 33.41577172279358, 39.079645201563835, 50.04771485924721, 49.99451771378517, 76.60135120153427, 104.58979815244675, 116.19904920458794, 131.46537601947784, 118.7190055847168, 92.70329877734184, 60.593820959329605, 33.35383504629135, 22.603736892342567, 27.067456170916557, 28.143923208117485, 53.89429025352001, 70.20794346928596, 80.39814546704292, 101.5295335650444, 84.95649486780167, 96.55116230249405, 90.89083403348923, 66.27289742231369, 27.683351822197437, 7.6485525816679, 2.5492839189246297, 1.4850614871829748, 0.4729610960930586, 0.15452691673999652, 0.0772420028806664, 0.021000619599362835, 0.03758814338652883, 0.034852883909479715, 0.019846889808832202, 0.02938233155873604, 0.023031686687318143, 0.013623710656247567, 0.05822318846185226, 0.03822639409918338, 0.008083759148576064, 0.02513220395485405, 0.059702923317672685, 0.008116808839986334, 0.028551786672323942, 0.052357401655172, 0.03225356362236198, 0.024177542290999554, 0.032679664000170305, 0.026338218049204443, 0.02990471817611251, 0.030402964584936853, 0.010016192027251236, 0.00014246994453515072, 0.016728813861845993, 0.030097617200226523, 0.08545328804757446, 0.02907317510107532, 0.03415027415030636, 0.012531156098702922, 0.03155528800562024, 0.07519525606767274, 0.024950526203610934, 0.042721348800114356, 0.03208601636288222, 0.0420560319616925, 0.03497736805002205, 0.05835152063809801, 0.02450172723911237, 0.04768565624544863, 0.009618822041375097, 0.01963888993486762, 0.030678948896820657, 0.018637716020748485, 0.029009808677074034, 0.03357130990480073, 0.014659816533821868, 0.04997298136004247, 0.017607288500585128, 0.05027395935030654, 0.010649735668266658, 0.05399591158493422, 0.08655456098495051, 0.05741840723203495, 0.03598934577894397, 0.08347598399268463, 0.035418281695456244, 0.0530638965574326, 0.034254824204253964, 0.04855328625126276, 0.03704090595419984, 0.0730117537023034, 0.009170716057269601, 0.053003827124484815, 0.05625865305773914, 0.06732293200911954, 0.01318004457061761, 0.024622346645628568, 0.026758735621115193, 0.040338431354030035, 0.03146398528770078, 0.018367943484918214, 0.054380755973397754, 0.10763434547698125, 0.02571559696662007, 0.02556371829996351, 0.049165658274432644, 0.0345719661709154, 0.10222604818409309, 0.05161140223208349, 0.025464615609962493, 0.019730446838366333, 0.09514464574749582, 0.05923527751292568, 0.036458939721342176, 0.033395153732271865, 0.05934184620855376, 0.04521041191765107, 0.035868371996912174, 0.045673990753130056, 0.004667811099352548, 0.023768537284922786, 0.019036060075450223, 0.05343738608644344, 0.025001194480864797, 0.09546276734909043, 0.015975331734807696, 0.03279628879681695, 0.02186416408221703, 0.01175651070298045, 0.09698074878542684, 0.004886334163529682, 0.10342213790863752, 0.11116824491182342, 0.6474457145668566, 1.307195525150746, 5.020081624388695, 37.13533513247967, 62.725191190838814, 76.31974831223488, 89.07011613249779, 90.2623401582241, 81.40343472361565, 86.01484447717667, 99.89517286419868, 92.15199396014214, 62.385117039084435, 66.24227106571198, 60.41106976568699, 35.1990882307291, 31.196808591485023, 63.89489382505417, 36.832191199064255, 38.60646419227123, 54.64442320168018, 69.4551582634449, 78.13345938920975, 71.18503823876381, 84.87505003809929, 57.73304186761379, 51.17142476141453, 35.63109464943409, 42.767696902155876, 56.22049123048782, 42.10594341158867, 44.57414276897907, 43.644389659166336, 40.57369463145733, 46.66406102478504, 35.16412250697613, 35.44503003358841, 31.787870675325394, 28.06743711233139, 31.47388592362404, 26.235179230570793, 29.993893839418888, 39.4165313243866, 38.150659650564194, 45.03991037607193, 54.909508377313614, 46.40257805585861, 57.242928966879845, 73.12170311808586, 80.26934757828712, 82.31395706534386, 76.72098398208618, 57.058289274573326, 36.43979385495186, 22.801995053887367, 27.993474081158638, 51.24589316546917, 63.93756553530693, 86.61956682801247, 110.80474466085434, 98.90339568257332, 117.50171810388565, 97.88360640406609, 115.07408916950226, 107.0210824906826, 75.38792431354523, 30.636032782495022, 7.0142853911966085, 1.6964680119417608, 0.7067166559863836, 0.2545142616145313, 0.1551802144967951, 0.10570763362920843, 0.05226654051512014, 0.11895812378497794, 0.0290674253119505, 0.02271663943247404, 0.03778891288675368, 0.05463929795951117, 0.09409396501723677, 0.04830647390917875, 0.08276310662040487, 0.015170197057159385, 0.05369223217712715, 0.05515885699423961, 0.04000471351901069, 0.022257433702179696, 0.08838274530717172, 0.038430414206231944, 0.03485329209070187, 0.044813032654928975, 0.09445322386454791, 0.020041703573951963, 0.025185540253005456, 0.022278853939496912, 0.015584791362925898, 0.014731090541317826, 0.11943914680159651, 0.05165161179320421, 0.02478778249496827, 0.03528389730490744, 0.030734821484657004, 0.09115796943660825, 0.020950370635546278, 0.033497369731776416, 0.06233742882614024, 0.05250723013887182, 0.08278143766801804, 0.0329295117262518, 0.02835272411175538, 0.01302990624026279, 0.03898309158103075, 0.03814159630564973, 0.03117532323813066, 0.048858372028917074, 0.007985686188476393, 0.02745217800111277, 0.04060853229020722, 0.03326431309687905, 0.0232365046031191, 0.04064257460413501, 0.03912398831744213, 0.033129891598946415, 0.044051088189007714, 0.04449868116353173, 0.0886102655204013, 0.03684231094666757, 0.1493914329330437, 0.11760808294638991, 0.1343800118775107, 0.2592905459459871, 0.21517421555472538, 0.19404877413762733, 0.19306894624605775, 0.11313614595565014, 0.10894429549807683, 0.18865995079977438, 0.1827329961815849, 0.13891576614696532, 0.09428926859982312, 0.06365235123666935, 0.11341117846313864, 0.1276411922299303, 0.08050947872106917, 0.1375457170070149, 0.2691427938407287, 0.1597488162224181, 0.16750575858168304, 0.19922215200494975, 0.05459594169224147, 0.19589528208598495, 0.18646714190253988, 0.10018342029070482, 0.11678978349664249, 0.22408911609090865, 0.2045812745927833, 0.21007671486586332, 0.12931519537232816, 0.1501290238229558, 0.11470621131593361, 0.21304646332282573, 0.14105297334026545, 0.16162057203473523, 0.09388424150529318, 0.10967718859319575, 0.18992360564880073, 0.08366083071450703, 0.19079825637163594, 0.2117890870431438, 0.1529376520193182, 0.11042507307138294, 0.132504174252972, 0.28542512794956565, 0.20494120137300342, 0.34651376714464277, 0.38233278261031955, 2.2925825184211135, 6.312930900603533, 29.54478643834591, 71.85472950339317, 100.66517114639282, 97.40696758031845, 95.83564549684525, 101.9537428021431, 89.69636052846909, 92.89427652955055, 100.79717606306076, 96.68514311313629, 47.34862469136715, 47.48863957822323, 34.47528786957264, 38.70827212929726, 37.12632581591606, 87.20135360956192, 107.47939109802246, 107.3570604622364, 134.65886145830154, 167.8952980041504, 197.41068542003632, 118.06753814220428, 165.3729173541069, 91.48459777235985, 73.0991019308567, 46.6513355076313, 65.25993257761002, 82.30439677834511, 61.976277977228165, 75.92365756630898, 69.54788848757744, 64.0892381966114, 94.11483183503151, 56.473211869597435, 66.98096662759781, 50.709529146552086, 39.84445296227932, 57.223789393901825, 50.682071819901466, 43.3847875893116, 54.33122120797634, 49.72496397793293, 60.324886590242386, 76.28447100520134, 72.89138227701187, 109.95792210102081, 149.8672565817833, 161.74864143133163, 182.45166331529617, 162.62631833553314, 129.09431844949722, 86.57013908028603, 52.95810028910637, 39.26085747778416, 46.4569341391325, 46.28592051565647, 75.14416739344597, 96.42291158437729, 107.53454133868217, 127.49567583203316, 106.45549044013023, 121.75843209028244, 121.72531306743622, 98.95489051938057, 46.71031594276428, 13.004672974348068, 4.565779902040958, 2.2816255688667297, 0.6959610956255347, 0.26784379791934043, 0.18449552269885316, 0.1891677876119502, 0.26930262276437134, 0.2649437222862616, 0.17548858100781217, 0.24974477535579354, 0.23106735257897526, 0.1927487985813059, 0.19453339657047763, 0.22710104822181165, 0.12714104406768456, 0.15696806309279054, 0.15412508830195293, 0.15680168842663988, 0.13405974546913058, 0.19345866283401847, 0.13807267154334113, 0.11334408831316978, 0.15470377053134143, 0.16177958459593356, 0.17219102592207491, 0.12738111399812624, 0.10775612448924221, 0.23224052478326485, 0.12068257070495747, 0.2701351937139407, 0.18040294933598489, 0.10291511745890602, 0.15629671630449593, 0.10887011041631922, 0.1315586781129241, 0.10192694040597416, 0.1146710483590141, 0.14009870501467958, 0.19116683659376577, 0.17350116890156642, 0.17550809949170798, 0.1977542878012173, 0.12106499940273352, 0.12051099358359352, 0.1422483951319009, 0.06882113520987332, 0.1422229246236384, 0.07405963653582148, 0.10187914609559812, 0.14376307401107624, 0.18092748447088525, 0.16669338889187202, 0.09161510271951556, 0.07928661230835132, 0.16045851720264181, 0.28554131858982146, 0.12899803114123642, 0.1682823122246191, 0.1473899497068487], [0.03594574831367936, 0.06842680988484062, 0.01598401300725527, 0.018640972193679772, 0.06093990166846197, 0.021065882210677955, 0.024211202398873866, 0.042463786448934115, 0.044765316270058975, 0.01324384886174812, 0.019665302970679477, 0.034328419278608635, 0.04061047300638165, 0.08965237444499508, 0.05994107479637023, 0.004218301992295892, 0.04872042904025875, 0.07006455169175752, 0.05279821139993146, 0.038488435311592184, 0.023446916457032785, 0.019022853557544295, 0.04042646491143387, 0.01939129833772313, 0.07600040466058999, 0.01587206559634069, 0.04222097428282723, 0.025199490773957223, 0.023390923270198982, 0.05860190271050669, 0.042503524746280164, 0.01645975007704692, 0.02193999673181679, 0.04512055267696269, 0.04255821360857226, 0.040320515909115784, 0.05552508089749608, 0.012015775355393998, 0.07360394301940687, 0.021531741294893436, 0.0037997998151695356, 0.011814003028121078, 0.0735469238134101, 0.04400460376928095, 0.024024353733693715, 0.21591774362605065, 0.3081760508939624, 0.971535014687106, 10.32804625108838, 33.538676127791405, 51.4781329035759, 79.31838780641556, 87.04353287816048, 82.90322944521904, 71.99013143777847, 69.53863978385925, 81.90790325403214, 49.8341853171587, 28.304278403520584, 26.770194321870804, 19.84643004834652, 27.733891010284424, 24.76147200912237, 35.43666288256645, 66.87284722924232, 90.2105413377285, 81.97199821472168, 94.2806701362133, 79.78589192032814, 37.88277022540569, 12.4103544652462, 3.8218080857768655, 1.3032797165215015, 1.1342647857964039, 0.892003501066938, 0.6339756154920906, 0.4398990998743102, 0.3579876967705786, 1.1284398171119392, 0.5984811263624579, 0.6613593210931867, 0.8965870644897223, 0.8049348543863744, 1.421289627905935, 0.877413471462205, 0.4568715125788003, 0.3784666385035962, 0.24588952597696334, 0.6335759244393557, 0.34857770951930434, 0.5661264562513679, 0.7017668278422207, 0.7034934789407998, 1.070726732723415, 1.0902439104393125, 0.4253379546571523, 0.639586845645681, 0.6165573501493782, 0.9982541715726256, 8.945725075900555, 28.259805589914322, 60.68642199039459, 100.35979673266411, 139.08509194850922, 115.96835598349571, 68.87331068515778, 36.81938588619232, 16.978469341993332, 21.065657325088978, 44.56459008157253, 53.08515407145023, 88.13769176602364, 84.87099945545197, 88.94327133893967, 97.77823805809021, 98.61052259802818, 91.09903246164322, 74.09919306635857, 74.00725319981575, 35.707968324422836, 17.826496437191963, 2.9289830569177866, 0.18098814762197435, 0.06676105200313032, 0.02873632725822972, 0.06039808562491089, 0.10487357838428579, 0.043019729273510166, 0.08811573541606776, 0.0846424323390238, 0.007723803610133473, 0.03591462635085918, 0.03697948210174218, 0.011366139169695089, 0.05603533711109776, 0.056898443726822734, 0.11978537353570573, 0.03252752372645773, 0.0603127423528349, 0.025228851991414558, 0.044113436015322804, 0.03312657048809342, 0.07441473193466663, 0.01666400581598282, 0.020970861332898494, 0.02695527859032154, 0.05060880896053277, 0.058329619860160165, 0.0771738588809967, 0.02743225690210238, 0.07352152009843849, 0.016698454455763567, 0.04231487080687657, 0.023757486706017517, 0.01835229715652531, 0.04728153828182258, 0.02656076587300049, 0.034176572153228335, 0.004807905388588551, 0.08530985316610895, 0.022454909922089428, 0.03002312412718311, 0.0363013335299911, 0.06328783056233078, 0.002330381043975649, 0.06680774793494493, 0.021093323121021967, 0.016491545538883656, 0.02622072679514531, 0.0221256152872229, 0.05493524418852758, 0.06308172130957246, 0.004473125818549306, 0.024426636737189256, 0.02747963932051789, 0.038699717333656736, 0.055873407909530215, 0.07360084084211849, 0.0050213837039336795, 0.03807978282566182, 0.029224992540548556, 0.053150453240959905, 0.010556344732322032, 0.08193485497031361, 0.034418768336763605, 0.016823914520500693, 0.05184549416298978, 0.06669618087471463, 0.04016353312181309, 0.0075315711274015484, 0.067383869754849, 0.02605958427011501, 0.027816758047265466, 0.01852476671047043, 0.06633917073486373, 0.06896108199725859, 0.029206090039224364, 0.04851655365200713, 0.06016622755851131, 0.027177741067134775, 0.002168385512959503, 0.042306406612624414, 0.046696239805896766, 0.029428799280140083, 0.05896980386751238, 0.04980292193067726, 0.02809113560942933, 0.021041610270913225, 0.041200398773071356, 0.02440947271679761, 0.039789498114259914, 0.0244237275182968, 0.046758056996623054, 0.06495578520116396, 0.080987919063773, 0.09203614536090754, 0.016440444960608147, 0.047715353284729645, 0.043853602692252025, 0.10915777427726425, 0.03216828714357689, 0.1801877561956644, 0.21758729388238862, 0.5482623679563403, 1.8450957303866744, 22.10882294923067, 37.25719839334488, 78.47826808691025, 98.14743384718895, 95.72883322834969, 82.05251589417458, 81.148202419281, 90.23597717285156, 59.167647287249565, 51.69199302792549, 47.33925059437752, 36.250605806708336, 28.565692976117134, 29.853369779884815, 20.54707445204258, 42.53710627555847, 39.25781764090061, 68.2314795255661, 93.26859444379807, 75.69062367081642, 42.82604277133942, 19.022438563406467, 6.1248034704476595, 1.9934231461957097, 1.2729869107715786, 0.33568897924851626, 0.6104281602893025, 0.5086186795961112, 0.6404571770690382, 1.4041976700536907, 0.5185344850178808, 0.7652197417337447, 0.40788789570797235, 0.748755403328687, 1.165247610770166, 0.9805417188908905, 0.18544996913988143, 0.4595630744006485, 0.3729972179280594, 0.6570866878610104, 0.4128276009578258, 0.7249650580342859, 0.6124250125139952, 0.7085177593398839, 0.9232190635520965, 0.953442701138556, 0.41626686172094196, 0.396743182791397, 0.44713794894050807, 1.7139343684539199, 11.16533037275076, 29.153996407985687, 57.43044130504131, 77.91091293096542, 89.00355130434036, 69.55283582210541, 45.060607865452766, 20.702966786921024, 28.427549488842487, 38.38625080883503, 73.35276111960411, 83.741335272789, 102.5042724609375, 98.99618670344353, 96.03256613016129, 112.71238669753075, 112.45093792676926, 101.47528767585754, 82.17872232198715, 78.36086198687553, 35.697454288601875, 17.269704714417458, 2.3611308401450515, 0.1171981799416244, 0.023796521818439942, 0.09783467874513008, 0.0743180004064925, 0.04064110144099686, 0.05690825862984639, 0.008141308062477037, 0.020566179337038193, 0.062469256517942995, 0.031557714828522876, 0.006540177328133723, 0.06294164093560539, 0.07240765291498974, 0.01978417090867879, 0.022550526373379398, 0.0627170670486521, 0.02102790094795637, 0.007576285524919513, 0.016636082509648986, 0.03527948152623139, 0.03645951859652996, 0.02350885610212572, 0.011613778078753967, 0.014383249636011897, 0.01374914938423899, 0.061856602478655986, 0.026919653646473307, 0.09267422909033485, 0.04264140094164759, 0.0028027633743477054, 0.08905996990506537, 0.022764428176742513, 0.03987031428550836, 0.017710614010866266, 0.08888932046829723, 0.03738721803529188, 0.05168080788280349, 0.03965919553593267, 0.02616884510644013, 0.040513860221835785, 0.04216350607748609, 0.026713293918874115, 0.047890874920994975, 0.04887885901553091, 0.004782285986948409, 0.020950300131516997, 0.04337361497164238, 0.019472518979455344, 0.014145976674626581, 0.03612139611504972, 0.02323014625289943, 0.03473962475254666, 0.014412070941034472, 0.04067275032866746, 0.173246790363919, 0.1440734401694499, 0.1362234028056264, 0.06654031501966529, 0.1238025001657661, 0.11164784300490282, 0.0844752487319056, 0.11393611435778439, 0.1135653151141014, 0.08281047048512846, 0.17779985151719302, 0.17716954549541697, 0.1255074137588963, 0.19279973959783092, 0.12168378729256801, 0.09709037141874433, 0.14064547489397228, 0.15413617598824203, 0.10570388578344136, 0.138722496049013, 0.16101066023111343, 0.1825699463370256, 0.11882379505550489, 0.09386669713421725, 0.18732916127191857, 0.07928102393634617, 0.1170855070813559, 0.09297663942561485, 0.15142387856030837, 0.14183041756041348, 0.08257279027020559, 0.124913502659183, 0.17780719877919182, 0.12524455989478156, 0.11998152316664346, 0.096501291700406, 0.23950346396304667, 0.19526107236742973, 0.2204494902980514, 0.22910881001735106, 0.2007557704928331, 0.1396658251178451, 0.21411922294646502, 0.27249537175521255, 0.11662726057693362, 0.4249649809207767, 0.3388796205399558, 3.3890317333862185, 19.302842617034912, 51.117904633283615, 83.15217688679695, 105.68900316953659, 111.90524160861969, 103.98064523935318, 97.0630632340908, 93.66561233997345, 107.20709010958672, 71.75430849194527, 46.393002569675446, 42.415349408984184, 36.93580783903599, 38.975105211138725, 39.177881330251694, 51.782815754413605, 97.6915343105793, 134.79445338249207, 122.37219795584679, 134.57073658704758, 111.80121839046478, 57.26967953145504, 21.946250572800636, 6.57178963534534, 2.72294030059129, 1.5197935234755278, 1.1635234532877803, 1.123397012706846, 0.6805012095719576, 0.8618237392511219, 1.4839322352781892, 0.9387409337796271, 1.0359603795222938, 1.148590729571879, 1.2485799891874194, 2.5199243193492293, 1.2588712619617581, 0.8097585767973214, 0.7407878839876503, 0.38247601711191237, 0.8835702098440379, 0.5202876753173769, 0.9484349854756147, 1.0722855990752578, 0.9678387630265206, 1.1284081125631928, 1.284882053732872, 1.0374007397331297, 1.280893930234015, 0.7029268937185407, 1.6537009505555034, 14.244345054030418, 45.2035865932703, 93.57847541570663, 144.0376853942871, 190.32608717679977, 150.50744622945786, 94.41060796380043, 57.632164880633354, 30.10221842676401, 32.59860277175903, 58.84344108402729, 70.44429078698158, 117.57129997015, 109.11327302455902, 110.16780003905296, 117.32273250818253, 128.52934956550598, 118.74625012278557, 102.32056751847267, 100.91784238815308, 58.6926955729723, 30.41014440357685, 7.098658913746476, 0.20825950690777972, 0.1712509771459736, 0.13417724228929728, 0.15491750906221569, 0.18936441221740097, 0.11864641433930956, 0.13810476200887933, 0.1496712671360001, 0.10542850446654484, 0.11860866128699854, 0.08223380689742044, 0.1234430112526752, 0.18733811157289892, 0.10950475800200365, 0.13765920622972772, 0.13457611697958782, 0.2196836977964267, 0.05483181477757171, 0.11959565090364777, 0.08458748372504488, 0.1827067241538316, 0.12875205371528864, 0.08606249481090344, 0.13468056684359908, 0.2045341779012233, 0.13932255213148892, 0.19059026206377894, 0.24308031890541315, 0.11644110767520033, 0.11408544931327924, 0.16928170312894508, 0.1366834156215191, 0.12407049711328, 0.16189663612749428, 0.1682400394929573, 0.18028264719760045, 0.15339917881647125, 0.20525348227238283, 0.08928292591008358, 0.1052067952696234, 0.16666613722918555, 0.17623834311962128, 0.09829886243096553, 0.16489326517330483, 0.08638222687295638, 0.1958311753696762, 0.10188153581111692, 0.1084815664216876, 0.1261678509763442, 0.14772373804589733, 0.1269445678917691, 0.1764543674653396, 0.13858024118235335, 0.1552451672614552], [0.008804172102827579, 0.05008202882891055, 0.051457376903272234, 0.03556974661478307, 0.05314611909852829, 0.03292196037364192, 0.049507465519127436, 0.04288758245820645, 0.014279725601227256, 0.10233939639874734, 0.018481540319044143, 0.026407924269733485, 0.07377919377177022, 0.05252993985777721, 0.03137240055366419, 0.03613795714045409, 0.03908433536707889, 0.016144055298354942, 0.04489293598453514, 0.06498883303720504, 0.02813690014590975, 0.03052686428418383, 0.05159098203876056, 0.015367456198873697, 0.027918786654481664, 0.026824148517334834, 0.009390610703121638, 0.08447083295322955, 0.04247150478477124, 0.015254626559908502, 0.038533765691681765, 0.02925336670159595, 0.07660868373932317, 0.05625749530736357, 0.02584788107924396, 0.0827631882566493, 0.008466415129078086, 0.07361287105595693, 0.017348954315821175, 0.07997515465831384, 0.1175353821599856, 0.0412892709573498, 0.14099173131398857, 0.15431239153258502, 0.21682570193661377, 9.256492350250483, 29.43417627364397, 48.66554282605648, 75.18123060464859, 85.97747728228569, 87.18652680516243, 81.47398933768272, 75.31787127256393, 59.41862002015114, 61.14726886153221, 54.303182512521744, 37.704947367310524, 21.506146788597107, 20.81931844353676, 105.85509225726128, 56.61040350794792, 60.66174231469631, 96.44396245479584, 129.39576387405396, 97.24714815616608, 52.72290050983429, 41.594190672039986, 4.805175606161356, 0.5472654558252543, 0.34179323294665664, 0.1616575161460787, 0.04294178150303196, 0.15109850617591292, 0.1425657226354815, 0.44225274701602757, 0.36993306828662753, 0.10066940085380338, 0.07597372445161454, 0.6934532895684242, 0.3221953095635399, 0.4931324621429667, 0.31049716228153557, 0.5206354160327464, 0.5415788234677166, 0.46056372695602477, 0.3416752314660698, 0.2803654916351661, 0.16269190673483536, 0.3669514157809317, 0.19932318798964843, 0.2868314681109041, 0.4694670648314059, 0.3636907454347238, 0.560604699421674, 0.46507467865012586, 0.21803998912218958, 0.15771742444485426, 0.46137026336509734, 0.07847287706681527, 0.3963571472559124, 0.8353367855306715, 0.4130411020014435, 2.0108416490256786, 16.312950253486633, 43.76605533063412, 99.35731172561646, 128.3886507153511, 97.62484028935432, 68.01711782813072, 32.18515835702419, 32.25006267428398, 32.474083453416824, 42.25373648107052, 75.65885737538338, 74.1990365087986, 82.29086190462112, 79.88677650690079, 84.71151441335678, 91.76706701517105, 93.73423665761948, 79.87385720014572, 52.15496018528938, 19.415814355015755, 0.9592807909939438, 0.02396460527961608, 0.028473339807533193, 0.04065494991664309, 0.06854855921119452, 0.04447329600225203, 0.07097590903867967, 0.018652488470252138, 0.04207995880278759, 0.02452613647619728, 0.08734050279599614, 0.010087321315950248, 0.046168101544026285, 0.018781061844492797, 0.03843880789645482, 0.052741021499969065, 0.010161132540815743, 0.03854908361972775, 0.018506478336348664, 0.04773274180479348, 0.03803077510383446, 0.01995585007534828, 0.009618391595722642, 0.0540649016329553, 0.01836393403209513, 0.09075010733795352, 0.024976429012895096, 0.04379495447210502, 0.022113514569355175, 0.02174903842387721, 0.02593146917206468, 0.05997639360430185, 0.03575359514798038, 0.015936819836497307, 0.07017131705651991, 0.07637003131094389, 0.03219372796593234, 0.012297880530240946, 0.043888639484066516, 0.05684268988261465, 0.03374014107976109, 0.05725485643779393, 0.009812979933485622, 0.022164917572808918, 0.051649997622007504, 0.024912687804317102, 0.029925769194960594, 0.013083253670629347, 0.04112898190214764, 0.08688692440045998, 0.08053987708990462, 0.0183021929115057, 0.054789671921753325, 0.04271751189662609, 0.04358754275017418, 0.01750428582454333, 0.027926753609790467, 0.03647131874458864, 0.053796837892150506, 0.08356665959581733, 0.0551209926197771, 0.02356574357690988, 0.024098017456708476, 0.021237568798824213, 0.02539010027248878, 0.03734398793312721, 0.03593234141590074, 0.03734342390089296, 0.06803282594773918, 0.014729146114405012, 0.04182926502835471, 0.012341747024038341, 0.04959145808243193, 0.02537960073823342, 0.02121284785971511, 0.08831296116113663, 0.011438582059781766, 0.04663359512051102, 0.026917848372249864, 0.08814411514322273, 0.05649803650157992, 0.09907999512506649, 0.03217095887521282, 0.053726040714536794, 0.038095679628895596, 0.06805295299272984, 0.020431846896826755, 0.029530855717894156, 0.03778714657528326, 0.0797288135800045, 0.04058937374793459, 0.06404835381545126, 0.01990103133721277, 0.05723851434595417, 0.03431854129303247, 0.05306984116032254, 0.21567636751569808, 0.14591320941690356, 0.9202591411303729, 11.253645233809948, 29.097339548170567, 62.51972481608391, 88.55632290244102, 97.54247590899467, 91.40608638525009, 84.20389965176582, 72.99375638365746, 76.74743056297302, 78.60611602663994, 64.94192004203796, 38.55105176568031, 18.22948381304741, 71.39639049768448, 35.88805966079235, 38.82085248827934, 40.691951885819435, 67.74675473570824, 83.44741344451904, 53.7750868499279, 36.04251377284527, 7.027998855337501, 1.003795105498284, 0.07888402687967755, 0.49840577761642635, 0.049923517217393965, 0.043591208959696814, 0.06690372989396565, 0.20486238528974354, 0.381073328317143, 0.1017522685287986, 0.39568992680869997, 0.8486122637987137, 0.24611332803033292, 0.22525085922097787, 0.0870497887081001, 0.29650188982486725, 0.7361252966802567, 0.7138333772309124, 0.58034832123667, 0.287579107680358, 0.16395940590882674, 0.06988070686929859, 0.14371832250617445, 0.36976353207137436, 0.5440495815128088, 0.20173957629594952, 0.3565372433513403, 0.3098344837781042, 0.10234703309834003, 0.06161053970572539, 0.21122783044120297, 0.0514796710194787, 0.5612454400397837, 0.7984464056789875, 0.2673108468297869, 2.199285887181759, 16.608659885823727, 43.38965132832527, 74.58711728453636, 85.46879097819328, 58.273452669382095, 35.46391122043133, 27.577060125768185, 40.066296458244324, 61.70342981815338, 67.7501517534256, 104.8495826125145, 87.29453980922699, 97.40300059318542, 92.60195061564445, 99.10462528467178, 105.31103745102882, 106.23277679085732, 88.6740405857563, 56.26929961144924, 18.13245601952076, 0.4581071884604171, 0.03384293966519181, 0.037622018717229366, 0.016115126381919254, 0.06066138106689323, 0.04580431188514922, 0.006153082376840757, 0.05471225478686392, 0.02169041061279131, 0.04081278988451231, 0.08967855741502717, 0.026996742381015792, 0.16479322366649285, 0.007116198494259152, 0.014912476999597857, 0.032115631765918806, 0.0049292460698779905, 0.03901878146280069, 0.06812539402744733, 0.06676015400444157, 0.03242133723688312, 0.033860116673167795, 0.053114718830329366, 0.015587251582473982, 0.002464532121848606, 0.07663701893761754, 0.020225477892381605, 0.054935722873779014, 0.1606650569010526, 0.02535289640945848, 0.041974343766923994, 0.08523552707629278, 0.02321015464985976, 0.039051217027008533, 0.023464405167032965, 0.0007132041491786367, 0.01080024321709061, 0.05655589062371291, 0.03729760370333679, 0.02392985792539548, 0.019041687410208397, 0.04149687563767657, 0.02852015633834526, 0.04269450160791166, 0.04172027693130076, 0.011695711182255764, 0.058923686810885556, 0.04993657530576456, 0.021143076701264363, 0.12388698625727557, 0.053019490151200444, 0.04313191231631208, 0.03727804069058038, 0.1026768509473186, 0.16988397081149742, 0.19096798554528505, 0.11877382625243627, 0.22648879123153165, 0.23968540888745338, 0.19922949926694855, 0.12005666561890393, 0.14512179797748104, 0.27164448460098356, 0.0715227828186471, 0.15597321413224563, 0.1362753679859452, 0.1191405214194674, 0.11826169982668944, 0.1342662109527737, 0.11686318190186284, 0.11816191065008752, 0.0988862723170314, 0.2020170504692942, 0.15038634126540273, 0.058661797738750465, 0.12893395411083475, 0.17300152539974079, 0.16372807847801596, 0.16625903954263777, 0.16458186000818387, 0.19054785574553534, 0.21565652248682454, 0.1842383833718486, 0.32504649250768125, 0.27839740505442023, 0.21674828109098598, 0.21470241743372753, 0.130726448551286, 0.23439095704816282, 0.17331821465631947, 0.13364313344936818, 0.12164036423200741, 0.17967300256714225, 0.2109286855557002, 0.15450068924110383, 0.19234698498621583, 0.3547653212444857, 0.5126244365237653, 16.1332293972373, 47.594995871186256, 69.228006452322, 98.36453899741173, 115.53603798151016, 107.53511890769005, 103.6453740298748, 101.09593123197556, 84.2378318309784, 87.99146041274071, 80.832629352808, 56.90152108669281, 38.7515290081501, 37.178329825401306, 122.4984347820282, 75.19117847084999, 88.05052444338799, 134.09263104200363, 183.33891570568085, 136.56686067581177, 72.99774616956711, 63.56853313744068, 7.864111689850688, 1.464586523361504, 0.4898334969766438, 0.6390915659721941, 0.15005001478129998, 0.2384511282434687, 0.2949355129385367, 0.7518488529603928, 0.683298334479332, 0.3506816684966907, 0.8662806625943631, 1.6278531937859952, 1.0527452663518488, 0.9813875297550112, 0.7355044456198812, 1.2235242524184287, 1.271235798485577, 1.2421119050122797, 0.9227459295652807, 0.6091714964713901, 0.5643344367854297, 0.8881079382263124, 0.5231100332457572, 1.1315064900554717, 1.5765408659353852, 0.7390427682548761, 0.6719649082515389, 0.5109853588510305, 0.27682722837198526, 0.1681019109673798, 0.4149159154621884, 0.19117903750156984, 0.499373241327703, 1.0449987882748246, 0.832579736597836, 4.044411778450012, 26.60871248692274, 68.90028923749924, 141.78770452737808, 172.67566949129105, 123.8680712878704, 93.53404060006142, 47.96178258955479, 51.58684127032757, 49.16616216301918, 58.41732054948807, 101.64645329117775, 96.586272418499, 105.78240215778351, 99.50573176145554, 107.74365931749344, 111.71919599175453, 117.27686136960983, 107.36377090215683, 80.75287163257599, 30.79501435160637, 1.195762229617685, 0.15018907841295004, 0.15134693268919364, 0.12551295018056408, 0.15390691172797233, 0.11137580877402797, 0.14778405980905518, 0.16722552361898124, 0.132363329466898, 0.16304966644383967, 0.25735487637575716, 0.15610819595167413, 0.22414203122025356, 0.1474670588504523, 0.1096049405168742, 0.13111138570820913, 0.07697149747400545, 0.20532723690848798, 0.13915810704929754, 0.14117308252025396, 0.09610456181690097, 0.10925719238002785, 0.1218961454287637, 0.12879465299192816, 0.06180442949698772, 0.20186005654977635, 0.0815729763417039, 0.09052913286723197, 0.3234211594099179, 0.11599806035519578, 0.1935307402163744, 0.1410173057229258, 0.11175365842063911, 0.14050326455617324, 0.18926555814687163, 0.28754140657838434, 0.18240346777020022, 0.16280566313071176, 0.18020209448877722, 0.14594375621527433, 0.19006531132617965, 0.07883439946454018, 0.12418304380844347, 0.1446339100948535, 0.1745421942905523, 0.20800420810701326, 0.24541082588257268, 0.10491550230653957, 0.10534824861679226, 0.2141109257354401, 0.1378477265825495, 0.18982481095008552, 0.12952074059285223], [0.0708202064561192, 0.040592939767520875, 0.09293924260418862, 0.0759815689525567, 0.04272431368008256, 0.028140100657765288, 0.07860546917072497, 0.011025464627891779, 0.03775998768105637, 0.018289633917447645, 0.042788034479599446, 0.046086751026450656, 0.06049448318663053, 0.03905893907358404, 0.030403491509787273, 0.026638630151865073, 0.07238794889417477, 0.03745088317373302, 0.0692493469978217, 0.02028955306741409, 0.03639848808234092, 0.04189523453533184, 0.02220032358309254, 0.020156166865490377, 0.032192759463214315, 0.05636326990497764, 0.053704811580246314, 0.018029936036327854, 0.08038351399591193, 0.0021147361212570104, 0.045359761716099456, 0.07123338233213872, 0.060213572869542986, 0.020142362918704748, 0.11256449186475947, 0.05102874209114816, 0.05363595511880703, 0.03912819258403033, 0.0339273960707942, 0.01568289771967102, 0.03378214292752091, 0.040154553134925663, 0.23489601822802797, 2.1855465369299054, 26.48844324052334, 71.79245844483376, 84.91388395428658, 90.12531951069832, 85.98467409610748, 87.8355623781681, 73.0449016392231, 65.809246301651, 63.35018925368786, 36.99435889720917, 26.763671971857548, 13.839719016104937, 8.189366161823273, 16.310070008039474, 62.28815384209156, 61.52212254703045, 69.81325104832649, 75.91228857636452, 81.4771431684494, 35.52265226840973, 9.030556473881006, 2.480593342334032, 0.24557883327361196, 0.2181980072055012, 0.25372874282766134, 0.12832892563892528, 0.06247019162401557, 0.1685349689796567, 0.14026693505002186, 0.26659289316739887, 0.28716697823256254, 0.22959147318033502, 0.22073411877499893, 0.038674666138831526, 0.22651685925666243, 0.11823226624983363, 0.13748696859693155, 0.10172274589422159, 0.03614461420511361, 0.08632466589915566, 0.18539620796218514, 0.060580843201023526, 0.16468056564917788, 0.1002967165550217, 0.3151178627740592, 0.11897914882865734, 0.11980055045569316, 0.05460588276037015, 0.1373134841560386, 0.2753549558110535, 0.3661135904258117, 0.40610656316857785, 0.30967168626375496, 0.42328564915806055, 0.15106350649148226, 0.5335676064714789, 0.27250214014202356, 0.29818632756359875, 0.21604858426144347, 0.6543875264469534, 0.28421088529285043, 3.1074571050703526, 20.096686519682407, 80.82333505153656, 103.55176225304604, 90.31633526086807, 63.83504703640938, 26.94959219545126, 24.84987996518612, 21.02962765842676, 29.484154991805553, 38.465404361486435, 71.08113661408424, 71.15689694881439, 71.4724700152874, 74.00416016578674, 77.73133456707001, 82.72531539201736, 71.02503642439842, 26.74709726125002, 1.0719103692099452, 0.22800842765718699, 0.08995769399916753, 0.06582993126357906, 0.020579242991516367, 0.06388892565155402, 0.041221112114726566, 0.05167892282770481, 0.048813342218636535, 0.03782704814511817, 0.043179825370316394, 0.049828659612103365, 0.09360805866890587, 0.07429507546476088, 0.03426947791012935, 0.019862512017425615, 0.025974649179261178, 0.02627456033224007, 0.0787410224438645, 0.060496505539049394, 0.06092881398217287, 0.0855533147114329, 0.026908313629974145, 0.019785276708716992, 0.047378722520079464, 0.010472714893694501, 0.12071063130861148, 0.05727752162783872, 0.05617152120976243, 0.035428727424005046, 0.018782904226100072, 0.05575623763434123, 0.04440288103069179, 0.008276032913272502, 0.03610770720115397, 0.023183800985862035, 0.023828235644032247, 0.033513548551127315, 0.1027608397998847, 0.032115205031004734, 0.050540167721919715, 0.05808885231090244, 0.06608327821595594, 0.03916376743291039, 0.062175685161491856, 0.04201332136290148, 0.05238733247097116, 0.01421583410774474, 0.020496441575232893, 0.0834140443475917, 0.008759280517551815, 0.07157568310503848, 0.020119593827985227, 0.10226314814644866, 0.02908235546783544, 0.026188666015514173, 0.06435396280721761, 0.07205212707049213, 0.03447710485488642, 0.011557333109522006, 0.04821550886845216, 0.039171322496258654, 0.03126865944068413, 0.04105958738364279, 0.026839102793019265, 0.028458788146963343, 0.013040502253716113, 0.05516228571650572, 0.02480448081769282, 0.07288110602530651, 0.03414383601921145, 0.057142773584928364, 0.07347529171966016, 0.021967511856928468, 0.03629843173257541, 0.03265253850258887, 0.019399267148401123, 0.03449847128649708, 0.05648739039315842, 0.054530766283278354, 0.07466516966815107, 0.02791361574054463, 0.04478309070691466, 0.06501883806777187, 0.11016823060344905, 0.03207432011549827, 0.09812585296458565, 0.029521998185373377, 0.07491848693462089, 0.029256168309075292, 0.13774456805549562, 0.06320181564660743, 0.08344336660229601, 0.047033787122927606, 0.1374073509941809, 1.2090270803309977, 11.405220050364733, 62.56119579076767, 86.18471816182137, 98.72222140431404, 96.80941164493561, 98.40373769402504, 86.09293788671494, 80.78816413879395, 77.16901794075966, 52.637469694018364, 44.12351354956627, 28.765203170478344, 12.237884569913149, 12.36186146736145, 37.25264623761177, 68.72714012861252, 60.55576600134373, 54.10887613892555, 69.26234140992165, 41.329781860113144, 15.109452232718468, 3.24605253059417, 0.19841745612211525, 0.22965178010053933, 0.12154819691204466, 0.04237906287016813, 0.1202152254700195, 0.18324923410546035, 0.026137005115742795, 0.32574099430348724, 0.5842273193411529, 1.1388817755505443, 0.4051332810195163, 0.6742947176098824, 1.0307936067692935, 0.8170556696131825, 0.8361554041039199, 0.5527525395154953, 0.2800922922324389, 0.9849866491276771, 0.8119635272305459, 1.0742392879910767, 2.153190323151648, 0.5506916251033545, 1.0967062949202955, 0.8639857044909149, 0.4395864182151854, 0.7157541147898883, 0.4296389379305765, 0.7848455104976892, 0.8142925053834915, 1.1046338570304215, 0.2382790538831614, 0.14597547560697421, 0.053789616795256734, 0.3426592599134892, 0.41837948898319155, 0.200645309232641, 0.035861176875187084, 0.6369174888823181, 0.26792970893438905, 3.505373178049922, 21.342462971806526, 67.39408805966377, 76.93565726280212, 58.611547127366066, 49.74913448095322, 30.527123026549816, 33.57297308743, 40.07000885903835, 52.692464143037796, 71.21977597475052, 90.2642248570919, 89.14418175816536, 85.99073097109795, 86.13893821835518, 87.53388896584511, 92.47891321778297, 80.25265127420425, 24.447494857013226, 0.747200099285692, 0.0584883207193343, 0.06872272642794997, 0.024231926872744225, 0.04989551969629247, 0.04280206478142645, 0.016731953146518208, 0.039604191260878, 0.08904330868972465, 0.031566264369757846, 0.046829759594402276, 0.04166391081525944, 0.03866981249302626, 0.10907291711191647, 0.038617171958321705, 0.05399290217610542, 0.0975548593851272, 0.013604533560283016, 0.011383671480871271, 0.04319346233387478, 0.04304413479985669, 0.09125402561039664, 0.035931020393036306, 0.035542658224585466, 0.017959947799681686, 0.04129309301788453, 0.054570326465182006, 0.030878232246323023, 0.05298559997754637, 0.025999780154961627, 0.029304860618140083, 0.01868719500635052, 0.009557391695125261, 0.01124865162637434, 0.04176259790256154, 0.0029165661544539034, 0.005150105971551966, 0.02486684163159225, 0.02310926152858883, 0.021612323689623736, 0.03883878838678356, 0.02776778557745274, 0.04625481778930407, 0.04821023961994797, 0.03459379273408558, 0.01650774291192647, 0.02581093882326968, 0.05906377460632939, 0.05040757190727163, 0.04490973078645766, 0.01799791421944974, 0.005984614390399656, 0.1542367963702418, 0.18066675314912573, 0.13331430265679955, 0.13595032214652747, 0.12446781329344958, 0.14166629902319983, 0.149248035158962, 0.12046099509461783, 0.11423845047829673, 0.08254369808128104, 0.11333256275975145, 0.15934235678287223, 0.2680952672380954, 0.12991479132324457, 0.10034592836746015, 0.13166146556613967, 0.163798181747552, 0.20287040155380964, 0.1158076549472753, 0.1903464220231399, 0.12949304364155978, 0.2077894305693917, 0.12536903290310875, 0.13027394626988098, 0.12752868264215067, 0.2819923684000969, 0.11632254216237925, 0.22848073043860495, 0.2270171558484435, 0.11805140486103483, 0.1296649844152853, 0.21030419797170907, 0.26743968366645277, 0.1567418416379951, 0.2548160485457629, 0.1837999076815322, 0.15196172782452777, 0.09274216528865509, 0.1582819316536188, 0.23283480695681646, 0.28775553102605045, 0.08413714109337889, 0.3399531223112717, 5.461771348491311, 44.79827754199505, 99.73290637135506, 106.5632526576519, 115.24834781885147, 105.54421573877335, 106.28302529454231, 97.76043981313705, 92.67815932631493, 89.26249220967293, 62.86359116435051, 45.591120198369026, 27.567336447536945, 19.120264314115047, 30.56906897574663, 93.23795288801193, 80.94557449221611, 92.55015179514885, 104.52343091368675, 119.64789614081383, 50.978455916047096, 16.249978132545948, 5.468784822151065, 0.3883708664216101, 0.4232027067337185, 0.6534397741779685, 0.27580092719290406, 0.2535485790576786, 0.44330273754894733, 0.2363186707952991, 0.4221404856070876, 0.4785969655495137, 0.7250139804091305, 0.4104141070274636, 0.4457297088811174, 0.36093298404011875, 0.3355271910550073, 0.36268273077439517, 0.2195340214530006, 0.315722149098292, 0.28875677729956806, 0.26300624187570065, 0.40534256666433066, 0.5556749389506876, 0.4022789216833189, 0.43268310895655304, 0.4766760498750955, 0.2897373028099537, 0.2421723012230359, 0.22540598292835057, 0.38560764282010496, 0.3543723688926548, 0.9080341283697635, 0.4245575121603906, 0.4762086452683434, 0.24601347948191687, 0.8646478783339262, 0.841906217392534, 0.6279180280398577, 0.25545195036102086, 0.6280200881883502, 0.5075920221861452, 7.236439995467663, 30.485786944627762, 120.63680827617645, 139.7719582915306, 122.39023178815842, 85.67861571907997, 41.097272336483, 39.035252183675766, 29.992210529744625, 43.28441597521305, 58.43112900853157, 96.49308621883392, 95.88418409228325, 98.31454887986183, 96.56711384654045, 99.02522474527359, 101.57182529568672, 95.27632310986519, 41.79406374692917, 3.003435549326241, 0.595709471963346, 0.34813666599802673, 0.17590865143574774, 0.17012429307214916, 0.1608580004540272, 0.0849422748433426, 0.1303898252081126, 0.23751247470499948, 0.15872502350248396, 0.21719955140724778, 0.1264018056099303, 0.19649933092296124, 0.25287307624239475, 0.12660043401410803, 0.09749179167556576, 0.1373699022224173, 0.1086910004960373, 0.14267061778809875, 0.10760367251350544, 0.15343640494393185, 0.2810069447150454, 0.08894924147170968, 0.08753976944717579, 0.14023380557773635, 0.10243581622489728, 0.1500372201553546, 0.14561801275704056, 0.08930680822231807, 0.17452168132876977, 0.06790156228817068, 0.11808672366896644, 0.1401082193478942, 0.09086144433240406, 0.11256617653998546, 0.14397069724509493, 0.07667067533475347, 0.12958211620571092, 0.14083222893532366, 0.14219559874618426, 0.1590507966466248, 0.12182783815660514, 0.20070592785486951, 0.10622689209412783, 0.13848943199263886, 0.12150522656156681, 0.09548621921567246, 0.13596280507044867, 0.12997999641811475, 0.18195161857875064, 0.0877821326139383, 0.11262709202128462], [0.04465205711312592, 0.05238862751866691, 0.0400372455624165, 0.07091351668350399, 0.09125111639150418, 0.04102812774362974, 0.010674536388251, 0.034815483377315104, 0.018552751243987586, 0.04662724975787569, 0.02600151492515579, 0.03636031200585421, 0.02883015142288059, 0.02474340577464318, 0.014391190616152016, 0.02837047999491915, 0.050410076655680314, 0.029684342989639845, 0.07276933858520351, 0.05530962058401201, 0.02964156559755793, 0.009158247976301936, 0.07782259985106066, 0.018711524462560192, 0.022530660935444757, 0.03181146996212192, 0.09353097921120934, 0.016303813717968296, 0.028245515313756187, 0.059937761106994, 0.0959782260179054, 0.03411633944779169, 0.0306816837110091, 0.08938132727053016, 0.05109440731757786, 0.044835720109404065, 0.029984833017806523, 0.024441129025944974, 0.07674163207411766, 0.144508398079779, 0.1163355668541044, 0.36700024909805506, 15.123230293393135, 58.81654992699623, 84.20415803790092, 90.65770894289017, 87.6784636080265, 70.88578149676323, 72.80720919370651, 75.82716554403305, 48.16912226378918, 24.960400834679604, 18.033435232937336, 16.490174643695354, 28.822025321424007, 45.9388243407011, 71.86210870742798, 73.6559696495533, 46.43487632274628, 50.31794875860214, 45.13886086642742, 39.01817969977856, 6.868360871449113, 0.18371119134826586, 0.1274729918804951, 0.054078427274362184, 0.17311269912170246, 0.05885819598915987, 0.06818305890192278, 0.2151557509205304, 0.08747662010136992, 0.09016017414978705, 0.019692051828315016, 0.18595128989545628, 0.4458974639419466, 0.418539674137719, 0.08831809682305902, 0.0288799458212452, 0.46163485385477543, 0.310919652110897, 0.3586086072027683, 0.7804419030435383, 0.7656530372332782, 2.0267430832609534, 1.244271257892251, 2.866866602562368, 1.8656455026939511, 0.7951162406243384, 0.3008312528254464, 0.23117068922147155, 0.07287018161150627, 0.2366169251035899, 0.11518319704919122, 0.40477123169694096, 0.5028914369177073, 0.14884224365232512, 0.11123125324957073, 0.17800230940338224, 0.16478047356940806, 0.13685483689187095, 0.23885089351097122, 0.08589157077949494, 0.21970603644149378, 0.532668064115569, 0.35501913574989885, 0.012854710221290588, 0.19331308314576745, 1.3204300962388515, 18.643471598625183, 49.669296965003014, 76.71444833278656, 87.57301926612854, 72.66994535923004, 50.60891434550285, 25.95412541180849, 22.276129871606827, 18.003525137901306, 31.9502055644989, 40.21700777113438, 49.95493903756142, 67.05114886164665, 73.47130715847015, 83.26780468225479, 93.13391447067261, 33.28151732683182, 2.971449578180909, 0.2500154514564201, 0.10560172915575095, 0.03071236966206925, 0.06444814134738408, 0.03217042081814725, 0.09340209042420611, 0.020021832569909748, 0.04620508276275359, 0.02238484190456802, 0.01835245857364498, 0.06396878816303797, 0.05351644336769823, 0.026452430865901988, 0.022297995783446822, 0.03252751259424258, 0.06407249587937258, 0.08790085397777148, 0.05977804721624125, 0.04376828539534472, 0.03949896214180626, 0.023744322861602996, 0.03208595699106809, 0.01978853288164828, 0.02247106091090245, 0.015450864320882829, 0.06632170800003223, 0.009412196068296907, 0.022175517297000624, 0.05177496044780128, 0.021041430300101638, 0.034705144571489654, 0.02813884086208418, 0.020502846309682354, 0.022672143968520686, 0.05598979892965872, 0.0302748327885638, 0.04636249228497036, 0.02992644083860796, 0.030146266835799906, 0.06579432301805355, 0.012141503520979313, 0.0447415193048073, 0.0468741956865415, 0.057073909702012315, 0.04137241005082615, 0.04923843327560462, 0.08308827120345086, 0.04536229986115359, 0.03507554305542726, 0.03667539080197457, 0.07485328926122747, 0.036105577237321995, 0.013788682663289364, 0.018677650987228844, 0.054538777767447755, 0.007346690081249108, 0.015832054559723474, 0.037365855314419605, 0.008612698929937324, 0.13058879500022158, 0.01673600712820189, 0.018561124525149353, 0.0391262073389953, 0.045290422858670354, 0.05618185561615974, 0.030500683169520926, 0.002326731068933441, 0.11452416249085218, 0.04830048848816659, 0.008417233002546709, 0.01931838232849259, 0.02608181344839977, 0.08022272770176642, 0.025920277585100848, 0.019162227035849355, 0.04702529695350677, 0.02351458362682024, 0.06852092163171619, 0.05481416650582105, 0.057624034088803455, 0.02552966670918977, 0.023949356000230182, 0.05053581502579618, 0.029381222047959454, 0.011121646966785192, 0.0340990733820945, 0.012204487738927128, 0.06816040855483152, 0.07020171542535536, 0.09968601065338589, 0.12217061390401796, 0.29605015937704593, 4.724736297503114, 42.54008151590824, 85.35993441939354, 99.28693190217018, 97.56826892495155, 84.69315379858017, 82.9662224650383, 85.9486672282219, 61.84749148786068, 44.24512222409248, 38.25880564749241, 30.94953875988722, 22.815680019557476, 23.914299868047237, 32.60758548974991, 45.53345449268818, 42.97325827181339, 45.42404316365719, 50.90418890118599, 43.8551339507103, 9.132936280220747, 0.674218840431422, 0.22832827846286818, 0.1680912685696967, 0.24934683577157557, 0.021710110922867898, 0.21731744898715988, 0.20455957419471815, 0.21728256804635748, 0.3086105635156855, 0.2832842990756035, 0.43218132806941867, 0.6552456866484135, 0.7408133544959128, 0.5299219395965338, 1.922612520866096, 3.228971022181213, 2.9159761173650622, 1.9536085263825953, 2.907488322816789, 3.503757552243769, 6.507631503045559, 8.75647148117423, 6.762541774660349, 6.61007828079164, 4.294362366199493, 2.7987980050966144, 1.6770497476682067, 2.4028260027989745, 2.5221647741273046, 2.6520543918013573, 1.3728795130737126, 1.619151660706848, 0.6157687737140805, 0.5316021619364619, 0.6307544570881873, 0.30896248994395137, 0.5547752184793353, 0.5606264295056462, 0.30590246664360166, 0.33207771833986044, 0.530835137469694, 0.3752261842601001, 0.03881755183101632, 0.21738155570346862, 1.8187860609032214, 17.758396491408348, 45.8081379532814, 61.903139501810074, 62.645254880189896, 51.02981016039848, 43.732309341430664, 28.454423546791077, 34.306455329060555, 40.975815653800964, 48.92061933875084, 52.78852678835392, 65.02321287989616, 80.1958367228508, 79.69372406601906, 93.31281647086143, 102.05795601010323, 35.8920456469059, 2.954194941557944, 0.24901479890104383, 0.03633309002907481, 0.059130122608621605, 0.048095362581079826, 0.022072583269618917, 0.10648085502907634, 0.005926528810960008, 0.03403084403544199, 0.010797266277222661, 0.02365448402997572, 0.008585950072301785, 0.04118931850825902, 0.024650251398270484, 0.025351547556056175, 0.04328767055994831, 0.045956993926665746, 0.05667458230163902, 0.09531801144476049, 0.023456903909391258, 0.07548879031674005, 0.028431527207430918, 0.04398516692162957, 0.028476211919041816, 0.05385147480410524, 0.01131599225118407, 0.03318570110423025, 0.052954574493924156, 0.0424612668575719, 0.010818562204804039, 0.015462581905012485, 0.05095094646094367, 0.018567406805232167, 0.015421137595694745, 0.04195292538497597, 0.04006044880952686, 0.028265742548683193, 0.03164189292874653, 0.026799548177223187, 0.07819500213372521, 0.08349422598257661, 0.034009726223303005, 0.04960120619216468, 0.022212789808691014, 0.015439748804055853, 0.021202522730163764, 0.03821320613496937, 0.06530414189910516, 0.025167270432575606, 0.041220963685191236, 0.018440716630721, 0.23984792438568547, 0.1677806649240665, 0.0945316391880624, 0.18348982353927568, 0.2442973668803461, 0.07892913461546414, 0.11682709126034752, 0.1764524230384268, 0.1042809066711925, 0.22678821813315153, 0.07567989334347658, 0.07112548148143105, 0.09364310288219713, 0.10568570316536352, 0.17797679436625913, 0.21510595281142741, 0.10558639638475142, 0.18321565934456885, 0.13607488421257585, 0.11353394453180954, 0.16232503345236182, 0.17348699388094246, 0.108227447635727, 0.14459764875937253, 0.1125846263312269, 0.13356749375816435, 0.2712587162386626, 0.20027180114993826, 0.13412499509286135, 0.20370554033434018, 0.19407185493037105, 0.11559875521925278, 0.14244513848097995, 0.26969747501425445, 0.1317899758578278, 0.07809087139321491, 0.13272048061480746, 0.11180499277543277, 0.29632157762534916, 0.20082024828298017, 0.2021940378472209, 0.6797107332386076, 28.190504908561707, 90.8410795032978, 112.02998131513596, 109.8564675450325, 108.32191228866577, 90.53210288286209, 96.40667125582695, 101.83387443423271, 68.95494550466537, 46.00866079330444, 35.35031631588936, 31.607657745480537, 47.784419506788254, 68.11449140310287, 97.0616041123867, 107.89508879184723, 65.44735372066498, 74.27920460700989, 69.12462919950485, 61.36816240847111, 12.167253959923983, 1.4299194398336112, 0.5427831807173789, 0.46166519285179675, 0.3940358280669898, 0.14404927584109828, 0.3196924610529095, 0.27980350772850215, 0.31355487008113414, 0.21725637023337185, 0.21095412637805566, 0.4729618679266423, 0.652619315078482, 0.7357377768494189, 0.3124385612318292, 1.0399425658397377, 1.8821944459341466, 2.2444533510133624, 1.1967476829886436, 2.56924947258085, 3.0292551638558507, 5.849180985242128, 9.368182606995106, 6.094299182295799, 6.524177715182304, 2.6664093090221286, 1.4870564988814294, 0.4390884668100625, 0.7708598859608173, 1.3428304879926145, 1.0788775328546762, 0.5821838008705527, 0.8067916485015303, 0.24556939315516502, 0.21767635160358623, 0.17297267069807276, 0.1586624901392497, 0.23236455250298604, 0.45556260156445205, 0.4321287840139121, 0.4836932342732325, 0.8638538990635425, 0.8168980968184769, 0.11437683133408427, 0.38604488654527813, 2.9811250464990735, 28.813183195888996, 71.44927605986595, 112.30961591005325, 121.98423877358437, 97.49966740608215, 71.7467848956585, 40.56593544781208, 33.01460064947605, 31.68202355504036, 51.24370828270912, 59.6177863329649, 70.69005399942398, 92.19841986894608, 95.81635773181915, 102.62727946043015, 114.05366912484169, 55.78187316656113, 9.338999222964048, 0.5735759565141052, 0.1600472189602442, 0.1162625766301062, 0.13930714514572173, 0.20511003996944055, 0.17146055964985862, 0.09236309109837748, 0.122631346603157, 0.07770796772092581, 0.09753853213624097, 0.1646289270138368, 0.13924559141742066, 0.10566425509750843, 0.20164351270068437, 0.1083418497000821, 0.19770235230680555, 0.18125094211427495, 0.14090662181843072, 0.15299666760256514, 0.1875182901858352, 0.1044024333532434, 0.2973745367489755, 0.14114320365479216, 0.11436107553890906, 0.08352783785085194, 0.1259215470054187, 0.10862034803722054, 0.1322745982906781, 0.15844656969420612, 0.11966324571403675, 0.17200332193169743, 0.19932645343942568, 0.06706340296659619, 0.08261582741397433, 0.1863312695058994, 0.20321879535913467, 0.11380727752111852, 0.14040259964531288, 0.16668388940161094, 0.14944523863960057, 0.09074932066141628, 0.1488844124833122, 0.15922380611300468, 0.22164348716614768, 0.09228889859514311, 0.12254136119736359, 0.2223800984211266, 0.09653019835241139, 0.1808618934592232, 0.10211398388491943], [0.08336770464666188, 0.03973499478888698, 0.035637801556731574, 0.02661362163053127, 0.07664301549084485, 0.016196788601519074, 0.05877530922589358, 0.02086232965666568, 0.05292801673931535, 0.010288500852766447, 0.04121857025893405, 0.01761999592417851, 0.041987817457993515, 0.06745556864188984, 0.07966901874169707, 0.02444038873363752, 0.021402813545137178, 0.008107169269351289, 0.035656299587571993, 0.022322900404105894, 0.050126327623729594, 0.018837977149814833, 0.020417326777533162, 0.010755394305306254, 0.0053643997216568096, 0.004178760827926453, 0.040335262383450754, 0.024948633727035485, 0.07035600792733021, 0.01478649464843329, 0.030457245266006794, 0.033214021459571086, 0.011833669941552216, 0.021662346298398916, 0.03493191521556582, 0.01612309704796644, 0.06915879013831727, 0.041691088263178244, 0.07043114295811392, 0.21804001880809665, 2.8132493421435356, 39.892478585243225, 88.57224404811859, 93.37196409702301, 87.57979050278664, 71.29185810685158, 55.65481178462505, 56.10351450741291, 59.32851925492287, 38.07094372808933, 24.959270395338535, 14.308539759367704, 23.889152817428112, 39.9039501696825, 56.235679015517235, 53.32106061279774, 46.78259186446667, 43.08042012155056, 37.3831008374691, 27.33497891575098, 6.231546392664313, 0.2612273138947785, 0.1285948371514678, 0.01657153607084183, 0.06785938603570685, 0.09324087368440814, 0.07537995435995981, 0.11933799207326956, 0.0485215408843942, 0.13372122222790495, 0.1761957141570747, 0.10488105923286639, 0.30244827386923134, 0.7903135952074081, 1.5516087412834167, 2.249454357661307, 0.8479036611970514, 3.2407544273883104, 5.854648416861892, 4.075117455795407, 2.712847567163408, 4.880336048081517, 5.44244178570807, 7.8364610485732555, 9.400019198656082, 10.543785374611616, 17.84858275204897, 6.869093282148242, 4.0248490031808615, 4.711032332852483, 0.4031463438877836, 4.158042781054974, 3.127578212879598, 4.208117444068193, 4.3217812199145555, 3.5143601708114147, 1.1821439978666604, 1.6364110470749438, 0.36082480859477073, 0.46494658396113664, 0.24489550822181627, 0.20250173227395862, 0.2366675395751372, 0.33068969438318163, 0.07785164008964784, 0.04944629028614145, 0.21696898096706718, 0.14146342553431168, 0.18602204625494778, 0.36839907872490585, 17.816261686384678, 52.65714883804321, 79.83449891209602, 76.63016125559807, 75.86778536438942, 64.7042427957058, 42.99166068434715, 59.2818159610033, 57.691935673356056, 26.211745887994766, 33.635525330901146, 68.65461722016335, 72.93758779764175, 81.37813568115234, 85.81475481390953, 62.024178206920624, 25.396877713501453, 4.139422355219722, 0.2979735686676577, 0.028268154528632294, 0.05046278027293738, 0.05771772652224172, 0.03220855236577336, 0.027549087644729298, 0.01899825507280184, 0.04430539622262586, 0.06970622052904218, 0.03487356014375109, 0.014382447188836522, 0.06163130128697958, 0.017456962777941953, 0.07338098701438867, 0.07894756956375204, 0.038389250985346735, 0.01956320571480319, 0.07881320372689515, 0.007534124579251511, 0.02727604965912178, 0.12056683277478442, 0.027633865029201843, 0.013940028838987928, 0.02938916859420715, 0.057898658415069804, 0.062370484083658084, 0.03612399363191798, 0.0432167175313225, 0.04399914156238083, 0.097181937599089, 0.01980046661628876, 0.03498424404824618, 0.04110907007998321, 0.07847968998248689, 0.05272981878079008, 0.030751211816095747, 0.04564809722069185, 0.03825387953838799, 0.021774358647235204, 0.028242980879440438, 0.05581508252362255, 0.058388078832649626, 0.0516289725783281, 0.010192446534347255, 0.043179231652175076, 0.008700263078935677, 0.025211656429746654, 0.02566836483310908, 0.0865672220243141, 0.05280123194097541, 0.07809392162016593, 0.01751231957314303, 0.0746799458283931, 0.014079679694987135, 0.04288751937565394, 0.024457608415104914, 0.041646114113973454, 0.029697412210225593, 0.004709323129645782, 0.03353947919094935, 0.07317101117223501, 0.051058034659945406, 0.05792831092549022, 0.09047655912581831, 0.08848735844367184, 0.03918865535524674, 0.01938231649546651, 0.017152298169094138, 0.06976242337259464, 0.07977078203111887, 0.05964578165730927, 0.033954161626752466, 0.041571854817448184, 0.05519872145669069, 0.04690109853981994, 0.026087483456649352, 0.041232622825191356, 0.027417640303610824, 0.035476707271300256, 0.031307507160818204, 0.05068813341495115, 0.027024756600440014, 0.015286650232155807, 0.05346226658730302, 0.03319872950669378, 0.022959611160331406, 0.04065217428433243, 0.13733410101849586, 0.6999708304647356, 25.930572375655174, 89.410729855299, 102.88153901696205, 101.15139305591583, 88.17499056458473, 74.36952576041222, 65.54437011480331, 74.30649474263191, 64.81565281748772, 42.74693101644516, 26.45470105111599, 14.539897944778204, 41.62916399538517, 58.03270138800144, 45.38190722465515, 50.12752577662468, 47.99863301217556, 43.63306626677513, 37.140453457832336, 9.302095603197813, 0.26897845265921205, 0.3119301307015121, 0.09220257939887233, 0.07311750974622555, 0.23430105327861384, 0.1580795182962902, 0.6878312537446618, 0.7948553015012294, 0.9283123339992017, 0.7210956781636924, 2.307685757987201, 2.3168648779392242, 1.8644965393468738, 2.6195908337831497, 4.713523099198937, 4.509269809350371, 5.473827626556158, 8.653056230396032, 10.942439083009958, 10.447319000959396, 11.465233080089092, 11.14335235208273, 10.87269477546215, 12.852603234350681, 16.928600817918777, 19.44188855588436, 20.37287089973688, 11.798744034022093, 11.355299279093742, 8.788999635726213, 5.2910645585507154, 4.345639189705253, 2.9159271949902177, 3.9459759229794145, 2.6800857251510024, 2.2863031178712845, 3.0910039879381657, 1.1422887677326798, 1.8298431113362312, 2.3205250315368176, 0.8578872692305595, 0.7142877497244626, 0.6222484947647899, 0.4756639088736847, 0.06259887260966934, 0.11490891411085613, 0.11614420407568105, 0.09932722678058781, 0.3960718953749165, 14.94272667914629, 46.612699180841446, 56.89913861453533, 50.716706961393356, 53.617117926478386, 47.48425841331482, 30.65643198788166, 54.687497690320015, 68.9252083003521, 46.0437823086977, 51.69880226254463, 81.35721400380135, 82.90569171309471, 93.97954389452934, 98.18053767085075, 64.98605087399483, 24.417704455554485, 3.564655934460461, 0.1605932615348138, 0.014198369517544052, 0.06471952248830348, 0.04491733780014329, 0.0323916401976021, 0.049006018598447554, 0.017352216054860037, 0.06866228592116386, 0.08071494230534881, 0.03324970763060264, 0.02600074680231046, 0.045338265408645384, 0.038639826016151346, 0.05773708544438705, 0.03907896221789997, 0.03412206511711702, 0.020609865860024, 0.055359166362904944, 0.018022497861238662, 0.016076343599706888, 0.04759829804243054, 0.031156892000581138, 0.04819285481062252, 0.028556230281537864, 0.021486190125870053, 0.03358461290190462, 0.04282031790353358, 0.08114744370686822, 0.00980472725132131, 0.08847822260577232, 0.03743533146916889, 0.016202799997699913, 0.010231157884845743, 0.033579926239326596, 0.05515698307135608, 0.048169380679610185, 0.051527966279536486, 0.055133174973889254, 0.02532994549255818, 0.0487910852098139, 0.048842812902876176, 0.07976235123351216, 0.04053205768286716, 0.03165442780300509, 0.09634419388021342, 0.02893982415116625, 0.05306188533722889, 0.033644533905317076, 0.17280730535276234, 0.1323990267701447, 0.208871214708779, 0.04958663783327211, 0.19274746271548793, 0.10543476077145897, 0.1539051454165019, 0.12013122919597663, 0.180289430427365, 0.07150816993089393, 0.1842622656840831, 0.13292351737618446, 0.13544925372116268, 0.2681998210027814, 0.1674207381438464, 0.1619784059585072, 0.14959651802200824, 0.11181705267517827, 0.16588542755926028, 0.1281521312193945, 0.18250002118293196, 0.11817573686130345, 0.1115857252443675, 0.1591389489476569, 0.13796504528727382, 0.12029697303660214, 0.17893159703817219, 0.19241649453761056, 0.10241322524962015, 0.11716136199538596, 0.22755007725208998, 0.11648764033452608, 0.12031902224407531, 0.10382492371718399, 0.13156626286217943, 0.1235054036078509, 0.189993352687452, 0.20057542860740796, 0.13445606717141345, 0.5231185234151781, 6.269591376185417, 70.43827950954437, 122.38273859024048, 114.53258782625198, 108.44988942146301, 95.09224578738213, 79.74485412240028, 78.37070345878601, 81.05234876275063, 58.44945162534714, 42.16223359107971, 27.641016393899918, 43.55776570737362, 65.21507978439331, 77.39238515496254, 73.88299226760864, 66.4552952349186, 62.318943589925766, 61.42849177122116, 47.80689910054207, 11.408018600195646, 0.5791135062463582, 0.5304841906763613, 0.1524191876524128, 0.3366801026277244, 0.44629970798268914, 0.1220103916421067, 0.47749267949257046, 0.3598580276593566, 0.42750653985422105, 0.602322838967666, 1.3833264587447047, 2.066920227371156, 4.945523450151086, 6.123426044359803, 8.917094562202692, 4.300138531252742, 9.757406171411276, 12.201881501823664, 13.257658649235964, 10.581600945442915, 12.50411443412304, 17.93933518230915, 21.14014472812414, 25.72207946330309, 28.179105520248413, 35.24138756096363, 29.01711255311966, 20.84458138793707, 13.29231658950448, 10.131213013082743, 13.18658821284771, 11.356263477355242, 13.012264017015696, 8.706703651696444, 9.771482516080141, 4.938585497438908, 3.248748485930264, 1.179613689891994, 1.9278153916820884, 0.9982603462412953, 0.40987222047988325, 0.32435973873361945, 0.3585890441900119, 0.37807187531143427, 0.24538832396501675, 0.42190032661892474, 0.1822284099762328, 0.28231805248651654, 1.3324229652062058, 29.11944106221199, 80.15055075287819, 118.59566420316696, 110.231803804636, 106.79017648100853, 89.5108088850975, 59.174361526966095, 72.70098969340324, 73.2949510216713, 42.62858256697655, 51.87223255634308, 94.34229522943497, 96.66176676750183, 101.63478791713715, 108.93590614199638, 84.17363807559013, 38.37493881583214, 9.941216558218002, 0.8235422777943313, 0.16281102143693715, 0.2739709394518286, 0.1795735993073322, 0.1985183436772786, 0.083782164438162, 0.14175167569192126, 0.2133058142499067, 0.1890323605039157, 0.14787973748752847, 0.12048197560943663, 0.10844523087143898, 0.1370330562349409, 0.19372761715203524, 0.15967428975272924, 0.11477517167804763, 0.18070561200147495, 0.1495404858724214, 0.11878380813868716, 0.17642012477153912, 0.26237123063765466, 0.10872257887967862, 0.10868697063415311, 0.09301037745899521, 0.1397380806156434, 0.22084590105805546, 0.08986678833025508, 0.1600169690209441, 0.08733220558497123, 0.1993988425238058, 0.0994959837407805, 0.1293322944547981, 0.13441916758893058, 0.16641168447677046, 0.1765225559938699, 0.11147835873998702, 0.19950424233684316, 0.1572014536941424, 0.1826855432591401, 0.14155846496578306, 0.15518546890234575, 0.10942960070678964, 0.14697295177029446, 0.14121784886810929, 0.22792869131080806, 0.12192410955321975, 0.13911859510699287, 0.16138323320774361], [0.027732099406421185, 0.037614352331729606, 0.04801929244422354, 0.04231244027323555, 0.0957539860974066, 0.03385306627023965, 0.04037619182781782, 0.02823339975293493, 0.005837819435328129, 0.16663278511259705, 0.032081637691590004, 0.03293608715466689, 0.03897402624716051, 0.03627561811299529, 0.07249706686707214, 0.04524452844634652, 0.03606098529417068, 0.0657056734780781, 0.013720627721340861, 0.024084096621663775, 0.027289890713291243, 0.036058870173292235, 0.019867098490067292, 0.05926456637098454, 0.04109773006348405, 0.033460210397606716, 0.019866577131324448, 0.04421247562277131, 0.023117736855056137, 0.016391225726692937, 0.08145363899529912, 0.039599701267434284, 0.06343729910440743, 0.02786140194075415, 0.03402376765734516, 0.07680238428292796, 0.02646558357810136, 0.09543288106215186, 0.085260975320125, 7.445671018213034, 70.39682373404503, 100.95218494534492, 96.95559740066528, 78.16228464245796, 67.86321848630905, 45.952298417687416, 25.22059377282858, 13.048036247491837, 10.578558258712292, 13.734210077673197, 15.581895131617785, 44.621058851480484, 42.550519555807114, 41.5484981238842, 36.771675646305084, 45.172709450125694, 38.024331629276276, 21.118993163108826, 5.0738302152603865, 0.4313413653289899, 0.2932864608010277, 0.060553450530278496, 0.034769741105264984, 0.15546107286354527, 0.07991686637979001, 0.08134209419949912, 0.2303070222842507, 0.018703216119320132, 0.4083279299084097, 0.9476614894811064, 0.604816455161199, 1.2110203108750284, 2.0412979647517204, 1.8849887209944427, 0.7551851926837116, 1.7089499859139323, 2.7469336381182075, 5.627393536269665, 9.083591178059578, 7.317056469619274, 6.732405591756105, 5.682601248845458, 4.320500688627362, 13.35602967068553, 16.361652240157127, 8.358718324452639, 9.560402892529964, 8.729491028934717, 5.651141786947846, 12.429572883993387, 15.320160426199436, 5.5819327756762505, 8.810027707368135, 2.2726851236075163, 2.269932646304369, 6.13108073361218, 8.34557007998228, 7.549649588763714, 2.576750982552767, 4.59692208096385, 1.0499070561490953, 0.8313719357829541, 0.7772444339934736, 1.1813513841480017, 0.48183353093918413, 0.2102094257134013, 0.06348354232613929, 0.11758840119000524, 0.20809604146052152, 0.10629111013258807, 0.17632909293752164, 0.2678407996427268, 17.693908251821995, 60.660784766077995, 66.68446093797684, 86.30275502800941, 76.30837172269821, 46.63817301392555, 43.29873360693455, 33.983085080981255, 18.934420086443424, 28.235249407589436, 53.71416471898556, 60.00668406486511, 76.35643154382706, 88.11514377593994, 84.70504716038704, 49.28325667977333, 14.914867524057627, 3.0517392698675394, 0.03753991120902356, 0.03531855560140684, 0.0141318081477948, 0.029029752040514722, 0.036169498416711576, 0.022716337007295806, 0.06456330782384612, 0.036933621086063795, 0.03311920096166432, 0.07327133469516411, 0.058794285941985436, 0.04155235117650591, 0.09601707002730109, 0.02515670410502935, 0.01770106071489863, 0.082250059931539, 0.00947455224377336, 0.026950421233777888, 0.0035418972356637823, 0.06592877049115486, 0.00835929817185388, 0.030215694750950206, 0.08217331444029696, 0.020450677038752474, 0.024062542797764763, 0.057066187655436806, 0.06267699107411318, 0.03235740863601677, 0.06305477392743342, 0.021078984827909153, 0.02193924901803257, 0.046319169414346106, 0.04928152236971073, 0.0385523935983656, 0.03250652094720863, 0.030887533212080598, 0.006883144178573275, 0.022172801036504097, 0.021454806555993855, 0.043497728038346395, 0.0646653382864315, 0.049242993773077615, 0.033559016228537075, 0.07559570411103778, 0.016989812356769107, 0.030498825944960117, 0.03829594446870033, 0.041499629005556926, 0.058553421913529746, 0.026401764444017317, 0.01804752308089519, 0.03772874697460793, 0.041272097660112195, 0.019628203008323908, 0.10545971177634783, 0.07966104807564989, 0.05287324253004044, 0.042587253847159445, 0.03685103860334493, 0.018351439975958783, 0.028973109474463854, 0.0312221008061897, 0.052298642112873495, 0.05931644620432053, 0.017131928070739377, 0.017860425796243362, 0.007666049677936826, 0.06521863164380193, 0.06992856797296554, 0.09763826194102876, 0.06117361510405317, 0.06947533838683739, 0.010552261064731283, 0.05497251855558716, 0.04532183796982281, 0.020800230449822266, 0.025415951131435577, 0.05836855292727705, 0.031895239881123416, 0.0724412573617883, 0.024963975774880964, 0.060083838034188375, 0.05848898865224328, 0.03150013159029186, 0.09303141734562814, 1.8627640698105097, 58.90141077339649, 106.62535652518272, 107.02310398221016, 94.24942821264267, 80.09885832667351, 56.51844464242458, 45.93615688383579, 39.3989572674036, 33.592203855514526, 27.275447510182858, 25.795692913234234, 40.24645239114761, 44.331544786691666, 33.71203422546387, 33.44642087817192, 45.6572974473238, 49.040806889534, 31.179076842963696, 8.566347733139992, 0.1701548250275664, 0.4752513935090974, 0.08712626702617854, 0.12347082694759592, 0.4392376681789756, 0.29942954366561025, 0.9140465932432562, 1.108638010919094, 1.0327702132053673, 2.256412021815777, 2.5213480554521084, 3.0845127487555146, 2.77213626075536, 2.4192107236012816, 0.8199467801023275, 0.5443266697693616, 2.0162219228222966, 2.9565596021711826, 1.213342105038464, 2.7382057439535856, 9.277854803949594, 7.696315543726087, 11.029104832559824, 13.676121644675732, 22.491452917456627, 21.55816789716482, 13.933807667344809, 10.717153921723366, 12.901460062712431, 6.884206496179104, 8.397264406085014, 3.2102463394403458, 2.4579123593866825, 1.266006922814995, 2.5239418912678957, 4.1339463740587234, 2.534868917427957, 4.185594627633691, 6.258493596687913, 4.067126959562302, 4.415426244959235, 1.6178387124091387, 1.6884564980864525, 1.2751370016485453, 1.585862715728581, 0.8999000117182732, 0.15775362640852109, 0.10952169381198473, 0.080902624031296, 0.07141914931708016, 0.06668495960184373, 0.23266668082214892, 0.6007031165063381, 18.838739320635796, 53.924453034996986, 56.49335078895092, 57.5467074662447, 56.871487498283386, 49.452526196837425, 48.59705530107021, 36.6010420024395, 31.16329248994589, 47.740858644247055, 66.74379855394363, 71.0389132797718, 87.65561163425446, 101.42372444272041, 91.9520790874958, 55.138259902596474, 14.302689973264933, 2.5327320070937276, 0.08398669291636907, 0.06005045994243119, 0.07305168124730699, 0.04373863659566268, 0.02900681967730634, 0.05027511710068211, 0.06492845190223306, 0.029889945726608858, 0.05145528404682409, 0.05027018181863241, 0.06829300065874122, 0.015925021543807816, 0.030579931553802453, 0.05939206363109406, 0.017896523859235458, 0.041391182676306926, 0.027831654806504957, 0.04892103526799474, 0.017809130404202733, 0.03311233609565534, 0.02537465432396857, 0.07419609522912651, 0.05899609444895759, 0.03905628218490165, 0.043674418557202443, 0.07293958726222627, 0.036485412128968164, 0.03241224963858258, 0.027552989486139268, 0.015527624655078398, 0.0601642163383076, 0.030459256486210506, 0.05575326162215788, 0.059842628907063045, 0.0642517839150969, 0.03923466480046045, 0.050663564616115764, 0.03717493782460224, 0.01576380480400985, 0.01785817523341393, 0.07157826577895321, 0.022328201193886343, 0.04419783675984945, 0.06731917674187571, 0.07245804474223405, 0.04920173036225606, 0.09458463595365174, 0.11436055603553541, 0.19559662701794878, 0.07798755701514892, 0.14775744639337063, 0.1970151680870913, 0.14554734545527026, 0.08309200420626439, 0.1624262920813635, 0.2716769609833136, 0.16164022410521284, 0.21142766112461686, 0.09630203247070312, 0.11349444001098163, 0.18821780889993533, 0.10837676774826832, 0.1537277572788298, 0.11206218405277468, 0.15520569984801114, 0.12277688176254742, 0.23390079819364473, 0.2044569796998985, 0.19283999368781224, 0.17781537724658847, 0.11980044655501842, 0.207291790866293, 0.06351130607072264, 0.11403054522816092, 0.218530519050546, 0.08285753006930463, 0.10945287445792928, 0.08858103974489495, 0.07266390908625908, 0.20482827618252486, 0.19335874007083476, 0.1775799531606026, 0.20925293094478548, 0.1939017843687907, 0.2172864569001831, 19.677804596722126, 106.69006705284119, 125.40776386857033, 114.46286916732788, 103.21022137999535, 94.28708419203758, 65.97193077206612, 39.58245702087879, 25.729853846132755, 21.993928514420986, 24.67331673949957, 25.58420956134796, 67.56010115146637, 65.32750815153122, 58.980640321969986, 53.84599484503269, 66.494569927454, 61.98683001101017, 39.55032214522362, 10.173369850963354, 0.541871526511386, 0.49395125883165747, 0.3329230839153752, 0.289209695183672, 0.4814393911510706, 0.1677771026152186, 0.45739160967059433, 0.46862021496053785, 0.4142948566004634, 1.5905352775007486, 3.5494733741506934, 5.412420546635985, 8.392670452594757, 9.488247614353895, 6.810749787837267, 7.488634837791324, 10.168154630810022, 11.790512725710869, 24.0981625020504, 24.469258189201355, 18.693619407713413, 17.791734002530575, 22.973966225981712, 25.57630218565464, 34.50085669755936, 31.453131437301636, 23.46719305962324, 26.445839926600456, 28.01671363413334, 20.710777267813683, 30.82734491676092, 42.19564139842987, 22.640967294573784, 30.84674097597599, 17.51071248203516, 23.132592514157295, 21.183116622269154, 22.81093217432499, 31.821743957698345, 14.602850116789341, 17.112039774656296, 8.54123868048191, 6.509800236672163, 2.6014935923740268, 2.199842082336545, 1.6955161630176008, 0.3473921731347218, 0.10292388222296722, 0.14109552808804438, 0.3174836217658594, 0.22436016326537356, 0.40441247751004994, 2.155596544034779, 31.42895333468914, 89.39740777015686, 99.16485205292702, 127.43620902299881, 103.73648554086685, 58.5370559245348, 56.32979616522789, 46.88355624675751, 32.23732575774193, 44.52250353991985, 75.5189336836338, 83.15523192286491, 98.93334567546844, 108.94905343651772, 108.62062186002731, 76.14431172609329, 28.013546504080296, 5.683496575802565, 0.4279998305719346, 0.3337176569039002, 0.34363387792836875, 0.19185975019354373, 0.18672276724828407, 0.251433250377886, 0.21284439135342836, 0.1254493184387684, 0.09505561771220528, 0.14898859517415985, 0.1359130218042992, 0.15663348807720467, 0.3003424743656069, 0.1133297648630105, 0.09454948041820899, 0.16054637264460325, 0.09360017706057988, 0.1770267414394766, 0.1416725033777766, 0.1530233255471103, 0.23392144474200904, 0.23741167620755732, 0.16055137471994385, 0.08362846565432847, 0.16292477783281356, 0.11159610789036378, 0.24389777972828597, 0.13368300162255764, 0.18561122298706323, 0.07850596943171695, 0.11740667148842476, 0.12976219091797248, 0.15912468486931175, 0.1456937860348262, 0.18292785447556525, 0.07605266669997945, 0.09184222217299975, 0.14640039968071505, 0.11902453115908429, 0.11554791810340248, 0.10292706603650004, 0.07705172363785096, 0.10011152844526805, 0.22231158334761858, 0.1421825963188894, 0.16604003176325932], [0.008871321624610573, 0.0020535632074825116, 0.020581510252668522, 0.019005513277079444, 0.022927693244128022, 0.04861622779571917, 0.040082843115669675, 0.012635161601792788, 0.01855266404163558, 0.012560418981593102, 0.05515333170478698, 0.03987028088886291, 0.03668076024041511, 0.07602026453241706, 0.025472142842772882, 0.013813914756610757, 0.030967837301432155, 0.03071215258387383, 0.028311887435847893, 0.0577246359171113, 0.04470310945180245, 0.024342803735635243, 0.010440792339068139, 0.1063112891279161, 0.09110446058912203, 0.04124258615775034, 0.056846174265956506, 0.029185790444898885, 0.018719619438343216, 0.0483263374917442, 0.05720083550841082, 0.08930867843446322, 0.019784823998634238, 0.05667278259352315, 0.06937462152563967, 0.026931585525744595, 0.03903684904798865, 0.03725644790392835, 22.301932387053967, 98.66931304335594, 98.70296403765678, 88.20191591978073, 77.52340972423553, 63.246743604540825, 46.38286471366882, 26.496580503880978, 25.648122131824493, 57.51315526664257, 40.73782682418823, 38.35747495293617, 70.02153307199478, 76.02702721953392, 55.210395231842995, 74.51596990227699, 59.408147782087326, 21.93635780364275, 6.381324855610728, 0.44740212382748723, 0.29179474397096783, 0.0734255975112319, 0.047123972908593714, 0.19723288452951238, 0.08580449459259398, 0.09234433702658862, 0.10500723918084987, 0.5273004365153611, 1.0852307919412851, 2.2053997591137886, 3.860779032111168, 6.785672083497047, 6.6039287857711315, 13.337848596274853, 10.168245825916529, 6.293979417532682, 4.91658752784133, 4.829948376864195, 7.301057428121567, 2.127980813384056, 5.519124045968056, 9.400490373373032, 13.544539455324411, 14.07148377969861, 7.932977769523859, 6.006740480661392, 8.184465374797583, 16.348265558481216, 14.831824880093336, 17.7481921389699, 9.6024732850492, 9.610035829246044, 5.694718323647976, 2.4684800673276186, 2.0682651177048683, 8.67423439398408, 28.28058287501335, 33.17790828645229, 37.29407921433449, 30.052025020122528, 19.125631526112556, 12.641110382974148, 16.072347164154053, 4.589526252821088, 4.252375569194555, 5.074783014133573, 4.298059567809105, 0.47196023573633283, 0.1981116022216156, 0.33679932123050094, 0.05866859581146855, 0.2395969003555365, 0.08762933182879351, 0.03527633482008241, 0.5890074034687132, 0.5729753512423486, 18.616107366979122, 60.769166350364685, 71.8501241505146, 65.01502051949501, 75.71699425578117, 63.700465857982635, 36.2199604511261, 19.2691745236516, 19.371826015412807, 44.375132247805595, 64.0596529841423, 59.98407527804375, 76.14812672138214, 82.48373955488205, 67.9845155775547, 37.291651144623756, 9.32325666770339, 0.5441780621185899, 0.16003702185116708, 0.04245335185260046, 0.02672275444638217, 0.011232049782847753, 0.07512579846661538, 0.0314533577329712, 0.03964621537306812, 0.021039522980572656, 0.04243995608703699, 0.03361773495271336, 0.011297367127554026, 0.03614357890910469, 0.07251788410940208, 0.01304527890169993, 0.029812719694746193, 0.01900377665151609, 0.03933684369258117, 0.022771949843445327, 0.05405424439231865, 0.05740679262089543, 0.0449671099340776, 0.06865665302029811, 0.02695652910915669, 0.04527772842266131, 0.05888805630092975, 0.0651339154865127, 0.05468856172228698, 0.03104507446550997, 0.010475049875822151, 0.07093377731507644, 0.037864593396079727, 0.05304490499838721, 0.04916945064906031, 0.0500454335269751, 0.023528120400442276, 0.025715474512253422, 0.05018522446334828, 0.038146390579640865, 0.04680202553572599, 0.043935528374277055, 0.08511640495271422, 0.046966203444753774, 0.040920950486906804, 0.060323407014948316, 0.05792579133412801, 0.04430762637639418, 0.0272937072077184, 0.008257886474893894, 0.08921031418140046, 0.07763687739497982, 0.028169534234621096, 0.049351692432537675, 0.018703494424698874, 0.06467402141424827, 0.01817610016587423, 0.05571574976784177, 0.08982063416624442, 0.07147509983042255, 0.06568852986674756, 0.03696069463330787, 0.04414013106725179, 0.052554334251908585, 0.02903545359004056, 0.002625243737384153, 0.0640644584200345, 0.02650494523550151, 0.04517080720688682, 0.04293834907002747, 0.0743269655504264, 0.007409428462779033, 0.024903739358705934, 0.03545115141605493, 0.10192618341534398, 0.029714502015849575, 0.0422200725734001, 0.03203558000677731, 0.04935870943882037, 0.04052471413160674, 0.08395611643209122, 0.04911570802505594, 0.04512167703069281, 0.022937895919312723, 12.101971562951803, 92.16281577944756, 113.54018747806549, 103.76408725976944, 90.30153885483742, 70.33870965242386, 70.05607321858406, 45.882530361413956, 33.72642025351524, 21.876754201948643, 17.65265006572008, 33.852493688464165, 41.74594312906265, 46.93333737552166, 45.41070207953453, 48.37986275553703, 54.601291716098785, 32.16916881501675, 10.378447696566582, 0.698145265923813, 0.5424330057576299, 0.06920345258549787, 0.11988465063041076, 0.15476614062208682, 0.25773200613912195, 0.46715319680515677, 1.0778889921493828, 1.9238177686929703, 3.1469118129462004, 1.6434736805967987, 1.746286426205188, 2.710513067431748, 4.567239973694086, 9.664131626486778, 11.666711568832397, 8.714649025350809, 5.460357824340463, 4.90417311899364, 5.755195878446102, 3.302947827614844, 1.431106876116246, 2.724968916736543, 2.156255808658898, 7.724836338311434, 12.873713001608849, 11.396154686808586, 8.70996767655015, 8.36854174733162, 8.645694125443697, 4.062220472842455, 2.7604889357462525, 2.9170614341273904, 0.4862803313881159, 1.776956005487591, 3.331590215675533, 12.012759000062943, 34.764121770858765, 41.33349046111107, 45.9633482247591, 38.215541169047356, 27.951839715242386, 18.529732301831245, 16.207912489771843, 7.545797545462847, 1.237641682382673, 3.078139778226614, 2.7118988055735826, 0.7260280509945005, 0.1005780350533314, 0.3596577368443832, 0.15961945988237858, 0.24820720864227042, 0.05376807595894206, 0.026102625124622136, 0.5523254780564457, 1.182919037528336, 22.877474203705788, 60.500437170267105, 60.075536370277405, 43.56793016195297, 46.14737994968891, 47.319256067276, 29.62704062461853, 34.14458781480789, 39.77704077959061, 59.507645443081856, 75.90377703309059, 72.42687240242958, 83.88778701424599, 90.5651231110096, 73.94237548112869, 40.33860884606838, 7.626445842906833, 0.34285103087313473, 0.14344452938530594, 0.009146849515673239, 0.04010886281321291, 0.06059444676793646, 0.03805791915510781, 0.04628620692528784, 0.07243420695886016, 0.02593234119558474, 0.021381326514529064, 0.06731410787324421, 0.05611646127363201, 0.04351828923972789, 0.012234748810442397, 0.05787249028799124, 0.06242803021450527, 0.03784439955779817, 0.0908264669124037, 0.06124025625467766, 0.051758789049927145, 0.02393605485849548, 0.017180583272420336, 0.048089176780194975, 0.032748505618656054, 0.034771934151649475, 0.02562162437243387, 0.08220018760766834, 0.03028901708603371, 0.09100700175622478, 0.040109237597789615, 0.029143161482352298, 0.003111208529844589, 0.04586361319525167, 0.030795319507888053, 0.04146288527408615, 0.03831111767794937, 0.018693382662604563, 0.025792572523641866, 0.019203345727873966, 0.005950086897428264, 0.06598257619771175, 0.0406892297178274, 0.07117524248315021, 0.028781468390661757, 0.08720854893908836, 0.19799417961621657, 0.14724934240803123, 0.10526322817895561, 0.08042590547120199, 0.13432446954539046, 0.1879415221628733, 0.08052629578742199, 0.13941716111730784, 0.11548247552127577, 0.15934048657072708, 0.16548591462196782, 0.13191872363677248, 0.21948325855191797, 0.1334526835125871, 0.1540020402171649, 0.20547753665596247, 0.18260463431943208, 0.14121259446255863, 0.10602024107356556, 0.1529513965942897, 0.19752046675421298, 0.11257626974838786, 0.0991974919452332, 0.2646408963482827, 0.21169904968701303, 0.1919454979361035, 0.11310309069813229, 0.10934222766081803, 0.1279911445453763, 0.14693345467094332, 0.10726266307756305, 0.17133896617451683, 0.14183000195771456, 0.11440404588938691, 0.2070650499081239, 0.259115191292949, 0.13991842250106856, 0.13133796339388937, 41.301355585455894, 133.07431608438492, 117.78690040111542, 107.83547759056091, 105.22327736020088, 84.53375995159149, 67.33017548918724, 40.7220234721899, 36.74712896347046, 77.33152002096176, 56.69318966567516, 54.77476380765438, 95.83379879593849, 104.78626281023026, 75.06534442305565, 106.18527933955193, 91.37647077441216, 40.116658955812454, 12.230698205530643, 1.4026061492040753, 0.5809704784769565, 0.14900458103511482, 0.4973901930497959, 0.2725993614876643, 0.1467458248953335, 0.25534261716529727, 0.35169992479495704, 1.1939592263661325, 3.660577037371695, 9.015465583652258, 14.053661786019802, 21.126718148589134, 19.74823571741581, 26.036527790129185, 21.191202588379383, 13.20990091189742, 12.747259587049484, 10.383611619472504, 14.301454089581966, 13.393522258847952, 19.406320564448833, 29.891021959483624, 31.504924558103085, 36.0274475812912, 26.312668472528458, 15.473706386983395, 19.694740287959576, 41.58176153898239, 42.57338672876358, 39.49764937162399, 30.243033170700073, 29.64393261820078, 20.531130507588387, 9.745543207973242, 5.870788050815463, 9.893091190606356, 33.35616812109947, 37.40499146282673, 42.050998359918594, 35.314495638012886, 26.116236113011837, 21.190877705812454, 29.59230288863182, 19.77261520922184, 20.158484503626823, 13.827230986207724, 11.12393444404006, 1.3166703167371452, 0.31190670852083713, 0.6169171433430165, 0.15780507208546624, 0.20982831803848967, 0.1505075191380456, 0.1457426490378566, 0.8553582080639899, 2.2376854391768575, 34.19643983244896, 88.88174504041672, 97.42770686745644, 93.8168366253376, 107.86692470312119, 88.72830927371979, 52.42776274681091, 31.833071149885654, 34.729186445474625, 66.00146278738976, 86.77084431052208, 82.55105674266815, 94.68838825821877, 105.32309040427208, 90.26089623570442, 57.28114351630211, 18.48088402301073, 2.469823295250535, 0.4873857455095276, 0.12270845574676059, 0.2470177091890946, 0.11123319767648354, 0.14634208171628416, 0.20832937269005924, 0.28151003178209066, 0.20838935306528583, 0.12634279002668336, 0.1568039890844375, 0.13176034932257608, 0.19487818353809416, 0.1632130131474696, 0.13170342659577727, 0.14264185214415193, 0.13907348737120628, 0.18813053233316168, 0.13681137672392651, 0.1516350789461285, 0.16323634627042338, 0.1273511757608503, 0.14278839662438259, 0.13032959250267595, 0.11089388775872067, 0.12625950621441007, 0.11748191784135997, 0.08797386646619998, 0.17298497550655156, 0.12316012682276778, 0.2137463679537177, 0.12428128931787796, 0.08585464893258177, 0.17783577146474272, 0.12591077102115378, 0.2679683599853888, 0.11813423596322536, 0.15366418490884826, 0.0853600594564341, 0.10498045507119969, 0.17309701011981815, 0.14689435833133757, 0.15014386677648872, 0.3981931909220293, 0.19090938556473702], [0.030203905735106673, 0.022053818065614905, 0.027030014716729056, 0.03879670119204093, 0.044333427140372805, 0.031186566775431857, 0.06431822097511031, 0.12888301309430972, 0.057380680154892616, 0.03678488727018703, 0.019600977320806123, 0.015522158737439895, 0.05514783610124141, 0.022703566501149908, 0.014878789061185671, 0.02811724250932457, 0.06887920084409416, 0.03194843702658545, 0.018283310819242615, 0.04587940238707233, 0.03658861147414427, 0.03561312514648307, 0.022200245657586493, 0.05988379954942502, 0.016875122710189316, 0.15621108730556443, 0.06159302873129491, 0.05352150481485296, 0.03611525855376385, 0.08065050162258558, 0.029609291450469755, 0.006280752650127397, 0.0005249899902537436, 0.05988768098177388, 0.04548013435851317, 0.059508202321012504, 0.16824057383928448, 23.993221633136272, 109.2805552482605, 97.03583389520645, 87.9127286374569, 71.34559482336044, 73.16892698407173, 43.884107396006584, 16.940268091857433, 16.089750230312347, 107.85219669342041, 236.9365292787552, 120.17568781971931, 55.51940605044365, 67.15556725859642, 62.1285206079483, 57.35109396278858, 23.051271177828312, 3.229376175440848, 0.6598613108508289, 0.39860689372289926, 0.027497745868458878, 0.06544339848915115, 0.260499682626687, 0.1231917942641303, 0.10403976062661968, 0.23551862075692043, 0.8545589447021484, 2.262403112836182, 5.339767020195723, 8.926562704145908, 14.34510424733162, 25.413984395563602, 38.69078926742077, 68.26605007052422, 88.80853816866875, 95.35541966557503, 97.557842284441, 104.77281153202057, 105.85167244076729, 111.29765421152115, 96.27414956688881, 54.250730127096176, 27.17427033931017, 3.989238264039159, 3.200044361874461, 13.047426380217075, 20.20169198513031, 13.104071840643883, 12.239059656858444, 5.19250069744885, 7.778317043557763, 1.5186778083443642, 1.4825577777810395, 1.5595252602361143, 23.575612641870975, 88.25160965323448, 130.16007006168365, 147.61203199625015, 152.72474884986877, 145.77849358320236, 143.79392087459564, 139.5372524857521, 134.16408240795135, 115.50187021493912, 99.96943607926369, 75.90017482638359, 49.1992773860693, 20.21511096507311, 6.921359002590179, 1.9928826251998544, 1.6777668404392898, 0.29042375972494483, 4.1893811244517565, 3.7086784187704325, 0.14734488649992272, 0.3801348677370697, 0.1488779261126183, 0.23669694346608594, 1.1454794090241194, 23.592343144118786, 57.19823196530342, 68.7176862359047, 65.66259697079659, 69.16037008166313, 45.01026436686516, 24.6109601855278, 19.428859055042267, 36.75868034362793, 47.57845535874367, 79.75427761673927, 80.40288001298904, 74.66219365596771, 75.01251205801964, 53.31584349274635, 33.826244696974754, 10.990467555820942, 1.4025660138577223, 0.16053682862548158, 0.06197874143254012, 0.052092284240643494, 0.05558764765737578, 0.051610682348837145, 0.10122068299097009, 0.026292147376807407, 0.04255595005815849, 0.04950807779096067, 0.0071828048567113, 0.05632708278426435, 0.06049715491826646, 0.00890353547220002, 0.08618621082860045, 0.03833629874861799, 0.014442826468439307, 0.024317123570654076, 0.03313440385682043, 0.05307899555191398, 0.048756412070360966, 0.052126033406239, 0.03937232948374003, 0.003640503614406043, 0.06179199852340389, 0.036111039444222115, 0.05103134702949319, 0.039195995195768774, 0.0303609924230841, 0.05303180980263278, 0.09176871986710466, 0.10001001006457955, 0.025317065519629978, 0.05461474400362931, 0.01944915988133289, 0.027803410521300975, 0.04511447077675257, 0.08170441069523804, 0.01887553538836073, 0.006097022860558354, 0.060689860983984545, 0.02942092138255248, 0.03623085547587834, 0.027400316721468698, 0.03631580912042409, 0.033536317641846836, 0.0525227707112208, 0.08913658180972561, 0.03773941905819811, 0.02731650041823741, 0.03823310682491865, 0.05023789097322151, 0.015336271153501002, 0.04371068731416017, 0.01663456110691186, 0.07702810107730329, 0.008435582603851799, 0.09288944449508563, 0.038937642457312904, 0.09084617835469544, 0.04779028793564066, 0.02577558105258504, 0.0319955893792212, 0.09276932789362036, 0.027835552937176544, 0.02699280343222199, 0.10159123732591979, 0.1524883706588298, 0.07396109416731633, 0.06280331203015521, 0.02582692282885546, 0.0353212644404266, 0.02116989420755999, 0.03446372764301486, 0.03625066710810643, 0.018501040249248035, 0.08918655061279424, 0.10839853493962437, 0.0891407897870522, 0.2082070370670408, 16.39050979167223, 113.07028189301491, 111.43459886312485, 100.29406785964966, 79.7222301363945, 85.22170543670654, 57.28676341474056, 35.37687689065933, 29.589990712702274, 74.63833093643188, 165.20627349615097, 74.64764043688774, 39.55893248319626, 54.36865299940109, 54.8141410946846, 56.89202919602394, 34.20957952737808, 6.836401736363769, 0.4558864748105407, 0.6986160250380635, 0.0858015927951783, 0.059299528948031366, 0.4453597927931696, 0.4321433894801885, 1.3705922733061016, 1.4794824365526438, 3.3726223139092326, 3.43285976909101, 4.121489217504859, 8.025158923119307, 13.876730930060148, 24.016670174896717, 41.91867046058178, 73.55046451091766, 96.38708710670471, 104.13144394755363, 103.44134777784348, 111.39418423175812, 119.97858479619026, 124.00133013725281, 109.80086892843246, 66.90294161438942, 30.728392526507378, 7.504913164302707, 1.4280893630348146, 2.234483161009848, 4.2957032192498446, 4.540905486792326, 2.9958502063527703, 2.517942013218999, 0.8423801825847477, 0.7470971485599875, 1.8418491608463228, 2.75739423930645, 32.185409143567085, 98.33581253886223, 143.0693605542183, 154.50689882040024, 160.4432898759842, 154.0857294201851, 154.0278661251068, 148.21160942316055, 144.4201424717903, 122.5139607489109, 113.44840720295906, 90.22824078798294, 61.669672429561615, 31.021223813295364, 14.231284204870462, 3.0528440605849028, 0.6438599538523704, 0.5274689930956811, 5.9195019118487835, 5.891477940604091, 0.16292792453896254, 0.2056700349203311, 0.11639006275800057, 0.1348523295018822, 1.6492397524416447, 29.462840035557747, 59.863446950912476, 62.782799899578094, 50.09500712156296, 47.094049751758575, 27.84537322819233, 27.191701903939247, 37.12845750153065, 56.4899005740881, 66.08059734106064, 98.80320265889168, 94.1189356148243, 85.03108486533165, 82.78836160898209, 57.103016674518585, 31.15170121192932, 10.02389157190919, 0.8580685907509178, 0.07485063237254508, 0.07124216936063021, 0.07012476955424063, 0.03177546837832779, 0.010256984623993048, 0.05318389812600799, 0.04505730314122047, 0.04440434306161478, 0.014140345629130024, 0.03426366689382121, 0.07441272071446292, 0.03944481133657973, 0.013092027711536502, 0.039585644990438595, 0.014127925787761342, 0.021041126019554213, 0.030408072416321374, 0.018987510629813187, 0.016519754572072998, 0.02321508807654027, 0.02391877023910638, 0.05455494174384512, 0.04612286764313467, 0.04101196376723237, 0.01020537474687444, 0.021075244403618854, 0.014765144915145356, 0.02622644133225549, 0.06494528381153941, 0.06513027896289714, 0.06495311346952803, 0.016516524374310393, 0.046555658482247964, 0.035727037393371575, 0.03581509692594409, 0.018075739535561297, 0.021698652162740473, 0.043830937502207235, 0.0521398225100711, 0.04056396632222459, 0.04049197057611309, 0.029490471752069425, 0.1883551655919291, 0.09307921165600419, 0.1258566090837121, 0.13120706338668242, 0.16404954716563225, 0.11658306568278931, 0.19050599861657247, 0.25141312333289534, 0.11863770152558573, 0.0957315435516648, 0.15266656031599268, 0.12622410577023402, 0.1397445669863373, 0.08678705358761363, 0.23089317051926628, 0.1718684588558972, 0.2823145198635757, 0.09396991503308527, 0.11168493554578163, 0.1488609309308231, 0.2912370051490143, 0.12070787794073112, 0.11098975097411312, 0.25739287433680147, 0.1946637177024968, 0.20412215235410258, 0.1090828693122603, 0.11711742685292847, 0.13854890770744532, 0.17867622402263805, 0.2900026651332155, 0.11965747180511244, 0.12004807897028513, 0.17206578108016402, 0.3286263457266614, 0.16710382624296471, 0.23196748865302652, 46.60077162086964, 143.36328238248825, 113.81964728236198, 113.91877636313438, 92.63909742236137, 94.11283314228058, 61.812259778380394, 24.654218964278698, 27.68162101507187, 128.80381643772125, 243.16393911838531, 131.8699935078621, 82.69281193614006, 98.9014881849289, 91.70789659023285, 86.64684176445007, 37.7356231212616, 6.331596449017525, 1.180385760962963, 0.8212859113700688, 0.21723328944062814, 0.21374236035626382, 0.35209825029596686, 0.26873413764405996, 0.6787063996307552, 0.5222822714131325, 3.4772772481665015, 7.550940569490194, 18.54051422327757, 27.811023071408272, 25.191253647208214, 37.46057108044624, 44.14800323545933, 75.13290479779243, 98.7340235710144, 105.2485080063343, 104.87447127699852, 116.6432985663414, 123.19670051336288, 125.07130712270737, 108.96654009819031, 67.19004660844803, 37.16119274497032, 20.503017716109753, 19.40649725496769, 36.09735243022442, 39.69094879925251, 38.16996641457081, 30.32605681568384, 21.96189433336258, 18.42437155544758, 12.679919600486755, 8.390781003981829, 3.1298286421224475, 31.472690887749195, 100.84421753883362, 151.94875448942184, 165.6828287243843, 170.0014641880989, 161.01230174303055, 164.2200592160225, 152.11700946092606, 143.1281813979149, 116.62850975990295, 105.78896060585976, 87.37911567091942, 58.28251138329506, 27.87424597889185, 13.661453481763601, 6.4014210272580385, 1.586363932583481, 0.5061494058463722, 5.244719870388508, 4.759901035577059, 0.17030096874805167, 0.5030600528698415, 0.27270436054095626, 0.3190801595337689, 3.597299032844603, 42.423488572239876, 87.79732882976532, 95.33504515886307, 92.64878690242767, 97.6933354139328, 58.67327481508255, 37.084919437766075, 33.83985176682472, 53.07293392717838, 68.50444167852402, 104.12718817591667, 100.87336957454681, 96.40923231840134, 95.66420629620552, 76.0117444396019, 50.41176952421665, 18.29967174679041, 2.3011284973472357, 0.37018726870883256, 0.1862992680980824, 0.1692869426915422, 0.19588869181461632, 0.10762770325527526, 0.1638099373667501, 0.1631337814615108, 0.17619808902963996, 0.16316792025463656, 0.0682526575110387, 0.2506861154688522, 0.16587315243668854, 0.07042655648547225, 0.1803891602321528, 0.13709970109630376, 0.17698187119094655, 0.0930302744382061, 0.10614964936394244, 0.12840821669669822, 0.08298142420244403, 0.1492337413947098, 0.14741550927283242, 0.14204691688064486, 0.1741331967059523, 0.14816849230555817, 0.09077483569853939, 0.12785398081177846, 0.12480893405154347, 0.1410695826052688, 0.19949717709096149, 0.17486415279563516, 0.09934535002685152, 0.09855240234173834, 0.10709950933232903, 0.13360206299694255, 0.15047441935166717, 0.15109289553947747, 0.14923475071555004, 0.13200304645579308, 0.2546359144616872, 0.09744280250743032, 0.09527676287689246], [0.012934365859109676, 0.028506905291578732, 0.03555448434781283, 0.020115881234232802, 0.024910509600886144, 0.046142556820996106, 0.020830613975704182, 0.07673672647797503, 0.07381584102404304, 0.036578952422132716, 0.05842474834935274, 0.042426500949659385, 0.03455668535025325, 0.036520103822113015, 0.040483324555680156, 0.041811631599557586, 0.02337805814022431, 0.03944143827538937, 0.08096742836642079, 0.025936224483302794, 0.05284725622914266, 0.03489594331767876, 0.1365935118519701, 0.03396326777874492, 0.0217536879790714, 0.052742468687938526, 0.014608822639274877, 0.012860996212111786, 0.0269751180530875, 0.06604617825360037, 0.07257897770614363, 0.07874035451095551, 0.05653477281157393, 0.1412703187088482, 0.044094500117353164, 0.28171712066978216, 25.846218802034855, 95.56278213858604, 103.44220653176308, 91.3193978369236, 75.98332956433296, 53.66570211946964, 17.18260008841753, 24.544824734330177, 43.56609486043453, 106.89575761556625, 90.96219420433044, 62.806810811161995, 48.78291852772236, 74.7126929461956, 55.65617971122265, 20.065385699272156, 4.390834914520383, 0.48045895469840616, 0.27541147777810693, 0.02969913028209703, 0.04776951522217132, 0.14144349144771695, 0.26728071563411504, 0.01356406239210628, 0.41867450752761215, 0.3785600303672254, 1.6351435775868595, 3.4686258248984814, 13.970423452556133, 25.78127458691597, 38.61426517367363, 55.30758261680603, 79.14324000477791, 112.99874693155289, 114.0583884716034, 117.7115124464035, 115.58871075510979, 119.46086257696152, 112.73185685276985, 113.34582790732384, 111.60017117857933, 122.36318483948708, 134.5781233906746, 131.89312666654587, 88.7497629225254, 25.10374054312706, 5.26416152715683, 5.300566898658872, 3.795831254683435, 6.714722765609622, 6.343416664749384, 15.577801801264286, 11.757180914282799, 16.101090721786022, 71.35341480374336, 134.02242600917816, 122.4227124452591, 112.70810812711716, 107.32737645506859, 109.25245955586433, 108.19102451205254, 116.86507746577263, 110.8590817451477, 117.5387205183506, 122.30271488428116, 131.59829288721085, 130.59488832950592, 138.87795746326447, 140.7663345336914, 125.53363591432571, 88.35234224796295, 36.99626259505749, 1.18848763871938, 3.946801903657615, 21.38261541724205, 0.05189860225073062, 0.13110921863699332, 0.1073328554048203, 0.31819228373933583, 0.0580047595576616, 0.12825396872358397, 3.755764067173004, 29.350407868623734, 62.29044891893864, 57.65863426029682, 89.77306321263313, 63.476707264781, 27.890613600611687, 15.829510744661093, 10.43039470911026, 13.62162496894598, 39.01472568511963, 65.0533376634121, 74.46235477924347, 71.11620873212814, 68.6615252494812, 49.5874797552824, 20.9563846886158, 1.7614444065839052, 0.21864362235646695, 0.04400573183374945, 0.014428894501179457, 0.03485065004497301, 0.0224989805064979, 0.03128001430013683, 0.027821092189697083, 0.03063031781493919, 0.06766218255506828, 0.023205147008411586, 0.09579137549735606, 0.07768545838189311, 0.02297834296768997, 0.009725356412673136, 0.04689494613558054, 0.06417435564799234, 0.03894363158906344, 0.05132445083290804, 0.05359561197110452, 0.0482624645519536, 0.044572168626473285, 0.03191397539922036, 0.05940553732216358, 0.06222450734640006, 0.0566201420588186, 0.08879937959136441, 0.0016545406674595142, 0.007957584766700165, 0.026545620494289324, 0.026718353510659654, 0.01812804981454974, 0.05532135764951818, 0.09249612849089317, 0.021439338343043346, 0.014100098960625473, 0.05212901683989912, 0.036080192076042295, 0.06410388872609474, 0.04495733213843778, 0.03053527652809862, 0.03979157983849291, 0.025397853860340547, 0.03122724017885048, 0.06430437992094085, 0.012591508475452429, 0.02189917489886284, 0.04116239710128866, 0.0416945058532292, 0.10166826483327895, 0.005221452338446397, 0.05027635648730211, 0.017306251138506923, 0.015774332168803085, 0.1071616642002482, 0.100790014694212, 0.025015905703185126, 0.030304587344289757, 0.013069712258584332, 0.04337266131187789, 0.04224095289828256, 0.02909114249632694, 0.06685103740892373, 0.04610968710039742, 0.10438876299303956, 0.06005554365401622, 0.008821670089673717, 0.010973847329296404, 0.02578181323769968, 0.02835567600413924, 0.04660469960072078, 0.06580353307072073, 0.08859701076289639, 0.035396444000070915, 0.06425774336094037, 0.0686187886458356, 0.048300718553946353, 0.1506362817599438, 22.81420949846506, 105.21725088357925, 117.38022342324257, 104.39846321940422, 84.0464437007904, 69.78525415062904, 48.88883024454117, 40.264341831207275, 25.719229616224766, 41.929093301296234, 83.54681611061096, 99.53157797455788, 61.41726337373257, 44.44232404232025, 46.19162477552891, 29.647358134388924, 8.127172999083996, 0.3304813290014863, 0.4047590011032298, 0.05725464492570609, 0.19319910410558805, 0.2203844633186236, 0.873276146594435, 0.5532538751140237, 2.080747685395181, 3.026379430666566, 5.547562669962645, 5.894722966477275, 12.946514245122671, 25.37975013256073, 41.08399584889412, 57.75395594537258, 90.35193175077438, 118.55723306536674, 119.28734868764877, 119.9181680381298, 117.9381474852562, 122.82659277319908, 118.69376733899117, 116.83834210038185, 116.17193385958672, 124.4069355726242, 137.33692735433578, 138.20838779211044, 98.24614495038986, 29.621918499469757, 2.7001206250861287, 1.0024609020911157, 2.200693474151194, 4.880366446450353, 6.671871989965439, 16.371290422976017, 14.72161179408431, 22.561238072812557, 80.68631440401077, 140.9313216805458, 126.44765406847, 116.45935043692589, 113.86564761400223, 115.13071373105049, 111.18610739707947, 119.41671654582024, 115.64782798290253, 122.64604926109314, 126.91515818238258, 134.3593007326126, 135.78984797000885, 144.2080682516098, 149.9856886267662, 137.42128282785416, 103.20976540446281, 49.993525967001915, 3.1134078232571483, 2.9223566874861717, 20.540027730166912, 0.06579350665560924, 0.07459444299456663, 0.08717631746549159, 0.05602597491815686, 0.06782020805985667, 0.09209162832121365, 5.432125814259052, 30.461074970662594, 54.54668864607811, 44.775851145386696, 54.44539748132229, 44.75234180688858, 29.01385422796011, 28.794881477952003, 22.169644385576248, 29.050039686262608, 49.84565310180187, 76.7629337310791, 86.08618184924126, 79.80908587574959, 76.33855730295181, 53.025292083621025, 20.0667954236269, 1.4656971325166523, 0.31749098387081176, 0.06260271693463437, 0.08015351500944234, 0.03499924285279121, 0.08671441959450021, 0.04688771761721, 0.048012987899710424, 0.016596618806943297, 0.06311961536994204, 0.03927681878849398, 0.05488138282089494, 0.096666130120866, 0.036550572694977745, 0.024025027232710272, 0.045303599690669216, 0.03672994607768487, 0.04812339349882677, 0.026784118927025702, 0.03546682928572409, 0.02282050671055913, 0.045041068660793826, 0.021789567108498886, 0.013482610756909708, 0.0665287375159096, 0.039611052416148596, 0.028880155477963854, 0.013790609464194858, 0.02925850792962592, 0.04512025210715365, 0.06091653885960113, 0.023038330764393322, 0.04822957998840138, 0.04195167486614082, 0.02424494785373099, 0.06188385785208084, 0.004203388534733676, 0.01677086951531237, 0.02193267358961748, 0.04429884305864107, 0.02104299252096098, 0.0463789494097, 0.09467612049775198, 0.12607785814907402, 0.13954988680779934, 0.18123842950444669, 0.1176343772385735, 0.0888496229890734, 0.12830082792788744, 0.18677400512387976, 0.2440167311578989, 0.12905220792163163, 0.09621588396839797, 0.10624082962749526, 0.27880974230356514, 0.1460908053559251, 0.23210757644847035, 0.2351585158612579, 0.12445288128219545, 0.1013454602798447, 0.16727907699532807, 0.11759063505451195, 0.17708268453134224, 0.10428435023641214, 0.19326757465023547, 0.16692726931069046, 0.10479533375473693, 0.12315757383476011, 0.1351922331377864, 0.12077168779796921, 0.15825381909962744, 0.16125019581522793, 0.1930332340998575, 0.12561753363115713, 0.17738659400492907, 0.28766516712494195, 0.11114380598883145, 0.3214040317106992, 50.064905136823654, 131.50610983371735, 122.76528686285019, 118.25395613908768, 96.88789263367653, 75.32165586948395, 33.56926068663597, 37.52963997423649, 62.33082555234432, 124.01595935225487, 104.56132248044014, 74.73149433732033, 66.21860593557358, 114.5783905684948, 85.8329938352108, 36.27095751464367, 10.325084310024977, 1.2886614259332418, 0.6173686066176742, 0.09700857190182433, 0.31343692797236145, 0.38393745431676507, 0.4683095816290006, 0.35932421567849815, 1.6648810193873942, 2.8802791703492403, 8.76424016430974, 15.289475172758102, 27.791182436048985, 41.63780853152275, 54.28163006901741, 64.28913787007332, 88.2234075665474, 124.19930711388588, 121.7260730266571, 126.42230942845345, 120.96748933196068, 125.1567493379116, 121.06443732976913, 122.17665284872055, 121.58365666866302, 133.76575738191605, 146.00532621145248, 144.95992630720139, 94.48427081108093, 33.78110691905022, 25.19731432199478, 22.690338045358658, 21.822610907256603, 12.054806593805552, 9.928490091115236, 21.183777786791325, 16.678758524358273, 22.677359841763973, 85.71279868483543, 147.15791076421738, 135.40222316980362, 118.24708610773087, 115.89340880513191, 117.90088668465614, 113.07390689849854, 125.04199549555779, 120.01019150018692, 130.30555665493011, 135.09723633527756, 143.8970473408699, 141.7924466729164, 154.4151869416237, 157.4622130393982, 142.79553204774857, 100.11172324419022, 45.538553819060326, 4.099908750504255, 9.000046961009502, 26.14182583987713, 0.16665310511598364, 0.48927204741630703, 0.27484578313305974, 0.41953174746595323, 0.18960523913847283, 0.45672744687180966, 8.515027686953545, 48.26874911785126, 92.08764061331749, 83.82156416773796, 122.61095434427261, 88.9979200065136, 40.96861504018307, 24.917364344000816, 18.613882586359978, 25.176341347396374, 56.35505720973015, 87.95147895812988, 94.11617696285248, 91.19121551513672, 87.29004085063934, 67.8780072927475, 34.83947932720184, 5.9639286529272795, 0.44733889284543693, 0.1534096134128049, 0.16394021396990865, 0.15890529117314145, 0.17554063524585217, 0.1747172966133803, 0.15440890041645616, 0.11916143514099531, 0.10072944802232087, 0.15546824201010168, 0.40728203603066504, 0.2225162528338842, 0.15945425780955702, 0.153737984073814, 0.11606212254264392, 0.0885817818925716, 0.15232536534313112, 0.12491501664044335, 0.16900933493161574, 0.10548510806984268, 0.17675116716418415, 0.18196868797531351, 0.12946206639753655, 0.13510658929590136, 0.23403957980917767, 0.18281573080457747, 0.09511628828477114, 0.10769009561045095, 0.13142702111508697, 0.14452059898758307, 0.08606537434388883, 0.12807990540750325, 0.11102436474175192, 0.11259664912358858, 0.1683012963621877, 0.21118098607985303, 0.1055325090419501, 0.12462630635127425, 0.11578970239497721, 0.19769500504480675, 0.14304446725873277], [0.017219408728124108, 0.048428880036226474, 0.06207947684742976, 0.034615014446899295, 0.03573403584596235, 0.03348915786773432, 0.09726185206091031, 0.13646847481140867, 0.08518191432813182, 0.0616211153101176, 0.04291358360205777, 0.06750363754690625, 0.09748517913976684, 0.04660764963773545, 0.02583241101092426, 0.03636123597971164, 0.06742511090124026, 0.020454076075111516, 0.005910109257456497, 0.23816289292881265, 0.02784989308565855, 0.04774492044816725, 0.020697901272797026, 0.051737456014961936, 0.04154633978032507, 0.004928889375150902, 0.04391620655951556, 0.06845171636086889, 0.1435219353879802, 0.0319106691313209, 0.03560757759260014, 0.06763986617443152, 0.03481928688415792, 0.034107121973647736, 1.74542743479833, 37.442195266485214, 83.08008715510368, 78.37432086467743, 98.09861406683922, 77.24591821432114, 52.096933498978615, 28.00922993570566, 28.081034682691097, 37.47147649526596, 73.06384742259979, 90.75328901410103, 71.88841849565506, 38.39383900165558, 32.21859276294708, 30.94059593975544, 7.930774837732315, 0.4881384613690898, 0.1033224377897568, 0.02959134817501763, 0.07171565215685405, 0.3452390246093273, 0.34809932112693787, 0.1652449689572677, 0.13549606839660555, 1.0195297049358487, 3.1304344721138477, 4.6304429322481155, 20.080406293272972, 26.73781245946884, 47.37246461212635, 63.10453623533249, 81.98978886008263, 105.33184513449669, 114.89938214421272, 103.46557527780533, 101.4618743956089, 98.7390848994255, 111.79647624492645, 114.64829921722412, 111.63755357265472, 100.58129444718361, 93.41359466314316, 91.68578937649727, 102.62939214706421, 104.67481479048729, 122.51896888017654, 124.55629035830498, 33.519099578261375, 9.362652953714132, 39.28573474287987, 78.6970603466034, 131.4536726474762, 142.7936777472496, 131.50791853666306, 69.75347265601158, 82.8152945637703, 107.80591517686844, 103.21624025702477, 115.57193085551262, 112.45150789618492, 112.25013390183449, 106.22598275542259, 106.02055817842484, 110.94167411327362, 116.91709667444229, 110.099578499794, 105.96070379018784, 109.83873009681702, 102.14259266853333, 105.79991921782494, 108.0667331814766, 123.3618776500225, 132.66995698213577, 113.55839610099792, 30.131600350141525, 8.984834477305412, 2.428330471739173, 0.2784537192201242, 0.11728191646398045, 0.03327410944621079, 0.0794226182915736, 0.1426970976172015, 0.2679487079149112, 1.5741414134390652, 19.108293056488037, 40.274460688233376, 51.398021802306175, 61.05398386716843, 69.5282207429409, 43.11720974743366, 83.26911941170692, 89.54024970531464, 46.21730379760265, 35.14433316886425, 53.33718694746494, 73.45987737178802, 69.2987434566021, 69.980388879776, 71.05507761240005, 42.618847489356995, 11.615136936306953, 1.112445406615734, 0.08474839618429542, 0.1720675770775415, 0.05617333576083183, 0.03263536149461288, 0.03879385505570099, 0.03935599852411542, 0.07751880169962533, 0.055113415291998535, 0.05056903355580289, 0.2796452818438411, 0.20225011452566832, 0.05555469630053267, 0.031325055242632516, 0.015336965989263263, 0.0262148860929301, 0.07770315118250437, 0.06866054187412374, 0.051675223221536726, 0.009268345584132476, 0.016681138295098208, 0.16467673616716638, 0.06797797381295823, 0.043487445582286455, 0.030256774480221793, 0.0284380822267849, 0.008979170524980873, 0.11342912359395996, 0.09977179550332949, 0.06730666413204744, 0.05051248190284241, 0.11155310785397887, 0.02509057132556336, 0.049578889811527915, 0.11708745150826871, 0.03375194864929654, 0.005633277041852125, 0.0738555088173598, 0.010335326660424471, 0.028083348624932114, 0.044757891082554124, 0.05890206062758807, 0.012377151178952772, 0.05315393391356338, 0.03937432586099021, 0.017308700225839857, 0.07493333730963059, 0.03936432913178578, 0.12044670133036561, 0.05273554073937703, 0.061404077932820655, 0.11315170137095265, 0.0251993850179133, 0.051986157122883014, 0.045455261279130355, 0.05132778678671457, 0.05218251084443182, 0.03663037212390918, 0.002991596820720588, 0.1470428323955275, 0.012774860697390977, 0.024276064250443596, 0.0634530400566291, 0.028161411428300198, 0.029724704691034276, 0.028060206605005078, 0.04419734323164448, 0.08842861003358848, 0.15577745041809976, 0.029214825117378496, 0.058466549817239866, 0.0681030034320429, 0.05220794053457212, 0.05728236043069046, 0.6608950335066766, 33.59627723693848, 97.25014999508858, 93.1968466937542, 111.3904832303524, 86.18369981646538, 74.22606065869331, 39.404824152588844, 25.09147670120001, 32.822570353746414, 42.91180416941643, 73.89506042003632, 47.54851296544075, 37.799060717225075, 38.03202621638775, 37.8314121812582, 15.314130149781704, 1.1630394542589784, 0.12599913112353534, 0.0033457928293501027, 0.048613812105031684, 0.5985694122500718, 1.3012190395966172, 0.9810330800246447, 1.0095238918438554, 2.1903739403933287, 4.233328141272068, 5.8153134025633335, 11.759509239345789, 24.586702287197113, 50.28720460832119, 67.75739416480064, 83.49992662668228, 107.85892233252525, 116.39767974615097, 109.67988342046738, 105.11465638875961, 104.87078547477722, 115.82191944122314, 122.30659067630768, 120.13860180974007, 109.72934916615486, 101.77249252796173, 99.48446810245514, 106.46866053342819, 112.13688477873802, 128.00519049167633, 136.9694110751152, 40.69935008883476, 13.15953841432929, 47.63211227953434, 88.32636684179306, 143.0830094218254, 156.45354956388474, 143.32107424736023, 77.76825338602066, 89.04756054282188, 113.21650564670563, 112.75825023651123, 122.39789217710495, 117.32011064887047, 118.70029538869858, 113.08216765522957, 111.81414529681206, 118.24935838580132, 123.12490716576576, 117.08488047122955, 113.25350046157837, 116.33503630757332, 108.78284275531769, 111.56851127743721, 112.34596475958824, 126.47058963775635, 139.09302592277527, 128.45747262239456, 43.57594773173332, 13.71675856411457, 6.903834342956543, 0.22959522844757885, 0.06234535496332683, 0.03696920335642062, 0.04307755742047448, 0.10668150949641131, 0.1470176290604286, 1.8866792740300298, 22.604926228523254, 42.581674084067345, 50.74612118303776, 44.5996318012476, 41.87852181494236, 27.834735698997974, 41.28945082426071, 53.73688369989395, 58.11736844480038, 47.32293426990509, 60.2541533857584, 84.7664062678814, 78.48658964037895, 78.8566517829895, 78.6532486975193, 46.382154151797295, 11.138436365872622, 0.9366586455143988, 0.02713746656809235, 0.12922999681904912, 0.029974643330206163, 0.049906247440958396, 0.05159987667866517, 0.10443776700412855, 0.007788413131493144, 0.09083090495551005, 0.02096294818329625, 0.26343172998167574, 0.09220706197083928, 0.09538749873172492, 0.023784725381119642, 0.04259861241735052, 0.023636531477677636, 0.058373447391204536, 0.04500157156144269, 0.07713440631050617, 0.02800110753014451, 0.07536134871770628, 0.10319959008484147, 0.09016369935125113, 0.04833194070670288, 0.07146859861677513, 0.028170244841021486, 0.04110490292077884, 0.17054510564776137, 0.03458461978880223, 0.1669093093369156, 0.0821134379657451, 0.10088896524393931, 0.03830616013146937, 0.09626300292438827, 0.13134535518474877, 0.03202986546966713, 0.04226500961522106, 0.010497530456632376, 0.03546024643583223, 0.06275368461501785, 0.16783142782514915, 0.12711732502793893, 0.12442368519259617, 0.1945437866379507, 0.09955296583939344, 0.11647305713267997, 0.1955372848897241, 0.1766874612076208, 0.3478278435068205, 0.15262413915479556, 0.16587135643931106, 0.17762247822247446, 0.19572059536585584, 0.16162449057446793, 0.08667548652738333, 0.16435295197879896, 0.19397396565182135, 0.06777816539397463, 0.14221197052393109, 0.29728544934187084, 0.14095576683757827, 0.13354502152651548, 0.17467413330450654, 0.16131259559188038, 0.11040045603294857, 0.14194614806910977, 0.1942689693532884, 0.13769051001872867, 0.2356381362187676, 0.19529929297277704, 0.12482953607104719, 0.21044682391220704, 0.09129372308962047, 0.07880316246883012, 5.095503302291036, 70.24976402521133, 123.11603084206581, 101.76564529538155, 123.17621961236, 94.17575776576996, 72.89296299219131, 41.506962552666664, 40.219192653894424, 56.05238825082779, 98.64028260111809, 116.68692022562027, 102.98304677009583, 67.45378285646439, 57.750220745801926, 52.61321559548378, 18.26689090579748, 2.429049820639193, 0.3280039213132113, 0.09555260432534851, 0.09578960918588564, 0.524819407146424, 0.6665645074099302, 0.4648682725382969, 0.5928527377545834, 2.4801984010264277, 9.964996632188559, 17.762543968856335, 37.84077487885952, 36.02415695786476, 62.34054543077946, 71.5080589056015, 88.68346408009529, 110.45517101883888, 121.84376031160355, 112.71289587020874, 108.52573335170746, 107.46411591768265, 119.81467679142952, 125.0929507613182, 123.18207889795303, 112.8858169913292, 103.55600282549858, 100.06681725382805, 114.32393342256546, 118.36765363812447, 139.61774736642838, 137.77691334486008, 41.66115067899227, 14.474767539650202, 50.915778279304504, 100.75580388307571, 144.90118145942688, 151.2484672665596, 151.96573197841644, 101.58499538898468, 97.59739056229591, 117.92200595140457, 116.15649908781052, 128.17253351211548, 125.20591109991074, 123.77268120646477, 120.64878523349762, 118.64326044917107, 122.91326612234116, 126.1919429898262, 120.7988315820694, 113.88241991400719, 118.74392464756966, 110.37422776222229, 114.49480265378952, 118.26657146215439, 140.98287731409073, 150.45119404792786, 129.20832753181458, 41.236656457185745, 15.020950231701136, 7.53260750323534, 0.35077051841653883, 0.203469745174516, 0.16534518857952207, 0.23056880745571107, 0.3000843554036692, 0.5228797299787402, 3.3000006107613444, 33.67933697998524, 66.4137102663517, 72.60735511779785, 83.03880617022514, 95.310627669096, 60.15167288482189, 100.3978630900383, 104.868885576725, 64.5719262957573, 53.298189640045166, 74.67091798782349, 95.8613321185112, 92.92264580726624, 89.82442125678062, 94.00999546051025, 66.78704783320427, 24.688343033194542, 2.791914436966181, 0.16152152500580996, 0.22567130072275177, 0.24565818370319903, 0.08695362121216021, 0.15167107310844585, 0.22665522526949644, 0.1347014360362664, 0.10159469573409297, 0.17973709444049746, 0.410092044621706, 0.21844447444891557, 0.16958356427494437, 0.07333672532695346, 0.101064141781535, 0.11798068560892716, 0.13082163641229272, 0.11776170009397902, 0.17755984095856547, 0.10096879064803943, 0.1675183157203719, 0.22782376647228375, 0.23513780994107947, 0.09590192581526935, 0.23583136178785935, 0.12421603969414718, 0.16498705779667944, 0.2893526031402871, 0.14168635185342282, 0.23879331769421697, 0.12624593975488096, 0.23394638090394437, 0.14871674648020416, 0.09962294294382446, 0.27297800523228943, 0.16655481507768854, 0.0811383746622596, 0.13869037589756772, 0.10328087751986459, 0.11844008244224824], [0.09266775014111772, 0.024328793842869345, 0.03308811239548959, 0.12730223854305223, 0.044520652445498854, 0.04803425043064635, 0.02724210382439196, 0.10866439450182952, 0.12701478990493342, 0.07650362531421706, 0.059714927556342445, 0.14418532635318115, 0.07476563419913873, 0.010980479346471839, 0.04382557548524346, 0.009803133489185711, 0.03314614834380336, 0.03199895872967318, 0.1546339938067831, 0.13181166141293943, 0.05394712650740985, 0.011632300229393877, 0.03840078767098021, 0.0014143319322101888, 0.2365327804000117, 0.13248250354081392, 0.12459206365747377, 0.3550899069523439, 0.1418492235825397, 0.1794863969553262, 0.004668899737225729, 0.0686868213233538, 0.03232323273550719, 1.0850963741540909, 64.80015724897385, 112.00313195586205, 107.2745668888092, 75.74672386050224, 59.751368165016174, 47.10652068257332, 13.559409957379103, 30.496715158224106, 97.88874372839928, 79.8395374417305, 53.291053622961044, 30.114563964307308, 43.14647197723389, 38.85090887546539, 13.716078400611877, 1.1752002267166972, 0.07740794710116461, 0.12341259804088622, 0.08719224395463243, 0.06868702170322649, 0.15594572498230264, 0.1820588589180261, 0.2698070160113275, 0.8788750867825001, 3.397872671484947, 3.6752912728115916, 7.625138238072395, 24.77454710751772, 47.22466014325619, 63.6022487282753, 79.34069260954857, 94.47208106517792, 102.91492402553558, 106.7727430164814, 103.6494018137455, 103.77259880304337, 93.00109639763832, 99.37676668167114, 109.9398122727871, 109.18994531035423, 105.17777100205421, 94.75536346435547, 82.67739236354828, 92.23903968930244, 97.89528697729111, 104.21055570244789, 96.58689558506012, 111.5511006116867, 97.967399507761, 54.01436001062393, 107.6064182817936, 131.47920727729797, 103.63753125071526, 105.08833900094032, 119.6906590461731, 62.45332717895508, 82.3861911892891, 113.98107782006264, 110.24757295846939, 107.0298220217228, 109.09314930438995, 105.51884829998016, 93.50556492805481, 86.85928076505661, 85.03363072872162, 89.64099749922752, 98.94078567624092, 102.24790021777153, 103.1338682770729, 103.90295460820198, 108.65262374281883, 101.86117976903915, 97.95748203992844, 91.40667915344238, 107.30768591165543, 125.84585756063461, 109.50081422924995, 74.29485216736794, 29.78648766875267, 4.062363440170884, 0.2851290110265836, 0.09589869747287594, 0.06542260351125151, 0.05634556226141285, 0.10445799794979393, 0.12688245013123378, 3.4670911822468042, 22.767137624323368, 50.41379861533642, 68.75167921185493, 87.09601566195488, 139.85227078199387, 137.94001579284668, 35.27762621641159, 33.36679995059967, 42.609853371977806, 37.973532155156136, 58.43208275735378, 69.29362893104553, 77.8877417743206, 72.16999098658562, 57.69118711352348, 28.439602442085743, 2.688562832772732, 0.22884778183652088, 0.1899247633991763, 0.025495891568425577, 0.08386957459151745, 0.16353170620277524, 0.060964993681409396, 0.10773351867101155, 0.067035379470326, 0.6658443273045123, 0.3545287245651707, 0.25779446528758854, 0.23591936565935612, 0.06743276986526325, 0.015792546328157187, 0.03842916739813518, 0.03570993460016325, 0.12152635550592095, 0.04291760233172681, 0.10244629535009153, 0.199384058942087, 0.28549061506055295, 0.04651606119296048, 0.08064229346928187, 0.008188452065951424, 0.00447830832854379, 0.1392069403664209, 0.20534420240437612, 0.1534047894529067, 0.14809340180363506, 0.033974874968407676, 0.042534635576885194, 0.09080054369405843, 0.14579345646779984, 0.05801871564472094, 0.01527506808997714, 0.05444792033813428, 0.08919478103052825, 0.08088476795819588, 0.018668496595637407, 0.029408547925413586, 0.02294616715516895, 0.11042358877602965, 0.06452981469919905, 0.05346112739061937, 0.11571153940167278, 0.09565395943354815, 0.11022579899872653, 0.11462303140433505, 0.04697002921602689, 0.08155811112374067, 0.058738238949445076, 0.03367562618223019, 0.07901379140093923, 0.03339974762639031, 0.09631693479605019, 0.05511756389751099, 0.1563621440436691, 0.13040313933743164, 0.010620825305522885, 0.027093841272289865, 0.06739308722899295, 0.040009043950703926, 0.25138789031188935, 0.04905723049887456, 0.15968451654771343, 0.16478029545396566, 0.06677687459159642, 0.06061660358682275, 0.015781781476107426, 0.05275508148770314, 0.07933574248454534, 0.4915257421089336, 62.95767031610012, 125.48469454050064, 117.5510622560978, 82.20589086413383, 81.6849236190319, 61.117926836013794, 28.94513301551342, 24.389270581305027, 38.552013114094734, 49.13583219051361, 43.5271355509758, 36.21285863220692, 42.565133571624756, 45.11429138481617, 20.134826973080635, 2.7688247384503484, 0.16886697616428137, 0.019819101944449358, 0.03608497521781828, 0.4451405326835811, 0.31975815596524626, 0.9851014742162079, 1.125574295874685, 3.031276180408895, 4.952284712344408, 3.3790634432807565, 6.579337930306792, 23.962154500186443, 48.06130304932594, 65.73042333126068, 81.87939718365669, 97.94898569583893, 104.99260693788528, 112.87700906395912, 109.055455327034, 109.89568144083023, 97.67223134636879, 100.51432684063911, 111.10378861427307, 112.93237969279289, 109.48995441198349, 96.66326388716698, 84.23246651887894, 95.9087535738945, 102.9232607781887, 109.0869252383709, 102.12363928556442, 115.31952559947968, 105.07609605789185, 60.25271326303482, 119.90483835339546, 142.41033911705017, 113.22798863053322, 111.99069142341614, 126.99231684207916, 70.19226551055908, 85.32486230134964, 120.63043981790543, 115.0923053920269, 110.7695509493351, 114.46090087294579, 109.49481055140495, 96.3217382133007, 90.3865858912468, 88.8759845495224, 95.9433089196682, 102.54709616303444, 107.27995499968529, 109.542695581913, 109.46959510445595, 115.02573296427727, 108.1971725821495, 103.74949604272842, 97.45436623692513, 107.65311017632484, 132.93094217777252, 121.91981703042984, 86.57464563846588, 39.52588565647602, 7.6721222419291735, 0.24768829898675904, 0.09865196887403727, 0.13039038924034685, 0.09659829782322049, 0.11921688099391758, 0.057598719431553036, 4.627964515239, 26.84127900749445, 48.494745790958405, 49.34927813708782, 53.18961426615715, 129.67960864305496, 155.25820970535278, 56.889760717749596, 38.020163252949715, 60.86844742298126, 55.87348625063896, 70.95587253570557, 82.03914061188698, 88.76718878746033, 86.99067011475563, 65.38198962807655, 29.838005304336548, 2.3228438571095467, 0.1502127677667886, 0.16377535328501835, 0.08680223050760105, 0.1479286895482801, 0.07704914096393622, 0.030943815836508293, 0.09016249707201496, 0.02717636809393298, 0.5906510527711362, 0.30301275139208883, 0.12934051745105535, 0.2841176121728495, 0.0869044687715359, 0.029898894172220025, 0.06152642468805425, 0.02407061736448668, 0.004720863526017638, 0.03155716563924216, 0.06544665651745163, 0.2293555295909755, 0.22204279230209067, 0.12167288514319807, 0.027710640206350945, 0.03283903279225342, 0.018209695335826837, 0.1410264044534415, 0.11397279871744104, 0.1525914846570231, 0.13228589377831668, 0.0844613705703523, 0.006562852258866769, 0.05750732765591238, 0.1639174300362356, 0.1549054417409934, 0.07807880407199264, 0.02330912189790979, 0.0781593716237694, 0.051283510256325826, 0.21919736842392012, 0.10622143730870448, 0.16980724758468568, 0.23896990431239828, 0.17267756309593096, 0.14476774900685996, 0.15119307063287124, 0.20833465678151697, 0.24490267736837268, 0.2596232359064743, 0.19345388340298086, 0.2555301133543253, 0.17928969813510776, 0.07389385558781214, 0.1474076573504135, 0.12386300004436634, 0.3341797477332875, 0.08295950858155265, 0.23085538035957143, 0.24535694596124813, 0.14588980207918212, 0.08056565187871456, 0.15316540229832754, 0.2160439977888018, 0.55355328717269, 0.30367851722985506, 0.3755003632977605, 0.5614052095916122, 0.1773709198459983, 0.294800442061387, 0.22081162867834792, 0.2008320632739924, 0.2937342133373022, 4.375277124345303, 104.79558750987053, 145.11966973543167, 129.49129074811935, 104.0472860634327, 85.19893705844879, 69.17439892888069, 24.536807164549828, 50.51652230322361, 136.4896184206009, 113.93969044089317, 74.20817121863365, 48.54507029056549, 70.64713150262833, 63.31987448036671, 26.055308282375336, 3.8260854687541723, 0.49081138044130057, 0.20726059097796679, 0.21358498051995412, 0.33060603949707, 0.20311251981183887, 0.4509496787795797, 0.5145844782236964, 3.6945923371240497, 10.625717528164387, 11.509573850780725, 18.176073879003525, 34.45152394473553, 56.5911765396595, 70.77022209763527, 86.39588803052902, 101.08306512236595, 107.66865134239197, 116.26246780157089, 113.69217932224274, 113.17084729671478, 100.6339368224144, 104.19065997004509, 114.35800999403, 112.10141748189926, 111.28630802035332, 98.82010415196419, 87.85906791687012, 100.2188090980053, 104.39419224858284, 113.00556376576424, 106.18803799152374, 120.2052654325962, 113.59691083431244, 74.65672954916954, 140.5586376786232, 136.0880559682846, 117.99446046352386, 115.74390202760696, 123.57791885733604, 80.98576873540878, 91.44291400909424, 127.1340112388134, 119.59293588995934, 115.74515596032143, 119.12233874201775, 114.94013875722885, 98.834870159626, 93.70392948389053, 93.80451008677483, 100.40843412280083, 108.5889695584774, 113.70661094784737, 113.7500350177288, 115.4192778468132, 122.56233215332031, 110.42044848203659, 104.52726870775223, 101.91629201173782, 117.50432476401329, 141.86760663986206, 123.45880284905434, 82.93947950005531, 37.911644876003265, 7.702103108167648, 0.35058020206633955, 0.35106057941447943, 0.2864002506248653, 0.23663242114707828, 0.17113342095399275, 0.13443132396787405, 7.663409309461713, 42.40292027592659, 78.22228342294693, 95.86828574538231, 118.98810714483261, 149.40664529800415, 147.52500146627426, 47.94201985001564, 46.963697746396065, 60.351477563381195, 55.685065761208534, 81.69766813516617, 93.7690731883049, 103.06101858615875, 98.307314068079, 84.58199456334114, 46.090443804860115, 4.123631352558732, 0.566412212792784, 0.30049324908759445, 0.25509937084279954, 0.2026504438254051, 0.34628007968422025, 0.13706047117011622, 0.1877328153932467, 0.1786668284330517, 0.7782403961755335, 0.500371519010514, 0.3939837293000892, 0.43806284840684384, 0.12629392702365294, 0.1525502509321086, 0.13021228864090517, 0.14603483257815242, 0.291911558015272, 0.12298604866373353, 0.18971029756357893, 0.39729281736072153, 0.3864935296587646, 0.15601201361278072, 0.13354398251976818, 0.08433522772975266, 0.2454250751179643, 0.26473859266843647, 0.3596187592484057, 0.3714581817621365, 0.25075513520278037, 0.1853775355266407, 0.13925670878961682, 0.2483118959935382, 0.3570925776148215, 0.197501779475715, 0.2253440284403041, 0.2829882415244356, 0.15384918748168275, 0.2301307622110471], [0.052715855272253975, 0.03671623861009721, 0.014530627177009592, 0.039866662918939255, 0.06107929555582814, 0.09324911894509569, 0.017134345616796054, 0.12411067698849365, 0.14387715695193037, 0.168206331145484, 0.06413827984943055, 0.03694771075970493, 0.06491851454484276, 0.05245063395705074, 0.04335454177635256, 0.06862860725959763, 0.04532140381343197, 0.047745098563609645, 0.022021388067514636, 0.09471852681599557, 0.017680716591712553, 0.0571135292557301, 0.02539495577366324, 0.1407445516088046, 0.1503998928819783, 0.08628708354081027, 0.26237601006869227, 0.23768803715938702, 0.05923783792241011, 0.02847948850103421, 0.19314685690915212, 0.11718090274371207, 1.9716696697287261, 67.78930485248566, 101.12281858921051, 97.88552910089493, 109.63426306843758, 90.75484693050385, 34.58401523530483, 14.330285992473364, 74.86749663949013, 70.77285155653954, 50.828895941376686, 42.24247768521309, 30.55963408201933, 32.992949411273, 21.06075558811426, 5.159969218075275, 0.34066751366481185, 0.39717226289212704, 0.14251286687795073, 0.13914022129029036, 0.09575709569617175, 0.07945177727378905, 0.37646904413122684, 1.1125583318062127, 5.344761852174997, 4.561185473576188, 3.126417612656951, 12.257886696606874, 33.77970099449158, 62.462473288178444, 71.32033377885818, 89.92076128721237, 94.15295898914337, 99.22881782054901, 102.7003875374794, 109.07842129468918, 107.50461414456367, 97.89647251367569, 88.9041106402874, 91.21791288256645, 102.7942880988121, 106.80340737104416, 102.19378352165222, 87.06621766090393, 84.69906628131866, 90.8922627568245, 90.33973440527916, 89.75910276174545, 99.69440683722496, 109.96010318398476, 89.29999619722366, 31.93312168121338, 86.06586053967476, 90.66511854529381, 92.21967592835426, 74.83552515506744, 91.4386810362339, 71.07324063777924, 94.3045936524868, 104.72925066947937, 100.98542556166649, 114.80909898877144, 117.58808746933937, 114.49493944644928, 107.73099079728127, 97.63927191495895, 88.5050256550312, 85.35262361168861, 88.65390166640282, 86.03199675679207, 87.2130037844181, 89.20962944626808, 88.8854992389679, 88.37801367044449, 89.5566800236702, 97.09484472870827, 102.75796964764595, 99.36208426952362, 101.73348382115364, 111.0803210735321, 102.23074033856392, 72.91271433234215, 20.283898673951626, 0.9642736637033522, 0.16663266636896878, 0.1307021506363526, 0.10348536146921106, 0.07469192409189418, 0.04487211503146682, 0.4315013129962608, 11.030896436423063, 31.18230476975441, 43.84594984352589, 29.483814910054207, 38.92172187566757, 46.74016714096069, 33.1049408018589, 14.387569818645716, 19.0371285751462, 32.49023638665676, 45.88111683726311, 76.44026264548302, 72.84763902425766, 72.00064927339554, 71.89320623874664, 38.476887345314026, 1.5893980697728693, 0.02227516917628236, 0.04488403021241538, 0.003862735561597219, 0.10365561014623381, 0.013549710183724528, 0.06763224431779236, 0.0679491191112902, 0.22051954903872684, 0.1756649449816905, 0.12809464446036145, 0.19805132498731837, 0.025784449717320967, 0.07355913956416771, 0.05695873209333513, 0.10062829329399392, 0.007655761655769311, 0.032813963043736294, 0.09542080631945282, 0.05212764757743571, 0.19207613077014685, 0.047150734753813595, 0.15381141216494143, 0.0640381863922812, 0.06721397730871104, 0.09156282583717257, 0.044859877016278915, 0.12541550619062036, 0.0449415243929252, 0.04180031013675034, 0.0583852957788622, 0.017853753888630308, 0.12326553405728191, 0.02693252063181717, 0.04476177993637975, 0.05830711052112747, 0.033781003730837256, 0.023390333262796048, 0.060869145308970474, 0.017102297824749257, 0.043070221290690824, 0.06827696284744889, 0.021178723909542896, 0.041115155690931715, 0.029254108849272598, 0.13916342082666233, 0.15646902815205976, 0.04572732148517389, 0.02921930583397625, 0.04102398284885567, 0.042570384830469266, 0.10879834473598748, 0.048269321996485814, 0.043964768992736936, 0.044849943369627, 0.0688778204494156, 0.053802311231265776, 0.05073630622064229, 0.052672695674118586, 0.04689498324296437, 0.022502481588162482, 0.13100349227897823, 0.039875041766208597, 0.04723365120298695, 0.3464541578432545, 0.12270875260583125, 0.03363068542967085, 0.05191574957279954, 0.13443390664178878, 0.09868123917840421, 1.1900322558358312, 70.4436220228672, 119.30162832140923, 109.85211297869682, 119.21712085604668, 107.7859054505825, 48.82057070732117, 22.43980798870325, 29.301154911518097, 49.75939393043518, 47.326335087418556, 47.9006514698267, 37.64658249914646, 40.47706201672554, 28.29137809574604, 8.765393402427435, 0.2289467101218179, 0.49689773353748024, 0.09068237151950598, 0.20125698734773323, 0.4130507499212399, 0.3008710913127288, 1.232960452325642, 2.73980759549886, 2.696103765629232, 1.97601153049618, 3.8305675657466054, 13.817602302879095, 37.76695244014263, 65.03826767206192, 74.86397802829742, 92.77522891759872, 95.39097055792809, 98.82205724716187, 106.97154074907303, 112.02065661549568, 110.80228999257088, 101.88297539949417, 92.72746548056602, 94.39534798264503, 106.41724169254303, 108.63725736737251, 105.83158671855927, 91.10671564936638, 87.49253958463669, 95.8597058057785, 95.8790771663189, 94.22790616750717, 105.87606713175774, 117.17034548521042, 94.95263367891312, 38.532831743359566, 92.1451011300087, 100.11088728904724, 100.42984217405319, 85.89196667075157, 101.01118817925453, 77.64444842934608, 98.4536974132061, 110.7517983019352, 107.46706455945969, 119.76992279291153, 122.01885491609573, 123.00297930836678, 114.83630552887917, 103.80618900060654, 92.53686770796776, 91.32439836859703, 95.97920179367065, 90.61821386218071, 95.07209166884422, 92.5905816257, 93.12395140528679, 93.33155706524849, 93.27774435281754, 101.73928990960121, 110.92281192541122, 103.70709031820297, 100.823455452919, 115.43247833848, 113.56581330299377, 87.3448871076107, 27.010179944336414, 2.441130322404206, 0.11573823445360176, 0.06670389178907499, 0.10074063218780793, 0.08250401544501074, 0.12153020725236274, 0.6011191941797733, 15.525970682501793, 39.17160406708717, 46.059882044792175, 37.11321271955967, 36.317569613456726, 24.52223874628544, 34.34586301445961, 24.61472388356924, 33.00342544913292, 50.550363287329674, 54.46414187550545, 82.84168794751167, 77.53008216619492, 84.36305791139603, 83.48234117031097, 43.16066801548004, 1.2472092127427459, 0.07856770127546042, 0.06421935206162743, 0.021015963502577506, 0.06902691791765392, 0.027798208066087682, 0.06526341283461079, 0.01658648849115707, 0.24352324748178944, 0.11518992090714164, 0.10481575765879825, 0.21330700168618932, 0.05430050383438356, 0.07072225780575536, 0.033061795838875696, 0.045414888445520774, 0.04330048002884723, 0.007224741302707116, 0.05305029670125805, 0.04957849276252091, 0.19298273837193847, 0.04311783748562448, 0.08536046763765626, 0.04240718284563627, 0.045101716968929395, 0.12654302146984264, 0.02342827556276461, 0.16422690561739728, 0.044280949878157116, 0.04106061896891333, 0.014588796711905161, 0.06474482972407714, 0.06968758520088159, 0.07910391039331444, 0.044483218516688794, 0.019861332002619747, 0.07418994282488711, 0.019581538617785554, 0.14438629994401708, 0.21577560750301927, 0.16632160259177908, 0.17439229530282319, 0.19041211693547666, 0.19540003209840506, 0.1815737466677092, 0.2695580996805802, 0.24844684812705964, 0.36084784485865384, 0.23001621913863346, 0.10670642339391634, 0.16475619049742818, 0.2014987642178312, 0.12193682254292071, 0.17880736151710153, 0.1506923881242983, 0.1931425672955811, 0.1337274265824817, 0.2289139962522313, 0.2081607567379251, 0.17758780508302152, 0.08337698149261996, 0.16024390293750912, 0.29619677807204425, 0.2643884177086875, 0.46372337616048753, 0.2847076492616907, 0.12515766924479976, 0.16965458780759946, 0.41267385764513165, 0.2931062673451379, 6.439864514395595, 112.01159790158272, 134.37457591295242, 118.00398275256157, 134.31415915489197, 117.104981392622, 59.8566909134388, 32.50290110707283, 106.18318945169449, 100.98439961671829, 71.38847172260284, 65.06607457995415, 51.96793422102928, 59.82830263674259, 36.85786262154579, 10.859018359333277, 0.9940294513944536, 0.6939771270845085, 0.5815066059585661, 0.3874786267988384, 0.42430743807926774, 0.16139757150085643, 1.0812100139446557, 4.354271376505494, 13.321402128785849, 11.967632621526718, 10.968601629137993, 19.105855487287045, 44.15524564683437, 73.25056180357933, 73.43637183308601, 96.31649449467659, 101.89761221408844, 104.157654941082, 108.20178553462029, 116.7963619530201, 112.87222892045975, 104.79678824543953, 95.41629239916801, 99.6573968231678, 108.89065057039261, 114.64006125926971, 108.26522693037987, 93.65444853901863, 88.42386201024055, 100.05325958132744, 99.06966716051102, 100.86117222905159, 111.15100488066673, 123.72174873948097, 98.07468295097351, 49.959430396556854, 95.91310814023018, 111.42283469438553, 110.24711698293686, 94.67677608132362, 107.85935550928116, 92.6298639178276, 105.1070947945118, 114.50231105089188, 112.83391937613487, 125.73587626218796, 128.7584164738655, 128.63528788089752, 119.52941849827766, 109.8622964322567, 96.3000337779522, 91.57681122422218, 97.49214380979538, 93.08450192213058, 98.30928236246109, 95.98931685090065, 96.25030964612961, 99.71757799386978, 101.7518900334835, 109.42722737789154, 114.54862296581268, 106.60297572612762, 108.04897293448448, 123.68999764323235, 117.79329925775528, 87.81161606311798, 25.956108905375004, 2.5853076484054327, 0.22118345950730145, 0.31242636032402515, 0.3315576509339735, 0.17761382478056476, 0.10682835083571263, 1.049152440391481, 22.559349574148655, 54.21698793768883, 68.05635452270508, 42.97115698456764, 49.75441239774227, 62.31696009635925, 48.767609149217606, 23.17938320338726, 31.52476329356432, 49.437064826488495, 65.50701051950455, 97.13535815477371, 91.63228824734688, 95.53966417908669, 95.97356289625168, 60.774516463279724, 3.341558505780995, 0.23407668719301, 0.18089502293150872, 0.08636804443085566, 0.2601772639900446, 0.10610046723741107, 0.1597094675526023, 0.1092091976897791, 0.4166441399138421, 0.2165656237048097, 0.30275249504484236, 0.3303140786010772, 0.08899296139134094, 0.20329482096713036, 0.23455926129827276, 0.13887448789319023, 0.10476729541551322, 0.19611078692832962, 0.15895989839918911, 0.161735619767569, 0.30953272653277963, 0.16241192410234362, 0.24518150225048885, 0.14606318261940032, 0.16462203988339752, 0.22007776336977258, 0.16616438602795824, 0.24039715819526464, 0.2705655206227675, 0.1268764238920994, 0.13582142593804747, 0.20815821859287098, 0.23313325422350317, 0.2694604330463335, 0.15763121657073498, 0.15297036588890478, 0.20413880614796653, 0.13993819331517443], [0.055377404642058536, 0.0711880816379562, 0.024600033975730184, 0.055689358996460214, 0.04803942691069096, 0.03623783908551559, 0.03629992716014385, 0.01806097450753441, 0.08832459061522968, 0.14488385058939457, 0.044195476730237715, 0.04395188530907035, 0.0391504199069459, 0.027470362474559806, 0.041574597053113393, 0.03457202925346792, 0.06612926168600097, 0.0491015070292633, 0.08563079492887482, 0.04309969568566885, 0.12970042938832194, 0.006227950234460877, 0.019926717068301514, 0.15097783296369016, 0.047123906115302816, 0.018205047636001837, 0.30821767053566873, 0.20254109578672796, 0.14815974980592728, 0.12451116956071928, 0.2376620619907044, 1.9185271463356912, 83.2059819996357, 107.32834920287132, 112.23738178610802, 91.11885219812393, 68.59278693795204, 42.57365271449089, 23.755363896489143, 26.725349128246307, 64.38357040286064, 36.31398640573025, 34.610017240047455, 32.00600937008858, 28.286212272942066, 13.824175000190735, 1.0438182391226292, 0.46579770860262215, 0.2241564288851805, 0.07690231446758844, 0.22720162407495081, 0.1496806033537723, 0.24778316030278802, 2.021078774705529, 0.6426985817961395, 4.664156148210168, 5.031858142465353, 9.41335553303361, 32.31350027024746, 58.54681000113487, 84.1580057144165, 99.03159320354462, 105.51403015851974, 100.1850213110447, 76.11322179436684, 95.88776350021362, 103.95503461360931, 105.43393805623055, 103.52108269929886, 99.05058458447456, 92.60188981890678, 89.02714043855667, 95.55375382304192, 90.68051531910896, 84.26055461168289, 80.77441647648811, 96.34989470243454, 105.5007004737854, 112.05863937735558, 99.88837122917175, 109.80899289250374, 94.45518717169762, 105.78040346503258, 55.49887575209141, 65.65809041261673, 97.89315909147263, 78.99216011166573, 74.31904166936874, 92.26117730140686, 51.892527267336845, 100.92671871185303, 104.6552762389183, 97.0712099969387, 101.08646973967552, 105.38772493600845, 111.71237915754318, 103.91121536493301, 98.27346548438072, 94.5849198102951, 85.31605437397957, 83.71456190943718, 93.27438533306122, 92.35275998711586, 104.7091193497181, 104.80906918644905, 105.52964732050896, 89.85488042235374, 79.56934913992882, 84.46065187454224, 102.46521055698395, 98.13772156834602, 92.49347403645515, 96.5354311466217, 110.38648590445518, 91.66001155972481, 44.75024051964283, 4.871227461844683, 0.06772316482965834, 0.12527467624749988, 0.04121148645936046, 0.053473254083655775, 0.060309165201033466, 0.1020146177324932, 4.5818820130079985, 21.97507582604885, 44.9020803719759, 67.94631242752075, 94.73830237984657, 55.95207743346691, 75.6015032529831, 25.05122546106577, 16.572134345769882, 25.448315553367138, 51.65331870317459, 58.068077489733696, 74.69757735729218, 73.63580793142319, 79.2716883122921, 44.288196712732315, 3.0269479751586914, 0.21953109739115462, 0.017219577566720545, 0.052281865864642896, 0.13223716436186805, 0.11029468514607288, 0.08326411567395553, 0.1647872567991726, 0.08058278806856833, 0.17144151614047587, 0.12693917989963666, 0.012885047362942714, 0.08247841877164319, 0.07456155843101442, 0.02315083664143458, 0.08226733712945133, 0.05101133130665403, 0.06873973645269871, 0.13801319582853466, 0.261778284329921, 0.04602556466124952, 0.03519390447763726, 0.05869428896403406, 0.012812569220841397, 0.10356593644246459, 0.06223168020369485, 0.057017621511477046, 0.08441624799161218, 0.061564771458506584, 0.037131863573449664, 0.027860964073624928, 0.06224930992175359, 0.02026650938205421, 0.005252293676676345, 0.03279254095104989, 0.09616613038815558, 0.11696492292685434, 0.06646549169090576, 0.03852543137327302, 0.005300111179167288, 0.0701496315014083, 0.027326523122610524, 0.05211410709307529, 0.054974603990558535, 0.04471681691939011, 0.10875238353037275, 0.1413388634682633, 0.042476191447349265, 0.07429022924043238, 0.05749662588641513, 0.03633014370279852, 0.02785837212286424, 0.018535067720222287, 0.09001998987514526, 0.05340741445252206, 0.14937301282770932, 0.10870945770875551, 0.045153930768719874, 0.04373199066321831, 0.03394982748432085, 0.1118171788402833, 0.06457746058003977, 0.04350717928900849, 0.10412023169919848, 0.12412874828442, 0.10403313324786723, 0.15103904530405998, 0.12487667729146779, 2.301271464675665, 94.23917636275291, 126.03846162557602, 123.8695228099823, 102.84112438559532, 96.94593831896782, 77.25500732660294, 45.03492884337902, 28.713271357119083, 60.679084584116936, 38.846083134412766, 40.502839833498, 36.59357160329819, 35.631425231695175, 19.324144273996353, 2.1929342905059457, 0.6166145845782012, 0.3336647863034159, 0.14009328733664006, 0.26301476173102856, 0.5805408640298992, 0.7570763037074357, 2.8406969318166375, 0.8119923819322139, 1.456324104219675, 1.6764163691550493, 8.534316401928663, 31.809937991201878, 63.01992617547512, 87.8321273624897, 99.99440833926201, 103.97659465670586, 103.445915132761, 86.51181221008301, 99.16875064373016, 107.08182603120804, 109.11288544535637, 107.37053453922272, 105.43566316366196, 93.89124423265457, 92.0608140528202, 96.60899519920349, 94.51276928186417, 86.22794464230537, 80.88790118694305, 98.76243844628334, 108.86154413223267, 117.67861381173134, 107.8206279873848, 114.09174308180809, 100.81511870026588, 110.91614708304405, 61.997074261307716, 72.85113483667374, 111.7155709862709, 86.42061710357666, 81.85734316706657, 98.19254502654076, 62.718837931752205, 104.06706020236015, 110.63392862677574, 99.71687883138657, 105.43006226420403, 108.18581119179726, 114.9797934293747, 107.49335154891014, 103.07062447071075, 97.78570085763931, 91.11718788743019, 88.35964545607567, 97.88156971335411, 97.99674153327942, 111.81266337633133, 112.49690786004066, 110.13985633850098, 94.66327920556068, 83.89402627944946, 86.07354372739792, 106.80650040507317, 103.28730404376984, 99.23645541071892, 99.97131317853928, 114.18120548129082, 103.28953832387924, 55.963837802410126, 8.798486776649952, 0.3166300925659016, 0.11867141729453579, 0.04605038950103335, 0.06817396017140709, 0.03801311941060703, 0.12270370600163005, 5.247488021850586, 28.281065449118614, 47.19550810754299, 55.09604036808014, 59.370784386992455, 41.10297963023186, 46.18264585733414, 27.424809895455837, 31.59293733537197, 37.16442257165909, 68.09872224926949, 71.3724897801876, 85.39280265569687, 85.63201501965523, 89.49024438858032, 50.14247037470341, 2.9706656327471137, 0.2778837498044595, 0.06660422135610133, 0.10589636178337969, 0.08428809393080883, 0.13498302170773968, 0.15097542840521783, 0.20527346088783816, 0.04867824536631815, 0.048924059519777074, 0.022256008778640535, 0.06999338715104386, 0.054668464363203384, 0.04071434770594351, 0.013725295830226969, 0.049726903744158335, 0.127913486212492, 0.13183258997742087, 0.132938627502881, 0.25180937082041055, 0.08702660401468165, 0.06643917513429187, 0.03750274074263871, 0.06885467286338098, 0.07238647202029824, 0.06582054309546947, 0.060792121512349695, 0.11082539494964294, 0.027884671981155407, 0.03197745871148072, 0.15588736248901114, 0.06974095304030925, 0.045771902296110056, 0.012030843736283714, 0.10922593311988749, 0.0928730949817691, 0.06527143545099534, 0.15797169908182696, 0.1533572474727407, 0.3312062588520348, 0.16827171435579658, 0.10307450851541944, 0.20328924001660198, 0.13434777298243716, 0.17492885323008522, 0.41642387048341334, 0.2021231479011476, 0.19005282840225846, 0.18074976978823543, 0.129913633572869, 0.11206621391465887, 0.11229858035221696, 0.09594703355105594, 0.23191963497083634, 0.17142628727015108, 0.2662724338006228, 0.2620913815917447, 0.17879863386042416, 0.19081528123933822, 0.14446005458012223, 0.24336145928828046, 0.21925233188085258, 0.12795074202585965, 0.38040759216528386, 0.3805468190694228, 0.23941844352521002, 0.20495942851994187, 0.3602924512233585, 7.573872338980436, 127.31517031788826, 135.35691440105438, 140.92767387628555, 118.62389668822289, 93.35676491260529, 63.72597008943558, 41.085561364889145, 46.92198358476162, 95.68045422434807, 58.467105478048325, 58.52486237883568, 54.42351445555687, 48.999978080391884, 23.502990938723087, 2.9500588634982705, 1.436905364971608, 0.4994042927864939, 0.24416330532403663, 0.36540697677992284, 0.40954232099466026, 0.39794068259652704, 5.904472293332219, 3.016629866324365, 11.908468846231699, 14.852579366415739, 16.428931429982185, 37.986557856202126, 66.70383989810944, 90.55012911558151, 103.18112254142761, 107.91303142905235, 106.24175950884819, 89.48549464344978, 103.47599431872368, 109.5574539899826, 117.01684892177582, 111.17131099104881, 109.45685058832169, 98.28186303377151, 96.01256400346756, 101.77180096507072, 95.06671875715256, 87.97407254576683, 84.10790920257568, 100.49224242568016, 112.37100541591644, 120.96409231424332, 112.83328101038933, 119.07588243484497, 106.52517110109329, 114.13406521081924, 66.48843705654144, 89.09587875008583, 121.9470539689064, 93.62747758626938, 87.06785157322884, 102.80913770198822, 74.06206905841827, 105.99186971783638, 117.18425273895264, 102.73131027817726, 110.75383499264717, 115.46550616621971, 121.7097795009613, 111.97425350546837, 105.88884204626083, 102.56354928016663, 96.73156142234802, 92.28294253349304, 102.9735016822815, 102.30285286903381, 117.55281776189804, 115.77651187777519, 115.84104761481285, 97.81825751066208, 87.47396618127823, 92.7979288995266, 114.95918333530426, 109.91163298487663, 103.17140266299248, 105.3461779654026, 119.87481236457825, 104.71758529543877, 57.742674350738525, 8.841424472630024, 0.3039002709556371, 0.17323414416750893, 0.16669837612425908, 0.15775132575072348, 0.1610389509005472, 0.2633312135003507, 9.880026541650295, 39.95520941913128, 74.65344652533531, 102.68788620829582, 131.51521414518356, 74.51993688941002, 92.789356559515, 35.307625606656075, 27.78419841080904, 41.35733038187027, 74.81728613376617, 78.19760754704475, 96.94124937057495, 94.11369949579239, 101.15623399615288, 73.5781118273735, 8.254000693559647, 0.5147333233617246, 0.12329487857641652, 0.2544522477546707, 0.29623851645737886, 0.19321439234772697, 0.3555283974856138, 0.33049154095351696, 0.29490835033357143, 0.2571247215382755, 0.19670094276079908, 0.19019989238586277, 0.1629593173856847, 0.11864734202390537, 0.1102867144800257, 0.19232320657465607, 0.14008444093633443, 0.21519548550713807, 0.31586081197019666, 0.4315942001994699, 0.19731900334591046, 0.12565940560307354, 0.11030039968318306, 0.2620035409927368, 0.25058607396204025, 0.2922605158528313, 0.18725856818491593, 0.20596536516677588, 0.1321137452032417, 0.12095822661649436, 0.24373873748118058, 0.2367112075444311, 0.11868838279042393, 0.1307331575662829, 0.2257348137209192, 0.20460978790652007, 0.23350118135567755], [0.03938890906283632, 0.04938075493555516, 0.098684074182529, 0.05983944138279185, 0.027374655110179447, 0.06506496996735223, 0.020620370960386936, 0.10015889230999164, 0.029721062601311132, 0.1322309600072913, 0.025641779247962404, 0.04759507341077551, 0.04945088418025989, 0.06061691157810856, 0.009297417363995919, 0.03462644723185804, 0.07259567602886818, 0.05957504014077131, 0.038188184626051225, 0.09850187692791224, 0.06085591281589586, 0.00815160999991349, 0.05347595921193715, 0.05656094836012926, 0.0466554216836812, 0.20426455565029755, 0.14396385464351624, 0.10132498442544602, 0.13067400839645416, 0.10565758318989538, 10.097770057618618, 96.995138078928, 111.42788842320442, 106.05032578110695, 90.98202154040337, 66.49999603629112, 22.874763049185276, 14.674753658473492, 23.891223706305027, 46.6634264588356, 43.87029513716698, 47.17800624668598, 39.93453852832317, 25.928188003599644, 10.302992295473814, 0.1555599714629352, 0.6180007383227348, 0.11011849186616018, 0.1944564952282235, 0.14455789932981133, 0.22347730438923463, 0.48840940464287996, 0.7825895003043115, 2.177852662280202, 4.542889455333352, 6.470143664628267, 26.617816798388958, 54.60640624165535, 93.50228950381279, 103.20000752806664, 103.67707192897797, 97.76821419596672, 93.70575338602066, 96.95514902472496, 103.75709563493729, 97.3565898835659, 96.70596599578857, 101.62144303321838, 103.7630233168602, 95.27608752250671, 89.01665300130844, 80.12133032083511, 82.96583488583565, 74.31266561150551, 75.37977755069733, 91.53100848197937, 107.24954143166542, 104.05420169234276, 102.370246052742, 102.73209303617477, 104.1143524646759, 101.32107675075531, 109.18738424777985, 79.23597022891045, 29.394082725048065, 95.00615760684013, 80.82450538873672, 94.8421736061573, 90.74396431446075, 56.71639882028103, 107.81267121434212, 97.36351311206818, 89.92709934711456, 84.4389246404171, 100.2054338157177, 107.29936435818672, 105.8687411248684, 98.18802326917648, 95.16713976860046, 88.79060313105583, 85.16371294856071, 83.59356120228767, 93.06187033653259, 106.0449680685997, 105.42930230498314, 100.44166713953018, 95.7213020324707, 85.4167565703392, 81.12206742167473, 73.04123103618622, 79.10949781537056, 84.38364520668983, 90.05072951316833, 100.26886761188507, 100.82578092813492, 98.24512660503387, 53.97497892379761, 9.751661829650402, 0.5338252801448107, 0.12918668508064002, 0.055868071867735125, 0.03489109338261187, 0.05441017470730003, 0.04918488360999618, 1.603203322738409, 17.13963959366083, 28.743276447057724, 42.665600180625916, 71.6201376914978, 71.8042454123497, 62.11823455989361, 34.07291226089001, 19.492410644888878, 14.263263288885355, 24.077113531529903, 53.04635435342789, 67.6779556274414, 76.016296595335, 82.78372585773468, 64.00156170129776, 10.665262956172228, 0.3175373829435557, 0.07758860811009072, 0.06445893217460252, 0.0616379360872088, 0.10021835318184458, 0.16272858367301524, 0.1825718759209849, 0.07834996256860904, 0.06767612750991248, 0.0159767028526403, 0.11154144129250199, 0.020205026157782413, 0.07596201336127706, 0.10905707225902006, 0.0685679737944156, 0.0487649467686424, 0.03593689820263535, 0.10917045758105814, 0.05032220637076534, 0.08759628399275243, 0.029557443158410024, 0.04079482991073746, 0.09220726235071197, 0.04745646619994659, 0.0500499272311572, 0.11362122852005996, 0.08364388006157242, 0.04142012643569615, 0.047071106018847786, 0.01225190262630349, 0.04833915438211989, 0.03141138928185683, 0.08483435172820464, 0.027631356570054777, 0.03360657676239498, 0.024387776029470842, 0.004122733780604904, 0.062336664414033294, 0.06362398635246791, 0.04359352446044795, 0.06454882852267474, 0.07544264357420616, 0.03854747315926943, 0.03441637119976804, 0.06716018644510768, 0.00696495158081234, 0.12366405993816443, 0.01486351844505407, 0.057281024564872496, 0.01124460135542904, 0.036116353221586905, 0.1077616831753403, 0.017059307065210305, 0.02875578822568059, 0.03903505676134955, 0.02063672975054942, 0.03908960832632147, 0.04281278139387723, 0.1880869088927284, 0.08369065762963146, 0.14815261034527794, 0.15873551747063175, 0.059833541308762506, 0.04271043180779088, 0.15038338751764968, 10.199815481901169, 114.29479658603668, 127.74871945381165, 115.87545856833458, 106.73626497387886, 87.09820434451103, 40.510390028357506, 31.614712066948414, 31.86042968183756, 43.904884681105614, 46.35277032852173, 48.89967106282711, 48.14761161804199, 37.30239696800709, 15.470844190567732, 0.7340281654614955, 0.5310521414503455, 0.31065981136634946, 0.2621860202634707, 0.29012090410105884, 0.5788883089553565, 1.2700583366677165, 0.7213058543857187, 0.8822750730905682, 3.7114240089431405, 10.318057537078857, 33.16645950078964, 63.75429376959801, 95.89421555399895, 108.15625637769699, 106.62544012069702, 102.49944671988487, 99.58277642726898, 102.98201322555542, 105.87279170751572, 98.7880490720272, 102.1225069463253, 105.15226677060127, 106.02330163121223, 99.59444180130959, 91.26162573695183, 83.3616216480732, 86.80975422263145, 78.67461115121841, 79.18025761842728, 96.230239123106, 111.8056945502758, 108.8793271780014, 106.8430544435978, 106.06406584382057, 110.40255904197693, 104.88913848996162, 113.72655227780342, 82.50614315271378, 37.31462851166725, 104.86907556653023, 87.98728063702583, 103.77131447196007, 97.11884424090385, 65.26920408010483, 109.0573400259018, 103.82850900292397, 94.69616264104843, 91.78412050008774, 104.33117642998695, 110.48913359642029, 111.36564016342163, 104.56967443227768, 100.35518378019333, 94.96740728616714, 89.41791906952858, 91.0302409529686, 98.85957643389702, 111.01998031139374, 107.74070307612419, 103.37632566690445, 100.10001227259636, 90.37219226360321, 84.4803424179554, 74.89487037062645, 80.90481787919998, 89.45482268929482, 98.13878551125526, 107.22146853804588, 105.54172307252884, 103.93797352910042, 62.96587787568569, 15.221338178962469, 1.1003142013214529, 0.16839798336150125, 0.10537768219364807, 0.04808590761967935, 0.06605634567677043, 0.127962393744383, 2.3762523662298918, 22.011757157742977, 32.70231820642948, 44.20395903289318, 51.79761216044426, 60.93839406967163, 33.27293738722801, 20.44673703610897, 28.07252313941717, 28.00200842320919, 35.74073776602745, 61.88085749745369, 76.80515706539154, 86.07119545340538, 96.63097321987152, 72.41803407669067, 12.16937044635415, 0.4479282768443227, 0.07793935452355072, 0.03468923292530235, 0.033214871218660846, 0.027214740839553997, 0.17636073811445385, 0.09543808351736516, 0.09235327248461545, 0.06619483043323271, 0.046424480169662274, 0.04583622794598341, 0.03036590358533431, 0.037415545812109485, 0.03367694720509462, 0.05769173651060555, 0.10808398306835443, 0.04392010283481795, 0.10136278200661764, 0.01139574251283193, 0.03674979481729679, 0.06805434080888517, 0.02733298908424331, 0.028145707583462354, 0.043990451013087295, 0.06589805299881846, 0.11739455963834189, 0.08423892664723098, 0.05220204417128116, 0.046854053798597306, 0.09701608985778876, 0.04484583929297514, 0.046454960174742155, 0.0807577493833378, 0.03451719196164049, 0.13665144389960915, 0.09959917195374146, 0.08144031002302654, 0.19253271486377344, 0.15893637231783941, 0.1304041635012254, 0.0967963325092569, 0.13464381569065154, 0.24764304282143712, 0.1356166080222465, 0.23795129178324714, 0.11704930511768907, 0.16097761981654912, 0.16046921897213906, 0.1349449940607883, 0.0865589025488589, 0.22351448598783463, 0.16908292629523203, 0.11067775209085084, 0.14629992772825062, 0.15996133763110265, 0.15987066202796996, 0.08933462391723879, 0.130612647626549, 0.3068195533705875, 0.17955749470274895, 0.3380631987238303, 0.29395023768302053, 0.1670697022927925, 0.39500180748291314, 0.18384081486146897, 21.814595237374306, 150.01002252101898, 136.94047182798386, 135.39941132068634, 119.87222090363503, 90.41721224784851, 36.42650216817856, 23.004419691860676, 36.58581621944904, 67.82847315073013, 63.04668813943863, 71.98573127388954, 63.854099214076996, 46.2377543002367, 20.565041787922382, 1.5848471014760435, 0.8973131224047393, 0.461878931382671, 0.47921045450493693, 0.392341801780276, 0.47069751599337906, 1.5858314861543477, 3.9712094189599156, 10.761746428906918, 8.733743000775576, 11.13626953214407, 32.61808052659035, 64.98317062854767, 100.13796463608742, 111.12903445959091, 111.45580932497978, 109.30227488279343, 102.59633392095566, 108.05752247571945, 109.8969429731369, 100.84457471966743, 104.94688779115677, 109.38634157180786, 108.64553332328796, 103.83104726672173, 95.7524299621582, 86.95897981524467, 90.28402179479599, 79.87763419747353, 82.60060608386993, 99.88864481449127, 115.68959534168243, 111.97698175907135, 111.42588973045349, 112.59031444787979, 116.17067232728004, 107.38988310098648, 117.3735661804676, 85.2715815603733, 45.18524497747421, 118.1342625617981, 97.77987957000732, 111.55136659741402, 108.85326817631721, 80.62246263027191, 114.61284711956978, 109.44559559226036, 97.48396664857864, 98.53926122188568, 111.3845631480217, 118.68387266993523, 115.84692969918251, 109.16773170232773, 104.51869636774063, 97.63672605156898, 91.7039903998375, 93.32947477698326, 100.1906906068325, 115.53441166877747, 111.97236880660057, 108.95682781934738, 105.49688547849655, 96.28195434808731, 87.41328343749046, 79.46093335747719, 84.6259506046772, 95.21315529942513, 102.62952893972397, 114.18978542089462, 111.10515654087067, 109.11464855074883, 63.75656604766846, 15.319604706019163, 1.720911506563425, 0.33273870474658906, 0.12144963970058598, 0.1712627476081252, 0.20511606620857492, 0.2419578650733456, 3.7728379759937525, 30.32990410923958, 44.896623864769936, 62.6745019108057, 99.61749136447906, 90.09001940488815, 83.2457734644413, 48.88106346130371, 27.502595521509647, 27.813745625317097, 39.786943048238754, 74.5716293156147, 90.81152468919754, 95.80398559570312, 104.83601734042168, 95.4525576531887, 22.126507200300694, 0.5636249436065555, 0.2894349815323949, 0.15568857081234455, 0.1612276048399508, 0.22595248563447967, 0.2724986965768039, 0.27754720067605376, 0.1844797149533406, 0.2585856837686151, 0.17412804620107636, 0.19521764188539237, 0.1434436091221869, 0.2804102876689285, 0.3065147087909281, 0.16679182735970244, 0.19960216130129993, 0.19169751671142876, 0.2635444770567119, 0.1829918276052922, 0.16067725780885667, 0.15327881730627269, 0.14318841422209516, 0.14444528584135696, 0.13893136609112844, 0.18585970887215808, 0.2140613947995007, 0.27409021742641926, 0.16258125251624733, 0.14922042726539075, 0.24602216260973364, 0.133196419919841, 0.07479494161088951, 0.14965903654228896, 0.07064442135742866, 0.2829732798272744], [0.0887170086207334, 0.0265309742098907, 0.04790582177520264, 0.048279971815645695, 0.006467909306593356, 0.04841246744035743, 0.06574655839358456, 0.034000430823653005, 0.0799840381660033, 0.021394651776063256, 0.004908939054075745, 0.03407374388189055, 0.09682066753157414, 0.015162432337092469, 0.03619495779275894, 0.06408103799913079, 0.09510350850177929, 0.050377555744489655, 0.06693435090710409, 0.061501978343585506, 0.0977631208661478, 0.08317907297168858, 0.16098277032142505, 0.01693644080660306, 0.08503810837282799, 0.03785464490647428, 0.09648345047025941, 0.24170256627257913, 0.05088560777949169, 18.801721706986427, 114.45691108703613, 100.82334145903587, 107.80821785330772, 79.70973640680313, 74.27593678236008, 29.67095486819744, 30.415086038410664, 42.78290368616581, 76.28361985087395, 65.28381809592247, 36.09617829322815, 27.17268582433462, 21.785209514200687, 5.1815971825271845, 0.2951420081080869, 0.14553458051523194, 0.16192367998883128, 0.2424064339720644, 0.15204774274025112, 0.16597221430856735, 0.04410163215652574, 3.235092256218195, 14.91023177281022, 38.46235312521458, 69.95455026626587, 92.93664425611496, 106.73324793577194, 104.64556396007538, 101.9455124437809, 98.31208661198616, 92.8936305642128, 94.27038788795471, 95.85183262825012, 90.88767260313034, 98.54806914925575, 101.45886495709419, 95.29213786125183, 94.77681711316109, 95.56440085172653, 95.53518801927567, 87.72567227482796, 79.43244248628616, 76.64034470915794, 75.79967021942139, 89.55888390541077, 100.85619449615479, 101.80583953857422, 99.83127549290657, 98.47689136862755, 102.74273246526718, 100.30732154846191, 103.15191730856895, 91.78170382976532, 111.29007741808891, 55.78800983726978, 72.79851526021957, 82.3115099966526, 91.35761618614197, 63.499213457107544, 39.04423490166664, 101.24733030796051, 100.45605316758156, 98.01017001271248, 90.8997255563736, 88.99006962776184, 99.57193180918694, 96.20197623968124, 91.85555666685104, 91.84147462248802, 88.75365391373634, 84.35939490795135, 87.29330107569695, 102.12939217686653, 108.85142907500267, 103.05607885122299, 99.5159076154232, 93.21182548999786, 82.14162111282349, 83.78186389803886, 92.31477722525597, 93.41224193572998, 87.92367205023766, 86.31034702062607, 87.31980085372925, 93.72985169291496, 96.3063034415245, 88.05633053183556, 51.187585294246674, 10.43822418898344, 0.35590261803008616, 0.1162313247914426, 0.03324969278764911, 0.02242591421236284, 0.020017201568407472, 0.07424581170198508, 0.9410103026311845, 11.487000212073326, 26.322893723845482, 36.8239114433527, 46.197461262345314, 64.6847802400589, 71.384656727314, 33.16625811159611, 28.55208020657301, 28.09052847325802, 37.91978023946285, 62.75886118412018, 67.16663226485252, 78.732048869133, 88.61696004867554, 79.30147111415863, 22.00080994516611, 1.727835803758353, 0.2527747268322855, 0.07346061203861609, 0.1927322635310702, 0.1633580436464399, 0.24553014838602394, 0.03406479358091019, 0.018897740446846, 0.08043491514399648, 0.04165204016317148, 0.048528869592701085, 0.10131257571629249, 0.03412858488445636, 0.054343173615052365, 0.018126645300071687, 0.17794287821743637, 0.03729109877895098, 0.02379096684308024, 0.07914786780020222, 0.04195348941721022, 0.08001519352546893, 0.019423746889515314, 0.04689082721597515, 0.04025740738143213, 0.10784636222524568, 0.011643331326922635, 0.05601033044513315, 0.06903038374730386, 0.04782820426044054, 0.016827899853524286, 0.0390877863537753, 0.04930587594571989, 0.018816300871549174, 0.05132322257850319, 0.04128222797589842, 0.04128911139559932, 0.055536227955599315, 0.030684273806400597, 0.022072603678680025, 0.1165550273435656, 0.05588094070844818, 0.03455622892943211, 0.007160729210227146, 0.02137949526513694, 0.07618634233949706, 0.02767561083601322, 0.046635955150122754, 0.054874799971003085, 0.02631081239087507, 0.04984267878171522, 0.056751543015707284, 0.043218524660915136, 0.05093347259389702, 0.0625805341405794, 0.10414239965029992, 0.045059715121169575, 0.09365480655105785, 0.00740727345146297, 0.10080541425850242, 0.08879609187715687, 0.10967260954203084, 0.21978039963869378, 0.13180775771616027, 21.950073167681694, 131.75867468118668, 116.76301494240761, 119.36138391494751, 98.15424308180809, 91.79466113448143, 56.89038008451462, 42.612596824765205, 37.023970708251, 44.28021714091301, 53.10884200036526, 49.517054334282875, 37.06577226519585, 33.072992116212845, 7.497538710013032, 0.1525791798485443, 0.25040941312909126, 0.22019166819518432, 0.3845751966582611, 0.3888498485321179, 0.9513119654729962, 1.047106368932873, 2.638052855618298, 16.780370771884918, 45.63216559588909, 80.29112040996552, 103.88059660792351, 112.33125194907188, 108.02127242088318, 107.34072133898735, 103.96442770957947, 99.20190006494522, 98.97586539387703, 100.73875799775124, 95.38904026150703, 105.48976466059685, 107.0203073322773, 98.83090317249298, 98.75084146857262, 103.55465769767761, 100.10230734944344, 91.44770935177803, 81.98576867580414, 78.66226181387901, 78.50518584251404, 94.47449013590813, 104.67989891767502, 102.87362784147263, 103.90414014458656, 104.37255620956421, 107.00592890381813, 104.78171825408936, 107.24131107330322, 97.64735788106918, 115.0026986002922, 62.75061942636967, 80.0064092874527, 92.5541415810585, 99.25980895757675, 72.1453607082367, 45.71396380662918, 108.42182412743568, 104.785016477108, 104.12854090332985, 95.23246586322784, 92.9524590075016, 103.26164022088051, 100.83346411585808, 95.97193658351898, 96.16171360015869, 93.51283773779869, 88.76626163721085, 93.08150008320808, 105.79934164881706, 110.8812041580677, 105.46584114432335, 105.53666934370995, 96.35478124022484, 85.77095076441765, 83.64757910370827, 97.91442275047302, 99.88818123936653, 92.97664850950241, 89.40340384840965, 92.22092986106873, 99.47758287191391, 102.67642602324486, 92.13084429502487, 57.53528147935867, 14.037805236876011, 1.4875692338682711, 0.24705346586415544, 0.19257644220488146, 0.007957850084494567, 0.0400466077553574, 0.2083920396398753, 0.6910988409072161, 14.739349242299795, 33.616366758942604, 38.79173085093498, 39.34564232826233, 55.582900643348694, 54.06625382602215, 27.44536679238081, 30.240453109145164, 35.579827800393105, 54.66663680970669, 68.10882970690727, 79.20928046107292, 88.54806214570999, 100.89185178279877, 89.1861543059349, 27.385542802512646, 1.5165980136953294, 0.17585741356015205, 0.05299047217704356, 0.20192750293063, 0.12603853916516528, 0.15161198331043124, 0.03704724760609679, 0.06004369897709694, 0.036806780626648106, 0.11606158819631673, 0.032002595253288746, 0.05365515447920188, 0.029061167151667178, 0.0255037212264142, 0.07534162985393777, 0.10208397885435261, 0.09044748920132406, 0.05520856233488303, 0.07514763987273909, 0.01925595657667145, 0.016616534339846112, 0.026394138876639772, 0.04274773586075753, 0.034775607782648876, 0.06366970264934935, 0.0203180348398746, 0.040200859439210035, 0.10204036283539608, 0.04003594680398237, 0.04240750567987561, 0.036372627946548164, 0.015660071112506557, 0.025224660712410696, 0.040996404641191475, 0.19489223981508985, 0.06718317075865343, 0.16961137996986508, 0.22812123410403728, 0.10397539415862411, 0.2428220069850795, 0.23716728697763756, 0.1597574696643278, 0.15947586914990097, 0.09151493504759856, 0.20842583704506978, 0.3042239957721904, 0.19667315675178543, 0.10893406128161587, 0.1499416760634631, 0.18036570836557075, 0.198583415185567, 0.10435899544972926, 0.13761338603217155, 0.22187666996615008, 0.25891754252370447, 0.11993939886451699, 0.3874931432073936, 0.16147373069543391, 0.1432159627438523, 0.1376833557151258, 0.19368739274796098, 0.3873440605821088, 0.2129126837826334, 37.38337442278862, 160.54372608661652, 124.31812673807144, 137.86409586668015, 107.00760081410408, 101.2551274895668, 50.652828589081764, 47.89918094873428, 58.380291536450386, 105.89559808373451, 92.20108732581139, 63.04722011089325, 49.46163810789585, 42.23643220961094, 11.464321129024029, 0.6714158970862627, 0.3721912455512211, 0.3767788759432733, 0.7814281282480806, 0.41216498182620853, 0.46966450579930097, 1.9541989197023213, 10.678457748144865, 23.070961721241474, 44.66333158314228, 79.37070339918137, 106.46855413913727, 118.91939163208008, 112.16676637530327, 110.75424537062645, 109.17688921093941, 101.81599259376526, 102.82244458794594, 102.41044789552689, 100.00734284520149, 110.72164312005043, 110.49901306629181, 102.57432550191879, 102.77219608426094, 106.0346782207489, 104.68329593539238, 95.19912645220757, 83.67708072066307, 82.2512224316597, 79.753358066082, 97.81474649906158, 107.14329913258553, 109.50424164533615, 108.20125356316566, 106.58767774701118, 112.1378043293953, 107.34108611941338, 112.86510050296783, 105.1882204413414, 119.70284879207611, 68.41911345720291, 89.54959720373154, 101.11943677067757, 106.71433255076408, 82.14570969343185, 53.521203473210335, 109.88092303276062, 109.57047209143639, 106.6656343638897, 99.06031206250191, 97.6040630042553, 110.48663333058357, 105.34553959965706, 101.31744414567947, 99.65209990739822, 98.25208783149719, 95.3927032649517, 100.18730118870735, 111.25751316547394, 118.1148000061512, 106.32740691304207, 107.87498027086258, 99.24151673913002, 86.6309130191803, 89.929880797863, 105.3259326517582, 103.4508852660656, 96.29479765892029, 93.79250273108482, 98.38520228862762, 106.9393564760685, 107.5825783610344, 94.24632757902145, 58.197236359119415, 16.004636697471142, 2.160081728361547, 0.3687724383780733, 0.1613501482643187, 0.08471355977235362, 0.20328315440565348, 0.5114238790702075, 1.5676971967332065, 23.87167565524578, 50.110027715563774, 56.305557265877724, 68.00885707139969, 90.66101476550102, 97.332324385643, 48.919939175248146, 42.581347301602364, 45.46483777463436, 56.6317355632782, 81.63440153002739, 89.48648259043694, 101.01868897676468, 102.75239154696465, 105.99350363016129, 42.64568164944649, 2.9834448220208287, 0.4049758269684389, 0.15443898708326742, 0.3505278658121824, 0.22735824692063034, 0.29747689375653863, 0.12141786093707196, 0.15174754400504753, 0.1402642484754324, 0.17287487047724426, 0.15891593357082456, 0.14022123359609395, 0.1753225625725463, 0.18637238448718563, 0.08683406122145243, 0.23513111576903611, 0.16861184063600376, 0.2108012736425735, 0.17447461432311684, 0.11017047188943252, 0.21033848519437015, 0.17848721385234967, 0.16070369310909882, 0.1773567745112814, 0.16624407784547657, 0.1302459673024714, 0.10470004941453226, 0.19985585706308484, 0.1170815662771929, 0.17106343642808497, 0.14334269188111648, 0.23317997984122485, 0.1864425916573964, 0.1652229271712713], [0.03062189443880925, 0.0344426506489981, 0.022906009544385597, 0.035079943991149776, 0.041094442349276505, 0.05365530290873721, 0.04034854311612435, 0.05711515084840357, 0.011274058124399744, 0.00807868749689078, 0.0032923934486461803, 0.04100603771803435, 0.12293524865526706, 0.00808051318017533, 0.06831329839769751, 0.030366194878297392, 0.02354727894271491, 0.040943994172266684, 0.06472012362792157, 0.02235265124909347, 0.03716956096468493, 0.039993399477680214, 0.021964867955830414, 0.008207620812754612, 0.06515756031149067, 0.08029859003727324, 0.0925162406929303, 0.5141643632669002, 18.519030176103115, 136.23180985450745, 105.59964716434479, 105.42435497045517, 79.92041990160942, 59.45463068783283, 27.01501328498125, 24.55816201865673, 22.749229185283184, 72.40848138928413, 65.70247203111649, 40.911416709423065, 30.741629116237164, 26.098215579986572, 3.1311599956825376, 0.3408108075382188, 0.04891127973678522, 0.0224261888070032, 0.4748752136947587, 0.04020437721919734, 0.3590221022022888, 0.8316594734787941, 8.879663720726967, 37.177136689424515, 87.07754105329514, 108.30351367592812, 101.57243326306343, 98.84778186678886, 98.20026621222496, 98.12384471297264, 94.73008722066879, 94.08127963542938, 90.6552466750145, 87.77171060442924, 85.43780744075775, 87.53535568714142, 93.58215361833572, 103.15066337585449, 97.84667998552322, 98.09050530195236, 96.74728497862816, 95.36580830812454, 82.52239108085632, 73.14975321292877, 72.85218358039856, 80.29357507824898, 94.82474014163017, 96.50339126586914, 97.83292472362518, 97.73797541856766, 100.14762371778488, 106.25938296318054, 103.69496136903763, 88.38365256786346, 86.3031730055809, 97.35033541917801, 92.22964659333229, 44.629703387618065, 78.11506077647209, 87.90018171072006, 41.21666193008423, 76.48362591862679, 100.65408334136009, 99.48714315891266, 98.33634451031685, 99.15654569864273, 90.01570299267769, 88.82239982485771, 93.7062169611454, 89.51066449284554, 92.10986942052841, 88.0199208855629, 80.08570343255997, 83.56063976883888, 95.98956763744354, 100.15744239091873, 100.43918967247009, 92.9871815443039, 91.50287479162216, 89.34681728482246, 92.68673926591873, 96.97904214262962, 95.93046560883522, 100.9023468196392, 101.84940800070763, 94.48896735906601, 90.13017565011978, 97.83125281333923, 97.19192191958427, 67.40596622228622, 31.145948320627213, 4.899011570960283, 0.4762196884257719, 0.018016247122432105, 0.07420025125611573, 0.019948280169046484, 0.01114568513003178, 0.02478063561284216, 0.17944379767868668, 5.532963378354907, 20.46182792633772, 30.50471182912588, 41.380410343408585, 45.33103555440903, 66.76920399069786, 53.5555612295866, 25.393408499658108, 12.908076457679272, 42.21807919442654, 57.887370586395264, 68.92146930098534, 73.61421748995781, 75.41032031178474, 87.07955494523048, 53.42183120548725, 6.016440410166979, 0.19672697730129585, 0.1651189968106337, 0.06792893269448541, 0.0808938592672348, 0.023814275846234523, 0.06259536967263557, 0.06130324603873305, 0.023319211395573802, 0.07443597220117226, 0.1099156257987488, 0.03433745492657181, 0.048381453088950366, 0.04794694046722725, 0.14696947851916775, 0.027000017107638996, 0.04026458023872692, 0.046817536422167905, 0.06644270033575594, 0.08524037330062129, 0.01945644962688675, 0.025332804616482463, 0.021770941057184245, 0.06514734835946001, 0.01589283830981003, 0.04119735225685872, 0.05927950951445382, 0.03485884335532319, 0.05142238092957996, 0.04410511282912921, 0.011270854829490418, 0.038433490408351645, 0.03754951831069775, 0.02816686621372355, 0.09903345504426397, 0.0935288863547612, 0.051006781941396184, 0.024315895316249225, 0.031891647886368446, 0.04944414547935594, 0.016691866039764136, 0.06111726754170377, 0.08366880138055421, 0.06639503219048493, 0.057656428834889084, 0.07058539835270494, 0.13135029788827524, 0.055372272690874524, 0.02941065376944607, 0.020525743420876097, 0.025543613519403152, 0.04295872102375142, 0.05950567530817352, 0.009359038813272491, 0.03810603258898482, 0.07223277323646471, 0.0503375317202881, 0.10256113528157584, 0.0945849328127224, 0.09401367948157713, 0.49669655214529485, 22.67500016838312, 154.10509318113327, 116.77858650684357, 117.36264556646347, 101.84022009372711, 69.4199113547802, 53.471209555864334, 37.89146035909653, 18.050524815917015, 48.14782440662384, 49.9356284737587, 46.58396892249584, 34.76824834942818, 35.03039628267288, 5.071326624602079, 0.1992712970240973, 0.065093037992483, 0.16588645172305405, 0.6837581691797823, 0.23828215606044978, 0.9098777419421822, 1.4747072802856565, 9.659507274627686, 43.3301617205143, 92.46128976345062, 114.893097281456, 105.62148839235306, 102.80573308467865, 102.166668176651, 102.15266212821007, 97.99614876508713, 96.59951090812683, 93.4385897219181, 93.52942004799843, 89.62658867239952, 93.18794757127762, 95.9176678955555, 105.4760929942131, 101.62638276815414, 102.26765155792236, 100.07644593715668, 100.36174222826958, 86.33886069059372, 78.61258327960968, 75.52371382713318, 86.16213977336884, 98.27355667948723, 99.65974509716034, 101.69833570718765, 101.06345817446709, 103.7517911195755, 109.89449590444565, 105.70054695010185, 95.7238706946373, 89.87986028194427, 100.73433503508568, 95.74275568127632, 53.28039139509201, 83.65863651037216, 98.54460373520851, 50.18859229981899, 80.18516689538956, 102.64342099428177, 101.93304911255836, 105.03936722874641, 104.70047101378441, 95.08129477500916, 91.41915768384933, 101.25124409794807, 95.40350988507271, 100.14889284968376, 91.92605808377266, 85.23889571428299, 87.42757067084312, 99.77789595723152, 102.97217935323715, 104.14172619581223, 98.84338170289993, 95.98914206027985, 94.09505769610405, 96.71846732497215, 100.76152637600899, 100.03714084625244, 106.69794023036957, 108.71243253350258, 100.30625000596046, 92.93910652399063, 100.87261721491814, 103.32568198442459, 73.95741507411003, 35.659019351005554, 6.745247477665544, 1.3894127821549773, 0.37350805301684886, 0.4502199398120865, 0.08487539991619997, 0.0608452370215673, 0.034807130505214445, 0.13499133376171812, 7.129934560507536, 25.628779269754887, 36.402814239263535, 35.069328993558884, 46.826384514570236, 45.83310641348362, 30.073968842625618, 31.688029132783413, 25.13039231300354, 55.050040036439896, 69.41238015890121, 80.14059528708458, 80.20846724510193, 87.66989126801491, 100.53683683276176, 63.657915741205215, 7.224772246554494, 0.33188069297466427, 0.14349490636959672, 0.06029452633811161, 0.08773865018156357, 0.10031961923232302, 0.03532160211761948, 0.04594690071826335, 0.05822633145726286, 0.02360882153880084, 0.02503392875951249, 0.009821187159104738, 0.04561995869153179, 0.020343425567261875, 0.06040535867214203, 0.09254211938241497, 0.02849252432497451, 0.04505428260017652, 0.05676432279869914, 0.059082970255985856, 0.03150484793877695, 0.04105356856598519, 0.021344636588764843, 0.0634199551132042, 0.027034905469918158, 0.043786297319456935, 0.07137692111427896, 0.043527439920580946, 0.03607236241805367, 0.018469803253537975, 0.05089463971671648, 0.05212796670093667, 0.050035154781653546, 0.21146056795259938, 0.18957987253088504, 0.20922416530083865, 0.11949203966651112, 0.14839627227047458, 0.1257207218441181, 0.08704246371053159, 0.18030332343187183, 0.19126800616504624, 0.14061365160159767, 0.12529964209534228, 0.13622003345517442, 0.305074704810977, 0.31162558298092335, 0.15863654465647414, 0.09781821790966205, 0.1255892578046769, 0.13708134036278352, 0.16795184870716184, 0.24904472229536623, 0.09480506865656935, 0.08072939934208989, 0.32363053411245346, 0.12712810101220384, 0.20631999301258475, 0.1954028819454834, 0.21494555985555053, 0.5472304858267307, 39.63636472821236, 183.85394006967545, 128.99357825517654, 138.00353318452835, 107.12345659732819, 90.32581955194473, 44.0284426510334, 36.96132726967335, 40.69032937288284, 103.611069470644, 98.79443272948265, 66.82049363851547, 53.281500935554504, 46.122343093156815, 8.101152945309877, 0.5626409151591361, 0.11023638944607228, 0.38002906716428697, 0.8003698743414134, 0.3459962230408564, 1.1965137580409646, 5.4384999722242355, 15.263552963733673, 43.04587997496128, 91.20135337114334, 119.15329948067665, 110.3579494357109, 107.17831805348396, 105.37992775440216, 105.3311687707901, 103.00352767109871, 100.43493390083313, 96.71722859144211, 96.68993845582008, 94.37607541680336, 97.739297747612, 102.4460443854332, 111.66767835617065, 105.59366628527641, 104.62138205766678, 104.60799917578697, 103.98757606744766, 90.6222340464592, 79.48025152087212, 79.30160790681839, 91.05841264128685, 103.76829743385315, 105.74312746524811, 105.80379500985146, 106.69129818677902, 109.30170491337776, 115.42204409837723, 113.26997637748718, 100.89051425457001, 94.09973904490471, 109.40078839659691, 99.04405653476715, 61.62279814481735, 92.28245615959167, 109.08760160207748, 61.79789274930954, 81.0605563223362, 107.41469576954842, 102.84159556031227, 111.18127405643463, 109.13446828722954, 101.69540986418724, 96.18982449173927, 106.67719334363937, 98.05978775024414, 102.99619406461716, 96.86358913779259, 89.42506268620491, 92.55325242877007, 103.58019232749939, 106.60447284579277, 109.44424286484718, 102.79770791530609, 102.12160259485245, 97.18538627028465, 102.09548279643059, 105.04659444093704, 104.62667137384415, 112.14857295155525, 115.59829384088516, 106.13386049866676, 96.8112887442112, 106.35417267680168, 107.19756782054901, 76.45306035876274, 37.431742027401924, 7.835272187367082, 2.4906231416389346, 1.270708458032459, 0.4405922658042982, 0.14853643428068608, 0.07572944654384628, 0.24739274609601125, 0.5029672547243536, 10.598587933927774, 37.81925283372402, 51.01915933191776, 58.89396697282791, 64.14637953042984, 87.73460939526558, 72.55582988262177, 38.312131986021996, 22.264570891857147, 61.0368087887764, 82.20759317278862, 92.799471616745, 95.58511734008789, 95.87451741099358, 112.39681363105774, 80.85311785340309, 11.278610844165087, 0.5403206159826368, 0.31651740486267954, 0.18993286765180528, 0.20600207179086283, 0.179384678194765, 0.0906565150944516, 0.16315367101924494, 0.10880363624892198, 0.13679144263733178, 0.23037019389448687, 0.08094199496554211, 0.19703361787833273, 0.15781569964019582, 0.33262233599089086, 0.18181249557528645, 0.10731712929555215, 0.18666796706384048, 0.14955829741666093, 0.11663183220662177, 0.12366297640255652, 0.1666757554630749, 0.09825679750065319, 0.18290866253664717, 0.11116513531305827, 0.1589968425105326, 0.16118098312290385, 0.19710642256541178, 0.18018241273239255, 0.16002363350708038, 0.12658903462579474, 0.08545852018869482, 0.20597741764504462], [0.05494609067682177, 0.0422655105649028, 0.07455599232343957, 0.041632929860497825, 0.025581305344530847, 0.0645786257518921, 0.03969716381106991, 0.05968219513306394, 0.11211497301701456, 0.044955447083339095, 0.03304858932096977, 0.04605187008564826, 0.047484059250564314, 0.009598974229447776, 0.0337347827735357, 0.045116129476809874, 0.04665433814807329, 0.04281475179595873, 0.06315667080343701, 0.05880543300008867, 0.02866514045308577, 0.05462175358843524, 0.07465097238309681, 0.08849067584378645, 0.045016510994173586, 0.11717245710315183, 0.13558157865190879, 13.562243655323982, 117.24886447191238, 107.15615764260292, 106.41449823975563, 87.74005070328712, 54.4394887983799, 33.86055305600166, 32.687966376543045, 47.763395234942436, 86.36545166373253, 66.64004892110825, 51.49889878928661, 29.823685772717, 25.540766492486, 1.8140985374338925, 0.5565490107983351, 0.051080974444630556, 0.14661226799944416, 0.14344215451274067, 0.04268346958269831, 0.39125431794673204, 1.1006245971657336, 18.358714878559113, 65.15836402773857, 94.92412000894547, 107.86980494856834, 92.14147612452507, 97.43233501911163, 96.24020978808403, 98.70809376239777, 91.63577646017075, 86.84253886342049, 85.11605590581894, 87.83627673983574, 92.18699008226395, 96.70979619026184, 86.25999212265015, 90.02851590514183, 90.6478750705719, 99.26704376935959, 93.47672447562218, 93.9012984931469, 90.72057276964188, 79.51245859265327, 71.4040432870388, 76.81524932384491, 86.23583301901817, 93.5526292026043, 90.19698366522789, 94.49605017900467, 87.91720479726791, 92.55747020244598, 88.21668192744255, 92.03829646110535, 75.97153499722481, 84.64115738868713, 89.00323212146759, 105.66631838679314, 66.72099217772484, 49.912259727716446, 65.43541476130486, 56.81297443807125, 107.12936148047447, 92.34934017062187, 102.84733325242996, 100.40818333625793, 101.80643990635872, 86.679877191782, 77.5766372680664, 87.69913449883461, 91.0342763364315, 92.73196443915367, 86.07119545340538, 79.50006365776062, 83.4764438867569, 88.8003458082676, 95.5039156973362, 98.1337621808052, 94.39576596021652, 90.78722879290581, 88.15384089946747, 93.79277631640434, 98.4656211733818, 90.77256917953491, 97.92504698038101, 97.78402134776115, 97.79604390263557, 94.81320396065712, 97.62219563126564, 102.4095131456852, 85.29304280877113, 46.79561376571655, 17.016246914863586, 1.8439429672434926, 1.608900404535234, 0.4830107552697882, 0.10563223884673789, 0.1234530376677867, 0.07974514082889073, 0.3335894731571898, 0.1088735242956318, 2.4589440040290356, 16.541093811392784, 31.665792725980282, 33.970883935689926, 83.31612288951874, 151.24361872673035, 48.08838799595833, 35.15830501914024, 17.438957132399082, 28.294539526104927, 41.661086082458496, 55.1175282150507, 78.01897153258324, 72.99175009131432, 89.73267897963524, 70.09202688932419, 8.132538311183453, 0.31556790112517774, 0.1665241495356895, 0.023032720127957873, 0.04956129349011462, 0.02277311315992847, 0.051271561678731814, 0.023413382514263503, 0.037997044491930865, 0.05918346818361897, 0.02915250512160128, 0.017621782644710038, 0.047440198322874494, 0.09329777414677665, 0.029617000509460922, 0.057594804602558725, 0.06224549899343401, 0.03651959174021613, 0.029223703058960382, 0.039798266589059494, 0.023594806079927366, 0.04891472330200486, 0.07338691677432507, 0.015107253657333786, 0.05061418210971169, 0.05037718467065133, 0.03656573848275002, 0.05847589716722723, 0.013328581717360066, 0.034659495067899115, 0.06272307102335617, 0.041205330344382674, 0.04330286603362765, 0.01940453083079774, 0.034188758218078874, 0.029468262982845772, 0.0751287819002755, 0.04162284778431058, 0.0023579358276037965, 0.01229426534337108, 0.06222331248864066, 0.05365194840123877, 0.01835313392803073, 0.04483153439650778, 0.03212800336768851, 0.03656571621831972, 0.08936131896916777, 0.09494565369095653, 0.05295204377034679, 0.01856109854998067, 0.03249137371312827, 0.07470765020116232, 0.06553790357429534, 0.04829186844290234, 0.03266506224463228, 0.04956806558766402, 0.07389188147499226, 0.11674137320369482, 0.1278099714545533, 17.82270234078169, 139.6120324730873, 119.61843252182007, 125.28379932045937, 99.878810942173, 79.22133341431618, 67.90786609053612, 38.01352120935917, 29.263835214078426, 45.0843869894743, 44.434276074171066, 48.041711300611496, 37.72832751274109, 37.06046774983406, 3.650145409628749, 0.4832347057526931, 0.2234322263393551, 0.1578469737432897, 0.39959430636372417, 0.40238534566015005, 0.807101153768599, 0.8454620547126979, 18.03149923682213, 72.70022973418236, 101.05419427156448, 110.96542283892632, 98.89530971646309, 104.71883922815323, 100.90178444981575, 100.70797964930534, 94.70173314213753, 90.70521399378777, 89.12335887551308, 93.15746560692787, 96.31571933627129, 102.32271820306778, 91.0249288380146, 94.50900748372078, 96.39672338962555, 103.1285409629345, 96.12689226865768, 99.3762955069542, 94.5147755742073, 82.94277012348175, 73.12253907322884, 77.38276407122612, 89.3164037168026, 94.66079413890839, 92.16014072299004, 95.59758067131042, 90.0129747390747, 97.34890669584274, 93.5961140692234, 95.12965098023415, 76.36646300554276, 89.2820155620575, 93.41898277401924, 109.37216073274612, 74.65350732207298, 57.27398470044136, 72.30673804879189, 64.0765392780304, 110.32319650053978, 96.09625831246376, 106.09087720513344, 103.02593886852264, 105.3252562880516, 89.73947301506996, 80.17967239022255, 90.41688546538353, 95.36906853318214, 96.83894366025925, 92.1495620906353, 85.52555233240128, 88.88469368219376, 93.52486029267311, 99.47317510843277, 102.51015454530716, 99.79558020830154, 98.05542558431625, 91.41425594687462, 97.43412852287292, 100.71383893489838, 94.5144335925579, 97.15802773833275, 97.92703047394753, 99.56003844738007, 102.90680766105652, 99.91708248853683, 102.59515598416328, 89.14129391312599, 52.665683180093765, 19.9102571234107, 3.8558637583628297, 2.25835585501045, 2.7327953092753887, 0.8051554206758738, 0.5397336662281305, 0.09397582995006815, 0.1519824337447062, 0.09101575167733245, 2.723745619878173, 19.884099327027798, 36.236721351742744, 30.582039579749107, 66.74490049481392, 133.8671663403511, 35.097439885139465, 28.04798975586891, 30.227531902492046, 45.04354678094387, 50.010229870676994, 61.818727031350136, 87.6696328818798, 80.81231564283371, 102.77046337723732, 85.53410947322845, 12.070008628070354, 0.1727744282106869, 0.06910531097673811, 0.03133275131403934, 0.12258243907126598, 0.019538217602530494, 0.0521056057914393, 0.026507032525842078, 0.05668354373483453, 0.07668381877010688, 0.028376868031045888, 0.04795462911715731, 0.03552841269993223, 0.02364726478845114, 0.017084369392250665, 0.022395231972041074, 0.02624817698233528, 0.05211854884692002, 0.033734456228557974, 0.007137515294743935, 0.08933979668654501, 0.03966901786043309, 0.03796957760641817, 0.05772219425125513, 0.017624693718971685, 0.04727587569504976, 0.04689764384238515, 0.09686109973699786, 0.053068445922690444, 0.0276701708935434, 0.09485085916821845, 0.043878041615244, 0.20601379772415385, 0.086643114045728, 0.316689761239104, 0.12676838203333318, 0.2133809047518298, 0.17352226073853672, 0.08609317519585602, 0.1636941623291932, 0.22687038872390985, 0.1514535941532813, 0.16580088209593669, 0.1376399103901349, 0.08770133499638177, 0.14331447542645037, 0.20820611680392176, 0.2589717786759138, 0.1704933779546991, 0.09527665897621773, 0.1659656091942452, 0.1609291130444035, 0.14723547908943146, 0.2451710231252946, 0.14983467321144417, 0.2135670799179934, 0.3153600700898096, 0.23754095833282918, 0.5436316039413214, 30.283535197377205, 169.0300539135933, 127.69447356462479, 138.19347739219666, 111.28420293331146, 83.97821456193924, 55.926964581012726, 50.59613563120365, 71.0531397163868, 120.5562449991703, 98.73623505234718, 78.9617845416069, 53.38835120201111, 48.14038060605526, 4.20940320007503, 0.769051598617807, 0.3128973866114393, 0.5653676250949502, 0.3747817862313241, 0.4495014518033713, 1.3609236921183765, 4.9586522206664085, 27.926534973084927, 72.69763827323914, 100.95745906233788, 117.14319974184036, 100.6620629131794, 109.34933915734291, 105.23542150855064, 105.34208178520203, 98.845494389534, 96.75382062792778, 94.07774582505226, 96.51497304439545, 99.02734503149986, 105.58986648917198, 95.6042531132698, 99.4316965341568, 102.03577280044556, 107.8683078289032, 100.81372037529945, 103.32943618297577, 100.34657344222069, 87.19718903303146, 79.24066677689552, 82.83314600586891, 94.04929295182228, 100.68591803312302, 98.00766214728355, 102.97765865921974, 96.5510331094265, 101.08629494905472, 97.90775790810585, 98.78550320863724, 82.44736790657043, 92.20965206623077, 98.75636637210846, 116.7625741660595, 78.85440990328789, 63.13356667757034, 80.90867847204208, 69.53329727053642, 112.99288764595985, 102.92028173804283, 111.39456421136856, 105.94997316598892, 109.61243703961372, 95.17494454979897, 83.83466586470604, 96.5313121676445, 97.91722699999809, 101.307093501091, 97.61944457888603, 92.35302597284317, 95.93733564019203, 99.01567205786705, 107.01824024319649, 107.28543430566788, 104.66922909021378, 101.22432634234428, 94.27704513072968, 104.786726385355, 105.51780715584755, 97.11758270859718, 99.77680161595345, 100.53286984562874, 104.72140029072762, 107.77040988206863, 106.81123495101929, 108.78915801644325, 91.72473728656769, 55.32510727643967, 20.693381801247597, 6.633561495691538, 5.609419550746679, 3.8530880073085427, 1.1696997843682766, 0.501788902329281, 0.17857705825008452, 0.45167968492023647, 0.33937976870220155, 5.961347166448832, 30.427566468715668, 52.753397673368454, 55.133468359708786, 102.21819341182709, 171.49291455745697, 66.42184183001518, 51.14903636276722, 29.92748860269785, 43.444896563887596, 60.35984471440315, 76.92734330892563, 103.57945516705513, 94.06585246324539, 109.81442660093307, 101.32399499416351, 18.955446258187294, 0.436608120216988, 0.22151502140332013, 0.21107616514200345, 0.2243451718823053, 0.17651955771725625, 0.15713301283540204, 0.17453204171033576, 0.11048932821722701, 0.20584999088896438, 0.11621727593592368, 0.10726527543738484, 0.21057288511656225, 0.18414778198348358, 0.17106820101616904, 0.25348754483275115, 0.15981936478056014, 0.10111939467606135, 0.15658417978556827, 0.09556932491250336, 0.10742105223471299, 0.22843263926915824, 0.10418145888252184, 0.19755557033931836, 0.08485115395160392, 0.1710635403287597, 0.20323017990449443, 0.2028545195935294, 0.10846282719285227, 0.11145016454975121, 0.23997374810278416, 0.1417635500547476], [0.01173513128378545, 0.05301867378875613, 0.02448870069201803, 0.02716831393627217, 0.028447787663026247, 0.06121626262029167, 0.015962416509864852, 0.04228500307362992, 0.023375757482426707, 0.013630843623104738, 0.04446318052941933, 0.09406936282175593, 0.04287172276235651, 0.026868951972573996, 0.011084670386480866, 0.02609972518257564, 0.027499521456775256, 0.028644970734603703, 0.011503118294058368, 0.020112576821702532, 0.08208752959035337, 0.013257412538223434, 0.022892491324455477, 0.16342295188223943, 0.07793471610057168, 0.2243086730595678, 4.749615462496877, 113.96379634737968, 108.73874232172966, 114.57519114017487, 86.18652686476707, 64.04820039868355, 30.89067231863737, 12.663105502724648, 50.48765525221825, 80.79473778605461, 46.99815809726715, 52.88252614438534, 32.04841889441013, 20.205573476850986, 0.9270547202322632, 0.1733686658553779, 0.04816659762582276, 0.06344725130475126, 0.05607864884950686, 0.12747891421895474, 0.7062462531030178, 0.58532569790259, 13.725660536438227, 82.18215733766556, 102.04094812273979, 106.91990152001381, 99.59973111748695, 102.67947345972061, 96.68046176433563, 94.69325199723244, 85.03580421209335, 85.286925137043, 87.69979566335678, 94.87283036112785, 96.24195009469986, 98.99353444576263, 91.90713509917259, 93.34934771060944, 88.37540701031685, 88.21662873029709, 92.6876512169838, 98.48221868276596, 94.68615397810936, 87.09701880812645, 71.94872125983238, 69.18904334306717, 69.96446773409843, 85.55788099765778, 86.34245529770851, 87.72564187645912, 78.34472045302391, 76.20326936244965, 71.23298406600952, 74.35794398188591, 75.30820459127426, 79.30051356554031, 74.76862594485283, 84.74955797195435, 86.57953977584839, 103.86633977293968, 39.595725908875465, 33.55006791651249, 99.02009502053261, 88.70712161064148, 92.00615778565407, 86.08987525105476, 89.88686710596085, 80.52579581737518, 73.60324367880821, 71.00234404206276, 83.50330084562302, 89.12643671035767, 89.38341692090034, 84.25160229206085, 78.41396033763885, 78.19736436009407, 79.18278068304062, 82.9638209939003, 94.20788884162903, 87.82173871994019, 86.69819220900536, 91.01280748844147, 95.93143835663795, 84.55130741000175, 88.5403561592102, 90.4259441792965, 90.57010844349861, 90.90892106294632, 91.39193594455719, 91.36900797486305, 94.08490464091301, 90.71391552686691, 65.37387326359749, 31.909365355968475, 7.879878468811512, 1.1040809866972268, 1.2147895898669958, 0.8050258120056242, 0.19032133743166924, 0.06702461832901463, 0.09409818783751689, 0.061377271558740176, 0.03128665281110443, 0.43072867789305747, 15.374313220381737, 28.44272207468748, 58.69379751384258, 35.876116901636124, 44.26859736442566, 51.86655566096306, 22.417326495051384, 18.89254443347454, 17.806781195104122, 41.35733798146248, 52.406145706772804, 71.8897408246994, 79.2016276717186, 81.42879456281662, 80.47959789633751, 25.14082845300436, 0.4835966363316402, 0.03496472185361199, 0.020978238280804362, 0.006194173238327494, 0.020984830407542177, 0.08311239100294188, 0.040344316585105844, 0.06042329638148658, 0.06703435530653223, 0.00038354957268893486, 0.07674132779357024, 0.0164529816902359, 0.03206167762982659, 0.0725762614456471, 0.05144485316122882, 0.014863551841699518, 0.04123062644794118, 0.05719257169403136, 0.015226936102408217, 0.12518334755441174, 0.033469643094576895, 0.0632390269311145, 0.03372237777512055, 0.03240535137592815, 0.01000182961433893, 0.04795913766429294, 0.018512699389248155, 0.06883491689222865, 0.021769313898403198, 0.03491252660751343, 0.04246415752277244, 0.09293153911130503, 0.03934918189770542, 0.07507371454266831, 0.053124355617910624, 0.034018977094092406, 0.011755142368201632, 0.028850916714873165, 0.04544547606201377, 0.03540548335877247, 0.026544006323092617, 0.006960279761187849, 0.03178370250680018, 0.02580696833319962, 0.037561871358775534, 0.051704946235986426, 0.03260292221966665, 0.04706746207375545, 0.08503971141180955, 0.04496391869906802, 0.05746432761952747, 0.11194180769962259, 0.04170662512478884, 0.16460488142911345, 0.06064435619919095, 0.29042286914773285, 6.067205211147666, 139.29433912038803, 120.34354001283646, 131.53655380010605, 100.70500820875168, 95.49126997590065, 53.66331584751606, 31.013189144432545, 39.64419610798359, 60.05965702235699, 56.68733038008213, 44.08455803990364, 47.68348552286625, 26.27493839710951, 1.8400430702604353, 0.369898573262617, 0.4149703000439331, 0.22039862349629402, 0.21387000975664705, 2.0094485487788916, 1.4972582389600575, 0.6284407374914736, 17.121993340551853, 91.09684377908707, 104.27898243069649, 112.44456946849823, 104.95428219437599, 107.07520678639412, 96.81247428059578, 98.50950881838799, 89.01694178581238, 89.81349304318428, 89.73514124751091, 99.00972157716751, 99.75698947906494, 104.49788108468056, 96.25696688890457, 96.21913611888885, 92.01083913445473, 92.06282794475555, 97.77310073375702, 101.39837980270386, 97.65564903616905, 89.76826786994934, 75.3353351354599, 72.77295023202896, 73.70122522115707, 88.7096294760704, 89.66885760426521, 92.03021809458733, 82.32809230685234, 78.51440414786339, 74.46791008114815, 77.45433703064919, 77.05518364906311, 81.77011504769325, 77.14782267808914, 87.48488679528236, 91.61150336265564, 107.79323905706406, 47.637097612023354, 42.5235828012228, 101.4585229754448, 94.87007930874825, 92.45309740304947, 90.66063478589058, 93.25857818126678, 84.55133020877838, 76.19776725769043, 74.6889366209507, 88.23058918118477, 94.95048299431801, 94.1261400282383, 89.67746034264565, 82.02798441052437, 82.04675540328026, 82.51051291823387, 86.82611614465714, 97.50795856118202, 93.39218661189079, 90.75838074088097, 96.51882603764534, 102.17533931136131, 87.12618604302406, 89.30195689201355, 93.4136326611042, 92.34110221266747, 92.1965503692627, 92.0175875723362, 92.41198360919952, 93.4845444560051, 91.66419893503189, 65.5338978767395, 33.24186645448208, 9.53517034649849, 1.1162750073708594, 2.2408340452238917, 2.0118823181837797, 1.0968698048964143, 0.7209249248262495, 0.04333498618507292, 0.08474570960970595, 0.0930639159923885, 0.4547131690196693, 17.935016714036465, 33.31569269299507, 55.106482207775116, 47.40418151021004, 43.30707795917988, 51.825726851820946, 25.990168377757072, 28.804544359445572, 36.81942768394947, 60.470202192664146, 65.57161465287209, 81.30201816558838, 89.41639915108681, 92.39702761173248, 97.20522880554199, 35.330025404691696, 0.5084379517938942, 0.044026875621057115, 0.05395178719481919, 0.03175492944137659, 0.04405926665640436, 0.0581758394400822, 0.013053422117081936, 0.05445677044917829, 0.039345504555967636, 0.02336845289391931, 0.011685124445648398, 0.05912220760365017, 0.08160128927556798, 0.0363564639701508, 0.051773108789348044, 0.04370350703538861, 0.06074408600397874, 0.024740695080254227, 0.0413723766541807, 0.06929623588803224, 0.03894247012794949, 0.06500379473436624, 0.031001790557638742, 0.01891130505100591, 0.0606102396704955, 0.014620679376093904, 0.03274235321441665, 0.023845575924497098, 0.026700265516410582, 0.02291420656547416, 0.09660660987719893, 0.19449073792202398, 0.2361803047824651, 0.11831138661364093, 0.15886224660789594, 0.12860625138273463, 0.10175112562137656, 0.15694458154030144, 0.1882961203227751, 0.13994834589539096, 0.13234321726486087, 0.1371443338575773, 0.21761524316389114, 0.06753926805686206, 0.18197489232989028, 0.12799282179912552, 0.1710924692451954, 0.1848276486271061, 0.1630632477463223, 0.12022212002193555, 0.21384995692642406, 0.26796346181072295, 0.19032700743991882, 0.22979027969995514, 0.24242433457402512, 0.6094530376140028, 10.253392606973648, 168.46206039190292, 134.9415358901024, 149.8976093530655, 115.22219002246857, 92.75132060050964, 50.92664949595928, 24.14537686854601, 78.22022393345833, 119.2125914990902, 70.84809511899948, 84.06739577651024, 58.057365864515305, 38.18557217717171, 2.562983608804643, 0.3462467127246782, 0.47989572398364544, 0.21929960668785498, 0.13180625857785344, 0.6399318552576005, 2.7097661700099707, 3.7315643532201648, 18.763035982847214, 91.88641101121902, 106.29749491810799, 114.14674133062363, 110.911306142807, 110.64356490969658, 103.67226138710976, 102.93410539627075, 94.99233394861221, 93.91393661499023, 95.59033066034317, 104.43196222186089, 103.80085408687592, 107.60506555438042, 101.15862786769867, 102.67334818840027, 97.84260660409927, 97.32686027884483, 103.8282810151577, 104.84625399112701, 100.1997721195221, 94.82135072350502, 79.66135740280151, 77.492935359478, 77.48477339744568, 95.14149874448776, 95.00336855649948, 98.28343614935875, 87.12461292743683, 84.9412652850151, 77.40167185664177, 81.4009116590023, 83.6381784081459, 85.85310995578766, 80.04689231514931, 91.27417266368866, 98.8332362473011, 110.81273183226585, 52.64467790722847, 50.66708542406559, 104.16838556528091, 101.51355162262917, 99.56943154335022, 96.5023273229599, 98.2220846414566, 92.28972136974335, 80.87208643555641, 80.48748627305031, 92.63883143663406, 100.82332625985146, 99.70425590872765, 93.70117843151093, 86.1194072663784, 86.77951544523239, 86.3908039033413, 91.96211814880371, 101.63709059357643, 98.59440386295319, 97.68727853894234, 101.96581855416298, 104.79314804077148, 88.14228191971779, 88.38972464203835, 96.37965470552444, 96.4038822054863, 94.45134937763214, 93.71423453092575, 95.7007223367691, 97.90370732545853, 96.14102751016617, 70.74385911226273, 36.46057493984699, 13.305737469345331, 4.548462331295013, 4.2274536564946175, 3.141267215833068, 1.9690010254271328, 0.6128205475397408, 0.19862219982314855, 0.16323800868121907, 0.22309426713036373, 2.2372636618092656, 24.161510802805424, 50.97964905202389, 81.3051263988018, 41.86021439731121, 63.0335408449173, 74.11186918616295, 32.085706293582916, 30.515706539154053, 31.347945481538773, 61.38887129724026, 71.397864818573, 96.39135047793388, 101.32677644491196, 103.73072504997253, 110.12593388557434, 47.54957690834999, 1.0489332396537066, 0.138873255928047, 0.11381495132809505, 0.10400295752333477, 0.08630315845948644, 0.21230195561656728, 0.10919413951341994, 0.16045036842115223, 0.12390645279083401, 0.06274909814237617, 0.15836518577998504, 0.13584287400590256, 0.1748651175876148, 0.10033214668510482, 0.17892215691972524, 0.08746861974941567, 0.10705939625040628, 0.16230989363975823, 0.16151215910213068, 0.20596345042577013, 0.09950403604307212, 0.2482197806239128, 0.1457157387631014, 0.10520396768697537, 0.19924265012377873, 0.09891199515550397, 0.10419077283586375, 0.1543719563051127, 0.1343014629674144, 0.1257491164142266], [0.01835882620071061, 0.048233921552309766, 0.008558785611967323, 0.004759326720886747, 0.09828236448811367, 0.061123457053327, 0.020116942505410407, 0.016196410106203984, 0.02538284763431875, 0.038700314762536436, 0.015325239128287649, 0.06919166728039272, 0.01672863760177279, 0.00762234923968208, 0.034439273877069354, 0.13553443743148819, 0.026121199225599412, 0.03550778470525984, 0.008910081214708043, 0.046536095469491556, 0.03782750456593931, 0.04802482515515294, 0.047059491407708265, 0.052747767622349784, 0.0482648320030421, 1.4300643070600927, 85.78358128666878, 113.93730416893959, 100.43033614754677, 80.38871437311172, 48.17435458302498, 19.654112868010998, 28.304259404540062, 62.77446694672108, 68.68607193231583, 53.10126140713692, 46.184754744172096, 30.100761204957962, 8.992792200297117, 0.24535411095712334, 0.11757326879887842, 0.160077097825706, 0.11788381307269447, 0.17398003226844594, 2.0086522540077567, 3.6963328812271357, 1.020254041068256, 8.884403966367245, 85.71217551827431, 107.34345719218254, 108.34702894091606, 101.39684468507767, 105.6163738667965, 100.75663983821869, 97.4466298520565, 93.50678846240044, 92.82912522554398, 90.59631183743477, 88.09429049491882, 91.92209869623184, 94.3051940202713, 97.10831120610237, 90.91757699847221, 95.13447672128677, 79.74429175257683, 82.44523242115974, 90.22352144122124, 99.10682156682014, 93.07157501578331, 82.90445297956467, 69.62978169322014, 68.83624747395515, 70.41124016046524, 83.19239392876625, 78.46300050616264, 81.43647015094757, 72.12725088000298, 74.85833153128624, 68.97038027644157, 75.80991446971893, 75.48110291361809, 81.55836760997772, 73.07203218340874, 85.64706981182098, 82.92699337005615, 106.48314535617828, 56.981917172670364, 26.414977982640266, 103.5585030913353, 82.32003673911095, 83.26064586639404, 71.62731170654297, 86.7048342525959, 80.56484252214432, 84.88079532980919, 70.0425535440445, 73.48510801792145, 82.57606700062752, 86.17566704750061, 81.8074518442154, 78.41431751847267, 70.66548451781273, 72.11769819259644, 81.94065749645233, 92.80102953314781, 91.14083021879196, 84.41866412758827, 85.92051073908806, 88.9115734398365, 93.35247874259949, 93.5161055624485, 92.99314722418785, 95.08175075054169, 91.26578271389008, 84.81105387210846, 82.57881045341492, 82.44061946868896, 84.50054213404655, 79.00471463799477, 53.90543505549431, 18.39846834540367, 2.7647767681628466, 1.0492670279927552, 0.43847117805853486, 0.48593870596960187, 0.34190455509815365, 0.03674931242130697, 0.04020953885628842, 0.1231531061057467, 0.08934701036196202, 0.10611662379233167, 15.030896198004484, 18.962673470377922, 40.718645453453064, 33.92916597425938, 41.23379901051521, 48.519357070326805, 25.369899161159992, 14.974905252456665, 10.906086433678865, 27.219237126410007, 55.3568659722805, 64.47361037135124, 70.79440400004387, 75.18194496631622, 95.89667022228241, 25.603174343705177, 0.6439583329483867, 0.035624146039481275, 0.07250443639350124, 0.07592184832901694, 0.028821737323596608, 0.06455075068515725, 0.04135570430662483, 0.033147851572721265, 0.05508371083124075, 0.033934249804588035, 0.037391915830085054, 0.03384552604984492, 0.03281529890955426, 0.05223729618592188, 0.005857226133230142, 0.019502575960359536, 0.05074688553577289, 0.03358938862220384, 0.01760245897457935, 0.029028930111962836, 0.1569229256710969, 0.012127458376198774, 0.04801108800165821, 0.07571440321044065, 0.030254553603299428, 0.032910442241700366, 0.02690665307454765, 0.07471058910596184, 0.01086703743567341, 0.06275015941355377, 0.03501801176753361, 0.09409004647750407, 0.04348797621787526, 0.06335993020911701, 0.09188668424030766, 0.0429397368861828, 0.02060355389403412, 0.044110155722592026, 0.02828450218657963, 0.04028188341180794, 0.010799007541208994, 0.027800781463156454, 0.008305966512125451, 0.06997484830208123, 0.026366575511929113, 0.030566897585231345, 0.05735476435802411, 0.03469436116574798, 0.03452031269262079, 0.04036970545712393, 0.05340241979865823, 0.049220844375668094, 0.05904212986933999, 0.06056922487914562, 2.6055296882987022, 110.5070686340332, 126.51420369744301, 115.02704009413719, 95.44489726424217, 70.44185131788254, 45.59322148561478, 41.34582079946995, 27.41653013974428, 48.80600608885288, 55.704273730516434, 40.09108252823353, 43.498078510165215, 13.468901664018631, 0.313092393334955, 0.14109632960753515, 0.15535791433649138, 0.06671456387266517, 0.6837938516400754, 6.986715495586395, 6.346311634406447, 1.8048740574158728, 13.49711325019598, 93.59906271100044, 109.80683460831642, 109.90072757005692, 107.13626950979233, 108.5821983218193, 104.43562522530556, 100.66552832722664, 99.0824268758297, 96.01422071456909, 94.79659885168076, 95.13712897896767, 96.4700898528099, 99.10265699028969, 100.91189950704575, 96.39909446239471, 99.45335537195206, 84.48940873146057, 89.09740626811981, 94.2622259259224, 104.8525008559227, 98.49411964416504, 86.84087455272675, 71.19887709617615, 72.74716481566429, 73.31368401646614, 85.70996403694153, 83.22367385029793, 86.34026661515236, 75.32965064048767, 76.63230434060097, 72.12248593568802, 79.48237180709839, 78.88538584113121, 83.75086516141891, 77.93211579322815, 89.9680307507515, 86.16020947694778, 108.75310555100441, 62.261745259165764, 28.70837911963463, 106.99763774871826, 86.07087627053261, 85.34214377403259, 76.3526925444603, 90.62347277998924, 85.37424445152283, 89.02285426855087, 72.84151375293732, 76.19984194636345, 86.19266733527184, 91.57717600464821, 87.21439450979233, 82.58800595998764, 77.23128899931908, 75.55142194032669, 84.55358728766441, 95.11087998747826, 95.05224153399467, 89.4547238945961, 91.65713131427765, 92.87410721182823, 95.287304520607, 97.62686178088188, 95.37637174129486, 95.059894323349, 91.39505937695503, 85.66488325595856, 81.61865517497063, 81.40659615397453, 83.40146631002426, 81.01312726736069, 57.2482068836689, 20.438956953585148, 3.931011613458395, 1.080900093074888, 1.1298143933527172, 1.769865823443979, 1.4667161903344095, 0.4265643982216716, 0.07975084052304737, 0.04056799618410878, 0.10752878981293179, 0.2644411101937294, 15.494375377893448, 27.66612734645605, 24.235530830919743, 24.5113580301404, 33.9610006660223, 31.161633878946304, 29.467280097305775, 23.738659992814064, 28.288851231336594, 38.75925399363041, 71.13521531224251, 70.77512383460999, 83.90275061130524, 84.20531317591667, 113.64919602870941, 39.720005840063095, 0.6477291556075215, 0.012555400207929779, 0.1495534140849486, 0.013596140797744738, 0.03548760199919343, 0.036145430567557923, 0.08525697514414787, 0.05210865601839032, 0.04084623105882201, 0.024268878405564465, 0.008135824518831214, 0.015196604526863666, 0.052643774179159664, 0.05421636284154374, 0.024335469461220782, 0.024822368432069197, 0.03688138131110463, 0.018482211962691508, 0.05902019940549508, 0.05552729249757249, 0.1455804452416487, 0.10284883624990471, 0.057624423716333695, 0.08334254584042355, 0.019246714982728008, 0.09006477106595412, 0.029824920602550264, 0.05238233039563056, 0.033997655191342346, 0.20164723828202114, 0.17596977471839637, 0.1381030402262695, 0.117701415438205, 0.16410799871664494, 0.2293540898244828, 0.12989464943530038, 0.08849451274727471, 0.19624275562819093, 0.18953078688355163, 0.11568891874048859, 0.13277240126626566, 0.18056553904898465, 0.10905270843068138, 0.1470890681957826, 0.2668688533594832, 0.11068847612477839, 0.15383652644231915, 0.09207722323480994, 0.09557599682011642, 0.10122942549060099, 0.13488772994605824, 0.15839960658922791, 0.15054265240905806, 0.14583090523956344, 4.813167052343488, 135.0458326935768, 139.34090942144394, 128.55777204036713, 107.06870913505554, 73.15413817763329, 34.29752580821514, 42.974014431238174, 90.63668847084045, 96.88431322574615, 75.8248096704483, 71.66255101561546, 54.14375826716423, 17.911862656474113, 1.436275311280042, 0.282619780045934, 0.4685223108390346, 0.2521808899473399, 0.6324051122646779, 3.577640550211072, 5.972943194210529, 6.01687453687191, 13.345113806426525, 93.23079407215118, 115.53700312972069, 114.3923145532608, 110.70714309811592, 112.92567685246468, 106.0584269464016, 105.24457141757011, 102.55472615361214, 102.625273168087, 101.36551916599274, 98.08070182800293, 100.87771654129028, 102.32598602771759, 105.43285131454468, 101.35866433382034, 104.7087773680687, 90.4902595281601, 93.87636423110962, 100.27274340391159, 108.737663179636, 103.41533437371254, 91.23717024922371, 77.1135713160038, 77.4189305305481, 77.94764935970306, 89.64953944087029, 87.83601835370064, 90.28785198926926, 80.23465543985367, 82.75918677449226, 76.49125590920448, 81.90527379512787, 82.84643769264221, 88.59338611364365, 81.54693022370338, 94.63494032621384, 90.14058709144592, 116.5287347137928, 65.54908946156502, 33.16139817237854, 111.76210328936577, 90.91393679380417, 88.32138910889626, 80.67122161388397, 94.30100664496422, 87.81918525695801, 92.07671239972115, 75.80296844244003, 79.01673719286919, 89.59048300981522, 96.5592634677887, 91.76940768957138, 87.94837072491646, 81.35664403438568, 80.48934817314148, 92.15905398130417, 101.38549089431763, 99.58009377121925, 94.4426554441452, 96.48369312286377, 97.60374382138252, 99.76989358663559, 102.83161729574203, 103.56791138648987, 99.95025470852852, 97.43143826723099, 88.05455982685089, 83.02025556564331, 82.40328267216682, 85.72579398751259, 83.12365561723709, 60.570334419608116, 22.58379176259041, 7.752839885652065, 5.259175719693303, 3.3114603208377957, 3.6030265130102634, 3.8327025761827826, 0.30549936171155423, 0.13755817024502903, 0.23010003729723394, 0.2820711844833568, 0.8353147585876286, 26.310949064791203, 34.79586146771908, 65.89975744485855, 45.90235009789467, 56.060257628560066, 65.93522474169731, 33.46533626317978, 22.476675510406494, 20.586757622659206, 41.75746031105518, 78.1677183508873, 84.69740957021713, 95.16549825668335, 94.12137508392334, 127.39549040794373, 49.94296208024025, 0.9929241263307631, 0.1457239469164051, 0.276923113851808, 0.20586746104527265, 0.41222334431950003, 0.13597951823612675, 0.15364475548267365, 0.21511355240363628, 0.1904108255985193, 0.06261200120206922, 0.16330074984580278, 0.06835436885012314, 0.10679144383175299, 0.16067112766904756, 0.1113896349852439, 0.17387273255735636, 0.12639993539778516, 0.1250385693856515, 0.28536450932733715, 0.11842014835565351, 0.30258848040830344, 0.17321490769973025, 0.17147126141935587, 0.22593836998566985, 0.10754982969956473, 0.12907313648611307, 0.1535351254278794, 0.1393092528451234, 0.08587948861531913], [0.04291507531888783, 0.015320502370741451, 0.01543689431855455, 0.038430221247836016, 0.025189577536366414, 0.026376490604889113, 0.0744583405321464, 0.06369380018441007, 0.019043546490138397, 0.0604621107049752, 0.05840969388373196, 0.053896653043921106, 0.015697768503741827, 0.04964453277352732, 0.04534208375844173, 0.03165040165185928, 0.032107367951539345, 0.03312825887405779, 0.010217552462563617, 0.038529175508301705, 0.047282707164413296, 0.04306313378037885, 0.03858525218674913, 0.07583815633552149, 0.37432094221003354, 78.53410989046097, 122.11807519197464, 100.21359577775002, 98.31476926803589, 49.83458809554577, 50.913308411836624, 36.80817648768425, 45.465605333447456, 84.7587002813816, 60.79210191965103, 49.355433806777, 44.810759872198105, 7.880678800866008, 0.1520635950146243, 0.2449900726787746, 0.32324132218491286, 0.17607751971809193, 0.4852602048777044, 1.1524895578622818, 15.529360100626945, 18.024849593639374, 4.406405529007316, 79.01454091072083, 106.34869337081909, 103.91205132007599, 99.63376969099045, 104.92103397846222, 104.12393555045128, 104.22006279230118, 99.93633985519409, 94.17635053396225, 91.19575247168541, 91.15134045481682, 90.9347976744175, 93.39341014623642, 96.79691031575203, 89.50169697403908, 89.41829904913902, 85.96895053982735, 75.29273182153702, 75.24887457489967, 89.44007948040962, 98.34570720791817, 92.81428322196007, 75.26103392243385, 66.4048719406128, 67.71923661231995, 70.16408622264862, 79.25670191645622, 75.15913859009743, 72.10580483078957, 67.1719291806221, 69.56862777471542, 68.18724989891052, 75.12716710567474, 75.55136114358902, 71.73661664128304, 69.59556832909584, 76.85378685593605, 77.01557457447052, 89.31766524910927, 83.75021159648895, 39.26228620111942, 98.85606542229652, 83.87409254908562, 84.29013222455978, 85.44416069984436, 91.66284620761871, 95.4612971842289, 94.5679423213005, 85.301333963871, 70.01817405223846, 74.45502117276192, 84.27386149764061, 80.21533727645874, 80.5123445391655, 74.0698890388012, 70.3257143497467, 73.58970880508423, 86.90344959497452, 84.02840226888657, 88.26502293348312, 92.66144782304764, 93.70162680745125, 89.90240067243576, 84.99457642436028, 81.90965116024017, 89.74814414978027, 95.51992043852806, 83.77396032214165, 80.95946654677391, 82.74805337190628, 87.7552118897438, 87.8296346962452, 86.65996626019478, 64.19243305921555, 11.95045754313469, 1.307652450632304, 1.657636589370668, 0.665811316575855, 1.0019354615360498, 0.605612809304148, 0.1246342176455073, 0.012763211761921411, 0.13521627872250974, 0.04227105811878573, 0.16499201534315944, 7.475630035623908, 34.396803081035614, 61.75508804619312, 55.37019565701485, 80.70081442594528, 63.697224631905556, 47.72874489426613, 28.199183642864227, 17.30125442147255, 15.194368176162243, 33.48452143371105, 55.9893724322319, 75.00960141420364, 72.76520624756813, 95.5270716547966, 11.18587302044034, 0.23990852816496044, 0.03766683330468368, 0.0913705576385837, 0.10185836596065201, 0.06609845513594337, 0.015126140388019849, 0.04096434386156034, 0.03580673292162828, 0.06070843322959263, 0.05662599018251058, 0.06641613887040876, 0.04067194138769992, 0.06635492653003894, 0.09330171495093964, 0.010530531908443663, 0.05581690449616872, 0.0989755304181017, 0.10897188854869455, 0.028594603027158882, 0.09325529361376539, 0.009468615990044782, 0.049800487686297856, 0.06472238717833534, 0.047377230803249404, 0.030067120496823918, 0.04621169529855251, 0.08471232780721039, 0.04165695689152926, 0.020697788095276337, 0.011235834735998651, 0.0654293793195393, 0.09027689171489328, 0.00931670299905818, 0.011801039563579252, 0.04457809467567131, 0.0401483265159186, 0.013932599013060099, 0.04211290644889232, 0.038438392293755896, 0.062489650736097246, 0.024692481456440873, 0.006961986237001838, 0.08920144551666453, 0.09054161579115316, 0.04512950297794305, 0.038398846954805776, 0.062200461761676706, 0.04838727894821204, 0.0752119989192579, 0.05831069138366729, 0.042674307769630104, 0.11020800229744054, 0.3615887457272038, 98.6476618051529, 135.32067954540253, 115.71292608976364, 110.19182994961739, 73.82703647017479, 70.55187061429024, 44.01987411081791, 44.60276663303375, 64.9223966896534, 63.474757969379425, 45.47955058515072, 52.53415323793888, 13.617377746850252, 0.2612529625184834, 0.20171713375020772, 0.18331139639485627, 0.10413600233732723, 0.3183404164155945, 1.8910458334721625, 28.4464268758893, 2.5604593567550182, 5.279700318351388, 88.89958888292313, 109.35009151697159, 108.55611652135849, 102.45906248688698, 109.92148205637932, 108.04578110575676, 106.74891069531441, 101.72699376940727, 97.72916749119759, 95.20088955760002, 95.71774542331696, 94.47139710187912, 96.38251975178719, 99.58225965499878, 95.60255080461502, 95.2201621234417, 90.1211929321289, 79.66184377670288, 79.72491279244423, 94.67758923768997, 100.51869660615921, 96.72661408782005, 78.40596556663513, 70.42448624968529, 70.90623199939728, 74.57317963242531, 83.29732149839401, 78.57314139604568, 75.87223872542381, 72.66998335719109, 72.04163387417793, 72.39091873168945, 80.9884361922741, 78.69253858923912, 75.90441539883614, 73.49187165498734, 80.93797490000725, 82.11677804589272, 91.65389388799667, 88.68895098567009, 43.953096494078636, 103.01883324980736, 87.68439888954163, 87.94084712862968, 90.21629422903061, 95.5380454659462, 99.00764688849449, 99.32256639003754, 91.11786425113678, 75.32449811697006, 77.69632324576378, 88.32328140735626, 86.47935435175896, 84.16423738002777, 77.14475244283676, 74.79582488536835, 76.48051768541336, 89.44107502698898, 89.53600153326988, 92.45857670903206, 95.95798373222351, 96.43383979797363, 92.3821248114109, 88.24290812015533, 86.5506461262703, 93.89593318104744, 97.10064321756363, 86.50393143296242, 78.76714378595352, 85.76180845499039, 89.47385966777802, 89.00910660624504, 92.0770163834095, 71.67797818779945, 17.687535993754864, 1.502123165410012, 0.8649585116654634, 0.6930671352893114, 1.8655139347538352, 2.2397632151842117, 0.1457648689392954, 0.14086090552154928, 0.16271322121610865, 0.1403302254038863, 0.2072115201735869, 8.230649046599865, 41.60874389111996, 38.38028892874718, 37.8867220133543, 64.34572443366051, 28.74391671270132, 37.13440798223019, 33.956923484802246, 34.86016921699047, 31.869661286473274, 49.08948227763176, 64.55073863267899, 88.14086839556694, 81.46267354488373, 115.65760865807533, 19.88844059407711, 0.3745236078975722, 0.030767654097871855, 0.050432708449079655, 0.07276167219970375, 0.010366366059315624, 0.0033462341752965585, 0.020631562547350768, 0.08186359395040199, 0.04249168749083765, 0.017053056326403748, 0.05649098238791339, 0.033053773222491145, 0.06071570998756215, 0.09084329882171005, 0.03875825794239063, 0.08442162856226787, 0.034544220980023965, 0.029076815335429274, 0.025604412112443242, 0.05740341955970507, 0.04369143600342795, 0.03322153199405875, 0.08041684384807013, 0.05772453201643657, 0.03453472520050127, 0.043984758740407415, 0.03918120048183482, 0.0613831530790776, 0.10032822814537212, 0.09666336191003211, 0.1443445318727754, 0.19358332880074158, 0.19412831752561033, 0.0864684941188898, 0.19591343501815572, 0.16335329390130937, 0.12390249714371748, 0.1556838655960746, 0.216692634858191, 0.1416824184707366, 0.08124433108605444, 0.17692111898213625, 0.15162774652708322, 0.22210339608136564, 0.19180722098099068, 0.18649032659595832, 0.19507277465891093, 0.13772559876088053, 0.1370261691045016, 0.11675743327941746, 0.1443210057914257, 0.19531493744580075, 0.3336470341309905, 116.35616317391396, 152.31186300516129, 130.13631373643875, 126.30463734269142, 77.34044954180717, 73.54563117027283, 52.28852681815624, 66.4525517821312, 123.45881804823875, 87.715412825346, 76.25454381108284, 74.32978749275208, 16.93952903151512, 1.233214563690126, 0.24180802545743063, 1.1166333756409585, 0.23413242248352617, 1.4678459172137082, 0.9450684848707169, 24.615364149212837, 29.582018740475178, 4.63747825473547, 94.22730579972267, 111.03827252984047, 116.84497654438019, 106.91495418548584, 115.54758176207542, 107.687027156353, 110.6348405778408, 105.10133430361748, 101.57656744122505, 99.21085238456726, 100.28716742992401, 98.34291815757751, 99.58729818463326, 103.35775226354599, 102.13962882757187, 98.16379576921463, 98.62625375390053, 82.44903981685638, 84.23368245363235, 99.83977183699608, 105.33124476671219, 101.20218873023987, 82.86279961466789, 73.5728757083416, 74.49080765247345, 79.1097030043602, 88.92196208238602, 83.14330816268921, 81.52261152863503, 76.7135439813137, 79.38435986638069, 75.96031799912453, 86.16774827241898, 84.36198636889458, 80.50061076879501, 76.70837625861168, 85.7160285115242, 88.07488113641739, 97.86453142762184, 92.4441146850586, 48.31496223807335, 107.42228776216507, 94.93789806962013, 93.04509803652763, 96.62585869431496, 100.01659914851189, 105.04559129476547, 104.86567854881287, 96.16964757442474, 78.84432524442673, 83.57902318239212, 94.50668960809708, 90.55827587842941, 87.61739328503609, 82.4157840013504, 76.85191735625267, 82.03578919172287, 93.7084512412548, 94.29551973938942, 97.54878357052803, 99.70569983124733, 101.03653281927109, 101.49881601333618, 93.1983058154583, 91.52422964572906, 101.09346896409988, 106.84147372841835, 86.9195531308651, 79.93024617433548, 86.4294022321701, 94.3373554944992, 94.76694524288177, 95.84367826581001, 70.94310522079468, 14.909173529595137, 6.218668883666396, 7.505022408440709, 4.747521774843335, 4.610845483839512, 2.4118821043521166, 0.27423722203820944, 0.2377585115027614, 0.2054850323474966, 0.27853375242557377, 0.5947992426808923, 14.188960175961256, 58.5698139667511, 93.2609112560749, 78.42439457774162, 112.06810846924782, 85.66598519682884, 67.63127133250237, 41.945523619651794, 29.767009913921356, 27.560808397829533, 52.69817143678665, 76.62248566746712, 103.07316273450851, 88.31989958882332, 131.6693338751793, 25.426316633820534, 0.5990528769325465, 0.17655359260970727, 0.1355636038351804, 0.19763489108299837, 0.12812936212867498, 0.07920847900095396, 0.11665121710393578, 0.22312036104267463, 0.2456990018254146, 0.11729008750990033, 0.10810274456162006, 0.10267253906931728, 0.23162789671914652, 0.1599151166738011, 0.07434174171066843, 0.23770178173435852, 0.28053835267201066, 0.19432126107858494, 0.13944561505923048, 0.1962631498463452, 0.1260008232202381, 0.13112599117448553, 0.23348915856331587, 0.18538427422754467, 0.14982466906076297, 0.12759838515194133, 0.16539813339477405, 0.2752365980995819], [0.06444759957958013, 0.06678764315438457, 0.024839996294758748, 0.03426638686505612, 0.018015670102613512, 0.072220846923301, 0.023454354632121976, 0.036766363264177926, 0.04595749487634748, 0.056308959538000636, 0.021656995413650293, 0.031735058437334374, 0.031707001544418745, 0.08698455392732285, 0.059140739031136036, 0.06681061262497678, 0.01968970293091843, 0.010540563889662735, 0.07207629139884375, 0.1212159448186867, 0.0916234593023546, 0.19884831737726927, 0.2760130033129826, 0.4640962608391419, 36.867897883057594, 116.82207137346268, 102.19748452305794, 76.69332906603813, 59.9742566049099, 29.753796122968197, 29.665958136320114, 85.97423985600471, 80.02320438623428, 45.893823355436325, 35.3163081407547, 39.30984824895859, 6.569019109010696, 0.12364074165816419, 0.10525187331950292, 0.1282382945646532, 0.18856966111343354, 0.38785299577284604, 0.2739091037074104, 4.388818172737956, 24.0833280980587, 1.8907040893100202, 45.39019837975502, 114.67888757586479, 100.62594205141068, 98.65171238780022, 93.33511367440224, 105.98307698965073, 99.61113810539246, 97.55699872970581, 95.11914074420929, 99.08313363790512, 92.23837092518806, 97.86522299051285, 91.4155250787735, 94.08560380339622, 90.4848638176918, 87.7392527461052, 89.16830286383629, 77.0037268102169, 66.17230162024498, 68.49913716316223, 80.96063688397408, 90.31634286046028, 80.6027264893055, 68.32397416234016, 66.05387717485428, 68.1431494653225, 70.10414063930511, 75.17092555761337, 71.88014253973961, 67.20578536391258, 66.37828096747398, 68.35482850670815, 73.64058807492256, 73.21855992078781, 77.41740301251411, 72.76981920003891, 70.68604901432991, 77.71817207336426, 86.17100849747658, 82.89052292704582, 93.20583701133728, 42.783302664756775, 75.86517870426178, 89.50744226574898, 83.79759505391121, 92.30259507894516, 87.08405390381813, 88.95099252462387, 87.4204270541668, 88.41503128409386, 70.40538087487221, 69.2658144235611, 80.15209347009659, 80.97924068570137, 79.16478484869003, 73.94951149821281, 71.06579303741455, 68.74433800578117, 79.3239963054657, 87.54870817065239, 87.8607702255249, 88.25943723320961, 85.42187109589577, 82.75916397571564, 71.98339059948921, 76.10445946455002, 82.22235158085823, 87.30362892150879, 82.00688794255257, 81.08036085963249, 91.266398280859, 89.95129644870758, 89.43110436201096, 88.94620478153229, 95.0996781885624, 86.70959159731865, 23.091699108481407, 0.41808366891928017, 1.0771312890574336, 0.7126805547159165, 1.262889071367681, 0.6123790587298572, 0.13066982268355787, 0.225139819085598, 0.15893806441454217, 0.09193486446747556, 0.009384396144014318, 3.5643334267660975, 24.078072980046272, 38.95180866122246, 42.85246655344963, 81.54864773154259, 73.65251943469048, 59.78889875113964, 24.80963632464409, 16.297629475593567, 12.855338137596846, 33.13779763877392, 41.2473376840353, 72.22201779484749, 78.84101942181587, 75.18813863396645, 1.9969479320570827, 0.18447659793309867, 0.06871046614833176, 0.010823879692907212, 0.029344511713134125, 0.02198598020186182, 0.0154674253462872, 0.04021244436444249, 0.031836907073738985, 0.04676035765442066, 0.048252694177790545, 0.04411167341459077, 0.06350503492285497, 0.056271729699801654, 0.08449954664683901, 0.02678869612282142, 0.01098647033359157, 0.013922261823609006, 0.06879539752844721, 0.024856126874510664, 0.02202679832407739, 0.057602678789407946, 0.043476981300045736, 0.047625464358134195, 0.023586579372931737, 0.07095411958289333, 0.014334314273583004, 0.0395495246630162, 0.040682220133021474, 0.04261190057150088, 0.10106525500304997, 0.04450168686162215, 0.013326397947821533, 0.0296558909030864, 0.0315091969241621, 0.02571828539657872, 0.04292231496947352, 0.05807798726891633, 0.06115097588917706, 0.05705012386897579, 0.11008315079379827, 0.05928760263486765, 0.07831816154066473, 0.10627741750795394, 0.07475850215996616, 0.029902417518314905, 0.12276606124942191, 0.09498079438344575, 0.23491268686484545, 0.26215642341412604, 0.32565071946009994, 0.49409609637223184, 54.59992378950119, 133.21314543485641, 115.72671175003052, 89.70415771007538, 78.24252873659134, 48.95233243703842, 49.89535443484783, 49.43669244647026, 40.82233428955078, 64.48687925934792, 38.98578263819218, 47.1578711271286, 11.006131265312433, 0.13128481077728793, 0.1576915234909393, 0.033995439880527556, 0.13811399432597682, 0.2024229458766058, 0.14010603743372485, 1.2101397081278265, 1.8187979352660477, 2.4831840908154845, 52.71426737308502, 117.15685620903969, 101.89830377697945, 104.33415547013283, 97.6596388220787, 108.52892518043518, 102.60045289993286, 99.78836819529533, 97.83038645982742, 103.6352513730526, 95.80145493149757, 100.71560204029083, 96.68778017163277, 97.60593250393867, 95.61987787485123, 92.87507995963097, 92.61533349752426, 83.01574900746346, 69.42151486873627, 73.55541944503784, 82.94253453612328, 94.7520500421524, 84.49801906943321, 71.64101377129555, 68.11112478375435, 71.48589089512825, 73.5491269826889, 77.35183373093605, 73.2285837829113, 71.10398098826408, 68.52986991405487, 73.72563511133194, 77.0823521912098, 77.36175119876862, 79.04943063855171, 75.72375789284706, 73.5383203625679, 81.36982932686806, 90.26846542954445, 86.46034777164459, 96.86126366257668, 44.03321519494057, 76.8012584745884, 93.5739840567112, 86.48438528180122, 95.18471762537956, 88.96575093269348, 91.29855215549469, 90.00314086675644, 92.19848826527596, 74.99737367033958, 71.61984130740166, 82.97534957528114, 84.36695650219917, 80.95819741487503, 79.53163996338844, 71.90349608659744, 75.48216685652733, 83.29716950654984, 93.01599159836769, 91.64510875940323, 91.92205309867859, 88.51950287818909, 86.08485952019691, 75.01063495874405, 79.4913849234581, 86.09403222799301, 91.71669691801071, 82.21554234623909, 81.28168165683746, 94.90213438868523, 91.75911024212837, 92.78068542480469, 92.93926611542702, 99.4480736553669, 94.43117246031761, 30.808197744190693, 1.118349814787507, 0.9323462331667542, 0.6933325272984803, 0.6416177179198712, 0.62926119659096, 0.03982291331340093, 0.2261065851780586, 0.2778538560960442, 0.019557305640773848, 0.12496410228777677, 3.331582141108811, 27.908579036593437, 31.610638685524464, 40.49712873995304, 72.40832939743996, 48.96643728017807, 39.86764691770077, 19.939447157084942, 26.10914759337902, 31.92102313041687, 53.01820546388626, 49.79610376060009, 83.2496340572834, 88.82501408457756, 95.94526201486588, 3.937189606949687, 0.19376945943804458, 0.08964090084191412, 0.051702819982892834, 0.05499952530954033, 0.029015235631959513, 0.00913252328246017, 0.024856449708750006, 0.01894443452329142, 0.026317391530028544, 0.025648816663306206, 0.03501056431559846, 0.07696020940784365, 0.03397762091481127, 0.08433209586655721, 0.030518546664097812, 0.03893100765708368, 0.0443136637477437, 0.013412276493909303, 0.0406619632121874, 0.04529592588369269, 0.04717631658422761, 0.031725614608149044, 0.02700214521610178, 0.03598743103793822, 0.021584448622888885, 0.03379916037374642, 0.017351872811559588, 0.09520373554551043, 0.1975296248565428, 0.30255080899223685, 0.12750527530442923, 0.17616522673051804, 0.1581555142183788, 0.19661722850287333, 0.17378317017573863, 0.22917943279026076, 0.09699723930680193, 0.1356777164619416, 0.14171439019264653, 0.19052956922678277, 0.22419519867980853, 0.18123799905879423, 0.16843279008753598, 0.2284611080540344, 0.11252551426878199, 0.2784701355267316, 0.15660067030694336, 0.31805739097762853, 0.4020768793998286, 0.3183633042499423, 0.6534860841929913, 68.3327516913414, 150.5797791481018, 128.86792659759521, 106.24512612819672, 89.22052726149559, 46.71805612742901, 41.74951113760471, 107.18483850359917, 113.50391462445259, 60.64033046364784, 54.48233149945736, 65.20610466599464, 15.317934695631266, 0.8808772824704647, 0.16162324376637116, 1.15595995914191, 0.3430334210861474, 0.9102345665451139, 0.2714329131413251, 7.7409531734883785, 45.87717264890671, 5.832185447216034, 53.46830651164055, 121.0955348610878, 107.81157687306404, 109.33233126997948, 100.86819425225258, 115.22767692804337, 108.4762068092823, 101.75388112664223, 100.52903965115547, 106.53118997812271, 99.14707660675049, 104.54255908727646, 100.78544229269028, 101.0132248699665, 100.19933894276619, 98.08451682329178, 98.65431144833565, 85.31695872545242, 73.28496515750885, 77.35276088118553, 87.22590029239655, 100.73153078556061, 89.92947801947594, 75.05905196070671, 71.45964950323105, 76.28540575504303, 76.64362773299217, 82.16386511921883, 76.90981864929199, 74.62189301848412, 72.23897248506546, 77.2642408311367, 79.36887189745903, 82.9808820784092, 83.1814581155777, 80.23765727877617, 78.10093313455582, 85.9195151925087, 94.33943778276443, 93.28908294439316, 98.84979575872421, 51.08860820531845, 82.0180669426918, 96.89102366566658, 91.11148059368134, 98.11270371079445, 94.18319016695023, 94.66398596763611, 94.40772011876106, 98.19990143179893, 78.09171482920647, 74.88534048199654, 89.50706228613853, 89.80502709746361, 90.49411252140999, 83.63615691661835, 78.60674679279327, 77.13434100151062, 86.3062584400177, 95.42636945843697, 96.71747177839279, 95.72863563895226, 95.5437071621418, 91.02358371019363, 80.85447818040848, 82.65609070658684, 90.5042351782322, 96.07194721698761, 85.95794633030891, 83.04604098200798, 100.36972180008888, 98.03999081254005, 96.84915751218796, 95.52406221628189, 104.0250800549984, 93.45907062292099, 26.771328561007977, 2.7781660621985793, 5.633680298924446, 2.216697740368545, 3.367449129000306, 1.6584803815931082, 0.2417024623719044, 0.4547727189492434, 0.6499929435085505, 0.21330817427951843, 0.4451470635831356, 6.6935583762824535, 41.85751274228096, 58.34662914276123, 58.389559239149094, 113.41696009039879, 97.74566620588303, 81.70994907617569, 35.19497685134411, 24.97032780200243, 23.598798997700214, 52.02606350183487, 58.97305212914944, 98.94251078367233, 98.79510149359703, 111.0352174937725, 5.05439568310976, 0.44593406666535884, 0.13454715837724507, 0.13110635394696146, 0.1471932212007232, 0.0869515209342353, 0.04679498255427461, 0.13654706825036556, 0.09392477018991485, 0.19898830127203837, 0.13794043567031622, 0.13495655672159046, 0.21390560315921903, 0.15046570653794333, 0.1287671341560781, 0.1056863933627028, 0.07632792185177095, 0.10388661845354363, 0.1538644460379146, 0.10858655805350281, 0.10496087721548975, 0.10558631474850699, 0.1238409434154164, 0.1393290830310434, 0.14866028388496488, 0.14281158131780103, 0.1025553910585586, 0.13325246691238135], [0.07646600584848784, 0.08283744755317457, 0.00689844726366573, 0.04375202493974939, 0.020072254083061125, 0.005552260490730987, 0.09096070658415556, 0.08645144698675722, 0.01402019470333471, 0.04973261457053013, 0.029498713302018587, 0.04715334340289701, 0.02112638580001658, 0.048243317141896114, 0.0922558804450091, 0.04381005717732478, 0.08797721355222166, 0.11630259323283099, 0.11356145594618283, 0.04279224245692603, 0.10552431573159993, 0.20635270688217133, 0.29877410852350295, 10.010882019996643, 117.48952075839043, 113.42903584241867, 109.52089995145798, 77.73466318845749, 46.0650497674942, 34.86278347671032, 45.76420471072197, 82.8671769797802, 145.92454254627228, 71.55615672469139, 38.99554431438446, 15.25939978659153, 0.08541387258446775, 0.05530762420676183, 0.1011422454030253, 0.09920051990775391, 0.1428871913230978, 0.13086379040032625, 0.03801545717578847, 3.0663905711844563, 7.704945830628276, 8.468761369585991, 104.65662896633148, 101.17737606167793, 105.65244913101196, 84.96622994542122, 92.57877945899963, 94.63083654642105, 102.0969571173191, 99.17919248342514, 96.23196423053741, 93.14168885350227, 93.29145401716232, 90.940892547369, 93.77268299460411, 89.85941737890244, 91.73614427447319, 85.09493663907051, 85.8276741206646, 68.81765887141228, 69.53282609581947, 67.44027078151703, 68.68976533412933, 69.13242638111115, 68.74831259250641, 66.40879333019257, 69.32335093617439, 65.96997007727623, 71.17135137319565, 66.69725105166435, 71.17659509181976, 62.719730883836746, 70.35520076751709, 64.5921716094017, 76.68546348810196, 72.85781487822533, 78.18112403154373, 68.0712117254734, 69.23513486981392, 77.17982456088066, 87.31074213981628, 77.72415295243263, 100.35487219691277, 38.00722114741802, 61.980488151311874, 94.35325384140015, 81.60462632775307, 86.33758395910263, 79.02448877692223, 88.98066133260727, 83.24057534337044, 83.55630040168762, 72.87752822041512, 69.57337751984596, 68.83030459284782, 77.24398791790009, 74.40294116735458, 75.20707681775093, 70.08644118905067, 67.4972677230835, 67.30530962347984, 76.38334929943085, 81.7779578268528, 81.485206335783, 69.73193541169167, 66.58318877220154, 67.5797612965107, 78.78475204110146, 84.59967121481895, 88.6137530207634, 78.4652803838253, 86.53589531779289, 89.79513242840767, 83.61835867166519, 85.6131300330162, 86.13547280430794, 84.96439844369888, 90.3401979804039, 95.6213065981865, 37.731067165732384, 0.30547003203537315, 0.7547543908003718, 1.3397463597357273, 0.318463227013126, 0.11677610571496189, 0.18241975049022585, 0.07114956417353824, 0.03996967301645782, 0.12946219998411834, 0.2409069097484462, 2.5511831045150757, 16.148802861571312, 36.713261380791664, 19.627054519951344, 49.48996938765049, 83.76958295702934, 82.63732731342316, 51.96416102349758, 21.149135045707226, 14.565959796309471, 36.55959002673626, 72.76015251874924, 71.04271307587624, 80.67657932639122, 14.693708941340446, 0.4944511695066467, 0.048542513977736235, 0.03128814081719611, 0.06717891825246625, 0.10698090671212412, 0.042203815828543156, 0.021669736233889125, 0.029785837250528857, 0.07884809951065108, 0.019897199999832083, 0.028971942447242327, 0.07168690877733752, 0.07960904578794725, 0.03374083127710037, 0.02252981303172419, 0.011211608252779115, 0.00483399698168796, 0.04782924697792623, 0.04060954161104746, 0.024619695323053747, 0.023975052863534074, 0.026717242144513875, 0.018569111889519263, 0.011039635010092752, 0.04757313923619222, 0.05410758996731602, 0.12068314958014525, 0.05678368543158285, 0.04421518817252945, 0.007936634865473025, 0.030628117347077932, 0.10791350432555191, 0.04703002814494539, 0.06272216560319066, 0.03180188883561641, 0.04693410926847719, 0.018798604360199533, 0.060155882019898854, 0.04943393723806366, 0.07590739871375263, 0.007587499840155942, 0.04746905302454252, 0.04481203817704227, 0.025427697473787703, 0.15043018735013902, 0.08183773010387085, 0.11643118516076356, 0.11106979160103947, 0.14128600771073252, 0.3255563776474446, 18.836140260100365, 141.7396143078804, 121.71318411827087, 126.11112132668495, 87.77408927679062, 63.91907572746277, 40.81965923309326, 32.65946410596371, 67.18270540237427, 119.06234756112099, 57.69924268126488, 43.987610042095184, 23.23171779513359, 0.12646954884985462, 0.1119769929209724, 0.1498842635191977, 0.10475761038833298, 0.0731220145826228, 0.23578043561428785, 0.01629938866244629, 1.5133462194353342, 2.10711233317852, 9.85039858147502, 113.02254885435104, 102.6120574772358, 110.10573416948318, 88.81513461470604, 97.3828236758709, 97.72473692893982, 105.10627403855324, 101.39357686042786, 96.89356192946434, 94.9047714471817, 97.79084578156471, 92.41568461060524, 96.24100774526596, 92.87911534309387, 97.20063865184784, 87.62200623750687, 88.5358875989914, 73.12877833843231, 72.1084874868393, 71.44491389393806, 71.14125698804855, 71.25640600919724, 70.10382905602455, 69.33842852711678, 74.98646065592766, 70.11804789304733, 74.81175363063812, 72.07279980182648, 75.0109389424324, 66.72787740826607, 73.10347929596901, 68.48517671227455, 80.85778400301933, 76.95084884762764, 80.36042109131813, 70.93891024589539, 71.89078196883202, 81.74982413649559, 90.23076385259628, 81.05551779270172, 104.70387563109398, 42.68722482025623, 64.42278429865837, 100.6752710044384, 84.80492860078812, 88.9637978374958, 83.1186094880104, 91.69732555747032, 88.70551809668541, 88.31711053848267, 77.86890238523483, 72.90671065449715, 72.59200394153595, 80.91326102614403, 77.40113988518715, 77.12824612855911, 72.65711724758148, 69.52038556337357, 69.9556902050972, 80.68594962358475, 83.92722129821777, 85.02172216773033, 73.68428573012352, 70.39905801415443, 69.1246747970581, 81.20146036148071, 89.22874242067337, 92.72451683878899, 77.94895648956299, 89.37076359987259, 93.50073918700218, 87.57071658968925, 88.08875799179077, 92.18005165457726, 89.8108483850956, 93.5343673825264, 101.78470507264137, 48.2365458458662, 1.2765301018953323, 0.9117197524756193, 1.462554344907403, 0.4700197570491582, 0.4968126834137365, 0.04723680904135108, 0.05418360815383494, 0.03457936167251319, 0.08777648487011902, 0.21373738796683028, 2.5562603445723653, 22.38855253905058, 34.51971508562565, 18.67090802639723, 54.11171078681946, 58.87815982103348, 45.11504754424095, 23.954007737338543, 20.019638054072857, 27.432190999388695, 45.99938169121742, 82.22537621855736, 81.77244812250137, 98.95736798644066, 25.366241857409477, 0.46218059957027435, 0.08634483747300692, 0.11354646456311457, 0.014836810405540746, 0.07966450648382306, 0.05387943150708452, 0.010099908140546177, 0.034847317801904865, 0.013323856092029018, 0.10426403023302555, 0.08033038364374079, 0.03046513800654793, 0.02048915182967903, 0.06640954859904014, 0.03811439288256224, 0.04098667879588902, 0.0711015694832895, 0.055849043201305903, 0.03738113242434338, 0.02774952688923804, 0.05317327428201679, 0.05273556300380733, 0.018502788007026538, 0.07249157497426495, 0.08970051756477915, 0.007471050839740201, 0.02892565098591149, 0.11718894020305015, 0.17942840553587303, 0.08269193465821445, 0.161396473122295, 0.14181692531565204, 0.1634037896292284, 0.12716712313704193, 0.15980508585926145, 0.10314375831512734, 0.19676083407830447, 0.15224530245177448, 0.20892821165034547, 0.12361043234704994, 0.07797505924827419, 0.15236002363963053, 0.2149301825556904, 0.27490770793519914, 0.3757344663608819, 0.16049378406023607, 0.2701011736644432, 0.3533694305224344, 0.5612981622107327, 0.6533044064417481, 27.003475204110146, 163.47349047660828, 139.00888323783875, 137.46595323085785, 108.31779330968857, 73.2880125939846, 54.77355167269707, 64.41703900694847, 108.74791502952576, 168.13305884599686, 92.09631934762001, 69.44313570857048, 29.23196442425251, 1.192630841396749, 0.2692007110454142, 0.237797993759159, 0.7078636600635946, 0.21360044687753543, 0.622221955563873, 0.18732019612798467, 8.996746838092804, 17.434150390326977, 9.60053538903594, 121.20940715074539, 105.83314463496208, 117.94494912028313, 92.01419815421104, 104.52183499932289, 100.99432468414307, 109.27727982401848, 105.46769544482231, 102.57969841361046, 97.19394341111183, 103.13556298613548, 94.65888664126396, 101.41761437058449, 94.68968018889427, 101.15663677453995, 93.04756790399551, 94.46454986929893, 76.27366438508034, 75.93516334891319, 74.72403153777122, 74.67613130807877, 74.81352433562279, 76.13058686256409, 72.91814804077148, 78.46449762582779, 75.30752822756767, 78.7580318748951, 74.04746264219284, 78.25654998421669, 69.85887140035629, 77.6990818977356, 71.45296186208725, 85.4322749376297, 81.01308926939964, 85.76855689287186, 74.23038482666016, 75.51252722740173, 86.75193652510643, 95.53369089961052, 85.86383298039436, 109.6622371673584, 48.44998799264431, 71.66133508086205, 102.35075309872627, 91.00482791662216, 94.16749700903893, 86.16676032543182, 93.86009350419044, 94.21367973089218, 92.00519263744354, 81.72501146793365, 76.51295274496078, 77.8659537434578, 86.53721764683723, 81.61941513419151, 82.42951646447182, 78.1451703608036, 72.00188040733337, 73.95262733101845, 84.32038620114326, 91.32887452840805, 90.34492492675781, 75.74545472860336, 74.46645855903625, 74.13958489894867, 87.23954156041145, 94.58653092384338, 96.46324262022972, 79.43489715456963, 91.46075025200844, 98.99623230099678, 92.78917416930199, 93.83490845561028, 94.89792421460152, 91.91192284226418, 98.78283575177193, 105.41284918785095, 44.2043200135231, 1.073897306341678, 3.8658436853438616, 5.243473062291741, 1.7941616009920835, 0.7810658414382488, 0.6204049999359995, 0.4786632244940847, 0.24231736140791327, 0.3517653822200373, 0.646651319693774, 5.805176496505737, 33.52717034518719, 57.46271297335625, 29.167113304138184, 70.784402936697, 110.45281514525414, 117.43832990527153, 75.61207428574562, 29.5187958329916, 23.45979865640402, 55.26359997689724, 96.89539343118668, 94.40129086375237, 113.3627749979496, 37.46489904820919, 0.9281949559226632, 0.26405566837638617, 0.21080738893942907, 0.23394611373078078, 0.2704354072920978, 0.17718869290547445, 0.19235194253269583, 0.17214474559295923, 0.16490264591993764, 0.24351437139557675, 0.15874795586569235, 0.12988166185095906, 0.161669138178695, 0.1461681816726923, 0.13394165493082255, 0.08481204276904464, 0.15349585097283125, 0.1874642915208824, 0.10529865830903873, 0.11710561928339303, 0.15309535840060562, 0.11946750426432118, 0.155362248478923, 0.14010008540935814, 0.1636104183853604, 0.09752904006745666, 0.22327313956338912], [0.0508686311513884, 0.02000733100430807, 0.029845036515325774, 0.06296484789345413, 0.04844950803089887, 0.025886615621857345, 0.03772557800402865, 0.07958140078699216, 0.05308022380631883, 0.024440488923573866, 0.04923411397612654, 0.03205338784027845, 0.06218621252628509, 0.12364688664092682, 0.01160735015218961, 0.02500560654880246, 0.045502576904254965, 0.007652155745745404, 0.05636954847432207, 0.041473876481177285, 0.07085940669639967, 0.06873967708088458, 0.3233469446422532, 80.68197503685951, 117.25663885474205, 105.4574815928936, 78.97645935416222, 58.97869862616062, 34.37345713376999, 35.84826439619064, 75.13132408261299, 37.17769905924797, 76.4246454834938, 73.05057853460312, 21.508162580430508, 0.46735577343497425, 0.04729745734948665, 0.0735196795722004, 0.10874226063606329, 0.18802875420078635, 0.10520709212869406, 0.11596087875659578, 0.12598985427757725, 0.1469728775555268, 0.9065133787225932, 38.199289441108704, 112.899199873209, 100.60033902525902, 97.60204911231995, 78.90186935663223, 84.22175109386444, 90.20041108131409, 95.32131269574165, 94.71111103892326, 92.50459223985672, 89.29792150855064, 94.6127039194107, 90.71763172745705, 87.9145373404026, 91.41796454787254, 85.22400051355362, 83.33359435200691, 81.21839985251427, 66.66972532868385, 64.57435816526413, 67.22160771489143, 67.29530856013298, 64.12656739354134, 66.81021139025688, 64.70183372497559, 69.17010515928268, 68.66805329918861, 69.39699098467827, 69.76698473095894, 70.03392040729523, 67.75573745369911, 67.70296588540077, 69.43640246987343, 81.43398508429527, 77.49700874090195, 81.96767404675484, 68.11129197478294, 73.40854972600937, 82.98049449920654, 95.04967287182808, 80.92365726828575, 97.34596565365791, 47.95277327299118, 43.32415424287319, 92.96990767121315, 73.69468197226524, 82.28500261902809, 80.36224499344826, 86.12893715500832, 80.22604510188103, 82.16477707028389, 70.06691783666611, 74.30611476302147, 65.8526323735714, 66.57263293862343, 70.53920969367027, 71.47994801402092, 67.69687861204147, 69.7605174779892, 64.40304055809975, 68.67220267653465, 68.85295137763023, 66.40019059181213, 64.89876195788383, 67.04943135380745, 71.96383684873581, 79.8577992618084, 82.26234063506126, 81.81763529777527, 79.47366267442703, 88.20471256971359, 84.12864089012146, 87.45973974466324, 77.23000466823578, 80.08799090981483, 85.18132880330086, 87.99973636865616, 86.92754030227661, 97.83830523490906, 47.89778642356396, 1.4192369068041444, 1.3273764797486365, 0.2931637689471245, 0.07631049622432329, 0.0837250413314905, 0.05951832892606035, 0.031092980098037515, 0.055943054758245125, 0.021500214861589484, 0.151777274440974, 0.8358371118083596, 14.281678050756454, 56.821330189704895, 24.96457301080227, 66.2413439154625, 131.33072644472122, 166.27394020557404, 94.74425286054611, 30.559622682631016, 19.07813597470522, 46.41175836324692, 73.65750476717949, 71.70149132609367, 22.086451649665833, 0.8708997897338122, 0.15030955866677687, 0.05961294904409442, 0.028520783453132026, 0.10016767933848314, 0.057413546164752916, 0.07971794111654162, 0.028192184581712354, 0.07781074775266461, 0.04129004279093351, 0.06825583390309475, 0.006264835437832517, 0.045938562689116225, 0.03207810877938755, 0.05460760083224159, 0.021614791330648586, 0.044581579059013166, 0.02829159526299918, 0.0538658464938635, 0.03722024222952314, 0.048346245603170246, 0.035896751724067144, 0.02663557621417567, 0.03780086146434769, 0.037272901317919604, 0.06425929444958456, 0.049311642433167435, 0.02710541506530717, 0.023324072462855838, 0.035638228291645646, 0.06213220643985551, 0.01712860510451719, 0.07252218114444986, 0.0933764418005012, 0.01932712853886187, 0.02586976330348989, 0.02575247985078022, 0.0637757481308654, 0.03388504912436474, 0.03302988348877989, 0.16517971933353692, 0.03423681228014175, 0.06146498228190467, 0.04086443965206854, 0.05391324004449416, 0.02736606289545307, 0.02348566398723051, 0.031023635674500838, 0.015192912342172349, 1.6245524771511555, 109.00033548474312, 128.32485973834991, 117.82535433769226, 94.67917755246162, 86.88538536429405, 57.70611271262169, 53.4454545378685, 58.93710605800152, 43.356897085905075, 75.33981889486313, 57.33277514576912, 30.566973388195038, 0.36501785391010344, 0.10948836395982653, 0.1258803132805042, 0.1266793391550891, 0.15913310082396492, 0.057350348579348065, 0.055005670292302966, 0.08218465445679612, 0.27505278296303004, 0.617251762887463, 43.79902996122837, 116.88938856124878, 103.3149741590023, 100.7519280910492, 82.50628754496574, 88.87601494789124, 93.85847479104996, 99.56763043999672, 98.78440886735916, 95.64649164676666, 93.65123391151428, 96.35180979967117, 92.46939852833748, 88.47812309861183, 93.97734761238098, 91.3826796412468, 87.21637800335884, 86.6853640973568, 70.48328429460526, 68.87653291225433, 69.85010147094727, 71.30659371614456, 67.32781201601028, 70.19831478595734, 67.93132603168488, 72.13133186101913, 70.22767961025238, 72.42527648806572, 71.06467589735985, 74.81013491749763, 70.0826033949852, 72.86255702376366, 73.57491999864578, 84.77606534957886, 82.61817634105682, 83.91315445303917, 71.78444847464561, 79.37175214290619, 85.84421843290329, 98.81912380456924, 83.83038729429245, 101.07148334383965, 52.21330985426903, 47.1324010938406, 92.02009543776512, 77.74703532457352, 85.46774223446846, 83.20972859859467, 89.14396896958351, 83.11590403318405, 86.1869828402996, 75.03603279590607, 76.24540910124779, 68.62150579690933, 70.72525531053543, 74.89413321018219, 74.15884986519814, 69.57069486379623, 70.7137343287468, 68.761687874794, 71.76023617386818, 70.89293271303177, 68.18069905042648, 68.08084800839424, 70.33759251236916, 76.31546974182129, 82.93707802891731, 88.31983879208565, 83.52948144078255, 82.88277134299278, 91.2664894759655, 86.6384594142437, 88.46135079860687, 80.37498950958252, 81.54551669955254, 89.19442266225815, 92.38446548581123, 90.0532753765583, 101.434515863657, 61.16696700453758, 2.9676445573568344, 0.7671396480873227, 0.8930496918037534, 0.06769600964616984, 0.35017074435018003, 0.04115325755265076, 0.08736146846786141, 0.06326118746073917, 0.07785791123751551, 0.15661508281482384, 0.4196903295814991, 19.008358418941498, 44.78931002318859, 21.76409024745226, 74.98886972665787, 112.41617739200592, 126.942607909441, 53.93040731549263, 37.48388662934303, 30.61147090047598, 54.86043781042099, 83.02237585186958, 87.55357950925827, 48.99569571018219, 0.4947479098336771, 0.08472126326523721, 0.08041872148169205, 0.018459405764588155, 0.01633982828934677, 0.009106961861107266, 0.025217853362846654, 0.02775248805846786, 0.06789411854697391, 0.009212967452185694, 0.042547764169285074, 0.015909299145278055, 0.029897176100348588, 0.046473369147861376, 0.0551302880194271, 0.023541672017017845, 0.04323720080719795, 0.03777867867029272, 0.015178364392340882, 0.007349583529503434, 0.009811898253246909, 0.007690301672482747, 0.04054949815326836, 0.0403527362504974, 0.05570624656684231, 0.06978727047680877, 0.02712066434469307, 0.16192117152968422, 0.11002779399859719, 0.1703348255250603, 0.14146485045785084, 0.15935481002088636, 0.10936924925772473, 0.28342830541078, 0.24409643781837076, 0.12562358955619857, 0.2056100100162439, 0.1334220328135416, 0.14753169991308823, 0.12733262206893414, 0.188356694416143, 0.1590223575476557, 0.16360679670469835, 0.14396553189726546, 0.10558119392953813, 0.2463337013614364, 0.16945794835919514, 0.2004520094487816, 0.1215270976535976, 2.672833576798439, 124.62781772017479, 140.163154900074, 133.09108078479767, 105.8069184422493, 84.1776430606842, 55.603928714990616, 54.30204637348652, 110.50317004323006, 50.72991505265236, 90.557059943676, 116.79454565048218, 36.95796824991703, 2.0529828127473593, 0.2564418566180393, 0.21570709242951125, 0.43330232729204, 0.4663623939268291, 0.3930097643751651, 0.4020074737491086, 0.35094786202535033, 0.4783306235913187, 1.9201782764866948, 44.6171260625124, 119.65363383293152, 109.6463692188263, 105.62559977173805, 88.08788403868675, 92.83449053764343, 99.71915870904922, 102.74169892072678, 105.8586260676384, 98.52627351880074, 98.23496595025063, 100.54606273770332, 96.01514026522636, 91.22684240341187, 97.01470702886581, 95.80477595329285, 91.55291050672531, 91.09277799725533, 73.66416200995445, 71.4578028023243, 74.45579633116722, 72.74315223097801, 73.12299504876137, 74.26202192902565, 73.2365633547306, 76.67715713381767, 75.54313078522682, 75.69406628608704, 76.4046661555767, 77.50847652554512, 73.05728897452354, 74.02629017829895, 76.73749789595604, 89.22078564763069, 86.49647623300552, 87.59012594819069, 76.08818873763084, 82.49312505126, 92.35664337873459, 101.2060721218586, 89.03555318713188, 103.40568289160728, 55.47826565802097, 52.00982317328453, 95.60938283801079, 82.54332035779953, 86.09640330076218, 84.63956147432327, 93.62656563520432, 87.93102845549583, 91.9080014526844, 76.68228685855865, 78.83485615253448, 73.48538160324097, 75.46787962317467, 78.28029111027718, 80.35939514636993, 74.48163494467735, 73.54762986302376, 71.50185003876686, 74.47577565908432, 74.32525053620338, 72.6316586136818, 72.54695355892181, 76.04078248143196, 79.64914485812187, 88.87518659234047, 91.5924359858036, 86.3035149872303, 83.06478917598724, 95.47959700226784, 92.22770109772682, 94.35843676328659, 86.03347107768059, 87.00570210814476, 94.17634293437004, 96.33546307682991, 95.1447057723999, 105.97294673323631, 59.52495351433754, 1.9251006748527288, 2.252534804865718, 2.033460410311818, 0.44361357868183404, 0.7307894330006093, 0.1818527645082213, 0.4992031410802156, 0.156485132756643, 0.1538599783089012, 0.32432809355668724, 1.2779313954524696, 27.038801908493042, 85.52384242415428, 35.92876687645912, 83.61298575997353, 146.27556771039963, 188.6539489030838, 128.35542529821396, 44.54762779176235, 33.857167437672615, 65.4893946647644, 98.34946140646935, 98.03398713469505, 76.31469458341599, 1.7204392631538212, 0.2171038291999139, 0.15633943432476372, 0.21274086175253615, 0.16758714249590412, 0.11755904924939387, 0.15764444164233282, 0.09768383722985163, 0.17754924308974296, 0.10620947388815694, 0.14736820477992296, 0.15569784765830263, 0.2482583574601449, 0.15874188509769738, 0.19435501395491883, 0.11401834432035685, 0.16461313411127776, 0.14959369786083698, 0.0893116470251698, 0.07305300969164819, 0.13271390518639237, 0.10739423843915574, 0.19259829103248194, 0.12249716630321927, 0.1280088521889411, 0.14221045654267073, 0.09583453138475306], [0.03589963496779092, 0.03674330473586451, 0.04516626155236736, 0.013084787133266218, 0.08954286313382909, 0.045274919393705204, 0.09805620240513235, 0.062288536137202755, 0.05928350969043095, 0.021769838967884425, 0.026901333731075283, 0.02135876151442062, 0.04778522277774755, 0.026410772261442617, 0.06072067124478053, 0.09006197316921316, 0.13124377001076937, 0.03761144311283715, 0.08043731228099205, 0.033937990228878334, 0.13085577520541847, 0.48271900217514485, 29.080540649592876, 132.61147052049637, 114.34392035007477, 105.67955687642097, 66.19940936565399, 25.99367368966341, 24.498558416962624, 48.20868954062462, 40.32187074422836, 65.71846157312393, 53.3916874229908, 24.37715493142605, 1.1199185368604958, 0.1962047873530537, 0.03932093946787063, 0.08288893775898032, 0.11243099434068426, 0.13488991186022758, 0.03973426377342548, 0.24339111550943926, 0.047082787423278205, 0.23700106074102223, 3.538004639558494, 80.59430614113808, 109.23844590783119, 99.84804779291153, 93.2893793284893, 79.60882902145386, 74.1707356274128, 76.50025382637978, 93.35982754826546, 94.53091710805893, 94.73980709910393, 96.0621589422226, 93.89698952436447, 83.70117902755737, 85.19254580140114, 89.29328575730324, 84.36967715620995, 80.76083600521088, 72.24241510033607, 64.75819990038872, 66.81088775396347, 65.93324884772301, 66.48602798581123, 66.46192967891693, 66.82881519198418, 69.28095281124115, 69.50997412204742, 67.28441834449768, 69.20599803328514, 67.59427651762962, 67.48575434088707, 65.5854307115078, 67.02039331197739, 72.88584977388382, 78.34500163793564, 80.34380078315735, 77.59415432810783, 69.28671330213547, 66.3016314804554, 73.64232078194618, 81.25968843698502, 76.97555512189865, 90.51552817225456, 66.11361756920815, 40.81387974321842, 82.6253579556942, 66.98911339044571, 84.60298463702202, 77.93237417936325, 84.4125084578991, 78.89855593442917, 78.72102946043015, 73.33702996373177, 72.49421238899231, 69.21242728829384, 65.88212639093399, 65.40497839450836, 68.20905312895775, 65.8231383562088, 66.58061251044273, 65.10226383805275, 67.59231582283974, 65.27881756424904, 68.10261324048042, 63.99229019880295, 72.14384838938713, 77.55568519234657, 82.98287317156792, 83.46395015716553, 82.95382753014565, 83.1643134355545, 84.05633077025414, 82.37577214837074, 77.84178704023361, 73.58571141958237, 72.80246704816818, 76.08133390545845, 82.78060242533684, 84.72314178943634, 87.27690875530243, 92.8269137442112, 61.23692885041237, 5.284289047122002, 0.4804180475184694, 0.374259403324686, 0.150803339201957, 0.0676568910421338, 0.029905469600635115, 0.16281827964121476, 0.06743855119566433, 0.09175716462777928, 0.10512898108572699, 0.6131576607003808, 9.159245118498802, 46.75040379166603, 56.655476689338684, 112.70746976137161, 111.25753596425056, 126.89421370625496, 36.97591848671436, 30.580297373235226, 43.04038166999817, 65.64372718334198, 67.88401857018471, 57.240846678614616, 4.975644433870912, 0.25001741072628647, 0.12621929665328935, 0.05158498548553325, 0.03766748639463913, 0.04915652985800989, 0.06548095858306624, 0.01781765397026902, 0.031074437538336497, 0.0816004209627863, 0.11368612933438271, 0.05074750151834451, 0.052935145067749545, 0.0740219873841852, 0.03727379931660835, 0.014188626973918872, 0.05705498864699621, 0.016306908473779913, 0.002533736465011316, 0.03703480550029781, 0.029189315646362957, 0.056806959182722494, 0.048608891665935516, 0.040915191420936026, 0.035517443757271394, 0.01786541673936881, 0.04250740988936741, 0.03650068181741517, 0.004980714475095738, 0.037277858864399604, 0.06403282066457905, 0.07796181191224605, 0.03422133479034528, 0.03107183816609904, 0.027429781839600764, 0.021470055835379753, 0.07085102784913033, 0.04080766535480507, 0.00918632156754029, 0.02543055103160441, 0.043933131237281486, 0.12092872624634765, 0.09606536157662049, 0.024557022807130124, 0.05588281092059333, 0.09682184754638001, 0.06778774652048014, 0.30365625279955566, 0.38131761364638805, 43.521052077412605, 152.0669737458229, 124.37487289309502, 119.67416793107986, 76.47499278187752, 48.954555317759514, 38.53107623755932, 43.60012203454971, 36.99548743665218, 60.89012525975704, 55.37806123495102, 34.20289568603039, 1.3141654198989272, 0.2791916811838746, 0.029625034258060623, 0.21966144820908085, 0.06177772331284359, 0.12220404023537412, 0.09715930209495127, 0.14072982739889994, 0.05052423381130211, 0.4645224317209795, 5.657799504697323, 84.31844830513, 112.03514903783798, 102.38303616642952, 96.37759521603584, 82.55937069654465, 76.05373218655586, 81.42587631940842, 97.77024328708649, 99.11867693066597, 97.99551039934158, 98.7745825946331, 96.86054170131683, 86.34661227464676, 86.43323242664337, 93.22066381573677, 87.85120233893394, 86.67031690478325, 76.81020319461823, 68.84526818990707, 70.73503598570824, 69.0321497619152, 70.44973969459534, 69.88059103488922, 68.89577507972717, 71.79235965013504, 73.3820803463459, 71.4297603070736, 71.56004771590233, 71.38995364308357, 71.7227853834629, 68.682621717453, 68.78131002187729, 77.69596606492996, 82.68061459064484, 82.72822603583336, 81.68897420167923, 72.16891184449196, 69.92381751537323, 76.90410375595093, 83.22717726230621, 80.22930532693863, 91.86399221420288, 72.83653602004051, 42.602743953466415, 85.5008764564991, 72.65793800354004, 84.16805237531662, 82.90452137589455, 88.98010656237602, 82.74689823389053, 81.81138083338737, 75.89072093367577, 77.28466093540192, 72.51448050141335, 70.6995002925396, 68.34610417485237, 70.68370074033737, 69.64479848742485, 69.48916643857956, 67.00499653816223, 71.23918533325195, 68.39609429240227, 70.25910392403603, 66.86513364315033, 76.33012935519218, 80.02906367182732, 88.8287302851677, 86.21655285358429, 83.71360436081886, 85.59199556708336, 87.1582867205143, 86.20513066649437, 81.83183133602142, 77.00139373540878, 76.78813397884369, 78.6728024482727, 86.30675241351128, 88.71440201997757, 90.73186576366425, 96.83943763375282, 77.89296269416809, 9.12445418536663, 0.6889402004890144, 0.7382843527011573, 0.30510109558235854, 0.22219735197722912, 0.10461686208145693, 0.19477262045256793, 0.10390358394943178, 0.12912614067317918, 0.106373325252207, 0.7283865963108838, 11.849019136279821, 32.8433932363987, 45.94269633293152, 117.30560302734375, 112.8604343533516, 110.35791143774986, 27.201550975441933, 36.59369699656963, 48.27148497104645, 75.03446727991104, 77.23745986819267, 86.97816878557205, 18.59710268676281, 0.1741799371666275, 0.09061790857231244, 0.06518501235404983, 0.06216176989255473, 0.03624344972195104, 0.022554148054041434, 0.002242469709017314, 0.04294632715755142, 0.008868985714798328, 0.0961852258478757, 0.06823923205956817, 0.05694503204722423, 0.043045893689850345, 0.05364590360841248, 0.031616470660082996, 0.04527792509179562, 0.008942235690483358, 0.033576378773432225, 0.024637230417283718, 0.01791630951629486, 0.05713741898944136, 0.008358787017641589, 0.06510934297693893, 0.034058370292768814, 0.04243296876666136, 0.0489207124337554, 0.08592803991632536, 0.11531037889653817, 0.11801829765317962, 0.17423691926524043, 0.19399713550228626, 0.2101781070814468, 0.2740266895852983, 0.1285988892777823, 0.1603041059570387, 0.1008471600653138, 0.08259862443082966, 0.13267595175420865, 0.1782578753773123, 0.2379111564368941, 0.22783786727814004, 0.16820058692246675, 0.2695521031273529, 0.16073483362561092, 0.19122410070849583, 0.1562250396818854, 0.2670760016189888, 0.513790202094242, 51.21730349957943, 168.4009748697281, 139.27719444036484, 136.3862031698227, 89.82515841722488, 44.23816479742527, 35.106031224131584, 71.70527592301369, 59.01320457458496, 94.52740609645844, 78.59371349215508, 44.22896169126034, 2.2885231487452984, 0.4044943512417376, 0.2484343503601849, 0.536469166399911, 0.21279818523908034, 0.35792948270682245, 0.30379960604477674, 0.3452841768739745, 0.2492986258585006, 1.7670717858709395, 7.193074347451329, 90.96474766731262, 118.22583764791489, 108.27054664492607, 101.70677125453949, 87.16327965259552, 80.76301708817482, 84.42180275917053, 102.06193819642067, 103.79797384142876, 101.19473353028297, 105.71047961711884, 101.25767335295677, 90.14255538582802, 86.07593759894371, 97.83673211932182, 92.92652159929276, 89.05107155442238, 79.99978244304657, 73.05161967873573, 72.92178064584732, 71.6263921558857, 73.59290063381195, 73.90080571174622, 72.52758979797363, 76.43900111317635, 76.21073216199875, 74.53810751438141, 74.74679991602898, 75.20294263958931, 73.30973982810974, 72.34184816479683, 71.88164725899696, 79.56706926226616, 87.29004085063934, 88.31292316317558, 87.92907536029816, 76.8755292892456, 73.79197955131531, 81.73224627971649, 88.61300066113472, 84.83053922653198, 95.52671447396278, 78.23428317904472, 48.89752417802811, 86.74672320485115, 75.30025541782379, 86.78151413798332, 86.13717511296272, 92.54827469587326, 90.52125066518784, 87.58616656064987, 81.0586716234684, 80.45987695455551, 78.11931654810905, 72.10594162344933, 72.06607416272163, 74.78558823466301, 74.56319376826286, 72.86179706454277, 71.23823538422585, 74.36244294047356, 73.808523863554, 74.93947997689247, 68.81581217050552, 78.78089904785156, 85.57364255189896, 92.3020327091217, 90.53865373134613, 86.56258508563042, 89.12056982517242, 89.93220627307892, 91.83946833014488, 86.95644155144691, 81.86105936765671, 79.52622905373573, 83.27456831932068, 92.0078144967556, 93.06652888655663, 95.12094184756279, 103.30980643630028, 77.14030668139458, 6.801218474283814, 1.051221073139459, 2.543714130297303, 0.841568213654682, 0.6397175823803991, 0.21989405213389546, 0.34717959235422313, 0.1956687044003047, 0.21108184999320656, 0.17711069318465889, 0.5407493398524821, 17.16935209929943, 79.95374411344528, 64.22508850693703, 117.84756034612656, 113.84407997131348, 146.8322530388832, 52.75164216756821, 47.65447027981281, 61.09775371849537, 92.32075810432434, 87.71982058882713, 105.98913386464119, 26.191249787807465, 0.6353522697463632, 0.33859184535685927, 0.23055454337736592, 0.20521207043202594, 0.1734853017842397, 0.17031935916747898, 0.14406313915969804, 0.14695420511998236, 0.23498586262576282, 0.22753190947696567, 0.14823302946751937, 0.22346537065459415, 0.22649186372291297, 0.11196235034731217, 0.10450727655552328, 0.1616852724691853, 0.06833843493950553, 0.13263353059301153, 0.1476443579304032, 0.14403032138943672, 0.11143395604449324, 0.21658812562236562, 0.14205827174009755, 0.1262557806330733, 0.12185068888356909, 0.21735853428253904], [0.0674631682340987, 0.011807460996351438, 0.034498040840844624, 0.08211594642489217, 0.10869229183299467, 0.023942018015077338, 0.02828772867360385, 0.011789231994043803, 0.041374276552232914, 0.04040012237965129, 0.025051810807781294, 0.022719925291312393, 0.04137780917517375, 0.06611622957279906, 0.0188584567149519, 0.03666993601655122, 0.01352762201349833, 0.03486289548163768, 0.009915786868077703, 0.026769192481879145, 0.05987441509205382, 0.9318644308950752, 74.57923650741577, 108.05056884884834, 100.03585651516914, 82.17768117785454, 74.48312446475029, 65.59748366475105, 53.49679358303547, 74.40902844071388, 56.51628255844116, 50.57154335081577, 37.20168337225914, 1.2034156126901507, 0.18358652538154274, 0.03156888415105641, 0.3167606214992702, 0.03675563923025038, 0.04935974473482929, 0.025085643464990426, 0.14245215919800103, 0.051108938569086604, 0.357771078706719, 0.5644009925890714, 38.50235357880592, 99.54835027456284, 105.8682319521904, 100.0042574107647, 96.46403297781944, 83.48130002617836, 74.09182906150818, 72.29676738381386, 81.63333758711815, 88.65785345435143, 89.26883786916733, 91.22512489557266, 96.9665940105915, 87.4228285253048, 89.31986913084984, 85.72998136281967, 84.43809628486633, 76.75737842917442, 66.66993051767349, 64.1850234568119, 64.39427062869072, 64.4721132516861, 64.83560174703598, 65.09030967950821, 65.24896636605263, 66.282769292593, 65.27671247720718, 67.65454888343811, 68.61205950379372, 65.10124549269676, 66.9364558160305, 65.28652355074883, 73.29026967287064, 78.24743047356606, 83.35368007421494, 77.39443704485893, 76.01425990462303, 70.25911912322044, 65.81977173686028, 64.00770977139473, 69.11544889211655, 66.62605807185173, 81.74899578094482, 73.28004062175751, 37.8901494294405, 75.96442177891731, 67.59040832519531, 78.25379893183708, 82.4015499651432, 78.59104603528976, 75.3146642446518, 73.65094631910324, 74.19359520077705, 70.46506807208061, 69.32090386748314, 66.23619139194489, 65.6870524585247, 64.11116302013397, 66.00101441144943, 65.34097462892532, 67.05981999635696, 65.68457499146461, 64.77470621466637, 62.94566676020622, 67.48807221651077, 77.72789195179939, 81.98892250657082, 84.77905198931694, 79.31692108511925, 82.5912357866764, 82.23850071430206, 78.6978431046009, 78.31247538328171, 72.60487005114555, 72.64862850308418, 69.70038190484047, 73.50548252463341, 76.52736157178879, 78.81670832633972, 82.3616673052311, 89.97024983167648, 93.71373295783997, 64.91180285811424, 3.689200426451862, 0.7291499397251755, 0.12913466052850708, 0.1969209747039713, 0.041554837371222675, 0.025913260578818154, 0.03830364796158392, 0.011525781628733966, 0.031356945328298025, 0.059093193340231664, 0.10080061998451129, 12.645475398749113, 62.20704339444637, 83.04723411798477, 100.68033993244171, 73.29159200191498, 66.1494192481041, 28.338503167033195, 34.83320206403732, 57.86638431251049, 69.09201934933662, 65.75101062655449, 49.336427226662636, 0.712964233243838, 0.12936419196194038, 0.047675774549134076, 0.04394422263430897, 0.04825202253414318, 0.06140548059192952, 0.02535207077016821, 0.09706733515486121, 0.037692133118980564, 0.08213616252760403, 0.07683228541282006, 0.023994723487703595, 0.06287999814958312, 0.06267046017455868, 0.024353342232643627, 0.015675960494263563, 0.05911167281738017, 0.038358655947376974, 0.0437944720761152, 0.01621336632524617, 0.010014483232225757, 0.04599953012075275, 0.06127724489488173, 0.04731819666631054, 0.06333250043098815, 0.08427284279605374, 0.04198411785182543, 0.05919371724303346, 0.014424838664126582, 0.016039134170569014, 0.032637936747050844, 0.03916291767382063, 0.0680671280133538, 0.008876358024281217, 0.08446927444310859, 0.03137098676234018, 0.003974621513407328, 0.06906548733240925, 0.02418775053229183, 0.06353927761665545, 0.02787171964882873, 0.008454297712887637, 0.02131870965968119, 0.06438141484977677, 0.02977849555463763, 0.13299921643920243, 0.07002592290518805, 2.1854482172057033, 100.83894342184067, 117.21502348780632, 115.57716697454453, 91.64021462202072, 96.34320706129074, 64.81080427765846, 48.1314966827631, 62.99282982945442, 58.30688327550888, 53.70325930416584, 44.84911881387234, 2.238397663459182, 0.304261667188257, 0.04120773861359339, 0.1564625120954588, 0.05133171645866241, 0.19023710367036983, 0.10935437661828473, 0.16250513785053045, 0.01619019833015045, 0.4054555809125304, 1.143283483106643, 43.704707622528076, 102.46099278330803, 108.66479828953743, 103.99113267660141, 100.33388212323189, 85.7670521736145, 76.30916208028793, 76.94750502705574, 83.97285684943199, 92.12667971849442, 93.80727633833885, 95.20104914903641, 99.50442463159561, 91.62796407938004, 88.55671048164368, 90.35973653197289, 87.47507572174072, 82.48231843113899, 70.20418927073479, 66.16489201784134, 67.62222781777382, 67.36872062087059, 67.53246903419495, 67.68075987696648, 67.76926472783089, 69.03979495167732, 69.03689190745354, 68.48415836691856, 72.43292167782784, 69.63082283735275, 68.00402373075485, 67.97254621982574, 75.19639939069748, 83.21551188826561, 85.67627504467964, 82.66647174954414, 78.62022086977959, 74.50265541672707, 70.35415202379227, 68.4560626745224, 72.68336623907089, 72.3124073445797, 84.38757419586182, 76.9664204120636, 41.17643728852272, 75.9913395345211, 69.58694279193878, 80.40900528430939, 84.96752947568893, 83.04447546601295, 80.61698332428932, 77.96309933066368, 76.88964173197746, 73.5995426774025, 75.06719872355461, 68.65322649478912, 68.17176192998886, 65.42016237974167, 69.5114940404892, 68.11531215906143, 68.05745646357536, 69.51414629817009, 67.73941352963448, 65.14336243271828, 69.06976014375687, 83.379807472229, 86.69658869504929, 86.01000353693962, 81.92149892449379, 84.93080824613571, 85.1303431391716, 84.15442630648613, 81.37596219778061, 76.59613028168678, 75.81347867846489, 73.5023058950901, 77.05100387334824, 79.06694009900093, 80.62472730875015, 87.1692605316639, 92.90632948279381, 97.9660239815712, 76.52667760848999, 6.244833804666996, 1.1967061227187514, 0.4164397227577865, 0.22694357932778075, 0.12944989517563954, 0.1978827387210913, 0.16316251741955057, 0.16430370305897668, 0.022609486295550596, 0.13259970350190997, 0.04127339270780794, 10.211019180715084, 55.557065829634666, 86.44324108958244, 109.42307040095329, 73.22225332260132, 39.37097556889057, 36.350445449352264, 45.17611026763916, 65.83772957324982, 79.64825570583344, 79.5145408809185, 74.54018980264664, 2.0327659975737333, 0.15330859227105975, 0.03905097582901362, 0.041780290703172795, 0.044692136798403226, 0.05658834103087429, 0.028399870898283552, 0.07812876545358449, 0.018148963536077645, 0.06986885477090254, 0.05269031797070056, 0.0387927232804941, 0.059990872905473225, 0.045083630830049515, 0.020730121614178643, 0.021042955413577147, 0.08683603533427231, 0.03182697713782545, 0.03034344619663898, 0.0294430039866711, 0.0351006758864969, 0.015415245870826766, 0.04557497341011185, 0.07091671533999033, 0.0887389390845783, 0.09510999487247318, 0.15381362376501784, 0.08074675817624666, 0.13521448272513226, 0.11759324741433375, 0.1444747342611663, 0.1409952194080688, 0.12273971500690095, 0.08549534555641003, 0.19600657455157489, 0.10558578040217981, 0.16925362026086077, 0.23060015577357262, 0.11545362081960775, 0.19852769473800436, 0.20633719599572942, 0.14872452418785542, 0.09198678511893377, 0.16631559119559824, 0.08429639114183374, 0.27644810965284705, 0.1632643400807865, 2.9630237678065896, 120.73483541607857, 134.5482113957405, 128.73738080263138, 104.25904110074043, 98.16081672906876, 83.61945301294327, 77.31391176581383, 102.37005606293678, 84.57130953669548, 75.99106594920158, 58.93930993974209, 3.7039908953011036, 0.66697001690045, 0.24078172427834943, 0.7747909531462938, 0.15483523457078263, 0.3156049194512889, 0.11747405107598752, 0.6819403229746968, 0.2823077514767647, 1.1359717254526913, 1.57961216988042, 42.93322741985321, 103.71780574321747, 112.17798337340355, 107.16973811388016, 104.11798506975174, 90.50697863101959, 82.2992442548275, 78.86673644185066, 89.8348630964756, 97.11697474122047, 99.70122367143631, 98.39894235134125, 105.06632298231125, 93.0119714140892, 92.63632357120514, 98.28366413712502, 94.06660482287407, 86.129689514637, 73.59951227903366, 70.33243238925934, 71.14981412887573, 70.66011160612106, 71.90109461545944, 71.80403262376785, 71.93912297487259, 73.87349277734756, 72.6320917904377, 74.52841803431511, 76.79604515433311, 72.19545722007751, 72.68470376729965, 71.29418358206749, 77.95906394720078, 86.84522911906242, 91.62994757294655, 88.00494208931923, 82.1788439154625, 77.63287425041199, 73.9032755792141, 72.25748509168625, 76.96360096335411, 76.41920417547226, 88.21791306138039, 82.32933104038239, 46.0832279920578, 77.33264476060867, 73.72891813516617, 82.23582565784454, 90.51140919327736, 84.14621114730835, 85.99705383181572, 80.31584948301315, 81.28843009471893, 77.28650003671646, 78.85752573609352, 71.50240480899811, 72.02423840761185, 69.27530631422997, 74.76982668042183, 70.26666551828384, 70.96373051404953, 70.97810134291649, 71.28890946507454, 68.97783547639847, 73.47621649503708, 87.54881456494331, 91.50773093104362, 89.43355903029442, 84.29859817028046, 87.24648758769035, 90.92661291360855, 87.95609951019287, 87.24221661686897, 78.58422920107841, 81.68271973729134, 76.57279193401337, 83.05193826556206, 83.91509234905243, 86.57943338155746, 90.09313523769379, 97.1530956029892, 103.79864260554314, 87.67218634486198, 5.1485042832791805, 2.636574497446418, 0.701788142323494, 0.32753093575593084, 0.2501436055172235, 0.4800934618106112, 0.26528994902037084, 0.4146602307446301, 0.1186400096048601, 0.5632166436407715, 0.23515428561950102, 24.48583859950304, 92.14224368333817, 91.79546669125557, 109.58965346217155, 87.78338357806206, 93.85578453540802, 42.058700546622276, 55.18737606704235, 77.29598432779312, 94.67012643814087, 92.0163944363594, 92.94713169336319, 2.071278356015682, 0.34025256405584514, 0.1265830677584745, 0.1529500458855182, 0.14286463003372774, 0.24606379709439352, 0.10925438706181012, 0.20047791040269658, 0.14818259311141446, 0.15345663588959724, 0.1293614014866762, 0.10763386308099143, 0.1349961874075234, 0.24153932346962392, 0.14419970917515457, 0.0957401302002836, 0.1697611008421518, 0.10789358508191071, 0.1654900558060035, 0.06521520292153582, 0.16510026500327513, 0.07526547065936029, 0.144520346657373, 0.15763412578962743, 0.16575031215324998, 0.20729149400722235], [0.026190437893092167, 0.043270025998936035, 0.05705982002837118, 0.04934738055453636, 0.042497973481658846, 0.011737168479157845, 0.0279877414504881, 0.0033292079160673893, 0.1131500092742499, 0.02457832801155746, 0.046855901746312156, 0.10821840085554868, 0.04130005807382986, 0.043179632411920466, 0.008709456433280138, 0.08013874627067707, 0.06407839595340192, 0.08123437888571061, 0.1234170509269461, 0.20388453151099384, 0.4093144816579297, 23.46066500991583, 120.29485702514648, 97.49758511781693, 83.53563711047173, 52.341248989105225, 37.94812671840191, 118.70936930179596, 119.72378566861153, 53.78526650369167, 48.340401872992516, 35.511081889271736, 3.4948178194463253, 0.7209967647213489, 0.25079437997192144, 0.2670760016189888, 0.14569532970199361, 0.18758595921099186, 0.011647319443000015, 0.08657825033878908, 0.11753037266316824, 0.1173274101165589, 0.05002754776796792, 30.958979353308678, 100.78937888145447, 103.93729716539383, 104.310984313488, 101.411701887846, 99.90072056651115, 91.72261700034142, 76.81284785270691, 66.49841532111168, 69.18716624379158, 74.73265707492828, 83.50624188780785, 81.76349580287933, 89.3768660724163, 89.48642939329147, 87.34450712800026, 83.53052258491516, 78.40078264474869, 70.17977178096771, 65.92666000127792, 65.58661624789238, 67.5553286075592, 63.21046695113182, 64.35409918427467, 65.86154669523239, 65.07666081190109, 63.943607211112976, 64.68809366226196, 63.09560291469097, 66.39188423752785, 62.82978057861328, 63.9608658850193, 68.73939827084541, 77.82946810126305, 76.86486706137657, 75.7881036400795, 76.08630403876305, 69.18601870536804, 61.8559954315424, 60.47155112028122, 60.46645179390907, 59.534339010715485, 63.65777134895325, 80.95607712864876, 76.32389008998871, 37.837229669094086, 70.18952965736389, 63.009108155965805, 77.00872734189034, 79.95978578925133, 79.21601369976997, 72.48456090688705, 76.80989161133766, 72.67956644296646, 72.20852091908455, 68.21121901273727, 64.98282864689827, 65.62266111373901, 65.94254314899445, 64.77518498897552, 64.22407776117325, 65.51354616880417, 64.28653120994568, 62.56373405456543, 64.83743324875832, 73.35953995585442, 78.41040372848511, 82.37343907356262, 78.23853895068169, 82.33719661831856, 80.20733490586281, 75.66773369908333, 74.40177842974663, 72.89802432060242, 68.97182419896126, 67.80917778611183, 69.18113976716995, 66.21199429035187, 71.1863985657692, 75.78260153532028, 73.74942183494568, 83.05793434381485, 88.09355333447456, 90.35498678684235, 31.963140070438385, 0.49890752881765366, 0.5666771891992539, 0.07199803934781812, 0.08440418809186667, 0.09796235783142038, 0.25050342839676887, 0.022568903805222362, 0.09657388858613558, 0.09823313041124493, 0.007291797592188232, 0.07632008477230556, 9.568818490952253, 34.96779844164848, 47.426398918032646, 30.02557083964348, 41.21302552521229, 30.29148817062378, 27.70882375538349, 45.788648799061775, 62.31401905417442, 65.69795027375221, 70.07004126906395, 12.57650624960661, 0.18525068764574826, 0.15030693146400154, 0.07329123167437501, 0.09850393267697655, 0.04337575606768951, 0.02798784349579364, 0.10579999390756711, 0.03002945835760329, 0.04258616660081316, 0.042729174747364596, 0.05908662533329334, 0.13217160303611308, 0.04855165352637414, 0.018926088632724714, 0.04908002185402438, 0.017353715193166863, 0.02379151788773015, 0.04187743783404585, 0.03667890116048511, 0.048080775668495335, 0.04915523109957576, 0.03563669204595499, 0.0012738392024402856, 0.018602141171868425, 0.009925419017235981, 0.056643523421371356, 0.02641532162670046, 0.03279116797784809, 0.05358233494916931, 0.06751288470695727, 0.0399920079507865, 0.02287968742166413, 0.03536193042236846, 0.028639944539463613, 0.013787642728857463, 0.022573419773834758, 0.017982175122597255, 0.06240094924578443, 0.04340847364801448, 0.06969373018364422, 0.025609829790482763, 0.07378886395599693, 0.1774773289798759, 0.08713283503311686, 0.30047505162656307, 0.42132097645662725, 35.98608300089836, 139.12550657987595, 106.97873756289482, 97.50109612941742, 65.16264259815216, 59.277427196502686, 108.86923491954803, 77.39550858736038, 42.147710770368576, 44.584539011120796, 38.381204679608345, 4.845627285540104, 0.7822361786384135, 0.22920773830264807, 0.48511560482438654, 0.0740654327091761, 0.27119581180159, 0.17995346017414704, 0.8225387160200626, 0.08163614795194007, 0.11638428142759949, 0.6912045821081847, 39.78264167904854, 106.70667216181755, 103.12797859311104, 104.64696228504181, 102.97596395015717, 103.12158733606339, 95.4669588804245, 79.4389933347702, 69.3640847504139, 72.55187049508095, 78.62684771418571, 85.2311897277832, 86.57358169555664, 94.68323573470116, 93.30620482563972, 90.03683745861053, 87.53727078437805, 85.11522755026817, 74.97583642601967, 69.75035682320595, 69.62826177477837, 71.57550528645515, 66.7363129556179, 66.99506387114525, 68.66344794631004, 68.90182435512543, 65.82720413804054, 68.86239767074585, 66.73769608139992, 68.55678766965866, 66.88909515738487, 65.65771043300629, 71.34207621216774, 82.33630746603012, 83.16454902291298, 78.50108966231346, 80.19994050264359, 72.97128438949585, 64.32603389024734, 62.6733011752367, 62.352856770157814, 62.662053778767586, 66.70832365751266, 83.7932176887989, 82.60724812746048, 40.33740811049938, 72.42919027805328, 66.87533229589462, 79.01533126831055, 83.3951510488987, 82.51672938466072, 77.41253167390823, 79.46946769952774, 78.31094026565552, 76.77559465169907, 70.9694454073906, 67.1570111811161, 68.01940530538559, 67.41294264793396, 67.53778114914894, 67.40982681512833, 67.49317154288292, 66.6912929713726, 67.03533411026001, 68.39702904224396, 76.64108946919441, 82.79146984219551, 83.56695502996445, 81.13279044628143, 85.65672889351845, 84.79722261428833, 78.09381231665611, 78.69750112295151, 76.29102945327759, 74.41519930958748, 72.1251229941845, 71.8628078699112, 70.71779251098633, 74.25010576844215, 77.67133578658104, 76.20763152837753, 84.53838050365448, 90.54101720452309, 92.27332904934883, 45.77139392495155, 1.5257941139861941, 1.1525893025100231, 0.1300880085909739, 0.07014985414571129, 0.2250723133329302, 0.4764637956395745, 0.042611640819814056, 0.06691827598842792, 0.09087291051400825, 0.05327141218003817, 0.07986896074726246, 9.541734494268894, 40.39766527712345, 53.36959920823574, 37.56314277648926, 25.548041202127934, 28.19807980209589, 47.90963038802147, 59.20726776123047, 70.82153454422951, 77.12452232837677, 87.43720695376396, 27.928315177559853, 0.32206299947574735, 0.0644498408655636, 0.09014437382575125, 0.07747262527118437, 0.10118220263393596, 0.07925046971649863, 0.03016845519596245, 0.022522410108649638, 0.06332798817311414, 0.049381289281882346, 0.07496179867302999, 0.05972538812784478, 0.04472237931622658, 0.05116439555422403, 0.020374614323372953, 0.05081784969661385, 0.05542071638046764, 0.02108033553668065, 0.06403950741514564, 0.050240948621649295, 0.08913506782846525, 0.01110670846173889, 0.042766311817104, 0.029549006794695742, 0.03463636232481804, 0.1310518803074956, 0.11047932406654581, 0.10792496308567934, 0.15928895183606073, 0.18121448782039806, 0.14273043489083648, 0.14565535762812942, 0.09693227912066504, 0.16981285822112113, 0.2112912543816492, 0.22459104540757835, 0.23839882167521864, 0.11908376196515746, 0.3139324451331049, 0.21983684739097953, 0.2980114775709808, 0.291360350092873, 0.37470804643817246, 0.2747547364560887, 0.5278140027076006, 0.8224174787756056, 43.29686410725117, 154.4928851723671, 122.54466310143471, 111.05293214321136, 74.42987412214279, 53.590276166796684, 128.05440545082092, 135.23529052734375, 74.0933945775032, 70.95803841948509, 60.66404119133949, 7.97768522053957, 1.169578309636563, 0.6268762901891023, 0.6849952996708453, 0.1961209691944532, 0.5279851716477424, 0.1701637901715003, 0.7838836871087551, 0.3142673021648079, 0.29219793796073645, 1.8651993828825653, 37.340923100709915, 111.18438228964806, 106.00521460175514, 110.04657134413719, 108.8779516518116, 108.07796537876129, 98.3741220831871, 84.71638575196266, 72.85544380545616, 77.27622538805008, 82.61051595211029, 91.34080588817596, 88.72298195958138, 99.3152479827404, 97.31194227933884, 91.96119859814644, 91.87477603554726, 86.97171673178673, 77.85656064748764, 72.33560130000114, 73.37343201041222, 74.18316096067429, 71.07080116868019, 70.9436447918415, 72.56510138511658, 71.12966001033783, 70.87448850274086, 71.0101868212223, 70.08204862475395, 72.36072555184364, 70.52472487092018, 68.3627700805664, 75.55164232850075, 85.49174174666405, 85.66789269447327, 83.56700822710991, 83.64314094185829, 77.91487231850624, 69.10037130117416, 67.6902973651886, 65.95097109675407, 66.92563399672508, 70.70220574736595, 89.94261771440506, 89.38014909625053, 47.17790745198727, 73.59078034758568, 70.25394380092621, 79.15881916880608, 88.42684864997864, 87.2655701637268, 80.983557254076, 85.69224938750267, 82.03262016177177, 81.45717144012451, 75.91886222362518, 71.14453241229057, 71.19672641158104, 70.85705503821373, 68.99514734745026, 70.45907959342003, 70.60333505272865, 70.1516380906105, 71.9416156411171, 71.60737797617912, 81.9251999258995, 85.97946837544441, 86.67381271719933, 83.42228159308434, 89.79821026325226, 89.67207223176956, 83.04126843810081, 81.48388400673866, 82.96368420124054, 79.1443419456482, 75.89630663394928, 77.4938853085041, 76.57296672463417, 79.96659502387047, 81.91085949540138, 81.78614258766174, 90.30716255307198, 93.18271905183792, 96.07520744204521, 51.54447354376316, 1.3313910830765963, 2.0356676168739796, 0.23395807715132833, 0.3390166210010648, 0.22088576923124492, 0.5260308890137821, 0.21170109801460057, 0.23090669244993478, 0.15545127651421353, 0.1490910560823977, 0.1849927319562994, 15.752697866410017, 54.359727278351784, 60.769173949956894, 50.10676749050617, 62.043302580714226, 43.83423127233982, 43.491132482886314, 62.20668241381645, 84.87897142767906, 86.97673246264458, 104.55007508397102, 34.14443962275982, 1.057106601074338, 0.36939634708687663, 0.21963810024317354, 0.18797480006469414, 0.14058683038456365, 0.19620922539616004, 0.13111325592035428, 0.1275738052208908, 0.17917472461704165, 0.19214445288525894, 0.1921376696554944, 0.14541163633111864, 0.11753109996789135, 0.10530663639656268, 0.12425307286321186, 0.10302422058884986, 0.1301012485055253, 0.09461688227020204, 0.20251764392014593, 0.16591641964623705, 0.17780057882191613, 0.12641675246413797, 0.09950324194505811, 0.25034428224898875, 0.08644549496239051], [0.051999285715282895, 0.03820684964011889, 0.03653516941994894, 0.06566668846062385, 0.05981627524306532, 0.01889132458018139, 0.030927271509426646, 0.014834246285317931, 0.12402090680552647, 0.0763858984282706, 0.08998386954772286, 0.047100105439312756, 0.02579479154519504, 0.0291560859841411, 0.02177726972149685, 0.04131440007768106, 0.087175827648025, 0.055748860686435364, 0.039945397365954705, 0.01762012208928354, 0.02189066060964251, 62.68805578351021, 116.19754448533058, 85.37926018238068, 69.56823259592056, 30.771199129521847, 34.49147880077362, 90.29562637209892, 146.57912582159042, 77.59023293852806, 61.9402939081192, 12.76298314332962, 0.171950169315096, 0.09374081404530443, 0.1145144403562881, 0.14603137416997924, 0.22484447399619967, 0.11780009881476872, 0.14298595633590594, 0.23202179902000353, 0.08465900449664332, 0.4410920577356592, 34.966814294457436, 101.49962916970253, 99.60207179188728, 100.8413676917553, 96.61265820264816, 98.65326270461082, 99.88187357783318, 93.08036014437675, 83.05944666266441, 68.13107371330261, 63.052068650722504, 67.25757658481598, 69.3903261423111, 77.46842667460442, 82.03507483005524, 86.97055399417877, 90.99024429917336, 81.86976850032806, 75.32231703400612, 71.62333711981773, 70.29622793197632, 71.13198548555374, 66.88318267464638, 66.7528572678566, 60.87779492139816, 62.66701631247997, 62.2204414755106, 62.04432472586632, 63.66621069610119, 64.50583264231682, 65.0265870988369, 60.87025232613087, 63.091833516955376, 74.1874547302723, 78.0582158267498, 75.41359573602676, 78.46945255994797, 69.8975533246994, 65.50381869077682, 65.53898200392723, 67.02080368995667, 68.78047406673431, 64.46935459971428, 67.90089726448059, 73.64365071058273, 81.33788824081421, 36.818299144506454, 64.4364483654499, 65.07508769631386, 72.68567651510239, 80.578293800354, 76.91013783216476, 75.01285403966904, 73.99920523166656, 75.01406997442245, 72.79926002025604, 70.65406993031502, 62.03219577670097, 62.08599328994751, 64.62098926305771, 67.65739113092422, 63.92648532986641, 65.08217051625252, 63.80334913730621, 61.10634505748749, 65.37454202771187, 76.92811846733093, 80.0457675755024, 79.57903102040291, 82.09470883011818, 79.66901019215584, 74.3452450633049, 73.30728515982628, 69.12272930145264, 67.92325526475906, 65.46594992280006, 67.45092540979385, 64.2029356956482, 68.37949678301811, 70.3538404405117, 68.05998712778091, 69.23681437969208, 73.8293619453907, 80.09983107447624, 93.11107769608498, 73.48757028579712, 17.362068258225918, 0.2561513503314927, 0.928628429537639, 0.1652018798631616, 0.09842520565143786, 0.1090679966728203, 0.10671930707758293, 0.02003261226491304, 0.07988093158928677, 0.07505075991502963, 0.06122360246081371, 0.46877597691491246, 16.105173602700233, 26.926187351346016, 37.202124148607254, 33.057599142193794, 38.08649629354477, 18.247574642300606, 37.486409693956375, 65.26689380407333, 65.10270461440086, 70.28051197528839, 54.07431699335575, 1.9984481390565634, 0.21679886587662622, 0.08930570984375663, 0.02354802480112994, 0.016553984278289136, 0.07820378916221671, 0.007220055567813688, 0.022422025358537212, 0.040817291010171175, 0.01591385036590509, 0.0620177635573782, 0.032274006080115214, 0.07241003520903178, 0.03526039348798804, 0.03806981949310284, 0.024264653729915153, 0.04408280015923083, 0.023991662128537428, 0.04274922015611082, 0.05561173034948297, 0.029947460316179786, 0.10778432610095479, 0.020736860315082595, 0.02722994002397172, 0.0806632665626239, 0.08259134396212175, 0.025362013693666086, 0.016513952832610812, 0.1267030878807418, 0.056530279107391834, 0.059868978860322386, 0.12351390862022527, 0.021331869793357328, 0.04761572366987821, 0.03425618604524061, 0.0741000464768149, 0.0610585673712194, 0.01434402434824733, 0.04839092660404276, 0.013686808979400666, 0.023905960770207457, 0.06904164954903536, 0.04521710237895604, 0.01579991770995548, 0.07446375821018592, 0.3875477355904877, 84.32695984840393, 124.7491604089737, 99.39169988036156, 83.52102309465408, 49.524205550551414, 47.21430949866772, 72.44147881865501, 123.41130539774895, 57.61049844324589, 60.2517519146204, 15.463920012116432, 0.24524370906874537, 0.17397949792211875, 0.394866083515808, 0.5344459530897439, 1.1435213265940547, 0.5485148762818426, 0.8431835426017642, 1.1095900973305106, 0.11508545620017685, 1.0473081143572927, 44.3964035063982, 105.16298219561577, 101.67246669530869, 104.43730473518372, 99.82702732086182, 100.49374714493752, 100.28139933943748, 96.99000835418701, 86.65079355239868, 70.44948890805244, 67.71384090185165, 70.8281309902668, 73.805430829525, 81.72107487916946, 87.99910560250282, 91.17632791399956, 94.44488972425461, 86.95628196001053, 78.77772241830826, 74.7928686439991, 74.70593690872192, 74.45312887430191, 69.39186125993729, 69.69043403863907, 64.39120799303055, 65.69744870066643, 65.1300935447216, 64.91560265421867, 67.08124324679375, 67.66170769929886, 68.46423983573914, 64.08073425292969, 67.67000645399094, 77.04361706972122, 82.55575329065323, 79.10266578197479, 81.26518294215202, 72.3400242626667, 68.7437604367733, 68.57858330011368, 73.01074907183647, 72.78080821037292, 67.3546613752842, 71.0769872367382, 77.57514774799347, 85.0810369849205, 39.49373938143253, 65.25000751018524, 70.17621517181396, 73.80829587578773, 84.22275424003601, 80.84089770913124, 79.6477085351944, 75.94782426953316, 79.29118126630783, 76.05120912194252, 74.78371873497963, 64.69082951545715, 64.27676573395729, 64.68129202723503, 70.652686804533, 67.31338798999786, 67.4380972981453, 65.84766983985901, 65.53145840764046, 69.041056483984, 78.75916421413422, 84.52859222888947, 79.80087831616402, 84.81596320867538, 83.11424732208252, 76.84595927596092, 77.22324103116989, 71.77197754383087, 71.9114376604557, 70.19248589873314, 69.61205184459686, 67.66823574900627, 72.5783322751522, 73.29391747713089, 70.92946395277977, 70.99862024188042, 76.60033285617828, 84.84308615326881, 95.39036259055138, 80.41438579559326, 26.03485208004713, 1.2753677205182612, 0.6131590262521058, 0.6102211901452392, 0.1522342296084389, 1.2668279162608087, 0.3352273040218279, 0.13522263150662184, 0.35657651780638844, 0.21613550459733233, 0.02299138250236865, 0.3269535448634997, 21.078922413289547, 26.508772149682045, 40.728954300284386, 27.971653752028942, 24.737491495907307, 25.79332184046507, 45.47818645834923, 75.07583186030388, 76.61854907870293, 79.0077392756939, 81.68666392564774, 6.831338983029127, 0.35557429189793766, 0.152910073811654, 0.12535896938061342, 0.05672287385095842, 0.03359270602231845, 0.023364495391433593, 0.10164628241909668, 0.05399353300163057, 0.08522901101969182, 0.031546296886517666, 0.05025782505981624, 0.037904023702139966, 0.023933605771162547, 0.06660278158960864, 0.07560407553683035, 0.03790557479078416, 0.053363052575150505, 0.09292122325859964, 0.013525881677196594, 0.06180572454468347, 0.05969209538307041, 0.02458450082485797, 0.0712837593164295, 0.04951536568114534, 0.10181124700466171, 0.07237179233925417, 0.14393997233128175, 0.18621165014337748, 0.16700400738045573, 0.10883162263780832, 0.18033979256870225, 0.13893029739847407, 0.1994371076580137, 0.14229418564355, 0.25128301000222564, 0.12470248038880527, 0.07878025237005204, 0.09192447440000251, 0.19708960549905896, 0.17078449280234054, 0.197563748806715, 0.17100681056035683, 0.12964266061317176, 0.23767515347572044, 0.8222867420408875, 98.18602457642555, 142.82910704612732, 112.67642542719841, 95.73745116591454, 52.677147164940834, 51.12155623733997, 98.51694881916046, 159.6380826830864, 108.3999752998352, 94.36147660017014, 22.77628943324089, 0.5726873385719955, 0.5762633623089641, 0.6141910864971578, 0.8787050459068269, 1.3200207869522274, 0.563930292846635, 0.9732942015398294, 1.8840835383161902, 0.2943983761360869, 1.1651684087701142, 40.9598109126091, 106.8525843322277, 106.48107066750526, 107.55164042115211, 101.79835394024849, 104.72978264093399, 106.34820699691772, 100.98002225160599, 90.3481775522232, 74.15843948721886, 71.39179274439812, 75.63860446214676, 79.03335750102997, 86.28333047032356, 91.12360194325447, 95.7151311635971, 99.6499416232109, 92.02568113803864, 84.08131062984467, 78.15164521336555, 77.9260665178299, 78.70089054107666, 72.51717075705528, 74.57602187991142, 67.69902929663658, 68.99394661188126, 68.63285958766937, 68.78004848957062, 72.370126247406, 70.51720887422562, 72.14599907398224, 68.49949434399605, 69.45483148097992, 80.60508236289024, 86.34921133518219, 82.73862227797508, 84.42757084965706, 75.80335602164268, 71.80333346128464, 71.70808017253876, 76.80693536996841, 76.7516179382801, 70.8201514184475, 76.21941089630127, 81.57990485429764, 91.02687433362007, 43.87317158281803, 66.39678597450256, 72.87128135561943, 76.6881537437439, 88.64929631352425, 83.97499233484268, 82.99785196781158, 80.55088967084885, 82.89474070072174, 80.70200756192207, 79.05318483710289, 68.87705728411674, 68.42002540826797, 71.2373386323452, 73.3747011423111, 69.2041665315628, 69.96458172798157, 69.45195883512497, 67.15264141559601, 71.11996293067932, 83.69260668754578, 87.24741473793983, 81.47480249404907, 87.51903176307678, 87.53040835261345, 82.2675995528698, 82.28654533624649, 77.40400493144989, 76.17443650960922, 74.93970796465874, 75.12924179434776, 71.90129220485687, 76.6525648534298, 78.44996720552444, 75.99003240466118, 77.02544644474983, 80.4943411052227, 92.28784427046776, 102.28424146771431, 84.04502257704735, 25.84494587033987, 1.776480081025511, 1.4517053333111107, 0.9678163204807788, 0.2731210022466257, 1.4002488506957889, 1.0495237517170608, 0.2668536244891584, 0.520102969603613, 0.3479252429679036, 0.1894367122440599, 1.395588875748217, 31.74819130450487, 43.101554587483406, 55.98323196172714, 53.14141005277634, 55.38746193051338, 28.887066431343555, 54.8113102465868, 84.47281882166862, 91.61810740828514, 92.20699220895767, 100.95895618200302, 6.794055383652449, 0.6081170530524105, 0.3079506754875183, 0.20233896444551647, 0.14869599603116512, 0.16123493725899607, 0.07698415851336904, 0.14996925427112728, 0.15299438178772107, 0.13106609985698014, 0.07159190645324998, 0.16712641721824184, 0.11495497921714559, 0.11302005179459229, 0.1326602924382314, 0.13593562762252986, 0.10595102095976472, 0.13501753157470375, 0.16705920832464471, 0.14787031221203506, 0.12439111975254491, 0.18965834722621366, 0.15906225540675223, 0.20667065778980032, 0.11888484412338585], [0.029557044254033826, 0.04972921553417109, 0.022570766595890746, 0.015155332766880747, 0.03485342938802205, 0.049510126118548214, 0.025696351221995428, 0.015012143721833127, 0.020472813448577654, 0.04235107648128178, 0.06557828382938169, 0.05753034165536519, 0.041895000758813694, 0.06952934447326697, 0.08145101179252379, 0.020829914501518942, 0.08781862401519902, 0.04542090726317838, 0.02423709778668126, 0.24002975056646392, 4.0181423630565405, 100.81087052822113, 94.76768240332603, 100.84691539406776, 72.35059529542923, 38.70870530605316, 47.482624500989914, 71.3200069963932, 73.79743605852127, 58.049048110842705, 29.127323739230633, 0.22950639337068424, 0.09345476064481772, 0.10889336190302856, 0.14980265696067363, 0.05048626924690325, 0.7982434728182852, 0.40071005118079484, 0.783504182472825, 0.44520990864839405, 0.37718536506872624, 45.70104829967022, 112.54801511764526, 100.31548351049423, 99.62048560380936, 93.10419246554375, 95.34902080893517, 99.18312147259712, 94.91294100880623, 90.84595084190369, 85.20989567041397, 73.88242989778519, 62.095249593257904, 64.22993704676628, 61.467375084757805, 69.01691257953644, 80.47933951020241, 86.0745620727539, 88.73288422822952, 84.87967059016228, 78.15590098500252, 74.26826119422913, 74.556794911623, 74.05509263277054, 70.55109545588493, 66.23127445578575, 59.719605669379234, 62.25802145898342, 60.68981520831585, 62.151786759495735, 60.45425444841385, 61.67192190885544, 62.55834214389324, 60.18145188689232, 66.08429074287415, 71.04923352599144, 73.28925132751465, 77.48437821865082, 71.24875321984291, 69.31176915764809, 68.61285746097565, 77.48357266187668, 79.2734058201313, 78.84225815534592, 72.37477719783783, 73.29846203327179, 75.81615373492241, 84.86191034317017, 34.75869946181774, 61.059094592928886, 63.916423469781876, 69.23656359314919, 77.25207388401031, 75.35342216491699, 77.59208723902702, 74.17901918292046, 74.68443006277084, 69.36226844787598, 71.4209371805191, 64.2452122271061, 63.580791279673576, 60.59831611812115, 67.59474769234657, 69.11745518445969, 62.82618597149849, 62.95706234872341, 61.422818675637245, 65.94023287296295, 79.05658945441246, 80.25232449173927, 77.56101250648499, 78.5828460752964, 75.41207581758499, 71.12756252288818, 68.04845854640007, 67.57102936506271, 69.65886533260345, 65.25197580456734, 63.23704272508621, 63.02588425576687, 65.58673784136772, 66.60920217633247, 69.99776914715767, 63.03692266345024, 69.86894086003304, 78.00900086760521, 82.09705710411072, 89.18908014893532, 53.44380542635918, 11.654902752488852, 0.36145067657344043, 0.5722694203723222, 1.5042574633844197, 0.2818765339907259, 0.10709277063142508, 0.10917485851678066, 0.08330616576131433, 0.15469652717001736, 0.0279744625731837, 0.1287103004870005, 0.9524542198050767, 26.808243580162525, 43.43177206814289, 33.95389124751091, 31.909414753317833, 39.61324296891689, 23.60116057097912, 32.602839544415474, 51.713176891207695, 65.46934694051743, 84.49960738420486, 37.90649235248566, 0.19925455417251214, 0.11689398845192045, 0.1592352203442715, 0.06547307697474025, 0.02101453301293077, 0.07778356288326904, 0.013602452763734618, 0.14351317804539576, 0.021906939618929755, 0.01731530348479282, 0.016869185528776143, 0.028904826322104782, 0.07756137129035778, 0.011891332032973878, 0.036725270547322, 0.04197278896754142, 0.0475867761997506, 0.05417318840045482, 0.004743708223031717, 0.07876559495343827, 0.016600965936959255, 0.018548376283433754, 0.011267670088273007, 0.0645835387695115, 0.06158462761959527, 0.04289959411835298, 0.014609438621846493, 0.044124004198238254, 0.04724579273897689, 0.0374949964316329, 0.00979649868895649, 0.014083103778830264, 0.09512500109849498, 0.043303648999426514, 0.0360695237031905, 0.05268986526061781, 0.08196711612981744, 0.016182363106054254, 0.13146616198355332, 0.020332888925622683, 0.09219099447363988, 0.07489804076612927, 0.17950898793060333, 0.46839175221975893, 8.68470948189497, 123.84758278727531, 104.82657104730606, 113.07133063673973, 80.32580494880676, 50.4808384180069, 34.29100915789604, 59.17042873799801, 81.51634946465492, 60.17612837255001, 32.6995063573122, 0.476770480745472, 0.07863597144023515, 0.08413318544626236, 0.324878262472339, 1.0938025382347405, 0.6748163583688438, 2.6628650492057204, 1.696094444487244, 0.5094431759789586, 1.216299890074879, 52.79101945459843, 119.13179263472557, 103.36969122290611, 102.43811041116714, 95.00251740217209, 99.56890717148781, 102.45742097496986, 96.62387520074844, 95.28763890266418, 88.42697024345398, 77.2154438495636, 65.97370147705078, 68.09202700853348, 64.51606929302216, 72.17035576701164, 84.4595043361187, 88.45752820372581, 90.19474938511848, 89.458067715168, 82.04572185873985, 77.64595314860344, 79.00227516889572, 78.32930848002434, 75.92852130532265, 68.71086180210114, 65.5434961616993, 65.03328993916512, 63.718936666846275, 64.3726421892643, 64.9463278055191, 66.90493270754814, 65.51106870174408, 62.892803996801376, 69.58535447716713, 74.0245270729065, 75.77239528298378, 81.1193011701107, 75.87399423122406, 71.65180519223213, 72.02157095074654, 80.69598108530045, 82.54162564873695, 81.6257531940937, 76.6692915558815, 76.30071133375168, 79.10995379090309, 85.84051743149757, 38.548661693930626, 62.506516724824905, 69.34212192893028, 71.138726323843, 81.14303469657898, 78.78228977322578, 79.84844416379929, 76.59915491938591, 77.34592124819756, 75.09255856275558, 74.21162143349648, 68.16290080547333, 66.24525010585785, 62.328921854496, 69.62465196847916, 72.1039505302906, 64.91551145911217, 64.78079348802567, 63.64586278796196, 69.9910207092762, 83.26895982027054, 80.57624951004982, 80.3163130581379, 81.22010976076126, 79.2040291428566, 75.96932351589203, 70.48413544893265, 72.83778235316277, 72.38708853721619, 67.2775787115097, 66.48335292935371, 65.5791762471199, 70.24711936712265, 69.33283522725105, 72.98494845628738, 66.16733908653259, 71.17063701152802, 81.13253965973854, 85.26244685053825, 92.37923696637154, 62.36542649567127, 15.977808237075806, 0.7651562138926238, 0.7541193498764187, 0.8893564087338746, 0.5484434519894421, 0.7846464368049055, 0.5631828017067164, 0.30713535204995424, 0.5696319462731481, 0.0883846303622704, 0.47327048261649907, 1.613084098789841, 29.64851137250662, 44.64532434940338, 38.80835875868797, 19.253076687455177, 34.97703194618225, 36.69249549508095, 45.58165870606899, 58.77773120999336, 76.88194334506989, 96.54950559139252, 57.97367915511131, 0.2311481724609621, 0.057340971543453634, 0.08184128499124199, 0.09621197285014205, 0.0687724725867156, 0.04851289857469965, 0.02938347817689646, 0.12838764436310157, 0.03874036105116829, 0.032547313094255514, 0.037919330497970805, 0.04032034150441177, 0.07097167879692279, 0.015845871494093444, 0.04348381276940927, 0.04597803752403706, 0.021066856279503554, 0.03777667116082739, 0.022435825594584458, 0.03212727606296539, 0.036606471257982776, 0.0431294743611943, 0.028209654738020618, 0.09942487857188098, 0.1471104717347771, 0.14098741201451048, 0.1280928187770769, 0.13996032415889204, 0.12602424540091306, 0.1261091767810285, 0.1544430392095819, 0.10291433078236878, 0.1340696308761835, 0.14644391922047362, 0.20846233586780727, 0.23959317477419972, 0.17964321275940165, 0.17077088181395084, 0.27968758426140994, 0.06957331672310829, 0.2667734428541735, 0.2006431866902858, 0.3512248018523678, 0.9234451514203101, 11.703478395938873, 141.06034755706787, 117.87473648786545, 130.19236832857132, 97.0011493563652, 57.26018384099007, 65.22365212440491, 85.57032153010368, 90.10778725147247, 85.10644242167473, 47.00412377715111, 1.277099121361971, 0.17851339682238176, 0.23219035560032353, 0.4896940028993413, 1.8136973027139902, 2.5299025839194655, 2.7207190822809935, 3.127700756303966, 4.336427533999085, 1.7330175382085145, 53.92580196261406, 124.0358018875122, 110.65853610634804, 110.14817789196968, 102.48016655445099, 103.77756893634796, 107.59405374526978, 102.8752313554287, 100.93279078602791, 93.67685973644257, 83.19644451141357, 70.25749281048775, 71.70932650566101, 69.1457636654377, 77.08378091454506, 86.65096834301949, 94.45052102208138, 95.56345850229263, 94.14896160364151, 85.49773782491684, 82.71819457411766, 81.71337649226189, 81.77196934819221, 80.70937156677246, 72.36630365252495, 68.1573835015297, 66.89098745584488, 68.15188899636269, 67.6975017786026, 68.08546096086502, 69.85148459672928, 70.3835928440094, 67.40189284086227, 71.68763726949692, 77.76873216032982, 80.46478629112244, 85.05858018994331, 79.20887008309364, 73.95583435893059, 75.74684545397758, 87.18237742781639, 86.74466371536255, 85.7327476143837, 81.25331997871399, 82.12119340896606, 84.20402884483337, 93.74649479985237, 43.994084894657135, 66.21197149157524, 70.75629964470863, 73.8201892375946, 84.30425226688385, 82.98503145575523, 83.87608364224434, 81.43029928207397, 83.11135187745094, 78.34130823612213, 79.05940890312195, 70.12117892503738, 67.94627442955971, 65.33205270767212, 72.97274351119995, 74.62028950452805, 68.79918426275253, 69.36613664031029, 67.60912612080574, 73.9496710896492, 89.29518565535545, 84.74928438663483, 83.52929145097733, 88.52172195911407, 83.75890552997589, 80.66067337989807, 74.96855601668358, 74.95111495256424, 77.79210850596428, 72.91991874575615, 70.34544289112091, 71.5908032655716, 74.83687788248062, 74.13038179278374, 79.1471765935421, 69.95682254433632, 75.70092871785164, 83.00894737243652, 90.84711357951164, 93.27981144189835, 64.92280706763268, 16.552901677787304, 1.2848148448392749, 1.8164338683709502, 3.879915992729366, 1.0139445983804762, 0.5372412968426943, 0.7918355916626751, 0.5712612869683653, 0.778808465693146, 0.26246681925840676, 0.5976191069930792, 3.684023441746831, 45.874356999993324, 61.27051144838333, 52.97763504087925, 45.540955290198326, 56.42047829926014, 39.7993303835392, 49.87232767045498, 72.87163853645325, 87.55364030599594, 112.5430677831173, 61.74645110964775, 0.7589199172798544, 0.2283454962889664, 0.20608934835763648, 0.1951059783459641, 0.12212287896545604, 0.12548166123451665, 0.1434283357230015, 0.40609804331324995, 0.1642907748464495, 0.12463723076507449, 0.24800350394798443, 0.16465113207232207, 0.12168215456767939, 0.11418927577324212, 0.0813275332620833, 0.17648804612690583, 0.25845040509011596, 0.10906030060141347, 0.12437169774784707, 0.12440679391147569, 0.14465485350228846, 0.2278809415292926, 0.1172901839890983, 0.19431314198300242], [0.04331631374952849, 0.04847958356549498, 0.038108106891741045, 0.06509866347187199, 0.037538783144555055, 0.0271226273252978, 0.07846334789064713, 0.03805384105362464, 0.08849959645885974, 0.010032727077486925, 0.04168259438301902, 0.04673055300372653, 0.06477798888226971, 0.04208596277749166, 0.04440715209057089, 0.0321753449679818, 0.06785027246223763, 0.08806642712443136, 0.1579386883531697, 0.21861865650862455, 23.117577619850636, 107.04621434211731, 83.76557797193527, 84.05899062752724, 46.76764726638794, 38.53970177471638, 68.25506865978241, 60.236020758748055, 57.29054041206837, 41.468185633420944, 4.928973438218236, 0.1885204270365648, 0.1979793218197301, 0.17249215976335108, 0.28482188063208014, 0.3605822747340426, 0.48375601996667683, 1.2330558034591377, 1.3335967459715903, 0.6933232059236616, 31.877401471138, 111.92447617650032, 96.59726142883301, 97.36983597278595, 84.71584618091583, 86.192636936903, 88.05247753858566, 91.67485356330872, 92.92292699217796, 90.31512692570686, 81.23913154006004, 70.42418986558914, 62.81900055706501, 62.63226717710495, 61.89716622233391, 61.295141726732254, 73.42045828700066, 83.07142361998558, 90.55170983076096, 87.21504807472229, 80.90506866574287, 80.33205181360245, 78.65894839167595, 75.06629437208176, 72.02946692705154, 66.24629124999046, 63.03335465490818, 60.622676610946655, 57.77708150446415, 59.0424820035696, 60.482745319604874, 60.83155520260334, 60.84266200661659, 63.00050541758537, 70.37934467196465, 72.14589267969131, 70.28668284416199, 74.99118000268936, 68.4326559305191, 62.75412283837795, 69.27092894911766, 78.50743532180786, 76.33214324712753, 82.22792208194733, 80.10552316904068, 75.98681017756462, 81.43201678991318, 74.09831151366234, 27.858457826077938, 65.0469996035099, 68.61474215984344, 68.53987097740173, 73.32404986023903, 77.2663839161396, 76.35802745819092, 76.63880199193954, 73.89036387205124, 72.7230817079544, 70.2126932144165, 68.30052182078362, 66.02789416909218, 61.07707902789116, 59.876651242375374, 67.38352462649345, 62.06369988620281, 62.22780928015709, 58.481263518333435, 63.0473493039608, 79.12623971700668, 77.76431679725647, 78.39039400219917, 76.67766630649567, 70.18667981028557, 68.4960213303566, 65.79055890440941, 68.11199113726616, 66.56766280531883, 65.66668555140495, 63.4591294080019, 63.59387017786503, 65.6711845099926, 64.19228866696358, 64.89252269268036, 62.44147181510925, 70.53144291043282, 78.06846767663956, 84.46281015872955, 76.26215860247612, 83.51401627063751, 51.97976678609848, 8.214660454541445, 0.2614811877720058, 0.5532811861485243, 0.4875592596363276, 0.7547179365064949, 0.3766428551170975, 0.4254134459188208, 0.1133096675039269, 0.06349392497213557, 0.09994948792154901, 0.18638820707565174, 8.368990123271942, 28.757616877555847, 42.18500956892967, 37.76730202138424, 33.84382635354996, 17.220257967710495, 25.54058600217104, 53.3916000276804, 63.05524528026581, 74.46638256311417, 75.67823633551598, 3.556949235498905, 0.1088124603847973, 0.029125461260264274, 0.07710023040999658, 0.008922205124690663, 0.05754047197115142, 0.02966382075101137, 0.034988218249054626, 0.04053637327160686, 0.05003882841265295, 0.06709563444019295, 0.10132980838534422, 0.03855608207231853, 0.04177603077550884, 0.012134725857322337, 0.0457063149951864, 0.02971582860482158, 0.023698257755313534, 0.0624703623179812, 0.10368265400757082, 0.012143412695877487, 0.014298750556918094, 0.05509475027793087, 0.04586404735164251, 0.02025217479967978, 0.05376335589971859, 0.05456000319099985, 0.0366358565952396, 0.004484245509956963, 0.014666426286567003, 0.08190932509023696, 0.12579790520248935, 0.0124014017819718, 0.04623217486368958, 0.05313440058671404, 0.09681717201601714, 0.051458007728797384, 0.019228766141168308, 0.05896111702895723, 0.07748990989057347, 0.054216240387177095, 0.03975559309765231, 0.1309812130057253, 0.3634139837231487, 37.05353692173958, 123.24518591165543, 89.99920427799225, 99.0803749859333, 64.6895831823349, 58.17514434456825, 45.83457313477993, 60.67222975194454, 60.10944955050945, 45.7883258163929, 6.6215812135487795, 0.2099116612225771, 0.07423916948027909, 0.5816738563589752, 0.18139334541046992, 0.9682773426175117, 2.0741688134148717, 2.2286986839026213, 1.0609863116405904, 1.3054659054614604, 40.12491211295128, 113.0458416044712, 97.54400342702866, 102.74061217904091, 86.80024713277817, 90.07893159985542, 90.90407252311707, 95.82910984754562, 93.94801318645477, 92.47825965285301, 86.02059736847878, 75.02641171216965, 67.79486015439034, 64.8012363910675, 66.96930885314941, 66.04509204626083, 77.25616246461868, 87.21828550100327, 92.13183224201202, 90.37379577755928, 84.42488819360733, 83.48246276378632, 83.55846628546715, 80.07473722100258, 75.3587418794632, 71.25185385346413, 66.44201874732971, 62.76257358491421, 62.51080669462681, 61.07757680118084, 62.72422984242439, 62.49417118728161, 63.80880564451218, 65.07839351892471, 70.58689713478088, 75.25102525949478, 72.81559154391289, 77.63041958212852, 72.80614525079727, 66.9160509109497, 73.78269284963608, 81.39708146452904, 79.86417531967163, 84.69357177615166, 82.88464844226837, 81.24794706702232, 83.38403284549713, 77.70842179656029, 32.37365864217281, 65.33513054251671, 71.68519020080566, 69.77059453725815, 76.58882707357407, 80.59301421046257, 80.31292364001274, 80.2350278198719, 76.635252982378, 74.97455209493637, 73.265031427145, 71.26162692904472, 68.52141916751862, 63.04772548377514, 60.77148802578449, 71.348817050457, 64.793431609869, 66.23307555913925, 61.11709088087082, 65.86607605218887, 82.06137701869011, 81.62357971072197, 81.4329819381237, 80.35420462489128, 72.51809790730476, 73.32177758216858, 71.83522135019302, 72.55827695131302, 67.69807934761047, 69.76864904165268, 67.04769864678383, 66.93577945232391, 68.92241925001144, 69.00818064808846, 67.75474190711975, 66.8970063328743, 73.77590641379356, 82.64686480164528, 87.10439801216125, 82.66642615199089, 84.56184044480324, 62.082413882017136, 12.431960105895996, 0.3562806383706629, 0.675020597409457, 2.512883059680462, 3.1130005326122046, 1.165380603633821, 0.5568444449454546, 0.36024067900143564, 0.23217270732857287, 0.15312391624320298, 0.3414257214171812, 8.24665853753686, 33.177231922745705, 46.215187311172485, 36.43007017672062, 32.152043133974075, 28.104238137602806, 31.928417533636093, 61.71033024787903, 71.99627190828323, 81.28681138157845, 94.74587917327881, 9.397465735673904, 0.21753954410087317, 0.1062590345100034, 0.05242471816018224, 0.028182531095808372, 0.03253489325288683, 0.06972725299419835, 0.008354379588126903, 0.02305971946043428, 0.07046627622912638, 0.021808456622238737, 0.07887394109275192, 0.012302238792472053, 0.05567398911807686, 0.042288079275749624, 0.0032868883363335044, 0.020005234437121544, 0.033970603908528574, 0.05697731176041998, 0.09319694596342742, 0.0260410843839054, 0.020011273663840257, 0.04454661648196634, 0.008610835211584345, 0.15334093506680802, 0.13738348352489993, 0.18497322831535712, 0.23255860927747563, 0.1722584426170215, 0.10137947290786542, 0.24725326686166227, 0.1642621131031774, 0.13606842752778903, 0.19414617359871045, 0.1878769404720515, 0.16812137007946149, 0.26328205363824964, 0.13576738274423406, 0.1967666673590429, 0.1407893031137064, 0.15932969574350864, 0.2005664783064276, 0.19095556199317798, 0.5324526038020849, 44.13626566529274, 139.58379238843918, 104.4542746245861, 113.37629467248917, 69.28831681609154, 57.67083540558815, 84.38928410410881, 77.46860146522522, 77.7645143866539, 70.48475861549377, 9.565585814416409, 0.34078910714015365, 0.45569829584565014, 0.7546979282051325, 1.363404009025544, 1.5697494428604841, 2.2088397620245814, 3.279402391053736, 6.5776745695620775, 4.260943159461021, 41.0433342307806, 118.67770180106163, 100.88991388678551, 108.94627198576927, 90.52435129880905, 94.94306579232216, 96.98469623923302, 102.80150771141052, 97.48553216457367, 98.20174053311348, 90.89610055088997, 79.74531009793282, 70.75436174869537, 70.25731042027473, 70.7480388879776, 68.57130289077759, 81.69325277209282, 92.51859068870544, 98.05705949664116, 96.05524331331253, 88.76151949167252, 87.61385187506676, 85.83053156733513, 83.01932841539383, 80.68142786622047, 74.03698280453682, 70.80182120203972, 66.19098141789436, 65.21173596382141, 64.89818438887596, 66.96494668722153, 66.56232789158821, 67.43622779846191, 69.0945728123188, 75.38322016596794, 78.52337926626205, 75.40154278278351, 81.00827112793922, 75.95193564891815, 70.61856463551521, 77.82808497548103, 84.74473983049393, 82.25699812173843, 87.37470790743828, 87.16545313596725, 81.84099644422531, 87.42040425539017, 83.97735580801964, 36.93430691957474, 69.06942576169968, 75.27011543512344, 72.17742338776588, 80.34549549221992, 83.29710111021996, 82.7442991733551, 83.65787655115128, 82.15374246239662, 80.24087190628052, 77.75561526417732, 75.13777613639832, 72.21987470984459, 66.3208432495594, 62.87255868315697, 75.34304112195969, 67.65772551298141, 68.65916937589645, 64.70419719815254, 68.93362864851952, 86.83782711625099, 85.01115873456001, 86.77905187010765, 83.49295780062675, 77.63171911239624, 77.82198250293732, 75.66098526120186, 77.27690935134888, 74.96193677186966, 71.80520296096802, 70.45011207461357, 70.44166132807732, 72.86333218216896, 73.33552524447441, 72.14532271027565, 70.97375437617302, 78.10625284910202, 87.002654671669, 92.00363472104073, 83.39828968048096, 89.48927164077759, 65.11401280760765, 12.340380270034075, 0.7559488923288882, 2.614901172928512, 3.3628630125895143, 2.8063966473564506, 1.0419682133942842, 1.29375244025141, 0.7960894634015858, 0.3809735242975876, 0.5051712552085519, 0.5283454991877079, 15.486802384257317, 46.63953334093094, 61.62434086203575, 57.97401733696461, 48.57254661619663, 27.34043162316084, 37.934694439172745, 71.82325959205627, 86.9434006512165, 94.36492681503296, 109.8823593556881, 9.688850250095129, 0.40565952309407294, 0.260521323652938, 0.11050675384467468, 0.1266427809605375, 0.2839777321787551, 0.17820452980231494, 0.08526074525434524, 0.08177153053111397, 0.1480207752319984, 0.11156225853483193, 0.19424394413363189, 0.23087256849976256, 0.22073964035371318, 0.1599974653800018, 0.14532685338053852, 0.20719451014883816, 0.15075377858011052, 0.2066094899782911, 0.195102549623698, 0.10307738804840483, 0.07490938078262843, 0.11982047712081112, 0.08206815953599289], [0.07619032767252065, 0.03271451154432725, 0.045110941864550114, 0.01978261239855783, 0.026656855443434324, 0.027670844392559957, 0.07539210331742652, 0.009612297635612777, 0.020507655426627025, 0.0811098465055693, 0.037732884447905235, 0.00958080552663887, 0.020464623848965857, 0.02970004683447769, 0.1017311766918283, 0.040897198050515726, 0.008537932189938147, 0.009327476200269302, 0.020774051190528553, 0.19572874414734542, 52.89477288722992, 100.65881788730621, 84.81353133916855, 79.64183405041695, 39.67372052371502, 38.24855379760265, 46.74991361796856, 59.61484909057617, 48.61747160553932, 23.055344559252262, 0.1951151216053404, 0.027699498714355286, 0.07408282122923993, 0.22098431159975007, 0.5160208605229855, 0.6256427220068872, 0.8032389578875154, 2.553467731922865, 1.280306268017739, 14.061141684651375, 106.48860946297646, 90.68443670868874, 99.10023272037506, 86.82198956608772, 81.54906570911407, 74.2004044353962, 85.21998032927513, 83.47253769636154, 84.98255386948586, 82.82083466649055, 81.99665129184723, 74.59800750017166, 66.48610398173332, 60.62874108552933, 61.715326979756355, 60.79132676124573, 68.76971304416656, 81.48119375109673, 85.97376108169556, 85.09958758950233, 83.16246673464775, 80.27662798762321, 76.78731322288513, 74.55389186739922, 76.22175917029381, 71.0881282389164, 65.32256841659546, 62.427169382572174, 55.22577300667763, 56.96716256439686, 58.95637862384319, 60.16944073140621, 61.52540937066078, 62.28183098137379, 66.6807447373867, 74.93131041526794, 71.71624213457108, 69.33697700500488, 62.36642964184284, 56.5958084911108, 64.22779396176338, 73.96869286894798, 73.20092886686325, 77.48139157891273, 70.20986616611481, 74.12767633795738, 71.85233563184738, 64.19063955545425, 29.86524224281311, 57.243726924061775, 67.99298912286758, 68.05830761790276, 68.18759188055992, 74.09811392426491, 76.82347968220711, 74.3802259862423, 72.45572045445442, 73.23820486664772, 69.13694813847542, 70.07661491632462, 69.34649169445038, 73.80503565073013, 62.8902505338192, 63.44212532043457, 63.92786845564842, 60.057099759578705, 62.63741210103035, 59.145574271678925, 70.67822143435478, 76.64418250322342, 79.67850968241692, 72.15903237462044, 66.06190234422684, 66.81877613067627, 67.6980109512806, 67.10498437285423, 64.59743812680244, 64.98992666602135, 62.850037291646004, 61.11883878707886, 60.38258649408817, 63.733995258808136, 62.99073614180088, 58.95190246403217, 72.02594071626663, 79.5845103263855, 75.86906209588051, 74.6037907898426, 77.0922164618969, 84.22824874520302, 51.50050990283489, 3.8595913583412766, 0.0699521682690829, 1.3197520701214671, 1.3507306203246117, 0.15717696282081306, 0.3618513175752014, 0.46435904048848897, 0.23280178138520569, 0.1263547534472309, 0.11400207644328475, 0.3514387778704986, 17.860286124050617, 34.06414233148098, 54.48441758751869, 44.91626501083374, 35.703492164611816, 32.94771283864975, 41.67405478656292, 58.43701109290123, 66.93495109677315, 86.20581462979317, 36.64596699178219, 0.5246002657804638, 0.2020155661739409, 0.12209087013616227, 0.03311395397759043, 0.05303768390149344, 0.05190491792745888, 0.06932854899787344, 0.0405193669575965, 0.01978303727810271, 0.017219028377439827, 0.027702541519829538, 0.016885950644791592, 0.023753356654196978, 0.02372697515966138, 0.03467252347036265, 0.024930744257289916, 0.04326703885453753, 0.09532990807201713, 0.013516773669834947, 0.008412453571509104, 0.04720016921055503, 0.040343767395825125, 0.07630720851011574, 0.05899577161471825, 0.03716238439665176, 0.03334002700285055, 0.01598774229933042, 0.034258223240613006, 0.06261729271500371, 0.13250852323835716, 0.1455670123687014, 0.027936631595366634, 0.057781996511039324, 0.01870955962658627, 0.033668861506157555, 0.05184417685086373, 0.05879586300579831, 0.11965338999289088, 0.045676031659240834, 0.020193732525513042, 0.02846990551915951, 0.03679310655570589, 0.2861514827236533, 70.87908625602722, 113.8000175356865, 95.35991862416267, 94.102224111557, 53.02538327872753, 38.70123490691185, 43.24101470410824, 68.9198885858059, 54.300275668501854, 26.566952727735043, 0.14138040889520198, 0.06545417447341606, 0.5333216290455312, 0.5701223574578762, 1.1243206006474793, 2.3201616760343313, 2.224775394424796, 1.896148247178644, 1.1695265374146402, 21.047593094408512, 111.45478338003159, 95.9425413608551, 101.95559710264206, 91.84172540903091, 86.80492088198662, 79.35811087489128, 86.89540922641754, 89.65814217925072, 89.14135470986366, 87.21304178237915, 85.54096430540085, 77.114088088274, 71.62931799888611, 64.97300237417221, 65.78696429729462, 62.78347246348858, 71.84298053383827, 84.81608480215073, 89.02818158268929, 87.09257304668427, 85.79197883605957, 83.5331292450428, 80.91884672641754, 79.40155774354935, 80.32450541853905, 73.42706993222237, 68.42872694134712, 65.17174690961838, 59.49674382805824, 59.51061688363552, 61.29087835550308, 63.47531273961067, 65.7472412288189, 65.90411201119423, 69.78947952389717, 76.19819283485413, 73.14195603132248, 70.7443454861641, 65.1117405295372, 59.660644233226776, 67.52901121973991, 76.36603742837906, 76.01343914866447, 78.59213277697563, 72.60763630270958, 76.4802972972393, 72.9346315562725, 70.60651928186417, 33.79354365170002, 61.33959174156189, 71.87951937317848, 71.29261806607246, 69.70110386610031, 76.08801394701004, 76.49849072098732, 78.59050646424294, 76.22838601469994, 75.69297194480896, 71.60820633172989, 71.66400253772736, 74.30052906274796, 77.39674732089043, 65.43505758047104, 62.8011567145586, 67.30240657925606, 62.30895012617111, 65.38363113999367, 61.841947585344315, 74.48285847902298, 78.10207307338715, 81.16385757923126, 76.00281491875648, 69.7877924144268, 70.06010860204697, 71.67276486754417, 71.09423831105232, 68.66431429982185, 69.01403233408928, 66.1965063214302, 64.93213936686516, 64.58922296762466, 66.43793016672134, 65.0475999712944, 61.65187418460846, 75.33185452222824, 80.95945134758949, 79.28879499435425, 78.61673265695572, 80.56970626115799, 86.63981214165688, 61.18532381951809, 6.335065187886357, 0.19394592731259763, 1.362143901642412, 1.1407059151679277, 0.46843138290569186, 0.6075668544508517, 0.3648579359287396, 0.4943317431025207, 0.4026121163042262, 0.13573768199421465, 0.25009405973833054, 19.228353314101696, 39.57913979887962, 44.170099049806595, 30.264912396669388, 32.21050679683685, 45.07257342338562, 49.447012692689896, 67.36055105924606, 76.36938124895096, 98.58245730400085, 53.66008222103119, 0.38455465401057154, 0.1344330605934374, 0.032818245235830545, 0.10543217067606747, 0.03205826003977563, 0.03148047951981425, 0.009607689826225396, 0.02511861894163303, 0.03425841990974732, 0.01760240145813441, 0.06030040043697227, 0.030324395265779458, 0.01787520381185459, 0.021452014225360472, 0.023233033207361586, 0.0417329713673098, 0.07650266052223742, 0.07661107345484197, 0.049672337336232886, 0.012941446875629481, 0.06940398830920458, 0.10162021077121608, 0.03491847121040337, 0.14498990349238738, 0.10432173221488483, 0.07037294373731129, 0.09116605142480694, 0.11039492703275755, 0.10309023462468758, 0.2890373981790617, 0.22310630476567894, 0.14825484860921279, 0.15158308407990262, 0.16509702923940495, 0.10223840494290926, 0.09452216196223162, 0.2003220742335543, 0.1524810679256916, 0.13923180231358856, 0.10839509137440473, 0.1057783528813161, 0.18985924660228193, 0.30792306759394705, 83.37643325328827, 131.192307472229, 106.29782930016518, 107.33176901936531, 59.62391920387745, 58.4505345672369, 63.1134619563818, 79.45316657423973, 71.12641498446465, 37.268282398581505, 0.457601934322156, 0.3317809186410159, 0.905273457756266, 1.8123882729560137, 2.195073338225484, 3.538667941465974, 2.6487143710255623, 10.74516411870718, 6.336525734513998, 18.7470730394125, 115.90055242180824, 97.81914666295052, 108.54625225067139, 98.53849366307259, 91.90382167696953, 84.59959521889687, 94.91455972194672, 93.47490057349205, 93.99130046367645, 90.615204423666, 89.31016445159912, 82.42678821086884, 75.11068359017372, 68.84124800562859, 68.94233778119087, 66.7097295820713, 76.64590761065483, 88.77927973866463, 94.91520568728447, 89.17348578572273, 91.29640147089958, 88.06203782558441, 87.76179313659668, 83.01738291978836, 84.76827576756477, 76.848254352808, 72.33482614159584, 69.87684443593025, 62.63800486922264, 62.96649344265461, 65.2860675752163, 66.83558642864227, 66.66546195745468, 68.57977643609047, 73.15682843327522, 80.05946204066277, 77.44718581438065, 73.03895115852356, 68.04558590054512, 62.50064603984356, 73.37733060121536, 81.41397535800934, 81.89553871750832, 83.00185695290565, 77.62802571058273, 77.91036576032639, 77.55839824676514, 77.67611593008041, 37.64208734035492, 66.06194034218788, 74.6400636434555, 76.2317830324173, 76.57554298639297, 81.18201300501823, 84.40693035721779, 82.29034513235092, 79.64039772748947, 81.48602709174156, 74.10632908344269, 75.15175178647041, 74.35198590159416, 78.85550424456596, 66.3372203707695, 66.71765595674515, 70.02029433846474, 66.14215403795242, 69.91644591093063, 67.37144127488136, 78.53344112634659, 83.07878002524376, 85.93624949455261, 81.73429816961288, 75.5061587691307, 74.45726305246353, 75.49696326255798, 75.00824868679047, 73.6563192307949, 73.94136473536491, 69.8587954044342, 69.55800354480743, 67.6157833635807, 70.96234738826752, 70.87200343608856, 65.37455722689629, 80.25352522730827, 85.31138822436333, 81.38962626457214, 81.75061449408531, 84.28865030407906, 91.96530237793922, 65.76240241527557, 5.8916874043643475, 0.423189852735959, 5.451177041977644, 4.258137485012412, 0.9406814421527088, 2.010515104047954, 2.8224206250160933, 0.6843299197498709, 0.32830692536663264, 0.28244196146260947, 1.0522658983245492, 30.72955146431923, 53.31058457493782, 70.21404594182968, 61.53148144483566, 49.21581409871578, 48.556135296821594, 59.42823730409145, 78.37879702448845, 84.44958686828613, 110.31827196478844, 56.004731208086014, 0.7219286647159606, 0.34489719138946384, 0.211189980909694, 0.17628526169573888, 0.17278355662710965, 0.13571051938924938, 0.14598504931200296, 0.06566465497598983, 0.1464295809273608, 0.23393925628624856, 0.11445109805208631, 0.11567252469831146, 0.16466446104459465, 0.23562268470413983, 0.15669379499740899, 0.09304029343184084, 0.1423600735142827, 0.13310544745763764, 0.16880416078493, 0.11541810163180344, 0.17903680389281362, 0.14463451865594834, 0.18860645679524168], [0.06129693407274317, 0.027675764831656124, 0.025450366374570876, 0.040799204871291295, 0.023667091263632756, 0.10680021601729095, 0.0296172268645023, 0.07491714364732616, 0.033535549519001506, 0.04767566693772096, 0.06056611528038047, 0.0633625870977994, 0.018863076584239025, 0.04103964958630968, 0.023169468258856796, 0.030320424775709398, 0.04078133395523764, 0.07240346720209345, 0.09234196215402335, 3.8169384095817804, 81.89533352851868, 81.51850014925003, 88.03109988570213, 53.53287644684315, 46.8145215511322, 59.43562410771847, 60.462389811873436, 40.31383037567139, 44.72290478646755, 2.3579344991594553, 0.0376839583623223, 0.13095182395773008, 0.13233443023636937, 0.3191224025795236, 0.03962654845963698, 0.5333262600470334, 2.3380323546007276, 2.232247218489647, 4.891063347458839, 89.49504733085632, 99.84417960047722, 93.21736559271812, 86.31987690925598, 81.16692021489143, 77.12852731347084, 75.00564202666283, 74.07240450382233, 72.54511445760727, 77.76086658239365, 78.43305051326752, 75.67092552781105, 70.15423715114594, 63.83263036608696, 61.00099951028824, 61.420975774526596, 61.26824676990509, 62.56367705762386, 72.90550231933594, 83.84665802121162, 82.55117073655128, 79.94606092572212, 76.86131805181503, 78.2062254846096, 74.80062782764435, 74.22379598021507, 70.43150827288628, 65.10501489043236, 64.78477567434311, 59.645148664712906, 57.87713773548603, 55.20196348428726, 57.016613110899925, 58.98470610380173, 61.95657603442669, 63.33815909922123, 66.41526818275452, 65.67872330546379, 64.23163175582886, 61.377635300159454, 59.071451649069786, 62.98542022705078, 73.41463699936867, 71.00494310259819, 78.14412921667099, 69.66820523142815, 70.66233068704605, 60.19648388028145, 61.27350948750973, 35.28219737112522, 57.331107035279274, 69.91188615560532, 62.31336168944836, 64.09774214029312, 63.36283877491951, 65.27239590883255, 67.900220900774, 76.20353534817696, 73.84284362196922, 70.18998563289642, 68.27115699648857, 77.27673456072807, 73.5727921128273, 72.43222251534462, 60.82717403769493, 63.14943462610245, 58.01277905702591, 61.388388723134995, 55.354612693190575, 60.72683662176132, 70.08710235357285, 72.4642775952816, 65.02608552575111, 60.07831782102585, 59.36345838010311, 60.3993321955204, 63.711295276880264, 65.63365772366524, 63.987897634506226, 63.1860114634037, 62.083417028188705, 60.98431080579758, 58.20221409201622, 59.44787085056305, 61.424292996525764, 71.34534403681755, 77.87622079253197, 74.92647707462311, 71.51581048965454, 81.62002310156822, 71.55423402786255, 85.60321256518364, 39.28868718445301, 2.7854464715346694, 0.9848544874694198, 4.5748490653932095, 0.8425092569086701, 0.2209087906521745, 0.7712362438905984, 0.355718654463999, 0.28297746554017067, 0.3429049998521805, 0.31617913395166397, 4.472662573680282, 25.716432966291904, 43.75861532986164, 69.96028795838356, 43.323257490992546, 20.803940668702126, 31.624889820814133, 63.67285653948784, 63.73303011059761, 75.92570945620537, 76.48596659302711, 3.4998881723731756, 0.0979700761672575, 0.029977168487675954, 0.06333355428068899, 0.046175237293937244, 0.027768436812039, 0.02096680735121481, 0.015519781081820838, 0.04232253348163795, 0.007610751326865284, 0.018923270326922648, 0.07614243688294664, 0.027099843391624745, 0.05036331021983642, 0.00688569484736945, 0.03770295363210607, 0.048047679592855275, 0.0948564698046539, 0.050076110201189294, 0.04053030250361189, 0.029406746361928526, 0.05727444542571902, 0.002890579389713821, 0.0023191453919935157, 0.021732095192419365, 0.027962178173766006, 0.053946870466461405, 0.03733972058398649, 0.04817046792595647, 0.0019012059715350915, 0.005915226829529274, 0.028887441512779333, 0.045288686233107, 0.013972118376841536, 0.12738326622638851, 0.01622211253561545, 0.027308474091114476, 0.09747860371135175, 0.08927546732593328, 0.042220350878778845, 0.08046984803513624, 0.21296328341122717, 6.812550891190767, 104.86589893698692, 91.62160322070122, 98.82103130221367, 65.1768234372139, 65.82151964306831, 52.727768048644066, 48.2375717908144, 46.6836641728878, 49.91226352751255, 2.6928026927635074, 0.043658195208990946, 0.48566639714408666, 1.023962760809809, 0.28023395338095725, 0.1976426539476961, 2.142279683612287, 1.977973768953234, 0.5084696563426405, 8.082552943378687, 95.69260597229004, 101.92605748772621, 98.72919782996178, 90.56940168142319, 85.21219834685326, 79.90541830658913, 79.72329407930374, 76.81502893567085, 76.95121362805367, 79.34408202767372, 81.69438511133194, 79.26296398043633, 73.73183637857437, 67.88110792636871, 65.64064934849739, 64.92817997932434, 65.23435235023499, 64.106215685606, 76.51332512497902, 88.93931195139885, 87.83982574939728, 84.8581637442112, 81.65328651666641, 81.4489258825779, 78.51840153336525, 77.80014887452126, 74.31132048368454, 70.52869185805321, 68.40373188257217, 62.53816902637482, 60.9366537630558, 59.431797713041306, 59.28940415382385, 61.364670395851135, 65.4520882666111, 66.72377362847328, 69.08232986927032, 67.7037638425827, 66.86454087495804, 64.17863219976425, 61.58021003007889, 66.48426488041878, 76.62282004952431, 74.13479715585709, 81.68102502822876, 72.00309634208679, 73.01515683531761, 65.29846251010895, 65.82001492381096, 38.360925167798996, 61.35892890393734, 72.75598794221878, 69.8555351793766, 71.50537624955177, 68.26703801751137, 69.08095434308052, 71.45161673426628, 79.7728206217289, 77.5552748143673, 73.09788599610329, 70.30074208974838, 80.70011526346207, 76.81463375687599, 75.85175782442093, 64.80458781123161, 65.00640258193016, 59.95724491775036, 63.884239196777344, 59.42609801888466, 63.65616783499718, 72.16454207897186, 74.4812473654747, 67.3083646595478, 61.90323829650879, 61.86900593340397, 64.45087999105453, 69.6762304008007, 68.38734716176987, 67.56885588169098, 66.77923545241356, 64.84550401568413, 64.71626535058022, 61.954907923936844, 62.72780545055866, 63.92901599407196, 74.51512634754181, 79.75085020065308, 78.29981446266174, 75.65805181860924, 82.47329771518707, 76.65850013494492, 88.10479313135147, 53.01909081637859, 4.081575684249401, 0.878647870849818, 1.6228090832009912, 1.3991416851058602, 0.34203146235086024, 1.1518139066174626, 1.345214385073632, 0.6254039879422635, 0.5713998014107347, 0.553612302755937, 3.7330797594040632, 29.623620808124542, 42.22277574241161, 43.837886676192284, 30.204858519136906, 27.824352756142616, 43.21812093257904, 70.88883653283119, 70.88581189513206, 80.58229118585587, 90.36339953541756, 7.98378674313426, 0.4314070305554196, 0.04943599669786636, 0.08251597144408152, 0.030488541633530986, 0.02826238989655394, 0.10334133286960423, 0.07977635556017049, 0.04922180174617097, 0.029931875214970205, 0.031038756933412515, 0.05110432983201463, 0.08294972707517445, 0.05161325017979834, 0.056268757398356684, 0.05367210884287488, 0.06256183944060467, 0.028498275969468523, 0.05195133555389475, 0.05521854793187231, 0.04413663555169478, 0.03895455600286368, 0.04446065351658035, 0.16301189112709835, 0.10423350569908507, 0.1700733817415312, 0.11883604791364633, 0.10384741821326315, 0.24177666229661554, 0.12789493252057582, 0.2035650666221045, 0.0922085165802855, 0.15660403965739533, 0.1342183127417229, 0.30574278614949435, 0.08721997059183195, 0.1643758249701932, 0.177741251536645, 0.1387832037289627, 0.29022424074355513, 0.18815120856743306, 0.42284537747036666, 8.653089478611946, 124.03153851628304, 105.97137361764908, 114.46713253855705, 72.68384501338005, 64.99849900603294, 84.07213032245636, 91.96771144866943, 58.044245168566704, 75.00321015715599, 4.417163701727986, 0.12706455832812935, 0.4019065713509917, 2.3081405460834503, 1.334291989915073, 1.6499714506790042, 3.4903255105018616, 7.714432021602988, 10.701414216309786, 7.096562376245856, 99.84050139784813, 105.56596577167511, 103.31598490476608, 94.22418236732483, 89.98276636004448, 83.53805378079414, 83.3244140446186, 82.40080520510674, 80.37303641438484, 84.68652695417404, 84.17122900485992, 83.13053324818611, 77.26873219013214, 70.35586193203926, 68.02219435572624, 68.00130307674408, 70.04832923412323, 70.00977650284767, 80.53543969988823, 92.52934411168098, 92.29625701904297, 88.08160677552223, 86.16244375705719, 87.4191427230835, 84.0533821284771, 83.3154845237732, 79.10862386226654, 74.73965629935265, 73.43598425388336, 66.5991023182869, 65.55842936038971, 61.64640247821808, 63.35252232849598, 66.27305701375008, 68.58840197324753, 70.00752702355385, 72.63643875718117, 71.96946054697037, 69.4433180987835, 65.70818692445755, 64.69212904572487, 70.93450248241425, 80.48657432198524, 77.72330179810524, 83.83058488368988, 74.15096148848534, 74.61525857448578, 69.33114051818848, 68.68386045098305, 41.9522150605917, 63.264237865805626, 73.9338867366314, 73.78048896789551, 75.83999365568161, 70.1069600880146, 70.70635512471199, 74.4458256661892, 84.32690665125847, 81.83414921164513, 77.9049700498581, 76.70392289757729, 83.3382984995842, 79.84594389796257, 78.7719315290451, 67.12349697947502, 66.30562886595726, 61.433271914720535, 66.59022599458694, 61.16319380700588, 67.64629572629929, 78.19265261292458, 79.92652237415314, 70.87001234292984, 67.24822908639908, 66.86067268252373, 68.36726143956184, 73.48250135779381, 72.81717225909233, 70.17266616225243, 71.54600366950035, 68.7387827038765, 69.74977165460587, 66.00662291049957, 66.77120268344879, 68.38097110390663, 79.83875468373299, 84.64694827795029, 82.75745406746864, 80.75898170471191, 89.50513198971748, 80.1453298330307, 94.13860335946083, 53.68983842432499, 4.433884229511023, 3.1166041642427444, 10.60048308223486, 5.000477526336908, 0.5203240702394396, 2.120340848341584, 2.9933380661532283, 0.7427529722917825, 0.9436429676134139, 0.5053086415864527, 7.904727710410953, 42.02964350581169, 65.16522645950317, 96.62250727415085, 59.125971123576164, 31.825741343200207, 51.8121387809515, 85.28990417718887, 84.39518138766289, 93.77735674381256, 103.06400522589684, 7.777952738106251, 0.5347290972713381, 0.268147811293602, 0.19123593054246157, 0.1674513443140313, 0.23375835036858916, 0.22089072677772492, 0.08106954046525061, 0.16345459705917165, 0.11311576658044942, 0.16594693675870076, 0.1317933452082798, 0.15697682043537498, 0.20251886104233563, 0.2178959976299666, 0.18052693252684548, 0.2112906309776008, 0.20825624145800248, 0.16764007246820256, 0.15523431706242263, 0.11260280894930474, 0.13937619456555694, 0.11361688695615157], [0.03799815400270745, 0.009258442551072221, 0.013781523721263511, 0.046803101649857126, 0.01621271137992153, 0.018056352782878093, 0.02518436209356878, 0.07709539902862161, 0.015366861553047784, 0.019093374285148457, 0.086396253464045, 0.05991332589474041, 0.0516128382878378, 0.03632723819464445, 0.041455467508058064, 0.07349161154706962, 0.04308435549319256, 0.21206798614002764, 0.30874489224515855, 17.806978784501553, 99.03548419475555, 78.12942400574684, 86.03323549032211, 49.143587574362755, 29.029668979346752, 44.940484911203384, 51.10783137381077, 47.79281705617905, 22.853094711899757, 0.0621132853848394, 0.26137826673220843, 0.053798555964021944, 0.2088345674565062, 0.3905299224425107, 0.11188101096195169, 2.540456517599523, 2.2178552532568574, 1.8745557870715857, 58.046946823596954, 105.39106115698814, 89.14007797837257, 90.28896152973175, 82.67436772584915, 80.32063722610474, 75.19729614257812, 72.94446542859077, 67.09456533193588, 65.93850776553154, 65.53712770342827, 68.41762393712997, 66.73998355865479, 63.7046342343092, 62.911555990576744, 64.907645881176, 62.095481380820274, 60.98771162331104, 63.23357351124287, 63.766073137521744, 67.92080819606781, 73.5881432890892, 73.38826641440392, 74.02351632714272, 73.47379222512245, 73.688123524189, 74.66884329915047, 68.30216333270073, 65.8798997104168, 65.71709364652634, 58.649826273322105, 57.597522139549255, 55.52151493728161, 56.401977092027664, 59.267369136214256, 64.41519990563393, 67.63608947396278, 72.13528364896774, 70.41498675942421, 68.63592982292175, 58.84306110441685, 61.40470504760742, 71.31569042801857, 76.6456264257431, 73.56917470693588, 78.75798627734184, 75.07612824440002, 74.44039195775986, 73.4024928510189, 64.11516040563583, 39.551313892006874, 60.92424362897873, 68.54957565665245, 71.03426232933998, 74.3140259385109, 68.32302421331406, 64.76620227098465, 65.49654588103294, 75.59669271111488, 69.75170195102692, 68.39420959353447, 65.91903761029243, 76.16204917430878, 77.64515519142151, 78.91117125749588, 70.75107872486115, 59.149020686745644, 58.70749197900295, 55.80623745918274, 58.107925951480865, 55.217345058918, 56.734394654631615, 59.64400492608547, 58.17470356822014, 57.295487746596336, 58.38322877883911, 57.12406374514103, 57.29335606098175, 61.46761827170849, 60.157505571842194, 58.755943179130554, 57.0266255736351, 56.59763239324093, 58.08269150555134, 55.55344842374325, 59.891941621899605, 68.63521546125412, 74.85504850745201, 69.87075716257095, 74.25566866993904, 70.28011679649353, 77.35141575336456, 72.14887171983719, 83.86973038315773, 24.20577272772789, 1.1541636055335402, 0.3937973908614367, 0.9449782990850508, 0.06272273705690168, 0.10421753468108363, 0.934828034369275, 0.1475760358152911, 0.09325249571702443, 0.04432020949025173, 0.0806234948686324, 12.767858281731606, 26.69818628579378, 44.96677950024605, 52.14405097067356, 33.33378352224827, 22.59484726935625, 32.32700854539871, 63.90542685985565, 64.16431456804276, 82.93967708945274, 28.539763167500496, 0.18794469855492935, 0.08038982225116342, 0.05840839512529783, 0.061498924405896105, 0.03210086302715354, 0.11304829793516546, 0.0367424883734202, 0.03357865716679953, 0.08520828283508308, 0.06315593607723713, 0.02212632774899248, 0.017784543051675428, 0.019246598094468936, 0.020422703637450468, 0.022742675828339998, 0.055293412078754045, 0.061884017413831316, 0.05313434863637667, 0.07537343088188209, 0.02094082476105541, 0.01904280619783094, 0.04535723099252209, 0.05467478003993165, 0.025337469014630187, 0.053453483269549906, 0.01470657183745061, 0.04771112304297276, 0.034802536611096, 0.04104856649064459, 0.014840747498965356, 0.018500687729101628, 0.03625409954111092, 0.04948149777192157, 0.08565526353777386, 0.0922916445415467, 0.07660061659407802, 0.13492829573806375, 0.12732868868624792, 0.0751199058140628, 0.2739208593266085, 0.4054407973308116, 28.07476881891489, 116.28503859043121, 88.05581375956535, 98.75027909874916, 61.379728987812996, 42.56245091557503, 51.926425248384476, 61.63655340671539, 55.98660998046398, 27.281510084867477, 0.04722205514553934, 0.13620183599414304, 0.504726500948891, 0.2236061857547611, 0.46283805335406214, 0.41957339679356664, 2.358456733636558, 1.1619920167140663, 3.3901704847812653, 67.97110229730606, 107.6172249019146, 95.64997985959053, 94.42484200000763, 88.27651351690292, 83.34643766283989, 80.7713234424591, 74.13602828979492, 73.03533375263214, 68.59391927719116, 70.12532830238342, 71.17669388651848, 70.82981809973717, 67.79639527201653, 68.72219279408455, 67.48907536268234, 64.81713473796844, 64.0422423183918, 65.68753883242607, 65.60818389058113, 70.33177882432938, 74.38261985778809, 77.34918907284737, 77.7248977124691, 76.90655842423439, 76.46471813321114, 77.12112531065941, 71.73896491527557, 70.4973055422306, 67.18904346227646, 62.022506296634674, 61.22501648962498, 58.60348396003246, 59.76273715496063, 61.98250204324722, 66.75958290696144, 69.03718069195747, 73.52638900279999, 75.68731784820557, 71.0797306895256, 61.754677668213844, 61.91554583609104, 74.01367485523224, 79.54715073108673, 76.0276047885418, 81.00915268063545, 78.58353763818741, 77.60936111211777, 77.11686193943024, 68.65264132618904, 43.218390718102455, 64.2430691421032, 71.99513956904411, 74.33630794286728, 74.68983337283134, 72.3343625664711, 66.88005924224854, 69.64369654655457, 80.14083087444305, 73.048937022686, 70.7958859205246, 69.91499438881874, 77.97835171222687, 80.96659496426582, 81.127789914608, 71.59840285778046, 61.953304409980774, 62.5119998306036, 58.002690598368645, 59.579453989863396, 57.933952286839485, 59.079100638628006, 59.821622595191, 60.54009564220905, 58.711987137794495, 60.156084448099136, 57.44313642382622, 60.140022709965706, 64.1207081079483, 64.94659379124641, 63.01805667579174, 60.592510029673576, 58.84305350482464, 61.056605726480484, 60.06838135421276, 63.68361756205559, 72.80975505709648, 77.26285770535469, 72.86998182535172, 76.42257079482079, 73.8663187623024, 81.02935239672661, 77.68524304032326, 88.59539240598679, 34.716901704669, 1.2324940273538232, 0.4222773079527542, 1.1416773567907512, 1.0912944353185594, 1.100335456430912, 0.7514736230950803, 0.933680614689365, 0.4813608422409743, 0.17261736007640138, 0.19050950155360624, 13.153833970427513, 30.689087435603142, 41.74880437552929, 37.71218977868557, 29.45260338485241, 36.660960987210274, 39.249013513326645, 72.75705188512802, 74.23695087432861, 93.19319128990173, 45.616639629006386, 0.09540382598061115, 0.06022884997946676, 0.050547444479889236, 0.03862793309963308, 0.05251981696346775, 0.031675809077569284, 0.021870450073038228, 0.019822931426460855, 0.03728631192643661, 0.02608932954899501, 0.07844326537451707, 0.03170264513755683, 0.04279917411622591, 0.015595285331073683, 0.04704754283011425, 0.052772143462789245, 0.10026870790170506, 0.03778948062972631, 0.03252416179748252, 0.004970703830622369, 0.008906692382879555, 0.04258777706127148, 0.2064974553650245, 0.14975968661019579, 0.186256505548954, 0.10146615575649776, 0.2031210545101203, 0.141390101343859, 0.15600643266225234, 0.281399303348735, 0.09301140904426575, 0.20153143355855718, 0.18623327632667497, 0.18855236907256767, 0.1290746801532805, 0.24656703259097412, 0.19769188802456483, 0.25223937118425965, 0.16527670319192111, 0.45576550473924726, 0.9361635439563543, 34.12463888525963, 133.8543078303337, 100.4669813811779, 111.40784069895744, 70.69097355008125, 41.665474846959114, 64.61389884352684, 73.62716719508171, 72.54709035158157, 38.762928396463394, 0.2880989375989884, 0.44489253661595285, 0.9401415148749948, 0.9087371500208974, 1.7048162827268243, 1.3061535498127341, 5.721404291689396, 10.414924789220095, 5.172856701537967, 69.72726926207542, 110.90796232223511, 98.43465283513069, 99.22854423522949, 95.6131674349308, 89.48947682976723, 86.04020431637764, 78.5301125049591, 76.53368443250656, 74.39268931746483, 75.89351758360863, 77.18338117003441, 74.80049103498459, 71.41975924372673, 71.64925172924995, 71.87068864703178, 69.9029490351677, 68.4087248146534, 70.57844638824463, 71.06083810329437, 74.16844055056572, 80.46531826257706, 81.14558055996895, 79.56203833222389, 81.6619348526001, 81.31219401955605, 81.28412112593651, 75.49585372209549, 74.89243850111961, 73.40783536434174, 66.4397844672203, 65.64324840903282, 61.21583618223667, 61.25549465417862, 65.15815883874893, 71.91556423902512, 72.55344361066818, 77.99317091703415, 79.98756989836693, 75.34953117370605, 64.32602629065514, 66.56130194664001, 77.98092037439346, 83.05009916424751, 78.20252448320389, 86.2086720764637, 83.74609261751175, 81.3196112215519, 82.63567060232162, 73.86095345020294, 48.66191402077675, 66.90551787614822, 77.12759256362915, 78.55725824832916, 80.66932931542397, 75.16525626182556, 68.25141325592995, 70.70176497101784, 84.38897252082825, 78.56722131371498, 75.27655988931656, 70.97481831908226, 82.54231721162796, 81.36139377951622, 84.18373793363571, 76.85904577374458, 65.12655213475227, 66.37765020132065, 61.75878144800663, 63.67131382226944, 61.40988036990166, 63.59117612242699, 65.47055527567863, 63.87611523270607, 63.41997250914574, 64.95829716324806, 62.043621763587, 62.232608422636986, 69.63768526911736, 69.21177372336388, 66.30964145064354, 64.9223966896534, 64.79432836174965, 65.51147148013115, 63.88043940067291, 66.6142863035202, 77.68977239727974, 79.38401788473129, 78.02073463797569, 81.92032098770142, 79.6700057387352, 86.7399899661541, 81.16485312581062, 92.48567685484886, 35.15450142323971, 1.5107203228399158, 3.634682851843536, 4.748928174376488, 0.9945897432044148, 1.015643107239157, 2.279730183072388, 3.1874335510656238, 0.2912479592487216, 0.2838306385092437, 0.16952068952377886, 21.54677990823984, 43.652319833636284, 67.11908161640167, 71.1395850777626, 46.42264097929001, 40.770672261714935, 48.378475829958916, 84.856628626585, 83.38973253965378, 109.46240589022636, 51.17600351572037, 0.36195311055053025, 0.2823753166012466, 0.19724288868019357, 0.15827952709514648, 0.09325566468760371, 0.24321335629792884, 0.19500761409290135, 0.13241483451565728, 0.15292668307665735, 0.15707649086834863, 0.19053038558922708, 0.062969968712423, 0.12908840988529846, 0.15706549223978072, 0.15467353543499485, 0.13229561591288075, 0.19883681408828124, 0.14662429079180583, 0.14862862386507913, 0.062082786826067604, 0.16512396920006722, 0.12180131379864179], [0.09113413907471113, 0.018974632512254175, 0.046994171279948205, 0.016182537510758266, 0.05307385988999158, 0.04922654406982474, 0.06990919049712829, 0.029430823487928137, 0.03295493770565372, 0.13878051715437323, 0.09110141778364778, 0.06252356688492, 0.027024450464523397, 0.05269863744615577, 0.03840113648038823, 0.030653240901301615, 0.049922452235477977, 0.12000274116871879, 0.06790131737943739, 53.20281855762005, 86.92190900444984, 78.02912458777428, 59.1776255518198, 36.191454380750656, 38.34118142724037, 57.108530178666115, 65.35189524292946, 49.13148142397404, 4.423768697306514, 0.235142337041907, 0.45076253882143646, 1.28318295115605, 0.3592613706132397, 0.29854457709006965, 0.2656491781817749, 0.4256548814009875, 1.7494744551368058, 25.264675207436085, 102.21716746687889, 94.35738801956177, 95.61065956950188, 83.04051607847214, 80.03920912742615, 72.30238348245621, 70.2806107699871, 67.40673378109932, 65.65020963549614, 61.196666210889816, 63.069692105054855, 61.822070851922035, 62.309105917811394, 61.32148951292038, 63.6783092468977, 60.45753367245197, 59.66520018875599, 59.18849676847458, 61.294602155685425, 61.92016638815403, 60.57946912944317, 59.62195850908756, 59.130242094397545, 61.33206434547901, 62.02228590846062, 61.3456030189991, 62.63027988374233, 63.404750525951385, 61.28333196043968, 58.655347377061844, 56.54798425734043, 58.47865305840969, 58.34480904042721, 56.30629062652588, 60.592259243130684, 65.98914384841919, 75.44967100024223, 80.11661097407341, 75.80701142549515, 75.00272378325462, 66.05062454938889, 56.18635766208172, 71.37324213981628, 76.81487694382668, 75.58880433440208, 74.94028553366661, 70.32474160194397, 68.70898470282555, 70.19856557250023, 72.50883400440216, 40.71523703634739, 62.16701254248619, 68.51829573512077, 69.57233637571335, 72.56472140550613, 71.05209097266197, 77.05231860280037, 76.15653187036514, 74.6949402987957, 68.0273924767971, 64.03974205255508, 68.92510950565338, 71.02209538221359, 76.76510721445084, 78.01615968346596, 71.7532217502594, 62.67034113407135, 59.293238148093224, 57.80369147658348, 55.04845172166824, 56.995664834976196, 56.6741830855608, 55.24732545018196, 55.50903640687466, 55.71666106581688, 55.73266960680485, 56.61336734890938, 55.5137025564909, 57.22764998674393, 59.33788575232029, 57.46949180960655, 54.545757696032524, 57.265412360429764, 56.59482054412365, 56.68097712099552, 60.83991475403309, 65.78913778066635, 69.17825192213058, 68.94822746515274, 68.43300551176071, 68.24730947613716, 69.89964321255684, 79.28444802761078, 77.95810639858246, 75.44032350182533, 16.6539990529418, 1.4747271104715765, 0.44059772801119834, 0.8442990202456713, 0.7249677297659218, 0.7919460232369602, 0.341179565875791, 0.7817518233787268, 0.22244050924200565, 0.11980695519014262, 0.8230190339963883, 20.97051043063402, 23.447660207748413, 58.98700878024101, 41.97722531855106, 16.526154913008213, 44.66186486184597, 62.58899509906769, 65.60474127531052, 66.66647270321846, 57.888597920536995, 1.6884861839935184, 0.1444180341786705, 0.023175316382548772, 0.0734417985950131, 0.05090795013529714, 0.051212842954555526, 0.03794185096921865, 0.014283796281233663, 0.026768849238578696, 0.03720700602571014, 0.039409525925293565, 0.061808678292436525, 0.04286295428755693, 0.08381227336940356, 0.010738516939454712, 0.05582394376688171, 0.03931586317776237, 0.024260302889160812, 0.03659476758912206, 0.05426302908745129, 0.029733480587310623, 0.04901870561297983, 0.010716002034314442, 0.05118328692333307, 0.06877397172502242, 0.04492336403927766, 0.009841737228271086, 0.04375196556793526, 0.0031980180074242526, 0.06395450924173929, 0.0629686625325121, 0.02379300960456021, 0.02135441252903547, 0.06044105968612712, 0.0586022774950834, 0.061196666210889816, 0.009765893446456175, 0.09307691099820659, 0.036933105293428525, 0.07326518971240148, 0.05537786848435644, 72.66644954681396, 100.87737455964088, 87.28558748960495, 68.92729058861732, 48.81489761173725, 38.05869698524475, 53.396855145692825, 73.4110575914383, 55.55354721844196, 5.082882754504681, 0.30799499654676765, 0.47322847705800086, 1.8635319848544896, 0.1676685709389858, 0.49651668523438275, 0.5624463537242264, 1.0787875251844525, 1.5972480922937393, 31.468079835176468, 104.86224353313446, 98.0165384709835, 99.4238917529583, 87.35424220561981, 81.97756111621857, 74.44024756550789, 74.05940160155296, 70.65118208527565, 69.6274334192276, 64.16699722409248, 65.71520894765854, 66.46658062934875, 67.099299877882, 63.81254464387894, 66.73009648919106, 65.13076990842819, 64.58811342716217, 63.76434803009033, 64.82156530022621, 64.54091995954514, 63.12427997589111, 62.5348974019289, 61.37170761823654, 63.64419087767601, 64.00909289717674, 66.04700714349747, 65.41069328784943, 65.7204070687294, 65.0617504119873, 61.65476202964783, 59.48124445974827, 60.78411854803562, 60.2966883033514, 58.19818250834942, 63.769280165433884, 68.34853604435921, 78.15853044390678, 83.44455599784851, 78.73930647969246, 79.23805251717567, 69.6110562980175, 58.94907921552658, 74.21564161777496, 80.34812495112419, 77.874366492033, 77.78958544135094, 70.71488946676254, 71.60411015152931, 73.05829972028732, 75.45558348298073, 44.43757049739361, 66.24539449810982, 72.3643733561039, 75.16828089952469, 76.09537035226822, 75.16964882612228, 80.15846952795982, 79.1702489554882, 76.65421396493912, 70.9595051407814, 68.47999379038811, 72.38477066159248, 74.70693245530128, 78.51596966385841, 80.525461435318, 75.49369543790817, 64.70396161079407, 61.65719389915466, 59.51768070459366, 56.32066525518894, 58.2806570827961, 57.376298010349274, 58.47339414060116, 57.92207412421703, 59.14458632469177, 59.742320850491524, 58.22318896651268, 59.4835889339447, 60.31943768262863, 62.07482188940048, 61.84214137494564, 58.091921210289, 61.19418114423752, 59.923772513866425, 60.62212564051151, 64.07090038061142, 70.03525033593178, 72.57042869925499, 73.17898884415627, 72.83749356865883, 72.11718901991844, 73.27656760811806, 81.53590321540833, 82.16958001255989, 80.6480124592781, 23.637703210115433, 1.2623050902038813, 0.2708219474880025, 0.09952843785868026, 0.6638185610063374, 1.8641927931457758, 1.0355807561427355, 1.07567846076563, 0.3295133903156966, 0.11128916303277947, 0.5875165178440511, 23.753579892218113, 32.09792263805866, 49.27691102027893, 34.095540046691895, 30.043095499277115, 63.070968836545944, 69.52068194746971, 74.876479357481, 74.62321534752846, 78.22282299399376, 4.7338292095810175, 0.42605570051819086, 0.1003576691437047, 0.15573980868794024, 0.07794541044859216, 0.05727556606871076, 0.06592772406293079, 0.01696702285698848, 0.018696518236538395, 0.09023455218994059, 0.08613615296781063, 0.06080224069592077, 0.017255883431062102, 0.008088502399914432, 0.034267722730874084, 0.021265200812194962, 0.05951982435362879, 0.012555433604575228, 0.019345366818015464, 0.06636023288592696, 0.03604479534260463, 0.09098083362914622, 0.19102873775409535, 0.15776394226122648, 0.18668611999601126, 0.061671347575611435, 0.09180832086713053, 0.161865183908958, 0.11511108998092823, 0.11928783773328178, 0.12971202173503116, 0.16816935734823346, 0.11766496856580488, 0.17986679216846824, 0.10972468604450114, 0.1519849125179462, 0.21550436737015843, 0.1443809861666523, 0.20286263868911192, 0.1985406526364386, 0.11843427884741686, 83.12571510672569, 120.0577649474144, 99.822558760643, 84.98529732227325, 52.97614932060242, 56.4197563380003, 79.6938456594944, 84.61936175823212, 73.3085010945797, 8.46124917268753, 0.3943641245132312, 1.638669075910002, 4.887290149927139, 1.064601105172187, 0.7571110362187028, 1.2535249488428235, 5.018599703907967, 5.956575097516179, 31.2918870896101, 108.2577033340931, 102.11740761995316, 103.35322290658951, 91.51339262723923, 86.10862344503403, 78.81304532289505, 77.6460899412632, 73.13548877835274, 73.48627835512161, 68.86662304401398, 71.01058200001717, 70.09208768606186, 70.753875374794, 66.89205139875412, 71.13807275891304, 66.38540178537369, 68.30169975757599, 67.85632565617561, 67.83662751317024, 68.43058124184608, 66.29764929413795, 66.57794505357742, 63.94719421863556, 69.32898223400116, 66.11201405525208, 69.66127440333366, 68.87869119644165, 69.50317248702049, 70.74920162558556, 66.05279803276062, 63.62119071185589, 65.7060894370079, 64.65770289301872, 61.358092948794365, 68.09955820441246, 71.80042281746864, 81.71497240662575, 89.01413753628731, 82.76174783706665, 82.74068176746368, 73.23849365115166, 61.818871423602104, 78.57390135526657, 83.25723364949226, 82.01096132397652, 82.70646840333939, 75.78482061624527, 76.59738421440125, 78.24780285358429, 80.65373495221138, 48.161796256899834, 69.13377150893211, 79.54093426465988, 78.46687629818916, 80.00336185097694, 77.45178356766701, 83.584403693676, 83.49434092640877, 81.47295579314232, 75.74534833431244, 71.87607675790787, 76.6238383948803, 78.1636069715023, 83.0374002456665, 84.46562200784683, 78.27575415372849, 69.21169012784958, 64.07846957445145, 63.47322665154934, 60.53094573318958, 63.76850500702858, 62.81154155731201, 62.216520085930824, 62.70144246518612, 61.96811601519585, 63.8101127743721, 60.7495404034853, 64.28004115819931, 64.13206189870834, 66.00137919187546, 64.48162034153938, 60.49495406448841, 65.4419656097889, 63.75533491373062, 63.28047439455986, 68.4426797926426, 73.03660288453102, 78.46681550145149, 75.90503096580505, 76.28667488694191, 77.14628756046295, 77.99476683139801, 86.10546201467514, 86.7275570333004, 82.90265187621117, 22.909056209027767, 3.9992455020546913, 4.137856364250183, 3.9603536389768124, 1.896509227808565, 2.824561335146427, 3.4692888893187046, 2.7237107092514634, 0.481778047978878, 0.2828326279995963, 2.0424255542457104, 35.348872393369675, 39.221616983413696, 84.21634018421173, 64.42179635167122, 26.14754643291235, 63.7027495354414, 79.50935795903206, 86.79704770445824, 82.99758598208427, 94.04946774244308, 4.752638675272465, 0.5645296513102949, 0.20044964941916987, 0.1821116404607892, 0.15468796278582886, 0.13607016415335238, 0.18287700251676142, 0.09420146510819905, 0.08822942501865327, 0.14476739277597517, 0.22037677466869354, 0.1291984406998381, 0.1640206330921501, 0.17105396662373096, 0.1326642555068247, 0.2080689975991845, 0.1923783333040774, 0.19740562682272866, 0.16968700481811538, 0.15373598027508706, 0.1758967770729214, 0.11891133137396537], [0.024856275304045994, 0.03717140149092302, 0.055116662188083865, 0.007317597892324557, 0.029247989841678645, 0.019043077081732918, 0.04425677812832873, 0.005562706219279789, 0.03296442977443803, 0.03761141713766847, 0.04845799820031971, 0.05271223359159194, 0.03955424472223967, 0.058256277116015553, 0.06570751400431618, 0.06794767192332074, 0.165451746142935, 0.14777444157516584, 5.884366147220135, 85.2800703048706, 77.08685114979744, 76.33921846747398, 68.76492530107498, 36.22532956302166, 56.54937118291855, 77.4665267765522, 52.91222535073757, 25.202309153974056, 0.19678605225635692, 0.23823361960239708, 0.3368532605236396, 0.08765439415583387, 0.23891399090643972, 0.12229950269102119, 0.1541250734589994, 0.7023651176132262, 7.0380977634340525, 82.31248274445534, 92.55013659596443, 99.43469077348709, 88.32347139716148, 93.8639084994793, 84.60447415709496, 77.83262193202972, 72.0998315513134, 71.75142824649811, 71.36515617370605, 70.97610265016556, 64.10870835185051, 63.718473091721535, 61.11186236143112, 60.900616496801376, 61.56942620873451, 66.31471037864685, 59.69399884343147, 60.15222005546093, 58.51066634058952, 61.020667254924774, 58.524182215332985, 62.00076766312122, 58.08105759322643, 57.79415398836136, 55.53036846220493, 57.423008903861046, 56.534206196665764, 58.41852508485317, 55.88190279901028, 56.043508127331734, 54.65679153800011, 57.492879554629326, 57.1349311619997, 59.116239845752716, 57.709847912192345, 66.08161568641663, 73.5173074901104, 75.9713526070118, 76.42371833324432, 74.52954277396202, 69.92980599403381, 61.723884120583534, 54.52161379158497, 66.2790758907795, 64.00465473532677, 65.86788475513458, 61.414276733994484, 66.59237667918205, 69.4557586312294, 72.67392754554749, 46.262118592858315, 67.18064591288567, 64.56450909376144, 69.20533686876297, 71.6807596385479, 71.78947180509567, 74.22641023993492, 70.70356607437134, 68.45111533999443, 63.01878243684769, 62.653948813676834, 68.94688233733177, 69.82084304094315, 66.92260935902596, 72.9918260872364, 74.12821590900421, 60.95797821879387, 61.57691180706024, 58.289016634225845, 53.30843769013882, 54.943725541234016, 53.656263425946236, 53.33198122680187, 54.04948532581329, 54.115601778030396, 55.42523570358753, 56.451036259531975, 54.96680550277233, 55.15840262174606, 56.26419648528099, 56.48504823446274, 54.850068166852, 55.48062913119793, 56.08915887773037, 55.518106520175934, 59.32395190000534, 64.02407169342041, 65.69777548313141, 64.46735590696335, 65.39058476686478, 64.08384248614311, 68.50226059556007, 75.38568243384361, 78.30868318676949, 72.470623254776, 70.05666598677635, 21.045924983918667, 0.6198535545263439, 2.5432341685518622, 1.6639688308350742, 0.15098938078153878, 0.6458816828671843, 1.6294569452293217, 0.5616925098001957, 0.07916020971606486, 0.19982214871561155, 6.874590162187815, 26.86952669173479, 40.87599121034145, 49.38753828406334, 22.610449232161045, 17.860998585820198, 51.53095006942749, 71.57359778881073, 61.034654304385185, 70.82765981554985, 19.47916455566883, 0.15853527118451893, 0.08204464087611996, 0.00991386656096438, 0.03698834705573972, 0.042339135325164534, 0.027291755359328818, 0.05096818284073379, 0.07907648061518557, 0.03292073211923707, 0.05301082186633721, 0.021569000818999484, 0.029138387617422268, 0.013819997584505472, 0.07056142698274925, 0.01273780897463439, 0.0348491471959278, 0.03129120959783904, 0.03334572298626881, 0.01361340315270354, 0.07657324618776329, 0.057805901087704115, 0.09162053524050862, 0.03047461337700952, 0.01863285680883564, 0.054735265075578354, 0.06778663329896517, 0.052762491832254454, 0.033480923739261925, 0.017686342071101535, 0.1104820922773797, 0.038256558691500686, 0.055110877146944404, 0.046333522550412454, 0.08225585610489361, 0.06490433210274205, 0.1229253038764, 0.08471832436043769, 0.2863596106180921, 0.32194470113608986, 11.188770364969969, 103.92202198505402, 87.28250205516815, 90.08385613560677, 80.24448171257973, 48.66027630865574, 56.533324643969536, 62.553869783878326, 55.25878183543682, 27.545272931456566, 0.04459675597900059, 0.25198009447194636, 1.0229102172888815, 1.1319062998518348, 0.300641322392039, 0.7309997279662639, 0.8502413076348603, 0.7334440655540675, 9.16280172765255, 89.02166113257408, 94.04379844665527, 102.42654383182526, 92.8171406686306, 96.9071651995182, 88.18964257836342, 82.56193175911903, 74.79845434427261, 76.49533689022064, 74.65495124459267, 74.97833669185638, 67.61480301618576, 66.32601857185364, 63.79160776734352, 65.67914888262749, 64.81639757752419, 67.29637250304222, 63.25734123587608, 62.46265947818756, 59.514933452010155, 63.91365721821785, 61.16069354116917, 64.09187525510788, 60.84933444857597, 61.30747206509113, 60.1725147664547, 61.577550172805786, 58.76081071794033, 60.59529908001423, 59.62127834558487, 58.79883147776127, 58.71667228639126, 60.02704717218876, 60.94723619520664, 61.53916083276272, 60.45760586857796, 67.62597441673279, 75.4337802529335, 79.02994528412819, 79.9211798608303, 77.07917556166649, 73.50314944982529, 63.822317719459534, 55.73541305959225, 67.35161393880844, 66.86815828084946, 68.02279472351074, 66.82121559977531, 69.2950576543808, 71.9335524737835, 77.282844632864, 49.72044222056866, 69.51305955648422, 69.05683323740959, 70.80242916941643, 75.64030677080154, 74.38217148184776, 77.49836146831512, 73.84934887290001, 70.30490666627884, 66.64563462138176, 67.19325363636017, 71.36237472295761, 72.78466880321503, 67.9022727906704, 75.8427295088768, 76.05062395334244, 62.698592618107796, 63.750425577163696, 62.1132530272007, 57.061872482299805, 57.86670349538326, 56.532097309827805, 56.916256695985794, 55.990196987986565, 58.85020472109318, 58.105687871575356, 58.47147524356842, 58.42586629092693, 57.869131565093994, 58.91800828278065, 58.945241421461105, 57.37476669251919, 59.11249704658985, 58.87561395764351, 59.31390903890133, 62.96063415706158, 67.35855996608734, 69.53563034534454, 66.84614226222038, 69.26163464784622, 67.14818805456161, 73.41665089130402, 77.88884371519089, 81.02385029196739, 75.40483340620995, 77.11398929357529, 32.253607884049416, 0.8500950154848397, 1.6375043196603656, 0.2739469532389194, 0.3756183944642544, 1.7027153517119586, 2.3235387448221445, 1.1671192478388548, 0.42759734904393554, 0.1977725001052022, 5.681216698139906, 31.93621091544628, 43.82321946322918, 42.77508370578289, 26.85209132730961, 30.63256546854973, 57.72356517612934, 81.61420181393623, 65.55848255753517, 84.36608254909515, 36.5279833227396, 0.1310656248824671, 0.002706745699470048, 0.04544496398011688, 0.011611495046963682, 0.0501323687058175, 0.03288052997959312, 0.06977595272473991, 0.08810641404124908, 0.0350071689899778, 0.08675797624164261, 0.0664988141215872, 0.06200962219736539, 0.028677762529696338, 0.067572479165392, 0.010499231830181088, 0.03587285085814074, 0.033850524414447136, 0.031622092428733595, 0.0501005862315651, 0.01919302059832262, 0.0485040558851324, 0.1719781185965985, 0.0788422068580985, 0.14282850228482857, 0.16703335189959034, 0.22083445714088157, 0.22628300852375105, 0.1337238197447732, 0.17200136266183108, 0.14877162087941542, 0.16749453730881214, 0.1615646734717302, 0.14477297372650355, 0.2015534753445536, 0.15317362529458478, 0.21741578355431557, 0.20643434312660247, 0.43891364650335163, 0.44332289427984506, 10.925526190549135, 117.11782470345497, 101.49725809693336, 101.53309777379036, 91.80308908224106, 53.201975002884865, 78.12934800982475, 103.7809507548809, 73.54275852441788, 41.347952485084534, 0.3740613686386496, 0.4287990048760548, 1.4214120525866747, 1.5195949841290712, 0.323338721645996, 0.60187125694938, 2.5541227217763662, 4.762670611962676, 8.687692321836948, 92.83307701349258, 95.0376883149147, 109.48448270559311, 95.0183093547821, 103.55688437819481, 91.50841489434242, 85.95710277557373, 80.21121069788933, 80.5689387023449, 78.1236483156681, 79.9739058315754, 72.76558622717857, 69.4428089261055, 66.66742265224457, 67.30892702937126, 68.53740110993385, 71.72248139977455, 67.3980550467968, 67.67664849758148, 64.16397258639336, 68.36538434028625, 65.20378679037094, 68.72269436717033, 63.90238702297211, 64.71744328737259, 63.10565337538719, 65.59242233633995, 61.935065388679504, 64.36606854200363, 63.75655084848404, 62.79927581548691, 61.69874846935272, 64.32756140828133, 65.08966371417046, 65.55202290415764, 64.76199209690094, 72.00162962079048, 78.23659345507622, 82.5909774005413, 84.0988352894783, 80.16298368573189, 75.65888017416, 65.77577769756317, 61.54674142599106, 73.30839470028877, 71.46764427423477, 75.53433045744896, 69.96874630451202, 73.42775389552116, 75.36451756954193, 82.49914392828941, 54.594018906354904, 72.28753387928009, 76.78030639886856, 75.83476513624191, 80.09191229939461, 79.30411577224731, 82.04214245080948, 78.09182122349739, 75.08274748921394, 69.54158842563629, 69.9538891017437, 75.87153196334839, 75.36511793732643, 70.58103784918785, 78.21108922362328, 80.59258863329887, 65.13564884662628, 67.41934150457382, 65.26440113782883, 59.02294725179672, 60.62129348516464, 59.29869845509529, 58.89482572674751, 60.75620524585247, 62.886868715286255, 62.813749238848686, 63.90129268169403, 61.13515131175518, 63.48459184169769, 63.22018302977085, 62.88037866353989, 61.86794579029083, 64.0176272392273, 63.53336602449417, 63.06078918278217, 66.9339707493782, 71.97740212082863, 72.85551220178604, 69.66578856110573, 72.87053659558296, 69.84377861022949, 76.91607311367989, 81.52317389845848, 85.47118484973907, 79.78531435132027, 79.21687245368958, 27.64707136899233, 1.459466298110783, 7.459967751055956, 6.9807920884341, 0.5296237149741501, 1.9592696288600564, 5.029591089114547, 1.4022166701033711, 0.5102800216991454, 0.3157904266845435, 11.18969751521945, 45.073907151818275, 59.0011440217495, 72.97420263290405, 30.418579950928688, 28.80205739289522, 66.1170145869255, 91.56452268362045, 76.17303058505058, 99.60441246628761, 41.07461795210838, 0.5312234291341156, 0.21085157641209662, 0.1527709953370504, 0.25219543604180217, 0.2496640000026673, 0.15221368696074933, 0.15488365228520706, 0.17779050045646727, 0.11548044203664176, 0.17454850254580379, 0.14242633245885372, 0.20616580441128463, 0.14198249846231192, 0.1159213000210002, 0.10153339433600195, 0.2078104778775014, 0.10389316419605166, 0.11573961484828033, 0.14419582032132894, 0.12905211886391044, 0.1290526828961447], [0.021358676167437807, 0.06837992099463008, 0.022087478173489217, 0.03803598498052452, 0.09730848119943403, 0.015999208480934612, 0.019311816176923458, 0.00815531702755834, 0.07242662220960483, 0.048736604148871265, 0.11443292285548523, 0.058673950406955555, 0.06464233170845546, 0.023085536922735628, 0.011827478574559791, 0.11392546453862451, 0.199869898497127, 0.22239755373448133, 46.72500975430012, 92.74666965007782, 76.93852990865707, 75.60465708374977, 52.1396242082119, 29.452058114111423, 40.014220252633095, 70.1271978020668, 46.10880061984062, 6.064508305862546, 0.25237741065211594, 0.26375453453511, 0.6137004971969873, 0.6041006685700268, 0.27655830373987556, 0.3384082083357498, 0.3479508915916085, 0.5427089065779, 46.93712957203388, 100.13579115271568, 93.70180919766426, 98.26756820082664, 90.81176027655602, 91.673044860363, 84.03258964419365, 86.87313482165337, 79.22816544771194, 78.92254024744034, 77.1419557929039, 78.53521183133125, 74.53515127301216, 69.55066233873367, 60.533210411667824, 62.41181440651417, 58.41419331729412, 61.0404983907938, 59.11616764962673, 58.79107989370823, 57.70919054746628, 59.05097454786301, 57.41427697241306, 57.223128229379654, 55.68881995975971, 56.606778502464294, 56.47162735462189, 58.101382702589035, 54.11128520965576, 56.91474437713623, 54.27995055913925, 54.64223071932793, 54.51249808073044, 57.420375645160675, 57.74165980517864, 60.6364356726408, 57.9939890652895, 60.68180903792381, 69.02317464351654, 74.98810216784477, 74.44983065128326, 80.79993590712547, 73.32289472222328, 71.66375175118446, 57.0800507068634, 56.88442960381508, 54.032378643751144, 59.20980602502823, 60.194637179374695, 65.18606454133987, 63.36348094046116, 71.38782575726509, 47.41448275744915, 68.04030418395996, 67.51397162675858, 64.70419719815254, 68.21195617318153, 71.06820210814476, 66.47071480751038, 65.48937186598778, 59.48670856654644, 61.43698051571846, 65.02567514777184, 69.68328282237053, 70.61422526836395, 67.22352281212807, 70.95242232084274, 71.81397289037704, 59.686163663864136, 60.65348155796528, 63.5330506414175, 56.32607236504555, 50.57398661971092, 53.82802560925484, 51.37321673333645, 52.37051501870155, 53.61279755830765, 51.77355945110321, 50.94069354236126, 53.35459381341934, 55.63012830913067, 54.239007756114006, 55.09346790611744, 57.5776682049036, 55.321778655052185, 55.56332789361477, 55.03439627587795, 58.92053134739399, 58.33182513713837, 59.56868536770344, 61.53409570455551, 60.497127547860146, 64.65188920497894, 67.8840109705925, 73.70554938912392, 76.82537958025932, 75.86772456765175, 74.80060502886772, 84.08644795417786, 49.715578481554985, 0.8742691401857883, 1.6900946851819754, 1.402064678259194, 0.2527642180211842, 0.1813432207563892, 0.5983209412079304, 0.09768175921635702, 0.04360485705547035, 0.026207076844002586, 17.622599378228188, 27.046574391424656, 53.92991714179516, 50.27362033724785, 28.06314904242754, 43.05719196796417, 51.95015497505665, 60.39893701672554, 64.32435438036919, 62.8609237074852, 1.4674079907126725, 0.08240184397436678, 0.0017350881580568966, 0.056540402001701295, 0.00826175584734301, 0.030521197986672632, 0.043464620830491185, 0.0801041918748524, 0.035271933884359896, 0.0248433266824577, 0.06910286188940518, 0.01805014100682456, 0.03529188652464654, 0.027301056325086392, 0.045515601595980115, 0.03764866924029775, 0.015419475184899056, 0.027245447199675255, 0.019531836987880524, 0.042983397433999926, 0.040885616836021654, 0.02049678296316415, 0.02619580176542513, 0.051095375820295885, 0.048150296352105215, 0.04565196381008718, 0.058799391918000765, 0.05062085030658636, 0.055666178013780154, 0.04155661110416986, 0.07388696845737286, 0.08686854140250944, 0.01581055639690021, 0.022582117744605057, 0.01502147808423615, 0.05503616514033638, 0.02743844270298723, 0.10982822306687012, 0.24767474737018347, 61.95121452212334, 102.48937726020813, 87.79646247625351, 82.5432975590229, 67.59081870317459, 40.72102792561054, 26.910782977938652, 56.04669235646725, 48.67989085614681, 7.877828953787684, 0.30854136566631496, 0.9099328389856964, 2.3693319875746965, 2.265499234199524, 1.2741020321846008, 1.164139376487583, 0.06995187883148901, 1.0782764526084065, 53.84152248501778, 103.71893808245659, 96.03661671280861, 101.15207701921463, 94.99534338712692, 97.7920313179493, 89.10865366458893, 89.36317160725594, 82.47118502855301, 83.39773491024971, 82.26424813270569, 81.81711852550507, 78.54581326246262, 73.23633536696434, 65.76419591903687, 66.3855005800724, 62.71367400884628, 63.932998180389404, 62.9647721350193, 63.52991200983524, 60.88952489197254, 62.65317365527153, 60.16198933124542, 59.50769864022732, 58.33408981561661, 62.07148566842079, 60.95025323331356, 61.301582381129265, 57.170007079839706, 60.31916029751301, 56.82479940354824, 57.5433636456728, 57.88538709282875, 59.29299496114254, 60.16800060868263, 63.80639657378197, 61.10362060368061, 63.20143103599548, 72.71781519055367, 77.11671754717827, 77.52636596560478, 84.84984219074249, 77.17159420251846, 73.36722314357758, 61.401885598897934, 58.301407769322395, 56.990432515740395, 62.91654132306576, 63.072891533374786, 67.87287756800652, 69.6209205687046, 74.19418036937714, 51.74151957035065, 70.69322302937508, 73.01802188158035, 68.88699755072594, 71.2573179602623, 73.41293469071388, 68.3132891356945, 68.41608121991158, 62.1895719319582, 63.281515538692474, 68.46278831362724, 74.75895166397095, 73.8444471359253, 69.85988974571228, 73.06609690189362, 75.7371711730957, 61.98508970439434, 62.26361095905304, 66.20249480009079, 58.459182903170586, 53.41387823224068, 56.5193147957325, 54.732190892100334, 56.69707305729389, 55.020454823970795, 54.42987151443958, 55.93439698219299, 55.64030796289444, 58.10002617537975, 57.159664034843445, 58.0639623105526, 60.087053552269936, 60.0125053524971, 59.64807830750942, 58.33332225680351, 61.33940935134888, 62.186866477131844, 64.67409521341324, 66.13526120781898, 65.19756272435188, 68.44222381711006, 72.47926399111748, 77.86773964762688, 81.1412563920021, 81.09901785850525, 77.6632422208786, 87.6439842581749, 63.597742170095444, 2.0386889297515154, 1.1674602795392275, 0.3860239579807967, 0.34032039635349065, 2.3477942682802677, 1.231817901134491, 0.4593796451808885, 0.11082322787842713, 0.03174077297444455, 17.736861146986485, 34.29829716682434, 43.853849619627, 24.49154019355774, 31.35578826069832, 53.36233779788017, 55.24957112967968, 70.52124425768852, 69.74496111273766, 82.0941236615181, 5.709234969690442, 0.2589593699667603, 0.021611355186905712, 0.03663681025500409, 0.045386545825749636, 0.018807491578627378, 0.08313317855936475, 0.08594283091952093, 0.030627996748080477, 0.02942537426861236, 0.04162610952334944, 0.010321518075215863, 0.04149452674027998, 0.01870401578344172, 0.022789399590692483, 0.0075308104260329856, 0.08778049988904968, 0.034443967961124144, 0.035728002185351215, 0.027740750992961694, 0.03354321961523965, 0.10662875763955526, 0.12323550676228479, 0.12741808779537678, 0.1483154227025807, 0.20121467008721083, 0.14025728713022545, 0.13124871271429583, 0.17386805702699348, 0.12874788284534588, 0.15933861635858193, 0.25982913735788316, 0.13086928229313344, 0.28361274395138025, 0.17534610349684954, 0.22467996954219416, 0.22156153921969235, 0.48700303479563445, 0.5949185800272971, 68.98513868451118, 119.84430760145187, 101.73938110470772, 97.41528153419495, 72.79025450348854, 40.916098058223724, 60.80778747797012, 96.01932004094124, 70.39743930101395, 11.113332062959671, 0.3821432084077969, 1.5967838047072291, 4.483508616685867, 3.195449933409691, 0.9752445656340569, 3.804382220841944, 4.474560571834445, 1.3253406202420592, 53.871183693408966, 105.91926321387291, 99.45539206266403, 103.07887762784958, 99.16939660906792, 103.7220311164856, 89.69048604369164, 93.11407953500748, 85.7177460193634, 85.75407966971397, 85.45625165104866, 87.16574192047119, 79.9197207391262, 77.82004460692406, 68.48338320851326, 70.53445994853973, 65.6175921857357, 66.43671423196793, 65.21153837442398, 65.6616698205471, 65.67330479621887, 67.33204498887062, 64.69975143671036, 63.00836339592934, 62.46007941663265, 66.2377417087555, 65.4267892241478, 65.82135245203972, 59.999810233712196, 64.44756656885147, 59.953201934695244, 60.489512756466866, 61.88334636390209, 64.09268841147423, 62.63634815812111, 67.3230242729187, 64.1563729941845, 67.03485533595085, 74.89690706133842, 81.671282351017, 81.76460534334183, 88.78155201673508, 80.91067716479301, 78.65441903471947, 64.18962121009827, 63.74030292034149, 59.417563676834106, 64.6913006901741, 67.61215835809708, 72.23450392484665, 69.82040986418724, 76.8853859603405, 55.01472093164921, 73.25933933258057, 78.84039625525475, 72.37669989466667, 76.55981943011284, 77.70000144839287, 72.69168019294739, 73.95901098847389, 66.23449668288231, 67.53237783908844, 72.29254961013794, 78.414948284626, 78.72045189142227, 71.85539066791534, 75.93827158212662, 79.28894698619843, 63.96227180957794, 64.68019008636475, 68.72014850378036, 62.58609585464001, 57.001090943813324, 59.713347405195236, 56.41811862587929, 60.35594992339611, 59.40757781267166, 58.69033969938755, 59.85512539744377, 59.090416431427, 61.909838542342186, 60.67872740328312, 61.22711777687073, 63.91551911830902, 61.63135528564453, 62.530166655778885, 62.42740876972675, 66.72058939933777, 65.81667870283127, 68.43321830034256, 70.03030300140381, 70.21466910839081, 72.81888216733932, 76.23462527990341, 81.97623878717422, 85.12607216835022, 84.62395191192627, 80.00470697879791, 90.98393663764, 58.06953281164169, 0.8009694702923298, 3.9376481948420405, 7.740074470639229, 0.7119807391427457, 2.7187902107834816, 3.5758449090644717, 0.36792107624933124, 0.2670478296931833, 0.2787279576295987, 28.702003061771393, 44.53435890376568, 76.58541485667229, 70.09373679757118, 37.78087869286537, 59.94885116815567, 67.29270949959755, 81.05897560715675, 81.04311525821686, 97.1528448164463, 6.110890042036772, 0.5409827898256481, 0.15686475613620132, 0.10305025512934662, 0.13599700323538855, 0.15360856836196035, 0.3377771453233436, 0.1554355281405151, 0.10462944148457609, 0.1557049129041843, 0.1118147445959039, 0.1326740815420635, 0.08293561142636463, 0.1313308981480077, 0.15037210687296465, 0.08720010329852812, 0.31480452802497894, 0.1232782618899364, 0.08437372292974032, 0.19997753959614784, 0.15783753362484276], [0.021069459362479392, 0.055609615228604525, 0.048418048390885815, 0.03321384334412869, 0.04516427630733233, 0.021157895534997806, 0.02336753263080027, 0.0948699472064618, 0.08510405561537482, 0.04218431960907765, 0.0643260357901454, 0.06774323992431164, 0.025551500693836715, 0.09677881040261127, 0.08995251380838454, 0.05287510903144721, 0.2028975196299143, 6.1398297641426325, 77.0411927998066, 71.20251730084419, 75.72948038578033, 57.81132906675339, 30.68371832370758, 50.46062350273132, 153.3098566532135, 73.95230054855347, 26.7208843678236, 0.6586561817675829, 0.027694693308149, 2.632540538907051, 0.7244655629619956, 0.5807589367032051, 1.0947409691289067, 1.325065609999001, 0.9322071250062436, 13.366475310176611, 97.39626735448837, 88.49872559309006, 93.56193110346794, 90.41967451572418, 93.6239741742611, 91.1875981092453, 95.04347920417786, 88.53122904896736, 86.15932032465935, 81.18826746940613, 86.0409414768219, 82.82950580120087, 81.18537202477455, 73.45337972044945, 68.61962109804153, 58.74510616064072, 63.164671808481216, 59.55720238387585, 60.385804921388626, 57.60098375380039, 59.566367492079735, 55.78170217573643, 57.499806582927704, 56.740261539816856, 55.21355286240578, 57.797410413622856, 56.325460597872734, 55.08586071431637, 54.941837042570114, 54.89638768136501, 55.93793459236622, 55.99471494555473, 56.95075884461403, 56.15927651524544, 57.16103956103325, 60.498104095458984, 56.04353092610836, 53.97357299923897, 58.76703858375549, 67.58990675210953, 70.45971795916557, 71.73704221844673, 76.72929033637047, 69.06940296292305, 69.74450513720512, 60.117280930280685, 58.41510146856308, 61.66999541223049, 63.3731210231781, 65.27923554182053, 67.88485452532768, 68.95620703697205, 51.776831075549126, 66.5732029080391, 70.41411280632019, 67.1986873447895, 62.98239178955555, 65.2889934182167, 65.40731906890869, 63.23433727025986, 65.97975075244904, 65.63252538442612, 68.01809817552567, 71.1420701444149, 70.25251507759094, 68.14390182495117, 70.32345727086067, 68.12073066830635, 61.159158423542976, 56.76598235964775, 65.93062698841095, 57.55286693572998, 52.58437894284725, 52.563681453466415, 51.119473949074745, 52.389210015535355, 52.15701587498188, 51.23955890536308, 51.52519717812538, 54.93009187281132, 53.133263289928436, 54.6109925955534, 54.1902981698513, 53.92976514995098, 55.061025246977806, 56.21700681746006, 55.12921258807182, 56.8034977465868, 61.02027587592602, 60.967253521084785, 59.38205078244209, 61.51826195418835, 59.83559064567089, 67.85081595182419, 69.49184909462929, 74.603441208601, 77.48310148715973, 78.18333551287651, 70.58286175131798, 83.58570322394371, 75.43984472751617, 3.19949671626091, 1.671126103028655, 2.408411465585232, 1.287653767503798, 1.3764611771330237, 0.9908801922574639, 0.1397702601389028, 0.06254258812987246, 4.246886288747191, 25.462241806089878, 32.50086061656475, 72.17147290706635, 26.023302599787712, 18.95696807652712, 48.19947883486748, 57.872767969965935, 59.632328152656555, 67.67661049962044, 30.040196254849434, 0.4837675084127113, 0.029015534346399363, 0.05193036988202948, 0.024209504736063536, 0.04602998786140233, 0.021520137815969065, 0.03982611568062566, 0.06923169130459428, 0.06137514530564658, 0.04369378490082454, 0.025109269736276474, 0.07683670861297287, 0.03411519654036965, 0.05854447532328777, 0.019598075523390435, 0.057876523860613815, 0.02575192880613031, 0.02538764376367908, 0.05847533684573136, 0.07512803233112209, 0.05333086934115272, 0.06081448984332383, 0.12159901176346466, 0.03788266098126769, 0.022518907171615865, 0.0972152674512472, 0.020865402148046996, 0.02255140210763784, 0.023098248057067394, 0.11157751709106378, 0.06117650576925371, 0.04246192365826573, 0.05006856627005618, 0.07975124128279276, 0.05223240172199439, 0.12684427405474707, 0.15955575392581522, 12.34215572476387, 97.57124796509743, 77.93226018548012, 88.26764479279518, 68.83855015039444, 54.07224990427494, 53.69448557496071, 109.45628061890602, 64.74752247333527, 33.761021196842194, 0.6592251418624073, 0.21551312471274287, 4.3707833904773, 2.08711258135736, 2.6389355957508087, 1.952968379482627, 0.650864759227261, 0.6760560418479145, 17.750240229070187, 103.3521893620491, 89.77052494883537, 98.12125325202942, 93.40129852294922, 96.81487575173378, 96.84020519256592, 99.77288782596588, 91.18376791477203, 93.05665701627731, 87.12971225380898, 89.61634442210197, 88.23546811938286, 82.61623084545135, 77.72682040929794, 71.59980118274689, 63.53420577943325, 64.86206352710724, 63.73011566698551, 63.90396773815155, 60.13306528329849, 62.55065135657787, 59.89575281739235, 60.064140781760216, 59.19565178453922, 61.176109313964844, 59.71080154180527, 60.48116460442543, 57.5872702896595, 58.472706377506256, 56.88022702932358, 59.23350915312767, 59.09475199878216, 60.74459306895733, 58.0866052955389, 60.915245711803436, 63.09612728655338, 58.65757405757904, 55.16386292874813, 61.13873451948166, 70.58559000492096, 73.8344232738018, 73.4505906701088, 80.06954669952393, 72.61415675282478, 72.47636094689369, 62.032180577516556, 61.41250602900982, 63.37865352630615, 65.64910769462585, 67.02405631542206, 70.72212427854538, 74.02669295668602, 54.9397661536932, 68.48142251372337, 71.09727054834366, 70.56500270962715, 67.71802067756653, 66.19158938527107, 67.7112190425396, 64.87071186304092, 70.48543497920036, 69.68686982989311, 71.16782516241074, 73.87638062238693, 71.97460547089577, 68.93565773963928, 72.41389229893684, 71.43340811133385, 61.78762190043926, 60.6787084043026, 67.87499025464058, 61.896546855568886, 56.72979690134525, 55.34438744187355, 53.639935702085495, 53.92466202378273, 56.666332706809044, 55.0693392008543, 55.12550778687, 57.93934799730778, 56.808836460113525, 56.89402408897877, 57.481833547353745, 57.19047278165817, 57.62089088559151, 58.72252397239208, 58.0824863165617, 59.897379130125046, 64.66819792985916, 62.799264416098595, 63.770268112421036, 63.49284119904041, 64.89666447043419, 72.68550932407379, 73.23375150561333, 77.42561057209969, 79.4195231795311, 83.36485147476196, 74.46939200162888, 86.67014971375465, 88.97869303822517, 7.013822766020894, 1.9461196032352746, 0.9160204092040658, 1.2023351644165814, 1.3689219066873193, 1.3260763557627797, 0.7818701514042914, 0.20273460337193683, 3.694159872829914, 30.23772105574608, 35.53897999227047, 43.22879076004028, 20.54193902760744, 30.1046084985137, 58.55725184082985, 64.80793163180351, 65.84263890981674, 78.60172346234322, 51.040916964411736, 0.666035742033273, 0.023681104867137037, 0.038687920896336436, 0.01057574354490498, 0.012005945609416813, 0.0042662345276767155, 0.03926898913050536, 0.013448504432744812, 0.01938797351613175, 0.04273910839401651, 0.012749326178891351, 0.07442137415637262, 0.051197717984905466, 0.08466484519885853, 0.002432109081382805, 0.08013857557671145, 0.007046066930342931, 0.01124714228353696, 0.013613365117635112, 0.12831957457819954, 0.09741663438035175, 0.1662042987300083, 0.14738865836989135, 0.10291749975294806, 0.12464425148209557, 0.19755177054321393, 0.08853102641296573, 0.1525657915044576, 0.16878373688086867, 0.1793110868311487, 0.24230959854321554, 0.11884877574630082, 0.08998936886200681, 0.267435735440813, 0.31720694911200553, 0.23603727808222175, 0.5082417873200029, 13.06255241855979, 112.20427796244621, 91.98350340127945, 101.07132375240326, 80.58144003152847, 49.10810887813568, 69.99987423419952, 175.13965487480164, 92.273990213871, 47.84617379307747, 1.4576026168651879, 0.18733606324531138, 7.938515497371554, 2.957810922525823, 3.676160001195967, 6.233947863802314, 8.22547372430563, 3.0233110953122377, 16.72439217567444, 108.97840306162834, 95.4504981637001, 101.10547631978989, 96.82909458875656, 100.33544763922691, 97.24163845181465, 104.65067848563194, 96.46881312131882, 96.693464666605, 89.85195457935333, 94.16710183024406, 90.92170357704163, 89.12645190954208, 81.06138467788696, 76.57536819577217, 65.2297393977642, 70.93885704874992, 67.96735569834709, 66.5598276257515, 63.459665179252625, 67.34193965792656, 62.38042049109936, 64.56769332289696, 60.605877712368965, 63.41238051652908, 62.75533877313137, 63.62516909837723, 61.64715103805065, 60.57708665728569, 61.79723158478737, 62.789609134197235, 62.15605013072491, 64.2799423635006, 61.935460567474365, 64.02462646365166, 65.83392977714539, 62.02262029051781, 58.006327003240585, 63.27961564064026, 73.33098068833351, 77.57950231432915, 75.23919269442558, 83.65997403860092, 76.99451610445976, 78.47723454236984, 64.56431150436401, 64.74819123744965, 67.71125704050064, 69.82477203011513, 71.1717389523983, 74.15458649396896, 77.22062677145004, 60.46959802508354, 72.22603797912598, 76.09688267111778, 74.07124936580658, 71.94391071796417, 70.18846571445465, 71.29210129380226, 68.42368841171265, 72.90459036827087, 73.26233357191086, 74.06067833304405, 77.57735162973404, 76.54301673173904, 72.72832542657852, 75.6577630341053, 73.40975806117058, 66.84695541858673, 63.865734189748764, 70.19061639904976, 65.8237387239933, 58.71733345091343, 59.34171974658966, 56.28040261566639, 58.05069722235203, 60.41020721197128, 57.74497702717781, 58.58026720583439, 62.784164026379585, 60.28778538107872, 62.12640792131424, 62.02716484665871, 59.73513923585415, 61.47110268473625, 62.25428245961666, 61.8400514870882, 62.87285506725311, 69.70702394843102, 67.35808879137039, 66.77683398127556, 67.86409243941307, 68.81933838129044, 75.4530680179596, 76.91738024353981, 81.53483927249908, 83.10581937432289, 86.92181780934334, 77.85631746053696, 91.75363093614578, 85.61222568154335, 3.5194046376273036, 5.381410885602236, 8.693614304065704, 2.914266209118068, 4.639139715582132, 2.735642781481147, 0.5179230740759522, 0.2951714862138033, 6.944187702611089, 43.5169292986393, 49.71115171909332, 103.75663965940475, 36.39573521912098, 29.972977861762047, 64.00180488824844, 78.87376606464386, 77.70355805754662, 92.91389107704163, 52.3663504421711, 0.6033933127764612, 0.1536178748938255, 0.21281898021697998, 0.1304335822351277, 0.11583904779399745, 0.1214251339843031, 0.17349355446640402, 0.15800352237420157, 0.09276618860894814, 0.17401262739440426, 0.12309456549701281, 0.26858924073167145, 0.09625546270399354, 0.16780683305114508, 0.10434733630972914, 0.19322619249578565, 0.10434452357003465, 0.23039317078655586, 0.13409611070528626, 0.28052383626345545], [0.02226190143119311, 0.027112279931316152, 0.03612649466958828, 0.07714339371887036, 0.02833681988704484, 0.06485783655080013, 0.009191724402626278, 0.08647656868561171, 0.01605634457519045, 0.06035167913069017, 0.04048997048812453, 0.08435930300038308, 0.029741675753029995, 0.21300571941537783, 0.09347827188321389, 0.19351123657543212, 0.4016126214992255, 30.77548149973154, 83.76082822680473, 78.84667351841927, 64.91675019264221, 57.29834899306297, 21.791794560849667, 56.803725734353065, 82.90112435817719, 40.87350994348526, 13.351359721273184, 0.2302590201725252, 0.21713685477152467, 1.0812193946912885, 0.8427498314995319, 3.3308608923107386, 1.6006858390755951, 0.9888129844330251, 1.3874758360907435, 64.69465970993042, 96.42302557826042, 82.76218101382256, 92.04964265227318, 89.67601642012596, 94.3877711892128, 87.29533776640892, 84.63865712285042, 85.97905039787292, 88.47359374165535, 86.53334185481071, 88.7897139787674, 83.3943758904934, 80.05327597260475, 75.06325453519821, 72.82650455832481, 64.24068287014961, 59.79251615703106, 59.23827789723873, 59.3147411942482, 58.69905263185501, 55.96013680100441, 56.562290489673615, 56.33129708468914, 56.8298227339983, 56.645152643322945, 55.95374554395676, 57.176823914051056, 55.13836249709129, 54.48863536119461, 54.17060002684593, 54.755362048745155, 56.20670177042484, 56.62562549114227, 56.108731627464294, 57.03180089592934, 55.72152100503445, 52.97784022986889, 61.62887401878834, 67.86464720964432, 66.88960433006287, 69.64951783418655, 71.52979373931885, 75.93827158212662, 72.40797221660614, 70.53523510694504, 68.04130733013153, 64.35912251472473, 62.17735558748245, 61.76858112215996, 63.4709619730711, 64.2543925344944, 69.13352072238922, 48.084964379668236, 66.753199249506, 68.90819281339645, 69.10842686891556, 67.06934228539467, 66.68050155043602, 70.58483004570007, 69.91759344935417, 70.61656594276428, 68.54719698429108, 70.21904647350311, 67.57280766963959, 68.09405609965324, 67.06551969051361, 69.6221213042736, 65.53031086921692, 58.32343138754368, 53.04081045091152, 64.56127926707268, 65.66667795181274, 55.49377262592316, 52.0532738417387, 51.52395464479923, 49.283670857548714, 52.123722061514854, 50.42976535856724, 52.23008595407009, 51.23162493109703, 53.15003179013729, 53.94088335335255, 54.83125917613506, 54.131842106580734, 54.96039144694805, 55.59141218662262, 55.38796730339527, 58.31257537007332, 59.23947863280773, 57.86575734615326, 60.29260732233524, 58.89254964888096, 60.95635950565338, 62.945358976721764, 70.92831641435623, 70.94992965459824, 69.2708757519722, 68.41563284397125, 76.57724529504776, 72.8814572095871, 80.95357686281204, 82.88034707307816, 5.03150001168251, 1.6799206123687327, 1.9404545822180808, 0.8129652484785765, 0.6836412067059427, 0.3209656599210575, 0.17857696919236332, 0.026599097800499294, 13.92165781930089, 25.38114845752716, 39.58421252667904, 51.008124724030495, 23.254461474716663, 36.523613557219505, 57.74116963148117, 60.74369631707668, 62.21098378300667, 74.17753726243973, 8.978072740137577, 0.33102104847785085, 0.10732439492130652, 0.0742894277209416, 0.04844483992201276, 0.009976356323022628, 0.023774628461978864, 0.02388484666880686, 0.00924594478419749, 0.06813665982917883, 0.08006245348951779, 0.031873606276349165, 0.026012565504061058, 0.045102759686415084, 0.026653302411432378, 0.03190559284121264, 0.028477006017055828, 0.03116289597528521, 0.004189821147519979, 0.02505849755834788, 0.026247228888678364, 0.02259680855786428, 0.02329035854927497, 0.06032888406480197, 0.032969724998110905, 0.056645415897946805, 0.03245426261855755, 0.07951031046104617, 0.10337596890167333, 0.042020512773888186, 0.04878774554526899, 0.11518816943862475, 0.08707254295586608, 0.13246846210677177, 0.16567679500440136, 0.25887458701618016, 0.41153777798172086, 45.187794640660286, 99.05365481972694, 87.49956920742989, 73.6359067261219, 69.13656055927277, 36.71323098242283, 62.20364257693291, 80.08796811103821, 43.112923577427864, 16.755352914333344, 0.517999604344368, 0.7977459963876754, 2.025220077484846, 1.890774741768837, 3.722782786935568, 1.2469705380499363, 0.36413086869288236, 2.3489434691146016, 72.34684109687805, 99.45062711834908, 87.1406252682209, 95.08463859558105, 94.61606293916702, 96.78962990641594, 90.4297211766243, 87.42278292775154, 88.8141618669033, 93.0792810022831, 90.72706282138824, 90.62459751963615, 86.44829481840134, 82.10727095603943, 79.16756629943848, 76.16364508867264, 68.51396396756172, 63.53763319551945, 62.41516202688217, 63.641261234879494, 62.10449829697609, 58.56289453804493, 59.66035544872284, 60.16611211001873, 59.173521772027016, 60.050377920269966, 59.211759120225906, 59.12967212498188, 59.54810947179794, 58.60773593187332, 58.000547513365746, 57.165777906775475, 59.86720874905586, 60.03093436360359, 58.1980799138546, 60.879117250442505, 57.57630407810211, 55.090454667806625, 65.62270671129227, 69.73448127508163, 68.9735721051693, 71.34142264723778, 74.0863573551178, 76.8736369907856, 78.01408499479294, 75.28824806213379, 72.26259961724281, 66.86325654387474, 66.13118022680283, 67.05767691135406, 65.63428089022636, 68.26459094882011, 72.92139306664467, 51.504089310765266, 70.06680384278297, 71.95113033056259, 72.64935046434402, 71.46710470318794, 70.7877391576767, 73.23937520384789, 73.13621073961258, 73.45133543014526, 72.8576248884201, 72.3784402012825, 70.2063475549221, 69.19857323169708, 70.75183108448982, 71.33643731474876, 69.29739832878113, 60.954862385988235, 54.98433776199818, 65.62387704849243, 68.93028482794762, 56.42175883054733, 54.06747356057167, 54.00362938642502, 53.38083140552044, 54.30272653698921, 53.23946379125118, 55.70622302591801, 54.48743462562561, 55.8706896007061, 56.72410860657692, 57.27012790739536, 57.19634726643562, 58.09974879026413, 58.49331647157669, 58.656909093260765, 60.928647592663765, 62.40637689828873, 62.951928824186325, 63.020359352231026, 63.21552827954292, 63.364180102944374, 65.00922963023186, 72.14875012636185, 75.68828299641609, 71.0184171795845, 71.65704131126404, 79.57750350236893, 77.71953999996185, 79.5086207985878, 94.62416410446167, 9.42034050822258, 0.9722079942002892, 1.1346898879855871, 1.1711912043392658, 2.219710028730333, 0.8493233600165695, 0.32949718181043863, 0.018154177123506088, 16.731877774000168, 35.02784661948681, 36.6475211083889, 38.08179594576359, 32.837894931435585, 51.41035594046116, 65.97785085439682, 68.9116658270359, 68.07650864124298, 86.60867661237717, 16.39047559350729, 0.3107664728304371, 0.06561841175425798, 0.08655463519971818, 0.07884694176027551, 0.07104219766915776, 0.012375792121019913, 0.0380601567303529, 0.05541141355934087, 0.02082068589515984, 0.0302162717707688, 0.1406568000675179, 0.01809797242458444, 0.06144793514977209, 0.050676259052124806, 0.03930188111553434, 0.008866608986863866, 0.01539882956421934, 0.06783832388464361, 0.0306178775645094, 0.14637377142207697, 0.07627579339896329, 0.12455004325602204, 0.2008066966664046, 0.16382077272282913, 0.17444866884034127, 0.11487420386401936, 0.13887346372939646, 0.14676531369332224, 0.23479536816012114, 0.22796829231083393, 0.22724922542693093, 0.2135257126064971, 0.3581606171792373, 0.4630647349404171, 0.5716885859146714, 0.840222432743758, 55.79663537442684, 112.21774443984032, 103.4478834271431, 82.8270511329174, 77.15522468090057, 30.896009132266045, 76.93150788545609, 101.1432158946991, 59.855376183986664, 23.96379791200161, 0.7363679492846131, 0.8431155618745834, 3.2970351073890924, 3.193691340275109, 8.029528688639402, 7.675998033955693, 3.9850295148789883, 1.8437205604277551, 74.57570269703865, 104.3575394153595, 91.22831672430038, 101.80315688252449, 97.99196138978004, 98.28583002090454, 95.35357296466827, 90.71455389261246, 91.39064401388168, 96.87048956751823, 91.94271638989449, 94.05743971467018, 89.19595777988434, 87.04496160149574, 82.4319027364254, 79.92406010627747, 72.60239258408546, 67.8022013604641, 65.49700945615768, 68.71616631746292, 66.10061466693878, 61.68951876461506, 63.53121154010296, 63.2562392950058, 62.88685351610184, 64.24331232905388, 61.98410555720329, 62.99387477338314, 61.76474712789059, 61.537469923496246, 59.68471214175224, 60.789464861154556, 63.622980415821075, 63.631142377853394, 60.65685197710991, 62.93788477778435, 60.77840365469456, 58.79406653344631, 68.07691141963005, 71.72828748822212, 72.65909314155579, 75.13709977269173, 77.21536785364151, 81.49473622441292, 78.86924430727959, 77.77157440781593, 75.0916314125061, 70.73624432086945, 67.75553226470947, 68.69849726557732, 67.64418303966522, 71.76679462194443, 75.22270917892456, 56.84022657573223, 70.81533327698708, 73.76312389969826, 76.77120968699455, 74.93739768862724, 73.5299988090992, 80.18688440322876, 79.6332997083664, 77.5594013929367, 76.68748497962952, 76.76436245441437, 72.48715236783028, 74.64765563607216, 70.38945972919464, 73.7005640566349, 71.5084844827652, 63.726996034383774, 57.358051389455795, 69.13798168301582, 71.48852795362473, 57.79622867703438, 57.8232566267252, 57.84015811979771, 56.026804223656654, 57.95320965349674, 57.42432363331318, 59.850653037428856, 57.71618977189064, 58.16577024757862, 60.179099813103676, 60.338546857237816, 60.46513706445694, 60.96875064074993, 63.08012634515762, 62.677496150135994, 65.32780453562737, 65.21403104066849, 66.67446747422218, 66.66228532791138, 65.74040919542313, 65.57753473520279, 68.60583543777466, 78.41792732477188, 78.43339249491692, 77.3631951212883, 74.19188529253006, 84.47269722819328, 81.00896269083023, 84.78921264410019, 97.03806817531586, 5.82873665727675, 4.079285832121968, 8.190668541938066, 2.30399401858449, 3.665630528703332, 0.6396149285137653, 0.31807962572202086, 0.1467391158803366, 25.18217023462057, 43.23751889169216, 55.653124675154686, 69.82055425643921, 33.25652226805687, 50.95186114311218, 74.67022642493248, 79.67097088694572, 79.48946982622147, 97.22479775547981, 14.188509900122881, 0.5594711727462709, 0.22109563375124708, 0.24966863100416958, 0.1389380157343112, 0.13791150675388053, 0.12933300691656768, 0.12454995419830084, 0.13185295450966805, 0.12846895406255499, 0.25399555976036936, 0.1939964378834702, 0.10297259679646231, 0.14322924718726426, 0.2351306556374766, 0.17400630429619923, 0.10362314118538052, 0.1729440237977542, 0.12610139907337725, 0.13208239688538015], [0.021396024749265052, 0.06846317512099631, 0.0563246596721001, 0.050334188345004804, 0.0410846831073286, 0.05267701868433505, 0.035383111317059956, 0.028768729425792117, 0.03767450340092182, 0.035215367388445884, 0.04400097837788053, 0.017840933287516236, 0.07177641178714111, 0.07473524325178005, 0.013754151459579589, 0.04693688119004946, 0.5461162549909204, 59.907608181238174, 79.59458738565445, 75.25450587272644, 60.14585919678211, 47.038318142294884, 40.410238802433014, 54.12741154432297, 22.644022330641747, 29.900899529457092, 1.9499546661973, 0.1570288449875079, 0.9061646880581975, 1.0484924633055925, 2.123012342490256, 2.062911679968238, 0.4865608038380742, 0.5219488393049687, 26.512218564748764, 99.9880550801754, 85.68417102098465, 87.07643151283264, 79.91858080029488, 91.81583359837532, 86.68790996074677, 98.51919069886208, 93.16808223724365, 88.8745254278183, 89.09555956721306, 86.94492816925049, 84.71107363700867, 81.40404269099236, 76.64735913276672, 73.51125061511993, 70.10715767741203, 67.13580071926117, 58.64557810127735, 59.94241811335087, 58.798124715685844, 60.885721296072006, 55.57875506579876, 55.22321954369545, 55.45024216175079, 56.543390303850174, 56.055796667933464, 55.68429060280323, 57.75657780468464, 57.765929102897644, 56.61638058722019, 56.31492376327515, 55.89365556836128, 59.74830932915211, 57.96437345445156, 57.45145417749882, 56.68098472058773, 56.58702336251736, 63.50319944322109, 72.32734814286232, 72.64051973819733, 69.87434417009354, 67.4737697839737, 70.74750691652298, 70.46045511960983, 71.07628047466278, 71.61082819104195, 71.13696321845055, 70.22508814930916, 68.35723757743835, 64.23391923308372, 64.21490505337715, 66.9078965485096, 67.91063234210014, 49.16868142783642, 65.39791837334633, 69.58989903330803, 68.50272417068481, 70.34151390194893, 66.79215475916862, 66.07394769787788, 67.95542433857918, 68.11473459005356, 68.01755860447884, 66.79678291082382, 66.1150386929512, 67.25504592061043, 69.63814124464989, 70.3860855102539, 67.05833807587624, 56.19644612073898, 52.95129865407944, 54.84111204743385, 63.35675150156021, 62.67494648694992, 53.766343519091606, 51.75319254398346, 50.11692434549332, 50.777435302734375, 53.14658537507057, 52.385102435946465, 53.05005915462971, 53.60925234854221, 54.131876304745674, 51.77344925701618, 54.106280878186226, 53.237278908491135, 55.737202763557434, 54.98108133673668, 55.074693113565445, 58.41925084590912, 58.06677035987377, 58.721232041716576, 59.80705037713051, 56.68283522129059, 57.95241929590702, 57.95795179903507, 57.66965366899967, 58.1559743732214, 61.955705881118774, 65.89676320552826, 77.5993524491787, 74.5538766682148, 78.37210178375244, 78.75363171100616, 2.564584747888148, 0.8469343569595367, 0.9131725213956088, 0.26313234760891646, 2.8342327661812305, 0.006039477657395764, 0.143913492502179, 1.7386747221462429, 20.8088918030262, 28.430916108191013, 63.17254118621349, 34.855560064315796, 20.90952180325985, 48.748040199279785, 56.53944231569767, 58.20625327527523, 68.68734866380692, 48.57582204043865, 1.0962922358885407, 0.09785023416043259, 0.06680106118437834, 0.016133008430188056, 0.06277942229644395, 0.03657268127426505, 0.06272623999393545, 0.07187647555838339, 0.04612150209140964, 0.049681046439218335, 0.05090505204861984, 0.03773796444875188, 0.05300997210724745, 0.025500791598460637, 0.031246695580193773, 0.03942798684875015, 0.01619038015633123, 0.009582104285073001, 0.07565258230897598, 0.0540436762094032, 0.01616801553609548, 0.12008649995550513, 0.012793097121175379, 0.022762389126000926, 0.051274522847961634, 0.028496980921772774, 0.036919011909049004, 0.029360191438172478, 0.02312380020157434, 0.05859646276803687, 0.06596431936486624, 0.012726876211672788, 0.03246643012971617, 0.024671974060765933, 0.06679701647954062, 1.9350310857407749, 84.07152235507965, 90.0816598534584, 86.89450487494469, 71.20296567678452, 69.06212255358696, 43.8940666615963, 30.82904912531376, 25.87560262531042, 34.89322364330292, 2.323806155472994, 0.12526851642178372, 2.1625112229958177, 2.586256409995258, 2.7571569895371795, 2.945591015741229, 0.3828993678325787, 0.28508958814200014, 31.507208235561848, 105.31001910567284, 89.45622861385345, 91.06266841292381, 81.96256712079048, 94.10758942365646, 89.4277073442936, 102.27828338742256, 91.65055006742477, 90.25974109768867, 89.7786945104599, 90.48595055937767, 85.52709504961967, 85.4435071349144, 79.8303571343422, 78.54778915643692, 74.87591698765755, 71.4651820063591, 63.083652555942535, 60.65777152776718, 61.15210220217705, 63.379265293478966, 60.81461191177368, 58.54191966354847, 60.108826383948326, 60.807950869202614, 59.8232489079237, 60.218347907066345, 62.21422120928764, 61.11640691757202, 58.06826747953892, 58.84844921529293, 58.52112337946892, 63.262607753276825, 60.560489147901535, 62.10529625415802, 58.9886274933815, 59.51005831360817, 68.82503047585487, 76.47297129034996, 75.08342385292053, 72.9692704975605, 70.7386001944542, 73.91686365008354, 71.74186035990715, 70.80749049782753, 73.23290035128593, 74.08539980649948, 72.4149638414383, 73.1973722577095, 67.22513392567635, 69.01794612407684, 72.83921107649803, 70.53996205329895, 52.84962370991707, 67.81740814447403, 71.57126471400261, 71.36539176106453, 71.43780067563057, 69.93379577994347, 69.52291622757912, 70.78009396791458, 69.19937118887901, 69.1329887509346, 67.44632765650749, 69.1088904440403, 69.54552501440048, 71.5349006652832, 72.85483583807945, 69.71346080303192, 60.38398861885071, 55.981107875704765, 56.27284102141857, 63.577618449926376, 65.06496503949165, 57.09064453840256, 55.973219498991966, 52.20806233584881, 54.91477869451046, 54.96742106974125, 55.255817994475365, 53.74862886965275, 56.002914905548096, 57.709015756845474, 56.15913972258568, 56.16118401288986, 55.9297726303339, 56.66113458573818, 57.797657400369644, 58.18106062710285, 62.14834414422512, 62.11399778723717, 61.020351871848106, 62.399180084466934, 60.40269881486893, 62.06941857933998, 61.70949809253216, 59.89015191793442, 62.090207263827324, 62.91778385639191, 68.70409056544304, 78.55434000492096, 79.8435652256012, 76.61427810788155, 87.27277457714081, 5.582149839028716, 0.7745524565689266, 0.5370779649820179, 1.8859536317177117, 3.1963452603667974, 0.8154645643662661, 0.2956404641736299, 1.575980989728123, 35.688843950629234, 36.9440495967865, 53.2677760720253, 31.214464344084263, 38.5639862716198, 61.514792740345, 62.2309897094965, 66.58957242965698, 74.24015790224075, 67.03240066766739, 1.8392300326377153, 0.03741701155377086, 0.044478698837338015, 0.06909959643962793, 0.034175941327703185, 0.05719793371099513, 0.07935498637380078, 0.07765091882902198, 0.06829437363194302, 0.03176366451953072, 0.03654065389127936, 0.019465726472844835, 0.05875842536624987, 0.04690247151302174, 0.06611651158891618, 0.04960903956089169, 0.027910686112591065, 0.008579562963859644, 0.1290914081619121, 0.14995199191616848, 0.07350485888309777, 0.23254168831044808, 0.1268951705424115, 0.14829161460511386, 0.1649410297977738, 0.16518706659553573, 0.08856824511894956, 0.16343588009476662, 0.06593507874640636, 0.21841417998075485, 0.08892282843589783, 0.1842442760244012, 0.26092997984960675, 0.08024996452149935, 0.23481812240788713, 2.3701539309695363, 95.17157793045044, 103.31289947032928, 98.09773251414299, 81.68898940086365, 65.88979437947273, 56.30526848137379, 76.66102319955826, 39.273685589432716, 50.01420445740223, 3.5805842047557235, 0.203450137632899, 3.0709142284467816, 4.2551627196371555, 6.6301207803189754, 7.929833913221955, 4.844133490696549, 1.6605211095884442, 32.23277360200882, 109.98316794633865, 93.89788627624512, 96.4952065050602, 86.61945283412933, 100.01456245779991, 93.0940318107605, 106.2840436398983, 96.19225636124611, 93.91105636954308, 94.1336940228939, 92.61381357908249, 90.11584281921387, 88.23486775159836, 85.07037475705147, 81.79567247629166, 77.98829957842827, 74.96732488274574, 67.30605438351631, 65.67000657320023, 64.66881349682808, 68.21601435542107, 63.37656743824482, 59.76188600063324, 61.48541271686554, 63.15678343176842, 61.740151047706604, 62.79857665300369, 65.08958771824837, 64.3702483177185, 60.91423876583576, 61.49683490395546, 61.990504413843155, 67.52103164792061, 63.71404252946377, 63.08231882750988, 61.03824511170387, 62.11954168975353, 72.46594950556755, 77.46347934007645, 77.44673743844032, 76.57666012644768, 75.23901790380478, 79.64330837130547, 74.30381208658218, 77.52948939800262, 78.7137034535408, 76.3525253534317, 77.84969821572304, 77.4356572329998, 71.3489082455635, 72.86530047655106, 74.07951772212982, 75.1866415143013, 56.242161467671394, 72.69215896725655, 76.01596221327782, 75.10056853294373, 76.42499506473541, 72.64849171042442, 72.51938983798027, 72.59913235902786, 72.61644423007965, 70.78110471367836, 70.7449534535408, 71.07532292604446, 73.91575410962105, 73.53566810488701, 76.40701442956924, 73.62163469195366, 63.859510123729706, 59.90718260407448, 59.942296519875526, 67.8759478032589, 68.20586889982224, 58.933648243546486, 58.73626783490181, 56.79028205573559, 56.843969374895096, 58.167943730950356, 57.03997425734997, 57.103119269013405, 61.36766083538532, 62.79585599899292, 57.117372304201126, 60.49060329794884, 59.8752149194479, 62.09483541548252, 60.277875512838364, 61.80676527321339, 65.23756697773933, 65.94274833798409, 66.17749974131584, 67.33651354908943, 63.709889352321625, 66.42679676413536, 65.55680304765701, 64.70301926136017, 64.31537166237831, 68.59502881765366, 74.11683931946754, 85.75532600283623, 83.80125805735588, 81.29704803228378, 87.8366719186306, 3.2878889981657267, 4.245724976062775, 4.660549191758037, 1.967748636379838, 7.347356043756008, 0.7912283961195499, 0.3210849378956482, 3.242121641524136, 43.45970056951046, 44.049626514315605, 90.47305405139923, 46.84565328061581, 34.19883370399475, 64.33592095971107, 74.61358666419983, 76.12977370619774, 86.24771878123283, 70.89601814746857, 1.6277937032282352, 0.1637241747812368, 0.17823163303546607, 0.1465671305777505, 0.15292374417185783, 0.18147731199860573, 0.2692476741503924, 0.3029403177788481, 0.1644254004349932, 0.16611058032140136, 0.1846080322866328, 0.10157830169191584, 0.1587932714028284, 0.14013912237714976, 0.18467573099769652, 0.11211049786652438, 0.0975413374544587, 0.13181369489757344, 0.20284656377043575], [0.05671464714396279, 0.0655777272186242, 0.05113205646921415, 0.07705557538429275, 0.05084666358015966, 0.09752379308338277, 0.09788445458980277, 0.0463720437255688, 0.12630782002815977, 0.04356516699772328, 0.06136309282737784, 0.09318621450802311, 0.1056603439792525, 0.11446826392784715, 0.28911737201269716, 0.5692286335397512, 14.682911820709705, 88.07365760207176, 76.265829205513, 74.60363119840622, 64.85401555895805, 27.069333270192146, 37.76166312396526, 65.8031590282917, 39.94518555700779, 17.483458444476128, 0.10189658656599931, 0.17821273795561865, 1.8858093582093716, 1.5133309015072882, 2.1884310571476817, 3.0398014979436994, 0.7920657168142498, 3.8778353668749332, 74.76570010185242, 96.52474611997604, 81.81220158934593, 79.85341429710388, 71.08191177248955, 83.72868195176125, 82.88853943347931, 89.60773408412933, 86.54569879174232, 88.39872255921364, 85.60125187039375, 87.52353832125664, 81.83937773108482, 76.85675829648972, 70.66835716366768, 70.44166132807732, 67.48124778270721, 66.86557441949844, 59.85761806368828, 59.737768694758415, 59.596492275595665, 57.27643556892872, 56.753226444125175, 56.84796296060085, 55.463199466466904, 56.389639154076576, 57.43076428771019, 55.63031069934368, 54.88216504454613, 56.04300655424595, 55.060690864920616, 55.16251400113106, 58.29585246741772, 56.76084503531456, 56.23104326426983, 57.28064574301243, 55.60089647769928, 57.91747637093067, 71.3203489780426, 72.45118349790573, 69.06656071543694, 71.44373595714569, 69.26859587430954, 68.14492776989937, 70.34907549619675, 63.54688189923763, 61.53465427458286, 72.31819063425064, 65.78852981328964, 65.77481254935265, 65.68480297923088, 63.82047101855278, 66.78723782300949, 63.58580321073532, 45.67871689796448, 63.25345404446125, 63.912357687950134, 69.61395174264908, 61.55910976231098, 65.90754702687263, 67.15744435787201, 69.24608588218689, 64.55686390399933, 65.31382888555527, 65.12682572007179, 66.66246011853218, 69.40967470407486, 69.95340272784233, 66.9302773475647, 65.74516654014587, 59.004890620708466, 58.190898299217224, 60.885797291994095, 63.166180327534676, 61.62251316010952, 57.8428103774786, 52.16729052364826, 51.13408796489239, 49.98794786632061, 49.81078237295151, 52.38555461168289, 51.471331268548965, 52.512726187705994, 54.107721000909805, 53.331836834549904, 53.73503319919109, 53.40804934501648, 54.78376932442188, 53.62195506691933, 56.1638742685318, 57.399803549051285, 55.601234659552574, 58.15293453633785, 57.29441240429878, 57.70719185471535, 55.66629096865654, 54.590846076607704, 55.51367975771427, 59.5965226739645, 58.25663097202778, 64.23160135746002, 64.38144251704216, 76.05943188071251, 75.06475165486336, 83.4450651705265, 61.539244428277016, 0.408175284974277, 0.4887075402075425, 2.5518905790522695, 0.4630578774958849, 0.8966353337746114, 0.15310830145608634, 0.3539178182836622, 13.474713452160358, 23.124789632856846, 41.31330594420433, 68.83710622787476, 23.415863513946533, 16.638689674437046, 35.25266915559769, 54.1270087659359, 58.21982614696026, 71.38713419437408, 17.260537706315517, 0.450705096591264, 0.04415593881276436, 0.09812214964767918, 0.009731014361022972, 0.04503125375777017, 0.0533763333078241, 0.03392888778762426, 0.06159644261060748, 0.02698809636058286, 0.06109949310484808, 0.056490733768441714, 0.00498057671393326, 0.02509976467990782, 0.03166142625559587, 0.02627577559906058, 0.08102227307972498, 0.01085960760974558, 0.024484195855620783, 0.07310623652301729, 0.0575151350494707, 0.06138837037724443, 0.03172565171553288, 0.06726512612658553, 0.03935783533961512, 0.04533876635832712, 0.030698131558892783, 0.05143391390447505, 0.027607578158495016, 0.07765451082377695, 0.15375604794826359, 0.07778106184559874, 0.044199150361237116, 0.3234401880763471, 0.60749038355425, 22.394142039120197, 104.21389192342758, 81.28005534410477, 85.0202402472496, 74.92064818739891, 40.755435079336166, 31.212800033390522, 52.042250633239746, 48.69173862040043, 21.10957346856594, 0.14370065939147025, 0.9442169743124396, 4.5651462860405445, 3.148132972419262, 3.0124869011342525, 2.4099206971004605, 0.5782804603222758, 5.364441471174359, 82.34411224722862, 99.42703038454056, 89.01093810796738, 82.30212450027466, 75.47737151384354, 88.05609494447708, 86.62347301840782, 92.53455743193626, 89.0610346198082, 92.15411424636841, 89.21781420707703, 88.45874413847923, 83.0841301381588, 81.09619840979576, 74.26522135734558, 73.97326782345772, 71.25821471214294, 71.01602330803871, 62.066625729203224, 61.536071598529816, 62.70501047372818, 61.84403367340565, 58.95289421081543, 59.78623889386654, 58.116699680686, 58.08245211839676, 58.32292981445789, 58.591009229421616, 56.83830387890339, 57.270557284355164, 56.700257286429405, 58.13409894704819, 60.96254177391529, 60.751527696847916, 58.84321689605713, 59.16550040245056, 57.073655650019646, 59.923996701836586, 75.87761923670769, 74.70427259802818, 73.05069252848625, 74.42991212010384, 72.45307579636574, 72.42738157510757, 73.66793900728226, 69.32152703404427, 64.87860023975372, 75.07137089967728, 70.82661107182503, 69.64685797691345, 68.55966791510582, 66.37009620666504, 69.78802040219307, 68.77614989876747, 46.990417912602425, 65.1475802063942, 65.95729395747185, 70.06105095148087, 62.93036498129368, 67.82888352870941, 68.84424224495888, 72.04419493675232, 67.90695413947105, 67.5258269906044, 65.49491956830025, 66.45991578698158, 68.06038230657578, 72.45693638920784, 71.67260527610779, 68.48569348454475, 61.98146469891071, 59.88770864903927, 65.13040512800217, 66.9895313680172, 64.31705117225647, 59.53228332102299, 55.440210700035095, 53.24350297451019, 53.33568602800369, 51.80928513407707, 56.24116972088814, 53.919821083545685, 55.97912818193436, 56.85878098011017, 56.25740244984627, 57.215042263269424, 56.38471461832523, 58.07461693882942, 56.193771064281464, 59.35448706150055, 59.575209617614746, 58.64003799855709, 61.42402321100235, 60.078606605529785, 61.026731729507446, 57.75771774351597, 58.37176099419594, 58.01047258079052, 61.736944019794464, 61.67947970330715, 66.85004845261574, 69.908017963171, 77.49330013990402, 78.72720032930374, 83.19606453180313, 71.9533722102642, 1.4242209331132472, 0.21783946081995964, 1.3117963657714427, 1.7273719911463559, 2.1025086427107453, 0.2545026544248685, 0.25522304233163595, 15.73359914124012, 37.626158595085144, 41.86375580728054, 54.89718183875084, 23.983629047870636, 31.231901608407497, 42.56083980202675, 62.34115719795227, 62.20503710210323, 79.93387877941132, 31.07873372733593, 0.43091074156109244, 0.04298580941394903, 0.06753462221240625, 0.027717378907254897, 0.05970080448605586, 0.014616208864026703, 0.0010527495828682731, 0.04043134082166944, 0.08270855134469457, 0.043278909506625496, 0.042503008953644894, 0.058626490063034, 0.031281342744478025, 0.05578671763942111, 0.07846723674447276, 0.09076561080291867, 0.008356373182323296, 0.010067884468298871, 0.12700822931947187, 0.24987616518046707, 0.13959103147499263, 0.16489106841618195, 0.1701694750227034, 0.17193017585668713, 0.19050256989430636, 0.10125779779627919, 0.22945142991375178, 0.1712316516204737, 0.22527285647811368, 0.24617646995466202, 0.3967134968843311, 0.22824894287623465, 0.39317731163464487, 1.1797097534872591, 26.56118843704462, 117.45681211352348, 96.73701792955399, 97.29456201195717, 82.69346550107002, 38.95054712891579, 52.85231776535511, 100.07121741771698, 60.63341483473778, 30.405596047639847, 0.31244429061189294, 1.0895730089396238, 7.813480831682682, 5.18163375556469, 5.9646871872246265, 8.808263652026653, 4.337051650509238, 5.720176482573152, 84.13717523217201, 106.48050829768181, 89.06406685709953, 87.47560009360313, 78.35048854351044, 93.165293186903, 90.54236993193626, 98.26107814908028, 91.69795632362366, 96.60013407468796, 90.85095137357712, 92.05610990524292, 89.42561745643616, 85.96807658672333, 78.19624722003937, 78.28409850597382, 75.4908911883831, 73.68732556700706, 67.13827818632126, 66.47909715771675, 66.74186065793037, 64.71600696444511, 61.832953467965126, 63.4371779859066, 60.69549970328808, 60.666290670633316, 62.31876499950886, 62.810918390750885, 60.341066122055054, 60.71905463933945, 60.251276940107346, 61.679122522473335, 65.54998621344566, 64.16673883795738, 61.309094578027725, 61.2490464001894, 60.78928627073765, 61.800829991698265, 80.61924800276756, 80.95256611704826, 74.59198862314224, 78.77687126398087, 76.82211175560951, 75.3018893301487, 79.21129435300827, 72.55922690033913, 67.6309597492218, 78.69756951928139, 74.81367632746696, 72.83813953399658, 71.69575363397598, 70.289266705513, 73.2337287068367, 71.69631600379944, 52.681725919246674, 67.19909012317657, 69.85214576125145, 72.97446861863136, 63.822712898254395, 68.64521652460098, 70.77514663338661, 75.37681370973587, 69.96081233024597, 71.38348639011383, 70.06833896040916, 71.11648991703987, 72.84590631723404, 73.57856780290604, 76.62772178649902, 71.81792467832565, 64.59684535861015, 62.449732571840286, 66.3255549967289, 68.77647668123245, 66.94170713424683, 63.90930265188217, 57.672408521175385, 57.38705903291702, 56.752892062067986, 55.036653354763985, 60.61339370906353, 57.542090713977814, 58.22600461542606, 61.473188772797585, 59.660754427313805, 60.258298963308334, 59.66534458100796, 61.67617008090019, 59.21268627047539, 62.54043750464916, 64.43634197115898, 62.84216031432152, 64.81575921177864, 63.528027310967445, 64.9085958302021, 61.606816202402115, 61.873375698924065, 60.188017934560776, 65.5819196999073, 63.92837002873421, 71.14393964409828, 72.33001559972763, 84.3928711116314, 84.63035076856613, 88.5942904651165, 71.26342043280602, 1.0013124137185514, 7.857038369402289, 9.393404703587294, 3.457384603098035, 3.57357619330287, 0.4696960322326049, 1.1405426426790655, 22.067997939884663, 42.293778732419014, 57.862607315182686, 90.56127771735191, 30.368088260293007, 30.324719287455082, 51.178530380129814, 75.55084437131882, 71.11468881368637, 93.94162952899933, 27.30933979153633, 0.8380982279777527, 0.1730529117048718, 0.2818558132275939, 0.1315824268385768, 0.17653198126936331, 0.14654286234872416, 0.11500325592351146, 0.10535394831094891, 0.17083682905649766, 0.1253470208030194, 0.1960953650996089, 0.10780169235658832, 0.1813064399175346, 0.11515520323882811, 0.10752003989182413, 0.2775245503289625, 0.07383370451861992, 0.2908462198683992], [0.018789882269629743, 0.04401195474201813, 0.01813804654375417, 0.03464608445938211, 0.007395058164547663, 0.07409730795188807, 0.03249293593398761, 0.048290150371030904, 0.020043365984747652, 0.005553210903599393, 0.03462920431047678, 0.08659042156068608, 0.19530623947503045, 0.037624081887770444, 0.15079238510224968, 0.11637310468358919, 42.921672239899635, 83.45001250505447, 67.08702653646469, 60.83664312958717, 59.90349680185318, 48.30384783446789, 55.9952887147665, 35.68387381732464, 23.821075670421124, 4.322115126997232, 0.1948122214525938, 0.22751437994884327, 2.531057484447956, 2.3518296517431736, 1.4572671661153436, 0.5327751708682626, 0.5961514357477427, 30.89576404541731, 96.30644783377647, 85.97111642360687, 85.29940366744995, 75.57911485433578, 71.28522366285324, 69.75901275873184, 73.61735612154007, 77.23588675260544, 79.96598705649376, 79.60959658026695, 79.61491629481316, 74.68794867396355, 70.83260715007782, 67.03128352761269, 67.27206900715828, 68.49024564027786, 68.03302377462387, 68.56004029512405, 63.20741571485996, 58.78672532737255, 58.07007618248463, 56.34740062057972, 57.36831083893776, 56.05577386915684, 56.69667027890682, 56.16709269583225, 54.123782739043236, 54.55915957689285, 53.55661377310753, 54.13770519196987, 53.63233610987663, 55.655001774430275, 55.930935367941856, 54.732947051525116, 53.564156368374825, 56.62983566522598, 53.59673961997032, 59.45052690804005, 68.00944223999977, 69.19965237379074, 71.05560958385468, 73.1425715982914, 69.66932997107506, 66.57000347971916, 67.24313735961914, 69.85457003116608, 65.24639010429382, 61.829814836382866, 64.85133290290833, 64.68429386615753, 67.032750248909, 63.5281603038311, 69.18026581406593, 62.308258563280106, 43.974515944719315, 63.04736450314522, 57.26188234984875, 62.927480936050415, 64.98461455106735, 70.0228326022625, 66.97299465537071, 64.09641221165657, 60.44417358934879, 59.15236830711365, 59.37132775783539, 63.43822292983532, 67.51976251602173, 62.27098636329174, 67.99794405698776, 66.59680724143982, 60.62507428228855, 58.95445212721825, 67.71360531449318, 77.09195047616959, 66.69513836503029, 57.43544563651085, 54.841636419296265, 49.51302655041218, 49.555994644761086, 50.99461644887924, 51.36146016418934, 52.23863169550896, 51.10568068921566, 52.73565262556076, 51.75399050116539, 52.89351515471935, 51.368736773729324, 53.84849511086941, 52.60598078370094, 53.204745054244995, 53.113325759768486, 54.81914922595024, 53.263862282037735, 55.71071818470955, 53.03460918366909, 56.209764406085014, 53.169938921928406, 55.35075969994068, 55.959205850958824, 59.15791980922222, 58.400031477212906, 65.9560476243496, 66.32275074720383, 72.93910011649132, 70.76019063591957, 87.60398000478745, 32.9430390894413, 0.610730362823233, 2.98582230694592, 1.4303629472851753, 0.6683942279778421, 0.20377439679577947, 0.07426136711728759, 6.615495840087533, 23.02438762038946, 24.34957981109619, 71.0702995955944, 66.67635217308998, 18.245646245777607, 27.743789479136467, 51.954277753829956, 60.93062348663807, 65.98642319440842, 67.60502234101295, 5.596707807853818, 0.15274974022759125, 0.03697223502967972, 0.04162130782788154, 0.0323087126162136, 0.017009033981594257, 0.07200816224212758, 0.014552655975421658, 0.052888553036609665, 0.039825614730943926, 0.05894514230021741, 0.04674681717006024, 0.013158026904420694, 0.04464167446712963, 0.05367732985178009, 0.0191124864431913, 0.014393817818927346, 0.06785468824091367, 0.02599875228042947, 0.045695988010265864, 0.03983563001384027, 0.08553369974833913, 0.0169058457686333, 0.02490306957042776, 0.07827099805581383, 0.040708295491640456, 0.03757681079150643, 0.03247657157771755, 0.04484864832193125, 0.057938378158723935, 0.13036714517511427, 0.04081240767845884, 0.054617408313788474, 0.015492163911403622, 58.195408657193184, 92.74981588125229, 76.86169803142548, 67.706758081913, 73.06390061974525, 48.33817899227142, 26.443248465657234, 38.295545876026154, 32.21654087305069, 4.697152627632022, 0.35600527189671993, 1.113001008052379, 5.939307874068618, 4.012276427820325, 6.250188667327166, 0.8669522765558213, 0.2681087446399033, 36.82000905275345, 99.29107367992401, 89.04533386230469, 88.46261993050575, 79.20914366841316, 75.34921199083328, 72.75659590959549, 79.51365172863007, 81.18192180991173, 85.07552728056908, 83.05097311735153, 80.81910967826843, 77.42814123630524, 72.91497141122818, 70.14514043927193, 70.24575904011726, 72.11127653717995, 73.5384039580822, 71.3701643049717, 66.17160245776176, 59.30098973214626, 59.63561497628689, 60.96382610499859, 60.731297582387924, 58.949117213487625, 59.033256098628044, 58.95058773458004, 56.304075345396996, 57.27837726473808, 56.37315943837166, 58.60353335738182, 54.97481927275658, 59.472178146243095, 59.29297216236591, 57.91128270328045, 57.258766517043114, 59.589614644646645, 55.908843353390694, 61.96952573955059, 69.4752287864685, 71.80279389023781, 71.74477100372314, 74.659693390131, 71.72334775328636, 70.13524577021599, 70.25913432240486, 74.65648636221886, 69.7685806453228, 68.04751619696617, 69.83423352241516, 69.4712845981121, 70.97582146525383, 69.18691545724869, 71.13110393285751, 64.80636611580849, 48.56292553246021, 65.04856511950493, 58.217078894376755, 64.60382178425789, 67.39657312631607, 71.43828704953194, 69.68997046351433, 66.86800628900528, 63.87972503900528, 62.06878021359444, 63.08035433292389, 67.01300650835037, 69.69074562191963, 65.7321484386921, 72.83965945243835, 70.30233800411224, 62.43980370461941, 61.93174436688423, 70.25284945964813, 78.07952508330345, 70.005421936512, 60.709323361516, 57.82614067196846, 52.75530897080898, 52.55838833749294, 53.660439401865005, 53.73095981776714, 56.44307188689709, 54.096409007906914, 55.31458184123039, 53.02394315600395, 56.50999769568443, 54.35272805392742, 54.88979883491993, 55.20459674298763, 56.71820752322674, 56.01688675582409, 58.38299699127674, 55.89166447520256, 59.868667870759964, 56.21121972799301, 57.15728156268597, 56.804436296224594, 57.132335901260376, 56.813080832362175, 62.40273669362068, 59.72164995968342, 68.00677478313446, 70.81425413489342, 75.39377599954605, 73.37679862976074, 89.95831847190857, 43.67347329854965, 0.12707641784800217, 0.28608641121536493, 1.9549828651361167, 2.7975407475605607, 0.6203522183932364, 0.11472117301309481, 2.1633714018389583, 26.277191676199436, 30.489003472030163, 58.45519691705704, 43.59686940908432, 22.008996605873108, 39.54431086778641, 59.75324146449566, 69.44771826267242, 70.67905738949776, 83.53245288133621, 12.630738839507103, 0.3438263019779697, 0.05391187820350751, 0.12921819667099044, 0.0337365082668839, 0.07004161190707237, 0.02179957682528766, 0.05750387666921597, 0.048352936064475216, 0.03972291262471117, 0.040769162733340636, 0.046858963105478324, 0.08186416540411301, 0.0983075900876429, 0.03213947326003108, 0.055442632001359016, 0.025814677392190788, 0.05025781392760109, 0.137201894831378, 0.1439038891112432, 0.11730458907550201, 0.15359075681772083, 0.14795178518397734, 0.14886241522617638, 0.17804637813242152, 0.07229925482533872, 0.12889469449874014, 0.10587783777737059, 0.13023959967540577, 0.19151330081513152, 0.2884364960482344, 0.19477140333037823, 0.2669306000461802, 0.1536033584852703, 66.84467554092407, 105.63445329666138, 88.33275809884071, 79.17760536074638, 79.6042312681675, 64.037264585495, 81.38038516044617, 52.749609276652336, 41.98979504406452, 7.455667331814766, 0.6454960629343987, 0.9394830814562738, 5.833409931510687, 8.080064076930285, 7.477217875421047, 6.399979004636407, 1.1920659779570997, 38.0734857916832, 103.62729460000992, 93.1989061832428, 94.16732981801033, 83.36621180176735, 77.96949818730354, 75.9108978509903, 82.93014720082283, 83.61809268593788, 86.57152980566025, 86.93881049752235, 86.05611026287079, 81.25691458582878, 75.75362429022789, 73.20865005254745, 75.60885205864906, 76.44574955105782, 75.27294248342514, 74.51952651143074, 69.93634924292564, 63.69013421237469, 63.28920632600784, 62.93311983346939, 64.01337146759033, 60.6652457267046, 61.4591409265995, 63.665340542793274, 59.9898661673069, 60.17318353056908, 60.52032150328159, 61.174171417951584, 57.55306072533131, 62.75118939578533, 60.72439335286617, 60.65342456102371, 59.796688333153725, 62.34011225402355, 57.62218281626701, 64.3760696053505, 72.75075942277908, 75.37730008363724, 74.38654884696007, 79.47561576962471, 76.66278630495071, 73.0664312839508, 72.7614064514637, 77.58579477667809, 72.55795776844025, 67.85609766840935, 70.06758660078049, 73.98515358567238, 72.72578716278076, 73.55843648314476, 75.61749279499054, 69.65305924415588, 49.8588839918375, 68.93186554312706, 63.31200510263443, 69.29511085152626, 68.6818465590477, 76.18115454912186, 74.6504294872284, 71.21695652604103, 66.18103355169296, 65.43736785650253, 65.2103604376316, 70.74088767170906, 73.4999880194664, 66.5642885863781, 73.75335082411766, 73.11560824513435, 65.08731544017792, 65.66652595996857, 73.89785706996918, 80.6943091750145, 73.33438530564308, 63.715524449944496, 59.209023267030716, 53.96408870816231, 56.509955897927284, 57.71105244755745, 57.049454748630524, 56.39055870473385, 55.526621863245964, 58.37768107652664, 56.51582658290863, 61.50826469063759, 57.174202054739, 59.47918117046356, 57.51063600182533, 61.39680527150631, 59.04174484312534, 60.07607214152813, 61.361573562026024, 62.17107452452183, 59.79309752583504, 63.249711245298386, 60.161107778549194, 62.37714886665344, 62.77284063398838, 66.17677018046379, 64.05162021517754, 71.90647512674332, 75.78057244420052, 80.73115959763527, 77.60525733232498, 94.38864514231682, 41.9499845802784, 1.1308285826817155, 8.94223116338253, 5.001890575513244, 3.4529281547293067, 0.7699997071176767, 0.20335867535322905, 9.986728616058826, 36.55786491930485, 40.11474385857582, 90.99060907959938, 84.9304510653019, 26.321453601121902, 43.29178377985954, 68.7778902053833, 79.89513605833054, 80.9233608841896, 92.19759151339531, 10.311013665050268, 0.3712686075596139, 0.1208998789661564, 0.23139210155932233, 0.2382860449142754, 0.10084025809192099, 0.21033686731243506, 0.0931956026761327, 0.17865933274151757, 0.10325177790946327, 0.11009141831891611, 0.1568519466673024, 0.20737301150802523, 0.2831953304121271, 0.13227758172433823, 0.16979158826870844, 0.06707832013489679, 0.14403498207684606], [0.05759398452937603, 0.07313833441003226, 0.011299909911031136, 0.03320167954370845, 0.10101446241606027, 0.026311565670766868, 0.04490955267101526, 0.059786559650092386, 0.036089788045501336, 0.061595930528710596, 0.017054965501301922, 0.10931067896308377, 0.023118607023207005, 0.09548312445986085, 0.2635007200296968, 3.7852706713601947, 79.3431244790554, 75.46334266662598, 71.73802256584167, 62.4221308529377, 33.30436930060387, 39.986527338624, 63.16043123602867, 36.109336987137794, 26.117016971111298, 0.23897843901067972, 0.04273218786693178, 0.8822724607307464, 2.188355061225593, 4.087411696091294, 2.536783777177334, 1.2301871948875487, 3.670918419957161, 69.35212299227715, 94.300816655159, 83.63451540470123, 82.08325624465942, 73.01534682512283, 73.81565228104591, 70.82097977399826, 68.01925331354141, 64.38127532601357, 67.29853838682175, 65.41870325803757, 68.72760370373726, 62.80646502971649, 64.11388367414474, 64.9566100537777, 70.41307166218758, 69.54538062214851, 71.19108751416206, 66.88855558633804, 64.55249413847923, 57.460148110985756, 57.94328458607197, 57.42583215236664, 58.401403203606606, 56.13189898431301, 58.178807348012924, 54.92322564125061, 55.506676733493805, 55.08199252188206, 54.58122879266739, 53.711048886179924, 51.750479489564896, 54.87143822014332, 54.57246646285057, 53.06082397699356, 56.34955130517483, 55.399590879678726, 52.221376821398735, 53.653903752565384, 63.295297399163246, 67.33088225126266, 75.47407329082489, 67.62686356902122, 71.11195296049118, 65.58469355106354, 67.95660987496376, 65.60625359416008, 72.06156760454178, 63.50495494902134, 68.89284163713455, 65.46333566308022, 68.62313970923424, 64.42703247070312, 69.56811860203743, 59.674904868006706, 42.0522028952837, 58.28168302774429, 60.84287479519844, 68.46328228712082, 67.27991938591003, 65.9030556678772, 59.78816919028759, 58.64277385175228, 56.25089719891548, 57.00421817600727, 58.07658143341541, 64.33836802840233, 65.42802795767784, 60.760856196284294, 65.86270943284035, 66.27623364329338, 61.066777780652046, 62.54125826060772, 67.50564247369766, 69.86732214689255, 68.72400909662247, 61.10441096127033, 57.2199098020792, 52.00753569602966, 50.381192564964294, 48.91281455755234, 48.46375085413456, 50.27247279882431, 52.988711446523666, 51.59930840134621, 52.98236198723316, 52.425114288926125, 53.504533767700195, 52.745482698082924, 53.765142783522606, 52.579313814640045, 53.86328011751175, 51.328154951334, 53.76232333481312, 50.91736279428005, 51.67923331260681, 48.95813852548599, 52.47172258794308, 52.50872500240803, 54.09266620874405, 51.76768496632576, 56.38201676309109, 54.49286833405495, 64.29554432630539, 66.84736579656601, 75.12212857604027, 73.27586844563484, 82.93495014309883, 7.515351679176092, 0.9660142671782523, 2.9352840688079596, 1.3590683229267597, 0.23581491579534486, 0.21675277850590646, 0.800786605104804, 23.578109107911587, 26.208109483122826, 34.914023727178574, 93.39328095316887, 61.11185856163502, 30.25879092514515, 51.195656061172485, 52.546992748975754, 57.02672056853771, 64.47026655077934, 46.82859219610691, 2.2378861159086227, 0.11419304588343948, 0.02479977745679207, 0.029529477178584784, 0.02101491150824586, 0.05193900105950888, 0.10321606576326303, 0.052163526706863195, 0.05389309815654997, 0.06869546734378673, 0.09046439532539807, 0.04106514235900249, 0.020171403157291934, 0.03134224709356204, 0.06211832085682545, 0.07911410750239156, 0.012598620105563896, 0.07815723423846066, 0.0945775855507236, 0.007394308131551952, 0.05115776075399481, 0.034192053353763185, 0.029108100570738316, 0.03507499386614654, 0.05958917063253466, 0.044231901338207535, 0.16110602620756254, 0.031240290845744312, 0.10490034765098244, 0.041029214989976026, 0.11790880860644393, 0.3332601673901081, 6.927580693736672, 97.51161396503448, 80.54936215281487, 82.71352082490921, 70.13615772128105, 55.86788535118103, 44.72798891365528, 50.074457824230194, 46.307077780365944, 28.646068163216114, 0.2148946633678861, 0.2797542588086799, 2.5653912546113133, 3.3483582409098744, 3.4040599269792438, 4.2247220780700445, 0.5419483536388725, 4.497037315741181, 74.00691121816635, 98.62113162875175, 86.3839490711689, 86.68998464941978, 76.60107761621475, 76.82056903839111, 74.7761495411396, 70.2588303387165, 68.33597391843796, 69.93790715932846, 68.56808826327324, 70.31793236732483, 66.4111340045929, 66.67030289769173, 68.07680502533913, 75.48226565122604, 71.12732693552971, 74.75577503442764, 70.74645057320595, 66.66298449039459, 60.72730019688606, 61.69995680451393, 60.00150494277477, 59.83480028808117, 59.61891487240791, 60.20012028515339, 57.908980026841164, 58.19863088428974, 57.42346867918968, 58.12127463519573, 56.452331990003586, 54.868751764297485, 57.928233593702316, 56.61129266023636, 56.15469016134739, 59.33393396437168, 57.508306726813316, 56.15586429834366, 55.393723994493484, 67.0941549539566, 69.85752627253532, 77.98677206039429, 72.98109546303749, 75.96948310732841, 70.15793055295944, 70.79321086406708, 68.45156371593475, 73.3248782157898, 67.22969368100166, 73.12090516090393, 68.42624187469482, 71.73268005251884, 67.53316059708595, 71.59207999706268, 62.73284398019314, 43.18844452500343, 61.07729181647301, 63.6436665058136, 70.04405826330185, 68.88254418969154, 68.25344234704971, 61.762687638401985, 61.27481661736965, 57.71940819919109, 58.96417200565338, 60.740740075707436, 65.12590616941452, 69.11882311105728, 64.39275830984116, 68.48483473062515, 69.24632906913757, 63.300115540623665, 63.978101760149, 70.19489496946335, 71.26638427376747, 70.8571158349514, 63.51829223334789, 61.30720607936382, 54.39170256257057, 53.408311530947685, 52.60124623775482, 50.89421443641186, 53.261065632104874, 55.62488839030266, 53.60461659729481, 54.64196853339672, 54.19778376817703, 56.87133550643921, 55.07813572883606, 56.38148479163647, 53.86616796255112, 55.88679313659668, 54.25701878964901, 55.73525346815586, 51.66107788681984, 55.34971855580807, 51.4880845695734, 54.96699549257755, 55.1519999653101, 59.25978474318981, 54.50231462717056, 60.15410095453262, 56.162198558449745, 66.50454059243202, 68.30418482422829, 77.71456226706505, 73.5113950073719, 91.07387021183968, 11.36550648137927, 0.6239308544900268, 2.3489042837172747, 1.4399528014473617, 1.5294116386212409, 0.2849265234544873, 0.23822509974706918, 16.766588911414146, 35.16803629696369, 35.549041852355, 75.37472382187843, 56.95700190961361, 46.63948394358158, 60.74968099594116, 62.73490346968174, 60.52410610020161, 70.22768720984459, 65.84372565150261, 6.37455646879971, 0.1951608230592683, 0.028867739347333554, 0.02888617800635984, 0.04980299614544492, 0.06027655894285999, 0.07332220149692148, 0.030492055702779908, 0.06152368245238904, 0.025582850867067464, 0.10676559482817538, 0.02944636591564631, 0.08916211168980226, 0.018397803796688095, 0.031102321881917305, 0.05144654154719319, 0.08828409161651507, 0.2422463972470723, 0.1568849425530061, 0.10070640433696099, 0.11074220761656761, 0.20136649865889922, 0.1275403640465811, 0.09922995348460972, 0.2826717006973922, 0.3037034237058833, 0.2983891119947657, 0.1388599566416815, 0.23923934844788164, 0.1534117804840207, 0.20640333619667217, 0.7553283381275833, 8.12557328492403, 109.57548782229424, 95.17225429415703, 91.90121501684189, 84.59442749619484, 48.78889560699463, 56.380101665854454, 92.34617114067078, 56.1400381475687, 44.4955287873745, 0.6802596256602556, 0.37492715811822563, 3.694386435672641, 8.515736348927021, 7.347635328769684, 11.073394306004047, 5.386885916814208, 4.619312379509211, 77.69452974200249, 102.39301443099976, 90.36912962794304, 88.31075727939606, 79.61862489581108, 80.16429841518402, 78.54335099458694, 76.21433436870575, 71.60080432891846, 75.5206435918808, 72.4704560637474, 75.91305613517761, 69.08293783664703, 70.11955261230469, 72.88397267460823, 78.26845094561577, 73.68159547448158, 79.26467388868332, 74.00758758187294, 71.29501953721046, 63.14231760799885, 65.65904796123505, 64.1445480287075, 63.89842763543129, 62.414641454815865, 62.36471973359585, 59.87304903566837, 63.0300298333168, 60.358887165784836, 62.3898059874773, 58.97853523492813, 56.76834583282471, 62.2273875027895, 60.98146855831146, 58.93328346312046, 61.87518060207367, 61.30185216665268, 58.27661409974098, 59.21857975423336, 70.67457363009453, 74.8814494907856, 83.20309415459633, 75.94805985689163, 79.20639261603355, 73.09135794639587, 74.66428354382515, 72.64750376343727, 79.18235510587692, 69.80548426508904, 72.02945932745934, 70.90587481856346, 74.01220053434372, 70.31854793429375, 75.0917986035347, 66.31483197212219, 47.048832178115845, 62.21240870654583, 65.4355363547802, 73.13405245542526, 73.06167393922806, 71.05754747986794, 66.2884233891964, 64.81037110090256, 62.27427698671818, 62.06413306295872, 64.98990386724472, 69.6565018594265, 73.14985200762749, 67.35577091574669, 70.59278681874275, 71.72413051128387, 67.78938084840775, 68.12803387641907, 72.65049800276756, 74.44555968046188, 75.67015036940575, 65.93068778514862, 62.70293578505516, 56.87879830598831, 55.6777473539114, 56.349695697426796, 54.67465437948704, 56.86421848833561, 57.574985548853874, 55.81646651029587, 57.88279563188553, 57.81623460352421, 60.0031578540802, 58.28419089317322, 60.121422708034515, 57.326733469963074, 58.761817663908005, 57.898040413856506, 59.90215927362442, 56.30355477333069, 59.12983551621437, 54.13954049348831, 59.45789851248264, 57.57325664162636, 63.00503097474575, 58.37103143334389, 64.17085781693459, 60.368542447686195, 72.06137001514435, 74.92317125201225, 82.64747276902199, 80.61826005578041, 92.74395659565926, 11.140654496848583, 2.4952339567244053, 10.87088417261839, 3.1317121535539627, 1.4262667670845985, 0.3644872776931152, 2.169862878508866, 31.003248877823353, 42.935264110565186, 52.981172651052475, 119.67027693986893, 78.445475846529, 43.36487665772438, 67.57112815976143, 72.31930777430534, 71.30103841423988, 83.77418830990791, 69.9506364762783, 4.45625077933073, 0.2931000629905611, 0.12943570531206205, 0.15114940266357735, 0.14413119410164654, 0.13106091966619715, 0.14695272082462907, 0.3951266664080322, 0.1742752140853554, 0.10001734248362482, 0.22934270527912304, 0.09303420782089233, 0.25125569896772504, 0.08199045667424798, 0.2360758846043609, 0.2387649824959226, 0.11428007754147984], [0.009434999483346473, 0.025835605956672225, 0.04021778411697596, 0.08633694844320416, 0.038557610896532424, 0.08309316937811673, 0.03722693269082811, 0.10676022910047323, 0.025186224884237163, 0.024359340641240124, 0.1127086763153784, 0.1682150736451149, 0.04209274229651783, 0.16395823331549764, 0.36471698724199086, 28.16255360841751, 90.0755725800991, 68.41757833957672, 64.02287095785141, 50.87500646710396, 23.262300454080105, 51.826163828372955, 32.76403069496155, 28.853432536125183, 4.453496877104044, 0.1984281133627519, 1.842235908843577, 3.678053249605, 6.028272500261664, 6.3438355922698975, 11.010705269873142, 1.8152437009848654, 13.507523741573095, 89.52261105179787, 87.86362767219543, 87.36035227775574, 84.28078472614288, 80.47789558768272, 77.18056172132492, 71.87011867761612, 68.87841761112213, 65.8576937019825, 65.10373055934906, 62.632270976901054, 62.889080196619034, 68.54569226503372, 68.55241790413857, 72.01753556728363, 69.29255738854408, 75.4356649518013, 75.56949377059937, 68.19961443543434, 63.30173045396805, 56.01429909467697, 57.714419066905975, 57.043762654066086, 57.289347276091576, 56.058661714196205, 54.0478590130806, 52.83201925456524, 55.38766711950302, 53.67627315223217, 53.37381698191166, 52.46298685669899, 54.690602123737335, 52.52856373786926, 52.53644071519375, 53.282393887639046, 54.790228977799416, 50.88520511984825, 54.65655975043774, 53.29286992549896, 60.338881239295006, 63.00557054579258, 71.4538586139679, 68.9228904247284, 67.40580663084984, 66.94061279296875, 65.24275749921799, 61.96438081562519, 68.20551931858063, 62.21432760357857, 64.83653649687767, 69.5161221921444, 66.32490143179893, 65.77543571591377, 70.11098027229309, 60.78476071357727, 40.04767365753651, 67.02395752072334, 65.72394847869873, 67.02369153499603, 61.41923546791077, 57.0273095369339, 52.8618248552084, 54.08745288848877, 56.30660980939865, 54.38493512570858, 52.66499921679497, 58.265245109796524, 65.91551139950752, 66.75921812653542, 65.86502730846405, 65.4114380478859, 59.83703076839447, 63.561769500374794, 66.17541745305061, 65.55489555001259, 66.76335990428925, 58.81186097860336, 59.701606035232544, 55.76750993728638, 50.52962400019169, 52.08498694002628, 49.36793513596058, 50.0244677066803, 49.26524944603443, 53.90022933483124, 50.963895097374916, 53.67242015898228, 53.14868666231632, 51.899549290537834, 53.298592418432236, 51.0754419118166, 51.4669007062912, 51.390338614583015, 51.81449085474014, 49.75991450250149, 48.97656753659248, 50.27742773294449, 53.24549026787281, 58.12898822128773, 56.08943246304989, 56.15620627999306, 55.99769778549671, 55.765948221087456, 57.62185983359814, 57.23147638142109, 66.30046114325523, 67.3251673579216, 82.67349377274513, 42.40942172706127, 0.13530466851079836, 1.0166235733777285, 4.411544753238559, 0.2396844292525202, 0.1360334426863119, 0.07174616926931776, 6.797552146017551, 64.36574175953865, 28.956378512084484, 44.680863842368126, 45.196952149271965, 15.82217238843441, 25.33326532691717, 34.26755681633949, 55.97137279808521, 61.24426245689392, 69.324901252985, 40.37255622446537, 1.3392551173456013, 0.16790393565315753, 0.017432805871067103, 0.035668582131620497, 0.06261212736717425, 0.06446285813581198, 0.05720391171053052, 0.02098191933328053, 0.014868169855617452, 0.028224618290551007, 0.04180812495178543, 0.07250040653161705, 0.10816860274644569, 0.028025262581650168, 0.024900125099520665, 0.02256155654322356, 0.025694911455502734, 0.03765980145544745, 0.025738145268405788, 0.0920513593882788, 0.04066767774929758, 0.047058482086868025, 0.03828427790722344, 0.09042851990670897, 0.03794359872699715, 0.07382561510894448, 0.06658672893536277, 0.09985585114918649, 0.1271243012160994, 0.19937899749493226, 0.2548499498516321, 39.4069292396307, 99.52137932181358, 77.75850310921669, 72.73539304733276, 64.1778190433979, 33.11209961771965, 42.23319098353386, 37.39668130874634, 37.95071057975292, 5.8695312682539225, 0.4340016975766048, 4.235594719648361, 8.346291091293097, 10.688703898340464, 16.028643809258938, 6.529002506285906, 0.983136564027518, 18.974798619747162, 94.17492181062698, 91.43751069903374, 89.93282943964005, 87.5449387729168, 84.29148495197296, 80.91537371277809, 75.8236089348793, 72.39826753735542, 69.48102727532387, 68.5257813334465, 67.23395705223083, 67.4237796664238, 70.73324248194695, 73.66768822073936, 74.99484300613403, 75.00465407967567, 78.54645162820816, 76.47879257798195, 71.5209250152111, 66.37730062007904, 58.485078513622284, 60.5758061259985, 58.04283544421196, 60.505076721310616, 58.99185732007027, 56.04684054851532, 55.095968171954155, 59.13453586399555, 58.02823282778263, 55.83216346800327, 54.91836570203304, 57.483703047037125, 53.840036764740944, 55.886789336800575, 55.47898381948471, 57.186745181679726, 54.556674510240555, 58.53067226707935, 55.51013074815273, 62.01891168951988, 64.64054301381111, 74.99054163694382, 70.24517387151718, 70.08042231202126, 66.88967272639275, 68.9385075867176, 65.78777745366096, 71.17777302861214, 68.04839015007019, 69.91662830114365, 69.42219123244286, 70.76607272028923, 68.0760982632637, 71.74946755170822, 63.08043412864208, 41.578695103526115, 69.69544976949692, 68.92737418413162, 70.61597317457199, 64.01295349001884, 59.51307535171509, 56.57051704823971, 57.949919030070305, 60.62803812325001, 56.49757616221905, 55.312218368053436, 62.19533622264862, 67.59188264608383, 67.93419867753983, 67.27632477879524, 67.37294599413872, 62.054705768823624, 66.75213530659676, 68.91909822821617, 68.52895796298981, 69.70578521490097, 61.98947846889496, 63.52340295910835, 59.66674670577049, 52.998742908239365, 53.61755110323429, 51.561276242136955, 52.36222766339779, 52.544412687420845, 54.51880194246769, 55.03177061676979, 55.67331679165363, 56.02540209889412, 54.53423671424389, 55.43766863644123, 53.989030569791794, 54.53890286386013, 54.57451835274696, 53.61880883574486, 54.020846262574196, 51.84474863111973, 54.075099751353264, 56.1369489133358, 60.07847361266613, 58.159170001745224, 58.975905776023865, 57.932109385728836, 59.39493589103222, 59.91339147090912, 59.9463053047657, 68.59499081969261, 69.34988871216774, 84.00521591305733, 51.15072347223759, 0.1556834054645151, 0.909944832092151, 4.239268647506833, 1.7039799713529646, 0.39694472041446716, 0.05403430659498554, 4.260501433163881, 68.76006916165352, 38.16832110285759, 42.5329264998436, 48.08135077357292, 22.644208520650864, 44.05505642294884, 39.71491791307926, 65.31299293041229, 68.1699988245964, 77.4394266307354, 59.12482738494873, 3.455533627420664, 0.16417262493632734, 0.04313157463911921, 0.020728657727886457, 0.020078415764146484, 0.004731888593596523, 0.01339770349659375, 0.05264253850327805, 0.08578317268984392, 0.041266761618317105, 0.04253143320966046, 0.057533477229299024, 0.015565707035420928, 0.065334718383383, 0.014621478112530895, 0.05240613107162062, 0.1485828630393371, 0.13932544650742784, 0.15645975130610168, 0.3939460578840226, 0.1394321970292367, 0.16183962434297428, 0.16014792839996517, 0.26378371578175575, 0.1009734661784023, 0.15070574678247795, 0.22026478458428755, 0.29834749235305935, 0.2905953145818785, 0.399778566788882, 0.5491312744561583, 45.16081988811493, 115.01193210482597, 89.25034806132317, 84.56573903560638, 69.88899618387222, 33.75180669128895, 69.21854496002197, 49.97006602585316, 47.24677115678787, 9.62042922154069, 0.5728532234206796, 4.614392118528485, 11.392229497432709, 15.463942810893059, 17.779130078852177, 26.227051466703415, 3.7804473051801324, 18.86568747460842, 96.50187894701958, 94.38128113746643, 94.40902724862099, 93.64769250154495, 90.01773208379745, 85.59969395399094, 79.63583037257195, 76.91576153039932, 75.59174537658691, 71.88730895519257, 68.29256504774094, 70.584936439991, 76.25781923532486, 77.0308193564415, 78.57979103922844, 79.7912572324276, 80.92143818736076, 78.90155777335167, 74.95421558618546, 71.66693598031998, 62.58646443486214, 63.89889121055603, 61.11359506845474, 63.29752407968044, 62.37714886665344, 59.53548654913902, 60.01206077635288, 61.95230506360531, 59.51537802815437, 58.84258233010769, 58.74283008277416, 58.61263006925583, 55.98412111401558, 59.88358587026596, 60.8607642352581, 59.90466333925724, 56.957127302885056, 59.88074742257595, 57.722873613238335, 66.0483218729496, 68.69671896100044, 79.83590483665466, 73.50949510931969, 72.59808361530304, 72.2955970466137, 71.48361101746559, 70.56777656078339, 73.96223321557045, 70.30927643179893, 69.9398298561573, 70.71372672915459, 72.33924150466919, 71.21842324733734, 76.5608985722065, 65.25389090180397, 45.61516530811787, 70.16289308667183, 73.82971152663231, 72.50493541359901, 67.12245583534241, 62.599205151200294, 62.29365214705467, 61.534107103943825, 63.6715342104435, 58.68528977036476, 58.477060943841934, 66.11481830477715, 70.33965960144997, 71.5701475739479, 70.48206835985184, 71.69196143746376, 66.29543781280518, 71.29441156983376, 71.34994938969612, 70.93526244163513, 72.79913082718849, 66.26139163970947, 66.21612846851349, 60.642545744776726, 57.3457932472229, 57.20077782869339, 55.02335786819458, 55.2136554569006, 55.54828830063343, 57.838459610939026, 56.9498734921217, 57.579153925180435, 60.06641685962677, 57.7680341899395, 58.086179718375206, 55.40920436382294, 57.85387918353081, 56.23305335640907, 58.16350556910038, 56.22550316154957, 54.43224638700485, 56.27892069518566, 59.50367085635662, 63.72438557446003, 63.343908190727234, 62.168061286211014, 61.853103786706924, 62.70436450839043, 64.16875272989273, 64.5930303633213, 74.36123460531235, 73.0778306722641, 90.23937419056892, 50.43368674814701, 0.2093878830783069, 4.688471518456936, 9.533411990851164, 2.3169270996004343, 0.29554603330325335, 0.1447146260761656, 9.469996243715286, 76.77377834916115, 43.37049275636673, 60.94382777810097, 58.39010260999203, 22.9408111050725, 40.964788645505905, 50.8228200674057, 75.889892578125, 78.11655789613724, 89.56927254796028, 60.725115314126015, 2.574197994545102, 0.28228925715666264, 0.2030099550029263, 0.16456012992421165, 0.14034523162990808, 0.18932601349661127, 0.15976024529663846, 0.1390295076998882, 0.13792057579848915, 0.23447309795301408, 0.14637006068369374, 0.22017523704562336, 0.19044353946810588, 0.25121229817159474, 0.14986009919084609, 0.2845682145562023], [0.03225598302378785, 0.049446987904957496, 0.07191904514911585, 0.06561609625350684, 0.012634966788027668, 0.031744342704769224, 0.016002715128706768, 0.030301288497867063, 0.060431370948208496, 0.046660939551657066, 0.009371966098115081, 0.05088950776553247, 0.05541861981328111, 0.08205822960007936, 0.3380253491923213, 57.59986661374569, 72.75504559278488, 72.81230852007866, 68.45312163233757, 35.349446162581444, 40.75860410928726, 59.282100945711136, 34.76160250604153, 28.336831256747246, 0.3340581542579457, 0.3572568891104311, 3.090622345916927, 3.8226715894415975, 1.0436902334913611, 43.861194625496864, 3.934185393154621, 0.43193843797780573, 71.24695971608162, 91.23668387532234, 90.75057595968246, 88.59657794237137, 83.30967843532562, 83.79210814833641, 84.52575758099556, 78.61604869365692, 75.15099942684174, 70.37934467196465, 66.52946725487709, 69.08619806170464, 68.70706960558891, 68.42352122068405, 69.90959867835045, 71.56058728694916, 75.81051483750343, 76.75681605935097, 80.38954272866249, 68.16247522830963, 63.42353671789169, 55.89575685560703, 58.47934082150459, 55.45518949627876, 58.04044537246227, 55.66672794520855, 53.621267303824425, 51.78410388529301, 52.49486714601517, 54.14994053542614, 54.19053375720978, 51.17409601807594, 53.20619657635689, 51.19212605059147, 51.30950555205345, 48.85147824883461, 51.40416607260704, 53.8703553378582, 58.571903854608536, 60.5607171356678, 63.90364855527878, 66.20775371789932, 69.02630567550659, 69.33874770998955, 67.16269567608833, 65.96398159861565, 67.10531115531921, 61.228934079408646, 63.26706491410732, 67.0403042435646, 63.46704438328743, 64.26649868488312, 70.73332607746124, 64.70534473657608, 68.5951580107212, 54.63172048330307, 48.5601706802845, 67.7934542298317, 65.41827008128166, 62.35450208187103, 56.94097816944122, 55.48987403512001, 55.790472105145454, 60.03863275051117, 57.78206303715706, 56.81870453059673, 53.921793177723885, 56.113637164235115, 59.51706513762474, 64.40430209040642, 65.1498144865036, 63.174292892217636, 59.47260372340679, 65.37124380469322, 67.59755194187164, 65.0895345211029, 63.70329290628433, 56.914113610982895, 56.7788864672184, 63.451286628842354, 50.422199964523315, 51.104688942432404, 48.556659668684006, 49.54088665544987, 48.56136001646519, 49.70185361802578, 50.99392868578434, 51.15329593420029, 53.147565722465515, 53.22409741580486, 51.81216157972813, 51.70645885169506, 51.9921313226223, 51.191993057727814, 51.840785443782806, 51.087536662817, 52.07433991134167, 51.89405478537083, 55.30085317790508, 54.23242270946503, 57.50594325363636, 58.585305735468864, 57.503769770264626, 59.669528156518936, 60.71119666099548, 62.276306077837944, 63.95655691623688, 69.06934216618538, 72.28619635105133, 71.02404087781906, 4.0549638122320175, 1.0523587558418512, 1.152449541259557, 3.0664884159341455, 0.4673507862025872, 0.052364837974892, 0.12815435766242445, 33.11035171151161, 67.54506155848503, 29.743487276136875, 68.2394514977932, 45.489631444215775, 13.1855290196836, 29.125102758407593, 42.960851937532425, 53.18205647170544, 60.75645223259926, 68.3616529405117, 29.051384814083576, 1.034842289518565, 0.015909228641248774, 0.04029460753372405, 0.08621444954769686, 0.04825406344025396, 0.07211809657746926, 0.08393794123549014, 0.0007479871032955998, 0.033885798693518154, 0.034167436315328814, 0.04305128910345957, 0.03854742863040883, 0.04336710262577981, 0.08197916860808618, 0.022663811505481135, 0.07992324884980917, 0.006748028308720677, 0.03533028153469786, 0.09742417460074648, 0.020379241614136845, 0.017024342632794287, 0.024905379505071323, 0.04399812482006382, 0.025508660219202284, 0.03977941974881105, 0.0426582848012913, 0.05019100950448774, 0.03404263305128552, 0.010639144293236313, 1.0232007829472423, 76.4738680422306, 81.96876838803291, 81.41198426485062, 79.27798077464104, 49.03366707265377, 41.551313772797585, 53.124462962150574, 42.70590841770172, 38.658232614398, 0.367197630694136, 0.40044599503744394, 5.165311731398106, 4.6738475281745195, 2.590716420672834, 41.565129831433296, 1.908365897834301, 0.9769940155092627, 73.39395090937614, 93.34294885396957, 94.40024971961975, 92.27002322673798, 86.5821236371994, 85.55800259113312, 87.58346870541573, 82.81350865960121, 78.75616237521172, 73.86607557535172, 69.33487951755524, 74.19185489416122, 71.59784808754921, 71.65924519300461, 74.51613709330559, 77.06871092319489, 76.87948867678642, 80.32653450965881, 82.6620563864708, 72.02087938785553, 67.48897656798363, 58.15802626311779, 59.83351595699787, 57.44748719036579, 57.32764542102814, 59.15702685713768, 57.16639347374439, 57.30543941259384, 55.26731237769127, 56.756433472037315, 57.497887685894966, 52.79682174324989, 55.32935544848442, 53.85143235325813, 52.88690350949764, 53.35231773555279, 54.22644942998886, 59.404040202498436, 61.20701305568218, 63.456655740737915, 67.17635974287987, 68.29859912395477, 71.22513368725777, 71.2187348306179, 69.25682410597801, 71.04566931724548, 69.59258928894997, 64.02735471725464, 66.17734774947166, 71.1831459403038, 67.44781717658043, 67.39510640501976, 72.09268033504486, 68.27373325824738, 70.7899658381939, 58.83065477013588, 50.40899187326431, 71.78457006812096, 67.67170876264572, 65.12479662895203, 59.36097711324692, 58.09903062880039, 59.91281770169735, 62.80120611190796, 61.93151257932186, 59.38649654388428, 55.57744413614273, 59.25186976790428, 61.40768028795719, 67.39747747778893, 66.8218007683754, 66.10085785388947, 62.57954880595207, 67.58980795741081, 71.12900644540787, 66.32334351539612, 65.96915692090988, 60.22558271884918, 59.23489607870579, 65.6199936568737, 52.22917780280113, 53.81845012307167, 51.47559463977814, 52.6409313082695, 50.94371438026428, 52.85238616168499, 53.182330057024956, 54.71145920455456, 53.668517768383026, 56.82533897459507, 53.86187419295311, 53.15136171877384, 53.95724907517433, 54.57910090684891, 53.67664933204651, 54.75564703345299, 53.24020475149155, 53.538009971380234, 58.459825068712234, 57.114131078124046, 58.945017233490944, 62.837011590600014, 62.2128950804472, 63.553683534264565, 63.2429514080286, 65.57384133338928, 66.91817119717598, 74.58334028720856, 74.30070385336876, 78.96920174360275, 5.615693964064121, 0.5857898073736578, 3.4237485704943538, 2.9074709862470627, 0.6043728289660066, 0.054488616005983204, 0.031116422687773593, 30.651119872927666, 78.12163442373276, 36.5466783195734, 49.540799260139465, 38.06043729186058, 21.78148951381445, 44.170296639204025, 53.511145412921906, 58.569631576538086, 66.03110119700432, 77.17271134257317, 44.60650563240051, 1.2351175490766764, 0.053861363921896555, 0.07467945601092651, 0.023454330512322485, 0.055755139255779795, 0.11562612562556751, 0.08823897645925172, 0.009350146028737072, 0.03993647675088141, 0.04622582207957748, 0.036007183298352174, 0.0648850659490563, 0.035289904990349896, 0.06992865703068674, 0.040223546893685125, 0.10640278851496987, 0.1209603862662334, 0.15500062960200012, 0.2416990336496383, 0.1277743186801672, 0.07510283641749993, 0.15920927486149594, 0.22862092213472351, 0.12507729465141892, 0.11017286902642809, 0.17881384788779542, 0.12641611421713606, 0.144535441941116, 0.14966084738261998, 1.2984772492200136, 85.82197442650795, 95.18736988306046, 91.9122876226902, 90.30995920300484, 50.74665315449238, 54.44341018795967, 84.27173361182213, 52.44760528206825, 50.465228855609894, 0.4611849639331922, 1.2292537512257695, 8.70856175199151, 10.009706933051348, 4.731630552560091, 56.83502085506916, 9.205094408243895, 0.6234434712678194, 80.34871771931648, 92.96527191996574, 96.00444003939629, 93.794364631176, 89.4377464056015, 89.11408737301826, 91.53697416186333, 84.39301550388336, 84.20032024383545, 78.11372324824333, 73.20807248353958, 78.96519675850868, 76.05808675289154, 74.84039649367332, 79.26101088523865, 81.09834149479866, 80.54807022213936, 82.10245281457901, 86.60709589719772, 76.64496526122093, 71.5007708966732, 61.38035975396633, 63.19563254714012, 61.24319851398468, 62.47106462717056, 63.37134271860123, 60.21305099129677, 60.31661443412304, 56.71994403004646, 60.40301039814949, 61.27522699534893, 55.20998865365982, 58.029710948467255, 57.40955002605915, 57.066614627838135, 55.72234556078911, 56.090150624513626, 61.001957058906555, 64.57428976893425, 66.60075902938843, 70.71697935461998, 71.40690073370934, 74.19808655977249, 74.6917712688446, 72.74566009640694, 71.8465219438076, 72.03615456819534, 68.22725415229797, 70.81866949796677, 72.54833668470383, 71.4620965719223, 67.53308460116386, 75.17133593559265, 69.75492417812347, 72.76627019047737, 61.370449885725975, 52.86609202623367, 73.84326159954071, 70.45127481222153, 67.8791244328022, 64.14978414773941, 60.342730432748795, 63.40795375406742, 65.56495741009712, 64.05801147222519, 60.86940877139568, 57.31347218155861, 62.606990933418274, 63.58560562133789, 70.31402617692947, 69.6778567135334, 68.53266656398773, 64.66680720448494, 71.88048452138901, 74.75841209292412, 69.39860209822655, 69.21194091439247, 63.211337104439735, 62.044408321380615, 69.0977418422699, 54.563381150364876, 55.69459185004234, 53.021845668554306, 55.96962109208107, 54.818286672234535, 55.4914965480566, 55.869716852903366, 58.64407338202, 57.41412118077278, 59.797486290335655, 55.94159759581089, 56.43948867917061, 56.95791386067867, 57.29291148483753, 56.54267594218254, 57.13986709713936, 56.66419342160225, 57.876282781362534, 61.73972547054291, 60.14728032052517, 63.0549792945385, 65.74012041091919, 66.24771997332573, 67.03339621424675, 68.80376681685448, 69.60246875882149, 71.93213894963264, 79.05664265155792, 79.31166976690292, 82.37765684723854, 6.144401868805289, 3.7433646200224757, 9.758292473852634, 7.229066966101527, 1.0051148221828043, 0.1624111967976205, 0.3911497938679531, 41.000358536839485, 83.12545672059059, 48.08478958904743, 83.41827660799026, 62.5970658659935, 21.675889380276203, 45.369854271411896, 61.61547973752022, 73.71666759252548, 78.17777261137962, 91.18695974349976, 43.875155076384544, 1.0097765782848, 0.21659376594470814, 0.15442932432051748, 0.1618849250371568, 0.09514099438092671, 0.17297966172918677, 0.14355108694871888, 0.09648041508626193, 0.07981223840033635, 0.19589574221754447, 0.10242941891192459, 0.22204737877473235, 0.13104131212458014, 0.20070328580914065, 0.18890150502556935], [0.028161682312202174, 0.07363087555859238, 0.029551318584708497, 0.023818350236979313, 0.033634986175457016, 0.04588161398714874, 0.07140456611523405, 0.0814282130158972, 0.06615088786929846, 0.09097318208659999, 0.0314342140336521, 0.10392212279839441, 0.24913478933740407, 0.4887233331101015, 17.417554780840874, 84.54193711280823, 72.012709826231, 70.18380716443062, 41.48053117096424, 36.77678257226944, 62.54915043711662, 48.55763241648674, 29.59049228578806, 12.485520131886005, 0.017734663306328002, 0.13506985298590735, 2.1142153395339847, 3.48788651637733, 10.277204979211092, 1.786628148984164, 0.9751846001017839, 25.191299244761467, 71.56925082206726, 84.64836180210114, 84.52609956264496, 89.74103853106499, 91.15862846374512, 91.75360813736916, 84.29719984531403, 84.0979765355587, 77.54351824522018, 77.79372721910477, 74.50007915496826, 74.85190227627754, 72.21450179815292, 76.53396561741829, 77.27509304881096, 79.9149177968502, 71.1485829949379, 83.93253341317177, 79.37426760792732, 71.15481466054916, 61.86213970184326, 55.276416689157486, 56.02183409035206, 55.26377856731415, 55.79937882721424, 53.61830726265907, 53.449463322758675, 53.71409252285957, 55.10056972503662, 53.526914566755295, 53.00402842462063, 52.2651656717062, 52.2520487755537, 49.63384486734867, 47.71206758916378, 49.776694402098656, 55.770998150110245, 61.28187283873558, 64.65095445513725, 66.69807180762291, 66.09135076403618, 65.00096127390862, 67.01078742742538, 62.09304951131344, 60.84353595972061, 66.04398250579834, 67.39500761032104, 62.468408569693565, 60.928020626306534, 60.74246138334274, 65.66979378461838, 59.52711179852486, 68.61572250723839, 64.11946937441826, 67.52366870641708, 53.61071527004242, 50.90366832911968, 69.53164055943489, 59.836065620183945, 60.19374042749405, 55.77158711850643, 61.47962562739849, 59.483068361878395, 62.22866803407669, 58.22103448212147, 57.08683334290981, 51.90709948539734, 52.57647916674614, 58.35970424115658, 61.26065097749233, 60.62349356710911, 58.503473326563835, 59.2111511528492, 66.71886429190636, 63.452084586024284, 64.11234855651855, 61.512566059827805, 55.057559832930565, 51.667324751615524, 64.56330835819244, 53.6010067909956, 49.52705539762974, 50.428218841552734, 50.1478660851717, 50.40656380355358, 48.81232514977455, 50.63628427684307, 53.394256085157394, 51.484151780605316, 52.10723854601383, 50.84434971213341, 52.37039342522621, 50.301290452480316, 51.57298341393471, 51.916184797883034, 54.02956299483776, 55.3600388020277, 57.79259227216244, 57.620427310466766, 63.116889372467995, 60.2366591244936, 64.37966421246529, 63.42836245894432, 67.11452946066856, 67.55150601267815, 68.87970194220543, 68.08436661958694, 70.37198066711426, 70.96748471260071, 76.28603652119637, 13.387225046753883, 0.789255826966837, 1.7390419961884618, 2.1521042939275503, 1.4090717397630215, 0.16109820397105068, 0.09059057527338155, 6.416485318914056, 70.95619171857834, 43.13186936080456, 48.50206799805164, 59.27481673657894, 25.901161953806877, 15.015444327145815, 27.954680062830448, 42.59419061243534, 55.732787400484085, 64.20889377593994, 66.50919914245605, 9.408320803195238, 0.2911865687929094, 0.08072950324276462, 0.08195272588636726, 0.06159646487503778, 0.053660264165955596, 0.07998734814464115, 0.009918094019667478, 0.07943414384499192, 0.034284224384464324, 0.0289505908585852, 0.05487036563863512, 0.033148411894217134, 0.06368618574924767, 0.07638787254109047, 0.013896879445383092, 0.05548140179598704, 0.03344995762745384, 0.04629300870874431, 0.04022150969831273, 0.03378842149686534, 0.04354919226898346, 0.05362342024454847, 0.09863520375802182, 0.033000550101860426, 0.051948437467217445, 0.09536272584227845, 0.2156849022139795, 0.45633111032657325, 27.240447588264942, 98.94868925213814, 82.26487129926682, 81.00918307900429, 59.984056279063225, 46.487826481461525, 49.59186092019081, 42.89655938744545, 38.87422062456608, 17.4068583548069, 0.3235975530697033, 0.4147849709261209, 3.2932443358004093, 2.186080883257091, 6.09243443235755, 2.2835905384272337, 1.1700639710761607, 33.94402697682381, 81.93015486001968, 83.923991471529, 86.29169762134552, 91.1970292031765, 92.17666983604431, 93.06680247187614, 88.34038808941841, 86.4239913225174, 80.0146396458149, 80.90688496828079, 78.89714241027832, 77.84250140190125, 76.97604909539223, 78.01026999950409, 79.3581260740757, 82.19672575592995, 75.23335620760918, 85.46002864837646, 81.98291882872581, 72.88824364542961, 64.96217295527458, 57.57425978779793, 57.99642093479633, 57.05975979566574, 59.2443385720253, 56.431064531207085, 57.52794027328491, 54.65790867805481, 57.580457255244255, 58.21226455271244, 56.58792771399021, 52.77397736907005, 55.39126932621002, 52.06346109509468, 51.18696592748165, 52.551685497164726, 58.967280238866806, 63.81998464465141, 66.80495247244835, 70.51276311278343, 68.84330749511719, 69.10635218024254, 69.5498339831829, 63.3787827193737, 62.90555231273174, 66.50810480117798, 71.49507880210876, 64.09265801310539, 64.19995665550232, 65.22584840655327, 71.0971337556839, 61.25735655426979, 72.5015839934349, 66.91193953156471, 72.87346243858337, 54.57099974155426, 52.99151949584484, 73.02147969603539, 62.51759693026543, 62.75590494275093, 57.596914172172546, 65.02215653657913, 62.54169903695583, 63.61619018018246, 61.541953682899475, 59.021130949258804, 54.71129201352596, 56.96498528122902, 59.92849946022034, 63.509161323308945, 62.6289651542902, 61.77489638328552, 63.20200100541115, 68.75829845666885, 66.28400042653084, 66.8635605275631, 62.088972330093384, 58.69820907711983, 53.55758272111416, 65.52743062376976, 56.605706959962845, 51.968811973929405, 53.46068412065506, 54.049967899918556, 52.29638859629631, 52.385265827178955, 53.43435913324356, 56.08743377029896, 54.39159236848354, 54.03927527368069, 52.90089815855026, 55.11789299547672, 52.57941260933876, 53.73073562979698, 54.27983656525612, 57.710946053266525, 59.54933300614357, 61.042113304138184, 61.54164969921112, 66.04084387421608, 65.66810667514801, 66.84429556131363, 67.69254684448242, 70.79539194703102, 70.39884522557259, 70.50598427653313, 70.85536792874336, 72.8579668700695, 76.46521210670471, 78.0899441242218, 17.499216198921204, 1.2195189110934734, 3.585821036249399, 4.401132836937904, 2.8124219365417957, 0.3532206150703132, 0.12645528477150947, 5.261630862951279, 73.17563742399216, 53.163361474871635, 44.40983958542347, 42.62203931808472, 27.535463757812977, 30.954328402876854, 43.63358683884144, 55.523012056946754, 63.55624079704285, 69.84441697597504, 81.4676208794117, 15.70297658443451, 0.2300539202406071, 0.06583636568393558, 0.14472224051132798, 0.06999243720201775, 0.016436227706435602, 0.006647705249633873, 0.10428877343656495, 0.020197016528982203, 0.06590581586351618, 0.01929993995872792, 0.05100342743389774, 0.04304826485167723, 0.0692657261970453, 0.07248943016747944, 0.14966512215323746, 0.19919488549930975, 0.15546625305432826, 0.18756011762889102, 0.16176457836991176, 0.15884020482189953, 0.14987759903306141, 0.25976783595979214, 0.24909539613872766, 0.22429102478781715, 0.17693814384983853, 0.249108161078766, 0.30636865412816405, 0.7312389963772148, 28.573385663330555, 114.75655540823936, 91.7924116551876, 91.93909138441086, 58.42769779264927, 50.539123490452766, 80.6125907599926, 68.16885128617287, 47.98108175396919, 22.258025743067265, 0.2845162048470229, 0.5133100622333586, 6.635520290583372, 10.471262466162443, 25.530978217720985, 5.388639522716403, 1.6678358358331025, 38.6806970089674, 90.73157697916031, 85.7330895960331, 87.3870724439621, 93.72706264257431, 96.34520575404167, 98.84012907743454, 92.26414114236832, 90.22954031825066, 84.2643392086029, 87.13712945580482, 80.56773036718369, 81.29642486572266, 81.66160047054291, 83.78950908780098, 82.89585024118423, 82.97098740935326, 78.33289548754692, 87.13943213224411, 85.44965520501137, 77.96340331435204, 68.49358946084976, 60.803125128149986, 62.65767261385918, 60.36283515393734, 61.06618881225586, 62.26741075515747, 59.6340836584568, 60.39224557578564, 61.80401422083378, 62.551749497652054, 59.10321794450283, 56.45017370581627, 58.02701689302921, 54.20608252286911, 54.03111711144447, 55.803687795996666, 60.999092012643814, 67.79712483286858, 70.56372597813606, 73.86969298124313, 70.56509390473366, 70.253936201334, 71.93213135004044, 62.84124456346035, 66.12049520015717, 69.55413535237312, 73.53625327348709, 68.08795362710953, 67.45120659470558, 68.5205452144146, 71.87924578785896, 66.69411242008209, 72.28277653455734, 70.23599356412888, 75.42028337717056, 58.86487573385239, 57.68411569297314, 75.69472745060921, 67.15747475624084, 66.83805629611015, 61.94379732012749, 70.01002728939056, 65.2546052634716, 68.3591602742672, 64.28409934043884, 63.44877876341343, 58.48491132259369, 59.2705799639225, 62.658082991838455, 66.49669021368027, 65.89667201042175, 63.718362897634506, 65.90823858976364, 74.08589377999306, 68.68044063448906, 68.89232486486435, 63.696631863713264, 60.6416679918766, 55.55201970040798, 67.86023184657097, 59.848749339580536, 53.382697105407715, 55.86593225598335, 56.64290316402912, 57.67103299498558, 56.06607511639595, 56.58364154398441, 58.313035145401955, 56.98239594697952, 56.640266105532646, 55.52109315991402, 58.79574604332447, 54.65097405016422, 57.99478322267532, 56.94804958999157, 61.93424843251705, 62.45984382927418, 63.95902678370476, 67.13853657245636, 69.90701481699944, 68.67489293217659, 72.26063892245293, 70.92294350266457, 73.49034413695335, 73.78154531121254, 75.2831943333149, 75.56109622120857, 77.08165302872658, 79.48193103075027, 83.8527300953865, 17.835800237953663, 2.884939620271325, 10.038102809339762, 10.394231099635363, 6.193538457155228, 0.27894410071894526, 0.310739814885892, 8.858934883028269, 84.70056340098381, 56.57133400440216, 69.53472599387169, 74.18770551681519, 36.92210577428341, 24.130179584026337, 43.499777019023895, 61.417700350284576, 74.44919988512993, 81.60769656300545, 93.76447543501854, 14.828091580420732, 0.5246591626200825, 0.2586543175857514, 0.20212935225572437, 0.23822873627068475, 0.0964134956302587, 0.12655439117224887, 0.22171077027451247, 0.1956569784670137, 0.15450039238203317, 0.0878468256269116, 0.08352835735422559, 0.33680896915029734, 0.19764988246606663, 0.14104377070907503], [0.035639582711155526, 0.014700215342600131, 0.03957451648602728, 0.10494590809685178, 0.0708820644649677, 0.03833886657957919, 0.10280350586981513, 0.03526171451085247, 0.055793879364500754, 0.025998665078077465, 0.03191747091477737, 0.06480762283899821, 0.04633187869330868, 0.13821991364238784, 58.87986972928047, 77.88513511419296, 67.95846417546272, 54.00086313486099, 23.73019214719534, 75.91361090540886, 96.13173320889473, 31.105953566730022, 40.97926206886768, 12.036692965775728, 0.1803180031129159, 1.185545646585524, 3.8643954880535603, 1.4783682650886476, 2.590502444654703, 0.37044506112579256, 12.25561061874032, 77.56920486688614, 57.762646079063416, 95.02221554517746, 89.45736095309258, 89.96176868677139, 80.69051697850227, 85.55011421442032, 85.73625102639198, 89.2581832408905, 77.41945490241051, 75.74344843626022, 77.85351321101189, 75.87998270988464, 76.09996050596237, 76.10378310084343, 74.69462871551514, 75.87481498718262, 78.89477893710136, 82.39979445934296, 70.284972935915, 74.19712141156197, 61.49005986750126, 55.73882907629013, 55.052046328783035, 55.11071518063545, 53.28787699341774, 54.06257562339306, 53.988019824028015, 53.67666073143482, 53.27378734946251, 54.88520868122578, 51.47609621286392, 52.162586376070976, 49.33855891227722, 49.940549209713936, 46.76420845091343, 52.710634768009186, 58.598855808377266, 58.969294130802155, 62.13977560400963, 66.2987132370472, 62.91182957589626, 67.17097163200378, 66.39640599489212, 66.61135286092758, 67.00185030698776, 65.07668361067772, 65.07882669568062, 65.21072521805763, 66.24488532543182, 61.8902163952589, 65.56294351816177, 64.94010373950005, 60.083124563097954, 64.3178491294384, 67.37502828240395, 51.52500718832016, 48.69277976453304, 70.59268042445183, 57.099482864141464, 54.98349040746689, 56.967793330550194, 68.30465599894524, 60.95486618578434, 62.39274322986603, 56.98399946093559, 56.137587279081345, 51.75885424017906, 53.92376907169819, 53.94491873681545, 57.43801049888134, 56.12632468342781, 58.7423475086689, 61.57230265438557, 65.10661080479622, 62.62789361178875, 65.66974818706512, 62.72945836186409, 57.15527907013893, 49.07970920205116, 54.887051582336426, 59.35921400785446, 48.46907436847687, 54.39694628119469, 49.28524777293205, 52.01745316386223, 48.81251893937588, 49.21547591686249, 51.68903298676014, 50.85906632244587, 52.08260826766491, 51.45029179751873, 51.422899067401886, 50.00058598816395, 52.482483610510826, 58.12800407409668, 61.0728270560503, 61.60392455756664, 64.60817635059357, 63.460292145609856, 65.6589263677597, 66.1920453608036, 65.48456892371178, 67.14521661400795, 69.12684828042984, 70.24512827396393, 70.02347096800804, 68.4109514951706, 72.2930359840393, 72.20053374767303, 71.45670086145401, 26.068719662725925, 0.4943428159458563, 1.478168300818652, 2.045005140826106, 0.8779319655150175, 0.2489478571806103, 0.019784833275480196, 0.1637305275653489, 33.26468043029308, 78.79153847694397, 32.6063771545887, 47.27493144571781, 52.123988047242165, 22.169102914631367, 13.483454883098602, 24.514300972223282, 42.22988896071911, 50.49702174961567, 67.78726816177368, 34.28770333528519, 0.6373843888286501, 0.00926039254409261, 0.07778449056786485, 0.07594497365062125, 0.02748280643572798, 0.04829773140954785, 0.015495403386012185, 0.05463117886392865, 0.05307531821017619, 0.029031590711383615, 0.03858337084238883, 0.08023036440135911, 0.007967754045239417, 0.018445557288941927, 0.03826980973826721, 0.04112227288715076, 0.019163572178513277, 0.06821596572990529, 0.09605209939763881, 0.013994457021908602, 0.07324535952648148, 0.02587106206192402, 0.09916565380990505, 0.007128245406420319, 0.07131123362341896, 0.05250307782262098, 0.012777937827195274, 0.3641883109230548, 74.06326219439507, 85.99793538451195, 72.78304249048233, 63.949702084064484, 37.712254375219345, 73.95407125353813, 73.82882997393608, 34.26767461001873, 52.808794900774956, 10.801308006048203, 0.1866473798872903, 2.8393002692610025, 4.944140324369073, 3.2423648284748197, 2.0167591189965606, 0.3712781664216891, 17.450031638145447, 88.44203263521194, 70.537598580122, 97.03574270009995, 90.68319797515869, 89.11156430840492, 79.82256755232811, 87.3952268064022, 88.20708364248276, 90.49598962068558, 82.8396588563919, 79.86942663788795, 79.65435817837715, 78.85329276323318, 79.14310321211815, 79.7177691757679, 78.67553070187569, 78.0037647485733, 78.97573739290237, 84.3027475476265, 76.13203078508377, 77.92651489377022, 64.90074545145035, 58.08913975954056, 58.86244386434555, 56.272989213466644, 57.00852334499359, 55.61804875731468, 56.77839249372482, 56.90443553030491, 55.914220064878464, 57.22111813724041, 54.13189150393009, 55.7745623588562, 52.859636172652245, 51.396194100379944, 49.71030816435814, 55.48607423901558, 62.679855823516846, 62.87282846868038, 63.3932713419199, 67.41866514086723, 67.64549016952515, 69.52321261167526, 69.17515128850937, 68.43165278434753, 69.29406210780144, 67.83878579735756, 66.91635489463806, 69.46677044034004, 70.30239880084991, 63.68364416062832, 68.40595856308937, 67.6202367246151, 63.70259754359722, 66.26734212040901, 71.10411018133163, 52.60747790336609, 52.868425101041794, 72.42990463972092, 58.6418467015028, 58.432899713516235, 60.28661884367466, 68.52417781949043, 62.519576624035835, 63.76556396484375, 59.072762578725815, 57.567602545022964, 54.40969839692116, 56.79880879819393, 57.063115015625954, 60.60276187956333, 58.1169580668211, 60.58955758810043, 65.47383829951286, 67.41947829723358, 64.655020236969, 66.27876430749893, 64.1819380223751, 59.13770109415054, 51.769045293331146, 55.58669663965702, 61.484413370490074, 50.436665788292885, 55.25596618652344, 53.93882006406784, 53.78856472671032, 49.452431201934814, 50.39413467049599, 53.29910159111023, 52.97161616384983, 54.9549463391304, 53.206751346588135, 53.93462888896465, 53.3048202842474, 55.44320873916149, 60.60534954071045, 65.26775255799294, 64.68986436724663, 67.94157788157463, 67.46405750513077, 68.23969468474388, 70.01498982310295, 67.18909665942192, 71.1818540096283, 72.18936994671822, 74.19111773371696, 74.60581228137016, 72.45777994394302, 77.47550189495087, 73.138118237257, 73.95793184638023, 30.430813394486904, 1.1647444940172136, 1.7342345416545868, 2.200144878588617, 4.58727914839983, 1.4745083847083151, 0.12474209623178467, 0.15816694329259917, 33.747524321079254, 85.06304115056992, 40.28394877910614, 39.22387406229973, 41.39725103974342, 20.16251228749752, 23.985067270696163, 38.243203684687614, 53.38332787156105, 55.56658431887627, 74.6398888528347, 48.142956867814064, 0.9273369144648314, 0.025451685542066116, 0.069913680490572, 0.03392126222024672, 0.012205311522848206, 0.058702203969005495, 0.11771776495152153, 0.024857542521203868, 0.06590329256141558, 0.013923447404522449, 0.029454186296788976, 0.0556749316456262, 0.01889114089863142, 0.03017405284481356, 0.17244825430680066, 0.0757262553088367, 0.1429815182927996, 0.15607175650075078, 0.19143156067002565, 0.09031511974171735, 0.15186924138106406, 0.10906344730756246, 0.22527641878696159, 0.2184334906633012, 0.2066013411968015, 0.2099840948358178, 0.11076189679442905, 0.4615464195376262, 83.58699515461922, 98.65462303161621, 84.88400235772133, 74.2435397207737, 35.94477541744709, 86.16125822067261, 116.28443822264671, 50.3950884193182, 62.30774559080601, 17.52432145178318, 0.5954484140966088, 3.5092943301424384, 12.706679664552212, 10.14922784641385, 10.84034901112318, 3.072385936975479, 15.949784740805626, 89.17018756270409, 72.74411737918854, 97.55122303962708, 92.17946648597717, 91.00808054208755, 81.3384810090065, 89.83192205429077, 88.96750643849373, 94.34376955032349, 85.20899131894112, 82.13045731186867, 84.717016518116, 83.02346259355545, 81.36328607797623, 81.47107869386673, 81.41610324382782, 83.1214289367199, 78.05791184306145, 88.01103696227074, 81.12982660531998, 81.11845761537552, 69.5819802582264, 61.29695422947407, 63.30559864640236, 58.07937428355217, 60.41839577257633, 59.65064696967602, 61.09292797744274, 60.93251958489418, 59.973910823464394, 61.66131287813187, 55.82159623503685, 57.22872152924538, 57.46177822351456, 55.376780703663826, 51.126264184713364, 58.71166415512562, 66.20054930448532, 68.06995779275894, 68.3944071829319, 72.05830737948418, 70.38301527500153, 73.71446371078491, 71.62571579217911, 70.36053568124771, 70.51866799592972, 71.006318628788, 71.14453241229057, 70.65087050199509, 74.26799520850182, 67.43289917707443, 71.39058440923691, 71.52432203292847, 66.79823443293571, 68.30616071820259, 72.44528621435165, 57.17427425086498, 55.70769354701042, 75.64375698566437, 61.37825466692448, 60.77668994665146, 63.00006844103336, 72.73321196436882, 67.30461046099663, 66.57748147845268, 62.82888002693653, 61.089637354016304, 58.49961653351784, 59.194291457533836, 59.94473218917847, 63.67480583488941, 62.94283211231232, 62.27406419813633, 70.99581599235535, 70.36873564124107, 67.90930241346359, 68.89120772480965, 67.1264836192131, 61.458593755960464, 54.200401827692986, 59.62594449520111, 64.07009482383728, 53.91695223748684, 59.07106027007103, 54.353222027421, 57.31495410203934, 51.52969613671303, 54.86416541039944, 55.596484914422035, 57.09949426352978, 58.44765052199364, 56.558980867266655, 57.203319892287254, 56.858967170119286, 58.695917800068855, 64.95182991027832, 66.93022415041924, 68.2589216530323, 70.93485966324806, 71.13179549574852, 70.41013062000275, 74.21058788895607, 68.87589454650879, 73.99996519088745, 75.15086263418198, 77.68537223339081, 78.88307556509972, 77.14225977659225, 81.14721447229385, 77.94355317950249, 77.78396934270859, 33.36218699812889, 1.4217872824519873, 9.160447753965855, 5.8555803168565035, 6.727998778223991, 2.1762484358623624, 0.22031813015928492, 0.44722032733261585, 43.34256425499916, 94.02046769857407, 44.422329515218735, 64.62992638349533, 67.48216733336449, 31.031316071748734, 22.25459262728691, 36.96855068206787, 62.122665122151375, 70.34381657838821, 87.5263349711895, 54.79240246117115, 1.1183202476240695, 0.12187752494355664, 0.15693358291173354, 0.153346337901894, 0.11470716126495972, 0.14846407488221303, 0.16742807056289166, 0.17649809480644763, 0.18311511317733675, 0.1164149989199359, 0.10779852338600904, 0.15066779335029423, 0.08108724068733864, 0.09582993749063462], [0.08641057691420428, 0.10922107947408222, 0.07113232408300973, 0.08306494550197385, 0.015003183216322213, 0.1024129506549798, 0.013322154718480306, 0.1030090288259089, 0.052489069785224274, 0.1047779007058125, 0.1316272228723392, 0.07563008781289682, 0.5426720960531384, 7.795287407934666, 87.98981130123138, 69.07481387257576, 71.516372859478, 45.669521391391754, 28.016039170324802, 35.35402111709118, 57.92027302086353, 27.618926279246807, 47.57628187537193, 1.445043459534645, 0.32731992832850665, 1.8741983687505126, 1.6687011206522584, 1.606153033208102, 0.6761167198419571, 2.7189118042588234, 88.31279397010803, 96.83550104498863, 98.77322986721992, 88.86197090148926, 90.51610574126244, 85.7385841012001, 88.43622654676437, 81.03565245866776, 82.04079732298851, 75.74587270617485, 79.70940962433815, 81.42917454242706, 81.19250044226646, 75.1708647608757, 75.83233326673508, 75.21928176283836, 76.87828034162521, 79.77524489164352, 79.18613970279694, 63.51204536855221, 74.38590288162231, 72.39878430962563, 63.465205281972885, 54.09916765987873, 55.43445020914078, 54.40880544483662, 53.169182762503624, 50.64542658627033, 54.16987046599388, 50.6082683801651, 54.45984050631523, 52.39160768687725, 51.16213046014309, 47.632838040590286, 48.56545999646187, 46.66009023785591, 49.73485104739666, 51.044766157865524, 56.630979403853416, 59.26239140331745, 65.04095792770386, 64.13287505507469, 65.6002651154995, 64.38466474413872, 68.0703529715538, 65.47809407114983, 68.65726187825203, 66.04219660162926, 68.41412052512169, 63.097407817840576, 67.20524579286575, 63.75044837594032, 64.35630306601524, 61.23846396803856, 65.8374635875225, 58.263128623366356, 74.46265116333961, 43.076240345835686, 47.56726495921612, 67.02833488583565, 58.30183334648609, 56.52791753411293, 61.83990329504013, 59.0745484828949, 61.6223231703043, 64.53799411654472, 50.99888741970062, 49.98589217662811, 49.03355307877064, 54.03215445578098, 54.85759936273098, 56.312453895807266, 59.30191308259964, 62.00373910367489, 62.77958907186985, 64.50563505291939, 56.97296105325222, 54.35064196586609, 67.38456577062607, 58.80051098763943, 57.254814729094505, 52.48862788081169, 51.397953405976295, 46.54893860220909, 47.184997871518135, 50.86567796766758, 50.503405407071114, 50.49238979816437, 47.164315581321716, 49.400130808353424, 51.04974769055843, 51.168780103325844, 52.08496794104576, 49.73221018910408, 52.95231319963932, 59.61694657802582, 64.2731711268425, 64.82234045863152, 65.88648095726967, 65.0532540678978, 66.02993085980415, 68.25389832258224, 69.55101951956749, 69.099200963974, 68.23540091514587, 69.53700587153435, 71.72334015369415, 70.23818984627724, 70.24300798773766, 67.14257955551147, 64.64915335178375, 63.830183297395706, 45.41618138551712, 3.111287299543619, 1.6143111954443157, 2.656263140961528, 2.245865687727928, 1.2627604720182717, 0.19599066290538758, 0.18043410469545051, 6.844554673880339, 65.87090939283371, 62.550343573093414, 28.098090067505836, 63.93543004989624, 126.76213279366493, 52.17956006526947, 12.104919254779816, 16.893002428114414, 49.811105355620384, 58.658239021897316, 53.20867024362087, 2.4121502274647355, 0.22986786381807178, 0.10501140262931585, 0.138010197551921, 0.016601318457105663, 0.06928209055331536, 0.029183621518313885, 0.044437134856707416, 0.06585132738109678, 0.02902580195950577, 0.02965540850709658, 0.030500924367515836, 0.07600988188642077, 0.029867954035580624, 0.009717031371110352, 0.05179170701012481, 0.05832128183101304, 0.06929054361535236, 0.030443144460150506, 0.05191404634388164, 0.02748418497503735, 0.04580699103826191, 0.06504674282041378, 0.10614580503897741, 0.17686700157355517, 0.1888130558654666, 0.7313033554237336, 11.991974115371704, 100.93931883573532, 75.73016434907913, 81.34179443120956, 53.739528357982635, 39.70433548092842, 49.50555235147476, 52.366605028510094, 38.400781229138374, 55.38724534213543, 0.7997492013964802, 0.3477218945045024, 4.557474497705698, 2.5949175702407956, 1.1938745621591806, 0.5828124296385795, 4.631142094731331, 95.69112405180931, 96.71768456697464, 102.45354518294334, 88.78661334514618, 93.99963721632957, 86.07963860034943, 91.97769731283188, 83.81193548440933, 81.02284714579582, 77.22884193062782, 84.5118199288845, 84.5535796880722, 85.32741576433182, 79.53099399805069, 80.38014963269234, 78.86398538947105, 81.17999911308289, 80.28101295232773, 81.39929294586182, 68.03739354014397, 77.7402412891388, 75.30272528529167, 65.26385396718979, 56.23809188604355, 58.35476070642471, 57.71914221346378, 56.600030064582825, 54.03780095279217, 55.090815648436546, 53.92344608902931, 57.696719616651535, 54.8697929084301, 55.45912608504295, 52.1608916670084, 53.48744608461857, 48.06544862687588, 51.79988443851471, 53.49984101951122, 60.1729479432106, 62.99359738826752, 67.46581301093102, 67.3479813337326, 66.96875408291817, 65.44173762202263, 73.8194140791893, 68.55841398239136, 71.52784064412117, 67.36978456377983, 71.32124572992325, 64.9866284430027, 70.0002846121788, 68.31535622477531, 68.62532839179039, 63.33929143846035, 67.31955125927925, 60.96744351089001, 77.69889190793037, 47.363257706165314, 51.54874451458454, 70.14094546437263, 60.112941563129425, 59.49631445109844, 65.67551627755165, 61.76383137702942, 63.70594896376133, 67.31927767395973, 55.68891495466232, 52.896296605467796, 52.600083500146866, 55.749156922101974, 57.71544121205807, 60.81982143223286, 63.46805892884731, 65.67305400967598, 66.37264207005501, 66.52352437376976, 56.46407335996628, 59.24298204481602, 70.04490181803703, 62.042736411094666, 61.326767429709435, 54.30939897894859, 52.74877332150936, 48.33860456943512, 50.038709342479706, 53.164999186992645, 53.42318393290043, 52.67655439674854, 50.030406787991524, 51.502972170710564, 53.8308260589838, 51.1028004437685, 53.50254267454147, 51.64730742573738, 56.55892767012119, 65.06118804216385, 68.24656471610069, 70.2409029006958, 67.9316072165966, 66.33047193288803, 70.39648935198784, 70.65771013498306, 72.77551889419556, 72.42426574230194, 71.55318528413773, 71.78355932235718, 75.45206487178802, 71.46098703145981, 71.38182207942009, 66.12543493509293, 66.14021614193916, 65.92450931668282, 49.091792553663254, 5.502966362982988, 0.8829590363893658, 1.4042837591841817, 3.0811613285914063, 2.693519191816449, 0.6485643389169127, 0.24964494165033102, 4.488403229042888, 70.47330603003502, 70.23144900798798, 34.18288595974445, 46.378920525312424, 96.26759871840477, 44.03802953660488, 21.04773748666048, 28.65555815398693, 59.556317031383514, 66.91902235150337, 63.72306324541569, 5.18063535913825, 0.3189779509557411, 0.05701725043763872, 0.042419892124598846, 0.05811968483612873, 0.03372328319528606, 0.07997083535883576, 0.04907336478936486, 0.06398023950168863, 0.032237755876849405, 0.09744655035319738, 0.03939952177461237, 0.008924959420255618, 0.04355639481218532, 0.33507180924061686, 0.23996932490263134, 0.18156875943532214, 0.1580358503269963, 0.15024666907265782, 0.16376710060285404, 0.21569349628407508, 0.22340898227412254, 0.14768953988095745, 0.19961937912739813, 0.23898670653579757, 0.340417439583689, 0.9116795577574521, 13.435166124254465, 113.35136041045189, 90.0795167684555, 91.44660741090775, 66.01157024502754, 43.448076993227005, 43.52150425314903, 77.78922066092491, 45.879912301898, 66.005619764328, 2.0097679691389203, 0.5858133779838681, 7.769586062058806, 10.047989878803492, 6.848401492461562, 3.6237225774675608, 4.144620476290584, 97.4877892434597, 100.2304744720459, 107.23499581217766, 93.4997208416462, 98.04030239582062, 88.972537368536, 93.01227539777756, 84.16411578655243, 82.67048433423042, 77.8533536195755, 85.89763596653938, 86.08354479074478, 87.91716679930687, 81.38413935899734, 85.6774377822876, 82.38215580582619, 82.58767157793045, 79.63073864579201, 84.85518470406532, 74.33206737041473, 80.58619737625122, 78.22128027677536, 68.25592741370201, 59.14402015507221, 61.96482539176941, 60.63999228179455, 60.01073844730854, 56.513060331344604, 59.416070356965065, 56.771560460329056, 59.53007183969021, 59.6291097253561, 57.943512573838234, 54.846952334046364, 56.41228973865509, 50.35347305238247, 53.973063826560974, 56.71021655201912, 61.66130527853966, 68.0470298230648, 69.11133751273155, 70.57791441679001, 71.88898846507072, 68.78590777516365, 77.86777004599571, 71.28744274377823, 73.47098037600517, 71.6650664806366, 75.75262874364853, 67.18413412570953, 73.91681805253029, 70.43650880455971, 70.23057505488396, 66.80061310529709, 69.84235748648643, 64.15254279971123, 78.48418816924095, 52.31279991567135, 57.04601213335991, 71.75393611192703, 65.19064709544182, 61.16385877132416, 69.50913056731224, 66.44489899277687, 66.29418388009071, 70.73974013328552, 58.08842159807682, 55.95913365483284, 55.12647673487663, 57.33385808765888, 59.882689118385315, 62.94811762869358, 66.91658288240433, 67.57048979401588, 70.28603687882423, 70.36418348550797, 57.84853667020798, 58.03132586181164, 71.87830343842506, 63.1752922385931, 62.695332393050194, 56.26962259411812, 56.132332161068916, 51.67479895055294, 51.587498635053635, 54.4387212395668, 57.947053983807564, 55.32397873699665, 52.66149580478668, 54.32593569159508, 55.06468065083027, 55.14670304954052, 56.90317779779434, 54.392340928316116, 59.993601366877556, 66.65662363171577, 70.77490344643593, 71.12179443240166, 70.923832654953, 70.38969531655312, 74.81951281428337, 74.35351341962814, 76.95613816380501, 76.51674494147301, 75.19113287329674, 74.2877085506916, 78.51883471012115, 76.12167254090309, 75.80601587891579, 67.14694932103157, 69.36193406581879, 65.38912564516068, 52.75046043097973, 5.288940472528338, 8.678133934736252, 8.857270572334528, 9.93862034752965, 5.1174556743353605, 0.6187060161028057, 0.3271611384116113, 9.005101639777422, 81.41168028116226, 76.27348959445953, 44.51028719544411, 79.28459241986275, 139.8459631204605, 63.83167281746864, 20.829794481396675, 30.30503634363413, 71.75483286380768, 75.99748000502586, 78.70891571044922, 6.136028543114662, 0.4173854266991839, 0.22343684249790385, 0.1763581851264462, 0.18015242996625602, 0.10880195899517275, 0.14646867726696655, 0.1404050042037852, 0.28304966166615486, 0.17202686285600066, 0.24069671868346632, 0.1272092029103078, 0.14475372241577134, 0.21575660852249712], [0.01028126305754995, 0.08464649930829182, 0.07079460236127488, 0.04744617632240988, 0.007375446912192274, 0.03583588819310535, 0.03504539701680187, 0.08133226816426031, 0.03434445337916259, 0.09146980504738167, 0.17037500540027395, 0.10788268293254077, 0.32893739466089755, 40.644085854291916, 85.88349312543869, 63.54381926357746, 56.10141322016716, 29.330669827759266, 23.331673331558704, 38.185579776763916, 34.07931871712208, 37.123472169041634, 29.27895650267601, 0.2789712039520964, 1.048664404079318, 2.677838383242488, 1.0010617459192872, 0.7106481387745589, 0.6494083686266094, 67.86009505391121, 101.43497183918953, 80.57047381997108, 85.92265382409096, 81.9086404144764, 88.20262268185616, 81.35664403438568, 88.29599887132645, 83.17556843161583, 86.58604502677917, 82.02299907803535, 75.17932310700417, 72.0773595571518, 75.0692430138588, 71.8502913415432, 77.55085945129395, 78.71786803007126, 79.62186232209206, 72.99067094922066, 67.02239200472832, 74.69927966594696, 74.7037710249424, 69.63358908891678, 57.5651478767395, 54.10045959055424, 55.97835302352905, 54.794207364320755, 52.17720039188862, 50.512289330363274, 52.75989152491093, 48.86084474623203, 52.59624570608139, 50.22416599094868, 49.22945536673069, 45.84855638444424, 48.04430656135082, 46.93047612905502, 48.33844117820263, 51.95584326982498, 55.90721324086189, 57.89448380470276, 63.02752196788788, 61.915694028139114, 63.67072105407715, 61.14733725786209, 62.479693964123726, 60.27404151856899, 62.8286824375391, 61.0782265663147, 67.38049238920212, 62.77103953063488, 68.13839972019196, 62.48211823403835, 67.30993017554283, 59.606352746486664, 68.93411502242088, 58.94467905163765, 72.08784699440002, 38.04919749498367, 36.686062440276146, 73.75195249915123, 52.589827850461006, 61.687979847192764, 60.67659191787243, 58.57263721525669, 59.52221766114235, 64.11782026290894, 52.305739894509315, 49.46008399128914, 52.30676583945751, 54.84989337623119, 55.765784829854965, 60.57948052883148, 63.34383599460125, 62.30275645852089, 62.458555698394775, 58.21773625910282, 57.636394053697586, 53.92608314752579, 59.329925179481506, 67.18968942761421, 62.753370478749275, 60.08990339934826, 54.129132851958275, 46.78569249808788, 43.754819333553314, 50.86980074644089, 48.71284268796444, 50.45175477862358, 45.83743058145046, 47.33634375035763, 52.062761932611465, 49.843194633722305, 52.62473277747631, 49.44365367293358, 58.364324793219566, 66.29596218466759, 66.86957940459251, 72.83868670463562, 68.22412312030792, 67.65600040555, 68.74416321516037, 68.69220480322838, 69.57042127847672, 68.00028473138809, 66.4655090868473, 68.67930069565773, 67.50985264778137, 64.22730758786201, 62.83354237675667, 67.98299565911293, 64.72541525959969, 65.58754339814186, 63.527331948280334, 22.34888456761837, 0.6492424244061112, 1.4221319952048361, 3.566175140440464, 1.8266080599278212, 0.46269176120404154, 0.11180382018210366, 0.2832992310868576, 28.46179325133562, 79.21161353588104, 33.610777258872986, 75.06456926465034, 115.70385977625847, 136.04762613773346, 44.551556780934334, 14.477590788155794, 51.33103899657726, 49.698574393987656, 60.47206029295921, 12.158550526946783, 0.6216595263686031, 0.05969260004349053, 0.08973998497822322, 0.11422458715969697, 0.024963905270851683, 0.035710958763957024, 0.07598691983730532, 0.026977819470630493, 0.012558822436403716, 0.11082577344495803, 0.04761412805237342, 0.017150021631096024, 0.023972846829565242, 0.05396167631261051, 0.07028237945633009, 0.05819906866236124, 0.09445203642826527, 0.051930592526332475, 0.03667100841994397, 0.030640034383395687, 0.041858646654873155, 0.11170765268616378, 0.08181384779163636, 0.1149597141193226, 0.16562986158533022, 0.26438277738634497, 51.53026610612869, 94.32407900691032, 73.18953707814217, 64.12364155054092, 44.81141723692417, 25.772440060973167, 31.584957763552666, 38.96923452615738, 49.826163947582245, 32.332970425486565, 0.43323645426426083, 1.8988914624787867, 2.9541854420676827, 1.344717680476606, 1.3324426766484976, 1.222954757977277, 81.46401107311249, 103.95574897527695, 85.86278423666954, 89.01222243905067, 85.47374591231346, 90.15510231256485, 83.73068824410439, 91.56902924180031, 85.13346657156944, 89.35643076896667, 82.53766626119614, 75.81654131412506, 72.90770620107651, 78.51303622126579, 73.78755658864975, 78.78662154078484, 81.5956512093544, 80.79928234219551, 76.80291518568993, 72.82482504844666, 76.1140501499176, 79.80134189128876, 73.6185796558857, 61.62406347692013, 55.16825169324875, 58.88983279466629, 56.79834142327309, 53.83561760187149, 54.65765409171581, 54.74955976009369, 51.790354549884796, 56.45694114267826, 51.81078605353832, 51.64261467754841, 48.62975254654884, 51.985816061496735, 49.4921238720417, 51.94911763072014, 54.58798483014107, 58.253952115774155, 60.45310690999031, 65.33539652824402, 64.98862713575363, 65.88203519582748, 63.995117247104645, 65.2444826066494, 64.88187566399574, 66.87521070241928, 65.18410384654999, 69.51593980193138, 64.94814410805702, 67.82268986105919, 69.22013327479362, 69.49010878801346, 63.551308661699295, 69.26501646637917, 65.45136630535126, 69.92191761732101, 56.73567898571491, 55.751155614852905, 71.49592235684395, 57.36964836716652, 62.84363083541393, 65.03217279911041, 59.842050299048424, 62.553645595908165, 62.92867787182331, 56.10215038061142, 51.34375311434269, 56.22475080192089, 56.911541149020195, 60.778418853878975, 65.60857146978378, 67.62394532561302, 64.47447672486305, 65.1074467599392, 59.08001258969307, 57.74161800742149, 54.61840599775314, 63.18974286317825, 68.3643887937069, 66.51201859116554, 62.45894327759743, 58.720570877194405, 49.11894589662552, 47.61349327862263, 50.7352689653635, 53.36720913648605, 52.34973393380642, 49.60195317864418, 51.41423933207989, 52.543443739414215, 52.159394547343254, 53.286611661314964, 51.40371389687061, 62.84822478890419, 64.9534410238266, 73.27371016144753, 74.9744001030922, 72.10460409522057, 70.39072126150131, 73.29130321741104, 68.90733405947685, 71.02980896830559, 68.84811043739319, 67.63336881995201, 69.02118355035782, 69.52489972114563, 66.40304803848267, 68.26515331864357, 68.37557539343834, 67.36449524760246, 68.37822005152702, 63.908671885728836, 28.055528551340103, 2.2849406534805894, 1.1171679594554007, 1.4783421414904296, 1.4943890366703272, 1.3414515182375908, 0.18888278806116432, 0.13280812825541943, 29.778321906924248, 87.17538580298424, 42.32413910329342, 68.17537173628807, 105.41015893220901, 110.63579812645912, 48.01331162452698, 25.243390649557114, 58.12359631061554, 57.2549819201231, 73.18243145942688, 20.14145951718092, 0.8567980933003128, 0.020806356878892984, 0.03755806785193272, 0.11060716642532498, 0.07093857901054434, 0.03080489692365518, 0.061390845439746045, 0.04001540786703117, 0.0150408991612494, 0.08047922136029229, 0.051701706761377864, 0.034034191121463664, 0.02656401276908582, 0.0881183403544128, 0.12003754789475352, 0.14807636209297925, 0.2245156728895381, 0.18274369795108214, 0.10286796139553189, 0.11624228631262667, 0.11714883454260416, 0.18816761003108695, 0.17610442999284714, 0.3273300809087232, 0.32246749964542687, 0.4788525018375367, 58.10536488890648, 108.36253970861435, 82.83420994877815, 79.00287553668022, 50.34626483917236, 35.713413432240486, 52.861840054392815, 53.05844530463219, 60.336084589362144, 41.33954733610153, 0.4966134612914175, 3.457593354396522, 8.768118806183338, 4.546611355617642, 6.080183889716864, 1.1783787561580539, 77.54981070756912, 107.87416711449623, 87.0266541838646, 93.78652185201645, 88.46973314881325, 93.65210026502609, 87.80073344707489, 94.25797015428543, 91.51467695832253, 92.39448934793472, 83.9058892428875, 78.57441812753677, 76.35925099253654, 81.91931784152985, 77.19500854611397, 78.91085207462311, 81.36989012360573, 81.71299651265144, 84.1293628513813, 78.33059281110764, 78.21898519992828, 83.08691918849945, 77.6933366060257, 64.154571890831, 59.87143412232399, 62.651197761297226, 60.012816935777664, 57.90195420384407, 57.93254256248474, 59.96863290667534, 55.513683557510376, 57.42587015032768, 53.54635812342167, 54.12042751908302, 52.24875055253506, 54.96151998639107, 53.26585717499256, 54.63129870593548, 56.602131351828575, 63.68048273026943, 64.51600089669228, 69.6968100965023, 67.85881832242012, 69.5403116941452, 68.03814589977264, 70.0567875802517, 67.36052066087723, 68.90567734837532, 69.35020789504051, 73.51416125893593, 67.60210409760475, 70.78260943293571, 69.641492664814, 73.57736706733704, 66.15812078118324, 72.4946303665638, 67.9251779615879, 73.63262370228767, 58.346435353159904, 58.75826485455036, 72.80551448464394, 61.274356842041016, 65.40285050868988, 69.93949547410011, 61.33433282375336, 65.01452654600143, 67.75885328650475, 58.72598558664322, 54.03322219848633, 59.60864022374153, 60.66874913871288, 63.77523824572563, 68.0651168525219, 69.44823503494263, 66.61278918385506, 68.12849745154381, 61.867535412311554, 59.89686235785484, 56.697650626301765, 65.73667019605637, 69.5607241988182, 69.24639746546745, 66.72703385353088, 60.14383390545845, 52.340253442525864, 49.88952934741974, 55.02430781722069, 54.41992364823818, 54.45832058787346, 53.91065217554569, 54.919729828834534, 55.02838499844074, 54.54487234354019, 56.984311044216156, 55.015659481287, 65.39878472685814, 70.62723577022552, 74.44584086537361, 77.12872490286827, 74.83478799462318, 72.58849292993546, 75.89680820703506, 71.97623938322067, 74.77347448468208, 72.56061002612114, 70.23245975375175, 70.68816930055618, 72.25609436631203, 68.50514084100723, 67.66302242875099, 72.05263048410416, 68.76576885581017, 70.31365379691124, 67.31547027826309, 30.564440824091434, 3.6681001586839557, 7.723056133836508, 11.65503479540348, 6.923258425667882, 1.5022364468313754, 0.2598336199298501, 0.4762197774834931, 40.87683476507664, 93.47411781549454, 48.919141218066216, 83.59587907791138, 114.05788689851761, 143.32400768995285, 58.7910570949316, 23.567733764648438, 74.48779061436653, 65.14397040009499, 89.26671758294106, 24.254261925816536, 1.2054561031982303, 0.11466229843790643, 0.13805420690914616, 0.21156755596166477, 0.14658906846307218, 0.09551263225148432, 0.22842547012260184, 0.0941461899492424, 0.13514283578842878, 0.23021538188913837, 0.15257116465363652, 0.11231509313802235, 0.12794826325261965], [0.04785211254784372, 0.01725107060337905, 0.03518471297866199, 0.043017881325795315, 0.05948764483036939, 0.013596699263871415, 0.04186936697806232, 0.08198773299227469, 0.0038964195573498728, 0.10788778148707934, 0.07155730010708794, 0.09397335859830491, 1.0570897394791245, 62.20850631594658, 75.45734658837318, 64.002116471529, 46.08945965766907, 27.386179268360138, 30.813842341303825, 73.60484719276428, 32.547761499881744, 51.8070774525404, 11.80163187906146, 0.7700412080157548, 1.1224741372279823, 2.2425199672579765, 0.7738662965130061, 2.1146922139450908, 31.078199855983257, 92.827088534832, 86.97322145104408, 90.90389013290405, 83.19563135504723, 85.32098650932312, 78.78945618867874, 80.30373573303223, 78.07688042521477, 80.27928784489632, 82.63012290000916, 85.77997148036957, 81.26028120517731, 78.08108299970627, 80.8622981607914, 83.44502717256546, 80.76555535197258, 73.38676929473877, 71.61040261387825, 73.17188322544098, 78.47761452198029, 73.79074841737747, 67.99597576260567, 65.37249773740768, 55.458647310733795, 53.27469930052757, 53.9097136259079, 53.37552689015865, 50.60748182237148, 50.76352424919605, 50.39566218852997, 50.94178028404713, 52.28648252785206, 52.667928859591484, 50.34461572766304, 45.7884968072176, 44.632412642240524, 46.665470749139786, 50.53244724869728, 53.67069125175476, 56.308954283595085, 56.12774200737476, 58.43525558710098, 56.69701226055622, 53.56045536696911, 53.69663625955582, 52.93228067457676, 50.72668142616749, 56.521575674414635, 56.89118184149265, 62.70879507064819, 68.42181131243706, 70.79159215092659, 57.442156076431274, 68.2273605465889, 59.014021530747414, 66.78336203098297, 52.10105247795582, 77.51148596405983, 24.140222445130348, 22.78840698301792, 79.68177750706673, 51.471870839595795, 72.45531007647514, 53.481396809220314, 57.68798388540745, 60.03270506858826, 62.64745496213436, 48.817781656980515, 50.73680408298969, 50.20479843020439, 59.600299671292305, 58.172058910131454, 62.76921562850475, 56.114366725087166, 60.544754192233086, 63.50314624607563, 63.48169259727001, 59.75769482553005, 63.274569511413574, 55.67001096904278, 63.888981342315674, 67.56124868988991, 63.54732267558575, 60.876844972372055, 54.99753065407276, 46.57794624567032, 45.79434089362621, 47.905389815568924, 49.0118258446455, 47.20678970217705, 44.80511337518692, 51.431019231677055, 50.33750630915165, 50.644298046827316, 50.61430625617504, 58.93885776400566, 70.43796792626381, 66.22420683503151, 70.55367171764374, 67.74129062891006, 65.78491240739822, 65.55444717407227, 68.21889460086823, 66.9152681529522, 69.79672953486443, 67.55760088562965, 71.89175471663475, 66.70991957187653, 69.85023066401482, 66.80726274847984, 70.68962842226028, 65.65182834863663, 66.98230415582657, 64.04664248228073, 58.219077587127686, 18.588007874786854, 0.6796557549387217, 1.9141153455711901, 2.0900932839140296, 1.6369939595460892, 0.28423086390830576, 0.16989997151540592, 3.584388750605285, 70.0461633503437, 53.38245391845703, 42.146810218691826, 74.22742858529091, 91.21766969561577, 55.00984199345112, 17.290962673723698, 36.52107909321785, 54.46448765695095, 57.640680223703384, 34.418678507208824, 3.2677135057747364, 0.17805755487643182, 0.2959996636491269, 0.05527015688130632, 0.05794314274680801, 0.1013428256555926, 0.05083380587166175, 0.08174582995707169, 0.01142966422776226, 0.0320880795334233, 0.03470861782261636, 0.15997800626792014, 0.016350103323929943, 0.06629769210121594, 0.073655039886944, 0.11619181284913793, 0.041133241829811595, 0.03763567052374128, 0.036930637652403675, 0.13423521886579692, 0.06419912111596204, 0.0887021582457237, 0.016282625401800033, 0.07756114864605479, 0.11780353495851159, 1.3217358011752367, 74.9154956638813, 83.67808386683464, 75.70032835006714, 55.73330417275429, 49.77189525961876, 36.30587384104729, 54.2723585665226, 40.66975727677345, 64.55326929688454, 11.972270272672176, 1.237141415476799, 2.648926922120154, 3.6399543564766645, 0.6070662313140929, 1.0978658264502883, 34.93068963289261, 102.06574559211731, 89.25951316952705, 94.8720172047615, 85.81205695867538, 86.82678490877151, 80.74398770928383, 84.92937952280045, 81.44071832299232, 84.57653045654297, 85.7245172560215, 86.79330870509148, 82.2551666200161, 77.72141709923744, 80.80818146467209, 84.83170196413994, 83.13149079680443, 77.1620187163353, 73.40041816234589, 74.64130237698555, 78.67097094655037, 74.7420121729374, 73.8326221704483, 67.44397938251495, 59.37286667525768, 55.1240448653698, 55.4790598154068, 57.26462200284004, 52.16953620314598, 54.13744680583477, 53.865077421069145, 54.394354820251465, 54.70878414809704, 53.25220450758934, 52.297566533088684, 46.340109407901764, 48.34456264972687, 50.256046280264854, 52.24293686449528, 57.12079592049122, 59.155385345220566, 59.31893616914749, 60.46987920999527, 59.05287064611912, 55.23790195584297, 52.75333307683468, 53.45717690885067, 53.175847604870796, 58.79322297871113, 60.30085667967796, 63.11451070010662, 69.90316182374954, 72.21080839633942, 62.58633144199848, 69.50949534773827, 63.59683781862259, 69.49569448828697, 60.72522550821304, 75.13197764754295, 52.0111683011055, 46.12093336880207, 78.03914085030556, 58.93012963235378, 71.31761312484741, 59.32934381067753, 57.01844081282616, 62.354486882686615, 65.18233314156532, 54.26711484789848, 51.308308616280556, 53.72408218681812, 60.739983916282654, 61.6643451154232, 64.95184510946274, 60.16164354979992, 61.199272871017456, 67.25061535835266, 65.14753460884094, 63.371897488832474, 64.4255581498146, 58.26691322028637, 63.69795799255371, 68.76917347311974, 65.40124699473381, 65.76856568455696, 58.59246075153351, 51.560014709830284, 47.13279627263546, 50.459475964307785, 52.18393363058567, 51.26336842775345, 45.98981760442257, 52.995870262384415, 52.28253073990345, 52.602192386984825, 52.61276341974735, 63.20157542824745, 69.91146057844162, 68.49092200398445, 72.48884707689285, 69.10335794091225, 69.16153281927109, 68.19608062505722, 70.50010979175568, 70.43685838580132, 70.38472518324852, 71.58090099692345, 73.0660817027092, 71.59615337848663, 71.42404541373253, 72.20871850848198, 69.35935780405998, 68.76893028616905, 70.97797214984894, 65.51233023405075, 61.980856731534004, 27.697369270026684, 1.8556692567653954, 0.4371244471985847, 1.671245084144175, 1.5730471909046173, 1.249171569943428, 0.1277447960455902, 3.3396709570661187, 73.04016709327698, 61.53719253838062, 46.73480562865734, 73.09494495391846, 95.86137771606445, 58.170311003923416, 20.12147068977356, 44.855187088251114, 62.03420966863632, 68.10762897133827, 47.5725656747818, 4.579080613330007, 0.20019524119561538, 0.12051778423483483, 0.08840560345561244, 0.09149149060249329, 0.0710987122147344, 0.03179009239829611, 0.02000448301259894, 0.03156418264552485, 0.05212183285038918, 0.002954326396320539, 0.05185140536923427, 0.06632322940276936, 0.15772183280205354, 0.1955763070145622, 0.1944911535247229, 0.1349300323636271, 0.17033408337738365, 0.2105791339999996, 0.23001034132903442, 0.18039126793155447, 0.11680781026370823, 0.2088292091502808, 0.22613999666646123, 0.23499589646235108, 1.930740640964359, 91.33310750126839, 95.82559883594513, 84.95654806494713, 67.28473752737045, 45.43593652546406, 47.10880436003208, 99.24618288874626, 47.23546676337719, 79.14309561252594, 16.420543380081654, 1.4751222892664373, 3.023390178568661, 8.011026531457901, 4.89146470092237, 5.161481536924839, 34.904455840587616, 103.83765891194344, 91.67010381817818, 100.31810536980629, 91.40082746744156, 90.70025146007538, 84.69105631113052, 90.15242725610733, 84.37110587954521, 88.36243450641632, 88.21197018027306, 92.53806084394455, 86.93536788225174, 82.52572730183601, 79.27834555506706, 83.83872404694557, 85.33423259854317, 80.0156731903553, 78.2232865691185, 79.73907843232155, 81.55807122588158, 80.17640456557274, 76.66506618261337, 71.68022766709328, 62.746561244130135, 58.17523933947086, 58.256148397922516, 58.77265468239784, 55.71860656142235, 55.8862079679966, 58.65917757153511, 58.0496446788311, 60.60766741633415, 57.083842903375626, 54.299470111727715, 51.22586823999882, 48.87302689254284, 52.43948131799698, 57.529650181531906, 60.45844182372093, 62.80120611190796, 60.61550259590149, 63.72608408331871, 64.83592092990875, 58.952366039156914, 57.94507049024105, 56.851789355278015, 57.01727047562599, 61.67987868189812, 65.14585509896278, 67.14873522520065, 74.71978336572647, 76.45016491413116, 63.4638487547636, 72.69093543291092, 66.8979562819004, 71.7610265314579, 63.05485010147095, 77.3853251338005, 40.30819907784462, 35.307181030511856, 81.95437476038933, 62.44415447115898, 74.60228607058525, 60.01222416758537, 58.82231041789055, 67.06580087542534, 67.4061182141304, 55.04463292658329, 53.76687549054623, 55.54042272269726, 63.286147490143776, 62.501208409667015, 65.83784356713295, 60.243840739130974, 63.3026310056448, 70.75648203492165, 68.17043960094452, 67.40592062473297, 66.68312340974808, 61.42815358936787, 67.36285373568535, 70.5018500983715, 67.08129644393921, 68.46630692481995, 61.56973399221897, 53.67539919912815, 50.461645647883415, 51.00333698093891, 54.436236172914505, 53.23906861245632, 49.913844242691994, 58.39621648192406, 53.98901917040348, 56.36269100010395, 55.617623180150986, 66.97680205106735, 73.38704288005829, 71.96491599082947, 74.96305391192436, 72.38562181591988, 71.25823751091957, 69.74513590335846, 73.42558801174164, 71.70018419623375, 75.53480923175812, 74.80004265904427, 78.3805601298809, 74.30518001317978, 74.5052620768547, 76.39724895358086, 75.44017910957336, 72.16681435704231, 74.36992093920708, 69.02654886245728, 64.95665565133095, 26.995337940752506, 2.380171618424356, 6.436843201518059, 8.950082492083311, 6.151209203526378, 0.9300128021277487, 0.2859007258666679, 5.449494207277894, 87.74575039744377, 66.80037751793861, 57.01429143548012, 75.29595404863358, 99.85972076654434, 63.9461986720562, 27.67999280244112, 54.106930643320084, 74.09078031778336, 79.70463708043098, 59.31202434003353, 5.192140191793442, 0.3687771287513897, 0.45928824227303267, 0.26004815998021513, 0.1227265121997334, 0.18247434287331998, 0.11667167069390416, 0.21758874849183485, 0.13864770240616053, 0.27749008499085903, 0.08830194768961519, 0.24870217661373317, 0.2451462799217552], [0.09181154920952395, 0.017273936173296534, 0.06916780723258853, 0.06429058339563198, 0.06731650501023978, 0.07328317195060663, 0.11072593973949552, 0.10157586002605967, 0.036851283512078226, 0.056674816078157164, 0.1268937753047794, 0.2520103444112465, 10.943256989121437, 74.31122928857803, 66.83477327227592, 61.84871882200241, 36.003098487854004, 15.717307515442371, 39.6442911028862, 36.246908605098724, 36.52516387403011, 72.6343260705471, 1.1171704530715942, 0.23235713102621958, 1.6002682177349925, 0.4021977010415867, 2.3438588669523597, 4.770751353353262, 84.14658352732658, 90.86575537919998, 84.27509263157845, 76.65030777454376, 72.44363710284233, 73.43606784939766, 73.19098860025406, 75.2562765777111, 76.6089203953743, 74.62015271186829, 81.269111931324, 83.6499273777008, 89.06331449747086, 83.11138227581978, 77.15788453817368, 75.99840715527534, 73.53442937135696, 70.03219529986382, 75.79697996377945, 74.21240419149399, 71.08139500021935, 65.52278727293015, 63.365270644426346, 59.29098106920719, 52.89086289703846, 52.85914219915867, 51.95780396461487, 49.88520137965679, 50.44133573770523, 52.650958970189095, 50.22202670574188, 51.26842975616455, 51.10916510224342, 49.48535643517971, 48.405408784747124, 43.946861028671265, 44.13427837193012, 45.13308137655258, 49.98554639518261, 53.02197106182575, 53.574902191758156, 52.20446012914181, 52.101975828409195, 46.882062926888466, 51.49820722639561, 51.87700890004635, 55.27244210243225, 46.48479424417019, 52.42458611726761, 50.54726265370846, 65.42362779378891, 58.45455475151539, 70.8176739513874, 58.688078820705414, 70.3877954185009, 60.70125639438629, 69.11407336592674, 50.53052455186844, 81.10605508089066, 12.718179747462273, 7.984163872897625, 80.48268333077431, 49.96777854859829, 75.24751424789429, 46.96459449827671, 64.58337888121605, 62.59434141218662, 60.351846143603325, 46.587814316153526, 53.53999726474285, 56.4936775714159, 64.63187947869301, 60.279779210686684, 59.72642630338669, 60.347172394394875, 65.39917230606079, 58.565599992871284, 58.253454342484474, 57.733019068837166, 61.316751167178154, 57.59274199604988, 60.53806275129318, 55.045134499669075, 64.00370478630066, 61.28596901893616, 60.445891097187996, 49.93563987314701, 44.80059541761875, 44.84713152050972, 49.97443199157715, 48.17756921052933, 44.650302082300186, 47.99016706645489, 51.489072516560555, 46.33640840649605, 51.45657666027546, 55.85731811821461, 71.03808492422104, 62.55645364522934, 65.7224589586258, 65.25850385427475, 65.48069313168526, 63.99514764547348, 66.43194928765297, 66.37944370508194, 65.75107142329216, 68.64369660615921, 67.28688061237335, 65.4704412817955, 66.13455444574356, 63.65811713039875, 67.44413137435913, 66.64096847176552, 69.78380262851715, 62.910146266222, 67.19078376889229, 61.189856976270676, 21.832180693745613, 1.8078222242183983, 0.9409135859459639, 3.7928118417039514, 0.9480959724169225, 0.15050636138767004, 0.03841879959509242, 28.13803542405367, 73.42356652021408, 40.77643655240536, 50.415151342749596, 54.55430343747139, 27.939876057207584, 29.5737636834383, 22.303057126700878, 46.82974733412266, 53.05829331278801, 50.548778772354126, 12.137858737260103, 0.43841777311172336, 0.085390888270922, 0.19450800027698278, 0.051079286058666185, 0.18253653484862298, 0.08206373633584008, 0.028306143212830648, 0.02289776242832886, 0.03494793447316624, 0.07622408797033131, 0.12469691428123042, 0.05139876207977068, 0.018689783246372826, 0.004680823731177952, 0.13883073086617514, 0.04307418435928412, 0.04322023902204819, 0.07244058200740255, 0.02674275718163699, 0.10738100594608113, 0.06487844599178061, 0.11358107833075337, 0.14083611778914928, 0.7262604322750121, 15.325595084577799, 89.49495613574982, 72.5452284514904, 70.71832448244095, 47.69309900701046, 28.66634577512741, 34.56267938017845, 38.62764045596123, 47.48839259147644, 78.45855474472046, 0.8756894920952618, 0.5385988333728164, 2.662546578794718, 0.6809440045617521, 1.4662177045829594, 5.202578706666827, 93.9158821105957, 93.99216681718826, 92.36552730202675, 77.64118820428848, 77.80857682228088, 77.29816541075706, 79.61788013577461, 74.06820952892303, 81.53355494141579, 77.23554477095604, 84.88224685192108, 84.98258426785469, 89.2092190682888, 86.44518658518791, 80.70227354764938, 78.60545486211777, 78.83805558085442, 72.2481831908226, 77.85304203629494, 75.98827689886093, 74.09486889839172, 68.33959892392159, 68.58533173799515, 59.902026280760765, 55.50297573208809, 56.889338940382004, 54.38218407332897, 52.255738377571106, 53.33531744778156, 55.41474066674709, 53.4271889179945, 52.50538878142834, 52.81279608607292, 50.752421244978905, 51.72903724014759, 47.39193096756935, 45.91583177447319, 49.53444220125675, 52.676307410001755, 55.76258920133114, 55.27741603553295, 55.33695884048939, 55.85762970149517, 52.074579298496246, 53.77244979143143, 54.97137665748596, 57.77876101434231, 49.7390004247427, 54.241211637854576, 53.15603546798229, 65.8222796022892, 61.0028538107872, 72.80041515827179, 61.27840742468834, 72.62310907244682, 63.187728971242905, 71.61656588315964, 54.513987600803375, 84.33211997151375, 27.067290879786015, 19.233500137925148, 81.86202451586723, 55.320851504802704, 75.2268585562706, 50.97945146262646, 66.6453230381012, 64.39033403992653, 65.30840277671814, 48.99455577135086, 54.38778877258301, 60.226897448301315, 66.08503550291061, 60.99242717027664, 60.885994881391525, 61.497328877449036, 67.54806339740753, 62.342506125569344, 59.995478466153145, 61.630903109908104, 62.58526749908924, 60.154119953513145, 64.67401921749115, 61.23600170016289, 64.48809519410133, 63.35158757865429, 64.37888905405998, 54.29226949810982, 46.653995364904404, 46.4205776900053, 52.49455936253071, 51.817048117518425, 45.822246596217155, 51.25211723148823, 52.52586588263512, 49.86197702586651, 52.05710783600807, 59.092202335596085, 73.14728334546089, 65.42057275772095, 69.3793523311615, 69.92689535021782, 67.44217067956924, 67.75737136602402, 69.13645416498184, 68.94068107008934, 68.31344872713089, 71.31578162312508, 70.31229346990585, 67.76126235723495, 65.47774448990822, 65.65573453903198, 70.45046925544739, 68.81415545940399, 70.8561734855175, 68.32633003592491, 66.98502480983734, 68.25966641306877, 29.153865315020084, 2.8113727178424597, 0.6059948075562716, 1.6737231449224055, 1.0242357524111867, 0.48631550918798894, 0.1405420937226154, 29.98580027371645, 77.62219682335854, 53.429354801774025, 49.911324977874756, 64.9608962237835, 36.550736501812935, 34.74433623254299, 35.139294639229774, 52.9240807145834, 62.92092248797417, 63.65590184926987, 17.027000337839127, 0.5840483726933599, 0.1371752072009258, 0.17992182984016836, 0.04297993531508837, 0.09431879865587689, 0.0627478513342794, 0.045162617607275024, 0.006114014331615181, 0.00623441434072447, 0.06467852625064552, 0.05780595674877986, 0.0316720649425406, 0.17547207564348355, 0.11667573766317219, 0.2034633923904039, 0.11964832112425938, 0.15388239116873592, 0.2159731078427285, 0.1608949148794636, 0.2366204428835772, 0.13285464607179165, 0.35915616375859827, 0.258391834795475, 1.037106967996806, 17.809984423220158, 105.32944366335869, 85.90052381157875, 80.25892853736877, 51.47364154458046, 24.233927316963673, 53.67743209004402, 55.93238689005375, 56.60705588757992, 90.98455220460892, 1.828814554028213, 0.5013997794594616, 4.257739456370473, 5.349516347050667, 7.1764288656413555, 5.606117052957416, 96.30430474877357, 97.75532528758049, 94.27459046244621, 83.99294257164001, 80.7042646408081, 81.15577921271324, 82.31586456298828, 79.63497161865234, 84.78914424777031, 81.4934366941452, 88.35245624184608, 88.16268682479858, 93.2268650829792, 87.7629254758358, 83.96657198667526, 85.62554016709328, 84.06970605254173, 74.77605074644089, 80.42304933071136, 80.78039735555649, 79.57202419638634, 71.15660816431046, 70.84212183952332, 64.96266692876816, 56.81766718626022, 57.64075241982937, 55.43682888150215, 55.333706215023994, 57.17229835689068, 58.21525119245052, 56.58985421061516, 56.410853415727615, 56.38725288212299, 55.53573377430439, 55.39626605808735, 50.539275482296944, 47.98295125365257, 51.77479438483715, 56.46862931549549, 57.8930588811636, 58.12491104006767, 59.49321761727333, 60.00603049993515, 55.08454978466034, 56.6017209738493, 58.27915236353874, 61.31205841898918, 50.509675070643425, 56.49955205619335, 54.64249670505524, 72.5931666791439, 64.44242924451828, 77.60946750640869, 60.578796565532684, 74.98899132013321, 65.600865483284, 78.13128590583801, 55.76406732201576, 91.40492364764214, 16.48161370307207, 10.905123185366392, 90.19508376717567, 55.667161121964455, 80.50665244460106, 51.33614972233772, 71.523068100214, 66.43853053450584, 70.19583731889725, 51.032899394631386, 58.38121488690376, 62.06651173532009, 70.58680593967438, 61.48017659783363, 62.51959562301636, 63.59305702149868, 71.13557249307632, 64.76400598883629, 65.3748232126236, 63.1132909655571, 67.10816860198975, 61.39672927558422, 69.3132434785366, 63.29820804297924, 68.12684834003448, 63.93257260322571, 66.2985460460186, 55.7480625808239, 49.99449871480465, 48.345014825463295, 57.92355604469776, 55.35713575780392, 49.45515185594559, 55.25990277528763, 56.25911995768547, 52.657338827848434, 57.13408760726452, 62.83882409334183, 78.64799737930298, 68.62703830003738, 72.07868188619614, 70.87806791067123, 71.84779867529869, 70.1416826248169, 74.0621830523014, 72.11934730410576, 71.79492071270943, 76.62806376814842, 77.06922009587288, 72.37618312239647, 69.92148444056511, 68.4665197134018, 73.45080345869064, 72.38844886422157, 75.20622566342354, 71.93446442484856, 69.81382861733437, 69.35484364628792, 29.341807030141354, 3.4018140099942684, 4.679771410301328, 12.156847268342972, 2.06381484400481, 0.5760580545756966, 0.23922155174659565, 38.8542602956295, 85.81440523266792, 58.60246181488037, 60.58468624949455, 68.42826336622238, 39.00225095450878, 41.50964520871639, 36.751137748360634, 65.15046045184135, 71.75715073943138, 77.83512979745865, 20.92453859746456, 0.6305012363009155, 0.2372162093524821, 0.39138677646405995, 0.19686376996105537, 0.28490883065387607, 0.21669676119927317, 0.16093396669020876, 0.09634152957005426, 0.09982836942072026, 0.1614425308071077, 0.20599616429535672, 0.12543024524347857], [0.030513503770634998, 0.07800050749210641, 0.04982842212484684, 0.05891117049031891, 0.02399840268481057, 0.040521997871110216, 0.06631491734879091, 0.06150234199594706, 0.04766982252476737, 0.10981194776832126, 0.14685842354083434, 0.07451781624695286, 43.670543655753136, 75.00705555081367, 63.61880823969841, 58.70309181511402, 33.76190274953842, 34.20269429683685, 70.6605675816536, 37.08541341125965, 60.743878707289696, 52.05873794853687, 0.2528259053360671, 0.805071706417948, 1.1450418387539685, 0.5273945408407599, 1.5714314463548362, 35.40129818022251, 97.97414034605026, 76.60516619682312, 79.68335822224617, 74.60418596863747, 76.74328878521919, 67.59328097105026, 71.49265453219414, 69.89436149597168, 72.54311576485634, 74.79258745908737, 77.29727625846863, 76.40325263142586, 75.58815836906433, 71.99591472744942, 72.54674836993217, 76.33221924304962, 79.20383155345917, 73.8050052523613, 73.09274107217789, 69.18275088071823, 67.86415323615074, 62.06033706665039, 56.99036791920662, 52.41198219358921, 52.48459629714489, 53.629379868507385, 53.80992338061333, 47.581821978092194, 50.41116535663605, 50.07444642484188, 52.734763473272324, 49.65721361339092, 50.95609411597252, 48.35425212979317, 48.887378722429276, 46.697807013988495, 44.37912203371525, 43.770751878619194, 49.82668451964855, 51.13632224500179, 51.329393684864044, 48.232130482792854, 52.72338308393955, 52.672500014305115, 63.01976278424263, 62.54434749484062, 62.379474341869354, 51.67663425207138, 52.04483449459076, 50.23783005774021, 57.78485968708992, 58.36652487516403, 64.14541438221931, 57.242997363209724, 66.65011838078499, 61.858909875154495, 65.8695338666439, 53.46396714448929, 65.5431617796421, 11.169009525328875, 6.285206638276577, 66.88838079571724, 55.00376231968403, 60.64572997391224, 50.27372673153877, 70.13167396187782, 54.75093528628349, 52.51529484987259, 43.87072831392288, 55.67218065261841, 58.117778822779655, 63.68439272046089, 60.30944421887398, 62.928107902407646, 60.481434389948845, 58.12961518764496, 55.09958937764168, 55.64921088516712, 52.11554490029812, 56.85961693525314, 59.779057279229164, 63.379143700003624, 61.12246759235859, 58.0059964209795, 53.66870395839214, 60.8137721568346, 57.12842211127281, 51.66330076754093, 46.45267456769943, 49.12619210779667, 46.17568463087082, 42.30685383081436, 44.437422305345535, 49.726571291685104, 48.245790749788284, 48.1368125975132, 52.55281023681164, 66.93154647946358, 64.9977694451809, 65.08785501122475, 65.3144596517086, 63.39587800204754, 59.76112984120846, 63.09760920703411, 60.79451099038124, 61.905172392725945, 58.958540707826614, 61.217014119029045, 57.39979974925518, 59.15311686694622, 62.074172124266624, 67.40601181983948, 67.23904117941856, 69.21751901507378, 70.23248255252838, 69.77933406829834, 62.492522075772285, 58.02146539092064, 24.322264976799488, 1.332131924573332, 0.12974090612260625, 3.338804366067052, 0.2824690053239465, 0.31918587104883045, 5.628657443448901, 61.48039698600769, 67.41060957312584, 41.406066566705704, 18.5828173533082, 28.984941579401493, 14.818198811262846, 15.767585467547178, 42.19779968261719, 48.488821908831596, 57.935529202222824, 38.67670342326164, 1.7051671701483428, 0.13169371930416673, 0.14236465998692438, 0.006030091808497673, 0.09784915804630145, 0.08490196880302392, 0.13302108010975644, 0.040491458494216204, 0.1337373862043023, 0.04466348989808466, 0.09192760626319796, 0.07673718660953455, 0.028488041753007565, 0.09230340758222155, 0.07074248875142075, 0.060389792124624364, 0.0056060462520690635, 0.0581077399692731, 0.04716672803624533, 0.0924653813126497, 0.020585061429301277, 0.04596222235704772, 0.0775022963352967, 0.16018082038499415, 52.9307721555233, 84.23703387379646, 71.65891081094742, 69.12857338786125, 45.803236216306686, 35.840068235993385, 47.471426501870155, 42.575457617640495, 72.06434905529022, 53.932804986834526, 0.2299353844136931, 0.6276792346034199, 3.4174618078395724, 1.406160502228886, 0.8661538443993777, 40.193509832024574, 104.70621630549431, 77.76038020849228, 83.45969438552856, 79.41116362810135, 80.068748742342, 71.4300262928009, 73.8960711658001, 72.58874371647835, 76.45796209573746, 78.43313410878181, 79.12031963467598, 79.5438677072525, 81.03836551308632, 76.37853875756264, 73.94088596105576, 79.71486613154411, 82.69028127193451, 75.96136674284935, 75.97953736782074, 71.94142565131187, 70.5987448990345, 63.99600639939308, 60.193041265010834, 55.237141996622086, 55.889320001006126, 56.031907349824905, 55.97467102110386, 50.574195608496666, 52.09953635931015, 52.60275095701218, 55.83385817706585, 52.11109533905983, 52.37565614283085, 51.78323373198509, 50.62306858599186, 48.75506602227688, 47.916264832019806, 46.6196072101593, 50.916481241583824, 53.772730976343155, 53.07896040380001, 50.23642413318157, 54.44056034088135, 55.76143026351929, 64.12266120314598, 65.00953361392021, 66.13543599843979, 55.91957777738571, 54.66583885252476, 54.30295832455158, 60.580529272556305, 61.09542444348335, 66.89565360546112, 58.483262211084366, 68.71108219027519, 62.67189905047417, 68.29131871461868, 55.8760929107666, 70.57659208774567, 17.654787451028824, 10.935965180397034, 69.58998262882233, 57.973671555519104, 64.3534304201603, 54.70614708960056, 71.22004196047783, 58.2332394272089, 53.70901979506016, 47.309672981500626, 58.52168194949627, 60.20409107208252, 65.49278408288956, 62.18406222760677, 63.58966380357742, 64.93520960211754, 60.03786899149418, 57.16523453593254, 56.7053984105587, 53.66513215005398, 58.142029121518135, 60.88210009038448, 66.78048178553581, 63.897462487220764, 60.54043382406235, 58.29574607312679, 61.27057984471321, 58.97458344697952, 56.525918841362, 49.445614367723465, 51.86314344406128, 47.78810530900955, 44.90790545940399, 46.86747170984745, 50.79715624451637, 51.02387487888336, 52.18596652150154, 55.169441029429436, 69.01372075080872, 65.58027058839798, 66.96693018078804, 67.53218784928322, 64.61478799581528, 61.43483743071556, 65.66277176141739, 63.3587121963501, 64.03541788458824, 61.80211432278156, 64.55584555864334, 59.9018818885088, 62.15553715825081, 65.8282832801342, 69.79519441723824, 69.16730090975761, 73.75896692276001, 72.7459716796875, 74.54473435878754, 65.21917596459389, 64.2507903277874, 33.216369822621346, 2.701190742664039, 0.9269889956340194, 1.7753730341792107, 0.42210435785818845, 0.22527603287016973, 5.170718841254711, 65.79294517636299, 74.32525053620338, 54.51700083911419, 20.5660430341959, 24.24126472324133, 20.939931571483612, 26.31545752286911, 52.09542118012905, 55.791870430111885, 64.85521629452705, 51.361475363373756, 2.2432528529316187, 0.17042173101799563, 0.16835643793456256, 0.13011401344556361, 0.1523180922959, 0.042489353436394595, 0.08425851192441769, 0.05028202649555169, 0.07721133733866736, 0.03779106882575434, 0.03395761261344887, 0.0244581427614321, 0.17157473164843395, 0.26521834661252797, 0.09396701323566958, 0.1442483050050214, 0.15518803673330694, 0.1588303194148466, 0.1453997174394317, 0.29296098451595753, 0.16735393000999466, 0.21657430683262646, 0.20008638297440484, 0.2732539357384667, 63.14382992684841, 98.80154594779015, 81.34532064199448, 79.8918454349041, 44.579204097390175, 47.95784220099449, 95.89192047715187, 56.8292261660099, 82.43317186832428, 63.97164970636368, 0.3213191597023979, 1.4961108192801476, 4.9402080103755, 6.673625595867634, 4.114589737728238, 41.787809282541275, 109.73722234368324, 80.3855149447918, 86.36696398258209, 81.2451808154583, 82.76734113693237, 73.53544011712074, 77.60559931397438, 74.83903616666794, 80.19005343317986, 80.9143553674221, 82.56157457828522, 81.9827288389206, 84.46828946471214, 81.87039166688919, 79.40551713109016, 83.36112007498741, 84.25822913646698, 80.58572620153427, 81.00776955485344, 77.24080368876457, 74.27768468856812, 70.22891074419022, 63.254951164126396, 58.11223492026329, 58.67556609213352, 58.01103115081787, 57.78017833828926, 53.21853071451187, 57.43627019226551, 55.59189476072788, 58.017217218875885, 54.69141907989979, 56.679650992155075, 53.79879377782345, 55.24811580777168, 52.71379239857197, 49.79620635509491, 49.464883133769035, 54.122487008571625, 58.45118433237076, 57.93699212372303, 52.14971266686916, 58.43348868191242, 57.96591617166996, 68.65631192922592, 68.0820183455944, 68.29842433333397, 57.49762549996376, 59.255312383174896, 55.33745661377907, 67.39695310592651, 63.56115773320198, 73.72278526425362, 59.59951691329479, 73.39256778359413, 63.076672330498695, 76.05199187994003, 55.29981203377247, 80.01289173960686, 15.490757022053003, 8.173308223485947, 82.2098958492279, 57.36063525080681, 68.56561839580536, 55.72391867637634, 76.03287890553474, 61.13401137292385, 59.868933856487274, 47.92299047112465, 62.853510305285454, 62.32435829937458, 68.53179261088371, 62.86355696618557, 66.94080278277397, 66.36224582791328, 64.85409155488014, 60.15311300754547, 61.9280281662941, 57.46090807020664, 61.10308863222599, 63.11026252806187, 69.03366208076477, 65.87268769741058, 63.78165990114212, 60.16696326434612, 65.65897196531296, 61.0413533449173, 59.94342125952244, 52.53218114376068, 58.35265941917896, 51.653725281357765, 47.55996935069561, 50.18107250332832, 51.989494264125824, 53.68303678929806, 55.764747485518456, 56.40726260840893, 74.31467190384865, 69.16565179824829, 73.04973497986794, 70.60942992568016, 68.05031284689903, 64.70237329602242, 70.81630602478981, 66.46556988358498, 68.28296676278114, 64.5896865427494, 66.62497133016586, 62.45091810822487, 64.90823864936829, 68.42660665512085, 76.10600978136063, 73.06755602359772, 76.48928001523018, 76.19656652212143, 77.26785823702812, 67.66749858856201, 65.77155232429504, 31.34800247848034, 2.9092483408749104, 3.867036821320653, 8.194189053028822, 1.471422950271517, 0.5459325585979968, 8.40030424296856, 77.78174266219139, 81.2232331931591, 60.513994842767715, 30.991701297461987, 40.68610779941082, 20.898964069783688, 26.196301616728306, 57.77122601866722, 67.72209405899048, 75.42285203933716, 61.86336703598499, 2.6687979558482766, 0.35651613667141646, 0.25591353652998805, 0.18498949619242921, 0.1931570391752757, 0.28209965326823294, 0.21515658212592825, 0.14556379144778475, 0.1476245277444832, 0.1426266529597342, 0.23219789582071826, 0.20185649424092844], [0.08215420413762331, 0.05006884457543492, 0.03786374734772835, 0.10743933875346556, 0.07189744865172543, 0.05978065215458628, 0.012985508183191996, 0.05353047738026362, 0.03159213563776575, 0.03514068135700654, 0.05837208555021789, 1.0011398792266846, 61.98485031723976, 66.22723147273064, 66.31860136985779, 52.04223923385143, 19.73152421414852, 39.09017823636532, 61.5178781747818, 27.16235037893057, 89.85232695937157, 20.33864613622427, 0.13209829368861392, 1.3569140760228038, 0.881113582290709, 1.2372498284094036, 3.471416775137186, 79.75108578801155, 85.59340909123421, 85.45521050691605, 79.19096544384956, 86.64500266313553, 80.53047716617584, 70.3683252632618, 66.6516686975956, 72.49032139778137, 70.10449022054672, 76.31394222378731, 75.83785817027092, 76.7277780175209, 76.91571593284607, 76.83759972453117, 78.50414469838142, 74.61807802319527, 73.2423086464405, 71.2929980456829, 73.15438896417618, 69.43368181586266, 61.34133964776993, 55.04863031208515, 54.10794138908386, 55.88141642510891, 55.76573543250561, 55.93147873878479, 52.36045315861702, 47.200854420661926, 49.4738582521677, 50.22446997463703, 52.685381323099136, 51.004248932003975, 49.31648209691048, 50.87474428117275, 48.55072818696499, 46.00078381597996, 43.088509887456894, 46.73589617013931, 48.047866970300674, 48.80493454635143, 47.95783840119839, 48.40124040842056, 50.339265614748, 56.977733597159386, 62.72192716598511, 62.379877120256424, 65.02347126603127, 58.21432784199715, 57.74211958050728, 52.75931775569916, 58.003883734345436, 55.48040874302387, 60.541915744543076, 59.457127153873444, 63.8153412938118, 61.25474609434605, 60.320315435528755, 61.56046248972416, 50.53123131394386, 11.06936177238822, 8.527949843555689, 56.49072892963886, 46.33180305361748, 57.220548167824745, 59.306685626506805, 62.45893947780132, 53.16908776760101, 49.576798528432846, 49.815779104828835, 59.97540034353733, 62.613233998417854, 63.53440336883068, 60.28909631073475, 60.23055285215378, 54.040320217609406, 54.35775898396969, 50.52368111908436, 47.60285384953022, 47.42201395332813, 48.0369121581316, 49.8895825445652, 56.69218271970749, 58.90660509467125, 62.52022638916969, 57.28549428284168, 53.57793062925339, 54.6723935008049, 56.003849655389786, 48.81618954241276, 48.395616710186005, 47.187338545918465, 44.239532724022865, 42.750309035182, 48.512411043047905, 49.910261034965515, 48.4738203138113, 49.86789710819721, 57.884319350123405, 59.99516308307648, 58.405020609498024, 57.44516931474209, 60.25593928992748, 55.84203153848648, 57.83784404397011, 58.576851189136505, 56.57716669142246, 57.94926926493645, 57.20213055610657, 56.83948181569576, 57.527822479605675, 59.93809014558792, 64.49678152799606, 68.73520329594612, 70.50041377544403, 71.3699971139431, 69.6740873157978, 70.22753521800041, 64.98668164014816, 64.29031580686569, 26.981521882116795, 0.1909759858972393, 1.0361178335733712, 0.8016974874772131, 0.19536311767296866, 0.022665557407890446, 36.13548718392849, 68.78281474113464, 66.27441734075546, 44.97667796909809, 59.21131454408169, 25.816371403634548, 16.925616078078747, 15.177744068205357, 45.39662383496761, 49.06963214278221, 60.1521934568882, 10.521649662405252, 0.3627690573921427, 0.10220612894045189, 0.05003785990993492, 0.06446322920965031, 0.12910219898913056, 0.02351953004108509, 0.059477310423972085, 0.02011438580666436, 0.04071159433806315, 0.02235761065094266, 0.08610174700152129, 0.05995605875796173, 0.029523432385758497, 0.034117482355213724, 0.06078663333028089, 0.061308370568440296, 0.05679649861122016, 0.12276393128558993, 0.055611875068279915, 0.03994345664978027, 0.11230864387471229, 0.13094694062601775, 1.3228965201415122, 78.90923336148262, 74.33994814753532, 76.893699914217, 61.19250163435936, 33.01133282482624, 28.98367054760456, 48.37107002735138, 37.65359312295914, 98.34808588027954, 20.984886959195137, 0.15533490775851533, 2.1121204644441605, 2.0049113547429442, 0.2775867423042655, 2.0596391055732965, 93.97623047232628, 88.8907353579998, 89.40234750509262, 83.04306954145432, 90.90224862098694, 83.45442026853561, 74.78836208581924, 69.91805702447891, 75.1642607152462, 72.81461119651794, 78.25871586799622, 77.99129381775856, 78.37397888302803, 78.62353429198265, 81.29887953400612, 79.81851696968079, 78.54903548955917, 76.20457649230957, 75.09486123919487, 76.44074141979218, 72.61433154344559, 64.11704510450363, 58.25783930718899, 55.94364568591118, 58.888423070311546, 55.15790864825249, 58.681451976299286, 54.39707547426224, 49.91774283349514, 51.985097900033, 52.92944982647896, 56.00357986986637, 53.37285563349724, 51.852025240659714, 52.64681339263916, 49.910029247403145, 49.17262561619282, 46.672287583351135, 48.77531513571739, 50.39242476224899, 53.27627241611481, 51.06506086885929, 52.1932203322649, 53.101846575737, 61.05952017009258, 65.69420367479324, 65.02792462706566, 68.76200705766678, 62.87579990923405, 57.67686568200588, 56.180901154875755, 61.56683474779129, 58.405586779117584, 64.9554169178009, 61.525713354349136, 66.23223200440407, 64.07818078994751, 63.77852886915207, 63.372516855597496, 53.68375115096569, 14.448957424610853, 13.797902259975672, 60.77863544225693, 48.32115210592747, 60.4181943833828, 61.88744634389877, 64.57529291510582, 54.87946338951588, 53.14811669290066, 54.46695752441883, 64.12982001900673, 65.11939331889153, 64.59484666585922, 61.464175656437874, 62.56917156279087, 57.67967373132706, 57.192068696022034, 52.049265056848526, 49.93153989315033, 50.57029701769352, 49.51265037059784, 50.60401640832424, 59.1112507134676, 60.06022699177265, 64.11117061972618, 60.23358888924122, 59.761247634887695, 57.59376414120197, 56.78525112569332, 51.908459812402725, 49.72423441708088, 48.99792239069939, 46.854286417365074, 44.27691891789436, 51.4675048738718, 52.37280249595642, 50.61362989246845, 52.12544336915016, 60.55733911693096, 61.15871764719486, 61.04595869779587, 59.307833164930344, 61.53136745095253, 58.33110697567463, 60.90664677321911, 59.595223143696785, 59.96920667588711, 59.824746027588844, 60.254552364349365, 60.014454647898674, 62.003925293684006, 62.554150968790054, 68.71986731886864, 71.80408582091331, 74.35584649443626, 73.16501319408417, 73.82486298680305, 72.72775545716286, 68.23690563440323, 67.04086661338806, 34.786665961146355, 0.6307291646953672, 0.22474566445453092, 1.005678023211658, 0.3483147220686078, 0.046799828778603114, 38.57972502708435, 74.85279902815819, 74.71574798226357, 51.81261755526066, 33.329432755708694, 21.52583923190832, 26.8305179849267, 24.091640152037144, 53.609134554862976, 57.15736895799637, 69.67574402689934, 15.327532030642033, 0.4682357230922207, 0.15859594917856157, 0.15221407287754118, 0.040468474180670455, 0.05351034662453458, 0.045553677482530475, 0.08352750388439745, 0.06772457491024397, 0.04260159585101064, 0.03970608813688159, 0.050097996136173606, 0.10890275007113814, 0.2267846409813501, 0.1211502350633964, 0.16193393646972254, 0.23070600087521598, 0.14705402398249134, 0.35471488488838077, 0.1879888860275969, 0.16371342848287895, 0.20003890036605299, 0.17711703112581745, 2.1726868394762278, 97.31179028749466, 84.03096333146095, 89.57745730876923, 68.07134091854095, 29.570832140743732, 54.51489195227623, 86.6525186598301, 43.204696252942085, 110.35362526774406, 25.00531442463398, 0.16834362846566364, 3.136849240399897, 7.784104607999325, 3.776860535144806, 4.88247343339026, 95.40621533989906, 95.08583933115005, 91.25887468457222, 86.59410819411278, 92.5977024435997, 87.83775106072426, 76.27017617225647, 74.12361055612564, 77.52422288060188, 75.23476973176003, 80.67874521017075, 81.12440049648285, 79.843230843544, 83.7805187702179, 83.58203262090683, 84.85665902495384, 80.0175578892231, 81.14931955933571, 78.37235257029533, 81.63090571761131, 76.08286142349243, 70.06655305624008, 60.66013500094414, 59.38715770840645, 61.95501431822777, 60.30370272696018, 61.22837170958519, 57.969864159822464, 52.952180206775665, 56.48856304585934, 57.88581266999245, 59.13666754961014, 54.97373253107071, 54.03606444597244, 56.34174272418022, 55.05673907697201, 53.82252350449562, 48.85727673768997, 51.7091529071331, 54.34189863502979, 55.23592606186867, 53.880743980407715, 53.4962198138237, 56.58464469015598, 63.40998664498329, 67.36784666776657, 68.00112828612328, 72.34548836946487, 63.35848420858383, 62.885557785630226, 57.337616086006165, 64.65797647833824, 60.46708256006241, 69.46130633354187, 61.74861699342728, 70.90180903673172, 66.77038192749023, 69.03550118207932, 63.092802464962006, 62.2497721016407, 14.33113619685173, 13.102821707725525, 66.67660295963287, 49.904291555285454, 66.38759046792984, 61.26123234629631, 70.3077033162117, 60.245531648397446, 57.9161274433136, 55.143089443445206, 66.75433158874512, 69.18629229068756, 67.19964489340782, 63.73880200088024, 65.98420411348343, 59.76787447929382, 58.73506709933281, 54.06684659421444, 53.2954765856266, 53.94529111683369, 52.95635238289833, 55.29574245214462, 64.08613756299019, 63.49578984081745, 66.74113869667053, 62.334575951099396, 61.26839116215706, 61.80043861269951, 60.379432663321495, 53.93074929714203, 54.27672453224659, 51.34537182748318, 49.177185371518135, 47.24982239305973, 54.78864826261997, 56.990956887602806, 53.8150455057621, 55.74735201895237, 65.23571267724037, 66.31841897964478, 65.2204678952694, 63.38339567184448, 64.81949061155319, 60.88808476924896, 64.91462990641594, 66.12422659993172, 62.07952603697777, 64.8578305542469, 64.55639272928238, 62.444671243429184, 64.29086297750473, 64.73746821284294, 72.80461013317108, 76.68654263019562, 77.82590389251709, 77.43384093046188, 76.50960892438889, 75.56719109416008, 70.64699470996857, 68.81059125065804, 32.784568592906, 1.0095262667164207, 5.033787963911891, 2.6116905827075243, 0.367196710431017, 0.10257839763653465, 49.484493881464005, 82.71926611661911, 80.49045011401176, 66.60838901996613, 79.44594696164131, 36.34734861552715, 26.681761667132378, 25.776711031794548, 64.72164586186409, 65.18744766712189, 83.27555626630783, 17.951049953699112, 0.6378734938334674, 0.25455822644289583, 0.3178104042308405, 0.1565988891525194, 0.20132812962401658, 0.1645462666056119, 0.18872834712965414, 0.11066795574151911, 0.11039618868380785, 0.09010774883790873, 0.16361053712898865], [0.03356486064149067, 0.05258068420516793, 0.031434922784683295, 0.0845173878769856, 0.16092299774754792, 0.05589978383795824, 0.06479438292444684, 0.062135805856087245, 0.11634105874691159, 0.11872209855937399, 0.6425557332113385, 11.789107751101255, 79.34032782912254, 63.42590019106865, 59.63004067540169, 49.71439674496651, 27.850324362516403, 45.024145022034645, 43.671083226799965, 49.17359836399555, 88.99622529745102, 3.555278987623751, 0.12457019998691976, 0.5647485551889986, 2.627138178795576, 1.9308281550183892, 24.509980604052544, 102.14501693844795, 79.4847884774208, 79.1920217871666, 84.13783639669418, 90.49006953835487, 84.90813106298447, 79.9260663986206, 65.54009154438972, 72.96151131391525, 72.4377778172493, 74.7583132982254, 73.75931650400162, 74.07880336046219, 74.77424204349518, 74.018614590168, 73.29871281981468, 76.07316434383392, 76.41994133591652, 71.44356116652489, 67.27053388953209, 57.93857663869858, 54.500996097922325, 54.22038875520229, 52.66242675483227, 54.33671571314335, 53.68631221354008, 54.78971220552921, 50.45158378779888, 49.71796095371246, 48.68325747549534, 51.411982253193855, 51.774163618683815, 49.723991230130196, 48.630079329013824, 46.534791961312294, 46.37883313000202, 46.5450856089592, 46.46080233156681, 46.26979038119316, 48.100760132074356, 50.933006554841995, 49.65284004807472, 50.01475162804127, 51.16160988807678, 58.97446185350418, 63.717067167162895, 63.60196374356747, 61.76108792424202, 60.757573172450066, 58.42820316553116, 56.50078319013119, 60.87278299033642, 61.10710881650448, 60.09607046842575, 59.100641682744026, 64.95591849088669, 60.351279973983765, 59.90966387093067, 58.92799034714699, 41.93385064601898, 19.203090369701385, 16.010089404881, 50.798280984163284, 47.65325054526329, 60.64290672540665, 57.078534588217735, 56.171416863799095, 44.11415085196495, 48.03347334265709, 54.69689458608627, 62.01752856373787, 61.80659808218479, 59.7779743373394, 59.71812754869461, 59.8513787984848, 58.67793336510658, 57.553094923496246, 53.08774173259735, 54.66731317341328, 52.60590858757496, 52.82411947846413, 48.47451187670231, 44.97689835727215, 49.7459464520216, 53.75551030039787, 57.53672920167446, 58.4900638461113, 53.6057261377573, 52.84474857151508, 50.491899624466896, 48.24784263968468, 44.461490213871, 44.627731293439865, 41.31569981575012, 46.67417608201504, 48.00521045923233, 47.90738470852375, 47.95295566320419, 51.97169981896877, 56.031873151659966, 57.85280764102936, 54.489342123270035, 55.58797337114811, 55.535266399383545, 56.646892949938774, 52.68667325377464, 56.534069404006004, 53.727840185165405, 56.18405498564243, 55.7561257481575, 59.05645005404949, 61.114883199334145, 69.64555084705353, 68.36716264486313, 74.395060390234, 69.01904046535492, 71.93014785647392, 65.49859777092934, 71.8874229490757, 60.461857840418816, 62.721873968839645, 13.435121476650238, 0.452748941606842, 0.8047917089425027, 0.2945681498385966, 0.09655013986048289, 7.752467505633831, 66.62298783659935, 65.12393787503242, 56.86753951013088, 53.514196649193764, 48.41865487396717, 13.710881229490042, 18.336696960031986, 36.38313129544258, 48.37083823978901, 57.69062854349613, 35.04903428256512, 1.0466649988666177, 0.09111476159887388, 0.10865863543585874, 0.042316470135119744, 0.047281523438869044, 0.046165426101651974, 0.01841572480770992, 0.02154648034775164, 0.03449296083999798, 0.029193961490818765, 0.06717746364302002, 0.0983370014000684, 0.032343344937544316, 0.03631940111517906, 0.07622354620252736, 0.08534373220754787, 0.04472008236916736, 0.11803412024164572, 0.005079915035821614, 0.20092021557502449, 0.2703755011316389, 0.8526278764475137, 14.873836375772953, 92.93372601270676, 67.65164583921432, 70.83254635334015, 54.67308886349201, 31.843140609562397, 34.13522131741047, 46.29928059875965, 56.82619772851467, 96.0489584505558, 3.092214222997427, 0.15698415285442024, 1.9310550740920007, 6.685085780918598, 3.8037554919719696, 34.383579790592194, 108.2313783466816, 80.78953966498375, 83.73766466975212, 84.43689554929733, 93.32059845328331, 86.05350360274315, 83.96619960665703, 69.2569912970066, 76.15287646651268, 74.34304118156433, 78.31832706928253, 76.62906691431999, 80.1640248298645, 78.5975132882595, 77.78781473636627, 76.58798351883888, 80.05599662661552, 77.75322899222374, 74.24625277519226, 68.50509524345398, 61.88881427049637, 56.829579547047615, 58.31208139657974, 54.68972057104111, 56.643609926104546, 55.70987842977047, 57.452506721019745, 53.34635965526104, 51.95486292243004, 51.85359835624695, 55.57187743484974, 55.695777386426926, 52.56463900208473, 51.59610137343407, 49.65048797428608, 50.090758949518204, 48.5540834069252, 49.00940157473087, 47.54659406840801, 49.12998050451279, 53.49643260240555, 51.34366571903229, 52.18305207788944, 53.71783912181854, 63.46342697739601, 66.47811681032181, 65.62232673168182, 65.15783965587616, 66.59011960029602, 60.17608277499676, 58.28577160835266, 62.48866908252239, 63.32572616636753, 62.84655287861824, 62.058874145150185, 66.83207541704178, 64.17654991149902, 62.38559201359749, 63.06080058217049, 47.12170086801052, 22.79743529856205, 20.804542936384678, 52.59819880127907, 53.37747238576412, 65.06991997361183, 60.42455144226551, 57.60379180312157, 46.06487117707729, 49.7911374270916, 57.51516915857792, 64.67482477426529, 62.51996420323849, 64.42180395126343, 61.42094537615776, 61.691084280610085, 61.55738465487957, 60.51924616098404, 57.386314272880554, 57.56949104368687, 55.40351986885071, 55.572105422616005, 50.19051119685173, 46.93867988884449, 51.663270369172096, 56.00530497729778, 58.18125441670418, 61.91018432378769, 56.88207373023033, 56.71224184334278, 52.412088587880135, 51.260450184345245, 46.538701951503754, 47.593228965997696, 43.71676817536354, 49.07601960003376, 50.77367350459099, 50.93423008918762, 50.6007219851017, 55.06902001798153, 59.61012974381447, 59.706914350390434, 57.981844916939735, 57.77051545679569, 58.110369220376015, 58.173183649778366, 56.68647922575474, 59.210155606269836, 55.53274713456631, 59.93613325059414, 59.52593006193638, 63.110946491360664, 64.92324024438858, 71.83693885803223, 70.43479889631271, 76.02951228618622, 71.81562960147858, 75.33300206065178, 66.295977383852, 74.24799308180809, 65.1267497241497, 68.87020245194435, 18.646285347640514, 0.22401821130188182, 0.2540160430362448, 0.12832297361455858, 0.1265386724844575, 7.673771353438497, 72.69771426916122, 69.97106418013573, 68.00564244389534, 47.07386903464794, 34.65373009443283, 14.495198093354702, 25.203200206160545, 42.72083021700382, 55.39462074637413, 66.25176295638084, 44.25775654613972, 0.8821139973588288, 0.06775261324946769, 0.18873651075409725, 0.08023320682696067, 0.027641065717034508, 0.04474488494452089, 0.008762009765632683, 0.04773683845996857, 0.015293349970306735, 0.07969065976794809, 0.010424630218039965, 0.15537790779490024, 0.23019608604954556, 0.17447158636059612, 0.17925615306012332, 0.28511087293736637, 0.1860169105930254, 0.1612335123354569, 0.221861990285106, 0.2933990891324356, 0.3397222253261134, 1.0506468289531767, 19.044965654611588, 107.1287003159523, 78.13817113637924, 82.47734069824219, 63.2048774510622, 41.32116012275219, 62.4396251142025, 64.90436285734177, 64.87811386585236, 107.96685174107552, 4.424510132521391, 0.3933059406699613, 1.818171562626958, 8.222955409437418, 6.735140969976783, 39.90836173295975, 110.673598498106, 85.78852102160454, 88.15278455615044, 89.22146961092949, 97.84592762589455, 92.24528655409813, 86.65197908878326, 72.68324464559555, 80.22792220115662, 79.98133823275566, 82.61015117168427, 80.33943101763725, 83.30432832241058, 83.92331510782242, 82.20231905579567, 82.47155740857124, 83.81864592432976, 83.91313165426254, 77.25792557001114, 71.13005518913269, 65.4893034696579, 59.47430603206158, 60.13929694890976, 59.487415328621864, 58.552027121186256, 59.648990258574486, 60.68087048828602, 56.802061423659325, 54.50582943856716, 54.69128988683224, 59.54036928713322, 59.65658985078335, 56.10490143299103, 53.349897265434265, 51.86352722346783, 52.88865901529789, 52.25499361753464, 52.41851024329662, 50.71686655282974, 53.70812304317951, 56.21522091329098, 55.70347957313061, 54.214464873075485, 56.36312037706375, 65.11892974376678, 72.29930564761162, 66.84029817581177, 66.19553357362747, 70.08962541818619, 64.79524031281471, 62.168422266840935, 66.03165596723557, 66.26422628760338, 65.66897302865982, 63.63659888505936, 72.1291583776474, 66.47770643234253, 66.22957974672318, 64.5361778140068, 56.09461538493633, 24.325470104813576, 24.31282438337803, 56.33644960820675, 54.75117847323418, 68.88536363840103, 62.21696086227894, 62.77582727372646, 48.057643845677376, 54.29882034659386, 59.5742292702198, 69.08701121807098, 64.1623006761074, 65.52569791674614, 64.11184698343277, 65.20930409431458, 63.41207653284073, 62.91201576590538, 59.22688610851765, 59.02966149151325, 57.482924088835716, 58.7171396613121, 51.26942530274391, 49.01955462992191, 53.90778332948685, 60.51730826497078, 62.55463734269142, 64.56802010536194, 60.1928436756134, 59.70567561686039, 55.61404377222061, 53.594839721918106, 49.39086310565472, 50.663076639175415, 48.30207332968712, 52.84199371933937, 53.24415273964405, 53.95463481545448, 54.14037644863129, 57.98605889081955, 61.82419113814831, 64.82645183801651, 60.95993131399155, 61.05471342802048, 60.77683053910732, 62.86492109298706, 59.32157322764397, 64.26944732666016, 58.8799799233675, 63.535007536411285, 63.32027725875378, 67.29907795786858, 66.85323268175125, 76.99010074138641, 73.26500102877617, 80.90237841010094, 73.5375528037548, 79.71895471215248, 68.79208624362946, 77.62516066431999, 68.01929131150246, 71.35102093219757, 15.691587645560503, 1.5844659344293177, 3.364035487174988, 0.5072981910780072, 0.16340303263859823, 11.581572387367487, 82.11293265223503, 77.65624299645424, 77.44542270898819, 74.95774939656258, 66.64270877838135, 20.450035259127617, 30.627792924642563, 51.059190183877945, 66.74262061715126, 74.29569572210312, 54.4799642264843, 1.6609255503863096, 0.18248157139169052, 0.29793479887302965, 0.2032297643017955, 0.1344267078093253, 0.21204169926932082, 0.09915832881233655, 0.11738245520973578, 0.14276896719820797, 0.26525904599111527, 0.14793345413636416], [0.02666246422450058, 0.07214222379843704, 0.030653849462396465, 0.01628530641028192, 0.016044080584833864, 0.10347815521527082, 0.05638170856400393, 0.0683691375888884, 0.07679504444240592, 0.09504502726485953, 0.19449961400823668, 31.301665864884853, 74.24347892403603, 62.21824139356613, 58.568465039134026, 32.4826367944479, 67.77945578098297, 64.01734605431557, 31.64927501231432, 69.12498638033867, 57.38218009471893, 0.6603863358031958, 0.10393240154371597, 2.1613100124523044, 11.124043688178062, 6.311470828950405, 71.63450092077255, 96.61958143115044, 77.75247663259506, 95.19974201917648, 78.60388934612274, 85.41453748941422, 81.11308470368385, 75.98377034068108, 69.27753299474716, 67.08739891648293, 73.01255017518997, 75.46822920441628, 76.79513320326805, 75.59923857450485, 75.16732335090637, 76.8353882431984, 71.76930248737335, 67.56769314408302, 62.19262316823006, 61.215950176119804, 55.1645202934742, 53.45672473311424, 53.54598194360733, 54.07476156949997, 53.0521984398365, 55.109164863824844, 53.63704025745392, 53.88280346989632, 49.526683017611504, 48.88318374752998, 49.33157108724117, 52.27441817522049, 52.76285916566849, 48.50996397435665, 48.11924234032631, 48.055371567606926, 47.67781622707844, 43.947495594620705, 44.315551444888115, 44.84740510582924, 47.315631061792374, 49.848708137869835, 48.149503916502, 49.913536459207535, 50.69605126976967, 60.52485466003418, 63.1102055311203, 63.555108457803726, 64.22226145863533, 62.618910893797874, 60.198478773236275, 60.08109547197819, 63.61813187599182, 61.84293173253536, 62.302384078502655, 61.14124998450279, 63.832402378320694, 57.46982999145985, 63.62353518605232, 55.86981184780598, 34.56815108656883, 38.9574171602726, 29.95269265025854, 37.644124031066895, 52.99355238676071, 57.89792262017727, 59.63843822479248, 50.47738820314407, 47.18755133450031, 53.21047134697437, 58.787637278437614, 62.746131867170334, 57.61585235595703, 59.98898081481457, 62.00512982904911, 60.38877256214619, 60.12467533349991, 59.21478755772114, 59.91718366742134, 56.1514413356781, 58.97137641906738, 60.042307153344154, 60.595219284296036, 51.13395497202873, 45.70884168148041, 50.61156280338764, 49.55287881195545, 52.3762983083725, 54.195367097854614, 52.987142130732536, 51.54048375785351, 48.246212527155876, 46.78469695150852, 46.26839205622673, 43.020501136779785, 44.755982011556625, 50.31766377389431, 46.55658759176731, 48.1176920235157, 48.59881080687046, 52.33714900910854, 51.38855271041393, 53.52911464869976, 54.077964797616005, 53.300864696502686, 55.36057457327843, 56.04902923107147, 53.66347163915634, 55.070612132549286, 54.34109307825565, 58.26852433383465, 57.665352299809456, 62.75705248117447, 61.018201187253, 67.03456655144691, 67.52307593822479, 70.19599691033363, 66.86437368392944, 71.07909992337227, 67.55750209093094, 70.68421751260757, 58.104528933763504, 53.06590050458908, 2.6000031223520637, 0.5880952742882073, 0.1657487388001755, 0.06701389429508708, 0.06539876572787762, 39.90568287670612, 72.27425739169121, 67.92107418179512, 45.497744008898735, 48.45061115920544, 36.539443507790565, 14.122406747192144, 21.281782127916813, 42.66424745321274, 47.754682302474976, 60.292189344763756, 7.436253698542714, 0.3223935520509258, 0.05113829050969798, 0.040034336343524046, 0.03876078495522961, 0.11708645703038201, 0.014127424838079605, 0.008153042344929418, 0.0273193354223622, 0.041931874366127886, 0.06978335935855284, 0.022714444530720357, 0.05333070606866386, 0.04736843264254276, 0.032700113879400305, 0.15638393349945545, 0.020704615853901487, 0.009496607945038704, 0.08000127083505504, 0.06870742334285751, 0.14364517643116415, 0.1570337580051273, 40.66308483481407, 85.62388345599174, 70.14569520950317, 71.03031054139137, 51.26759760081768, 59.21654686331749, 59.90915469825268, 40.173557102680206, 78.26499313116074, 62.90627047419548, 0.5277969629969448, 0.06827318531577475, 4.137752344831824, 15.236907843500376, 13.307588919997215, 81.90832883119583, 94.21303376555443, 84.47132930159569, 94.3459202349186, 85.51273941993713, 88.41401293873787, 83.92630934715271, 79.78380963206291, 72.52392679452896, 69.78957831859589, 76.684300750494, 78.278938382864, 77.88170009851456, 77.66342461109161, 79.36413735151291, 77.69813194870949, 75.08679047226906, 68.79717037081718, 65.60724154114723, 63.713635951280594, 58.28265957534313, 55.50525560975075, 55.8009747415781, 55.512722209095955, 55.30054919421673, 58.683431670069695, 55.568674206733704, 57.82352641224861, 52.72798843681812, 52.959236428141594, 52.72408604621887, 55.26197366416454, 55.49332045018673, 50.14392949640751, 50.82026660442352, 49.195621982216835, 50.82831837236881, 48.123946487903595, 47.28595085442066, 47.63205528259277, 49.83021833002567, 51.057689264416695, 50.483384281396866, 51.75516463816166, 52.19116844236851, 62.87917412817478, 64.5845340192318, 66.26342073082924, 66.89477205276489, 65.35479068756104, 62.30523772537708, 62.76842527091503, 67.15107589960098, 65.17329722642899, 65.19904464483261, 62.330605164170265, 65.66341772675514, 61.385953053832054, 68.34731251001358, 59.13402669131756, 38.90547774732113, 47.15856648981571, 36.57654471695423, 41.42935171723366, 56.03952594101429, 61.578028947114944, 60.73708467185497, 54.575042724609375, 49.45418670773506, 54.857724756002426, 61.18326433002949, 64.49816465377808, 60.048740208148956, 62.46393620967865, 62.1677079051733, 61.72970540821552, 60.91446295380592, 61.25004194676876, 62.44344390928745, 60.1428497582674, 61.62119083106518, 61.751641631126404, 63.14543344080448, 52.69130900502205, 47.84008651971817, 52.4737972766161, 53.523878529667854, 54.93057444691658, 56.891235038638115, 56.50652848184109, 54.37364213168621, 51.59757189452648, 49.21767979860306, 47.606589049100876, 45.1248662173748, 46.995099261403084, 52.26075790822506, 48.75943958759308, 50.51121398806572, 50.08713014423847, 54.25164967775345, 55.261624082922935, 56.648120284080505, 55.66365770995617, 55.75737968087196, 56.32310472428799, 59.67212341725826, 56.49647042155266, 59.014450907707214, 57.61106841266155, 60.13523496687412, 58.8374450057745, 64.72031593322754, 64.16908711194992, 68.674725741148, 68.90310868620872, 71.26157373189926, 68.02865400910378, 74.54140573740005, 70.52170783281326, 75.29723078012466, 63.71230602264404, 59.26189363002777, 4.131324039772153, 0.5000092915724963, 0.9793545200955123, 0.06544728734297678, 0.11031543559511192, 41.24471202492714, 77.7250649034977, 74.84858885407448, 55.409485548734665, 37.399432361125946, 31.38110440224409, 22.948414497077465, 30.857234112918377, 53.64556699991226, 53.638339787721634, 70.86648613214493, 9.843704290688038, 0.3504003054695204, 0.10231197404209524, 0.05632046282698866, 0.031396869162563235, 0.014973277448007138, 0.042863681592280045, 0.013229197011241922, 0.03752710545086302, 0.05045614547270816, 0.033608740122872405, 0.1730319534544833, 0.15352057933341712, 0.11014737625373527, 0.08496275069774128, 0.22079004702391103, 0.2499578014248982, 0.2258634872850962, 0.27038657397497445, 0.21455995476571843, 0.29447339242324233, 0.25417596101760864, 52.578842639923096, 96.09570354223251, 78.78900021314621, 79.18544054031372, 48.146695867180824, 80.50770118832588, 80.64729809761047, 50.974097549915314, 84.08742070198059, 73.9727434515953, 1.5231566992588341, 0.26958300615660846, 7.9915715754032135, 24.8363583907485, 18.828789554536343, 83.14451649785042, 102.12187618017197, 89.03440564870834, 97.13693127036095, 86.81938290596008, 93.93556505441666, 87.21485048532486, 84.35459196567535, 77.48268350958824, 72.88296952843666, 79.29884165525436, 81.73714801669121, 79.95346292853355, 81.19168728590012, 82.67090231180191, 82.61340379714966, 78.78991976380348, 74.78529945015907, 69.45945963263512, 69.45837289094925, 63.02459232509136, 58.791437074542046, 59.30636264383793, 59.71457853913307, 56.503697633743286, 60.40271781384945, 58.82849268615246, 60.013307109475136, 56.91735103726387, 56.3065642118454, 56.00667670369148, 59.41739268600941, 59.25581395626068, 53.342856243252754, 53.2417094707489, 52.1728990226984, 54.58608113229275, 49.36045713722706, 49.9650464951992, 49.811998307704926, 53.88442598283291, 53.44118356704712, 52.11083695292473, 53.41565653681755, 54.33227375149727, 66.40198409557343, 68.28355953097343, 68.13382476568222, 69.83378514647484, 68.55292707681656, 65.73381274938583, 65.73200404644012, 71.15979999303818, 67.86198735237122, 66.75685465335846, 67.30474725365639, 70.13383984565735, 63.715402856469154, 69.35441046953201, 61.34041249752045, 45.02596892416477, 48.632119819521904, 41.54509350657463, 45.91898940503597, 57.44367599487305, 64.6132604777813, 64.06561106443405, 58.51362258195877, 50.923795849084854, 58.57259921729565, 62.87211790680885, 68.06158304214478, 61.69088289141655, 64.75564643740654, 66.17508307099342, 65.50933599472046, 65.38227841258049, 63.300054743885994, 65.3768903017044, 62.95981340110302, 64.10785719752312, 66.39645159244537, 67.12130069732666, 55.37379406392574, 50.645745769143105, 55.73534086346626, 56.121544539928436, 58.80775719881058, 60.441456735134125, 59.45738933980465, 57.40345515310764, 54.54490274190903, 51.93460240960121, 51.82380795478821, 49.27304282784462, 50.747781693935394, 54.57364819943905, 50.98007082939148, 53.74666817486286, 56.00210554897785, 57.80501000583172, 58.713051080703735, 59.95287135243416, 58.49183835089207, 59.19468283653259, 62.314414232969284, 65.81455081701279, 60.45757167041302, 63.926576524972916, 61.44689418375492, 64.47928726673126, 63.63008223474026, 69.19456824660301, 66.8573896586895, 72.45498329401016, 72.97015964984894, 75.71260169148445, 71.47473469376564, 78.27630132436752, 74.44153189659119, 76.22077122330666, 66.17422431707382, 61.898416355252266, 3.107065726071596, 2.0383082376793027, 2.204031595028937, 0.21258407563436776, 0.40423400583676994, 53.55243019759655, 84.94241282343864, 83.43972265720367, 63.82894456386566, 68.67125272750854, 51.590500473976135, 25.660974942147732, 34.32537831366062, 61.968302205204964, 63.81766676902771, 83.05104151368141, 12.02150708064437, 0.6086465902626514, 0.21942258055787534, 0.22565267281606793, 0.12888817844213918, 0.1384026452433318, 0.11012920847861096, 0.15166673896601424, 0.232621202012524, 0.20083129144040868, 0.22357362031470984], [0.03519663187034894, 0.060067989470553584, 0.1030772841477301, 0.0314761527988594, 0.07710763704380952, 0.05183985012990888, 0.03265404135163408, 0.04540044996247161, 0.07627070226590149, 0.030631414338131435, 0.23232818726683035, 48.620165660977364, 75.09318932890892, 58.775675520300865, 43.00663948059082, 17.56063610315323, 88.19759175181389, 59.832721799612045, 36.18961147964001, 94.24055948853493, 29.80959802865982, 0.13696995883947238, 0.19583037385018542, 7.95574139803648, 11.648687236011028, 18.584871143102646, 97.1898852288723, 79.38896521925926, 79.17300760746002, 100.59113591909409, 103.89110684394836, 76.91684827208519, 86.47119238972664, 73.62445414066315, 67.11544141173363, 67.56332337856293, 73.48839104175568, 72.459307461977, 77.65719294548035, 74.18224141001701, 67.47421056032181, 59.50610272586346, 57.80033625662327, 57.3349030315876, 55.58951608836651, 54.35118533670902, 54.41480912268162, 52.705242857337, 53.24600704014301, 52.001972794532776, 53.21385696530342, 53.64486783742905, 52.85280413925648, 53.04434046149254, 48.92724238336086, 49.52841192483902, 48.3821502327919, 51.49873159825802, 50.816007032990456, 49.11999464035034, 49.172675013542175, 48.0574956536293, 46.07581838965416, 45.48353657126427, 44.8513150960207, 42.83158667385578, 46.394537687301636, 48.24316129088402, 49.4448734074831, 49.6915827691555, 50.55406428873539, 59.04245160520077, 62.56754145026207, 63.62041935324669, 62.454284727573395, 60.11840187013149, 58.180635049939156, 62.007227316498756, 61.58984251320362, 65.15001967549324, 60.30282877385616, 59.95278775691986, 61.833793222904205, 61.50004953145981, 58.86443495750427, 44.611198380589485, 35.34595414996147, 54.39098820090294, 44.55639012157917, 32.17534348368645, 52.5468635559082, 60.787944942712784, 53.90913225710392, 48.108580112457275, 48.07020217180252, 50.3277712315321, 58.15321572124958, 60.58330312371254, 61.54649443924427, 60.217386558651924, 60.70896238088608, 60.728185549378395, 60.27680777013302, 59.25753526389599, 59.71683941781521, 62.7966121584177, 58.02407965064049, 57.21011392772198, 59.356018379330635, 58.87124039232731, 48.81184637546539, 45.27329005300999, 50.31135231256485, 50.39022848010063, 51.607968136668205, 51.681285202503204, 51.65506660938263, 46.13671392202377, 48.57026293873787, 45.02578653395176, 43.6392979323864, 41.77796021103859, 47.17321090400219, 48.9121799916029, 47.217102348804474, 48.121947795152664, 48.67047496140003, 49.74285341799259, 51.60862550139427, 50.083299949765205, 50.33945560455322, 50.6315915286541, 52.09545537829399, 51.01366102695465, 53.61735351383686, 52.7596141397953, 58.110627606511116, 56.76652953028679, 62.35766351222992, 62.15003505349159, 64.93339329957962, 65.61736419796944, 70.78287541866302, 67.37917765974998, 71.06989681720734, 69.7250197827816, 78.01899433135986, 71.54061555862427, 67.78070971369743, 20.07922075688839, 0.3001361573114991, 0.7834844710305333, 0.22100228641647846, 0.17529945209389552, 12.070705890655518, 65.03523543477058, 64.8900756239891, 56.986161544919014, 49.98940698802471, 34.343621134757996, 15.43749338015914, 12.93756477534771, 22.900263480842113, 47.74040266871452, 61.11359886825085, 35.606813952326775, 1.2117562838830054, 0.14573828520951793, 0.15916171803837642, 0.10158428340218961, 0.03318956027214881, 0.10184461396420375, 0.033388014271622524, 0.038259746215771884, 0.011017032902600477, 0.02079775724268984, 0.02156771133741131, 0.10486197119462304, 0.03809156813076697, 0.05486104797455482, 0.04532922604994383, 0.11658147006528452, 0.013220807031757431, 0.0011447152473920141, 0.011674508950818563, 0.14555194677086547, 0.34600192273501307, 61.33609212934971, 78.98362576961517, 67.33686313033104, 54.289985820651054, 30.01060914248228, 73.11893686652184, 54.08726289868355, 42.78940513730049, 103.7468133866787, 29.94264978915453, 0.16709325806004927, 0.256662541651167, 12.43566395714879, 13.407087530940771, 23.263277001678944, 101.4297965168953, 78.96202772855759, 86.1963303387165, 96.7746739089489, 100.63137575984001, 80.6660158932209, 89.55148190259933, 75.83734139800072, 71.25288739800453, 69.8803098499775, 76.73172980546951, 76.96704357862473, 80.44587850570679, 74.87145602703094, 70.71821048855782, 61.35848432779312, 60.26134639978409, 59.44744527339935, 59.34573233127594, 55.65580353140831, 57.03386038541794, 54.141930565238, 56.76214076578617, 53.586392775177956, 55.77196329832077, 55.74399299919605, 54.86684046685696, 55.69286674261093, 51.96625471115112, 52.04776033759117, 51.50678716599941, 53.18164989352226, 54.69980522990227, 51.64479196071625, 52.42276221513748, 49.40573550760746, 49.28759604692459, 47.32269108295441, 47.019239366054535, 45.6204242259264, 50.39139121770859, 50.772119387984276, 49.52377997338772, 50.76491877436638, 53.72733101248741, 59.59212251007557, 63.95519658923149, 64.28344577550888, 64.14958655834198, 61.91357374191284, 59.40808318555355, 65.46696826815605, 64.72457930445671, 65.8678087592125, 61.058589220047, 61.212340369820595, 65.02815261483192, 62.93945409357548, 64.1708654165268, 45.570160523056984, 40.534716323018074, 56.22569315135479, 49.63435783982277, 36.434215754270554, 53.705972358584404, 63.956230133771896, 55.825810208916664, 52.06471882760525, 51.425881907343864, 50.97418114542961, 59.76560220122337, 62.38236218690872, 65.12975916266441, 62.74007499217987, 62.593794241547585, 64.55918937921524, 62.08476975560188, 61.8478524684906, 60.84159806370735, 63.119986206293106, 61.9085618108511, 59.514572471380234, 62.63580858707428, 60.33071167767048, 52.08048038184643, 48.4171349555254, 52.12151437997818, 55.4307796061039, 56.85913436114788, 54.78953741490841, 53.3274594694376, 47.71250456571579, 49.62162472307682, 47.44937248528004, 48.33397261798382, 44.776554107666016, 49.00482662022114, 50.65763533115387, 49.55922447144985, 52.26831190288067, 50.694907531142235, 51.7577750980854, 53.35445702075958, 51.75230719149113, 54.72397953271866, 52.858435437083244, 55.915918573737144, 54.509021267294884, 55.53953357040882, 54.96298290789127, 60.2315977960825, 58.29821594059467, 66.1904114484787, 63.54862980544567, 69.87592488527298, 68.43001887202263, 73.82954433560371, 69.83419552445412, 75.24448201060295, 71.84351250529289, 78.65063443779945, 72.38150283694267, 74.49086084961891, 24.160636849701405, 0.177314234606456, 1.0361185460351408, 0.8906633604783565, 0.3281404764857143, 11.911375690251589, 70.38046181201935, 69.63749527931213, 64.79744419455528, 50.65434090793133, 27.133973501622677, 21.414510905742645, 24.046432077884674, 28.737367764115334, 55.63323654234409, 68.05174916982651, 43.79217512905598, 1.2819392303936183, 0.09069518840988167, 0.14995116071077064, 0.056787704161251895, 0.026214270110358484, 0.03429004653298762, 0.03344246193591971, 0.024339100418728776, 0.09945507656084374, 0.0404049018106889, 0.12032498168991879, 0.15717972361017019, 0.13402851589489728, 0.11951666412642226, 0.11864372034324333, 0.2185316025861539, 0.09097236572415568, 0.20056054112501442, 0.2572328969836235, 0.30995192122645676, 0.528445600066334, 75.23476973176003, 90.36854445934296, 80.561483502388, 58.538511246442795, 30.957277044653893, 90.99687874317169, 82.96069756150246, 50.910257175564766, 114.99151960015297, 35.11018440127373, 0.4449143260717392, 0.36478544294368476, 17.7030448615551, 23.029509745538235, 27.0958349481225, 102.98641338944435, 84.62934002280235, 88.1587578356266, 102.17878192663193, 97.74494424462318, 83.87633442878723, 94.10609990358353, 79.92836907505989, 74.00868952274323, 74.24744591116905, 80.94318822026253, 80.34733459353447, 85.90277329087257, 80.67177638411522, 74.16573509573936, 65.24360865354538, 64.72324937582016, 63.74187223613262, 61.401285231113434, 59.61893767118454, 61.35601066052914, 55.93913912773132, 58.92192967236042, 58.27075481414795, 59.537777826189995, 58.63762892782688, 57.37813711166382, 59.630424454808235, 55.31173579394817, 56.159135922789574, 55.367494001984596, 55.421834886074066, 55.71111336350441, 55.02316027879715, 55.264074951410294, 53.69853235781193, 51.33662469685078, 52.50395625829697, 50.410922169685364, 47.74826064705849, 54.54065836966038, 53.67255315184593, 53.0486798286438, 54.793648794293404, 55.32228022813797, 63.17901223897934, 66.66117578744888, 67.68968179821968, 64.40618678927422, 65.99792897701263, 62.68696904182434, 69.43662285804749, 67.15762674808502, 70.31975626945496, 65.17711222171783, 64.95036318898201, 67.7437224984169, 64.45149555802345, 66.79276272654533, 50.934549272060394, 43.73476020991802, 57.83297650516033, 51.89172551035881, 40.77289514243603, 56.419463753700256, 67.52148762345314, 58.42483654618263, 53.72237227857113, 54.09037493169308, 54.96209375560284, 62.807908952236176, 65.40233373641968, 67.86589354276657, 66.60781905055046, 66.32490143179893, 68.07341560721397, 66.58386513590813, 65.50076365470886, 63.20814527571201, 64.0822921693325, 66.49370357394218, 65.82170203328133, 64.52072024345398, 63.663368448615074, 54.43650595843792, 50.85975028574467, 55.37987753748894, 55.82571521401405, 59.977505430579185, 59.63591895997524, 56.55589923262596, 52.20022715628147, 53.366593569517136, 50.755852460861206, 50.44896572828293, 46.33657559752464, 50.98095618188381, 52.566098123788834, 51.85797572135925, 53.946404457092285, 54.449638053774834, 55.253880098462105, 56.82214334607124, 55.59672050178051, 57.28105612099171, 56.43954947590828, 61.16511270403862, 58.34936499595642, 59.85299751162529, 59.502078741788864, 65.18105641007423, 62.888343036174774, 69.78175073862076, 66.27314060926437, 72.96692982316017, 73.08097690343857, 78.92728239297867, 73.77401411533356, 77.3098535835743, 76.26280456781387, 84.80435863137245, 74.93308112025261, 78.74990031123161, 25.716818645596504, 0.8507741696666926, 2.488232357427478, 0.9073281974997371, 0.34742414485663176, 18.12944658100605, 80.44521734118462, 76.3557779788971, 73.9854347705841, 71.09312117099762, 48.90741124749184, 24.474085830152035, 23.810631930828094, 35.784868597984314, 66.0333126783371, 78.1621478497982, 54.01014603674412, 1.4574235514737666, 0.2537149388808757, 0.27788282954134047, 0.3002698329510167, 0.19324113934999332, 0.32680190925020725, 0.07681659641093574, 0.11623246769886464, 0.21018891275161877, 0.1263848104281351], [0.028307985594437923, 0.02853505124221556, 0.025643662447691895, 0.11799349507782608, 0.02599058123450959, 0.04148497529968154, 0.04217736939608585, 0.07056072194245644, 0.1092244042956736, 0.15126776037504897, 3.7238308181986213, 72.20139250159264, 62.73902624845505, 54.9513403326273, 37.50496029853821, 30.906344577670097, 33.64804185926914, 45.41336573660374, 47.29510076344013, 87.8656567633152, 9.959409032016993, 0.07834333518985659, 0.2691982174292207, 7.972074821591377, 3.4629764780402184, 43.06113615632057, 100.75371399521828, 75.02377465367317, 84.41878572106361, 72.58286163210869, 95.64414337277412, 87.49139964580536, 78.1133508682251, 73.649373203516, 70.36948800086975, 68.89594227075577, 69.59225490689278, 70.82203611731529, 70.56849092245102, 61.32287263870239, 55.4511047154665, 54.699847027659416, 56.17690756917, 53.529487028717995, 54.335264191031456, 53.045864179730415, 55.11584870517254, 52.63889081776142, 54.33519959449768, 54.33669671416283, 52.299489229917526, 52.939523085951805, 54.68980796635151, 52.65234589576721, 48.65391165018082, 46.2302915006876, 48.58804978430271, 50.894092842936516, 52.61960685253143, 49.36454191803932, 48.90284389257431, 45.27202092111111, 46.29787087440491, 42.39081792533398, 44.633879363536835, 42.702051624655724, 44.74466621875763, 46.83683395385742, 49.83462609350681, 50.73319427669048, 56.92127622663975, 57.69673101603985, 63.00098419189453, 63.12864974141121, 63.43775935471058, 58.48970666527748, 50.91438375413418, 52.279198318719864, 55.93275547027588, 53.644138276576996, 59.77258622646332, 52.784320414066315, 58.36952291429043, 52.417989671230316, 57.163334637880325, 38.29020336270332, 43.00700046122074, 48.32669220864773, 46.813408210873604, 32.34280429780483, 49.62515093386173, 62.79046028852463, 54.58429142832756, 54.69293139874935, 55.06432726979256, 51.59867763519287, 51.307803243398666, 54.9522864818573, 53.515515178442, 55.21177835762501, 54.51670825481415, 57.858267948031425, 58.17689225077629, 57.612793520092964, 59.46981467306614, 51.95754177868366, 53.604400008916855, 61.96229472756386, 60.35509876906872, 57.16741941869259, 46.494799107313156, 45.62743104994297, 46.784047186374664, 51.972326785326004, 51.56432367861271, 49.71883490681648, 49.92664955556393, 47.08097465336323, 48.28523263335228, 46.74640640616417, 44.40167762339115, 43.54422323405743, 46.75171472132206, 48.60761113464832, 48.900780603289604, 47.51709245145321, 46.482989341020584, 48.39316964149475, 48.53501223027706, 49.66204695403576, 49.13872383534908, 50.08023351430893, 50.69662123918533, 51.62910260260105, 51.94284036755562, 54.10115875303745, 54.006027057766914, 54.38406877219677, 57.60675944387913, 57.95920953154564, 62.49080836772919, 65.71490496397018, 65.67254483699799, 69.12631630897522, 71.42654567956924, 71.27570897340775, 68.63043531775475, 68.79662320017815, 76.24856293201447, 41.25972501933575, 0.4758490005042404, 0.5212491424754262, 0.03572025045286864, 0.09153023071121424, 0.2887508104322478, 51.433188915252686, 67.4116887152195, 68.58481496572495, 45.12711949646473, 56.00237913429737, 33.27766813337803, 9.563977550715208, 33.99243637919426, 48.49185794591904, 49.94671627879143, 64.71072524785995, 3.8109527807682753, 0.16444325650809333, 0.09286939166486263, 0.08045647453400306, 0.04412767040776089, 0.03517843440931756, 0.06271155289141461, 0.02577718780230498, 0.03720040091138799, 0.014248916268115863, 0.031712337586213835, 0.08851623540977016, 0.007309690772672184, 0.041129096935037524, 0.08244957149145193, 0.0756978607387282, 0.029843118063581642, 0.0625123678764794, 0.05523378051293548, 0.27723166916985065, 4.625537395477295, 85.10360017418861, 68.891511708498, 65.27305707335472, 45.27687706053257, 37.94463090598583, 34.49035406112671, 47.701549753546715, 55.90247489511967, 96.99594363570213, 10.066401790827513, 0.11672359876683913, 0.29570232960395515, 12.522488348186016, 5.869631487876177, 50.55422767996788, 102.22382470965385, 78.02637353539467, 86.65177389979362, 78.11903536319733, 99.0955437719822, 87.86540597677231, 81.45786300301552, 76.10762849450111, 74.10988569259644, 70.88410958647728, 74.10509034991264, 74.09255862236023, 72.09146440029144, 64.0762048959732, 58.92675161361694, 57.52650395035744, 58.2681405544281, 56.983950063586235, 57.29100398719311, 54.961474388837814, 57.43828788399696, 55.09275734424591, 56.77130587399006, 55.8640019595623, 55.8049151301384, 55.739706829190254, 56.07805207371712, 53.939165845513344, 50.79079918563366, 49.0387511998415, 50.753314197063446, 53.56976866722107, 55.06862483918667, 50.83206497132778, 51.77931994199753, 47.93269135057926, 49.167659282684326, 45.310315266251564, 46.271629482507706, 44.94076229631901, 48.42272445559502, 48.74919913709164, 52.87198171019554, 52.878270372748375, 59.91678088903427, 62.699705958366394, 64.19130831956863, 65.60032591223717, 65.65134957432747, 60.536375641822815, 54.3667721003294, 54.39032703638077, 58.206196278333664, 55.5311094224453, 61.52109280228615, 56.67112044990063, 60.82542613148689, 55.1628103852272, 58.06024610996246, 41.51038996875286, 44.73387099802494, 48.5611130297184, 48.14163453876972, 37.47935347259045, 51.78133003413677, 64.06853690743446, 57.90749430656433, 56.399826407432556, 57.40605801343918, 53.12987767159939, 53.54783624410629, 54.21491704881191, 55.20953267812729, 58.116904869675636, 56.224351823329926, 59.10884164273739, 59.05220188200474, 60.09684942662716, 60.89647091925144, 52.429590448737144, 57.159664034843445, 63.836673349142075, 62.07206703722477, 58.57693858444691, 48.76566365361214, 49.88098740577698, 49.54041168093681, 56.019542813301086, 53.10319550335407, 52.14678302407265, 52.053175047039986, 50.2203243970871, 50.885079726576805, 49.41226735711098, 48.147854804992676, 45.156229734420776, 49.62330423295498, 52.27775439620018, 50.767487436532974, 49.72410902380943, 50.13087719678879, 50.38317985832691, 50.47095134854317, 50.95921754837036, 52.24515214562416, 50.01138500869274, 52.613717168569565, 53.21334779262543, 55.51548846065998, 56.32027007639408, 57.210756093263626, 58.40175278484821, 60.433465763926506, 61.0513012111187, 65.98088309168816, 67.84393072128296, 68.77333045005798, 70.73489919304848, 74.12544205784798, 71.64095297455788, 71.05688631534576, 71.92076236009598, 78.37263375520706, 45.64552187919617, 1.1619176832027733, 1.5294922655448318, 1.2345604039728642, 0.23062510677846149, 0.3781265567522496, 53.72587189078331, 75.02798482775688, 73.10591876506805, 54.058901220560074, 47.833744660019875, 33.27931344509125, 20.29629360884428, 45.9400250762701, 59.44095902144909, 56.31706304848194, 74.22774016857147, 4.846114134415984, 0.2759474271442741, 0.044858188630314544, 0.07486643269658089, 0.0635051165590994, 0.018208969886472914, 0.03891223874234129, 0.04553863043838646, 0.07346709840930998, 0.028323366605036426, 0.10946903843432665, 0.20131370227318257, 0.11905836567166261, 0.18464586697518826, 0.13455066131427884, 0.16359544184524566, 0.09891478563076816, 0.1946756217512302, 0.455939345411025, 0.6084905017632991, 5.591006688773632, 97.51852199435234, 78.31936061382294, 75.63009291887283, 48.570791110396385, 44.7674535959959, 42.41929739713669, 70.76440840959549, 62.05054119229317, 105.11271089315414, 12.454354204237461, 0.1516870886553079, 0.31107989663723856, 14.984236601740122, 9.555770941078663, 51.36754743754864, 107.07285091280937, 81.46300032734871, 91.69572204351425, 85.48686280846596, 104.79472875595093, 86.57442525029182, 87.7797281742096, 78.84760066866875, 77.73362964391708, 72.74277225136757, 78.18919479846954, 77.93063387274742, 76.9531287252903, 66.61303237080574, 64.50322598218918, 59.64905485510826, 61.157057136297226, 59.98638175427914, 59.11251604557037, 57.743403911590576, 61.53084307909012, 57.864142432808876, 59.39481049776077, 58.888833448290825, 60.51902577280998, 58.588649556040764, 60.1116344332695, 58.256053403019905, 54.41491551697254, 51.67555890977383, 54.45825599133968, 54.95582029223442, 59.293720722198486, 54.2194540053606, 55.62854379415512, 50.31948767602444, 52.74538390338421, 47.55317151546478, 48.84290970861912, 48.086738884449005, 51.61834917962551, 50.666876435279846, 55.06943039596081, 54.788264483213425, 60.80705411732197, 64.00422155857086, 67.29388743638992, 69.28181156516075, 67.42398485541344, 62.33812116086483, 56.26954659819603, 57.79291145503521, 61.106736436486244, 60.41213370859623, 63.66535574197769, 57.64587454497814, 61.44196204841137, 59.680118188261986, 61.41555726528168, 44.2427359521389, 48.849475756287575, 48.36744882166386, 52.63195998966694, 41.958309933543205, 56.82102620601654, 66.77458450198174, 61.16215266287327, 58.39941971004009, 60.120951533317566, 56.851857751607895, 56.30179166793823, 58.24424363672733, 58.260837346315384, 61.075061336159706, 60.278639271855354, 62.951225861907005, 63.00639510154724, 64.17204335331917, 61.261631324887276, 55.204144567251205, 57.5982441008091, 66.92053467035294, 66.23369112610817, 62.1201154589653, 51.16186827421188, 52.675973027944565, 51.25264160335064, 59.256152138113976, 56.11494429409504, 55.306575670838356, 56.06325946748257, 54.04783621430397, 53.68609942495823, 52.53574155271053, 51.11790843307972, 49.44021865725517, 52.24351443350315, 55.1303069293499, 53.99540662765503, 53.3766820281744, 53.68476949632168, 53.41557294130325, 54.75477308034897, 55.08617229759693, 55.87651468813419, 54.679609313607216, 56.30736976861954, 57.700827196240425, 58.789901956915855, 60.37947066128254, 62.165978997945786, 61.04368641972542, 63.33654038608074, 66.0815016925335, 68.69532063603401, 71.98336020112038, 70.4133452475071, 75.40832161903381, 78.57937306165695, 76.12445399165154, 75.08226871490479, 76.06418162584305, 81.56175702810287, 48.884916454553604, 1.3504069251939654, 3.4368060948327184, 0.961505927843973, 0.13560703431721777, 0.6151731556747109, 67.9575902223587, 80.50635606050491, 85.2640275657177, 61.88028372824192, 78.75034868717194, 44.37923602759838, 20.01909278333187, 48.06086607277393, 67.11460545659065, 63.23340632021427, 86.95173740386963, 6.3799080066382885, 0.43424378614872694, 0.20894030865747482, 0.18989049101946875, 0.17629772977670655, 0.08195389847969636, 0.2037310553714633, 0.2072107928688638, 0.19060563936363906, 0.06973817740799859], [0.03919823648175225, 0.04672772171034012, 0.036030423652846366, 0.055360646947519854, 0.05336505637387745, 0.02675818272109609, 0.014751725029782392, 0.09906672552460805, 0.15312513336539268, 0.5921569594647735, 14.783446826040745, 71.98892310261726, 60.826482474803925, 45.833334401249886, 34.16709400713444, 24.87615555524826, 33.76724526286125, 39.48001071810722, 66.27842992544174, 75.61418697237968, 1.3415722805075347, 0.07401445458526723, 0.6210700829979032, 10.925777927041054, 5.851222425699234, 74.52238395810127, 88.96323546767235, 74.35239627957344, 80.80460965633392, 79.05978128314018, 71.89962029457092, 86.64765492081642, 78.2765445113182, 73.67797806859016, 67.7835975587368, 66.8220667541027, 65.96272006630898, 63.74798230826855, 57.748412042856216, 52.74708241224289, 52.95558102428913, 52.70802050828934, 56.67689993977547, 56.70143902301788, 58.79085950553417, 57.98741541802883, 55.06346091628075, 53.43175247311592, 53.717918917536736, 54.01701606810093, 51.87126360833645, 54.60637204349041, 52.407080456614494, 51.49846941232681, 45.75954616069794, 47.80575156211853, 48.18807564675808, 52.029403522610664, 48.546404018998146, 50.83223596215248, 49.55221764743328, 44.99963253736496, 44.16700981557369, 46.08334958553314, 43.735474571585655, 42.27351061999798, 45.26175767183304, 50.81683158874512, 56.155552715063095, 58.414873480796814, 62.65171833336353, 61.67892873287201, 62.970399633049965, 63.43850411474705, 63.20022650063038, 59.00881960988045, 57.637609988451004, 56.651661694049835, 55.91889001429081, 53.88790659606457, 56.940172612667084, 53.90329197049141, 52.30687603354454, 55.232228860259056, 57.971528470516205, 36.87031835317612, 46.26315973699093, 46.19317889213562, 45.40230832993984, 33.23697991669178, 44.97527964413166, 60.11402830481529, 56.37510873377323, 60.836198553442955, 57.56910726428032, 54.74552817642689, 53.15515011548996, 51.35359838604927, 53.538678735494614, 55.619458481669426, 58.86422976851463, 60.798561573028564, 57.431068271398544, 54.830822199583054, 44.783568531274796, 52.5665844976902, 63.35251472890377, 58.61888833343983, 58.81199777126312, 55.234877318143845, 45.7690304517746, 47.05525383353233, 50.96963658928871, 51.21493622660637, 50.24584002792835, 48.46111759543419, 47.34966583549976, 46.204829066991806, 47.63055056333542, 45.892178043723106, 45.98137445747852, 45.620317831635475, 43.55773150920868, 49.30499531328678, 47.56181985139847, 47.82861493527889, 47.16089956462383, 49.57969777286053, 48.079827055335045, 50.21487928926945, 49.25180196762085, 48.85158844292164, 46.46175988018513, 50.73392763733864, 49.56658847630024, 53.23989696800709, 54.88096050918102, 56.2734641879797, 55.5605274438858, 56.7562472820282, 60.352514907717705, 64.60749238729477, 65.07479891180992, 66.6686537861824, 60.510263442993164, 65.32047092914581, 66.07170581817627, 71.24046966433525, 72.0528356730938, 63.71479868888855, 5.395757965743542, 0.33126684778835624, 1.4664391614496708, 0.4186337784631178, 0.26896690484136343, 19.003279991447926, 67.28057295084, 67.1318793296814, 53.494920283555984, 45.712234899401665, 47.51453898847103, 22.096918188035488, 9.423282500356436, 37.81666897237301, 49.513676315546036, 71.26772180199623, 17.392447628080845, 0.5576951242983341, 0.15889513859292492, 0.03254657465731725, 0.039388927616528235, 0.021129389642737806, 0.04741492448374629, 0.07675987406400964, 0.03761877182114404, 0.06541517461300828, 0.05175556070753373, 0.049617585391388275, 0.007955411201692186, 0.006637735887125018, 0.05100727175886277, 0.024537426397728268, 0.08315163577208295, 0.04186648002360016, 0.14492889895336702, 0.5750263505615294, 18.153634183108807, 85.54131388664246, 67.75261402130127, 55.342411547899246, 43.85989509522915, 28.429299294948578, 31.095741614699364, 45.804486349225044, 73.05940926074982, 79.08179730176926, 1.3251203508116305, 0.17716733389534056, 2.528382665477693, 9.208296686410904, 8.812502324581146, 80.48044145107269, 89.22823324799538, 81.18256017565727, 79.90304723381996, 84.1477158665657, 74.24643516540527, 88.49820122122765, 80.91047197580338, 78.37963297963142, 71.27554938197136, 72.04286500811577, 68.1597013771534, 66.44155517220497, 61.4495350420475, 56.357017904520035, 56.16972975432873, 56.36549524962902, 58.83838355541229, 59.363538175821304, 60.40982723236084, 60.06616987287998, 57.61631593108177, 56.09992370009422, 57.1777206659317, 57.242096811532974, 54.468238055706024, 57.074214220047, 54.39407743513584, 53.70775826275349, 49.665018394589424, 50.17938919365406, 51.29408597946167, 54.287413358688354, 51.096371188759804, 51.90343268215656, 53.06229829788208, 47.64637291431427, 46.55339956283569, 47.74062305688858, 48.47320094704628, 47.07284688949585, 47.45992831885815, 53.6858182400465, 57.84997679293156, 61.63566045463085, 65.61222687363625, 65.39255306124687, 66.02583467960358, 67.41990387439728, 64.37404811382294, 63.35120379924774, 60.59945225715637, 60.00508055090904, 58.90714846551418, 58.0595887452364, 57.64220394194126, 56.95406846702099, 56.20723754167557, 57.35427439212799, 57.31287181377411, 39.53660108149052, 48.070798739790916, 46.5467195212841, 48.89155849814415, 38.77536132931709, 46.664809584617615, 59.857830852270126, 61.12158603966236, 60.45808084309101, 60.30487686395645, 59.84707362949848, 55.47446206212044, 54.104411378502846, 57.71948039531708, 57.15103089809418, 61.52624152600765, 63.0288290977478, 59.10526983439922, 53.63330505788326, 45.47124423086643, 58.02403785288334, 65.04357978701591, 59.658672139048576, 60.386773869395256, 56.790434047579765, 49.82519879937172, 49.18818578124046, 54.468694031238556, 54.56118106842041, 52.935373708605766, 51.739167496562004, 48.544173538684845, 48.772393092513084, 51.08474001288414, 48.589930683374405, 46.993883326649666, 47.767039239406586, 45.95526605844498, 49.135064631700516, 49.47728946805, 50.87997280061245, 51.301096603274345, 52.46644847095013, 50.29059782624245, 53.36059749126434, 51.23284466564655, 50.7713670283556, 50.56335099041462, 52.64434352517128, 52.620929181575775, 55.98052270710468, 56.7750258743763, 60.9044086933136, 58.24778504669666, 61.685673370957375, 62.11164191365242, 66.10642835497856, 65.11548712849617, 69.28492739796638, 62.287652269005775, 68.55024442076683, 66.79566577076912, 74.71664473414421, 74.85713839530945, 68.80509674549103, 7.656721193343401, 0.35832317720633, 3.571062390692532, 0.26768610638100654, 0.3910682169953361, 18.959538638591766, 74.66407835483551, 72.66120582818985, 62.13865466415882, 51.30126379430294, 36.813059225678444, 23.17162211984396, 20.558312349021435, 43.18831533193588, 56.803030371665955, 78.06331515312195, 21.346705444157124, 0.7388812769204378, 0.03569059794244822, 0.08910389762604609, 0.03469415336439852, 0.08644072295282967, 0.02674356241186615, 0.040401306105195545, 0.022361749979609158, 0.03927058474801015, 0.2057197439717129, 0.09699496091343462, 0.11456657623057254, 0.1441025620442815, 0.18116534280125052, 0.14916069922037423, 0.17482358700362965, 0.20253352588042617, 0.31913881888613105, 0.8203082357067615, 21.794693805277348, 96.4862009882927, 77.02675357460976, 64.49265494942665, 47.71155461668968, 36.19554676115513, 50.23707389831543, 60.902820378541946, 77.41608068346977, 91.69992461800575, 1.9375938107259572, 0.32948308100458235, 3.646722505800426, 20.667782574892044, 10.70935484021902, 84.21278357505798, 95.01114293932915, 84.74765047430992, 84.66639563441277, 85.77730402350426, 82.3018205165863, 90.84304019808769, 84.67961132526398, 81.68160259723663, 75.49530655145645, 77.09001258015633, 71.11078262329102, 70.53096413612366, 65.39327502250671, 58.7353178858757, 59.334804117679596, 59.465976879000664, 61.63259781897068, 62.9843220859766, 63.17902743816376, 63.558752462267876, 61.53711274266243, 57.61789284646511, 58.887537717819214, 61.30691349506378, 56.82581774890423, 59.46705222129822, 55.8126325160265, 57.181102484464645, 50.28384938836098, 54.3184918910265, 52.76375211775303, 56.39063090085983, 55.27499556541443, 56.97404019534588, 56.34726382791996, 51.3460747897625, 50.48303849995136, 50.50492912530899, 51.62509001791477, 49.74088132381439, 50.820285603404045, 58.11373583972454, 62.233147993683815, 64.61594313383102, 68.76359537243843, 66.64897084236145, 68.67050796747208, 68.8975077867508, 68.5513387620449, 64.35357481241226, 64.62820127606392, 61.9073610752821, 57.70917534828186, 60.87386593222618, 60.712553188204765, 58.376662731170654, 58.15071165561676, 60.098285749554634, 59.503032490611076, 42.39480771124363, 49.951971396803856, 48.16946044564247, 51.82006135582924, 45.82541182637215, 51.49406164884567, 65.22929862141609, 62.16284416615963, 66.52193605899811, 62.34110400080681, 60.5806090682745, 57.82785817980766, 55.718994140625, 60.33029370009899, 61.51617966592312, 65.56019246578217, 66.01223140954971, 61.14495478570461, 55.085085555911064, 48.639119043946266, 60.41976369917393, 65.56396186351776, 65.67905768752098, 64.75601881742477, 61.03960543870926, 52.83847890794277, 53.141657039523125, 56.65941707789898, 57.40885466337204, 55.88658034801483, 55.431824550032616, 52.39031955599785, 53.07810164988041, 54.25433233380318, 51.64523273706436, 50.03077156841755, 52.25829564034939, 49.4182026386261, 53.93162705004215, 52.335940673947334, 52.05763220787048, 53.20458926260471, 55.148010179400444, 53.7226914614439, 57.83888518810272, 55.43652109801769, 53.25546853244305, 52.22830004990101, 57.133605033159256, 55.76390013098717, 61.36500097811222, 61.77512437105179, 64.53249961137772, 62.304964140057564, 64.3783874809742, 66.29039168357849, 71.98519170284271, 71.5238356590271, 74.6897953748703, 67.1396917104721, 72.64829412102699, 72.83158108592033, 78.53372991085052, 78.78506362438202, 73.82406502962112, 7.357482500374317, 1.9762975838966668, 5.891119334846735, 1.1924261273816228, 0.4756376665318385, 25.154707208275795, 83.66935953497887, 79.43106696009636, 69.91887778043747, 64.09031733870506, 64.28091511130333, 31.497936733067036, 19.539664909243584, 52.29465588927269, 64.95294705033302, 88.41442331671715, 27.51011721789837, 0.9786944836378098, 0.36317432939540595, 0.25515354762319475, 0.1735757547430694, 0.19090448739007115, 0.16250154585577548, 0.14312368410173804, 0.0876024215540383, 0.16449810122139752], [0.030916560463083442, 0.01052830824846751, 0.03256867581512779, 0.0562830066337483, 0.04109303597942926, 0.0607541866338579, 0.050922262453241274, 0.08793233588221483, 0.16091579891508445, 0.17011961754178628, 24.29155122488737, 61.59010849893093, 60.02409093081951, 46.504625380039215, 32.00899600982666, 39.69874978065491, 46.86799228191376, 43.28891113400459, 84.30971637368202, 44.23976831138134, 0.03413908627408091, 0.12763084669131786, 2.8870188212022185, 4.361876668408513, 19.191172309219837, 89.8840020596981, 80.90003773570061, 78.77972111105919, 73.91738042235374, 88.07488113641739, 77.81762793660164, 78.58140215277672, 79.76794168353081, 73.13431084156036, 69.07328635454178, 61.606379225850105, 59.44997973740101, 55.76373673975468, 54.885995239019394, 58.75660814344883, 60.4517275840044, 63.00727665424347, 62.67036013305187, 63.72480735182762, 61.114773005247116, 61.938633397221565, 58.687163069844246, 56.102351769804955, 51.842328161001205, 51.69408671557903, 51.64194591343403, 50.91549329459667, 52.30893172323704, 48.13848830759525, 47.66911469399929, 49.57970157265663, 49.92797188460827, 51.91157564520836, 47.3765379935503, 45.654987171292305, 48.5806629806757, 44.95441496372223, 45.094042271375656, 43.618972823023796, 41.27607934176922, 42.270052805542946, 44.17609132826328, 53.91078896820545, 59.32221159338951, 60.440153405070305, 61.25877767801285, 63.3726042509079, 64.12487268447876, 64.86783921718597, 63.35477560758591, 59.57070305943489, 57.04966753721237, 64.94201883673668, 61.918156296014786, 69.78031441569328, 55.828770250082016, 53.884585574269295, 62.959748804569244, 62.141094133257866, 49.36022914946079, 36.26024208962917, 48.59820283949375, 43.31780858337879, 44.6048679202795, 33.269707560539246, 35.24505436420441, 51.66253700852394, 62.012087255716324, 58.237958773970604, 60.754544734954834, 63.03187273442745, 61.73431076109409, 60.09866572916508, 55.560751631855965, 58.8643741607666, 59.32669535279274, 56.60796783864498, 57.199383303523064, 52.96986825764179, 55.900225415825844, 64.20005545020103, 58.32712858915329, 57.329822704195976, 53.901547864079475, 48.98175045847893, 47.58223615586758, 49.4456447660923, 49.86261919140816, 49.0475857257843, 48.941863998770714, 47.782671600580215, 47.108249589800835, 45.102333426475525, 46.95346489548683, 48.012031093239784, 43.506852239370346, 43.05665239691734, 41.99076019227505, 47.955273538827896, 48.94086845219135, 47.26301908493042, 46.731036230921745, 46.341241747140884, 49.39036153256893, 48.868512734770775, 49.98015448451042, 49.06851500272751, 48.97731229662895, 51.55753344297409, 53.28092336654663, 51.986743211746216, 51.248572021722794, 52.34456241130829, 54.924395978450775, 53.91707003116608, 52.81524695456028, 54.484865963459015, 55.34437604248524, 57.145240008831024, 55.06930500268936, 57.19170391559601, 59.98731650412083, 68.47387611865997, 69.49067115783691, 72.99121052026749, 18.948768116533756, 0.8088514942210168, 2.5506815314292908, 0.4891588550526649, 0.12225174548802897, 2.5166249088943005, 62.01632782816887, 63.4369195997715, 65.53368508815765, 40.49351133406162, 58.484812527894974, 35.49704164266586, 18.331882618367672, 33.10937136411667, 43.0319195240736, 61.17724545300007, 43.63296367228031, 0.3393335180589929, 0.05002178128052037, 0.08826359349768609, 0.08041628723731264, 0.034961730998475105, 0.026766750816022977, 0.04843325870751869, 0.023141337151173502, 0.023804063894203864, 0.06684016494546086, 0.0521311022748705, 0.01661260837863665, 0.04271375662938226, 0.02946037580841221, 0.015950814886309672, 0.06579469409189187, 0.04282213616534136, 0.13392813300015405, 0.23378772457363084, 28.9554475620389, 72.0423786342144, 69.69307109713554, 57.04830341041088, 45.75119040906429, 35.9310619533062, 45.76674297451973, 53.08638520538807, 92.77000799775124, 47.90563300251961, 0.1171141465601977, 0.10566691940766759, 5.080885961651802, 5.955527303740382, 22.930853739380836, 93.79287511110306, 80.9981332719326, 83.3877794444561, 76.2329913675785, 90.94112813472748, 78.15805166959763, 84.18322116136551, 82.59422242641449, 76.72152355313301, 69.76667314767838, 64.70443278551102, 61.460695043206215, 58.43772165477276, 56.46942727267742, 60.524660870432854, 62.05747961997986, 66.36302098631859, 65.00285357236862, 67.47567728161812, 64.36644092202187, 64.63722959160805, 61.13039016723633, 59.14518289268017, 54.511510133743286, 54.486659467220306, 53.57569254934788, 53.71333636343479, 54.14278171956539, 50.97087152302265, 50.411556735634804, 52.84935012459755, 52.56509117782116, 54.678940549492836, 50.265823155641556, 48.435689359903336, 52.464879155159, 47.5543000549078, 46.89912401139736, 45.73005974292755, 45.706953182816505, 45.10792292654514, 47.12902307510376, 56.096933260560036, 61.831650137901306, 63.30016873776913, 62.842832878232, 65.34948617219925, 65.08552193641663, 66.71549007296562, 67.63669744133949, 61.62848263978958, 60.04014506936073, 67.28061094880104, 64.76231127977371, 72.16632038354874, 60.8942898362875, 55.02838879823685, 63.584750667214394, 65.87092459201813, 53.89392547309399, 39.4528079777956, 48.64839434623718, 44.0633399784565, 46.07573479413986, 37.51513995230198, 37.915965244174004, 54.6289998292923, 63.01714092493057, 58.94234977662563, 60.12524530291557, 66.55816331505775, 67.32119277119637, 62.72425264120102, 59.5295512676239, 61.147641241550446, 59.097715839743614, 59.261536449193954, 57.970620319247246, 55.67258723080158, 59.5208877325058, 66.91633969545364, 60.3820925205946, 59.04345855116844, 55.896155834198, 50.187539756298065, 50.25007300078869, 53.20476025342941, 52.768980637192726, 52.783024683594704, 52.633989080786705, 49.39499728381634, 50.20415246486664, 46.945698112249374, 48.69144223630428, 51.47726275026798, 46.28842458128929, 46.252824291586876, 44.62472565472126, 52.055147141218185, 50.427052304148674, 51.35509170591831, 49.07543443143368, 49.18240249156952, 52.725210785865784, 52.711037546396255, 51.7034038156271, 51.440404728055, 52.516199201345444, 53.374789729714394, 55.90478517115116, 55.3372286260128, 55.18366366624832, 56.46862551569939, 56.79947756230831, 55.65217472612858, 55.41182242333889, 56.627324000000954, 56.59723721444607, 58.2375255972147, 56.19098201394081, 59.986860528588295, 64.74904239177704, 72.4000534415245, 70.319794267416, 77.39270433783531, 22.382554560899734, 0.07809813701896928, 3.1501257279887795, 1.1097280774265528, 0.05934245476964861, 2.149563180282712, 65.37865340709686, 71.35276883840561, 72.82699853181839, 51.804820373654366, 48.85932482779026, 24.890351593494415, 28.437037579715252, 43.768335208296776, 52.47185938060284, 68.80382761359215, 50.53544528782368, 0.5499639641493559, 0.059782837779494, 0.039747117771185, 0.027693481752066873, 0.0639775232411921, 0.03411760480958037, 0.08657405720441602, 0.05019595591875259, 0.036777885106857866, 0.14584899879992008, 0.16299075476126745, 0.08197450792067684, 0.13661470758961514, 0.11101453870651312, 0.13945938932010904, 0.176978012023028, 0.2171418271609582, 0.40881442255340517, 0.42857938853558153, 37.01045863330364, 84.70674946904182, 78.46126779913902, 64.03087332844734, 47.08422727882862, 55.08716784417629, 72.45754435658455, 60.06863214075565, 100.87075531482697, 55.1857041567564, 0.6597553915344179, 0.15693773893872276, 8.360942155122757, 13.579954504966736, 23.883618414402008, 98.82068932056427, 82.88697391748428, 85.84824621677399, 80.80366730690002, 96.54790967702866, 83.1986103951931, 87.99730449914932, 83.4466078877449, 82.1471156179905, 74.00536850094795, 69.33592826128006, 65.2753521502018, 62.63273075222969, 58.98238442838192, 63.50569970905781, 64.55836102366447, 67.80788585543633, 68.30867618322372, 72.51593202352524, 68.80851656198502, 68.73797714710236, 64.248738437891, 62.05086037516594, 56.72008082270622, 56.90002776682377, 55.20167089998722, 55.69380909204483, 56.281565353274345, 51.743233278393745, 52.90826216340065, 56.14621661603451, 56.04340173304081, 58.41727115213871, 51.26655265688896, 49.56485576927662, 54.657133519649506, 51.82283140718937, 52.36093953251839, 50.91711200773716, 48.86241406202316, 47.03099973499775, 49.109552800655365, 57.58688651025295, 63.49353276193142, 65.81815302371979, 65.13525366783142, 68.37496742606163, 68.97051706910133, 69.92608979344368, 69.03362408280373, 63.16900737583637, 62.111911699175835, 71.82898208498955, 66.62992626428604, 74.00397777557373, 62.427032589912415, 56.94759741425514, 66.30545407533646, 67.7620755136013, 54.26667407155037, 42.6759622246027, 48.91778849065304, 46.26307234168053, 47.4018332362175, 42.47059464454651, 41.312640979886055, 57.03072935342789, 66.23683735728264, 63.29230695962906, 67.18954503536224, 69.55698519945145, 69.21979889273643, 67.31486991047859, 61.9068519026041, 66.9487975537777, 62.85889081656933, 63.783369809389114, 59.39527027308941, 59.603035524487495, 61.93186596035957, 67.97503888607025, 64.42440301179886, 63.83869484066963, 57.199375703930855, 53.86506222188473, 53.21093492209911, 55.04825793206692, 56.05236545205116, 56.42158783972263, 55.71186192333698, 52.49218448996544, 54.365122988820076, 49.905876070261, 51.00537747144699, 52.432250306010246, 48.60601142048836, 48.98233562707901, 46.731207221746445, 54.551134407520294, 52.866418808698654, 54.39871318638325, 52.19698593020439, 50.996470749378204, 55.793508142232895, 54.438713639974594, 55.99664144217968, 56.40996426343918, 57.12516188621521, 57.00034238398075, 61.674414575099945, 58.801597729325294, 57.09000997245312, 58.16906467080116, 62.283278703689575, 60.25349222123623, 58.780888840556145, 61.13570608198643, 62.06382907927036, 64.17956694960594, 61.69334135949612, 63.800058513879776, 67.281773686409, 76.79717749357224, 73.59583407640457, 81.10158652067184, 21.81341540068388, 1.7888017510995269, 6.7554432805627584, 1.094996624160558, 0.16418737883213907, 3.8489906396716833, 76.97094976902008, 74.77671951055527, 80.8722460269928, 58.76853570342064, 79.50470700860023, 47.850216776132584, 27.588265724480152, 45.61121352016926, 61.20568312704563, 76.03676229715347, 64.92741242051125, 0.9233756270259619, 0.2032661295379512, 0.15171610662946478, 0.17031002294970676, 0.2611659234389663, 0.11072093024267815, 0.18593285494716838, 0.3086736163822934, 0.16158686368726194], [0.017476371795055456, 0.06231347972061485, 0.09303851969889365, 0.060817105913884006, 0.04125010411371477, 0.019607074063969776, 0.06631911790464073, 0.07556877157185227, 0.10093589866301045, 0.0844092272745911, 37.76485875248909, 59.72565494477749, 57.19417758285999, 42.14939787983894, 35.43375223875046, 40.15771575272083, 46.46039955317974, 48.46637651324272, 88.70899111032486, 18.032893761992455, 0.20585641788784415, 0.21436721901409328, 4.60805500857532, 2.1639435086399317, 40.17524041235447, 93.56671124696732, 78.97815406322479, 75.45189008116722, 74.7020535171032, 84.30838644504547, 77.08568841218948, 79.53163996338844, 77.07363545894623, 71.96578994393349, 62.524292171001434, 58.87634351849556, 55.50470843911171, 59.81342263519764, 63.58505465090275, 67.51911655068398, 66.88635170459747, 68.08140277862549, 72.83543407917023, 80.10508999228477, 88.82228583097458, 73.54833662509918, 61.85773193836212, 60.820076018571854, 52.30100154876709, 52.89136826992035, 50.37372596561909, 51.418894082307816, 52.318207025527954, 51.04374021291733, 48.41415211558342, 48.93032781779766, 49.26594860851765, 52.41310693323612, 50.34735158085823, 48.13164107501507, 48.070601150393486, 47.9222647100687, 43.83631356060505, 44.48633328080177, 43.62035974860191, 41.62476383149624, 42.71191969513893, 53.478208780288696, 60.78428953886032, 64.10608649253845, 59.72058981657028, 63.85302007198334, 63.063449040055275, 65.16584202647209, 56.8080423027277, 56.543785482645035, 61.50961361825466, 63.62247884273529, 60.46010233461857, 64.50894087553024, 65.94779446721077, 62.13653437793255, 54.45311866700649, 61.82888388633728, 49.73491944372654, 43.975682482123375, 46.94320924580097, 41.17961011826992, 41.44665978848934, 39.40939910709858, 35.66143602132797, 49.097769632935524, 57.02231280505657, 54.578283950686455, 32.86480128765106, 36.89270295202732, 58.13358597457409, 55.4638796299696, 62.38141603767872, 54.29024800658226, 48.69131304323673, 59.80985462665558, 59.9092572927475, 58.23850214481354, 61.78574860095978, 59.44181777536869, 58.596085757017136, 53.967884704470634, 49.466479048132896, 47.841826826334, 51.55657209455967, 47.64568515121937, 50.891767367720604, 48.49121958017349, 49.960665330290794, 46.69825918972492, 45.05687266588211, 46.156514659523964, 47.71084025502205, 49.28637631237507, 46.89361050724983, 44.399640932679176, 42.80818372964859, 46.74925625324249, 50.155218690633774, 46.441666558384895, 47.45635651051998, 47.104666382074356, 49.01467189192772, 48.01879093050957, 50.29578074812889, 48.11601631343365, 49.29529443383217, 48.57163466513157, 49.59889814257622, 48.56146641075611, 48.94633635878563, 49.11784775555134, 50.64228415489197, 49.53359864652157, 49.58243362605572, 50.577744618058205, 52.408436983823776, 53.32860700786114, 58.21275092661381, 61.25498168170452, 68.35379496216774, 69.05133873224258, 71.63396134972572, 72.88901880383492, 36.157727390527725, 0.20854453614447266, 1.9418647815473378, 0.5134540982544422, 0.18619545648107305, 0.17559592524776235, 34.20315407216549, 68.03753033280373, 66.06844559311867, 51.12197421491146, 49.65101234614849, 42.244145795702934, 18.454937115311623, 24.740303345024586, 39.70839366316795, 52.35603779554367, 63.160682022571564, 1.659178000409156, 0.11464145893114619, 0.010339353739254875, 0.10693982883822173, 0.04677822485973593, 0.06578785891178995, 0.08650758303701878, 0.0742522683867719, 0.056736855913186446, 0.049333238930557854, 0.02785381719149882, 0.08654557357658632, 0.020986344388802536, 0.07103599331458099, 0.06733140733558685, 0.10453954513650388, 0.033648355965851806, 0.13715212640818208, 0.13636133837280795, 43.93051430583, 70.56007817387581, 64.61359485983849, 47.95594610273838, 44.479611441493034, 40.445896089076996, 47.15592563152313, 60.24694137275219, 93.90741616487503, 19.865769110620022, 0.40947900095488876, 0.08445275423582643, 9.60605839267373, 2.875156095251441, 43.27463909983635, 94.15808871388435, 80.6752797961235, 79.15143996477127, 77.60749161243439, 84.98401299118996, 76.79883420467377, 84.68879163265228, 79.92573961615562, 75.44344693422318, 66.01182103157043, 61.01777940988541, 57.8154556453228, 64.72188144922256, 68.19664299488068, 70.95334947109222, 70.44210970401764, 71.27506300806999, 75.27357324957848, 80.19818499684334, 89.5073738694191, 77.09482312202454, 65.41674256324768, 64.14647072553635, 55.944740027189255, 56.22032403945923, 56.66113458573818, 55.30228570103645, 52.54228860139847, 53.165299370884895, 51.275489777326584, 52.575008645653725, 51.007980331778526, 54.88674379885197, 50.68900264799595, 49.93913568556309, 51.620032489299774, 50.6073222309351, 45.4923976957798, 46.80784910917282, 46.49396315217018, 45.1096860319376, 44.74861040711403, 55.45553907752037, 62.009970769286156, 66.80711075663567, 62.74954788386822, 66.90270602703094, 65.20818695425987, 67.31960445642471, 60.163843631744385, 58.8485936075449, 63.46063032746315, 66.80695876479149, 61.65419206023216, 63.93362134695053, 67.67632931470871, 64.77755606174469, 56.90729297697544, 65.17046257853508, 51.025831773877144, 46.35223835706711, 47.330218479037285, 41.92144051194191, 43.56894850730896, 44.118836000561714, 40.11071987450123, 52.58548088371754, 58.97204898297787, 56.5400692820549, 36.63248531520367, 37.04070881009102, 59.52270783483982, 55.22697754204273, 66.18714362382889, 56.63500718772411, 50.80560699105263, 60.59439092874527, 62.61477291584015, 60.15594385564327, 61.964521408081055, 60.66640466451645, 62.24995829164982, 57.5768056511879, 50.8058425784111, 49.31302048265934, 55.17801716923714, 50.76138496398926, 52.310687229037285, 50.82184351980686, 51.426953449845314, 50.79264968633652, 48.275204971432686, 48.74408461153507, 49.66222934424877, 50.21242842078209, 47.89316587150097, 47.47101232409477, 45.46904794871807, 50.404192730784416, 53.08445870876312, 49.05691422522068, 51.203612834215164, 50.538203939795494, 51.70540250837803, 53.620495945215225, 53.32226134836674, 51.68746367096901, 50.097055211663246, 51.53189241886139, 52.305834889411926, 51.62757508456707, 51.66710056364536, 52.64525167644024, 54.39025864005089, 52.911377996206284, 53.266700729727745, 52.130633890628815, 55.561386197805405, 56.514253467321396, 62.82385669648647, 64.24749970436096, 70.77598258852959, 70.72596967220306, 75.04636824131012, 74.7857554256916, 40.51555775105953, 0.5952726735267788, 1.847281325608492, 1.9642984215170145, 0.20740335050504655, 0.2339543664129451, 33.50603207945824, 74.56436410546303, 73.93248081207275, 60.841548666357994, 50.78816972672939, 33.648619428277016, 22.532982788980007, 33.95198754966259, 45.80884091556072, 60.928184017539024, 71.66280940175056, 2.2963497787714005, 0.194048403063789, 0.02903346834500553, 0.024898716874304228, 0.04939393918903079, 0.05471406191645656, 0.11852106559672393, 0.08529331811587326, 0.07379036309430376, 0.15519664564635605, 0.11760872119339183, 0.22144284012028947, 0.2623674605274573, 0.21969714551232755, 0.37623063661158085, 0.1946475388831459, 0.09873802831862122, 0.3501304902601987, 0.3098350774962455, 52.23756015300751, 83.84392976760864, 74.10091057419777, 57.56005235016346, 50.75594745576382, 56.469944044947624, 66.35472983121872, 65.55547311902046, 107.39157021045685, 23.38661838322878, 0.3458464576397091, 0.40926576708443463, 14.895647205412388, 7.841215543448925, 41.98208525776863, 102.98300877213478, 83.96285578608513, 83.33831369876862, 81.13668903708458, 89.14491131901741, 78.98857310414314, 87.54978731274605, 83.18752259016037, 80.65218463540077, 68.1062762439251, 64.90326091647148, 61.63486249744892, 67.11706012487411, 72.4749094247818, 74.18035671114922, 74.92246448993683, 75.5771541595459, 77.31837272644043, 80.21797433495522, 87.61363908648491, 79.65025439858437, 68.25019732117653, 67.53604844212532, 58.68000045418739, 59.39318798482418, 57.42908477783203, 58.461557775735855, 56.69786721467972, 57.96748548746109, 54.72369834780693, 57.406639382243156, 55.70165567100048, 58.00351895391941, 54.08117562532425, 53.85347284376621, 54.38942268490791, 56.16141200065613, 50.10496638715267, 49.81734462082386, 48.77881854772568, 47.01907217502594, 46.86114124953747, 59.65034298598766, 67.0775118470192, 71.0588014125824, 64.49314132332802, 70.12912049889565, 68.14008682966232, 69.06782984733582, 63.31528812646866, 62.4079804122448, 67.13543593883514, 69.60552379488945, 64.99270811676979, 67.3020949959755, 69.17939946055412, 67.78498068451881, 58.617155626416206, 69.45087969303131, 55.35238981246948, 50.656654983758926, 46.7033851146698, 43.823789432644844, 45.83816394209862, 47.45544455945492, 44.24997456371784, 55.90796560049057, 60.32382644712925, 60.417711809277534, 37.69537188112736, 41.57387316226959, 62.593330666422844, 58.66411730647087, 68.05745646357536, 58.9202843606472, 52.05023020505905, 62.18606472015381, 64.37175303697586, 63.894316256046295, 65.78362047672272, 66.28580152988434, 64.6013443171978, 60.859711691737175, 53.62662881612778, 52.28415705263615, 58.98312158882618, 53.394651263952255, 55.263637974858284, 51.6928593814373, 53.75160411000252, 52.51042351126671, 50.44029459357262, 53.48794765770435, 52.93348141014576, 53.365271240472794, 51.73944868147373, 50.56744337081909, 49.304896518588066, 53.313495218753815, 56.43993705511093, 51.62649594247341, 51.99952192604542, 53.45478683710098, 54.57851193845272, 55.987145751714706, 57.35984109342098, 54.4333179295063, 55.03238998353481, 54.958035573363304, 55.50829544663429, 56.55292019248009, 54.634296745061874, 55.692851543426514, 57.30911381542683, 56.03375785052776, 54.98726360499859, 55.31332030892372, 58.34186039865017, 58.03072549402714, 64.4819775223732, 67.60646626353264, 75.51500469446182, 75.4076300561428, 78.89420136809349, 78.00346836447716, 43.372719436883926, 0.9469181543681771, 7.195084914565086, 3.233748315833509, 0.6431304523721337, 0.29238685907330364, 43.05120728909969, 80.77396810054779, 80.2961665391922, 69.12028223276138, 70.42190238833427, 61.24828264117241, 25.820568278431892, 35.88696911931038, 55.61297222971916, 70.24661019444466, 82.82485485076904, 4.359370702877641, 0.3580359066836536, 0.11324814346153289, 0.2369608957087621, 0.15573093260172755, 0.24543844861909747, 0.26816238707397133, 0.21491398889338598, 0.11092348460806534], [0.06515724860946648, 0.02572386078099953, 0.026948627091769595, 0.10448133849422447, 0.049941295364988036, 0.0617030706780497, 0.05899265830521472, 0.06227257996215485, 0.024390466314798687, 0.3442781214835122, 36.25608131289482, 51.11143738031387, 45.332593470811844, 52.78983011841774, 36.42023250460625, 37.61239193379879, 47.25722059607506, 59.53331306576729, 77.70437121391296, 4.830487947911024, 0.11751826081308536, 0.39962791081052274, 1.7434591404162347, 4.306390145793557, 66.11425593495369, 85.77241748571396, 80.33051669597626, 76.79590836167336, 74.81707334518433, 85.33148914575577, 78.90047863125801, 80.82409501075745, 76.56274527311325, 73.54506120085716, 69.17047753930092, 66.62484213709831, 64.23414722084999, 70.9653340280056, 74.17553097009659, 75.75488582253456, 80.48352688550949, 86.01970821619034, 84.31396454572678, 78.66339415311813, 77.42890879511833, 71.25930145382881, 64.90451484918594, 65.68892195820808, 57.13548593223095, 53.98436442017555, 52.130223512649536, 53.79997171461582, 51.11217454075813, 50.686760768294334, 46.56485594809055, 49.39348876476288, 47.95239709317684, 47.93141461908817, 47.86782883107662, 44.40126344561577, 46.51939898729324, 45.866537019610405, 43.47014620900154, 44.38159570097923, 41.37959338724613, 43.557085543870926, 42.487621530890465, 48.010815158486366, 57.42386765778065, 60.89381106197834, 60.40157787501812, 62.763565331697464, 63.062206506729126, 60.65802611410618, 50.12938767671585, 56.32812425494194, 63.19201894104481, 61.37009650468826, 61.33693188428879, 62.3735124617815, 60.32276250422001, 64.82709780335426, 64.05310973525047, 61.688204035162926, 51.32800675928593, 49.72438640892506, 46.78224228322506, 42.70780451595783, 43.174073696136475, 41.692814379930496, 40.57012662291527, 51.86559431254864, 55.34660652279854, 62.4887602776289, 50.05280278623104, 31.746943071484566, 50.08034370839596, 56.70652695000172, 64.09132808446884, 54.93469722568989, 57.07322247326374, 60.01032046973705, 57.85245805978775, 56.0900404304266, 55.09955897927284, 56.89082846045494, 53.10526259243488, 50.32452620565891, 48.826304599642754, 48.1321806460619, 51.85911945998669, 50.44920891523361, 48.08997631072998, 47.58020706474781, 46.7550053447485, 44.7315227240324, 46.6464451700449, 45.52114315330982, 48.21840561926365, 52.06849202513695, 45.6663865596056, 46.34873494505882, 43.22619549930096, 44.19811874628067, 48.47345173358917, 46.809217035770416, 47.074351608753204, 47.22079195082188, 49.41242694854736, 49.871286526322365, 49.33961145579815, 49.92451027035713, 50.5502150952816, 46.315817311406136, 49.08271484076977, 49.45307716727257, 50.326490700244904, 49.38446804881096, 50.49338534474373, 52.9241719096899, 54.48961190879345, 55.12543559074402, 60.286580845713615, 61.74155317246914, 65.75478002429008, 64.86509576439857, 67.89690747857094, 69.76826146245003, 73.60570594668388, 67.92727544903755, 49.78910073637962, 1.564279398880899, 1.0973912081681192, 1.9064124464057386, 0.1655752692022361, 0.2937234373530373, 8.93816253170371, 69.58822712302208, 63.6342354118824, 60.655373856425285, 42.01856330037117, 44.09149266779423, 34.48294445872307, 17.590874880552292, 40.552012994885445, 51.456641256809235, 71.46352529525757, 10.365574937313795, 0.41912478336598724, 0.15665434242691845, 0.041748604708118364, 0.04146698563999962, 0.034831573138944805, 0.026589999069983605, 0.045561332735815085, 0.016836056056490634, 0.04967218148522079, 0.05671547092788387, 0.06665692868409678, 0.021186052617849782, 0.08183463534805924, 0.04948438101564534, 0.05792139781988226, 0.0638920500932727, 0.09732639664434828, 0.4458060610340908, 44.01022642850876, 63.3882100135088, 56.04802988469601, 62.53985993564129, 41.81976556777954, 31.51361469179392, 52.61149048805237, 72.32632979750633, 85.71061000227928, 5.316183110699058, 0.4604202846530825, 0.8322135312482715, 3.1119945365935564, 6.822900110855699, 70.25696083903313, 87.79058039188385, 83.18393558263779, 80.20729690790176, 76.95530220866203, 89.24806818366051, 81.53654918074608, 82.30624347925186, 80.67087203264236, 75.44452607631683, 71.66723996400833, 72.9663598537445, 70.06823256611824, 75.07615864276886, 77.90194541215897, 77.57482096552849, 82.25093364715576, 86.76858723163605, 84.4883219897747, 79.48117107152939, 80.69118574261665, 75.11153474450111, 69.3092080950737, 68.72294515371323, 61.45147293806076, 56.20641678571701, 54.6304627507925, 54.44708079099655, 54.98280644416809, 51.61493696272373, 49.832604601979256, 51.86997927725315, 50.67324109375477, 49.25916597247124, 50.8638084679842, 46.966388002038, 49.513942301273346, 49.607899859547615, 46.935966834425926, 46.70894801616669, 44.58762064576149, 46.80051930248737, 44.62451286613941, 50.43941304087639, 59.85254913568497, 63.94064337015152, 64.33133840560913, 64.27442505955696, 66.78276166319847, 61.058235839009285, 52.819194942712784, 59.74843092262745, 66.98049545288086, 63.32440763711929, 63.09216029942036, 65.84647670388222, 63.998187482357025, 67.2162652015686, 65.5946034193039, 63.75789597630501, 55.838957503437996, 49.94461119174957, 48.09560760855675, 42.899633422493935, 43.15825514495373, 44.61037762463093, 43.621545284986496, 56.09661407768726, 59.49303902685642, 64.58039224147797, 55.523399636149406, 37.563036382198334, 50.144028291106224, 59.40292686223984, 65.19990339875221, 56.82789243757725, 59.346138909459114, 62.122931107878685, 59.711774289608, 58.14716264605522, 57.098035141825676, 58.08718666434288, 55.74430078268051, 54.596017599105835, 50.996968522667885, 52.367858961224556, 54.331388399004936, 53.062568083405495, 51.35371617972851, 50.71747072041035, 50.14245517551899, 47.05377571284771, 50.184727907180786, 48.00516866147518, 49.24493573606014, 51.992564499378204, 48.393051847815514, 49.19906459748745, 46.22535936534405, 46.57138779759407, 51.2307433784008, 50.42041026055813, 48.713842034339905, 49.954319670796394, 49.6949265897274, 52.02177353203297, 53.2177821546793, 51.31463907659054, 51.91622659564018, 48.50436307489872, 52.13588900864124, 52.04986162483692, 52.35720053315163, 53.14397111535072, 53.73286351561546, 55.82188121974468, 57.80729368329048, 57.31377996504307, 63.575327172875404, 64.45921674370766, 70.3704759478569, 68.75405788421631, 71.33908957242966, 71.50938123464584, 74.29625809192657, 67.76316225528717, 53.52099448442459, 3.731241845525801, 0.7221466780174524, 2.3650265811011195, 0.7533094589598477, 0.2559207798913121, 8.413473386317492, 74.97343495488167, 69.31688368320465, 68.2069480419159, 52.427481561899185, 40.191359147429466, 19.30628713220358, 25.384914055466652, 47.48944893479347, 57.851048335433006, 80.0309407711029, 12.592908069491386, 0.5783932073973119, 0.15035591321066022, 0.049176445390912704, 0.06269688063184731, 0.013932007150287973, 0.013314210955286399, 0.05348692815459799, 0.12486158200772479, 0.12808484811102971, 0.1277980674058199, 0.14317002380266786, 0.19458451570244506, 0.23043940658681095, 0.23588148644194007, 0.18117399624316022, 0.2283597900532186, 0.21994392445776612, 0.6160506710875779, 52.67387934029102, 75.66123604774475, 64.83118638396263, 68.85028392076492, 48.920254558324814, 56.173989325761795, 67.94476971030235, 77.1648533642292, 94.74530920386314, 6.959968730807304, 0.47037649259436876, 1.6300900862552226, 6.434907680377364, 7.980217784643173, 73.75260606408119, 91.65894761681557, 87.88594007492065, 83.35357367992401, 80.35112679004669, 91.80111318826675, 85.31264215707779, 83.88508915901184, 83.75716522336006, 80.91385379433632, 75.5424316227436, 76.15590870380402, 70.57675167918205, 77.36644014716148, 81.20147556066513, 80.77662035822868, 81.41859591007233, 87.31858491897583, 85.58187291026115, 81.83533474802971, 88.11201274394989, 78.65995913743973, 68.83906692266464, 71.91811010241508, 63.90516847372055, 60.60074418783188, 57.4355748295784, 59.30415116250515, 57.34751835465431, 55.211185589432716, 52.18682147562504, 56.15782879292965, 53.49785752594471, 51.08073502779007, 53.0993577092886, 50.77586218714714, 51.596956327557564, 52.59958192706108, 49.77965824306011, 50.80930799245834, 48.125713393092155, 50.29171496629715, 47.28249303996563, 52.521207332611084, 63.03644008934498, 67.56893187761307, 66.14202484488487, 67.68360212445259, 69.29321855306625, 64.16328102350235, 54.315155670046806, 63.506794050335884, 70.14333933591843, 65.84728226065636, 67.19727382063866, 69.38836544752121, 65.6266812980175, 69.45371434092522, 68.7212960422039, 68.3117388188839, 58.67459334433079, 54.13425497710705, 49.5939090102911, 45.3446464240551, 43.436320424079895, 45.87202772498131, 48.78052845597267, 59.74619284272194, 60.596188232302666, 67.19204530119896, 51.152444779872894, 32.81633108854294, 52.74055056273937, 60.87732754647732, 68.62260773777962, 57.66584247350693, 60.094409957528114, 64.5410567522049, 61.229234263300896, 59.51940581202507, 59.65257726609707, 61.65176399052143, 57.366137355566025, 57.515731528401375, 52.8125225007534, 53.00887696444988, 57.39111341536045, 57.14454084634781, 53.66824418306351, 52.48865827918053, 53.193227872252464, 50.43945103883743, 52.30351701378822, 52.20752276480198, 52.9227963835001, 56.621571108698845, 49.97383922338486, 52.87565231323242, 49.273715391755104, 49.28361766040325, 53.95600654184818, 52.06474922597408, 51.53650537133217, 52.137135341763496, 55.211253985762596, 56.77154526114464, 56.614195704460144, 55.72307892143726, 55.96824936568737, 51.21620535850525, 54.667491763830185, 55.77775798738003, 55.391451716423035, 56.87999904155731, 54.77056123316288, 60.42546719312668, 60.81406854093075, 61.7313127219677, 66.39395132660866, 68.0638325214386, 72.66508162021637, 71.56219080090523, 74.84026730060577, 77.96515882015228, 78.00947204232216, 67.84505546092987, 56.016316786408424, 3.3434864273294806, 6.8838155921548605, 7.150935558602214, 0.4845932516036555, 0.255104090902023, 11.940612271428108, 85.39424657821655, 72.8481937944889, 77.33769848942757, 61.308528408408165, 65.10263621807098, 46.0611017793417, 30.85985977202654, 58.258667662739754, 65.68872436881065, 91.13753199577332, 18.11115436255932, 0.8960404281970114, 0.2740853786235675, 0.45023816695902497, 0.2918991196202114, 0.21141075500054285, 0.1485117059201002, 0.1469318219460547, 0.22583565674722195], [0.07158179098041728, 0.039716904939268716, 0.0892622274113819, 0.045597824137075804, 0.007282164979187655, 0.03645660566689912, 0.03706701099872589, 0.003491663810564205, 0.11176802639965899, 1.1702181003056467, 23.613413013517857, 57.50499710440636, 46.35080963373184, 39.96139548718929, 31.243912763893604, 57.0744726061821, 43.59521649777889, 71.59434467554092, 58.80187511444092, 0.5387590185273439, 0.029571304621640593, 0.5493837234098464, 2.4105350766330957, 15.520692765712738, 80.48022106289864, 80.81761255860329, 77.32019662857056, 68.84199276566505, 78.40710550546646, 76.27171888947487, 77.9698021709919, 76.65070295333862, 80.11164084076881, 76.80465549230576, 74.93381828069687, 73.92922058701515, 75.96924751996994, 73.51816624403, 76.64541363716125, 70.64221456646919, 71.80453419685364, 65.60551643371582, 66.20699375867844, 64.88656461238861, 65.65538495779037, 71.10057637095451, 69.79991376399994, 65.36957189440727, 62.85810045897961, 55.988259091973305, 52.06735588610172, 52.45509088039398, 49.55865450203419, 48.35431672632694, 44.93913218379021, 46.217657178640366, 51.566987335681915, 48.91168601810932, 47.44476333260536, 46.23993158340454, 44.785377234220505, 44.33885559439659, 44.681711196899414, 42.876967638731, 42.20167927443981, 42.551180720329285, 43.25943611562252, 45.27652747929096, 49.8582798242569, 57.31754556298256, 62.83798813819885, 61.02594897150993, 61.41827031970024, 60.02034433186054, 60.184149742126465, 56.27657622098923, 60.48158258199692, 60.362196788191795, 58.698927238583565, 56.41874939203262, 63.68386834859848, 60.033776611089706, 60.30924662947655, 59.44321610033512, 54.46500062942505, 47.1511796861887, 41.56001530587673, 46.38216555118561, 45.19797809422016, 42.81176693737507, 40.65210722386837, 52.591070383787155, 55.8026884496212, 57.01102361083031, 65.07900148630142, 61.67954050004482, 58.21021646261215, 60.56066393852234, 56.41544356942177, 60.54771043360233, 56.15443557500839, 58.05314049124718, 56.02779597043991, 54.931452199816704, 55.007524117827415, 50.25235287845135, 46.42765291035175, 48.508542850613594, 52.73330435156822, 52.93867953121662, 52.26427271962166, 49.86310176551342, 47.78166085481644, 47.340979501605034, 45.443300530314445, 45.20590826869011, 45.61650663614273, 51.180521473288536, 52.01589144766331, 51.16602145135403, 47.28062354028225, 44.71239075064659, 44.19703960418701, 43.83694052696228, 48.20856414735317, 49.140277951955795, 47.05663315951824, 48.38563084602356, 48.49974252283573, 48.71070720255375, 48.12814146280289, 48.50956119596958, 48.84189896285534, 49.58108089864254, 51.411423683166504, 52.3286222666502, 52.59081959724426, 53.20656515657902, 55.31171679496765, 58.583892211318016, 61.54263384640217, 63.465342074632645, 65.007633715868, 67.8317941725254, 67.26226553320885, 69.54937040805817, 68.28139364719391, 66.88737004995346, 64.70775380730629, 61.382704228162766, 70.10217234492302, 22.76575829833746, 1.351577618625015, 1.9572772295214236, 0.27711322240065783, 0.09239766033715568, 0.18804286984959617, 49.35649774968624, 65.7028292119503, 64.51853156089783, 46.241136118769646, 45.4741320759058, 37.473323196172714, 13.495949562638998, 34.48378041386604, 57.05778010189533, 63.45238097012043, 17.107214033603668, 0.5661783472169191, 0.15711011015810072, 0.025146983825834468, 0.02952629150968278, 0.08093909316812642, 0.051015149656450376, 0.05552022354095243, 0.03428414274821989, 0.017463554904679768, 0.03411363431951031, 0.08510360290529206, 0.006505535729957046, 0.036425531943677925, 0.03477574879070744, 0.1299820447457023, 0.06920295534655452, 0.056528260465711355, 1.42498386092484, 34.692279025912285, 72.4369190633297, 52.239771634340286, 47.94046953320503, 23.725250512361526, 40.87586581707001, 53.776367381215096, 79.70203801989555, 63.5625446587801, 0.34381000441499054, 0.04307716779294424, 0.15881700528552756, 2.3336462024599314, 19.555658251047134, 85.99749460816383, 82.13332235813141, 80.37715539336205, 69.51699614524841, 82.2232711315155, 80.41070759296417, 79.7674249112606, 80.85117235779762, 82.93931230902672, 77.95260429382324, 79.11757618188858, 76.84566289186478, 80.10679990053177, 75.67570567131042, 77.68428549170494, 72.83725038170815, 75.45059815049171, 70.4924950003624, 73.18582087755203, 68.96787241101265, 71.06020733714104, 72.8721097111702, 73.21718439459801, 69.9416233599186, 64.73499834537506, 57.93528601527214, 54.03315760195255, 53.76387745141983, 52.380858063697815, 50.2275326102972, 47.86405563354492, 48.56637194752693, 52.90832296013832, 52.08796598017216, 49.43076856434345, 48.82293798029423, 47.405424043536186, 47.329139336943626, 46.63767144083977, 46.604662612080574, 46.23011291027069, 46.2575626373291, 45.54164305329323, 49.84113894402981, 52.85037226974964, 60.25560110807419, 64.94102329015732, 63.4362318366766, 63.2065911591053, 63.93322616815567, 62.27196291089058, 58.221528455615044, 64.01611492037773, 61.86244748532772, 58.966113701462746, 59.767361506819725, 64.71542179584503, 63.230469077825546, 62.737247943878174, 62.83187806606293, 56.91607430577278, 49.66534897685051, 44.87877622246742, 47.03091233968735, 45.031486228108406, 44.164688140153885, 43.57252411544323, 53.3599629253149, 57.05744571983814, 59.09038983285427, 65.8883048593998, 64.8797781765461, 59.27888251841068, 62.25519061088562, 58.23497973382473, 60.997625291347504, 59.53989431262016, 60.25945030152798, 59.09538276493549, 57.86866419017315, 56.41059882938862, 54.81603339314461, 50.147520303726196, 51.53363652527332, 53.836932331323624, 54.734531566500664, 55.032716765999794, 52.34589993953705, 51.36097379028797, 49.88237053155899, 48.34248036146164, 47.48743124306202, 47.94012755155563, 55.33949330449104, 54.87010069191456, 56.71523988246918, 49.734022691845894, 47.74542599916458, 46.704650446772575, 45.85876263678074, 51.14918075501919, 52.96351499855518, 48.13185766339302, 51.62513181567192, 51.42447218298912, 51.563187539577484, 51.62534460425377, 52.161153852939606, 52.7018990367651, 51.94758251309395, 53.05469110608101, 56.80630959570408, 55.8100638538599, 56.7291509360075, 58.55607010424137, 60.98871856927872, 64.45627570152283, 67.57302045822144, 69.40149754285812, 71.71166718006134, 71.87644153833389, 70.77247157692909, 69.77587625384331, 69.50642511248589, 64.24762889742851, 62.38230139017105, 70.91008499264717, 29.645488634705544, 0.6426159956026822, 0.8958921174053103, 0.6010909925680608, 0.10223470162600279, 0.1621711565530859, 51.07308603823185, 74.21381011605263, 71.28102108836174, 56.43277443945408, 47.82860353589058, 34.244492053985596, 20.72405755519867, 42.95674055814743, 63.09398800134659, 74.21169742941856, 21.20181541889906, 0.503129696007818, 0.11764144248445518, 0.028721335875161458, 0.054723617067793384, 0.043547808163566515, 0.029651488111994695, 0.06740103563060984, 0.08601435169111937, 0.15385695034638047, 0.15348599525168538, 0.18272026092745364, 0.13679884927114472, 0.1280470282654278, 0.1398835564032197, 0.17607095913263038, 0.2135928621282801, 0.22575560869881883, 2.004026002250612, 48.73513229191303, 83.30850809812546, 64.76242527365685, 55.046662017703056, 44.11941356956959, 82.76145905256271, 62.328435480594635, 85.81904098391533, 71.72961741685867, 0.8130908198654652, 0.10609377306536771, 2.0120720705017447, 6.205402845516801, 21.7772451415658, 90.16245871782303, 85.47370791435242, 84.9118472635746, 73.77000153064728, 86.26958280801773, 81.62253856658936, 81.46791726350784, 82.2511388361454, 84.83427062630653, 82.54769012331963, 83.2425132393837, 78.23996767401695, 85.27074560523033, 77.8677624464035, 81.32797077298164, 73.81170809268951, 74.21881064772606, 73.78526911139488, 78.10797795653343, 74.31270360946655, 73.68013635277748, 76.3081057369709, 76.36759534478188, 71.98004677891731, 68.64882633090019, 61.81875742971897, 57.37290099263191, 56.846070662140846, 56.24526210129261, 53.669118136167526, 50.83372928202152, 52.41774268448353, 58.20089936256409, 54.67775881290436, 53.26559118926525, 51.468629613518715, 50.011586397886276, 51.11781723797321, 50.51727086305618, 48.13634142279625, 48.26851733028889, 49.69532556831837, 49.367418363690376, 51.21234856545925, 54.0653570741415, 62.99125671386719, 70.26700749993324, 66.19687870144844, 64.89799439907074, 65.51858469843864, 65.08640348911285, 61.71898998320103, 66.97935551404953, 64.9115140736103, 60.680688098073006, 60.924676805734634, 69.1642914712429, 65.34418165683746, 66.1655455827713, 62.35604479908943, 60.75218126177788, 54.21577200293541, 44.67572271823883, 48.83628286421299, 46.343403831124306, 45.252185985445976, 47.77527719736099, 58.48692141473293, 60.229811891913414, 62.19177961349487, 67.68486365675926, 62.279539704322815, 60.63260927796364, 65.63193261623383, 62.34414003789425, 66.1950471997261, 62.12397985160351, 63.279106467962265, 61.316177397966385, 60.32431282103062, 59.262402802705765, 56.071258038282394, 51.478740870952606, 54.588634595274925, 57.99739368259907, 57.966315150260925, 58.00012953579426, 56.26370631158352, 54.96636092662811, 52.25473903119564, 51.321737095713615, 51.94597899913788, 49.68203388154507, 57.47881270945072, 55.911605805158615, 57.90946640074253, 53.897542878985405, 51.201933324337006, 50.5693356692791, 50.34977205097675, 55.33340983092785, 55.95660299062729, 51.889198645949364, 55.38221441209316, 52.881648391485214, 55.01508191227913, 53.969925194978714, 55.493609234690666, 55.88119223713875, 54.91720296442509, 56.95609375834465, 60.97551427781582, 58.289746195077896, 59.43900212645531, 61.72052510082722, 64.93147060275078, 69.78548973798752, 70.17249137163162, 72.03061446547508, 75.47281175851822, 76.05200707912445, 76.40025079250336, 72.20423474907875, 71.74303829669952, 66.83883905410767, 63.842487037181854, 72.58352279663086, 29.103607311844826, 2.778224959038198, 8.851901460438967, 1.7941993614658713, 0.24404984578723088, 0.3779240691801533, 61.527487859129906, 79.84392240643501, 79.10555362701416, 63.63942973315716, 65.34298852086067, 56.92637175321579, 24.62371800094843, 53.84626843035221, 70.12826174497604, 84.76484075188637, 31.127564907073975, 0.9910570608917624, 0.3176520299166441, 0.22868197120260447, 0.2584850782295689, 0.19198855734430254, 0.17566347552929074, 0.13925914303399622, 0.19077783246757463], [0.043247650246485136, 0.031742988285259344, 0.07057782102492638, 0.02380410656769527, 0.06666411267360672, 0.054602858508587815, 0.008524913064320572, 0.019390366942388937, 0.05403672970714979, 1.8797685136087239, 22.79806986451149, 42.49287284910679, 48.287098333239555, 50.606129094958305, 53.742796182632446, 76.4518292248249, 42.29483887553215, 83.03214892745018, 31.038604080677032, 0.061018584165140055, 0.018921927039627917, 0.3408758493606001, 1.4221722492948174, 37.17992573976517, 88.56482684612274, 78.47265958786011, 75.36494314670563, 72.13940262794495, 76.19317710399628, 86.28458440303802, 77.23495200276375, 79.72447961568832, 77.42798924446106, 77.56015375256538, 75.19189283251762, 74.41767677664757, 74.24436807632446, 74.75108608603477, 66.60475641489029, 62.13119566440582, 65.64112052321434, 69.0833406150341, 72.57027670741081, 73.72606828808784, 71.99756383895874, 68.21388646960258, 68.21786105632782, 70.26955336332321, 61.99332006275654, 58.37783306837082, 50.14292635023594, 49.82695050537586, 49.900415763258934, 48.93585652112961, 46.35873220860958, 47.94423893094063, 48.37225556373596, 47.604658752679825, 46.922374963760376, 48.409166783094406, 44.92714382708073, 46.28940872848034, 43.88745501637459, 41.898033767938614, 40.0330900400877, 42.46065817773342, 40.75885109603405, 45.124474838376045, 46.33209943771362, 55.87369903922081, 60.05044251680374, 61.473154574632645, 62.3209422826767, 63.572420328855515, 63.948964923620224, 61.39451779425144, 59.197179302573204, 58.17635267972946, 55.29218204319477, 52.53952994942665, 56.358655616641045, 58.63905765116215, 60.78360557556152, 59.43215489387512, 48.55290926992893, 36.26434966921806, 43.2541885972023, 45.02661108970642, 42.43409000337124, 44.79031316936016, 44.20288369059563, 49.07496705651283, 57.56038673222065, 58.115248158574104, 57.23926976323128, 58.67255285382271, 61.76182508468628, 58.86346220970154, 54.813282340765, 56.478820368647575, 56.721163764595985, 58.52917514741421, 56.616870760917664, 55.24079740047455, 49.451196268200874, 52.053019255399704, 46.10967457294464, 50.67484460771084, 55.65994530916214, 54.73019599914551, 50.856782644987106, 52.08155572414398, 47.11397208273411, 44.82480011880398, 42.164388075470924, 45.19574001431465, 45.6362047791481, 49.828899800777435, 57.64407344162464, 53.29991474747658, 48.077220395207405, 48.77884894609451, 45.86539328098297, 44.29568611085415, 46.95878081023693, 47.13144734501839, 47.35044479370117, 48.95302399992943, 46.0942891985178, 47.279719188809395, 47.346914783120155, 50.68045690655708, 50.20008288323879, 53.281630128622055, 55.09851783514023, 56.77857868373394, 58.503636717796326, 61.91160544753075, 59.880888015031815, 64.69425693154335, 64.64158415794373, 66.28132537007332, 66.00156158208847, 71.3039718568325, 65.30249029397964, 67.42305770516396, 61.56056888401508, 68.20617288351059, 67.87633538246155, 76.16591736674309, 67.4219861626625, 77.65724614262581, 9.076301269233227, 1.2858799751847982, 4.227386210113764, 0.4306574317160994, 0.3699284966569394, 22.23398633301258, 69.58906307816505, 63.76885458827019, 53.83705772459507, 41.01501815021038, 35.31746707856655, 33.28422658145428, 36.03975512087345, 42.366624623537064, 55.27062579989433, 33.97415556013584, 0.2189975674264133, 0.14959647349314764, 0.010765323313535191, 0.05418327418738045, 0.051193847684771754, 0.03061102568608476, 0.08294957864563912, 0.03733816207386553, 0.04417806594574358, 0.08981393999420106, 0.12082994639058597, 0.031110954914765898, 0.061745666243950836, 0.019206190008844715, 0.016745673601690214, 0.08808021622826345, 0.1767123825266026, 2.4644427839666605, 34.26291726529598, 57.63248026371002, 64.04808640480042, 62.102830186486244, 30.09707350283861, 69.93784636259079, 53.34834314882755, 90.9488645195961, 34.5514889806509, 0.14826311613433063, 0.15315324591938406, 0.7600331981666386, 1.940123881213367, 41.571011915802956, 89.77546468377113, 83.32946017384529, 79.01178985834122, 73.58561262488365, 82.08359062671661, 87.48098820447922, 76.1673916876316, 80.39147302508354, 81.20061680674553, 77.95937553048134, 78.26019018888474, 76.68334320187569, 77.28275343775749, 76.04525104165077, 68.03350254893303, 65.54957583546638, 68.88850226998329, 71.3478747010231, 75.08252710103989, 76.33864849805832, 76.52695119380951, 72.0978556573391, 71.72341614961624, 72.1181769669056, 65.70559546351433, 60.784232541918755, 54.27119582891464, 52.56544075906277, 53.531664311885834, 52.366958409547806, 50.33444367349148, 51.386326029896736, 52.05253668129444, 49.31243911385536, 48.85426729917526, 51.544484943151474, 48.62572096288204, 48.869181498885155, 47.1517800539732, 44.93561737239361, 42.94559955596924, 44.28232982754707, 44.30685371160507, 46.369736418128014, 47.11279034614563, 56.762554943561554, 62.08685204386711, 63.77450108528137, 64.56879526376724, 64.51081797480583, 66.52843371033669, 64.39667209982872, 62.595431953668594, 60.894305035471916, 57.79165752232075, 54.243464916944504, 59.45933483541012, 63.355064392089844, 62.88123741745949, 63.85452479124069, 55.08622549474239, 40.27369312942028, 43.756312653422356, 46.34786479175091, 41.90265811979771, 46.631804555654526, 47.61579215526581, 51.27863600850105, 58.58302965760231, 59.52911429107189, 60.514466017484665, 58.88083107769489, 62.92082369327545, 62.479906752705574, 56.14387594163418, 57.390543445944786, 60.24829789996147, 61.313346549868584, 57.832326740026474, 57.55713410675526, 52.84290187060833, 53.067952394485474, 50.61438985168934, 53.80618818104267, 56.528084725141525, 57.81901605427265, 52.171006724238396, 53.124584555625916, 49.240041598677635, 47.04422302544117, 44.67092737555504, 48.1811486184597, 47.94936865568161, 51.737966760993004, 59.514891654253006, 53.26856642961502, 50.67661911249161, 51.15226238965988, 48.01765859127045, 47.31007196009159, 49.9093908816576, 49.665766954422, 50.21405853331089, 50.99504962563515, 47.802042961120605, 51.232426688075066, 49.71754677593708, 53.18906709551811, 54.24628436565399, 55.87629050016403, 57.88030296564102, 60.832432955503464, 61.31407991051674, 65.22641837596893, 64.74799364805222, 68.02698969841003, 67.43517145514488, 69.28720727562904, 67.89279609918594, 74.61869359016418, 67.14436545968056, 68.45230847597122, 60.575160160660744, 69.72843199968338, 68.31216439604759, 80.71555763483047, 67.70516976714134, 83.6565314233303, 13.943723235279322, 0.9558153175748885, 1.2193932803347707, 0.3688811184838414, 0.27288621640764177, 22.727448754012585, 75.83902850747108, 70.24445191025734, 62.56847620010376, 49.11636583507061, 27.535710744559765, 29.658938013017178, 49.59987089037895, 48.425030931830406, 65.32679378986359, 40.273620933294296, 0.2728065097471699, 0.055222674272954464, 0.015672014123992994, 0.004696031264757039, 0.012874505155195948, 0.04651438393921126, 0.047270105496863835, 0.038347664740285836, 0.11306648055324331, 0.12927777628647164, 0.17793995415559039, 0.20501599501585588, 0.19407166197197512, 0.14466923632426187, 0.1529389136703685, 0.18785874301102012, 0.3837399836629629, 3.1392397871240973, 51.28558583557606, 68.49200874567032, 67.93843165040016, 68.46920996904373, 77.9314698278904, 103.43447014689445, 60.236442536115646, 102.49510735273361, 39.53773342072964, 0.17667230655206367, 0.3408266301266849, 3.4981918008998036, 3.9696648018434644, 44.454285800457, 93.52317318320274, 86.4426027238369, 82.80618265271187, 76.70534402132034, 82.79086947441101, 90.00486597418785, 79.35377910733223, 81.8341264128685, 84.44890290498734, 83.32196697592735, 80.37688180804253, 78.42641606926918, 78.98063153028488, 78.08662310242653, 69.3218994140625, 69.1208066046238, 75.24633631110191, 77.10047721862793, 76.98282033205032, 77.62179404497147, 78.54652002453804, 76.33319199085236, 74.03779596090317, 76.03220254182816, 68.07621225714684, 65.97656652331352, 57.437550723552704, 55.8234429359436, 55.50088584423065, 56.22310929000378, 52.17850752174854, 54.59219120442867, 56.00862219929695, 53.03198732435703, 52.137382328510284, 53.77999238669872, 50.57398661971092, 53.79004284739494, 50.67723847925663, 48.70384097099304, 45.64178287982941, 46.107037514448166, 47.33955457806587, 49.97647248208523, 50.73252171278, 60.13972632586956, 64.24325153231621, 66.32411107420921, 68.81223276257515, 69.27702382206917, 69.81722563505173, 64.4376415014267, 64.52120661735535, 63.653268590569496, 60.92745825648308, 57.618675604462624, 61.84256695210934, 65.7734826207161, 67.18975022435188, 68.63233521580696, 57.45822161436081, 47.44173489511013, 48.716045916080475, 47.5746251642704, 42.47300371527672, 47.08915941417217, 51.63427032530308, 55.351561456918716, 61.30838021636009, 63.6674228310585, 62.817925214767456, 62.46802099049091, 65.94686731696129, 65.9554472565651, 60.453042313456535, 60.79686686396599, 61.67037159204483, 64.73512753844261, 61.60595744848251, 61.70375280082226, 55.72286993265152, 57.0248244702816, 50.98827838897705, 56.70691452920437, 59.921705424785614, 61.53996638953686, 55.16129046678543, 57.827918976545334, 51.90824322402477, 50.04036225378513, 46.689496859908104, 51.40377089381218, 49.00296092033386, 53.51684130728245, 62.59245291352272, 56.10944218933582, 52.779502272605896, 54.510446190834045, 52.160648480057716, 50.77939219772816, 50.991249829530716, 50.90919703245163, 52.205805256962776, 54.56977620720863, 51.91554643213749, 52.92217701673508, 54.18654777109623, 55.37753686308861, 56.48949019610882, 59.28950294852257, 60.39006449282169, 62.681466937065125, 64.45696726441383, 69.69247832894325, 67.47576847672462, 71.23660907149315, 69.13349032402039, 71.89806997776031, 72.88406386971474, 77.51396343111992, 69.11178588867188, 71.592528373003, 62.19834566116333, 72.86265581846237, 72.09887400269508, 83.4799624979496, 71.04159593582153, 84.70871016383171, 11.207088232040405, 4.981082417070866, 11.550459656864405, 0.7607776613440365, 0.33418354752939194, 29.376844950020313, 83.44954892992973, 77.42289751768112, 71.27898439764977, 58.85345734655857, 51.89690463244915, 44.08255934715271, 53.538207560777664, 56.229067370295525, 75.11790320277214, 51.966608092188835, 0.3248072834685445, 0.34570613235700876, 0.08830953243887052, 0.17772303923266008, 0.10181063102209009, 0.09048839638126083, 0.19874076533596963, 0.1646397029981017], [0.043111866907565854, 0.009606583098502597, 0.010718464109231718, 0.018895287648774683, 0.04600251355441287, 0.030596529686590657, 0.06467683415394276, 0.06494391825981438, 0.23047583119478077, 2.3140713153406978, 27.490641362965107, 45.75551077723503, 41.14128537476063, 31.531663723289967, 36.16656571626663, 54.45557713508606, 47.40570902824402, 84.97215762734413, 13.652312122285366, 0.38856866362039, 0.35136304912157357, 0.6951296527404338, 5.317080812528729, 53.43020975589752, 81.3048680126667, 79.54925581812859, 76.02617606520653, 71.7626528441906, 79.95845586061478, 78.8870045542717, 77.43130266666412, 67.83726587891579, 68.74844178557396, 78.25197502970695, 72.05835297703743, 75.51957964897156, 74.4097276031971, 75.49697086215019, 73.16245973110199, 73.02170768380165, 72.05587550997734, 72.80584126710892, 65.60461208224297, 64.52566757798195, 64.56960842013359, 68.69750931859016, 67.63080775737762, 68.6617760360241, 63.78909230232239, 57.639943063259125, 50.507463589310646, 51.32560148835182, 48.804455772042274, 48.08726325631142, 49.091579765081406, 47.274334877729416, 49.95266295969486, 50.74632257223129, 48.03695395588875, 48.137545958161354, 48.44961941242218, 46.01347133517265, 43.333976715803146, 39.562565088272095, 42.983620315790176, 38.915885388851166, 42.610187754034996, 42.24468916654587, 47.27703273296356, 50.23892439901829, 59.36187386512756, 62.79067687690258, 61.415196284651756, 60.19251309335232, 60.09248726069927, 60.23156739771366, 59.489140436053276, 58.39185431599617, 53.32467041909695, 50.42399726808071, 54.19019937515259, 58.843110501766205, 56.94888934493065, 62.53101021051407, 45.92731095850468, 28.846668899059296, 52.709133848547935, 46.12555772066116, 40.38443438708782, 42.64427572488785, 41.32326900959015, 45.30882574617863, 56.82612933218479, 52.84599870443344, 58.39718163013458, 60.3911018371582, 58.40490281581879, 59.22578416764736, 54.060367941856384, 50.56974224746227, 55.88062986731529, 57.25399397313595, 54.616247713565826, 51.69509746134281, 51.01965330541134, 50.76684907078743, 50.984235405921936, 52.70598001778126, 52.501201406121254, 52.18494437634945, 49.787292033433914, 47.57749401032925, 42.6459476351738, 43.64875942468643, 44.85468551516533, 48.62202376127243, 50.21916925907135, 43.32333728671074, 53.41510936617851, 51.24447964131832, 50.31040616333485, 48.349722772836685, 48.434283435344696, 45.210612416267395, 46.344919949769974, 48.61513093113899, 47.98270806670189, 49.838228300213814, 48.08496057987213, 48.8961448520422, 50.59313379228115, 52.05113835632801, 53.457876071333885, 58.29364098608494, 60.85254527628422, 63.235545605421066, 62.887571677565575, 62.35083527863026, 63.8881453871727, 65.90416520833969, 63.57444941997528, 66.27996504306793, 66.69033542275429, 66.39360174536705, 62.46328264474869, 68.05891558527946, 69.26312416791916, 71.25881507992744, 69.55006957054138, 70.78501850366592, 67.01436683535576, 71.08607634902, 68.80946651101112, 2.9292974900454283, 1.5356015064753592, 0.554721012013033, 0.46209780557546765, 4.943987857550383, 60.288321152329445, 60.47491393983364, 59.74395476281643, 45.163996517658234, 49.13276195526123, 26.97055947035551, 14.856458958238363, 49.948464184999466, 56.22203014791012, 40.594665706157684, 0.4412828787462786, 0.1456217680242844, 0.04887691087787971, 0.05653378946590237, 0.04359399201348424, 0.016517949297849555, 0.09720161935547367, 0.01833994781918591, 0.026072547734656837, 0.0496611568814842, 0.012952304496138822, 0.06346454334561713, 0.007023440239208867, 0.03300857642898336, 0.12269436236238107, 0.04790147278981749, 0.22143328125821427, 3.2432119455188513, 40.1509977132082, 56.24455153942108, 49.25631232559681, 42.43059039115906, 36.36592201888561, 62.27971449494362, 54.883175790309906, 88.40573698282242, 13.339686747640371, 0.5244161537848413, 0.29323833994567394, 0.23016071529127657, 7.212203470990062, 61.057859659194946, 81.61969631910324, 81.34515345096588, 80.21095231175423, 75.23267984390259, 82.24189773201942, 79.4208075106144, 75.762470215559, 69.43150833249092, 69.04283478856087, 76.57435745000839, 74.62721273303032, 75.78023046255112, 74.82816874980927, 76.40724241733551, 74.38512772321701, 74.75721135735512, 74.95509713888168, 73.73267233371735, 70.15861451625824, 68.47943902015686, 68.39860215783119, 71.07919111847878, 70.23585677146912, 69.02517333626747, 65.95917865633965, 59.21899013221264, 53.4301033616066, 52.163502126932144, 53.38620811700821, 50.25760039687157, 50.930031314492226, 49.74437713623047, 52.42342717945576, 52.20306180417538, 50.03035359084606, 52.26297318935394, 50.300070717930794, 48.72238017618656, 46.48528441786766, 40.87229780852795, 43.74373532831669, 41.43877521157265, 44.63267482817173, 44.640749394893646, 49.4273791462183, 50.179522186517715, 63.29295292496681, 64.8764343559742, 62.404119819402695, 64.78402331471443, 61.79849311709404, 62.2237890958786, 62.3458993434906, 59.556541219353676, 56.69908694922924, 51.34501464664936, 55.33245608210564, 60.06496913731098, 60.004894360899925, 63.95708128809929, 50.39792686700821, 36.95077523589134, 55.90256609022617, 46.312747076153755, 42.86112628877163, 44.026516154408455, 44.27834004163742, 46.84412956237793, 57.208825796842575, 54.29512694478035, 60.340629145503044, 62.64621242880821, 61.974837854504585, 61.76687881350517, 57.608822733163834, 50.24625800549984, 58.91000971198082, 59.288746789097786, 57.981871515512466, 54.035851657390594, 55.174293369054794, 51.223044991493225, 53.31994727253914, 54.85889509320259, 53.18919248878956, 54.38748098909855, 53.14131885766983, 48.87013904750347, 44.307963252067566, 45.7980190962553, 45.69814905524254, 51.15031689405441, 50.678135231137276, 44.67381902039051, 52.610434144735336, 52.2093390673399, 52.231393083930016, 50.034411773085594, 49.81528893113136, 47.10632689297199, 48.63279618322849, 50.38126476109028, 50.730367228388786, 50.655898824334145, 48.57195004820824, 51.70163311064243, 52.293227165937424, 54.70107056200504, 57.345633655786514, 61.72041490674019, 66.16686791181564, 66.83593600988388, 67.71478325128555, 65.14720022678375, 66.84888571500778, 67.06957027316093, 68.08445781469345, 69.93216186761856, 69.6833436191082, 65.82515984773636, 63.534775748848915, 68.40670332312584, 70.38722544908524, 72.2770844399929, 70.83311632275581, 72.14867413043976, 72.47613295912743, 70.97869411110878, 77.37989902496338, 4.730636905878782, 1.5018403180874884, 0.5045550945214927, 0.44456142000854015, 4.747681366279721, 66.88444420695305, 67.48724386096, 65.8523815870285, 54.833884835243225, 40.203184112906456, 31.026744917035103, 26.772105619311333, 52.20907688140869, 66.69506996870041, 52.23388954997063, 0.47601019497960806, 0.05138607135450002, 0.011254690853093052, 0.017693698609946296, 0.09492368611972779, 0.020105077419430017, 0.0898672484618146, 0.01111216417484684, 0.20707221905468032, 0.19165009347489104, 0.11612529415288009, 0.18928051984403282, 0.17785003554308787, 0.1348127581877634, 0.19668155786348507, 0.22796395816840231, 0.3255674504907802, 4.274706495925784, 58.36727723479271, 69.71340000629425, 57.93791927397251, 44.879893362522125, 58.6064288020134, 73.07553559541702, 63.3587159961462, 98.75755190849304, 17.134207785129547, 0.5179946171119809, 0.7285435160156339, 2.1008559688925743, 8.079625200480223, 68.26154351234436, 86.9782903790474, 84.77560177445412, 84.49130102992058, 79.57498043775558, 85.05455240607262, 82.7751687169075, 74.49228957295418, 69.49729040265083, 73.91397580504417, 78.87814342975616, 76.76743268966675, 77.8329411149025, 78.67135092616081, 81.41141429543495, 79.05927211046219, 80.30021712183952, 77.68618538975716, 79.0357057750225, 73.60369965434074, 74.08622056245804, 71.2157329916954, 75.9656149148941, 73.4819845855236, 73.86515602469444, 70.42662173509598, 64.55433323979378, 55.5287117511034, 55.02775423228741, 55.78563496470451, 54.28738296031952, 55.73319397866726, 52.541547641158104, 54.528609216213226, 56.261456832289696, 52.69729748368263, 52.90426857769489, 55.585507303476334, 51.49821102619171, 50.01545079052448, 46.00548416376114, 47.24583260715008, 43.9979112893343, 49.325544610619545, 47.29065880179405, 52.981773018836975, 54.5287574082613, 66.0034690797329, 68.53593438863754, 63.195609748363495, 66.13438725471497, 64.96164098381996, 63.78506451845169, 65.83817794919014, 62.96150431036949, 59.82401266694069, 53.42559300363064, 59.619937017560005, 62.1513307839632, 61.86061978340149, 66.90579906105995, 54.22427594661713, 41.74926795065403, 57.87250958383083, 45.69421626627445, 45.02293288707733, 43.45791086554527, 48.112790286540985, 50.0435084849596, 62.67129108309746, 58.56719970703125, 63.49223703145981, 64.47849690914154, 63.264503851532936, 63.41927334666252, 59.27550829946995, 55.25071866810322, 60.115806609392166, 63.437060192227364, 61.95411756634712, 56.82791143655777, 59.93664622306824, 56.213795989751816, 57.0672719925642, 56.08496010303497, 56.13181918859482, 57.70978331565857, 57.22884312272072, 51.662411615252495, 47.05115005373955, 48.365826308727264, 48.8185416162014, 54.44556087255478, 53.550359308719635, 45.82332953810692, 56.24680481851101, 53.831384629011154, 56.00809022784233, 53.35997052490711, 54.51315924525261, 49.348028004169464, 52.20965065062046, 51.85370475053787, 53.845113292336464, 54.77112740278244, 51.58076539635658, 54.52598735690117, 55.980146527290344, 57.051419243216515, 57.9549765586853, 65.1466454565525, 69.05956909060478, 69.5018881559372, 68.03591921925545, 66.65169149637222, 69.6143165230751, 71.35038256645203, 71.45327344536781, 73.64274635910988, 72.29615941643715, 68.37236076593399, 66.52874529361725, 70.64962416887283, 75.15143260359764, 75.76262220740318, 74.54139813780785, 77.43954062461853, 76.57896280288696, 72.8685075044632, 78.06502506136894, 3.7344460235908628, 4.410984758287668, 1.5312975249253213, 0.40853724523913115, 7.040034709498286, 79.32667896151543, 72.66556039452553, 75.87746724486351, 60.23372568190098, 73.24981704354286, 38.056873083114624, 29.342452995479107, 63.42004470527172, 76.01891845464706, 60.262106359004974, 1.2408329173922539, 0.19142458448186517, 0.12496353825554252, 0.10946986221824773, 0.15117517003091052, 0.14458734774962068, 0.29969377792440355, 0.21338494203519076], [0.04854310769587755, 0.021308464311005082, 0.074119809869444, 0.0393028867256362, 0.021910646646574605, 0.07446752089890651, 0.032994111970765516, 0.04439026823092718, 0.20753239514306188, 1.2770005641505122, 25.3154119849205, 40.17334431409836, 49.23191003501415, 24.928328655660152, 30.65129466354847, 53.53424817323685, 56.05040095746517, 74.43938881158829, 3.174445373006165, 0.2379959839163348, 0.2386282492079772, 0.37322410731576383, 22.92569361627102, 63.260738253593445, 73.91709163784981, 83.39184522628784, 71.47093489766121, 79.08523231744766, 75.69059327244759, 85.83546370267868, 74.6785555779934, 68.39354082942009, 76.669382750988, 78.89116153120995, 75.03592640161514, 72.97454461455345, 73.86742830276489, 68.27406764030457, 66.17129847407341, 64.01901796460152, 66.27691760659218, 65.45193627476692, 66.0496897995472, 65.05760863423347, 65.46120017766953, 67.23832681775093, 69.5886754989624, 68.5568180680275, 58.21079783141613, 52.65852056443691, 51.42015181481838, 49.41023826599121, 50.66238507628441, 46.33136607706547, 45.72237275540829, 48.671831488609314, 49.100152105093, 49.17184665799141, 47.759595438838005, 49.649241641163826, 51.025052815675735, 46.7683008313179, 44.988316744565964, 40.862752720713615, 40.28311662375927, 39.665699154138565, 40.90589560568333, 40.11043108999729, 42.08952449262142, 44.12300817668438, 50.39381928741932, 62.103122770786285, 59.37500976026058, 60.09985126554966, 64.88963484764099, 58.79913926124573, 58.55105817317963, 55.23444414138794, 50.73336146771908, 49.83201563358307, 52.73466847836971, 59.69712607562542, 61.87821663916111, 56.910006031394005, 42.29776091873646, 26.85592722147703, 57.44932249188423, 51.22240662574768, 37.90374130010605, 43.18328820168972, 36.859169751405716, 47.71094284951687, 58.870423436164856, 55.19124425947666, 53.10131460428238, 58.29564727842808, 59.815159142017365, 58.68711747229099, 57.604863345623016, 46.99766792356968, 49.615214467048645, 52.64018654823303, 51.888195499777794, 52.42753855884075, 48.74101437628269, 50.03710202872753, 50.52630677819252, 54.10963989794254, 54.319441840052605, 51.068005710840225, 47.21107207238674, 44.92205210030079, 43.21066953241825, 40.24999760091305, 45.44572860002518, 49.960091561079025, 46.079185009002686, 41.745232567191124, 45.080982372164726, 50.48522338271141, 51.71378865838051, 48.11583772301674, 46.94881774485111, 45.67802533507347, 44.87469904124737, 44.540795758366585, 48.510131165385246, 47.66421675682068, 50.444212183356285, 47.603397220373154, 50.2774353325367, 54.97594401240349, 55.951378270983696, 60.49340754747391, 66.82033404707909, 65.51697358489037, 67.44337901473045, 63.867466896772385, 66.45136624574661, 62.446396350860596, 66.2560187280178, 65.28007909655571, 66.90039575099945, 65.90315446257591, 70.13469859957695, 67.05545783042908, 71.15315794944763, 66.45205020904541, 70.1259058713913, 66.96401193737984, 70.88156372308731, 63.9853897690773, 81.79051235318184, 42.88112461566925, 0.0985590965137817, 0.28538763464894146, 0.19084872241364792, 0.056635511937201954, 38.28887723386288, 64.48041960597038, 61.61155454814434, 47.3214865475893, 39.22724448144436, 21.716877780854702, 41.91511385142803, 41.67666904628277, 53.04675713181496, 38.35499368607998, 1.3416405580937862, 0.0656943408830557, 0.06997546428465284, 0.08609311582404189, 0.06032822355336975, 0.013372586436162237, 0.05562469938013237, 0.0821184845699463, 0.027185303551959805, 0.011994131546089193, 0.04384038875286933, 0.03593090164940804, 0.016834677517181262, 0.011710517028404865, 0.020089353165531065, 0.0684920595085714, 0.1548988069407642, 2.4017884209752083, 40.27275077998638, 52.77939587831497, 60.732969492673874, 33.75635124742985, 38.73281881213188, 63.44384282827377, 64.8358753323555, 80.15419855713844, 3.3638618839904666, 0.15321312239393592, 0.2922769618453458, 0.29289983154740185, 26.85233261436224, 72.92171224951744, 75.55128514766693, 84.51356023550034, 73.63484278321266, 82.9309831559658, 77.97826051712036, 86.63440123200417, 72.66170740127563, 73.51562798023224, 78.8223548233509, 82.43269309401512, 77.42796644568443, 75.65438121557236, 75.12382328510284, 72.09644973278046, 70.09630545973778, 68.91839146614075, 67.03291743993759, 69.40468937158585, 67.38916352391243, 69.26674157381058, 69.47725787758827, 70.0350147485733, 71.35111212730408, 69.37972471117973, 61.63397714495659, 55.743050649762154, 53.93633879721165, 52.17048995196819, 51.58842958509922, 48.80243808031082, 50.999943763017654, 51.159083023667336, 51.46989494562149, 52.73933842778206, 50.118379667401314, 51.431182622909546, 52.43752062320709, 49.94372583925724, 50.037611201405525, 45.890042558312416, 41.75964139401913, 42.41060346364975, 44.777925834059715, 42.07402132451534, 44.58786003291607, 47.29590632021427, 53.67186538875103, 64.4359239935875, 62.00902462005615, 62.127080485224724, 65.89185386896133, 60.927481055259705, 60.00444978475571, 57.63457395136356, 54.90567058324814, 52.427686750888824, 54.79747898876667, 60.79999789595604, 64.5498950779438, 60.48591434955597, 48.75480383634567, 33.666052892804146, 58.59746888279915, 55.77329322695732, 40.06942369043827, 43.40093672275543, 40.75669661164284, 47.75287739932537, 59.03719648718834, 58.882556185126305, 55.41965760290623, 61.68381907045841, 62.30554550886154, 61.5014972537756, 59.244840145111084, 50.03088556230068, 51.30266211926937, 55.63618138432503, 54.431022852659225, 55.329986214637756, 52.52556949853897, 52.61625163257122, 53.516134545207024, 56.26344792544842, 57.32612170279026, 54.46217738091946, 49.89097326993942, 47.26368024945259, 46.61064349114895, 43.04362289607525, 47.341614067554474, 51.79411254823208, 46.282424703240395, 43.544694408774376, 44.29499074816704, 51.5004301071167, 53.72624807059765, 50.47289304435253, 49.09231312572956, 46.85195334255695, 47.31613263487816, 49.25746366381645, 51.16164788603783, 49.07378911972046, 51.108515337109566, 49.878103360533714, 52.66627974808216, 57.70274229347706, 60.56267783045769, 61.02642014622688, 68.33769902586937, 67.79862955212593, 69.17439132928848, 67.0164643228054, 67.03941509127617, 65.518888682127, 68.18231776356697, 66.98738068342209, 68.75300914049149, 67.79892593622208, 72.51090869307518, 69.44074183702469, 72.30629727244377, 68.54677140712738, 72.49558791518211, 70.18907368183136, 74.68265175819397, 68.72682094573975, 82.92405992746353, 51.50150544941425, 0.10031077283201739, 0.12294600979657844, 0.20737645507324487, 0.06531680293846875, 41.00492589175701, 72.49714583158493, 68.45250606536865, 57.135045155882835, 45.04013456404209, 16.922173462808132, 41.853256970644, 50.84670938551426, 59.36635002493858, 47.70868197083473, 1.6570188850164413, 0.10627487194142304, 0.06137701551779173, 0.07579710814752616, 0.013633986618515337, 0.057696341536939144, 0.1607404145761393, 0.03396869287826121, 0.166813037940301, 0.07352669286774471, 0.16665024042595178, 0.11015301657607779, 0.15019188373116776, 0.15928213892038912, 0.17892959323944524, 0.2122824074467644, 0.35105838265735656, 4.42792852409184, 56.32377348840237, 66.73737689852715, 72.55392238497734, 39.4402876496315, 48.907924219965935, 74.82818394899368, 73.591737896204, 90.05160346627235, 4.574155602604151, 0.3156256699003279, 1.014065716881305, 0.9701312868855894, 27.503621466457844, 74.77988854050636, 82.75280311703682, 87.18683078885078, 79.39811512827873, 84.87923741340637, 82.46892794966698, 84.44507271051407, 73.21508690714836, 76.34194672107697, 81.65839344263077, 85.9349499642849, 80.4409995675087, 80.73293030261993, 79.67908725142479, 76.37427538633347, 71.2902469933033, 71.8328046798706, 72.58411556482315, 74.76916551589966, 72.46360123157501, 70.83742529153824, 73.34527552127838, 72.59714126586914, 73.28764021396637, 76.03186815977097, 64.54899832606316, 59.01256240904331, 56.23431868851185, 54.059828370809555, 56.06694146990776, 52.853814885020256, 54.658607840538025, 55.19123665988445, 54.94725175201893, 55.51360756158829, 52.46603049337864, 53.95168237388134, 55.70230923593044, 51.21009148657322, 54.0671543776989, 48.68817061185837, 45.62069781124592, 45.14289624989033, 47.419589683413506, 46.43133111298084, 48.053844049572945, 49.1776717454195, 56.888670176267624, 68.06764751672745, 64.04974311590195, 63.792588114738464, 71.02106183767319, 65.16014993190765, 64.53699097037315, 60.000289008021355, 56.25773683190346, 55.576239600777626, 57.183408960700035, 63.865050226449966, 67.87040770053864, 62.187432646751404, 51.82097710669041, 40.10099999606609, 65.2295570075512, 55.94356968998909, 40.616696923971176, 44.513775408267975, 42.96965226531029, 53.89194197952747, 61.43860682845116, 61.94636598229408, 55.8524239808321, 65.67834332585335, 64.75718915462494, 62.200690135359764, 61.48772679269314, 50.64756967127323, 55.32973922789097, 58.21956396102905, 56.45370751619339, 55.9762479364872, 55.308623760938644, 55.58096654713154, 57.697988748550415, 60.50940088927746, 61.911708042025566, 56.57082483172417, 51.66960462927818, 52.358211278915405, 49.93927247822285, 45.09070985019207, 49.227582067251205, 53.35812762379646, 47.16896653175354, 41.99255749583244, 46.35284252464771, 54.38282623887062, 55.66765509545803, 54.19440574944019, 51.856186017394066, 51.031432673335075, 49.596777856349945, 50.067435801029205, 54.513729214668274, 51.81654654443264, 54.40154403448105, 52.701663449406624, 55.07063493132591, 61.720042526721954, 62.33204148709774, 64.28943425416946, 72.32325196266174, 70.01423746347427, 71.81141942739487, 69.10347953438759, 70.81073552370071, 68.39015141129494, 69.55603525042534, 69.88962695002556, 71.6867633163929, 69.33291882276535, 74.73426818847656, 72.42528408765793, 76.90474212169647, 72.32276558876038, 75.66867604851723, 73.96705895662308, 78.79718497395515, 71.98807194828987, 86.37821897864342, 50.35789221525192, 0.16799993987660855, 1.130295186303556, 0.7529015745967627, 0.3086943371454254, 52.36361838877201, 80.24695158004761, 77.39617735147476, 63.21905829012394, 59.48005132377148, 32.00750268995762, 56.005065590143204, 59.103445932269096, 69.55116391181946, 58.69127444922924, 2.734830337576568, 0.34231318160891533, 0.19103099388303235, 0.33805530227255076, 0.12045513212797232, 0.11429003716330044, 0.2638130751438439, 0.20991277444409207], [0.02387176446063677, 0.03297243012639228, 0.03665551979793236, 0.025807547208387405, 0.024102778334054165, 0.06811342318542302, 0.09628888903534971, 0.033714395976858214, 0.06227399004274048, 1.9864866184070706, 28.947133608162403, 42.01482430100441, 33.10651771724224, 32.62234389781952, 51.94306455552578, 44.63068753480911, 70.13573214411736, 60.57656608521938, 0.536570098483935, 0.03110913294221973, 0.3534057957585901, 1.1127530713565648, 52.34819121658802, 90.18268123269081, 75.31683772802353, 70.73846340179443, 70.44938251376152, 73.71752634644508, 87.56440132856369, 75.47017470002174, 65.1343797147274, 76.58558964729309, 78.90208974480629, 76.1965437233448, 72.36416816711426, 71.08095422387123, 67.2434413433075, 66.5238131582737, 67.78476029634476, 67.26305589079857, 68.67188349366188, 62.714867144823074, 60.650373324751854, 57.528122663497925, 59.63181518018246, 61.42013981938362, 61.50636859238148, 55.20950607955456, 51.60037234425545, 51.387260779738426, 50.74061907827854, 48.715677335858345, 48.83763559162617, 45.41593819856644, 45.48264741897583, 47.10965931415558, 49.246387258172035, 49.61009994149208, 49.15991149842739, 47.78229542076588, 46.372806653380394, 45.08534453809261, 44.3831992149353, 43.593764975667, 44.03274402022362, 42.32825428247452, 40.16473017632961, 41.02846942842007, 39.8749615252018, 43.55908803641796, 45.7040349394083, 49.23353634774685, 56.75527833402157, 60.22758141160011, 59.35416787862778, 54.249244406819344, 55.9722201526165, 56.487882882356644, 53.28806318342686, 52.29283578693867, 53.10938157141209, 60.38813039660454, 58.461249992251396, 60.99688433110714, 43.74480687081814, 30.765847116708755, 29.25064042210579, 42.02200211584568, 45.43747164309025, 39.993279576301575, 38.94797466695309, 41.94353252649307, 51.461710184812546, 54.965239986777306, 53.571558371186256, 58.59666332602501, 57.88463853299618, 58.98799292743206, 56.60012885928154, 48.97507421672344, 45.617186799645424, 49.41951356828213, 52.66433425247669, 53.943839594721794, 49.8576794564724, 48.92806313931942, 48.51767756044865, 51.517586186528206, 50.08709594607353, 47.580541446805, 45.216099321842194, 40.05153425037861, 43.79993051290512, 42.536490708589554, 46.70061506330967, 46.59188769757748, 46.255799531936646, 45.321498066186905, 43.654550313949585, 46.16167478263378, 48.19563344120979, 47.54234589636326, 46.73189878463745, 45.78749366104603, 45.41485905647278, 47.90371410548687, 48.68821620941162, 48.18996034562588, 47.09337338805199, 50.71839027106762, 47.51896195113659, 50.987313240766525, 56.02808475494385, 61.42417140305042, 63.73097822070122, 63.52259740233421, 62.736195400357246, 63.9883916079998, 64.92963910102844, 66.19285851716995, 66.67889043688774, 66.28986731171608, 69.82791066169739, 69.14886429905891, 68.71463119983673, 67.2286981344223, 65.94136521220207, 67.69314721226692, 61.53742052614689, 62.73225121200085, 65.02308368682861, 67.54349604249, 68.51315081119537, 84.84994098544121, 14.132356513291597, 1.6651335870847106, 0.5258857843000442, 0.8359746169298887, 13.649468924850225, 65.02518117427826, 59.206963777542114, 55.31207397580147, 40.27197942137718, 45.167864710092545, 29.41671621054411, 32.728339210152626, 60.46161845326424, 53.193957433104515, 1.874051601625979, 0.04906118985672947, 0.05490335781360045, 0.13441185001283884, 0.11671568747260608, 0.029691974123124965, 0.061020064749754965, 0.030829154020466376, 0.01243385126144858, 0.027848529389302712, 0.04001902954769321, 0.06139274533779826, 0.07431406702380627, 0.04887007198703941, 0.028179128348710947, 0.017610980685276445, 0.03585522485082038, 2.625799225643277, 46.547236293554306, 54.702290296554565, 44.86163914203644, 34.509584829211235, 55.32757334411144, 55.137659534811974, 76.49807274341583, 66.92711591720581, 0.27319005166646093, 0.12706455832812935, 0.1404661571723409, 1.3600954553112388, 58.63314136862755, 90.82285568118095, 80.95572754740715, 74.27215978503227, 74.51932892203331, 77.40294098854065, 88.1831981241703, 78.72927501797676, 68.41877907514572, 80.93697935342789, 80.46652659773827, 78.55856537818909, 74.50370416045189, 73.87185126543045, 69.095598757267, 68.29206347465515, 70.23812144994736, 70.75419455766678, 70.36787688732147, 67.40419551730156, 62.34386645257473, 60.37586845457554, 60.313396006822586, 64.90835264325142, 64.74522739648819, 56.98584236204624, 53.57055522501469, 54.89207871258259, 51.22989982366562, 52.071011289954185, 49.83512386679649, 48.692506179213524, 47.15107709169388, 47.220609560608864, 52.68891893327236, 52.86742955446243, 51.214324459433556, 50.20696431398392, 48.36689405143261, 46.03251971304417, 47.185024470090866, 47.40497946739197, 46.80503726005554, 45.11960729956627, 43.56127291917801, 43.88776659965515, 43.67344669997692, 45.23449033498764, 48.4474953263998, 50.615518391132355, 58.118147403001785, 61.03620462119579, 60.15573486685753, 57.07973912358284, 56.991967633366585, 58.094326481223106, 54.67064179480076, 52.4238071590662, 56.365670040249825, 63.44325006008148, 61.56805068254471, 61.71143598854542, 47.62219861149788, 33.39714892208576, 32.1014716476202, 45.15073902904987, 47.98843435943127, 43.8534202426672, 39.9265893548727, 43.92603434622288, 53.08335676789284, 57.55049966275692, 55.81844620406628, 61.92823335528374, 61.282674595713615, 60.047649666666985, 58.80728222429752, 49.93397556245327, 46.32834143936634, 53.09811897575855, 53.81586246192455, 54.154610484838486, 53.54402884840965, 51.88540644943714, 51.4150220900774, 53.74382212758064, 51.43747128546238, 50.82866035401821, 46.51220217347145, 43.492694199085236, 44.96904417872429, 46.005780547857285, 49.50214013457298, 47.223945781588554, 44.909649565815926, 43.95705208182335, 43.117502331733704, 47.647782638669014, 50.0935859978199, 49.50401723384857, 48.59638653695583, 47.55548179149628, 49.170129150152206, 50.79824298620224, 49.73087266087532, 49.77131009101868, 50.30597560107708, 52.72303730249405, 50.50354599952698, 53.59529949724674, 57.71149322390556, 63.338660672307014, 66.582550406456, 65.75466603040695, 65.37312850356102, 64.91066291928291, 66.67455866932869, 68.13464552164078, 67.75792613625526, 68.41757833957672, 70.93619719147682, 72.00984477996826, 68.63407552242279, 68.96097958087921, 67.72070333361626, 69.07944202423096, 63.84013116359711, 63.96602600812912, 66.85667529702187, 72.69833743572235, 69.66642692685127, 88.48208248615265, 19.686945006251335, 1.5856838878244162, 0.6552421837113798, 1.0351585038006306, 13.438307605683804, 73.98258492350578, 67.25662663578987, 64.27569419145584, 47.5513856112957, 36.80156484246254, 42.04763934016228, 43.36304895579815, 65.7009369134903, 62.84350544214249, 3.4022664232179523, 0.19705295824678615, 0.106379522185307, 0.04886106231424492, 0.11711314466083422, 0.022726862516719848, 0.03690287390782032, 0.02082262661133427, 0.11925604412681423, 0.15940855635562912, 0.12261834417586215, 0.1839298428967595, 0.1511099055642262, 0.14461136364843696, 0.2084492740686983, 0.1384957550908439, 0.12492556998040527, 5.800794381648302, 59.447893649339676, 66.31394281983376, 48.86047996580601, 45.290765315294266, 71.64598390460014, 63.13281051814556, 82.67768874764442, 75.60181483626366, 0.5578240205068141, 0.23256092477822676, 1.3993192068301141, 1.9104747846722603, 60.61805225908756, 94.4611756503582, 84.34344336390495, 77.47744739055634, 80.1596474647522, 82.6192706823349, 90.18552348017693, 78.07506412267685, 72.3997874557972, 82.97727227210999, 86.4681525528431, 81.35212987661362, 77.96385169029236, 78.90363246202469, 73.9055934548378, 73.7692491710186, 74.65460926294327, 73.90598103404045, 72.7339719235897, 69.74127531051636, 69.46473374962807, 63.747260347008705, 66.24616205692291, 68.06349813938141, 68.46010565757751, 59.51185181736946, 56.7205785959959, 56.650419160723686, 54.32576850056648, 54.06905047595501, 53.70175078511238, 50.33719092607498, 50.53487911820412, 50.9703965485096, 54.704972952604294, 55.73431111872196, 52.15702347457409, 52.44309492409229, 48.02718088030815, 47.17934377491474, 48.72904881834984, 52.02971130609512, 51.369439736008644, 48.65920476615429, 45.85558220744133, 46.5174724906683, 47.56969302892685, 48.022320941090584, 50.40144167840481, 54.13855254650116, 63.36044490337372, 64.85305041074753, 62.633969485759735, 60.244767889380455, 59.89651657640934, 60.05413591861725, 57.716493755578995, 55.978303626179695, 58.758276253938675, 64.64479118585587, 63.739637956023216, 65.21118879318237, 53.05220603942871, 39.45948801934719, 40.646487325429916, 48.96460197865963, 50.57324945926666, 44.335093796253204, 41.242872923612595, 48.697635903954506, 57.435666024684906, 59.99286040663719, 58.25983040034771, 65.42294383049011, 63.438177332282066, 62.48452350497246, 61.48734301328659, 50.839957147836685, 49.20730635523796, 55.183443278074265, 56.275227293372154, 58.392348289489746, 55.843331068754196, 55.65715625882149, 53.71690437197685, 54.193790182471275, 53.47526773810387, 53.11001993715763, 49.31447200477123, 45.23009397089481, 48.96213211119175, 48.738016337156296, 50.64455643296242, 47.945633456110954, 45.584208369255066, 46.734953820705414, 43.67582157254219, 49.41388987004757, 49.896076396107674, 52.912700325250626, 51.38314560055733, 51.3616007566452, 51.4900566637516, 52.68432877957821, 52.85584397614002, 52.67561584711075, 53.32369387149811, 56.75117075443268, 52.427257373929024, 56.386371329426765, 61.89566910266876, 68.48728939890862, 70.42201638221741, 69.94271770119667, 68.45001339912415, 68.01138773560524, 69.30602386593819, 70.44923052191734, 71.83590531349182, 73.12175631523132, 73.76756966114044, 75.5443923175335, 73.59715640544891, 73.37471634149551, 71.67526513338089, 72.81198933720589, 67.06176549196243, 69.47585955262184, 70.31887471675873, 76.85397684574127, 72.9685029387474, 92.46603190898895, 17.125606946647167, 2.161651044152677, 2.4415150517597795, 0.9802984725683928, 18.310934342443943, 83.65528509020805, 73.15791517496109, 73.04965138435364, 56.69783301651478, 68.70683401823044, 43.835135623812675, 50.80954737961292, 74.4148725271225, 73.10088023543358, 5.164022175595164, 0.45600967132486403, 0.15542690438451245, 0.2718192752217874, 0.24553100927732885, 0.12779579643392935, 0.21094579948112369, 0.17371559020830318], [0.029263333744893316, 0.040569873817730695, 0.04732018191134557, 0.15516477782512084, 0.07941976844449528, 0.07775784004479647, 0.033373301193933, 0.05982537768431939, 0.13624342594994232, 2.8451236942783, 35.548057705163956, 44.34251859784126, 43.222798481583595, 33.39040048420429, 44.57363739609718, 46.40266165137291, 77.16619849205017, 42.64654420316219, 0.02510677426471375, 0.2309845288982615, 0.5926785408519208, 11.701769437640905, 82.03794747591019, 74.77673470973969, 78.55133816599846, 72.1625965833664, 74.51511114835739, 86.33417934179306, 71.98876351118088, 63.77364233136177, 77.7423007786274, 76.89915642142296, 75.54117769002914, 71.05684831738472, 70.44350802898407, 69.37450379133224, 67.72232204675674, 64.04952272772789, 61.81998856365681, 57.461227253079414, 57.194257378578186, 55.9833649545908, 57.98904933035374, 54.16955888271332, 52.52955548465252, 51.535335034132004, 51.00981563329697, 47.85953767597675, 49.92872044444084, 50.564684718847275, 49.849703684449196, 51.66804291307926, 47.05613538622856, 44.991979748010635, 44.94179584085941, 46.92229136824608, 48.93769562244415, 48.73705118894577, 52.647246569395065, 49.12729024887085, 47.54335664212704, 46.09740503132343, 43.67199897766113, 43.68569724261761, 37.449631467461586, 42.000088691711426, 41.164882108569145, 40.814096331596375, 41.78612217307091, 40.50473213195801, 44.08076964318752, 46.57437063753605, 47.07096219062805, 48.145616725087166, 52.35193021595478, 56.695952117443085, 53.10664191842079, 52.9713349789381, 52.84897394478321, 47.8792130202055, 51.602051854133606, 60.14555521309376, 61.75324894487858, 57.751102298498154, 40.86143799126148, 20.97556795924902, 15.563384424895048, 28.265079706907272, 29.934594221413136, 48.2150200009346, 40.77605277299881, 40.387018248438835, 49.73743110895157, 58.29147130250931, 50.72616845369339, 53.22590991854668, 57.875906601548195, 57.496489360928535, 53.47241409122944, 46.59826375544071, 45.928800478577614, 47.29572393000126, 48.25724333524704, 49.86512325704098, 49.494244158267975, 52.755928337574005, 50.70458561182022, 48.23594927787781, 48.33501756191254, 42.74497792124748, 38.58386680483818, 39.91306968033314, 38.39364521205425, 44.05251435935497, 46.20656557381153, 45.3852054476738, 46.85285769402981, 44.46575738489628, 45.67909687757492, 44.79561388492584, 48.812860921025276, 46.14927984774113, 47.707150653004646, 45.90473257005215, 45.401495173573494, 48.82628180086613, 49.87559549510479, 47.23981752991676, 46.281619146466255, 47.23466120660305, 48.28578740358353, 45.89353457093239, 48.39450716972351, 52.34510578215122, 59.28079001605511, 62.19825826585293, 63.5762695223093, 62.138552069664, 63.37613806128502, 65.42054235935211, 66.92353650927544, 65.69120943546295, 65.76940923929214, 66.4364330470562, 63.97645264863968, 61.40994496643543, 59.414303451776505, 55.13893626630306, 56.525307074189186, 55.83589106798172, 59.86231841146946, 65.05224332213402, 68.72853845357895, 74.95040819048882, 65.583036839962, 0.202807244786527, 0.3692841046722606, 0.11269073860603385, 0.9910439397208393, 52.84612789750099, 64.97794970870018, 53.25155474245548, 46.070635467767715, 29.12090588361025, 21.33104458451271, 43.92943896353245, 50.00673405826092, 47.62925483286381, 3.719883542507887, 0.14493415335891768, 0.018391538214928005, 0.04062405801960267, 0.06816236782469787, 0.04490739302127622, 0.034781767608365044, 0.03910754603566602, 0.05148375654243864, 0.05952063700533472, 0.05499673854501452, 0.016581068957748357, 0.03130741068162024, 0.03839244964183308, 0.004161972519796109, 0.09196321450872347, 0.039524087551399134, 4.613807899877429, 54.00039575994015, 52.86028213799, 58.08533236384392, 32.045736238360405, 46.51822865009308, 55.80735459923744, 83.81577327847481, 46.33517347276211, 0.08922994398744777, 0.45556607481557876, 0.1966108608758077, 15.087321270257235, 84.30430546402931, 76.824931204319, 80.39781868457794, 75.91524481773376, 78.77999469637871, 89.26808550953865, 76.65164530277252, 67.60705903172493, 82.27355003356934, 78.30879718065262, 77.66044557094574, 74.46114644408226, 72.18424782156944, 71.93455561995506, 70.08301377296448, 67.19830736517906, 65.35771653056145, 61.90915837883949, 59.287709444761276, 60.50501972436905, 59.2023204267025, 56.79335989058018, 56.88396602869034, 53.94246406853199, 53.28327924013138, 51.62221737205982, 53.91942210495472, 54.74323309957981, 52.83792033791542, 52.10399731993675, 49.70026910305023, 50.693638399243355, 48.87928135693073, 50.37185646593571, 51.25786632299423, 51.76253244280815, 55.12948237359524, 50.98053440451622, 48.86645704507828, 47.84889064729214, 44.67366702854633, 48.39019440114498, 41.04085296392441, 44.14962574839592, 43.65885928273201, 45.8346301317215, 44.357637986540794, 42.59067580103874, 46.89764589071274, 48.27486298978329, 47.693524584174156, 50.16233190894127, 54.76036258041859, 56.721498146653175, 56.198144629597664, 54.69493389129639, 53.7872613966465, 52.14707560837269, 52.76582680642605, 61.900669634342194, 64.88412514328957, 60.43156586587429, 45.80824814736843, 25.13476587831974, 18.07116150856018, 34.21676114201546, 30.18947884440422, 52.49220348894596, 43.0555884540081, 42.53863379359245, 52.78337046504021, 61.33305609226227, 53.715920224785805, 54.276523143053055, 57.87382431328297, 60.065307319164276, 56.212424263358116, 48.37384007871151, 47.72875629365444, 49.064396023750305, 49.69067461788654, 52.016111835837364, 49.48704734444618, 54.05527621507645, 52.229918763041496, 50.97474351525307, 51.76075413823128, 45.23364298045635, 40.76602131128311, 42.92088948190212, 41.00063972175121, 46.350391656160355, 45.22367611527443, 45.74426718056202, 48.42747800052166, 44.353066831827164, 45.64946606755257, 44.844897240400314, 49.229649156332016, 48.88389430940151, 48.08163195848465, 48.24292190372944, 47.64469340443611, 50.360278487205505, 50.89031584560871, 48.630542904138565, 50.5859711766243, 48.921611085534096, 50.48692189157009, 48.882773369550705, 49.70235899090767, 55.93235269188881, 61.999027356505394, 64.10341903567314, 64.30583417415619, 64.49548199772835, 64.83177155256271, 68.0346728861332, 70.21350637078285, 67.21951022744179, 68.07587027549744, 68.20733562111855, 66.91343665122986, 63.308699280023575, 62.66439065337181, 57.96067625284195, 58.875412568449974, 57.63869673013687, 61.82573385536671, 67.27589160203934, 71.02185979485512, 76.45540103316307, 74.435193836689, 0.7471341372001916, 0.3999755624681711, 0.1475053239846602, 0.9831930859945714, 57.896110117435455, 73.12266826629639, 60.34911409020424, 57.3470813781023, 34.987488985061646, 26.741367168724537, 57.81155325472355, 56.737423092126846, 58.77068258821964, 4.6526779141277075, 0.1633180122007616, 0.048736659809947014, 0.05110920203151181, 0.023749291540298145, 0.052301280447863974, 0.025777048649615608, 0.00788766888945247, 0.10666860354831442, 0.18752154079265893, 0.16433836135547608, 0.24765686161117628, 0.1959536297363229, 0.1028105265868362, 0.12205022270791233, 0.21530977624934167, 0.2635716990334913, 7.474718559533358, 69.69573095440865, 65.20533710718155, 67.70794361829758, 52.47486501932144, 65.85395470261574, 61.655085012316704, 92.64831572771072, 51.83212570846081, 0.318960317526944, 0.38657193013932556, 1.3451608316972852, 14.799724202603102, 90.57501778006554, 78.90800222754478, 85.85934162139893, 77.72533848881721, 83.95345509052277, 87.7213405072689, 79.07456248998642, 72.4869091808796, 85.20218208432198, 80.94347700476646, 80.70351228117943, 77.45781004428864, 75.1736082136631, 77.05756232142448, 72.49321684241295, 70.80477744340897, 69.9399970471859, 64.15000453591347, 64.00647103786469, 64.40835267305374, 63.232741355895996, 59.85838942229748, 58.36288467049599, 58.213298097252846, 56.56705163419247, 53.115613237023354, 55.222349390387535, 57.52357430756092, 55.30545473098755, 57.14861802756786, 52.13553562760353, 52.21334405243397, 53.80271516740322, 53.62657941877842, 54.7978475689888, 54.360920414328575, 56.94366842508316, 51.616852059960365, 49.799770563840866, 48.1375839561224, 47.37819090485573, 49.98641274869442, 45.07251262664795, 47.089486196637154, 48.10446493327618, 48.297585770487785, 47.697647362947464, 44.775379970669746, 49.396426007151604, 49.891892820596695, 51.076999828219414, 52.80964985489845, 58.35920266807079, 61.14155776798725, 59.23644259572029, 56.7184317111969, 57.08419248461723, 53.81481371819973, 57.266768887639046, 65.79983800649643, 67.31088012456894, 61.99724145233631, 52.51972161233425, 30.159382559359074, 21.360086426138878, 35.75792044401169, 29.59729202091694, 57.52281814813614, 43.24946545064449, 46.90338738262653, 57.48509757220745, 64.48709964752197, 56.5332942456007, 58.07275503873825, 62.51135006546974, 62.38762490451336, 58.9922297000885, 50.63438057899475, 50.74248857796192, 52.38663375377655, 51.04558311402798, 54.613956436514854, 52.848719358444214, 58.73904548585415, 55.523483231663704, 55.252310782670975, 55.76837249100208, 49.41878780722618, 43.01009729504585, 44.89922292530537, 44.72007013857365, 49.750772193074226, 47.31200985610485, 46.11490689218044, 48.85076008737087, 44.407605305314064, 47.14457184076309, 46.725735515356064, 52.87847176194191, 50.05046211183071, 52.855350002646446, 50.292980298399925, 51.51901111006737, 53.92465062439442, 55.205843076109886, 51.46346569061279, 51.46975815296173, 51.61356143653393, 52.41115003824234, 50.65446250140667, 53.44005882740021, 58.881887421011925, 65.48829272389412, 67.58437424898148, 67.95105457305908, 70.02901867032051, 68.4407950937748, 71.82938486337662, 73.02961885929108, 70.38915574550629, 72.1469946205616, 71.45504415035248, 70.16403302550316, 66.4836797118187, 67.06828594207764, 61.60750776529312, 63.35078962147236, 60.97016416490078, 66.46476432681084, 71.13016158342361, 76.0189488530159, 79.43251088261604, 73.59874472022057, 0.5429544090293348, 1.0678651300258934, 0.23279663088032976, 1.7730631143786013, 67.17008247971535, 81.40147402882576, 67.73812159895897, 65.925862044096, 47.46861845254898, 29.832334108650684, 63.46775494515896, 62.7617984265089, 71.45185992121696, 7.953804451972246, 0.41739225445780903, 0.16257317794952542, 0.1391352340579033, 0.2250192646170035, 0.1713745595770888, 0.12892053608084098, 0.14412818098207936], [0.07450716642779298, 0.06906613300088793, 0.09353987014037557, 0.043268935041851364, 0.07467272473149933, 0.04776780086103827, 0.014962502391426824, 0.05684609634045046, 0.06346851383568719, 4.113198537379503, 33.67076463997364, 41.71051003038883, 32.663579285144806, 30.26107270270586, 41.48950628936291, 49.099468141794205, 80.81730857491493, 26.394327990710735, 0.2761571283917874, 0.6751433783210814, 0.07421429269015789, 40.10924555361271, 87.05817729234695, 77.3287233710289, 77.92431101202965, 79.89509806036949, 87.88441255688667, 64.9189692735672, 61.9626747071743, 77.76328325271606, 77.64202415943146, 72.3213292658329, 71.80575013160706, 67.19472795724869, 65.98560243844986, 64.96100261807442, 60.72927229106426, 57.01875999569893, 55.76814830303192, 54.537603333592415, 54.18419949710369, 54.09632161259651, 50.35344645380974, 49.35154661536217, 49.28714767098427, 50.100611820816994, 49.92097645998001, 48.78034986555576, 49.858184829354286, 51.69158644974232, 50.55945239961147, 47.84998878836632, 50.51988512277603, 45.670121759176254, 44.76769678294659, 45.11253967881203, 47.92693845927715, 49.028818532824516, 47.75330677628517, 48.06897483766079, 45.35198763012886, 45.936434268951416, 41.92721240222454, 44.08165119588375, 45.889210402965546, 39.86448548734188, 41.884373500943184, 40.37164807319641, 40.251992493867874, 41.078512743115425, 40.181377083063126, 47.2649759799242, 45.18939055502415, 42.810820788145065, 45.49511454999447, 49.27986726164818, 45.17609506845474, 49.707070738077164, 46.987218484282494, 49.488403871655464, 46.02163329720497, 62.11868293583393, 56.18022859096527, 63.707788065075874, 46.30768574774265, 32.75580793619156, 19.37865424901247, 34.77631151676178, 24.212971441447735, 34.63047914206982, 50.234573632478714, 32.94155336916447, 38.620785623788834, 48.44530664384365, 56.795837357640266, 49.75628189742565, 51.57375477254391, 50.36625936627388, 47.132553085684776, 45.10090850293636, 45.853203535079956, 44.92292985320091, 46.004879996180534, 46.086644008755684, 49.150294214487076, 46.410204246640205, 47.4523439258337, 45.432847291231155, 44.14409704506397, 41.135597079992294, 39.97852876782417, 37.73405380547047, 44.13998946547508, 44.7950629144907, 45.47374069690704, 43.33774611353874, 43.849833235144615, 45.00102326273918, 43.18520709872246, 47.91969984769821, 46.87194027006626, 48.35892967879772, 45.46261489391327, 45.65230831503868, 46.4944951236248, 45.9540881216526, 50.88229447603226, 47.54047639667988, 49.01643879711628, 48.40289331972599, 48.1415281444788, 48.42290684580803, 47.967064306139946, 48.0740437656641, 47.83562935888767, 48.02661091089249, 51.724925860762596, 57.10141696035862, 57.92969271540642, 60.556073784828186, 60.86108721792698, 59.66517359018326, 58.70916768908501, 59.94155175983906, 56.4802984893322, 53.49919505417347, 52.20572166144848, 50.48533737659454, 53.874861896038055, 53.168548196554184, 60.274250507354736, 64.13977548480034, 73.66460278630257, 68.62642273306847, 80.35590693354607, 17.781305462121964, 1.5787301422096789, 0.5106862436514348, 0.4124778416007757, 22.63050075620413, 68.52667048573494, 56.428663060069084, 53.56370039284229, 30.83826933056116, 37.51698665320873, 33.61463025212288, 41.586385890841484, 53.17604519426823, 7.2971507627516985, 0.2974014321807772, 0.04823329072678462, 0.08399395112064667, 0.03801097089308314, 0.03314904271974228, 0.041646529716672376, 0.09912610476021655, 0.015769422861922067, 0.0748757466499228, 0.09563280822476372, 0.030614960924140178, 0.06432481124647893, 0.024033051704464015, 0.09643978992244229, 0.04112311522476375, 0.15148705017054453, 6.471879221498966, 50.9526477009058, 53.47430258989334, 42.08070516586304, 30.173911079764366, 48.26425775885582, 57.64805182814598, 89.40856397151947, 27.791364826261997, 0.32477400556672364, 0.5072830512654036, 0.5087442509829998, 46.21541529893875, 89.83075931668282, 78.81595596671104, 79.50342267751694, 81.5529491007328, 89.85281333327293, 72.1082367002964, 64.4206640124321, 79.69928696751595, 79.75337326526642, 74.78357434272766, 74.49578538537025, 70.89848801493645, 66.85615852475166, 66.78582429885864, 61.40043027698994, 60.668897330760956, 58.2692538946867, 58.20078916847706, 58.89327920973301, 57.66003258526325, 54.21000391244888, 52.84154534339905, 50.42213536798954, 52.652383893728256, 53.617889285087585, 51.42459377646446, 53.13339628279209, 53.55591841042042, 52.09765546023846, 49.0671356767416, 51.373608112335205, 49.79562118649483, 46.05449013411999, 48.7601425498724, 51.777043864130974, 51.04537412524223, 50.22285506129265, 49.40031699836254, 45.124775022268295, 47.322535291314125, 44.06404294073582, 45.7634561508894, 51.1078579723835, 42.65305705368519, 44.736276268959045, 44.037767350673676, 44.69714596867561, 44.848199263215065, 44.32182490825653, 47.5349210947752, 47.842320799827576, 45.28671093285084, 47.993731275200844, 51.39620549976826, 47.72278681397438, 52.26138487458229, 48.6875094473362, 49.24507632851601, 48.85796070098877, 66.61449149250984, 59.13884863257408, 65.5133181810379, 54.09637100994587, 38.47141943871975, 22.177661955356598, 40.53878590464592, 26.874477826058865, 34.38929468393326, 53.52325916290283, 37.51548193395138, 39.17785853147507, 49.93302181363106, 60.25959849357605, 51.61296866834164, 53.19200813770294, 51.138974502682686, 48.977452889084816, 48.244392424821854, 47.78419531881809, 48.580351397395134, 48.84958975017071, 50.050028935074806, 50.95431961119175, 48.37251774966717, 49.087369590997696, 47.938212454319, 46.12631008028984, 42.55195587873459, 40.3358805924654, 40.617966055870056, 46.26650355756283, 44.6503970772028, 44.50817450881004, 42.91303530335426, 44.32593248784542, 43.88596169650555, 44.21179801225662, 49.82544958591461, 48.540658727288246, 48.34612436592579, 46.90620303153992, 49.05125252902508, 48.8068800419569, 47.99281172454357, 53.42734470963478, 48.81307750940323, 51.74626551568508, 50.011198818683624, 50.76499857008457, 49.598844945430756, 51.03255741298199, 50.86361847817898, 49.37245689332485, 51.648511961102486, 55.13584703207016, 58.430756628513336, 59.75635729730129, 62.003427520394325, 61.30477041006088, 61.65596276521683, 61.51568569242954, 62.78488978743553, 58.802771866321564, 55.585233718156815, 55.69243736565113, 52.04921565949917, 57.27214179933071, 54.321018755435944, 63.60365845263004, 66.67921721935272, 76.64777711033821, 70.44116735458374, 89.86666738986969, 18.802276477217674, 2.062794123776257, 0.46642158762551844, 0.4536795651074499, 24.687178395688534, 77.57760241627693, 62.57366292178631, 65.15647932887077, 36.67317733168602, 36.71640761196613, 44.89280886948109, 49.61796551942825, 64.89539533853531, 9.78656105697155, 0.3803041367791593, 0.11052353380364366, 0.12846628233091906, 0.1010998168203514, 0.08915624130167998, 0.018638851506693754, 0.07850149428122677, 0.10612270940328017, 0.2636619145050645, 0.24367063801037148, 0.17433810367947444, 0.16727987851481885, 0.13881738705094904, 0.14299253176432103, 0.16329211124684662, 0.3406664152862504, 10.268253609538078, 69.97640669345856, 60.043944865465164, 46.105502396821976, 44.41110111773014, 62.48156726360321, 61.7064468562603, 97.67280891537666, 31.787220910191536, 0.4288152727531269, 1.1087490362115204, 0.6753468455281109, 47.079420536756516, 93.490981310606, 81.59811347723007, 83.13152119517326, 84.98845875263214, 86.156797260046, 72.10502207279205, 67.77246415615082, 81.18937700986862, 84.99367967247963, 76.44092381000519, 78.1771494448185, 73.03557693958282, 73.68180066347122, 71.5601921081543, 65.32077491283417, 62.22972057759762, 63.591791689395905, 62.2829595208168, 61.600744128227234, 60.76443940401077, 57.508614510297775, 56.64202161133289, 53.83928440511227, 54.61623631417751, 55.74064537882805, 53.61867964267731, 55.844383612275124, 58.355646058917046, 55.03355652093887, 51.760769337415695, 55.283138528466225, 50.46621300280094, 49.348518177866936, 50.499126836657524, 54.07300226390362, 53.65246742963791, 53.11686336994171, 51.411423683166504, 46.71994462609291, 48.65657910704613, 41.56567320227623, 45.80035977065563, 53.46220023930073, 45.59619292616844, 48.184359446167946, 49.24192249774933, 47.27133683860302, 46.947860196232796, 46.14888846874237, 51.91271938383579, 49.658228158950806, 47.89581052958965, 51.36979691684246, 54.37716834247112, 50.4383946955204, 55.41330434381962, 50.41637107729912, 52.3369400203228, 50.01567877829075, 68.12610357999802, 63.49508687853813, 68.35558846592903, 55.97733087837696, 39.1654521971941, 23.46944823861122, 46.661910340189934, 27.324985451996326, 38.879148960113525, 57.283601984381676, 40.533200204372406, 45.55158331990242, 53.32189276814461, 61.811712607741356, 53.37783336639404, 55.43831840157509, 55.34345269203186, 49.99250002205372, 50.43603502213955, 49.23807330429554, 49.58016894757748, 51.14057421684265, 51.81956358253956, 55.701385885477066, 51.25944323837757, 52.53156177699566, 51.89940109848976, 50.57443119585514, 46.60206355154514, 44.50645700097084, 43.973615393042564, 49.807058572769165, 45.8829103410244, 46.64103426039219, 44.150385707616806, 45.64885430037975, 45.62721826136112, 45.185324773192406, 51.30119539797306, 51.7609479278326, 51.16421274840832, 49.94248330593109, 51.65743388235569, 51.20634488761425, 50.936323776841164, 55.80097854137421, 51.48220248520374, 52.18572333455086, 53.2096391916275, 52.926265597343445, 51.6669599711895, 52.98833906650543, 52.742404863238335, 50.57589411735535, 53.82483758032322, 57.76711843907833, 62.07060791552067, 64.54316943883896, 66.07427448034286, 65.37961095571518, 64.32527393102646, 64.74255234003067, 66.80478528141975, 61.17687687277794, 59.131682217121124, 58.81649672985077, 54.83500577509403, 61.95953227579594, 58.216315135359764, 66.95911020040512, 69.39657300710678, 81.5983946621418, 76.06013864278793, 88.53777229785919, 16.86995856463909, 1.658807995263487, 1.2370636384002864, 0.347670330083929, 31.331370770931244, 84.74277913570404, 71.30613014101982, 73.65900188684464, 48.06093826889992, 49.3415417522192, 51.15625977516174, 57.414801344275475, 77.1127961575985, 12.336929105222225, 0.4824811883736402, 0.22655338776530698, 0.2682737389113754, 0.18691462726565078, 0.18849234416848049, 0.21085276384837925, 0.2912067552097142], [0.08140853125951253, 0.02608445178339025, 0.039769623399479315, 0.039962288647075184, 0.04525112613919191, 0.01218104051076807, 0.06842421236797236, 0.11355847251252271, 0.13230115233454853, 6.201146123930812, 42.99793414771557, 40.51895096898079, 46.67840525507927, 43.967870101332664, 51.270713433623314, 57.76193171739578, 82.26582884788513, 13.66377990692854, 0.21191422798437998, 0.258969611604698, 3.243475081399083, 69.99111950397491, 79.46562230587006, 81.42159014940262, 76.14070191979408, 82.58420616388321, 65.72434365749359, 61.005806252360344, 79.23810571432114, 78.75836625695229, 74.28179606795311, 73.21561127901077, 69.64162185788155, 63.49697157740593, 59.5837477594614, 60.650563314557076, 53.59082333743572, 53.44887055456638, 50.77240437269211, 51.921512112021446, 49.41835083067417, 50.94026416540146, 48.92617464065552, 52.856702730059624, 52.47665472328663, 48.89658562839031, 49.23080049455166, 50.77698692679405, 49.43376660346985, 54.30140420794487, 48.15878301858902, 49.5969108492136, 50.25020979344845, 45.76379053294659, 46.87095232307911, 47.44176909327507, 48.76022234559059, 48.643329218029976, 50.429712161421776, 47.75651000440121, 44.24386449158192, 44.324632957577705, 42.076707780361176, 43.29983934760094, 44.17940855026245, 44.13000740110874, 36.706417948007584, 42.278233766555786, 39.20820750296116, 41.04105435311794, 41.564476266503334, 42.169027626514435, 40.61408646404743, 44.59267057478428, 47.68679514527321, 44.36756305396557, 44.2864716053009, 46.89411208033562, 45.45936606824398, 47.693927362561226, 43.9297429472208, 52.265769839286804, 55.51742635667324, 59.58815172314644, 53.84010896086693, 48.49117398262024, 19.809790514409542, 27.032602541148663, 33.967084139585495, 19.607506468892097, 41.9212581217289, 42.451219484210014, 38.22838827967644, 53.263493701815605, 55.23645423352718, 50.42471922934055, 49.653322622179985, 46.22952774167061, 45.72663612663746, 45.509998351335526, 45.73931224644184, 45.43096259236336, 43.99043329060078, 45.81717386841774, 47.51152195036411, 44.57745619118214, 42.99356438219547, 42.31104500591755, 43.43319319188595, 39.2729826271534, 38.978783413767815, 40.96130043268204, 44.31342735886574, 44.41765956580639, 42.067128494381905, 42.56940074265003, 43.902544006705284, 44.18532483279705, 42.0658403635025, 46.51683792471886, 47.61059783399105, 45.51224783062935, 45.708556696772575, 44.27973456680775, 45.645407885313034, 44.0448197722435, 48.85222300887108, 47.87744991481304, 46.83216020464897, 46.58181443810463, 47.26968012750149, 48.86869132518768, 48.690997660160065, 49.46283884346485, 49.822246357798576, 49.67381112277508, 46.84432715177536, 48.821649849414825, 48.50507363677025, 51.30496099591255, 50.985306948423386, 51.6529843211174, 49.39563944935799, 50.67805923521519, 51.350824534893036, 50.534833520650864, 51.52935415506363, 51.28237500786781, 54.56107847392559, 63.69465596973896, 64.50776293873787, 69.5980229973793, 70.95534056425095, 76.05328381061554, 69.9644373357296, 39.77255322039127, 1.2479728530161083, 0.06309779622824863, 0.2855090203229338, 12.599696405231953, 70.71863606572151, 55.42618565261364, 54.01405982673168, 37.85822734236717, 41.03556364774704, 35.8625478297472, 41.364314407110214, 48.13969664275646, 5.7076347805559635, 0.08912631048588082, 0.13797687512123957, 0.05845736202900298, 0.02020738618739415, 0.018365717041888274, 0.09360501586343162, 0.07036708819214255, 0.10385440924437717, 0.07461965375114232, 0.05353868553356733, 0.03688941134896595, 0.05687639080861118, 0.10098686936544254, 0.049404273595428094, 0.139575194043573, 0.14237132447306067, 11.906726639717817, 60.57386822998524, 50.407578349113464, 59.160298481583595, 34.430564269423485, 62.96009078621864, 64.58534717559814, 89.83845010399818, 14.777430798858404, 0.12269445142010227, 0.39044285367708653, 4.249459700658917, 75.11525094509125, 80.34657463431358, 83.05115550756454, 79.28773105144501, 85.56782126426697, 70.54893717169762, 62.69351989030838, 80.29421344399452, 82.41925701498985, 76.09541594982147, 75.48194646835327, 71.41371756792068, 66.02543950080872, 62.7143731713295, 63.09748001396656, 57.268516793847084, 56.77806571125984, 54.850090965628624, 55.58064356446266, 52.01443612575531, 52.97168456017971, 52.95897424221039, 53.68971683084965, 53.78989465534687, 50.513250678777695, 50.19155614078045, 52.860597521066666, 54.09285619854927, 54.02508303523064, 50.17109803855419, 52.488529086112976, 52.3897609859705, 49.675935208797455, 49.90343660116196, 50.049470365047455, 50.04185937345028, 50.887017622590065, 53.274950087070465, 50.48867739737034, 44.71203736960888, 44.419491067528725, 43.38196434080601, 42.40137755870819, 45.58146871626377, 48.59621934592724, 39.051431715488434, 43.49087789654732, 42.71033897995949, 43.151453509926796, 43.63392502069473, 45.84021583199501, 43.356699496507645, 48.75796526670456, 49.30346019566059, 47.0722047239542, 47.16453596949577, 47.90378250181675, 48.23110073804855, 48.92506130039692, 45.76539784669876, 54.37264658510685, 58.6570230871439, 60.73357366025448, 57.399598360061646, 55.11399820446968, 23.264358043670654, 31.098158285021782, 39.4140500575304, 20.74677273631096, 42.3793463408947, 45.04847891628742, 40.07510058581829, 56.71149328351021, 58.125101029872894, 53.326520919799805, 52.481985837221146, 49.771017506718636, 46.491660475730896, 47.57652886211872, 47.969412580132484, 46.65581926703453, 46.0237991809845, 47.81372353434563, 47.93918900191784, 45.558096170425415, 46.1610896140337, 44.85790014266968, 44.427466839551926, 43.414608389139175, 40.95267489552498, 44.553057700395584, 44.71896439790726, 44.73026879131794, 42.74078294634819, 43.21264922618866, 42.84818418323994, 43.371165320277214, 42.718326151371, 47.56912685930729, 50.20302772521973, 47.34305419027805, 49.077360928058624, 47.50457972288132, 47.980568781495094, 46.442662104964256, 51.57435514032841, 49.53218512237072, 48.00057850778103, 48.04003559052944, 49.75931793451309, 49.803551360964775, 51.69936463236809, 51.62532560527325, 50.91025337576866, 52.326893359422684, 51.02822184562683, 50.81665299832821, 51.03757694363594, 52.30522692203522, 52.521370723843575, 51.82476930320263, 51.36592872440815, 52.916336730122566, 55.11134214699268, 52.12666690349579, 54.17169436812401, 53.523080572485924, 58.34133602678776, 66.68427854776382, 67.56646201014519, 73.86404648423195, 74.25655022263527, 79.3026414513588, 76.56264647841454, 46.06001503765583, 0.8172499935608357, 0.22027976112440228, 0.3397248376859352, 13.328350055962801, 79.00986716151237, 60.76738424599171, 66.4011025428772, 40.236892104148865, 36.64462186396122, 47.17241674661636, 49.14234884083271, 59.851963967084885, 9.206815715879202, 0.10652365468558855, 0.04167985214735381, 0.02579697160399519, 0.024031201901379973, 0.06366228117258288, 0.021980605197313707, 0.023083779888111167, 0.2061035975930281, 0.21029440162237734, 0.1325429292046465, 0.10153128663660027, 0.22378194116754457, 0.14705620589666069, 0.12210025830427185, 0.2570480725262314, 0.3482864610850811, 14.277246538549662, 75.58315023779869, 54.629759788513184, 65.3732804954052, 65.84533676505089, 73.44603091478348, 69.9898199737072, 98.50843727588654, 16.9608211889863, 0.2363901396165602, 1.1703957407735288, 4.3246804643422365, 80.42996495962143, 82.06276774406433, 87.2587077319622, 83.88575032353401, 84.79566469788551, 70.69183230400085, 65.42213067412376, 81.59039989113808, 87.46411710977554, 79.17704299092293, 78.20241808891296, 75.26486411690712, 68.18651273846626, 63.09902273118496, 65.59816762804985, 59.89648997783661, 58.70599485933781, 57.800849229097366, 58.471608236432076, 55.12725569307804, 54.753534346818924, 55.594915598630905, 57.14316911995411, 57.06217646598816, 54.41671662032604, 54.08245235681534, 54.76328082382679, 55.50200678408146, 58.223929926753044, 52.945739552378654, 55.71311965584755, 55.94582676887512, 51.327755972743034, 54.67907354235649, 53.252535089850426, 52.04759694635868, 54.71387967467308, 55.160427913069725, 50.270196720957756, 45.81261411309242, 45.48920586705208, 44.27108243107796, 44.38554368913174, 48.145650923252106, 51.28427870571613, 41.48480214178562, 47.53876268863678, 46.25969432294369, 46.349312514066696, 46.60687029361725, 49.71379637718201, 44.665204882621765, 50.706971883773804, 51.62533700466156, 49.71245504915714, 49.26249839365482, 50.69157510995865, 50.495448634028435, 53.31495054066181, 49.10121224820614, 57.11975857615471, 59.78861756622791, 63.31912212073803, 61.527829840779305, 59.28460121154785, 24.268845543265343, 36.74349635839462, 44.710069075226784, 23.42756688594818, 46.77646279335022, 47.98249527812004, 41.27388305962086, 59.05441336333752, 63.17549742758274, 57.00696162879467, 55.88205859065056, 51.81208558380604, 48.835370913147926, 51.02195978164673, 49.74129170179367, 49.61947783827782, 49.13685813546181, 51.71188876032829, 51.79471291601658, 48.194983676075935, 49.15127456188202, 47.855791077017784, 47.889860048890114, 45.426201447844505, 43.27615901827812, 47.03657403588295, 46.33560284972191, 45.79865366220474, 44.97442469000816, 42.47990034520626, 43.748534470796585, 43.520459309220314, 41.48476034402847, 47.998724207282066, 51.911666840314865, 48.91654595732689, 51.13246165215969, 50.76585352420807, 51.73322081565857, 49.83057551085949, 53.041919991374016, 51.353036016225815, 49.81550171971321, 50.87285578250885, 52.89886146783829, 53.66568312048912, 53.627286180853844, 54.92614008486271, 54.160268381237984, 54.25303280353546, 52.047874331474304, 54.17216554284096, 54.41932328045368, 56.85504958033562, 54.979303032159805, 55.63004091382027, 53.7080280482769, 55.16876466572285, 58.35059992969036, 55.08987329900265, 57.8836315870285, 56.86985358595848, 61.271313205361366, 69.41576957702637, 71.67747661471367, 76.82414084672928, 77.41204530000687, 82.26199865341187, 79.48843628168106, 44.25596684217453, 1.7786494083702564, 0.5934280506335199, 0.4571236053016037, 17.426961176097393, 84.49198499321938, 68.48661303520203, 69.04833689332008, 58.18242855370045, 56.63294769823551, 53.56600686907768, 57.82490573823452, 72.58159250020981, 11.906216517090797, 0.14738482888787985, 0.21884630288695917, 0.15167426434345543, 0.10855269385501742, 0.09812027201405726, 0.11508973097079434, 0.11895340372575447], [0.07583362923469394, 0.05004911457945127, 0.08609597309259698, 0.010489047708688304, 0.04236063534335699, 0.04570896446239203, 0.01871027023298666, 0.059770963416667655, 0.05235009150055703, 11.396520417183638, 50.24412252008915, 39.53054420650005, 44.300211668014526, 44.909759759902954, 56.38964295387268, 58.84529538452625, 81.84909000992775, 5.118816001340747, 0.10525310528464615, 0.046566998498747125, 13.924996890127659, 78.31249818205833, 75.92823252081871, 81.13380879163742, 77.42491900920868, 71.380036175251, 62.246481478214264, 79.37805220484734, 74.23264190554619, 75.4478394985199, 71.36217713356018, 67.9388116300106, 63.51371727883816, 68.23043838143349, 59.743582382798195, 60.63074737787247, 57.43011452257633, 54.61385764181614, 51.917917504906654, 53.533594608306885, 51.7721801251173, 49.96321879327297, 49.77204345166683, 49.09069821238518, 50.25527872145176, 50.70266291499138, 49.08415496349335, 52.00117103755474, 48.35300959646702, 49.734718054533005, 47.115864381194115, 48.11636969447136, 47.45464280247688, 46.477168053388596, 43.38095359504223, 45.754682421684265, 50.41571371257305, 43.64875182509422, 48.55603650212288, 48.35630401968956, 44.636854603886604, 42.079356238245964, 43.437186777591705, 45.79741112887859, 46.70314572751522, 48.27579014003277, 43.80586959421635, 38.6048074811697, 40.76244190335274, 41.34238198399544, 41.780399680137634, 40.4422140866518, 40.97873389720917, 40.44633686542511, 45.2801638841629, 45.277329236269, 45.792592987418175, 46.18540830910206, 45.44638976454735, 46.1255045235157, 46.71909727156162, 45.932566076517105, 57.59990081191063, 59.75481078028679, 60.54028943181038, 46.05813033878803, 32.05623507499695, 34.69108588993549, 36.1060805618763, 28.487460874021053, 38.987606540322304, 48.314863443374634, 55.56860961019993, 59.095641151070595, 52.34016604721546, 49.76699732244015, 45.314715430140495, 45.07846310734749, 45.57723194360733, 47.43945501744747, 44.16700601577759, 44.6852146089077, 43.65029454231262, 43.84806253015995, 43.61405588686466, 40.24630419909954, 39.45286497473717, 38.45861412584782, 40.280376970767975, 40.50375938415527, 41.3055619597435, 45.59030324220657, 46.855357959866524, 46.81889891624451, 43.750445768237114, 47.5972605496645, 42.53074161708355, 42.49983407557011, 39.29684914648533, 47.410466372966766, 46.62083834409714, 45.55213429033756, 45.37417083978653, 44.22563686966896, 43.07648353278637, 45.557556599378586, 47.25722439587116, 46.5546914935112, 47.02400051057339, 47.73503735661507, 47.116464748978615, 46.1766117811203, 47.41405338048935, 48.06099906563759, 48.229953199625015, 47.61686369776726, 47.703852429986, 46.576202139258385, 47.77471102774143, 47.92195312678814, 49.222376346588135, 48.82451869547367, 49.581890255212784, 51.43768407404423, 51.407901272177696, 54.23180714249611, 54.387203603982925, 58.67093414068222, 61.883118376135826, 67.1220226585865, 65.64078614115715, 69.30351600050926, 72.46162533760071, 75.14259427785873, 69.45110008120537, 51.735728681087494, 0.9489491453859955, 0.24251051276223734, 0.2683578687720001, 4.4967475812882185, 65.25351852178574, 60.15151709318161, 54.75278578698635, 44.71772186458111, 53.17794509232044, 35.47501042485237, 41.25174544751644, 53.119971603155136, 7.698315661400557, 0.2055148221552372, 0.0848136235435959, 0.09351341257570311, 0.06175757029268425, 0.05511728930287063, 0.0345186502818251, 0.02403410184342647, 0.026540351245785132, 0.05093650055641774, 0.08813822991214693, 0.07554603216703981, 0.08489370869938284, 0.04987989377696067, 0.03146185161313042, 0.07737595311482437, 0.15158502850681543, 17.457163855433464, 63.91724422574043, 48.75142581760883, 42.892250418663025, 40.713998302817345, 67.36739829182625, 64.64349925518036, 87.73463979363441, 5.30990157276392, 0.11857544275699183, 0.07343364981352352, 16.72825276851654, 82.1466900408268, 78.39490815997124, 83.27842131257057, 76.69502377510071, 76.06083780527115, 67.30685994029045, 78.96439120173454, 75.84426462650299, 77.73923814296722, 73.74307617545128, 72.06436425447464, 66.9966521859169, 68.06450888514519, 62.63478264212608, 62.50313110649586, 58.541444689035416, 57.62393832206726, 53.94535951316357, 57.33478143811226, 53.94603207707405, 52.528651133179665, 52.39950746297836, 50.61165779829025, 52.85534620285034, 53.48086103796959, 52.59292088449001, 54.95453596115112, 49.22535918653011, 51.645183339715004, 49.696370512247086, 49.87010858952999, 49.756148904562, 48.52370783686638, 44.84052747488022, 49.890266507864, 52.116597443819046, 46.8704279512167, 48.829272240400314, 50.43749414384365, 44.13627706468105, 42.73799389600754, 43.60837899148464, 46.45870104432106, 45.31724229454994, 49.80165146291256, 45.877324640750885, 42.19297394156456, 42.62101337313652, 44.48252588510513, 44.968911185860634, 42.79086425900459, 43.952332735061646, 43.95548276603222, 47.173917666077614, 49.016906172037125, 48.34263615310192, 49.60125021636486, 46.86684474349022, 49.76122923195362, 49.694998785853386, 47.436563372612, 57.551806792616844, 62.21197932958603, 62.770735546946526, 49.76207658648491, 36.32854722440243, 40.113615319132805, 40.56935906410217, 31.362833082675934, 42.46562451124191, 49.72360745072365, 57.27657236158848, 61.28572963178158, 56.28525875508785, 51.165592074394226, 46.43863432109356, 46.297825276851654, 47.44856312870979, 48.405898958444595, 46.440158039331436, 46.463344395160675, 44.35460574924946, 47.04582653939724, 46.09560772776604, 43.10572676360607, 43.63082438707352, 41.38421393930912, 43.25017601251602, 41.90823622047901, 44.26737003028393, 49.10344272851944, 48.76139648258686, 48.48457753658295, 46.14557504653931, 46.91829778254032, 43.03201071918011, 42.925316244363785, 39.52980324625969, 47.939321994781494, 49.019102454185486, 48.63002233207226, 47.00506612658501, 47.06381097435951, 44.866909459233284, 48.97620275616646, 50.849407240748405, 48.87117259204388, 49.17547546327114, 49.98560719192028, 49.254712611436844, 48.27973812818527, 49.19847562909126, 50.107584446668625, 48.99180851876736, 47.4974475055933, 50.64576476812363, 49.52314540743828, 50.2294135093689, 50.741728618741035, 50.79935632646084, 51.43891900777817, 51.204779371619225, 53.74519765377045, 54.36845920979977, 56.242951825261116, 57.4108761548996, 61.045346930623055, 66.1442743241787, 69.56223651766777, 68.12983497977257, 72.7918504178524, 75.27842938899994, 78.10647323727608, 70.13041242957115, 63.880355805158615, 1.1714466218836606, 0.15377276111394167, 0.2570674871094525, 4.807443609461188, 71.01043000817299, 66.35133281350136, 64.18676376342773, 52.2042815387249, 48.71960632503033, 42.24175192415714, 49.70388650894165, 64.92543652653694, 10.882488749921322, 0.25512623658869416, 0.10626610717736185, 0.0390897567558568, 0.08615109240054153, 0.026268274341418874, 0.049880357619258575, 0.054339937851182185, 0.17264950991375372, 0.12799730437109247, 0.2445830195210874, 0.15612235612934455, 0.14742594386916608, 0.1915608427952975, 0.1467193302232772, 0.19670508394483477, 0.2608494716696441, 25.041573978960514, 78.83671045303345, 56.89161501824856, 59.07728053629398, 64.53249201178551, 76.1469791829586, 68.76867949962616, 97.40012794733047, 6.674930350854993, 0.30377253249753267, 0.19815233128610998, 18.351506665349007, 86.43494233489037, 80.54271250963211, 88.64629447460175, 80.43351396918297, 76.58243581652641, 67.38933071494102, 82.38449648022652, 78.16130429506302, 80.72901651263237, 76.8660905957222, 75.64329341053963, 69.43392500281334, 71.6161023080349, 65.66465646028519, 65.66027149558067, 62.82111704349518, 60.54985731840134, 55.43217033147812, 59.753074273467064, 58.17584350705147, 55.989562422037125, 56.05053395032883, 54.83934514224529, 57.330799251794815, 56.05047695338726, 55.351732447743416, 56.8855619430542, 52.047634944319725, 54.90765407681465, 51.19041994214058, 52.08953529596329, 54.21693094074726, 51.44488088786602, 46.41842320561409, 51.927462592720985, 56.40057876706123, 47.4819253385067, 52.45532266795635, 51.522533521056175, 44.826263040304184, 44.0410465747118, 43.179723992943764, 46.741797253489494, 46.6274081915617, 51.164604127407074, 48.49028863012791, 45.47088325023651, 47.48773142695427, 47.82418817281723, 48.46457161009312, 46.34853355586529, 46.018430069088936, 45.75566276907921, 51.13982565701008, 50.80997675657272, 49.3486587703228, 52.3139588534832, 50.428006052970886, 51.59572519361973, 51.78036108613014, 50.553064942359924, 60.287849977612495, 66.41587615013123, 65.45746877789497, 52.849346324801445, 36.763255298137665, 46.83825507760048, 48.49822260439396, 34.50900726020336, 46.00041523575783, 50.333353132009506, 59.84525352716446, 63.558418080210686, 60.026830583810806, 54.529217183589935, 49.2964381724596, 48.26502911746502, 48.70854511857033, 51.20727203786373, 48.52400042116642, 48.383757546544075, 48.87900397181511, 50.64566597342491, 49.6932964771986, 46.534989550709724, 45.08201591670513, 43.04103143513203, 46.19216434657574, 45.46940892934799, 48.73024955391884, 50.42254954576492, 49.63205896317959, 51.034776493906975, 47.644241228699684, 49.90654483437538, 43.00537794828415, 42.217752411961555, 39.92479585111141, 49.003477692604065, 49.84224088490009, 50.14010310173035, 49.83599781990051, 51.95740878582001, 48.39369401335716, 51.014265194535255, 51.63208544254303, 51.82341277599335, 50.098632127046585, 51.87557637691498, 51.99063800275326, 50.933743715286255, 52.165671810507774, 53.1061365455389, 51.073055639863014, 51.94958880543709, 54.12517346441746, 53.25031980872154, 52.85747408866882, 52.911841571331024, 53.706059753894806, 55.4312089830637, 53.75605747103691, 58.02428103983402, 55.4759705811739, 60.52580080926418, 58.874375224113464, 63.84900748729706, 67.07552075386047, 76.43559649586678, 69.92590740323067, 77.96217978000641, 77.44544550776482, 82.76562362909317, 70.40532007813454, 74.32848796248436, 4.378606220707297, 0.7626110629644245, 0.3138456435408443, 6.721647419035435, 79.65099915862083, 75.16536265611649, 70.48510059714317, 70.60490816831589, 72.36975386738777, 52.317462265491486, 59.387051314115524, 76.58571124076843, 15.521383378654718, 0.431881767581217, 0.15119302610401064, 0.19628770009148866, 0.16166870773304254, 0.10607448464725167, 0.15355525247287005, 0.1138963203993626], [0.06824171083280817, 0.08306528688990511, 0.025174571310344618, 0.02497944027709309, 0.019210872960684355, 0.03770790746784769, 0.11682369964546524, 0.036440152252907865, 0.21107634325744584, 11.803729366511106, 48.464640006423, 36.89829625189304, 43.64242136478424, 41.65868081152439, 55.6205528229475, 66.70409828424454, 67.79591649770737, 1.1519574676640332, 0.09333798370789737, 0.139899913338013, 29.798299334943295, 82.9438416659832, 72.15964794158936, 79.90607187151909, 77.09974005818367, 66.15315064787865, 69.07383352518082, 76.11093431711197, 73.24854031205177, 77.1357773244381, 68.68873178958893, 73.53091835975647, 69.08835634589195, 69.9315918982029, 66.01369813084602, 63.919227719306946, 54.32651326060295, 57.070551216602325, 51.77762143313885, 52.19910241663456, 48.88261757791042, 49.26201581954956, 49.37012381851673, 49.59499955177307, 49.12800841033459, 51.18626296520233, 49.216657653450966, 49.91588853299618, 49.02861334383488, 51.73674702644348, 46.459039226174355, 49.5495729893446, 48.643329218029976, 45.5855268985033, 44.41961646080017, 45.58814495801926, 46.47928833961487, 47.62678876519203, 49.48945641517639, 47.52895921468735, 46.08916327357292, 44.36626352369785, 45.89263401925564, 46.17728054523468, 37.676308304071426, 43.4651380777359, 47.232297733426094, 45.680943578481674, 39.74408134818077, 41.33543595671654, 39.791985377669334, 41.18219017982483, 40.497406125068665, 42.188338190317154, 40.98058819770813, 44.153702929615974, 44.221696481108665, 48.46375845372677, 53.13032604753971, 53.383202478289604, 52.310352846980095, 51.268965527415276, 49.126131311059, 55.13211563229561, 52.88643233478069, 56.01309075951576, 35.89845970273018, 36.3008239120245, 41.180206686258316, 39.892178401350975, 39.55172047019005, 48.934746980667114, 56.034874990582466, 54.3622275441885, 53.45465004444122, 45.72344429790974, 48.675638884305954, 46.57434403896332, 46.23203560709953, 43.99133384227753, 46.768312230706215, 44.7977227717638, 43.58285196125507, 40.58324731886387, 41.353048011660576, 40.075001791119576, 40.21890386939049, 40.215541049838066, 40.71364112198353, 43.82029362022877, 48.18233795464039, 50.13742424547672, 48.49010244011879, 41.33282549679279, 43.098313361406326, 49.134335070848465, 45.262175649404526, 42.30970747768879, 44.51249487698078, 44.85870189964771, 48.53647895157337, 46.54220536351204, 43.63197572529316, 43.53530131280422, 42.393876761198044, 45.49080178141594, 47.37615041434765, 45.7438188046217, 47.43984639644623, 46.74976542592049, 47.18450389802456, 47.229520082473755, 48.971707597374916, 47.78365954756737, 47.31881909072399, 48.357972130179405, 48.26631344854832, 46.98196716606617, 50.50763837993145, 49.133031740784645, 50.16328565776348, 49.88202095031738, 48.16129848361015, 49.67248499393463, 52.92409211397171, 50.87239220738411, 56.3176292181015, 65.02553835511208, 66.19703069329262, 68.83858054876328, 68.72698813676834, 70.80239117145538, 70.8150140941143, 70.86875841021538, 76.05838313698769, 60.50404317677021, 2.6262625632807612, 0.4814552137395367, 0.32508799340575933, 0.2597516274545342, 43.53052876889706, 66.30899548530579, 51.98463432490826, 52.86801092326641, 37.695045098662376, 22.272250279784203, 40.45201376080513, 49.19262394309044, 13.413019962608814, 0.25056971702724695, 0.13669417676283047, 0.0269428049432463, 0.11304526255116798, 0.031782626392669044, 0.037787198525620624, 0.04283048532670364, 0.010308538840035908, 0.022582284727832302, 0.01897410929814214, 0.020483765692915767, 0.09492595709161833, 0.06451761379139498, 0.05078903952380642, 0.06543686016811989, 0.20271572313504294, 19.74720787256956, 60.85813857614994, 49.67423290014267, 43.302206620574, 41.84016667306423, 68.9258162677288, 72.76905924081802, 75.24824380874634, 1.317888388875872, 0.06368358081090264, 0.37447112321387976, 35.904269590973854, 83.24787095189095, 75.77054858207703, 82.82789468765259, 76.12727344036102, 69.05908271670341, 73.68674799799919, 78.73615264892578, 77.11740911006927, 79.94323387742043, 70.84617242217064, 73.4830105304718, 72.80759677290916, 74.03861671686172, 69.12800341844559, 66.73812165856361, 57.06800915300846, 60.09433016180992, 55.018577724695206, 54.516199082136154, 54.11334469914436, 53.93042631447315, 51.51122532784939, 51.360479816794395, 50.27322515845299, 54.54791598021984, 53.11028212308884, 51.26964949071407, 52.81285308301449, 52.55056835711002, 51.612041518092155, 51.62141181528568, 49.87132452428341, 49.11518409848213, 46.529175862669945, 48.59741248190403, 49.4037102162838, 48.66749592125416, 51.19243383407593, 47.71906681358814, 46.10784687101841, 44.37771990895271, 48.106968998909, 47.62880265712738, 40.2696767449379, 43.95887218415737, 49.08983565866947, 47.9882899671793, 42.361643090844154, 44.07138414680958, 42.32280537486076, 44.121564254164696, 43.571927547454834, 45.19150324165821, 44.230341017246246, 47.64719367027283, 47.02704034745693, 51.09740473330021, 57.36883521080017, 56.06619291007519, 54.896311685442924, 53.01505543291569, 53.89612555503845, 57.99928218126297, 56.965787038207054, 60.824449583888054, 39.343974217772484, 40.10506197810173, 44.88031513988972, 41.96914695203304, 40.88768318295479, 50.04991114139557, 60.76761603355408, 58.54821212589741, 56.64516404271126, 48.8616769015789, 50.92301309108734, 48.09901222586632, 45.784738808870316, 45.45725338160992, 48.487191796302795, 46.316991448402405, 45.69452404975891, 43.622214049100876, 43.779157027602196, 41.558920964598656, 43.79875637590885, 43.6296084523201, 43.01387429237366, 46.53020180761814, 48.15234996378422, 51.41938425600529, 49.69195514917374, 44.601140320301056, 44.56178963184357, 48.88932801783085, 46.406267657876015, 42.61249043047428, 44.92153152823448, 46.224276423454285, 49.127415642142296, 48.43324989080429, 48.92631143331528, 46.93116769194603, 45.672181248664856, 45.89962184429169, 49.08224366605282, 48.77839297056198, 48.985804840922356, 49.50938634574413, 48.86391878128052, 49.593878611922264, 51.35961726307869, 50.03586709499359, 50.09988225996494, 50.421933978796005, 50.320677012205124, 51.593141332268715, 51.367760226130486, 52.59286008775234, 51.79019495844841, 52.59078919887543, 50.73423162102699, 52.14131511747837, 54.349593222141266, 53.22840258479118, 59.44822423160076, 69.3513934314251, 69.61613282561302, 73.23802247643471, 71.22306659817696, 74.58093881607056, 72.51668438315392, 75.51049053668976, 74.9870078265667, 76.67738512158394, 4.713851781561971, 1.1503626219928265, 0.6687800260260701, 0.5766918486915529, 48.2290830463171, 75.52183672785759, 60.087190344929695, 61.7998306453228, 33.72288264334202, 31.769595555961132, 48.587597608566284, 59.24335062503815, 17.866726778447628, 0.229396095382981, 0.06638761813519523, 0.040645684202900156, 0.027640119478746783, 0.034009748487733305, 0.02080161084450083, 0.08351723998202942, 0.2154807819169946, 0.14556021429598331, 0.1183746027527377, 0.08069491916103289, 0.14576393383322284, 0.15785565687110648, 0.20016178517835215, 0.12952520832186565, 0.2835424477234483, 25.584880225360394, 77.69332900643349, 53.34673583507538, 62.47263394296169, 62.33163110911846, 76.52284741401672, 80.7096679508686, 83.59543070197105, 1.729748526122421, 0.19112635985948145, 0.4247953853337094, 38.29759016633034, 87.32775002717972, 78.12047928571701, 85.74694365262985, 80.93063369393349, 72.11167931556702, 72.3666000366211, 80.94321101903915, 80.16268730163574, 83.71082291007042, 74.80707228183746, 77.37894147634506, 74.65436607599258, 77.6842474937439, 72.03652694821358, 70.17002910375595, 58.61130394041538, 64.62720572948456, 57.47741438448429, 57.188553884625435, 57.538317516446114, 56.69436760246754, 57.077170461416245, 54.98480133712292, 54.43802587687969, 56.803623139858246, 55.97834922373295, 53.43996003270149, 56.15507774055004, 55.721536204218864, 52.166306376457214, 53.97999085485935, 52.63855263590813, 52.54580341279507, 50.15825852751732, 50.91058775782585, 51.37972578406334, 52.923529744148254, 51.77115797996521, 47.70139016211033, 47.51967251300812, 45.110685378313065, 49.14112530648708, 48.93443159759045, 42.66871601343155, 44.64668847620487, 50.13629570603371, 52.85478763282299, 46.46953046321869, 48.00471268594265, 45.43309047818184, 47.44922809302807, 46.1350192129612, 47.79825456440449, 47.0297572016716, 50.27703635394573, 50.12741178274155, 52.944394424557686, 58.24393205344677, 57.10494317114353, 57.30182580649853, 55.11415399610996, 56.327083110809326, 61.97791188955307, 61.78409568965435, 62.67618142068386, 46.09392061829567, 43.996357172727585, 50.08023351430893, 47.912525832653046, 44.55256752669811, 53.32723908126354, 63.473488837480545, 60.72799555957317, 58.19573163986206, 52.00823485851288, 51.758360266685486, 52.66428865492344, 50.85392899811268, 47.95550152659416, 50.25492534041405, 47.829226702451706, 48.917837888002396, 45.85704892873764, 47.62765131890774, 44.07419979572296, 46.35972775518894, 47.26607412099838, 46.15498714148998, 50.38597650825977, 51.15890063345432, 51.890859156847, 50.29326908290386, 45.42875111103058, 46.2187135219574, 49.4861201941967, 47.47964546084404, 44.255833849310875, 46.64692394435406, 46.92039526998997, 52.01019935309887, 50.09439915418625, 49.373547434806824, 50.06465435028076, 47.63517111539841, 50.4973941296339, 51.39534294605255, 50.90914003551006, 51.66648879647255, 51.5872098505497, 51.697202548384666, 52.39948086440563, 54.604137763381004, 52.86596283316612, 50.787493363022804, 54.76882092654705, 54.629976376891136, 53.48369188606739, 54.961364194750786, 57.143704891204834, 54.809805527329445, 55.22547282278538, 52.10241660475731, 55.597317069768906, 56.62749119102955, 57.49764069914818, 61.85773953795433, 74.07849177718163, 70.80187439918518, 74.51913133263588, 73.95853981375694, 79.08044457435608, 73.49897727370262, 80.66622108221054, 76.6446004807949, 81.37609899044037, 8.492141515016556, 0.9583791112527251, 0.7245440525002778, 0.8656172419432551, 58.94271835684776, 81.74715667963028, 67.586540132761, 73.64966198801994, 52.89378114044666, 44.41256023943424, 61.46579436957836, 70.5701020359993, 24.02482643723488, 0.40465703001245856, 0.21940432372502983, 0.19052360235946253, 0.20661073678638786, 0.18730432901065797, 0.11799639687524177, 0.26941358868498355], [0.019998523566755466, 0.01715934857202228, 0.04913242861221079, 0.06223449294338934, 0.123154367756797, 0.05597618051979225, 0.03235009477066342, 0.020716345497930888, 0.2399184284149669, 19.464402347803116, 47.41438776254654, 32.77887649834156, 47.38043278455734, 40.69237746298313, 60.12522630393505, 70.27387753129005, 52.78406202793121, 0.2736055356217548, 0.09006526830489747, 0.9287852898705751, 55.47301433980465, 74.52396467328072, 75.20926550030708, 73.02409395575523, 71.04723483324051, 70.01119762659073, 66.47237911820412, 82.00191020965576, 71.48847475647926, 73.41648370027542, 73.0969588458538, 71.7694316804409, 69.72383424639702, 72.32105568051338, 72.96898931264877, 67.18669518828392, 57.31568746268749, 55.35019353032112, 54.01719845831394, 53.82459819316864, 52.652452290058136, 51.72414310276508, 48.93359564244747, 47.905142828822136, 46.24916888773441, 49.82908599078655, 49.01870347559452, 48.90166215598583, 50.52458167076111, 48.238312751054764, 47.76715703308582, 47.295207157731056, 50.029430240392685, 45.3141188621521, 44.33424264192581, 45.91651193797588, 46.63071021437645, 46.81238226592541, 48.1501042842865, 49.18969050049782, 51.046772450208664, 45.12582756578922, 48.48133251070976, 51.97460666298866, 39.71760056912899, 38.35759274661541, 40.497466921806335, 50.901023671031, 43.512871116399765, 41.13642543554306, 38.66340413689613, 41.148793771862984, 39.63250033557415, 39.33485470712185, 40.503641590476036, 40.87502606213093, 42.12232053279877, 48.15764307975769, 53.602891489863396, 51.69389292597771, 51.50938242673874, 55.226088389754295, 54.60560068488121, 55.960946157574654, 56.45678535103798, 50.76027162373066, 39.03491020202637, 42.309164106845856, 44.2419645935297, 43.93913984298706, 33.62780034542084, 39.365971237421036, 52.25611075758934, 56.86371311545372, 57.0760153234005, 56.475123167037964, 50.17236717045307, 51.34990118443966, 44.847940877079964, 46.56733341515064, 45.46038061380386, 44.45974610745907, 43.31338942050934, 40.27475707232952, 39.92600418627262, 40.75410135090351, 41.44937664270401, 40.218428894877434, 42.62059919536114, 46.85201793909073, 48.42196449637413, 45.668320655822754, 47.83566355705261, 52.58968345820904, 41.597773879766464, 48.339930698275566, 48.95816892385483, 42.1626515686512, 42.95327514410019, 48.60494747757912, 47.311850264668465, 44.61048021912575, 45.75019486248493, 43.568473532795906, 43.597344383597374, 45.89494809508324, 47.58873760700226, 46.67333632707596, 45.58326981961727, 46.47315926849842, 48.88211980462074, 45.80399617552757, 48.597811460494995, 46.88419461250305, 47.75531306862831, 49.532910883426666, 49.337559565901756, 48.835910484194756, 47.54432179033756, 49.06389445066452, 48.918772637844086, 49.36370216310024, 49.79594796895981, 49.72686007618904, 52.54270277917385, 53.83063226938248, 65.39281144738197, 69.6479295194149, 70.39257556200027, 66.70105084776878, 70.98172634840012, 66.62710681557655, 71.8569865822792, 71.99296608567238, 72.95799270272255, 79.12874758243561, 11.031194720417261, 1.4068030240014195, 0.23725646344246343, 0.10238021452096291, 29.522743821144104, 64.5414899289608, 57.99648553133011, 43.573360070586205, 34.00725178420544, 17.62173492461443, 29.51444886624813, 37.94510968029499, 22.227881960570812, 0.19159095914801583, 0.07385502642136998, 0.046340869812411256, 0.11893309114384465, 0.023652942218177486, 0.10047644245787524, 0.03716716011695098, 0.0282307057568687, 0.023330876101681497, 0.0787991845572833, 0.05487377209647093, 0.03265904713771306, 0.04715660143119749, 0.01715310525469249, 0.041712595702847466, 0.16896398970857263, 27.339371480047703, 64.38097134232521, 38.48810814321041, 39.53199192881584, 50.08172303438187, 66.9819849729538, 77.92261630296707, 58.20690684020519, 0.23894023324828595, 0.0939455206389539, 2.284398232586682, 63.00907015800476, 73.93490508198738, 79.15801361203194, 74.60963487625122, 75.91669633984566, 71.6986794769764, 71.40316173434258, 84.16307464241982, 75.4992127418518, 73.99659097194672, 73.96341875195503, 73.76117080450058, 69.4066272675991, 74.15467008948326, 74.19250085949898, 68.15501242876053, 60.35631090402603, 58.38292859494686, 57.51250930130482, 56.10434286296368, 56.49312660098076, 54.91371475160122, 52.71680563688278, 51.83129735291004, 51.829636842012405, 51.556834280490875, 52.60571099817753, 52.724568620324135, 52.08580009639263, 51.26180671155453, 50.177455097436905, 48.962059915065765, 52.208187729120255, 47.283887565135956, 46.846656426787376, 48.60310457646847, 49.317287653684616, 47.85583287477493, 48.50770689547062, 52.25990675389767, 48.91147702932358, 46.48242697119713, 49.307434782385826, 54.0717863291502, 45.3042583912611, 42.050097808241844, 41.27569556236267, 52.01696678996086, 46.395008862018585, 45.03300614655018, 42.45705597102642, 43.482715934515, 41.5326301753521, 42.6962873339653, 42.34089620411396, 41.44835829734802, 44.21739511191845, 50.453567281365395, 54.40883584320545, 55.27809239923954, 56.793451085686684, 59.16215278208256, 60.0693579018116, 60.454775020480156, 59.1792556643486, 53.31729121506214, 43.74594300985336, 46.43808335065842, 47.034434750676155, 48.191210478544235, 38.195869624614716, 41.411865055561066, 54.56161804497242, 59.51203040778637, 57.907669097185135, 57.53156527876854, 51.37819446623325, 52.926607578992844, 47.638788521289825, 48.598377630114555, 47.45046682655811, 45.17465874552727, 44.64299887418747, 44.19760577380657, 43.421330228447914, 44.262715280056, 43.45901280641556, 42.122799307107925, 45.35326436161995, 48.54144148528576, 48.649013713002205, 46.527211368083954, 48.11861537396908, 52.22103103995323, 43.54769624769688, 48.87347146868706, 50.452788323163986, 42.91136719286442, 41.190101355314255, 50.49237459897995, 48.51510129868984, 49.05168950557709, 46.955972760915756, 46.88498497009277, 45.23152269423008, 48.07342439889908, 49.07139904797077, 49.45707455277443, 48.31249617040157, 48.70550528168678, 50.18018335103989, 50.05186423659325, 51.29089795053005, 49.12640489637852, 50.39057046175003, 51.234767362475395, 51.51922009885311, 51.80985510349274, 49.44026805460453, 52.40344785153866, 51.89436636865139, 51.841830387711525, 51.237769201397896, 52.54247859120369, 52.57889583706856, 58.129535391926765, 68.9174035191536, 71.51875913143158, 72.13437929749489, 69.18694585561752, 72.42385536432266, 72.86963984370232, 72.95204982161522, 78.27024444937706, 72.44084805250168, 86.96381315588951, 18.971217311918736, 2.188099049963057, 0.48434935219120234, 0.17732898850226775, 32.89094388484955, 73.9839680492878, 68.06225180625916, 54.16166290640831, 32.26929724216461, 21.95330109447241, 40.391665399074554, 47.646635100245476, 23.838562332093716, 0.30837482772767544, 0.05350289917259943, 0.042834040214074776, 0.06531953404191881, 0.03039606261154404, 0.07679428003029898, 0.042848385928664356, 0.2666825149208307, 0.10438009470817633, 0.1280856051016599, 0.16333619481883943, 0.2679417614126578, 0.15211864752927795, 0.14436871104408056, 0.21494039450772107, 0.2404839449445717, 36.92505821585655, 71.32697582244873, 44.41814973950386, 64.06741976737976, 61.360555216670036, 76.0009454190731, 83.78836154937744, 65.37779465317726, 0.5333595676347613, 0.15286498091882095, 2.290369849652052, 66.9790667295456, 76.7882251739502, 82.46572092175484, 79.23251241445541, 77.48243272304535, 74.23825040459633, 73.12664285302162, 83.5465045273304, 77.59473189711571, 76.41332969069481, 79.05854254961014, 77.43474528193474, 74.97058510780334, 75.11687725782394, 78.05254653096199, 74.31604743003845, 63.0147622525692, 60.921427980065346, 60.634577572345734, 57.91105471551418, 57.60601468384266, 57.79135353863239, 55.267376974225044, 54.76736940443516, 53.45087684690952, 54.899279326200485, 55.79386152327061, 54.76674623787403, 54.873003736138344, 53.71890686452389, 51.883137971162796, 51.68931037187576, 54.929111525416374, 50.2461402118206, 49.62963469326496, 51.87127120792866, 50.52238918840885, 50.65130867063999, 52.77105152606964, 54.84722591936588, 51.55693307518959, 48.988719284534454, 51.05103962123394, 56.34141594171524, 48.614009991288185, 48.416891768574715, 44.822440445423126, 51.02640554308891, 49.64826129376888, 47.044762596488, 46.61091327667236, 45.68815179169178, 43.34659583866596, 44.86048020422459, 44.82951186597347, 44.527340680360794, 47.357007041573524, 54.97564382851124, 57.81467668712139, 58.401137217879295, 59.5434395223856, 61.24075144529343, 60.465167462825775, 62.29140266776085, 61.37091726064682, 56.241124123334885, 47.35468536615372, 48.29180248081684, 49.60585556924343, 51.87899999320507, 44.53706815838814, 44.71111781895161, 59.371213763952255, 62.03006029129028, 63.69366802275181, 60.84351696074009, 55.076836198568344, 55.04731558263302, 50.9331813454628, 49.071520641446114, 50.244992673397064, 50.42258374392986, 48.28866004943848, 45.30384041368961, 44.84807386994362, 47.49449886381626, 47.8623191267252, 44.975188449025154, 49.75766882300377, 49.170497730374336, 49.41621154546738, 48.217030093073845, 48.234995529055595, 53.24369676411152, 46.336586996912956, 49.70044769346714, 51.64103776216507, 44.151860028505325, 43.116199001669884, 52.62692905962467, 51.868748143315315, 51.093859523534775, 49.660709425807, 49.37068618834019, 48.07164989411831, 51.39146335422993, 52.463112249970436, 50.03815457224846, 50.42445704340935, 51.28471948206425, 53.40400256216526, 52.00031988322735, 53.92720028758049, 51.36744864284992, 52.62230470776558, 54.61600452661514, 53.545848950743675, 56.012277603149414, 52.901612520217896, 55.74465036392212, 53.98218333721161, 56.18927210569382, 54.77560356259346, 55.94635874032974, 57.198509350419044, 60.58251276612282, 69.45988520979881, 75.74149534106255, 74.6758197247982, 74.17032524943352, 75.71561112999916, 76.07985198497772, 74.82700601220131, 83.50282967090607, 77.41715222597122, 90.72720721364021, 23.807031624019146, 2.7133106673136353, 0.6930459989234805, 0.2088702647597529, 41.95525109767914, 79.98427927494049, 74.82641324400902, 66.87549188733101, 50.07477320730686, 33.465093076229095, 51.026717126369476, 62.62624830007553, 31.36981900781393, 0.4753333859844133, 0.16749855974921957, 0.11760564870201051, 0.18758959573460743, 0.12805042730178684, 0.21153292735107243, 0.18629537924425676], [0.007656990374016459, 0.024594378810434137, 0.08954356075264513, 0.031517375391558744, 0.03146804483549204, 0.05986604737699963, 0.0826440067612566, 0.024523774591216352, 0.09507291717454791, 23.73902477324009, 52.29206442832947, 54.87376369535923, 57.519196942448616, 46.916139498353004, 59.524459540843964, 73.96675497293472, 35.73664538562298, 0.13285145483678207, 5.763829965144396, 17.511523738503456, 75.2314867079258, 75.24702787399292, 76.6078108549118, 71.52617633342743, 77.91662022471428, 81.72797530889511, 65.87310567498207, 68.94584879279137, 77.8670708835125, 71.17955893278122, 69.34414342045784, 79.8241938650608, 76.33668020367622, 68.73882070183754, 71.32674783468246, 65.2418227493763, 67.77110382914543, 63.74330095946789, 62.38808088004589, 61.41587644815445, 62.44335651397705, 60.19145295023918, 60.79331785440445, 56.6887629032135, 50.788720697164536, 48.64165350794792, 49.87345241010189, 48.8216308504343, 50.34194067120552, 45.73766693472862, 47.783081978559494, 48.72182160615921, 45.844851583242416, 44.29314024746418, 47.36296132206917, 42.68825836479664, 47.42431282997131, 46.4130274951458, 47.02820688486099, 50.43015293776989, 48.292851224541664, 44.050253480672836, 41.16091892123222, 44.74983014166355, 41.127511113882065, 29.96525287628174, 34.73169431090355, 43.5697540640831, 49.083467200398445, 41.312298998236656, 39.83958542346954, 38.84131819009781, 42.443338707089424, 41.51152990758419, 40.69703981280327, 42.0090714097023, 39.880722016096115, 41.1587568372488, 42.62779600918293, 44.19356279075146, 47.00597047805786, 50.928374603390694, 50.68915843963623, 53.121487721800804, 49.22278672456741, 42.77066074311733, 48.48540589213371, 40.93799248337746, 46.04544661939144, 41.25641919672489, 45.15207275748253, 36.832327991724014, 50.489129573106766, 52.436528876423836, 56.18468575179577, 54.04161594808102, 51.194687113165855, 54.019379541277885, 48.86120952665806, 42.64815911650658, 40.91183088719845, 39.49200287461281, 40.482142344117165, 39.63084742426872, 39.16623495519161, 40.11064387857914, 41.46452262997627, 42.97084540128708, 44.20145496726036, 51.02846883237362, 48.08500237762928, 48.76522667706013, 48.24827961623669, 46.88292168080807, 34.85283561050892, 43.1011214107275, 51.61495216190815, 45.025079771876335, 45.07756635546684, 47.91696019470692, 47.31190726161003, 46.084656715393066, 44.56466607749462, 40.93644216656685, 45.36648005247116, 44.86465997993946, 47.835135385394096, 46.00652150809765, 47.73790240287781, 46.796730905771255, 46.16029165685177, 47.752049043774605, 48.21880079805851, 47.812066823244095, 47.73191772401333, 48.68744485080242, 49.25636172294617, 47.713701501488686, 49.49242785573006, 47.96060845255852, 48.039378225803375, 47.960023283958435, 50.843969732522964, 49.589660838246346, 56.40854313969612, 57.93888062238693, 66.06988951563835, 66.12837597727776, 69.64736714959145, 67.1023777127266, 71.07385620474815, 67.53081992268562, 71.61807060241699, 66.82781964540482, 72.88657933473587, 80.68061470985413, 26.376311257481575, 0.9553247876465321, 0.23067543923389167, 0.27540138456970453, 18.287622593343258, 66.61233320832253, 57.55149520933628, 49.41906899213791, 26.681930758059025, 37.36144199967384, 26.79713487625122, 40.92999771237373, 24.251565970480442, 0.3926772822160274, 0.010604261497064726, 0.036761520750587806, 0.07326996172196232, 0.08149526605848223, 0.03995049592049327, 0.018675183346203994, 0.009384372024214827, 0.034562715300126, 0.055862780354800634, 0.06682800114504062, 0.03088565557845868, 0.03142792062135413, 0.09556238583172671, 0.045278719189809635, 0.04861678069573827, 37.23350286483765, 61.97542302310467, 60.9513133764267, 51.445777639746666, 53.98635931313038, 66.49383276700974, 80.08716255426407, 39.403444826602936, 0.13860630540875718, 11.090310998260975, 25.04629522562027, 79.72767904400826, 78.8579361140728, 79.27440896630287, 76.26961380243301, 82.23754316568375, 81.29866674542427, 68.06907624006271, 70.54649010300636, 79.01441931724548, 73.397948294878, 72.74863913655281, 74.86340805888176, 77.8638106584549, 73.52441310882568, 74.75715056061745, 69.8810014128685, 69.79611396789551, 64.83168795704842, 65.43172135949135, 63.63324746489525, 65.2608597278595, 62.04115569591522, 63.993642926216125, 59.18613709509373, 51.66840009391308, 50.394176468253136, 51.86205290257931, 51.550249233841896, 52.54741072654724, 49.138450250029564, 50.46115167438984, 50.03435477614403, 48.44352833926678, 47.964868023991585, 48.72263476252556, 45.391900688409805, 48.44201222062111, 48.147425428032875, 48.22815589606762, 54.16746899485588, 48.589630499482155, 48.031102269887924, 44.6659230440855, 49.111422300338745, 44.057051315903664, 34.48873534798622, 39.42897945642471, 43.650708720088005, 51.77812300622463, 44.70091536641121, 42.914118245244026, 42.50687889754772, 44.457299038767815, 43.3597507327795, 43.531007543206215, 42.92068809270859, 42.65663266181946, 42.58836932480335, 44.08795885741711, 47.15070851147175, 49.39536206424236, 52.378859370946884, 52.9986859112978, 54.54627826809883, 48.727810084819794, 44.84468065202236, 50.51844120025635, 44.44359317421913, 47.784050926566124, 45.848940163850784, 46.634240224957466, 39.41097982227802, 50.70608653128147, 58.3002944290638, 57.33465604484081, 56.229701936244965, 53.48067104816437, 55.8868083357811, 50.57605750858784, 44.68232676386833, 43.53071875870228, 42.97581933438778, 42.753736451268196, 41.58839978277683, 41.29548490047455, 43.107847049832344, 43.02903547883034, 45.73277659714222, 44.41546328365803, 50.94611965119839, 48.03194582462311, 48.03367093205452, 49.3164137005806, 47.13638707995415, 37.53619842231274, 45.22917062044144, 51.318058893084526, 46.74787312746048, 46.16789124906063, 47.465886399149895, 48.19480888545513, 46.90351277589798, 46.916036903858185, 44.81125384569168, 49.21474255621433, 47.77613215148449, 48.96084778010845, 47.65211820602417, 49.50772203505039, 47.579371109604836, 48.31490904092789, 49.81826797127724, 50.79039640724659, 49.58963803946972, 50.2250437438488, 50.210159942507744, 50.578018203377724, 51.477152556180954, 52.47125901281834, 50.15577346086502, 52.402972877025604, 51.85977302491665, 53.06790679693222, 52.71757699549198, 58.44927303493023, 61.90079502761364, 67.96109363436699, 70.63065558671951, 71.49200096726418, 71.18468105792999, 74.06244143843651, 68.7649405002594, 71.50192603468895, 72.82482504844666, 74.43276956677437, 85.27595892548561, 37.95607589185238, 0.949908890761435, 0.3159056673757732, 0.4923408874310553, 21.217814460396767, 73.8939356803894, 66.19399085640907, 60.23467183113098, 30.732036530971527, 45.14633506536484, 37.53703437745571, 52.30859354138374, 29.02771968394518, 0.3987163456622511, 0.05724973561882507, 0.054448751543532126, 0.048067235184134915, 0.06461856813984923, 0.017693717163638212, 0.026506171634537168, 0.07425351519486867, 0.07839586440240964, 0.11827254260424525, 0.1379646742134355, 0.15262865141266957, 0.11410067076212727, 0.18515469826525077, 0.18762602034257725, 0.16484017192851752, 46.55805051326752, 70.47589749097824, 68.53040188550949, 74.53872308135033, 64.20718386769295, 75.35861268639565, 87.85646125674248, 46.30595684051514, 0.21255887229926884, 11.513151358813047, 25.662804543972015, 81.81154802441597, 80.75504511594772, 81.92994207143784, 76.49926587939262, 84.45038482546806, 86.47120758891106, 71.43669113516808, 73.46932366490364, 81.31774172186852, 75.7939401268959, 74.69516828656197, 75.81533297896385, 76.37703403830528, 74.67048481106758, 77.4536606669426, 73.05109530687332, 71.89649686217308, 67.96799406409264, 69.05299544334412, 66.3859261572361, 68.80505874752998, 66.26408189535141, 66.16930738091469, 61.262805461883545, 56.12967610359192, 55.25038808584213, 55.77151872217655, 53.910192400217056, 54.203137680888176, 49.58279840648174, 52.32175223529339, 51.007155776023865, 50.89311249554157, 51.16247244179249, 54.10971209406853, 47.47664362192154, 51.449661031365395, 51.12018831074238, 50.14626257121563, 56.51248276233673, 49.750874787569046, 50.75472392141819, 47.872958555817604, 50.872149020433426, 46.669988706707954, 41.26014679670334, 44.80212293565273, 44.8267038166523, 54.708369970321655, 45.34570276737213, 46.876051649451256, 44.01906095445156, 49.55618843436241, 47.11517661809921, 46.85590513050556, 45.47511622309685, 45.70827171206474, 45.84237411618233, 47.737556621432304, 49.35422167181969, 52.80851751565933, 56.79720148444176, 56.23644657433033, 58.242119550704956, 53.97580347955227, 49.66188736259937, 52.862869799137115, 45.62388204038143, 54.584485217928886, 50.758269131183624, 48.71158115565777, 44.33855161070824, 54.80430342257023, 60.03309644758701, 60.23769646883011, 58.35237443447113, 54.95731361210346, 59.16646555066109, 52.43029721081257, 46.193509474396706, 46.50731943547726, 43.3854715526104, 46.627472788095474, 44.77786883711815, 43.91446016728878, 46.32475443184376, 48.134563118219376, 48.83055277168751, 45.269703045487404, 52.167343720793724, 49.92432788014412, 48.304600194096565, 50.76632849872112, 51.065760031342506, 42.03785486519337, 48.43062803149223, 52.97416962683201, 47.637450993061066, 46.25968672335148, 49.96215105056763, 51.01572431623936, 49.916948676109314, 49.39733795821667, 46.62611626088619, 51.725894808769226, 51.64660446345806, 51.45479075610638, 51.4948558062315, 51.499955132603645, 52.10228741168976, 52.30360820889473, 53.78043696284294, 54.50660079717636, 51.88897825777531, 52.59417101740837, 54.939256981015205, 53.795875534415245, 54.12358894944191, 54.70949470996857, 53.80654916167259, 55.09784907102585, 55.7477205991745, 56.601625978946686, 56.57266393303871, 62.35661096870899, 64.79299083352089, 70.9715960919857, 73.73131200671196, 73.82363945245743, 70.62495589256287, 75.82898944616318, 74.94226902723312, 73.82865518331528, 78.40648993849754, 77.28570967912674, 90.38934454321861, 43.49956423044205, 1.3616584776900709, 0.7210529898293316, 0.4433826223248616, 27.97640159726143, 82.72975355386734, 72.67363116145134, 69.56278368830681, 46.17791511118412, 60.810139551758766, 50.005651116371155, 65.59119120240211, 35.731454864144325, 0.7594765280373394, 0.1431229419540614, 0.21204315387876704, 0.2122273697750643, 0.19321014726301655, 0.14184140134602785, 0.09429269732208923], [0.01745902409311384, 0.03513845120323822, 0.042356015474069864, 0.039833199480199255, 0.03738591927685775, 0.0231528905351297, 0.08336470637004822, 0.04201090938295238, 0.08656409016111866, 38.812390342354774, 50.576973259449005, 36.9883818179369, 24.084487035870552, 52.14501231908798, 56.90254703164101, 81.19972005486488, 18.86612445116043, 0.10916613828158006, 4.2829145304858685, 31.43231425434351, 86.2145085632801, 72.16891184449196, 82.5127623975277, 78.70380878448486, 82.24878296256065, 73.65714758634567, 78.22992101311684, 63.759985864162445, 68.85368093848228, 70.69834515452385, 71.82485550642014, 46.34685404598713, 53.83422687649727, 73.11773613095284, 70.19886955618858, 68.13588425517082, 67.40249320864677, 66.96791052818298, 65.86128070950508, 67.16152533888817, 64.76669624447823, 64.72395613789558, 64.50463950634003, 63.83702293038368, 60.25319203734398, 48.80114234983921, 48.146148696541786, 48.89472372829914, 50.37989683449268, 49.91212673485279, 49.61215563118458, 49.06432382762432, 46.597435399889946, 46.6463615745306, 44.75404031574726, 44.97587241232395, 44.101402536034584, 47.312914207577705, 44.4209273904562, 50.49933202564716, 51.218603029847145, 46.49174027144909, 29.35529250651598, 44.50624041259289, 33.77342753112316, 27.568863965570927, 45.654911175370216, 44.21570800244808, 45.439318343997, 48.27170915901661, 38.5428100079298, 41.92574568092823, 39.34699505567551, 40.01651532948017, 38.40273052453995, 39.29100885987282, 38.198837265372276, 39.18847516179085, 38.934766575694084, 40.632310286164284, 38.43258552253246, 42.772507444024086, 42.87881813943386, 44.48216110467911, 40.24524785578251, 42.98230558633804, 42.11255505681038, 39.56713244318962, 44.851208701729774, 40.3982238471508, 41.370831057429314, 38.90135116875172, 40.539211481809616, 41.814461052417755, 46.16370767354965, 49.18220870196819, 45.88378809392452, 42.94619992375374, 42.019923627376556, 40.05130246281624, 41.16006776690483, 40.19398480653763, 40.27042530477047, 39.469618275761604, 40.338962227106094, 39.0103255212307, 43.75785157084465, 45.55206589400768, 41.83418199419975, 44.218060076236725, 44.6972219645977, 46.214047372341156, 41.94756790995598, 41.2692017108202, 41.672808453440666, 48.22954282164574, 50.763569846749306, 49.322364181280136, 44.36968334019184, 46.41214594244957, 44.561934024095535, 44.43436726927757, 42.62523874640465, 42.41212718188763, 43.34121532738209, 46.45634137094021, 46.95025406777859, 46.248621717095375, 46.2308044731617, 44.53773692250252, 45.48784554004669, 45.205133110284805, 47.30452045798302, 46.06551334261894, 45.092351362109184, 47.60235607624054, 48.15084524452686, 48.16797852516174, 49.464050978422165, 48.38599182665348, 51.495573967695236, 49.18795399367809, 55.068708434700966, 57.3096913844347, 61.626214161515236, 64.13712322711945, 71.4202532172203, 68.01030099391937, 70.72726920247078, 67.98147574067116, 73.66500556468964, 70.72972387075424, 71.470235735178, 66.85993552207947, 71.77127838134766, 75.68153455853462, 41.5307454764843, 0.3492402395932004, 0.1976084112538956, 0.23155583417974412, 9.458438213914633, 65.57577162981033, 55.177337005734444, 54.275854378938675, 29.565793611109257, 22.165713496506214, 26.69232700020075, 38.30121137201786, 34.80120778083801, 0.8830805704928935, 0.03629393802839331, 0.02833905931765912, 0.017053202900569886, 0.01549875974887982, 0.07696511500398628, 0.09319704244262539, 0.05560667261306662, 0.0211766867141705, 0.0266435598678072, 0.08007684373296797, 0.07645247649634257, 0.02585252506833058, 0.05173727789951954, 0.0743562432762701, 0.3536446485668421, 52.19205379486084, 57.547167241573334, 42.875288128852844, 34.15811888873577, 61.972839161753654, 64.34395372867584, 89.3044039607048, 19.904872812330723, 0.27448803826700896, 4.870345434173942, 36.86227038502693, 91.60157829523087, 74.7547034919262, 86.42129346728325, 81.75975680351257, 85.79729855060577, 75.54970443248749, 81.20374783873558, 64.83953833580017, 73.4281338751316, 69.56368044018745, 76.09563633799553, 47.94416293501854, 50.19184872508049, 74.64302748441696, 73.59536290168762, 70.9401261806488, 68.39147374033928, 67.93891042470932, 68.34293514490128, 69.30360719561577, 68.59224736690521, 66.84284403920174, 66.80078789591789, 65.2996176481247, 63.47388781607151, 50.09621545672417, 49.311979338526726, 49.989589378237724, 51.54018357396126, 50.20771287381649, 50.40535926818848, 50.9323263913393, 50.06284944713116, 48.973960876464844, 47.60234087705612, 48.31674814224243, 46.08422353863716, 48.60695376992226, 47.83888578414917, 52.339379489421844, 52.45874248445034, 47.85497032105923, 33.525445237755775, 47.46622458100319, 39.43577729165554, 32.46063217520714, 46.81352600455284, 45.592697113752365, 45.219454541802406, 51.91220261156559, 41.10339380800724, 42.45496608316898, 42.64700397849083, 42.20181226730347, 41.60601943731308, 41.87400005757809, 41.05922497808933, 41.44922465085983, 40.11290855705738, 42.45247721672058, 42.2213052213192, 44.562344402074814, 43.17805588245392, 44.88128408789635, 42.84977249801159, 46.40269584953785, 45.14145612716675, 43.880334198474884, 48.45346860587597, 43.03965210914612, 43.25060538947582, 40.173340514302254, 42.057499811053276, 44.811018258333206, 47.97817870974541, 48.95523548126221, 48.51749137043953, 46.08490750193596, 43.98490458726883, 43.45916859805584, 43.97325821220875, 43.46449211239815, 43.86081464588642, 43.29201176762581, 42.15310648083687, 42.31413044035435, 47.191343531012535, 43.318747133016586, 41.97247937321663, 45.599635541439056, 45.808825716376305, 48.50494064390659, 44.354962930083275, 44.06894847750664, 42.932554855942726, 48.242883905768394, 49.32867184281349, 50.378878489136696, 46.256802678108215, 46.990186125040054, 46.45960159599781, 46.500920578837395, 45.62398083508015, 44.67288427054882, 45.29280200600624, 47.726290225982666, 49.16225977241993, 47.92242430150509, 48.40608514845371, 46.87845692038536, 48.2016409188509, 48.25077228248119, 49.75376643240452, 49.075415432453156, 49.5185324549675, 49.58235003054142, 50.96845865249634, 51.341777220368385, 52.13432729244232, 51.410481333732605, 52.877328023314476, 53.83423827588558, 57.84503325819969, 62.70822510123253, 64.57397058606148, 65.97271353006363, 73.8267856836319, 72.11395919322968, 73.91796559095383, 70.08718594908714, 73.22564274072647, 73.05700019001961, 75.51141768693924, 70.4922366142273, 74.14952516555786, 78.35798934102058, 49.636094346642494, 0.20817019685637206, 0.12413901218678802, 0.6343056040350348, 11.674438454210758, 73.89724150300026, 65.32692298293114, 64.37619119882584, 36.492759212851524, 32.97863557934761, 40.006107687950134, 48.501562625169754, 42.123604863882065, 0.9596749604679644, 0.0717013880785089, 0.051920024343417026, 0.04059721082739998, 0.022728779113094788, 0.025143571801891085, 0.02454232828313252, 0.12952606921317056, 0.11831201743916608, 0.07490777774364688, 0.18178040510974824, 0.1388927298830822, 0.10643141315085813, 0.19574548699893057, 0.21745231206296012, 0.5019020650070161, 59.82218876481056, 70.27089849114418, 50.28835594654083, 36.506016701459885, 72.41730451583862, 72.3016919195652, 98.35820853710175, 24.24928229302168, 0.387906608521007, 10.266718491911888, 39.05293643474579, 92.37362086772919, 76.74626782536507, 87.40987122058868, 85.9630760550499, 89.72719207406044, 78.13717558979988, 84.6322126686573, 67.86177456378937, 74.59856227040291, 72.14669063687325, 76.72658488154411, 53.23025308549404, 55.21267510950565, 74.77768465876579, 78.07981386780739, 73.41478899121284, 73.30959543585777, 73.86360570788383, 72.36027717590332, 71.57462373375893, 71.53916403651237, 72.3515072464943, 73.3254785835743, 67.48387724161148, 67.22425237298012, 53.634156212210655, 53.26806105673313, 53.7178885191679, 54.051484018564224, 53.24613243341446, 53.38544815778732, 53.738061636686325, 51.13150790333748, 52.04725496470928, 51.879577562212944, 49.86936002969742, 49.26108866930008, 52.017114982008934, 50.75603865087032, 56.167343482375145, 53.42752330005169, 51.013433039188385, 38.63680176436901, 48.04844453930855, 45.66818006336689, 38.877758234739304, 50.04386946558952, 47.43076868355274, 45.84476038813591, 52.96727679669857, 44.55490820109844, 46.833782717585564, 45.56615173816681, 45.073375180363655, 43.345011323690414, 42.737218737602234, 43.82624410092831, 44.04601290822029, 42.64684438705444, 45.98999999463558, 44.81012150645256, 48.948768228292465, 46.25666208565235, 47.63981446623802, 46.278180330991745, 48.42179350554943, 47.695694267749786, 45.89145228266716, 51.156210377812386, 45.26879869401455, 45.22061347961426, 43.46107229590416, 44.00839872658253, 46.916329488158226, 52.01445512473583, 53.20596858859062, 52.578542456030846, 49.30382877588272, 46.98347568511963, 46.13582096993923, 47.473269402980804, 45.62062181532383, 44.79631684720516, 46.24983765184879, 46.23984418809414, 46.70178160071373, 48.477175533771515, 44.47200044989586, 41.00278280675411, 45.53116321563721, 47.1120797842741, 50.90141884982586, 48.07340160012245, 48.243887051939964, 45.459540858864784, 50.0617703050375, 50.75372077524662, 51.85577563941479, 49.7516043484211, 49.66360107064247, 48.29599365592003, 48.65122139453888, 47.42501199245453, 47.75833770632744, 48.69615398347378, 52.1550589799881, 51.491739973425865, 50.24213142693043, 48.62725228071213, 48.92613664269447, 50.5062248557806, 50.57188533246517, 51.95892110466957, 50.38383722305298, 51.62401847541332, 51.92585147917271, 53.980876207351685, 54.35158431529999, 54.14701849222183, 53.656502813100815, 55.737822130322456, 56.39672577381134, 61.31209261715412, 65.2713243663311, 68.10316801071167, 67.8169521689415, 77.44769498705864, 74.4448833167553, 77.04229474067688, 75.42186409235, 75.30603110790253, 71.46583557128906, 79.5111134648323, 72.56956234574318, 77.84942463040352, 82.4381572008133, 57.02794790267944, 0.50394362420775, 0.8449074625968933, 0.7265946955885738, 14.302564579993486, 81.06623321771622, 71.27120241522789, 73.98412764072418, 49.67605300247669, 35.69480963051319, 47.96302132308483, 64.59453508257866, 51.00074551999569, 1.7730106296949089, 0.18534387170802802, 0.2221593985450454, 0.10353980542276986, 0.09857154233031906, 0.1637319673318416, 0.15072856040205806], [0.08808342972770333, 0.03154349156829994, 0.05626008911349345, 0.08726484084036201, 0.0365652783511905, 0.011423173218645388, 0.02794508280203445, 0.07920171061414294, 0.599597078980878, 49.57459084689617, 53.56248065829277, 40.71895703673363, 23.058887869119644, 57.40926504135132, 54.832923486828804, 82.14221388101578, 10.41479654610157, 0.2449640678241849, 0.2379103103885427, 40.27986399829388, 87.76862516999245, 69.64606761932373, 80.34981206059456, 72.45686799287796, 81.45438998937607, 73.01808267831802, 75.71788340806961, 72.4149714410305, 73.91882434487343, 70.04232555627823, 76.5714544057846, 54.34323996305466, 38.66357892751694, 56.48825906217098, 68.87746766209602, 71.40202179551125, 70.35833179950714, 68.88901144266129, 67.54920333623886, 66.156365275383, 65.42905390262604, 64.7424079477787, 66.9176772236824, 63.37967947125435, 64.33330669999123, 56.751801520586014, 47.60168731212616, 50.407365560531616, 48.143823221325874, 50.15639282763004, 47.26798161864281, 48.827490136027336, 47.39354208111763, 44.680031687021255, 44.26089137792587, 46.87112331390381, 43.83914440870285, 45.588099360466, 46.05637103319168, 46.50623269379139, 47.26319007575512, 47.45625391602516, 36.17160424590111, 38.860187977552414, 38.84031504392624, 34.63514909148216, 40.36162041127682, 47.698342725634575, 42.12425082921982, 45.11941730976105, 44.6866699308157, 38.952827006578445, 40.42408145964146, 39.97151054441929, 39.557857140898705, 40.88534630835056, 38.62673990428448, 41.152285784482956, 39.603272303938866, 39.83804650604725, 41.12023450434208, 40.06449915468693, 38.91783848404884, 41.941940411925316, 40.54374843835831, 41.21088244020939, 43.19907635450363, 43.51746506989002, 42.497766986489296, 41.517605781555176, 41.2142376601696, 38.61768878996372, 38.844624012708664, 41.25463329255581, 39.13159981369972, 40.54397262632847, 40.303992703557014, 39.29626777768135, 40.259565487504005, 37.852124869823456, 39.6144513040781, 38.13669539988041, 40.53400196135044, 39.418674409389496, 40.309164226055145, 45.554984137415886, 42.32791230082512, 38.21426063776016, 39.49937827885151, 47.94768154621124, 42.77730278670788, 41.959305480122566, 42.48563423752785, 34.936149939894676, 42.56507657468319, 47.05442927777767, 45.70799432694912, 44.24318052828312, 46.04614578187466, 46.327813267707825, 43.056242018938065, 45.92783913016319, 42.375766932964325, 40.20223416388035, 40.839083790779114, 46.2180295586586, 48.79812531173229, 47.71970137953758, 48.73198606073856, 47.01447442173958, 49.74636822938919, 53.28231029212475, 54.48258228600025, 51.646437272429466, 54.19440574944019, 52.552620247006416, 50.758690908551216, 50.40941745042801, 51.95550888776779, 50.81615902483463, 52.445693984627724, 54.77947175502777, 61.77347145974636, 64.7541569173336, 68.87970194220543, 65.95094829797745, 65.71604490280151, 63.47488336265087, 68.72319594025612, 78.38892728090286, 80.38155555725098, 66.6698469221592, 68.30087140202522, 66.06165915727615, 71.57651603221893, 72.63676553964615, 55.14269806444645, 0.23751648230245337, 0.28261663333978504, 0.20272857713280246, 4.9314547050744295, 62.727148085832596, 56.870328560471535, 58.502565175294876, 35.5992865562439, 35.725348591804504, 30.485490560531616, 39.61849808692932, 39.2327693849802, 1.4300151471979916, 0.1287507772212848, 0.0920499418862164, 0.083520653861342, 0.02976406078232685, 0.0030654989586764714, 0.03624212127760984, 0.016546343867958058, 0.08069741277722642, 0.015702915297879372, 0.0406675181875471, 0.05216843230300583, 0.06212889275047928, 0.08848059005686082, 0.0703539521782659, 1.5561777586117387, 58.79029333591461, 59.59202751517296, 45.5814915150404, 29.557508155703545, 64.75754633545876, 63.71872387826443, 89.38359931111336, 10.992802530527115, 0.3505043842596933, 0.17128633306128904, 46.74861028790474, 91.43354371190071, 73.6459381878376, 84.82364639639854, 75.18120020627975, 84.6720041334629, 74.50805112719536, 77.76865616440773, 75.0426672399044, 77.9314698278904, 72.27068558335304, 79.55504670739174, 59.88569475710392, 41.84956356883049, 58.33886235952377, 71.06599062681198, 73.72711703181267, 73.26395988464355, 71.82489350438118, 70.8554895222187, 70.92776164412498, 70.11992499232292, 68.43806684017181, 67.21069470047951, 65.60038670897484, 67.0357520878315, 58.653299286961555, 49.02119234204292, 54.00136090815067, 50.97670041024685, 51.251839846372604, 50.10216973721981, 50.15044614672661, 49.602865129709244, 47.94615022838116, 47.872118800878525, 49.64339755475521, 47.19914071261883, 48.72668154537678, 49.62485454976559, 50.338566452264786, 49.053266420960426, 48.85126166045666, 41.14918515086174, 41.70742079615593, 39.95578698813915, 39.271428510546684, 44.70823377370834, 50.543546453118324, 43.71434010565281, 45.59825241565704, 48.84244233369827, 41.83606669306755, 43.59155349433422, 40.75912468135357, 42.97388143837452, 44.181445240974426, 44.593928307294846, 42.958013489842415, 42.40921653807163, 42.57851265370846, 44.33870740234852, 42.75222793221474, 43.73365826904774, 45.465681329369545, 43.970469161868095, 43.821638748049736, 47.07335986196995, 45.28486803174019, 45.61763897538185, 44.10909332334995, 45.263247191905975, 42.16175101697445, 40.92562414705753, 42.70206682384014, 43.2525584846735, 41.6737812012434, 42.38426327705383, 42.829599380493164, 40.94998084008694, 43.74047510325909, 44.561987221241, 41.09686195850372, 41.48148111999035, 41.762050464749336, 43.627727553248405, 47.75834910571575, 41.771542355418205, 38.94076645374298, 40.20166799426079, 48.726438358426094, 43.1854996830225, 44.793189615011215, 44.26368422806263, 36.04275695979595, 44.32458736002445, 48.20596508681774, 48.13073292374611, 44.66688819229603, 48.99438098073006, 48.66110846400261, 45.42172908782959, 47.767476215958595, 45.163791328668594, 43.10398265719414, 45.00325374305248, 48.45883011817932, 51.20646268129349, 49.43947769701481, 50.78671060502529, 50.03984548151493, 52.77332380414009, 54.41919408738613, 57.50720098614693, 53.99257957935333, 56.98844142258167, 56.68625123798847, 54.95162531733513, 54.40406709909439, 53.291217014193535, 53.94193969666958, 55.22239878773689, 59.711880683898926, 64.02211859822273, 67.4507050216198, 71.21544420719147, 69.64519366621971, 68.29539209604263, 67.34484270215034, 67.80461803078651, 76.4229279756546, 82.89642781019211, 70.37902548909187, 70.37294581532478, 69.39695298671722, 74.63795095682144, 74.61096480488777, 65.39014399051666, 1.0155008523724973, 0.20321784541010857, 0.2075999602675438, 5.354205295443535, 70.72971627116203, 63.20903442800045, 69.38773468136787, 39.58198964595795, 37.562135830521584, 45.17623946070671, 48.656970486044884, 49.273004829883575, 1.887514516711235, 0.0391033677442465, 0.07180758198956028, 0.05379217349400278, 0.02638804213347612, 0.051429605737212114, 0.012258898295840481, 0.19228290795581415, 0.2198803224018775, 0.08380763494642451, 0.10859267335035838, 0.22857235599076375, 0.14408602699404582, 0.15224392205709592, 0.2108438580762595, 2.0140242157503963, 73.27054113149643, 68.22526305913925, 53.99027690291405, 34.984547942876816, 78.111382573843, 67.6668830215931, 99.23645541071892, 12.626130636781454, 0.43175943195819855, 0.7182091393042356, 46.72554552555084, 93.72909173369408, 76.42985120415688, 88.83008301258087, 78.61353322863579, 90.13615652918816, 79.16728511452675, 80.4141654074192, 77.7141746878624, 78.16308259963989, 75.24280250072479, 80.3686286509037, 61.334253028035164, 45.1262341439724, 60.373489782214165, 73.05217444896698, 77.41803377866745, 75.9532655775547, 74.26633849740028, 72.92805790901184, 72.59236112236977, 72.2740750014782, 69.73960340023041, 72.44383469223976, 67.20621094107628, 71.75677075982094, 62.889270186424255, 51.09505645930767, 57.36054785549641, 52.6306414604187, 53.7483286857605, 52.417396903038025, 52.99942687153816, 52.46295265853405, 50.751718282699585, 51.2247359007597, 53.81343059241772, 47.76853255927563, 51.043094247579575, 50.19366882741451, 52.075597643852234, 49.30301941931248, 50.58532901108265, 47.990919426083565, 44.22475151717663, 45.05254469811916, 42.65850976109505, 48.874326422810555, 53.9617670327425, 44.40513923764229, 48.556606471538544, 53.06906573474407, 44.7455857694149, 47.6436560600996, 44.93916638195515, 45.920638516545296, 46.951443403959274, 44.47157867252827, 46.09965071082115, 45.011324509978294, 47.283199802041054, 46.30029134452343, 46.46236404776573, 45.975655764341354, 48.300234228372574, 47.819449827075005, 45.26547007262707, 48.862664848566055, 48.40919338166714, 48.21814343333244, 46.11628241837025, 47.09052354097366, 44.3623611330986, 43.914653956890106, 46.83240719139576, 45.331814512610435, 44.46866802871227, 45.86362637579441, 44.74055103957653, 43.928561210632324, 45.49662686884403, 46.0901740193367, 43.15047316253185, 44.8204455524683, 44.6052061021328, 45.84671728312969, 50.289302095770836, 42.48338095843792, 38.934853971004486, 40.9013282507658, 48.385326862335205, 46.926626935601234, 47.15866908431053, 46.30603663623333, 38.606980964541435, 45.34782685339451, 49.092556312680244, 48.30341845750809, 45.334918946027756, 49.44023385643959, 50.453327894210815, 46.639966517686844, 50.452788323163986, 48.251501843333244, 45.857877284288406, 47.19722181558609, 51.923962980508804, 53.40806074440479, 50.47609627246857, 53.77199001610279, 49.99558165669441, 55.7533822953701, 58.44861567020416, 60.26930697262287, 55.78343868255615, 60.63122995197773, 58.73541288077831, 55.007189735770226, 55.99381819367409, 55.93199171125889, 56.41817942261696, 57.96107903122902, 62.59404502809048, 67.44937509298325, 69.77375596761703, 75.52594050765038, 73.75731781125069, 74.66497510671616, 71.26770660281181, 71.4453774690628, 72.20088332891464, 82.51425951719284, 75.4252915084362, 75.02252072095871, 73.54336649179459, 80.4934823513031, 79.98544961214066, 71.23312085866928, 1.0880030994303524, 1.154875592328608, 0.4619728575926274, 7.028970653191209, 81.12788870930672, 71.96067541837692, 75.48004657030106, 54.73198190331459, 51.81205898523331, 53.22900675237179, 60.78495070338249, 58.70036356151104, 2.675887900404632, 0.18059969268506393, 0.19535496889147907, 0.08424196203122847, 0.12291411228943616, 0.165791783365421, 0.13286681729368865], [0.09461429217481054, 0.026769285250338726, 0.08201151140383445, 0.02700660737900762, 0.008510260286129778, 0.10994439144269563, 0.03529857327521313, 0.027619510037766304, 0.7197392103262246, 43.07002767920494, 43.694398775696754, 44.569324627518654, 32.18941792845726, 50.78514128923416, 63.94923850893974, 74.37818169593811, 9.009589198976755, 0.2133896917803213, 0.47900232661049813, 47.173412293195724, 85.80347701907158, 70.54486379027367, 76.32157981395721, 71.48978188633919, 74.70142275094986, 71.36889517307281, 71.95908710360527, 72.96323642134666, 73.86267095804214, 70.39706692099571, 73.15009519457817, 75.60464188456535, 70.87605401873589, 57.67469979822636, 61.64493575692177, 65.92266261577606, 67.60116934776306, 67.18386054039001, 69.78368103504181, 66.0512325167656, 67.06264704465866, 66.44288510084152, 62.42965824902058, 62.34743446111679, 64.67489317059517, 56.51688292622566, 48.96462097764015, 49.00075323879719, 50.823621824383736, 49.52041335403919, 47.50587925314903, 47.06918388605118, 47.08481624722481, 44.77982573211193, 44.85864110291004, 45.46277828514576, 45.42144790291786, 45.55393539369106, 46.95671372115612, 46.27031475305557, 50.053270161151886, 45.68408980965614, 50.20995855331421, 46.722479090094566, 39.63467761874199, 36.79516218602657, 34.447492361068726, 43.9563225209713, 43.30653838813305, 42.288857996463776, 45.92666499316692, 41.208237782120705, 39.46796156466007, 41.042840257287025, 40.58763988316059, 40.76431520283222, 39.92464005947113, 38.97528380155563, 38.74579891562462, 40.07846340537071, 39.16574478149414, 40.541096180677414, 42.187388241291046, 40.586750730872154, 43.1987913697958, 43.773248344659805, 42.173442989587784, 41.95133350789547, 43.647072315216064, 41.254321709275246, 39.736075177788734, 41.50626339018345, 40.70698007941246, 39.86133545637131, 38.06453727185726, 38.99458296597004, 39.466274455189705, 40.273791924118996, 39.68703880906105, 40.485410168766975, 40.36852844059467, 42.19543620944023, 38.86807255446911, 40.22733561694622, 44.99664969742298, 45.19950181245804, 38.661382645368576, 42.19786047935486, 38.468482196331024, 53.789195492863655, 48.731473088264465, 31.29370529204607, 45.270254015922546, 40.84161065518856, 39.7099781781435, 42.701770439743996, 44.30848382413387, 41.764622926712036, 45.98134405910969, 44.36995692551136, 43.706276938319206, 43.4713127464056, 42.59378403425217, 42.862999588251114, 41.17468558251858, 45.43186314404011, 46.1106663197279, 48.60481448471546, 47.50874049961567, 54.71335530281067, 56.32992535829544, 57.030934542417526, 60.1679740101099, 59.541775211691856, 57.32438139617443, 59.02286745607853, 57.79954969882965, 58.93339745700359, 58.00032712519169, 56.38730987906456, 59.64976541697979, 61.00321479141712, 64.70991969108582, 63.16385105252266, 65.40684029459953, 67.23128199577332, 73.72438877820969, 73.04709032177925, 75.04846572875977, 76.35644674301147, 68.78923639655113, 64.82569947838783, 68.1109119951725, 65.84986612200737, 73.54028865695, 69.53829020261765, 82.17180669307709, 5.8398135378956795, 0.650685396976769, 0.352617961470969, 2.0553954457864165, 55.70438772439957, 60.5334497988224, 54.051107838749886, 37.0444668084383, 35.35859227180481, 27.567792423069477, 39.874136969447136, 45.99141351878643, 4.9610750656574965, 0.11605426319874823, 0.04591451339365449, 0.052967150186304934, 0.039219109385157935, 0.011803843026427785, 0.059940666615148075, 0.014501352234219667, 0.023051895368553232, 0.022417494546971284, 0.016476053206133656, 0.011332441026752349, 0.055667647466179915, 0.026451707271917257, 0.11124846365419216, 1.3534851162694395, 58.650502637028694, 50.6807266920805, 50.86023285984993, 32.61139288544655, 59.27070155739784, 70.4163470864296, 81.70484974980354, 10.057395324110985, 0.20515568205155432, 0.4845558770466596, 51.504533886909485, 91.65780767798424, 74.67832759022713, 80.04816144704819, 72.04901307821274, 79.88701969385147, 71.84681832790375, 76.18137493729591, 73.23924601078033, 76.4666636288166, 71.80198073387146, 73.26209038496017, 74.18193742632866, 70.35908415913582, 57.85900130867958, 61.03702537715435, 65.59550777077675, 69.47003066539764, 68.39373841881752, 72.23945125937462, 67.12851271033287, 68.01728501915932, 67.6075530052185, 67.14478343725204, 63.34476314485073, 66.27335339784622, 59.55144949257374, 50.88985987007618, 51.42982989549637, 54.186319783329964, 49.90721359848976, 49.68220107257366, 49.47089821100235, 50.919988453388214, 47.046586498618126, 45.639525800943375, 48.32302540540695, 47.86414682865143, 47.938406243920326, 47.796141877770424, 49.29069668054581, 51.801225766539574, 45.96614107489586, 50.91462694108486, 49.8347020894289, 44.666113033890724, 41.35353818535805, 39.73251096904278, 46.06491297483444, 43.15252125263214, 44.03605364263058, 49.17559325695038, 44.52868200838566, 42.87196330726147, 43.99888403713703, 43.95050123333931, 41.99648268520832, 43.00504356622696, 42.28959135711193, 40.63048258423805, 41.9315517693758, 42.17612944543362, 42.853302508592606, 44.713766276836395, 44.49342370033264, 43.334010913968086, 45.76348274946213, 44.68810245394707, 44.19983245432377, 44.24843944609165, 43.668810948729515, 41.03327617049217, 44.33212235569954, 41.629555374383926, 41.2349883466959, 40.01961976289749, 40.53664281964302, 42.82854303717613, 43.96464407444, 41.83501414954662, 42.455448657274246, 42.08471395075321, 44.084527641534805, 41.91222220659256, 42.57526382803917, 45.92343136668205, 44.60730738937855, 39.70018610358238, 42.49066136777401, 39.19148840010166, 52.72051803767681, 50.73743864893913, 34.16428215801716, 45.523537024855614, 42.164046093821526, 40.16973450779915, 45.521659925580025, 45.9169565141201, 43.00906755030155, 47.54141494631767, 47.448623925447464, 44.54770378768444, 45.41328974068165, 45.89618302881718, 45.74083596467972, 43.77550922334194, 45.98948322236538, 47.170429453253746, 50.69519251585007, 50.331088453531265, 57.30692133307457, 59.569103345274925, 60.074730813503265, 62.69824683666229, 62.62950472533703, 59.868086501955986, 59.53782342374325, 60.674540027976036, 61.52852140367031, 62.07558944821358, 58.59119541943073, 62.570976465940475, 64.4415856897831, 67.69893810153008, 65.51886588335037, 68.48154410719872, 70.21734416484833, 74.63297322392464, 70.4726068675518, 74.9077820777893, 77.09501311182976, 71.81987777352333, 66.57476082444191, 71.44639581441879, 67.5812204182148, 77.027308344841, 68.49425822496414, 89.13013771176338, 8.466632533818483, 0.6427831866312772, 0.4626810149056837, 1.9670190755277872, 64.20805782079697, 67.04309329390526, 64.71064165234566, 44.748230427503586, 36.69037140905857, 41.878715604543686, 50.238175839185715, 56.24471873044968, 5.836859196424484, 0.10369003095547669, 0.10338665582821704, 0.04848880475037731, 0.04425183171406388, 0.014464500891335774, 0.07942727155750617, 0.19704567035660148, 0.14247483923099935, 0.2597115217940882, 0.15227432042593136, 0.18896893656346947, 0.29577114153653383, 0.0872998998966068, 0.2903429843718186, 2.2773764468729496, 70.90107187628746, 58.547353371977806, 55.98734334111214, 44.72250580787659, 71.48722842335701, 75.7432508468628, 90.2394349873066, 11.659121476113796, 0.33419111743569374, 1.2128615495748818, 56.98018826544285, 93.53700444102287, 78.15449506044388, 82.7774865925312, 76.81171551346779, 82.74657145142555, 75.29268622398376, 77.61690750718117, 78.81599396467209, 79.23827290534973, 74.08041447401047, 76.15235209465027, 78.05047944188118, 69.52301502227783, 57.79022499918938, 63.120791763067245, 67.8704684972763, 70.35833179950714, 71.18272796273232, 75.40375426411629, 68.58964830636978, 70.45945197343826, 72.34567075967789, 67.59350895881653, 68.77931892871857, 70.11628478765488, 64.506676197052, 55.23495331406593, 53.48972596228123, 55.87160915136337, 52.231434881687164, 52.148542329669, 53.232175782322884, 54.64273229241371, 50.34476391971111, 49.37529534101486, 49.961626678705215, 51.47780232131481, 49.91744264960289, 50.55014669895172, 51.318469271063805, 53.702491745352745, 45.99624685943127, 50.60904733836651, 52.74019718170166, 49.357538893818855, 44.4624287635088, 41.96059361100197, 49.29304875433445, 44.57320421934128, 44.67845097184181, 50.26387766003609, 48.712006732821465, 45.11393420398235, 48.29416215419769, 46.135490387678146, 47.31048993766308, 46.45956739783287, 45.50805665552616, 43.26300412416458, 44.589562341570854, 45.88290274143219, 44.78555202484131, 47.65083767473698, 45.84351785480976, 47.19230107963085, 49.456804767251015, 46.68060153722763, 47.38684684038162, 46.38153478503227, 47.56306618452072, 44.04437139630318, 46.739764362573624, 45.10741375386715, 43.795990124344826, 41.61849416792393, 42.2126454859972, 44.23542894423008, 48.72502103447914, 44.7828009724617, 44.50625941157341, 43.63774001598358, 47.594102919101715, 44.57541570067406, 45.18688648939133, 48.20997007191181, 49.27142791450024, 38.650431632995605, 43.304520696401596, 38.53933699429035, 53.34509052336216, 53.685316666960716, 40.177638083696365, 46.876127645373344, 44.45346884429455, 42.83653400838375, 46.44070900976658, 46.25941313803196, 45.39005398750305, 50.38560792803764, 49.52850691974163, 47.60938949882984, 48.5344460606575, 48.85965161025524, 47.37534485757351, 45.62768183648586, 48.8624482601881, 49.397816732525826, 52.2705689817667, 53.986211121082306, 60.62089450657368, 63.49407613277435, 60.28770558536053, 64.75364774465561, 64.84106585383415, 62.4079804122448, 61.55866518616676, 64.43710193037987, 62.0498002320528, 64.09515827894211, 60.290954411029816, 64.85128730535507, 66.3192169368267, 71.29599988460541, 69.24014300107956, 72.63676553964615, 72.3278497159481, 77.83392146229744, 69.39550906419754, 73.62897589802742, 81.4757752418518, 75.81704288721085, 72.22406968474388, 75.71496516466141, 69.37619090080261, 83.61465007066727, 72.64642462134361, 95.84528177976608, 7.348182499408722, 0.8356806077063084, 0.5653572943992913, 3.235923699103296, 72.97069922089577, 76.13104283809662, 70.86119681596756, 63.0064444988966, 59.076243191957474, 45.066265761852264, 61.89823016524315, 68.68582114577293, 7.134990664198995, 0.3815906646195799, 0.19701571727637202, 0.13022814091527835, 0.13674303976586089, 0.1909089699620381, 0.15791680983966216], [0.015937318930809852, 0.026036663039121777, 0.06491639200248756, 0.020710749704448972, 0.04944801577948965, 0.0060006916282873135, 0.030181572656147182, 0.07438310902216472, 1.2815685127861798, 48.09482865035534, 46.027629375457764, 36.67596258223057, 26.139525063335896, 56.17050111293793, 62.62049540877342, 74.84016850590706, 6.051109274849296, 0.09922388271661475, 0.062462681089527905, 41.9402989000082, 87.45494440197945, 70.45846402645111, 77.04593494534492, 70.11136025190353, 76.97226449847221, 71.95507451891899, 75.37544578313828, 70.65706416964531, 73.71600642800331, 71.19201466441154, 75.15276253223419, 65.59535577893257, 63.80958080291748, 70.91781377792358, 68.54965165257454, 67.20670491456985, 66.14956364035606, 68.92808854579926, 65.82189202308655, 66.15921512246132, 62.99486272037029, 65.19931823015213, 65.36589369177818, 65.98721355199814, 61.610923781991005, 51.413695961236954, 47.82571569085121, 51.80972971022129, 49.5514614880085, 50.34271202981472, 48.051700964570045, 47.309441193938255, 46.875348687171936, 44.63175147771835, 44.124102517962456, 44.40513163805008, 43.78997504711151, 44.58575114607811, 46.075943782925606, 44.1168525069952, 50.150510743260384, 46.36022932827473, 40.97306080162525, 54.69701237976551, 59.62139613926411, 44.732442274689674, 39.00160878896713, 42.5613983720541, 43.99269796907902, 42.47311010956764, 42.46862255036831, 44.44028355181217, 43.16851459443569, 40.64962975680828, 39.63128060102463, 39.0650387853384, 39.18948210775852, 38.580397590994835, 43.625067695975304, 41.61027140915394, 41.67298324406147, 41.88728414475918, 42.93178349733353, 40.62352515757084, 43.818997889757156, 41.85936324298382, 42.025444731116295, 41.52504198253155, 42.4330298602581, 40.10010324418545, 42.92085908353329, 38.75592917203903, 38.64194668829441, 39.182779267430305, 40.22000961005688, 39.11352038383484, 39.63795684278011, 41.569374203681946, 40.12487031519413, 37.72586904466152, 39.008566215634346, 38.84507618844509, 41.610218212008476, 44.8243061453104, 44.28941264748573, 40.30413709580898, 42.02864795923233, 39.20471929013729, 44.76774998009205, 41.078839525580406, 45.022936686873436, 41.91257558763027, 41.412978395819664, 45.469959899783134, 44.042353704571724, 38.580500185489655, 42.93515771627426, 42.21774101257324, 44.386125057935715, 43.93523745238781, 41.95254184305668, 42.082582265138626, 41.20762221515179, 41.38996683061123, 43.93351994454861, 45.1661130040884, 45.92064991593361, 44.720180332660675, 54.31056551635265, 60.82995168864727, 61.352279260754585, 62.4970780313015, 60.468477085232735, 59.201476871967316, 61.246048361063, 62.14590087532997, 61.15867964923382, 61.468317434191704, 62.676261216402054, 62.19461806118488, 63.2269124686718, 62.19554141163826, 65.65919995307922, 63.42281095683575, 69.70947101712227, 69.45376753807068, 67.12800353765488, 60.84381714463234, 57.918749302625656, 57.778012454509735, 74.46936920285225, 79.21108156442642, 69.42377954721451, 65.13400733470917, 72.69266054034233, 70.71529984474182, 88.26845794916153, 27.89632849395275, 0.35594889835920185, 0.4993791785091162, 0.4538371379021555, 50.927363857626915, 61.28758393228054, 58.604935482144356, 41.34118504822254, 29.038437008857727, 26.313624121248722, 33.472639471292496, 46.4841178804636, 4.956232700496912, 0.18363541807048023, 0.06434886425267905, 0.07260907921590842, 0.028308538494457025, 0.0254182258140645, 0.0318060522840824, 0.016677535168128088, 0.06283353970502503, 0.03550961038854439, 0.11207931282115169, 0.04713861919299234, 0.043507320297067054, 0.0638414356217254, 0.11035423507564701, 2.9125874117016792, 60.94854332506657, 55.691977590322495, 40.43059051036835, 27.283117398619652, 64.8959881067276, 68.48712220788002, 78.89603286981583, 5.278309118002653, 0.13701766409212723, 0.10375381854828447, 45.835272297263145, 91.5445889532566, 72.98593640327454, 79.47755366563797, 73.25183093547821, 78.77652928233147, 72.85681173205376, 76.84315502643585, 72.88419306278229, 76.52615323662758, 72.31074303388596, 76.22668370604515, 67.23775684833527, 65.35491988062859, 73.3908274769783, 71.70000940561295, 67.91252464056015, 66.64486706256866, 70.9406353533268, 67.7401202917099, 70.46746954321861, 66.35865122079849, 67.46047049760818, 68.8216182589531, 66.297178119421, 64.32224169373512, 54.30205397307873, 49.44753706455231, 53.52550484240055, 51.85841269791126, 51.95564188063145, 49.27923649549484, 49.87601727247238, 49.01922024786472, 46.59529231488705, 46.60760745406151, 47.750719115138054, 46.63782723248005, 47.78753913938999, 49.15986590087414, 46.936616599559784, 51.77145056426525, 47.03813575208187, 41.482841446995735, 54.57941249012947, 58.11409682035446, 47.3364045470953, 41.07930310070515, 44.15531404316425, 46.012399792671204, 43.94051916897297, 43.646832928061485, 47.998104840517044, 43.34306962788105, 43.1462287902832, 43.07123601436615, 42.997896149754524, 41.3176529109478, 41.727867498993874, 46.39666177332401, 45.63316874206066, 44.61119458079338, 46.73620015382767, 45.08589170873165, 44.06381115317345, 45.204540342092514, 43.65873008966446, 44.99516397714615, 44.940682500600815, 44.67815838754177, 43.625789657235146, 45.82589440047741, 42.12173156440258, 40.99612936377525, 41.674780547618866, 40.99281594157219, 40.58047726750374, 41.504211500287056, 42.804243341088295, 41.81649014353752, 40.06406597793102, 41.256559789180756, 41.34909622371197, 43.07917758822441, 46.837282329797745, 44.645594134926796, 41.993743032217026, 44.23924393951893, 41.72739252448082, 46.9626148045063, 43.61767329275608, 46.373904794454575, 45.21381564438343, 44.05218757688999, 46.04353912174702, 44.94246460497379, 40.95343105494976, 43.42280834913254, 43.89586016535759, 47.973280772566795, 46.07779808342457, 45.567990839481354, 42.519889399409294, 44.64529015123844, 42.65130914747715, 44.84397768974304, 46.58585362136364, 49.58912506699562, 46.53948470950127, 56.50103397667408, 63.93191143870354, 62.94800363481045, 63.855771124362946, 61.77860878407955, 60.13393923640251, 61.991841942071915, 64.13068637251854, 63.148275688290596, 63.21609444916248, 65.16791671514511, 64.20400723814964, 64.86129596829414, 67.38748401403427, 68.13233524560928, 66.43973886966705, 71.62649855017662, 68.39224889874458, 67.76825398206711, 62.91808404028416, 63.12329202890396, 61.479124054312706, 80.57605192065239, 80.41643008589745, 72.67949044704437, 66.4619068801403, 75.46726405620575, 71.18550941348076, 91.47591143846512, 34.96260792016983, 0.26050190906971693, 0.7071001979056746, 0.5896210705395788, 58.233741000294685, 69.89531144499779, 65.97267553210258, 52.15114898979664, 25.292510613799095, 30.907319225370884, 44.43026348948479, 58.45879152417183, 7.263883547857404, 0.2573991974350065, 0.07923769735498354, 0.036239508917788044, 0.022137359774205834, 0.056663101277081296, 0.00951399368204875, 0.15522257628617808, 0.13960556272650138, 0.20273019501473755, 0.22979370842222124, 0.1554962803493254, 0.1463457924546674, 0.15289865958038718, 0.20597530994564295, 3.6026560328900814, 74.70681846141815, 60.33273696899414, 47.47299961745739, 38.06435488164425, 78.55699986219406, 75.87238311767578, 92.30573371052742, 8.52366367354989, 0.3648525627795607, 0.16063118528109044, 49.68112953007221, 93.30552846193314, 76.90439254045486, 85.49205332994461, 75.39564549922943, 81.38877511024475, 76.23874425888062, 80.38177594542503, 77.36026167869568, 78.71264711022377, 76.12788900732994, 79.18200552463531, 68.17624568939209, 65.43091580271721, 75.11876195669174, 73.01675274968147, 72.2574470937252, 69.70465287566185, 74.79829475283623, 68.3726267516613, 72.59972512722015, 69.03419405221939, 71.95305302739143, 72.10040152072906, 73.11994761228561, 67.43463188409805, 55.32500848174095, 51.59623436629772, 55.24288348853588, 53.135372176766396, 54.84662555158138, 50.9789764881134, 53.17493565380573, 52.42587424814701, 49.60067264735699, 48.33240330219269, 50.48200875520706, 49.1901008784771, 51.088277623057365, 51.43535479903221, 49.09504897892475, 53.922401145100594, 48.18799205124378, 42.18708425760269, 55.73012374341488, 59.49281483888626, 49.806165620684624, 43.77506464719772, 45.253873094916344, 45.18914736807346, 44.66999262571335, 44.26162853837013, 51.176945865154266, 47.583144307136536, 46.3717845082283, 47.06337779760361, 44.599852189421654, 44.877184107899666, 44.826985001564026, 50.065832287073135, 48.84908437728882, 48.81472662091255, 49.55344498157501, 48.605836629867554, 46.4237467199564, 49.105342626571655, 45.999374091625214, 46.97304144501686, 46.958089247345924, 48.264554142951965, 45.5428209900856, 48.154371455311775, 45.47817125916481, 43.475511521101, 44.495072811841965, 45.29419273138046, 44.36001665890217, 45.63389830291271, 47.07833379507065, 43.702477142214775, 43.76868478953838, 44.47484649717808, 43.404918909072876, 47.909155413508415, 49.89294536411762, 47.77380667626858, 40.63603028655052, 42.59994350373745, 40.903672724962234, 46.91323645412922, 45.008022487163544, 47.92175553739071, 45.6253145635128, 45.53758107125759, 45.97116440534592, 45.88484823703766, 41.00864589214325, 44.192274659872055, 44.906982108950615, 48.91189120709896, 48.41830529272556, 46.98398485779762, 46.56080536544323, 46.97877533733845, 46.55046992003918, 50.17215058207512, 49.58971403539181, 49.76092904806137, 48.38768653571606, 60.05477428436279, 65.78841581940651, 66.08484551310539, 68.03233221173286, 66.63063302636147, 62.6583793759346, 67.45119899511337, 66.52446672320366, 66.41931876540184, 66.3045497238636, 68.39427798986435, 67.11034208536148, 70.42583137750626, 68.37941318750381, 71.31686076521873, 67.1742394566536, 73.28625708818436, 71.52455002069473, 71.34747952222824, 67.56427332758904, 68.7870629131794, 67.61393666267395, 85.7101920247078, 78.75762149691582, 75.3696320950985, 71.31983980536461, 80.46721056103706, 76.18242368102074, 96.14722117781639, 34.46781367063522, 0.3497186576714739, 1.199995439965278, 0.9729113720823079, 65.88217958807945, 79.7935751080513, 74.72399353981018, 65.35112768411636, 48.92300561070442, 42.267822325229645, 56.28617450594902, 67.11503103375435, 8.8998444378376, 0.47029432200361043, 0.20415603881701827, 0.24275108735309914, 0.1790002011694014, 0.15014647913631052, 0.11458347493316978], [0.0795018499775324, 0.0506040221080184, 0.0869800713553559, 0.02951388836663682, 0.031140583305386826, 0.07458117339410819, 0.06158613789011724, 0.2015398198273033, 4.202162688598037, 59.074126705527306, 48.12887102365494, 49.24630366265774, 33.676008358597755, 48.70019316673279, 70.83792686462402, 37.39521458745003, 0.29248758335597813, 0.09081423631869256, 0.09720176036353223, 44.40364211797714, 87.81980082392693, 73.0172011256218, 73.44288468360901, 72.2101092338562, 72.48542726039886, 72.81404122710228, 71.24367669224739, 71.4550593495369, 72.25093424320221, 72.85756409168243, 70.54492458701134, 67.71346092224121, 72.09540858864784, 69.02847915887833, 66.70513942837715, 64.52794745564461, 63.22651728987694, 64.96481761336327, 64.17491599917412, 62.46906593441963, 62.717944979667664, 61.713415682315826, 59.23264279961586, 55.36107614636421, 48.44469107687473, 47.578101977705956, 49.93017956614494, 48.33840698003769, 49.14217785000801, 47.4731820076704, 48.8835409283638, 46.356000155210495, 48.41978721320629, 44.80128698050976, 42.72434502840042, 44.92098055779934, 44.704323783516884, 41.771078780293465, 46.133628487586975, 43.34575988352299, 50.00607669353485, 48.9108956605196, 43.38991731405258, 43.52220721542835, 52.28204056620598, 56.54336370527744, 46.33083790540695, 46.25260770320892, 50.95504157245159, 48.353769555687904, 43.574500009417534, 44.176000133156776, 44.57337141036987, 42.08721041679382, 40.86076162755489, 42.109952196478844, 40.132891684770584, 39.03044544160366, 39.08203527331352, 42.54555702209473, 39.98332031071186, 41.5000469237566, 42.05527313053608, 42.18681067228317, 42.59445279836655, 41.80710844695568, 41.0411037504673, 41.71361826360226, 42.756958678364754, 41.80708184838295, 41.74558214843273, 38.4894684702158, 41.496433317661285, 40.98517835140228, 39.63402785360813, 38.52365143597126, 40.36382049322128, 39.39204543828964, 40.36037787795067, 39.58603262901306, 41.72206901013851, 40.3939338773489, 42.7498796582222, 43.92758086323738, 44.35777097940445, 42.379232347011566, 43.422325775027275, 43.54131639003754, 43.28148253262043, 48.50973978638649, 47.71663494408131, 47.1583840996027, 43.68760094046593, 41.45534232258797, 41.11453860998154, 39.68148730695248, 39.00645732879639, 42.61368356645107, 47.433189153671265, 44.732571467757225, 44.75359193980694, 41.6868980973959, 41.74413442611694, 39.362768009305, 41.810953840613365, 46.981089413166046, 47.06760697066784, 47.350026816129684, 56.34687624871731, 54.80252891778946, 58.739376068115234, 52.00464405119419, 50.2541121840477, 61.188751235604286, 59.417278692126274, 59.58809472620487, 63.40628184378147, 63.516168147325516, 64.14330929517746, 64.71867442131042, 62.24465757608414, 64.85344558954239, 65.30910953879356, 59.628950133919716, 55.412323996424675, 53.49080890417099, 58.402235358953476, 61.699660420417786, 67.07115858793259, 71.2860444188118, 64.35118854045868, 64.88168567419052, 76.63277551531792, 70.45598655939102, 70.20484283566475, 70.47675624489784, 80.49108847975731, 58.0580498278141, 0.07450214208802208, 0.10721324346377514, 0.10362469227402471, 48.28774809837341, 64.88163247704506, 57.65649877488613, 45.16974560916424, 37.53862649202347, 38.721742406487465, 33.00827018916607, 52.32800669968128, 8.191431351006031, 0.13918835698859766, 0.11167525051860139, 0.07104809032171033, 0.04441669239895418, 0.11324485574732535, 0.05866082552529406, 0.04962493265338708, 0.02187739657529164, 0.07397047491394915, 0.03476803787634708, 0.009257927686121548, 0.03869038853736129, 0.11535337151144631, 0.21126410661963746, 5.767824975773692, 72.48427212238312, 55.83477392792702, 56.426493376493454, 39.85426023602486, 57.759746834635735, 77.62424871325493, 38.997520208358765, 0.44116550066974014, 0.06003944276017137, 0.10616662970278412, 46.80305756628513, 89.01913046836853, 76.1414922773838, 76.14979863166809, 76.1973112821579, 74.77613434195518, 76.24451234936714, 74.55468222498894, 74.46680814027786, 73.67488503456116, 72.72259533405304, 71.6849622130394, 69.63797405362129, 75.07970005273819, 70.24971842765808, 70.21127209067345, 66.92229777574539, 65.17848014831543, 68.1262555718422, 65.91679573059082, 63.988171219825745, 65.1216883957386, 65.66796228289604, 61.783704310655594, 58.68937075138092, 50.37311039865017, 51.49415284395218, 51.9414534419775, 50.13352945446968, 50.19190952181816, 49.54967178404331, 51.18979297578335, 49.792961329221725, 51.0636967420578, 47.92026221752167, 45.861194506287575, 46.65858931839466, 47.072740495204926, 44.826620221138, 49.82951536774635, 45.51241882145405, 52.18506217002869, 49.56062659621239, 43.672952726483345, 45.468090400099754, 52.34427362680435, 59.05991546809673, 47.23932735621929, 48.90532895922661, 51.754697263240814, 49.5193038135767, 44.583600461483, 45.74053198099136, 47.36681051552296, 45.22858925163746, 42.00025588274002, 43.69968429207802, 42.868798077106476, 42.22110003232956, 40.820742174983025, 44.850608333945274, 42.41439186036587, 44.645506739616394, 43.878354504704475, 44.70749281346798, 43.94856333732605, 44.89475056529045, 43.32028605043888, 43.54781024158001, 45.2283650636673, 44.90152180194855, 42.24555552005768, 41.394841969013214, 42.69541338086128, 42.74905890226364, 43.236097767949104, 42.36817114055157, 41.48994326591492, 43.48637893795967, 43.65561045706272, 43.90117987990379, 41.9300090521574, 43.24666500091553, 46.130714043974876, 47.960331067442894, 44.06855329871178, 42.38314613699913, 43.62691819667816, 45.2083895355463, 43.49287658929825, 50.05205422639847, 47.70724944770336, 47.65343673527241, 44.6576888859272, 42.74694241583347, 42.008535638451576, 40.840687304735184, 38.66538383066654, 44.35434356331825, 48.919543996453285, 47.361680790781975, 45.96039958298206, 45.36633566021919, 44.231009781360626, 41.73143170773983, 45.153638273477554, 48.33364963531494, 48.21791924536228, 50.011989176273346, 58.09141963720322, 58.801924511790276, 60.901919826865196, 55.55230848491192, 54.547448605298996, 63.351910561323166, 62.45349816977978, 63.83217439055443, 65.03883004188538, 64.66696679592133, 65.459725856781, 66.98202297091484, 66.43030777573586, 66.43007218837738, 68.37334871292114, 62.05341383814812, 59.11856152117252, 57.22780957818031, 63.2871088385582, 64.9326865375042, 69.06899258494377, 72.16271057724953, 69.37594011425972, 69.09840300679207, 80.34549549221992, 74.98077616095543, 72.35189482569695, 73.16166177392006, 83.17166224122047, 65.00634178519249, 0.12837335059884936, 0.10949766307021491, 0.08886619514669292, 51.81740529835224, 75.02840280532837, 65.32810091972351, 55.079777240753174, 31.42539482563734, 41.80837757885456, 42.520843148231506, 62.44601637125015, 11.425344720482826, 0.24018551252083853, 0.18662282964214683, 0.10337774263462052, 0.08415100441197865, 0.011211871715204325, 0.04397920005430933, 0.18238071352243423, 0.2383887581527233, 0.17143563833087683, 0.12658538325922564, 0.11726712546078488, 0.1991151343099773, 0.2787423849804327, 0.4270033340435475, 8.218430802226067, 84.91080611944199, 62.25033067166805, 64.36717808246613, 49.52578626573086, 68.64941909909248, 81.31606981158257, 50.746375769376755, 0.7830274268053472, 0.17718189483275637, 0.2108978122123517, 53.93268719315529, 92.37058863043785, 79.71771597862244, 79.12833720445633, 79.48253139853477, 78.62438544631004, 80.57930454611778, 78.7936207652092, 78.31677675247192, 77.06760138273239, 75.40717408061028, 73.06934952735901, 71.04159593582153, 75.86799815297127, 74.04611751437187, 74.65486004948616, 71.33155837655067, 69.01462510228157, 73.79384905099869, 69.12907496094704, 67.2059753537178, 67.70326986908913, 67.70754083991051, 65.90504676103592, 61.46969296038151, 52.64927566051483, 52.51525305211544, 54.55898858606815, 54.218899235129356, 53.729512095451355, 51.13274283707142, 53.917385414242744, 52.511441856622696, 53.26849803328514, 51.14242471754551, 48.42106394469738, 49.57501642405987, 49.60075244307518, 47.5741083920002, 52.70799770951271, 46.664843782782555, 54.03271682560444, 50.07946975529194, 43.520219922065735, 44.37648497521877, 54.78501185774803, 60.87926544249058, 48.40737707912922, 48.841397389769554, 52.20806613564491, 51.87992714345455, 45.585648491978645, 48.38370814919472, 50.229884684085846, 47.7339506149292, 46.062093526124954, 47.9273222386837, 46.97025239467621, 45.250958651304245, 42.41669073700905, 48.77617008984089, 45.28681732714176, 46.36658638715744, 46.919939294457436, 46.754283383488655, 45.64555987715721, 46.4020536839962, 43.98762904107571, 45.57930663228035, 48.95615503191948, 48.95692639052868, 45.361399725079536, 42.15880997478962, 46.4301797747612, 45.452382043004036, 45.22816747426987, 44.40920501947403, 44.27799426019192, 46.5709014236927, 46.97927311062813, 46.47149495780468, 45.7776103913784, 44.95845414698124, 48.83108854293823, 50.886812433600426, 45.81524357199669, 43.49284619092941, 44.66085031628609, 45.61363399028778, 43.199121952056885, 50.77054627239704, 49.311181381344795, 48.134494721889496, 46.242481246590614, 44.58520397543907, 42.33603246510029, 41.78609177470207, 38.7999802082777, 44.57320421934128, 50.3876294195652, 49.46440435945988, 51.76708459854126, 46.97537451982498, 47.28249303996563, 46.026911213994026, 47.726666405797005, 51.49795264005661, 50.07323049008846, 53.67997795343399, 61.187181919813156, 60.813012197613716, 62.17528849840164, 62.87336423993111, 58.09005171060562, 67.96886041760445, 65.9467001259327, 66.07502683997154, 67.93146282434464, 67.27214500308037, 67.97106429934502, 70.01637294888496, 67.08473905920982, 68.26069235801697, 71.93200215697289, 66.44337147474289, 60.713795721530914, 59.35346871614456, 65.95230862498283, 68.0775497853756, 70.91528311371803, 71.40791147947311, 72.4406124651432, 76.79612874984741, 80.18214985728264, 75.86080893874168, 77.8861990571022, 79.18358623981476, 88.03923144936562, 68.30706506967545, 0.20427455980097875, 0.700045817065984, 0.2859614632325247, 59.990333542227745, 83.30574184656143, 75.04547148942947, 64.95769679546356, 64.96172457933426, 62.11323022842407, 52.88569897413254, 77.99187138676643, 14.626463949680328, 0.3802380559500307, 0.26372526423074305, 0.27146533015184104, 0.29666860587894917, 0.13175692060030997, 0.20542742684483528], [0.05883173471374903, 0.009817443024076056, 0.07136008920497261, 0.0036637402581618517, 0.010772417317639338, 0.06500963543658145, 0.050108449286199175, 0.26544075342826545, 4.064148394390941, 60.37981644272804, 48.95995482802391, 27.330721244215965, 27.8771186247468, 50.52499584853649, 77.33468905091286, 20.664643943309784, 0.5279260373208672, 0.3705345344496891, 0.43175123864784837, 34.67700004577637, 86.33219584822655, 70.87479248642921, 73.56236547231674, 71.45277947187424, 71.44737616181374, 69.50547516345978, 71.3941790163517, 72.16866105794907, 72.52946689724922, 71.0329931974411, 71.30207195878029, 68.28651577234268, 65.16978621482849, 65.4030404984951, 63.422696962952614, 63.51652532815933, 61.774770990014076, 61.34546622633934, 58.02704729139805, 58.327424973249435, 53.03121216595173, 52.41359330713749, 47.842560186982155, 48.508406057953835, 48.02731767296791, 47.611228600144386, 46.433527395129204, 47.39198036491871, 47.169692292809486, 47.85185068845749, 46.56539171934128, 50.00127375125885, 45.8606169372797, 43.95137898623943, 44.17058162391186, 43.750464767217636, 43.4588798135519, 43.637759014964104, 45.39363719522953, 46.83703154325485, 47.055109441280365, 55.43745584785938, 49.070810079574585, 46.1687234044075, 51.30516618490219, 48.45148891210556, 47.463914304971695, 55.788199827075005, 49.79913219809532, 43.56645964086056, 44.87591877579689, 44.353085830807686, 44.940750896930695, 43.947833776474, 41.98344558477402, 38.96270267665386, 41.13554008305073, 38.92763435840607, 41.49949975311756, 38.899884447455406, 41.647767797112465, 42.221567407250404, 42.15645410120487, 40.971426889300346, 43.62262822687626, 40.859553292393684, 42.91172817349434, 41.18757829070091, 41.80268168449402, 43.034127205610275, 40.05134046077728, 40.85701882839203, 40.857983976602554, 44.0220095962286, 40.34373477101326, 39.28891897201538, 41.94593399763107, 39.475063383579254, 40.586963519454, 40.12227885425091, 41.06823809444904, 41.98453992605209, 40.95962472259998, 44.71696950495243, 41.29936449229717, 42.38339692354202, 41.56732231378555, 44.39385764300823, 43.52342315018177, 45.68856216967106, 44.83244530856609, 45.5855268985033, 46.27999283373356, 47.350266203284264, 41.15830846130848, 40.392421558499336, 41.57614924013615, 44.27159920334816, 41.78853124380112, 42.605487406253815, 41.88447989523411, 41.23448297381401, 41.704012379050255, 39.30403456091881, 41.38547167181969, 43.85706804692745, 43.60840559005737, 44.81205180287361, 54.030801728367805, 59.85106721520424, 56.85482919216156, 50.08474387228489, 58.50611798465252, 60.31233586370945, 61.01540453732014, 59.758340790867805, 59.41873401403427, 61.434841230511665, 62.648993879556656, 62.96350680291653, 63.753837794065475, 65.69548040628433, 60.674179047346115, 59.782032519578934, 58.10439594089985, 63.37938688695431, 67.3679530620575, 67.09059074521065, 65.15849322080612, 64.3337094783783, 72.91612654924393, 67.16572031378746, 61.67784959077835, 72.78313368558884, 71.0803310573101, 73.45543161034584, 74.47933226823807, 80.11002972722054, 3.0899778055027127, 0.1437291133333929, 0.045672636333620176, 40.958416387438774, 66.92117303609848, 59.38859023153782, 49.68744099140167, 28.53152710944414, 27.109240628778934, 34.383708983659744, 57.08729311823845, 10.298069659620523, 0.20487356203375384, 0.08019217348191887, 0.06559706016560085, 0.04805024742381647, 0.01433515382814221, 0.03886714956024662, 0.036423639467102475, 0.054020213210606016, 0.09627968640415929, 0.0294458371354267, 0.014817261308053276, 0.011964643235842232, 0.07615155045641586, 0.2806290431180969, 7.624547844752669, 71.18599578738213, 53.1061365455389, 38.607607930898666, 38.60845148563385, 58.69396470487118, 83.04826766252518, 25.066648833453655, 0.3880527225555852, 0.28770473843906075, 0.3981005708919838, 37.98587389290333, 88.95058214664459, 73.39056149125099, 78.39424699544907, 73.27203825116158, 75.33163413405418, 73.41932594776154, 72.29565784335136, 73.81277203559875, 73.8488321006298, 72.64583185315132, 71.6851370036602, 71.3113434612751, 66.00034564733505, 68.0889567732811, 67.83083662390709, 65.30695125460625, 62.28683151304722, 63.37304122745991, 60.83875581622124, 59.36812832951546, 56.57017506659031, 55.26082992553711, 51.41232803463936, 50.52685774862766, 50.11903703212738, 50.342708230018616, 48.70053134858608, 48.983676955103874, 49.13406528532505, 48.38587023317814, 48.31406928598881, 50.90864606201649, 48.47942501306534, 46.72227770090103, 46.4891792088747, 45.9235567599535, 45.90847156941891, 47.022670581936836, 47.2942154109478, 46.68804153800011, 50.390771850943565, 54.58320468664169, 47.60553650557995, 46.92990995943546, 50.61721310019493, 49.09113138914108, 48.48065994679928, 54.94906045496464, 49.880805015563965, 44.580070450901985, 44.566239193081856, 46.95485182106495, 47.668381333351135, 46.35422945022583, 44.57908250391483, 41.21916979551315, 42.942688912153244, 41.5509869903326, 44.24576058983803, 41.332012340426445, 43.64319272339344, 43.045344203710556, 43.0988073348999, 42.402650490403175, 47.19415158033371, 44.32907871901989, 43.832031190395355, 43.70351828634739, 43.6604817956686, 45.29864989221096, 42.85926818847656, 43.413244262337685, 43.86375188827515, 46.690500006079674, 42.94082321226597, 43.281284943223, 42.94617332518101, 42.002026587724686, 44.059547781944275, 41.71044923365116, 42.53880858421326, 42.59334325790405, 43.32031264901161, 46.18313983082771, 43.271059691905975, 43.29137720167637, 42.2466878592968, 44.73664104938507, 45.73552004992962, 47.91735917329788, 45.93345142900944, 45.58088734745979, 46.42544522881508, 49.12246830761433, 40.80913759768009, 40.0166255235672, 40.21038472652435, 44.34782311320305, 42.4873935431242, 44.273765087127686, 43.578326404094696, 43.55036370456219, 44.5565877109766, 41.257057562470436, 42.82386548817158, 47.290772795677185, 45.961265936493874, 47.96338990330696, 54.55622233450413, 63.160313442349434, 60.04042245447636, 57.2700747102499, 60.41414760053158, 62.432006523013115, 64.48235750198364, 63.51335629820824, 62.707389146089554, 63.57579454779625, 63.79921495914459, 65.7795698940754, 65.61971247196198, 66.30481570959091, 61.579100489616394, 60.344592332839966, 58.071284517645836, 65.31442165374756, 67.02636659145355, 68.71224492788315, 66.54648274183273, 67.61933237314224, 73.88803079724312, 71.4486300945282, 67.84960761666298, 77.9144923388958, 72.42736637592316, 77.23897218704224, 73.63250970840454, 84.36806604266167, 4.2587848752737045, 0.1767161674797535, 0.038382137499866076, 44.217554703354836, 76.06725946068764, 66.01842507719994, 59.228607416152954, 36.01173162460327, 31.191013902425766, 43.80266256630421, 67.61744007468224, 13.02999671548605, 0.22360774426488206, 0.10695241566281766, 0.04844534458243288, 0.02808379205816891, 0.047742493625264615, 0.03349270162289031, 0.16969212563708425, 0.1928673344082199, 0.19883160421159118, 0.13124431920005009, 0.07628682171343826, 0.2148075500736013, 0.24596654606284574, 0.5004469805862755, 11.054535917937756, 84.29869696497917, 62.36058175563812, 38.62747326493263, 39.179857224226, 70.91344401240349, 87.76170954108238, 31.934504806995392, 0.6160432496108115, 0.47392107895575464, 0.5242033652029932, 41.53007671236992, 91.23137935996056, 76.3406927883625, 82.33889132738113, 77.55403608083725, 78.29899370670319, 74.59159344434738, 73.82016643881798, 77.41389960050583, 75.6657350063324, 75.26771396398544, 75.0528734922409, 73.94570410251617, 69.87676844000816, 71.55310928821564, 70.07627293467522, 69.51919242739677, 66.08212485909462, 67.89641350507736, 63.78886431455612, 62.81632550060749, 57.878205478191376, 59.14776295423508, 53.80550041794777, 52.93145231902599, 54.15970221161842, 53.79342466592789, 51.23422019183636, 53.18339020013809, 50.747249722480774, 52.90638506412506, 50.268524810671806, 54.7325024753809, 50.470761358737946, 48.36223550140858, 48.49838599562645, 50.21821171045303, 48.4652403742075, 50.257813185453415, 49.40131634473801, 51.4530960470438, 52.90982387959957, 58.20846475660801, 50.44670484960079, 47.473296001553535, 51.986021250486374, 50.45634873211384, 47.79173791408539, 56.148667484521866, 51.90667390823364, 45.31243555247784, 45.721453204751015, 48.74300926923752, 51.08694389462471, 50.48103980720043, 48.24341967701912, 43.40868070721626, 47.418996915221214, 45.0063543766737, 48.43405544757843, 43.91580909490585, 46.05468772351742, 47.072303518652916, 46.4227169752121, 45.15244133770466, 49.200827702879906, 45.664840042591095, 46.75936371088028, 46.25203773379326, 47.00843274593353, 49.635813161730766, 44.74765665829182, 46.10584817826748, 46.827155873179436, 49.15342904627323, 45.82621358335018, 45.78540377318859, 46.745733842253685, 44.701109156012535, 47.114800438284874, 43.11083368957043, 45.54892726242542, 46.41810022294521, 47.37041652202606, 48.15275654196739, 44.0519367903471, 44.26448978483677, 42.758854776620865, 44.58195894956589, 44.888374507427216, 49.11674201488495, 46.922580152750015, 46.323842480778694, 48.239281699061394, 50.11256217956543, 41.38395555317402, 40.983130261301994, 42.93067015707493, 46.27473011612892, 45.463906824588776, 46.78533531725407, 47.6569477468729, 45.9106108546257, 48.62931936979294, 43.531383723020554, 46.96569263935089, 48.99932071566582, 48.2232541590929, 49.27389018237591, 58.23482394218445, 64.67247650027275, 63.13148818910122, 58.84467601776123, 60.29156997799873, 66.78118854761124, 67.30641916394234, 64.99461561441422, 63.87707278132439, 66.67759090662003, 66.61314636468887, 66.45700514316559, 69.36050534248352, 71.18601858615875, 63.38790982961655, 61.756452172994614, 59.34805020689964, 66.11939325928688, 67.51627430319786, 70.03348723053932, 70.12905210256577, 73.38815242052078, 75.11865556240082, 73.8609990477562, 74.39963534474373, 81.17311388254166, 73.86635676026344, 81.3706424832344, 79.79208558797836, 89.28240314126015, 4.133844254538417, 0.5731799465138465, 0.12905780371511355, 49.97258149087429, 85.28741911053658, 72.81459599733353, 68.69580700993538, 49.097264260053635, 41.81582137942314, 52.238285914063454, 82.74458795785904, 16.91205270588398, 0.39670788624789566, 0.0753779431397561, 0.140263625071384, 0.1500889626913704, 0.11304791201837361, 0.17978043586481363], [0.04412554044392891, 0.019235289619246032, 0.013544028115575202, 0.04461064156203065, 0.05576958887104411, 0.04953902534907684, 0.08116804572637193, 0.21664302970748395, 6.704425793141127, 53.89538459479809, 48.11080679297447, 41.572725623846054, 49.62447077035904, 55.96737161278725, 75.66948160529137, 26.412945091724396, 0.2861796546494588, 0.4940922965761274, 0.3995166183449328, 30.19849956035614, 84.5116375386715, 74.74600195884705, 74.54808577895164, 72.3860701918602, 69.97003063559532, 72.6156310737133, 69.77522268891335, 72.74728640913963, 68.78053486347198, 71.6917334496975, 67.9582741856575, 66.68896749615669, 66.38167038559914, 63.223572447896004, 60.02843789756298, 56.53469257056713, 52.800613939762115, 54.12344075739384, 53.30608941614628, 49.7612976282835, 49.04377453029156, 48.3903843909502, 45.90703904628754, 48.777925595641136, 45.167667120695114, 47.57111795246601, 46.25555254518986, 45.82344353199005, 47.909231409430504, 46.116571202874184, 46.54722489416599, 46.61505125463009, 47.07687847316265, 46.53207130730152, 42.338327541947365, 42.14348539710045, 42.806215435266495, 42.917161881923676, 44.96865279972553, 44.26353983581066, 51.417400762438774, 51.354263350367546, 50.84438011050224, 51.799854040145874, 54.42337766289711, 56.93283520638943, 55.624071434140205, 56.51890441775322, 48.138499706983566, 47.595030069351196, 47.59142026305199, 52.41532601416111, 47.406829968094826, 43.563567996025085, 43.02212364971638, 41.312743574380875, 41.698001101613045, 41.897630989551544, 41.19370736181736, 45.04845231771469, 42.05075517296791, 41.06216982007027, 42.95082427561283, 41.0827799141407, 43.53818915784359, 42.17297561466694, 40.377936735749245, 41.09029971063137, 40.85784338414669, 42.53259211778641, 39.669411554932594, 39.10398289561272, 41.25381253659725, 38.92533168196678, 40.9775597602129, 40.066862627863884, 39.67877425253391, 39.93801534175873, 40.34452512860298, 41.43696650862694, 41.77381083369255, 44.02725711464882, 41.47306837141514, 44.96680989861488, 42.90061756968498, 46.857717633247375, 41.26984387636185, 44.320593774318695, 44.76541690528393, 49.63523559272289, 49.40777599811554, 52.12769664824009, 49.30558808147907, 47.09354817867279, 40.3237896412611, 40.003056451678276, 37.31125809252262, 42.73769371211529, 43.591462299227715, 42.07465209066868, 41.46407425403595, 41.03013373911381, 42.14569307863712, 41.548767909407616, 43.311181738972664, 45.28658553957939, 45.12805424630642, 47.91820652782917, 48.573139384388924, 58.08052942156792, 58.001539260149, 60.8456714451313, 59.11438934504986, 60.259028524160385, 59.27797056734562, 60.70445582270622, 61.33065462112427, 62.619340270757675, 60.644381046295166, 63.70248354971409, 60.199139937758446, 60.76023302972317, 61.23588390648365, 63.065987303853035, 61.51937149465084, 63.26771467924118, 62.268117517232895, 65.60916423797607, 65.03346472978592, 69.65266406536102, 66.14685818552971, 72.75132939219475, 69.23728555440903, 70.04396706819534, 66.99782252311707, 81.15897104144096, 71.42586171627045, 87.7150784432888, 8.112433589994907, 0.1383860656642355, 0.2555379207478836, 30.144857838749886, 72.51725435256958, 56.20198242366314, 54.88287940621376, 31.146531589329243, 37.07394182682037, 31.589829102158546, 54.34042431414127, 17.451562955975533, 0.1762744560255669, 0.22625967540079728, 0.07825574692105874, 0.015491915291931946, 0.08349638563231565, 0.028563750092871487, 0.05130088022269774, 0.015996688889572397, 0.12444017571397126, 0.07831520037143491, 0.06538099129102193, 0.11946073587751016, 0.11777412364608608, 0.3374311560764909, 10.107147954404354, 65.28173580765724, 56.127802804112434, 42.63098023831844, 47.41081215441227, 65.78435003757477, 83.13964515924454, 31.594398356974125, 0.4430713062174618, 0.4581494611920789, 0.6957902829162776, 33.74788910150528, 86.86457008123398, 76.52483850717545, 75.28118044137955, 72.60849505662918, 71.10342621803284, 74.15141746401787, 73.51077184081078, 73.62237945199013, 68.7037181854248, 71.8394847214222, 68.44882026314735, 69.60075125098228, 66.13995015621185, 66.11433193087578, 62.06662952899933, 59.86044891178608, 56.05396896600723, 56.791832372546196, 54.61698867380619, 50.925699546933174, 51.76293522119522, 50.71953400969505, 47.337935864925385, 51.21072605252266, 48.61445836722851, 51.08014985918999, 48.322573229670525, 48.39169152081013, 48.584280386567116, 48.36453057825565, 48.70190687477589, 49.2435260117054, 47.817743718624115, 46.333387568593025, 44.702971056103706, 44.39796902239323, 45.283648297190666, 45.71676425635815, 46.665710136294365, 48.254176899790764, 52.11745239794254, 57.031508311629295, 53.19364584982395, 54.437847286462784, 54.84255596995354, 59.162373170256615, 58.43207135796547, 55.27407221496105, 49.39969763159752, 50.02585083246231, 48.221137672662735, 50.94695560634136, 50.107523649930954, 46.75825037062168, 45.90282127261162, 41.838411167263985, 43.754553347826004, 44.00275982916355, 42.507361471652985, 47.581248208880424, 43.87617342174053, 43.46593223512173, 45.38817308843136, 43.55213440954685, 45.53114041686058, 45.48676259815693, 43.16376104950905, 43.59340399503708, 42.10511885583401, 45.604324489831924, 42.04199284315109, 42.203233391046524, 42.99007996916771, 40.104833990335464, 43.42537321150303, 42.91661851108074, 43.210202157497406, 43.063514828681946, 42.09025025367737, 45.792156010866165, 44.00516889989376, 46.04914382100105, 45.562967509031296, 46.58497206866741, 45.0539506226778, 45.818370804190636, 43.93187463283539, 45.290259942412376, 45.52604869008064, 49.537489637732506, 48.85598100721836, 54.761312529444695, 49.39068831503391, 49.76956218481064, 41.30619652569294, 38.53342831134796, 36.81809775531292, 42.55269303917885, 44.67170253396034, 44.78390671312809, 42.44420126080513, 42.92125806212425, 43.64972837269306, 42.196184769272804, 45.93771480023861, 47.373129576444626, 46.87194027006626, 50.66756419837475, 51.47579602897167, 58.89882691204548, 59.54115964472294, 61.807947009801865, 60.744254887104034, 61.430836245417595, 59.95986297726631, 64.51476976275444, 62.9316683113575, 66.30378976464272, 61.60856030881405, 64.25424054265022, 62.48645380139351, 63.66512395441532, 61.870605647563934, 62.90495954453945, 61.62072345614433, 64.5370289683342, 64.50718536973, 68.78529980778694, 69.28358986973763, 71.04527413845062, 67.46984079480171, 74.09714117646217, 72.45648801326752, 74.88586485385895, 70.47797977924347, 84.13480415940285, 73.78380998969078, 88.51121172308922, 9.773993231356144, 0.13718074362259358, 0.18416115548461676, 31.13405115902424, 82.15302810072899, 62.57463186979294, 66.66223213076591, 35.586963817477226, 46.34252227842808, 46.23751111328602, 63.76691669225693, 21.499797329306602, 0.158451022580266, 0.049210944125661626, 0.0517239415057702, 0.07889647269621491, 0.05675065614923369, 0.0904573523439467, 0.15711701213149354, 0.10681540035875514, 0.23297096136957407, 0.2246516343438998, 0.20796278142370284, 0.27721079997718334, 0.3151001699734479, 0.5489237699657679, 14.211467318236828, 77.94273242354393, 62.64862149953842, 51.36487238109112, 62.59856678545475, 73.87328758835793, 86.83755353093147, 35.35385772585869, 0.44893382757436484, 0.7308377616573125, 0.5962023173924536, 37.15366534888744, 90.82474797964096, 80.40504589676857, 79.70058649778366, 79.08656224608421, 75.86014777421951, 78.6187769472599, 74.60844174027443, 75.31536340713501, 70.42026847600937, 73.71495008468628, 71.23714104294777, 72.36938148736954, 71.76027417182922, 68.29710960388184, 65.32303959131241, 61.73170030117035, 59.14087392389774, 61.02045826613903, 58.33462938666344, 54.934317246079445, 55.43411202728748, 54.7776098549366, 50.32234512269497, 56.27265103161335, 50.52969239652157, 54.26007002592087, 51.402034386992455, 50.13021603226662, 51.91527284681797, 51.30930036306381, 52.76047669351101, 50.73039382696152, 49.338631108403206, 50.64445003867149, 47.20373846590519, 46.83127485215664, 47.17092342674732, 47.65772670507431, 52.01445512473583, 50.99664553999901, 54.905617386102676, 61.20243810117245, 56.764656230807304, 52.814540192484856, 56.843369007110596, 58.006190210580826, 58.31243857741356, 57.31604464352131, 50.4518573731184, 50.4437980055809, 50.621563866734505, 55.05814120173454, 53.06395500898361, 51.554030030965805, 49.32428687810898, 45.785407572984695, 46.66288688778877, 46.488795429468155, 45.80943748354912, 50.8225616812706, 46.684249341487885, 46.11803412437439, 48.04743379354477, 46.00429102778435, 48.1483069807291, 47.57585629820824, 45.549675822257996, 45.00135764479637, 44.47722516953945, 46.47542394697666, 44.22582685947418, 44.34175483882427, 45.41723392903805, 42.912993505597115, 46.238495260477066, 45.72286292910576, 45.91658413410187, 43.42110984027386, 44.47944425046444, 46.454221084713936, 46.77890606224537, 49.87887851893902, 47.336400747299194, 47.799272909760475, 45.08920133113861, 46.68720558285713, 44.74792264401913, 46.243852972984314, 46.38650871813297, 50.83647273480892, 49.51730512082577, 55.72693571448326, 51.00252382457256, 50.90813308954239, 41.673914194107056, 40.81995941698551, 38.17965969443321, 43.74364793300629, 46.42658516764641, 46.126511469483376, 47.110385075211525, 45.6968305259943, 46.99616700410843, 45.249028354883194, 49.95027668774128, 49.94238831102848, 49.23317916691303, 53.66213031113148, 54.49096083641052, 63.16596373915672, 63.673840686678886, 64.9153670668602, 64.68658894300461, 65.41301876306534, 64.76587548851967, 65.33690124750137, 64.89892914891243, 69.33646783232689, 64.57741320133209, 67.19160452485085, 64.73002061247826, 65.35946443676949, 64.88336518406868, 65.80439776182175, 65.00182762742043, 67.20653012394905, 65.814558416605, 72.60647356510162, 71.17630630731583, 74.07789140939713, 72.03578978776932, 78.84462162852287, 73.177560120821, 80.72410717606544, 76.97778180241585, 86.35021448135376, 77.8077332675457, 96.9954040646553, 10.161459390074015, 0.2582935447571799, 0.21878464525798336, 36.83828227221966, 92.44364351034164, 69.8751649260521, 76.0277871787548, 48.762042447924614, 57.24508725106716, 49.31620851159096, 79.25254493951797, 24.758891947567463, 0.30709732440300286, 0.4215338540961966, 0.15137511945795268, 0.15616912627592683, 0.1746989507228136, 0.17731286905473098], [0.06592350124265067, 0.02745956793660298, 0.07290082488907501, 0.03340598908835091, 0.017123591896961443, 0.02847631767508574, 0.06670712755294517, 0.3378841036465019, 7.550425697118044, 56.430053785443306, 41.98260582983494, 58.230207189917564, 56.91249869763851, 53.93558643758297, 79.39449772238731, 29.96999692171812, 0.23058819235302508, 0.30775816238019615, 0.6066480162553489, 24.84211888164282, 86.58172085881233, 72.5190782546997, 71.99147656559944, 67.3642672598362, 71.72541484236717, 69.5136371254921, 71.93322569131851, 71.02032467722893, 69.88855540752411, 71.53545543551445, 67.45246812701225, 65.00960201025009, 61.62136182188988, 56.28985270857811, 53.12368780374527, 50.77774688601494, 50.63430078327656, 51.5642324835062, 48.07229965925217, 48.99171732366085, 46.136330142617226, 46.220066249370575, 46.876154243946075, 45.89553326368332, 46.12477496266365, 44.45190332829952, 44.695990830659866, 46.40494912862778, 45.46823479235172, 46.84623844921589, 44.54210288822651, 48.79964143037796, 46.210152581334114, 46.06627330183983, 42.573519721627235, 43.102101758122444, 42.479645758867264, 41.323470398783684, 43.412301912903786, 45.78727327287197, 48.467159271240234, 56.09755262732506, 58.19513887166977, 56.54476583003998, 54.10410359501839, 58.114100620150566, 61.83491416275501, 58.46673309803009, 48.91871564090252, 51.74598053097725, 46.8832066655159, 46.8075755238533, 46.709734573960304, 43.38697627186775, 44.063613563776016, 41.85155466198921, 40.89520677924156, 43.56824554502964, 39.55666020512581, 39.9893543869257, 41.99924133718014, 42.87254847586155, 41.559487134218216, 41.19495369493961, 42.52173610031605, 41.41374595463276, 41.051021218299866, 40.65570183098316, 38.74790020287037, 39.92780528962612, 40.491584837436676, 42.934637144207954, 39.678835049271584, 42.86311738193035, 42.95924462378025, 44.22065153717995, 42.153000086545944, 43.459362387657166, 41.89388819038868, 43.032953068614006, 43.45497742295265, 40.337487906217575, 42.25324250757694, 46.49696499109268, 44.988977909088135, 45.88528901338577, 43.28544192016125, 43.58703933656216, 47.43731193244457, 49.54581119120121, 50.96978098154068, 51.71217754483223, 51.44209563732147, 53.19530636072159, 41.755704805254936, 36.37334682047367, 44.25147168338299, 49.376473277807236, 42.205870449543, 40.666432455182076, 39.24989126622677, 41.65252134203911, 38.97021487355232, 42.09887959063053, 43.203632310032845, 45.485189482569695, 44.63528148829937, 46.03585213422775, 45.04326559603214, 49.44589555263519, 50.9583055973053, 53.34626466035843, 55.61099253594875, 57.50861071050167, 55.21782763302326, 57.94358856976032, 58.02868880331516, 60.74946440756321, 59.418050050735474, 61.397196650505066, 63.61257277429104, 66.58416911959648, 63.249513655900955, 63.417612835764885, 63.28623868525028, 63.87410134077072, 63.68882708251476, 67.75085091590881, 64.19731959700584, 65.40370166301727, 67.42202416062355, 72.94369027018547, 67.5289960205555, 74.26863357424736, 64.150969684124, 73.91698524355888, 74.67668607831001, 87.84823089838028, 14.273916967213154, 0.19577459403080866, 0.33862960583064705, 21.263049133121967, 70.533487200737, 57.40432150661945, 56.27716898918152, 30.2725537866354, 25.014316141605377, 37.26745404303074, 42.66417145729065, 19.854785799980164, 0.056084159296005964, 0.03894804736773949, 0.06943889893591404, 0.06340993611956947, 0.06967616354813799, 0.046258817965281196, 0.03976771607995033, 0.040785423188935965, 0.0434751964348834, 0.0660899055947084, 0.042854890853050165, 0.041024346501217224, 0.08660100458655506, 0.3938431665301323, 12.374336197972298, 68.12199980020523, 47.11953118443489, 50.12765496969223, 56.74298219382763, 62.52376779913902, 83.37333261966705, 34.77612912654877, 0.32142626645509154, 0.3658891946543008, 0.6451736146118492, 26.428414061665535, 88.83746981620789, 76.58266380429268, 74.7550530731678, 71.77291989326477, 73.07621195912361, 72.90994808077812, 74.13871854543686, 73.14705535769463, 71.65167599916458, 73.50691124796867, 68.41369494795799, 67.77887061238289, 62.714688554406166, 58.75858023762703, 57.25719340145588, 53.13155338168144, 53.2714656740427, 54.34494607150555, 50.098803117871284, 52.82696172595024, 49.170512929558754, 49.941689148545265, 48.70994724333286, 47.73330084979534, 47.007387802004814, 46.90586864948273, 46.246117651462555, 49.27088834345341, 46.57344348728657, 49.58800032734871, 48.71592812240124, 49.70875024795532, 48.58937211334705, 48.74004542827606, 45.40350526571274, 43.62668260931969, 44.980318173766136, 44.62825566530228, 44.460772052407265, 47.60653205215931, 50.716756358742714, 57.138955146074295, 63.11669558286667, 57.059273421764374, 54.63958606123924, 59.56725284457207, 64.7607609629631, 62.330046594142914, 51.880238726735115, 54.52445603907108, 47.799333706498146, 48.62118020653725, 49.30190987884998, 48.72701212763786, 47.011924758553505, 45.318393632769585, 42.88163758814335, 45.3576835244894, 43.85506175458431, 43.43644201755524, 43.34077075123787, 43.85139115154743, 45.12348689138889, 44.04950112104416, 42.868231907486916, 44.273062124848366, 41.935492157936096, 42.4355149269104, 40.3833894431591, 41.71608433127403, 42.95389071106911, 44.32244427502155, 43.52272018790245, 44.757285341620445, 45.39157770574093, 46.58389672636986, 44.9797710031271, 45.64965985715389, 44.09675158560276, 44.33529518544674, 45.33182971179485, 43.22694405913353, 44.49552498757839, 47.89952673017979, 48.40167738497257, 47.04300709068775, 44.413445591926575, 45.8414051681757, 47.23809242248535, 49.6719454228878, 51.88544064760208, 52.78215833008289, 51.90654471516609, 54.01644229888916, 41.31523624062538, 36.369482427835464, 46.91704764962196, 50.845170468091965, 42.96948127448559, 43.869744166731834, 41.65735848248005, 43.80115784704685, 43.09371940791607, 43.970374166965485, 44.821410700678825, 48.93307127058506, 46.87099412083626, 48.20691503584385, 46.79910957813263, 53.719085454940796, 52.84282587468624, 56.87512770295143, 58.06020811200142, 59.794811233878136, 56.833341345191, 59.63961996138096, 60.03121554851532, 63.02545487880707, 62.43460178375244, 64.63029116392136, 66.31945252418518, 68.8193991780281, 65.55839896202087, 66.10183820128441, 65.69247856736183, 67.62383133172989, 64.4249501824379, 69.09331128001213, 66.46302402019501, 70.43259501457214, 68.58301386237144, 77.29054301977158, 68.29865232110023, 76.31891995668411, 67.42225974798203, 77.71797448396683, 76.41117140650749, 92.50151440501213, 15.425211489200592, 0.15458553156349808, 0.3736137645319104, 23.42344220727682, 80.18144309520721, 65.30045360326767, 68.46893638372421, 33.194391801953316, 31.716567501425743, 48.950010761618614, 54.632195457816124, 24.50232971459627, 0.04075628276041243, 0.06886384580866434, 0.0571716913691489, 0.08002594724530354, 0.06696892756735906, 0.05460673994093668, 0.18026796751655638, 0.10941481712507084, 0.2256376962759532, 0.15422189404489473, 0.09117401466937736, 0.1850745314732194, 0.26540320075582713, 0.7953158486634493, 16.472636684775352, 83.74740734696388, 53.20846505463123, 71.67352482676506, 72.83474251627922, 70.05677998065948, 90.5277407169342, 40.74494384229183, 0.6470282119698822, 0.522347817895934, 0.718948437133804, 29.971336349844933, 92.06383109092712, 78.11351045966148, 77.87293776869774, 73.64726811647415, 77.97411873936653, 74.52746048569679, 77.8003616631031, 74.94426012039185, 73.35265472531319, 77.53164768218994, 73.85896235704422, 72.25952178239822, 66.77372574806213, 62.309090718626976, 60.86377367377281, 57.34692558646202, 56.47809460759163, 57.98174612224102, 51.35261043906212, 55.09056866168976, 52.054941952228546, 51.0473196208477, 52.708438485860825, 50.086917355656624, 51.20377242565155, 48.860795348882675, 49.82788145542145, 52.19105824828148, 50.87081529200077, 51.938352808356285, 51.94027170538902, 53.30037832260132, 50.03669925034046, 49.994221329689026, 48.858633264899254, 47.617589458823204, 48.7929879873991, 48.22035491466522, 47.36557558178902, 50.340443551540375, 54.67037960886955, 61.156688556075096, 63.1253857165575, 59.22082923352718, 56.343357637524605, 61.43342770636082, 69.04901325702667, 63.03355984389782, 51.2114480137825, 55.87495297193527, 50.413487032055855, 50.09932368993759, 51.9592896848917, 49.48113866150379, 49.4304683804512, 48.8050789386034, 46.90183326601982, 48.581054359674454, 45.1982706785202, 44.63775895535946, 46.483616307377815, 49.161055237054825, 50.138480588793755, 46.535950899124146, 46.59504912793636, 46.77176624536514, 45.101303681731224, 46.620629355311394, 42.87470296025276, 44.10986848175526, 44.9381860345602, 48.23581628501415, 45.073272585868835, 47.356809452176094, 47.64657810330391, 48.288211673498154, 46.143610551953316, 49.25571195781231, 46.634179428219795, 47.45392844080925, 48.16884487867355, 45.91697931289673, 45.680540800094604, 49.51136223971844, 48.32605764269829, 48.62175777554512, 45.58763578534126, 46.28119736909866, 48.743366450071335, 50.58212198317051, 55.47487623989582, 55.02152256667614, 53.35235193371773, 54.97562102973461, 40.99886901676655, 37.49230697751045, 45.781060606241226, 54.461748003959656, 44.25022155046463, 46.52387894690037, 44.970146119594574, 48.3642303943634, 45.1321542263031, 46.78058557212353, 48.97516541182995, 51.68850101530552, 49.72852438688278, 51.25306338071823, 49.4879174977541, 56.578078642487526, 55.99146232008934, 60.05423091351986, 60.55386230349541, 63.893981873989105, 59.9725466966629, 62.04803712666035, 62.865354269742966, 66.21574088931084, 63.92386347055435, 66.79726928472519, 68.69672656059265, 72.09363788366318, 69.06007066369057, 67.78146967291832, 67.9334083199501, 72.1392810344696, 66.76839843392372, 71.47174045443535, 70.40015995502472, 73.0902636051178, 71.48062437772751, 80.82387462258339, 71.84579998254776, 79.7839692234993, 72.3161007463932, 85.54664120078087, 75.98012253642082, 94.74199578166008, 17.20340207219124, 0.2865003515034914, 0.5158736777957529, 27.375380247831345, 91.16382658481598, 71.60746157169342, 78.08841660618782, 48.26635144650936, 37.656876146793365, 55.60242019593716, 70.32069861888885, 31.368973553180695, 0.21117243653861806, 0.16711112897610292, 0.2590953907929361, 0.19840253895381466, 0.2093042727210559, 0.1577223968342878], [0.04616901067493018, 0.032423307638964616, 0.04629086019122042, 0.05728482807171531, 0.03614307053794619, 0.03592762506741565, 0.0918366560654249, 0.2416992117650807, 6.826581638306379, 51.17383383214474, 47.29043461382389, 38.56620915234089, 29.157991893589497, 56.86350032687187, 75.94739109277725, 39.96549926698208, 0.0675684270390775, 0.3628014447167516, 0.5336336279287934, 20.71501214057207, 83.98710608482361, 72.94476181268692, 69.70625638961792, 69.51530903577805, 70.17200499773026, 74.1327452659607, 70.0645087659359, 68.20968389511108, 67.45876058936119, 67.66295403242111, 62.77987025678158, 62.96838954091072, 57.78754994273186, 53.82097318768501, 52.143196016550064, 52.20392815768719, 48.84221814572811, 50.96560500562191, 49.39875528216362, 47.298558577895164, 45.70886068046093, 45.76896205544472, 44.08780686557293, 44.20623891055584, 46.47341765463352, 45.90713784098625, 46.18247486650944, 47.19516232609749, 45.80781117081642, 47.07317367196083, 46.23441807925701, 45.51008574664593, 45.69157160818577, 44.95324842631817, 43.35490219295025, 42.13018611073494, 40.706349313259125, 41.40951298177242, 43.197852820158005, 44.61627870798111, 40.32894216477871, 51.36548034846783, 58.843615874648094, 56.56577110290527, 54.125694036483765, 48.50483424961567, 50.71104906499386, 53.9053438603878, 52.38177761435509, 49.91059921681881, 48.20240467786789, 47.38437317311764, 45.34148119390011, 44.38407316803932, 43.15390057861805, 43.02559666335583, 44.42394442856312, 41.17655508220196, 43.795294761657715, 40.985470935702324, 40.21733835339546, 42.64275200664997, 41.569955572485924, 42.875424921512604, 39.68134291470051, 40.504120364785194, 38.223737329244614, 42.582445442676544, 37.60175630450249, 39.35577638447285, 40.8121432363987, 41.16961285471916, 38.57031673192978, 40.198878943920135, 42.0688384026289, 44.23257149755955, 42.752516716718674, 42.36529849469662, 42.732392996549606, 44.83738884329796, 45.38190722465515, 45.41146583855152, 46.7735331505537, 47.77214236557484, 48.267700374126434, 49.55364637076855, 46.66672848165035, 47.40444749593735, 45.461402758955956, 48.596112951636314, 44.270592257380486, 47.9824610799551, 56.004294231534004, 55.73932684957981, 45.28053626418114, 47.59501866996288, 54.134741351008415, 47.46247038245201, 44.24763008952141, 40.47920510172844, 40.60749761760235, 41.474223509430885, 39.60066944360733, 39.855415374040604, 43.94335001707077, 44.16193708777428, 44.061915054917336, 45.84817260503769, 44.43228878080845, 47.90583819150925, 47.68057867884636, 52.65647627413273, 48.94369550049305, 49.56793360412121, 48.778335973620415, 52.7272816747427, 52.489779219031334, 57.4329187721014, 56.704794242978096, 60.74589639902115, 58.211804777383804, 60.06449036300182, 61.78873524069786, 66.09944432973862, 63.168794587254524, 64.74372267723083, 63.00324887037277, 66.40731140971184, 65.73857769370079, 70.45624494552612, 65.8253726363182, 68.59278693795204, 69.94027823209763, 71.31236180663109, 69.93371978402138, 75.66471666097641, 75.98796531558037, 96.91055461764336, 13.949991948902607, 0.19111129426164553, 0.4639271105406806, 16.1068607121706, 74.08634215593338, 53.74743573367596, 58.6501644551754, 32.331712692976, 41.760557144880295, 38.39484974741936, 42.58462272584438, 22.04257160425186, 0.04427712039614562, 0.09357138173072599, 0.040470986350555904, 0.11088645886047743, 0.030505924587487243, 0.1385078817838803, 0.0481818821572233, 0.04551880767394323, 0.030536541889887303, 0.05244594729447272, 0.010242076732538408, 0.02668993667612085, 0.05959151952993125, 0.47183507995214313, 10.100255124270916, 63.01696993410587, 50.84367334842682, 41.730903536081314, 35.602208599448204, 64.6199481189251, 80.75384438037872, 43.773943707346916, 0.11939386837184429, 0.4011407046345994, 0.5017089878674597, 21.086269319057465, 85.82770451903343, 74.24100145697594, 73.12071517109871, 72.69312411546707, 71.93543717265129, 74.40643697977066, 70.75681641697884, 68.76460611820221, 70.2794024348259, 70.48227354884148, 65.87898775935173, 65.29428273439407, 60.032309889793396, 57.85870112478733, 54.35633026063442, 54.97962221503258, 51.07670344412327, 52.46416099369526, 52.15271070599556, 49.30181108415127, 48.386896178126335, 47.97769233584404, 47.387800589203835, 47.01398424804211, 48.39940510690212, 48.873855248093605, 47.70411841571331, 48.499256148934364, 49.141254499554634, 48.61826576292515, 50.04620634019375, 47.93492563068867, 47.9163484275341, 46.866077184677124, 44.96046423912048, 43.38724225759506, 43.63392882049084, 45.34043624997139, 45.222292989492416, 46.46896429359913, 43.772879764437675, 53.421679213643074, 61.84820204973221, 59.57630775868893, 54.28454451262951, 50.34459672868252, 49.876389652490616, 54.28611382842064, 53.83951239287853, 51.706747636199, 51.34002551436424, 49.52029936015606, 47.271093651652336, 45.89218184351921, 46.660462617874146, 47.24011771380901, 48.41643199324608, 45.82414649426937, 47.191780507564545, 41.74205593764782, 43.368129283189774, 44.33550417423248, 44.46881242096424, 44.16833974421024, 42.42723137140274, 43.01177680492401, 42.39254303276539, 45.440503880381584, 41.0201782733202, 42.21418060362339, 42.923651933670044, 42.20694579184055, 41.82486489415169, 42.8396612405777, 44.000267162919044, 46.20024271309376, 45.80673202872276, 44.37466487288475, 44.652711153030396, 47.16056898236275, 47.07553714513779, 48.84988233447075, 49.455357044935226, 50.00429458916187, 49.2646224796772, 52.076422199606895, 46.63336247205734, 50.27127206325531, 46.699900701642036, 47.76605889201164, 45.13224922120571, 49.22812923789024, 56.254947781562805, 58.50495524704456, 47.77422845363617, 51.01375222206116, 54.736461862921715, 49.67003412544727, 46.424594074487686, 42.95108646154404, 43.338665664196014, 42.95546382665634, 42.56467379629612, 42.608994618058205, 45.09389407932758, 47.32205651700497, 46.376948431134224, 47.59577102959156, 48.822721391916275, 49.77042853832245, 50.80596037209034, 52.69653372466564, 51.93146377801895, 51.26196250319481, 50.526344776153564, 56.440548822283745, 53.86779427528381, 59.52864691615105, 57.84980580210686, 64.69260782003403, 59.773870557546616, 64.09236922860146, 62.566507905721664, 68.41674998402596, 65.88832005858421, 67.38411739468575, 65.78581675887108, 69.86945003271103, 68.05586814880371, 74.57455515861511, 68.30249771475792, 73.00388664007187, 72.35412150621414, 75.19117847084999, 70.54422542452812, 79.51524004340172, 75.89488551020622, 97.41391360759735, 15.045029539614916, 0.26446907431818545, 0.5017284024506807, 16.691805124282837, 85.18934637308121, 60.37421174347401, 71.04294866323471, 37.68310233950615, 47.10656628012657, 50.51456540822983, 54.360183253884315, 27.94176835566759, 0.17076939751859754, 0.04457567156350706, 0.034052529590553604, 0.04652407638786826, 0.06198165436217096, 0.03384231997188181, 0.19829941011266783, 0.10071575539768673, 0.17523681482998654, 0.1288214890519157, 0.0945265703194309, 0.19389311608392745, 0.35050358274020255, 0.6726480403449386, 17.09291160106659, 76.93815752863884, 59.366908594965935, 54.21177461743355, 43.471179753541946, 73.305674046278, 85.5673348903656, 49.024855345487595, 0.2290148541214876, 0.6471864378545433, 0.7749323768075556, 25.314572229981422, 89.75601732730865, 77.7537153661251, 75.55213630199432, 75.14431178569794, 75.01561269164085, 78.77648368477821, 73.38329628109932, 70.73358446359634, 73.15983787178993, 76.6428829729557, 67.71110504865646, 68.28388631343842, 62.65262648463249, 59.85970035195351, 59.407323226332664, 58.685635551810265, 54.422739297151566, 56.20048530399799, 55.50104163587093, 52.59323246777058, 51.06366254389286, 48.868615329265594, 49.841218739748, 50.821547135710716, 52.30121813714504, 53.16881038248539, 49.771256893873215, 50.62260501086712, 53.16638231277466, 52.535965740680695, 52.74236686527729, 52.19548501074314, 50.327744632959366, 49.771815463900566, 46.692054122686386, 47.302924543619156, 46.50899514555931, 46.857451647520065, 48.15891221165657, 48.32505829632282, 46.610407903790474, 56.47921934723854, 64.30519580841064, 61.36500097811222, 56.958594024181366, 51.15966059267521, 53.884490579366684, 55.51129348576069, 57.022350803017616, 53.01478944718838, 53.35452161729336, 53.23886722326279, 52.418624237179756, 48.276002928614616, 49.530748799443245, 46.291608810424805, 50.52242338657379, 46.72604709863663, 50.91265484690666, 44.96646411716938, 45.35576082766056, 48.06656576693058, 46.2520757317543, 45.897322967648506, 46.65455013513565, 44.507361352443695, 43.99726912379265, 46.54472842812538, 44.25773374736309, 42.38126903772354, 44.51699383556843, 44.539758414030075, 45.0084974616766, 44.896570667624474, 45.587612986564636, 48.39559771120548, 49.01084169745445, 45.51041252911091, 48.33424620330334, 49.53790381550789, 51.92784637212753, 51.60492070019245, 49.557829946279526, 50.27333915233612, 51.206804662942886, 53.10203276574612, 50.540973991155624, 50.57320386171341, 47.21526324748993, 50.3062491863966, 45.36832295358181, 51.157118529081345, 56.920888647437096, 63.344991132617, 49.167005717754364, 49.6119200438261, 57.524170875549316, 51.920782551169395, 50.87213382124901, 45.161640644073486, 46.66020803153515, 47.6644067466259, 46.2238622456789, 43.375041112303734, 47.13284946978092, 50.423537492752075, 48.195728436112404, 50.42721189558506, 50.54183654487133, 52.519638016819954, 53.6410566419363, 57.90474325418472, 54.22741457819939, 53.82802560925484, 53.461390882730484, 58.9401762932539, 58.68335947394371, 63.11506547033787, 61.73570528626442, 66.19000107049942, 62.49262847006321, 66.935855448246, 66.58749014139175, 71.39573693275452, 68.39340403676033, 70.33766850829124, 70.41121736168861, 73.8189049065113, 70.86131080985069, 77.4808520078659, 71.3091091811657, 74.97417971491814, 75.27039662003517, 78.58745902776718, 73.63954693078995, 84.68431547284126, 81.70388460159302, 97.15582385659218, 17.98896811902523, 0.28983746306039393, 0.4938097164267674, 21.108310036361217, 94.816183000803, 67.18177065253258, 80.80564320087433, 52.301829904317856, 62.70795911550522, 61.33519537746906, 69.05420377850533, 33.63194592297077, 0.35413381294347346, 0.1992253729258664, 0.14843802549876273, 0.2039669841178693, 0.28057044313754886, 0.34877669415436685], [0.1190315221901983, 0.07230755203636363, 0.056003369099926203, 0.08288500437629409, 0.03782684034376871, 0.040150760760298, 0.07068818580592051, 0.21660476457327604, 5.552659621462226, 51.104373559355736, 47.91920967400074, 40.04776105284691, 36.86861604452133, 58.21895979344845, 76.0753758251667, 46.819514483213425, 0.031390386502607726, 0.42376216733828187, 0.6580659071914852, 12.699494250118732, 79.11666423082352, 72.65107557177544, 70.78511729836464, 69.36500430107117, 71.94911643862724, 72.03984037041664, 66.0708774626255, 69.10601779818535, 66.07295215129852, 64.87340211868286, 63.103753477334976, 60.550963059067726, 57.584333047270775, 56.93916566669941, 52.8030876070261, 50.98361223936081, 49.78272087872028, 48.76093290746212, 49.41824443638325, 46.33899226784706, 45.05615450441837, 45.0621771812439, 43.519053384661674, 45.664874240756035, 45.86454972624779, 44.53508086502552, 47.69004017114639, 48.48372258245945, 50.70685029029846, 50.21522507071495, 48.083170875906944, 46.43030896782875, 46.42188861966133, 46.100501865148544, 41.956106051802635, 40.683603733778, 40.37385955452919, 39.82339449226856, 42.829394191503525, 42.300846353173256, 43.48860181868076, 44.523818269371986, 50.867304280400276, 57.278954833745956, 57.2281439602375, 54.09351356327534, 47.842491790652275, 48.570517525076866, 48.44586901366711, 51.467033699154854, 47.30190619826317, 47.35180512070656, 45.28595857322216, 45.644138753414154, 44.74261432886124, 47.199832275509834, 46.06340825557709, 48.6338297277689, 45.811303183436394, 41.63967803120613, 41.732191666960716, 41.505024656653404, 40.77619716525078, 42.39047214388847, 41.158399656414986, 37.81872846186161, 41.79646521806717, 44.705319330096245, 37.270376086235046, 39.60971675813198, 44.008250534534454, 42.52390958368778, 40.612201765179634, 41.88736014068127, 41.365670934319496, 41.533933505415916, 42.39245943725109, 44.682775139808655, 40.474056378006935, 44.596998542547226, 43.32453042268753, 45.0953684002161, 45.4224244505167, 44.436426758766174, 44.81284216046333, 47.84565322101116, 44.261373952031136, 45.19008591771126, 44.69242662191391, 45.83092913031578, 47.36189737915993, 48.92253443598747, 47.44782216846943, 50.741736218333244, 53.265139013528824, 55.97032405436039, 50.415896102786064, 43.15979406237602, 39.91240851581097, 40.34148529171944, 38.13610263168812, 38.966487273573875, 40.07003165781498, 40.531562492251396, 43.83168160915375, 44.527108892798424, 45.019102692604065, 46.49133749306202, 45.319586768746376, 49.52174708247185, 47.203871458768845, 49.97667007148266, 49.927462711930275, 51.14758484065533, 48.79949703812599, 49.11038875579834, 48.26748378574848, 49.32492524385452, 49.06534977257252, 56.22228853404522, 57.9499988257885, 58.52617330849171, 57.44944408535957, 62.050890773534775, 63.454056680202484, 65.6983682513237, 62.47517980635166, 63.20724092423916, 63.48007768392563, 66.20212242007256, 66.20570942759514, 70.41118696331978, 66.67241558432579, 72.88239195942879, 68.29805195331573, 81.9913923740387, 66.66446641087532, 109.31834042072296, 15.081478133797646, 0.21610537340166047, 0.2623703103745356, 6.805042969062924, 70.57976871728897, 57.011141404509544, 55.103206783533096, 36.62517070770264, 30.533563680946827, 34.82019916176796, 53.7834046036005, 31.696263290941715, 0.06287308875471354, 0.1490666245808825, 0.04688914996222593, 0.02565882823546417, 0.033508787673781626, 0.03145901660900563, 0.0881490355823189, 0.005590619784925366, 0.04335031524533406, 0.06630919539020397, 0.07175839244155213, 0.050772092581610195, 0.13117362221237272, 0.3042304376140237, 10.843882821500301, 64.40296456217766, 48.78555938601494, 41.04542791843414, 47.939983159303665, 65.82069128751755, 80.7901856303215, 49.94851738214493, 0.03394532635866199, 0.34979880962055176, 0.4472476086812094, 12.996897641569376, 82.99171909689903, 74.85880270600319, 73.50561931729317, 70.68339675664902, 75.87825760245323, 73.81004378199577, 69.19681012630463, 71.46740108728409, 70.8428817987442, 67.81589582562447, 65.39708241820335, 63.57280790805817, 60.36512263119221, 58.678921312093735, 54.66494970023632, 53.56460854411125, 50.92622771859169, 51.440803706645966, 51.91404551267624, 48.432045355439186, 48.8998344540596, 48.34979496896267, 48.061451241374016, 47.62311436235905, 48.08863878250122, 47.856383845210075, 48.25264558196068, 51.35797955095768, 52.71531991660595, 52.60788448154926, 50.90724013745785, 49.65741120278835, 47.99045965075493, 48.48310321569443, 45.18331088125706, 44.51195530593395, 41.72705814242363, 43.098457753658295, 45.07500909268856, 44.6152413636446, 44.96661230921745, 45.98745033144951, 53.020960316061974, 59.61277820169926, 58.12706932425499, 54.47439752519131, 49.710425958037376, 50.4552847892046, 52.542079612612724, 52.368767112493515, 48.11450019478798, 47.65694014728069, 49.286174923181534, 47.57264167070389, 48.24523977935314, 49.23584662377834, 48.94992336630821, 50.28396338224411, 48.89578007161617, 44.360537230968475, 44.0666875988245, 42.412571758031845, 44.14432883262634, 43.93716014921665, 41.55690707266331, 40.66624626517296, 44.23340365290642, 46.7688973993063, 41.39078378677368, 41.6696622222662, 47.453890442848206, 44.03731897473335, 43.08882527053356, 43.17413069307804, 43.45024287700653, 44.48640547692776, 45.14533191919327, 47.606235668063164, 43.59721139073372, 46.66964292526245, 47.039416283369064, 46.893827095627785, 47.40396112203598, 46.6504767537117, 46.63733705878258, 49.44148398935795, 48.40404085814953, 48.11284728348255, 47.76849456131458, 46.952146366238594, 47.89727725088596, 49.00954216718674, 49.16845723986626, 49.813997000455856, 55.091765597462654, 58.65366406738758, 51.37382850050926, 44.95697222650051, 42.27726861834526, 42.38964758813381, 40.755742862820625, 41.93507798016071, 42.42380015552044, 43.21857690811157, 45.96139132976532, 46.14341676235199, 48.40959995985031, 47.8844453394413, 48.33818279206753, 52.35091187059879, 50.88360920548439, 53.02366957068443, 53.17168302834034, 54.211333841085434, 50.6499407440424, 49.383016526699066, 50.16439899802208, 52.19020329415798, 49.68844793736935, 59.11629304289818, 58.78121182322502, 61.70779958367348, 60.418285578489304, 64.66114550828934, 66.37581869959831, 68.76686319708824, 65.18671050667763, 66.09288588166237, 65.95920145511627, 70.66765040159225, 68.1651046872139, 74.71831664443016, 68.5008242726326, 76.55184745788574, 71.79264843463898, 84.23591673374176, 67.38160952925682, 104.24094647169113, 16.409197188913822, 0.10600983616313897, 0.3705538302892819, 6.527684926986694, 79.17759016156197, 62.727695256471634, 66.37048378586769, 43.34057696163654, 39.29517723619938, 44.977487325668335, 63.76710668206215, 37.02479146420956, 0.15965766564477235, 0.13689290906768292, 0.04944314729073085, 0.027693481752066873, 0.04627539754437748, 0.04504788157646544, 0.29164868930820376, 0.2353742581908591, 0.20192558818962425, 0.2311512449523434, 0.17525882693007588, 0.22610450716456398, 0.38425755745265633, 0.4924164083786309, 16.92855142056942, 76.06416642665863, 59.59561072289944, 53.32666911184788, 51.15294635295868, 76.65495872497559, 87.10781782865524, 57.93014869093895, 0.07145169249270111, 0.8144820202142, 0.6588391656987369, 16.00390713661909, 85.47225639224052, 77.87828788161278, 76.66447341442108, 74.70603570342064, 78.56769248843193, 75.40310829877853, 71.81812986731529, 74.167141020298, 73.32490101456642, 71.0854759812355, 67.56982862949371, 66.4589050412178, 63.038203194737434, 62.54276677966118, 58.99110496044159, 57.074085026979446, 56.00574195384979, 53.025333881378174, 55.35179704427719, 52.73587681353092, 51.44406393170357, 50.99758788943291, 49.892888367176056, 49.11317020654678, 52.32062369585037, 50.48711188137531, 53.22399482131004, 55.26993803679943, 56.55671998858452, 57.49043248593807, 54.725776836276054, 52.25071884691715, 51.78121604025364, 51.319259628653526, 46.62701681256294, 45.78849300742149, 45.31968176364899, 45.95555104315281, 46.96716696023941, 47.989950478076935, 49.27659943699837, 51.17226831614971, 57.29704186320305, 62.32079789042473, 61.96333207190037, 57.41201989352703, 50.810261741280556, 52.49126873910427, 53.945006132125854, 55.66507503390312, 51.893127635121346, 50.46834468841553, 51.118178218603134, 50.051674246788025, 50.51558755338192, 54.50147867202759, 49.956686943769455, 50.17629235982895, 50.671189203858376, 48.13726857304573, 47.26313307881355, 44.800812005996704, 45.18717907369137, 47.29242190718651, 47.604727149009705, 43.24791893362999, 46.02729119360447, 49.08993445336819, 43.54787863790989, 43.95107880234718, 49.38160300254822, 45.46732284128666, 45.24196073412895, 46.60687029361725, 45.598081424832344, 47.4844978004694, 46.865435019135475, 50.84072470664978, 46.1332219094038, 51.0374553501606, 47.298892959952354, 47.26551555097103, 51.09230160713196, 47.972851395606995, 49.07729633152485, 53.41056860983372, 49.22983534634113, 50.45287571847439, 49.624801352620125, 48.76539766788483, 50.45495040714741, 51.36923834681511, 51.29609227180481, 51.86451897025108, 56.48049607872963, 61.69671557843685, 55.26613064110279, 46.71843610703945, 44.956007078289986, 44.07718263566494, 41.91179662942886, 43.87106269598007, 45.332509875297546, 47.08155982196331, 49.861665442585945, 49.02446776628494, 51.21331371366978, 50.833318904042244, 50.86488001048565, 55.183230489492416, 52.978265807032585, 55.04240624606609, 54.96641032397747, 56.22203014791012, 54.103279039263725, 53.97506631910801, 53.975054919719696, 54.66774255037308, 51.13667942583561, 62.54023231565952, 63.061313554644585, 65.10189145803452, 62.62419641017914, 68.71036022901535, 69.07726854085922, 71.55586034059525, 67.64758765697479, 67.78386354446411, 67.997115701437, 73.30000475049019, 70.62006935477257, 76.4233535528183, 71.76031976938248, 78.66046831011772, 77.3944142460823, 87.08378031849861, 71.5693648159504, 108.67384180426598, 17.53748394548893, 0.17023807915393263, 0.47806392540223897, 8.682914078235626, 89.15928974747658, 70.72485253214836, 76.95774927735329, 52.98705093562603, 49.950702264904976, 57.14520201086998, 74.1251988708973, 44.532238617539406, 0.2958737360313535, 0.20305240585003048, 0.17195929773151875, 0.17255865619517863, 0.10760609191493131, 0.2083026256877929], [0.012087432496628026, 0.07462296372978017, 0.10194755726843141, 0.10065846159704961, 0.0670333905145526, 0.03448602175922133, 0.014973845190979773, 0.23195913207018748, 8.753012716770172, 58.66048090159893, 42.45794132351875, 50.25935970246792, 29.240065589547157, 59.165204018354416, 72.83825352787971, 49.076057597994804, 0.014844317229290027, 0.3555360564496368, 0.22954682557610795, 7.891238434240222, 71.93310409784317, 76.07516303658485, 70.34450054168701, 68.72818887233734, 70.95986992120743, 70.4593075811863, 64.77277591824532, 68.31280276179314, 64.07150074839592, 65.77513933181763, 62.17059575021267, 63.49524646997452, 59.939841851592064, 57.5431964546442, 52.76997998356819, 52.863333374261856, 48.5268160700798, 48.40442083775997, 47.17772886157036, 47.68953859806061, 43.44823658466339, 44.22342158854008, 44.82443533837795, 45.73650799691677, 43.616065979003906, 48.14243249595165, 49.46348860859871, 51.63336217403412, 53.9874916523695, 52.490748167037964, 50.91703221201897, 45.5917813628912, 46.996018812060356, 43.843992948532104, 43.55544023215771, 41.17791920900345, 39.405329525470734, 40.37151888012886, 41.37026868760586, 42.57943220436573, 41.94627597928047, 40.838776007294655, 43.91690343618393, 46.56490534543991, 51.16276502609253, 49.61817070841789, 48.548288717865944, 50.08224740624428, 49.44536738097668, 51.36514976620674, 51.07266426086426, 50.19126735627651, 50.48578195273876, 49.347822815179825, 49.56494316458702, 51.49807043373585, 50.65795451402664, 51.23479776084423, 55.259386003017426, 50.39068825542927, 45.63995897769928, 44.07778300344944, 42.80969224870205, 43.94044317305088, 42.76684194803238, 46.322873532772064, 51.44072771072388, 47.94004775583744, 40.04729747772217, 41.610826179385185, 50.80866202712059, 47.09264762699604, 38.36681105196476, 39.44648891687393, 41.86309464275837, 44.10738341510296, 42.481834441423416, 41.25500567257404, 40.6282939016819, 44.52028065919876, 46.825217977166176, 44.516648054122925, 41.556595489382744, 42.808343321084976, 41.07975147664547, 41.55563794076443, 41.16133689880371, 41.69195182621479, 43.88819977641106, 48.60318437218666, 48.651088401675224, 48.296711817383766, 44.22842592000961, 48.78526300191879, 50.943330600857735, 51.45523153245449, 44.79063615202904, 42.16452106833458, 41.67617127299309, 40.12969225645065, 39.73763309419155, 39.318188801407814, 39.49395976960659, 40.398904010653496, 43.63633029162884, 44.13311943411827, 43.95664170384407, 43.62773135304451, 44.73628766834736, 47.1556406468153, 47.32585251331329, 51.454342380166054, 48.01808796823025, 50.23115761578083, 47.359750494360924, 50.6499407440424, 48.7216430157423, 48.14160034060478, 46.01564101874828, 47.801074013113976, 47.91811153292656, 49.786178693175316, 54.897238835692406, 57.79152072966099, 60.940103977918625, 64.01345506310463, 64.5534136891365, 63.319813683629036, 60.29907077550888, 65.33712163567543, 64.55292731523514, 69.33866411447525, 66.64865925908089, 77.28796675801277, 69.11694601178169, 78.88780251145363, 65.79348474740982, 101.67696565389633, 12.44518244639039, 0.3216849791351706, 0.21700660785427317, 4.9204818438738585, 69.8052866756916, 56.37416258454323, 58.50383050739765, 34.772226735949516, 39.977046847343445, 43.08642379939556, 46.065490543842316, 31.497533954679966, 0.10072800825582817, 0.027396975201554596, 0.05256564458250068, 0.017955515322682913, 0.0221925644291332, 0.1121668417181354, 0.07328879742999561, 0.06393882766133174, 0.055288317234953865, 0.058309054948040284, 0.05061844574811403, 0.11688533501001075, 0.16640680114505813, 0.3069976984988898, 12.651710864156485, 67.95249849557877, 51.099126040935516, 55.01067794859409, 36.528484895825386, 66.79541498422623, 78.55183213949203, 56.96827970445156, 0.0681573137990199, 0.44945914938580245, 0.11902790050953627, 8.283017836511135, 77.99823224544525, 75.40521338582039, 72.44340151548386, 72.02667787671089, 73.53107035160065, 71.32921010255814, 68.13940286636353, 71.50753453373909, 68.3978421986103, 68.28837007284164, 64.28111270070076, 64.68276634812355, 62.63054206967354, 61.153762713074684, 55.992195680737495, 53.97695481777191, 50.25823496282101, 50.327110067009926, 50.55856704711914, 49.73430007696152, 46.71630062162876, 45.54545044898987, 48.20878453552723, 47.868782579898834, 47.664847522974014, 50.92049762606621, 52.056879848241806, 54.09384034574032, 55.31538359820843, 54.81029190123081, 53.42762589454651, 47.62513965368271, 49.30268503725529, 46.85298688709736, 45.447449907660484, 44.78706054389477, 42.279252111911774, 42.280718833208084, 44.797297194600105, 47.17674471437931, 44.86964911222458, 44.10079076886177, 46.37265846133232, 49.549405798316, 54.134251177310944, 52.411575615406036, 50.02326317131519, 53.51678431034088, 53.31580549478531, 51.21220797300339, 55.02057641744614, 52.06498101353645, 52.80795894563198, 53.187140598893166, 51.451401337981224, 52.598289996385574, 54.77365806698799, 53.7754288315773, 58.61111395061016, 53.64236377179623, 46.81385658681393, 44.58216793835163, 44.48333144187927, 45.36746419966221, 44.84561540186405, 47.867684438824654, 51.54434435069561, 49.670129120349884, 41.81180499494076, 43.80116164684296, 51.416124030947685, 48.82658578455448, 41.49930216372013, 41.4586291462183, 45.08724823594093, 46.33348636329174, 43.12729440629482, 43.0171725153923, 42.799356803298, 45.573435947299004, 47.01679989695549, 46.259751319885254, 44.89671505987644, 45.79884745180607, 43.58846426010132, 44.01699386537075, 45.07095091044903, 43.808491453528404, 46.16081602871418, 48.99333603680134, 49.95565339922905, 48.044713139534, 45.51440991461277, 50.583189725875854, 53.61399069428444, 53.848639503121376, 48.116297498345375, 43.11727054417133, 43.39416168630123, 43.20862904191017, 42.74116672575474, 40.79564072191715, 43.39900642633438, 43.42465125024319, 45.55452436208725, 45.971411392092705, 46.513140723109245, 47.40686036646366, 45.53782045841217, 49.3858777731657, 48.657289668917656, 52.67482928931713, 51.35340839624405, 52.153599858284, 49.474006444215775, 52.63058066368103, 52.06937737762928, 49.2175430059433, 49.17118549346924, 49.07921902835369, 49.439998269081116, 52.07373194396496, 56.029745265841484, 60.072587728500366, 61.7452921718359, 66.93751975893974, 66.40171810984612, 65.62184795737267, 61.598772034049034, 67.2881193459034, 66.52503669261932, 72.66366809606552, 68.88798549771309, 77.43555083870888, 71.05107262730598, 80.87786972522736, 68.2138940691948, 95.57621821761131, 12.93155824765563, 0.31394051969982684, 0.3724718070589006, 5.23968561552465, 78.11885297298431, 65.75034946203232, 68.01050618290901, 43.389328345656395, 40.66367760300636, 47.53604203462601, 55.85802488029003, 37.98503413796425, 0.39871848304755986, 0.04115239666134585, 0.009287723987654317, 0.11246778260101564, 0.04460649666725658, 0.07499295403249562, 0.10835153472726233, 0.20975637424271554, 0.1840541823185049, 0.2452010801061988, 0.1640649393084459, 0.3875212260754779, 0.32687443192116916, 0.38125393737573177, 19.527591057121754, 80.68183824419975, 56.26367971301079, 62.90785498917103, 39.626648649573326, 74.38146471977234, 84.04209673404694, 64.53974202275276, 0.23250409110914916, 0.7716940005775541, 0.4429211252136156, 11.36367877945304, 82.00637876987457, 79.68919470906258, 77.60968029499054, 73.681101500988, 77.41615667939186, 73.75160291790962, 72.06983596086502, 72.82152682542801, 72.43996649980545, 72.4991749227047, 69.21296685934067, 68.82473409175873, 65.19630879163742, 61.92493513226509, 59.61417652666569, 56.92677453160286, 54.35903191566467, 53.06436538696289, 52.353271543979645, 53.291224613785744, 49.4511354714632, 48.56982596218586, 51.42038740217686, 51.911796033382416, 49.53226111829281, 54.4062215834856, 54.925801903009415, 56.39529325067997, 59.230769500136375, 57.57625088095665, 55.35862147808075, 51.648656353354454, 53.402634635567665, 48.79289299249649, 49.75061260163784, 47.47722499072552, 43.63485597074032, 45.23352898657322, 48.260138779878616, 49.600277468562126, 48.78085143864155, 48.704228550195694, 49.152361303567886, 52.95168623328209, 58.85173603892326, 55.87273769080639, 54.48415160179138, 55.618204548954964, 54.15008872747421, 54.436897337436676, 58.03157664835453, 55.692011788487434, 55.50308212637901, 55.584789142012596, 53.498856872320175, 55.75331009924412, 57.15414673089981, 54.79760058224201, 58.38136687874794, 54.382830038666725, 47.637116611003876, 48.668977841734886, 46.192650720477104, 47.048668786883354, 46.106478944420815, 50.567120388150215, 53.45096804201603, 53.822656497359276, 45.67390635609627, 46.31753481924534, 53.295563980937004, 52.92045570909977, 42.02806279063225, 43.895582780241966, 47.056754752993584, 49.34851057827473, 45.89621342718601, 44.50630120933056, 45.15532158315182, 46.69603630900383, 48.8993176817894, 48.528267592191696, 46.117068976163864, 47.76586890220642, 42.94520817697048, 46.96118228137493, 46.7392285913229, 44.86081838607788, 48.47375191748142, 52.06207416951656, 52.959194630384445, 50.388377979397774, 46.18847854435444, 53.52128326892853, 56.76855482161045, 57.544328793883324, 51.99201352894306, 45.657217651605606, 45.38241259753704, 44.96495179831982, 47.30624556541443, 44.55828621983528, 45.344901010394096, 45.18865719437599, 48.5668583214283, 47.90710352361202, 49.240486174821854, 48.77983309328556, 49.563506841659546, 52.7235122770071, 52.94892758131027, 55.79811729490757, 54.05482403934002, 55.41206941008568, 52.13625378906727, 55.43370544910431, 54.52225595712662, 51.09125666320324, 51.260089203715324, 53.105855360627174, 54.56748493015766, 54.40659396350384, 59.520644545555115, 64.23080340027809, 66.15176752209663, 69.70431849360466, 68.987205773592, 67.93315753340721, 63.0025877058506, 67.82993987202644, 69.33420315384865, 75.62039583921432, 71.84252455830574, 81.97971180081367, 75.49596771597862, 82.62535035610199, 70.75261384248734, 105.89223146438599, 14.728374481201172, 0.34788035787642, 0.5101996916346252, 7.734771855175495, 88.17844077944756, 73.03591132164001, 79.57659155130386, 51.64436638355255, 58.79402853548527, 65.1736544072628, 67.6986189186573, 44.8676086217165, 0.768998876446858, 0.17458151327446103, 0.1431166336988099, 0.29228470986709, 0.21017404011217877, 0.17152478510979563], [0.01773082825820893, 0.09753891063155606, 0.02444353358441731, 0.05524018524738494, 0.027381230538594536, 0.1092699721630197, 0.025247335179301444, 0.20632214524084702, 5.836885320022702, 58.447468131780624, 44.27091903984547, 39.883020892739296, 40.10765723884106, 55.3041286021471, 71.27408266067505, 55.02704747021198, 0.385849226731807, 0.14838196366326883, 0.10158294011489488, 1.756982496008277, 62.12393045425415, 74.27098944783211, 67.84650698304176, 72.00454026460648, 69.27193969488144, 69.92821767926216, 65.54544165730476, 66.39795631170273, 67.9088768362999, 64.9442607164383, 62.75140978395939, 59.67499606311321, 61.35819174349308, 59.81442578136921, 56.31588511168957, 50.0350159406662, 48.37274573743343, 46.28589391708374, 46.5780184417963, 44.99843180179596, 45.40503278374672, 46.960961893200874, 47.04102359712124, 46.68818213045597, 47.83853240311146, 48.84824462234974, 51.69164724647999, 53.71142886579037, 54.46793407201767, 52.74059236049652, 50.40874108672142, 48.49282309412956, 45.51138527691364, 45.9407090395689, 42.50426843762398, 43.10265652835369, 40.70429742336273, 41.55385583639145, 43.25349323451519, 44.049360528588295, 40.718311071395874, 41.09068349003792, 43.850099220871925, 44.55023445188999, 46.482210382819176, 47.80548557639122, 47.24612899124622, 48.87302689254284, 49.9508086591959, 50.598111525177956, 49.50296089053154, 52.274714559316635, 53.00885036587715, 51.76575846970081, 52.27672465145588, 53.819852247834206, 52.34450161457062, 52.36701540648937, 56.031272783875465, 54.81523163616657, 56.92661873996258, 49.14228804409504, 43.52454029023647, 45.7009457051754, 46.59412197768688, 46.06802120804787, 52.932535260915756, 51.09487786889076, 36.60946235060692, 39.65760558843613, 50.29146797955036, 59.83662039041519, 44.575320705771446, 42.63859122991562, 41.95576027035713, 41.61333404481411, 42.52130292356014, 45.73115788400173, 50.47117553651333, 51.405507400631905, 48.87166276574135, 47.68178701400757, 48.10415334999561, 45.97573556005955, 45.649010092020035, 46.4651682972908, 43.9968017488718, 46.26616157591343, 47.98879534006119, 45.706994980573654, 43.898702412843704, 44.61619131267071, 47.78236001729965, 49.44977134466171, 46.514778435230255, 46.342244893312454, 40.17849683761597, 39.43533651530743, 39.304794520139694, 41.46396405994892, 39.19674351811409, 39.64845187962055, 38.13638001680374, 42.525729686021805, 42.37329326570034, 43.856889456510544, 44.24339331686497, 43.85191552340984, 43.993457928299904, 46.04500964283943, 47.472102865576744, 48.03868666291237, 46.51345610618591, 48.31468865275383, 47.87544742226601, 49.667856842279434, 46.49309299886227, 46.20320275425911, 45.33560290932655, 48.1865519285202, 46.09877295792103, 48.6939463019371, 51.19616523385048, 51.88474528491497, 59.73652996122837, 64.39152717590332, 64.80019524693489, 68.06304216384888, 61.60939246416092, 65.86960226297379, 65.54544925689697, 68.21998134255409, 65.66237658262253, 71.47912725806236, 65.43786182999611, 77.81097069382668, 67.88125991821289, 83.53314444422722, 6.825194712728262, 0.12446779102901928, 0.14032541628694162, 3.545869505032897, 63.62945146858692, 58.64458255469799, 59.32905122637749, 35.18418923020363, 28.20777878165245, 31.922562047839165, 56.21048256754875, 39.482678174972534, 0.2876391028985381, 0.046600588102592155, 0.017339788792014588, 0.053338472644099966, 0.0728764156519901, 0.07057465947582386, 0.10666534552001394, 0.01118741238315124, 0.007590125651404378, 0.09690990336821415, 0.05533722847758327, 0.035399854168645106, 0.08773704714258201, 0.23357757803751156, 13.117026295512915, 69.86373513936996, 49.849384501576424, 43.52191463112831, 42.8418043255806, 64.3097023665905, 74.11798685789108, 61.42048940062523, 0.4610122216399759, 0.14633232989581302, 0.024675358254171442, 2.053453749977052, 62.400973588228226, 76.58252701163292, 71.2443682551384, 72.90905892848969, 71.72773271799088, 71.65790766477585, 68.39642107486725, 69.68852654099464, 71.23812139034271, 68.47185462713242, 64.91584584116936, 62.40818940103054, 65.08071899414062, 62.92305037379265, 57.67495818436146, 53.27051192522049, 51.49242773652077, 48.4378856420517, 49.340105429291725, 48.00762712955475, 48.39592829346657, 48.54108810424805, 51.337145268917084, 50.54144136607647, 50.322531312704086, 53.29299911856651, 55.6220955401659, 57.52039387822151, 57.04608432948589, 56.678640246391296, 52.653919011354446, 52.66552358865738, 47.64601573348045, 47.37500287592411, 45.2726174890995, 43.77067968249321, 44.43099685013294, 42.1976362913847, 44.184298887848854, 44.78641077876091, 44.709753692150116, 45.01654163002968, 46.212854236364365, 46.16950236260891, 48.86648364365101, 50.77468425035477, 50.2924445271492, 50.55523082613945, 53.46790753304958, 52.413752898573875, 52.89041452109814, 52.79490664601326, 55.637997686862946, 54.94615741074085, 55.03773249685764, 55.25783948600292, 54.95825596153736, 54.63827133178711, 58.428936526179314, 56.22069261968136, 58.65994893014431, 51.95856012403965, 45.95054291188717, 45.25419607758522, 46.050207763910294, 49.295834004879, 53.83820526301861, 51.168312728405, 38.83143492043018, 41.55519716441631, 50.322934091091156, 58.52533355355263, 46.32782466709614, 42.956881150603294, 43.45273554325104, 43.395442217588425, 45.0127000361681, 48.583326637744904, 51.8581885099411, 52.78804041445255, 51.70727200806141, 50.83998754620552, 50.441837310791016, 48.746881261467934, 49.70439188182354, 48.471369445323944, 47.482609301805496, 47.75276720523834, 50.364815443754196, 48.42057757079601, 45.576471984386444, 47.22942888736725, 49.499415680766106, 50.14724671840668, 48.84727567434311, 47.09589645266533, 42.794561460614204, 42.47929997742176, 43.03324565291405, 42.816942259669304, 41.6074975579977, 41.64835676550865, 41.3510949164629, 44.295169338583946, 46.331628262996674, 45.770649164915085, 46.661294773221016, 46.69796280562878, 46.58256679773331, 48.456896021962166, 51.136504635214806, 51.614910364151, 48.45533810555935, 50.91185308992863, 51.61570832133293, 51.50766111910343, 47.75053672492504, 47.93836064636707, 47.99984514713287, 49.33521889150143, 49.06072162091732, 51.01745322346687, 52.88280352950096, 54.88643981516361, 62.39672541618347, 67.25117012858391, 65.9118027985096, 70.36874324083328, 63.31496134400368, 66.5862438082695, 67.4334767460823, 72.50111281871796, 67.69197687506676, 72.72857621312141, 67.70105838775635, 78.94061967730522, 70.27301877737045, 83.77224281430244, 7.265827618539333, 0.16818791104014963, 0.1996433801832609, 4.007596028968692, 73.59655603766441, 67.66398757696152, 69.23859268426895, 42.33079634606838, 33.164677396416664, 40.3792704641819, 65.4947979748249, 48.45678582787514, 0.6775249599013478, 0.03189872426446527, 0.03163840483466629, 0.03559228563972283, 0.055320333485724404, 0.06961219041841105, 0.19649138994282112, 0.18563232966698706, 0.1566559899947606, 0.1387856379733421, 0.11018725926987827, 0.3011289134155959, 0.27673825970850885, 0.35488501482177526, 22.01162986457348, 82.68546313047409, 56.88503757119179, 50.43763093650341, 54.06802833080292, 73.66768822073936, 79.51294496655464, 68.18581357598305, 0.7136854226700962, 0.48918975808192044, 0.1363858737749979, 2.6710080122575164, 70.3307680785656, 79.17653381824493, 75.62610313296318, 77.02913224697113, 75.76537325978279, 75.81919357180595, 70.73947414755821, 73.54968175292015, 75.1928959786892, 72.31657952070236, 67.32035681605339, 66.00392505526543, 67.86477640271187, 67.12868750095367, 61.83095097541809, 55.34453943371773, 53.02165187895298, 52.75880478322506, 52.78941974043846, 50.74498504400253, 52.19577759504318, 52.2498144954443, 53.99708993732929, 51.204110607504845, 53.77725653350353, 55.185312777757645, 56.306518614292145, 60.84938384592533, 60.665131732821465, 57.31477551162243, 54.28223043680191, 56.09384022653103, 50.84357835352421, 50.502934232354164, 46.95057325065136, 46.94690644741058, 46.008884981274605, 45.38479506969452, 47.365583181381226, 49.11637343466282, 48.294739723205566, 47.98974148929119, 49.60601896047592, 50.21838650107384, 52.1357636153698, 53.610753268003464, 53.22420001029968, 53.28145153820515, 56.08349338173866, 54.17256832122803, 54.170877411961555, 56.67008690536022, 59.87863093614578, 56.16141580045223, 57.33131602406502, 60.46010613441467, 57.577960789203644, 58.04025158286095, 61.84419326484203, 58.66256698966026, 61.422244906425476, 51.68263033032417, 47.6183570176363, 48.374315053224564, 48.95069472491741, 51.4657873660326, 57.637233808636665, 53.33574682474136, 40.84603741765022, 44.563898518681526, 51.55596412718296, 59.54111024737358, 47.456626296043396, 43.23007509112358, 43.71284678578377, 43.15063655376434, 45.080853179097176, 48.11093218624592, 53.06005261838436, 55.23933447897434, 53.0934452265501, 52.66670912504196, 52.900977954268456, 51.58537834882736, 51.58170774579048, 50.24727635085583, 47.41073615849018, 48.513250797986984, 52.02080078423023, 50.99237836897373, 46.69922053813934, 49.335302487015724, 53.37816774845123, 52.67669878900051, 49.50171835720539, 50.42820744216442, 45.61532489955425, 43.67526300251484, 43.95866699516773, 47.0801766961813, 44.880003556609154, 43.370720744132996, 43.44998449087143, 48.020778223872185, 48.850178718566895, 48.9686069637537, 49.9356322735548, 48.954308331012726, 49.83029432594776, 51.54803015291691, 55.314190462231636, 54.53685097396374, 50.6617771089077, 52.19461865723133, 55.202404260635376, 56.336172223091125, 51.38411834836006, 51.25679478049278, 49.949904307723045, 53.10145519673824, 52.65051059424877, 53.35004925727844, 57.039997056126595, 58.076041862368584, 64.90342810750008, 71.34631678462029, 69.53826740384102, 72.8937229514122, 65.49281448125839, 67.51821219921112, 68.90753924846649, 73.64099085330963, 70.26655152440071, 78.7622344493866, 70.25455936789513, 83.0897006392479, 70.86767166852951, 98.53860005736351, 9.471652004867792, 0.25083065615035594, 0.285965203656815, 5.805428707972169, 84.11362409591675, 74.96773526072502, 78.4024241566658, 53.296054154634476, 44.1650453209877, 52.16595679521561, 76.81907191872597, 59.643286764621735, 1.0154089448042214, 0.10745330597274005, 0.2569425984984264, 0.26013505063019693, 0.24243828695034608, 0.237564543785993], [0.0559787372185383, 0.051512715144781396, 0.10232404136331752, 0.03570817942090798, 0.18853117333492264, 0.05769471623352729, 0.05910563915676903, 0.38646877161227167, 11.788844615221024, 55.65953113138676, 44.400951862335205, 38.01810376346111, 35.59985652565956, 54.86934453248978, 65.86419895291328, 65.0330999493599, 1.4088318776339293, 0.10581243972410448, 0.13852214586222544, 0.09951386207831092, 40.79366482794285, 75.9603787958622, 66.61418750882149, 67.72000417113304, 68.32244664430618, 70.21074011921883, 64.73207250237465, 67.18006834387779, 66.25821501016617, 65.06321713328362, 62.358602061867714, 63.85094538331032, 61.999722719192505, 61.044275388121605, 54.6458101272583, 51.24838203191757, 48.48360098898411, 45.666067376732826, 44.157115146517754, 45.8420929312706, 44.75139945745468, 47.06267103552818, 45.977285876870155, 49.240786358714104, 50.16577452421188, 52.96701841056347, 53.573933243751526, 58.23533311486244, 55.95229022204876, 53.04092064499855, 50.77108584344387, 45.17646744847298, 43.693995997309685, 44.33005906641483, 43.53301763534546, 43.71999800205231, 41.65075063705444, 41.49017125368118, 43.83037827908993, 42.39084832370281, 40.62757954001427, 44.514368176460266, 42.799930572509766, 43.41661848127842, 45.60253858566284, 45.465270951390266, 47.563309371471405, 47.34362035989761, 48.84211555123329, 51.40946678817272, 49.85269412398338, 49.29175302386284, 50.4350508749485, 51.17661528289318, 51.45109735429287, 52.489471435546875, 55.39490193128586, 54.702795669436455, 55.25189280509949, 56.547148302197456, 56.29537761211395, 56.12307205796242, 49.855954349040985, 40.79270727932453, 44.40167382359505, 40.96945479512215, 49.75397162139416, 51.75180941820145, 39.51367691159248, 39.15449358522892, 44.27172839641571, 61.25751234591007, 49.58286680281162, 39.416212141513824, 41.42583690583706, 42.147710770368576, 51.037075370550156, 57.693778574466705, 53.4018936753273, 50.08799269795418, 51.34596459567547, 50.36460645496845, 48.24569195508957, 52.43380442261696, 51.60598084330559, 48.344851434230804, 48.16152647137642, 48.26444014906883, 48.250498697161674, 46.90736956894398, 46.545074209570885, 46.75633907318115, 43.48969615995884, 44.25238363444805, 43.818412721157074, 41.41362816095352, 41.197621151804924, 40.31899809837341, 39.3910688906908, 40.47097094357014, 38.83645825088024, 39.45543743669987, 39.598366767168045, 41.75617977976799, 42.54745692014694, 44.62645836174488, 42.76800848543644, 43.81690040230751, 42.288421019911766, 43.84265162050724, 45.57320415973663, 47.82026298344135, 46.44028723239899, 47.965092211961746, 47.15071991086006, 48.10289941728115, 47.71806366741657, 45.32525986433029, 45.670611932873726, 45.02206273376942, 44.221335500478745, 48.08624491095543, 45.657654628157616, 48.27546715736389, 52.75788903236389, 58.16361576318741, 63.46468850970268, 66.22452601790428, 68.20149913430214, 69.95300754904747, 66.28315687179565, 70.82481756806374, 67.80259653925896, 69.56482797861099, 69.83965963125229, 72.06847563385963, 71.60840392112732, 61.34799309074879, 2.083472851663828, 0.11924351667403243, 0.5417954712174833, 3.877225499600172, 62.508059442043304, 58.16393494606018, 55.29688999056816, 38.661629632115364, 32.11884431540966, 31.040842160582542, 57.1517338603735, 36.6080754250288, 1.4124741009436548, 0.08369034592760727, 0.05749350515543483, 0.025903761088557076, 0.05138489133969415, 0.06615576377953403, 0.07624713907716796, 0.06508742735604756, 0.07695869542658329, 0.05157135223271325, 0.12342119211098179, 0.06647686139331199, 0.06427702435757965, 0.569604872725904, 19.70505863428116, 65.04902869462967, 48.755320608615875, 35.34689649939537, 34.320921152830124, 66.99358955025673, 71.66177585721016, 71.5420214831829, 1.4495654543861747, 0.09008515044115484, 0.2780159708345309, 0.09846633547567762, 40.603815615177155, 78.46607074141502, 68.69962200522423, 72.3140336573124, 69.64656919240952, 72.659792304039, 68.7883472442627, 71.06039732694626, 67.23316669464111, 70.42413666844368, 65.93464717268944, 65.62808722257614, 64.29667666554451, 63.18007618188858, 55.6208112090826, 53.662111312150955, 50.77662594616413, 49.34012062847614, 46.837137937545776, 48.494567200541496, 47.077121660113335, 48.92715498805046, 50.721920281648636, 50.077486261725426, 53.561086133122444, 55.39120852947235, 58.23294684290886, 59.54079486429691, 59.95751850306988, 55.80730140209198, 52.980674877762794, 47.70993210375309, 45.72831183671951, 47.89020203053951, 46.37618847191334, 45.45000337064266, 43.45908880233765, 44.32793118059635, 45.241972133517265, 46.024407148361206, 42.26405672729015, 45.17213188111782, 44.70011740922928, 45.59094540774822, 47.44976386427879, 49.7336845099926, 50.143515318632126, 52.07467809319496, 52.25169159471989, 52.47399866580963, 53.07728089392185, 54.32639926671982, 52.073944732546806, 52.49176651239395, 55.57585582137108, 55.61314322054386, 58.61563950777054, 55.21677128970623, 58.371483609080315, 57.74770528078079, 58.78330931067467, 59.13556940853596, 53.216296434402466, 43.59818793833256, 46.51740029454231, 46.58232741057873, 51.849034801125526, 53.95336948335171, 41.875884756445885, 43.45649354159832, 48.76830071210861, 60.875678434967995, 51.40559859573841, 40.215780436992645, 43.17761890590191, 42.69995033740997, 54.041460156440735, 57.09649242460728, 55.76991520822048, 53.57758104801178, 52.83166587352753, 52.171519696712494, 52.01284781098366, 54.4151359051466, 51.33348226547241, 50.62209963798523, 48.54041174054146, 49.83790911734104, 51.49918757379055, 49.77402314543724, 48.55733223259449, 47.58978255093098, 45.94420105218887, 46.477707624435425, 46.44836559891701, 44.931559190154076, 42.51484327018261, 41.76017716526985, 42.422151044011116, 43.04584197700024, 41.47113807499409, 40.35603851079941, 41.985372081398964, 42.629027143120766, 43.83372589945793, 45.76529525220394, 45.72679191827774, 45.78336328268051, 44.248051866889, 47.23935395479202, 47.38690383732319, 49.07394491136074, 48.826433792710304, 51.54720559716225, 49.19145740568638, 49.91074360907078, 49.65053357183933, 47.269402742385864, 47.61366426944733, 47.57227689027786, 46.864363476634026, 48.68296109139919, 47.813465148210526, 51.065269857645035, 56.02551989257336, 61.02685712277889, 64.75262179970741, 68.8855992257595, 70.16567453742027, 73.8497744500637, 69.97274369001389, 73.26301753520966, 70.92560335993767, 72.91043445467949, 72.83022075891495, 74.56334576010704, 71.41076892614365, 63.184890523552895, 1.8079279060475528, 0.0449409269640455, 0.46283953764941543, 5.209159478545189, 72.44050607085228, 65.45098632574081, 65.7191151380539, 47.32308626174927, 28.377251587808132, 42.27193370461464, 67.2833164036274, 48.396141082048416, 2.114025824703276, 0.09819622340728529, 0.09632650850107893, 0.02503961917682318, 0.030627879859821405, 0.03819333142018877, 0.1873577933292836, 0.15773669059854, 0.2032830801908858, 0.15725894045317546, 0.3881426708539948, 0.1762671087635681, 0.22256017313338816, 0.49161382019519806, 27.30011198669672, 77.4576884508133, 57.60414898395538, 48.05724486708641, 45.5741199105978, 75.6635083258152, 76.6716930270195, 79.27962988615036, 1.6555725876241922, 0.2497501188190654, 0.5930904031265527, 0.41514316108077765, 46.232457384467125, 82.58828714489937, 70.10683849453926, 73.62174868583679, 71.66544646024704, 77.25787997245789, 72.21305027604103, 76.39262080192566, 70.52178382873535, 73.00156116485596, 68.65856140851974, 67.65676036477089, 66.91430300474167, 66.91504016518593, 59.63126800954342, 58.15139181911945, 54.24737110733986, 52.31878459453583, 48.52294407784939, 52.07636900246143, 50.98362363874912, 51.920223981142044, 52.99748137593269, 54.051484018564224, 56.04501284658909, 57.59064070880413, 58.92959386110306, 61.6381911188364, 62.05651067197323, 58.19050692021847, 56.245600283145905, 50.67666471004486, 47.12953224778175, 50.49212761223316, 48.93311686813831, 48.47547322511673, 48.76523047685623, 48.801153749227524, 48.09604838490486, 49.95851844549179, 46.0292898863554, 48.25364112854004, 48.233897387981415, 48.57685558497906, 50.46676777303219, 50.9978386759758, 52.64815092086792, 53.54403264820576, 55.424756929278374, 57.93566979467869, 56.060265228152275, 57.07085520029068, 56.94209150969982, 55.835560485720634, 57.11779788136482, 57.02013172209263, 62.823621109128, 58.75943899154663, 59.964924305677414, 60.91524951159954, 61.189685985445976, 61.27809204161167, 52.01701998710632, 43.75743359327316, 48.90487678349018, 48.92944626510143, 55.27911834418774, 56.05390436947346, 43.53332541882992, 44.75530184805393, 50.44463396072388, 64.47728857398033, 55.195997804403305, 43.46541166305542, 42.62414060533047, 42.6193680614233, 54.008101746439934, 62.36006498336792, 59.59919013082981, 55.78311949968338, 53.54893818497658, 54.8864284157753, 54.48955111205578, 60.29593974351883, 56.54524080455303, 54.03095372021198, 50.78730717301369, 54.00307461619377, 54.238851964473724, 52.0692253857851, 52.197434306144714, 52.017004787921906, 47.34689958393574, 50.97009636461735, 49.43981967866421, 47.195827290415764, 45.11687144637108, 45.40300749242306, 44.988540932536125, 45.56299790740013, 44.461577609181404, 44.833364859223366, 44.15224000811577, 45.53513020277023, 47.118368446826935, 50.10312728583813, 46.32182478904724, 48.82553704082966, 46.01621858775616, 48.09413328766823, 50.698407143354416, 54.35444936156273, 52.142451256513596, 55.00337474048138, 52.246501073241234, 53.430726528167725, 53.91215689480305, 51.19534067809582, 52.46096156537533, 49.98837724328041, 49.211828112602234, 52.348685190081596, 50.93088246881962, 53.809862583875656, 59.33665081858635, 64.10555452108383, 68.50764870643616, 73.79520937800407, 75.28210759162903, 77.16655567288399, 72.74766638875008, 76.01306676864624, 73.46610903739929, 77.14792907238007, 75.20314782857895, 76.95629015564919, 74.45120617747307, 75.97106382250786, 3.1454344047233462, 0.20197011705022305, 0.7714329427108169, 7.283285306766629, 80.47584369778633, 71.88175365328789, 73.69948491454124, 62.386823147535324, 46.621917486190796, 49.31185394525528, 78.24520379304886, 62.02900014817715, 3.202496892772615, 0.250160971772857, 0.22480916260974482, 0.2554900967516005, 0.2187338675139472, 0.13958785508293658], [0.011940431595576229, 0.03178771752573084, 0.03222522842406761, 0.08200006006518379, 0.07192441829829477, 0.0641748083580751, 0.0780665289494209, 0.10398923521279357, 10.475413743406534, 54.591241255402565, 44.04128596186638, 43.78768377006054, 45.2293948084116, 55.86996763944626, 65.10054633021355, 71.43421366810799, 4.934190083295107, 0.19129889435134828, 0.4824140388518572, 0.23811794846551493, 20.312720127403736, 72.71069437265396, 67.82588928937912, 67.6286418735981, 68.53252977132797, 68.38424652814865, 66.33606523275375, 64.76081416010857, 66.86121985316277, 66.03845000267029, 63.88284087181091, 62.587570175528526, 62.86943145096302, 60.837304294109344, 56.79486081004143, 50.16490817070007, 45.9776696562767, 46.64592079818249, 47.70948752760887, 44.95048977434635, 43.85620169341564, 46.80186063051224, 49.82544578611851, 49.93234924972057, 53.887519016861916, 55.432903692126274, 57.28351838886738, 59.517034739255905, 56.24287202954292, 54.47301059961319, 48.65921996533871, 43.45730669796467, 43.95317628979683, 44.37681935727596, 41.66963182389736, 42.20600724220276, 40.66558130085468, 41.95705980062485, 42.78156615793705, 42.25703090429306, 40.827148631215096, 41.42043739557266, 42.27110154926777, 43.64016808569431, 47.72095911204815, 47.400784492492676, 45.24000383913517, 47.72269181907177, 49.71673361957073, 49.53329846262932, 48.282021805644035, 50.096401646733284, 50.123171210289, 52.34100580215454, 54.09357815980911, 54.49233256280422, 54.68423366546631, 53.542668521404266, 54.20390143990517, 55.398663729429245, 54.72277119755745, 54.3732925504446, 55.53658112883568, 47.711976394057274, 45.01288242638111, 45.952013432979584, 43.880968764424324, 43.876561000943184, 44.774255231022835, 39.27052415907383, 40.69276504218578, 48.62763226032257, 39.36941385269165, 40.64281292259693, 38.58678124845028, 49.510374292731285, 56.19275651872158, 53.016202971339226, 51.45560011267662, 51.26775719225407, 53.570623621344566, 53.444679379463196, 48.40031325817108, 49.66595694422722, 50.14894142746925, 50.821296349167824, 47.76861235499382, 46.0245705395937, 49.2352956533432, 46.80507145822048, 47.98215329647064, 45.1029109954834, 45.37187956273556, 44.38382998108864, 40.47846794128418, 39.25911337137222, 38.48292522132397, 39.82542358338833, 39.9358456581831, 40.16389042139053, 39.094532802700996, 41.44796311855316, 39.90304581820965, 43.18508170545101, 43.233380913734436, 42.93732739984989, 44.11495640873909, 42.94574394822121, 43.332244008779526, 42.95511804521084, 43.28086316585541, 44.61002044379711, 46.57460242509842, 47.62309156358242, 48.30905355513096, 47.98136293888092, 44.706561863422394, 44.992511719465256, 46.055250093340874, 44.08504441380501, 44.37383271753788, 45.5803781747818, 44.95752699673176, 45.73896266520023, 48.04071955382824, 55.68243630230427, 59.113006219267845, 65.29989123344421, 64.87802267074585, 63.18651303648949, 66.13216817378998, 67.55272954702377, 68.2989639043808, 71.66442051529884, 71.52076542377472, 73.44717845320702, 67.58674532175064, 46.75794258713722, 0.1360900537110865, 0.06698687269818038, 0.24722056783502921, 7.145194541662931, 62.65030860900879, 60.626354813575745, 52.520272582769394, 41.734395548701286, 23.18915817886591, 33.77865985035896, 50.859130918979645, 58.14943112432957, 4.167280085384846, 0.20928410114720464, 0.12387273702188395, 0.05972404484055005, 0.09802674656384625, 0.06584179820492864, 0.030186238909664098, 0.056223156134365126, 0.044089063885621727, 0.11368030347512104, 0.028443698429327924, 0.04395478710648604, 0.05868767271749675, 0.22362122166668996, 17.116291746497154, 64.5811977982521, 50.60105636715889, 47.942863404750824, 43.010785058140755, 64.10754561424255, 67.33080625534058, 79.66924577951431, 5.09259550832212, 0.2576297678751871, 0.4952248139306903, 0.22803569416282699, 19.797957949340343, 74.22705620527267, 70.73128178715706, 72.03284874558449, 70.4912942647934, 71.34517684578896, 67.63831615447998, 67.63760939240456, 67.35779240727425, 69.12146016955376, 64.98629406094551, 65.4885283112526, 63.81451293826103, 64.31372255086899, 58.27784143388271, 53.70108962059021, 49.597378224134445, 49.24731820821762, 50.203935876488686, 46.95482902228832, 48.025254383683205, 50.18987663090229, 50.81257201731205, 52.649792432785034, 56.72470137476921, 58.24535317718983, 59.42127227783203, 61.82055093348026, 58.61067317426205, 57.79719762504101, 50.944892317056656, 46.91992409527302, 46.12088397145271, 47.89347365498543, 44.772644117474556, 45.377510860562325, 44.673119857907295, 45.21999031305313, 43.978862911462784, 44.490030482411385, 42.652308493852615, 44.87181879580021, 43.6985519528389, 43.84566865861416, 48.15522260963917, 49.53410401940346, 49.83586102724075, 51.47191263735294, 51.30678869783878, 52.641440480947495, 53.177166134119034, 53.867083713412285, 54.23289768397808, 54.21592019498348, 55.80253265798092, 55.52729442715645, 55.74064917862415, 56.86819687485695, 56.81536830961704, 57.19177611172199, 56.14617481827736, 56.142200231552124, 58.45352880656719, 47.91415594518185, 46.80050790309906, 46.15584969520569, 46.592735052108765, 47.44881011545658, 45.76909504830837, 42.03212097287178, 43.962983563542366, 50.52524283528328, 43.87672059237957, 42.59260609745979, 38.15485082566738, 49.35711331665516, 58.72539661824703, 54.88346457481384, 53.33996839821339, 54.82609525322914, 55.849452540278435, 55.119371116161346, 51.41495369374752, 52.15215973556042, 51.102933436632156, 51.88713915646076, 49.61807191371918, 49.46182809770107, 50.90965300798416, 51.21348090469837, 48.9440830796957, 47.855019718408585, 45.89074932038784, 46.126743257045746, 43.71539644896984, 41.76195167005062, 40.343867763876915, 42.34637551009655, 42.85930618643761, 41.67965188622475, 40.67286930978298, 43.05510587990284, 41.36814460158348, 44.06414933502674, 45.716942846775055, 43.898797407746315, 47.11916260421276, 45.701720863580704, 44.01627950370312, 47.2604314237833, 45.42547568678856, 48.222467601299286, 48.58429938554764, 50.70213094353676, 49.79847103357315, 50.41392020881176, 46.71836391091347, 47.637956365942955, 48.591705188155174, 47.163293436169624, 46.94196671247482, 48.27295169234276, 50.091575905680656, 48.59919838607311, 50.78967824578285, 56.78046338260174, 59.78924833238125, 67.71646276116371, 68.37047606706619, 66.96700617671013, 69.12777543067932, 69.1026359796524, 70.6465919315815, 72.56094440817833, 74.52003568410873, 75.16096249222755, 70.16727045178413, 49.47261191904545, 0.06590912584215403, 0.0626513795577921, 0.13171586499083787, 8.89243483543396, 71.2881875038147, 69.76988777518272, 60.84945984184742, 53.79308268427849, 32.76316814124584, 45.53641073405743, 60.30984699726105, 68.33448439836502, 5.981473261490464, 0.19181614159606397, 0.135797098337207, 0.039716110841254704, 0.05074124892416876, 0.04214750537357759, 0.17305433662841097, 0.16083279711892828, 0.2352073194924742, 0.19541306421160698, 0.15815245656995103, 0.1776627471554093, 0.1920485228765756, 0.3376057685818523, 26.925286799669266, 79.55639943480492, 57.57876254618168, 55.76159745454788, 60.33873684704304, 74.09543886780739, 75.99953949451447, 86.3553062081337, 6.956324726343155, 0.396450242260471, 1.1293864413164556, 0.3028815099969506, 23.834051974117756, 80.41852757334709, 73.82612451910973, 74.73289266228676, 73.64298194646835, 76.67432248592377, 72.14798256754875, 71.62075325846672, 70.34801915287971, 73.20696294307709, 68.3721935749054, 69.08443495631218, 65.06907641887665, 67.90755450725555, 61.190020367503166, 55.09722210466862, 51.36843279004097, 55.03939300775528, 53.853860422968864, 48.461277186870575, 51.55810721218586, 51.32286183536053, 54.76436756551266, 54.418760910630226, 60.32414183020592, 60.62490329146385, 60.66511653363705, 65.1757138967514, 61.59259736537933, 60.37234224379063, 54.33760866522789, 48.225655630230904, 49.63500380516052, 49.20277699828148, 46.221943348646164, 47.882838025689125, 47.182698994874954, 46.13170579075813, 47.47342899441719, 48.06774750351906, 46.92495882511139, 46.54498681426048, 46.8910076469183, 47.65040069818497, 52.32259579002857, 53.23881022632122, 50.426144152879715, 53.06087337434292, 55.53642153739929, 55.281303226947784, 55.77311843633652, 57.96459764242172, 56.53193011879921, 58.976696133613586, 60.3521691262722, 59.0741191059351, 59.83284719288349, 60.732163935899734, 61.3201329857111, 59.455713629722595, 59.79535460472107, 58.76958824694157, 60.31424716114998, 47.47865751385689, 45.913768485188484, 50.82443118095398, 49.531178176403046, 49.31308887898922, 47.69154869019985, 42.1452447026968, 46.37216068804264, 54.37286697328091, 47.67824940383434, 44.065129682421684, 37.06180527806282, 51.27881079912186, 60.62150627374649, 59.150179624557495, 54.0157887339592, 56.71066492795944, 58.40404786169529, 58.5042978823185, 53.47105376422405, 56.86891123652458, 57.28574126958847, 56.39641419053078, 52.47732348740101, 50.918814316391945, 54.75093528628349, 54.27233576774597, 54.16008599102497, 49.67698395252228, 49.788663759827614, 48.830602169036865, 45.01665562391281, 44.135258719325066, 42.16852605342865, 45.37143498659134, 45.47956198453903, 44.097484946250916, 44.03620943427086, 46.01349413394928, 42.168898433446884, 47.64238312840462, 48.60049031674862, 49.03582915663719, 50.09002938866615, 47.420429438352585, 47.61146418750286, 50.29306009411812, 49.47866499423981, 51.44518867135048, 52.21955291926861, 54.63514409959316, 52.558965906500816, 53.71946543455124, 50.65050311386585, 50.48104740679264, 53.35719287395477, 51.18616037070751, 49.95796747505665, 52.280357256531715, 51.91518545150757, 52.062469348311424, 54.464901834726334, 61.41665160655975, 63.675391003489494, 72.17642024159431, 71.47813931107521, 69.53544795513153, 72.68129914999008, 73.51197257637978, 74.463319927454, 78.10677722096443, 77.76816979050636, 79.94736805558205, 69.66333389282227, 56.74584724009037, 0.44045116868801415, 0.16681147943018004, 0.4567939433036372, 10.735312197357416, 82.08891034126282, 77.02040031552315, 70.29951095581055, 66.2358646094799, 34.787729904055595, 49.12611611187458, 70.29802143573761, 79.935322701931, 7.446056697517633, 0.4022442188579589, 0.20290736050810665, 0.12384777117404155, 0.16200274840230122, 0.17394990107277408], [0.005607564407910104, 0.03607808437664062, 0.05425024930445943, 0.03653042338555679, 0.07568273576907814, 0.022395499145204667, 0.0946393545018509, 0.2755355945555493, 18.83034937083721, 59.05875653028488, 44.82433274388313, 25.71515053510666, 28.04234705865383, 52.34084241092205, 61.23649947345257, 75.1297889649868, 5.119999162852764, 0.2542724699014798, 0.3329512261552736, 0.5751950852572918, 4.2997656762599945, 55.319411382079124, 68.87078002095222, 67.33390688896179, 67.62574642896652, 65.77707722783089, 60.75933627784252, 60.68200662732124, 63.16219054162502, 63.83912041783333, 65.69241777062416, 65.05883976817131, 64.3234272301197, 58.406950905919075, 51.432254165410995, 47.781668454408646, 44.585386365652084, 45.48727177083492, 43.00836078822613, 45.13548284769058, 46.229850724339485, 48.5123236477375, 48.77567991614342, 51.37759029865265, 56.13950617611408, 56.165603175759315, 58.20583909749985, 62.768695056438446, 57.95376442372799, 52.386964336037636, 44.44547787308693, 43.9625009894371, 42.44491942226887, 42.55056515336037, 41.283819526433945, 44.35631185770035, 43.67649033665657, 44.391269981861115, 43.62057253718376, 41.05825982987881, 42.19689153134823, 42.03698471188545, 41.622746139764786, 41.611836925148964, 42.79253616929054, 45.22369131445885, 47.570247799158096, 49.40496414899826, 51.96824960410595, 48.20572569966316, 49.778537303209305, 51.30205415189266, 47.45630331337452, 49.00918498635292, 53.37939888238907, 54.56277698278427, 51.11108399927616, 51.88196383416653, 54.64503116905689, 52.807757556438446, 54.221315905451775, 54.71628114581108, 54.17683929204941, 51.19203105568886, 43.208579644560814, 43.968907445669174, 35.76903484761715, 42.166679352521896, 41.71282410621643, 40.10048322379589, 41.99633829295635, 50.08041590452194, 36.31181672215462, 40.43970242142677, 42.387455105781555, 52.77391277253628, 54.93185117840767, 53.25609549880028, 53.68593983352184, 51.72731213271618, 51.06569543480873, 52.14819274842739, 46.93197324872017, 48.209354504942894, 49.051077738404274, 48.615039736032486, 48.465958535671234, 47.79049538075924, 46.9529215246439, 48.57482649385929, 47.2938734292984, 46.123509630560875, 44.1500361263752, 42.797331511974335, 42.556747421622276, 40.71514204144478, 37.61913277208805, 40.398147851228714, 40.99396347999573, 40.301085859537125, 39.33136269450188, 40.46599701046944, 39.93081092834473, 40.7468893378973, 41.614565178751945, 42.753280475735664, 41.529027968645096, 43.80379870533943, 43.01958538591862, 41.161504089832306, 42.3387037217617, 41.37340731918812, 44.12053070962429, 46.45306594669819, 46.2543898075819, 46.455668807029724, 43.28449197113514, 45.29081091284752, 45.70578284561634, 41.332415118813515, 44.389556273818016, 43.27350676059723, 43.916565254330635, 44.31577943265438, 45.70674419403076, 44.486960247159004, 50.80187939107418, 52.293219566345215, 59.50440041720867, 62.474100664258, 63.427739292383194, 63.06060679256916, 67.96901240944862, 66.67507544159889, 74.68848824501038, 65.8076199889183, 76.30940526723862, 31.22240401804447, 0.7960959943011403, 0.15412747801747173, 0.32786080555524677, 6.964681427925825, 64.18890684843063, 58.382107838988304, 55.23699000477791, 36.33496508002281, 23.214972093701363, 37.63848893344402, 49.540670067071915, 64.06244203448296, 4.544150037690997, 0.1940805380581878, 0.05098774214275181, 0.034546618117019534, 0.031057293927005958, 0.05078066067653708, 0.0450903175806161, 0.04141146557230968, 0.07246481312904507, 0.08577963264542632, 0.05614599504042417, 0.1062280053156428, 0.07876944669988006, 0.29509822139516473, 27.95577060431242, 67.16099336743355, 53.4355104714632, 28.626172430813313, 30.046663507819176, 61.103024035692215, 64.87089425325394, 83.59926849603653, 5.563534637913108, 0.36935291660483927, 0.40505859127733856, 1.6810240969061852, 4.220186546444893, 55.94251714646816, 71.14861339330673, 70.85045099258423, 68.25206682085991, 67.26519897580147, 64.13694843649864, 64.6395094692707, 64.0323856472969, 66.07135623693466, 67.49613538384438, 68.28501105308533, 65.58008819818497, 62.579355016350746, 54.29138034582138, 51.51735059916973, 48.860453367233276, 47.85097673535347, 44.984064772725105, 48.632180616259575, 48.59151139855385, 52.641501277685165, 51.14975452423096, 56.31901614367962, 59.9536769092083, 57.75024734437466, 62.60335072875023, 62.30694003403187, 61.428924947977066, 54.51779879629612, 46.48779608309269, 44.85728457570076, 45.42153149843216, 44.5095956325531, 45.06146281957626, 46.012297198176384, 46.114789098501205, 46.13213136792183, 46.76799304783344, 43.737686052918434, 47.276306971907616, 44.683804884552956, 43.04818645119667, 43.274430111050606, 46.346078887581825, 46.98016606271267, 50.18478870391846, 53.02833192050457, 53.37734319269657, 53.21218505501747, 53.887682408094406, 54.01808001101017, 52.00289994478226, 52.42370456457138, 54.475484266877174, 56.64214700460434, 55.2782291918993, 54.82704520225525, 57.62455768883228, 56.34339943528175, 55.48640862107277, 56.86519883573055, 58.33526395261288, 51.4768485724926, 44.794751331210136, 44.851003512740135, 40.36940239369869, 44.733282029628754, 43.315015733242035, 40.37355937063694, 44.420220628380775, 51.68790824711323, 40.808172449469566, 42.86103129386902, 42.03831844031811, 56.5832843631506, 57.4876244366169, 54.85311560332775, 56.21493972837925, 54.687368497252464, 54.725537449121475, 54.94274899363518, 50.8939066529274, 52.44298852980137, 52.005350813269615, 52.05002501606941, 51.14997111260891, 49.85857240855694, 49.734889045357704, 51.6501534730196, 48.36290426552296, 47.292585298419, 45.98481707274914, 45.37865839898586, 44.809927716851234, 42.987074330449104, 41.19695618748665, 41.53866425156593, 43.50773759186268, 43.18158209323883, 41.86893492937088, 42.391889467835426, 41.95334739983082, 42.97353945672512, 44.810398891568184, 43.88454057276249, 44.39535856246948, 45.10009154677391, 44.307028502225876, 45.15698589384556, 45.67100331187248, 44.09953683614731, 45.88004529476166, 49.42726135253906, 48.80991227924824, 49.212154895067215, 46.867441311478615, 47.34512507915497, 47.70072139799595, 45.75287751853466, 47.87290155887604, 45.628567188978195, 45.95710515975952, 47.56104849278927, 48.57368655502796, 46.75126634538174, 51.66441410779953, 55.957697331905365, 62.826106175780296, 64.13464576005936, 65.04131510853767, 66.09598651528358, 69.4402402639389, 68.73584166169167, 76.26430168747902, 69.08027037978172, 77.2378246486187, 30.91956976801157, 0.7227832626085728, 0.27556495391763747, 0.37534252332989126, 9.073639512062073, 72.17304602265358, 69.15464758872986, 63.27752195298672, 44.96821582317352, 30.65744273364544, 44.20106738805771, 59.469605684280396, 72.59755164384842, 5.7923564594239, 0.2541185187874362, 0.09741020738147199, 0.008126413158606738, 0.01244257149664918, 0.023892381323094014, 0.14028220844920725, 0.12085052614565939, 0.21325036097550765, 0.25015871564392, 0.23966483655385673, 0.2336369053227827, 0.30553848773706704, 0.3218139347154647, 35.33512473106384, 79.72430482506752, 56.452601775527, 33.983111679553986, 40.56922227144241, 69.70180302858353, 71.53889045119286, 92.42347419261932, 7.495884373784065, 0.520617188885808, 1.2520557339303195, 1.3782524247653782, 6.045774361118674, 62.070862501859665, 72.70169645547867, 76.49217545986176, 72.44518741965294, 71.55460640788078, 67.62288898229599, 67.52536341547966, 67.92024582624435, 67.85855233669281, 69.1228736937046, 71.4798492193222, 70.38765862584114, 64.49134781956673, 55.49424760043621, 53.184480741620064, 50.90516924858093, 50.67957915365696, 46.23758710920811, 50.81339277327061, 50.34355938434601, 56.802859380841255, 53.09737801551819, 57.558084055781364, 62.50040665268898, 61.4996163547039, 63.93555164337158, 65.6363707780838, 64.75709795951843, 57.63865493237972, 47.4612620472908, 48.6736211925745, 46.42214320600033, 45.210015848279, 45.22289715707302, 48.97880181670189, 49.444945603609085, 49.394206926226616, 50.96284255385399, 47.42467761039734, 48.62927757203579, 46.91869676113129, 45.46913154423237, 45.59123419225216, 47.35206350684166, 48.978969007730484, 53.17386791110039, 54.58769604563713, 56.589181646704674, 54.26744543015957, 56.82183176279068, 58.423689007759094, 53.49332816898823, 53.38812701404095, 57.77594916522503, 59.926569163799286, 57.15839870274067, 58.27333867549896, 59.685141518712044, 58.181740790605545, 60.66480495035648, 59.47882018983364, 60.60921013355255, 52.973789647221565, 44.40434508025646, 48.371032029390335, 43.198153004050255, 47.068469524383545, 46.59073255956173, 41.0857779532671, 46.66149616241455, 54.42432761192322, 41.10825754702091, 41.212877333164215, 43.73721107840538, 57.41159051656723, 58.1425990909338, 56.04308634996414, 60.16566753387451, 56.761544197797775, 56.75297185778618, 57.65372112393379, 52.34149217605591, 54.52122621238232, 54.93489861488342, 54.97760072350502, 55.404785200953484, 53.59608605504036, 51.12456947565079, 55.93318484723568, 52.74956747889519, 50.70308469235897, 47.23821401596069, 47.55898140370846, 47.95165993273258, 45.3645421564579, 44.22940246760845, 45.695899575948715, 46.19239613413811, 44.66098710894585, 43.5825327783823, 45.387295335531235, 45.48719197511673, 46.86094366014004, 46.37385539710522, 47.00473174452782, 46.72114536166191, 48.75541180372238, 48.26367259025574, 46.46827273070812, 48.75684812664986, 47.120967507362366, 49.05867353081703, 53.22621010243893, 53.523836731910706, 54.13474515080452, 48.199957609176636, 52.22146801650524, 52.22176060080528, 46.9444365799427, 50.302798971533775, 48.59107822179794, 48.42710182070732, 49.90260824561119, 53.24658840894699, 51.505529433488846, 56.475313156843185, 59.704265892505646, 66.30579605698586, 68.41471329331398, 69.64577123522758, 71.17871537804604, 73.75762179493904, 73.46867769956589, 81.109778881073, 72.03583538532257, 78.4415240585804, 36.53114095330238, 0.8787235105410218, 0.3679320006631315, 0.4943495546467602, 10.713477618992329, 81.04217290878296, 75.06545841693878, 71.4920237660408, 54.337468072772026, 33.42767268419266, 53.780516758561134, 66.76638454198837, 84.09602344036102, 8.438416197896004, 0.4665809712605551, 0.16654354927595705, 0.14180304715409875, 0.15252742246957496, 0.12371201009955257], [0.035652985898195766, 0.08448427324765362, 0.05520604274352081, 0.017396646580891684, 0.0689209095435217, 0.04325463385612238, 0.07525092456489801, 0.26658116723410785, 20.75094111263752, 60.6432069092989, 41.896992623806, 34.493979066610336, 28.844681605696678, 49.749012887477875, 57.92211212217808, 77.45739966630936, 8.186468817293644, 0.20841428922722116, 0.14033657818799838, 0.9394757787231356, 0.1846136132371612, 24.58783082664013, 66.18984147906303, 64.50843170285225, 67.887012809515, 61.46120801568031, 60.65569683909416, 63.26950818300247, 66.65376618504524, 68.32104071974754, 65.29803693294525, 63.39321814477444, 62.27417819201946, 53.497519344091415, 49.171337485313416, 46.86264976859093, 45.83530269563198, 44.20636810362339, 45.46173334121704, 46.70052386820316, 47.43765011429787, 50.094087570905685, 52.337836772203445, 54.73958149552345, 58.434674218297005, 57.72974744439125, 58.123695105314255, 58.87052223086357, 53.70582416653633, 46.89551800489426, 44.26512435078621, 44.825674071908, 45.62003284692764, 43.36602799594402, 43.42700332403183, 44.29489955306053, 41.469420567154884, 43.779423013329506, 44.768468141555786, 42.39592105150223, 42.141631096601486, 41.214309856295586, 41.21841363608837, 41.52284190058708, 41.28627799451351, 47.066163048148155, 47.31778174638748, 51.870119869709015, 49.78979989886284, 48.530376479029655, 50.165588334202766, 50.55509403347969, 49.20515567064285, 53.61589439213276, 54.22540068626404, 53.97209867835045, 52.89897546172142, 53.40089052915573, 51.49649351835251, 54.16125252842903, 54.262254908680916, 54.4833954423666, 55.811310186982155, 53.8178725540638, 44.17978473007679, 43.85185092687607, 36.10932178795338, 38.98319497704506, 42.41515561938286, 42.88211636245251, 42.78785102069378, 41.27697989344597, 40.55873103439808, 41.591986790299416, 50.18788553774357, 53.0569139868021, 53.69643107056618, 53.55109266936779, 55.320285335183144, 50.84638640284538, 52.147835567593575, 50.61035446822643, 49.87995386123657, 49.54791247844696, 48.75958777964115, 48.41458909213543, 48.19301538169384, 46.6846027225256, 48.8801135122776, 45.559228509664536, 47.00149431824684, 44.84523542225361, 43.10561276972294, 43.23280334472656, 41.2351593375206, 37.56685517728329, 38.45197208225727, 38.946017771959305, 41.534241288900375, 40.39534740149975, 39.74137209355831, 40.760511606931686, 42.843320444226265, 42.427535355091095, 42.42206744849682, 40.66539891064167, 41.84797525405884, 40.78108750283718, 41.93284370005131, 40.71921542286873, 41.3749348372221, 41.41519747674465, 43.390092104673386, 42.035829573869705, 43.42919580638409, 42.48022332787514, 43.509903475642204, 43.156264051795006, 43.40791314840317, 45.19032150506973, 44.88757275044918, 44.80626471340656, 45.240866392850876, 46.408444941043854, 47.91170507669449, 44.97585341334343, 47.71605357527733, 47.67536535859108, 49.51268456876278, 51.415618658065796, 59.67866286635399, 60.068350955843925, 64.30668532848358, 65.00450268387794, 70.65804451704025, 70.9148271381855, 80.19885376095772, 15.090660341084003, 0.8404998772311956, 0.6475806073285639, 0.28573118965141475, 9.323961529880762, 66.42925903201103, 61.26969449222088, 53.83071966469288, 44.47706937789917, 32.19867803156376, 42.37799361348152, 47.5806250423193, 55.34337289631367, 4.843723112717271, 0.16450469149276614, 0.11836146673886105, 0.029955317804706283, 0.032634897652314976, 0.02378388675424503, 0.038340076280292124, 0.007520991348428652, 0.042177707073278725, 0.06511636369396001, 0.0030622151871284586, 0.03126887095277198, 0.04144630198425148, 0.22918311384273693, 27.821331918239594, 69.3698300421238, 49.62677724659443, 34.59621258080006, 33.81896048784256, 59.42011334002018, 62.55990765988827, 83.64379450678825, 9.177745375782251, 0.21705955266952515, 0.11939177551539615, 2.4375354778021574, 1.0622334759682417, 24.212884046137333, 66.78391680121422, 66.00503459572792, 70.42376428842545, 63.513242304325104, 64.96226415038109, 65.68195313215256, 70.5287754535675, 70.54272830486298, 68.59199658036232, 64.9742791056633, 64.78094547986984, 56.627616584300995, 52.353598326444626, 50.57435140013695, 49.342335909605026, 47.34431952238083, 47.53486789762974, 48.20990927517414, 50.82327604293823, 53.02480190992355, 55.23119531571865, 57.29112558066845, 58.24641712009907, 58.35884168744087, 61.097989305853844, 60.84466449916363, 55.959232449531555, 48.610776364803314, 45.827357321977615, 46.848134547472, 47.817238345742226, 47.14913159608841, 45.21859958767891, 46.42128825187683, 45.42576067149639, 46.104601845145226, 46.5889048576355, 43.657464757561684, 45.51596783101559, 44.68652553856373, 43.78300242125988, 42.623110860586166, 43.8149207085371, 47.68479265272617, 48.99541832506657, 53.894206658005714, 52.69140399992466, 50.86631253361702, 52.716148272156715, 55.015317499637604, 54.05138902366161, 55.64795695245266, 56.7667081207037, 55.91968797147274, 56.85674048960209, 56.91256709396839, 55.588174760341644, 57.83811762928963, 56.35786525905132, 54.638643711805344, 56.8490307033062, 54.41327020525932, 43.85886535048485, 42.783105075359344, 39.772116243839264, 41.32606565952301, 43.5797893255949, 42.44652293622494, 44.56862926483154, 44.706451669335365, 42.29914404451847, 40.95335125923157, 49.371472746133804, 54.944075122475624, 56.63017004728317, 55.63020050525665, 55.9930544346571, 54.12852868437767, 53.73819462954998, 52.98312574625015, 53.91559191048145, 51.877065896987915, 52.35586680471897, 51.265370920300484, 51.74414522945881, 51.86538152396679, 51.66588842868805, 47.411184534430504, 47.42291450500488, 47.18280538916588, 45.42852692306042, 44.17030043900013, 43.23608256876469, 39.74604204297066, 42.23152667284012, 40.858842730522156, 44.38132591545582, 42.71278604865074, 40.97527228295803, 42.394005954265594, 42.667101100087166, 43.899492770433426, 45.31657353043556, 43.498903065919876, 43.34973447024822, 43.0561014264822, 44.494909420609474, 44.06605303287506, 43.46275940537453, 43.215662464499474, 43.74505005776882, 44.47736196219921, 45.19162483513355, 45.2460341155529, 46.869447603821754, 45.048661306500435, 45.545302256941795, 47.14281253516674, 47.07746364176273, 47.0359318703413, 47.68332213163376, 49.178659692406654, 50.18522188067436, 49.072216004133224, 49.947073459625244, 49.67260278761387, 52.1355090290308, 53.61052148044109, 60.847423151135445, 61.52524597942829, 67.2474767267704, 69.20772314071655, 72.74683803319931, 73.73003527522087, 81.49217516183853, 16.437959745526314, 0.8234126097522676, 0.5966027802787721, 0.17826023540692404, 10.805977955460548, 74.08793807029724, 70.16693606972694, 62.838539108633995, 50.24484068155289, 23.056598491966724, 43.88501174747944, 59.12355065345764, 65.20974487066269, 7.3398457467556, 0.3731445490848273, 0.19301004940643907, 0.09122903749812394, 0.047208069372572936, 0.026956358415191062, 0.21094226685818285, 0.183197476726491, 0.1941816185717471, 0.1567981854896061, 0.12834255147026852, 0.09346604871097952, 0.1407499989727512, 0.27685777517035604, 35.15136279165745, 81.73145592212677, 56.070794463157654, 47.727525159716606, 44.278712421655655, 68.68520557880402, 70.80019488930702, 92.93991968035698, 10.603712908923626, 0.27153405302669853, 0.33962328219786286, 3.3524104859679937, 1.2823287094943225, 27.488621771335602, 73.08328717947006, 69.06700149178505, 73.22213172912598, 66.29847764968872, 65.82260638475418, 65.72672992944717, 73.38583454489708, 74.90032687783241, 70.17639756202698, 70.18416434526443, 69.1367657482624, 58.717200458049774, 53.65720197558403, 55.259256809949875, 52.41855204105377, 49.27856393158436, 51.78511843085289, 50.468386486172676, 53.440605998039246, 54.12345215678215, 58.02694469690323, 60.35098738968372, 62.46178552508354, 61.64537653326988, 61.53352573513985, 63.53522792458534, 59.59576651453972, 51.310854479670525, 49.39035013318062, 50.12824013829231, 50.73243051767349, 48.8345767557621, 47.16471455991268, 48.2403152436018, 45.21475039422512, 49.028601944446564, 50.452461540699005, 46.04054868221283, 47.7186032384634, 45.656613484025, 43.56782376766205, 46.965559646487236, 46.75377041101456, 51.34075507521629, 53.01846005022526, 56.91953592002392, 55.99013239145279, 52.78980731964111, 54.72054831683636, 56.612094417214394, 56.60303570330143, 58.03984120488167, 59.21870514750481, 59.13887903094292, 58.67633365094662, 59.93741378188133, 56.73100903630257, 59.47119779884815, 58.888730853796005, 58.99017781019211, 58.710710406303406, 56.91658727824688, 44.27561558783054, 43.98315668106079, 40.89299149811268, 43.768601194024086, 45.894484519958496, 45.98157584667206, 45.84326706826687, 46.85172155499458, 44.00087513029575, 40.01683451235294, 50.46476908028126, 56.269003227353096, 58.47144864499569, 58.16104710102081, 58.6009456962347, 55.59958174824715, 57.49264016747475, 56.797577664256096, 56.12524174153805, 55.20793296396732, 56.288743168115616, 55.581350326538086, 54.05656434595585, 53.23358170688152, 56.93079851567745, 51.21315412223339, 50.52347593009472, 49.25609953701496, 47.037512585520744, 47.24601499736309, 46.2230870872736, 41.670919954776764, 43.9534916728735, 45.030251294374466, 45.12134000658989, 44.42237891256809, 42.97267310321331, 45.528864338994026, 47.03540749847889, 47.583649680018425, 48.06443028151989, 46.87535248696804, 46.14663518965244, 45.92851549386978, 47.33157880604267, 45.272302106022835, 47.39005006849766, 46.79384686052799, 47.23697908222675, 47.35172152519226, 49.58673879504204, 47.87135884165764, 49.695067182183266, 48.106608018279076, 49.342335909605026, 50.33870704472065, 50.48845320940018, 48.980925902724266, 50.762308314442635, 52.56733685731888, 53.5392677038908, 51.39056280255318, 52.72199995815754, 54.07339744269848, 55.15803024172783, 58.365267142653465, 64.58778664469719, 65.76432511210442, 71.35635584592819, 72.30893433094025, 76.77633181214333, 77.59179845452309, 81.4392440021038, 19.42750632762909, 0.9391706669703126, 1.0826274566352367, 0.2656433003721759, 13.449955880641937, 83.27191606163979, 77.55247816443443, 72.81883656978607, 66.03702887892723, 44.79006238281727, 60.44575050473213, 66.65498971939087, 77.25952908396721, 10.079219453036785, 0.5433802236802876, 0.2589602011721581, 0.21607653354294598, 0.20188993541523814, 0.08996429911348969], [0.02979304907057667, 0.06306843686616048, 0.08660413644975051, 0.013053708771622041, 0.041945266420952976, 0.16734839358832687, 0.06303650967311114, 0.16641573660308495, 25.705303363502026, 55.764188915491104, 42.12680049240589, 27.987356409430504, 22.907089814543724, 53.00291508436203, 55.90486876666546, 78.96559953689575, 11.203389130532742, 0.3101506980601698, 0.10166304011363536, 0.10786168757476844, 0.6098627625033259, 5.7363389153033495, 49.568153992295265, 64.89322185516357, 64.32216569781303, 60.83895340561867, 67.14188039302826, 66.66002064943314, 64.66716438531876, 62.85028047859669, 64.19909030199051, 59.8898783326149, 55.385664626955986, 48.658068627119064, 46.97511613368988, 47.902741357684135, 47.947495356202126, 46.98557697236538, 46.98941856622696, 50.14901362359524, 50.87950922548771, 52.88590796291828, 55.25208279490471, 58.76795433461666, 59.01207223534584, 59.38555419445038, 59.70648877322674, 55.95717296004295, 52.02126435935497, 42.571125850081444, 42.90936090052128, 42.031087428331375, 42.250962629914284, 42.47838042676449, 44.091944843530655, 43.984190225601196, 46.372867450118065, 43.50330322980881, 42.10986480116844, 43.16133677959442, 42.59009823203087, 43.21891129016876, 42.099624350667, 42.22440205514431, 40.00907152891159, 45.61076134443283, 44.68366049230099, 47.37121447920799, 51.058779805898666, 48.914330676198006, 49.66582775115967, 49.16391268372536, 53.35448361933231, 52.23260521888733, 53.39133404195309, 53.87801192700863, 54.73831616342068, 53.214195147156715, 54.09094490110874, 56.00488319993019, 54.736317470669746, 54.64989110827446, 56.42103686928749, 57.207951843738556, 45.25328792631626, 43.09466935694218, 39.53702285885811, 40.0817958265543, 46.95726469159126, 42.82992996275425, 41.96924954652786, 38.88620898127556, 42.01414033770561, 40.56593544781208, 47.18534745275974, 57.054162696003914, 54.241717010736465, 53.38648170232773, 52.57124684751034, 51.223713755607605, 51.97306014597416, 49.74460132420063, 51.243024319410324, 48.81248474121094, 49.070844277739525, 46.55032932758331, 49.64850828051567, 46.8763442337513, 47.85197988152504, 44.92039158940315, 47.44996525347233, 45.7830972969532, 42.3043991625309, 41.319716200232506, 39.42702256143093, 39.75905254483223, 37.119212597608566, 39.15771961212158, 41.85801811516285, 39.539929702878, 39.420749098062515, 40.252615660429, 40.874114111065865, 41.62544399499893, 42.04024113714695, 41.961646154522896, 40.197043642401695, 42.15311788022518, 44.431650415062904, 41.22438311576843, 41.819966956973076, 40.91620825231075, 40.87660297751427, 42.86187864840031, 41.702743247151375, 43.568173348903656, 44.60202567279339, 41.71427942812443, 43.22774201631546, 42.87500314414501, 45.12365408241749, 44.25275981426239, 46.35897159576416, 47.70891755819321, 50.27683116495609, 47.47210666537285, 43.79790902137756, 48.120397478342056, 51.0761296749115, 50.478642135858536, 51.21003448963165, 53.328322023153305, 60.34433774650097, 66.856280118227, 69.25291791558266, 67.46071368455887, 77.92285948991776, 7.960646934807301, 1.1951755173504353, 1.1850547604262829, 0.3687049326254055, 11.809421461075544, 70.95876038074493, 61.138886511325836, 58.5128740221262, 44.970165118575096, 52.2532457113266, 71.30918517708778, 45.82183241844177, 58.48537489771843, 6.148730311542749, 0.2636670204810798, 0.14684548048535362, 0.044399745456757955, 0.07579221739433706, 0.09396918772836216, 0.05788083202787675, 0.032461843657074496, 0.06194400892127305, 0.09088274397072382, 0.0269041186402319, 0.1078902231529355, 0.03862510551698506, 0.1562603362253867, 33.254151195287704, 66.09602451324463, 42.69086502492428, 35.32363414764404, 34.077023640275, 59.82009507715702, 62.95104347169399, 84.73818138241768, 12.85625483840704, 0.3461934858933091, 0.02924678014096571, 0.8492785936687142, 2.2371793538331985, 6.834331322461367, 48.90424221754074, 65.89828312397003, 64.80713367462158, 61.07466235756874, 72.23958045244217, 68.8403132557869, 67.19865694642067, 65.06292834877968, 65.93914613127708, 62.94346287846565, 58.744274005293846, 52.24519394338131, 48.35405074059963, 50.84986701607704, 50.86502060294151, 49.16656494140625, 50.34105911850929, 50.45230574905872, 53.726897835731506, 55.781348794698715, 57.924441397190094, 60.439553037285805, 60.896455720067024, 60.850903764367104, 60.83981975913048, 59.08711440861225, 53.516324535012245, 46.34044758975506, 45.84320247173309, 43.323626071214676, 43.20898622274399, 44.63861010968685, 45.75285851955414, 45.91328591108322, 47.76095576584339, 44.74359467625618, 47.3198526352644, 44.22348998486996, 45.966300666332245, 46.548437029123306, 44.39004264771938, 43.67149740457535, 42.08654925227165, 45.285996571183205, 47.19819836318493, 50.07470861077309, 51.98092572391033, 52.498431354761124, 52.218443378806114, 54.400958865880966, 55.55004380643368, 55.45955166220665, 55.771393328905106, 55.05325846374035, 54.38745439052582, 54.2935386300087, 56.94184452295303, 57.96515241265297, 55.518763884902, 57.811446860432625, 59.61983822286129, 58.01058277487755, 44.80136677622795, 41.54967986047268, 42.35207140445709, 40.82434058189392, 48.30237731337547, 42.67036132514477, 43.38677108287811, 42.259177789092064, 42.06535778939724, 40.78012615442276, 48.701219111680984, 59.97316986322403, 54.25916947424412, 54.716395139694214, 54.161324724555016, 52.60749690234661, 53.28399360179901, 52.025930508971214, 52.400324419140816, 51.95813834667206, 50.864180848002434, 49.09156456589699, 52.89752013981342, 49.77283000946045, 49.72244471311569, 47.756764590740204, 48.605262860655785, 46.73118442296982, 44.81889523565769, 44.65752549469471, 41.1007035523653, 42.08115354180336, 40.65436810255051, 41.60324938595295, 43.60943913459778, 43.35696168243885, 41.949767991900444, 41.66608661413193, 42.43627868592739, 44.15663257241249, 43.914319574832916, 44.839588925242424, 42.79620297253132, 45.17176330089569, 45.22328093647957, 43.064996749162674, 43.46032373607159, 44.71929118037224, 43.786084055900574, 45.54135046899319, 45.61820134520531, 46.70914560556412, 46.25785522162914, 45.273305252194405, 47.1330888569355, 45.82783229649067, 48.33827778697014, 47.812967374920845, 48.91378350555897, 50.17929419875145, 52.17923328280449, 48.66764411330223, 46.905256882309914, 50.64786985516548, 54.23550434410572, 53.072147369384766, 54.52009007334709, 56.97117894887924, 62.928415685892105, 68.70948627591133, 73.78124132752419, 73.18859472870827, 79.34084460139275, 9.720557648688555, 1.241378781851381, 1.3070899620652199, 0.4065568093210459, 14.558428600430489, 79.42470610141754, 67.05812528729439, 66.8137376010418, 51.047904789447784, 39.1297797113657, 74.14751887321472, 52.42113970220089, 69.00139421224594, 9.730849396437407, 0.2980292891152203, 0.18858588446164504, 0.06243726995307952, 0.03826076295808889, 0.03850969413178973, 0.15221401350572705, 0.10974408578476869, 0.19797641260083765, 0.20415364910149947, 0.2266436180798337, 0.21909196861088276, 0.15182359929895028, 0.34450073610059917, 45.14680624008179, 74.12877827882767, 57.86712907254696, 38.05138997733593, 34.76890191435814, 72.24499136209488, 69.10025730729103, 95.81901758909225, 14.158280622214079, 0.6383198511321098, 0.24319748918060213, 1.8434692989103496, 2.310846713371575, 7.960524866357446, 52.5156444311142, 69.82146620750427, 67.76696965098381, 63.69956910610199, 73.61066848039627, 72.07833990454674, 71.30828082561493, 67.95322045683861, 68.80913212895393, 66.31375283002853, 61.574582532048225, 54.8881459236145, 49.94599051773548, 52.96504631638527, 52.78340466320515, 52.64927566051483, 52.32599280774593, 54.798949509859085, 56.131363213062286, 56.98937237262726, 60.30082248151302, 64.93824943900108, 64.28821831941605, 64.46152701973915, 65.409986525774, 62.61547587811947, 57.13351383805275, 50.287132412195206, 47.96366348862648, 46.06321446597576, 45.333513021469116, 46.59275025129318, 47.873311936855316, 49.19680371880531, 50.15923127532005, 48.66969980299473, 49.08605486154556, 47.250734344124794, 50.31496971845627, 49.29376691579819, 47.67490558326244, 47.54815958440304, 43.13470780849457, 48.597921654582024, 50.54640009999275, 51.83059819042683, 56.0541095584631, 52.660416662693024, 54.13041718304157, 54.36691269278526, 57.34491549432278, 57.367269694805145, 58.063874915242195, 60.853829607367516, 59.72053661942482, 58.85911904275417, 57.37613461911678, 61.67673625051975, 59.40797299146652, 59.794416055083275, 62.28168658912182, 61.46984115242958, 46.64966359734535, 43.84266681969166, 42.62337304651737, 43.41606751084328, 48.33451598882675, 45.06117783486843, 45.84342285990715, 43.252330496907234, 45.28301753103733, 41.975348219275475, 48.70808154344559, 62.80339479446411, 55.90572752058506, 56.446123123168945, 55.92071011662483, 55.41160203516483, 57.37939104437828, 55.278825759887695, 56.62457674741745, 53.6739856749773, 53.921348601579666, 51.44776493310928, 58.41439090669155, 53.40964525938034, 53.47089797258377, 48.843559473752975, 52.04894207417965, 49.536167308688164, 46.05221405625343, 46.17251560091972, 43.26562978327274, 44.69749554991722, 42.424833700060844, 45.1671427488327, 45.32429851591587, 46.65760897099972, 44.6764712780714, 44.93611514568329, 45.13690397143364, 47.45889097452164, 46.50768801569939, 46.45377270877361, 44.95527371764183, 47.73187592625618, 50.0599730014801, 46.12794019281864, 46.48320212960243, 47.54190891981125, 45.832133665680885, 49.98523861169815, 48.624926805496216, 50.56849591434002, 48.700044974684715, 48.57838310301304, 50.104635804891586, 47.5639059394598, 51.16519309580326, 50.43931804597378, 52.51358114182949, 53.440511003136635, 55.068305656313896, 54.12095949053764, 49.708522260189056, 55.239011496305466, 58.110069036483765, 57.78728015720844, 58.622205555438995, 60.55116064846516, 67.72208645939827, 73.80169183015823, 77.23540037870407, 75.73125869035721, 83.88373643159866, 11.70141700655222, 1.6459529288113117, 2.6131202559918165, 0.9726050135213882, 16.231729611754417, 88.44102948904037, 74.09847110509872, 75.7289408147335, 64.51350063085556, 68.26493293046951, 87.40116968750954, 65.07017835974693, 86.58162966370583, 14.255949631333351, 0.454515638994053, 0.3182062064297497, 0.19428201630944386, 0.23764858458889648, 0.16411923483246937], [0.04243623050570022, 0.05567097970924806, 0.03722314031620044, 0.042280735724489205, 0.04841705762373749, 0.03369442107214127, 0.10921134249656461, 0.16390367061831057, 28.341223821043968, 51.402608156204224, 44.6948204934597, 30.963204726576805, 29.300168864428997, 48.00821229815483, 49.47712987661362, 78.29621225595474, 12.235483098775148, 0.47559854050632566, 0.10223303179373033, 0.2577429305529222, 0.5279997177422047, 1.4189724647440016, 27.072764486074448, 57.856835424900055, 64.02239218354225, 67.8180693089962, 69.93256464600563, 62.05594450235367, 61.443432569503784, 59.00932498276234, 55.26918567717075, 52.64211304485798, 47.02652357518673, 48.30517776310444, 44.904709830880165, 46.55149586498737, 47.28364057838917, 48.94181840121746, 52.7767626196146, 54.315239265561104, 53.78189988434315, 56.63604453206062, 57.780816704034805, 58.89063075184822, 59.20428492128849, 58.00169125199318, 55.41503705084324, 53.33932623267174, 42.95445688068867, 41.43472082912922, 43.71084429323673, 41.34392470121384, 44.11325789988041, 46.945150941610336, 52.059133127331734, 52.6763492077589, 53.90050671994686, 48.79311338067055, 44.40285935997963, 42.37637870013714, 42.97105059027672, 41.65084183216095, 42.93212927877903, 39.678698256611824, 41.36116437613964, 42.77998924255371, 42.54197381436825, 42.12093360722065, 50.53560487926006, 52.13917203247547, 53.04446965456009, 54.27968457341194, 51.7922430485487, 51.175779327750206, 53.420444279909134, 52.09162898361683, 56.965505853295326, 52.780908197164536, 54.881906658411026, 57.28197567164898, 53.73645432293415, 54.58900697529316, 56.72810599207878, 56.123832017183304, 54.382461458444595, 41.155998185276985, 41.03494048118591, 42.34300509095192, 43.42949599027634, 41.894826740026474, 39.292095601558685, 42.200790122151375, 42.49839015305042, 37.22767777740955, 49.71239425241947, 56.047076135873795, 55.19954301416874, 54.09268140792847, 52.120036259293556, 51.5857545286417, 50.66697522997856, 52.21620909869671, 51.304140239953995, 48.89929108321667, 48.436434119939804, 49.50068861246109, 46.87819853425026, 48.760533928871155, 47.67293728888035, 48.514744117856026, 47.52641715109348, 43.280004411935806, 40.26319809257984, 41.27224154770374, 38.143698424100876, 37.72782973945141, 40.48913396894932, 41.75329573452473, 41.709423288702965, 40.16868196427822, 42.14719019830227, 40.256734639406204, 42.174662724137306, 41.94554261863232, 41.113748252391815, 40.98917953670025, 41.75090566277504, 42.28334069252014, 41.21763087809086, 42.55954787135124, 41.394370794296265, 42.62956291437149, 43.08966502547264, 43.044588044285774, 40.93857765197754, 40.820377394557, 41.94396570324898, 45.11768840253353, 43.703187704086304, 45.10480709373951, 44.04698945581913, 46.77814230322838, 48.16938064992428, 49.18301045894623, 49.341537952423096, 47.96877421438694, 48.130550533533096, 47.067705765366554, 48.55387821793556, 49.354233071208, 51.2307433784008, 52.95045129954815, 54.84479404985905, 64.4392754137516, 70.85182651877403, 75.33330604434013, 73.0870945751667, 5.269527789205313, 1.0366039699874818, 1.2135253264568746, 0.29239407274872065, 21.83262526988983, 73.23657095432281, 64.57788437604904, 57.49971158802509, 48.64645265042782, 39.10910502076149, 37.534800097346306, 48.96057419478893, 50.79395301640034, 11.356059238314629, 0.2825171558652073, 0.18013540509855375, 0.0912862793484237, 0.06977612341870554, 0.03643601849034894, 0.03519432750181295, 0.08762571014813147, 0.03456821090367157, 0.09639595125918277, 0.03309181942313444, 0.02005409187404439, 0.061883282687631436, 0.19805288349743932, 38.61706182360649, 59.849315509200096, 52.48037472367287, 30.50016537308693, 31.040939055383205, 57.703126072883606, 55.42476832866669, 87.40638300776482, 12.897928152233362, 0.4483211401384324, 0.0715402232890483, 0.24230438866652548, 1.8153001042082906, 1.891343048773706, 27.79164221137762, 57.596492394804955, 65.01694321632385, 68.4325723350048, 71.7679725587368, 65.55829256772995, 65.10224863886833, 61.618907153606415, 58.62443223595619, 56.123763620853424, 48.70429314672947, 50.22117555141449, 48.09760630130768, 48.30535255372524, 50.297027081251144, 51.854426711797714, 54.686236158013344, 56.9532211124897, 56.70849144458771, 59.87429536879063, 61.243297308683395, 60.71946121752262, 61.04082137346268, 59.55110751092434, 58.529566526412964, 56.147576943039894, 47.27932021021843, 43.22737343609333, 45.92343136668205, 43.99914622306824, 46.55902326107025, 50.02596862614155, 52.7512051910162, 55.75940117239952, 54.903250113129616, 53.58504764735699, 46.52971923351288, 45.56764505803585, 45.19600220024586, 43.079823553562164, 46.008542999625206, 42.38679014146328, 44.4575460255146, 45.00876344740391, 42.813701033592224, 44.738582745194435, 50.98695605993271, 52.451997846364975, 55.89072212576866, 55.77579349279404, 55.308863148093224, 54.971817433834076, 54.62664395570755, 54.29353483021259, 58.96900534629822, 56.0210095345974, 55.581460520625114, 57.40850888192654, 55.574050918221474, 55.379695147275925, 58.69282856583595, 58.213640078902245, 56.73008568584919, 42.46062017977238, 41.718675792217255, 43.493104577064514, 44.332924112677574, 40.89440882205963, 39.787752404809, 44.9318403750658, 44.00093212723732, 38.33996929228306, 50.133096277713776, 58.672233670949936, 54.85886849462986, 56.61377772688866, 55.016845017671585, 54.9089802056551, 54.142888113856316, 53.511745780706406, 53.8196774572134, 51.15630157291889, 51.71239033341408, 52.24365122616291, 50.897729247808456, 50.500061586499214, 50.18427573144436, 49.194558039307594, 48.18057864904404, 44.35873232781887, 43.685248866677284, 43.37778456509113, 41.849901750683784, 40.28436295688152, 41.21302932500839, 42.715130522847176, 44.208875969052315, 43.6133149266243, 45.885197818279266, 42.67623580992222, 45.06281554698944, 43.6741154640913, 43.269053399562836, 43.45574498176575, 44.12173144519329, 45.04182927310467, 43.79207633435726, 44.51555371284485, 44.87653814256191, 44.770987406373024, 45.462044924497604, 45.48583924770355, 43.963659927248955, 43.61802287399769, 45.373600870370865, 46.263224333524704, 46.977247819304466, 49.36844430863857, 45.74535772204399, 49.861057475209236, 50.453054308891296, 51.759295016527176, 52.40047641098499, 51.729812398552895, 50.32101519405842, 51.09640918672085, 51.82889208197594, 52.482730597257614, 53.46019774675369, 54.221418499946594, 57.64286890625954, 68.97779747843742, 74.65554401278496, 76.30466312170029, 76.92771568894386, 6.519953291863203, 1.1946389148943126, 1.6674071713350713, 0.5980614270083606, 25.021999329328537, 81.47324457764626, 70.13952434062958, 63.73895399272442, 54.591902419924736, 42.68192030489445, 52.484600096940994, 54.58445481956005, 65.12943997979164, 15.804215501993895, 0.2868973708245903, 0.15026213543023914, 0.015330580736190313, 0.1684633071999997, 0.03399022629309911, 0.1372735417680815, 0.17534105689264834, 0.15953440975863487, 0.10406951332697645, 0.1823135046288371, 0.1854427851503715, 0.1383825033553876, 0.2720762661192566, 50.821562334895134, 68.61506894230843, 64.624675065279, 39.885464161634445, 40.395225808024406, 66.99206203222275, 61.65098123252392, 94.36872661113739, 14.439662173390388, 0.5947646289132535, 0.4673674103105441, 2.4737309105694294, 2.3463790817186236, 2.7208803361281753, 31.7076113820076, 59.56008642911911, 67.91718319058418, 71.71265512704849, 76.75991669297218, 69.12393003702164, 69.034034460783, 64.6501412987709, 61.92956328392029, 59.00810144841671, 51.48641265928745, 53.08554545044899, 48.93693186342716, 51.26356601715088, 53.057293966412544, 54.434374272823334, 58.447399735450745, 60.44157072901726, 59.82072964310646, 62.97018684446812, 63.963715732097626, 61.866927444934845, 62.99186088144779, 63.08594383299351, 61.082847118377686, 58.39901693165302, 49.21782799065113, 45.534343644976616, 49.71747078001499, 45.5822628736496, 49.21035759150982, 53.330001533031464, 56.88189893960953, 58.708916902542114, 57.023901119828224, 54.46631535887718, 47.93772228062153, 46.78528591990471, 48.4101889282465, 46.08766235411167, 49.39766474068165, 45.0277928262949, 45.68193532526493, 47.677060067653656, 45.438117608428, 48.45602206885815, 55.28572618961334, 55.56047044694424, 58.15095864236355, 60.55258937180042, 57.770773842930794, 55.93041479587555, 56.444280222058296, 57.40626700222492, 62.45773494243622, 58.91773469746113, 59.005422592163086, 61.3373688608408, 58.0008514970541, 58.22988420724869, 61.8451052159071, 61.438021659851074, 60.18909327685833, 43.10224235057831, 42.423017397522926, 46.14142946898937, 45.367160215973854, 42.81511075794697, 42.40385502576828, 47.67300948500633, 45.41945680975914, 39.29372951388359, 52.15323127806187, 62.0039214938879, 57.98082657158375, 58.63685756921768, 57.25863352417946, 54.3462760001421, 57.08280935883522, 56.71839751303196, 56.81281104683876, 54.77639012038708, 54.80006664991379, 54.93149019777775, 54.157859310507774, 55.20209267735481, 54.83221672475338, 53.79224292933941, 52.45451711118221, 47.22364939749241, 46.740794107317924, 46.42397850751877, 43.14980819821358, 41.37323632836342, 44.090075343847275, 45.87016582489014, 47.02827148139477, 46.5143870562315, 48.86815935373306, 44.4981924444437, 48.99737522006035, 47.18644179403782, 46.693501845002174, 47.649241760373116, 47.522062584757805, 48.63420970737934, 45.4681321978569, 48.21537718176842, 46.303296983242035, 49.13228698074818, 48.183227106928825, 49.24871653318405, 46.19644671678543, 45.963789001107216, 47.63122692704201, 51.594908237457275, 49.41261313855648, 52.75896057486534, 48.48817974328995, 53.48945997655392, 54.825274497270584, 55.29148668050766, 54.14139859378338, 55.45401155948639, 53.384437412023544, 53.86999815702438, 54.091051295399666, 56.59948289394379, 57.037682980298996, 58.789977952837944, 61.04440078139305, 74.60433796048164, 77.04094961285591, 81.43806606531143, 77.65907004475594, 8.241543062031269, 1.7942096921615303, 3.431006418541074, 0.9139337274245918, 28.444981053471565, 89.04220283031464, 77.81372174620628, 73.06340664625168, 68.38961184024811, 52.06906199455261, 52.29611121118069, 70.58643355965614, 78.86610567569733, 20.244983062148094, 0.6906037987209857, 0.5696191219612956, 0.1358609230373986, 0.20185064611723647, 0.1462598517537117], [0.01725796886603348, 0.03195140932803042, 0.035941232345066965, 0.02920776172686601, 0.03430962809943594, 0.04843908085604198, 0.10536137720919214, 0.21024752757512033, 31.467538364231586, 54.537903517484665, 35.58586187660694, 48.777503818273544, 39.24769498407841, 46.149827018380165, 50.99268615245819, 79.39970344305038, 18.650178238749504, 0.2874941169284284, 0.3863756766077131, 0.21257502143271267, 2.1210153121501207, 0.6666438875254244, 9.660772606730461, 54.20471079647541, 68.02074283361435, 61.254814490675926, 61.963054686784744, 59.280710220336914, 58.88539843261242, 54.28148567676544, 51.1119769513607, 47.44315981864929, 47.81154625117779, 47.65843726694584, 50.14102265238762, 49.78009141981602, 54.03467372059822, 52.700284123420715, 56.48975618183613, 57.74449445307255, 59.39692698419094, 56.79178297519684, 60.75328700244427, 59.120355024933815, 57.451803758740425, 55.053041875362396, 53.92047464847565, 43.74702215194702, 41.017902195453644, 41.2698894739151, 40.93542002141476, 41.96167655289173, 47.761704325675964, 54.416606426239014, 56.495858654379845, 55.882347375154495, 57.6291174441576, 53.89378488063812, 50.44182971119881, 42.62320585548878, 43.348647728562355, 42.90913291275501, 46.338996067643166, 41.458735540509224, 40.802366361021996, 40.90337634086609, 43.39228458702564, 41.96098878979683, 47.53995202481747, 50.56803613901138, 49.655955880880356, 49.660405442118645, 50.58661334216595, 52.975925132632256, 51.5138927847147, 51.44079990684986, 52.2262367606163, 54.339105784893036, 51.971057653427124, 51.23778440058231, 54.33989994227886, 56.91222511231899, 58.67991305887699, 55.21392524242401, 55.278525575995445, 51.195990443229675, 40.41687324643135, 45.90847156941891, 46.45113945007324, 46.468884497880936, 33.559677600860596, 41.72151044011116, 42.22939878702164, 43.821619749069214, 52.29476988315582, 55.21997071802616, 54.36885818839073, 51.24151200056076, 52.736796364188194, 51.71476140618324, 50.6512326747179, 50.77408388257027, 50.76191693544388, 50.62920145690441, 48.97054485976696, 50.39801426231861, 51.0853935778141, 46.22565194964409, 46.36750593781471, 48.15611556172371, 44.604449942708015, 41.73545949161053, 42.00943998992443, 39.55178886651993, 40.217554941773415, 39.363011196255684, 40.73279209434986, 42.409828305244446, 44.04858537018299, 41.69070929288864, 42.778355330228806, 42.51401111483574, 43.34321402013302, 41.062424406409264, 43.88515993952751, 41.37238137423992, 40.84853768348694, 42.502721920609474, 43.118456080555916, 43.89210216701031, 43.31256866455078, 41.93752124905586, 42.092032358050346, 41.51552349328995, 40.818067118525505, 40.163404047489166, 42.99886129796505, 43.75158190727234, 44.42400902509689, 43.84248822927475, 44.840215891599655, 45.6542956084013, 48.09504143893719, 49.665884748101234, 50.98230130970478, 50.11602759361267, 48.858564868569374, 47.846204191446304, 46.81937389075756, 50.876454189419746, 51.5088352560997, 53.057062178850174, 59.78019341826439, 65.37100821733475, 70.43470770120621, 70.4578484594822, 68.84844481945038, 5.556214330717921, 0.960745137417689, 1.2037351517938077, 0.17026521207299083, 35.30504934489727, 70.0433287024498, 61.43733769655228, 56.10497742891312, 47.80487380921841, 30.681269355118275, 32.02944651246071, 52.2945798933506, 46.99018232524395, 10.503112357109785, 0.18943917617434636, 0.09198993182508275, 0.02737796508881729, 0.06078451078792568, 0.020968818571418524, 0.058116838699788786, 0.05192490396439098, 0.17148297250969335, 0.026982661984220613, 0.025643168919486925, 0.0325750916817924, 0.033724414970492944, 0.26855489413719624, 41.457390412688255, 66.06003284454346, 46.542425751686096, 51.6943147033453, 40.92481479048729, 53.74142825603485, 56.00215494632721, 89.7278380393982, 20.205136500298977, 0.43368548329453915, 0.46826386533211917, 0.7744229072704911, 0.04382845501822885, 0.610827257623896, 9.906005747616291, 57.95484356582165, 69.68902051448822, 66.42695635557175, 63.46026934683323, 62.05625228583813, 60.241792649030685, 57.10128776729107, 52.05914832651615, 49.69979792833328, 51.35452173650265, 48.64037297666073, 51.83197371661663, 52.692874521017075, 57.12512768805027, 55.084606781601906, 60.50098054111004, 60.35995110869408, 62.32169084250927, 58.936418294906616, 62.37213313579559, 62.11997486650944, 60.10021984577179, 57.916777208447456, 56.998279094696045, 46.53169892728329, 42.7029749751091, 44.93154019117355, 43.73608633875847, 44.26725223660469, 50.07710628211498, 55.49909994006157, 58.435445576906204, 59.68372419476509, 59.84412118792534, 57.482065334916115, 50.828010588884354, 44.78035390377045, 44.37843807041645, 44.87758308649063, 50.753614380955696, 43.57594013214111, 43.58808808028698, 41.38851910829544, 45.47133542597294, 44.271002635359764, 49.923149943351746, 51.976460963487625, 51.57753936946392, 51.65504761040211, 52.38609418272972, 54.61834140121937, 52.4128333479166, 55.10530047118664, 55.21347686648369, 55.48224784433842, 54.13308843970299, 54.45776201784611, 54.997010082006454, 57.041205391287804, 60.545654743909836, 56.98190197348595, 56.907338574528694, 51.12091027200222, 39.98628795146942, 49.038686603307724, 47.18271039426327, 46.31511814892292, 35.863231793046, 42.98828266561031, 42.180339619517326, 43.403554782271385, 54.51496034860611, 55.66796287894249, 58.94914761185646, 53.29798065125942, 56.68002337217331, 53.812245056033134, 53.856888860464096, 53.24834391474724, 54.467500895261765, 54.049477726221085, 51.32175229489803, 54.95668284595013, 53.62567126750946, 47.68193520605564, 48.22646118700504, 50.599604845047, 48.18771466612816, 43.76247592270374, 43.7539491802454, 40.87016612291336, 42.16542921960354, 41.28680996596813, 43.2162856310606, 44.174806997179985, 46.34328983724117, 43.241010904312134, 44.33817923069, 44.60441954433918, 43.64019088447094, 43.786581829190254, 46.536148488521576, 44.4737521559, 42.310311645269394, 45.4586973041296, 45.03867544233799, 46.31769061088562, 46.21541529893875, 45.17905130982399, 43.83876822888851, 45.62889017164707, 44.10986088216305, 42.845592722296715, 45.04086032509804, 46.711767464876175, 47.615104392170906, 46.69817939400673, 46.98236994445324, 49.95704412460327, 50.75938627123833, 52.654302790760994, 53.56042496860027, 53.01387369632721, 51.75647556781769, 52.903816401958466, 50.661131143569946, 53.330499306321144, 53.810162767767906, 56.31307706236839, 61.654313653707504, 69.78001803159714, 72.09522619843483, 75.39183810353279, 74.68129903078079, 6.391510684043169, 1.173708331771195, 1.711457495111972, 0.17477751447586343, 40.983483642339706, 77.30005010962486, 68.57939645648003, 66.28444120287895, 58.171998113393784, 33.58905382454395, 37.928185388445854, 66.34638547897339, 62.29746334254742, 15.410787463188171, 0.27963017171714455, 0.16113096236949787, 0.16372956277336925, 0.111415817955276, 0.011159797995787812, 0.14611375256208703, 0.25030949036590755, 0.30612303293310106, 0.15701673313742504, 0.12363730551442131, 0.17277462116908282, 0.11000403785146773, 0.44076245510950685, 51.08855880796909, 77.30897963047028, 51.768710911273956, 64.96972694993019, 51.20188392698765, 64.75781232118607, 60.692657455801964, 99.51690316200256, 22.630838938057423, 0.7191263150889426, 0.7868890289682895, 1.730936081148684, 6.663537612184882, 1.1459978437051177, 14.025716185569763, 65.23237645626068, 74.08264875411987, 68.98654460906982, 67.35862076282501, 66.0216473042965, 63.64207059144974, 61.40062786638737, 55.94036266207695, 53.456899523735046, 54.46205198764801, 51.864838153123856, 55.03974638879299, 55.111539736390114, 60.55687174201012, 57.63144671916962, 61.06567203998566, 63.813433796167374, 65.84105059504509, 60.67589655518532, 65.87023302912712, 64.34988901019096, 63.16965714097023, 61.96219213306904, 59.837695732712746, 49.99692678451538, 45.45779675245285, 46.39028191566467, 46.128380969166756, 45.49100697040558, 53.35616692900658, 59.491215124726295, 60.99028028547764, 60.743551924824715, 63.816306442022324, 61.456621661782265, 55.23739658296108, 47.80851401388645, 47.79845975339413, 47.30007089674473, 52.70272359251976, 47.36308291554451, 46.7507191747427, 44.1272297501564, 47.94455051422119, 44.83084559440613, 52.28702209889889, 54.31751534342766, 52.070752903819084, 54.10767160356045, 56.10380709171295, 58.22096608579159, 55.26781015098095, 57.233212888240814, 57.73026421666145, 59.045434445142746, 55.218568593263626, 57.81018152832985, 59.009169191122055, 59.80057932436466, 63.0636428296566, 57.945469468832016, 61.03362835943699, 54.93489861488342, 41.35381557047367, 50.05375653505325, 49.56572972238064, 49.22441303730011, 38.06530483067036, 44.794758930802345, 43.30965802073479, 44.009854048490524, 55.46217352151871, 56.28523975610733, 61.47039972245693, 55.536493733525276, 57.67431601881981, 57.397326081991196, 55.78548677265644, 57.51457639038563, 55.973132103681564, 57.11355730891228, 55.264530926942825, 56.56675145030022, 57.044036239385605, 49.968606904149055, 50.564110949635506, 54.30907979607582, 52.101641446352005, 47.09840811789036, 46.09635628759861, 44.02001850306988, 45.40110379457474, 44.522393345832825, 47.28267543017864, 47.368087247014046, 48.4582145512104, 48.20715442299843, 48.386193215847015, 47.19416297972202, 46.86487264931202, 46.39239460229874, 49.182759672403336, 46.72959230840206, 45.10534666478634, 48.97432565689087, 45.73997341096401, 49.45793330669403, 48.93361084163189, 48.18968676030636, 46.9133086502552, 48.740999177098274, 46.902771815657616, 43.77675175666809, 49.12577413022518, 48.7947890907526, 51.32751278579235, 51.549717262387276, 51.8765377253294, 53.23789827525616, 54.347567930817604, 57.16493435204029, 57.3577094078064, 56.017441526055336, 55.500958040356636, 56.13632954657078, 53.27773913741112, 58.71783122420311, 57.949748039245605, 58.664884865283966, 65.84250971674919, 73.04493203759193, 76.91999450325966, 77.62176364660263, 74.68086585402489, 7.685351707041264, 1.0186908999457955, 3.047546907328069, 0.46561410126741976, 44.807811230421066, 85.2824717760086, 77.5602525472641, 75.6805694103241, 68.81576657295227, 46.01704694330692, 51.34938821196556, 73.09222429990768, 77.93144702911377, 23.007075749337673, 0.703028894495219, 0.2825626346748322, 0.1690019282978028, 0.19635113887488842, 0.08338616185938008], [0.0651539460523054, 0.015431796691700583, 0.0398669634887483, 0.04936978599289432, 0.0541807842819253, 0.06254523759707808, 0.016184543164854404, 0.512187103740871, 40.27097247540951, 57.040133848786354, 42.98386350274086, 24.63131569325924, 24.209678918123245, 50.355141162872314, 46.608162224292755, 78.0962897837162, 27.3122276365757, 0.26495351863559335, 0.15320304402848706, 0.4300511861220002, 0.3752849326701835, 0.12569511774927378, 5.23667142726481, 59.62540492415428, 67.92751863598824, 64.07812759280205, 62.43964031338692, 58.706979006528854, 51.81706331670284, 50.103374272584915, 47.80582755804062, 47.22618006169796, 48.25769931077957, 51.89418017864227, 55.12668952345848, 58.775975704193115, 58.15557539463043, 58.81921738386154, 61.332178339362144, 59.84779939055443, 58.8070048391819, 62.15535096824169, 58.623843267560005, 57.981278747320175, 54.72287759184837, 52.28081323206425, 44.97346714138985, 43.511377796530724, 43.17844346165657, 42.053692415356636, 45.17729580402374, 51.466186344623566, 53.16542476415634, 53.42617817223072, 56.245866268873215, 56.35121561586857, 56.9580240547657, 53.9993242174387, 52.410887852311134, 44.90132421255112, 41.6564579308033, 44.80637110769749, 42.52292923629284, 40.72754077613354, 40.592420026659966, 42.62337304651737, 45.45653522014618, 40.745187029242516, 44.31449510157108, 46.41739346086979, 46.315954104065895, 47.902243584394455, 49.26554962992668, 49.13228698074818, 50.22836856544018, 53.568754121661186, 53.23749169707298, 54.99382205307484, 52.26922765374184, 51.75748251378536, 53.24747756123543, 54.94215242564678, 53.80657196044922, 54.06602963805199, 54.590880274772644, 53.51718328893185, 41.49988353252411, 46.729105934500694, 51.63612462580204, 43.555360436439514, 35.92004634439945, 45.33763200044632, 44.16239306330681, 49.88667190074921, 55.881283432245255, 53.26481983065605, 55.60658097267151, 52.33752898871899, 54.31778892874718, 53.119086250662804, 50.52695274353027, 51.91751092672348, 49.79453444480896, 50.87113447487354, 50.29830381274223, 49.6707446873188, 47.67047122120857, 46.511674001812935, 46.74846209585667, 45.56842781603336, 43.83591838181019, 41.81869402527809, 41.3530708104372, 38.82611520588398, 38.69106665253639, 39.826183542609215, 41.99246630072594, 41.666333600878716, 44.79979366064072, 40.68631298840046, 41.87556937336922, 44.103838205337524, 48.36022160947323, 46.357466876506805, 42.54050709307194, 40.69373399019241, 41.49769105017185, 41.897467598319054, 45.95894046127796, 44.87570978701115, 46.71449191868305, 46.84180028736591, 45.56015565991402, 42.41430066525936, 44.698407500982285, 42.46615268290043, 42.983388528227806, 42.355126440525055, 44.66741256415844, 44.49175179004669, 42.739517614245415, 46.16264373064041, 48.880542889237404, 49.90163929760456, 50.35763002932072, 51.97628617286682, 50.922690108418465, 51.15600138902664, 51.33641570806503, 54.55309510231018, 55.24598032236099, 60.96957519650459, 62.674547508358955, 68.3290658891201, 67.03260585665703, 80.64743489027023, 75.83854973316193, 2.880133828148246, 0.36940617312211543, 1.0440470580942929, 0.15042606100905687, 40.68516165018082, 70.19563972949982, 62.83257722854614, 50.00245548784733, 45.61809495091438, 31.02308191359043, 43.942719250917435, 51.229322254657745, 46.67147442698479, 19.857797138392925, 0.19358381861820817, 0.0906454051437322, 0.08821910916594788, 0.022583503705391195, 0.06268040495342575, 0.04492415442655329, 0.05570954170252662, 0.07187660172348842, 0.03521533028106205, 0.028650368003582116, 0.06631309908698313, 0.03715716709848493, 0.5234622862190008, 48.48835453391075, 68.86284604668617, 47.80537538230419, 27.2485164552927, 34.10399079322815, 56.84640884399414, 53.761445581912994, 83.62413436174393, 30.441876500844955, 0.14951356075471267, 0.39753710268996656, 0.45156827371101826, 0.5801046593114734, 0.06887467374326661, 6.205577636137605, 63.4078511595726, 71.14579394459724, 67.21513286232948, 64.0527069568634, 61.35823734104633, 53.63808140158653, 52.11832635104656, 49.78252708911896, 50.092354863882065, 50.846002623438835, 54.144970402121544, 57.35926352441311, 61.72597020864487, 59.92577500641346, 60.885189324617386, 60.88093355298042, 62.708787471055984, 62.06272713840008, 63.60307328402996, 60.786729007959366, 60.29546856880188, 57.28172108530998, 55.84996171295643, 47.977183163166046, 45.154538825154305, 44.7108518332243, 43.82791221141815, 46.89669594168663, 53.14372792840004, 56.114598512649536, 55.476817935705185, 57.39653952419758, 58.42397019267082, 56.21261425316334, 57.226251661777496, 53.482118770480156, 46.60349227488041, 43.38322587311268, 47.161347940564156, 45.849532932043076, 43.33598680794239, 43.12563009560108, 44.63336639106274, 44.56495866179466, 43.07182498276234, 46.760860830545425, 50.61961077153683, 49.81353722512722, 49.79710690677166, 51.27754166722298, 50.566322430968285, 51.07199169695377, 57.46719293296337, 55.54073050618172, 56.11539267003536, 54.46906641125679, 53.32794204354286, 55.51271840929985, 55.99960908293724, 56.393112167716026, 56.138780415058136, 57.10587032139301, 54.99843880534172, 43.022146448493004, 46.38003006577492, 51.81440345942974, 46.44534096121788, 39.05425876379013, 46.75435557961464, 43.70610974729061, 52.528248354792595, 58.37657153606415, 54.97436709702015, 56.34393900632858, 54.12625640630722, 55.876138508319855, 53.53270165622234, 53.69792439043522, 54.67148154973984, 51.57669961452484, 52.830035760998726, 53.04832264780998, 52.741933688521385, 49.82826143503189, 49.65467154979706, 50.48884078860283, 48.14227670431137, 45.31305491924286, 42.66336590051651, 43.81250783801079, 41.605354472994804, 41.07043817639351, 42.33172349631786, 43.164057433605194, 44.93433304131031, 46.84704400599003, 42.315319776535034, 44.81251917779446, 47.97209523618221, 49.3216460198164, 47.768274173140526, 43.48320610821247, 43.563712388277054, 44.29732762277126, 45.152532532811165, 47.74170219898224, 47.52604477107525, 49.67859126627445, 50.12429594993591, 47.97220163047314, 45.677535161376, 45.96842095255852, 44.19863551855087, 45.49077518284321, 44.36374045908451, 46.79429903626442, 47.12976023554802, 47.44677722454071, 47.72235743701458, 52.42427073419094, 52.909227311611176, 54.32589769363403, 54.867448434233665, 54.232969880104065, 55.45082353055477, 54.367668852210045, 57.89189614355564, 59.494422152638435, 63.40455673635006, 65.57618960738182, 70.13935714960098, 70.81976383924484, 82.87776321172714, 85.4645124077797, 3.2332310685887933, 0.5154760053846985, 1.6424908395856619, 0.208564069471322, 46.91056899726391, 76.95923879742622, 69.28178876638412, 60.352385714650154, 54.70296286046505, 37.55949877202511, 56.58263459801674, 62.06958957016468, 60.9636665135622, 25.27986489236355, 0.27476462186314166, 0.11703561991453171, 0.0511271100549493, 0.04040781102958135, 0.04322220200265292, 0.20396498031914234, 0.14100311585934833, 0.21039855462731794, 0.1061338564613834, 0.18717333994572982, 0.1320261717773974, 0.22276668314589188, 1.0489148343913257, 62.81387083232403, 74.14341509342194, 59.439378306269646, 33.459108397364616, 35.69263234734535, 69.38143461942673, 59.74158748984337, 91.01327106356621, 33.76931995153427, 0.4162395210005343, 0.7700638880487531, 1.0123223229311407, 3.4379491209983826, 0.6885941815562546, 8.766044117510319, 67.98050299286842, 74.80508878827095, 69.72382664680481, 68.6997663974762, 65.20727500319481, 57.08027109503746, 55.027598440647125, 52.94822461903095, 53.51074643433094, 53.830845057964325, 56.968454495072365, 60.997207313776016, 64.3521536886692, 64.01083320379257, 63.718773275613785, 64.40312415361404, 66.06938034296036, 64.49064865708351, 65.80994546413422, 62.769132032990456, 63.39822247624397, 61.43058925867081, 58.44063229858875, 50.432448014616966, 48.64888831973076, 48.927519768476486, 46.356995701789856, 51.09133645892143, 54.98079255223274, 57.06575587391853, 57.099836245179176, 59.47834901511669, 61.73133172094822, 59.67293277382851, 58.550036028027534, 57.6367512345314, 48.443003967404366, 44.62529942393303, 50.3603582829237, 48.53106424212456, 44.835800528526306, 44.79210667312145, 47.981374338269234, 49.164125472307205, 44.99197214841843, 50.5117953568697, 52.490998953580856, 52.790590077638626, 53.350034058094025, 52.62214131653309, 53.29129680991173, 53.92340049147606, 60.12640044093132, 60.72711020708084, 59.40035820007324, 58.35476070642471, 54.90691311657429, 57.58363388478756, 57.48966492712498, 60.00642567873001, 57.35684685409069, 58.45509052276611, 57.69199647009373, 42.67260700464249, 47.9042536765337, 54.41622644662857, 47.00115233659744, 40.713587924838066, 49.952974542975426, 44.56492446362972, 54.12868067622185, 60.72001978754997, 58.018049374222755, 58.717827424407005, 57.966641932725906, 60.70506379008293, 56.96556285023689, 55.94041585922241, 57.819130048155785, 55.27439899742603, 56.600220054388046, 56.42664536833763, 55.35561963915825, 53.847301974892616, 53.96637238562107, 51.07954189181328, 50.55294334888458, 47.6981945335865, 45.41846506297588, 45.579842403531075, 42.376599088311195, 42.88770206272602, 43.96491006016731, 44.74272832274437, 48.652125746011734, 49.55694079399109, 45.309749096632004, 47.28226125240326, 48.77417899668217, 52.81237430870533, 51.31884925067425, 48.24454441666603, 45.13384513556957, 46.56499654054642, 46.50368683040142, 51.93665809929371, 50.792235508561134, 52.020853981375694, 52.2087386995554, 51.43370948731899, 47.83652611076832, 49.37932692468166, 47.70576752722263, 48.868710324168205, 46.83050349354744, 51.43850103020668, 50.5523581802845, 48.37467223405838, 51.12730152904987, 56.699896305799484, 55.3975123912096, 56.96062311530113, 58.52339185774326, 57.811815440654755, 57.776047959923744, 56.87588386237621, 62.419075816869736, 62.20420114696026, 67.69103452563286, 69.87949669361115, 73.06899234652519, 75.08420661091805, 84.6054545044899, 77.38396480679512, 4.629260720685124, 0.5197353393305093, 2.890404677018523, 0.41466376336757094, 51.189773976802826, 83.90617042779922, 76.0273540019989, 68.19900646805763, 65.50785407423973, 46.884069219231606, 64.74911838769913, 71.68756887316704, 78.06092128157616, 33.51985573768616, 0.4476096876896918, 0.266926918993704, 0.13982507516629994, 0.16836805996717885, 0.08583132323110476], [0.04594723097397946, 0.0293568443521508, 0.009022190970426891, 0.11560973158339038, 0.07953453416121192, 0.07622796198120341, 0.09775425220141187, 0.2952544286381453, 33.9934129267931, 57.56579004228115, 54.826577827334404, 43.78824234008789, 27.739013135433197, 45.84707826375961, 48.72622177004814, 72.67220243811607, 42.12145797908306, 0.07747816911432892, 0.3115775511832908, 0.04997500371246133, 0.01622365805815207, 0.08747900981688872, 5.875740135088563, 58.88811908662319, 64.90269854664803, 61.57696880400181, 55.3378289937973, 51.06005273759365, 50.768517181277275, 49.802753403782845, 47.357546612620354, 51.55422382056713, 57.03483313322067, 60.024360716342926, 56.159162521362305, 60.7578581571579, 59.967728555202484, 63.618470057845116, 59.81290206313133, 59.884224236011505, 59.19170759618282, 57.987016439437866, 59.13927420973778, 55.37736967206001, 51.52282990515232, 45.87311066687107, 40.85864894092083, 43.38974632322788, 41.638522893190384, 43.411701545119286, 47.479083091020584, 52.50533178448677, 51.82785853743553, 56.693208664655685, 53.77759471535683, 53.46938945353031, 56.254955381155014, 57.16997288167477, 52.71710582077503, 45.22001691162586, 41.28839448094368, 44.17289949953556, 41.04306064546108, 40.971939861774445, 39.237625524401665, 41.78916200995445, 41.481648311018944, 41.91869705915451, 43.646703734993935, 45.22551141679287, 47.82430976629257, 47.708229795098305, 46.66334666311741, 47.52826385200024, 50.44650726020336, 51.2441186606884, 53.23131702840328, 49.39178265631199, 51.14939734339714, 50.61332210898399, 53.5446710139513, 55.788355618715286, 55.25229558348656, 55.89720457792282, 55.96256487071514, 53.89036126434803, 46.38873539865017, 42.22728990018368, 45.46552553772926, 44.289640635252, 39.47301909327507, 45.26343338191509, 42.44264334440231, 55.05971811711788, 57.89409622550011, 55.31924419105053, 54.332467541098595, 51.61574251949787, 49.77842330932617, 49.414281249046326, 51.08484260737896, 50.46262599527836, 51.75410069525242, 49.26529124379158, 47.89094679057598, 49.54796947538853, 44.4028327614069, 45.47338351607323, 44.954403564333916, 46.183800995349884, 42.37086519598961, 39.681529104709625, 40.21730795502663, 38.92981544137001, 39.150621592998505, 40.53556367754936, 42.832874804735184, 43.67277413606644, 41.136319041252136, 40.92816241085529, 46.91829778254032, 50.911070331931114, 51.586700677871704, 53.43309000134468, 50.27542144060135, 44.28006894886494, 42.44284853339195, 41.76148049533367, 46.073413118720055, 46.946435272693634, 50.8084150403738, 50.64212456345558, 49.82804864645004, 46.90714918076992, 45.70196785032749, 43.54375205934048, 42.720773220062256, 42.115697488188744, 43.64226557314396, 43.375538885593414, 44.60558608174324, 44.233882427215576, 45.504982620477676, 49.52302761375904, 53.18615645170212, 52.29410111904144, 53.47010761499405, 53.391923010349274, 58.59321691095829, 61.93739466369152, 61.8434789031744, 62.83821992576122, 69.37338665127754, 69.58403214812279, 77.35412880778313, 63.257462829351425, 48.489942848682404, 3.5720265889540315, 0.22464020526967943, 1.9450355926528573, 0.4436614323640242, 53.05428072810173, 66.07063427567482, 65.94925358891487, 47.12256342172623, 47.517544627189636, 31.918051689863205, 25.386454872787, 48.665778413414955, 56.79040364921093, 19.599236212670803, 0.4771469277329743, 0.2431940456153825, 0.12402153020957485, 0.06717002732330002, 0.12462431739550084, 0.06873575111967511, 0.04557453554298263, 0.04104960920813028, 0.11150565493153408, 0.03179077888489701, 0.09039513068273664, 0.07334906724281609, 0.27813480352051556, 42.92754292488098, 63.51473182439804, 64.47422593832016, 45.35471208393574, 29.974260292947292, 54.28394414484501, 55.22051028907299, 78.92672002315521, 46.453586518764496, 0.10371107826358639, 0.3356809343677014, 0.09252605930669233, 0.04852965255849995, 0.055461590163758956, 7.092168387025595, 62.492890655994415, 67.10876896977425, 65.18848121166229, 58.93874377012253, 54.48713444173336, 51.898435950279236, 50.08909083902836, 51.38686940073967, 54.14288431406021, 57.57883094251156, 61.57745137810707, 60.718940645456314, 62.72736847400665, 62.578462064266205, 63.29184718430042, 62.42025375366211, 62.978082820773125, 64.04547214508057, 61.396539285779, 60.93565061688423, 57.46805928647518, 53.41529555618763, 48.25147904455662, 41.750404089689255, 44.18621398508549, 44.070893973112106, 45.23136310279369, 50.108477398753166, 53.67618575692177, 53.62622983753681, 57.66835413873196, 57.543618232011795, 55.11294566094875, 56.832049414515495, 58.387511149048805, 54.214909449219704, 47.70662248134613, 44.403284937143326, 48.06384511291981, 43.05483989417553, 44.017905816435814, 42.47706949710846, 41.78759269416332, 44.71432864665985, 43.29420045018196, 46.2656220048666, 47.88994364440441, 49.97379742562771, 50.90270698070526, 49.522457644343376, 50.5472968518734, 51.05848342180252, 52.98414409160614, 54.28234823048115, 50.804995223879814, 54.436665549874306, 55.915242210030556, 55.413319543004036, 55.85856445133686, 58.20827856659889, 56.764219254255295, 55.98042011260986, 55.31919099390507, 47.64225013554096, 43.258007392287254, 46.376804038882256, 44.72684897482395, 40.552012994885445, 47.78421051800251, 45.16951002180576, 57.680049911141396, 59.811583533883095, 57.70987831056118, 57.36648693680763, 52.16939181089401, 52.39877790212631, 53.30629080533981, 52.51875266432762, 52.21367843449116, 54.18315835297108, 52.969784662127495, 50.714518278837204, 50.29701568186283, 47.55901180207729, 49.11100432276726, 46.32407046854496, 48.13026174902916, 44.19939547777176, 41.18016108870506, 42.32399471104145, 42.13074088096619, 42.66683891415596, 42.693958058953285, 45.355928018689156, 45.83052255213261, 42.61084891855717, 43.173241540789604, 48.689994513988495, 53.54553356766701, 54.43845525383949, 57.81548224389553, 54.18229199945927, 44.80753764510155, 44.14182096719742, 44.456732869148254, 49.61231902241707, 49.414186254143715, 53.0195277929306, 52.9878830909729, 52.97036603093147, 49.1986808180809, 48.12975637614727, 46.474971771240234, 45.80030657351017, 44.0846948325634, 46.394347697496414, 47.01959654688835, 48.74139055609703, 47.24871665239334, 49.0478403121233, 53.49826790392399, 53.98302689194679, 55.138989463448524, 54.764880537986755, 58.085545152425766, 62.6686692237854, 65.75431644916534, 65.76496347784996, 66.054158359766, 70.92606693506241, 72.52967208623886, 79.44554418325424, 67.06667482852936, 55.32068431377411, 3.88853226788342, 0.2205565376789309, 2.477286094799638, 0.5251290311571211, 60.408261716365814, 70.87483808398247, 74.97186943888664, 53.22527155280113, 59.29689735174179, 31.349947974085808, 33.0248448997736, 60.26119440793991, 69.61709037423134, 26.5381882712245, 0.7241896621417254, 0.09342621764517389, 0.02234394400147721, 0.10417369601782411, 0.06445533275837079, 0.129034114361275, 0.1873888893169351, 0.2609549160115421, 0.19745903176954016, 0.16994865640299395, 0.15503206697758287, 0.35447710077278316, 0.5183790496084839, 55.751018822193146, 74.70664367079735, 70.65541505813599, 53.13422843813896, 41.4190960675478, 63.66638168692589, 61.59864664077759, 86.13038867712021, 51.75729252398014, 0.19172568863723427, 0.976839589420706, 0.21345744986319914, 0.4404364444781095, 0.5642604595050216, 8.597899340093136, 65.64499631524086, 70.09717181324959, 69.22381147742271, 60.96596159040928, 56.89479544758797, 55.53284212946892, 54.634589329361916, 53.40238004922867, 58.69551882147789, 61.49496540427208, 67.5927186012268, 61.26533232629299, 66.78001061081886, 66.14910006523132, 66.03531137108803, 65.82028090953827, 65.50048246979713, 65.23296162486076, 63.065276741981506, 64.38426196575165, 60.49205482006073, 55.74601449072361, 49.67698775231838, 45.266317427158356, 48.01499493420124, 47.18203403055668, 48.61540071666241, 52.52431556582451, 56.10896721482277, 56.00213214755058, 62.37984672188759, 57.8441821038723, 58.00699196755886, 58.984953090548515, 62.675961032509804, 57.515568137168884, 51.334523409605026, 46.10481083393097, 51.042889058589935, 45.42504630982876, 46.09205111861229, 46.01868465542793, 44.182353392243385, 48.6145343631506, 46.081620678305626, 49.26030971109867, 50.845702439546585, 52.91836202144623, 52.27963909506798, 51.93677209317684, 51.09601400792599, 53.90531726181507, 55.27178853750229, 59.781527146697044, 52.6357027888298, 57.64724627137184, 56.67244277894497, 58.79941284656525, 58.7799046933651, 62.12563656270504, 60.72354979813099, 59.58723597228527, 59.23323176801205, 50.88215008378029, 43.930423110723495, 48.30815300345421, 46.47178754210472, 42.79399909079075, 48.3030840754509, 44.435723796486855, 59.900380969047546, 62.68814317882061, 59.0170081704855, 60.26768445968628, 55.4659391194582, 54.687163308262825, 54.24919880926609, 55.34992374479771, 54.23031762242317, 57.077128663659096, 55.200413167476654, 53.81553567945957, 52.91333869099617, 51.2715569883585, 52.05691784620285, 50.650126934051514, 52.882138565182686, 46.539336517453194, 43.40059854090214, 43.79715286195278, 43.012156784534454, 45.10909706354141, 45.735611245036125, 45.879133343696594, 50.72087533771992, 46.719108670949936, 44.852401837706566, 51.4935676753521, 55.85761070251465, 57.94771134853363, 59.39367815852165, 57.91986644268036, 47.80120700597763, 47.31029614806175, 46.67755410075188, 52.986876145005226, 52.49444156885147, 57.56560005247593, 55.86737997829914, 54.70608249306679, 51.47418491542339, 50.80705091357231, 48.921155110001564, 47.18545004725456, 47.86131218075752, 48.396441265940666, 49.864674881100655, 51.09048530459404, 49.40169632434845, 51.83886654675007, 56.1707329005003, 56.727707013487816, 59.1178547590971, 59.49059195816517, 60.64431644976139, 66.00349947810173, 69.62544992566109, 68.88309895992279, 68.81935358047485, 75.71219891309738, 76.45733132958412, 82.9982091486454, 69.3702632188797, 58.47883924841881, 4.797297203913331, 0.20982358313631266, 4.07896569930017, 0.8272224990651011, 63.991902619600296, 78.14618110656738, 81.72900125384331, 63.087133169174194, 71.10828995704651, 41.68562136590481, 38.139366656541824, 71.05268374085426, 84.20522198081017, 32.48346894979477, 0.7174380181822926, 0.27605619630776346, 0.1933684473624453, 0.16280947776976973, 0.35125825786963105], [0.06810398306697607, 0.028664496639976278, 0.05713795333576854, 0.05866117433470208, 0.017288270755670965, 0.1439865049906075, 0.07765789501718245, 0.4142179701011628, 38.513255193829536, 52.21083618700504, 41.34128004312515, 27.57695183157921, 27.74283193051815, 43.786213248968124, 50.95382943749428, 65.45825153589249, 56.765590980648994, 1.4365713391453028, 0.3533615043852478, 0.019676917581818998, 0.0698086665943265, 0.1015288449707441, 3.0490293027833104, 57.02698275446892, 66.7750708758831, 64.95307624340057, 56.641474440693855, 56.010898277163506, 51.76646523177624, 52.52111613750458, 56.46796055138111, 58.60602982342243, 58.960881382226944, 58.65094341337681, 60.41334584355354, 61.783062145113945, 61.56098686158657, 60.39861783385277, 58.39595049619675, 60.195511132478714, 57.66550049185753, 56.092772483825684, 54.10508394241333, 51.95351779460907, 44.10307064652443, 43.71419571340084, 41.185659393668175, 41.437118500471115, 44.427911415696144, 48.50296474993229, 52.7188803255558, 59.1492410749197, 57.30745330452919, 56.564365178346634, 54.08510461449623, 56.81350640952587, 58.27271930873394, 55.276819467544556, 47.73532994091511, 45.955410450696945, 43.76845300197601, 42.89527125656605, 42.588475719094276, 40.95154255628586, 41.506320387125015, 39.945926517248154, 40.70290669798851, 41.031684055924416, 41.93885877728462, 42.75915116071701, 47.05057628452778, 47.803809866309166, 48.25763091444969, 48.112053126096725, 48.4671326726675, 49.53831419348717, 48.95532667636871, 50.671428591012955, 50.09300082921982, 51.34750351309776, 55.246668085455894, 53.7308382242918, 52.5471181422472, 54.559737145900726, 56.70903101563454, 50.60734882950783, 52.86017194390297, 45.76573222875595, 44.22700859606266, 44.55440282821655, 39.3106310069561, 42.73900464177132, 49.10101845860481, 53.26253995299339, 56.576174944639206, 55.87572433054447, 53.56065675616264, 54.39685508608818, 50.33648036420345, 50.26472121477127, 50.01827783882618, 49.97898794710636, 49.60900940001011, 50.1614997535944, 47.927926406264305, 47.14830324053764, 46.934446915984154, 43.19549314677715, 44.13243927061558, 42.372860088944435, 37.7457419782877, 40.25360740721226, 38.855396434664726, 41.025733575224876, 37.91417934000492, 40.369789972901344, 44.89602729678154, 42.23143547773361, 41.40236556529999, 43.26724089682102, 49.40230429172516, 57.79877074062824, 56.63854859769344, 52.4693401157856, 54.414489939808846, 50.944204553961754, 43.808586448431015, 43.38646709918976, 44.68906760215759, 47.52089224755764, 49.22455742955208, 52.26914785802364, 52.22473204135895, 54.07831057906151, 50.97615323960781, 46.76925837993622, 45.239304676651955, 44.425810128450394, 44.13962848484516, 44.437019526958466, 44.59430828690529, 46.27602204680443, 47.59639419615269, 48.16505268216133, 54.95648145675659, 54.00342799723148, 58.753773495554924, 58.058095425367355, 63.28657686710358, 61.415477469563484, 67.82983347773552, 64.94318917393684, 71.51160031557083, 65.7486167550087, 79.41912040114403, 59.68669183552265, 58.8709744066, 2.627424350939691, 0.2809641673229635, 1.0180857824161649, 1.8699860572814941, 68.49159836769104, 61.60856410861015, 70.23984655737877, 45.003831312060356, 33.25239568948746, 24.845762886106968, 59.94932994246483, 49.12421241402626, 60.88645085692406, 20.557521991431713, 0.5426964978687465, 0.14582459698431194, 0.08839610396535136, 0.09921863573254086, 0.01630341666896129, 0.03516210344969295, 0.04320901403843891, 0.08045026275794953, 0.04789905338839162, 0.010226430404145503, 0.10221853764960542, 0.04167092040006537, 0.6489682453684509, 49.94610831141472, 59.113048017024994, 55.774642154574394, 25.335731394588947, 27.314917892217636, 53.30355115234852, 54.484573379158974, 73.68582084774971, 60.30333794653416, 1.5211363951675594, 0.3454490820877254, 0.014220725788618438, 0.07395402892143466, 0.01466856274419115, 3.6512466380372643, 60.02628721296787, 68.11041042208672, 68.8018973171711, 59.713062420487404, 57.75994062423706, 54.45816479623318, 57.09116131067276, 57.343988344073296, 61.38329699635506, 60.71414530277252, 64.36514139175415, 62.65622489154339, 64.1340833902359, 63.46425913274288, 62.74245746433735, 59.04210962355137, 62.94418103992939, 59.1833708435297, 57.02915243804455, 56.06025002896786, 53.57938975095749, 47.12128289043903, 45.96607647836208, 44.83721785247326, 45.1639699190855, 45.956713780760765, 52.85473823547363, 56.270272359251976, 60.602199509739876, 60.25270186364651, 59.005962163209915, 56.10507622361183, 57.88269683718681, 58.060907274484634, 57.87572041153908, 52.247264832258224, 46.95095703005791, 46.333463564515114, 44.72425751388073, 45.81642150878906, 44.71572697162628, 43.662260100245476, 42.29544684290886, 43.41107077896595, 40.62927804887295, 44.41707439720631, 44.22912508249283, 49.56573352217674, 49.561979323625565, 51.81005269289017, 52.054717764258385, 51.533818915486336, 51.61905214190483, 52.14475393295288, 52.11397938430309, 53.1525282561779, 52.71205589175224, 56.39630779623985, 57.14424066245556, 54.40154783427715, 57.26915895938873, 58.01445096731186, 55.85958659648895, 55.69416247308254, 45.08347883820534, 43.48191037774086, 46.480219289660454, 40.003432631492615, 42.57549561560154, 51.1951544880867, 55.87170034646988, 58.948421850800514, 58.22204142808914, 54.791110530495644, 56.49669460952282, 52.125986739993095, 51.799854040145874, 51.653691083192825, 52.41498403251171, 52.2143168002367, 52.872027307748795, 49.47602413594723, 47.949003875255585, 49.67954881489277, 44.73544031381607, 46.61451928317547, 44.475769847631454, 40.410231202840805, 43.486382737755775, 41.80241569876671, 42.45487488806248, 39.902897626161575, 42.25798845291138, 45.3455925732851, 44.989715069532394, 42.39345498383045, 45.00891163945198, 51.95210427045822, 57.80724048614502, 58.356478214263916, 56.57183177769184, 56.45119205117226, 52.869713231921196, 46.24704100191593, 45.402927696704865, 47.27773569524288, 49.63437303900719, 53.8161626458168, 55.54964102804661, 56.10672153532505, 55.106584802269936, 55.13777352869511, 50.373665168881416, 46.81578308343887, 46.11751735210419, 46.43415056169033, 45.62726005911827, 48.359317258000374, 48.537554293870926, 48.57810951769352, 52.556530237197876, 56.58247120678425, 57.94542767107487, 61.63104750216007, 58.91835406422615, 65.72651714086533, 65.06141602993011, 70.77818647027016, 67.42238134145737, 75.0443771481514, 68.53167101740837, 78.90234813094139, 61.47462509572506, 62.80222825706005, 3.4908522572368383, 0.163404279446695, 1.786103539634496, 2.074647112749517, 76.94505795836449, 68.19431751966476, 81.76446095108986, 51.15308314561844, 45.7303561270237, 24.526264630258083, 49.16922099888325, 60.112812370061874, 71.8979711830616, 27.092719115316868, 0.5339560762513429, 0.13516928593162447, 0.09423450552276336, 0.1320616019074805, 0.057083112333202735, 0.14284030243288726, 0.10394520359113812, 0.36504899442661554, 0.12290728453081101, 0.11541557090822607, 0.269062255974859, 0.18868047860451043, 0.8062270225491375, 62.45294339954853, 69.1089740395546, 59.307080805301666, 35.21629370748997, 38.99821937084198, 62.0173841714859, 62.838109731674194, 81.01637229323387, 67.53832072019577, 1.976114718709141, 0.9080781228840351, 0.20923544594552368, 0.28223959263414145, 0.17308277572738007, 5.05576740950346, 62.984420880675316, 72.8119969367981, 73.26788887381554, 62.53225654363632, 60.78824132680893, 56.90384276211262, 59.11666542291641, 62.353354543447495, 65.25586679577827, 63.682527020573616, 65.20054936408997, 65.3324630856514, 67.19288885593414, 64.40484926104546, 65.98801910877228, 62.276674658060074, 67.48810261487961, 62.873140051960945, 60.401281490921974, 58.47096987068653, 56.085674464702606, 49.71341259777546, 47.421922758221626, 45.22338733077049, 47.324575781822205, 50.53126931190491, 52.414531856775284, 57.48493418097496, 64.3828484416008, 61.68508820235729, 59.73070107400417, 59.17795613408089, 58.800662979483604, 61.96331687271595, 60.330612882971764, 53.33299957215786, 49.79977436363697, 47.7663666754961, 47.211459651589394, 47.61804163455963, 46.53453357517719, 46.747542545199394, 42.954076901078224, 46.90581165254116, 43.65583084523678, 44.935598373413086, 47.94022634625435, 53.64368610084057, 51.53694614768028, 54.834956377744675, 53.55675056576729, 55.006254985928535, 54.030440747737885, 55.294287130236626, 55.596560910344124, 57.06018157303333, 54.56878446042538, 60.685437843203545, 58.00390273332596, 57.32711344957352, 60.34835033118725, 60.457852855324745, 61.90373606979847, 58.08628611266613, 46.66952133178711, 44.01090659201145, 48.42061556875706, 39.92558240890503, 42.83372215926647, 53.70477542281151, 56.736009567976, 62.24527694284916, 60.42861722409725, 56.07155442237854, 59.232714995741844, 56.59567929804325, 55.38719214498997, 54.91730555891991, 54.27274614572525, 54.15720574557781, 56.30343317985535, 53.88116955757141, 52.146361246705055, 54.14042204618454, 47.65228159725666, 49.72702346742153, 47.305667996406555, 44.9717116355896, 45.11958070099354, 42.35656276345253, 44.800812005996704, 40.42150899767876, 45.19005171954632, 50.12177288532257, 48.48571367561817, 45.51764354109764, 48.33064779639244, 53.77661056816578, 63.43188486993313, 60.06495013833046, 57.839367762207985, 59.61762294173241, 55.97357667982578, 48.42183530330658, 49.28943134844303, 51.41835071146488, 53.18986505270004, 54.02733251452446, 57.80599035322666, 57.4348034709692, 59.5834855735302, 57.573416233062744, 53.48769687116146, 48.88821467757225, 48.95455911755562, 48.26062135398388, 49.27412576973438, 51.94391950964928, 51.63083530962467, 51.498290821909904, 54.44681480526924, 60.07626213133335, 60.72490252554417, 65.32202884554863, 62.53097601234913, 69.65173691511154, 67.4510546028614, 74.30829584598541, 70.91554909944534, 78.61613228917122, 73.91530573368073, 83.2084746658802, 61.29528991878033, 69.28870439529419, 4.513158900663257, 0.3784248704323545, 3.4371319273486733, 3.01543150562793, 83.08496609330177, 74.62817788124084, 87.6847256720066, 59.65025559067726, 54.41049635410309, 34.97678115963936, 78.43066424131393, 69.5644935965538, 85.91783568263054, 35.77074095606804, 0.6588526431005448, 0.2386443834984675, 0.1865790132433176, 0.2578283072216436, 0.15747462341096252], [0.04000945955340285, 0.09315237257396802, 0.015926515116007067, 0.03945470045437105, 0.02178723119868664, 0.07969293073983863, 0.05918794333410915, 1.056714984588325, 44.91387873888016, 48.96428659558296, 55.32997101545334, 40.1578563451767, 23.98284249007702, 35.54073169827461, 49.32166501879692, 56.30172707140446, 72.30304464697838, 7.891089292243123, 0.3767413826426491, 0.23904679081169888, 0.2630139602115378, 0.013970875279483153, 0.7908355328254402, 47.18915484845638, 62.920637503266335, 62.429570853710175, 58.40981975197792, 60.0360032916069, 57.840268313884735, 62.4873049557209, 59.66234274208546, 60.80700471997261, 60.18327198922634, 63.114180117845535, 62.78909616172314, 63.72977368533611, 58.67740519344807, 58.3554332703352, 55.07171407341957, 53.61388050019741, 53.35432782769203, 52.683356031775475, 49.71264883875847, 44.701736122369766, 44.49358709156513, 42.05960109829903, 41.76347158849239, 42.89470888674259, 46.091249361634254, 53.3758232742548, 56.077364310622215, 44.16495032608509, 62.91076183319092, 52.005764991045, 56.403975784778595, 58.942763954401016, 53.45930099487305, 51.19898088276386, 46.34253367781639, 46.290864050388336, 41.10967867076397, 47.17460922896862, 42.77522049844265, 40.99877402186394, 41.40821725130081, 38.27952593564987, 39.89155903458595, 39.475485160946846, 41.60957224667072, 40.32306008040905, 43.23484003543854, 46.00174896419048, 46.67976938188076, 47.60923370718956, 46.00434422492981, 49.37104716897011, 50.71075648069382, 46.06810100376606, 47.056549564003944, 49.999195262789726, 51.30475200712681, 51.83827377855778, 53.34640525281429, 55.70145048201084, 51.072618663311005, 52.17007577419281, 57.76742622256279, 46.99661538004875, 38.767602145671844, 43.61842945218086, 41.842476949095726, 45.53136460483074, 47.86694347858429, 54.16570208966732, 55.52078917622566, 55.239858850836754, 55.12288212776184, 53.66373762488365, 50.73327787220478, 47.63075955212116, 46.12402260303497, 45.95106728374958, 50.12983225286007, 49.158019199967384, 45.331556126475334, 46.038211807608604, 44.68062825500965, 42.82412387430668, 45.10457530617714, 40.955441147089005, 36.896624341607094, 39.626261070370674, 39.143033400177956, 39.085166305303574, 40.19768200814724, 39.610560312867165, 41.41887187957764, 42.404861971735954, 42.229018807411194, 46.458165273070335, 52.17159189283848, 55.860806331038475, 55.079298466444016, 54.65723231434822, 54.39400143921375, 53.34002539515495, 46.74179345369339, 44.02680113911629, 43.457595482468605, 43.82607690989971, 48.02795223891735, 51.114671006798744, 54.55668590962887, 54.10534232854843, 54.97494846582413, 55.01821294426918, 53.7210613489151, 49.238711670041084, 44.674594178795815, 43.031349554657936, 44.85710598528385, 44.34415630996227, 45.45858331024647, 47.82954588532448, 53.22407841682434, 54.678252786397934, 60.044613629579544, 61.06842689216137, 64.92191791534424, 64.4960443675518, 70.55111825466156, 66.2131342291832, 68.92241925001144, 67.42683470249176, 73.3753091096878, 69.40697684884071, 74.420967400074, 1.8467738153412938, 0.11581297614611685, 1.0592074133455753, 6.314425645396113, 72.80494451522827, 62.500900626182556, 68.22672218084335, 48.29161249101162, 40.292038545012474, 23.47513273358345, 46.09123036265373, 52.41484723985195, 60.53337760269642, 24.500815495848656, 0.38881841115653515, 0.05643641597998794, 0.0183563492828398, 0.04325917208916508, 0.1150103508553002, 0.03481152773019858, 0.1418621517950669, 0.07052282788208686, 0.039818924269638956, 0.06971937880734913, 0.09128080972004682, 0.13222919369582087, 1.8627291591838002, 57.462788969278336, 55.611858889460564, 61.32952228188515, 36.08233943581581, 31.675732992589474, 44.45166774094105, 55.734117329120636, 63.45499522984028, 78.36116597056389, 8.832363858819008, 0.31318035267759115, 0.08735049210372381, 0.4349545855075121, 0.16660051653161645, 1.2089761393144727, 50.80730929970741, 66.6961719095707, 65.23006618022919, 62.3097974807024, 63.036702275276184, 61.170014441013336, 64.80284750461578, 61.52887098491192, 64.28610563278198, 61.94230020046234, 64.44213286042213, 64.31496888399124, 65.90269848704338, 59.84695203602314, 60.2676996588707, 57.6677081733942, 55.51748335361481, 55.74901632964611, 55.70632562041283, 50.98020762205124, 46.599707677960396, 45.74497014284134, 43.780399560928345, 43.48553918302059, 44.2130671441555, 49.76174980401993, 54.02767829596996, 60.796794667840004, 41.47394612431526, 59.794647842645645, 55.116601064801216, 56.55161306262016, 62.69347049295902, 57.115115225315094, 55.71286126971245, 48.10159608721733, 49.35168720781803, 42.33154110610485, 50.09885251522064, 46.271895468235016, 45.04303760826588, 43.266644328832626, 41.42223849892616, 41.188668832182884, 41.77168294787407, 42.94243812561035, 41.28102287650108, 44.66417133808136, 48.96769501268864, 48.30706626176834, 50.23321710526943, 48.51710379123688, 52.04528667032719, 52.70908445119858, 48.11000123620033, 49.766841530799866, 51.30402244627476, 53.68259221315384, 55.929776430130005, 56.74130268394947, 56.611057072877884, 54.30370308458805, 54.58130858838558, 59.94537815451622, 48.914706856012344, 40.507961958646774, 44.21658955514431, 41.67680203914642, 46.67377710342407, 50.21044112741947, 56.957666873931885, 54.61472399532795, 57.334230467677116, 56.928701028227806, 55.18288850784302, 53.620271757245064, 51.20848797261715, 48.29222805798054, 47.882872223854065, 52.18571573495865, 50.39879322052002, 47.160686776041985, 47.840417101979256, 48.117163851857185, 46.02529630064964, 46.388294622302055, 44.5009358972311, 40.12816473841667, 39.50611911714077, 41.018829345703125, 42.910189256072044, 43.666614666581154, 41.1701600253582, 43.52135606110096, 44.1746512055397, 43.873749151825905, 48.381527066230774, 54.69671979546547, 57.65171863138676, 55.508804619312286, 56.65178328752518, 57.354517579078674, 56.63846880197525, 50.20339250564575, 47.02879585325718, 46.45454406738281, 45.72196237742901, 52.21175193786621, 54.96728427708149, 57.01121360063553, 55.840963795781136, 57.57454477250576, 58.38827110826969, 58.50545682013035, 52.370112240314484, 47.339470982551575, 45.537592470645905, 47.97213323414326, 47.28352278470993, 48.54222424328327, 50.61812125146389, 55.99422097206116, 57.356550469994545, 63.174300491809845, 63.721638321876526, 68.65938976407051, 67.2072596848011, 75.03121465444565, 69.46034878492355, 72.10020393133163, 71.044742166996, 76.60838842391968, 71.4773641526699, 77.28827074170113, 2.1447348268702626, 0.08040758184506558, 1.496548152063042, 6.735364682972431, 82.26933225989342, 67.40627020597458, 75.61116233468056, 53.79545755684376, 52.78834439814091, 23.50722011178732, 46.01163603365421, 64.60441455245018, 70.80204918980598, 29.775093980133533, 0.4443101288052276, 0.020338998656370677, 0.02303728248080006, 0.0630985977477394, 0.0871920509962365, 0.11004002459230833, 0.21352995769120753, 0.08621828645118512, 0.19426059792749584, 0.13342060789000243, 0.20908508682623506, 0.2857584413141012, 2.735888580791652, 73.87641862034798, 65.98710715770721, 76.35838463902473, 53.56897071003914, 40.58126002550125, 51.28187343478203, 64.01670008897781, 67.59935304522514, 86.28892377018929, 10.332801695913076, 0.4987294727470726, 0.2595364046283066, 0.5929330084472895, 0.3057238465407863, 1.9814261212013662, 53.162939697504044, 68.9048033952713, 67.55243316292763, 66.08863770961761, 64.9085882306099, 63.86682853102684, 68.0309034883976, 64.47950765490532, 66.15033119916916, 63.3804090321064, 67.34134688973427, 66.26637697219849, 68.3962994813919, 62.82750830054283, 61.10265925526619, 61.34408690035343, 57.261202186346054, 58.77491556107998, 58.444929867982864, 53.79744865000248, 50.27299717068672, 49.49320301413536, 45.37895858287811, 45.71585230529308, 47.58898079395294, 54.16128292679787, 58.074833527207375, 65.35101369023323, 43.87963503599167, 60.08112967014313, 54.35091935098171, 59.57889921963215, 62.134995460510254, 58.23025278747082, 57.08592899143696, 52.117934972047806, 51.29723221063614, 44.81343872845173, 52.164094895124435, 48.275976330041885, 46.389708146452904, 45.37464961409569, 43.5274813324213, 42.95238219201565, 44.11397986114025, 46.194417625665665, 45.75073443353176, 46.405728086829185, 51.376222372055054, 52.33129732310772, 53.30057591199875, 50.288279950618744, 56.48946739733219, 55.95670938491821, 51.221604868769646, 53.938721269369125, 53.63133676350117, 55.74031099677086, 58.804804757237434, 59.25427123904228, 61.75142124295235, 57.68959499895573, 58.291159719228745, 62.00080186128616, 51.0171340405941, 40.8292119204998, 44.01593752205372, 43.66952531039715, 47.7838609367609, 55.22887364029884, 57.619226574897766, 57.892766296863556, 59.010077342391014, 59.99301999807358, 59.74664881825447, 58.35550166666508, 51.88816890120506, 49.48510944843292, 48.914931043982506, 56.2214981764555, 53.66169333457947, 49.18017581105232, 51.028294041752815, 49.70845006406307, 49.207146763801575, 48.67041416466236, 46.309049874544144, 41.440025344491005, 43.0741922557354, 43.51997293531895, 45.46626649796963, 45.13860248029232, 42.631800994277, 45.33451236784458, 45.73062211275101, 46.62691801786423, 50.519254356622696, 56.51962637901306, 60.85949130356312, 57.785285264253616, 58.73870350420475, 60.74234738945961, 59.02965389192104, 52.03744389116764, 48.108861297369, 48.333292454481125, 48.2881660759449, 53.92112821340561, 57.58951596915722, 59.692843705415726, 60.320991799235344, 62.53217674791813, 60.31248025596142, 60.879846811294556, 54.83621031045914, 49.33724798262119, 48.199630826711655, 50.576004311442375, 48.60523246228695, 51.46571137011051, 53.94423857331276, 59.52134370803833, 59.57634575664997, 67.3032121360302, 67.78950244188309, 71.70200809836388, 69.6040266752243, 79.46544751524925, 73.47744762897491, 76.32744669914246, 73.99508625268936, 79.77038115262985, 72.75156497955322, 79.59264189004898, 2.523480453528464, 0.22549584216903895, 2.3354841163381934, 8.39010464027524, 90.12253046035767, 72.9245088994503, 83.96350935101509, 63.07450644671917, 63.11145946383476, 35.691587403416634, 64.76791977882385, 72.99253284931183, 86.45248219370842, 35.37136718630791, 0.4638614156283438, 0.20467502268729731, 0.06416012125555426, 0.19854477897752076, 0.18329506914597005], [0.04240419941197615, 0.030527385642926674, 0.03438265543081798, 0.09698401423520409, 0.030641743178421166, 0.04618089988071006, 0.08930349824368022, 2.031634133309126, 49.42292578518391, 46.484045684337616, 36.522078439593315, 17.486703470349312, 24.957125410437584, 38.119318932294846, 49.13903921842575, 58.81950996816158, 73.357123285532, 30.562248341739178, 0.23073435091646388, 0.6539002619683743, 0.25068314687814564, 0.16821871016873047, 0.05759498271800112, 31.574143543839455, 67.393259704113, 67.52932280302048, 63.62923488020897, 62.30401799082756, 61.572222858667374, 62.640125155448914, 61.496736109256744, 62.87472456693649, 59.312104135751724, 61.10444135963917, 60.695514902472496, 59.95517782866955, 54.56847287714481, 54.197494983673096, 51.653725281357765, 50.393070727586746, 48.32672260701656, 45.828523859381676, 44.11658272147179, 45.90455777943134, 45.22648796439171, 41.87406845390797, 43.22539374232292, 42.959719598293304, 50.843422561883926, 53.12800817191601, 59.465935081243515, 33.19064520299435, 37.608991116285324, 53.52418631315231, 54.30973336100578, 57.4072777479887, 53.530592769384384, 50.771348029375076, 48.06428588926792, 43.55305016040802, 46.401422917842865, 51.706907227635384, 39.46234546601772, 39.376956447958946, 40.90942941606045, 41.061447858810425, 39.470613822340965, 40.69830894470215, 38.04625645279884, 41.7733396589756, 42.31955274939537, 45.034906044602394, 44.02583599090576, 47.25859232246876, 47.404101714491844, 46.07346251606941, 48.52165214717388, 46.63082420825958, 47.5103098154068, 50.05796670913696, 51.847602277994156, 54.81320634484291, 51.642113104462624, 49.43255066871643, 52.536060735583305, 54.37329635024071, 54.62252117693424, 53.69212590157986, 39.845383912324905, 39.76360470056534, 42.62806199491024, 45.64797654747963, 53.009762316942215, 55.268098935484886, 52.894734889268875, 53.768760189414024, 53.395715206861496, 52.17320680618286, 52.05182231962681, 50.513113886117935, 47.860989198088646, 45.945428386330605, 49.95935060083866, 48.33320505917072, 45.041620284318924, 45.04086792469025, 43.54630932211876, 43.50806437432766, 43.65844130516052, 39.02994006872177, 39.73248437047005, 37.35767640173435, 39.513395726680756, 40.698658525943756, 40.225872695446014, 39.590056613087654, 42.45122708380222, 45.675327479839325, 42.77784235775471, 43.0804543197155, 51.863063648343086, 53.80206920206547, 53.68143327534199, 55.27636729180813, 56.35104462504387, 52.80664041638374, 50.76429560780525, 46.0137715190649, 45.57820089161396, 42.88578316569328, 47.355608716607094, 49.68096613883972, 53.94506312906742, 52.93656684458256, 56.69582672417164, 55.579161643981934, 57.9873052239418, 52.850957438349724, 52.642778009176254, 45.32402493059635, 45.10226882994175, 42.19855584204197, 44.84470345079899, 43.385289162397385, 47.42932856082916, 51.97677634656429, 60.03112435340881, 59.5171183347702, 63.994577676057816, 61.24764807522297, 68.40617895126343, 64.01353865861893, 71.55431002378464, 65.17355561256409, 74.14352148771286, 66.44480779767036, 73.56566369533539, 1.2302750651724637, 0.20235788921127096, 1.185648359823972, 10.53402654826641, 74.78085368871689, 60.76585292816162, 67.72796094417572, 46.97853974997997, 36.62706680595875, 26.442081928253174, 41.07682183384895, 47.06705220043659, 67.73610770702362, 27.686420157551765, 0.36247478099539876, 0.09368713450385258, 0.07961824841913767, 0.0975811091484502, 0.021743758043157868, 0.027057839688495733, 0.058940244125551544, 0.01114436596253654, 0.035981731343781576, 0.03956377389840782, 0.04348705224401783, 0.09739426604937762, 2.3086877167224884, 62.80065894126892, 52.49436937272549, 52.43424139916897, 26.369059346616268, 29.09655299037695, 45.76266959309578, 52.380797266960144, 63.65246683359146, 79.52995285391808, 33.02549086511135, 0.5299581564031541, 0.5242476565763354, 0.5066320393234491, 0.14639320084825158, 0.21074942720588297, 34.525277987122536, 70.4257781803608, 69.54256117343903, 65.97532778978348, 65.21934315562248, 65.52561432123184, 65.28139382600784, 64.22182828187943, 63.11554044485092, 60.18897168338299, 64.53851088881493, 63.22917714715004, 62.23588764667511, 58.14500816166401, 55.86383476853371, 54.249844774603844, 53.01375590264797, 49.781968519091606, 47.88292542099953, 46.663506254553795, 48.46286930143833, 47.80861660838127, 43.3618938177824, 44.620621874928474, 43.80464605987072, 53.78590866923332, 53.28113615512848, 63.33582602441311, 33.86474423110485, 39.67420309782028, 55.93851216137409, 56.83785930275917, 59.95338052511215, 56.7716820538044, 53.3895443379879, 51.0559793561697, 47.43889644742012, 49.4930624216795, 55.444352477788925, 43.32529038190842, 41.09943822026253, 42.653182446956635, 43.891182616353035, 42.63837844133377, 43.311972096562386, 41.59332811832428, 43.08363854885101, 45.634681060910225, 47.06932067871094, 47.9777455329895, 49.156586676836014, 49.342472702264786, 47.87663675844669, 49.72504757344723, 48.75718250870705, 48.08080740272999, 52.3082971572876, 53.98164376616478, 55.50150901079178, 53.442912474274635, 53.66155654191971, 57.661107927560806, 55.34599855542183, 58.310352489352226, 56.23491905629635, 39.709545001387596, 40.35764962434769, 42.90478974580765, 47.63080894947052, 55.04646822810173, 56.81479074060917, 56.19542017579079, 55.80484673380852, 54.81586240231991, 56.06425881385803, 54.21788468956947, 50.4563145339489, 51.0239090770483, 46.99817709624767, 51.70256406068802, 52.021344155073166, 48.53005349636078, 49.81090396642685, 47.25446194410324, 47.51619569957256, 44.79951627552509, 41.36426880955696, 41.72417789697647, 40.53246684372425, 42.3420475423336, 42.73625738918781, 41.63333237171173, 42.080412581562996, 44.75677236914635, 48.30706626176834, 45.19828587770462, 46.288230791687965, 54.18796889483929, 55.487176179885864, 56.07334412634373, 55.98555363714695, 60.07372386753559, 56.578986793756485, 54.25947345793247, 48.25251638889313, 48.16581264138222, 45.23377597332001, 49.50180195271969, 53.322987109422684, 54.96508799493313, 55.73507867753506, 58.278460800647736, 57.2658721357584, 60.624082535505295, 56.99507586658001, 55.50972796976566, 48.583482429385185, 47.488723173737526, 44.77623112499714, 47.914558723568916, 45.18820121884346, 49.82328750193119, 53.40145289897919, 63.47467817366123, 63.13600994646549, 65.43183535337448, 65.75769066810608, 72.74448215961456, 65.43372005224228, 72.24153354763985, 66.9306193292141, 77.06879451870918, 69.6290597319603, 78.56683373451233, 1.7530159838497639, 0.1105085424205754, 1.1383068189024925, 12.098452001810074, 81.98120892047882, 65.55058658123016, 75.62262251973152, 56.3464430719614, 47.030121982097626, 32.624004408717155, 49.064491018652916, 53.15119072794914, 76.48216679692268, 31.576100438833237, 0.3199824329931289, 0.07376570894848555, 0.028115539280406665, 0.1027797645656392, 0.07816628101863898, 0.1811131401336752, 0.18019850249402225, 0.09545309716486372, 0.2310079213930294, 0.09911733257467858, 0.1905504977912642, 0.09458351531066, 3.8838300202041864, 77.44375839829445, 61.48398779332638, 56.65691301226616, 27.439659498631954, 39.84876953065395, 55.97417704761028, 61.88719555735588, 67.27855905890465, 86.69957533478737, 36.50288566946983, 1.2263210210949183, 0.8421633567195386, 0.822836821898818, 0.5783822236116976, 0.3394993138499558, 37.58863180875778, 73.0836671590805, 72.92485848069191, 69.52508211135864, 66.74801632761955, 68.58715564012527, 66.91776841878891, 66.11622422933578, 65.96005260944366, 62.09357388317585, 65.40668830275536, 64.81345653533936, 65.46141296625137, 60.15163868665695, 59.01603922247887, 57.14793786406517, 56.96246221661568, 51.61773361265659, 50.885121524333954, 47.364553436636925, 52.05371081829071, 49.30224806070328, 46.417526453733444, 47.82560169696808, 45.473733097314835, 56.43498212099075, 57.101515755057335, 64.42256391048431, 34.51343022286892, 40.47520391643047, 56.58442050218582, 58.88647377490997, 61.416849195957184, 59.301350712776184, 56.12361542880535, 54.393762052059174, 49.20224882662296, 54.34875726699829, 57.44546949863434, 45.44690653681755, 43.25057499110699, 44.038401916623116, 46.20161823928356, 44.18524123728275, 44.97208021581173, 43.193239867687225, 45.11332243680954, 47.63142071664333, 49.54039268195629, 49.06554736196995, 52.987879291176796, 52.9937993735075, 49.778066128492355, 53.78547549247742, 51.02867402136326, 51.65511600673199, 56.329533979296684, 55.763178169727325, 58.66858586668968, 57.96156160533428, 56.482703760266304, 58.310960456728935, 58.5017254203558, 60.62726676464081, 59.47628952562809, 40.33246837556362, 41.00146047770977, 44.299379512667656, 48.910770267248154, 56.34887494146824, 59.77536767721176, 58.42169031500816, 58.63554663956165, 57.22363360226154, 58.37888181209564, 57.417898178100586, 52.50526338815689, 53.84953625500202, 50.032371282577515, 55.9614135324955, 54.27529580891132, 51.36369824409485, 52.400221824645996, 49.74298261106014, 50.357979610562325, 48.293880969285965, 44.53176364302635, 44.99480299651623, 41.77316106855869, 44.16258305311203, 44.17150877416134, 44.73034478724003, 45.22058308124542, 47.9828904569149, 50.65828889608383, 47.83512398600578, 48.944067880511284, 56.95057265460491, 55.830373764038086, 58.942144587635994, 58.84342588484287, 60.317682176828384, 59.50756944715977, 56.64733752608299, 50.90027891099453, 51.51225887238979, 47.95062638819218, 52.486556991934776, 56.622813642024994, 58.194234520196915, 58.85104067623615, 61.528054028749466, 62.77713820338249, 64.4625073671341, 59.26182523369789, 57.827379405498505, 51.96458660066128, 48.93646828830242, 47.269258350133896, 50.34633323550224, 48.30190233886242, 52.44660593569279, 54.96045984327793, 67.6264151930809, 66.40911251306534, 69.57929760217667, 68.09325814247131, 77.33588978648186, 69.34589132666588, 79.0494154393673, 70.2042804658413, 81.71169698238373, 71.84204578399658, 83.87560486793518, 1.9763349881395698, 0.33597524045035243, 2.144355559721589, 12.041714396327734, 90.90011313557625, 71.67594149708748, 84.6085475385189, 59.97899875044823, 57.86663509905338, 36.560057401657104, 60.51110699772835, 63.90176385641098, 92.01859831809998, 38.14835697412491, 0.5202791257761419, 0.12750036228680983, 0.1335350173758343, 0.13647117622895166, 0.14952786936191842], [0.07597212141263299, 0.09022329380968586, 0.11549600487342104, 0.01672628684900701, 0.09074278976186179, 0.05351676249119919, 0.05415951804025099, 4.26256662234664, 53.52416731417179, 51.3640022277832, 31.01352922618389, 28.973975367844105, 45.31737148761749, 41.024274453520775, 51.63933925330639, 60.398374646902084, 67.96883761882782, 45.93517653644085, 0.5567693989723921, 0.8102153241634369, 0.199368963658344, 0.4624841676559299, 0.20452920551178977, 15.205232743173838, 58.34532581269741, 57.023122161626816, 61.343129351735115, 61.91846027970314, 65.62176436185837, 64.23442840576172, 63.74629519879818, 64.47319239377975, 61.920428574085236, 60.922328531742096, 60.33326894044876, 55.1995088160038, 53.1803959608078, 50.09432315826416, 48.40486541390419, 47.081419229507446, 46.59220688045025, 46.87965385615826, 48.42054717242718, 49.51479725539684, 45.41565701365471, 42.92163424193859, 46.311922520399094, 45.192646980285645, 49.76274535059929, 54.8419214040041, 54.59720313549042, 45.70299759507179, 42.41989016532898, 49.3588612228632, 56.84433415532112, 56.4797019213438, 54.513626620173454, 49.88301269710064, 47.106174901127815, 44.66973803937435, 51.45752280950546, 54.28886868059635, 45.74300564825535, 39.49303641915321, 38.23365479707718, 41.39964871108532, 40.562500432133675, 39.84569929540157, 39.3061700463295, 41.4551105350256, 41.78592458367348, 42.91798263788223, 45.139936208724976, 44.40424628555775, 44.33735467493534, 46.685457676649094, 47.37235441803932, 45.80046236515045, 48.75481143593788, 51.33086420595646, 52.01792433857918, 52.95680835843086, 51.67954109609127, 55.409409552812576, 53.790928199887276, 54.246603548526764, 52.83893868327141, 55.30672386288643, 43.703377693891525, 37.81313896179199, 41.121902614831924, 50.49455188214779, 55.604631677269936, 54.955816492438316, 55.579754412174225, 54.93638053536415, 53.43514569103718, 50.72271063923836, 50.62508627772331, 48.618109971284866, 47.81806290149689, 47.598905861377716, 46.66460819542408, 47.053711116313934, 45.1908078789711, 44.33721408247948, 42.60426767170429, 42.67029672861099, 42.29940243065357, 41.75371751189232, 39.35690872371197, 39.3546212464571, 39.65542070567608, 39.459799602627754, 40.265789553523064, 40.82770720124245, 43.11718314886093, 42.88317270576954, 41.44115388393402, 43.22789400815964, 48.36804538965225, 53.589899986982346, 56.97055198252201, 52.014911100268364, 54.443858563899994, 54.974526688456535, 54.52206216752529, 52.290742099285126, 47.611441388726234, 43.15722160041332, 44.08622235059738, 45.277302637696266, 51.9892168790102, 55.083679631352425, 55.91238096356392, 57.293591648340225, 57.27534882724285, 54.7154375910759, 58.133950755000114, 51.59642435610294, 47.02131785452366, 43.61030928790569, 45.90876795351505, 44.98087294399738, 46.11644200980663, 48.11363384127617, 51.15636616945267, 54.252846613526344, 62.063384503126144, 57.177329286932945, 62.006805539131165, 58.98565225303173, 63.38352486491203, 61.35071374475956, 68.39095696806908, 67.96598017215729, 74.18367773294449, 0.6524393591098487, 0.1991067035123706, 0.5115923762787133, 18.217295967042446, 78.73451113700867, 59.46107134222984, 73.02885130047798, 41.8351661413908, 44.315680637955666, 11.980447433888912, 34.976598769426346, 59.55823972821236, 70.83176359534264, 18.203857988119125, 0.5168829392641783, 0.08708508525160141, 0.08552330225938931, 0.06677953890175559, 0.08881669389666058, 0.04404180021083448, 0.06047207774827257, 0.05133764250786044, 0.03045732133614365, 0.038840328343212605, 0.10036945444880985, 0.1075406938616652, 6.511701559647918, 67.80616074800491, 56.56594209372997, 45.75693570077419, 22.075141556560993, 37.37104028463364, 47.68041908740997, 56.86346232891083, 69.23075750470161, 73.37773337960243, 49.40193571150303, 0.7852976268623024, 1.2204144755378366, 0.3107576858019456, 0.21320010273484513, 0.20081359863979742, 17.538893669843674, 60.96991337835789, 61.491720378398895, 65.21647050976753, 63.22310507297516, 68.65325689315796, 65.43093100190163, 64.15264919400215, 67.01925337314606, 62.23178766667843, 64.56354394555092, 61.142059341073036, 60.06818376481533, 58.68544556200504, 54.61894936859608, 50.83219416439533, 49.3778982013464, 48.13060373067856, 48.84948715567589, 50.45466162264347, 50.4142089933157, 47.0258966088295, 47.12547026574612, 48.02942655980587, 47.393606677651405, 51.92611746490002, 58.76893848180771, 56.68137609958649, 46.410333439707756, 42.60334812104702, 50.426771119236946, 59.497689977288246, 57.55599796772003, 58.51470172405243, 52.86115609109402, 49.72518056631088, 47.03247785568237, 53.47670026123524, 57.04382725059986, 47.58025646209717, 40.448571145534515, 41.11538216471672, 43.02208945155144, 42.50423803925514, 41.397270038723946, 40.398269444704056, 43.297643065452576, 43.83874922990799, 45.7605455070734, 46.618357077240944, 45.30540592968464, 48.99345763027668, 49.79198478162289, 50.841663256287575, 47.804752215743065, 50.48599474132061, 51.969438940286636, 54.25887309014797, 55.0343506783247, 54.93018686771393, 58.85398551821709, 56.7596784979105, 57.472520247101784, 55.4893496632576, 56.72484576702118, 44.476001635193825, 39.46536250412464, 42.677022367715836, 52.06374228000641, 55.34442164003849, 54.87065926194191, 56.79990693926811, 55.40744125843048, 55.210163444280624, 53.07785086333752, 51.49470001459122, 51.745410561561584, 50.60995548963547, 48.186570927500725, 49.439808279275894, 48.48776176571846, 47.87143863737583, 46.330378130078316, 45.641756281256676, 45.851847007870674, 44.950425177812576, 43.354959189891815, 41.317022144794464, 40.18300339579582, 42.988780438899994, 40.77667973935604, 41.51515871286392, 43.00856597721577, 43.66349123418331, 44.14687089622021, 43.278066515922546, 46.00565515458584, 51.255407854914665, 55.845515951514244, 60.27825549244881, 54.59673956036568, 57.30413228273392, 57.566557601094246, 56.702229380607605, 54.21835966408253, 49.71043735742569, 44.590196907520294, 46.5293924510479, 48.529168143868446, 54.829572066664696, 56.66529916226864, 60.33567801117897, 60.36779768764973, 60.69347061216831, 60.1726059615612, 61.088721603155136, 53.79454180598259, 49.22305651009083, 47.27737471461296, 48.556127697229385, 48.292406648397446, 48.54262702167034, 50.57409681379795, 53.18244785070419, 56.71210505068302, 64.21210080385208, 60.510487630963326, 64.6539106965065, 60.937497317790985, 67.31148049235344, 63.6420363932848, 71.88920125365257, 70.98017603158951, 79.28988173604012, 0.5982396611943841, 0.626773398835212, 0.334507153602317, 20.147824175655842, 87.2275722026825, 64.09538626670837, 79.9198043346405, 53.71337816119194, 55.107587948441505, 17.38280564546585, 49.252090752124786, 60.76383523643017, 84.07389342784882, 23.012623451650143, 0.2783903101226315, 0.2191993870656006, 0.0441186829993967, 0.051627952125272714, 0.01861676704720594, 0.21362879691878334, 0.1515065983403474, 0.24037225171923637, 0.13422175630694255, 0.3318730043247342, 0.16725397756090388, 0.3679126751376316, 9.812272377312183, 81.5451443195343, 68.81753727793694, 46.23704373836517, 39.991607666015625, 58.47530163824558, 57.392754927277565, 65.99681183695793, 71.95571288466454, 82.20014557242393, 52.879429310560226, 2.2278632037341595, 1.5089002205058932, 0.4202971688937396, 1.6562909865751863, 0.2832803805358708, 18.054231517016888, 63.77318635582924, 62.560489028692245, 68.41226622462273, 66.01334854960442, 70.96595719456673, 68.38926985859871, 65.80643445253372, 69.18645188212395, 65.93870535492897, 67.48952373862267, 64.30771887302399, 62.81592272222042, 61.51197329163551, 56.448395401239395, 54.0977693349123, 51.29430256783962, 49.36336398124695, 51.75938241183758, 53.11633139848709, 52.949942126870155, 49.81818437576294, 48.84284131228924, 51.358678713440895, 49.310341626405716, 55.12421205639839, 60.9433414041996, 58.85792210698128, 46.51046186685562, 41.756878942251205, 51.354134157299995, 61.62519581615925, 59.28416423499584, 61.480959355831146, 55.36764979362488, 52.840804383158684, 50.92593513429165, 56.20188742876053, 59.94644209742546, 51.20833218097687, 44.36597093939781, 41.441970840096474, 45.10043352842331, 44.90920498967171, 43.74045990407467, 42.85572297871113, 47.97794692218304, 45.53861081600189, 47.29621410369873, 50.38073658943176, 47.425513565540314, 50.38450978696346, 53.81138630211353, 52.837863340973854, 49.75201092660427, 52.99515210092068, 57.38762520253658, 56.34149573743343, 58.74711625277996, 59.310759007930756, 60.67419804632664, 59.367782548069954, 61.62504002451897, 57.700519412755966, 60.974009558558464, 45.14834135770798, 38.868323341012, 42.82030887901783, 55.6306678801775, 59.224302247166634, 60.28082795441151, 61.135455295443535, 58.425885289907455, 59.623907804489136, 55.340207666158676, 55.05823239684105, 54.89631548523903, 53.077858462929726, 51.99524335563183, 53.29129301011562, 50.99674813449383, 50.843996331095695, 50.56069493293762, 47.21233360469341, 47.170532047748566, 47.146220952272415, 46.546651124954224, 44.1258580237627, 42.53525197505951, 43.466582000255585, 43.45558159053326, 43.723718002438545, 45.118163377046585, 47.83247172832489, 47.103173062205315, 45.40906436741352, 49.01471748948097, 54.53781232237816, 59.389084205031395, 63.10898199677467, 55.88738210499287, 58.022954910993576, 60.18663860857487, 59.306556433439255, 55.63951760530472, 53.18762317299843, 48.43516878783703, 50.41923612356186, 51.29491053521633, 56.84119552373886, 61.6935009509325, 61.1907347291708, 61.76548428833485, 63.28678585588932, 62.0232168585062, 65.20024538040161, 56.75536572933197, 51.6659302264452, 50.951150581240654, 50.76880216598511, 51.07510752975941, 51.53300195932388, 53.36929902434349, 56.94964550435543, 58.339721113443375, 68.5909478366375, 64.11038026213646, 69.24140453338623, 66.436607837677, 71.5200586616993, 66.4580462872982, 76.26509204506874, 71.79148569703102, 84.12753134965897, 0.9347236587200314, 0.9974081232212484, 0.722340289503336, 21.22005444020033, 99.72425803542137, 69.89239320158958, 89.46920111775398, 56.09560713171959, 68.08429822325706, 18.798698969185352, 52.39291861653328, 74.93498101830482, 96.58649280667305, 30.221431329846382, 0.7472203450743109, 0.2678892173571512, 0.2206382926669903, 0.3550799918593839, 0.15885326662100852], [0.029487842693924904, 0.05655990564264357, 0.010918021125689847, 0.031836046182434075, 0.014188950735842809, 0.07773918987368234, 0.15338913013692945, 4.063983103260398, 60.140957459807396, 47.346253618597984, 34.34376932680607, 44.80957053601742, 91.5560795366764, 57.190389186143875, 41.06645978987217, 65.1668755710125, 60.34233145415783, 63.72911252081394, 1.2028682045638561, 0.5485043674707413, 0.14441824198001996, 0.32928783679381013, 0.2119321731152013, 5.147679252550006, 56.40375539660454, 57.42771305143833, 63.34079995751381, 62.222155183553696, 62.603742107748985, 61.13586947321892, 62.4859332293272, 59.455713629722595, 60.48227034509182, 56.63150757551193, 56.49938106536865, 50.92965893447399, 47.493678107857704, 44.998025223612785, 44.90013487637043, 48.448878452181816, 52.91239254176617, 52.911773175001144, 53.60517516732216, 49.381044432520866, 46.42681695520878, 42.6199646294117, 45.54618000984192, 49.98191758990288, 55.493521839380264, 56.17508366703987, 51.51498332619667, 46.43431015312672, 53.900518119335175, 55.229527205228806, 57.66721799969673, 56.368630081415176, 56.1015310138464, 52.9481790214777, 45.229417607188225, 46.28020942211151, 54.96843181550503, 53.62992703914642, 44.868041798472404, 40.11350892484188, 39.0402565151453, 38.70368577539921, 38.95371235907078, 38.86825494468212, 38.706873804330826, 38.183573484420776, 41.96665048599243, 43.04570518434048, 45.963789001107216, 44.98855993151665, 46.47627130150795, 44.78613719344139, 46.40264265239239, 46.738480031490326, 47.934477254748344, 51.83342143893242, 52.849988490343094, 47.21432089805603, 53.68283160030842, 55.848020017147064, 51.37919761240482, 53.946377858519554, 51.39921113848686, 54.790168181061745, 48.63502286374569, 39.61097829043865, 43.88970449566841, 52.79121704399586, 53.813970163464546, 51.87389686703682, 55.180559232831, 52.39450693130493, 51.4109905064106, 52.291110679507256, 52.79158562421799, 47.64458321034908, 45.881405621767044, 43.975055515766144, 46.792254745960236, 47.04370245337486, 42.53894157707691, 42.65082277357578, 40.72918988764286, 42.58631743490696, 40.98148874938488, 39.0290243178606, 38.03229980170727, 36.02635324001312, 39.410303458571434, 39.752437099814415, 39.3247776478529, 40.691780894994736, 45.40024124085903, 45.04283621907234, 43.92471581697464, 44.44598324596882, 46.503527238965034, 49.8995266109705, 56.3947194814682, 56.395726427435875, 52.5501199811697, 53.332763984799385, 59.50135678052902, 51.200561597943306, 51.91371113061905, 46.50106877088547, 44.00864951312542, 42.65740402042866, 48.579067066311836, 50.028993263840675, 55.406115129590034, 55.76296538114548, 58.47425289452076, 56.77592262625694, 60.242734998464584, 56.62148371338844, 52.562017142772675, 46.44766643643379, 44.556298926472664, 45.0554933398962, 46.85053601861, 45.17035737633705, 47.3855435103178, 47.18921184539795, 50.09774297475815, 50.578576773405075, 52.076129615306854, 53.056951984763145, 56.509758308529854, 58.97657074034214, 66.16907179355621, 71.94302156567574, 61.166583225131035, 0.20967917604139075, 0.6497609778307378, 0.36713169829454273, 26.630472019314766, 76.25058442354202, 59.43188890814781, 73.09338703751564, 39.536118507385254, 42.59517855942249, 25.584238059818745, 34.997417852282524, 50.56262142956257, 75.10797053575516, 29.895678609609604, 0.40947024361230433, 0.07562897459138185, 0.11913429480046034, 0.040765422309050336, 0.047970770829124376, 0.07060608942992985, 0.09764215079485439, 0.05485632049385458, 0.07278037432115525, 0.011135866516269743, 0.119884420564631, 0.08204606579965912, 6.285058446228504, 71.8119589984417, 54.74485941231251, 43.436723202466965, 35.73775872588158, 88.61490815877914, 61.33348546922207, 48.28702613711357, 70.0951275229454, 66.25256091356277, 66.86878144741058, 1.8224787502549589, 0.947338150581345, 0.1952118828194216, 0.5028913775458932, 0.46868754259776324, 5.366409765556455, 60.16051881015301, 61.20870016515255, 67.95616149902344, 64.32918012142181, 65.514085739851, 63.039460927248, 65.26205286383629, 61.71095721423626, 62.77537129819393, 59.993335381150246, 58.526344299316406, 52.908927127718925, 49.34028781950474, 47.831308990716934, 48.63303177058697, 50.21824210882187, 55.53086243569851, 56.24023497104645, 56.24046675860882, 51.35602645576, 47.570863366127014, 45.34788765013218, 47.036509439349174, 52.45599903166294, 57.08833806216717, 58.42462755739689, 53.98403383791447, 46.3523143529892, 55.21070681512356, 57.18874767422676, 58.72067727148533, 58.66782210767269, 58.3893920481205, 54.3882941454649, 48.98042432963848, 49.18810598552227, 58.06373052299023, 56.69697046279907, 47.23822541534901, 42.76701293885708, 40.23640193045139, 40.9344282746315, 42.62320585548878, 41.05815723538399, 40.70997431874275, 39.71527889370918, 43.27051252126694, 44.89221230149269, 49.21012960374355, 47.44797796010971, 48.18934477865696, 48.818982392549515, 49.18454937636852, 48.565421998500824, 48.27862858772278, 51.62463404238224, 54.25440452992916, 50.85424058139324, 55.00441588461399, 56.73090644180775, 54.46299433708191, 54.671306759119034, 53.516993299126625, 57.62984700500965, 49.64722394943237, 40.17424486577511, 46.86895363032818, 54.20726805925369, 56.891998797655106, 55.243461057543755, 56.58670797944069, 53.07642214000225, 52.33932249248028, 55.42163349688053, 54.444417133927345, 48.81625413894653, 49.345292150974274, 46.275539472699165, 49.85153518617153, 49.50802601873875, 46.02982945740223, 47.45527736842632, 45.70533826947212, 44.43791627883911, 43.168902173638344, 41.10479213297367, 40.619501173496246, 37.73833617568016, 40.23561917245388, 42.93584167957306, 41.011472940444946, 43.51629473268986, 47.38492414355278, 47.18964882194996, 46.46651342511177, 46.24836713075638, 47.805850356817245, 53.95892098546028, 58.15207198262215, 59.06317949295044, 53.84232424199581, 55.50708331167698, 62.037257105112076, 52.85283833742142, 55.215027183294296, 51.01322025060654, 46.51107743382454, 44.918643683195114, 50.497557520866394, 52.116236463189125, 58.990432396531105, 58.26856233179569, 61.575011909008026, 59.09630611538887, 61.906365528702736, 59.790103286504745, 56.454338282346725, 49.14811693131924, 48.72446246445179, 46.953939869999886, 49.08192828297615, 47.31783114373684, 49.87957388162613, 49.106543362140656, 51.8744782358408, 52.17336259782314, 54.13937330245972, 55.09882941842079, 60.71633778512478, 62.62529455125332, 70.67324370145798, 75.1226681470871, 65.37021026015282, 0.16611347469734028, 0.8898947923444211, 0.28054550697561353, 29.184814654290676, 84.44498911499977, 65.78687310218811, 82.82285615801811, 45.710091814398766, 55.18343947827816, 20.526473857462406, 33.40175427496433, 61.33056342601776, 85.46946734189987, 38.27241271734238, 0.5403269093949348, 0.09606205159798265, 0.036777963032363914, 0.1159624669526238, 0.007785731195326662, 0.09038773889187723, 0.18118162552127615, 0.2019828077754937, 0.10914022990618832, 0.13499977940227836, 0.24532829906092957, 0.5273637268692255, 9.460560400038958, 84.8846635222435, 62.20658361911774, 50.399534180760384, 55.92226803302765, 94.42066222429276, 71.12122446298599, 56.26568220555782, 76.32082745432854, 72.06303432583809, 73.6106988787651, 2.74720698595047, 1.6328203584998846, 0.7401480933185667, 2.374274334870279, 0.6178269570227712, 6.5877212304621935, 63.735374584794044, 61.40138782560825, 70.09499832987785, 67.45109260082245, 67.77975976467133, 66.33128508925438, 68.64336982369423, 64.05257776379585, 66.76390707492828, 63.74820649623871, 61.46757647395134, 55.598464608192444, 50.122806429862976, 49.60656613111496, 49.445082396268845, 53.483000323176384, 60.46919144690037, 58.268771320581436, 58.30144576728344, 52.604096084833145, 50.10437361896038, 45.55644325911999, 50.711398646235466, 56.015203446149826, 60.71637958288193, 61.764986515045166, 53.847419768571854, 48.10453712940216, 56.73410966992378, 57.86069601774216, 61.02909900248051, 61.00611783564091, 61.14645570516586, 58.28937001526356, 52.519459426403046, 51.742237731814384, 61.66133567690849, 59.08513091504574, 50.687285140156746, 45.35766452550888, 43.493370562791824, 44.35109853744507, 43.70983734726906, 42.50915877521038, 44.1319414973259, 42.71533951163292, 46.14882007241249, 47.88990944623947, 52.57548362016678, 50.79534374177456, 53.02619643509388, 51.812400966882706, 52.013900354504585, 50.71596220135689, 52.449733167886734, 55.092666149139404, 58.14573012292385, 55.183238089084625, 57.75989502668381, 61.35656923055649, 56.78687363862991, 59.416997507214546, 57.657585516572, 61.15085206925869, 50.55143482983112, 42.16821067035198, 46.668377593159676, 57.31959365308285, 59.40511554479599, 58.44851687550545, 62.15639591217041, 56.693885028362274, 54.49609816074371, 57.60408438742161, 57.20088042318821, 52.32162684202194, 53.582061007618904, 48.52748863399029, 50.901544243097305, 52.091617584228516, 48.18162739276886, 49.30739678442478, 47.05242678523064, 47.56750054657459, 44.98832054436207, 44.62835066020489, 42.76229739189148, 39.93427634239197, 43.83571699261665, 44.55423183739185, 43.03551033139229, 46.408178955316544, 50.6354521214962, 49.18601989746094, 49.9330598115921, 48.38677078485489, 50.56382216513157, 54.94087569415569, 61.30749486386776, 61.61059319972992, 54.59533363580704, 56.567025035619736, 65.05906775593758, 55.486697405576706, 58.88947181403637, 52.42874689400196, 49.27338860929012, 46.91095657646656, 55.43746344745159, 55.42637564241886, 60.96578299999237, 62.24969990551472, 64.11082863807678, 62.84619189798832, 66.67480945587158, 61.62707291543484, 59.17211964726448, 51.42709404230118, 51.377654895186424, 49.875367507338524, 53.09816837310791, 50.40374055504799, 55.3227324038744, 52.884015664458275, 57.39546798169613, 54.92764860391617, 57.416507452726364, 57.48833119869232, 65.79635739326477, 64.50196444988251, 74.22383397817612, 77.40822270512581, 70.77409788966179, 0.34969968837685883, 1.5507649490609765, 0.6074054818600416, 30.856582447886467, 94.22574028372765, 71.11116260290146, 87.05103367567062, 52.08803057670593, 65.82551702857018, 32.30398938059807, 47.162229493260384, 69.42536026239395, 95.09953379631042, 47.91172407567501, 0.6875364133156836, 0.2422343150828965, 0.20372085826238617, 0.11646829996607266, 0.15940227778628469], [0.05282568199618254, 0.05140689972904511, 0.05005848790460732, 0.0314626531326212, 0.09322418278316036, 0.08809280305285938, 0.12197776683024131, 5.37374384701252, 63.74700956046581, 45.2224525809288, 29.522185251116753, 52.06317991018295, 96.82478561997414, 58.906361907720566, 37.744624838232994, 69.41838383674622, 54.816143587231636, 73.15274745225906, 6.690789274871349, 0.9895722905639559, 0.07474377052858472, 0.16474501375341788, 0.2406908557168208, 3.2341613061726093, 60.067218616604805, 67.39335849881172, 66.85290589928627, 59.56210792064667, 59.27204668521881, 57.52944499254227, 58.92564967274666, 55.07644101977348, 53.94632466137409, 51.17441900074482, 49.8470514267683, 43.95735986530781, 45.60924902558327, 49.08541649580002, 50.909124836325645, 52.41487763822079, 56.002717316150665, 54.26519215106964, 55.8732620626688, 49.247595593333244, 45.85173301398754, 44.54953148961067, 49.97390761971474, 51.13078594207764, 52.53523238003254, 55.591313391923904, 52.64852710068226, 61.440054550766945, 57.77201257646084, 57.856698632240295, 55.14323003590107, 54.852047860622406, 54.73286345601082, 48.428408950567245, 44.532405808568, 47.413388416171074, 53.87879088521004, 52.81472258269787, 45.91723769903183, 38.84630352258682, 38.49472738802433, 39.90190967917442, 37.26014323532581, 38.71257349848747, 38.057199865579605, 35.3686161339283, 41.81391008198261, 40.579823702573776, 43.31006079912186, 42.7178967744112, 44.44942966103554, 45.433276668190956, 43.757076412439346, 48.11732344329357, 48.567112907767296, 49.27417516708374, 47.5928907841444, 47.40273758769035, 52.86995641887188, 52.69509740173817, 55.20909570157528, 52.15510077774525, 53.659280464053154, 55.41257098317146, 52.3116409778595, 39.15975250303745, 47.34294779598713, 54.76399138569832, 52.44040846824646, 53.03103357553482, 55.040358155965805, 53.97234186530113, 54.21470046043396, 52.55839593708515, 50.11983498930931, 48.8251418620348, 46.982871517539024, 47.21684016287327, 45.27499996125698, 46.085762456059456, 44.70598429441452, 43.76370705664158, 41.582931876182556, 40.712634176015854, 40.04853621125221, 37.339380383491516, 37.56010293960571, 37.79928110539913, 36.569944471120834, 40.120561346411705, 37.18617640435696, 40.818667486310005, 50.41285626590252, 51.9075782597065, 47.74926759302616, 43.88710543513298, 44.84349511563778, 49.153774827718735, 54.75435510277748, 54.53443430364132, 55.766848772764206, 52.007212713360786, 54.79713320732117, 54.2229688167572, 54.49794106185436, 51.93468600511551, 49.9370875954628, 44.50108788907528, 43.87406073510647, 45.53465522825718, 52.35329054296017, 55.99208548665047, 55.63274256885052, 57.775508388876915, 57.33350470662117, 57.597563937306404, 57.2706750780344, 54.30196277797222, 49.39866788685322, 48.76362316310406, 47.953977808356285, 47.06366278231144, 45.72978995740414, 46.45881123840809, 49.035300984978676, 49.84999246895313, 49.0706504881382, 51.5763234347105, 57.40592502057552, 66.13846063613892, 64.60810795426369, 76.46184548735619, 44.772446528077126, 0.4432640568120405, 1.4582691248506308, 0.1380066797719337, 36.675248220562935, 73.37995246052742, 63.11182424426079, 62.37537816166878, 29.918650276958942, 44.89176392555237, 53.82956072688103, 41.92197248339653, 42.88171738386154, 74.91234183311462, 28.706823103129864, 0.2181920551811345, 0.028251801304577384, 0.0425152469688328, 0.06835013118688948, 0.045735440580756404, 0.044118530859122984, 0.05021268021664582, 0.07036227165372111, 0.016197779368667398, 0.05243565741693601, 0.06484741679742001, 0.13172904553357512, 9.208746012300253, 73.14491227269173, 53.49711276590824, 35.915589183568954, 55.46696126461029, 99.09647852182388, 64.0442182123661, 45.193049758672714, 72.17780336737633, 59.99084651470184, 78.72333213686943, 7.691453704610467, 1.2742930906824768, 0.09134271225775592, 0.3198068408528343, 0.10468332882737741, 3.3730205800384283, 61.922237277030945, 67.21239700913429, 68.60942244529724, 60.76872177422047, 64.1033810377121, 60.206701532006264, 62.38565281033516, 57.38785319030285, 57.04286590218544, 54.393454268574715, 52.47959576547146, 46.21929869055748, 49.133624508976936, 50.91184549033642, 52.8095206618309, 55.5416614562273, 59.063004702329636, 56.877969950437546, 56.751159355044365, 50.03985308110714, 48.76610442996025, 47.45097599923611, 51.89894512295723, 52.62160174548626, 56.5805447101593, 58.21736387908459, 52.0806285738945, 62.94635832309723, 63.03821459412575, 58.73073913156986, 57.806206941604614, 57.886489033699036, 58.003480955958366, 49.84558090567589, 47.575100138783455, 52.20533788204193, 57.12046153843403, 56.33264601230621, 47.96731889247894, 42.09704428911209, 40.345573872327805, 43.161777555942535, 40.5263339728117, 39.445797353982925, 39.464910328388214, 39.32964138686657, 44.018490985035896, 40.73116198182106, 45.2219358086586, 45.72705030441284, 45.921280682086945, 47.47721739113331, 46.848609521985054, 50.45205496251583, 49.5740170776844, 51.44136227667332, 50.39535440504551, 51.14718206226826, 55.28548680245876, 56.26542381942272, 56.405742689967155, 55.46210132539272, 56.51523761451244, 57.83358447253704, 54.23680007457733, 37.429838329553604, 47.32415780425072, 56.55024513602257, 55.86110271513462, 54.88105170428753, 53.94439056515694, 54.958430752158165, 54.37176503241062, 55.773099437355995, 54.15791630744934, 50.91765157878399, 49.69865418970585, 50.74619717895985, 46.746907979249954, 49.15058299899101, 47.566877380013466, 46.45929001271725, 44.53295297920704, 43.38308908045292, 43.32902558147907, 38.41172844171524, 40.76442539691925, 40.22996887564659, 40.76016202569008, 40.85449956357479, 40.037721991539, 43.0837145447731, 51.88256040215492, 54.4343438744545, 49.79190118610859, 46.916500478982925, 47.025927007198334, 50.65921604633331, 56.86236798763275, 58.23774978518486, 57.61867940425873, 51.13656543195248, 56.51807986199856, 56.921701803803444, 57.6428385078907, 53.793774247169495, 52.444614842534065, 46.621780693531036, 47.093285992741585, 47.33008548617363, 55.5841051787138, 58.088752180337906, 58.55624869465828, 60.41759021580219, 59.28643271327019, 61.76314361393452, 60.98765082657337, 56.10094964504242, 52.516130805015564, 49.296244382858276, 50.673613473773, 49.8647128790617, 48.8371492177248, 50.124793723225594, 52.720632031559944, 52.614256739616394, 52.53661550581455, 54.703179448843, 60.578933358192444, 67.53107830882072, 68.4310220181942, 80.58632656931877, 47.189979404211044, 0.4204718110850081, 2.202849145978689, 0.038970441673882306, 40.15903428196907, 82.02188953757286, 69.56726744771004, 69.72851559519768, 33.08136686682701, 53.97585667669773, 39.9154407531023, 39.308123141527176, 52.53796063363552, 82.29962423443794, 36.27011775970459, 0.4758192552253604, 0.08574881867389195, 0.1454130167257972, 0.14196128788171336, 0.0350418718153378, 0.14786053070565686, 0.2046418932150118, 0.15523949725320563, 0.16150841867784038, 0.2935327647719532, 0.3996165707940236, 0.4131893831072375, 14.305530320852995, 85.57883307337761, 62.45691418647766, 45.14649085700512, 61.1018081009388, 102.80271604657173, 72.59776443243027, 52.71198369562626, 79.6730987727642, 66.19969055056572, 85.7354074716568, 8.896341025829315, 1.9234857615083456, 0.15009415772510692, 0.7264608121477067, 1.4617044967599213, 4.375374494120479, 66.02438315749168, 69.2899963259697, 74.09529447555542, 64.29647907614708, 65.39006799459457, 61.82831771671772, 64.31963503360748, 59.00958716869354, 59.69135798513889, 57.20279552042484, 56.687866151332855, 47.51316346228123, 51.574780717492104, 54.19652223587036, 54.721695855259895, 57.50411555171013, 62.068958804011345, 57.2011312097311, 59.89136405289173, 53.89014087617397, 52.33187489211559, 49.998560696840286, 54.9178147315979, 53.38776983320713, 58.59982095658779, 59.66528378427029, 54.36223894357681, 65.75620874762535, 66.83193862438202, 60.698524340987206, 60.6797381490469, 58.33184413611889, 60.315246507525444, 52.52618886530399, 51.27348728477955, 54.35949549078941, 61.25424072146416, 59.90796156227589, 51.88611701130867, 43.725131526589394, 41.45772859454155, 45.63702933490276, 41.16633743047714, 42.91609413921833, 42.78900235891342, 40.245783627033234, 47.08799287676811, 43.572527915239334, 47.347754538059235, 48.5462786257267, 48.396125882864, 52.402368709445, 48.812309950590134, 54.15443189442158, 52.97820121049881, 52.11779057979584, 55.858807638287544, 52.6895496994257, 58.37631694972515, 58.411351069808006, 61.796312034130096, 59.10306215286255, 59.50840540230274, 62.70398832857609, 55.44662855565548, 38.887595906853676, 51.08061723411083, 59.513303339481354, 57.45355926454067, 56.520899310708046, 56.99582062661648, 60.004970356822014, 58.96763361990452, 58.36405120790005, 57.683522924780846, 54.56951782107353, 53.252447694540024, 53.872521221637726, 48.93028222024441, 50.72862692177296, 48.93949672579765, 49.0622491389513, 46.70378789305687, 45.28394468128681, 45.55974528193474, 41.24165698885918, 44.058620631694794, 42.27477215230465, 43.10087822377682, 42.528773322701454, 41.98048934340477, 45.06980337202549, 56.89014449715614, 57.01008126139641, 52.82671473920345, 49.98358190059662, 50.32755084335804, 51.85686998069286, 60.754913315176964, 59.54169161617756, 60.55701993405819, 52.81294047832489, 57.74570278823376, 57.35669486224651, 61.51900291442871, 57.48328886926174, 55.916245356202126, 49.53147456049919, 49.576977118849754, 49.272301867604256, 58.86457934975624, 61.23723283410072, 62.77127131819725, 61.86316944658756, 62.68363282084465, 63.82622390985489, 63.86854603886604, 60.474393367767334, 55.981981828808784, 53.75885412096977, 53.75762298703194, 53.07284653186798, 53.112037628889084, 52.23013915121555, 54.69069331884384, 56.17044411599636, 54.972451999783516, 56.431664898991585, 64.54459056258202, 72.42466852068901, 73.564812541008, 82.45365276932716, 54.57787737250328, 0.3386553138261661, 3.3881487557664514, 0.2987649949500337, 44.23745043575764, 91.26282647252083, 75.75572177767754, 78.28865066170692, 42.02963210642338, 66.391162276268, 67.69050255417824, 54.184735268354416, 61.5926543623209, 93.38579535484314, 48.737955540418625, 0.6732300028670579, 0.2396512107225135, 0.2599992376053706, 0.23811095743440092, 0.21139564487384632], [0.05316668401064817, 0.07559652789495885, 0.04526189099124167, 0.06783471704693511, 0.12771214154781774, 0.18768090958474204, 0.15604952175635844, 7.335788039490581, 62.450743317604065, 49.0747656673193, 33.17042648792267, 35.87883375585079, 103.9715713262558, 47.89557494223118, 40.02746254205704, 69.32036429643631, 58.89011397957802, 75.4191966354847, 19.119779840111732, 0.598642083350569, 0.5420683440752327, 0.166847518121358, 0.09708364013931714, 1.673322266433388, 63.12532491981983, 61.503313556313515, 61.70094095170498, 55.50732649862766, 58.58498275279999, 53.74645538628101, 53.7372674793005, 49.85094241797924, 51.59642055630684, 45.792919769883156, 48.60938563942909, 45.3762037307024, 49.56543333828449, 50.0232669711113, 57.065284699201584, 55.06810426712036, 57.89695747196674, 55.42520150542259, 53.74822609126568, 46.65303781628609, 43.30020412802696, 46.294705644249916, 54.557985439896584, 55.02535656094551, 56.71953745186329, 53.543242290616035, 56.427086144685745, 54.37298856675625, 54.551996961236, 56.071189641952515, 55.58171510696411, 53.224013820290565, 50.406096428632736, 44.60119351744652, 47.009884268045425, 51.961531564593315, 49.574302062392235, 51.31641358137131, 49.59734782576561, 42.66139380633831, 40.07598973810673, 40.33724471926689, 40.527625903487206, 37.84175522625446, 37.45907016098499, 36.15223668515682, 40.953624844551086, 40.59842750430107, 43.72486174106598, 44.47308339178562, 42.74801395833492, 45.08078098297119, 44.216448962688446, 44.84728731215, 46.3536062836647, 44.77520518004894, 45.63869744539261, 50.62472529709339, 54.22597445547581, 52.077554538846016, 52.327459529042244, 52.04883188009262, 50.56864410638809, 56.06524296104908, 53.418027609586716, 40.43344035744667, 50.97230784595013, 52.43140675127506, 53.06083917617798, 53.19260850548744, 54.05246816575527, 52.41550840437412, 53.66293966770172, 51.20609030127525, 52.358408868312836, 48.49883057177067, 47.22364939749241, 46.660394221544266, 46.76258213818073, 44.80319827795029, 45.9467089176178, 47.09865130484104, 41.82323098182678, 41.91511005163193, 38.58374901115894, 35.89372135698795, 37.03951947391033, 37.853128015995026, 39.78118635714054, 39.42063890397549, 38.42029318213463, 41.45542211830616, 51.72577701508999, 53.2854413241148, 52.989251017570496, 45.14005780220032, 45.32940164208412, 46.81154631078243, 53.17626938223839, 57.744080275297165, 56.12255908548832, 52.00386509299278, 48.33302266895771, 52.97533616423607, 57.382909655570984, 56.30849450826645, 54.136610850691795, 49.17069531977177, 45.20999684929848, 42.93500192463398, 44.599400013685226, 49.91334646940231, 56.00387245416641, 58.2083735615015, 59.63591895997524, 59.02583509683609, 59.45843048393726, 57.64897897839546, 54.75885026156902, 53.02803933620453, 50.7165701687336, 49.06600333750248, 50.62603622674942, 50.63832476735115, 51.65576197206974, 52.506973296403885, 53.555907011032104, 56.22951194643974, 60.89889898896217, 68.68691548705101, 66.61056250333786, 80.64000248908997, 18.13254341483116, 0.639043296687305, 2.9231142718344927, 0.34653368638828397, 52.3146466165781, 63.03320646286011, 65.08366763591766, 53.38257171213627, 30.349015183746815, 48.72614957392216, 92.83107832074165, 49.98575918376446, 40.58591477572918, 79.68395859003067, 53.83195839822292, 0.2682233619270846, 0.12359417931293137, 0.025390170776518062, 0.014664043992524967, 0.024646395941090304, 0.0645046410500072, 0.09392279607709497, 0.07637381626409478, 0.08751354936975986, 0.1939697057241574, 0.2899701887508854, 0.2948693430516869, 10.979243908077478, 73.86270895600319, 55.98553843796253, 34.53294217586517, 57.67056182026863, 120.97919270396233, 53.58210280537605, 48.40886279940605, 74.1214370727539, 64.75195303559303, 82.20197707414627, 21.59949827939272, 1.0584795149043202, 0.8335515344515443, 0.11691417486872524, 0.17581781256012619, 1.5271773585118353, 65.7093496620655, 64.14912298321724, 65.66277176141739, 56.593049839138985, 59.58759695291519, 56.237119138240814, 55.92638321220875, 51.737632378935814, 52.3118119686842, 46.466217041015625, 50.59696778655052, 47.160618379712105, 53.96524764597416, 52.36179068684578, 61.24475263059139, 57.254548743367195, 60.87698936462402, 56.76599755883217, 55.49370802938938, 48.185731172561646, 45.75176417827606, 49.21451456844807, 57.76853956282139, 57.84028351306915, 59.93459053337574, 52.13923662900925, 58.917054533958435, 56.05415515601635, 58.452544659376144, 57.894704192876816, 59.8421984910965, 56.15041919052601, 52.26616121828556, 46.809361428022385, 49.60881941020489, 54.19678822159767, 52.07793451845646, 54.742207154631615, 53.04168060421944, 45.54489567875862, 43.26373748481274, 42.509797140955925, 42.77334339916706, 39.67589020729065, 40.08937641978264, 37.54421219229698, 42.75778703391552, 41.34660355746746, 44.88414153456688, 48.80507133901119, 45.113155245780945, 45.62038242816925, 47.731264159083366, 47.88675181567669, 48.56609456241131, 48.23151871562004, 49.736587554216385, 53.08102749288082, 55.13563424348831, 54.474146738648415, 55.24738624691963, 56.080947518348694, 55.4156868159771, 58.291684091091156, 54.22955386340618, 39.86465647816658, 53.62174227833748, 55.072781816124916, 54.33250933885574, 55.57149365544319, 54.478786289691925, 55.20583547651768, 56.47546894848347, 53.769292160868645, 53.946849033236504, 51.80155634880066, 50.74781969189644, 48.348693028092384, 49.72817860543728, 45.551047548651695, 45.74273206293583, 49.06238213181496, 45.34984454512596, 43.90380173921585, 41.674677953124046, 36.32647253572941, 39.42791171371937, 39.269114434719086, 40.46831488609314, 41.054665222764015, 41.264748349785805, 44.3753944337368, 54.04334485530853, 54.81976479291916, 54.95061457157135, 47.97989621758461, 47.85535790026188, 49.30412136018276, 54.27282214164734, 57.540684789419174, 58.6757180839777, 53.11966381967068, 49.45297457277775, 54.57627385854721, 60.31062975525856, 58.28474946320057, 57.318305522203445, 51.16452433168888, 47.03492872416973, 46.048262268304825, 48.532553762197495, 52.502633929252625, 59.21070657670498, 61.31554663181305, 63.49292479455471, 62.63849504292011, 62.5456166267395, 61.14823400974274, 57.80092902481556, 55.123296305537224, 52.73340314626694, 52.92727254331112, 53.41195933520794, 54.213891103863716, 54.57161910831928, 58.03457848727703, 55.53184278309345, 60.919094905257225, 64.32753100991249, 72.79180482029915, 69.33557868003845, 84.28848311305046, 18.319115303456783, 0.48365954076871276, 4.110193848609924, 0.27902057161554694, 57.02808849513531, 70.0488232076168, 70.42356669902802, 60.282439067959785, 30.944817513227463, 52.046802788972855, 90.99914342164993, 46.99659638106823, 49.384935423731804, 84.77950036525726, 60.67887559533119, 0.5224638304207474, 0.06402278682799079, 0.09923620236804709, 0.022142571506265085, 0.034118814510293305, 0.21011953678680584, 0.2093771516229026, 0.20300357253290713, 0.1747686680755578, 0.4246836178936064, 0.4431506566470489, 0.3529691754374653, 16.76065932959318, 85.50086125731468, 64.35466155409813, 45.96755459904671, 49.82153959572315, 108.79167348146439, 63.23744170367718, 54.881921857595444, 80.22365882992744, 69.32075187563896, 89.15316447615623, 23.425406701862812, 1.5220217476598918, 1.2339742854237556, 0.3311958984704688, 1.1539070005528629, 2.183186626061797, 70.13166636228561, 65.94943597912788, 67.73659408092499, 59.72779422998428, 63.15321542322636, 57.998841404914856, 61.187748089432716, 55.79615280032158, 56.532636880874634, 49.59281086921692, 53.4204176813364, 48.88452887535095, 55.876465290784836, 54.88697178661823, 64.48615729808807, 59.12877917289734, 65.20890891551971, 60.66177651286125, 59.738471657037735, 51.35188467800617, 49.03630793094635, 51.56667575240135, 59.61910866200924, 60.14744371175766, 62.70595662295818, 54.99158397316933, 60.630754977464676, 57.54257328808308, 59.23885926604271, 60.08647598326206, 62.85615116357803, 57.511160373687744, 54.53254200518131, 48.80974888801575, 53.135440573096275, 56.972923055291176, 53.439181074500084, 59.42237041890621, 55.7196819037199, 47.2485114634037, 45.714738965034485, 44.77026544511318, 45.078109726309776, 42.39554867148399, 42.144811525940895, 38.64188589155674, 46.70481003820896, 44.613865837454796, 47.71764189004898, 50.973481982946396, 48.00019472837448, 50.57067319750786, 48.37486982345581, 49.29907903075218, 51.74372345209122, 52.21102997660637, 52.91069783270359, 54.80439081788063, 58.55579651892185, 55.033043548464775, 58.752694353461266, 58.73991183936596, 58.87021444737911, 62.168627455830574, 54.834929779171944, 41.02444164454937, 55.12929618358612, 57.8290057182312, 58.45716901123524, 57.93870583176613, 56.996599584817886, 59.12458039820194, 59.87876772880554, 56.07834465801716, 55.751387402415276, 54.34765912592411, 54.45129096508026, 52.99221105873585, 53.28734502196312, 49.10592399537563, 51.3760893791914, 51.99482157826424, 47.10345804691315, 47.147060707211494, 42.302655056118965, 38.443323746323586, 41.70634925365448, 42.574899047613144, 43.70984114706516, 44.04663227498531, 42.996190041303635, 47.39559397101402, 56.233064755797386, 59.5006500184536, 58.280577287077904, 49.86101567745209, 51.78373910486698, 50.97199626266956, 57.72216685116291, 61.094242706894875, 60.85300125181675, 54.835317358374596, 51.05266213417053, 56.596420258283615, 62.581976875662804, 62.2423131018877, 59.8809602111578, 52.67338536679745, 50.09570248425007, 48.10387596487999, 50.74123464524746, 55.623163282871246, 64.01971712708473, 65.15604615211487, 64.33163478970528, 65.2352187037468, 66.94679126143456, 64.09991562366486, 60.13066001236439, 58.09479005634785, 55.24319127202034, 55.92258341610432, 55.77167071402073, 57.10029222071171, 59.79813225567341, 58.30005124211311, 59.019622430205345, 60.639870688319206, 66.3050588965416, 77.42800444364548, 72.19345852732658, 87.44114354252815, 23.842937797307968, 0.5302177299745381, 6.701548872515559, 0.44909499236382544, 62.1478121727705, 77.86650091409683, 76.66776403784752, 68.92467632889748, 42.98185721039772, 66.26256197690964, 107.85535052418709, 61.60496190190315, 55.9853408485651, 97.59888008236885, 74.6688660979271, 0.9138377232011408, 0.20147025090409443, 0.15306680055800825, 0.2060455468017608, 0.14799987635342404], [0.03557180978532415, 0.05723562368075363, 0.028150583493697923, 0.010757848958746763, 0.014594875829061493, 0.034407647253829055, 0.07942448850371875, 5.20952520892024, 68.82317617535591, 49.217960983514786, 36.57355807721615, 14.530177116394043, 23.422767743468285, 40.27393251657486, 38.332016319036484, 67.3642672598362, 58.443584740161896, 69.16033208370209, 36.28075338900089, 0.02282666839164449, 1.3997943000867963, 0.29887127049732953, 0.1251145504647866, 1.1962510971352458, 60.52860505878925, 63.601868748664856, 60.71193002164364, 54.92539532482624, 52.97838740050793, 50.05523465573788, 49.60827223956585, 46.21747098863125, 50.47201909124851, 50.34333139657974, 51.35347679257393, 51.78814306855202, 53.55314835906029, 54.282173439860344, 60.231134220957756, 56.54394507408142, 57.461082860827446, 51.80848337709904, 47.620078325271606, 41.316946148872375, 44.04528334736824, 51.970081105828285, 55.022331923246384, 63.222869485616684, 56.25539615750313, 54.89479936659336, 58.11260350048542, 57.37811431288719, 56.1405473202467, 53.26372168958187, 54.37400311231613, 48.49526256322861, 47.260047644376755, 45.50626315176487, 49.739167615771294, 53.20100225508213, 51.093232557177544, 50.45328609645367, 52.73550823330879, 46.44485078752041, 40.701580569148064, 42.37731724977493, 39.14648361504078, 38.437886238098145, 39.195668175816536, 36.106464341282845, 37.65470266342163, 40.109481140971184, 41.08283691108227, 43.68425332009792, 43.873038589954376, 44.635456278920174, 44.69784513115883, 44.27044406533241, 48.784107863903046, 50.63552051782608, 45.92712476849556, 50.40011174976826, 53.005913123488426, 50.985736325383186, 55.05032122135162, 52.64319218695164, 51.374953240156174, 55.137841925024986, 54.53307397663593, 43.55760611593723, 53.79683308303356, 51.865480318665504, 51.11608073115349, 52.629383727908134, 50.69892391562462, 53.772901967167854, 53.55349414050579, 52.27681964635849, 51.59333132207394, 49.12607051432133, 48.7580868601799, 47.46651716530323, 46.196811497211456, 43.5627244412899, 42.42776334285736, 44.658551439642906, 42.99420274794102, 40.40424272418022, 38.475618213415146, 36.478962153196335, 36.94469176232815, 38.480094373226166, 38.80628027021885, 39.341188967227936, 38.23845773935318, 42.15531416237354, 51.49373106658459, 51.29201889038086, 54.178465604782104, 49.34036001563072, 43.748842254281044, 45.26947885751724, 49.813875406980515, 57.39512600004673, 53.89946557581425, 56.328720822930336, 57.013474479317665, 47.17905879020691, 50.913205817341805, 55.13135187327862, 55.20821034908295, 54.572918638587, 50.67459002137184, 46.312652081251144, 41.41714297235012, 46.98907658457756, 52.24583990871906, 56.48985117673874, 56.87439054250717, 56.82924896478653, 60.753078013658524, 60.13176955282688, 57.635474503040314, 56.745174676179886, 55.7660736143589, 54.855520874261856, 53.40282462537289, 58.53338532149792, 55.79149805009365, 56.22488759458065, 55.66320553421974, 61.50653578341007, 65.49262449145317, 68.21871981024742, 73.82787242531776, 59.804234728217125, 1.7836271412670612, 0.07872316637076437, 1.084957206621766, 1.1781375878490508, 59.145566672086716, 59.548584446311, 69.44235295057297, 54.74438823759556, 46.549489572644234, 47.955273538827896, 60.25200270116329, 44.703940004110336, 45.549881011247635, 78.8958428800106, 44.96027044951916, 0.2327443688409403, 0.01661182726820698, 0.12064713315339759, 0.02767084624792915, 0.03517167344398331, 0.033072100559365936, 0.08224577773944475, 0.010813186272571329, 0.018888981248892378, 0.061258026980794966, 0.19797100976575166, 0.18225655221613124, 8.412806522101164, 74.84448507428169, 57.862573117017746, 39.96925346553326, 33.115937411785126, 47.521401420235634, 42.87943370640278, 45.36557950079441, 72.58819654583931, 63.802011609077454, 74.71550479531288, 38.83772358298302, 0.08524912322172895, 1.8995445524342358, 0.3070405055768788, 0.10139504316612147, 1.205198667012155, 65.30456498265266, 65.6424580514431, 65.16640439629555, 55.59991613030434, 56.374675557017326, 52.25226156413555, 51.87560297548771, 48.0362281948328, 52.22102724015713, 51.94612719118595, 54.68350030481815, 53.61502803862095, 56.39522485435009, 57.84251019358635, 62.21075959503651, 58.91613878309727, 58.759784772992134, 54.86981190741062, 50.35922594368458, 44.37654197216034, 48.89780156314373, 54.51106175780296, 56.5092833340168, 60.47460615634918, 58.0726258456707, 59.32105265557766, 61.129143834114075, 59.67192962765694, 59.54993337392807, 55.55619187653065, 55.18316209316254, 49.83960762619972, 50.665641501545906, 46.44992731511593, 49.439261108636856, 56.338452100753784, 54.53409992158413, 53.75369779765606, 54.56043630838394, 48.1645131111145, 42.75298789143562, 43.279008865356445, 40.5845582485199, 40.562166050076485, 40.59741295874119, 40.10249711573124, 39.63587075471878, 42.698331624269485, 42.990342155098915, 45.959046855568886, 45.35130366683006, 46.56749680638313, 47.081400230526924, 46.707762479782104, 50.120807737112045, 51.969720125198364, 49.52078573405743, 51.62657953798771, 55.263896360993385, 53.969146236777306, 56.981377601623535, 54.662354439496994, 54.1059996932745, 57.59067490696907, 55.89017875492573, 44.93891939520836, 55.79697735607624, 53.09570610523224, 53.788199946284294, 55.302441492676735, 54.32326443493366, 54.647812619805336, 53.60902436077595, 52.78655469417572, 52.49502293765545, 51.00004255771637, 50.23664452135563, 50.121168717741966, 46.640886068344116, 46.10880061984062, 45.755282789468765, 46.97459936141968, 46.73646613955498, 42.59650468826294, 38.213344886898994, 38.132986798882484, 37.967752665281296, 38.41315716505051, 40.018362030386925, 39.79482002556324, 40.85620567202568, 43.315813690423965, 53.89288052916527, 54.7009489685297, 55.81230193376541, 50.593532770872116, 45.097127705812454, 46.139537170529366, 51.67496994137764, 57.166773453354836, 56.68491370975971, 59.59306865930557, 58.35319899022579, 49.04708035290241, 52.92154625058174, 55.89022055268288, 57.682219594717026, 56.638423204422, 53.928404822945595, 49.14475791156292, 45.67123509943485, 49.792771339416504, 55.53534239530563, 59.671378657221794, 60.73912516236305, 58.690807074308395, 62.2833015024662, 61.46958276629448, 60.212431624531746, 58.05495299398899, 58.81568357348442, 58.13168607652187, 55.28268255293369, 60.59323959052563, 58.37386608123779, 60.37779115140438, 59.639274179935455, 64.44521829485893, 67.51663908362389, 71.47293359041214, 76.14988222718239, 63.49103629589081, 1.5956103801727295, 0.04077160068845842, 2.2111296141520143, 1.4323091553524137, 67.18782752752304, 66.15376621484756, 76.03650391101837, 60.659325644373894, 46.50548033416271, 54.45509076118469, 74.04755383729935, 53.51677671074867, 47.8305946290493, 87.89443641901016, 56.46781235933304, 0.5441837024409324, 0.04128767533984501, 0.08932325421483256, 0.043248622459941544, 0.06682262057438493, 0.08197922797990032, 0.1607775516458787, 0.11231271826545708, 0.12493077985709533, 0.20890818850602955, 0.2932026277994737, 0.3682574175763875, 11.760828718543053, 89.88964855670929, 67.59958863258362, 51.30803123116493, 22.241872809827328, 35.41047088801861, 56.73604756593704, 52.32190042734146, 80.0834159553051, 67.86270931363106, 82.6102651655674, 44.60689701139927, 0.6503516680095345, 3.2142380252480507, 1.0703087551519275, 0.5676108703482896, 1.5965193626470864, 68.61199110746384, 68.37030127644539, 68.09601679444313, 58.64310823380947, 59.58104610443115, 54.328188970685005, 54.7107258439064, 49.97504375874996, 55.85275836288929, 56.50459058582783, 56.97094716131687, 56.6376556456089, 57.10897855460644, 58.77224050462246, 64.11662712693214, 61.59956619143486, 61.28328636288643, 58.16288240253925, 51.538903042674065, 46.62786416709423, 50.163255259394646, 59.234440103173256, 59.94127817451954, 62.442227974534035, 58.2834043353796, 60.43973542749882, 65.9263788163662, 62.053797617554665, 63.5723215341568, 57.97935225069523, 57.78100289404392, 53.985842540860176, 53.27673599123955, 49.70990538597107, 55.15749827027321, 58.96422900259495, 59.84598308801651, 59.35540281236172, 57.595052272081375, 50.611540004611015, 46.66932754218578, 45.84127217531204, 43.22903014719486, 42.835903242230415, 42.855616584420204, 41.06868267059326, 41.77898235619068, 45.29144927859306, 46.42559342086315, 48.30118037760258, 49.60553638637066, 49.135965183377266, 48.52656528353691, 49.41988214850426, 53.9122024923563, 55.89763395488262, 52.77092233300209, 54.120104536414146, 58.75157721340656, 56.00574195384979, 59.26744133234024, 59.78951811790466, 57.43530124425888, 61.76071934401989, 58.22351574897766, 45.42305141687393, 58.241218999028206, 56.71676740050316, 56.74626901745796, 60.32495118677616, 56.536026298999786, 58.30075040459633, 57.90243677794933, 57.178830206394196, 55.30055299401283, 53.251668736338615, 53.97713340818882, 50.89875899255276, 51.12219840288162, 46.127282828092575, 47.79594048857689, 48.78991775214672, 49.11466732621193, 45.52860975265503, 39.64804530143738, 40.83885960280895, 40.1187564432621, 41.10855773091316, 44.028617441654205, 42.56614051759243, 42.65874154865742, 45.612995624542236, 56.844166964292526, 56.905168890953064, 60.315212309360504, 54.398633390665054, 47.88927488029003, 49.91469159722328, 54.906738325953484, 62.87710703909397, 57.0197669416666, 60.9538022428751, 61.144510209560394, 49.865301847457886, 53.63771662116051, 57.498100474476814, 59.583527371287346, 59.681216329336166, 55.46433940529823, 53.05230103433132, 48.525436744093895, 52.44171179831028, 58.916024789214134, 63.94599348306656, 61.72173723578453, 60.23623734712601, 64.58126619458199, 66.36530086398125, 63.51594015955925, 62.914379239082336, 61.034783497452736, 62.1719104796648, 59.21273946762085, 64.87470924854279, 60.50623565912247, 63.33990320563316, 62.18946933746338, 69.04690816998482, 70.40316939353943, 75.56375607848167, 77.4184213578701, 71.66594803333282, 3.4136197390034795, 0.1735608821036294, 4.125184519216418, 1.6246301354840398, 75.90797960758209, 72.82001450657845, 84.12060812115669, 70.63528373837471, 59.12024863064289, 66.11094251275063, 78.91948521137238, 57.83052943646908, 61.39940433204174, 98.37846145033836, 68.40723529458046, 0.7025250059086829, 0.14090635464526713, 0.19146617443766445, 0.1564749504905194, 0.2756525273434818], [0.017422515993530396, 0.04550851408566814, 0.09215423589921556, 0.10042713416623883, 0.016576222733419854, 0.11868015237268992, 0.1023782478296198, 5.1577287632972, 64.57058116793633, 50.946340039372444, 47.078185603022575, 35.181768760085106, 34.34530444443226, 44.742048159241676, 45.18293470144272, 66.05429515242577, 62.752238139510155, 58.511825278401375, 56.83706894516945, 0.7912513730116189, 0.4939728998579085, 0.11285876826150343, 0.09603856262401678, 0.2014730265364051, 50.78506149351597, 67.9166816174984, 58.64258386194706, 57.3850679397583, 53.57524797320366, 51.38881489634514, 51.97522222995758, 51.13365858793259, 55.094159469008446, 53.788534328341484, 55.25434747338295, 56.26475125551224, 61.49728327989578, 58.68408143520355, 54.497188702225685, 55.19555702805519, 57.3195518553257, 49.32192720472813, 45.93022160232067, 42.25061684846878, 53.384908586740494, 48.31863284111023, 69.05250906944275, 74.20044243335724, 53.31196770071983, 57.05786369740963, 55.33974789083004, 56.17387913167477, 54.59141604602337, 51.128794848918915, 46.7002122849226, 45.972106754779816, 51.25740274786949, 45.397474989295006, 47.219332829117775, 51.63010574877262, 49.289081767201424, 50.818184316158295, 50.97178727388382, 47.09322899580002, 43.17004591226578, 40.856536254286766, 39.86101247370243, 39.48923662304878, 37.169282510876656, 36.598389744758606, 37.63425976037979, 41.178774163126945, 40.25048777461052, 45.99786177277565, 40.8867484331131, 44.19119171798229, 44.416618421673775, 48.128080666065216, 44.11429524421692, 47.56971962749958, 47.28537328541279, 49.395878836512566, 51.12923562526703, 51.39833718538284, 51.88387893140316, 50.96528202295303, 50.89494779706001, 54.76065516471863, 53.388734981417656, 46.735941767692566, 55.81212714314461, 48.38291399180889, 51.721855625510216, 51.32192708551884, 52.03044466674328, 52.21955291926861, 51.157015934586525, 53.57465520501137, 50.66171631217003, 49.66175816953182, 50.40180645883083, 43.28095816075802, 42.9581730812788, 45.00946640968323, 44.71354588866234, 43.10009926557541, 40.38035340607166, 39.040028527379036, 37.5040103495121, 34.61304947733879, 38.58556151390076, 36.296366751194, 38.786897510290146, 37.89806820452213, 37.02104106545448, 43.521462455391884, 51.47347055375576, 49.86824668943882, 51.584549993276596, 51.44556865096092, 43.32915097475052, 45.66391669213772, 47.379114255309105, 51.89776338636875, 56.64066128432751, 55.41671276092529, 58.51169988512993, 49.03876639902592, 31.036865673959255, 50.96812047064304, 56.13764047622681, 58.24711628258228, 53.11992980539799, 50.261510387063026, 46.46967105567455, 42.36766196787357, 48.56287233531475, 55.10298639535904, 56.69376343488693, 56.70832805335522, 54.94878686964512, 60.36887302994728, 58.07155430316925, 58.491089791059494, 57.99522399902344, 57.8849995136261, 59.6371690928936, 56.38533018529415, 56.56251847743988, 57.79458336532116, 63.82240131497383, 59.48057569563389, 67.65392571687698, 64.8056973516941, 76.0579651594162, 18.597210980951786, 0.9287254430819303, 0.570714472560212, 0.5163139791693538, 5.251660672947764, 62.77712680399418, 55.1690686494112, 67.57026180624962, 64.32169452309608, 49.92588199675083, 42.15127497911453, 46.508998945355415, 26.68860699981451, 48.96058939397335, 75.09388089179993, 49.22822043299675, 0.6000111973844469, 0.11871478840475902, 0.04600201631546952, 0.03331214080390055, 0.019274020451121032, 0.0306060811271891, 0.036097899719607085, 0.08545008939108811, 0.05359155242331326, 0.05258017212327104, 0.19508439669152722, 0.1198683753318619, 7.665378553792834, 75.86303561925888, 55.94614215195179, 50.70490099489689, 18.05722575634718, 26.487782076001167, 52.13011331856251, 46.70091524720192, 72.14447155594826, 68.01407039165497, 66.25929415225983, 59.62342143058777, 0.891276968177408, 1.0554665140807629, 0.1463686951319687, 0.107959740125807, 0.23896987462649122, 53.68704937398434, 72.41193920373917, 63.166043534874916, 60.661556124687195, 55.83572007715702, 55.21986812353134, 54.422309920191765, 53.026963993906975, 56.76420405507088, 56.17017813026905, 56.57460942864418, 58.0735681951046, 62.45595283806324, 61.63362756371498, 58.29067334532738, 58.02962735295296, 59.68996725976467, 51.54582627117634, 45.82834146916866, 46.971810311079025, 53.05113449692726, 53.710045740008354, 66.55493348836899, 67.5091914832592, 55.115271136164665, 60.14542602002621, 57.99157999455929, 58.04378159344196, 55.03544881939888, 54.22743737697601, 49.14437033236027, 47.938174456357956, 52.3441406339407, 46.600479036569595, 49.61830370128155, 53.69963049888611, 52.63942278921604, 52.83190906047821, 54.52753387391567, 48.73452052474022, 46.07827685773373, 41.64791978895664, 40.60687445104122, 41.87395825982094, 39.77664180099964, 38.52626949548721, 40.899162366986275, 44.01012763381004, 41.011814922094345, 47.31120049953461, 43.3028943836689, 46.35294131934643, 47.22315162420273, 51.282865181565285, 45.403322875499725, 50.48441782593727, 51.42011001706123, 51.9817578792572, 53.66336524486542, 52.76010811328888, 54.72165785729885, 55.045495480298996, 54.07456398010254, 57.87591800093651, 55.17725721001625, 47.099795043468475, 58.35092291235924, 51.807324439287186, 51.78893342614174, 53.28865595161915, 54.72788952291012, 54.73358541727066, 51.96072980761528, 52.17745117843151, 51.99846938252449, 52.523035034537315, 50.559779182076454, 46.26048468053341, 44.82342079281807, 48.67658503353596, 45.43212532997131, 44.26662527024746, 40.27193762362003, 38.57853189110756, 37.30675533413887, 38.363060653209686, 39.27798315882683, 37.23628431558609, 39.34236690402031, 40.40795512497425, 39.812059700489044, 46.63352586328983, 53.32449942827225, 53.46926026046276, 56.3334933668375, 54.820197969675064, 46.852812096476555, 47.348389104008675, 51.07718221843243, 54.88005615770817, 60.53417555987835, 57.267677038908005, 60.30660957098007, 51.09751112759113, 30.278143286705017, 52.66412906348705, 57.97651380300522, 61.537416726350784, 56.74924425780773, 53.26067425310612, 50.24783872067928, 46.089011281728745, 51.83331124484539, 56.343718618154526, 59.89820748567581, 58.43017905950546, 58.11019442975521, 62.40710645914078, 62.416902333498, 63.75592768192291, 60.30190922319889, 60.72413116693497, 62.5751106441021, 60.83102323114872, 60.65688997507095, 61.50015212595463, 67.09894269704819, 63.624032959342, 71.10204309225082, 68.05038124322891, 78.36710125207901, 18.128145150840282, 0.903556365519762, 0.9891915391199291, 0.7085336709860712, 5.138991493731737, 71.72370493412018, 63.0055021494627, 74.02149483561516, 70.03015100955963, 61.11402064561844, 48.45465034246445, 62.21263289451599, 38.911587819457054, 49.01245281100273, 83.98271352052689, 59.483334347605705, 0.8875298942439258, 0.07044072408461943, 0.02160401905712206, 0.057531792554073036, 0.07423053830279969, 0.11138973888591863, 0.12204070837469772, 0.1977068794076331, 0.2982488163979724, 0.13742997165536508, 0.39752433774992824, 0.2661303570494056, 10.56005610153079, 86.32168561220169, 66.26872524619102, 62.133847922086716, 47.752512618899345, 50.56980304419994, 62.58867211639881, 55.965973287820816, 80.37293002009392, 75.66974759101868, 70.91087535023689, 66.87489151954651, 1.6098749334923923, 2.539920983836055, 0.3405726671917364, 0.5800574587192386, 0.3475913655711338, 58.5450354963541, 72.31011226773262, 67.61116281151772, 63.46061892807484, 59.22646053135395, 57.311788871884346, 58.009207248687744, 53.92696850001812, 60.7768951356411, 58.634828478097916, 61.20350204408169, 60.71657717227936, 67.96845003962517, 62.4665542691946, 59.317370653152466, 60.62153287231922, 64.06442552804947, 54.70260947942734, 49.18256588280201, 49.28921855986118, 58.460117653012276, 54.86639969050884, 65.95773473381996, 69.23656359314919, 57.5393358618021, 59.81263987720013, 60.08831508457661, 61.23779900372028, 57.15771473944187, 55.29868349432945, 52.36434035003185, 48.78829523921013, 57.119283601641655, 51.03945404291153, 53.6865060031414, 56.620465368032455, 55.983045771718025, 56.540612652897835, 59.19162020087242, 52.43725463747978, 48.81482161581516, 43.507262617349625, 42.58971065282822, 43.58543962240219, 42.132481187582016, 40.35704925656319, 43.65038953721523, 45.69938398897648, 43.368988037109375, 51.40613816678524, 45.75576916337013, 49.623927399516106, 49.716874212026596, 54.55852121114731, 50.35602651536465, 52.44349770247936, 53.731184005737305, 52.4571617692709, 57.41868853569031, 56.58727414906025, 58.281512036919594, 58.49561534821987, 57.32117436826229, 60.50376579165459, 57.65913963317871, 48.13360936939716, 60.06757199764252, 54.01070460677147, 57.24642477929592, 55.32549485564232, 58.032978773117065, 56.9563939422369, 56.4375089854002, 56.58127807080746, 53.372236266732216, 55.05530655384064, 53.521511256694794, 47.997189089655876, 47.58573196828365, 50.699273496866226, 47.727122381329536, 49.8379585146904, 42.24838636815548, 41.15349791944027, 40.9674409031868, 39.92442727088928, 42.447267696261406, 40.17410807311535, 41.92777097225189, 42.953031957149506, 42.45574504137039, 49.0831708163023, 57.13097557425499, 56.747762337327, 60.23098602890968, 58.28442648053169, 48.37301932275295, 50.408083721995354, 54.20546315610409, 56.63466140627861, 62.405396550893784, 60.05798891186714, 62.12485000491142, 52.49847695231438, 32.71445095539093, 55.64165309071541, 57.192019298672676, 65.95362335443497, 59.231008887290955, 57.24774710834026, 51.63624621927738, 49.65957708656788, 52.88719229400158, 61.12572401762009, 63.91347482800484, 60.84030993282795, 58.19848269224167, 66.94647207856178, 64.79460954666138, 68.36441159248352, 63.61472345888615, 66.12651407718658, 64.33459103107452, 65.02262011170387, 63.96809309720993, 63.77998039126396, 67.33087465167046, 67.5688710808754, 74.06078472733498, 73.87576505541801, 83.21443274617195, 25.48014834523201, 0.9722376801073551, 2.1760525088757277, 1.4777359552681446, 6.423879247158766, 76.70497164130211, 71.56975239515305, 81.69791892170906, 81.23138755559921, 64.53489348292351, 62.11482234299183, 65.82037970423698, 37.0113629847765, 64.33281272649765, 92.30347663164139, 73.01826506853104, 1.2230799137614667, 0.14830577478278428, 0.10473814385477453, 0.21369903377490118, 0.16695769736543298], [0.05383519208407961, 0.04202973024803214, 0.02473710494086845, 0.03797976729401853, 0.05251320813840721, 0.15858002268942073, 0.07674956563278101, 5.52325869910419, 70.13383984565735, 52.65552632510662, 44.83268089592457, 72.66653314232826, 37.46354252099991, 32.63894900679588, 57.84884825348854, 61.858583092689514, 67.49168962240219, 49.20503027737141, 71.69274419546127, 3.7073290161788464, 0.5808477569371462, 0.42028291965834796, 0.14639556087786332, 0.030433628271566704, 32.91708268225193, 74.95713382959366, 55.542007237672806, 61.88561484217644, 51.26979388296604, 54.41320560872555, 51.506308391690254, 55.29310919344425, 54.23573613166809, 56.773730143904686, 57.08420388400555, 61.00061193108559, 57.434336096048355, 57.05748751759529, 56.4385387301445, 56.644920855760574, 52.82048687338829, 47.637758776545525, 43.076251745224, 50.42576417326927, 50.87462268769741, 55.72807565331459, 64.22714799642563, 48.32909747958183, 55.536569729447365, 55.180331245064735, 55.707970932126045, 53.375572487711906, 46.91131755709648, 49.56299766898155, 46.62733979523182, 49.694569408893585, 48.82615640759468, 45.3763747215271, 48.20791818201542, 52.36725099384785, 49.54338312149048, 51.578211933374405, 48.53337071835995, 50.36114864051342, 42.17290721833706, 42.026052698493004, 38.60859587788582, 37.15334616601467, 39.6705286949873, 39.60748627781868, 39.55376096069813, 41.15487724542618, 41.37713871896267, 42.701683044433594, 45.5985563993454, 42.086321264505386, 45.91220296919346, 45.26805393397808, 43.57511557638645, 45.13922184705734, 49.82257314026356, 50.89822702109814, 52.388841435313225, 51.65138840675354, 52.135573625564575, 52.21828378736973, 49.0301788598299, 53.18498991429806, 54.906533136963844, 50.48797443509102, 55.52057258784771, 52.234668508172035, 50.00899873673916, 51.703692600131035, 51.643340438604355, 54.8837723582983, 52.655237540602684, 50.255179926753044, 47.66715779900551, 48.34533020853996, 46.66819520294666, 47.23344907164574, 43.88391740620136, 44.75769191980362, 43.40721018612385, 45.14255806803703, 43.02079752087593, 39.68285523355007, 35.59490159153938, 37.239460945129395, 37.096641808748245, 39.112479239702225, 36.48910380899906, 36.65278002619743, 40.62971502542496, 46.62201628088951, 49.075012654066086, 48.481685891747475, 49.38799425959587, 53.97502452135086, 45.6668995320797, 45.22618018090725, 46.05780355632305, 47.18725875020027, 53.711117282509804, 59.652607664465904, 56.34165532886982, 59.5831473916769, 21.670377776026726, 26.36994279921055, 48.60387973487377, 51.992632895708084, 57.94609643518925, 54.789389222860336, 51.51937209069729, 46.70837044715881, 47.680977657437325, 51.02230176329613, 53.378281742334366, 56.93263001739979, 59.417297691106796, 56.43017537891865, 59.346834272146225, 60.47293804585934, 60.87669298052788, 58.04152071475983, 55.76690196990967, 61.464141458272934, 66.85943394899368, 62.63067126274109, 58.96526254713535, 65.87927654385567, 64.10579770803452, 71.28980621695518, 52.308585941791534, 1.5524109732359648, 0.1473201284534298, 0.7810300996061414, 0.5463915620930493, 7.2805119305849075, 70.43201744556427, 51.024083867669106, 69.49193269014359, 67.11528941988945, 46.82939015328884, 42.00271815061569, 33.752722442150116, 36.139134988188744, 50.55888622999191, 73.8324473798275, 46.26615397632122, 0.9554621146526188, 0.14104944071732461, 0.09961040064808913, 0.06637296814005822, 0.04537923196039628, 0.021169992542127147, 0.03188035982020665, 0.06623663561185822, 0.05623926444968674, 0.020585874081007205, 0.17006141832098365, 0.16270493884803727, 6.770589742809534, 77.72187307476997, 58.79904806613922, 43.497580736875534, 53.5079649835825, 51.46083623170853, 40.460764691233635, 63.34441356360912, 66.660415828228, 73.18508371710777, 55.12100122869015, 77.85767018795013, 3.9073813939467072, 0.5957318551372737, 0.73508569621481, 0.12305063777603209, 0.1056231401162222, 35.58046616613865, 78.80815878510475, 59.123964831233025, 63.02441753447056, 53.90931084752083, 58.14441919326782, 54.24540661275387, 56.693345457315445, 55.836160853505135, 60.50953388214111, 60.59532567858696, 63.657744750380516, 60.38901574909687, 59.87923130393028, 59.6321077644825, 58.51778715848923, 55.07278561592102, 50.939884185791016, 45.54204203188419, 51.77998870611191, 52.380592077970505, 59.22326870262623, 62.055572122335434, 50.333987697958946, 59.66676190495491, 56.969491839408875, 57.22535490989685, 53.81138250231743, 51.15403309464455, 49.390380531549454, 48.329827040433884, 51.68679490685463, 50.797133445739746, 47.85001918673515, 49.663251489400864, 55.252911150455475, 54.936391934752464, 53.55128265917301, 50.85476875305176, 52.59957052767277, 44.32595148682594, 43.01822505891323, 41.11366465687752, 40.117483511567116, 40.39432905614376, 40.157571360468864, 38.70764896273613, 42.47244134545326, 42.957937493920326, 43.77709373831749, 48.60346555709839, 43.90432231128216, 48.697875291109085, 47.431920021772385, 47.08371430635452, 47.14915819466114, 51.88295938074589, 53.09971109032631, 53.58007371425629, 53.664486184716225, 54.51299965381622, 57.16328144073486, 51.30170837044716, 55.56563436985016, 56.22606173157692, 50.99006049335003, 58.329602256417274, 52.94150657951832, 51.237700805068016, 54.50872488319874, 54.18217420578003, 54.806761890649796, 53.689260855317116, 50.854593962430954, 50.67505359649658, 50.525949597358704, 48.11789721250534, 50.85409618914127, 47.62148045003414, 46.821076199412346, 46.07686333358288, 47.469298616051674, 42.72085681557655, 41.605886444449425, 35.81256151199341, 39.25166197121143, 39.9114965647459, 40.937194526195526, 38.72710011899471, 39.28132317960262, 40.80689191818237, 46.700919046998024, 51.023988872766495, 52.200238555669785, 52.835024893283844, 55.82769110798836, 47.67240151762962, 49.339470863342285, 48.36196571588516, 49.343441650271416, 55.49316085875034, 62.13704735040665, 59.0700913220644, 61.45384021103382, 26.64260856807232, 27.761247642338276, 49.35240916907787, 53.75666543841362, 60.560230761766434, 56.93749375641346, 51.66195183992386, 50.66305764019489, 51.33570894598961, 55.22998698055744, 55.5617281794548, 60.72164990007877, 58.70244964957237, 58.47629718482494, 62.45670519769192, 62.23960764706135, 64.23970252275467, 61.52320548892021, 58.18066164851189, 62.99869291484356, 70.34519970417023, 69.34137716889381, 63.721269741654396, 69.5865324139595, 66.58429071307182, 74.01001185178757, 54.032070860266685, 1.7228870443068445, 0.48356570361647755, 1.5025001764297485, 0.6417216779664159, 7.756766499951482, 77.88977846503258, 56.64379611611366, 76.97478756308556, 73.4901313483715, 53.24962444603443, 49.24197569489479, 51.74880377948284, 37.626245990395546, 55.4347237944603, 83.77643018960953, 58.87481600046158, 0.9022618818562478, 0.12838403752539307, 0.09584019397152588, 0.09793518038350157, 0.025405492415302433, 0.21017629624111578, 0.12068797354004346, 0.19495036482112482, 0.21204658260103315, 0.1522293165908195, 0.5019446345977485, 0.38018292922060937, 9.346369877457619, 94.12743955850601, 67.25385278463364, 63.91332283616066, 90.15807375311852, 53.54697749018669, 48.836784437298775, 71.77116438746452, 71.49391606450081, 79.45386573672295, 60.02143107354641, 86.46136611700058, 4.182482119649649, 1.1318633146584034, 1.3925258838571608, 0.3559263964416459, 0.18796837306581438, 38.33132855594158, 78.82101729512215, 63.60254131257534, 67.93311953544617, 55.38595721125603, 61.29224248230457, 57.56734795868397, 60.17210818827152, 60.01896120607853, 63.286713659763336, 62.460991367697716, 66.98468282818794, 61.5134172141552, 61.22647561132908, 60.57403542101383, 59.869758412241936, 59.11575727164745, 52.924620285630226, 48.261020332574844, 51.88093788921833, 56.78418718278408, 60.48735447227955, 64.97875526547432, 59.783233255147934, 59.42970782518387, 60.91716080904007, 59.4031548500061, 57.12902247905731, 52.111133337020874, 53.60222652554512, 49.38108243048191, 56.23745732009411, 52.6253217458725, 51.0609532892704, 52.54806809127331, 58.70393916964531, 56.51223957538605, 59.62162792682648, 54.76152911782265, 56.509450525045395, 47.02069468796253, 45.57612620294094, 42.721844762563705, 42.34721526503563, 44.222570434212685, 43.99425968527794, 42.88698770105839, 45.690420269966125, 46.2427282333374, 46.48398868739605, 53.93309757113457, 47.064825519919395, 50.17241656780243, 51.54856212437153, 47.698050141334534, 49.095865935087204, 56.096743270754814, 55.60773991048336, 58.03839348256588, 56.747085973620415, 58.06366592645645, 59.95972618460655, 53.801955208182335, 59.00299832224846, 57.891831547021866, 51.13935828208923, 59.66440603137016, 56.86382710933685, 54.76386599242687, 56.75742521882057, 56.34203150868416, 58.92608664929867, 57.20205456018448, 55.322052240371704, 53.91673564910889, 53.64934779703617, 51.472068428993225, 53.60993251204491, 50.06764858961105, 48.727407306432724, 49.8954114317894, 50.95098339021206, 47.19613507390022, 44.19306881725788, 39.19783025979996, 41.36688306927681, 41.68679930269718, 43.217360973358154, 40.94440653920174, 40.81421032547951, 43.221924528479576, 51.84673972427845, 54.552635326981544, 57.68693134188652, 55.718287378549576, 60.6151682138443, 50.92551335692406, 51.46841682493687, 49.24571469426155, 51.37804627418518, 57.30603218078613, 65.22610679268837, 60.857602804899216, 64.84681874513626, 22.654466070234776, 29.27131701260805, 55.7086206972599, 53.80736991763115, 62.083417028188705, 59.15166914463043, 57.21211642026901, 52.178131341934204, 53.91780339181423, 56.3695952296257, 57.069855853915215, 64.27237316966057, 61.04251988232136, 59.592042714357376, 63.27900767326355, 64.49859023094177, 66.92675113677979, 64.58478480577469, 61.772000938653946, 64.49868142604828, 69.73623678088188, 71.30011886358261, 66.15580290555954, 72.99786016345024, 70.99154502153397, 79.1154482960701, 62.27718383073807, 3.46529649104923, 0.5029166699387133, 2.9125114157795906, 1.6798208677209914, 9.053713381290436, 86.37514114379883, 63.06352123618126, 83.17894265055656, 80.19220411777496, 61.484132185578346, 59.82182778418064, 54.13260966539383, 48.3819792419672, 70.53218007087708, 89.55543369054794, 71.99913695454597, 1.1867901985533535, 0.2913108636857942, 0.22755740967113525, 0.2980398869840428, 0.20935925102094188], [0.09109870894462802, 0.0265161015704507, 0.05124608374899253, 0.04868369273026474, 0.02554034064814914, 0.052218749915482476, 0.10377027196227573, 3.834041766822338, 71.34252458810806, 51.01923152804375, 48.53484883904457, 31.737002804875374, 16.117686331272125, 48.29522989690304, 46.22492998838425, 54.90530200302601, 69.0569320321083, 47.10619769990444, 74.45760503411293, 16.807602010667324, 0.03667913122626487, 0.49801849527284503, 0.05184638845094014, 0.11037626944016665, 13.662487976253033, 74.64738965034485, 53.79035823047161, 62.634862437844276, 51.60052053630352, 56.817488595843315, 53.202841356396675, 58.33338305354118, 55.13839669525623, 59.25605334341526, 55.85815787315369, 57.6009077578783, 51.178754568099976, 59.33779835700989, 56.13419406116009, 55.39871692657471, 48.46360266208649, 49.3349415063858, 45.44768929481506, 53.00272509455681, 53.43904808163643, 59.969727247953415, 33.91215428709984, 43.51899638772011, 59.37415860593319, 56.717451363801956, 55.27937673032284, 49.00252774357796, 49.01588782668114, 47.35161133110523, 48.31725351512432, 48.236169666051865, 50.94146490097046, 45.070665925741196, 47.89064660668373, 51.11528657376766, 49.11073453724384, 53.345094323158264, 47.201891764998436, 49.84192170202732, 47.03813195228577, 43.047392293810844, 42.48832829296589, 36.349297910928726, 38.50126303732395, 37.035130709409714, 38.371317610144615, 40.448837131261826, 40.397737473249435, 41.77705965936184, 43.00097018480301, 43.15622605383396, 42.452351823449135, 46.74993261694908, 46.39323055744171, 45.557024627923965, 46.883408054709435, 49.736192375421524, 48.39916571974754, 50.208575427532196, 50.293417274951935, 53.30483928322792, 53.01806107163429, 53.951385989785194, 57.44282104074955, 51.65247514843941, 53.15864212810993, 50.21088570356369, 50.82853876054287, 50.123182609677315, 50.52846506237984, 49.894723668694496, 48.94446685910225, 49.215361922979355, 49.63394746184349, 47.746261954307556, 48.29309061169624, 46.62391237914562, 45.47657534480095, 43.403383791446686, 43.126215264201164, 43.781927078962326, 40.34028075635433, 39.31775562465191, 37.05349512398243, 38.11266928911209, 36.4046685397625, 37.437608912587166, 38.84524717926979, 39.12522755563259, 41.74407362937927, 48.22028271853924, 47.837457060813904, 46.8885263800621, 47.2111214697361, 52.4345263838768, 47.953172251582146, 45.30010901391506, 48.76025654375553, 46.79915137588978, 50.04709929227829, 56.58417351543903, 54.63972665369511, 61.89950689673424, 53.88946831226349, 35.44861324131489, 39.37277667224407, 49.427306950092316, 56.185312718153, 54.63361658155918, 52.611771672964096, 46.79765045642853, 48.51306460797787, 47.74558179080486, 52.16911442577839, 54.005289897322655, 61.16369538009167, 57.40225061774254, 50.92777043581009, 58.53351831436157, 57.42222614586353, 62.72782064974308, 70.99641636013985, 66.44223913550377, 53.76200035214424, 60.070288851857185, 59.378372579813, 64.84423488378525, 59.15478117763996, 74.5092062652111, 29.736421555280685, 0.24837019911501557, 0.26922434102743864, 0.986542368773371, 0.2525143220555037, 10.309288557618856, 75.19253879785538, 51.479744017124176, 62.32708655297756, 66.91413581371307, 55.01235745847225, 45.48764035105705, 27.22916219383478, 45.99163770675659, 60.673818066716194, 68.47714394330978, 41.00187465548515, 0.9267750789877027, 0.10625238486682065, 0.08402718449360691, 0.08645814115880057, 0.14884855190757662, 0.08674923374201171, 0.051885722277802415, 0.09624860525946133, 0.16160506114829332, 0.04938052858051378, 0.3674538794439286, 0.19718308642040938, 5.9811317548155785, 80.8993461728096, 61.1794189363718, 54.18243259191513, 51.4567856490612, 24.546382650732994, 51.123281344771385, 56.85626931488514, 60.12301862239838, 77.18060731887817, 51.229288056492805, 82.4287337064743, 17.11957097053528, 0.042233319909428246, 0.6456889025866985, 0.062282739963848144, 0.3251195792108774, 14.108746480196714, 77.67197415232658, 57.320311814546585, 64.9643312394619, 54.116331338882446, 60.28710901737213, 54.280186146497726, 58.821003288030624, 56.67856425046921, 62.79795728623867, 58.066318184137344, 60.448984131217, 52.972630709409714, 59.6809047460556, 57.023635134100914, 59.542991146445274, 50.81891767680645, 52.00034648180008, 47.33559899032116, 54.133172035217285, 58.23132053017616, 60.762288719415665, 35.3365458548069, 45.92787712812424, 59.81949470937252, 59.97137635946274, 57.88888290524483, 52.0616789907217, 50.117437317967415, 50.50812475383282, 48.43805283308029, 50.294576212763786, 53.28330583870411, 47.618816792964935, 52.75768384337425, 52.91105881333351, 51.62475563585758, 56.08048774302006, 50.375310480594635, 53.83486904203892, 49.19814124703407, 47.1751070022583, 43.789078295230865, 40.25173790752888, 41.703548803925514, 40.748538449406624, 41.06556683778763, 41.12001791596413, 43.552506789565086, 43.91749620437622, 44.350992143154144, 46.344954147934914, 46.498211324214935, 49.314798787236214, 48.73314879834652, 49.63813103735447, 50.353530049324036, 51.03851169347763, 50.91735519468784, 52.76824347674847, 52.295184060931206, 55.19087187945843, 54.10510294139385, 56.703069135546684, 58.586677461862564, 52.62960031628609, 55.234174355864525, 51.98386296629906, 52.3814432322979, 53.78799855709076, 53.661286756396294, 53.84869650006294, 52.66078144311905, 52.59808860719204, 52.270340994000435, 47.83346347510815, 48.93399082124233, 49.06208194792271, 49.864811673760414, 45.84210053086281, 45.57307116687298, 44.13945369422436, 41.82626321911812, 41.18762768805027, 39.499982446432114, 40.55012829601765, 40.30747711658478, 40.57407461106777, 39.38690431416035, 41.638610288500786, 46.36887386441231, 50.591070502996445, 54.110259264707565, 50.47899171710014, 50.928306207060814, 56.15266866981983, 50.31873531639576, 47.7377238124609, 51.96255370974541, 48.13307359814644, 52.86038473248482, 58.300875797867775, 56.28940813243389, 62.210964784026146, 60.79793460667133, 42.911716774106026, 41.77464298903942, 49.40144173800945, 56.05850592255592, 58.03109407424927, 56.66016943752766, 49.771215096116066, 49.628901332616806, 50.4256159812212, 54.32831056416035, 58.612120896577835, 63.74935023486614, 60.02659119665623, 52.63460464775562, 60.5079759657383, 59.53428581357002, 65.67703619599342, 69.80136528611183, 68.47910463809967, 59.91154856979847, 64.4812935590744, 63.21623884141445, 69.77566346526146, 63.078173249959946, 79.68718841671944, 34.037349969148636, 0.21121603029314429, 0.50523258629255, 2.3564589908346534, 0.3350668813800439, 11.389236208051443, 83.28575491905212, 57.70548194646835, 70.55858865380287, 73.58358353376389, 62.113439217209816, 54.742096960544586, 37.74843603372574, 42.06937797367573, 64.24240797758102, 77.61099502444267, 51.623763889074326, 0.9665329393465072, 0.07029168598819524, 0.04969507303030696, 0.041536465505487286, 0.10171175468713045, 0.16466406028484926, 0.13985361816594377, 0.16120982298161834, 0.34858257800806314, 0.1389735349221155, 0.5431597167626023, 0.26018052943982184, 7.201222535222769, 96.22049644589424, 63.89148160815239, 69.64056551456451, 38.43508578836918, 23.630324006080627, 66.25719666481018, 60.70034444332123, 67.49801248311996, 80.6907069683075, 58.14564272761345, 88.03445890545845, 20.572001114487648, 0.16708015173207968, 1.1693670647218823, 0.2645551337627694, 0.46455309726297855, 16.133860163390636, 83.39062169194221, 60.51717147231102, 70.45961916446686, 57.2261680662632, 63.90310138463974, 57.32036501169205, 63.56525011360645, 58.84374126791954, 64.98939469456673, 62.28409945964813, 62.751664370298386, 54.67674046754837, 63.03396262228489, 59.328834637999535, 62.04726576805115, 52.13600680232048, 55.69853603839874, 49.703487530350685, 57.46462807059288, 61.39215052127838, 62.516969963908195, 41.39990709722042, 47.797779589891434, 61.49111621081829, 62.54710614681244, 59.0811563283205, 55.15169598162174, 54.30317871272564, 52.91262052953243, 51.05449363589287, 51.402558758854866, 57.630861550569534, 50.52155323326588, 56.121996715664864, 57.49373070895672, 54.8059069365263, 61.48466035723686, 54.324088990688324, 57.049378752708435, 52.8146655857563, 49.690762013196945, 47.97986961901188, 43.101269602775574, 45.68025201559067, 42.889301776885986, 42.93375939130783, 44.56689275801182, 45.55751480162144, 47.37378694117069, 46.139749959111214, 49.994502514600754, 49.53933633863926, 51.91575542092323, 51.097058951854706, 51.39124296605587, 52.16104365885258, 55.11145234107971, 52.64138728380203, 54.98750679194927, 55.49927853047848, 58.90945874154568, 58.119355738162994, 59.00477282702923, 60.6033356487751, 55.42629584670067, 57.51401402056217, 54.79964107275009, 56.674582064151764, 57.15590603649616, 56.37798137962818, 57.56833590567112, 55.223584324121475, 56.19211055338383, 53.87863889336586, 53.312465474009514, 52.896167412400246, 49.57609176635742, 51.69309116899967, 49.56102937459946, 47.75188185274601, 48.640524968504906, 43.11287797987461, 44.75744113326073, 41.656788513064384, 43.33814889192581, 41.75662435591221, 42.59886436164379, 42.60359510779381, 43.84555086493492, 48.464081436395645, 51.70381039381027, 56.29487603902817, 56.440385431051254, 55.170751959085464, 59.71636064350605, 52.99865551292896, 50.40053352713585, 53.59665222465992, 50.625207871198654, 55.07650941610336, 60.363663509488106, 58.0193755030632, 65.12892320752144, 56.733459904789925, 33.55510264635086, 43.44440259039402, 51.93316228687763, 60.32197214663029, 59.749586060643196, 59.41346749663353, 51.79076112806797, 55.28419487178326, 54.39639151096344, 55.94704270362854, 60.343201607465744, 65.61500072479248, 62.95354753732681, 53.46275880932808, 62.76247099041939, 60.642313957214355, 67.01052144169807, 70.81540927290916, 69.20157507061958, 62.21373103559017, 68.77966091036797, 64.35816496610641, 72.58875891566277, 66.2703287601471, 82.78230473399162, 37.50273361802101, 0.9140793664846569, 0.44627186260186136, 3.657618183642626, 0.5396519706118852, 12.763674706220627, 91.26338884234428, 64.3942554295063, 79.08231407403946, 79.29725334048271, 70.36124244332314, 64.18173283338547, 44.15866546332836, 52.816143706440926, 79.17256683111191, 85.48448413610458, 64.52721789479256, 1.56037688953802, 0.25563894188962877, 0.13680404430488124, 0.2466150643886067, 0.2482285676524043], [0.05813008974655531, 0.10068316027172841, 0.06649950431892648, 0.05714574217563495, 0.0449936454242561, 0.13605339161586016, 0.12254542816663161, 2.3288798332214355, 61.94136545062065, 57.38020800054073, 39.535518139600754, 42.773054614663124, 38.52623149752617, 40.11677294969559, 38.05060721933842, 49.74356397986412, 67.30713352560997, 47.78277039527893, 70.99811866879463, 34.06566604971886, 0.05757366452598944, 0.5911073251627386, 0.44383049360476434, 0.0069903506573609775, 2.9778899950906634, 59.563202261924744, 58.569012209773064, 57.18932904303074, 54.2871967703104, 54.18610319495201, 55.47230377793312, 57.080738469958305, 56.4930772036314, 60.073796063661575, 56.03862538933754, 46.78892992436886, 54.70730982720852, 59.62372161448002, 56.44724026322365, 54.36487980186939, 50.7386963814497, 49.1148117184639, 51.312613785266876, 51.652087569236755, 57.477254793047905, 46.484912037849426, 34.942100420594215, 57.62546584010124, 54.67148914933205, 54.878570437431335, 51.70920990407467, 51.80861636996269, 47.2651431709528, 48.1995814293623, 46.62905730307102, 49.70462366938591, 47.74761848151684, 45.282386764883995, 48.581438139081, 50.017571076750755, 48.58324684202671, 51.874664425849915, 48.571262285113335, 49.09273870289326, 50.188105925917625, 45.47211058437824, 44.739893674850464, 40.963348522782326, 40.14461785554886, 40.73949873447418, 38.220651894807816, 38.767130970954895, 39.275460094213486, 40.55968098342419, 42.01229363679886, 42.2154725342989, 42.18233071267605, 44.349647015333176, 45.54347075521946, 46.24311961233616, 46.69391602277756, 49.71680961549282, 48.77651207149029, 50.18264181911945, 52.875963896512985, 52.92566142976284, 54.48895074427128, 55.46047501266003, 56.04696214199066, 52.27780379354954, 56.640710681676865, 51.70516312122345, 49.653930589556694, 50.428716614842415, 51.1431884765625, 51.5561693161726, 49.551963061094284, 50.17484463751316, 48.85254219174385, 48.669354021549225, 48.43512699007988, 47.79822416603565, 48.5716612637043, 44.404200688004494, 43.12256745994091, 42.38006070256233, 40.67678689956665, 37.5209878385067, 38.163875341415405, 34.94429670274258, 39.14987303316593, 37.18447409570217, 39.927953481674194, 43.43201145529747, 44.773381277918816, 50.867783054709435, 46.93507768213749, 48.19184124469757, 45.939846485853195, 51.050066873431206, 48.730477541685104, 43.22990410029888, 49.490968734025955, 46.83765470981598, 46.43964506685734, 53.51594835519791, 55.29484190046787, 53.42857964336872, 59.425528049468994, 66.09890475869179, 60.13314127922058, 57.98279106616974, 55.00396370887756, 57.58707270026207, 54.78182002902031, 55.422811433672905, 48.62057223916054, 48.95264782011509, 48.783404901623726, 55.347393080592155, 52.80718758702278, 59.531895741820335, 53.242222443223, 56.4363918453455, 58.16907986998558, 63.964794874191284, 51.77748084068298, 53.364834263920784, 55.72392627596855, 67.17346429824829, 58.55228930711746, 67.66211047768593, 56.117554754018784, 71.78522363305092, 19.61693186312914, 0.17366127984132618, 0.19180821545887738, 0.7571083644870669, 0.22249143541557714, 16.238700337707996, 75.22621259093285, 54.75867547094822, 66.94847837090492, 62.63545900583267, 31.42586600035429, 43.2535882294178, 29.425672329962254, 37.07665488123894, 49.81642886996269, 64.73423078656197, 33.89950476586819, 0.791978380875662, 0.21765275130746886, 0.07188823859905824, 0.10583244802546687, 0.08041211636736989, 0.09292374656070024, 0.09703031682875007, 0.0593020448286552, 0.032300411694450304, 0.2060683158924803, 0.14371073775691912, 0.09295111696701497, 3.473588121123612, 74.01359885931015, 60.14611378312111, 52.78229512274265, 37.771276608109474, 30.07974073290825, 54.803425669670105, 52.76653736829758, 56.315299943089485, 75.13085290789604, 54.35189589858055, 76.28631010651588, 37.696853801608086, 0.10735926101915538, 0.8140225417446345, 0.17894667747896165, 0.060293580099823885, 3.017468433827162, 63.77105847001076, 61.91157124936581, 58.84357027709484, 56.08950845897198, 58.29124331474304, 58.58177572488785, 61.86614088714123, 58.224883675575256, 60.953471660614014, 58.91208820044994, 52.25663512945175, 55.85397429764271, 62.42664121091366, 59.47436302900314, 57.241530641913414, 51.91986680030823, 50.93146003782749, 53.75207908451557, 54.051286429166794, 59.060800820589066, 46.91504515707493, 36.45750090479851, 59.270617961883545, 57.287682965397835, 56.594147980213165, 54.10212390124798, 52.97448880970478, 50.57929113507271, 50.18445432186127, 48.3063443005085, 51.86552211642265, 49.743028208613396, 47.78482988476753, 51.43424145877361, 53.43882009387016, 53.09013940393925, 53.26327331364155, 52.81555473804474, 51.213458105921745, 53.67960937321186, 48.922811821103096, 46.560904160141945, 41.66757993400097, 41.401240825653076, 42.93116793036461, 42.74468153715134, 41.6839836537838, 41.70591987669468, 43.5344273597002, 46.03950373828411, 46.43365278840065, 46.58566363155842, 46.06784641742706, 49.560565799474716, 48.36900673806667, 50.84229402244091, 52.21752382814884, 50.21858409047127, 50.07335968315601, 54.3076054751873, 53.08326557278633, 56.40649504959583, 56.190119460225105, 57.2686991840601, 50.30846826732159, 57.65057109296322, 53.7201151996851, 53.32389146089554, 51.51182949542999, 52.554067969322205, 53.295632377266884, 52.95652337372303, 51.321797892451286, 50.97910948097706, 50.01180678606033, 51.841754391789436, 50.36277115345001, 51.0397694259882, 45.83941027522087, 44.79574307799339, 44.49354909360409, 42.96043395996094, 39.5888102799654, 39.919901713728905, 38.713090270757675, 39.90621864795685, 39.339061081409454, 41.822820603847504, 44.704008400440216, 46.92777827382088, 55.09752228856087, 51.398553773760796, 54.35374639928341, 51.98365017771721, 54.84645076096058, 49.78319585323334, 46.02072134613991, 52.94857420027256, 48.86569708585739, 48.96973930299282, 54.58822041749954, 59.022168293595314, 55.301514342427254, 60.4825971275568, 68.57655420899391, 64.2385321855545, 61.46778546273708, 55.8426509052515, 58.96432399749756, 58.91170062124729, 57.79634267091751, 50.37901148200035, 51.934572011232376, 52.312788516283035, 57.386435866355896, 56.94323904812336, 62.978375405073166, 54.033579379320145, 58.23613487184048, 57.94715657830238, 70.12259244918823, 56.98577016592026, 57.71436586976051, 59.09288249909878, 68.73134270310402, 60.54370164871216, 71.39505296945572, 59.0887825191021, 78.42783719301224, 22.509237863123417, 0.21972540649585426, 0.4385425429791212, 2.1274839900434017, 0.10337622123188339, 17.53850419074297, 80.74356973171234, 61.73498712480068, 70.7673342525959, 70.29299810528755, 39.37244229018688, 51.18166521191597, 30.716993138194084, 30.366764031350613, 56.74913786351681, 72.74274945259094, 44.559927731752396, 1.3429633621126413, 0.21224862488452345, 0.015513611051574117, 0.08622329594800249, 0.1877281695487909, 0.22633754153503105, 0.1840220027952455, 0.1625191792845726, 0.1716561452485621, 0.3257410536753014, 0.2847532171290368, 0.1547558989841491, 3.888549841940403, 85.45706480741501, 68.96962031722069, 61.536618769168854, 55.52118435502052, 55.99744699895382, 56.69576592743397, 52.375481352210045, 61.04932151734829, 81.58335506916046, 58.43656271696091, 83.45622897148132, 39.52306620776653, 0.25624880916438997, 1.292623900808394, 0.9193621517624706, 0.1576362334890291, 4.245743975043297, 66.73767328262329, 64.72090870141983, 64.44894209504128, 58.40493701398373, 61.760054379701614, 60.27035191655159, 64.88249123096466, 62.293397560715675, 64.1415385901928, 61.297569796442986, 54.053148329257965, 57.57859155535698, 65.41794329881668, 60.43574944138527, 59.49200168251991, 54.89224970340729, 54.64323006570339, 56.71042174100876, 56.197878643870354, 61.65384627878666, 49.20733295381069, 38.318021669983864, 60.19686006009579, 60.13536795973778, 58.07893730700016, 55.05080759525299, 55.58847874403, 51.3945297896862, 53.89038406312466, 50.18711417913437, 54.12644259631634, 53.1153966486454, 50.39779007434845, 54.16374899446964, 56.81409917771816, 54.22626703977585, 57.47049495577812, 53.854263201355934, 54.311165884137154, 57.70546294748783, 50.58261215686798, 48.313860297203064, 44.461045637726784, 43.03795360028744, 45.08688725531101, 43.98859038949013, 44.27925579249859, 44.411063119769096, 46.02921389043331, 49.256874695420265, 46.87355898320675, 46.29295393824577, 49.451994225382805, 51.289450228214264, 51.11327648162842, 51.30295850336552, 55.23282542824745, 52.72356167435646, 53.31714682281017, 57.524889037013054, 55.985078662633896, 61.9426079839468, 59.311898946762085, 57.49584339559078, 50.783378183841705, 60.41439838707447, 58.07233326137066, 56.45466886460781, 55.03595419228077, 57.31957845389843, 56.01248659193516, 55.03993257880211, 55.7106763869524, 51.997375041246414, 51.90544657409191, 57.293599247932434, 53.51996473968029, 54.09396953880787, 47.393709272146225, 48.71061980724335, 48.12417447566986, 47.96271733939648, 42.384821847081184, 41.4858964830637, 38.68315927684307, 43.30009013414383, 41.158612444996834, 44.419209882617, 48.47815968096256, 50.471772104501724, 57.521013244986534, 56.33362255990505, 56.90639242529869, 55.562286749482155, 61.53826028108597, 53.42541441321373, 48.534879237413406, 56.88346445560455, 51.74848459661007, 52.7391142398119, 56.70776568353176, 60.495565831661224, 56.40499792993069, 65.20678862929344, 69.0987753868103, 57.112740352749825, 61.12958841025829, 58.75514902174473, 61.51528671383858, 62.28170558810234, 60.06993547081947, 52.69130140542984, 54.837057664990425, 56.03580214083195, 60.53642503917217, 58.32117050886154, 66.79790765047073, 55.60207441449165, 59.62329223752022, 59.07565422356129, 66.02633625268936, 57.0229397714138, 63.54670710861683, 62.696757316589355, 72.82785728573799, 63.63521195948124, 76.65118172764778, 63.207571506500244, 80.50784558057785, 25.741068944334984, 0.3326211782405153, 0.6926940428093076, 3.5558717558160424, 0.24679553986061364, 19.29424937814474, 92.68626809120178, 68.12425687909126, 78.89594167470932, 75.69419547915459, 45.89089371263981, 58.818552419543266, 46.004401221871376, 46.707162111997604, 67.60766699910164, 80.56767717003822, 57.04384244978428, 1.587396883405745, 0.3434592951089144, 0.15833619749173522, 0.2762676787097007, 0.22629041515756398], [0.037336477398639545, 0.12075898222974502, 0.04814020314370282, 0.0783712176780682, 0.02079290174151538, 0.2377394976792857, 0.058701331945485435, 2.578957239165902, 66.0844275355339, 55.48881009221077, 42.48065270483494, 43.54850560426712, 23.033294342458248, 35.16113206744194, 24.34976790100336, 48.963036462664604, 66.93989843130112, 49.716942608356476, 65.12936398386955, 49.61193144321442, 1.1136240558698773, 1.301604243926704, 0.09080177565920167, 0.05018635252781678, 0.22199605184141546, 39.98939238488674, 70.28844594955444, 55.50876662135124, 59.09357026219368, 54.219309613108635, 61.53578281402588, 59.34854798018932, 60.24004474282265, 55.91812625527382, 52.56583593785763, 53.169878125190735, 61.234842762351036, 56.68433994054794, 55.976760908961296, 51.47720195353031, 51.14565074443817, 51.144856587052345, 52.363853976130486, 53.72698903083801, 54.50490228831768, 42.36726298928261, 49.7700447589159, 56.643180549144745, 57.874363884329796, 55.86940906941891, 56.05322040617466, 50.39428286254406, 48.351831659674644, 49.39469330012798, 54.759367033839226, 49.898006692528725, 50.021576061844826, 45.09043246507645, 48.62500660121441, 50.82102656364441, 49.54586058855057, 49.8507334291935, 48.38427051901817, 47.78575323522091, 51.23376801609993, 45.646335035562515, 46.41410283744335, 42.355795204639435, 39.158331379294395, 39.999146461486816, 39.322581365704536, 40.21403253078461, 40.048023238778114, 39.54208418726921, 41.891878098249435, 44.960395842790604, 43.88172872364521, 44.478745087981224, 46.20486706495285, 47.60791897773743, 47.889791652560234, 49.728577584028244, 50.94293162226677, 45.575092658400536, 49.34947572648525, 53.68334077298641, 53.80268856883049, 57.43649058043957, 55.662240386009216, 54.877943471074104, 57.93360650539398, 50.71172162890434, 50.744669660925865, 51.888564079999924, 51.89185470342636, 50.7512167096138, 48.28231818974018, 49.97737683355808, 48.7639195472002, 48.61028619110584, 49.13789168000221, 47.07202613353729, 44.10939730703831, 43.653186187148094, 43.42402808368206, 41.72836907207966, 38.84571075439453, 36.12686164677143, 37.496623545885086, 38.878438398242, 37.37642839550972, 38.166406005620956, 41.202963665127754, 41.760188564658165, 48.67845453321934, 48.11003163456917, 47.529806569218636, 49.4017419219017, 48.592442348599434, 51.38305060565472, 46.85480318963528, 43.00956152379513, 50.6079263985157, 47.53301739692688, 45.987549126148224, 49.77997362613678, 53.402368649840355, 58.238920122385025, 54.708848744630814, 56.519569382071495, 57.842779979109764, 60.57921074330807, 58.93229931592941, 56.76275633275509, 54.79276344180107, 53.633761033415794, 54.2965442687273, 53.28034579753876, 49.35508422553539, 51.6602723300457, 54.335564374923706, 54.907570481300354, 58.43190036714077, 60.43132267892361, 51.07646405696869, 46.023506596684456, 49.14831832051277, 64.45809960365295, 60.29293030500412, 65.3925758600235, 59.82956036925316, 67.90589019656181, 60.226126089692116, 66.39648959040642, 10.672621261328459, 0.1711340295150876, 0.22080088237999007, 1.2129662814550102, 0.20160146261332557, 21.53422348201275, 72.77947828173637, 58.296658024191856, 69.92840006947517, 51.2189906090498, 31.097276732325554, 38.69888283312321, 45.71061618626118, 49.516256377100945, 49.71554048359394, 67.76758521795273, 35.15817582607269, 0.7124939491041005, 0.18900985858635977, 0.18642635346623138, 0.06087729780119844, 0.014837918060948141, 0.027981561215710826, 0.0731318183534313, 0.05840676611114759, 0.0785239071410615, 0.010202249377471162, 0.18099910172168165, 0.03404713417694438, 3.527253591455519, 77.41069257259369, 61.45694464445114, 48.62030245363712, 39.141661673784256, 28.669360913336277, 40.99088944494724, 32.68211469054222, 59.16967257857323, 70.48751726746559, 53.856938257813454, 71.40788108110428, 54.27730590105057, 1.3440534286201, 1.829752391204238, 0.18850936903618276, 0.09719604582642205, 0.2520796313183382, 44.50644180178642, 72.8053092956543, 59.84099015593529, 62.190065905451775, 57.7842403203249, 64.82183888554573, 61.004453524947166, 60.86249694228172, 59.02869634330273, 55.72811745107174, 57.35997408628464, 62.38423548638821, 57.92134456336498, 60.60835137963295, 53.737092688679695, 54.34306137263775, 54.18479986488819, 55.792831778526306, 55.49934692680836, 55.86382336914539, 42.47638173401356, 50.01211076974869, 58.972493559122086, 58.976540341973305, 56.842031478881836, 57.73473657667637, 49.71505790948868, 51.81597277522087, 51.3162387907505, 52.9130233079195, 52.75658570230007, 52.36348159611225, 48.75627435743809, 52.66716510057449, 53.07002708315849, 52.77537189424038, 54.920949563384056, 50.70582054555416, 50.21730735898018, 54.78411130607128, 48.377514481544495, 46.49812012910843, 45.50446204841137, 41.81979976594448, 42.43129715323448, 41.15594498813152, 42.072839587926865, 41.933098286390305, 41.37611657381058, 43.928432017564774, 47.08287455141544, 44.66829791665077, 46.190344244241714, 48.623365089297295, 49.95719991624355, 50.07436282932758, 51.03937424719334, 51.70702122151852, 48.443174958229065, 50.82468196749687, 54.694504514336586, 55.93255028128624, 58.34395028650761, 58.300617411732674, 55.84095999598503, 58.763816356658936, 53.89998994767666, 53.925456181168556, 53.64150121808052, 53.21558967232704, 49.9972003698349, 51.02125681936741, 51.01578511297703, 50.88638685643673, 50.37580065429211, 50.41229009628296, 47.99382247030735, 47.82958388328552, 46.26358911395073, 45.4052759706974, 43.24497029185295, 41.20253808796406, 39.44471821188927, 39.69549335539341, 41.48883752524853, 39.467801973223686, 40.58469124138355, 42.95121565461159, 44.5859145373106, 51.48023039102554, 50.358948558568954, 51.70774318277836, 53.37353579699993, 51.496953293681145, 54.09124128520489, 49.50432501733303, 43.86735409498215, 53.441035374999046, 49.65440936386585, 48.48302721977234, 50.632590875029564, 55.14338202774525, 61.2330112606287, 56.730553060770035, 56.69059440493584, 59.39636841416359, 59.8082435131073, 59.41151440143585, 59.74919468164444, 58.007356747984886, 54.567496329545975, 56.542155370116234, 55.48110790550709, 51.60694219172001, 55.06992056965828, 54.156719371676445, 58.93749363720417, 61.50028891861439, 62.725757360458374, 55.32274380326271, 48.44101667404175, 50.16113117337227, 65.70249482989311, 64.21745851635933, 68.6539788544178, 62.65775240957737, 71.29173651337624, 62.91594095528126, 73.07718470692635, 11.988192368298769, 0.12379148669424467, 1.094781698193401, 1.8169988505542278, 0.31555691733956337, 24.40445076674223, 78.8919746875763, 65.40712147951126, 75.22840887308121, 57.87794329226017, 31.929561272263527, 44.116529524326324, 46.54080703854561, 37.59390972554684, 59.15475457906723, 73.46047773957253, 42.14974746108055, 0.9433251502923667, 0.14483345876215026, 0.12843500822782516, 0.09509839510428719, 0.03874121823173482, 0.0905512785539031, 0.2714767592260614, 0.18270849046530202, 0.20396187814185396, 0.16571311571169645, 0.453443918377161, 0.15011551673524082, 4.2642133589833975, 88.45807537436485, 70.34760117530823, 59.14208225905895, 59.90144871175289, 38.81093122065067, 48.084158822894096, 34.78880524635315, 62.49739721417427, 78.93386363983154, 60.25208629667759, 76.75355583429337, 59.3739078193903, 2.1869014017283916, 3.077924852259457, 0.3652599424822256, 0.206201353284996, 0.446030130260624, 48.702951818704605, 75.14212310314178, 60.91480873525143, 64.30369108915329, 60.98456919193268, 66.14699497818947, 63.20437967777252, 62.56325148046017, 61.67241208255291, 59.02989707887173, 60.77154502272606, 65.31555399298668, 60.89509919285774, 63.03065299987793, 55.4389301687479, 55.90812899172306, 56.505779922008514, 56.27504110336304, 59.302638843655586, 57.879979982972145, 42.63082064688206, 52.2750299423933, 59.95051167905331, 62.79250077903271, 59.13395829498768, 60.97221605479717, 53.23566399514675, 52.64031954109669, 53.95855240523815, 59.01716396212578, 54.974036514759064, 56.699991300702095, 50.56773595511913, 55.22373631596565, 57.676474303007126, 56.141387075185776, 57.70987071096897, 52.76323914527893, 53.1861412525177, 59.440525844693184, 51.318932846188545, 50.33571280539036, 46.76177278161049, 45.70029594004154, 43.97479712963104, 44.241793602705, 45.08742682635784, 45.01548148691654, 44.58121418952942, 46.1677772551775, 51.002972200512886, 48.508611246943474, 49.201374873518944, 53.17677855491638, 52.10916884243488, 53.14010292291641, 54.75020952522755, 55.61233006417751, 51.925000324845314, 52.81600311398506, 59.35572199523449, 57.80398406088352, 60.99194459617138, 59.81493875384331, 57.512395307421684, 61.99046641588211, 57.19318963587284, 55.45802794396877, 55.88591158390045, 58.576319217681885, 54.870165288448334, 53.85778561234474, 54.62318994104862, 53.33178363740444, 52.25142180919647, 54.69336837530136, 50.69990426301956, 48.55439879000187, 48.95708218216896, 48.81101042032242, 45.367923974990845, 42.790180295705795, 40.53616404533386, 43.48912999033928, 42.77512930333614, 41.3978286087513, 42.454855889081955, 44.59067188203335, 47.793554216623306, 56.10558919608593, 55.50165720283985, 54.05524201691151, 58.93464758992195, 56.2105243653059, 58.07808995246887, 52.3422559350729, 46.95917218923569, 55.954121723771095, 52.93765738606453, 50.95207393169403, 54.6476948261261, 58.3568961918354, 65.72892621159554, 58.83049517869949, 60.01389987766743, 63.70063304901123, 61.8324176967144, 61.40969417989254, 61.91042751073837, 61.06484368443489, 57.925197556614876, 60.37726677954197, 60.45966535806656, 54.692334830760956, 59.189564511179924, 58.30627150833607, 62.20693700015545, 63.94917771220207, 65.48830792307854, 56.01871445775032, 51.65417365729809, 56.21208228170872, 67.5572969019413, 66.6622169315815, 74.90962117910385, 66.30277901887894, 74.19544190168381, 65.67012816667557, 77.03481674194336, 14.768079500645399, 0.3708281577564776, 0.7116097840480506, 3.4547475446015596, 0.37724770547356457, 25.208738408982754, 88.06407451629639, 68.9295020699501, 83.2825630903244, 64.92080837488174, 43.358766585588455, 57.83300690352917, 68.00091549754143, 60.1491916179657, 69.79388728737831, 83.71045053005219, 53.5980087518692, 1.04373476235196, 0.34878233447670937, 0.2982754149707034, 0.23448083113180473, 0.19518900982802734], [0.04027632843644824, 0.059698815530282445, 0.01819044402509462, 0.12063365575158969, 0.05456532810057979, 0.25634416029788554, 0.03605387180869002, 2.4301880970597267, 60.387321040034294, 60.72052516043186, 45.902939066290855, 25.13170324265957, 19.7133269906044, 40.8645386248827, 29.268738850951195, 42.91260972619057, 69.4102294743061, 54.088950008153915, 52.00601577758789, 63.5199261456728, 4.705524053424597, 2.0391783909872174, 0.1710291046765633, 0.20867116138106212, 0.0668432522797957, 16.702302061021328, 71.15046009421349, 57.466337978839874, 62.51584142446518, 55.8541376888752, 58.454319164156914, 55.408216416835785, 58.798048719763756, 53.58285516500473, 57.75216244161129, 58.99921752512455, 57.5460235029459, 55.76407112181187, 53.68671879172325, 53.10607574880123, 53.78827214241028, 52.89975441992283, 54.28648240864277, 53.87828551232815, 54.97225061058998, 48.05027224123478, 53.39034229516983, 56.75129994750023, 57.97926485538483, 52.9587272554636, 56.20746932923794, 54.958054572343826, 55.69646894931793, 54.04965631663799, 57.616695910692215, 51.9819288700819, 51.56224139034748, 45.44694073498249, 49.919547736644745, 50.01641973853111, 46.663335263729095, 50.661507323384285, 48.84252592921257, 46.7286841571331, 52.42405414581299, 41.04826636612415, 40.579360127449036, 45.965992882847786, 41.17610290646553, 41.339995712041855, 40.19281826913357, 39.605578780174255, 39.91644009947777, 37.44760997593403, 41.957048401236534, 42.62844577431679, 44.480435997247696, 42.76889383792877, 43.339361026883125, 47.246660962700844, 46.87151849269867, 45.53937837481499, 53.78493592143059, 42.69781105220318, 46.34504534304142, 49.977430030703545, 54.302574545145035, 56.39888785779476, 53.5718547552824, 53.54039244353771, 59.55406375229359, 51.82721637189388, 52.20878429710865, 50.938117280602455, 52.07725055515766, 47.465544417500496, 51.13256424665451, 49.56769801676273, 50.200136080384254, 49.192825332283974, 46.24138690531254, 45.428637117147446, 43.20965498685837, 43.53032737970352, 43.388025015592575, 40.97895048558712, 37.547935992479324, 37.2872281819582, 38.40904958546162, 37.63715900480747, 38.52764122188091, 41.507787108421326, 42.21720524132252, 41.3942302018404, 48.25245179235935, 46.71891488134861, 47.33970656991005, 49.41890940070152, 47.38520912826061, 49.97592531144619, 50.38521654903889, 43.96958000957966, 50.74706733226776, 48.664672672748566, 46.25223532319069, 47.315828651189804, 46.54359228909016, 46.647968888282776, 52.35019750893116, 51.88132546842098, 54.71357189118862, 54.39253091812134, 56.96160726249218, 53.87859709560871, 56.25893376767635, 81.57228246331215, 55.31651973724365, 54.77685369551182, 53.67954097688198, 51.41885608434677, 50.62365375459194, 58.9456669986248, 53.59196327626705, 52.612208649516106, 47.1236577630043, 57.02043950557709, 58.265613690018654, 59.89604540169239, 55.23218706250191, 67.59344816207886, 61.36474259197712, 68.34962278604507, 60.53047835826874, 56.53053939342499, 5.322611415758729, 0.1890593598363921, 0.8725687908008695, 1.804415825754404, 0.2448502223705873, 26.130321957170963, 70.6596328318119, 59.91621091961861, 64.37378212809563, 61.98877550661564, 50.74661895632744, 37.565000876784325, 43.19276489317417, 44.2393047362566, 52.92679376900196, 70.48493340611458, 16.70367568731308, 1.099606251809746, 0.19403695914661512, 0.13219863205449656, 0.06992053793510422, 0.08573560102377087, 0.04940386541420594, 0.07365173732978292, 0.008661137981107458, 0.030687734069942962, 0.01867010705609573, 0.25879413820803165, 0.045723002185695805, 3.0356039106845856, 72.95173823833466, 66.24696001410484, 51.039150059223175, 32.05889493227005, 24.523589573800564, 41.32889270782471, 22.100474797189236, 53.39463986456394, 73.34113374352455, 56.782895252108574, 59.50619772076607, 68.36660027503967, 5.264302119612694, 2.8499292489141226, 0.29662695655133575, 0.4571514209965244, 0.030633384740212932, 18.767673633992672, 74.73563611507416, 61.617877408862114, 66.05942487716675, 57.404253110289574, 61.06015473604202, 59.33559827506542, 61.36852718889713, 56.31695665419102, 59.4179854542017, 61.26071937382221, 59.26158204674721, 56.5909219533205, 56.14932484924793, 55.70871189236641, 57.047843635082245, 53.92066463828087, 57.48890116810799, 55.405841544270515, 55.88448666036129, 47.91889429092407, 55.694987028837204, 57.57779359817505, 58.68391044437885, 56.13459303975105, 57.418977320194244, 56.795715764164925, 56.98063284158707, 55.766586586833, 57.835655361413956, 55.43543815612793, 54.09154146909714, 47.18782112002373, 51.63721516728401, 53.27366195619106, 51.46841302514076, 53.49128767848015, 52.921284064650536, 52.63917200267315, 55.336844846606255, 42.869029864668846, 44.696066826581955, 47.13974229991436, 44.51805777847767, 42.15702407062054, 40.89031644165516, 42.070996686816216, 42.29250580072403, 39.103587716817856, 44.392060339450836, 45.02372324466705, 46.13691911101341, 45.16224481165409, 46.407692581415176, 50.6307365745306, 49.39986862242222, 47.85208247601986, 54.03451032936573, 43.975545689463615, 46.4618244767189, 52.590204030275345, 56.12990029156208, 58.00350375473499, 54.813578724861145, 54.40672695636749, 60.26511199772358, 54.34021532535553, 55.381625443696976, 54.50601942837238, 55.22089026868343, 48.620063066482544, 51.04919672012329, 51.34225979447365, 51.43389567732811, 52.5815024971962, 49.36237223446369, 46.870184764266014, 46.30912967026234, 45.72539359331131, 45.029658526182175, 43.5398268699646, 39.64106507599354, 39.47600193321705, 40.91661863029003, 39.34502676129341, 39.76636715233326, 42.34335087239742, 45.11787839233875, 44.363607466220856, 51.94667436182499, 49.22579616308212, 50.98773121833801, 54.03286121785641, 51.83372542262077, 53.27764414250851, 52.82557100057602, 45.647843554615974, 51.62483163177967, 51.486792638897896, 46.54239535331726, 49.09430041909218, 47.533845752477646, 51.02718450129032, 52.043903544545174, 56.02317161858082, 57.874500676989555, 58.408117443323135, 58.63624580204487, 57.638176158070564, 53.74156504869461, 73.25323686003685, 60.93230679631233, 58.149206936359406, 55.00364452600479, 53.59189487993717, 54.63596485555172, 61.010806784033775, 58.17206270992756, 56.35376147925854, 51.50573082268238, 60.84135487675667, 62.03539900481701, 62.214684784412384, 58.3655559271574, 67.4537144601345, 62.78943054378033, 70.8735765516758, 63.737434074282646, 62.57379591464996, 6.28363162279129, 0.12201378325698897, 1.2381375557743013, 2.282823217101395, 0.21248208970064297, 29.208437986671925, 78.45308303833008, 67.74898141622543, 73.03822919726372, 66.36536166071892, 50.763870030641556, 40.98223730921745, 55.0376109033823, 47.299048751592636, 59.0126384049654, 81.11765205860138, 23.2228946685791, 1.018538314383477, 0.15646081999875605, 0.14690934971440583, 0.15657935582567006, 0.13710713741602376, 0.08673306976561435, 0.17326773377135396, 0.056149330994230695, 0.27047806594055146, 0.14218847412848845, 0.40569431497715414, 0.14275361958425492, 3.881930122151971, 84.47446033358574, 76.35900780558586, 63.611592426896095, 36.784203574061394, 33.063466027379036, 58.37467163801193, 38.54278340935707, 57.798421159386635, 79.17217925190926, 65.62984272837639, 65.14670625329018, 75.33686265349388, 6.4017288107424974, 4.136814745143056, 0.7880626316182315, 0.6303098215721548, 0.10366531001636758, 21.026542223989964, 79.87905532121658, 63.763724863529205, 68.6689880490303, 58.879615142941475, 64.62288156151772, 60.743380934000015, 64.57606807351112, 61.22674539685249, 60.836969912052155, 61.70906491577625, 63.780823945999146, 58.316903337836266, 59.513588324189186, 57.127308771014214, 58.893077820539474, 57.63026878237724, 61.56845346093178, 56.68012976646423, 56.963070183992386, 49.77246902883053, 57.81509466469288, 59.33209866285324, 63.645653799176216, 57.982221096754074, 59.7343260794878, 59.44423824548721, 59.719810858368874, 59.13637116551399, 61.833861619234085, 59.80309098958969, 57.43354953825474, 49.40274886786938, 55.14881953597069, 56.72910913825035, 54.611676558852196, 58.893678188323975, 57.63259805738926, 54.651996195316315, 60.25362901389599, 46.815699487924576, 46.92065745592117, 53.3755648881197, 49.00209456682205, 45.501285418868065, 43.83986636996269, 44.66552026569843, 44.40744951367378, 41.97315193712711, 47.16802038252354, 45.10919965803623, 50.62355875968933, 48.232233077287674, 50.107960626482964, 53.06922532618046, 52.358887642621994, 50.36864943802357, 57.480290830135345, 48.944094479084015, 50.186631605029106, 54.53539565205574, 59.404082000255585, 61.56282216310501, 54.80871118605137, 55.78542597591877, 65.10672479867935, 56.4722391217947, 59.38498042523861, 56.55586503446102, 58.77509415149689, 50.512437522411346, 55.24139776825905, 54.728315100073814, 55.07125809788704, 54.092689007520676, 53.27791392803192, 50.063301622867584, 49.8894989490509, 50.21688178181648, 46.76293931901455, 46.21050976216793, 40.97856670618057, 43.376131653785706, 43.795131370425224, 42.01666720211506, 41.3524666428566, 43.20090405642986, 47.60707922279835, 47.10700325667858, 55.8955592662096, 52.19717212021351, 54.32898312807083, 59.45423550903797, 56.3465266674757, 55.696924924850464, 56.128026992082596, 47.03739479184151, 55.62165096402168, 54.224359542131424, 49.139753580093384, 53.184131160378456, 50.830902233719826, 52.35552102327347, 56.76437124609947, 57.0165941119194, 58.818218037486076, 62.21237450838089, 61.59662514925003, 59.096473306417465, 53.531417325139046, 72.73049131035805, 62.83217445015907, 59.63458143174648, 59.99756455421448, 58.389715030789375, 58.404842019081116, 65.33673405647278, 60.18690839409828, 59.986567944288254, 54.29592490196228, 64.67382922768593, 61.79620563983917, 64.48433339595795, 58.571098297834396, 72.09473222494125, 65.66822066903114, 73.73426824808121, 68.01090136170387, 68.28600659966469, 7.839607754722238, 0.3062038973439485, 2.346174605190754, 4.421427072957158, 0.3708904981613159, 30.6227220967412, 84.55565437674522, 73.69598150253296, 75.75444504618645, 77.45985433459282, 62.34111540019512, 54.78808209300041, 61.38612784445286, 52.86900646984577, 71.06149166822433, 90.56524470448494, 33.9556809514761, 1.4470495143905282, 0.253577611874789, 0.23856823914684355, 0.17029562528477982, 0.22497400845168158], [0.02036305537330918, 0.04376305696496274, 0.06391730537870899, 0.18888681050157174, 0.08840357739245519, 0.19422938319621608, 0.11150682752486318, 2.4081796780228615, 58.8307573646307, 64.30401027202606, 41.74629271030426, 31.618204079568386, 21.131475493311882, 47.872616574168205, 64.3013048171997, 30.543224662542343, 67.15283140540123, 60.52252918481827, 48.72724011540413, 64.20767784118652, 12.688634432852268, 0.8512635715305805, 0.530915348790586, 0.12509555148426443, 0.13566655456088483, 2.424253053031862, 58.71071420609951, 63.456929326057434, 63.138061836361885, 54.72501687705517, 61.16665542125702, 56.94359242916107, 58.47446568310261, 56.02594926953316, 59.46593128144741, 59.27247606217861, 59.28503058850765, 54.62433747947216, 58.17644767463207, 52.16383270919323, 54.98720660805702, 53.163703456521034, 54.910074546933174, 54.34869647026062, 54.4914586097002, 53.049276396632195, 55.62545835971832, 53.6939612030983, 56.71734496951103, 52.67796032130718, 57.89997071027756, 55.42025797069073, 54.98284064233303, 52.75890737771988, 57.597427144646645, 52.53124639391899, 51.272936314344406, 44.33583855628967, 49.056139066815376, 47.503367587924004, 48.0722426623106, 45.703977942466736, 49.900537356734276, 48.808958530426025, 49.87139292061329, 42.78132677078247, 44.06545266509056, 44.35331001877785, 45.239475667476654, 40.287193804979324, 40.62078170478344, 39.01643179357052, 41.38321079313755, 37.96856962144375, 41.479467228055, 44.553889855742455, 44.6644601225853, 42.839471250772476, 45.03949619829655, 49.13970798254013, 47.804615423083305, 44.8890470713377, 48.828432485461235, 47.71209418773651, 45.37450522184372, 49.114553332328796, 53.3982040733099, 56.09849497675896, 53.76529857516289, 53.25506195425987, 57.69660942256451, 54.65557940304279, 54.19087573885918, 52.1927909553051, 47.95482516288757, 44.41656902432442, 50.470932349562645, 49.26032871007919, 46.943950206041336, 47.26770803332329, 44.79852452874184, 45.036897137761116, 43.28313164412975, 41.47531405091286, 41.10227666795254, 38.734939098358154, 38.84168677031994, 39.088836908340454, 38.51580485701561, 39.814050793647766, 40.10171055793762, 44.80786822736263, 41.23527333140373, 43.53210188448429, 46.45208179950714, 48.54692459106445, 48.39909352362156, 46.727365627884865, 47.196686044335365, 50.9872068464756, 47.67903596162796, 44.69742335379124, 50.932037606835365, 48.4113934636116, 49.379703104496, 48.155032619833946, 48.77661846578121, 47.262012138962746, 48.14934432506561, 46.40118733048439, 53.37452754378319, 53.387412652373314, 58.43984194099903, 55.17714321613312, 62.60976858437061, 57.80709229409695, 56.42202861607075, 62.2290214151144, 53.0351335555315, 53.95155318081379, 51.55725985765457, 54.52792905271053, 51.73214927315712, 56.381055414676666, 56.24444134533405, 58.034924268722534, 60.34120291471481, 64.2723959684372, 63.39247338473797, 62.73158624768257, 62.935798689723015, 58.88836607336998, 51.85237102210522, 48.429488092660904, 1.101675359532237, 0.1888913376023993, 2.211509356275201, 2.369052702561021, 0.38701665471307933, 28.10045164078474, 67.71483644843102, 60.38281448185444, 58.329492062330246, 73.89906540513039, 55.99976867437363, 35.05022741854191, 37.562018036842346, 27.38886572420597, 52.03713230788708, 64.16721001267433, 8.362406026571989, 0.76864282367751, 0.15487490978557616, 0.1001540980360005, 0.0073884869107132545, 0.04839852619625162, 0.07285206578671932, 0.14494368253508583, 0.03584114630939439, 0.1434204838005826, 0.12931785226101056, 0.16344456322258338, 0.030388596605916973, 2.8768591163679957, 68.50701794028282, 74.45611551404, 47.908247262239456, 36.48900121450424, 26.3495359942317, 54.07200671732426, 60.823868215084076, 36.84070274233818, 73.1147874891758, 64.37999099493027, 53.971323519945145, 71.73730060458183, 13.829210679978132, 0.9420409379526973, 1.3736309227533638, 0.1980032041319646, 0.1731249742442742, 3.0968110263347626, 64.99959334731102, 63.78244265913963, 66.8188901245594, 54.496280550956726, 63.21674041450024, 56.413099095225334, 61.41841471195221, 58.51384297013283, 62.62623310089111, 60.46634919941425, 63.02948646247387, 56.46747797727585, 58.003298565745354, 54.34426210820675, 58.399609699845314, 53.06139774620533, 55.940393060445786, 56.76179118454456, 56.21823415160179, 54.7828383743763, 58.84263172745705, 53.93403612077236, 59.13287155330181, 53.74486327171326, 59.64567683637142, 56.23300015926361, 58.04430976510048, 55.27106277644634, 59.26592141389847, 54.42633010447025, 53.78864452242851, 46.388594806194305, 53.52498807013035, 51.34014330804348, 53.42728391289711, 50.39418786764145, 51.20299346745014, 51.292949840426445, 54.169976860284805, 46.69280648231506, 47.820179387927055, 46.51643134653568, 46.22870698571205, 40.50996445119381, 40.628031715750694, 41.081290394067764, 43.05116169154644, 41.0655402392149, 45.457800552248955, 44.227852150797844, 46.552886590361595, 47.09049694240093, 46.11698158085346, 49.26289737224579, 49.19984355568886, 46.80914103984833, 51.63520507514477, 49.592138305306435, 46.12012781202793, 49.646274000406265, 53.867581486701965, 55.84605172276497, 55.95013193786144, 56.39055110514164, 62.493266835808754, 55.92403493821621, 56.89371630549431, 52.90114514529705, 50.528636053204536, 47.49121583998203, 54.12151426076889, 51.51357360184193, 49.84374180436134, 47.74926379323006, 46.83620698750019, 46.72447398304939, 43.44230130314827, 43.34229826927185, 43.480500653386116, 42.849400117993355, 39.30998124182224, 39.75608870387077, 40.939166620373726, 40.25410138070583, 41.15973338484764, 46.227312460541725, 42.99751617014408, 45.963694006204605, 50.10275110602379, 52.24296346306801, 52.443003728985786, 51.81277334690094, 52.45183065533638, 53.14148984849453, 50.18723577260971, 47.094581723213196, 51.936319917440414, 48.379060998559, 50.501083731651306, 51.90614193677902, 51.24972715973854, 51.08879819512367, 49.298148080706596, 48.36799219250679, 56.117771342396736, 56.147808730602264, 59.9325842410326, 57.21621260046959, 57.31225624680519, 55.59472180902958, 62.06294372677803, 64.14296731352806, 57.28245064616203, 56.18905171751976, 54.9407085031271, 55.071014910936356, 55.470225289464, 58.190917298197746, 60.60349524021149, 62.22823105752468, 63.21032635867596, 66.86469286680222, 64.79568868875504, 63.726319670677185, 64.55817103385925, 62.533073499798775, 56.879942044615746, 53.48047345876694, 1.1339459591545165, 0.09766182512976229, 1.6660530189983547, 3.4029515739530325, 0.41361110110301524, 31.37449275702238, 75.18788784742355, 66.97553291916847, 64.06415194272995, 80.42905300855637, 64.22834113240242, 41.999195739626884, 48.706029653549194, 31.701305620372295, 58.4997533261776, 76.33290320634842, 12.454167064279318, 0.7412847073283046, 0.2106405096128583, 0.11661374606774189, 0.04113524562853854, 0.1096629913081415, 0.19854247831972316, 0.19851794291753322, 0.09736493637319654, 0.36178099166136235, 0.29072806995827705, 0.5452562542632222, 0.22807888715760782, 3.556291158311069, 80.00377222895622, 82.01504990458488, 59.15270268917084, 42.2398292273283, 36.206459775567055, 64.2118652164936, 70.950758010149, 44.934705421328545, 78.80388021469116, 72.04911947250366, 58.93595851957798, 80.26449903845787, 14.569163024425507, 1.2829950987361372, 2.0826577953994274, 0.4859875689726323, 0.2558184525696561, 4.374458743259311, 70.69133833050728, 66.62494093179703, 70.36288395524025, 58.34551960229874, 65.2448245882988, 59.250201657414436, 66.05327680706978, 60.21191865205765, 64.82707500457764, 63.02570566534996, 64.58106860518456, 59.60800185799599, 63.695655316114426, 58.18769507110119, 61.30233474075794, 55.92351816594601, 58.46932835876942, 59.00401286780834, 57.743050530552864, 56.564057394862175, 60.37898048758507, 55.02655349671841, 60.7782668620348, 55.485409274697304, 62.519037052989006, 56.91641628742218, 60.41619569063187, 56.5217162668705, 61.43835224211216, 56.547858864068985, 58.6806920170784, 48.00163485109806, 54.28128808736801, 53.13860960304737, 57.23754845559597, 55.64367078244686, 56.94191671907902, 56.92615516483784, 60.35766363143921, 51.72463707625866, 54.40748691558838, 50.067196413874626, 50.72503611445427, 44.337195083498955, 43.51913698017597, 42.71957628428936, 46.03728465735912, 42.81319946050644, 46.351182013750076, 47.97301098704338, 50.599851831793785, 48.12736630439758, 47.44065195322037, 55.59213034808636, 52.47744508087635, 48.40345948934555, 55.565151795744896, 51.74333967268467, 49.00015667080879, 54.22440133988857, 56.12480476498604, 57.97916606068611, 57.804193049669266, 58.31370770931244, 63.20802368223667, 57.894214019179344, 59.55478571355343, 54.631389901041985, 53.72174911201, 49.478645995259285, 55.546988770365715, 54.40165042877197, 51.53318054974079, 50.01525700092316, 48.33600550889969, 51.06634899973869, 47.19135493040085, 45.519182458519936, 46.31363622844219, 43.343073427677155, 42.94559195637703, 42.68613427877426, 44.04901474714279, 42.12074741721153, 44.65600557625294, 50.83090603351593, 46.26225918531418, 48.30950953066349, 54.786531776189804, 55.84031403064728, 55.50871342420578, 54.46301333606243, 54.54931050539017, 56.74957863986492, 52.9475786536932, 47.12799333035946, 57.15094730257988, 53.078732416033745, 53.70344169437885, 55.29962584376335, 53.508838936686516, 53.145996406674385, 51.33548095822334, 50.42753867805004, 59.810941368341446, 57.19516173005104, 63.50272446870804, 58.99507574737072, 59.057054221630096, 66.18463575839996, 62.80699700117111, 67.6526489853859, 60.35575993359089, 60.609521716833115, 57.05358512699604, 61.12561762332916, 58.186748921871185, 62.37124778330326, 63.32408465445042, 63.48137341439724, 66.12848997116089, 71.45276427268982, 67.92516276240349, 68.0419608950615, 66.82117760181427, 65.292679220438, 60.61502002179623, 60.368971824645996, 1.8226243299432099, 0.2827794902259484, 4.706156719475985, 4.8398425709456205, 0.486119938432239, 35.58649644255638, 81.6634851694107, 70.23142620921135, 68.8133043050766, 86.73698052763939, 67.40367874503136, 53.25428679585457, 51.862094700336456, 40.93197740614414, 70.00772461295128, 86.90067574381828, 20.994538441300392, 1.3850066810846329, 0.5386183666996658, 0.29949051851872355, 0.1613263550098054, 0.18825409992132336], [0.019945628846471664, 0.07253599993418902, 0.04870840253715869, 0.03760710154892877, 0.0219259849836817, 0.1830861991038546, 0.04280425040633418, 2.0918685011565685, 61.02689892053604, 57.523912489414215, 49.55719158053398, 41.93556435406208, 48.72777208685875, 48.241219595074654, 54.086882919073105, 40.91851092875004, 61.165355890989304, 61.80298447608948, 50.7717964053154, 62.65801079571247, 23.309737108647823, 0.07022179794148542, 3.3943564351648092, 0.48293217667378485, 0.31602945760823786, 0.0861770156188868, 31.955825462937355, 63.37684862315655, 61.534973457455635, 57.34000615775585, 59.558650106191635, 55.70739336311817, 58.46020124852657, 56.03640250861645, 60.082474797964096, 59.14064593613148, 60.71720413863659, 53.41829739511013, 57.718663439154625, 53.531683310866356, 56.978273168206215, 53.999734595417976, 56.21931329369545, 53.95706668496132, 57.68213979899883, 53.94474394619465, 57.317344173789024, 53.528381288051605, 54.70376081764698, 54.83691327273846, 60.608526170253754, 61.77437961101532, 53.90332616865635, 52.99007557332516, 52.8643973171711, 52.70865887403488, 48.25141444802284, 44.032090455293655, 47.54203051328659, 49.728706777095795, 47.9780039191246, 50.54928034543991, 48.84000666439533, 47.24055849015713, 46.65466032922268, 47.963488698005676, 43.57424162328243, 41.91171683371067, 44.418119341135025, 44.61310587823391, 42.96028196811676, 40.69023057818413, 38.03171843290329, 39.78067338466644, 39.694562405347824, 41.1957972496748, 39.568849951028824, 44.03669200837612, 46.12835057079792, 43.29935297369957, 47.556560933589935, 45.151362195611, 46.06884576380253, 50.3068533539772, 50.09611666202545, 51.22578464448452, 53.459205999970436, 55.06298594176769, 51.366969868540764, 56.36694297194481, 55.827440321445465, 55.34906879067421, 52.533891052007675, 49.7763030230999, 46.26877583563328, 46.62878751754761, 49.032135754823685, 47.370598912239075, 48.38204383850098, 45.594961792230606, 44.64943952858448, 41.07387699186802, 44.57842513918877, 43.05369235575199, 39.05401557683945, 40.069822669029236, 38.83377939462662, 36.81458294391632, 40.028283298015594, 41.95585146546364, 43.87586563825607, 42.62163653969765, 41.49986453354359, 47.62408331036568, 44.769144505262375, 47.86477379500866, 49.47580374777317, 45.72948597371578, 45.542456209659576, 49.84040558338165, 46.80895484983921, 48.19472149014473, 45.171474516391754, 50.68397931754589, 52.703833132982254, 55.726483538746834, 52.974724397063255, 52.66724489629269, 51.17690026760101, 53.499027863144875, 54.030604138970375, 54.64744783937931, 53.61823506653309, 58.450272381305695, 37.904740646481514, 31.448936462402344, 58.87853220105171, 58.251938223838806, 59.45608600974083, 54.134114384651184, 55.72090543806553, 53.96987199783325, 53.391573429107666, 53.16355146467686, 54.329287111759186, 58.11403602361679, 58.927249386906624, 59.31091859936714, 59.5382945984602, 64.03854891657829, 61.87225855886936, 57.90662795305252, 49.566618874669075, 33.71733874082565, 0.49365781364031136, 0.23147747822804376, 0.656643477268517, 2.175642130896449, 0.11030695284716785, 47.24536903202534, 63.54175217449665, 66.61807850003242, 60.12493371963501, 74.73929151892662, 49.80924345552921, 36.5212956815958, 44.42799501121044, 41.54039315879345, 58.59333850443363, 63.21128390729427, 7.017879523336887, 0.7221901381853968, 0.14188235305482522, 0.09078259856323712, 0.16409201285568997, 0.0697529387252871, 0.14609879086492583, 0.1719078520545736, 0.07109970669262111, 0.019864706919179298, 0.03863873876980506, 0.27286240831017494, 0.018203620857093483, 2.8365352051332593, 71.84815585613251, 64.48383182287216, 54.05523061752319, 40.81194564700127, 44.84146982431412, 55.871498957276344, 59.66558776795864, 43.387785628437996, 66.45002111792564, 67.86108300089836, 55.21127298474312, 69.01058211922646, 26.243084706366062, 0.1083776137966197, 3.6321092024445534, 0.38213020598050207, 0.177381606772542, 0.1745446285349317, 37.10957631468773, 64.71257194876671, 66.04431688785553, 61.466379538178444, 61.55576974153519, 58.61737221479416, 59.895243644714355, 57.834952399134636, 63.49031053483486, 60.89082062244415, 62.193907499313354, 56.79802604019642, 59.12037402391434, 54.83113758265972, 59.890072122216225, 56.85163736343384, 58.006934970617294, 56.2455128878355, 59.46461275219917, 55.84987051784992, 58.14709424972534, 54.98293563723564, 56.79188936948776, 56.66580073535442, 60.030850768089294, 63.947954177856445, 58.22662778198719, 53.99202860891819, 56.214403957128525, 56.89605697989464, 51.90319709479809, 46.92654713988304, 51.958119347691536, 52.207176983356476, 49.85735647380352, 52.82832205295563, 52.5429155677557, 52.28740967810154, 50.516450107097626, 50.90263098478317, 46.429351419210434, 44.75675716996193, 47.99531199038029, 47.1473228931427, 44.03050974011421, 42.4676726013422, 41.12898923456669, 42.0255359262228, 41.855837032198906, 42.143937572836876, 43.22224751114845, 45.112513080239296, 49.640201926231384, 47.229949459433556, 50.198334977030754, 47.993989661335945, 46.64647936820984, 51.683120504021645, 51.08212575316429, 51.74024663865566, 57.01699689030647, 56.37428417801857, 53.901084288954735, 56.783446222543716, 57.1909249573946, 54.413726180791855, 55.95118448138237, 52.38775089383125, 47.745710983872414, 46.76086463034153, 50.062100887298584, 47.25020997226238, 49.20174725353718, 47.75026693940163, 45.40922395884991, 43.8316436111927, 46.680202558636665, 45.52076317369938, 41.273427084088326, 41.214385852217674, 40.823649019002914, 40.26887118816376, 42.96474672853947, 43.56598846614361, 47.91250303387642, 47.143492698669434, 46.417990028858185, 50.84655739367008, 48.71223472058773, 51.52698688209057, 52.7278858423233, 49.91137057542801, 50.00482656061649, 53.34964647889137, 47.6880718767643, 49.01214122772217, 47.78913125395775, 52.15957693755627, 56.08475111424923, 58.58128175139427, 56.06547474861145, 54.704801961779594, 53.89387987554073, 54.726438000798225, 57.47229985892773, 56.833858117461205, 57.48876057565212, 61.59774608910084, 41.04853995144367, 33.71588721871376, 60.7271634042263, 60.6103652715683, 63.14767152070999, 57.67064921557903, 59.02298904955387, 57.34083071351051, 56.10731050372124, 57.539005279541016, 56.79562456905842, 60.73378644883633, 60.84645040333271, 60.92984452843666, 62.822416573762894, 66.4489571750164, 65.13380214571953, 60.079172775149345, 55.10277360677719, 37.46358431875706, 0.5347228038590401, 0.2537917363224551, 0.7632472913246602, 2.776458766311407, 0.10869395424379036, 52.71653585135937, 69.791911393404, 73.32748487591743, 63.377832770347595, 82.24829658865929, 56.56653106212616, 45.13293698430061, 46.38678230345249, 36.27754256129265, 65.69512322545052, 74.02166202664375, 10.301864705979824, 0.8530469227116555, 0.20630638202419505, 0.12600227782968432, 0.07743579990346916, 0.1638530264608562, 0.22486108326120302, 0.21055041288491338, 0.1634948214632459, 0.09124351679929532, 0.10565631411736831, 0.43165244394913316, 0.14006943471031263, 3.1618101010099053, 83.41790422797203, 72.4722495675087, 65.58384239673615, 54.372376799583435, 64.42886397242546, 65.63506364822388, 60.41494935750961, 53.854719176888466, 73.26906681060791, 74.7409026324749, 63.19616451859474, 75.70193946361542, 28.652106039226055, 0.18150258954847232, 5.482628429308534, 1.3120774319395423, 0.508858838584274, 0.2624160860432312, 42.086955830454826, 65.9703728556633, 67.41158992052078, 63.9267361164093, 64.75090429186821, 62.585408091545105, 63.29152800142765, 58.60504187643528, 65.41142284870148, 63.76567795872688, 64.45518895983696, 59.925634413957596, 60.2933406829834, 59.75799880921841, 62.301122546195984, 57.58871041238308, 60.123839378356934, 57.52536781132221, 63.683100789785385, 58.556237295269966, 61.337023079395294, 57.517696022987366, 57.88960486650467, 60.050016939640045, 59.71384897828102, 64.81192141771317, 59.89191122353077, 55.586624443531036, 58.9818524569273, 57.18724675476551, 55.30840337276459, 47.84106306731701, 55.057757422327995, 56.03775143623352, 55.364925339818, 57.907137125730515, 54.950523376464844, 54.68159660696983, 56.311500146985054, 54.38732139766216, 50.14497444033623, 46.79616093635559, 53.15469793975353, 50.231735184788704, 47.6371356099844, 43.95419083535671, 42.726955488324165, 44.45000723004341, 43.99084746837616, 45.62484338879585, 45.036243572831154, 49.72392663359642, 52.61861890554428, 50.275246649980545, 54.57700341939926, 49.606132954359055, 50.61776407063007, 52.76126705110073, 54.15683716535568, 55.36093935370445, 59.358856827020645, 58.16149927675724, 56.83983899652958, 60.01434825360775, 59.58206444978714, 58.679650872945786, 59.17013235390186, 54.09935005009174, 50.79852037131786, 48.97003188729286, 53.19767743349075, 50.77889822423458, 52.85133361816406, 51.13516330718994, 48.72442066669464, 46.088669300079346, 48.69632877409458, 48.38811211287975, 43.31002660095692, 44.09344956278801, 42.505860552191734, 42.56359465420246, 44.414741322398186, 45.32521426677704, 50.15279442071915, 49.27132532000542, 48.39918091893196, 54.35085855424404, 50.62335357069969, 55.10937385261059, 56.22260391712189, 51.612717881798744, 53.749681413173676, 57.5688336789608, 52.81455159187317, 52.343118488788605, 49.41360868513584, 53.08676518499851, 57.01308310031891, 61.70588068664074, 57.793652415275574, 57.21838988363743, 55.16084209084511, 58.09842646121979, 59.205052480101585, 57.784563302993774, 60.02289019525051, 61.82163767516613, 48.69485445320606, 38.287889286875725, 60.73655270040035, 63.65267962217331, 65.11820778250694, 60.23355469107628, 61.80327706038952, 61.4828934520483, 59.09320168197155, 60.15610344707966, 59.113940969109535, 62.946688905358315, 63.865597397089005, 65.95883667469025, 65.71238189935684, 69.2904295027256, 67.15549886226654, 63.5908417403698, 57.872289195656776, 44.71619054675102, 1.200669666286558, 0.3670630347914994, 1.9348311214707792, 4.155933894217014, 0.1634869398549199, 55.949318781495094, 75.57908445596695, 80.23410826921463, 67.78160646557808, 89.10964921116829, 60.556757748126984, 57.18719735741615, 59.49017398059368, 53.876594603061676, 73.7045006453991, 86.83394372463226, 16.30161166191101, 1.4246523287147284, 0.5406921647954732, 0.2790951426140964, 0.22529764421051368, 0.19960992416599765], [0.01661122056248132, 0.056850359978852794, 0.015732929605292156, 0.05479550520249177, 0.01713093359285267, 0.19644407060695812, 0.06981214726692997, 1.526030176319182, 53.94159011542797, 71.08987614512444, 41.564708054065704, 51.60484850406647, 102.00769230723381, 60.560120567679405, 40.011210814118385, 44.332718923687935, 64.12154406309128, 60.72569288313389, 55.72555258870125, 59.32172901928425, 31.049490496516228, 0.7837122213095427, 2.4169743061065674, 0.13046340172877535, 0.24908494669944048, 0.25978253048378974, 16.344112381339073, 59.258785396814346, 61.76099292933941, 55.30434139072895, 57.90739931166172, 59.109267219901085, 58.00347715616226, 61.54941648244858, 55.17383359372616, 57.14003428816795, 57.409021854400635, 54.723272770643234, 54.7160417586565, 55.58020658791065, 55.05295068025589, 56.323720291256905, 53.95744286477566, 54.81757611036301, 56.33226603269577, 55.68833738565445, 55.945177003741264, 56.70088805258274, 53.168738186359406, 55.58931089937687, 62.11392939090729, 47.17667631804943, 51.25013753771782, 51.632621213793755, 56.12527213990688, 52.88597255945206, 48.498347997665405, 45.42159229516983, 47.662541046738625, 54.06949885189533, 48.556435480713844, 48.02674390375614, 47.83046543598175, 47.990790233016014, 48.25154364109039, 48.061732426285744, 43.914068788290024, 42.759918719530106, 42.05697163939476, 41.98802813887596, 41.57506249845028, 39.92100365459919, 41.35559007525444, 41.616879254579544, 41.85803331434727, 39.83950562775135, 43.894294649362564, 44.310174733400345, 43.5447134077549, 43.99777829647064, 48.84194076061249, 46.574100852012634, 45.76334595680237, 45.95051251351833, 50.48394665122032, 54.693550765514374, 53.08051832020283, 52.92333595454693, 48.33776481449604, 57.36244015395641, 57.49731011688709, 53.30181084573269, 54.20199774205685, 45.7278710603714, 43.91158752143383, 47.74628855288029, 48.613048642873764, 46.622586250305176, 46.35454103350639, 46.88233271241188, 44.17425602674484, 43.753105625510216, 44.42090459167957, 40.933827906847, 39.237393736839294, 39.940766394138336, 39.85301770269871, 37.3319935798645, 40.67742146551609, 44.267658814787865, 45.34569516777992, 42.16234378516674, 44.73273865878582, 51.05425424873829, 48.47481586039066, 51.15989238023758, 49.13862124085426, 46.567523404955864, 46.229121163487434, 49.195261001586914, 46.16382546722889, 45.55028758943081, 47.68966019153595, 55.001683831214905, 56.04418449103832, 55.118915140628815, 55.40418483316898, 56.76410146057606, 56.93174086511135, 55.412719175219536, 55.0034811347723, 57.41536371409893, 57.55887821316719, 51.25630080699921, 41.1339707672596, 56.274919509887695, 57.14162640273571, 55.619690269231796, 57.21284978091717, 60.205227211117744, 59.28622752428055, 58.26842173933983, 56.16326630115509, 53.97839114069939, 57.18042992055416, 55.630116909742355, 57.36061245203018, 58.4254103153944, 59.202419221401215, 57.82254606485367, 63.28791819512844, 57.13567592203617, 52.4880351126194, 17.983030937612057, 0.051342919177841395, 0.15351784822996706, 0.5247019696980715, 1.6741367289796472, 0.2615769248222932, 57.85588547587395, 61.670933961868286, 69.99694839119911, 53.869914561510086, 74.55479621887207, 51.15636996924877, 35.69494642317295, 41.40925079584122, 41.651616990566254, 53.907969519495964, 59.8783003538847, 5.451565571129322, 0.5523853248450905, 0.1418372304760851, 0.0881800647766795, 0.08183129568351433, 0.18933169834781438, 0.0470061235682806, 0.05147445743205026, 0.031249875682988204, 0.18018064642092213, 0.051279469262226485, 0.21925167879089713, 0.10844324191566557, 1.6949670924805105, 66.46826773881912, 76.80234521627426, 51.75480745732784, 53.07456783950329, 84.73595470190048, 65.5337230861187, 44.21948499977589, 49.92287635803223, 70.20374089479446, 67.0412389934063, 59.380869045853615, 67.55957677960396, 34.54871132969856, 0.8535242720972747, 3.388561033643782, 0.3226390545023605, 0.1055812458798755, 0.3715835156617686, 18.489942736923695, 62.890847101807594, 66.71239703893661, 60.104623809456825, 60.11967860162258, 60.61845503747463, 60.75681321322918, 64.06097531318665, 58.28419849276543, 58.859901800751686, 60.21037973463535, 55.30359663069248, 58.03603380918503, 57.87024490535259, 58.34624916315079, 59.32846985757351, 56.68499730527401, 55.707138776779175, 56.19841441512108, 55.307620614767075, 58.850029930472374, 59.231909438967705, 54.13805477321148, 54.84776929020882, 62.42414474487305, 50.933272540569305, 53.315725699067116, 55.30272647738457, 57.6378607749939, 55.88686913251877, 49.19265814125538, 48.19273799657822, 50.08334554731846, 56.32947698235512, 51.09424330294132, 53.29507380723953, 52.79681794345379, 52.27278046309948, 51.3582569360733, 52.21885375678539, 47.87893943488598, 45.527595207095146, 45.41943781077862, 46.03442721068859, 44.43058267235756, 42.3027728497982, 43.911249339580536, 43.72903771698475, 43.25408220291138, 41.87172777950764, 44.053810089826584, 45.08694805204868, 46.43868371844292, 45.68355783820152, 49.21589769423008, 49.59768980741501, 47.87099406123161, 47.871955409646034, 52.386071383953094, 56.048166677355766, 54.039111882448196, 54.234231412410736, 50.841921642422676, 56.83603160083294, 57.6377809792757, 56.36701516807079, 55.223447531461716, 47.80054584145546, 47.55528800189495, 49.27359379827976, 49.85152378678322, 48.20162571966648, 48.37282173335552, 46.397178545594215, 47.69048474729061, 45.58811075985432, 46.300192549824715, 42.99596585333347, 44.056701734662056, 42.407168447971344, 42.256168350577354, 39.58334617316723, 42.51765891909599, 46.33029453456402, 48.26539009809494, 44.46228817105293, 47.23189875483513, 52.6510463654995, 51.54242545366287, 51.54943227767944, 51.946362778544426, 50.993700698018074, 50.91146931052208, 53.57180915772915, 47.694459334015846, 48.153839483857155, 49.99275840818882, 57.89416462182999, 58.08476619422436, 56.01244859397411, 58.7398586422205, 59.41217556595802, 58.28619718551636, 56.49754196405411, 56.40077255666256, 59.09037083387375, 62.296904772520065, 53.353799656033516, 43.366122990846634, 57.65034310519695, 57.967078909277916, 58.263926580548286, 60.7239031791687, 62.49484375119209, 62.05968350172043, 60.16063280403614, 58.47246699035168, 57.21575282514095, 60.116524770855904, 57.93338991701603, 61.73198148608208, 62.14922569692135, 64.2130659520626, 63.32559697329998, 67.15371295809746, 60.44822037220001, 56.95180758833885, 22.37679786980152, 0.04075349970662501, 0.9346220141742378, 1.088609048165381, 2.0665597217157483, 0.23910280811833218, 63.94357681274414, 66.70941799879074, 77.24802330136299, 58.991864919662476, 83.14757153391838, 54.93370547890663, 46.112980395555496, 46.0147138684988, 34.71769966185093, 62.616228237748146, 68.28282237052917, 8.954997528344393, 0.7090179075021297, 0.23979477176908404, 0.05106887001602445, 0.03401144058443606, 0.14431944728130475, 0.12045030816807412, 0.18176462705014274, 0.12161685299361125, 0.3102006297558546, 0.1947874782490544, 0.3644942241953686, 0.20311070897150785, 2.433855850249529, 77.51456379890442, 86.44330188632011, 59.782530292868614, 67.63469114899635, 108.11945915222168, 76.39658778905869, 52.37001724541187, 54.71888020634651, 79.33067634701729, 72.46331244707108, 67.24157184362411, 73.58178243041039, 41.01286366581917, 1.0399150173179805, 4.94573243893683, 0.7084037060849369, 0.6585749611258507, 0.3772359201684594, 21.90176445990801, 65.99194049835205, 64.69408974051476, 65.3921426832676, 64.62379351258278, 63.81053075194359, 62.060846239328384, 64.68018248677254, 60.47366000711918, 60.64532719552517, 62.37875618040562, 58.100945726037025, 61.56614698469639, 59.05888192355633, 61.35851472616196, 57.768828347325325, 58.43756206333637, 57.66408696770668, 60.77939160168171, 57.5319604575634, 63.332041427493095, 59.81937691569328, 57.007060423493385, 55.92821091413498, 61.490983217954636, 53.9187191426754, 54.141831770539284, 57.397170290350914, 61.94848246872425, 57.065299898386, 52.6919549703598, 51.739596873521805, 53.28025080263615, 59.766890332102776, 54.091625064611435, 57.13388241827488, 55.82577981054783, 56.613526940345764, 54.31161046028137, 56.46390616893768, 51.72523744404316, 51.29275985062122, 49.63654652237892, 50.33328473567963, 48.39406259357929, 44.357090815901756, 46.21877811849117, 46.24226085841656, 45.91829404234886, 43.88535372912884, 44.85296420753002, 46.57117500901222, 46.51546239852905, 48.37669752538204, 51.460722237825394, 52.7151945233345, 49.74967025220394, 50.31913809478283, 54.58186335861683, 59.30713400244713, 58.97535860538483, 54.54887732863426, 51.045761704444885, 59.02427718043327, 60.1750036329031, 58.462834507226944, 58.38007874786854, 49.94293548166752, 49.545009434223175, 54.01179514825344, 54.162901639938354, 52.24225290119648, 52.0837178081274, 51.21595077216625, 49.088346138596535, 47.76805758476257, 48.5085466504097, 45.99808596074581, 45.0164770334959, 44.15174223482609, 44.75511945784092, 40.88128052651882, 45.36500573158264, 48.910401687026024, 51.020018085837364, 48.45413736999035, 50.79101197421551, 57.837369069457054, 54.16639365255833, 56.41657590866089, 55.35793371498585, 54.091701060533524, 54.34775412082672, 56.9791167229414, 50.54449640214443, 48.96209791302681, 53.193786442279816, 61.81150741875172, 60.950086042284966, 59.83022153377533, 61.812894344329834, 61.84627555310726, 59.81230549514294, 60.72136491537094, 60.46568803489208, 60.73517717421055, 63.8771715760231, 55.224355682730675, 45.15037424862385, 58.236013278365135, 62.59126357734203, 59.0429911762476, 61.95153370499611, 65.60623079538345, 64.82770577073097, 62.998096346855164, 61.644084602594376, 60.37878289818764, 63.49753014743328, 60.42477183043957, 66.44514977931976, 64.82398957014084, 67.26226553320885, 66.2926259636879, 71.05959936976433, 65.34425005316734, 65.02938374876976, 27.23592583090067, 0.15438163391081616, 1.1283004120923579, 2.4953593499958515, 2.9392080707475543, 0.2984208462294191, 68.01858454942703, 72.04115509986877, 83.18278044462204, 64.17119979858398, 89.43747282028198, 62.740644961595535, 56.08211785554886, 57.17899739742279, 56.139224991202354, 72.10083469748497, 84.43591520190239, 12.949707973748446, 1.0094782942906022, 0.35106743685901165, 0.1862658714526333, 0.24463548936182633, 0.31911227968521416], [0.04657499885070138, 0.04475312278373167, 0.01780177200998878, 0.0291006679617567, 0.08315590312122367, 0.1480436630663462, 0.19986296683782712, 0.8740803378168494, 52.98733212053776, 75.92585384845734, 39.952496364712715, 64.94311317801476, 104.92713645100594, 61.17010563611984, 40.292965695261955, 59.68566969037056, 63.41464899480343, 62.68579490482807, 56.681881472468376, 57.50721238553524, 39.278640523552895, 0.3229923464823514, 1.1183321219868958, 0.2767892007250339, 0.15303156338632107, 0.10939308704109862, 4.021716546267271, 47.36422285437584, 55.983687937259674, 56.19132399559021, 55.31248055398464, 57.697988748550415, 61.31216861307621, 59.939404875040054, 54.9839273840189, 53.67819204926491, 54.297934994101524, 55.74456676840782, 55.30795879662037, 57.91136249899864, 58.53231757879257, 52.57456786930561, 50.91221027076244, 57.804105654358864, 53.66727903485298, 54.19531390070915, 53.984539210796356, 57.475256100296974, 49.17193405330181, 60.317545384168625, 44.75194662809372, 47.76429198682308, 59.005601182579994, 56.24821074306965, 55.63594199717045, 52.135805413126945, 48.46159256994724, 46.63897477090359, 48.34623456001282, 53.225480541586876, 49.09651570022106, 47.803414687514305, 47.95480616390705, 46.127488017082214, 50.80800846219063, 50.59893228113651, 47.70075939595699, 42.589049488306046, 40.9394896030426, 40.67867159843445, 40.872468799352646, 39.871811494231224, 40.42421065270901, 42.40156374871731, 38.911675214767456, 40.08703954517841, 43.135289177298546, 40.37162907421589, 41.15130543708801, 45.12105882167816, 46.66441060602665, 48.810535445809364, 44.885448664426804, 43.73903878033161, 51.475001871585846, 52.77832813560963, 46.64409689605236, 48.80034439265728, 39.21983867883682, 57.163239642977715, 57.872460186481476, 51.21365189552307, 53.62445153295994, 49.541202038526535, 46.96375474333763, 47.45721146464348, 46.903748363256454, 46.543960869312286, 45.26746116578579, 45.36234587430954, 46.48416347801685, 45.15314429998398, 44.14678730070591, 43.25908653438091, 38.699600994586945, 41.27959795296192, 41.503174155950546, 39.246365055441856, 45.260237753391266, 46.191271394491196, 43.62677000463009, 42.3675137758255, 46.201622039079666, 50.39125822484493, 48.30180734395981, 48.33941392600536, 48.76015014946461, 46.44246831536293, 48.03105287253857, 49.371525943279266, 46.28221191465855, 45.8719365298748, 49.53479938209057, 53.16662549972534, 49.0475857257843, 51.75569660961628, 55.843612253665924, 57.12037034332752, 54.226882606744766, 54.94000554084778, 57.50296041369438, 52.783746644854546, 55.619405284523964, 50.36383889615536, 52.439933493733406, 53.69583070278168, 59.445518776774406, 56.71493209898472, 56.63390524685383, 58.69243338704109, 60.02498768270016, 58.751132637262344, 58.97566258907318, 56.26442827284336, 56.40901431441307, 54.69896927475929, 57.99160659313202, 56.334602907299995, 61.09337255358696, 60.95922075212002, 64.9111720919609, 51.979599595069885, 60.07541477680206, 12.050338983535767, 0.1027835495187901, 0.38180817326065153, 0.414379402063787, 0.6784408295061439, 1.6455856547690928, 68.07572588324547, 53.59112732112408, 60.741545632481575, 60.52327774465084, 73.80043029785156, 36.7873840034008, 35.3636460006237, 40.62836229801178, 35.60294955968857, 53.52269299328327, 57.430999875068665, 1.786015669349581, 0.3985718940384686, 0.03911731640982907, 0.011946808499487815, 0.03787658650253434, 0.03637106572568882, 0.08935196790844202, 0.16559015668462962, 0.03106444637523964, 0.07922609016532078, 0.01187661153380759, 0.0624555119429715, 0.0800114605226554, 0.8610358752775937, 64.44980084896088, 81.97520524263382, 47.809570357203484, 63.84564846754074, 103.57998713850975, 67.31351718306541, 45.86716018617153, 62.87329204380512, 71.03548586368561, 69.64854508638382, 63.076980113983154, 64.86316546797752, 42.997915148735046, 0.2763001254061237, 1.4630777668207884, 0.36396213399711996, 0.32406534359324723, 0.2671492367517203, 4.631515424698591, 54.91163246333599, 62.27428458631039, 64.78057309985161, 56.94352403283119, 60.10527737438679, 61.75149343907833, 62.628824561834335, 57.7833017706871, 56.63855999708176, 56.6910769790411, 59.746515825390816, 57.9684354364872, 59.94496017694473, 60.49586981534958, 54.855365082621574, 53.81010577082634, 59.63281072676182, 55.63490465283394, 55.156020149588585, 55.422237664461136, 58.28120045363903, 51.42369322478771, 57.4191939085722, 48.514949306845665, 48.834846541285515, 60.86049824953079, 58.48167769610882, 58.592810332775116, 55.33597469329834, 50.65435990691185, 48.95061492919922, 50.1937410235405, 56.33051812648773, 53.649154007434845, 52.40692466497421, 50.100672617554665, 51.494544222950935, 53.84395435452461, 54.47449252009392, 50.81983722746372, 45.65654508769512, 44.23346824944019, 44.44569066166878, 43.46509248018265, 43.75025577843189, 41.274532824754715, 43.237298503518105, 41.98392055928707, 42.308776527643204, 44.762035086750984, 43.83028328418732, 45.17687402665615, 46.66633330285549, 48.15860062837601, 50.28498932719231, 48.51262383162975, 47.689322009682655, 53.84671300649643, 53.423206731677055, 48.144191801548004, 50.39426386356354, 42.85978116095066, 57.13000662624836, 57.538317516446114, 54.85126510262489, 54.971695840358734, 53.51282112300396, 48.155450597405434, 49.97507035732269, 49.0797434002161, 50.12744598090649, 45.72003208100796, 48.61748680472374, 47.51582331955433, 46.29163920879364, 45.485721454024315, 44.43834945559502, 40.734809786081314, 42.90147252380848, 43.09788018465042, 41.163388788700104, 46.27456672489643, 48.30919034779072, 46.525341868400574, 45.642869621515274, 50.02546705305576, 52.66810745000839, 52.3848782479763, 51.28658518195152, 53.306951969861984, 49.62081156671047, 51.07943929731846, 53.34432676434517, 46.550443321466446, 48.33244130015373, 50.95551274716854, 54.79905590415001, 53.41399982571602, 54.81286056339741, 57.733961418271065, 58.28065328299999, 58.30460339784622, 57.89136417210102, 60.451609790325165, 56.93027414381504, 57.71371230483055, 51.084333434700966, 54.824761524796486, 57.610479444265366, 61.34677715599537, 59.013018384575844, 59.14807453751564, 60.577580630779266, 60.401049703359604, 62.454011142253876, 61.57523989677429, 59.618838876485825, 59.3816252052784, 57.805074602365494, 62.88865461945534, 58.55914793908596, 64.58087861537933, 63.10848422348499, 69.54797208309174, 55.49082778394222, 65.8451695740223, 13.711166214197874, 0.1701365681947209, 1.3192388601601124, 0.8708225470036268, 0.8149005321320146, 1.6816314705647528, 76.93480610847473, 60.90590961277485, 69.38434526324272, 63.90242502093315, 81.73492893576622, 44.28542286157608, 45.28975456953049, 39.534214809536934, 37.087427303195, 61.54972806572914, 68.92327800393105, 2.852088720537722, 0.513601815328002, 0.16027536999899894, 0.07674855631194077, 0.06366674148011953, 0.13579619291704148, 0.2973333920817822, 0.22363342257449403, 0.07754825754091144, 0.1618743865401484, 0.20580912823788822, 0.28086216654628515, 0.19792115228483453, 1.2060518399812281, 72.72922977805138, 93.65249544382095, 54.41046595573425, 81.31835728883743, 107.5549766421318, 74.89674746990204, 53.12034398317337, 69.64733675122261, 77.88403317332268, 73.93387153744698, 67.79922991991043, 70.8929631114006, 50.338368862867355, 0.38256831059698015, 2.004382945597172, 0.5233017448335886, 0.35157476901076734, 0.3747509722597897, 6.225279103964567, 59.385284408926964, 57.889308482408524, 61.46924838423729, 61.37986958026886, 60.56597225368023, 65.20048096776009, 63.893047124147415, 60.20874202251434, 58.26782517135143, 59.95288275182247, 63.683305978775024, 60.51608093082905, 64.66457292437553, 62.77704320847988, 55.92506468296051, 55.45635223388672, 61.966998875141144, 59.00954157114029, 57.440339773893356, 57.83755145967007, 62.160644084215164, 52.374539002776146, 56.93722017109394, 54.40665856003761, 49.18098896741867, 63.992852568626404, 60.57690806686878, 60.5731500685215, 56.778069511055946, 53.43143329024315, 51.33828520774841, 53.452731147408485, 59.6989081799984, 56.446594297885895, 56.304941698908806, 53.80378670990467, 55.217949226498604, 58.05703528225422, 57.947878539562225, 54.341514855623245, 49.30515490472317, 48.89190427958965, 48.60694237053394, 46.626564636826515, 47.66167089343071, 45.630942061543465, 47.231381982564926, 44.58619952201843, 44.4190426915884, 48.92020896077156, 45.78771024942398, 47.736382484436035, 51.029631569981575, 50.31831353902817, 53.08594062924385, 51.42509534955025, 49.314430207014084, 56.60722307860851, 56.75797238945961, 50.78787714242935, 49.940446615219116, 44.4423658400774, 57.62780271470547, 57.72234924137592, 57.0373447984457, 55.4377294331789, 54.865939915180206, 48.881633430719376, 51.28180503845215, 51.07888452708721, 51.35657362639904, 48.16890947520733, 51.05115741491318, 52.41225577890873, 49.165299609303474, 50.33865764737129, 48.424145579338074, 42.89290778338909, 45.0187873095274, 44.92873594164848, 41.56808987259865, 50.430244132876396, 51.91662937402725, 50.17282694578171, 49.52987104654312, 53.90927664935589, 55.85473045706749, 55.83065114915371, 54.416462033987045, 58.39541852474213, 55.074685513973236, 55.18139138817787, 57.632662653923035, 49.43392999470234, 52.029171735048294, 53.806526362895966, 57.947620153427124, 56.64362892508507, 58.939093351364136, 58.59884820878506, 60.44425718486309, 61.166556626558304, 60.99298194050789, 62.17982925474644, 57.675015181303024, 61.32329821586609, 52.11845934391022, 57.89445720613003, 58.7436318397522, 62.67626501619816, 58.97805266082287, 62.075441256165504, 64.01710286736488, 61.99857898056507, 62.23497949540615, 62.969833463430405, 61.37176461517811, 62.12320849299431, 58.94529081881046, 65.59210315346718, 62.4616639316082, 66.81569829583168, 66.40620946884155, 73.66018742322922, 58.827212154865265, 71.44339397549629, 17.05796867609024, 0.13511266006389633, 3.171842750161886, 1.6174899623729289, 1.1177028995007277, 1.68056835886091, 81.65232136845589, 64.69929546117783, 77.29247331619263, 68.90585973858833, 86.93582385778427, 49.04325395822525, 54.53373894095421, 53.75251226127148, 52.763182148337364, 68.50472286343575, 85.31499803066254, 4.7975660394877195, 0.7395661901682615, 0.2906215866096318, 0.11537624450284056, 0.2311127126449719, 0.22844926337711513], [0.031020342394185718, 0.09483258007094264, 0.0993100312189199, 0.022647929545200896, 0.07597035510116257, 0.06631675045355223, 0.3641065856209025, 0.34530195873230696, 40.0698758661747, 70.9325721859932, 49.25706848502159, 52.6140059530735, 86.29397749900818, 60.11860325932503, 34.614554196596146, 52.55043536424637, 62.20356658101082, 59.07776691019535, 57.9013766348362, 53.030976578593254, 51.08852460980415, 1.6720512346364558, 0.6522716931067407, 0.6990559701807797, 0.05819274556415621, 0.15521175577305257, 0.6721750844735652, 39.2964805662632, 59.411730989813805, 47.78014473617077, 56.41621872782707, 63.54890339076519, 62.72877439856529, 59.857435673475266, 56.13963156938553, 52.023548036813736, 57.52537541091442, 57.893169075250626, 54.673639833927155, 54.18029710650444, 55.56877680122852, 52.14558608829975, 54.016446098685265, 56.039092764258385, 53.215042501688, 50.3276040405035, 55.65718285739422, 52.565763741731644, 59.06901217997074, 44.32125873863697, 42.26335756480694, 55.701325088739395, 52.66870401799679, 54.52462702989578, 53.32061603665352, 49.48822908103466, 50.81293299794197, 47.46921882033348, 46.8180325627327, 53.440237417817116, 48.39339002966881, 49.34157595038414, 49.546483755111694, 50.63089996576309, 52.033674493432045, 52.39610284566879, 49.36665080487728, 45.15398025512695, 40.65087988972664, 42.21573852002621, 39.15800839662552, 39.5746636390686, 42.20952965319157, 42.05324403941631, 39.837461337447166, 40.29587633907795, 41.43285132944584, 41.45664185285568, 43.88454057276249, 44.65372949838638, 48.34598757326603, 47.793124839663506, 46.788850128650665, 47.159915417432785, 51.91448628902435, 43.13134878873825, 47.35039919614792, 51.54997944831848, 44.798197746276855, 47.16246508061886, 58.6425344645977, 48.51884789764881, 56.223116889595985, 53.313563615083694, 46.83238439261913, 46.91651947796345, 43.8274372369051, 46.19239993393421, 45.66568359732628, 44.924749955534935, 44.90015767514706, 42.89676837623119, 43.15734699368477, 40.44111594557762, 39.42402832210064, 39.39910925924778, 41.33695587515831, 42.81477637588978, 44.84919100999832, 45.45811213552952, 42.2872468829155, 42.88859881460667, 44.49706010520458, 48.09486284852028, 46.621761694550514, 47.4454814940691, 48.698749244213104, 46.71992942690849, 47.719112411141396, 50.91667503118515, 44.77231353521347, 46.516442745923996, 47.56300538778305, 53.411947935819626, 50.70835120975971, 56.10235556960106, 55.119705498218536, 57.00677163898945, 59.20803152024746, 56.109768971800804, 53.094991743564606, 62.53720387816429, 56.06803581118584, 53.150540962815285, 55.26048794388771, 58.296528831124306, 56.59828595817089, 56.83192782104015, 57.286516427993774, 59.19999495148659, 60.035463720560074, 58.18893760442734, 60.303850919008255, 60.3936704993248, 58.82099948823452, 55.415189042687416, 60.71407690644264, 59.8077267408371, 63.44456858932972, 57.09833152592182, 65.61311602592468, 55.58108054101467, 58.36864896118641, 4.923124127089977, 0.18267852254211903, 3.2174049178138375, 0.8471317088697106, 0.06508290767669678, 7.30795263312757, 74.62434008717537, 45.36388099193573, 67.85460814833641, 59.182987064123154, 75.47754630446434, 31.571400091052055, 38.15243415534496, 35.730520114302635, 32.91186176240444, 58.142732083797455, 42.38893702626228, 0.5209186195861548, 0.35406972107011825, 0.040858098000171594, 0.03535596355504822, 0.06785721896449104, 0.01580525375175057, 0.06294050544966012, 0.04475764617382083, 0.06985550353419967, 0.06453590031014755, 0.04147403233218938, 0.08778836665442213, 0.41204398206900805, 0.412483838154003, 47.98418238759041, 81.15491285920143, 49.85872820019722, 54.8316353559494, 94.52048286795616, 67.55293473601341, 43.33343714475632, 61.64030380547047, 70.26121661067009, 66.86884224414825, 64.133141040802, 60.39537660777569, 55.58935649693012, 1.860312963835895, 0.6679641385562718, 1.1574924644082785, 0.445070177083835, 0.641291351057589, 0.803020647726953, 41.51809975504875, 63.40153969824314, 56.78062677383423, 56.15174911916256, 63.82548674941063, 62.54701875150204, 60.48312909901142, 57.92511776089668, 55.502493157982826, 59.3497259169817, 59.81475256383419, 58.49816881120205, 57.95912213623524, 57.9120122641325, 53.51841822266579, 54.6446967869997, 58.84143479168415, 55.010757744312286, 51.80631749331951, 56.18616387248039, 55.90491436421871, 57.91440613567829, 46.24528929591179, 46.79911717772484, 57.12702378630638, 55.52367702126503, 58.167309165000916, 56.87151789665222, 51.32786996662617, 51.88373073935509, 50.20592696964741, 48.20969268679619, 55.405917540192604, 52.61490650475025, 52.9807660728693, 53.4885024279356, 53.30745354294777, 54.2378032207489, 55.77351361513138, 51.659143790602684, 46.53535433113575, 43.973110020160675, 46.5971390157938, 43.63127276301384, 41.5039037168026, 44.129049852490425, 41.67068436741829, 40.35795360803604, 41.49916537106037, 44.20063801109791, 42.69210755825043, 46.76405265927315, 47.1867685765028, 49.095565751194954, 50.19143834710121, 49.052536860108376, 47.59105548262596, 53.70559237897396, 46.7637524753809, 49.37589950859547, 52.91561856865883, 46.04356192052364, 52.715540304780006, 56.44347846508026, 50.280649960041046, 56.26908302307129, 52.66962356865406, 49.01456169784069, 48.00969421863556, 46.73984035849571, 49.81859855353832, 47.56123848259449, 45.702872201800346, 45.00994898378849, 43.765264973044395, 45.418989434838295, 41.74451820552349, 41.37525022029877, 41.85182444751263, 42.581210508942604, 45.06302073597908, 48.09034489095211, 48.153847083449364, 46.33612722158432, 44.94638979434967, 47.965065613389015, 50.0737738609314, 49.51837666332722, 48.9728057384491, 49.81251887977123, 51.44518107175827, 53.6944779753685, 54.45442199707031, 47.88772836327553, 48.93274448812008, 51.36370204389095, 55.535490587353706, 55.56993193924427, 57.45674729347229, 57.80110761523247, 59.15525235235691, 56.05319760739803, 56.87889330089092, 54.40657116472721, 61.33860379457474, 58.89110192656517, 56.111725866794586, 57.14763768017292, 58.88929322361946, 58.82589362561703, 57.287785559892654, 61.948493868112564, 60.16777262091637, 60.014781430363655, 59.63886000216007, 64.09976363182068, 61.74125298857689, 62.076273411512375, 59.34100158512592, 63.65928366780281, 61.97475045919418, 65.98766192793846, 62.223253324627876, 69.63095963001251, 57.94496029615402, 65.00758811831474, 5.93379626981914, 0.18695949751418084, 1.8812931817956269, 1.3347991439513862, 0.17412935238098726, 7.817528089508414, 84.01473060250282, 50.007281228899956, 74.16440516710281, 65.12364149093628, 81.58817321062088, 37.2911761701107, 48.476335778832436, 39.507247656583786, 39.73726451396942, 65.4837329685688, 53.24158787727356, 1.256036376580596, 0.1952508752583526, 0.1804615493165329, 0.07368039165157825, 0.027012401696993038, 0.015424636821990134, 0.12476802687160671, 0.17249701340915635, 0.14809349086135626, 0.1308359153335914, 0.13589874288300052, 0.20366711192764342, 0.5884990619961172, 0.7358255283907056, 57.12968744337559, 94.16981488466263, 65.52518114447594, 66.91006243228912, 92.50824764370918, 74.98903691768646, 48.960517197847366, 64.98418137431145, 75.20420417189598, 70.7242825627327, 68.70917469263077, 63.55589881539345, 63.58135744929314, 2.1837803442031145, 0.975269858026877, 1.7388206580653787, 0.5439357657451183, 0.6274965475313365, 0.7994639198295772, 50.420022681355476, 58.60408052802086, 53.88822577893734, 60.7696907222271, 66.79806724190712, 66.70070126652718, 63.77025291323662, 59.579727575182915, 58.21663051843643, 63.84649962186813, 62.601101249456406, 61.05307191610336, 60.60171693563461, 59.6582617610693, 55.2545602619648, 56.691415160894394, 61.38772755861282, 57.14201398193836, 55.5484326928854, 61.08169578015804, 58.69470566511154, 56.20332755148411, 50.68668097257614, 48.25092427432537, 58.96142475306988, 58.0761406570673, 60.31322121620178, 58.93199533224106, 54.2980869859457, 56.56468816101551, 51.58422701060772, 50.52069067955017, 58.00917685031891, 56.627855971455574, 56.867953687906265, 57.0839910954237, 56.07061207294464, 57.5240720808506, 60.42955957353115, 55.15922337770462, 51.005894243717194, 48.25100786983967, 51.77418641746044, 45.58379039168358, 44.05361630022526, 49.71031196415424, 46.53346203267574, 41.90032124519348, 43.220036029815674, 45.55593028664589, 45.564742013812065, 49.330579340457916, 47.3335774987936, 53.592848628759384, 51.50025151669979, 51.94508224725723, 49.67186562716961, 55.30057579278946, 51.83797739446163, 52.731187865138054, 55.533328503370285, 47.826217263937, 54.75736454129219, 59.36620943248272, 52.20148488879204, 62.30630926787853, 54.25177127122879, 52.44812585413456, 50.38135975599289, 50.13189174234867, 51.94845266640186, 49.843802601099014, 49.28497038781643, 47.15714916586876, 46.24696500599384, 49.08613085746765, 43.8521359115839, 43.886372074484825, 44.45103697478771, 47.43218220770359, 47.591701447963715, 50.17113983631134, 51.276751309633255, 50.1898006349802, 49.779764637351036, 50.96118964254856, 54.826767817139626, 51.889156848192215, 52.513155564665794, 53.675437197089195, 55.189693942666054, 55.724940821528435, 58.39983008801937, 51.09977960586548, 51.98770076036453, 54.22971725463867, 57.50768356025219, 58.089299350976944, 59.704094901680946, 61.19052194058895, 60.35855658352375, 56.51534780859947, 56.25416122376919, 57.42896318435669, 63.7621745467186, 55.83636984229088, 57.90307514369488, 58.57706777751446, 60.66051498055458, 60.46060770750046, 59.48304556310177, 64.0360714495182, 64.05243337154388, 62.67303138971329, 60.50061956048012, 67.01943576335907, 63.11530105769634, 64.85955566167831, 62.09008567035198, 66.44301429390907, 63.95733967423439, 70.3528980910778, 64.42096799612045, 72.93510273098946, 60.24738594889641, 72.04785794019699, 7.735373172909021, 0.2242408407619223, 5.955516854301095, 3.2856575679033995, 0.3366624691989273, 8.038519956171513, 89.3389593064785, 55.658603981137276, 83.17155584692955, 69.54684734344482, 87.99057126045227, 41.637143567204475, 60.46808950603008, 49.08074654638767, 48.42075236141682, 75.14191791415215, 68.19522187113762, 2.897784118540585, 0.547994066728279, 0.2593546675052494, 0.2206787545583211, 0.13321302918484434, 0.14688096998725086], [0.05695959298464004, 0.03273465714300983, 0.07287736560101621, 0.16706660011550412, 0.3190716099925339, 0.15004740242147818, 0.9797034482471645, 0.2490003567072563, 32.031080424785614, 67.76082918047905, 48.84223714470863, 41.12726412713528, 54.12312537431717, 55.547288954257965, 30.143890790641308, 51.42120435833931, 65.80388098955154, 60.72622865438461, 58.148579970002174, 52.17885710299015, 60.234219655394554, 6.896807570010424, 0.22017550421878695, 2.487835753709078, 0.4468657588586211, 1.049238529521972, 0.17435921035939828, 27.678649574518204, 55.27741223573685, 45.51175385713577, 55.802186876535416, 62.55750238895416, 60.17547860741615, 59.02242287993431, 55.08847877383232, 56.23763971030712, 58.56077805161476, 58.760438337922096, 56.37950889766216, 55.64927168190479, 50.47979347407818, 56.34921692311764, 56.48070886731148, 54.64826099574566, 50.67125380039215, 52.01638162136078, 53.795267567038536, 57.19688683748245, 48.421926498413086, 43.2464712113142, 58.57869789004326, 54.373406544327736, 52.52680443227291, 52.02498055994511, 51.486990228295326, 46.96731515228748, 50.34182667732239, 47.03415356576443, 48.60695376992226, 50.41108936071396, 45.132484808564186, 47.26041242480278, 48.65743026137352, 51.69310636818409, 50.94019956886768, 52.06582836806774, 48.80984768271446, 43.5767836868763, 41.9041932374239, 41.90425783395767, 38.878480195999146, 39.289291352033615, 39.03770685195923, 41.50649897754192, 39.08712700009346, 43.27479489147663, 42.591253370046616, 42.76268497109413, 41.16837412118912, 43.25332224369049, 46.26857444643974, 46.042475178837776, 46.35575696825981, 48.02764445543289, 46.69985510408878, 47.72421553730965, 57.51456119120121, 57.2349151968956, 60.341951474547386, 48.9497409760952, 46.9437450170517, 51.84031426906586, 45.61241805553436, 54.52765166759491, 51.011692732572556, 46.598601937294006, 48.653413876891136, 47.45922155678272, 46.69782981276512, 41.21011108160019, 44.51323963701725, 42.17547208070755, 45.25442026555538, 43.07735748589039, 39.35896061360836, 40.09896330535412, 42.463371232151985, 45.55928170681, 42.298444882035255, 42.667667269706726, 41.696902960538864, 40.466851964592934, 47.950402200222015, 48.09609018266201, 49.93945486843586, 48.47318574786186, 48.200858160853386, 48.26702781021595, 48.74853037297726, 51.30515098571777, 45.06309673190117, 46.565270125865936, 45.5519974976778, 51.597180515527725, 56.644844859838486, 53.865711987018585, 53.4695528447628, 57.589607164263725, 58.869769871234894, 55.067139118909836, 55.941137820482254, 47.331160828471184, 43.342438861727715, 51.48570589721203, 55.09241156280041, 58.492309525609016, 56.5153744071722, 54.34778831899166, 55.18644131720066, 57.11401708424091, 57.36355349421501, 58.38072091341019, 58.63960102200508, 56.94642707705498, 60.32544516026974, 56.63664110004902, 61.01043060421944, 56.123524233698845, 65.94797685742378, 62.097385078668594, 65.42869672179222, 53.255552127957344, 49.15023721754551, 0.4579514858778566, 0.22876519564306363, 0.7445873238611966, 1.3073853962123394, 0.09810874646063894, 17.01424442231655, 65.34774586558342, 56.87369517982006, 62.936201468110085, 63.6457259953022, 57.82936289906502, 31.752832755446434, 45.32572723925114, 22.675425745546818, 37.87075147032738, 55.17908111214638, 31.523995734751225, 0.3603254322661087, 0.01916200253617717, 0.018461207328073215, 0.07171212695538998, 0.1163889940653462, 0.055921239327290095, 0.045194118065410294, 0.010823404718394158, 0.10605582705466077, 0.17054623371222988, 0.12779898766893893, 0.04592308891005814, 0.7540206739213318, 0.4275760939344764, 37.600194588303566, 79.47692289948463, 51.77756443619728, 48.288831040263176, 66.37024819850922, 63.14492426812649, 35.97956255078316, 56.63591913878918, 72.00617417693138, 64.78522405028343, 62.905529513955116, 56.91169694066048, 65.93102976679802, 7.362134400755167, 0.22857576987007633, 3.698648144491017, 1.454048976302147, 1.816587878856808, 0.12167702632723376, 31.04938980191946, 62.66835384070873, 54.97537024319172, 55.49574472010136, 64.39066842198372, 62.11272865533829, 61.65616795420647, 57.43301376700401, 60.13876497745514, 60.6527291983366, 61.153359934687614, 58.281880617141724, 57.231628373265266, 51.70110493898392, 58.12724411487579, 60.08601240813732, 57.667822167277336, 52.842639684677124, 55.15486501157284, 55.63484005630016, 58.67118872702122, 51.17079019546509, 46.032964289188385, 60.630067214369774, 57.12425373494625, 54.90805685520172, 53.711402267217636, 52.52903491258621, 47.930369675159454, 53.19912515580654, 49.18164633214474, 50.83983555436134, 53.97217087447643, 50.114298686385155, 48.22948582470417, 52.81452119350433, 54.4423196464777, 52.51410931348801, 54.94931124150753, 51.6879690438509, 49.51627157628536, 44.9740257114172, 43.44013921916485, 42.37667888402939, 40.781235694885254, 41.35891869664192, 44.7998658567667, 41.078615337610245, 44.43316653370857, 42.04836130142212, 44.60015997290611, 44.569119438529015, 43.95465821027756, 47.53902867436409, 47.953780218958855, 46.82851240038872, 51.50039590895176, 48.88218440115452, 50.07299870252609, 58.68718586862087, 58.599805757403374, 60.237111300230026, 54.68981556594372, 50.663779601454735, 51.77001044154167, 49.820460453629494, 58.0257211625576, 51.703829392790794, 48.55054199695587, 49.77911487221718, 50.720290169119835, 48.923146203160286, 45.18623672425747, 46.10831044614315, 43.54786343872547, 47.0571993291378, 44.10487174987793, 41.92185468971729, 43.93661677837372, 44.910086542367935, 47.94923946261406, 45.76453909277916, 44.67682085931301, 44.868908151984215, 44.23760622739792, 52.279183119535446, 50.17621636390686, 51.439781561493874, 52.40272209048271, 51.29326522350311, 50.90040810406208, 50.70957474410534, 54.20599512755871, 45.99871672689915, 49.01681877672672, 48.1035415828228, 54.937892854213715, 58.12220938503742, 56.12508974969387, 55.39951868355274, 60.27526505291462, 58.067176938056946, 51.478379890322685, 59.72593992948532, 51.27452842891216, 45.91008648276329, 53.001539558172226, 57.5554583966732, 60.03253787755966, 60.81498049199581, 57.64390245079994, 58.911172449588776, 59.713313207030296, 61.72789670526981, 59.032211154699326, 63.07382248342037, 59.99652720987797, 63.2596705108881, 59.85779665410519, 64.39035683870316, 58.761946856975555, 67.9123954474926, 65.46313047409058, 69.49450135231018, 58.56164060533047, 53.092882856726646, 1.0614546365104616, 0.6893812736961991, 1.4486064808443189, 2.73205126170069, 0.0860044514411129, 19.574533738195896, 73.60081180930138, 61.62174940109253, 69.63773846626282, 71.2988269329071, 67.93862164020538, 32.022352293133736, 56.13474503159523, 36.014049500226974, 41.687240079045296, 64.4086566567421, 39.20891046524048, 0.42319190106354654, 0.019791076592809986, 0.07666801844607107, 0.06370321803842671, 0.12306899108807556, 0.044946815905859694, 0.12247612641658634, 0.15494430059334263, 0.15545598173048347, 0.3325485368259251, 0.36693200119771063, 0.2668108470970765, 1.1607276345603168, 0.6879001250490546, 42.672458812594414, 92.67383515834808, 64.371357858181, 55.818864181637764, 63.48709210753441, 70.06431117653847, 40.87085768580437, 63.69394160807133, 78.47896724939346, 69.75427821278572, 68.47239419817924, 62.24235489964485, 75.98941683769226, 8.53728024289012, 0.2632011892274022, 5.334727065637708, 2.5199207570403814, 3.061623964458704, 0.29851857223547995, 36.838795244693756, 62.45433032512665, 50.71095027029514, 56.9205504655838, 66.50373503565788, 65.113625228405, 64.01055201888084, 59.08879391849041, 63.65834131836891, 63.4820231795311, 64.03034135699272, 59.92478705942631, 59.66711528599262, 52.14063875377178, 59.69637371599674, 61.900388449430466, 57.497492507100105, 57.37470209598541, 57.97131188213825, 58.48065175116062, 58.817298486828804, 53.07504281401634, 50.34642443060875, 64.39816921949387, 59.6809883415699, 56.37411318719387, 56.76154799759388, 57.06737078726292, 51.63808532059193, 54.75597381591797, 52.39230304956436, 53.24825271964073, 58.01751360297203, 52.95998498797417, 51.37494944036007, 55.60986779630184, 58.03925223648548, 56.726084500551224, 59.72823120653629, 54.18138764798641, 52.897512540221214, 49.09184955060482, 49.281254187226295, 47.47569367289543, 46.43882431089878, 45.59000685811043, 49.36621382832527, 42.73002952337265, 48.51279102265835, 46.24042555689812, 45.93625567853451, 45.86811013519764, 47.79498293995857, 48.9029236882925, 50.68817049264908, 48.973326310515404, 53.70437644422054, 49.49316121637821, 51.96749724447727, 59.82493981719017, 61.484542563557625, 62.357899099588394, 56.07337452471256, 55.686429888010025, 56.28249250352383, 51.44360035657883, 59.34763602912426, 54.59165543317795, 50.590831115841866, 53.83603177964687, 52.90909431874752, 52.54843667149544, 46.543231308460236, 49.94272269308567, 47.42641791701317, 49.11068893969059, 46.48987837135792, 44.233992621302605, 46.97266146540642, 48.55941832065582, 51.23335003852844, 48.73898148536682, 49.07036170363426, 49.10102225840092, 47.77431204915047, 56.372806057333946, 54.49441485106945, 55.15966795384884, 55.8598829805851, 57.04880878329277, 55.02455100417137, 53.81992444396019, 57.24401190876961, 48.635285049676895, 51.363831236958504, 50.55157162249088, 58.41447830200195, 61.66369915008545, 56.99853368103504, 58.28565001487732, 61.882654801011086, 63.55602040886879, 52.16598719358444, 55.37754826247692, 46.19737386703491, 46.75733841955662, 55.09770467877388, 58.208890333771706, 64.11520600318909, 62.64206685125828, 60.162376910448074, 61.711990758776665, 60.63413679599762, 64.63901549577713, 60.35741664469242, 63.21743197739124, 62.4764983355999, 64.22388017177582, 61.72958381474018, 68.34247916936874, 59.76163901388645, 71.63773834705353, 66.92305773496628, 72.97975033521652, 60.89633792638779, 60.043910667300224, 1.771434189286083, 0.8131351706106216, 2.7667885227128863, 4.119407879188657, 0.1357472556992434, 21.309634633362293, 82.06526800990105, 66.49928167462349, 77.64755666255951, 76.94383442401886, 75.102179646492, 41.53025530278683, 67.15616002678871, 33.63024361431599, 53.664759770035744, 74.0411701798439, 56.238920241594315, 0.7650042220484465, 0.14963212626753375, 0.229098865238484, 0.11284939493634738, 0.15734971995698288, 0.13014331343583763], [0.07770495460135862, 0.014507132636936149, 0.04581023793434724, 0.016525465398444794, 0.1905420669936575, 0.048034391438704915, 0.6647394772153348, 0.039486297391704284, 10.955181699246168, 63.417251855134964, 52.66115382313728, 31.4970912784338, 22.18632359057665, 46.6929242759943, 37.25137710571289, 60.300814881920815, 67.28431195020676, 62.36475013196468, 62.018220126628876, 50.45294791460037, 60.559827983379364, 11.862444765865803, 1.0991053911857307, 3.1885305047035217, 0.5025008297525346, 0.7382349553517997, 0.052905180855304934, 19.296510256826878, 50.17262555658817, 48.709897845983505, 58.18353429436684, 62.389251217246056, 61.709984466433525, 57.681653425097466, 57.4011904746294, 57.83330328762531, 58.209654092788696, 56.87438294291496, 55.02667888998985, 50.78572265803814, 52.46273227035999, 55.60523584485054, 57.558540031313896, 53.493548557162285, 47.85356059670448, 52.3700400441885, 54.547414407134056, 53.72895732522011, 48.98950584232807, 55.21606832742691, 57.15939424932003, 54.26642328500748, 51.8431831151247, 49.27271604537964, 49.94765862822533, 49.58320878446102, 51.39190033078194, 45.21737605333328, 46.35462082922459, 52.06145480275154, 48.758098259568214, 49.25874799489975, 47.95803979039192, 50.64462102949619, 49.067295268177986, 48.36968310177326, 48.90711486339569, 44.80105139315128, 42.04103149473667, 40.90903043746948, 38.12692232429981, 36.434166356921196, 37.571946904063225, 39.90216426551342, 40.11594459414482, 41.7447803914547, 39.08144250512123, 40.501813888549805, 40.74055887758732, 43.3217603713274, 41.322433054447174, 43.564768731594086, 44.7622212767601, 43.803312331438065, 46.193380281329155, 53.39038409292698, 57.83100441098213, 53.11537005007267, 51.462508141994476, 59.71564628183842, 42.88664571940899, 50.464176312088966, 52.28275492787361, 44.05008248984814, 48.83118733763695, 46.85335546731949, 47.95984089374542, 47.59523905813694, 44.02225658297539, 44.50400993227959, 41.32658243179321, 42.663825675845146, 40.942974016070366, 40.40814131498337, 40.7353151589632, 41.83221749961376, 40.11462986469269, 39.59923692047596, 39.24846634268761, 44.74306270480156, 40.21444670855999, 44.88286480307579, 49.11484591662884, 48.55384781956673, 48.6199376732111, 50.347860753536224, 52.6497658342123, 47.060520350933075, 46.86127804219723, 51.31179682910442, 44.525136798620224, 49.564107209444046, 45.42267523705959, 46.73945277929306, 50.55037848651409, 51.87991954386234, 51.213184520602226, 56.34655326604843, 51.817287504673004, 39.21090915799141, 32.31689728796482, 34.135088324546814, 53.46872068941593, 55.163703337311745, 59.239721819758415, 55.36878973245621, 56.912544295191765, 53.19828540086746, 57.43569642305374, 59.22446943819523, 54.36447702348232, 48.91126424074173, 58.44060190021992, 56.010932475328445, 61.08999453485012, 58.08786302804947, 59.79012608528137, 60.69416217505932, 65.71572571992874, 57.949379459023476, 56.964878886938095, 57.782222628593445, 45.00930681824684, 0.23167739796917886, 0.18391912628430873, 0.7265338988509029, 2.1105326246470213, 0.12774351955158636, 30.106029622256756, 65.57441890239716, 62.062202766537666, 59.38044726848602, 60.44690564274788, 38.68363045156002, 36.95538818836212, 54.56296317279339, 21.96505006402731, 40.446162074804306, 59.47882018983364, 22.430576384067535, 0.7125845504924655, 0.033302737792837434, 0.04620207335392479, 0.04737405812193174, 0.05423441187303979, 0.0863788129936438, 0.13506197137758136, 0.03537179727572948, 0.12664600188145414, 0.018057905726891477, 0.2042465956765227, 0.1142693980364129, 0.7198084972333163, 0.11126655721454881, 14.13140656426549, 76.22057363390923, 59.61534686386585, 37.48932033777237, 36.636608093976974, 60.59490390121937, 37.31899447739124, 68.01657825708389, 72.0207729935646, 69.33734938502312, 67.33724310994148, 55.19837647676468, 67.19431757926941, 13.415238093584776, 1.0220673750154674, 3.1345798121765256, 0.5632416985463351, 2.093581734225154, 0.2200576214818284, 21.801911517977715, 60.773669108748436, 57.32799880206585, 58.102625235915184, 63.53411078453064, 64.30503621697426, 61.76778696477413, 58.49129498004913, 61.41276441514492, 60.83224676549435, 58.89242045581341, 56.87244884669781, 54.7491379827261, 53.58535163104534, 59.21452917158604, 58.562966734170914, 56.298459246754646, 50.37923187017441, 53.78907009959221, 56.54285453259945, 54.8088251799345, 50.62832370400429, 56.89232558012009, 62.394095957279205, 56.099710911512375, 53.91287125647068, 51.335199773311615, 50.94323940575123, 49.617410749197006, 54.3476515263319, 47.88265943527222, 47.495669201016426, 54.82555188238621, 50.77317953109741, 53.46991762518883, 52.72001266479492, 53.22420381009579, 52.63463504612446, 52.453969940543175, 52.383525520563126, 47.96710230410099, 45.51121428608894, 45.746843442320824, 41.64362221956253, 40.34474551677704, 41.36145696043968, 41.47057190537453, 40.69823294878006, 43.24837490916252, 40.38109816610813, 42.53522537648678, 43.18974785506725, 45.099487379193306, 44.69290919601917, 47.38523572683334, 46.96340896189213, 47.717850878834724, 48.654698207974434, 54.30195517838001, 60.130340829491615, 56.56270086765289, 53.228565976023674, 58.8021145015955, 49.42466989159584, 52.79806427657604, 51.24067224562168, 45.91488562524319, 52.752652913331985, 48.93749803304672, 50.04621773958206, 49.165770784020424, 46.92144401371479, 47.215593829751015, 42.87464216351509, 44.36558336019516, 44.130448177456856, 42.431582137942314, 41.22268080711365, 44.11270312964916, 40.99984936416149, 42.71923430263996, 42.96380437910557, 47.76472896337509, 43.73655751347542, 50.41540212929249, 52.3593208193779, 51.93888857960701, 49.85661171376705, 53.159098103642464, 53.72742220759392, 51.598286256194115, 49.73873823881149, 53.12576249241829, 46.46523289382458, 51.45378760993481, 47.77194857597351, 48.9325051009655, 51.96790002286434, 54.100216403603554, 54.39984172582626, 59.26635839045048, 55.391314923763275, 39.792825132608414, 35.46780601143837, 36.17083668708801, 54.56674017012119, 57.938204258680344, 59.886257126927376, 57.80407525599003, 59.262702986598015, 56.17564983665943, 60.47611087560654, 63.7612321972847, 56.38375326991081, 51.088991984725, 60.31093753874302, 59.84172351658344, 63.17539483308792, 60.39223037660122, 63.035520538687706, 62.41836905479431, 66.83342054486275, 62.64992482960224, 62.81232051551342, 60.88026098906994, 49.064088240265846, 0.0795552326599136, 0.7349854765925556, 1.449563791975379, 3.333254288882017, 0.0853711471427232, 32.51708574593067, 72.98291936516762, 66.90252363681793, 66.209706813097, 67.00793758034706, 47.34639801084995, 38.88949200510979, 65.27289748191833, 22.284282334148884, 41.298011764883995, 70.37422254681587, 29.425659030675888, 0.7404439430683851, 0.03757232079806272, 0.10752411428256892, 0.06150510649604257, 0.056743487002677284, 0.026676867455535103, 0.21949955611489713, 0.12957476894371212, 0.17482250346802175, 0.14205442741513252, 0.26038272015284747, 0.2664223773172125, 1.0325994598679245, 0.20821919344598427, 15.917126443237066, 88.98477271199226, 71.73414677381516, 46.550158336758614, 30.559349097311497, 68.94568920135498, 47.36233435571194, 74.10173133015633, 78.42513933777809, 76.56222090125084, 71.53529584407806, 63.97515311837196, 72.09173038601875, 16.915073543787003, 1.0543131572194397, 5.211792262271047, 1.9847397808916867, 5.54530369117856, 0.393109330907464, 24.227205477654934, 60.99810026586056, 51.2485758215189, 62.09111921489239, 65.71339264512062, 66.36128067970276, 63.30116808414459, 60.160131230950356, 62.252192571759224, 64.00473833084106, 62.02199712395668, 58.776009902358055, 55.21098420023918, 54.53291058540344, 58.7628398090601, 61.92058436572552, 58.176630064845085, 51.59976437687874, 56.46150089800358, 59.515560418367386, 56.98017306625843, 51.67535752058029, 58.613997995853424, 65.28202459216118, 58.657140880823135, 56.883749440312386, 53.91265466809273, 52.05549292266369, 53.61553341150284, 55.51529087126255, 50.11215180158615, 51.3210379332304, 58.86998265981674, 53.1594742834568, 56.473151072859764, 56.13560378551483, 56.98626793920994, 55.31085044145584, 56.728873550891876, 56.71086251735687, 50.91780737042427, 50.70821441709995, 49.485626220703125, 45.89507728815079, 44.01970311999321, 43.86528700590134, 45.5720604211092, 43.008470982313156, 46.76074683666229, 43.620884120464325, 45.40936455130577, 43.71012233197689, 46.950698643922806, 45.5134941637516, 49.46072995662689, 49.382191970944405, 49.55747276544571, 51.22186325490475, 57.83987693488598, 61.94219000637531, 57.48850978910923, 54.53375034034252, 63.55317436158657, 53.24607163667679, 62.4732419103384, 57.488240003585815, 46.854354813694954, 53.61821986734867, 50.3628471493721, 53.02787594497204, 52.996934205293655, 50.948441326618195, 50.28656244277954, 44.98422436416149, 46.8256701529026, 46.05880670249462, 46.21095813810825, 44.442438036203384, 47.69839972257614, 45.185659155249596, 47.60361760854721, 47.332559153437614, 52.296399995684624, 48.696476966142654, 52.14149750769138, 53.93497847020626, 54.865354746580124, 55.30065178871155, 57.00003080070019, 58.1341103464365, 54.75394852459431, 51.81462004780769, 55.910842046141624, 50.84155686199665, 52.743400409817696, 51.2267079949379, 51.54009237885475, 55.385911613702774, 57.555887773633, 56.601701974868774, 61.04411959648132, 59.59159053862095, 45.45227564871311, 34.96102340519428, 37.38677144050598, 56.65098913013935, 58.85938502848148, 61.87545418739319, 60.55343672633171, 62.491313740611076, 56.79396025836468, 62.69227735698223, 65.48462972044945, 58.39961349964142, 52.52624586224556, 62.45956264436245, 60.22047579288483, 68.7397326529026, 62.59224772453308, 64.70940291881561, 63.34705822169781, 73.24656441807747, 64.67605590820312, 66.57978415489197, 63.145847618579865, 52.32942022383213, 0.4680093383649364, 1.0894719581119716, 2.5526301143690944, 4.297419302165508, 0.1418523702886887, 35.30225649476051, 78.64267766475677, 72.93447196483612, 74.56972941756248, 73.62517610192299, 53.314319774508476, 47.56546005606651, 72.43200212717056, 29.029211103916168, 56.90455712378025, 78.22831749916077, 42.29736194014549, 0.8139448834117502, 0.14390133612323552, 0.24675589433172718, 0.19433797424426302, 0.1870051395962946, 0.15222127171000466], [0.0656074057042133, 0.04432064735738095, 0.1640608871821314, 0.0242198038904462, 0.03968437660660129, 0.04571090517856646, 0.21865732240257785, 0.1840170007199049, 2.6358351996168494, 47.58356608450413, 50.539602264761925, 35.32513506710529, 19.894138388335705, 36.07652194797993, 34.93430703878403, 48.68017964065075, 69.30256605148315, 57.754541113972664, 66.41166597604752, 50.79044200479984, 61.85960903763771, 17.96909138560295, 0.8336550195235759, 2.337061744183302, 0.1750151946907863, 1.7813955922611058, 0.09078273214981891, 7.960339626297355, 44.378973841667175, 50.169813707470894, 56.85387164354324, 55.18862999975681, 59.29638057947159, 55.3452005982399, 58.77024181187153, 55.417024344205856, 55.66790208220482, 54.89030420780182, 55.86566247045994, 52.19807647168636, 54.75653998553753, 55.97714088857174, 57.872372791171074, 51.221167892217636, 46.56691163778305, 52.22363010048866, 59.83290418982506, 53.344049379229546, 53.75218167901039, 53.5115709900856, 55.28944618999958, 51.7876984924078, 49.26637798547745, 48.212048560380936, 48.485322296619415, 47.022970765829086, 54.64954152703285, 49.07567381858826, 46.55216082930565, 53.80912162363529, 49.823025315999985, 49.24180090427399, 47.9166866093874, 48.919612392783165, 48.809729889035225, 50.97423814237118, 50.178397446870804, 48.66960860788822, 46.221506372094154, 41.419814229011536, 41.24484121799469, 38.34496982395649, 34.0070503950119, 38.14116396009922, 37.93186359107494, 40.39898380637169, 40.050132125616074, 41.42774820327759, 42.28861100971699, 42.81300947070122, 43.31224948167801, 45.27899734675884, 47.07320027053356, 50.5616220831871, 52.36731559038162, 58.237555995583534, 56.328789219260216, 42.7546826004982, 47.94958524405956, 46.802749782800674, 50.42187698185444, 39.72011223435402, 48.07272143661976, 51.146460101008415, 46.98213815689087, 46.83983579277992, 46.03943534195423, 45.730432122945786, 41.40002869069576, 41.5507248044014, 42.49573029577732, 43.07068504393101, 41.09266698360443, 39.107273519039154, 40.868703201413155, 41.94976419210434, 38.50003570318222, 38.45463953912258, 41.46984614431858, 42.69073203206062, 43.541897758841515, 47.93905220925808, 50.1823378354311, 48.530308082699776, 52.04836070537567, 43.65607403218746, 47.642835304141045, 45.83702400326729, 47.50635422766209, 52.402399107813835, 45.68182893097401, 48.90757843852043, 46.874558329582214, 43.44941072165966, 46.79098941385746, 48.476806953549385, 52.49368540942669, 54.27867762744427, 59.51674595475197, 52.724454626441, 33.990604877471924, 52.50696949660778, 57.1180334687233, 57.39232175052166, 56.643522530794144, 54.613682851195335, 54.80793222784996, 49.17541466653347, 57.32618249952793, 57.67883777618408, 58.83726641535759, 45.79754792153835, 51.83583430945873, 56.495782658457756, 58.29331800341606, 61.00263722240925, 59.81180012226105, 55.49839697778225, 57.16440998017788, 58.525888323783875, 57.508975490927696, 64.13728281855583, 46.31617829203606, 0.32027783745434135, 1.559952381066978, 0.979442271636799, 1.6519482946023345, 0.15466342738363892, 45.222232192754745, 60.53249605000019, 67.00906231999397, 58.06288696825504, 66.16610035300255, 31.006474904716015, 42.78533175587654, 46.05650022625923, 40.11005870997906, 44.57237206399441, 52.843293249607086, 16.327436976134777, 1.474665601272136, 0.1838375790975988, 0.11702689967933111, 0.0664172372489702, 0.18941277056001127, 0.0359528432454681, 0.19201528950361535, 0.127739749441389, 0.10443893959745765, 0.010852938485186314, 0.02342670220969012, 0.04078203157405369, 0.2778701239731163, 0.1308102667098865, 2.982632853090763, 58.19878667593002, 61.3304228335619, 39.365405067801476, 24.429934099316597, 53.90494868159294, 33.607501834630966, 55.924760699272156, 73.15650165081024, 64.2228390276432, 72.02155575156212, 56.31563812494278, 67.35231310129166, 20.78109249472618, 0.9202822961378843, 2.5523425173014402, 0.6724632752593607, 2.809154111891985, 0.18608413432957605, 9.467772413045168, 49.53785061836243, 58.188386633992195, 59.234649091959, 59.33472812175751, 61.60333938896656, 57.49630317091942, 60.77996917068958, 57.64713227748871, 59.6870756149292, 58.909971714019775, 58.476582169532776, 53.952826112508774, 57.02171243727207, 58.913950100541115, 59.116855412721634, 54.1103732585907, 49.21530872583389, 55.45059934258461, 60.6637068092823, 55.219852924346924, 55.69331131875515, 56.74205884337425, 56.65308281779289, 53.93807910382748, 50.80870762467384, 50.827573612332344, 49.93244044482708, 49.95236277580261, 55.17179310321808, 50.44303044676781, 47.9545059800148, 55.77538311481476, 53.381701558828354, 52.84286767244339, 52.54004292190075, 53.90882447361946, 52.622498497366905, 56.81513652205467, 53.133270889520645, 53.2993333786726, 48.45193348824978, 45.82004651427269, 44.26810719072819, 41.5266302973032, 37.15116128325462, 40.207162499427795, 40.69140091538429, 43.69575150310993, 40.89628592133522, 43.43315899372101, 45.641866475343704, 43.142147809267044, 42.946059331297874, 47.44760937988758, 49.692468121647835, 50.41308805346489, 53.75918850302696, 61.62476643919945, 59.20030273497105, 43.647296503186226, 48.80460776388645, 47.8184162825346, 51.69194743037224, 47.99374267458916, 52.44777627289295, 53.946678042411804, 48.47137324512005, 49.28752765059471, 48.863702192902565, 46.971012353897095, 45.25663174688816, 43.98383304476738, 44.296085089445114, 42.970609813928604, 44.911887645721436, 40.31546048820019, 44.86904114484787, 43.572185933589935, 41.12095646560192, 42.03820064663887, 45.13025052845478, 44.92146693170071, 46.83915562927723, 51.096500381827354, 53.98873798549175, 52.15439781546593, 55.25047928094864, 46.86212919652462, 51.32168009877205, 49.12022642791271, 51.47340215742588, 54.0173352509737, 48.3547119051218, 47.91373796761036, 49.72515016794205, 45.81029623746872, 48.18214036524296, 48.99489015340805, 53.403801172971725, 55.20764037966728, 59.48116086423397, 55.84531456232071, 36.475523337721825, 54.59506005048752, 58.87335307896137, 59.60699871182442, 58.27887877821922, 56.34362742304802, 56.5117722004652, 52.60291054844856, 58.281941413879395, 59.95413288474083, 61.88252180814743, 48.619823679327965, 53.127498999238014, 58.862516060471535, 61.67908452451229, 64.569441229105, 62.29383833706379, 58.86043757200241, 59.8638953268528, 61.686608120799065, 58.89626584947109, 67.53841951489449, 52.07123547792435, 0.4995552159380168, 2.192075061611831, 1.3103916286490858, 1.9144804822281003, 0.09305340718128718, 48.51884789764881, 67.74125263094902, 71.24186038970947, 65.33127754926682, 71.42626449465752, 37.09661900997162, 46.14853888750076, 59.62801918387413, 31.51803195476532, 47.97433711588383, 65.49281448125839, 21.00977372378111, 1.7121243593282998, 0.20524555613519624, 0.11708784484653734, 0.0903482417925261, 0.13982590637169778, 0.04715772949566599, 0.34362437843810767, 0.1736381248338148, 0.23705698898993433, 0.08944789791712537, 0.15596138429827988, 0.11504145426442847, 0.3386651398614049, 0.32686433871276677, 3.7468162598088384, 71.8295368552208, 69.62757021188736, 53.448357582092285, 23.410034626722336, 55.70312239229679, 47.12782233953476, 62.11830295622349, 79.96564507484436, 71.30818963050842, 75.5960163474083, 61.56708173453808, 74.86168295145035, 24.05413046479225, 1.3698838488198817, 4.162272904068232, 0.9082575445063412, 6.684398967772722, 0.13748071971349418, 10.631536915898323, 53.67031127214432, 53.963100761175156, 60.05316697061062, 60.29962554574013, 64.15631219744682, 61.5209636092186, 61.66636660695076, 59.20833930373192, 60.46408832073212, 61.069734022021294, 61.30108840763569, 54.57548730075359, 58.590545654296875, 59.95091065764427, 61.498039439320564, 56.143461763858795, 52.13421329855919, 56.14894486963749, 64.73947450518608, 57.593406960368156, 57.09176927804947, 59.40650247037411, 60.086179599165916, 55.81026904284954, 54.408847242593765, 52.91915997862816, 53.17343093454838, 51.67724221944809, 59.187045246362686, 54.59838107228279, 51.33007384836674, 60.871741846203804, 57.72066593170166, 56.92680113017559, 56.59896992146969, 58.761749267578125, 56.45059548318386, 60.424718633294106, 56.05053775012493, 55.19611559808254, 54.011627957224846, 48.94205018877983, 49.62073177099228, 45.96565090119839, 41.605320274829865, 43.222532495856285, 44.27217297255993, 45.190598890185356, 43.56571868062019, 45.174837335944176, 49.16241556406021, 46.14794231951237, 46.09164074063301, 50.06026178598404, 52.51429170370102, 53.623642176389694, 55.003929510712624, 61.385405883193016, 60.647166296839714, 44.55409124493599, 50.2272742241621, 50.78510329127312, 54.41735498607159, 48.75947758555412, 59.89672176539898, 57.10609070956707, 51.67585529386997, 52.303080037236214, 49.848366156220436, 51.27314530313015, 48.28661575913429, 44.841811805963516, 48.17485995590687, 45.47328092157841, 46.51721030473709, 41.80966950953007, 47.918483912944794, 48.36219370365143, 46.4980099350214, 45.23495011031628, 50.26746466755867, 49.58573944866657, 50.66823296248913, 56.005434170365334, 58.17473016679287, 55.15331469476223, 57.39993654191494, 50.00321164727211, 53.20564180612564, 50.62335357069969, 53.08088310062885, 58.29824633896351, 50.33987358212471, 51.034373715519905, 51.5676598995924, 47.0836117118597, 51.26704663038254, 51.941320449113846, 56.07231058180332, 58.510719537734985, 62.37835340201855, 55.28833284974098, 36.968588680028915, 56.80841848254204, 59.95594918727875, 63.29022467136383, 60.27254819869995, 59.03162978589535, 58.555215150117874, 54.40625578165054, 60.41338004171848, 60.95482058823109, 62.958608865737915, 47.82756619155407, 58.8270677626133, 60.83447724580765, 63.49580504000187, 66.62314742803574, 65.89415654540062, 61.5725876390934, 64.86891075968742, 64.0174600481987, 60.69654084742069, 65.63931182026863, 52.76276037096977, 0.6543758895713836, 4.151606876403093, 3.37719916831702, 3.3834327338263392, 0.26688132144045085, 52.235303074121475, 73.4669753909111, 76.5657015144825, 70.38771942257881, 80.66237568855286, 42.95341953635216, 55.9215422719717, 65.74623808264732, 51.468595415353775, 62.895589247345924, 75.00891745090485, 30.798493064939976, 2.159478273242712, 0.39991829835344106, 0.24152071040589362, 0.30319695244543254, 0.15098638250492513, 0.15747205558000132], [0.06875562583445571, 0.045905247679911554, 0.03168915289279539, 0.024427200769423507, 0.11606866828515194, 0.08951844647526741, 0.09764428075868636, 0.5524481402244419, 0.929027704987675, 34.29021120071411, 58.44397611916065, 39.96484950184822, 31.47061049938202, 36.80079348385334, 30.415690205991268, 40.44578969478607, 72.1902970969677, 59.20023813843727, 68.58608409762383, 53.73445563018322, 59.12084519863129, 37.82745659351349, 0.5289922363590449, 0.6926724314689636, 1.9814381143078208, 1.2198114953935146, 0.23043345456244424, 1.6295439843088388, 32.00209178030491, 46.4783725887537, 58.81525419652462, 58.03644798696041, 62.971436977386475, 57.67888717353344, 59.14099171757698, 57.618899792432785, 60.3077457100153, 54.51808378100395, 55.62405243515968, 50.02156466245651, 57.3572838306427, 59.17102910578251, 56.35996274650097, 48.73779594898224, 46.53666526079178, 55.09135141968727, 56.59236207604408, 53.2698355615139, 56.26916661858559, 55.760613307356834, 55.24839699268341, 51.126351580023766, 54.907623678445816, 51.80934973061085, 52.95646257698536, 46.97440557181835, 47.40872606635094, 48.94186779856682, 45.60698814690113, 49.36643421649933, 51.600463539361954, 50.072512328624725, 47.35426738858223, 48.76059092581272, 49.4029388576746, 52.058319970965385, 51.018748953938484, 51.98469512164593, 47.59283758699894, 41.63080170750618, 42.029681503772736, 39.73322533071041, 36.238891035318375, 39.07833807170391, 40.103469863533974, 40.7427703589201, 40.373821556568146, 40.27635298669338, 41.54572047293186, 40.775877982378006, 41.85076430439949, 45.795192047953606, 57.24407270550728, 55.10782353579998, 39.20591622591019, 46.21955707669258, 46.69464558362961, 42.9660614579916, 40.476723834872246, 44.25171107053757, 42.622544690966606, 51.49199455976486, 33.956767693161964, 40.961410626769066, 51.18060126900673, 43.69652286171913, 46.84472993016243, 46.56178951263428, 44.61572013795376, 39.237598925828934, 43.51588815450668, 42.1557891368866, 41.18491843342781, 38.343430906534195, 41.03663519024849, 38.67789275944233, 38.60638439655304, 38.62987093627453, 42.815289348363876, 41.12478286027908, 43.19479778409004, 45.276820063591, 49.77402314543724, 47.56855309009552, 49.57978896796703, 50.033237636089325, 48.0275684595108, 46.813495606184006, 51.117631047964096, 49.22884739935398, 45.78001946210861, 47.751946449279785, 47.53696158528328, 46.30047753453255, 52.28165678679943, 49.58907946944237, 53.2808967679739, 51.74980692565441, 54.502557814121246, 51.888651475310326, 56.63574054837227, 56.32271334528923, 55.10025814175606, 55.11391460895538, 55.03056988120079, 51.14008404314518, 50.0072318315506, 47.868904173374176, 54.159052446484566, 55.20650044083595, 63.78210827708244, 51.88746213912964, 42.53093920648098, 55.01422695815563, 61.68609894812107, 56.410382241010666, 56.69205732643604, 58.88813428580761, 64.87983897328377, 63.58448088169098, 62.850759252905846, 62.157102674245834, 40.62579743564129, 0.2811631222721189, 0.5891869438346475, 0.42499618080910295, 0.9915993630420417, 0.31960649066604674, 44.418092742562294, 61.29922270774841, 63.71788792312145, 56.40578828752041, 64.61569234728813, 24.744984693825245, 46.4912348985672, 50.182565823197365, 29.083886370062828, 37.293501645326614, 56.678989827632904, 8.053311612457037, 0.8346111432183534, 0.047651973873144016, 0.042980080033885315, 0.0037619832164637046, 0.08291353253298439, 0.06547784156282432, 0.07750011442112736, 0.05421917187049985, 0.07134547631721944, 0.11762834357796237, 0.024481498148816172, 0.08869524142937735, 0.16346816351870075, 0.6750934466253966, 0.7978703803382814, 42.66414485871792, 67.84751772880554, 48.1811486184597, 24.699364341795444, 44.115834161639214, 36.0527428239584, 42.95648217201233, 80.77881664037704, 64.29481476545334, 75.32914906740189, 57.030436769127846, 66.10866263508797, 39.72521536052227, 0.5233332712668926, 1.0873640212230384, 1.931715051177889, 2.505906871519983, 0.34326841472648084, 1.7004885524511337, 38.434774205088615, 56.6461405903101, 64.14754986763, 60.30373312532902, 64.79259565472603, 60.988065004348755, 62.8640965372324, 59.08543489873409, 64.13140073418617, 58.419634625315666, 56.708103865385056, 51.84588856995106, 58.093270137906075, 61.644023805856705, 58.74988630414009, 50.08442088961601, 50.03640666604042, 56.48040868341923, 57.18065790832043, 57.19559110701084, 56.82990252971649, 57.62533284723759, 57.14500442147255, 53.57154697179794, 55.994467958807945, 53.58213320374489, 55.16091428697109, 47.417788580060005, 49.525630474090576, 50.56740917265415, 47.98002541065216, 50.5010799318552, 55.72067745029926, 53.34963507950306, 50.78286521136761, 53.315596505999565, 53.40052954852581, 55.66409848630428, 52.59209632873535, 53.44266168773174, 49.744407534599304, 42.46088236570358, 45.40711127221584, 43.776557967066765, 40.272686183452606, 41.33255571126938, 43.12643565237522, 43.5847632586956, 43.49320337176323, 42.061109617352486, 45.41664496064186, 44.149466156959534, 44.710103273391724, 48.35989102721214, 58.72585639357567, 54.297858998179436, 39.69990111887455, 46.35739468038082, 48.740888983011246, 44.83015403151512, 44.717881456017494, 45.086906254291534, 45.14877073466778, 50.56345358490944, 37.96829603612423, 44.573329612612724, 51.33039303123951, 45.50076864659786, 49.01347875595093, 46.66577473282814, 46.694770976901054, 39.93804953992367, 45.05779981613159, 43.18160869181156, 44.481515139341354, 40.35879336297512, 43.03025521337986, 41.48345701396465, 41.645195335149765, 42.57973998785019, 46.609560549259186, 43.56943108141422, 46.373407021164894, 48.93578052520752, 52.57097326219082, 49.84054237604141, 51.05976775288582, 50.23461923003197, 51.00964844226837, 50.59842690825462, 53.376910015940666, 51.446393206715584, 49.31759163737297, 49.07942421734333, 47.75102309882641, 48.19810330867767, 54.54806797206402, 52.97397583723068, 55.743518024683, 52.59373404085636, 56.567253023386, 53.43955725431442, 58.71126517653465, 57.361661195755005, 57.09824413061142, 56.46712839603424, 58.08410502970219, 53.796517699956894, 52.43875555694103, 49.02558870613575, 56.65719799697399, 57.211793437600136, 64.94501307606697, 59.474150240421295, 45.4363165050745, 56.02583907544613, 62.477687671780586, 59.2109839618206, 60.97891129553318, 60.893214493989944, 66.58176764845848, 64.5757032930851, 65.47257676720619, 70.63956990838051, 45.670345947146416, 0.412103888229467, 1.2041667848825455, 1.0259810462594032, 1.4509687665849924, 0.3440478479024023, 49.9526933580637, 65.2074421942234, 69.50280010700226, 62.38690674304962, 72.35053449869156, 26.53783868998289, 52.61288121342659, 57.49166741967201, 29.332575425505638, 46.329648569226265, 65.3521004319191, 12.282810509204865, 0.804902674863115, 0.1664197738864459, 0.12655995727982372, 0.08163180638803169, 0.02666016913281055, 0.09210216681822203, 0.1745396709884517, 0.23088300309609622, 0.1741200458491221, 0.16383377515012398, 0.18252192938234657, 0.23892420285847038, 0.22633730404777452, 0.9467254334595054, 0.9931141161359847, 50.89258052408695, 78.16572725772858, 61.128133088350296, 38.18531759083271, 54.45542894303799, 42.711323127150536, 51.79888129234314, 83.99603560566902, 72.46104776859283, 81.18444487452507, 64.76882413029671, 70.92791363596916, 46.66540615260601, 0.7862682966515422, 1.2624650378711522, 2.9800221556797624, 4.499837765470147, 0.4579838435165584, 3.2090776646509767, 46.06426700949669, 60.376396626234055, 58.20964649319649, 62.8723306953907, 66.16089463233948, 60.97948506474495, 63.998461067676544, 60.7950771600008, 66.66546195745468, 59.10131424665451, 60.347833558917046, 53.35719667375088, 60.768926963210106, 64.87183660268784, 61.201442554593086, 53.3642452955246, 52.160663679242134, 59.497131407260895, 59.35550160706043, 58.44914764165878, 58.389380648732185, 60.64403906464577, 59.78373482823372, 56.76343649625778, 59.60582457482815, 57.381838113069534, 58.2880362868309, 51.72572761774063, 53.14908184111118, 53.485257402062416, 49.9693288654089, 53.06084677577019, 58.4147746860981, 56.514568850398064, 54.70689184963703, 58.03012132644653, 55.3369702398777, 61.22149407863617, 58.18343549966812, 57.6408626139164, 53.600026443600655, 47.3065647482872, 51.05980955064297, 48.26233126223087, 44.23506036400795, 46.039644330739975, 46.897968873381615, 45.58856673538685, 47.46840186417103, 44.27959777414799, 48.00679497420788, 45.61323881149292, 46.18298403918743, 48.89791555702686, 62.33763478696346, 57.4176511913538, 40.4692230373621, 46.80677376687527, 49.41862441599369, 47.51045800745487, 43.76224413514137, 48.02523918449879, 46.910420805215836, 52.97938294708729, 39.29515063762665, 47.13686965405941, 55.58957688510418, 49.241945296525955, 52.00043007731438, 50.593745559453964, 51.461915373802185, 44.017237052321434, 49.98813405632973, 45.15862360596657, 47.80141219496727, 44.08010087907314, 46.316691264510155, 44.2563696205616, 46.120036616921425, 47.966703325510025, 49.83852468430996, 48.85852687060833, 49.90494132041931, 50.24756893515587, 55.68561673164368, 52.34218753874302, 54.11645293235779, 53.76452721655369, 54.800716415047646, 55.208886712789536, 59.511589631438255, 53.6410566419363, 52.57161922752857, 50.655838027596474, 49.14056293666363, 50.009287521243095, 59.1478655487299, 54.95157591998577, 58.336848467588425, 55.53652033209801, 56.187322810292244, 54.33592155575752, 61.41121029853821, 59.61661599576473, 59.83912445604801, 58.034779876470566, 60.32254211604595, 54.26880955696106, 54.0597789734602, 50.64681351184845, 59.552946612238884, 58.60702157020569, 68.28557342290878, 56.99160285294056, 47.26482778787613, 61.58068500459194, 65.90072259306908, 63.604954183101654, 62.03069105744362, 63.07272054255009, 68.98170366883278, 68.17825198173523, 63.43680940568447, 65.13014674186707, 47.30812266469002, 0.6114183634053916, 2.9910370521247387, 2.317479969933629, 2.268090220168233, 0.45593892980832607, 52.743476405739784, 71.0647214949131, 75.79560443758965, 68.93470779061317, 77.94472351670265, 34.30733688175678, 63.16184476017952, 68.47079828381538, 42.017221972346306, 55.12704290449619, 81.41641482710838, 18.262167759239674, 1.100399459246546, 0.34566656104288995, 0.25972321804147214, 0.21353438089136034, 0.2674945432227105, 0.19175869936589152], [0.01840923843701603, 0.08031642384594306, 0.11258219950832427, 0.1704697628156282, 0.10893259925069287, 0.16485122992889956, 0.14995886420365423, 0.7123435009270906, 0.44455845141783357, 18.032198399305344, 61.85515947639942, 46.39231480658054, 38.94563399255276, 39.91550914943218, 26.70249715447426, 38.25654096901417, 70.55274456739426, 58.368903547525406, 62.20677740871906, 56.39293737709522, 58.85691896080971, 45.56807443499565, 0.641336414264515, 0.3341206134064123, 2.2203702433034778, 1.675279636401683, 0.7399358984548599, 0.5210257263388485, 31.568922623991966, 40.9899926930666, 47.68820866942406, 62.467166036367416, 57.314197942614555, 58.178172782063484, 56.48617297410965, 58.02805803716183, 52.75807902216911, 54.05674673616886, 54.48979809880257, 53.72317023575306, 59.17431592941284, 56.75085537135601, 56.00444242358208, 46.03402063250542, 48.1954700499773, 53.95742766559124, 56.63566455245018, 57.49152682721615, 55.03439627587795, 54.025364220142365, 53.35750825703144, 55.62485799193382, 55.38143925368786, 53.999647200107574, 55.43223112821579, 54.537629932165146, 48.98422412574291, 49.39409293234348, 44.86745662987232, 48.696837946772575, 55.438572987914085, 50.67955255508423, 49.501095190644264, 48.72297294437885, 49.342240914702415, 51.868284568190575, 49.854977801442146, 48.728471249341965, 48.54260802268982, 47.60136812925339, 38.966958448290825, 39.47002865374088, 37.04053021967411, 38.56950357556343, 40.61953917145729, 41.75686754286289, 42.588088139891624, 41.244932413101196, 41.03410452604294, 40.889180302619934, 46.19665950536728, 50.29605433344841, 56.009594947099686, 51.43710270524025, 41.82093970477581, 37.0257718116045, 47.02576361596584, 46.773286163806915, 44.24108304083347, 45.377742648124695, 45.04231184720993, 46.28658927977085, 35.560087859630585, 31.262600161135197, 45.10696537792683, 44.48413699865341, 47.65408270061016, 44.18166942894459, 43.424392864108086, 39.964028745889664, 41.80663727223873, 41.486724838614464, 40.42184337973595, 41.111270785331726, 40.51092579960823, 38.74206371605396, 38.78047965466976, 39.46212127804756, 42.22570538520813, 41.26166671514511, 44.53773312270641, 48.243389278650284, 49.31651249527931, 47.439664006233215, 51.026956513524055, 50.79414300620556, 50.36590218544006, 51.35028876364231, 50.21084010601044, 48.87972213327885, 44.91745434701443, 49.23544384539127, 45.4803941398859, 53.78582127392292, 55.693239122629166, 57.10728384554386, 56.12220570445061, 54.97847467660904, 57.02703595161438, 57.54845157265663, 53.41745384037495, 56.501649543643, 56.6649229824543, 55.123364701867104, 52.806127443909645, 46.86422288417816, 42.67428271472454, 46.53929851949215, 52.505445778369904, 58.112531304359436, 55.46618610620499, 63.874405324459076, 48.171006962656975, 44.28609922528267, 56.81436136364937, 59.23462249338627, 61.780884861946106, 63.44956912100315, 61.315850615501404, 71.41618743538857, 66.88730925321579, 46.35284252464771, 39.80624981224537, 0.4635330004384741, 1.050529272761196, 1.406641413923353, 0.4958592017646879, 2.302793520502746, 60.28829835355282, 60.68923383951187, 64.32493194937706, 56.451062858104706, 57.56337337195873, 28.72337881475687, 51.065140664577484, 40.912685841321945, 34.055391401052475, 38.868000358343124, 50.939462408423424, 2.8292445838451385, 0.5370311799924821, 0.05585765953583177, 0.1261366214021109, 0.08632421318907291, 0.15519162872806191, 0.10994593510986306, 0.053868124887230806, 0.019038460923184175, 0.05649964325129986, 0.10636368475388736, 0.08039331034524366, 0.12614361243322492, 0.13561041851062328, 0.959679294610396, 0.3648765489924699, 22.904450856149197, 73.69977369904518, 51.83222070336342, 34.71440903842449, 47.24170222878456, 32.744252756237984, 41.65019206702709, 77.93417528271675, 63.56170490384102, 69.99228984117508, 61.12885884940624, 65.15619054436684, 49.965373277664185, 0.8982634276617318, 0.7246376224793494, 1.9561244663782418, 2.3935224395245314, 2.8404689440503716, 0.46372969925869256, 39.41318370401859, 47.19312943518162, 57.803927063941956, 63.69833417236805, 58.109605461359024, 59.84833136200905, 59.35236297547817, 60.62371015548706, 54.43059727549553, 57.223462611436844, 54.962504133582115, 55.043838769197464, 60.7646331936121, 58.20720702409744, 58.669361025094986, 49.434765949845314, 50.80230496823788, 57.648355811834335, 60.16832359135151, 56.802183017134666, 56.90455712378025, 57.026568576693535, 55.58491453528404, 58.57094630599022, 59.860984683036804, 58.06210421025753, 56.18408538401127, 56.743415370583534, 50.67778564989567, 51.114697605371475, 46.363614946603775, 52.906852439045906, 57.14708670973778, 52.194679453969, 54.551502987742424, 54.47535887360573, 53.57670709490776, 54.85772095620632, 54.35128033161163, 51.154553666710854, 52.55871891975403, 50.418529361486435, 43.38971592485905, 43.17412689328194, 42.17196486890316, 41.48816496133804, 43.64790067076683, 44.15380172431469, 43.50050278007984, 43.82734224200249, 43.05168226361275, 43.58668975532055, 46.47495657205582, 50.01705050468445, 56.886356100440025, 52.53423683345318, 39.680354967713356, 35.151643976569176, 49.3794409185648, 48.33621829748154, 45.79388111829758, 45.900203213095665, 45.03900982439518, 46.9156227260828, 34.410748332738876, 34.745419174432755, 49.15259689092636, 47.859058901667595, 51.208442375063896, 45.86990363895893, 44.41851831972599, 43.78285422921181, 44.59266297519207, 42.839984223246574, 42.32841767370701, 43.02770175039768, 42.67627000808716, 41.26146912574768, 41.1774518340826, 43.55716533958912, 46.85879297554493, 43.57915095984936, 47.7247779071331, 51.55698247253895, 50.42025826871395, 49.667188078165054, 52.89853848516941, 53.025018498301506, 53.30780312418938, 53.1833977997303, 51.610703989863396, 49.894636273384094, 47.844228297472, 52.351231053471565, 48.24711687862873, 56.08288921415806, 56.736256554722786, 60.38070559501648, 57.225453704595566, 56.74873508512974, 59.593817219138145, 61.1104716360569, 54.28248502314091, 56.63280330598354, 58.754993230104446, 54.45043981075287, 53.11157405376434, 49.23149585723877, 44.15738493204117, 48.22712995111942, 54.19858932495117, 60.879254043102264, 56.959802359342575, 66.31532594561577, 55.99452495574951, 47.25853532552719, 58.6593371629715, 63.76042664051056, 64.02177661657333, 64.98273745179176, 62.96140171587467, 71.39233231544495, 71.00123450160027, 51.609203070402145, 43.473391234874725, 0.6287567142862827, 3.7267018016427755, 0.8181581448297948, 0.6122878042515367, 2.2205535834655166, 66.0657325387001, 65.17943769693375, 71.37392610311508, 62.72786624729633, 63.19696627557278, 31.5752549842, 55.79723194241524, 50.59272341430187, 35.62420941889286, 44.98487792909145, 62.146907821297646, 5.33258113078773, 0.8030839380808175, 0.00914882548386231, 0.0706116110086441, 0.05662088420649525, 0.12664802052313462, 0.13341364654479548, 0.09727038675919175, 0.2264252188615501, 0.22084049822296947, 0.2854601573199034, 0.25937826780136675, 0.3189607331296429, 0.2582951181102544, 1.0525590763427317, 0.4906512546585873, 28.036160990595818, 86.08514830470085, 66.35905399918556, 54.22377057373524, 56.35829843580723, 39.648892655968666, 48.127978071570396, 84.52806025743484, 68.86100694537163, 77.53844171762466, 64.99792143702507, 71.45036280155182, 55.56920237839222, 1.160933654755354, 0.9041547146625817, 3.304846538230777, 3.6019696947187185, 3.154736068099737, 1.1824346822686493, 43.18519949913025, 53.76323528587818, 55.08218251168728, 57.85645544528961, 60.141170248389244, 61.01259648799896, 63.429437801241875, 60.917096212506294, 59.81729842722416, 59.908535331487656, 57.552794739603996, 58.38034473359585, 63.741241469979286, 60.708213821053505, 60.93726933002472, 52.73203521966934, 53.74341934919357, 60.54230712354183, 61.17938093841076, 59.6462582051754, 60.56494630873203, 58.14601130783558, 58.17032240331173, 60.56655362248421, 61.50738313794136, 60.0984301418066, 59.37461078166962, 57.79693923890591, 54.58657510578632, 54.63444873690605, 49.397926926612854, 55.44176861643791, 63.61375451087952, 58.202791661024094, 56.70464225113392, 57.51859277486801, 57.39548318088055, 57.36567758023739, 56.23597539961338, 55.050750598311424, 55.35594642162323, 55.14504253864288, 46.383586674928665, 46.906921193003654, 45.67658141255379, 44.89106476306915, 47.43253938853741, 48.34843464195728, 45.4551786929369, 45.9835821390152, 45.17248146235943, 44.15330395102501, 50.68106107413769, 55.62408663332462, 59.593543633818626, 53.74606400728226, 41.82356156408787, 36.93051092326641, 50.6403386592865, 50.964666455984116, 47.46587119996548, 49.54869143664837, 49.22501340508461, 48.6116199195385, 35.41897103190422, 37.96384647488594, 54.31962423026562, 50.384828969836235, 52.93012239038944, 48.646312057971954, 48.5431931912899, 46.47876016795635, 46.20169423520565, 45.34993574023247, 46.43700420856476, 47.78792291879654, 45.168457478284836, 47.75484949350357, 45.344513431191444, 47.77660332620144, 49.14514549076557, 47.565752640366554, 50.865776762366295, 55.798121094703674, 55.41814528405666, 54.92483675479889, 56.94813698530197, 56.51966817677021, 55.76264999806881, 58.47193501889706, 56.10574118793011, 53.17166402935982, 49.6407300978899, 54.51781779527664, 49.04157444834709, 59.2529983073473, 59.47025924921036, 60.373926758766174, 59.17183466255665, 59.7096312046051, 63.34475934505463, 61.441289484500885, 55.481833666563034, 59.250311851501465, 61.71300910413265, 57.319335266947746, 57.44211807847023, 51.10018238425255, 45.684013813734055, 51.67644806206226, 57.729853838682175, 61.16686061024666, 59.69720967113972, 68.35441052913666, 52.663574293255806, 53.239243403077126, 62.4247907102108, 66.81405678391457, 65.84472119808197, 67.63101294636726, 67.3447135090828, 69.68382239341736, 67.41719081997871, 53.85839357972145, 46.913354247808456, 0.9382994449697435, 5.6525918841362, 5.3896835166960955, 0.7612278778105974, 2.4884427711367607, 71.57023876905441, 69.93979185819626, 77.99903020262718, 67.19614148139954, 72.98897624015808, 39.914422407746315, 67.14642494916916, 58.56259435415268, 46.76228955388069, 55.045674070715904, 75.46726405620575, 9.09913994371891, 1.0896290559321642, 0.2110596894635819, 0.2684903866611421, 0.35053499042987823, 0.1771365199238062, 0.27113976480904967], [0.07742373258224688, 0.0034071352774844854, 0.07977357992785983, 0.26104824850335717, 0.08899831227608956, 0.28815240191761404, 0.06969523674342781, 0.6037371349520981, 0.06468032966949977, 8.015658482909203, 58.697057738900185, 52.3873595148325, 33.68137747049332, 32.91125759482384, 30.265765450894833, 30.087832398712635, 71.53893604874611, 62.148906514048576, 62.851032838225365, 57.32561632990837, 56.51690952479839, 53.65465611219406, 2.7417716151103377, 1.2520412472076714, 1.3709067064337432, 0.7797560992185026, 1.1283804452978075, 0.14234978734748438, 16.599335186183453, 51.7089819163084, 34.48075197637081, 50.22336043417454, 65.11093497276306, 57.55249835550785, 58.41903045773506, 55.91465324163437, 57.87504404783249, 54.17626552283764, 58.7288848310709, 57.67030343413353, 57.41676963865757, 54.07627768814564, 49.457902908325195, 43.58693294227123, 51.35718159377575, 56.09342224895954, 55.339975878596306, 54.622977152466774, 57.9788962751627, 57.47840993106365, 55.57063490152359, 55.39564669132233, 58.83429877460003, 56.77749954164028, 55.28755009174347, 57.72275201976299, 52.8339571505785, 45.39671503007412, 45.851968601346016, 45.68916633725166, 52.76564821600914, 50.35019762814045, 49.81586650013924, 49.15830798447132, 49.64344695210457, 51.824457719922066, 50.34872330725193, 50.79756662249565, 50.593403577804565, 47.73687265813351, 41.871537789702415, 39.465202912688255, 38.567269295454025, 38.32974024116993, 39.89109925925732, 40.02181224524975, 40.82374021410942, 41.227635741233826, 40.96226938068867, 42.59291008114815, 44.6467112749815, 54.620138704776764, 54.56894785165787, 46.86214819550514, 41.395563930273056, 38.194634690880775, 52.89646379649639, 53.979238495230675, 45.97645752131939, 47.47312121093273, 55.67645162343979, 46.880391016602516, 38.84520538151264, 37.562831193208694, 44.609826654195786, 53.64913880825043, 52.89085529744625, 49.91404943168163, 41.66467688977718, 40.45016705989838, 40.393690690398216, 40.20134501159191, 39.10921521484852, 40.77933579683304, 38.87491978704929, 39.55633342266083, 37.29673907160759, 39.47627171874046, 40.75252443552017, 42.78902895748615, 49.80330057442188, 48.640456572175026, 50.77164061367512, 48.853385746479034, 48.66429649293423, 48.49138297140598, 50.24294078350067, 47.66205467283726, 49.91495758295059, 48.20862494409084, 46.56005300581455, 46.0242323577404, 52.04696998000145, 55.781417191028595, 56.93788133561611, 54.54548791050911, 52.75524817407131, 53.00750143826008, 53.8682996481657, 54.39060062170029, 58.499358147382736, 55.821258053183556, 55.15429884195328, 49.89985719323158, 44.34292517602444, 45.949106588959694, 43.53407397866249, 42.62561112642288, 48.01217168569565, 54.967675656080246, 58.27965773642063, 61.850386932492256, 64.4759738445282, 47.23056122660637, 53.229124546051025, 63.836673349142075, 59.90276724100113, 63.90722796320915, 64.43332493305206, 70.47215849161148, 45.23751877248287, 57.136048302054405, 42.36084893345833, 0.1796015931176953, 1.645584348589182, 0.4913947085151449, 0.42065850575454533, 8.356829825788736, 72.65478417277336, 53.630280420184135, 63.258705362677574, 51.959327682852745, 60.39799466729164, 25.90978179126978, 52.77765557169914, 35.13330236077309, 28.286820240318775, 45.41826367378235, 46.99867486953735, 0.833316125208512, 0.23421097139362246, 0.04864453701884486, 0.06719806566252373, 0.07476994607714005, 0.06301889850874431, 0.114073285512859, 0.05417942986241542, 0.0775150909612421, 0.022280740849964786, 0.1883670102688484, 0.04456750422832556, 0.2573641680646688, 0.09655535715864971, 0.8419497369322926, 0.11763428818085231, 9.960967898368835, 68.13178047537804, 63.45809206366539, 33.98224912583828, 41.10039956867695, 36.759406104683876, 34.87267054617405, 82.00849905610085, 68.17721843719482, 68.71142417192459, 62.40295708179474, 63.03673267364502, 57.52700932323933, 3.5572532191872597, 1.0841797920875251, 1.8958114902488887, 1.1587656335905194, 5.591498762369156, 0.20356107386760414, 22.577005326747894, 55.72776027023792, 38.74727323651314, 55.566831305623055, 63.9816127717495, 58.44619520008564, 61.84463404119015, 59.24851454794407, 60.65180964767933, 56.97344742715359, 60.32443821430206, 58.78737889230251, 60.38128316402435, 55.95220282673836, 51.47475108504295, 47.23909176886082, 53.84854070842266, 57.862409725785255, 58.19141507148743, 55.77980987727642, 57.73575872182846, 57.60409578680992, 56.20153784751892, 60.48631712794304, 59.22923818230629, 57.8220596909523, 58.240284249186516, 59.189298525452614, 56.132400557398796, 47.281315103173256, 47.524574249982834, 49.85878139734268, 55.416268184781075, 52.23658740520477, 52.58328080177307, 52.14403577148914, 55.27533754706383, 53.66510175168514, 54.33125160634518, 54.603598192334175, 52.060197070240974, 50.055713430047035, 45.4240507632494, 42.489396035671234, 41.38630002737045, 41.37883722782135, 42.31372386217117, 41.69281058013439, 44.27183859050274, 43.540450036525726, 42.344646602869034, 43.66267807781696, 47.55377568304539, 56.50102257728577, 55.373710468411446, 47.214925065636635, 40.33072046935558, 37.35049098730087, 54.5519095659256, 54.91513207554817, 47.9658217728138, 48.26412096619606, 54.971661642193794, 45.778906121850014, 37.88613684475422, 37.204947397112846, 47.76384361088276, 56.3784259557724, 56.40926510095596, 49.818222373723984, 43.95423263311386, 43.08158665895462, 41.65171578526497, 43.38664568960667, 41.53666935861111, 41.38699159026146, 40.793284848332405, 42.50318929553032, 41.66929744184017, 42.755279168486595, 45.33269986510277, 45.734342113137245, 53.71363654732704, 53.52061450481415, 52.74392858147621, 52.85006068646908, 54.03355658054352, 53.37477073073387, 53.94975587725639, 51.113196685910225, 51.83377102017403, 50.27527704834938, 46.598377749323845, 49.21841315925121, 52.781671956181526, 57.650403901934624, 56.176637783646584, 56.00811302661896, 55.36609947681427, 54.90532100200653, 55.9835397452116, 54.54777918756008, 59.179267063736916, 57.830122858285904, 56.664729192852974, 50.72273723781109, 46.733977273106575, 48.20552811026573, 46.836244985461235, 45.70285700261593, 48.75914320349693, 55.75764186680317, 60.12487292289734, 60.01784406602383, 68.94052147865295, 55.187851041555405, 53.493138179183006, 67.608153373003, 61.57449893653393, 67.40916565060616, 65.653515458107, 72.11800217628479, 47.06641003489494, 62.02842637896538, 44.18936401605606, 0.5304191191680729, 2.2144052758812904, 1.479872865602374, 0.37716440681833774, 9.618482775986195, 77.8759092092514, 58.951963260769844, 70.85235089063644, 61.11543796956539, 66.06121838092804, 29.832362607121468, 59.482099413871765, 47.75435172021389, 33.71644578874111, 50.241485461592674, 58.7546094506979, 1.6923791938461363, 0.1762859444716014, 0.011411098475946346, 0.12379128631437197, 0.08200431999284774, 0.05709193275833968, 0.0732828231411986, 0.17864168446976691, 0.1817908842349425, 0.1239103045372758, 0.3575400629779324, 0.1263864283100702, 0.48017723544035107, 0.1632953915395774, 0.8166848332621157, 0.16910844133235514, 12.365189138799906, 82.11398899555206, 74.11848843097687, 49.467987567186356, 48.037672117352486, 45.79591780900955, 38.25010411441326, 85.93505635857582, 71.21434986591339, 76.27837613224983, 68.39314565062523, 69.48876366019249, 62.51341715455055, 4.6109742019325495, 1.8331293412484229, 2.885029627941549, 3.6186166014522314, 8.181078806519508, 0.22623416036367416, 27.945277467370033, 62.817161455750465, 44.634608924388885, 57.25578747689724, 62.548337280750275, 59.963013008236885, 62.85154581069946, 62.006900534033775, 61.909819543361664, 59.235956221818924, 62.06868141889572, 60.246910974383354, 63.182473853230476, 59.25716668367386, 53.9492467045784, 49.28994432091713, 54.87787887454033, 62.00468525290489, 61.19830012321472, 57.768125385046005, 60.049021393060684, 60.49395851790905, 59.248176366090775, 62.337190210819244, 63.478189185261726, 60.43531246483326, 59.248769134283066, 61.229207664728165, 58.05697828531265, 47.923518642783165, 49.549485594034195, 49.676493778824806, 59.11001957952976, 56.011696234345436, 58.769071474671364, 54.74080502986908, 59.343095272779465, 61.34821727871895, 58.024934604763985, 58.166184425354004, 56.32204458117485, 54.56341914832592, 47.71385349333286, 46.294481456279755, 44.60665762424469, 44.03971664607525, 44.95331682264805, 43.7520644813776, 47.8600050508976, 47.01865799725056, 45.15718728303909, 46.79425723850727, 50.33450827002525, 58.08415822684765, 58.62182557582855, 46.11020274460316, 40.365613996982574, 38.002851381897926, 56.262855157256126, 57.886318042874336, 50.33021070063114, 51.747401654720306, 59.78324085474014, 48.62914837896824, 40.15480890870094, 38.06419529020786, 51.35483331978321, 60.25014080107212, 58.66104707121849, 53.58134284615517, 47.46859945356846, 45.28601936995983, 45.441206842660904, 47.34190285205841, 43.026178032159805, 44.243450313806534, 44.271295219659805, 45.07225424051285, 44.64244410395622, 45.302624478936195, 47.31167547404766, 48.64414617419243, 58.066052198410034, 56.60736747086048, 58.712116330862045, 55.04943586885929, 58.2796311378479, 54.92406539618969, 59.10187281668186, 53.91828216612339, 55.182698518037796, 51.640133410692215, 50.83493381738663, 52.541547641158104, 56.57039165496826, 58.723067343235016, 58.425961285829544, 61.025306805968285, 58.263409808278084, 57.61572316288948, 56.33672319352627, 57.53825671970844, 63.1263280659914, 60.92384845018387, 59.5611047744751, 52.13566482067108, 48.723428919911385, 52.6742859184742, 47.80599854886532, 47.16507934033871, 52.13843107223511, 60.40502808988094, 62.19853565096855, 65.46386003494263, 71.29776298999786, 53.28514873981476, 61.30318209528923, 69.88609313964844, 65.97867161035538, 69.01426792144775, 66.30245223641396, 74.66388836503029, 55.499020144343376, 64.7875951230526, 46.89541921019554, 0.5312807229347527, 4.399584894999862, 2.8174096439033747, 0.5088139534927905, 10.463098604232073, 85.61296284198761, 61.698486283421516, 76.79263293743134, 65.48386216163635, 74.96241554617882, 34.119892939925194, 71.56549662351608, 49.24446456134319, 39.47974093258381, 62.18653969466686, 71.9395637512207, 3.648580606095493, 0.42942564468830824, 0.18776506913127378, 0.26304017286747694, 0.23862290574470535, 0.1664747076574713, 0.11562475265236571], [0.013942342484369874, 0.07896139577496797, 0.00978179210505914, 0.05403855910117272, 0.06305754955974407, 0.10391175499535166, 0.024885690327209886, 0.15533649595454335, 0.20152157783741131, 1.684604692272842, 51.21567338705063, 55.01398377120495, 40.97014255821705, 37.07777202129364, 39.981127828359604, 30.9822379052639, 49.202678203582764, 63.857519030570984, 59.50530856847763, 61.986655220389366, 48.86546529829502, 64.6627414226532, 9.942010715603828, 0.28568318753968924, 1.6022892342880368, 0.600197387393564, 3.4455615375190973, 0.23101494211005047, 5.54090685211122, 49.967877343297005, 51.52051962912083, 32.467635199427605, 50.393652096390724, 57.52797067165375, 64.74519699811935, 60.85294805467129, 58.08966413140297, 58.002724796533585, 61.49323269724846, 54.89361383020878, 56.04044169187546, 51.201401352882385, 43.533287420868874, 44.01585392653942, 52.955626621842384, 55.35638339817524, 57.88523130118847, 53.55825528502464, 41.346280574798584, 39.62560370564461, 43.5628954321146, 48.930400013923645, 51.53384171426296, 52.06282652914524, 56.32944658398628, 55.27429260313511, 56.59857854247093, 47.1563246101141, 45.279909297823906, 45.74453316628933, 50.285631492733955, 50.79535514116287, 49.839497432112694, 48.61435577273369, 52.52703621983528, 52.93223887681961, 48.77282626926899, 50.68798050284386, 50.74776649475098, 46.92003808915615, 41.64981588721275, 40.356798470020294, 38.555246740579605, 39.120933786034584, 39.73549760878086, 40.149280205368996, 38.35821971297264, 42.25861541926861, 42.004439458251, 45.26150308549404, 46.998933255672455, 61.5089600533247, 54.954452365636826, 47.127981930971146, 39.68041576445103, 40.05087308585644, 48.603659346699715, 60.23258574306965, 49.47736546397209, 51.0863321274519, 54.277123510837555, 48.016594648361206, 39.64352734386921, 40.587218105793, 38.191933035850525, 46.31011761724949, 51.59425847232342, 50.1783062517643, 48.43407064676285, 40.44657625257969, 38.36508594453335, 38.36818277835846, 38.664331287145615, 39.427858516573906, 38.33003282546997, 38.04917089641094, 40.1309347897768, 40.93970999121666, 43.79064381122589, 48.20007540285587, 50.72517670691013, 48.84771265089512, 47.19535991549492, 49.10731852054596, 48.023206293582916, 51.525010988116264, 46.964624896645546, 49.34732124209404, 48.40838402509689, 45.362752452492714, 43.66627648472786, 46.50851637125015, 51.894225776195526, 54.47242543101311, 48.61036218702793, 38.412408605217934, 37.988024577498436, 44.895784109830856, 52.595744132995605, 56.2572580575943, 52.81849958002567, 54.945036470890045, 49.79575797915459, 46.33968003094196, 42.49436616897583, 46.47303007543087, 43.41933533549309, 42.87032179534435, 41.839174926280975, 46.41890957951546, 52.10563883185387, 58.57801392674446, 59.178830087184906, 67.04677149653435, 45.29238022863865, 58.9969452470541, 58.56808885931969, 63.13640132546425, 56.490455344319344, 51.77218772470951, 50.08412450551987, 70.70842981338501, 31.866644248366356, 0.6746430520433933, 2.765823849476874, 0.16501531878020614, 0.6078808719757944, 17.83061731606722, 69.62248608469963, 57.15166546404362, 58.87148357927799, 54.34115767478943, 50.974253341555595, 30.70080030709505, 49.386272951960564, 29.765163213014603, 33.45883101224899, 43.307872116565704, 36.862255185842514, 0.9034293098375201, 0.06695927964756265, 0.055458053830079734, 0.016012261003197636, 0.05735076789278537, 0.03502780440612696, 0.08875880637788214, 0.03838051219645422, 0.14546878170222044, 0.055917933059390634, 0.08868025004630908, 0.049757350352592766, 0.07884714214014821, 0.042062169522978365, 0.22723237867467105, 0.1873624837026, 2.627939460799098, 62.58657842874527, 62.59143836796284, 45.02515196800232, 40.294474214315414, 49.226423129439354, 30.403192676603794, 58.6102893948555, 70.3179931640625, 69.24555391073227, 66.40927970409393, 53.89979235827923, 68.19155886769295, 10.520341582596302, 0.4468045465182513, 1.8197367223910987, 0.608933949843049, 7.787630818784237, 0.3105698333820328, 8.769284393638372, 55.55749900639057, 51.83860056102276, 39.76863943040371, 53.90306778252125, 61.51681803166866, 66.7882789671421, 62.17202827334404, 61.16446673870087, 57.776279747486115, 63.93622040748596, 58.10397796332836, 59.39207084476948, 52.926694974303246, 46.309376657009125, 45.79742632806301, 54.86206412315369, 59.955766797065735, 59.883984848856926, 54.88363936543465, 43.11641938984394, 43.114150911569595, 45.98361253738403, 50.58525301516056, 53.652490228414536, 53.402402848005295, 59.265773221850395, 58.705478087067604, 58.35744336247444, 49.065391570329666, 48.50862264633179, 47.23450541496277, 55.839136093854904, 53.008724972605705, 51.738852113485336, 53.3802842348814, 57.205291986465454, 54.75045271217823, 52.17286102473736, 54.25347737967968, 53.926235139369965, 49.80510927736759, 46.020949333906174, 42.16156102716923, 42.911382392048836, 42.073337361216545, 40.79222850501537, 40.85174471139908, 42.1545922011137, 43.683911338448524, 43.103560879826546, 44.78593200445175, 49.95039828121662, 62.784996181726456, 57.21327155828476, 45.81474959850311, 39.48485545814037, 39.89986538887024, 49.620093405246735, 61.14044442772865, 51.03002294898033, 52.041950449347496, 56.684624925255775, 46.94732442498207, 40.604028403759, 40.133860632777214, 39.50703486800194, 49.2731112241745, 54.23556134104729, 51.86563991010189, 49.49368938803673, 43.651670068502426, 42.386896535754204, 42.29931503534317, 39.96994122862816, 43.54108080267906, 41.63944624364376, 38.99285785853863, 43.438482508063316, 44.59778130054474, 44.30023066699505, 51.575981453061104, 54.00343179702759, 51.05187177658081, 50.97121350467205, 51.65025606751442, 51.555606946349144, 54.72048372030258, 51.964370012283325, 52.385926991701126, 52.00430206954479, 46.5117309987545, 45.361817702651024, 47.73207351565361, 52.76296555995941, 57.57462456822395, 51.88138626515865, 42.55317181348801, 38.84745106101036, 46.584485694766045, 53.11124727129936, 59.39460910856724, 55.254841446876526, 56.311363354325294, 52.13213860988617, 48.41267019510269, 44.438930824398994, 45.24719685316086, 46.33174225687981, 46.174008920788765, 42.819096744060516, 49.30815674364567, 54.22831133008003, 59.68297563493252, 59.67039071023464, 71.5744337439537, 51.85823030769825, 59.26662057638168, 60.69230407476425, 66.56434938311577, 58.78665693104267, 54.897383227944374, 53.12377139925957, 74.40173283219337, 36.19825601577759, 0.5188808601815253, 2.8301121247932315, 0.5057618266437203, 0.5689839029219002, 20.42913258075714, 76.0506771504879, 60.811648070812225, 66.0661581158638, 61.61259189248085, 56.99876166880131, 33.45121622085571, 57.250501960515976, 34.42743703722954, 31.9402576982975, 52.52843834459782, 44.95827175676823, 0.9702342376112938, 0.02654565018019639, 0.05287410342134535, 0.027784864250861574, 0.09980878414353356, 0.055861518703750335, 0.11165651128976606, 0.22914211760507897, 0.19240144378272817, 0.2325827142340131, 0.1703237378387712, 0.1357903447933495, 0.24813894589897245, 0.23128006694605574, 0.2628633042331785, 0.3192359214881435, 3.1763060856610537, 75.59557557106018, 72.07408413290977, 59.13737431168556, 47.0948439091444, 59.443767070770264, 39.884324222803116, 65.64512550830841, 72.4879503250122, 72.29229882359505, 70.62880888581276, 60.22552192211151, 75.2095390856266, 12.43249112740159, 0.5381917208433151, 2.642529490403831, 3.2015210576355457, 11.967338137328625, 0.2655636827694252, 14.203754682093859, 66.91196233034134, 56.64026990532875, 45.66839285194874, 57.097434774041176, 63.29215116798878, 69.15481477975845, 64.40777510404587, 63.49392034113407, 62.19164282083511, 66.47319987416267, 60.28430476784706, 60.35916455090046, 56.58845968544483, 48.10959465801716, 48.685347363352776, 56.414436623454094, 60.81417113542557, 60.22744841873646, 56.61584861576557, 47.36954256892204, 45.2712457627058, 46.29560239613056, 52.34159477055073, 54.40126284956932, 53.77985559403896, 61.01624049246311, 60.24567224085331, 62.098946794867516, 51.95444114506245, 49.849650487303734, 50.5988334864378, 60.90976260602474, 57.900046706199646, 55.49891754984856, 58.06219540536404, 60.93254618346691, 60.76304487884045, 56.105319410562515, 57.44204968214035, 59.52075093984604, 53.33151385188103, 48.12493063509464, 46.63031503558159, 45.1076303422451, 45.066797733306885, 43.255256339907646, 43.36192421615124, 43.69398079812527, 46.33011594414711, 47.69999563694, 48.20946089923382, 51.70229807496071, 68.28236639499664, 60.68468548357487, 47.657525315880775, 40.31164549291134, 39.64267998933792, 50.76005503535271, 64.33725088834763, 53.22019502520561, 52.55551189184189, 57.647128477692604, 48.06522063910961, 40.97497969865799, 40.749739184975624, 40.4358646273613, 50.58711491525173, 60.98797760903835, 53.27031433582306, 54.58749085664749, 45.33142693340778, 45.771188735961914, 43.896422535181046, 42.657582610845566, 46.3543738424778, 44.226807206869125, 43.61046127974987, 46.272845417261124, 47.884080559015274, 47.92460538446903, 56.106322556734085, 56.64917662739754, 53.70277673006058, 53.64303633570671, 54.613314270973206, 53.199702724814415, 58.7679847329855, 54.18018311262131, 56.84580087661743, 54.61875557899475, 49.431406930089, 46.80691435933113, 49.986975118517876, 55.799922198057175, 58.476726561784744, 56.12203851342201, 41.31340853869915, 37.720879912376404, 47.14861862361431, 55.63882604241371, 61.48543171584606, 55.786801502108574, 58.08229252696037, 52.24377661943436, 51.286904364824295, 46.54425345361233, 48.26366879045963, 46.75890393555164, 49.01340655982494, 44.271124228835106, 51.13267444074154, 56.71726517379284, 63.18731479346752, 62.58814014494419, 68.8766697049141, 50.14018289744854, 67.55906760692596, 60.74610158801079, 67.58875921368599, 60.58208338916302, 61.450010016560555, 55.99066436290741, 75.39203569293022, 37.50717557966709, 1.517328405752778, 7.529898723587394, 2.0264728227630258, 0.6031063094269484, 22.347148060798645, 83.98400545120239, 65.36234468221664, 70.37904068827629, 66.87028616666794, 63.46197925508022, 41.785544604063034, 65.82281917333603, 43.71308997273445, 50.6468591094017, 60.56341879069805, 62.84551553428173, 1.5778099978342652, 0.2146461626398377, 0.1522156610735692, 0.1228021370479837, 0.1805204906850122, 0.11902577054570429, 0.20662920142058283], [0.07025287908618338, 0.03825294072157703, 0.047984162883949466, 0.10031385274487548, 0.047672572181909345, 0.013081218330626143, 0.06869271397590637, 0.03940541071642656, 0.32870447903405875, 0.6482779292855412, 40.00144153833389, 64.09550786018372, 43.473098650574684, 25.081639029085636, 32.966787815093994, 46.21009558439255, 32.83030293881893, 64.97965961694717, 47.37958163022995, 65.90925693511963, 46.26908361911774, 65.60262098908424, 25.289343483746052, 0.19805349205853418, 1.1107901204377413, 0.3014133044052869, 2.234432101249695, 0.2909633901435882, 0.6142815097700804, 33.59227605164051, 54.77665230631828, 50.62866568565369, 53.79002384841442, 53.67899000644684, 56.845546290278435, 54.599790796637535, 57.788636684417725, 53.92235554754734, 56.14886127412319, 52.084884345531464, 51.158912032842636, 44.053665697574615, 42.212675884366035, 46.10399007797241, 54.35781218111515, 56.154959946870804, 52.229223400354385, 40.81248141825199, 46.65143050253391, 52.48644679784775, 55.369500294327736, 49.0306044369936, 49.214419573545456, 50.22289305925369, 50.127016603946686, 51.44660599529743, 55.60041770339012, 51.99107117950916, 47.96433225274086, 43.7593524903059, 49.881036803126335, 48.29318180680275, 49.75534334778786, 50.58857023715973, 50.795195549726486, 51.47413171827793, 51.7814402282238, 52.516731172800064, 51.598149463534355, 50.00287726521492, 43.4416439384222, 42.4268551915884, 38.95196445286274, 39.71283942461014, 39.693585857748985, 41.49881199002266, 39.950026497244835, 41.456189677119255, 39.94564153254032, 48.502387180924416, 51.13731399178505, 58.85746233165264, 57.2982008010149, 39.63369347155094, 37.99827262759209, 38.726355358958244, 44.80555035173893, 54.52826723456383, 54.147398471832275, 53.34116153419018, 51.725207045674324, 40.48078961670399, 41.63113608956337, 40.18031693994999, 43.73626872897148, 39.70265977084637, 51.37185260653496, 53.47166173160076, 48.29265743494034, 41.948601454496384, 37.816589176654816, 39.844954535365105, 36.65805034339428, 39.37534913420677, 39.10024009644985, 37.95670285820961, 40.823580622673035, 41.897931173443794, 41.27691529691219, 46.49061933159828, 50.099095702171326, 49.90079574286938, 49.370393604040146, 51.72351993620396, 50.65579243004322, 51.82782433927059, 46.04588359594345, 51.411682069301605, 51.289613619446754, 47.820240184664726, 45.20851872861385, 48.4254565089941, 49.35650534927845, 56.22549556195736, 58.96269388496876, 53.9050854742527, 44.55969974398613, 48.42597708106041, 54.94104288518429, 57.40047611296177, 54.748374223709106, 53.08123268187046, 46.183451414108276, 43.48008647561073, 39.67445768415928, 45.3004851937294, 40.36885902285576, 44.40654516220093, 41.684375032782555, 41.2528245896101, 42.63831004500389, 53.55964221060276, 54.96299050748348, 66.40965968370438, 63.75353381037712, 57.05951660871506, 54.307848662137985, 62.79958739876747, 51.460843831300735, 62.55255505442619, 57.88224846124649, 69.20591443777084, 27.618789486587048, 0.404426934546791, 1.9196376367472112, 0.771603814791888, 0.19034594704862684, 22.570572271943092, 66.14038333296776, 60.208856016397476, 56.214198768138885, 55.81623092293739, 42.382139191031456, 39.56600770354271, 34.12042871117592, 33.142323195934296, 35.48448331654072, 43.76491919159889, 26.83242928236723, 1.2127963593229651, 0.01628020228963578, 0.03737437516974751, 0.05933795364398975, 0.06884568545501679, 0.030861218510835897, 0.09632748813601211, 0.03752616663405206, 0.07883704893174581, 0.11027960470528342, 0.0452434040926164, 0.06694659634376876, 0.04067593785293866, 0.04512234496360179, 0.03630574559792876, 0.3411395492730662, 0.6485711666755378, 48.69750291109085, 71.99421241879463, 51.65564797818661, 34.61901895701885, 48.635155856609344, 49.15289707481861, 37.59566903114319, 68.62528279423714, 55.051214173436165, 73.62952306866646, 51.26785598695278, 72.01514929533005, 27.10755541920662, 0.20220249833073467, 1.5601662383414805, 0.9473502624314278, 7.879414418712258, 0.17724845063639805, 2.476622317917645, 41.720416098833084, 57.26918175816536, 55.604570880532265, 55.59896998107433, 57.473215609788895, 59.32660415768623, 58.22571203112602, 59.31639030575752, 57.44164690375328, 58.741435557603836, 53.75246286392212, 50.185343474149704, 46.05936527252197, 45.24090439081192, 48.97964537143707, 56.239478811621666, 57.8392119705677, 52.26784832775593, 45.256662145256996, 52.14493252336979, 55.20440295338631, 56.246124655008316, 49.420668706297874, 49.48330454528332, 51.52126058936119, 51.77973411977291, 53.763847053050995, 57.892842292785645, 52.390608340501785, 50.03910832107067, 47.566850781440735, 52.774459943175316, 51.036953777074814, 51.549717262387276, 54.14723128080368, 54.5248968154192, 53.44565212726593, 54.775975942611694, 56.4803820848465, 53.495691642165184, 53.51466402411461, 46.69511295855045, 44.96481120586395, 41.88267879188061, 42.77169808745384, 42.36348979175091, 43.80192920565605, 43.49213942885399, 43.72515432536602, 44.4977592676878, 50.20817644894123, 51.23406819999218, 58.56351010501385, 56.84335760772228, 39.283606857061386, 38.82255859673023, 37.465898394584656, 45.31314991414547, 57.316907197237015, 56.03925235569477, 53.62971045076847, 53.736062943935394, 41.777751222252846, 39.85823482275009, 40.675118789076805, 43.17420668900013, 43.35002705454826, 57.05721773207188, 55.74208930134773, 50.389947295188904, 44.48777720332146, 42.29077309370041, 42.59779281914234, 39.615028873085976, 43.105061799287796, 42.29870706796646, 41.942153200507164, 43.73789884150028, 45.13458229601383, 44.90132801234722, 49.15867656469345, 52.24457077682018, 53.06364342570305, 52.545047253370285, 53.366000801324844, 53.0721739679575, 52.59510196745396, 48.1663104146719, 52.72123999893665, 52.81558133661747, 49.759492725133896, 47.662362456321716, 51.322842836380005, 51.70939989387989, 60.41332304477692, 61.48897312581539, 54.0875630825758, 44.47958864271641, 50.41051559150219, 55.768889263272285, 56.417225673794746, 55.2199175208807, 54.45153795182705, 47.09992803633213, 46.411636769771576, 43.28071877360344, 46.97108834981918, 42.088129967451096, 46.064855977892876, 42.87483975291252, 46.466920003294945, 44.83949393033981, 55.47780968248844, 56.992131024599075, 65.94039246439934, 68.97104144096375, 61.873368099331856, 54.44471351802349, 64.03372317552567, 54.65014949440956, 66.06771603226662, 60.85769400000572, 72.78251051902771, 32.04874947667122, 0.2318167733028531, 1.2978422082960606, 1.7079818691127002, 0.10393560762167908, 24.425942413508892, 74.12272900342941, 63.75579848885536, 64.4205804169178, 62.330468371510506, 48.957462161779404, 43.330416306853294, 43.65660600364208, 34.45869795978069, 36.82369485497475, 54.750319719314575, 34.81059327721596, 1.170763608533889, 0.011851718973048264, 0.07822346349712461, 0.027606819312495645, 0.10874320316361263, 0.07175425867899321, 0.1164779404643923, 0.12748492561513558, 0.18477621779311448, 0.19718713854672387, 0.11026081352611072, 0.20219944068230689, 0.2318987954640761, 0.2433514254516922, 0.13424226926872507, 0.4385611857287586, 0.9157430834602565, 56.85134097933769, 84.08595398068428, 59.8388546705246, 34.81449946761131, 54.47652921080589, 55.65355785191059, 43.81401635706425, 76.2595671415329, 60.814152136445045, 78.92982825636864, 56.57372027635574, 77.27038130164146, 31.161248199641705, 0.46579203859437257, 2.190797380171716, 2.659852998331189, 13.034396879374981, 0.26431052188854665, 5.160306924954057, 51.62019208073616, 59.45870026946068, 57.50030055642128, 58.529600724577904, 63.69155153632164, 62.610824927687645, 59.799519181251526, 61.01893834769726, 60.24863228201866, 61.66620321571827, 56.512923538684845, 54.69244882464409, 48.30555774271488, 46.70214258134365, 51.20457038283348, 58.122030794620514, 61.25014454126358, 57.48428821563721, 52.21330225467682, 51.66075870394707, 53.27327437698841, 58.43917317688465, 49.824165254831314, 52.015743255615234, 51.45056538283825, 54.755540639162064, 56.68114811182022, 60.38107417523861, 56.37293145060539, 52.92390592396259, 48.10476511716843, 55.98601721227169, 54.53456349670887, 56.40875592827797, 57.12090611457825, 58.66925083100796, 57.71660774946213, 59.50602672994137, 60.5461411178112, 56.48634776473045, 56.12920492887497, 51.496379524469376, 48.64754319190979, 43.83051887154579, 45.12302331626415, 44.43376690149307, 46.63439221680164, 45.69582358002663, 44.00521829724312, 46.57421104609966, 53.972284868359566, 56.09237350523472, 62.952692583203316, 60.00177472829819, 39.30450573563576, 39.26903083920479, 37.95113615691662, 45.73334276676178, 56.90804533660412, 59.400301203131676, 56.90784774720669, 55.037683099508286, 39.52438473701477, 39.42157745361328, 40.597264766693115, 45.560505241155624, 45.91468423604965, 60.573248863220215, 60.60797140002251, 53.241523280739784, 47.32829198241234, 43.25502835214138, 45.07721297442913, 41.2408172339201, 44.74915377795696, 44.449289068579674, 44.99568074941635, 47.16317564249039, 47.98602908849716, 47.6227305829525, 52.72344008088112, 54.631211310625076, 56.07912361621857, 55.010731145739555, 58.8066590577364, 57.42527358233929, 56.39262579381466, 51.573374792933464, 58.43380406498909, 55.01114912331104, 53.14552143216133, 50.396680533885956, 52.755069583654404, 53.16683828830719, 61.87407486140728, 59.306385442614555, 53.702921122312546, 44.9869754165411, 49.02826376259327, 59.10874284803867, 60.468066707253456, 57.968492433428764, 55.90942092239857, 48.890053778886795, 48.97424206137657, 44.3875727802515, 50.13492777943611, 43.35656650364399, 49.95119243860245, 44.61483098566532, 48.07238705456257, 48.08203473687172, 58.67253005504608, 57.99257934093475, 68.16917046904564, 65.34567877650261, 63.34155231714249, 59.790813848376274, 66.91730484366417, 57.801267206668854, 67.1311117708683, 63.792793303728104, 74.95774939656258, 34.46766547858715, 0.602602717699483, 5.5477650091052055, 2.462970125488937, 0.21677712094970047, 26.976893730461597, 80.3157202899456, 68.80733102560043, 70.91403678059578, 67.19870254397392, 56.068617179989815, 49.57373969256878, 54.98843394219875, 49.88458961248398, 51.667814925312996, 63.729450702667236, 51.432117372751236, 1.4098331239074469, 0.12786431150743738, 0.1885983080137521, 0.19607494119554758, 0.2602398715680465, 0.1424437135574408, 0.1856515512918122], [0.032711394524085335, 0.19375886156922206, 0.046199624266591854, 0.0980182786588557, 0.07547862289356999, 0.05654627238982357, 0.03344037650094833, 0.10409393740701489, 0.34971429384313524, 0.17070116446120664, 20.25631595402956, 64.59581941366196, 38.1214240193367, 29.96467910706997, 19.285872727632523, 51.76934167742729, 36.62676282227039, 45.8319740742445, 55.3450296074152, 51.32287323474884, 53.95729847252369, 56.054964512586594, 51.408045664429665, 2.698417128995061, 1.4976548426784575, 0.704556293785572, 4.294698648154736, 0.2712472574785352, 0.41885072307195514, 25.900003015995026, 54.88191805779934, 51.275155395269394, 63.90579164028168, 57.10378423333168, 55.58021038770676, 54.426725283265114, 54.17795643210411, 50.46856127679348, 49.57295313477516, 45.81641010940075, 45.244217813014984, 41.95249244570732, 43.69027979671955, 45.52328623831272, 51.023954674601555, 56.89164161682129, 55.24734064936638, 63.84505569934845, 64.59048449993134, 56.61022491753101, 56.021419912576675, 58.17787639796734, 59.79757368564606, 56.51404447853565, 54.3023731559515, 55.36031998693943, 56.21488653123379, 50.62787912786007, 48.30344505608082, 43.94330061972141, 49.46479573845863, 49.54067386686802, 48.67922969162464, 50.627476349473, 49.736690148711205, 51.119200363755226, 50.47940969467163, 52.60802127420902, 49.310212433338165, 52.286581322550774, 45.63832126557827, 40.68442828953266, 39.79486182332039, 41.39891915023327, 38.22754092514515, 36.97403758764267, 37.97785632312298, 39.43575069308281, 42.16028809547424, 47.73737043142319, 54.67274688184261, 55.61153590679169, 57.541490346193314, 39.25708048045635, 37.34455190598965, 39.12144675850868, 41.06160745024681, 55.133434161543846, 52.76266157627106, 53.24514828622341, 47.42024324834347, 40.29064781963825, 41.44454710185528, 41.19358956813812, 42.30353280901909, 45.46483397483826, 47.53038413822651, 58.76557186245918, 47.71900601685047, 47.9960947483778, 39.05138611793518, 39.281813353300095, 39.432634860277176, 40.76525375247002, 38.83578948676586, 39.83293578028679, 40.39275214076042, 40.99010668694973, 42.25784406065941, 47.0300117880106, 49.96422193944454, 51.26274526119232, 51.124987453222275, 52.94104680418968, 48.284199088811874, 50.338068678975105, 49.84058037400246, 50.601181760430336, 49.74441893398762, 43.80122244358063, 48.03976960480213, 46.50067359209061, 48.60563524067402, 54.98578168451786, 51.949113830924034, 56.70893982052803, 50.16427740454674, 52.51669317483902, 54.92354482412338, 56.555739641189575, 51.760830134153366, 52.74231366813183, 44.32442016899586, 41.725811809301376, 40.19759841263294, 41.139636263251305, 43.753269016742706, 52.526781633496284, 49.07981939613819, 47.43211381137371, 41.19165927171707, 45.19726753234863, 49.81546372175217, 61.391690745949745, 64.12169605493546, 69.18604910373688, 54.761681109666824, 60.36207519471645, 56.04638457298279, 67.40987241268158, 55.47743730247021, 67.7892516553402, 16.737053096294403, 0.06459740950958803, 0.5912868061568588, 0.23315919970627874, 0.7639627216849476, 40.14858864247799, 61.95742338895798, 61.24816484749317, 56.029144898056984, 48.96834097802639, 33.997311517596245, 41.809213533997536, 48.530007898807526, 32.6898168772459, 29.961787462234497, 50.406335815787315, 18.879119753837585, 1.272752748336643, 0.052299180169939063, 0.12517653463874012, 0.0839678275224287, 0.04814601044927258, 0.01792124294297537, 0.07214683995698579, 0.08239287883043289, 0.16285062243696302, 0.011562966010387754, 0.12646496237721294, 0.04462120232346933, 0.09821495521464385, 0.009844395972322673, 0.08975711374660023, 0.3680790646467358, 0.19640942715341225, 25.20269103348255, 75.69416508078575, 41.739453077316284, 34.38827633857727, 32.383203729987144, 55.56637912988663, 40.091063529253006, 55.73600962758064, 58.91067087650299, 56.92662633955479, 63.41489218175411, 60.13245351612568, 56.19605854153633, 3.157702758908272, 1.747042704373598, 0.5269271065481007, 9.520969558507204, 0.6567308725789189, 0.18285740981809795, 35.38837507367134, 55.79361453652382, 53.50794978439808, 65.90427920222282, 59.925334230065346, 59.66403745114803, 56.75563931465149, 57.20202036201954, 53.20024609565735, 52.50475041568279, 47.684382274746895, 46.825252175331116, 45.32313957810402, 46.713336780667305, 48.28918442130089, 52.940792217850685, 60.69002419710159, 57.63136312365532, 65.12128561735153, 66.91823959350586, 57.62702755630016, 56.739110201597214, 62.07546025514603, 61.04348123073578, 56.4682075381279, 55.38755312561989, 56.331669464707375, 58.077527582645416, 53.23165521025658, 51.676999032497406, 45.65311387181282, 51.60848490893841, 53.667617216706276, 53.25917333364487, 52.6007978618145, 52.83141128718853, 54.25024755299091, 54.381226524710655, 56.27073593437672, 54.51527953147888, 55.469332337379456, 48.86215187609196, 44.18247498571873, 41.39913573861122, 44.115499779582024, 40.254618152976036, 41.83545872569084, 40.29168136417866, 41.976309567689896, 43.424126878380775, 51.086210533976555, 56.923556104302406, 57.89680168032646, 57.15368315577507, 38.86414356529713, 35.79376772046089, 38.076236844062805, 43.52186523377895, 55.93136094510555, 54.62156742811203, 53.679518178105354, 48.03492106497288, 39.41018186509609, 39.62696023285389, 39.427292346954346, 44.014520198106766, 44.73823316395283, 50.968352258205414, 60.96096485853195, 49.62286725640297, 51.932976096868515, 41.37885622680187, 43.618706837296486, 41.21013768017292, 41.796393021941185, 40.644659623503685, 42.2228479385376, 44.392839297652245, 44.02402728796005, 44.79321241378784, 48.762832805514336, 51.57969765365124, 54.032044261693954, 52.22379349172115, 54.01546195149422, 52.47563637793064, 52.01891988515854, 53.062336295843124, 54.33158218860626, 52.944409623742104, 47.22401037812233, 48.76153327524662, 47.22497932612896, 51.89348101615906, 56.858674585819244, 51.95803955197334, 57.868094220757484, 53.94335322082043, 52.82455265522003, 56.59190230071545, 59.44427244365215, 55.764508098363876, 54.06293660402298, 46.094558984041214, 44.24492083489895, 41.71800322830677, 44.12169724702835, 46.76173858344555, 53.618694841861725, 52.86327637732029, 50.233106911182404, 43.386387303471565, 48.66883344948292, 54.08766567707062, 61.77078500390053, 62.852507159113884, 72.96594187617302, 58.92373077571392, 64.25136789679527, 58.27177695930004, 69.18407320976257, 59.23939123749733, 70.05548804998398, 20.76732963323593, 0.031074196340341587, 0.893700763117522, 0.8510570763610303, 1.74760329304263, 47.53847010433674, 65.47981917858124, 67.0649953186512, 63.91678065061569, 56.61103047430515, 40.21999441087246, 46.61435969173908, 54.67244289815426, 41.93001665174961, 35.230364352464676, 60.01940198242664, 26.769183576107025, 1.5553534403443336, 0.025861887261271477, 0.10494427537196316, 0.021621878840960562, 0.10231343607301824, 0.02686005176656181, 0.06728844440658577, 0.16876749868970364, 0.2868829434737563, 0.09442508904612623, 0.31123898341320455, 0.13535652979044244, 0.2128806823748164, 0.2152788732200861, 0.3183277108473703, 0.6397430528886616, 0.3294961724895984, 32.746483236551285, 83.02591726183891, 54.67618949711323, 37.82289683818817, 33.043672889471054, 68.45575109124184, 47.55020007491112, 58.6185235530138, 66.75382241606712, 62.20422014594078, 66.41623333096504, 64.27687972784042, 59.279809668660164, 5.450647920370102, 2.1064649429172277, 2.736720973625779, 16.011738516390324, 1.1380793061107397, 1.135314479470253, 42.71996006369591, 57.56700597703457, 59.13806967437267, 69.37805280089378, 63.43005336821079, 60.96303194761276, 59.86985720694065, 59.79868322610855, 55.249928310513496, 55.50046406686306, 50.94076193869114, 50.03066137433052, 46.903740763664246, 49.48918282985687, 50.21025113761425, 54.806366711854935, 63.72040718793869, 61.10314182937145, 64.91393074393272, 66.00325629115105, 59.50821541249752, 60.671245604753494, 64.92466136813164, 64.13972228765488, 59.42978002130985, 55.27277268469334, 56.77301198244095, 61.596397161483765, 54.9481713026762, 53.546278327703476, 48.12178820371628, 55.26717558503151, 55.58548450469971, 55.76736554503441, 56.623440608382225, 56.990637704730034, 58.00019033253193, 57.5591441988945, 60.92655390501022, 58.05366866290569, 59.73417788743973, 52.22907520830631, 46.80893585085869, 43.07352349162102, 47.71438546478748, 43.82774122059345, 43.46044532954693, 42.986815944314, 44.34131786227226, 48.52161794900894, 54.55194756388664, 61.48914031684399, 62.64202505350113, 61.189317405223846, 38.6360228061676, 35.194338485598564, 38.210628032684326, 43.99695374071598, 59.22003507614136, 59.225461184978485, 55.91379068791866, 49.65915530920029, 41.053798869252205, 40.65389692783356, 40.27546003460884, 44.10585969686508, 47.1903707832098, 52.82777488231659, 67.30769589543343, 55.93160033226013, 53.31166751682758, 45.592670515179634, 44.91593822836876, 43.99876244366169, 45.335048139095306, 42.07796551287174, 43.6979553848505, 47.00489893555641, 46.18471674621105, 47.96783946454525, 52.14111752808094, 56.01697035133839, 57.67169415950775, 56.537398025393486, 59.05206888914108, 55.68681746721268, 56.38448283076286, 55.144556164741516, 56.718359515070915, 54.889890030026436, 50.87558403611183, 51.7962746322155, 50.17137922346592, 53.58932621777058, 58.93132656812668, 54.039385467767715, 61.27790205180645, 53.783176615834236, 53.40372137725353, 58.85973080992699, 62.45429612696171, 56.17115467786789, 57.35254928469658, 48.012031093239784, 47.449995651841164, 43.230276480317116, 44.947826117277145, 47.92614810168743, 58.445359244942665, 53.742708787322044, 52.12955854833126, 46.928032860159874, 50.54970592260361, 56.0573735833168, 64.95528012514114, 65.52918612957001, 73.37464794516563, 59.88668650388718, 67.48060941696167, 59.09066341817379, 72.08373561501503, 60.28255306184292, 72.53169357776642, 23.209374994039536, 0.14752625254914165, 2.4255388090386987, 1.4846204733476043, 2.1534166485071182, 49.44140039384365, 73.25494676828384, 69.22773286700249, 66.55878648161888, 61.57957166433334, 49.249069914221764, 51.11579954624176, 65.18174037337303, 46.02432735264301, 44.59284916520119, 71.1035706102848, 36.67012609541416, 1.7925116582773626, 0.22569182852748781, 0.1968092517927289, 0.21802686795126647, 0.1654102304019034, 0.12756973825162277, 0.22862969432026148], [0.04308434436097741, 0.08121131293592043, 0.1702263977495022, 0.05525703571038321, 0.07905057223979384, 0.06797425565309823, 0.05142921982042026, 0.09732766571687534, 0.31821724958717823, 0.08308187389047816, 7.388941012322903, 56.63306549191475, 38.3791109919548, 46.08443632721901, 25.382037609815598, 57.04792723059654, 45.25027468800545, 31.530236899852753, 73.26788127422333, 52.5656383484602, 46.73655353486538, 51.791638880968094, 64.10869315266609, 36.62327840924263, 0.5203046556562185, 2.2185976384207606, 2.871637959033251, 1.4777903398498893, 0.07684306139708497, 15.320490058511496, 59.525386691093445, 58.81243094801903, 58.83246347308159, 55.25466665625572, 57.59346775710583, 51.28047131001949, 49.79007728397846, 47.0367032289505, 43.51409465074539, 42.71674543619156, 42.91352167725563, 40.17163060605526, 43.73820662498474, 45.75523339211941, 51.45511753857136, 54.09942984580994, 60.309972390532494, 58.86463634669781, 52.65666626393795, 54.07001182436943, 55.68734563887119, 53.44318985939026, 55.040282160043716, 58.12361150979996, 56.41982473433018, 55.05413621664047, 54.67808559536934, 51.359982043504715, 50.45135200023651, 45.16649678349495, 48.397983983159065, 53.40902589261532, 48.41926284134388, 47.845869809389114, 47.50823512673378, 50.203814283013344, 49.655819088220596, 52.77728319168091, 53.204737454652786, 50.73984391987324, 45.221263244748116, 38.14598210155964, 40.77560819685459, 39.93037015199661, 39.36021454632282, 39.76016208529472, 38.39972868561745, 41.13232545554638, 44.2591168731451, 49.81156513094902, 52.73879885673523, 55.78537277877331, 54.92105595767498, 42.22525700926781, 39.41963195800781, 44.238502979278564, 40.89627832174301, 48.63830208778381, 54.88916426897049, 51.38664521276951, 42.583638578653336, 43.56316901743412, 39.028150364756584, 40.25961868464947, 43.42974677681923, 42.27388300001621, 52.649013474583626, 55.06108224391937, 50.34406095743179, 49.36959184706211, 41.48026518523693, 40.71718253195286, 39.627032428979874, 41.08797803521156, 39.47427682578564, 36.5341541916132, 41.112623512744904, 40.34056194126606, 42.303631603717804, 49.86698515713215, 51.25591702759266, 50.37366136908531, 50.07124699652195, 50.318689718842506, 48.958989679813385, 49.08715680241585, 48.6436066031456, 53.07781666517258, 48.01140032708645, 45.08768901228905, 47.139172330498695, 47.10262589156628, 47.3139401525259, 52.518935054540634, 52.609438598155975, 56.41404904425144, 56.31879195570946, 56.53881914913654, 56.13229036331177, 55.29763475060463, 54.29443538188934, 48.54817472398281, 43.75384658575058, 40.782865807414055, 41.01410239934921, 42.13064208626747, 53.38752284646034, 56.475176364183426, 54.82793055474758, 57.500140964984894, 50.86096242070198, 43.451325818896294, 41.42011821269989, 52.30799317359924, 57.8691353648901, 64.69212144613266, 62.269816026091576, 58.03435429930687, 56.31012462079525, 62.092696130275726, 61.60690739750862, 62.414968237280846, 9.021189976483583, 0.7494955323636532, 0.09308291497291066, 1.2972666579298675, 7.533115725964308, 58.30551154911518, 55.657232254743576, 61.385584473609924, 42.02579811215401, 45.14929510653019, 42.62651547789574, 48.663137555122375, 37.78885446488857, 30.75207855552435, 43.70420224964619, 45.6737619638443, 14.652601797133684, 1.1809014645405114, 0.07876296032918617, 0.05166754199308343, 0.026236245103063993, 0.10192279922193848, 0.014166144537739456, 0.03998653090093285, 0.01964343373401789, 0.07138840213883668, 0.06780529089155607, 0.02756175796093885, 0.07055022797430865, 0.029185836829128675, 0.028255717988940887, 0.06042035005521029, 0.4003568779444322, 0.06970608694246039, 10.149309542030096, 68.31309154629707, 41.86121754348278, 46.46657422184944, 34.914882481098175, 66.96008294820786, 47.365077808499336, 34.53274838626385, 76.78921312093735, 57.45382905006409, 53.3260877430439, 57.39760346710682, 68.03314536809921, 41.14285849034786, 1.2451003259047866, 0.6021363520994782, 9.300134908407927, 5.684352004900575, 0.04888216899416875, 20.43846108019352, 62.95445568859577, 60.77048107981682, 61.901931166648865, 57.16810718178749, 61.24923638999462, 53.93151305615902, 52.74986766278744, 49.82225775718689, 46.88618190586567, 43.37546668946743, 46.54612675309181, 43.789481073617935, 45.887040719389915, 47.780733704566956, 54.1005127876997, 55.989699214696884, 60.74574060738087, 60.075175389647484, 54.88941505551338, 58.01640786230564, 58.59866961836815, 54.28200624883175, 56.25175975263119, 57.92532294988632, 58.99878054857254, 57.306864336133, 57.96675592660904, 52.861729860305786, 52.85406567156315, 47.129790633916855, 48.283420130610466, 54.6984601020813, 51.79811753332615, 52.06265173852444, 50.99631115794182, 52.14669942855835, 53.1322031468153, 55.68167634308338, 55.885512605309486, 54.580712020397186, 48.467330262064934, 41.57726638019085, 42.41538740694523, 43.49353775382042, 43.08738134801388, 41.357163190841675, 40.411971509456635, 42.60507322847843, 45.82627817988396, 52.43236429989338, 57.231875360012054, 58.82105268537998, 56.68293781578541, 43.30081969499588, 38.05074401199818, 43.34004119038582, 40.48787623643875, 50.30996158719063, 56.00671850144863, 53.764208033680916, 43.13974253833294, 42.69500680267811, 39.287353456020355, 38.92579145729542, 43.39783228933811, 42.38387569785118, 55.51342137157917, 59.00190398097038, 51.83376342058182, 51.66337676346302, 43.28233368694782, 42.567269057035446, 42.7011738717556, 42.70647078752518, 42.431506142020226, 38.382508009672165, 43.206767141819, 42.64951944351196, 45.8203960955143, 53.265545591712, 53.099080324172974, 54.35525871813297, 52.65929572284222, 52.36694701015949, 52.9362628608942, 52.093555480241776, 51.90514259040356, 56.72827698290348, 48.58221709728241, 46.165991351008415, 50.35981111228466, 50.32703407108784, 50.46782411634922, 53.63877296447754, 56.267099529504776, 59.70042049884796, 56.799188777804375, 56.81871972978115, 55.57318076491356, 57.49230578541756, 55.61704561114311, 50.95459699630737, 45.91861702501774, 41.51212267577648, 42.26141206920147, 46.124383583664894, 53.69994968175888, 59.45034831762314, 56.09001763164997, 59.54663135111332, 52.08198510110378, 46.65386997163296, 42.456364408135414, 54.68703031539917, 60.288697332143784, 64.38973367214203, 64.55800384283066, 62.99381397664547, 61.453004255890846, 67.1785332262516, 63.60134057700634, 67.61143639683723, 10.327150449156761, 1.7662890278734267, 0.7730702986009419, 1.8051465740427375, 14.89918576553464, 66.52131289243698, 61.417981535196304, 68.23226228356361, 47.84694895148277, 46.3149319589138, 47.361319810152054, 48.531174436211586, 46.56444936990738, 39.51889783143997, 44.66754175722599, 56.88143156468868, 19.824801608920097, 1.322632315568626, 0.04362062769359909, 0.04971388647390995, 0.06067138150683604, 0.09085454978048801, 0.05008337953768205, 0.05093829284305684, 0.20049235259648412, 0.12941541499458253, 0.2840515610296279, 0.08462484343908727, 0.22858721378725022, 0.0834523317462299, 0.16491852788021788, 0.26494298013858497, 0.655453191138804, 0.4577591805718839, 13.258528802543879, 85.50066366791725, 54.61593993008137, 55.763983726501465, 40.62601402401924, 72.7330219745636, 50.9622535854578, 44.41797874867916, 83.52591723203659, 64.01187434792519, 57.848783656954765, 63.5816690325737, 73.90086650848389, 47.712569162249565, 1.5128687513060868, 3.4473985014483333, 15.952142514288425, 4.316157046705484, 0.15459155780263245, 26.961662247776985, 65.35541385412216, 63.10751527547836, 64.34003233909607, 60.551194846630096, 63.21732558310032, 56.62990786135197, 54.274490252137184, 52.593471854925156, 47.530980706214905, 46.11471690237522, 49.92802508175373, 45.39923429489136, 48.034240901470184, 50.55871143937111, 57.74207018315792, 57.90733091533184, 59.915986731648445, 61.99257530272007, 56.35438844561577, 60.5193867534399, 62.131419852375984, 56.40057496726513, 58.08329947292805, 60.747686102986336, 60.681227669119835, 59.98649574816227, 59.427997916936874, 55.53287252783775, 56.43739879131317, 50.784483924508095, 53.228634372353554, 59.163988083601, 54.417172595858574, 56.230670884251595, 56.17264799773693, 56.869633197784424, 55.85924841463566, 58.096708953380585, 59.76831905543804, 56.41003645956516, 50.89901737868786, 45.00281676650047, 44.44969184696674, 45.674879103899, 46.700584664940834, 44.777196273207664, 42.399211674928665, 46.4715139567852, 49.16124142706394, 56.716653406620026, 58.67741659283638, 62.20518909394741, 58.863709196448326, 44.47622962296009, 37.95036479830742, 45.48827111721039, 40.72770796716213, 52.91349448263645, 59.00905519723892, 55.73730155825615, 42.89052911102772, 43.22466418147087, 40.06131872534752, 38.80713142454624, 43.315160125494, 42.58075453341007, 55.850987657904625, 64.9173429608345, 54.70441438257694, 53.933010175824165, 46.310277208685875, 45.00150963664055, 44.16223347187042, 45.6849105656147, 45.22043488919735, 40.869827941060066, 45.835101306438446, 46.82405523955822, 46.98690690100193, 56.231366246938705, 56.21620126068592, 56.6755548119545, 56.314657777547836, 56.05557627975941, 54.54972468316555, 55.98960041999817, 54.785160049796104, 59.613720551133156, 52.03152380883694, 48.53531241416931, 51.677075028419495, 53.085712641477585, 51.09066769480705, 57.116513550281525, 55.96449136734009, 61.7467474937439, 58.31146202981472, 58.63996960222721, 58.1268223375082, 59.29011471569538, 56.20176583528519, 53.28581750392914, 47.959388718008995, 44.133662804961205, 44.380303770303726, 46.913103461265564, 56.177230551838875, 61.46750047802925, 58.87983553111553, 62.48746074736118, 54.45358604192734, 48.947662487626076, 44.8173601180315, 57.86106839776039, 61.838801354169846, 66.32168680429459, 64.24520462751389, 66.30220904946327, 62.20700919628143, 67.94866070151329, 65.77893912792206, 68.55491816997528, 13.073410335928202, 2.015225663781166, 1.6282382793724537, 2.148181479424238, 13.932816870510578, 68.09122905135155, 65.28016269207001, 72.49507874250412, 54.78156924247742, 56.412301138043404, 54.9925073236227, 60.90180203318596, 54.687315300107, 44.89904433488846, 58.89880791306496, 68.59287053346634, 29.6537683904171, 1.6388897015713155, 0.40297042520251125, 0.17251816461794078, 0.12902329384814948, 0.23500367417000234, 0.08723304723389447, 0.24802222091238946], [0.06498033544630744, 0.03719118714798242, 0.06223664888239, 0.04310713571612723, 0.06792606800445355, 0.06868101030704565, 0.02559202566772001, 0.09790672644157894, 0.0734911514155101, 0.19566367263905704, 2.59757861495018, 46.067470237612724, 45.7232391089201, 46.39970541000366, 29.65912990272045, 45.44885203242302, 35.77787697315216, 42.320096120238304, 67.51535475254059, 56.955831572413445, 56.83969460427761, 59.9946653097868, 53.46833311021328, 57.889137491583824, 9.112860057502985, 0.5576662695966661, 6.4782011322677135, 1.860409383662045, 0.08541641072952189, 4.935626881197095, 61.17462359368801, 57.399666756391525, 60.04966735839844, 56.6267616301775, 54.38261345028877, 48.1573086977005, 46.78886912763119, 44.41656522452831, 45.46487957239151, 46.72314025461674, 46.564977541565895, 44.056667536497116, 44.18702334165573, 42.47754827141762, 45.82867585122585, 49.712740033864975, 50.5511574447155, 50.723155215382576, 52.782272323966026, 50.000832974910736, 51.87965735793114, 54.509587436914444, 55.12641213834286, 55.4116590321064, 57.894267216324806, 56.28163754940033, 56.912468299269676, 48.65799643099308, 47.85630784928799, 45.63766770064831, 44.938752204179764, 53.50398279726505, 49.823918268084526, 50.62269240617752, 48.48023056983948, 50.79145275056362, 51.30464181303978, 52.65391141176224, 51.79317019879818, 51.1076033860445, 45.54278299212456, 39.395324662327766, 40.137968212366104, 40.8726853877306, 39.03300270438194, 39.16045926511288, 40.09042516350746, 42.80412554740906, 45.6814831495285, 51.377423107624054, 54.061507880687714, 53.44331905245781, 55.68942792713642, 49.016564190387726, 41.78752809762955, 42.67240181565285, 39.01636339724064, 45.89940145611763, 53.60655449330807, 49.562572091817856, 42.55954407155514, 41.35668821632862, 43.46439331769943, 39.34512935578823, 40.092135071754456, 41.256027817726135, 47.96401686966419, 56.942376494407654, 51.50089368224144, 51.05472542345524, 41.12094886600971, 41.065247654914856, 37.92780540883541, 39.07717153429985, 38.37903119623661, 39.431080743670464, 38.13938185572624, 42.1251779794693, 43.24864089488983, 51.32364459335804, 50.812009647488594, 48.714081421494484, 49.90168109536171, 52.129854932427406, 50.8904754370451, 49.89945061504841, 47.45222993195057, 50.82209810614586, 46.96022093296051, 45.322056636214256, 47.89626270532608, 44.83118377625942, 48.18976275622845, 51.00333698093891, 54.13420557975769, 55.74344202876091, 56.27298541367054, 54.84709672629833, 55.763390958309174, 54.98944088816643, 52.340416833758354, 49.4181152433157, 45.7843816280365, 42.27399319410324, 39.2908226698637, 43.48908059298992, 57.5495421141386, 59.28154617547989, 58.364408388733864, 56.81784197688103, 56.966774985194206, 52.09431163966656, 47.01257452368736, 43.44320945441723, 49.07017931342125, 55.17516352236271, 55.92817671597004, 56.167316883802414, 57.576144486665726, 60.86477302014828, 61.568742245435715, 43.53359900414944, 9.475519247353077, 2.4907934200018644, 0.23453107452951372, 2.272301819175482, 34.87699471414089, 58.67197148501873, 56.39248140156269, 48.420030400156975, 48.50781328976154, 70.78228265047073, 45.36253206431866, 53.31942670047283, 33.43983203172684, 30.833584181964397, 44.817911088466644, 39.69961993396282, 5.570117784664035, 1.082695140503347, 0.023301839573832694, 0.22133736609248444, 0.040655079792486504, 0.07545419881353155, 0.053085237013874575, 0.046581125279772095, 0.044375989309628494, 0.10720909485826269, 0.03356945082487073, 0.04560655550449155, 0.0779995130142197, 0.07502260283217765, 0.1770263258367777, 0.044853093786514364, 0.2797258197097108, 0.11593536371947266, 5.070691583678126, 59.401733726263046, 54.0261659771204, 39.74205985665321, 32.335877269506454, 55.8829515427351, 34.24188159406185, 47.35521353781223, 71.6330797970295, 62.56998851895332, 57.90071927011013, 67.07008704543114, 56.71784274280071, 66.56613528728485, 11.162743661552668, 0.06568872282514349, 5.176436584442854, 6.715638991445303, 0.010482702346052974, 8.274910971522331, 65.95306098461151, 58.37589517235756, 63.54364447295666, 58.75346191227436, 56.64235219359398, 50.54239511489868, 48.73095631599426, 46.67729951441288, 48.12972217798233, 48.94621476531029, 47.282154858112335, 45.618585124611855, 46.73019267618656, 45.57613380253315, 50.31924828886986, 51.19159407913685, 52.82792307436466, 51.146589294075966, 54.4254295527935, 51.65811024606228, 53.37103933095932, 56.517673283815384, 58.57462450861931, 58.86123552918434, 58.853890523314476, 57.80982814729214, 56.83489166200161, 53.293059915304184, 51.45196370780468, 47.15982422232628, 45.26941806077957, 55.87047301232815, 52.92766772210598, 54.82112891972065, 50.418270975351334, 53.16888637840748, 52.42413014173508, 53.77350613474846, 55.94007007777691, 53.829146549105644, 47.19073176383972, 40.58021128177643, 41.74342766404152, 42.03418046236038, 42.90272265672684, 40.321555361151695, 42.6004184782505, 44.50684078037739, 48.206740245223045, 52.78318427503109, 56.89068406820297, 54.67468857765198, 58.08693587779999, 49.56068739295006, 39.69964653253555, 42.01957784593105, 38.59046325087547, 45.97008906304836, 56.64484865963459, 52.55447834730148, 41.63482949137688, 41.71709507703781, 41.565901190042496, 39.48733672499657, 39.098021015524864, 40.064255967736244, 49.46807116270065, 59.77722957730293, 54.57220807671547, 53.06778520345688, 44.57946628332138, 42.62190632522106, 40.43820910155773, 42.41791807115078, 40.78867569565773, 41.70967407524586, 40.57750962674618, 45.35812430083752, 46.009150967001915, 53.83697032928467, 52.96735659241676, 52.017475962638855, 53.426242768764496, 53.294887617230415, 52.15990751981735, 51.14815481007099, 51.06938883662224, 53.482460752129555, 47.5634765625, 47.62785650789738, 47.91314139962196, 48.443904519081116, 48.51914048194885, 52.52007499337196, 54.13509473204613, 56.170311123132706, 56.12534433603287, 58.2517596334219, 58.11754323542118, 57.925607934594154, 53.10109041631222, 50.21343916654587, 46.2697371840477, 44.413316398859024, 41.79063253104687, 46.841758489608765, 57.27412149310112, 60.62412433326244, 61.81734390556812, 59.81470316648483, 59.508553594350815, 53.75615246593952, 48.107181787490845, 45.45189566910267, 49.70229819417, 58.16702798008919, 55.79579181969166, 58.9181412756443, 60.80307573080063, 65.18668010830879, 63.639178946614265, 45.79091727733612, 15.04643451422453, 3.5822931630536914, 0.13517819170374423, 4.132648268714547, 42.354450076818466, 62.108507081866264, 65.26224285364151, 53.78376558423042, 48.049565479159355, 72.19380050897598, 50.674738213419914, 58.6554841697216, 44.1045031696558, 33.13781663775444, 49.9824495613575, 54.939754754304886, 8.021659310907125, 0.9027279505971819, 0.021428289619507268, 0.12022210517898202, 0.08852962375385687, 0.029168483561079483, 0.03270842964411713, 0.08602762129157782, 0.14138563361484557, 0.2060133672785014, 0.13250359537778422, 0.14911772886989638, 0.1917169609805569, 0.21576018567429855, 0.3171202662633732, 0.18357880704570562, 0.37462483684066683, 0.31317052664235234, 6.234356816858053, 74.2160139977932, 67.30875983834267, 61.311264261603355, 40.01498021185398, 62.67129868268967, 41.08384765684605, 54.23089139163494, 76.88527196645737, 68.70399937033653, 66.72289967536926, 73.09584930539131, 61.91593341529369, 70.83899080753326, 14.56396870315075, 0.5632094596512616, 19.009733945131302, 7.057419726625085, 0.12186451509478502, 14.285917673259974, 68.65469321608543, 60.916720032691956, 66.25279650092125, 60.46010613441467, 59.616756588220596, 52.872825264930725, 52.919824942946434, 49.48935002088547, 50.8227364718914, 52.59105518460274, 51.89220428466797, 48.88218820095062, 50.9468188136816, 48.19442130625248, 51.76543168723583, 53.20035628974438, 55.02369225025177, 55.346621721982956, 56.39579102396965, 53.24966624379158, 55.81333547830582, 61.33689388632774, 60.64210116863251, 60.3243850171566, 60.649723559617996, 60.90144105255604, 60.51502078771591, 55.66155642271042, 53.66533353924751, 49.6292395144701, 49.237742722034454, 57.69665502011776, 55.34021146595478, 58.777552619576454, 53.19168135523796, 57.67727605998516, 57.32642188668251, 59.24579009413719, 59.5565640181303, 56.60451002418995, 50.43326877057552, 43.82019482553005, 43.33306096494198, 44.985102117061615, 44.135722294449806, 44.12702076137066, 44.959746077656746, 47.76238828897476, 52.71701082587242, 55.24119257926941, 60.315573289990425, 58.47250498831272, 60.96910402178764, 49.80855569243431, 42.74045616388321, 41.34088106453419, 40.08617699146271, 46.90872609615326, 57.37801931798458, 52.94170796871185, 41.61918193101883, 42.13883064687252, 44.158410876989365, 40.59521667659283, 40.49732252955437, 40.42793445289135, 51.07667684555054, 63.3804926276207, 58.19590263068676, 59.11260724067688, 47.50170327723026, 46.83478966355324, 43.95802862942219, 43.85406240820885, 44.51788678765297, 46.694204807281494, 42.370990589261055, 47.95786879956722, 48.44830088317394, 58.374880626797676, 56.04563981294632, 55.69543160498142, 54.65611897408962, 57.291345968842506, 55.57522125542164, 53.67136761546135, 51.86069257557392, 54.921899512410164, 49.49617065489292, 49.734915643930435, 49.390441328287125, 50.14676034450531, 50.87583102285862, 55.18893398344517, 57.048683390021324, 58.03684316575527, 58.417172357439995, 59.257231280207634, 59.81024220585823, 59.38897781074047, 55.09459264576435, 53.3774533867836, 49.677941501140594, 45.687855407595634, 44.56269018352032, 48.48536029458046, 59.64483708143234, 65.60522004961967, 62.317887246608734, 62.234914898872375, 62.221596613526344, 56.660142838954926, 51.282325610518456, 47.459514141082764, 52.09235854446888, 60.75739458203316, 59.45884846150875, 61.28900125622749, 61.99176974594593, 68.51458713412285, 66.99778452515602, 50.81162586808205, 17.757885418832302, 7.270634835585952, 1.5859026135876775, 4.511582935228944, 46.83688335120678, 69.91253972053528, 67.67243832349777, 61.521544978022575, 57.384676560759544, 83.00891697406769, 57.57497034966946, 67.9257783293724, 48.32532808184624, 42.40847937762737, 61.28105968236923, 67.54354164004326, 14.699223395437002, 1.341484528966248, 0.14673864090582356, 0.3398667956935242, 0.27057555445935577, 0.19073506991844624, 0.11759332905057818, 0.14060024841455743], [0.047236723694368266, 0.08807531805359758, 0.04701075085904449, 0.1268013333901763, 0.025914854340953752, 0.09723263370688073, 0.05588256972259842, 0.0641769976937212, 0.015721346535428893, 0.49352476140484214, 0.5739983869716525, 33.3319216221571, 49.88297089934349, 45.84540635347366, 36.16509139537811, 39.88852299749851, 40.68618759512901, 36.7023179680109, 62.96939268708229, 58.06649297475815, 62.681789919734, 56.91707745194435, 53.476673662662506, 48.820380717515945, 27.630781643092632, 0.17009018396493047, 5.811302242800593, 8.079882636666298, 0.006599076486963895, 1.6139753884635866, 51.608697697520256, 56.81183069944382, 63.283814415335655, 52.404895573854446, 55.52640527486801, 46.78650185465813, 52.17774756252766, 49.66889798641205, 53.344262167811394, 51.20180793106556, 53.93644139170647, 48.54522608220577, 47.49314233660698, 43.639620915055275, 44.357056617736816, 43.51390466094017, 48.00279378890991, 46.07666574418545, 44.18067768216133, 45.02644769847393, 48.473204746842384, 49.48377192020416, 57.00268305838108, 54.84529562294483, 56.83838367462158, 54.76712241768837, 53.357040882110596, 49.95478704571724, 48.90467159450054, 46.241744086146355, 42.20091171562672, 50.68390712141991, 53.615924790501595, 52.76866905391216, 50.266738906502724, 51.57234124839306, 52.84298926591873, 51.98326639831066, 52.05154113471508, 50.31571827828884, 41.25833809375763, 38.21658991277218, 40.18972523510456, 38.946359753608704, 38.85129265487194, 39.54372949898243, 40.99097304046154, 43.572691306471825, 48.17189231514931, 52.665675580501556, 54.6670775860548, 55.120887234807014, 56.355482786893845, 54.480218812823296, 41.26793257892132, 42.08742320537567, 40.96386529505253, 45.716274082660675, 52.340538427233696, 49.93719018995762, 43.00366424024105, 41.423716619610786, 42.171470895409584, 44.067333564162254, 40.16152694821358, 40.99995955824852, 49.6216057240963, 57.327634021639824, 54.80604752898216, 49.19254034757614, 44.53795351088047, 39.61691357195377, 40.868129432201385, 38.58534872531891, 39.73162181675434, 36.52335897088051, 39.90450493991375, 42.03356109559536, 45.08679986000061, 49.96695019304752, 51.68547637760639, 49.68306362628937, 49.94070500135422, 49.878240153193474, 49.60365168750286, 51.22848629951477, 48.45845393836498, 53.68279740214348, 45.079025477170944, 44.25436332821846, 48.74295987188816, 47.757630944252014, 48.98290179669857, 50.994369462132454, 55.3318215161562, 53.516666516661644, 56.418228819966316, 56.60672150552273, 53.194523602724075, 56.84531830251217, 54.709844291210175, 50.58464504778385, 48.202127292752266, 43.99094246327877, 40.84758013486862, 43.43116030097008, 56.36838309466839, 58.3259354531765, 58.452039286494255, 58.17910373210907, 57.117938473820686, 57.02922083437443, 53.11829589307308, 50.51873378455639, 46.272872015833855, 47.79134273529053, 52.27932371199131, 55.02879537642002, 60.09676203131676, 58.72921161353588, 61.9522100687027, 45.54531745612621, 13.77196865156293, 0.1365502891712822, 0.343022852903232, 9.646081645041704, 67.17289432883263, 57.36557878553867, 57.83477760851383, 54.678184390068054, 59.03055064380169, 61.3239061832428, 53.82527835667133, 43.386052921414375, 28.970477655529976, 28.209490589797497, 35.78801102936268, 34.75258558988571, 3.0111052002757788, 0.652414244832471, 0.04951637500198558, 0.07418083667289466, 0.04650050206691958, 0.0479078886564821, 0.060444017144618556, 0.05686737371433992, 0.06052377575542778, 0.12794225185643882, 0.010799805349961389, 0.06808185222325847, 0.03155818238155916, 0.06580799337825738, 0.06571564794285223, 0.03872500601573847, 0.06539226451423019, 0.3454413637518883, 1.3122750213369727, 45.79226240515709, 59.50392924249172, 45.77193729579449, 36.22782222926617, 53.37193988263607, 40.16682006418705, 43.858511969447136, 71.00901648402214, 64.27369549870491, 67.32298627495766, 62.59157136082649, 58.48228566348553, 55.39611406624317, 33.59516389667988, 0.03689402379677631, 3.4489452559500933, 8.949723411351442, 0.01621692492335569, 3.5768281063064933, 56.86158902943134, 59.94603171944618, 64.415602684021, 54.867577627301216, 59.513603523373604, 49.29633177816868, 54.1458747535944, 51.222136840224266, 56.296468153595924, 52.598392590880394, 56.38050064444542, 51.42838977277279, 49.274042174220085, 47.37481668591499, 49.03029665350914, 46.26901522278786, 50.47769598662853, 48.822728991508484, 46.942259296774864, 48.47007371485233, 49.848974123597145, 53.19972172379494, 57.4895965307951, 57.76487275958061, 58.83343242108822, 57.343927547335625, 55.50325691699982, 52.36904449760914, 49.63811583817005, 48.30498777329922, 45.1249498128891, 51.319198831915855, 57.38840416073799, 55.232304856181145, 55.03770589828491, 53.91226328909397, 56.064509600400925, 55.631899014115334, 54.35256086289883, 52.55561448633671, 44.145050793886185, 40.80178879201412, 43.53053256869316, 40.38231410086155, 41.413742154836655, 41.31986439228058, 44.91145446896553, 46.002033948898315, 50.72124771773815, 54.54503953456879, 57.97511547803879, 56.279703453183174, 57.427492663264275, 55.91481663286686, 42.52414897084236, 42.32741452753544, 40.66256046295166, 44.48851436376572, 56.04902163147926, 51.27586975693703, 42.755776941776276, 40.273704528808594, 42.80840031802654, 42.80333898961544, 39.40663285553455, 40.83854041993618, 51.608731895685196, 58.84295850992203, 56.23966500163078, 53.17437708377838, 47.8974824398756, 42.55523130297661, 42.97014243900776, 40.19939571619034, 41.560763865709305, 38.95122729241848, 42.399485260248184, 43.615704998373985, 46.70571058988571, 52.511251866817474, 55.001007467508316, 52.17854171991348, 51.737727373838425, 53.0316187441349, 51.94349393248558, 53.945511505007744, 52.167499512434006, 55.85691533982754, 47.32168793678284, 46.607888638973236, 50.67843161523342, 49.654352366924286, 51.46811664104462, 52.68945470452309, 57.72305600345135, 54.29220870137215, 59.45306517183781, 58.56437265872955, 54.12754453718662, 57.594949677586555, 56.147877126932144, 53.54855440557003, 49.17164906859398, 46.414019241929054, 41.149188950657845, 46.06220372021198, 58.2733728736639, 58.211231008172035, 60.50525911152363, 60.40737256407738, 59.29629698395729, 60.561682283878326, 56.50959111750126, 53.70988994836807, 48.46907816827297, 49.41673971712589, 53.26190918684006, 58.022533133625984, 62.03415647149086, 62.882468551397324, 60.72859972715378, 53.024767711758614, 15.33409047871828, 0.8031706209294498, 0.1799029199173674, 10.972189586609602, 69.22186598181725, 64.20399203896523, 63.571056202054024, 59.777153581380844, 63.81778076291084, 65.86514130234718, 59.80127468705177, 50.07269851863384, 39.85909357666969, 28.88456616550684, 42.80635602772236, 48.68546895682812, 4.763244856148958, 0.6397979124449193, 0.04692348542448599, 0.018249528257001657, 0.01022986376483459, 0.11045302235288545, 0.05755145204602741, 0.09710301019367762, 0.21153632638743147, 0.19583629618864506, 0.1550086893257685, 0.1956180899287574, 0.11995905835647136, 0.2311042373185046, 0.1618112446158193, 0.14083979884162545, 0.1712594970013015, 0.4194385337177664, 1.787709309719503, 61.355786472558975, 69.6859958767891, 62.50022426247597, 43.52301277220249, 65.18493220210075, 49.31840479373932, 49.90833833813667, 74.81691375374794, 69.1103495657444, 72.51087829470634, 70.38730904459953, 63.526663184165955, 62.97683268785477, 35.73860988020897, 0.4764408781193197, 16.438079439103603, 18.409233167767525, 0.12085066715371795, 8.324762396514416, 62.94162377715111, 58.15202258527279, 67.22463235259056, 57.186574190855026, 62.931862100958824, 52.33602046966553, 56.48708492517471, 53.151072934269905, 59.63450163602829, 55.22138424217701, 59.826737120747566, 54.39134918153286, 52.101136073470116, 49.936346635222435, 51.44630581140518, 49.40109595656395, 53.42179700732231, 51.68286591768265, 50.15084512531757, 50.1012159883976, 52.97969073057175, 54.418760910630226, 61.32609486579895, 60.11649817228317, 60.55132403969765, 60.15146769583225, 59.39213544130325, 55.87192453444004, 51.28978081047535, 51.59438766539097, 47.47338339686394, 54.66289781033993, 61.93954914808273, 59.036626517772675, 56.71139448881149, 59.29194241762161, 58.837236016988754, 60.565463081002235, 59.08794656395912, 55.46537294983864, 45.742317885160446, 44.461543411016464, 47.06325240433216, 43.68756674230099, 43.259071335196495, 43.30815330147743, 47.50617943704128, 50.56763716042042, 53.28450657427311, 56.61942422389984, 62.47933678328991, 58.538845628499985, 61.88979461789131, 57.49196760356426, 42.781159579753876, 42.043117582798004, 42.5418484210968, 46.31366662681103, 58.809117525815964, 51.76453873515129, 43.43164287507534, 40.10521396994591, 43.35527077317238, 44.89952690899372, 41.0968391597271, 43.985208570957184, 52.85200238227844, 60.4771064221859, 59.490082785487175, 57.36321151256561, 52.67663039267063, 46.41531117260456, 46.20213881134987, 42.556413039565086, 44.40895803272724, 41.08818702399731, 47.320126220583916, 45.775915682315826, 50.45157618820667, 55.3810478746891, 57.64230653643608, 54.471703469753265, 55.72672292590141, 57.36193858087063, 52.65211410820484, 57.16718003153801, 54.984455555677414, 58.4819170832634, 48.437995836138725, 48.351360484957695, 52.17931307852268, 52.53954894840717, 54.50220063328743, 54.1073714196682, 60.27467608451843, 56.34593389928341, 60.664018392562866, 60.68504646420479, 56.602439135313034, 60.180247351527214, 57.89296008646488, 54.56094928085804, 51.977859288454056, 48.91979478299618, 43.87277640402317, 48.237404599785805, 60.30206121504307, 61.877422481775284, 62.00125403702259, 63.06253708899021, 60.40333338081837, 64.56097528338432, 57.60100655257702, 56.54483802616596, 51.126685962080956, 51.882974579930305, 57.215532436966896, 60.96408449113369, 61.97221599519253, 66.11770614981651, 60.298303216695786, 57.0565527677536, 23.71053960174322, 1.4943923614919186, 0.9831083030439913, 13.150160517543554, 82.44059666991234, 70.68607181310654, 66.60934656858444, 69.10101726651192, 69.07898604869843, 74.44201827049255, 63.50276626646519, 58.530854657292366, 43.96504685282707, 39.60446164011955, 53.51854361593723, 64.60242345929146, 8.570765946060419, 1.1105127353221178, 0.15099800453754142, 0.1875613644369878, 0.1039992096775677, 0.17901627608807757, 0.16026925470214337, 0.24900350341340527], [0.0343217881891178, 0.12299670590437017, 0.03179050429025665, 0.1069262252713088, 0.0503498587931972, 0.06293323240242898, 0.048915201987256296, 0.10459407072630711, 0.03977655876951758, 0.6778791721444577, 0.34891749441158026, 23.37923727929592, 55.92276580631733, 37.808149829506874, 28.185316286981106, 34.559913128614426, 43.37337300181389, 34.6874912828207, 60.81233583390713, 60.39258375763893, 57.296164110302925, 58.990139812231064, 55.24450600147247, 52.96509951353073, 38.07976305484772, 2.135285921394825, 1.5844440856017172, 7.333705751225352, 0.0473420418711612, 1.93504236638546, 43.84688079357147, 59.659975469112396, 62.64153108000755, 55.70650801062584, 58.55860076844692, 54.32031199336052, 57.892629504203796, 58.8658294826746, 62.52170450985432, 57.0150475949049, 58.7324870377779, 56.087543964385986, 53.68321917951107, 49.02753420174122, 43.480534851551056, 41.09884165227413, 44.14872519671917, 42.308966517448425, 42.24057778716087, 47.36347809433937, 51.321566104888916, 55.98053030669689, 55.81716567277908, 56.53113596141338, 56.2919881939888, 55.47414667904377, 55.413927510380745, 50.24132587015629, 46.82434782385826, 49.547144919633865, 44.5817955583334, 46.447206661105156, 54.78801749646664, 53.23685333132744, 51.97297655045986, 49.35702972114086, 52.447187304496765, 50.90156704187393, 49.88885298371315, 49.781710132956505, 40.61271853744984, 37.8260962665081, 38.22122946381569, 40.32646469771862, 40.08942201733589, 39.56497795879841, 45.89175246655941, 51.41268901526928, 51.53461307287216, 51.93700768053532, 53.50598908960819, 53.6214192956686, 52.861574068665504, 56.901380494236946, 43.59018176794052, 41.57426454126835, 39.73632216453552, 42.29986600577831, 50.3545293956995, 47.27900102734566, 41.075708493590355, 42.97596752643585, 40.72448953986168, 41.60049833357334, 41.40507102012634, 43.48649673163891, 53.67225296795368, 55.32183565199375, 54.82617124915123, 50.476472452282906, 43.48054625093937, 44.13781978189945, 40.767309442162514, 38.0949280411005, 36.720028817653656, 39.08452793955803, 38.87373425066471, 40.82712583243847, 40.67966714501381, 47.49386429786682, 49.5678424090147, 51.1769762635231, 50.312085673213005, 49.2466988414526, 51.30012005567551, 50.35408101975918, 51.45642466843128, 50.051932632923126, 43.00048381090164, 46.26934580504894, 46.98126420378685, 46.75160072743893, 51.983878165483475, 54.553836062550545, 53.03721584379673, 56.38188377022743, 54.13246147334576, 50.27843087911606, 55.25717072188854, 55.59480540454388, 54.66416694223881, 53.58245238661766, 52.55737379193306, 47.651221454143524, 44.0429312735796, 40.903775319457054, 48.76027934253216, 59.0259300917387, 55.4765709489584, 58.53183500468731, 55.559106320142746, 57.57451057434082, 57.444052174687386, 59.884190037846565, 51.93228833377361, 50.108777582645416, 47.44486212730408, 58.27273070812225, 56.65033556520939, 63.80351632833481, 50.098734721541405, 32.55146250128746, 4.673278983682394, 0.46834538283292204, 0.2097715437412262, 23.17695513367653, 70.90217381715775, 49.24079015851021, 57.96061925590038, 55.11861115694046, 55.22754371166229, 59.673506543040276, 46.16003327071667, 34.906306341290474, 28.77714402973652, 23.011990785598755, 38.04091773927212, 34.33051943778992, 1.6610165080055594, 0.14916841755621135, 0.05191761607420631, 0.05920091978623532, 0.07173212041379884, 0.04462113181944005, 0.024634773908474017, 0.03926277735445183, 0.007800656712788623, 0.13344735489226878, 0.020805850363103673, 0.09110526953008957, 0.018596840382087976, 0.029053426551399752, 0.02823227539920481, 0.10050284807221033, 0.020602999138645828, 0.4913368506822735, 0.6367465574294329, 31.331583559513092, 67.46928602457047, 41.36774182319641, 35.8226727694273, 49.83419671654701, 48.194314911961555, 38.84939655661583, 66.7532068490982, 65.9599994122982, 64.55987334251404, 64.27824765443802, 61.79040715098381, 56.351599395275116, 47.465441823005676, 3.4709847858175635, 0.9687459643464535, 8.69012039154768, 0.06040785970981233, 5.000338833779097, 49.578580632805824, 62.71899372339249, 64.36541497707367, 56.92999295890331, 62.10091128945351, 58.18743288516998, 60.732790902256966, 60.32835200428963, 64.8692299425602, 59.96934346854687, 61.63966923952103, 58.13606724143028, 57.70670548081398, 51.32582567632198, 46.35050944983959, 43.298558816313744, 45.85184320807457, 44.66400034725666, 45.738046914339066, 48.9910751581192, 52.967136204242706, 57.907608300447464, 58.59854802489281, 58.57786573469639, 58.60455550253391, 59.55594465136528, 57.500296756625175, 52.219799906015396, 50.19704304635525, 50.60290306806564, 44.53455649316311, 49.04898785054684, 58.03219601511955, 55.71664206683636, 54.143967255949974, 53.97924989461899, 56.43606886267662, 53.05157907307148, 51.3597958534956, 54.23926994204521, 41.868125572800636, 41.927748173475266, 41.12988218665123, 42.54655256867409, 40.99427126348019, 42.96286202967167, 47.100490406155586, 54.38321381807327, 52.733813524246216, 52.93092414736748, 56.49222984910011, 54.8795697838068, 56.43921509385109, 58.995577320456505, 44.49564278125763, 41.49602293968201, 39.51561100780964, 43.54458421468735, 53.82949233055115, 48.77373822033405, 41.71686328947544, 42.58653782308102, 39.78842496871948, 41.05629153549671, 40.24536944925785, 42.42564685642719, 54.18484166264534, 57.55589157342911, 55.1049242913723, 53.01706552505493, 46.29929579794407, 46.92183159291744, 44.39385764300823, 41.14555634558201, 40.41226029396057, 41.0342413187027, 40.73518596589565, 42.11654484272003, 44.01082679629326, 48.279114961624146, 55.4964666813612, 54.170071855187416, 52.057248428463936, 49.93258863687515, 53.671356216073036, 51.80086478590965, 53.3970907330513, 53.49322937428951, 45.065084025263786, 48.46547216176987, 48.3599404245615, 46.98558837175369, 52.818723767995834, 55.57987600564957, 55.190852880477905, 58.44123266637325, 55.311754792928696, 50.55396169424057, 56.83928042650223, 57.97164246439934, 56.49471111595631, 54.99322548508644, 53.48594516515732, 48.86285863816738, 45.74514113366604, 44.30247254669666, 48.225287050008774, 59.76015329360962, 57.44410537183285, 60.51837220788002, 57.14549079537392, 61.05952396988869, 60.380477607250214, 62.21402361989021, 53.307354748249054, 52.28151619434357, 48.691031858325005, 62.735963612794876, 59.33853931725025, 68.3782884478569, 50.13279229402542, 41.488594338297844, 3.7379152374342084, 0.9781290858518332, 0.28930837113875896, 26.896868124604225, 75.66707253456116, 56.896870136260986, 63.794054836034775, 60.98773442208767, 62.24317945539951, 66.37029379606247, 52.5360531359911, 43.707192689180374, 37.08703212440014, 22.407656013965607, 45.237400978803635, 45.97051844000816, 2.2411520406603813, 0.4375914658885449, 0.05738648003898561, 0.12970891955774277, 0.04754528643388767, 0.14891439524944872, 0.05046099169703666, 0.09593037975719199, 0.3374196379445493, 0.161894261254929, 0.11246885871514678, 0.23757045128149912, 0.13031797047005966, 0.1901591633213684, 0.16028059471864253, 0.1816172810504213, 0.11752619437174872, 0.7722499582450837, 0.9038496622815728, 40.71637697517872, 77.09527149796486, 52.72397205233574, 35.838198736310005, 54.82448793947697, 53.80728632211685, 44.0473922342062, 74.11308512091637, 73.43462392687798, 69.12617951631546, 71.16558328270912, 64.65703412890434, 64.84806507825851, 51.08303390443325, 5.216847416013479, 4.3027352169156075, 15.522514767944813, 0.2300069126067683, 7.768091792240739, 56.82992912828922, 61.73016518354416, 68.06730553507805, 58.15803386271, 65.3537267446518, 59.182113111019135, 64.79501232504845, 64.49572518467903, 69.04079049825668, 61.23440198600292, 65.04122391343117, 62.122133150696754, 59.240295588970184, 55.137788727879524, 49.81409199535847, 45.4972880333662, 48.58987748622894, 46.92982256412506, 48.316166773438454, 52.479249984025955, 56.05838432908058, 60.03877714276314, 60.54926835000515, 61.10274285078049, 61.68505780398846, 62.00655475258827, 61.66747234761715, 54.33672331273556, 52.02624589204788, 53.17878104746342, 48.47139984369278, 50.3199702501297, 59.80849049985409, 59.52854052186012, 57.14788466691971, 56.63862459361553, 60.57518295943737, 58.63892465829849, 53.9218919724226, 58.51771876215935, 44.859328866004944, 42.71198809146881, 42.627001851797104, 45.46551413834095, 44.442643225193024, 46.30341857671738, 51.093962118029594, 59.19333390891552, 56.82707168161869, 55.02168595790863, 57.997948452830315, 56.96117788553238, 56.70341491699219, 60.7243287563324, 46.92587457597256, 41.801271960139275, 37.72320918738842, 46.15188270807266, 58.528958559036255, 49.62041638791561, 41.89531311392784, 43.67609515786171, 39.311561957001686, 42.12018124759197, 42.424104139208794, 43.20202499628067, 58.612721264362335, 60.55743031203747, 59.046084210276604, 54.885052889585495, 49.864709079265594, 51.349255219101906, 47.38274686038494, 44.010009840130806, 42.82874062657356, 44.522488340735435, 43.957538455724716, 44.10832956433296, 45.8258032053709, 53.36025930941105, 57.29587532579899, 57.24085047841072, 54.577254205942154, 53.01672734320164, 56.90093971788883, 56.52549706399441, 55.89688919484615, 55.612109676003456, 46.54408246278763, 50.34844972193241, 50.88955968618393, 50.02529226243496, 56.35832883417606, 58.531960397958755, 56.919250935316086, 60.71439988911152, 54.751322865486145, 53.995551019907, 57.04865679144859, 60.06082735955715, 59.58519168198109, 57.63385958969593, 54.49577897787094, 51.06107108294964, 46.49641402065754, 45.51238842308521, 50.839022397994995, 63.26461024582386, 58.63303877413273, 64.08671513199806, 58.00807870924473, 63.95594134926796, 61.787606701254845, 65.83204507827759, 54.77502599358559, 54.33416984975338, 50.73075860738754, 66.95310652256012, 59.46242406964302, 72.68039479851723, 56.435738280415535, 59.941164180636406, 6.68846569955349, 0.8195719064678997, 0.6888288189657032, 28.914689049124718, 82.71115735173225, 59.91433762013912, 70.68480268120766, 66.112812012434, 67.45519638061523, 73.52749094367027, 58.767631351947784, 50.39160020649433, 43.76910276710987, 32.63001188635826, 54.23744983971119, 61.29957988858223, 3.836954548023641, 0.653990269638598, 0.27194900263566524, 0.3692105726804584, 0.1354202802758664, 0.27966531983111054, 0.10764728853246197, 0.17360664292937145], [0.035972491605207324, 0.06466254781116731, 0.01816009018511977, 0.07030782027868554, 0.062072964501567185, 0.03238981080357917, 0.05970961006823927, 0.1714929024456069, 0.009884992377919843, 0.656206738203764, 0.022593060712097213, 12.08733094856143, 61.111007407307625, 39.648060500621796, 25.588887110352516, 27.228445932269096, 51.35797195136547, 40.48041723668575, 63.959855139255524, 60.31148470938206, 60.38186453282833, 56.377890184521675, 56.0948433727026, 52.29782111942768, 58.85575242340565, 8.912116829305887, 0.2812336856732145, 6.742966175079346, 0.03605109246564098, 12.461019046604633, 43.2895153015852, 55.61867572367191, 60.79059340059757, 58.35644781589508, 59.7411847114563, 58.46326768398285, 63.29553298652172, 61.3564932346344, 57.446161061525345, 55.62877178192139, 57.42859460413456, 58.953266590833664, 55.820889472961426, 50.702161341905594, 45.43420381844044, 42.83594124019146, 41.909911930561066, 40.54096318781376, 49.24093835055828, 52.21759222447872, 55.2327798306942, 56.518505439162254, 55.53317651152611, 52.29366414248943, 56.745140478014946, 58.16573604941368, 54.255445674061775, 52.49914951622486, 46.17144025862217, 46.41269311308861, 43.65343317389488, 43.89658972620964, 51.43416166305542, 52.28417985141277, 51.95085793733597, 51.556705087423325, 53.50515693426132, 50.031702518463135, 51.12115725874901, 47.739521116018295, 38.90231251716614, 39.63058903813362, 37.96015687286854, 40.21888867020607, 39.984619840979576, 43.47428038716316, 48.11525635421276, 53.114492297172546, 53.74129146337509, 53.53625446557999, 52.04501688480377, 54.01165835559368, 54.50881987810135, 57.331544011831284, 47.63365499675274, 41.18913620710373, 39.97235029935837, 43.32438983023167, 49.347051456570625, 42.65052258968353, 39.992850199341774, 41.95388317108154, 41.34952560067177, 44.619850516319275, 40.68616099655628, 43.23751129209995, 54.33053344488144, 55.59115760028362, 52.39132650196552, 51.214856430888176, 50.586962923407555, 44.49740968644619, 43.58499884605408, 41.125949397683144, 37.90930800139904, 39.787782803177834, 39.95644815266132, 37.729687839746475, 41.17684006690979, 46.20973080396652, 48.0176167935133, 51.24997414648533, 48.43507379293442, 51.179567724466324, 50.51787123084068, 49.08822454512119, 52.81407281756401, 47.31194905936718, 43.52187283337116, 46.18207208812237, 44.51485835015774, 51.292341873049736, 54.11992974579334, 54.0980277210474, 52.646885588765144, 55.95851428806782, 43.624718114733696, 34.38729979097843, 45.612934827804565, 53.01939859986305, 58.736324831843376, 56.70071326196194, 56.12951651215553, 51.51553049683571, 47.14259214699268, 40.80903880298138, 44.16036777198315, 52.24302425980568, 58.00180144608021, 56.87051475048065, 55.63835486769676, 58.05911757051945, 60.30206121504307, 58.5299389064312, 59.721380174160004, 53.65636222064495, 52.02580891549587, 55.02027243375778, 60.0502373278141, 57.51059800386429, 45.54711475968361, 9.923746045678854, 0.9671376412734389, 0.8762427780311555, 1.1578543949872255, 38.29030975699425, 47.560436725616455, 40.90030610561371, 61.76563248038292, 55.99154591560364, 60.691604912281036, 53.218500316143036, 51.67758800089359, 39.63569216430187, 28.125990070402622, 29.741368889808655, 39.81798738241196, 26.875397376716137, 0.779047793475911, 0.12974212324479595, 0.11327955115120858, 0.02756615518592298, 0.07848164925235324, 0.09558839068631642, 0.08913756886613555, 0.09144167022895999, 0.06256730164750479, 0.025379628568771295, 0.07708569915848784, 0.017265123169636354, 0.011852621610159986, 0.04060084364027716, 0.031222687102854252, 0.11180016881553456, 0.04338931881648023, 0.642700184835121, 0.10095739125972614, 15.425443276762962, 71.54281184077263, 43.914904743433, 26.390324905514717, 46.73054225742817, 53.450466468930244, 43.38490158319473, 67.19196930527687, 65.72267174720764, 66.32576018571854, 62.62617610394955, 61.463062316179276, 57.75085151195526, 62.327173948287964, 11.535868439823389, 0.6193801830522716, 7.025800673291087, 0.07512531607062556, 19.89938970655203, 49.18189711868763, 54.11405146121979, 63.29004608094692, 61.783301532268524, 63.11888046562672, 62.03492783010006, 66.00703328847885, 61.35005638003349, 60.437151566147804, 58.88125665485859, 58.82246620953083, 59.89419490098953, 60.11850446462631, 54.28142108023167, 47.26738125085831, 44.379616007208824, 44.92524012923241, 45.08952051401138, 50.270599499344826, 55.7922276109457, 57.173214107751846, 58.366236090660095, 55.91755248606205, 55.211193189024925, 58.52132476866245, 59.145969450473785, 56.97327263653278, 54.413631185889244, 48.60415332019329, 47.80767045915127, 45.881603211164474, 45.24077519774437, 54.70156833529472, 54.91903826594353, 55.3265929967165, 55.641417503356934, 56.60416804254055, 53.22176814079285, 53.7379514425993, 49.7390042245388, 40.65835028886795, 41.27501919865608, 39.31780122220516, 41.084455624222755, 43.906617388129234, 46.09123796224594, 51.81469604372978, 57.023988515138626, 55.31819544732571, 55.99337361752987, 56.22488759458065, 55.581597313284874, 56.88832439482212, 59.04044911265373, 47.96676032245159, 41.02209337055683, 40.46970561146736, 43.611133843660355, 52.995691671967506, 45.35192683339119, 41.456961035728455, 40.31503491103649, 40.74533902108669, 45.09337730705738, 40.71137644350529, 44.17390264570713, 57.44434095919132, 56.26032069325447, 55.856003388762474, 52.674711495637894, 52.95094907283783, 47.033575996756554, 47.492743358016014, 43.27555865049362, 41.20140194892883, 43.63122336566448, 41.76087252795696, 41.217558681964874, 44.24303613603115, 47.77187258005142, 52.00401708483696, 53.73153738677502, 50.09346820414066, 53.501471132040024, 52.67759554088116, 52.73547023534775, 55.02608612179756, 51.39767222106457, 43.601641952991486, 48.26777637004852, 46.06079779565334, 53.14241319894791, 57.96944618225098, 55.01942127943039, 55.35078629851341, 56.769519969820976, 45.99028877913952, 38.920969516038895, 46.31370082497597, 53.3493272960186, 59.82598476111889, 58.92566107213497, 60.31542509794235, 54.10219229757786, 48.616050481796265, 43.30938443541527, 45.69424666464329, 53.79099279642105, 59.12811420857906, 59.174832701683044, 57.11275555193424, 59.21528913080692, 62.11517572402954, 60.233904272317886, 61.38541728258133, 56.22590593993664, 54.86502416431904, 56.67332053184509, 63.27071271836758, 59.79617916047573, 51.07426017522812, 13.723979126662016, 0.8900645957328379, 1.017313830088824, 1.8592765694484115, 47.17877000570297, 59.053562209010124, 49.118394926190376, 65.42442575097084, 63.91733542084694, 65.29637262225151, 61.834537982940674, 56.7175767570734, 49.07043009996414, 36.0583171248436, 27.82654143869877, 49.28305149078369, 36.75732001662254, 0.9098324412479997, 0.04318179206165951, 0.10283876530593261, 0.04088630332262255, 0.03538957913406193, 0.09898193515255116, 0.05498679376614746, 0.11454271618276834, 0.11876708013005555, 0.10974593373248354, 0.26225340727251023, 0.2269014104967937, 0.10440972866490483, 0.1491427095606923, 0.1398274500388652, 0.26339450385421515, 0.07774124562274665, 0.8906956587452441, 0.45784960384480655, 20.441584512591362, 81.95576548576355, 58.58746401965618, 32.72854819893837, 42.327076345682144, 64.36623573303223, 49.108720645308495, 76.19940117001534, 70.62867969274521, 71.25553965568542, 67.8304186463356, 67.40050211548805, 64.79148611426353, 70.12913569808006, 15.354821216315031, 1.4225638657808304, 17.57912401109934, 0.2204266469925642, 25.203741677105427, 53.523072972893715, 53.38979132473469, 67.66264244914055, 63.63679267466068, 66.43162250518799, 64.2111736536026, 67.52585738897324, 64.52938377857208, 62.54097707569599, 58.569494783878326, 60.7102657109499, 62.55019158124924, 61.88222922384739, 56.68050594627857, 48.39773699641228, 47.322911471128464, 47.649617940187454, 46.98342248797417, 54.1205795109272, 57.43773311376572, 60.22187031805515, 61.2787152081728, 59.54813987016678, 54.931144416332245, 60.69040037691593, 62.42707438766956, 58.489254489541054, 57.849847599864006, 51.086586713790894, 51.820357739925385, 47.98548951745033, 49.18073818087578, 57.56331257522106, 57.35583230853081, 59.584796503186226, 57.54347003996372, 61.423460841178894, 56.06984071433544, 57.67091140151024, 52.24730283021927, 43.991820216178894, 44.420562610030174, 42.6403733342886, 44.35915410518646, 45.713443234562874, 49.63938497006893, 56.08262702822685, 60.31416356563568, 58.99251468479633, 58.10850732028484, 58.231350928545, 57.769238725304604, 58.115179762244225, 62.95457348227501, 50.44195890426636, 40.911348313093185, 40.20658113062382, 45.014687329530716, 57.65815548598766, 47.61793524026871, 40.40016174316406, 41.20039880275726, 41.18315152823925, 45.42600005865097, 40.57774141430855, 45.01136630773544, 59.26974780857563, 61.09622620046139, 57.563658356666565, 55.908166989684105, 59.11754697561264, 52.022689282894135, 49.91137817502022, 48.67736019194126, 43.50107654929161, 46.71544946730137, 45.259603187441826, 43.97602826356888, 47.22836494445801, 51.77922874689102, 52.97271050512791, 56.592354476451874, 52.524467557668686, 57.584659829735756, 55.34516640007496, 56.73952057957649, 57.20930457115173, 51.977600902318954, 47.92804419994354, 50.81252261996269, 46.397425532341, 54.538709074258804, 58.95301580429077, 57.293489053845406, 56.251733154058456, 59.238684475421906, 46.92938558757305, 37.51351363956928, 49.885554760694504, 55.78238993883133, 60.53631864488125, 61.43697291612625, 61.010882779955864, 56.86259597539902, 49.96036134660244, 45.87507516145706, 47.8990213572979, 56.56962409615517, 60.990603268146515, 62.0058061927557, 57.177036702632904, 61.34555742144585, 64.95827436447144, 63.79255771636963, 62.8250802308321, 58.02694849669933, 56.477885618805885, 58.98500248789787, 65.07694959640503, 63.836878538131714, 55.299166068434715, 22.18605760484934, 0.6980177946388721, 4.182167686522007, 2.4584725918248296, 46.572284549474716, 61.731920689344406, 55.37620313465595, 70.52154824137688, 69.19468984007835, 70.25325983762741, 66.58475428819656, 63.38096760213375, 55.20512491464615, 41.29276804625988, 41.201994717121124, 61.86747841536999, 51.73790976405144, 0.864789776969701, 0.1994398536044173, 0.308586458559148, 0.13527008442906663, 0.21837067528394982, 0.17723316239425912, 0.19252980564488098, 0.45676494017243385], [0.13490187528077513, 0.06763392157154158, 0.03892080312652979, 0.15046774002257735, 0.14367149298777804, 0.015423720269609476, 0.03546744897903409, 0.09781097454833798, 0.04692750044341665, 0.27862414601258934, 0.12382187022012658, 3.965075835585594, 55.81181935966015, 48.18925738334656, 32.86782592535019, 25.929850414395332, 45.583049431443214, 36.807716712355614, 55.650252029299736, 61.977676302194595, 56.97640746831894, 59.121650755405426, 62.32194922864437, 48.26944828033447, 58.917423114180565, 15.57746171951294, 0.43003200902603567, 4.336494505405426, 0.15226511779474095, 33.99806767702103, 46.2202562391758, 48.8173408806324, 51.97529062628746, 58.58795419335365, 57.636641040444374, 62.469711899757385, 58.21349188685417, 56.56617768108845, 58.05937975645065, 57.75638401508331, 59.159390330314636, 57.8310652077198, 56.717234775424004, 51.973390728235245, 46.689550057053566, 42.19425067305565, 39.64895345270634, 41.5529590845108, 48.65614593029022, 56.7777731269598, 56.94472476840019, 53.612409979104996, 51.24723069369793, 46.941043362021446, 53.296996504068375, 58.77767041325569, 55.77461935579777, 56.56328983604908, 52.61046454310417, 47.82644525170326, 48.39165352284908, 41.44781492650509, 47.350619584321976, 54.27316792309284, 52.6090320199728, 51.20512135326862, 50.800956040620804, 50.94992324709892, 49.62165132164955, 41.70192249119282, 39.676703363657, 38.75483863055706, 37.775015607476234, 41.1721321195364, 44.55765165388584, 46.65426515042782, 52.259811758995056, 50.050465911626816, 52.03977316617966, 53.86111043393612, 53.01205359399319, 52.66472563147545, 54.10282306373119, 55.93346983194351, 47.13465057313442, 39.01129826903343, 44.99012164771557, 40.61831943690777, 50.307301729917526, 45.03000810742378, 40.57483457028866, 40.563256591558456, 42.84984089434147, 41.156659349799156, 42.28409685194492, 44.9297770857811, 53.98405663669109, 55.81598773598671, 56.505703926086426, 51.3641694188118, 52.17697620391846, 50.014466643333435, 44.735151529312134, 45.02517856657505, 41.72459967434406, 39.16458584368229, 39.593024253845215, 37.32480816543102, 37.95116275548935, 42.54307955503464, 49.41735528409481, 48.234756141901016, 48.86782497167587, 50.001399144530296, 50.74631117284298, 48.94663654267788, 51.21405087411404, 42.95533083379269, 45.67609503865242, 46.17922984063625, 50.34193307161331, 55.30245289206505, 57.04421103000641, 57.299732118844986, 54.20431561768055, 44.611832946538925, 43.60254630446434, 54.482532888650894, 47.10042580962181, 41.593734696507454, 45.53708329796791, 51.856459602713585, 54.737301617860794, 56.665048375725746, 49.14025895297527, 43.37387077510357, 41.00839510560036, 47.45615132153034, 55.05851738154888, 57.103411853313446, 58.4293507039547, 50.61363369226456, 58.07217746973038, 62.9057727009058, 62.10894785821438, 59.88950975239277, 58.113268464803696, 55.20162150263786, 62.521180137991905, 57.87341773509979, 52.74976126849651, 1.8481274927034974, 0.04423290694830939, 0.4473203094676137, 3.225789167918265, 61.25818111002445, 41.71809822320938, 49.93036575615406, 56.470612809062004, 55.1584330201149, 56.838858649134636, 58.9852836728096, 54.067477360367775, 35.46374402940273, 33.13069961965084, 34.89767700433731, 40.99123142659664, 16.933888234198093, 0.7742432481609285, 0.026229237373627257, 0.11927447165362537, 0.11222715605981648, 0.044597735613933764, 0.03722643916262314, 0.06704245213768445, 0.0390586607682053, 0.1251347517245449, 0.0754856807179749, 0.02638065219798591, 0.03145253394905012, 0.05479273328091949, 0.05822781204187777, 0.11190648889169097, 0.05227185429248493, 0.011973067539656768, 0.3519832174060866, 0.015563897122774506, 5.9161438420414925, 63.49515527486801, 58.106200844049454, 30.75961545109749, 34.15057249367237, 55.62018044292927, 38.13918426632881, 64.81862425804138, 65.72103783488274, 64.52449724078178, 63.822849690914154, 68.97474244236946, 54.50072631239891, 66.373660415411, 18.067821487784386, 0.20532961178105325, 5.204302864149213, 0.1878766732988879, 40.26217594742775, 50.28174810111523, 50.17201378941536, 53.180528953671455, 59.94959972798824, 60.49213081598282, 63.64234037697315, 60.063206031918526, 58.19492608308792, 60.05436010658741, 59.31854858994484, 60.11807128787041, 61.2563382089138, 61.24236635863781, 55.36577269434929, 47.26232372224331, 45.43437860906124, 42.00554899871349, 45.36304123699665, 51.9766965508461, 56.84966526925564, 59.211474135518074, 56.19901478290558, 53.15422676503658, 48.21153558790684, 54.93774086236954, 60.61461344361305, 58.052813708782196, 59.592445492744446, 54.97605420649052, 48.24544496834278, 50.358948558568954, 44.0625686198473, 50.88175870478153, 56.317769810557365, 55.593483075499535, 54.23434540629387, 53.55015031993389, 53.23900021612644, 53.917712196707726, 45.668510645627975, 40.26536397635937, 39.72527615725994, 40.95354124903679, 42.69778065383434, 46.32909379899502, 49.40804198384285, 56.13348729908466, 52.934917733073235, 54.673795625567436, 55.237571373581886, 54.807875230908394, 56.20854087173939, 56.03840880095959, 59.13451686501503, 47.000270783901215, 37.70791880786419, 42.52593107521534, 41.657183691859245, 52.48019993305206, 46.360871493816376, 40.41146233677864, 38.88399749994278, 41.38743996620178, 41.779723316431046, 42.40637049078941, 44.860548600554466, 56.61210581660271, 56.48371450603008, 58.44337955117226, 54.8950881510973, 55.210216641426086, 51.440967097878456, 48.6851953715086, 47.93787807226181, 44.383225813508034, 38.7014514952898, 42.9603161662817, 41.41614742577076, 40.89547276496887, 45.07279001176357, 51.28303997218609, 50.4940465092659, 52.76154823601246, 50.00653266906738, 53.30930784344673, 51.659367978572845, 53.94192449748516, 45.15718728303909, 47.655424028635025, 47.170334458351135, 52.038975208997726, 56.757710203528404, 58.72376650571823, 56.324176266789436, 54.9843605607748, 45.126241743564606, 41.29966847598553, 54.8766515403986, 49.30779196321964, 42.41438426077366, 46.39002352952957, 53.41616190969944, 55.443478524684906, 57.067404985427856, 51.036038026213646, 43.4866639226675, 41.78949639201164, 48.974656239151955, 56.61221981048584, 57.44812175631523, 61.15315854549408, 53.48203897476196, 57.21131466329098, 62.61004216969013, 65.42526170611382, 61.067024767398834, 59.71516750752926, 58.10480251908302, 64.77663651108742, 58.8530545681715, 54.70175452530384, 3.031181897968054, 0.35985651367809623, 1.5564812673255801, 5.318374168127775, 61.85272000730038, 47.22688302397728, 54.452776685357094, 62.670515924692154, 61.3225344568491, 63.15240986645222, 65.97956076264381, 58.360866978764534, 44.53538104891777, 37.72316358983517, 38.35867188870907, 51.430453062057495, 23.228197284042835, 0.5068336660042405, 0.06412878778064623, 0.18586407270049676, 0.08945796886109747, 0.046876555716153234, 0.022222981351660565, 0.07075975852785632, 0.007490130064979894, 0.20123996248003095, 0.21055026445537806, 0.1783297152724117, 0.19009189505595714, 0.21020038635469973, 0.2101378233055584, 0.16486861102748662, 0.2442002939642407, 0.17529026430565864, 0.42254106723703444, 0.20699920656625181, 7.221059845760465, 77.17734709382057, 68.78485903143883, 42.689584493637085, 38.238727524876595, 61.978379264473915, 43.28523673117161, 70.71647018194199, 72.27191671729088, 71.84863463044167, 66.97560131549835, 73.81930008530617, 59.49589267373085, 73.05126249790192, 20.97388844937086, 0.586607001023367, 15.556687284260988, 0.3777491598157212, 50.374007150530815, 52.13489346206188, 50.95148116350174, 54.91122208535671, 61.839565113186836, 61.24770127236843, 65.37315890192986, 63.013884499669075, 60.326026529073715, 61.247815266251564, 61.53085067868233, 62.472421154379845, 63.03428180515766, 62.81459279358387, 58.375256806612015, 51.03576444089413, 47.17717029154301, 44.885311871767044, 49.006384536623955, 53.74771311879158, 60.11810548603535, 62.730792090296745, 57.6696764677763, 56.13055385649204, 50.239102989435196, 55.88866263628006, 63.17144684493542, 60.8099115639925, 60.976103246212006, 59.284217432141304, 52.29774512350559, 51.88672877848148, 45.526367872953415, 51.67808957397938, 59.78041000664234, 59.94946673512459, 57.47229985892773, 55.852549374103546, 56.75137214362621, 56.24872751533985, 49.96859930455685, 43.7260814756155, 43.22670467197895, 43.02679359912872, 45.69838844239712, 50.22900693118572, 53.1151382625103, 58.623516485095024, 56.910032629966736, 55.937254428863525, 56.331137493252754, 57.771332412958145, 59.11889970302582, 57.70177334547043, 60.14015190303326, 51.08445502817631, 37.890480011701584, 43.949923664331436, 42.396012246608734, 57.70692206919193, 47.38917991518974, 40.6077978014946, 39.93999883532524, 43.011556416749954, 42.46696583926678, 42.11246766149998, 46.14683277904987, 59.23368774354458, 59.90579567849636, 62.971410378813744, 57.7617759257555, 59.682827442884445, 55.51282100379467, 51.73833154141903, 51.54567427933216, 47.3629005253315, 43.37473712861538, 45.57113707065582, 42.531645968556404, 43.136839494109154, 47.221931889653206, 55.653227269649506, 52.19597898423672, 54.60077114403248, 54.65120583772659, 54.641208574175835, 52.741530910134315, 56.35646693408489, 46.73224076628685, 50.54272569715977, 49.7871058434248, 53.62188667058945, 58.002922385931015, 61.96367785334587, 58.476889953017235, 60.12322761118412, 45.64250484108925, 43.844661712646484, 52.513079568743706, 47.548250779509544, 44.159809201955795, 47.719944566488266, 52.99087733030319, 58.93685147166252, 58.407251089811325, 55.03920681774616, 45.98569102585316, 43.589292615652084, 52.39315800368786, 59.397394359111786, 59.25622433423996, 63.22547234594822, 54.26316685974598, 59.73315194249153, 64.57641765475273, 67.25740179419518, 63.95961955189705, 62.75768704712391, 59.136614352464676, 70.27804970741272, 60.01003548502922, 62.81434580683708, 4.2342310678213835, 0.33847417042125016, 4.3903556652367115, 4.8580236453562975, 73.48711431026459, 51.23882554471493, 62.61294901371002, 68.2505165040493, 67.10379883646965, 68.48851293325424, 71.82278081774712, 67.5250594317913, 51.524403020739555, 44.43883962929249, 47.20285311341286, 62.8567249327898, 32.62691505253315, 0.984294373774901, 0.11697498644934967, 0.32642688718624413, 0.19193492975318804, 0.1689130486920476, 0.13192651618737727, 0.11388818646082655, 0.2570128353545442], [0.04854997627262492, 0.01612617139471695, 0.0467328388185706, 0.13654457463417202, 0.06418270480935462, 0.030452859173237812, 0.0797537794278469, 0.03484109489363618, 0.08224418212193996, 0.041900199503288604, 0.31429502880200744, 0.4746546474052593, 37.297362238168716, 52.55923189222813, 39.43121373653412, 39.86854746937752, 43.03695045411587, 40.71384631097317, 45.6809663772583, 68.99361982941628, 57.50586345791817, 49.738096073269844, 51.842506751418114, 51.55318267643452, 55.97931057214737, 27.114085368812084, 0.09171613870421425, 4.044445501640439, 0.3838768060086295, 15.816086065024137, 41.406229957938194, 46.56536512076855, 53.72042678296566, 51.74753464758396, 57.66562968492508, 55.240725204348564, 58.142124116420746, 62.570136711001396, 58.80406379699707, 60.007877200841904, 58.568860217928886, 55.998814925551414, 52.56601832807064, 49.69352066516876, 42.79170401394367, 42.22702391445637, 44.13182370364666, 43.827786818146706, 47.982164695858955, 52.119580283761024, 57.24487826228142, 56.55472509562969, 51.04364901781082, 49.571368619799614, 46.696872264146805, 51.91004432737827, 56.15351602435112, 56.95100963115692, 51.3936710357666, 47.99305111169815, 45.96546471118927, 43.778898641467094, 43.39890383183956, 52.0206031948328, 52.11289644241333, 49.61871027946472, 53.3022516220808, 51.321668699383736, 46.18490293622017, 38.844874799251556, 38.255370631814, 40.83350948989391, 39.9857559800148, 43.87175425887108, 48.370036482810974, 48.06213900446892, 53.84527288377285, 50.84868527948856, 55.7005575299263, 52.368371933698654, 55.28275854885578, 53.933040574193, 53.62019196152687, 53.52059930562973, 46.69659487903118, 41.362273916602135, 42.58915588259697, 40.78611083328724, 44.76494573056698, 45.96923030912876, 39.21703822910786, 43.577289059758186, 42.8545830398798, 42.762320190668106, 40.45242413878441, 50.30668616294861, 53.965544030070305, 52.26240321993828, 55.229724794626236, 52.7814781665802, 52.20507949590683, 49.27916429936886, 51.30232393741608, 49.16137062013149, 45.57374753057957, 40.804699435830116, 39.073272943496704, 37.942609414458275, 41.88816949725151, 39.77954864501953, 46.71018674969673, 51.24611355364323, 51.4939134567976, 48.35641801357269, 51.34270817041397, 51.81569159030914, 50.291787162423134, 42.787068262696266, 45.05698285996914, 45.69416306912899, 54.10535752773285, 53.50824996829033, 54.81883764266968, 47.56636820733547, 47.63329781591892, 54.64621290564537, 53.139411360025406, 54.79787416756153, 59.410256668925285, 54.26190912723541, 43.45807045698166, 44.02576379477978, 53.650886714458466, 54.91448991000652, 50.100304037332535, 45.41148483753204, 42.11926929652691, 42.29030951857567, 48.86399857699871, 56.19529478251934, 58.857276141643524, 57.594075724482536, 53.19314427673817, 45.34967355430126, 65.59917077422142, 59.60142821073532, 61.162236258387566, 57.90708392858505, 60.99358230829239, 57.009606286883354, 29.27392367273569, 0.33641886664554477, 0.5918417545035481, 0.6153609487228096, 21.96848127990961, 69.07957881689072, 60.98645009100437, 59.9198055267334, 53.00975851714611, 58.806237280368805, 60.094143971800804, 58.8479932397604, 49.95761789381504, 28.14108856022358, 38.712558299303055, 36.856228709220886, 38.171284943819046, 7.552522709593177, 0.8391631802078336, 0.12948419724125415, 0.2264532572007738, 0.043464758127811365, 0.0720979027391877, 0.07124333453248255, 0.07142183589166962, 0.04225115742883645, 0.06496988600702025, 0.003751833883143263, 0.06915735779330134, 0.10124708860530518, 0.08557114852010272, 0.054000279124011286, 0.05460321102873422, 0.026611506509652827, 0.03726876755536068, 0.12050515288137831, 0.3075069305486977, 0.5817493773065507, 43.49707916378975, 59.74282242357731, 33.524810671806335, 42.64281280338764, 57.036463245749474, 40.839513167738914, 53.743848726153374, 72.8108797967434, 64.87940579652786, 54.90573137998581, 60.290661826729774, 55.2694820612669, 61.21530041098595, 28.809170611202717, 0.19788836420048028, 5.399374896660447, 0.6599628960248083, 18.497586026787758, 47.94664800167084, 46.80146165192127, 55.43037302792072, 52.36448474228382, 59.20324757695198, 57.23826661705971, 60.71349933743477, 64.46472644805908, 61.11856900155544, 61.58005803823471, 59.66841101646423, 60.63010521233082, 52.751144394278526, 50.16280688345432, 44.8761011660099, 45.03904402256012, 45.5580847710371, 45.931863114237785, 52.096367329359055, 53.73740807175636, 58.23322422802448, 58.752796947956085, 54.38053496181965, 52.10642918944359, 46.82788543403149, 53.87760154902935, 57.415074929594994, 59.137849286198616, 54.93100002408028, 48.90263110399246, 49.65919330716133, 46.68771095573902, 43.65386255085468, 53.53294484317303, 55.48393115401268, 53.37958887219429, 54.125196263194084, 54.48184132575989, 49.870256781578064, 40.89791223406792, 41.28498986363411, 42.79352031648159, 41.346272975206375, 47.18378573656082, 49.044397696852684, 51.28941982984543, 56.05718359351158, 53.218678906559944, 56.86486065387726, 54.832589104771614, 56.571166813373566, 55.346397534012794, 56.090800389647484, 55.469442531466484, 46.799432560801506, 41.28574602305889, 42.31322608888149, 40.51572874188423, 48.54255862534046, 45.640589743852615, 40.299311354756355, 42.059240117669106, 41.76888629794121, 42.607417702674866, 41.10735699534416, 51.42623148858547, 58.892435654997826, 54.449820443987846, 56.55999921262264, 55.963340029120445, 54.07457917928696, 52.890885695815086, 52.8034295886755, 52.288477420806885, 47.484949976205826, 42.326612770557404, 41.64024040102959, 39.79844503104687, 42.96320781111717, 42.8359754383564, 49.23317916691303, 55.362459272146225, 53.46786193549633, 51.57274402678013, 51.53942361474037, 54.90903340280056, 51.16447493433952, 44.52681630849838, 46.78623966872692, 47.787884920835495, 55.21555155515671, 56.18072636425495, 56.6228174418211, 50.27051970362663, 47.33784846961498, 54.58044983446598, 54.01074260473251, 54.838702976703644, 58.88814568519592, 54.68426026403904, 45.457895547151566, 45.804015174508095, 55.075327679514885, 55.987290143966675, 50.7284939289093, 47.84985199570656, 44.148086830973625, 43.530604764819145, 51.06224901974201, 59.267513528466225, 60.197768211364746, 60.287454798817635, 55.57000033557415, 45.594969391822815, 68.1469264626503, 62.03044407069683, 62.49775819480419, 59.37496416270733, 63.39358292520046, 57.76610389351845, 32.02968209981918, 0.31752369774039835, 0.23500823095673695, 0.7943048654124141, 26.718935072422028, 72.54221141338348, 61.712876111269, 64.95317503809929, 59.96950685977936, 65.50433546304703, 65.61026617884636, 65.03170922398567, 56.961037293076515, 38.2440510392189, 43.12719941139221, 41.29151031374931, 48.7080929428339, 10.424306485801935, 0.8886809356044978, 0.16861170704942197, 0.21870360273169354, 0.06657780832028948, 0.19679506192915142, 0.09413343243068084, 0.07763050976791419, 0.042394273186801, 0.23668315436225384, 0.0829727336531505, 0.23591961798956618, 0.31696269346866757, 0.20223902683937922, 0.16310856328345835, 0.13202255009673536, 0.18028074729954824, 0.16400424647144973, 0.2218895684927702, 0.4288323124637827, 0.8443167724180967, 51.84596836566925, 72.24219471216202, 52.300192192196846, 49.9397436529398, 64.25363257527351, 46.995099261403084, 58.30426521599293, 81.10372200608253, 72.79157683253288, 64.10430058836937, 68.53062227368355, 60.94654083251953, 68.0098070204258, 33.79548154771328, 0.24120816233335063, 12.32669910416007, 0.6985193083528429, 23.452311158180237, 54.94709976017475, 44.975876212120056, 58.01135413348675, 55.20670562982559, 62.649499252438545, 60.21864429116249, 65.33237189054489, 67.94234544038773, 64.10204350948334, 64.97909724712372, 63.439891040325165, 63.897720873355865, 57.130379006266594, 52.73289777338505, 48.57290379703045, 47.54079557955265, 49.47310969233513, 49.43971328437328, 54.42574493587017, 56.058566719293594, 62.45580464601517, 59.66079622507095, 55.50712890923023, 52.764983251690865, 46.88494697213173, 54.4893953204155, 60.38651928305626, 60.68249300122261, 55.0534750521183, 50.54420381784439, 52.17565767467022, 48.48980225622654, 46.21650584042072, 55.859229415655136, 58.919695392251015, 55.81448681652546, 58.039556220173836, 58.30834999680519, 53.1129951775074, 44.07302565872669, 43.065030947327614, 47.004841938614845, 43.960684686899185, 52.34363526105881, 54.429932311177254, 54.68494042754173, 60.29344707727432, 56.67820706963539, 62.33640365302563, 55.352598801255226, 58.43460202217102, 59.24669824540615, 59.160469472408295, 58.49610172212124, 47.46785469353199, 43.09408038854599, 41.86876393854618, 42.241109758615494, 52.75344707071781, 46.68328799307346, 39.55523908138275, 42.94127158820629, 43.09981808066368, 43.391832411289215, 40.624087527394295, 53.706272542476654, 62.95347534120083, 56.83103106915951, 60.017730072140694, 57.23563335835934, 58.692042008042336, 55.171242132782936, 56.0026603192091, 54.8784526437521, 52.84802779555321, 44.898371770977974, 44.28297199308872, 41.99740223586559, 46.45535722374916, 47.235238775610924, 51.29183650016785, 57.76757441461086, 55.80687202513218, 52.71881952881813, 55.075525268912315, 59.131306037306786, 54.71483342349529, 45.01894690096378, 48.70925948023796, 48.899348080158234, 56.237616911530495, 58.459046110510826, 58.51572006940842, 51.853157579898834, 47.40004353225231, 55.63244618475437, 55.41786789894104, 57.2579799592495, 60.04283532500267, 56.80931143462658, 48.21223855018616, 46.48108944296837, 56.80021092295647, 57.09596425294876, 55.00680975615978, 48.49880017340183, 47.23134018480778, 45.601546838879585, 53.75734940171242, 60.817469358444214, 62.415815591812134, 62.67814211547375, 58.50057028234005, 47.97147586941719, 69.2631621658802, 64.48087558150291, 65.6644132733345, 60.43623201549053, 66.42480567097664, 59.36385735869408, 38.39346282184124, 0.627736944006756, 1.5535392751917243, 2.43240337818861, 29.88361045718193, 80.13796582818031, 73.42635557055473, 71.02319732308388, 66.93566545844078, 71.07239708304405, 74.01993691921234, 70.48895359039307, 67.11608737707138, 42.29142285883427, 48.78633454442024, 49.410302862524986, 63.097039237618446, 16.39760971069336, 1.3086143927648664, 0.2538989915046841, 0.45453692378941923, 0.1098799730243627, 0.2890237426618114, 0.1849201350705698, 0.16468378657009453, 0.27255337801761925], [0.05313373636454344, 0.07334180903853849, 0.04768957478518132, 0.02866518869268475, 0.05676383669197094, 0.07968727557454258, 0.059731648143497296, 0.04371935188828502, 0.06172802910441533, 0.025597252242732793, 0.7600269047543406, 0.37650790298357606, 17.720162943005562, 60.8003056794405, 38.27654309570789, 27.91630782186985, 33.38642589747906, 48.67432415485382, 44.09283399581909, 64.1981403529644, 57.082607969641685, 58.841446191072464, 51.84979096055031, 56.9173738360405, 52.12510898709297, 39.80282239615917, 1.1306546232663095, 2.741067702881992, 0.241127431509085, 0.24543813691707328, 18.158152140676975, 49.71011057496071, 57.930840253829956, 57.36681751906872, 59.481225460767746, 60.217576548457146, 60.5984491109848, 59.094208627939224, 56.618964448571205, 58.50160002708435, 53.65121729671955, 51.71856500208378, 47.72976703941822, 44.44460391998291, 42.07051791250706, 43.51398445665836, 43.55658017098904, 43.407559767365456, 47.805645167827606, 52.57526323199272, 56.394081115722656, 56.4249050617218, 56.67652755975723, 53.56655403971672, 47.45477959513664, 51.00296840071678, 54.7876413166523, 54.08291593194008, 54.01249811053276, 50.206884518265724, 49.534563794732094, 45.202055275440216, 40.8510797470808, 46.73415586352348, 50.890954211354256, 52.23840370774269, 51.27852201461792, 52.750114649534225, 41.8237629532814, 38.206398859620094, 38.65763984620571, 39.0170169621706, 42.789655923843384, 48.03963281214237, 49.54893462359905, 51.53917282819748, 51.90901078283787, 51.2517524510622, 52.1758096665144, 51.861460134387016, 54.59078148007393, 50.22293485701084, 54.74648952484131, 52.117007821798325, 45.96267946064472, 41.28084048628807, 42.555725276470184, 40.986227095127106, 45.0163896381855, 44.99664209783077, 38.70766796171665, 41.80534154176712, 40.453047305345535, 42.57557161152363, 42.585652470588684, 49.36553746461868, 56.374709755182266, 53.556431382894516, 53.768684193491936, 52.05854795873165, 51.38640582561493, 49.74028095602989, 48.34883742034435, 50.79154014587402, 49.59511734545231, 45.436415299773216, 39.13400128483772, 38.25681835412979, 37.00929209589958, 37.0857097953558, 40.30565321445465, 49.21418398618698, 50.29840640723705, 48.58320124447346, 50.09140111505985, 51.39929473400116, 45.74919171631336, 40.45693829655647, 45.440488681197166, 49.583710357546806, 54.59900803864002, 51.881766244769096, 46.95476442575455, 46.34668305516243, 52.746083065867424, 53.82204093039036, 55.33695504069328, 55.01448534429073, 53.199763521552086, 56.48431867361069, 57.271184250712395, 56.57311610877514, 55.926964581012726, 50.39991036057472, 45.18040403723717, 41.72783710062504, 41.15407168865204, 44.560364708304405, 42.70222261548042, 49.04421150684357, 54.2374612390995, 59.2611488699913, 59.48802329599857, 56.75488695502281, 55.16856707632542, 67.7376276254654, 63.04662734270096, 59.8729844391346, 60.07217735052109, 53.69249828159809, 17.582123950123787, 0.4052063974086195, 0.2439688181038946, 3.010928272269666, 49.15452718734741, 50.27009032666683, 52.98913322389126, 50.67327909171581, 57.56778493523598, 52.84807339310646, 60.16946732997894, 56.51850923895836, 45.22041969001293, 28.614545054733753, 58.007774725556374, 37.822068482637405, 37.49374330043793, 2.4075636360794306, 0.4414875333895907, 0.16531208879314363, 0.11915788025362417, 0.055552729609189555, 0.023877922430983745, 0.0881614071840886, 0.11212303274078295, 0.04749741048726719, 0.026912525318039116, 0.028598128228622954, 0.03546579027897678, 0.028151288533990737, 0.11088336410466582, 0.01773268548276974, 0.10268803511280566, 0.005192476110096322, 0.06224188473424874, 0.10881234906264581, 0.6574433937203139, 0.48048757191281766, 22.424960285425186, 71.6600051522255, 38.04239206016064, 29.728058204054832, 50.73313347995281, 49.993499368429184, 48.99336263537407, 68.93219992518425, 65.16004353761673, 61.881385669112206, 58.34555380046368, 61.161867678165436, 59.033024311065674, 44.444565922021866, 1.5507775358855724, 3.32250680308789, 1.0113496938720345, 0.44724051374942064, 22.572802752256393, 51.6034159809351, 59.61755834519863, 59.5355511456728, 62.158801183104515, 64.0873534977436, 63.55308696627617, 60.43132647871971, 60.34564107656479, 59.8867055028677, 55.918088257312775, 53.019991368055344, 48.99676725268364, 47.71564319729805, 45.00010371208191, 45.93321584165096, 45.80671302974224, 45.97446262836456, 49.4428975135088, 54.55884039402008, 58.05097460746765, 58.8021145015955, 59.85978774726391, 55.90448118746281, 48.41389372944832, 50.98381742835045, 55.59178076684475, 58.67849953472614, 55.99067576229572, 51.89255006611347, 50.93861885368824, 48.23287904262543, 42.37941853702068, 49.630212262272835, 54.07821178436279, 53.74351814389229, 54.23415541648865, 53.29898379743099, 46.78369380533695, 40.42336329817772, 39.67040330171585, 41.667868718504906, 43.88544872403145, 48.23486253619194, 51.54242165386677, 54.04017582535744, 53.532325476408005, 54.80849839746952, 55.58519572019577, 55.55339142680168, 57.02556163072586, 54.253868758678436, 56.556940376758575, 55.35892926156521, 45.17448775470257, 41.53028950095177, 42.198654636740685, 44.19456973671913, 47.30803906917572, 46.15544691681862, 39.25708048045635, 41.53239458799362, 40.080051720142365, 43.22617270052433, 42.922280207276344, 49.268999844789505, 58.4880955517292, 55.845584347844124, 56.325745582580566, 55.07902108132839, 55.501068234443665, 53.75761918723583, 53.18731538951397, 52.842742279171944, 52.24411100149155, 45.789720341563225, 43.03728863596916, 40.85824616253376, 40.120929926633835, 40.49437388777733, 44.210779666900635, 50.75028195977211, 53.83996456861496, 52.680646777153015, 53.063776418566704, 53.71923364698887, 49.2428382486105, 42.23055012524128, 46.533351838588715, 50.84452450275421, 54.64505776762962, 53.32542657852173, 48.9012935757637, 48.25269877910614, 52.328823655843735, 56.04394890367985, 56.27382516860962, 56.80963821709156, 54.80488479137421, 57.65778310596943, 59.25103381276131, 58.69434468448162, 56.829750537872314, 51.27829022705555, 47.19429597258568, 44.832635298371315, 43.479847088456154, 46.223607659339905, 44.6334233880043, 51.42975389957428, 56.29748649895191, 60.18339738249779, 59.18112896382809, 60.541767552495, 54.24649715423584, 65.98184064030647, 65.68048641085625, 63.0145912617445, 63.32307390868664, 56.00543037056923, 19.892937652766705, 0.25649193674325943, 0.6778009794652462, 4.744223076850176, 55.70985183119774, 58.246534913778305, 59.899058640003204, 56.1378912627697, 64.30479303002357, 59.90203768014908, 65.10919466614723, 67.60848015546799, 51.12668216228485, 40.85297964513302, 54.8157712072134, 41.53358772397041, 49.16305772960186, 3.5333078540861607, 0.5025252315681428, 0.18447014124831185, 0.04324740162701346, 0.15681654622312635, 0.03905338038748596, 0.05078959613456391, 0.07626014150446281, 0.03773256903514266, 0.10820510156918317, 0.19244978728238493, 0.20995653147110716, 0.10573015781119466, 0.23463640012778342, 0.1261194481048733, 0.45256224693730474, 0.11106997713795863, 0.16862450167536736, 0.16952836333075538, 0.9064418950583786, 0.9339213673956692, 28.257974088191986, 83.38369846343994, 52.62445919215679, 32.462729662656784, 52.12978273630142, 58.70827853679657, 54.51274126768112, 74.37036171555519, 70.48101961612701, 69.49585407972336, 65.00675976276398, 68.40638414025307, 63.97839054465294, 52.76897303760052, 1.9288526172749698, 9.00232208892703, 0.4223816539160907, 0.5338096059858799, 29.740903414785862, 52.577049136161804, 63.9488585293293, 61.55298449099064, 63.61548721790314, 66.84498712420464, 63.799321353435516, 63.84447053074837, 61.896220073103905, 61.425767317414284, 56.788598746061325, 56.04650616645813, 52.01353557407856, 49.40100096166134, 47.187311947345734, 48.19226302206516, 46.74245081841946, 48.41291718184948, 51.93498618900776, 56.85860238969326, 59.16072405874729, 60.76983131468296, 62.78321027755737, 58.67386758327484, 48.99680905044079, 50.41449397802353, 58.63022692501545, 59.898690059781075, 57.91877590119839, 55.84914095699787, 55.081331357359886, 50.81204004585743, 46.51618055999279, 52.47334510087967, 56.95846103131771, 57.341054901480675, 56.681794077157974, 58.70141230523586, 50.958149805665016, 44.12262819707394, 44.68116022646427, 45.31099922955036, 46.432345658540726, 52.42268621921539, 53.79863418638706, 55.530756041407585, 55.53569197654724, 58.010613173246384, 57.63948328793049, 57.86843240261078, 59.799363389611244, 55.45422054827213, 60.44523373246193, 56.269235014915466, 47.88389816880226, 40.552886947989464, 44.70533832907677, 44.10294145345688, 52.164402678608894, 47.98749580979347, 38.00782911479473, 42.07572743296623, 42.41713151335716, 43.06843936443329, 42.65259727835655, 50.80358549952507, 61.127000749111176, 59.51243318617344, 58.32578346133232, 56.87685661017895, 55.43897196650505, 56.97404019534588, 52.919114381074905, 58.746880665421486, 56.58813290297985, 50.458077639341354, 44.97019171714783, 43.780726343393326, 42.00579218566418, 43.557017147541046, 46.381280198693275, 53.09966929256916, 54.471566677093506, 56.83933362364769, 56.08118310570717, 56.92090764641762, 50.02666398882866, 43.15886311233044, 49.19426545500755, 54.19573947787285, 57.142238169908524, 53.557434529066086, 52.37455800175667, 48.31091545522213, 53.487107902765274, 57.93478824198246, 59.733900502324104, 59.36305180191994, 57.09081552922726, 59.0393053740263, 59.06581275165081, 60.05748353898525, 59.908911511301994, 52.96966306865215, 48.29022936522961, 46.45791068673134, 45.17582908272743, 48.20793718099594, 46.07493303716183, 52.80073933303356, 58.81229415535927, 61.56910702586174, 62.2351086884737, 59.25765685737133, 55.3793303668499, 66.3116705417633, 65.72798386216164, 66.2006177008152, 64.16556850075722, 58.869986459612846, 24.96348436921835, 0.7037569710519165, 2.3430160246789455, 5.406697578728199, 64.99904617667198, 62.86140248179436, 66.99048891663551, 60.10043263435364, 70.23394927382469, 63.55071969330311, 73.57618153095245, 69.26437050104141, 60.494425892829895, 43.59709359705448, 64.76915091276169, 52.73318275809288, 62.094770818948746, 5.334331886842847, 0.5950405891053379, 0.29672489035874605, 0.2739839121932164, 0.21952159790089354, 0.1879084372194484, 0.17315136501565576, 0.21207068755757064, 0.199569299002178], [0.05726081217289902, 0.06627190246945247, 0.02107571010128595, 0.037441298336489126, 0.08692608011187986, 0.03264432663854677, 0.01677825017395662, 0.039509274283773266, 0.012825710800825618, 0.05380532435083296, 0.22101401234976947, 0.11970948151429184, 3.8868556078523397, 47.723664566874504, 44.7896634042263, 34.397635236382484, 27.627422623336315, 51.19898088276386, 46.04882463812828, 56.9979827105999, 59.250653833150864, 57.07741744816303, 60.91974847018719, 56.93801052868366, 49.153733029961586, 54.58339087665081, 10.279622599482536, 2.9066471429541707, 1.7411808064207435, 0.07102644187398255, 5.7280192617326975, 44.806017726659775, 55.80471754074097, 62.43270568549633, 57.811944633722305, 56.573636680841446, 52.239555045962334, 51.70656904578209, 48.70973065495491, 48.97682212293148, 46.01778790354729, 43.34672123193741, 43.42087425291538, 43.012388572096825, 40.85965968668461, 42.582035064697266, 42.36916668713093, 42.01680779457092, 43.0265162140131, 47.63573348522186, 51.23624928295612, 53.34899291396141, 52.78158836066723, 53.061823323369026, 51.70119233429432, 50.27792930603027, 53.63258309662342, 54.398257210850716, 55.34186437726021, 51.624098271131516, 49.93278622627258, 47.336271554231644, 42.006578743457794, 43.00023302435875, 47.82072655856609, 53.44724424183369, 52.41237357258797, 46.62158690392971, 36.62344180047512, 36.389625146985054, 37.98443377017975, 39.566140696406364, 43.10889959335327, 50.66783778369427, 49.34623830020428, 51.58475898206234, 50.70965074002743, 54.56352934241295, 54.27396968007088, 54.92187671363354, 54.20628011226654, 55.514223128557205, 53.91496114432812, 53.95343407988548, 43.729839473962784, 40.204194858670235, 42.06118941307068, 42.074906677007675, 44.567550122737885, 46.86710312962532, 39.31190773844719, 43.28904412686825, 40.05036771297455, 42.61186346411705, 41.45758420228958, 48.44050370156765, 54.6621036529541, 54.404515475034714, 51.97887763381004, 55.21039143204689, 51.10302463173866, 52.074970677495, 52.644066140055656, 50.58701612055302, 53.082942590117455, 49.235060065984726, 42.74367079138756, 40.28630465269089, 40.406826585531235, 37.40077368915081, 40.15560686588287, 45.209267288446426, 48.98615442216396, 51.5620020031929, 50.5833987146616, 50.42190358042717, 42.47739627957344, 43.59197147190571, 46.21847413480282, 48.86597067117691, 52.384897246956825, 53.81897829473019, 53.943805396556854, 54.92700643837452, 54.250042364001274, 53.09477135539055, 52.248739153146744, 53.0781776458025, 54.25917327404022, 52.32704155147076, 52.02344164252281, 52.54961080849171, 50.812199637293816, 46.35711349546909, 42.098814994096756, 42.42796093225479, 41.386577412486076, 42.44811125099659, 41.729729399085045, 43.23711231350899, 49.15243349969387, 53.84933106601238, 56.14147067070007, 61.40316233038902, 59.319247752428055, 53.39166462421417, 59.26825828850269, 61.28434270620346, 56.64742112159729, 38.52764882147312, 6.7577706556767225, 0.16947291005635634, 0.3397976572159678, 8.49709739908576, 55.82316555082798, 51.367372646927834, 52.1967351436615, 54.687239304184914, 56.33348576724529, 55.414904057979584, 60.29761925339699, 46.69351704418659, 37.687764689326286, 24.236716367304325, 40.658715069293976, 40.807184502482414, 28.781889975070953, 0.6818652770016342, 0.11771570178098045, 0.10050895594758913, 0.11450670717749745, 0.12506438128184527, 0.005023632875236217, 0.036500596470432356, 0.06475156842498109, 0.08160620971466415, 0.02792600960674463, 0.09913315516314469, 0.06144494800537359, 0.030825101894151885, 0.055847655385150574, 0.03861383971525356, 0.017174089480249677, 0.01076046781236073, 0.13568417314672843, 0.035397742758505046, 0.34202763286884874, 0.06741939636413008, 6.070701973512769, 58.967614620923996, 46.96931764483452, 27.17685990035534, 43.23827125132084, 56.184081584215164, 46.677231118083, 64.46055427193642, 62.651547342538834, 64.11014467477798, 65.3011603653431, 61.68674871325493, 53.89468543231487, 61.461261212825775, 10.049971472471952, 1.362636093981564, 4.027386317029595, 0.37010082334745675, 8.292847909033298, 47.91843831539154, 59.55402195453644, 61.87773406505585, 59.889608547091484, 59.40753601491451, 55.48158288002014, 54.485705718398094, 51.076562851667404, 50.47668904066086, 48.69789429008961, 45.953069776296616, 44.25887368619442, 44.50186304748058, 42.09275811910629, 43.60069580376148, 44.11930337548256, 43.85329104959965, 44.31088149547577, 49.81041379272938, 53.37289363145828, 55.64849652349949, 54.711052626371384, 55.56562677025795, 51.12913303077221, 50.517787635326385, 56.45509444177151, 58.345827385783195, 57.20324769616127, 52.7755618840456, 50.54548054933548, 48.34710091352463, 44.92136813700199, 46.603515073657036, 49.781968519091606, 54.93726588785648, 55.8647695183754, 49.16714251041412, 39.923040345311165, 38.428230956196785, 39.791556000709534, 42.640559524297714, 44.38827954232693, 51.785756796598434, 52.41885602474213, 52.13960900902748, 53.1759350001812, 56.948387771844864, 55.4025699198246, 57.65709534287453, 55.81055022776127, 56.414505019783974, 56.78778938949108, 55.30879855155945, 43.840386942029, 41.135802268981934, 40.40785253047943, 41.803346648812294, 47.27588139474392, 47.575932294130325, 40.190337002277374, 42.45265580713749, 39.96330298483372, 42.1817721426487, 40.94273462891579, 48.820810094475746, 56.55592583119869, 56.226468309760094, 53.21697659790516, 56.34861655533314, 53.68988402187824, 55.225317031145096, 54.47772994637489, 52.5137635320425, 52.633586302399635, 52.28652812540531, 43.96846666932106, 43.1144966930151, 41.11617632210255, 39.3008541315794, 42.861293479800224, 48.15564438700676, 51.77636370062828, 53.009230345487595, 51.55064441263676, 51.678078174591064, 44.37003292143345, 45.68820498883724, 47.70757623016834, 50.153033807873726, 52.47607335448265, 55.34016586840153, 55.16077749431133, 55.07925666868687, 54.3916417658329, 54.17587034404278, 54.19876031577587, 54.070445001125336, 55.223660320043564, 53.80958519876003, 53.45909580588341, 53.14625859260559, 51.478208899497986, 46.81377299129963, 43.214685916900635, 43.71525585651398, 43.22938732802868, 43.948069363832474, 44.241934195160866, 44.08328890800476, 50.41298545897007, 56.953517496585846, 57.19671204686165, 63.368150889873505, 63.26166920363903, 53.737556263804436, 58.5718734562397, 61.359027698636055, 57.81337335705757, 40.49725413322449, 8.402447327971458, 0.1754712444380857, 0.6421159661840647, 11.96187973022461, 63.62881690263748, 56.86428688466549, 59.162243977189064, 60.11499725282192, 60.048044845461845, 62.894354313611984, 66.77479729056358, 53.26049946248531, 43.35279330611229, 36.2614656239748, 40.48778124153614, 46.67634956538677, 36.07185199856758, 0.8495610253885388, 0.14816203562077135, 0.11528298622579314, 0.08872038539266214, 0.1283628269447945, 0.022715257182426285, 0.028162873459223192, 0.055154738074634224, 0.08459958815365098, 0.1864965309505351, 0.2025175400194712, 0.12159927893662825, 0.15703536104410887, 0.24663051590323448, 0.14646835072198883, 0.1192173411254771, 0.10596138134133071, 0.21363471925724298, 0.15613268682500347, 0.666131746256724, 0.18904036085586995, 8.66510633379221, 71.34171903133392, 62.96021617949009, 43.65380175411701, 47.257570177316666, 65.2669470012188, 53.43848951160908, 67.32110917568207, 69.52996864914894, 69.44603875279427, 70.049849152565, 69.79851543903351, 60.891113206744194, 67.14326351881027, 13.47189400345087, 6.62791452370584, 5.674976008012891, 0.6264057091902941, 10.25841023772955, 54.43877063691616, 56.33011154830456, 66.49437233805656, 64.29367482662201, 63.148720264434814, 56.99092648923397, 56.620841547846794, 52.67687737941742, 53.76246392726898, 51.65918558835983, 49.58658680319786, 47.50279001891613, 47.63806656002998, 43.60269829630852, 45.87276488542557, 46.277785152196884, 44.55415204167366, 45.96569649875164, 53.10254193842411, 55.19811809062958, 57.87729352712631, 55.81192575395107, 55.957389548420906, 54.37482386827469, 54.40312474966049, 58.69609639048576, 59.24906551837921, 61.25473089516163, 54.95447896420956, 54.09344136714935, 51.29176430404186, 46.85266010463238, 50.256202071905136, 53.15078414976597, 58.057460859417915, 58.90886217355728, 53.40040795505047, 42.27963589131832, 42.29806870222092, 45.05519695580006, 44.89978909492493, 49.13085825741291, 56.421519443392754, 55.244935378432274, 56.24151170253754, 54.98952068388462, 60.216102227568626, 57.76060178875923, 61.50919184088707, 58.990158811211586, 60.95046602189541, 58.68937835097313, 58.37085664272308, 45.15365347266197, 40.792091712355614, 41.20131075382233, 44.21630457043648, 51.55287489295006, 50.089406222105026, 39.50175695121288, 43.98129478096962, 40.171695202589035, 42.8443767875433, 42.773073613643646, 51.23588070273399, 60.51702328026295, 58.02508659660816, 54.9133537709713, 58.23331542313099, 57.06412576138973, 58.30581933259964, 58.73744957149029, 55.18025904893875, 55.49214631319046, 56.95548579096794, 46.55302718281746, 46.403455808758736, 43.86648394167423, 42.234714701771736, 45.39742939174175, 50.67205935716629, 55.000973269343376, 55.577577129006386, 54.54286605119705, 55.409880727529526, 47.07595892250538, 49.949801713228226, 49.0925183147192, 53.13230574131012, 53.93169164657593, 57.89530836045742, 57.28724218904972, 55.362930446863174, 56.44541636109352, 56.85407303273678, 56.294214874506, 57.63030678033829, 58.13596464693546, 55.75777105987072, 56.144472509622574, 56.38548217713833, 54.52913738787174, 48.82730774581432, 45.130964890122414, 45.782105550169945, 45.51002115011215, 46.68746396899223, 45.617752969264984, 48.02392825484276, 52.093091905117035, 59.66648072004318, 59.20690298080444, 66.01973220705986, 62.56998851895332, 58.315436616539955, 58.763816356658936, 65.33713683485985, 56.985853761434555, 47.35402800142765, 11.34211778640747, 0.32132711552549154, 2.321129674091935, 11.03442169725895, 72.96290203928947, 61.489877477288246, 64.89249989390373, 66.34190171957016, 66.26291155815125, 68.04696142673492, 71.66380494832993, 60.45012027025223, 53.435563668608665, 37.11387388408184, 48.78087043762207, 56.44557975232601, 50.30957780778408, 1.2748546293005347, 0.19225626485422254, 0.14414152479730546, 0.24464749731123447, 0.24652415129821748, 0.10032332997070625, 0.13353026763070375, 0.12491661967942491, 0.13283039268571883], [0.03576180701202247, 0.1446779046091251, 0.016002952615963295, 0.045579942088807, 0.05022790908697061, 0.02938958419690607, 0.06565156349097379, 0.06222692674782593, 0.02755933855951298, 0.0958800918306224, 0.19385093240998685, 0.17029391834512353, 1.6386629012413323, 41.150047704577446, 48.73845711350441, 40.68859286606312, 23.085448443889618, 47.524908632040024, 52.7772755920887, 47.42220774292946, 63.825380355119705, 52.7598687261343, 47.620549499988556, 58.4099717438221, 51.83728963136673, 53.84944126009941, 23.99040788412094, 0.6520189472939819, 5.895884754136205, 0.1308240558137186, 3.9862900972366333, 36.842902824282646, 60.905271247029305, 62.574844658374786, 57.23222874104977, 56.02114252746105, 50.46598121523857, 47.91631802916527, 45.80512851476669, 43.85038420557976, 44.84801687300205, 45.44839605689049, 43.386524096131325, 45.15309490263462, 46.889419332146645, 47.98474855720997, 46.9223939627409, 46.37871153652668, 46.75367921590805, 46.66020803153515, 47.82212868332863, 52.719663083553314, 53.02594184875488, 57.554542645812035, 55.77001020312309, 56.79182477295399, 57.683720514178276, 55.43441981077194, 55.90878635644913, 51.587601229548454, 47.630349174141884, 48.382898792624474, 42.38465465605259, 40.8181469142437, 43.22185233235359, 48.0694992095232, 47.90937580168247, 40.37996202707291, 37.67699606716633, 37.553852275013924, 38.674210757017136, 43.303407356143, 47.27728731930256, 49.9288534373045, 50.69879092276096, 52.361357510089874, 52.436160296201706, 55.1652916520834, 56.275930255651474, 55.53058125078678, 56.66523456573486, 55.553900599479675, 53.87603223323822, 52.47196577489376, 42.14760437607765, 40.80729089677334, 41.06549844145775, 42.80426613986492, 42.98199400305748, 47.67514117062092, 39.386714324355125, 44.26362723112106, 40.910242572426796, 44.18703854084015, 40.204153060913086, 50.26005506515503, 55.894875302910805, 58.08541215956211, 51.69690616428852, 53.590344563126564, 51.98794774711132, 53.52191783487797, 49.73323233425617, 51.62122182548046, 49.11320440471172, 52.27130614221096, 49.47554536163807, 43.54277931153774, 40.98586991429329, 38.38297538459301, 36.9192673265934, 38.793911933898926, 45.34585855901241, 51.118375808000565, 50.470974147319794, 46.43385797739029, 40.33260516822338, 45.33427678048611, 47.54014581441879, 49.55031394958496, 50.84251821041107, 52.71340101957321, 56.06322146952152, 53.649488389492035, 52.66480162739754, 54.63567227125168, 51.1850356310606, 49.53700326383114, 45.154899805784225, 44.63415674865246, 42.020265609025955, 43.905716836452484, 41.74992151558399, 42.260378524661064, 43.40641222894192, 42.76725612580776, 42.66246534883976, 44.98232066631317, 41.340056508779526, 44.31576043367386, 41.97455786168575, 47.41620026528835, 52.33052596449852, 57.80020706355572, 58.621168211102486, 58.79339016973972, 53.65622542798519, 56.13175459206104, 47.556602731347084, 25.084726363420486, 4.933284306898713, 0.12672330398345366, 0.5864006245974451, 17.54262886941433, 62.45577424764633, 46.13229475915432, 54.77566435933113, 55.235401690006256, 58.90754744410515, 57.393518686294556, 56.244562938809395, 56.21863692998886, 35.245096161961555, 28.599885441362858, 34.97626058757305, 50.25676064193249, 13.602020870894194, 1.1763217602856457, 0.03402023503440432, 0.3158786235144362, 0.038398546384996735, 0.14637363783549517, 0.05762592285464052, 0.1446966512594372, 0.05280752906401176, 0.03290746251877863, 0.03327515958517324, 0.050156670331489295, 0.04842870192078408, 0.04769051731273066, 0.04131653004151303, 0.0196545418293681, 0.046095482393866405, 0.08895583916455507, 0.041399168185307644, 0.0775011014775373, 0.5309790547471493, 0.09366169368149713, 2.0970761217176914, 49.75835278630257, 56.42643257975578, 38.77767160534859, 34.06408913433552, 59.04988020658493, 52.953019961714745, 54.72708776593208, 71.59650295972824, 59.22148659825325, 55.172982439398766, 63.50111335515976, 56.391018480062485, 63.71838569641113, 26.70950397849083, 0.43066580314189196, 5.358849596232176, 0.5149279441684484, 5.958507293835282, 40.80178119242191, 61.992442309856415, 64.96686190366745, 60.01306772232056, 60.503910183906555, 52.55306862294674, 50.64690090715885, 47.70732544362545, 47.49543361365795, 46.91328585147858, 46.39242500066757, 46.480477675795555, 47.07196533679962, 48.24804022908211, 49.10232558846474, 47.380957156419754, 47.023973912000656, 48.94632875919342, 50.80510161817074, 51.38113170862198, 54.59057629108429, 55.76527185738087, 62.36945427954197, 58.64758439362049, 60.15266843140125, 59.23367254436016, 59.09872278571129, 58.03299397230148, 55.33552631735802, 49.916804283857346, 49.30159069597721, 44.7136826813221, 43.406993597745895, 45.40351286530495, 51.1658276617527, 49.863310754299164, 44.08393867313862, 39.650169387459755, 40.040279254317284, 41.394207403063774, 44.72365714609623, 50.78010655939579, 52.14071474969387, 53.06752681732178, 54.128464087843895, 54.247694090008736, 55.64643323421478, 56.22066222131252, 56.46663822233677, 57.44794316589832, 56.50393322110176, 55.356672182679176, 52.84865476191044, 41.98374956846237, 40.58057986199856, 39.34272788465023, 43.46422232687473, 46.35367847979069, 48.149937093257904, 39.44460801780224, 44.02011349797249, 40.02846568822861, 44.0076007694006, 40.15196666121483, 52.06033006310463, 56.649397015571594, 59.56344164907932, 55.44865384697914, 55.919794365763664, 55.34773126244545, 55.9711904078722, 52.605133429169655, 54.388575330376625, 52.96529330313206, 55.0009086728096, 49.515021443367004, 45.66905781626701, 42.59165994822979, 40.69967307150364, 40.07918916642666, 43.031383752822876, 47.80077002942562, 53.11621740460396, 52.873999401926994, 46.71948105096817, 44.78111766278744, 46.91367343068123, 49.31999310851097, 49.84651565551758, 52.768714651465416, 55.40690168738365, 56.960634514689445, 55.63436508178711, 54.5708629488945, 55.84511697292328, 53.3121956884861, 50.44730521738529, 46.99656218290329, 46.585188657045364, 43.40130530297756, 45.29513508081436, 42.87385940551758, 43.619588389992714, 42.40694046020508, 44.23599511384964, 43.38970832526684, 45.10500468313694, 44.01680387556553, 46.19026444852352, 45.193897113204, 48.65631692111492, 52.53628492355347, 59.55198906362057, 60.36850444972515, 62.85078585147858, 56.321755796670914, 56.01118706166744, 49.39670339226723, 30.485851541161537, 6.251901900395751, 0.1997703913366422, 0.7419861853122711, 21.235348619520664, 68.32510650157928, 51.292657256126404, 62.15907856822014, 59.650335386395454, 65.83526730537415, 61.50334395468235, 63.29292252659798, 56.63769744336605, 48.819711953401566, 36.13305151462555, 29.206046015024185, 62.79457166790962, 17.905927374958992, 1.2256367015652359, 0.024732429410505574, 0.2665931306546554, 0.06750616084900685, 0.17318421247182414, 0.0046160727379174205, 0.04868659823841881, 0.050546869315439835, 0.056768055801512673, 0.08210999440052547, 0.2765146060846746, 0.2561596326995641, 0.2356892850366421, 0.14117394341155887, 0.09746143041411415, 0.15944759332342073, 0.250239847227931, 0.24714148457860574, 0.1546529631013982, 0.8426649891771376, 0.12230748820002191, 2.8858736576512456, 61.70376420021057, 70.40627002716064, 51.949277222156525, 34.00925047695637, 62.5445868819952, 58.872532323002815, 58.24275031685829, 75.89297041296959, 64.29144814610481, 61.94356553256512, 70.23646473884583, 65.2944727241993, 66.84338361024857, 33.209784775972366, 0.9839886089321226, 15.546987354755402, 0.26668851147405803, 7.314842138439417, 49.01168905198574, 60.29327608644962, 70.35501077771187, 61.05024866759777, 65.53454384207726, 54.76786717772484, 53.60774002969265, 50.06722301244736, 51.390680596232414, 47.70200192928314, 49.654420763254166, 49.21194590628147, 50.91759838163853, 51.3667418807745, 51.49870119988918, 51.52557335793972, 50.188284516334534, 51.57345458865166, 52.55424655973911, 51.26154072582722, 57.98885174095631, 56.92119263112545, 64.84664395451546, 60.76453059911728, 63.582873567938805, 61.41116090118885, 61.155958995223045, 61.36572293937206, 57.600873559713364, 52.19777628779411, 53.65731976926327, 46.05175048112869, 47.267001271247864, 47.53565065562725, 53.9396408200264, 52.28870540857315, 45.89769534766674, 42.22394607961178, 44.58283670246601, 45.27211591601372, 48.26555348932743, 53.354871198534966, 56.02121852338314, 54.432170391082764, 56.97177171707153, 56.98113061487675, 58.680319637060165, 59.52094852924347, 60.60337744653225, 61.8298414349556, 61.2798285484314, 58.412859588861465, 52.96692721545696, 41.719918325543404, 40.41440337896347, 40.11065527796745, 42.853549495339394, 48.743898421525955, 50.68395271897316, 39.417671263217926, 45.29798112809658, 40.265439972281456, 44.91084270179272, 39.48523923754692, 53.08553025126457, 59.99108970165253, 61.753530129790306, 56.688242331147194, 57.68093906342983, 56.196541115641594, 59.768957421183586, 53.08132767677307, 58.115970119833946, 54.068146124482155, 57.91665181517601, 53.611843809485435, 49.58129748702049, 45.48246122896671, 42.83236563205719, 42.14679501950741, 44.515945091843605, 50.81263281404972, 57.04822361469269, 54.44053754210472, 50.4221847653389, 44.988404139876366, 49.625625908374786, 53.17642517387867, 52.42682799696922, 53.89494001865387, 56.71305499970913, 58.89975406229496, 57.41770438849926, 55.68616770207882, 58.352971002459526, 54.7507680952549, 54.639760851860046, 49.2101676017046, 48.40351648628712, 43.783006221055984, 47.37363114953041, 44.19098272919655, 45.684469789266586, 45.928466096520424, 47.42445722222328, 45.269524455070496, 47.62765891849995, 45.79127065837383, 49.307210594415665, 46.23679295182228, 52.53409244120121, 55.74205510318279, 61.11079841852188, 62.24139355123043, 66.27806514501572, 55.3913377225399, 57.602135092020035, 50.31680881977081, 39.68021057546139, 8.581231534481049, 0.8962992299348116, 2.228381638415158, 24.502297416329384, 76.00646272301674, 56.262801960110664, 66.76410466432571, 65.32008334994316, 69.88422363996506, 68.53493124246597, 69.52980905771255, 68.73266503214836, 52.019421458244324, 39.33513589203358, 47.790217995643616, 72.9269027709961, 28.366551361978054, 1.299436935223639, 0.07372020787443034, 0.34823816211428493, 0.15045337204355747, 0.2905807684874162, 0.1782637828728184, 0.2717914595268667, 0.11625111786997877, 0.17244677001144737], [0.042870761681115255, 0.021341193023545202, 0.016459622056572698, 0.09245279448805377, 0.07246661654789932, 0.019856153667205945, 0.012332808782957727, 0.0969155140046496, 0.039771931478753686, 0.06257766945054755, 0.0667109718779102, 0.6010462855920196, 0.22261160396737978, 25.21052621304989, 56.11959904432297, 42.42224223911762, 24.11395825445652, 37.27929040789604, 57.01045744121075, 59.66201215982437, 49.252789914608, 54.09952864050865, 48.71860697865486, 56.96521706879139, 53.52172404527664, 52.15415082871914, 39.95246596634388, 1.8716171197593212, 4.130642451345921, 0.543246102752164, 1.6166804870590568, 28.15685011446476, 56.8348840624094, 61.002967804670334, 59.49343420565128, 55.6551081687212, 56.38979114592075, 56.86125844717026, 56.007862240076065, 55.214392617344856, 53.26133541762829, 52.500996217131615, 53.12170051038265, 53.87306459248066, 56.35969676077366, 54.10163752734661, 55.35267099738121, 54.13588508963585, 52.43643768131733, 51.595637798309326, 52.669627368450165, 53.3612472563982, 51.68079882860184, 54.297395423054695, 54.767392203211784, 55.16715355217457, 54.83087919652462, 55.6720856577158, 54.694272726774216, 53.38267430663109, 49.69284050166607, 47.02767491340637, 43.8940704613924, 41.78684413433075, 42.45557405054569, 44.56317275762558, 43.93939442932606, 41.785544604063034, 37.372924983501434, 38.70066873729229, 40.041772574186325, 47.733810022473335, 51.35809734463692, 51.29906751215458, 51.86666585505009, 51.6335179656744, 56.129071936011314, 55.92238962650299, 54.429658725857735, 55.134976878762245, 54.33823563158512, 55.61449594795704, 54.616487100720406, 45.109811425209045, 41.833900809288025, 41.70129552483559, 42.16909982264042, 44.23054240643978, 43.39953079819679, 53.344391360878944, 41.34471505880356, 42.243169248104095, 38.85529384016991, 45.23350238800049, 41.283348351716995, 45.3224366158247, 52.75726206600666, 55.5949991941452, 53.72237227857113, 55.53702190518379, 53.05355116724968, 53.75508092343807, 50.96035748720169, 51.181395426392555, 50.60433179140091, 52.02241189777851, 48.507729694247246, 47.920953780412674, 41.82493709027767, 40.40912166237831, 37.65470266342163, 39.7630575299263, 42.36185967922211, 48.74446079134941, 43.759588077664375, 42.28002727031708, 40.693152621388435, 44.398823976516724, 46.61321595311165, 48.266131058335304, 50.89291110634804, 52.529156506061554, 53.83353151381016, 56.136249750852585, 55.396049469709396, 53.24662260711193, 53.95011305809021, 50.344775319099426, 45.76773092150688, 42.71057076752186, 42.25301831960678, 42.50226594507694, 43.03684405982494, 49.44111920893192, 49.146289229393005, 50.68377032876015, 51.22103489935398, 53.228995352983475, 51.157547906041145, 51.53569981455803, 48.77638287842274, 49.83320876955986, 47.334394454956055, 57.23698228597641, 54.29014541208744, 63.91645386815071, 57.0349433273077, 62.78336226940155, 31.94951020181179, 19.853605963289738, 7.239140700548887, 0.5844905145931989, 1.2512993370182812, 33.29721048474312, 57.4507550150156, 51.88319496810436, 55.48732437193394, 51.946404576301575, 55.20111992955208, 57.378889471292496, 60.3170932084322, 52.01361536979675, 24.151437543332577, 21.95521619170904, 43.16647030413151, 39.495935663580894, 4.431867487728596, 0.7689974515233189, 0.08016352658160031, 0.15528809308307245, 0.04388108070997987, 0.1278383660246618, 0.058394227526150644, 0.082459738914622, 0.027151795584359206, 0.12543739954708144, 0.03321678224892821, 0.04431217945239041, 0.017456892273912672, 0.09289690307923593, 0.011812150441983249, 0.015545242313237395, 0.09367411723360419, 0.02072518262139056, 0.0452378491172567, 0.023901932763692457, 0.03616901973146014, 0.49320442078169435, 0.4212826816365123, 34.50814850628376, 65.56895479559898, 41.10127352178097, 27.053239233791828, 52.53719687461853, 60.4671623557806, 64.37584921717644, 56.72021001577377, 63.181349113583565, 53.16297009587288, 64.46837425231934, 56.850588619709015, 60.358586981892586, 44.484824761748314, 2.595930453389883, 3.1699770502746105, 2.6864950312301517, 2.3228970542550087, 32.90602907538414, 59.28519017994404, 65.89194506406784, 61.556316912174225, 59.821463003754616, 59.898990243673325, 59.928651452064514, 58.91828566789627, 56.82074122130871, 55.7903391122818, 53.987753838300705, 55.00657416880131, 57.198946326971054, 57.617562264204025, 58.746390491724014, 56.645460426807404, 55.201135128736496, 52.380858063697815, 54.10597309470177, 54.92615528404713, 54.849919974803925, 54.15653698146343, 55.91315232217312, 55.84438741207123, 57.518140599131584, 56.991975232958794, 58.144301399588585, 56.03732205927372, 55.798045098781586, 52.466429471969604, 49.72837619483471, 46.555090472102165, 44.40019950270653, 44.54310983419418, 47.02423609793186, 47.17659652233124, 42.56177455186844, 41.16903528571129, 41.22532166540623, 43.39658595621586, 48.6998625844717, 53.75283904373646, 53.83887782692909, 55.71131095290184, 56.05947867035866, 55.699626579880714, 57.77903079986572, 57.44312882423401, 56.713727563619614, 56.79371327161789, 57.19174951314926, 57.29575753211975, 44.8409416526556, 41.51475213468075, 40.970362946391106, 42.75112599134445, 43.73850680887699, 45.96239447593689, 53.5502453148365, 41.18975557386875, 41.329276487231255, 39.84894812107086, 43.4906081110239, 40.72586126625538, 45.90993069112301, 56.911206766963005, 58.16790573298931, 55.57469308376312, 56.12817518413067, 54.16550450026989, 56.24043636023998, 53.20506423711777, 53.77331234514713, 52.70380653440952, 54.237548634409904, 50.62739655375481, 49.12440240383148, 43.54991912841797, 42.45133727788925, 40.31039535999298, 42.07079529762268, 44.26029860973358, 50.76137736439705, 47.1542689204216, 45.09137861430645, 42.620640993118286, 45.984592884778976, 49.166355952620506, 48.5540796071291, 51.82530127465725, 52.64148607850075, 53.28543372452259, 56.920200884342194, 54.48680765926838, 55.358275696635246, 55.55526852607727, 50.14329873025417, 46.53068818151951, 44.05137822031975, 43.05067151784897, 43.309897407889366, 45.37418603897095, 50.07794223725796, 50.44219069182873, 53.981776759028435, 53.949482291936874, 54.74465802311897, 52.63576738536358, 53.66627208888531, 50.17970837652683, 51.382431238889694, 48.92176687717438, 58.70952107012272, 56.920998841524124, 67.14845404028893, 58.598331436514854, 63.49684998393059, 34.13726560771465, 23.165922425687313, 7.715943865478039, 0.6280266784597188, 2.4777793558314443, 39.04305316507816, 63.40850092470646, 58.287078738212585, 58.81196357309818, 57.8918581455946, 62.64476850628853, 62.1099928021431, 67.43327155709267, 56.622498258948326, 35.542851984500885, 24.291741214692593, 42.99481451511383, 50.495741218328476, 6.344566103070974, 0.7697475550230592, 0.12583747651660815, 0.149635169073008, 0.09480569206061773, 0.08951138122938573, 0.015353592880273936, 0.04469788844289724, 0.07027988584013656, 0.09222254317137413, 0.18653679988346994, 0.11381563410395756, 0.08283585935714655, 0.16585664707235992, 0.09641412645578384, 0.09275121206883341, 0.16944962146226317, 0.24959245696663857, 0.13493650389136747, 0.1486679576919414, 0.15592688927426934, 0.7582016370724887, 0.6857457000296563, 40.959275141358376, 80.8099065721035, 52.58869171142578, 34.47820991277695, 54.93359908461571, 68.11984151601791, 71.35320961475372, 62.418277859687805, 66.42115026712418, 62.8348571062088, 67.93903961777687, 63.75155791640282, 65.12778326869011, 54.06460851430893, 3.1877781450748444, 10.09086487814784, 3.145287400111556, 3.0451774969697, 41.24766446650028, 58.36387261748314, 68.92357438802719, 64.64492797851562, 62.308558747172356, 62.844326198101044, 62.16794729232788, 62.78264410793781, 63.21368917822838, 59.758253395557404, 56.739797964692116, 57.922100722789764, 59.774744510650635, 60.23988515138626, 60.64500421285629, 59.88307669758797, 57.672169134020805, 56.43919609487057, 57.11359150707722, 58.12361150979996, 58.800199404358864, 57.17502661049366, 59.649754017591476, 58.97374749183655, 60.49427010118961, 57.80789405107498, 61.19930326938629, 59.079408422112465, 57.60071776807308, 55.850995257496834, 51.61948911845684, 46.75592489540577, 46.055345088243484, 46.836347579956055, 48.44621479511261, 49.622494876384735, 47.543713822960854, 44.45120416581631, 43.483354300260544, 46.558639481663704, 53.51024106144905, 58.20987828075886, 58.601891845464706, 57.43931382894516, 57.33600117266178, 61.18888042867184, 61.724020913243294, 60.920322239398956, 60.582337975502014, 58.11617910861969, 60.57736784219742, 58.13081972301006, 45.75493700802326, 40.09190708398819, 41.175301149487495, 41.84224896132946, 45.05259029567242, 49.03800643980503, 59.38481703400612, 43.18526029586792, 40.92814341187477, 38.882956355810165, 44.11004327237606, 42.31583274900913, 44.414441138505936, 57.02526904642582, 59.112113267183304, 56.62423096597195, 58.67625005543232, 56.42709754407406, 57.716193571686745, 55.099570378661156, 56.950154677033424, 53.77544783055782, 57.10923694074154, 52.32486806809902, 51.8524432182312, 48.3138071000576, 45.471761003136635, 42.34112039208412, 44.84455905854702, 47.18418851494789, 53.36641117930412, 49.182227700948715, 46.314855962991714, 44.4866144657135, 48.57255041599274, 49.03082862496376, 49.651453122496605, 53.307312950491905, 57.60001100599766, 55.66352091729641, 58.72700393199921, 56.54260374605656, 57.485143169760704, 56.14837110042572, 51.73192888498306, 49.262714982032776, 47.33504422008991, 45.90523414313793, 44.183683320879936, 47.40799270570278, 53.417959213256836, 51.64439678192139, 54.399055168032646, 56.102952137589455, 56.94899193942547, 54.71095383167267, 55.31311511993408, 51.355266496539116, 54.397691041231155, 51.547357589006424, 59.61536206305027, 57.99708969891071, 70.48449262976646, 58.59389327466488, 64.49736669659615, 38.98661099374294, 31.67379889637232, 8.501628655940294, 0.9753041749354452, 2.5794640369713306, 43.38750444352627, 69.55972105264664, 63.15494433045387, 64.20888617634773, 65.76307877898216, 67.9944558441639, 68.81657972931862, 72.00657695531845, 69.19399827718735, 33.28608848154545, 32.827817872166634, 59.10757631063461, 62.95118406414986, 10.626656077802181, 1.3171752146445215, 0.1851547576370649, 0.3316958388313651, 0.17323438165476546, 0.2707038272637874, 0.14040691894479096, 0.1660928875207901, 0.1473755223560147, 0.21212054503848776], [0.029146937158657238, 0.015131103500607423, 0.024030723216128536, 0.12357007435639389, 0.05285472965624649, 0.09535595745546743, 0.044452924048528075, 0.07077194459270686, 0.06186989805428311, 0.07017134674242698, 0.09150510901235975, 0.3705374733544886, 0.1932514106738381, 8.680067081004381, 50.06234027445316, 44.952712655067444, 30.984360091388226, 29.918722473084927, 45.46181693673134, 67.57425919175148, 50.744377076625824, 44.296145886182785, 46.17461308836937, 56.786033883690834, 58.889304623007774, 52.22564399242401, 43.78278583288193, 11.529375538229942, 2.349556186236441, 2.093450641259551, 0.9618594869971275, 15.591381322592497, 61.03169806301594, 58.03649738430977, 59.63043585419655, 59.424095526337624, 62.035019025206566, 59.93654362857342, 59.935057908296585, 59.5958349108696, 57.222949638962746, 57.92123056948185, 56.505369544029236, 57.83691689372063, 59.33033935725689, 55.618626326322556, 57.964882627129555, 56.89175181090832, 57.87946321070194, 56.97768799960613, 54.59340713918209, 55.4999852925539, 57.53053933382034, 57.112877145409584, 57.04306349158287, 56.66750304400921, 56.51301093399525, 56.59413278102875, 58.529798313975334, 56.08792394399643, 51.93645291030407, 47.70841218531132, 47.02028810977936, 43.02944965660572, 41.77692286670208, 41.63375794887543, 41.68939456343651, 38.91507603228092, 37.08257116377354, 39.59938131272793, 43.66302765905857, 46.96795351803303, 50.76640449464321, 51.260647773742676, 51.2127323448658, 52.889289781451225, 53.488342836499214, 53.840097561478615, 54.502394422888756, 56.536478474736214, 54.0756431221962, 55.64760737121105, 46.31463557481766, 42.722239941358566, 37.77405805885792, 42.89607681334019, 41.42120115458965, 45.8007625490427, 46.83554582297802, 50.70455141365528, 46.17649398744106, 40.32283589243889, 42.35083267092705, 41.42351143062115, 42.62849897146225, 40.939637795090675, 50.262889713048935, 55.11335603892803, 54.03776295483112, 54.331859573721886, 56.65578067302704, 52.00618676841259, 54.44630183279514, 49.70364712178707, 51.48898132145405, 52.13637538254261, 50.56582845747471, 48.456671833992004, 47.208286821842194, 39.18222449719906, 38.3582729101181, 38.95044453442097, 42.302415668964386, 42.772188261151314, 42.980249896645546, 40.04799664020538, 40.356163904070854, 44.81595039367676, 47.05045469105244, 46.34250707924366, 50.53945027291775, 51.556002125144005, 53.79457600414753, 53.8728442043066, 55.53568817675114, 53.73098261654377, 55.19542023539543, 51.0624124109745, 45.896927788853645, 41.81819245219231, 42.301043942570686, 44.72253240644932, 52.62649968266487, 56.08630143105984, 55.56002967059612, 58.27149197459221, 56.339687034487724, 56.20185703039169, 56.63219153881073, 55.40982373058796, 53.591305911540985, 55.36480754613876, 54.42003384232521, 56.18641085922718, 56.89552120864391, 61.470908895134926, 54.478493705391884, 53.18360298871994, 22.641009092330933, 7.724068304523826, 3.1439251732081175, 1.3358426629565656, 5.192656489089131, 44.999602138996124, 58.10532309114933, 51.93083681166172, 53.28780859708786, 52.377844825387, 56.200306713581085, 57.29495957493782, 58.663581535220146, 46.44465319812298, 27.947870828211308, 37.192039489746094, 39.42269839346409, 27.871582321822643, 0.5711336375679821, 0.18940232112072408, 0.08466488230624236, 0.12146886874688789, 0.0691861382802017, 0.020747638154716697, 0.046671452073496766, 0.048254623761749826, 0.04004506037745159, 0.03497993959172163, 0.026309472814318724, 0.07861141377361491, 0.07500613457523286, 0.1336536422604695, 0.053475146560231224, 0.034755592059809715, 0.054628930156468414, 0.06807103913160972, 0.01992377445276361, 0.05481053740368225, 0.02170135914639104, 0.5903051525820047, 0.1835668584681116, 12.497594933956861, 63.034901171922684, 47.591674849390984, 31.00183915346861, 45.80929309129715, 49.85657751560211, 74.84558701515198, 53.15836474299431, 50.91447874903679, 52.40276388823986, 62.26218223571777, 64.87154021859169, 58.2563041895628, 52.905332520604134, 13.278431184589863, 1.6522092930972576, 4.591914424672723, 1.0317817912437022, 21.151553615927696, 60.102891102433205, 60.20019248127937, 61.58153235912323, 63.91793578863144, 63.80586460232735, 61.56722232699394, 62.666906118392944, 60.901266261935234, 61.314171105623245, 59.67576362192631, 60.33881664276123, 61.064908280968666, 61.98398016393185, 59.95784908533096, 59.6505443751812, 59.44583795964718, 60.34508630633354, 58.694793060421944, 59.64279659092426, 57.440176382660866, 59.28056202828884, 60.1692583411932, 60.48555336892605, 58.996804654598236, 58.4272114187479, 58.78358669579029, 61.39915734529495, 58.65074202418327, 53.060322403907776, 49.845193326473236, 48.79853568971157, 43.6683663725853, 44.43733111023903, 44.311512261629105, 43.53653244674206, 41.616229489445686, 39.73290614783764, 41.997197046875954, 46.135190203785896, 50.56878849864006, 52.571372240781784, 53.46651680767536, 53.60504597425461, 54.79579567909241, 56.56936191022396, 55.77916771173477, 54.14283111691475, 56.60192996263504, 56.40674203634262, 56.09078139066696, 48.473668321967125, 41.80606350302696, 38.7071929872036, 41.71542316675186, 42.54522643983364, 44.216988533735275, 49.867976903915405, 54.04130816459656, 45.43773002922535, 40.55621176958084, 41.91778130829334, 40.53524449467659, 41.389518454670906, 41.27248093485832, 50.45286811888218, 57.783354967832565, 56.313472241163254, 58.53051647543907, 57.1514792740345, 54.28712457418442, 56.30029454827309, 52.04759694635868, 55.51969103515148, 54.11024026572704, 55.23497611284256, 50.80329671502113, 47.22439035773277, 42.604708448052406, 40.32495237886906, 41.467380076646805, 45.13992100954056, 46.40627145767212, 44.13482554256916, 41.767297983169556, 44.53382693231106, 46.25641889870167, 49.57350790500641, 48.47562901675701, 50.95791041851044, 52.23481670022011, 55.64212046563625, 55.469039753079414, 56.77164405584335, 54.98640105128288, 56.01812168955803, 52.940602228045464, 46.30270801484585, 44.41987484693527, 43.37461933493614, 45.07652901113033, 54.0043019503355, 57.45553135871887, 57.343019396066666, 61.17642469704151, 59.328937232494354, 57.772308960556984, 58.240987211465836, 55.55371440947056, 55.70562645792961, 56.370944157242775, 59.27067495882511, 56.84195168316364, 58.10219585895538, 64.55470561981201, 57.67724946141243, 54.234873577952385, 26.032435409724712, 9.895856492221355, 3.063833308406174, 2.2286896593868732, 6.77766733802855, 50.63380680978298, 63.03375743329525, 58.08230772614479, 57.406673580408096, 58.44340234994888, 62.95481666922569, 63.49716156721115, 64.63171988725662, 53.545256182551384, 35.72383627295494, 28.08655958622694, 47.30203919112682, 35.842614099383354, 0.7434397260658443, 0.13934414862887934, 0.07058205868816003, 0.06383257437846623, 0.0578976194083225, 0.04079117483342998, 0.028294179792283103, 0.044587156298803166, 0.13650014967424795, 0.06507375699584372, 0.10214358815574087, 0.24641325959237292, 0.09390604580403306, 0.2604445262113586, 0.1057027948263567, 0.17344911466352642, 0.16735983750550076, 0.2554680104367435, 0.13955209840787575, 0.21929978480329737, 0.17367446038406342, 0.8423404034692794, 0.41820223443210125, 17.78229720890522, 73.10670912265778, 63.90361815690994, 38.111780136823654, 44.3748814612627, 55.952947586774826, 77.98082917928696, 64.34572443366051, 56.729215532541275, 58.88385571539402, 68.65502759814262, 70.91290444135666, 62.60810807347298, 56.99483647942543, 16.15560069680214, 4.738381365314126, 7.9759895615279675, 1.7633253056555986, 27.536294013261795, 64.25090432167053, 60.41868835687637, 62.70263560116291, 65.62263831496239, 66.09355464577675, 64.68288794159889, 63.93375054001808, 67.28571027517319, 61.96316868066788, 62.82260276377201, 61.80970251560211, 63.09904173016548, 64.48956191539764, 60.31780757009983, 62.903333231806755, 62.270982563495636, 64.07423660159111, 62.56261311471462, 61.03189565241337, 60.46153485774994, 62.73431830108166, 61.85791812837124, 62.31663331389427, 59.2996522039175, 61.61189652979374, 61.42169773578644, 64.48320105671883, 61.97195380926132, 56.40433296561241, 53.31476055085659, 51.59612417221069, 47.00339801609516, 45.96702262759209, 45.78401304781437, 46.42789609730244, 44.256871193647385, 42.134495079517365, 46.06828339397907, 49.76854003965855, 53.23318272829056, 57.163232043385506, 56.412893906235695, 54.79410856962204, 58.373208716511726, 57.604297176003456, 56.904819309711456, 57.80675031244755, 60.03927491605282, 59.37098577618599, 58.94076146185398, 47.99263693392277, 42.51814529299736, 38.115177154541016, 42.659193724393845, 42.7177219837904, 45.61293102800846, 53.7376968562603, 56.73705071210861, 51.11838720738888, 39.39969062805176, 40.873840525746346, 41.05197876691818, 41.360867992043495, 40.835998356342316, 53.836316764354706, 60.385649129748344, 57.1497617661953, 60.296673104166985, 61.03120408952236, 56.66992351412773, 58.94488804042339, 55.14260306954384, 57.515457943081856, 57.783499360084534, 56.33988842368126, 53.50472755730152, 52.74539530277252, 44.72811430692673, 44.6803280711174, 42.695534974336624, 47.36821264028549, 49.58580404520035, 47.021770030260086, 43.917405009269714, 46.92720830440521, 48.02192956209183, 52.08868034183979, 49.212401881814, 53.833007141947746, 53.975225910544395, 56.78708642721176, 56.76171898841858, 59.06332388520241, 56.17329016327858, 59.641588255763054, 54.81398530304432, 50.10478399693966, 44.357903972268105, 45.726890712976456, 47.82250106334686, 56.34505234658718, 58.404344245791435, 60.48926576972008, 64.10361662507057, 60.35099498927593, 61.127034947276115, 60.14933981001377, 58.23257826268673, 58.10924828052521, 58.85784991085529, 61.17110878229141, 59.73995737731457, 62.31822922825813, 66.21839314699173, 59.99159127473831, 56.16440623998642, 32.20571905374527, 15.790906716138124, 4.627934116870165, 2.9484418127685785, 6.743047395721078, 55.72953097522259, 68.84570136666298, 62.08799198269844, 62.28253394365311, 62.931664511561394, 68.57090011239052, 71.67879894375801, 69.97317686676979, 61.25797212123871, 40.31372778117657, 49.227050095796585, 55.309653505682945, 50.997500494122505, 0.9897023742087185, 0.2986671798862517, 0.17207315802806988, 0.23569308483274654, 0.14564302313374355, 0.1819402488763444, 0.09326667073764838, 0.1296047813957557, 0.14633451180998236, 0.20376552070956677], [0.03453103301580995, 0.04918694306979887, 0.04639827493519988, 0.11040755096473731, 0.020243831204425078, 0.1342138004838489, 0.05385236167057883, 0.03525316125887912, 0.009787219987629214, 0.042705693194875494, 0.04469877159863245, 0.26253343443386257, 0.39985203940887004, 2.495643859729171, 45.10112129151821, 46.93074211478233, 26.378317549824715, 27.19720020890236, 46.75086356699467, 59.94894236326218, 62.983022555708885, 59.7615098208189, 56.31207771599293, 56.42419449985027, 54.81343433260918, 49.53529715538025, 52.707374542951584, 27.606548443436623, 0.2869972342159599, 2.602545185945928, 0.4098214575788006, 10.023206658661366, 57.725206688046455, 55.58881692588329, 49.37657207250595, 53.64726550877094, 56.9555389881134, 64.58854660391808, 60.02483569085598, 58.88037510216236, 58.3422289788723, 59.53967772424221, 59.688538536429405, 55.970046669244766, 57.18540385365486, 57.86418043076992, 59.080601558089256, 56.91855937242508, 59.08728539943695, 56.10560059547424, 58.76495249569416, 54.76092495024204, 55.02251051366329, 50.43615281581879, 52.33394578099251, 52.80327379703522, 53.30129027366638, 51.727198138833046, 56.13612435758114, 53.31349901854992, 53.53800617158413, 46.21015638113022, 47.28340119123459, 42.753136083483696, 42.051727920770645, 41.61494515836239, 40.19522354006767, 39.34809699654579, 38.33079278469086, 37.979311645030975, 47.68203780055046, 48.921979665756226, 54.13665644824505, 52.14046396315098, 53.53478014469147, 51.98816433548927, 53.951344192028046, 54.09250281751156, 56.24183468520641, 53.41910295188427, 53.65146428346634, 50.621571466326714, 44.29108455777168, 43.74601140618324, 41.84257194399834, 43.09930130839348, 42.937167808413506, 44.97483506798744, 52.765405029058456, 43.31235207617283, 48.88400450348854, 43.402327448129654, 42.68697403371334, 41.10423356294632, 42.45485208928585, 41.666728779673576, 50.008626356720924, 54.17433142662048, 54.361193999648094, 54.67694565653801, 53.10466982424259, 52.80049994587898, 54.747291281819344, 50.257273614406586, 50.62217943370342, 52.42032654583454, 51.23572491109371, 48.48420895636082, 49.80895087122917, 42.718200758099556, 38.72317112982273, 40.19043579697609, 42.136854752898216, 41.81894101202488, 38.70654322206974, 39.71360698342323, 40.35574592649937, 44.71953436732292, 48.72185580432415, 44.96187016367912, 50.9234044700861, 50.98172374069691, 53.75791937112808, 54.20025363564491, 53.65744136273861, 52.8378177434206, 54.6664734184742, 51.577904149889946, 47.43907883763313, 41.58585771918297, 42.249256521463394, 45.638952031731606, 56.081034913659096, 54.55030605196953, 55.58080695569515, 53.18087853491306, 55.28733350336552, 54.148565009236336, 59.72235672175884, 54.28768314421177, 58.77487376332283, 56.32332131266594, 59.100409895181656, 56.927834674715996, 62.16034770011902, 55.32335937023163, 55.88546700775623, 44.095417857170105, 17.135799899697304, 3.360248515382409, 0.227319106052164, 1.4087689435109496, 9.591026399284601, 61.98167368769646, 53.187748566269875, 53.44849817454815, 58.29574227333069, 58.56917180120945, 59.42818410694599, 56.70421667397022, 59.42517466843128, 35.99335581064224, 29.413452185690403, 40.88229887187481, 43.91762539744377, 14.309845939278603, 0.8596794668119401, 0.06542197268572636, 0.25231320003513247, 0.048519826523261145, 0.08363115965039469, 0.02778231126285391, 0.11373663248377852, 0.014656459243269637, 0.05357420101063326, 0.018208006949862465, 0.08815691719064489, 0.028869437010143884, 0.05177678613108583, 0.043925360951106995, 0.05646449513733387, 0.09725088311824948, 0.0028775929649782483, 0.055949589368538, 0.004867513762292219, 0.05416364067059476, 0.1363504584878683, 0.5388287804089487, 0.21216275839833543, 3.838037489913404, 55.32570764422417, 53.060664385557175, 24.678201377391815, 43.124740943312645, 53.40576946735382, 66.73012688755989, 67.63508632779121, 61.0524183511734, 61.143799647688866, 61.791987866163254, 61.69900685548782, 55.279536321759224, 56.59673564136028, 29.863615930080414, 0.1640101391240023, 6.2341122049838305, 0.1637696981197223, 14.280514363199472, 60.27346394956112, 57.059558406472206, 50.42652413249016, 54.66045454144478, 59.442798122763634, 66.04238659143448, 64.20313328504562, 61.93667270243168, 61.7325172573328, 63.67906540632248, 61.32959447801113, 58.31051968038082, 60.54242491722107, 60.07118560373783, 60.105953738093376, 58.877513855695724, 62.26994901895523, 60.15291541814804, 61.627259105443954, 57.44394198060036, 57.119944766163826, 53.545909747481346, 53.844463527202606, 54.09058392047882, 56.086282432079315, 52.501254603266716, 57.256760224699974, 55.39793036878109, 56.40171870589256, 48.036649972200394, 49.03305910527706, 44.78706054389477, 44.15665917098522, 44.234497994184494, 41.762856021523476, 41.97909861803055, 40.980584397912025, 41.18500962853432, 51.06125347316265, 52.18776002526283, 54.57312382757664, 55.00931762158871, 54.47599343955517, 53.532591462135315, 56.10999695956707, 56.35807044804096, 57.50861831009388, 56.35941557586193, 57.60112814605236, 52.074526101350784, 43.435925245285034, 42.02545613050461, 41.77786901593208, 43.28787378966808, 45.2567533403635, 46.059255078434944, 52.24914193153381, 47.5109937787056, 50.91913729906082, 40.87716914713383, 43.90380173921585, 40.849605426192284, 42.45336256921291, 40.55485524237156, 50.61296112835407, 56.519105806946754, 59.2203276604414, 55.712842270731926, 55.444850251078606, 57.19858914613724, 55.6966133415699, 52.29402892291546, 52.93916590511799, 54.07364822924137, 53.60956393182278, 50.804524049162865, 51.3673460483551, 45.3262934088707, 41.50830388069153, 42.38146282732487, 44.487458020448685, 43.68522986769676, 43.45693051815033, 42.27565750479698, 43.543193489313126, 46.61148324608803, 50.61793506145477, 45.8392658829689, 52.089748084545135, 53.71829889714718, 54.56523925065994, 57.20072463154793, 54.8076206445694, 54.04043801128864, 56.10714711248875, 53.6545193195343, 49.17821131646633, 43.40357758104801, 45.520854368805885, 47.04062841832638, 57.90117904543877, 56.899818778038025, 57.975909635424614, 55.45694500207901, 56.913984417915344, 55.92563085258007, 61.05848282575607, 54.99355986714363, 61.13087274134159, 57.15798832476139, 61.539320424199104, 58.14408101141453, 65.52657186985016, 57.52984397113323, 56.9607675075531, 44.51700523495674, 22.231334075331688, 3.919515092857182, 0.24146163545083255, 1.2028137012384832, 10.761081464588642, 67.93737530708313, 58.493852242827415, 57.84108147025108, 60.53444914519787, 63.07810105383396, 64.18761491775513, 65.90995609760284, 64.89635288715363, 44.19472172856331, 36.69687286019325, 34.95941989123821, 54.79834534227848, 18.474962040781975, 0.7789868186227977, 0.09259553175070323, 0.13120220974087715, 0.0482629283942515, 0.0831254008517135, 0.07339649047935382, 0.024394334759563208, 0.0649297951895278, 0.018269404827151448, 0.03933898107788991, 0.19111098255962133, 0.21925804641796276, 0.12806804588763043, 0.2418346982449293, 0.16598815564066172, 0.21436334500322118, 0.14239219366572797, 0.19307629350805655, 0.1184056764759589, 0.18340751936193556, 0.2180773636791855, 0.7776748796459287, 0.5237622326239944, 5.078347222879529, 66.11705258488655, 69.34111878275871, 35.09531579911709, 39.65864673256874, 61.1704970151186, 69.75003764033318, 77.19731882214546, 68.79870548844337, 68.07949528098106, 65.99647745490074, 66.80741474032402, 61.19385436177254, 64.61084380745888, 34.30105201900005, 0.6106535950675607, 8.81494464352727, 0.798755792202428, 19.17482938617468, 65.50574898719788, 56.832881569862366, 53.403671979904175, 55.18111400306225, 62.20340698957443, 66.84517711400986, 65.58024778962135, 64.0393240749836, 64.27355110645294, 65.70121049880981, 65.79250440001488, 59.88149978220463, 64.16274905204773, 60.244201719760895, 61.88016973435879, 61.91356994211674, 63.45559559762478, 62.65511155128479, 63.74146945774555, 58.127168118953705, 58.34742709994316, 55.53577557206154, 57.606501057744026, 56.0265002399683, 58.13986323773861, 54.83095899224281, 60.71925602853298, 57.30936840176582, 59.33467112481594, 50.3992909938097, 52.47454583644867, 48.29114891588688, 46.075077429413795, 44.57869112491608, 45.30160993337631, 45.27529634535313, 43.70837442576885, 42.85752788186073, 54.124098122119904, 55.04097372293472, 59.45042431354523, 57.90774889290333, 58.00043351948261, 56.56033359467983, 59.81371521949768, 60.13343386352062, 61.64662666618824, 59.17260222136974, 57.62069329619408, 51.89620167016983, 43.59034515917301, 42.952226400375366, 42.74445354938507, 43.5920474678278, 45.30034840106964, 47.90035888552666, 54.307153299450874, 49.732042998075485, 55.37410564720631, 44.12088789045811, 43.00458759069443, 40.69868512451649, 43.803217336535454, 41.856369003653526, 52.20175087451935, 57.87772670388222, 59.97601971030235, 58.19134667515755, 56.49810433387756, 55.99930129945278, 59.90779057145119, 53.53028118610382, 54.31281499564648, 56.22590593993664, 56.44616112112999, 51.54285863041878, 55.94962276518345, 48.35399754345417, 42.42858029901981, 44.81137923896313, 48.14062759280205, 46.92665733397007, 43.75037357211113, 44.467588886618614, 44.73116174340248, 48.174206390976906, 52.441134229302406, 47.79585689306259, 54.994601011276245, 55.42977645993233, 57.18787372112274, 60.40296860039234, 56.446833685040474, 54.1883260756731, 58.591590598225594, 56.512999534606934, 51.412917003035545, 45.18761985003948, 47.83748745918274, 48.59768606722355, 59.95302714407444, 56.99298597872257, 58.949390798807144, 55.12651853263378, 58.153493106365204, 56.680395752191544, 65.2194495499134, 57.434472888708115, 63.408633917570114, 57.89782002568245, 62.279881685972214, 59.53531555831432, 68.36446478962898, 57.31220304965973, 57.72077992558479, 45.543630346655846, 29.550554528832436, 6.778161311522126, 1.1143375863321126, 4.081267900764942, 11.531259287148714, 72.71945670247078, 63.14464308321476, 63.27996902167797, 67.87006571888924, 68.2866981625557, 69.53784942626953, 67.15552166104317, 71.88421592116356, 49.512920156121254, 43.720484375953674, 55.226920545101166, 65.57553604245186, 29.29917521774769, 1.1148895067162812, 0.17494920291937888, 0.2772641455521807, 0.2291604783385992, 0.22376359527697787, 0.15995128895156085, 0.20970645738998428, 0.19194344960851595, 0.08958028221968561, 0.12338760992861353], [0.023106936750991736, 0.03650018457847182, 0.1011246936104726, 0.059104589017806575, 0.04642356732802, 0.0661346570996102, 0.05326265854819212, 0.039121657973737456, 0.12034723127726465, 0.09658021910581738, 0.07689257749007083, 0.11163028379087336, 0.3985486796591431, 0.3316585533320904, 32.72331587970257, 56.02203167974949, 39.85440082848072, 27.505133785307407, 36.49388775229454, 54.84017729759216, 57.90708012878895, 56.75385341048241, 58.13228264451027, 52.213898822665215, 58.59886720776558, 51.44526466727257, 59.22163479030132, 41.20976150035858, 2.1747382543981075, 4.670529356226325, 0.19204170996090397, 2.6319691445678473, 36.875717863440514, 56.64976179599762, 56.468735709786415, 58.39707903563976, 59.92645896971226, 60.24859428405762, 58.233775198459625, 60.03116995096207, 59.80775713920593, 57.4935407191515, 57.49857924878597, 55.177492797374725, 55.380819886922836, 57.15680658817291, 56.18485674262047, 58.36345084011555, 59.63787205517292, 57.83875599503517, 57.308863028883934, 59.67176243662834, 57.478987500071526, 58.82584422826767, 57.94993802905083, 52.584553733468056, 53.04771088063717, 54.1492185741663, 56.259826719760895, 57.91004776954651, 54.40919302403927, 49.281322583556175, 46.23076267540455, 45.177709981799126, 42.96146370470524, 40.45059263706207, 41.21811345219612, 40.22360801696777, 38.17834496498108, 42.77810834348202, 49.77325178682804, 51.68593615293503, 52.37363085150719, 51.602401435375214, 52.68711023032665, 52.54293076694012, 53.566386848688126, 52.09395445883274, 53.53983387351036, 55.6484205275774, 49.53034222126007, 43.67397867143154, 42.3849206417799, 41.594027280807495, 44.01867717504501, 42.70814649760723, 45.01114971935749, 45.698730424046516, 50.693775191903114, 47.55350969731808, 41.837107837200165, 47.678302600979805, 43.18302981555462, 41.041346937417984, 43.786711022257805, 42.01940305531025, 43.77172462642193, 53.232160583138466, 53.36578421294689, 54.987654983997345, 53.30392353236675, 54.886158630251884, 53.875587657094, 53.2387950271368, 50.38306586444378, 52.37037442624569, 50.84759093821049, 49.16758328676224, 50.30172362923622, 46.56104475259781, 40.797563418745995, 40.62935784459114, 38.85215900838375, 41.43502861261368, 40.10171435773373, 39.66617412865162, 41.23263627290726, 45.06547540426254, 48.37399587035179, 46.46573446691036, 51.237415820360184, 51.261419132351875, 52.12651491165161, 54.49018947780132, 55.22556021809578, 55.264306738972664, 54.649286940693855, 51.72233060002327, 47.6159593462944, 42.663593888282776, 41.84070244431496, 42.6492078602314, 50.31584367156029, 55.25871343910694, 54.83199633657932, 57.9975912719965, 55.2129714936018, 55.411887019872665, 56.25576093792915, 55.95715396106243, 58.78705970942974, 55.76035112142563, 60.48840321600437, 57.299808114767075, 61.169087290763855, 51.7599181830883, 49.42455969750881, 43.994582667946815, 6.557922279462218, 0.042902184213744476, 0.1762185723055154, 0.3330306359566748, 12.924047000706196, 58.07852312922478, 50.78044854104519, 54.26487296819687, 56.054896116256714, 54.24347251653671, 56.810200586915016, 53.613181337714195, 49.62110035121441, 30.252620056271553, 27.7627257630229, 34.61009323596954, 35.90448997914791, 1.637891186401248, 0.2708963700570166, 0.1278917264426127, 0.12637982319574803, 0.05174845093279146, 0.07880685094278306, 0.03251409827498719, 0.024596384464530274, 0.09195766324410215, 0.11010508125764318, 0.1045669823361095, 0.021302859240677208, 0.024734049147809856, 0.04167574807070196, 0.007412525073959841, 0.050677576364250854, 0.03776081888645422, 0.015662791083741467, 0.025061510677915066, 0.027435878582764417, 0.1232645618438255, 0.019144890466122888, 0.11418106019846164, 0.3994451940525323, 0.5340320721734315, 39.338692501187325, 66.19978174567223, 31.04820616543293, 32.06094682216644, 51.9196692109108, 55.27778461575508, 67.242331802845, 61.56402289867401, 64.9973438680172, 56.60676330327988, 65.95575124025345, 55.533404499292374, 66.05774536728859, 45.98989740014076, 2.5862165121361613, 4.500745916739106, 0.34564601839520037, 3.6256239004433155, 43.139328360557556, 59.360194355249405, 62.17021197080612, 62.374663800001144, 63.03814239799976, 62.141728699207306, 59.86517205834389, 62.6009264588356, 60.98305307328701, 57.933883890509605, 60.23971036076546, 57.660891339182854, 58.806742653250694, 59.492355063557625, 56.819323897361755, 60.86981534957886, 61.62220157682896, 59.85324829816818, 59.35447186231613, 61.59087225794792, 58.811955973505974, 60.49430809915066, 58.94719071686268, 53.768296614289284, 55.517962127923965, 55.005928203463554, 58.5848193615675, 59.63544778525829, 56.82915396988392, 52.3992794752121, 48.59142020344734, 47.22837634384632, 45.033956095576286, 41.86718702316284, 41.68265752494335, 41.329842656850815, 41.07846334576607, 44.060379937291145, 52.01515048742294, 52.663787081837654, 54.468504041433334, 53.75748999416828, 53.691111356019974, 54.72826950252056, 55.72219356894493, 53.661852926015854, 55.014606937766075, 57.175148203969, 51.09463848173618, 43.44064839184284, 42.90364980697632, 42.39562086760998, 45.35645619034767, 43.578223809599876, 45.15475921332836, 47.02021211385727, 51.34268157184124, 49.83219802379608, 46.759804487228394, 48.33612710237503, 43.20448726415634, 41.00564405322075, 42.19767048954964, 43.453582897782326, 43.973942175507545, 52.63628415763378, 57.49227158725262, 57.701488360762596, 55.06671354174614, 56.77324377000332, 56.84427335858345, 55.84631010890007, 55.29146008193493, 56.39878146350384, 52.51254379749298, 51.34910702705383, 53.66173133254051, 47.25427955389023, 43.56387197971344, 42.611225098371506, 42.281285002827644, 44.1267965734005, 41.56681314110756, 41.92706041038036, 42.30538330972195, 47.13272027671337, 50.70993572473526, 48.133198991417885, 51.851014494895935, 52.240311205387115, 53.80364611744881, 56.268615648150444, 55.224963650107384, 58.10981824994087, 55.843251273036, 53.37526090443134, 48.86392258107662, 44.23059180378914, 44.18474726378918, 45.75327269732952, 52.236940786242485, 56.381724178791046, 57.005285918712616, 60.791383758187294, 56.685928255319595, 56.9019428640604, 56.97875194251537, 57.47551068663597, 60.06565310060978, 57.91193626821041, 62.59136237204075, 60.13200134038925, 62.07704856991768, 55.2816604077816, 48.85633818805218, 47.101371958851814, 8.050576709210873, 0.09952459353371523, 1.1368132615461946, 0.34224315255414695, 14.87930428236723, 65.76146006584167, 55.136485397815704, 61.54493272304535, 60.19758582115173, 62.75020144879818, 61.02196678519249, 65.7315556704998, 52.3580364882946, 45.78374706208706, 31.42235118895769, 34.3621451407671, 47.86721706390381, 2.430297341197729, 0.1971739431610331, 0.10176616895478219, 0.05438758002128452, 0.10862045193789527, 0.026834544150915463, 0.008798419530648971, 0.04532317383564077, 0.1050644216593355, 0.008788223349256441, 0.14376852137502283, 0.13242590735899284, 0.11231619893806055, 0.15977226808900014, 0.28122893592808396, 0.18105430266587064, 0.16045060590840876, 0.10581263268250041, 0.09508398259640671, 0.191314316180069, 0.21513031009817496, 0.22510158363729715, 0.1534558046841994, 0.5507331853732467, 0.9300056181382388, 45.66849924623966, 77.42276832461357, 54.209422543644905, 38.766230419278145, 50.09485512971878, 64.62313234806061, 70.77180281281471, 68.87545377016068, 70.06910651922226, 63.53095315396786, 69.87372860312462, 62.12308309972286, 69.25989434123039, 49.9336601793766, 3.302282150834799, 10.474726930260658, 0.8528378745540977, 7.087862268090248, 50.32390683889389, 60.34234665334225, 63.83643016219139, 64.73730862140656, 67.67403423786163, 64.88486230373383, 61.64506494998932, 63.80907163023949, 61.201613545417786, 61.34570561349392, 61.90316990017891, 57.89532735943794, 61.01879395544529, 62.11397498846054, 56.5080825984478, 63.83589059114456, 62.818875163793564, 61.16648443043232, 60.935285836458206, 64.55073863267899, 60.557719096541405, 61.951624900102615, 62.32556663453579, 57.70708166062832, 58.66179943084717, 57.90267616510391, 61.41273781657219, 62.62235350906849, 60.13660669326782, 54.504708498716354, 51.3923829048872, 50.946442633867264, 49.1071817278862, 43.42939339578152, 46.01782590150833, 44.30536039173603, 43.40083032846451, 47.98547811806202, 56.899089217185974, 56.73164360225201, 58.71706746518612, 56.723375245928764, 59.3695380538702, 56.79374746978283, 58.0661927908659, 55.771864503622055, 57.61126980185509, 58.52028362452984, 50.404131934046745, 43.89717109501362, 42.758862376213074, 41.59721910953522, 47.39623613655567, 44.78785090148449, 45.68920433521271, 49.81606028974056, 53.57098080217838, 52.26090990006924, 48.01888592541218, 51.644233390688896, 44.85332898795605, 41.17374703288078, 43.65351676940918, 41.95860631763935, 43.401582688093185, 54.06699098646641, 58.3060435205698, 60.92442221939564, 55.80621086061001, 58.53800967335701, 59.75274749100208, 59.15708005428314, 58.491484969854355, 59.45405691862106, 56.30646541714668, 53.76879818737507, 56.38037145137787, 51.74868978559971, 45.89634642004967, 45.041783675551414, 42.98755690455437, 45.63650116324425, 44.23505276441574, 43.146323785185814, 45.737077966332436, 48.70379537343979, 54.63258683681488, 50.526302978396416, 55.28527781367302, 53.19286309182644, 54.128456488251686, 58.7357434630394, 56.32492482662201, 59.69481199979782, 58.02257113158703, 56.60046324133873, 51.996569484472275, 45.63040629029274, 46.21503531932831, 48.039085641503334, 54.668760895729065, 58.408581018447876, 59.56130616366863, 61.309736743569374, 57.60449856519699, 57.97084450721741, 59.239524230360985, 59.40413899719715, 61.908740401268005, 57.650061920285225, 64.16733920574188, 60.52586540579796, 64.58326488733292, 53.88623088598251, 50.804113671183586, 49.86978940665722, 15.086113885045052, 0.12042169095366262, 1.5339706814847887, 1.0407374356873333, 16.22174184769392, 69.27526071667671, 60.45656472444534, 64.90446165204048, 64.97636139392853, 67.42358207702637, 68.13211485743523, 67.53696799278259, 64.50176686048508, 43.50752480328083, 38.95933985710144, 47.545104548335075, 62.01681800186634, 5.207240581512451, 0.6586413981858641, 0.21752263797679916, 0.21357831603381783, 0.2742306614527479, 0.17620877595618367, 0.1818035452743061, 0.14094061218202114, 0.13904156017815694, 0.1269410055829212, 0.2576368331210688], [0.018032104962912854, 0.040342572538065724, 0.06899820422404446, 0.024452166617265902, 0.04774816734425258, 0.03241963029722683, 0.02683796174096642, 0.0320954045309918, 0.08268941877759062, 0.03293905574537348, 0.14169209607644007, 0.06499276641989127, 0.6256520433817059, 0.26198255305644125, 9.804971069097519, 53.000403419137, 32.78249390423298, 33.423219323158264, 28.66105265915394, 54.968291223049164, 61.31725654006004, 55.93032360076904, 59.134847447276115, 55.06036028265953, 58.189355581998825, 50.15615724027157, 53.49074050784111, 41.641163751482964, 4.340817723423243, 5.320843085646629, 0.5937313812319189, 0.33801757148467004, 23.221002370119095, 63.874017745256424, 57.879774793982506, 59.73105065524578, 57.16219089925289, 59.15590971708298, 59.62339103221893, 63.490029349923134, 59.26055230200291, 58.87316308915615, 58.23656424880028, 59.95334632694721, 59.3483579903841, 57.815220057964325, 57.50848911702633, 57.52396568655968, 56.538203582167625, 54.959965869784355, 59.47073042392731, 60.71779690682888, 56.07836365699768, 57.34125629067421, 56.5442718565464, 57.584906816482544, 57.22293063998222, 57.55522660911083, 56.94378241896629, 55.46558953821659, 54.94528345763683, 51.42071418464184, 48.877130672335625, 45.224230885505676, 41.5245708078146, 41.80250309407711, 39.83966141939163, 38.47821347415447, 38.77651646733284, 42.233460769057274, 50.85888773202896, 53.34959328174591, 52.85614416003227, 52.8963840007782, 52.085279524326324, 54.17320668697357, 53.869245797395706, 54.11321550607681, 53.519463166594505, 50.422997921705246, 42.61121369898319, 41.401677802205086, 41.81264474987984, 44.582753106951714, 43.025912046432495, 42.58710019290447, 47.108910754323006, 44.766005873680115, 45.18667750060558, 48.45776617527008, 40.62669038772583, 40.02856828272343, 43.775486424565315, 43.27070251107216, 41.55908055603504, 43.706995099782944, 43.25675345957279, 42.71899871528149, 50.85282325744629, 55.25071866810322, 53.109826147556305, 53.851246163249016, 53.07900220155716, 52.7311422675848, 51.87427304685116, 52.19013869762421, 51.42141334712505, 50.56099511682987, 49.10269416868687, 48.46554435789585, 43.14487226307392, 40.699232295155525, 40.29819421470165, 40.84271639585495, 39.89938661456108, 39.60843622684479, 41.636474803090096, 45.64269483089447, 46.57680630683899, 49.27858293056488, 52.77881070971489, 54.39020924270153, 52.31371566653252, 55.47970578074455, 54.828679114580154, 52.68896833062172, 54.7741786390543, 53.907471746206284, 48.18386547267437, 48.53607997298241, 45.29999502003193, 41.48309223353863, 42.30707801878452, 48.58952410519123, 51.666021421551704, 54.25776734948158, 54.66086491942406, 55.06762929260731, 56.853050887584686, 57.03704081475735, 56.16628333926201, 56.58478528261185, 58.192023038864136, 57.43632338941097, 57.202806919813156, 59.826444536447525, 51.58247530460358, 34.26808498799801, 1.952596118208021, 0.396382202161476, 0.4864027560688555, 0.21182340395171195, 19.818478748202324, 59.127198457717896, 52.55495712161064, 54.7408202290535, 54.34613540768623, 57.68533542752266, 58.49284529685974, 54.86808679997921, 42.4115914106369, 20.018367022275925, 26.13176967948675, 41.19461551308632, 19.846177361905575, 0.30969501938670874, 0.1366908074123785, 0.05991901816742029, 0.12231076107127592, 0.02304366495081922, 0.15081761812325567, 0.01401569728841423, 0.038701231314917095, 0.050340901070740074, 0.03936940171115566, 0.017459124283050187, 0.06531618695589714, 0.02838567175786011, 0.0267303169312072, 0.07457665371475741, 0.05230723989370745, 0.049808784897322766, 0.07049915337120183, 0.05935129003773909, 0.14667448966065422, 0.020714171005238313, 0.15416863752761856, 0.05824841406138148, 0.6493774952832609, 0.2319087105570361, 14.334439169615507, 61.38938806951046, 34.93769645690918, 23.834773935377598, 45.58754839003086, 58.56585077941418, 66.56675085425377, 60.333143547177315, 65.40060862898827, 59.900886341929436, 65.51435932517052, 56.44657529890537, 59.5299806445837, 47.68693953752518, 3.784997323527932, 2.6974215824157, 0.748092932626605, 0.3688252199208364, 26.835583113133907, 66.17606341838837, 62.295411452651024, 62.90988028049469, 60.31785696744919, 62.116585448384285, 62.455356270074844, 64.62839886546135, 61.44619882106781, 60.694048181176186, 59.925832003355026, 62.38927781581879, 61.66983962059021, 59.304952919483185, 60.480233654379845, 59.62993048131466, 58.84339548647404, 58.3198481798172, 60.98200432956219, 60.81498809158802, 58.08417722582817, 59.79739509522915, 58.09173122048378, 59.06780004501343, 60.44211409986019, 60.796289294958115, 58.96779701113701, 57.729074880480766, 56.56152293086052, 51.98205046355724, 50.49022391438484, 46.71099230647087, 42.13725373148918, 44.09603722393513, 42.711535915732384, 40.71956120431423, 41.0330405831337, 45.64412735402584, 53.43346618115902, 55.96413038671017, 55.08735403418541, 54.63969625532627, 54.582725912332535, 55.57308956980705, 55.03429748117924, 55.741637125611305, 55.925060883164406, 50.86676850914955, 41.469523161649704, 39.512263387441635, 41.39936752617359, 44.233726635575294, 42.28441223502159, 44.643622040748596, 48.2810452580452, 47.70189933478832, 48.3643139898777, 50.38318745791912, 42.596037313342094, 42.608918622136116, 45.515648648142815, 42.4655257165432, 41.12630657851696, 43.59287962317467, 40.66604867577553, 43.030980974435806, 53.06813098490238, 57.587540075182915, 55.523502230644226, 55.3717839717865, 55.354817882180214, 53.43657061457634, 54.384030774235725, 54.51163932681084, 54.755688831210136, 53.455508798360825, 52.73749552667141, 51.18532061576843, 45.554159581661224, 42.79310613870621, 42.24869795143604, 42.591785341501236, 42.35753171145916, 41.332088336348534, 42.15183734893799, 46.54888540506363, 48.466087728738785, 51.252029836177826, 53.60834039747715, 55.53877741098404, 53.03707905113697, 56.794568225741386, 56.85719646513462, 55.126393139362335, 56.277757957577705, 55.37874519824982, 52.11391098797321, 49.70712773501873, 45.47088325023651, 42.048520892858505, 42.24934011697769, 49.73260156810284, 54.32498574256897, 56.17414511740208, 57.746352553367615, 57.62421950697899, 58.48446674644947, 58.764150738716125, 57.91315600275993, 61.50368973612785, 59.867725521326065, 57.88343779742718, 61.97409309446812, 63.12430277466774, 56.68871350586414, 38.54539006948471, 2.604922908358276, 0.6264609843492508, 1.2407197547145188, 0.015000754538050387, 21.438607312738895, 63.42143923044205, 57.16856315732002, 59.67972680926323, 59.44977454841137, 63.48437525331974, 67.2497946023941, 60.086213797330856, 48.542140647768974, 29.410674534738064, 23.24253011494875, 49.64237540960312, 28.06996777653694, 0.32618984521832317, 0.05545411302591674, 0.02076013963232981, 0.05448818556033075, 0.0709278327121865, 0.042942152576870285, 0.08631911463453434, 0.03193412099790294, 0.03462164182565175, 0.05003225669497624, 0.017631313676247373, 0.14332948165247217, 0.1724520541029051, 0.11644541213172488, 0.27256338216830045, 0.17231637466466054, 0.14395233651157469, 0.11395582580007613, 0.13562830426963046, 0.4014594719046727, 0.13913354196120054, 0.33601620700210333, 0.13612699782242998, 0.817815747577697, 0.5685642035678029, 16.327051296830177, 74.69140648841858, 48.004784882068634, 43.357660844922066, 44.7515856474638, 65.67773535847664, 71.67684584856033, 67.42281451821327, 69.79478403925896, 67.66735419631004, 68.19454550743103, 62.43181653320789, 63.74086149036884, 52.545355036854744, 5.7382958102971315, 13.04580956697464, 1.8625130457803607, 0.9742542437743396, 33.93648438155651, 67.68322214484215, 65.15791565179825, 65.84250971674919, 63.98057162761688, 64.34258580207825, 65.65749004483223, 68.33055540919304, 63.490253537893295, 62.239296063780785, 64.03060734272003, 65.3715705871582, 65.19189342856407, 62.64775514602661, 62.597096264362335, 62.953695729374886, 62.44541980326176, 59.886728301644325, 66.08008816838264, 63.69002781808376, 59.26759712398052, 63.644057884812355, 60.65318517386913, 61.32377319037914, 63.82107138633728, 62.89536125957966, 60.97823493182659, 60.749631598591805, 59.40244808793068, 56.4242172986269, 55.71734502911568, 49.31932434439659, 45.50650253891945, 46.48262456059456, 45.14747120440006, 43.910724967718124, 45.09463123977184, 48.26617665588856, 57.55482003092766, 58.52645069360733, 58.0453547090292, 56.90481171011925, 57.22300283610821, 58.68739105761051, 58.83696623146534, 59.91279490292072, 57.896436899900436, 51.44309118390083, 42.49915771186352, 40.62463849782944, 42.67593562602997, 44.907358288764954, 44.059410989284515, 44.74651671946049, 51.38265162706375, 49.456094205379486, 49.137412905693054, 51.371567621827126, 45.51970303058624, 44.555527567863464, 50.82970529794693, 45.2856469899416, 40.20807825028896, 42.81284607946873, 41.77488997578621, 42.27803237736225, 51.60404294729233, 58.97076465189457, 58.094299882650375, 58.07835973799229, 58.2122303545475, 56.11740656197071, 55.757345482707024, 57.54088997840881, 59.056693241000175, 56.98851741850376, 55.940488055348396, 54.4907708466053, 49.52346459031105, 46.36704996228218, 44.80950213968754, 44.9045654386282, 45.25168061256409, 44.73298944532871, 45.19660636782646, 49.122312515974045, 49.720928594470024, 52.605407014489174, 56.498887091875076, 58.152018785476685, 55.29003895819187, 60.609890297055244, 57.012942507863045, 55.93748241662979, 58.80788639187813, 56.575547978281975, 50.499624609947205, 51.99516735970974, 48.103135004639626, 42.08906851708889, 43.266712725162506, 52.44263134896755, 56.651927679777145, 59.582239240407944, 60.867121294140816, 58.69056388735771, 61.31602920591831, 60.99503003060818, 61.19909048080444, 62.91601315140724, 61.577968150377274, 60.87361894547939, 64.49671313166618, 64.56083849072456, 56.23281016945839, 44.12023812532425, 5.0511278584599495, 1.0821003536693752, 2.2647057892754674, 0.5191266594920307, 23.13350636512041, 70.99229738116264, 62.4134711176157, 64.5347110927105, 64.73703503608704, 67.62960702180862, 71.22416093945503, 65.60881465673447, 56.72427199780941, 32.0059447735548, 36.57559856772423, 57.143902480602264, 39.390734508633614, 0.4373143776319921, 0.14805081736994907, 0.11850856040837243, 0.20798093435587361, 0.12331899095443077, 0.23233566811541095, 0.15814610378583893, 0.1001380082743708, 0.17094399518100545, 0.1400248464778997, 0.17403910722350702], [0.032906597916735336, 0.022357259986165445, 0.08129124224069528, 0.014643124704889487, 0.05086793353257235, 0.03327863283629995, 0.02540275760111399, 0.11695053268340416, 0.053482527218875475, 0.026824204178410582, 0.11614044880843721, 0.050097869971068576, 0.27784812671598047, 0.3606287034926936, 1.6234741662628949, 50.37670120596886, 47.32629328966141, 44.539389833807945, 30.190846771001816, 42.73191422224045, 65.36253467202187, 55.66161721944809, 58.07264484465122, 56.06395862996578, 60.283408015966415, 53.75701881945133, 55.24976871907711, 48.02703268826008, 4.657678920775652, 1.2880374281667173, 2.006934746168554, 0.22508414316689596, 14.869066681712866, 64.10897433757782, 55.35505726933479, 52.99852631986141, 47.34339997172356, 56.23588800430298, 57.04225413501263, 58.50462086498737, 57.40594781935215, 62.25976936519146, 59.745280891656876, 60.227334424853325, 54.87652614712715, 55.60327135026455, 55.77586568892002, 55.973158702254295, 54.8232302069664, 55.13400413095951, 52.98472926020622, 56.344926953315735, 56.2230408936739, 59.04048331081867, 57.72282041609287, 53.286835849285126, 57.19331122934818, 58.36890734732151, 58.707640171051025, 56.3071645796299, 55.38071729242802, 53.63584332168102, 46.558126509189606, 46.74384154379368, 43.629091680049896, 41.864454969763756, 41.17025502026081, 40.34910388290882, 38.36827017366886, 40.06719321012497, 49.88235913217068, 54.31449830532074, 52.34806962311268, 53.72546151280403, 51.78172141313553, 51.40830785036087, 56.188816130161285, 50.49585901200771, 45.79163543879986, 45.40162816643715, 41.96127377450466, 44.7424091398716, 43.92449922859669, 41.90201595425606, 44.39869478344917, 41.793425381183624, 41.649413108825684, 41.71831861138344, 41.69949062168598, 41.749005764722824, 41.50286637246609, 41.16262502968311, 37.83325508236885, 42.238100320100784, 45.050728395581245, 42.01021134853363, 42.752809301018715, 43.988673985004425, 42.04331137239933, 47.589565962553024, 55.487046986818314, 54.5174416154623, 52.87259727716446, 51.87390826642513, 51.332129538059235, 51.8901713937521, 52.53735266625881, 51.6753651201725, 51.49592734873295, 48.714503198862076, 43.50274845957756, 41.62536419928074, 39.30710859596729, 39.991676062345505, 39.190401658415794, 40.27472287416458, 41.165558472275734, 45.12064464390278, 48.62886719405651, 54.37995359301567, 53.84196326136589, 52.588307932019234, 54.671933725476265, 55.75141400098801, 51.01882874965668, 55.09411387145519, 53.80838066339493, 52.452727407217026, 51.6736476123333, 54.40969459712505, 48.65550756454468, 48.342237174510956, 42.714837938547134, 41.93057522177696, 41.511457711458206, 46.8460788577795, 50.71342773735523, 53.41280668973923, 51.28026232123375, 56.61590561270714, 57.88072094321251, 56.53695724904537, 54.88420933485031, 56.79361827671528, 53.783586993813515, 56.14591263234615, 53.71136426925659, 37.76288665831089, 2.671255236491561, 0.6821826787199825, 1.3880357122980058, 0.03985420225944836, 26.947262920439243, 58.54199565947056, 49.451154470443726, 55.50131522119045, 54.38664883375168, 57.442422062158585, 51.629911959171295, 58.67607146501541, 31.079115606844425, 31.38437982648611, 42.6802483946085, 40.441856905817986, 11.091337893158197, 0.3925406082998961, 0.09977289388189092, 0.18752295087324455, 0.13371884735533968, 0.10550626670010388, 0.07107200231985189, 0.061593325590365566, 0.035447177215246484, 0.13130633305991068, 0.003989848528362927, 0.03762860898859799, 0.029493857800844125, 0.04411234876897652, 0.007335808340940275, 0.01606888687092578, 0.035211845897720195, 0.03582357596314978, 0.04067447953275405, 0.0632151000900194, 0.04530532147327904, 0.06689270900096744, 0.05988969591271598, 0.07856397569412366, 0.41236708348151296, 0.36031919822562486, 3.277604612521827, 56.3878608494997, 51.307655051350594, 39.67870205640793, 43.46785493195057, 55.06753049790859, 66.93158447742462, 62.37553395330906, 62.34070122241974, 64.59581941366196, 64.64457839727402, 58.559512719511986, 59.07131485641003, 53.84244583547115, 4.742523618042469, 2.4131918465718627, 1.2710935436189175, 0.19686997431563213, 19.6343482285738, 69.2713089287281, 58.860802352428436, 56.8696141988039, 50.8512007445097, 56.90753236413002, 59.19648393988609, 62.8400894254446, 59.337718561291695, 62.76366412639618, 61.531774029135704, 61.08981594443321, 58.23910631239414, 59.504104033112526, 56.73962317407131, 58.0342935025692, 58.078709319233894, 58.22861887514591, 55.61804875731468, 58.46102960407734, 59.79982316493988, 60.78608684241772, 58.12726691365242, 56.66954733431339, 59.23271879553795, 59.77813012897968, 61.072162091732025, 60.31532630324364, 58.01940970122814, 55.856998935341835, 48.93176034092903, 48.970772847533226, 43.58036309480667, 43.93345534801483, 43.30055370926857, 41.12164422869682, 41.242299154400826, 42.55703620612621, 50.29762364923954, 56.046734154224396, 53.56209307909012, 54.293785616755486, 53.17956380546093, 53.69043119251728, 56.6059273481369, 53.473003059625626, 45.882503762841225, 44.64287348091602, 41.642022505402565, 44.84564960002899, 44.573329612612724, 42.08399958908558, 46.27983324229717, 44.21756610274315, 45.53940497338772, 44.37961220741272, 43.89212876558304, 44.15610060095787, 43.17780889570713, 43.41371923685074, 43.160671815276146, 46.69293187558651, 43.359108567237854, 43.71318876743317, 43.01307253539562, 42.48235501348972, 42.341188788414, 50.10189615190029, 57.50456012785435, 56.27557687461376, 55.37368007004261, 54.077672213315964, 53.65766555070877, 54.15297657251358, 55.89929446578026, 54.86984230577946, 53.14394451677799, 51.670721769332886, 45.08905313909054, 41.81795686483383, 40.35875156521797, 42.085565105080605, 41.13361358642578, 41.570343151688576, 42.592229917645454, 47.4899011105299, 48.83923150599003, 54.97786670923233, 55.13295538723469, 54.320042207837105, 55.61593607068062, 55.79395271837711, 52.849809899926186, 55.31759887933731, 55.735196471214294, 54.65632416307926, 54.01741124689579, 55.272153317928314, 50.94831593334675, 50.7449546456337, 44.64918874204159, 43.31357181072235, 43.497238755226135, 49.246360659599304, 53.77323254942894, 54.559452161192894, 54.56661857664585, 59.06747706234455, 59.75558213889599, 58.03225681185722, 58.12387749552727, 59.86763432621956, 55.348723009228706, 58.70363898575306, 57.10548274219036, 41.428998336195946, 3.3207555720582604, 1.5060464548878372, 1.986637304071337, 0.08568589939386584, 29.9687372893095, 65.03668695688248, 55.16887106001377, 61.58405922353268, 63.54317709803581, 62.716162875294685, 58.81221055984497, 60.7667800784111, 38.99602308869362, 35.162044018507004, 34.93818663060665, 50.026918575167656, 14.056768119335175, 0.4070921352831647, 0.08785455138422549, 0.15076262498041615, 0.1313886372372508, 0.029292169892869424, 0.021058976526546758, 0.014671286426164443, 0.053527787094935775, 0.04674151823564898, 0.052566416416084394, 0.03928212514438201, 0.10097606369527057, 0.11075476475525647, 0.20545044826576486, 0.0991216444526799, 0.10404749380541034, 0.1328693109098822, 0.13720947958063334, 0.20555040071485564, 0.08460433047730476, 0.22282831108896062, 0.21413529786514118, 0.14896903216140345, 0.5467423901427537, 0.369693503016606, 4.04216562397778, 66.83190062642097, 65.16132026910782, 54.65202659368515, 44.535555839538574, 56.32129602134228, 71.66284739971161, 67.47764557600021, 68.23978587985039, 68.6105927824974, 70.06190970540047, 64.85356718301773, 65.46251490712166, 62.41311773657799, 5.410682139918208, 4.942343020811677, 4.998947158455849, 0.18782004743115976, 24.45190642029047, 75.24535596370697, 61.19515769183636, 60.068024173378944, 53.47287766635418, 61.57720819115639, 62.83525228500366, 66.44554495811462, 62.381043657660484, 67.07886457443237, 64.6228663623333, 64.07826438546181, 60.00723883509636, 61.15109905600548, 61.05633594095707, 60.96392869949341, 60.469951406121254, 60.74590019881725, 58.91326613724232, 60.40933705866337, 63.38603653013706, 64.63323220610619, 62.625454142689705, 60.00651687383652, 63.29706430435181, 62.56684608757496, 62.926340997219086, 62.59934574365616, 62.25266754627228, 59.57656994462013, 50.049572959542274, 52.280030474066734, 45.624433010816574, 46.87764376401901, 45.92259161174297, 44.540487974882126, 43.981135189533234, 45.86271442472935, 52.55902670323849, 61.81550860404968, 56.37681484222412, 57.10303567349911, 55.418540462851524, 56.14906646311283, 59.49991285800934, 53.48749168217182, 45.996486246585846, 46.12494595348835, 41.32881671190262, 45.57059369981289, 45.81123858690262, 41.714800000190735, 47.439527213573456, 46.078550443053246, 46.79013445973396, 47.377476543188095, 46.19832381606102, 46.37842275202274, 45.34959375858307, 46.5223628282547, 44.361479580402374, 48.86111073195934, 48.389126658439636, 42.21626669168472, 41.72857046127319, 44.944026321172714, 42.15712286531925, 48.44439089298248, 58.71323727071285, 59.67178523540497, 57.1704288572073, 56.01921983063221, 57.21002273261547, 55.38438029587269, 59.379265531897545, 56.946176290512085, 55.75522139668465, 54.93607275187969, 47.018783390522, 43.920980617403984, 42.83819451928139, 42.976457700133324, 42.11672343313694, 42.64618322253227, 44.01604011654854, 49.04551103711128, 52.40195833146572, 59.49240446090698, 57.60468855500221, 56.78404659032822, 57.57383421063423, 58.68541896343231, 53.615180030465126, 57.29734964668751, 57.991329208016396, 56.860775873064995, 55.20383298397064, 57.73504436016083, 51.297691985964775, 53.813711777329445, 46.36788211762905, 47.41834715008736, 44.89978149533272, 51.02417126297951, 56.335769444704056, 58.11312787234783, 55.03614038228989, 62.77703180909157, 61.60462751984596, 60.980682000517845, 58.7920868396759, 64.20426562428474, 56.71127289533615, 60.99088065326214, 58.964456990361214, 45.1924379914999, 4.068141030147672, 3.6686468543484807, 2.739606681279838, 0.2506513532716781, 34.43773828446865, 72.36951068043709, 59.50825721025467, 66.62082955241203, 63.90214383602142, 68.78058046102524, 64.85943406820297, 70.83793446421623, 44.36503618955612, 45.70151947438717, 52.31187276542187, 61.02431505918503, 20.87425969541073, 0.7705321535468102, 0.2346181878237985, 0.36182308627758175, 0.16890724509721622, 0.23332330340053886, 0.2423265195102431, 0.19116238370770589, 0.2115928038256243, 0.21257601591059938, 0.12880119873443618, 0.14207246160367504], [0.044042401350452565, 0.04440871060069185, 0.05932683627179358, 0.020968096832802985, 0.05537456221645698, 0.06861272529931739, 0.03759759463719092, 0.0711669675365556, 0.04160879892879166, 0.026206204820482526, 0.06844666233519092, 0.06415452546207234, 0.023566634154121857, 0.39186792564578354, 0.34856449929066, 17.99240503460169, 51.14397123456001, 34.772629514336586, 33.340976536273956, 34.0149349719286, 57.45325908064842, 63.51696990430355, 57.49998517334461, 56.39367833733559, 61.80082619190216, 54.006961807608604, 53.97872172296047, 52.03527420759201, 5.207929294556379, 0.9463930106721818, 0.04818542962311767, 0.10870139056351036, 10.492798760533333, 57.404785081744194, 57.11001969873905, 56.34853295981884, 51.61557152867317, 49.371867924928665, 47.66979105770588, 52.213686034083366, 52.98108905553818, 54.304314851760864, 57.81753413379192, 56.37813717126846, 53.85908134281635, 52.93189689517021, 49.71854992210865, 47.44141571223736, 47.96992555260658, 47.45370425283909, 48.88850726187229, 49.481400847435, 49.018099308013916, 55.04715219140053, 55.9256536513567, 55.80110013484955, 54.53100688755512, 55.44437527656555, 49.31811600923538, 54.8763969540596, 52.85647094249725, 54.462998136878014, 50.44492654502392, 47.32150934636593, 42.30150751769543, 40.54551534354687, 39.54840324819088, 38.504044488072395, 40.4304613173008, 40.243176966905594, 44.41856391727924, 52.690370455384254, 52.11762338876724, 52.73909904062748, 53.849882036447525, 51.287839114665985, 47.71018289029598, 43.83679613471031, 43.73579755425453, 44.01988171041012, 42.884935811161995, 44.0527119487524, 43.63085858523846, 41.82303339242935, 40.02484068274498, 38.230675756931305, 38.857668712735176, 39.354256466031075, 37.50312499701977, 38.458321541547775, 39.067193269729614, 39.0993395447731, 40.092013478279114, 36.00899577140808, 40.046978294849396, 44.51454296708107, 43.04606236517429, 42.019760236144066, 43.49556304514408, 42.91220314800739, 46.77028812468052, 51.47817090153694, 52.85971596837044, 52.4976409971714, 50.530942529439926, 51.508865654468536, 53.698144778609276, 51.85333617031574, 50.495551228523254, 51.91713474690914, 42.723474875092506, 37.3106387257576, 39.54468324780464, 39.10926081240177, 39.724079221487045, 39.94614690542221, 42.130790278315544, 44.79425735771656, 48.365621119737625, 53.321239203214645, 54.55619193613529, 56.6870491951704, 53.818127140402794, 51.07202589511871, 51.43242135643959, 44.54195089638233, 44.31026592850685, 56.56285285949707, 53.62402215600014, 53.97894591093063, 55.27153015136719, 57.317002192139626, 54.55870360136032, 47.90695533156395, 42.80041314661503, 40.84861747920513, 43.48070204257965, 47.550078481435776, 49.67052049934864, 52.43343964219093, 51.59180000424385, 52.334561347961426, 49.937786757946014, 51.40579618513584, 53.193083480000496, 60.30122525990009, 52.59292468428612, 42.44463823735714, 4.498602356761694, 0.6490285077597946, 2.1919729420915246, 0.21884564979700372, 34.220222756266594, 54.269440323114395, 53.60082820057869, 54.70355182886124, 42.658532559871674, 53.30938383936882, 61.54533550143242, 52.7500082552433, 28.56044165790081, 22.325709611177444, 35.953302159905434, 30.92528846114874, 1.473568647634238, 0.0711309585312847, 0.09565017448039725, 0.016426358997705393, 0.02465420519001782, 0.06053980614524335, 0.14065159019082785, 0.021485355209733825, 0.04738350195111707, 0.015094481295818696, 0.029248975042719394, 0.0474448886961909, 0.011428940633777529, 0.029805342746840324, 0.04513971864071209, 0.023418926357408054, 0.050787447617040016, 0.08223655284382403, 0.042079647100763395, 0.03191481402609497, 0.09222339664120227, 0.038115817806101404, 0.03354602122271899, 0.027548898397071753, 0.015706451631558593, 0.4821710003307089, 0.21576330269454047, 25.71930181235075, 60.919934660196304, 33.17299135029316, 36.41495458781719, 50.59521608054638, 60.83764627575874, 68.87280151247978, 61.66890487074852, 63.71500767767429, 66.37948930263519, 61.46381467580795, 59.939663261175156, 58.15962977707386, 6.430523665621877, 0.8363147580530494, 2.3608297063037753, 0.24579055316280574, 12.62341758236289, 64.0912976861, 60.45521579682827, 61.75950340926647, 53.91096755862236, 51.08365707099438, 50.5460125207901, 56.850546821951866, 56.17677457630634, 58.61969769001007, 60.07172517478466, 58.80499094724655, 57.2015567868948, 56.159223318099976, 53.018509447574615, 50.11613018810749, 51.087171882390976, 51.103712394833565, 53.249335661530495, 52.67429731786251, 53.0130947381258, 56.983391493558884, 59.7897195070982, 58.908839374780655, 57.354810163378716, 55.695272013545036, 52.312891110777855, 59.704205095767975, 55.865909457206726, 57.183443158864975, 51.909960731863976, 47.458245009183884, 44.32378560304642, 42.747064009308815, 43.42732630670071, 40.009485706686974, 41.10094293951988, 42.75706507265568, 46.75230748951435, 56.47100418806076, 53.11389572918415, 53.33218641579151, 55.311188623309135, 51.81078605353832, 49.839258044958115, 44.459666311740875, 42.301119938492775, 44.556933492422104, 43.441062569618225, 42.4331134557724, 44.4743487238884, 43.92012946307659, 43.053034991025925, 40.00997208058834, 42.28966735303402, 41.106863021850586, 39.79979395866394, 40.545891523361206, 40.111970007419586, 41.51883691549301, 41.582715287804604, 38.27816940844059, 44.25871789455414, 44.21068087220192, 42.834641709923744, 41.611494943499565, 43.88585150241852, 43.269866555929184, 48.950637727975845, 53.917685598134995, 55.01718319952488, 55.382936373353004, 52.649252861738205, 53.766392916440964, 55.24474538862705, 52.708396688103676, 53.37850213050842, 54.52943757176399, 45.11560991406441, 39.32471685111523, 41.46167278289795, 41.61849416792393, 41.535373628139496, 41.795021295547485, 43.81013676524162, 46.950561851263046, 52.80967265367508, 54.4602432847023, 55.48402614891529, 58.412703797221184, 55.61001218855381, 52.52825975418091, 50.29134638607502, 46.74076750874519, 45.25508902966976, 57.47851252555847, 56.05782575905323, 57.44676522910595, 57.783499360084534, 59.59410220384598, 54.395897537469864, 51.070304587483406, 44.11149099469185, 42.35299855470657, 44.950390979647636, 49.29392270743847, 50.42552478611469, 54.582418128848076, 54.0041309595108, 55.25668814778328, 52.74838574230671, 52.667526081204414, 55.0572444498539, 62.09917478263378, 55.88765189051628, 47.05552741885185, 5.580577198415995, 2.4886553222313523, 2.4479008466005325, 0.1324532480794005, 40.28214767575264, 63.20538282394409, 59.707282930612564, 58.760179951786995, 49.687665179371834, 59.04053270816803, 67.62703835964203, 56.60216934978962, 44.36239533126354, 26.101073026657104, 38.67226906120777, 41.82329937815666, 2.183724297210574, 0.08739034543395974, 0.16012075095204636, 0.03213616328139324, 0.0028002071394439554, 0.0436159558739746, 0.07848930821637623, 0.01091682534024585, 0.03371560567757115, 0.030075875984039158, 0.05996560648782179, 0.04423047270392999, 0.09875685660517775, 0.07680767579586245, 0.1094346992613282, 0.10484899103175849, 0.15679508331231773, 0.21045430476078764, 0.17253225058084354, 0.11162286973558366, 0.13387545535806566, 0.1069336170621682, 0.15298354643164203, 0.10185850696871057, 0.12921914662001655, 0.6805646186694503, 0.4179325676523149, 31.491247192025185, 74.32069838047028, 46.61812908947468, 44.85790394246578, 50.373535975813866, 66.77102789282799, 74.08283114433289, 68.02682250738144, 68.10857132077217, 74.49975237250328, 65.33483415842056, 66.6021953523159, 64.4855797290802, 7.550747729837894, 2.151122521609068, 3.7234862241894007, 0.32573924283497036, 15.820718016475439, 66.56504854559898, 64.18906643986702, 64.88539427518845, 58.232445269823074, 54.785186648368835, 54.65861923992634, 57.08641916513443, 58.70763637125492, 60.6300900131464, 62.78232492506504, 62.488277703523636, 60.858769342303276, 58.71184654533863, 53.86418826878071, 52.83689819276333, 51.6581292450428, 53.31740140914917, 54.807609245181084, 53.85477237403393, 54.44977484643459, 60.97580686211586, 63.03563453257084, 62.49610908329487, 60.02003654837608, 58.373121321201324, 54.291889518499374, 62.21726484596729, 57.27945640683174, 58.487514182925224, 58.14283847808838, 51.370933055877686, 46.7761056125164, 44.85761135816574, 46.41541376709938, 42.49058537185192, 43.89360688626766, 45.86542747914791, 47.65013851225376, 57.90475085377693, 54.022081196308136, 57.305348217487335, 58.17934691905975, 53.520758897066116, 47.65160523355007, 43.64460624754429, 43.79413582384586, 45.14737620949745, 44.295587316155434, 44.028761833906174, 46.1555191129446, 43.69216829538345, 44.672014117240906, 42.47849062085152, 43.74491706490517, 43.89596275985241, 41.808715760707855, 40.91089613735676, 42.822208777070045, 45.677968338131905, 44.50634300708771, 40.65592221915722, 47.03967846930027, 47.423100695014, 42.99376957118511, 41.363801434636116, 42.72674649953842, 43.08867707848549, 46.97429537773132, 55.423480197787285, 56.67519003152847, 56.8000703305006, 54.041433557868004, 57.04378545284271, 58.04421477019787, 55.843912437558174, 54.07037280499935, 57.29663908481598, 46.390259116888046, 41.425988897681236, 44.82005797326565, 44.2148644477129, 42.89826549589634, 43.98855239152908, 45.85379250347614, 50.11729292571545, 54.4287695735693, 57.42300130426884, 56.24620445072651, 60.18934786319733, 55.502964332699776, 51.95252604782581, 51.45940750837326, 46.408969312906265, 46.70393608510494, 59.73336473107338, 56.96246221661568, 59.46080155670643, 60.204892829060555, 61.09505586326122, 57.3554827272892, 51.39365203678608, 46.400529965758324, 44.60537329316139, 47.305402010679245, 51.76939867436886, 55.124284252524376, 56.95186838507652, 55.589804872870445, 55.944337248802185, 54.3606848269701, 56.50321125984192, 59.18587490916252, 66.66346326470375, 57.673438265919685, 52.31716588139534, 6.440530428662896, 4.495042422786355, 3.5917130950838327, 0.215572451998014, 43.227248042821884, 67.52331152558327, 65.18210515379906, 64.16945949196815, 55.075456872582436, 66.70746490359306, 71.13457694649696, 65.9207171201706, 43.480645045638084, 32.88896419107914, 49.45989400148392, 54.82419915497303, 2.8681882191449404, 0.14853115018922836, 0.15529290220001712, 0.1393290830310434, 0.062127920537022874, 0.1739454927155748, 0.15603853797074407, 0.08301726993522607, 0.1351454629912041, 0.14771377842407674, 0.11844370412291028, 0.11445174372056499], [0.020183247834211215, 0.02995173508679727, 0.06310737735475414, 0.041470158321317285, 0.024378118832828477, 0.03068370420805877, 0.06065417481295299, 0.02622314805194037, 0.012885488940810319, 0.09938258357578889, 0.05325229816662613, 0.0705138775811065, 0.0734456058125943, 0.06039443796908017, 0.6627422093879431, 3.76531224232167, 54.300328865647316, 45.25068886578083, 31.704313158988953, 28.88936910778284, 46.315585523843765, 60.745277032256126, 61.18406608700752, 56.70999996364117, 59.97454158961773, 57.56383694708347, 54.201883748173714, 53.2833818346262, 8.245645891875029, 1.0458197817206383, 0.6100383843295276, 0.3324175626039505, 7.856871178373694, 54.70830537378788, 57.178993597626686, 56.678723841905594, 55.53082063794136, 53.18484552204609, 48.02300490438938, 43.96965220570564, 47.955117747187614, 49.58637781441212, 50.131830945611, 49.356889128685, 46.68612644076347, 50.039556697010994, 46.52963183820248, 45.08428439497948, 49.23542484641075, 48.704863116145134, 49.04253579676151, 50.65719075500965, 50.7874059677124, 50.48260912299156, 53.052354231476784, 53.197704032063484, 55.115442126989365, 55.29925726354122, 53.61143343150616, 49.49715860188007, 55.82047909498215, 56.28992110490799, 52.554805129766464, 47.5663910061121, 44.93739567697048, 41.65390066802502, 39.94610130786896, 37.28272542357445, 39.41201336681843, 40.39131581783295, 43.53463634848595, 50.21330617368221, 49.97744902968407, 53.530094996094704, 52.972383722662926, 43.07794265449047, 43.39317373931408, 43.50788578391075, 43.48610155284405, 44.61138837039471, 46.953168511390686, 45.086598470807076, 44.51699383556843, 40.14658235013485, 38.692141994833946, 38.507190719246864, 39.869102239608765, 38.519581854343414, 39.146548211574554, 37.65068247914314, 37.43202701210976, 37.01661430299282, 38.822311609983444, 37.67917335033417, 35.43223612010479, 35.67104570567608, 43.284917548298836, 44.28088590502739, 40.808385238051414, 42.2438608109951, 45.82984998822212, 45.559194311499596, 50.064236372709274, 52.46001161634922, 52.561450973153114, 53.030163422226906, 50.41471816599369, 53.1647028028965, 51.60431273281574, 48.62746126949787, 41.22115708887577, 36.95663832128048, 38.60166124999523, 37.10554473102093, 40.980645194649696, 39.84559670090675, 40.61410166323185, 45.15787124633789, 53.879201263189316, 52.1274458616972, 54.13108594715595, 45.543162971735, 46.96370154619217, 45.06607577204704, 54.01109218597412, 39.207690730690956, 38.60482648015022, 48.5330705344677, 45.482780411839485, 45.52018940448761, 43.32242153584957, 42.551746889948845, 48.37723709642887, 52.610468342900276, 47.42107540369034, 45.13162985444069, 42.560364827513695, 43.054228127002716, 45.34794844686985, 47.66461193561554, 48.38704816997051, 47.99502320587635, 47.250487357378006, 49.52594965696335, 51.62483163177967, 56.42535723745823, 50.049933940172195, 42.53314308822155, 7.739451779052615, 1.064014749135822, 0.9748544928152114, 0.8982558874413371, 37.3805245757103, 56.728615164756775, 55.179860070347786, 50.495156049728394, 58.0247788131237, 55.74572950601578, 57.66180709004402, 36.08295500278473, 21.914982050657272, 20.61322320252657, 46.850840002298355, 12.60528115555644, 0.7640559948049486, 0.02609012179163983, 0.1549173754756339, 0.003175818746967707, 0.1170397388341371, 0.04336941441579256, 0.16282230208162218, 0.11193426005775109, 0.05467118062369991, 0.028676691981672775, 0.056268334374180995, 0.04519018097198568, 0.045571040027425624, 0.06653386575635523, 0.06861015746835619, 0.05269809567835182, 0.0684475306479726, 0.06677746088826098, 0.05373574429540895, 0.07224143409985118, 0.021700745019188616, 0.03913866057700943, 0.09267403613193892, 0.1775151042966172, 0.1413993039750494, 0.29281573137268424, 0.6748775707092136, 7.2113903146237135, 65.65091639757156, 44.13916490972042, 32.47759826481342, 43.94117273390293, 53.041961789131165, 67.54205971956253, 67.08451867103577, 62.96196028590202, 67.09163948893547, 61.833595633506775, 59.86173704266548, 59.93970885872841, 10.007056575268507, 1.1611659172922373, 2.107204240746796, 0.5872426950372756, 9.820934012532234, 61.297098621726036, 60.62815211713314, 62.156692296266556, 57.07703746855259, 58.00348475575447, 51.00078731775284, 45.87632529437542, 49.000536650419235, 52.21194952726364, 53.521743044257164, 52.05324724316597, 50.562173053622246, 51.36544995009899, 48.14966730773449, 48.04801136255264, 52.098878994584084, 49.902612045407295, 51.48612007498741, 53.86373229324818, 52.50009946525097, 53.45038287341595, 55.62838800251484, 56.6412578523159, 56.621700301766396, 57.878452464938164, 53.47328044474125, 52.587897554039955, 57.62084908783436, 59.54664275050163, 55.21688528358936, 50.102276131510735, 46.10894501209259, 44.65530641376972, 42.09707468748093, 39.0014111995697, 41.610552594065666, 42.935875877738, 45.16390152275562, 53.33909064531326, 54.13933910429478, 55.13946443796158, 52.72046484053135, 43.96535463631153, 43.02590824663639, 43.44963110983372, 45.57500906288624, 44.23148475587368, 45.04960745573044, 44.59281496703625, 45.65303787589073, 41.90315589308739, 39.82211776077747, 40.84924064576626, 42.36432194709778, 40.38920693099499, 40.911880284547806, 39.36893127858639, 38.27339306473732, 38.788276836276054, 40.39270654320717, 38.78845162689686, 38.19650039076805, 42.60771408677101, 45.8293142169714, 43.99799108505249, 41.90973713994026, 43.00148695707321, 46.1750690639019, 46.962052434682846, 52.92672157287598, 56.416230127215385, 55.118341371417046, 55.04578426480293, 53.41272309422493, 56.08878269791603, 53.906837180256844, 51.40946678817272, 42.942913100123405, 40.000867769122124, 40.99015608429909, 39.91242751479149, 42.807989940047264, 41.070289984345436, 42.707523331046104, 46.085872650146484, 55.43270230293274, 54.48684185743332, 57.45880678296089, 47.9248371720314, 48.08661729097366, 46.01757511496544, 55.71306645870209, 39.6502909809351, 38.89028616249561, 51.39716684818268, 44.88194525241852, 45.56682430207729, 43.60566973686218, 46.81698761880398, 51.046567261219025, 54.619823321700096, 49.15115296840668, 47.448521330952644, 43.75924989581108, 45.8079669624567, 46.29152901470661, 49.56296727061272, 51.607135981321335, 48.794697895646095, 49.83972541987896, 53.39535802602768, 55.5203901976347, 59.03818063437939, 53.25638048350811, 46.61333754658699, 8.722678944468498, 1.609152378514409, 1.6408969438634813, 1.1912883259356022, 42.68274866044521, 62.83411994576454, 61.142959892749786, 53.922898918390274, 59.2361082136631, 64.20196294784546, 64.87457245588303, 44.03707958757877, 33.0772440880537, 16.05738926678896, 53.31222228705883, 17.28254422545433, 1.0228894371539354, 0.044645737725659274, 0.1658621389651671, 0.02623884818603983, 0.12246269354363903, 0.03472674849035684, 0.12648093339521438, 0.02003785368287936, 0.06507424681331031, 0.05034698668168858, 0.03519660218444187, 0.041722614696482196, 0.11152664286782965, 0.27133774012327194, 0.2721644629491493, 0.13370057567954063, 0.15057319920742884, 0.20846463652560487, 0.16019567818148062, 0.06332710501737893, 0.11523192646563984, 0.28660276788286865, 0.21526644966797903, 0.28659199189860374, 0.11739714973373339, 0.5926108569838107, 0.8457715006079525, 8.821670282632113, 79.86624240875244, 60.31849533319473, 41.79898828268051, 40.55220678448677, 58.51085253059864, 70.4721736907959, 72.90860295295715, 68.10000658035278, 73.75902771949768, 68.23493734002113, 65.92318698763847, 66.54316931962967, 11.125840991735458, 2.007034965790808, 4.7817992605268955, 1.001341980881989, 12.94795436784625, 63.50319944322109, 66.11159607768059, 64.56142365932465, 60.63635967671871, 59.452540799975395, 54.246930330991745, 49.444105848670006, 52.30285964906216, 53.74759912490845, 55.815322771668434, 55.31963177025318, 52.2137164324522, 54.00613345205784, 50.83529479801655, 51.17273189127445, 54.6686165034771, 53.30272279679775, 53.65070052444935, 55.78038364648819, 55.079142674803734, 54.51269567012787, 60.01495622098446, 58.029874339699745, 59.861113876104355, 59.12183314561844, 56.4514846354723, 53.726700246334076, 60.679631754755974, 63.45143482089043, 58.31531502306461, 53.90735775232315, 49.17359836399555, 48.42680163681507, 44.70763720571995, 41.72825127840042, 44.589193761348724, 44.24332872033119, 48.87401483952999, 58.35729897022247, 54.47977423667908, 58.14761862158775, 55.8673419803381, 43.54965694248676, 42.07010753452778, 42.72079221904278, 45.06395548582077, 44.05326671898365, 45.64924567937851, 46.75099655985832, 47.82113313674927, 43.80318693816662, 42.10929483175278, 42.31710188090801, 44.649838507175446, 42.363846972584724, 42.95232519507408, 41.9012787938118, 40.02948023378849, 40.58069385588169, 42.69479401409626, 40.901434645056725, 39.92049068212509, 43.23797486722469, 48.94206918776035, 46.1808979511261, 40.78493669629097, 42.19900421798229, 46.0121414065361, 47.269892916083336, 53.342787846922874, 57.92167894542217, 58.52727144956589, 57.31621943414211, 54.82336699962616, 58.65078002214432, 56.09318666160107, 52.40705765783787, 45.750650838017464, 42.70621620118618, 43.31017479300499, 43.38777422904968, 43.807290717959404, 43.893584087491035, 43.85577231645584, 48.544868901371956, 57.403774335980415, 55.6323017925024, 58.15229997038841, 50.039522498846054, 49.36276361346245, 46.74006834626198, 57.56203204393387, 39.18139234185219, 37.561964839696884, 51.4464958012104, 45.372400134801865, 47.13408060371876, 45.05494996905327, 50.73092199862003, 54.610475823283195, 55.47149062156677, 50.93580700457096, 49.83485788106918, 45.03762669861317, 48.66672836244106, 49.46009919047356, 51.09694115817547, 54.11491021513939, 52.318841591477394, 51.97123244404793, 55.275953114032745, 57.773897275328636, 61.497275680303574, 57.435339242219925, 52.64579884707928, 10.427840296179056, 3.7705371994525194, 3.7963751005008817, 1.598303485661745, 45.83135850727558, 67.20152199268341, 64.86149355769157, 60.327432453632355, 66.1533634364605, 67.87522584199905, 69.58975464105606, 49.0751114487648, 33.074622228741646, 29.02794387191534, 62.77667082846165, 27.011612467467785, 1.0151029424741864, 0.17488444311311468, 0.21494440210517496, 0.09352781766210683, 0.17590869596460834, 0.17823666479671374, 0.28427177108824253, 0.25935983285307884, 0.15910457266727462, 0.14625058975070715, 0.15100195276318118, 0.1931539666838944], [0.04313943769375328, 0.04080967657500878, 0.029733103947364725, 0.07377842935966328, 0.027139559424540494, 0.07985739808646031, 0.12409809016389772, 0.09073522727703676, 0.09656496054958552, 0.021362911975302268, 0.004115124447707785, 0.0664480437990278, 0.09863868443062529, 0.046175330062396824, 0.19609125360148028, 0.09432791965082288, 27.87627127021551, 51.30239613354206, 40.67663110792637, 35.0112035125494, 43.205657601356506, 56.38395085930824, 65.38469508290291, 59.33467872440815, 60.41738502681255, 55.809201300144196, 52.215597331523895, 58.705899864435196, 11.081705410033464, 0.9514598012901843, 2.0935803093016148, 0.316792979137972, 6.506165256723762, 52.12803862988949, 56.46927908062935, 58.46855700016022, 57.33872562646866, 57.898758575320244, 57.95501455664635, 49.20970022678375, 43.025087490677834, 46.562549471855164, 44.943916127085686, 44.336628913879395, 45.66188760101795, 48.17860275506973, 46.783078238368034, 47.67979972064495, 49.421869441866875, 53.05009715259075, 51.3445320725441, 53.56734819710255, 53.60587812960148, 54.48557652533054, 54.84645836055279, 55.531348809599876, 56.96636460721493, 55.52010901272297, 53.82449559867382, 53.27995441854, 53.88605609536171, 57.07550995051861, 53.18370558321476, 47.96201437711716, 41.30225233733654, 40.83540938794613, 38.9520138502121, 39.41839702427387, 38.65290530025959, 41.31790369749069, 42.56718926131725, 50.87189823389053, 51.7771502584219, 52.60066106915474, 46.428504064679146, 44.66393955051899, 44.64761182665825, 41.65947496891022, 43.43870289623737, 46.50310166180134, 44.789450615644455, 41.684511825442314, 41.21079124510288, 39.76587317883968, 38.951086699962616, 37.51332364976406, 38.23078595101833, 39.05699081718922, 38.4757474064827, 36.96382373571396, 37.1656347066164, 37.73461997509003, 38.613053038716316, 35.404987782239914, 38.58338423073292, 37.89359964430332, 35.51733635365963, 40.06844714283943, 45.44816806912422, 44.31353375315666, 42.701968029141426, 43.922139555215836, 41.03290379047394, 48.492036536335945, 50.22215589880943, 51.50998279452324, 52.137579917907715, 50.80276094377041, 49.33414734899998, 46.25029742717743, 39.11929987370968, 39.31924134492874, 35.902134105563164, 37.56873607635498, 38.639841601252556, 39.286855682730675, 41.54754437506199, 46.201929822564125, 50.9005980938673, 55.79296477138996, 47.41016238927841, 45.85107184946537, 55.135269463062286, 49.43966768682003, 53.2367317378521, 55.11707603931427, 49.964560121297836, 49.472600519657135, 49.4149424135685, 48.92755776643753, 50.77947959303856, 52.61202625930309, 54.766218066215515, 53.163437470793724, 50.934009701013565, 46.86724752187729, 46.16116560995579, 41.777561232447624, 40.98858296871185, 45.60437008738518, 43.86264614760876, 45.143109038472176, 46.81071795523167, 51.495608165860176, 56.49229824542999, 56.96847729384899, 41.27628453075886, 32.80802473425865, 9.058654066175222, 0.4588405491085723, 0.2675277617527172, 1.3872832339257002, 42.17679440975189, 59.74106311798096, 50.50321161746979, 60.652474611997604, 53.39116305112839, 52.79939420521259, 50.31177029013634, 24.382151663303375, 32.9923452436924, 39.28472399711609, 40.77644035220146, 1.702317560557276, 0.07794034157996066, 0.14727270521689206, 0.18598722468595952, 0.07580880439491011, 0.03733584286237601, 0.04840444482397288, 0.06082116917241365, 0.008864273077051621, 0.037775873352074996, 0.0823381454392802, 0.05094022613775451, 0.0257764530761051, 0.0263128199003404, 0.004975197534804465, 0.02156218975869706, 0.05407245669630356, 0.059088065099786036, 0.009841224218689604, 0.0671783096913714, 0.07973585656145588, 0.047518580249743536, 0.03552505819243379, 0.01538211361548747, 0.014641099569416838, 0.04127140004129615, 0.06816108390921727, 0.2859521715436131, 0.29450287052895874, 35.3279697149992, 59.54850845038891, 33.493443354964256, 42.90681503713131, 53.26637014746666, 61.30282871425152, 71.24184519052505, 63.772608786821365, 66.84055656194687, 62.3729082942009, 58.52928154170513, 65.05436360836029, 13.29090591520071, 1.1839072220027447, 1.2315734080038965, 0.27723632985726, 8.064947538077831, 58.72683294117451, 61.37989237904549, 62.484683096408844, 61.78003370761871, 59.97176393866539, 60.19693985581398, 51.84278793632984, 45.95582842826843, 49.84428897500038, 48.44424270093441, 46.91496156156063, 49.330225959420204, 50.911894887685776, 49.27893631160259, 50.263661071658134, 51.35121211409569, 54.48499135673046, 54.7197275608778, 55.79104967415333, 54.91877228021622, 57.05716073513031, 57.65753611922264, 59.439222514629364, 58.566568940877914, 56.80831968784332, 54.755525439977646, 55.36779038608074, 57.01134279370308, 60.91556489467621, 54.71267133951187, 49.75336365401745, 44.79939088225365, 44.12159465253353, 40.053734332323074, 40.07958434522152, 40.51239252090454, 43.067124634981155, 44.915394857525826, 53.313734605908394, 53.32261472940445, 54.879873767495155, 46.216798424720764, 44.665702655911446, 43.691928908228874, 42.735505029559135, 42.00498282909393, 46.530171409249306, 46.85975432395935, 45.42188487946987, 41.77159175276756, 42.754439413547516, 40.486439913511276, 40.86187116801739, 40.194341987371445, 40.98567232489586, 40.26137039065361, 38.394994139671326, 37.61363446712494, 39.31317687034607, 38.76692958176136, 39.357558488845825, 38.92803333699703, 37.995517775416374, 38.991379737854004, 42.344441413879395, 46.41881078481674, 43.51906858384609, 42.79251717031002, 45.758763402700424, 41.15127883851528, 49.241781905293465, 52.51704655587673, 53.35975393652916, 53.33931863307953, 54.51016120612621, 52.35561981797218, 47.86732725799084, 41.32012277841568, 42.90522292256355, 39.039393961429596, 40.88517911732197, 40.40281780064106, 41.32808715105057, 42.91377626359463, 48.350680321455, 54.05197039246559, 56.69467158615589, 50.56920267641544, 47.31540307402611, 53.167803436517715, 49.42948803305626, 52.344019040465355, 57.606276869773865, 50.80556519329548, 50.10422542691231, 50.07976233959198, 49.80742335319519, 50.22554151713848, 52.28368207812309, 54.854019954800606, 55.08366823196411, 52.217877209186554, 48.2217950373888, 47.39877060055733, 44.26195912063122, 43.417249247431755, 49.795662984251976, 45.41031830012798, 48.25208321213722, 47.04925395548344, 56.10631115734577, 58.970384672284126, 64.10659566521645, 45.87542474269867, 38.301446959376335, 9.923074431717396, 0.34595383156556636, 0.1995471236295998, 1.5969401900656521, 47.1963706612587, 64.61800262331963, 55.790035128593445, 66.07813507318497, 59.14901688694954, 61.9863436371088, 54.66566406190395, 35.99729239940643, 33.92214395105839, 35.37217654287815, 51.727464124560356, 2.5115804420784116, 0.09523906177491881, 0.13896854768972844, 0.07902406272478402, 0.060259853198658675, 0.04855083716392983, 0.10530663639656268, 0.03382053422683384, 0.031776704054209404, 0.04664212239731569, 0.0906120084982831, 0.05113970059028361, 0.04683432380261365, 0.09486970971920528, 0.11955137437325902, 0.07284865932888351, 0.11794662103056908, 0.1262098120059818, 0.1789096591528505, 0.28083164943382144, 0.16814416885608807, 0.19660137622850016, 0.1116228177852463, 0.09290739704738371, 0.21289193333359435, 0.34450447652488947, 0.15612146555213258, 0.4088932980084792, 0.40374163538217545, 40.35216651856899, 70.94179049134254, 50.177968069911, 48.261046931147575, 57.463054955005646, 65.57543724775314, 76.51295274496078, 68.82654279470444, 70.78601405024529, 67.73090958595276, 62.38990858197212, 72.86818832159042, 16.11353125423193, 1.6462646308355033, 5.893460484221578, 0.7190667057875544, 10.01621788367629, 63.72576490044594, 63.33600461483002, 65.28565719723701, 64.5028156042099, 62.69967935979366, 64.8027715086937, 54.59119565784931, 47.8504903614521, 51.33168116211891, 49.33411695063114, 50.237765461206436, 51.68646812438965, 55.33171132206917, 51.96629650890827, 53.18487972021103, 53.66751842200756, 56.049485206604004, 57.76643827557564, 58.1751823425293, 56.61989539861679, 60.38251429796219, 59.43437397480011, 60.5617468804121, 61.62727050483227, 59.55048814415932, 54.688937813043594, 55.02125658094883, 56.81139372289181, 63.7892746925354, 57.583193108439445, 53.33995699882507, 45.13183884322643, 46.261271238327026, 43.96313555538654, 43.91141653060913, 44.37525004148483, 45.12144260108471, 47.185024470090866, 55.34490421414375, 57.39210516214371, 56.49352177977562, 47.937513291835785, 45.26463411748409, 44.86531354486942, 41.140776202082634, 42.300682961940765, 47.05930441617966, 49.06162977218628, 46.50502435863018, 45.24093858897686, 44.96232233941555, 43.587312921881676, 42.265713438391685, 41.86984308063984, 45.49696885049343, 43.328033834695816, 39.696500301361084, 40.597933530807495, 42.26312577724457, 42.08540931344032, 41.49355307221413, 41.39836058020592, 41.70125752687454, 41.962554305791855, 44.1857086122036, 47.771659791469574, 46.27064913511276, 42.466954439878464, 44.834170415997505, 38.83912190794945, 49.94468338787556, 52.73194022476673, 55.76296538114548, 54.83867257833481, 55.457172989845276, 53.561257123947144, 49.08847913146019, 43.02774354815483, 44.904580637812614, 40.89571215212345, 42.559164091944695, 41.05548597872257, 43.18872570991516, 45.82500524818897, 50.626940578222275, 55.867151990532875, 58.727353513240814, 51.046369671821594, 48.67205187678337, 54.4267138838768, 51.821953654289246, 53.18686701357365, 58.2370126247406, 51.14751264452934, 52.979105561971664, 50.289412289857864, 50.01335710287094, 49.80069011449814, 53.909204453229904, 58.1784425675869, 57.6058778911829, 53.88989008963108, 49.66930456459522, 50.733623653650284, 46.20840087532997, 45.20769417285919, 50.792121514678, 46.48559980094433, 49.80094090104103, 50.134597197175026, 58.033244758844376, 61.91979020833969, 65.56818723678589, 47.42815062403679, 42.44332730770111, 13.484852258116007, 0.639617956476286, 1.324096661992371, 2.2783066844567657, 53.812332451343536, 66.07691913843155, 61.9355745613575, 68.6480663716793, 66.33675679564476, 64.53777372837067, 63.75115513801575, 36.29354350268841, 44.81768310070038, 48.78239795565605, 61.757215932011604, 4.766873186454177, 0.4619686718797311, 0.2698832791065797, 0.2790462499251589, 0.13906311214668676, 0.22175433434313163, 0.13222126755863428, 0.19712047884240746, 0.14398117637028918, 0.19438484829152003, 0.19592493830714375, 0.1275050378171727, 0.14422779204323888], [0.04143898440815974, 0.01814805254980456, 0.09295064199250191, 0.013175617659726413, 0.06926870220922865, 0.012432480143615976, 0.04047253372846171, 0.05471847027365584, 0.04686331580160186, 0.028811402917199302, 0.036207032535457984, 0.023541109840152785, 0.10829396633198485, 0.07798389822710305, 0.3534801589557901, 0.2536550327204168, 3.6036988394334912, 55.16740433871746, 45.03462865948677, 35.710958763957024, 34.84988696873188, 54.58336427807808, 66.89747750759125, 60.58199979364872, 58.52246850728989, 58.93761523067951, 50.31680881977081, 59.783636033535004, 19.999613128602505, 1.185592075344175, 1.216366623993963, 0.09050482753082179, 5.559928631410003, 55.242328718304634, 58.54396775364876, 63.68452951312065, 59.11663502454758, 58.904002234339714, 59.627681002020836, 57.65713334083557, 46.23684614896774, 45.842716097831726, 45.54964542388916, 44.27058085799217, 45.273537039756775, 46.092518493533134, 45.7329285889864, 50.65288558602333, 52.45643600821495, 53.58313634991646, 58.36818918585777, 57.45716147124767, 60.738741382956505, 59.57546040415764, 53.890501856803894, 55.71439638733864, 55.759309977293015, 58.01310583949089, 54.113166108727455, 54.693467170000076, 56.840237975120544, 54.89839397370815, 53.72207969427109, 45.894853100180626, 40.66180430352688, 42.382773756980896, 39.672979563474655, 39.09098379313946, 38.56628894805908, 43.50249387323856, 42.893356159329414, 47.64784723520279, 52.455402463674545, 49.638024643063545, 41.55278429389, 43.640658259391785, 41.276512518525124, 49.20893646776676, 45.577133148908615, 41.51352100074291, 37.54083037376404, 39.14329558610916, 38.68965692818165, 40.273989513516426, 38.39440517127514, 39.64719034731388, 38.23552429676056, 38.78217816352844, 36.6963978856802, 38.98564204573631, 38.04162070155144, 37.71666593849659, 38.01859773695469, 37.90904961526394, 35.58346800506115, 37.703096866607666, 39.550166353583336, 34.41866710782051, 36.24042995274067, 44.00765776634216, 45.14606148004532, 42.506419122219086, 41.7535313218832, 43.3404515683651, 45.05103997886181, 50.59434212744236, 50.940089374780655, 48.63875426352024, 45.12373387813568, 40.623753145337105, 39.72246430814266, 38.902662098407745, 36.11408673226833, 38.87565314769745, 37.35938251018524, 39.8592683672905, 38.493857234716415, 44.718242436647415, 50.430578514933586, 54.826904609799385, 54.244118481874466, 50.256715044379234, 51.61492556333542, 53.71926784515381, 51.82272881269455, 47.69892029464245, 47.70042881369591, 50.476350858807564, 52.13015131652355, 52.54427209496498, 54.25946965813637, 59.6858748793602, 58.60193744301796, 55.46173274517059, 48.30278389155865, 49.009146988391876, 42.56872437894344, 42.680236995220184, 44.052867740392685, 46.40545830130577, 42.83258982002735, 46.45501524209976, 47.83880978822708, 55.89777074754238, 54.495482593774796, 59.333781972527504, 46.56783118844032, 30.855708494782448, 9.210695307701826, 0.4244865331565961, 0.32489708333741874, 2.9696964472532272, 45.40815241634846, 55.29399074614048, 54.896459877491, 49.62343342602253, 39.680294170975685, 62.27787919342518, 42.31698788702488, 24.2918761074543, 29.781566932797432, 40.09983345866203, 19.35787696391344, 0.46872735139913857, 0.07271816750289872, 0.15376161405583844, 0.005265573481665342, 0.0257585042345454, 0.05858882606844418, 0.028673383858404122, 0.09007434477098286, 0.10627173265675083, 0.01653602987062186, 0.0550100897817174, 0.01806050138839055, 0.04527917561063077, 0.04295363360142801, 0.028287058885325678, 0.027643093635560945, 0.020809342167922296, 0.02898711751186056, 0.05513936448551249, 0.014087605832173722, 0.023871534394857008, 0.04774558467033785, 0.07062831675284542, 0.013665034366567852, 0.05732838842959609, 0.06950949202291667, 0.06714195929816924, 0.4494203795911744, 0.3904609620803967, 6.543473554775119, 66.37407839298248, 40.164304599165916, 39.943251460790634, 55.26927687227726, 57.09780715405941, 72.79292196035385, 64.58541557192802, 67.92802780866623, 63.914819955825806, 56.84718020260334, 65.77921271324158, 24.276173450052738, 1.2259041122160852, 2.103139408864081, 0.08263380965217948, 7.039027288556099, 61.230579391121864, 62.28790305554867, 65.3521080315113, 62.08677604794502, 61.91372573375702, 62.14044436812401, 59.8871348798275, 50.59928946197033, 47.799470499157906, 46.553916335105896, 46.9317452609539, 48.43854680657387, 48.437387868762016, 48.48404176533222, 52.776302844285965, 55.31977616250515, 56.3129098713398, 60.61685912311077, 59.97963711619377, 62.238395512104034, 60.23907199501991, 57.30235017836094, 58.77515874803066, 56.87176488339901, 58.86571928858757, 55.521948114037514, 57.841666638851166, 59.142572432756424, 57.51467138528824, 55.796088203787804, 49.59186851978302, 44.319058656692505, 43.507228419184685, 41.64609968662262, 40.32560594379902, 41.87219135463238, 44.446633011102676, 43.95629212260246, 49.4591074436903, 53.54112200438976, 50.549610927700996, 40.46952322125435, 42.5345604121685, 40.92703387141228, 45.667249113321304, 48.12246456742287, 43.632667288184166, 40.885494500398636, 40.556112974882126, 40.737538039684296, 41.4916455745697, 39.89304095506668, 41.439690962433815, 41.62863962352276, 40.63408859074116, 38.55068318545818, 40.70125758647919, 40.19589230418205, 38.92240583896637, 40.8115428686142, 37.98665665090084, 38.496893271803856, 41.16938106715679, 39.65219467878342, 37.49635376036167, 41.293900385499, 48.738685101270676, 45.685978308320045, 43.859781101346016, 41.69315256178379, 45.61940208077431, 46.60143658518791, 52.91146159172058, 52.57492505013943, 49.78388361632824, 46.541658192873, 43.21383476257324, 41.51021897792816, 41.062751188874245, 39.03490640223026, 42.25171118974686, 40.12487791478634, 42.569317147135735, 41.30814582109451, 47.70570673048496, 52.78503097593784, 55.277967005968094, 56.605767756700516, 52.207321375608444, 52.6180375367403, 55.99161051213741, 51.32093533873558, 49.162407964468, 49.01519626379013, 51.7251006513834, 51.46786205470562, 55.890304148197174, 55.79293817281723, 60.81700958311558, 57.47641883790493, 55.77246107161045, 51.37448966503143, 52.382400780916214, 46.998503878712654, 46.08051113784313, 45.99915370345116, 48.98645460605621, 45.13334736227989, 48.296977803111076, 50.386303290724754, 59.231917038559914, 57.39992894232273, 63.72182451188564, 53.484987616539, 39.72795121371746, 11.673406809568405, 0.4510518576717004, 0.49246880400460213, 3.88913881033659, 49.034347236156464, 60.07396325469017, 58.99097576737404, 55.46144396066666, 45.3292116522789, 68.95708099007607, 48.784218057990074, 32.54272677004337, 26.895815581083298, 43.98444481194019, 26.684493720531464, 0.7350988173857331, 0.04599603089445736, 0.16220786317717284, 0.02834410592186032, 0.11722732408088632, 0.011878020686708624, 0.07089763472322375, 0.04803898533282336, 0.07309927517781034, 0.04071552772074938, 0.06376909106620587, 0.08403032377827913, 0.04946684777678456, 0.1602177496533841, 0.09443182774703018, 0.23455088987248018, 0.08579359986470081, 0.2473402168834582, 0.15178974252194166, 0.13161251350538805, 0.09164616902126, 0.1739121405989863, 0.1401093474123627, 0.192776569747366, 0.20201837149215862, 0.40647846821229905, 0.1316006391425617, 0.6142547924537212, 0.39537023927550763, 8.960767518728971, 78.11573714017868, 57.211801037192345, 46.63897097110748, 50.50384238362312, 65.5307212471962, 76.81827396154404, 71.70341402292252, 72.16429889202118, 70.90617880225182, 60.32658509910107, 72.26754695177078, 27.637233696877956, 1.5612878906540573, 3.706653364934027, 0.24102646973915398, 8.923182785511017, 67.6473368704319, 66.79017886519432, 69.52077314257622, 64.36919197440147, 67.8246733546257, 64.60748478770256, 64.0406160056591, 52.726069539785385, 49.824765622615814, 48.63320276141167, 48.641672506928444, 50.78408494591713, 52.810527607798576, 51.04428358376026, 56.043671518564224, 57.57770240306854, 57.87568621337414, 62.267885729670525, 63.19628231227398, 64.35747340321541, 63.63967292010784, 60.15666961669922, 60.051878839731216, 59.55928847193718, 62.34911397099495, 58.36806759238243, 60.829020738601685, 60.59336498379707, 60.46869747340679, 57.78914585709572, 51.23589590191841, 46.124668568372726, 47.03038416802883, 43.94327022135258, 43.25050659477711, 44.030756726861, 49.04216341674328, 46.32589437067509, 52.79037348926067, 55.4886619001627, 51.729341223835945, 39.38239395618439, 42.91421703994274, 38.76391254365444, 46.98862060904503, 48.831612914800644, 46.09957471489906, 42.88848102092743, 42.51882545650005, 43.53789657354355, 45.045712664723396, 42.23703257739544, 43.14933702349663, 43.15613865852356, 43.173868507146835, 41.2886680662632, 43.62966164946556, 42.155257165431976, 41.191043704748154, 42.80275382101536, 42.1553635597229, 39.571851789951324, 42.23557345569134, 43.45034547150135, 39.18089836835861, 43.22307966649532, 51.58005863428116, 46.67013309895992, 43.28904412686825, 41.35338619351387, 45.50384268164635, 46.18437096476555, 55.17116613686085, 56.01155564188957, 52.703054174780846, 50.58841064572334, 43.39298754930496, 42.28297211229801, 44.960027262568474, 40.38394421339035, 44.35490593314171, 41.54387757182121, 45.02128377556801, 42.1521907299757, 49.431927502155304, 54.40177962183952, 58.132210448384285, 56.791402995586395, 51.962261125445366, 53.74355614185333, 56.92224517464638, 53.19945193827152, 51.007224172353745, 49.38924819231033, 51.44379414618015, 53.90594802796841, 55.484425127506256, 56.557840928435326, 62.14221127331257, 57.89636850357056, 57.24658437073231, 53.555169850587845, 55.3457173705101, 49.08964566886425, 48.71695786714554, 48.148797154426575, 49.65827375650406, 46.6658241301775, 49.24362100660801, 52.41838485002518, 61.08059003949165, 61.665029078722, 65.54737955331802, 55.79272918403149, 38.412796184420586, 15.616388730704784, 0.9436389897018671, 0.7738325733225793, 3.9559235516935587, 50.28902091085911, 67.97117829322815, 65.41236519813538, 61.07916131615639, 54.35272425413132, 75.32742395997047, 53.9989860355854, 36.86921641230583, 41.44178844988346, 54.04704585671425, 37.9401433467865, 0.500759573187679, 0.16903110954444855, 0.18113592406734824, 0.2049569200607948, 0.17292506934609264, 0.09714965417515486, 0.14986015856266022, 0.19692612520884722, 0.1854742522118613, 0.15972843684721738, 0.16839252115460113, 0.15285190427675843, 0.14805938175413758], [0.02553694346715929, 0.0581671414693119, 0.08411757808062248, 0.05292168621963356, 0.03578859854314942, 0.03124531518551521, 0.11060812379582785, 0.038310434902086854, 0.062187585499486886, 0.03022068012796808, 0.06010610617522616, 0.025296576677646954, 0.08706983411684632, 0.03493404889013618, 0.09100280120037496, 0.33712545060552657, 0.11661979457130656, 26.842639334499836, 59.00424085557461, 30.928542986512184, 30.315668173134327, 41.705642491579056, 56.89892962574959, 63.68034973740578, 55.854529067873955, 55.784795209765434, 50.36843664944172, 56.018383875489235, 19.671337343752384, 0.316258009406738, 0.9470827924087644, 0.08822112780762836, 9.232125207781792, 61.508853659033775, 56.32712870836258, 62.681793719530106, 61.121160462498665, 61.12785570323467, 59.6214759349823, 59.46032278239727, 54.94145326316357, 44.94376793503761, 44.83561433851719, 47.47661702334881, 47.66409896314144, 46.86516523361206, 47.85114772617817, 50.166230499744415, 54.29367162287235, 56.315828114748, 59.69125539064407, 56.87037035822868, 54.852724224328995, 58.362067714333534, 61.7092777043581, 57.05010071396828, 55.80461114645004, 56.84952847659588, 59.58484210073948, 57.11878962814808, 56.88922494649887, 56.68199926614761, 52.53212794661522, 44.934739619493484, 42.408095598220825, 39.81411539018154, 41.94017730653286, 38.16643640398979, 41.53022110462189, 42.06512600183487, 44.485622718930244, 47.94196665287018, 50.44133573770523, 53.42648595571518, 47.45138257741928, 45.395305305719376, 49.75510396063328, 48.33468697965145, 39.486348778009415, 38.40684570372105, 38.11192072927952, 38.627948239445686, 38.26216846704483, 40.176239758729935, 40.02356015145779, 38.58951710164547, 38.3924824744463, 37.42219693958759, 37.22478233277798, 38.79556864500046, 36.86814486980438, 38.03666576743126, 38.83638605475426, 38.23062635958195, 37.8041410446167, 37.82269544899464, 37.51853697001934, 39.22741547226906, 36.91210851073265, 35.25386989116669, 41.77992470562458, 44.63810473680496, 44.751942828297615, 43.01205798983574, 42.85995215177536, 45.03452226519585, 53.59831653535366, 49.3444599956274, 46.58587262034416, 41.61051079630852, 40.69424696266651, 38.17258447408676, 38.00217121839523, 37.972407415509224, 37.60500892996788, 39.13606457412243, 40.284682139754295, 40.82136154174805, 47.65357732772827, 50.10650910437107, 54.5525973290205, 54.40248638391495, 51.63855269551277, 48.44288617372513, 50.422207564115524, 53.43742176890373, 52.78601512312889, 54.95804697275162, 53.51627893745899, 56.39541104435921, 52.50316210091114, 51.02541759610176, 49.98704731464386, 50.87972201406956, 46.151312738657, 47.04539716243744, 45.543474555015564, 43.21603484451771, 42.21909373998642, 43.94559569656849, 45.13145886361599, 47.369192987680435, 50.884342566132545, 58.02661031484604, 57.79104195535183, 57.76234969496727, 55.271039977669716, 46.260404884815216, 13.765418753027916, 0.5300809373147786, 0.2839159854920581, 1.9791657174937427, 41.95647083222866, 59.73146863281727, 51.01881355047226, 54.12209942936897, 58.325418680906296, 62.0624877512455, 28.16274169832468, 43.23293633759022, 49.83844108879566, 41.49296410381794, 5.3446573577821255, 0.6131161004304886, 0.021344419510569423, 0.32049344619736075, 0.07889597545727156, 0.16035929205827415, 0.05227125315286685, 0.0117396129280678, 0.023876382474554703, 0.03246962878620252, 0.10245631434372626, 0.057127522450173274, 0.06825478747487068, 0.0946468576148618, 0.021421526798803825, 0.07573941358714364, 0.04521945498709101, 0.0211231055072858, 0.028867006476502866, 0.02046460529527394, 0.08721256395801902, 0.021211829262028914, 0.034324163061683066, 0.04584910420817323, 0.03637732574134134, 0.050752652023220435, 0.04461082338821143, 0.01806471307645552, 0.13666036451468244, 0.28566430730279535, 0.3610762779135257, 35.006294175982475, 61.53515584766865, 24.43528801202774, 42.74019777774811, 50.31572587788105, 62.18334786593914, 70.67622274160385, 62.18538075685501, 63.53908471763134, 57.62850567698479, 63.99521604180336, 24.872435554862022, 0.34180976799689233, 1.4507583528757095, 0.12970995856449008, 10.968325193971395, 68.3383297920227, 59.8611518740654, 66.55966803431511, 64.3942478299141, 65.36303624510765, 62.19578459858894, 63.67662973701954, 58.230233788490295, 48.55152614414692, 46.13311171531677, 49.47003185749054, 49.470723420381546, 50.4941301047802, 51.6614730656147, 53.41898135840893, 57.37330377101898, 61.27463802695274, 62.5442411005497, 59.25901718437672, 58.056062534451485, 61.79088592529297, 62.540859282016754, 58.474678471684456, 58.21390226483345, 58.47553722560406, 62.55401037633419, 59.94572393596172, 58.761380687355995, 60.1406192779541, 54.93073783814907, 47.73528814315796, 43.22899594902992, 42.97886677086353, 42.1037433296442, 40.45153118669987, 42.69993133842945, 46.11120209097862, 47.68900662660599, 49.96338978409767, 52.25516840815544, 53.27819511294365, 45.340132266283035, 45.27966611087322, 49.017833322286606, 48.390239998698235, 42.98709332942963, 40.791312754154205, 39.606118351221085, 40.722152665257454, 42.16487064957619, 40.68782910704613, 43.33267718553543, 39.918058812618256, 40.59557385742664, 40.228239968419075, 38.77687744796276, 40.49856126308441, 40.56094251573086, 42.06038385629654, 41.11764684319496, 40.45419864356518, 38.524453192949295, 39.08283323049545, 39.69575934112072, 42.09650471806526, 37.70776301622391, 38.47216039896011, 45.33490754663944, 47.44208447635174, 44.268430173397064, 41.9484456628561, 42.56458260118961, 47.104681581258774, 56.1219435185194, 50.0804653018713, 49.06949155032635, 42.07686737179756, 43.05805452167988, 40.87764412164688, 40.31877391040325, 39.81299825012684, 39.94604051113129, 42.557484582066536, 41.03800691664219, 43.676554933190346, 51.653622686862946, 52.58524909615517, 55.39386838674545, 55.966452062129974, 53.703555688261986, 50.88259465992451, 51.57141789793968, 53.28669525682926, 54.779285565018654, 56.658683717250824, 55.374310836195946, 58.25790390372276, 53.61834526062012, 52.04728156328201, 53.04091304540634, 51.665823832154274, 48.327854946255684, 48.91386330127716, 48.99361342191696, 46.21814735233784, 44.028393253684044, 45.15809163451195, 46.94590710103512, 48.410082533955574, 54.96502719819546, 59.43261466920376, 60.40071152150631, 60.82255728542805, 58.62001687288284, 54.812146201729774, 17.074171006679535, 0.3664824675070122, 0.15144727105507627, 2.004118859767914, 46.28428280353546, 64.47298720479012, 55.626111924648285, 59.21685844659805, 62.35548622906208, 64.79665383696556, 34.38628904521465, 46.360871493816376, 43.94300423562527, 49.6651703864336, 6.754228295758367, 0.4735859844367951, 0.031113157237996347, 0.22204243607120588, 0.0492250486422563, 0.04806240009202156, 0.02566783790825866, 0.04591521472320892, 0.05097591601952445, 0.012272450840100646, 0.07743387774098665, 0.06704325365717523, 0.03896136149705853, 0.13654476759256795, 0.13504420436220244, 0.1079188626317773, 0.17223386268597096, 0.18595780595205724, 0.13564173714257777, 0.16145185218192637, 0.34261407796293497, 0.08324475304107182, 0.13531741860788316, 0.1737637704354711, 0.15145506360568106, 0.1288759330054745, 0.2689479058608413, 0.10850705177290365, 0.2303433875204064, 0.4049966367892921, 0.45604288985487074, 42.446348145604134, 75.91362610459328, 41.3116492331028, 42.16585859656334, 54.57484893500805, 67.13760182261467, 74.62967500090599, 69.45840328931808, 68.82886826992035, 62.45602123439312, 69.25177797675133, 26.848424524068832, 0.3595410712296143, 2.258964297361672, 0.19558071537176147, 13.795477990061045, 73.59898790717125, 61.94896504282951, 69.75455939769745, 66.79131880402565, 68.04892212152481, 66.65040716528893, 65.74636727571487, 61.297364607453346, 49.87861633300781, 48.57954204082489, 51.751311644911766, 53.009959906339645, 53.346922025084496, 54.60162989795208, 55.417803302407265, 59.927306324243546, 63.099079728126526, 65.44598579406738, 59.440552443265915, 61.131571903824806, 63.90636160969734, 64.02024149894714, 61.99407622218132, 59.768638238310814, 58.67543309926987, 65.7097752392292, 63.8708259165287, 60.07665731012821, 61.74706667661667, 56.68793834745884, 50.512255132198334, 45.85720472037792, 44.47809912264347, 46.90154828131199, 43.635615929961205, 46.53577230870724, 48.0588635802269, 48.25096607208252, 51.92960187792778, 54.209756925702095, 53.61519142985344, 46.58048450946808, 46.501710936427116, 50.667852982878685, 51.09277278184891, 45.0497442483902, 44.05265875160694, 41.285312846302986, 42.60923780500889, 43.773556128144264, 44.63733717799187, 45.04911348223686, 43.78364458680153, 41.40878342092037, 40.71839086711407, 41.475697830319405, 42.733403742313385, 42.92578361928463, 44.78300616145134, 44.53089728951454, 42.919897735118866, 41.814700439572334, 42.57552221417427, 40.34323699772358, 44.35141012072563, 41.69323615729809, 40.59803992509842, 46.410436034202576, 48.49681667983532, 44.282143637537956, 42.85609915852547, 43.52931283414364, 46.55060291290283, 57.65522204339504, 52.08086036145687, 49.96609523892403, 44.21120144426823, 45.00002771615982, 42.44603656232357, 42.379471734166145, 41.66063390672207, 41.43362268805504, 43.470784574747086, 43.86123642325401, 44.79200027883053, 52.677945122122765, 53.12713421881199, 56.497735753655434, 59.126229509711266, 54.233365058898926, 52.02390141785145, 54.72559064626694, 56.27988584339619, 55.83901830017567, 58.9596426486969, 55.99148131906986, 60.66357381641865, 54.80516977608204, 53.8204450160265, 56.4604027569294, 54.790829345583916, 49.90416616201401, 51.978391259908676, 52.25185118615627, 47.05227479338646, 45.8333458006382, 47.23604813218117, 48.77573311328888, 51.00614123046398, 56.39421030879021, 61.96520157158375, 63.51942837238312, 63.4082805365324, 61.04249708354473, 53.27432692050934, 19.14107009768486, 0.6552540580742061, 1.1255316669121385, 3.02658224478364, 51.26268446445465, 72.00357511639595, 62.228630036115646, 67.83150538802147, 66.19068503379822, 74.83618631958961, 39.846026077866554, 59.094938188791275, 61.25026233494282, 61.761623695492744, 13.62632341682911, 0.6514955847524107, 0.21048706315923482, 0.40691586036700755, 0.11409003578592092, 0.17722298012813553, 0.18206647335318848, 0.1474124813103117, 0.18260611861478537, 0.13206402130890638, 0.2083813675562851, 0.13581056089606136, 0.1581669581355527, 0.21830891375429928], [0.03262373946199659, 0.05785136134363711, 0.02558498268626863, 0.020509295572992414, 0.044889232667628676, 0.021880220447201282, 0.03158540064760018, 0.06220723756996449, 0.03458251208940055, 0.04895946738542989, 0.008341186057805317, 0.12829541024984792, 0.07632894601556472, 0.02785071872494882, 0.04571625977405347, 0.3824469249229878, 0.4028596670832485, 4.949826244264841, 51.88846908509731, 43.45022767782211, 36.65791355073452, 34.690941497683525, 48.965711519122124, 63.29749748110771, 62.12651051580906, 56.306184232234955, 50.18802992999554, 56.37140013277531, 24.11251623183489, 0.0200400355970487, 1.3886899896897376, 0.11686280340654776, 12.708423770964146, 66.35451704263687, 60.64070664346218, 61.59844525158405, 59.38251435756683, 64.56360474228859, 60.20179219543934, 62.28286072611809, 57.16296225786209, 50.90122506022453, 44.837772622704506, 47.293653041124344, 45.25328032672405, 47.9315210133791, 47.222129479050636, 51.24484062194824, 53.03995169699192, 54.72171485424042, 54.53732594847679, 59.082881435751915, 57.80938357114792, 52.646004036068916, 53.483627289533615, 58.54969784617424, 56.30655661225319, 56.4999358355999, 53.03940832614899, 57.78419092297554, 52.79122084379196, 53.22238750755787, 47.564536705613136, 42.69703209400177, 41.236398071050644, 41.236759051680565, 39.21323463320732, 39.93348978459835, 43.04085664451122, 44.19029876589775, 45.38703314960003, 46.635817140340805, 52.73197062313557, 56.0307902097702, 53.15169230103493, 48.92532728612423, 41.887367740273476, 38.541362285614014, 37.5868459045887, 39.62960489094257, 39.380247071385384, 38.01721081137657, 37.95588590204716, 38.36943671107292, 37.967916056513786, 38.1740739941597, 39.631732776761055, 38.13630402088165, 37.12866269052029, 37.983084842562675, 37.38935150206089, 38.43178376555443, 38.28449226915836, 37.67041862010956, 39.307598769664764, 39.37193311750889, 39.50516536831856, 36.95779725909233, 39.446241930127144, 37.3080662637949, 35.659277737140656, 36.67529381811619, 42.92296417057514, 45.40411703288555, 46.87529928982258, 51.67926751077175, 54.1297560185194, 48.36159333586693, 47.225575894117355, 41.17006503045559, 40.476267859339714, 39.78251248598099, 39.71663162112236, 36.625356897711754, 36.75552651286125, 38.10552567243576, 38.66698354482651, 40.955646336078644, 44.8276461660862, 49.5125287771225, 52.490679770708084, 52.35626578330994, 53.21880429983139, 52.87954330444336, 55.040624141693115, 53.98124858736992, 54.789807200431824, 55.1660668104887, 55.25062747299671, 54.173313081264496, 51.97671554982662, 49.50313948094845, 50.00810958445072, 45.825522020459175, 46.94670885801315, 42.49788857996464, 40.89176796376705, 41.65949396789074, 42.8438676148653, 41.699065044522285, 44.37836967408657, 44.26710784435272, 53.69697444140911, 54.16969187557697, 57.38786838948727, 56.425592824816704, 54.426854476332664, 56.33638881146908, 27.502827309072018, 0.5684538907371461, 0.11927821949939243, 1.7225065897218883, 41.40768148005009, 58.61838676035404, 53.23916740715504, 57.340085953474045, 54.300971031188965, 46.179385632276535, 30.76568752527237, 44.01924714446068, 39.6408636868, 23.024313524365425, 0.6951349962037057, 0.010196113671554485, 0.12995776167372242, 0.03455616213614121, 0.062409765960182995, 0.04489732949878089, 0.033983754765358754, 0.028267902198422235, 0.06705455656629056, 0.044277057313593104, 0.04968990026100073, 0.06263020608457737, 0.014758936849830206, 0.010946721831714967, 0.04426135717949364, 0.03269464425102342, 0.03264214472437743, 0.04974483403202612, 0.01704406149656279, 0.052480063823168166, 0.09304071645601653, 0.01747549420542782, 0.04986626794561744, 0.05164679896552116, 0.02572457138739992, 0.04629858965927269, 0.0803670976893045, 0.024522277308278717, 0.12005907759885304, 0.2750053151976317, 0.4786587122362107, 7.822522446513176, 63.19506257772446, 34.47470270097256, 33.16134877502918, 50.333470925688744, 54.965186789631844, 72.0921103656292, 64.6082903444767, 65.28285294771194, 55.43742164969444, 64.78830948472023, 27.133652418851852, 0.003566096352187742, 1.295153615064919, 0.14708035538205877, 16.407629773020744, 74.88217905163765, 62.80052214860916, 66.52233883738518, 60.64556658267975, 68.27170416712761, 62.914162650704384, 64.66647282242775, 59.37925413250923, 53.075217604637146, 47.71158501505852, 50.1660443097353, 49.742101058363914, 49.07440088689327, 50.0206109136343, 54.40826587378979, 54.85591985285282, 57.18948483467102, 56.857276260852814, 62.361269518733025, 58.449337631464005, 54.784593880176544, 57.12958104908466, 61.637868136167526, 57.794537767767906, 56.586533188819885, 56.31881095468998, 60.770040303468704, 55.67280001938343, 56.373448222875595, 49.48878765106201, 46.0045076161623, 43.071961775422096, 42.130816876888275, 40.83666332066059, 42.77580946683884, 44.629498198628426, 46.54763527214527, 47.15089850127697, 49.6297524869442, 56.95909179747105, 55.882373973727226, 53.28300565481186, 49.816774651408195, 47.910861521959305, 40.583509504795074, 39.42041091620922, 41.79282121360302, 41.475287452340126, 40.432406812906265, 40.48922896385193, 39.33008596301079, 40.70129558444023, 41.412963196635246, 42.187901213765144, 40.82396440207958, 39.335322082042694, 39.37989369034767, 39.35954958200455, 40.47361560165882, 40.34889109432697, 39.11512769758701, 40.41155733168125, 42.30384439229965, 41.24286912381649, 39.728452786803246, 42.173674777150154, 39.18437898159027, 39.76751089096069, 41.35436654090881, 48.21706049144268, 48.50576899945736, 47.13216170668602, 52.43292286992073, 56.69556833803654, 51.431087628006935, 48.442566990852356, 43.483312502503395, 43.10220815241337, 41.94399230182171, 42.550819739699364, 39.60747487843037, 38.59895959496498, 39.9404776096344, 43.397406712174416, 42.11729720234871, 47.22423456609249, 50.57008422911167, 54.567032754421234, 52.97297649085522, 57.647694647312164, 55.016442239284515, 56.40923470258713, 54.983942583203316, 56.144259721040726, 57.17828303575516, 56.267080530524254, 56.706466153264046, 53.44659447669983, 51.97108805179596, 52.41134762763977, 50.83497181534767, 48.381846249103546, 44.80797462165356, 42.94019624590874, 45.09361669421196, 43.63202512264252, 44.692498818039894, 43.77570681273937, 46.37768939137459, 54.14152018725872, 58.3348573744297, 58.912620171904564, 61.35123051702976, 56.49079352617264, 59.452711790800095, 32.529446482658386, 0.4718653595773503, 0.13785710732918233, 1.8308437638916075, 47.08414368331432, 63.86204078793526, 58.95960845053196, 60.40028214454651, 61.62342891097069, 51.06056571006775, 39.99332897365093, 50.41075877845287, 42.88374647498131, 31.866851337254047, 0.8031956758350134, 0.04442820682015736, 0.1312826288631186, 0.02042695243289927, 0.055365504304063506, 0.02706433348066639, 0.025085604502237402, 0.016333225030393805, 0.02902094645833131, 0.047967497957870364, 0.048800510485307314, 0.08408006993704475, 0.017618036654312164, 0.05637836147798225, 0.14872100640786812, 0.10071194818010554, 0.1239130282192491, 0.11160114707308821, 0.19975823495769873, 0.12205913590150885, 0.18650680227437988, 0.1445874071214348, 0.22206360212294385, 0.1740778176463209, 0.11817428225185722, 0.16993372439173982, 0.16472378832986578, 0.2769726002588868, 0.3214121062774211, 0.5981560656800866, 0.48237384413369, 10.135445035994053, 74.58518698811531, 54.6373175829649, 48.75352330505848, 49.447423070669174, 61.077546402812004, 77.11183860898018, 72.74303063750267, 69.45826649665833, 62.610866725444794, 70.41418880224228, 34.199935644865036, 0.13398708921158686, 3.215130502358079, 0.21363587700761855, 21.093998104333878, 78.53719532489777, 68.45542430877686, 69.04884606599808, 63.743494749069214, 68.4919099509716, 65.11666506528854, 70.35027623176575, 62.422849014401436, 56.02100193500519, 49.9323720484972, 51.62453904747963, 52.051442340016365, 53.20777349174023, 53.224743381142616, 59.01294618844986, 58.72976638376713, 59.13398489356041, 59.894069507718086, 64.63220626115799, 61.17294028401375, 57.86126598715782, 58.35913427174091, 62.63920180499554, 59.80549246072769, 59.408987537026405, 57.297167256474495, 65.77301904559135, 56.66236191987991, 58.102515041828156, 50.61857722699642, 49.934442937374115, 46.36617220938206, 46.04036629199982, 44.63532328605652, 44.290339797735214, 47.71036148071289, 49.33439053595066, 49.68312822282314, 51.46692730486393, 58.020226657390594, 60.72499372065067, 55.23722559213638, 52.25961796939373, 48.17516393959522, 41.75381250679493, 40.29702387750149, 44.836150109767914, 42.44385547935963, 44.13399338722229, 43.15650723874569, 42.742116674780846, 41.92137211561203, 44.424123018980026, 44.8393951356411, 41.71933315694332, 41.8008653819561, 42.93351620435715, 42.787110060453415, 44.692248031497, 42.38991737365723, 42.13918402791023, 42.95204401016235, 46.100194081664085, 43.667952194809914, 43.682691603899, 44.50240261852741, 42.231188490986824, 41.10123932361603, 42.29622960090637, 48.585222736001015, 50.75186647474766, 48.8880854845047, 53.220935985445976, 60.20900420844555, 53.07636134326458, 50.01214116811752, 44.93738807737827, 45.82323834300041, 44.3854258954525, 44.70565751194954, 41.43212176859379, 39.13847364485264, 40.733103677630424, 44.46014888584614, 44.83622610569, 49.434621557593346, 52.78851918876171, 53.98751065135002, 54.58772264420986, 59.280463233590126, 58.90237592160702, 57.368744015693665, 57.27153763175011, 57.644548416137695, 61.79660461843014, 58.53451006114483, 59.86516445875168, 54.09641660749912, 51.98860131204128, 54.1648243367672, 53.12638945877552, 52.45280720293522, 47.73555412888527, 45.915166810154915, 47.538853883743286, 46.351755782961845, 45.4879367351532, 46.22235372662544, 48.982878997921944, 57.603977993130684, 60.18355317413807, 62.00945019721985, 62.80536308884621, 62.030208483338356, 61.74192935228348, 32.411063835024834, 0.435226300614886, 0.3797663765726611, 2.7265657810494304, 51.674426570534706, 71.23033180832863, 63.78032997250557, 66.58492147922516, 66.25512957572937, 58.92797514796257, 41.56154662370682, 56.695720329880714, 53.010826259851456, 46.360271126031876, 0.6961988203693181, 0.22840304241981357, 0.14210587309207767, 0.1322522893315181, 0.11469060395029373, 0.14890329272020608, 0.23190039850305766, 0.15877489582635462, 0.14328569493955, 0.1774907173239626, 0.15038337267469615, 0.13061785750323907, 0.10936501901596785, 0.12478845077566803], [0.032922754471655935, 0.05507086796569638, 0.06063157270546071, 0.03320911215269007, 0.025881667352223303, 0.04687370586907491, 0.0227444458505488, 0.007469172742275987, 0.037302806158550084, 0.02114648130373098, 0.03934507411031518, 0.07017130963504314, 0.0754656946810428, 0.035971998077002354, 0.022358824062393978, 0.036541117733577266, 0.20892712811473757, 0.3266889840597287, 25.59368435293436, 50.340048372745514, 35.7537292689085, 32.71354280412197, 36.96615681052208, 56.961842849850655, 54.06776234507561, 56.11505448818207, 52.039883360266685, 53.7916349619627, 33.646054565906525, 0.09712602419313043, 0.47461121692322195, 0.11689919832861051, 23.702816516160965, 69.39940765500069, 55.18910117447376, 57.7960766851902, 55.79706475138664, 64.25785034894943, 62.628121599555016, 59.8246244341135, 58.95482450723648, 50.73465719819069, 47.266317307949066, 43.32745626568794, 43.260279670357704, 45.83261623978615, 44.600034579634666, 48.67579087615013, 48.91530342400074, 49.78215470910072, 53.57161156833172, 55.600497499108315, 57.89500817656517, 62.56767824292183, 58.83673444390297, 53.481020629405975, 56.091385558247566, 53.441753536462784, 56.67944960296154, 52.53253452479839, 50.82951910793781, 46.056785210967064, 44.072109907865524, 42.409733310341835, 40.53441233932972, 40.185819044709206, 39.654269367456436, 41.94131724536419, 45.161222666502, 42.377199456095695, 44.3940894305706, 47.23065622150898, 47.44362719357014, 47.83598653972149, 45.17353020608425, 40.9863942861557, 38.45416076481342, 39.243070632219315, 38.251445442438126, 39.37841936945915, 38.17723162472248, 40.27312695980072, 37.6883764564991, 38.23340781033039, 38.4363055229187, 38.42392198741436, 37.288417518138885, 38.04771177470684, 37.900728061795235, 38.368281573057175, 38.052955493330956, 37.89163514971733, 37.453077882528305, 38.95007215440273, 37.67235651612282, 35.84135636687279, 38.45969706773758, 38.036920353770256, 36.385851949453354, 36.53184771537781, 36.96056731045246, 37.137193232774734, 37.42937095463276, 39.82395686209202, 45.99066875874996, 49.48660656809807, 48.99126134812832, 46.25324606895447, 45.71994088590145, 42.3275513201952, 43.54047663509846, 40.688547268509865, 40.89594013988972, 36.97896972298622, 37.715590596199036, 38.48200187087059, 39.72394622862339, 41.82275980710983, 40.44456996023655, 44.87218737602234, 51.37787148356438, 51.99902035295963, 53.474443182349205, 52.93363340198994, 54.41868111491203, 51.80358923971653, 53.071391209959984, 54.6524977684021, 52.909029722213745, 51.927367597818375, 50.57346984744072, 45.11505514383316, 46.396046206355095, 42.85842463374138, 42.38667994737625, 39.86309856176376, 41.3048741966486, 40.97165487706661, 43.77761051058769, 42.022640481591225, 47.026242390275, 45.5582557618618, 49.03302490711212, 53.468473702669144, 55.401870757341385, 57.121445685625076, 54.00356099009514, 52.96896390616894, 40.53990684449673, 0.7005844975356013, 0.026309198219678365, 1.9480179576203227, 44.240243285894394, 54.863074868917465, 54.61012244224548, 54.08766947686672, 58.84150318801403, 36.80332414805889, 34.81215879321098, 31.724047400057316, 39.72577393054962, 6.712024910375476, 0.9790802816860378, 0.05385752701840829, 0.2034397327224724, 0.08145380968926474, 0.08479378593619913, 0.04587028510286473, 0.13950022228527814, 0.10417476471047848, 0.051780971843982115, 0.048484986400580965, 0.03807050969044212, 0.09573707997333258, 0.07075644112774171, 0.010819549261213979, 0.029299424386408646, 0.03825532301561907, 0.016165828055818565, 0.07626869846717454, 0.02481954827089794, 0.07600570359500125, 0.006781841020710999, 0.046856873959768564, 0.011165008800162468, 0.061006075266050175, 0.05622518219752237, 0.06752566448994912, 0.09549254973535426, 0.05123485505464487, 0.03826114145340398, 0.0731789150449913, 0.2879256312735379, 0.4358792718267068, 34.233814626932144, 56.49994343519211, 32.033611088991165, 47.7198039740324, 45.74634566903114, 63.14022772014141, 62.731590047478676, 61.77502557635307, 57.82261446118355, 60.7344514131546, 38.250210508704185, 0.3557862195884809, 0.8557850320357829, 0.11020872218068689, 29.976982846856117, 72.35270038247108, 58.948551043868065, 61.88948683440685, 60.415568724274635, 66.2454628944397, 67.21821069717407, 64.17236253619194, 60.4406625777483, 55.05208432674408, 48.32014136016369, 45.8980031311512, 45.96757359802723, 48.346679136157036, 49.17460151016712, 51.036182418465614, 52.09770865738392, 53.37032496929169, 56.81469574570656, 57.7648613601923, 61.217709481716156, 62.53161817789078, 58.62516559660435, 56.11000835895538, 58.77072438597679, 57.13327445089817, 58.39117795228958, 55.82459047436714, 52.84689165651798, 50.56252263486385, 45.39745219051838, 45.18922336399555, 43.82188193500042, 39.80647400021553, 42.0242477953434, 42.81404301524162, 47.010184451937675, 44.600771740078926, 45.85730351507664, 50.04739947617054, 50.3424346446991, 50.38292147219181, 48.356197625398636, 42.53602333366871, 40.21218582987785, 41.6754113137722, 39.61542025208473, 40.483103692531586, 41.21451884508133, 41.768643110990524, 39.75218251347542, 40.14223538339138, 39.53747123479843, 40.150712728500366, 38.996756449341774, 40.20140200853348, 40.36715671420097, 40.36916680634022, 40.744658857584, 39.670217111706734, 39.49003078043461, 41.47580802440643, 40.48456281423569, 39.54844884574413, 40.9846767783165, 39.96107630431652, 40.31633824110031, 38.63500066101551, 38.9794559776783, 38.239559680223465, 41.1922824382782, 43.311181738972664, 48.560771048069, 53.75113673508167, 52.32490986585617, 48.22631299495697, 48.810596242547035, 45.60208261013031, 44.65402968227863, 42.480443716049194, 42.612672820687294, 39.37240429222584, 39.95736390352249, 40.11506304144859, 42.16352932155132, 42.882773727178574, 42.418146058917046, 47.80782625079155, 53.09107795357704, 53.99643637239933, 55.183238089084625, 54.61417682468891, 56.87109611928463, 54.704991951584816, 54.254708513617516, 55.71148954331875, 54.467535093426704, 53.80319394171238, 51.932299733161926, 48.69021490216255, 47.90798507630825, 45.278571769595146, 44.615982323884964, 41.45636826753616, 43.270269334316254, 42.868326902389526, 45.85696153342724, 44.474166333675385, 46.76635153591633, 48.86862672865391, 51.369405537843704, 55.84851399064064, 57.354114800691605, 59.436342269182205, 58.17847676575184, 56.52488149702549, 44.054060876369476, 0.5718440213240683, 0.10137319433852099, 2.2768352134153247, 49.16419766843319, 60.26561737060547, 60.422951728105545, 57.32540354132652, 66.40332162380219, 42.49277405440807, 42.321467846632004, 33.21898028254509, 45.72987735271454, 9.06543005257845, 0.8098285761661828, 0.07698512330534868, 0.1637203898280859, 0.0704965484328568, 0.1134037718293257, 0.029682589665753767, 0.09843561056186445, 0.02167776441638125, 0.04341362044215202, 0.03978178348916117, 0.037259316304698586, 0.0350747155607678, 0.06083834246965125, 0.041013629888766445, 0.16425630950834602, 0.11553554650163278, 0.12591241858899593, 0.27628234354779124, 0.10106835718033835, 0.16478249221108854, 0.19913900177925825, 0.0973927001177799, 0.09451766454731114, 0.14233299996703863, 0.2101750049041584, 0.14792650763411075, 0.15890100155957043, 0.12679995299549773, 0.15463001589523628, 0.1569861121242866, 0.34396769595332444, 0.5176439671777189, 42.9590318351984, 66.5987603366375, 46.789716482162476, 49.56576772034168, 49.73058767616749, 69.23271059989929, 67.17401146888733, 69.23605442047119, 63.92254114151001, 69.18473437428474, 41.64210230112076, 0.5927293631248176, 1.6169579909183085, 0.19313101947773248, 35.34408465027809, 76.10176160931587, 63.468043729662895, 63.47571171820164, 63.312130495905876, 68.98933365941048, 69.1322135925293, 66.745994836092, 64.35371160507202, 57.70110838115215, 52.237138375639915, 49.328048676252365, 48.208841532468796, 50.566751807928085, 51.67869374155998, 52.91375666856766, 54.23409461975098, 55.94372548162937, 60.926143527030945, 58.804462775588036, 61.860084012150764, 67.09900349378586, 63.83495584130287, 59.269288033246994, 61.82511828839779, 59.78450618684292, 63.2113941013813, 57.418882325291634, 55.17039477825165, 51.48826315999031, 49.46556709706783, 46.79296150803566, 45.10309338569641, 41.65536358952522, 43.46125468611717, 45.80798976123333, 49.92858745157719, 47.306310161948204, 49.586727395653725, 52.32429049909115, 52.091446593403816, 51.1515898257494, 50.81212744116783, 44.07917372882366, 43.182243257761, 44.084672033786774, 42.66079343855381, 43.8806077837944, 44.04518835246563, 45.05295887589455, 42.7452477067709, 42.497671991586685, 42.56127677857876, 42.82983876764774, 40.867358073592186, 43.007182851433754, 42.040871903300285, 40.597994327545166, 42.68686383962631, 42.39954225718975, 42.774452939629555, 43.89740668237209, 44.01358164846897, 42.72667430341244, 44.01038981974125, 44.34544064104557, 42.46562831103802, 40.53492911159992, 41.398109793663025, 41.293767392635345, 42.70664557814598, 43.82890775799751, 51.891353130340576, 55.22048369050026, 55.9470085054636, 50.41540592908859, 51.03911966085434, 47.18979321420193, 47.219974994659424, 43.95527757704258, 44.65920880436897, 41.497565656900406, 42.24311225116253, 42.84981809556484, 43.5267099738121, 45.12793645262718, 44.39292669296265, 49.50699247419834, 56.683519184589386, 56.52739316225052, 57.210600301623344, 55.423419401049614, 57.47003898024559, 56.31927452981472, 56.53174392879009, 56.83765411376953, 54.70194071531296, 57.02577821910381, 54.32131513953209, 50.209475979208946, 50.72767697274685, 47.530114352703094, 47.53918446600437, 42.651107758283615, 45.404660403728485, 45.30883714556694, 48.48793275654316, 46.697199046611786, 49.74865570664406, 51.22484229505062, 52.84285627305508, 57.58297652006149, 62.98343673348427, 63.7438253313303, 62.709680423140526, 60.00668786466122, 46.39849707484245, 0.8541116968262941, 0.2950714743928984, 3.443026361055672, 53.77795949578285, 65.04262983798981, 64.10550892353058, 63.135515972971916, 70.42467623949051, 50.10607972741127, 46.27020075917244, 40.71681395173073, 59.876043274998665, 16.703415401279926, 1.0451885405927896, 0.1953607428004034, 0.21530511556193233, 0.12181261670775712, 0.3548382892040536, 0.13176282809581608, 0.21991302142851055, 0.19119187665637583, 0.10307046381058171, 0.10022031987318769, 0.10590397621854208, 0.16583543649176136, 0.1613557737437077, 0.11275952827418223], [0.033482782819191925, 0.06274429644690827, 0.07498611143091694, 0.03307798950118013, 0.04455083188076969, 0.05543721803405788, 0.01590474792465102, 0.051460419708746485, 0.05477091784996446, 0.015085307422850747, 0.05581093020737171, 0.008048035870160675, 0.0564504351495998, 0.05725031078327447, 0.06425591767765582, 0.09469359065406024, 0.13641777128214017, 0.12238910960149951, 2.885163095779717, 44.636573418974876, 39.84308883547783, 30.691851787269115, 32.728012427687645, 45.33439837396145, 52.98460006713867, 59.36030454933643, 53.378889709711075, 54.378946647048, 27.999454960227013, 0.2869928703876212, 0.3260889428202063, 0.05359403861803003, 30.017937049269676, 73.71622681617737, 56.82328708469868, 59.994577914476395, 53.45434606075287, 57.946480214595795, 59.967093989253044, 58.1354820728302, 55.970799028873444, 51.30994252860546, 50.73339946568012, 45.12914478778839, 44.11146059632301, 43.232890740036964, 43.71458329260349, 44.538584277033806, 46.073473915457726, 47.363481894135475, 50.21854609251022, 51.72494865953922, 55.32236002385616, 55.10537266731262, 60.27878366410732, 58.39797958731651, 56.91770821809769, 51.791623681783676, 48.99394780397415, 46.84705160558224, 44.8590324819088, 41.84594616293907, 42.75519177317619, 42.481199875473976, 42.920498102903366, 41.30762904882431, 42.49308563768864, 43.103363290429115, 44.82956126332283, 46.866035386919975, 42.16032989323139, 42.692894116044044, 45.20416796207428, 43.04546199738979, 41.30966193974018, 40.651966631412506, 39.35967497527599, 38.298984691500664, 38.43336448073387, 40.34564606845379, 37.22143091261387, 39.50428381562233, 36.970553174614906, 39.211110547184944, 40.02258740365505, 40.283352211117744, 39.397672936320305, 39.672679379582405, 36.1239168047905, 37.00483873486519, 39.07411269843578, 38.31408128142357, 38.275832533836365, 38.855438232421875, 39.647870510816574, 38.69914881885052, 38.85204881429672, 37.15750314295292, 37.6769732683897, 37.55058445036411, 37.41547890007496, 38.41232120990753, 36.9840994477272, 37.49170280992985, 38.731055706739426, 39.2684380710125, 47.549341320991516, 46.1419690400362, 42.206406220793724, 39.168210849165916, 45.38971960544586, 43.740961477160454, 40.74161522090435, 39.63941216468811, 38.032212406396866, 39.10303674638271, 38.463724851608276, 40.7784428447485, 40.134362205863, 41.20851896703243, 44.67404320836067, 48.949444591999054, 52.12520018219948, 52.505172193050385, 54.40386191010475, 54.07988369464874, 53.646820932626724, 54.95453976094723, 52.82845884561539, 50.58785207569599, 47.27227918803692, 46.02931268513203, 45.13706736266613, 43.212440237402916, 43.09663385152817, 41.134217754006386, 41.75864204764366, 41.777150854468346, 43.65961164236069, 47.191601917147636, 46.061116978526115, 46.0976368188858, 46.087666153907776, 49.810691177845, 51.156046986579895, 54.48404900729656, 53.581411242485046, 52.00555980205536, 44.03265282511711, 1.007172055542469, 0.029396918471320532, 3.469473891891539, 47.787748128175735, 58.09231638908386, 54.518893137574196, 55.16986660659313, 51.34512484073639, 35.977244675159454, 32.52468913793564, 34.88428272306919, 22.736805751919746, 0.3351945901522413, 0.019999328796984628, 0.0321641904884018, 0.021097649841976818, 0.037432678291224875, 0.02589078834716929, 0.05527389359485824, 0.013169373414712027, 0.04971711110556498, 0.049996756060863845, 0.04157778086664621, 0.05975098109047394, 0.03568726941011846, 0.07463567671948113, 0.05053949978901073, 0.02463500582962297, 0.02818003747961484, 0.01726857230096357, 0.049800910710473545, 0.062377690337598324, 0.01309393595875008, 0.03909312239557039, 0.036288880291976966, 0.06741819408489391, 0.045714107545791194, 0.0939364887017291, 0.08580884357797913, 0.0220654159784317, 0.03068082467507338, 0.05676620414305944, 0.07703550771111622, 0.21961467806249857, 0.1473021536367014, 5.728052509948611, 57.20051944255829, 36.59248486161232, 33.469474241137505, 47.67071060836315, 49.43119414150715, 63.08287739753723, 65.31274974346161, 60.600398406386375, 61.17636390030384, 34.30183857679367, 0.39550243061967194, 0.542581791523844, 0.09071556778508238, 34.055349603295326, 76.5106500685215, 59.944078624248505, 63.02004016935825, 56.41566015779972, 60.16295447945595, 63.43674100935459, 60.19655987620354, 59.45119567215443, 54.40471686422825, 52.150947600603104, 45.906856656074524, 46.618615463376045, 46.85463219881058, 46.43991105258465, 46.80544003844261, 49.11993384361267, 50.62605902552605, 52.63194479048252, 54.45058420300484, 58.16028334200382, 56.76145300269127, 62.79690854251385, 60.43692357838154, 59.38139721751213, 53.433720767498016, 51.27694129943848, 47.62789450585842, 46.27131029963493, 43.671744391322136, 44.79408636689186, 44.481952115893364, 43.01066346466541, 42.96834513545036, 44.139940068125725, 43.751448914408684, 47.238935977220535, 48.27578254044056, 44.06818471848965, 46.07158161699772, 49.76372189819813, 45.01400716602802, 41.05732128024101, 41.620337069034576, 40.35586751997471, 40.38058139383793, 40.597257167100906, 41.54590666294098, 41.978144869208336, 39.65917490422726, 40.227571204304695, 40.9612662345171, 41.123635321855545, 40.927273258566856, 41.071737706661224, 41.73594206571579, 39.300671741366386, 39.43412058055401, 40.98973050713539, 40.81207104027271, 41.19932346045971, 39.01394672691822, 41.91506065428257, 41.41263261437416, 40.187464356422424, 40.51752984523773, 40.30180782079697, 40.97558006644249, 39.81554791331291, 40.872278809547424, 39.15924713015556, 39.63585555553436, 40.92788502573967, 43.44891294836998, 50.11838346719742, 48.93679887056351, 43.952237740159035, 42.038094252347946, 45.680806785821915, 44.7652231156826, 42.531269788742065, 42.55914889276028, 40.46719774603844, 40.16249969601631, 41.592723950743675, 43.01383249461651, 42.96744838356972, 43.83702032268047, 48.08201193809509, 50.71892984211445, 56.17100648581982, 55.411320850253105, 56.310952976346016, 55.424004569649696, 55.8297847956419, 57.9561772942543, 53.94535571336746, 53.84024195373058, 48.88009071350098, 48.60989861190319, 46.63431242108345, 45.313187912106514, 45.6633847206831, 44.96430963277817, 42.96928748488426, 44.33618813753128, 45.98981760442257, 49.21764940023422, 48.18537399172783, 46.906108036637306, 48.90851318836212, 52.302266880869865, 54.58868399262428, 57.973124384880066, 56.805200055241585, 56.40479654073715, 48.95593084394932, 1.230604697484523, 0.11018312550731935, 3.7443433050066233, 52.46085897088051, 62.99640543758869, 58.61186631023884, 61.906338930130005, 58.388556092977524, 44.47638541460037, 37.36336089670658, 39.028708934783936, 30.29394093900919, 0.25323420530185103, 0.05807885929243639, 0.07397207053145394, 0.08309853510581888, 0.06247911223908886, 0.02545801235100953, 0.04354155928012915, 0.023395214739139192, 0.03973264218075201, 0.014912141177774174, 0.04295198232284747, 0.06218414564500563, 0.0056064043383230455, 0.03671188962471206, 0.06009242468280718, 0.17495551117463037, 0.18121312226867303, 0.13818308827467263, 0.12433620082447305, 0.2136224738205783, 0.15961306256940588, 0.1238607513369061, 0.13124032644554973, 0.1540856357314624, 0.0801326087093912, 0.1929304318036884, 0.13428296864731237, 0.14221836783690378, 0.16467421286506578, 0.17345160827971995, 0.1865763118257746, 0.4061229794751853, 0.2585922146681696, 8.87855987995863, 74.34629380702972, 49.99838210642338, 41.62821404635906, 46.941883116960526, 56.883183270692825, 70.49302697181702, 73.52540105581284, 64.86935153603554, 70.5590370297432, 41.3036734610796, 1.1617968021892011, 1.10575539059937, 0.3281888348283246, 39.55138608813286, 81.0312294960022, 62.29735694825649, 67.97870188951492, 60.39184659719467, 65.31584277749062, 63.68929445743561, 63.0664736777544, 61.055104807019234, 58.833257630467415, 55.943968668580055, 50.36943979561329, 48.93554873764515, 49.282059744000435, 47.74580217897892, 49.10408869385719, 51.736260652542114, 54.03221145272255, 57.14898280799389, 57.50539988279343, 60.04710249602795, 60.1241509616375, 66.34472876787186, 62.690179869532585, 62.05945931375027, 56.01129725575447, 55.865841060876846, 51.78573779761791, 49.228885397315025, 46.84064134955406, 48.24341207742691, 47.81709395349026, 48.063818514347076, 46.68886989355087, 46.793900057673454, 46.435286700725555, 48.192342817783356, 50.07106460630894, 48.66043210029602, 48.16371135413647, 49.820255264639854, 45.68005822598934, 43.8115730881691, 44.57317382097244, 42.329075038433075, 43.03070738911629, 43.24464350938797, 44.89043399691582, 42.705121859908104, 42.75000125169754, 41.66183844208717, 43.71680237352848, 44.96158517897129, 44.42312367260456, 44.5573590695858, 45.006183385849, 41.58342964947224, 42.61211805045605, 44.10551771521568, 43.989635333418846, 43.06571491062641, 41.7378343641758, 45.74709042906761, 43.64059366285801, 43.35060082376003, 43.76865819096565, 43.20311173796654, 43.0722239613533, 43.02196405827999, 44.03107970952988, 42.898991256952286, 42.147042006254196, 44.29095156490803, 45.68308286368847, 51.938463002443314, 51.916914358735085, 46.37235447764397, 44.03445392847061, 48.981294482946396, 47.59365074336529, 45.68189352750778, 44.753770530223846, 42.242971658706665, 41.47695556282997, 42.910645231604576, 43.40439073741436, 43.88565771281719, 45.9106070548296, 49.610711708664894, 52.699049189686775, 58.08963753283024, 57.276963740587234, 58.05721387267113, 56.85396283864975, 58.2492745667696, 60.272688791155815, 57.28861391544342, 55.790593698620796, 52.061200216412544, 50.96467025578022, 49.78687785565853, 48.09302754700184, 48.53356830775738, 47.5166554749012, 46.300355941057205, 47.57478095591068, 49.0010230243206, 51.08865760266781, 51.22099690139294, 50.093282014131546, 53.29711049795151, 56.036881282925606, 58.34869243204594, 61.385481879115105, 63.45100164413452, 60.08364513516426, 54.17131818830967, 1.763380877673626, 0.21902380976825953, 4.615106005221605, 58.79255801439285, 68.50415289402008, 63.46123069524765, 65.33566251397133, 64.41177248954773, 51.37195900082588, 45.545541644096375, 49.215259328484535, 42.93863832950592, 0.6411213101819158, 0.2084587884019129, 0.14643899135990068, 0.20961331785656512, 0.0825735621037893, 0.13310828246176243, 0.14649221819126979, 0.0960696734546218, 0.15559880062937737, 0.2708026219625026, 0.16537076298845932, 0.17703325749607757, 0.09161568159470335, 0.2106896843179129, 0.322248981683515], [0.01827739404689055, 0.05045409343438223, 0.0210554921432049, 0.015958366238919552, 0.008461873185297009, 0.06298067048192024, 0.05669754435075447, 0.07097440247889608, 0.03974517334427219, 0.024604093523521442, 0.03606366444728337, 0.06223572119779419, 0.12076772472937591, 0.022856664145365357, 0.032471046288264915, 0.016968188028840814, 0.06644489709287882, 0.27092406700830907, 0.3181244811275974, 18.828185386955738, 55.57636119425297, 34.1451957821846, 33.18737357854843, 38.67570027709007, 59.20246861875057, 60.347430780529976, 57.198433354496956, 48.01799677312374, 39.50663588941097, 2.0594070805236697, 0.20331810956122354, 0.3386708692414686, 25.908020585775375, 75.8093672990799, 58.77713464200497, 57.54174493253231, 52.8642263263464, 55.101139694452286, 57.60989807546139, 57.57883474230766, 54.556530117988586, 48.990991562604904, 46.808419078588486, 45.06417967379093, 45.69964997470379, 43.88582870364189, 44.893880411982536, 42.93674223124981, 43.46099629998207, 44.141775369644165, 45.396711230278015, 44.48028400540352, 44.51272666454315, 47.954046204686165, 48.22026751935482, 45.04485011100769, 45.796434581279755, 44.36208374798298, 45.03985337913036, 40.6947485357523, 42.16208919882774, 43.34309242665768, 42.79415488243103, 40.79804979264736, 40.58251015841961, 38.34149681031704, 42.45029613375664, 41.49036884307861, 47.30354391038418, 46.13209716975689, 40.24200662970543, 45.27958631515503, 41.36002063751221, 39.95800606906414, 40.66194489598274, 38.358565494418144, 37.65501044690609, 39.48651596903801, 37.895624935626984, 38.03641878068447, 38.74467417597771, 39.37376841902733, 39.12696786224842, 39.14278641343117, 39.29769650101662, 38.92147108912468, 37.65054188668728, 37.62412570416927, 38.99946570396423, 38.88794168829918, 38.5753970593214, 38.84474940598011, 38.58282946050167, 38.78815524280071, 37.135494723916054, 38.10638062655926, 39.331609681248665, 38.67460213601589, 37.31366716325283, 36.746482998132706, 37.57665865123272, 35.4016287624836, 36.29698991775513, 37.42144837975502, 37.224318757653236, 39.39471669495106, 39.31313507258892, 44.88031893968582, 41.87181897461414, 39.31990250945091, 45.70071391761303, 46.641201451420784, 38.00929203629494, 40.14549560844898, 37.98530772328377, 39.62767079472542, 38.785833567380905, 41.002691611647606, 41.39964871108532, 42.99259163439274, 41.41327477991581, 42.79937960207462, 46.695861518383026, 51.718253418803215, 52.88233235478401, 54.722022637724876, 53.00410442054272, 52.72795043885708, 47.921888530254364, 47.77791425585747, 45.256962329149246, 45.43939433991909, 43.12465354800224, 41.291992887854576, 41.2293304502964, 42.66589276492596, 41.46687850356102, 42.498846128582954, 44.60878171026707, 50.89437782764435, 44.02196019887924, 46.80578202009201, 44.651373624801636, 46.33606642484665, 48.10143269598484, 54.669068679213524, 52.656491473317146, 52.40041181445122, 44.80287529528141, 1.3809286686591804, 0.2144442984717898, 5.738705238327384, 46.43931448459625, 60.32066881656647, 51.14457160234451, 56.81857913732529, 48.33685666322708, 25.681851021945477, 32.5528684258461, 31.213628388941288, 4.521684218198061, 0.7168708986137062, 0.051527988543966785, 0.1569382584420964, 0.02984970276884269, 0.06820263675763272, 0.03783041378483176, 0.04258288630808238, 0.05700865265680477, 0.08630811600596644, 0.03145162481814623, 0.0895396496343892, 0.06028222524037119, 0.04327324691985268, 0.04160105461778585, 0.10176253985264339, 0.021539164627029095, 0.025476079936197493, 0.024685724201845005, 0.07204858702607453, 0.0267944106599316, 0.036896346719004214, 0.01101582134651835, 0.06609689662582241, 0.024381499315495603, 0.010877123222599039, 0.03607435879530385, 0.09817176221986301, 0.05177929830097128, 0.027576430220506154, 0.045139562789699994, 0.03483064174361061, 0.005579334965659655, 0.3073039383161813, 0.31326899479608983, 32.085645496845245, 60.3095468133688, 28.77608198672533, 45.148793533444405, 45.63793368637562, 67.64919877052307, 68.13935726881027, 61.75749711692333, 55.50522141158581, 49.818188175559044, 2.676145574077964, 0.37233347073197365, 0.28534503537230194, 28.55308335274458, 80.03859356045723, 62.17932388186455, 63.187257796525955, 57.07127317786217, 60.39065346121788, 60.58415807783604, 60.88617727160454, 57.268516793847084, 52.82936319708824, 48.65040823817253, 48.627028092741966, 47.58487321436405, 45.68196952342987, 45.68784400820732, 44.519323110580444, 46.27135589718819, 45.65949372947216, 46.0264628380537, 47.746474742889404, 48.86876732110977, 51.90722867846489, 51.34306915104389, 49.74310040473938, 49.4795997440815, 46.73769347369671, 46.83716453611851, 43.37874211370945, 45.83204247057438, 44.24859903752804, 46.140574514865875, 42.92350374162197, 42.324838265776634, 41.2553970515728, 44.93184417486191, 44.57756258547306, 47.767278626561165, 48.28861065208912, 42.98963539302349, 48.34490083158016, 44.89790819585323, 42.91694149374962, 43.26641634106636, 40.651769042015076, 39.04832348227501, 40.94714619219303, 39.90026816725731, 40.23026905953884, 41.22823990881443, 41.64742961525917, 41.033956333994865, 41.63237102329731, 41.57965645194054, 41.12707793712616, 40.591614469885826, 40.087100341916084, 41.07700042426586, 41.573926359415054, 40.14946259558201, 40.052894577383995, 41.88433550298214, 41.72503665089607, 38.52503456175327, 40.50384297966957, 40.17636515200138, 41.93879798054695, 38.799501433968544, 39.467235803604126, 39.66591954231262, 39.72917094826698, 39.82201896607876, 40.854564160108566, 39.68730479478836, 41.48214988410473, 43.157172203063965, 47.54669666290283, 44.44600984454155, 40.75461432337761, 46.889924705028534, 48.74691545963287, 40.09619705379009, 40.474922731518745, 41.33366905152798, 41.799155473709106, 40.73115058243275, 42.782770693302155, 42.177318781614304, 42.902696058154106, 44.226233437657356, 45.126473531126976, 47.75591343641281, 54.38672862946987, 55.45766316354275, 57.201811373233795, 54.11019466817379, 53.94347861409187, 49.11221645772457, 50.6925630569458, 47.132199704647064, 47.922583892941475, 46.099601313471794, 42.908353954553604, 43.68897266685963, 45.13860248029232, 43.914756551384926, 45.113250240683556, 47.78439670801163, 53.68220843374729, 45.38528524339199, 49.27142411470413, 47.018570601940155, 48.60106408596039, 50.31003378331661, 58.48106972873211, 55.57034611701965, 59.02004420757294, 49.40434858202934, 2.1205666987225413, 0.03878658571920823, 6.354643162339926, 53.240675926208496, 63.60566474497318, 56.83046869933605, 60.81540606915951, 53.644848838448524, 33.32233093678951, 36.707774475216866, 39.70626957714558, 7.672197762876749, 0.6767825153656304, 0.124668104108423, 0.11028559383703396, 0.022454197460319847, 0.11680307536153123, 0.05661293580487836, 0.08321615809109062, 0.01629888400202617, 0.060408431163523346, 0.11627894840785302, 0.039950618374859914, 0.04064911663590465, 0.02408178297628183, 0.021149347849132027, 0.057822588278213516, 0.19737502065254375, 0.10418602309073322, 0.16928231169003993, 0.1526017114520073, 0.1322340324986726, 0.17948951397556812, 0.19617530924733728, 0.2756682608742267, 0.11588143926928751, 0.15614355186698958, 0.12961061467649415, 0.15661753190215677, 0.13452606654027477, 0.11497016355860978, 0.19098069111350924, 0.16913554456550628, 0.18144887289963663, 0.39893759472761303, 0.24915818183217198, 43.916496858000755, 76.10334992408752, 44.30080063641071, 52.362695038318634, 50.07707208395004, 75.84237992763519, 71.98047235608101, 68.82658079266548, 61.742047145962715, 57.53319539129734, 4.039177559316158, 0.7158913824241608, 0.32467197510413826, 33.720393776893616, 82.87384942173958, 64.38372999429703, 67.14463904500008, 59.714487344026566, 63.89027327299118, 63.04899841547012, 62.70108908414841, 60.124595537781715, 56.56670965254307, 51.16371117532253, 51.46110601723194, 49.21980768442154, 49.76535581052303, 49.27431955933571, 46.51005528867245, 48.42034958302975, 47.231682166457176, 50.94271883368492, 49.74444933235645, 49.37218330800533, 54.520230665802956, 52.7083320915699, 50.841902643442154, 50.95077060163021, 49.3194193392992, 48.22905644774437, 47.03622825443745, 47.23213814198971, 46.58864267170429, 47.2974756360054, 45.10009914636612, 44.09811191260815, 42.90779158473015, 47.44365379214287, 45.620412826538086, 51.50543823838234, 51.38901248574257, 44.9591951072216, 50.249959006905556, 46.26027189195156, 45.72944037616253, 46.31298266351223, 44.23357844352722, 42.06633813679218, 43.74988719820976, 43.94499912858009, 43.438634499907494, 44.46470484137535, 44.72638159990311, 44.22847531735897, 45.698643028736115, 44.16072875261307, 43.640692457556725, 41.995217353105545, 42.41447165608406, 44.15044270455837, 43.593358397483826, 44.41333159804344, 41.55836999416351, 45.168199092149734, 46.11206844449043, 41.4511701464653, 43.50116014480591, 43.75516131520271, 44.67628888785839, 39.91453640162945, 40.73080860078335, 41.94907642900944, 41.271420791745186, 42.57285475730896, 43.83980557322502, 41.30704768002033, 42.891023084521294, 44.84449826180935, 50.63107095658779, 47.68008850514889, 42.337187603116035, 48.60660798847675, 51.71580255031586, 42.115879878401756, 43.28556351363659, 43.259037137031555, 45.14676444232464, 43.03972810506821, 44.725154265761375, 45.53987614810467, 46.00155897438526, 46.121830120682716, 48.351987451314926, 49.07474286854267, 56.354840621352196, 57.47731178998947, 59.622448682785034, 55.14617867767811, 55.77685363590717, 52.40059420466423, 53.03177833557129, 49.43888492882252, 50.4134376347065, 48.928667306900024, 45.125048607587814, 46.80116906762123, 47.42885738611221, 47.301020845770836, 47.90655255317688, 50.51306068897247, 55.0672797113657, 46.87357418239117, 52.341343984007835, 50.52438028156757, 51.530680283904076, 52.89156585931778, 59.42776992917061, 59.81411799788475, 62.31179237365723, 54.187212735414505, 3.161584963090718, 0.32490299083292484, 7.765624299645424, 58.08678388595581, 69.35876503586769, 64.0892305970192, 68.90940114855766, 58.1216774135828, 41.814100071787834, 45.22731252014637, 52.905651703476906, 16.871693171560764, 0.942224693717435, 0.21731535613071173, 0.4367610620101914, 0.22590529988519847, 0.24267730303108692, 0.14696389756863937, 0.18934143532533199, 0.21535052015678957, 0.22089167672675103, 0.20332740125013515, 0.1920332049485296, 0.12298766654566862, 0.08281376562081277, 0.07559230507467873, 0.32194704632274806], [0.03358875779667869, 0.05322713936038781, 0.016981144071905874, 0.03851422865409404, 0.05178955849260092, 0.008437571559625212, 0.03866307008138392, 0.02324348079127958, 0.029393877521215472, 0.004981418587703956, 0.02136577295459574, 0.07071360436384566, 0.04928501417452935, 0.06931699375854805, 0.05483585948240943, 0.04811353406694252, 0.019077317920164205, 0.033479821649962105, 0.24059186805970967, 0.4150609904900193, 34.2807687073946, 50.261183604598045, 41.89365640282631, 34.89219769835472, 46.09027661383152, 54.43003490567207, 62.09102801978588, 46.19285210967064, 45.60195341706276, 6.037107976153493, 0.36367382446769625, 0.05984538598568179, 27.075602933764458, 78.34240257740021, 59.71499651670456, 60.00467777252197, 54.526979103684425, 54.05490003526211, 55.39853073656559, 52.88800925016403, 49.33255523443222, 51.21871702373028, 47.13366262614727, 45.29675379395485, 43.3269888907671, 42.63124622404575, 43.63877736032009, 44.93659771978855, 42.99911588430405, 43.121663108468056, 43.78495551645756, 43.59412595629692, 42.422082647681236, 42.96316601336002, 42.731671035289764, 42.325260043144226, 42.32509285211563, 43.08999940752983, 43.74539203941822, 43.13715107738972, 42.42916166782379, 41.82691678404808, 41.87523879110813, 41.99091978371143, 41.23974569141865, 41.09090767800808, 43.362239599227905, 41.28586381673813, 47.051378041505814, 45.433147475123405, 45.064464658498764, 41.31321094930172, 42.02482916414738, 40.60537353157997, 40.1486000418663, 40.13904735445976, 38.703005611896515, 38.29397656023502, 37.02248878777027, 39.12682726979256, 37.43869185447693, 40.20792245864868, 37.62057289481163, 38.8523755967617, 38.72011989355087, 39.90923948585987, 41.19509428739548, 39.8006147146225, 39.69553515315056, 40.38523614406586, 39.84878093004227, 39.04530644416809, 38.2166089117527, 37.94816851615906, 38.04453894495964, 39.75612670183182, 40.547776222229004, 37.80899338424206, 37.77283072471619, 38.309088349342346, 36.90936125814915, 36.87286041676998, 36.54870741069317, 36.94495774805546, 36.48135982453823, 37.28149428963661, 39.95815806090832, 41.725116446614265, 41.22165106236935, 41.16816133260727, 41.75751730799675, 45.98863206803799, 40.13754643499851, 40.85739120841026, 39.18823957443237, 38.941739201545715, 38.964727967977524, 40.374824702739716, 40.00692844390869, 40.7170495390892, 41.30921736359596, 40.3643524646759, 39.68961127102375, 42.74938568472862, 47.51345984637737, 50.714047104120255, 47.719986364245415, 49.243951588869095, 45.02720005810261, 45.37751466035843, 45.23607484996319, 44.657194912433624, 41.87248393893242, 43.40912528336048, 41.665862426161766, 42.90630206465721, 41.22490368783474, 45.409847125411034, 45.08571311831474, 47.31374256312847, 45.88432386517525, 48.033298552036285, 46.41944155097008, 47.40915544331074, 48.34977976977825, 56.83876745402813, 51.72814428806305, 54.439006224274635, 46.26006670296192, 0.9132948867045343, 0.1051273186749313, 5.606748769059777, 50.2981062233448, 54.70454357564449, 54.414033964276314, 55.93813598155975, 32.62709744274616, 27.089912965893745, 26.713051088154316, 20.792887061834335, 0.3734167094808072, 0.2370252992841415, 0.0722283055074513, 0.11930728942388669, 0.07405189593555406, 0.03503847648971714, 0.01732643384457333, 0.021406891646620352, 0.04421322519192472, 0.03812632290646434, 0.013526974489650456, 0.023349555958702695, 0.01680166864389321, 0.06390265538357198, 0.08390765418880619, 0.08698037563590333, 0.014494467886834173, 0.031927463933243416, 0.01299047593420255, 0.035361730042495765, 0.06897237748489715, 0.021780980459880084, 0.048767956177471206, 0.06270231315284036, 0.03125019109575078, 0.09373699940624647, 0.059859178800252266, 0.05993694103381131, 0.02311806340003386, 0.06668680754955858, 0.054082319838926196, 0.059651280971593224, 0.15663535828934982, 0.0264438850354054, 0.2511049242457375, 2.9029231052845716, 46.084234938025475, 44.962899908423424, 45.11181391775608, 45.189774334430695, 52.96770237386227, 63.57473820447922, 66.34402960538864, 53.07924538850784, 53.270405530929565, 9.424470886588097, 0.25684374442789704, 0.023247596000146586, 29.86625298857689, 81.76564648747444, 61.36308588087559, 64.09597143530846, 57.432037219405174, 58.13880689442158, 55.825297236442566, 57.90813647210598, 52.46243588626385, 53.841761872172356, 50.14079846441746, 48.82810950279236, 46.2537856400013, 46.60666510462761, 45.10129228234291, 46.03657029569149, 44.90198537707329, 43.7843057513237, 44.35667663812637, 46.25771842896938, 46.005943939089775, 44.568458274006844, 44.679799899458885, 44.31945763528347, 45.42957566678524, 45.32762333750725, 45.00051788985729, 45.29703117907047, 43.58893543481827, 45.125873163342476, 43.822178319096565, 44.36747185885906, 42.08966128528118, 42.60951519012451, 45.963017642498016, 44.42198373377323, 48.44786390662193, 48.42967428267002, 46.070608869194984, 43.43492969870567, 44.61933754384518, 42.39803373813629, 40.606680661439896, 42.214742973446846, 41.30617372691631, 41.38774394989014, 40.352390706539154, 40.91189928352833, 41.03619821369648, 41.67042598128319, 41.648007184267044, 40.7776752859354, 41.30142778158188, 43.06283086538315, 43.27972322702408, 41.91249959170818, 42.78807520866394, 41.46923057734966, 41.91221460700035, 40.75063593685627, 40.18363036215305, 39.345801919698715, 40.37004455924034, 41.798220723867416, 41.951356306672096, 39.662492126226425, 41.26128673553467, 41.386953592300415, 39.33106251060963, 40.470754355192184, 39.59203250706196, 39.03911657631397, 38.50983917713165, 40.14904461801052, 42.58663281798363, 43.74582141637802, 44.696530401706696, 42.08594128489494, 45.454635322093964, 49.16946038603783, 42.92099207639694, 42.720549032092094, 42.84529633820057, 40.83711929619312, 41.129046231508255, 43.18250544369221, 42.603017538785934, 41.8926190584898, 43.01637075841427, 43.94101694226265, 43.000229224562645, 44.75674197077751, 48.27614352107048, 53.04261535406113, 50.195454731583595, 51.2606667727232, 46.166857704520226, 46.30573645234108, 45.340132266283035, 47.159220054745674, 45.299254059791565, 44.64833378791809, 42.69186817109585, 45.49843557178974, 43.768513798713684, 46.79906018078327, 48.14025521278381, 48.828861862421036, 47.86997951567173, 50.712606981396675, 47.86048382520676, 50.15263482928276, 49.66501459479332, 58.22838708758354, 55.10181225836277, 60.311241522431374, 49.2298049479723, 0.9083263564389199, 0.11758463850128464, 6.671153828501701, 56.16305351257324, 62.38780729472637, 61.654313653707504, 63.1519690901041, 39.679952189326286, 33.83132502436638, 33.88393320143223, 32.95185461640358, 1.694130899850279, 0.4802409413969144, 0.0699299261032138, 0.05270154666504823, 0.05145357339642942, 0.011925352082471363, 0.009273847681470215, 0.029897402455389965, 0.04717114752565976, 0.06330374962999485, 0.012883764375146711, 0.06221225077752024, 0.008896448889572639, 0.04335704281402286, 0.039773423195583746, 0.01189115670058527, 0.1324847002979368, 0.13806582894176245, 0.10358887622714974, 0.10953987643006258, 0.14656278159236535, 0.15755811502458528, 0.2343857620144263, 0.2646843862021342, 0.2092345108394511, 0.15158237161813304, 0.11685276214848273, 0.21208447666140273, 0.11512704615597613, 0.2674243360524997, 0.21453577559441328, 0.1621032351977192, 0.2708918577991426, 0.16710217867512256, 0.3043580276425928, 3.6651047319173813, 58.174057602882385, 60.14952979981899, 59.87832695245743, 49.560607597231865, 60.80398008227348, 70.2715976536274, 74.24032509326935, 59.885398373007774, 63.87739956378937, 11.943820249289274, 0.6335224898066372, 0.10083651766763069, 31.921251118183136, 83.63803401589394, 65.72704911231995, 66.98187857866287, 62.174870520830154, 61.37129344046116, 60.564528331160545, 61.61834478378296, 52.41369970142841, 56.77598722279072, 53.29644553363323, 51.8943739682436, 47.7362684905529, 48.63541804254055, 47.4625463783741, 49.86629359424114, 47.73640148341656, 47.8817854821682, 47.29086019098759, 49.37178812921047, 48.823861330747604, 47.43006192147732, 46.4927776157856, 46.41930475831032, 46.76678851246834, 48.54820892214775, 48.26244905591011, 48.409482166171074, 45.63815787434578, 47.56629601120949, 45.142387077212334, 46.580883488059044, 44.902847930788994, 46.56804017722607, 49.4070540368557, 47.13174372911453, 51.441274881362915, 50.20971156656742, 49.82327230274677, 45.718675553798676, 48.06210480630398, 45.796107798814774, 44.90428805351257, 45.086366683244705, 43.81962485611439, 43.59283782541752, 42.594692185521126, 44.56766791641712, 42.886505126953125, 44.258113726973534, 43.36335673928261, 43.41281868517399, 41.921573504805565, 45.589087307453156, 46.15481615066528, 45.59368886053562, 46.02583967149258, 44.86314386129379, 44.18457627296448, 43.18253584206104, 42.37189494073391, 43.14319655299187, 42.475701570510864, 43.954605013132095, 44.737211018800735, 43.613911494612694, 46.19681529700756, 45.69325491786003, 41.81128442287445, 42.17481851577759, 42.57943220436573, 43.09518612921238, 41.28530144691467, 43.80803167819977, 44.47762794792652, 45.50318531692028, 48.41142386198044, 46.7525240778923, 47.24641017615795, 52.18239851295948, 45.3570793569088, 45.336735248565674, 43.93343634903431, 43.01081545650959, 44.755518436431885, 45.391934886574745, 43.60038802027702, 43.22328105568886, 44.71592076122761, 45.86334519088268, 44.543607607483864, 46.92139461636543, 48.46513018012047, 55.11203370988369, 52.29057490825653, 53.628315925598145, 49.08690221607685, 48.335503935813904, 49.414349645376205, 48.77928212285042, 48.00121307373047, 48.03758092224598, 45.446302369236946, 50.01736208796501, 46.30521968007088, 51.32796496152878, 50.85629627108574, 52.899572029709816, 50.8068685233593, 52.79479265213013, 51.30179576575756, 52.188303396105766, 53.771735429763794, 60.6327498704195, 59.35560800135136, 62.01519548892975, 53.193691447377205, 1.7907082987949252, 0.29969315452035517, 8.058975208550692, 62.37024083733559, 66.98240295052528, 64.846081584692, 69.78361263871193, 46.29276394844055, 43.29382807016373, 40.77927879989147, 49.12062160670757, 4.829197442159057, 0.7523226994089782, 0.16040585440350696, 0.19983071309980005, 0.20560756092891097, 0.11604228493524715, 0.10199161115451716, 0.14090353448409587, 0.14313869032775983, 0.23272275750059634, 0.12492831592680886, 0.11570365779334679, 0.25068320624995977, 0.1653837357298471, 0.13642609817907214, 0.16999806859530509], [0.011706784025591332, 0.02448613286105683, 0.03350272432726342, 0.024601425502623897, 0.07276665201061405, 0.06823981093475595, 0.06557437271112576, 0.051218602020526305, 0.011114375774923246, 0.04207076730381232, 0.04592742305248976, 0.07558931421954185, 0.07991270293132402, 0.021799454370921012, 0.03723606852872763, 0.03227610264730174, 0.06334401114145294, 0.08970696682808921, 0.2369250648189336, 0.19161260017426684, 22.826064862310886, 52.032732143998146, 55.19781030714512, 36.374121978878975, 37.428234815597534, 61.90441243350506, 59.361455887556076, 50.236940905451775, 54.392492920160294, 13.669991623610258, 0.14158816571580246, 0.11932021763641387, 17.245955988764763, 74.62397530674934, 60.20077385008335, 63.61536182463169, 54.47433292865753, 52.16276876628399, 50.57433620095253, 49.6259830892086, 48.84284511208534, 46.59236267209053, 44.2796965688467, 44.93230774998665, 41.769243478775024, 43.028647899627686, 42.61257402598858, 43.32483820617199, 43.577570244669914, 41.96284309029579, 43.14984239637852, 43.208066672086716, 43.71285818517208, 44.26876835525036, 44.17678289115429, 44.14298750460148, 43.62046614289284, 42.56867118179798, 43.17033849656582, 41.8943327665329, 42.350547686219215, 42.82489903271198, 41.12896643579006, 42.75499038398266, 41.047050431370735, 44.73675884306431, 42.74158090353012, 42.79149502515793, 42.92683236300945, 42.576221376657486, 41.29717580974102, 39.52485591173172, 41.23550131917, 39.88506518304348, 40.07672689855099, 40.526759549975395, 39.86293517053127, 39.27196808159351, 38.73577505350113, 39.22862000763416, 40.1263028383255, 38.985626846551895, 39.55163687467575, 39.473794251680374, 38.97907219827175, 38.248401805758476, 38.43059062957764, 38.304885774850845, 39.46122832596302, 39.88391004502773, 39.77032653987408, 40.76881416141987, 38.4556844830513, 37.455684542655945, 36.574891805648804, 35.67233003675938, 38.12715031206608, 38.81436623632908, 36.88645228743553, 38.373118713498116, 39.284454211592674, 37.87927061319351, 37.282003462314606, 38.595068603754044, 36.77763372659683, 38.93462598323822, 38.23577128350735, 39.23617780208588, 39.35954198241234, 40.98588891327381, 43.05952504277229, 42.366309240460396, 39.7744607180357, 38.935085758566856, 39.76443685591221, 40.63259147107601, 39.483449533581734, 39.26897384226322, 40.30073247849941, 40.51722206175327, 41.236922442913055, 41.933596059679985, 41.60726957023144, 39.989506378769875, 40.915334299206734, 41.792722418904305, 43.25165793299675, 42.51604400575161, 41.72036290168762, 43.951876759529114, 40.893922448158264, 40.03671884536743, 40.68061329424381, 41.85689337551594, 41.38813532888889, 42.54327334463596, 42.70747013390064, 44.87895481288433, 45.327174961566925, 45.61917029321194, 43.78079853951931, 45.250084698200226, 44.002170860767365, 45.9052911400795, 49.824123457074165, 57.82911591231823, 56.55050732195377, 59.59788300096989, 39.956801533699036, 0.3361360786948353, 0.10801126001751982, 9.375863894820213, 60.13797841966152, 38.382868990302086, 56.28173254430294, 42.57106125354767, 33.64598236978054, 38.03961060941219, 27.579909972846508, 10.071273129433393, 0.49387665814720094, 0.01400035987899173, 0.05568116197537165, 0.018894384083978366, 0.06371969371684827, 0.05535600852454081, 0.1114032905024942, 0.018009881350735668, 0.032869334681890905, 0.034725791119853966, 0.028031351903337054, 0.015204893388727214, 0.058885930047836155, 0.014891561422700761, 0.0737662061874289, 0.019433148045209236, 0.051661612233147025, 0.06681432336336002, 0.062261499697342515, 0.03991112498624716, 0.04496177389228251, 0.032933738257270306, 0.06603387344512157, 0.07155292143579572, 0.04347709262219723, 0.008482922348775901, 0.04670240334235132, 0.04955521901138127, 0.0658430450130254, 0.018186211927968543, 0.07973240557475947, 0.009803179873415502, 0.08159378616255708, 0.11321197118377313, 0.2645016397582367, 0.27141584374476224, 31.259142346680164, 57.47392617166042, 54.72514986991882, 48.71413841843605, 42.97337606549263, 67.67187595367432, 69.01403233408928, 56.894613057374954, 62.0608614385128, 15.590523518621922, 0.18022818840108812, 0.14114148187218234, 19.486602656543255, 80.34920409321785, 62.14506112039089, 67.71591559052467, 57.86524057388306, 57.27492704987526, 53.487940058112144, 52.748286947607994, 53.060569390654564, 50.35725384950638, 47.50941686332226, 48.08179534971714, 44.19587306678295, 47.72286280989647, 46.129555106163025, 46.9273678958416, 45.82020990550518, 45.908125787973404, 45.39668843150139, 45.07561706006527, 46.15175351500511, 47.422393932938576, 45.37857100367546, 46.10399387776852, 45.66297434270382, 43.820274621248245, 44.00105372071266, 45.5565420538187, 44.29617628455162, 45.4271399974823, 41.804984360933304, 44.22127090394497, 44.19064074754715, 45.57567022740841, 45.25201499462128, 44.821349903941154, 46.82342067360878, 44.59604099392891, 44.47020314633846, 40.76047740876675, 42.46813237667084, 42.404117211699486, 43.476830050349236, 43.09088855981827, 43.03606890141964, 41.0339031368494, 41.309475749731064, 41.80622309446335, 42.667131498456, 42.06968955695629, 42.27425917983055, 40.378297716379166, 40.011681988835335, 40.16677066683769, 41.07662044465542, 40.939064025878906, 41.743363067507744, 42.14355759322643, 41.23525433242321, 42.4332008510828, 41.88956782221794, 40.10910876095295, 40.37286780774593, 39.02832515537739, 40.005894899368286, 41.2601125985384, 40.76137036085129, 41.111251786351204, 40.37920966744423, 40.81261821091175, 39.12488557398319, 40.68014971911907, 40.346208438277245, 39.61450830101967, 41.535620614886284, 40.411868914961815, 42.537288665771484, 43.65176506340504, 46.53035759925842, 44.60705280303955, 40.91279223561287, 41.105791479349136, 40.96526362001896, 42.232757806777954, 42.0315358042717, 41.903471276164055, 43.22708085179329, 43.786942809820175, 42.84192971885204, 42.76252157986164, 43.827091455459595, 40.952439308166504, 42.57801488041878, 43.144078105688095, 45.500008687376976, 44.85508069396019, 42.9750669747591, 46.20007552206516, 43.88310045003891, 41.80778481066227, 42.3893778026104, 43.95782344043255, 45.36459535360336, 44.39111039042473, 45.133100375533104, 47.50910148024559, 46.85557834804058, 46.71088211238384, 45.390373170375824, 48.37702810764313, 45.54128587245941, 48.70206266641617, 51.6005053371191, 61.954026371240616, 59.27499532699585, 61.10101394355297, 42.68277905881405, 0.21382801904110238, 0.34698137955274433, 10.762537736445665, 67.92415961623192, 43.91524292528629, 63.19508537650108, 47.25988045334816, 40.93124024569988, 44.86161634325981, 33.49373213946819, 20.021813437342644, 0.6456497171893716, 0.05672517821949441, 0.06480961179477163, 0.01743319364322815, 0.024424478942819405, 0.022568478925677482, 0.03680628338770475, 0.05837231561599765, 0.05035094603954349, 0.00934018918997026, 0.07062952645355836, 0.017021908388414886, 0.026224795619782526, 0.01759633069013944, 0.045632712499354966, 0.01953980765392771, 0.13622031547129154, 0.128557744610589, 0.15065584477270022, 0.15137437731027603, 0.17812408099416643, 0.12237526854733005, 0.15579327300656587, 0.1529372067307122, 0.12301417606067844, 0.08963072599726729, 0.11434916406869888, 0.2602978184586391, 0.18915460706921294, 0.1362479678937234, 0.1406346692238003, 0.1196304131008219, 0.32918726094067097, 0.24221377243520692, 0.48929846787359565, 0.39170500938780606, 39.67624358832836, 68.11375424265862, 63.14351834356785, 51.90920077264309, 50.453438088297844, 77.19439297914505, 74.23186674714088, 62.94544257223606, 70.44119015336037, 19.90992844104767, 0.21640873368596658, 0.2784125745529309, 22.19127282500267, 80.78729018568993, 67.47785076498985, 71.61056980490685, 62.099193781614304, 60.25890693068504, 56.93734936416149, 53.45502242445946, 56.069722920656204, 54.31357495486736, 50.11098526418209, 51.404967829585075, 46.775265857577324, 48.94046567380428, 48.2707592099905, 50.661480724811554, 47.891079783439636, 47.19636686146259, 47.885539680719376, 48.728376254439354, 47.096664011478424, 51.22638501226902, 48.33686426281929, 49.939888045191765, 48.42954508960247, 47.32296086847782, 46.84980645775795, 46.59397378563881, 44.76875312626362, 48.881443440914154, 42.819104343652725, 47.04695887863636, 45.24373523890972, 49.84795197844505, 47.713340520858765, 48.27698327600956, 51.072276681661606, 49.71943147480488, 47.38765239715576, 44.60894130170345, 45.652080327272415, 45.95814250409603, 46.57024785876274, 46.45434647798538, 47.337069511413574, 43.651936054229736, 44.337924644351006, 44.15879465639591, 44.90489982068539, 43.624649718403816, 45.18565155565739, 43.88517513871193, 42.558119148015976, 42.47668191790581, 41.92707560956478, 43.89525219798088, 43.75693581998348, 44.65727850794792, 43.87298159301281, 46.19538277387619, 43.2539302110672, 42.830629125237465, 42.18681447207928, 40.772773548960686, 43.49168725311756, 43.9840230345726, 44.069871827960014, 44.3874853849411, 45.06309673190117, 43.51346008479595, 41.714336425065994, 42.266990169882774, 43.78102272748947, 43.301097080111504, 44.7780816257, 44.8881009221077, 45.198829248547554, 46.60454861819744, 48.44066709280014, 46.77774712443352, 44.06593143939972, 42.653440833091736, 44.32156652212143, 44.1480678319931, 45.66735930740833, 44.394648000597954, 44.88093450665474, 46.25034682452679, 46.29782147705555, 46.30778454244137, 44.92684364318848, 43.076251745224, 43.85696165263653, 45.59307709336281, 47.89521776139736, 48.12689512968063, 44.403516724705696, 48.20691503584385, 45.967125222086906, 44.8457407951355, 45.10464370250702, 46.95665292441845, 47.32636548578739, 47.978152111172676, 48.02265912294388, 51.055390387773514, 51.001383885741234, 51.277112290263176, 48.95546346902847, 50.484284833073616, 47.623764127492905, 52.439135536551476, 54.08893100917339, 64.25986424088478, 62.86115549504757, 64.68036487698555, 48.86677622795105, 0.6556517304852605, 0.45902914367616177, 12.687056567519903, 73.50131034851074, 47.01743446290493, 68.9673100411892, 52.74236686527729, 47.739247530698776, 51.62486582994461, 44.442825615406036, 35.11816777288914, 0.5608451552689075, 0.14855344430543482, 0.18399163411231712, 0.10602484238916077, 0.25375005730893463, 0.12064401613315567, 0.17583176493644714, 0.0773485678655561, 0.20619424351025373, 0.1290973008144647, 0.18693980091484264, 0.08236098132329062, 0.11324454404530115, 0.18566125858342275, 0.1319656422128901, 0.08772346584009938], [0.05728586336772423, 0.012964709494553972, 0.02482863772456767, 0.014637195872637676, 0.03835368355794344, 0.05005626146157738, 0.055328159432974644, 0.06055496822227724, 0.041863889928208664, 0.017140874660981353, 0.022235974502109457, 0.04286864656023681, 0.12455292278900743, 0.06563956296304241, 0.06981838872889057, 0.013353800823097117, 0.009132143859460484, 0.05592977402557153, 0.47726810560561717, 0.23820791160687804, 5.932909967377782, 47.45032623410225, 51.37303814291954, 45.25286614894867, 29.85844250768423, 54.06227543950081, 64.0486715734005, 52.24672146141529, 58.776344284415245, 24.556997381150723, 0.11696210276568308, 0.0998618477024138, 7.258806070312858, 67.36646354198456, 66.78184971213341, 64.10498455166817, 62.02220991253853, 57.032503858208656, 49.054303765296936, 49.098806977272034, 48.4924279153347, 48.13428953289986, 46.94292426109314, 46.57665431499481, 45.38756512105465, 44.70967769622803, 44.82824273407459, 46.26604378223419, 42.61552266776562, 44.63655062019825, 44.246588945388794, 45.372468531131744, 44.43356551229954, 43.51813763380051, 45.849111154675484, 42.77625024318695, 43.00301067531109, 42.01812632381916, 44.15618799626827, 43.904903680086136, 42.88035325706005, 43.31559710204601, 42.07357294857502, 43.14653277397156, 42.5913255661726, 42.8142824023962, 44.04861576855183, 42.91878819465637, 42.219534516334534, 42.38698773086071, 43.08035932481289, 40.423283502459526, 40.22107735276222, 41.6736102104187, 40.9577514231205, 41.37029528617859, 41.29858933389187, 40.22399179637432, 39.59503814578056, 41.55052721500397, 40.631341338157654, 40.86860440671444, 43.01036708056927, 43.904250115156174, 46.72638148069382, 49.45566102862358, 50.01492641866207, 48.70687700808048, 48.68892677128315, 44.35734540224075, 44.72464509308338, 43.32725487649441, 45.3025408834219, 45.392926633358, 45.86711458861828, 44.03077192604542, 41.04500234127045, 38.71380463242531, 40.38212031126022, 36.353223100304604, 38.45466613769531, 38.07321220636368, 38.04799675941467, 39.36768114566803, 38.16510647535324, 38.10060113668442, 37.91040614247322, 36.707208305597305, 38.84908117353916, 37.4866908788681, 39.58047352731228, 41.62821784615517, 37.56076790392399, 41.25629760324955, 40.15487730503082, 39.864523485302925, 37.89662428200245, 39.17789652943611, 39.050884544849396, 40.983001068234444, 41.03979282081127, 40.718835443258286, 40.27795650064945, 40.724554136395454, 42.23312258720398, 41.99889175593853, 40.548034608364105, 40.96540801227093, 38.687304854393005, 40.680001527071, 38.908783569931984, 40.95247730612755, 38.42200309038162, 40.06715141236782, 41.55762143433094, 42.01593764126301, 41.30487039685249, 41.2463915348053, 41.13136410713196, 43.19877617061138, 41.834261789917946, 43.11665117740631, 40.27743972837925, 47.96525940299034, 50.796069502830505, 61.280299723148346, 53.084245920181274, 65.12341350317001, 25.43776921927929, 0.07705720810918137, 0.28527752961963415, 14.183346927165985, 58.5539536178112, 40.84302797913551, 67.92146176099777, 32.71877512335777, 32.93591447174549, 34.385441690683365, 31.57742276787758, 7.971274014562368, 0.5629723879974335, 0.0005899473933368427, 0.030943207275413442, 0.0938710461196024, 0.05046377846156247, 0.007267768705787603, 0.025247769335692283, 0.020465954148676246, 0.04161993114394136, 0.11809649775386788, 0.027261614886811003, 0.034203092800453305, 0.028123385636718012, 0.030507844894600566, 0.048460725593031384, 0.0279596567270346, 0.03755650934181176, 0.01879609775642166, 0.04983311991964001, 0.05285655533953104, 0.026114004103874322, 0.051553741068346426, 0.08674898141180165, 0.024433512735413387, 0.0856350251706317, 0.03157902930979617, 0.038713469330105, 0.040520962575101294, 0.07320642645936459, 0.09073563545825891, 0.023697443248238415, 0.05914922548981849, 0.052025268305442296, 0.02722655211982783, 0.31384457484818995, 0.26989550970029086, 9.449819326400757, 57.245493829250336, 54.71078284084797, 48.51936846971512, 41.6159825026989, 60.63492715358734, 70.77019169926643, 57.16312184929848, 64.08993735909462, 25.36488153040409, 0.021888946248509455, 0.029943480549263768, 8.100148849189281, 72.05890014767647, 67.47092753648758, 68.71913015842438, 64.15170684456825, 59.69713367521763, 50.286041870713234, 53.63944932818413, 50.147569701075554, 51.08328089118004, 49.05977167189121, 49.8748355358839, 47.14282013475895, 48.0718968808651, 46.328713819384575, 48.28770250082016, 45.74473835527897, 48.539055213332176, 45.853545516729355, 48.50474685430527, 46.001194193959236, 46.0315203666687, 46.38804003596306, 44.995179176330566, 44.893964007496834, 44.658524841070175, 45.659805312752724, 46.033127680420876, 45.367247611284256, 45.546966567635536, 44.414980709552765, 45.94015046954155, 45.386618971824646, 45.873448848724365, 44.495107010006905, 46.03465139865875, 43.95636811852455, 43.270527720451355, 44.21055927872658, 42.64085590839386, 43.60170274972916, 43.90479348599911, 42.0585485547781, 43.11789371073246, 43.62577445805073, 42.73923642933369, 41.8382553756237, 43.387751430273056, 44.16368119418621, 42.04459570348263, 45.81234812736511, 45.743431225419044, 47.2146400809288, 49.80850249528885, 49.16811145842075, 48.25155884027481, 47.642322331666946, 46.25678367912769, 44.630235359072685, 45.1234070956707, 45.26360437273979, 45.14459855854511, 45.67133009433746, 43.698472157120705, 43.63066479563713, 42.18089438974857, 43.13124619424343, 41.26846455037594, 41.61825858056545, 41.04355461895466, 39.47820961475372, 39.8272854834795, 40.73353685438633, 41.18375949561596, 39.979182332754135, 39.17533926665783, 40.28832994401455, 39.36703898012638, 42.88083203136921, 42.70785391330719, 41.648204773664474, 42.6684158295393, 41.473064571619034, 41.79059833288193, 40.554475262761116, 40.52843526005745, 41.259269043803215, 44.60095413029194, 42.752113938331604, 42.72237293422222, 42.9357922822237, 41.35440073907375, 42.90676183998585, 43.45988675951958, 41.86195470392704, 44.58648830652237, 39.58481289446354, 43.92208635807037, 40.38462437689304, 43.209370002150536, 40.39160840213299, 42.461562529206276, 45.28507702052593, 44.88777033984661, 44.27780047059059, 44.041814133524895, 44.73268546164036, 45.37896238267422, 43.5107546299696, 45.16028791666031, 42.93610766530037, 49.881302788853645, 54.440051168203354, 64.23464879393578, 55.498890951275826, 68.69537383317947, 26.028740108013153, 0.06412301387172192, 0.282622926752083, 17.48346794396639, 65.58315083384514, 45.53509600460529, 71.60917907953262, 37.430868074297905, 40.50555668771267, 37.82119832932949, 41.412446424365044, 12.809422351419926, 0.5782108171842992, 0.0650758201663848, 0.04130768735194579, 0.08903824724256992, 0.04607417904480826, 0.08897832623915747, 0.09183301954180934, 0.04536209948128089, 0.021889875788474455, 0.014101300312177045, 0.014585292847186793, 0.03771624178625643, 0.04879111860645935, 0.05181102140340954, 0.02086137785227038, 0.0122899673806387, 0.18481244944268838, 0.19184953824151307, 0.155327545653563, 0.1313750262488611, 0.1679945964133367, 0.23240640963194892, 0.1709750317968428, 0.10401087623904459, 0.17583017674041912, 0.17475633358117193, 0.1485187711659819, 0.1334836013847962, 0.2973075059708208, 0.17976967472350225, 0.16889528167666867, 0.16384195361752063, 0.18703978304984048, 0.14579072536434978, 0.6126279453746974, 0.7628742582164705, 13.032345939427614, 69.64934304356575, 62.297934517264366, 55.0528708845377, 46.31420239806175, 65.11591270565987, 77.09995284676552, 61.51012659072876, 73.09986189007759, 31.9138453155756, 0.2355176559649408, 0.2108650834998116, 9.785697553306818, 75.82965821027756, 70.13622611761093, 73.39933142066002, 68.43064203858376, 63.71036432683468, 53.30745354294777, 57.43424490094185, 52.92801350355148, 54.68811705708504, 52.07331396639347, 53.40378977358341, 50.15434093773365, 49.8127506673336, 49.64051350951195, 50.203875079751015, 48.929191678762436, 52.34798222780228, 48.87126378715038, 50.61359569430351, 47.82360680401325, 48.24707128107548, 50.64049445092678, 47.333596497774124, 47.638598531484604, 47.580701038241386, 48.694907650351524, 48.86765018105507, 48.6297145485878, 47.27673254907131, 45.34973055124283, 48.933170065283775, 47.18236081302166, 48.09389770030975, 47.52601437270641, 49.02337342500687, 46.77280738949776, 47.132287099957466, 47.457439452409744, 45.45319139957428, 44.41354438662529, 47.22508952021599, 44.76720280945301, 46.659201085567474, 45.50898380577564, 45.352352410554886, 43.36550362408161, 47.3325439542532, 47.70786501467228, 43.85055899620056, 47.67213173210621, 48.65040063858032, 51.195834651589394, 54.78880785405636, 56.33437491953373, 54.30333450436592, 52.727699652314186, 50.73119938373566, 47.8628358989954, 48.62528018653393, 50.29436342418194, 50.492431595921516, 51.55171595513821, 48.32539647817612, 46.897026523947716, 46.16295911371708, 45.9822142124176, 41.133925169706345, 42.70682796835899, 43.9883965998888, 41.72250218689442, 45.525159537792206, 43.24953764677048, 43.87549325823784, 40.85565850138664, 42.51726754009724, 45.55972248315811, 43.820969983935356, 44.25366036593914, 45.415543019771576, 41.62203177809715, 46.04216359555721, 45.33186011016369, 44.33567516505718, 42.235949635505676, 42.54899583756924, 42.18587592244148, 47.76754081249237, 44.71418425440788, 44.229208678007126, 45.26066333055496, 44.12111587822437, 46.17502346634865, 46.92199118435383, 43.17290335893631, 46.108451038599014, 42.60430566966534, 46.1191588640213, 43.505514711141586, 45.72404466569424, 41.45637206733227, 45.49238629639149, 47.403725534677505, 46.73976816236973, 47.26396523416042, 45.476544946432114, 46.56846195459366, 48.90419282019138, 45.34294031560421, 47.5156257301569, 43.611863404512405, 51.57448813319206, 58.6149213463068, 67.30686753988266, 60.02743475139141, 69.4144244492054, 30.30022770166397, 0.16092872712761164, 0.6129597744438797, 19.68526739627123, 72.1649144589901, 52.5240533798933, 81.75750732421875, 42.709263637661934, 49.49990205466747, 45.635752603411674, 55.12911379337311, 20.305542312562466, 0.7518069364596158, 0.1554216499789618, 0.21919643331784755, 0.1420332762063481, 0.2430566740804352, 0.13242938061011955, 0.14375284721609205, 0.11734873944078572, 0.2656138816382736, 0.21887713170144707, 0.21832671045558527, 0.18699512060265988, 0.15976845344994217, 0.1347874806378968, 0.16876356530701742, 0.1038545799383428], [0.009670149902376579, 0.009187519208353478, 0.011474798866402125, 0.04095737880561501, 0.04120769037399441, 0.006803285377827706, 0.07361435535131022, 0.04050552219268866, 0.015863599546719342, 0.02610712810565019, 0.022023636774974875, 0.036913182339048944, 0.0434195576235652, 0.03814090981904883, 0.04926990033709444, 0.133609707118012, 0.03569295055058319, 0.07648766913916916, 0.07810962546500377, 0.12692233314737678, 0.21673677780199796, 28.091647513210773, 47.61774905025959, 34.88681338727474, 31.213833577930927, 34.7102140635252, 69.37503576278687, 54.05070886015892, 62.682838663458824, 33.35266850888729, 0.2443987739388831, 0.30156660242937505, 0.2682962705148384, 44.767464995384216, 74.21040549874306, 65.00023931264877, 64.19423416256905, 57.80186377465725, 54.28431652486324, 47.89831459522247, 49.98799346387386, 48.05761344730854, 48.96473877131939, 46.02579407393932, 45.822683572769165, 46.44143097102642, 45.35113267600536, 42.95133724808693, 46.47257409989834, 45.19135884940624, 44.887781739234924, 45.643264800310135, 43.896935507655144, 44.180020317435265, 43.09768259525299, 41.71003885567188, 43.13049763441086, 43.89664672315121, 44.095984026789665, 43.65823231637478, 45.30127175152302, 44.59647037088871, 44.17807102203369, 42.77947627007961, 42.79604338109493, 43.54988493025303, 43.956653103232384, 44.45696845650673, 43.11685636639595, 42.64701917767525, 40.629137456417084, 40.516203716397285, 40.858705937862396, 41.31933242082596, 42.29445889592171, 41.6972791403532, 40.380064621567726, 40.906750559806824, 43.550637289881706, 44.75236840546131, 42.57097765803337, 40.99297173321247, 42.62849137187004, 42.812310308218, 51.506676971912384, 58.36274407804012, 60.17023488879204, 61.215642392635345, 60.81150367856026, 58.560489267110825, 52.2214300185442, 56.166150346398354, 60.602978467941284, 63.26820865273476, 61.64077118039131, 53.33426870405674, 43.33370313048363, 42.771082520484924, 41.93036623299122, 42.463568821549416, 39.760849848389626, 38.193775936961174, 39.02865573763847, 38.80002200603485, 37.71214418113232, 39.18284386396408, 38.77793379127979, 38.87275770306587, 37.71475464105606, 37.709484323859215, 39.26833167672157, 41.783162131905556, 39.049391224980354, 39.27551709115505, 38.85620579123497, 39.45611000061035, 41.6689782589674, 40.770030096173286, 40.52524343132973, 39.84131433069706, 40.40315218269825, 39.71464432775974, 41.70984506607056, 41.50568962097168, 40.9647012501955, 40.95021262764931, 39.47318248450756, 37.075435146689415, 38.67743298411369, 39.11438673734665, 38.67708720266819, 38.77746641635895, 38.8281062990427, 38.574515506625175, 38.30411821603775, 38.86022597551346, 40.81641800701618, 42.17539228498936, 40.781022906303406, 42.5619113445282, 41.33782222867012, 44.974253699183464, 45.91674752533436, 55.67318759858608, 55.51685258746147, 61.8270979821682, 57.50148609280586, 64.70977529883385, 4.358360907062888, 0.1009424147196114, 0.47057366638910025, 25.64945586025715, 62.111972495913506, 51.286630779504776, 58.68512637913227, 26.799460351467133, 42.8633301705122, 33.18266183137894, 32.95280836522579, 1.9885285338386893, 0.43996108404826373, 0.04943176645610947, 0.015873021111474372, 0.025560627254890278, 0.05797383426397573, 0.03851858506095596, 0.060421938251238316, 0.05915948197070975, 0.054816203701193444, 0.05005764185625594, 0.03419923363253474, 0.05877635194337927, 0.02691383891942678, 0.0143730460331426, 0.021330214804038405, 0.04644545326300431, 0.011100319497927558, 0.011241776555834804, 0.057293188365292735, 0.05758974686614238, 0.025724988845468033, 0.04618412822310347, 0.019298615225125104, 0.05229200731264427, 0.041280027508037165, 0.0343898653954966, 0.008926724804041442, 0.060728293101419695, 0.04926096116832923, 0.038051599767641164, 0.010062085511890473, 0.0781618281325791, 0.04316471895435825, 0.02245986004709266, 0.045514328812714666, 0.15611328708473593, 0.3255284432088956, 36.21243305504322, 52.96258024871349, 35.565095990896225, 39.052598252892494, 44.53452229499817, 76.28479018807411, 60.137286856770515, 70.96822187304497, 37.96746388077736, 0.09874357958324254, 0.381737639545463, 0.2385243633762002, 46.61283977329731, 77.01104521751404, 67.7697890996933, 67.03889831900597, 62.39595405757427, 56.72345124185085, 51.163164004683495, 52.532329335808754, 50.59520088136196, 50.698688328266144, 48.59925538301468, 48.36752861738205, 49.34927813708782, 49.24025818705559, 46.24994404613972, 47.60930970311165, 47.17147059738636, 47.58987374603748, 46.66235111653805, 47.717106118798256, 46.581502854824066, 46.19105860590935, 44.47047673165798, 45.49913853406906, 44.99055862426758, 45.80128312110901, 44.60648663341999, 48.012528866529465, 47.28479951620102, 46.43993005156517, 45.23062974214554, 44.812370985746384, 45.76351694762707, 46.881899535655975, 47.397740855813026, 46.73979476094246, 44.8243897408247, 43.9314566552639, 42.791723012924194, 43.24568085372448, 43.1426227837801, 44.76703181862831, 43.80416348576546, 41.54420055449009, 43.23852203786373, 42.51529544591904, 45.983126163482666, 44.07007321715355, 44.578459337353706, 44.648234993219376, 44.964264035224915, 53.32459822297096, 60.340982526540756, 61.740709617733955, 61.62686012685299, 62.502481341362, 59.52610105276108, 53.94837275147438, 55.86612984538078, 59.987753480672836, 62.84760542213917, 61.81112743914127, 54.9396787583828, 46.07009969651699, 43.96211341023445, 44.06481429934502, 42.81852677464485, 42.30643205344677, 41.011685729026794, 41.90737746655941, 41.68401785194874, 40.965389013290405, 41.74380764365196, 40.82556031644344, 42.222836539149284, 40.890441834926605, 39.54420447349548, 41.49074122309685, 43.759580478072166, 41.50694355368614, 42.50909797847271, 42.37971492111683, 42.17845492064953, 42.55927808582783, 43.20327512919903, 42.66422085464001, 43.39628577232361, 42.28691630065441, 42.28851221501827, 42.351243048906326, 41.81490942835808, 40.62510587275028, 41.95133350789547, 41.7813116312027, 39.773172587156296, 40.989563316106796, 43.286699652671814, 40.6095153093338, 42.03736089169979, 40.51771983504295, 41.159463599324226, 40.93421168625355, 42.74300962686539, 42.6787056773901, 44.38220366835594, 43.357170671224594, 44.93313990533352, 41.948430463671684, 46.871241107583046, 47.698779702186584, 57.925410345196724, 58.107469975948334, 65.01400217413902, 58.971763998270035, 64.23597112298012, 3.7941954424604774, 0.1228768787404988, 0.20947824697941542, 30.032704956829548, 66.06553494930267, 55.424243956804276, 63.97137612104416, 35.612730234861374, 47.627107948064804, 36.52665339410305, 44.1275717318058, 3.26227362267673, 0.47931376146152616, 0.05415346582594793, 0.059486353493412025, 0.061774008863721974, 0.05400950030889362, 0.03110871919489, 0.030533217068295926, 0.029689326511288527, 0.042411869508214295, 0.03146746224956587, 0.017063036357285455, 0.025376828816661146, 0.0336734776647063, 0.043940003524767235, 0.041740838132682256, 0.05526072418433614, 0.11855841046781279, 0.14295886794570833, 0.13952419365523383, 0.13895471405703574, 0.08884380455128849, 0.18443968350766227, 0.15874151402385905, 0.211662981309928, 0.1290307895396836, 0.1565111821400933, 0.07250536407809705, 0.1499948583659716, 0.15998048504116014, 0.11077391958679073, 0.16582866810495034, 0.13851119176251814, 0.22966640040976927, 0.15285917732398957, 0.1198200169892516, 0.1485285972012207, 0.36571538366843015, 46.316828057169914, 65.20053416490555, 44.42498177289963, 46.45167902112007, 48.690336495637894, 81.61332026124, 65.37429884076118, 75.64980626106262, 42.03474283218384, 0.2802384359529242, 0.7598288997542113, 0.45524983084760606, 49.853647872805595, 78.54978784918785, 71.2752377986908, 71.94330275058746, 64.85909208655357, 60.46614781022072, 52.24547892808914, 55.71812778711319, 53.02805833518505, 54.343794733285904, 50.918282344937325, 50.58600917458534, 51.95377618074417, 52.166530564427376, 49.57574978470802, 51.83613069355488, 51.06022372841835, 49.02370020747185, 50.223941802978516, 48.60433951020241, 48.490809202194214, 48.70572566986084, 47.071136981248856, 48.34967717528343, 48.76318998634815, 48.244992792606354, 47.846306785941124, 51.709532886743546, 48.967565819621086, 49.214434772729874, 47.86596693098545, 47.28056654334068, 49.06245432794094, 49.42589342594147, 51.33549615740776, 49.28989112377167, 46.276345029473305, 47.747443690896034, 44.93159718811512, 46.91475257277489, 45.74935130774975, 49.16853703558445, 47.698335126042366, 45.09566478431225, 46.99589341878891, 48.610878959298134, 50.71062348783016, 46.30608983337879, 47.86616452038288, 46.603986248373985, 47.16368481516838, 55.706470012664795, 61.87403306365013, 65.3671096265316, 64.39812362194061, 64.75563883781433, 63.62223945558071, 55.887021124362946, 58.90571594238281, 63.28546352684498, 67.51980811357498, 66.08960285782814, 58.52733984589577, 48.50007310509682, 46.74070671200752, 44.900131076574326, 47.13551312685013, 45.38523584604263, 44.28465910255909, 43.11982020735741, 45.40058322250843, 42.583904564380646, 45.30907653272152, 43.188490122556686, 45.44056847691536, 42.15067461133003, 42.356935143470764, 44.445303082466125, 46.999936401844025, 42.61823572218418, 43.79413582384586, 43.19106638431549, 44.81522083282471, 46.26353591680527, 47.16487035155296, 42.59747363626957, 44.11741107702255, 43.775862604379654, 43.218132331967354, 45.887219309806824, 45.38003012537956, 44.75893445312977, 45.33277586102486, 43.64577278494835, 41.93394184112549, 42.43211790919304, 46.29448905587196, 42.96889990568161, 43.34977626800537, 44.77270871400833, 43.26908379793167, 43.55697154998779, 44.46476183831692, 46.72047659754753, 47.18563623726368, 46.14583343267441, 49.55634422600269, 44.53710995614529, 50.56400075554848, 50.21555185317993, 61.402185782790184, 60.29614493250847, 67.18186184763908, 59.6691557765007, 70.08956462144852, 6.2137277238070965, 0.222268286452163, 1.21304013999179, 34.83093738555908, 76.5025869011879, 61.491469591856, 69.6494722366333, 40.426095351576805, 56.89682453870773, 42.801104709506035, 57.74460844695568, 4.20827561058104, 0.57692761416547, 0.2847158128861338, 0.19584299036068842, 0.14782038051635027, 0.15030779235530645, 0.09006811073049903, 0.2102531085256487, 0.17468462727265432, 0.10939492756733671, 0.13734964159084484, 0.1030038931639865, 0.1505956714390777, 0.12005818702164106, 0.1418259646743536, 0.1254181779222563, 0.199361527338624], [0.020328090940893162, 0.04148925007029902, 0.030948513631301466, 0.04332356824306771, 0.018344146519666538, 0.01933524021296762, 0.07435419494868256, 0.06144269929791335, 0.029600636153190862, 0.008992440125439316, 0.036064057785551995, 0.07358876609941944, 0.011360444113961421, 0.04723833786556497, 0.02652955114172073, 0.0352748542354675, 0.04507507386733778, 0.07814055075868964, 0.008138519442582037, 0.08594150247517973, 0.05128367723955307, 2.0407942542806268, 49.998807683587074, 37.70900934934616, 40.71643777191639, 32.09462821483612, 34.1939889639616, 58.43660071492195, 50.03960229456425, 52.59498417377472, 2.5184167502447963, 0.5085034982766956, 0.12354202859569341, 7.253151973709464, 75.27242571115494, 66.26207560300827, 67.37973242998123, 61.05950877070427, 57.077565640211105, 53.370606154203415, 55.25025509297848, 58.83663944900036, 62.814854979515076, 58.177401423454285, 55.65730445086956, 48.757661283016205, 49.288063421845436, 46.73385187983513, 47.16482475399971, 45.927018374204636, 46.82958774268627, 48.35489809513092, 49.76866543292999, 48.340667858719826, 50.215202271938324, 47.6367100328207, 44.37632158398628, 44.47795853018761, 46.02052755653858, 45.150096863508224, 44.15231980383396, 42.900792360305786, 44.06290300190449, 41.91686935722828, 42.84213110804558, 42.73870825767517, 44.75139185786247, 42.67944663763046, 43.36061708629131, 43.85055139660835, 43.17008391022682, 40.083627328276634, 41.81224197149277, 42.811291962862015, 40.54381303489208, 40.42491361498833, 43.235223814845085, 41.199190467596054, 45.12826323509216, 43.58464926481247, 43.4244080632925, 42.950622886419296, 42.185286954045296, 44.682440757751465, 45.281410217285156, 50.25617927312851, 53.715346455574036, 55.20579747855663, 56.418570801615715, 59.317841827869415, 50.84756053984165, 55.755802765488625, 58.88802409172058, 56.48576259613037, 52.326593175530434, 46.278719902038574, 42.99861051142216, 43.1596914678812, 42.19777688384056, 43.670243471860886, 43.650784716010094, 42.713090032339096, 40.68212941288948, 39.4143046438694, 39.483502730727196, 38.94686512649059, 38.932391703128815, 40.53289622068405, 37.75413192808628, 37.94909946620464, 39.587837532162666, 40.15461891889572, 41.38459771871567, 40.25136552751064, 41.055744364857674, 41.05180397629738, 41.77443020045757, 38.88330593705177, 40.26209995150566, 40.309593603014946, 40.07010005414486, 38.88496644794941, 38.835329711437225, 42.72876799106598, 39.05250325798988, 41.14324986934662, 39.91886056959629, 39.04065549373627, 40.90591840445995, 39.728916361927986, 39.23916444182396, 40.07080301642418, 37.655607014894485, 39.994145929813385, 41.466642916202545, 40.97401075065136, 39.186962842941284, 42.15180315077305, 42.451888248324394, 42.2411135584116, 46.08309119939804, 47.713040336966515, 54.87007409334183, 57.74336591362953, 60.50949968397617, 59.02611628174782, 62.955170050263405, 26.424450874328613, 0.5056136939674616, 0.2584578562527895, 0.06530607890454121, 46.32540799677372, 51.473166570067406, 53.6492870002985, 39.957743883132935, 28.83637335151434, 40.16114316880703, 39.73483644425869, 25.433977022767067, 0.6968133186455816, 0.13685182377230376, 0.18718478386290371, 0.008309398017445346, 0.053128018116694875, 0.020072931292816065, 0.10606955678667873, 0.02237798074929742, 0.016806770909170154, 0.041190825068042614, 0.04822980634344276, 0.08522136689862236, 0.03547267369867768, 0.017912057010107674, 0.03681566784507595, 0.02275658738653874, 0.020319456052675378, 0.03838700598862488, 0.07648681566934101, 0.02216325516201323, 0.09213058365276083, 0.05003996018785983, 0.07085347693646327, 0.023758583229209762, 0.013845547873643227, 0.026324072714487556, 0.1577807147987187, 0.07438101616571657, 0.10654298021108843, 0.00874859637406189, 0.034009095397777855, 0.03314202571345959, 0.0505604877253063, 0.03522093720675912, 0.06838093773694709, 0.022331670734274667, 0.07598866388434544, 0.1087680205819197, 3.6626332020387053, 62.93740600347519, 41.10494792461395, 43.392159193754196, 42.37964652478695, 47.37689897418022, 65.6483705341816, 57.63708181679249, 55.372988507151604, 2.629238753579557, 1.428540707565844, 0.34544649941381067, 8.645028211176395, 76.23646438121796, 67.20735087990761, 70.2709972858429, 63.511536195874214, 60.28064176440239, 56.389620155096054, 57.87781409919262, 60.7845289260149, 63.73944416642189, 59.294860661029816, 58.32033835351467, 50.230963826179504, 50.59050813317299, 50.37557266652584, 49.18674185872078, 48.89435134828091, 48.222630992531776, 50.434769690036774, 50.146266371011734, 51.40282854437828, 51.34663335978985, 50.071406587958336, 47.59003333747387, 46.534886956214905, 46.986268535256386, 48.04769977927208, 47.55396947264671, 45.2871935069561, 46.76081903278828, 45.38250759243965, 45.57503566145897, 44.75699655711651, 46.761195212602615, 45.51876828074455, 45.4738774895668, 44.606019258499146, 43.65489609539509, 43.497504740953445, 44.04301106929779, 44.64491777122021, 43.712930381298065, 43.24382655322552, 45.00452287495136, 43.68785172700882, 44.93177577853203, 45.76991580426693, 44.27251495420933, 44.3995725363493, 41.751863211393356, 45.6843975931406, 47.30121463537216, 51.296894028782845, 57.82212048768997, 57.70187973976135, 59.86287698149681, 59.355057030916214, 52.26811431348324, 57.98766240477562, 60.77215678989887, 58.5830220580101, 56.046905145049095, 51.00929506123066, 47.28338599205017, 44.459898099303246, 43.57367545366287, 44.79431435465813, 46.516188159585, 44.467759877443314, 41.79174967110157, 40.892121344804764, 42.97512397170067, 40.805368199944496, 41.000761315226555, 43.2402965426445, 39.45945002138615, 39.81077916920185, 43.81044074892998, 43.74795690178871, 43.3059836179018, 42.7519391477108, 42.81159594655037, 42.92346574366093, 42.13927522301674, 41.56555160880089, 41.746725887060165, 41.74931734800339, 42.35616758465767, 42.380835860967636, 41.395579129457474, 42.592058926820755, 43.12730960547924, 43.45419466495514, 42.55407236516476, 41.98972284793854, 42.115758284926414, 42.87740081548691, 40.29441721737385, 41.9310387969017, 40.99709451198578, 42.51629859209061, 43.18946287035942, 44.59537222981453, 41.47545464336872, 45.36817096173763, 43.822014927864075, 44.760792553424835, 48.17513354122639, 49.35060806572437, 58.44463348388672, 59.67268578708172, 63.71842749416828, 59.55491490662098, 62.703342363238335, 25.960963144898415, 0.7568049151450396, 0.10181987818214111, 0.4511893627932295, 53.12391199171543, 57.62115687131882, 59.545734599232674, 45.29165826737881, 38.08372624218464, 42.007403299212456, 44.710661843419075, 33.32885138690472, 0.5344236292876303, 0.1425284519791603, 0.1464773010229692, 0.01773502881405875, 0.04528461184236221, 0.026526159526838455, 0.025007363583426923, 0.025519334158161655, 0.03933415711799171, 0.03308810126327444, 0.051920265541411936, 0.01376762515064911, 0.017853403223853093, 0.03034837220184272, 0.04572142141114455, 0.05119355824717786, 0.008855187334120274, 0.12497740157414228, 0.21687187836505473, 0.062281663849717006, 0.2776617289055139, 0.14721076557179913, 0.15489043551497161, 0.1393736564205028, 0.22742931498214602, 0.16603477735770866, 0.23374016775051132, 0.19443034194409847, 0.18230983841931447, 0.0721784406050574, 0.13331737514818087, 0.07518583079217933, 0.14808459993219003, 0.10655364487320185, 0.18973244325025007, 0.08743815458728932, 0.3583308955421671, 0.29157747281715274, 6.0822191555053, 75.60985520482063, 51.13798275589943, 55.97988814115524, 44.27645154297352, 50.137101262807846, 71.71022325754166, 63.521757647395134, 61.275504380464554, 2.8508635237812996, 0.7310140365734696, 0.32472546910867095, 9.75834472104907, 79.37669947743416, 70.10522738099098, 73.5072760283947, 68.4522932767868, 62.58356139063835, 59.94017243385315, 60.78799434006214, 63.12030538916588, 69.84467536211014, 61.68800264596939, 61.4985828101635, 52.88674771785736, 55.51075391471386, 52.009766176342964, 54.01164695620537, 52.156001329422, 51.717960834503174, 53.945245519280434, 52.904990538954735, 52.52108573913574, 54.31648939847946, 52.95699454843998, 50.41604429483414, 48.5265576839447, 50.63594989478588, 49.99979943037033, 48.36283206939697, 47.6046359539032, 49.17356036603451, 47.56958283483982, 47.34132528305054, 46.73587717115879, 48.643663600087166, 46.69093698263168, 47.30658754706383, 47.32635408639908, 46.39204882085323, 45.490900576114655, 48.226787969470024, 46.453225538134575, 46.025110110640526, 46.25273309648037, 47.12565265595913, 44.69313718378544, 46.952302157878876, 47.11197718977928, 46.808001101017, 48.211155608296394, 44.137360006570816, 47.733483240008354, 49.73790988326073, 53.459616377949715, 61.46391727030277, 59.363435581326485, 60.959038361907005, 61.681087017059326, 53.474709168076515, 59.93543788790703, 62.129181772470474, 59.00416485965252, 56.02390877902508, 52.02734023332596, 49.46269445121288, 48.19022633135319, 45.330142602324486, 47.9854591190815, 48.459905460476875, 48.68593633174896, 46.98492340743542, 45.54730474948883, 44.88602623343468, 43.984000235795975, 44.81335513293743, 46.53259567916393, 42.40342564880848, 43.011092841625214, 45.85439287126064, 45.00796929001808, 46.550880298018456, 45.388796254992485, 45.916530936956406, 44.62373770773411, 44.606859013438225, 43.61613817512989, 43.04413206875324, 43.368258476257324, 44.570354372262955, 42.92098447680473, 43.594840317964554, 45.851204842329025, 43.83118003606796, 43.43170367181301, 44.37181122601032, 44.544610753655434, 44.80199754238129, 44.89689365029335, 42.15275689959526, 43.981100991368294, 41.326894015073776, 45.992754846811295, 46.76494941115379, 46.4377261698246, 43.81378836929798, 48.33291247487068, 46.6723407804966, 46.67124643921852, 50.02137467265129, 50.88587388396263, 59.446803107857704, 63.42346832156181, 65.55801138281822, 63.29623594880104, 64.05949339270592, 30.28170559555292, 0.9086533170193434, 0.30653284688014537, 0.43899397656787187, 56.938629895448685, 64.33160439133644, 62.812445908784866, 49.77624222636223, 45.66070206463337, 47.631618306040764, 54.67522814869881, 42.47621454298496, 0.8200414781458676, 0.21527185250306502, 0.2056671999162063, 0.21684617036953568, 0.13809986383421347, 0.10752647431218065, 0.2052390549215488, 0.14811974804615602, 0.1362404870451428, 0.0758846073586028, 0.2427008587983437, 0.2380007633473724, 0.11686630634358153, 0.07940829484141432, 0.1149720857210923, 0.16003642813302577, 0.0588110696116928], [0.04484830322326161, 0.013975521123938961, 0.01693041827820707, 0.05302621029841248, 0.020694181257567834, 0.05692966587957926, 0.027780845521192532, 0.02321325126104057, 0.025596293016860727, 0.03575908704078756, 0.10398674159660004, 0.09080910065677017, 0.04215881570416968, 0.007890972374298144, 0.04579757689498365, 0.03525841195369139, 0.01517143087767181, 0.053735822220915, 0.023834015119064134, 0.04566611285554245, 0.08791522937826812, 0.19347027002368122, 19.10091955214739, 51.721133664250374, 40.535411685705185, 46.566356867551804, 27.005371302366257, 62.72790804505348, 49.794606640934944, 67.7020463347435, 14.493628777563572, 0.4941151844104752, 1.0770921036601067, 0.27961339917965233, 40.055235251784325, 78.88458788394928, 65.98722115159035, 66.10707432031631, 62.86217764019966, 61.887533739209175, 62.31692209839821, 64.0635059773922, 66.53492376208305, 60.54701127111912, 59.47657831013203, 56.22795782983303, 56.41505219042301, 51.72000512480736, 52.41302713751793, 53.537899777293205, 55.70871189236641, 60.15385016798973, 60.19057519733906, 61.28955602645874, 57.65080668032169, 53.76490339636803, 50.699041709303856, 44.635053500533104, 44.6764712780714, 40.949695855379105, 46.63805142045021, 44.024954438209534, 44.70735602080822, 44.27204377949238, 44.96207535266876, 45.22186741232872, 44.56662677228451, 44.165022522211075, 43.04639674723148, 40.95702566206455, 42.000122889876366, 41.25688657164574, 41.186183765530586, 41.282618790864944, 42.49923750758171, 41.290997341275215, 42.732495591044426, 43.847294971346855, 45.24021662771702, 43.8723736256361, 42.21981570124626, 43.50393779575825, 43.7772723287344, 50.43760433793068, 52.62774981558323, 52.61150188744068, 55.69954678416252, 55.77798217535019, 58.09083066880703, 61.25146687030792, 55.719024538993835, 58.705934062600136, 60.52363872528076, 57.54390701651573, 50.30429229140282, 47.28781655430794, 44.34378772974014, 45.60911983251572, 44.69057612121105, 42.79473625123501, 42.8470366448164, 41.411169692873955, 40.136417895555496, 41.54756337404251, 40.48155337572098, 38.97441364824772, 39.34514455497265, 39.710255563259125, 39.15811479091644, 40.543790236115456, 41.06838248670101, 43.06159593164921, 41.37855224311352, 40.10809801518917, 41.22239202260971, 39.50269930064678, 41.275338381528854, 40.11322773993015, 41.03416532278061, 41.241303607821465, 41.62595696747303, 40.83882920444012, 42.25914739072323, 41.98461592197418, 40.160831585526466, 39.739479795098305, 39.61040072143078, 40.15587665140629, 41.706474646925926, 38.59718509018421, 40.854632556438446, 40.03297984600067, 39.75676126778126, 41.3063333183527, 39.78276327252388, 41.76291681826115, 42.91351027786732, 40.67989893257618, 43.18806454539299, 43.261677995324135, 46.559635028243065, 53.535996079444885, 59.87947829067707, 60.19337184727192, 63.93329456448555, 59.30617645382881, 55.3417693823576, 0.9847098577301949, 0.06230595434317365, 0.5026078177616, 3.4525310760363936, 59.22760047018528, 48.118372187018394, 61.196871399879456, 31.445668637752533, 41.37618876993656, 33.91788437962532, 43.429777175188065, 4.285022467374802, 0.33912179816979915, 0.03198334023181815, 0.10769303451525047, 0.037650372469215654, 0.0900159525917843, 0.06613893187022768, 0.04809842765098438, 0.03102871010923991, 0.06476859329268336, 0.08163311256794259, 0.05729921089368872, 0.05814174146507867, 0.0276171648511081, 0.04410120913235005, 0.04166945094766561, 0.056484733504476026, 0.0487799307302339, 0.011641890632745344, 0.02923600230133161, 0.00874965857292409, 0.0528865306841908, 0.05637733731418848, 0.055013841338222846, 0.04307957235141657, 0.0495566290919669, 0.04767495447595138, 0.03710671589942649, 0.05276066985970829, 0.08099162238067947, 0.07520264785853215, 0.03430403601669241, 0.04420469420438167, 0.029738981756963767, 0.028214623416715767, 0.01451069772883784, 0.05131629091920331, 0.06130090085207485, 0.15249879041220993, 0.2394216792890802, 27.2043951228261, 58.01666244864464, 43.6384429782629, 57.09561467170715, 35.37878058850765, 70.46268180012703, 57.08191640675068, 70.2168881893158, 16.15084335207939, 0.7146279502194375, 0.7839808787684888, 0.1351706960122101, 43.2269174605608, 78.64127174019814, 68.38897347450256, 70.56305721402168, 64.83788162469864, 63.78915309906006, 65.93532353639603, 66.64234399795532, 67.74458885192871, 62.79245138168335, 60.89634172618389, 59.33130070567131, 57.44812175631523, 55.680984780192375, 54.96719688177109, 54.27636355161667, 56.93806752562523, 61.628349646925926, 62.3811424523592, 60.90065449476242, 57.78820350766182, 55.8293592184782, 50.53011417388916, 47.49654695391655, 47.96869061887264, 45.05322866141796, 49.032736122608185, 46.410246044397354, 47.081058248877525, 43.81767936050892, 48.12165521085262, 46.72615349292755, 47.42685109376907, 48.28620158135891, 46.81008718907833, 44.53168384730816, 43.602679297327995, 44.64785121381283, 44.63700279593468, 43.56501951813698, 43.871169090270996, 43.791460767388344, 44.90115702152252, 46.11500948667526, 45.672549828886986, 45.90235769748688, 45.15948235988617, 45.226476565003395, 45.864941105246544, 51.823454573750496, 53.2309902459383, 54.05573599040508, 57.42576755583286, 58.823568150401115, 60.35191833972931, 62.07053951919079, 56.60278871655464, 59.113116413354874, 62.8640129417181, 59.77964244782925, 51.34177342057228, 49.05856713652611, 45.97065903246403, 46.89563199877739, 45.50324611365795, 44.46540020406246, 45.00372111797333, 43.958986178040504, 42.796457558870316, 41.428663954138756, 42.853241711854935, 42.152228727936745, 41.36185593903065, 42.30005979537964, 41.17705285549164, 43.712991178035736, 44.00128170847893, 44.0746633708477, 44.17060822248459, 43.76969553530216, 43.10222715139389, 42.51000612974167, 42.702617794275284, 41.262681260704994, 42.91903518140316, 41.61922372877598, 44.88224543631077, 42.46712923049927, 43.07837963104248, 42.460308596491814, 42.68879413604736, 41.63098029792309, 41.998648568987846, 42.46419578790665, 44.07263047993183, 39.77690778672695, 42.05648526549339, 42.69775405526161, 41.38690799474716, 43.64639215171337, 41.568747237324715, 42.94526897370815, 45.39342060685158, 42.280186861753464, 46.01922422647476, 46.05402655899525, 47.94606663286686, 55.019512474536896, 62.60074786841869, 62.32006832957268, 66.84610426425934, 59.16891261935234, 57.37656019628048, 0.7456955581437796, 0.23194265639176592, 1.1226714891381562, 4.170567383989692, 66.69178694486618, 53.27933505177498, 66.68533489108086, 37.33573637902737, 47.90059447288513, 36.57928057014942, 52.16013550758362, 7.614469835534692, 0.5012519436422735, 0.03143013593216892, 0.07427653661579825, 0.07100608476321213, 0.040612172524561174, 0.0588552236877149, 0.05281930694764014, 0.03647442834335379, 0.05174564561457373, 0.00421840635681292, 0.05499778868397698, 0.019685725019371603, 0.053130426385905594, 0.06579835287993774, 0.018240700410387944, 0.03907787497155368, 0.022996230582066346, 0.15835040219826624, 0.09828873953665607, 0.18897465110057965, 0.13126202684361488, 0.1175303355557844, 0.18302341341041028, 0.16814281814731658, 0.14075305662117898, 0.16451852512545884, 0.1649490895215422, 0.31641213863622397, 0.25131943461019546, 0.20741889107739553, 0.14000660448800772, 0.144598079205025, 0.2826091821771115, 0.06563062750501558, 0.20075970387551934, 0.2004807602497749, 0.30238477571401745, 0.24115521751809865, 0.45511710515711457, 36.10278993844986, 70.0530257821083, 53.25495555996895, 60.72164610028267, 37.96179078519344, 77.522953748703, 57.99254514276981, 81.75002932548523, 18.707015588879585, 0.7264115929137915, 1.22842563316226, 0.23815640655811876, 44.169069305062294, 80.95797702670097, 72.02339485287666, 72.11133733391762, 70.2220331132412, 67.83594354987144, 68.29263344407082, 70.48879399895668, 71.95759758353233, 66.12537413835526, 63.63949432969093, 62.77629464864731, 62.405791729688644, 58.584697768092155, 57.370168939232826, 57.78260640799999, 60.162969678640366, 65.52951291203499, 65.10325938463211, 63.24146568775177, 63.928658813238144, 59.34788301587105, 53.93019072711468, 50.6023520976305, 50.999635979533195, 46.37475594878197, 52.06094183027744, 47.718922421336174, 49.271161928772926, 47.52347230911255, 51.16846092045307, 48.83098974823952, 48.48601385951042, 50.081027671694756, 47.807058691978455, 45.193007960915565, 47.60080575942993, 46.50894194841385, 46.49126909673214, 47.56676718592644, 46.71034634113312, 45.846892073750496, 47.3603280633688, 48.033271953463554, 48.604191318154335, 49.44256313145161, 46.270060166716576, 46.962626203894615, 48.148960545659065, 55.922932997345924, 56.937926933169365, 55.89331358671188, 62.688105180859566, 60.58003529906273, 62.29909725487232, 66.05591386556625, 57.35836677253246, 59.53808180987835, 64.450424015522, 62.603783905506134, 55.559980273246765, 51.185844987630844, 47.81830608844757, 50.16487397253513, 48.623399287462234, 45.95342695713043, 47.51122556626797, 45.441130846738815, 45.37404924631119, 45.087111443281174, 45.82477726042271, 43.69545131921768, 43.725766092538834, 44.43607337772846, 45.0963981449604, 46.79598994553089, 46.72985449433327, 45.94256334006786, 45.907578617334366, 45.13341575860977, 46.14326857030392, 42.7093206346035, 45.418757647275925, 44.135361313819885, 45.50536260008812, 44.009553864598274, 47.30518542230129, 46.66492737829685, 44.95166391134262, 45.149264708161354, 45.82030110061169, 44.107372015714645, 44.09015133976936, 44.42577973008156, 48.035441637039185, 41.81983396410942, 45.44375650584698, 44.691024497151375, 44.1857124119997, 47.46566221117973, 44.16654244065285, 45.76031751930714, 48.96445758640766, 44.42640669643879, 48.987305760383606, 46.90262362360954, 48.61798457801342, 56.82077921926975, 66.16755947470665, 63.666001707315445, 70.05256220698357, 60.449071526527405, 58.970631659030914, 1.8639163579791784, 0.208209827542305, 1.1921645351685584, 5.000226264819503, 72.0530940592289, 58.713153675198555, 71.41504749655724, 44.131846502423286, 54.92480255663395, 42.301290929317474, 66.89564600586891, 9.721792582422495, 0.5426690087188035, 0.2252445658086799, 0.24396375665673986, 0.13548100279876962, 0.23151531291659921, 0.14191778318490833, 0.07158104141126387, 0.11263735592365265, 0.18619585724081844, 0.17771296086721122, 0.16137688042363152, 0.20009095460409299, 0.1344421147950925, 0.24071941355941817, 0.09090791761991568, 0.12855001143179834, 0.14225296676158905], [0.017215879815921653, 0.02211616032582242, 0.010909890897892183, 0.03322797754663043, 0.11508766780025326, 0.023225390941661317, 0.01349450181805878, 0.0419207829691004, 0.05275183459161781, 0.027708679081115406, 0.03910579456714913, 0.015666594590584282, 0.037233563780318946, 0.005091106622785446, 0.09039789889357053, 0.03741777967661619, 0.06304108130279928, 0.04285787799744867, 0.09344670092104934, 0.05932080632192083, 0.10530051367823035, 0.06504435310489498, 2.448965976946056, 40.95391362905502, 48.34074005484581, 48.733616173267365, 29.101737812161446, 44.30932737886906, 48.024722412228584, 62.82338932156563, 35.68167373538017, 0.6062512344215065, 0.6207975663710386, 0.13383462239289656, 4.091647043824196, 67.79758840799332, 70.81309899687767, 69.13153722882271, 63.81298542022705, 64.97649818658829, 67.28250324726105, 67.47966706752777, 64.55273732542992, 65.39921790361404, 60.79569272696972, 60.954269617795944, 59.18528974056244, 62.439879700541496, 60.92060722410679, 62.16913282871246, 62.65410080552101, 62.85137861967087, 63.805051445961, 63.24609003961086, 60.61720110476017, 56.56037539243698, 48.724192678928375, 43.95067982375622, 45.065992176532745, 45.55887512862682, 45.1506782323122, 45.48837751150131, 45.57515725493431, 44.39505837857723, 45.41476786136627, 43.119295835494995, 43.602223321795464, 43.918700739741325, 44.95236687362194, 45.41534163057804, 43.2014512270689, 40.32280929386616, 42.45830990374088, 42.54257418215275, 42.00580358505249, 43.84093791246414, 43.24071832001209, 41.92472733557224, 44.87393528223038, 44.51723702251911, 45.39426416158676, 44.53136086463928, 47.32382722198963, 50.079268366098404, 58.865088522434235, 57.3300126940012, 58.64587068557739, 59.0265266597271, 60.63762500882149, 60.99846504628658, 45.47302633523941, 50.61916619539261, 61.33225433528423, 57.96446464955807, 54.6355164796114, 50.52254118025303, 53.55005532503128, 53.84783014655113, 56.773300766944885, 53.7302340567112, 49.7718458622694, 43.52618180215359, 43.5344273597002, 39.72676567733288, 40.69710820913315, 39.802130833268166, 41.12906523048878, 39.4261410087347, 40.78418433666229, 39.06178615987301, 40.94741217792034, 42.283990457654, 41.429469510912895, 40.11809527873993, 40.44295884668827, 40.3197580575943, 42.301127538084984, 39.79120261967182, 42.36409015953541, 41.45480655133724, 40.6875479221344, 40.84154985845089, 41.41786113381386, 42.60937079787254, 42.7310174703598, 40.83503320813179, 41.10212467610836, 40.19179232418537, 41.71829581260681, 43.33361953496933, 44.44778814911842, 44.73582789301872, 44.40083406865597, 43.84925186634064, 46.31380341947079, 43.6422123759985, 43.693790808320045, 43.53446155786514, 44.51483175158501, 42.89139546453953, 50.307145938277245, 57.55401827394962, 61.28924444317818, 61.672879457473755, 59.91755984723568, 60.0112210214138, 10.603502970188856, 0.9629117930307984, 0.9921749727800488, 1.507991119287908, 13.973682727664709, 61.14862158894539, 56.83744892477989, 39.9851518124342, 31.785488203167915, 36.82387724518776, 37.105020359158516, 19.466450437903404, 0.7353005628101528, 0.1432349914102815, 0.04998715266992804, 0.010014377476181835, 0.10592258186079562, 0.016170024900930002, 0.05326682570739649, 0.07078902883222327, 0.01992671150219394, 0.11058796706493013, 0.038261204535956495, 0.05903175093408208, 0.024562564794905484, 0.012589845136972144, 0.023133420290832873, 0.03237277480366174, 0.012030985672026873, 0.02716442322707735, 0.05526307679247111, 0.032315963399014436, 0.025367140078742523, 0.03349601160152815, 0.04745045109302737, 0.02460398962284671, 0.07234572811285034, 0.02213322230090853, 0.04508645841269754, 0.02245265379315242, 0.07772199431201443, 0.05807325607747771, 0.06457163472077809, 0.03791148599702865, 0.033858086899272166, 0.042163350226473995, 0.038391169437090866, 0.05133628066687379, 0.04283237780327909, 0.06948563939658925, 0.07081544928951189, 0.10502761855605058, 3.309472077526152, 52.34850659966469, 50.91819114983082, 53.428891226649284, 42.830199748277664, 51.90519958734512, 54.19752158224583, 69.73231539130211, 38.49768362939358, 2.3870084015652537, 1.9274102384224534, 0.1719060560571961, 4.82066547498107, 70.7031936943531, 71.74766644835472, 72.54663437604904, 67.13206931948662, 68.40783566236496, 67.70327746868134, 71.93042144179344, 66.37413918972015, 66.32217317819595, 63.44653308391571, 63.95961955189705, 61.872741132974625, 65.59583455324173, 63.69410499930382, 63.2352302223444, 64.8980475962162, 65.77352061867714, 66.65628165006638, 65.99108934402466, 63.04418407380581, 59.07054729759693, 50.30619598925114, 47.18601621687412, 47.251524701714516, 48.03261838853359, 46.31180092692375, 48.20779278874397, 47.939124405384064, 47.00138032436371, 46.620492562651634, 45.529267117381096, 45.40567874908447, 46.625037118792534, 47.9458462446928, 45.82645297050476, 45.65979391336441, 44.16391298174858, 46.13546758890152, 44.91826370358467, 43.22937212884426, 44.779521748423576, 43.68549965322018, 44.5025660097599, 47.42101080715656, 46.42164923250675, 46.340994760394096, 47.36776806414127, 49.107915088534355, 52.98009350895882, 58.83000500500202, 58.55067819356918, 59.693820253014565, 61.11820802092552, 61.88020773231983, 62.93435096740723, 48.37149940431118, 53.95162917673588, 62.5028233230114, 57.25482992827892, 57.942862808704376, 53.133305087685585, 53.53183150291443, 55.57133786380291, 57.01141498982906, 54.3941306322813, 50.83001308143139, 45.75967535376549, 45.03462105989456, 42.5893534719944, 42.706322595477104, 43.97096313536167, 43.49107928574085, 40.67492499947548, 43.67443464696407, 42.06739068031311, 44.5733068138361, 45.37561096251011, 45.11393420398235, 43.00749443471432, 43.55881825089455, 42.7973885089159, 43.54269191622734, 41.99687406420708, 44.928754940629005, 42.72517338395119, 43.252649679780006, 43.28272506594658, 44.6895007789135, 43.18006597459316, 44.46247436106205, 41.72277197241783, 44.15939122438431, 42.502809315919876, 43.29613074660301, 44.52932417392731, 46.86939440667629, 46.99530445039272, 46.34761020541191, 46.23656876385212, 47.08768889307976, 46.574591025710106, 45.11135034263134, 44.85546447336674, 46.61733113229275, 43.09072896838188, 53.65252822637558, 58.93313147127628, 62.914516031742096, 63.28987888991833, 59.74693760275841, 59.43111374974251, 9.355100858956575, 1.9846535730175674, 1.0385184735059738, 1.5247153281234205, 17.683705799281597, 66.77546605467796, 63.00897516310215, 45.774251371622086, 42.3605677485466, 40.2884591370821, 41.24584436416626, 25.924502201378345, 1.0333285457454622, 0.2579490398056805, 0.05134543876920361, 0.05560336634516716, 0.007534657534051803, 0.0312456491519697, 0.08642642176710069, 0.1120749935216736, 0.02668745790288085, 0.05766838483395986, 0.013904180323152104, 0.014514469694404397, 0.01835150491388049, 0.029368883842835203, 0.023827165096008684, 0.016029861035349313, 0.054191512026591226, 0.037834284084965475, 0.18496359523851424, 0.14542321383487433, 0.075661829469027, 0.12176982447272167, 0.20566622028127313, 0.0927341946226079, 0.10684004708309658, 0.1892839337233454, 0.20034056855365634, 0.11834502816782333, 0.16353324986994267, 0.23091595445293933, 0.22400681191356853, 0.1262311710161157, 0.17147256759926677, 0.16962295747362077, 0.17148151790024713, 0.16406045673647895, 0.16201509773964062, 0.1958817007835023, 0.24933318025432527, 0.4271939175669104, 5.074849035590887, 64.26149815320969, 61.54030077159405, 58.8562273979187, 41.74458660185337, 56.06195613741875, 60.53558148443699, 73.17655697464943, 44.52788785099983, 4.456609860062599, 1.517404995393008, 0.24241609673481435, 5.624888995662332, 73.63044261932373, 74.81274917721748, 77.72956386208534, 67.27480486035347, 71.63703918457031, 72.315583974123, 73.38397264480591, 68.36964771151543, 70.53848013281822, 67.34669700264931, 67.34630942344666, 64.63231265544891, 69.42928925156593, 66.39735594391823, 67.8041772544384, 68.75777408480644, 70.01043766736984, 68.22739854454994, 69.40063878893852, 66.01012632250786, 62.59204253554344, 53.05743455886841, 49.22364927828312, 50.17875462770462, 51.82178646326065, 48.20763699710369, 51.6514378041029, 51.472532004117966, 48.313681706786156, 49.719822853803635, 46.52348376810551, 47.5299471616745, 49.49501171708107, 49.66796703636646, 51.253306567668915, 48.257273733615875, 45.463770031929016, 48.351352885365486, 48.496983870863914, 45.50934478640556, 46.383457481861115, 47.13510274887085, 45.142938047647476, 49.753093868494034, 47.04684108495712, 51.603636369109154, 48.97680312395096, 50.53674101829529, 55.90852037072182, 61.69866867363453, 61.44342117011547, 60.4261739552021, 60.57944253087044, 64.2620301246643, 63.3640319108963, 47.41125673055649, 53.5782004147768, 65.32823011279106, 59.74877670407295, 60.22784359753132, 55.412589982151985, 57.86012604832649, 59.30164709687233, 61.80894635617733, 59.96039494872093, 53.70952896773815, 47.66033336520195, 48.40266153216362, 45.33567890524864, 45.549854412674904, 44.93773765861988, 49.0938064455986, 44.009417071938515, 48.03362153470516, 44.08197037875652, 46.162525936961174, 48.1614238768816, 48.996562063694, 44.779502749443054, 45.72017267346382, 45.60779370367527, 46.2545607984066, 43.726222068071365, 46.01743072271347, 45.45731797814369, 43.80523882806301, 45.153056904673576, 46.50720924139023, 47.18749813735485, 47.07322306931019, 44.076244086027145, 45.34609414637089, 44.86621029675007, 44.746231734752655, 48.523970022797585, 50.40163926780224, 49.5730747282505, 48.38473029434681, 47.08648815751076, 50.33979378640652, 50.27916043996811, 47.16726042330265, 48.04138071835041, 48.16062971949577, 45.90937212109566, 55.534460842609406, 61.864449977874756, 64.87200379371643, 66.44693568348885, 60.57490557432175, 60.31129091978073, 13.914700392633677, 1.4180923369713128, 0.7368813373614103, 2.718894467689097, 17.7227696031332, 72.76547223329544, 66.89089626073837, 49.317363649606705, 44.661507681012154, 44.395936131477356, 50.147923082113266, 36.35235294699669, 0.9158910973928869, 0.3841901110718027, 0.12428579415427521, 0.17260187887586653, 0.25019380438607186, 0.13103050645440817, 0.1748452874016948, 0.23049232171615586, 0.13649198604980484, 0.1397169442498125, 0.14615584717830643, 0.1335606214706786, 0.08416352444328368, 0.04346912195615005, 0.09767661613295786, 0.10713239389588125, 0.20137567160418257, 0.07245008149766363], [0.05816261065774597, 0.04465789410460275, 0.05682456663635094, 0.06113585834100377, 0.05269183937343769, 0.0663810501282569, 0.016828862790134735, 0.057327123067807406, 0.10164107254240662, 0.0342751108109951, 0.020674497645813972, 0.10633496363880113, 0.02911973002483137, 0.016709603369235992, 0.10488842133781873, 0.10962173531879671, 0.06142518461274449, 0.0401370161853265, 0.0758240332652349, 0.03756920006708242, 0.062257506942842156, 0.25229449791368097, 0.1486843146267347, 18.502824045717716, 57.00730361044407, 41.832494884729385, 28.687529638409615, 26.275588162243366, 58.14700685441494, 59.08103093504906, 52.733425945043564, 1.4227092079818249, 1.1718877544626594, 0.5430711340159178, 0.09551705545163713, 18.457177095115185, 79.30289223790169, 62.70035192370415, 69.82914939522743, 63.42715412378311, 69.57755729556084, 62.39575646817684, 67.83654391765594, 64.20898497104645, 66.28224492073059, 62.94040784239769, 64.34960782527924, 62.75837101042271, 65.41839927434921, 61.95692181587219, 63.517000302672386, 63.6723929643631, 66.46592706441879, 67.05449268221855, 62.9174380749464, 56.64778970181942, 50.08448928594589, 45.75312830507755, 44.3875727802515, 43.199285343289375, 45.6712730973959, 45.460278019309044, 49.0147440880537, 48.37570197880268, 45.35177104175091, 43.51839981973171, 42.2006381303072, 45.247193053364754, 45.0518037378788, 44.941446259617805, 44.016465693712234, 44.336328729987144, 42.57707633078098, 44.60630044341087, 42.78472758829594, 44.42807860672474, 44.13838595151901, 47.38277345895767, 43.7698133289814, 44.513570219278336, 43.69267366826534, 45.99981106817722, 45.85340112447739, 54.486066699028015, 59.455618634819984, 59.287990629673004, 59.09689508378506, 60.459292978048325, 58.4007952362299, 57.126358821988106, 35.09683571755886, 33.57274129986763, 66.6839973628521, 62.017695754766464, 59.33105371892452, 54.901217222213745, 59.1568748652935, 58.60629960894585, 59.577789679169655, 56.67639456689358, 57.16587670147419, 47.13910013437271, 41.4946436136961, 41.99504256248474, 42.22856663167477, 39.98159520328045, 39.171691462397575, 39.720598608255386, 41.602713614702225, 40.39953477680683, 43.38326387107372, 40.651940032839775, 43.29677291214466, 40.71581080555916, 41.96491397917271, 42.0642976462841, 43.51198956370354, 42.0564890652895, 43.029092475771904, 41.402346566319466, 41.15719132125378, 40.191427543759346, 41.459499299526215, 40.76380982995033, 41.225534453988075, 41.54791675508022, 43.27676698565483, 42.476833909749985, 47.82040737569332, 49.0686821937561, 49.71163809299469, 46.75703063607216, 49.710262566804886, 48.329887837171555, 50.06541050970554, 44.41674001514912, 49.91571754217148, 43.24516028165817, 46.866027787327766, 43.112357407808304, 52.954745069146156, 56.584602892398834, 64.56425070762634, 59.27227847278118, 69.49396178126335, 24.330497235059738, 0.11335936913383193, 0.09529044065857306, 0.2122855541529134, 0.5811068555340171, 18.06076716631651, 58.97174879908562, 52.73967280983925, 27.91979033499956, 25.183021388947964, 27.823501601815224, 43.61649535596371, 5.976481279358268, 0.5905717913992703, 0.16726879082852975, 0.04114861170819495, 0.2018663054332137, 0.029346912560868077, 0.07097816516761668, 0.04849257486057468, 0.023955868346092757, 0.029423359337670263, 0.03211922747141216, 0.052266406928538345, 0.10649186107912101, 0.03514258125505876, 0.02391656791587593, 0.057636197889223695, 0.032662576049915515, 0.051186537530156784, 0.02883004752220586, 0.03738946303201374, 0.04253397506545298, 0.05959141562925652, 0.06757801558705978, 0.035749565286096185, 0.046273690604721196, 0.02747548329352867, 0.014113322176854126, 0.023275803177966736, 0.0571562213008292, 0.04951908013026696, 0.015562236567348009, 0.025413952898816206, 0.013179890574974706, 0.031189546498353593, 0.1917631522519514, 0.013412587268248899, 0.05821212675073184, 0.059234409200144, 0.06937698897672817, 0.03718332409334835, 0.2159064036095515, 0.3003346372861415, 24.489752389490604, 64.00808215141296, 38.941431418061256, 32.82065525650978, 36.939166858792305, 60.44207990169525, 67.11506143212318, 59.72176015377045, 1.5307242306880653, 2.3746837629005313, 0.9827700618188828, 0.18409016163786873, 22.24992837756872, 80.65277740359306, 67.7541795372963, 71.96767464280128, 64.98000919818878, 72.64235123991966, 65.00316515564919, 70.61576038599014, 67.26965233683586, 69.77377876639366, 66.27587646245956, 69.1367581486702, 64.81840386986732, 68.45913290977478, 65.1739051938057, 66.30153268575668, 64.50533866882324, 68.16865369677544, 68.68183895945549, 63.517144694924355, 59.5785154402256, 52.50231474637985, 48.97220157086849, 46.541912779212, 46.8075755238533, 48.24709787964821, 49.846367463469505, 48.76174606382847, 49.95757229626179, 48.63215021789074, 44.44177307188511, 44.71525199711323, 46.848670318722725, 49.554090946912766, 47.32337884604931, 45.44211499392986, 46.84974946081638, 45.46225771307945, 46.6432761400938, 47.186430394649506, 45.240608006715775, 46.091678738594055, 45.51000975072384, 46.29673473536968, 44.50575403869152, 47.49583259224892, 48.790890499949455, 50.41914872825146, 54.970160722732544, 62.23773814737797, 59.62552651762962, 61.65674552321434, 61.43194958567619, 62.64995902776718, 57.766795456409454, 36.27889148890972, 39.09938894212246, 65.55874854326248, 64.0919816493988, 60.2760212123394, 55.49830578267574, 60.5319906771183, 61.67686924338341, 60.29295310378075, 57.91847571730614, 58.46719667315483, 47.342533618211746, 45.5935862660408, 43.58583100140095, 44.56294856965542, 42.11465634405613, 42.49262586236, 41.57056733965874, 44.13968168199062, 42.33590707182884, 45.052236914634705, 43.21273662149906, 45.71696564555168, 42.399614453315735, 43.76618452370167, 42.62210391461849, 43.42607617378235, 44.35853473842144, 44.68906760215759, 43.655245676636696, 43.47926951944828, 41.34113945066929, 42.89221242070198, 42.24326804280281, 42.07208722829819, 43.86391527950764, 44.141604378819466, 44.95398938655853, 48.96856516599655, 50.1532693952322, 52.405872121453285, 49.18328404426575, 51.82982683181763, 51.01321265101433, 52.092483937740326, 45.92162646353245, 50.51424242556095, 45.65466418862343, 49.757520630955696, 44.66305039823055, 55.25645636022091, 59.080848544836044, 67.98843696713448, 60.12649163603783, 70.54741725325584, 24.867712408304214, 0.36824782902840525, 0.958415565546602, 1.722997238393873, 1.387383216060698, 22.712602950632572, 65.4388801753521, 56.345854103565216, 34.87359769642353, 32.72796303033829, 29.115578569471836, 51.606406420469284, 7.763530137017369, 0.44469937041867524, 0.1216618790931534, 0.09022363519761711, 0.09000398174975999, 0.01784682594006881, 0.129256313375663, 0.018827143649104983, 0.05971637103357352, 0.07781911175698042, 0.03785213273658883, 0.03063089297938859, 0.05089017569844145, 0.0017133281562564662, 0.083525611407822, 0.05664206139044836, 0.038986416402622126, 0.08838539477437735, 0.0176780504261842, 0.11360568794771098, 0.2206110261613503, 0.17242958187125623, 0.18375702638877556, 0.15270314819645137, 0.2645678096450865, 0.21438896394101903, 0.14843412180198357, 0.1932537558604963, 0.14815632108366117, 0.061013248123344965, 0.18252908368594944, 0.06050910349586047, 0.05802436338854022, 0.23830673599150032, 0.3172247903421521, 0.11634036112809554, 0.16611058032140136, 0.18309035513084382, 0.22801374143455178, 0.21503711119294167, 0.5066789430566132, 0.39712912926916033, 34.0275464951992, 75.33759981393814, 51.9616873562336, 40.22302284836769, 39.578087255358696, 67.98478156328201, 72.27547332644463, 66.31693705916405, 1.7501186393201351, 3.5664380388334394, 1.1761886486783624, 0.22172395081724972, 24.494604729115963, 81.86030700802803, 71.32306203246117, 75.53509041666985, 69.25078243017197, 73.67625296115875, 67.39338129758835, 70.65562784671783, 71.26530513167381, 71.8538935482502, 67.921651750803, 70.89804723858833, 70.41269928216934, 70.63262388110161, 66.89036428928375, 69.02104675769806, 66.62207588553429, 70.61303973197937, 71.1540699005127, 67.97169506549835, 64.1366520524025, 54.227634966373444, 51.37142322957516, 49.55249883234501, 49.63576376438141, 50.88781177997589, 51.908220425248146, 52.2903773188591, 52.85875461995602, 53.97341340780258, 47.342499420046806, 47.72848650813103, 50.21546445786953, 51.42088517546654, 51.00250102579594, 48.274612203240395, 50.02779632806778, 47.94208824634552, 50.35635329782963, 48.57210583984852, 49.14367876946926, 48.78623954951763, 50.245061069726944, 47.066885009408, 48.6898273229599, 48.93309026956558, 49.85444203019142, 52.02931232750416, 57.7273877710104, 64.03699859976768, 60.38279548287392, 63.94692823290825, 62.13013172149658, 64.92594569921494, 57.913817167282104, 35.03993757069111, 36.30240462720394, 69.32345733046532, 66.29986837506294, 63.483083322644234, 58.021959364414215, 64.10255268216133, 64.61297929286957, 62.06237755715847, 61.14995911717415, 60.37270322442055, 49.81216549873352, 44.8450568318367, 45.770443975925446, 45.7342167198658, 43.75939428806305, 45.725868567824364, 44.57234166562557, 47.464153692126274, 45.404018238186836, 49.50600452721119, 44.71383087337017, 47.268031015992165, 45.019566267728806, 45.6743623316288, 45.48454351723194, 47.605661898851395, 47.01264671981335, 46.47500976920128, 46.690663397312164, 44.99121978878975, 43.92821542918682, 44.79127071797848, 44.89459477365017, 45.186430513858795, 46.972908452153206, 45.86856611073017, 46.57516859471798, 51.07717081904411, 53.817587569355965, 55.6342738866806, 51.57388396561146, 53.7092249840498, 54.7545450925827, 52.63687312602997, 48.55662927031517, 55.238547921180725, 46.58677697181702, 51.94558762013912, 45.88362090289593, 57.74617396295071, 63.166275322437286, 72.36491292715073, 62.747325003147125, 71.021419018507, 27.689302302896976, 0.2668354567140341, 0.3585210634628311, 1.3197083724662662, 4.8970109783113, 24.443524070084095, 72.84399881958961, 61.66239582002163, 38.77395160496235, 37.457356452941895, 36.73448324203491, 63.10808144509792, 12.099454198032618, 0.8079473802354187, 0.18340636161156, 0.18624598189489916, 0.2814989589387551, 0.07769768897560425, 0.27134685369674116, 0.08133931114571169, 0.12938872736413032, 0.12847664271248505, 0.17652896814979613, 0.14228777348762378, 0.2736430586082861, 0.13873175805201754, 0.15062431833939627, 0.1095898897619918, 0.1507738759391941, 0.2250927669228986, 0.18476312630809844], [0.060265430438448675, 0.0779266118479427, 0.02889146580855595, 0.06027151604939718, 0.004939925111102639, 0.05286270774377044, 0.052357249514898285, 0.023152782923716586, 0.018542166362749413, 0.019846724680974148, 0.04278131804312579, 0.011079295381932752, 0.034045657303067856, 0.06816280569182709, 0.07899085161625408, 0.029204820966697298, 0.030332514361361973, 0.07672295963857323, 0.04632494332327042, 0.09655419198679738, 0.18240245844935998, 0.13975978101370856, 0.10038168504252099, 1.6555673629045486, 49.64744433760643, 47.55514360964298, 52.88683891296387, 22.943260073661804, 45.74196830391884, 59.447095692157745, 66.86534643173218, 8.834647536277771, 1.538219922222197, 0.44272199214901775, 0.15102406876394525, 0.2353545615915209, 33.30704815685749, 74.27872583270073, 63.146972358226776, 66.80995300412178, 59.64299038052559, 65.05048781633377, 66.33351176977158, 66.35089203715324, 64.16440576314926, 69.63356629014015, 63.58019471168518, 66.51197299361229, 67.37136527895927, 67.01815143227577, 62.495276927948, 65.6321682035923, 65.2303397655487, 62.58655562996864, 57.563582360744476, 54.474671110510826, 45.58657184243202, 49.85743626952171, 45.41377991437912, 45.38672536611557, 48.04057136178017, 45.429400876164436, 46.36239901185036, 47.977148965001106, 44.36233073472977, 43.675867170095444, 44.25877869129181, 46.39430969953537, 42.690614238381386, 45.045762062072754, 44.150495901703835, 42.688075974583626, 43.04714150726795, 42.91988633573055, 44.14690129458904, 47.505126893520355, 42.82727770507336, 45.33493414521217, 46.284149810671806, 47.96601556241512, 42.51529164612293, 47.0523925870657, 43.684640899300575, 53.861536011099815, 56.06572553515434, 60.526214987039566, 58.21915738284588, 60.2169343829155, 50.89736446738243, 72.68041759729385, 35.08610889315605, 26.499622240662575, 71.4934752881527, 54.56752672791481, 62.68870934844017, 55.80173850059509, 61.878049448132515, 57.28759936988354, 62.86746695637703, 59.23673518002033, 59.57916900515556, 48.606490194797516, 42.086226269602776, 41.515633687376976, 41.561303436756134, 39.17014114558697, 39.008547216653824, 41.05922877788544, 37.80525058507919, 42.51816809177399, 40.27485206723213, 40.50794675946236, 43.50470155477524, 41.19651921093464, 42.76627577841282, 39.64589461684227, 42.4958860874176, 40.079246163368225, 41.80257149040699, 41.295101121068, 41.41887187957764, 42.01054573059082, 40.80029547214508, 41.69477507472038, 41.86120234429836, 42.009470388293266, 42.33868092298508, 42.20256842672825, 48.63945722579956, 49.22117181122303, 53.48057985305786, 52.08170011639595, 52.060086876153946, 48.118904158473015, 49.90122132003307, 49.891467243433, 51.499122977256775, 52.225142419338226, 50.50498612225056, 45.6940832734108, 49.10464346408844, 55.08148334920406, 62.244877964258194, 58.99245008826256, 62.81425081193447, 1.8038355256430805, 0.23398936609737575, 1.1194677860476077, 1.4526075473986566, 0.7425952213816345, 23.817790746688843, 65.55659785866737, 40.29339887201786, 25.96010059118271, 25.40766153484583, 37.63839393854141, 32.39623323082924, 0.3126861120108515, 0.06291211087955162, 0.055336456643999554, 0.028112483487348072, 0.06498978298623115, 0.012763253507728223, 0.03671018639579415, 0.04970170783053618, 0.0732717577193398, 0.06587368829059415, 0.0344486694666557, 0.05881630175281316, 0.044084551627747715, 0.04473181201319676, 0.007217819384095492, 0.07655606546904892, 0.043600285425782204, 0.10150464353500865, 0.07508572249207646, 0.022782824162277393, 0.05496861114806961, 0.02411477515124716, 0.04539115456282161, 0.05770361458417028, 0.02522592607419938, 0.1293583438382484, 0.02743484885286307, 0.027415762669988908, 0.03982325470133219, 0.04467167949769646, 0.036119073192821816, 0.0987225619610399, 0.028244229542906396, 0.05838780052727088, 0.07861352889449336, 0.03778356942348182, 0.06628566930885427, 0.09081293013878167, 0.012527313629107084, 0.15610886388458312, 0.06787394697312266, 0.21988315740600228, 3.4487141808494925, 60.572922080755234, 47.36413165926933, 47.63266324996948, 33.696056082844734, 58.52452039718628, 68.57867449522018, 71.95434495806694, 10.626242849975824, 1.2432803423143923, 2.7991924714297056, 0.32371350622270256, 0.20696088206022978, 38.72049227356911, 75.10627582669258, 64.39218834042549, 68.89164090156555, 60.50607606768608, 68.81538659334183, 65.52668586373329, 69.2366623878479, 67.55182519555092, 73.24851751327515, 67.14944958686829, 70.50042137503624, 68.8012133538723, 70.12939408421516, 66.01134225726128, 68.48468273878098, 68.11905115842819, 64.90710631012917, 59.35359410941601, 56.48035928606987, 48.997424617409706, 49.39701497554779, 48.346994519233704, 47.2148110717535, 48.53540360927582, 46.942730471491814, 48.76101650297642, 49.81680504977703, 47.136634066700935, 46.06804400682449, 47.570521384477615, 45.959928408265114, 45.24856097996235, 48.297251388430595, 45.74831396341324, 44.658490642905235, 45.394746735692024, 44.743153899908066, 46.27245023846626, 46.473607644438744, 44.09089230000973, 46.91540613770485, 46.60298690199852, 48.379117995500565, 45.15429183840752, 47.685077637434006, 46.23907282948494, 57.431360855698586, 58.06993938982487, 63.17522384226322, 59.04852367937565, 63.024174347519875, 51.88271999359131, 74.10031020641327, 32.02207490801811, 20.164636373519897, 73.94963309168816, 58.34437966346741, 67.05970600247383, 60.05961902439594, 64.73856255412102, 57.85173609852791, 65.03206640481949, 61.347776502370834, 63.88898894190788, 49.590466395020485, 44.489034935832024, 43.96183982491493, 43.14492166042328, 40.125010907649994, 41.643531024456024, 42.4494905769825, 42.19106264412403, 44.257539957761765, 42.41164080798626, 42.915429174900055, 44.24435466527939, 45.236895605921745, 43.72354321181774, 43.09012860059738, 44.45958271622658, 44.21945080161095, 44.05784547328949, 42.20586284995079, 43.06723862886429, 44.89815138280392, 42.76080407202244, 43.49747434258461, 43.20808567106724, 43.76903437077999, 42.61538587510586, 45.51115728914738, 50.450592041015625, 51.2555218487978, 55.32004974782467, 54.1950137168169, 54.61466699838638, 49.78880435228348, 51.67686603963375, 53.15489172935486, 52.5951361656189, 54.339972138404846, 53.02764415740967, 46.78859934210777, 50.6196715682745, 55.953787341713905, 66.13251775503159, 57.94457271695137, 63.671788796782494, 1.6712397406809032, 0.3572915028780699, 5.669798785820603, 4.226222522556782, 0.22927433863515034, 26.790143251419067, 72.05332204699516, 45.895521864295006, 34.65847223997116, 27.88830142468214, 40.24942383170128, 39.411169812083244, 0.496623168583028, 0.10506702659768052, 0.04162290344538633, 0.07781125241308473, 0.04234431922668591, 0.036379285011207685, 0.02223541603598278, 0.029608771947096102, 0.036672904607257806, 0.06629032999626361, 0.10372066681156866, 0.11419854519772343, 0.04452001790923532, 0.0909605210472364, 0.039676164742559195, 0.019624605447461363, 0.023286106043087784, 0.05053219705587253, 0.08805796664091758, 0.19543446775060147, 0.21885872643906623, 0.10803407363709994, 0.15117684728465974, 0.11753523373045027, 0.06626865928410552, 0.27018957829568535, 0.11336587034747936, 0.12316246458794922, 0.10503273937501945, 0.1372183408238925, 0.1314062558230944, 0.310605961130932, 0.20468369097216055, 0.14108993229456246, 0.15935132192680612, 0.10267568577546626, 0.14370434044394642, 0.213370633427985, 0.12405658926581964, 0.2616458258125931, 0.23294820712180808, 0.28508103860076517, 4.091024827212095, 72.32403472065926, 62.7617072314024, 66.31697505712509, 40.037623196840286, 61.39639489352703, 72.16432929039001, 81.07472956180573, 11.649918369948864, 7.547606248408556, 1.2578064878471196, 0.5871300073340535, 0.4853607510449365, 38.01025718450546, 79.20956164598465, 62.89592742919922, 70.58499723672867, 62.19709172844887, 67.84894645214081, 68.05054843425751, 70.94945847988129, 69.42482829093933, 77.16203391551971, 69.02831196784973, 73.9298589527607, 71.46167859435081, 71.31636679172516, 66.11607983708382, 71.16310581564903, 70.83841323852539, 68.63346755504608, 60.713883116841316, 60.72386138141155, 51.734410151839256, 54.36241373419762, 51.09534904360771, 51.18893042206764, 53.55004772543907, 50.34394696354866, 50.81528127193451, 54.60066094994545, 49.59550492465496, 48.63833628594875, 49.642937779426575, 48.76268081367016, 47.865480557084084, 50.74457086622715, 48.41271959245205, 47.985835298895836, 48.982141837477684, 48.706234842538834, 49.110814332962036, 50.955558344721794, 45.68271428346634, 49.39062371850014, 49.7075305134058, 52.6471021771431, 46.67587839066982, 50.59227503836155, 48.32329139113426, 58.990569189190865, 58.60298998653889, 66.35415226221085, 59.830723106861115, 66.4167957007885, 52.40675367414951, 79.8092682659626, 32.763111144304276, 23.618436343967915, 79.78125616908073, 60.35481758415699, 69.43339303135872, 60.75354538857937, 68.82585123181343, 58.590313866734505, 70.30853927135468, 63.513227105140686, 65.99204689264297, 51.575073301792145, 49.44391965866089, 46.478205397725105, 47.070734202861786, 43.43614183366299, 45.30731722712517, 46.06347665190697, 44.721825644373894, 47.44206927716732, 44.54644225537777, 44.04938332736492, 48.17433558404446, 47.11103484034538, 45.864504128694534, 44.994415417313576, 48.93775261938572, 46.32468223571777, 46.379213109612465, 45.29268801212311, 47.217018753290176, 46.697335839271545, 45.46652488410473, 45.12783005833626, 47.2126641869545, 46.80041290819645, 46.57812483608723, 46.94031000137329, 52.19848684966564, 51.972379982471466, 59.42123807966709, 58.06435368955135, 57.914759516716, 51.10999345779419, 55.76668918132782, 56.206747367978096, 56.96121968328953, 55.35492807626724, 54.93423365056515, 49.42181244492531, 54.65277135372162, 55.6364169716835, 69.11150470376015, 59.86950762569904, 68.85565683245659, 2.2467607771977782, 0.37551467190496624, 5.231949230656028, 8.62969508394599, 2.8852260299026966, 28.65541946142912, 79.74304541945457, 51.34253337979317, 39.26416330039501, 38.04795116186142, 48.51597525179386, 49.78012941777706, 0.7628958695568144, 0.2230330102611333, 0.09587277425453067, 0.2042985163279809, 0.09522645268589258, 0.13436411507427692, 0.17806545132771134, 0.14777683129068464, 0.18249858141643927, 0.21156532951863483, 0.12754143273923546, 0.2415089844726026, 0.21400359633844346, 0.23815860331524163, 0.14107992814388126, 0.12495813542045653, 0.19534153601853177, 0.2235787411336787, 0.20053070678841323], [0.14296220761025324, 0.07923369717900641, 0.01866031812824076, 0.02704466100112768, 0.028998583693464752, 0.04831581383768935, 0.024391889382968657, 0.048108376140589826, 0.014605153646698454, 0.03597074013669044, 0.3253916505491361, 0.08801855859928764, 0.06739697608281858, 0.05909770188736729, 0.08841755945468321, 0.026342973360442556, 0.06739776275935583, 0.08496457638102584, 0.07750696444418281, 0.09004135630675592, 0.15511849749600515, 0.10516068563447334, 0.05314378133334685, 0.3153816517442465, 14.154040049761534, 55.61948508024216, 33.53594787418842, 36.25985451042652, 29.33339048177004, 52.98586539924145, 71.61737143993378, 37.18429930508137, 0.2145304618170485, 1.9932780414819717, 0.18935935077024624, 0.2308041276410222, 0.38773680513259023, 46.232715770602226, 73.7304000556469, 60.979310274124146, 65.51696598529816, 62.26577304303646, 66.50710925459862, 62.762383595108986, 66.08451873064041, 67.84149125218391, 71.50872766971588, 68.4443137049675, 65.85962399840355, 67.62398332357407, 68.0945348739624, 65.76280519366264, 59.82503101229668, 52.43111416697502, 51.37475565075874, 47.668955102562904, 49.969180673360825, 46.90596364438534, 45.82266457378864, 46.512916535139084, 44.872742146253586, 46.247147396206856, 43.569176495075226, 44.47865009307861, 47.887811958789825, 47.128228917717934, 45.34566476941109, 43.732746317982674, 45.28901360929012, 46.14924564957619, 38.35028573870659, 40.564377531409264, 43.119527623057365, 46.819985657930374, 44.785232841968536, 43.913829401135445, 42.82946638762951, 50.681855231523514, 51.52940735220909, 51.886550188064575, 50.53224205970764, 50.202776938676834, 44.29194711148739, 48.742861077189445, 50.510849207639694, 62.18970872461796, 55.25853864848614, 62.706146612763405, 54.39248912036419, 79.98890742659569, 38.36437538266182, 27.77508269995451, 56.66115738451481, 56.9765480607748, 69.60794046521187, 56.934883296489716, 58.93466658890247, 56.3466976583004, 62.86888428032398, 55.8449649810791, 57.938196659088135, 43.51543217897415, 41.18271455168724, 42.81090058386326, 44.44852910935879, 40.13798341155052, 41.74741744995117, 39.392296224832535, 42.71405138075352, 40.769376531243324, 38.53342831134796, 40.68911723792553, 41.03268340229988, 40.435990020632744, 42.02247329056263, 40.411800518631935, 43.28450717031956, 42.83263921737671, 41.08531817793846, 39.24283504486084, 41.33082680404186, 41.92389518022537, 41.77017442882061, 42.56814680993557, 39.76512461900711, 43.31845074892044, 39.656788632273674, 43.646095767617226, 49.02875013649464, 50.33108465373516, 53.08065511286259, 51.66060671210289, 50.270709693431854, 50.04371367394924, 48.800614178180695, 54.07657407224178, 55.80485813319683, 59.32430148124695, 55.890999510884285, 56.79129660129547, 46.30544766783714, 56.23025290668011, 57.27150723338127, 64.40619438886642, 43.034605979919434, 0.13422438350971788, 1.4851779746823013, 3.719739387743175, 2.214168501086533, 0.4216070001712069, 40.26053063571453, 58.12514282763004, 24.433600902557373, 26.53558351099491, 28.779800087213516, 45.94376027584076, 10.872947461903095, 0.2874395245453343, 0.15026520792162046, 0.05646441350108944, 0.05751301992859226, 0.14892546809278429, 0.015015801582194399, 0.009869904515653616, 0.2021428890293464, 0.0449353942531161, 0.025296220446762163, 0.06199204071890563, 0.037645210832124576, 0.03410482131585013, 0.028612978603632655, 0.06401017773896456, 0.047741116941324435, 0.09528240319923498, 0.061684520696871914, 0.08567848533857614, 0.1352747154305689, 0.10478563388460316, 0.013830892312398646, 0.03237630742660258, 0.008876018491719151, 0.056430052063660696, 0.03851498193398584, 0.008739585773582803, 0.13571455667261034, 0.11794599020504393, 0.2614124055253342, 0.1585497727501206, 0.1801796371000819, 0.07803922533639707, 0.025755895585461985, 0.03912663036317099, 0.05924510354816448, 0.011702726333169267, 0.11103646917035803, 0.16322047915309668, 0.2144022929132916, 0.1825035092770122, 0.07336370981647633, 0.41997564083430916, 21.979322098195553, 61.97511903941631, 32.93854773044586, 46.94259747862816, 37.39951215684414, 62.91891239583492, 79.9194623529911, 40.18297679722309, 0.583643278805539, 5.006959028542042, 0.6389002106152475, 0.8616430114489049, 0.5006002786103636, 51.77969232201576, 73.20360392332077, 61.55669689178467, 68.13966125249863, 63.32869000732899, 68.28647017478943, 65.21308869123459, 66.58407792448997, 67.99966156482697, 73.43202486634254, 70.19496336579323, 70.11105626821518, 70.14216139912605, 69.33909729123116, 70.4064068198204, 64.33111041784286, 56.125317737460136, 53.46610642969608, 50.83129361271858, 51.746748089790344, 50.88874652981758, 46.813495606184006, 46.53072997927666, 47.98387460410595, 47.58363448083401, 45.2706415951252, 46.34467676281929, 49.114568531513214, 49.434355571866035, 47.97347076237202, 47.450219839811325, 47.31457091867924, 48.751547411084175, 42.21952311694622, 43.12325902283192, 45.598005428910255, 49.837122559547424, 47.70080879330635, 46.03607252240181, 43.40029075741768, 50.49840487539768, 51.99759542942047, 53.16778443753719, 49.777526557445526, 54.115472584962845, 46.868949830532074, 51.46163418889046, 51.91467247903347, 65.43640270829201, 57.67278090119362, 64.22989904880524, 56.41420863568783, 83.52994501590729, 44.33455802500248, 27.287251576781273, 63.809558004140854, 64.62171882390976, 68.49509418010712, 59.97269108891487, 58.245763555169106, 58.58046479523182, 65.54283499717712, 59.344554394483566, 61.88417091965675, 46.22988872230053, 42.59105198085308, 44.71143700182438, 45.615978464484215, 42.44041666388512, 41.89195789396763, 42.78175234794617, 44.04670067131519, 44.16377238929272, 40.52044428884983, 42.60946199297905, 43.16505677998066, 44.1287724673748, 43.2431273907423, 44.10308584570885, 47.07936353981495, 45.469849705696106, 44.963150694966316, 42.45261400938034, 43.74463587999344, 44.89108756184578, 43.212379440665245, 44.44799333810806, 42.27571830153465, 44.922587871551514, 41.04508213698864, 45.12586176395416, 49.255578964948654, 53.38922135531902, 56.020314171910286, 53.08084890246391, 52.695576176047325, 51.534263491630554, 50.90868405997753, 56.51173420250416, 58.01673464477062, 61.33355386555195, 58.316747546195984, 59.29097346961498, 48.334363996982574, 58.053353279829025, 60.70202775299549, 66.50685846805573, 45.93482695519924, 0.13663407764397562, 3.06032158434391, 11.408292185515165, 5.649315984919667, 0.33145262219477445, 43.21012236177921, 63.92147719860077, 30.827493108808994, 34.36582714319229, 29.775367565453053, 50.15494130551815, 12.831071689724922, 0.46900022425688803, 0.2876091201324016, 0.023056042118696496, 0.11959171009948477, 0.16238908079685643, 0.04106117186893243, 0.09089135288377292, 0.07068212988087907, 0.046350840566447005, 0.05318235816957895, 0.014037663004273782, 0.016750679387769196, 0.04365122273156885, 0.04302436027501244, 0.06917570368386805, 0.024120665948430542, 0.22406848438549787, 0.03357301313371863, 0.06090620816394221, 0.24515659577446058, 0.308026255806908, 0.1433395451749675, 0.12728565896395594, 0.22837534546852112, 0.2678171399747953, 0.14787038642680272, 0.12195179908303544, 0.3519139008130878, 0.2774678502464667, 0.4164348542690277, 0.3107160364743322, 0.2873628161614761, 0.12727336899843067, 0.1395238671102561, 0.17657802411122248, 0.1897524218657054, 0.1355770367081277, 0.1592413950129412, 0.1947989221662283, 0.2563207974890247, 0.2543570153648034, 0.1459192208130844, 0.5846305727027357, 27.90940549224615, 75.49462258815765, 44.6266483515501, 53.6398521065712, 42.734038308262825, 68.13159808516502, 85.9310057759285, 45.49529694020748, 2.017969354055822, 5.7579402811825275, 0.47692187887150794, 0.6204014969989657, 1.1938765808008611, 52.33141511678696, 76.54886841773987, 64.02247577905655, 68.59859302639961, 65.44086366891861, 66.81831255555153, 67.88333460688591, 68.6484007537365, 70.4174642264843, 77.29280009865761, 73.60616192221642, 72.14318722486496, 72.76864126324654, 74.26236391067505, 74.52068164944649, 64.11089703440666, 57.87288956344128, 55.52968829870224, 53.582790568470955, 54.51871834695339, 54.05130162835121, 50.09070575237274, 49.19923558831215, 50.16317546367645, 50.4582030326128, 47.91879929602146, 49.132902547717094, 50.54314747452736, 51.945264637470245, 50.76909475028515, 49.869709610939026, 50.85201770067215, 51.98957785964012, 43.93850527703762, 46.415881142020226, 47.87490405142307, 51.08940236270428, 50.081628039479256, 49.87021878361702, 47.2347865998745, 55.86239464581013, 56.08810633420944, 56.67085446417332, 54.50623221695423, 56.41023024916649, 48.10175187885761, 55.86583726108074, 52.285931557416916, 67.87877485156059, 59.13604058325291, 68.48310962319374, 56.840667352080345, 84.37815070152283, 41.37180380523205, 23.27314507216215, 63.429908975958824, 64.87030148506165, 71.81364610791206, 62.234675511717796, 60.218226313591, 59.79061245918274, 68.50333973765373, 59.622973054647446, 63.67388628423214, 48.70501130819321, 45.082764476537704, 46.62110053002834, 49.08066675066948, 45.53163439035416, 44.67652067542076, 45.405336767435074, 47.51816779375076, 45.85467405617237, 42.73632578551769, 44.447643756866455, 44.94972601532936, 45.13297498226166, 44.40839186310768, 44.782538786530495, 49.25100781023502, 48.0251669883728, 44.67555172741413, 44.32430997490883, 45.12015447020531, 47.3273990303278, 46.01040109992027, 47.59723015129566, 45.356665179133415, 48.06691534817219, 43.42591278254986, 47.11905620992184, 52.74718880653381, 58.131138905882835, 60.01516900956631, 57.15193524956703, 54.213898703455925, 55.96997827291489, 54.75383833050728, 61.89419858157635, 61.545099914073944, 64.81047749519348, 60.70201255381107, 61.66200064122677, 48.94693672657013, 61.79900988936424, 62.165952399373055, 66.91170394420624, 47.69465692341328, 0.35188828187529, 3.9588280208408833, 13.181886915117502, 10.550280176103115, 0.7296939636580646, 48.84133279323578, 70.60865476727486, 34.646863862872124, 42.8560421615839, 39.4221056252718, 62.05848276615143, 20.235525369644165, 0.7815808325540274, 0.45423397910781205, 0.20577641436830163, 0.16036632761824876, 0.3454306471394375, 0.07611087334225886, 0.15265676396666095, 0.20665418211137876, 0.15685381687944755, 0.16795308067230508, 0.1196884193632286, 0.14853322820272297, 0.25166533479932696, 0.1885498606134206, 0.13710799830732867, 0.15683588659157977, 0.21290116565069184, 0.14380835986230522, 0.15504097274970263], [0.006277649545154418, 0.027138483310409356, 0.03913329856004566, 0.03494943732221145, 0.08159275457728654, 0.04142728816077579, 0.022131838195491582, 0.06544612959260121, 0.089408630883554, 0.030685765523230657, 0.016091398065327667, 0.07281966361915693, 0.019856854996760376, 0.07803555170539767, 0.09202608183841221, 0.02402749116299674, 0.11447758530266583, 0.07215479578007944, 0.1278115002787672, 0.09041709825396538, 0.04036807644297369, 0.040130032575689256, 0.09726513235364109, 0.03073409417993389, 0.47189350181724876, 44.657761082053185, 51.32702261209488, 35.457744151353836, 30.685354135930538, 33.18486951291561, 62.93933629989624, 45.05024582147598, 2.564463629387319, 5.582868475466967, 1.1385112954303622, 0.23290151118999347, 0.41618587856646627, 1.9755115010775626, 47.75815151631832, 65.73354676365852, 69.11050155758858, 67.38436818122864, 66.15875914692879, 67.77523800730705, 70.88407918810844, 67.71609798073769, 68.35792914032936, 69.15289208292961, 67.15682879090309, 66.51777148246765, 59.88618113100529, 57.149305790662766, 48.85501965880394, 45.805052518844604, 47.040875405073166, 45.12986674904823, 48.1660520285368, 48.99273946881294, 47.771249413490295, 50.59726037085056, 44.147254675626755, 46.52135208249092, 46.17209002375603, 46.32054805755615, 46.85305908322334, 47.15582683682442, 46.63842000067234, 44.8467705398798, 43.10323029756546, 47.20612473785877, 41.89906731247902, 45.8900311589241, 43.64625535905361, 44.22114551067352, 43.22467938065529, 46.2428118288517, 51.962226927280426, 58.8993588835001, 55.46552874147892, 55.275823920965195, 51.427683010697365, 55.164611488580704, 50.79182893037796, 51.905792355537415, 43.63597311079502, 53.806834146380424, 51.4670716971159, 64.21932801604271, 58.48778396844864, 64.97782051563263, 47.05543242394924, 64.70453158020973, 18.222729675471783, 30.077363960444927, 73.77279818058014, 55.55971808731556, 64.48888555169106, 56.59823276102543, 61.43205597996712, 54.781884625554085, 52.90583789348602, 43.66077058017254, 45.08354343473911, 41.3484350591898, 43.53359140455723, 42.082589864730835, 41.104298159480095, 40.38115136325359, 41.23246528208256, 39.30126070976257, 40.00036619603634, 41.20991349220276, 40.0473240762949, 42.181323766708374, 43.26489642262459, 42.884396240115166, 43.11577722430229, 43.26262414455414, 42.633434906601906, 43.376876413822174, 43.59400816261768, 42.843012660741806, 42.8151373565197, 43.11730094254017, 39.78017561137676, 43.80619257688522, 42.11304523050785, 44.20485958456993, 46.686985194683075, 49.83192063868046, 49.6596796810627, 50.89600794017315, 47.18830369412899, 49.17198345065117, 49.00169938802719, 56.09350964426994, 55.92571824789047, 63.90689358115196, 57.1237787604332, 60.11199161410332, 53.422477170825005, 60.16646169126034, 53.85628469288349, 68.85920584201813, 39.57580737769604, 0.20671678968938068, 1.7028179462067783, 6.59668542444706, 2.418406354263425, 2.0064780581742525, 57.89419122040272, 47.85095013678074, 26.902879402041435, 28.1553852930665, 36.26372270286083, 40.60267947614193, 0.9947496314998716, 0.17616850702324882, 0.08649309631437063, 0.036369484951137565, 0.04667350782256108, 0.042620784079190344, 0.02744268593232846, 0.07594257651362568, 0.018748136462818366, 0.021863997098989785, 0.08659384286147542, 0.09098121212446131, 0.05512616909982171, 0.06415942363673821, 0.054839132353663445, 0.059028173782280646, 0.11310876070638187, 0.041636959722382016, 0.028803541717934422, 0.042688341782195494, 0.016244491998804733, 0.05766403584857471, 0.03397936867258977, 0.045183067486505024, 0.06984742896747775, 0.06034914840711281, 0.03017326060216874, 0.03240359619667288, 0.047165893120109104, 0.027752805326599628, 0.0231271064694738, 0.052794085058849305, 0.05695990097592585, 0.015090365159267094, 0.07013746027951129, 0.019304637753521092, 0.018799951358232647, 0.07191246972070076, 0.06897244427818805, 0.07096536312019452, 0.07682650408241898, 0.04718740798125509, 0.08409996691625565, 0.21477994218003005, 1.0089554660953581, 57.82522492110729, 47.21927583217621, 39.444604218006134, 41.308670192956924, 41.53926461935043, 75.56598275899887, 54.1198917478323, 2.8807584196329117, 4.653040794655681, 3.62081715837121, 1.501393485814333, 0.7064575573895127, 2.123910994268954, 55.92382214963436, 66.41441702842712, 69.99980583786964, 69.32769030332565, 69.20603603124619, 69.00234416127205, 72.87917733192444, 69.72663089632988, 69.22191917896271, 73.42768549919128, 71.50425910949707, 68.08976992964745, 63.515396788716316, 61.21478743851185, 52.65169993042946, 50.32075300812721, 50.231032222509384, 45.069772973656654, 50.118972435593605, 51.62569418549538, 49.9679571390152, 52.286968901753426, 45.32898746430874, 50.034882947802544, 48.22874866425991, 48.05996932089329, 48.100459948182106, 49.58752155303955, 49.46913130581379, 47.63191469013691, 45.59414103627205, 48.35037253797054, 44.17178235948086, 48.92734497785568, 45.04876010119915, 46.855555549263954, 45.16386732459068, 48.52215752005577, 55.95564164221287, 59.605478793382645, 57.06069074571133, 57.50150889158249, 54.40592899918556, 55.04570446908474, 50.60447998344898, 53.648941218853, 47.04419642686844, 58.8194415718317, 53.64824205636978, 67.87104606628418, 59.43812437355518, 70.09500592947006, 53.002044931054115, 69.66443583369255, 17.503420673310757, 29.4324017688632, 77.99787506461143, 58.443318754434586, 64.09417793154716, 60.48685669898987, 63.67499962449074, 56.84452794492245, 57.08603538572788, 45.942221358418465, 47.394807413220406, 42.97012344002724, 45.1938097178936, 43.35865639150143, 44.70642887055874, 41.66151165962219, 43.73849160969257, 42.039302587509155, 42.372601702809334, 44.254625514149666, 41.4166983962059, 42.40033641457558, 45.541871041059494, 45.26641242206097, 43.363919109106064, 44.79160510003567, 45.988814458251, 45.75212895870209, 46.25894956290722, 44.101026356220245, 45.27374602854252, 45.72914019227028, 41.75467886030674, 45.949760153889656, 42.71535471081734, 46.21090114116669, 48.342442363500595, 51.773263067007065, 49.342636093497276, 53.21213185787201, 50.64546078443527, 51.44564464688301, 51.68791584670544, 58.243688866496086, 58.0479271709919, 66.98974415659904, 58.96579071879387, 61.38474091887474, 57.01233074069023, 62.02953591942787, 54.745235592126846, 68.10357078909874, 40.39322331547737, 0.2899898705072701, 5.326571753248572, 16.3818671554327, 2.8432021848857403, 2.4362518591806293, 63.20218339562416, 53.92185777425766, 34.67405520379543, 32.71978206932545, 38.73758375644684, 48.64400178194046, 1.6475234320387244, 0.26100104791112244, 0.05303977675794158, 0.026621325123414863, 0.1452111525577493, 0.06289285214734264, 0.012997095891478239, 0.08023305097594857, 0.026484074187465012, 0.030722609444637783, 0.046244401746662334, 0.09569759771693498, 0.028629710323002655, 0.044937958373338915, 0.11818268336355686, 0.026857810480578337, 0.08710579117177986, 0.02922138199210167, 0.06669318259810098, 0.03092755352554377, 0.121942024998134, 0.1653268575319089, 0.25364930334035307, 0.11676271737087518, 0.18200668593635783, 0.20230230235029012, 0.09491786768194288, 0.13057886506430805, 0.1624322441057302, 0.1280628508538939, 0.22320100280921906, 0.1484715408878401, 0.13965300080599263, 0.3025560040259734, 0.22514943731948733, 0.2657084312522784, 0.2175679980427958, 0.24149975215550512, 0.19770711689488962, 0.20416599843883887, 0.13822871551383287, 0.13875877222744748, 0.31000256538391113, 0.47569822578225285, 1.5174501179717481, 70.3311176598072, 63.527632132172585, 51.357983350753784, 46.247850358486176, 44.28068831562996, 77.47427836060524, 59.28546756505966, 3.2309174677357078, 16.410166136920452, 5.029242932796478, 1.0946520301513374, 0.5635437229648232, 2.9194087581709027, 54.01909835636616, 68.41320857405663, 72.89195224642754, 71.7566567659378, 70.7960607111454, 70.65494388341904, 74.73741441965103, 75.66977798938751, 72.51562803983688, 75.8239509165287, 76.77368715405464, 72.38098606467247, 66.25338926911354, 63.72583329677582, 55.16996540129185, 53.11147525906563, 52.71814316511154, 47.909147813916206, 52.97103859484196, 54.63888309895992, 52.861695662140846, 54.4369163364172, 50.02510987222195, 52.217979803681374, 52.4349557608366, 50.49553602933884, 52.52821035683155, 51.341116055846214, 52.31067582964897, 50.30908763408661, 48.395924493670464, 52.06332050263882, 45.75495980679989, 53.69485795497894, 48.167868331074715, 48.6720784753561, 46.72223210334778, 52.40063600242138, 58.56881842017174, 63.69575411081314, 59.57200638949871, 58.27794402837753, 55.62866538763046, 58.427978977561, 52.66755647957325, 57.562552616000175, 49.23851028084755, 61.001322492957115, 55.39689302444458, 69.37247470021248, 62.71658085286617, 71.6887392103672, 51.04066237807274, 77.46255978941917, 18.20997755974531, 29.47727356106043, 81.7320866882801, 58.95448252558708, 67.49313354492188, 63.5873307287693, 66.44229993224144, 59.99387875199318, 59.59384001791477, 50.603830218315125, 50.900419503450394, 44.23200912773609, 48.45771297812462, 46.63330167531967, 47.20390945672989, 43.78812454640865, 46.760104671120644, 43.714765682816505, 43.34948368370533, 45.791297256946564, 42.45615541934967, 46.597743183374405, 47.79497914016247, 46.91341504454613, 44.9171731621027, 47.7254618704319, 46.94252908229828, 48.00646059215069, 49.434663355350494, 46.30698658525944, 47.41513632237911, 48.92514109611511, 43.4573332965374, 47.6312193274498, 45.65005503594875, 50.00784359872341, 50.14076426625252, 54.16202388703823, 53.016518354415894, 55.84263190627098, 52.648945078253746, 55.16910284757614, 54.24905061721802, 61.14619351923466, 59.41369168460369, 70.12757778167725, 61.07364781200886, 67.10226371884346, 57.43862986564636, 64.06298160552979, 57.556009367108345, 69.0592423081398, 43.10104161500931, 0.3954240895109251, 3.660229118540883, 17.246318869292736, 9.029910508543253, 2.4451350700110197, 71.12770691514015, 59.23048451542854, 40.419552102684975, 41.81934379041195, 48.710300624370575, 60.15307500958443, 2.9415373457595706, 0.37554308131802827, 0.18414340331219137, 0.10888136879657395, 0.24068447324680164, 0.14401405351236463, 0.15225305047351867, 0.1293364356388338, 0.14265337027609348, 0.11601063233683817, 0.22318157338304445, 0.20743210130603984, 0.1845511986175552, 0.0970370184222702, 0.26157291722483933, 0.2075982533278875, 0.3365593106718734, 0.13930583896581084, 0.17191687657032162, 0.12786291626980528], [0.03978114153142087, 0.058364393189549446, 0.04849569930229336, 0.030930733628338203, 0.010742017093434697, 0.08897182502551004, 0.11477675245259888, 0.0296287357195979, 0.07384157128399238, 0.044218312614248134, 0.042660811814130284, 0.08558107103453949, 0.12961683387402445, 0.03206083158147521, 0.13614301336929202, 0.13146623619832098, 0.029104968707542866, 0.09899012846290134, 0.05221746600000188, 0.09958993221516721, 0.017138327239081264, 0.03509767018840648, 0.13773431157460436, 0.21763629047200084, 0.39261589176021516, 5.365778999403119, 54.830111637711525, 37.286255434155464, 34.802720099687576, 30.341672077775, 40.791552141308784, 65.40906697511673, 10.782167483121157, 3.035166934132576, 4.745714021846652, 1.4458003314211965, 0.9204687236342579, 0.021505840340978466, 3.5437506437301636, 51.26197390258312, 68.88723313808441, 67.35786080360413, 64.22933667898178, 73.14889445900917, 65.29160007834435, 65.64223766326904, 65.39648205041885, 66.09117597341537, 59.351105242967606, 56.8348840624094, 49.796905517578125, 48.66355173289776, 46.84768997132778, 50.563286393880844, 49.438102170825005, 46.58899985253811, 48.774357587099075, 48.77520874142647, 46.49040274322033, 48.00807550549507, 44.22160908579826, 47.360008880496025, 44.34165984392166, 44.629900977015495, 43.77733312547207, 46.9499234855175, 47.25318901240826, 48.58734302222729, 44.834770783782005, 46.47938333451748, 42.2760146856308, 46.64755091071129, 42.508364617824554, 43.79385083913803, 43.05184565484524, 54.334679022431374, 59.14827972650528, 57.201252803206444, 56.46420255303383, 61.13841153681278, 55.613454803824425, 57.2420322149992, 56.438679322600365, 56.94720223546028, 51.573633179068565, 52.213564440608025, 46.656260043382645, 56.074525862932205, 54.91570584475994, 65.32084330916405, 39.12842318415642, 68.86685103178024, 32.16755770146847, 33.29748407006264, 68.4097583591938, 57.10419461131096, 63.28379541635513, 54.82125051319599, 56.34271927177906, 52.29393012821674, 46.548083648085594, 42.97747604548931, 43.305839225649834, 40.18200404942036, 42.978593185544014, 42.201664075255394, 43.09500753879547, 40.77937759459019, 42.56288409233093, 41.991668343544006, 41.326533034443855, 40.41596509516239, 41.140004843473434, 42.273560017347336, 44.34266299009323, 44.686479941010475, 41.01508654654026, 41.61739222705364, 41.81851923465729, 41.19105510413647, 41.33929654955864, 42.52751938998699, 42.841975316405296, 41.42448037862778, 40.849168449640274, 44.16316442191601, 41.76173888146877, 43.99609498679638, 44.544827342033386, 48.474595472216606, 47.576684653759, 48.29556807875633, 47.908323258161545, 48.018429949879646, 48.40858541429043, 53.63690726459026, 59.26040790975094, 61.66747234761715, 58.591541200876236, 63.937861919403076, 55.990291982889175, 60.806510746479034, 53.948505744338036, 71.7193503677845, 30.509391278028488, 0.1543122876319103, 4.506796142086387, 15.360738448798656, 2.63591927010566, 7.178672645241022, 69.28085401654243, 28.01855843514204, 23.219854831695557, 26.048464849591255, 41.98245383799076, 16.424550265073776, 0.11419206624850631, 0.06391680071828887, 0.06526245546410792, 0.08457546835415997, 0.07193358382210135, 0.11734298037481494, 0.030856899211357813, 0.03907791950041428, 0.07542157400166616, 0.06686251843348145, 0.047785252463654615, 0.027988505862595048, 0.0216316083970014, 0.10294504085322842, 0.02907947407948086, 0.06902854322106577, 0.032452384984935634, 0.028009575435135048, 0.06332740187644958, 0.07044221580144949, 0.05733001002226956, 0.08644105691928416, 0.005821714366902597, 0.05452084376884159, 0.020626853620342445, 0.05642213705868926, 0.04957160563208163, 0.08680943676154129, 0.0672611927438993, 0.07043094257824123, 0.09670268089394085, 0.06416197662474588, 0.07968343124957755, 0.06472194931120612, 0.12257121779839508, 0.18533717753598467, 0.02661418195202714, 0.07087796038831584, 0.052808315740549006, 0.044823348507634364, 0.042927970134769566, 0.2649228530935943, 0.30085690144915134, 0.3089369600638747, 0.8358965429943055, 11.57625362277031, 65.85530743002892, 35.63200280070305, 42.32068128883839, 35.44540621340275, 50.875287652015686, 72.31557637453079, 11.333209164440632, 1.4494142937473953, 8.983438052237034, 1.312038959003985, 3.070464190095663, 0.28217912244144827, 4.266070984303951, 57.675368562340736, 70.5686505138874, 69.53917935490608, 68.4329979121685, 74.99133959412575, 68.03487047553062, 68.24778065085411, 67.85838514566422, 68.91033589839935, 65.18785044550896, 57.43440069258213, 53.42776648700237, 50.65100088715553, 49.46417257189751, 53.39360632002354, 50.69228947162628, 48.70086193084717, 48.960198014974594, 52.39890329539776, 50.38123816251755, 52.45586983859539, 47.384654358029366, 48.59100982546806, 46.06344245374203, 48.43609593808651, 45.61515770852566, 48.71901735663414, 49.66442942619324, 51.376514956355095, 48.49117398262024, 47.72263862192631, 45.07539667189121, 51.36415421962738, 43.48665252327919, 45.528735145926476, 45.73312237858772, 55.97171477973461, 62.21271649003029, 59.797391295433044, 56.77344895899296, 61.44037753343582, 58.018562346696854, 58.8064918667078, 56.64810888469219, 60.92818021774292, 55.04530169069767, 55.54229982197285, 46.28786601126194, 59.183503836393356, 57.68668815493584, 68.50563481450081, 45.09657293558121, 77.27122485637665, 34.28442791104317, 30.910349562764168, 69.63029846549034, 58.698300272226334, 66.50131836533546, 58.209353908896446, 56.2498864531517, 54.80339527130127, 49.34472218155861, 46.535658314824104, 44.43398728966713, 42.6574420183897, 45.03095805644989, 44.185028448700905, 44.32945869863033, 43.56224186718464, 44.461235627532005, 42.565065175294876, 43.0634768307209, 42.527823373675346, 42.6020447909832, 45.25584518909454, 46.88425920903683, 46.757661402225494, 42.516819164156914, 45.042581632733345, 43.72082255780697, 44.04038541018963, 43.935739025473595, 42.866575196385384, 44.78107966482639, 43.5392265021801, 43.84159527719021, 44.050800651311874, 43.949623480439186, 45.588057562708855, 44.92449916899204, 50.84278039634228, 50.259580090641975, 49.50760044157505, 49.11353878676891, 50.96075266599655, 50.6955610960722, 55.712713077664375, 61.41640841960907, 64.94552224874496, 59.604646638035774, 67.64014005661011, 58.29679101705551, 67.00226068496704, 57.2384338080883, 72.54535004496574, 31.363038271665573, 0.21679533325368538, 7.1136704832315445, 14.290961902588606, 0.5342623160686344, 8.263841215521097, 75.81689089536667, 34.8845487087965, 33.43715697526932, 29.163815081119537, 46.532116904854774, 20.005436316132545, 0.14736842742422596, 0.12524978461442515, 0.06031160315615125, 0.041054299581446685, 0.008792584394541336, 0.10588258752250113, 0.06714499468216673, 0.05330655287252739, 0.04875519123743288, 0.048410946037620306, 0.03207432382623665, 0.020663139075622894, 0.03246056345233228, 0.07968206569785252, 0.012217139501444763, 0.053567996656056494, 0.018853669862437528, 0.05349660947103985, 0.01348354400761309, 0.09866566892014816, 0.08915014826925471, 0.31442419218365103, 0.10770589593448676, 0.1845261437119916, 0.07152627833420411, 0.1915345707675442, 0.28038538119290024, 0.2490795438643545, 0.3061068244278431, 0.16956039442447945, 0.19895772478776053, 0.17950242734514177, 0.2644525689538568, 0.2355149990762584, 0.2153818536316976, 0.42420166719239205, 0.10497037670575082, 0.2486978573142551, 0.19835369079373777, 0.2383815444773063, 0.1735476718749851, 0.3166123107075691, 0.5207644309848547, 0.3573592461179942, 0.9779003262519836, 18.102002553641796, 80.02872928977013, 48.966372683644295, 51.6026446223259, 43.14513824880123, 54.53288018703461, 85.29754936695099, 12.987539693713188, 8.623016942292452, 16.189682967960835, 4.568168548867106, 2.99426996614784, 0.306205025408417, 4.915755372494459, 59.08376678824425, 72.54772871732712, 73.3315658569336, 71.01036921143532, 78.2928304374218, 69.90428656339645, 71.1244010925293, 71.78516283631325, 72.51935184001923, 67.11414188146591, 61.187660694122314, 55.90436339378357, 54.810713678598404, 53.00684027373791, 56.95350229740143, 54.967956840991974, 51.34489305317402, 52.87564091384411, 54.718583822250366, 52.65154793858528, 54.95193310081959, 48.947799280285835, 51.854992881417274, 48.29302601516247, 49.96290720999241, 48.024122044444084, 49.40991908311844, 52.93329142034054, 54.3643744289875, 51.040753573179245, 51.30548536777496, 48.47910203039646, 53.910705372691154, 45.647835955023766, 49.08353939652443, 47.09495410323143, 61.06025733053684, 63.5779832303524, 62.93883852660656, 58.87768104672432, 65.25762990117073, 59.540171697735786, 62.32701815664768, 59.84606668353081, 62.64095351099968, 57.01266132295132, 57.979177460074425, 47.26133577525616, 61.9602732360363, 57.62559123337269, 69.48286637663841, 45.25667354464531, 77.77981996536255, 34.39150236546993, 31.436672620475292, 73.14338475465775, 61.73377498984337, 68.91587600111961, 59.000243470072746, 59.70912203192711, 56.79726608097553, 52.24293306469917, 48.496136516332626, 45.450485944747925, 44.82372857630253, 48.16548965871334, 47.275816798210144, 48.604594096541405, 46.41096420586109, 47.54596330225468, 46.8619430065155, 46.03892236948013, 46.53727702796459, 44.073945209383965, 47.308635637164116, 47.32669606804848, 49.33240704238415, 44.51379060745239, 47.608424350619316, 44.347845911979675, 45.90902253985405, 46.67416848242283, 46.25096619129181, 47.31533467769623, 45.90896934270859, 45.22252477705479, 48.048037961125374, 46.12033300101757, 49.276116862893105, 46.30057252943516, 55.99064156413078, 52.07910105586052, 52.79361471533775, 54.1189493983984, 53.82450319826603, 53.6016109585762, 57.690149769186974, 65.2614676952362, 67.64950275421143, 61.67687684297562, 71.53980240225792, 58.11354584991932, 67.91671201586723, 56.26945540308952, 73.9196527004242, 33.52388732135296, 0.22652665560599416, 9.712962806224823, 28.88913732022047, 6.515614874660969, 8.896162435412407, 82.56264612078667, 36.79560296237469, 36.71754375100136, 38.95935885608196, 56.34595289826393, 31.00718166679144, 0.21941558952676132, 0.256731502013281, 0.1630996575113386, 0.18940511159598827, 0.16556682356167585, 0.17213453364092857, 0.1424125730409287, 0.10472670735907741, 0.12319273679167964, 0.23424948885804042, 0.10533873428357765, 0.07997404143679887, 0.11959887182456441, 0.31404008623212576, 0.10370422081905417, 0.21978611417580396, 0.1025502108677756, 0.13050819776253775, 0.21222707291599363, 0.21411603171145543], [0.1335644064238295, 0.017552829704072792, 0.06092275434639305, 0.06772192544303834, 0.06154028800665401, 0.04479029325011652, 0.018140803622372914, 0.04724906189949252, 0.025458418676862493, 0.04151822351559531, 0.005144222595845349, 0.10325488008675165, 0.029099903549649753, 0.04525477379502263, 0.014955441783968126, 0.04442884506715927, 0.03115836516371928, 0.059517178597161546, 0.1271380903199315, 0.041898099225363694, 0.032055154151748866, 0.017511152545921504, 0.023659766266064253, 0.03145475668134168, 0.13026125554461032, 1.06037228833884, 36.112365424633026, 50.51256291568279, 29.001134410500526, 37.35594369471073, 29.81338072568178, 80.69772139191628, 28.12460884451866, 0.22700234258081764, 3.3199105923995376, 1.953546185977757, 2.356586284004152, 0.37725892674643546, 0.05394354564487003, 16.689665839076042, 67.91687920689583, 67.57528513669968, 69.50742065906525, 66.03383705019951, 68.13683420419693, 62.96546749770641, 59.18005742132664, 53.332824781537056, 48.700447753071785, 48.12235437333584, 49.22596715390682, 48.97516541182995, 48.71853858232498, 55.150377452373505, 57.451511174440384, 61.58777542412281, 56.342096105217934, 49.90052975714207, 46.4130312949419, 48.81558537483215, 46.94541692733765, 45.86582265794277, 46.112250834703445, 48.10888409614563, 46.88682407140732, 46.58998399972916, 48.489798456430435, 48.90070840716362, 46.740581318736076, 46.546780318021774, 45.30584670603275, 44.566881358623505, 43.37035596370697, 44.5936319231987, 46.51038207113743, 56.455307230353355, 60.58881662786007, 59.49110113084316, 61.78080506622791, 62.37913616001606, 57.125363275408745, 59.31887537240982, 57.85328261554241, 57.70120717585087, 57.40284338593483, 57.652034014463425, 50.82438938319683, 57.43421830236912, 54.76619526743889, 61.3547757267952, 51.28777451813221, 49.27401177585125, 57.97908626496792, 63.832067996263504, 63.07121202349663, 60.34374117851257, 56.827041283249855, 54.260438606143, 49.45732533931732, 46.20458967983723, 45.08364222943783, 43.40436793863773, 43.36261957883835, 45.235102102160454, 45.04437893629074, 43.549539148807526, 42.83235803246498, 42.97535575926304, 41.88861407339573, 39.891885817050934, 40.00480055809021, 42.4985421448946, 42.852428555488586, 44.573519602417946, 42.185203358531, 42.672158628702164, 44.56772491335869, 48.52186493575573, 49.640528708696365, 53.15579608082771, 49.6410758793354, 44.314548298716545, 41.5003927052021, 43.36362272500992, 42.57420748472214, 44.20711286365986, 42.727829441428185, 44.492637142539024, 41.72835387289524, 45.77624626457691, 42.90870353579521, 48.80211889743805, 46.41265891492367, 48.54792393743992, 46.20840847492218, 56.21359080076218, 55.74503414332867, 62.25895620882511, 59.63130980730057, 65.31404167413712, 57.51465618610382, 67.37315878272057, 56.58709175884724, 75.7697582244873, 12.005675230175257, 0.2786033658776432, 8.584542106837034, 20.832716524600983, 0.7098366448190063, 22.303543500602245, 58.36198411881924, 16.16385005414486, 34.60954986512661, 26.34769879281521, 34.4611906260252, 1.4644953282549977, 0.13658153358846903, 0.053956121337250806, 0.09031266323290765, 0.013916007374064066, 0.024219306651502848, 0.04356370867753867, 0.04193726235826034, 0.06275504274526611, 0.07673360945773311, 0.08186161983758211, 0.05399578913056757, 0.0907224920229055, 0.05409818324551452, 0.050245780003024265, 0.084338649030542, 0.03983240538218524, 0.017615533761272673, 0.03889181854901835, 0.022576950541406404, 0.01916680052090669, 0.08606463961768895, 0.020776669116457924, 0.051262759807286784, 0.04723559191916138, 0.005253033041299204, 0.09910650464007631, 0.026609836677380372, 0.05198941886192188, 0.058905726837110706, 0.031099921034183353, 0.03821947728283703, 0.04523272829828784, 0.04993279777409043, 0.05213531025219709, 0.010073327193822479, 0.008728244829399046, 0.03695550331030972, 0.03789140348089859, 0.032361349440179765, 0.05146462397533469, 0.07944759156089276, 0.04548592311039101, 0.019910823975806125, 0.033680383348837495, 0.13293996336869895, 1.2397996103391051, 52.65005461871624, 50.872962176799774, 32.31832221150398, 46.720020622015, 32.68297724425793, 89.525635689497, 28.844377622008324, 0.2066522228415124, 3.9306629821658134, 8.053206168115139, 4.40776395611465, 1.4607540727593005, 0.1781419519102201, 19.18652705848217, 70.62176406383514, 70.8306160569191, 72.02380523085594, 69.42456230521202, 69.2858013510704, 65.65080240368843, 62.47464023530483, 56.81866653263569, 51.64913132786751, 50.49709394574165, 52.00570419430733, 51.582885682582855, 51.199786439538, 54.571269527077675, 59.738342463970184, 62.397276386618614, 60.18862210214138, 51.68137639760971, 48.554790169000626, 51.02849543094635, 48.59651952981949, 48.55372242629528, 48.299299478530884, 49.64206002652645, 48.786011561751366, 49.07343573868275, 49.888643994927406, 50.49919903278351, 47.49705232679844, 48.23170490562916, 47.432786375284195, 47.37629480659962, 46.18768058717251, 47.46737591922283, 48.8693030923605, 58.19084130227566, 64.19782117009163, 63.375739082694054, 62.542747780680656, 62.43095777928829, 60.85211969912052, 61.88237741589546, 60.108875781297684, 59.96690019965172, 58.60052011907101, 56.92319132387638, 53.578606992959976, 59.53925974667072, 58.448805660009384, 61.54533930122852, 52.19089485704899, 52.22107283771038, 64.88083451986313, 70.16087159514427, 64.46458205580711, 62.47406646609306, 58.612557873129845, 56.73645034432411, 52.108956053853035, 48.956014439463615, 46.35596215724945, 46.30839630961418, 45.8156843483448, 46.91408760845661, 46.24224565923214, 47.1700494736433, 44.35567729175091, 45.35785831511021, 44.83265049755573, 43.56862552464008, 42.410626262426376, 44.52845022082329, 46.73129081726074, 47.300298884510994, 45.10689698159695, 45.94811864197254, 44.27676312625408, 49.093578457832336, 49.755084961652756, 53.27998101711273, 50.853093042969704, 45.88861383497715, 44.289207458496094, 45.71129634976387, 45.42823813855648, 47.64371685683727, 43.61188240349293, 47.035840675234795, 44.042338505387306, 48.775402531027794, 47.753542363643646, 51.02533780038357, 48.42636466026306, 50.67825682461262, 48.61462935805321, 60.327090471982956, 56.99394732713699, 64.11878541111946, 59.97379682958126, 65.04598885774612, 61.593395322561264, 67.96768248081207, 57.92806260287762, 76.31403341889381, 11.786625534296036, 0.5146367254201323, 6.760800518095493, 7.256483444944024, 0.7180174277164042, 26.578897386789322, 65.56359708309174, 24.053440801799297, 37.9145061224699, 30.72143130004406, 44.7063984721899, 2.196775646880269, 0.2337124411133118, 0.05598828865913674, 0.019433224115346093, 0.05845545842021238, 0.05137184067280032, 0.05508361806278117, 0.10584314979496412, 0.0455371164571261, 0.028955208872503135, 0.08172160625690594, 0.075059264927404, 0.022561949881492183, 0.11379574454622343, 0.011922560679522576, 0.008162428657669807, 0.0275598432199331, 0.026009058856288902, 0.04397985314426478, 0.010719192341639427, 0.004127964530198369, 0.21329298993805423, 0.101696228957735, 0.16762310697231442, 0.15235801984090358, 0.18833255977369845, 0.13566461013397202, 0.10141898485017009, 0.13860309933079407, 0.10762840087409131, 0.14378196909092367, 0.1579238602425903, 0.18570837011793628, 0.13330854359082878, 0.09191237739287317, 0.08547037228709087, 0.06642396852839738, 0.1118869184574578, 0.2683815878117457, 0.17504335177363828, 0.11879065816174261, 0.14068232994759455, 0.14839665818726644, 0.18925717187812552, 0.16927788848988712, 0.29205286293290555, 1.4376793359406292, 66.78462356328964, 65.00606060028076, 46.273833364248276, 55.49275428056717, 40.407434552907944, 98.55712026357651, 38.24402444064617, 0.5653331300709397, 10.28559872880578, 6.587698431685567, 6.34626698680222, 1.6457794443704188, 0.34387964755296707, 20.650844983756542, 71.80297628045082, 72.30898752808571, 76.05131551623344, 72.12791964411736, 75.20849034190178, 68.9944937825203, 64.80705007910728, 57.653405740857124, 54.788598865270615, 55.30578911304474, 54.22784395515919, 54.21374291181564, 54.70309965312481, 59.279330894351006, 62.5472467392683, 65.68602651357651, 62.71076336503029, 54.52662952244282, 50.35291828215122, 53.25605370104313, 53.21013696491718, 50.18194265663624, 51.074461564421654, 53.64054746925831, 51.007345765829086, 50.51469840109348, 53.42639096081257, 54.854551926255226, 50.967478305101395, 51.49971954524517, 51.04835316538811, 50.92764884233475, 48.150727450847626, 49.89211320877075, 52.041760459542274, 59.625081941485405, 66.29445746541023, 64.9085958302021, 64.83120158314705, 64.68722730875015, 61.23305685818195, 65.02823621034622, 62.83855810761452, 63.25557433068752, 62.10981801152229, 60.387792214751244, 58.68613712489605, 61.92398138344288, 59.03872400522232, 64.08952698111534, 59.12785202264786, 54.74540278315544, 62.263949140906334, 72.94021725654602, 65.69820865988731, 66.16679191589355, 60.143632516264915, 57.965251207351685, 50.98732464015484, 52.73181103169918, 48.858986645936966, 49.837578535079956, 48.50196920335293, 50.74651636183262, 49.79338690638542, 50.13250730931759, 47.05335013568401, 48.03919583559036, 45.37571735680103, 46.736652329564095, 45.205364897847176, 46.68213665485382, 50.180627927184105, 50.872498601675034, 46.084732711315155, 48.40621814131737, 45.996220260858536, 55.01279063522816, 52.8913264721632, 58.667001351714134, 53.74052010476589, 49.212550073862076, 46.30050413310528, 48.989756628870964, 48.76719877123833, 50.25021359324455, 46.670581474900246, 50.53491711616516, 45.23657642304897, 50.886212065815926, 48.1892953813076, 55.35095728933811, 49.75549913942814, 53.823838233947754, 49.78145934641361, 62.329070046544075, 59.102621376514435, 67.06714600324631, 59.935092106461525, 67.18240141868591, 62.14865192770958, 72.78427362442017, 58.181201219558716, 78.58345404267311, 13.505043424665928, 0.388551089563407, 13.748853541910648, 35.065240412950516, 2.3894941806793213, 29.09522496163845, 70.31393498182297, 25.205799266695976, 49.430323988199234, 38.49854998290539, 60.17599917948246, 5.672233505174518, 0.41014871501829475, 0.18623005540575832, 0.07583215236081742, 0.13779911590972915, 0.11712580570019782, 0.10875800158828497, 0.1670983640360646, 0.25568133336491883, 0.12201000572531484, 0.14356609317474067, 0.20678010972915217, 0.1711875235196203, 0.18384197261184454, 0.21512236911803484, 0.1666756664053537, 0.18842431891243905, 0.12101205458748154, 0.13683055381989107, 0.18375788728008047, 0.22320085437968373], [0.004660429049181403, 0.06551427359227091, 0.06724105827743188, 0.00883612805409939, 0.031126352623687126, 0.06817139976192266, 0.09251445211702958, 0.022571432673430536, 0.02107902750140056, 0.0306429974079947, 0.03490966191748157, 0.06782347350963391, 0.0021616006597469095, 0.03334129607537761, 0.06098368838138413, 0.030713625747011974, 0.02626929108373588, 0.013655036709678825, 0.08448019143543206, 0.010497386665520025, 0.05910249616135843, 0.044252132283872925, 0.10856556269573048, 0.013057364776614122, 0.10247804442769848, 0.1871159570873715, 7.3615302331745625, 55.85310414433479, 26.533774808049202, 41.71014904975891, 22.02033329755068, 46.58515825867653, 59.66273032128811, 1.5919846622273326, 2.424060688354075, 0.9295776661019772, 2.6879957132041454, 1.8011211650446057, 0.12778871634509414, 5.561942523345351, 62.13006712496281, 71.05309411883354, 68.65233734250069, 65.06563380360603, 65.03072887659073, 57.657737508416176, 54.45807360112667, 53.64704892039299, 54.539541229605675, 54.31562304496765, 52.542801573872566, 57.77605555951595, 63.34868833422661, 67.19171091914177, 61.48920491337776, 64.36473101377487, 65.51884308457375, 61.02578558027744, 49.473432675004005, 46.043022349476814, 48.18292312324047, 47.81722314655781, 47.3227708786726, 45.94213016331196, 45.99503092467785, 48.15101623535156, 45.6589275598526, 48.72054487466812, 47.1317133307457, 47.52662234008312, 45.25569699704647, 44.48496535420418, 44.08587656915188, 45.053027272224426, 49.44239214062691, 57.58027486503124, 58.231434524059296, 63.82509157061577, 61.958905309438705, 61.42795979976654, 59.816823452711105, 61.78937740623951, 61.150821670889854, 62.03659974038601, 56.88707046210766, 60.07228374481201, 57.35606029629707, 61.65994115173817, 58.788477033376694, 66.76573097705841, 48.35185065865517, 48.07158909738064, 58.24474520981312, 57.12016515433788, 62.855037823319435, 57.670968398451805, 54.4297119230032, 47.41605207324028, 44.69211883842945, 45.13765633106232, 46.104997023940086, 45.301286950707436, 45.58045417070389, 43.79466399550438, 43.89845162630081, 44.08542439341545, 43.43530207872391, 43.04029807448387, 42.88851901888847, 41.04528732597828, 42.71911270916462, 41.4304156601429, 42.85813964903355, 42.97937594354153, 46.016157791018486, 48.769281059503555, 54.350862354040146, 56.80339515209198, 57.14376948773861, 57.39851161837578, 58.05801182985306, 54.126150012016296, 45.4171921312809, 41.462330147624016, 43.04802305996418, 44.118235632777214, 45.599445551633835, 42.349647134542465, 44.76391978561878, 43.37762877345085, 45.167222544550896, 43.57815161347389, 45.281759798526764, 46.626735627651215, 47.79925011098385, 50.23534119129181, 57.65871785581112, 57.81465008854866, 61.310508102178574, 65.71230590343475, 63.738049641251564, 62.539677545428276, 63.77998799085617, 53.97561728954315, 0.06008506257785484, 0.2935942145995796, 3.688877443782985, 6.436404325067997, 0.11053951224312186, 42.61860430240631, 24.11847621202469, 24.63378556072712, 34.024236872792244, 25.48405073583126, 17.029614597558975, 0.3863668302074075, 0.06484008437837474, 0.017771494240150787, 0.02101440870319493, 0.03545429812220391, 0.07453300800989382, 0.06237314097234048, 0.0440664061170537, 0.03248929941037204, 0.10612214537104592, 0.009083355998882325, 0.010656172871676972, 0.03356202934810426, 0.05097550412756391, 0.012516756578406785, 0.039664817304583266, 0.15265807014657184, 0.04250727630278561, 0.05144218885106966, 0.06398108555004, 0.0037445360203491873, 0.02130433240381535, 0.04601856991939712, 0.04696692332800012, 0.04376869728730526, 0.013941166180302389, 0.011948059946007561, 0.05438001382572111, 0.05008088221075013, 0.025635155579948332, 0.03645805285486858, 0.01159290239229449, 0.10393441276391968, 0.036751431252923794, 0.013256808615551563, 0.014836058053333545, 0.05248699177172966, 0.016110066790133715, 0.03949768935854081, 0.03565403232641984, 0.021256847940094303, 0.040841173322405666, 0.013271887200971832, 0.03939142494346015, 0.048097908147610724, 0.0841714208945632, 0.2396883032633923, 14.285539593547583, 64.1342505812645, 29.107587598264217, 48.667313531041145, 29.62459545582533, 59.83153626322746, 63.84839192032814, 1.505337436683476, 2.124199066311121, 5.127915563061833, 6.475721290335059, 3.5174833657220006, 0.592467711539939, 5.989867486059666, 66.89864784479141, 72.21665248274803, 71.19616404175758, 65.2783615887165, 67.78189525008202, 60.27254819869995, 59.36823472380638, 54.27149221301079, 55.69014988839626, 56.18220068514347, 55.83859272301197, 58.58532093465328, 64.72691997885704, 67.62470528483391, 64.33556377887726, 65.70932686328888, 67.53138989210129, 61.805469542741776, 50.055584236979485, 49.603184312582016, 51.679681688547134, 48.36814418435097, 49.09175455570221, 48.14088597893715, 49.474762603640556, 49.69130538403988, 48.177181631326675, 49.63788405060768, 48.335264548659325, 51.10368959605694, 49.197620674967766, 46.39145225286484, 48.597313687205315, 47.99254193902016, 51.851785853505135, 59.148173332214355, 60.310755148530006, 64.80521857738495, 63.06436479091644, 63.38784523308277, 62.37650670111179, 65.69057866930962, 61.74609772861004, 63.08462530374527, 59.57099564373493, 61.804671585559845, 60.35094179213047, 61.137917563319206, 63.248415514826775, 65.79400151968002, 49.897216334939, 48.48428875207901, 62.29399032890797, 58.84552337229252, 65.01320421695709, 60.02736255526543, 57.83602014183998, 50.82954950630665, 47.82239846885204, 47.22573548555374, 47.76788279414177, 47.72310599684715, 49.21513773500919, 46.65043495595455, 45.50017587840557, 46.89657814800739, 45.420558750629425, 47.16066397726536, 45.577999502420425, 43.08874547481537, 45.62495358288288, 44.72966082394123, 45.806089863181114, 44.990178644657135, 47.655382230877876, 52.15475119650364, 57.510723397135735, 56.470107436180115, 60.73097839951515, 59.831562861800194, 60.553740710020065, 55.901794731616974, 46.93681798875332, 44.33781445026398, 45.319818556308746, 47.602112889289856, 45.738989263772964, 44.7418125718832, 46.67180880904198, 44.622096195816994, 48.80159452557564, 46.19981713593006, 47.36923098564148, 50.29627852141857, 49.717740565538406, 55.14671064913273, 59.61520627140999, 60.79372063279152, 63.247473165392876, 66.87850892543793, 63.926644921302795, 64.14925217628479, 65.00128045678139, 50.86716748774052, 0.032326969449059106, 0.5042913055513054, 4.841197673231363, 4.332584990188479, 0.19161188771249726, 47.074720188975334, 32.137858495116234, 27.080916948616505, 33.38650569319725, 31.52396533638239, 28.770897164940834, 0.3565206192433834, 0.024386152581428178, 0.03272045243647881, 0.037440437445184216, 0.04095507072634064, 0.060918594608665444, 0.08021854198887013, 0.12162536542746238, 0.015235981954901945, 0.058624571611289866, 0.05317461756931152, 0.06336377453408204, 0.08959168902947567, 0.08775120732025243, 0.04134564820560627, 0.005743959090978024, 0.052035918124602176, 0.034722451455309056, 0.051701569464057684, 0.05730329270591028, 0.04766178877616767, 0.1533770331298001, 0.13995175977470353, 0.23617312079295516, 0.07097381618223153, 0.12213919137138873, 0.09566244218149222, 0.26510922121815383, 0.10783047284348868, 0.1589744444936514, 0.09552104078466073, 0.1034862372034695, 0.20263898506527767, 0.16742729872930795, 0.14080040564294904, 0.17562087625265121, 0.1582390206749551, 0.18284146848600358, 0.12371485252515413, 0.19104344712104648, 0.06407489301636815, 0.11382557888282463, 0.12959421321284026, 0.3189620393095538, 0.2351449494017288, 0.2543782111024484, 0.4575339239090681, 20.405716337263584, 80.66904813051224, 39.69991251826286, 65.84211453795433, 33.890465050935745, 59.71030376851559, 72.8530803322792, 1.8393442640081048, 7.23344718106091, 7.266814140602946, 7.6602155808359385, 5.158961797133088, 0.7553540461231023, 7.603571070358157, 67.00084716081619, 76.84585288167, 73.41555655002594, 70.1698163151741, 70.30966401100159, 65.26219725608826, 61.58989191055298, 59.34649609029293, 60.200416669249535, 58.7293142080307, 58.553980216383934, 63.23910981416702, 67.10730224847794, 71.45990788936615, 65.8202277123928, 70.72023957967758, 70.40941625833511, 67.2705490887165, 53.20485904812813, 52.96999365091324, 54.126260206103325, 50.6315953284502, 51.19003236293793, 49.63929757475853, 52.2396956384182, 52.48642019927502, 50.317796766757965, 52.21576452255249, 53.633548244833946, 53.27743135392666, 51.9417954236269, 48.71381923556328, 51.06509506702423, 51.97096265852451, 54.91110809147358, 62.09896199405193, 63.31331983208656, 68.49304988980293, 65.60903504490852, 67.26133078336716, 64.39800962805748, 68.33127737045288, 64.86191153526306, 64.60222586989403, 60.57843558490276, 64.47664260864258, 61.681265607476234, 63.71607542037964, 64.29783180356026, 67.01758146286011, 53.27769733965397, 54.428982362151146, 62.30613827705383, 61.771974340081215, 66.34430319070816, 63.84725958108902, 59.06062602996826, 50.203396305441856, 50.18696218729019, 49.97059039771557, 50.08789010345936, 51.43870621919632, 51.57137230038643, 48.08949753642082, 46.3072943687439, 48.87461140751839, 46.97865754365921, 50.22438257932663, 47.805295586586, 46.63422502577305, 48.668924644589424, 46.42924502491951, 47.46068827807903, 47.73985169827938, 50.118045285344124, 55.575852021574974, 59.89614799618721, 61.84362709522247, 62.915123999118805, 61.59909501671791, 64.81430768966675, 60.829879492521286, 48.98248381912708, 45.829055830836296, 46.773628145456314, 49.418559819459915, 48.737845346331596, 45.09787626564503, 48.98709677159786, 47.91815333068371, 50.12723699212074, 48.92318420112133, 50.997945070266724, 51.66187584400177, 51.91876865923405, 55.01203827559948, 61.48711122572422, 62.295035272836685, 65.58384999632835, 69.09348607063293, 65.38660258054733, 66.45414769649506, 64.93966296315193, 55.78680530190468, 0.3423503483645618, 0.5192037241067737, 11.625518929213285, 16.006035022437572, 0.17598653241293505, 52.73471787571907, 33.34136411547661, 37.4958635866642, 51.033940538764, 44.40560661256313, 45.100927501916885, 0.6067198561504483, 0.185155930230394, 0.09134985171840526, 0.11167268268764019, 0.12708516034763306, 0.14406820060685277, 0.25548142846673727, 0.20926648256136104, 0.2011637735995464, 0.1557191027677618, 0.15255985432304442, 0.17265050439164042, 0.190645047405269, 0.13408340513706207, 0.12427230190951377, 0.1672753959428519, 0.227584334788844, 0.1850544786429964, 0.17519261251436546, 0.1142144420009572, 0.20812529692193493], [0.05936522386036813, 0.027829335595015436, 0.02026964124524966, 0.0721190836338792, 0.026906591847364325, 0.04257975073414855, 0.0051982611512357835, 0.07824989137589, 0.007509641127398936, 0.06248441117350012, 0.05513068135769572, 0.02354329546506051, 0.07540846025221981, 0.13723646407015622, 0.03767183166928589, 0.011301461927359924, 0.05125373158080038, 0.11802706983871758, 0.028544764099933673, 0.01786848923075013, 0.005952306846666033, 0.03585675738577265, 0.013829793006152613, 0.11050902481656522, 0.07566402622614987, 0.07230908086057752, 1.2931023188866675, 36.27617463469505, 37.534036338329315, 39.88829120993614, 39.67930622398853, 21.935305260121822, 70.18857970833778, 7.477708999067545, 0.8911840512882918, 9.890477880835533, 5.503299320116639, 1.2672684551216662, 0.18696582061238587, 1.3190919742919505, 44.206717684865, 74.23220112919807, 71.11902818083763, 68.95941406488419, 64.59207281470299, 59.40474696457386, 59.42187264561653, 64.80068162083626, 61.53009071946144, 62.82629996538162, 65.91390788555145, 67.77637794613838, 67.92481318116188, 65.97331389784813, 66.14960163831711, 64.72415372729301, 68.1886938214302, 61.60951025784016, 50.28041437268257, 46.31590850651264, 48.7739472091198, 44.77171316742897, 48.35757315158844, 47.31680519878864, 48.14317345619202, 48.55046220123768, 48.11688646674156, 46.229216158390045, 46.09012842178345, 45.268426313996315, 48.20251867175102, 45.943087711930275, 44.717265889048576, 44.582471922039986, 46.0259460657835, 54.32082876563072, 59.57535021007061, 60.35746604204178, 59.858408421278, 62.25704871118069, 61.79401695728302, 65.19679516553879, 59.360236153006554, 60.972493439912796, 60.47528252005577, 63.978413343429565, 61.82846590876579, 65.67982524633408, 57.75085911154747, 64.71124961972237, 46.97266526520252, 54.69396494328976, 64.78976860642433, 63.088755682110786, 60.14599218964577, 56.74365475773811, 51.18829965591431, 46.09989009797573, 43.18313620984554, 44.316391199827194, 50.961698815226555, 50.344817116856575, 53.90223182737827, 51.84705130755901, 47.134825363755226, 43.32972474396229, 44.360700622200966, 44.48346823453903, 42.32067368924618, 41.61986589431763, 41.47443629801273, 43.90638940036297, 44.04938332736492, 50.64395606517792, 55.955786034464836, 57.67753444612026, 59.306951612234116, 58.304949179291725, 57.78163745999336, 57.90447346866131, 59.35603737831116, 56.06175474822521, 54.11606915295124, 48.99381101131439, 43.32719407975674, 43.4638537466526, 47.294941172003746, 42.91241213679314, 45.98664477467537, 45.51609322428703, 49.05053436756134, 47.438824251294136, 46.70265555381775, 44.946230202913284, 48.72142642736435, 49.14215125143528, 54.46098804473877, 56.57580256462097, 64.3125370144844, 60.44073857367039, 69.2761878669262, 55.791596844792366, 75.48990324139595, 5.187029466032982, 0.15390057378681377, 0.11708541060215794, 3.1206207862123847, 1.1574689531698823, 1.6935865790583193, 45.971909165382385, 18.132710605859756, 46.27192586660385, 41.560627073049545, 28.607139252126217, 7.286946410313249, 0.20351556537207216, 0.016628946759738028, 0.04428329135407694, 0.073228690889664, 0.01147748451330699, 0.04014113510493189, 0.11700776711222716, 0.05105488053231966, 0.04304950052755885, 0.046767203966737725, 0.041819019679678604, 0.04969463887391612, 0.02486486566340318, 0.018514421171857975, 0.05443755253509153, 0.028627543251786847, 0.08052478180616163, 0.07026022634818219, 0.03207381916581653, 0.04962677317962516, 0.06415016905521043, 0.0335550271847751, 0.04858951419009827, 0.05669463142112363, 0.08009882614715025, 0.012871761991846142, 0.030567506146326195, 0.011188619300810387, 0.028826427696913015, 0.02566773215221474, 0.04222563868097495, 0.033657087333267555, 0.03716097060532775, 0.03472046249953564, 0.12778696487657726, 0.015302223273465643, 0.043423583774711005, 0.0388926497544162, 0.008957074005593313, 0.034035523276543245, 0.045862856204621494, 0.009705948323244229, 0.054487424858962186, 0.0016110381739053992, 0.2694690419593826, 0.14933351572835818, 0.059239396432531066, 3.202583813108504, 54.6412617713213, 42.35887683928013, 46.46931767463684, 43.23834344744682, 27.317043878138065, 80.02348557114601, 7.34180549159646, 0.6347532081417739, 6.757765905931592, 7.2639956418424845, 3.5564319882541895, 1.0905626183375716, 1.782457041554153, 47.873277738690376, 76.60245314240456, 71.32640585303307, 70.0466801226139, 65.79739853739738, 62.381465435028076, 61.38439513742924, 66.72991409897804, 61.61033481359482, 64.74965035915375, 68.51150929927826, 71.17057621479034, 68.14585492014885, 71.25247702002525, 66.71313419938087, 67.18655839562416, 70.01762688159943, 64.28785353899002, 53.60113598406315, 50.25395639240742, 50.91111592948437, 47.77804344892502, 49.38547499477863, 50.37380576133728, 49.792034178972244, 50.31200207769871, 49.470069855451584, 50.460213124752045, 46.758501157164574, 48.02359387278557, 49.674255698919296, 48.139271065592766, 45.61874471604824, 48.03555183112621, 49.72174555063248, 57.82949589192867, 62.02391602098942, 62.563327476382256, 61.76834173500538, 64.49829384684563, 63.32220375537872, 65.97906678915024, 62.53324829041958, 62.3007919639349, 62.116593047976494, 64.53498467803001, 62.733391150832176, 65.71650087833405, 59.9799183011055, 67.32712805271149, 47.198281958699226, 56.68092392385006, 69.06896978616714, 64.8980475962162, 60.84913305938244, 59.552714824676514, 53.88817258179188, 48.86350080370903, 46.607991233468056, 46.458644047379494, 51.787850484251976, 52.74351440370083, 56.019979789853096, 52.98052668571472, 48.21787744760513, 46.19022645056248, 45.72776086628437, 46.155648306012154, 44.674096405506134, 44.48037900030613, 44.66935805976391, 45.862429440021515, 47.09949105978012, 52.01356217265129, 57.30778008699417, 58.24658051133156, 60.86055904626846, 58.48358519375324, 60.02197444438934, 58.987901732325554, 61.15297235548496, 58.50843966007233, 56.77969582378864, 50.14784328639507, 45.39132311940193, 46.20187282562256, 47.83613473176956, 45.56355647742748, 48.08969132602215, 47.85172909498215, 51.465080603957176, 48.66002172231674, 51.0203030705452, 47.17568837106228, 51.4115908741951, 52.693467289209366, 56.425380036234856, 57.128836289048195, 66.57335489988327, 60.56815713644028, 69.50563475489616, 55.40870279073715, 74.93245795369148, 5.796739524230361, 0.3595864906674251, 0.845733858877793, 3.6204770766198635, 0.6954050192143768, 1.9575005862861872, 53.462781608104706, 21.988242119550705, 57.441042736172676, 51.28770612180233, 35.28300292789936, 16.07638444751501, 0.32451431325171143, 0.10643596993759274, 0.03786182147450745, 0.09056367984157987, 0.03802196210017428, 0.0832490278116893, 0.0710069530759938, 0.028390260085870977, 0.04795761626155581, 0.061307702635531314, 0.030410703329835087, 0.02969579989439808, 0.02695994669920765, 0.048092126817209646, 0.070005617744755, 0.02501191665942315, 0.060439642184064724, 0.01732953231112333, 0.043491727774380706, 0.04506748911808245, 0.03155828999297228, 0.1586340955691412, 0.08562068687751889, 0.11844083943287842, 0.14911717968061566, 0.11161058719153516, 0.13049825298367068, 0.08971957591711544, 0.20693662867415696, 0.10201597586274147, 0.15083324775332585, 0.12675904581556097, 0.13615067233331501, 0.14069841970922425, 0.2661085082218051, 0.16174394666450098, 0.09679949405835941, 0.14369317854288965, 0.27498180395923555, 0.29625211260281503, 0.13463480601785704, 0.11433048421167769, 0.1341686927480623, 0.12264877965208143, 0.48938319145236164, 0.23361841100268066, 0.19349792244611308, 2.836778867058456, 72.01414614915848, 53.49915325641632, 59.69886638224125, 57.05491125583649, 33.26554678380489, 85.68202033638954, 10.070018246769905, 2.1948736114427447, 26.702022179961205, 13.98866817355156, 4.987078020349145, 0.9535600198432803, 2.668946860358119, 49.95288334786892, 78.31116825342178, 76.48065447807312, 72.97468140721321, 71.87163099646568, 65.32645180821419, 65.80604687333107, 69.7802384197712, 67.91348218917847, 69.24471035599709, 72.28612035512924, 73.10778066515923, 72.64430433511734, 73.38818281888962, 70.0507079064846, 68.02546218037605, 73.95495280623436, 66.79314270615578, 56.20315656065941, 52.03991375863552, 55.106550604104996, 50.27665637433529, 54.25526328384876, 53.32127720117569, 53.33675757050514, 53.43239463865757, 54.27171640098095, 52.21003822982311, 50.89618653059006, 49.656556248664856, 54.159899801015854, 52.17992104589939, 48.8567029684782, 51.18387669324875, 52.679978013038635, 58.40393006801605, 64.43288415670395, 64.84798908233643, 64.72824230790138, 66.38733968138695, 65.49219891428947, 67.98540472984314, 63.34823235869408, 64.21942681074142, 65.57948783040047, 65.28491243720055, 66.32425546646118, 67.48713746666908, 61.03197544813156, 69.36096891760826, 51.108120158314705, 57.77514360845089, 71.65776327252388, 67.51947373151779, 63.38925115764141, 62.282514944672585, 56.634862795472145, 49.80129048228264, 49.11659762263298, 48.726723343133926, 57.51562513411045, 55.68381182849407, 60.92085421085358, 57.30189420282841, 53.18198427557945, 47.717174515128136, 48.65493759512901, 48.20984087884426, 47.338407039642334, 46.879729852080345, 47.0463053137064, 49.4160595536232, 49.73172761499882, 55.397953167557716, 61.149088963866234, 61.60184606909752, 65.54782792925835, 62.436345890164375, 62.662661746144295, 60.31327821314335, 65.80394178628922, 60.61303272843361, 59.93877790868282, 53.86682532727718, 49.598244577646255, 47.05238118767738, 51.64614088833332, 46.03902496397495, 51.034100130200386, 49.9921428412199, 54.087148904800415, 51.480959951877594, 52.33956187963486, 49.75239850580692, 52.644579112529755, 53.33545424044132, 59.90012638270855, 59.193371906876564, 69.2268893122673, 64.38467994332314, 69.59580391645432, 54.186912551522255, 79.23546865582466, 6.965135028585792, 0.4190366162220016, 0.605560087133199, 10.315119344741106, 4.190838821232319, 2.263038153760135, 58.194895684719086, 27.2732987254858, 64.34226661920547, 51.592780351638794, 50.315893068909645, 28.100265450775623, 0.4433202522341162, 0.19823272072244436, 0.1118571731785778, 0.13732817868003622, 0.14807024679612368, 0.24517173558706418, 0.22816953307483345, 0.11046667787013575, 0.15531715558608994, 0.10800897420267574, 0.2031649896525778, 0.1293894398258999, 0.12600652291439474, 0.11977764777839184, 0.13340214325580746, 0.07445089679094963, 0.22504835680592805, 0.1801057340344414, 0.1030881714541465, 0.09674871631432325, 0.11757574757211842], [0.11747211407055147, 0.023975694821274374, 0.06566380150616169, 0.008936441372497939, 0.0925088266376406, 0.010051095232483931, 0.04430322915141005, 0.05729681004595477, 0.054720644766348414, 0.030026792192074936, 0.042112145747523755, 0.030591640788770746, 0.1144801382906735, 0.14379814791027457, 0.025885064533213153, 0.03771898402192164, 0.024535450429539196, 0.035302629112266004, 0.12633772857952863, 0.06378868376486935, 0.18316298170248047, 0.030433667234319728, 0.09944853081833571, 0.039189501403598115, 0.04596295337250922, 0.2021295006852597, 0.302706808433868, 23.10879249125719, 46.957789063453674, 33.93113046884537, 50.75031615793705, 30.25087784975767, 56.70364290475845, 29.752361699938774, 0.39902175427414477, 2.655652086250484, 6.659040553495288, 3.4373527904972434, 0.43432856909930706, 0.04932737225317396, 15.973278880119324, 81.10839575529099, 67.21143946051598, 70.60005962848663, 63.426823541522026, 68.94336372613907, 66.19036585092545, 68.17062199115753, 70.31253665685654, 71.45333424210548, 68.37971717119217, 69.39541786909103, 70.48861160874367, 69.49680402874947, 67.90965959429741, 69.47051703929901, 66.07194140553474, 62.25970096886158, 50.793170258402824, 47.9918047785759, 48.04527550935745, 47.928568571805954, 48.01004759967327, 49.327387511730194, 52.91670151054859, 53.1582735478878, 52.703559547662735, 47.09053114056587, 47.08637796342373, 44.91641320288181, 45.45729897916317, 44.39823120832443, 45.50488382577896, 44.325772896409035, 47.52521261572838, 52.052008509635925, 57.32584051787853, 58.759237602353096, 61.02279134094715, 59.03754986822605, 61.77630990743637, 61.93638011813164, 63.250148221850395, 59.62189771234989, 63.38421642780304, 60.900624096393585, 63.72252747416496, 60.03015160560608, 63.01760829985142, 57.30548121035099, 42.11802676320076, 60.74112765491009, 64.13955509662628, 61.84513181447983, 58.57267141342163, 51.80259369313717, 47.68416948616505, 43.855278342962265, 47.14789666235447, 55.276013910770416, 56.62670463323593, 59.960482344031334, 61.539689004421234, 59.87849794328213, 53.468697890639305, 44.80455480515957, 45.03660835325718, 42.71011859178543, 43.137139678001404, 43.05135928094387, 40.56221544742584, 40.21673038601875, 49.05342601239681, 57.62008532881737, 56.66316367685795, 59.640938490629196, 59.59110036492348, 56.70990876853466, 59.53455559909344, 57.851648703217506, 59.64967042207718, 58.68805602192879, 57.223086431622505, 56.39172904193401, 48.612980246543884, 43.695394322276115, 45.06752349436283, 42.64465570449829, 46.295571997761726, 51.688858196139336, 52.5843371450901, 52.2101978212595, 52.68535852432251, 49.76071625947952, 48.89684781432152, 51.038276106119156, 52.61282801628113, 56.493293792009354, 61.55069701373577, 66.16637393832207, 62.54912003874779, 67.71201699972153, 11.697534564882517, 0.38952377799432725, 0.44597945641726255, 0.9154493117239326, 2.040640600025654, 1.9279492157511413, 7.990610226988792, 36.62467673420906, 25.006851442158222, 51.404777839779854, 41.24058544635773, 32.06364847719669, 3.987608151510358, 0.42570338817313313, 0.08480550444801338, 0.08063313536695205, 0.09164841772872023, 0.03823276543698739, 0.0399640772229759, 0.07265277687110938, 0.03317059097753372, 0.03872468318149913, 0.025984629210142884, 0.055941618702490814, 0.019274404512543697, 0.08053172088693827, 0.08472139685181901, 0.030657087081635837, 0.06968877263716422, 0.019885819165210705, 0.049174586310982704, 0.027050494281866122, 0.08953299999120645, 0.11195834274985828, 0.06239919035579078, 0.04009342985227704, 0.043281273246975616, 0.04740867188957054, 0.048348676136811264, 0.027402036648709327, 0.034542202338343486, 0.04814132007595617, 0.03945594355172943, 0.06638931023189798, 0.026391903156763874, 0.014043535247765249, 0.08683477368322201, 0.10383500950410962, 0.01503106570453383, 0.04356426157755777, 0.04836580490518827, 0.028359754105622414, 0.06162357924040407, 0.02632198913488537, 0.07058352814055979, 0.056116015985026024, 0.07644601981155574, 0.05193197663174942, 0.02999707474373281, 0.26090103609021753, 0.23462528275558725, 28.040865138173103, 58.52635569870472, 39.549239203333855, 61.63031414151192, 35.75308710336685, 69.34684127569199, 28.15799955278635, 0.3802924702176824, 4.937235144898295, 3.6304819397628307, 5.502919340506196, 1.091163579840213, 0.22129472228698432, 19.08489391207695, 81.6631355881691, 69.68561589717865, 74.28003296256065, 66.82707488536835, 72.47367829084396, 70.45940637588501, 71.16778716444969, 71.78980618715286, 72.64406874775887, 70.16074240207672, 71.35133251547813, 72.73536264896393, 71.99550434947014, 69.3673449754715, 70.97915008664131, 68.5139487683773, 64.83071520924568, 52.1854155510664, 50.173313319683075, 51.30247212946415, 50.954410806298256, 51.365993320941925, 50.79037740826607, 54.267863407731056, 56.03664189577103, 54.588410407304764, 49.137781485915184, 49.36075732111931, 47.32341304421425, 46.440458223223686, 47.476263642311096, 46.26529522240162, 46.70487843453884, 49.64464768767357, 54.55874539911747, 58.44407871365547, 60.51882058382034, 62.62843698263168, 60.91686062514782, 65.45276463031769, 64.20320928096771, 64.55962255597115, 61.76183648407459, 66.24746918678284, 62.4842993170023, 64.85572546720505, 61.52279511094093, 65.3289520740509, 61.230837777256966, 43.76018084585667, 63.316108882427216, 64.12358835339546, 64.30897280573845, 60.653367564082146, 56.59571349620819, 49.60999734699726, 47.29842558503151, 49.125751331448555, 56.40597067773342, 59.77355897426605, 61.8437334895134, 63.56948308646679, 61.89226068556309, 54.584724605083466, 47.276177778840065, 46.4982683211565, 45.66657654941082, 44.088703617453575, 44.20003764331341, 43.02270121872425, 42.95545622706413, 51.265724301338196, 58.64980347454548, 60.94850912690163, 61.624891832470894, 62.99108952283859, 60.30104286968708, 62.23513528704643, 61.6958150267601, 61.18683613836765, 59.80494908988476, 60.558790639042854, 57.54543073475361, 50.709673538804054, 44.29446257650852, 46.607957035303116, 44.865967109799385, 48.13694939017296, 53.171306848526, 56.1426942050457, 54.1330998390913, 53.84902708232403, 50.29997572302818, 52.59904235601425, 54.31666798889637, 55.015233904123306, 60.009275525808334, 63.651577681303024, 70.01625895500183, 60.58976657688618, 70.44705703854561, 11.726455762982368, 0.673648277297616, 1.120369762647897, 2.9143258184194565, 2.7977713476866484, 1.4811228797771037, 9.32657578960061, 43.69838856160641, 29.684713929891586, 60.08650258183479, 45.2049545198679, 45.73492348194122, 7.859292598441243, 0.5255497992038727, 0.12529894447652623, 0.021187204802117776, 0.03919101167412009, 0.03742208413314074, 0.016850618849275634, 0.07944584751385264, 0.023148513719206676, 0.03251029476814438, 0.05615156114799902, 0.036820551176788285, 0.00710037451426615, 0.08649826908367686, 0.01735052210278809, 0.03346456680446863, 0.07694920335779898, 0.05733824786148034, 0.029413811607810203, 0.02993578076711856, 0.0721895950846374, 0.008250305436376948, 0.26807965245097876, 0.10774792375741526, 0.19719384756172076, 0.14462772058323026, 0.13625253952341154, 0.0957783953344915, 0.13618966477224603, 0.17040443897712976, 0.15056307631311938, 0.12769067863700911, 0.17740093229804188, 0.08700015387148596, 0.2788262179819867, 0.1710268485476263, 0.12589138612383977, 0.15574535995256156, 0.2215029689250514, 0.13726392353419214, 0.1356635711272247, 0.101968894014135, 0.28383322118315846, 0.13918942568125203, 0.22797912766691297, 0.13351705740205944, 0.10728446737630293, 0.24816305085550994, 0.3793887421488762, 36.78739920258522, 76.44252732396126, 46.08920507133007, 74.90123122930527, 40.47037437558174, 74.06734317541122, 35.05874656140804, 0.35605882527306676, 9.406909178942442, 13.884688653051853, 11.857938207685947, 1.3892476097680628, 0.4529192199697718, 21.691935919225216, 86.68216466903687, 74.39279571175575, 76.55716717243195, 70.9944024682045, 76.31128996610641, 75.17814517021179, 75.09827345609665, 75.6232000887394, 75.54617822170258, 74.05329152941704, 74.22584027051926, 74.88234624266624, 73.8327893614769, 73.13281372189522, 75.41886985301971, 70.42524620890617, 67.37057492136955, 56.04378171265125, 53.129436895251274, 54.36247073113918, 54.22101192176342, 55.373657271265984, 54.742146357893944, 57.32528194785118, 59.37739223241806, 58.54115590453148, 52.16668635606766, 52.298159301280975, 48.9687779545784, 49.73218359053135, 50.32359145581722, 48.60604181885719, 49.679168835282326, 52.73348294198513, 57.00186990201473, 60.83107262849808, 64.84986618161201, 65.99818736314774, 63.14117766916752, 66.33891507983208, 68.16017255187035, 65.01208707690239, 64.78275418281555, 68.09488445520401, 65.1109729707241, 65.50143241882324, 64.82051655650139, 61.52447462081909, 63.04855763912201, 43.30474108457565, 61.63309559226036, 68.9782002568245, 66.03522777557373, 63.34125593304634, 58.33598591387272, 51.90228894352913, 47.39640332758427, 53.97614546120167, 58.9536389708519, 62.84165874123573, 62.5393545627594, 67.65464007854462, 62.9864651709795, 58.44105787575245, 50.43658599257469, 49.40919332206249, 47.057271525263786, 47.8010094165802, 48.504598662257195, 45.402190536260605, 44.46134202182293, 54.69590283930302, 61.27594895660877, 62.21614770591259, 63.66481237113476, 65.96941530704498, 60.09884051978588, 65.40949255228043, 62.3987203091383, 65.52444398403168, 61.45223289728165, 62.53876939415932, 60.79714424908161, 52.99800954759121, 46.71237923204899, 48.375105410814285, 47.10666887462139, 52.06919118762016, 55.32129608094692, 57.777016907930374, 56.4234459400177, 57.16836176812649, 53.89315411448479, 55.38299337029457, 56.284874975681305, 59.73485805094242, 60.30673876404762, 67.15174466371536, 70.00502675771713, 62.09561437368393, 71.32623866200447, 14.253149181604385, 0.7752716867253184, 0.6685452105011791, 3.2042728224769235, 9.868497960269451, 4.435217482969165, 9.915738925337791, 49.42954123020172, 38.43114919960499, 64.3460664153099, 48.9924430847168, 59.233710542321205, 13.162892684340477, 0.7042666780762374, 0.19750042876694351, 0.17234539263881743, 0.18669404613319784, 0.1079496469174046, 0.11641102842986584, 0.17977958981646225, 0.13088768755551428, 0.12611095793545246, 0.07264753730851226, 0.15665741491829976, 0.16240052471403033, 0.2718806656775996, 0.178201858070679, 0.10598118184134364, 0.24316936178365722, 0.17749755992554128, 0.15588808979373425, 0.20473066892009228, 0.2442018227884546, 0.20136474719038233], [0.03338145368616097, 0.021403568680398166, 0.06437351839849725, 0.017167697733384557, 0.07173900754423812, 0.0705374704557471, 0.045978382622706704, 0.05193855948164128, 0.05036797832872253, 0.014106438757153228, 0.052909255246049725, 0.050388550662319176, 0.031864117918303236, 0.07006965766777284, 0.02973035429022275, 0.0189904736544122, 0.02517229106160812, 0.016808965810923837, 0.04024045672849752, 0.05208877759287134, 0.08637944381916896, 0.01778448924596887, 0.054438376319012605, 0.013076657833153149, 0.12418899583281018, 0.111658515088493, 0.38093267648946494, 4.8208146169781685, 48.40542018413544, 44.75095488131046, 41.89877472817898, 36.34821116924286, 29.803831838071346, 58.8262128084898, 2.70077561493963, 4.182911971583962, 2.50646092928946, 2.4370163306593895, 1.147715945262462, 0.26831868337467313, 0.8719588641542941, 55.175665095448494, 73.73293831944466, 73.50129514932632, 70.00496596097946, 73.26817005872726, 70.60306146740913, 70.37233024835587, 75.77317804098129, 69.43039119243622, 71.10091835260391, 72.62472778558731, 70.04173278808594, 67.97934025526047, 67.50537648797035, 68.70284423232079, 64.31240782141685, 58.496329709887505, 52.14198388159275, 52.38203600049019, 47.90363810956478, 49.77327838540077, 52.31841221451759, 55.57353034615517, 59.88553896546364, 60.96981078386307, 63.18587847054005, 54.448995888233185, 47.92341984808445, 44.85782794654369, 46.13632634282112, 47.52178519964218, 45.25933340191841, 45.751741379499435, 43.98336946964264, 48.039575815200806, 53.58141504228115, 56.289119347929955, 58.23051117360592, 60.54149016737938, 60.06567969918251, 59.305560886859894, 62.13282197713852, 63.920960426330566, 60.52320554852486, 60.44540472328663, 59.585275277495384, 57.21096508204937, 57.021765634417534, 40.90852506458759, 55.43745964765549, 68.14483657479286, 66.65199548006058, 62.61812813580036, 56.55779533088207, 48.59990134835243, 46.975256726145744, 54.778669998049736, 58.62503260374069, 59.09676969051361, 58.35879608988762, 60.75345799326897, 60.674255043268204, 62.239767238497734, 57.693349197506905, 47.26993851363659, 42.31728047132492, 43.015097826719284, 41.35490991175175, 41.29005119204521, 41.17591671645641, 44.38726119697094, 55.30483156442642, 60.5452785640955, 59.356379359960556, 58.76576565206051, 58.181638196110725, 58.11168394982815, 59.65893052518368, 58.621931970119476, 57.42023125290871, 57.598635479807854, 59.166883528232574, 59.406715258955956, 57.95824438333511, 47.81855687499046, 44.82049115002155, 44.484748765826225, 45.27115076780319, 51.59670174121857, 54.92492415010929, 57.07809381186962, 56.19484260678291, 52.38248057663441, 55.10699138045311, 51.212565153837204, 55.68446159362793, 58.39422158896923, 64.71601456403732, 56.60344608128071, 72.92338415980339, 16.283849515020847, 0.4104615451069549, 0.1514266393496655, 0.5177337373606861, 1.7093844688497484, 0.8674619835801423, 0.451205808785744, 13.898045886307955, 27.58068323135376, 35.70316918194294, 32.47883699834347, 35.56853100657463, 35.76328955590725, 0.9371942386496812, 0.0795688881771639, 0.07359312992775813, 0.018541092103987467, 0.09701147369924001, 0.008691652310517384, 0.008010251276573399, 0.030246653441281524, 0.006594150481760153, 0.05237925419351086, 0.01888439292088151, 0.05440830449515488, 0.09037304436787963, 0.042534509411780164, 0.04097983619431034, 0.11400604693335481, 0.042298339467379265, 0.07000272336881608, 0.04044641013024375, 0.05645945595460944, 0.05459752988826949, 0.023370039234578144, 0.04593588353600353, 0.03236442193156108, 0.07947702513774857, 0.03590272230212577, 0.04060439110617153, 0.04212942665617447, 0.11259457111009397, 0.05606592101685237, 0.06262849914492108, 0.015978168594301678, 0.05671793856890872, 0.06741827572113834, 0.04366808061604388, 0.018597499038151, 0.02901209820265649, 0.04307459625124466, 0.014661879704362946, 0.013934782782598631, 0.01290736838200246, 0.11638641139143147, 0.029701603489229456, 0.02093293944199104, 0.04624096560291946, 0.024000026132853236, 0.08582778318668716, 0.20181309344479814, 0.3588792239315808, 9.280460514128208, 59.126571491360664, 49.28745925426483, 52.02948331832886, 40.079280361533165, 43.77146624028683, 65.77145352959633, 2.2882500384002924, 1.9392137113027275, 3.3379812352359295, 4.768648641183972, 1.6813900647684932, 0.45810053881723434, 1.556421301793307, 61.39639109373093, 77.89989352226257, 78.01355302333832, 71.84087544679642, 76.50334686040878, 73.04586678743362, 75.06798148155212, 75.22184282541275, 71.57242745161057, 74.65953379869461, 73.27168107032776, 70.28186470270157, 71.41907528042793, 71.33450701832771, 70.76979652047157, 66.13426566123962, 60.35485178232193, 55.64465492963791, 54.14700709283352, 50.55203519761562, 52.031839191913605, 53.2671757042408, 56.047539710998535, 60.21738275885582, 62.5345554202795, 63.19461800158024, 55.894043147563934, 50.097431391477585, 47.538356110453606, 48.65808002650738, 49.81352582573891, 47.563780546188354, 49.562005922198296, 46.254298612475395, 51.89922250807285, 56.63011685013771, 58.62489961087704, 61.189169213175774, 62.68783539533615, 62.081676721572876, 60.4582404345274, 66.09833478927612, 63.456363156437874, 61.79409295320511, 60.709285363554955, 61.06638640165329, 57.41062916815281, 58.88310335576534, 42.49421037733555, 56.5560170263052, 70.8891861140728, 64.88342598080635, 65.56256353855133, 58.59722949564457, 51.96626231074333, 49.28947314620018, 56.07842445373535, 57.27717652916908, 60.067043825984, 60.23824363946915, 64.21095326542854, 61.912118420004845, 64.99023824930191, 60.066147074103355, 48.176246881484985, 46.33108489215374, 46.06908895075321, 44.35557469725609, 43.346117064356804, 44.44301180541515, 46.76110781729221, 57.45734006166458, 63.40174488723278, 61.220479533076286, 60.55599018931389, 60.37243723869324, 59.34063300490379, 61.09646558761597, 60.15224665403366, 60.75490191578865, 60.3084372729063, 63.788172751665115, 59.802699610590935, 59.00707550346851, 49.992857202887535, 45.08402980864048, 46.51369549334049, 47.7459579706192, 53.612212389707565, 58.72546501457691, 59.60738629102707, 58.954220339655876, 55.156825706362724, 58.12528721988201, 54.36929516494274, 57.98520393669605, 61.472744196653366, 68.36306646466255, 56.97747141122818, 74.10765901207924, 17.06965494900942, 0.7566313119605184, 1.612403579056263, 1.878505318891257, 2.474214672110975, 0.6117807095870376, 0.34474220126867294, 17.66009196639061, 33.18359658122063, 42.28096202015877, 33.057564944028854, 36.13484501838684, 49.81761820614338, 1.5240847994573414, 0.11461604037322104, 0.09550401591695845, 0.028689302926068194, 0.06433802889660001, 0.021914698772889096, 0.02512460807338357, 0.08785233236267231, 0.08923668268835172, 0.05572353118623141, 0.019125611324852798, 0.005971797500023968, 0.06357632562867366, 0.03053814307349967, 0.07855766743887216, 0.027142143953824416, 0.08828159800032154, 0.04672872360970359, 0.0107409984957485, 0.01734683733957354, 0.04886856542725582, 0.005771635633209371, 0.15824445319594815, 0.1802363817114383, 0.17988991749007255, 0.12803668272681534, 0.1053057012904901, 0.11301481965347193, 0.180173150729388, 0.11162501454236917, 0.17075983865652233, 0.09245237146387808, 0.18098247761372477, 0.343407285399735, 0.25780158990528435, 0.16746789420722052, 0.16410525277024135, 0.15878409845754504, 0.11646682309219614, 0.17749692167853937, 0.09341427648905665, 0.37075990985613316, 0.1415053420350887, 0.06995685864239931, 0.1421213839785196, 0.07476809070794843, 0.13673848297912627, 0.20589731022482738, 0.35158023121766746, 7.531692702323198, 80.12642964720726, 58.40870641171932, 59.32115525007248, 50.2028339356184, 43.276839181780815, 71.97272837162018, 3.2862318120896816, 10.922377109527588, 7.442814996466041, 7.235848177224398, 4.8126360308378935, 0.6215384672395885, 1.9828511634841561, 60.23535959422588, 77.83743247389793, 81.48728862404823, 76.10239997506142, 81.8111452460289, 76.76433965563774, 75.08118197321892, 81.76370099186897, 73.77652198076248, 78.98664280772209, 75.3950147330761, 73.5360860824585, 70.5683009326458, 72.3729532957077, 74.69155848026276, 69.58247423171997, 63.97098854184151, 58.09121064841747, 57.88135550916195, 54.074199199676514, 57.43631958961487, 56.48414388298988, 60.10858699679375, 64.14174377918243, 66.78891733288765, 67.30023309588432, 59.50736425817013, 53.3232606947422, 50.886390656232834, 50.51947094500065, 54.216710552573204, 51.6337725520134, 52.72307530045509, 47.734976559877396, 54.27666373550892, 58.93894895911217, 61.674889549613, 62.610182762145996, 65.87774142622948, 64.56276878714561, 64.69741076231003, 68.14536094665527, 67.72190406918526, 62.16503284871578, 63.84745717048645, 62.4804425239563, 59.23901125788689, 60.52503705024719, 46.160451248288155, 52.89148226380348, 68.91328454017639, 72.0265106856823, 67.96319872140884, 60.15967145562172, 54.95498813688755, 52.75641091167927, 62.06449404358864, 61.228033527731895, 62.55739599466324, 63.61546441912651, 66.11650541424751, 63.507094234228134, 67.3520091176033, 63.12150612473488, 50.38545973598957, 47.27261357009411, 48.39194990694523, 46.8012260645628, 46.88224531710148, 45.63542202115059, 51.24571077525616, 59.77177307009697, 67.5962296128273, 65.92936545610428, 62.475267201662064, 63.28657306730747, 62.89040632545948, 63.10699850320816, 61.50492466986179, 60.14631137251854, 61.025299206376076, 65.2239865064621, 63.394905254244804, 60.834500044584274, 52.42891028523445, 47.96842843294144, 49.89989899098873, 49.98263195157051, 54.71677131950855, 61.024011075496674, 61.36940874159336, 60.87925024330616, 57.09110431373119, 60.26157058775425, 55.99669083952904, 59.98296573758125, 64.12407472729683, 70.49184143543243, 59.902463257312775, 74.05127763748169, 19.80423331260681, 0.8046887582167983, 1.1777377780526876, 1.0090400115586817, 6.389896245673299, 6.040076091885567, 0.8639436692465097, 18.609550818800926, 39.30056914687157, 50.500859543681145, 44.41395476460457, 49.184138998389244, 62.87486515939236, 2.916474840603769, 0.44221685675438493, 0.3901969059370458, 0.15515603532548994, 0.20126826799241826, 0.16011877683922648, 0.12444822059478611, 0.17209956364240497, 0.20308359089540318, 0.1642538158921525, 0.09222154127201065, 0.18304468336282298, 0.13864595093764365, 0.14085891656577587, 0.13255130063043907, 0.1492599688936025, 0.16724431479815394, 0.17935113311978057, 0.11131972467410378, 0.15514200873440132, 0.19621537037892267, 0.13390929729212075], [0.01613098236703081, 0.023894262667454313, 0.0650855571439024, 0.011036802789021749, 0.08977867313660681, 0.10870521262404509, 0.06814034088165499, 0.02025396708631888, 0.025387628920725547, 0.019127865598420613, 0.08903880385332741, 0.03540636651450768, 0.05901382435695268, 0.007768780542392051, 0.01772907122358447, 0.11107802944025025, 0.018650605270522647, 0.07571341615403071, 0.0083479841305234, 0.04295164835639298, 0.004853658329011523, 0.05469191251904704, 0.04107489046873525, 0.10502293560421094, 0.06990817375481129, 0.024054455243458506, 0.040242230461444706, 0.6961354112718254, 33.36224019527435, 50.79748682677746, 53.4601179510355, 85.22991299629211, 30.10914545506239, 45.78741006553173, 18.97497721016407, 0.8263996650930494, 2.791311931796372, 2.4079578649252653, 0.9560809470713139, 0.3126059897476807, 0.17995674046687782, 6.625604247674346, 77.73826539516449, 70.21965444087982, 79.26759213209152, 68.5864868760109, 73.33372414112091, 67.63889372348785, 74.4721582531929, 71.32625386118889, 75.83465114235878, 68.27968373894691, 71.88632860779762, 68.76231104135513, 66.89101785421371, 64.01539295911789, 60.53669482469559, 58.12242217361927, 52.717254012823105, 48.02017405629158, 48.91377590596676, 51.45716182887554, 56.67774349451065, 59.83980841934681, 64.4966371357441, 63.25126156210899, 63.90249341726303, 63.65565866231918, 53.9857779443264, 46.65971785783768, 46.01494565606117, 45.21597392857075, 46.764512434601784, 45.830940529704094, 48.45367379486561, 47.28885769844055, 49.751190170645714, 55.643921568989754, 57.63348340988159, 56.8359138071537, 56.5936654061079, 57.59058751165867, 54.81184981763363, 59.39098410308361, 59.87723261117935, 61.401707008481026, 58.27502578496933, 59.15866456925869, 53.52225221693516, 63.581733629107475, 69.33092772960663, 63.61264497041702, 62.39731818437576, 60.51816701889038, 55.497561022639275, 49.8101744055748, 56.49413734674454, 60.65600082278252, 59.89232920110226, 63.127669394016266, 62.0202112197876, 63.14699895679951, 63.476585671305656, 62.11446516215801, 59.4629218429327, 46.78623966872692, 41.34275436401367, 44.57777917385101, 41.22131668031216, 45.1879808306694, 43.23938459157944, 47.57596269249916, 54.75290738046169, 59.675657227635384, 58.54522168636322, 59.33687500655651, 61.282416209578514, 60.471007749438286, 59.3587314337492, 59.76909041404724, 58.68924915790558, 60.867368280887604, 60.34433014690876, 60.0210814923048, 59.78006802499294, 56.675619408488274, 47.46771030128002, 42.87253327667713, 45.72533279657364, 51.99129916727543, 55.631393641233444, 58.9481520652771, 58.15945118665695, 57.394590228796005, 54.27624195814133, 56.452142000198364, 59.81247268617153, 60.52613899111748, 57.64663830399513, 73.10509040951729, 44.8001204431057, 0.25191303400788456, 0.017274709862249438, 1.3151228497736156, 2.9477469250559807, 3.1328067323192954, 0.43829359696246684, 0.16788337816251442, 9.728422276675701, 32.33145050704479, 34.45884235203266, 21.60413023084402, 53.9712019264698, 17.069839239120483, 0.10434690586407669, 0.060926617225049995, 0.06010675184370484, 0.032703832039260305, 0.04756159512908198, 0.020853353380516637, 0.012963475674041547, 0.028047089144820347, 0.011102498629043112, 0.03197583711880725, 0.08882199283107184, 0.06761199852917343, 0.02859145446564071, 0.05420458495791536, 0.016948463598964736, 0.0319355459214421, 0.055575324295205064, 0.08756242721574381, 0.042402151084388606, 0.09009232700918801, 0.021274926657497417, 0.028714402360492386, 0.04390196474560071, 0.03346830351802055, 0.048574199972790666, 0.04708160740847234, 0.08042220215429552, 0.08259523281594738, 0.0319993298035115, 0.05657585810695309, 0.07052293178276159, 0.025117142067756504, 0.022853528571431525, 0.07728834258159623, 0.037074636566103436, 0.08599225053330883, 0.03216271732526366, 0.08498132665408775, 0.008247174500866095, 0.10042355701443739, 0.027607498377619777, 0.038480679868371226, 0.039165930793387815, 0.07953546184580773, 0.04733623827632982, 0.08382221072679386, 0.06583276626770385, 0.04062324165715836, 0.050631077101570554, 0.894098257413134, 44.432037994265556, 60.83551838994026, 54.66950945556164, 78.84456843137741, 32.65763260424137, 63.07713210582733, 17.681368924677372, 0.7665840466506779, 2.220758772455156, 1.3168093655258417, 3.849521423690021, 1.7827927297912538, 0.24786776513792574, 8.520089015364647, 81.58967033028603, 71.61452919244766, 80.06836116313934, 72.94460982084274, 77.10501417517662, 67.62784391641617, 79.57482844591141, 72.92943343520164, 76.91517636179924, 69.8123998939991, 75.95042333006859, 69.98240277171135, 68.8755601644516, 66.10545560717583, 63.134725615382195, 60.08417710661888, 54.294161796569824, 49.226320534944534, 53.14393311738968, 53.77781890332699, 58.35660360753536, 62.18932494521141, 66.48115664720535, 65.56592255830765, 66.1698317527771, 65.33059358596802, 56.37907572090626, 48.12031768262386, 48.763398975133896, 47.92293727397919, 48.62728267908096, 47.997899651527405, 49.76639315485954, 49.4717151671648, 54.21765670180321, 57.77819864451885, 58.23274165391922, 58.98320518434048, 60.00134535133839, 57.74289473891258, 59.54489104449749, 62.76605799794197, 65.07611364126205, 65.83206787705421, 61.05820544064045, 61.82604543864727, 52.784183621406555, 60.464232712984085, 72.98961460590363, 66.38142719864845, 62.587646171450615, 60.46103708446026, 57.51329965889454, 52.041160091757774, 58.46698388457298, 60.890144258737564, 63.30621801316738, 64.29235249757767, 63.180243372917175, 65.47474265098572, 66.04219660162926, 64.31005194783211, 61.19499050080776, 50.50284303724766, 43.57545755803585, 45.74115514755249, 44.549542888998985, 46.828322410583496, 44.280555322766304, 48.43752086162567, 56.93107210099697, 61.93750485777855, 60.60761421918869, 61.512645855546, 62.248943746089935, 65.07636442780495, 62.35377252101898, 61.317188143730164, 60.66197410225868, 61.28836669027805, 61.87481202185154, 61.15671135485172, 63.44353124499321, 59.62808758020401, 49.24720421433449, 45.05208492279053, 47.48824819922447, 54.73333463072777, 58.44079948961735, 59.112740233540535, 60.11156223714352, 59.683538004755974, 57.88754157721996, 58.49604852497578, 61.47120147943497, 64.89406540989876, 59.97317746281624, 74.01809021830559, 46.44976772367954, 0.3015741426497698, 0.7612772157881409, 3.7117308424785733, 3.4679810469970107, 2.011460065841675, 0.3316658263793215, 0.1257100497605279, 15.27361387386918, 35.43100118637085, 45.310805439949036, 24.667028076946735, 57.612143754959106, 23.14778219908476, 0.19964553241152316, 0.08698243138496764, 0.025010256103996653, 0.05632300097204279, 0.01871355423645582, 0.07900085576693527, 0.08820795468636788, 0.02633368167153094, 0.045958782502566464, 0.021439299380290322, 0.03265777064370923, 0.0787693724851124, 0.04119535587960854, 0.06163000995002221, 0.021306356611603405, 0.022842134749225806, 0.010294136536685983, 0.020202539963065647, 0.031363658054033294, 0.09743806018377654, 0.055001777727738954, 0.04150961460254621, 0.1546777953626588, 0.11459065892267972, 0.12141210929257795, 0.10933876183116809, 0.15978283627191558, 0.2316265756962821, 0.14307479141280055, 0.16898469562875107, 0.09463919865083881, 0.133761580218561, 0.25702194892801344, 0.15149450133321807, 0.14160804043058306, 0.20823710889089853, 0.10834744549356401, 0.2702302479883656, 0.1232451324176509, 0.2414851912180893, 0.11303700986900367, 0.16192255192436278, 0.17097250849474221, 0.1900586616829969, 0.14185496780555695, 0.22418255248339847, 0.16092026664409786, 0.20056515728356317, 0.07214644661871716, 0.9288761881180108, 51.648211777210236, 75.2814844250679, 65.45187547802925, 101.75646498799324, 39.448138028383255, 62.20194786787033, 22.427789233624935, 1.3845514180138707, 9.935450367629528, 7.213731463998556, 7.749314624816179, 1.3432502467185259, 0.2580682880943641, 10.055300686508417, 83.3400160074234, 73.45199659466743, 86.08020097017288, 76.89863204956055, 79.53834280371666, 72.2944039106369, 81.14342987537384, 75.6997811794281, 81.40906602144241, 74.5723208785057, 78.97569939494133, 71.50747373700142, 72.03986316919327, 70.34244865179062, 65.53584337234497, 63.17197881639004, 57.81089209020138, 52.18276709318161, 56.20847627520561, 56.27924747765064, 62.367409989237785, 65.54997861385345, 70.55516883730888, 67.66272604465485, 68.13313320279121, 69.40727323293686, 59.14260283112526, 52.0868032425642, 52.590245828032494, 51.543071419000626, 52.347499653697014, 51.45405359566212, 53.203783705830574, 51.73377938568592, 54.890387803316116, 60.6661918759346, 60.41713044047356, 62.827177718281746, 63.44461038708687, 61.33907496929169, 62.40490637719631, 67.47713640332222, 66.13087624311447, 68.07433515787125, 60.485712960362434, 64.52471002936363, 54.65939819812775, 59.08533610403538, 59.441494792699814, 66.53228670358658, 65.61088934540749, 64.13952469825745, 60.48050343990326, 54.13262486457825, 61.56749211251736, 63.05744156241417, 64.13618087768555, 68.84602054953575, 65.5371581017971, 67.02873006463051, 69.20925065875053, 64.33889240026474, 62.804272547364235, 51.06938123703003, 46.34222209453583, 49.60721969604492, 46.08996503055096, 49.71446134150028, 45.51360435783863, 52.21882715821266, 57.744920030236244, 62.99676261842251, 62.79185101389885, 64.17309209704399, 65.83414256572723, 66.32108643651009, 65.168167501688, 63.69192771613598, 63.44578452408314, 63.21257583796978, 64.2963270843029, 63.822370916604996, 64.20708507299423, 63.08292679488659, 50.10921075940132, 46.99270538985729, 50.45827902853489, 57.945169284939766, 60.46248860657215, 61.841149628162384, 63.775276243686676, 60.56216485798359, 58.53154242038727, 61.23400680720806, 64.65667694807053, 66.50840878486633, 61.946289986371994, 74.70475137233734, 47.01269991695881, 0.593605216126889, 0.4815586394397542, 4.204025538638234, 8.768742922693491, 9.186446908861399, 2.0384550048038363, 0.2937854512128979, 17.42756724357605, 42.990874126553535, 49.9815908074379, 32.752836495637894, 69.85803544521332, 31.580886282026768, 0.3365468722768128, 0.17390477849403396, 0.1452151156263426, 0.1521700932062231, 0.16597962094238028, 0.10499273019377142, 0.22965792508330196, 0.1297914463793859, 0.12068927229847759, 0.1254968307330273, 0.2590271725784987, 0.15188460383797064, 0.14749261841643602, 0.1018403317721095, 0.12267577898455784, 0.1715032331412658, 0.11277720623183995, 0.14359788678120822, 0.11287541463389061, 0.20196205732645467, 0.12642053741728887, 0.14674103062134236], [0.02859317810361972, 0.011472656842670403, 0.029411549912765622, 0.01351407967376872, 0.028764102135028224, 0.058479882500250824, 0.016993675235426053, 0.009380902483826503, 0.059848425080417655, 0.05138951491971966, 0.03420784996706061, 0.04184206707577687, 0.06172945773869287, 0.019496161949064117, 0.06588692820514552, 0.034036833167192526, 0.03787433037359733, 0.046275078420876525, 0.045663626660825685, 0.031147296031122096, 0.011303470364509849, 0.10489161257282831, 0.05016117145714816, 0.04145117047301028, 0.09239662875188515, 0.07548405541456304, 0.06211814274138305, 0.9802830358967185, 9.611317310482264, 49.88641731441021, 52.59723745286465, 49.78663086891174, 61.26449637115002, 25.396020859479904, 39.20560844242573, 1.0199735686182976, 3.493815385736525, 0.5199421907309443, 2.2299944143742323, 1.0392747516743839, 0.7347602199297398, 0.3834286972414702, 21.517823562026024, 86.50984391570091, 67.77640834450722, 76.17489248514175, 67.51951932907104, 76.77646860480309, 73.21345299482346, 74.12212863564491, 70.23380488157272, 69.84165832400322, 67.60733261704445, 63.433416187763214, 65.41003212332726, 64.13608968257904, 59.61682878434658, 56.9935217499733, 49.95991677045822, 53.53891812264919, 52.09523878991604, 54.7269319742918, 56.12592190504074, 62.56623052060604, 65.8079619705677, 65.72233736515045, 66.16008907556534, 65.60382172465324, 59.55519989132881, 50.81343077123165, 44.64030861854553, 45.415353029966354, 45.88769048452377, 46.00407063961029, 45.86157068610191, 47.870788872241974, 44.30487781763077, 49.98539440333843, 51.50113306939602, 55.55368401110172, 58.51571626961231, 58.18527080118656, 59.02657225728035, 61.62409767508507, 61.08110301196575, 59.33205686509609, 62.31127180159092, 60.68811669945717, 64.03908088803291, 68.79361376166344, 58.568670228123665, 63.99615079164505, 64.02369171380997, 62.80730098485947, 54.52484741806984, 58.24230574071407, 64.04486417770386, 60.98688326776028, 61.5637531131506, 61.920496970415115, 62.17232085764408, 61.35476052761078, 61.34016551077366, 61.26210629940033, 57.26659409701824, 47.53717817366123, 43.661169558763504, 44.95889872312546, 42.77930147945881, 44.36925396323204, 42.352458983659744, 48.45883771777153, 54.81280356645584, 60.00995188951492, 61.22644901275635, 61.10002599656582, 58.81841942667961, 58.09808447957039, 61.45796678960323, 59.34683807194233, 61.81528061628342, 57.66129791736603, 58.735458478331566, 60.76013423502445, 60.76440140604973, 60.81424333155155, 54.852731823921204, 46.10500082373619, 44.93811383843422, 50.29797703027725, 53.864781036973, 62.308095172047615, 58.59203517436981, 61.542356461286545, 59.85966615378857, 60.36327213048935, 57.89794921875, 66.79815083742142, 57.26764664053917, 70.89216515421867, 16.174968257546425, 0.2694303315365687, 0.9547818917781115, 3.881066143512726, 3.9669417729601264, 0.7617702393326908, 0.2552391914650798, 0.25890730088576674, 20.618563815951347, 40.26069022715092, 28.328916281461716, 37.951561734080315, 46.2049962580204, 1.6836795606650412, 0.12889482808532193, 0.05743296816945076, 0.025282679962401744, 0.04192726562905591, 0.06734018694260158, 0.020953775238012895, 0.021721575249102898, 0.035068559445790015, 0.05577424955845345, 0.05889147760171909, 0.04095425065315794, 0.04892745484539773, 0.05135426661581732, 0.02202038245741278, 0.07841825499781407, 0.03695167753903661, 0.04443734636879526, 0.05383699179219548, 0.00339166845606087, 0.0259038445801707, 0.048812711393111385, 0.03953854458814021, 0.02484247506799875, 0.05918057380768005, 0.019750085921259597, 0.004763507331517758, 0.018983133813890163, 0.06759161915397272, 0.07588729393319227, 0.022392443352146074, 0.13776074687484652, 0.03184312998200767, 0.13748186262091622, 0.09817313519306481, 0.04817834582354408, 0.04892398530500941, 0.05818163561343681, 0.018011885149462614, 0.037020515446783975, 0.04759039788041264, 0.05281047539028805, 0.022173897559696343, 0.030615324576501735, 0.09064130848855712, 0.025703143728605937, 0.07601816425449215, 0.03689828372444026, 0.03323736571474001, 0.1743789663305506, 0.9963011951185763, 16.6268153116107, 62.004704251885414, 55.875496342778206, 77.04810082912445, 57.4526397138834, 34.99769523739815, 45.440564677119255, 1.237497883848846, 1.7822094610892236, 1.0598520725034177, 5.732314456254244, 2.322877342812717, 1.5229884395375848, 0.31415900797583163, 26.806839555501938, 88.40703651309013, 69.86970841884613, 78.4651055932045, 69.05216708779335, 77.50115051865578, 75.54929405450821, 75.00370413064957, 74.43507224321365, 73.45014989376068, 68.74687626957893, 68.27073141932487, 67.77953177690506, 66.73070445656776, 60.21835930645466, 61.24644733965397, 53.8259357213974, 54.69461850821972, 52.20476411283016, 57.17464283108711, 59.074461087584496, 62.68159233033657, 66.54522120952606, 68.27029824256897, 67.08082526922226, 67.8644648194313, 62.22565479576588, 52.41997316479683, 47.07950033247471, 47.7497273683548, 48.35843950510025, 48.30860897898674, 48.62127140164375, 49.740968719124794, 49.71964046359062, 54.18629318475723, 55.26259683072567, 58.03343094885349, 59.49020817875862, 60.31113512814045, 59.895714819431305, 62.505676969885826, 63.405487686395645, 64.22812834382057, 62.57280796766281, 64.20703187584877, 65.21750405430794, 70.14332413673401, 64.92295145988464, 68.13738897442818, 66.99969962239265, 64.08514961600304, 56.10814265906811, 60.80319732427597, 63.776560574769974, 63.34375619888306, 64.96111661195755, 65.27503296732903, 64.60376858711243, 64.85303521156311, 63.466592207551, 62.8893081843853, 58.973496705293655, 49.48349453508854, 45.84471859037876, 46.41592673957348, 44.34808149933815, 45.95836669206619, 45.72960376739502, 50.745433419942856, 60.02221763134003, 62.51548424363136, 62.976711094379425, 62.19261556863785, 61.31475247442722, 61.78446426987648, 61.41222104430199, 60.433207377791405, 63.29736448824406, 59.09938395023346, 62.81089939177036, 64.70710024237633, 62.863382175564766, 62.36291863024235, 56.98072403669357, 47.3863984644413, 45.58484673500061, 52.766544967889786, 55.26608884334564, 63.78940388560295, 62.835373878479004, 61.695423647761345, 59.09225933253765, 62.901600524783134, 59.21187311410904, 68.63024532794952, 61.15284316241741, 70.61957538127899, 18.85630387812853, 0.4683256120188162, 2.3941755294799805, 7.129624402150512, 4.39361066557467, 0.9904568712227046, 0.33739986713044345, 0.8913628198206425, 26.354977302253246, 48.0679564923048, 32.77446113526821, 35.81299088895321, 55.76039291918278, 2.8619629656895995, 0.19556057348381728, 0.06569004384800792, 0.040416156480205245, 0.09902682024403475, 0.018888740050897468, 0.02907421596319182, 0.03112719681666931, 0.023966549706528895, 0.03436522980337031, 0.07516870202380233, 0.03798744481173344, 0.03363839634403121, 0.030365771854121704, 0.01947226108313771, 0.012993104992347071, 0.036709099149447866, 0.04974925352144055, 0.09718708068248816, 0.044990999667788856, 0.048464733190485276, 0.06238062182092108, 0.013601213377114618, 0.12049759781803004, 0.1804224678198807, 0.08250371116446331, 0.09000311343697831, 0.09287777793360874, 0.14156941906549037, 0.1612454460700974, 0.12352846955764107, 0.31592395389452577, 0.14543531084200367, 0.1664942706702277, 0.1677810656838119, 0.15461174421943724, 0.11244240857195109, 0.10683247717679478, 0.12711685005342588, 0.10658621773472987, 0.12546254351036623, 0.11276540608378127, 0.09157571694231592, 0.13125736615620553, 0.18257154937600717, 0.13304137042723596, 0.1171499106567353, 0.22914277069503441, 0.17500075249699876, 0.2985548780998215, 1.095542369876057, 16.052533127367496, 79.75942254066467, 62.76250138878822, 70.31048476696014, 70.88345602154732, 40.778116062283516, 46.456656754016876, 1.465394098777324, 6.807962637394667, 3.8580840267241, 7.556514395400882, 2.3989986581727862, 1.8473295355215669, 0.35335984197445214, 25.925146266818047, 93.14700096845627, 71.88611581921577, 79.25337329506874, 69.55985024571419, 82.15100660920143, 79.7082544863224, 80.83452925086021, 76.15939691662788, 76.84809476137161, 71.59229278564453, 71.09004333615303, 68.23182910680771, 69.18353363871574, 66.80905625224113, 63.82767543196678, 54.34067890048027, 59.1160536557436, 57.718294858932495, 60.90451888740063, 60.89166037738323, 67.16176092624664, 70.5119651556015, 73.44299107789993, 72.13313296437263, 72.01822713017464, 64.65561300516129, 57.221175134181976, 50.602150708436966, 51.14046782255173, 51.82978503406048, 51.27273492515087, 52.6766037940979, 52.016541212797165, 50.2740953117609, 54.25198785960674, 56.31653107702732, 59.70758691430092, 63.82522076368332, 62.45328538119793, 63.275504261255264, 64.45980951189995, 68.54030415415764, 66.93747416138649, 68.37179839611053, 69.11577567458153, 67.64707088470459, 69.07146245241165, 60.23293912410736, 70.87652519345284, 68.68053182959557, 67.80736148357391, 58.26546169817448, 63.51108402013779, 67.63886332511902, 66.48004710674286, 67.55367189645767, 69.45122167468071, 67.11923360824585, 67.16930732131004, 65.69149821996689, 67.57687345147133, 60.5523119866848, 52.63830944895744, 48.2087617367506, 49.285973533988, 46.25213272869587, 51.005217880010605, 47.54652187228203, 54.10189211368561, 60.46610601246357, 65.7428714632988, 65.35640940070152, 66.01855427026749, 63.777624517679214, 64.70058739185333, 64.8919527232647, 63.01228478550911, 64.02316734194756, 61.176401898264885, 63.393784314394, 67.23731607198715, 64.24638256430626, 66.41198515892029, 59.63789865374565, 52.56345346570015, 49.81305465102196, 54.709312319755554, 57.157650142908096, 69.1141265630722, 62.071592062711716, 66.41458421945572, 62.427017390728, 65.96827536821365, 60.861273407936096, 75.50986737012863, 60.76450780034065, 74.44301381707191, 19.09769732505083, 0.563185770297423, 2.346162018366158, 11.174410935491323, 13.94411651417613, 2.8701821621507406, 0.9110363235231489, 0.7967167859897017, 32.735961601138115, 52.082562670111656, 40.35369023680687, 48.3788900077343, 66.53319865465164, 4.246432688087225, 0.4232733295066282, 0.18472946248948574, 0.1563893214915879, 0.21641317172907293, 0.19608642964158207, 0.1533628284232691, 0.07557593329693191, 0.12038951143040322, 0.1310066835139878, 0.2246959405601956, 0.17313800635747612, 0.13423438766039908, 0.149897919036448, 0.08487177823553793, 0.19993983849417418, 0.1625233204686083, 0.12428261776221916, 0.22058665403164923, 0.1319166604662314, 0.14598225883673877, 0.24799562233965844, 0.11973152330028825], [0.010756161500466987, 0.0061111686591175385, 0.04118593060411513, 0.02836623119947035, 0.06680313919787295, 0.071465615183115, 0.03778756959945895, 0.029316647778614424, 0.11082650074968114, 0.06940992549061775, 0.027432848764874507, 0.05655373097397387, 0.03856718831229955, 0.053455216184374876, 0.045846250650356524, 0.06368889458826743, 0.028549242961162236, 0.07006458879914135, 0.04168936276983004, 0.06893902536830865, 0.03189394483342767, 0.052597827816498466, 0.09818644190090708, 0.10270010243402794, 0.04423159334692173, 0.043797889666166157, 0.027734602299460676, 0.0489429768640548, 0.6427938735578209, 24.567952193319798, 58.757102116942406, 37.555721774697304, 49.85429763793945, 41.873080506920815, 28.50731860846281, 7.456416841596365, 1.741828196682036, 2.0214917650446296, 2.0968877943232656, 2.1794207906350493, 0.5073683685623109, 0.4868932266253978, 0.31392294564284384, 28.80523592233658, 78.76792654395103, 72.38565221428871, 81.34660497307777, 74.92710024118423, 77.6779094338417, 71.22242823243141, 70.42614296078682, 66.70534461736679, 65.35051971673965, 65.41823968291283, 64.78625759482384, 62.29724295437336, 61.9956873357296, 59.56691466271877, 52.48988941311836, 50.73985151946545, 54.11088243126869, 57.26667769253254, 62.58716739714146, 62.93858394026756, 67.86044463515282, 66.83356493711472, 67.35222190618515, 65.77656045556068, 61.20246849954128, 54.58935655653477, 46.49810492992401, 44.91775073111057, 46.22551515698433, 46.76912538707256, 46.806659772992134, 47.281288504600525, 46.19920536875725, 46.60103760659695, 49.761506617069244, 52.336662635207176, 56.93394094705582, 55.495357140898705, 57.94288940727711, 57.85514071583748, 62.56137058138847, 62.16660596430302, 62.37287409603596, 60.00983789563179, 63.682371228933334, 60.58475844562054, 62.33485333621502, 60.03166772425175, 63.54902498424053, 58.37546579539776, 61.57362498342991, 62.11905151605606, 63.41008543968201, 63.58579941093922, 60.708445608615875, 62.25280433893204, 65.19323095679283, 63.14007192850113, 59.78686586022377, 59.12621051073074, 53.02100971341133, 44.20584753155708, 45.39582207798958, 43.53137232363224, 43.11056770384312, 44.86583411693573, 44.67614069581032, 46.14553704857826, 58.00032712519169, 60.21827191114426, 60.31582027673721, 58.278194814920425, 60.572203919291496, 61.919835805892944, 60.82948811352253, 60.15077993273735, 62.139258831739426, 61.339751332998276, 61.739706471562386, 59.7659669816494, 59.99482110142708, 62.727946043014526, 58.39834436774254, 54.3026315420866, 44.99413043260574, 48.859989792108536, 56.58665478229523, 56.08527168631554, 64.59434509277344, 60.888137966394424, 58.85179303586483, 60.21463170647621, 64.77481260895729, 58.6809466034174, 63.97678703069687, 66.23499065637589, 3.116717445664108, 0.25275914173107594, 2.064525643363595, 6.097213150933385, 3.0371295288205147, 0.6830454699229449, 0.16199191304622218, 4.854614278301597, 41.739384680986404, 33.35311308503151, 24.77161556482315, 54.807936027646065, 21.534297578036785, 0.35502436046954244, 0.059970582587993704, 0.03013768575328868, 0.06009138196532149, 0.08016178253456019, 0.054403354370151646, 0.04784315111464821, 0.04053233969898429, 0.07111915096174926, 0.01224970494149602, 0.027679887461999897, 0.06468260064139031, 0.04642137428163551, 0.0327814495540224, 0.08382213651202619, 0.03745757363503799, 0.09843753272434697, 0.03030833147931844, 0.0351954666984966, 0.12190312903840095, 0.013541030766646145, 0.009085339388548164, 0.003414637694731937, 0.066395855974406, 0.04427433363161981, 0.029035960105829872, 0.007106825632945402, 0.08066839480306953, 0.019208357080060523, 0.04065384782734327, 0.07335538291954435, 0.019568285715649836, 0.021912542833888438, 0.014205264997144695, 0.05131556732521858, 0.04655389588151593, 0.0324244171497412, 0.0211596228837152, 0.040926149231381714, 0.03339694972964935, 0.012339693130343221, 0.01793963892851025, 0.016600782255409285, 0.058031068692798726, 0.03283875819761306, 0.03806278022238985, 0.09964222394046374, 0.004299152951716678, 0.0374720232503023, 0.11189858501893468, 0.06613249002839439, 1.4367707096971571, 37.33082704246044, 63.98233473300934, 39.85741026699543, 67.07285329699516, 39.875208511948586, 39.94149595499039, 7.883341507986188, 1.4462022786028683, 1.0468153282999992, 2.2588023310527205, 4.573851143941283, 1.1898316978476942, 1.4552488806657493, 0.2949307335074991, 36.45236358046532, 82.97399684786797, 71.28111228346825, 80.49466028809547, 75.41125506162643, 79.44166839122772, 73.05209085345268, 72.19884663820267, 69.93069514632225, 67.42627993226051, 67.39684671163559, 68.59961897134781, 64.80280190706253, 65.08608430624008, 62.540319710969925, 54.96937416493893, 51.666511595249176, 55.9340626001358, 60.27013532817364, 62.85415627062321, 65.73796212673187, 69.47310090065002, 69.00203257799149, 68.36980730295181, 69.80629742145538, 62.60414108633995, 55.60077488422394, 47.770580649375916, 48.576468005776405, 49.527800157666206, 48.04207228124142, 48.42168711125851, 50.337700098752975, 46.45052008330822, 50.515051782131195, 52.45917186141014, 55.549922212958336, 59.79876682162285, 59.638544619083405, 60.530862137675285, 64.16621446609497, 66.81030258536339, 63.65633882582188, 64.1381947696209, 63.10791425406933, 64.2019173502922, 62.14128412306309, 63.74523125588894, 61.87614195048809, 64.56985160708427, 60.15344358980656, 59.68427136540413, 64.18672576546669, 66.98778346180916, 65.07843151688576, 63.786432445049286, 63.267418295145035, 64.97446149587631, 64.55622553825378, 62.859472185373306, 62.82718911767006, 57.119120210409164, 47.622795179486275, 46.84370778501034, 46.5498885512352, 45.99376179277897, 48.22027891874313, 46.28581032156944, 49.637929648160934, 59.435878694057465, 61.554249823093414, 62.70087629556656, 61.57935127615929, 62.23882108926773, 64.19340580701828, 63.31212289631367, 62.32389472424984, 62.59265810251236, 61.83065079152584, 63.30868408083916, 62.220061495900154, 62.13252939283848, 63.842874616384506, 60.36628156900406, 55.15286631882191, 46.80489666759968, 50.908627063035965, 58.27005185186863, 59.51495245099068, 64.03886809945107, 63.55896145105362, 59.503819048404694, 63.293606489896774, 66.06998071074486, 61.77923955023289, 63.36687035858631, 68.81963476538658, 2.8843143163248897, 0.11594798765145242, 4.210903644561768, 4.510864298790693, 0.48513160552829504, 0.25608740688767284, 0.2508019201923162, 7.699728235602379, 45.19896224141121, 45.12312211096287, 24.092875085771084, 58.23963828384876, 27.029159925878048, 0.29919505468569696, 0.14824938640231267, 0.024141130670614075, 0.060578650154639035, 0.04546559568552766, 0.03186068177456036, 0.010458422057126882, 0.03935939384973608, 0.06652772819506936, 0.046310905599966645, 0.026408694247948006, 0.10071449374663644, 0.002692607786229928, 0.042720257843029685, 0.05870697226782795, 0.020013878602185287, 0.1022800468490459, 0.00929130206714035, 0.026231380325043574, 0.08419519930612296, 0.013864365027984604, 0.012874987551185768, 0.040356183526455425, 0.17464300763094798, 0.05869386593985837, 0.11711451021255925, 0.10820497540407814, 0.15963615820510313, 0.1541641549556516, 0.1028068306914065, 0.141209150897339, 0.15011314186267555, 0.14333552273456007, 0.10820982904988341, 0.17204780626343563, 0.15836975740967318, 0.18063473689835519, 0.09091307554626837, 0.10613724807626568, 0.15848327631829306, 0.12194304916192777, 0.2496443479321897, 0.23282737063709646, 0.12205186285427772, 0.11047355757909827, 0.2891183813335374, 0.14027636032551527, 0.09733405560837127, 0.10695834542275406, 0.34733873850200325, 0.11994949207291938, 0.7043344213161618, 45.82284316420555, 79.49591428041458, 46.593593806028366, 65.66903382539749, 50.27656897902489, 43.352059945464134, 9.329798016697168, 2.8871342400088906, 6.7891716957092285, 6.820692429319024, 7.9678109753876925, 1.351290496531874, 1.4578978135250509, 0.814796156482771, 37.02374652028084, 85.95591723918915, 73.08870568871498, 84.18871566653252, 79.06898438930511, 83.25107797980309, 75.9189610183239, 76.47033423185349, 72.57673636078835, 69.67819109559059, 70.6925618648529, 71.55922695994377, 68.4398527443409, 68.81841123104095, 65.98731234669685, 56.11205264925957, 54.79699641466141, 60.138495191931725, 63.15068855881691, 66.74647361040115, 67.45958894491196, 72.73708775639534, 71.48142993450165, 71.79119691252708, 71.18424788117409, 65.9830641746521, 60.27295857667923, 52.358845844864845, 50.32813601195812, 50.347560569643974, 51.53632678091526, 50.9705675393343, 53.339949399232864, 48.510533943772316, 53.57562035322189, 55.55892013013363, 59.198114052414894, 62.00029268860817, 61.18334412574768, 63.21982964873314, 64.24045488238335, 69.01869848370552, 65.85514783859253, 66.23297676444054, 64.06589984893799, 67.87094727158546, 64.06421273946762, 65.16760513186455, 63.42323653399944, 65.80442816019058, 63.18434335291386, 63.11501607298851, 67.28017777204514, 68.52948993444443, 67.73904114961624, 64.9944332242012, 65.37081822752953, 66.8813207745552, 65.95303818583488, 65.29920727014542, 64.64609071612358, 60.20109683275223, 48.01174230873585, 49.413551688194275, 48.17052058875561, 50.152775421738625, 49.57231476902962, 49.2690834403038, 51.19033634662628, 64.08726990222931, 65.55415838956833, 64.7773964703083, 65.86557447910309, 65.64431235194206, 66.52730137109756, 64.86612170934677, 66.2355986237526, 65.69928780198097, 64.52232375741005, 65.97235634922981, 63.24436113238335, 65.8364300429821, 67.48985812067986, 64.3573822081089, 58.033423349261284, 49.31608311831951, 53.96652817726135, 59.36470851302147, 60.142842158675194, 67.4887789785862, 65.29917687177658, 62.754715606570244, 65.4702740907669, 69.10475626587868, 62.191403433680534, 66.3786381483078, 71.8521836400032, 4.162396397441626, 0.71100466651842, 9.276859257370234, 16.22691337019205, 8.319030404090881, 3.2712496910244226, 0.3723590896697715, 9.049037732183933, 57.65275217592716, 47.433481737971306, 35.14455735683441, 68.38118389248848, 35.938855335116386, 0.4567954275989905, 0.23146116582211107, 0.13217779254773632, 0.1419217759394087, 0.11301410719170235, 0.17344399384455755, 0.17004648630972952, 0.128554820548743, 0.12192890382721089, 0.25664369110018015, 0.12445584245142527, 0.17628664209041744, 0.07767806659103371, 0.10612700643832795, 0.14358955988427624, 0.07063118886435404, 0.2042724669445306, 0.12654078018385917, 0.14918950939318165, 0.34915658470708877, 0.07545420623500831, 0.13359051517909393, 0.0871076391194947], [0.07041391771053895, 0.022008454288879875, 0.0240391187617206, 0.058684199466370046, 0.030563659965991974, 0.07092018859111704, 0.05326948259607889, 0.07561035410617478, 0.05354510140023194, 0.06482366065029055, 0.04412886897625867, 0.09049104584846646, 0.09242986212484539, 0.0595760160649661, 0.024661173956701532, 0.04825274241738953, 0.0694785889936611, 0.06556169682880864, 0.060041928954888135, 0.04504784075834323, 0.0037812853179275407, 0.008152628597599687, 0.04018410916614812, 0.061712317838100716, 0.04558784967230167, 0.06415210606064647, 0.16456468671094626, 0.03749909308680799, 0.8258532069157809, 4.459227919578552, 43.568781316280365, 63.366117998957634, 37.61093661189079, 62.2720693051815, 36.68092131614685, 7.881356589496136, 0.2292684162966907, 0.9197839291300625, 2.095682783983648, 3.150426624342799, 0.5449320247862488, 1.2187162041664124, 0.1859708974370733, 0.10240599673124962, 33.8335707038641, 86.01004153490067, 73.61650496721268, 77.11436927318573, 71.62080645561218, 71.58859178423882, 70.36083206534386, 71.73395678400993, 70.18766775727272, 62.891842648386955, 64.52154859900475, 61.47651359438896, 62.86322258412838, 61.47866427898407, 54.83135797083378, 54.48672406375408, 54.779346361756325, 57.5840100646019, 65.12887760996819, 65.92695638537407, 68.73760476708412, 66.86197981238365, 68.92925888299942, 62.58354239165783, 62.29663498699665, 53.875093683600426, 46.64995238184929, 45.878852158784866, 48.09525802731514, 47.469591200351715, 46.54437504708767, 48.16076271235943, 47.00663924217224, 46.698243990540504, 47.918871492147446, 48.050139248371124, 48.25603500008583, 49.93883930146694, 53.27877268195152, 52.032036781311035, 54.21634577214718, 50.865837559103966, 55.10839730501175, 61.57216966152191, 64.94664698839188, 63.01063947379589, 58.381697461009026, 66.0372644662857, 65.69098144769669, 64.49826344847679, 64.25933226943016, 63.015556409955025, 63.67577098309994, 61.366642490029335, 62.41488464176655, 63.663326650857925, 60.64892940223217, 59.438116773962975, 58.95375296473503, 55.0346926599741, 52.37875297665596, 47.43042670190334, 46.11991882324219, 43.400647938251495, 42.998960092663765, 43.96582581102848, 43.76436822116375, 47.465122640132904, 58.132518231868744, 60.863211303949356, 63.36519844830036, 55.99625766277313, 58.86603087186813, 59.55455392599106, 63.686642199754715, 58.46079021692276, 62.56724126636982, 60.215851441025734, 63.52495327591896, 59.20233942568302, 63.54229174554348, 62.45761714875698, 63.69687885046005, 60.01365669071674, 54.2576989531517, 45.66342651844025, 51.74606792628765, 56.546384543180466, 61.71812362968922, 55.89612923562527, 63.94556790590286, 58.09350572526455, 65.03040969371796, 58.15988816320896, 70.02968743443489, 20.939317904412746, 0.03389697172679007, 0.4533162689767778, 1.878516599535942, 3.7738936068490148, 1.7014831490814686, 0.6268927955534309, 0.045711792045040056, 19.12282157689333, 55.81644371151924, 22.343068979680538, 36.50824338197708, 52.72960714995861, 1.582613771315664, 0.08221948344726115, 0.08954317483585328, 0.040705401115701534, 0.08118391284369864, 0.06270396072068252, 0.04318243401939981, 0.025197102913807612, 0.05210785449889954, 0.030124763106869068, 0.09003926345030777, 0.04424454011314083, 0.009933878573065158, 0.011862802948598983, 0.044098344442318194, 0.034544818408903666, 0.025664368367870338, 0.0931657015462406, 0.004422325810082839, 0.08265960670541972, 0.02426066654152237, 0.016179954836843535, 0.023882447676442098, 0.07847634289646521, 0.044935501864529215, 0.03323864220874384, 0.030985717494331766, 0.05691291931725573, 0.022951603386900388, 0.04445894286618568, 0.050932993908645585, 0.023217262569232844, 0.017766098826541565, 0.05656930123222992, 0.058087779907509685, 0.058098659792449325, 0.026449193246662617, 0.027441704442026094, 0.05062519558123313, 0.03457229642663151, 0.028505189075076487, 0.054740452687838115, 0.06553483850439079, 0.05720964109059423, 0.01742070886393776, 0.052142802232992835, 0.0325291898479918, 0.07985969874425791, 0.10569227859377861, 0.11971377112786286, 0.20747477479744703, 0.090487913985271, 1.069714562036097, 8.006762210279703, 64.1791033744812, 56.63762144744396, 46.18224307894707, 75.20948588848114, 40.54260849952698, 12.77822507545352, 0.2897231129463762, 1.4981273235753179, 1.5955190663225949, 5.606621475890279, 0.9338280942756683, 4.775754259899259, 1.1103815236128867, 0.03899176728737075, 42.81740203499794, 85.44930562376976, 75.77173411846161, 80.0213272869587, 73.42125624418259, 75.20069316029549, 72.46613949537277, 75.98231881856918, 71.88059091567993, 65.37192776799202, 68.65241333842278, 63.77406790852547, 67.01975494623184, 63.86944279074669, 59.09290909767151, 55.652881488204, 56.01212181150913, 60.88564150035381, 68.18959057331085, 69.15015622973442, 69.73844066262245, 69.83269840478897, 72.26669579744339, 67.33137622475624, 65.00133365392685, 55.90203791856766, 49.55216825008392, 50.638921335339546, 49.746809005737305, 49.58019554615021, 50.24625800549984, 50.008823946118355, 49.12667468190193, 49.8812647908926, 50.38091138005257, 49.5436605066061, 52.81890235841274, 53.25733043253422, 57.816128209233284, 54.444382935762405, 57.33355790376663, 54.49006408452988, 59.04943563044071, 62.421416491270065, 65.74849516153336, 63.94666984677315, 60.31745418906212, 67.5647521018982, 67.22813576459885, 66.6217491030693, 65.07378816604614, 65.48738077282906, 65.5228328704834, 63.244334533810616, 65.62190875411034, 66.37034699320793, 63.53555470705032, 61.31522744894028, 60.67554697394371, 57.62906804680824, 54.325745701789856, 49.53373163938522, 49.1002357006073, 45.84338106215, 43.37014697492123, 45.495369136333466, 45.70092290639877, 49.75002363324165, 60.715821012854576, 62.818704172968864, 63.27312558889389, 58.63024592399597, 61.76170349121094, 59.917024075984955, 62.8224241733551, 61.94420009851456, 62.84410960972309, 62.1549291908741, 65.36580249667168, 61.874405443668365, 65.14796778559685, 63.70115742087364, 64.72156226634979, 63.07655453681946, 55.443322733044624, 47.60011799633503, 52.75054022669792, 59.48234260082245, 63.415933325886726, 59.5919781178236, 65.35858288407326, 62.28566877543926, 65.94209477305412, 60.76654449105263, 72.28700950741768, 22.83645160496235, 0.08231064144638367, 0.8199625136330724, 4.503706432878971, 1.6751914098858833, 0.6490428757388145, 0.7030873757321388, 0.08926860988140106, 22.85973485559225, 63.99349853396416, 28.490109331905842, 34.29487355053425, 61.24923638999462, 2.8484311792999506, 0.1306633066269569, 0.05356152883905452, 0.03498359095829073, 0.03592156914237421, 0.06441804725909606, 0.04000030145107303, 0.0699657569930423, 0.14123126689810306, 0.02825142837536987, 0.047883690931485035, 0.06925424517248757, 0.03157282124448102, 0.011095047466369579, 0.039299105483223684, 0.02679086319403723, 0.06089671980589628, 0.14938591135432944, 0.014200043988239486, 0.02506192628061399, 0.017243895890715066, 0.05771255375293549, 0.03117583903076593, 0.05681043985532597, 0.21510708087589592, 0.1038718422933016, 0.1089166356541682, 0.14565657475031912, 0.07676741428440437, 0.17533961712615564, 0.2121674784575589, 0.1517217469518073, 0.09899041047901846, 0.2310802659485489, 0.10680478022550233, 0.1903511123964563, 0.17398347583366558, 0.11344296464812942, 0.12417344041750766, 0.07422602604492567, 0.1904081687098369, 0.11093113615061156, 0.2237762266304344, 0.14696789032313973, 0.0987423476180993, 0.09858026256551966, 0.1290769362822175, 0.14213867601938546, 0.248626388492994, 0.1954777943319641, 0.29291835555341095, 0.14796590083278716, 0.8298179972916842, 7.538861017674208, 78.3545771241188, 74.04747784137726, 52.57839426398277, 74.24713432788849, 51.4023307710886, 14.151333644986153, 0.39815783500671387, 2.5370545126497746, 5.319378739222884, 10.338355097919703, 4.429195756092668, 1.9667230476625264, 0.7676370651461184, 0.10726549808168784, 40.90913683176041, 87.55766808986664, 77.58796066045761, 82.87008002400398, 77.25043997168541, 77.80671492218971, 74.79648604989052, 78.22891026735306, 75.91399848461151, 68.70552688837051, 70.53112372756004, 66.46220326423645, 71.21347591280937, 66.12718284130096, 61.92963548004627, 59.57426346838474, 59.488255083560944, 62.65038460493088, 70.21210044622421, 71.73021778464317, 75.13121008872986, 72.21678167581558, 75.15338569879532, 70.15890330076218, 67.11805567145348, 59.483075961470604, 51.686319932341576, 53.519402369856834, 53.772559985518456, 52.90383540093899, 51.44024133682251, 52.80030995607376, 52.188937962055206, 51.67953349649906, 54.22046855092049, 52.43449978530407, 53.845481872558594, 54.20008264482021, 58.35302419960499, 56.937653347849846, 61.87638893723488, 57.174183055758476, 62.658820152282715, 68.02660211920738, 69.15934413671494, 67.32472658157349, 60.25118574500084, 71.1426629126072, 70.75731799006462, 70.1857602596283, 68.06774631142616, 68.10102492570877, 68.07449474930763, 64.1237935423851, 67.20669731497765, 68.01799178123474, 66.16068184375763, 65.82426309585571, 63.86554419994354, 60.73154836893082, 59.12724785506725, 53.2584323734045, 52.08278305828571, 49.98368449509144, 46.72624468803406, 49.42543365061283, 49.00791585445404, 52.25766107439995, 63.47574591636658, 67.00517132878304, 67.42175057530403, 59.576117768883705, 63.038598373532295, 63.16470220685005, 65.77608168125153, 64.14983734488487, 65.2447409927845, 65.21143957972527, 68.89547109603882, 63.41782182455063, 67.06437215209007, 65.80926150083542, 69.60243836045265, 66.04970499873161, 59.24130253493786, 50.95104418694973, 55.350007340312004, 63.716200813651085, 65.34666672348976, 61.87217116355896, 69.97331365942955, 63.74035991728306, 69.78317946195602, 62.959741204977036, 75.65966293215752, 24.67941541224718, 0.3994276496814564, 0.7304248306900263, 10.635713841766119, 14.134094920009375, 2.6680363342165947, 2.4524527648463845, 0.20431773795280606, 31.73613455146551, 70.74012011289597, 36.4978813380003, 46.47842958569527, 72.89404973387718, 5.009382348507643, 0.22522610117448494, 0.21418514050310478, 0.1200345199322328, 0.21196148794842884, 0.19220008427510038, 0.2336899540387094, 0.11377754708519205, 0.2338602620875463, 0.1144376874435693, 0.21416312840301543, 0.1659836433827877, 0.17420940042939037, 0.0897443042777013, 0.10823909935425036, 0.13003267406020314, 0.15674377122195438, 0.36870220152195543, 0.0801016240438912, 0.14817232178756967, 0.12863822310464457, 0.06939251470612362, 0.1411529109464027, 0.18831836991012096], [0.06326572198304348, 0.03064656713831937, 0.02116447467415128, 0.01721241213090252, 0.055990760010899976, 0.0685439801600296, 0.008990524456748972, 0.040947701199911535, 0.047392103442689404, 0.04618656988895964, 0.052212115115253255, 0.0064885057599894935, 0.03156323640723713, 0.07541809332906269, 0.018971537756442558, 0.044497345297713764, 0.03615545698266942, 0.024126261741912458, 0.022363145217241254, 0.07097449153661728, 0.009922268600348616, 0.017634193209232762, 0.023698795812379103, 0.07716444102698006, 0.020916235553158913, 0.030512728226312902, 0.04738206960610114, 0.06617474049562588, 0.031042207920108922, 0.13532106997445226, 18.585650101304054, 66.65308222174644, 38.2466235011816, 33.923401683568954, 57.93098084628582, 15.68564286455512, 0.06418410004698671, 0.14747612789506093, 0.4807988880202174, 2.025611693970859, 1.6418231441639364, 2.371816341765225, 1.7107109539210796, 0.07492626464227214, 1.6080219391733408, 56.08779475092888, 84.44661542773247, 71.30780965089798, 75.11680126190186, 75.42392358183861, 79.40415680408478, 73.17778810858727, 72.32104808092117, 69.98966798186302, 64.9430675804615, 66.20410591363907, 64.97715935111046, 64.5501458644867, 59.27581608295441, 55.63457027077675, 59.59685705602169, 63.11492867767811, 67.03485533595085, 69.91680309176445, 70.49231261014938, 70.29918417334557, 68.72813567519188, 64.75028872489929, 61.44544646143913, 53.92374247312546, 48.35618622601032, 46.86169981956482, 48.76420833170414, 47.53443472087383, 47.91109710931778, 48.95566865801811, 48.18789325654507, 47.93626695871353, 49.62544731795788, 47.15994581580162, 47.82601587474346, 45.88218457996845, 48.75621736049652, 46.89466305077076, 49.840356186032295, 51.060117334127426, 55.286645740270615, 62.25527040660381, 65.39183869957924, 55.64326420426369, 52.93252386152744, 64.04946193099022, 61.98365718126297, 65.06776168942451, 64.15146365761757, 64.39153477549553, 62.8133350610733, 64.97274398803711, 62.40216672420502, 62.40366004407406, 58.44815209507942, 60.12223966419697, 57.46749311685562, 54.4680442661047, 51.098335683345795, 47.45784983038902, 44.26994249224663, 45.93215569853783, 45.97806103527546, 46.218367740511894, 44.056340754032135, 47.09717318415642, 57.40091308951378, 61.74866259098053, 60.95460779964924, 57.9211887717247, 58.71757663786411, 61.86499334871769, 62.253488302230835, 61.663524359464645, 61.72311656177044, 65.27992710471153, 61.312909573316574, 64.87413167953491, 60.9349362552166, 61.506710574030876, 61.60839691758156, 64.08858463168144, 58.691844418644905, 51.078132167458534, 46.45224139094353, 53.42822626233101, 54.556537717580795, 61.261460334062576, 56.52451291680336, 66.92425847053528, 60.45854061841965, 66.54726549983025, 30.760168321430683, 0.0788982686935924, 0.4643111571203917, 0.4787249118089676, 2.6870232028886676, 1.5582476975396276, 0.30012796400114894, 0.09601709229173139, 0.9168121917173266, 46.07456065714359, 37.93972156941891, 20.82623027265072, 59.529296681284904, 19.532728381454945, 0.0944621222151909, 0.14595574932172894, 0.01138486912168446, 0.04098613702808507, 0.032487618445884436, 0.09012852897285484, 0.05138157393957954, 0.04000546679890249, 0.0626040824863594, 0.03943474410334602, 0.01968584747373825, 0.045604195474879816, 0.0543078659393359, 0.055080296951928176, 0.013439801823551534, 0.0021177369490033016, 0.10275768567225896, 0.027294954015815165, 0.04975562485924456, 0.03239789279177785, 0.04949521637172438, 0.048224281053990126, 0.005276284528008546, 0.09149180230451748, 0.043613336092676036, 0.018218933219031896, 0.012419236518326215, 0.05462128232466057, 0.0633303407812491, 0.11195279890671372, 0.014388786057679681, 0.007089917653502198, 0.042799968214239925, 0.07657409965759143, 0.11179607216035947, 0.05237310550000984, 0.10103286025696434, 0.11921558223548345, 0.06928094022441655, 0.029351018492889125, 0.03161090826324653, 0.03423262285650708, 0.02738287439569831, 0.02423180812911596, 0.09338096147985198, 0.0363174010271905, 0.06372184594511054, 0.14044408570043743, 0.06451076376833953, 0.034664200284169056, 0.07012814632616937, 0.0978773002861999, 0.016433381570095662, 0.3307187568861991, 29.485479220747948, 75.87708726525307, 33.6703884601593, 58.29600065946579, 61.04002341628075, 18.92909087240696, 0.08941156236687675, 0.1132674838299863, 0.6400009046774358, 0.647421075263992, 1.8784410785883665, 6.976867374032736, 7.148404894396663, 0.024816134391585365, 2.4886016501113772, 63.42670954763889, 84.84549522399902, 73.20941761136055, 78.35355117917061, 78.39951351284981, 81.38025596737862, 75.02342507243156, 76.76107943058014, 73.09033200144768, 68.2215316593647, 67.61987954378128, 67.066880017519, 67.08096206188202, 61.019382923841476, 58.92884150147438, 62.29805991053581, 66.81075856089592, 68.65969374775887, 71.83813199400902, 73.35548177361488, 71.8965120613575, 72.57883384823799, 66.00002646446228, 63.53746220469475, 56.47956892848015, 51.067903116345406, 49.223216101527214, 49.76456165313721, 49.510366693139076, 49.837517738342285, 50.95686547458172, 51.68744467198849, 49.2062272131443, 50.37111930549145, 49.08038176596165, 49.855817556381226, 50.35411521792412, 50.84008254110813, 50.36580339074135, 51.32563568651676, 52.562754303216934, 55.979230776429176, 63.705739974975586, 67.11861804127693, 57.95230910181999, 53.60172115266323, 65.89848071336746, 64.42621931433678, 66.9792415201664, 65.69408968091011, 65.29383435845375, 63.265522196888924, 64.79052856564522, 64.28056553006172, 65.13808071613312, 60.528897643089294, 62.4845577031374, 59.39599223434925, 59.2695502191782, 53.640699461102486, 48.19978281855583, 46.948494762182236, 48.107208386063576, 47.76621088385582, 46.24245844781399, 46.89301393926144, 48.60310837626457, 57.642815709114075, 63.9672115445137, 62.72845521569252, 58.25935162603855, 60.40035434067249, 62.81545154750347, 64.61329087615013, 63.5950443148613, 63.934267312288284, 65.23019537329674, 65.1303443312645, 64.78064149618149, 63.13271552324295, 64.29811298847198, 64.20351326465607, 65.01699641346931, 63.54161158204079, 51.62602096796036, 50.57557873427868, 55.73995381593704, 58.26044596731663, 62.201883271336555, 60.252356082201004, 66.95966497063637, 63.144380897283554, 67.46211960911751, 36.593237221241, 0.06646213718340732, 0.8405828196555376, 2.3526948178187013, 3.595495317131281, 1.110767440404743, 0.37937042594421655, 0.1051125350932125, 1.4620109740644693, 50.764409601688385, 52.72938296198845, 19.946170896291733, 63.79762664437294, 27.159876711666584, 0.09250027709640563, 0.1314338340307586, 0.053305721667129546, 0.022814599215053022, 0.011588311281229835, 0.08434210001723841, 0.056242674618260935, 0.01852788929681992, 0.08052769844653085, 0.04528907957137562, 0.031944091751938686, 0.04738282659673132, 0.007145936351662385, 0.04831983627809677, 0.02470540966896806, 0.026855383657675702, 0.022817922181275208, 0.03750060706806835, 0.035921840026276186, 0.04727975341666024, 0.02110638677550014, 0.04898221050098073, 0.030193983220669907, 0.02150371037714649, 0.1732861835625954, 0.15914414398139343, 0.09667525853728876, 0.09288244604249485, 0.1431277659139596, 0.1996084547135979, 0.16771946742665023, 0.12155477976193652, 0.09546348723233677, 0.13080011412966996, 0.23988690198166296, 0.20018764160340652, 0.21773468441097066, 0.24799404898658395, 0.1505941871437244, 0.09904140344588086, 0.12740118167130277, 0.09543910025968216, 0.13143528864020482, 0.2314240881241858, 0.24040987860644236, 0.1143895294808317, 0.15819912281585857, 0.12574881955515593, 0.11872333052451722, 0.13171807659091428, 0.11091690917965025, 0.20026147045427933, 0.12121902473154478, 0.28640793927479535, 36.35389566421509, 93.94954070448875, 46.5116436034441, 50.701621770858765, 68.5984106361866, 28.587800189852715, 0.24941941781435162, 0.5403019732329994, 1.4384143589995801, 10.050019919872284, 7.581496629863977, 6.7109020706266165, 2.6616823626682162, 0.12965609348611906, 2.90534523781389, 62.8568959236145, 87.80302852392197, 77.12220445275307, 79.78389322757721, 82.32713475823402, 85.20278245210648, 77.06814855337143, 78.57226744294167, 77.05259218811989, 72.32309997081757, 72.88576617836952, 68.95459592342377, 69.30928409099579, 65.17741620540619, 62.34121419489384, 64.7824501991272, 70.51508098840714, 73.28767821192741, 75.80752059817314, 75.2114237844944, 75.22204801440239, 74.63977485895157, 70.88289365172386, 66.08809053897858, 61.40968278050423, 55.2450417727232, 52.655940502882004, 53.1047610193491, 52.62626029551029, 51.916484981775284, 52.67427071928978, 54.72758933901787, 52.40875996649265, 55.49159154295921, 53.9920400083065, 52.35428988933563, 54.46303993463516, 55.56256413459778, 54.020124301314354, 55.95218002796173, 55.29502809047699, 59.1926309466362, 67.50651642680168, 71.77024483680725, 58.80472116172314, 55.39350360631943, 65.09320512413979, 65.81851780414581, 70.34510850906372, 66.60398125648499, 66.94309026002884, 65.74456617236137, 67.06635564565659, 65.35780012607574, 67.52252116799355, 63.150718957185745, 63.32918778061867, 62.42694899439812, 60.38620010018349, 56.67659975588322, 51.70698702335358, 49.33608524501324, 51.011837124824524, 52.25345470011234, 50.64465142786503, 50.03706403076649, 52.084139585494995, 61.73394598066807, 66.13414406776428, 64.47987243533134, 60.4210290312767, 61.992073729634285, 64.68695372343063, 66.63530677556992, 66.38110041618347, 65.07466971874237, 69.39626142382622, 66.79964795708656, 66.28112778067589, 64.11978855729103, 65.25169461965561, 66.83399811387062, 67.16885134577751, 66.61160364747047, 55.378315821290016, 51.12831987440586, 58.475818410515785, 60.99495783448219, 64.11901339888573, 62.03222617506981, 71.10455095767975, 65.21769404411316, 71.22626602649689, 37.54010081291199, 0.31907635973766446, 0.8018092252314091, 2.802734118886292, 11.696216985583305, 5.027238065376878, 1.3107019057497382, 0.5232891580089927, 2.545217899605632, 61.98484651744366, 53.919152319431305, 30.54493837058544, 76.63888558745384, 35.191568434238434, 0.18303304648725316, 0.21403997641755268, 0.0877770192164462, 0.12998070887988433, 0.09293136099586263, 0.23778784117894247, 0.18786349275615066, 0.09108560261665843, 0.11775395207223482, 0.1079287331958767, 0.14847670623566955, 0.14695248333737254, 0.09633516194298863, 0.14082586130825803, 0.14093673817114905, 0.09810143630602397, 0.1821393522550352, 0.09374433182529174, 0.09070933374459855, 0.26482966903131455, 0.17206123913638294, 0.13955289992736652, 0.08118036537780426, 0.2007062840857543], [0.05261555030301679, 0.034730885963654146, 0.007687028337386437, 0.03818354620307218, 0.08835022439598106, 0.035684898248291574, 0.039030080661177635, 0.02839240860339487, 0.08592481157393195, 0.010010749301727628, 0.04020858519652393, 0.017539099972054828, 0.02547179403336486, 0.0849621718225535, 0.10079235988087021, 0.08925652771722525, 0.06182192562846467, 0.12992997566470876, 0.05309646199748386, 0.018061967130051926, 0.060872117610415444, 0.03349021171743516, 0.0778607462416403, 0.03783134146942757, 0.015470579473912949, 0.038335385906975716, 0.02537744108849438, 0.11426084107370116, 0.1976637012558058, 0.14710261981235817, 2.2277938574552536, 48.95909607410431, 60.566739812493324, 30.68302296102047, 51.61872535943985, 51.71734146773815, 1.8912050686776638, 0.37595351866912097, 0.6418705231044441, 2.0572810946032405, 0.19502824579831213, 27.721944451332092, 12.765094880014658, 0.2606873569311574, 0.15086793573573232, 16.433356292545795, 80.1999481022358, 72.9573467373848, 76.6717766225338, 73.22001904249191, 73.69422599673271, 75.24824380874634, 75.58834075927734, 69.92362752556801, 71.3604824244976, 66.4216822385788, 65.94587936997414, 65.92906907200813, 62.23441332578659, 59.201989844441414, 61.053056716918945, 63.9431132376194, 70.46452090144157, 70.3738197684288, 72.03293234109879, 68.37180599570274, 68.95606264472008, 66.12166553735733, 62.87259288132191, 54.98586907982826, 48.65973673760891, 48.05716887116432, 49.198802411556244, 49.15452718734741, 49.15826998651028, 49.32759270071983, 47.9913754016161, 49.482582584023476, 48.564753234386444, 48.904185220599174, 49.51925441622734, 53.88817638158798, 53.82839038968086, 52.122445330023766, 52.535467967391014, 53.63429680466652, 58.85691896080971, 60.46011373400688, 68.23432177305222, 52.868656888604164, 55.98493807017803, 64.20887097716331, 62.044567912817, 66.30755916237831, 65.6839594244957, 64.60123032331467, 65.10712757706642, 66.26591339707375, 59.177431762218475, 58.19356195628643, 62.530508637428284, 57.179894149303436, 57.07702226936817, 55.01365318894386, 53.042501360177994, 46.47251710295677, 45.306097492575645, 45.97460322082043, 46.73574797809124, 45.48083111643791, 44.88591983914375, 45.5483914911747, 56.8301685154438, 62.51869887113571, 65.84051862359047, 60.70300430059433, 60.362230986356735, 60.31415596604347, 65.48937946557999, 63.32789205014706, 62.96045936644077, 63.631746545434, 63.27942945063114, 61.10511772334576, 64.40474286675453, 62.91056424379349, 65.04428654909134, 65.24625331163406, 63.85769382119179, 56.89108684659004, 48.6450619250536, 51.17931313812733, 56.05961926281452, 58.338847160339355, 65.79978480935097, 59.942699298262596, 63.430999517440796, 46.265249624848366, 1.401964221149683, 0.11810777097707614, 0.556087038712576, 1.7265941016376019, 2.079578535631299, 0.1385530934203416, 0.17787721299100667, 0.2909483393887058, 17.537770830094814, 59.057662189006805, 16.485559791326523, 42.37274989485741, 43.69419738650322, 1.4363065408542752, 0.16791344998637214, 0.13339530065422878, 0.02399358058028156, 0.023944019958435092, 0.03755445359274745, 0.037283573401509784, 0.038975388088147156, 0.028037046031386126, 0.028102490468882024, 0.027844312135130167, 0.05246900211204775, 0.0386856721888762, 0.031266414443962276, 0.01617883604922099, 0.042884235372184776, 0.048660162938176654, 0.04154718582867645, 0.012274491746211424, 0.008243398824561154, 0.021518150715564843, 0.06214076711330563, 0.01648435598326614, 0.0839741803065408, 0.0545693987805862, 0.0217217960380367, 0.008451131525362143, 0.032734208143665455, 0.08036850034841336, 0.057540972920833156, 0.043370702042011544, 0.07523994077928364, 0.05392395665694494, 0.030880436424922664, 0.043619714851956815, 0.03470634313998744, 0.01168346852864488, 0.017101468474720605, 0.038289101867121644, 0.02454036715789698, 0.13125114695867524, 0.005887771540074027, 0.04539924026175868, 0.010095944144268287, 0.09539519480313174, 0.04104945335711818, 0.03995547944214195, 0.0773574884806294, 0.07279395562363788, 0.05739417239965405, 0.04196510402834974, 0.029382691500359215, 0.04067402311193291, 0.05543405648495536, 0.10735540927271359, 4.407773930579424, 69.82742428779602, 53.59429255127907, 28.842430226504803, 76.90367057919502, 50.19819438457489, 2.90224626660347, 0.33857011527288705, 0.15069056244101375, 0.7639145711436868, 2.4617323419079185, 11.582858618348837, 19.244162365794182, 0.6938865850679576, 0.2914133097510785, 19.804922975599766, 83.96542444825172, 75.09489923715591, 79.07562643289566, 74.37752053141594, 77.55563959479332, 77.57597610354424, 78.11607912182808, 73.008803576231, 73.48559439182281, 70.66663965582848, 69.80207964777946, 68.89938488602638, 67.2195254266262, 63.0867075920105, 62.75417983531952, 67.89118498563766, 71.7613685131073, 73.69351923465729, 73.17880645394325, 69.85808864235878, 70.1360285282135, 69.0174749493599, 65.32692298293114, 59.56464618444443, 51.18788167834282, 50.071980357170105, 52.02369622886181, 52.51821309328079, 50.30632518231869, 50.95795601606369, 51.25655919313431, 52.20435753464699, 52.37356245517731, 51.044165790081024, 50.79977050423622, 54.791076332330704, 55.46661168336868, 53.49430471658707, 55.26364557445049, 55.784795209765434, 61.77061781287193, 64.37875986099243, 68.85451689362526, 56.59061037003994, 55.04019856452942, 64.15102288126945, 63.4029646217823, 68.0243830382824, 66.19852781295776, 67.29894876480103, 66.47327587008476, 66.70435667037964, 62.77793996036053, 61.69956922531128, 65.15516459941864, 60.77355891466141, 59.780189618468285, 57.71679773926735, 53.85270148515701, 49.504526406526566, 49.0159448236227, 48.228684067726135, 48.19174624979496, 46.70556619763374, 48.19814510643482, 48.45924809575081, 59.60603356361389, 64.6637749671936, 65.92122629284859, 62.10625380277634, 59.192102774977684, 63.03269349038601, 64.05901461839676, 66.06560334563255, 65.7173140347004, 64.57884192466736, 65.58163091540337, 63.78701001405716, 66.17037132382393, 65.68753883242607, 65.12706890702248, 66.44224673509598, 65.80068156123161, 60.26167318224907, 50.220502987504005, 55.3973376005888, 57.6305727660656, 62.32529304921627, 66.82152718305588, 65.04025876522064, 63.66598270833492, 51.353165209293365, 1.1905541340820491, 0.3825152915669605, 2.076198379509151, 1.1981520638801157, 0.14043093484360725, 0.24124022311298177, 0.47631147725041956, 0.27952178847044706, 20.113417021930218, 75.43304309248924, 21.751140542328358, 36.59758798778057, 56.549523174762726, 2.339780735783279, 0.30543488392140716, 0.05688675861165393, 0.0059912751657975605, 0.08626829236163758, 0.0031932534193401807, 0.046320316032506526, 0.04561383968393784, 0.024572491020080633, 0.04430342582054436, 0.015530279688391602, 0.016943853006523568, 0.030090596483205445, 0.0511406097211875, 0.03728113915713038, 0.057036783764488064, 0.033339978763251565, 0.04216483823256567, 0.06566976837348193, 0.04715818962722551, 0.04242047099978663, 0.06915080462931655, 0.03999356646090746, 0.059540678703342564, 0.03180076448188629, 0.16592700267210603, 0.07708950637606904, 0.135779078991618, 0.13910047186072916, 0.23317785729886964, 0.09832709372858517, 0.14173417584970593, 0.1656907919095829, 0.1532696740468964, 0.10548851452767849, 0.1568244129884988, 0.08626547220046632, 0.1019727012317162, 0.16680143075063825, 0.16576626832829788, 0.22362370043992996, 0.1099987760244403, 0.1547789797768928, 0.22910290252184495, 0.23999708122573793, 0.1620309054851532, 0.11052771209506318, 0.1562165198265575, 0.11483763824799098, 0.14483711012871936, 0.16130477335536852, 0.21861004759557545, 0.2570016437675804, 0.30473735416308045, 0.24848361412296072, 4.588703121989965, 80.01937419176102, 76.22725367546082, 40.823136046528816, 71.89672484993935, 66.90022855997086, 5.295099467039108, 1.7071630130521953, 1.0459113330580294, 7.839578781276941, 4.397051380947232, 50.03657005727291, 25.207984149456024, 0.2855096437269822, 0.3092838398879394, 20.405093170702457, 82.68278807401657, 77.65437349677086, 82.79925182461739, 76.71172767877579, 78.30590173602104, 80.16886577010155, 81.54644384980202, 74.69080612063408, 77.95930713415146, 73.03369224071503, 74.13482755422592, 72.80980065464973, 71.3970972597599, 65.71582451462746, 67.06254824995995, 70.95328107476234, 76.48696973919868, 75.99026799201965, 76.25228673219681, 73.59156310558319, 76.01904764771461, 74.2511697113514, 68.64131033420563, 60.34569427371025, 55.318408235907555, 54.782750979065895, 55.276724472641945, 56.12071618437767, 53.92615154385567, 53.23160581290722, 52.88118861615658, 53.29966016113758, 54.26698945462704, 53.12969908118248, 55.074651315808296, 59.97418060898781, 58.975476399064064, 57.41175390779972, 58.10449093580246, 58.951963260769844, 65.60560002923012, 67.17556178569794, 70.76400563120842, 59.00144040584564, 57.21149705350399, 65.41127845644951, 63.593497797846794, 67.78941124677658, 69.2303167283535, 67.15885028243065, 69.49884831905365, 70.73296129703522, 65.34354329109192, 64.35961648821831, 68.43261033296585, 61.67370021343231, 61.64043299853802, 60.28593108057976, 57.84737013280392, 51.20886795222759, 52.24888354539871, 49.65641185641289, 51.45158752799034, 49.428678676486015, 51.319540813565254, 51.25343196094036, 62.227702885866165, 69.89667937159538, 70.60205832123756, 64.15632739663124, 61.98345959186554, 64.18421030044556, 68.31170082092285, 68.41286659240723, 66.79112121462822, 67.25127652287483, 65.60534924268723, 66.35950237512589, 68.33513036370277, 68.42589989304543, 69.5681793987751, 69.9789297580719, 70.01994475722313, 61.21590077877045, 54.35697242617607, 57.15050272643566, 59.86383453011513, 65.54187744855881, 69.75543335080147, 66.0448944568634, 67.18282699584961, 53.23778808116913, 1.5131314122118056, 0.40639237908180803, 2.065272778272629, 2.879391205497086, 8.919942509382963, 0.8863634755834937, 2.8520533349364996, 0.3067304956493899, 26.424435675144196, 73.00386384129524, 26.605619452893734, 52.80532568693161, 67.6296754181385, 3.7866347981616855, 0.3718398237833753, 0.34499432367738336, 0.11084975223639049, 0.14979204424889758, 0.14478915254585445, 0.09734935127198696, 0.310594710172154, 0.07540886843344197, 0.1542920566862449, 0.10056072074803524, 0.13639856450026855, 0.15506509254919365, 0.17548072908539325, 0.1204135495936498, 0.12904008122859523, 0.1356608103378676, 0.17942629783647135, 0.17901918530697003, 0.1433563622413203, 0.12451505841454491, 0.1377999916439876, 0.15070083376485854, 0.17263680434552953, 0.15187667770078406], [0.06101191967900377, 0.0283910300640855, 0.045257957608555444, 0.11417490779422224, 0.012496124872996006, 0.013625735791720217, 0.04942187362757977, 0.05154344005859457, 0.015837574283068534, 0.0892894048593007, 0.026678732101572677, 0.011866618515341543, 0.05979509063763544, 0.07025190687272698, 0.02358603018365102, 0.020867359562544152, 0.03569890628568828, 0.02528747423639288, 0.1250969764078036, 0.07720611261902377, 0.0305254987324588, 0.03245049992983695, 0.04217218920530286, 0.06776168971555308, 0.009512189335509902, 0.09086649093660526, 0.03742630324268248, 0.04004150177934207, 0.08499332718201913, 0.11209257500013337, 0.2631612616823986, 14.496776908636093, 72.07774713635445, 44.93721328675747, 25.303932800889015, 64.34106588363647, 19.89249497652054, 0.11682608193950728, 0.3497571009211242, 0.2957073465222493, 0.27726907341275364, 1.3478311384096742, 14.40739905461669, 1.7873134184628725, 0.15343673148890957, 0.9876932913903147, 46.31678245961666, 80.55122405290604, 71.93523198366165, 74.0323394536972, 74.87471625208855, 76.37884274125099, 77.41434037685394, 77.72751197218895, 71.18882283568382, 67.31580466032028, 71.59212559461594, 68.3104544878006, 62.137936502695084, 60.891671776771545, 65.95915585756302, 67.82104834914207, 71.68363228440285, 70.5547508597374, 67.67230913043022, 66.53572171926498, 67.94641882181168, 67.99209997057915, 63.02020736038685, 54.39885377883911, 47.79652185738087, 47.605627700686455, 50.41799359023571, 48.51100891828537, 48.34136322140694, 49.494434148073196, 49.80063311755657, 51.65920078754425, 50.59625722467899, 51.45818017423153, 55.65368704497814, 56.33567824959755, 56.52173526585102, 53.39737191796303, 58.940335884690285, 58.27557295560837, 63.54598514735699, 62.82856084406376, 68.52464899420738, 43.72937209904194, 51.693429350852966, 65.35463109612465, 62.250710651278496, 64.75984901189804, 66.76905199885368, 66.59046918153763, 64.92423579096794, 61.281181275844574, 57.21257999539375, 64.44058254361153, 60.03504954278469, 61.787899285554886, 58.18583317101002, 58.73003616929054, 49.513341933488846, 46.42020530998707, 48.073678985238075, 45.70447951555252, 48.08723285794258, 46.91401541233063, 45.77985227108002, 47.54783660173416, 54.32822696864605, 60.78096851706505, 63.29839043319225, 62.79607638716698, 60.24002954363823, 63.82086619734764, 62.459995821118355, 63.85481357574463, 64.96926337480545, 65.18170237541199, 62.38806188106537, 61.66444770991802, 64.12317037582397, 61.57392516732216, 63.43222305178642, 64.51596289873123, 63.04087445139885, 62.91139639914036, 58.59521560370922, 47.25779436528683, 58.15593257546425, 64.10486295819283, 62.42465391755104, 59.79274794459343, 67.05172643065453, 3.709847331047058, 0.024452133220620453, 0.4099253879394382, 0.2882200264139101, 2.661300483159721, 1.0530358320102096, 0.16176226286916062, 0.1987191688385792, 2.2370302118360996, 52.17747777700424, 32.05102935433388, 19.34541553258896, 59.170246347784996, 16.049717478454113, 0.09657915783463977, 0.223315219336655, 0.07468960116966628, 0.06124289458966814, 0.055891390147735365, 0.07780613159411587, 0.03967422402638476, 0.02860830121790059, 0.016112395278469194, 0.01878030670923181, 0.06643087792326696, 0.03192927848431282, 0.08801341551588848, 0.015610786940669641, 0.07279538054717705, 0.07174852187745273, 0.04924991801090073, 0.04289097778382711, 0.03397651140403468, 0.01600481726200087, 0.03098575831245398, 0.03889077212079428, 0.036124535399721935, 0.02580740434495965, 0.04599342224537395, 0.0482135755737545, 0.015443652500835015, 0.07072864769725129, 0.033997974314843304, 0.059614281199174, 0.04412734757352155, 0.012696015855908627, 0.02404233226116048, 0.01944678686413681, 0.10936998398392461, 0.10669094961485825, 0.039484853914473206, 0.05915333327720873, 0.019488423204165883, 0.0429497187724337, 0.047098083086893894, 0.04254763429344166, 0.010856981334654847, 0.04760827992868144, 0.05597829935140908, 0.06889361335197464, 0.06853520055301487, 0.029089988456689753, 0.05754619021899998, 0.013617082349810516, 0.030685691308462992, 0.02862347257178044, 0.015550260159216123, 0.065503720252309, 0.06579859778867103, 0.29157518700230867, 22.806923389434814, 86.4386585354805, 33.262256160378456, 36.75826996564865, 83.5033768415451, 18.25239848345518, 0.13223597692558542, 0.32945306855253875, 0.6449715129565448, 0.5637241539079696, 2.7169292606413364, 14.207575377076864, 3.985328748822212, 0.2302127398434095, 1.4556604460813105, 53.32663871347904, 82.08627328276634, 74.27266135811806, 77.26829901337624, 74.61900517344475, 78.33128437399864, 80.97022756934166, 78.65566536784172, 73.60745385289192, 70.44036939740181, 73.55253919959068, 71.78076267242432, 64.03410315513611, 64.47936326265335, 69.25606414675713, 72.60545521974564, 72.69468203186989, 73.51505801081657, 69.19882401823997, 68.81220996379852, 69.90880072116852, 69.61018234491348, 64.8624587059021, 56.22730426490307, 51.674836948513985, 50.396311953663826, 52.75988392531872, 49.23224061727524, 50.32291889190674, 51.91336914896965, 51.124060302972794, 52.189716920256615, 51.34380251169205, 52.93122433125973, 55.92497728765011, 57.65237219631672, 59.56651568412781, 58.4712890535593, 60.54741784930229, 57.81430050730705, 63.103460893034935, 63.75489413738251, 72.0374085009098, 46.9127044826746, 53.09167832136154, 63.173624128103256, 62.13468387722969, 65.27496457099915, 66.90310880541801, 66.6219998896122, 65.99071696400642, 61.88589222729206, 60.761714950203896, 65.30008882284164, 62.34459601342678, 64.91205364465714, 62.42971144616604, 60.197707414627075, 52.48978681862354, 48.90570893883705, 50.3252861648798, 48.488468527793884, 50.325187370181084, 47.921341359615326, 48.109678253531456, 49.02919851243496, 56.08004316687584, 63.97489473223686, 64.28904667496681, 65.54407373070717, 60.7760363817215, 64.04561653733253, 65.70578545331955, 65.03655016422272, 66.67083486914635, 68.00431251525879, 66.03703647851944, 62.91284032166004, 65.85759490728378, 63.28384481370449, 67.17404946684837, 67.27999538183212, 64.37901824712753, 62.52414397895336, 59.73498344421387, 51.03929065167904, 58.8339301943779, 64.90016788244247, 65.0740921497345, 59.608507230877876, 69.97538074851036, 4.389872141182423, 0.3172393364366144, 1.2274062191136181, 0.825781129533425, 0.6407971400767565, 0.23946847912156954, 0.5120666977018118, 0.07370044448180124, 2.691445453092456, 62.375313565135, 48.10927927494049, 16.01514123380184, 62.085525915026665, 25.519759319722652, 0.21478331153048202, 0.22186889225849882, 0.032492368191014975, 0.10951670657959767, 0.029310753270692658, 0.06687866014544852, 0.04559059190796688, 0.04388689914776478, 0.06545225973241031, 0.052539231546688825, 0.08902510380721651, 0.023875259976193774, 0.03244649233238306, 0.03950877333409153, 0.040272547194035724, 0.02025576679443475, 0.013966775841254275, 0.022198839287739247, 0.08446100691799074, 0.02307983722857898, 0.047531501040793955, 0.04162258432188537, 0.02130127661075676, 0.034731572450255044, 0.05209960181673523, 0.13616032025311142, 0.12084668182069436, 0.16336133878212422, 0.17547776049468666, 0.17540406523039564, 0.1533777901204303, 0.0937955771223642, 0.2715838956646621, 0.03874252441164572, 0.15063346159877256, 0.146070693153888, 0.15268913644831628, 0.15383765450678766, 0.12950212752912194, 0.11241344254813157, 0.16710271302144974, 0.17348697903798893, 0.15609771682647988, 0.2894603629829362, 0.1913327065994963, 0.08953275508247316, 0.16937607462750748, 0.12686631584074348, 0.13737987668719143, 0.092116913292557, 0.17790603800676763, 0.12800347903976217, 0.22995027189608663, 0.3622741636354476, 0.28179287910461426, 0.8441479783505201, 31.565326116979122, 97.81156986951828, 56.6249643266201, 39.52186547219753, 83.51917639374733, 29.99681208282709, 0.5222776997834444, 2.264574933797121, 0.8981141669210047, 4.337611170485616, 9.222249537706375, 29.049258828163147, 6.462346957996488, 0.4317867726786062, 1.5846695797517896, 53.60134117305279, 85.65267831087112, 75.57238161563873, 79.47108641266823, 80.20991116762161, 80.78085333108902, 83.61522763967514, 82.27446958422661, 77.43656918406487, 73.50989788770676, 77.47191488742828, 74.62332174181938, 69.06615793704987, 67.20593735575676, 73.09516534209251, 73.74227061867714, 76.67634397745132, 75.64073234796524, 70.1650133728981, 69.49935749173164, 73.55367913842201, 72.73518025875092, 68.60795572400093, 58.552996069192886, 54.17424023151398, 54.233099073171616, 54.78437349200249, 52.90051057934761, 53.528483882546425, 53.93159285187721, 54.022723361849785, 57.21941962838173, 56.487035527825356, 57.894677594304085, 61.205618530511856, 63.781492710113525, 64.1777278482914, 62.08653286099434, 64.4346396625042, 64.33179438114166, 67.37860009074211, 67.20533698797226, 76.48367911577225, 46.88533075153828, 52.95813448727131, 64.60746958851814, 62.611022517085075, 67.36766427755356, 69.75052401423454, 68.77577751874924, 69.03942257165909, 63.96256819367409, 63.28864775598049, 68.26091274619102, 64.38385158777237, 66.96978002786636, 64.78251099586487, 63.96333575248718, 55.20692601799965, 50.17216198146343, 54.15034331381321, 51.58470198512077, 54.449938237667084, 51.94688335061073, 50.39340130984783, 52.016104236245155, 57.40055590867996, 67.35751122236252, 66.11060813069344, 67.30932980775833, 62.47549518942833, 64.39969673752785, 67.49974519014359, 66.7991691827774, 70.09579628705978, 69.33739498257637, 69.01015654206276, 64.67167854309082, 70.00725343823433, 65.77907592058182, 67.25120812654495, 69.28795963525772, 66.41734287142754, 67.28248804807663, 63.13088022172451, 52.512847781181335, 62.59958513081074, 66.7954757809639, 66.47122398018837, 62.83584505319595, 72.42330059409142, 4.267273144796491, 0.35940466448664665, 0.9949589765165001, 2.0166095020249486, 11.347429901361465, 2.7515468280762434, 1.674627021420747, 0.6778088165447116, 4.48942537419498, 69.90743279457092, 45.836017057299614, 28.888109475374222, 74.82324421405792, 34.69655379652977, 0.26304887083824724, 0.3237161482684314, 0.14483363687759265, 0.17632216127822176, 0.1411040627863258, 0.2803321840474382, 0.1136210652475711, 0.10322060028556734, 0.11465109200798906, 0.13184289098717272, 0.2689766715047881, 0.1842971911537461, 0.12198665775940754, 0.13069594628177583, 0.1367576007032767, 0.11634096968919039, 0.09481657936703414, 0.1115026863408275, 0.19229723140597343, 0.11165363917825744, 0.14223652076907456, 0.09252118339645676, 0.11645831807982177, 0.11722089708200656, 0.13200371438870206], [0.10578764457022771, 0.03947728400817141, 0.03398142442165408, 0.03725341994140763, 0.0562587495369371, 0.03073404594033491, 0.03801363149250392, 0.023579354565299582, 0.03385606083611492, 0.04463147735805251, 0.10439755744300783, 0.017277240585826803, 0.03758645128982607, 0.021427493666124064, 0.058056576308445074, 0.08862692673574202, 0.08304544186103158, 0.04825903582968749, 0.013943948306405218, 0.039784013642929494, 0.11068641295423731, 0.10011184756876901, 0.04797342771780677, 0.0151240929881169, 0.04247656252118759, 0.07125894189812243, 0.01166186553746229, 0.03542823760653846, 0.05523061896383297, 0.022834613082522992, 0.09625220467569306, 2.769948053173721, 52.88928598165512, 62.65054039657116, 43.94156031310558, 45.401821956038475, 56.085355281829834, 2.3506023176014423, 0.10188186235609464, 0.44404731946997344, 1.0103933326900005, 3.344132867641747, 19.42862156778574, 2.8542968770489097, 0.766371792415157, 0.22975015919655561, 3.885765066370368, 49.78744402527809, 71.0437086224556, 70.36552101373672, 68.7872377038002, 73.63138496875763, 79.84497874975204, 77.13931873440742, 75.2686259150505, 74.8465521633625, 72.07200944423676, 67.77197778224945, 63.68120089173317, 66.86968579888344, 74.08422186970711, 70.11478766798973, 71.53711214661598, 72.51347735524178, 66.09519615769386, 70.3721858561039, 70.15011817216873, 69.37118276953697, 63.18311221897602, 53.004077821969986, 48.88953320682049, 50.72756677865982, 50.85862174630165, 49.8171204328537, 49.87393498420715, 49.383100122213364, 51.690940484404564, 52.37920515239239, 51.208449974656105, 58.17675165832043, 60.954269617795944, 60.056791976094246, 61.83158554136753, 60.97660481929779, 58.51375177502632, 60.70971094071865, 65.07614403963089, 64.48779881000519, 74.13342922925949, 49.972611889243126, 54.81609418988228, 69.41314771771431, 62.45598703622818, 70.06805017590523, 64.24517422914505, 66.20466828346252, 62.174262553453445, 58.36692005395889, 67.62190863490105, 62.790372893214226, 64.73869934678078, 63.64850364625454, 60.68150505423546, 56.9904401153326, 45.48254482448101, 47.56981462240219, 45.74019379913807, 47.269661128520966, 46.40133932232857, 48.171117156744, 45.43959192931652, 47.73276887834072, 52.33928829431534, 59.54217039048672, 64.02978658676147, 67.65355333685875, 62.71628826856613, 63.8824000954628, 62.64017075300217, 68.25817689299583, 64.79166850447655, 66.8560141324997, 60.71574121713638, 62.69079923629761, 58.818723410367966, 65.26937887072563, 63.81450533866882, 66.75813898444176, 63.2837688177824, 66.29467785358429, 54.84636716544628, 60.473709404468536, 58.89419496059418, 70.68519786000252, 60.1810909062624, 76.92621096968651, 14.880362525582314, 0.08796541340416297, 0.4395735345315188, 0.1469106410513632, 3.4089994244277477, 0.3087611304363236, 0.12134998411056586, 0.24844067345838994, 0.22001235047355294, 30.610593147575855, 52.84417100250721, 15.32769637182355, 48.62170837819576, 48.562541753053665, 3.201465248130262, 0.21174702211283147, 0.18709222320467234, 0.12126876346883364, 0.09234061886672862, 0.028234058408997953, 0.14155304728774354, 0.0043173504127480555, 0.05250924135907553, 0.04884335838141851, 0.02004364057938801, 0.029561469309555832, 0.00925231241126312, 0.06638061968260445, 0.028672322587226517, 0.01743955199344782, 0.018327919460716657, 0.030578959340346046, 0.08995586831588298, 0.04952069801220205, 0.07876809599110857, 0.09221408268786035, 0.0731022511899937, 0.015508262022194685, 0.05096883964142762, 0.036421836048248224, 0.0888792124169413, 0.012694411889242474, 0.002887040504901961, 0.01922835424920777, 0.015568881572107784, 0.02979292105010245, 0.016803618636913598, 0.07332751527428627, 0.0959969504037872, 0.020783164763997775, 0.027712623596016783, 0.020465761190280318, 0.03914048626029398, 0.0071285009835264646, 0.024804029962979257, 0.05412623271695338, 0.03839653516479302, 0.04557912572636269, 0.04719719690911006, 0.035521677709766664, 0.0434181178570725, 0.10750605040811934, 0.036530408542603254, 0.06314249578281306, 0.046279483067337424, 0.09184144291793928, 0.0424792602279922, 0.05145520612131804, 0.017347247376164887, 0.08941772219259292, 0.11269948852714151, 4.545450042933226, 69.85882580280304, 59.74867410957813, 32.57779888808727, 64.80668529868126, 65.29883489012718, 2.0075764367356896, 0.06724418271915056, 0.5362993036396801, 0.5714382149744779, 1.35424341307953, 3.176749711856246, 4.067650381475687, 0.9789177810307592, 0.08696250471984968, 5.7466235384345055, 61.40572339296341, 72.08325684070587, 73.21849152445793, 71.86799079179764, 74.97425571084023, 79.60710391402245, 80.51391765475273, 78.74236151576042, 75.80305203795433, 74.05096605420113, 70.49157544970512, 67.4241216480732, 71.15831047296524, 72.64146208763123, 72.4050235748291, 76.4712841808796, 73.98532077670097, 68.97224217653275, 71.64364323019981, 73.85838478803635, 70.45651093125343, 66.23767331242561, 56.296699941158295, 51.326889619231224, 52.49796777963638, 51.799941435456276, 51.223052591085434, 51.212215572595596, 51.742872297763824, 53.47499415278435, 54.29300285875797, 53.323203697800636, 59.27301563322544, 61.29722401499748, 60.50516411662102, 63.38346406817436, 61.83941312134266, 61.65929138660431, 62.601333037018776, 66.43164530396461, 65.90519115328789, 72.61987924575806, 51.65717929601669, 55.64172528684139, 68.35425093770027, 65.1397754251957, 69.77624863386154, 66.40555590391159, 69.70192462205887, 65.33519893884659, 61.827010586857796, 67.31001377105713, 65.40767624974251, 66.304382532835, 66.71922147274017, 61.294499561190605, 59.31579373776913, 47.95237809419632, 49.61994521319866, 46.64377771317959, 49.89507704973221, 48.233194425702095, 49.747234582901, 48.70160289108753, 50.222775265574455, 54.94027152657509, 64.91158246994019, 65.82741692662239, 66.74293980002403, 64.56312596797943, 64.62877124547958, 62.89030373096466, 68.8223098218441, 66.6037304699421, 68.96472617983818, 63.047926872968674, 65.42577847838402, 62.16197781264782, 66.0004748404026, 64.50837850570679, 67.82838195562363, 65.19640758633614, 69.78975310921669, 56.20176963508129, 60.480902418494225, 61.04445017874241, 71.6506652534008, 62.17498831450939, 80.07308810949326, 17.43963349610567, 0.27044493646826595, 0.7225621619727463, 0.9105782106053084, 1.4195354282855988, 0.22616004949668422, 0.3161973017267883, 0.21958425000775605, 0.516577708767727, 33.77161502838135, 73.50529253482819, 18.51371806114912, 39.67248938977718, 61.582410112023354, 3.8853952987119555, 0.3444646974094212, 0.11489333643112332, 0.09552362345857546, 0.028920916083734483, 0.039714081067359075, 0.05490158779139165, 0.01697263534879312, 0.03649682636023499, 0.03248374072427396, 0.054377004416892305, 0.06431719681131653, 0.023173542649601586, 0.08839109446853399, 0.0829195068217814, 0.025639658560976386, 0.06861220579594374, 0.03982308029662818, 0.029306357901077718, 0.05113738137879409, 0.03907439800968859, 0.05654114414937794, 0.041143476046272554, 0.022979736349952873, 0.026951326653943397, 0.031359824861283414, 0.2807197632500902, 0.11891798843862489, 0.15297179081244394, 0.21270108263706788, 0.1602918456774205, 0.10114099117345177, 0.15575454774079844, 0.1405167271150276, 0.13922403944889084, 0.10595266110613011, 0.2463176561286673, 0.1437822065781802, 0.10586438263999298, 0.10166588253923692, 0.13231354620074853, 0.2106432555592619, 0.18841143522877246, 0.2447882530395873, 0.1488224431523122, 0.15730906510725617, 0.21534685394726694, 0.1812636328395456, 0.15231752826366574, 0.145050804130733, 0.13302672043209895, 0.2072781798779033, 0.16072687780251727, 0.11142959963763133, 0.11500592023367062, 0.2460680273361504, 0.35130824893713, 5.523862391710281, 83.74889686703682, 78.22343856096268, 56.69129736721516, 59.766160771250725, 74.95424598455429, 4.2294020019471645, 0.44054815254639834, 3.3098480198532343, 3.537345612421632, 12.576085422188044, 36.00534036755562, 9.017146043479443, 2.2098592948168516, 0.27132607356179506, 4.8790602665394545, 60.272859781980515, 74.21821787953377, 79.47529658675194, 76.53734743595123, 78.24708849191666, 84.87790748476982, 83.78368020057678, 80.2592933177948, 79.70831528306007, 76.46338820457458, 76.44184336066246, 72.22817346453667, 74.73357662558556, 79.51937422156334, 76.93916827440262, 78.54683920741081, 75.05983471870422, 69.44991454482079, 75.35434171557426, 75.96604809165001, 74.0363672375679, 69.06886339187622, 58.91610838472843, 54.68126602470875, 55.48949025571346, 55.90354643762112, 55.24108238518238, 53.45916420221329, 54.63694140315056, 56.31031461060047, 58.95531848073006, 56.92104823887348, 62.42384076118469, 65.38781091570854, 64.65195000171661, 67.62309417128563, 65.15777885913849, 63.3880390226841, 67.55719810724258, 72.72957935929298, 69.7383114695549, 77.21362754702568, 55.69693632423878, 55.81009425222874, 72.52065896987915, 67.1185952425003, 74.7155199944973, 67.0261538028717, 71.75943061709404, 68.94267976284027, 63.68717797100544, 72.31166258454323, 69.42849889397621, 71.7996096611023, 70.78752636909485, 64.99433442950249, 61.93207114934921, 49.663946852087975, 53.970996737480164, 48.936916664242744, 54.20596472918987, 49.180065616965294, 53.30836929380894, 50.40616102516651, 53.71845468878746, 58.63029532134533, 66.47463619709015, 69.43546012043953, 71.00833252072334, 66.45514324307442, 67.61820763349533, 63.06906893849373, 71.92051157355309, 67.4653722345829, 71.5022224187851, 65.24357065558434, 69.44541558623314, 63.92740488052368, 68.34143802523613, 68.50174382328987, 71.05985015630722, 66.08070373535156, 72.72095382213593, 60.17733670771122, 65.81129059195518, 63.43715898692608, 78.74711126089096, 64.4086642563343, 83.11029553413391, 17.26289927959442, 0.3410595457535237, 0.9436901682056487, 0.8849270339123905, 9.216194562613964, 1.9147265190258622, 0.4669846105389297, 0.9598949924111366, 0.45390286250039935, 46.91874235868454, 65.18630772829056, 26.225848831236362, 58.83056737482548, 69.96901988983154, 5.981555907055736, 0.774247997906059, 0.5912849656306207, 0.23142911988543347, 0.17547684023156762, 0.11058479067287408, 0.28040206467267126, 0.10046862764284015, 0.1294897188199684, 0.3402092820033431, 0.1258119911653921, 0.15213871520245448, 0.09773006560862996, 0.15024821273982525, 0.12958371924469247, 0.16895233799004927, 0.15762170223752037, 0.14781932666664943, 0.1581389643251896, 0.20016836060676724, 0.15994288783986121, 0.15777354565216228, 0.13645395840285346, 0.21425107290269807, 0.13992156920721754, 0.15552464523352683], [0.04935046788887121, 0.055194019951159135, 0.05460833555844147, 0.017704888341540936, 0.06640722567681223, 0.04752771979838144, 0.04398569384647999, 0.029613824117404874, 0.003637673248704232, 0.03685780699015595, 0.02481110077496851, 0.045107041878509335, 0.06235504741198383, 0.017770458944141865, 0.06627047754591331, 0.07504235880332999, 0.05363557291275356, 0.03684643728774972, 0.02716512455663178, 0.06181366552482359, 0.009412377894477686, 0.06270983853028156, 0.07810221883119084, 0.08516609173966572, 0.08204746103729121, 0.03814836098172236, 0.042682779385359026, 0.03469894021691289, 0.13386206701397896, 0.031374400641652755, 0.25600214896257967, 0.5335540696978569, 14.100136142224073, 63.08607682585716, 46.773920729756355, 28.967610709369183, 62.09705449640751, 32.380030900239944, 0.18046707089524716, 0.16870480205398053, 0.3519645449705422, 0.26510877592954785, 1.5816908958368003, 2.5921033462509513, 0.22463052766397595, 0.5809818184934556, 0.5513458431232721, 6.16476877592504, 65.46064540743828, 67.68105626106262, 70.34674242138863, 73.90527427196503, 76.37440457940102, 84.6575877070427, 75.80384999513626, 77.42396146059036, 73.25574472546577, 73.3025050163269, 65.1965519785881, 72.40813940763474, 73.84409755468369, 78.70156690478325, 73.17766651511192, 69.62887734174728, 71.86590850353241, 71.28666758537292, 72.75080502033234, 66.95271134376526, 63.82663428783417, 52.68970549106598, 51.957963556051254, 50.18992602825165, 54.757273346185684, 51.42490155994892, 51.728345677256584, 49.260476902127266, 51.41503348946571, 49.32247057557106, 54.2843659222126, 61.157262325286865, 66.37978568673134, 63.66552293300629, 65.80850154161453, 62.68090456724167, 67.88911789655685, 62.846359089016914, 66.30255863070488, 64.58696588873863, 70.22865235805511, 36.82364545762539, 53.14354173839092, 70.08106827735901, 64.022346585989, 67.5980307161808, 66.7913644015789, 68.69329154491425, 57.96812765300274, 71.14605993032455, 69.58123549818993, 67.68506124615669, 66.95907980203629, 63.556787967681885, 63.304249718785286, 50.0880990922451, 47.60548710823059, 47.96486422419548, 49.53881576657295, 48.732415437698364, 47.92424060404301, 48.87688368558884, 49.315022975206375, 48.072409853339195, 50.20003728568554, 55.27143515646458, 62.56314508616924, 65.69670394062996, 67.69464433193207, 63.50614808499813, 63.51905599236488, 64.54965949058533, 67.72086292505264, 64.88977923989296, 64.66033235192299, 59.18084017932415, 66.56124114990234, 62.68251568078995, 68.10462713241577, 65.76055571436882, 67.26638451218605, 63.14529284834862, 65.3546766936779, 55.41548162698746, 68.52388143539429, 64.8031210899353, 73.78067135810852, 38.193578347563744, 0.08851090678945184, 0.4329331236658618, 0.08551533901481889, 3.062639459967613, 0.5747845291625708, 0.11238625025725923, 0.22171023592818528, 0.3277776553295553, 23.904608488082886, 67.65783950686455, 16.81861761957407, 29.09524206072092, 60.33282816410065, 18.804611451923847, 0.19929620350012556, 0.22630982974078506, 0.05344606550352182, 0.07732013618806377, 0.021944095242361072, 0.05277953154291026, 0.04439309210283682, 0.05223795298661571, 0.04099433033843525, 0.04061599829583429, 0.06272408776567318, 0.002780146423901897, 0.036052869909326546, 0.018310838931938633, 0.033472177528892644, 0.061201646021800116, 0.09093065702472813, 0.08690069123986177, 0.01754788143443875, 0.01800025569536956, 0.043001609737984836, 0.031950151387718506, 0.03626732461270876, 0.030397929112950806, 0.10078473060275428, 0.039943033625604585, 0.06966259708860889, 0.024842823877406772, 0.031521382989012636, 0.026158154469158035, 0.034689136446104385, 0.04080231075931806, 0.02622956391860498, 0.05322279408574104, 0.026323759157094173, 0.04182407741609495, 0.054941886410233565, 0.05071650943136774, 0.04170862150203902, 0.015346226136898622, 0.013135152985341847, 0.017043462212313898, 0.03137061939924024, 0.0819638729444705, 0.022771107505832333, 0.06200365533004515, 0.08690256145200692, 0.045319826749619097, 0.02176933801820269, 0.038166105732670985, 0.06192652021127287, 0.03420738983550109, 0.029531338113883976, 0.09608939231839031, 0.12621993490029126, 0.04238847330270801, 0.08169615801307373, 0.45918187766801566, 20.128946788609028, 79.31633591651917, 42.92947322130203, 31.48811426013708, 86.74026355147362, 31.291490010917187, 0.18308636237634346, 0.20004390244139358, 0.495809685671702, 0.6330702546983957, 2.079902943223715, 0.9419674950186163, 1.0424519749358296, 0.43155035411473364, 0.2970324066700414, 7.763475514948368, 75.28056487441063, 69.24484714865685, 74.52311351895332, 71.59258916974068, 82.24336445331573, 85.2969565987587, 79.04663398861885, 80.64746528863907, 77.16967150568962, 74.63921248912811, 67.86160737276077, 73.8991641998291, 78.47051650285721, 80.251404941082, 74.23677608370781, 69.90901350975037, 74.9444805085659, 72.45542407035828, 75.7405149936676, 69.31801602244377, 66.14124968647957, 54.526120349764824, 53.271982446312904, 52.01398395001888, 54.027799889445305, 51.97443187236786, 52.436365485191345, 52.14968986809254, 51.585431545972824, 50.55052287876606, 55.710638388991356, 61.87465243041515, 66.58290758728981, 65.86066514253616, 66.69233411550522, 65.20001739263535, 68.57990562915802, 64.5119047164917, 67.51423761248589, 67.1621561050415, 71.46442204713821, 41.3506655395031, 55.70085011422634, 71.97642177343369, 64.83448460698128, 68.83658185601234, 66.64466187357903, 71.56518504023552, 61.099817007780075, 71.53692975640297, 71.09946683049202, 69.99408334493637, 69.09767344594002, 64.79534670710564, 65.77750280499458, 54.41407956182957, 49.458271488547325, 51.26130513846874, 52.02301986515522, 50.78498549759388, 49.9612732976675, 50.108245611190796, 51.41520828008652, 49.73230138421059, 51.03948824107647, 59.600805044174194, 63.985815346241, 67.79871314764023, 69.02933791279793, 65.43563514947891, 66.69362604618073, 65.52004382014275, 68.228819668293, 66.66068941354752, 65.49703985452652, 63.40796135365963, 65.55401399731636, 65.5944362282753, 68.66328835487366, 67.68559321761131, 67.00233668088913, 64.4981038570404, 67.24886745214462, 58.1227907538414, 68.56884822249413, 67.75506108999252, 73.51493641734123, 41.86393819749355, 0.019421397992118727, 0.7420649123378098, 1.1277540726587176, 1.7769765481352806, 0.9617788007017225, 0.33826728933490813, 0.3777312592137605, 0.7134241866879165, 25.26603553444147, 83.52907866239548, 28.364864252507687, 17.39350587129593, 70.56653022766113, 22.619853727519512, 0.08045611830311827, 0.3228364064125344, 0.05436790197563823, 0.11740083820768632, 0.003476514953035803, 0.03992226091213524, 0.025834179177763872, 0.10159399069380015, 0.010489722135389457, 0.042597350766300224, 0.015086965195223456, 0.02483429474523291, 0.03328182778204791, 0.02263176371343434, 0.02745592955761822, 0.022438577107095625, 0.029395875753834844, 0.035113841586280614, 0.059083003652631305, 0.028838982980232686, 0.07793914672220126, 0.02445628182613291, 0.03528893277689349, 0.06712228496326134, 0.04404509534651879, 0.027736496631405316, 0.26314505317714065, 0.15670302731450647, 0.13272189069539309, 0.10128045556484722, 0.18657559936400503, 0.12625511270016432, 0.13388747815042734, 0.141820962599013, 0.0825501250801608, 0.20794097712496296, 0.25813902961090207, 0.15838704945053905, 0.2247840483323671, 0.06722919875755906, 0.11040012948797084, 0.1782755830208771, 0.15703282289905474, 0.19216713291825727, 0.13363161531742662, 0.24604312086012214, 0.1716582677909173, 0.1478158385725692, 0.2928912523202598, 0.14057960186619312, 0.41694951883982867, 0.19014638353837654, 0.15920198697131127, 0.1360297467908822, 0.3480538126314059, 0.25857078144326806, 0.6170806533191353, 1.1126920371316373, 25.882185772061348, 91.06348916888237, 59.608214646577835, 39.48324054479599, 83.2016122341156, 47.99367427825928, 0.3852634644135833, 0.9716643858700991, 0.7438006473239511, 1.0686656995676458, 6.165289347991347, 12.337214089930058, 0.8769292943179607, 0.9963990398682654, 0.685573877999559, 8.299252465367317, 79.13668155670166, 74.00579407811165, 76.0559056699276, 77.05079108476639, 81.63636222481728, 87.88933709263802, 81.79086953401566, 84.29365083575249, 80.0437080860138, 79.39102470874786, 73.71837750077248, 78.830835968256, 82.1715559065342, 84.40228700637817, 75.21653831005096, 71.90246254205704, 77.12874010205269, 73.18166390061378, 77.47082814574242, 72.6675894856453, 69.6000824868679, 58.54552946984768, 56.584405303001404, 57.38407239317894, 58.26694741845131, 54.93947356939316, 55.559003725647926, 53.99008311331272, 54.787937700748444, 53.4964744001627, 60.87387353181839, 65.84975972771645, 73.41542735695839, 71.72635719180107, 71.65070325136185, 68.55509296059608, 75.54750055074692, 67.15241342782974, 70.15565827488899, 68.90179395675659, 74.28593024611473, 40.14886982738972, 55.47553360462189, 72.75545597076416, 68.39316844940186, 72.4550212919712, 69.724852591753, 72.8395302593708, 64.354038387537, 74.83638390898705, 74.2580397427082, 72.12183997035027, 71.82711258530617, 64.91492629051208, 68.39813098311424, 54.26152154803276, 52.95279577374458, 54.45843458175659, 55.78138679265976, 54.057453498244286, 53.856999054551125, 53.49786892533302, 54.79576528072357, 53.45442585647106, 54.51243348419666, 60.68571902811527, 66.8430644273758, 71.34681835770607, 70.91375559568405, 66.17335796356201, 67.38003641366959, 67.59273380041122, 71.6553846001625, 67.4993348121643, 68.39773580431938, 65.43936654925346, 70.62066212296486, 66.54869422316551, 74.81838047504425, 68.43821123242378, 71.40880823135376, 67.10146576166153, 71.44089370965958, 58.99270087480545, 73.0284409224987, 68.1418727338314, 76.24300003051758, 40.5253042280674, 0.24221473722718656, 0.6766930420417339, 1.1729056248441339, 7.714332276955247, 2.136565027758479, 0.23004118498647586, 0.4979548486880958, 0.5935978540219367, 37.80732527375221, 79.34196934103966, 29.290502183139324, 37.72853270173073, 77.29719266295433, 31.172026321291924, 0.5593561695422977, 0.5139091238379478, 0.17071400361601263, 0.17151800188003108, 0.13493190257577226, 0.09722838120069355, 0.16720122570404783, 0.2254833740880713, 0.21282260189764202, 0.14348852389957756, 0.17733160086208954, 0.1357152097625658, 0.13086390914395452, 0.1423317680018954, 0.1403811070485972, 0.09585191248334013, 0.11945427919272333, 0.12720936618279666, 0.12991260940907523, 0.12963684217538685, 0.21897948870901018, 0.11288477311609313, 0.1219172817945946, 0.132719827524852, 0.1911688849213533, 0.21308217546902597], [0.04502045921981335, 0.0404073360550683, 0.052580038536689244, 0.052632289443863556, 0.025361507177876774, 0.04797946508915629, 0.05808839217934292, 0.02641869468789082, 0.03412932332139462, 0.009518604274489917, 0.030711213767062873, 0.01649542882660171, 0.025123140476353, 0.05790828035969753, 0.0209929253833252, 0.06992597787757404, 0.0242282365434221, 0.07341220174566843, 0.03570669512555469, 0.06365863722749054, 0.07269970286870375, 0.015095870039658621, 0.05672630628396291, 0.015503256236115703, 0.06359429302392527, 0.026174969680141658, 0.0666312949033454, 0.019385674713703338, 0.029574610889540054, 0.009783034274732927, 0.036035963785252534, 0.11944535115617327, 0.18836450180970132, 38.747854605317116, 56.90056353807449, 33.903327360749245, 30.20754687488079, 68.56767028570175, 15.82872323691845, 0.08708668829058297, 0.25745907390955836, 0.3771661879727617, 0.10760311590274796, 1.4308117982000113, 1.346587655134499, 0.23413902759784833, 0.03641448878624942, 0.2946413849713281, 12.148779351264238, 78.51291462779045, 69.57582458853722, 74.68800187110901, 73.76649811863899, 76.16400226950645, 85.17377480864525, 79.10272657871246, 76.5691365301609, 72.27224349975586, 73.05342078208923, 79.80818152427673, 76.37441977858543, 72.39977985620499, 70.80586418509483, 72.2293969988823, 71.68654292821884, 72.97881558537483, 70.90699195861816, 68.04050177335739, 54.987096413969994, 50.88666804134846, 51.30007065832615, 53.55859726667404, 52.263790145516396, 49.680779948830605, 49.41527299582958, 48.79482328891754, 51.13021977245808, 51.26601308584213, 55.74804738163948, 66.22650191187859, 68.6758504807949, 67.5308047235012, 69.56814140081406, 67.40604221820831, 69.37229990959167, 69.84632447361946, 69.31125238537788, 62.33404777944088, 67.04216614365578, 28.381267972290516, 52.28923738002777, 75.14555811882019, 69.65042978525162, 69.39966604113579, 69.33803334832191, 57.9122706502676, 68.2748655974865, 69.15248170495033, 65.69484204053879, 68.59876021742821, 66.08115211129189, 66.41738846898079, 55.695374608039856, 48.465118780732155, 48.5829808562994, 47.86799982190132, 48.71887296438217, 47.46198780834675, 53.962963968515396, 59.69717927277088, 59.40088637173176, 55.363093838095665, 50.452298149466515, 52.63447925448418, 62.53452122211456, 65.94508901238441, 67.4422238767147, 68.37666973471642, 66.5793889760971, 68.61508414149284, 69.00503441691399, 67.77460724115372, 65.78959375619888, 65.9957554936409, 64.18057009577751, 70.47476515173912, 70.01114442944527, 68.70721399784088, 68.85202422738075, 65.65331026911736, 60.763797238469124, 70.42340710759163, 67.84159764647484, 65.24796321988106, 69.6210041642189, 3.0630714492872357, 0.12270743900444359, 2.490089270286262, 0.6392108439467847, 1.3114112801849842, 0.7648492616135627, 0.2465024360571988, 1.1555411503650248, 17.681450620293617, 61.113142892718315, 19.34366002678871, 30.14060016721487, 50.905762016773224, 38.318872824311256, 1.4644690859131515, 0.2735036239027977, 0.0605831290158676, 0.04902816057438031, 0.09625248669181019, 0.10942421271465719, 0.09393127882503904, 0.03569434578821529, 0.03661601527710445, 0.030363879377546255, 0.07581369514809921, 0.04103015751752537, 0.015002233267296106, 0.03611414533224888, 0.057185591795132495, 0.04080618848092854, 0.02900204581237631, 0.0476809918473009, 0.0625002189190127, 0.01947487715369789, 0.02220567075710278, 0.007957608886499656, 0.014088943553360878, 0.008759335250942968, 0.03242153390601743, 0.01270012735403725, 0.024807822337606922, 0.025363972963532433, 0.05616344293230213, 0.018205118140031118, 0.05140692199347541, 0.08040742599405348, 0.02053604257525876, 0.03473931676126085, 0.02059391154034529, 0.026960755640175194, 0.014492469654214801, 0.035988982126582414, 0.02464087250700686, 0.02711915036343271, 0.03163443805533461, 0.04396031981741544, 0.045136727785575204, 0.0736550176225137, 0.034054514835588634, 0.03940605638490524, 0.016316892215400003, 0.033255184680456296, 0.04592611687257886, 0.05354320892365649, 0.06584006900084205, 0.02909727263613604, 0.055734860070515424, 0.043371436768211424, 0.06151486944872886, 0.06883718044264242, 0.06162606914585922, 0.07811142146238126, 0.03287941675807815, 0.9604248264804482, 53.762380331754684, 62.94930696487427, 24.93753746151924, 54.66953985393047, 84.51911553740501, 16.325616873800755, 0.1355070373392664, 0.14747747860383242, 0.586478995392099, 0.1661936563323252, 0.8440511429216713, 1.5294632920995355, 0.8070937322918326, 0.20342632953543216, 0.34427470760419965, 18.546162620186806, 84.02245938777924, 70.71700975298882, 81.49605855345726, 71.38502150774002, 81.52330309152603, 87.64846041798592, 83.99149104952812, 77.69867911934853, 76.95800766348839, 74.64190274477005, 82.67889708280563, 78.43462362885475, 74.83821541070938, 71.6037529706955, 73.4472544491291, 72.9332484304905, 76.24983206391335, 73.36339294910431, 71.35261684656143, 59.422852993011475, 54.89342384040356, 55.54038092494011, 55.50210937857628, 55.68989150226116, 51.534495279192924, 52.709494829177856, 52.000772058963776, 54.049975499510765, 53.72962228953838, 59.04429450631142, 66.9834440946579, 70.85294365882874, 68.5695169866085, 71.26714423298836, 66.46943807601929, 71.55966013669968, 70.26013746857643, 70.1241047680378, 65.48104271292686, 70.03739342093468, 31.17681786417961, 51.37828566133976, 74.4122126698494, 71.41708418726921, 70.72837874293327, 73.19555595517159, 61.52973733842373, 69.02204990386963, 72.72863700985909, 67.81444430351257, 69.2394970357418, 66.76171079277992, 66.8211168050766, 58.387872129678726, 50.738058015704155, 51.33026763796806, 49.17396694421768, 50.00118635594845, 49.07586380839348, 53.220848590135574, 59.69319328665733, 61.46929018199444, 57.84689895808697, 53.094425573945045, 56.30084931850433, 64.82208967208862, 68.76633122563362, 69.11440774798393, 68.68217334151268, 65.66939100623131, 67.60645106434822, 71.7707996070385, 68.13691020011902, 67.84077689051628, 67.62629359960556, 67.92449399828911, 70.77794328331947, 70.33519104123116, 68.63656058907509, 70.20721390843391, 67.5439140200615, 63.451203033328056, 70.23332610726357, 70.951267182827, 65.73108449578285, 73.70008528232574, 3.6230580881237984, 0.30332480964716524, 2.8285292722284794, 1.5194724407047033, 1.410410099197179, 0.9278462058864534, 0.5211664375383407, 1.69887435156852, 24.507296048104763, 67.25465834140778, 41.85559004545212, 20.962827242910862, 50.67941956222057, 47.097051590681076, 2.5832232227548957, 0.2771437691990286, 0.15773446415551007, 0.06158111726108473, 0.09207584284013137, 0.04720428813016042, 0.05988566605083179, 0.07473779623978771, 0.041200190971721895, 0.0053770074191561434, 0.025829442420217674, 0.021301504821167327, 0.05373982239689212, 0.008459045602648985, 0.03505054010020103, 0.04372405710455496, 0.03750928648514673, 0.0625261347158812, 0.035941221212851815, 0.03172259406710509, 0.04916440033412073, 0.06295430939644575, 0.02704434002225753, 0.020788018409803044, 0.047295754120568745, 0.015943918479024433, 0.07237976300530136, 0.2696289599407464, 0.13175469415728003, 0.11624806022155099, 0.2024701761547476, 0.14897758170263842, 0.1224204950267449, 0.17344736319500953, 0.11025360727217048, 0.20470101269893348, 0.11991737934295088, 0.1781474586459808, 0.17031239782227203, 0.0650995020987466, 0.20436903520021588, 0.11612294896622188, 0.1301469054305926, 0.20690360310254619, 0.13493589533027261, 0.14992209820775315, 0.15627376909833401, 0.15394574089441448, 0.1300020975759253, 0.1921558819594793, 0.18103356705978513, 0.18925922020571306, 0.13991894200444221, 0.20837151183513924, 0.16610673599643633, 0.25573830062057823, 0.09781207292689942, 0.13721655966946855, 0.1462215866195038, 0.9553659323137254, 68.99538293480873, 78.42543572187424, 47.31313079595566, 49.33061733841896, 87.28728219866753, 26.30394224077463, 0.25479200296103954, 0.31154747935943305, 1.3778292224742472, 1.4051426318474114, 3.976622703485191, 4.939872678369284, 0.6827221310231835, 0.4119551321491599, 0.6157449062447995, 17.97004323452711, 87.15350657701492, 76.6750368475914, 82.08656206727028, 78.0654202401638, 81.02992996573448, 89.81752082705498, 84.44540709257126, 83.13355788588524, 79.08454835414886, 79.3251970410347, 85.77000081539154, 83.16436663269997, 75.76781272888184, 74.08238276839256, 75.40827602148056, 77.42118760943413, 78.41865688562393, 77.24882885813713, 75.25356352329254, 60.69622926414013, 57.00527831912041, 57.67846159636974, 60.752272456884384, 58.95548567175865, 55.79984240233898, 54.24376890063286, 54.686992317438126, 56.965540051460266, 56.73941418528557, 60.200709253549576, 71.58099979162216, 74.61086601018906, 71.11857980489731, 74.0620082616806, 69.64287579059601, 73.90025854110718, 75.08149355649948, 76.1943094432354, 69.24594148993492, 73.76839801669121, 36.92529760301113, 52.49519772827625, 78.04479494690895, 74.6649295091629, 73.32458943128586, 76.76074504852295, 64.27750289440155, 70.15250444412231, 73.98617953062057, 71.77806481719017, 74.62665796279907, 71.71483621001244, 68.72048288583755, 60.72559408843517, 56.85404643416405, 55.05717225372791, 52.10718534886837, 53.18525590002537, 53.61732691526413, 58.35015915334225, 65.9673710167408, 66.08283922076225, 63.0294256657362, 57.35269367694855, 59.89636838436127, 68.84793564677238, 71.07401579618454, 71.90233334898949, 72.80544608831406, 70.01166120171547, 71.01259589195251, 73.68759915232658, 73.43192607164383, 69.41971376538277, 73.46727937459946, 69.28531497716904, 74.44381177425385, 76.38346329331398, 70.97032696008682, 72.7705791592598, 70.61617836356163, 65.29717817902565, 73.88211831450462, 72.02449679374695, 69.29424449801445, 73.25827538967133, 3.9954856038093567, 0.422793249017559, 5.456856312230229, 2.5766999227926135, 2.4193197302520275, 1.081640578340739, 0.4703300935216248, 1.6294405586086214, 30.349598452448845, 73.2781483232975, 31.093942411243916, 39.78151313960552, 62.453615963459015, 59.218822941184044, 3.5401360876858234, 0.6001599237788469, 0.3830382088199258, 0.22111455851700157, 0.19378428754862398, 0.24658350826939568, 0.18431917356792837, 0.16046003118390217, 0.08373523101909086, 0.11263996086199768, 0.17595484270714223, 0.07663531941943802, 0.16607047466095537, 0.14027339173480868, 0.15866452362388372, 0.09071455846424215, 0.19253543112426996, 0.24171194701921195, 0.1043614668014925, 0.0756605678179767, 0.2468186800251715, 0.18962499510962516, 0.10473710484802723, 0.08240418173954822, 0.1403714294428937, 0.16701200773240998, 0.14964072033762932], [0.0339874840574339, 0.05165880320419092, 0.02739348896284355, 0.02995871127495775, 0.016655176113999914, 0.057825571711873636, 0.02876294995076023, 0.02610089592053555, 0.04521390743320808, 0.04678974670241587, 0.03346341647556983, 0.009087751368497266, 0.017507721968286205, 0.031296066954382695, 0.1010740123456344, 0.021120968121977057, 0.007762670811644057, 0.04589711745211389, 0.0560802555992268, 0.06969229783862829, 0.012048201642755885, 0.03338055939821061, 0.06905092639499344, 0.07722454756731167, 0.006775635274607339, 0.04450495973287616, 0.05226962413871661, 0.08202158976928331, 0.046214600806706585, 0.10278055866365321, 0.08395582699449733, 0.08801890740869567, 0.3253605990903452, 4.699707515537739, 64.1478006541729, 56.82972013950348, 22.60360199958086, 33.21307919919491, 77.0568935573101, 9.375619757920504, 0.3190974367316812, 0.4104481270769611, 0.950786821777001, 0.23424300248734653, 1.2226049392484128, 0.15236112201819196, 0.5368436244316399, 0.19481671886751428, 0.07715940926573239, 14.312820229679346, 84.71206158399582, 61.80971011519432, 73.71893227100372, 79.65588569641113, 78.62399786710739, 84.96087983250618, 81.98031216859818, 77.73963332176208, 76.93910747766495, 72.06789806485176, 76.57116562128067, 74.53668639063835, 71.44858449697495, 72.0643262565136, 77.71133244037628, 74.63703140616417, 67.92420521378517, 56.720624193549156, 55.53228735923767, 54.196567833423615, 53.94388519227505, 53.32479581236839, 54.00562807917595, 53.25260728597641, 54.19062115252018, 50.653797537088394, 52.28259153664112, 50.85036098957062, 59.2460560798645, 70.72114393115044, 72.89413332939148, 68.31258237361908, 70.92835441231728, 71.81765869259834, 70.48316270112991, 69.11101073026657, 69.41488042473793, 59.10466566681862, 53.48931938409805, 26.90354246646166, 52.8129518777132, 77.1766023337841, 66.08454912900925, 71.9207851588726, 61.229207664728165, 70.74927002191544, 73.2267826795578, 69.86835569143295, 68.4447468817234, 66.76035806536674, 68.39889094233513, 61.61114417016506, 49.72066640853882, 49.507938623428345, 48.56545239686966, 50.18959924578667, 49.8199512809515, 51.17854557931423, 62.95578941702843, 70.12866452336311, 69.32973459362984, 63.773748725652695, 54.58935275673866, 52.07715556025505, 55.017042607069016, 63.699375316500664, 68.20171192288399, 71.66578844189644, 67.65022471547127, 65.60716554522514, 68.84055644273758, 70.9356652200222, 67.13006302714348, 70.7321709394455, 71.00187286734581, 69.76297214627266, 68.29420655965805, 71.23000502586365, 64.57123473286629, 71.93538397550583, 70.82168653607368, 63.52925084531307, 66.15717843174934, 84.07401502132416, 11.551613844931126, 0.26030583365354687, 0.05396224405558314, 1.5349108935333788, 0.18195531447418034, 0.46152733149938285, 0.3477960202144459, 1.49289132328704, 15.428410917520523, 57.48835399746895, 55.96074856817722, 53.598183542490005, 42.25703090429306, 55.98598301410675, 17.091355584561825, 0.190987563400995, 0.22300454147625715, 0.0679280718031805, 0.10735166884842329, 0.05134411774633918, 0.09724108676891774, 0.08408998503000475, 0.05904893907427322, 0.12352384597761557, 0.049907750290003605, 0.09260352468118072, 0.08017024301807396, 0.031491556073888205, 0.04330676230893005, 0.03093088020250434, 0.025997043485403992, 0.05865636150701903, 0.06894905920489691, 0.04839705674385186, 0.08769979132921435, 0.03588123341614846, 0.03660635251435451, 0.02315462344995467, 0.015379254491563188, 0.040243147013825364, 0.04137916359468363, 0.03179303130309563, 0.06508452555863187, 0.034154055392718874, 0.07184238871559501, 0.047788421434233896, 0.004093896241101902, 0.03614832123275846, 0.04009962678537704, 0.018381049812887795, 0.007944520184537396, 0.05019477590394672, 0.02305042406078428, 0.05578247997618746, 0.014452834329858888, 0.07251368355355226, 0.05099353089462966, 0.06833248291513883, 0.03311578337161336, 0.07953696098411456, 0.03642851166659966, 0.009582296315784333, 0.05638733404339291, 0.01213218678458361, 0.048851488609216176, 0.16279804869554937, 0.022872907902637962, 0.10073172641568817, 0.0321122698369436, 0.05561211997701321, 0.0438860308349831, 0.0944312488718424, 0.0676415508496575, 0.25028663221746683, 0.32991646556183696, 10.092403795570135, 78.98937106132507, 50.64860701560974, 18.134202025830746, 70.38280248641968, 78.4215447306633, 8.789813742041588, 0.508726320695132, 0.7313464593607932, 0.9462547930888832, 0.13624559302115813, 1.1978174443356693, 0.7487591437529773, 0.9007502160966396, 0.19186651858035475, 0.06352738098939881, 22.27461565285921, 88.58491256833076, 64.15866807103157, 79.03727889060974, 79.30443495512009, 83.51116642355919, 85.31092464923859, 84.61135178804398, 77.54868596792221, 79.60730910301208, 75.19008412957191, 80.41218191385269, 74.02893483638763, 72.5628063082695, 74.78195562958717, 80.62072992324829, 76.25482499599457, 70.97740978002548, 61.358290538191795, 57.72665821015835, 56.47847458720207, 54.847552701830864, 55.83084113895893, 55.0676216930151, 52.949375957250595, 55.635759606957436, 53.04020248353481, 53.62629063427448, 52.918753400444984, 59.83881667256355, 71.67169332504272, 73.55826169252396, 70.90097308158875, 71.45632088184357, 73.32144320011139, 73.11054691672325, 71.50697216391563, 70.680121332407, 60.87830789387226, 58.45008239150047, 30.14318212866783, 53.40616464614868, 76.65752738714218, 67.50641763210297, 75.01992926001549, 62.57742092013359, 69.58657801151276, 74.11794885993004, 69.60198238492012, 69.19324591755867, 71.74906477332115, 70.52210301160812, 65.66276416182518, 54.24721531569958, 51.93715587258339, 52.370465621352196, 52.20880709588528, 52.85017468035221, 53.57919216156006, 64.58593994379044, 73.85737404227257, 69.03853341937065, 63.56819495558739, 53.524007722735405, 55.84942974150181, 57.697088196873665, 66.05826213955879, 70.09818255901337, 74.36489760875702, 71.24864682555199, 66.49283722043037, 70.1639798283577, 72.49396160244942, 68.18695351481438, 70.65027013421059, 71.24065205454826, 70.13531416654587, 68.56487363576889, 71.62285834550858, 65.84136977791786, 73.70370268821716, 72.41712212562561, 66.68509170413017, 64.32614028453827, 88.60418513417244, 13.460302725434303, 0.3887051891069859, 0.16113924473756924, 2.4355543591082096, 0.19156220834702253, 0.6896749860607088, 0.6411314033903182, 2.6745373103767633, 25.2867691218853, 51.240983828902245, 64.47002336382866, 31.6142275929451, 36.82284750044346, 62.16515064239502, 21.873019002377987, 0.4034495260566473, 0.37280547665432096, 0.1982198964105919, 0.08548376805265434, 0.0029994958231327473, 0.11844953740364872, 0.03717715684615541, 0.03556903415301349, 0.05299760421621613, 0.021483327291207388, 0.05914722911256831, 0.08982810759334825, 0.045458797612809576, 0.08126284767058678, 0.04891608143225312, 0.023355010744126048, 0.04396361866383813, 0.051954107475467026, 0.01985867325856816, 0.11783275331254117, 0.07280272038769908, 0.0177282901131548, 0.04786691097251605, 0.04113231785595417, 0.04567743060761131, 0.021339762533898465, 0.027963202337559778, 0.21232053899439052, 0.16144941793754697, 0.12939371459651738, 0.1277555275009945, 0.12575395521707833, 0.1115767378360033, 0.11019266210496426, 0.09831082585151307, 0.12730707734590396, 0.10901312969508581, 0.13717327761696652, 0.07728646494797431, 0.12094116464140825, 0.11649387437500991, 0.27243065647780895, 0.13469166937284172, 0.18410544988000765, 0.28031778638251126, 0.11549598260899074, 0.22889757994562387, 0.10812828928465024, 0.11691953317495063, 0.23408729990478605, 0.23478658113162965, 0.1909959496697411, 0.28236222511623055, 0.14991469157394022, 0.34401228418573737, 0.19502085400745273, 0.3500902955420315, 0.12612425722181797, 0.3198866662569344, 0.5380143178626895, 12.722441218793392, 99.77805554866791, 70.83209037780762, 31.876823902130127, 50.07605753839016, 96.84937790036201, 18.33351083099842, 0.5001719703432173, 1.1967973178252578, 2.371283657848835, 0.4856974189169705, 3.7915070867165923, 2.1422293363139033, 1.1496197618544102, 0.6184339744504541, 0.13106336875353009, 18.92230063676834, 90.4499588906765, 68.37182119488716, 80.96604019403458, 82.8234489262104, 81.87220796942711, 87.9918783903122, 85.50180360674858, 80.78566387295723, 84.1141028702259, 77.0153845846653, 80.6705604493618, 76.16236075758934, 75.63038930296898, 77.21333876252174, 82.13671177625656, 82.11662605404854, 75.14007121324539, 61.61072239279747, 64.68652814626694, 61.14844299852848, 58.58177192509174, 59.78955991566181, 57.349596843123436, 57.197908982634544, 58.60539145767689, 55.776443257927895, 57.74601437151432, 55.978372022509575, 62.927720323204994, 77.13267669081688, 77.66484573483467, 74.82552409172058, 77.31348618865013, 76.64100587368011, 76.30460232496262, 72.74873793125153, 72.2184307873249, 63.336019814014435, 58.70100572705269, 34.17407043278217, 54.451036378741264, 77.8615839779377, 70.88543951511383, 76.03916376829147, 66.6656519472599, 72.50276193022728, 77.14965417981148, 74.01107579469681, 72.22799867391586, 72.66649514436722, 73.80238339304924, 66.9811338186264, 56.409523487091064, 54.6636463701725, 54.59570221602917, 56.140528321266174, 54.72012273967266, 57.993403896689415, 69.07935082912445, 78.10747638344765, 73.75240087509155, 68.93717005848885, 56.073359325528145, 60.0071856379509, 58.00785452127457, 72.4088005721569, 72.5094647705555, 76.19598135352135, 72.84377083182335, 69.33432474732399, 74.35610488057137, 73.76056283712387, 72.41763889789581, 73.24702799320221, 76.2215007841587, 73.09894993901253, 68.85004073381424, 72.95384332537651, 67.04584434628487, 77.58818104863167, 73.2189778983593, 68.19103449583054, 68.08227673172951, 85.74821278452873, 12.488222736865282, 0.5663386511150748, 0.3828079649247229, 3.3094775397330523, 0.8865265105850995, 0.8061029354576021, 0.4572803765768185, 2.159072645008564, 26.59445945173502, 74.08446505665779, 68.62758547067642, 58.175300136208534, 53.05149547755718, 69.1758580505848, 26.635174266994, 0.5906142422463745, 0.4536442388780415, 0.28629991225898266, 0.22183451597811654, 0.15735077380668372, 0.2348547102883458, 0.2352036681259051, 0.21846270159585401, 0.16599335067439824, 0.10742667771410197, 0.1863549737026915, 0.20677500375313684, 0.21549382887315005, 0.2340800268575549, 0.1679745435831137, 0.10151530819712207, 0.2187648744438775, 0.11136334811453708, 0.13676192000275478, 0.20454272744245827, 0.14754262432688847, 0.11381498843547888, 0.0906331003352534, 0.1759897533338517, 0.10813683140440844, 0.12317847271333449, 0.12211444074637257], [0.014572261661669472, 0.03389761368453037, 0.06334137651720084, 0.023705200546828564, 0.010685558208933799, 0.02174791592551628, 0.04857112748140935, 0.0398246239637956, 0.08784630612353794, 0.009397380945301848, 0.016306669131154194, 0.02048850987193873, 0.06227773046703078, 0.11899293051101267, 0.05633991451759357, 0.06343556990032084, 0.024890959575714078, 0.07198844337835908, 0.04608685863786377, 0.056709359341766685, 0.06357746111461893, 0.01837028125009965, 0.0344661767303478, 0.03839358141703997, 0.06472819819464348, 0.013228623702161713, 0.06281125301029533, 0.018424198278808035, 0.030726572513231076, 0.02949366669781739, 0.027369044473743998, 0.166277400276158, 0.35255992552265525, 0.3058027516817674, 21.730336658656597, 70.84019154310226, 58.98634761571884, 28.009779006242752, 42.04436391592026, 90.87801352143288, 17.00842883437872, 1.3949747337028384, 0.3373873990494758, 0.3833067772211507, 0.17025238776113838, 0.8308708376716822, 0.7392386952415109, 0.24399774702033028, 0.2498727513011545, 0.21415226336102933, 10.711088497191668, 84.835524559021, 68.74373003840446, 67.52203479409218, 78.5506846010685, 81.29686564207077, 80.9927299618721, 79.28751826286316, 81.56371012330055, 83.28154474496841, 74.60007458925247, 73.03965032100677, 80.16292288899422, 76.40687003731728, 73.65095391869545, 66.8109105527401, 59.857504069805145, 56.72111436724663, 59.70428489148617, 55.08219391107559, 60.34198187291622, 57.8457248210907, 57.73803859949112, 53.09209629893303, 55.61988405883312, 52.30164751410484, 55.11844016611576, 51.171903535723686, 58.1813608109951, 67.20801204442978, 73.56702402234077, 69.69721287488937, 69.85513240098953, 65.73453471064568, 73.61877724528313, 65.54594323039055, 73.12459096312523, 57.75773674249649, 58.33283968269825, 31.561640314757824, 54.34487767517567, 78.00626501441002, 68.66611540317535, 71.11461281776428, 68.38133588433266, 75.88364571332932, 69.52277183532715, 70.22974669933319, 68.13190206885338, 64.32682424783707, 58.988460302352905, 52.69301511347294, 49.868406280875206, 50.79139955341816, 50.174350664019585, 51.34802408516407, 48.314479663968086, 54.02898922562599, 69.24776539206505, 72.12468981742859, 72.52006620168686, 70.4665195941925, 63.010753467679024, 54.304873421788216, 59.06975694000721, 61.80794321000576, 66.23142644762993, 68.01593989133835, 71.12693175673485, 69.87168431282043, 66.60737067461014, 69.57343071699142, 74.09872189164162, 68.2320798933506, 72.31005907058716, 74.59415450692177, 73.95714148879051, 68.18931698799133, 74.11838963627815, 67.81433790922165, 67.7469751238823, 77.52345532178879, 85.02153217792511, 14.789928328245878, 0.14992809476098046, 0.2072898464393802, 0.12092101533198729, 0.19415978458710015, 0.37282260542269796, 0.6586591503582895, 4.3591127917170525, 15.282530095428228, 74.78434950113297, 39.883362874388695, 73.76252353191376, 69.32354092597961, 46.769820749759674, 52.201336696743965, 0.6910459406208247, 0.1158757098892238, 0.043309905304340646, 0.13335987052414566, 0.037034883425803855, 0.013121177416905994, 0.03516631513775792, 0.057276649604318663, 0.079881369456416, 0.03449938041740097, 0.05895004047488328, 0.02982286114274757, 0.013217372743383748, 0.03232667258998845, 0.0357268333027605, 0.054811235022498295, 0.024044172787398566, 0.0376456041703932, 0.07429144636262208, 0.032792815545690246, 0.01511689786639181, 0.02827617157890927, 0.013832056556566386, 0.015120720854611136, 0.009169220629701158, 0.0032361115199819324, 0.020079894493392203, 0.03479289611277636, 0.014112991921138018, 0.03594202644308098, 0.060505882574943826, 0.07742849717033096, 0.026421852526254952, 0.05917628048337065, 0.046285475909826346, 0.017152734180854168, 0.026307647131034173, 0.04986305815691594, 0.002046904983217246, 0.010252772935928078, 0.06370935559971258, 0.011281399820290972, 0.07850213252822869, 0.015251536442519864, 0.05397087152232416, 0.14265727397287264, 0.058303010155214, 0.05475736994412728, 0.022996353036432993, 0.008312097579619149, 0.06356241035973653, 0.02821011486958014, 0.03647086974524427, 0.028993561209063046, 0.08418621189775877, 0.045999177600606345, 0.0681919720955193, 0.10554709224379621, 0.0405907875392586, 0.18397474283119664, 0.2557411801535636, 0.4692800436168909, 33.38459439575672, 85.90973451733589, 41.573010608553886, 21.682683415710926, 87.02660098671913, 87.4326927959919, 16.036059111356735, 1.782649050001055, 0.2781872288323939, 0.09565869433572516, 0.3731834969948977, 0.9948804276064038, 0.15703939832746983, 0.5972694070078433, 0.313532724394463, 0.2901371126063168, 19.46750868111849, 90.04729449748993, 69.07474547624588, 71.99122577905655, 79.77297261357307, 81.68107822537422, 83.13047245144844, 82.75306910276413, 86.63465201854706, 83.3634227514267, 74.4530376791954, 73.84669661521912, 80.40041774511337, 78.80109116435051, 77.78711557388306, 71.06168925762177, 62.779079899191856, 56.313457041978836, 62.150612622499466, 56.71270541846752, 64.1308231651783, 59.48355853557587, 57.344850897789, 54.59710814058781, 55.23786395788193, 54.01302628219128, 58.0707411468029, 53.829910308122635, 62.50635713338852, 71.86594650149345, 76.53553873300552, 71.5687644481659, 72.4892270565033, 67.47193828225136, 73.83024349808693, 65.92333137989044, 73.53790998458862, 57.475009113550186, 59.10764090716839, 31.459898874163628, 54.54580329358578, 77.13411301374435, 71.15420669317245, 70.83949998021126, 70.52009671926498, 79.44695010781288, 72.72767186164856, 73.42705473303795, 70.29334768652916, 65.93978449702263, 63.87901067733765, 55.83402156829834, 50.915177911520004, 51.54782496392727, 50.82897573709488, 51.746071726083755, 50.23523099720478, 54.80849839746952, 70.15070334076881, 72.76648297905922, 74.36694949865341, 71.29957929253578, 66.09762042760849, 56.14802151918411, 60.643351301550865, 64.95873793959618, 67.35145434737206, 68.83069977164268, 70.726258456707, 69.41981256008148, 70.73958814144135, 71.25746235251427, 76.13817125558853, 69.72323387861252, 72.8746023774147, 73.13576236367226, 75.02075761556625, 66.82014405727386, 73.38232353329659, 68.56843784451485, 68.60199764370918, 74.75622341036797, 89.80120450258255, 17.556205540895462, 0.13332553877262399, 0.18781356106046587, 0.2662030578358099, 0.39695404178928584, 0.5766511789988726, 0.9385897731408477, 8.079121727496386, 25.317213088274002, 63.257956802845, 62.02015042304993, 71.05319291353226, 64.36248153448105, 47.79928430914879, 60.04099242389202, 1.2248713988810778, 0.3093469818122685, 0.055359329635393806, 0.04508258440182544, 0.014503032271022676, 0.08823465715977363, 0.08449363172985613, 0.06165082348161377, 0.07425171919749118, 0.02918036905612098, 0.04447277278813999, 0.0670354239991866, 0.03672738566820044, 0.046495184578816406, 0.0371713161439402, 0.029949052222946193, 0.05070280567451846, 0.04868283554969821, 0.06645375091466121, 0.09712683313409798, 0.03708364994963631, 0.02866869905119529, 0.034766286407830194, 0.06335705809760839, 0.027203196732443757, 0.019664414248836692, 0.05213443080720026, 0.030915254283172544, 0.16588523460086435, 0.10483059319085442, 0.18716257880441844, 0.1842833129921928, 0.10989860093104653, 0.14209762040991336, 0.1899046660400927, 0.20165108260698617, 0.24239783990196884, 0.12404078894178383, 0.11354009693604894, 0.08563499548472464, 0.14917603199137375, 0.1842546957777813, 0.18945081304991618, 0.09789448100491427, 0.2664222882594913, 0.211893952509854, 0.11064975085901096, 0.17400464188540354, 0.1429072886821814, 0.099042479560012, 0.2684217528440058, 0.1596040528966114, 0.20946736709447578, 0.14040515263332054, 0.22206847061170265, 0.12433634925400838, 0.1880985457682982, 0.18821776437107474, 0.20960974070476368, 0.40908839378971606, 0.5538628518115729, 0.6070617190562189, 40.44790618121624, 103.30857530236244, 70.49253299832344, 38.13584804534912, 62.94309429824352, 107.30897784233093, 30.404729694128036, 1.7633566539734602, 0.3006342868320644, 0.5775404500309378, 0.38376649317797273, 4.518404044210911, 1.9243207667022943, 0.5580220848787576, 0.7347146817483008, 0.24388448044192046, 16.264998726546764, 92.09008008241653, 74.86485198140144, 75.70950865745544, 82.92500987648964, 82.3653607070446, 85.67367598414421, 85.2846984565258, 86.00769326090813, 84.16600048542023, 75.77869534492493, 77.47962087392807, 84.32017341256142, 84.77990314364433, 80.31624466180801, 72.93562710285187, 64.63826313614845, 61.42808139324188, 66.00535377860069, 62.54402831196785, 66.58361434936523, 63.14075209200382, 62.79907822608948, 58.941829204559326, 58.61711762845516, 59.26245220005512, 61.56269297003746, 58.17456677556038, 64.90041106939316, 74.75044012069702, 77.92146876454353, 74.4949646294117, 72.52103134989738, 69.31094840168953, 75.52625209093094, 70.9955196082592, 74.34500947594643, 61.64775900542736, 57.405009269714355, 36.55970402061939, 58.79359535872936, 79.43337723612785, 75.51857650279999, 77.33533501625061, 73.23737651109695, 79.87106814980507, 78.16919267177582, 76.33064612746239, 75.58647885918617, 69.68031898140907, 66.90156608819962, 56.94466017186642, 54.714810624718666, 54.640076234936714, 56.75064258277416, 55.10765254497528, 54.725529849529266, 59.175493866205215, 75.6625659763813, 76.24082654714584, 77.09825813770294, 75.83077535033226, 72.96924769878387, 59.88119959831238, 65.74286386370659, 67.31176927685738, 74.2417462170124, 72.39821434020996, 73.3650116622448, 71.82565346360207, 70.69880872964859, 74.43977639079094, 78.13048034906387, 73.5078763961792, 75.00231340527534, 74.79261785745621, 75.28445586562157, 68.4253679215908, 74.00192588567734, 69.731874614954, 72.18899756669998, 79.47041764855385, 87.44555130600929, 18.104916997253895, 0.4116621322464198, 0.3623191674705595, 1.385927894152701, 0.9588705911301076, 0.6777291989419609, 0.7547154428903013, 5.263324622064829, 27.621208056807518, 90.21390795707703, 51.507946103811264, 81.48412719368935, 74.19008418917656, 59.01940204203129, 71.18364751338959, 1.346604754216969, 0.5744294263422489, 0.19669515400892124, 0.24457829946186393, 0.08203884470276535, 0.19839213404338807, 0.19400724355364218, 0.18069871002808213, 0.20610885199857876, 0.16355208557797596, 0.22318020783131942, 0.12622803915292025, 0.12280793322133832, 0.1316914038034156, 0.19833472149912268, 0.2193783485563472, 0.07396889413939789, 0.2008876798208803, 0.14913174061803147, 0.23084467859007418, 0.08409659014432691, 0.14072504796786234, 0.13553794036852196, 0.12238134673680179, 0.14955849037505686, 0.13980956427985802, 0.1137103233486414, 0.09723808107082732], [0.028239936218596995, 0.033654263461357914, 0.07488795497920364, 0.04980060642992612, 0.05474885751027614, 0.033288336417172104, 0.07831308525055647, 0.09786765978788026, 0.023743827478028834, 0.054417399514932185, 0.016762876584834885, 0.041959908994613215, 0.006419370529329171, 0.05123779395944439, 0.027862839851877652, 0.06746665632817894, 0.002229766228083463, 0.08525032550096512, 0.011502705474413233, 0.0469039632298518, 0.026147758835577406, 0.025859523520921357, 0.011266768378845882, 0.04505145130679011, 0.10907684307312593, 0.03701422945596278, 0.014282742431532824, 0.05522965046111494, 0.03629361519415397, 0.07207854752778076, 0.02324462926480919, 0.026410083919472527, 0.026076403191837016, 0.03849669541523326, 0.22308760264422745, 32.458109110593796, 65.84648430347443, 67.12195426225662, 23.293863460421562, 34.72250260412693, 92.95513406395912, 33.0299936234951, 5.54406875744462, 0.3267189965117723, 0.06852916689240374, 0.035851525244652294, 0.38343528751283884, 0.20263898506527767, 0.20560647739330307, 0.427573214401491, 0.5311206565238535, 6.569941509515047, 71.55395284295082, 73.43720018863678, 67.24553883075714, 68.48016858100891, 86.78985849022865, 83.48593577742577, 77.52880543470383, 74.56932663917542, 77.7153754234314, 77.59728536009789, 77.16104596853256, 75.58334022760391, 71.17075100541115, 65.43569594621658, 63.94804537296295, 64.52727869153023, 67.43451029062271, 65.57597681879997, 66.63716107606888, 58.63453209400177, 58.84934976696968, 57.59393893182278, 57.73043520748615, 55.496557876467705, 55.691882595419884, 53.79485338926315, 50.554463267326355, 63.41622970998287, 73.46743896603584, 71.30433663725853, 69.64425891637802, 71.01223111152649, 72.31210336089134, 68.3930392563343, 72.4042484164238, 68.39426279067993, 82.7300651371479, 29.895891398191452, 51.455261930823326, 80.86671352386475, 69.36984524130821, 70.39023488759995, 65.97510740160942, 65.28729870915413, 64.09116849303246, 62.48075790703297, 55.400628224015236, 52.24880374968052, 50.16208112239838, 50.77997736632824, 49.8015982657671, 52.056990042328835, 48.88623498380184, 51.755419224500656, 53.184704929590225, 60.17565339803696, 69.8871798813343, 72.97130718827248, 70.62032014131546, 73.49030613899231, 68.0364815890789, 60.18810532987118, 55.30736602842808, 62.70651139318943, 69.50719267129898, 72.6466678082943, 71.2568011879921, 70.79235211014748, 71.73981606960297, 72.22058907151222, 70.34276023507118, 74.96790245175362, 69.1310128569603, 68.83484914898872, 68.16487669944763, 78.20221289992332, 71.61371603608131, 74.60159450769424, 87.86690309643745, 50.671823769807816, 3.7641086569055915, 0.0720461824676022, 0.13252637931145728, 0.231986636063084, 0.0922929729858879, 0.06300731358351186, 0.17647259461227804, 6.753692049533129, 16.588813550770283, 70.78855231404305, 54.9240729957819, 12.142883017659187, 29.52946186065674, 31.27518318593502, 53.91389720141888, 2.9130310378968716, 0.0339437084767269, 0.06263439921895042, 0.06818676221882924, 0.081952607142739, 0.0833782134577632, 0.03906505437043961, 0.05522940926312003, 0.024892651672416832, 0.005023854128012317, 0.039699163899058476, 0.06857203334220685, 0.03674898216559086, 0.0351807276456384, 0.005022340146751958, 0.06456157119828276, 0.018983376867254265, 0.05738893283705693, 0.020630825965781696, 0.021653299518220592, 0.06481288466602564, 0.05852574351592921, 0.06186948987306096, 0.02529304962081369, 0.02990263088577194, 0.03824639497906901, 0.012776016592397355, 0.027252800027781632, 0.04170116291788872, 0.045640972602996044, 0.05340014882676769, 0.06366226632962935, 0.08117531877360307, 0.06215730216354132, 0.03832268776022829, 0.028624661863432266, 0.06321024644421414, 0.024538582292734645, 0.07260272643179633, 0.05411333047959488, 0.04408660366607364, 0.012697544680122519, 0.045146702250349335, 0.02252588892588392, 0.022157362509460654, 0.016699786610843148, 0.03326243917399552, 0.057672908224049024, 0.024743008725636173, 0.05187434515391942, 0.0309473113520653, 0.031085027985682245, 0.039245630032382905, 0.06032808996678796, 0.09701460556243546, 0.030170050813467242, 0.03668073426524643, 0.05699411027308088, 0.04763174663821701, 0.08558478177292272, 0.030599179153796285, 0.02683499871636741, 0.042807233839994296, 0.956234245095402, 48.94681133329868, 73.2616876065731, 41.11897677183151, 22.2188251465559, 82.4532499909401, 94.19282644987106, 28.722259774804115, 7.950629247352481, 0.13514648715499789, 0.3484126855619252, 0.19169675972079858, 0.22171017655637115, 0.48806804639752954, 0.11630206630798057, 0.7868607679847628, 0.528883645310998, 13.219565693289042, 82.15697228908539, 76.8882966041565, 69.00587797164917, 73.4412431716919, 88.04904252290726, 82.80332520604134, 77.20700070261955, 77.41988807916641, 78.35659861564636, 79.23763453960419, 79.32258278131485, 78.40539559721947, 75.62880098819733, 66.4259684085846, 65.08755102753639, 67.76354983448982, 68.53655755519867, 66.1896362900734, 64.96567636728287, 62.74734780192375, 60.93316175043583, 58.75042587518692, 58.495565950870514, 56.37102775275707, 55.34073203802109, 54.40469026565552, 53.00030082464218, 65.12199997901917, 73.93417552113533, 74.33696150779724, 70.14784589409828, 73.17245319485664, 73.22632670402527, 71.01324945688248, 73.38110759854317, 67.3481485247612, 78.98143708705902, 31.03914935141802, 53.163456469774246, 79.92792829871178, 69.28069442510605, 72.29023933410645, 69.54424068331718, 68.18516001105309, 66.81694462895393, 64.98539730906487, 59.4731280952692, 56.506748870015144, 53.451462015509605, 53.15439395606518, 52.335203513503075, 56.170257925987244, 51.588004007935524, 53.21433573961258, 55.09674333035946, 61.954102367162704, 73.26139122247696, 75.56526079773903, 71.31516605615616, 73.43967005610466, 67.67792522907257, 61.35581687092781, 58.34239237010479, 63.54441963136196, 70.91888532042503, 75.29664561152458, 73.35054963827133, 72.43839338421822, 70.69259226322174, 72.48851269483566, 71.18682414293289, 75.6034791469574, 70.40748596191406, 68.38890507817268, 68.50198701024055, 79.37315046787262, 71.56912922859192, 72.26479589939117, 86.32282555103302, 59.60883781313896, 5.612790919840336, 0.18011995358392596, 0.12387367954943329, 0.22391539416275918, 0.329804252833128, 0.05254561401670799, 0.5361343687400222, 12.682697251439095, 26.990086622536182, 55.89114390313625, 88.02615255117416, 17.502073645591736, 36.822338327765465, 36.527686938643456, 65.01917749643326, 6.057745143771172, 0.14422014792216942, 0.10342660563765094, 0.033381475950591266, 0.07481013337383047, 0.023585978233313654, 0.03602640863391571, 0.03681558620883152, 0.02136661158147035, 0.03610228581237607, 0.03851010602375027, 0.06570696481503546, 0.009191514745907625, 0.036395074203028344, 0.02088854045723565, 0.06653330172412097, 0.010393561133241747, 0.03140438340778928, 0.04881738692347426, 0.03375139203853905, 0.019947864566347562, 0.07087617181241512, 0.021268759410304483, 0.007027522515272722, 0.016846258731675334, 0.023195495377876796, 0.04999067787139211, 0.04332813616201747, 0.006619051855523139, 0.11414301770855673, 0.12626802606973797, 0.17213643353898078, 0.0984014717687387, 0.09759814143762924, 0.09761722947587259, 0.16793163260445, 0.24407052202150226, 0.1585757330758497, 0.15816201543202624, 0.17506926757050678, 0.20414484723005444, 0.07993927923962474, 0.1336176332551986, 0.10399970691651106, 0.13500199100235477, 0.11406044635805301, 0.1576164923608303, 0.11627439904259518, 0.1101772476977203, 0.1715304996469058, 0.11066967010265216, 0.10131410454050638, 0.1539877464529127, 0.3696672013029456, 0.12683679320616648, 0.09395926521392539, 0.11234786637942307, 0.14907732635037974, 0.14414300909265876, 0.2118428482208401, 0.10841920375241898, 0.13904025399824604, 0.16880257258890197, 0.8947689807973802, 60.84149166941643, 92.9637748003006, 80.94215467572212, 35.3196557611227, 53.84273461997509, 105.83014279603958, 52.05010861158371, 9.465263597667217, 0.34199937188532203, 0.465906715253368, 0.5036880285479128, 1.9867963017895818, 1.0943014989607036, 0.3728629188844934, 1.3195094768889248, 0.5756704753730446, 10.895706340670586, 77.38663986325264, 80.2666649222374, 73.6918093264103, 77.10300788283348, 87.32849478721619, 82.82468006014824, 78.37752789258957, 76.22083202004433, 78.37229937314987, 79.6549129486084, 83.15703302621841, 81.30483761429787, 78.32383677363396, 71.53212681412697, 71.77018404006958, 71.87618315219879, 72.93611347675323, 70.95979392528534, 73.02084892988205, 67.4087704718113, 64.0130066871643, 63.53817656636238, 63.28970789909363, 60.35190314054489, 59.58893068134785, 60.71228340268135, 55.18722787499428, 68.03091108798981, 80.34983485937119, 80.2426578104496, 76.15506514906883, 77.5963582098484, 78.66761192679405, 72.24627569317818, 76.50403842329979, 68.99514734745026, 78.96191373467445, 34.079915285110474, 54.96740587055683, 84.22125712037086, 74.99389305710793, 73.71568724513054, 69.26488727331161, 70.66098555922508, 68.89384478330612, 67.84200802445412, 59.7868050634861, 57.12763175368309, 55.98315216600895, 56.92615896463394, 55.38828268647194, 59.873444214463234, 54.46048267185688, 57.52547040581703, 58.492427319288254, 64.81318295001984, 77.7822594344616, 80.88898032903671, 75.49285188317299, 77.84630119800568, 71.69145226478577, 65.2939635515213, 60.78998163342476, 69.30827334523201, 73.01559761166573, 77.94615224003792, 80.23224636912346, 74.02284756302834, 76.88068941235542, 75.3048987686634, 71.06858968734741, 75.63785970211029, 72.00954079627991, 69.34709966182709, 67.56558045744896, 78.45002800226212, 72.54340454936028, 72.49061778187752, 86.64637818932533, 52.381450831890106, 5.098513215780258, 0.474627009825781, 0.19750382780330256, 0.7003971794620156, 0.6617681554052979, 0.23182107775937766, 0.5128928564954549, 8.283750247210264, 29.099798016250134, 85.55702224373817, 69.15095418691635, 20.50402846187353, 46.6951509565115, 40.655857622623444, 79.22394007444382, 7.942140502855182, 0.45540473191067576, 0.1000796680455096, 0.12749311892548576, 0.19218807632569224, 0.12806724436813965, 0.15310300252167508, 0.11509923046105541, 0.13057018193649128, 0.1141635826206766, 0.06800181901780888, 0.16178470541490242, 0.13540344836656004, 0.14298920694272965, 0.09713310428196564, 0.18030776147497818, 0.12795059359632432, 0.1864277190179564, 0.11165766904014163, 0.125631901610177, 0.1846521455445327, 0.11944380006752908, 0.16220030811382458, 0.1525293817394413, 0.11772472629672848, 0.13346452818950638, 0.11071743472712114, 0.09221653177519329, 0.12137685727793723], [0.04697432625107467, 0.06283459355472587, 0.05564868559304159, 0.06515200904686935, 0.019481599156279117, 0.07447414827765897, 0.04312131815822795, 0.054111215358716436, 0.07786996371578425, 0.041438565094722435, 0.04573922182316892, 0.01611024305020692, 0.030543924403900746, 0.0062900016655476065, 0.04857650805206504, 0.009582422480889363, 0.03975930383603554, 0.040798069385346025, 0.04040342122607399, 0.046955037832958624, 0.059556697960942984, 0.02867730425350601, 0.03306179212813731, 0.04034573779790662, 0.029265291159390472, 0.031326350290328264, 0.05023404664825648, 0.08975770004326478, 0.048221939578070305, 0.044423223298508674, 0.029572371458925772, 0.03831218265986536, 0.07354483837843873, 0.03710554701683577, 0.012022300688840915, 0.8299772324971855, 49.65848654508591, 73.73638853430748, 55.69731630384922, 26.284468285739422, 32.575253024697304, 87.7775090932846, 59.45426590740681, 13.920952957123518, 1.7014136840589345, 0.14624665636802092, 0.04628511225746479, 0.25094856857322156, 0.19590807671193033, 0.4561640677275136, 0.19759995077038184, 0.5455201026052237, 1.8796155718155205, 53.88794079422951, 81.15093067288399, 71.00592344999313, 60.28663784265518, 73.60306888818741, 84.15761813521385, 82.43331626057625, 74.7234083712101, 74.54302445054054, 77.77547299861908, 72.62063160538673, 72.6021645963192, 71.35480552911758, 69.75385263562202, 69.24982488155365, 69.0604430437088, 62.55078434944153, 67.15858429670334, 61.345375031232834, 63.49434211850166, 60.51264211535454, 59.27079275250435, 57.03120432794094, 55.35370834171772, 56.05573587119579, 56.65919288992882, 50.50733059644699, 59.79977376759052, 67.22411558032036, 73.60239252448082, 70.65680578351021, 73.96220281720161, 72.27497175335884, 77.88936048746109, 71.07770919799805, 75.68816900253296, 30.743156634271145, 54.98055316507816, 80.84389194846153, 70.119309425354, 69.8192623257637, 58.10617804527283, 60.19277147948742, 55.96155032515526, 52.44248315691948, 51.70547850430012, 52.51921243965626, 53.589067831635475, 55.533670485019684, 57.322584092617035, 59.33149829506874, 59.07160364091396, 57.02661797404289, 51.76830433309078, 60.83610735833645, 72.40580633282661, 74.20835360884666, 74.98974367976189, 72.96531111001968, 71.88942164182663, 66.83671116828918, 62.52988547086716, 63.74979481101036, 68.39729502797127, 74.25338119268417, 75.77745661139488, 73.25840458273888, 72.27851316332817, 71.75449848175049, 74.6233369410038, 67.28514790534973, 72.67015054821968, 78.69981899857521, 69.14924427866936, 62.64541067183018, 78.98309379816055, 71.75526604056358, 19.51342921704054, 0.0697377989126835, 0.09623498684959486, 0.20212743751471862, 0.27285430405754596, 0.0032784818904474378, 0.04070071816386189, 0.1974689617054537, 9.103568606078625, 18.725467398762703, 76.16900280117989, 48.711208775639534, 11.228336691856384, 43.41485917568207, 39.702298790216446, 53.24707478284836, 4.759711045771837, 0.023869313517934643, 0.05405614800110925, 0.04508098507358227, 0.01956227803020738, 0.00411521628848277, 0.051158502901671454, 0.0827559968456626, 0.052466026099864393, 0.025734816736076027, 0.03150470321998, 0.030941296245146077, 0.028449874953366816, 0.05577688047196716, 0.026685186930990312, 0.05332021210051607, 0.03431587327213492, 0.054116941028041765, 0.028806770060327835, 0.03560871678928379, 0.026441907211847138, 0.09797584265470505, 0.04411258254549466, 0.03931049745006021, 0.10519351082621142, 0.03857041665469296, 0.028084558325645048, 0.05648194673995022, 0.0471078423288418, 0.05110228892590385, 0.012811597935069585, 0.011040589597541839, 0.0302512844427838, 0.07168128329794854, 0.0320638447010424, 0.04563532485917676, 0.03843280392175075, 0.0841850764118135, 0.06760974240023643, 0.034443544936948456, 0.015719389120931737, 0.05881437216885388, 0.011718861551344162, 0.054259069729596376, 0.036595613637473434, 0.05292632835335098, 0.0388182642927859, 0.02178312155592721, 0.028731649872497655, 0.04379229387268424, 0.0321343784162309, 0.03858971249428578, 0.030938496493035927, 0.027687622496159747, 0.036106597690377384, 0.03366737350006588, 0.03761843414395116, 0.07364315810264088, 0.044262002847972326, 0.034975308590219356, 0.04274750579497777, 0.045430621976265684, 0.07257330769789405, 0.017926434265973512, 0.24406085925875232, 2.221595677547157, 64.16759759187698, 78.62136840820312, 33.2151310890913, 16.266961321234703, 74.55691650509834, 102.84960553050041, 53.95813822746277, 20.755981542170048, 3.960470245219767, 0.21751583990408108, 0.03311113752715755, 0.6164790387265384, 0.2513731661019847, 0.27015730971470475, 0.6053058570250869, 0.7075675728265196, 4.287452436983585, 64.05079185962677, 87.70536616444588, 71.85893967747688, 67.0928630232811, 78.34024429321289, 84.53978642821312, 81.60351678729057, 72.27994948625565, 76.02648004889488, 82.62628510594368, 75.63651457428932, 72.60144263505936, 72.72630393505096, 72.33173310756683, 71.19078353047371, 69.59337204694748, 64.6475650370121, 71.34883224964142, 66.59101635217667, 64.85555067658424, 62.91119121015072, 60.710588693618774, 60.26448503136635, 58.049648478627205, 58.64808216691017, 57.482065334916115, 55.90891554951668, 67.20527619123459, 70.50239726901054, 74.32042479515076, 73.17064449191093, 76.43582448363304, 72.0445217192173, 78.65338549017906, 72.91313230991364, 73.90408873558044, 32.261598855257034, 53.63311506807804, 81.16115212440491, 73.84674221277237, 70.46364694833755, 62.80926167964935, 64.43539202213287, 60.49437269568443, 56.87639683485031, 53.762517124414444, 53.79634290933609, 53.89455243945122, 56.46885730326176, 57.45221793651581, 59.65970568358898, 60.010046884417534, 55.01357339322567, 54.08916279673576, 64.61387604475021, 73.77332255244255, 75.28935760259628, 74.70575451850891, 75.19682496786118, 74.4198426604271, 70.03302365541458, 63.30864988267422, 66.71558126807213, 70.13884797692299, 74.90503862500191, 74.19428676366806, 72.48984262347221, 73.21493491530418, 71.24469503760338, 74.56881746649742, 68.6277374625206, 70.4577724635601, 76.28862798213959, 69.35536801815033, 62.24596090614796, 75.36864414811134, 76.89115405082703, 24.590752869844437, 0.07679234302486293, 0.12471468129660934, 0.16714471857994795, 0.06719223980326205, 0.14341280999360606, 0.06267059376114048, 0.39420310815330595, 16.973860189318657, 23.098970018327236, 52.98367291688919, 76.1662745475769, 13.929605092853308, 33.31550270318985, 41.12294755876064, 61.11838661134243, 11.393917556852102, 0.346915892441757, 0.04476620313653257, 0.07812517345882952, 0.03495650627883151, 0.03373079372977372, 0.015672075351176318, 0.024036268914642278, 0.03406671203265432, 0.06355438032187521, 0.05738786043366417, 0.03610726191254798, 0.06099744779930916, 0.023804780066711828, 0.03127391384623479, 0.041199077750206925, 0.032133083368535154, 0.009728839868330397, 0.033822270852397196, 0.07535233162343502, 0.03398600347281899, 0.05496010613569524, 0.056657279128558, 0.05351834697648883, 0.012530513213278027, 0.01758797596266959, 0.05211386589508038, 0.013278714031912386, 0.05109095262014307, 0.08123408202663995, 0.11068109175539576, 0.12884549010777846, 0.10484828599146567, 0.14937059342628345, 0.0984476185112726, 0.18018980452325195, 0.09427583572687581, 0.2881183521822095, 0.12090435411664657, 0.0881180509168189, 0.054839774311403744, 0.11934045600355603, 0.08756401541177183, 0.1654893285012804, 0.1626820064848289, 0.14630445482907817, 0.15305455512134358, 0.1263772405218333, 0.12972450465895236, 0.14454186893999577, 0.16295600740704685, 0.09580828904290684, 0.17676626244792715, 0.22139546141261235, 0.1129145926097408, 0.13382249569986016, 0.15163393603870645, 0.1997468207264319, 0.163189071463421, 0.16165788721991703, 0.09567082845023833, 0.1457723052590154, 0.21208757883869112, 0.17966423038160428, 0.28888273460324854, 2.0522974245250225, 75.18205136060715, 100.19181534647942, 71.08926057815552, 36.197678446769714, 50.87339535355568, 98.14209133386612, 83.28029081225395, 22.620457895100117, 3.3274928480386734, 0.35020464565604925, 0.27498064620886, 1.0116200731135905, 1.4940357743762434, 0.7997798966243863, 0.5766708904411644, 0.6917518121190369, 3.215426648966968, 59.78657327592373, 91.89528733491898, 80.49686416983604, 72.03941479325294, 79.65302065014839, 82.57709294557571, 80.08656218647957, 74.58840921521187, 77.88138091564178, 85.3456699848175, 79.45261180400848, 78.14827099442482, 78.19881588220596, 76.16603136062622, 74.96623814105988, 72.41541221737862, 67.15970903635025, 74.51859176158905, 67.63699382543564, 72.45817512273788, 70.30880525708199, 66.39405772089958, 64.7349451482296, 62.20250643789768, 62.03384108841419, 63.23790907859802, 55.95971122384071, 67.9321239888668, 71.47842809557915, 78.16996023058891, 77.72979184985161, 78.18982556462288, 78.3870729804039, 85.28817906975746, 75.70885509252548, 75.4995547235012, 37.56074510514736, 58.91480505466461, 88.241768181324, 78.5712642967701, 73.8690622150898, 64.85970005393028, 67.52189800143242, 64.01113718748093, 59.33865711092949, 56.499305069446564, 58.43588635325432, 61.35313801467419, 62.60350652039051, 64.73101615905762, 65.29194965958595, 66.98660552501678, 62.23485790193081, 58.057897835969925, 68.68317648768425, 78.7287886440754, 80.26687011122704, 80.01052066683769, 77.8485506772995, 80.5335322022438, 73.89378368854523, 69.14837032556534, 69.02092516422272, 76.05740278959274, 79.32380631566048, 80.1611977815628, 75.23256585001945, 72.44122043251991, 73.43372717499733, 75.76498568058014, 70.45025646686554, 70.80697372555733, 75.4993799328804, 70.54296389222145, 63.28832857310772, 77.70030543208122, 73.24844911694527, 21.5722993388772, 0.1698727792245336, 0.31249193649273366, 0.39544118859339505, 0.49397022812627256, 0.14190481044352055, 0.14064213522942737, 0.48880722548346967, 13.707512710243464, 31.50087397545576, 89.97869297862053, 59.23793211579323, 19.3682599067688, 58.12551140785217, 54.579013511538506, 80.63417360186577, 13.74894568696618, 0.3372844780096784, 0.14983222412411124, 0.27476655144710094, 0.08895323422621004, 0.12278606212930754, 0.22023780009476468, 0.16422974062152207, 0.09660410141805187, 0.09286124288337305, 0.10342923284042627, 0.12062814901582897, 0.2720120258163661, 0.0754631936433725, 0.07289762623258866, 0.1064498555206228, 0.1077902558608912, 0.1340922515373677, 0.14187778142513707, 0.18185899854870513, 0.1324806481716223, 0.12020790789392777, 0.13215395476436242, 0.08205616642953828, 0.2440358340390958, 0.14372299803653732, 0.11977397414739244, 0.07735786697594449, 0.15626982087269425, 0.11485029186587781], [0.05510763396159746, 0.023064808738126885, 0.050024735028273426, 0.02519583940738812, 0.02101395784848137, 0.031169441717793234, 0.07392690342385322, 0.048081109634949826, 0.031087803617992904, 0.14348617871291935, 0.04005597365903668, 0.1128364444593899, 0.046733350900467485, 0.0469324023288209, 0.045139967260183766, 0.04649420123314485, 0.05567480548052117, 0.0369303445040714, 0.023043282744765747, 0.032417719266959466, 0.05199276594794355, 0.039116147527238354, 0.005641758398269303, 0.02785240711091319, 0.06419769619242288, 0.05587647669017315, 0.07874182396335527, 0.034715690489974804, 0.05319461844919715, 0.0666961437673308, 0.07062739648972638, 0.017576552454556804, 0.061314600898185745, 0.035935874038841575, 0.065212464396609, 0.13046435167780146, 2.094870815053582, 46.6151462495327, 74.00169029831886, 68.94671514630318, 27.799534387886524, 21.740326322615147, 76.12832218408585, 88.78348991274834, 25.423100106418133, 4.254192346706986, 0.17783304036129266, 0.03961635877203662, 0.0985157179820817, 0.6809668033383787, 0.28969880018848926, 0.31292024475988, 0.6784094218164682, 0.1151789964933414, 24.977627210319042, 73.03102478384972, 89.84085157513618, 78.32949087023735, 63.82595032453537, 64.92457777261734, 80.91700002551079, 81.88288539648056, 79.48313176631927, 76.88597112894058, 75.39017379283905, 75.97446084022522, 73.89657273888588, 74.28538307547569, 73.63871857523918, 73.43633383512497, 68.96233230829239, 63.24814572930336, 63.03153075277805, 63.07909280061722, 64.86441180109978, 63.94358441233635, 62.61367477476597, 63.142469599843025, 65.69976657629013, 62.322956174612045, 57.25464753806591, 56.09324745833874, 62.88033686578274, 65.97933277487755, 72.11068376898766, 68.59502121806145, 73.12449216842651, 69.2767122387886, 87.16007262468338, 27.89367813616991, 45.36748319864273, 82.62710586190224, 68.4032455086708, 69.43308144807816, 54.886553809046745, 55.15214815735817, 53.4801010787487, 58.53138282895088, 59.42080110311508, 65.40163457393646, 68.21216136217117, 72.80369818210602, 71.30943596363068, 70.97532749176025, 66.89531162381172, 62.4273631721735, 57.75968983769417, 66.22610673308372, 74.18139025568962, 76.5764245390892, 73.38795483112335, 73.33170264959335, 76.28363505005836, 73.41634690761566, 66.34573951363564, 68.20956990122795, 71.97053968906403, 69.66853201389313, 76.6931314766407, 73.15956428647041, 78.89520451426506, 73.8672611117363, 68.01487594842911, 82.9045669734478, 70.29986053705215, 57.55955457687378, 65.66136583685875, 83.62487152218819, 43.71823109686375, 5.584008414298296, 0.22040441224817187, 0.23003189329756424, 0.1786830517812632, 0.06938411359442398, 0.022066410456318408, 0.09729880359373055, 0.45394400716759264, 9.338367506861687, 31.458202265203, 82.37518697977066, 43.82569693028927, 15.398824755102396, 51.063263565301895, 41.06011413037777, 42.49015599489212, 4.201713362708688, 0.28275387128815055, 0.06635749436100014, 0.049575045486562885, 0.06188229192048311, 0.04385062296933029, 0.037244109698804095, 0.03760809973755386, 0.01667488755629165, 0.051025855136686005, 0.017856113918242045, 0.045443609560607, 0.04623361834092066, 0.0605379359330982, 0.11947448045248166, 0.018032637453870848, 0.11848003225168213, 0.02549232554883929, 0.010335906463296851, 0.03961543850891758, 0.05815644341055304, 0.024262256592919584, 0.041211137649952434, 0.029386513560893945, 0.028214539925102144, 0.010654163506842451, 0.01765010856615845, 0.022731653079972602, 0.012153607021900825, 0.05086401499283966, 0.05797051315312274, 0.004861182778768125, 0.030188953314791434, 0.09625213788240217, 0.04976394433469977, 0.031298694157158025, 0.05067736856290139, 0.029445107975334395, 0.09892244459479116, 0.05195800004003104, 0.03082757324591512, 0.07465489092282951, 0.040790610801195726, 0.0287423293775646, 0.06485699050244875, 0.05861213321622927, 0.012158222252764972, 0.07952150204801, 0.033461011917097494, 0.10069877505884506, 0.015570621908409521, 0.05693316510587465, 0.029761437290289905, 0.031416803249157965, 0.02331018873519497, 0.033702900109346956, 0.030658126088383142, 0.01239220564457355, 0.00738309659936931, 0.006747802881363896, 0.05660987815645058, 0.029378240469668526, 0.04108279063075315, 0.03275690301961731, 0.01204174681333825, 0.05872978588740807, 0.13934998190961778, 5.153970289975405, 62.62995310127735, 79.55511510372162, 45.45679360628128, 14.455311633646488, 54.08830024302006, 104.24758091568947, 70.53747698664665, 27.359432503581047, 10.89022608473897, 0.23722937505226582, 0.24656591936945915, 0.2823840145720169, 0.2312949692714028, 0.2033364406088367, 0.6156927184201777, 0.7423983444459736, 0.728019856614992, 36.825982332229614, 85.6512875854969, 94.80708628892899, 76.78309544920921, 67.00056597590446, 73.02602425217628, 82.90086597204208, 82.35160544514656, 79.6649520099163, 79.49046537280083, 79.08619746565819, 75.54204404354095, 76.17800831794739, 75.4451036453247, 77.31229305267334, 73.35877999663353, 68.66916283965111, 65.52613869309425, 66.59025639295578, 64.98812556266785, 66.82776644825935, 64.99392405152321, 63.96782711148262, 62.69605815410614, 64.19028997421265, 60.56053854525089, 56.138814613223076, 59.27335761487484, 66.11737176775932, 68.12644556164742, 73.62027436494827, 71.21875002980232, 78.41294199228287, 71.40050947666168, 85.69014430046082, 30.88322851806879, 48.7988168746233, 82.85190939903259, 68.31943720579147, 71.26319244503975, 58.13597224652767, 56.41461901366711, 54.1052321344614, 57.51407101750374, 60.98531015217304, 65.2101780474186, 66.4488735795021, 70.96673235297203, 71.8887984752655, 72.45686799287796, 70.76156616210938, 65.32408073544502, 59.95902322232723, 67.24865466356277, 75.85796669125557, 77.56830051541328, 73.4162101149559, 73.96711215376854, 77.96017348766327, 72.56326228380203, 68.71853739023209, 66.9305357336998, 73.73604655265808, 73.67982476949692, 78.38751375675201, 73.81050735712051, 76.89423188567162, 75.27663588523865, 67.42557317018509, 81.45274087786674, 73.50485935807228, 58.81620034575462, 65.89223384857178, 85.04756838083267, 52.62907974421978, 7.7917255740612745, 0.34812906640581787, 0.2091358497273177, 0.33500685647595674, 0.12354573191259988, 0.068355548864929, 0.3494507720461115, 0.939925282727927, 19.438727125525475, 29.066775888204575, 70.0164033472538, 72.99022257328033, 14.457630459219217, 32.77401655912399, 46.94459617137909, 55.482836812734604, 11.33795415982604, 0.38304111803881824, 0.013900282192480518, 0.07697470355196856, 0.08216116548283026, 0.027598961823969148, 0.06833153296611272, 0.07068906896165572, 0.04338587896199897, 0.008123241404973669, 0.03817703756794799, 0.05356371446396224, 0.0695620286569465, 0.05163272413483355, 0.03914443819667213, 0.03659912399598397, 0.037531977650360204, 0.05660374059516471, 0.0676642605685629, 0.04441160868736915, 0.023157150462793652, 0.04907037022348959, 0.02590430471173022, 0.05572120084252674, 0.11597065284149721, 0.06715561481541954, 0.033247529427171685, 0.02002802022616379, 0.025461173900112044, 0.046817317488603294, 0.011408690206735628, 0.13143246847903356, 0.11949975800234824, 0.17773092084098607, 0.11197694839211181, 0.21969533467199653, 0.13758114713709801, 0.1414867289713584, 0.23254312807694077, 0.09034574817633256, 0.19365651940461248, 0.1187292454415001, 0.15672337700380012, 0.1365442480891943, 0.24569506844272837, 0.14795484283240512, 0.17959765973500907, 0.24471075797919184, 0.09622576195397414, 0.140466884477064, 0.14571223582606763, 0.209555356123019, 0.17723016411764547, 0.1007543396553956, 0.11014751726179384, 0.19668289372930303, 0.137408078298904, 0.15171975799603388, 0.19885471469024196, 0.07807585774571635, 0.16670830606017262, 0.1294747571228072, 0.26835205033421516, 0.13592989824246615, 0.10752352798590437, 0.14969106763601303, 0.2440511222812347, 4.383400613442063, 69.54375430941582, 104.37722995877266, 85.63260778784752, 39.13430526852608, 42.91388265788555, 87.16084778308868, 102.7169394493103, 39.27611365914345, 9.091484304517508, 0.23881014960352331, 0.2549784304574132, 0.5945613991934806, 1.2642790842801332, 1.181286193896085, 0.9483988280408084, 0.6288775359280407, 0.4417444352293387, 31.545268893241882, 85.69909662008286, 99.35543462634087, 88.8855068385601, 76.1284589767456, 75.85478246212006, 79.20225083827972, 80.59314340353012, 83.21483552455902, 82.36131012439728, 81.30133420228958, 79.39476370811462, 81.23962551355362, 81.55626252293587, 82.84983471035957, 80.39134383201599, 72.85140082240105, 73.3151051402092, 69.9959908425808, 69.04579102993011, 73.40028136968613, 71.30755126476288, 70.1083356142044, 69.0886603295803, 71.11423283815384, 68.04077535867691, 63.716725185513496, 62.14922569692135, 69.08149391412735, 72.83848151564598, 78.73682141304016, 74.81873765587807, 81.97135224938393, 74.6108204126358, 90.2573624253273, 32.63129621744156, 49.99424792826176, 85.26927888393402, 71.98556408286095, 76.8447357416153, 60.7690105587244, 59.38714250922203, 58.9314291626215, 66.10765188932419, 66.50736764073372, 74.6700668334961, 75.43601453304291, 78.6037677526474, 79.33245465159416, 78.6861777305603, 74.05972078442574, 69.95356231927872, 66.5845339000225, 72.41888523101807, 79.52780976891518, 84.71687212586403, 76.64756432175636, 75.13285160064697, 81.63681820034981, 81.46862402558327, 73.41368705034256, 75.48845171928406, 74.51861456036568, 77.7319273352623, 82.77457594871521, 77.28000998497009, 84.63047236204147, 75.27844458818436, 69.0158486366272, 79.76465865969658, 73.7519221007824, 60.179141610860825, 68.19924965500832, 85.068938434124, 47.99872800707817, 7.161821974441409, 0.3633991110837087, 0.322469369857572, 0.5361903563607484, 0.5094434728380293, 0.14698167942697182, 0.3039072471437976, 0.5953204084653407, 18.02704967558384, 48.473033756017685, 91.4776137471199, 58.9234533905983, 25.928602181375027, 63.469476252794266, 57.42597654461861, 69.52317461371422, 14.514332916587591, 0.5656280892435461, 0.18042329902527854, 0.28939395560882986, 0.20980473258532584, 0.12242273631272838, 0.19323652319144458, 0.17592230695299804, 0.08724711835384369, 0.14871247170958668, 0.12621856934856623, 0.2691383409546688, 0.17769296740880236, 0.1261737584718503, 0.1522399441455491, 0.11987651669187471, 0.2007379589485936, 0.1555539303808473, 0.12168050699983723, 0.1637442721403204, 0.1786186482058838, 0.1286652372800745, 0.11828630944364704, 0.13121105614118278, 0.1896100927842781, 0.20062455878360197, 0.14978955063270405, 0.10538712231209502, 0.1071642542956397, 0.14885871933074668, 0.14715544588398188], [0.01876037633337546, 0.05503771622898057, 0.04598998239089269, 0.047702836964163, 0.04256454783899244, 0.03071391889534425, 0.026520537758187857, 0.07168991447542794, 0.057054858771152794, 0.04683503997512162, 0.0298149535592529, 0.062192747136577964, 0.06402171813533641, 0.03644445299869403, 0.016274456211249344, 0.03566945786587894, 0.009572614999342477, 0.05811885363073088, 0.03885285208525602, 0.034680241806199774, 0.011195571369171375, 0.02733965728111798, 0.05991898106003646, 0.023148558248067275, 0.052399904452613555, 0.04503302006924059, 0.051445843928377144, 0.06292592966929078, 0.04273014325008262, 0.03580433578463271, 0.026877605414483696, 0.026709058111009654, 0.04166432270721998, 0.05953039995802101, 0.025641951797297224, 0.02429695385217201, 0.04280950852262322, 0.3265181416645646, 33.65818731486797, 64.66905668377876, 64.5016984641552, 36.316950246691704, 21.395986899733543, 63.15868712961674, 99.45663839578629, 48.169635236263275, 13.696895129978657, 1.873144875280559, 0.11768680255045183, 0.07093066029483452, 0.13330628746189177, 0.27598723594564945, 0.10207375948084518, 0.41612546774558723, 0.6182614993304014, 3.71999136172235, 36.2692666053772, 72.74551570415497, 91.16546049714088, 84.42684128880501, 67.99290552735329, 72.38527983427048, 80.38035482168198, 82.94031545519829, 78.707524985075, 75.55877074599266, 79.19440045952797, 78.03272679448128, 75.60987800359726, 70.73280170559883, 72.38720253109932, 69.25671771168709, 66.3851509988308, 64.66459572315216, 65.42598366737366, 64.45069760084152, 65.92441812157631, 65.24132117629051, 70.63383981585503, 70.25040999054909, 70.44244408607483, 64.89548653364182, 60.237658470869064, 59.27967667579651, 66.34254768490791, 72.40028902888298, 75.16544625163078, 75.52026361227036, 73.03448259830475, 35.77956408262253, 49.3628966063261, 81.5220719575882, 75.69275915622711, 67.68968939781189, 61.41284041106701, 62.678955271840096, 68.54448392987251, 70.38518115878105, 74.7594228386879, 73.98737266659737, 78.48700001835823, 72.7462300658226, 77.1337178349495, 74.09996062517166, 72.6297815144062, 67.2844335436821, 58.959741443395615, 64.86543774604797, 77.27437868714333, 77.33399748802185, 80.31067416071892, 76.00095301866531, 79.34867218136787, 73.40576827526093, 76.40055477619171, 69.68212008476257, 73.01701873540878, 80.06451576948166, 72.02508196234703, 70.38850978016853, 70.76547235250473, 73.98672670125961, 74.13956969976425, 47.50367157161236, 54.250198155641556, 72.68599569797516, 56.548417434096336, 11.082377973943949, 0.23758191004162654, 0.04578343156026676, 0.2575526142027229, 0.11742374088498764, 0.11128695143270306, 0.054980329659883864, 0.2545705164084211, 1.489746398292482, 21.14470638334751, 50.63920632004738, 67.42453202605247, 34.125459641218185, 17.66645472496748, 51.805755123496056, 41.69812649488449, 38.126975521445274, 4.437055634334683, 0.05085469732875936, 0.05785070825368166, 0.03167658833262976, 0.12612108082976192, 0.028404064032656606, 0.03925463599443901, 0.04539637557172682, 0.07312898334930651, 0.03617960275732912, 0.025467977538937703, 0.02303574437974021, 0.031700014224043116, 0.006887703748361673, 0.0330832401959924, 0.020793220865016337, 0.014987396807555342, 0.05169063020730391, 0.057359759011887945, 0.020884256409772206, 0.04983931685274001, 0.050319705333095044, 0.049326860171277076, 0.08800102164968848, 0.047633668800699525, 0.10195033290074207, 0.029638231499120593, 0.052737017613253556, 0.051218947119195946, 0.026188450792687945, 0.04690707282861695, 0.029080331260047387, 0.032853727316251025, 0.00817736716271611, 0.03544249426340684, 0.028233243901922833, 0.03644164025899954, 0.03281086086644791, 0.06229750128113665, 0.04472103973967023, 0.01634062053199159, 0.02973736758576706, 0.03561284684110433, 0.07840045087505132, 0.0383844567113556, 0.054833165486343205, 0.04036193517094944, 0.026125275471713394, 0.01661773847445147, 0.03168190210999455, 0.010906736770266434, 0.037406710544019006, 0.025261213340854738, 0.022254012401390355, 0.031114075645746198, 0.011068213261751225, 0.011758619330066722, 0.07103717332938686, 0.06168692525534425, 0.024963571304397192, 0.06746702740201727, 0.07634663139469922, 0.0540822975744959, 0.04673359951993916, 0.03933833912014961, 0.009029309094330529, 0.08185996484826319, 0.04402795915666502, 0.14572866697562858, 1.6161814075894654, 46.532888263463974, 74.22114372253418, 50.14093905687332, 17.609621174633503, 38.987906724214554, 100.44409140944481, 93.8844045996666, 38.39654825627804, 18.776990734040737, 3.381156180985272, 0.08536957378964871, 0.0646421461715363, 0.17501399241155013, 0.3578223759541288, 0.2910274820169434, 0.6615409988444299, 0.4757478309329599, 6.843035230413079, 52.00337111949921, 88.7047353386879, 100.16333967447281, 82.52038478851318, 68.75414907932281, 76.20713755488396, 83.6481262743473, 83.69320705533028, 80.35864278674126, 79.85895439982414, 81.17540895938873, 79.21759441494942, 77.62011453509331, 73.1573224067688, 77.43374973535538, 72.36311182379723, 67.48760104179382, 68.12783628702164, 67.38514333963394, 67.66633585095406, 69.03252974152565, 68.18000748753548, 73.00134837627411, 72.50682011246681, 72.00276955962181, 63.41305308043957, 62.6029859483242, 63.304481506347656, 70.00733703374863, 73.59703481197357, 76.47194534540176, 73.61646696925163, 75.33823058009148, 32.881079614162445, 50.64964056015015, 81.78717613220215, 75.02743765711784, 69.66275632381439, 60.32261051237583, 64.22760397195816, 67.2143805027008, 71.20606631040573, 77.0013253390789, 74.18125346302986, 77.14531481266022, 73.97696882486343, 76.34114876389503, 75.24745345115662, 72.50843122601509, 68.06509405374527, 60.5918412655592, 67.79245868325233, 76.5712796151638, 78.40847343206406, 79.01317298412323, 76.28313347697258, 80.36007910966873, 73.98891538381577, 77.19311624765396, 74.67824399471283, 75.92201605439186, 77.60785639286041, 72.82107084989548, 72.54795670509338, 75.09653314948082, 74.5835530757904, 78.05105701088905, 56.0511115193367, 53.21147449314594, 74.12310138344765, 64.77982074022293, 16.34392239153385, 0.34343112318310887, 0.10310722980648279, 0.5132480780594051, 0.37244194303639233, 0.1658340560970828, 0.04353433818323538, 0.08424183586612344, 3.128754012286663, 24.480313695967197, 38.69760610163212, 82.07085371017456, 64.16758999228477, 16.0083319991827, 42.49832555651665, 50.064004585146904, 53.547254875302315, 8.733601458370686, 0.2464405112550594, 0.07420254449243657, 0.03665037300379481, 0.007013530248514144, 0.02621604569867486, 0.04310527292545885, 0.023416241638187785, 0.03875732654705644, 0.04923982109175995, 0.02702672514715232, 0.016507945147168357, 0.035621485440060496, 0.005722077794416691, 0.06311708464636467, 0.017148333245131653, 0.0365739540575305, 0.03936306748073548, 0.11253973381826654, 0.04819079164008144, 0.05894421832635999, 0.022460852669610176, 0.09048458916367963, 0.021090347108838614, 0.03285903738287743, 0.026868621716857888, 0.058808527755900286, 0.03538056575052906, 0.03483462336589582, 0.023527639859821647, 0.025842550603556447, 0.04291071520128753, 0.1319253584370017, 0.13186859898269176, 0.12053376267431304, 0.2654567244462669, 0.09603370897821151, 0.19755086512304842, 0.13049577421043068, 0.14755568612599745, 0.14697649923618883, 0.12495521135861054, 0.1277632309938781, 0.1676086350926198, 0.12518069066572934, 0.12489104527048767, 0.12124864384531975, 0.09860985941486433, 0.10225093239569105, 0.10082212742418051, 0.1582987338770181, 0.13322285522008315, 0.12854828964918852, 0.11867273089592345, 0.13897878932766616, 0.05908886290853843, 0.13820784632116556, 0.1285659972927533, 0.3145716420840472, 0.14250877022277564, 0.2041745331371203, 0.13823254499584436, 0.2009273401927203, 0.09576655065757222, 0.15794294828083366, 0.1752201610361226, 0.12864381889812648, 0.1051499616005458, 0.18907326768385246, 1.3663011160679162, 50.59382535517216, 94.86799702048302, 80.8820267021656, 48.45527730882168, 39.03233014047146, 77.37813591957092, 113.4579598903656, 61.82808592915535, 24.109493494033813, 2.4634707486256957, 0.2437431606813334, 0.2183566932217218, 0.37729330302681774, 1.1527390382252634, 0.4342195327626541, 0.65650240983814, 0.6221233983524144, 4.611763609573245, 45.10778993368149, 82.81728565692902, 105.23065656423569, 93.21326181292534, 78.15951839089394, 78.10680001974106, 85.65242752432823, 89.60085645318031, 84.68627616763115, 82.67825871706009, 82.93254107236862, 82.83829092979431, 80.33860266208649, 76.54078245162964, 81.76554769277573, 76.21710821986198, 74.08294513821602, 76.85523837804794, 74.06469091773033, 76.20485007762909, 75.19545704126358, 73.35013926029205, 79.7914320230484, 77.25278064608574, 78.7721899151802, 71.02916300296783, 65.375856757164, 64.54513013362885, 72.04981103539467, 81.5073211491108, 82.34121680259705, 79.63453844189644, 75.6706291437149, 44.71420705318451, 60.45359328389168, 86.31692826747894, 85.21166637539864, 72.25939258933067, 69.03156459331512, 70.63318625092506, 76.01633459329605, 78.34915101528168, 84.17098581790924, 79.77035835385323, 84.12580624222755, 75.858164280653, 82.78705447912216, 79.10857066512108, 77.31597125530243, 71.68956756591797, 65.62671169638634, 70.51855400204659, 81.98378518223763, 81.46767407655716, 84.28394615650177, 80.99431827664375, 86.89801588654518, 77.58093863725662, 85.08912295103073, 75.25715813040733, 83.23096185922623, 85.07733598351479, 73.10401886701584, 70.93143984675407, 72.64138609170914, 79.98956099152565, 81.02730810642242, 60.58291174471378, 60.274463295936584, 77.1428981423378, 61.575285494327545, 12.864704634994268, 0.2948849875247106, 0.1213782822014764, 0.5636394897010177, 0.5273811821825802, 0.4032552911667153, 0.2172705452539958, 0.49733405699953437, 1.7564806854352355, 33.55429328978062, 63.681599870324135, 78.53218719363213, 47.72902227938175, 28.816044442355633, 63.901262283325195, 61.518569737672806, 69.25728768110275, 10.78255221247673, 0.27009894722141325, 0.21344389824662358, 0.11090865649748594, 0.17129850428318605, 0.11872219503857195, 0.14753383729839697, 0.07766538328723982, 0.13122794742230326, 0.1578286723815836, 0.08795490459306166, 0.18431164819048718, 0.08583979855757207, 0.1918520763865672, 0.14543170400429517, 0.1627208653371781, 0.10723560437327251, 0.16037284367484972, 0.15837955375900492, 0.14763721846975386, 0.2765568491304293, 0.1064413356652949, 0.15083838341524825, 0.29554256005212665, 0.09567086555762216, 0.19226668460760266, 0.1518808485707268, 0.20182133128400892, 0.12622300739167258, 0.11990225437330082, 0.11839151629828848, 0.1211782734026201], [0.054518031029147096, 0.00530784157490416, 0.025758921692613512, 0.08153246250003576, 0.07456257517333142, 0.11597569202422164, 0.04348857364675496, 0.1305757777299732, 0.03881200427713338, 0.033131164382211864, 0.07464081238140352, 0.0457274958898779, 0.05674334228388034, 0.058142004927503876, 0.030952365377743263, 0.03435794933466241, 0.014167213230393827, 0.03959948975534644, 0.04946286244376097, 0.024063275668595452, 0.01908501213620184, 0.051719759503612295, 0.0636862673854921, 0.039903499418869615, 0.07009054912487045, 0.06143285099824425, 0.09303444530814886, 0.07297775591723621, 0.07469400952686556, 0.01469869950597058, 0.040455137786921114, 0.12357176645309664, 0.11042272046324797, 0.05163050511328038, 0.03751395830477122, 0.014443869185924996, 0.06077741214539856, 0.006069881592338788, 0.28602620819583535, 22.671918533742428, 69.09192055463791, 67.22342401742935, 47.51711145043373, 20.701944641768932, 38.434637412428856, 82.46149554848671, 82.11391299962997, 39.7113461047411, 6.569623276591301, 0.1734901702729985, 0.18620887451106682, 0.1026656742033083, 0.06431435438571498, 0.08375546196475625, 0.32766746124252677, 0.0879704748513177, 0.6573773128911853, 1.32872742600739, 19.982610940933228, 50.906559973955154, 83.48918080329895, 82.3356007039547, 71.00369676947594, 71.21764048933983, 84.41550269722939, 85.87288409471512, 79.09158557653427, 77.21168205142021, 82.03088745474815, 84.79562669992447, 81.24808385968208, 70.62115609645844, 69.26426410675049, 68.84994953870773, 71.55739545822144, 70.88949009776115, 67.66185969114304, 74.66302961111069, 72.99086093902588, 79.28912177681923, 78.81373688578606, 81.19061574339867, 70.85938811302185, 67.17260554432869, 63.612390384078026, 72.49387040734291, 70.53937688469887, 86.13008469343185, 63.47775600850582, 53.84127929806709, 44.99513357877731, 71.70293524861336, 78.00592303276062, 73.35105881094933, 72.11135253310204, 75.05512297153473, 78.44303637742996, 74.28042814135551, 77.93289095163345, 76.02858513593674, 77.11487084627151, 75.36428958177567, 79.33961346745491, 76.13032847642899, 78.93907696008682, 68.49169716238976, 63.210364356637, 67.89792582392693, 80.0004132091999, 79.50118839740753, 78.55452239513397, 73.05855810642242, 76.81025639176369, 81.51686623692513, 73.04394409060478, 80.73304429650307, 79.82977956533432, 60.64911939203739, 78.46980974078178, 64.41415876150131, 66.22263371944427, 56.53970830142498, 45.87486617267132, 65.65655529499054, 68.05862680077553, 21.726603358983994, 0.5818605213426054, 0.05175471094844397, 0.3530171775491908, 0.227774977684021, 0.3626986424205825, 0.28835711593274027, 0.037802175065735355, 0.07689101897994988, 3.1588766584172845, 27.327360324561596, 74.57327842712402, 55.495889112353325, 19.62883472442627, 26.074113473296165, 50.262220948934555, 43.66404600441456, 28.224818967282772, 2.8534910827875137, 0.40017540799453855, 0.05440965520392638, 0.018195269840362016, 0.02776212670141831, 0.11437640830990858, 0.020940598406014033, 0.04112772767257411, 0.03827662265393883, 0.04118929624382872, 0.0554396040388383, 0.0656360451830551, 0.02249703051347751, 0.012744664563797414, 0.016490346970385872, 0.02985221679409733, 0.01906191278976621, 0.050722747182589956, 0.00528946089616511, 0.09964117751223966, 0.015413847850140883, 0.08711708665941842, 0.01555434197143768, 0.041203530636266805, 0.007857828059059102, 0.053852918281336315, 0.02804964027745882, 0.11658670962788165, 0.05517954064998776, 0.035680456494446844, 0.07013123366050422, 0.04021063352411147, 0.02674215047591133, 0.1225692436855752, 0.061557761873700656, 0.04736298156785779, 0.017161450705316383, 0.03228857814974617, 0.08082174477749504, 0.10766084014903754, 0.08820821443805471, 0.028187815187266096, 0.06399202480679378, 0.04551641795842443, 0.033845117868622765, 0.06104554267949425, 0.0575788966671098, 0.05227034031122457, 0.02039695296844002, 0.07423477596603334, 0.05630433966871351, 0.0819153587508481, 0.021938783320365474, 0.06898262654431164, 0.01631244860618608, 0.05642284209898207, 0.011273656436969759, 0.045153552273404785, 0.11183924289071001, 0.021518737012229394, 0.04624411230906844, 0.051165594122721814, 0.06880586181068793, 0.04665071646741126, 0.047024558516568504, 0.007947001740831183, 0.07574887597002089, 0.03460535910562612, 0.0898412881360855, 0.020202126215735916, 0.14964221947593614, 0.5651330470573157, 33.4615782648325, 85.89320540428162, 65.53858682513237, 25.14030598104, 22.674460597336292, 69.62776780128479, 95.94881102442741, 72.73461028933525, 38.1155077368021, 8.797410484403372, 0.34756028442643583, 0.2605009591206908, 0.08301685433252715, 0.2365983565687202, 0.15332870447309688, 0.4354968579718843, 0.24291481997352093, 0.7850800885353237, 3.9884588308632374, 29.866032600402832, 69.99073952436447, 89.57488104701042, 79.92821708321571, 71.30507379770279, 77.53303080797195, 85.46706587076187, 85.19146665930748, 81.09818190336227, 82.1277442574501, 84.79639425873756, 87.2278305888176, 77.19921872019768, 70.64559638500214, 73.37403997778893, 71.42409101128578, 74.57785338163376, 72.63807266950607, 69.64928224682808, 73.93965482711792, 74.72224563360214, 77.25361660122871, 77.05215901136398, 78.08861419558525, 70.28891712427139, 64.81619998812675, 66.06799721717834, 76.27538189291954, 76.57478302717209, 82.83122330904007, 64.64895576238632, 51.99043281376362, 51.42106756567955, 73.63106578588486, 80.41795760393143, 74.24622237682343, 70.88571310043335, 71.99445560574532, 77.28624925017357, 73.82579773664474, 79.93885651230812, 78.3183042705059, 78.56135442852974, 77.24089488387108, 79.38857764005661, 78.41161966323853, 79.99360397458076, 71.12348914146423, 65.12609615921974, 69.45615381002426, 82.12855741381645, 80.28985127806664, 79.0541423857212, 73.75435397028923, 78.16049873828888, 81.27111822366714, 73.90094250440598, 73.42182621359825, 82.72799044847488, 70.45543178915977, 80.93702495098114, 75.15785425901413, 72.40250051021576, 66.20034411549568, 49.624098390340805, 64.65515702962875, 74.72002655267715, 30.18543016165495, 1.456295249518007, 0.24435518018435687, 0.6724086531903595, 0.13376371760386974, 0.16339656111085787, 0.10866653188713826, 0.019082765284110792, 0.17987632134463638, 6.055649556219578, 26.553258262574673, 76.75236269831657, 83.283421844244, 37.0912878960371, 13.257017433643341, 44.06130708754063, 52.62954331934452, 43.608363792300224, 5.232482627034187, 0.5548673635348678, 0.09045420563779771, 0.017440286719647702, 0.03996926483523566, 0.08469406355288811, 0.017666307794570457, 0.033142010870506056, 0.029966351685288828, 0.02204812022682745, 0.016564058932999615, 0.04463587458303664, 0.004626420595741365, 0.01639988287934102, 0.01781478556949878, 0.08940050436649472, 0.03999718072009273, 0.037287039231159724, 0.004631511264960864, 0.05459047206386458, 0.012771066467394121, 0.08659538652864285, 0.027309874894854147, 0.016918319415708538, 0.018713917888817377, 0.02354859811021015, 0.029405046843749005, 0.014100828120717779, 0.0413196359295398, 0.042580619046930224, 0.06000935238262173, 0.0911698215350043, 0.05022615390771534, 0.1672113040694967, 0.1273687943466939, 0.15275437122909352, 0.1535385986790061, 0.1518214025418274, 0.194822225603275, 0.19960965699283406, 0.3398118767654523, 0.13563989661633968, 0.24062903481535614, 0.16030747530749068, 0.08581692556617782, 0.1162138620566111, 0.13985078316181898, 0.10951485863188282, 0.1101540778472554, 0.13050181529251859, 0.2415845202631317, 0.21032496326370165, 0.10638624604325742, 0.14453740121098235, 0.19332990021212026, 0.20708827913040295, 0.07546265929704532, 0.22455413098214194, 0.1595824267133139, 0.2862272708443925, 0.21639003156451508, 0.21148513304069638, 0.1268061128212139, 0.17899693571962416, 0.2945503976661712, 0.2812938886927441, 0.20900540985167027, 0.12347084179054946, 0.18443163862684742, 0.2834135515149683, 0.23783434415236115, 0.665052366675809, 35.5840265750885, 102.29007795453072, 83.93129467964172, 58.16488489508629, 35.68188652396202, 58.74781921505928, 93.39523404836655, 99.59944993257523, 58.45844954252243, 11.534817796200514, 0.30218300060369074, 0.4990402248222381, 0.5697690951637924, 0.3998498129658401, 0.23407262022374198, 0.8984632731880993, 0.25123960920609534, 0.8577925118152052, 2.9118939489126205, 24.109932370483875, 61.405958980321884, 90.64887821674347, 85.51584005355835, 77.90496245026588, 78.9669218659401, 86.78447037935257, 88.55656608939171, 85.27950793504715, 85.78551158308983, 92.22766309976578, 95.23406937718391, 84.0894041955471, 79.34722065925598, 77.03998446464539, 74.67236950993538, 79.40653547644615, 77.31461092829704, 74.27073866128922, 83.50552752614021, 79.71028357744217, 83.57263192534447, 85.25164783000946, 88.0634817481041, 78.34892302751541, 73.66212531924248, 74.28715378046036, 79.3410573899746, 82.08996668457985, 86.86077028512955, 65.89590445160866, 63.93732234835625, 56.593908593058586, 77.19148233532906, 83.44245851039886, 80.95461040735245, 76.5607313811779, 79.56843718886375, 83.37167590856552, 78.85846808552742, 82.85583838820457, 84.63841393589973, 81.89790219068527, 83.578400015831, 84.81809869408607, 83.3375309407711, 85.74687525629997, 78.71179595589638, 72.76208281517029, 74.21595320105553, 88.86892452836037, 88.0826099216938, 80.4748709499836, 74.66875210404396, 80.5516268312931, 88.81843283772469, 76.7531530559063, 90.91664984822273, 84.75891306996346, 68.5842677950859, 90.10423824191093, 82.03712671995163, 86.60746067762375, 70.20261615514755, 60.526564568281174, 69.4828587770462, 72.6238614320755, 22.92771700769663, 0.8858704520389438, 0.15686252969317138, 1.2434246158227324, 0.9921345405746251, 1.9315855018794537, 0.9288896655198187, 0.33965860842727125, 0.3970723401289433, 5.8800719026476145, 41.600502133369446, 91.27235636115074, 63.13707768917084, 30.984616577625275, 38.77687744796276, 65.20982086658478, 62.82731831073761, 57.159227058291435, 5.559998927637935, 0.5884560174308717, 0.12812222266802564, 0.11535248093423434, 0.23321270855376497, 0.24804123473586515, 0.19857321807648987, 0.04990209883544594, 0.279432968236506, 0.21364729123888537, 0.12854815606260672, 0.14100700471317396, 0.1532594472519122, 0.10635339858708903, 0.16887628269614652, 0.18481075734598562, 0.17354290728690103, 0.13103694829624146, 0.19561838678782806, 0.31531174143310636, 0.12367356684990227, 0.18093829014105722, 0.17943544109584764, 0.12337937208940275, 0.07483779321773909, 0.12290193364606239, 0.0903429280151613, 0.1599225975223817, 0.1786305967834778, 0.08609211392467842, 0.12962588807567954, 0.25208568724337965, 0.16403578774770722], [0.060312274799798615, 0.04969443107256666, 0.04146387604123447, 0.02977764765091706, 0.20369700563605875, 0.11795356753282249, 0.05424011527793482, 0.07503291126340628, 0.032963297999231145, 0.05243829946266487, 0.038008495830581523, 0.027465015300549567, 0.019125262515444774, 0.02364847077842569, 0.017647368185862433, 0.0263525025366107, 0.08419793783104979, 0.04490822793741245, 0.0035244240643805824, 0.17359396704705432, 0.05175357175176032, 0.03240260914026294, 0.02544572238548426, 0.3138606052380055, 0.2616085106274113, 0.14587242098059505, 0.0348180512082763, 0.1894437478040345, 0.03127454467175994, 0.13084728503599763, 0.36221099202521145, 0.0786600838182494, 0.029866280492569786, 0.06684776453766972, 0.06585405848454684, 0.09422087226994336, 0.06775784539058805, 0.17128835170296952, 0.08793017623247579, 0.4318559408420697, 9.879851751029491, 56.071311235427856, 80.05620181560516, 57.95983649790287, 50.911131128668785, 40.4979532957077, 49.492838233709335, 96.18571311235428, 64.04572293162346, 18.115594424307346, 1.1154440394602716, 0.20468910865020007, 0.20235134346876293, 0.25951019197236747, 0.7346236053854227, 0.31328184879384935, 0.11339223885443062, 0.045127573393983766, 0.5413634225260466, 0.16360078530851752, 14.546023216098547, 55.05519635975361, 84.42172676324844, 80.82822918891907, 74.85454693436623, 76.37673765420914, 85.67734658718109, 86.53537854552269, 83.57576295733452, 75.24352446198463, 75.08175194263458, 82.20727398991585, 80.08275479078293, 72.82548621296883, 72.7576294541359, 72.97221913933754, 76.48347392678261, 73.32078203558922, 77.9844617843628, 78.2301414012909, 78.44423711299896, 77.94894888997078, 75.52350103855133, 76.7876324057579, 74.67775002121925, 78.10027956962585, 77.4973963201046, 80.50866633653641, 56.73813745379448, 67.74714231491089, 35.05866676568985, 76.07384070754051, 83.79848420619965, 76.97600349783897, 81.65598437190056, 84.16620567440987, 74.91098150610924, 76.0264040529728, 76.2128372490406, 81.94949582219124, 80.75610905885696, 78.32373797893524, 76.64681196212769, 80.58478385210037, 77.58670672774315, 77.62705296278, 69.53427001833916, 64.76038858294487, 76.110280752182, 84.85443234443665, 78.8564769923687, 81.74584954977036, 82.24534794688225, 77.02895745635033, 72.93915331363678, 93.72635588049889, 59.40106876194477, 81.36276930570602, 65.3140340745449, 62.284289449453354, 66.16465643048286, 62.01350457966328, 84.3217085301876, 48.47245618700981, 3.7872306536883116, 0.27017043088562787, 0.09217713857651688, 2.071879436261952, 0.4022302367957309, 0.6387109926436096, 0.18598863476654515, 0.2026069985004142, 0.2880350238410756, 15.2355988137424, 50.49075208604336, 63.80864605307579, 35.309761092066765, 14.471849296241999, 40.99645234644413, 60.41249468922615, 54.30706970393658, 29.57315381616354, 0.7204259047284722, 0.37329167244024575, 0.2643336175242439, 0.06745987309841439, 0.05009499785955995, 0.11648152503767051, 0.12170983667601831, 0.024661695315444376, 0.06173023699375335, 0.06238622503587976, 0.029619054403156042, 0.032802478308440186, 0.020819368583033793, 0.10258031979901716, 0.04601353815814946, 0.035670552533701994, 0.024824823085509706, 0.04483670345507562, 0.029546162513724994, 0.07338175884797238, 0.004882415623796987, 0.03419487351493444, 0.015428425485879416, 0.02113798927894095, 0.040854554245015606, 0.05482554362970404, 0.10983155530993827, 0.027851410777657293, 0.029708514739468228, 0.05089947480882984, 0.02664746356458636, 0.012196942880109418, 0.024208974100474734, 0.025993134222517256, 0.036147875944152474, 0.005225416334724287, 0.07209040704765357, 0.03339224822411779, 0.11743833150831051, 0.04300371743738651, 0.10806311387568712, 0.06079523482185323, 0.01628208363399608, 0.03205001848982647, 0.06958936937735416, 0.011996350567642367, 0.02683299120690208, 0.01146071754192235, 0.01730752206640318, 0.041124139388557523, 0.04321020518545993, 0.08906860850402154, 0.1530847160029225, 0.22400590649340302, 0.05273494702123571, 0.013348578886507312, 0.09532125463010743, 0.20500695565715432, 0.09103634627535939, 0.08412638737354428, 0.056293292800546624, 0.12824421690311283, 0.030338429278344847, 0.1258095569210127, 0.3023965610191226, 0.14900854410370812, 0.018541780445957556, 0.06017592742864508, 0.05598069277766626, 0.0066504229016572936, 0.10221238524536602, 0.009847547316894634, 0.06168776017148048, 0.31113122357055545, 17.097254768013954, 70.31594127416611, 85.00681176781654, 37.689478397369385, 34.83648508787155, 53.074925020337105, 87.13396042585373, 106.49166449904442, 57.93490223586559, 16.73877440392971, 1.760237377602607, 0.00973562031504116, 0.1332189069944434, 0.2539343771059066, 0.30939780408516526, 0.7852283993270248, 0.5274393071886152, 0.13852003816282377, 1.0100283147767186, 0.4753551457542926, 23.964284285902977, 68.09730872511864, 90.59095412492752, 78.94558221101761, 75.17179191112518, 82.72134080529213, 89.80486750602722, 86.44353747367859, 79.80170667171478, 77.53955125808716, 84.35705423355103, 85.38645699620247, 77.3252123594284, 77.46284857392311, 74.57184210419655, 76.89414069056511, 76.21405318379402, 78.69942381978035, 78.4729939699173, 84.52070385217667, 79.75757583975792, 83.9425952732563, 79.0526756644249, 78.48981186747551, 72.85740450024605, 76.46875351667404, 71.04513734579086, 82.43282988667488, 59.36156988143921, 63.15661624073982, 45.97489960491657, 72.27508574724197, 85.28816387057304, 76.99792832136154, 81.07643947005272, 84.62025851011276, 78.71794402599335, 77.2636404633522, 76.56792059540749, 80.20481944084167, 79.66609194874763, 79.84346643090248, 77.58638754487038, 76.77961483597755, 75.40387585759163, 75.28232038021088, 67.00777038931847, 66.88349425792694, 77.4309378862381, 82.33681663870811, 75.6975544989109, 75.07409915328026, 77.02527925372124, 80.07361248135567, 79.220672249794, 95.15064105391502, 58.90908256173134, 86.42452329397202, 87.2293809056282, 74.32048559188843, 73.16742226481438, 61.094045117497444, 91.0347931087017, 63.21672901511192, 8.610325623303652, 0.4199613322271034, 0.17927985725691542, 3.128364533185959, 0.742523797089234, 0.21119373617693782, 0.09892320158542134, 0.1892868132563308, 0.6507682206574827, 15.568092372268438, 51.573640778660774, 83.78109633922577, 64.68839004635811, 17.857700362801552, 17.21497055143118, 56.83400250971317, 62.55337581038475, 42.174780517816544, 1.8055259599350393, 0.5258549109566957, 0.11848301568534225, 0.01624802462174557, 0.0709218361589592, 0.036621310500777327, 0.11339202363160439, 0.007103702118911315, 0.07993695631739683, 0.04994677241484169, 0.03552424182998948, 0.02993299400259275, 0.08890793353202753, 0.03606056226999499, 0.05331357730028685, 0.04583665468089748, 0.059407240551081486, 0.02142748810001649, 0.043670689265127294, 0.048395969497505575, 0.038099924713606015, 0.05612054308585357, 0.044164458668092266, 0.02837408126652008, 0.032604280349914916, 0.05344079254427925, 0.02248633431008784, 0.016534415699425153, 0.06639875777182169, 0.02465993085934315, 0.003718238713190658, 0.026166616808041, 0.07411328639136627, 0.020999066655349452, 0.16658567357808352, 0.14621814305428416, 0.16631459671771154, 0.23713200527708977, 0.25929241615813226, 0.2859126002294943, 0.14840575691778213, 0.19645450520329177, 0.104963920020964, 0.09599594108294696, 0.1472453644964844, 0.10303941977326758, 0.07506062305765226, 0.1752795625361614, 0.1142284982779529, 0.15933674614643678, 0.1613537551020272, 0.23579382395837456, 0.2512972295517102, 0.3298459912184626, 0.1252257835585624, 0.15477618930162862, 0.2408910426311195, 0.4646811028942466, 0.3128945961361751, 0.17310745955910534, 0.21135893824975938, 0.3077320090960711, 0.1896942820167169, 0.239188808191102, 0.731996699469164, 0.21116566815180704, 0.1615069343824871, 0.1631523499963805, 0.16443568660179153, 0.21830974495969713, 0.13511504977941513, 0.36468047357629985, 0.21157067298190668, 0.48222775978501886, 16.11716765910387, 80.21252542734146, 104.86983552575111, 71.68978795409203, 68.39006781578064, 56.396334394812584, 66.06197074055672, 106.95574879646301, 77.45094001293182, 27.89130136370659, 2.316055283881724, 0.3058475477155298, 0.6826256518252194, 0.8570660382974893, 1.3825231580995023, 0.8693888364359736, 0.30771980818826705, 0.3058579674689099, 0.6862212682608515, 0.45567377528641373, 20.695274099707603, 59.6352805942297, 90.14728993177414, 88.70670363306999, 84.75999981164932, 83.43613564968109, 89.3810610473156, 85.8847926557064, 81.20694726705551, 80.09668484330177, 86.66568115353584, 88.39743822813034, 87.72700220346451, 87.34372437000275, 80.4126986861229, 84.7578339278698, 86.44143998622894, 85.16960263252258, 86.7290997505188, 88.2828439772129, 85.41657418012619, 85.62000766396523, 84.24151763319969, 83.7669686973095, 78.66031631827354, 83.34733441472054, 78.52276369929314, 83.31790119409561, 65.47140643000603, 72.34405964612961, 52.25840963423252, 79.08010259270668, 92.15571016073227, 83.21805015206337, 91.1005599796772, 92.49478876590729, 84.55581396818161, 80.40988683700562, 79.98522162437439, 85.56414306163788, 84.37353774905205, 83.61899703741074, 80.35040482878685, 81.48022100329399, 80.02608463168144, 81.49147599935532, 73.15889552235603, 70.83186998963356, 82.08663806319237, 85.3014175593853, 80.33960580825806, 82.44954138994217, 84.87486764788628, 82.41075307130814, 88.8882502913475, 99.04828950762749, 55.95282979309559, 118.45990508794785, 97.50706940889359, 95.9780390560627, 81.8469849228859, 75.40907397866249, 96.20577603578568, 53.823462054133415, 4.840974435210228, 0.2574645954882726, 0.5004446057137102, 4.4154024962335825, 1.3849096675403416, 1.2815097346901894, 1.5458182082511485, 0.516850819112733, 0.9789103595539927, 25.24617400020361, 65.46731784939766, 76.40871673822403, 45.28437785804272, 25.851656310260296, 57.74724170565605, 76.40268266201019, 73.59979346394539, 53.547486662864685, 2.2671972680836916, 0.5069083557464182, 0.5668075103312731, 0.1393768476555124, 0.19067422865191475, 0.1791141356807202, 0.24100711452774704, 0.07337408504099585, 0.15588589303661138, 0.1724230361287482, 0.1728087302763015, 0.17199009686009958, 0.20779505604878068, 0.1633234298788011, 0.1346756686689332, 0.22701568639604375, 0.1602140537579544, 0.1975194425904192, 0.10146633387194015, 0.14915830950485542, 0.1462537216139026, 0.15216224128380418, 0.1578970390255563, 0.11237075421377085, 0.1164361352857668, 0.19641236605821177, 0.13662891229614615, 0.0520065439195605, 0.17625147913349792, 0.14210421068128198, 0.10958850194583647, 0.23445761675247923, 0.11426394325098954, 0.13126541103702039], [0.06575515246368013, 0.008682798488734988, 0.04204458062304184, 0.010787738028739113, 0.010521339481783798, 0.06955954246222973, 0.06282368398387916, 0.03793388030317146, 0.0010886307995860989, 0.07364816759945825, 0.05238808946160134, 0.05734699407184962, 0.11487442650832236, 0.014073217444092734, 0.01853750567534007, 0.06913679288118146, 0.0071396610292140394, 0.051100355631206185, 0.005298541072988883, 0.05325657293724362, 0.04740542128274683, 0.03430763172218576, 0.013859539212717209, 0.053071318034199066, 0.014595902775909053, 0.04395742173073813, 0.03611102460126858, 0.06500324554508552, 0.06789955106796697, 0.12967277696589008, 0.04294620841392316, 0.03378974994120654, 0.03585119869967457, 0.03912478241545614, 0.047927885825629346, 0.08026256618904881, 0.048393835822935216, 0.06238408022909425, 0.061968384761712514, 0.23083106760168448, 0.4247897450113669, 2.032473888248205, 38.88732232153416, 72.28961616754532, 80.1055383682251, 52.465931698679924, 27.97700386494398, 34.55591954290867, 64.49766308069229, 89.29923623800278, 51.50916203856468, 10.197827238589525, 0.22832519112853333, 0.25841101189143956, 0.20256943098502234, 0.020480908424360678, 0.16092111269244924, 0.24753035511821508, 0.7786850910633802, 0.22014319110894576, 0.3689989121630788, 0.30655564565677196, 13.186691757291555, 65.16975581645966, 87.02009573578835, 83.12386080622673, 65.31253695487976, 74.17282551527023, 83.63738045096397, 95.60196563601494, 87.20437064766884, 82.76683196425438, 75.76187744736671, 82.06233456730843, 76.62677183747292, 77.62313157320023, 74.77564796805382, 77.33173280954361, 79.99324679374695, 75.99531412124634, 81.91692396998405, 79.00540620088577, 81.41924947500229, 76.78844556212425, 81.89217209815979, 77.66500532627106, 87.09235265851021, 80.19313126802444, 62.58410096168518, 68.27571675181389, 31.031889840960503, 71.79050534963608, 76.26782789826393, 81.01504996418953, 75.98823890089989, 76.5741902589798, 76.99392333626747, 83.0799351632595, 81.22292920947075, 82.87710964679718, 81.02419227361679, 81.0934853553772, 79.85646173357964, 85.03946721553802, 86.02144852280617, 79.98845905065536, 75.22620499134064, 76.89189121127129, 84.73020941019058, 84.96127501130104, 77.2423768043518, 76.3165032863617, 76.68246164917946, 84.44821134209633, 76.41204535961151, 73.49336877465248, 66.75089657306671, 61.02974496781826, 59.91741165518761, 76.27848252654076, 73.02011176943779, 57.49167501926422, 11.632103025913239, 0.14116126752924174, 0.09748720520292409, 0.9422048041597009, 0.1408862869720906, 0.5391459446400404, 0.6938458560034633, 0.2642013964941725, 0.08189677537302487, 3.567471345886588, 37.77466222643852, 64.02652636170387, 42.39248983561993, 18.50949078798294, 22.605859078466892, 60.93153543770313, 62.410663068294525, 42.44581617414951, 15.225642397999763, 0.1016048260498792, 0.06212954584043473, 0.0385051187913632, 0.04983468214049935, 0.04888817296887282, 0.024354140041396022, 0.02763197997410316, 0.06691878064884804, 0.021654622396454215, 0.08208038270822726, 0.052930417587049305, 0.022746080430806614, 0.02716965536819771, 0.0033377709087289986, 0.027802158147096634, 0.05680055073753465, 0.10259332964778878, 0.021295131627994124, 0.06452647503465414, 0.08556762331863865, 0.04084999003680423, 0.03850921173579991, 0.034339332560193725, 0.08127052889904007, 0.042116324038943276, 0.03636145862401463, 0.05134126047778409, 0.04929790899041109, 0.05050869323895313, 0.046139261685311794, 0.07128279452444986, 0.07776070473482832, 0.06880718283355236, 0.03661698749056086, 0.04172537548583932, 0.051708790560951456, 0.09041936180437915, 0.014304756386991357, 0.05378947578719817, 0.03408436772588175, 0.036746566474903375, 0.050171565235359594, 0.06374284872435965, 0.06100651684391778, 0.06926598594873212, 0.06095316755818203, 0.05953253734332975, 0.05255336574919056, 0.0492682713229442, 0.020250161724106874, 0.011897199638042366, 0.07073742730426602, 0.06149548826215323, 0.013950184202258242, 0.037027024081908166, 0.034167699777754024, 0.020106856718484778, 0.021738633513450623, 0.05844649327627849, 0.020156819955445826, 0.0674705600249581, 0.05210271512623876, 0.08074933342868462, 0.14241779776057228, 0.09767144336365163, 0.13242789631476626, 0.038381458434741944, 0.036747323465533555, 0.01743066663038917, 0.13327854598173872, 0.1331241347361356, 0.007537154397141421, 0.09602091435226612, 0.008557194632885512, 0.04312258352001663, 0.2850546775152907, 5.3170722629874945, 55.02327807247639, 84.6149691939354, 82.90776640176773, 36.23031489551067, 17.729305252432823, 62.66490742564201, 94.17654052376747, 97.54484698176384, 46.52608282864094, 10.519026853144169, 0.6040593457873911, 0.19490390637656674, 0.3212423325749114, 0.2306646780925803, 0.2652705938089639, 1.4485386782325804, 1.098099157679826, 0.31326261232607067, 0.5542646208778024, 0.9086277871392667, 24.928011372685432, 83.06560233235359, 93.01697194576263, 76.28507897257805, 62.491192147135735, 75.28482064604759, 88.48830655217171, 94.06154349446297, 77.913116812706, 84.2499303817749, 81.82988584041595, 81.79449453949928, 80.37476152181625, 78.06486546993256, 79.30287703871727, 79.69499319791794, 82.2593691945076, 78.12966719269753, 79.65496614575386, 77.81575083732605, 77.42418184876442, 74.82684642076492, 79.45933744311333, 81.75428509712219, 88.38804513216019, 80.0389051437378, 60.16730144619942, 73.68870869278908, 43.48371148109436, 75.64993545413017, 76.5696533024311, 77.24044650793076, 77.21966922283173, 77.92678087949753, 76.6434833407402, 80.42092904448509, 82.65612110495567, 84.7502951323986, 83.60108479857445, 84.35989648103714, 79.3775050342083, 83.76836702227592, 84.63326141238213, 83.22406902909279, 75.754574239254, 73.19905936717987, 82.30916172266006, 83.00745785236359, 75.20694762468338, 76.35751068592072, 79.65085476636887, 80.22305086255074, 74.35327783226967, 79.71902310848236, 62.068153247237206, 78.89666363596916, 68.10132130980492, 90.54290190339088, 89.15671348571777, 74.89461958408356, 21.656732708215714, 0.1154218049487099, 0.178358243429102, 1.3890442019328475, 0.518649488221854, 0.2906326297670603, 0.12420029874192551, 0.23755456932121888, 0.1298222751938738, 4.5067149214446545, 37.29344084858894, 79.13447007536888, 63.869336396455765, 32.06585995852947, 13.308027796447277, 35.112874656915665, 67.54539594054222, 54.780478700995445, 24.76047456264496, 0.2182946348330006, 0.32847580849193037, 0.07334304842515849, 0.017221180605702102, 0.06561597008840181, 0.04691522532084491, 0.033533070745761506, 0.04014045975054614, 0.043796750469482504, 0.015817243147466797, 0.0428299398481613, 0.03534327282977756, 0.05417068365204614, 0.029088498595228884, 0.07097763824276626, 0.04019124862679746, 0.051268474344396964, 0.04732172186777461, 0.058620118725229986, 0.07411670027067885, 0.05727035990275908, 0.061863897790317424, 0.06970901842578314, 0.06174205198476557, 0.034133297522203065, 0.04125685023609549, 0.050014326407108456, 0.051865031200577505, 0.07582011472550221, 0.033767967906896956, 0.06628526112763211, 0.07450407167198136, 0.04995178562239744, 0.021694004462915473, 0.029886338888900355, 0.17355608782963827, 0.131361682433635, 0.11477768755867146, 0.11045331179047935, 0.09630583226680756, 0.14513527537928894, 0.19444506615400314, 0.2239496962283738, 0.07169002579757944, 0.2600871672620997, 0.20376065222080797, 0.17182667594170198, 0.2241632269578986, 0.12560325470985845, 0.19554182683350518, 0.18145420151995495, 0.11272471412667073, 0.2490801375824958, 0.08622057968750596, 0.14674585458124056, 0.1148307511175517, 0.0789157314284239, 0.15268817165633664, 0.1619153976207599, 0.13006905413931236, 0.1599347242154181, 0.10588801262201741, 0.18237580050481483, 0.22862872952828184, 0.3498688683612272, 0.10856555527425371, 0.0981042193598114, 0.13248225121060386, 0.13602896011434495, 0.1901872016605921, 0.194842501077801, 0.12424194806953892, 0.179461520165205, 0.14364851609570906, 0.5481610202696174, 0.5028510047122836, 4.398558950051665, 63.23543541133404, 100.88509574532509, 97.83167079091072, 65.44997557997704, 39.81683984398842, 55.98643898963928, 76.05763077735901, 104.34816911816597, 69.61316898465157, 17.152486704289913, 0.6826358044054359, 0.6370398541912436, 1.1871104501187801, 0.8460902085062116, 1.5149290720000863, 1.808607594575733, 1.6282294923439622, 0.19118487078230828, 0.7578390534035861, 0.4913466767175123, 20.763660930097103, 75.50602197647095, 91.00098252296448, 81.91875547170639, 69.68532711267471, 81.30481481552124, 93.0620527267456, 99.74851593375206, 85.38245961070061, 93.72904613614082, 85.16193464398384, 84.86190274357796, 86.19964376091957, 84.8351901769638, 85.4836405813694, 89.05281946063042, 88.38296100497246, 82.82553121447563, 87.14599058032036, 88.47848027944565, 87.97864750027657, 83.98934796452522, 88.51214647293091, 89.6685916185379, 96.43581569194794, 83.46162468194962, 69.4449520111084, 78.73450353741646, 50.145016238093376, 77.53731697797775, 75.57264000177383, 80.9512285888195, 78.50363552570343, 78.89854073524475, 82.13527545332909, 88.2169859111309, 88.85551124811172, 92.16324135661125, 90.04430785775185, 90.48989474773407, 87.13834539055824, 91.65356710553169, 93.38029325008392, 93.63801822066307, 85.13089790940285, 84.98759239912033, 91.32119134068489, 91.7653115093708, 78.38268041610718, 77.98665046691895, 82.43088439106941, 92.14764699339867, 82.40680128335953, 84.80999752879143, 74.18318375945091, 84.88888889551163, 83.6092771589756, 98.06680217385292, 86.27656683325768, 64.36067283153534, 13.685032166540623, 0.09956693305866793, 0.2989714010618627, 2.0255271485075355, 0.8112228044774383, 1.2663233745843172, 2.089820886030793, 0.7698632113169879, 0.23698461474850774, 7.662394288927317, 54.3042578548193, 80.62268301844597, 49.21678684651852, 29.45611249655485, 35.129802748560905, 77.87467807531357, 78.87995213270187, 65.75360208749771, 27.313920445740223, 0.3256338875507936, 0.5040957941673696, 0.18558658368419856, 0.09355997492093593, 0.11147715646075085, 0.11674371839035302, 0.08475685666780919, 0.23882472538389266, 0.15496723295655102, 0.19158257287926972, 0.11000712518580258, 0.28331659734249115, 0.1539797757868655, 0.09280734811909497, 0.11907103413250297, 0.13773462327662855, 0.3109000890981406, 0.14653181919129565, 0.17491262988187373, 0.11131374296383001, 0.11921650992007926, 0.26306243729777634, 0.11924509744858369, 0.15983293124008924, 0.11689173232298344, 0.1702929090242833, 0.1671826868550852, 0.22038683819118887, 0.1318784398608841, 0.13539795647375286, 0.12505436228821054, 0.22599213116336614, 0.1797843395615928, 0.17967277992283925, 0.17377546668285504], [0.03368295117979869, 0.07541039725765586, 0.06768498133169487, 0.04721575431176461, 0.07036337745375931, 0.08829709404380992, 0.03847622327157296, 0.030122731477604248, 0.10780817872728221, 0.05013532987504732, 0.05027172177506145, 0.043231215386185795, 0.037022166725364514, 0.055315309145953506, 0.013735618176724529, 0.07658345813979395, 0.06413868060917594, 0.06365613618982024, 0.050098040665034205, 0.050111410455428995, 0.05745651280449238, 0.05775789155450184, 0.03644635660748463, 0.051289762850501575, 0.019602576649049297, 0.1082236404181458, 0.02718721458222717, 0.013102924294798868, 0.0876890895597171, 0.013962351713416865, 0.041038291456061415, 0.014653212347184308, 0.03486496978439391, 0.10339476750232279, 0.07296134703210555, 0.02399879231234081, 0.07204126944998279, 0.035239754361100495, 0.1062679105962161, 0.1662696967832744, 0.06448875166825019, 0.2872632199432701, 0.02761874748102855, 18.97920448333025, 63.37694361805916, 75.20836874842644, 71.68570697307587, 45.24604931473732, 28.139895424246788, 34.31573823094368, 72.91629374027252, 78.65359827876091, 39.23317216336727, 4.854440437629819, 0.13037057389738038, 0.36600342602469027, 1.6827323427423835, 0.9516003343742341, 0.8768384554423392, 0.6627306318841875, 0.7010731869377196, 0.09052352965227328, 0.19710376567672938, 0.27007564378436655, 14.921904746443033, 62.7928351610899, 102.01295122504234, 94.81724694371223, 75.08787721395493, 75.99832355976105, 83.43367338180542, 93.46055254340172, 93.61008211970329, 77.70376324653625, 75.65672188997269, 81.63210645318031, 79.4212406873703, 83.12161892652512, 79.99029815196991, 76.01615980267525, 70.11386811733246, 74.67550054192543, 69.04787331819534, 74.52955037355423, 71.73457235097885, 85.85816368460655, 72.76899084448814, 78.13810274004936, 66.69994130730629, 38.6056624352932, 7.3277239222079515, 23.7566976249218, 107.36103504896164, 82.87311226129532, 91.81625157594681, 82.64288261532784, 82.96464174985886, 81.93766325712204, 78.49600553512573, 80.29197156429291, 82.92994201183319, 80.08751213550568, 80.76057761907578, 85.03543183207512, 82.30717062950134, 83.78105074167252, 81.79317221045494, 80.71510925889015, 81.80077940225601, 88.87049004435539, 87.479088306427, 87.3010678589344, 81.54585868120193, 75.05439341068268, 76.56282886862755, 78.3532851934433, 73.96520465612411, 58.07555168867111, 38.48496571183205, 20.244633480906487, 5.396753987297416, 0.027533192696864717, 0.20484270353335887, 0.3430509060854092, 0.13958124996861443, 0.3618332982296124, 0.2737765561323613, 0.5831345217302442, 0.19104337290627882, 1.419249374885112, 16.033038273453712, 58.66055689752102, 58.18601556122303, 27.474475130438805, 28.637723810970783, 44.697009176015854, 59.339614659547806, 56.63640171289444, 34.83116917312145, 5.541779855266213, 0.3819224640028551, 0.06154020637040958, 0.09230455048964359, 0.037968115575495176, 0.024449884513160214, 0.050342897447990254, 0.05355266388505697, 0.04502816642343532, 0.0825200680992566, 0.03158970139338635, 0.040135149683919735, 0.02489135105861351, 0.039217684461618774, 0.019396068491914775, 0.11842611522297375, 0.01516416710728663, 0.0193135991867166, 0.02526779248000821, 0.10480197597644292, 0.029485671911970712, 0.02563202186138369, 0.027979242004221305, 0.04448000130651053, 0.016170548115042038, 0.032164940057555214, 0.03558296426490415, 0.10212516062892973, 0.05921309471887071, 0.0774861397803761, 0.0607001174648758, 0.02939538779173745, 0.03664802781713661, 0.02311828975507524, 0.015815109472896438, 0.08412768613197841, 0.03817773518676404, 0.1256394269876182, 0.03600280462705996, 0.005395620482886443, 0.0679874287743587, 0.08207417093217373, 0.04448733001481742, 0.060149180426378734, 0.05442763744213153, 0.06887030991492793, 0.04097542041563429, 0.056822406986611895, 0.031693724522483535, 0.08192489534849301, 0.08032087673200294, 0.06581720343092456, 0.09194516547722742, 0.005124872950545978, 0.05190434276300948, 0.08018334934604354, 0.057307003444293514, 0.08561693161027506, 0.04382053259178065, 0.022449006137321703, 0.0397478265222162, 0.026309992317692377, 0.036178478403599, 0.03328124890686013, 0.037513249553740025, 0.04254146333551034, 0.033734055468812585, 0.01806098563974956, 0.011608607164816931, 0.026055849411932286, 0.04658435733290389, 0.04221656592562795, 0.05348941063857637, 0.037874679183005355, 0.019838343978335615, 0.07375001994660124, 0.10693973978050053, 0.10840108792763203, 0.4156663455069065, 0.735357025405392, 29.39419101923704, 74.50373455882072, 82.52346262335777, 54.71000388264656, 26.154505759477615, 30.772853940725327, 60.27923583984375, 105.58896973729134, 87.97459691762924, 34.70123514533043, 4.977692048996687, 0.3163344506174326, 0.48510785680264235, 0.4409764608135447, 1.2029468128457665, 0.5148503452073783, 0.9773617051541805, 2.0440038945525885, 0.2681827516062185, 0.240366448124405, 1.4016824425198138, 24.423311054706573, 83.19772124290466, 101.77487879991531, 87.91202947497368, 68.47395211458206, 77.88127452135086, 94.31020215153694, 93.78108814358711, 88.04082736372948, 86.1105689406395, 82.0826330780983, 87.03819036483765, 83.66854637861252, 85.46330407261848, 84.92819398641586, 84.03021857142448, 77.80993714928627, 82.98956081271172, 82.14526131749153, 84.40039470791817, 81.79029956459999, 83.83747011423111, 76.65538430213928, 76.65134131908417, 78.83310064673424, 61.349748596549034, 17.584873102605343, 36.365804225206375, 95.21229654550552, 80.01727670431137, 82.45749816298485, 77.30799928307533, 81.88271820545197, 80.44163033366203, 78.54040995240211, 78.64330843091011, 80.0637786090374, 79.15932834148407, 78.80897954106331, 81.07139334082603, 82.09208697080612, 80.75496152043343, 79.342090934515, 78.37676793336868, 84.61459681391716, 86.47369265556335, 81.40959799289703, 75.74442878365517, 74.71086144447327, 78.89696761965752, 76.23698875308037, 80.68901225924492, 83.23345452547073, 73.5016143321991, 59.91626791656017, 36.49345837533474, 13.042377401143312, 0.22211380099179223, 0.20314042456448078, 0.34285946167074144, 0.4927491577109322, 0.15383259305963293, 0.4490138904657215, 0.29962226457428187, 0.13685529702343047, 2.278447039425373, 17.927658408880234, 63.52262020111084, 82.18886777758598, 43.47692884504795, 24.242326766252518, 20.366597436368465, 50.89095801115036, 65.31551599502563, 43.338228687644005, 8.045649323612452, 0.3470672608818859, 0.11833834883873351, 0.058047510974574834, 0.06387824614648707, 0.056895634697866626, 0.06788490849430673, 0.112562473223079, 0.09810595598537475, 0.07946526951855049, 0.04657358134863898, 0.04262751535861753, 0.06250168094993569, 0.02047261492407415, 0.06487663515144959, 0.10886975418543443, 0.0592460720508825, 0.020148795483692084, 0.04730659689812455, 0.03370739010279067, 0.05997964421112556, 0.029436992590490263, 0.12543428252683952, 0.010578448673186358, 0.1208497914194595, 0.05752543976996094, 0.05145622657437343, 0.04966435182723217, 0.038571578115806915, 0.052108099407632835, 0.009987243629439035, 0.03652308354503475, 0.008889159144018777, 0.015720995870651677, 0.027919762578676455, 0.061953385957167484, 0.03270012130087707, 0.16687922267010435, 0.1848756952676922, 0.27131972077768296, 0.16447859758045524, 0.16032034414820373, 0.1222817505185958, 0.20801796752493829, 0.14102447486948222, 0.20361660135677084, 0.1597861759364605, 0.17690102162305266, 0.1125361121376045, 0.2210191628546454, 0.1252791885053739, 0.09450526325963438, 0.22914662986295298, 0.15472392726223916, 0.17579013045178726, 0.15642752725398168, 0.12776835181284696, 0.15448167541762814, 0.18011107749771327, 0.11615831972449087, 0.18802997132297605, 0.11231868513277732, 0.15667896688682958, 0.17752025480149314, 0.08598564541898668, 0.18305443518329412, 0.09709211546578445, 0.10037674233899452, 0.14318001311039552, 0.1039796021359507, 0.14539109368342906, 0.09767470881342888, 0.11062038407544605, 0.14805328130023554, 0.1716501041664742, 0.18066857883241028, 0.2723038976546377, 0.25849632918834686, 0.3229991445550695, 0.6721026508603245, 29.75413240492344, 88.92051815986633, 101.3086286187172, 88.10294643044472, 59.48749132454395, 42.35378511250019, 48.78579877316952, 87.17866882681847, 96.85044184327126, 53.61219719052315, 8.778280410915613, 0.5919206002727151, 0.7976095599588007, 3.5674801329150796, 4.093474745750427, 3.5751882568001747, 3.3942597778514028, 1.7198071908205748, 0.13323762395884842, 0.4006498184753582, 0.5505654599983245, 17.713211216032505, 73.71540606021881, 105.8210688829422, 89.45563584566116, 66.81784898042679, 76.90792635083199, 94.20493260025978, 88.83142814040184, 98.33465740084648, 97.87968501448631, 87.01419085264206, 99.3883940577507, 93.10358449816704, 95.6348566710949, 94.90853324532509, 93.831587433815, 83.47803980112076, 89.99373257160187, 88.09159263968468, 89.93550449609756, 86.46793976426125, 94.79688763618469, 80.61742410063744, 83.19829121232033, 96.79787546396255, 62.80376337468624, 13.756122551858425, 28.661278747022152, 107.0510932803154, 83.73049825429916, 90.95925316214561, 87.06394538283348, 87.67052963376045, 86.31385803222656, 81.35931149125099, 81.53388172388077, 84.35573190450668, 83.16407024860382, 81.01178213953972, 83.74291598796844, 82.26274341344833, 86.41535818576813, 86.27048715949059, 85.54144307971, 90.26297092437744, 92.6095350086689, 91.40519723296165, 86.67451187968254, 83.13363388180733, 83.81360739469528, 87.52451106905937, 95.30425921082497, 94.2950713634491, 77.42299631237984, 50.98854057490826, 25.429080985486507, 7.159730661660433, 0.12477651704102755, 0.17891363706439734, 0.6831788190174848, 0.5955790320876986, 0.2782775927335024, 0.8245716069359332, 1.0430094762705266, 0.15432208398124203, 3.500778512097895, 27.97519326210022, 78.46633672714233, 71.92647725343704, 41.026865914464, 44.719640761613846, 59.55303020775318, 74.7307875752449, 74.55693930387497, 51.44905686378479, 9.188504498451948, 0.31599718902725726, 0.33206848602276295, 0.2834797214018181, 0.2367310377303511, 0.21724612859543413, 0.217999838932883, 0.1902495272224769, 0.1909156344481744, 0.2007779903942719, 0.18422276858473197, 0.1330503058852628, 0.1231470204947982, 0.10462705176905729, 0.14332501392345876, 0.3060992545215413, 0.13812965364195406, 0.11093423090642318, 0.2365363427088596, 0.18301235541002825, 0.11901169942575507, 0.13148087135050446, 0.336544259916991, 0.12455991382012144, 0.24586551007814705, 0.14893873769324273, 0.1582121549290605, 0.15465342323295772, 0.21424618957098573, 0.12291728868149221, 0.142202693677973, 0.11272803894826211, 0.12557319772895426, 0.11869716981891543, 0.10365830414230004, 0.2800117543665692, 0.1653396076289937], [0.05312300490913913, 0.03304704565380234, 0.010378294227848528, 0.01036793384628254, 0.046008921999600716, 0.03571115172235295, 0.038688941349391825, 0.1489816338289529, 0.04249506055202801, 0.10485011167475022, 0.013567509668064304, 0.04989285909687169, 0.00797972674263292, 0.05074427688668948, 0.015497742078878218, 0.033718277409207076, 0.019510906568029895, 0.08154265960911289, 0.018167459711548872, 0.037681772737414576, 0.039169133160612546, 0.08871717931469902, 0.09176417792332359, 0.026397942383482587, 0.0431851131725125, 0.1024067314574495, 0.06624751549679786, 0.011008243091055192, 0.04081604420207441, 0.07057097100187093, 0.038613498327322304, 0.022744562738807872, 0.02133289210178191, 0.010339453001506627, 0.024585369137639645, 0.0747244301601313, 0.04378831225039903, 0.0698298029601574, 0.032748242156230845, 0.022882999255671166, 0.08613449797849171, 0.08232259002397768, 0.02633750187669648, 0.32739862566813827, 3.1371909845620394, 32.03557178378105, 63.95298510789871, 71.23701944947243, 62.11415357887745, 42.20946125686169, 23.514922298491, 44.166652634739876, 76.78912952542305, 75.73763474822044, 33.700729832053185, 3.5473305266350508, 0.42320659558754414, 0.4030227614566684, 1.6199519927613437, 1.6252680262550712, 0.7269531232304871, 0.23166153085185215, 0.3391875821398571, 0.2366400504251942, 0.5284518341068178, 0.023902272296254523, 9.152674321085215, 45.3179794549942, 81.12955302000046, 93.19759145379066, 88.83420199155807, 62.331513315439224, 62.076976373791695, 76.64340734481812, 68.65232974290848, 72.92071670293808, 77.76679426431656, 74.87505823373795, 78.02212536334991, 71.31317496299744, 71.45192831754684, 65.6982010602951, 71.1502169072628, 69.89528864622116, 71.1575049161911, 68.97943899035454, 70.04928678274155, 55.27580492198467, 13.717701863497496, 4.0825071092695, 0.551829842152074, 0.5082573427353054, 54.26441319286823, 106.25695869326591, 76.52158588171005, 80.0455167889595, 84.57071676850319, 91.7828057706356, 90.3430326282978, 88.81084084510803, 88.95723938941956, 85.23578748106956, 90.52414610981941, 86.0818500816822, 90.32790184020996, 90.87001875042915, 92.5493386387825, 88.98670300841331, 99.74438935518265, 92.51190304756165, 85.19674837589264, 83.76215815544128, 80.76647490262985, 72.46265888214111, 51.32807895541191, 30.24804700165987, 12.69508933648467, 2.845035823993385, 0.008556098109693266, 0.4056542686885223, 0.10746227853815071, 0.4287874570582062, 0.1993040257366374, 0.46174329647328705, 0.25957648060284555, 0.7795157027430832, 0.1609911269042641, 0.4722185031278059, 13.244731742888689, 43.33459608256817, 66.93454071879387, 43.407430574297905, 16.291280016303062, 30.179234594106674, 59.50600013136864, 59.68077935278416, 43.22196252644062, 15.568346958607435, 0.5552932375576347, 0.29745955718681216, 0.1218974293442443, 0.07736583022051491, 0.020663302348111756, 0.030201564259186853, 0.05070847568276804, 0.0663052694289945, 0.0939380843192339, 0.05674554646247998, 0.032915347837843, 0.08814176253508776, 0.04029983225336764, 0.028529305163829122, 0.05207940055697691, 0.030925373466743622, 0.051601156883407384, 0.11767397081712261, 0.07671912273508497, 0.05463904562930111, 0.12807509629055858, 0.06667167515843175, 0.10248490929370746, 0.0643706537084654, 0.05567587788391393, 0.012231600248924224, 0.14451684372033924, 0.029142788553144783, 0.08079532432020642, 0.08158991957316175, 0.03415776613110211, 0.07286168402060866, 0.0837996717018541, 0.04826092459552456, 0.051059455872746184, 0.058631651700125076, 0.05383147392421961, 0.026890285007539205, 0.03826870393822901, 0.029620410678035114, 0.010689848750189412, 0.06533908963319845, 0.05741152381233405, 0.021200615410634782, 0.038668090710416436, 0.042437599768163636, 0.051991908767377026, 0.10546688092290424, 0.00267470927155955, 0.08542237759684213, 0.06157236362923868, 0.023576434214191977, 0.08723663180717267, 0.03301001248473767, 0.013104555164318299, 0.03775567209231667, 0.02426636066957144, 0.058419853885425255, 0.06137538279290311, 0.032190533020184375, 0.0447773501946358, 0.011422368916100822, 0.0759927902254276, 0.025745444290805608, 0.04371279130282346, 0.03344748998642899, 0.035775729702436365, 0.03720199652889278, 0.042676456287153997, 0.016244037433352787, 0.13428531383397058, 0.02660366015334148, 0.0672178364766296, 0.04354674689238891, 0.023525561846327037, 0.04516785345913377, 0.022544889761775266, 0.08476308328681625, 0.05663887015543878, 0.12873485073214397, 0.13516805396648124, 0.12877393222879618, 8.9771275408566, 47.541194558143616, 80.05972802639008, 76.5157949924469, 41.07735760509968, 21.642415076494217, 30.62242951244116, 73.44601571559906, 107.97491490840912, 86.81818976998329, 29.70051348209381, 2.568699214607477, 0.3112723503727466, 0.4955445014638826, 1.37402847642079, 0.7770036219153553, 0.08286901109386235, 0.863216839497909, 0.7770553941372782, 0.24722279427805915, 0.5667192838154733, 0.19783448427915573, 23.245670646429062, 70.22695004940033, 87.48676389455795, 84.56562504172325, 73.10610875487328, 77.94511869549751, 75.81600934267044, 82.63149842619896, 79.2618316411972, 77.60217949748039, 87.37149327993393, 82.73798391222954, 83.87890309095383, 79.36269342899323, 73.34955409169197, 69.07655417919159, 69.10065248608589, 73.119415640831, 73.552987575531, 79.65300545096397, 81.4868326485157, 81.55015245079994, 38.94099064171314, 9.89951379597187, 0.8660681114997715, 2.7141684712842107, 71.0882118344307, 91.51669085025787, 81.52427583932877, 81.75476387143135, 83.60729366540909, 86.7667481303215, 87.02596262097359, 87.61776566505432, 87.91944667696953, 84.58913818001747, 87.00640127062798, 84.91770654916763, 86.67794689536095, 86.20801091194153, 89.51207041740417, 84.95450377464294, 88.4951613843441, 83.40324461460114, 84.15883406996727, 89.61024194955826, 87.12513729929924, 82.22847685217857, 71.0283574461937, 54.64216612279415, 31.596053168177605, 10.022264309227467, 0.9250594710465521, 0.47573108808137476, 0.014248140723793767, 0.4388348007341847, 0.9790460241492838, 0.2275400434155017, 0.38980923767667264, 0.7064246060326695, 0.14685992267914116, 0.996520989574492, 11.398824043571949, 44.871051236987114, 76.2738011777401, 64.69337537884712, 25.281715393066406, 19.489619694650173, 51.851546466350555, 68.8923628628254, 56.41162097454071, 19.580157436430454, 0.7248802157118917, 0.6338935042731464, 0.041354791464982554, 0.08327667281264439, 0.018807543528964743, 0.06016092862410005, 0.007673392765354947, 0.04267670119588729, 0.07258702258695848, 0.03669287951197475, 0.03694696119055152, 0.02539997083658818, 0.10211052547674626, 0.012584739160956815, 0.04686777981987689, 0.07416579333948903, 0.051338317862246186, 0.04660103710193653, 0.02084188163280487, 0.08010875608306378, 0.10471107772900723, 0.013750039961450966, 0.028142302980995737, 0.06140885365311988, 0.06791035673813894, 0.06292204823694192, 0.06305585746304132, 0.02672890499525238, 0.03904807032085955, 0.03516768440022133, 0.04159039366641082, 0.0856900034705177, 0.020290937172831036, 0.05336648129741661, 0.020211672090226784, 0.07115882617654279, 0.04363947453384753, 0.07100736125721596, 0.16842722397996113, 0.12425831242580898, 0.1501368312165141, 0.1551303718588315, 0.20448650233447552, 0.15891771472524852, 0.0999361886351835, 0.15255841455655172, 0.15853518212679774, 0.1494482220732607, 0.10794527566758916, 0.10946835565846413, 0.13934089802205563, 0.08499985808157362, 0.15779304929310456, 0.1886737992754206, 0.13413841312285513, 0.10142531536985189, 0.061223906741361134, 0.10952925629680976, 0.17620988917769864, 0.12710859737126157, 0.19410010107094422, 0.05559983001148794, 0.23277423286344856, 0.11292907191091217, 0.10695611155824736, 0.12195735034765676, 0.13371028297115117, 0.13194493629271165, 0.12274655760847963, 0.14109000650933012, 0.33053957275114954, 0.09550144066452049, 0.12627936608623713, 0.1650995822274126, 0.10297726490534842, 0.28349560336209834, 0.11679252202156931, 0.14669418625999242, 0.24307580664753914, 0.20255604264093563, 0.22400249261409044, 0.42378158192150295, 7.5462359469383955, 54.5850095897913, 96.72027602791786, 98.87197136878967, 78.24588015675545, 59.38596837222576, 41.18364930152893, 61.72817029058933, 93.71714517474174, 96.72198593616486, 47.58889339864254, 6.514312494546175, 0.48464585503097624, 0.6438280711881816, 3.03441243711859, 7.6721925381571054, 7.533964980393648, 1.7153373244218528, 0.8842324430588633, 0.2361705678049475, 0.9190362598747015, 0.12891465827124193, 14.820566084235907, 58.6922661960125, 80.8166778087616, 80.83294093608856, 79.68780398368835, 97.909946590662, 64.36514899134636, 86.28124058246613, 82.18460440635681, 75.08444979786873, 100.54652631282806, 88.73738318681717, 92.04656481742859, 83.99260058999062, 86.79555058479309, 75.08763402700424, 81.845533400774, 85.78255534172058, 86.55343517661095, 88.88520285487175, 99.54925462603569, 89.13969799876213, 29.427304342389107, 5.154676102101803, 1.1146555817686021, 1.3773481920361519, 57.66754098236561, 110.5201019346714, 82.88174539804459, 81.03503689169884, 87.36221417784691, 93.61218720674515, 99.66678231954575, 97.97561466693878, 100.79051122069359, 93.37722301483154, 97.81216263771057, 93.29574778676033, 95.1993316411972, 96.02347701787949, 102.20976546406746, 99.24225389957428, 104.19888272881508, 91.94896325469017, 89.57568660378456, 99.67709496617317, 103.30320999026299, 96.0660271346569, 64.9614205956459, 41.68762005865574, 18.28303813934326, 4.061023537069559, 0.24826861394103616, 0.39671361562795937, 0.3146652120631188, 1.0753405163995922, 0.8893577149137855, 0.4610774415777996, 0.8140234916936606, 1.864528600126505, 0.18802550359396264, 1.6283148690126836, 22.56918154656887, 61.86904393136501, 77.415069937706, 53.15269164741039, 27.94218633323908, 45.774319767951965, 74.10613909363747, 77.86111280322075, 65.85624977946281, 23.91721621155739, 0.7288662018254399, 0.5283854564186186, 0.3709266259102151, 0.2800251427106559, 0.1971763328765519, 0.12110425901482813, 0.17722024902468547, 0.09322680998593569, 0.28877025470137596, 0.17900092847412452, 0.1465697429375723, 0.24545649765059352, 0.160161598760169, 0.21999572636559606, 0.14577512542018667, 0.15538544801529497, 0.12148685098509304, 0.31161715218331665, 0.20162976812571287, 0.1260187683510594, 0.23547317163320258, 0.0907026618369855, 0.20288059866288677, 0.18122799490811303, 0.15396631322801113, 0.12159083329606801, 0.1969850220484659, 0.12472915317630395, 0.26176353043410927, 0.11433093692176044, 0.13039607409154996, 0.10458897217176855, 0.12134100412367843, 0.15402427496155724, 0.17056964104995131, 0.11609152643359266, 0.12548951315693557, 0.19264399248640984], [0.1082770453649573, 0.04396023818117101, 0.026725880743470043, 0.13141965901013464, 0.00926191301914514, 0.02057775498542469, 0.11707114652381279, 0.07430962898069993, 0.030936557632230688, 0.038100807869341224, 0.03219494137738366, 0.03750497089640703, 0.035517799988156185, 0.05644247190502938, 0.021828689423273318, 0.10513204615563154, 0.017200634247274138, 0.01070582626198302, 0.027144563355250284, 0.01200395201522042, 0.049078982847277075, 0.06582832080312073, 0.04011942357465159, 0.004730755890705041, 0.053916895121801645, 0.051588673959486187, 0.030753193350392394, 0.023547894925286528, 0.054585403195233084, 0.007392430961772334, 0.02483593674696749, 0.055949938177946024, 0.013304050953593105, 0.047327506908914074, 0.1261343652731739, 0.006263346967898542, 0.04908306465949863, 0.010428453206259292, 0.026644752870197408, 0.08839214089675806, 0.053413385030580685, 0.0989197580202017, 0.025693753705127165, 0.08837760222377256, 0.17424723511794582, 0.39814907766412944, 11.324392687529325, 42.103188559412956, 67.35210031270981, 80.4127062857151, 72.46725663542747, 34.20327186584473, 22.72779643535614, 45.50472043454647, 71.73154771327972, 77.6304879784584, 34.894849956035614, 3.482366125099361, 0.5400751729030162, 0.46039736713282764, 1.6932576592080295, 1.1989211663603783, 1.1603185627609491, 0.4033570841420442, 0.3157813724828884, 0.7270239538047463, 0.006396690960173146, 0.06516838082461618, 3.410512930713594, 27.221017330884933, 71.69947743415833, 100.45973137021065, 73.90826851129532, 62.91718728840351, 55.692133381962776, 57.70027622580528, 61.28078609704971, 59.07261438667774, 72.28161379694939, 76.6091787815094, 78.5901340842247, 78.79412993788719, 76.94590911269188, 70.69681763648987, 59.47583355009556, 48.58119875192642, 26.26803796738386, 1.257337094284594, 0.24463228328386322, 0.12590389873366803, 2.5263792229816318, 0.11084621219197288, 2.8575661266222596, 52.515093460679054, 88.63513827323914, 97.6995138823986, 84.60096314549446, 82.39591106772423, 83.56373280286789, 82.31328830122948, 78.90391364693642, 83.01311954855919, 80.2737857401371, 81.93244233727455, 82.73072630167007, 88.78969877958298, 90.11229380965233, 92.50939518213272, 90.99076107144356, 67.06114992499352, 24.895042441785336, 38.480060175061226, 19.068140611052513, 3.8625157764181495, 1.1977344425395131, 0.8174686005804688, 0.0957637230749242, 0.19305178779177368, 0.27883313479833305, 0.12281109477044083, 0.06642904481850564, 0.4948590538697317, 0.476560007664375, 0.716743249213323, 0.2854835498146713, 0.5120772658847272, 7.884869500994682, 41.0541370511055, 66.98703110218048, 46.40653744339943, 31.68284621089697, 25.13377983123064, 47.55981735885143, 61.352853029966354, 47.46463246643543, 22.145582176744938, 3.508917912840843, 0.4551769816316664, 0.010724409639806254, 0.16506905027199537, 0.08183758167433552, 0.035831123605021276, 0.08190513937734067, 0.0662139778432902, 0.07692039318499155, 0.06166362923977431, 0.0650546392716933, 0.06117128847108688, 0.08304190923809074, 0.079563863837393, 0.03373810388438869, 0.05832423557876609, 0.07436815474648029, 0.044039061685907654, 0.035049634680035524, 0.028134211715951096, 0.11726084689144045, 0.061772839981131256, 0.027424260260886513, 0.013701223342650337, 0.0816453060542699, 0.037295028450898826, 0.026309827189834323, 0.01884343564597657, 0.01835408573242603, 0.029377873106568586, 0.03654023457784206, 0.018691683144425042, 0.059559581204666756, 0.08555534819606692, 0.1128959350171499, 0.04294862781534903, 0.031209473163471557, 0.056319138093385845, 0.05500968160049524, 0.028375246438372415, 0.07638897091965191, 0.004154141470280592, 0.06597300249268301, 0.018087099961121567, 0.04464855417609215, 0.01737912076350767, 0.06853210579720326, 0.06992637121584266, 0.03519377460179385, 0.040947519373730756, 0.07518332233303227, 0.03196650090103503, 0.048805468031787314, 0.029786674022034276, 0.059032441131421365, 0.041144199640257284, 0.10554110311204568, 0.010227146576653467, 0.07275928990566172, 0.05848224252986256, 0.05856181189301424, 0.0814912881469354, 0.12339184759184718, 0.022007704719726462, 0.02123423655575607, 0.034203894319944084, 0.023470431406167336, 0.04431855079019442, 0.042757554474519566, 0.09865036583505571, 0.035802606580546126, 0.03315229703730438, 0.03837801115878392, 0.05682721981429495, 0.06504085758933797, 0.014102210370765533, 0.06699019751977175, 0.08634630692540668, 0.0607434959965758, 0.08010259625734761, 0.05891624678042717, 0.13635750889079645, 0.017100000877690036, 0.060693222912959754, 0.24870921217370778, 0.3728368249721825, 21.848388724029064, 58.2058846950531, 85.44938921928406, 74.70992669463158, 46.65196627378464, 18.866365738213062, 30.440685264766216, 71.48291185498238, 97.33363911509514, 83.06464478373528, 29.67985399067402, 1.6202164348214865, 0.2055832778569311, 0.49207220028620213, 0.6076009932439774, 0.6867101951502264, 0.5330273823346943, 0.7519477664027363, 1.3834087480790913, 0.7099599600769579, 0.045777238337905146, 0.1985896789119579, 9.023594297468662, 45.33124454319477, 93.78650665283203, 105.27409583330154, 68.86299803853035, 74.05414268374443, 66.9281342625618, 72.52287045121193, 82.10428431630135, 75.61207428574562, 86.23381912708282, 80.56430295109749, 82.25553140044212, 78.94935920834541, 81.96042403578758, 83.64767029881477, 81.23378902673721, 78.11252251267433, 56.41294710338116, 11.281562335789204, 0.6662288191728294, 0.23647168680327013, 2.209117147140205, 0.06009635435475502, 9.20618399977684, 77.29346126317978, 83.50177332758904, 80.66118255257607, 78.90960574150085, 82.07154527306557, 83.12398999929428, 81.97112426161766, 79.70814809203148, 83.19126158952713, 81.90126121044159, 79.91034284234047, 80.0104446709156, 83.62046375870705, 85.35063251852989, 86.70531302690506, 93.66014063358307, 88.36108937859535, 58.29831853508949, 62.553140223026276, 41.612893268465996, 15.518380589783192, 5.443251617252827, 2.539863749407232, 0.15961006429279223, 0.08892947807908058, 0.32499187043868005, 1.8405808601528406, 0.8904932008590549, 0.16267109691398218, 1.2142238952219486, 0.5940150003880262, 0.231024872045964, 0.4117364063858986, 5.416138172149658, 42.03247055411339, 83.87156188488007, 66.08277842402458, 45.79051069915295, 17.788838557899, 27.960689440369606, 65.39201349020004, 60.88442176580429, 28.90841368585825, 4.947138838469982, 0.28210389835294336, 0.28257112484425306, 0.10730803798651323, 0.2286745051969774, 0.06599664731766097, 0.06296274019405246, 0.057407256463193335, 0.015774309904372785, 0.020927378900523763, 0.08369138493435457, 0.03921741728845518, 0.02454989076795755, 0.010905173621722497, 0.05261302700091619, 0.03859546784951817, 0.05978601046081167, 0.05071051658887882, 0.02751410280325217, 0.06308928379439749, 0.016962931767920963, 0.041450762291788124, 0.009826866444200277, 0.04029763178550638, 0.023549633406219073, 0.11665056401398033, 0.0771490488841664, 0.03105964839051012, 0.04428764776093885, 0.02029827330261469, 0.06514609412988648, 0.021398240060079843, 0.030881846505508292, 0.06312631696346216, 0.08055193698965013, 0.05535311785934027, 0.04920462844893336, 0.009048059455381008, 0.06469978136010468, 0.023824862582841888, 0.22620603296672925, 0.1875521766487509, 0.06290615885518491, 0.20226788154104725, 0.0954860559431836, 0.12548333848826587, 0.15469967387616634, 0.17515204672235996, 0.1763886577100493, 0.1406680658692494, 0.2042172956862487, 0.16215830255532637, 0.1186347848852165, 0.10431399903609417, 0.12916410894831643, 0.14637451356975362, 0.13116548827383667, 0.10771469038445503, 0.1667030664975755, 0.11107530575827695, 0.16407960414653644, 0.18078525929013267, 0.17282903543673456, 0.14234626956749707, 0.12198722921311855, 0.16658761800499633, 0.2270326073630713, 0.11438110610470176, 0.05964235664578155, 0.1825780951185152, 0.09765355760464445, 0.15666863619117066, 0.06923035543877631, 0.15197720902506262, 0.2158989227609709, 0.05367512196244206, 0.15664077596738935, 0.24049513653153554, 0.19954084506025538, 0.2279664814705029, 0.22532657312694937, 0.19315733603434637, 0.11719174552126788, 0.24782121763564646, 0.2632170415017754, 0.3449426108272746, 20.32058760523796, 68.29019397497177, 102.36377120018005, 97.89118319749832, 90.67565158009529, 48.438322618603706, 37.426418513059616, 61.302851513028145, 88.40894401073456, 96.75090238451958, 46.89337112009525, 6.196239162236452, 0.6285591248888522, 0.7128275593277067, 4.195513520389795, 7.000152049586177, 3.5792784998193383, 1.3469563541002572, 0.8065247721970081, 1.582721946761012, 0.07852396651287563, 0.22985405987128615, 4.46660284884274, 34.04391221702099, 74.06086072325706, 117.6104074716568, 103.67686673998833, 84.24996078014374, 85.21910637617111, 81.7300195991993, 94.33654233813286, 87.77076825499535, 101.33119940757751, 103.17046791315079, 100.68137347698212, 103.45812767744064, 102.62891337275505, 103.52994382381439, 100.12844234704971, 90.46311378479004, 47.534024342894554, 4.437048984691501, 0.430344482883811, 0.33734037657268345, 5.365304024890065, 0.15712507185526192, 3.986315745860338, 61.27317510545254, 96.990517526865, 107.05241560935974, 87.07158297300339, 84.36778485774994, 83.21649983525276, 85.28928101062775, 81.36645510792732, 84.68484744429588, 82.82724112272263, 82.106564193964, 78.56714531779289, 84.09046813845634, 86.78494155406952, 92.0173367857933, 103.07017609477043, 93.87002617120743, 52.008166462183, 57.488418594002724, 24.9248955398798, 5.353113329038024, 1.6748060868121684, 1.1980050592683256, 0.16609603422693908, 0.1556095023988746, 0.48667470866348594, 1.0197014082223177, 1.8682014592923224, 1.9830784387886524, 2.756957025267184, 1.7062377627007663, 0.403050072491169, 0.8396915893536061, 16.69071838259697, 60.67823342978954, 82.40382984280586, 56.58842168748379, 47.679434940218925, 34.29855555295944, 62.14379958808422, 76.69368624687195, 70.26652872562408, 37.105335742235184, 5.995720122009516, 0.412842562654987, 0.19691842171596363, 0.24401638976996765, 0.42841038666665554, 0.2081913480651565, 0.20073096791747957, 0.20066448632860556, 0.17200663191033527, 0.15737689740490168, 0.21858414664166048, 0.11254821656621061, 0.1705706206848845, 0.11292357259662822, 0.13626346393721178, 0.15573320357361808, 0.15885935223195702, 0.1445731578860432, 0.17861980595625937, 0.13093368586851284, 0.21051710529718548, 0.22417584346840158, 0.13611084868898615, 0.2085290994727984, 0.12354434409644455, 0.25368810282088816, 0.14533434907207265, 0.12441677579772659, 0.12294788000872359, 0.130620083946269, 0.3179588040802628, 0.09021336387377232, 0.18194444943219423, 0.13661107106599957, 0.23334025405347347, 0.1282714685657993, 0.16924674797337502, 0.14677499129902571, 0.12915748899104074, 0.15892331051873043], [0.06372442119754851, 0.03294809881481342, 0.0975361127348151, 0.05862698730197735, 0.02981952333357185, 0.02283225676364964, 0.08666615773108788, 0.03013401583302766, 0.049196127147297375, 0.04220034257741645, 0.017242699177586474, 0.07622419187100604, 0.025862607144517824, 0.023425227191182785, 0.052239819488022476, 0.014345382478495594, 0.04978383760317229, 0.030044210398045834, 0.03681040230731014, 0.08291135061881505, 0.0345317528990563, 0.0411336388788186, 0.03346301571582444, 0.08347861861693673, 0.057899831008398905, 0.0628556111769285, 0.04658007514080964, 0.020696570973086637, 0.0258566588308895, 0.01431669383237022, 0.02204568783781724, 0.051313615476829, 0.03275191207649186, 0.1057445554761216, 0.006382725596267846, 0.009298781060351757, 0.0667122112645302, 0.06509976185043342, 0.02549611235735938, 0.09785580026800744, 0.01829774188081501, 0.09539779232000001, 0.04386508742754813, 0.10681342624593526, 0.040992137292050757, 0.012301211845624493, 0.6502725253812969, 1.271980321034789, 12.563401702791452, 46.231959611177444, 75.66486865282059, 83.56770738959312, 69.0325677394867, 36.90805412828922, 22.301998883485794, 39.23810049891472, 74.92568671703339, 78.61420959234238, 36.47028721868992, 4.95931338518858, 0.6273083388805389, 0.40024264657404274, 0.7752704992890358, 1.3672657893039286, 0.11470250799902715, 0.6203931849449873, 0.48803488723933697, 0.16224780556512997, 0.020687357209681068, 0.08445035709883086, 1.2085266946814954, 15.285284947603941, 39.730725064873695, 42.72376365959644, 37.911713272333145, 43.000700399279594, 40.90522684156895, 39.78948511183262, 36.26482844352722, 32.39614203572273, 29.34078488498926, 24.809241145849228, 21.280186213552952, 13.122662343084812, 6.804960323497653, 0.9057810273952782, 0.23308517789701, 0.45161630550865084, 0.2053575759055093, 0.4229498718632385, 0.2305622468702495, 0.056813133851392195, 0.1829343705321662, 0.20379602297907695, 9.514100477099419, 44.803205877542496, 77.9829190671444, 101.360944211483, 88.39730903506279, 90.18746137619019, 90.67933738231659, 81.96811482310295, 87.81786292791367, 88.8626092672348, 96.84022799134254, 97.69295543432236, 88.85158985853195, 66.26316234469414, 41.43789745867252, 8.958479091525078, 1.7928558960556984, 1.3303217967040837, 0.2977473323699087, 0.15727197256637737, 0.4345052893040702, 2.543080751784146, 0.25931432435754687, 0.39929715043399483, 0.37195070064626634, 2.092759790830314, 0.18441997206537053, 0.8107328682672232, 0.56133390404284, 0.4804875125410035, 6.738274851813912, 51.041559129953384, 67.48323127627373, 46.35665372014046, 24.10542581230402, 24.642984867095947, 39.15873795747757, 63.26487623155117, 69.40078318119049, 35.76145425438881, 8.90302961692214, 0.25495141628198326, 0.140011680778116, 0.13427768455585465, 0.052098919040872715, 0.07226403991808183, 0.05779170380264986, 0.05146749237610493, 0.01672221431363141, 0.04128910026338417, 0.08767510749748908, 0.08954999517300166, 0.02685479736101115, 0.023580755369039252, 0.06264922732952982, 0.016564160978305154, 0.08954707853263244, 0.03434317317442037, 0.06726054707542062, 0.004430275139384321, 0.048957582330331206, 0.044269023564993404, 0.11373116285540164, 0.0170913771216874, 0.03734993253601715, 0.0417621637461707, 0.04251909129379783, 0.02996479503053706, 0.04199546528980136, 0.01875114772701636, 0.04665521017159335, 0.03130414894258138, 0.053220730915199965, 0.06008702555845957, 0.06237564201001078, 0.06306281880824827, 0.057524653093423694, 0.06031201875885017, 0.019176812093064655, 0.08294076935271733, 0.10135349773918279, 0.012340183875494404, 0.005825086500408361, 0.06875787454191595, 0.016381895075028297, 0.02763336964562768, 0.021172374836169183, 0.04130832930968609, 0.05658440393744968, 0.03336452158691827, 0.03263317215896677, 0.014569083414244233, 0.03757512240554206, 0.07728915894404054, 0.022293179245025385, 0.05032652938098181, 0.04786840268934611, 0.01775490538420854, 0.04980071775207762, 0.06838461136794649, 0.01180239676614292, 0.13840586616424844, 0.13282120489748195, 0.10315952895325609, 0.01734110053803306, 0.01135509508458199, 0.064110427047126, 0.04670364272897132, 0.016152792231878266, 0.05517964826140087, 0.005860851988472859, 0.021742707904195413, 0.024573602386226412, 0.05021905526518822, 0.03094287145358976, 0.05260569458187092, 0.07746915202005766, 0.049851176372612827, 0.06897967279655859, 0.0715798391320277, 0.026347940183768515, 0.017003870489133988, 0.08250915110693313, 0.02594465342554031, 0.033811446628533304, 0.09710816069855355, 0.2071890330989845, 0.05147797521203756, 0.5493310606107116, 2.6902497047558427, 19.948342479765415, 57.66164369881153, 91.12151205539703, 76.36102169752121, 36.309457048773766, 20.270960368216038, 27.542597874999046, 65.5970048904419, 109.05504494905472, 87.42521479725838, 28.98261610418558, 2.681706575676799, 0.18014821456745267, 0.23832151957321912, 1.2378935376182199, 0.7093034265562892, 1.261628489010036, 0.655370723688975, 1.854056480806321, 1.0839861212298274, 0.22710297780577093, 0.2937274449504912, 4.250602489337325, 31.03939063847065, 58.99558871984482, 66.55092090368271, 63.14662277698517, 68.02629053592682, 68.43859121203423, 71.50938123464584, 69.61383014917374, 63.81283342838287, 58.495995327830315, 57.60207049548626, 51.44296579062939, 39.28095079958439, 27.540718875825405, 9.599852375686169, 1.2626678519882262, 0.4491798346862197, 0.5528522841632366, 1.3129040063358843, 2.793927378952503, 0.5739000078756362, 0.3637022338807583, 1.5724113187752664, 31.032210923731327, 74.22577187418938, 88.0561101436615, 98.074591755867, 91.35958448052406, 92.55711302161217, 93.73634934425354, 88.45680624246597, 90.05899786949158, 88.42898413538933, 93.96548464894295, 99.95025470852852, 92.15330868959427, 85.83869352936745, 72.07661479711533, 40.41086956858635, 8.579341135919094, 7.135257124900818, 0.9749955602455884, 0.34386495302896947, 0.8289549092296511, 2.0593714574351907, 0.38874404795933515, 0.9011593472678214, 1.114512614440173, 0.08162327911122702, 0.9459384600631893, 0.42342523229308426, 0.3249873878667131, 0.37549196218606085, 1.0342660266906023, 43.62374156713486, 81.62946179509163, 66.34957730770111, 36.42878584563732, 20.691770687699318, 26.2053432315588, 57.73849077522755, 77.75159507989883, 42.676258608698845, 11.347540095448494, 0.22272751259151846, 0.2952806412940845, 0.12838534370530397, 0.007972889707161812, 0.2896706579485908, 0.052832253713859245, 0.03863270139845554, 0.028910052897117566, 0.045642223121831194, 0.04620511615939904, 0.03811844129813835, 0.10344190872274339, 0.039348807113128714, 0.04919721439364366, 0.06799333626986481, 0.029026738920947537, 0.04196445835987106, 0.03200161190761719, 0.012770197226927849, 0.06479119168943726, 0.02834669045114424, 0.05611587126622908, 0.16291729698423296, 0.021440668642753735, 0.07968898251419887, 0.04884952191787306, 0.03893384266120847, 0.02930683287559077, 0.012207804211357143, 0.03846183302812278, 0.04859039734583348, 0.0329084421537118, 0.02054160682746442, 0.030001902414369397, 0.013610414152935846, 0.019364497529750224, 0.04187427257420495, 0.048130696231964976, 0.037328959442675114, 0.0402411691902671, 0.015320746351790149, 0.08855238542309962, 0.15426953992573544, 0.16100543551146984, 0.13672662345925346, 0.11623821934335865, 0.1399484052672051, 0.14031670347321779, 0.14099167194217443, 0.1433916884707287, 0.18308023223653436, 0.09782858571270481, 0.14846720674540848, 0.06299707194557413, 0.28718487883452326, 0.12445969419786707, 0.1567411737050861, 0.1616019441280514, 0.23734561022138223, 0.11441977199865505, 0.38235044572502375, 0.21447833336424083, 0.2036515119834803, 0.10594116523861885, 0.18150045216316357, 0.14882512972690165, 0.18456466117640957, 0.13648780033690855, 0.15335562959080562, 0.09779031315702014, 0.15428208222147077, 0.10984348904457875, 0.16968163166893646, 0.08714546638657339, 0.19943933410104364, 0.19967220519902185, 0.14574011089280248, 0.197648917674087, 0.23649708309676498, 0.19367064989637583, 0.20350149425212294, 0.2097294936538674, 0.2031126682413742, 0.18656973639735952, 0.1901848119450733, 0.20630561019061133, 0.13807163253659382, 0.8603801729623228, 1.8916712561622262, 21.461322493851185, 69.29575681686401, 106.06053203344345, 98.88361394405365, 85.23222327232361, 50.18752835690975, 32.81507335603237, 56.81957088410854, 95.68473279476166, 100.24809032678604, 47.52176620066166, 8.139276299625635, 0.6994313781615347, 0.5242040182929486, 2.2657414712011814, 7.370961327105761, 3.3309694239869714, 1.3254223158583045, 1.9454146223142743, 1.2873855256475508, 0.17707008286379278, 0.4586552793625742, 1.6107930592261255, 15.100820045918226, 45.16368493437767, 63.37631285190582, 62.17689961194992, 71.41025215387344, 75.39428517222404, 75.42209208011627, 63.9364255964756, 50.238244235515594, 43.955539762973785, 40.892911702394485, 34.64810639619827, 24.60951056331396, 15.124090947210789, 3.0131787015125155, 0.29149081965442747, 0.6864351849071681, 0.7555354270152748, 1.100595979951322, 1.3790578627958894, 0.2846383326686919, 0.29546211124397814, 0.24735841434448957, 14.136797524988651, 53.062138706445694, 89.95376631617546, 114.63141292333603, 110.26365369558334, 111.74657732248306, 114.02664497494698, 103.13544139266014, 108.99626210331917, 107.26516619324684, 116.7681522667408, 118.82437393069267, 111.8349377810955, 94.10118296742439, 70.20859703421593, 36.01890563964844, 6.757120890542865, 2.4808769021183252, 0.2976408787071705, 0.42310438700951636, 1.1178417108021677, 3.3130871085450053, 1.0297313262708485, 0.9590577310882509, 1.7552994238212705, 6.873249784111977, 2.646931316703558, 2.173204799182713, 0.5824374966323376, 0.7097320910543203, 13.86873995885253, 68.92720699310303, 84.2917813360691, 56.96868248283863, 34.61114197969437, 35.946169942617416, 53.34297023713589, 80.81147968769073, 86.81188970804214, 51.20504155755043, 14.011883977800608, 0.30330958077684045, 0.33487665408756584, 0.30406303878407925, 0.11651838009129278, 0.326316871214658, 0.11894785246113315, 0.08044218076975085, 0.17328698508208618, 0.15645685693016276, 0.17110012820921838, 0.15665741491829976, 0.22177129983901978, 0.2061734040034935, 0.11611428068135865, 0.17881035979371518, 0.12023203511489555, 0.06785162317100912, 0.11685444682370871, 0.23215222405269742, 0.12418563390383497, 0.16670208686264232, 0.16287195176118985, 0.20589401508914307, 0.16542594908969477, 0.09654200592194684, 0.14348568889545277, 0.12970894924364984, 0.11074170295614749, 0.10132019757293165, 0.194100457301829, 0.10991171468049288, 0.0866393068281468, 0.20936360000632703, 0.19022007880266756, 0.16000907256966457, 0.2479906944790855, 0.09366232450702228, 0.11015059717465192, 0.14488707151031122, 0.20717674313345924, 0.09706323849968612], [0.04573620499286335, 0.036148818471701816, 0.06766429767594673, 0.05036164409830235, 0.027575693638937082, 0.028835524572059512, 0.0622125921654515, 0.012046151459799148, 0.10210687411017716, 0.04112967952096369, 0.06416031421395019, 0.008806737150734989, 0.01851130415161606, 0.037355160966399126, 0.04445059741556179, 0.0795624685997609, 0.1094075218134094, 0.02195512170146685, 0.023451027955161408, 0.08917286540963687, 0.05413234801380895, 0.026305652609153185, 0.05728854623157531, 0.1266437754384242, 0.016341776426997967, 0.07714970197412185, 0.11579939484363422, 0.020670167214120738, 0.044313563557807356, 0.045407786092255265, 0.029227335871837568, 0.06133376315119676, 0.027883582879439928, 0.019373332797840703, 0.017329146394331474, 0.019118098934995942, 0.029532312182709575, 0.005136891568326973, 0.1483176343026571, 0.024296911178680602, 0.05794837117718998, 0.0427581667463528, 0.016909729056351352, 0.07028198611806147, 0.150155488809105, 0.13072867499431595, 0.029391261450655293, 0.1834794186288491, 0.5745292303618044, 0.6363569002132863, 16.04508362710476, 42.070662304759026, 74.7059141099453, 81.22998923063278, 67.22570389509201, 34.24224257469177, 22.544093392789364, 42.49342001974583, 63.786113262176514, 72.82181560993195, 40.70402383804321, 6.027317801490426, 0.17214266757946461, 0.6588328129146248, 2.4407394183799624, 0.887717924779281, 0.5334942822810262, 1.142310022842139, 1.158628009725362, 1.1661615804769099, 0.09221413463819772, 0.6526579661294818, 0.20592992019373924, 0.3523661656072363, 1.6376073891296983, 0.8445326483342797, 4.3505736999213696, 6.832401501014829, 1.2687280518002808, 0.22439039836172014, 0.42513517022598535, 0.286285633337684, 0.5543594970367849, 0.3421344724483788, 0.28218740480951965, 0.06974109404836781, 0.06477204427937977, 0.0892685134022031, 0.12114470606320538, 0.7546367752365768, 2.48575821518898, 1.6186908166855574, 0.13933650450780988, 0.17081392637919635, 0.34289223491214216, 0.08133942988933995, 1.662243485916406, 7.606332097202539, 12.999492902308702, 13.341170568019152, 12.019660379737616, 12.326026540249586, 16.64837535470724, 20.963891185820103, 21.14963471889496, 19.87570747733116, 14.49277002364397, 5.0208192598074675, 0.5441097251605242, 1.4579242933541536, 0.69445192348212, 0.16253280511591583, 0.07667359197512269, 0.252249434706755, 2.1327464701607823, 5.345972087234259, 1.091442983597517, 0.5002319952473044, 1.4657607791014016, 1.397949499078095, 0.5258306278847158, 0.36368320521432906, 7.439120169728994, 44.98495772480965, 69.37812879681587, 42.394340336322784, 21.969125345349312, 21.265651993453503, 46.96682497859001, 62.234056144952774, 67.22195729613304, 43.25345903635025, 10.631768703460693, 0.7079259410966188, 0.2791529113892466, 0.03863042300508823, 0.10671886178897694, 0.058712130194180645, 0.048962068613036536, 0.09450726705836132, 0.13110440952004865, 0.05552150003495626, 0.05042024036811199, 0.03276490337157156, 0.07863544451538473, 0.01368147015455179, 0.1068047653825488, 0.05338618531823158, 0.005915989850109327, 0.026323749880248215, 0.044892535224789754, 0.10969500755891204, 0.030115682930045296, 0.039082569055608474, 0.056796780627337284, 0.01780393908120459, 0.026127472228836268, 0.03277432493632659, 0.056173153934651054, 0.06287661395617761, 0.05702035632566549, 0.03954878622607794, 0.011915438844880555, 0.028398473805282265, 0.02772084844764322, 0.07230622359202243, 0.05470873700687662, 0.04513849038630724, 0.06817197863711044, 0.03536062424245756, 0.0240224093067809, 0.039589029183844104, 0.00930903846892761, 0.060325425656628795, 0.019693309768626932, 0.028157346314401366, 0.04522654249740299, 0.02918638045230182, 0.0699511515267659, 0.02453373235766776, 0.05421515685156919, 0.015226816431095358, 0.02624194294185145, 0.04905255867925007, 0.1310975817614235, 0.085439446993405, 0.009597708867659094, 0.026472799108887557, 0.027321899542585015, 0.02843160884367535, 0.08946254049078561, 0.043906332284677774, 0.03629159284173511, 0.01595357938640518, 0.05593388181296177, 0.03950397534936201, 0.08098919555777684, 0.043700263850041665, 0.09382794960401952, 0.08466923129162751, 0.023114131872716825, 0.02910771650931565, 0.0390294015960535, 0.073808501183521, 0.029726244647463318, 0.06795444773160852, 0.0072971623922057915, 0.03663565621536691, 0.06263681119889952, 0.04185710298770573, 0.031700507752248086, 0.016357643544324674, 0.0641844562778715, 0.07102886127540842, 0.03304537582152989, 0.03391472389921546, 0.06889821466756985, 0.13245133333839476, 0.03497378718748223, 0.20440344116650522, 0.2868023165501654, 0.07418084409437142, 0.012568750516948057, 0.387544707627967, 0.31478478689678013, 1.7332988418638706, 21.384788900613785, 57.24771670997143, 93.01030710339546, 76.27768456935883, 42.766674757003784, 18.911651708185673, 29.488427862524986, 65.26164248585701, 102.74280086159706, 91.30727648735046, 30.201060622930527, 1.6241540922783315, 0.31677249586209655, 0.49222404370084405, 0.8305374055635184, 0.18937640532385558, 1.7273697350174189, 0.8560841472353786, 1.9378265482373536, 3.643058077432215, 0.622116451850161, 0.6383532774634659, 2.015359131619334, 1.6057901526801288, 6.398969683796167, 5.8016270119696856, 14.370848815888166, 18.006644770503044, 8.707594703882933, 1.0841281386092305, 2.757475459948182, 1.7729330901056528, 2.4254827620461583, 1.3013729313388467, 1.0280271177180111, 0.10340831911889836, 0.1340862104552798, 0.7791668933350593, 0.9851800231263041, 3.1245120149105787, 3.387858308851719, 3.785815229639411, 1.1723145190626383, 0.7918524532578886, 0.35179168393369764, 0.7552209938876331, 11.733721923083067, 30.62973652034998, 37.20887638628483, 41.23711623251438, 38.79744194447994, 40.18920846283436, 44.114591628313065, 50.6707788258791, 52.52528831362724, 47.532610818743706, 39.18002441525459, 28.339855894446373, 12.81852476298809, 3.5508885607123375, 0.708456962602213, 0.2429803812992759, 0.10304810290108435, 1.2568091601133347, 4.669208452105522, 12.026838194578886, 0.2837215724866837, 0.41540956241078675, 0.8930663752835244, 0.7263578020501882, 0.2163632251904346, 0.3516324487281963, 1.4635947765782475, 35.26191785931587, 89.15542155504227, 75.74931532144547, 35.038520246744156, 21.58729713410139, 28.864605836570263, 50.945390090346336, 75.10636702179909, 52.212869077920914, 14.132678546011448, 0.8721356140449643, 0.3694878687383607, 0.10763670550659299, 0.0963958325155545, 0.12270539809833281, 0.0786962264101021, 0.09520320119918324, 0.11590601920033805, 0.04752538945467677, 0.0647498614853248, 0.028458467168093193, 0.08913085985113867, 0.029499047268473078, 0.04768819439050276, 0.025269469733757433, 0.042929677074425854, 0.02981282174005173, 0.0158087882300606, 0.06961307357414626, 0.06939034763490781, 0.014841759602859383, 0.06625324487686157, 0.008828139762044884, 0.026518161030253395, 0.029271282146510202, 0.09155555278994143, 0.07542446837760508, 0.05169623713300098, 0.0611860906064976, 0.0695484176685568, 0.038183271608431824, 0.04145525599597022, 0.0868164723215159, 0.03203565051080659, 0.05442082823719829, 0.03255516501667444, 0.0022291588265943574, 0.02472805073921336, 0.12616710882866755, 0.01033773029121221, 0.030923245358280838, 0.0705583619128447, 0.042372220268589444, 0.10595718078548089, 0.21062430110760033, 0.2620646049035713, 0.26548703375738114, 0.13112613960402086, 0.07783097127685323, 0.17756338842445984, 0.07155877698096447, 0.15148127626162022, 0.09646992111811414, 0.10938471561530605, 0.07238264995976351, 0.09162532209302299, 0.11380260199075565, 0.14984663663199171, 0.19709082262124866, 0.1481811236590147, 0.15961530385538936, 0.09412331695784815, 0.1668258325662464, 0.30041541263926774, 0.1470955100376159, 0.2234130195574835, 0.23653803480556235, 0.22334944718750194, 0.1724497979739681, 0.21221868664724752, 0.11859989652293734, 0.11594294846872799, 0.10837193636689335, 0.1646554216858931, 0.2824804640840739, 0.1686586849973537, 0.15191519516520202, 0.15613611554726958, 0.11089247767813504, 0.15935158909996971, 0.17996013950323686, 0.2561920793959871, 0.19424321682890877, 0.29296469525434077, 0.18041630799416453, 0.2600455773063004, 0.23812713625375181, 0.36195720720570534, 0.13360477925743908, 0.29553846339695156, 0.29579999623820186, 0.5672759539447725, 1.8770295730791986, 27.156206108629704, 70.88211089372635, 107.37842291593552, 101.79491892457008, 82.0464438199997, 48.86268004775047, 36.20184302330017, 58.329465463757515, 84.13506254553795, 91.85523748397827, 53.03629249334335, 9.552335925400257, 0.24777284445008263, 0.9898475382942706, 5.202464237809181, 1.7283294210210443, 6.803694991394877, 4.83801344409585, 3.4605837939307094, 4.479016307741404, 0.9991258685477078, 0.7294568326324224, 0.6657879834529012, 0.3105596808018163, 2.391346343792975, 1.638888514135033, 7.368851965293288, 14.71407774835825, 4.4079468213021755, 0.339327254332602, 0.9194319136440754, 0.49120121577288955, 1.0390770435333252, 0.5422174267005175, 0.6171643082052469, 0.12871579237980768, 0.2701123058795929, 0.5803299159742892, 0.46506075595971197, 2.155921901576221, 6.662925845012069, 3.8935311371460557, 0.832873567705974, 0.583326886408031, 0.6359243171755224, 0.2762986411107704, 3.280606926418841, 13.076048344373703, 19.85540896654129, 22.54873674362898, 20.643422082066536, 22.538891471922398, 25.797351524233818, 32.378556579351425, 32.475987151265144, 28.886017687618732, 21.672123782336712, 17.21988558769226, 6.128010498359799, 1.8868828006088734, 1.4098490355536342, 0.24353820917895064, 0.2921189437620342, 1.3860458065755665, 4.852436995133758, 12.731480933725834, 2.060469835996628, 1.1700285854749382, 3.741851826198399, 3.311643423512578, 0.5673261824995279, 0.5565839807968587, 13.925436716526747, 65.04433214664459, 89.80094611644745, 56.90024055540562, 29.878017157316208, 33.496426194906235, 60.34515090286732, 77.38554552197456, 84.96193617582321, 59.7102277725935, 18.008580766618252, 1.0413386346772313, 0.3927083336748183, 0.07511794654419646, 0.17600406194105744, 0.2959594689309597, 0.19627267902251333, 0.26760930893942714, 0.1542435647570528, 0.16595089982729405, 0.11818115453934297, 0.169792523374781, 0.1524453260935843, 0.13377076800679788, 0.20363030140288174, 0.15932405542116612, 0.10659829989890568, 0.1100325066363439, 0.06972911578486674, 0.24205676367273554, 0.11537911661434919, 0.09472456789808348, 0.15408358740387484, 0.13372533372603357, 0.07213238292024471, 0.131656656449195, 0.15775938547449186, 0.1964167002006434, 0.13541655469452962, 0.11517190156155266, 0.13359504227992147, 0.0969102670205757, 0.22676426160614938, 0.27128068380989134, 0.13397848029853776, 0.21439415897475556, 0.14678027539048344, 0.1387234459980391, 0.0935063547512982, 0.18992903816979378, 0.0732608481484931, 0.12861977331340313, 0.1754953939234838, 0.12450705806259066], [0.05173488818400074, 0.04517786503129173, 0.005475484385897289, 0.06201970798429102, 0.03808071051025763, 0.03621355972427409, 0.026145118645217735, 0.03518443838402163, 0.04726004568510689, 0.014657148512924323, 0.0870904212933965, 0.07621078126248904, 0.05386010969232302, 0.09597786236554384, 0.055425083919544704, 0.023609368872712366, 0.06546971504576504, 0.043834277166752145, 0.04663522413466126, 0.050538776195026, 0.05014885180571582, 0.13447557081235573, 0.02810419369779993, 0.03598581315600313, 0.09385508252307773, 0.04693636168667581, 0.02190829960454721, 0.05686532167601399, 0.018277839335496537, 0.031679208113928325, 0.09269761416362599, 0.035818533069686964, 0.012537668444565497, 0.039649588434258476, 0.06832047496573068, 0.06710588349960744, 0.038155147922225296, 0.036833620397374034, 0.05091480015835259, 0.10287133816746064, 0.042353332610218786, 0.023461189812223893, 0.05080531853309367, 0.061140789912315086, 0.022385745469364338, 0.04044001652800944, 0.1923947941395454, 0.03935307446226943, 0.20031772524816915, 0.2763144933851436, 0.7927713508252054, 0.7284988090395927, 11.016747895628214, 43.08423891663551, 75.88610798120499, 81.62256136536598, 57.5300719588995, 49.46049816906452, 23.991648517549038, 26.354565024375916, 61.49823322892189, 83.93194824457169, 51.26019559800625, 12.023917101323605, 0.3250079008284956, 0.2636593912029639, 0.4995249363128096, 0.5754214699845761, 2.1113628800958395, 2.4551069224253297, 1.667190701700747, 3.514732075855136, 2.0124969352036715, 0.4654999589547515, 0.303767723380588, 0.15039492049254477, 0.3371715231332928, 0.23317006474826485, 0.8515561558306217, 0.15971657732734457, 0.1397077416186221, 0.10330370598239824, 0.11484629168990068, 0.17563611996592954, 0.16547243722015992, 0.06668256246484816, 0.524785565212369, 1.3150843768380582, 3.551130797713995, 4.369924636557698, 2.9923323076218367, 2.9675089521333575, 0.8048275695182383, 0.3073291416512802, 0.17112732050009072, 0.11563443767954595, 0.0707136414712295, 0.3669324464863166, 0.36339777521789074, 0.5586770153604448, 0.397587331244722, 0.311604684102349, 0.27979629405308515, 0.4163958766730502, 0.4030775319552049, 0.38575218350160867, 0.41112882492598146, 0.4554277384886518, 0.16635741863865405, 0.13167981145670637, 0.29552080028224736, 0.3171094012213871, 0.9557016205508262, 1.8342620367184281, 4.709656806662679, 2.523447680287063, 0.7357724499888718, 0.2668452827492729, 0.3565077355597168, 1.8264517933130264, 13.219972271472216, 47.21749372780323, 61.03876568377018, 37.0057924836874, 15.899793673306704, 25.20513240247965, 44.972152411937714, 63.83177921175957, 63.272502422332764, 49.0439797192812, 15.518851764500141, 1.8559484230354428, 0.0802281082724221, 0.05728284282668028, 0.122572872787714, 0.04643960885005072, 0.06452617817558348, 0.11818805651273578, 0.035276245762361214, 0.022226380388019606, 0.1737251045415178, 0.06929386101546697, 0.052787186796194874, 0.02010228137805825, 0.11889386863913387, 0.03363241834449582, 0.006831642840552377, 0.005291326469887281, 0.01413386853528209, 0.012433013562258566, 0.07400922244414687, 0.05318044713931158, 0.026758464737213217, 0.03314740628411528, 0.005626658939945628, 0.02100556972436607, 0.03300111413409468, 0.05598622919933405, 0.04647090892831329, 0.06148454158392269, 0.053800266614416614, 0.017610099384910427, 0.028830567025579512, 0.04431973080500029, 0.05099559777590912, 0.020365402415336575, 0.0690983644744847, 0.044703621533699334, 0.09031656692968681, 0.07362058197031729, 0.09298756383941509, 0.0319522776408121, 0.06540091053466313, 0.031081124288903084, 0.020746261470776517, 0.07009074208326638, 0.03329422906972468, 0.07529173526563682, 0.0012612701198122522, 0.03034707344340859, 0.1256411339272745, 0.04287856165319681, 0.02231692982604727, 0.0273103276049369, 0.040578111656941473, 0.05267069187539164, 0.01978104090085253, 0.10359912528656423, 0.04520824855717365, 0.04812450672034174, 0.028864891355624422, 0.005300572702253703, 0.03198148486262653, 0.041416441672481596, 0.03380195084901061, 0.07479842970496975, 0.10630187869537622, 0.07908592073363252, 0.0461229938082397, 0.03618899834691547, 0.10187080435571261, 0.0379057417740114, 0.008502346208842937, 0.054265058861346915, 0.048220195531030186, 0.026611128014337737, 0.10413163108751178, 0.05366173732909374, 0.07690665603149682, 0.06300666791503318, 0.04140068958804477, 0.04562049303785898, 0.02129214262822643, 0.015075862665980821, 0.012238489234732697, 0.0958083855221048, 0.056928511839942075, 0.07885331680881791, 0.024001887068152428, 0.0125481141731143, 0.05638331531372387, 0.013036294276389526, 0.21825896721566096, 0.04838901186303701, 0.17866798618342727, 0.3771590336691588, 0.5195565707981586, 1.3773173186928034, 16.77056349813938, 62.026572078466415, 93.24563607573509, 73.32240834832191, 37.76973769068718, 35.779210701584816, 24.590397588908672, 51.605840250849724, 103.60310509800911, 109.42021295428276, 49.35513362288475, 4.613853022456169, 1.0201539401896298, 0.06867367788800038, 0.4485725500853732, 0.3535417572129518, 1.1289600329473615, 1.7527074879035354, 0.2727145724929869, 5.238399859517813, 1.1754536256194115, 1.060673778411001, 0.6193978758528829, 0.3622147621354088, 0.4416140844114125, 2.6151429349556565, 1.8264120141975582, 0.284386447747238, 0.6010557257104665, 0.8550681173801422, 0.9384741762187332, 0.27852829021867365, 0.3235305519774556, 0.09254902877728455, 0.847114787902683, 2.313274070620537, 4.194136569276452, 5.484665594995022, 6.962566366419196, 6.116234455257654, 2.231752770021558, 0.7887255772948265, 0.5667447543237358, 0.4157360183307901, 0.1151218511222396, 0.5722025083377957, 0.6751988909672946, 1.2072544754482806, 0.9321753610856831, 0.8502804336603731, 0.8842113660648465, 1.3017847342416644, 1.2187109794467688, 1.2541981064714491, 1.2388579733669758, 0.932590370066464, 0.26242324034683406, 0.33474731259047985, 0.7659363001585007, 0.33164771797601134, 0.4787506494903937, 0.5060940713156015, 1.8473677709698677, 0.5162942677270621, 0.47135114029515535, 0.2092632171115838, 0.16764728614361957, 1.237280226778239, 1.5483245300129056, 33.12780797481537, 79.82401907444, 71.37863025069237, 33.86583857238293, 18.336033895611763, 27.728535197675228, 52.50508099794388, 71.36633411049843, 62.10701376199722, 20.95536444336176, 2.2818286204710603, 0.03156234583002515, 0.13639328040881082, 0.10663420500350185, 0.07693753679632209, 0.055053958130883984, 0.033493892769911326, 0.028088192993891425, 0.03544434221112169, 0.17999856790993363, 0.03482217754935846, 0.061011492944089696, 0.06529325459268875, 0.029974298231536523, 0.11180908200913109, 0.014940509772713995, 0.09058040785021149, 0.00824835729872575, 0.03148224583128467, 0.02304021210875362, 0.03725520109583158, 0.0846100524358917, 0.06479177056462504, 0.03955120933824219, 0.038305351190501824, 0.00706429500496597, 0.08042040615691803, 0.012705537610600004, 0.03758879276574589, 0.026195432546956, 0.00791525637396262, 0.03279642609413713, 0.011460173918749206, 0.022876494331285357, 0.024258826015284285, 0.06572486541699618, 0.035044966571149416, 0.040873705365811475, 0.060826490371255204, 0.08148020788212307, 0.023307290648517665, 0.04390397596580442, 0.03470446179562714, 0.02868834741093451, 0.07584277249407023, 0.14804773003561422, 0.1915321810520254, 0.2324292974662967, 0.1579204315203242, 0.2016544371144846, 0.12604005314642563, 0.09027459105709568, 0.10607096686726436, 0.13141510222340003, 0.08652946155052632, 0.25084698339924216, 0.1337884904933162, 0.11271027935435995, 0.19008432514965534, 0.17689478758256882, 0.13665920676430687, 0.106795733445324, 0.09366363810840994, 0.1242911747249309, 0.18705605092691258, 0.1971221560961567, 0.28140690294094384, 0.1432567066513002, 0.18072223610943183, 0.32066164654679596, 0.13277361838845536, 0.1939309953013435, 0.1870622849673964, 0.24691505532246083, 0.07864576036809012, 0.12916118488647044, 0.16956506995484233, 0.18018827569903806, 0.23501566727645695, 0.17550676362589002, 0.37859123025555164, 0.13443500502035022, 0.0975287654728163, 0.1693407929269597, 0.2831592917209491, 0.1263037382159382, 0.13584453641669825, 0.12907775264466181, 0.21144505706615746, 0.100905500294175, 0.14588509686291218, 0.4057322535663843, 0.18400006490992382, 0.3848953591659665, 0.46940959291532636, 0.8786761318333447, 1.9683777401223779, 25.679774433374405, 76.33981883525848, 105.16859829425812, 100.30479088425636, 74.13075417280197, 71.1628246307373, 31.28977820277214, 43.65633241832256, 80.3071403503418, 110.50607308745384, 65.46788021922112, 19.47472259402275, 1.479365830309689, 0.2340820454992354, 0.752002625958994, 2.5429850444197655, 7.959898374974728, 10.187260955572128, 5.583062740042806, 8.696657940745354, 5.766318831592798, 0.8257596369367093, 0.45059024181682616, 0.3209165594307706, 0.43457522930111736, 2.221761681139469, 1.454080562107265, 0.2727098821196705, 0.2549644483951852, 0.6128710135817528, 0.6978427071589977, 0.3038495674263686, 0.34067074942868203, 0.09206132643157616, 1.5497404290363193, 8.60847607254982, 8.508977461606264, 17.105849906802177, 14.591670166701078, 13.07015961036086, 3.9818697469308972, 0.3491798881441355, 0.30084496771451086, 0.20211997150909156, 0.19411323708482087, 0.6651432649232447, 0.4778820101637393, 0.6679316028021276, 0.5976335937157273, 0.4157889779889956, 0.502424358855933, 0.893461019732058, 0.5523225094657391, 0.5930869595613331, 0.4736325319390744, 0.6213063828181475, 0.21778817841550335, 0.4135552322259173, 1.113200259860605, 0.43108407757245004, 4.050493827089667, 7.1158829145133495, 10.79653736203909, 8.57737759128213, 2.788264495320618, 0.7370396819896996, 0.34571865980979055, 3.3571345824748278, 22.533098682761192, 71.30390346050262, 79.78580832481384, 52.75246672332287, 27.03817494213581, 36.39047630131245, 64.72800672054291, 79.96333479881287, 84.33581337332726, 70.26660472154617, 27.366832606494427, 2.5677407160401344, 0.1834019087255001, 0.18800559919327497, 0.43523363303393126, 0.14454402116825804, 0.1804965638439171, 0.13740364025579765, 0.13423446187516674, 0.1489447194035165, 0.41209783230442554, 0.14721753395861015, 0.14276963513111696, 0.20324297453043982, 0.13810666190693155, 0.14050510508241132, 0.1926208968507126, 0.07603411300806329, 0.10063485387945548, 0.09007034459500574, 0.0840563137899153, 0.16499859077157453, 0.1575873704859987, 0.16031091887271032, 0.07308333384571597, 0.170065411075484, 0.18547166953794658, 0.16706234018784016, 0.133642599103041, 0.2325277210911736, 0.1631527952849865, 0.13196697807870805, 0.19711178087163717, 0.12207593070343137, 0.22614735877141356, 0.10379699670011178, 0.15989638486644253, 0.1972552973893471, 0.2294517119298689, 0.3615601878846064, 0.18712149350903928, 0.15575983183225617, 0.10015521867899224, 0.1511235610814765, 0.10837528345291503, 0.22895659552887082], [0.008260545218945481, 0.03035300505871419, 0.019218518937123008, 0.05363208110793494, 0.04266839285264723, 0.0336621228052536, 0.054393346508732066, 0.06522032374050468, 0.030008490830368828, 0.023213004496938083, 0.05012208624975756, 0.045775846811011434, 0.042787069687619805, 0.04603270783263724, 0.023213878375827335, 0.04494958782743197, 0.03945254080463201, 0.016937926957325544, 0.04818439803784713, 0.023018645297270268, 0.0244754941741121, 0.04865408474870492, 0.055701363235129975, 0.06763693469110876, 0.020540337754937354, 0.032010306167649105, 0.052485010237433016, 0.07177248582593165, 0.11359687123331241, 0.010507813840376912, 0.03925075085135177, 0.018008417464443482, 0.06489160427008756, 0.09122416158788837, 0.02281731733091874, 0.02360405880608596, 0.04450038068171125, 0.024799135499051772, 0.11685105520882644, 0.0664814627089072, 0.005445407459774287, 0.06679156169411726, 0.017842250599642284, 0.028091499261790887, 0.040479123999830335, 0.032417214606539346, 0.08457233649096452, 0.10754976290627383, 0.14970703865401447, 0.050670325581450015, 0.1562921001459472, 0.26168420969042927, 0.3492519655264914, 1.2576216040179133, 21.285281740128994, 57.651631236076355, 78.58622789382935, 65.25416448712349, 72.49112695455551, 41.421125158667564, 14.5075654797256, 23.48548337817192, 41.62286393344402, 63.87784034013748, 67.41730481386185, 31.42321564257145, 8.613725490868092, 1.012457690667361, 0.39646826160605997, 0.35639457288198173, 1.273467110004276, 2.4895879346877337, 1.2713864841498435, 0.3893118799896911, 0.5677248048596084, 0.5725357623305172, 0.6166076380759478, 0.17940954014193267, 0.4763071134220809, 1.048280862160027, 1.3675996963866055, 2.331385323777795, 2.974287075921893, 1.0536760976538062, 0.18910286453319713, 1.698578679934144, 1.9038213416934013, 0.184982193459291, 1.809702767059207, 2.315847482532263, 3.3020598627626896, 2.7564134169369936, 1.6496118949726224, 3.501662202179432, 0.9302011888939887, 0.7821942621376365, 0.42275946645531803, 0.8673411619383842, 0.3272031736560166, 0.553029568400234, 0.1879241707501933, 0.430525655974634, 0.43074755812995136, 0.5405624373815954, 0.7234126632101834, 0.39134913473390043, 1.1118506197817624, 0.5913128703832626, 0.40516733075492084, 0.49104684905614704, 0.6496909784618765, 1.696641140151769, 0.47163823270238936, 0.5870115011930466, 1.1789198708720505, 0.3421684034401551, 1.4051706553436816, 9.047853145748377, 30.701985843479633, 61.38963505625725, 61.211432218551636, 33.45647893846035, 16.575077287852764, 22.321626730263233, 46.82366006076336, 64.15848568081856, 64.86238270998001, 54.48621109127998, 27.84876074641943, 2.936574574559927, 0.026727532022050582, 0.21440992219140753, 0.09354673500638455, 0.039072679937817156, 0.10965502806357108, 0.017653110553510487, 0.06227757461601868, 0.0545079155563144, 0.08085083696641959, 0.11508866969961673, 0.0592561875237152, 0.02301931137481006, 0.008491482094541425, 0.052158465259708464, 0.08706723659997806, 0.07194203688413836, 0.023986300111573655, 0.06979108511586674, 0.027287000048090704, 0.019924305088352412, 0.026153911239816807, 0.04614034893165808, 0.058219637285219505, 0.0725828146096319, 0.0013097424516672618, 0.04858351392613258, 0.025786665028135758, 0.04057683516293764, 0.0012359980200926657, 0.05971432270598598, 0.08227495156461373, 0.04180674826784525, 0.03513766823743936, 0.03750202085939236, 0.05211553943809122, 0.06176279501232784, 0.015769556448503863, 0.05505918285052758, 0.043119373731315136, 0.0607410617521964, 0.0349358819948975, 0.018132014738512225, 0.03425538452574983, 0.11391945314244367, 0.0072384019222226925, 0.026309597124054562, 0.030448677171079908, 0.016752193369029555, 0.0679515533556696, 0.08523622469510883, 0.03644222655566409, 0.028988668600504752, 0.04664141364628449, 0.0917588864103891, 0.040780421113595366, 0.0339088052714942, 0.05349140330508817, 0.03322606280562468, 0.07601432735100389, 0.11013396564521827, 0.04351713148935232, 0.015333592928072903, 0.05463876361318398, 0.005497164374901331, 0.057751713175093755, 0.026133902938454412, 0.07934089298942126, 0.07236914287204854, 0.0192975094250869, 0.07881063589593396, 0.015299086771847215, 0.022600341180805117, 0.015400734100694535, 0.0691677255963441, 0.0620432600408094, 0.008457750554953236, 0.043118650137330405, 0.035256118717370555, 0.029808027466060594, 0.03668045967060607, 0.04005453760328237, 0.03757029844564386, 0.06968408226384781, 0.026253427677147556, 0.02104339513607556, 0.016229584107350092, 0.06378743695677258, 0.023609470918017905, 0.015127646020118846, 0.051225292481831275, 0.12736950680846348, 0.06220528572157491, 0.052622500516008586, 0.07739907101495191, 0.07545125248725526, 0.04112763861485291, 0.14920064160833135, 0.3964824811555445, 0.20383609895361587, 2.5845581386238337, 27.80649371445179, 73.76634612679482, 86.47914916276932, 67.09692880511284, 52.44342550635338, 17.973039373755455, 20.51784262061119, 52.792227789759636, 78.5410787165165, 95.9807901084423, 66.80530205368996, 19.700460880994797, 1.4005289669148624, 0.4724383569555357, 0.16094452003017068, 0.4110338893951848, 0.4307417693780735, 0.6048932229168713, 1.3685268466360867, 0.9475839498918504, 0.6413278053514659, 0.6138180533889681, 0.46189315093215555, 0.18418048101011664, 0.6238793197553605, 0.6036274158395827, 0.8531334868166596, 1.1972441500984132, 1.7217035265639424, 0.7886159769259393, 1.416929243132472, 1.8676236527971923, 1.07178901322186, 3.8985725166276097, 4.664904233068228, 2.0650545274838805, 5.121494857594371, 4.249450676143169, 5.101470407098532, 4.894095109775662, 3.0667945370078087, 2.2392416931688786, 2.2619153140112758, 2.3513416154310107, 0.3201482881559059, 2.1070349123328924, 0.6143479468300939, 1.706292147282511, 1.1428842670284212, 0.6567660206928849, 1.3294888101518154, 0.7722993555944413, 0.468776214402169, 0.40434060792904347, 0.3482151258504018, 0.33672599704004824, 1.7253159452229738, 0.6700569950044155, 0.20962452428648248, 1.1170777142979205, 0.7286806055344641, 0.3848709276644513, 1.1674375995062292, 1.042823523748666, 10.249190032482147, 52.77558848261833, 80.0248534977436, 66.93719297647476, 30.419092923402786, 16.435575373470783, 23.553169146180153, 49.99581724405289, 74.17019605636597, 66.55900686979294, 33.45774807035923, 3.61110582947731, 0.09201577340718359, 0.1208439061883837, 0.0850267757778056, 0.04244539974024519, 0.019368249086255673, 0.04070265516929794, 0.04697972166468389, 0.01836525505495956, 0.057794368112809025, 0.08023608635994606, 0.07693858322454616, 0.07872282498283312, 0.036469196202233434, 0.01718513263767818, 0.050557689828565344, 0.022872735353303142, 0.0313301055575721, 0.06021008848620113, 0.0298561408999376, 0.028430777638277505, 0.005882024070160696, 0.03590567233914044, 0.03336339352244977, 0.01631084185646614, 0.07580921999760903, 0.04275823725038208, 0.027659151855914388, 0.059696507451008074, 0.03660928770841565, 0.07306888423045166, 0.049097261944552884, 0.03583059296943247, 0.02823903636453906, 0.03448218485573307, 0.026626846702129114, 0.07376852910965681, 0.045889940884080715, 0.09046127830515616, 0.061809528051526286, 0.05995323488605209, 0.037489289315999486, 0.00646611794763885, 0.0017502091850474244, 0.0523343171516899, 0.031952949284459464, 0.04666710308811162, 0.10249896557070315, 0.13307083368999884, 0.14484193408861756, 0.2535211789654568, 0.158721208863426, 0.1259410209604539, 0.16761000064434484, 0.17020586994476616, 0.1712102777673863, 0.07726107607595623, 0.0964742701034993, 0.1435968032456003, 0.15629965520929545, 0.22040867217583582, 0.08817828362225555, 0.1151171830133535, 0.10141482882318087, 0.07891614703112282, 0.1664561391226016, 0.07195982616394758, 0.15183191135292873, 0.13748163997661322, 0.16434714838396758, 0.22559530480066314, 0.13405805337242782, 0.10861126414965838, 0.15533513040281832, 0.20242707221768796, 0.27310366567689925, 0.09674592583905905, 0.22814107913291082, 0.1795523293549195, 0.09394124586833641, 0.11301789214485325, 0.18476737139280885, 0.15111933083971962, 0.14002820098539814, 0.08883197471732274, 0.16819365526316687, 0.22310406347969547, 0.15570123185170814, 0.15264401386957616, 0.09126083110459149, 0.14392555982340127, 0.17806179996114224, 0.16370769910281524, 0.24417243374045938, 0.14736057550180703, 0.21939420083072037, 0.27346740709617734, 0.2747546473983675, 0.37491712428163737, 0.5625122564379126, 3.4569435892626643, 35.226469561457634, 87.79005602002144, 101.36649191379547, 86.41117081046104, 96.8243296444416, 59.93644863367081, 24.857454858720303, 35.19640177488327, 58.961679339408875, 86.32105484604836, 82.81774923205376, 39.31488297879696, 13.870652206242085, 3.1399831222370267, 0.8923671534284949, 0.6888656294904649, 3.222959744744003, 5.781195983290672, 2.40739478264004, 1.8507898435927927, 2.0919765578582883, 1.4522722153924406, 2.7161013800650835, 0.3912219306221232, 2.1119558857753873, 3.045780952088535, 2.4448555475100875, 8.449073676019907, 8.185894098132849, 3.5315986583009362, 3.3764878939837217, 7.086903294548392, 7.5841498374938965, 5.825974205508828, 10.603200886398554, 6.346725337207317, 8.323345072567463, 8.438894022256136, 11.528037060052156, 14.900388401001692, 5.182468285784125, 2.53774750046432, 1.8130930163897574, 1.958824577741325, 0.5464291444513947, 0.9990230365656316, 0.5335194559302181, 0.8616072696167976, 1.0463860700838268, 0.9207630297169089, 1.1849816143512726, 1.3117213197983801, 2.5298831099644303, 1.017512131948024, 1.1870025121606886, 1.698712504003197, 4.216812802478671, 3.799978969618678, 3.702505175024271, 2.833334351889789, 1.8710520188324153, 0.7485813251696527, 3.046836107969284, 17.411243319511414, 47.4244724214077, 87.37716257572174, 80.62917307019234, 47.91301220655441, 26.432451345026493, 35.17080634832382, 70.23492962121964, 83.48139122128487, 87.8946416079998, 71.77288949489594, 42.155865132808685, 5.356958722695708, 0.18182894156780094, 0.2328832692001015, 0.36160234187263995, 0.1256882306188345, 0.3338813449954614, 0.08898742496967316, 0.22754373931093141, 0.16712613520212471, 0.1431328570470214, 0.13201904715970159, 0.2076340396888554, 0.25362148764543235, 0.1550566469086334, 0.12997824494959787, 0.13765372917987406, 0.11710229446180165, 0.15973229601513594, 0.17078030708944425, 0.12160693790065125, 0.20319509116234258, 0.12453753064619377, 0.09902613004669547, 0.1633275710628368, 0.07722296679276042, 0.16681450739270076, 0.10000445137848146, 0.14145990775432438, 0.12003493553493172, 0.11086217578849755, 0.22289406537311152, 0.19929609959945083, 0.13535105274058878, 0.159383486607112, 0.13526355352951214, 0.12197173316963017, 0.2392197705921717, 0.07731637349934317, 0.25456161063630134, 0.2128037513466552, 0.1583964450401254, 0.14749799156561494, 0.13372463610721752, 0.15675016853492707, 0.18642561131855473, 0.1590086129726842, 0.10724244697485119], [0.020471985953918193, 0.012794337435479974, 0.00798509154265048, 0.05699108602129854, 0.03396505635464564, 0.06487570004537702, 0.06639169994741678, 0.043796509271487594, 0.10022170768934302, 0.05086530261905864, 0.005957391949777957, 0.05278301592625212, 0.026687968129408546, 0.08673851712956093, 0.022495310586236883, 0.0619739434478106, 0.026171103090746328, 0.031114006997086108, 0.014670057244074997, 0.06572441270691343, 0.04048170296300668, 0.0035821334677166305, 0.005132301848789211, 0.040429251675959677, 0.055907168207340874, 0.044305255214567296, 0.0191044972234522, 0.026641179429134354, 0.01668792338023195, 0.03928573198209051, 0.07256642056745477, 0.056259395205415785, 0.05576054951234255, 0.061206844766275026, 0.02015661957557313, 0.014719753307872452, 0.0167657060228521, 0.06377590398187749, 0.018408017604087945, 0.09946945938281715, 0.11567207940970547, 0.012928543710586382, 0.019735831119760405, 0.09746512630954385, 0.05388091209169943, 0.03464353518211283, 0.08152341571985744, 0.07401066221063957, 0.03416729159653187, 0.07105931159458123, 0.023720396020507906, 0.06237891488126479, 0.08138412944390438, 0.3386966366088018, 0.15662036690628156, 4.548904532566667, 38.91449086368084, 69.4581601023674, 64.57606047391891, 71.59211799502373, 71.6735552251339, 49.795978367328644, 22.667972445487976, 21.161129102110863, 35.57626359164715, 50.60977689921856, 62.73930363357067, 73.15875872969627, 51.58627510070801, 28.470012210309505, 16.817285791039467, 9.524652510881424, 3.433669600635767, 0.28857560420874506, 0.018063161987811327, 0.3897353494539857, 0.7137748959939927, 0.83389031002298, 1.0178817808628082, 1.2549558095633984, 1.0686759115196764, 1.0003079613670707, 1.31037013605237, 0.7914807857014239, 1.080658568535, 1.6748070367611945, 0.8556028199382126, 5.109930178150535, 2.5094152707606554, 0.5026527028530836, 2.53006502520293, 2.66612954903394, 2.422622940503061, 0.048566303521511145, 1.2249644938856363, 1.1692383466288447, 4.966832231730223, 4.254673970863223, 0.4937238647835329, 5.653289146721363, 0.07172288067522459, 2.7478121034801006, 1.3265396934002638, 0.15440366085385904, 2.0702937338501215, 1.1633347696624696, 2.168666892684996, 0.9727990406099707, 0.9057645814027637, 1.0376657755114138, 0.9920681035146117, 0.9048897377215326, 0.9678530716337264, 2.3869523545727134, 13.31195393577218, 25.428108237683773, 58.10137890279293, 61.19550347328186, 50.99490903317928, 25.55811256170273, 11.024116650223732, 22.776405327022076, 53.265423998236656, 63.425520211458206, 59.72504697740078, 44.841519221663475, 30.835949555039406, 6.167048653587699, 0.0613539607002167, 0.055007113769534044, 0.09606012943550013, 0.16084372153272852, 0.0597345907590352, 0.024313117828569375, 0.07821063918527216, 0.015184363728621975, 0.0842109254153911, 0.09964768614736386, 0.06982161707128398, 0.05756488120823633, 0.09252385512809269, 0.024124285773723386, 0.013991878058732254, 0.015685823636886198, 0.04745395031932276, 0.057829438301268965, 0.03723184941918589, 0.013990211009513587, 0.008895253104128642, 0.014203495902620489, 0.06948367270524614, 0.05599749871180393, 0.04658317360735964, 0.07558083889307454, 0.04198111215373501, 0.05191957905481104, 0.03218155674403533, 0.03451257951383013, 0.02063115065539023, 0.02081833143165568, 0.027453790316940285, 0.0729783125279937, 0.048708532413002104, 0.07141721231164411, 0.03730251672095619, 0.02952542134153191, 0.08113119809422642, 0.007497151709685568, 0.022844259146950208, 0.05301059551129583, 0.022346413497871254, 0.0648081794497557, 0.02724228750594193, 0.029512736182368826, 0.06915097532328218, 0.03013342953636311, 0.01756778026901884, 0.013055014023848344, 0.023499443814216647, 0.024130939127644524, 0.09892168018268421, 0.03893829554726835, 0.04665529922931455, 0.021922728810750414, 0.01761819250532426, 0.11608487679040991, 0.05217581296165008, 0.02529340585169848, 0.07277853379491717, 0.05833316361531615, 0.06253415733226575, 0.03403466609597672, 0.0025888692243825062, 0.026145391384488903, 0.03686100935738068, 0.07894341353676282, 0.012188461987534538, 0.022382852948794607, 0.035144173161825165, 0.03305545047624037, 0.03281267541751731, 0.05880775221157819, 0.04922898573568091, 0.012689703889918746, 0.0209799786171061, 0.03674215069622733, 0.03450156233157031, 0.013213860529504018, 0.04842303562327288, 0.032632303846185096, 0.025660887695266865, 0.08381344596273266, 0.05898707364394795, 0.04827033502806444, 0.06033144818502478, 0.10546381585299969, 0.053824412389076315, 0.07197776387329213, 0.06405869193258695, 0.10540437724557705, 0.16939304012339562, 0.05817063327413052, 0.08557494831620716, 0.14078655716730282, 0.0251860170828877, 0.10176165669690818, 0.12005193071672693, 0.11979915521806106, 0.17626286367885768, 0.27198524912819266, 0.26576489384751767, 5.924502918496728, 47.29643829166889, 82.18885257840157, 75.97730308771133, 64.87337931990623, 40.50596706569195, 16.168620698153973, 12.517922893166542, 35.209062695503235, 73.75702142715454, 97.34531208872795, 96.62230968475342, 68.49547415971756, 30.680268108844757, 9.66087520122528, 2.344569666311145, 2.2578032221645117, 2.540504727512598, 1.0915442719124258, 0.2216339876758866, 0.6432069232687354, 0.5120420583989471, 0.35518697986844927, 0.46517382957972586, 1.2237045052461326, 0.8521122322417796, 0.3582778468262404, 1.1394141032360494, 0.9804865624755621, 0.8511558710597456, 0.7206238503567874, 1.0491301165893674, 1.0624354588799179, 2.0077417278662324, 0.28371424006763846, 3.5864959750324488, 0.5755143868736923, 1.576331639662385, 1.2169262627139688, 1.6802293458022177, 1.9849656312726438, 2.3103479901328683, 2.8058725129812956, 0.7436615391634405, 3.4479128988459706, 0.9267046046443284, 1.8455116893164814, 0.7802496571093798, 1.49854565737769, 1.7345452937297523, 0.6652707955799997, 1.0604803450405598, 0.7416160020511597, 1.3306530914269388, 0.5891334498301148, 0.34758738765958697, 0.3522792155854404, 0.238271216803696, 2.8550214506685734, 2.233852157369256, 5.439237607643008, 35.315179601311684, 64.01705726981163, 78.59348550438881, 56.98955476284027, 28.076478727161884, 17.63434834778309, 30.789280459284782, 50.65568223595619, 69.42721456289291, 61.01716764271259, 37.63578727841377, 8.124098964035511, 0.18970407836604863, 0.05640611037961207, 0.011546240784809925, 0.0652083900058642, 0.013566611669375561, 0.008549783360649599, 0.1080727024236694, 0.05033070767240133, 0.01968366927030729, 0.055961485995794646, 0.13356090348679572, 0.10355718652135693, 0.0833085628983099, 0.08656026810058393, 0.05579952339758165, 0.030308656168926973, 0.08371811709366739, 0.015618445904692635, 0.012000831284240121, 0.01835886145272525, 0.0417429977824213, 0.034757406610879116, 0.015330004644056316, 0.06582121102837846, 0.04064856002514716, 0.02541836311138468, 0.023263168113771826, 0.038142787452670746, 0.05482500928337686, 0.03814764851995278, 0.04623027867637575, 0.005387970795709407, 0.03816223172179889, 0.07103495430783369, 0.01927571625856217, 0.09920658325427212, 0.07778341445373371, 0.02580324831797043, 0.10800082542118616, 0.06429042754461989, 0.008934541474445723, 0.075779348553624, 0.05232340387010481, 0.09700471273390576, 0.09877280535874888, 0.03881205622747075, 0.04218683920043986, 0.026340596632508095, 0.10530890736845322, 0.13747678633080795, 0.11565803797566332, 0.1508837434812449, 0.10683048822102137, 0.14810134278377518, 0.17541451466968283, 0.1683798007434234, 0.17251299927011132, 0.17079535784432665, 0.1563349665957503, 0.13635715265991166, 0.18097481864970177, 0.13631974841700867, 0.10195819966611452, 0.1306873225257732, 0.06743595367879607, 0.08806260506389663, 0.12237475646543317, 0.19485957047436386, 0.12657718994887546, 0.12837682384997606, 0.09958678550901823, 0.1178587284812238, 0.1497094432124868, 0.19057497382164001, 0.15216798550682142, 0.16482512117363513, 0.13175399653846398, 0.10293927436578088, 0.17946714564459398, 0.28861615515779704, 0.16488061897689477, 0.11848467809613794, 0.18761908868327737, 0.24027025094255805, 0.16711613105144352, 0.21373078285250813, 0.19890595256583765, 0.21193736814893782, 0.13234428595751524, 0.17231095698662102, 0.139703422319144, 0.2217790627037175, 0.2972914755810052, 0.163235500222072, 0.2979165123542771, 0.2742716280044988, 0.2708387793973088, 0.19125047663692385, 0.18955175997689366, 0.1969233198906295, 0.2762409910792485, 0.5206511495634913, 0.27818630856927484, 7.275011725723743, 58.16368415951729, 95.75656414031982, 89.37186554074287, 86.21326223015785, 99.08064097166061, 74.50460091233253, 30.720107071101665, 33.45368228852749, 50.45365087687969, 74.36321809887886, 84.72393214702606, 92.10999101400375, 67.04702228307724, 39.59850735962391, 25.916490331292152, 15.230285748839378, 5.348721714690328, 1.1493290774524212, 0.11662575401715003, 0.5742174689657986, 1.4645542250946164, 1.558776581659913, 2.263587461784482, 4.275435106828809, 4.252592157572508, 3.570854114368558, 5.292024482041597, 3.8207116071134806, 4.21356825158, 5.891949590295553, 5.651644309982657, 16.37218527495861, 16.676668636500835, 11.383690405637026, 16.127639897167683, 12.451708596199751, 9.412372335791588, 10.81700686365366, 12.032744027674198, 16.48857682943344, 17.56266139447689, 18.633869513869286, 9.040334299206734, 17.881445288658142, 5.172600215300918, 8.699837420135736, 8.379669450223446, 9.591920301318169, 10.33475099131465, 8.449707292020321, 7.111911177635193, 2.146208197809756, 3.7152344919741154, 1.9548106868751347, 1.0129488143138587, 1.3817623676732183, 1.3298702146857977, 6.308554485440254, 28.79420891404152, 52.6868936419487, 84.47848051786423, 90.53942888975143, 69.10594180226326, 40.429370775818825, 19.522676020860672, 39.15864296257496, 79.01982262730598, 87.03933790326118, 85.92335298657417, 68.61455976963043, 41.85371674597263, 10.686314776539803, 0.1884309240267612, 0.2413529553450644, 0.17180818162159994, 0.3013203281443566, 0.2851239941082895, 0.18147061782656237, 0.28777981409803033, 0.17401713965227827, 0.1126810981077142, 0.16174866672372445, 0.20442968350835145, 0.22489017545012757, 0.2312634131521918, 0.1344787175185047, 0.1547199345077388, 0.06906554670422338, 0.2539281133795157, 0.10787889055791311, 0.12561416428070515, 0.1163416079361923, 0.1763828392722644, 0.17378173040924594, 0.13803176436340436, 0.1016492213238962, 0.10906013732892461, 0.17874291341286153, 0.13611680071335286, 0.11323868107865565, 0.2165402570972219, 0.10988150927005336, 0.18857038841815665, 0.14092501223785803, 0.12374496145639569, 0.26111723855137825, 0.16627756354864687, 0.2434176398674026, 0.2578891930170357, 0.10381480082287453, 0.23255957406945527, 0.13458509696647525, 0.0855472958937753, 0.23259975394466892, 0.1164422431611456, 0.23497128684539348, 0.2597738621989265, 0.20330904051661491, 0.11536996593349613, 0.17805679788580164], [0.03809690417256206, 0.03191224990587216, 0.06305144168436527, 0.04444186975888442, 0.022285108389041852, 0.0654516214854084, 0.05280194811348338, 0.03189307652064599, 0.02763787633739412, 0.04684851737692952, 0.06346233174554072, 0.014870269205857767, 0.08310389341204427, 0.10837151334271766, 0.08366884590941481, 0.04995200826670043, 0.05231372626440134, 0.023812498402548954, 0.04175015208602417, 0.10435059433802962, 0.06110507034463808, 0.08910974574973807, 0.017449975457566325, 0.01580025167640997, 0.024891390021366533, 0.054324939046637155, 0.025586648807802703, 0.0045379751463769935, 0.014548113103955984, 0.030756913365621585, 0.011932323632208863, 0.07060669056954794, 0.01933026040205732, 0.0337217469495954, 0.016207963490160182, 0.07851391041185707, 0.013165563414077042, 0.031957309402059764, 0.03393558938114438, 0.059762391611002386, 0.03712828271090984, 0.06029620359186083, 0.05534953328606207, 0.042844575000344776, 0.029476697491190862, 0.04537273445748724, 0.09269228554330766, 0.023734958813292906, 0.05129700992256403, 0.05648767240927555, 0.033916738830157556, 0.20033503213198856, 0.06294919599895366, 0.05269784334814176, 0.07991521139047109, 0.4762594972271472, 0.16281053161947057, 13.60916543751955, 55.6742287427187, 69.10782650113106, 70.50652384757996, 73.40316161513329, 71.49299651384354, 49.33437913656235, 33.75542789697647, 23.758299238979816, 13.150059822946787, 36.52082450687885, 58.080913200974464, 62.28939637541771, 64.33561697602272, 57.84202761948109, 59.31883357465267, 58.11792701482773, 44.551522582769394, 30.56020025163889, 21.63801871240139, 10.304414369165897, 5.814155889675021, 3.1021138792857528, 0.5058649554848671, 0.32083361700642854, 0.23298190062632784, 0.09765052222064696, 0.26948866434395313, 0.2933908661361784, 0.07252435563714243, 0.49922593985684216, 0.3707791166380048, 0.21413767273770645, 1.7670861538499594, 0.8802834455855191, 1.7836327222175896, 0.4344614432193339, 0.7151433569379151, 1.3830817281268537, 0.9901703428477049, 0.19273448997410014, 0.5732714978512377, 1.6808330384083092, 2.414067699573934, 1.3801725092343986, 0.968484787736088, 0.8341310627292842, 1.5015953499823809, 0.3387589770136401, 0.19873221579473466, 0.3792721062200144, 1.338026358280331, 5.254510995000601, 12.260195072740316, 25.76996259391308, 33.735296577215195, 46.61619879305363, 44.04386222362518, 35.834862515330315, 51.70597247779369, 24.981601797044277, 13.790594302117825, 32.89125546813011, 52.09390126168728, 64.31134387850761, 58.546692207455635, 50.328284204006195, 28.36782619357109, 5.313409259542823, 0.10205418904661201, 0.04176078335149214, 0.06549050260218792, 0.15553647506749257, 0.07058297152980231, 0.22239430312765762, 0.019811283418675885, 0.02323222241102485, 0.07657608119188808, 0.01631808336242102, 0.0850539532257244, 0.07345211444771849, 0.07139830238884315, 0.0632151000900194, 0.04128801301703788, 0.10395989069365896, 0.030965590449341107, 0.017037732832250185, 0.030871782983012963, 0.032629056950099766, 0.03831498797808308, 0.022428925476560835, 0.01620492996153189, 0.07349176739808172, 0.07152261212468147, 0.027941247753915377, 0.026007329652202316, 0.02667204535100609, 0.12668382172705606, 0.030468895129160956, 0.02635489039676031, 0.042948991467710584, 0.07467515155440196, 0.10445027219248004, 0.06510502367746085, 0.03427493269555271, 0.036465147786657326, 0.048201523095485754, 0.04897794315184001, 0.014983605360612273, 0.025403889376320876, 0.0452420979127055, 0.06022615227266215, 0.007116758351912722, 0.05947645695414394, 0.08380646235309541, 0.01767098332493333, 0.04191163599898573, 0.10007868098909967, 0.046666320122312754, 0.06906508657266386, 0.04042813474370632, 0.07986902754055336, 0.09097099275095388, 0.007192045522970147, 0.08080571438767947, 0.045213547491584904, 0.006833873922005296, 0.004633155122064636, 0.019601723179221153, 0.0733501062495634, 0.07593860602355562, 0.041242560182581656, 0.03354775042680558, 0.08476591829094104, 0.04946904824464582, 0.040971386843011715, 0.06236032408196479, 0.05479342718899716, 0.04804724172572605, 0.07244003281812184, 0.11921439479920082, 0.028386495541781187, 0.04397702185087837, 0.07216353085823357, 0.05341741860320326, 0.054105578747112304, 0.04960780017427169, 0.044032508521922864, 0.049670585867716, 0.0888843926077243, 0.04836124069697689, 0.034630632944754325, 0.03941106959246099, 0.03765312212635763, 0.13429741084109992, 0.023393029114231467, 0.10639081767294556, 0.06096777302445844, 0.01399998602209962, 0.056691388235776685, 0.03299592652183492, 0.07316632822039537, 0.07864120358135551, 0.04409157976624556, 0.07168230004026555, 0.017902245817822404, 0.11351844106684439, 0.01229773117302102, 0.0288942878250964, 0.1310647788341157, 0.08763481630012393, 0.05837269411131274, 0.06246596880373545, 0.15043523395434022, 0.5488565610721707, 0.3576387092471123, 19.4858692958951, 67.16993808746338, 82.74171531200409, 80.99947839975357, 72.36123472452164, 55.04764996469021, 25.18441591411829, 17.417220398783684, 22.799882367253304, 29.85337357968092, 77.4818703532219, 106.69352486729622, 109.16983678936958, 95.04067495465279, 78.47465828061104, 65.89795634150505, 42.72960014641285, 24.462422356009483, 10.197940282523632, 1.2509807478636503, 1.49822837440297, 2.510168580338359, 2.4652378913015127, 0.7912476919591427, 0.4219870094675571, 0.10641133805620484, 0.1309787342324853, 0.16612552717560902, 0.2557857387000695, 0.3326858044601977, 0.2105201777885668, 0.4485823167487979, 0.3721116576343775, 0.698830772889778, 0.5633308156393468, 0.624959827400744, 1.0369539074599743, 0.7171017362270504, 0.18443664070218801, 0.6805513193830848, 0.35782807564828545, 0.6257396168075502, 0.5816342553589493, 0.16597889363765717, 0.27411215531174093, 0.28423463401850313, 0.21751267835497856, 0.8390912809409201, 0.2530114125693217, 0.09050632666912861, 0.42588898446410894, 0.8537425228860229, 2.1632718946784735, 1.5625698468647897, 5.0902320351451635, 10.889808107167482, 27.275230921804905, 55.572173818945885, 58.452666252851486, 81.36517077684402, 46.131663993000984, 22.57909331470728, 14.011441301554441, 19.37834646552801, 48.59160639345646, 65.83818554878235, 65.2427726984024, 40.40977902710438, 8.08147570118308, 0.2881768631050363, 0.030657014722237363, 0.030403678902075626, 0.03792141593294218, 0.0394262279587565, 0.1180896996811498, 0.060795746903750114, 0.05797645775601268, 0.03938569927413482, 0.06232908708625473, 0.09266669629141688, 0.03502416417177301, 0.018686261755647138, 0.0672002846840769, 0.03035620742593892, 0.03581939767173026, 0.013814310877933167, 0.03319207244203426, 0.031227373765432276, 0.04169170053501148, 0.022320777861750685, 0.010469372446095804, 0.031325285308412276, 0.06500357951154001, 0.02055653698334936, 0.047160419780993834, 0.07763270652503707, 0.011488549935165793, 0.016073801743914373, 0.036782464158022776, 0.026810261078935582, 0.01044631855620537, 0.04389531881315634, 0.04064341323100962, 0.04183822646155022, 0.011893169776158174, 0.0306175454534241, 0.04755172456498258, 0.037858003124711104, 0.023765153091517277, 0.053456659661605954, 0.025646462199802045, 0.028729787081829272, 0.020870198277407326, 0.04221499628329184, 0.0260882033398957, 0.09406323268194683, 0.03524369887600187, 0.04512869032623712, 0.03038620689039817, 0.1598921843105927, 0.19762136915232986, 0.26363012089859694, 0.1566102440119721, 0.09693267988041043, 0.16269340587314218, 0.1395824522478506, 0.10183185644564219, 0.16100297158118337, 0.15448511898284778, 0.11471001111203805, 0.12181364087155089, 0.10569711739663035, 0.16086224553873762, 0.17363638820825145, 0.2308405374060385, 0.211156866280362, 0.19352088449522853, 0.26683418022003025, 0.17578030441654846, 0.2507431717822328, 0.2783579524839297, 0.16647647396894172, 0.13694344932446256, 0.17279779101954773, 0.15679922449635342, 0.10298643042915501, 0.1984050325700082, 0.14494294038740918, 0.0996721324918326, 0.12485424958867952, 0.1425887885852717, 0.09575773394317366, 0.10469146276591346, 0.14319218433229253, 0.1815076806815341, 0.061532951876870357, 0.11335381044773385, 0.262827918631956, 0.1627077886951156, 0.1715144098852761, 0.18114241043804213, 0.2461004295037128, 0.13720661489060149, 0.1293846158660017, 0.13396593800280243, 0.20959482353646308, 0.1722550138947554, 0.13143806427251548, 0.16900013230042532, 0.17522937851026654, 0.3086303046438843, 0.3727631742367521, 0.21396748343249783, 0.24177706305636093, 0.7766673993319273, 0.81068180850707, 22.42770753800869, 83.61509844660759, 98.18268075585365, 92.5621135532856, 92.88808286190033, 98.15428107976913, 74.92114216089249, 50.0846678763628, 31.301926150918007, 21.164389327168465, 51.59088045358658, 78.68499979376793, 84.67198893427849, 86.7875026166439, 80.78801214694977, 88.66034612059593, 82.30547592043877, 71.72704875469208, 54.32019799947739, 43.17022830247879, 23.972026370465755, 12.952802907675505, 6.652652621269226, 1.2669235048815608, 0.6835667544510216, 0.532148441998288, 0.3689457447035238, 0.9021519846282899, 1.641027561854571, 0.571479715872556, 0.9237342327833176, 1.7571602552197874, 1.8759837979450822, 5.050337500870228, 3.60890194773674, 8.299367409199476, 6.643956312909722, 5.498801311478019, 6.74164954572916, 4.177576582878828, 6.58785754814744, 6.634630188345909, 8.889501392841339, 7.08771787583828, 5.5708283465355635, 5.078240353614092, 3.239367501810193, 5.178183540701866, 1.8700564722530544, 0.5035235092509538, 0.8923966612201184, 3.2154458854347467, 13.465100917965174, 28.010307177901268, 53.37895430624485, 72.80320420861244, 80.49461469054222, 76.56595230102539, 56.81677043437958, 62.037591487169266, 37.870629876852036, 24.518456049263477, 51.64094656705856, 74.42086100578308, 90.49924984574318, 79.28859740495682, 76.20178744196892, 47.8836739808321, 9.382599033415318, 0.25931322597898543, 0.34484334115404636, 0.20133424492087215, 0.2655895985662937, 0.24028267449466512, 0.3381442412501201, 0.1514142454834655, 0.2167591906618327, 0.13345161481993273, 0.17734918976202607, 0.19535965926479548, 0.12765219085849822, 0.14041107497178018, 0.10070256001199596, 0.12074425059836358, 0.17760054033715278, 0.2121592703042552, 0.1630309791653417, 0.1333754853112623, 0.14883897820254788, 0.1315115814213641, 0.15813454112503678, 0.13478938053594902, 0.14005471050040796, 0.18478265963494778, 0.17831684643169865, 0.12219909753184766, 0.11294191106571816, 0.15065734391100705, 0.17419528478058055, 0.12223601937876083, 0.10436010124976747, 0.15674019407015294, 0.13793057994917035, 0.20123270427575335, 0.14090040262090042, 0.148710809298791, 0.1710243697743863, 0.12715527846012264, 0.14694026758661494, 0.12480611389037222, 0.12863378506153822, 0.10429204630781896, 0.1067452080314979, 0.14565204764949158, 0.13619747216580436, 0.2051936651696451, 0.09640806310926564, 0.19504335592500865, 0.1522291830042377], [0.053611467956216075, 0.02781264283839846, 0.00971251911323634, 0.04483966462430544, 0.024981996975839138, 0.04379924779641442, 0.048421113460790366, 0.023683431500103325, 0.06878548985696398, 0.04550049146928359, 0.026301142206648365, 0.0542389909242047, 0.05151834062417038, 0.06143365993921179, 0.08047450872254558, 0.011712246232491452, 0.05909373139729723, 0.015024806616565911, 0.01982829715416301, 0.02547035055613378, 0.01710176162305288, 0.03514251817250624, 0.01947937642398756, 0.08175133669283241, 0.026378639122413006, 0.0261750049321563, 0.08291573671158403, 0.10266236422467045, 0.024868381588021293, 0.021898564482398797, 0.07611884400830604, 0.012951113349117804, 0.0662919033493381, 0.03734725709364284, 0.05654199019772932, 0.011063891179219354, 0.05858494092535693, 0.03413064063352067, 0.03525703155901283, 0.03682416172523517, 0.028725575393764302, 0.04829600591619965, 0.02546135387092363, 0.055905401895870455, 0.05665999909979291, 0.03768419584957883, 0.040160913340514526, 0.06381581668392755, 0.012059171513101319, 0.08842428331263363, 0.052400858112378046, 0.022267107597144786, 0.07012571950326674, 0.12358152569504455, 0.04102949700609315, 0.23351609852397814, 0.17628352507017553, 0.7091031060554087, 0.3411957446951419, 24.145173579454422, 61.80228911340237, 73.30956503748894, 66.31781861186028, 66.74517408013344, 70.10881438851357, 61.50159224867821, 67.84675776958466, 38.84005285799503, 16.915865801274776, 13.042470496147871, 14.33041613548994, 19.67730112373829, 27.378971055150032, 28.77624537795782, 45.6925405561924, 44.19456973671913, 37.16412618756294, 44.95842754840851, 36.025532484054565, 27.296086102724075, 33.90671297907829, 24.68604415655136, 24.74678199738264, 15.034224819391966, 11.99524573981762, 7.755584288388491, 6.123861595988274, 4.8065905552357435, 3.214603280648589, 1.2931500538252294, 0.5944834440015256, 0.28721569280605763, 0.5906121642328799, 0.30859310820233077, 0.1389744848711416, 0.1802669433527626, 0.3618616779567674, 0.24347046593902633, 0.3542131930589676, 1.9580420572310686, 1.8782268650829792, 2.625902770087123, 3.6331349099054933, 8.261879570782185, 17.36292701214552, 28.430823013186455, 39.784758165478706, 55.10770954191685, 51.65458783507347, 52.229094207286835, 45.68544253706932, 43.15438315272331, 26.24665081501007, 14.069474637508392, 16.862030290067196, 14.748852532356977, 23.48309140652418, 37.20434322953224, 49.72181394696236, 60.84904946386814, 67.18370094895363, 62.79470086097717, 42.24178992211819, 10.478137247264385, 0.20009895495604724, 0.22385842690709978, 0.10894493374507874, 0.15797803702298552, 0.0525513211323414, 0.03638619811681565, 0.030636600095022004, 0.01640901686187135, 0.040773957007331774, 0.03474842291325331, 0.1583507881150581, 0.05487893744430039, 0.02013310462643858, 0.13737327157286927, 0.06579308363143355, 0.03260577948822174, 0.059933816592092626, 0.02212548912211787, 0.049819880005088635, 0.04264048067852855, 0.03221476414182689, 0.023603528170497157, 0.038595549485762604, 0.0495471110480139, 0.08860173082211986, 0.10463963117217645, 0.046959182727732696, 0.033800544479163364, 0.015185472311713966, 0.061548603771370836, 0.07624758436577395, 0.02923829739302164, 0.07356877264101058, 0.060776480750064366, 0.025457546653342433, 0.06411340305930935, 0.09861561848083511, 0.010752050002338365, 0.03029219533345895, 0.02201904102548724, 0.0397812231676653, 0.04102353756024968, 0.005790084496766212, 0.012079396892659133, 0.059694407173083164, 0.025232351217709947, 0.04103043582290411, 0.028639614283747505, 0.045471614503185265, 0.06700843208818696, 0.036009432005812414, 0.0976007389544975, 0.035482948733260855, 0.051774923340417445, 0.04526933473243844, 0.050121726308134384, 0.03839518816675991, 0.04632814940123353, 0.00912923649593722, 0.020129562726651784, 0.08251343329902738, 0.027648071591102052, 0.047515240585198626, 0.02968313143355772, 0.03296729817520827, 0.02931690753030125, 0.03746635324205272, 0.07248186026117764, 0.03841937847028021, 0.04850264580454677, 0.017800699606596027, 0.0421085723064607, 0.021065275504952297, 0.07531747294706292, 0.020497387813520618, 0.04995806419174187, 0.02801467398967361, 0.05611166328890249, 0.09400938986800611, 0.12078955871402286, 0.062039330368861556, 0.03341911025927402, 0.06843827606644481, 0.024915454159781802, 0.008166043844539672, 0.06233324311324395, 0.06040272404788993, 0.030094225585344248, 0.0911834993166849, 0.014343256225402001, 0.03693686056067236, 0.049747561424737796, 0.028482008092396427, 0.05513553500350099, 0.02218966263171751, 0.016795286173874047, 0.06332344622933306, 0.023066597314027604, 0.042201184915029444, 0.06095375385484658, 0.013576328237832058, 0.04453530244063586, 0.019953206174250226, 0.029533436536439694, 0.028521907806862146, 0.04604199210007209, 0.02173378914449131, 0.06510805906145833, 0.13759701425442472, 0.8307001437060535, 1.8642547773197293, 33.38051341474056, 74.45021063089371, 78.6026506125927, 76.63357347249985, 68.72748211026192, 55.102693811059, 34.60358418524265, 20.939194411039352, 25.187784433364868, 20.74695512652397, 25.42793344706297, 32.702800780534744, 45.990877747535706, 55.96217729151249, 65.66969498991966, 73.74365374445915, 67.14373469352722, 61.29746340215206, 55.728953406214714, 43.676718324422836, 36.83198221027851, 25.75414214283228, 15.641344841569662, 7.127873646095395, 5.335435252636671, 3.0932646291330457, 2.4778717383742332, 0.9100296744145453, 1.2344418978318572, 1.272456245496869, 0.8979010221082717, 0.6004018045496196, 0.43880823184736073, 0.23683320177951828, 0.30538403196260333, 0.4570745344972238, 0.21176931622903794, 0.8589236042462289, 0.6409676559269428, 0.9554912068415433, 1.1414031777530909, 1.3202488934621215, 1.3087591412477195, 2.2993573173880577, 2.095282142981887, 2.495551952160895, 3.105163690634072, 7.424339912831783, 19.334605112671852, 28.10146238654852, 35.777709782123566, 42.00912460684776, 55.142960250377655, 47.32315845787525, 30.335653200745583, 39.92874763906002, 20.656599774956703, 31.629840955138206, 21.948950327932835, 28.699850477278233, 51.05387046933174, 67.35520854592323, 74.21314135193825, 55.08773401379585, 16.5615177154541, 0.5221221456304193, 0.30209895980078727, 0.08570898760808632, 0.04332969467213843, 0.014794328944844892, 0.04883168810920324, 0.04536812200967688, 0.021106256899656728, 0.06031138422258664, 0.016910261547309346, 0.09345279395347461, 0.08412102164584212, 0.037942671042401344, 0.062093781743897125, 0.05033545370679349, 0.03323318000184372, 0.03606274418416433, 0.044741044330294244, 0.009621117133065127, 0.018835991904779803, 0.0783268224040512, 0.06532672545290552, 0.06083076885261107, 0.037186823319643736, 0.08277765271486714, 0.07979199261171743, 0.06953559335670434, 0.04045875204610638, 0.026747790798253845, 0.025482683195150457, 0.030052143956709187, 0.015024792701296974, 0.04189093007880729, 0.063556198583683, 0.030998463880678173, 0.05259812838630751, 0.1138453719613608, 0.030951934932090808, 0.05528416491870303, 0.017264915368286893, 0.009762193840288091, 0.029274497501319274, 0.08270337857538834, 0.04952165167196654, 0.04633453187125269, 0.028525499801617116, 0.015019498405308696, 0.06643540502409451, 0.01578846451593563, 0.07843997766030952, 0.017566995447850786, 0.11468977274489589, 0.16133613651618361, 0.15107741433894262, 0.1280857386882417, 0.08258862770162523, 0.14839449111605063, 0.11890200999914669, 0.1063137456367258, 0.13532142620533705, 0.19730033091036603, 0.13918948505306616, 0.19765105505939573, 0.1154554019740317, 0.07170650889747776, 0.16607479396043345, 0.2606926707085222, 0.17023729247739539, 0.13216765481047332, 0.14723072934430093, 0.12955462705576792, 0.10800787582411431, 0.1262129141832702, 0.0986408960307017, 0.14059080829611048, 0.16861844575032592, 0.09247548936400563, 0.0887414846511092, 0.19703538418980315, 0.19668992928927764, 0.13053414324531332, 0.1301515067461878, 0.195607996720355, 0.10885845869779587, 0.18874606961617246, 0.1768088320386596, 0.13387309532845393, 0.1468365895561874, 0.1595667377114296, 0.07983220959431492, 0.11416570516303182, 0.31746735388878733, 0.14358285086927935, 0.12612563761649653, 0.15421614982187748, 0.10879329071030952, 0.1775897346669808, 0.08735867057112046, 0.19759842194616795, 0.13172653707442805, 0.18070443940814584, 0.16309645143337548, 0.14524275320582092, 0.13538290571887046, 0.24388465855736285, 0.20630117214750499, 0.14773500384762883, 0.38085899606812745, 0.26157282816711813, 0.739324843743816, 1.9983372325077653, 39.877549186348915, 91.60375937819481, 92.56566256284714, 84.48071479797363, 84.1915275156498, 90.99732711911201, 96.82180657982826, 95.87881118059158, 61.63650020956993, 26.046604849398136, 22.186678871512413, 20.454957894980907, 28.025219477713108, 34.156013801693916, 41.67342782020569, 62.499012127518654, 68.49541336297989, 67.47756958007812, 86.80400893092155, 79.20426473021507, 70.30320435762405, 77.24613100290298, 62.88672812283039, 61.05865761637688, 40.77461265027523, 34.661048501729965, 23.40949695557356, 14.222082048654556, 9.899080619215965, 5.9163471311330795, 2.2311835130676627, 1.0245940019376576, 0.9683569008484483, 1.0379616846330464, 0.9879620082210749, 0.7931149355135858, 1.094764955341816, 1.4917111303657293, 1.524195468518883, 2.445398918353021, 4.386120792478323, 4.6516818925738335, 6.768944906070828, 10.202072560787201, 16.61362811923027, 30.975631959736347, 47.93520301580429, 64.4469889998436, 86.39161705970764, 89.53360766172409, 89.99886989593506, 78.44682857394218, 66.29036888480186, 43.6307217925787, 18.989376537501812, 30.000448487699032, 23.6467220261693, 44.24420267343521, 55.21215833723545, 77.65877366065979, 80.90403512120247, 87.65578642487526, 82.55714401602745, 65.27328506112099, 18.67219615727663, 0.39004126272629946, 0.3469134878832847, 0.2359544247156009, 0.2660406759241596, 0.19725798396393657, 0.22012122353771701, 0.15202265814878047, 0.14705509267514572, 0.16935618506977335, 0.056474417651770636, 0.2236194850411266, 0.2356274938210845, 0.21347570669604465, 0.17647352971835062, 0.13654260052135214, 0.14773188682738692, 0.165499510767404, 0.1630271051544696, 0.1268720006919466, 0.17377404175931588, 0.16226892708800733, 0.12977106700418517, 0.19658353499835357, 0.13412570755463094, 0.20003619894851, 0.25937889120541513, 0.14607842633267865, 0.21094474563142285, 0.1116933515004348, 0.18680673383641988, 0.19561207853257656, 0.17527892428915948, 0.15525689319474623, 0.15590486233122647, 0.10483037796802819, 0.12080299900844693, 0.2794479893054813, 0.17238506785361096, 0.08374384735361673, 0.14718197024194524, 0.10850645805476233, 0.10537348163779825, 0.07706198011874221, 0.21059370978036895, 0.11800824897363782, 0.10391485717264004, 0.07982717041159049, 0.19790069869486615, 0.17520125111332163, 0.1259930306696333, 0.11747078562621027, 0.3029852028703317], [0.07411615108139813, 0.020048156548000406, 0.043166158720850945, 0.11571520561119542, 0.024182227098208386, 0.016052824939833954, 0.03625500496127643, 0.03637854286353104, 0.04636678560927976, 0.02913022028224077, 0.02387685002759099, 0.0678512075683102, 0.03389722034626175, 0.042896146842394955, 0.04051271731441375, 0.04837390544707887, 0.06985867250477895, 0.019142200180795044, 0.015866801913944073, 0.02784935502859298, 0.03065540426177904, 0.028922867932124063, 0.029949901982035954, 0.06931590280146338, 0.03976596090069506, 0.06387269488186575, 0.03638513313489966, 0.0030251356338339974, 0.050442679203115404, 0.05059655610239133, 0.02248099641292356, 0.03117555330391042, 0.038720864831702784, 0.060990286074229516, 0.04849680881306995, 0.05210937590163667, 0.035796283482341096, 0.0538651377428323, 0.07517669495427981, 0.055789003454265185, 0.05292221685522236, 0.06848492746939883, 0.025707893473736476, 0.05653594169416465, 0.026615092938300222, 0.04727016857941635, 0.05090275139082223, 0.04510663740802556, 0.022624073208135087, 0.007612537119712215, 0.00532633264811011, 0.0813710231159348, 0.09684999720775522, 0.014041679878573632, 0.05149048782186583, 0.18061967130051926, 0.091913653886877, 0.143558805284556, 0.04665034910431132, 0.3606303362175822, 2.6966402493417263, 31.09717983752489, 75.4950861632824, 76.34927272796631, 66.44282430410385, 71.5811213850975, 61.5311698615551, 72.2327484190464, 78.86701762676239, 87.46208041906357, 79.72770184278488, 62.16219440102577, 52.85346530377865, 39.18994568288326, 29.818658642470837, 36.19368106126785, 16.265979073941708, 12.80311468988657, 10.957625918090343, 16.222965382039547, 5.053299441933632, 9.924304615706205, 13.832060527056456, 19.650732949376106, 33.35429482161999, 44.17584054172039, 52.691726982593536, 41.969268545508385, 43.16300868988037, 37.888431921601295, 39.33597184717655, 41.08991213142872, 38.08143116533756, 34.084649831056595, 35.80478332936764, 42.27805137634277, 35.19124545156956, 38.506787940859795, 39.48895923793316, 25.840410813689232, 34.839559122920036, 43.70256833732128, 56.811853498220444, 54.40537802875042, 52.839432656764984, 45.90770401060581, 45.09059965610504, 35.15430763363838, 28.493876829743385, 30.991049632430077, 20.63369270414114, 22.91215304285288, 34.36904937028885, 46.95966996252537, 46.8282388150692, 58.71215432882309, 57.406054213643074, 55.99742420017719, 63.55940982699394, 65.81321328878403, 51.55069001019001, 15.934885740280151, 0.7342821580823511, 0.30101649288553745, 0.12689950468484312, 0.16289656137814745, 0.029340954970393796, 0.024530641312594526, 0.06876395273138769, 0.041757555009098724, 0.12426598623278551, 0.016835942878969945, 0.08082613829174079, 0.10616059604217298, 0.11718859139364213, 0.017684861486486625, 0.08538851339835674, 0.11852090232423507, 0.08180271557648666, 0.10578466855804436, 0.057579898566473275, 0.049838641498354264, 0.07924643985461444, 0.049728981757652946, 0.027616136976575945, 0.07464556212653406, 0.05739131513109896, 0.03417536987399217, 0.018563512385298964, 0.07124881900381297, 0.031289810649468563, 0.03282163685071282, 0.0458347473613685, 0.022662447809125297, 0.053181289476924576, 0.022565545586985536, 0.03486761554086115, 0.07547649292973801, 0.03546104424458463, 0.05045433092163876, 0.017998264884226955, 0.14769538800464943, 0.02249468903755769, 0.030320090809254907, 0.01868998362624552, 0.022019933458068408, 0.05592067158431746, 0.0323713239049539, 0.029609853627334815, 0.05642876072670333, 0.03018129435076844, 0.02127589330484625, 0.013948405830888078, 0.01951598471350735, 0.06860406443593092, 0.13284722459502518, 0.01212898627272807, 0.026700328598963097, 0.02078113870084053, 0.07666463425266556, 0.01863247831352055, 0.022635535679000895, 0.05592270135821309, 0.0215823205144261, 0.1061560763628222, 0.08856979620759375, 0.06391894552507438, 0.020155775382590946, 0.016856795373314526, 0.05645323675707914, 0.05850528621522244, 0.007803639218764147, 0.0185633936416707, 0.06609826217754744, 0.066388419654686, 0.014533364774251822, 0.0892413804831449, 0.03300733704236336, 0.032448095371364616, 0.05593242349277716, 0.07938588940305635, 0.01964331870112801, 0.026588941509544384, 0.004143515307077905, 0.042418055309099145, 0.041626217134762555, 0.08967911402578466, 0.014724898246640805, 0.031717191232019104, 0.041005837338161655, 0.013821466109220637, 0.09088127451832406, 0.004222693187330151, 0.032087192666949704, 0.034656567295314744, 0.036849342795903794, 0.008780959578871261, 0.03652175138995517, 0.06256509746890515, 0.0640793978527654, 0.022367676028807182, 0.052263790857978165, 0.1294986839639023, 0.012556424371723551, 0.05191530428419355, 0.03075222670304356, 0.015606846136506647, 0.1026298655779101, 0.025222775657312013, 0.05429520118923392, 0.038242420778260566, 0.1261441022506915, 0.016344956529792398, 0.1898926284047775, 0.08739676501136273, 0.5090364790521562, 4.772630352526903, 37.38684743642807, 84.28755596280098, 85.29752656817436, 77.00202450156212, 73.76791164278984, 63.44942472875118, 50.19561432301998, 35.78494839370251, 30.39757277816534, 23.778725042939186, 19.69397272914648, 26.67398728430271, 24.07353602349758, 39.63171377778053, 44.79261204600334, 30.66209938377142, 33.60932573676109, 26.70495182275772, 31.38972233980894, 32.719367891550064, 38.18510860204697, 43.33413250744343, 42.260781303048134, 45.71908973157406, 43.580762073397636, 42.06767186522484, 37.895146161317825, 32.5121346116066, 25.83583015948534, 22.944762893021107, 18.283999487757683, 16.901886351406574, 12.141917869448662, 10.315212439745665, 14.946932103484869, 22.959090024232864, 22.06737097352743, 26.284228898584843, 27.64237482100725, 31.307232566177845, 38.40814143419266, 51.917784512043, 60.24508707225323, 69.02997627854347, 73.7144561111927, 74.35697123408318, 71.26394480466843, 56.08059413731098, 53.31778518855572, 39.436921030282974, 34.83210392296314, 28.914772644639015, 22.374168410897255, 19.7530310600996, 21.440347619354725, 34.65745389461517, 54.463986083865166, 73.40905889868736, 78.58873575925827, 66.12494096159935, 24.933021403849125, 1.4033842762000859, 0.22136944171506912, 0.07871786001487635, 0.04478895367356017, 0.016099522727017757, 0.08754385125939734, 0.08214480854803696, 0.036236158121027984, 0.035852686705766246, 0.04528899422439281, 0.011080352014687378, 0.0756778079085052, 0.021560416025749873, 0.03332285370561294, 0.06085348599299323, 0.0437863047409337, 0.02063162377453409, 0.033201293626916595, 0.07525618639192544, 0.009054608908627415, 0.03863384801661596, 0.028894638489873614, 0.016622825896774884, 0.0036805072295464925, 0.12891149672213942, 0.045030177643639036, 0.007996229323907755, 0.059549250509007834, 0.05587227613432333, 0.009636240247345995, 0.0497387076029554, 0.03530301502905786, 0.03372178405697923, 0.0979390024440363, 0.029256526395329274, 0.035699277359526604, 0.07578534510685131, 0.05201895262871403, 0.016502122998645063, 0.012691020274360199, 0.05031882588809822, 0.032244698668364435, 0.05331550317350775, 0.06998417709837668, 0.04139978045714088, 0.054603741664323024, 0.02288373769260943, 0.013718723184865667, 0.036258192485547625, 0.03547439177054912, 0.01092151942430064, 0.0335673987865448, 0.024955303779279348, 0.059390334427007474, 0.2530109672807157, 0.09598362143151462, 0.14769982604775578, 0.14394899684702978, 0.09191067787469365, 0.09758921340107918, 0.15338645840529352, 0.12946616305271164, 0.16592250525718555, 0.23092448915122077, 0.1210435587563552, 0.11203423477127217, 0.10155285344808362, 0.10641655535437167, 0.15646649000700563, 0.13738122739596292, 0.24202920030802488, 0.16369034769013524, 0.15827654366148636, 0.1707414779230021, 0.17227018339326605, 0.10986720808432437, 0.0625458535796497, 0.1806156785460189, 0.11347609412041493, 0.09413383319042623, 0.13038902368862182, 0.09822246574913152, 0.11865388776641339, 0.08771543580223806, 0.21719451964600012, 0.12429580572643317, 0.08729828201467171, 0.16874996916158125, 0.11845423519844189, 0.13571788149420172, 0.15367282350780442, 0.10298251931089908, 0.1645384295261465, 0.15877237252425402, 0.10253737171296962, 0.14288468286395073, 0.2196418258245103, 0.21834109327755868, 0.1245215447852388, 0.13754041807260364, 0.2509654895402491, 0.18003631354076788, 0.12438731995644048, 0.08099379687337205, 0.16391033510444686, 0.25143791106529534, 0.3320774214807898, 0.14379749482031912, 0.1219233896699734, 0.29496703937184066, 0.26137684180866927, 0.28491850825957954, 0.15324954700190574, 0.7574767665937543, 5.166638335213065, 46.44822880625725, 103.70414927601814, 106.69415563344955, 88.65675911307335, 87.43010893464088, 85.15862122178078, 93.39765071868896, 107.96819686889648, 123.37142273783684, 110.40901109576225, 90.04440665245056, 75.62616392970085, 52.84442938864231, 43.17515663802624, 46.791882365942, 27.790804356336594, 24.766892418265343, 22.131747119128704, 32.45731495320797, 22.51877535134554, 31.216518133878708, 38.722445368766785, 49.898211881518364, 68.97892221808434, 77.80993714928627, 90.24271801114082, 72.50590056180954, 71.652891933918, 60.38376443088055, 60.045111402869225, 61.370981857180595, 60.96390210092068, 59.577489495277405, 62.49951370060444, 72.2777684032917, 70.85138574242592, 73.37081775069237, 77.42808803915977, 60.63345283269882, 76.80535465478897, 83.62355679273605, 94.70956832170486, 90.16957193613052, 83.95551458001137, 72.32594221830368, 68.40739488601685, 54.71652813255787, 43.77286076545715, 42.918894588947296, 34.0852539986372, 43.23973797261715, 59.96480271220207, 81.47177785634995, 79.05200690031052, 84.81115266680717, 89.34017524123192, 86.23154684901237, 96.12403482198715, 94.19180810451508, 75.42376399040222, 26.465904749929905, 1.066314100753516, 0.43087969010230154, 0.16482298378832638, 0.32976566115394235, 0.11212136290851049, 0.2798368450021371, 0.1711489021545276, 0.16736725898226723, 0.19796346954535693, 0.33285872486885637, 0.22111982776550576, 0.2485054629505612, 0.17733704822603613, 0.09766220362507738, 0.1296369609190151, 0.1695317475241609, 0.17613692121813074, 0.17074011237127706, 0.23591627832502127, 0.26743012480437756, 0.1655476019368507, 0.1323837088420987, 0.16304316523019224, 0.15367084939498454, 0.25297519576270133, 0.15677207673434168, 0.0801623985171318, 0.1721531615476124, 0.0867942524200771, 0.13501843699486926, 0.11163996139657684, 0.1204854340176098, 0.11337081305100583, 0.21547097072470933, 0.12068052237736993, 0.08170812885509804, 0.21354775439249352, 0.09123118230490945, 0.08049259486142546, 0.19518241955665872, 0.09189971635350958, 0.1310548637411557, 0.23782898584613577, 0.1761933689704165, 0.13898919423809275, 0.16939314402407035, 0.12107679212931544, 0.28284319618251175, 0.2614220237592235, 0.11991726802079938, 0.12932582292705774, 0.08886917858035304, 0.11816612604889087, 0.20875138754490763], [0.04465233541850466, 0.12563414289616048, 0.028775512655556668, 0.029194716626079753, 0.05032740882597864, 0.012285630455153296, 0.07493735232856125, 0.05076788831502199, 0.09913296220474876, 0.04309682728489861, 0.06869246164569631, 0.03316874674055725, 0.06795605819206685, 0.022343107229971793, 0.03693294944241643, 0.12761394056724384, 0.051377462441450916, 0.02063351625110954, 0.05718006650567986, 0.05091874467325397, 0.07359507435467094, 0.05830421985592693, 0.05103556613903493, 0.021950203117739875, 0.03146027826005593, 0.022784694374422543, 0.03477057231066283, 0.017780583693820518, 0.023853155107644852, 0.0376561389566632, 0.01620146413188195, 0.05565216255490668, 0.04356196463049855, 0.041866153478622437, 0.05445963884994853, 0.03407326148590073, 0.013988279570185114, 0.03476885423879139, 0.0705152950831689, 0.06465221711550839, 0.0188448011977016, 0.02028300175879849, 0.016705942725820933, 0.03844274870061781, 0.049027960194507614, 0.03334489549160935, 0.0385053191712359, 0.07435937513946556, 0.033585317942197435, 0.009061782693606801, 0.03587891420465894, 0.022470361436717212, 0.04402154329000041, 0.04774693908984773, 0.0312903115991503, 0.12580787966726348, 0.04558316300972365, 0.019824432420136873, 0.017016017591231503, 0.16796026466181502, 0.05208275135373697, 0.39331232313998044, 2.3319704923778772, 14.083502534776926, 37.67750523984432, 78.8439528644085, 94.86991211771965, 76.05407416820526, 74.88217145204544, 65.11158853769302, 72.51603081822395, 75.8065402507782, 79.13743391633034, 74.83200654387474, 57.30209179222584, 54.871058240532875, 48.37534859776497, 55.92621602118015, 47.275509014725685, 42.029852494597435, 34.58191394805908, 30.199825689196587, 22.479057982563972, 15.039593931287527, 9.62961807847023, 19.64313715696335, 16.711113788187504, 32.515698820352554, 63.7164705991745, 52.625963911414146, 26.144479997456074, 24.102976843714714, 20.514605194330215, 42.793619111180305, 44.402296990156174, 31.85766153037548, 12.815027050673962, 19.785904996097088, 19.29165791720152, 57.46390610933304, 42.574386075139046, 14.700575172901154, 15.52660334855318, 14.424640629440546, 18.84098120033741, 20.136643275618553, 27.93814145028591, 31.107089705765247, 41.926418244838715, 42.61152148246765, 64.83112558722496, 59.668061435222626, 64.3755604326725, 58.06728333234787, 65.8630134165287, 57.58698910474777, 60.84778033196926, 52.0913477987051, 37.19790257513523, 14.46352869272232, 1.3513195887207985, 0.479466465767473, 0.03405599170946516, 0.04593753481458407, 0.06642229869612493, 0.08303221678943373, 0.01985815746593289, 0.07291500733117573, 0.09282899656682275, 0.01655199161177734, 0.05441842367872596, 0.12750588386552408, 0.058645054887165315, 0.015036936092656106, 0.021596809092443436, 0.05181226079002954, 0.03448638541158289, 0.04858244523347821, 0.03551999674527906, 0.04400559082569089, 0.027069328134530224, 0.0436030091077555, 0.014803615067648934, 0.029636914186994545, 0.021007836985518225, 0.09109093865845352, 0.04459106370632071, 0.0314360508491518, 0.06993203380261548, 0.0784769440360833, 0.057573208105168305, 0.07822517785825767, 0.014739267153345281, 0.02197251949837664, 0.03618950671807397, 0.02610504081530962, 0.07428513810737059, 0.028322045582171995, 0.028230076786712743, 0.011126386507385178, 0.036073995142942294, 0.02240977806650335, 0.05160079323104583, 0.02206110966653796, 0.047882774379104376, 0.06124102808826137, 0.04767517340951599, 0.02799639118165942, 0.023712453184998594, 0.01891655945655657, 0.011825179772131378, 0.031620463414583355, 0.08125920372549444, 0.03638772323029116, 0.04053789838508237, 0.08184938924387097, 0.06219845425221138, 0.03980276029324159, 0.027246506615483668, 0.015772304250276648, 0.03919310081982985, 0.02030721432674909, 0.08967195972218178, 0.08605268361861818, 0.01362040809908649, 0.1287123339716345, 0.0525035379541805, 0.04786899640748743, 0.022076802379160654, 0.03686492047563661, 0.0323084899719106, 0.020928410485794302, 0.015142925913096406, 0.03425535112910438, 0.05255734366073739, 0.035535667193471454, 0.018019750059465878, 0.07213599717942998, 0.035489101137500256, 0.03533493851136882, 0.00832091243864852, 0.022713991820637602, 0.032775074505480006, 0.018129214986402076, 0.047613745846319944, 0.04243496143317316, 0.04963747494912241, 0.015546009508398129, 0.06233235995750874, 0.025237837544409558, 0.11225608497625217, 0.10490223270608112, 0.07292129332199693, 0.056812777620507404, 0.008324914469994837, 0.07932699998491444, 0.08106891706120223, 0.011125777018605731, 0.03276548224675935, 0.026575703450362198, 0.07361610681982711, 0.06900172200403176, 0.06250427846680395, 0.04613751021679491, 0.05276078489259817, 0.08739269062061794, 0.04979229066520929, 0.030277914556791075, 0.0438286220014561, 0.04846458476094995, 0.020781810344487894, 0.031296664383262396, 0.05806029817904346, 0.2042407327098772, 0.09993157989811152, 0.14688969764392823, 0.43390397157054394, 0.5742996395565569, 3.250498529523611, 22.536849081516266, 51.41102470457554, 97.43849068880081, 103.36013093590736, 87.7231416106224, 81.90073683857918, 70.17150342464447, 70.23706510663033, 55.67628063261509, 51.69978640973568, 42.73490846157074, 26.85454409569502, 33.435447067022324, 18.474832847714424, 16.994266994297504, 12.39724326878786, 25.353960916399956, 13.850271999835968, 17.789343930780888, 21.133561581373215, 25.08892133831978, 28.4065081179142, 45.766062811017036, 41.23898573219776, 53.445192351937294, 70.85339963436127, 65.99358960986137, 61.88812270760536, 60.401068702340126, 63.106101751327515, 75.60065969824791, 82.13770732283592, 67.7158471941948, 49.500984996557236, 53.25410060584545, 51.463594883680344, 56.02702461183071, 62.06016227602959, 39.14613023400307, 41.39636188745499, 36.67268715798855, 37.62360133230686, 28.536005169153214, 34.02300573885441, 36.86938740313053, 29.555897042155266, 40.1298176497221, 35.46325385570526, 39.99414972960949, 42.13336654007435, 48.07293422520161, 58.655715957283974, 65.10971143841743, 76.10039368271828, 72.19143703579903, 53.26961137354374, 23.7157529219985, 3.3901220373809338, 0.2904232550645247, 0.08445482482784428, 0.01587217877386138, 0.07448110220138915, 0.10554720356594771, 0.07039497068035416, 0.0694998589460738, 0.02907435697125038, 0.0472249866288621, 0.06290676741627976, 0.08389077032916248, 0.04715130249678623, 0.022021688637323678, 0.05289423788781278, 0.023248970828717574, 0.04586933515383862, 0.052722638502018526, 0.011626595896814251, 0.043256589415250346, 0.05507534311618656, 0.017108500323956832, 0.02563058580562938, 0.05243389110546559, 0.017647429413045757, 0.03144572845485527, 0.009806094658415532, 0.01465578574425308, 0.04233782543451525, 0.059795279885292985, 0.0026243165166306426, 0.010147985394723946, 0.04389507390442304, 0.02710781220230274, 0.07826805172953755, 0.03250036112149246, 0.04660188686102629, 0.0985157847753726, 0.04756578826345503, 0.013736938271904364, 0.04033621975395363, 0.06378631631378084, 0.012770316898240708, 0.026714095438364893, 0.02003782028623391, 0.008876320916897384, 0.00916281960599008, 0.050101083470508456, 0.05592636014625896, 0.05867237334314268, 0.028874978997919243, 0.036711266220663674, 0.07244755077408627, 0.05953610707365442, 0.05776408848760184, 0.022725686212652363, 0.12749405403155833, 0.2642431348795071, 0.12739473982946947, 0.07180578599218279, 0.16998426464851946, 0.09675231573055498, 0.1197605486959219, 0.17918852856382728, 0.1412965907366015, 0.1928560240776278, 0.1550430359202437, 0.15129514562431723, 0.18075790372677147, 0.132455266721081, 0.13369123946176842, 0.20449950476177037, 0.224400699371472, 0.1062581290898379, 0.10935834710835479, 0.16987564391456544, 0.17492968443548307, 0.12426555578713305, 0.29705749126151204, 0.08068075898336247, 0.07537438825238496, 0.16185875691007823, 0.1599250762956217, 0.13592548988526687, 0.1332092739176005, 0.12448984765796922, 0.13919672841439024, 0.07435445470036939, 0.1758863721624948, 0.1722193165915087, 0.2497422817396, 0.1289192892727442, 0.14262788492487743, 0.13842593383742496, 0.2353446464985609, 0.19720489071914926, 0.12901400215923786, 0.14657523483037949, 0.14533948473399505, 0.13474486651830375, 0.14898488443577662, 0.23240191221702844, 0.12763480975991115, 0.18455195560818538, 0.14303909410955384, 0.17772072373190895, 0.260886371252127, 0.1345507800579071, 0.12029194127535447, 0.11424658441683277, 0.11440169328125194, 0.2107222200720571, 0.17111868190113455, 0.39822777500376105, 0.15771801816299558, 0.2980984572786838, 0.3543849557172507, 0.7701313938014209, 4.257962219417095, 27.59660817682743, 67.99981355667114, 116.58334538340569, 124.15255442261696, 101.84576019644737, 98.22260901331902, 85.8763039112091, 96.58061072230339, 90.1187914609909, 94.44930508732796, 95.66643297672272, 78.51631924510002, 81.87112122774124, 82.22068727016449, 91.07831597328186, 83.054119348526, 75.12180179357529, 58.62389266490936, 56.913049668073654, 38.17286565899849, 30.291252583265305, 18.864446841180325, 34.816551357507706, 32.08906151354313, 46.58003993332386, 77.1717993915081, 70.88152572512627, 46.491763070225716, 39.068249613046646, 38.974907621741295, 63.39287996292114, 70.81100910902023, 54.67854157090187, 28.829586915671825, 34.83287148177624, 39.67085927724838, 77.78171986341476, 71.18772089481354, 27.800032161176205, 25.98479736596346, 25.90510994195938, 30.712021104991436, 30.267256870865822, 45.7905562967062, 51.79783634841442, 66.89446806907654, 72.80876711010933, 94.8528890311718, 91.99976652860641, 87.58885681629181, 77.21122607588768, 86.98114022612572, 83.5112652182579, 93.63322287797928, 85.28233498334885, 59.03633393347263, 21.740675903856754, 2.4353546323254704, 0.6815734051633626, 0.22208110196515918, 0.32242350513115525, 0.271945737185888, 0.23891336750239134, 0.15619073761627078, 0.15580115461489186, 0.2762338664615527, 0.2346275537274778, 0.1395509555004537, 0.24799863545922562, 0.19354015064891428, 0.08690071350429207, 0.1698708051117137, 0.1281918806489557, 0.18284008809132501, 0.20891678257612512, 0.10330952442018315, 0.13577355741290376, 0.14363144669914618, 0.16173095908015966, 0.08337465114891529, 0.09719338151626289, 0.1330966901150532, 0.15999123133951798, 0.08764963698922656, 0.12695472047198564, 0.18725199275650084, 0.20242643397068605, 0.11107215905212797, 0.1500458735972643, 0.20728834730107337, 0.14414615579880774, 0.12176405798527412, 0.1616700881277211, 0.15219090302707627, 0.19911307113943622, 0.10924401925876737, 0.06615701800910756, 0.24570381094235927, 0.10483594407560304, 0.14462568709859625, 0.1400794240180403, 0.13138939422788098, 0.15159878792474046, 0.11544291162863374, 0.13496075727744028, 0.17264943569898605, 0.16789339715614915, 0.09000611913506873, 0.1366003099246882, 0.24910489562898874, 0.18671086319955066, 0.09480378474108875, 0.17891383002279326], [0.05357118418032769, 0.02648201658303151, 0.013326644711924018, 0.04731000335596036, 0.02979232547659194, 0.041526090280967765, 0.051344685489311814, 0.060068471866543405, 0.037934422070975415, 0.08682000494445674, 0.02896454509027535, 0.034022739782813005, 0.05402640272222925, 0.016619499219814315, 0.05579931559623219, 0.06715041978168301, 0.010505615227884846, 0.04287839095923118, 0.024678976224095095, 0.03557290074240882, 0.10872830825974233, 0.06091513620049227, 0.02079835281620035, 0.03095921354542952, 0.018201444509031717, 0.00818698539660545, 0.02639420381456148, 0.005030298752899398, 0.03996817387815099, 0.03162012573739048, 0.03741566826647613, 0.02788430832879385, 0.08901501059881411, 0.06748002240783535, 0.08650924544781446, 0.0245362018540618, 0.07407006371067837, 0.03802373212238308, 0.02558070049417438, 0.14539047027938068, 0.01971903631783789, 0.03297837101854384, 0.01235450175954611, 0.033574245098861866, 0.008941024134401232, 0.010912662819464458, 0.012712134375760797, 0.024714187420613598, 0.07704216477577575, 0.09476638791966252, 0.05946615965513047, 0.05275321127555799, 0.050391853219480254, 0.05831543370732106, 0.0414726556482492, 0.04089082300197333, 0.007907726358098444, 0.08602130561484955, 0.014959120981075102, 0.1498918334254995, 0.007150041355998837, 0.21630135976010934, 0.09372963730129413, 0.3990891115972772, 0.12324169627390802, 4.37030746601522, 18.89412134885788, 25.681123360991478, 39.33877229690552, 68.37141841650009, 83.90954464673996, 90.27646780014038, 88.65458562970161, 85.20831495523453, 84.00264725089073, 81.63893088698387, 71.32481753826141, 70.84909066557884, 64.99438002705574, 56.57372407615185, 55.556875839829445, 61.26229628920555, 61.422054916620255, 69.57945719361305, 60.91994225978851, 50.62052272260189, 51.8197725713253, 41.659756153821945, 53.52656878530979, 63.06530334055424, 62.37653709948063, 46.954411044716835, 40.61453104019165, 27.963503189384937, 20.190161503851414, 32.52151630818844, 48.56555879116058, 45.90723663568497, 29.116990193724632, 60.10438822209835, 39.772940799593925, 50.29093600809574, 62.75974653661251, 69.31316748261452, 68.72272476553917, 72.9344567656517, 73.41497898101807, 74.70700845122337, 71.48442417383194, 70.71775451302528, 72.79438868165016, 81.17928475141525, 82.61313781142235, 88.57881009578705, 63.39969299733639, 32.65084616839886, 12.179516851902008, 2.6643222710117698, 0.18207217304734513, 0.5417381774168462, 0.1255521207349375, 0.026515775025472976, 0.11746377975214273, 0.05240135906205978, 0.06886081784614362, 0.08120457423501648, 0.08460106502752751, 0.06014201127982233, 0.052308019148767926, 0.10748364496976137, 0.02908094353188062, 0.03332101317937486, 0.0506020294415066, 0.05531727212655824, 0.04635950885131024, 0.010065792539535323, 0.07574584800750017, 0.04149129839788657, 0.030452300707111135, 0.07134273779229261, 0.03319222458230797, 0.05584074599028099, 0.033768758294172585, 0.012218693373142742, 0.04854982042161282, 0.01758117046847474, 0.03528561537677888, 0.05765874062490184, 0.07969855621922761, 0.0422375575726619, 0.04484533463255502, 0.01678221880865749, 0.04227178913424723, 0.05115230967930984, 0.04465353398700245, 0.054356061009457335, 0.028427860997908283, 0.025451776455156505, 0.060148423435748555, 0.06168793457618449, 0.03975847634137608, 0.0377422095334623, 0.03988139455032069, 0.07765157191897742, 0.0702249001187738, 0.07640275260200724, 0.01536082696475205, 0.027303008173475973, 0.0809621368534863, 0.009935427806340158, 0.06556209758855402, 0.015049121229822049, 0.015963416553859133, 0.023150150154833682, 0.04010443590232171, 0.061422587095876224, 0.01852394107118016, 0.0262591941645951, 0.07680897455429658, 0.049819616542663425, 0.0718214749940671, 0.03024278314114781, 0.039370555750792846, 0.03059626807953464, 0.058994124046876095, 0.07013885551714338, 0.030844590692140628, 0.04037215083371848, 0.0737801288778428, 0.05867314888746478, 0.01552308920508949, 0.10083019456942566, 0.008794948134891456, 0.03534333962306846, 0.04805455188034102, 0.014024591000634246, 0.05856298819708172, 0.005664902737407829, 0.03633358355727978, 0.028297523167566396, 0.013076061331958044, 0.018500444675737526, 0.039993469981709495, 0.05652993771946058, 0.04532643928541802, 0.03527657601807732, 0.054654660416417755, 0.029358217325352598, 0.009052401946973987, 0.02013972458371427, 0.01825421491957968, 0.024212625467043836, 0.04596933213179, 0.04019468105980195, 0.02068452406092547, 0.06097083067288622, 0.0384871254209429, 0.03976298117777333, 0.09808703864109702, 0.03956519140047021, 0.006505425335490145, 0.05123479197209235, 0.0438773551286431, 0.023205443867482245, 0.016706211754353717, 0.02125911520124646, 0.07913881359854713, 0.03266927022195887, 0.03800822494667955, 0.036007687958772294, 0.014598459474655101, 0.03272650465078186, 0.013907086758990772, 0.08599939741543494, 0.05972156977804843, 0.1851426754728891, 0.026168158619839232, 0.1421795238275081, 0.1438252511434257, 0.6598560267593712, 0.623591128969565, 7.331493319943547, 32.75509737432003, 40.38316145539284, 60.0191093981266, 86.2779575586319, 97.16300547122955, 101.28143727779388, 99.12831321358681, 88.99339064955711, 75.11373862624168, 69.64613601565361, 56.92561559379101, 48.37202377617359, 45.557659193873405, 37.487842217087746, 30.226914435625076, 27.198277451097965, 15.186475049704313, 18.71505405753851, 12.884421776980162, 37.08921320736408, 17.93546698987484, 32.87355601787567, 64.4198888540268, 55.277685821056366, 27.825200110673904, 32.01272360980511, 23.70446752756834, 34.60484951734543, 30.086994543671608, 28.04049275815487, 16.434828713536263, 28.21558926254511, 14.863988254219294, 68.8988833129406, 49.60584796965122, 11.579461600631475, 28.630965873599052, 27.080704160034657, 30.393375903367996, 27.16414388269186, 41.29685662686825, 44.48833957314491, 55.56534178555012, 59.37895014882088, 70.92809602618217, 81.36640191078186, 91.429842710495, 100.4844756424427, 87.60132014751434, 56.43136091530323, 26.389441452920437, 8.586251065135002, 0.8190814359113574, 0.18047671881504357, 0.13366035127546638, 0.21623553126119077, 0.07215832840302028, 0.04580089429509826, 0.0251498763464042, 0.12985340086743236, 0.05350519983039703, 0.03869552419928368, 0.06333546160021797, 0.06223925010999665, 0.10441677906783298, 0.012326774194661994, 0.020327432284830138, 0.0953610114811454, 0.014082706729823258, 0.04917330610624049, 0.05615189882519189, 0.0231278374849353, 0.02111221449013101, 0.056887048049247824, 0.03761656393180601, 0.07308682936127298, 0.08206418904592283, 0.02290360313054407, 0.016081115609267727, 0.02167520215152763, 0.030597065888287034, 0.07847321845474653, 0.006939354443602497, 0.10500980701181106, 0.035182204519514926, 0.05994988408929203, 0.02353673302422976, 0.06492811793577857, 0.06807774072512984, 0.04506645753281191, 0.04067089124873746, 0.031512454952462576, 0.09291481110267341, 0.04293532852898352, 0.012272124295122921, 0.006127257493062643, 0.06937974234460853, 0.03748938579519745, 0.009091044648812385, 0.022972392798692454, 0.042459597025299445, 0.01788790752470959, 0.0843771813379135, 0.02611738829727983, 0.0530482706381008, 0.034762994982884265, 0.011709337013598997, 0.06239050722797401, 0.013500887071131729, 0.030553520373359788, 0.15395096561405808, 0.16789854766102508, 0.21363859326811507, 0.1354387152241543, 0.16125681577250361, 0.11724283496732824, 0.17945993196917698, 0.16419094114098698, 0.16622519760858268, 0.15517628111410886, 0.11146687029395252, 0.15823106485186145, 0.16013995773391798, 0.177746431727428, 0.07824246247764677, 0.16665562841808423, 0.0870507831859868, 0.08194246198399924, 0.09149290068307891, 0.11225782902329229, 0.1778214777004905, 0.13220148190157488, 0.16377798048779368, 0.15148531354498118, 0.12109592469641939, 0.058620953641366214, 0.1171982689993456, 0.1533575591747649, 0.11361507611582056, 0.20267867512302473, 0.10696880970499478, 0.11737997643649578, 0.12976808357052505, 0.10009094126871787, 0.17697602306725457, 0.09565590386046097, 0.14953543926822022, 0.22406018717447296, 0.1286445462028496, 0.287168076611124, 0.13845688139554113, 0.10801074051414616, 0.11918853095266968, 0.15231455967295915, 0.08898067142581567, 0.14488944638287649, 0.11303477600449696, 0.11238861770834774, 0.1659183343872428, 0.2035330206854269, 0.17309643124463037, 0.14376635430380702, 0.1768115779850632, 0.18822242505848408, 0.12631371268071234, 0.12250313317053951, 0.16944599978160113, 0.16487218817928806, 0.1262433422380127, 0.2678618469508365, 0.17738781112711877, 0.4124334017978981, 0.40005939546972513, 0.6392955675255507, 0.5966605490539223, 7.936221845448017, 32.54482805728912, 46.97306804358959, 71.25017434358597, 101.41726478934288, 115.64864873886108, 120.06819918751717, 113.65136191248894, 102.33514353632927, 95.26658803224564, 91.12424030900002, 82.49478176236153, 80.00988990068436, 80.01136422157288, 72.57055029273033, 87.79523134231567, 97.82017260789871, 96.44528478384018, 108.9104551076889, 99.05117735266685, 89.15327847003937, 70.57108238339424, 68.9144016802311, 75.1900765299797, 84.02270257472992, 88.26228708028793, 72.09436744451523, 60.21295219659805, 43.93478907644749, 34.83128696680069, 49.481655433773994, 74.05055567622185, 66.98228895664215, 52.21511855721474, 96.51009410619736, 74.05307114124298, 73.17085728049278, 101.30935817956924, 103.81401658058167, 105.51401495933533, 106.95688873529434, 108.00794273614883, 100.13877019286156, 94.07092899084091, 91.14534437656403, 87.86159098148346, 95.32583445310593, 103.2738983631134, 113.70082005858421, 96.59132614731789, 62.76748292148113, 25.515936724841595, 5.8934148866683245, 0.4199087881715968, 0.4758408962516114, 0.17422253644326702, 0.3936391352908686, 0.28791728953365237, 0.18485167936887592, 0.19980971032055095, 0.4228655045153573, 0.18878780800150707, 0.13442194322124124, 0.18595090397866443, 0.34247137780766934, 0.13525279238820076, 0.2396175023750402, 0.15611627051839605, 0.21058027690742165, 0.16501992009580135, 0.0940592770348303, 0.13582889194367453, 0.11681089017656632, 0.11620494886301458, 0.19458076043520123, 0.15976741444319487, 0.20845371211180463, 0.1601766495150514, 0.14658960280939937, 0.14431300543947145, 0.14723681495524943, 0.10157134776818566, 0.24397690751357004, 0.1437759428517893, 0.1531074702506885, 0.15926705847959965, 0.15744205797091126, 0.15083053149282932, 0.14347071235533804, 0.16923202376347035, 0.10233120308839716, 0.24025190505199134, 0.1772514043841511, 0.16721250634873286, 0.1745681546162814, 0.10029497250798158, 0.09219459388987161, 0.14260035124607384, 0.10773837231681682, 0.15435261593665928, 0.10684959110221826, 0.16070081357611343, 0.05304103840899188, 0.19105468323687091, 0.09380966308526695, 0.1725674283807166, 0.13920290308305994, 0.0581040440738434, 0.17501106834970415, 0.12526919919764623, 0.12462927494198084], [0.04643911532184575, 0.040345351881114766, 0.0763995094166603, 0.06536870874697343, 0.0045569778376375325, 0.04981463302101474, 0.05655154163832776, 0.02399755107035162, 0.09687003519502468, 0.09090516425203532, 0.04983227758202702, 0.012530445492302533, 0.03917224647011608, 0.06275006293435581, 0.03547085914760828, 0.0648427041596733, 0.09266425462556072, 0.05712039412173908, 0.03848951142572332, 0.05442224944999907, 0.03611250518588349, 0.11435199907282367, 0.056250099805765785, 0.05948982303380035, 0.04725547776615713, 0.047522743698209524, 0.039497626275988296, 0.047732534003444016, 0.09209905721945688, 0.03008413979841862, 0.03755033467314206, 0.016332560808223207, 0.08746056002564728, 0.07521952429669909, 0.038609928596997634, 0.10588632794679143, 0.028029962231812533, 0.07262368468218483, 0.06723643469740637, 0.01926522600115277, 0.019654215284390375, 0.042642955741030164, 0.04204204247798771, 0.031084178226592485, 0.035571494372561574, 0.05634230423311237, 0.05066955003712792, 0.055303508997894824, 0.03582657423976343, 0.039486768655478954, 0.05521459970623255, 0.04552312697342131, 0.04493709377129562, 0.08323451140313409, 0.03757535989279859, 0.033927707772818394, 0.051532255893107504, 0.14591496088542044, 0.025361429252370726, 0.03172301709128078, 0.02167418355384143, 0.23812229745090008, 0.05099670357594732, 0.13279050966957584, 0.04726426108391024, 0.19965480925748125, 0.21123464335687459, 0.2546934754354879, 0.1333136940957047, 2.3322832630947232, 10.137730613350868, 14.454507976770401, 19.83603000640869, 44.81424428522587, 60.3244686126709, 58.49414102733135, 80.71473687887192, 81.4359001815319, 85.58280766010284, 80.8922253549099, 87.70623251795769, 80.2675312757492, 81.03549286723137, 79.96494591236115, 87.79255628585815, 83.1989523768425, 82.02150195837021, 72.34149858355522, 61.11764945089817, 68.21387127041817, 73.05048733949661, 81.48592829704285, 92.51897066831589, 81.75451308488846, 95.64298063516617, 86.36397734284401, 82.87486776709557, 74.00393977761269, 74.2490266263485, 59.93233345448971, 58.546597212553024, 70.65901726484299, 67.82496213912964, 71.16625964641571, 76.15138694643974, 76.4420485496521, 84.4120828807354, 91.43209978938103, 78.59757408499718, 77.1934962272644, 64.33841362595558, 37.75876767933369, 27.50620912760496, 14.931279793381691, 3.1992680160328746, 0.13120501505909488, 0.2976782829500735, 0.06578699802048504, 0.10241849449812435, 0.34824300091713667, 0.02251977548439754, 0.09960342445992865, 0.07193332407041453, 0.11784631977207027, 0.061733650873065926, 0.0038367246770576457, 0.022121435140434187, 0.03022068940481404, 0.022931608073122334, 0.01844354235799983, 0.0481838080304442, 0.06574566039489582, 0.04983434817404486, 0.019259108848928008, 0.0617637783579994, 0.04485189521801658, 0.040350112758460455, 0.06492583954241127, 0.025512365391477942, 0.01636118544411147, 0.07726341384113766, 0.043172081059310585, 0.019788952195085585, 0.019741020587389357, 0.054616721827187575, 0.020939956448273733, 0.06030834512785077, 0.13267776259453967, 0.016768554014561232, 0.03148887321003713, 0.0140001233194198, 0.10920307497144677, 0.04947166802594438, 0.04881204717094079, 0.04705716477474198, 0.06646320587606169, 0.03657210610981565, 0.033934387101908214, 0.044365343201207, 0.037653749241144396, 0.11406103265471756, 0.004440322427399224, 0.08709311528946273, 0.03473463380942121, 0.0027150997311764513, 0.027428321664046962, 0.0204886935534887, 0.03333455366373528, 0.06560841502505355, 0.030918386146367993, 0.046864243486197665, 0.05484312139742542, 0.02300578387803398, 0.01734916582790902, 0.02096659769449616, 0.07305455335881561, 0.0317905822157627, 0.0418172051286092, 0.03232780065445695, 0.04501121205976233, 0.0336133228847757, 0.041403769500902854, 0.05218986923864577, 0.04490863982937299, 0.031268236416508444, 0.06144892220618203, 0.041818481622613035, 0.04963557134033181, 0.05924405711994041, 0.10615400577080436, 0.042255844091414474, 0.06840520596597344, 0.01524032073575654, 0.08549023215891793, 0.03185350891726557, 0.02926544886577176, 0.031102301472856198, 0.03581369426683523, 0.07272765215020627, 0.02206611359724775, 0.13429513986920938, 0.04039928375277668, 0.04043780492793303, 0.05170502787223086, 0.024147923177224584, 0.0668544735526666, 0.03529712979798205, 0.06878784246509895, 0.06092610885389149, 0.054544102677027695, 0.004903535755147459, 0.03344648066558875, 0.018126218565157615, 0.020644941614591517, 0.04454401154362131, 0.040273708655149676, 0.04770369043399114, 0.003482388819975313, 0.008323642614413984, 0.039490694616688415, 0.09144203388132155, 0.04025073547381908, 0.022947629186091945, 0.11102615331765264, 0.015164191227086121, 0.018163426138926297, 0.022876225302752573, 0.03398115353775211, 0.05851803631230723, 0.03328944221721031, 0.03200384206138551, 0.011478645046736347, 0.03705109193106182, 0.09620873708627187, 0.023864393078838475, 0.05036311726144049, 0.06617735285544768, 0.1643949723802507, 0.06764254532754421, 0.13661411387147382, 0.12359167827526107, 0.24218534817919135, 0.2111018286086619, 0.2822033758275211, 0.18904600117821246, 5.165668437257409, 16.793301478028297, 28.20675853639841, 38.1622414290905, 70.55293455719948, 83.79031464457512, 88.5979762673378, 102.39391878247261, 92.54706636071205, 95.15690311789513, 90.99341332912445, 82.75532618165016, 79.25106301903725, 69.01706457138062, 64.09287080168724, 65.07259503006935, 57.46536523103714, 57.053056955337524, 56.998203098773956, 54.98312562704086, 67.91906028985977, 59.57991376519203, 55.48988163471222, 44.7636803984642, 37.32260428369045, 34.54227827489376, 47.7772568911314, 45.3129181265831, 39.90107752382755, 39.159273728728294, 53.47807198762894, 45.90097077190876, 55.97669631242752, 65.87834179401398, 68.65537717938423, 75.62390685081482, 77.87274017930031, 89.14431095123291, 97.56330639123917, 95.14742642641068, 97.59565025568008, 89.4748704135418, 65.67126050591469, 50.26541277766228, 29.28240481764078, 8.506261557340622, 0.6579265021719038, 0.32690533495042473, 0.1717066261335276, 0.06545979253132828, 0.2723246777895838, 0.06969087291508913, 0.03561262048606295, 0.05318287025147583, 0.08215997804654762, 0.10767256608232856, 0.05124322648043744, 0.014260298958106432, 0.09544966844259761, 0.06384155436535366, 0.02782804240268888, 0.11809544390416704, 0.018409982440061867, 0.041918159477063455, 0.041317724899272434, 0.026506297799642198, 0.03757384591153823, 0.07353768407483585, 0.0424619310797425, 0.034667595609789714, 0.030107526727078948, 0.017858091741800308, 0.07073513406794518, 0.032382890276494436, 0.04184822319075465, 0.0276753714933875, 0.06517422152683139, 0.09118936228333041, 0.04597738814482, 0.10600966546917334, 0.09552705218084157, 0.01830265118769603, 0.0391045403375756, 0.09784733978449367, 0.06586987365153618, 0.04892670527624432, 0.01685329985775752, 0.05247311361017637, 0.04165448553976603, 0.11314193470752798, 0.03354084474267438, 0.09146437252638862, 0.04407711159728933, 0.15282517211744562, 0.03484886146907229, 0.021743975121353287, 0.06231356877833605, 0.02449267489282647, 0.045416762368404306, 0.020676753774750978, 0.028828507565776818, 0.03582038843887858, 0.056379122179350816, 0.0698828516760841, 0.06163849640870467, 0.08264895688625984, 0.0569337736669695, 0.09433922255993821, 0.14054645755095407, 0.29569962818641216, 0.11962350370595232, 0.13104153476888314, 0.13561059662606567, 0.15887179062701762, 0.12349284646916203, 0.12002405564999208, 0.20760729268658906, 0.15268394141457975, 0.10066984614240937, 0.1853039738489315, 0.15203454735456035, 0.23517154797445983, 0.07824470376363024, 0.1653380342759192, 0.16981426830170676, 0.12477145559387282, 0.1558139789267443, 0.16296338435495272, 0.22313717810902745, 0.1394140292541124, 0.13986475038109347, 0.20881981356069446, 0.15852504438953474, 0.11474182698293589, 0.22709666955051944, 0.20712635130621493, 0.13732197432545945, 0.12525128375273198, 0.1749679198837839, 0.14799239550484344, 0.1561319298343733, 0.11887938191648573, 0.21218950540060177, 0.1631237773108296, 0.12154683136031963, 0.1146061549661681, 0.17864175868453458, 0.2632788475602865, 0.12278549809707329, 0.12619266839465126, 0.18418913445202634, 0.166731461067684, 0.16049710888182744, 0.1172665688500274, 0.17525896051665768, 0.16139745275722817, 0.13342378428205848, 0.10599064422422089, 0.15009142662165686, 0.2859802544116974, 0.23988215223653242, 0.1611239861813374, 0.1281484353239648, 0.21512170118512586, 0.26465799543075264, 0.17056502489140257, 0.24509280076017603, 0.1305661298101768, 0.35687524708919227, 0.14823960489593446, 0.3770517191151157, 0.2352307119872421, 0.29756455624010414, 0.3648850985337049, 0.42535469750873744, 0.20058250869624317, 3.2169627165421844, 11.962049771100283, 24.44196805357933, 39.558286517858505, 72.6890355348587, 90.95274031162262, 99.88577976822853, 120.40524110198021, 108.49006846547127, 120.62132030725479, 116.39407753944397, 114.38209310173988, 102.61382818222046, 110.41074380278587, 108.3337752521038, 115.15765428543091, 108.2301776111126, 102.1426610648632, 93.21035116910934, 80.19394442439079, 87.20010727643967, 94.16513353586197, 111.61562114953995, 117.92437702417374, 101.64636209607124, 117.78528168797493, 114.35978829860687, 115.70992425084114, 104.07673448324203, 99.77516010403633, 76.7544373869896, 84.27988797426224, 105.35802572965622, 104.3842139840126, 101.31786212325096, 102.04921647906303, 99.99777495861053, 105.83495333790779, 114.35246229171753, 102.69236236810684, 102.74330243468285, 90.49019873142242, 64.93162259459496, 46.680981516838074, 22.621666230261326, 6.01178708486259, 0.38446669466793537, 0.41868320549838245, 0.16485121508594602, 0.254186944803223, 0.48048323777038604, 0.15321781276725233, 0.18332243955228478, 0.1628951364546083, 0.4440965980757028, 0.13752029102761298, 0.1175914217310492, 0.1416417636210099, 0.22239682642975822, 0.1872419292340055, 0.27059496904257685, 0.17662316153291613, 0.11733428982552141, 0.13681508746230975, 0.08628283103462309, 0.15613285009749234, 0.1705697301076725, 0.13217164756497368, 0.25627867318689823, 0.10178288954193704, 0.1424817115184851, 0.2311882039066404, 0.20964750117855147, 0.1345129602123052, 0.1303483243100345, 0.15898106445092708, 0.14379038504557684, 0.1401624851860106, 0.32499353284947574, 0.28495137055870146, 0.13170531165087596, 0.07554534196970053, 0.23571408761199564, 0.2094320408650674, 0.10867912613321096, 0.11559174934518524, 0.0910856768314261, 0.1221539378457237, 0.17089091677917168, 0.21550301666138694, 0.19454562716418877, 0.20289667358156294, 0.13180683745304123, 0.20291389140766114, 0.10248354374198243, 0.09213620913214982, 0.09910156193654984, 0.1651980058522895, 0.12174186776974238, 0.2757667290279642, 0.2118527633138001, 0.12390303891152143, 0.1149422513844911, 0.18186459434218705, 0.15784508868819103, 0.16532859415747225, 0.1452042060554959], [0.09392105945153162, 0.05723898189899046, 0.015576837395201437, 0.042224250864819624, 0.04062565363710746, 0.006113751796874567, 0.05929623752308544, 0.006138035332696745, 0.08443624145002104, 0.04817156630451791, 0.050390098040224984, 0.03149779382511042, 0.036217604429111816, 0.06876614948851056, 0.014141037681838498, 0.017691169741738122, 0.07282494771061465, 0.009026780226122355, 0.00441372060777212, 0.04956149015924893, 0.03418509200855624, 0.023544712967122905, 0.029710958260693587, 0.02968426877487218, 0.0528402095369529, 0.060398675632313825, 0.055564811773365363, 0.01647878987569129, 0.08335044971317984, 0.05722397567296866, 0.06715189665555954, 0.01800814101443393, 0.0393349994556047, 0.0033358018981743953, 0.04286649804271292, 0.04025938891572878, 0.04520621136180125, 0.007860105524741812, 0.029408124901237898, 0.030945630387577694, 0.0404983419139171, 0.0218717618190567, 0.018244594830321148, 0.017559431107656565, 0.04153067675360944, 0.09109270496992394, 0.08919253232306801, 0.03582857061701361, 0.042212914559058845, 0.029295337008079514, 0.038453045999631286, 0.03559774413588457, 0.0262957783343154, 0.045968938793521374, 0.034823160895030014, 0.032419793569715694, 0.01001032627755194, 0.0991280195012223, 0.00831227662274614, 0.13561003259383142, 0.029818285802321043, 0.08299528752104379, 0.059352065582061186, 0.07623600686201826, 0.07065047728247009, 0.08867724434821866, 0.029136398661648855, 0.04345960020145867, 0.02649929934705142, 0.1252591802040115, 0.5728028761222959, 0.4483966314001009, 0.21549059310927987, 0.08135808748193085, 1.741405469365418, 6.377937337383628, 10.962648298591375, 21.28873385488987, 33.35946634411812, 47.431011870503426, 43.54918956756592, 49.58006255328655, 60.41823998093605, 65.71216151118279, 75.0160002708435, 73.677499294281, 83.95353108644485, 89.2484101653099, 97.5538221001625, 92.04044714570045, 89.47782665491104, 85.59017926454544, 83.77068489789963, 89.40290987491608, 72.91719049215317, 78.64092975854874, 78.33316147327423, 74.02337193489075, 71.9038912653923, 77.21923604607582, 72.78978332877159, 69.25171718001366, 66.18536531925201, 64.16168510913849, 40.24324916303158, 30.87530594319105, 26.11681178212166, 14.702222384512424, 8.9517230540514, 3.0280202301219106, 0.3132365777855739, 0.1549220213200897, 0.033560463416506536, 0.07324711099499837, 0.058389937912579626, 0.038199031114345416, 0.37433649762533605, 0.123714570509037, 0.06523737829411402, 0.06732912152074277, 0.036542928573908284, 0.2438279436319135, 0.17973172129131854, 0.058682039816631004, 0.03992345205915626, 0.04761551215779036, 0.04808456062164623, 0.05833218398038298, 0.018385126059001777, 0.039860647812020034, 0.032324891435564496, 0.004998075164621696, 0.022908156206540298, 0.044220219933777116, 0.023715388379059732, 0.05700503468688112, 0.0510298404697096, 0.06891018550959416, 0.07855585659854114, 0.08266587043181062, 0.05299666911014356, 0.08090369272395037, 0.02801321752485819, 0.018371351798123214, 0.032965936334221624, 0.026278111508872826, 0.0348855977790663, 0.04758612310979515, 0.030784806986048352, 0.13018478464800864, 0.0629514892352745, 0.0464179010305088, 0.0496111621032469, 0.016158141261257697, 0.0646036583930254, 0.02701592504308792, 0.051757664696197025, 0.06279680339503102, 0.02133655460056616, 0.012089473402738804, 0.04182762488198932, 0.08953311131335795, 0.026940333591483068, 0.02526265125197824, 0.03478007551166229, 0.01962895257747732, 0.0496228917472763, 0.043467533760122024, 0.054477109006256796, 0.07397426728857681, 0.027414018622948788, 0.0365045929356711, 0.06228581245522946, 0.0783975342346821, 0.043963563002762385, 0.06297841435298324, 0.05873249472642783, 0.06505965618998744, 0.017694780290185008, 0.08604791160905734, 0.03271003268309869, 0.035067642893409356, 0.029550871440733317, 0.06784480283386074, 0.08018383916351013, 0.04018140403786674, 0.05913857195992023, 0.04020517873868812, 0.03341143274155911, 0.051718015456572175, 0.026811919778992888, 0.03467054935754277, 0.10545928875217214, 0.013872388572053751, 0.006025258107911213, 0.0469824639003491, 0.04164847043284681, 0.06033322191797197, 0.007573380944450037, 0.0035048631389145157, 0.046321429254021496, 0.036811656536883675, 0.019254758008173667, 0.07009017062955536, 0.04425175007781945, 0.05318960153090302, 0.06756053800927475, 0.02477058322256198, 0.07481296095647849, 0.03936456661904231, 0.05500672043126542, 0.024318581890838686, 0.028290713962633163, 0.025733480870258063, 0.031672320983489044, 0.08842653202009387, 0.010626197527017212, 0.014267192582337884, 0.02336939171073027, 0.040345786037505604, 0.027749786640924867, 0.03213346928532701, 0.08670178824104369, 0.05303384328726679, 0.041179785621352494, 0.05022107761760708, 0.04722993675386533, 0.00831914427180891, 0.01688570759142749, 0.04371904760773759, 0.0022778015045332722, 0.03999280204880051, 0.04680715748691, 0.017406658153049648, 0.02687046038772678, 0.12735886441078037, 0.0994550839823205, 0.07076225956552662, 0.02161805492505664, 0.16162067593540996, 0.015653838927391917, 0.09002851715194993, 0.04504879441810772, 0.05127562122652307, 0.06071900141250808, 0.1904696482233703, 0.46516397385858, 0.3053005551919341, 0.10663243869203143, 0.08368870578124188, 5.715414388105273, 12.817164435982704, 21.01825676858425, 37.67111398279667, 50.19730143249035, 63.30624081194401, 69.48574662208557, 77.13162034749985, 83.61263617873192, 89.81903314590454, 98.85459870100021, 99.77584406733513, 100.72206169366837, 108.15997257828712, 105.76392754912376, 102.54676178097725, 100.10722428560257, 90.71933403611183, 97.60807558894157, 100.83155661821365, 94.24524083733559, 94.82583448290825, 91.21360391378403, 90.39189040660858, 92.192013412714, 98.19442212581635, 92.79554262757301, 89.26228702068329, 91.6120733320713, 88.15131783485413, 72.25854143500328, 58.496458902955055, 50.824393182992935, 36.46996043622494, 21.37066885828972, 9.19162793084979, 1.9200693885795772, 0.15651913796318695, 0.25836867978796363, 0.16103580419439822, 0.014731984829268185, 0.03864600810629781, 0.12327460310189053, 0.09187132920487784, 0.05964165160548873, 0.01979326036234852, 0.12108011695090681, 0.2444846701109782, 0.08831085346173495, 0.023388307199638803, 0.027693036463460885, 0.04633482873032335, 0.10704246786190197, 0.05121171117934864, 0.013129130456945859, 0.03501243823848199, 0.08966342502390034, 0.01373544098896673, 0.09066363229067065, 0.03404234732443001, 0.0664244731888175, 0.029538473863794934, 0.019734634406631812, 0.012419244867487578, 0.059168966618017294, 0.08187316765543073, 0.04882548746536486, 0.01573430999997072, 0.04378797828394454, 0.04327867573010735, 0.053650590270990506, 0.06835184554802254, 0.020256807656551246, 0.011264845288678771, 0.014454630327236373, 0.016252076748060063, 0.009025194813148119, 0.033097897612606175, 0.032214459861279465, 0.0697588016919326, 0.04106690495973453, 0.01722938504826743, 0.0722242088522762, 0.03371866332599893, 0.02575080630776938, 0.04847574666200671, 0.0626845535589382, 0.054731146155972965, 0.01890070161607582, 0.07494633231544867, 0.09839367921813391, 0.019282020803075284, 0.04493804743106011, 0.060185308175277896, 0.03511377108225133, 0.012806936319975648, 0.08739277225686237, 0.02996332372276811, 0.04344087952631526, 0.0812174059683457, 0.06859224944491871, 0.09337195922853425, 0.19135494134388864, 0.21849848795682192, 0.09960267489077523, 0.17347296728985384, 0.09422468690900132, 0.06618651837925427, 0.10145764332264662, 0.12094189936760813, 0.18839415803086013, 0.22078635112848133, 0.170734679850284, 0.1616244312026538, 0.14231993816792965, 0.11147216180688702, 0.08489433210343122, 0.11572886112844571, 0.2530392282642424, 0.07888384134275839, 0.08685515305842273, 0.10029903947724961, 0.12066996161593124, 0.12843652220908552, 0.06262118156882934, 0.0689754425548017, 0.168057827395387, 0.1617448520846665, 0.1232025257195346, 0.17321603576419875, 0.10098234968609177, 0.1468689026660286, 0.17781355156330392, 0.08571457598009147, 0.1718471889034845, 0.11439287656685337, 0.09595120442099869, 0.09038207630510442, 0.09725126903504133, 0.1018363241746556, 0.1051437424030155, 0.16890688886633143, 0.10288652250892483, 0.10631663259118795, 0.11923202080652118, 0.09330211571068503, 0.281856317888014, 0.24672833096701652, 0.2127434147405438, 0.15036867815069854, 0.11299980600597337, 0.13438575610052794, 0.13356237293919548, 0.10432591792778112, 0.1566798723069951, 0.134023884893395, 0.1046576356748119, 0.09756167230079882, 0.09151869031484239, 0.17892577860038728, 0.1130197400925681, 0.2699715946801007, 0.12916645413497463, 0.16751594084780663, 0.10878742774366401, 0.3158629790414125, 0.2377307551796548, 0.16772984265116975, 0.11010848029400222, 0.14352242520544678, 0.15296462166588753, 0.29965483001433313, 0.6364842527545989, 0.7128200784791261, 0.2974281198112294, 0.11449901852756739, 3.7314149737358093, 9.888010863214731, 15.784053783863783, 32.27524392306805, 43.2484433054924, 60.38420520722866, 63.693219646811485, 77.34232664108276, 86.41947716474533, 94.09405454993248, 101.11408665776253, 106.4063210785389, 113.33495289087296, 126.29958361387253, 126.83434411883354, 126.3021294772625, 125.67207768559456, 111.96123540401459, 112.491534948349, 122.232775837183, 106.1818215250969, 108.8548032939434, 108.94596800208092, 109.74248126149178, 107.56040275096893, 123.09881776571274, 111.35580629110336, 100.57823181152344, 95.47821387648582, 90.58169782161713, 70.20662873983383, 53.327292278409004, 43.05568724870682, 27.990291751921177, 14.375644158571959, 5.3736612014472485, 1.0320100164972246, 0.19658677076222375, 0.27320908033289015, 0.334349877666682, 0.14969117153668776, 0.1715956156840548, 0.5571185646113008, 0.12367089511826634, 0.1057731058972422, 0.1549097165116109, 0.28695119137410074, 0.6632427137810737, 0.29771919013001025, 0.18516793817980215, 0.10857358531211503, 0.153998923196923, 0.19442835298832506, 0.1458829446346499, 0.13844134082319215, 0.10377200116636232, 0.13788731273962185, 0.0912255939329043, 0.25465102458838373, 0.13614544761367142, 0.16737853962695226, 0.14152122399536893, 0.2303497848333791, 0.155783194641117, 0.1866321064881049, 0.1658895390573889, 0.16152701689861715, 0.17163616663310677, 0.21633030351949856, 0.1377514106570743, 0.15183669078396633, 0.14595240965718403, 0.1454553785151802, 0.14668490941403434, 0.19541211426258087, 0.1558734249556437, 0.13395624555414543, 0.13105294900014997, 0.1510818226961419, 0.16033573629101738, 0.152897234656848, 0.10819249248015694, 0.3224245144519955, 0.11604636674746871, 0.12628522905288264, 0.11290956084849313, 0.11920795295736752, 0.20358789508463815, 0.1232600050570909, 0.16721115563996136, 0.16469356807647273, 0.09436121239559725, 0.10861091534025036, 0.15913580224150792, 0.14090105571085587, 0.17256739869480953, 0.09626172643038444, 0.15850793046411127, 0.12490004010032862, 0.2349285242962651, 0.18131075921701267, 0.1523861027089879], [0.035954876730102114, 0.03053847889532335, 0.04433249203430023, 0.02064099895505933, 0.036838511150563136, 0.04454657937458251, 0.02887210503104143, 0.04696275616879575, 0.06286974909016863, 0.026610163222358096, 0.021846059389645234, 0.03003106510732323, 0.037481255567399785, 0.02915226577897556, 0.029852829065930564, 0.01448527267712052, 0.05305457147187553, 0.07451305165886879, 0.05588197229371872, 0.03561164456186816, 0.07488627772545442, 0.03967404962168075, 0.0411187662393786, 0.04419881268404424, 0.027597464541031513, 0.03613661385315936, 0.09178005988360383, 0.07693422681768425, 0.027457252435851842, 0.016702449065633118, 0.04379040139610879, 0.006988789364186232, 0.032895076074055396, 0.024962107418105006, 0.01621622173843207, 0.005791821122329566, 0.05430893834272865, 0.03831739995803218, 0.07038979791104794, 0.05012021974835079, 0.057107235843432136, 0.03952189450501464, 0.032134749490069225, 0.07144199262256734, 0.0015094648279045941, 0.09683844196842983, 0.07607506471686065, 0.04659440972318407, 0.022992616322881076, 0.044319081425783224, 0.045285706510185264, 0.09005082611110993, 0.0024199366998800542, 0.025768554769456387, 0.011112163247162243, 0.04652408380934503, 0.03175126694259234, 0.04885573740466498, 0.04407115586218424, 0.13250347663415596, 0.00990463980997447, 0.06564288778463379, 0.06394707292201929, 0.04508021323999856, 0.012352633402770152, 0.061462076773750596, 0.08664691384183243, 0.06356772413710132, 0.1646987334243022, 0.05609759216895327, 0.05436876657768153, 0.024431158271909226, 0.06322442888631485, 0.052229811626602896, 0.10677994796424173, 0.2906665310729295, 0.35030961502343416, 0.5945339100435376, 0.35198805620893836, 0.1693366072140634, 0.1157750969287008, 0.2780307247303426, 0.5105661344714463, 1.2925577606074512, 3.406706959940493, 3.7757170340046287, 6.824105121195316, 9.966822434216738, 11.508659049868584, 16.15917820483446, 18.281727209687233, 22.689110711216927, 20.33374059945345, 20.65122116357088, 15.252790041267872, 12.464748546481133, 13.359912112355232, 6.762043526396155, 7.649066504091024, 9.716048240661621, 7.542147841304541, 3.0143473763018847, 0.8130540093407035, 0.39290440909098834, 0.23231227562064305, 0.1708538390812464, 0.27404681663028896, 0.31364636204671115, 0.21915871737292036, 0.02864476107788505, 0.0492867953289533, 0.05181112159334589, 0.12085286391084082, 0.11629854852799326, 0.1508069905685261, 0.03503790503600612, 0.017052442199201323, 0.031621494999853894, 0.059837578592123464, 0.04714157294074539, 0.032514929480385035, 0.015652516049158294, 0.015497479544137605, 0.03225837273930665, 0.020638742826122325, 0.0021675499010598287, 0.04605001100571826, 0.058109298479394056, 0.024761569839029107, 0.08901355598936789, 0.015561103864456527, 0.04454480564163532, 0.0236402793234447, 0.03286197628767695, 0.040720377655816264, 0.016070007513917517, 0.02349333222809946, 0.07869168446632102, 0.027512572123669088, 0.033922624061233364, 0.07963420459418558, 0.04023678309749812, 0.08763523190282285, 0.02459283328789752, 0.052446563277044334, 0.020084675779799, 0.024096019224089105, 0.02730674488702789, 0.009772130269993795, 0.04008964489912614, 0.03669748824904673, 0.024707506236154586, 0.024088638565444853, 0.03351583807670977, 0.038576650695176795, 0.02978631036967272, 0.04893195226031821, 0.017556482926011086, 0.03161955428367946, 0.054832957684993744, 0.0350691383209778, 0.026469472431926988, 0.04240433299855795, 0.029299285233719274, 0.032642356236465275, 0.016190623209695332, 0.028264963293622714, 0.02894429930165643, 0.052566865415428765, 0.02124831695255125, 0.016110022261273116, 0.07148247677832842, 0.03739735206181649, 0.05488720868015662, 0.034552952347439714, 0.02333045307750581, 0.050760696904035285, 0.049284216365776956, 0.06106426335463766, 0.017823761845647823, 0.0291377605026355, 0.03019326519279275, 0.05327863327693194, 0.04974487113940995, 0.008392454546992667, 0.05474738063639961, 0.03295553142379504, 0.0447556386643555, 0.017191344413731713, 0.014895042095304234, 0.023263845323526766, 0.036166626305202954, 0.03161472290230449, 0.019992976012872532, 0.021061221523268614, 0.06922078173374757, 0.06090493538067676, 0.03392634593183175, 0.018064998803311028, 0.05307796767738182, 0.025923279572452884, 0.02322752832697006, 0.06084503293095622, 0.08336971586686559, 0.025286030759161804, 0.026618631127348635, 0.03846955136395991, 0.02117357711540535, 0.01736710539262276, 0.02641943869093666, 0.011546863261173712, 0.03331755848194007, 0.0390810142562259, 0.017121621494879946, 0.019319744169479236, 0.02506452194211306, 0.04732026354759, 0.0206681392955943, 0.005546146585402312, 0.04868964846536983, 0.0882542498584371, 0.049136165325762704, 0.046522369448211975, 0.04576449566229712, 0.05511351548193488, 0.09232082578819245, 0.04142328427406028, 0.02643627431098139, 0.06492264088592492, 0.03437279228819534, 0.023675822631048504, 0.02908830934757134, 0.053223038994474337, 0.043268957306281663, 0.045366693375399336, 0.09852777046035044, 0.02976653770019766, 0.08747685016714968, 0.022917724345461465, 0.06895329686813056, 0.07996630083653145, 0.02996825714944862, 0.09528435504762456, 0.1752830357872881, 0.12029766323394142, 0.05125965391926002, 0.06464639125624672, 0.0432911475218134, 0.07935424422612414, 0.022340767609421164, 0.19855855323839933, 0.39523635583464056, 0.34485180163756013, 0.2590105781564489, 0.42600986547768116, 0.4112163686659187, 0.5536279175430536, 1.0657063708640635, 2.763114357367158, 4.474171567708254, 9.615383092314005, 10.814397353678942, 18.12081154435873, 22.487054653465748, 27.110597155988216, 35.46735003590584, 37.717802077531815, 44.11461062729359, 41.05074003338814, 42.052655071020126, 34.16052035987377, 32.05427438020706, 33.01803566515446, 22.689393796026707, 20.95314536243677, 21.29923079162836, 17.609453983604908, 11.502713318914175, 4.440535772591829, 2.376774363219738, 1.0618286789394915, 0.3476012806640938, 0.4172451311023906, 0.02258391003124416, 0.06051588301488664, 0.1943040729383938, 0.0549832871183753, 0.17891138093546033, 0.07488428134820424, 0.15611503855325282, 0.13738728332100436, 0.05749552379711531, 0.007003259852353949, 0.05134066304890439, 0.09774020334589295, 0.10013259801780805, 0.08390569491893984, 0.04054712328070309, 0.039558597418363206, 0.07045872858725488, 0.029724682426603977, 0.035920930895372294, 0.04385709449707065, 0.027695572753145825, 0.013190470817789901, 0.022766276124457363, 0.07039131931378506, 0.038636349054286256, 0.039756943806423806, 0.03743691966519691, 0.12822974502341822, 0.035554235728341155, 0.015136733618419385, 0.026163559159613214, 0.040216340639744885, 0.07366045756498352, 0.03183528177032713, 0.03638278794824146, 0.10000438458519056, 0.08670091250678524, 0.02646832581376657, 0.08276007865788415, 0.04915849283861462, 0.02868752919312101, 0.020567422434396576, 0.022049064609745983, 0.02245266492536757, 0.03236100063077174, 0.036467259196797386, 0.05086630451842211, 0.07652511791093275, 0.088621397735551, 0.07152339880121872, 0.020297928203945048, 0.05675776963471435, 0.04804201329534408, 0.019411514440434985, 0.09154658022453077, 0.018822260317392647, 0.034527418756624684, 0.026167607575189322, 0.03753484234039206, 0.043500377505552024, 0.05957142588158604, 0.05170769218239002, 0.052315110369818285, 0.029240624025987927, 0.08644548754091375, 0.031177134078461677, 0.03201776846253779, 0.06321747496258467, 0.02548724183725426, 0.21174280671402812, 0.1254726664046757, 0.18820642435457557, 0.13227983785327524, 0.2030936544178985, 0.07284392442670651, 0.19240395224187523, 0.15127847698749974, 0.09880528174107894, 0.14934697828721255, 0.08149312867317349, 0.12370940516120754, 0.09097650690819137, 0.10658419167157263, 0.140052929345984, 0.0776164757553488, 0.16820017131976783, 0.13009608315769583, 0.14635024534072727, 0.09119863170781173, 0.2012480073608458, 0.09894153263303451, 0.09931459542713128, 0.16509315522853285, 0.12203924634377472, 0.13276370329549536, 0.13320664671482518, 0.2095819398527965, 0.1070241813431494, 0.23165660299127921, 0.22219272097572684, 0.10611527308356017, 0.15897365781711414, 0.0963837503513787, 0.09026766681927256, 0.17822768480982631, 0.140896380180493, 0.11767537347623147, 0.17255126440431923, 0.12072338882717304, 0.11895732226548716, 0.12119146136683412, 0.09660421274020337, 0.1359663376933895, 0.1317486382322386, 0.18543564568972215, 0.18004823243245482, 0.13301549915922806, 0.14142379484837875, 0.1556907527265139, 0.1399818909703754, 0.23741201759548858, 0.07880979726905935, 0.06300484965322539, 0.06481429474661127, 0.12672830605879426, 0.13574985321611166, 0.17335362994344905, 0.14058337197639048, 0.30078372568823397, 0.11281607250566594, 0.19361343031050637, 0.14332298043882474, 0.2153034828370437, 0.166743632289581, 0.27507302875164896, 0.23181528900749981, 0.40007679141126573, 0.40882932487875223, 0.15771322388900444, 0.1265927602071315, 0.17049622780177742, 0.1183510321425274, 0.07881106634158641, 0.16545771301025525, 0.49499106709845364, 0.3713602479547262, 0.6078934588003904, 0.316728976322338, 0.14847499929601327, 0.22018506308086216, 0.3231750038685277, 1.0760222235694528, 1.8493019859306514, 4.71903707832098, 6.415640814229846, 11.457666736096144, 15.475656632333994, 16.731834076344967, 24.357147105038166, 27.21782550215721, 33.79999190568924, 32.2278718650341, 31.65056314319372, 27.817133143544197, 25.210393220186234, 25.336457155644894, 15.963072627782822, 14.829150773584843, 12.77884729206562, 10.058597009629011, 6.214766493067145, 1.531741744838655, 0.5787771055474877, 0.3444305883022025, 0.19960288860602304, 0.6991323817055672, 0.6383319629821926, 0.5666057649068534, 0.2486010961001739, 0.18822151963831857, 0.32470703416038305, 0.5170731071848422, 0.34917383221909404, 0.22154960548505187, 0.23580802866490558, 0.1396756956819445, 0.13123569544404745, 0.24566593172494322, 0.2385768629028462, 0.1649473380530253, 0.12950870295753703, 0.16738115198677406, 0.2837039390578866, 0.08409161033341661, 0.10173133996431716, 0.1330890756798908, 0.169892119592987, 0.1268611801788211, 0.18760893610306084, 0.15054815914481878, 0.13806501257931814, 0.24711029953323305, 0.0847450787841808, 0.24362717784242705, 0.10388085938757285, 0.09747642179718241, 0.1804198554600589, 0.10309225326636806, 0.18621130875544623, 0.1738302074954845, 0.2738806646084413, 0.23553358245408162, 0.22602606215514243, 0.11357273659086786, 0.11693444292177446, 0.10318579355953261, 0.09115653709159233, 0.09965954566723667, 0.1713024525088258, 0.13218356645666063, 0.16992625838611275, 0.08814968125079758, 0.10034828839707188, 0.11534154909895733, 0.18962738482514396, 0.13541477354010567, 0.0797896771109663, 0.12436981269274838, 0.14944338327040896, 0.06312427605735138, 0.15728697879239917, 0.15018570906249806, 0.06638090169872157, 0.13666248705703765, 0.09893526148516685, 0.10944241017568856, 0.19730456115212291, 0.12258685484994203, 0.18937671702587977, 0.10401971521787345, 0.11763408780097961, 0.10871171383769251, 0.12556583562400192, 0.0881566722819116, 0.1451518846442923], [0.04445016696990933, 0.0492521147680236, 0.08784540070337243, 0.04763631084642839, 0.028923337340529542, 0.0179374811341404, 0.024388558995269705, 0.020820413155888673, 0.03859936783555895, 0.02270005614263937, 0.030758241809962783, 0.004326081316321506, 0.04397091026476119, 0.05413230348494835, 0.04083672414708417, 0.020651426129916217, 0.029726929278695025, 0.0422952558437828, 0.04079714170075022, 0.03256944393797312, 0.04877610866969917, 0.001454652931442979, 0.047918887285050005, 0.04282209905795753, 0.02457937072904315, 0.05727103525714483, 0.07181846187449992, 0.03228506036975887, 0.07553349729278125, 0.06598339256015606, 0.027500803516886663, 0.033786981730372645, 0.04396528107463382, 0.00785287329563289, 0.0409818362822989, 0.0315135347773321, 0.009971737381420098, 0.06769517101929523, 0.05801490100566298, 0.029955069185234606, 0.005978058907203376, 0.017802909351303242, 0.04886723698291462, 0.030149858830554876, 0.029303945921128616, 0.06598952269996516, 0.003548827967279067, 0.03861222925479524, 0.010686517434805864, 0.03692823309393134, 0.10715085110859945, 0.0815299095120281, 0.018800994075718336, 0.020834556635236368, 0.04677589451603126, 0.02366458465985488, 0.029658456878678408, 0.031786366816959344, 0.031953891812008806, 0.07514012191677466, 0.03825403910013847, 0.022644036980636884, 0.008459904638584703, 0.023504028431489132, 0.033782013051677495, 0.04863808033405803, 0.03023164907062892, 0.1291186746675521, 0.052772867056773975, 0.08923295710701495, 0.043179161148145795, 0.04778386835823767, 0.03789191927353386, 0.034646641070139594, 0.030055203460506164, 0.020565557788359, 0.09004998006275855, 0.055140956392278895, 0.1634797707083635, 0.04292653778975364, 0.03456422928138636, 0.0878045974241104, 0.053482764706132, 0.03199051308911294, 0.1473875599913299, 0.16482589300721884, 0.14337521279230714, 0.3835398709634319, 0.45234165096189827, 0.517697223694995, 0.30056927469559014, 0.5900670122355223, 0.5070428329054266, 0.42200479132588953, 0.3981699171708897, 0.2703261037822813, 0.2811642800224945, 0.01588601055118488, 0.28825042478274554, 0.24436831619823352, 0.17800771223846823, 0.0887194651295431, 0.003486125069684931, 0.0644808032666333, 0.1411850904696621, 0.06825555188697763, 0.05878095696971286, 0.05718777742004022, 0.05498458587680943, 0.043530961411306635, 0.05743812980654184, 0.09934508285368793, 0.11647371022263542, 0.031441201354027726, 0.018306846177438274, 0.07353168010013178, 0.050505108665674925, 0.014212052865332225, 0.04710690351203084, 0.06885286202304997, 0.05434740385680925, 0.03916974543244578, 0.07471235541743226, 0.059630315299727954, 0.06659343052888289, 0.021656195749528706, 0.07791322350385599, 0.02335050405235961, 0.038918168502277695, 0.08211174586904235, 0.030409048340516165, 0.0253980189881986, 0.018967337200592738, 0.012382338791212533, 0.05605193153314758, 0.05299691030813847, 0.044249275015317835, 0.06317896491964348, 0.02435840739053674, 0.014858949598419713, 0.05360700764867943, 0.08414465162786655, 0.024906314611143898, 0.04723084959550761, 0.05479627703607548, 0.009684866690804483, 0.06551819955348037, 0.04792060535692144, 0.07317667375900783, 0.05927916812652256, 0.07371886458713561, 0.016493801667820662, 0.05849889261298813, 0.053423485660459846, 0.013968245293654036, 0.03320771691505797, 0.01970136207091855, 0.014641879752161913, 0.051701387637876906, 0.06455857292166911, 0.05028273895732127, 0.03564006510714535, 0.03254721290431917, 0.043221300293225795, 0.07849491885281168, 0.033798180738813244, 0.027894060149264988, 0.05801205858006142, 0.053613327036146075, 0.02449442821671255, 0.06670996997854672, 0.02462534492224222, 0.012884049174317624, 0.023067875663400628, 0.026251717026752885, 0.03473286378721241, 0.00868158322191448, 0.052069722951273434, 0.02631230225233594, 0.06678192119579762, 0.02299209125339985, 0.1025786277023144, 0.02052969535725424, 0.009420068399776937, 0.029884836039855145, 0.048423833432025276, 0.11824375469586812, 0.013630680350615876, 0.03985618008300662, 0.046538997266907245, 0.08590535246185027, 0.058171609198325314, 0.04245554118824657, 0.05197531805606559, 0.03969967227021698, 0.035603673895820975, 0.06363957887515426, 0.009548606522002956, 0.05770275369286537, 0.054720681873732246, 0.06125750005594455, 0.05391549988416955, 0.016844254932948388, 0.06874657163280062, 0.008299668461404508, 0.018956056555907708, 0.04683200088038575, 0.027123263716930524, 0.05431650082755368, 0.03963242626923602, 0.04830494879570324, 0.013713144089706475, 0.0270553906011628, 0.05805174121633172, 0.011389571554900613, 0.04762587253935635, 0.017721792610245757, 0.041604331199778244, 0.014024531628820114, 0.06421266531106085, 0.06182503522722982, 0.049095380600192584, 0.03405887124245055, 0.007426562333421316, 0.08303841372253373, 0.01801901718863519, 0.03966893993492704, 0.04666816064855084, 0.026304938292014413, 0.06006895797327161, 0.0376567363855429, 0.0255972726517939, 0.02698222411709139, 0.04083254956640303, 0.0209846263169311, 0.16351154947187752, 0.07899808755610138, 0.04637452992028557, 0.019606604655564297, 0.049583513391553424, 0.006507562256956589, 0.04576424333208706, 0.04328778188209981, 0.033368013391736895, 0.06270400524954312, 0.07517121790442616, 0.13112501153955236, 0.05389702411775943, 0.06795817331294529, 0.029722843755735084, 0.06237150082597509, 0.09067624880117364, 0.14793956943321973, 0.12057996878866106, 0.09973400534363464, 0.17087120533687994, 0.17160389805212617, 0.152240805036854, 0.04480065363168251, 0.08569959201849997, 0.24673394160345197, 0.16449553339043632, 0.1751265168422833, 0.25472957349848, 0.3282801486784592, 0.0612889596959576, 0.3237394813913852, 0.5471942690201104, 0.3925204515689984, 0.4431862203637138, 0.8451615739613771, 0.33001092611812055, 0.10972882722853683, 0.28466582181863487, 0.13008855778025463, 0.06336922189802863, 0.014245472702896222, 0.20377681619720533, 0.22974980296567082, 0.14648639975348487, 0.08667291869642213, 0.13405324425548315, 0.07564774350612424, 0.0856041518272832, 0.09650186315411702, 0.15573168959235772, 0.044430960188037716, 0.14477775315754116, 0.043097421003039926, 0.15403374476591125, 0.07191237324150279, 0.06269683610298671, 0.030269355738710146, 0.019233822022215463, 0.05173270255909301, 0.047568085210514255, 0.061019615750410594, 0.02475650097039761, 0.04660425802285317, 0.07276660006027669, 0.034440836097928695, 0.02635783857840579, 0.012486148552852683, 0.04361617851827759, 0.029395118763204664, 0.05036287606344558, 0.06584889313671738, 0.07593558548251167, 0.06067583068215754, 0.056564065380371176, 0.024530767477699555, 0.02674315979675157, 0.046801127537037246, 0.06551085971295834, 0.03183891087246593, 0.018531876485212706, 0.026919607262243517, 0.09727014185045846, 0.023498432638007216, 0.026915061607724056, 0.033763893516152166, 0.0412948927260004, 0.012532594009826425, 0.036957503398298286, 0.015229310047288891, 0.11424040232668631, 0.05668672012689058, 0.033983079410973005, 0.02895841495046625, 0.0734715438738931, 0.03547140091541223, 0.04932055191602558, 0.04116814503504429, 0.009982259180105757, 0.0008438151246537018, 0.014319922174763633, 0.030553102915291674, 0.029402271211438347, 0.0169689876929624, 0.04515216816798784, 0.031696489022579044, 0.03597598341002595, 0.03274709182733204, 0.016829679152579047, 0.056449696712661535, 0.052705825146404095, 0.03437592415139079, 0.01937009146786295, 0.04058122867718339, 0.04809706952073611, 0.038417070391005836, 0.028257230114832055, 0.20924914599163458, 0.20889511186396703, 0.14927645941497758, 0.20481313636992127, 0.10667509734048508, 0.15033860632684082, 0.08773473164183088, 0.11375472604413517, 0.15411929955007508, 0.1458858686964959, 0.2720176661387086, 0.11005266336724162, 0.25432634982280433, 0.09382156713400036, 0.21812897262861952, 0.15440343820955604, 0.14684432273497805, 0.13917400385253131, 0.2009863409330137, 0.1996466307900846, 0.12195850067655556, 0.07296370706171729, 0.1910629656049423, 0.17201847658725455, 0.10697727760998532, 0.16248515923507512, 0.1289999607251957, 0.16922439448535442, 0.12083801353583112, 0.13171927887015045, 0.1760838131303899, 0.0925792267662473, 0.10403444684925489, 0.1593795680673793, 0.10613985301461071, 0.1372884144075215, 0.11630476772552356, 0.17110299289925024, 0.14257447997806594, 0.2120513323461637, 0.09174666323815472, 0.09628616535337642, 0.1262642559595406, 0.1116906946117524, 0.16914989770157263, 0.15059001627378166, 0.163649900641758, 0.15650689252652228, 0.13241955457488075, 0.1303106380510144, 0.24594040762167424, 0.13062009878922254, 0.07845728454412892, 0.10974157732562162, 0.13071890833089128, 0.18720790918450803, 0.14506293082376942, 0.1735129690496251, 0.11410582868847996, 0.36317964317277074, 0.18656546162674204, 0.18814780953107402, 0.05441463130409829, 0.14627163705881685, 0.10372741293394938, 0.13437572226393968, 0.10472057721926831, 0.25444767612498254, 0.1477893884293735, 0.20009757456136867, 0.12053420054144226, 0.2541642647702247, 0.28191758960019797, 0.09463533206144348, 0.10530564191867597, 0.25053293618839234, 0.23008848947938532, 0.43471502023749053, 0.23232827632455155, 0.16693356272298843, 0.21630162693327293, 0.19869062583893538, 0.14289848681073636, 0.07662512973183766, 0.2612340822815895, 0.3912237414624542, 0.22483910084702075, 0.4426950967172161, 0.4001396958483383, 0.4528746020514518, 0.38355688098818064, 0.8403430762700737, 0.9227827400900424, 0.6284966063685715, 0.8990797307342291, 0.8863745187409222, 0.5231097363866866, 0.4889506084145978, 0.507277351571247, 0.30609901703428477, 0.3008371900068596, 0.24054416280705482, 0.1547780298278667, 0.14671091426862404, 0.21437851450173184, 0.3075066930614412, 0.40408685279544443, 0.2435505882021971, 0.23214187851408496, 0.27223009848967195, 0.17286544520175084, 0.4976158950012177, 0.33616647706367075, 0.21358688041800633, 0.14065613213460892, 0.16027042729547247, 0.23782315256539732, 0.08380120794754475, 0.1337850617710501, 0.15624148567439988, 0.1569190961890854, 0.289759982842952, 0.09634975256631151, 0.18394450773485005, 0.09017867589136586, 0.13217716914368793, 0.1940175742493011, 0.09765896043973044, 0.12895314604975283, 0.14989970019087195, 0.17388420616043732, 0.197167813021224, 0.2189761193585582, 0.13139479706296697, 0.1668220030842349, 0.1379816693952307, 0.11862079540151171, 0.1826059553422965, 0.10287797296768986, 0.13513912505004555, 0.09461851499509066, 0.15638528420822695, 0.08751303728786297, 0.08730442699743435, 0.1602569647366181, 0.09770035743713379, 0.18584562290925533, 0.14182617247570306, 0.19933960429625586, 0.22363271011272445, 0.1413578327628784, 0.13684541161637753, 0.11374075140338391, 0.13758135493844748, 0.1315796808921732, 0.08316597406519577, 0.14132952725049108, 0.09814787248615175, 0.09785741814994253, 0.16441875079181045, 0.11981059171375819, 0.09001789701869711, 0.06858534747152589, 0.19260025030234829, 0.16519595752470195, 0.06974556919885799, 0.09209745418047532, 0.20175983692752197, 0.21531577280256897, 0.08784332268987782, 0.11409904545871541, 0.11514072393765673, 0.07334411711781286, 0.10241871714242734, 0.13198018830735236, 0.08824964112136513], [0.032374407528550364, 0.060829102731077, 0.058033580862684175, 0.027077007507614326, 0.01494889233072172, 0.03628505452070385, 0.018183851898356806, 0.05704583425540477, 0.04277054948033765, 0.025366685513290577, 0.011369312778697349, 0.13296160439494997, 0.029807550636178348, 0.03873277630191296, 0.037167980190133676, 0.013776275809505023, 0.04028169045341201, 0.028965149940631818, 0.05943598021985963, 0.01813469389162492, 0.030307307315524668, 0.05700706075003836, 0.07040077427518554, 0.022140033361210953, 0.02665346382855205, 0.03473032564215828, 0.03152719771605916, 0.030993452528491616, 0.044722364473273046, 0.07084416298312135, 0.07439138396875933, 0.03902168326021638, 0.011386490714357933, 0.03559238582965918, 0.05008635183912702, 0.00508970489136118, 0.04717692514532246, 0.0433685646567028, 0.006687117929686792, 0.04974178009433672, 0.04476220296055544, 0.027723685307137202, 0.020253935545042623, 0.02242873622890329, 0.016330274993379135, 0.022155896767799277, 0.070356586802518, 0.013362147201405605, 0.07331135871936567, 0.06657369682216085, 0.013617417243949603, 0.11316557953250594, 0.043620460710371844, 0.07286929845577106, 0.04174589215836022, 0.04211711813695729, 0.0797943452198524, 0.013621328362205531, 0.025719083205331117, 0.01769990110915387, 0.0409435043548001, 0.028791899276257027, 0.030020276135473978, 0.025841823298833333, 0.06019422879035119, 0.056826859872671776, 0.050461214341339655, 0.024767503309703898, 0.04684736704803072, 0.08522274729330093, 0.052401488937903196, 0.06664360713330097, 0.036152811226202175, 0.028275119584577624, 0.039778792634024285, 0.039548073764308356, 0.06372912641381845, 0.07272578935953788, 0.027150133173563518, 0.12148552254075184, 0.0722242979099974, 0.03311164218757767, 0.045010692556388676, 0.0028247321051821928, 0.11038765398552641, 0.06653613672824576, 0.11638936513918452, 0.11616403426160105, 0.1443331324844621, 0.07688265497563407, 0.06719527518725954, 0.11272813542746007, 0.22167122864630073, 0.11135787848616019, 0.22519828547956422, 0.03576705028535798, 0.052797391326748766, 0.03503366737277247, 0.0753917099791579, 0.15463032759726048, 0.036021102278027683, 0.09930486587109044, 0.0430742325988831, 0.04416275172843598, 0.08922518682084046, 0.034251922406838275, 0.0607970122655388, 0.022102165276010055, 0.08692647345014848, 0.047009021654957905, 0.03646822769951541, 0.020510729773377534, 0.02133970872819191, 0.10179575096117333, 0.05894966940104496, 0.05871916204341687, 0.10199052761890925, 0.01244097587914439, 0.046197215997381136, 0.051369725551921874, 0.04228955614962615, 0.038361490951501764, 0.011844035889225779, 0.0957882881630212, 0.018277655653946567, 0.041470559081062675, 0.04353534379333723, 0.054933693099883385, 0.03139596003165934, 0.03968926364905201, 0.02165215104469098, 0.03502766710880678, 0.020369615958770737, 0.04504986311076209, 0.09708347686682828, 0.08542579889763147, 0.020828814267588314, 0.04096622520592064, 0.03555798357410822, 0.05595043541688938, 0.07458718479028903, 0.010688046259019757, 0.022110635036369786, 0.04911804207949899, 0.06510823717690073, 0.03170923169818707, 0.05294304894050583, 0.019615161618276034, 0.015820835142221767, 0.047332293761428446, 0.02769757469650358, 0.02644954205607064, 0.06697921373415738, 0.008892619407561142, 0.0374318099784432, 0.047513058671029285, 0.03479267717921175, 0.056915071545518, 0.0783268446684815, 0.03828601824352518, 0.013895867341489065, 0.04646062647225335, 0.031557276961393654, 0.021296992563293315, 0.061174780275905505, 0.04019313368189614, 0.05727628966269549, 0.08231702391640283, 0.05221577390329912, 0.043454980332171544, 0.04322820226661861, 0.011748990891646827, 0.01555641349114012, 0.030559737715520896, 0.05123885894136038, 0.03271041117841378, 0.021828309072589036, 0.01603062544745626, 0.05014548987674061, 0.015542249602731317, 0.009886409879982239, 0.06356042882543989, 0.03883472141751554, 0.029270803461258765, 0.04487729151151143, 0.04554079750960227, 0.07254731026478112, 0.1359488081652671, 0.02562355210102396, 0.01653459381486755, 0.04723404083051719, 0.02744524819718208, 0.026076468129758723, 0.0285499591336702, 0.020379263878567144, 0.036882323838653974, 0.03037121921806829, 0.030957358176237904, 0.0816152490733657, 0.056886695529101416, 0.025384090731677134, 0.016717067519493867, 0.03229634472518228, 0.05450263888633344, 0.04010961238236632, 0.02482919804606354, 0.026338609532103874, 0.03324470926600043, 0.07722033958998509, 0.029460769146680832, 0.026612810834194534, 0.027126078311994206, 0.0038566198008993524, 0.10243344135233201, 0.054674293933203444, 0.005341152873370447, 0.02616939429572085, 0.026298802586097736, 0.025929409712261986, 0.06570203695446253, 0.0390475508174859, 0.027903619011340197, 0.029178977529227268, 0.012924039801873732, 0.026497215767449234, 0.010470782526681433, 0.01784936037438456, 0.049674712208798155, 0.0693149899598211, 0.045857063742005266, 0.03432136516494211, 0.026256752498738933, 0.03340817100252025, 0.012332421938481275, 0.041250716385548, 0.07020409029792063, 0.07437608830514364, 0.1172042878170032, 0.06180035139550455, 0.02432097160635749, 0.020355049455247354, 0.021498147980310023, 0.0682068669993896, 0.03802155391895212, 0.023273116603377275, 0.10346815106458962, 0.04512808547588065, 0.10560112801613286, 0.03294149741122965, 0.027732320195354987, 0.10548402453423478, 0.055602271677344106, 0.09153305829386227, 0.07466384122380987, 0.03177076687279623, 0.22171869641169906, 0.02099938392348122, 0.12958563398569822, 0.05485986424901057, 0.07307800522539765, 0.0843102544604335, 0.03635972199845128, 0.00547701135474199, 0.11171345628099516, 0.05834956878970843, 0.013457174572977237, 0.06561064888956025, 0.08146957290591672, 0.02723161542235175, 0.0866208718798589, 0.3397407493321225, 0.1042597703053616, 0.0988638297712896, 0.13172206934541464, 0.07018207077635452, 0.046305569558171555, 0.09477801737375557, 0.1608524046605453, 0.05276137118926272, 0.06558203909662552, 0.13661691918969154, 0.08306993273436092, 0.10097523991134949, 0.15857264574151486, 0.1117529533803463, 0.10889650118770078, 0.04799963295226917, 0.11581217462662607, 0.06333018493023701, 0.05947863886831328, 0.045741043795715086, 0.009940321342583047, 0.03739042782399338, 0.07207724134786986, 0.04974669311195612, 0.017565132657182403, 0.02376172436925117, 0.05454445148643572, 0.01670680176175665, 0.023531756924057845, 0.06351051197270863, 0.015279185154213337, 0.0660835528105963, 0.01673383820161689, 0.020883684956061188, 0.038273357204161584, 0.04251514306815807, 0.0328217073547421, 0.07475578589946963, 0.031222609177348204, 0.028928953543072566, 0.051795350955217145, 0.0464142941928003, 0.04226368117087986, 0.060197297570994124, 0.011219385032745777, 0.12901716370834038, 0.03099539695540443, 0.029993579228175804, 0.032779616449261084, 0.044911252189194784, 0.08038660133024678, 0.032004465465433896, 0.0913423857127782, 0.009551114053465426, 0.018260745819134172, 0.024295155999425333, 0.016917614375415724, 0.02022246477281442, 0.06364236935041845, 0.0627367859124206, 0.08735679293749854, 0.03540557612723205, 0.030231220480345655, 0.050649474942474626, 0.015398359228129266, 0.042725927851279266, 0.009250724215235095, 0.021368841735238675, 0.02371553495322587, 0.04265046998625621, 0.021507549136003945, 0.09580077850841917, 0.0518478579033399, 0.04314011675887741, 0.058397452157805674, 0.038382378697860986, 0.06465702623245306, 0.03449009243922774, 0.06248302335734479, 0.0503196051431587, 0.029091990400047507, 0.15607049484970048, 0.09320614859461784, 0.16027608246076852, 0.09094408989767544, 0.12578280991874635, 0.1347736024763435, 0.10229318286292255, 0.09420438174856827, 0.18381147034233436, 0.11507551142130978, 0.1429252338130027, 0.25519555318169296, 0.1069333944178652, 0.14836605201708153, 0.17583299690159038, 0.11640583339612931, 0.15698820498073474, 0.09271138842450455, 0.15163070027483627, 0.11436289380071685, 0.10943826899165288, 0.11886263906490058, 0.1766020993818529, 0.17014879878843203, 0.1381659891922027, 0.16012732638046145, 0.0983110856031999, 0.1433283239020966, 0.14795643102843314, 0.128502766310703, 0.16901726106880233, 0.16083437047200277, 0.15266256756149232, 0.2361820117221214, 0.11108114646049216, 0.19054018193855882, 0.18934866384370252, 0.17773329571355134, 0.1273579738335684, 0.1294603297719732, 0.14657899009762332, 0.07545929736807011, 0.12387103750370443, 0.177949245844502, 0.15908005210803822, 0.08992519535240717, 0.1596062644966878, 0.1143597842019517, 0.11304483952699229, 0.15072669018991292, 0.10536039757425897, 0.18985221104230732, 0.13990083360113204, 0.11301924285362475, 0.17070852656615898, 0.15008795337053016, 0.1289379913941957, 0.10577139895758592, 0.05495342680660542, 0.18932982813566923, 0.19071878719842061, 0.31232171750161797, 0.1492578611942008, 0.12597925640875474, 0.0996449995727744, 0.2250722688040696, 0.19926331151509658, 0.2145991104771383, 0.15274709818186238, 0.16414719895692542, 0.15329505549743772, 0.19908415706595406, 0.1574418501695618, 0.16605616605374962, 0.13116768503095955, 0.149338161572814, 0.21002748078899458, 0.11647204781183973, 0.061720303347101435, 0.3198085626354441, 0.14608684228733182, 0.19457086018519476, 0.15059644327266142, 0.10039847242296673, 0.1804256738978438, 0.13578256708569825, 0.21162366232601926, 0.21618199272779748, 0.2007809144561179, 0.1457474284688942, 0.2812566328793764, 0.422595392446965, 0.357658420689404, 0.3459706634748727, 0.5856793164275587, 0.321622519986704, 0.29239727882668376, 0.2754880377324298, 0.2517810801509768, 0.20928107318468392, 0.1999034732580185, 0.2681775268865749, 0.1441775041166693, 0.41761863918509334, 0.3896773135056719, 0.40059368242509663, 0.3593470441410318, 0.26939176954329014, 0.23013062862446532, 0.19885331945260987, 0.14153326163068414, 0.24266563646961004, 0.1855078715016134, 0.2079677686560899, 0.17233746650163084, 0.15099708427442238, 0.24629797437228262, 0.1630510319955647, 0.2027409413130954, 0.14089937845710665, 0.14951544580981135, 0.14427968300879002, 0.15948464133543894, 0.12325201212661341, 0.1209033299528528, 0.11134746615425684, 0.10267019388265908, 0.15325916523579508, 0.1500556551036425, 0.18936748470878229, 0.17368216387694702, 0.20256600226275623, 0.1797235428239219, 0.09805571258766577, 0.24661237781401724, 0.2577894483692944, 0.11789702330133878, 0.18894440116127953, 0.1107907440746203, 0.14855191548122093, 0.19491331680910662, 0.055892388336360455, 0.08300584828248248, 0.18708788906224072, 0.13952716224594042, 0.20994349935790524, 0.1750275885569863, 0.22279699245700613, 0.19281952525489032, 0.13605410407762975, 0.16479430720210075, 0.1137262349948287, 0.12163775187218562, 0.13605168467620388, 0.13560629216954112, 0.11964712626649998, 0.10378993887570687, 0.0926774945401121, 0.15767484001116827, 0.09528661859803833, 0.08267171113402583, 0.12562298099510372, 0.12398566963383928, 0.1215130191121716, 0.16246339946519583, 0.1126477905199863, 0.15143104770686477, 0.1416917992173694, 0.14294829976279289, 0.11252995231188834, 0.12579471396747977, 0.13453801511786878, 0.10336710765841417, 0.15397777198813856, 0.1237542531453073, 0.17058902594726533], [0.08351699507329613, 0.009832606028794544, 0.016823767946334556, 0.00898668477020692, 0.06706372951157391, 0.015432017480634386, 0.008455587194475811, 0.045437223379849456, 0.016584172990405932, 0.020773097530764062, 0.04737355346151162, 0.021072557829029392, 0.04554376981104724, 0.04320667256251909, 0.04298025443858933, 0.01769995677022962, 0.06571479447302409, 0.03196974408638198, 0.031323596922447905, 0.014545516514772316, 0.01891737581900088, 0.019004678360943217, 0.03245314939704258, 0.04764997378515545, 0.09740170979057439, 0.019205696480639745, 0.034086256491718814, 0.03667155760922469, 0.0765057404350955, 0.022125567047623917, 0.061392737916321494, 0.04733631249109749, 0.007488334067602409, 0.07476853599655442, 0.027815667090180796, 0.04352060474047903, 0.013711132869502762, 0.049936831346713006, 0.03403839538805187, 0.024252087314380333, 0.05729993819841184, 0.030108740138530266, 0.02364495856454596, 0.02996814582729712, 0.062242300336947665, 0.04627999143849593, 0.03739764149941038, 0.03100635476585012, 0.11075327303842641, 0.03945818112697452, 0.01279749898458249, 0.058690682126325555, 0.04756564354465809, 0.01038664617226459, 0.03643099786131643, 0.011376904949429445, 0.06480851341621019, 0.05651402236253489, 0.04802536692295689, 0.019358198551344685, 0.08298564702272415, 0.06086367939133197, 0.015432724376296392, 0.05246594446361996, 0.0680744530109223, 0.017935310352186207, 0.05807654750242364, 0.00754041474465339, 0.046560823830077425, 0.03144837050058413, 0.025208698971255217, 0.083458684530342, 0.018620821028889623, 0.0351113219949184, 0.05982544076687191, 0.05361062561860308, 0.05055922236351762, 0.010017453678301536, 0.16739557933760807, 0.07318890435271896, 0.052546942461049184, 0.033900671332958154, 0.027682008148985915, 0.015833787474548444, 0.05004380080208648, 0.033734099997673184, 0.02323896853340557, 0.12889619363704696, 0.11486909788800403, 0.1484063357929699, 0.06475265196058899, 0.11546711306436919, 0.16759575140895322, 0.08307261188747361, 0.01224921141329105, 0.10150851012440398, 0.06718841032125056, 0.06832310216850601, 0.07279911354999058, 0.03394776431377977, 0.08775854716077447, 0.012179104433016619, 0.06520831579109654, 0.022288692962320056, 0.022515511845995206, 0.10182626807363704, 0.08196903829229996, 0.09311575500760227, 0.09728399774758145, 0.008809244682197459, 0.06443011458031833, 0.03347266363562085, 0.05082783529360313, 0.05003160360502079, 0.04339735256507993, 0.013660655695275636, 0.03304429228592198, 0.08457251460640691, 0.00922943663681508, 0.058915493500535376, 0.0217319987132214, 0.005030772335885558, 0.031883339543128386, 0.0236108438912197, 0.04287543721147813, 0.06959682054002769, 0.06556406427989714, 0.038299822190310806, 0.019411674002185464, 0.010965294077323051, 0.04376517950731795, 0.047292288290918805, 0.026992295061063487, 0.06791924766730517, 0.05158273306733463, 0.06880760585772805, 0.02588504969025962, 0.06662497180514038, 0.02600364117824938, 0.017292632728640456, 0.03545960447809193, 0.029072457073198166, 0.0542488837527344, 0.09340976423118263, 0.009946123082045233, 0.013989279614179395, 0.051255553553346545, 0.06320367843727581, 0.02339762115298072, 0.012984094391867984, 0.021616175436065532, 0.038683078382746316, 0.0072584264580655145, 0.04574993101414293, 0.06991308677243069, 0.02647265439009061, 0.0935660456889309, 0.03641839990450535, 0.035256129849585705, 0.08072200755123049, 0.052706663773278706, 0.010807436483446509, 0.07580478195450269, 0.052198641424183734, 0.025253290914406534, 0.030990572995506227, 0.04537779590464197, 0.04287507355911657, 0.031015221575216856, 0.041044247191166505, 0.017400663455191534, 0.02339324990316527, 0.010453356899233768, 0.039443137793568894, 0.09317762785940431, 0.0053647244112653425, 0.01656570464547258, 0.10708059198805131, 0.03027641912922263, 0.009210211301251547, 0.10321254798327573, 0.039827013679314405, 0.045911927009001374, 0.051017112637055106, 0.06800921823014505, 0.024928126331360545, 0.06132643815362826, 0.006475140608017682, 0.018026377438218333, 0.025627973445807584, 0.04775709909154102, 0.0024129292023644666, 0.07777052334859036, 0.011297456185275223, 0.0231878586782841, 0.029521584438043647, 0.05304203659761697, 0.047124225238803774, 0.01291751354074222, 0.046608770280727185, 0.025066399575734977, 0.03552358131855726, 0.05791087416582741, 0.012532372293208027, 0.1273407114786096, 0.0195732729480369, 0.025595324514142703, 0.015173910578596406, 0.019523057380865794, 0.042102620282093994, 0.03886979531671386, 0.03570177468645852, 0.04324623274442274, 0.05687813856638968, 0.032206448377110064, 0.0025310072169304476, 0.04078828787896782, 0.0730414767167531, 0.02818407661834499, 0.026837336481548846, 0.019182641663064715, 0.06196755726705305, 0.031020101196190808, 0.026528480593697168, 0.026871684931393247, 0.02841715180693427, 0.031499497054028325, 0.0715813456918113, 0.04431982357345987, 0.06309170319582336, 0.04217801135382615, 0.02115731665981002, 0.009137071720033418, 0.06553014813107438, 0.07847179353120737, 0.059098967249155976, 0.023598236657562666, 0.05350004190404434, 0.013475086307153106, 0.016241278499364853, 0.010776043636724353, 0.03502974141156301, 0.025686486224003602, 0.03441814122197684, 0.012941868972120574, 0.011969316910835914, 0.08477745126583613, 0.013271309253468644, 0.0019014715212506417, 0.09033642680151388, 0.12638861022423953, 0.0828215284855105, 0.02420661592623219, 0.06706402637064457, 0.051546957838581875, 0.13464449846651405, 0.07321079028770328, 0.047219498446793295, 0.04738425894174725, 0.03353794294525869, 0.03386042095371522, 0.029932266697869636, 0.139689217612613, 0.008672952972119674, 0.1218889985466376, 0.047814355784794316, 0.10534577726502903, 0.07327995845116675, 0.16771209047874436, 0.07810827475623228, 0.10552922874921933, 0.0886289008485619, 0.08872055608662777, 0.10251076571876183, 0.053722589727840386, 0.10207730694673955, 0.01749893865053309, 0.04490977902605664, 0.08945595764089376, 0.055418567862943746, 0.11126689860248007, 0.08727021398954093, 0.08401211147429422, 0.10509349158382975, 0.059310486758477055, 0.05557831143960357, 0.010819107683346374, 0.07122919661924243, 0.029127366724424064, 0.08610552453319542, 0.03349610808072612, 0.042670244511100464, 0.06669319744105451, 0.04993119102437049, 0.017941249388968572, 0.004009702834082418, 0.009562557970639318, 0.09793754783459008, 0.007823631749488413, 0.05869854889169801, 0.0325955415610224, 0.026875330731854774, 0.04927470945403911, 0.05229008886090014, 0.030868790272506885, 0.007550521868324722, 0.02098292865412077, 0.088417915685568, 0.042486655729589984, 0.02485978380718734, 0.12952670746017247, 0.04712648136774078, 0.025852656799543183, 0.02847307077900041, 0.04144548191106878, 0.017803211776481476, 0.047675785681349225, 0.0294365417357767, 0.05789614995592274, 0.020691312856797595, 0.04101039041415788, 0.011638750420388533, 0.02915824192314176, 0.06495957757579163, 0.03499757302051876, 0.005521014682017267, 0.027886852039955556, 0.013894746698497329, 0.0493606501549948, 0.042197630027658306, 0.09701292088720948, 0.05066316014563199, 0.03010040210938314, 0.057272968551842496, 0.024137321597663686, 0.012050634031766094, 0.06364730463246815, 0.007396010896627558, 0.011103262113465462, 0.037992981233401224, 0.03228529414627701, 0.03409168901271187, 0.018534960108809173, 0.02852867248293478, 0.014910893441992812, 0.013346871019166429, 0.006168969903228572, 0.05625991470878944, 0.09071837310330011, 0.011334358550811885, 0.019964362509199418, 0.045036007213639095, 0.20211404917063192, 0.17295395373366773, 0.058567029191181064, 0.12642500514630228, 0.10644535068422556, 0.11832881966256537, 0.18381147034233436, 0.18362961447564885, 0.1531304174568504, 0.07284884486580268, 0.14722329302458093, 0.1328263257164508, 0.14265056495787576, 0.1241919792664703, 0.1629234864958562, 0.15281420317478478, 0.11822636617580429, 0.11586387263378128, 0.12746462045470253, 0.23930600815219805, 0.11962925535044633, 0.06763196230167523, 0.1173592334089335, 0.15285856876289472, 0.25238008238375187, 0.06289113036473282, 0.10185207996983081, 0.17186605429742485, 0.22348677419358864, 0.07383301432128064, 0.138736700755544, 0.12442797480616719, 0.15047703171148896, 0.17250320292077959, 0.2803862717701122, 0.20096404681680724, 0.1148182904580608, 0.1262299984227866, 0.18029088503681123, 0.10068206189316697, 0.11470477154944092, 0.14358623506268486, 0.08833937419694848, 0.13934468297520652, 0.1381528383353725, 0.12748240231303498, 0.11646252605714835, 0.08255114924395457, 0.10459381839609705, 0.1663354955962859, 0.11727908145985566, 0.23851208825362846, 0.2038746906328015, 0.14103703200817108, 0.11202810463146307, 0.1640379845048301, 0.16277346876449883, 0.28968879603780806, 0.15646280895452946, 0.36848083371296525, 0.13791909150313586, 0.11405787852709182, 0.10106333284056745, 0.1403716966160573, 0.22666595672490075, 0.1485943960142322, 0.11656549162580632, 0.15098201867658645, 0.08578365508583374, 0.12623733084183186, 0.19144855585182086, 0.15760185720864683, 0.10018198052421212, 0.2680218836758286, 0.26919649564661086, 0.16076057130703703, 0.13768014963716269, 0.20783113926881924, 0.26085065910592675, 0.1444545478443615, 0.14304550626548007, 0.10968281407258473, 0.1281878285226412, 0.11836338890134357, 0.1518004888202995, 0.11709940008586273, 0.25281845417339355, 0.23038946004817262, 0.2807773242238909, 0.15098333969945088, 0.1672457842505537, 0.32000214443542063, 0.508201711345464, 0.2972999954363331, 0.22234153642784804, 0.3340391255915165, 0.2936276706168428, 0.24534893076634035, 0.22730184369720519, 0.20869946689344943, 0.27171869936864823, 0.21941078040981665, 0.19239670888055116, 0.11519427731400356, 0.1473523525055498, 0.26735035877209157, 0.3250035073142499, 0.2632498147431761, 0.27829397935420275, 0.14713606098666787, 0.170928914740216, 0.1531991403317079, 0.15309748094296083, 0.1911923219449818, 0.11160379654029384, 0.18244565144414082, 0.3425228828564286, 0.08728015134693123, 0.10339922780985944, 0.14278716465923935, 0.07380902810837142, 0.24194119643652812, 0.1554575699265115, 0.09061620163265616, 0.1469969973550178, 0.14483651641057804, 0.12455722724553198, 0.10506281119887717, 0.21702574042137712, 0.11739045556169003, 0.1718107791384682, 0.15201247588265687, 0.09410917162313126, 0.10987045869114809, 0.24303552287165076, 0.13881314196623862, 0.13159367779735476, 0.17306383611867204, 0.28332390007562935, 0.18988538504345343, 0.14885537966620177, 0.1615448432858102, 0.08292118407553062, 0.15933223388856277, 0.062024387225392275, 0.15116323629627004, 0.16009391489205882, 0.15459704969543964, 0.16639514942653477, 0.09326687111752108, 0.06902493638335727, 0.0848147738724947, 0.11727108852937818, 0.14723251049872488, 0.17489858844783157, 0.15613397816196084, 0.21906743320869282, 0.12182904043584131, 0.11655855254502967, 0.15010232134955004, 0.10875841719098389, 0.07556580298114568, 0.12171967013273388, 0.18504727981053293, 0.12161570266471244, 0.128502766310703, 0.17158984177513048, 0.1111457429942675, 0.1553164134384133, 0.15607917797751725, 0.11274740900262259, 0.2571209811139852, 0.21303006185917184, 0.07429345016134903, 0.21070485381642357, 0.07753874320769683], [0.0491840598260751, 0.007048291981845978, 0.04362507686892059, 0.0311620573484106, 0.04884399662842043, 0.0701852174825035, 0.05956604531093035, 0.020059168164152652, 0.03376659864443354, 0.03993709644419141, 0.022756568832846824, 0.050266114849364385, 0.017530084733152762, 0.025610427219362464, 0.07542131424997933, 0.028996518667554483, 0.05900934549572412, 0.049574919321457855, 0.11394945075153373, 0.03342709576827474, 0.0383057333965553, 0.08690863964147866, 0.018095040941261686, 0.021435022754303645, 0.05289747365168296, 0.018449225353833754, 0.05986592863337137, 0.02611020430776989, 0.026124160394829232, 0.03653387808299158, 0.019290928430564236, 0.022019823991286103, 0.021915971556154545, 0.02291119901201455, 0.028234546371095348, 0.03775501158088446, 0.015773712475493085, 0.032896026023081504, 0.006761884205843671, 0.009060503416549182, 0.030556247766071465, 0.027837283996632323, 0.018738930120889563, 0.012827428872697055, 0.08532539373845793, 0.024287196465593297, 0.072850455326261, 0.03605573088862002, 0.02033302251220448, 0.03209751223039348, 0.013837091100867838, 0.02535828811232932, 0.022974279709160328, 0.05160927968972828, 0.04493732383707538, 0.03666905286081601, 0.057739412077353336, 0.024008733380469494, 0.0430753383989213, 0.042455544898984954, 0.052622099756263196, 0.04294491336622741, 0.04389686990180053, 0.047420164046343416, 0.08332143916049972, 0.04704901970399078, 0.051893707786803134, 0.014251624179451028, 0.013990326970088063, 0.051661014804267325, 0.01680690449575195, 0.021307941096893046, 0.04308754672820214, 0.028117697074776515, 0.02410984357993584, 0.07886494626291096, 0.12789873231668025, 0.07961942101246677, 0.034904273925349116, 0.04861226843786426, 0.06873215912492014, 0.06374337564921007, 0.07398558504064567, 0.01928654790390283, 0.02222148406872293, 0.01784531010343926, 0.052280923337093554, 0.025441267644055188, 0.033673440557322465, 0.06758886578609236, 0.06978506629820913, 0.033871133855427615, 0.11071389468270354, 0.04060648396261968, 0.017054210366040934, 0.07184408823377453, 0.07433425344061106, 0.03705443530634511, 0.08537113229976967, 0.06367316105752252, 0.027955352270510048, 0.021929985159658827, 0.017142104770755395, 0.05795069409941789, 0.09413948093424551, 0.003524788180584437, 0.014600883514503948, 0.03130122116999701, 0.05087479839858133, 0.10740295125287957, 0.06671132810879499, 0.0964900036342442, 0.04292547651857603, 0.07418080698698759, 0.06276240485021845, 0.017177987610921264, 0.0348801986547187, 0.05539107500226237, 0.09301591388066299, 0.06675999815342948, 0.021622183121507987, 0.16460988350445405, 0.014841229894955177, 0.033092435405706055, 0.04739003656140994, 0.03002691279107239, 0.022032505439710803, 0.0398489033250371, 0.04822464470635168, 0.01921402152220253, 0.04645326436730102, 0.02109168483002577, 0.043911809334531426, 0.05397100881964434, 0.04218476118694525, 0.04014202568214387, 0.007819343063601991, 0.0472682538384106, 0.034343566512688994, 0.024758419422141742, 0.05628393802908249, 0.02821640642650891, 0.03103055991232395, 0.04182519805908669, 0.023474468689528294, 0.012292310711927712, 0.049016497723641805, 0.054625041302642785, 0.08800102907116525, 0.016388368458137847, 0.06647877613431774, 0.08565438038203865, 0.015466749991901452, 0.014057034914003452, 0.02769268765405286, 0.038034066528780386, 0.017800124442146625, 0.03631859959568828, 0.07753867641440593, 0.043464390764711425, 0.020552549794956576, 0.08052707504248247, 0.02643786065164022, 0.03029784307727823, 0.05397877910581883, 0.022753034354536794, 0.025510198320262134, 0.02339545408176491, 0.03236339776776731, 0.010223604676866671, 0.05449977419630159, 0.03163690198562108, 0.05239510275714565, 0.09630184693378396, 0.04343282722402364, 0.05540068952541333, 0.03821014106506482, 0.004840398933083634, 0.015807684285391588, 0.02780421760689933, 0.020714939128083643, 0.06292358448263258, 0.0908971119497437, 0.017863698667497374, 0.008039729382289806, 0.0048686650188756175, 0.016350394616893027, 0.007116557044355432, 0.054643873299937695, 0.08045450042118318, 0.048360921573475935, 0.04490693660045508, 0.013099985389999347, 0.06277298045461066, 0.029036047308181878, 0.03591161694203038, 0.02247531712782802, 0.08430909671005793, 0.014938159019948216, 0.011723178995453054, 0.06544978838064708, 0.07532297226134688, 0.049472131868242286, 0.06820117472670972, 0.03907069098204374, 0.023957712583069224, 0.03390256009879522, 0.052880255825584754, 0.05587905936408788, 0.038397366370190866, 0.012929085478390334, 0.04516782006248832, 0.0337043732724851, 0.026276219032297377, 0.05775371326308232, 0.07393776846583933, 0.005956163231530809, 0.045471889097825624, 0.02196978653955739, 0.036896933015668765, 0.05804643114970531, 0.020178121449134778, 0.09741299043525942, 0.04092509167094249, 0.041084401091211475, 0.04619709725375287, 0.030666916827613022, 0.04747885679535102, 0.024308657521032728, 0.027810459068859927, 0.07120382259017788, 0.006039512445568107, 0.061063602843205445, 0.06803134165238589, 0.026275022319168784, 0.043416514818090945, 0.04614918048901018, 0.043296617150190286, 0.04681515412812587, 0.0642232780228369, 0.0028159610792499734, 0.030276012803369667, 0.07047852908726782, 0.04286994531867094, 0.02308559629454976, 0.03295701200840995, 0.03230232272471767, 0.006773506702302257, 0.0322738984687021, 0.06333539480692707, 0.03750114512513392, 0.03222045270376839, 0.06733267640811391, 0.020084657226107083, 0.06160365999676287, 0.11040640063583851, 0.06906662281835452, 0.04042138119984884, 0.04833768864045851, 0.02359949274250539, 0.05325440586602781, 0.05727213734644465, 0.050965021291631274, 0.09584798652213067, 0.0964703515637666, 0.014725253549841, 0.021525138035940472, 0.012869318470620783, 0.015091201930772513, 0.05816980577947106, 0.015378764674096601, 0.07468157113180496, 0.10914759943261743, 0.023281515859707724, 0.08565953830839135, 0.0029509681780837127, 0.09205526308505796, 0.04273524922609795, 0.06141134355857503, 0.05836702410306316, 0.1002857179264538, 0.008882329530024435, 0.042312399455113336, 0.045422636467264965, 0.03152008051984012, 0.03904625576979015, 0.06774503592168912, 0.06880243308842182, 0.048118198465090245, 0.04102682898519561, 0.03624906406912487, 0.058964746131096035, 0.05660498369252309, 0.04681187012465671, 0.059348725917516276, 0.018114234735548962, 0.042084994274773635, 0.08111171671771444, 0.036576358616002835, 0.018697638879530132, 0.04781133153301198, 0.011041390189348022, 0.02845293074642541, 0.08768436207901686, 0.024741311062825844, 0.00759429930440092, 0.0489870196179254, 0.05897134753467981, 0.00946744803513866, 0.014105591781117255, 0.04412878734001424, 0.06666893663350493, 0.033504575985716656, 0.044114378542872146, 0.04276911713532172, 0.036774578838958405, 0.0976541661657393, 0.02214249543612823, 0.00717442137101898, 0.022826603453722782, 0.031051160076458473, 0.02485270186298294, 0.07470070369890891, 0.05795489836600609, 0.07754291407763958, 0.04735299226013012, 0.027406131448515225, 0.04300047796277795, 0.03648205762146972, 0.07357652808423154, 0.036162655815132894, 0.052322995688882656, 0.09064946469152346, 0.08700672929990105, 0.00633999690762721, 0.02452347402140731, 0.02314426121301949, 0.03725328264408745, 0.04667703673476353, 0.04586002862197347, 0.042209207531413995, 0.015367664000223158, 0.02745284407865256, 0.011452061316958861, 0.04576364590320736, 0.05121560374391265, 0.08076446581981145, 0.0451579086802667, 0.03417379281017929, 0.0717050839739386, 0.0634854422241915, 0.05644829034281429, 0.2060931036248803, 0.1257104059914127, 0.14672888908535242, 0.09219309475156479, 0.159001755528152, 0.15367009240435436, 0.14747645444003865, 0.12302605042350478, 0.14405620750039816, 0.17582409112947062, 0.058645021490519866, 0.1287820958532393, 0.20628965401556343, 0.16442486608866602, 0.15421212738147005, 0.10598361608572304, 0.14952320867450908, 0.17066070256987587, 0.23381323961075395, 0.10069876763736829, 0.1290823391173035, 0.19589572737459093, 0.12901475914986804, 0.0882457967964001, 0.09167969183181413, 0.16696209087967873, 0.18949019140563905, 0.07351029882556759, 0.09232942727976479, 0.11115434448583983, 0.1547609010594897, 0.11413685788284056, 0.08697105426108465, 0.1365529460599646, 0.12273079439182766, 0.1416217107907869, 0.08516418442013673, 0.1810225090594031, 0.1838971141842194, 0.26572125556413084, 0.14804737380472943, 0.14552754495525733, 0.18408504081889987, 0.12379316394799389, 0.1828596362611279, 0.08564174902858213, 0.16189129266422242, 0.11980623530689627, 0.10497267736354843, 0.13473423896357417, 0.07948964906972833, 0.1252137904521078, 0.12315179250435904, 0.15466142358491197, 0.12972490541869774, 0.09136463530012406, 0.14010428596520796, 0.17304059205343947, 0.16089592420030385, 0.18449754134053364, 0.22297381656244397, 0.16342112619895488, 0.1534917246317491, 0.16798016906250268, 0.21636451652739197, 0.15275175886927173, 0.16795302130049095, 0.12450932161300443, 0.17519856453873217, 0.17476467532105744, 0.13332325295777991, 0.176134783832822, 0.13638710574014112, 0.11811627598945051, 0.11587447792408057, 0.11868418223457411, 0.11621502722846344, 0.18214905954664573, 0.16870477236807346, 0.18059516558423638, 0.15385058271931484, 0.11859556980198249, 0.2477649034699425, 0.12039608685881831, 0.20163606153801084, 0.14985858520958573, 0.28916973795276135, 0.24667648453032598, 0.15482478513149545, 0.16315842076437548, 0.14113714772975072, 0.16548870509723201, 0.39860036282334477, 0.1284402477904223, 0.2477853125310503, 0.3501888527534902, 0.23210799205116928, 0.2121052419533953, 0.2789482270600274, 0.18216036987723783, 0.2683180896565318, 0.17413845111150295, 0.16870981897227466, 0.12335010920651257, 0.2175219848868437, 0.16494077746756375, 0.28291687660384923, 0.22516517085023224, 0.21158472925890237, 0.24919885152485222, 0.16796090290881693, 0.18522134312661365, 0.18395357677945867, 0.12686313944868743, 0.14297618967248127, 0.14875909342663363, 0.19087964028585702, 0.09703430958325043, 0.22262626880547032, 0.19387512642424554, 0.1856919241254218, 0.2715800068108365, 0.08345969385118224, 0.19918983889510855, 0.14764441730221733, 0.20993345067836344, 0.12638712592888623, 0.18775024102069438, 0.17215567000675946, 0.07351435837335885, 0.1802725688321516, 0.13452057464746758, 0.16718096507247537, 0.13161733746528625, 0.15770222526043653, 0.15317717276047915, 0.12978344602743164, 0.1667464227648452, 0.13802205707179382, 0.14434033131692559, 0.20363237941637635, 0.10638256499078125, 0.12471957947127521, 0.1178814827289898, 0.14646786090452224, 0.11104095174232498, 0.18314300308702514, 0.22263070684857666, 0.278459953260608, 0.17558060731971636, 0.1736110809724778, 0.1720416167518124, 0.18841798097128049, 0.1629075303208083, 0.09930871019605547, 0.18124409951269627, 0.24957280489616096, 0.2918327122461051, 0.16726623784052208, 0.12150601323810406, 0.13735174929024652, 0.141322283889167, 0.07650673491298221, 0.06902944864123128, 0.131366862624418, 0.08551812206860632, 0.07397685738396831, 0.06492399159469642, 0.12360222419374622, 0.09623167687095702, 0.12552899541333318, 0.12422182102454826, 0.18087580130668357, 0.14693851611809805, 0.12518826057203114, 0.10103316453751177], [0.03772608266444877, 0.006737766725564143, 0.023729791610094253, 0.021453472545545083, 0.028553955598908942, 0.11684864322887734, 0.044938073406228796, 0.056909609338617884, 0.019900804982171394, 0.10891499550780281, 0.008953315955295693, 0.04207374331599567, 0.03016719168954296, 0.023706061438133474, 0.06101244660385419, 0.020341008021205198, 0.025788655839278363, 0.037252028414513916, 0.06802023912314326, 0.04374226940853987, 0.059761942611658014, 0.060714615319739096, 0.04349779483163729, 0.07040551659883931, 0.012281761082704179, 0.014608486817451194, 0.05312861925631296, 0.04671000293456018, 0.04509888938628137, 0.0573193787568016, 0.009713511735753855, 0.028291747403272893, 0.02344863081816584, 0.035105280912830494, 0.011638488813332515, 0.0879567970696371, 0.051406769853201695, 0.029511715729313437, 0.024067177510005422, 0.057920588878914714, 0.015077123389346525, 0.03710988115926739, 0.04469719082408119, 0.10867105156648904, 0.04990343841200229, 0.031134100645431317, 0.04432697045558598, 0.010231656979158288, 0.07941486284835264, 0.04274126062227879, 0.008779608870099764, 0.07937656802823767, 0.016029120743041858, 0.03159077750751749, 0.07829447218682617, 0.03453259152593091, 0.08321790213813074, 0.017230685662070755, 0.030320604746520985, 0.033274187371716835, 0.07690296755754389, 0.029302788170753047, 0.03352712985360995, 0.04663274536142126, 0.11735893654986285, 0.04810875092516653, 0.06306377617875114, 0.02084745887259487, 0.03749056581000332, 0.05260870770143811, 0.05270997375191655, 0.044192482164362445, 0.05499366976437159, 0.03305903504951857, 0.03359367823577486, 0.08558441812056117, 0.030737268716620747, 0.06182619668834377, 0.046596673273597844, 0.0783790324931033, 0.004196202689854545, 0.022326160287775565, 0.03822410086286254, 0.03906985235516913, 0.07249038753798231, 0.021823190108989365, 0.02222454913862748, 0.11874930569319986, 0.008544170868844958, 0.09207308205077425, 0.04492106338148005, 0.14819537289440632, 0.08694593256223015, 0.055807950484449975, 0.03872557375871111, 0.044627376992139034, 0.02499992540833773, 0.05285267761792056, 0.1067872135899961, 0.05460774555103853, 0.0654813890287187, 0.07727284653810784, 0.037865506237722, 0.04670139773224946, 0.08940364365116693, 0.09102321768295951, 0.028394388282322325, 0.06311940756859258, 0.053699557174695656, 0.02893590190069517, 0.059477551621966995, 0.008992457751446636, 0.024174510617740452, 0.040646359557285905, 0.04233945073792711, 0.04222136391035747, 0.04454127301869448, 0.03732386088813655, 0.03446569804509636, 0.043324662910890765, 0.023099697100406047, 0.05757483340858016, 0.043153249062015675, 0.02537183230742812, 0.05283533362671733, 0.05072325555374846, 0.010999969072145177, 0.07584862803923897, 0.043789603587356396, 0.04699471675849054, 0.04334420736995526, 0.05257116616121493, 0.024188338684325572, 0.12254903500434011, 0.03497252182569355, 0.055402133002644405, 0.05033771725720726, 0.03671452053822577, 0.02709872645937139, 0.01680269280768698, 0.04050932198879309, 0.006971718112254166, 0.04911436844849959, 0.03319288880447857, 0.00876782913110219, 0.041679818750708364, 0.03754503202799242, 0.03739545587450266, 0.022542260703630745, 0.04223290059599094, 0.014495364030153723, 0.021325420530047268, 0.005428545400718576, 0.024416563937847968, 0.07885653772973455, 0.027666768146445975, 0.017954485592781566, 0.08528226753696799, 0.015826102535356767, 0.046829644561512396, 0.045993737658136524, 0.038152160777826793, 0.005953595864411909, 0.05603433521173429, 0.09281149672460742, 0.043230699593550526, 0.07747325609670952, 0.02455269237543689, 0.036562781024258584, 0.06442761354264803, 0.023787001919117756, 0.007978109788382426, 0.044242469521122985, 0.06667312234640121, 0.09941594311385415, 0.03917321126209572, 0.021239453853922896, 0.00943827142691589, 0.011574045347515494, 0.04818551868083887, 0.07977098241099156, 0.058490153824095614, 0.00803419574367581, 0.0644360517617315, 0.022146185765450355, 0.0649504640023224, 0.005802602672702051, 0.03905205194314476, 0.03508306101139169, 0.014180229572957614, 0.04240146830852609, 0.05063716642325744, 0.028533622607938014, 0.02099433546391083, 0.03818924960796721, 0.0349835761153372, 0.03735663784027565, 0.1304640548187308, 0.038366596927517094, 0.019425765531195793, 0.01216276419654605, 0.08634448124212213, 0.02835534389305394, 0.009167581411020365, 0.08450483073829673, 0.07045868405839428, 0.006325039848888991, 0.01731514021230396, 0.01814117840694962, 0.06806137636885978, 0.05553990900807548, 0.058588169267750345, 0.051047384840785526, 0.06105540582211688, 0.025081003186642192, 0.056681484275031835, 0.03476881713140756, 0.05313414825650398, 0.04344594468420837, 0.05390893558796961, 0.015274992019840283, 0.008855806099745678, 0.02376181713771075, 0.024440932356810663, 0.024723801943764556, 0.03769558410567697, 0.023766023259668145, 0.03675172440125607, 0.027012466634914745, 0.07080304800183512, 0.07573208858957514, 0.030561960447812453, 0.11662331235129386, 0.046676509809913114, 0.02403951952146599, 0.023175596543296706, 0.0772385964228306, 0.04232463747030124, 0.014622220260207541, 0.09307547123171389, 0.06095359058235772, 0.0352024837047793, 0.08302101778099313, 0.06020912740495987, 0.10601221103570424, 0.06691072834655643, 0.01611264204257168, 0.060601244840654545, 0.08676515280967578, 0.06423446218832396, 0.04438482086698059, 0.09222922250046395, 0.011546938403625973, 0.019298544721095823, 0.05315712885931134, 0.06032817531377077, 0.06636242964304984, 0.042897386229014955, 0.007792283431626856, 0.0058667678331403295, 0.07314891001442447, 0.056160934473155066, 0.08477674622554332, 0.11114117878605612, 0.060001110832672566, 0.04571694626065437, 0.024406979100604076, 0.033475160962552764, 0.011098709037469234, 0.008452818055957323, 0.07302704194444232, 0.03292535569926258, 0.035719901643460616, 0.0582352186756907, 0.031195116316666827, 0.11245611603953876, 0.017048427180270664, 0.03259458047978114, 0.031418914659298025, 0.044432359136408195, 0.04040346575493459, 0.07392546365736052, 0.06887836221721955, 0.02553426802478498, 0.06663681648205966, 0.021412667410913855, 0.026475984777789563, 0.12499126489274204, 0.07054731133393943, 0.03950666563468985, 0.04935234923323151, 0.04012728662928566, 0.02357060649956111, 0.01875586593087064, 0.05955128770438023, 0.016422208536823746, 0.03187878646713216, 0.06876584520796314, 0.038367253728210926, 0.03287573570560198, 0.04647666428354569, 0.036342081148177385, 0.024636894595460035, 0.05920696828979999, 0.050110894662793726, 0.04089072652277537, 0.10928771691396832, 0.01130271522924886, 0.07577774551464245, 0.08710590991540812, 0.06502204414573498, 0.13653296744450927, 0.06123469014710281, 0.06634994671912864, 0.04716999348602258, 0.03120237452094443, 0.04564188544463832, 0.008460288700007368, 0.10161536454688758, 0.03855908405967057, 0.02067358851491008, 0.04683219754952006, 0.019559686079446692, 0.030015465163160115, 0.014760471240151674, 0.026599123775667977, 0.10215813425020315, 0.019956432661274448, 0.008113477524602786, 0.03403016125957947, 0.042579806395224296, 0.023876182094682008, 0.017621639781282283, 0.07235276367282495, 0.01853869682236109, 0.015404961559397634, 0.04323487788497005, 0.018888773447542917, 0.021233396073512267, 0.029863757190469187, 0.05350206796720158, 0.05314989663020242, 0.018267534615006298, 0.07817589925252832, 0.019231916558055673, 0.036393905320437625, 0.030818949489912484, 0.07731154953944497, 0.0057831607227853965, 0.03443937035626732, 0.07064618766889907, 0.06644607710768469, 0.12245110119692981, 0.08270377933513373, 0.12433138428605162, 0.08758590876823291, 0.194908982666675, 0.27154343377333134, 0.17192797909956425, 0.24365598801523447, 0.10301270987838507, 0.14279810391599312, 0.13779331231489778, 0.09232273310772143, 0.16492379712872207, 0.06796622561523691, 0.09248179019778036, 0.12604786053998396, 0.10783620964502916, 0.10656243190169334, 0.18407750059850514, 0.08493687942973338, 0.16999560466501862, 0.22507651388878003, 0.12169026624178514, 0.08309003751492128, 0.07534362623118795, 0.15256498998496681, 0.12040431727655232, 0.11494952443172224, 0.15335923642851412, 0.13662033306900412, 0.08969618342234753, 0.08884096212568693, 0.19348250061739236, 0.17411324777640402, 0.19709880813024938, 0.12930248980410397, 0.17548632487887517, 0.17988080391660333, 0.07750340955681168, 0.17935157840838656, 0.17994195688515902, 0.11781073379097506, 0.12154583688243292, 0.25106069224420935, 0.1859507555491291, 0.14634410035796463, 0.10585600379272364, 0.08360896201338619, 0.15880256309174, 0.08923893881728873, 0.11867200359120034, 0.18057215900626034, 0.11935221904423088, 0.0938897482410539, 0.25657847116235644, 0.0935759607818909, 0.22820883721578866, 0.25180640222970396, 0.0810365223151166, 0.09636222064727917, 0.14970645977882668, 0.19982856087153777, 0.11109644212410785, 0.13788415119051933, 0.31714502430986613, 0.11704480028129183, 0.22855901217553765, 0.17131616739789024, 0.23018801148282364, 0.11507702540257014, 0.07369064071099274, 0.09868630062555894, 0.22294116206467152, 0.1588347426149994, 0.1353054551873356, 0.2449398292810656, 0.18018634611507878, 0.15549167903373018, 0.12719522084807977, 0.1517001207685098, 0.20436634862562642, 0.16721548978239298, 0.0841872657474596, 0.11425465156207792, 0.19182829797500744, 0.17069788416847587, 0.21689617627998814, 0.23389941779896617, 0.16411549440817907, 0.16145973379025236, 0.11973397238762118, 0.3157040406949818, 0.2127471996936947, 0.18160773703129962, 0.2608967019477859, 0.14638165303040296, 0.12282689509447664, 0.1818896789336577, 0.14307249075500295, 0.21021684719016775, 0.19386026862775907, 0.16561009077122435, 0.1415060248109512, 0.17074423871235922, 0.24473051395034418, 0.2135372901102528, 0.154177394870203, 0.2707253198605031, 0.13761613197857514, 0.1248115167254582, 0.15665484708733857, 0.22207878646440804, 0.15837038081372157, 0.1341373147442937, 0.22176407132064924, 0.16499890247359872, 0.10014868777943775, 0.12049585377098992, 0.16321690200129524, 0.08906667149858549, 0.11421449395129457, 0.16423359978944063, 0.16786605643574148, 0.1071568179759197, 0.13438146648695692, 0.10618998509016819, 0.06174057511088904, 0.20687826618086547, 0.14693519129650667, 0.1476607593940571, 0.15531157463556156, 0.15298240352422, 0.1867901987861842, 0.25369751325342804, 0.15503254195209593, 0.21536659507546574, 0.23634062352357432, 0.15950329892802984, 0.15524677030043676, 0.10678437116439454, 0.12271986255655065, 0.08807888036244549, 0.2099316695239395, 0.158790391869843, 0.08239729460910894, 0.1378647514502518, 0.13614065333968028, 0.17959396383957937, 0.0856837842729874, 0.06579418200999498, 0.1946069730911404, 0.1086946518626064, 0.1450932104489766, 0.0966389526729472, 0.14092796598561108, 0.09854418676695786, 0.21564067021245137, 0.1693280428298749, 0.08473693742416799, 0.1691177478642203, 0.0888930237852037, 0.09469229189562611, 0.06310192256933078, 0.14470693742623553, 0.1934831982362084, 0.17056906217476353, 0.16414391866419464, 0.22538155142683536, 0.12237891991389915, 0.11182138681760989, 0.1066484913462773, 0.22095864813309163, 0.13691452040802687, 0.12490533903473988, 0.2039420627988875, 0.15543441491900012], [0.06401396269211546, 0.0134878354765533, 0.05100450354802888, 0.052522510959533975, 0.054300425908877514, 0.03433729536482133, 0.05086345838208217, 0.013652026373165427, 0.04052605370816309, 0.029133493153494783, 0.019148146639054175, 0.06865205912617967, 0.02277765510370955, 0.03396226587938145, 0.06141377780295443, 0.05922057927818969, 0.07737420164630748, 0.07075271554640494, 0.015885225730016828, 0.02564028196502477, 0.02916939640272176, 0.05844917985086795, 0.09237142541678622, 0.06771024403860793, 0.03551780740963295, 0.009172766240226338, 0.04619779487256892, 0.015683892197557725, 0.016615243002888747, 0.03436992017668672, 0.007059139397824765, 0.01646737007831689, 0.09488910203799605, 0.0465604972850997, 0.015966733953973744, 0.06716834264807403, 0.029608617951453198, 0.03916368579666596, 0.036331420196802355, 0.09623423728044145, 0.09420746166142635, 0.02662673723534681, 0.028615501905733254, 0.058682225353550166, 0.10323122784029692, 0.01647936132940231, 0.04734501788334455, 0.023320178042922635, 0.0576880072185304, 0.03778205544222146, 0.07589055938296951, 0.046168238841346465, 0.03878149829688482, 0.019983192651125137, 0.08597558931796812, 0.056718632476986386, 0.02881911197619047, 0.035578003007685766, 0.06625734153203666, 0.07566507265437394, 0.0026065249176099314, 0.06894228339660913, 0.02327916881768033, 0.04551201331196353, 0.029616189713124186, 0.0751174493052531, 0.049540227628313005, 0.036355391566758044, 0.03266249812440947, 0.015489281595364446, 0.04104213207028806, 0.01097120806662133, 0.035195054806536064, 0.08232341380789876, 0.07475033111404628, 0.06193607907334808, 0.024802890766295604, 0.051888074885937385, 0.016609099875495303, 0.037580083662760444, 0.002353121840314998, 0.05251251051959116, 0.039428736417903565, 0.05852801819855813, 0.031504339567618445, 0.01648042816668749, 0.0382505361631047, 0.021540806628763676, 0.09685240176622756, 0.051608214707812294, 0.042261053968104534, 0.09305008235969581, 0.15679680509492755, 0.04763145720062312, 0.059698711629607715, 0.008906979965104256, 0.05263048231427092, 0.03904896089807153, 0.09108529091463424, 0.04370458686025813, 0.06392356168362312, 0.04390733789477963, 0.04662690465920605, 0.049104045174317434, 0.09495729056652635, 0.028569368150783703, 0.04418592528963927, 0.03232721064705402, 0.05395254789618775, 0.02115259845595574, 0.10625112321577035, 0.05027711347793229, 0.03346857811266091, 0.028828379545302596, 0.02535620082198875, 0.025250626604247373, 0.0016578566760472313, 0.032619134435663, 0.03792948307818733, 0.12080024564056657, 0.07299346718355082, 0.08963828106061555, 0.02620299688715022, 0.03917253219697159, 0.034787530385074206, 0.0765755468455609, 0.031924272698233835, 0.014629057295678649, 0.03295285969215911, 0.026130142105103005, 0.05032508590375073, 0.03718857478816062, 0.012808864976250334, 0.054315610250341706, 0.031591096631018445, 0.08609025113401003, 0.04059099534060806, 0.03532981398166157, 0.018681447072594892, 0.03854218164633494, 0.09398567824973725, 0.06596203355002217, 0.02919708964327583, 0.021354815144150052, 0.032427278129034676, 0.027635982005449478, 0.07553500385256484, 0.04166942868323531, 0.015072696478455327, 0.026107970443263184, 0.026034757574961986, 0.08523649928974919, 0.01917920366395265, 0.07775248916004784, 0.05023306701332331, 0.017760749797162134, 0.04869456148298923, 0.030260795065260027, 0.04314707810408436, 0.051147292761015706, 0.08333196281455457, 0.059499081326066516, 0.004542723499980639, 0.011510233634908218, 0.06206224417837802, 0.04046113434014842, 0.025364334760524798, 0.025261909104301594, 0.012971566011401592, 0.04419363620399963, 0.02970182798890164, 0.05523022191482596, 0.01757381578499917, 0.01556895764224464, 0.06702290396788158, 0.007528137302870164, 0.011883813149324851, 0.016439467181044165, 0.04975013667717576, 0.02970406370877754, 0.020559125223371666, 0.0525209784245817, 0.03910803956387099, 0.06076404235500377, 0.08936997983255424, 0.0590428571740631, 0.054099623012007214, 0.03542460108292289, 0.0035378112488615443, 0.022901497286511585, 0.03313739100121893, 0.0332258809794439, 0.04296307000913657, 0.05216745637881104, 0.006973230238145334, 0.04466718579351436, 0.004982473828931688, 0.12177687487564981, 0.0571941339148907, 0.020520761754596606, 0.04721521254396066, 0.0036597382268155343, 0.04878910738625564, 0.036834655693382956, 0.056905583187472075, 0.02935303156846203, 0.020062646981386933, 0.0206056393290055, 0.05523921674466692, 0.014615365598729113, 0.023485695528506767, 0.026940333591483068, 0.027233661894570105, 0.02460943884216249, 0.05550669789954554, 0.03268430242314935, 0.06271116697462276, 0.028946971033292357, 0.02202871492045233, 0.08622420878964476, 0.002996673806592298, 0.01808067667298019, 0.0386037168209441, 0.04483091841393616, 0.018866896789404564, 0.02113163092872128, 0.03348660859046504, 0.04695973933849018, 0.04802627976459917, 0.02362711362366099, 0.043911278698942624, 0.03285203893028665, 0.059067566980957054, 0.07060020419885404, 0.051700767944566905, 0.019235131912864745, 0.026894073671428487, 0.05580035089224111, 0.05224823915341403, 0.05108861856570002, 0.016868593666004017, 0.060602922094403766, 0.039145273112808354, 0.06678108256892301, 0.020850585169682745, 0.03516450058668852, 0.06857064552605152, 0.010856603767024353, 0.06691441682050936, 0.05377107052481733, 0.06291496814810671, 0.04049501338158734, 0.009587294680386549, 0.04756921327498276, 0.005512173383976915, 0.024643507131258957, 0.035745019631576724, 0.025350350842927583, 0.05137065323651768, 0.025527841025905218, 0.011589388323045569, 0.04240939444571268, 0.056240793273900636, 0.006919748293512384, 0.06900312466314062, 0.04567398704239167, 0.03965132877056021, 0.010148421406483976, 0.0816341738391202, 0.0729780008259695, 0.06289694880251773, 0.03512952316668816, 0.04972670336428564, 0.09590589630533941, 0.1380556615185924, 0.03421134177187923, 0.03503026833641343, 0.015765517309773713, 0.05616968439426273, 0.05125305993715301, 0.07810122435330413, 0.020134796723141335, 0.07618853167514317, 0.00740100137591071, 0.019983899546787143, 0.008459412965748925, 0.058552583286655135, 0.05081213515950367, 0.05639613591483794, 0.053560411906801164, 0.02870943924790481, 0.025992718619818334, 0.0391987337206956, 0.01405479362801998, 0.023209021019283682, 0.1416483538923785, 0.04410056346387137, 0.05125297830090858, 0.022716392668371554, 0.08407759116380475, 0.016152560310729314, 0.02018027924350463, 0.04965140877175145, 0.07172204204834998, 0.01858337225712603, 0.08758400144870393, 0.05499025217432063, 0.045038289317744784, 0.015854361663514283, 0.026225595283904113, 0.030243755354604218, 0.1384560056612827, 0.04132271955313627, 0.04610358664649539, 0.03392351092770696, 0.03333696935442276, 0.036862608685623854, 0.05643768876325339, 0.026372534957772586, 0.041075083427131176, 0.031630975936423056, 0.0875753999571316, 0.05585700644587632, 0.06139733552117832, 0.0684365765482653, 0.029306413562153466, 0.049698227157932706, 0.015332956536440179, 0.037402944144560024, 0.03559474214853253, 0.014025370255694725, 0.04675028299971018, 0.03489912342047319, 0.011740121299226303, 0.010280904043611372, 0.040969954497995786, 0.06439246542868204, 0.06275623760302551, 0.017974451220652554, 0.0692529538355302, 0.028854553238488734, 0.02297164322953904, 0.03137526895443443, 0.04100372963875998, 0.021365563297877088, 0.04464163364900742, 0.035022750380449, 0.013782834539597388, 0.01660251888097264, 0.08610214033978991, 0.022904755314812064, 0.043181354194530286, 0.16350283665815368, 0.07487261478672735, 0.24386594159295782, 0.11261377047048882, 0.09390427207108587, 0.16705898568034172, 0.2713534439681098, 0.05287158382998314, 0.12390772186336108, 0.10960550454910845, 0.1261134070227854, 0.13679953204700723, 0.13200270506786183, 0.10603441609418951, 0.12097522921976633, 0.14119138388196006, 0.16176435572560877, 0.1304667117074132, 0.11630666020209901, 0.1678693515714258, 0.1445441844407469, 0.21797675814013928, 0.10325428636861034, 0.15989040315616876, 0.12318795736064203, 0.11921610916033387, 0.1923020405229181, 0.12099433210096322, 0.10276300687110052, 0.10756219387985766, 0.06699792327708565, 0.07250530470628291, 0.16820566321257502, 0.19212677492760122, 0.09169296143227257, 0.18657087930478156, 0.12904103117762133, 0.13201167021179572, 0.1476878923131153, 0.17033773474395275, 0.21785127581097186, 0.1213111549441237, 0.06759124065865763, 0.12417214165907353, 0.16996694292174652, 0.1278717181412503, 0.14536396076437086, 0.14793271198868752, 0.12406142806867138, 0.09713778723380528, 0.14690170559333637, 0.16360085952328518, 0.12453102943254635, 0.09107688238145784, 0.16528284817468375, 0.10809455125126988, 0.1032443786971271, 0.12742672639433295, 0.16653404978569597, 0.1775473283487372, 0.052504139093798585, 0.15736871893750504, 0.11564776665181853, 0.18578930874355137, 0.1344483785214834, 0.21601974440272897, 0.09165787269012071, 0.2074117070878856, 0.10832282845512964, 0.11178925182321109, 0.1245998265221715, 0.09208888237481005, 0.13629856752231717, 0.24199624895118177, 0.13933582173194736, 0.1783378195250407, 0.09501949738478288, 0.1748761162161827, 0.072529231547378, 0.14452212781179696, 0.13795027654850855, 0.1081963516480755, 0.08258549583842978, 0.14371752098668367, 0.10058574596769176, 0.2719397406326607, 0.08778858929872513, 0.12477886222768575, 0.19011371419765055, 0.16695646540028974, 0.23672668874496594, 0.15831952885491773, 0.2609681856120005, 0.243291623191908, 0.17759432113962248, 0.12245153164258227, 0.19763539574341848, 0.25178013020195067, 0.2795410546241328, 0.16607691650278866, 0.15468355442862958, 0.1486688037402928, 0.14200503006577492, 0.23743990750517696, 0.295987106510438, 0.11366273683961481, 0.16996361810015514, 0.08919368265196681, 0.0915654085110873, 0.14203234110027552, 0.19675897870911285, 0.14987802947871387, 0.1851063102367334, 0.1527487754356116, 0.12025907155475579, 0.12182972321170382, 0.11903844642802142, 0.15229075157549232, 0.10978558668284677, 0.29520414071157575, 0.13903213490266353, 0.30337863019667566, 0.17537832754896954, 0.11355045731761493, 0.08099464292172343, 0.15515058796154335, 0.26623719662893564, 0.12476526608224958, 0.1005682535469532, 0.21518043475225568, 0.1389087751158513, 0.1297548139700666, 0.06544978095917031, 0.15893169678747654, 0.14807530824327841, 0.21842350135557353, 0.20103187911445275, 0.203253423969727, 0.18865019897930324, 0.12429551628883928, 0.20045990590006113, 0.11416295179515146, 0.13478136534104124, 0.10044837443274446, 0.08917084676795639, 0.13769972749287263, 0.20692604564828798, 0.14241769385989755, 0.171357074577827, 0.13537597405957058, 0.11532608274137601, 0.14555028436006978, 0.10291873913956806, 0.24980031768791378, 0.27781134587712586, 0.10641304499586113, 0.09475790517171845, 0.059612013938021846, 0.07745823502773419, 0.14556202513631433, 0.2000268330448307, 0.17231869016541168, 0.09216029924573377, 0.1768131513381377, 0.10895935367443599, 0.08708644338184968, 0.1545451587298885, 0.1797228748910129, 0.11040527999284677, 0.16946584481047466, 0.07012251342530362, 0.13496014871634543, 0.15199827117612585, 0.1668803210486658, 0.13410276034846902, 0.06910200099810027], [0.014829571682639653, 0.0738259193894919, 0.038999147946015, 0.024962578681879677, 0.036964961982448585, 0.017715480644255877, 0.04717659488960635, 0.07002886180998757, 0.020894321787636727, 0.015630051238986198, 0.004769353599840542, 0.01890376297524199, 0.010229487124888692, 0.082935440732399, 0.10164341030758806, 0.023089999085641466, 0.051947621104773134, 0.02523857227060944, 0.0489063926943345, 0.05291680288792122, 0.033572868414921686, 0.010904205119004473, 0.07447016294463538, 0.03879407770000398, 0.015076656763994833, 0.025171378219965845, 0.046724077765247785, 0.05175418402359355, 0.033622570044826716, 0.048116454418050125, 0.030346490857482422, 0.03642692347057164, 0.038799005560576916, 0.043245249398751184, 0.05675513129972387, 0.019994887043139897, 0.07326003920752555, 0.032529100790270604, 0.029785458755213767, 0.03427186020417139, 0.01133978643338196, 0.06591846948140301, 0.01752565411152318, 0.05925507430220023, 0.03983339986007195, 0.02546178988268366, 0.01652796272537671, 0.06089135036745574, 0.04096002085134387, 0.05177509032364469, 0.07489383278880268, 0.004065176981384866, 0.06601732355193235, 0.05566672349232249, 0.04754911220516078, 0.06116131029557437, 0.019748434642679058, 0.015625538981112186, 0.06305935297859833, 0.023063806838763412, 0.061507403443101794, 0.006806735900681815, 0.06670006972854026, 0.009410628281329991, 0.04393965100462083, 0.06030790726072155, 0.0402518375631189, 0.07970987397129647, 0.08222075994126499, 0.028850230228272267, 0.06307947260211222, 0.045779657739331014, 0.07014267015620135, 0.04173657449427992, 0.014427351761696627, 0.03841144862235524, 0.025962138424802106, 0.06953110336326063, 0.018793589297274593, 0.018996857979800552, 0.012258703482075362, 0.03644055672339164, 0.01861937384092016, 0.03861720164422877, 0.034991086649824865, 0.06474369423813187, 0.06611930206418037, 0.06513397485832684, 0.024203532302635722, 0.08257811146904714, 0.021077782548672985, 0.06567211356014013, 0.0608508365257876, 0.028063310637662653, 0.08562656468711793, 0.03430753895372618, 0.04797179870365653, 0.008100016821117606, 0.027992563555017114, 0.05406008138379548, 0.021804139178129844, 0.03229321286198683, 0.013142832358425949, 0.0627901685948018, 0.03481028834357858, 0.029893487626395654, 0.014972834014770342, 0.04680035199271515, 0.05356713576475158, 0.040988485925481655, 0.034820604196283966, 0.05004049453418702, 0.025369483410031535, 0.01541355191875482, 0.04237043540342711, 0.04218043075525202, 0.011609528355620569, 0.015978363408066798, 0.03360065813467372, 0.009347014165541623, 0.023959849968377966, 0.09658928072894923, 0.03322431133710779, 0.04118513279536273, 0.018521664533182047, 0.04651938972529024, 0.0351794437301578, 0.036357321150717326, 0.08180013290257193, 0.017508571727375966, 0.030009782167326193, 0.047217227474902757, 0.020978208594897296, 0.0244162689341465, 0.05947597455815412, 0.042530791251920164, 0.02493945707101375, 0.02702171008422738, 0.050210743211209774, 0.047704451135359704, 0.059047005779575557, 0.02669937864993699, 0.0317037583590718, 0.026694786611187737, 0.02778086778562283, 0.053991844615666196, 0.024361752621189225, 0.029499598313122988, 0.052084974086028524, 0.03561888792319223, 0.055099711535149254, 0.029888487406424247, 0.03147273149807006, 0.030336705640365835, 0.059151236710022204, 0.03502280975226313, 0.056192204865510575, 0.005694699038940598, 0.03383849048987031, 0.04673329523939174, 0.005349391176423524, 0.04655440054193605, 0.008071954362094402, 0.07162712878198363, 0.033252097346121445, 0.03180557359883096, 0.052650590805569664, 0.10041257322882302, 0.04321577500377316, 0.030224737820390146, 0.05477038350363728, 0.023636735568288714, 0.10585759198875166, 0.04389942288980819, 0.025862813090498094, 0.02293831708811922, 0.02322300679225009, 0.046915069469832815, 0.023457178504031617, 0.04948549052642193, 0.02691073859750759, 0.056311219377676025, 0.037491675320779905, 0.037938793320790865, 0.037773175645270385, 0.01778528148861369, 0.0012300770731599187, 0.009903438458422897, 0.032559098399360664, 0.01097038892112323, 0.03452430544712115, 0.020714551355922595, 0.0735422334400937, 0.09340583084849641, 0.024211480704252608, 0.05923289521888364, 0.045977811168995686, 0.02786522585665807, 0.017383883496222552, 0.053356154312496074, 0.021156702532607596, 0.015075886785780312, 0.0036406803383215447, 0.02807683627906954, 0.01344895435977378, 0.013954357855254784, 0.04585799513733946, 0.05140320383361541, 0.04621690146450419, 0.08915428203181364, 0.07023360551102087, 0.02005394529987825, 0.04635286662960425, 0.02697059651836753, 0.04787591322383378, 0.027861029011546634, 0.010646117698343005, 0.04808027842955198, 0.020473512922762893, 0.0526491213531699, 0.01394394366798224, 0.018545771345088724, 0.01973190144781256, 0.01792620234482456, 0.013881042013963452, 0.012198968943266664, 0.007838546134735225, 0.0811594442347996, 0.05832335242303088, 0.019996297123725526, 0.06621555119636469, 0.021108832152094692, 0.06720893070450984, 0.036526471449178644, 0.04149001819314435, 0.017075064715754706, 0.022365536788129248, 0.03731549688382074, 0.02143854981113691, 0.04024854984891135, 0.004241420356265735, 0.08982359533547424, 0.015990939100447576, 0.025861174799501896, 0.05930515813815873, 0.01138659554271726, 0.04810095837456174, 0.044652947690337896, 0.05922821968852077, 0.04013582874904387, 0.03900356372469105, 0.04629579547327012, 0.08622713285149075, 0.072595141682541, 0.07009503911831416, 0.04811849161342252, 0.0746158094261773, 0.016379045227949973, 0.009908206757245352, 0.018920424190582708, 0.07004860293818638, 0.012775252180290408, 0.05736418592277914, 0.05638469570840243, 0.04103922656213399, 0.02958360386401182, 0.012987101945327595, 0.07574816350825131, 0.007372711634161533, 0.005501667355929385, 0.08225411947933026, 0.0864833890227601, 0.08328087336849421, 0.06729113098117523, 0.057149545682477765, 0.07909051462775096, 0.052606581448344514, 0.08970458453404717, 0.04848390286497306, 0.06819516333052889, 0.05485711830260698, 0.11220399363082834, 0.034280368927284144, 0.016082642578112427, 0.019103723534499295, 0.0354113648791099, 0.0826429232256487, 0.0023492462059948593, 0.05674268919392489, 0.046213580353651196, 0.08652013275423087, 0.02570427179307444, 0.014694418241560925, 0.05375482862291392, 0.03921720948710572, 0.022852817965031136, 0.012355999970168341, 0.040957627425086685, 0.06209039012901485, 0.012737493561871815, 0.03996296400146093, 0.018453097509336658, 0.019694675320351962, 0.07618169649504125, 0.052399076957954094, 0.02565117298217956, 0.0383886832423741, 0.017873673132271506, 0.016740083374315873, 0.049674767869873904, 0.038909299837541766, 0.006116969934737426, 0.07609066466102377, 0.025100503116846085, 0.06356739017064683, 0.032151859704754315, 0.08089166251011193, 0.032294125703629106, 0.048444557905895635, 0.03879774019878823, 0.017814249367802404, 0.020730787691718433, 0.0799521258159075, 0.0361191436968511, 0.060777341641369276, 0.05180393018235918, 0.01770843951817369, 0.023564953189634252, 0.034014865595963784, 0.04269689874490723, 0.01012638147585676, 0.05358568945666775, 0.0833769963355735, 0.013653885453095427, 0.05746508832089603, 0.014713088821736164, 0.050962520253960975, 0.02293392357387347, 0.05702318390831351, 0.06439124830649234, 0.04604902394930832, 0.10585467534838244, 0.0061296481362660415, 0.06725020153680816, 0.027533135180419777, 0.048932943027466536, 0.005971781265543541, 0.040035976489889435, 0.10393772274255753, 0.027095611294498667, 0.017556956045154948, 0.006417115328076761, 0.06609347532503307, 0.19150764564983547, 0.0964664998173248, 0.10325165916583501, 0.12924204929731786, 0.1458199362969026, 0.09992922728997655, 0.18705860391492024, 0.15040658705402166, 0.15592994692269713, 0.06819393136538565, 0.06945380868273787, 0.07818505735485815, 0.13815694983350113, 0.18921442417195067, 0.08667501155287027, 0.10553526983130723, 0.18034439388429746, 0.1898106507724151, 0.18008764047408476, 0.18747530499240384, 0.16090935707325116, 0.13839482300681993, 0.13852823147317395, 0.10259838367346674, 0.15112114168005064, 0.11235357349505648, 0.1817679964005947, 0.125232819118537, 0.11740519461454824, 0.09520025487290695, 0.082684067892842, 0.13194860250223428, 0.16977993655018508, 0.18301392876310274, 0.08636029640911147, 0.13431681058136746, 0.07793427823344246, 0.12146559587563388, 0.07620467338711023, 0.057807652556221, 0.10589354162220843, 0.1386922164238058, 0.16363064933102578, 0.09941098556737415, 0.11249898991081864, 0.1095305105263833, 0.1566719016409479, 0.0858659295772668, 0.13734655425651, 0.13386908773100004, 0.1440259872470051, 0.12951726734172553, 0.13439938193187118, 0.2396540011977777, 0.13328924775123596, 0.14927620708476752, 0.10541645940975286, 0.14618968911236152, 0.2005994741921313, 0.27519480034243315, 0.12142699677497149, 0.16791380621725693, 0.2089863218134269, 0.2293984850984998, 0.17014428653055802, 0.10165513624087907, 0.1423576392699033, 0.14432139170821756, 0.06086121175030712, 0.1301667356165126, 0.18698654137551785, 0.23577276180731133, 0.17654939205385745, 0.0767598592210561, 0.16807206178782508, 0.25953735457733274, 0.2241983453859575, 0.2297325702966191, 0.1596925317426212, 0.17431963904527947, 0.21985939383739606, 0.11140321628772654, 0.08074335171841085, 0.20154931931756437, 0.14373698009876534, 0.1513793645426631, 0.19147666840581223, 0.11303550330922008, 0.16931322956224903, 0.15990589919965714, 0.17502111702924594, 0.15871826995862648, 0.12742311955662444, 0.2233282069209963, 0.25508256861940026, 0.2587209624471143, 0.1305723044788465, 0.17171722400235012, 0.1787571923341602, 0.12742911610985175, 0.133793804270681, 0.10301660615368746, 0.28025428822729737, 0.23636443162104115, 0.23355431912932545, 0.13368080486543477, 0.11469229604699649, 0.15885095112025738, 0.15757595625473186, 0.17737274552928284, 0.14813374495133758, 0.1941171704675071, 0.14945898321457207, 0.14080799039220437, 0.1283151365350932, 0.10186601750319824, 0.15978636889485642, 0.1307329349219799, 0.09984224758227356, 0.12995215103728697, 0.2115898797637783, 0.19949220470152795, 0.16521498619113117, 0.18506279069697484, 0.16913918108912185, 0.21662925544660538, 0.22183410037541762, 0.2179627909208648, 0.13868665031623095, 0.17911740113049746, 0.09810116171138361, 0.12462054728530347, 0.1741176116047427, 0.11197782412637025, 0.24029459338635206, 0.26595826784614474, 0.1020398062246386, 0.10890250516240485, 0.11535630299476907, 0.12508259358583018, 0.1119871306582354, 0.09955869521945715, 0.17138288647402078, 0.17871137213660404, 0.16464612999698147, 0.12475561816245317, 0.19215013773646206, 0.13834965589921921, 0.16524639388080686, 0.1551966308034025, 0.10874626823351718, 0.08779800715274177, 0.1212899517850019, 0.1661186252022162, 0.11081527947681025, 0.13791021541692317, 0.11842056395835243, 0.15019896382000297, 0.1277341684908606, 0.2503054233966395, 0.1297285864711739, 0.09251413299352862, 0.26466476381756365, 0.19881530664861202, 0.13527878239983693, 0.0975387250946369, 0.1649074995657429, 0.12110623312764801, 0.10636528037139215, 0.1740108462399803, 0.1123662493773736, 0.2213416260201484, 0.11320944788167253, 0.13711308944039047, 0.14134971366729587], [0.020519821082416456, 0.07477832492440939, 0.02349188318476081, 0.015789449716976378, 0.051419750016066246, 0.019967147418356035, 0.050979322477360256, 0.06940952473087236, 0.01780408936610911, 0.012650455410039285, 0.0447781257389579, 0.00937323238758836, 0.021606425470963586, 0.01897104608360678, 0.03109568151558051, 0.06689599671517499, 0.0067239354120829375, 0.04680729478423018, 0.026517311271163635, 0.03935536769859027, 0.06919631312484853, 0.046425983018707484, 0.027474856178741902, 0.054763325679232366, 0.025112804214586504, 0.012742743328999495, 0.01818911001464585, 0.052194062373018824, 0.026414041421958245, 0.04236137006955687, 0.07065088546369225, 0.039056668101693504, 0.01874326240795199, 0.08537107292795554, 0.02053379201242933, 0.05724341252062004, 0.04531891390797682, 0.02991085573739838, 0.07394458880298771, 0.04376368407974951, 0.07620672171469778, 0.023666736888117157, 0.051502043061191216, 0.05813960779050831, 0.07169139134930447, 0.04197929760266561, 0.04673712843214162, 0.031299247057177126, 0.08074562269030139, 0.028875474381493405, 0.03596121838199906, 0.0324293746962212, 0.036803177499677986, 0.05998952219670173, 0.03570669512555469, 0.035847176259267144, 0.06819792411988601, 0.030433377796725836, 0.03978599146648776, 0.06275991865550168, 0.008243959146057023, 0.008605812727182638, 0.12579840986290947, 0.04812352708540857, 0.014787391719437437, 0.06294877297477797, 0.041200246632797644, 0.014219053173292195, 0.042264568037353456, 0.05134458901011385, 0.025675517281342763, 0.09938447605236433, 0.018140564279747196, 0.024138431108440273, 0.035316503563080914, 0.06802501855418086, 0.05717634463508148, 0.03500376995361876, 0.04158528769039549, 0.02836926101736026, 0.05498231119418051, 0.02754199642367894, 0.1008708865265362, 0.018762882937153336, 0.10896301988395862, 0.030289816750155296, 0.025351085569127463, 0.016984186877380125, 0.02235323569038883, 0.010483195874257945, 0.04969492831151001, 0.0320259098225506, 0.0878741811902728, 0.029161117745388765, 0.027681277133524418, 0.030451013080892153, 0.03995343853603117, 0.019521530412021093, 0.027137728175148368, 0.05053062741353642, 0.06049312876712065, 0.028782327426597476, 0.046155993404681794, 0.05831909249536693, 0.0655097168055363, 0.03302681099739857, 0.07534847245551646, 0.052304185956018046, 0.04998486314434558, 0.00930956539377803, 0.0499507763015572, 0.07194703153800219, 0.027062268454756122, 0.041987153235822916, 0.036724005185533315, 0.05396447792008985, 0.027624471294984687, 0.055386481108143926, 0.005688489118256257, 0.04370712129457388, 0.08575316023780033, 0.08166814193828031, 0.06959364414797164, 0.08729408888029866, 0.05516845667443704, 0.03592791821574792, 0.07235920551465824, 0.02873360543162562, 0.0268201947255875, 0.027827478370454628, 0.04318929888540879, 0.05060651572421193, 0.02718625164561672, 0.027300883775751572, 0.04743761193822138, 0.06377003359375522, 0.026719236666394863, 0.12063008602126502, 0.023332479140663054, 0.033749536669347435, 0.07889507745858282, 0.037337913454393856, 0.04849896104133222, 0.0021759656237918534, 0.05720591921999585, 0.04155840339080896, 0.043548750691115856, 0.04628103786672, 0.033698261686367914, 0.06254317442653701, 0.035203823281335644, 0.020528096029011067, 0.0200038280672743, 0.028249953356862534, 0.05510511065949686, 0.023825226235203445, 0.0793223615619354, 0.037980887937010266, 0.013263887776702177, 0.009233390428562416, 0.02136798826541053, 0.06502386982901953, 0.037088039753143676, 0.0419798096845625, 0.06340825886582024, 0.030466392236121465, 0.057561214998713695, 0.031102828397706617, 0.03825255851552356, 0.044243308147997595, 0.012582827203004854, 0.009514382381894393, 0.021975886993459426, 0.036791540624108166, 0.048545545650995336, 0.016680867411196232, 0.0340187136316672, 0.009061180626304122, 0.08413986477535218, 0.02436805716570234, 0.04621243002475239, 0.06340903812088072, 0.0595592398167355, 0.01832413636293495, 0.002883637757804536, 0.01206234512210358, 0.0358575663267402, 0.044511839441838674, 0.063664247863926, 0.04603283028700389, 0.020849325374001637, 0.058688099452410825, 0.06751306282239966, 0.0795665207260754, 0.07900533833890222, 0.06212860702362377, 0.07966738601680845, 0.03270512337621767, 0.03149360440147575, 0.05044910249125678, 0.014655474969913485, 0.02415355422272114, 0.008474806963931769, 0.00989261330687441, 0.011182439993717708, 0.021734830006607808, 0.027655396588670556, 0.03226128937967587, 0.017829882708610967, 0.07105485870852135, 0.03408218210097402, 0.04654866374039557, 0.014842410837445641, 0.03417132145841606, 0.1301009368035011, 0.06482763856183738, 0.04709509594249539, 0.01788607070920989, 0.09226784386555664, 0.02921757291915128, 0.09594750110409223, 0.03376174128788989, 0.04596565479005221, 0.006723580572725041, 0.11843263127957471, 0.052783750652452, 0.02743510118307313, 0.04223020288918633, 0.04242060458636843, 0.03456934638961684, 0.030367940780706704, 0.029078401676088106, 0.025403290092071984, 0.023892379467724822, 0.031876118446234614, 0.04742597506265156, 0.044737051575793885, 0.04137780546443537, 0.04669580564950593, 0.0354478154622484, 0.05154206337465439, 0.017050443966581952, 0.11744474366423674, 0.0332687511399854, 0.05227685636782553, 0.04085522588866297, 0.045379718067124486, 0.014863902506476734, 0.056197596568381414, 0.03312347202154342, 0.08584796218201518, 0.02338043115742039, 0.037822981175850146, 0.028129495367466006, 0.07336136462981813, 0.03650010665296577, 0.011393010481697274, 0.060252312978263944, 0.10830330997123383, 0.011488188138173427, 0.07660103961825371, 0.0671721350227017, 0.05456481230794452, 0.020424074755283073, 0.04800459420948755, 0.08190942156943493, 0.032656839248375036, 0.039304430392803624, 0.07406719159916975, 0.040926965593826026, 0.05286123829137068, 0.05536370830668602, 0.0562756593717495, 0.03644878714112565, 0.084503487451002, 0.0211531606328208, 0.03607984326663427, 0.09266409135307185, 0.048735479795141146, 0.010500066746317316, 0.04902070199023001, 0.09800231506233104, 0.02236089279904263, 0.05061208925326355, 0.08061188025749288, 0.07513073374866508, 0.0654045470582787, 0.08264257441624068, 0.06352199299726635, 0.03034148692677263, 0.033502141741337255, 0.03409536635444965, 0.0653920863987878, 0.03174382320139557, 0.031186128908302635, 0.04504571079451125, 0.06844140792964026, 0.06808364079915918, 0.049162066279677674, 0.05250373462331481, 0.028136478977103252, 0.04794228349055629, 0.058646695033530705, 0.06832677579950541, 0.027177136216778308, 0.01246653358975891, 0.03554802395228762, 0.04367835936136544, 0.0035007187079827418, 0.035771447510342114, 0.0718077972123865, 0.004079730497323908, 0.015118684586923337, 0.040592709701741114, 0.0665174049208872, 0.040812678562360816, 0.037103554350323975, 0.034317966128583066, 0.09412840066943318, 0.042974847892764956, 0.0042096286051673815, 0.03774890741624404, 0.047847336827544495, 0.02206939574534772, 0.04912132237222977, 0.06545178475789726, 0.020773030737473164, 0.06158934767881874, 0.0323985681461636, 0.07898927084170282, 0.025924621004378423, 0.02534143022785429, 0.11552480020327494, 0.01442691946067498, 0.020595687128661666, 0.029021764676144812, 0.05173416459001601, 0.03866696264594793, 0.037608407728839666, 0.008258602647401858, 0.0301325463806279, 0.06821846676757559, 0.0038288291534627206, 0.03109515459073009, 0.08582265494624153, 0.04859454966208432, 0.07757415107334964, 0.06025190479704179, 0.05702240836399142, 0.013022576604271308, 0.02361465296417009, 0.02504538009816315, 0.11504469002829865, 0.30493696220219135, 0.14848921884549782, 0.1255090910126455, 0.15123936580494046, 0.17013604869134724, 0.1462888697278686, 0.11196324092452414, 0.08998323130072095, 0.16034039697842672, 0.20609356375643983, 0.14299410511739552, 0.13971994252642617, 0.09070776781300083, 0.13905867410358042, 0.23621295928023756, 0.13965727557661012, 0.13635454030008987, 0.16039587993873283, 0.1438960520317778, 0.17382961377734318, 0.14303890115115792, 0.09948890365194529, 0.13484608061844483, 0.12233848028699867, 0.11929879183298908, 0.09037898897076957, 0.1545883368817158, 0.046263979602372274, 0.11967324244324118, 0.15743821364594623, 0.13699332164833322, 0.09387703525135294, 0.15923685306916013, 0.14846585603663698, 0.25030610617250204, 0.11631647881586105, 0.20424196467502043, 0.19192951207514852, 0.1674350319080986, 0.18141155771445483, 0.09486789145739749, 0.09687194251455367, 0.12957785627804697, 0.16377277061110362, 0.2121083441306837, 0.16494496318046004, 0.08613375583081506, 0.23375680670142174, 0.1921574107836932, 0.11216192127903923, 0.13715784094529226, 0.16265598678728566, 0.1268931370577775, 0.11653239926090464, 0.20558010146487504, 0.11261892839684151, 0.12342934089247137, 0.08910377888241783, 0.18643726303707808, 0.09805119290831499, 0.07558161814813502, 0.23063189000822604, 0.16697362385457382, 0.10707996858400293, 0.1367631074390374, 0.17114112444687635, 0.1865803639520891, 0.15961049473844469, 0.09895751849398948, 0.1126079965615645, 0.21697478456189856, 0.1469115910003893, 0.13457837310852483, 0.13500712666427717, 0.15928418724797666, 0.12518313975306228, 0.1424160017631948, 0.14945976989110932, 0.14728702866705135, 0.16224130435148254, 0.18047526420559734, 0.1873554481426254, 0.11520802931045182, 0.13539331062929705, 0.14934908598661423, 0.15891443443251774, 0.17621377803152427, 0.08706427543074824, 0.16614915715763345, 0.10630724442307837, 0.12035763618769124, 0.22626089252298698, 0.12489140150137246, 0.14227695297449827, 0.1637138589285314, 0.18444291927153245, 0.18222515936940908, 0.20949038851540536, 0.12532303459011018, 0.17456098546972498, 0.18524562619859353, 0.20544405095279217, 0.11193267928319983, 0.14001607429236174, 0.23602500295965, 0.19775597989792004, 0.25725329120177776, 0.2159556228434667, 0.13857687183190137, 0.16748310823459178, 0.13752333383308724, 0.14436639554332942, 0.15951699897414073, 0.12015225423965603, 0.12748357490636408, 0.17208191537065431, 0.1181440768414177, 0.10706666187616065, 0.15807102812686935, 0.2402655011974275, 0.19742152362596244, 0.1431081583723426, 0.1721489758347161, 0.19500264170346782, 0.11457096232334152, 0.18155762722017244, 0.1964159877388738, 0.12264828241313808, 0.07647782826097682, 0.07988038982148282, 0.1445095706731081, 0.11661039156024344, 0.17390451132087037, 0.14427150454139337, 0.2088152419310063, 0.21243217284791172, 0.27041032270062715, 0.16738821723265573, 0.09793728066142648, 0.13221488508861512, 0.12736696866340935, 0.12722009763820097, 0.17532046971609816, 0.11667541853967123, 0.18529742810642347, 0.08890598910511471, 0.08816313638817519, 0.11680685289320536, 0.13882342813303694, 0.09457322914386168, 0.11420913564506918, 0.13702214666409418, 0.19407280487939715, 0.10462950085639022, 0.14983796834712848, 0.17051341594196856, 0.11926637482247315, 0.23148004605900496, 0.06794131913920864, 0.15652933507226408, 0.13783733651507646, 0.10288097866578028, 0.09999961257562973, 0.18824869708623737, 0.14586142235202715, 0.10300136244040914, 0.1488323582452722, 0.13057408563327044, 0.17477766290539876, 0.11106423291494139, 0.1087868117610924, 0.11011880356818438, 0.13608331501018256, 0.14737473567947745, 0.06879981330712326], [0.04163571662502363, 0.06945786080905236, 0.025226606994692702, 0.05975509629934095, 0.0712451824801974, 0.05614519723167177, 0.030085338366916403, 0.03191580850398168, 0.008881986286723986, 0.05333584173058625, 0.04224224423523992, 0.014718126149091404, 0.05999120316118933, 0.028406735764292534, 0.019361721897439566, 0.032453190215164796, 0.010830553455889458, 0.018138786836061627, 0.061198477051220834, 0.012743170063913567, 0.03192797230440192, 0.04474911889701616, 0.02290103344421368, 0.005205992010814953, 0.039680354166193865, 0.04098058205272537, 0.0049771716476243455, 0.06728131236741319, 0.014275022240326507, 0.030138062393234577, 0.017131297245214228, 0.052895369663019665, 0.06016737417667173, 0.04377364370157011, 0.19602466811193153, 0.004989194439986022, 0.039048155667842366, 0.0207488107480458, 0.023115580916055478, 0.06619281179155223, 0.0212111242217361, 0.02831405265169451, 0.00656501654702879, 0.027231231360929087, 0.06152042813482694, 0.059929523267783225, 0.049853228410938755, 0.019684123835759237, 0.0023349287857854506, 0.018740915365924593, 0.045762766458210535, 0.03414138322114013, 0.04360509825346526, 0.029473771573975682, 0.029473671384039335, 0.00783356539614033, 0.05060752133431379, 0.03751385440409649, 0.029236093214422, 0.049656522169243544, 0.017165564058814198, 0.04840772882744204, 0.04707534739281982, 0.02099956946040038, 0.06246451419428922, 0.03004854454047745, 0.0963661540299654, 0.03386951968423091, 0.11355322552844882, 0.04897815095318947, 0.0208126168945455, 0.06315399165032431, 0.05724262955482118, 0.02688314183615148, 0.05014499634853564, 0.07590832639834844, 0.05567480176978279, 0.014017019238963258, 0.03861744284222368, 0.013329617941053584, 0.037186144254519604, 0.01942849477927666, 0.052203005252522416, 0.03973567385401111, 0.017819310814957134, 0.08173900219844654, 0.0178654631235986, 0.025603393514757045, 0.08755131726502441, 0.028053892783646006, 0.029536486763390712, 0.057602953384048305, 0.0365491663251305, 0.023955695796757936, 0.05653555206663441, 0.02689578617719235, 0.02449402745696716, 0.046192922673071735, 0.009005219908431172, 0.025072568678297102, 0.012305284381000092, 0.007633068171344348, 0.01938352990691783, 0.03557154632289894, 0.018525748200772796, 0.054241072648437694, 0.011000475587934488, 0.015592914169246797, 0.03771302457607817, 0.024421838752459735, 0.07340924799791537, 0.11068969324696809, 0.036556621198542416, 0.007914952093415195, 0.03864000413159374, 0.012014155618089717, 0.01639759891986614, 0.01856573511759052, 0.02498465015378315, 0.03992005302279722, 0.014206424602889456, 0.022454657591879368, 0.04336418969614897, 0.0305741001284332, 0.014777068445255281, 0.07039880016236566, 0.043099977701785974, 0.05403471106546931, 0.007090841627359623, 0.044741010933648795, 0.07740189117612317, 0.05290096545650158, 0.04554996674414724, 0.04456391965504736, 0.044508614810183644, 0.014097167477302719, 0.04765654921357054, 0.02175484387407778, 0.039627609730814584, 0.029216314978839364, 0.006906137768964982, 0.03951645456254482, 0.07175198770710267, 0.06922757238498889, 0.00699332249496365, 0.02573249195847893, 0.010420778471598169, 0.05367760815715883, 0.02018272647546837, 0.044088982249377295, 0.058271747184335254, 0.04501910108956508, 0.054459917155327275, 0.09646921607782133, 0.010665386635082541, 0.016884568394743837, 0.03160083360853605, 0.014269289149524411, 0.05588400206761435, 0.013994732544233557, 0.019304871530039236, 0.02689530563657172, 0.04512538405833766, 0.09900758377625607, 0.03995438106358051, 0.03807018685620278, 0.014698861850774847, 0.0331142248614924, 0.029796130838803947, 0.010038196705863811, 0.00894099815923255, 0.023670968985243235, 0.05550617468543351, 0.031640315864933655, 0.03913210370228626, 0.030927820698707364, 0.0269475417007925, 0.017125189369835425, 0.07118687935872003, 0.048818518698681146, 0.03114349252427928, 0.024852612805261742, 0.03287740553787444, 0.015129279672692064, 0.05801796607556753, 0.04997612064471468, 0.08519950322806835, 0.03251511872804258, 0.05692750622984022, 0.04130138651817106, 0.011896884225279791, 0.0663945720589254, 0.012937544106534915, 0.044903288944624364, 0.05858131553395651, 0.0084600382251665, 0.030336301169882063, 0.05866921550477855, 0.01444856234229519, 0.050287908015889116, 0.0602061773679452, 0.012835362431360409, 0.04155942384386435, 0.04230842154356651, 0.035207266846555285, 0.02744335200986825, 0.016425210524175782, 0.002858117618416145, 0.06974432981223799, 0.1184959735837765, 0.10064650559797883, 0.03749014278582763, 0.033719802522682585, 0.05699152759916615, 0.04676317039411515, 0.02123699177900562, 0.058470509175094776, 0.03654345920949709, 0.09357800168800168, 0.03223108025849797, 0.036566213457263075, 0.024973764702735934, 0.04318240433349274, 0.021102800346852746, 0.0479164975695312, 0.055329766182694584, 0.014978051312937168, 0.06918250175658613, 0.08149676519678906, 0.07200317500974052, 0.014625429121224442, 0.049993828288279474, 0.03931150306016207, 0.0315809032326797, 0.027503517922013998, 0.029880750516895205, 0.047030113491928205, 0.040022551038418896, 0.037400075743789785, 0.08012597390916198, 0.031283546923077665, 0.026577328753774054, 0.12610757374204695, 0.011327878673910163, 0.040643216561875306, 0.05717326843296178, 0.026157443862757646, 0.0598821445601061, 0.06263174233026803, 0.06788047787267715, 0.038746650752727874, 0.018229134038847405, 0.06406579428585246, 0.07941381642012857, 0.05812143259390723, 0.03359078385983594, 0.052945093557354994, 0.06526920158648863, 0.018069323668896686, 0.06800605668104254, 0.039175077763502486, 0.04255604653735645, 0.040576493775006384, 0.03181336614943575, 0.011498894546093652, 0.11668955645291135, 0.03549516448401846, 0.06978589750360698, 0.06385812652297318, 0.0357446485577384, 0.08124001178657636, 0.05858172742591705, 0.06018933061568532, 0.004425412216733093, 0.031566961988573894, 0.0565973469929304, 0.04794570850208402, 0.026539182363194413, 0.005513009227797738, 0.08701181301148608, 0.028945431076863315, 0.057224884803872555, 0.018290951229573693, 0.03252282222092617, 0.044607858508243226, 0.021546508178289514, 0.02038505448581418, 0.1354355685180053, 0.016442035012005363, 0.02617360783915501, 0.024376384062634315, 0.01355196074655396, 0.05410747864516452, 0.03660837115603499, 0.023886802227934822, 0.051393555913819, 0.04364859552879352, 0.03833619484794326, 0.015107342715054983, 0.045753344893455505, 0.05278711629216559, 0.04746648148284294, 0.03414852268178947, 0.019700141237990465, 0.037322443386074156, 0.05294891932862811, 0.019229769895900972, 0.046637079503852874, 0.03790774557273835, 0.048368643620051444, 0.042375938428449444, 0.04779787268489599, 0.08625932721770369, 0.02166291218600236, 0.013462608949339483, 0.004786442477779929, 0.04696847070590593, 0.048677273152861744, 0.054645008785882965, 0.04066349945787806, 0.030835772122372873, 0.03685856027004775, 0.02086383250571089, 0.07924206860479899, 0.005571781757680583, 0.042763280143844895, 0.08977258010418154, 0.05038001596403774, 0.008381842762901215, 0.05641550225846004, 0.04676940443459898, 0.05664341209921986, 0.019346455919730943, 0.021827071541338228, 0.02246495489089284, 0.022797615165472962, 0.013520699631044408, 0.035119556123390794, 0.06594283418962732, 0.06211132982571144, 0.015275284240487963, 0.05276614690956194, 0.022919010116311256, 0.0529399578954326, 0.024164230017049704, 0.010504946367291268, 0.04746766891912557, 0.05937185494985897, 0.048139004575205036, 0.05384822790801991, 0.069215905823512, 0.010638975454639876, 0.15686514205299318, 0.15153049549553543, 0.1529956582817249, 0.13250233372673392, 0.10534963643294759, 0.09479458210989833, 0.07763963076286018, 0.09710125872516073, 0.13670869317138568, 0.22829887457191944, 0.2419839144567959, 0.06606263166759163, 0.09631755077862181, 0.19118585041724145, 0.09823784304899164, 0.1360547126387246, 0.09095609784708358, 0.11446263844845816, 0.274834621232003, 0.16364175186026841, 0.1069532023393549, 0.1331836252938956, 0.10507268176297657, 0.11396335117751732, 0.195910629699938, 0.1085857862199191, 0.1222580463218037, 0.12413481905241497, 0.12160175770986825, 0.13735222426475957, 0.07706790245720185, 0.09383287004311569, 0.15131294232560322, 0.18601005314849317, 0.2714661316713318, 0.17307051544776186, 0.1931153898476623, 0.06378000805852935, 0.20923755364492536, 0.15404627221869305, 0.18387686839560047, 0.14517094299662858, 0.19306683854665607, 0.2059513979475014, 0.12031778285745531, 0.12244042911333963, 0.14793876791372895, 0.0801615821546875, 0.11918521355255507, 0.07389824168058112, 0.15379230928374454, 0.17191102844662964, 0.19573652185499668, 0.21035902784205973, 0.11289693691651337, 0.12883165647508577, 0.20750183350173756, 0.1376873187837191, 0.09008408916997723, 0.19824262097245082, 0.13677670358447358, 0.11645397651591338, 0.14711726980749518, 0.1432452182052657, 0.0978129412396811, 0.10532060361583717, 0.24838297889800742, 0.08256717963377014, 0.22136602783575654, 0.21091283328132704, 0.08723203791305423, 0.19320569437695667, 0.13014855299843475, 0.14562248048605397, 0.1277334411861375, 0.13293277937918901, 0.17714073532260954, 0.15202314796624705, 0.2782856079284102, 0.13074535847408697, 0.194963293033652, 0.21777611109428108, 0.09854337040451355, 0.1441158910165541, 0.24239068559836596, 0.115388497360982, 0.09653148226789199, 0.13743486983003095, 0.16307660640450194, 0.27224488207139075, 0.09697461122414097, 0.22527839289978147, 0.10830731756868772, 0.152235847490374, 0.23679750447627157, 0.10705484688514844, 0.15820707863895223, 0.10699387203203514, 0.15123247867450118, 0.08776434333412908, 0.18448762624757364, 0.07158317879657261, 0.11410540566430427, 0.12865400116425008, 0.09877978896838613, 0.1676500914618373, 0.22567143430933356, 0.13255551602924243, 0.16022444382542744, 0.11447634591604583, 0.14675464160973206, 0.20653854066040367, 0.18307954946067184, 0.18229566339869052, 0.08825645403703675, 0.13721583236474544, 0.11612763191806152, 0.10208800129476003, 0.09261467916076072, 0.1262169366236776, 0.10617774707498029, 0.15377666481072083, 0.1963250746484846, 0.1829989967518486, 0.10814746638061479, 0.1833084278041497, 0.12263281605555676, 0.10043768008472398, 0.0903815939091146, 0.15213081875117496, 0.13940311968326569, 0.14990556315751746, 0.1442986077745445, 0.1981931197224185, 0.07789221330313012, 0.12735715747112408, 0.18091185484081507, 0.10961393534671515, 0.05931581908953376, 0.1318248567986302, 0.13103828416205943, 0.09477341605816036, 0.18699541746173054, 0.14985027315560728, 0.09707595148938708, 0.12050375022226945, 0.09204294343362562, 0.14458178164204583, 0.1278098823968321, 0.10839529917575419, 0.08097741025267169, 0.20752504788106307, 0.14624824456404895, 0.17671900248387828, 0.07055799826048315, 0.16742523555876687, 0.07730722281849012, 0.14068531338125467, 0.09344889025669545, 0.12222064950037748, 0.09354749199701473, 0.08434431161731482, 0.2593878860352561, 0.21116557909408584, 0.11444891613791697, 0.11328320251777768, 0.12825738260289654, 0.12588384590344504, 0.07888054620707408, 0.07680006878217682, 0.1049726179917343, 0.12042693051625974, 0.16928931756410748, 0.11468915676232427, 0.10204475634964183, 0.10018319764640182], [0.009716028544062283, 0.03730055374035146, 0.03362110430316534, 0.03292789013357833, 0.04763376527989749, 0.037876126370974816, 0.03285235434304923, 0.06527248187921941, 0.021056128534837626, 0.0484860402502818, 0.050354270861134864, 0.016035644221119583, 0.03143302659736946, 0.015653299014957156, 0.020643334864871576, 0.07377705638646148, 0.031486379593843594, 0.04516786088061053, 0.04380839105579071, 0.03590022126445547, 0.04656615245039575, 0.03543565908330493, 0.04499859183852095, 0.006268824017752195, 0.04703752012574114, 0.0599774660076946, 0.06824896903708577, 0.02066319102596026, 0.013485421641235007, 0.030001371778780594, 0.09340799791971222, 0.03203879350621719, 0.034340994970989414, 0.04731642664410174, 0.05296199597069062, 0.021214719927229453, 0.021466306134243496, 0.010786418861243874, 0.05075709748780355, 0.03932888044801075, 0.016941886315180454, 0.05867443651368376, 0.05640871160721872, 0.029473055401467718, 0.047358962838188745, 0.04077093646628782, 0.0754982081707567, 0.029071902317809872, 0.017191160732181743, 0.05885078193387017, 0.04113072594918776, 0.031578999623889104, 0.008561654012737563, 0.051843007968273014, 0.02846197567123454, 0.04930824339680839, 0.01150744687038241, 0.04536368025583215, 0.04003717505838722, 0.048547657061135396, 0.06740171098499559, 0.03836740957922302, 0.032370637418353, 0.04983217368135229, 0.011540221039467724, 0.025639350569690578, 0.02719904441619292, 0.03162450811942108, 0.034557646431494504, 0.06032235687598586, 0.06799361086450517, 0.12191178990178742, 0.01573972582264105, 0.07415304324240424, 0.021454016168718226, 0.05609762556559872, 0.01664010309468722, 0.07992503742570989, 0.07030747146927752, 0.0216136595554417, 0.07512524927733466, 0.04513155130553059, 0.047203479189192876, 0.03125011317024473, 0.05394420986704063, 0.05022760851716157, 0.027007141725334805, 0.0311211575899506, 0.0699486727535259, 0.03622651762270834, 0.049198019623872824, 0.07605850740219466, 0.034163695891038515, 0.018761539649858605, 0.06322700413875282, 0.043067078295280226, 0.004151825041844859, 0.08460483513772488, 0.040313803183380514, 0.04263239497959148, 0.016579846269451082, 0.0032584582822892116, 0.016388982585340273, 0.04507817604462616, 0.05983790884783957, 0.05633430017041974, 0.095432717789663, 0.0446186419139849, 0.025246670957130846, 0.10547234312980436, 0.05563384263950866, 0.0457133097370388, 0.06931270414497703, 0.006065080360713182, 0.04626123365596868, 0.018381270601821598, 0.060554367082659155, 0.026870131987379864, 0.05297430820064619, 0.0762581525486894, 0.06431779052945785, 0.046593218576163054, 0.030396519032365177, 0.04631047886505257, 0.06924852321390063, 0.0457876284053782, 0.005850919269505539, 0.018743305081443395, 0.011633331814664416, 0.06366075234836899, 0.022302426405076403, 0.04493636646657251, 0.013487495016306639, 0.026039312506327406, 0.06545108713908121, 0.09240856248652562, 0.06522741125081666, 0.03274989714554977, 0.08562430855818093, 0.035000656644115224, 0.03425668699492235, 0.018129545242118184, 0.010758049338619458, 0.04039673076476902, 0.10039408633019775, 0.03275660244980827, 0.021908375674684066, 0.04262373040546663, 0.01645370157348225, 0.04802684379683342, 0.03194598051777575, 0.007850211768527515, 0.061220544812385924, 0.04892119482974522, 0.026452573729329742, 0.03865207887429278, 0.07910195854492486, 0.06320839849649929, 0.047937236886355095, 0.01998991094296798, 0.15179890062427148, 0.03236395066778641, 0.05190826501348056, 0.046471521200146526, 0.015154885622905567, 0.00108144762180018, 0.033702773944241926, 0.04933741351123899, 0.004220718146825675, 0.07405227443086915, 0.07530867849709466, 0.07777615624945611, 0.07693627514527179, 0.0291808514521108, 0.00945400031923782, 0.016309966122207697, 0.013048949749645544, 0.018868169572670013, 0.046214096146286465, 0.03095017047598958, 0.028364106801745947, 0.06209968552866485, 0.053122715471545234, 0.04197659247438423, 0.056490581628168, 0.055231639416888356, 0.045263939318829216, 0.09077616414288059, 0.024127029864757787, 0.006722125963278813, 0.01743419183185324, 0.0523969952337211, 0.08315867875353433, 0.055477516652899794, 0.010839238439075416, 0.039478931576013565, 0.050954108010046184, 0.03543980768881738, 0.045329637941904366, 0.04886250208073761, 0.03454407626122702, 0.0247713977296371, 0.07951394698466174, 0.06329768628347665, 0.021648388355970383, 0.04650123308238108, 0.05347417063603643, 0.03322692740766797, 0.02288032010255847, 0.025909475625667255, 0.06269159654038958, 0.04655371776607353, 0.03186050365911797, 0.05121702495671343, 0.02864034344383981, 0.06259647547267377, 0.022134511782496702, 0.020786318891623523, 0.035420968270045705, 0.028414468943083193, 0.009699509264464723, 0.029415789431368466, 0.07318929026951082, 0.018862124779843725, 0.03092050683335401, 0.04096000971912872, 0.03533988492563367, 0.05817165372718591, 0.03958596040320117, 0.019353849565959536, 0.01397930607708986, 0.03568129883205984, 0.02628864072903525, 0.04729693042463623, 0.041141906403936446, 0.06276381493080407, 0.02373058014200069, 0.06620676416787319, 0.05243500061624218, 0.02191283227148233, 0.018686545627133455, 0.06122128696006257, 0.013407860715233255, 0.0682093457726296, 0.010310091784049291, 0.05851470777997747, 0.013662546316481894, 0.09992825507652014, 0.02572732475528028, 0.07014143819105811, 0.06633190510910936, 0.07613822148414329, 0.05282016412820667, 0.09888699220027775, 0.009910455464705592, 0.05387927565607242, 0.037870307933189906, 0.047719783906359226, 0.02380694157182006, 0.016294920933432877, 0.07047072169370949, 0.03342550386150833, 0.023230322512972634, 0.0437447630247334, 0.023694869851169642, 0.06038637824531179, 0.019201763097953517, 0.08794311186647974, 0.019708944964804687, 0.021606698210234754, 0.07154871345846914, 0.10070927644846961, 0.06468348379712552, 0.02087135231704451, 0.049204769456991926, 0.051813908357871696, 0.02279944827023428, 0.024292189264087938, 0.0181577153125545, 0.028611609341169242, 0.02495798107702285, 0.10028054515714757, 0.08377181889954954, 0.030977141977928113, 0.049875596741912887, 0.04284409631509334, 0.04601098145940341, 0.005335839559847955, 0.035525718703866005, 0.043482065011630766, 0.032518625375814736, 0.03258159660617821, 0.014767160773772048, 0.041449649070273153, 0.04331809119321406, 0.009615524122636998, 0.04376926131953951, 0.01278556988836499, 0.01779689238901483, 0.007922990480437875, 0.042578578140819445, 0.13508720439858735, 0.051558182822191156, 0.035393048674450256, 0.014746411252417602, 0.09633448658860289, 0.03531085581926163, 0.05435046521597542, 0.01135057354986202, 0.00876888483617222, 0.03329765037051402, 0.05869862681720406, 0.100475433137035, 0.038554100538021885, 0.023053574477671646, 0.035266839040559717, 0.029612835205625743, 0.03853286769299302, 0.03338121619890444, 0.08495131420204416, 0.011743357063096482, 0.006760093310731463, 0.034092946953023784, 0.01637818062590668, 0.044992090624873526, 0.0633763094083406, 0.06292775535257533, 0.08323983260197565, 0.03948565914470237, 0.03690902631205972, 0.02999613407155266, 0.01453920825952082, 0.027189146021555644, 0.02758771828666795, 0.03749267722014338, 0.03978209519118536, 0.03380868954991456, 0.014719793198310072, 0.034869741793954745, 0.03675444808322936, 0.014623528295487631, 0.015406273305416107, 0.034772761646308936, 0.05605614322121255, 0.06461482771555893, 0.045752231671940535, 0.05061960720922798, 0.029547312842623796, 0.022835659510747064, 0.0774949490732979, 0.07447736177709885, 0.030715197244717274, 0.12427234643837437, 0.08045443362789229, 0.0696512422291562, 0.12255854191607796, 0.12224668404087424, 0.16296955902362242, 0.13352125795790926, 0.16301094117807224, 0.12069064527167939, 0.17776161606889218, 0.18637959816260263, 0.15806219656951725, 0.14700055966386572, 0.1466514979256317, 0.1706232241122052, 0.15677121584303677, 0.14583384414436296, 0.2599224401637912, 0.15887934569036588, 0.09993571366067044, 0.20378872024593875, 0.10187495296122506, 0.13505389681085944, 0.10792027271236293, 0.10972899050102569, 0.14735940290847793, 0.24507411348167807, 0.10214071604423225, 0.16357611631974578, 0.17094209528295323, 0.15428128070198, 0.09236372192390263, 0.15930649620713666, 0.1250350070768036, 0.16560707765165716, 0.20008133637020364, 0.17069764668121934, 0.1460455937194638, 0.08049511816352606, 0.12365002592559904, 0.1552273557172157, 0.22523926687426865, 0.17546738527016714, 0.12508762534707785, 0.15946825471473858, 0.1673097425373271, 0.15408985113026574, 0.13444785901810974, 0.11112413165392354, 0.10090354844578542, 0.20075295033166185, 0.14974122197600082, 0.2009758321219124, 0.13503281981684268, 0.12530534178949893, 0.12071902499883436, 0.2034801203990355, 0.16249402047833428, 0.1143260981189087, 0.18904521450167522, 0.1731916784774512, 0.27002779010217637, 0.16663269605487585, 0.14385637681698427, 0.22334189212415367, 0.1546781515935436, 0.2302968845469877, 0.16533021203940734, 0.2011684194440022, 0.24789578863419592, 0.19383037491934374, 0.19697982701472938, 0.1466909356531687, 0.20977886131731793, 0.1454067975282669, 0.20187345973681659, 0.11496310573420487, 0.21374516567448154, 0.20102479902561754, 0.12317392334807664, 0.21345602493965998, 0.15062593622133136, 0.15240474545862526, 0.1080044025729876, 0.17123252735473216, 0.20665652729803696, 0.1121282203530427, 0.13823797751683742, 0.09739055531099439, 0.1922658088733442, 0.10773108442663215, 0.1205104666587431, 0.1549430686281994, 0.14208877400960773, 0.16443840286228806, 0.21285457361955196, 0.1884299740777351, 0.12186677864519879, 0.1317161915358156, 0.18214836192782968, 0.062443919596262276, 0.13727645098697394, 0.07864170082029887, 0.0964478199603036, 0.12431936149368994, 0.3143697482300922, 0.31499428034294397, 0.1689411315601319, 0.08726354208192788, 0.14062785630812868, 0.13950774766271934, 0.2734945103293285, 0.1322565641021356, 0.13166808552341536, 0.12928691954584792, 0.08194051755708642, 0.14190481044352055, 0.13828670693328604, 0.1323119134758599, 0.22482571250293404, 0.15602402156218886, 0.20160487649263814, 0.0717114812869113, 0.18007996666710824, 0.09448279844946228, 0.3857263270765543, 0.20855330833001062, 0.13415848079603165, 0.12244828103575855, 0.20942589588230476, 0.07779972685966641, 0.15389727865112945, 0.16188262437935919, 0.10773611618787982, 0.15758150751935318, 0.19742351258173585, 0.21789356338558719, 0.17123899888247252, 0.17965033737709746, 0.09711142614833079, 0.16717544349376112, 0.13648505439050496, 0.09963540360331535, 0.18507010827306658, 0.1971245458116755, 0.09745803879923187, 0.07678433525143191, 0.13413413835223764, 0.14688862895127386, 0.2339015106554143, 0.28009790286887437, 0.16062989394413307, 0.18026263889623806, 0.13855638855602592, 0.10632645120494999, 0.15165493881795555, 0.22466341964900494, 0.1573666260810569, 0.1562633048160933, 0.15745939454063773, 0.20743110682815313, 0.2805756381712854, 0.28492987796198577, 0.17109827284002677, 0.1067675169906579, 0.09024474929901771, 0.0992740667425096, 0.22748901334125549, 0.1895033274195157, 0.21173706249101087, 0.20828647655434906, 0.13398928596870974, 0.17111431807279587, 0.15331022499594837, 0.14500741817755625, 0.12665250309510157], [0.04963175299053546, 0.07674071923247539, 0.02482022548065288, 0.03413578371691983, 0.03697029060276691, 0.07309108186746016, 0.057254733983427286, 0.013048820801486727, 0.045183987749624066, 0.046331503908731975, 0.013963905585114844, 0.07584300255984999, 0.029615041239594575, 0.05357825313694775, 0.014162745501380414, 0.010708765166782541, 0.02955459145596251, 0.01582905442774063, 0.008456929554085946, 0.020552790992951486, 0.05115774220030289, 0.051130917272530496, 0.02946369135315763, 0.046634830796392635, 0.03357166613568552, 0.036054921947652474, 0.041394385043531656, 0.05919551695114933, 0.08742090707528405, 0.040717728188610636, 0.011847830119222635, 0.04432120767887682, 0.015185117008513771, 0.018512422939238604, 0.01936661450599786, 0.07798338614520617, 0.05815884425828699, 0.04790946943103336, 0.03319566443678923, 0.021389519824879244, 0.029764005121251103, 0.0317848491249606, 0.057400599398533814, 0.037896906505920924, 0.03522330465784762, 0.021866260649403557, 0.052357479580678046, 0.018942979913845193, 0.02150202384655131, 0.0566635873838095, 0.037140298081794754, 0.039544515166198835, 0.021215259839664213, 0.06735968316206709, 0.05552422000619117, 0.09004401319543831, 0.018907158300862648, 0.025544016134517733, 0.12607152020791546, 0.021468840568559244, 0.051703268982237205, 0.0660862987569999, 0.0073242721191491, 0.036085654282942414, 0.027072103766840883, 0.0059091741513839224, 0.026304079256078694, 0.030968586870585568, 0.06341519794659689, 0.09787244664039463, 0.04791803381522186, 0.017669406261120457, 0.0460118905903073, 0.019739328490686603, 0.0358723721728893, 0.04714594419056084, 0.037745449008070864, 0.008864218343660468, 0.0545016963587841, 0.0683332844346296, 0.033544451580382884, 0.08761301942286082, 0.03136406994599383, 0.03933345949917566, 0.040785434321151115, 0.01779423178959405, 0.05716409177694004, 0.016853086490300484, 0.018623505748109892, 0.02775844379357295, 0.015652677466277964, 0.07529404334491119, 0.07166244758991525, 0.02628621947224019, 0.02240989309939323, 0.02889648087148089, 0.028357715054880828, 0.0809707235021051, 0.039768510177964345, 0.04540747439023107, 0.07280041230842471, 0.06529639387736097, 0.03711261226271745, 0.06410849004168995, 0.029480347002390772, 0.05783052554761525, 0.06605192989809439, 0.03351338156790007, 0.0061649131384911016, 0.04075473167176824, 0.0014433470073527133, 0.043873640679521486, 0.023898570834717248, 0.026779161380545702, 0.021077940255054273, 0.07710925492574461, 0.1087681764329318, 0.05360279596061446, 0.046142371284076944, 0.12587525183334947, 0.030799577580182813, 0.02440436674078228, 0.013336250885913614, 0.0735124881612137, 0.047733576720929705, 0.035934623520006426, 0.025685892505862284, 0.03625015502620954, 0.012370173135423101, 0.025360256659041625, 0.027504343561304267, 0.06497034613857977, 0.09613723857910372, 0.04071196170116309, 0.05936440378718544, 0.02739315685175825, 0.02283273915963946, 0.05841868871357292, 0.037957684689899907, 0.0392507211654447, 0.04069491085829213, 0.07737464693491347, 0.010753015722002601, 0.05562222060689237, 0.008675319495523581, 0.06835019798018038, 0.016481227830809075, 0.042261799826519564, 0.05591367313172668, 0.01907918442157097, 0.03189012277289294, 0.015321036717068637, 0.005018879883209593, 0.06537373308674432, 0.01056012319168076, 0.06812660372816026, 0.04709618318884168, 0.04557847263640724, 0.03270946122938767, 0.02437742306938162, 0.0249236437593936, 0.02753495158685837, 0.036086285108467564, 0.015720949486421887, 0.05132162325026002, 0.04565442774037365, 0.03865339247568045, 0.03286689301603474, 0.06100238679209724, 0.041977453365689144, 0.10593421873636544, 0.063439696241403, 0.046162557700881734, 0.07596444760565646, 0.0915804815304, 0.0787876961112488, 0.04305734873923939, 0.030512822850141674, 0.050647693788050674, 0.029006817821937148, 0.00972829902821104, 0.028380237381497864, 0.052049057849217206, 0.0502761598181678, 0.09066605169209652, 0.03875924870953895, 0.062351114029297605, 0.088974622922251, 0.04302246779843699, 0.0711372890509665, 0.045450890029314905, 0.038097950600786135, 0.02789981364912819, 0.06757724375347607, 0.030782090725551825, 0.00555941293896467, 0.06530533675686456, 0.04867279429163318, 0.030824938621663023, 0.07263759995112196, 0.0180846360308351, 0.08258200032287277, 0.027042473520850763, 0.02397947791905608, 0.03732475517608691, 0.054384956529247575, 0.03397491578652989, 0.02922043204307556, 0.03029989511560416, 0.0592487734684255, 0.05772009397333022, 0.014382369263330474, 0.0402152756578289, 0.02296060192747973, 0.058656806795625016, 0.02015258971368894, 0.007715594529145164, 0.05670669132086914, 0.020211703631503042, 0.01990416134503903, 0.013520548418455292, 0.01525767678685952, 0.05460056527226698, 0.08719890101929195, 0.03478627615550067, 0.02473904565704288, 0.018938916655315552, 0.015222805122903083, 0.04353333257313352, 0.01829970486141974, 0.028034246279275976, 0.05078887625131756, 0.027150700916536152, 0.005679240566678345, 0.05532281968044117, 0.08444114704616368, 0.045985236356500536, 0.0922295861528255, 0.041167484523612075, 0.09203074252582155, 0.03921562500181608, 0.024488683993695304, 0.024997326036100276, 0.014743444517080206, 0.02465630546794273, 0.058183635701425374, 0.018770194947137497, 0.016568491409998387, 0.04288493670173921, 0.0566894809162477, 0.07887258296250366, 0.04640825682145078, 0.038660320424241945, 0.03268901135015767, 0.021578986415988766, 0.037491330222110264, 0.011517568837007275, 0.0459543704346288, 0.024381326766160782, 0.07885730956331827, 0.04588692405377515, 0.01708498351945309, 0.05887044513656292, 0.04824698706215713, 0.01877073671494145, 0.02032154705375433, 0.08359304294572212, 0.001458448784887878, 0.05639580194838345, 0.0039256583204405615, 0.06661487117526121, 0.04137177180382423, 0.008089109105640091, 0.053837529849261045, 0.07992468861630186, 0.05866735642484855, 0.026894025431829505, 0.017582626933290157, 0.034554481171653606, 0.037708475210820325, 0.04237637258484028, 0.1071627477358561, 0.06901837579789571, 0.10764992315671407, 0.03185988767654635, 0.04610855903592892, 0.06163206198834814, 0.04767029749928042, 0.026285215717507526, 0.03982692462159321, 0.013997729893162614, 0.033456065502832644, 0.03217752688215114, 0.031073931022547185, 0.017886467758216895, 0.0918528571492061, 0.06474449575762264, 0.08936541562434286, 0.024731008197704796, 0.07834385469323024, 0.07250620270497166, 0.11289455462247133, 0.0625828570628073, 0.0523821671231417, 0.025374682154506445, 0.05093578809464816, 0.028513733050203882, 0.044295395782683045, 0.03211224015103653, 0.022804734217061196, 0.022090313177614007, 0.029700006016355474, 0.06859538872959092, 0.04865482318564318, 0.01874385055998573, 0.09394441483891569, 0.031060025030456018, 0.08486959632136859, 0.037830840519745834, 0.049269469891441986, 0.053787471988471225, 0.017227370117325336, 0.042142763049923815, 0.08823983735055663, 0.0764391029952094, 0.010480633609404322, 0.016111111362988595, 0.012545921126729809, 0.013533584242395591, 0.05555898591410369, 0.10291721773683093, 0.044267453922657296, 0.026308892083761748, 0.03914495770004578, 0.029849188831576612, 0.003184489119121281, 0.0320563638524618, 0.027517735616129357, 0.037295737201930024, 0.004999698148822063, 0.07287473839824088, 0.0687388310325332, 0.11520307918544859, 0.020356741551950108, 0.026651107509678695, 0.049575078883208334, 0.11899618111783639, 0.06478120238170959, 0.07034750291495584, 0.05181255022762343, 0.06432620648411103, 0.06943779313587584, 0.13508839183486998, 0.13227001181803644, 0.15822160989046097, 0.09302781050791964, 0.12168662971816957, 0.16325908567523584, 0.14848541904939339, 0.14647853298811242, 0.16329479782143608, 0.12494249094743282, 0.11128094745799899, 0.2861363725969568, 0.23856464715208858, 0.18793283903505653, 0.13581149600213394, 0.11643957885098644, 0.10084612848004326, 0.16595982044236735, 0.10446383865200914, 0.09509431329206564, 0.17105273465858772, 0.18219455319922417, 0.0724872037244495, 0.13783516944386065, 0.11461212183348835, 0.19344813917996362, 0.08575315281632356, 0.09077617898583412, 0.2320459485054016, 0.12556297093397006, 0.1452877273550257, 0.1465611340245232, 0.12074882964952849, 0.1803176468820311, 0.08641505948617123, 0.14169723173836246, 0.20700689521618187, 0.09509753421298228, 0.1132092771877069, 0.07153677972382866, 0.0916123716160655, 0.16953032260062173, 0.13767768570687622, 0.13243893947219476, 0.10246003992506303, 0.11089818479376845, 0.16263394500128925, 0.22195805388037115, 0.11253059055889025, 0.16417750826803967, 0.09139516725554131, 0.08499250339809805, 0.10577778142760508, 0.12626539886696264, 0.12518532166723162, 0.28530754207167774, 0.18837573792552575, 0.0909542350564152, 0.2555902273161337, 0.17872538388473913, 0.10685320536140352, 0.1976312990882434, 0.06958921352634206, 0.18575347785372287, 0.08679286460392177, 0.12366419352474622, 0.17822637862991542, 0.13825195957906544, 0.1670350885251537, 0.17067760869394988, 0.13157916138879955, 0.21827820368343964, 0.1737933375989087, 0.10469179673236795, 0.10795659341965802, 0.13342157268198207, 0.16250420274445787, 0.20732100179884583, 0.1655901418416761, 0.11759353685192764, 0.09326516417786479, 0.23535215703304857, 0.061402471183100715, 0.17668576911091805, 0.11092054570326582, 0.16332188621163368, 0.16611391998594627, 0.17640364909311756, 0.08603389986092225, 0.15759495523525402, 0.18391660298220813, 0.21375341835664585, 0.130467067938298, 0.1465416155406274, 0.13276273850351572, 0.19762366981012747, 0.08805461213341914, 0.20998977968702093, 0.16323735559126362, 0.11641836827038787, 0.09281591992476024, 0.13572640134952962, 0.09502433618763462, 0.1724493972142227, 0.2208627774962224, 0.2336602087598294, 0.22431265097111464, 0.20009052415844053, 0.14283565658843145, 0.11638460055110045, 0.1422739398549311, 0.14566460478818044, 0.13101725169690326, 0.181655902415514, 0.10384721041191369, 0.1431288049207069, 0.19201898539904505, 0.1436727397958748, 0.12824669567635283, 0.21244855946861207, 0.09839622478466481, 0.1906464426429011, 0.10424883104860783, 0.1744672967470251, 0.11081124219344929, 0.23706371284788474, 0.10831982275703922, 0.11556122481124476, 0.12562066549435258, 0.12966919981408864, 0.0781024934258312, 0.16027704725274816, 0.1162749927607365, 0.12061228931997903, 0.1606712760985829, 0.11578917547012679, 0.12108632872696035, 0.14021333714481443, 0.14022408344317228, 0.23051440803101286, 0.10922038185526617, 0.1889601198490709, 0.18918129469966516, 0.10322888265363872, 0.08032258367165923, 0.10091524469316937, 0.13048201479250565, 0.16214923351071775, 0.13558594248024747, 0.14334902982227504, 0.096073703316506, 0.12069477903423831, 0.11828757851617411, 0.21117525669978932, 0.1735642069252208, 0.15316362114390358, 0.06614971527596936, 0.10191122171818279, 0.16542170400498435, 0.10531911932048388, 0.11797870407463051, 0.14370120858075097, 0.16546893428312615, 0.12318997600232251, 0.16427248832769692, 0.21197875030338764, 0.27243412972893566, 0.08655747762531973, 0.17372978007188067, 0.13361695047933608, 0.22604492754908279, 0.14250219479436055, 0.15909312875010073, 0.17158366710646078, 0.19108790176687762, 0.21435850620036945], [0.12164739237050526, 0.03097615306614898, 0.06925984096596949, 0.039900894480524585, 0.013905143259762553, 0.014753683371964144, 0.08202658442314714, 0.0022683409770252183, 0.12963210727320984, 0.012632548314286396, 0.040785664386930875, 0.051261947155580856, 0.058147730596829206, 0.03692000638693571, 0.00566129497201473, 0.010118372774741147, 0.027447431966720615, 0.032491689125890844, 0.02531953501602402, 0.030592661241826136, 0.024126031676132698, 0.06557419459568337, 0.0069332456405390985, 0.023466381135222036, 0.025897929663187824, 0.019391572932363488, 0.014260226598707959, 0.037502039413084276, 0.04549914076051209, 0.06108049041358754, 0.013496147530531744, 0.011462647125881631, 0.0366129947360605, 0.031271898915292695, 0.03601147291192319, 0.0632030401902739, 0.0034794554812833667, 0.025414836054551415, 0.03367673198226839, 0.016575649424339645, 0.044485411563073285, 0.13233757694251835, 0.031033799386932515, 0.041882770165102556, 0.01736447633447824, 0.03402263959287666, 0.032499667213414796, 0.04237424262100831, 0.046494171547237784, 0.03706025003339164, 0.023313994097406976, 0.0643619557376951, 0.018918921341537498, 0.041564511266187765, 0.009090257044590544, 0.025698457066027913, 0.04766411169839557, 0.0546084839879768, 0.026347262974013574, 0.07522843006881885, 0.06773306507966481, 0.06983954735915177, 0.019148115097777918, 0.03856451286992524, 0.04329267634602729, 0.06660108949290588, 0.03155596336000599, 0.020299015450291336, 0.10840103597729467, 0.026788056020450313, 0.06825961885624565, 0.022606007478316315, 0.020953096172888763, 0.013817699709761655, 0.050628668832359836, 0.023229402249853592, 0.023378406949632335, 0.02177356454922119, 0.04086497770913411, 0.03769048926187679, 0.00553593973563693, 0.04288725591322873, 0.07055047288304195, 0.03702076035551727, 0.07287050815648399, 0.043069601597380824, 0.06340345717035234, 0.023280137320398353, 0.033004208889906295, 0.041651049396023154, 0.06407597655197605, 0.031176191550912336, 0.017611247858440038, 0.020378683148010168, 0.059680039194063284, 0.05723289628804196, 0.03056929101148853, 0.023589698248542845, 0.04762262193253264, 0.03283342215581797, 0.05514886026503518, 0.04805398413736839, 0.04665411921450868, 0.04088903071533423, 0.04148664142121561, 0.02653984287462663, 0.05456329832668416, 0.028033635862811934, 0.05889270585612394, 0.04580363653076347, 0.058577897943905555, 0.009566607313900022, 0.042872286794590764, 0.04137266238103621, 0.0086115532394615, 0.029743785307800863, 0.018549560008978005, 0.05051523898146115, 0.027975136072200257, 0.046373264558496885, 0.08432469665422104, 0.04485689729335718, 0.03425676863116678, 0.07384333017398603, 0.044134219861007296, 0.025569677745806985, 0.02567799234384438, 0.018122832516382914, 0.014722657888341928, 0.004102339098608354, 0.007841521219233982, 0.013217765153967775, 0.030949793836043682, 0.06275985928368755, 0.05231970797467511, 0.039409136297763325, 0.020183145788905676, 0.027239170485700015, 0.019445000143605284, 0.04245155585522298, 0.08689130307175219, 0.09831783172558062, 0.015155133314692648, 0.06301849774899893, 0.02784048450848786, 0.05939557027886622, 0.017980692682613153, 0.04013130906969309, 0.030226368689909577, 0.08664834618684836, 0.029422917759802658, 0.028491850825957954, 0.06515319648315199, 0.04782437106769066, 0.05463737579702865, 0.0628954719286412, 0.060490401374408975, 0.048757866679807194, 0.020194255739625078, 0.043576269526965916, 0.048435997232445516, 0.029553094173024874, 0.03138964435493108, 0.016953283848124556, 0.02245199884782778, 0.050387229639454745, 0.05057200956798624, 0.08410413036472164, 0.0444408121984452, 0.05972046026727185, 0.016383030560973566, 0.04652854040614329, 0.05092206207336858, 0.0547125701996265, 0.012440330210665707, 0.013923067981522763, 0.09571480070007965, 0.026747388183139265, 0.029956178696011193, 0.02455649959301809, 0.03174285840941593, 0.0986320422089193, 0.03578398609533906, 0.03070718390517868, 0.021054039389127865, 0.014199857523635728, 0.043461819223011844, 0.016962781483016443, 0.017592033655091655, 0.026605799394019414, 0.018243878657813184, 0.10073866549646482, 0.03485054614429828, 0.006107901817813399, 0.027418005811341573, 0.014729450394952437, 0.020398988308443222, 0.046458529905066825, 0.06423725266358815, 0.0838465457491111, 0.02820817786414409, 0.04641481369617395, 0.027919823805859778, 0.043331616834620945, 0.009948784609150607, 0.0027570027805268182, 0.014217225634638453, 0.05854596332937945, 0.016359482215193566, 0.08407863759202883, 0.026256110540998634, 0.037126460738363676, 0.039034923174767755, 0.042692508941399865, 0.019630739298008848, 0.008569307410652982, 0.02632692441693507, 0.018716355843935162, 0.02488193134922767, 0.018456500256434083, 0.04533641375019215, 0.027784257545135915, 0.01868098694103537, 0.037388680066214874, 0.03437755316554103, 0.029129411341273226, 0.026093337146448903, 0.01801130627427483, 0.045199743544799276, 0.05168336829228792, 0.017738867572916206, 0.03004214166139718, 0.019513186816766392, 0.009794594152481295, 0.024817811645334587, 0.025418483710382134, 0.03227467030228581, 0.05317272138199769, 0.0017647275649324001, 0.05293943468132056, 0.060865048653795384, 0.05259274781565182, 0.04248491539328825, 0.019163618562743068, 0.0086288823877112, 0.02638364861923037, 0.07586396823171526, 0.04206561679893639, 0.021312687131285202, 0.02076639222650556, 0.03228727568057366, 0.027894702107005287, 0.06314668149570934, 0.03214978911273647, 0.03485242006718181, 0.03777435566007625, 0.04015300946775824, 0.06799916955060326, 0.03506002845824696, 0.0437193555990234, 0.10609378790832125, 0.020116679042985197, 0.019549329408619087, 0.04623731423635036, 0.04062956475536339, 0.0759705480595585, 0.011686396301229252, 0.07109116457286291, 0.048768598135211505, 0.027650234951579478, 0.03927460347767919, 0.09268052250263281, 0.06327036040602252, 0.09254303964553401, 0.04246519281878136, 0.04935758508509025, 0.07353409208008088, 0.05379968031775206, 0.06145306339021772, 0.031250324682332575, 0.04827739656320773, 0.03352537838509306, 0.07139000517781824, 0.029720012462348677, 0.08890437122317962, 0.011393261884222738, 0.029748008128080983, 0.0550377756007947, 0.035096939172944985, 0.008173074766091304, 0.009968159301934065, 0.03429610987950582, 0.04660620244976599, 0.035045389595325105, 0.042218031667289324, 0.030078313939156942, 0.04858586282352917, 0.043672596584656276, 0.028638649491767865, 0.08491845190292224, 0.055734555789968, 0.03405907904380001, 0.05870598521141801, 0.05013970112486277, 0.07109391794074327, 0.021163094279472716, 0.02997754327225266, 0.052898445865139365, 0.003506207585814991, 0.020108070129936095, 0.07754969730740413, 0.03042211199499434, 0.060623965691775084, 0.04585739770845976, 0.029066178503853735, 0.050538100840640254, 0.019426854632911272, 0.12781604222254828, 0.053134181653149426, 0.06548377132276073, 0.027687186484399717, 0.027658010803861544, 0.03839208970020991, 0.040104636282194406, 0.03800734179094434, 0.05612912602373399, 0.04827538534300402, 0.03437990206293762, 0.013806808692606864, 0.028211166863911785, 0.05098085130157415, 0.009144736250163987, 0.009326723848062102, 0.03931329905753955, 0.014536148755723843, 0.03760403276828583, 0.020353733998490497, 0.024215393677877728, 0.01644531530473614, 0.031293139181798324, 0.007311767858482199, 0.027422974490036722, 0.02602080890937941, 0.02763099106232403, 0.03819176177785266, 0.01784722484444501, 0.057617031925474294, 0.051346993568586186, 0.09362631550175138, 0.03393291393877007, 0.030052188485569786, 0.024019292286538985, 0.24327514751348644, 0.1118459073768463, 0.21336775389499962, 0.10599941640975885, 0.09065258913324215, 0.1491087637259625, 0.17166656500194222, 0.0889388142968528, 0.2529447083361447, 0.09225586560205556, 0.10891684345551766, 0.13696857844479382, 0.2142700125114061, 0.2018951007630676, 0.21589819545624778, 0.19355901604285464, 0.1461431712959893, 0.1331497388309799, 0.09322317346232012, 0.10265185541356914, 0.21164951875107363, 0.1335729262791574, 0.19030808267416432, 0.13219086918979883, 0.07795621611876413, 0.10870035897823982, 0.1714342282502912, 0.09813225769903511, 0.15080525394296274, 0.15150784514844418, 0.1803417518385686, 0.15227435011183843, 0.1001913241634611, 0.14667604817077518, 0.1108713709982112, 0.17152013926533982, 0.14630910067353398, 0.18438330997014418, 0.10301689559128135, 0.1368159631965682, 0.09562704915879294, 0.2334987767972052, 0.1198112299607601, 0.1449619690538384, 0.1212824041431304, 0.15716485097073019, 0.15358811477199197, 0.14232445042580366, 0.11880563470185734, 0.13348741602385417, 0.17856494640000165, 0.1532046915963292, 0.10022193775512278, 0.18826910614734516, 0.09695987217128277, 0.1624742496642284, 0.1347284353687428, 0.13612739858217537, 0.19680616445839405, 0.15239673026371747, 0.12707759044133127, 0.2316908456850797, 0.13099280535243452, 0.08418590761721134, 0.11932480410905555, 0.10163024460780434, 0.15206035925075412, 0.12615334941074252, 0.14282940770499408, 0.10037251209723763, 0.22228997200727463, 0.1561247161589563, 0.13647757354192436, 0.07324630205403082, 0.12312789534917101, 0.2107627858640626, 0.12246244121342897, 0.09315005707321689, 0.16492341121193022, 0.09334713438875042, 0.10249093553284183, 0.17728941718814895, 0.18956108135171235, 0.20047132013132796, 0.12554196815472096, 0.0911312446987722, 0.20776033838046715, 0.17363119317451492, 0.11485809925943613, 0.13325193256605417, 0.11855924167321064, 0.18170323659433052, 0.1634859899058938, 0.06334829333354719, 0.17541435139719397, 0.1813119021244347, 0.17200906615471467, 0.07202594410046004, 0.1221491138858255, 0.11233891607844271, 0.20145007933024317, 0.20891755440970883, 0.11387194826966152, 0.14924269169569016, 0.10213742090854794, 0.1532439363654703, 0.19871548778610304, 0.14767818502150476, 0.1265506655909121, 0.17474517168011516, 0.09317102274508215, 0.25580536108464, 0.22501987317809835, 0.14726687193615362, 0.1861440108041279, 0.18104420945746824, 0.11858293844852597, 0.1417698137811385, 0.1209492985799443, 0.14586381206754595, 0.24696460110135376, 0.20697294938145205, 0.1251089249853976, 0.16615473810816184, 0.13720936083700508, 0.07724831855739467, 0.16420566535089165, 0.09364358527818695, 0.15616638032952324, 0.10883352253586054, 0.1385484921047464, 0.17077533470001072, 0.07894819296780042, 0.1905829444876872, 0.26249196322169155, 0.1491513184737414, 0.1782683693454601, 0.10031401601736434, 0.09156167550827377, 0.1209130891948007, 0.11721366856363602, 0.2787195862038061, 0.07839639874873683, 0.12483683880418539, 0.1326966131455265, 0.16660915513057262, 0.13831758027663454, 0.1496997062349692, 0.12587485107360408, 0.156130668183323, 0.12379319363390096, 0.0833890784997493, 0.16277281567454338, 0.09256498495233245, 0.15565723733743653, 0.10657920443918556, 0.15503742528380826, 0.11645916412817314, 0.11651603490463458, 0.20734252408146858, 0.12496858485974371, 0.0944895223074127, 0.09523244923911989, 0.10405415829154663, 0.12801729782950133, 0.11378657902241684, 0.08706160369911231, 0.13587091234512627, 0.10435143296490423, 0.10025963143561967, 0.23703623854089528, 0.13465098483720794, 0.29738964687567204, 0.10900259119807743, 0.07836793738533743, 0.12380393251078203], [0.01063467007043073, 0.04767646845721174, 0.05803426363854669, 0.040501306793885306, 0.050018938854918815, 0.06836832864792086, 0.06007037176459562, 0.012695397090283222, 0.026924737358058337, 0.03874412002915051, 0.04095851800229866, 0.07267015054821968, 0.0477170676458627, 0.04899284918792546, 0.03622148586146068, 0.04247057710017543, 0.02719772524869768, 0.052404390735318884, 0.01311628944677068, 0.0006021042361226137, 0.01752350559399929, 0.04359034435765352, 0.029292056715348735, 0.04120471807254944, 0.043992859282298014, 0.07179429012467153, 0.027873472972714808, 0.029523410121328197, 0.07398994886898436, 0.04932093412207905, 0.08294342624139972, 0.015463906638615299, 0.016018751084629912, 0.03307335849967785, 0.03138403742923401, 0.03371167229488492, 0.029617659165523946, 0.039155017511802725, 0.04239545320160687, 0.06522580079035833, 0.0016315550783474464, 0.03976170097303111, 0.06109799396654125, 0.03780832004849799, 0.03501473147480283, 0.022628349834121764, 0.045306753818294965, 0.013497561321855756, 0.08925007103243843, 0.08309305805596523, 0.033185055435751565, 0.026205757676507346, 0.028192782010592055, 0.09736943378811702, 0.03752191783860326, 0.022212010553630535, 0.021412344576674514, 0.05831314789247699, 0.04048338763823267, 0.02348429843550548, 0.03256163283367641, 0.007377562960755313, 0.048892915292526595, 0.04100558871868998, 0.04035974954604171, 0.020720993197755888, 0.023994478578970302, 0.01783681807864923, 0.01132478762883693, 0.02506331595213851, 0.014331519159895834, 0.053202299677650444, 0.05795205965114292, 0.03666278542368673, 0.042330333453719504, 0.08011779544176534, 0.035886057376046665, 0.05082251409476157, 0.03809160894888919, 0.05499876831891015, 0.012358911044429988, 0.0517946310719708, 0.02122061629052041, 0.046919704182073474, 0.017854998841357883, 0.05764763438492082, 0.013843458727933466, 0.08143918195855804, 0.02628868711326504, 0.1323071785736829, 0.07723468530457467, 0.04118957825994585, 0.05929196275246795, 0.012644223224924644, 0.04688040375185665, 0.07756621009320952, 0.028352742665447295, 0.0315469314227812, 0.041529166483087465, 0.01986443417990813, 0.04811358972801827, 0.07916541217127815, 0.05361342722608242, 0.027473492482386064, 0.07042005527182482, 0.03321438511193264, 0.013210744436946698, 0.023962041159393266, 0.052175185846863315, 0.02865138289052993, 0.016454664510092698, 0.04381973107228987, 0.038243122107815, 0.09594804287189618, 0.09945710262400098, 0.05839261335495394, 0.03743828521692194, 0.01362121796773863, 0.06352975586196408, 0.08294068029499613, 0.0715390729601495, 0.010470616471138783, 0.01337292875177809, 0.04327303911850322, 0.030981811942183413, 0.06501990676042624, 0.01357184381049592, 0.05322073462593835, 0.033351040474371985, 0.023958796118677128, 0.04338497354183346, 0.061407198663800955, 0.0742117025947664, 0.027752467649406753, 0.007195005764515372, 0.04100026380911004, 0.0072531395835540025, 0.019647858789539896, 0.009700566824903945, 0.03966899930674117, 0.020333362044766545, 0.02838142852851888, 0.05112745515361894, 0.03497534569760319, 0.03892012406140566, 0.0052716428581334185, 0.041065350160351954, 0.02063499683572445, 0.02778216468868777, 0.035943826151196845, 0.01127264247770654, 0.07941015021060593, 0.028868381305073854, 0.04723413730971515, 0.01233149796462385, 0.022243316198000684, 0.03137260093353689, 0.05885228849365376, 0.04582067624141928, 0.019443213423073757, 0.013656495957548032, 0.010952748998533934, 0.055596349338884465, 0.014089717242313782, 0.014508834010484861, 0.02360206428420497, 0.05949892176431604, 0.015913453316898085, 0.08244851022027433, 0.0867520019528456, 0.028843081490776967, 0.10327718162443489, 0.02637561487063067, 0.03768574693822302, 0.018728215363807976, 0.0381277478300035, 0.020800529164262116, 0.034064214705722407, 0.08416293814661913, 0.030351947498274967, 0.04226251599902753, 0.05644757788104471, 0.02111076915753074, 0.013704383964068256, 0.05375788998208009, 0.04091836410225369, 0.04211653555103112, 0.031959272382664494, 0.038448329651146196, 0.07358066184679046, 0.025768115046957973, 0.05263435632514302, 0.01756702327838866, 0.031094193509488832, 0.07227592912386172, 0.023120043078961316, 0.033584089687792584, 0.09757851163158193, 0.09079806492081843, 0.030760802219447214, 0.03676145766803529, 0.10506336038815789, 0.031166439730441198, 0.017232118007086683, 0.03335242086905055, 0.06267827498959377, 0.01853799734817585, 0.04848843367653899, 0.02243892591650365, 0.08621784116257913, 0.05663104049745016, 0.014521421762765385, 0.023375007913273294, 0.03495923367154319, 0.04661304505134467, 0.06271981299505569, 0.04671126458561048, 0.027243040785833728, 0.06582645801245235, 0.03659706453618128, 0.030754375220567454, 0.055855585233075544, 0.06430404595448636, 0.0340501844038954, 0.03801791739533655, 0.019171800740878098, 0.02662577429873636, 0.027405508044466842, 0.07319564305362292, 0.0684339864528738, 0.03579466931114439, 0.0339391702436842, 0.025306363750132732, 0.031434703851118684, 0.03208651360182557, 0.014252399723773124, 0.05584578888374381, 0.045183204783825204, 0.06362286570947617, 0.11275025884970091, 0.02938150220870739, 0.04560823646897916, 0.0530621042707935, 0.021435091402963735, 0.009105986864597071, 0.0439238543913234, 0.02076347744150553, 0.018548919906606898, 0.0432074443961028, 0.024786953144939616, 0.0670085359888617, 0.05590779532212764, 0.031755567688378505, 0.04201886891678441, 0.03146850496705156, 0.11156898239278235, 0.031231596585712396, 0.006441308414650848, 0.048728663168731146, 0.048570147846476175, 0.009536990983178839, 0.07607021849253215, 0.09205930036841892, 0.02229814421298215, 0.04486656005610712, 0.0364307603740599, 0.08414391690166667, 0.05520145256014075, 0.02778468613541918, 0.052193925075698644, 0.05061844945885241, 0.028588239110831637, 0.025096829485846683, 0.04269081684469711, 0.023465108351956587, 0.013810821856168332, 0.08492347624269314, 0.07443323367624544, 0.07141377616790123, 0.041522015890222974, 0.028799599058402237, 0.07331661312491633, 0.018682760673982557, 0.01617634428839665, 0.0997414713492617, 0.03456710881437175, 0.026275690252077766, 0.03767752023122739, 0.05029642044974025, 0.05641598465444986, 0.062080515854177065, 0.020978472057322506, 0.03486404581053648, 0.08024998678592965, 0.020569519001583103, 0.036763034731848165, 0.05937586254731286, 0.029367646311584394, 0.04389525201986544, 0.025331112519779708, 0.044387166053638794, 0.04241962495143525, 0.056363169715041295, 0.047619979886803776, 0.057789640632108785, 0.02423733712930698, 0.032232156372629106, 0.08055065307416953, 0.06313529695034958, 0.030357025643752422, 0.015846615497139283, 0.05170122436538804, 0.05591175467998255, 0.012676796086452669, 0.032959672607830726, 0.021952540882921312, 0.00960511271841824, 0.02181115803978173, 0.0564564317028271, 0.038723929901607335, 0.033634180945227854, 0.06767103637685068, 0.04901373693428468, 0.02793430867313873, 0.03940775219234638, 0.024475406971760094, 0.017300356630585156, 0.015056204101711046, 0.010634276732162107, 0.017372020265611354, 0.06684767547994852, 0.03991194877016824, 0.02578760941105429, 0.10168013177462853, 0.013110504405631218, 0.00764952947065467, 0.030710078281117603, 0.036083806335227564, 0.019976446528744418, 0.013749590962106595, 0.060419700675993226, 0.0013265619531921402, 0.05445726026664488, 0.06133833478088491, 0.04533538216492161, 0.024648932230775245, 0.019018319035239983, 0.07471530174370855, 0.03997960295237135, 0.057345368768437766, 0.01821877551265061, 0.022352682790369727, 0.08587950345827267, 0.14211666391929612, 0.13223594723967835, 0.12916209030663595, 0.15079827775480226, 0.20313883636845276, 0.223552513634786, 0.10999172562151216, 0.14025218115421012, 0.11646224404103123, 0.13466910808347166, 0.09990762337110937, 0.19806701398920268, 0.13177814602386206, 0.08748858352191746, 0.14363543945364654, 0.10444907733472064, 0.10392236028565094, 0.16373086895328015, 0.11149016630952246, 0.09493628778727725, 0.14783307124162093, 0.19758348993491381, 0.13267480884678662, 0.19426830142037943, 0.3186413424555212, 0.14587317797122523, 0.0899925600970164, 0.2323040080955252, 0.10935513360891491, 0.1363665927783586, 0.11908750981092453, 0.12732485920423642, 0.20572041190462187, 0.09245135472156107, 0.1250606557005085, 0.09210771066136658, 0.09008325054310262, 0.19078964745858684, 0.14149613940389827, 0.12282392650377005, 0.08836143824737519, 0.20830111170653254, 0.2386137773282826, 0.12095606696675532, 0.11564984466531314, 0.13634921167977154, 0.14135686797089875, 0.2467012871056795, 0.2488806631299667, 0.143749448179733, 0.11820418338174932, 0.23376833967631683, 0.14706344925798476, 0.13698463852051646, 0.12938387371832505, 0.10335619808756746, 0.11453423343482427, 0.1297565209097229, 0.11996377099421807, 0.1796609946177341, 0.15529581141890958, 0.13944606034783646, 0.19195314205717295, 0.13258045219117776, 0.16724106419133022, 0.12982729211216792, 0.08963332351413555, 0.06969770809519105, 0.13441404676996171, 0.14025017735548317, 0.14257589005865157, 0.13481336674885824, 0.1299680329975672, 0.14532164350384846, 0.16004898527171463, 0.09853778945398517, 0.11214618774829432, 0.17852127843070775, 0.2679957007057965, 0.20656675711506978, 0.13104230660246685, 0.08438530043349601, 0.1383874609018676, 0.09698840774944983, 0.19300985644804314, 0.2181623989599757, 0.1174385096237529, 0.11841891639051028, 0.2165823517134413, 0.1377999916439876, 0.186606012575794, 0.17150289175333455, 0.14150875591440126, 0.14429768751142547, 0.22953315521590412, 0.12115996461943723, 0.19394877715967596, 0.12704034947091714, 0.09970817118301056, 0.21373061958001927, 0.2580188907450065, 0.1793317630654201, 0.12116038022213615, 0.1418993333936669, 0.1741860673064366, 0.17231800738954917, 0.09503220295300707, 0.09536519719404168, 0.10021963709732518, 0.17003939137794077, 0.12772927031619474, 0.13962429453385994, 0.1740033653913997, 0.22301279415842146, 0.15133485052501783, 0.15775380452396348, 0.10285596828907728, 0.12316151463892311, 0.1539647250319831, 0.1798096764832735, 0.249834218993783, 0.08081005595158786, 0.15568428119877353, 0.1698403770569712, 0.10907363699516281, 0.09825862318393774, 0.23644051660085097, 0.23467341845389456, 0.19093454437097535, 0.10305437404895201, 0.2280522440560162, 0.21408785978564993, 0.1569911587284878, 0.047797727966099046, 0.08323912756168284, 0.18546193256042898, 0.11293227798887528, 0.0748450068931561, 0.11789835174567997, 0.0668312814377714, 0.06638167353230529, 0.18628099642228335, 0.16185048938496038, 0.1393012228072621, 0.19951035763369873, 0.11604925370193087, 0.09196840212098323, 0.1160866059944965, 0.12833710410632193, 0.0979331617418211, 0.15754264866700396, 0.10932394856354222, 0.16046442469814792, 0.11496642313431948, 0.11163787596160546, 0.2185243889107369, 0.14423485728912055, 0.21381798520451412, 0.08582043592468835, 0.06258677560254, 0.12896478292532265, 0.23215952678583562, 0.1489568460965529, 0.13522580789867789, 0.07026574050541967, 0.12963942484930158, 0.1695287344045937, 0.19506251817801967, 0.11175987019669265, 0.09749451535753906, 0.21105341089423746, 0.22571526555111632, 0.22594635549467057, 0.11749962548492476, 0.0837015820434317], [0.062273559597088024, 0.033858372626127675, 0.019371662965568248, 0.02622533924295567, 0.021403065875347238, 0.02862204022676451, 0.02449699790304294, 0.05345750570995733, 0.03844079314148985, 0.029442723825923167, 0.022258543212956283, 0.02916626453952631, 0.047396775262313895, 0.09116980669205077, 0.0302057369844988, 0.028097317699575797, 0.03338364673254546, 0.005913058366786572, 0.053981847886461765, 0.06162916761240922, 0.005408088563854108, 0.005657997053276631, 0.03875384958519135, 0.023628672133781947, 0.021331175885279663, 0.04876803781371564, 0.025245216347684618, 0.03219504527805839, 0.034530758421169594, 0.0171252172003733, 0.05143973234225996, 0.07173972742748447, 0.04293662728741765, 0.027388702110329177, 0.03391124322661199, 0.04875524318777025, 0.03777091951633338, 0.03610735097026918, 0.02508416844648309, 0.038763623670092784, 0.07473672012565657, 0.014845958303340012, 0.0957698532147333, 0.040806396282278, 0.021630983137583826, 0.0510335808939999, 0.0496493827085942, 0.021824897048645653, 0.023224915967148263, 0.0446510440815473, 0.05490126866789069, 0.027344241898390464, 0.04458928255189676, 0.02158361741749104, 0.01416975323081715, 0.039485770466853864, 0.03472839976893738, 0.04924305685563013, 0.010268806108797435, 0.09656592534156516, 0.03162310546031222, 0.02198524547566194, 0.08416357639362104, 0.04917800019029528, 0.05844767329108436, 0.07243442218168639, 0.07384764947346412, 0.030835232209938113, 0.04202840180369094, 0.09284648898756132, 0.07228672737255692, 0.04573231613903772, 0.04710124834673479, 0.07818263053195551, 0.05229099428106565, 0.01899714185128687, 0.045673519489355385, 0.035680244982359, 0.006335352454698295, 0.05545282539969776, 0.04848971017054282, 0.047902834630804136, 0.03320087431347929, 0.04982265192666091, 0.05186612957913894, 0.06813136089476757, 0.01181418856504024, 0.017134969020844437, 0.07287971078767441, 0.03858507036056835, 0.0597229056438664, 0.08406525666941889, 0.045933478977531195, 0.03145958064123988, 0.04321928907302208, 0.07898787560407072, 0.008226240370277083, 0.031617661807104014, 0.012882033315690933, 0.02905747311160667, 0.04008095806057099, 0.0143654547900951, 0.03860749435261823, 0.048183266262640245, 0.05846323983860202, 0.021240403802949004, 0.04284993701730855, 0.016387069699703716, 0.04298936801205855, 0.01114745793529437, 0.009515660731267417, 0.042666426161304116, 0.02390343746810686, 0.04995838702598121, 0.011261202271271031, 0.040458306757500395, 0.023075996614352334, 0.01670816731348168, 0.04669893751270138, 0.06452082729083486, 0.08912762408726849, 0.04255185711372178, 0.010643413497746224, 0.062284498853841797, 0.043689866361091845, 0.0201041515902034, 0.026753249294415582, 0.009165328992821742, 0.039314805617323145, 0.02784528063784819, 0.05525087588466704, 0.02731512373429723, 0.09029908935190178, 0.017509543940832373, 0.050399245010339655, 0.028658412884396967, 0.08556181972380728, 0.04248552766512148, 0.010862168019230012, 0.03822646089247428, 0.07813122938387096, 0.07720101406448521, 0.04888332303380594, 0.03564971673768014, 0.04850198900385294, 0.042975812684744596, 0.06895887781865895, 0.005453361891341046, 0.055514011764898896, 0.025451435067225248, 0.05300347460433841, 0.010267721645504935, 0.0040784707016428, 0.05898376366531011, 0.016821701065055095, 0.04371522183646448, 0.01689069853455294, 0.030067059269640595, 0.04796906760020647, 0.017191268343594857, 0.0506412704999093, 0.0163752992375521, 0.05944067430391442, 0.11401669675251469, 0.016816661882330664, 0.026000073303293902, 0.06070815863495227, 0.03253867820603773, 0.05427636919193901, 0.01909842831082642, 0.06272512677242048, 0.03853846719721332, 0.04814180618268438, 0.08798733644653112, 0.0431237412703922, 0.05012090623495169, 0.020000289878225885, 0.006547427647092263, 0.06766991573385894, 0.10388757582404651, 0.010096060104842763, 0.039472044445574284, 0.043726702861022204, 0.08423157196375541, 0.01664107716351282, 0.030512446210195776, 0.03510884693241678, 0.030044692794035655, 0.0153410301754775, 0.03690614306833595, 0.0632365704223048, 0.05421087465947494, 0.006904160409249016, 0.020580777381837834, 0.026881069388764445, 0.02426435316010611, 0.0142866210808279, 0.02938664343673736, 0.043477727158460766, 0.027989303671347443, 0.011690691480907844, 0.06203258795721922, 0.012325888255872997, 0.08471352266496979, 0.054694343052688055, 0.021129595588718075, 0.04926793364575133, 0.06774534762371331, 0.03266102125053294, 0.018749891642073635, 0.01590158080944093, 0.09726603035232984, 0.021131523317308165, 0.04036646969325375, 0.024196044032578357, 0.03424079761316534, 0.03154281621391419, 0.013514496204152238, 0.039161006643553264, 0.026822558465937618, 0.00976550289124134, 0.06583073278306983, 0.015625678133801557, 0.07142195463529788, 0.02155587779270718, 0.0170579136829474, 0.013119408322381787, 0.05978962843073532, 0.03528273955453187, 0.0707805906131398, 0.04387396351376083, 0.07238875041366555, 0.06150980800157413, 0.0465679781336803, 0.020781183229701128, 0.0698978133732453, 0.018321397838008124, 0.04236514389049262, 0.003967000120610464, 0.05049572420830373, 0.06696629294310696, 0.07533926240284927, 0.04960003730957396, 0.020885150697722565, 0.07686326265684329, 0.058460556974750943, 0.019460312505543698, 0.054966158349998295, 0.03831256857665721, 0.020384946874401066, 0.020447626811801456, 0.07150759105570614, 0.039607460421393625, 0.053362926410045475, 0.07564176921732724, 0.06378090605721809, 0.030544545952579938, 0.03554826515028253, 0.023219865652208682, 0.01821774392738007, 0.01430333702955977, 0.056699191918596625, 0.015354780316556571, 0.04332106720539741, 0.03740594984265044, 0.06149021901364904, 0.04300288994272705, 0.043975956868962385, 0.0333956324175233, 0.037337727917474695, 0.04679395839048084, 0.006752261797373649, 0.050950137519976124, 0.03185259236488491, 0.005859202565261512, 0.05754372257797513, 0.03318908158689737, 0.04802479917998426, 0.06768257677322254, 0.007454489350493532, 0.008767223353061127, 0.124276457936503, 0.030300318139779847, 0.01070948690539808, 0.007701352251388016, 0.04660943821363617, 0.050033499792334624, 0.0836333267216105, 0.03574884540284984, 0.030578326659451704, 0.045428454905049875, 0.03745351408724673, 0.035875314788427204, 0.01570392276335042, 0.08743307829718105, 0.07421951740980148, 0.04918447542877402, 0.04928180067508947, 0.057429164662607946, 0.06114576230174862, 0.027918894265894778, 0.032509901429875754, 0.03257929965911899, 0.08321842164150439, 0.025418817676836625, 0.02349027829041006, 0.046037049396545626, 0.018207929024356417, 0.02232567418104736, 0.02384556850302033, 0.04952512121235486, 0.021318436920410022, 0.03294502261269372, 0.019801552007265855, 0.05947641984676011, 0.04622820437361952, 0.047051457659108564, 0.03378003522811923, 0.03698557513416745, 0.025248296260542702, 0.042961077342624776, 0.10791478824103251, 0.004159475192864193, 0.017790185229387134, 0.09415146661922336, 0.05004194172215648, 0.02197484613134293, 0.10956294980132952, 0.0038044034499762347, 0.05309980166202877, 0.028933098437846638, 0.07966993900481611, 0.04237766392179765, 0.032691690503270365, 0.04626072899554856, 0.05701737660274375, 0.04777806476340629, 0.01637049197597662, 0.06860012363176793, 0.05585517705185339, 0.10653331002686173, 0.03345497083500959, 0.04343924309068825, 0.05108668156026397, 0.04745851823827252, 0.017124768201028928, 0.051238959131296724, 0.05895265283470508, 0.09032470086822286, 0.05784521265013609, 0.021272741032589693, 0.028920186923642177, 0.17655290983384475, 0.1372697568149306, 0.11649182604742236, 0.1652769703650847, 0.13977028982480988, 0.15042692190036178, 0.13603373954538256, 0.2924745809286833, 0.11586607681238092, 0.12374723242828622, 0.11582510283915326, 0.09100220006075688, 0.06595881262910552, 0.08722345868591219, 0.19143788376823068, 0.1516936789266765, 0.09988529956899583, 0.10349434145609848, 0.05741911969380453, 0.13155913824448362, 0.15603320935042575, 0.10672447242541239, 0.15282107546227053, 0.12114909957745112, 0.1695008741808124, 0.14151353534543887, 0.09051208573509939, 0.15584048844175413, 0.15558766841422766, 0.048852256732061505, 0.20554931717924774, 0.33107246446888894, 0.1447187821031548, 0.13536000304156914, 0.1348847761983052, 0.1552848276332952, 0.13428691687295213, 0.10782000856124796, 0.10644435620633885, 0.2117773165809922, 0.1094074104912579, 0.11663425160804763, 0.1823302177945152, 0.16939820547122508, 0.09442760492675006, 0.15343204111559317, 0.1572371509973891, 0.1291348089580424, 0.17200697329826653, 0.16512858535861596, 0.1399794121971354, 0.1526098750764504, 0.20654787687817588, 0.1428732686326839, 0.07506128356908448, 0.1841662169317715, 0.16090187622467056, 0.13516355655156076, 0.06098166973970365, 0.166808525682427, 0.09181774614262395, 0.15302859479561448, 0.11559208331163973, 0.07928107588668354, 0.13554727658629417, 0.1573190395720303, 0.11622109057498164, 0.13911501795519143, 0.18515414907597005, 0.18369729834375903, 0.17371130059473217, 0.11179647292010486, 0.17742471070960164, 0.17758263973519206, 0.13740021153353155, 0.1393470133189112, 0.13923273741966113, 0.13886693282984197, 0.08155421484843828, 0.1889284746721387, 0.07310977656743489, 0.10549755388638005, 0.13867925852537155, 0.1568231513374485, 0.10363581706769764, 0.14948448340874165, 0.0719727692194283, 0.17822789261117578, 0.17814009654102847, 0.14865212026052177, 0.1819110379437916, 0.16805140039650723, 0.13829378702212125, 0.159424957819283, 0.16211690555792302, 0.11772671525250189, 0.09039990269229747, 0.13329653564142063, 0.091808306024177, 0.17924693558597937, 0.11339176387991756, 0.08162097103195265, 0.20094074337976053, 0.1506004063412547, 0.14928894233889878, 0.1817401361768134, 0.11480293542263098, 0.11029250323190354, 0.136196180828847, 0.0841441321244929, 0.12049647717503831, 0.20535346440738067, 0.15016270248452201, 0.1503391852020286, 0.1575154860620387, 0.12631264398805797, 0.08003231487236917, 0.16657103842590004, 0.14296979235950857, 0.17398792871972546, 0.18970534001709893, 0.15438820933923125, 0.15304250264307484, 0.1371974271023646, 0.18740294559393078, 0.08862424758262932, 0.21116201678523794, 0.13220228342106566, 0.2073021957767196, 0.10657380902557634, 0.24485985544743016, 0.18823360180249438, 0.14172069844789803, 0.050288731799810193, 0.13553240394685417, 0.10803342796862125, 0.16063388669863343, 0.09921443517669104, 0.09414200423634611, 0.24963710457086563, 0.25100788101553917, 0.1262716922792606, 0.13283104577567428, 0.1633506963844411, 0.15576873760437593, 0.23879005224443972, 0.19633366871858016, 0.15222474496113136, 0.14234653674066067, 0.08550044411094859, 0.07844411142286845, 0.261932858848013, 0.1029856140667107, 0.12489303422626108, 0.12781855068169534, 0.18539481272455305, 0.1271398417884484, 0.15369185217423365, 0.13119723735144362, 0.1383017873740755, 0.12685867171967402, 0.1192546117817983, 0.1734039475559257, 0.1654879777925089, 0.19279825530247763, 0.18964400893310085, 0.1363826380111277, 0.12097930361051112, 0.21317549311788753, 0.13412129919743165, 0.12538461800431833, 0.10435726624564268, 0.2039842019439675, 0.1472048432333395, 0.15611315349815413, 0.10512991619179957], [0.04927240879624151, 0.04720223609183449, 0.013150200957170455, 0.048622168687870726, 0.13473401631927118, 0.043728194577852264, 0.06765525831724517, 0.022918195609236136, 0.016192074108403176, 0.03992667298007291, 0.039402742695529014, 0.036857914601569064, 0.027566181161091663, 0.01597572507307632, 0.03726991046278272, 0.03190307324985042, 0.03325977857457474, 0.058121714610024355, 0.041508419744786806, 0.0501428589632269, 0.10832628686330281, 0.026864747705985792, 0.011372043882147409, 0.03961618807807099, 0.021735316113336012, 0.038706463456037454, 0.02936894878075691, 0.05054401575762313, 0.04489046463277191, 0.01944740470207762, 0.07087554840836674, 0.019314691999170464, 0.007204069706858718, 0.048655287027941085, 0.05303969141095877, 0.0676415508496575, 0.05710752528102603, 0.0605904317490058, 0.014960930893721525, 0.029603313450934365, 0.024345661004190333, 0.062287422915687785, 0.07242574647534639, 0.01886549227492651, 0.07316951945540495, 0.08517741691321135, 0.04339940831414424, 0.040268439406645484, 0.04608488823578227, 0.0414572523732204, 0.030635934017482214, 0.03146530631056521, 0.00903451433259761, 0.027780274067481514, 0.0745053259015549, 0.03332227854116354, 0.01688595992163755, 0.02090366542688571, 0.046230553271016106, 0.02850795914127957, 0.04704606966697611, 0.08058295876253396, 0.024209339608205482, 0.05925848447077442, 0.03150853641272988, 0.04217936577333603, 0.02412330428342102, 0.023687858410994522, 0.031445973363588564, 0.014751757498743245, 0.07092927990015596, 0.02254086546599865, 0.06489523337222636, 0.04940711231029127, 0.06909278352395631, 0.04211156316159759, 0.06768253224436194, 0.03164917339745443, 0.019001351683982648, 0.013125877067068359, 0.07655863330001011, 0.011360778080415912, 0.02237461510958383, 0.09279808611609042, 0.03831573383649811, 0.03551943642378319, 0.08129980662488379, 0.03352912994159851, 0.03885980971972458, 0.07632854525581934, 0.01634933149034623, 0.09052761146449484, 0.020905029123241547, 0.011904601633432321, 0.04304073205275927, 0.04413384507643059, 0.09632192202843726, 0.02380310837907018, 0.058961302565876395, 0.07039770920528099, 0.0106018550832232, 0.033869400940602645, 0.01704609312582761, 0.03406550604267977, 0.03194256663846318, 0.015299465267162304, 0.06583624694030732, 0.11203738147742115, 0.02362075527344132, 0.03285129307187162, 0.025250736071029678, 0.008964451881183777, 0.0615338944044197, 0.039403043265338056, 0.04539764835499227, 0.05100470021716319, 0.06721319805365056, 0.05382687631936278, 0.04510460392339155, 0.03503374529827852, 0.017954140494111925, 0.02685103096155217, 0.05437079264083877, 0.04209214857837651, 0.034025678687612526, 0.042776694463100284, 0.051154740212950855, 0.07058242234052159, 0.05042799952207133, 0.014469707984972047, 0.028224842790223192, 0.04557000102067832, 0.058488179711275734, 0.018211864262411837, 0.06842775983386673, 0.02993921320012305, 0.0762010294420179, 0.01691405392193701, 0.03049744183954317, 0.014657733881904278, 0.06588823438505642, 0.05283589765895158, 0.0403459196240874, 0.054562118311878294, 0.014446671721088933, 0.049751071783248335, 0.11260497602052055, 0.02381064488872653, 0.029203225349192508, 0.03223344770958647, 0.046723573104827665, 0.04074267177202273, 0.028826297821069602, 0.020070166792720556, 0.030549336515832692, 0.011783373665821273, 0.0230279555398738, 0.05961963950539939, 0.012246154692547861, 0.04544652620097622, 0.0823257293086499, 0.09421094975550659, 0.009557118028169498, 0.0155844369874103, 0.07116859283996746, 0.038750944077037275, 0.0339468069432769, 0.02287763352796901, 0.04059863575093914, 0.027478861920826603, 0.024181080480047967, 0.03906272402673494, 0.016614022169960663, 0.08023124755709432, 0.03822411199507769, 0.023404387684422545, 0.0331429311336251, 0.033023408250301145, 0.024367739897570573, 0.033234575239475816, 0.0077943837095517665, 0.04137403164349962, 0.0100989071688673, 0.07312125759199262, 0.019063996369368397, 0.028632773537538014, 0.05224997948971577, 0.02127611038304167, 0.04751239815959707, 0.03708886724780314, 0.04359448554168921, 0.023077191472111735, 0.051301596395205706, 0.04552212136331946, 0.01078113476978615, 0.048016969521995634, 0.045400420276564546, 0.010837512945727212, 0.02428073978080647, 0.002683423476810276, 0.06828163837781176, 0.0665350903000217, 0.02762837499176385, 0.03947034492739476, 0.055381211859639734, 0.009054606125573628, 0.034491695478209294, 0.009871122565527912, 0.043687847719411366, 0.04936316232488025, 0.022658323323412333, 0.023814533742552157, 0.027701203798642382, 0.05620466923573986, 0.05122683243826032, 0.043872479218407534, 0.027569246230996214, 0.08305062205181457, 0.07606863771798089, 0.05334040593879763, 0.02732461394771235, 0.044460085773607716, 0.022471489501185715, 0.07212346972664818, 0.012250199397385586, 0.05849812077940442, 0.11271882147411816, 0.026480313354113605, 0.05682380222424399, 0.04420082019350957, 0.01602252490556566, 0.07021414639893919, 0.012798455427400768, 0.029104694112902507, 0.05177423314307816, 0.0683109977398999, 0.03345210243423935, 0.04541965674434323, 0.01893930628284579, 0.0407364822603995, 0.04230936407111585, 0.0452137256070273, 0.044727641143254004, 0.010463292401254876, 0.04506801604293287, 0.01636005923501216, 0.05414455634308979, 0.05009023327147588, 0.02141663047950715, 0.01631843959330581, 0.002458571516399388, 0.03678427128761541, 0.06796269299229607, 0.030669666484754998, 0.05872231617104262, 0.040509292302886024, 0.06661393606918864, 0.024312455461767968, 0.06424431048799306, 0.026667688944144174, 0.012502386744017713, 0.09520409177639522, 0.020900873096252326, 0.04402168058732059, 0.005200591494940454, 0.044778778828913346, 0.025992384653363843, 0.016221212681557517, 0.027334590267855674, 0.03145552480418701, 0.03714547827257775, 0.1191900300909765, 0.04642933010472916, 0.01749967152136378, 0.0743380977655761, 0.02756474324996816, 0.0382739509223029, 0.059416454314487055, 0.042980725702364, 0.04388314759125933, 0.01962401544005843, 0.03460139974777121, 0.06309925825917162, 0.09207224342389964, 0.056445199297741055, 0.013498160606104648, 0.03599254443543032, 0.05276809875795152, 0.01648927642236231, 0.059158238873351365, 0.025188145191350486, 0.0382103006268153, 0.046290993777802214, 0.024676315624674316, 0.04004625523521099, 0.0576396488759201, 0.05749262942117639, 0.023236474917212036, 0.07185842652688734, 0.05301466990204062, 0.04045221001433674, 0.05511371586180758, 0.06166160688735545, 0.11290201320662163, 0.02046017467364436, 0.061560570902656764, 0.029620282657560892, 0.02974431037728209, 0.020269973356334958, 0.07274835064890794, 0.03882716264342889, 0.08400201084441505, 0.04715313931228593, 0.04748182538605761, 0.04672355826187413, 0.04558376414934173, 0.07334615060244687, 0.05723995782318525, 0.025083843756874558, 0.017911129325511865, 0.04758663519169204, 0.04955168267770205, 0.04163929377682507, 0.047564838314428926, 0.0385418588120956, 0.04336144746048376, 0.05100490801851265, 0.06534874497447163, 0.04564130285871215, 0.06729460423230194, 0.035650046993396245, 0.021373296476667747, 0.02830156601703493, 0.07084867524099536, 0.03240336613089312, 0.04092492468771525, 0.05617268638161477, 0.09059540665475652, 0.00830320479508373, 0.059422821941552684, 0.03214338808902539, 0.03777928723138757, 0.0269766004930716, 0.014846784870314877, 0.021705266553908587, 0.025279284636781085, 0.021204890181252267, 0.058690852820291184, 0.04993720613128971, 0.03110736477538012, 0.06545194060890935, 0.04364358232123777, 0.1516895674285479, 0.1309735540417023, 0.1118721126113087, 0.19551684614270926, 0.14862466079648584, 0.16892484884010628, 0.16897075809538364, 0.18766554712783545, 0.13027264008997008, 0.24467439274303615, 0.16001180367311463, 0.1211538196366746, 0.10615123755997047, 0.08240335795562714, 0.10313012506230734, 0.12099592029699124, 0.13711865554796532, 0.14640281908214092, 0.11364010875695385, 0.15029829286504537, 0.12158198689576238, 0.15305480745155364, 0.22331582789774984, 0.17942218633834273, 0.1357838584226556, 0.1583110386854969, 0.15400773991132155, 0.14789184933761135, 0.12466975167626515, 0.10410148504888639, 0.12318093664362095, 0.11569986541871913, 0.09521677508018911, 0.16093570331577212, 0.11533495882758871, 0.17308426002273336, 0.1495991600677371, 0.1348412418155931, 0.07019572629360482, 0.1256382543942891, 0.10369565643486567, 0.19108389416942373, 0.15088876039953902, 0.09503690074780025, 0.13826381909893826, 0.1723452887381427, 0.15572701406199485, 0.16250297077931464, 0.1395756987039931, 0.18362361792242154, 0.19939530990086496, 0.08200057214708067, 0.1275304934824817, 0.11877556287799962, 0.13780379144009203, 0.07339951844187453, 0.1265572410193272, 0.0857096555409953, 0.147377006651368, 0.1326641664491035, 0.1149333975627087, 0.21690420631784946, 0.07727318050456233, 0.11459399858722463, 0.10787540246383287, 0.20590888772858307, 0.13107574777677655, 0.17062338738469407, 0.15251158503815532, 0.08372872980544344, 0.1467316795606166, 0.19407727260841057, 0.13961325137643144, 0.13480547029757872, 0.16195995616726577, 0.21822086535394192, 0.16484395688166842, 0.11200371765880845, 0.15231942816171795, 0.12553852458950132, 0.19131559267407283, 0.11348801301210187, 0.1698966763797216, 0.21904929511947557, 0.2619622478960082, 0.18009877268923447, 0.13404206751147285, 0.0943409072351642, 0.06416918287868612, 0.21214239386608824, 0.10632700039423071, 0.20190939452731982, 0.15073332499014214, 0.12864650547271594, 0.13166069373255596, 0.2057015019818209, 0.16411697870353237, 0.13665528822457418, 0.2393568749539554, 0.2788288303418085, 0.10983275016769767, 0.1441653328947723, 0.12119356164475903, 0.13439351896522567, 0.13962831697426736, 0.13854672579327598, 0.18239960860228166, 0.21944024367257953, 0.19592614058637992, 0.12959452491486445, 0.08912277044146322, 0.14673398021841422, 0.13248259259853512, 0.11050023036659695, 0.09356626091175713, 0.09170634977635927, 0.18470112729119137, 0.11289115558611229, 0.2144579539890401, 0.2168807841371745, 0.07748985051875934, 0.11782343935919926, 0.27066906506661326, 0.07236776989884675, 0.11141898692585528, 0.1555335510056466, 0.1399376441258937, 0.245969143579714, 0.11419441885664128, 0.11866394386743195, 0.09239404607797042, 0.11190585064468905, 0.1677661485155113, 0.13219889922766015, 0.14553162676747888, 0.21128856780705974, 0.09708795201731846, 0.11501205779495649, 0.21190397150348872, 0.18851978878956288, 0.16964143695076928, 0.24289215478347614, 0.09686025368864648, 0.15763991454150528, 0.15220304456306621, 0.08982378829387017, 0.24870717868907377, 0.13358699739910662, 0.16572678607190028, 0.1787759389844723, 0.13225576258264482, 0.12164005995145999, 0.12277992456802167, 0.14109177282080054, 0.1821282200398855, 0.12222508754348382, 0.11593954943236895, 0.20794787909835577, 0.2532121486729011, 0.1397124319919385, 0.190055322018452, 0.2705390111077577, 0.11305471009109169, 0.22385343967471272, 0.17853944620583206, 0.08123220439301804, 0.12620938156032935, 0.14961612556362525, 0.19115151866571978, 0.07119115412933752, 0.19570947799365968, 0.12390472358674742, 0.1619179209228605, 0.1967191995936446, 0.1255925084115006, 0.11760570807382464], [0.03329037732328288, 0.07649586244951934, 0.020533153765427414, 0.015206789576041047, 0.02698933760257205, 0.026861717888095882, 0.08467742460197769, 0.050041626309393905, 0.02852078716387041, 0.030839020873827394, 0.008635057984065497, 0.012075007089151768, 0.014996378649811959, 0.034810355136869475, 0.03323905410070438, 0.08600065906648524, 0.023112608614610508, 0.04607843155099545, 0.03911787302058656, 0.06574269180418923, 0.018089302284352016, 0.011524078399816062, 0.08099193408270366, 0.03522411730955355, 0.03839411947410554, 0.05978671550110448, 0.009089708782994421, 0.018215721574961208, 0.05531609211175237, 0.08830840437440202, 0.11486764327855781, 0.05089004211185966, 0.01542864349175943, 0.07844782958272845, 0.06257663786527701, 0.02345358836464584, 0.050317961286054924, 0.06130428133474197, 0.056797459692461416, 0.04151172972342465, 0.024241188875748776, 0.04806913508218713, 0.07504569104639813, 0.044918781277374364, 0.03896353598975111, 0.045813559045200236, 0.011444358751759864, 0.02089209905534517, 0.0309590187316644, 0.01338547754130559, 0.038667263215756975, 0.025207134895026684, 0.06213917520653922, 0.055271952878683805, 0.0583895891031716, 0.08246463708928786, 0.06031945136783179, 0.05121656482515391, 0.020800868696824182, 0.00542633797522285, 0.019937784345529508, 0.008810632498352788, 0.017147934340755455, 0.06394181851646863, 0.031437802317668684, 0.06915054487762973, 0.020051737410540227, 0.06727300031343475, 0.02370940852415515, 0.05320108997693751, 0.01183247415610822, 0.03373793690116145, 0.04066791523655411, 0.09239204970072024, 0.05413726103142835, 0.01664374147367198, 0.016980631990008987, 0.04867248258960899, 0.04727209816337563, 0.04201870193355717, 0.11124933938845061, 0.010187399930146057, 0.05130009725689888, 0.04031817072245758, 0.022570436340174638, 0.07411679674987681, 0.046658412538818084, 0.007252813502418576, 0.025413952898816206, 0.03060127201024443, 0.06598269494134001, 0.031078936808626167, 0.007987943245097995, 0.0839087599888444, 0.027671369462041184, 0.03031720199942356, 0.06619601044803858, 0.02664899053343106, 0.03581397257221397, 0.03332577405672055, 0.028607983949768823, 0.09726456832140684, 0.029250995539769065, 0.02108015371049987, 0.04063753171067219, 0.01747170554153854, 0.06697997072478756, 0.09418982081115246, 0.015507942898693727, 0.041920122457668185, 0.023016068189463113, 0.08897175823221914, 0.0017119395283771155, 0.03234535615774803, 0.029307892291399185, 0.06447327046771534, 0.05539573940041009, 0.07201749103842303, 0.024284162936965004, 0.03000206754222745, 0.03364126845553983, 0.029620616624015383, 0.053733399108750746, 0.01149852532762452, 0.10506416932912543, 0.04640478357032407, 0.029711679999309126, 0.03783540472795721, 0.054105578747112304, 0.029103810957167298, 0.028325823113846127, 0.03531628834025469, 0.03525533575157169, 0.031088859323062934, 0.011224190438952064, 0.03055454453715356, 0.03465877518465277, 0.019419917407503817, 0.030303314561024308, 0.013613778864964843, 0.08249869424616918, 0.010123888787347823, 0.021025589157943614, 0.04283823705918621, 0.05805372275062837, 0.06268401179113425, 0.01588175247889012, 0.009300996371166548, 0.03982079077104572, 0.04189810664684046, 0.06419440847821534, 0.04010433200164698, 0.03777279343921691, 0.02803707571729319, 0.03879099036566913, 0.06515744898933917, 0.10654623081791215, 0.06112636998295784, 0.013456900906021474, 0.06654507960774936, 0.02836889550962951, 0.01751054955093423, 0.03705650960910134, 0.049359529512003064, 0.05589919011981692, 0.07662803895073012, 0.13623220467707142, 0.02066363816993544, 0.036910280541633256, 0.0320111930341227, 0.05995174687996041, 0.018638816254679114, 0.07122812792658806, 0.023720557437627576, 0.0409484841657104, 0.0904189313587267, 0.019351105474925134, 0.028606826199393254, 0.01895362787763588, 0.08691470298799686, 0.056157101280405186, 0.06126660249719862, 0.04857425192312803, 0.05998158492729999, 0.021999689524818677, 0.021252938677207567, 0.05782484069641214, 0.0322764217708027, 0.024586827457824256, 0.02197037283622194, 0.020858448224316817, 0.034773103034240194, 0.08635780279291794, 0.03910313025698997, 0.017124009355029557, 0.05582488258369267, 0.04926585192151833, 0.033390908647561446, 0.10837250782060437, 0.04615759273292497, 0.019778024070546962, 0.030304069696285296, 0.027261974828434177, 0.04315227684855927, 0.034055171636282466, 0.04295103237382136, 0.06186253594933078, 0.023567919924971648, 0.05851067049661651, 0.026168709664489143, 0.08064628622378223, 0.10070229283883236, 0.029817450886184815, 0.0229560933803441, 0.07327494895434938, 0.03806273940426763, 0.018194854237663094, 0.0164111746562412, 0.0631063457694836, 0.03679930719954427, 0.04814085994439665, 0.03638676957052667, 0.031826190461288206, 0.027189238790015224, 0.011692362240864895, 0.044954356126254424, 0.019865974136337172, 0.05184941641346086, 0.05042560238507576, 0.05377164940000512, 0.010158687164221192, 0.03783087391639128, 0.007281793905349332, 0.02242013102659257, 0.0505513036478078, 0.04406404237670358, 0.038307314171106555, 0.07077751070028171, 0.04961441271007061, 0.0642265286296606, 0.038148409221321344, 0.056901612697402015, 0.020952615632268135, 0.003889640502166003, 0.019730836465896573, 0.03168888943037018, 0.044462757505243644, 0.022197288199095055, 0.07567944805487059, 0.06058565602870658, 0.018579830357339233, 0.04633518125046976, 0.061143521015765145, 0.03400053101358935, 0.08474608068354428, 0.018202945502707735, 0.10080731415655464, 0.05329662664735224, 0.03672108112368733, 0.03072901974519482, 0.008125400127028115, 0.04128385699004866, 0.02078738387353951, 0.025018946653290186, 0.07988773708348162, 0.025009628989209887, 0.05698832523194142, 0.046006317061255686, 0.03114699175057467, 0.07130894038709812, 0.14037310669664294, 0.013985456625960069, 0.013573215856013121, 0.04036913771415129, 0.045867977023590356, 0.02011459175264463, 0.047474582024733536, 0.07786761852912605, 0.04349077040387783, 0.056393616323475726, 0.07570790941826999, 0.049792624631663784, 0.049158912152051926, 0.04499590155319311, 0.04843955211981665, 0.02245270945422817, 0.024783632034086622, 0.11208038151380606, 0.019864844216499478, 0.01622663035959704, 0.042388506699353456, 0.05334149318514392, 0.02991675395605853, 0.056327101337956265, 0.03484969638520852, 0.01728432809613878, 0.01600792871613521, 0.044257572226342745, 0.03309914442070294, 0.0889150433067698, 0.05643739190418273, 0.052703357505379245, 0.07716832988080569, 0.0342040241957875, 0.02218795198132284, 0.015303073960239999, 0.049809092888608575, 0.019734903435164597, 0.05559581499255728, 0.029671544652956072, 0.029043504036962986, 0.055784572832635604, 0.011194173348485492, 0.022231614384509157, 0.03824054685537703, 0.01745908160955878, 0.02824320166837424, 0.031049210083438084, 0.039954325402504764, 0.004653840169339674, 0.01938397705089301, 0.04285236384021118, 0.031681846448918805, 0.05964841628156137, 0.0572380653466098, 0.05133012826263439, 0.06273079678067006, 0.036509179408312775, 0.08877937871147878, 0.028553762640513014, 0.03825879997748416, 0.028285964217502624, 0.06927147784153931, 0.037603806413244456, 0.0614228802442085, 0.07201193235232495, 0.0975609004672151, 0.06300601482507773, 0.027176544354006182, 0.010390973820904037, 0.07721129280980676, 0.01091820202418603, 0.060065948564442806, 0.02122293364664074, 0.05034282694396097, 0.03819789933913853, 0.018945208212244324, 0.03716970568348188, 0.044141058751847595, 0.06763006982509978, 0.014600494814658305, 0.028696245717583224, 0.07677425688598305, 0.1653556528617628, 0.07577382697490975, 0.14178976271068677, 0.11670845895423554, 0.16311726125422865, 0.15649160428438336, 0.15514508122578263, 0.12181823476566933, 0.13227695832028985, 0.12416916564689018, 0.06954285156098194, 0.1365468604490161, 0.08610959150246345, 0.0784717638453003, 0.14168926107231528, 0.1759256169316359, 0.07659197057364509, 0.06903812434757128, 0.13554166594985873, 0.08987348250229843, 0.10177819174714386, 0.20711225050035864, 0.1789014509995468, 0.07083832970238291, 0.16974143392872065, 0.0853776780422777, 0.09598117976565845, 0.14099041029112414, 0.15368147694971412, 0.21571006102021784, 0.0820244693022687, 0.1396148098865524, 0.15457482979400083, 0.11620349425356835, 0.14938113192329183, 0.1106037302815821, 0.16479917569085956, 0.1502401233301498, 0.10891941128647886, 0.09815546465688385, 0.1998078846372664, 0.26209586416371167, 0.1015684608137235, 0.11548570386366919, 0.10998112775268964, 0.11250762108829804, 0.07986288255779073, 0.11562340936507098, 0.13559980579884723, 0.2579910453641787, 0.12375906226225197, 0.12866584584116936, 0.11009083202225156, 0.19598157901782542, 0.22430248354794458, 0.1087892237410415, 0.1490896608447656, 0.10173039743676782, 0.1473597888252698, 0.0718636141391471, 0.11979470975347795, 0.1437681948300451, 0.14929087192285806, 0.13484676339430735, 0.16344621079042554, 0.14863426418742165, 0.15833076497074217, 0.12184752733446658, 0.3010351653210819, 0.1403121615294367, 0.07995500534889288, 0.20185811212286353, 0.15649516659323126, 0.18570480780908838, 0.1552494420320727, 0.14341279515065253, 0.10848782272660173, 0.15569484938168898, 0.13449822115944698, 0.20608116989023983, 0.12473301234422252, 0.12949291005497798, 0.09559158934280276, 0.09435816216864623, 0.11032310198061168, 0.26137494191061705, 0.10975671713822521, 0.15570853458484635, 0.16928971832385287, 0.12795492773875594, 0.17795579158701003, 0.11999549780739471, 0.15190027799690142, 0.129919036407955, 0.1564578217221424, 0.13314111507497728, 0.17661293473793194, 0.12997192185139284, 0.15653746901080012, 0.15823124296730384, 0.30360225413460284, 0.0854851039184723, 0.11645434016827494, 0.279894020059146, 0.12085310881957412, 0.13289684458868578, 0.19485298020299524, 0.12347590323770419, 0.1352356784627773, 0.17126898164860904, 0.296639691805467, 0.1668340852484107, 0.0943988021754194, 0.09226417023455724, 0.1555477557121776, 0.14139914070256054, 0.17244050628505647, 0.13216156919952482, 0.2065080829197541, 0.1236908885766752, 0.15780155430547893, 0.14907737087924033, 0.19198284280719236, 0.1400518012815155, 0.2415727498009801, 0.1983602810651064, 0.0895967504766304, 0.1028753086575307, 0.13281823630677536, 0.15219986817101017, 0.14947908057365566, 0.11569452937692404, 0.16888205660507083, 0.14960491913370788, 0.11613054855843075, 0.14036378532182425, 0.119054031529231, 0.14813656511250883, 0.14057485212106258, 0.09495049991528504, 0.09928020430379547, 0.07701256792643107, 0.14600574038922787, 0.1941443924442865, 0.11499748943606392, 0.11790187694714405, 0.14115258440142497, 0.11046459243516438, 0.09607625630451366, 0.12261570213013329, 0.21422555786557496, 0.11823932407423854, 0.09675955909187905, 0.16248207190074027, 0.1333669209270738, 0.28153585852123797, 0.14063912210986018, 0.083948019600939, 0.13006463093915954, 0.1949239443638362, 0.20728954958030954, 0.206566400884185, 0.11379504692740738, 0.18811398243997246, 0.13290462229633704, 0.297492835088633, 0.10024538962170482, 0.10944701891276054, 0.09769378943019547, 0.15830974734853953, 0.05316316623066086, 0.16420189524069428, 0.14761715079657733, 0.2350734212086536, 0.20999451458919793], [0.029246867343317717, 0.02983162961754715, 0.027885672025149688, 0.0397452809556853, 0.026908072431979235, 0.06563758142874576, 0.03264076432969887, 0.026593385118758306, 0.031476282674702816, 0.027224605837545823, 0.02412511697912123, 0.0036972043926652987, 0.02261106150399428, 0.06418085686163977, 0.05147408264747355, 0.028457897569751367, 0.004810396221728297, 0.03032294993317919, 0.031971506687114015, 0.019116610928904265, 0.029396643876680173, 0.07098885951563716, 0.060995117455604486, 0.040691148169571534, 0.06424562408938073, 0.005758912902820157, 0.010932826044154353, 0.02592797922261525, 0.06182035227539018, 0.04840767687710468, 0.03582203600672074, 0.01718886192975333, 0.061423711449606344, 0.03342886579048354, 0.0759136030683294, 0.05450166296213865, 0.015679969947086647, 0.053577329163090326, 0.02547374773712363, 0.027858828543685377, 0.05674850021023303, 0.03433833066083025, 0.0579899759759428, 0.023518350026279222, 0.014178509645716986, 0.03924540367734153, 0.021458435658132657, 0.016349162651749793, 0.04472391556191724, 0.10585346564766951, 0.06731631947332062, 0.005201277981541352, 0.08192116234567948, 0.03002769019076368, 0.038169352628756315, 0.02299644209415419, 0.03868574640364386, 0.02895588979299646, 0.014553648597939173, 0.0061980676582606975, 0.041715130137163214, 0.06511899089673534, 0.009287180364481173, 0.030701011091878172, 0.020042727737745736, 0.032640393255860545, 0.03558693475497421, 0.04872503035585396, 0.017695444512355607, 0.03252462935051881, 0.0499196135206148, 0.013943570738774724, 0.07817008081474341, 0.02278789303090889, 0.025042802990355995, 0.04281764988263603, 0.014348850163514726, 0.02404318944172701, 0.024505024230165873, 0.026726569085440133, 0.0730538705829531, 0.0404147946392186, 0.057773446969804354, 0.09563566549331881, 0.048032302292995155, 0.07254661264596507, 0.09334826987469569, 0.017589517774467822, 0.05129592267621774, 0.05073700383945834, 0.05199411294597667, 0.06958528014365584, 0.01952545266249217, 0.020882892713416368, 0.04732056782813743, 0.0214803809649311, 0.009943998684320832, 0.03707646596012637, 0.00717528226232389, 0.07806731562595814, 0.0358718638017308, 0.026699308145907708, 0.03243644365284126, 0.01954842769919196, 0.05086935474537313, 0.09075165100512095, 0.014335624164232286, 0.026024796097772196, 0.06742839119397104, 0.010361779586673947, 0.007437154636136256, 0.018849682674044743, 0.047380240212078206, 0.013794045607937733, 0.04584097026963718, 0.03190840558090713, 0.024464515954605304, 0.09680059985839762, 0.056523774183006026, 0.0815969922405202, 0.02739549832767807, 0.03346682293340564, 0.044391370320227, 0.15682564495364204, 0.0040891826756705996, 0.04176219714281615, 0.03294743459264282, 0.06511186627903953, 0.02927973520854721, 0.030846455338178203, 0.04233749146806076, 0.03544482089637313, 0.06276328800595365, 0.060947478996240534, 0.03670580030302517, 0.024173777746909764, 0.023301127112063114, 0.042038610044983216, 0.033597299916436896, 0.06356180179864168, 0.01792572180420393, 0.030108339378784876, 0.07063954544719309, 0.04491350089665502, 0.029014385872869752, 0.0690896887681447, 0.09435556465177797, 0.05007737556297798, 0.03063226780795958, 0.031511935449088924, 0.05733812911785208, 0.03223621963115875, 0.038294875776045956, 0.12129990398534574, 0.03563412421499379, 0.028385026089381427, 0.015830612937861588, 0.04201326199108735, 0.05861792938958388, 0.04282901587430388, 0.056666140371817164, 0.04804248826985713, 0.022552370610355865, 0.037469262460945174, 0.031230015811161138, 0.024363485536014196, 0.045333986927289516, 0.02581777956947917, 0.021149034291738644, 0.07621003169333562, 0.02854882364772493, 0.0201968625333393, 0.041130406825686805, 0.09727266515255906, 0.015411456279252889, 0.060317885436234064, 0.02482020136085339, 0.036178964510327205, 0.04421991194249131, 0.03419139284233097, 0.07442770467605442, 0.019307988550281152, 0.03238788493035827, 0.046551550694857724, 0.042641913023544475, 0.02504048006812809, 0.05393231695052236, 0.029209051208454184, 0.05250594622339122, 0.0331169262790354, 0.05274164490401745, 0.05084588803583756, 0.04503956210101023, 0.01476484991144389, 0.04443428500962909, 0.050429702750989236, 0.07719619752606377, 0.024758437975833658, 0.05191847696551122, 0.053419411269715056, 0.022944866541365627, 0.06369964830810204, 0.028583207349583972, 0.031466241416637786, 0.021381387741712388, 0.05328550556441769, 0.016121774169732817, 0.03521259546687361, 0.07324395686737262, 0.017076233598345425, 0.029929626507509965, 0.08715956719242968, 0.062284268788062036, 0.08051459211856127, 0.03666654811240733, 0.033538796415086836, 0.10754894654382952, 0.060267037188168615, 0.016923460643738508, 0.0422895227529807, 0.006553009061462944, 0.04748051178466994, 0.032335010619135574, 0.05031430620874744, 0.017370749337715097, 0.08331077449838631, 0.04408965018228628, 0.04364750457170885, 0.04257140899426304, 0.051921619960921817, 0.05310570544679649, 0.018193492396676447, 0.033026336022885516, 0.0392371992347762, 0.014948699372325791, 0.0163201020041015, 0.050589030724950135, 0.04942464183841366, 0.008034048241825076, 0.027078245038865134, 0.058231125731253996, 0.06297181666013785, 0.059120886580785736, 0.02920963008364197, 0.02060604379948927, 0.009731281534186564, 0.005836157488374738, 0.040302730340044945, 0.030843197309877723, 0.028300998274062295, 0.015346880154538667, 0.01861559630924603, 0.04040196661662776, 0.026173990045208484, 0.0353330386133166, 0.04312969329475891, 0.005505346089194063, 0.031104453701118473, 0.044382828200468794, 0.06778420647606254, 0.04273126018233597, 0.055928445581230335, 0.018674344719329383, 0.0711834135290701, 0.0169262288545724, 0.03322911674331408, 0.015100215314305387, 0.043384197997511365, 0.06760986856534146, 0.010929134787147632, 0.03376183034561109, 0.02221291040768847, 0.019999644209747203, 0.03479104445432313, 0.023190365282061975, 0.01859857886302052, 0.0210394914392964, 0.0386533368146047, 0.0345614981779363, 0.023785493503964972, 0.03185522698913701, 0.036646428488893434, 0.027568765690375585, 0.10846850462257862, 0.0200506149121793, 0.008870070178090828, 0.027353032637620345, 0.010455594474478858, 0.049058499571401626, 0.02523216011468321, 0.026574931616778485, 0.04772489730385132, 0.047510902732028626, 0.05298247553582769, 0.10130103531992063, 0.01686306652118219, 0.05887271610845346, 0.04353242344222963, 0.09650034175137989, 0.11897114847670309, 0.010820912029885221, 0.023419030258082785, 0.06669152760878205, 0.09196889193844981, 0.045873851122451015, 0.10778867508633994, 0.011084401357948082, 0.01739433479087893, 0.05866804662218783, 0.06991371017647907, 0.03890979707648512, 0.018130203898181207, 0.04171357533778064, 0.011811142976512201, 0.07265261359862052, 0.035829591070069, 0.01672596401476767, 0.027852744788106065, 0.028932827553944662, 0.016592310639680363, 0.013771302492386894, 0.0955962945590727, 0.09542644664179534, 0.08046038565225899, 0.08028255222598091, 0.031652698598918505, 0.058887239938485436, 0.030650815933768172, 0.043915616552112624, 0.03598967974539846, 0.07079248724039644, 0.018376366861048155, 0.034310826667933725, 0.06714272371027619, 0.012568389647640288, 0.024798745871521533, 0.03225704429496545, 0.02697767660720274, 0.038963625047472306, 0.07157193525927141, 0.023167375402408652, 0.057880713284248486, 0.0549932912690565, 0.043777313621831127, 0.04934692042297684, 0.0558027665829286, 0.08635953199700452, 0.02829295895935502, 0.07966718563693576, 0.04013011421193369, 0.03612254644394852, 0.051097784089506604, 0.11631322820903733, 0.11760566354496405, 0.23657441488467157, 0.14131026109680533, 0.20246259140549228, 0.1346882851794362, 0.26632034685462713, 0.1097499487514142, 0.11937673960346729, 0.10357626713812351, 0.13036128220846877, 0.18206723034381866, 0.1358539320062846, 0.12252288914169185, 0.12972631549928337, 0.1884396665263921, 0.09972734827897511, 0.10832112151547335, 0.09322100639110431, 0.13374050322454423, 0.17575973208295181, 0.17079897952498868, 0.19746897654840723, 0.14245229278458282, 0.14659951790235937, 0.15451143553946167, 0.0643420587584842, 0.13572784111602232, 0.2321292768465355, 0.14169809262966737, 0.11642820914858021, 0.08737792188185267, 0.1027712447103113, 0.17863895336631685, 0.12589864432811737, 0.19594720273744315, 0.1633719218079932, 0.1507554855197668, 0.09879492878098972, 0.09295956260757521, 0.14723277767188847, 0.14735229313373566, 0.24318836076417938, 0.07204690235084854, 0.09366651764139533, 0.15122012933716178, 0.11344530241331086, 0.12612131831701845, 0.13600375677924603, 0.23109246685635298, 0.12037998967571184, 0.1495128928218037, 0.14368041360285133, 0.12197944408399053, 0.1328853561426513, 0.10922238565399311, 0.11435601409175433, 0.11711957165971398, 0.1339159024064429, 0.09906012783176266, 0.16527740081073716, 0.223946638579946, 0.10378216116805561, 0.12960718595422804, 0.17520956316730008, 0.1133569423109293, 0.19017847400391474, 0.1186249588499777, 0.14086734736338258, 0.1443344831932336, 0.16010716964956373, 0.08793341199634597, 0.13599036843515933, 0.07926572085125372, 0.13203525566495955, 0.1647022957331501, 0.13351324276300147, 0.1387379624065943, 0.09510339717962779, 0.0951128224551212, 0.09836044584517367, 0.07858707875129767, 0.1469005923718214, 0.11136166343931109, 0.12745567015372217, 0.1704934670124203, 0.08750859924475662, 0.1152783032739535, 0.12684648565482348, 0.14176179858623073, 0.18234154296806082, 0.12746623833663762, 0.14066478557651863, 0.10437317047035322, 0.158872414031066, 0.1059490320039913, 0.12670280586462468, 0.09337566254544072, 0.17480749724199995, 0.13294008211232722, 0.09258647754904814, 0.09840202837949619, 0.21777474554255605, 0.16305845347233117, 0.1271082559833303, 0.14415810437640175, 0.09281442078645341, 0.12087260503903963, 0.16055078100180253, 0.07130937083275057, 0.12033802864607424, 0.08921783955884166, 0.19522972404956818, 0.20890946500003338, 0.1262165655498393, 0.13503811875125393, 0.13668112980667502, 0.2458478172775358, 0.2850494527956471, 0.18959257809910923, 0.2561143320053816, 0.1155075230053626, 0.22155612154165283, 0.18245586339617148, 0.06312240584520623, 0.15836132661206648, 0.1609862584155053, 0.11535085563082248, 0.16289565595798194, 0.27681470091920346, 0.18180465849582106, 0.11560918239410967, 0.21089444286189973, 0.1494888769229874, 0.11525472524226643, 0.10925352617050521, 0.09846604603808373, 0.05012305475247558, 0.12391286494676024, 0.09914476235280745, 0.12549911654787138, 0.11310562142170966, 0.13752777187619358, 0.19197782588889822, 0.129524243529886, 0.20894707704428583, 0.2238692919490859, 0.13846606918377802, 0.15625580912455916, 0.12295646665734239, 0.06641377884079702, 0.14721811283379793, 0.21013991616200656, 0.22245686617679894, 0.16691946191713214, 0.12001636700006202, 0.06739835647749715, 0.13415843626717106, 0.13865433720638976, 0.10972697928082198, 0.16239498829236254, 0.20598635310307145, 0.09123147916398011, 0.13599966012407094, 0.11459929010015912, 0.20815343916183338, 0.16039800248108804, 0.10113528405781835, 0.14542276854626834, 0.2044054152793251, 0.14371925761224702, 0.13956993963802233, 0.1217238706885837, 0.14763073209905997, 0.10123417523573153, 0.13713783264392987], [0.036137719653197564, 0.06374250733642839, 0.053103334284969606, 0.035687365889316425, 0.055527103249914944, 0.050804431666620076, 0.04143073172599543, 0.01416561019141227, 0.02825531908456469, 0.06900839391164482, 0.028709075595543254, 0.06570430792635307, 0.023158315634645987, 0.01161977741503506, 0.04553393635433167, 0.04668839159421623, 0.030800059976172633, 0.05313111287250649, 0.010740574543888215, 0.06422990540158935, 0.05121604532178026, 0.05748234696511645, 0.040061818071990274, 0.006985721511227894, 0.1041505929606501, 0.03604120334784966, 0.05287137973937206, 0.02050460891041439, 0.05261545753455721, 0.036805114505114034, 0.030315842013806105, 0.018218148397863843, 0.024128130098688416, 0.015146090245252708, 0.029548324018833227, 0.06479721050709486, 0.03616993999457918, 0.07355445661232807, 0.13165588461561128, 0.011930362506973324, 0.010174532944802195, 0.0672622094862163, 0.053131287277210504, 0.03668445242510643, 0.041802451232797466, 0.07399335532682016, 0.06586112373042852, 0.018360390276939142, 0.00794525398305268, 0.018588359489513095, 0.06367811118252575, 0.022869115528010298, 0.009785168876987882, 0.06777415037504397, 0.020670714548032265, 0.021303317516867537, 0.02299974836205365, 0.04055475255881902, 0.031923972128424793, 0.056657958193682134, 0.022084928896219935, 0.02038017672020942, 0.04001112567493692, 0.03021262411493808, 0.03421119705308229, 0.06592625461053103, 0.06195874055265449, 0.0470357575250091, 0.02707928590098163, 0.023219889772008173, 0.031070936456671916, 0.005783220558441826, 0.05679098816472106, 0.021178837087063584, 0.021262245209072717, 0.04386803375382442, 0.04816152875719126, 0.06811655504861847, 0.03613879205659032, 0.04339506303949747, 0.01475819470215356, 0.026249700240441598, 0.03846083483949769, 0.04966913125826977, 0.030272456060629338, 0.05985444389807526, 0.006602509847652982, 0.061340375686995685, 0.01721889479085803, 0.02809907658956945, 0.04675765994761605, 0.011141536524519324, 0.030446528653556015, 0.0136648247098492, 0.0371521279157605, 0.03293469562777318, 0.039976222469704226, 0.03665146396087948, 0.017343343679385725, 0.031867628276813775, 0.023257635402842425, 0.0446682396432152, 0.03234005722333677, 0.03317536298709456, 0.02869706764613511, 0.025046396840480156, 0.030185613650246523, 0.11646607352304272, 0.040951051996671595, 0.03303471858089324, 0.008559867292206036, 0.0182423702426604, 0.03604636869567912, 0.08702326435013674, 0.02428176208923105, 0.039328988059423864, 0.05694546620361507, 0.0068551726326404605, 0.07903328019892797, 0.035543645280995406, 0.00985127753665438, 0.03418637592403684, 0.05245043728791643, 0.03350253507960588, 0.03796685392444488, 0.02949704346974613, 0.006073460599509417, 0.029470433764799964, 0.02654380223248154, 0.05523777326743584, 0.021605657348118257, 0.03752544304006733, 0.06646231529884972, 0.043073204724350944, 0.01615550478163641, 0.06861461777589284, 0.1345014272374101, 0.04618006496457383, 0.08675010947627015, 0.06908954033860937, 0.06125867264927365, 0.02457975293509662, 0.07624893507454544, 0.04093950417882297, 0.03761513529752847, 0.017955554285435937, 0.028787949195248075, 0.023226455923577305, 0.019113223024760373, 0.06394834199454635, 0.06708660250296816, 0.062464825896313414, 0.009789171836018795, 0.021973398943373468, 0.012134527332818834, 0.025007769909279887, 0.07045155944069847, 0.02833382346580038, 0.03261206918978132, 0.04425293009262532, 0.04857075269683264, 0.08444775216048583, 0.032488568394910544, 0.013639181652251864, 0.007283940103661735, 0.01389934986946173, 0.04389423156681005, 0.03590087435441092, 0.019202852199668996, 0.016032799940148834, 0.03363596952112857, 0.028461291040002834, 0.01608144029887626, 0.014538434570567915, 0.05078443078673445, 0.044573649211088195, 0.024490053256158717, 0.03904679382685572, 0.026847800763789564, 0.053680632408941165, 0.07464447116944939, 0.02469403996656183, 0.103445226122858, 0.015700130388722755, 0.029529842686315533, 0.021162177727092057, 0.08194525245926343, 0.03827489344985224, 0.021745876874774694, 0.02212344821600709, 0.060960184564464726, 0.038587311646551825, 0.03703648646478541, 0.045923575016786344, 0.0382224941131426, 0.013406826346908929, 0.015096858951437753, 0.0963316515844781, 0.007100577677192632, 0.009737773470988031, 0.07287977758096531, 0.016992599121294916, 0.03187766582414042, 0.002175889785576146, 0.04506570054218173, 0.02842903915734496, 0.03854399619740434, 0.017446214624214917, 0.009327131101599662, 0.01874715311714681, 0.01988527183129918, 0.012228671548655257, 0.038511215534526855, 0.026543121311988216, 0.04283431109797675, 0.03967218683101237, 0.04277958512830082, 0.013431283823592821, 0.03468853159574792, 0.043554717558436096, 0.08574995415983722, 0.054435645215562545, 0.0582024194591213, 0.07606788072735071, 0.024834905161696952, 0.03576351395167876, 0.027864405783475377, 0.053133524852455594, 0.019926221684727352, 0.026899509903159924, 0.025132556475000456, 0.023780506271577906, 0.007228189970192034, 0.006734634398526396, 0.06621011125389487, 0.04072341675055213, 0.012935056056448957, 0.058978587185265496, 0.024179976535378955, 0.03405170209589414, 0.017601674153411295, 0.028821379237342626, 0.02482873976987321, 0.03347277866851073, 0.03776383942749817, 0.05249322210147511, 0.031100739251996856, 0.021457034854392987, 0.03398991088033654, 0.021009395495639183, 0.02203809195634676, 0.07006310450378805, 0.07275224692421034, 0.00975022299826378, 0.017148797087429557, 0.02410564302408602, 0.03801929407927673, 0.06914964687894098, 0.02156522143195616, 0.046029679870116524, 0.03331638959934935, 0.03278153119026683, 0.04402209619001951, 0.05363352087442763, 0.036922410945408046, 0.01784915442840429, 0.034526672898209654, 0.021804781135870144, 0.031415586126968265, 0.014291519255493768, 0.037417093190015294, 0.0697565678274259, 0.10806649806909263, 0.1024151177261956, 0.013809183565172134, 0.05080148905108217, 0.05560108424106147, 0.012289585174585227, 0.05370207305531949, 0.03352552310389001, 0.027686527828336693, 0.10176846219110303, 0.023198523340397514, 0.033722028965712525, 0.015884383392403834, 0.07610906250192784, 0.05893099325476214, 0.06481653603259474, 0.055203385854838416, 0.07837101729819551, 0.0160003402561415, 0.010616519921313738, 0.04238887777319178, 0.06953090298338793, 0.0306369989993982, 0.04227013785566669, 0.0063481039433099795, 0.05398091649112757, 0.020902665382891428, 0.04637062251276802, 0.03356782552145887, 0.01244268189111608, 0.012760393456119346, 0.013444923570204992, 0.03939254929719027, 0.10003732109908015, 0.05077992223959882, 0.05248612716968637, 0.052309670427348465, 0.05997580359689891, 0.039546374246128835, 0.040937325975392014, 0.06005002578604035, 0.020369601115817204, 0.06420249788789079, 0.046269593949546106, 0.017604943313926924, 0.04589518786815461, 0.08126010172418319, 0.0330555321124848, 0.019396736424823757, 0.015868638729443774, 0.019954514209530316, 0.03647364537755493, 0.03689029079396278, 0.01962006906978786, 0.021718452662753407, 0.07964744450873695, 0.01229101195349358, 0.00621779997345584, 0.020269798951630946, 0.07722991329501383, 0.04869848373346031, 0.01775880722561851, 0.08452400041278452, 0.019537416083039716, 0.023698742006672546, 0.01620512848603539, 0.08563106210203841, 0.036899422921123914, 0.016954695784079377, 0.02057633006188553, 0.04758889503136743, 0.021523032191907987, 0.05118752829730511, 0.017550350930832792, 0.019982422672910616, 0.014360314489749726, 0.07299576784134842, 0.08825729266391136, 0.06330872944090515, 0.01717898208880797, 0.12957405648194253, 0.17727933882270008, 0.2104846140719019, 0.09832314550294541, 0.16458505124319345, 0.17137659306172282, 0.19376220123376697, 0.08818280330160633, 0.09496405895333737, 0.13189251098083332, 0.2308722716406919, 0.10828239624970593, 0.07661142226425, 0.07281501777470112, 0.1313258070149459, 0.12937643739860505, 0.12317118482314982, 0.2550570684252307, 0.12489312328398228, 0.12013832412776537, 0.1713093841681257, 0.14260599156841636, 0.09775421509402804, 0.20875374757451937, 0.15850606025196612, 0.07436429557856172, 0.17442579584894702, 0.0307424581842497, 0.15959266835125163, 0.19966255727922544, 0.1268384259310551, 0.14348920667544007, 0.14713022770592943, 0.14040438079973683, 0.1468525902600959, 0.15706461650552228, 0.17053493822459131, 0.13389794243266806, 0.1955035765422508, 0.12269640326849185, 0.15242484281770885, 0.11892302019987255, 0.18516243144404143, 0.12275079527171329, 0.16775183990830556, 0.1701031270204112, 0.1689757898566313, 0.14091140124946833, 0.07483544803108089, 0.07121650589397177, 0.2254492649808526, 0.21438482275698334, 0.07447778480127454, 0.147731248580385, 0.07842091188649647, 0.14933703350834548, 0.141860622970853, 0.14463987696217373, 0.13464317744364962, 0.2409970510052517, 0.08220690404414199, 0.17950187815586105, 0.091607525391737, 0.120750751812011, 0.11385323130525649, 0.25071330775972456, 0.09581162128597498, 0.13811577548040077, 0.129070850671269, 0.1487583215930499, 0.1013020372192841, 0.10121962914126925, 0.1155273531912826, 0.11895756717422046, 0.07027811952866614, 0.11717707326170057, 0.145036822068505, 0.11311957379803061, 0.1012388730305247, 0.2606573444791138, 0.0687498296611011, 0.22230787260923535, 0.19698021293152124, 0.20830314519116655, 0.1706864550942555, 0.10855903921765275, 0.17002782871713862, 0.12296946166316047, 0.17083886254113168, 0.10284111049259081, 0.13997216883581132, 0.09492974204476923, 0.08972083014668897, 0.09045135579071939, 0.09492039840552025, 0.18389723292784765, 0.21813057566760108, 0.18603617674671113, 0.09737248401506804, 0.13527668954338878, 0.20448209397727624, 0.1476387176080607, 0.09294406656408682, 0.14160942082526162, 0.10992306953994557, 0.1372346977586858, 0.14628836506744847, 0.27403289393987507, 0.2353180924546905, 0.12521680357167497, 0.17290856398176402, 0.14582682342734188, 0.1336965087102726, 0.21329977316781878, 0.14886455261148512, 0.11071275919675827, 0.16793175134807825, 0.19117822113912553, 0.11529964744113386, 0.20935821201419458, 0.16517111042048782, 0.15802609850652516, 0.14569421648047864, 0.1398869851254858, 0.0712081122037489, 0.08541023606085218, 0.09903579280944541, 0.12701962870778516, 0.13512132834875956, 0.20140359119977802, 0.1327075672452338, 0.10216747046797536, 0.1921150489943102, 0.07502810956793837, 0.0853824129444547, 0.12400529943988658, 0.2158852672437206, 0.15147661557421088, 0.17637706536334008, 0.19036393670830876, 0.22684770869091153, 0.22035373840481043, 0.18240049917949364, 0.11779399836086668, 0.08634894154965878, 0.076220570190344, 0.18301379517652094, 0.141505713108927, 0.12468934437492862, 0.11382995013264008, 0.11124867887701839, 0.213356206077151, 0.1605659950291738, 0.09156259577139281, 0.09544750879285857, 0.1772300453740172, 0.22887326718773693, 0.08273597370134667, 0.11036104056984186, 0.15952026442391798, 0.1169366693648044, 0.14421305299038067, 0.17433615925256163, 0.10302073991624638, 0.09128837220487185, 0.1038483607408125, 0.15048593748360872, 0.10321934605599381, 0.13027364941081032, 0.09965516699594446, 0.09723028109874576, 0.10080431587994099, 0.09920434196828865, 0.15994984918506816, 0.16336012165993452, 0.11558530750335194], [0.056077865883708, 0.01214365111081861, 0.027597325388342142, 0.025564456736901775, 0.030795412276347633, 0.059017787425545976, 0.04080619219166692, 0.045367713828454725, 0.006180579412102816, 0.06104314554249868, 0.035630539641715586, 0.02654821058968082, 0.05219414029852487, 0.05222718813456595, 0.03094643005169928, 0.023366450950561557, 0.020551115594571456, 0.03233884752262384, 0.014391231434274232, 0.06435509087168612, 0.0261011501061148, 0.024516293742635753, 0.01558011026645545, 0.03058608952414943, 0.023813819425413385, 0.06657469872152433, 0.06798459377023391, 0.030177776570781134, 0.03804594089160673, 0.0960500659130048, 0.03753581826458685, 0.03730419026396703, 0.03739546700671781, 0.032795821243780665, 0.053570223099086434, 0.06795243651140481, 0.008491162043355871, 0.06699475430650637, 0.041806948647717945, 0.027009232726413757, 0.08358587379916571, 0.06179263305966742, 0.08663089087349363, 0.010715078988141613, 0.019253203208791092, 0.018191748349636327, 0.011997422043350525, 0.06397058416041546, 0.08441041471087374, 0.03504230968246702, 0.042394473566673696, 0.029179626908444334, 0.034347915498074144, 0.03003154750331305, 0.0398835838859668, 0.03053360112971859, 0.08859331486746669, 0.09097684087464586, 0.028670897663687356, 0.03054430846532341, 0.029368989598879125, 0.11341913428623229, 0.03632901192759164, 0.03814285053522326, 0.02083989638776984, 0.042164830811088905, 0.023221116171043832, 0.027163961240148637, 0.03687356278533116, 0.06525589487864636, 0.043035896960645914, 0.04190513107459992, 0.06618208775762469, 0.04103561230294872, 0.028847473149653524, 0.05612917426333297, 0.07996691681910306, 0.03206223052984569, 0.03113218590442557, 0.024171690456569195, 0.06514330365462229, 0.01699769767583348, 0.059015687147621065, 0.08197928735171445, 0.027730049223464448, 0.03938198853575159, 0.023914081721159164, 0.0316876908618724, 0.09110866856644861, 0.04512785169936251, 0.04386299457109999, 0.03619778166466858, 0.02035432215052424, 0.08122542858473025, 0.0379159017757047, 0.08409706511883996, 0.04792477993760258, 0.05026823368098121, 0.024822080849844497, 0.056175116915255785, 0.018011304418905638, 0.03327071412059013, 0.04653100062569138, 0.050067516131093726, 0.005177880848350469, 0.032996071240631863, 0.0408633635379374, 0.030853576245135628, 0.04094657313544303, 0.04416795418364927, 0.03588443207263481, 0.029568039171863347, 0.02654364081536187, 0.025120008613157552, 0.009419983052794123, 0.03655265441921074, 0.03912854881491512, 0.017156326175609138, 0.03709626274940092, 0.06607069139136001, 0.07009376262431033, 0.011886849461006932, 0.006566787960764486, 0.058744606576510705, 0.0680718629155308, 0.08676920493599027, 0.06053381701349281, 0.06731660891091451, 0.05099362737382762, 0.018770282149489503, 0.06680140999378636, 0.021738887699029874, 0.02791009424981894, 0.020370597449073102, 0.06264164258027449, 0.025534609412716236, 0.019631882205430884, 0.05226527515333146, 0.03368178600794636, 0.043440141089376993, 0.03681583853904158, 0.03791158247622661, 0.02010341686400352, 0.05423685353889596, 0.014538956856995355, 0.07108798818080686, 0.07067842656397261, 0.03244753504986875, 0.01514075605882681, 0.06487872058642097, 0.04429735505254939, 0.05199592749704607, 0.030637967502116226, 0.009547386616759468, 0.008656190639158012, 0.03532587317749858, 0.03701800698763691, 0.03912331296305638, 0.018190050686825998, 0.05259066980215721, 0.02558019397838507, 0.02925145010522101, 0.011592503487918293, 0.030261195825005416, 0.02869923471735092, 0.03824148196144961, 0.04991608831915073, 0.01705250713712303, 0.02194446075009182, 0.0967813262832351, 0.0634247568086721, 0.035281366581330076, 0.07775354300974868, 0.05526442750124261, 0.03830405243206769, 0.030189816061465535, 0.058607609826140106, 0.02222990744485287, 0.07636416092282161, 0.05075095992651768, 0.035230447829235345, 0.031074734397407155, 0.015457273693755269, 0.03106397511146497, 0.047290588772739284, 0.024163805137504824, 0.034012364558293484, 0.02891915719374083, 0.03884591300447937, 0.0448138675710652, 0.0067217377272754675, 0.015212415983114624, 0.03146608185488731, 0.03859401695081033, 0.04584590555168688, 0.0328695350617636, 0.039688707038294524, 0.00954036589973839, 0.02090962301735999, 0.02971264664665796, 0.06631753713008948, 0.05867245497938711, 0.05792703443148639, 0.03242434293497354, 0.015735831402707845, 0.009859265828708885, 0.008061576354521094, 0.07956484347232617, 0.049994804212474264, 0.06268958532018587, 0.08569311306928284, 0.07249580521602184, 0.03575569542590529, 0.07880694000050426, 0.03324917328427546, 0.03536313270160463, 0.031114155426621437, 0.06684990934445523, 0.027030910860048607, 0.033693270743242465, 0.027586877804424148, 0.01945752574101789, 0.029115872712281998, 0.030860034785291646, 0.05717062267649453, 0.1037678006105125, 0.01813827475416474, 0.01495581935159862, 0.06850749618024565, 0.040904541601776145, 0.04531087644863874, 0.024980390226119198, 0.08452276102616452, 0.08907564406399615, 0.08175345181371085, 0.025062417953449767, 0.022919357070350088, 0.06393003321136348, 0.020170818715996575, 0.07277067445102148, 0.035669487551786005, 0.05272163660265505, 0.021303347202774603, 0.008442163598374464, 0.027300349429424386, 0.05527220149815548, 0.05009455628169235, 0.008985337772173807, 0.021577541083388496, 0.06838885645265691, 0.041373727362952195, 0.058021955119329505, 0.036192838961142115, 0.0179030658910051, 0.029294570740603376, 0.014910314566805027, 0.029061321147310082, 0.04183350640232675, 0.057546468524378724, 0.014248017341742525, 0.004178340586804552, 0.05881507349840831, 0.019649892274173908, 0.0515707436716184, 0.09211490207235329, 0.015307468402170343, 0.03361324124853127, 0.026228756833006628, 0.016625673888484016, 0.08257438588771038, 0.002245108275928942, 0.11324939769110642, 0.08304310409585014, 0.051244525238871574, 0.02879402552935062, 0.03482099011307582, 0.0720234282198362, 0.06482529337517917, 0.11383876684703864, 0.11249374292674474, 0.07349363761022687, 0.07322347359149717, 0.041811353294178843, 0.0596292651607655, 0.023694574847468175, 0.041742648973013274, 0.023932166004669853, 0.015253331512212753, 0.029318809283722658, 0.0025611312230466865, 0.019678772951010615, 0.04736612085253, 0.05914643872529268, 0.012255283108970616, 0.03012684112036368, 0.022981647380220238, 0.08504683602950536, 0.015127853821468307, 0.04287744472094346, 0.03867131163133308, 0.0173217045085039, 0.022000194185238797, 0.05677875757100992, 0.024004113511182368, 0.03393291022803169, 0.046135614029481076, 0.10716442498960532, 0.032076279385364614, 0.02531772232032381, 0.012205193706904538, 0.02439542757201707, 0.028257382255105767, 0.030576961107726675, 0.014231320874387166, 0.03439128660829738, 0.01805513194995001, 0.038041365551180206, 0.03573972440790385, 0.018710173753788695, 0.01933109717356274, 0.027143982624693308, 0.042665472501539625, 0.023099556092347484, 0.057521784692653455, 0.02149768413801212, 0.06816770386649296, 0.038376764350687154, 0.021334587909223046, 0.0217890772910323, 0.03531082984409295, 0.01832365211157594, 0.04171995409706142, 0.04763530523632653, 0.06255981337744743, 0.03110300465777982, 0.031202723330352455, 0.023509941493102815, 0.011442033974162769, 0.032068798536784016, 0.023628822418686468, 0.043010170411434956, 0.014975538215367123, 0.054415447666542605, 0.014924794795661, 0.04238433211867232, 0.08295007588458247, 0.04771662235725671, 0.009384283894178225, 0.08749272470595315, 0.06303472109721042, 0.06942174790310673, 0.05625509445962962, 0.14100065192906186, 0.11201991132111289, 0.1787995095946826, 0.13363973441300914, 0.07139499983168207, 0.1577136988635175, 0.16752147726947442, 0.10656223152182065, 0.16060495778219774, 0.11784380389144644, 0.10023069509770721, 0.05167399125639349, 0.12446789492969401, 0.2517004532273859, 0.11592000868404284, 0.12030690297251567, 0.1586045729345642, 0.11250356154050678, 0.16911877202801406, 0.1708217931445688, 0.14637915941420943, 0.17253892990993336, 0.11009276902768761, 0.1762337566469796, 0.12893687817268074, 0.12296249289647676, 0.21759193972684443, 0.08258764806669205, 0.06904472946189344, 0.1464743769611232, 0.10857645742362365, 0.208750200108625, 0.1738813117844984, 0.162732531898655, 0.15807441232027486, 0.14325842843391, 0.07448609685525298, 0.10872979255509563, 0.12510070198914036, 0.09272338153095916, 0.18885810422943905, 0.1375484184245579, 0.14656546816695482, 0.1439622070756741, 0.0946880468109157, 0.09352664506877773, 0.17254405072890222, 0.2428805030649528, 0.12893760547740385, 0.21877207327634096, 0.12574908672831953, 0.09195280217682011, 0.26090649829711765, 0.11326337233185768, 0.12050757970428094, 0.13724467222345993, 0.17139517643954605, 0.1955230356543325, 0.15743769414257258, 0.10424840802443214, 0.19286154565634206, 0.2004971171845682, 0.10130815251613967, 0.14026481250766665, 0.10392866111942567, 0.23572706035338342, 0.14648870041128248, 0.13722353585762903, 0.08922345019527711, 0.15121475618798286, 0.20382211689138785, 0.12523418467026204, 0.09828668378759176, 0.1324879954336211, 0.0967367083649151, 0.1366882395814173, 0.22501233295770362, 0.12936800660099834, 0.12307902492466383, 0.10262070747558028, 0.1690219365991652, 0.1288492008461617, 0.23801407747669145, 0.17167768237413839, 0.13691172993276268, 0.16741539468057454, 0.1146521681221202, 0.08628813739051111, 0.13953786401543766, 0.14209441433195025, 0.21507067111087963, 0.11247596848988906, 0.08390585076995194, 0.21932293981080875, 0.12238815223099664, 0.18552069581346586, 0.20870718522928655, 0.1577284824452363, 0.11638223310001194, 0.23687507375143468, 0.234756093705073, 0.14549322804668918, 0.10909736345638521, 0.2204317826544866, 0.0891979128937237, 0.2556107996497303, 0.11112123727798462, 0.1333096864982508, 0.14889029029291123, 0.14858676673611626, 0.12134493750636466, 0.0779498039628379, 0.11490295466501266, 0.07134858591598459, 0.09820475810556673, 0.10567555800662376, 0.1423597172833979, 0.13437247165711597, 0.166612257307861, 0.24222328676842153, 0.19871520576998591, 0.08741525933146477, 0.13888557557947934, 0.23617659404408187, 0.1482504402520135, 0.18579980271169916, 0.11385979931219481, 0.1717339816968888, 0.09231505187926814, 0.06296978317550384, 0.20261131779989228, 0.13835128862410784, 0.08363282948266715, 0.06151972309453413, 0.13353095040656626, 0.1485073717776686, 0.10860475551453419, 0.08985844659036957, 0.14511535613564774, 0.0910186386317946, 0.14930884673958644, 0.1298559390124865, 0.07217889331514016, 0.12304801799473353, 0.1262450937065296, 0.1870698103448376, 0.16397329891333356, 0.11374197594705038, 0.07785870533552952, 0.1643051576684229, 0.18320262723136693, 0.2486079980735667, 0.07175232909503393, 0.08595889841672033, 0.11507764880661853, 0.11376438880688511, 0.08584040711866692, 0.22216990735614672, 0.18373504397459328, 0.19911719748051837, 0.1312395991408266, 0.19920015474781394, 0.0848124064214062, 0.15911387919913977, 0.08115269069094211, 0.10476215975359082, 0.14329382887808606, 0.1542151256580837, 0.10902903391979635, 0.17627898312639445, 0.17129482323070988, 0.1235734140209388, 0.20217958081047982, 0.1415540714515373, 0.18077641288982704, 0.11273704119957983], [0.024941577757999767, 0.054534258088096976, 0.00926797265492496, 0.030313686074805446, 0.04255700019712094, 0.0826839788351208, 0.02337972055102, 0.04043068031023722, 0.03427566742175259, 0.02834694092598511, 0.0212591504532611, 0.03635500564996619, 0.05900963122257963, 0.029772686393698677, 0.054021678952267393, 0.038201268689590506, 0.1094607041159179, 0.019666195403260645, 0.045975480825291015, 0.04980766796506941, 0.11368718318408355, 0.03284591621195432, 0.07009918030234985, 0.04173075234575663, 0.06208643448189832, 0.03686959600599948, 0.029268532489368226, 0.03417067578993738, 0.017953988353838213, 0.05888147345103789, 0.07658276794245467, 0.06216630070412066, 0.0880933967710007, 0.052614626329159364, 0.007044977364785154, 0.029878214227210265, 0.04761352320201695, 0.0576695054769516, 0.06058384518837556, 0.07331558153964579, 0.02045195909886388, 0.04565897710563149, 0.08528601538273506, 0.014058728866075398, 0.04476322341361083, 0.035536149589461274, 0.07072810592944734, 0.08042210567509755, 0.012926128947583493, 0.03597560862544924, 0.016352504171663895, 0.03801044396823272, 0.04074668679095339, 0.055250445439014584, 0.0587485473806737, 0.046046571151237004, 0.04104088897292968, 0.03971563215600327, 0.03477957085124217, 0.03277785384852905, 0.03043174136109883, 0.03783858112001326, 0.018276193623023573, 0.034475768989068456, 0.028088330291211605, 0.09006516440422274, 0.06301481669652276, 0.05376301451178733, 0.04540754860499874, 0.024372845873585902, 0.04416706731717568, 0.03890350737492554, 0.048488441098015755, 0.04977518416126259, 0.04565805313177407, 0.012431797367753461, 0.006616125474465662, 0.009681375813670456, 0.03134878170385491, 0.011293893876427319, 0.03716752376931254, 0.021957108801871073, 0.048704599030315876, 0.033508212509332225, 0.045107030746294186, 0.0470458507334115, 0.015196445892797783, 0.032940989040071145, 0.028506920134532265, 0.026121317969227675, 0.04519370246271137, 0.03288942461949773, 0.037011060485383496, 0.071310914499918, 0.044125462518422864, 0.04545977724774275, 0.046789627958787605, 0.010562358911556657, 0.05543048304389231, 0.07287182175787166, 0.140702590579167, 0.07175061473390087, 0.07593279500724748, 0.029723558072873857, 0.033869412072817795, 0.009567847628204618, 0.04886441311100498, 0.04009497723018285, 0.030616324620496016, 0.03116415762633551, 0.016568875471421052, 0.0032317861905539758, 0.03230135051126126, 0.021241596805339213, 0.03383933653822169, 0.03694306862598751, 0.07243212152388878, 0.010918791103904368, 0.0422561038431013, 0.023592585203005, 0.033270732674282044, 0.06777095914003439, 0.048348587079090066, 0.06331512675387785, 0.019500958078424446, 0.01985132785193855, 0.025134346906270366, 0.03127823685645126, 0.07949888880830258, 0.022597617498831823, 0.05850729001394939, 0.07387174700852484, 0.06151331836008467, 0.006383487689163303, 0.07401870709145442, 0.010047885443782434, 0.04239511923515238, 0.05407411910709925, 0.017375840470776893, 0.035976714425487444, 0.0513638551637996, 0.018999064013769384, 0.02540287077863468, 0.016959399144980125, 0.014167098197503947, 0.004795359382114839, 0.048928030009847134, 0.016142817767104134, 0.016618014924461022, 0.03829781839158386, 0.0448183612752473, 0.051824454276356846, 0.07481140244635753, 0.05576859810389578, 0.007349729175984976, 0.07282508129719645, 0.016789810979389586, 0.05229249341937248, 0.015627798820787575, 0.01719821484584827, 0.007057770135361352, 0.046145573651301675, 0.029180075907788705, 0.057788698104559444, 0.022685129697492812, 0.08158229029504582, 0.012332484093349194, 0.016818990370666143, 0.014682800847367616, 0.028920318654854782, 0.01846248567744624, 0.005447640860438696, 0.027442075515864417, 0.04788379112142138, 0.0630779066705145, 0.04008712159702554, 0.06369749607983977, 0.04760462856211234, 0.010522928605496418, 0.018815616240317468, 0.07928164734039456, 0.06761505617760122, 0.015456358996743802, 0.07260605867486447, 0.03340153620229103, 0.03969480749219656, 0.034455352506483905, 0.032178046385524794, 0.03084526975726476, 0.025406609347555786, 0.04707297252025455, 0.03136333521979395, 0.019431608088780195, 0.06136115582194179, 0.02770793693343876, 0.04798865287739318, 0.03484854234557133, 0.041930219376808964, 0.018702060224313755, 0.027385750217945315, 0.012937953215441667, 0.04415861054440029, 0.06652224372373894, 0.03742657041584607, 0.05140953064255882, 0.03272474576078821, 0.08782430144492537, 0.024951513260020874, 0.04437552546733059, 0.04220178976538591, 0.05538580575375818, 0.03855149931041524, 0.03192724128894042, 0.07291352303582244, 0.03503883272060193, 0.040137747200788, 0.016459586804558057, 0.0553316438163165, 0.09634295449359342, 0.007783935197949177, 0.04383845174743328, 0.01582275544933509, 0.029664271605724934, 0.0508785685087787, 0.014387622741196537, 0.03192698524799198, 0.046130393020575866, 0.022943911026231945, 0.037787269029649906, 0.05741287452110555, 0.07074215478496626, 0.050154262062278576, 0.051605427943286486, 0.05018778487283271, 0.04205238430586178, 0.027674022639985196, 0.021893091143283527, 0.05139810156833846, 0.01326940471699345, 0.011655986800178653, 0.022656807486782782, 0.05154267564648762, 0.03584648235118948, 0.058228680354659446, 0.0879174706642516, 0.04506197125010658, 0.014460177881119307, 0.02179402370529715, 0.039016803639242426, 0.059136779673281126, 0.04971685877535492, 0.09573489063768648, 0.06554503561346792, 0.0206198032174143, 0.01670926754741231, 0.03117618412943557, 0.03595930364099331, 0.047263184969779104, 0.04700593060988467, 0.061529300510301255, 0.030252991382440086, 0.049795678569353186, 0.03296231465355959, 0.054624904005322605, 0.03301441713119857, 0.05170553253265098, 0.03668742843728978, 0.0798305768694263, 0.015548832452623174, 0.03460672465735115, 0.01583388766448479, 0.022372624298441224, 0.07265802385518327, 0.0515330759662902, 0.03974163701059297, 0.044497875933302566, 0.08347976152435876, 0.025965969762182795, 0.08994461735710502, 0.011734683212125674, 0.017870812152978033, 0.007466213428415358, 0.019065612395934295, 0.061679726422880776, 0.04763880446262192, 0.05846288360771723, 0.052874930916004814, 0.023779504372214433, 0.03284360071120318, 0.025271356644225307, 0.04724320264358539, 0.030241271015256643, 0.05160391396202613, 0.016509525921719614, 0.04584306683682371, 0.03955251922889147, 0.026773109166242648, 0.04630376242857892, 0.02117042113241041, 0.010582779104879592, 0.029892734346503858, 0.01797977056412492, 0.024097605564747937, 0.055114873612183146, 0.050102148452424444, 0.0008968706822543027, 0.07251478193211369, 0.05578241318289656, 0.051917256132583134, 0.06880235145217739, 0.016032408457249403, 0.056695577659411356, 0.020870357839157805, 0.047511155062238686, 0.025480729491391685, 0.06474195019109175, 0.0023106206663214834, 0.05860218472662382, 0.0173402730433736, 0.04102032777154818, 0.005656375460603158, 0.06832442319137044, 0.0660054046602454, 0.05210467068536673, 0.04765168443555012, 0.0553470470913453, 0.010016452706622658, 0.05767080052464735, 0.02129205171513604, 0.02501410970580764, 0.02495671942597255, 0.044888108313898556, 0.043535759396036156, 0.013950495904282434, 0.04388942616060376, 0.035697154817171395, 0.04736764225526713, 0.018846804996428546, 0.05663061747327447, 0.02400002984359162, 0.06098300560552161, 0.030874925978423562, 0.037019231531303376, 0.06823011106462218, 0.02989475669892272, 0.013075613260298269, 0.01605714609468123, 0.030663280303997453, 0.027098967657366302, 0.020624766330001876, 0.0848492540535517, 0.055958350421860814, 0.1476374114281498, 0.12510021217167377, 0.09537127538351342, 0.13686080375919119, 0.15058262448292226, 0.1970595188322477, 0.12613978295121342, 0.10240673887892626, 0.13403626391664147, 0.11466919298982248, 0.11837862519314513, 0.09480794818955474, 0.11746379459509626, 0.08280191352241673, 0.11034269467927516, 0.11782656380091794, 0.20841779216425493, 0.19159774237778038, 0.12837005546316504, 0.08874643477611244, 0.20934556581778452, 0.15404748934088275, 0.12328671495197341, 0.10339967309846543, 0.12657282612053677, 0.13137201312929392, 0.15647947759134695, 0.1257745869224891, 0.07212559226900339, 0.15589209739118814, 0.209627463191282, 0.15841364802327007, 0.15964424761477858, 0.17284937028307468, 0.12703715823590755, 0.16133907542098314, 0.09782966924831271, 0.18380615656496957, 0.17227199423359707, 0.16053626459324732, 0.10947032977128401, 0.11511917196912691, 0.15894811309408396, 0.10078595514642075, 0.1524030978907831, 0.12455556483473629, 0.12147048662882298, 0.21436383482068777, 0.09638537565479055, 0.19751090789213777, 0.11890134948771447, 0.18201198487076908, 0.1744595932541415, 0.2413470923784189, 0.1215428089199122, 0.20239321544067934, 0.08756317678489722, 0.08585704606957734, 0.16219670127611607, 0.20584645826602355, 0.07728483222308569, 0.11070346008636989, 0.10797493931022473, 0.19179496070137247, 0.12347202922683209, 0.24063381424639374, 0.17148585204267874, 0.1168042999051977, 0.30714013148099184, 0.12321409580181353, 0.13380112184677273, 0.13789034070214257, 0.11237665428780019, 0.1614189601968974, 0.13073677924694493, 0.16387773997848853, 0.10425693530123681, 0.09313032336649485, 0.12668536539422348, 0.12627090560272336, 0.27661518193781376, 0.11347196777933277, 0.1913381539634429, 0.12228710140334442, 0.08742326710489579, 0.1948784655542113, 0.1300158421508968, 0.16085268667666242, 0.1052848543622531, 0.1406484583276324, 0.2145241090329364, 0.257826229208149, 0.11865934997331351, 0.17900265025673434, 0.19558393629267812, 0.10513443587115034, 0.30585490982048213, 0.21303875982994214, 0.12124582368414849, 0.16713878139853477, 0.16303789598168805, 0.14936599211068824, 0.2498189901234582, 0.09651392305386253, 0.1015746354823932, 0.076214373257244, 0.11448386387201026, 0.12247271253727376, 0.11061939701903611, 0.1451198387076147, 0.15356893767602742, 0.11850965878693387, 0.12276675144676119, 0.15333842660766095, 0.18416106642689556, 0.15616216493071988, 0.14070848323171958, 0.1323070895159617, 0.10664772693417035, 0.08083900713245384, 0.11796015780419111, 0.09648712410125881, 0.12444613515981473, 0.19369782734429464, 0.12570966384373605, 0.059765593978227116, 0.07896237540990114, 0.15138372837100178, 0.15693254390498623, 0.08476613351376727, 0.21006409835536033, 0.1354534988058731, 0.17013101693009958, 0.20844363374635577, 0.166354910179507, 0.11487874580780044, 0.19234073610277846, 0.21610993018839508, 0.08398025107453577, 0.17453126987675205, 0.11678941984428093, 0.14340109890326858, 0.2166341239353642, 0.06485051155323163, 0.07309425083803944, 0.16398337727878243, 0.16746949724620208, 0.3087698284070939, 0.07732958372798748, 0.15782613423652947, 0.11975719418842345, 0.15611370268743485, 0.12984875502297655, 0.2191953794681467, 0.1190625736489892, 0.2161283206078224, 0.09786369671928696, 0.12425213775713928, 0.11393599561415613, 0.14288788894191384, 0.11104538978543133, 0.11267703855992295, 0.10548346792347729, 0.10202674442552961, 0.16032905696192756, 0.1764420181280002, 0.12356150997220539, 0.17557351238792762, 0.10158108474570327, 0.1436875679064542, 0.0600525602203561, 0.12154510957770981, 0.10764394886791706, 0.1301128408522345, 0.1608096866402775, 0.11175391817232594], [0.012932115296280244, 0.049718929367372766, 0.025319850428786594, 0.04187519283732399, 0.06430417954106815, 0.01787253022484947, 0.03195428515027743, 0.035644540257635526, 0.02447304879751755, 0.08220079616876319, 0.030974655783211347, 0.01915264962008223, 0.01941761303896783, 0.022060614282963797, 0.05489817762281746, 0.04295554834243376, 0.06520081267808564, 0.03884376819769386, 0.0494374475965742, 0.015422812066390179, 0.03235315984056797, 0.015876947072683834, 0.035612624196801335, 0.06591714845853858, 0.027474609414639417, 0.0749066867865622, 0.034425425401423126, 0.02702907775528729, 0.051167820565751754, 0.017822969603003003, 0.06016707360686269, 0.05479341976752039, 0.030673774272145238, 0.04539209709037095, 0.019118193558824714, 0.008769948890403612, 0.021189364451856818, 0.07119965172023512, 0.018059430840366986, 0.14406431175302714, 0.050803878766600974, 0.01227793438374647, 0.029484978003893048, 0.016869139144546352, 0.07766527938656509, 0.04865806637099013, 0.07168444484705105, 0.01624856082344195, 0.02085670603264589, 0.011940556832996663, 0.05553177878027782, 0.05693401486496441, 0.004598470850396552, 0.021752702778030653, 0.04813716404896695, 0.044106493223807774, 0.01251279814823647, 0.03574020680389367, 0.04262339272827376, 0.03647835059382487, 0.02851827499398496, 0.11432672894443385, 0.04759023089718539, 0.020648637510021217, 0.020961521404387895, 0.06785845092963427, 0.007011481920926599, 0.017948726526810788, 0.026418540692247916, 0.03566069310181774, 0.039140649532782845, 0.010129286984010832, 0.03258547432778869, 0.04243815266818274, 0.024373708620260004, 0.045162825408624485, 0.033326690609101206, 0.012002441744698444, 0.01642191538849147, 0.04138590971706435, 0.018735547782853246, 0.020122794339840766, 0.08303063601488248, 0.028938269351783674, 0.010242920925520593, 0.03904810000676662, 0.04180584284767974, 0.015335536427301122, 0.05395847765612416, 0.05820978527481202, 0.0596651183150243, 0.02760843162832316, 0.04173523120698519, 0.11790322023443878, 0.029754071474599186, 0.0686965360364411, 0.011900240588147426, 0.05040878531872295, 0.006504001339635579, 0.026918744515569415, 0.06356574260280468, 0.05288116866722703, 0.012970153147762176, 0.08444499879260547, 0.024207586284319405, 0.07403642957797274, 0.03841806486889254, 0.05174527825147379, 0.02566904204286402, 0.06399693040293641, 0.01239813262145617, 0.0591905222972855, 0.035154455617885105, 0.0021001916502427775, 0.037386902622529306, 0.05197184480493888, 0.013511007182387402, 0.013708355381822912, 0.03537560820404906, 0.026393153675599024, 0.010537153721088544, 0.016984659996523988, 0.04744352314446587, 0.06541643626405858, 0.015797999258211348, 0.011248090377193876, 0.011635923765425105, 0.045281932689249516, 0.0810772216937039, 0.04808342884643935, 0.04623328808520455, 0.033047977049136534, 0.01961166795808822, 0.04116563286515884, 0.042622427936294116, 0.05264541432552505, 0.05689343423000537, 0.017393247544532642, 0.03689422046591062, 0.035982811168651097, 0.02968262862850679, 0.07475004909792915, 0.07566993372165598, 0.03227517496270593, 0.044476850889623165, 0.029471168490999844, 0.0633952564385254, 0.009607736210455187, 0.049770935365813784, 0.04353460535639897, 0.05082406147266738, 0.032881498482311144, 0.027908838164876215, 0.04656908022298012, 0.02539510234782938, 0.017085059589589946, 0.041754345220397227, 0.06796835557906888, 0.04329012335801963, 0.06741043864167295, 0.028994318199693225, 0.020796094831894152, 0.036477701214607805, 0.03915161105396692, 0.01972379905055277, 0.0722320681961719, 0.016651426412863657, 0.05630300009215716, 0.06546013391925953, 0.00514176794240484, 0.03351430183101911, 0.09365440579131246, 0.027769039807026275, 0.04318046361731831, 0.035581572738010436, 0.0034146040661653387, 0.026054858644783963, 0.031979711129679345, 0.04879560859990306, 0.0016696890611456183, 0.03396054780751001, 0.04579376596666407, 0.020801942955586128, 0.028400668707035948, 0.019412948640820105, 0.03531853333697654, 0.021944783584331162, 0.0038710116677975748, 0.0438513057451928, 0.051220461100456305, 0.04950400711095426, 0.030192498925316613, 0.02792077932099346, 0.025932957178156357, 0.04486445977818221, 0.030403951641346794, 0.01471170007789624, 0.05198890678002499, 0.05571728972427081, 0.053361917089205235, 0.02751723466644762, 0.019392500616959296, 0.06988875917159021, 0.016765882282925304, 0.01644140233111102, 0.043388821577536874, 0.031792701047379524, 0.03409995282709133, 0.02677268614206696, 0.07280925128725357, 0.04116753276321106, 0.03993255078967195, 0.026080679817823693, 0.01724761961668264, 0.057079026810242794, 0.046913577753002755, 0.011478739670565119, 0.03172575932694599, 0.02558388987381477, 0.023305492795770988, 0.0314514541241806, 0.04378634555905592, 0.06394880954758264, 0.027981455459666904, 0.08156200739904307, 0.04379236437671352, 0.07476640603272244, 0.02689068205654621, 0.04602185763360467, 0.055182153009809554, 0.015525423259532545, 0.032788440585136414, 0.016597865615040064, 0.06071387688280083, 0.008019918677746318, 0.03655361921119038, 0.0454010065732291, 0.02858249488781439, 0.017094390241254587, 0.06911458040121943, 0.012969955550943268, 0.04821793198061641, 0.024651088169775903, 0.035736080462811515, 0.05763275803474244, 0.014047776621737285, 0.03821002603217494, 0.004813344403373776, 0.017525431467220187, 0.04467423619644251, 0.04859309505263809, 0.010270211550960084, 0.02760862829745747, 0.09208467439748347, 0.048850327148102224, 0.008671073483128566, 0.06565026473253965, 0.028785038120986428, 0.026750141551019624, 0.04502054456679616, 0.07933862201753072, 0.024723211936361622, 0.03916116991604213, 0.02138039326382568, 0.027502035482029896, 0.046751425907132216, 0.018070490696118213, 0.06398562007234432, 0.04838940149056725, 0.06434995520976372, 0.015575733450532425, 0.11921098834136501, 0.016146730740729254, 0.07787401584209874, 0.0422698706825031, 0.030035722083994187, 0.01879378040030133, 0.01851294429798145, 0.025457732190261595, 0.04419774399138987, 0.016601208990323357, 0.017712801491143182, 0.026219860337732825, 0.10006824639276601, 0.04871425437158905, 0.06563017479493283, 0.025819278707785998, 0.045260221158969216, 0.017644306826696265, 0.02224091163952835, 0.022614560730289668, 0.03963460818340536, 0.045141663067624904, 0.010150868638447719, 0.022600842130486853, 0.027942889755649958, 0.009342100220237626, 0.016161916937562637, 0.04843676906602923, 0.04818546301976312, 0.04557162261335179, 0.05746072820329573, 0.02329221948457416, 0.029379132902249694, 0.03262683421780821, 0.11945839811232872, 0.05569116612605285, 0.04106813321413938, 0.024357424044865184, 0.013801525528833736, 0.012282564457564149, 0.015039495574455941, 0.016645205359964166, 0.1199475402245298, 0.030603735940530896, 0.007608730829815613, 0.00366396197478025, 0.10798808274557814, 0.05644259807013441, 0.01040178691255278, 0.014168751331453677, 0.0393393373087747, 0.03082663257373497, 0.017015603843901772, 0.04645410670491401, 0.03880613759974949, 0.04708999738795683, 0.03046964469831437, 0.0793380950926803, 0.04819089554075617, 0.12094969191821292, 0.0504761649062857, 0.044399044127203524, 0.008008227068785345, 0.05012213077861816, 0.039124325994635, 0.09667446443927474, 0.03257020463934168, 0.016878184069355484, 0.05916601287026424, 0.02972919653984718, 0.0640903296880424, 0.049927086947718635, 0.06807940313592553, 0.019366551423445344, 0.04430626824614592, 0.06721333164023235, 0.04684352272306569, 0.042055753656313755, 0.10141589751583524, 0.08014981169253588, 0.05574520560912788, 0.09414429747266695, 0.12435379714588635, 0.09605448911315762, 0.10534094588365406, 0.14289056067354977, 0.20117784471949562, 0.13781287532765418, 0.12365200003841892, 0.10849110301933251, 0.16336516826413572, 0.09036082119564526, 0.07475327744032256, 0.12862142088124529, 0.12517893919721246, 0.11709312893799506, 0.09203394860378467, 0.13964626210508868, 0.1427960704313591, 0.10323307578801177, 0.16785372194135562, 0.10390691619249992, 0.23683004023041576, 0.13521803019102663, 0.1566761318827048, 0.08743580940063111, 0.15870013186940923, 0.11988626109086908, 0.10943524102913216, 0.13697571790544316, 0.17016444326145574, 0.21470712264999747, 0.1291825290536508, 0.10069055948406458, 0.1934976107440889, 0.16530782886547968, 0.13967627455713227, 0.1267085352446884, 0.15349778055679053, 0.1321163130342029, 0.197772633691784, 0.14442404557485133, 0.10209545987891033, 0.17322130501270294, 0.09952987020369619, 0.2289002516772598, 0.14024565025465563, 0.12016847016639076, 0.14074309699935839, 0.1773047202732414, 0.19527904718415812, 0.13936675444711, 0.13031553622568026, 0.10704906555474736, 0.11352962523233145, 0.10895218452787958, 0.14821824588580057, 0.09407706631463952, 0.17214335035532713, 0.21019146573962644, 0.1434213446918875, 0.11840351682621986, 0.26189034862909466, 0.17123516940046102, 0.09561456623487175, 0.17750606493791565, 0.13217721367254853, 0.08515996159985662, 0.0705533598375041, 0.14442805317230523, 0.1344130077632144, 0.12233573434059508, 0.1414592398214154, 0.104108297964558, 0.15196776890661567, 0.09168504271656275, 0.0873148393293377, 0.13591794966487214, 0.2055963544989936, 0.12699114507995546, 0.07534891774412245, 0.10015081774326973, 0.07789365306962281, 0.11786937830038369, 0.12612091755727306, 0.09488930983934551, 0.11650736661977135, 0.11605812978814356, 0.1309351553209126, 0.1125722547294572, 0.11471062709460966, 0.09993268569814973, 0.11155804313602857, 0.0960228662006557, 0.2852600743062794, 0.0900379721133504, 0.2124562778044492, 0.13959472737042233, 0.16316314082359895, 0.09665715755545534, 0.10663394525181502, 0.10261769435601309, 0.11735159670934081, 0.13811694807372987, 0.18267987325089052, 0.17290235962718725, 0.08693814743310213, 0.12159253281424753, 0.20972334867110476, 0.15242605993989855, 0.16530002147192135, 0.11164487441419624, 0.13089822605252266, 0.13219719228800386, 0.07900815107859671, 0.17369727400364354, 0.150746327417437, 0.12758297816617414, 0.17777240689611062, 0.0924514140933752, 0.15204474446363747, 0.1012068048294168, 0.10584442628896795, 0.0889598170761019, 0.15597873571095988, 0.10812955093570054, 0.08854076339048333, 0.10762140242150053, 0.0995494777453132, 0.21262710535665974, 0.1433580691809766, 0.1364633985213004, 0.13393171015195549, 0.11611144567723386, 0.12722265062620863, 0.14690633659483865, 0.1545067154802382, 0.1728488359367475, 0.25160827848594636, 0.09899683005642146, 0.11104567180154845, 0.08335748527315445, 0.23257989407284185, 0.18640990747371688, 0.09595765368430875, 0.11124047814519145, 0.09582578888512217, 0.14375415339600295, 0.11616954841883853, 0.08488109218887985, 0.13613338029244915, 0.11530851610586978, 0.1987914985511452, 0.16517998650670052, 0.12958849867573008, 0.2358230497338809, 0.11597507604165003, 0.12070657176082022, 0.13132546562701464, 0.1551658019889146, 0.14609435282181948, 0.18842247838620096, 0.13282610307214782, 0.08569743236876093, 0.13233303499873728, 0.16297493217280135, 0.16004107397748157, 0.09746879251906648, 0.10614931539748795, 0.1862409501336515, 0.10681523708626628, 0.1502752714441158, 0.1870542549295351, 0.07968285237438977, 0.30890213849488646, 0.12379110819892958, 0.10759504875750281], [0.029089541312714573, 0.02571882345364429, 0.0146995140130457, 0.032656653711455874, 0.03645805656560697, 0.05739141161029693, 0.05941053939750418, 0.05863004123966675, 0.08180201795767061, 0.08193624278646894, 0.11362603763700463, 0.008382592332054628, 0.0354826073453296, 0.049120973562821746, 0.14568479120498523, 0.018594604662212078, 0.04313973826356232, 0.010761197900137631, 0.011911165001947666, 0.022981255897320807, 0.046283178962767124, 0.04390675159811508, 0.01736616100970423, 0.031165233740466647, 0.014381302426045295, 0.050248258776264265, 0.03925380478904117, 0.06329702577204444, 0.04318468643759843, 0.05006258455978241, 0.03070140999625437, 0.005551721505980822, 0.027730696747312322, 0.036731337604578584, 0.02353949752432527, 0.05173881785594858, 0.020915103777952027, 0.048955975580611266, 0.09384073680848815, 0.049919465091079473, 0.031396446138387546, 0.054663681221427396, 0.05695918851415627, 0.03936029184842482, 0.0074042505912075285, 0.01947059867234202, 0.019401072422624566, 0.035085691924905404, 0.028666762045759242, 0.023008292337181047, 0.047648760373704135, 0.062397327565122396, 0.011460765781521332, 0.01380868632622878, 0.023891060300229583, 0.01884620385681046, 0.021218054025666788, 0.021058058118796907, 0.04504969241679646, 0.03707629526616074, 0.04657362587749958, 0.021478477356140502, 0.050019098416669294, 0.023650198127143085, 0.023184376150311437, 0.04961431994161103, 0.04497881360293832, 0.03978688575443812, 0.04221654366119765, 0.027555338383535855, 0.06042576402251143, 0.029864751668355893, 0.06439222794142552, 0.03520956379361451, 0.03678429355204571, 0.015474639021704206, 0.05046241662057582, 0.04031153963296674, 0.040890897216740996, 0.04414263581566047, 0.03610460873460397, 0.05878288655367214, 0.018176990743086208, 0.02653183510119561, 0.01888248745672172, 0.04559699664241634, 0.07566369968117215, 0.03494024582323618, 0.012608356155396905, 0.046952893026173115, 0.023905673187982757, 0.05609131359960884, 0.09236323210643604, 0.013276023746584542, 0.03201856627129018, 0.012257157031854149, 0.05143193979165517, 0.04766345118696336, 0.08286999072879553, 0.017116181552410126, 0.05988905766571406, 0.07408913690596819, 0.021793068190163467, 0.030696804969920777, 0.06969646128709428, 0.039834553899709135, 0.011603300808928907, 0.06906699389219284, 0.04757116883411072, 0.0435322750126943, 0.021564907874562778, 0.05317971983458847, 0.003424702144911862, 0.019097871700068936, 0.012110460411349777, 0.05968449950159993, 0.011730663554772036, 0.034304536966374144, 0.031790188877494074, 0.0482209228357533, 0.018031225517916027, 0.08847288656397723, 0.013048724322288763, 0.02017885803070385, 0.03468423827143852, 0.04364620581327472, 0.0959558280010242, 0.1468818011926487, 0.0828721429570578, 0.026457852254679892, 0.06804721619118936, 0.038728887448087335, 0.016035597836889792, 0.059031212877016515, 0.014189101948431926, 0.004228065408824477, 0.03779105027206242, 0.05236130906268954, 0.04509936807153281, 0.009991376464313362, 0.06772305350750685, 0.0370560309238499, 0.024176169317797758, 0.06405878099030815, 0.056785422057146206, 0.07663058451726101, 0.016035070912039373, 0.030592273469665088, 0.07451363795553334, 0.05444066955533344, 0.05010037843021564, 0.05140292181749828, 0.018701154804148246, 0.0792886977433227, 0.011056332405132707, 0.018433881450619083, 0.020748992574226577, 0.052513237824314274, 0.018918125388154294, 0.035694538746611215, 0.03857786039588973, 0.0948676910775248, 0.06477686823927797, 0.04390209462144412, 0.057282802008558065, 0.030602700644521974, 0.009474808284721803, 0.050187621600343846, 0.038745815836591646, 0.0449502446281258, 0.0044654311386693735, 0.06295928178587928, 0.028853647818323225, 0.06402279424946755, 0.041600639015086927, 0.04507390498474706, 0.02196761946834158, 0.035637389664771035, 0.03538140437740367, 0.015958824515109882, 0.02949278539745137, 0.03473338329058606, 0.07191524535301141, 0.05713030921469908, 0.05119803339766804, 0.027480620810820255, 0.08667510061059147, 0.05504557557287626, 0.03080699720158009, 0.04416557560034562, 0.031117997896217275, 0.03594866495404858, 0.029159718797018286, 0.016875900109880604, 0.06280721572693437, 0.021869078955205623, 0.023130095469241496, 0.06320319604128599, 0.08417714285315014, 0.01975147744815331, 0.05672171610058285, 0.042553478706395254, 0.06899127256474458, 0.017540981316415127, 0.07079243529005907, 0.004750079560835729, 0.0045122717892809305, 0.016659487992001232, 0.043945306169916876, 0.040694421040825546, 0.01912042742333142, 0.0462456040258985, 0.015862916770856827, 0.05194422206841409, 0.04225129843689501, 0.0347909628180787, 0.06579697990673594, 0.07545885207946412, 0.01751899519149447, 0.019152130116708577, 0.06314672602456994, 0.044074191246181726, 0.017777553875930607, 0.020220947080815677, 0.027482502155180555, 0.012216709983476903, 0.13747564342338592, 0.007182043227658141, 0.04088610294274986, 0.02395699826593045, 0.04125972976908088, 0.04345568537246436, 0.017382119040121324, 0.01825077135436004, 0.08105673841782846, 0.04668933412176557, 0.04884922134806402, 0.03176494101353455, 0.04494731685554143, 0.03630468803748954, 0.03929544298443943, 0.028654557427216787, 0.08094544595223852, 0.039744572204654105, 0.07703958210186101, 0.035996028818772174, 0.06989567598793656, 0.060050018364563584, 0.024510007751814555, 0.025591450503270607, 0.08444820487056859, 0.03685440053232014, 0.020187737827654928, 0.0406478883814998, 0.07978769557666965, 0.048061635679914616, 0.013570554328907747, 0.11463049740996212, 0.08833459476591088, 0.07124368334189057, 0.027273509658698458, 0.06679287529550493, 0.046187553234631196, 0.042000148241641, 0.0522097810608102, 0.010450374393258244, 0.012884473126177909, 0.02158449871785706, 0.013477698666974902, 0.02488229871232761, 0.035507287466316484, 0.04503604803176131, 0.025308170879725367, 0.03891722968546674, 0.020000703625555616, 0.020748037059092894, 0.03287091545644216, 0.03681588677864056, 0.005117410655657295, 0.0075565235238173045, 0.022699269466102123, 0.029347435774980113, 0.03825372739811428, 0.060810608410974964, 0.021065386827103794, 0.016913601211854257, 0.04234361789713148, 0.03361560498888139, 0.049567071109777316, 0.06623022345593199, 0.03183723361871671, 0.04140804427152034, 0.0013587720900432032, 0.01790375423297519, 0.046286359065561555, 0.008813501826807624, 0.02231941787613323, 0.05301135250192601, 0.0738803188141901, 0.04944817163050175, 0.0178828590651392, 0.04983523132978007, 0.020216162083670497, 0.02251405723654898, 0.049838975464808755, 0.02888608338253107, 0.0877402829064522, 0.019815632404061034, 0.06239030684810132, 0.02926093846326694, 0.027959597355220467, 0.08305538663989864, 0.00682149907333951, 0.08612894671387039, 0.030506108269037213, 0.03505903026962187, 0.05650195504131261, 0.025142493832390755, 0.037659415538655594, 0.03045301873498829, 0.016218262644542847, 0.06191522843437269, 0.057696252479217947, 0.06088285648729652, 0.020471520256251097, 0.06550770558533259, 0.016615944332443178, 0.02571158009232022, 0.022701976449752692, 0.11343666381435469, 0.08474361675325781, 0.030108554601611104, 0.04130483379412908, 0.06053637000150047, 0.020497133627941366, 0.013167809338483494, 0.06299279717495665, 0.004683952811319614, 0.007557298604297102, 0.03526284628605936, 0.007171850293161697, 0.05003699530789163, 0.015501713496632874, 0.06499053255538456, 0.029871050646761432, 0.04036359016026836, 0.051956883107777685, 0.03868635496473871, 0.014691195465275086, 0.03646336292149499, 0.02606478301458992, 0.07150259640184231, 0.09512373944744468, 0.21330971794668585, 0.14351861056638882, 0.11658090603305027, 0.17099063174100593, 0.1417630899231881, 0.19375421572476625, 0.15844986482989043, 0.1795265471446328, 0.14777466421946883, 0.22918726986972615, 0.14180174097418785, 0.1586092633078806, 0.10568467900156975, 0.3003047435777262, 0.08147582178935409, 0.1502663063001819, 0.07206241323729046, 0.15906891989288852, 0.10130955517524853, 0.13619941659271717, 0.2017821162007749, 0.0899526770808734, 0.1713630711310543, 0.1253522009938024, 0.19278563879197463, 0.22289814718533307, 0.1596727460855618, 0.16615539119811729, 0.10486010098247789, 0.10316840503946878, 0.1199540265952237, 0.17890873888973147, 0.1309645888977684, 0.13790025579510257, 0.12211930923513137, 0.112872319878079, 0.09965383113012649, 0.2396980402409099, 0.09228365161106922, 0.11595347212278284, 0.11686114099575207, 0.18766443390632048, 0.14124195382464677, 0.10895911618717946, 0.13025586755247787, 0.13051627232925966, 0.11163221337483265, 0.20440139283891767, 0.07375092536676675, 0.203375329147093, 0.22711186873493716, 0.08955271885497496, 0.10872364015085623, 0.11398016082239337, 0.09110087601584382, 0.08296113388496451, 0.07477851788280532, 0.0951737305149436, 0.14531763590639457, 0.20409519755048677, 0.13823670102283359, 0.15984344005119056, 0.087037238990888, 0.09743451271788217, 0.14442949293879792, 0.16231296613113955, 0.08637459017336369, 0.16279138420941308, 0.09272081369999796, 0.1390497386455536, 0.1253113234997727, 0.15594204392982647, 0.10284902178682387, 0.1294982386752963, 0.12184708204586059, 0.20568361622281373, 0.08670824492583051, 0.22567130072275177, 0.12041811380186118, 0.1004740824282635, 0.12409857255988754, 0.2303361738449894, 0.1663369353627786, 0.12210227694595233, 0.11823841123259626, 0.2142747474135831, 0.11191293073352426, 0.11471969613921829, 0.13456134824082255, 0.1106979681935627, 0.07566872402094305, 0.17391338740708306, 0.1414154827944003, 0.11882382474141195, 0.15420963376527652, 0.1101351085526403, 0.10615608378429897, 0.11446913966210559, 0.10858861380256712, 0.14001135423313826, 0.13682715478353202, 0.17015728895785287, 0.1629631023388356, 0.1758186734514311, 0.10915189646766521, 0.11286532142548822, 0.1947271267999895, 0.05195801117224619, 0.059107171691721305, 0.18523710634326562, 0.1260961891966872, 0.16211573296459392, 0.14601877250242978, 0.15891394461505115, 0.1243792824971024, 0.07979784815688618, 0.09293790673837066, 0.2379788106190972, 0.16434343764558434, 0.0847090697789099, 0.19840139604639262, 0.20927909907186404, 0.14090947166550905, 0.10417317651445046, 0.11734739615349099, 0.15952209010720253, 0.15212798374705017, 0.20389156707096845, 0.08868122968124226, 0.2615384222008288, 0.1310966318123974, 0.18763042869977653, 0.14281701383879408, 0.12061519111739472, 0.15288111520931125, 0.07635188580024987, 0.2219595678616315, 0.12983116612304002, 0.13038771750871092, 0.16264782316284254, 0.20822976162889972, 0.18828656146069989, 0.14184950559865683, 0.11320003002765588, 0.24277741875266656, 0.1819370873272419, 0.12070335083990358, 0.21675841882824898, 0.11422828305512667, 0.0968696344352793, 0.16457739227917045, 0.0822116166818887, 0.14441487262956798, 0.13329387875273824, 0.06173324269184377, 0.12694076809566468, 0.13002979452721775, 0.0829045228601899, 0.0974732602480799, 0.09347347760922275, 0.11196652121725492, 0.12984885892365128, 0.14679185289423913, 0.1666570533416234, 0.10614024635287933, 0.12650517193833366, 0.18876756221288815, 0.14436762750847265, 0.14895469386829063, 0.09222689957823604, 0.1636654115281999, 0.2128384096431546, 0.14691096759634092, 0.11546530964551494, 0.19870414776960388], [0.07635500282049179, 0.12055354090989567, 0.046781375276623294, 0.032880570797715336, 0.023367987196252216, 0.06573524806299247, 0.05742316810938064, 0.07914322937722318, 0.03184149354638066, 0.00380362326723116, 0.059676781165762804, 0.016322103947459254, 0.04231769096804783, 0.007208018860183074, 0.03060659877519356, 0.06936340767424554, 0.051749482518061996, 0.07869788139942102, 0.024310557419084944, 0.09704842523206025, 0.012173914965387667, 0.04025021225970704, 0.05697023167158477, 0.0569846775761107, 0.047816912483540364, 0.06384260079357773, 0.044256228939048015, 0.05396888627728913, 0.04714756578323431, 0.12059956148732454, 0.0254631535790395, 0.008635167450847803, 0.015035862761578755, 0.03485533299681265, 0.02659499557921663, 0.030919089331291616, 0.009752929981914349, 0.020942069713782985, 0.01188840147733572, 0.032644790480844676, 0.013255925459816353, 0.0419089865317801, 0.055702762183500454, 0.022425760216719937, 0.019524769886629656, 0.04168343672063202, 0.030334315924847033, 0.03963312388805207, 0.06558115594089031, 0.0791735238453839, 0.07904358120867983, 0.0684785598423332, 0.01731049251247896, 0.033802188336267136, 0.009767622650542762, 0.06283871247433126, 0.05913724351557903, 0.037953320861561224, 0.048964168890961446, 0.09839953476330265, 0.03213583302567713, 0.01534881808765931, 0.03971276746597141, 0.023586931893078145, 0.02249706391012296, 0.029244408979138825, 0.02786296416161349, 0.04150648273935076, 0.0524303473503096, 0.04608246141287964, 0.02883701257815119, 0.047641416822443716, 0.040832942904671654, 0.0217924856042373, 0.07485427631763741, 0.02744086395978229, 0.01641616374399746, 0.008289360957860481, 0.02597536164103076, 0.05155889899469912, 0.03902064425346907, 0.020136956372880377, 0.03422781745030079, 0.04017154460598249, 0.029650764518009964, 0.04085093256435357, 0.021206908822932746, 0.047171069600153714, 0.054735484009142965, 0.040586089744465426, 0.1174464580253698, 0.01659350178670138, 0.01400166791427182, 0.08386622750549577, 0.04289713760954328, 0.06331745709758252, 0.09834327254793607, 0.03446224334766157, 0.02892651373258559, 0.038983729828032665, 0.053683318983530626, 0.039680810587015, 0.060268035376793705, 0.09813912998652086, 0.006459288333644508, 0.044777123839594424, 0.07992755330633372, 0.01645073112740647, 0.03215118435036857, 0.03209434697055258, 0.041060496514546685, 0.04952738847350702, 0.025725371051521506, 0.03669977035315242, 0.0020395574892972945, 0.02829313336405903, 0.014967847710067872, 0.03146134324197192, 0.0456389465398388, 0.021801135335408617, 0.006671166393061867, 0.07255977092427202, 0.04835104358789977, 0.015612855677318294, 0.008842569895932684, 0.02621968222229043, 0.05460586791741662, 0.065368181822123, 0.024948103091446683, 0.06645748391747475, 0.032720849485485815, 0.050255661699338816, 0.027973605392617173, 0.024462465771648567, 0.006860694211354712, 0.030054342569201253, 0.004404097271617502, 0.10175344854360446, 0.022057549213059247, 0.06225994118722156, 0.03293176785518881, 0.05176930528250523, 0.02854042439139448, 0.04526900076598395, 0.04146903025684878, 0.019993807218270376, 0.0404946460184874, 0.03161604021443054, 0.02111063186021056, 0.026125978656637017, 0.03746282804058865, 0.04164569480053615, 0.03808899287832901, 0.03829688699624967, 0.056657234599697404, 0.020232455935911275, 0.10114935517776757, 0.05737234583648387, 0.02953586335934233, 0.05633278989989776, 0.08826793506159447, 0.009779033171071205, 0.01909543374495115, 0.04075339580595028, 0.06976348464377224, 0.01678481447015656, 0.03438831801759079, 0.04765296835103072, 0.028495624646893702, 0.020628130114346277, 0.03286850347649306, 0.06995186398853548, 0.044800698160543106, 0.02356529457756551, 0.023053793411236256, 0.028578251658473164, 0.044369829483912326, 0.03366098360856995, 0.02048218306299532, 0.03567110172298271, 0.05736316918046214, 0.027288810888421722, 0.05523584739421494, 0.018550092499936, 0.03203381740604527, 0.012762709884555079, 0.0442512083100155, 0.016451504816359375, 0.005187354827285162, 0.013348373868211638, 0.04575736362312455, 0.03127963580482174, 0.04962818697094917, 0.10048989759525284, 0.01444375971914269, 0.03389906087249983, 0.018709138457779773, 0.01562503803143045, 0.043931624677497894, 0.03951370119466446, 0.03877202849253081, 0.010680271334422287, 0.06676588338450529, 0.026656319241737947, 0.04748890547489282, 0.033455698139732704, 0.015044733281683875, 0.032076865682029165, 0.0105513055495976, 0.019261895613453817, 0.0031180284031506744, 0.06233233027160168, 0.040159180425689556, 0.04592435056110844, 0.04107432272576261, 0.025922338900272734, 0.08667250309372321, 0.023392363036691677, 0.07604155674926005, 0.024999333545565605, 0.03156919214234222, 0.10867351549677551, 0.100984821037855, 0.017088942877308, 0.056653516439837404, 0.057603940440458246, 0.011728782210411737, 0.029513250119634904, 0.05829382236697711, 0.06958374389796518, 0.03814922929450404, 0.008963677264546277, 0.10167492189793848, 0.016758529454818927, 0.08316135048517026, 0.07618942967383191, 0.12291196748265065, 0.019969442510046065, 0.050622664857655764, 0.03414839651668444, 0.08012578095076606, 0.0810502000967972, 0.02712559962674277, 0.022852667680126615, 0.057796078763203695, 0.014092929814069066, 0.11992887521046214, 0.04520752125245053, 0.07847777524148114, 0.008668501941428985, 0.06610353142605163, 0.04311678734666202, 0.016782933125796262, 0.0526181589521002, 0.04414449489559047, 0.05448478652397171, 0.014563804888894083, 0.01945781332324259, 0.022378292451321613, 0.054864139019628055, 0.04966975837305654, 0.024809340029605664, 0.03510919945256319, 0.0014641964867223578, 0.07455467130057514, 0.02232249222288374, 0.1665345099172555, 0.022686122320010327, 0.036252752543077804, 0.025155286602966953, 0.04479514689592179, 0.05537029115657788, 0.0949692317226436, 0.04340169041824993, 0.03469607181614265, 0.03233446885133162, 0.01792751223547384, 0.02166091766412137, 0.06290936493314803, 0.03777504214667715, 0.009428601242689183, 0.02768677830317756, 0.03453164899838157, 0.09965278470190242, 0.021977861106279306, 0.04142529549426399, 0.03922457530279644, 0.02704428436118178, 0.05413340186350979, 0.020398116284923162, 0.03462392764049582, 0.026545624205027707, 0.04156200651777908, 0.06342316861264408, 0.06945865490706638, 0.029145783119020052, 0.05808413596241735, 0.042990280853700824, 0.037403459937195294, 0.029792698405799456, 0.04965324558725115, 0.05868224390724208, 0.030996179921203293, 0.01911637715238612, 0.018935374755528755, 0.01839834927523043, 0.015970808344718534, 0.027179069511475973, 0.018973907062900253, 0.04349239570728969, 0.06125655010691844, 0.02557530693593435, 0.03861581011733506, 0.006999326005825424, 0.06517704910947941, 0.036097005431656726, 0.009240165309165604, 0.0484736686485121, 0.010137072113138856, 0.05508381473191548, 0.04337820515502244, 0.04444005520781502, 0.05774873345217202, 0.0226700381244882, 0.003382590598448587, 0.06757037146599032, 0.060290058609098196, 0.04940530146996025, 0.015043707262520911, 0.10175134084420279, 0.0497703342261957, 0.03843078899080865, 0.0548648366384441, 0.0333373367175227, 0.039179898012662306, 0.043177142506465316, 0.026082928525283933, 0.0561503032076871, 0.055463356475229375, 0.05098354158690199, 0.11162214243086055, 0.018365475843893364, 0.04789854501723312, 0.07739362365100533, 0.08678472324390896, 0.02529089182644384, 0.03809538276982494, 0.10258736278046854, 0.04794931533979252, 0.044551856044563465, 0.028465654868341517, 0.04302335837564897, 0.1484797045122832, 0.26231087918858975, 0.13144796452252194, 0.11601629492361099, 0.1729784594499506, 0.1479903917061165, 0.18128217168850824, 0.09397967427503318, 0.09297886586864479, 0.09230567113263533, 0.19923086481867358, 0.11823553169961087, 0.10177838470553979, 0.060414880426833406, 0.1274176870356314, 0.18164393899496645, 0.23392316652461886, 0.18977557687321678, 0.11612553164013661, 0.2028586162487045, 0.1494526452734135, 0.1399013531045057, 0.13266250403830782, 0.11476909348857589, 0.16973837628029287, 0.11621610334259458, 0.15811572025995702, 0.13652223598910496, 0.13670539803570136, 0.15047035238239914, 0.08146703476086259, 0.18983067391673103, 0.06182204066135455, 0.09270510243368335, 0.0880982652597595, 0.1254053832963109, 0.21946967724943534, 0.1230700004089158, 0.0942625587049406, 0.09347238665213808, 0.15963314508553594, 0.13434429973131046, 0.16418967948993668, 0.1383435257594101, 0.15368658292572945, 0.1509614463429898, 0.1395481056533754, 0.10963735752739012, 0.1560696488013491, 0.2608732500812039, 0.10527824924793094, 0.14109051116975024, 0.13238580169854686, 0.1474718828103505, 0.11683701377478428, 0.06525501172291115, 0.20146055845543742, 0.09540329163428396, 0.19152894528815523, 0.14508136577205732, 0.2803758520167321, 0.06739951422787271, 0.14970726129831746, 0.16699001047527418, 0.11891074507730082, 0.1618632988538593, 0.12231439017341472, 0.21214893960859627, 0.10791446169605479, 0.12340556990238838, 0.1577145597548224, 0.11119714414235204, 0.19746532518183812, 0.14594074309570715, 0.19649492256576195, 0.09904023085255176, 0.1339633998577483, 0.16318748326739296, 0.1484486085246317, 0.16049635189119726, 0.07172338533564471, 0.19220097485231236, 0.1873413918656297, 0.13612184731755406, 0.15748761099530384, 0.12692111602518708, 0.18527641048422083, 0.1979823349392973, 0.15518410335062072, 0.08913884536013938, 0.2706632763147354, 0.07854027149733156, 0.11865350184962153, 0.24760623229667544, 0.11832605145173147, 0.16518611664650962, 0.19175043184077367, 0.10412694813567214, 0.10743416598415934, 0.1043825586384628, 0.14715667784912512, 0.18349761608988047, 0.18502741993870586, 0.17863660817965865, 0.15300941769964993, 0.1528589249937795, 0.1915302811539732, 0.2274037554161623, 0.09281261736759916, 0.1010281550406944, 0.1757784787332639, 0.08338844767422415, 0.11604214392718859, 0.19464286335278302, 0.07202195876743644, 0.08753891597734764, 0.09040179516887292, 0.19479341543046758, 0.13907909800764173, 0.1851512843859382, 0.0897690474812407, 0.18397731066215783, 0.13269275397760794, 0.11108727660030127, 0.2174628060311079, 0.1389758355799131, 0.12504407612141222, 0.14730648777913302, 0.07153536964324303, 0.16785376647021621, 0.08834924476104788, 0.13377090159337968, 0.101434718380915, 0.12638608692213893, 0.18857693416066468, 0.070091358065838, 0.10670192597899586, 0.18144862056942657, 0.1490179990651086, 0.21215609391219914, 0.2010746713494882, 0.12945164664415643, 0.11856365003040992, 0.15221677429508418, 0.15894256182946265, 0.15357123833382502, 0.19426160724833608, 0.15920784993795678, 0.06852709630038589, 0.17164293501991779, 0.19239642686443403, 0.17916574463015422, 0.08833287298330106, 0.21053145843325183, 0.08508768383762799, 0.08711585469427519, 0.13194100291002542, 0.11136691784486175, 0.1366445270832628, 0.17855106823844835, 0.15703156124800444, 0.08158556316629983, 0.1564753067214042, 0.12127726105973125, 0.16870882449438795, 0.08849318430293351, 0.17237479652976617, 0.1366686320398003, 0.21900638414081186, 0.13197888212744147, 0.16369196557207033, 0.10931457523838617, 0.16506961430422962, 0.12599904206581414, 0.11244699504459277, 0.11561012492165901], [0.05689528217772022, 0.020333319371275138, 0.01908994741825154, 0.043229322909610346, 0.055741572796250694, 0.035228002452640794, 0.09517937083728611, 0.072774852742441, 0.02536335141485324, 0.04416168303578161, 0.05044920268119313, 0.08908451272873208, 0.04112925278604962, 0.06494612243841402, 0.09078014205442742, 0.0844008855347056, 0.02883695506170625, 0.04363657644717023, 0.060601463774219155, 0.09106272962526418, 0.02257054395158775, 0.049287337096757255, 0.04594516780343838, 0.008532782612746814, 0.04348547518020496, 0.024227188259828836, 0.04346538524259813, 0.08318887674249709, 0.0073775597138592275, 0.012787508749170229, 0.04398539698740933, 0.047312359674833715, 0.0013665155893249903, 0.04019598723971285, 0.024326224156538956, 0.09574873169185594, 0.019332689080329146, 0.005580218585237162, 0.041929095023078844, 0.07359916358836927, 0.013594380052381894, 0.016854214554768987, 0.04065075307153165, 0.021234566811472178, 0.029617126674565952, 0.041008019252330996, 0.05385606869822368, 0.010656970680429367, 0.06067168578738347, 0.027842864947160706, 0.08773234934778884, 0.01837599578720983, 0.025808131649682764, 0.031662821493227966, 0.006936991167094675, 0.01381987420245423, 0.028151216174592264, 0.058268752618459985, 0.01178999176772777, 0.05557946176850237, 0.045630382155650295, 0.014575946424884023, 0.02105499675963074, 0.059994776602252387, 0.03837335047137458, 0.0262660553198657, 0.0409577795653604, 0.004530657570285257, 0.05872147754416801, 0.05432970363472123, 0.033238267424167134, 0.06514155960758217, 0.04171939377556555, 0.04019667743705213, 0.004737918079626979, 0.017812917212722823, 0.0675687387411017, 0.04396699914650526, 0.01975777828192804, 0.04689586639869958, 0.016265967897197697, 0.05106951568450313, 0.03200893690518569, 0.041997309526777826, 0.046439501238637604, 0.017688679836282972, 0.032486412455909885, 0.037548022883129306, 0.024828515270201024, 0.02306655835127458, 0.07633453438756987, 0.046566182136302814, 0.08423418432357721, 0.03396628089831211, 0.04297482191759627, 0.050279896531719714, 0.06059435771021526, 0.011585764787014341, 0.05886168779397849, 0.03775017277803272, 0.040483654811396264, 0.060976730746915564, 0.09872541180811822, 0.017562173343321774, 0.07983163071912713, 0.03171067888615653, 0.045324966122279875, 0.08111262213787995, 0.017129885309259407, 0.020647181045205798, 0.009568206642143195, 0.0630071948398836, 0.07829130321624689, 0.03943908195651602, 0.048241710392176174, 0.0784572029078845, 0.01805288324248977, 0.02296914219186874, 0.017331617746094707, 0.05190675474295858, 0.026634939822542947, 0.024841300619300455, 0.032928491273196414, 0.020397223852341995, 0.02984693641337799, 0.023699118646618444, 0.046117423989926465, 0.027493816196511034, 0.016793757349660154, 0.024607219820609316, 0.01258568076082156, 0.06205340519954916, 0.01893805576401064, 0.04080606231582351, 0.01749392173223896, 0.03393641687580384, 0.03897109847457614, 0.061057806669850834, 0.04169225714576896, 0.017384690581820905, 0.02727086019149283, 0.04820295544050168, 0.02632832150993636, 0.05665667056746315, 0.030710013343195897, 0.02500693499314366, 0.033118703722720966, 0.008718648859940004, 0.0661470732302405, 0.007726760140940314, 0.045895573784946464, 0.042339480423834175, 0.16164340049726889, 0.015444987438968383, 0.05597845520242117, 0.09814074786845595, 0.03673524501209613, 0.003420136545173591, 0.01768830876244465, 0.0595108814741252, 0.016707861177565064, 0.005537533497772529, 0.030669321386085358, 0.010911479093920207, 0.03368381949258037, 0.036483979783952236, 0.012500394077505916, 0.05482458625920117, 0.06233995212824084, 0.01781656486855354, 0.021055015313322656, 0.020557243879011367, 0.08799299161182716, 0.037722887718700804, 0.028431933533283882, 0.04422733712999616, 0.04060062470671255, 0.014544709429173963, 0.020275353926990647, 0.040097853052429855, 0.03732790930371266, 0.06817407891503535, 0.037351201608544216, 0.04268515054718591, 0.03163647896144539, 0.04828239863854833, 0.027954008983215317, 0.015139340412133606, 0.05592627851001453, 0.022268198554229457, 0.052160921768518165, 0.06274181767366827, 0.050610122561920434, 0.027753764552471694, 0.037820283469045535, 0.0885321841633413, 0.07667522470001131, 0.048756753458292224, 0.06472335939179175, 0.05042742064688355, 0.029831119391019456, 0.03251141541113611, 0.04203604221402202, 0.09565774438669905, 0.00989017627944122, 0.046377190519706346, 0.0988170225173235, 0.05883910424017813, 0.027184867540199775, 0.02327086047444027, 0.15301128791179508, 0.08498777591739781, 0.01918046902574133, 0.023374737029371317, 0.02397693049715599, 0.06368202230078168, 0.027084959619969595, 0.01933698611537693, 0.04806468219612725, 0.044643054861808196, 0.05200493716984056, 0.029903872127761133, 0.019587670612963848, 0.05665042539476417, 0.059276084502926096, 0.02485484852513764, 0.03884843259584159, 0.013613250084745232, 0.0793185320799239, 0.08695155804161914, 0.019013971905224025, 0.030065281825955026, 0.020435450023796875, 0.052570791376638226, 0.03791683688177727, 0.03747876937268302, 0.06152668072900269, 0.01323163218330592, 0.051744294905802235, 0.04148238149355166, 0.031713933203718625, 0.06102245817601215, 0.0371007824287517, 0.026533273012319114, 0.04362388572189957, 0.02985989431181224, 0.04653782467357814, 0.05305490172759164, 0.07585536674014293, 0.02661277187144151, 0.03499696445942391, 0.044534827466122806, 0.08048414922086522, 0.021024049201514572, 0.031202318859868683, 0.03904512028384488, 0.027360123858670704, 0.05000855620892253, 0.03459413783275522, 0.03732863660843577, 0.03770870898733847, 0.07322993769776076, 0.05443894406198524, 0.06759889962268062, 0.01626965451578144, 0.020278047923056874, 0.09379836017615162, 0.03037266640603775, 0.04766420446685515, 0.027016735839424655, 0.16536110022570938, 0.01783993880962953, 0.1098276293487288, 0.0334489483066136, 0.008602108482591575, 0.0032534102865611203, 0.03484913977445103, 0.04330898133048322, 0.03821503181825392, 0.027886597854376305, 0.059521457078517415, 0.020559158620017115, 0.09101580362766981, 0.04329496958234813, 0.013595984946732642, 0.02596850234112935, 0.06083789347030688, 0.03510658338200301, 0.04513832711381838, 0.011246273970755283, 0.0405119751667371, 0.06647103553405032, 0.021366728469729424, 0.029371089876804035, 0.029596314998343587, 0.04817236040253192, 0.040199564391514286, 0.03776602134166751, 0.026803450018633157, 0.03193469616235234, 0.04468697516131215, 0.03073541149205994, 0.026554203432169743, 0.02944468866189709, 0.017729664941725787, 0.011259465645707678, 0.022659095156996045, 0.08583124159486033, 0.03875751579471398, 0.04172788765572477, 0.05171368131414056, 0.014043954561202554, 0.02023711847868981, 0.01838489784859121, 0.011693361357174581, 0.044750387969543226, 0.03825078107183799, 0.05328822182491422, 0.03373497944267001, 0.041138670640066266, 0.07462755762389861, 0.056185388239100575, 0.033507158659631386, 0.04761030970257707, 0.05581583209277596, 0.04079254038515501, 0.07094548098393716, 0.06981072976486757, 0.12616281921509653, 0.09617419753340073, 0.03524925385136157, 0.06228917438420467, 0.032999355244101025, 0.025886652729241177, 0.019554465070541482, 0.041442902947892435, 0.032989900282700546, 0.02956002212158637, 0.04799746588105336, 0.02717417875828687, 0.025138773817161564, 0.008174374452210031, 0.02509597787138773, 0.07733687161817215, 0.029076217906549573, 0.032528124866075814, 0.03637464287749026, 0.06756244532880373, 0.05778817860118579, 0.013600885904452298, 0.019451634943834506, 0.06834337022155523, 0.16102502821013331, 0.12313930958043784, 0.1505312233348377, 0.15704205521615222, 0.1327571872388944, 0.17608329362701625, 0.16712520009605214, 0.16659680579323322, 0.08367590373381972, 0.1599249872379005, 0.16605027340119705, 0.26818506710696965, 0.12828105711378157, 0.13642845820868388, 0.19987775041954592, 0.17976701783481985, 0.09002253544167615, 0.1400014985119924, 0.18084849027218297, 0.12949279131134972, 0.14083455927902833, 0.06887599476613104, 0.27668939670547843, 0.09477957588387653, 0.1302567432867363, 0.10765761180664413, 0.15170889295404777, 0.2149462277884595, 0.11480047891382128, 0.1086786956875585, 0.09550811257213354, 0.11627696687355638, 0.13211070239776745, 0.16463611100334674, 0.2293042471865192, 0.16228755499469116, 0.10409018213977106, 0.12794024805771187, 0.1286144446930848, 0.17082253529224545, 0.119905712781474, 0.08298795510199852, 0.1399528284673579, 0.1450917261536233, 0.14092835190240294, 0.13954138179542497, 0.17311315925326198, 0.1302285268320702, 0.22884236415848136, 0.08173681286280043, 0.25460890028625727, 0.06857258253148757, 0.1483334568911232, 0.19101287063676864, 0.0902203177975025, 0.13333420705748722, 0.12330777710303664, 0.14048767945496365, 0.10947194023174234, 0.06302226043771952, 0.2064236265141517, 0.16648532036924735, 0.21887545444769785, 0.17079752491554245, 0.13967722450615838, 0.1114964003500063, 0.12083334542694502, 0.09882367958198301, 0.17567266331752762, 0.18546985869761556, 0.10619184045935981, 0.1327137419139035, 0.2023499333881773, 0.11167926553753205, 0.1917894688085653, 0.11735714055248536, 0.14614636253099889, 0.13159884314518422, 0.08891436053090729, 0.07646659956662916, 0.12414903860189952, 0.13162753457436338, 0.2080696210032329, 0.1245639065746218, 0.15997459238860756, 0.2774948050500825, 0.20582496566930786, 0.14680172345833853, 0.12406496811308898, 0.15053503797389567, 0.17766501812729985, 0.18093750346451998, 0.16865818033693358, 0.12107597576687112, 0.16255048307357356, 0.1184142631245777, 0.27235534333158284, 0.044587935553863645, 0.17797596316086128, 0.16285739082377404, 0.08332371755386703, 0.17084808001527563, 0.11547560323379003, 0.2115399480680935, 0.19075071439146996, 0.20314155262894928, 0.18317734968150035, 0.14781929698074237, 0.1078382357081864, 0.13708616432268173, 0.12457342090783641, 0.1970495592104271, 0.19304527173517272, 0.10652611861587502, 0.28782449138816446, 0.1638148503843695, 0.14386632159585133, 0.1293328288011253, 0.14411694486625493, 0.13873420713935047, 0.1842953951563686, 0.22041027521481737, 0.22643284813966602, 0.1349337727879174, 0.16664886003127322, 0.07390739978291094, 0.2530803135596216, 0.2077747805742547, 0.058565010549500585, 0.1960948307532817, 0.1043327160004992, 0.1838075221166946, 0.13316579890670255, 0.11223052541026846, 0.17790992686059326, 0.08867288794135675, 0.12140887352870777, 0.12774423201335594, 0.1418077078415081, 0.09440572641324252, 0.14056845480808988, 0.19419141492107883, 0.1656603638548404, 0.17755532870069146, 0.13696071167942137, 0.08548635814804584, 0.10492781453649513, 0.1995909251854755, 0.14300038368673995, 0.1094227061548736, 0.11500851775053889, 0.19386976811802015, 0.23173795721959323, 0.13093940040562302, 0.12405614397721365, 0.138798670086544, 0.09969231890863739, 0.04805825148650911, 0.09248293310520239, 0.11835069817607291, 0.14871112100081518, 0.1202190772164613, 0.20796462194994092, 0.08075890713371336, 0.07738620959571563, 0.10876451764488593, 0.17638516961596906, 0.16519925266038626, 0.1410086522810161, 0.17147135047707707, 0.11403150259866379, 0.13029840745730326, 0.09800420011742972, 0.20519755402347073, 0.06186616505146958, 0.1709338277578354], [0.021403639184427448, 0.04318452687584795, 0.021730959706474096, 0.06582225003512576, 0.03415510553168133, 0.05794401848106645, 0.04396782664116472, 0.04587331677612383, 0.07299027594854124, 0.007669143506063847, 0.06850789693999104, 0.05712400467018597, 0.011807227219833294, 0.03829321707598865, 0.01239452300069388, 0.042483857832849026, 0.045521475694840774, 0.04520415561273694, 0.02395373652689159, 0.06071686031646095, 0.0500480458867969, 0.05407577409641817, 0.018721497071965132, 0.02515943891921779, 0.03374446780071594, 0.033878043250297196, 0.028201099630678073, 0.06925024499651045, 0.05756959013524465, 0.02323184391570976, 0.057656302669784054, 0.020921571594954003, 0.026928702282020822, 0.030915888819436077, 0.012708393951470498, 0.04700241654063575, 0.02127783216565149, 0.016446647459815722, 0.021591801450995263, 0.1370023313211277, 0.0738222234940622, 0.03289671993115917, 0.016489421141159255, 0.06237666617380455, 0.04462519136723131, 0.041339885428897105, 0.02297483260917943, 0.016736699180910364, 0.023232821695273742, 0.045124404423404485, 0.03122971895209048, 0.03801618819124997, 0.03423866393859498, 0.018611950508784503, 0.0240714096071315, 0.018125532078556716, 0.04552498234261293, 0.05360413924790919, 0.023840238027332816, 0.04396149983222131, 0.08430494810454547, 0.012469581961340737, 0.0181831450026948, 0.04993543610908091, 0.08317712854477577, 0.07482386310584843, 0.058704786642920226, 0.04842653484956827, 0.0798839372873772, 0.02662686340045184, 0.037523198043345474, 0.05038763410993852, 0.009922340959747089, 0.059856091465917416, 0.08252452840679325, 0.03605371595767792, 0.04352130607003346, 0.02983298218168784, 0.022561940604646225, 0.023541338050563354, 0.05970827420242131, 0.0533949463715544, 0.03775946817768272, 0.059006736846640706, 0.01253157262908644, 0.03151535303913988, 0.012703781503660139, 0.02139933658327209, 0.02245705843961332, 0.025506639722152613, 0.014990977670095162, 0.02113644004566595, 0.0163632152180071, 0.049493568803882226, 0.0467339446186088, 0.0557679969642777, 0.09398779337061569, 0.0998234935104847, 0.027018821274396032, 0.06139873818028718, 0.07132810264010914, 0.06553045983309858, 0.07389499849523418, 0.02667950579052558, 0.06530916623887606, 0.012452936516638147, 0.09125767697696574, 0.08461311008431949, 0.01916489320137771, 0.012729160171147669, 0.021064345964987297, 0.015727007266832516, 0.047216273815138265, 0.05398003704613075, 0.10111423674970865, 0.015735157903691288, 0.029097745755279902, 0.013208441923779901, 0.018337467190576717, 0.021561312169069424, 0.006705583955408656, 0.05536169708648231, 0.0015998203798517352, 0.07255772259668447, 0.019878913481079508, 0.051785951654892415, 0.05925281817326322, 0.041157569430652075, 0.05519642450963147, 0.047159432724583894, 0.03125021336018108, 0.01773760963260429, 0.040131672722054645, 0.021963700928608887, 0.016349494762835093, 0.010609580840537092, 0.02229413661552826, 0.010006589564000024, 0.039304122401517816, 0.024529997499485034, 0.06908904309966601, 0.033296782057732344, 0.057075791046372615, 0.04316038110118825, 0.04116764037462417, 0.07284940889803693, 0.02504692933143815, 0.019018803286598995, 0.015242254030454205, 0.05751969925768208, 0.014925266987120267, 0.024874283517419826, 0.010903332167799817, 0.020565617160173133, 0.028350525499263313, 0.07503867775085382, 0.03577214512915816, 0.023597991748829372, 0.04467423619644251, 0.027274112653685734, 0.025803647222346626, 0.07416473206831142, 0.06755995913408697, 0.03956273489166051, 0.014415039531741058, 0.045977866830071434, 0.03432184756093193, 0.015395315494970419, 0.031807436389499344, 0.03792907860770356, 0.013376511469687102, 0.037571879220195115, 0.015874030432314612, 0.014214060374797555, 0.05249755624390673, 0.02976945248519769, 0.0683755571662914, 0.07812244235537946, 0.04088521978701465, 0.058029309802805074, 0.0054509744950337335, 0.061936735874041915, 0.016574981491430663, 0.05157045423402451, 0.03999269814812578, 0.05899117029912304, 0.05961429975286592, 0.02016828799241921, 0.05139097323990427, 0.049782089845393784, 0.012649832933675498, 0.05309885542374104, 0.019757253212446813, 0.04843718095798977, 0.07635073547135107, 0.06303344460320659, 0.0519625679589808, 0.06821333852712996, 0.08991144335595891, 0.029996358571224846, 0.03997406653070357, 0.11088861108873971, 0.016697957216820214, 0.007234691647681757, 0.009870243120531086, 0.016589176921115723, 0.09435005049454048, 0.04023211498861201, 0.006381208368111402, 0.015706421945651527, 0.02509368092432851, 0.031042196787893772, 0.0028463167745940154, 0.1015596960496623, 0.013375953931245022, 0.06894364894833416, 0.019850390890496783, 0.040475658170180395, 0.032427300393464975, 0.045539769635070115, 0.044635262311203405, 0.027692195981217083, 0.032771571568446234, 0.04957735356583726, 0.028299148470978253, 0.024592185764049646, 0.014575317454728065, 0.04207844482152723, 0.023397465301968623, 0.03631642881373409, 0.059637169033521786, 0.03577989315090235, 0.03716021732543595, 0.014340257021103753, 0.02812369362800382, 0.01499790561865666, 0.02322063377505401, 0.026483515721338335, 0.015175057196756825, 0.06002156442264095, 0.015261994230968412, 0.049771039266488515, 0.009208191731886473, 0.013255810426926473, 0.03500643426377792, 0.008299721339426469, 0.05164945214346517, 0.028717870045511518, 0.05193127901293337, 0.018751108764263336, 0.0951772260305006, 0.021154466812731698, 0.08568476390792057, 0.007623831679666182, 0.018021915275312494, 0.01978291111299768, 0.01780107253580354, 0.05427902979135979, 0.01663371320319129, 0.046059874148340896, 0.018398996799078304, 0.04058311002154369, 0.05175525642698631, 0.057678760058479384, 0.008664551860420033, 0.05150933837285265, 0.006669644062640145, 0.060488026501843706, 0.027944403736910317, 0.03983990478445776, 0.04314506317314226, 0.009568352288624737, 0.06817104353103787, 0.03869595464493614, 0.02520280260796426, 0.05097549670608714, 0.05544175255636219, 0.09426836972124875, 0.04359880113042891, 0.05403423238021787, 0.015717444694018923, 0.03305282327346504, 0.10405917520984076, 0.01923529889609199, 0.05210544251895044, 0.05562082165852189, 0.021584537680610083, 0.02002771037950879, 0.025467970117460936, 0.011112484226032393, 0.0360812088183593, 0.07857121163397096, 0.017458178044762462, 0.013613643423013855, 0.08775281778071076, 0.061347696973825805, 0.031047317606862634, 0.04155132330197375, 0.014168109373713378, 0.06463824247475713, 0.03216129982320126, 0.04194357432425022, 0.01939548961672699, 0.03376160399056971, 0.04429364431416616, 0.028772080222552177, 0.04261880625563208, 0.003690647286020976, 0.015692957531427965, 0.00557135966118949, 0.010687857011362212, 0.023098205383575987, 0.03686168471176643, 0.033840067553683184, 0.057700196994119324, 0.027752029782277532, 0.025868538759823423, 0.05370108970964793, 0.030877326826157514, 0.05043345801823307, 0.016658949934935663, 0.042819382797461, 0.05179092775506433, 0.04782616706506815, 0.015823874236957636, 0.046323874630616046, 0.006525981898448663, 0.033979268482653424, 0.07026731385849416, 0.05064052093075588, 0.023366577115666587, 0.03465479356236756, 0.047088813662412576, 0.0076923309825360775, 0.017058088087651413, 0.0388678842864465, 0.04472370776056778, 0.06399492660420947, 0.0666688104683999, 0.025672673000372015, 0.058383099021739326, 0.03850378292554524, 0.07319962096516974, 0.05341106952982955, 0.06745257778675295, 0.05777931735792663, 0.0204283625134849, 0.04987984553736169, 0.01171109126516967, 0.016404239286202937, 0.014554891695297556, 0.018295769623364322, 0.11221114051295444, 0.25104513682890683, 0.1148876293154899, 0.19250252429628745, 0.16016014415072277, 0.14929545839549974, 0.15000458050053567, 0.1306623566779308, 0.16895949229365215, 0.10295685584424064, 0.13409250386757776, 0.14732769835973158, 0.22460241510998458, 0.09469560187426396, 0.08918048726627603, 0.11261016363278031, 0.17898332473123446, 0.15775622392538935, 0.16825457074446604, 0.1664742623688653, 0.2836312382714823, 0.14020837959833443, 0.15411521773785353, 0.12494032387621701, 0.10477721050847322, 0.32258268096484244, 0.1266767267952673, 0.12861730938311666, 0.12427856563590467, 0.1202737660787534, 0.18054931570077315, 0.10176958283409476, 0.17463778291130438, 0.08591384263127111, 0.10590957943350077, 0.19814718078123406, 0.10325243842089549, 0.14859883405733854, 0.10274177402607165, 0.19880004809238017, 0.18006075988523662, 0.11885784479090944, 0.0759838696103543, 0.1773246840457432, 0.15068955312017351, 0.11259297549258918, 0.0745846243808046, 0.17621699895244092, 0.09030688932398334, 0.10487086954526603, 0.11254279146669433, 0.09186558498186059, 0.08848914701957256, 0.11609538560151123, 0.16548871994018555, 0.10516358743188903, 0.08670789611642249, 0.10815725530846976, 0.20340897812275216, 0.11723309056833386, 0.16198924131458625, 0.1310954146902077, 0.11483013513498008, 0.0941114871238824, 0.17134398309281096, 0.20809762965654954, 0.1261586631881073, 0.19756889931159094, 0.19607324909884483, 0.1430999650619924, 0.10135617689229548, 0.14241068798583, 0.132605581311509, 0.1760231054504402, 0.25851737649645656, 0.1574989064829424, 0.2328322094399482, 0.09538160607917234, 0.07521968756918795, 0.12378726387396455, 0.16750782175222412, 0.1989994928590022, 0.08170624379999936, 0.12653586716623977, 0.16333042090991512, 0.12818514194805175, 0.26434878702275455, 0.11763423623051494, 0.1588205379084684, 0.2850608224980533, 0.09468270334764384, 0.16979203355731443, 0.10431511225760914, 0.14852136868285015, 0.12162693878053688, 0.12587298086145893, 0.2311300195287913, 0.3230867179809138, 0.14853898726869375, 0.15861724881688133, 0.14799172757193446, 0.20236517710145563, 0.1464487728662789, 0.16087434254586697, 0.1376663605333306, 0.2007679417147301, 0.19036794430576265, 0.13599667669041082, 0.14201708254404366, 0.13319873542059213, 0.09636162692913786, 0.10389078190200962, 0.12914450140669942, 0.10335452083381824, 0.17528867610963061, 0.17595880577573553, 0.07186540271504782, 0.12953567260410637, 0.2173431421397254, 0.20093796774744987, 0.12931840145029128, 0.11636160881607793, 0.10252578678773716, 0.18366672185948119, 0.10544761476921849, 0.1332113816170022, 0.1576825583470054, 0.14947669085813686, 0.12880128779215738, 0.1278187584830448, 0.18001060554524884, 0.07447039301041514, 0.12850858474848792, 0.11642003068118356, 0.08719745383132249, 0.11780999164329842, 0.12955167330801487, 0.1938091791816987, 0.11484599483083002, 0.1557882857741788, 0.15257402934366837, 0.19601959182182327, 0.13093021261738613, 0.1317367935553193, 0.07327618091949262, 0.14324737043352798, 0.16507056425325572, 0.12301734503125772, 0.11499458021717146, 0.13745202828431502, 0.06609698568354361, 0.0748983005178161, 0.09067946972209029, 0.11421936244005337, 0.16138213482918218, 0.16670462500769645, 0.2320651404443197, 0.12055429047904909, 0.1354306109715253, 0.15082701371284202, 0.14603159681428224, 0.18597760645207018, 0.22096857806900516, 0.12820902426028624, 0.12211224398924969, 0.23045540729071945, 0.22966460441239178, 0.10748165601398796, 0.21072224975796416, 0.14434134063776582, 0.08665012734127231, 0.13651199435116723, 0.09726392265292816, 0.13269610848510638, 0.055655747128184885, 0.13464693271089345], [0.03423571019084193, 0.04583119247399736, 0.0038849995280543226, 0.04601487402396742, 0.07206708876765333, 0.02435541282466147, 0.033618929810472764, 0.05504050299350638, 0.014429589336941717, 0.07765870395815, 0.045311332869459875, 0.017546545568620786, 0.016741280087444466, 0.07329379950533621, 0.028708708232443314, 0.08500208452460356, 0.009719426652736729, 0.052506747742882, 0.06065670553653035, 0.050598704619915225, 0.05144930233655032, 0.02338112135475967, 0.06951423434657045, 0.0295483963782317, 0.08847722070640884, 0.0067215248236607295, 0.014933123547962168, 0.027773926849476993, 0.024609281135781202, 0.02208542799053248, 0.016515518764208537, 0.023949636160978116, 0.023013262871245388, 0.02049293863819912, 0.008921273729356471, 0.04952806753863115, 0.046822768563288264, 0.0894243644142989, 0.030074625465204008, 0.04721110104583204, 0.01895376517495606, 0.060618859715759754, 0.007599963746542926, 0.08789341765805148, 0.013965166308480548, 0.016586416131758597, 0.02916609384556068, 0.02346489498449955, 0.02279480057040928, 0.02844215661752969, 0.04609268820786383, 0.02336960878892569, 0.02568811338278465, 0.04870765296800528, 0.036064896412426606, 0.0240465773458709, 0.04765696110553108, 0.06674746327917092, 0.08340228872839361, 0.06690919210086577, 0.012082752327842172, 0.03810296380834188, 0.061958013247931376, 0.02728739709709771, 0.02901610580011038, 0.03982052359788213, 0.019451462394499686, 0.014600034683098784, 0.0029162611781430314, 0.025208326042047702, 0.030459725894615985, 0.03628578924690373, 0.03172495780745521, 0.014084287504374515, 0.02801827526127454, 0.10278946443577297, 0.04567663279885892, 0.03761369924177416, 0.045337590054259636, 0.041495291152386926, 0.05381440081691835, 0.012573839794640662, 0.04050050527439453, 0.026100007198692765, 0.017694926864351146, 0.11045207240385935, 0.034332412033108994, 0.06964108964893967, 0.06805215147323906, 0.09645092955906875, 0.059631680851452984, 0.053584821143886074, 0.05418237989943009, 0.03806219021498691, 0.03314792207675055, 0.03809903413639404, 0.02583462632173905, 0.053629268368240446, 0.045905158622190356, 0.02099340777931502, 0.030862027451803442, 0.029287238321558107, 0.09403503849171102, 0.048017741355579346, 0.028270785442146007, 0.041006193569046445, 0.040966566593851894, 0.01176908361230744, 0.04399023579026107, 0.03459729938185774, 0.03350601575220935, 0.0547700680908747, 0.00799188590463018, 0.023472958419006318, 0.041125805510091595, 0.026590431371005252, 0.01128378582507139, 0.01764450906193815, 0.028960841773368884, 0.03039745042769937, 0.02511290254915366, 0.04130902321776375, 0.034007878275588155, 0.05306308019498829, 0.01885995956399711, 0.030924347447580658, 0.017239812223124318, 0.07251342380186543, 0.03603766701417044, 0.06871830322779715, 0.051581809093477204, 0.026444532559253275, 0.002079670571220049, 0.02344109430850949, 0.021605341935355682, 0.038507909266627394, 0.031035632491693832, 0.03456956161244307, 0.05050391009717714, 0.03775039171159733, 0.051478676541591994, 0.013101301774440799, 0.02443803798087174, 0.06623109919019043, 0.03774879238335416, 0.031230308959493414, 0.07808604743331671, 0.04795161228685174, 0.0655578302394133, 0.06474774636444636, 0.024783144071989227, 0.030963397402956616, 0.06988308174186386, 0.039560385994263925, 0.03215336626453791, 0.004125313671465847, 0.019038989703403786, 0.07506219641072676, 0.07484410889446735, 0.06041979715519119, 0.08286119627882726, 0.023180717362265568, 0.04742470970086288, 0.05706908574211411, 0.04816270506125875, 0.05223463929723948, 0.04596876438881736, 0.016795488409115933, 0.069159116683295, 0.05343396849639248, 0.024634840701764915, 0.06962177896639332, 0.04224167649226729, 0.011600083598750643, 0.04180458861810621, 0.08597906256909482, 0.006498670400105766, 0.039129769647843204, 0.0384698408015538, 0.04507100318733137, 0.02361240425670985, 0.004112198066650308, 0.04096075557754375, 0.06637291618972085, 0.008784656401985558, 0.026873965180129744, 0.017573420591361355, 0.057872289908118546, 0.02496173448889749, 0.03780070932407398, 0.028462541558837984, 0.05083321586425882, 0.009505780890322058, 0.06273120496189222, 0.09060617521754466, 0.021672213151759934, 0.031709665854577906, 0.044457469703047536, 0.0724299915600568, 0.045440711473929696, 0.0545927467464935, 0.04214493012113962, 0.019405705279496033, 0.05054537017713301, 0.045451439218595624, 0.07538874138845131, 0.025676123987068422, 0.020193461641611066, 0.06831563616287895, 0.03726361333974637, 0.015518063009949401, 0.010069591407955159, 0.051785183532047085, 0.023418664750352036, 0.020308284874772653, 0.04629463772289455, 0.03816126692981925, 0.0756280543282628, 0.050921713263960555, 0.06581396766705438, 0.07223756751045585, 0.02604934819828486, 0.04502233314269688, 0.033763949177227914, 0.015699737050454132, 0.09539640450384468, 0.03944088537537027, 0.042734017260954715, 0.031022860130178742, 0.08491681175655685, 0.02647907953360118, 0.05302389479766134, 0.015379202541225823, 0.06002025453199167, 0.07578153788927011, 0.006120112466305727, 0.04727793886559084, 0.12315393731114455, 0.004337407881394029, 0.030005629851075355, 0.012244856861798326, 0.04296930776035879, 0.07174021724495105, 0.045346781553234905, 0.10303699295036495, 0.08408337249420583, 0.016756186123529915, 0.023710460518486798, 0.056344556651310995, 0.048146199696930125, 0.011080615477112588, 0.045497482060454786, 0.06322763496427797, 0.050432927382644266, 0.017577058970346116, 0.031772744696354493, 0.0706464251561556, 0.03615760178945493, 0.03750589115952607, 0.0430036320904037, 0.011117997455585282, 0.04512188854278065, 0.03247076427214779, 0.03743280074559152, 0.10036378444056027, 0.022847604377602693, 0.03492323950922582, 0.03245709762268234, 0.0602168012119364, 0.029282408795552328, 0.07844322826713324, 0.014764090137759922, 0.020939743080816697, 0.012133019845350645, 0.06322968329186551, 0.06357953170663677, 0.05175724167202134, 0.026242074673064053, 0.07371203682851046, 0.03050095219805371, 0.09697329020127654, 0.025337270490126684, 0.03062418953049928, 0.01027504386001965, 0.04409879715240095, 0.06261695874854922, 0.07836910997866653, 0.08509883089573123, 0.01936885208124295, 0.04475670735700987, 0.032780800174805336, 0.05041571697802283, 0.012110138504795032, 0.03876405411574524, 0.06336744816508144, 0.014783797869313275, 0.06083921078243293, 0.08001124529982917, 0.026640196083462797, 0.04436665680259466, 0.03856956318486482, 0.07596366092911921, 0.03378452893230133, 0.028149251338618342, 0.04949896792822983, 0.0444284405966755, 0.021081786435388494, 0.041970180318458006, 0.02578717339929426, 0.04513375919486862, 0.038253482489380985, 0.012244227891642367, 0.009592280985089019, 0.07034382928395644, 0.03490537230391055, 0.018110861674358603, 0.05187240814848337, 0.042067127069458365, 0.06307762465439737, 0.041486073678242974, 0.038584799476666376, 0.029079080741212238, 0.06130959140136838, 0.06298008418525569, 0.020453213328437414, 0.03551206689735409, 0.049757439410313964, 0.02315764213562943, 0.007931365616968833, 0.062417959270533174, 0.0643618666799739, 0.02331288458663039, 0.018413296129438095, 0.01274268488486996, 0.014090077183936955, 0.02830143057508394, 0.026327217565267347, 0.007167069470597198, 0.05062307303887792, 0.0655171531252563, 0.05626006313832477, 0.05340447183698416, 0.027176742878509685, 0.07162919937400147, 0.014281031781138154, 0.05700352070562076, 0.018185879816883244, 0.01873705434263684, 0.03951622078602668, 0.046461283272947185, 0.0222110884351423, 0.03877920506056398, 0.11999623995507136, 0.1779248588718474, 0.11889483343111351, 0.25015260034706444, 0.1541437755804509, 0.12879857153166085, 0.10953215809422545, 0.09826767738559283, 0.18985311646247283, 0.12678944418439642, 0.11230386444367468, 0.13378057919908315, 0.12091492972103879, 0.1292807745630853, 0.07329178086365573, 0.16370297904359177, 0.10634179881890304, 0.1896954100811854, 0.13210479490226135, 0.05799407634185627, 0.21098967525176704, 0.11209353237063624, 0.16041701630456373, 0.13554741017287597, 0.24940540606621653, 0.09180524095427245, 0.09689159458503127, 0.14255893940571696, 0.15747230791021138, 0.26226296613458544, 0.09968903119442984, 0.12872411927673966, 0.19605166744440794, 0.18946052034152672, 0.16184201405849308, 0.12072362631442957, 0.1470125379273668, 0.16535798320546746, 0.08329925636644475, 0.13817352941259742, 0.13095918606268242, 0.23607877898029983, 0.11477937223389745, 0.16470487840706483, 0.16020679555367678, 0.073964886541944, 0.12136809251387604, 0.09845659849816002, 0.08579379282309674, 0.21954279363853857, 0.18837253184756264, 0.20133427460677922, 0.09519217288470827, 0.2036431257147342, 0.06244291027542204, 0.16849288920639083, 0.14824248442891985, 0.13158299087081105, 0.1225009215704631, 0.15480762667721137, 0.08799506962532178, 0.1769812181009911, 0.12379962063278072, 0.1023184900986962, 0.12677765887929127, 0.11045101113268174, 0.1507346608559601, 0.13857253768946975, 0.13375791400903836, 0.13666175975231454, 0.08914667501812801, 0.10952649550745264, 0.14607827790314332, 0.1452157538733445, 0.11647049672319554, 0.2072244929149747, 0.14081187924603, 0.17424567660782486, 0.10664253932191059, 0.13967554725240916, 0.13467063690768555, 0.10741628022515215, 0.1332238645409234, 0.15623654297087342, 0.16393101133871824, 0.13915608840761706, 0.10038115811767057, 0.12136961391661316, 0.2669213677290827, 0.19885170157067478, 0.0993187959829811, 0.10967850219458342, 0.14380479755345732, 0.1272227248409763, 0.20805902313441038, 0.1479305003886111, 0.0898002325266134, 0.10765902188722976, 0.13989415427204221, 0.16091872297693044, 0.15238399500958622, 0.16281030897516757, 0.23564062983496115, 0.12497820309363306, 0.2112106274580583, 0.1259560717153363, 0.09444954281207174, 0.09477924191742204, 0.12052650447003543, 0.16951645928202197, 0.14619016408687457, 0.22345895849866793, 0.10179212928051129, 0.09428913501324132, 0.10916548519162461, 0.13368570304010063, 0.1501978060696274, 0.07206328155007213, 0.09756843326613307, 0.14828716171905398, 0.20838835858739913, 0.11546742476639338, 0.08957553989603184, 0.1614938280545175, 0.09907905259751715, 0.09899534576106817, 0.1569247365114279, 0.13532250974094495, 0.13170458434615284, 0.2206224255496636, 0.07615232228999957, 0.14726034103659913, 0.137063528818544, 0.10441288279253058, 0.05916185684327502, 0.2277814640547149, 0.13187545642722398, 0.14645695133367553, 0.1587972344714217, 0.08646307644085027, 0.17707931518089026, 0.12747702916385606, 0.12981624895473942, 0.23152276407927275, 0.08768878527916968, 0.14581365772755817, 0.18864690384361893, 0.10702312749344856, 0.12986808054847643, 0.14051393663976341, 0.25415568554308265, 0.10116506644408219, 0.11908814805792645, 0.12287626275792718, 0.1827406551456079, 0.07493880693800747, 0.10236235844786279, 0.17029235983500257, 0.11452758379164152, 0.14796229399507865, 0.1952878342126496, 0.15742000134196132, 0.1451184879988432, 0.13204864400904626, 0.1034674905531574, 0.21882439468754455, 0.16685345530277118, 0.14050326455617324, 0.19390035944525152, 0.09397843488841318, 0.05640464834868908, 0.07961146518937312, 0.11671901971567422, 0.11361322074662894, 0.11655393638648093, 0.19022405671421438]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.020406970106705558, 0.0419951461663004, 0.09269617439713329, 0.07230190429254435, 0.025103570042119827, 0.019977784249931574, 0.03003569054271793, 0.055062682076822966, 0.03044939148821868, 0.024807215631881263, 0.016731123796489555, 0.06697821183479391, 0.021103180697537027, 0.07264712170581333, 0.07539274156442843, 0.033588082442292944, 0.043280044992570765, 0.01376666221403866, 0.07328594758291729, 0.02560382581577869, 0.009414698033651803, 0.0295230334813823, 0.07210962867247872, 0.023529441423306707, 0.07397744368063286, 0.012181172241980676, 0.024896290051401593, 0.019687526582856663, 0.044601386980502866, 0.024953943793661892, 0.07394303771434352, 0.08371062140213326, 0.036262370776967146, 0.059388178488006815, 0.022267142849159427, 0.039065117452992126, 0.03767085203435272, 0.038453836386906914, 0.019049591282964684, 0.007319105843635043, 0.06639308776357211, 0.027780622876889538, 0.04585936439980287, 0.04538824905466754, 0.05378956855565775, 0.029265159428177867, 0.01265548067749478, 0.039488260372309014, 0.008397072560910601, 0.03542662343534175, 0.016775250041973777, 0.024919153765949886, 0.09163101436570287, 0.03531085581926163, 0.05723853661038447, 0.07115441039786674, 0.08893623162293807, 0.02733426372287795, 0.021737620481872, 0.06253313316847198, 0.05311256660206709, 0.04291322737117298, 0.0645489917951636, 0.04935500241117552, 0.025374774922966026, 0.029233863060653675, 0.0343862362933578, 0.02680327932466753, 0.08829201775370166, 0.061672278970945626, 0.06137257005320862, 0.01543140799185494, 0.0422320693905931, 0.062362142343772575, 0.035426189278950915, 0.03672855455079116, 0.03498663747450337, 0.011295838303340133, 0.03782789790420793, 0.015339951278292574, 0.06855577288661152, 0.05238243058556691, 0.01610114617506042, 0.02209295707871206, 0.039241358972503804, 0.06672989664366469, 0.06335571481031366, 0.046828609265503474, 0.04970750400389079, 0.026435168510943186, 0.037747207898064516, 0.03357113178935833, 0.016902238930924796, 0.06815674234530888, 0.0798317049338948, 0.05080200484371744, 0.04430109547683969, 0.02828843742463505, 0.06828167548519559, 0.026694339467212558, 0.02812384020216996, 0.02728893705352675, 0.02277500378113473, 0.008368680773855885, 0.03212907577108126, 0.039738019040669315, 0.057417583448113874, 0.03724356050952338, 0.03426161485549528, 0.0162717436614912, 0.017700522657833062, 0.07025348764727823, 0.04382641411211807, 0.021090632835694123, 0.07950464787427336, 0.005733466514357133, 0.0290435448550852, 0.030996298664831556, 0.10954490819131024, 0.013303779142006533, 0.06217298374394886, 0.014374493221112061, 0.04543740891676862, 0.0399956815817859, 0.04266602911229711, 0.058741393077070825, 0.030280705032055266, 0.05868046646355651, 0.07867798442021012, 0.05107107790536247, 0.024808063535601832, 0.012838459042541217, 0.04482704069232568, 0.055043560641934164, 0.03828980690741446, 0.0678935470932629, 0.08851455073454417, 0.03889754421834368, 0.03606215046602301, 0.038331070318236016, 0.03774134864215739, 0.0236055764980847, 0.07280991179868579, 0.02084505988023011, 0.04183918754279148, 0.01923427658766741, 0.02117645479302155, 0.0159544161579106, 0.014504782811854966, 0.03974208972067572, 0.021176321206439752, 0.028095935449528042, 0.06711015827022493, 0.03822265367489308, 0.060031794928363524, 0.03308587853098288, 0.06397861419827677, 0.07791031428496353, 0.025065395821002312, 0.05725162067392375, 0.035317182628205046, 0.052223614693502896, 0.04524316289462149, 0.04626992049452383, 0.02276255425385898, 0.043996818640152924, 0.046916835781303234, 0.059475495872902684, 0.04714631526439916, 0.032382727004005574, 0.016285107885778416, 0.0640109644155018, 0.04217841582430992, 0.014005393495608587, 0.012438568537618266, 0.059079445054521784, 0.029342550587898586, 0.06628955074120313, 0.03861290460918099, 0.028657470356847625, 0.004000448252554634, 0.009676434965513181, 0.027004675939679146, 0.0233338409816497, 0.04930459945171606, 0.04448265448445454, 0.03898770773957949, 0.03840951161691919, 0.051758525587501936, 0.09539142469293438, 0.007968358895595884, 0.027853767096530646, 0.018327995530853514, 0.04312326629587915, 0.034167414050898515, 0.052583804936148226, 0.05083258503873367, 0.045307685213629156, 0.06558805791428313, 0.06585742783499882, 0.01689942062512273, 0.045881688201916404, 0.03775628065341152, 0.04289633237931412, 0.03492779258522205, 0.006830548636571621, 0.012223097091919044, 0.03807302928180434, 0.0180161153912195, 0.06807045283494517, 0.015345539650297724, 0.06113188785093371, 0.007786254409438698, 0.03175056932377629, 0.019801368325715885, 0.036057653051102534, 0.043840177240781486, 0.03581912678782828, 0.0273732487403322, 0.023257692919287365, 0.054458150843856856, 0.03201578692824114, 0.04598045321472455, 0.04227173347317148, 0.02204345953941811, 0.054685530049027875, 0.04564995630062185, 0.05392410508648027, 0.023905623093014583, 0.09076771850232035, 0.12953012133948505, 0.04008712901850231, 0.04060819832375273, 0.022771244803152513, 0.10571400125627406, 0.0545520696323365, 0.06079019934986718, 0.07911246735602617, 0.04225130956911016, 0.022005873470334336, 0.0553838316409383, 0.03222677580197342, 0.020936295804858673, 0.028864985979453195, 0.05584080907283351, 0.09504139816272072, 0.03140353364869952, 0.009604174829291878, 0.07730154538876377, 0.03826725675025955, 0.021592079756374005, 0.012434160180418985, 0.0778919535514433, 0.03420647328312043, 0.0564163520175498, 0.04832637459912803, 0.06739038581144996, 0.031634096667403355, 0.05987125354295131, 0.05063085816800594, 0.051167063575121574, 0.021066062181489542, 0.07223482898552902, 0.015290614228433697, 0.04618447332177311, 0.026497182370803785, 0.08017189058591612, 0.05388542063883506, 0.08643350927741267, 0.12005268028588034, 0.058465985785005614, 0.031508825850323774, 0.05127351723785978, 0.026587236425257288, 0.012306016324146185, 0.06819974980317056, 0.010289384008501656, 0.04065697969053872, 0.04879762353084516, 0.019776996196014807, 0.02307940121681895, 0.010056112150778063, 0.020556097260850947, 0.032431649378850125, 0.02826457923220005, 0.02779849379294319, 0.029781970661133528, 0.015385122096631676, 0.04520540613157209, 0.06127474014647305, 0.06727280735503882, 0.01311968198933755, 0.03395064013602678, 0.04408412489283364, 0.08890783705282956, 0.02309388422872871, 0.010731280999607407, 0.03854941016470548, 0.04417294141603634, 0.03125199451460503, 0.035233442395110615, 0.027041844550694805, 0.02233280065411236, 0.019872505035891663, 0.11849240385345183, 0.011858048565045465, 0.03168775023368653, 0.017055796706699766, 0.07544351188698784, 0.04973215443897061, 0.0499210532871075, 0.06461291297455318, 0.03212473420717288, 0.04066491324920207, 0.014896245302224997, 0.02614403325424064, 0.04200860872515477, 0.01440362344510504, 0.04753600216645282, 0.03680513676954433, 0.06867350719403476, 0.04380303274956532, 0.014183348448568722, 0.026261173843522556, 0.03694720238854643, 0.049415509711252525, 0.04867188887146767, 0.022895795736985747, 0.006136544079708983, 0.021390736947068945, 0.029275794404384214, 0.012404258122842293, 0.029153965297155082, 0.026176928950008005, 0.034216885615023784, 0.057086370361503214, 0.022978569322731346, 0.07744529939373024, 0.05472539080074057, 0.02379084995482117, 0.07498548802686855, 0.043302513513481244, 0.04049899129313417, 0.07326261445996352, 0.017218395696545485, 0.05117735345265828, 0.04943682419252582, 0.05274899216601625, 0.03510986738547217, 0.05897324743273202, 0.02764611974271247, 0.07735156614216976, 0.09799694191315211, 0.11553586562513374, 0.17467725032474846, 0.24377194116823375, 0.11258881946559995, 0.11696347573888488, 0.17870685987873003, 0.08666753070428967, 0.15649372682673857, 0.14583779237000272, 0.12008826626697555, 0.20270585257094353, 0.16390686185332015, 0.18138852145057172, 0.18080413952702656, 0.1504001155262813, 0.1660198750323616, 0.14726210734806955, 0.11958366521866992, 0.2074281679233536, 0.1995132223237306, 0.09443651069886982, 0.18395339866401628, 0.1318267863825895, 0.16754491429310292, 0.1551081519573927, 0.16298493632348254, 0.0755402359936852, 0.15967424522386864, 0.201660018065013, 0.17446236888645217, 0.13173404760891572, 0.08480128904921003, 0.24307291227160022, 0.0686830141057726, 0.20063389500137419, 0.13029821449890733, 0.18834351387340575, 0.1599710449227132, 0.08870386518537998, 0.16399618674768135, 0.10801952754263766, 0.20297366398153827, 0.09005480402265675, 0.16711469128495082, 0.1113078132038936, 0.10959193066810258, 0.14272406726377085, 0.17982299061259255, 0.14277895650593564, 0.11338049807818606, 0.13039715762715787, 0.197331189410761, 0.28595481358934194, 0.25755537499208003, 0.1336562100914307, 0.1926727284444496, 0.06369344395352527, 0.19636979646747932, 0.11600454672588967, 0.09518400183878839, 0.1543305889936164, 0.2144415970542468, 0.07659284630790353, 0.11594974654144607, 0.08167136285919696, 0.2069626038428396, 0.11826705071143806, 0.12580989830894396, 0.16952622594544664, 0.1266385952476412, 0.11161187110701576, 0.191209762415383, 0.1598079060204327, 0.16797605756437406, 0.11501256245537661, 0.13779460365185514, 0.13577824778622016, 0.09599271274055354, 0.11136955246911384, 0.11053907437599264, 0.1437931161490269, 0.21982537378789857, 0.10156458680285141, 0.17440048861317337, 0.12586024560732767, 0.16737992002163082, 0.08438755656243302, 0.10281800001394004, 0.16377323074266315, 0.15162655909080058, 0.11594475188758224, 0.16348000819562003, 0.2578312758123502, 0.2363561640959233, 0.17485058633610606, 0.10275537017150782, 0.10604433118714951, 0.26074132591020316, 0.1368489145534113, 0.09814475546590984, 0.10985108121531084, 0.10629954835167155, 0.16693406738340855, 0.08663210057420656, 0.07117087123333476, 0.15759442088892683, 0.13907163200201467, 0.08154780269251205, 0.17249129887204617, 0.127997541858349, 0.16879003029316664, 0.19882217893609777, 0.09897377894958481, 0.16923487361054868, 0.21688269887818024, 0.08891135483281687, 0.16265040583675727, 0.2786833100253716, 0.09522063424810767, 0.1559134415583685, 0.11722729439497925, 0.2621465380070731, 0.14907049859175459, 0.12216422401252203, 0.15470549231395125, 0.1229090805281885, 0.09724060437292792, 0.14324912190204486, 0.10213727247901261, 0.1092687773052603, 0.09903467958793044, 0.11556272394955158, 0.18620495597133413, 0.1332067506154999, 0.13544060027925298, 0.196165498055052, 0.147897326387465, 0.09229533301549964, 0.17452012281864882, 0.094936963141663, 0.0673158593417611, 0.12509384454460815, 0.12622548616491258, 0.11320017103571445, 0.13523619796615094, 0.09247749316273257, 0.0995753490133211, 0.06269064659136347, 0.14816527138464153, 0.10466700157849118, 0.11262847241596319, 0.15727318968856707, 0.10819503804668784, 0.1269290124764666, 0.11551479605259374, 0.14952589524909854, 0.11825070119812153, 0.12376468774164096, 0.12081523702363484, 0.07023652957286686, 0.16701889486284927, 0.1480616972548887, 0.11239116327487864, 0.13362325873458758, 0.18556656053988263, 0.10846635239431635, 0.17047157365595922, 0.1818485342664644, 0.15338340075686574, 0.1177240360993892, 0.12586845376063138, 0.13984174380311742, 0.10623092195601203, 0.050102701352443546, 0.1409803912974894], [0.030900684068910778, 0.0077110720667405985, 0.03171917276631575, 0.022491145282401703, 0.02569379266788019, 0.0524166918330593, 0.01730421579850372, 0.0408183040417498, 0.021276175320963375, 0.03814173731370829, 0.012683497679972788, 0.08385230481508188, 0.046637573032057844, 0.0973889596934896, 0.07770923679345287, 0.016652975646138657, 0.07579551253002137, 0.036918622281518765, 0.0065654896661726525, 0.01739360006467905, 0.009122813207795843, 0.07828213027096353, 0.08323588437633589, 0.028740817251673434, 0.05666586948791519, 0.05357909176382236, 0.00103462424931422, 0.040669058143976144, 0.035724421322811395, 0.03720751068613026, 0.09672436644905247, 0.0050466607899579685, 0.011063804904551944, 0.01404171141984989, 0.018135161444661207, 0.035932397076976486, 0.05292948248097673, 0.04381033548270352, 0.0614935030171182, 0.0034080207524311845, 0.019312216936668847, 0.07436435495037585, 0.07260121245053597, 0.018520694175094832, 0.025996863514592405, 0.041604594662203453, 0.02437767354422249, 0.0445121214579558, 0.022583672543987632, 0.054368432611227036, 0.04124032631807495, 0.09295585929066874, 0.052934903869754635, 0.06246821751119569, 0.023456280505342875, 0.05570327797613572, 0.016338295754394494, 0.041623819997766986, 0.02178095262934221, 0.1146892829274293, 0.09027590465848334, 0.012891907590528717, 0.020000783406430855, 0.06696781434584409, 0.07530560600571334, 0.05186971786315553, 0.09013330840389244, 0.035511488022166304, 0.04531014172243886, 0.05124146387970541, 0.03276338567957282, 0.09855062860879116, 0.03635824512457475, 0.015185087322606705, 0.04646108289307449, 0.04013645957456902, 0.029564682808995713, 0.007692449262322043, 0.04619795814505778, 0.07662518910365179, 0.021532190294237807, 0.026280187666998245, 0.024001415804377757, 0.051187480057706125, 0.03569985994545277, 0.023848294040362816, 0.030098889983491972, 0.02187667298130691, 0.0293664941273164, 0.05069581464340445, 0.04326487549406011, 0.08917448329157196, 0.007059100898914039, 0.05225516339123715, 0.010829887378349667, 0.04261232359567657, 0.03453458790318109, 0.03115800893283449, 0.025069694711419288, 0.03742009888810571, 0.01232284637808334, 0.08779247815255076, 0.03670259793580044, 0.037713443889515474, 0.029932287106930744, 0.05718323176552076, 0.09814036195166409, 0.027156048090546392, 0.026924162193608936, 0.017263520130654797, 0.040587592593510635, 0.03343459888128564, 0.06186258418892976, 0.03034303616004763, 0.008804965273156995, 0.03406022566196043, 0.0477708251128206, 0.07789101844537072, 0.08215975540224463, 0.02391441197687527, 0.04162286262726411, 0.04675422751461156, 0.024444873160973657, 0.04346589732449502, 0.02581780183390947, 0.03351122562889941, 0.00793016241004807, 0.04751191947434563, 0.029123630010872148, 0.02715145419642795, 0.03966197858972009, 0.03585528422263451, 0.040341425919905305, 0.0476904876268236, 0.03918154558050446, 0.044349194067763165, 0.05897376322536729, 0.0138845059882442, 0.046153700168360956, 0.028863676088803913, 0.011358742740412708, 0.009894822123897029, 0.018808187342074234, 0.03817268858256284, 0.008911674049159046, 0.032663885940564796, 0.11209326519747265, 0.0709528876177501, 0.024777934195299167, 0.09060760014108382, 0.04561368754366413, 0.0194552436369122, 0.04891320189926773, 0.015739215596113354, 0.04443322373845149, 0.019809227669611573, 0.016604489283054136, 0.021680007557733916, 0.044728182911057957, 0.01657235243328614, 0.08184558202628978, 0.02073266532534035, 0.02802149061608361, 0.04789016988070216, 0.04725758175482042, 0.01485318496634136, 0.009454592182009947, 0.10274633823428303, 0.03982028239988722, 0.02653773331985576, 0.0076394965617510024, 0.04826922551728785, 0.015833433099032845, 0.02524074305256363, 0.05244370229775086, 0.030624022547272034, 0.029081266366119962, 0.03639547125203535, 0.032554222489125095, 0.013820817657688167, 0.014757273511349922, 0.057841245870804414, 0.047244237939594314, 0.04165786231169477, 0.03267963431426324, 0.0156857791080256, 0.05506916844751686, 0.03248504319344647, 0.025464212994847912, 0.014476685100817122, 0.03364771029737312, 0.058675445834524, 0.05201953150390182, 0.023574265287606977, 0.015766691758472007, 0.04115606287086848, 0.015573794589727186, 0.04854972394241486, 0.03517105375067331, 0.009359974847029662, 0.039415541032212786, 0.05073820240795612, 0.022714945480402093, 0.021531327547563706, 0.03886340171447955, 0.054128600168041885, 0.08669147980981506, 0.03156634600600228, 0.029199813325249124, 0.03188823400705587, 0.033371560857631266, 0.05360772382118739, 0.02882022334233625, 0.08843074741889723, 0.038745975398342125, 0.008224263474403415, 0.024358787741221022, 0.02267338892124826, 0.01261018740478903, 0.031047299053170718, 0.038677901902701706, 0.029243202989164274, 0.028174751532787923, 0.028552189287438523, 0.021642202555085532, 0.05752678305725567, 0.08217056849389337, 0.024189824835048057, 0.07667668673093431, 0.017890829731186386, 0.04369277186924592, 0.08048052011872642, 0.04598357394570485, 0.0811503900331445, 0.026120640759472735, 0.023968171299202368, 0.08385807130252942, 0.016729617236705963, 0.053979795848135836, 0.027587365766521543, 0.018082736132782884, 0.030572816212952603, 0.0567286997102201, 0.015501268208026886, 0.11151004844577983, 0.06910279509611428, 0.012200178643979598, 0.0178553495061351, 0.07118630790500902, 0.014114111636445159, 0.035321175382705405, 0.03851895613479428, 0.032325050997314975, 0.029203203084762208, 0.026805190354934894, 0.05983829476463143, 0.023855075414758176, 0.03102640388533473, 0.049080875323852524, 0.05039153038524091, 0.021869778429390863, 0.052245118422433734, 0.05463755762320943, 0.045631376633537, 0.015521702316618757, 0.052773464485653676, 0.008382099731534254, 0.02593293862446444, 0.021202225871093106, 0.03210491515346803, 0.047918508789734915, 0.04070560520631261, 0.08068852926953696, 0.0628746472648345, 0.007604838265251601, 0.050222840218339115, 0.01477009040172561, 0.02166126276279101, 0.03176691141561605, 0.005750241834903136, 0.06826843557064421, 0.033858038659673184, 0.09065287857083604, 0.02042999523837352, 0.019201946779503487, 0.1024449743272271, 0.03821253078058362, 0.044635377344093286, 0.04069653987244237, 0.02244440111098811, 0.04777127782290336, 0.012115618337702472, 0.07002160360570997, 0.07108267440344207, 0.06282807749812491, 0.022402785180020146, 0.01866879902081564, 0.022988601303950418, 0.023910860800242517, 0.04333298980782274, 0.0697414725436829, 0.03298636765975971, 0.09923646211973391, 0.03431477860431187, 0.04825610805710312, 0.020291441833251156, 0.06343905057292432, 0.03341587078466546, 0.03323030046885833, 0.026071523570863064, 0.02627190900966525, 0.01662739010498626, 0.007229584280139534, 0.0942343199858442, 0.052061392343603075, 0.02715490889386274, 0.02968915767269209, 0.049277262442046776, 0.015981020296749193, 0.04807714656635653, 0.04278999374946579, 0.01846763803769136, 0.0397658866859274, 0.07016465999186039, 0.018213031289633363, 0.09922722238115966, 0.019623837324616034, 0.027611823243205436, 0.06924875327968039, 0.020391774633026216, 0.09465930343139917, 0.012991324765607715, 0.042645868670661, 0.04948380956193432, 0.02627522640977986, 0.04744768659293186, 0.079175935825333, 0.030731288861716166, 0.035150414623785764, 0.033426746958866715, 0.04043144843308255, 0.024889096785045695, 0.02398545777396066, 0.10413148265797645, 0.017079940625990275, 0.04958526486007031, 0.0279447172943037, 0.018610401275509503, 0.05330297200998757, 0.008844555140967714, 0.06020844833983574, 0.019125288490613457, 0.13644098566146567, 0.1136508327908814, 0.11727169709047303, 0.11718522946466692, 0.06761725293472409, 0.11212347802938893, 0.08005650146515109, 0.13230085547547787, 0.18428513867547736, 0.204974805819802, 0.10459090175572783, 0.20646208460675552, 0.12982341810129583, 0.17016353784129024, 0.1739425686537288, 0.12006082906736992, 0.15425634454004467, 0.12223271682159975, 0.08193458779715002, 0.16974941943772137, 0.08015409388463013, 0.17437610164051875, 0.1910133901401423, 0.06964929780224338, 0.2283911086851731, 0.10563647650997154, 0.09102588941459544, 0.06728825144818984, 0.0892809072684031, 0.12920031091198325, 0.14791405439609662, 0.10069744661450386, 0.07426433570799418, 0.12544556317152455, 0.1871122166630812, 0.13161629845853895, 0.21257392305415124, 0.1591636476223357, 0.1103001250885427, 0.09102006355533376, 0.1900612295139581, 0.15747117984574288, 0.06980816193390638, 0.1466043567052111, 0.13068643194856122, 0.14852320920908824, 0.10436621654662304, 0.11760813489672728, 0.056227720342576504, 0.17068489658413455, 0.10447160893818364, 0.2145831543020904, 0.12633012898731977, 0.10232827902655117, 0.14293274434749037, 0.16170820483239368, 0.08695075652212836, 0.18514315044740215, 0.06511596293421462, 0.15339227684307843, 0.16340548172593117, 0.10413520081783645, 0.12422116793459281, 0.1302938358276151, 0.1701738833799027, 0.14844924677163363, 0.11886308435350657, 0.09213053170242347, 0.2613481058506295, 0.2353731746552512, 0.14377273677382618, 0.23110790352802724, 0.14716666715685278, 0.127568268799223, 0.19359416415682063, 0.20769341150298715, 0.1940806716447696, 0.12174655814305879, 0.19124827987980098, 0.2032396348658949, 0.061428980698110536, 0.068418757582549, 0.12934047292219475, 0.15531923359958455, 0.13263005734188482, 0.11410469320253469, 0.11340161960106343, 0.1225953375978861, 0.11476726038381457, 0.13204715971369296, 0.11276466393610463, 0.15903255465673283, 0.11538656777702272, 0.12743980303639546, 0.12405505302012898, 0.12989156210096553, 0.15715357032604516, 0.18760982668027282, 0.13840411469573155, 0.18286106118466705, 0.08987758657895029, 0.2520139957778156, 0.1092019617499318, 0.10125247659743764, 0.14510281383991241, 0.07376913767075166, 0.2527128910878673, 0.10037205938715488, 0.08969257658463903, 0.1701088564004749, 0.13408356840955094, 0.12802676763385534, 0.11895675081177615, 0.17003477521939203, 0.1472808391554281, 0.06961485472857021, 0.17986472899792716, 0.1837278451421298, 0.18738580198260024, 0.1406873023370281, 0.09857163138804026, 0.20523068349575624, 0.09573607807396911, 0.14723015046911314, 0.15444471646333113, 0.10923739188001491, 0.1334751260583289, 0.13193101360229775, 0.15084470651345327, 0.12625241128262132, 0.15068915236042812, 0.1804064225871116, 0.11616246833000332, 0.14347013348015025, 0.10972706091706641, 0.1035492232767865, 0.18656917236512527, 0.1298824039986357, 0.12643002206459641, 0.14642716152593493, 0.0630134140374139, 0.18095722974976525, 0.13053648843197152, 0.11461083049653098, 0.14337648928631097, 0.09277648219722323, 0.13934834918472916, 0.1553746868739836, 0.07856971249566413, 0.2517102495767176, 0.12297136898268946, 0.1384353739558719, 0.11928610110771842, 0.11129590915516019, 0.2049904948216863, 0.21106007538037375, 0.13793365244055167, 0.14473546558292583, 0.14230010798200965, 0.08946726797148585, 0.17345907428534701, 0.20711514487629756, 0.1445196638815105, 0.1460077441879548, 0.1387541857548058, 0.143218990706373, 0.09874111565295607, 0.2169611884164624, 0.12033345701638609, 0.1850954451947473, 0.1312634369242005, 0.13360008888412267, 0.13419707247521728, 0.12894223647890612, 0.19689903681864962, 0.13861584942787886], [0.02039476177742472, 0.016838928167999256, 0.06664213768090121, 0.1347475530928932, 0.01516381737019401, 0.022645653007202782, 0.04600973836204503, 0.051823823450831696, 0.03491461575322319, 0.04519871195952874, 0.025437156145926565, 0.048973267621477135, 0.013007489669689676, 0.018401017296127975, 0.057306487651658244, 0.040223261166829616, 0.037920087488600984, 0.036917048928444274, 0.055809557234169915, 0.036483348958427086, 0.09847766807070002, 0.018737071040959563, 0.05873771573533304, 0.045606099083670415, 0.06366107889334671, 0.08561315407860093, 0.03263760278059635, 0.02887090275180526, 0.014745242369826883, 0.10563016083324328, 0.03341347735840827, 0.08030233046156354, 0.04786964207596611, 0.0111374918196816, 0.024598052441433538, 0.07377239569905214, 0.017916051619977225, 0.04413863192894496, 0.04256451073160861, 0.06742499957908876, 0.027063210982305463, 0.02002019427891355, 0.06502219999674708, 0.0680023682070896, 0.08494510984746739, 0.01694096234132303, 0.03757226142624859, 0.05468770825245883, 0.012187292177259224, 0.05130354082211852, 0.0511437304521678, 0.07245197397423908, 0.020179631719656754, 0.013438645928545156, 0.06015273531374987, 0.01382605350954691, 0.029718721125391312, 0.07866931613534689, 0.06277125125052407, 0.03908298836904578, 0.018573991510493215, 0.08609344979049638, 0.024791094328975305, 0.039357378918793984, 0.03259925601014402, 0.014184337360347854, 0.02587597322417423, 0.06489695515483618, 0.048188591172220185, 0.012020455524179852, 0.010716973320086254, 0.04587413313856814, 0.042743160520331, 0.048412745745736174, 0.027923295201617293, 0.048585410113446414, 0.027885028212040197, 0.04192226355371531, 0.01862629065726651, 0.013463280592986848, 0.017393729940522462, 0.027975638877251185, 0.13534207275370136, 0.034696160873863846, 0.029781497541989665, 0.029236341833893675, 0.09850998860201798, 0.07684732874622568, 0.030144392912916373, 0.013882222956453916, 0.04213552711007651, 0.053728497223346494, 0.06229888167581521, 0.029236388218123466, 0.04088312321982812, 0.052966211369493976, 0.0516271134983981, 0.019187085272278637, 0.03387691147509031, 0.015139716124394909, 0.06681582250166684, 0.05197753707761876, 0.04721026612969581, 0.014288815054896986, 0.028488316347647924, 0.04895765283436049, 0.01801133039407432, 0.0693907261302229, 0.06899735817569308, 0.031210378583637066, 0.04101693986740429, 0.037684733906644396, 0.014861173258395866, 0.013848251146555413, 0.02340670132980449, 0.0232889800099656, 0.019397120486246422, 0.05227723115240224, 0.043245156630291604, 0.0301898902762332, 0.04323729357565753, 0.04141984070884064, 0.03857041294395458, 0.04033256096590776, 0.047771537574590184, 0.07474479469237849, 0.015681738113926258, 0.013926269421062898, 0.029187623549660202, 0.04638531703676563, 0.02437231709336629, 0.03358604524692055, 0.04484824385144748, 0.013652542165800696, 0.0760260755487252, 0.06670996255706996, 0.022550511530425865, 0.030825502653897274, 0.02632390387589112, 0.032935964700300246, 0.048138889542315155, 0.0313312113576103, 0.04224148724460974, 0.04580419685225934, 0.06183199286169838, 0.046702436738996767, 0.03641929419245571, 0.05451711447676644, 0.0314267109206412, 0.07042163604637608, 0.03978363143687602, 0.04475601344893221, 0.008803960590739734, 0.02962655566079775, 0.04949690104695037, 0.046600313507951796, 0.04290513425075915, 0.023147855063143652, 0.016700825617590453, 0.03849438362522051, 0.03178919811034575, 0.02491903131158324, 0.043574005976552144, 0.0356311778887175, 0.026893121867033187, 0.033924060116987675, 0.043664952463586815, 0.09141675633145496, 0.0803299383551348, 0.04630919123883359, 0.05099051406432409, 0.04898443694401067, 0.04894236088148318, 0.02360858034080593, 0.024816544428176712, 0.0838835492322687, 0.04467194667086005, 0.05937852314673364, 0.026401265349704772, 0.029065080125292297, 0.03622523741796613, 0.04603529792802874, 0.04195569359580986, 0.04445828977623023, 0.040812448496581055, 0.03164545523759443, 0.050728175992844626, 0.06249939513509162, 0.0460771365032997, 0.04110332956770435, 0.03320006908325013, 0.017403351885150187, 0.023435886287188623, 0.06726928215357475, 0.023273643528227694, 0.04068248359544668, 0.051516867461032234, 0.06133890994533431, 0.06265366537263617, 0.01008415605610935, 0.035047834971919656, 0.020524750798358582, 0.02937268920504721, 0.027458161566755734, 0.0369718194269808, 0.10039538508863188, 0.05693362152669579, 0.08167954132659361, 0.06298916065134108, 0.08719509380171075, 0.0681935009197332, 0.01918776433740277, 0.018080697082041297, 0.10298373643308878, 0.04756343194458168, 0.048817761708050966, 0.07989167788764462, 0.04712203219241928, 0.06746050392393954, 0.051676874500117265, 0.048151984738069586, 0.041650385173852555, 0.029256973539304454, 0.04858575150137767, 0.05287623709591571, 0.02319070295925485, 0.03922924712242093, 0.05360034316254314, 0.026309025670343544, 0.052630686404882, 0.04682106533437036, 0.027072242919530254, 0.025195672424160875, 0.051667556836036965, 0.049950108368648216, 0.07700346919591539, 0.046427051711361855, 0.0692918201093562, 0.01380796922603622, 0.058202397194691, 0.07082229189109057, 0.029916638923168648, 0.09291310416301712, 0.032473547325935215, 0.05226071094512008, 0.04399338249641005, 0.039177990693133324, 0.03430951677728444, 0.031310342164942995, 0.02140261873137206, 0.05995448911562562, 0.005335668402040028, 0.03859248070511967, 0.05698911190847866, 0.027327794050506782, 0.04411401489051059, 0.05363186959584709, 0.016552308879909106, 0.02225710530183278, 0.003913958362318226, 0.028016273317916784, 0.06554564417456277, 0.060046760336263105, 0.007155866751418216, 0.03720909888215829, 0.011682228214340284, 0.07008150976616889, 0.024476464532199316, 0.050375915598124266, 0.030358439435076434, 0.1039933467109222, 0.014535679347318364, 0.004210349416098325, 0.04004965056083165, 0.038546872019651346, 0.04839382840145845, 0.004038423485326348, 0.06539466165122576, 0.028269095200812444, 0.02825439139996888, 0.021158832496439572, 0.0302927816301235, 0.012761300731654046, 0.06249742102227174, 0.025445880091865547, 0.020241328311385587, 0.03316381887998432, 0.051989875282743014, 0.029657466111530084, 0.021334446901164483, 0.028390070838213433, 0.04516743414569646, 0.03379582441993989, 0.06319092091871426, 0.10385556699475273, 0.06663349166046828, 0.005430380824691383, 0.008646070527902339, 0.041019860218511894, 0.041814440628513694, 0.028564881868078373, 0.06884808259201236, 0.03644981872639619, 0.06901242377352901, 0.022817564095021226, 0.07791493044351228, 0.01113292390073184, 0.01864037290943088, 0.03840902922092937, 0.033373683399986476, 0.05409377859905362, 0.04140766948694363, 0.056513480594730936, 0.043384954988141544, 0.06819883696152829, 0.04031463438877836, 0.06353619770379737, 0.048703003412811086, 0.032508825315744616, 0.07830357091734186, 0.0215278320320067, 0.0494039618934039, 0.031268971142708324, 0.011491517598187784, 0.034323680665693246, 0.05576434930844698, 0.05862640842678957, 0.055751387699274346, 0.026154321276408155, 0.01997659866901813, 0.03262939462729264, 0.023530678954557516, 0.01878985443909187, 0.02919179813034134, 0.05426289550086949, 0.015730057493783534, 0.060967839817749336, 0.017928282213688362, 0.02547686846810393, 0.057433925539953634, 0.052921983078704216, 0.032768625242169946, 0.0556649720238056, 0.03652813014923595, 0.05925163073698059, 0.04376516466436442, 0.024010282613744494, 0.027842900199175347, 0.048579524882370606, 0.010770246535685146, 0.03797053126618266, 0.07998783054063097, 0.09239936727681197, 0.13308554305694997, 0.18031445564702153, 0.1771460342570208, 0.09408267695107497, 0.0980692270968575, 0.1411071204347536, 0.19374358817003667, 0.11032894268282689, 0.09102048657950945, 0.18636282562511042, 0.11589499830733985, 0.11103659533546306, 0.12018309789709747, 0.16084180679172277, 0.1438782108016312, 0.10776373150292784, 0.10204436301137321, 0.12483888713177294, 0.09745977542479523, 0.19530876277713105, 0.11140645205159672, 0.21073453972348943, 0.11142003335407935, 0.1186002824397292, 0.21117139753187075, 0.1009574432100635, 0.11638859330560081, 0.11475048042484559, 0.14677476865472272, 0.23854183353250846, 0.21705910738091916, 0.11743772294721566, 0.21912604803219438, 0.16853084263857454, 0.10277231340296566, 0.11461997375590727, 0.09957039888831787, 0.11047209554817528, 0.17493649735115469, 0.19113370712148026, 0.2321021884563379, 0.09540237879264168, 0.20977752545149997, 0.1937101618386805, 0.10101421750732698, 0.18357284017838538, 0.18665975891053677, 0.20482857304159552, 0.1253958244342357, 0.12826711958041415, 0.20269902481231838, 0.11204285110579804, 0.08439110402832739, 0.12823489552829415, 0.07522124607930891, 0.08400898703257553, 0.17002030333969742, 0.1744534631143324, 0.11056924267904833, 0.15413997578434646, 0.15595516510074958, 0.1314100407762453, 0.16035853506764397, 0.1618497323943302, 0.1328412428847514, 0.14184603234753013, 0.13047490501776338, 0.20220205304212868, 0.18449507741024718, 0.10283066105330363, 0.20036618749145418, 0.16265427984762937, 0.1564552093623206, 0.15448229882167652, 0.1538208671263419, 0.11839248851174489, 0.12156214928836562, 0.18688344222027808, 0.08572147053200752, 0.20150416705291718, 0.10268984595313668, 0.31055074534378946, 0.09074261906789616, 0.10465094150276855, 0.20149955089436844, 0.21471846266649663, 0.20375698601128533, 0.18953900987980887, 0.11308580607874319, 0.1877805354888551, 0.14098533400101587, 0.1433625814388506, 0.07078145892592147, 0.21971988491714, 0.11787029856350273, 0.18517843214794993, 0.17470153339672834, 0.11969875748036429, 0.12572186475154012, 0.1561415777541697, 0.12193619171739556, 0.12436370481736958, 0.15744872245704755, 0.10731644651968963, 0.14141251420369372, 0.10953970573609695, 0.1316826167749241, 0.09835886507062241, 0.12974794168258086, 0.0796071087825112, 0.14965574140660465, 0.06955511184060015, 0.12768865999532863, 0.0926771828380879, 0.12988183996640146, 0.09823242537095211, 0.19083845108980313, 0.18996877275640145, 0.1322832962614484, 0.13370954082347453, 0.07812826821464114, 0.15945565304718912, 0.14808209147304296, 0.09668231636169367, 0.21549684199271724, 0.2193692943546921, 0.16712947486666963, 0.1534742396324873, 0.20736180507810786, 0.07516182973631658, 0.12346746501862071, 0.1358326175250113, 0.09660091018304229, 0.19660640798974782, 0.19125078833894804, 0.1947957754600793, 0.12351835408480838, 0.17939152079634368, 0.09512082280707546, 0.17037614830769598, 0.09845184133155271, 0.16288142156554386, 0.21787529170978814, 0.21145043021533638, 0.21811188838910311, 0.08306844843900762, 0.09329999316832982, 0.1313489323365502, 0.17300372215686366, 0.1993530520121567, 0.1782484055729583, 0.18205508880782872, 0.1876186582376249, 0.10829861959791742, 0.09251822222722694, 0.1335509290220216, 0.12988963251700625, 0.13502743182471022, 0.09924403202603571, 0.1449438903364353, 0.1542617622180842, 0.22204215405508876, 0.2082637816783972, 0.16427765367552638, 0.12015174215775914, 0.11984114593360573, 0.2220762483193539, 0.15444513206603006, 0.18131656281184405, 0.18687800969928503, 0.16315571934683248, 0.16107375762658194, 0.14942304842406884, 0.1320479909190908, 0.1694602787028998], [0.06009367520164233, 0.025548561789037194, 0.03449411487963516, 0.026243375286867376, 0.01867841539933579, 0.06950940296519548, 0.035708090363186784, 0.027633881727524567, 0.0347010627592681, 0.011299815287202364, 0.05694278333976399, 0.04849515753448941, 0.01605083412869135, 0.07793392942403443, 0.05110788843012415, 0.023787738500686828, 0.07385227305348963, 0.0027393681921239477, 0.052361093839863315, 0.04386474232887849, 0.024212386124418117, 0.051004236374865286, 0.04286719937226735, 0.1313515001675114, 0.033302474330412224, 0.0158530295084347, 0.03287968022050336, 0.058948277874151245, 0.045278626421350054, 0.03906732534233015, 0.05584807469858788, 0.020303555538703222, 0.0213883787728264, 0.04129840308451094, 0.027146424290549476, 0.046472623289446346, 0.015128013383218786, 0.015740258313599043, 0.05989601158944424, 0.0566226208320586, 0.08120389145915397, 0.006093726797189447, 0.05366883968235925, 0.02374554554990027, 0.03084851665335009, 0.030646066188637633, 0.06381928993505426, 0.014663262882095296, 0.04119859164347872, 0.05452666591736488, 0.0818704959237948, 0.016537354604224674, 0.00675570072417031, 0.027863303694175556, 0.1015772701066453, 0.046518914750777185, 0.09367002799990587, 0.06357892314554192, 0.04145700375374872, 0.009670182371337432, 0.0333454817882739, 0.012997103312955005, 0.04127523323404603, 0.04394724688609131, 0.02630577135278145, 0.029152855786378495, 0.05663206466124393, 0.01996484490518924, 0.06471338492701761, 0.015006469075160567, 0.023340344050666317, 0.036214127467246726, 0.04569265576719772, 0.06782708776881918, 0.06385419314028695, 0.06293677986832336, 0.03718455976922996, 0.01393816048221197, 0.017818462911236566, 0.0669117970392108, 0.07289639426744543, 0.03922708747268189, 0.021185874502407387, 0.04042191925691441, 0.054171507435967214, 0.05922636803006753, 0.03376981585461181, 0.07609526597661898, 0.030381600008695386, 0.07468006457202137, 0.046286414726637304, 0.032305669810739346, 0.10072569275507703, 0.017747717683960218, 0.0324710945278639, 0.01613884356629569, 0.007242015717565664, 0.016634075000183657, 0.029960815263621043, 0.027643713328870945, 0.051696211157832295, 0.012986049950995948, 0.022699662804370746, 0.04122626633034088, 0.03870387707138434, 0.046320063702296466, 0.007677625790165621, 0.03069884030992398, 0.058572046109475195, 0.040489395323675126, 0.03651058577816002, 0.06272412487305701, 0.1015163843112532, 0.018158049279008992, 0.019305808491481002, 0.019814213046629447, 0.02829280125297373, 0.0663277565035969, 0.06217620466486551, 0.04943690211803187, 0.06404266154277138, 0.02565622144174995, 0.023735528411634732, 0.043988614197587594, 0.06904077381477691, 0.13546004454838112, 0.08107762987492606, 0.03103943043242907, 0.0713292158616241, 0.014896961474732962, 0.01431364175005001, 0.051894238422391936, 0.03508896108542103, 0.014605634187319083, 0.06877118124975823, 0.01425808828571462, 0.026797935861395672, 0.021887018519919366, 0.036553715690388344, 0.0416717330517713, 0.031449613597942516, 0.014933321144781075, 0.04755746507726144, 0.03532228118274361, 0.006250288415685645, 0.06222560943569988, 0.021296267113939393, 0.005457248425955186, 0.062134748295648023, 0.023832957558624912, 0.08436342191998847, 0.011870566740981303, 0.022634797242062632, 0.07651194478967227, 0.04368704619992059, 0.0024817174789859564, 0.021530628073378466, 0.026744657079689205, 0.023804501761333086, 0.028883311460958794, 0.07600493176141754, 0.027801286123576574, 0.10337654777686112, 0.07138200482586399, 0.014335566647787346, 0.015523978854616871, 0.0488325823971536, 0.040198414062615484, 0.03550111279764678, 0.05814747455588076, 0.06592184625333175, 0.02274771686643362, 0.04218089088681154, 0.050575018976815045, 0.013978712358948542, 0.05873970098036807, 0.061962751860846765, 0.030722037990926765, 0.053336728597059846, 0.012011069211439462, 0.056880543124862015, 0.042942980071529746, 0.038483121534227394, 0.07629304091096856, 0.02769177852314897, 0.017938477467396297, 0.02335553952434566, 0.03326792735606432, 0.038425746097345836, 0.023503868869738653, 0.02282039353303844, 0.02507601966499351, 0.040986879175761715, 0.03006719285622239, 0.01727121434669243, 0.07345588455791585, 0.04767408987390809, 0.010396872967248783, 0.05967183846223634, 0.025218792179657612, 0.02901122617913643, 0.017872673088277224, 0.05114342246088199, 0.008393214320676634, 0.009385250541527057, 0.0005940368009760277, 0.062380273011513054, 0.023529554600827396, 0.013857796093361685, 0.04385706481116358, 0.010449962501297705, 0.06351706513669342, 0.007844693900551647, 0.013614920844702283, 0.09637051785830408, 0.05918406190176029, 0.07730981291388161, 0.04949854119331576, 0.006784663501093746, 0.07219111648737453, 0.009030648670886876, 0.06495724723208696, 0.0038043651829866576, 0.017835628786997404, 0.03530248439346906, 0.04430829802004155, 0.04086991299118381, 0.030684847115480807, 0.014067055763007374, 0.011157248718518531, 0.06662913525360636, 0.02551686280639842, 0.058658732668845914, 0.03954190280637704, 0.0570992095163092, 0.03740085870958865, 0.03210501905414276, 0.05398077919380739, 0.05412140875705518, 0.04483211327169556, 0.0716394410119392, 0.04782972566317767, 0.02081126433040481, 0.03220691221940797, 0.05928794402279891, 0.016022951640479732, 0.026587626052787527, 0.06657978985458612, 0.027645735681289807, 0.011214202986593591, 0.05640290801238734, 0.06481882926891558, 0.031457049917662516, 0.023121210106182843, 0.025588058888388332, 0.0274635254390887, 0.025856024294625968, 0.05608725405181758, 0.05554706702241674, 0.01881983163912082, 0.06746992919943295, 0.02127159998053685, 0.05602277255093213, 0.018947759344882797, 0.03955064530600794, 0.02293705543706892, 0.013555177956732223, 0.05908157501835376, 0.05649935010296758, 0.014270798492361791, 0.03931449762603734, 0.02353324121941114, 0.04006374023447279, 0.017128426989074796, 0.07307065796339884, 0.07690888989600353, 0.043906803548452444, 0.03217285506252665, 0.05847310669196304, 0.0548463794257259, 0.06974807023652829, 0.08402591542107984, 0.018944282383017708, 0.025038912281161174, 0.04868319920205977, 0.016199198726098984, 0.06779949471820146, 0.021278999192873016, 0.022393159524654038, 0.045831908646505326, 0.03289632288215216, 0.05469332631037105, 0.13783258676994592, 0.028322893485892564, 0.022200536950549576, 0.02732757511694217, 0.030462523791356944, 0.029287692887010053, 0.0008934341326494177, 0.04432722649653442, 0.026225689907732885, 0.04879875159531366, 0.04411028930917382, 0.028311982059676666, 0.01903606749692699, 0.022749167765141465, 0.05691504185961094, 0.04778312621056102, 0.05341358541045338, 0.016087405310827307, 0.03772514013689943, 0.015739043046778534, 0.025466140723438002, 0.0254018262057798, 0.025369552058691625, 0.007743287769699236, 0.0417064358771313, 0.007439908467858913, 0.05277085212583188, 0.013909260323998751, 0.03206173700164072, 0.08599443244747818, 0.03677224478451535, 0.03852304165775422, 0.10783291450934485, 0.06539622758282349, 0.03411429854168091, 0.029778193129459396, 0.03363123832968995, 0.05470903015520889, 0.0032088301713883993, 0.04934486838465091, 0.03435608283325564, 0.05853057489730418, 0.02863620040443493, 0.043570944617385976, 0.03668092351290397, 0.017676679308351595, 0.051363769816816784, 0.05095424159662798, 0.026767136732814834, 0.032009779242798686, 0.007451559722539969, 0.0415831169084413, 0.0140394293157442, 0.05752850112912711, 0.04005332419183105, 0.10302025752025656, 0.04801466144272126, 0.0770959111105185, 0.04133142123464495, 0.01492462224632618, 0.18778250960167497, 0.09903798956656829, 0.13050747045781463, 0.0605371158599155, 0.14692581054987386, 0.19130425265757367, 0.16421471955254674, 0.14659184409538284, 0.09068566665519029, 0.10077924613142386, 0.16414411162259057, 0.11145979762659408, 0.10241868003504351, 0.18349334131926298, 0.07922986769699492, 0.14113944838754833, 0.18290953827090561, 0.14127664180705324, 0.14059441513381898, 0.20445074565941468, 0.21772563020931557, 0.10378204984590411, 0.12912666017655283, 0.2601641428191215, 0.1009623562276829, 0.14413548371521756, 0.13103648816468194, 0.15399583586258814, 0.12102455235435627, 0.12506403989391401, 0.16263863537460566, 0.05683687515556812, 0.09493285906501114, 0.14960432541556656, 0.12543714721687138, 0.09798837010748684, 0.11697264126269147, 0.042678634490584955, 0.1761805298156105, 0.3203631250653416, 0.24380418006330729, 0.17429324827389792, 0.16263217868981883, 0.14772461378015578, 0.13220695895142853, 0.14828751794993877, 0.10877030639676377, 0.07759594052913599, 0.10918822459643707, 0.07195227852207609, 0.1662339549511671, 0.0977779489767272, 0.17966895044082776, 0.14948598254704848, 0.1501463307067752, 0.19730154803255573, 0.1589825635892339, 0.15622465376509354, 0.18429946212563664, 0.16485072526847944, 0.16333448787918314, 0.1649103790987283, 0.1379991543944925, 0.12589886697242036, 0.13703698961762711, 0.12094888297724538, 0.07495056997868232, 0.13141489442205057, 0.2708678419003263, 0.08990606278530322, 0.20384573203045875, 0.12296050394070335, 0.12196166964713484, 0.1343299020663835, 0.1343869138509035, 0.2565132512245327, 0.18617987137986347, 0.1505219761747867, 0.16799619945231825, 0.3051319986116141, 0.1786496996646747, 0.20422844274435192, 0.11279205660684966, 0.08771723179961555, 0.13754570216406137, 0.10065213107736781, 0.11112531166872941, 0.1372084257309325, 0.11812121127150021, 0.18999829539097846, 0.18228842003736645, 0.21235375752439722, 0.10104622633662075, 0.1663731670123525, 0.21783428062917665, 0.13628088956465945, 0.0974433368537575, 0.05575745104579255, 0.19802505295956507, 0.13203881797380745, 0.16738792037358508, 0.13289399474160746, 0.17417548428056762, 0.11560888553503901, 0.11368160223355517, 0.17494342901045457, 0.13192253827583045, 0.1353156819823198, 0.15059997589560226, 0.10949591160169803, 0.14298401190899312, 0.1232585652905982, 0.1466289217933081, 0.14843772863969207, 0.1481973024783656, 0.12163194827735424, 0.2485043348860927, 0.20224373205564916, 0.11689853039570153, 0.116241195355542, 0.12100438078050502, 0.1588812901172787, 0.11695885958033614, 0.22119482920970768, 0.144944216881413, 0.17568164330441505, 0.1834221842000261, 0.08797070491709746, 0.18326389894355088, 0.13914421404479071, 0.11961800439166836, 0.1855430196155794, 0.14750774338608608, 0.13340402831090614, 0.16236070106970146, 0.05422804424597416, 0.16337894252501428, 0.14427236543269828, 0.09323148551629856, 0.07786939968355, 0.09725579613586888, 0.10694263415643945, 0.12185312312794849, 0.09615340255550109, 0.14986254827817902, 0.2201763354241848, 0.08135944561217912, 0.11076988972490653, 0.22521329170558602, 0.16739091865019873, 0.12669971853028983, 0.13786368275759742, 0.10175065806834027, 0.1579019965720363, 0.11709721817169338, 0.07841349783120677, 0.1039872610999737, 0.10158726683584973, 0.1090269410633482, 0.0899342198681552, 0.11372968598152511, 0.16059519111877307, 0.20156814018264413, 0.16105711867567152, 0.11878708100994118, 0.08452352543827146, 0.12016821041470394, 0.12174048737506382, 0.1133816855144687, 0.22544111619936302, 0.21872370009077713, 0.15606855042278767, 0.11254771190579049, 0.14481641905149445, 0.07634043446159922, 0.19278324907645583], [0.11032679787604138, 0.04343630789662711, 0.03736382182978559, 0.04420619334268849, 0.031250669781002216, 0.025875680075841956, 0.04510343133006245, 0.02394907769485144, 0.0388225798815256, 0.018415806443954352, 0.010172257334488677, 0.08587728443671949, 0.09347692859591916, 0.05955401138635352, 0.013635560899274424, 0.007042947590889526, 0.017762055977073032, 0.028737375541822985, 0.02567855266534025, 0.01829296801588498, 0.03869337939249817, 0.088858343224274, 0.0021817833658133168, 0.07225633642519824, 0.005705815947294468, 0.0035412422903391416, 0.017796209613152314, 0.023204024510050658, 0.04627581685781479, 0.011964070854446618, 0.02420124648779165, 0.032882578307180665, 0.02544470193242887, 0.050700620049610734, 0.04489867278607562, 0.0168314157781424, 0.010453859704284696, 0.010849431837414159, 0.05077368077763822, 0.0071094982922659256, 0.04025564106996171, 0.038897455160622485, 0.04637222555174958, 0.017682622055872343, 0.028546407957037445, 0.06695386196952313, 0.12895630759885535, 0.03864410078676883, 0.01271431165150716, 0.058292427129345015, 0.03462619861238636, 0.011569284470169805, 0.05213718417508062, 0.0070911783768679015, 0.029747872686129995, 0.035002894219360314, 0.09915446964441799, 0.10272875675582327, 0.013099269217491383, 0.05436664403532632, 0.06099044192524161, 0.025229592283722013, 0.0328032724064542, 0.03516240401950199, 0.046552010826417245, 0.020715954015031457, 0.017060913814930245, 0.024626990634715185, 0.02345484259421937, 0.04231615843309555, 0.06487617501989007, 0.07122781622456387, 0.013149597034498584, 0.03253701208450366, 0.025279926594521385, 0.05239709913439583, 0.073024986195378, 0.03487066205707379, 0.06790755884139799, 0.01629833110200707, 0.03079515623539919, 0.011445952513895463, 0.02174502154957736, 0.00704184225469362, 0.03061182906094473, 0.10236125264782459, 0.01916830522532109, 0.045646104554180056, 0.04155917893513106, 0.060629613435594365, 0.030762397836952005, 0.03805866501352284, 0.022693131904816255, 0.032859419588930905, 0.04839932400500402, 0.023707185791863594, 0.008209990119212307, 0.016897414971026592, 0.011530580541148083, 0.021580604297923855, 0.06076754900277592, 0.027451654787000734, 0.03219036603695713, 0.03012237710208865, 0.03301906668639276, 0.012626464558707085, 0.017488439116277732, 0.02272627807542449, 0.03783753840252757, 0.038192730280570686, 0.05996363608574029, 0.08351462762220763, 0.026273191069776658, 0.04074058262631297, 0.017601342042325996, 0.008536702080164105, 0.052335022191982716, 0.01011626507533947, 0.02834271810570499, 0.008661391239002114, 0.02508983845473267, 0.10524189143325202, 0.019170386949554086, 0.051952934882137924, 0.02529203844460426, 0.008310626271850197, 0.009068240306078224, 0.03813502458797302, 0.0426775398227619, 0.024546076128899585, 0.026182793772022706, 0.02621004172397079, 0.07543559317127801, 0.04318640822020825, 0.02479430040693842, 0.039235210279002786, 0.0018418299828226736, 0.07221476873382926, 0.016739894126658328, 0.12214020069222897, 0.05068344675237313, 0.027989387162961066, 0.0167096015138668, 0.10671308045857586, 0.05823824292747304, 0.03218100384401623, 0.026724285125965253, 0.02830620258464478, 0.04084164458618034, 0.0023932105705171125, 0.04701032412413042, 0.02914641208917601, 0.03314250068797264, 0.03424818569328636, 0.012874598851340124, 0.030506462644552812, 0.05405260053521488, 0.053914486852590926, 0.035493691320880316, 0.028230045245436486, 0.02320785770280054, 0.06356185374897905, 0.028448615157685708, 0.003446197988523636, 0.10586024887743406, 0.034503929782658815, 0.03149287338601425, 0.056634962747921236, 0.050514645263319835, 0.03732399447471835, 0.0356300052953884, 0.06440442142775282, 0.048767381013021804, 0.0394491788756568, 0.08224243807489984, 0.09176038554869592, 0.06935495461220853, 0.026427661687193904, 0.11406584177166224, 0.04461934695427772, 0.04071548319188878, 0.017152043983514886, 0.039457906532334164, 0.06963795778574422, 0.04755120135087054, 0.022485052249976434, 0.0170198693376733, 0.05865977167559322, 0.033114766629296355, 0.038850072742206976, 0.04858223743212875, 0.026429977187945042, 0.05022531157010235, 0.004569306765915826, 0.03721452027093619, 0.025494282963336445, 0.012534889101516455, 0.07735816383501515, 0.05576023038884159, 0.02171081410779152, 0.016467080640722997, 0.0569466981687583, 0.019657924167404417, 0.009481208380748285, 0.026376162204542197, 0.05235023993009236, 0.03465316454821732, 0.028065967526345048, 0.05741466680774465, 0.027374972378311213, 0.027743530336010735, 0.03611884683778044, 0.06319503983831964, 0.03220653743483126, 0.040671811511856504, 0.018617473942867946, 0.005754661788159865, 0.02468401911755791, 0.0275477369359578, 0.05205068315262906, 0.025783841156226117, 0.03202280022378545, 0.11638282681815326, 0.06552564329467714, 0.02561920311563881, 0.05004168568120804, 0.07865697421948425, 0.05379550202633254, 0.015708379360148683, 0.05262279366434086, 0.04536222193564754, 0.008217307695304044, 0.0998963278834708, 0.03914600041753147, 0.019580898515414447, 0.052635491811088286, 0.02340454353543464, 0.013412151256488869, 0.011847355144709582, 0.013156405311747221, 0.00419544245232828, 0.030620144825661555, 0.07343098550336435, 0.05318537128914613, 0.021130144777998794, 0.020626543773687445, 0.0632440290064551, 0.10970232513500378, 0.01610111092304578, 0.03342114374390803, 0.03393020509975031, 0.09490614174865186, 0.03307380378828384, 0.028183954163978342, 0.03840115503408015, 0.023816685970814433, 0.03902570198988542, 0.009331825185654452, 0.026889654182014056, 0.03666673736006487, 0.035062533206655644, 0.04321375636209268, 0.012552029929793207, 0.023390305432258174, 0.044392984491423704, 0.04655828197428491, 0.039321106451097876, 0.021839018263563048, 0.02371898779529147, 0.059853037528228015, 0.016958781307039317, 0.026550798829703126, 0.047050381544977427, 0.01956271404196741, 0.05082618030428421, 0.0587031984468922, 0.08036558370804414, 0.02743615688814316, 0.02155529520678101, 0.01977258227270795, 0.007735082399449311, 0.025262038980145007, 0.0327337109047221, 0.01570416396134533, 0.02068243862595409, 0.04630115377949551, 0.04415213530592155, 0.09032015892444178, 0.020678199107351247, 0.06854045495856553, 0.06013102007273119, 0.014993781132943695, 0.04613388853613287, 0.02636855704622576, 0.0049150130689668, 0.01411270619428251, 0.037044293858343735, 0.1338419844978489, 0.016108395102492068, 0.10163080121856183, 0.014774603587284219, 0.03610580359236337, 0.023387424043903593, 0.050074069295078516, 0.00395366650991491, 0.03847308398690075, 0.014772028334846254, 0.05526583387108985, 0.07004610190051608, 0.031923204005579464, 0.04016247927211225, 0.0873919484729413, 0.0578546601900598, 0.03641744995547924, 0.02635107946844073, 0.08388209462282248, 0.036334184696897864, 0.04996905168809462, 0.026101014664163813, 0.03458772196609061, 0.03716679275385104, 0.026248620415572077, 0.04037474835058674, 0.026349224099249113, 0.020857795134361368, 0.027294516148685943, 0.016341303307854105, 0.04042999382363632, 0.04174533183686435, 0.011186732390342513, 0.03467337322945241, 0.11589479050599039, 0.009301570607931353, 0.02665136726136552, 0.016724270062695723, 0.03134248829155695, 0.04916885693091899, 0.06163848527648952, 0.0794513245637063, 0.034315658049308695, 0.07748163494397886, 0.0336417842481751, 0.08452678346657194, 0.09939069524989463, 0.04252682818332687, 0.017132280590885784, 0.008021315770747606, 0.013186111627874197, 0.05116756452480331, 0.03825755316938739, 0.06341902000713162, 0.05031348242482636, 0.27070106647443026, 0.17728825943777338, 0.20795144140720367, 0.14835015521384776, 0.0697402108926326, 0.07040975426207297, 0.14931813842849806, 0.1440327853197232, 0.2684677066281438, 0.17512902530143037, 0.07542032719356939, 0.17252275109058246, 0.12843319738749415, 0.176486769632902, 0.07576176707516424, 0.19666919368319213, 0.11416627661674283, 0.09021709687658586, 0.06579392967978492, 0.09945433441316709, 0.13909845321904868, 0.20346646488178521, 0.10546532983426005, 0.16423631604993716, 0.12495638395193964, 0.1190438715275377, 0.17981225915718824, 0.09634442394599319, 0.13621602585772052, 0.10193478490691632, 0.08668236623634584, 0.08418627869104967, 0.17896276724059135, 0.21221154718659818, 0.11488926204037853, 0.07162650537793525, 0.09915285918395966, 0.08213677851017565, 0.18751230847556144, 0.13108259037835523, 0.08751046945690177, 0.11613997383392416, 0.0994623644510284, 0.1685913573601283, 0.1319045783020556, 0.1068404849502258, 0.31414158234838396, 0.1478665866306983, 0.19324249005876482, 0.0822164183773566, 0.14975043945014477, 0.15346134110586718, 0.14375569706317037, 0.08845157208270393, 0.1233566994778812, 0.18709798227064312, 0.25871630175970495, 0.316740256967023, 0.07010037516010925, 0.10737811157014221, 0.15274562872946262, 0.10646080219885334, 0.10204587699263357, 0.06564075039932504, 0.1330534674343653, 0.07280791542143561, 0.33865005942061543, 0.1706769407610409, 0.13596705015515909, 0.10150142261409201, 0.17968959698919207, 0.14918820321327075, 0.0890054740011692, 0.11279165584710427, 0.1087964819453191, 0.21219431451754645, 0.13720300805289298, 0.12031235775793903, 0.17963844817131758, 0.12093412165995687, 0.0792639545397833, 0.1272796030389145, 0.10720133941504173, 0.09286001091822982, 0.11996837230981328, 0.18192335759522393, 0.10218199429800734, 0.13676564558409154, 0.1852024332038127, 0.1769275905098766, 0.15707730723079294, 0.10759216180304065, 0.1404374509002082, 0.18590903200674802, 0.1602299654041417, 0.1523390950751491, 0.16460347134852782, 0.08585409974330105, 0.16147568996530026, 0.08761589153436944, 0.17429750820156187, 0.11953275388805196, 0.09193639329168946, 0.1897483252105303, 0.06467031067586504, 0.10757696261862293, 0.1684079726692289, 0.08832530307699926, 0.13842961488990113, 0.1572111461427994, 0.15724791213870049, 0.23917495971545577, 0.13199586246628314, 0.14911798120010644, 0.13171415805118158, 0.06884820133564062, 0.1132603369478602, 0.14764529303647578, 0.1019045572320465, 0.06598113643121906, 0.1660603962955065, 0.34887142188381404, 0.14304090494988486, 0.13544131274102256, 0.0629128678701818, 0.16500040161190554, 0.09095666187931783, 0.2512670389842242, 0.09637074792408384, 0.15823349909624085, 0.10843872223631479, 0.12259259907295927, 0.14316739659989253, 0.09617443502065726, 0.13282588042784482, 0.14743750652996823, 0.14759271929506212, 0.18117252679076046, 0.09052531080669723, 0.1745566216413863, 0.08438962715445086, 0.13180888578062877, 0.11709384882124141, 0.26762590336147696, 0.19293158955406398, 0.09130781647399999, 0.19882004155078903, 0.16563461133046076, 0.1380886128754355, 0.10516570997424424, 0.12342147412709892, 0.13809984899125993, 0.1504813361680135, 0.1815544062992558, 0.11501450688228942, 0.1400083559565246, 0.16071163408923894, 0.12572964245919138, 0.11258071521297097, 0.08399817394092679, 0.08794454421149567, 0.19757281785132363, 0.19852664088830352, 0.1169641139858868, 0.2845646225614473, 0.09673822234617546, 0.09063249177415855, 0.2209708490408957, 0.13520349893951789, 0.11238544131629169, 0.10854899053811096, 0.1354431829531677, 0.1105119043495506, 0.1178318182064686, 0.23917018028441817, 0.17462581949075684], [0.019138452335027978, 0.022718158979841974, 0.02390529654803686, 0.0655792560428381, 0.03021473366970895, 0.03150689626636449, 0.0510211647633696, 0.0065365570389985805, 0.030121557028905954, 0.03549943554389756, 0.006465249634857173, 0.029753414673905354, 0.05438797707029153, 0.04362860578112304, 0.011986412282567471, 0.07103810843545943, 0.043292346090311185, 0.04577176499878988, 0.03982391892350279, 0.04118653916520998, 0.024656904752191622, 0.11695497814798728, 0.016368983560823835, 0.009721000933495816, 0.06316042607068084, 0.012280075479793595, 0.030220767330320086, 0.04235201529809274, 0.03396020641957875, 0.011701790299412096, 0.06977657612878829, 0.030957005656091496, 0.04188582781353034, 0.053270443677320145, 0.016518717420694884, 0.05610282802081201, 0.03870651540637482, 0.01185057328257244, 0.007416810512950178, 0.06395433854777366, 0.10204856356722303, 0.013829305044055218, 0.04760971598443575, 0.036016478698002174, 0.011512556557136122, 0.09380549963680096, 0.03043111239094287, 0.0576738433301216, 0.014198639473761432, 0.04888859599304851, 0.03098838551522931, 0.05465567715873476, 0.06336447957437485, 0.054973984297248535, 0.034421566233504564, 0.038494955078931525, 0.05098457317217253, 0.03265817140345462, 0.016210022949962877, 0.048538120463490486, 0.027865962438227143, 0.0170297399017727, 0.04569090800941922, 0.03582636272767559, 0.0440919026004849, 0.06986033491557464, 0.03425323229748756, 0.02776724380964879, 0.05260636993625667, 0.05756134858529549, 0.08406225097132847, 0.016510032437508926, 0.01897481062769657, 0.03308696948806755, 0.04858863845583983, 0.0025989863206632435, 0.055317750811809674, 0.03544081700965762, 0.0824098962766584, 0.05597596158622764, 0.07653412016225047, 0.01940298345289193, 0.04024565547297243, 0.024348855949938297, 0.028365171783661935, 0.07735039354884066, 0.02713458517973777, 0.032024295651353896, 0.012742298968078103, 0.029149425208743196, 0.05362727941246703, 0.030289686874311883, 0.018821674020728096, 0.056506489563616924, 0.05263421902782284, 0.033098550702561624, 0.009471880512137432, 0.02714132202527253, 0.04618602069967892, 0.04968877590727061, 0.045855924545321614, 0.04303981550037861, 0.028453021659515798, 0.08577371772844344, 0.0850379525218159, 0.02327507401787443, 0.04874237063631881, 0.07756586870527826, 0.015379115338873817, 0.018382849521003664, 0.034594794633449055, 0.0393083526432747, 0.05023187586630229, 0.037853001049370505, 0.009030347173393238, 0.07336120135732926, 0.058234899552189745, 0.031299762849812396, 0.058572354100761004, 0.05981988950225059, 0.015287609458027873, 0.04036505219119135, 0.03861877499730326, 0.031437780053238384, 0.06960704733501188, 0.03772163348912727, 0.039975855106604286, 0.03978284847107716, 0.06543993265950121, 0.04404768544191029, 0.05739306659961585, 0.02881398373574484, 0.04228930381941609, 0.05790395363874268, 0.051143448436050676, 0.011670137701003114, 0.027873662220372353, 0.03357425252033863, 0.06862914902740158, 0.14910068915924057, 0.04557303269393742, 0.041746504430193454, 0.08367657908820547, 0.012373401477816515, 0.113744848058559, 0.007684487409278518, 0.010283757601428078, 0.04725015285657719, 0.08938679689890705, 0.04283103822672274, 0.07848013527109288, 0.031196344571071677, 0.04860499167989474, 0.015237820625770837, 0.012543675202323357, 0.054529367334907874, 0.017608694870432373, 0.0789897606591694, 0.035975979699287564, 0.047330122979474254, 0.03262376914790366, 0.027046067370974924, 0.023548948774987366, 0.023384997221000958, 0.03854645270621404, 0.03249290253734216, 0.025161390767607372, 0.033998490107478574, 0.02123261681845179, 0.039703431248199195, 0.04976366231858265, 0.04490710729442071, 0.025335999562230427, 0.018725471272773575, 0.06556891050422564, 0.03142704488709569, 0.029245501791592687, 0.02109029515850125, 0.004655439961425145, 0.0447074807016179, 0.04328559625719208, 0.04370051246951334, 0.0360824704694096, 0.03744165085663553, 0.03612464672187343, 0.05213374060986098, 0.036725749232573435, 0.10354736790759489, 0.03747649840079248, 0.03709475618961733, 0.01752636286255438, 0.032963494668365456, 0.054056819644756615, 0.02767187968856888, 0.02222647501184838, 0.03780770406592637, 0.08140159217873588, 0.052927927681594156, 0.049798880936577916, 0.03827930922852829, 0.0354756126034772, 0.036174088600091636, 0.018514732873882167, 0.08669101967825554, 0.05095296881336253, 0.031752157519804314, 0.03688545941258781, 0.031190169902401976, 0.08568048913730308, 0.050883362782769836, 0.07544312597019598, 0.023760169569868594, 0.014293687254394172, 0.029576976485259365, 0.08326473907800391, 0.05261339065327775, 0.029580488699139096, 0.0057712942452781135, 0.030071363726165146, 0.0702731248748023, 0.0862860593770165, 0.06630449017393403, 0.05130727011419367, 0.07930211577331647, 0.05579060649324674, 0.02093553324812092, 0.03011964599863859, 0.012970250554644736, 0.05382569259381853, 0.06249470476177521, 0.008170750916178804, 0.023737346673442516, 0.06395916992914863, 0.0743415487522725, 0.05370133832911961, 0.02055584864137927, 0.0423008330835728, 0.06176149625389371, 0.011484441220090957, 0.029390782765403856, 0.04320043110055849, 0.04778678499860689, 0.030846455338178203, 0.03397933156520594, 0.03067508601816371, 0.07814818745828234, 0.016652432022965513, 0.03255192183132749, 0.027648548420984298, 0.027465850216685794, 0.02879798488720553, 0.04198958748020232, 0.04032949589600321, 0.04303937021177262, 0.057447926155873574, 0.07924916353658773, 0.0311049342417391, 0.014658311829407467, 0.019279948355688248, 0.04239822883391753, 0.0686171262350399, 0.03515588054142427, 0.04179547875537537, 0.008917944269342115, 0.12584979616804048, 0.040429982691421174, 0.06013328362314496, 0.03613176762883086, 0.034440709932823665, 0.07237646044814028, 0.04920624262013007, 0.009903765003400622, 0.018202726569143124, 0.024237826946773566, 0.013276040444907267, 0.0189557263001916, 0.03653152918559499, 0.044009858174831606, 0.04802240575372707, 0.013068974749330664, 0.10897475323872641, 0.02008801544434391, 0.03331839710881468, 0.017194066240335815, 0.059783312754007056, 0.03557137562893331, 0.04583800538966898, 0.016302490839734674, 0.03964402603742201, 0.03410786412132438, 0.028162164708191995, 0.012898217701149406, 0.11848820329760201, 0.05958317779004574, 0.016799714940134436, 0.05151871911948547, 0.03498703081277199, 0.026279521589458454, 0.028054109861841425, 0.013519809981517028, 0.019817157517536543, 0.047585529391653836, 0.0400844090472674, 0.03324550336401444, 0.018829166001523845, 0.019504776428220794, 0.045761022411170416, 0.036268660478526726, 0.04897033613815438, 0.025809428552747704, 0.06422150428988971, 0.07058920557028614, 0.02070484963041963, 0.013704295834031655, 0.15499053639359772, 0.0975005044892896, 0.040624510729685426, 0.013503517056960845, 0.07227009584312327, 0.024692720799066592, 0.06609547912376001, 0.038337508449330926, 0.009716913555166684, 0.018082997739838902, 0.030239818261179607, 0.026406768374727108, 0.05962921692116652, 0.01684050337644294, 0.023449727341358084, 0.02584694968390977, 0.06286843548878096, 0.013886122942494694, 0.022923344258742873, 0.056623544805916026, 0.07799572063959204, 0.03425813789363019, 0.02636904871906154, 0.056614190034451894, 0.014753417126485147, 0.03288982537924312, 0.039236850425368175, 0.06300766239291988, 0.011233897730562603, 0.006926451278559398, 0.021802580668008886, 0.04000599743449129, 0.10033572383690625, 0.028535956662381068, 0.021079942198412027, 0.03637686560978182, 0.07089620237820782, 0.0087268607239821, 0.12035235209623352, 0.1002014173718635, 0.11666585225611925, 0.11043268008506857, 0.0898743508150801, 0.11529311654157937, 0.09862888065981679, 0.17384482780471444, 0.1497221042518504, 0.10435234580654651, 0.17114360322011635, 0.1508390810340643, 0.10675538287614472, 0.08821026276564226, 0.12932344805449247, 0.23323458706727251, 0.1653416856424883, 0.1485221553593874, 0.16501785692526028, 0.16480058577144518, 0.1288884604582563, 0.1986376810236834, 0.09711774924653582, 0.10118313774000853, 0.15606611617840827, 0.15745492681162432, 0.09283312290790491, 0.21366051631048322, 0.08954074801295064, 0.18220086145447567, 0.2777680638246238, 0.10864204843528569, 0.14152701274724677, 0.12338472297415137, 0.32323983788955957, 0.11542983498657122, 0.09127511002589017, 0.08653631899505854, 0.12865745957242325, 0.17146666010376066, 0.16144107619766146, 0.10262167968903668, 0.21660814876668155, 0.2203350214404054, 0.1666641334304586, 0.21013990131905302, 0.1621513263671659, 0.12713345931842923, 0.1780213083839044, 0.09169092794763856, 0.09052866531419568, 0.10120612205355428, 0.1287572635919787, 0.15273041470209137, 0.10542443749727681, 0.15460867172805592, 0.17501470487331972, 0.1933835426461883, 0.1360281289089471, 0.10807225713506341, 0.10956819678540342, 0.10357810024288483, 0.11093477267422713, 0.07796262827469036, 0.08268456513178535, 0.1436616966384463, 0.11296249824226834, 0.18622705712914467, 0.13485348725225776, 0.20625330362236127, 0.19943204621085897, 0.08395625001867302, 0.07523469379520975, 0.06908775918418542, 0.10656656566425227, 0.127182025462389, 0.24893941154005006, 0.20186115492833778, 0.24014482798520476, 0.13956044014776126, 0.16818152857013047, 0.09426903023268096, 0.08888550582923926, 0.12758942000800744, 0.19486388977384195, 0.13521063840016723, 0.17702356504742056, 0.07925867044832557, 0.3049416228896007, 0.11162184557178989, 0.17951900692423806, 0.0823826965643093, 0.1089006349502597, 0.19202422496164218, 0.1287096770829521, 0.10569244928774424, 0.10575627398793586, 0.16893091960810125, 0.09895517330733128, 0.0986121674941387, 0.1275142701342702, 0.15332940209191293, 0.2367823795066215, 0.1248451805440709, 0.2533897594548762, 0.11071929751778953, 0.11913962342077866, 0.1576216280227527, 0.14936599211068824, 0.12461404607165605, 0.20244804531103, 0.17569889081642032, 0.1559351567993872, 0.12968380528036505, 0.1360367823508568, 0.15081273479154333, 0.18358179047936574, 0.13820327469147742, 0.10296380234649405, 0.20885960751911625, 0.13366985076572746, 0.10614747487124987, 0.115229633229319, 0.11378798910300247, 0.09249152717529796, 0.19029321003472432, 0.14383941132109612, 0.15403255732962862, 0.264178627403453, 0.1449432224035263, 0.16583787073614076, 0.07369138285866939, 0.11978940339758992, 0.12698952719802037, 0.1461011212086305, 0.15562628977932036, 0.1085872259864118, 0.1039757726539392, 0.2850854321150109, 0.3649402846349403, 0.081568397290539, 0.1712406612932682, 0.1447107075364329, 0.0585284894623328, 0.17372973554302007, 0.06271659207413904, 0.14124127104878426, 0.1400846487376839, 0.18380623077973723, 0.13371853565331548, 0.14740724174771458, 0.11423997930251062, 0.10072023796965368, 0.13673152163391933, 0.1265200148918666, 0.09853411582298577, 0.1149670391168911, 0.1483978604665026, 0.15733250213088468, 0.08898644533473998, 0.11915325667359866, 0.15233814512612298, 0.0967134939855896, 0.07878380725742318, 0.09857511206064373, 0.10231034131720662, 0.11944043813855387, 0.10643064131727442, 0.11015508716809563, 0.13312585651874542, 0.12246029640664347, 0.1351631706347689, 0.18336239678319544, 0.12032725266180933, 0.17927619104739279, 0.10232193366391584], [0.011580911141209072, 0.05714435435947962, 0.054129219861351885, 0.033948294949368574, 0.031120140847633593, 0.0725728104589507, 0.013876751472707838, 0.031265794750652276, 0.051603431566036306, 0.02768512331385864, 0.03625330173235852, 0.059442525962367654, 0.08049127383856103, 0.0420589745772304, 0.05066488192824181, 0.029297737855813466, 0.08334467580425553, 0.0692678487394005, 0.03960454749176279, 0.012740629135805648, 0.029964705972815864, 0.04493875247135293, 0.03619081289798487, 0.030049056622374337, 0.053658219549106434, 0.025315147067885846, 0.021698611344618257, 0.011023812421626644, 0.03885308215103578, 0.04968106499291025, 0.036163060285616666, 0.05344289282220416, 0.018231260291941, 0.09608714361093007, 0.06411443464457989, 0.03395064384676516, 0.04319315805332735, 0.039889498802949674, 0.0257903739111498, 0.024964356125565246, 0.014570987950719427, 0.03802494924457278, 0.10036593666882254, 0.018017282418441027, 0.06703722741804086, 0.08301473179017194, 0.08690607923199423, 0.02788504119962454, 0.016560476215090603, 0.025884307542582974, 0.06068638031138107, 0.049859941136674024, 0.005844230199727463, 0.07044602301903069, 0.02316537716978928, 0.03955596279411111, 0.025563530907675158, 0.026621640536177438, 0.04874600715993438, 0.012704198034043657, 0.0859201731509529, 0.10152143833693117, 0.04140874189033639, 0.008019932593015255, 0.0941359854186885, 0.08307873460580595, 0.02301883083418943, 0.028570370050147176, 0.03292328881798312, 0.01699202024610713, 0.0984659866662696, 0.016330996731994674, 0.007082863075993373, 0.021312887511157896, 0.028817225065722596, 0.021408734028227627, 0.03925548204279039, 0.023019459804345388, 0.06038407016603742, 0.04018731153337285, 0.02932551273261197, 0.02568741390859941, 0.04726722967461683, 0.03500079023069702, 0.01847666997491615, 0.03813406721747015, 0.0481694882910233, 0.04093821284186561, 0.051890241957153194, 0.039171277967398055, 0.05539317899092566, 0.07612426910782233, 0.07405406300676987, 0.0493719159567263, 0.05952286344836466, 0.026071187749039382, 0.06432421010686085, 0.0068971526798122795, 0.03288074891315773, 0.0500480681512272, 0.1292458936222829, 0.029644600981555413, 0.006078613423596835, 0.005289568971420522, 0.028229906092747115, 0.03398287903110031, 0.05204510591283906, 0.07316712231840938, 0.03533481234626379, 0.05209367947827559, 0.04511178791290149, 0.01931248410983244, 0.01726625308947405, 0.0739525594690349, 0.05982660593872424, 0.017166079851449467, 0.06369298382196575, 0.07365536643192172, 0.05481250409502536, 0.010562130701146089, 0.01131526216340717, 0.025980610480473842, 0.03032603912288323, 0.058707265416160226, 0.09408996484125964, 0.007619664056619513, 0.018924403957498726, 0.058926933706970885, 0.013760248202743242, 0.04684665458626114, 0.026352209388278425, 0.054554155067307875, 0.015657375261071138, 0.0933701112808194, 0.033742204250302166, 0.0358382445119787, 0.03998559208412189, 0.06578941742191091, 0.061702929669991136, 0.0053017272057331866, 0.02364514224609593, 0.01582378888997482, 0.05429139768239111, 0.05281169622321613, 0.04451280052307993, 0.011403868102206616, 0.023632705706404522, 0.054571413711528294, 0.15678460418712348, 0.06773446773877367, 0.052838702977169305, 0.06262725975830108, 0.013169948579161428, 0.05455975086078979, 0.035929161313106306, 0.039253088616533205, 0.0647302762081381, 0.01822096670366591, 0.03935215419915039, 0.02921163944847649, 0.05142278540006373, 0.04485328674491029, 0.03630784587585367, 0.04347586436779238, 0.028890842404507566, 0.04901744767266791, 0.032580364641034976, 0.029979730752529576, 0.06668232497759163, 0.06607191593502648, 0.04591259123117197, 0.04487690930545796, 0.023005514849501196, 0.04662436280341353, 0.01586152153322473, 0.06588897653273307, 0.029456930387823377, 0.07054284360492602, 0.05193512704863679, 0.04381592385470867, 0.005218663254709099, 0.03628725869930349, 0.04867454947088845, 0.034537322717369534, 0.04658538520743605, 0.02138276628102176, 0.0367468262265902, 0.02188399426813703, 0.1283818407682702, 0.027621586195891723, 0.050530044827610254, 0.01140314358053729, 0.023729750791972037, 0.023278762491827365, 0.05780059102107771, 0.04441357166797388, 0.048192561662290245, 0.05944118638581131, 0.01039223918269272, 0.03397895678062923, 0.021609446012007538, 0.027009195619029924, 0.05738809049944393, 0.04396124750201125, 0.012569886930577923, 0.013706066783925053, 0.02709772641537711, 0.02092762937536463, 0.06970896647544578, 0.08396900011575781, 0.016536619878024794, 0.03405714203836396, 0.040204599863500334, 0.009762935060280142, 0.013665139194927178, 0.049299730962957256, 0.03901022450008895, 0.020034499175380915, 0.0198041977637331, 0.052576194211724214, 0.04762429547554348, 0.05851257410540711, 0.05070708786661271, 0.0503914673026884, 0.09144686526269652, 0.018684849819692317, 0.07796856545610353, 0.03690309284138493, 0.049080600729212165, 0.021269521967042238, 0.03865875078190584, 0.055379044788423926, 0.05393197185185272, 0.015432865384354955, 0.05486909285536967, 0.03738991203135811, 0.056651568302186206, 0.021428046566143166, 0.03650093414762523, 0.05238104648014996, 0.02666829008376226, 0.06220404262421653, 0.017934137758857105, 0.06272264057770371, 0.026228051792713813, 0.060862042955704965, 0.04019810236059129, 0.037612445012200624, 0.044275487671257, 0.05404287097917404, 0.03235945325286593, 0.04635246215912048, 0.01584034806001, 0.04844517017772887, 0.027783212972281035, 0.0257345792488195, 0.02580491258413531, 0.022722866051481105, 0.01761984563927399, 0.03292211622465402, 0.051670265675056726, 0.04598228260874748, 0.06262604263611138, 0.0498762795177754, 0.024752489662205335, 0.04822195442102384, 0.0177137273203698, 0.0538968088949332, 0.006834733421783312, 0.05857632088009268, 0.015427469970745733, 0.10839742913958617, 0.0327852567716036, 0.04728731219074689, 0.030015567208465654, 0.06833143648691475, 0.033590620587347075, 0.041241124126827344, 0.010608025113469921, 0.0424289314833004, 0.023225251788971946, 0.05331884654879104, 0.020424011672730558, 0.037619183713104576, 0.015658126685593743, 0.030573022158932872, 0.029194917005952448, 0.02102683596604038, 0.05976310778351035, 0.040151617940864526, 0.06262290335143916, 0.03895986978022847, 0.02099329274642514, 0.03755876918148715, 0.07214338154881261, 0.075240438018227, 0.04188626568065956, 0.06686461871140637, 0.014509265383821912, 0.031440811726497486, 0.045021123441983946, 0.052574576329789124, 0.04300917593354825, 0.01944545470905723, 0.008714940904610557, 0.020648615245590918, 0.045399269947665744, 0.027685963796102442, 0.006635239951719996, 0.07348744809860364, 0.08335875434568152, 0.0131427766973502, 0.058487218630034477, 0.020097273736610077, 0.05206763751630206, 0.03397872671484947, 0.004217372452330892, 0.030124597979011014, 0.06032123252225574, 0.06295377505011857, 0.05631650717987213, 0.0639331502316054, 0.01633042898902204, 0.048006675933720544, 0.02191726103774272, 0.04243863506417256, 0.029613206279464066, 0.06906092312419787, 0.03749633229745086, 0.06155024020699784, 0.005131635307407123, 0.03190236820955761, 0.03475394449196756, 0.031166814515017904, 0.021385883301263675, 0.0484168572438648, 0.04108992638066411, 0.03804063453571871, 0.02340773291507503, 0.03887529092025943, 0.04191599982732441, 0.0800398328283336, 0.022708592696289998, 0.06744536411133595, 0.06796552799642086, 0.07931808679131791, 0.019077158358413726, 0.054584802055615, 0.026708132281783037, 0.06556145934155211, 0.029350213262659963, 0.027014488987333607, 0.14153750671539456, 0.1411406061379239, 0.13006933615542948, 0.14672124496428296, 0.15307419234886765, 0.2316471331869252, 0.10638888066750951, 0.165127026848495, 0.1135874014289584, 0.1265054094255902, 0.19243614660808817, 0.16707320522982627, 0.1924598656478338, 0.13554487202782184, 0.11195133687579073, 0.10862607741728425, 0.23689028777880594, 0.10935584607068449, 0.12174684758065268, 0.08775782727752812, 0.1904401255887933, 0.15576110832626, 0.17849049414508045, 0.12652881676331162, 0.12232387482072227, 0.16297867259709165, 0.10776851093396544, 0.09208811796270311, 0.06583315960597247, 0.10449299021274783, 0.10731522939749993, 0.10622486603097059, 0.08680113955051638, 0.17291225987719372, 0.18608607875648886, 0.12681402411544695, 0.20990101882489398, 0.1406127164955251, 0.1125065004453063, 0.11969321363721974, 0.107269401778467, 0.12869017344200984, 0.2109828474931419, 0.11817455684649758, 0.1886656801798381, 0.25501672527752817, 0.1392198834219016, 0.15411532163852826, 0.16034787782700732, 0.16557543247472495, 0.15934084280161187, 0.24421028327196836, 0.08769137537456118, 0.1610396188334562, 0.0807946638087742, 0.10650249605532736, 0.23591320583363995, 0.05918945731536951, 0.1676412599044852, 0.13017951539950445, 0.15915708703687415, 0.21414424816612154, 0.10718825535150245, 0.11680265233735554, 0.2642157644731924, 0.23452617635484785, 0.1785282843047753, 0.2419839144567959, 0.0951648098998703, 0.1115830683556851, 0.2106084636761807, 0.11699818598572165, 0.12263594049727544, 0.12386429880280048, 0.08973893112852238, 0.12804809695808217, 0.14524546946631745, 0.11094471003161743, 0.15870566829107702, 0.09305711049819365, 0.1432605361333117, 0.13572795985965058, 0.11357465133187361, 0.07599204065627418, 0.16088587552076206, 0.1480065259966068, 0.11165720148710534, 0.20456717378692701, 0.13941379176685587, 0.11875533193233423, 0.16153998964000493, 0.13496454223059118, 0.12050117496983148, 0.1245910840225406, 0.2101883784052916, 0.2741540124407038, 0.132471727556549, 0.11119857648736797, 0.07830486225429922, 0.23098463279893622, 0.321317853522487, 0.12627627875190228, 0.09293966562836431, 0.09458611282752827, 0.06458766511059366, 0.16298173024551943, 0.13160371163394302, 0.16971933277091011, 0.09382849879330024, 0.11596418131375685, 0.11151660160976462, 0.19274955557193607, 0.09804089189856313, 0.19339520920766518, 0.1978873845655471, 0.13873815536499023, 0.16966095543466508, 0.17599616548977792, 0.225617777032312, 0.16000708361389115, 0.12853721680585295, 0.15783800859935582, 0.10658774655894376, 0.2512270520674065, 0.1937413914129138, 0.1257947733392939, 0.1098340934549924, 0.17115853523137048, 0.11288032765151002, 0.11498956329887733, 0.15266396279912442, 0.22533188690431416, 0.08202020937460475, 0.23631452961126342, 0.19682793907122687, 0.0950558997283224, 0.21591538359643891, 0.13199225562857464, 0.16378805885324255, 0.11689876788295805, 0.09237290229066275, 0.14596980559872463, 0.2365626147366129, 0.15533082594629377, 0.10307187389116734, 0.10195946873864159, 0.09449338147533126, 0.12908983480883762, 0.23027576302411035, 0.09701012299046852, 0.09578266268363222, 0.19787119090324268, 0.10851849569007754, 0.2323069321573712, 0.08350899472134188, 0.10447090389789082, 0.2120894193649292, 0.18981499975780025, 0.10867681063245982, 0.17585613706614822, 0.15042853978229687, 0.15459056332474574, 0.14624065981479362, 0.1475801769993268, 0.07161047498811968, 0.15048249391838908, 0.10595849438686855, 0.09547778099658899, 0.22927312151296064, 0.18467822461389005, 0.14154292439343408, 0.17436519206967205, 0.09934330169926398, 0.1582465460523963, 0.07142792892409489, 0.11280404971330427], [0.06737228482961655, 0.037940619004075415, 0.06182522818562575, 0.043211533629801124, 0.023300164175452664, 0.023207030208141077, 0.021308716641215142, 0.04680033714976162, 0.023310908618441317, 0.014948032367101405, 0.04249239253113046, 0.02393458540609572, 0.024029298292589374, 0.08853747567627579, 0.02774941000097897, 0.011244272955082124, 0.024676152352185454, 0.011655307735054521, 0.040047438960755244, 0.027614917999017052, 0.06578955842996947, 0.042033010540762916, 0.06346044669044204, 0.02711110733798705, 0.03572172732674517, 0.050432285424903966, 0.03694509097840637, 0.07828634566976689, 0.04733094305265695, 0.02884548419388011, 0.018857293398468755, 0.004063047481395188, 0.028005257991026156, 0.04651973482395988, 0.016024374708649702, 0.026846689397643786, 0.01206244252898614, 0.05822303632157855, 0.0412662977760192, 0.09805229128687643, 0.020338516260380857, 0.053017575410194695, 0.06439636170398444, 0.06197011025506072, 0.0774283338978421, 0.023895149533927906, 0.044217533359187655, 0.03815841337200254, 0.02268610376631841, 0.12956431950442493, 0.04013743549876381, 0.049446884004282765, 0.04042991218739189, 0.052027906640432775, 0.0451176731439773, 0.018648479017429054, 0.06576418440090492, 0.05654858046909794, 0.0253822836020845, 0.07051943626720458, 0.008332886063726619, 0.029421216386253946, 0.04139208438573405, 0.026958243470289744, 0.07033017376670614, 0.01731229593133321, 0.024724568211240694, 0.02954108436824754, 0.03910095947503578, 0.032738200898165815, 0.015722149910288863, 0.022806877168477513, 0.03978725682827644, 0.00911150658794213, 0.06614282072405331, 0.03638137786765583, 0.01835942177422112, 0.055984607606660575, 0.022315605092444457, 0.019439732750470284, 0.03621790499892086, 0.03355389540956821, 0.02476549765560776, 0.0984248865279369, 0.030772164500376675, 0.031824457546463236, 0.0207341588975396, 0.04340480001701508, 0.04947575354890432, 0.09270042690332048, 0.053991351087461226, 0.014114217392489081, 0.15538970794295892, 0.06766216029063798, 0.03139209344226401, 0.04502754301938694, 0.057077375531662256, 0.03126344585325569, 0.07822835425031371, 0.030642852689197753, 0.007122788765627774, 0.02642911629664013, 0.06938452177564614, 0.05193405464524403, 0.040882496105041355, 0.03047572845389368, 0.031687779919593595, 0.04746021033497527, 0.05663870688294992, 0.050317378700128756, 0.018883639640989713, 0.07387582882074639, 0.052532118061208166, 0.08103112690150738, 0.045071719359839335, 0.030910742025298532, 0.03012591343576787, 0.039114945248002186, 0.06273858933127485, 0.037368827615864575, 0.026417021144879982, 0.0580636081576813, 0.02275891587487422, 0.020328630853327923, 0.02122559610143071, 0.003885200371769315, 0.04497457965044305, 0.043979593392577954, 0.06587976648006588, 0.07242696359753609, 0.03831221976724919, 0.0356064792140387, 0.03180943647748791, 0.013002194446016802, 0.0425225051731104, 0.010700556085794233, 0.009493000179645605, 0.06000002729706466, 0.05893594709050376, 0.020486307548708282, 0.040730660111876205, 0.05419103334133979, 0.031093970865185838, 0.13197211374063045, 0.04218911759380717, 0.03273654590884689, 0.03395866275241133, 0.029960097235743888, 0.039881969714770094, 0.059446117957122624, 0.022883891688252334, 0.03505759050312918, 0.02266799350763904, 0.03520523336192127, 0.03260698176745791, 0.04517551242315676, 0.004950639404341928, 0.06336847975035198, 0.06654839700786397, 0.033375356942997314, 0.02432782534015132, 0.020105376133869868, 0.05522229948837776, 0.07184570611570962, 0.06821232920628972, 0.011882816816068953, 0.05675553948094603, 0.03317385271657258, 0.02585165304481052, 0.010896604599111015, 0.007571477335659438, 0.07480303844204172, 0.060868763102917, 0.04616755606548395, 0.048927102325251326, 0.05859875229361933, 0.05253290102700703, 0.1231520893634297, 0.10098545928485692, 0.014549301467923215, 0.0264398570288904, 0.013402418917394243, 0.022067796417104546, 0.01134551395807648, 0.04738187664770521, 0.10185180537519045, 0.015507243424508488, 0.03722757835930679, 0.05101827409816906, 0.08654086836031638, 0.0435563985229237, 0.005686148570021032, 0.03292003078968264, 0.04232814782881178, 0.04588343595969491, 0.017418786701455247, 0.03673739352962002, 0.012875495922344271, 0.028798298444598913, 0.014708237958984682, 0.024699578243598808, 0.05116093343531247, 0.016066274511103984, 0.0508128810179187, 0.053569581141346134, 0.006890950180604705, 0.045801714368280955, 0.0361610601976281, 0.0194316507622716, 0.03633436652307864, 0.011280045400781091, 0.02829349887178978, 0.0011785032597799727, 0.04365587970823981, 0.01877360697108088, 0.03930005172151141, 0.030319706747832242, 0.05595434282440692, 0.06426313877454959, 0.033485755120636895, 0.06523727439343929, 0.020235049742041156, 0.018709921423578635, 0.056679350600461476, 0.045233848941279575, 0.04421933677804191, 0.03798426841967739, 0.06062498614483047, 0.034853251272579655, 0.050189135581604205, 0.06618172410526313, 0.02723237241298193, 0.02096016327413963, 0.04305206464778166, 0.056715003374847583, 0.002373668430664111, 0.04281985777197406, 0.006998753160587512, 0.04606069422152359, 0.02750267001829343, 0.04100598947843537, 0.009530178995191818, 0.03073551539273467, 0.04499816881434526, 0.004000675071438309, 0.005565841329371324, 0.034324218722758815, 0.03876531947753392, 0.01921345934533747, 0.04000993081717752, 0.06067583439289592, 0.03706135212269146, 0.04052613534440752, 0.05694830491847824, 0.003166768256051, 0.044966909554204904, 0.02779091832053382, 0.02752827411313774, 0.01655362248129677, 0.01854033882409567, 0.026829696071217768, 0.027216152775508817, 0.03452569697401486, 0.04556853156827856, 0.07813840595190413, 0.05875809511053376, 0.048358420535805635, 0.0603128536749864, 0.11749051191145554, 0.043014393231715076, 0.04169170424574986, 0.02971224588691257, 0.0564064369245898, 0.03381023692782037, 0.010243222423014231, 0.08112298994092271, 0.02811330912663834, 0.013100678370392416, 0.054273229907266796, 0.05538701545447111, 0.03323758464830462, 0.04319044550356921, 0.010776967610581778, 0.05906449077883735, 0.07156810577725992, 0.03908933373168111, 0.06180751683132257, 0.04974293784471229, 0.020771585404872894, 0.08889574004570022, 0.012701365812972654, 0.02361035963986069, 0.024824112479109317, 0.018985857495863456, 0.03550450441252906, 0.016796659147075843, 0.04214670756482519, 0.06231757637578994, 0.0506095548189478, 0.025684525098768063, 0.016156523379322607, 0.05372553234337829, 0.0040290473771165125, 0.031370396754937246, 0.1242661198193673, 0.055298391889664344, 0.03048405906156404, 0.022175348458404187, 0.05572857779043261, 0.01772075360349845, 0.03112171976681566, 0.022151154444145504, 0.03787975547311362, 0.01860895037680166, 0.019999575561087113, 0.026943740049318876, 0.04967371030943468, 0.021750561681983527, 0.009012348236865364, 0.029382105203694664, 0.014074076480028452, 0.026102176125277765, 0.026165536983171478, 0.06866741416160949, 0.017702543154882733, 0.05919196206377819, 0.009739434026414528, 0.019050019873247948, 0.037695955179515295, 0.04340422856330406, 0.05948240155703388, 0.059454589572851546, 0.027773644833359867, 0.03292050205345731, 0.059918301994912326, 0.10112976990058087, 0.05390471647842787, 0.05316003065672703, 0.04816273103642743, 0.09819658705964684, 0.03418902539124247, 0.05646330399031285, 0.027299186112941243, 0.047555175551678985, 0.003132418414679705, 0.060510955154313706, 0.034159083443228155, 0.005231293216638733, 0.0348157060216181, 0.020681009991676547, 0.01194807107822271, 0.026531428775342647, 0.18587600643513724, 0.13412793399766088, 0.22859542194055393, 0.08493511311826296, 0.06574961604201235, 0.07050793297821656, 0.1130583391932305, 0.0875316429301165, 0.14830935193458572, 0.14585826080292463, 0.0937580170284491, 0.1866584675735794, 0.17393013025866821, 0.1440927805379033, 0.1306374798878096, 0.08438627264695242, 0.08403757456107996, 0.14178303885273635, 0.09873672213871032, 0.07995982930879109, 0.13053595408564433, 0.14979949541157112, 0.12034737970679998, 0.10543072348809801, 0.10627122057485394, 0.20993263431591913, 0.13635728624649346, 0.16442173422547057, 0.1878932974068448, 0.11348059895681217, 0.07828201894881204, 0.08306632589665242, 0.17266684648348019, 0.16796266922028735, 0.10130162903806195, 0.10574514177278616, 0.09680592105723917, 0.24770756514044479, 0.17398969503119588, 0.279423053143546, 0.13450181315420195, 0.0818631931906566, 0.1908641293994151, 0.21685566985979676, 0.15684244717704132, 0.08761005083215423, 0.11443282637628727, 0.18359271489316598, 0.10527648293646052, 0.2263104828307405, 0.1082437155127991, 0.13172460749046877, 0.13982345728436485, 0.1622324579511769, 0.1271973582333885, 0.1543591616791673, 0.12624706781934947, 0.18516915530199185, 0.16206986823817715, 0.16375197563320398, 0.14626583346398547, 0.1571530062938109, 0.1366169488755986, 0.07893046305980533, 0.1375134038971737, 0.10771302055218257, 0.15337173419538885, 0.11622342834016308, 0.2257317560724914, 0.053439527182490565, 0.11414344073273242, 0.06404040541383438, 0.09891016205074266, 0.11410927967517637, 0.1311039790743962, 0.14018942514667287, 0.10599698958685622, 0.1251950438017957, 0.11529155803145841, 0.08450546156382188, 0.1299419836141169, 0.09639284908189438, 0.059726642357418314, 0.2622313506435603, 0.08589093995396979, 0.10244082572171465, 0.1670971023850143, 0.19010238902410492, 0.12706553796306252, 0.14996722078649327, 0.200774650729727, 0.17819296714151278, 0.22892348089953884, 0.16756575379986316, 0.14627692115027457, 0.10924488757154904, 0.18439267587382346, 0.15468408877495676, 0.26857306191232055, 0.20303621218772605, 0.07726398529484868, 0.11289330781437457, 0.17250851669814438, 0.20292564702685922, 0.12785409955540672, 0.14462114515481517, 0.14011843129992485, 0.12694529519649222, 0.1446752477204427, 0.16427728260168806, 0.1579736138228327, 0.21924399014096707, 0.22248129767831415, 0.2267984746140428, 0.09420704605872743, 0.10011943231802434, 0.1158333480998408, 0.09398086913279258, 0.12276891109650023, 0.09538994039758109, 0.09704256226541474, 0.10230301631963812, 0.14374653896084055, 0.07312179935979657, 0.07262298706336878, 0.10683727887226269, 0.15007606416475028, 0.09369369508931413, 0.29085233516525477, 0.17055959237040952, 0.15463614603504539, 0.10153427007026039, 0.13203120353864506, 0.10954622921417467, 0.16032208077376708, 0.10765408660518005, 0.1008685190754477, 0.19808709650533274, 0.11883863058756106, 0.09280705126002431, 0.19952701142756268, 0.13420694303931668, 0.10705026783398353, 0.19252867758041248, 0.12814914778573439, 0.12089134426787496, 0.1286194467684254, 0.17270104464842007, 0.0933567674655933, 0.09179056127322838, 0.12903047783765942, 0.2264840860152617, 0.11126715093269013, 0.1505091370199807, 0.07737789754173718, 0.06699692879919894, 0.14724794717039913, 0.13094434310914949, 0.18980189342983067, 0.20680704968981445, 0.1315558431087993, 0.13574106618762016, 0.1299660885706544, 0.23537151224445552, 0.20364311087178066, 0.10065172289614566, 0.13080222182907164, 0.06916591475601308, 0.11140376547700725, 0.09056027338374406, 0.16830730775836855, 0.14984178298618644, 0.10212074485025369, 0.12360911874566227, 0.13399403571384028, 0.13772487145615742], [0.05412355356384069, 0.008843277719279286, 0.015870946808718145, 0.053355727577582, 0.03727667142811697, 0.030561698840756435, 0.03961754249758087, 0.03346869685628917, 0.004248614550306229, 0.04706945474026725, 0.05952869301836472, 0.08954674456617795, 0.049461229718872346, 0.038987036095932126, 0.06821242568548769, 0.025499047551420517, 0.08910280666896142, 0.02106050720612984, 0.02599168332380941, 0.013354480815905845, 0.030250833588070236, 0.09835801160079427, 0.06386184468283318, 0.06707396372803487, 0.05110726873681415, 0.06335380006930791, 0.03094640593189979, 0.06044520087016281, 0.06922421045601368, 0.011599992685660254, 0.05116504122270271, 0.03404360897548031, 0.054495558797498234, 0.04936723300488666, 0.019441326512605883, 0.03801528648182284, 0.03983600479841698, 0.044811496409238316, 0.06430551540688612, 0.10021934765973128, 0.03992454301624093, 0.03859564596496057, 0.05237909463176038, 0.0678175882785581, 0.01849095817306079, 0.07766201393678784, 0.054111994613776915, 0.02424755093670683, 0.0298211504923529, 0.04735112204798497, 0.058610155392671004, 0.010675388002709951, 0.030092273736954667, 0.02696656851185253, 0.06935733690625057, 0.04589587806549389, 0.08211449181544594, 0.04417341267981101, 0.04129707835090812, 0.03334458378958516, 0.09593253940693103, 0.056590159292682074, 0.05979772155114915, 0.052626411634264514, 0.016048006546043325, 0.0236791437419015, 0.03537583084835205, 0.046478486256091855, 0.07085722478223033, 0.04106713873625267, 0.027613981037575286, 0.029562437812273856, 0.03236859651224222, 0.03586113976780325, 0.01763007243425818, 0.03626931727922056, 0.11080266296630725, 0.04984893508662935, 0.09366680707898922, 0.04268915072316304, 0.03682194641442038, 0.04525922668108251, 0.05458992287458386, 0.055954702766030096, 0.02024759760388406, 0.006454603990277974, 0.012493651665863581, 0.058900988224195316, 0.054625397533527575, 0.0830720849626232, 0.12067460746038705, 0.007181559903983725, 0.020168740702501964, 0.043679995796992444, 0.022574553404410835, 0.028540557977976277, 0.008086914203886408, 0.06356121550197713, 0.06739703545463271, 0.03132933743472677, 0.024927712584030814, 0.0414708188327495, 0.05540387333894614, 0.026453197133378126, 0.05515276767255273, 0.06507144149509259, 0.0342021205869969, 0.07469429154298268, 0.05293479254760314, 0.04433755348145496, 0.05523850428289734, 0.031041937036206946, 0.06171694512886461, 0.03466339876467828, 0.060342365177348256, 0.021208372709224932, 0.03233143717807252, 0.055533289050799794, 0.01209188445500331, 0.04076656521647237, 0.04694573501183186, 0.03164179273881018, 0.07443871072609909, 0.02251667701784754, 0.07509065777412616, 0.07295891278772615, 0.04688153923780192, 0.031159482095972635, 0.017539799446240067, 0.04421721794642508, 0.022707050884491764, 0.07443070295266807, 0.009733521892485442, 0.038212456565815955, 0.047813298224355094, 0.05844565836014226, 0.03542592952726409, 0.053884363078395836, 0.03602755525207613, 0.022778363854740746, 0.004304905060052988, 0.07454699007212184, 0.04933798867568839, 0.03474239296338055, 0.011496653260110179, 0.07313839378184639, 0.035006018661079, 0.03753300552489236, 0.03343831704114564, 0.014343660695885774, 0.02193699845520314, 0.03865229409711901, 0.037762637148262, 0.056416107108816504, 0.04560967623547185, 0.028626379935303703, 0.032242186498478986, 0.028726414020638913, 0.03357043788128067, 0.027220627925998997, 0.015239892145473277, 0.03857936324493494, 0.03408402633795049, 0.033695255988277495, 0.03602072007197421, 0.013079918644507416, 0.07299736345885321, 0.029138600984879304, 0.011542733209353173, 0.04155599141085986, 0.03594755915401038, 0.017638603421801236, 0.05588614316366147, 0.02068639427307062, 0.047320437952294014, 0.059448437168612145, 0.014132385167613393, 0.0005318357227679371, 0.01828206401114585, 0.08006997144548222, 0.03453569741395768, 0.027109324328193907, 0.05447053728858009, 0.04516204244282562, 0.03925045770301949, 0.040732678753556684, 0.022472406053566374, 0.03654986394394655, 0.0024742171490288456, 0.04398806129756849, 0.037309003091650084, 0.04581006724038161, 0.04023486835649237, 0.06752399465767667, 0.036877481325063854, 0.04130629953579046, 0.03825875173788518, 0.03481981751974672, 0.052004198732902296, 0.034734960354398936, 0.043656529087456875, 0.008575457031838596, 0.022019256248313468, 0.033534195099491626, 0.049021926533896476, 0.04451373562915251, 0.026941098003590014, 0.05850136025401298, 0.01606251553312177, 0.0535975638194941, 0.03106811629550066, 0.01526701857073931, 0.004262219044903759, 0.04243213013978675, 0.07222006024676375, 0.05574308306677267, 0.015616813179804012, 0.02138666812243173, 0.0933702893962618, 0.038562512781936675, 0.023426809821103234, 0.007756659879305516, 0.02912453914177604, 0.009340409051219467, 0.05102663810248487, 0.012174665462225676, 0.023722529695078265, 0.0270510304835625, 0.04399846620799508, 0.051317073885002173, 0.020204625398037024, 0.002514848806640657, 0.034697916053119116, 0.057260355752077885, 0.029883468632760923, 0.040675414638826624, 0.05546248074097093, 0.020406001603987534, 0.017022837928379886, 0.057237931760028005, 0.028604612743947655, 0.045951553984195925, 0.07684472380788065, 0.028240014144103043, 0.04489939266932197, 0.007774262230668683, 0.036908499387209304, 0.034562800647108816, 0.05119409259350505, 0.022020833312126342, 0.015405763078888413, 0.03683364637254272, 0.02122410438460065, 0.06749893975211307, 0.030722657684236765, 0.059675612283172086, 0.060964637450524606, 0.09570470749167725, 0.05785140958323609, 0.05895635986234993, 0.026092526350112166, 0.07443152673658915, 0.022399968729587272, 0.07727457574219443, 0.03957095788791776, 0.11865643333294429, 0.14301222836365923, 0.012797236449841876, 0.029731953618465923, 0.04835990854189731, 0.002742852111623506, 0.06750820175511762, 0.0176666306288098, 0.03266022715251893, 0.014787851850996958, 0.030589690795750357, 0.0368237349903211, 0.011918759955733549, 0.037464353154064156, 0.03200514453055803, 0.050615035579539835, 0.04700404926552437, 0.08843586823786609, 0.03151497083308641, 0.03667361706902739, 0.07797387923346832, 0.04482839511183556, 0.030128123180475086, 0.045859438614570536, 0.04445239341293927, 0.003938307299904409, 0.0429346680175513, 0.038484086326207034, 0.03615631787397433, 0.02737620990956202, 0.020219705838826485, 0.010888762881222647, 0.09688413600088097, 0.011383269793441286, 0.022663681629637722, 0.04141046367294621, 0.05273632370517589, 0.05914879133342765, 0.016551668777537998, 0.01972828718862729, 0.027042877991334535, 0.0697131892957259, 0.03341310628456995, 0.03745477202755865, 0.08413259172812104, 0.030764277325943112, 0.05426789015473332, 0.06845947922556661, 0.04466489626793191, 0.043768775212811306, 0.032127450467669405, 0.01858706815255573, 0.03946993674617261, 0.05033162422478199, 0.01767110949003836, 0.012206253122712951, 0.007661799027118832, 0.030168173179845326, 0.04685443971538916, 0.060372154985088855, 0.013556354260799708, 0.054681652327417396, 0.06144771621620748, 0.05155767074029427, 0.05111087557452265, 0.009419117523066234, 0.03509883536025882, 0.05215106975811068, 0.02916939640272176, 0.048360164582845755, 0.020083440103917383, 0.015104653357411735, 0.023632022930542007, 0.07330266817007214, 0.044052134617231786, 0.02890278170525562, 0.025191241802531295, 0.06131918737082742, 0.028834164586442057, 0.008942629956436576, 0.0366094101627823, 0.008193299217964523, 0.034811423829523847, 0.034926408479805104, 0.04458960909687448, 0.03585064579965547, 0.014255734749895055, 0.09549884314765222, 0.06850150704849511, 0.13522163702873513, 0.14835566194960847, 0.15462968935025856, 0.10215975213213824, 0.1303576456848532, 0.08785474434262142, 0.08992701361421496, 0.14280414499808103, 0.11745516341761686, 0.22144242451759055, 0.1618995750322938, 0.07771797929308377, 0.09932350119925104, 0.12404740889905952, 0.11614009999902919, 0.16325124859577045, 0.11267709793173708, 0.09987444194848649, 0.1696836354676634, 0.1820521499030292, 0.1653380788047798, 0.13355627248529345, 0.27948203904088587, 0.13777441723505035, 0.09710479876957834, 0.11450317455455661, 0.20813990238821134, 0.1588434405857697, 0.12033826613333076, 0.10835861481609754, 0.1324871790711768, 0.08807891746982932, 0.14746567845577374, 0.1514892023988068, 0.21622622472932562, 0.22943056072108448, 0.15029382513603196, 0.1861505417036824, 0.1049015944590792, 0.09427303783013485, 0.12963589222636074, 0.15326513210311532, 0.1044184785860125, 0.11600649857427925, 0.13868255366105586, 0.1495643236557953, 0.11873873751028441, 0.10675279278075323, 0.12296051878365688, 0.11334622569847852, 0.1262500957818702, 0.26127047720365226, 0.1766585768200457, 0.14463863015407696, 0.19336224300786853, 0.1254748334758915, 0.08919424668420106, 0.09832856318098493, 0.16672202094923705, 0.1344768176204525, 0.1650401361985132, 0.2277279255213216, 0.1052920457732398, 0.11253784876316786, 0.17717563110636547, 0.08453625327092595, 0.16850078565767035, 0.10069540570839308, 0.20159022649750113, 0.09292978022131138, 0.15922095626592636, 0.1418443996226415, 0.1031067845178768, 0.21234204643405974, 0.22887766070198268, 0.17014945187838748, 0.1614105442422442, 0.1904380030464381, 0.10917914070887491, 0.15867881738813594, 0.1343220946728252, 0.21677324693882838, 0.08608279254985973, 0.16744852415286005, 0.10207549610640854, 0.1402854293701239, 0.17084902996430174, 0.17752625135472044, 0.21333175973268226, 0.13171823986340314, 0.10820804789545946, 0.0906121198204346, 0.21532773622311652, 0.11230219461140223, 0.08590743789682165, 0.10832607164047658, 0.13376808143220842, 0.13870950846467167, 0.09858818128122948, 0.18859440431697294, 0.15661474142689258, 0.14200832520145923, 0.20308718289015815, 0.2184284440591, 0.18387746211374179, 0.2673571865307167, 0.16873879241757095, 0.13233490521088243, 0.07680173861444928, 0.13378642732277513, 0.1393255652510561, 0.14005110366269946, 0.12906258314615116, 0.13108999701216817, 0.10939919491647743, 0.09520277075353079, 0.12846153258578852, 0.15847500879317522, 0.15437942231073976, 0.15220679983031005, 0.17437749687815085, 0.06666687346296385, 0.11846656969282776, 0.19341530656674877, 0.11359365031239577, 0.12834712309995666, 0.11245793430134654, 0.13380803866311908, 0.12938951404066756, 0.16299945273203775, 0.11487127980217338, 0.20852038665907457, 0.17733146727550775, 0.11731529826647602, 0.14367971598403528, 0.11582914012251422, 0.14387742412509397, 0.13220443564932793, 0.12449398142052814, 0.1493623259011656, 0.20477654848946258, 0.1593129083630629, 0.08883463160600513, 0.09693064639577642, 0.20174517208943143, 0.23727277584839612, 0.15497977525228634, 0.1944886747514829, 0.15933307993691415, 0.17489271063823253, 0.16478452569572255, 0.16916916385525838, 0.08498442140989937, 0.13777495158137754, 0.122810835018754, 0.1332590720267035, 0.16781144920969382, 0.12544308439828455, 0.13296377146616578, 0.14092894562054425, 0.11145851371111348, 0.09206215021549724, 0.21759076713351533, 0.09282057319069281, 0.12283937801839784, 0.172527946124319, 0.1039736278471537, 0.11203200090676546, 0.10605920382658951, 0.12541779200546443, 0.14278726855991408, 0.07453671874827705, 0.15565683657769114, 0.12910783931147307], [0.043541555569390766, 0.03931898761948105, 0.04613574761606287, 0.027871151905856095, 0.02238763980130898, 0.03781882143812254, 0.05727398158342112, 0.010206927690887824, 0.057128750704578124, 0.08142714432324283, 0.09028682165080681, 0.03855857197777368, 0.020799848243768793, 0.03023923753062263, 0.014148879399726866, 0.01621458159206668, 0.026693244799389504, 0.03836030722595751, 0.040187697450164706, 0.013898706984036835, 0.040244583069579676, 0.011145941170980223, 0.02420975150016602, 0.05702084243239369, 0.08776815797318704, 0.03896124275343027, 0.034723872668109834, 0.03974423452746123, 0.02745401481661247, 0.032118763629114255, 0.04480506198888179, 0.05675986991263926, 0.031053614729898982, 0.08298837812617421, 0.028401488780218642, 0.07024325343081728, 0.03993977188656572, 0.05914975983614568, 0.06472335939179175, 0.016736413454054855, 0.042001313413493335, 0.019902181666111574, 0.015716819434601348, 0.055243261449504644, 0.05673028419550974, 0.05139115506608505, 0.09100053022848442, 0.08960469145677052, 0.021182924465392716, 0.01957580738235265, 0.06918081708136015, 0.03596137794374954, 0.02235430623841239, 0.053346469285315834, 0.021202235147939064, 0.03283650577941444, 0.034431677995598875, 0.04379286903713364, 0.04706594809249509, 0.05448181422252674, 0.028419213122106157, 0.04152944478846621, 0.01622051691811066, 0.02570319382357411, 0.03703889102325775, 0.019085329404333606, 0.018222820217488334, 0.006301276744125062, 0.013338135941012297, 0.09038216536282562, 0.012387381684675347, 0.02998935084178811, 0.10386695896158926, 0.008412851548200706, 0.039042140560923144, 0.07721343761659227, 0.011760729812522186, 0.029058090949547477, 0.007612499084643787, 0.027652333374135196, 0.07061166295898147, 0.047332854082924314, 0.04104457002540585, 0.027168855704076122, 0.04004196191090159, 0.02023237986577442, 0.03900787189195398, 0.0546270302584162, 0.04758909541124012, 0.03651194761914667, 0.029507292529160623, 0.04562275658827275, 0.03391320620721672, 0.03261921236116905, 0.040925451612565666, 0.046706381253898144, 0.07466603798093274, 0.04374345313408412, 0.03168584662489593, 0.014052302794880234, 0.03653291700175032, 0.059324487374396995, 0.0416271373978816, 0.04795612083398737, 0.04626035050023347, 0.018949267760035582, 0.05608952131296974, 0.06840899091912434, 0.03226408356567845, 0.022733144796802662, 0.0019860071279254043, 0.03531926435243804, 0.04850623408856336, 0.024323116413142998, 0.021006645838497207, 0.031062043672136497, 0.08764511730987579, 0.03174306250002701, 0.05564643688558135, 0.0306574711430585, 0.02837767511664424, 0.013532789216696983, 0.026711214050010312, 0.029871102597098798, 0.0315722943196306, 0.0617248044727603, 0.02506547189113917, 0.0283100265005487, 0.020702728943433613, 0.008385133260162547, 0.06914215860888362, 0.01597432798007503, 0.057815964610199444, 0.028433935476641636, 0.021553306251007598, 0.023488252227252815, 0.007024664782875334, 0.07677439789404161, 0.033455746379331686, 0.03537492542818654, 0.0688364976667799, 0.04882265617197845, 0.035362568669370376, 0.10182938509387895, 0.014115634894551476, 0.0260835556400707, 0.011673101653286722, 0.05683538343873806, 0.025748724583536386, 0.04862228743149899, 0.04823192888579797, 0.025828251273196656, 0.005992663909637486, 0.07846014181268401, 0.02441782929963665, 0.05597264789685141, 0.031080228145583533, 0.03256187032093294, 0.05883253994397819, 0.01039816615957534, 0.07171039775130339, 0.05984182367683388, 0.10269964972394519, 0.011359150921634864, 0.07697730106883682, 0.04437103918462526, 0.044773947447538376, 0.05357104317226913, 0.030789183801971376, 0.05711685407732148, 0.009824116787058301, 0.05360029863368254, 0.03450718410022091, 0.007554525755040231, 0.08626012873719446, 0.04325023292039987, 0.028680558571068104, 0.037810334979440086, 0.0926054097362794, 0.03631552339356858, 0.03404652190511115, 0.07663239535759203, 0.07629962376086041, 0.008218425555241993, 0.025325692986370996, 0.09758755099028349, 0.011834940869448474, 0.012425823078956455, 0.014096008799242554, 0.009326785075245425, 0.04972232098225504, 0.07872277303249575, 0.03747772294445895, 0.016998792343656532, 0.05113332183100283, 0.01097086482332088, 0.029538442322518677, 0.015282779932022095, 0.01575966176460497, 0.01911294471938163, 0.04559240645903628, 0.09882787271635607, 0.02548772608861327, 0.040983413346111774, 0.07762361521599814, 0.008801935455267085, 0.023352348289336078, 0.01575517548189964, 0.04104197993001435, 0.03362848496180959, 0.026940836396533996, 0.027693242409441154, 0.021123361548234243, 0.057533284270903096, 0.04672424845921341, 0.025849298581306357, 0.05360259187000338, 0.028283051287871785, 0.054080208428786136, 0.05607008446531836, 0.034211723977932706, 0.0007922746499389177, 0.028115518871345557, 0.057606222544563934, 0.07214658762677573, 0.014712958945892751, 0.07378113819868304, 0.022713882353855297, 0.017129391781054437, 0.05420943118224386, 0.027036569736083038, 0.051245449212729, 0.04300756176235154, 0.07349973064265214, 0.05812109120597597, 0.010506783182790969, 0.046500657917931676, 0.03888198880304117, 0.040604862369946204, 0.02806362976116361, 0.03867225786962081, 0.029698941034439486, 0.04540934460237622, 0.04389379369968083, 0.029946139293315355, 0.05936680092418101, 0.027077452796220314, 0.047319714358309284, 0.0322607958514709, 0.041480715372017585, 0.04713470065325964, 0.08523692231392488, 0.017142629840236623, 0.057016794016817585, 0.04468447783438023, 0.027102032727270853, 0.07383754142210819, 0.03779925471462775, 0.06882974412292242, 0.06266061187488958, 0.10521348202018999, 0.025637177932367194, 0.04699388926383108, 0.026931049324048217, 0.04849755467148498, 0.02932658142526634, 0.03076964676438365, 0.007207016033135005, 0.05350036473828368, 0.010597788113955176, 0.013529701882362133, 0.08315501996548846, 0.02174750032281736, 0.06321580513031222, 0.03435986036492977, 0.06586707575479522, 0.09263649088097736, 0.03278897864220198, 0.04260331392288208, 0.020799896483367775, 0.032356633091694675, 0.04678667421103455, 0.11369682368240319, 0.0513637438416481, 0.06633933400735259, 0.029369689073064364, 0.06687642628094181, 0.03148350748233497, 0.02936902856163215, 0.013097653190925485, 0.024963417308754288, 0.02281653622048907, 0.03553499926056247, 0.013690706182387657, 0.047289019130403176, 0.013671474353031954, 0.06021958797646221, 0.03606457728892565, 0.05867290397873148, 0.0016584379864070797, 0.03611073516367469, 0.060305639999569394, 0.04948665198753588, 0.053702755831182, 0.06331888944259845, 0.01615487581148045, 0.027200350596103817, 0.06056133584934287, 0.05992769016302191, 0.09286780346883461, 0.04465654710656963, 0.004246589878675877, 0.05362782489100937, 0.05903720943024382, 0.030170948812155984, 0.034895724384114146, 0.06271903373999521, 0.060164579990669154, 0.022534200979862362, 0.07954577769851312, 0.046543060525436886, 0.027559485133679118, 0.04857832260313444, 0.06891375523991883, 0.0750567193608731, 0.0571539429074619, 0.05839309575094376, 0.048961322754621506, 0.04090871618245728, 0.012238418730703415, 0.06497001217212528, 0.057045919602387585, 0.03765345609281212, 0.01794152398360893, 0.08970141556346789, 0.029980242834426463, 0.053690250642830506, 0.014593850737583125, 0.07537720099207945, 0.04330421674239915, 0.058094288542633876, 0.022308478619379457, 0.04594055164488964, 0.04162454359175172, 0.008940854368120199, 0.08082523287157528, 0.07596988012664951, 0.04142727702856064, 0.054457690712297335, 0.02217891076725209, 0.030613213166361675, 0.021006643983128015, 0.21624005836201832, 0.1286942552542314, 0.11600504396483302, 0.11412882042350248, 0.1266548185958527, 0.17275201535085216, 0.19303013192256913, 0.1170383881253656, 0.11855473683681339, 0.15838268562220037, 0.1317652326542884, 0.09452441066969186, 0.09268993293517269, 0.1519794948399067, 0.12090917807654478, 0.17115486902184784, 0.13466337870340794, 0.09369739098474383, 0.12791927496436983, 0.177451457711868, 0.2056370538775809, 0.11219260908546858, 0.07151879006414674, 0.11069537067669444, 0.19847528426907957, 0.18661160836927593, 0.15105271566426381, 0.10450909481733106, 0.18293671571882442, 0.13113678200170398, 0.1649112399900332, 0.2433544088853523, 0.09107380989007652, 0.12020417489111423, 0.13786478113615885, 0.15943251288263127, 0.10288953562849201, 0.20118145155720413, 0.12860927934525535, 0.2767826401395723, 0.1368059145170264, 0.13700466166483238, 0.11417654051911086, 0.20530080160824582, 0.28354140871670097, 0.13598618272226304, 0.12790793494787067, 0.17408749525202438, 0.11439185982453637, 0.06566245821886696, 0.17950404522707686, 0.20218605233822018, 0.07668430858757347, 0.19196927634766325, 0.13980821357108653, 0.13598383753560483, 0.2390160213690251, 0.16142157255671918, 0.1303913540323265, 0.15408330538775772, 0.08245913035352714, 0.12361463290289976, 0.10999589649145491, 0.16084743227111176, 0.1315169397275895, 0.13809385243803263, 0.1274431130150333, 0.11580288293771446, 0.12380458560073748, 0.17680746648693457, 0.09087262107641436, 0.15937002404825762, 0.1865677919704467, 0.1004468159226235, 0.12074399084667675, 0.1817932294216007, 0.14101720182225108, 0.14996451936895028, 0.10872271246626042, 0.10407004767330363, 0.19852303405059502, 0.1713049758109264, 0.1950384132214822, 0.23367946007056162, 0.15941700199618936, 0.09941578726284206, 0.1399881101679057, 0.1565745467087254, 0.14327677432447672, 0.10959052058751695, 0.19022894004592672, 0.12948801188031211, 0.09338334377389401, 0.1424119941657409, 0.08718581695575267, 0.20986710267607123, 0.1548059197375551, 0.0775173693546094, 0.1097722577105742, 0.15093045425601304, 0.21227218065178022, 0.1524844521190971, 0.07676780020119622, 0.11597932112636045, 0.10427334418636747, 0.1484187741880305, 0.20828707027249038, 0.2587858558399603, 0.1631466206163168, 0.1030004867061507, 0.10341050845454447, 0.14710595947690308, 0.07822546729585156, 0.1186437277647201, 0.11543258093297482, 0.13488398952176794, 0.16250307467998937, 0.14126222929917276, 0.1363659100024961, 0.161414047179278, 0.16065402858657762, 0.07849504501791671, 0.11014158008038066, 0.09368935352540575, 0.11648977029835805, 0.12035929117701016, 0.17550376534927636, 0.1621706222067587, 0.1186744452570565, 0.07471198434359394, 0.12547342339530587, 0.21153597015654668, 0.16931924095842987, 0.18808638938935474, 0.09589832639903761, 0.12558832269860432, 0.1496634745853953, 0.25746916711796075, 0.10764472812297754, 0.12540505675133318, 0.156549135572277, 0.1438468773267232, 0.16631964332191274, 0.22230787260923535, 0.1576623719302006, 0.1701628847513348, 0.11244297260418534, 0.13477572501869872, 0.22996015730313957, 0.11123124582809396, 0.2017264551250264, 0.1482138375286013, 0.1978087762836367, 0.09039308977662586, 0.13292887568240985, 0.11622996666119434, 0.12157706645666622, 0.11482294372399338, 0.16260348726063967, 0.12121048261178657, 0.09069691761396825, 0.10509801126318052, 0.22425468923756853, 0.11516611280967481, 0.15707951883086935, 0.13472888065734878, 0.09119008216657676, 0.16388919873861596, 0.20067551464308053, 0.22513097268529236, 0.14471128641162068, 0.10678802253096364, 0.07623667479492724, 0.11976248570135795, 0.0899813833530061, 0.1275277920649387], [0.07036584880552255, 0.05053493929153774, 0.042974179959855974, 0.03968419478042051, 0.02884319837903604, 0.042315828177379444, 0.03985358627687674, 0.04200658266199753, 0.013974805879115593, 0.03764763765502721, 0.029971383446536493, 0.011069230931752827, 0.05455609207274392, 0.031246224316419102, 0.054065977747086436, 0.07776344325975515, 0.03743598826986272, 0.045175516133895144, 0.04718531883554533, 0.03914063468982931, 0.04595472666551359, 0.03167573857354, 0.0337874121760251, 0.04100959260540549, 0.046107026500976644, 0.02596799768070923, 0.06353639808367006, 0.06304986090981402, 0.038259252687566914, 0.012855191689595813, 0.048643809714121744, 0.0686245180258993, 0.017558041436132044, 0.06941194413229823, 0.02378506862442009, 0.03702365473145619, 0.02083885181491496, 0.0367952290980611, 0.07361966912867501, 0.05820497986860573, 0.025642367399996147, 0.07267844775924459, 0.03398053755518049, 0.01518998642495717, 0.047410798142664135, 0.035619073460111395, 0.030895589225110598, 0.05909780949878041, 0.055713241308694705, 0.0213852580418461, 0.043783462315332144, 0.05182993503694888, 0.03852033652947284, 0.02892051161325071, 0.05636292109556962, 0.008437104006588925, 0.018440722196828574, 0.016451300725748297, 0.04174343564955052, 0.043183855232200585, 0.054782925799372606, 0.04298698571801651, 0.03921602576156147, 0.03168041781464126, 0.02278505988215329, 0.03993496276962105, 0.026120368020201568, 0.024319142212334555, 0.041970510574174114, 0.02003822290134849, 0.05184563517104834, 0.007596011346322484, 0.028359880270727444, 0.042401060127303936, 0.06292189238592982, 0.034632365859579295, 0.022141745866974816, 0.01979420288989786, 0.03603613447921816, 0.018800224097503815, 0.06992113165324554, 0.041035823815036565, 0.03202726424206048, 0.004827509219467174, 0.01756468180246884, 0.03465167654212564, 0.08272039602161385, 0.03419041691813618, 0.024038230039877817, 0.025732061512826476, 0.03700545355968643, 0.010682304819056299, 0.03727414441527799, 0.043963896969216876, 0.01208628495078301, 0.018520354642532766, 0.046122771163936704, 0.04825056421395857, 0.08099590457277372, 0.041602256897022016, 0.011586677628656616, 0.037403864407679066, 0.05877992538444232, 0.06058398248569574, 0.0534755287662847, 0.10004438634496182, 0.09862385632004589, 0.0311676345882006, 0.00786475786298979, 0.03606769059842918, 0.03012408960785251, 0.06939925340702757, 0.014582407748093829, 0.05857223164639436, 0.06268410827033222, 0.07803057931596413, 0.020227806380717084, 0.04473144465009682, 0.02621674331749091, 0.020880825832136907, 0.007519243590650149, 0.013453366427711444, 0.009839506146818167, 0.057837850545183755, 0.06906738723046146, 0.047943652753019705, 0.08255208435002714, 0.0118181813195406, 0.02967739277664805, 0.046522599513991736, 0.027454716146166902, 0.04612817028828431, 0.009323563226644183, 0.01748110484186327, 0.01867768994998187, 0.020146813949395437, 0.0435906152415555, 0.043797418402391486, 0.06535035543492995, 0.03086281598370988, 0.06415422860300168, 0.02096273296047002, 0.058585081933415495, 0.03033764074643841, 0.04498149275605101, 0.07465741422493011, 0.05329695690306835, 0.0586052201106213, 0.027881950154551305, 0.02706469713302795, 0.10734497467637993, 0.034045564534608275, 0.0059864192007808015, 0.03080073347518919, 0.051771056751022115, 0.018807727210514713, 0.03290018947154749, 0.05259125980956014, 0.025620102969696745, 0.023526291006419342, 0.03048638754989952, 0.0211705565743614, 0.008842543920764001, 0.04754488938488066, 0.05761042681115214, 0.03466218535322696, 0.033966151022468694, 0.05679329624399543, 0.0461694708064897, 0.11325827377731912, 0.05053672786743846, 0.03206483546819072, 0.06640692881774157, 0.023064580527716316, 0.008363421729882248, 0.030062713994993828, 0.06597679486731067, 0.08753484158660285, 0.024599186072009616, 0.021248354059935082, 0.0632349080115091, 0.04336551814049017, 0.021660017810063437, 0.02315435998752946, 0.06544311647303402, 0.00668553158902796, 0.028725966876663733, 0.014472692346316762, 0.02468960934493225, 0.06753307112376206, 0.02915042896347586, 0.030434053151111584, 0.04548689161310904, 0.04566020536003634, 0.021388016975834034, 0.03494971933832858, 0.008800815739959944, 0.03834019502392039, 0.047535274861729704, 0.020273641421226785, 0.01942629060067702, 0.03214935495634563, 0.07081202798872255, 0.06498418719274923, 0.02081105838442454, 0.03742097091162577, 0.040568211406935006, 0.05252900104096625, 0.04472611231904011, 0.060177389459568076, 0.03381189191713929, 0.08070659314398654, 0.024709328208700754, 0.09681734270998277, 0.01554344631585991, 0.018551348584878724, 0.021718740244978108, 0.07838213467039168, 0.01299658195421216, 0.050024044830934145, 0.05184943867789116, 0.06504613425931893, 0.08376145851798356, 0.09853262410615571, 0.06470542910392396, 0.02371017479163129, 0.01912491185066756, 0.04576980572892353, 0.03213099422282539, 0.08142952661728486, 0.056635534201632254, 0.023216321897052694, 0.011545086745172739, 0.037214639014564455, 0.024000037265068386, 0.05118018474604469, 0.02662749608134618, 0.02387943084613653, 0.06361390056554228, 0.061358105594990775, 0.023400981226586737, 0.04902050903183408, 0.01411052613548236, 0.07915065827546641, 0.05190770469198469, 0.010336561408621492, 0.01728741728584282, 0.013286830344441114, 0.05354632965463679, 0.014433973574341508, 0.00916871782465023, 0.059980211954098195, 0.06300562890828587, 0.020096431398997083, 0.09140901573118754, 0.11444378789747134, 0.01659800847846782, 0.021451927023008466, 0.02465761535859201, 0.009693741849332582, 0.03782612788199913, 0.03642156516434625, 0.0273289406686672, 0.006436781313823303, 0.031385610782308504, 0.026056712158606388, 0.0709614297375083, 0.05335229143383913, 0.07110244521754794, 0.10959737803204916, 0.027036781248170882, 0.0331813075899845, 0.02973634713271167, 0.01542302636153181, 0.02149226831534179, 0.029939918240415864, 0.07182808010838926, 0.01957190739631187, 0.029466591295204125, 0.03016309317899868, 0.018267798077431507, 0.0653410266386345, 0.05125210627738852, 0.01449615720048314, 0.04457095892576035, 0.03207348519936204, 0.013524951209546998, 0.025576216066838242, 0.028868982444691937, 0.02202886520535685, 0.043662944954121485, 0.05983173046843149, 0.00625393467998947, 0.037540219200309366, 0.049182701695826836, 0.006616408418267383, 0.05472554294101428, 0.04192311331280507, 0.032270209994749166, 0.021302193163137417, 0.05619857620331459, 0.05651355109876022, 0.029714375850744545, 0.02481413059285842, 0.03736459737410769, 0.03090992566285422, 0.023257887733052485, 0.03734835176146589, 0.05244458174274769, 0.044007594624417834, 0.020307251434132922, 0.04533849176368676, 0.06356790225254372, 0.08061825530603528, 0.03145057838992216, 0.03691468147735577, 0.06145538260170724, 0.025285539086326025, 0.025431879475945607, 0.009492003846389707, 0.015631921451131348, 0.05167569077457301, 0.03986885225458536, 0.04122950209421106, 0.03352229847223498, 0.02669889810931636, 0.010907390787906479, 0.04032373311929405, 0.07128924378775991, 0.02318247625225922, 0.10412736373837106, 0.0442196707444964, 0.06145363855466712, 0.047080171352718025, 0.022513723270094488, 0.03907239421096165, 0.048184861880145036, 0.0341897489852272, 0.030005939697730355, 0.061415072850650176, 0.010434627874928992, 0.06771925371140242, 0.06941621148143895, 0.06111321541538928, 0.016379108310502488, 0.05749258118157741, 0.022752390541427303, 0.01232260518008843, 0.05282233491016086, 0.010954246281471569, 0.036701284334412776, 0.02330033115867991, 0.18113693338818848, 0.20926588884321973, 0.10644204070558771, 0.1373606699053198, 0.15458697132999077, 0.12789463566150516, 0.12925203860504553, 0.17294761579250917, 0.13330317044164985, 0.13055079703917727, 0.09407941150129773, 0.18844257574528456, 0.12732606148347259, 0.20838853670284152, 0.19818277418380603, 0.15285105822840706, 0.15876683610258624, 0.12495019444031641, 0.08546772281988524, 0.11247599817579612, 0.14169168047374114, 0.16884526092326269, 0.14465292391832918, 0.15053195063956082, 0.14484373008599505, 0.17905718326801434, 0.15825782669708133, 0.19058485922869295, 0.10147160312044434, 0.17751914157997817, 0.10865387826925144, 0.13818571547744796, 0.19196471956092864, 0.14539799565682188, 0.06565852483618073, 0.20477301586652175, 0.062439088214887306, 0.17751448089256883, 0.18546417384641245, 0.1358397421427071, 0.1343901941436343, 0.17721230804454535, 0.06576022133231163, 0.15557549719233066, 0.14519204967655241, 0.14309485908597708, 0.13756682368693873, 0.2257998555433005, 0.20214345306158066, 0.1118619526096154, 0.14163934421958402, 0.17229629214853048, 0.17856084974482656, 0.22654369531664997, 0.134876582887955, 0.1546964084263891, 0.1829562193597667, 0.19949535140767694, 0.10484377373359166, 0.16758779558585957, 0.11064085250836797, 0.1277145609492436, 0.22988110373262316, 0.14136713929474354, 0.09944104996975511, 0.18069863581331447, 0.11039098622859456, 0.24291346926474944, 0.07819995968020521, 0.11061561206588522, 0.08041326669626869, 0.12016282984404825, 0.12851495237555355, 0.18035061308182776, 0.14907315548043698, 0.2538327919319272, 0.10554320338997059, 0.10469898814335465, 0.2260827919235453, 0.20158397761406377, 0.10784029887872748, 0.10837224806891754, 0.1376738413819112, 0.11846189416246489, 0.1135996394441463, 0.125674931332469, 0.18625006370712072, 0.10062822650070302, 0.11481049790745601, 0.13645729806739837, 0.13078803196549416, 0.13551212847232819, 0.14983182336436585, 0.21481001400388777, 0.14495468116365373, 0.057870211894623935, 0.12460690661100671, 0.08282670867629349, 0.15013555472251028, 0.15135264722630382, 0.1221712892584037, 0.1518938658409752, 0.17683556419797242, 0.16204156272578984, 0.1613665497279726, 0.12794372130883858, 0.22283292724750936, 0.09472464211285114, 0.11113916014437564, 0.17700061784125865, 0.09969423364964314, 0.2055329454015009, 0.08132576695061289, 0.14619344437960535, 0.2132883737795055, 0.22201280953595415, 0.09590018176822923, 0.1755813939962536, 0.12788026768248528, 0.1351876466651447, 0.09944513920345344, 0.09089470739127137, 0.12640918255783617, 0.18966988020110875, 0.23346031870460138, 0.11163272545672953, 0.26612011541146785, 0.11596613316214643, 0.10945254791295156, 0.22859460557810962, 0.1502112834714353, 0.1366582716582343, 0.12327646589255892, 0.17103403253713623, 0.1473721381626092, 0.1229759406123776, 0.1741662371205166, 0.17652821115916595, 0.13507396448403597, 0.12454468494979665, 0.1634220316191204, 0.1593695193878375, 0.13078202056931332, 0.12279769158340059, 0.14308203477412462, 0.20528466731775552, 0.09025315041071735, 0.21937017008895054, 0.13860597886377946, 0.12859782058512792, 0.27867867902386934, 0.10648982017301023, 0.2277263076393865, 0.12309626501519233, 0.14144196262350306, 0.1494000418460928, 0.16768014844274148, 0.1786997649469413, 0.09301167621742934, 0.13507973839296028, 0.14296234119683504, 0.05148317024577409, 0.09766938019311056, 0.07299011267605238, 0.11852895462652668, 0.09903569633024745, 0.09027280248119496, 0.12709844479104504, 0.16566664242418483, 0.1666134299011901, 0.14233927853638306, 0.14781564561417326, 0.17525553179439157, 0.09312399284681305, 0.11518447354319505, 0.2192303049378097], [0.03738717350643128, 0.06840502785053104, 0.10345749382395297, 0.043031570239691064, 0.01662665537878638, 0.023336041449510958, 0.038470809304271825, 0.05415927684225608, 0.02314664721779991, 0.03237789933336899, 0.02858870295312954, 0.029407607253233436, 0.05130705118062906, 0.018489768881408963, 0.04295233855373226, 0.07484879926778376, 0.015667657717131078, 0.04861113666265737, 0.033272844084422104, 0.059367706344346516, 0.02927184246800607, 0.04786007208167575, 0.05446172799565829, 0.08418056415393949, 0.06132421171059832, 0.02882241824408993, 0.006500011368189007, 0.029993762909725774, 0.039951687067514285, 0.014495301875285804, 0.06354441327857785, 0.02644875909027178, 0.1330586476251483, 0.02247971249744296, 0.08985696229501627, 0.03351262828800827, 0.024073873537417967, 0.026670802253647707, 0.029626577925228048, 0.06818465451942757, 0.018080565350828692, 0.05837951073772274, 0.08254825486801565, 0.06946612833417021, 0.03721433473401703, 0.07873884052969515, 0.034719776012934744, 0.03021099510078784, 0.02495617951353779, 0.02002898501814343, 0.03689089935505763, 0.029751726287940983, 0.027411268965806812, 0.029328908058232628, 0.04008649819297716, 0.02995671304233838, 0.012381540054775542, 0.08508216225891374, 0.04330925963586196, 0.07005378312896937, 0.044497256239992566, 0.03639152302639559, 0.05340984869690146, 0.03246860462240875, 0.05947060511971358, 0.047604405917809345, 0.04740113166917581, 0.04776749658049084, 0.034290547482669353, 0.0493315468338551, 0.03836352814687416, 0.05559391880524345, 0.04655324650229886, 0.05254706120467745, 0.007789855681039626, 0.029724370724579785, 0.03462668842985295, 0.002967398631881224, 0.028494149628386367, 0.04445482023584191, 0.02958621807920281, 0.04701263220340479, 0.030889869121892843, 0.034227546566398814, 0.04056141333421692, 0.12337962441961281, 0.051798668355331756, 0.1334319924353622, 0.046167745313141495, 0.03330786232254468, 0.047385127254528925, 0.038642798317596316, 0.07633532848558389, 0.056240151316160336, 0.018297686219739262, 0.0266769119843957, 0.09961038580513559, 0.035148292081430554, 0.029308443336049095, 0.10550730570685118, 0.03875590533425566, 0.04822360569960438, 0.007994649477041094, 0.04412913243868388, 0.03510488757456187, 0.032858054037205875, 0.025602408313716296, 0.01237169175510644, 0.037551818968495354, 0.08749513668590225, 0.005943757305431063, 0.038566576040466316, 0.02199844271672191, 0.021849742297490593, 0.02377883643930545, 0.053600910905515775, 0.021746164456999395, 0.029375253325270023, 0.02856193925254047, 0.0430699170101434, 0.04731377346615773, 0.04779759437951725, 0.010798444436659338, 0.0231324851847603, 0.03677336913824547, 0.03146332106553018, 0.02272022029501386, 0.04363292136986274, 0.043399783098720945, 0.013692957672901684, 0.0545568935922347, 0.027984325715806335, 0.07939225703012198, 0.04701938945800066, 0.035236941621406004, 0.08843235787935555, 0.015970255444699433, 0.047993306143325754, 0.035247613704996184, 0.031183327300823294, 0.01010878886518185, 0.03409664655919187, 0.059130753434146754, 0.044971388415433466, 0.02156883569114143, 0.03918364585842937, 0.04247259574185591, 0.06832650862634182, 0.002447054312142427, 0.027953385579166934, 0.0585035904077813, 0.013991696232551476, 0.06677513796603307, 0.051718108225031756, 0.02311628224560991, 0.022922314528841525, 0.01887201204226585, 0.05965041265881155, 0.06406372369383462, 0.06431315210647881, 0.0009523205358163978, 0.02946298074675724, 0.07286389562068507, 0.04642026477085892, 0.006861442852823529, 0.007153026181185851, 0.05107988719828427, 0.027868864235642832, 0.018728020550042856, 0.017691537104838062, 0.01491220611569588, 0.05909655897994526, 0.05092023639008403, 0.044340588865452446, 0.046139146652421914, 0.04649957067158539, 0.02184326520364266, 0.08253838430391625, 0.02118163127306616, 0.014263916000345489, 0.033089348071371205, 0.0849844585172832, 0.07016094183200039, 0.04070890034199692, 0.004763850574818207, 0.020738639614137355, 0.024515180521120783, 0.06875502469483763, 0.019031093252124265, 0.0032077104560812586, 0.023019350337563083, 0.05515330944035668, 0.03900134841387626, 0.041060095754801296, 0.051037788871326484, 0.08194595749955624, 0.05545909654756542, 0.05022794990509283, 0.027702146326191723, 0.01808051525586052, 0.05344448843970895, 0.04234570333210286, 0.053287472255760804, 0.04854492224694695, 0.017084896317101084, 0.029440148573485203, 0.007773412471578922, 0.061249499703990296, 0.01660232592257671, 0.05549896843149327, 0.04825211159186438, 0.12303131967200898, 0.11271134804701433, 0.04092494695214555, 0.01626791046874132, 0.07131628022762015, 0.03198756305209827, 0.043343698998796754, 0.011896487176272785, 0.01115251288865693, 0.02716327475354774, 0.04199977345706429, 0.0645540606637951, 0.03166725211485755, 0.06803387979744002, 0.021614698562189005, 0.039301721553783864, 0.011442311351856915, 0.026121399605472106, 0.03139431246381719, 0.024317492789123207, 0.022736016908311285, 0.021557837062573526, 0.0699610443552956, 0.03898058312188368, 0.06584760922123678, 0.03252262555179186, 0.06803604686865583, 0.060450785531429574, 0.03856008595903404, 0.017161291143565904, 0.03210796166968066, 0.004955148415319854, 0.019337166086188518, 0.0230624153118697, 0.02077750032185577, 0.029637932784680743, 0.11241050364333205, 0.05165490321815014, 0.047988385704229586, 0.03074820797337452, 0.06429787870729342, 0.013293783340486698, 0.04199216273264028, 0.04842791524424683, 0.02038636437646346, 0.09655185422161594, 0.11931094821193255, 0.06500103394500911, 0.03400964829779696, 0.030610172216256615, 0.03664474752440583, 0.019854723177559208, 0.04805953169125132, 0.05046599006163888, 0.006261032394832, 0.04407021704537328, 0.07121520713553764, 0.09768579649971798, 0.053101508601685055, 0.031469614477828145, 0.0291399294292205, 0.04476239220821299, 0.07093386637279764, 0.02318403476238018, 0.04549036115349736, 0.027468620282888878, 0.052307087753433734, 0.046120199622237124, 0.05168193223653361, 0.010262550731567899, 0.017075164905691054, 0.05795937351649627, 0.0131548829813255, 0.08475961745716631, 0.013783747381239664, 0.02286927880049916, 0.05629740058793686, 0.05318245464877691, 0.03935825836379081, 0.015123432476684684, 0.028914938084199093, 0.10689331102184951, 0.02345934928598581, 0.030486294781439938, 0.030141236929921433, 0.04852187485084869, 0.06509279308374971, 0.048185229243244976, 0.025377107122039888, 0.04630033370631281, 0.010825257304531988, 0.034071053596562706, 0.050166010259999894, 0.0588438688282622, 0.01105945220842841, 0.04366906767245382, 0.07414846419123933, 0.061554674539365806, 0.04795986496901605, 0.0547181251749862, 0.053936610274831764, 0.03039052062376868, 0.01782866002031369, 0.016963506932370365, 0.06937307785847224, 0.019554752652766183, 0.05389529120293446, 0.029362634959397838, 0.012581179635162698, 0.06593478930881247, 0.008532662941433955, 0.04024377041787375, 0.02154715755750658, 0.11368149833288044, 0.0396401112084277, 0.016283714503515512, 0.032289498412865214, 0.02436750797642162, 0.013637566553370561, 0.04120360485103447, 0.03284994978457689, 0.025184250771417283, 0.01675471110502258, 0.0588643409719225, 0.03212499024812132, 0.003639294609456556, 0.027159172532265075, 0.03870389562507626, 0.06420467980206013, 0.012398052840580931, 0.062291541835293174, 0.04955992793838959, 0.037107075841049664, 0.03615386136516463, 0.028117251786170527, 0.0532535227102926, 0.02539887987950351, 0.014930358120182063, 0.0430499309732113, 0.02689718883630121, 0.018964427981700283, 0.1195771417405922, 0.21735559537773952, 0.2355370408622548, 0.07909992506029084, 0.09832638868829235, 0.1545314586837776, 0.1949126785621047, 0.11640868324320763, 0.16038741945521906, 0.0746401073411107, 0.07965816112118773, 0.11554599594091997, 0.12128096437663771, 0.10125819113454781, 0.14908075507264584, 0.17601231462322176, 0.10891626458032988, 0.13678019167855382, 0.1019774583983235, 0.1948263222584501, 0.06412822374841198, 0.09282287384849042, 0.10050412456621416, 0.32072835077997297, 0.16700710955774412, 0.11408355683670379, 0.168124754272867, 0.11034356299205683, 0.12462730082916096, 0.14806828752625734, 0.1376934043946676, 0.19819968030788004, 0.21718758798670024, 0.1305720373056829, 0.14625563635490835, 0.27379982988350093, 0.17838454514276236, 0.14705019450047985, 0.11059015640057623, 0.16589752456638962, 0.253750235424377, 0.15783618291607127, 0.2669009438250214, 0.17392785928677768, 0.14321928756544366, 0.202175825543236, 0.1949403903563507, 0.14810512773692608, 0.1783001481089741, 0.07589394357637502, 0.1261469372548163, 0.09940447693224996, 0.11891522764926776, 0.09847158988122828, 0.11781888999394141, 0.1366180769400671, 0.11684976387186907, 0.16248128522420302, 0.1640265851165168, 0.13241999986348674, 0.09141218470176682, 0.23375078046228737, 0.17934558185515925, 0.16531850094906986, 0.14153636380797252, 0.1469350725528784, 0.1451068659662269, 0.13618015043903142, 0.1259424607269466, 0.15859624603763223, 0.08738883887417614, 0.15112704917555675, 0.08284912895760499, 0.12513717112597078, 0.10908462078077719, 0.096262312727049, 0.06877487714518793, 0.13640037534059957, 0.1751538278767839, 0.12993325595743954, 0.14252702705562115, 0.17147964768810198, 0.16305929952068254, 0.13122959499014542, 0.1401999784866348, 0.1394005073234439, 0.08785325262579136, 0.20117392617976293, 0.18055228429147974, 0.1496335511910729, 0.13301302038598806, 0.1440031290985644, 0.2485916411387734, 0.14533160312566906, 0.12590277066919953, 0.11386584781575948, 0.16323695483151823, 0.160798866127152, 0.14323594135930762, 0.19306140602566302, 0.1133950961229857, 0.16297997877700254, 0.21102739119669423, 0.18277430412126705, 0.05531345377676189, 0.05772500328021124, 0.19510532525600865, 0.11532791584613733, 0.14480515324976295, 0.23417760443408042, 0.22241426690015942, 0.1849318016320467, 0.150495748675894, 0.19052608113270253, 0.14516944385832176, 0.1314173880382441, 0.2185987966367975, 0.1276974767097272, 0.15454780077561736, 0.06844896299298853, 0.26973538391757756, 0.14431733958190307, 0.14865036879200488, 0.07756901541142724, 0.12625515722902492, 0.17798871325794607, 0.17797167354729027, 0.20180245104711503, 0.19138769974233583, 0.11229096591705456, 0.13375902723055333, 0.1589950465131551, 0.1751711347606033, 0.1570187963079661, 0.14427668473217636, 0.1826349287875928, 0.11962993070483208, 0.08586546202423051, 0.14665062219137326, 0.14698623621370643, 0.12440176215022802, 0.11705294164130464, 0.17500352812930942, 0.1851712036295794, 0.12633737234864384, 0.1758846058510244, 0.13644885242683813, 0.08397263663937338, 0.19663437211420387, 0.05909551997319795, 0.08640959727927111, 0.08800069510471076, 0.13704760232940316, 0.11113813598058186, 0.13009348564082757, 0.09764005051692948, 0.10358685758546926, 0.18897120753536, 0.10582234739558771, 0.11402327960240655, 0.14856514055281878, 0.135005701740738, 0.22160571184940636, 0.11992593630566262, 0.10441294216434471, 0.15900634200079367, 0.09676946676336229, 0.21239668334601447, 0.13195894804084674, 0.12712793773971498, 0.1283828797750175, 0.17074420902645215, 0.17146195488749072, 0.22504532884340733, 0.13392598077189177, 0.14452932664426044], [0.015626501917722635, 0.028188499818497803, 0.08026876312214881, 0.06774639405193739, 0.026680695082177408, 0.03556025825673714, 0.04416339368617628, 0.10017317123129033, 0.07336255948757753, 0.02809695404721424, 0.057832421734929085, 0.010428369714645669, 0.03815699958067853, 0.04931354975269642, 0.013126391932019033, 0.005173388999537565, 0.08266982607892714, 0.07980971509823576, 0.070911609363975, 0.02982646426971769, 0.01421978697180748, 0.05547528649913147, 0.05533339899557177, 0.03482782900391612, 0.08233495420427062, 0.04236355940520298, 0.014318785761133768, 0.05472253353218548, 0.048751153954071924, 0.005445923716251855, 0.022967873119341675, 0.011436517961556092, 0.034848260329454206, 0.03782974585192278, 0.02688852426217636, 0.018105894851032645, 0.027189609863853548, 0.009836001354415203, 0.007876660056354012, 0.032770747784525156, 0.05125311930896714, 0.09816503094043583, 0.05455706428620033, 0.03614600202126894, 0.019292559300083667, 0.07677140703890473, 0.03660676440631505, 0.018065731674141716, 0.03599959112762008, 0.016051494640123565, 0.023039219486236107, 0.035817030220641755, 0.052290311505203135, 0.06324701244011521, 0.018598781098262407, 0.036385021812748164, 0.03944995070924051, 0.07176262268330902, 0.03933747451810632, 0.00970259288806119, 0.013765215953753795, 0.02798653360514436, 0.07258325989823788, 0.02266152012452949, 0.017043415828084107, 0.02490796960046282, 0.03901066607795656, 0.0704420822148677, 0.028293033174122684, 0.04096708980796393, 0.021555543826252688, 0.10460504709044471, 0.05568231601500884, 0.02263033136841841, 0.0220400753460126, 0.03407867545320187, 0.02315480527613545, 0.029668242095794994, 0.04134625676670112, 0.03197476100467611, 0.03500403712678235, 0.04441615063115023, 0.022591583838220686, 0.04385730229842011, 0.03738437189895194, 0.03398448578082025, 0.03650337952421978, 0.06330450662062503, 0.05561229067097884, 0.021546682582993526, 0.100695821311092, 0.0815610277641099, 0.012430274109647144, 0.03469132207101211, 0.016887559249880724, 0.06092056130000856, 0.013652389097842388, 0.04109489877009764, 0.15486184798646718, 0.014939017128199339, 0.029319698005565442, 0.025542092116666026, 0.01473224921937799, 0.04579358042974491, 0.020870908883807715, 0.028865720705653075, 0.047840542465564795, 0.07281012702151202, 0.03522820654325187, 0.05322153985616751, 0.05075778397440445, 0.048125783214345574, 0.02959943944006227, 0.041934765031328425, 0.034864565313910134, 0.01683307818893809, 0.052318542802822776, 0.02481935160176363, 0.08093228767393157, 0.014080892178753857, 0.012194081900815945, 0.046274436463136226, 0.02003690373385325, 0.047715791151858866, 0.039349003782263026, 0.039265564118977636, 0.041089829901466146, 0.051735838133026846, 0.008849510832078522, 0.02655092870554654, 0.0396555367478868, 0.033703519802656956, 0.018977189211000223, 0.019464420292933937, 0.05230316179222427, 0.04771223626448773, 0.02057599980616942, 0.03737300219654571, 0.059961172155453824, 0.01500600152212428, 0.04197671492875088, 0.05856081741512753, 0.04310817472287454, 0.007208087045000866, 0.03503107727738097, 0.06531603852636181, 0.056827123335096985, 0.04675437965488527, 0.044520080991787836, 0.0247366949042771, 0.02856616207282059, 0.05658598842273932, 0.03700670407852158, 0.031172863018582575, 0.02044246888544876, 0.0812187566771172, 0.05630048421153333, 0.03935773886041716, 0.05654037231579423, 0.031487552187172696, 0.021246430042083375, 0.025206227619491983, 0.04814953193999827, 0.0434752186993137, 0.07632930224644952, 0.05280505400151014, 0.06758437579264864, 0.047515537444269285, 0.04364699991128873, 0.006056476549929357, 0.042381274470244534, 0.03615256631746888, 0.03797345532802865, 0.012017202134302352, 0.049959437164943665, 0.041471189906587824, 0.07230293587781489, 0.03096012082096422, 0.025389141046616714, 0.011238812603551196, 0.02849494372640038, 0.035968279917142354, 0.06767476195818745, 0.09494752390310168, 0.012962059099663747, 0.0854665131191723, 0.020564897276926786, 0.009911731031024829, 0.022842038270027842, 0.008600395049143117, 0.059187984152231365, 0.044414837029762566, 0.0812470844539348, 0.021012373363191728, 0.004857674275626778, 0.060595942195504904, 0.05597464427410159, 0.010578195415291702, 0.03992597536125686, 0.05333204935595859, 0.022566425031982362, 0.036076659453101456, 0.008187967814592412, 0.020719597960123792, 0.058534716081339866, 0.09004566818475723, 0.03371728293132037, 0.041562882252037525, 0.017878239195852075, 0.12157783829024993, 0.00437548330410209, 0.06194435030920431, 0.034342104481766, 0.015992254557204433, 0.0431084047886543, 0.040818574925651774, 0.035020750292460434, 0.039104718453017995, 0.046208737840061076, 0.027101704326923937, 0.05604400168522261, 0.05962798495602328, 0.011135270015074639, 0.03319230250781402, 0.0397099807014456, 0.01840070002799621, 0.04932044801535085, 0.035193715229979716, 0.06134455026767682, 0.04912772339594085, 0.03279851523984689, 0.019284848385723308, 0.028206559982209, 0.0498708581289975, 0.03736905397090595, 0.05153240061190445, 0.014488334036286687, 0.0167393245283165, 0.03814006377069745, 0.011588464349188143, 0.016634460916975513, 0.03025975605851272, 0.03270690453064162, 0.012707770547422115, 0.009133829462371068, 0.030329028122650925, 0.04175068643235136, 0.06137974291050341, 0.007735331946605584, 0.04063404361659195, 0.04107351378479507, 0.03561946679838002, 0.030317393102450296, 0.04139883050811477, 0.04306773880671244, 0.0521039025625214, 0.021921138759353198, 0.025919999279722106, 0.025963426051021088, 0.00866501755808713, 0.015595956974721048, 0.040813275991240516, 0.02016295195062412, 0.03354234388098121, 0.06019138265401125, 0.08008497767150402, 0.06272302649449557, 0.03506335699057672, 0.06376784425810911, 0.03467755523161031, 0.062296350952237844, 0.050356074279989116, 0.033049491030396894, 0.01695109636784764, 0.08587700242060237, 0.04508836573222652, 0.002715285500016762, 0.03792791714658961, 0.039961887887329794, 0.025475322945567314, 0.0306302936951397, 0.028291350354265887, 0.033954228420043364, 0.06668274800176732, 0.07702938499278389, 0.03968363074818626, 0.021741559430665802, 0.030091835869825445, 0.02423512367386138, 0.03492384807032067, 0.034972874345839955, 0.01042358657286968, 0.08371489617275074, 0.023990554473130032, 0.03609025930927601, 0.01914782937092241, 0.05943586518696975, 0.04408369444718119, 0.020939960159012116, 0.023166241771832574, 0.0688070418254938, 0.005940756709605921, 0.039960455542313866, 0.03304875630419701, 0.0224788850027835, 0.04571802608552389, 0.04729323823994491, 0.040506171571905725, 0.04059550759848207, 0.06515715955174528, 0.03237626289774198, 0.04763858923979569, 0.08249931765021756, 0.011183535589225357, 0.05228456728218589, 0.061382904459605925, 0.021026568792876787, 0.041371923944097944, 0.032570850307820365, 0.01742813219607342, 0.04602090768457856, 0.04689577363024, 0.030961011398176197, 0.035181941057089716, 0.04160181531915441, 0.03959751564252656, 0.016044709554989822, 0.013462214683386264, 0.02368794932408491, 0.0066397141745255794, 0.05634704284602776, 0.020202077976136934, 0.06109709596785251, 0.06040769272658508, 0.02218613928562263, 0.023355699086096138, 0.050833063723985106, 0.010619030235829996, 0.03323711709526833, 0.10293885876308195, 0.019318779377499595, 0.041678019042592496, 0.06514073582366109, 0.06886457311338745, 0.048264709548675455, 0.01680830529949162, 0.003263777857682726, 0.030256614918471314, 0.06560907553648576, 0.06808825695770793, 0.04171118933300022, 0.04646018489438575, 0.13049963337834924, 0.08024770097108558, 0.15931921661831439, 0.12263259341125377, 0.09550180431688204, 0.10551697589107789, 0.25553257728461176, 0.2699006750481203, 0.1452344114659354, 0.16423426772234961, 0.21305360278347507, 0.0655058873235248, 0.11712590217939578, 0.08619147265562788, 0.15498449531150982, 0.14045266492757946, 0.2858928294153884, 0.22452784411143512, 0.17119273339631036, 0.11972741922363639, 0.08798717317404225, 0.17257542873267084, 0.15078990632900968, 0.18466511828592047, 0.15878253994742408, 0.19700468896189705, 0.1882317612762563, 0.1140619974466972, 0.13844810921000317, 0.20385592913953587, 0.10393937031039968, 0.19195274129742756, 0.12404844790580682, 0.2073788596317172, 0.13400395080680028, 0.11043046848499216, 0.09745621311594732, 0.1075508538633585, 0.1181876112241298, 0.10153649651329033, 0.10483422229299322, 0.1947784685762599, 0.11347033505444415, 0.11164560171891935, 0.10502756660571322, 0.1877023873385042, 0.1325120113324374, 0.10570283935521729, 0.1494385741534643, 0.12517294264398515, 0.1875674945767969, 0.12621088069863617, 0.16340435366146266, 0.11426144221331924, 0.12138714344473556, 0.10112654897966422, 0.0975870166439563, 0.23274426494026557, 0.0910387137264479, 0.14246839738916606, 0.06430653957067989, 0.12737268320051953, 0.18627433193614706, 0.11664514633594081, 0.08805780336842872, 0.07580047007650137, 0.10115285811480135, 0.13316484895767644, 0.15579086844809353, 0.19126367202261463, 0.17626555025344715, 0.1837801220244728, 0.12571077706525102, 0.07543850239017047, 0.12312323466176167, 0.10350772237870842, 0.19164369616191834, 0.19051297480473295, 0.20337282068794593, 0.13627092994283885, 0.12794099020538852, 0.17213808110682294, 0.14472428883891553, 0.14944229973480105, 0.08745350220124237, 0.05800325670861639, 0.11211438672035001, 0.16150124953128397, 0.1992328092455864, 0.153338678937871, 0.18953908409457654, 0.1836267052567564, 0.1502798282308504, 0.1330439976300113, 0.16872555250301957, 0.11102150747319683, 0.10460965582751669, 0.09198836589348502, 0.22993851627688855, 0.08105350265395828, 0.13307936838828027, 0.16381559253204614, 0.1660780594102107, 0.11623943646554835, 0.21733333094744012, 0.08989552428829484, 0.11982286683632992, 0.18723556160693988, 0.15735818044049665, 0.15096701245056465, 0.12388588045723736, 0.28512708144262433, 0.1021423190832138, 0.09694949694676325, 0.14028945181053132, 0.07082077790983021, 0.10329721961170435, 0.11682814511004835, 0.1342910877428949, 0.14977095241192728, 0.11812498880317435, 0.08682094747200608, 0.11936249036807567, 0.10184353785007261, 0.13647509476868436, 0.08742428384721279, 0.08638127692393027, 0.09135891334153712, 0.1069965586066246, 0.13383794721448794, 0.10113655313034542, 0.1690230201347731, 0.1589277634047903, 0.16113599413074553, 0.07277686396264471, 0.1729739471920766, 0.12119156526750885, 0.12366105424007401, 0.12749433604767546, 0.1371675927657634, 0.15405213518533856, 0.1031304664502386, 0.2656273590400815, 0.17844707850599661, 0.15122719458304346, 0.10173558504902758, 0.22706153627950698, 0.12236524213221855, 0.0824643402302172, 0.10051665201899596, 0.1388113311259076, 0.14824468118604273, 0.14803058642428368, 0.1026929407089483, 0.17176071385620162, 0.1480238328804262, 0.1150982359831687, 0.2263857811340131, 0.14814956753980368, 0.16520222125109285, 0.1624980874476023, 0.12048627264448442, 0.18357570486841723, 0.3028412855928764, 0.15519970329478383, 0.11401206575101241, 0.21322484593838453, 0.15964513819199055, 0.1292011421173811, 0.19333111733430997, 0.21972248243400827, 0.1613722791080363, 0.10829332808498293, 0.12757337477523834, 0.17992521403357387, 0.17820507899159566], [0.015312323903344804, 0.0031521208120466326, 0.021671799404430203, 0.01723443165246863, 0.03892704458849039, 0.02131499335519038, 0.03415413331822492, 0.09481596338446252, 0.030953135355957784, 0.047910590074025095, 0.05238874255155679, 0.008830488659441471, 0.027897741201741155, 0.04802892552106641, 0.02872244167519966, 0.00993737501630676, 0.027052345940319356, 0.059070691422675736, 0.039525453103124164, 0.03641754272393882, 0.03191048359440174, 0.01622981231776066, 0.030248850198404398, 0.05013616850192193, 0.03842617283225991, 0.057055894067161717, 0.061473368550650775, 0.03302106306364294, 0.050557585927890614, 0.07940713709103875, 0.036732072330778465, 0.02377716104092542, 0.059601638713502325, 0.073335278138984, 0.015700486619607545, 0.04044820983835962, 0.034911227849079296, 0.02968590892123757, 0.025373719217895996, 0.04386870910821017, 0.00769698471231095, 0.013398879800661234, 0.10443082050187513, 0.06445996375987306, 0.08200992320780642, 0.05585543309280183, 0.009018565579026472, 0.007796693644195329, 0.03254951356211677, 0.0243313486862462, 0.030367645777005237, 0.06525757213239558, 0.02536287829570938, 0.0494859395257663, 0.06631160737015307, 0.055050985829439014, 0.007916804679553024, 0.049538390812813304, 0.039266447274712846, 0.041421651549171656, 0.02518959609005833, 0.0326078686339315, 0.07409602403640747, 0.09707339107990265, 0.10648558993125334, 0.027535753106349148, 0.05059477494796738, 0.03253417708037887, 0.0045661085732717765, 0.0132326767561608, 0.040623798267915845, 0.005743346355302492, 0.053852769851800986, 0.025935929479601327, 0.010029727873188676, 0.017416205882909708, 0.04803730065759737, 0.030891514834365807, 0.0678773237450514, 0.06252819046494551, 0.008400556016567862, 0.04418466363858897, 0.04566127034195233, 0.04296290673664771, 0.04499213144299574, 0.05971185506496113, 0.030099995783530176, 0.024702775044715963, 0.028992299558012746, 0.06354917044518515, 0.06009841010381933, 0.06862574999104254, 0.03757311118533835, 0.018269482752657495, 0.04592394609062467, 0.022094819869380444, 0.0436004635412246, 0.014238133790058782, 0.01880027419247199, 0.05817038094392046, 0.03196924313670024, 0.017902099243656266, 0.02265011702547781, 0.07709429322858341, 0.0375630068447208, 0.03128253389149904, 0.015300907816708786, 0.034300982079003006, 0.0456982812465867, 0.027081324951723218, 0.06594264123123139, 0.05836851581989322, 0.0013715916475121048, 0.055092894908739254, 0.04448819832759909, 0.025997750381065998, 0.05750954667746555, 0.04760217205330264, 0.016462685271108057, 0.04039866405946668, 0.04854208353208378, 0.025226735015166923, 0.027795582718681544, 0.030059828895900864, 0.08390981383854523, 0.09032888658111915, 0.04556417145067826, 0.05593158115516417, 0.02005985279538436, 0.07232007206766866, 0.010282346593157854, 0.026328833591833245, 0.062089777857181616, 0.03716253653692547, 0.035117010556859896, 0.04695358693425078, 0.035206992251914926, 0.052454700926318765, 0.0502506855991669, 0.03517936580465175, 0.01253344933502376, 0.02789083922834834, 0.020150071977695916, 0.04014987760456279, 0.0919197840266861, 0.02077686021948466, 0.06705112042254768, 0.02645781514729606, 0.06009251002978999, 0.06404240179108456, 0.0823725142981857, 0.03368197154486552, 0.030907235377526376, 0.007738888225503615, 0.04339004241046496, 0.044072684686398134, 0.043490944808581844, 0.11895103627466597, 0.010661780725058634, 0.10102818472660147, 0.03601328375225421, 0.06318148080026731, 0.042652173215174116, 0.022457485174527392, 0.02536864107241854, 0.05259013545583002, 0.04117326214327477, 0.03893470726325177, 0.010386711110186297, 0.031403630127897486, 0.030402074007724877, 0.011152171500725672, 0.07991629492607899, 0.04016634586150758, 0.012092512497474672, 0.019944632513215765, 0.06170632870635018, 0.030823205706838053, 0.0020547202620946337, 0.08981419974588789, 0.04553761369606946, 0.04802038711204659, 0.05273426795611158, 0.022797631863795687, 0.05376157845603302, 0.050461548307794146, 0.0390518664062256, 0.030424344004131854, 0.04165899779764004, 0.08305341252707876, 0.07590182518470101, 0.04227243109198753, 0.052664168397313915, 0.06155842980660964, 0.04705789207946509, 0.07717608532402664, 0.07445267052389681, 0.018939606852654833, 0.04416720832523424, 0.11743702532839961, 0.026016441370302346, 0.08620819324278273, 0.050860834890045226, 0.058041614611283876, 0.023996857162273955, 0.04749675739731174, 0.04610753858287353, 0.023295021092053503, 0.05099458103359211, 0.05983366005239077, 0.047529801522614434, 0.04212954539980274, 0.06654685334069654, 0.0352829325129278, 0.012428540267137578, 0.07098267742549069, 0.04445109094376676, 0.02514346233510878, 0.07770140713546425, 0.0333027452143142, 0.06906808484927751, 0.05636058333038818, 0.08940468265791424, 0.08112111972877756, 0.038867698749527335, 0.058778919774340466, 0.03843187994789332, 0.039615687128389254, 0.05051862317486666, 0.040761069612926804, 0.10154683463042602, 0.10968940434395336, 0.04394256022351328, 0.05273883587506134, 0.012162037819507532, 0.02543199821957387, 0.04486914273002185, 0.05568388194660656, 0.08582902999478392, 0.06648497306741774, 0.09690421109553427, 0.030750196929147933, 0.06370847986545414, 0.04077491437783465, 0.030282196748885326, 0.02435609931126237, 0.0794052000856027, 0.04189981729723513, 0.0433264700404834, 0.07112545921700075, 0.02121090528817149, 0.0238706512391218, 0.042125582331209444, 0.056980829540407285, 0.0330537175614154, 0.04375120115582831, 0.06325775873847306, 0.05901163873204496, 0.0953758841205854, 0.053166416837484576, 0.014120687064860249, 0.032022503364714794, 0.036859499086858705, 0.026053300134663004, 0.0212104377351352, 0.01776396886270959, 0.02359455746045569, 0.03861662647977937, 0.0023481160542360158, 0.027215894879191183, 0.018145646135963034, 0.03555826930096373, 0.009386452820763225, 0.010581310580164427, 0.008755167164054, 0.02477792491845321, 0.050569890736369416, 0.0018275466550221608, 0.013099092029733583, 0.05257662465737667, 0.10659243693226017, 0.014163871710479725, 0.034288781171198934, 0.021733852227043826, 0.023252963583217934, 0.012734254087263253, 0.011814075387519551, 0.017101897065003868, 0.027560192029341124, 0.03680440946482122, 0.02807939483318478, 0.01432184155419236, 0.10916026047198102, 0.04051327763590962, 0.10288354649674147, 0.05714478851587046, 0.09014570227009244, 0.04882175817328971, 0.05009666027035564, 0.05222812695137691, 0.07269079709658399, 0.06663953274255618, 0.029822684882674366, 0.045231496333144605, 0.03603934426791966, 0.07228958464111201, 0.06671774026472121, 0.05899433555896394, 0.04439733347680885, 0.015482577218790539, 0.09372232714667916, 0.04355397541075945, 0.020663011055148672, 0.07515676086768508, 0.02769384540442843, 0.019402540019655135, 0.01191704002849292, 0.06490587576990947, 0.08588660581153817, 0.031182043385342695, 0.07033712026895955, 0.012192735830467427, 0.01403769640091923, 0.06929332666913979, 0.08521674331859685, 0.1174645812716335, 0.028827713467762806, 0.02725098547671223, 0.007077559039316839, 0.05272134716506116, 0.04379685808089562, 0.03108982968115015, 0.05025840022426564, 0.0320285444468027, 0.024638108006911352, 0.05299047217704356, 0.027213661014684476, 0.06632235366851091, 0.040681084647076204, 0.024867990105121862, 0.010515842950553633, 0.09421908369404264, 0.016683513167663477, 0.03897554022842087, 0.03851256624329835, 0.03992808677139692, 0.10475431525264867, 0.01606460467883153, 0.05800291532068513, 0.04418288990564179, 0.02443848512484692, 0.06460920223616995, 0.1369338162476197, 0.17937051801709458, 0.11005863023456186, 0.1431513810530305, 0.18996121769305319, 0.10670707648387179, 0.17358789627905935, 0.19862107175868005, 0.11628167951130308, 0.0864618964260444, 0.1668512585456483, 0.14383391942828894, 0.10839504684554413, 0.1765546909882687, 0.10440002879477106, 0.11823663007817231, 0.09058443771209568, 0.1272594611509703, 0.18156921956688166, 0.18453467841027305, 0.1657633887953125, 0.16563483397476375, 0.1086848035629373, 0.19797483924776316, 0.16650412639137357, 0.14483175182249397, 0.0940368790179491, 0.11205713744857349, 0.11210189637495205, 0.1717179809929803, 0.1210546909715049, 0.09339163356344216, 0.1297046002582647, 0.14495861454633996, 0.2073927377932705, 0.20106016978388652, 0.11262150364927948, 0.16174709337064996, 0.10545634984737262, 0.16063115559518337, 0.08897820007405244, 0.10953401346341707, 0.25461691548116505, 0.12290014507016167, 0.2096613941830583, 0.1224468338477891, 0.173068318690639, 0.15642653277609497, 0.18941363145131618, 0.1023257928318344, 0.11657421928248368, 0.16454415890621021, 0.07481823020498268, 0.10872845668927766, 0.1951533422106877, 0.2869261958403513, 0.0930118617543485, 0.1634450233541429, 0.08126194225042127, 0.1467483927262947, 0.12816841393942013, 0.1615010862587951, 0.14999600127339363, 0.3063125774497166, 0.16711610136553645, 0.20116714294999838, 0.23516142508015037, 0.14555208035744727, 0.12295242937398143, 0.09407894394826144, 0.1818454617750831, 0.11378792973118834, 0.1139707058609929, 0.11543239539605565, 0.1457561709685251, 0.1467697962652892, 0.17430619132937863, 0.11145118871354498, 0.08628009250969626, 0.11945008605835028, 0.16229007829679176, 0.11583273953874595, 0.15185435389867052, 0.20617923728423193, 0.13686951657291502, 0.0941100918862503, 0.1546085678273812, 0.16445695655420423, 0.11922485908144154, 0.14813974150456488, 0.15976070542819798, 0.0780479826789815, 0.09215060679707676, 0.11854316675453447, 0.12510595639469102, 0.13532791257603094, 0.06701519305352122, 0.06212382759258617, 0.12160800659330562, 0.13805576541926712, 0.1324572556768544, 0.12785908678779379, 0.07948710350319743, 0.15553390723653138, 0.2359199000056833, 0.07604696700582281, 0.21053803386166692, 0.11001738166669384, 0.09768162562977523, 0.21207827230682597, 0.18077982676913962, 0.13664396305102855, 0.1279840199276805, 0.17529836855828762, 0.08222328324336559, 0.10095912788528949, 0.18789635505527258, 0.12202836645883508, 0.1793986454140395, 0.20028199825901538, 0.10622945992508903, 0.07457300234818831, 0.10934979014564306, 0.19763541058637202, 0.19031195668503642, 0.19295973179396242, 0.1516697817714885, 0.16641071968479082, 0.16977619612589478, 0.14390748110599816, 0.11083508739829995, 0.10321649620891549, 0.2084762288723141, 0.20242998143658042, 0.20658991212258115, 0.1564660744043067, 0.0815685086126905, 0.2515764255076647, 0.15617948665749282, 0.08086416593869217, 0.11146463642944582, 0.14622341230278835, 0.19653110968647525, 0.16616880922811106, 0.18403166555799544, 0.17154281929833815, 0.2023095457116142, 0.23016414401354268, 0.11931825094507076, 0.23716854862868786, 0.21591196971712634, 0.13152060593711212, 0.15571868716506287, 0.13617893331684172, 0.20970994548406452, 0.14876955770887434, 0.2818666188977659, 0.16458965255878866, 0.13330830610357225, 0.1961612529703416, 0.12495884788222611, 0.11108324673841707, 0.09775287922821008, 0.15517813648330048, 0.08857346983859316, 0.18298589042387903, 0.14610518817789853, 0.16876231849892065, 0.1343711803201586, 0.21073333744425327, 0.2562279102858156, 0.11883975123055279, 0.1859722036169842, 0.10402712185168639, 0.10923315421678126, 0.16872167849214748], [0.01599696719495114, 0.029273924192239065, 0.05365325458114967, 0.08737642274354585, 0.03580567165045068, 0.003881681432176265, 0.045895184157416224, 0.03722583060152829, 0.051502002243069, 0.027510414329299238, 0.038853571968502365, 0.0015617447252225247, 0.03894797686371021, 0.0324326512782136, 0.05699498600733932, 0.02112732832756592, 0.044877447362523526, 0.02619618953758618, 0.0666514590557199, 0.052767827874049544, 0.033649491451797076, 0.10559510919847526, 0.03904301629518159, 0.015406335460284026, 0.018090435914928094, 0.021539938315982, 0.04418296040967107, 0.027254388223809656, 0.058482223976170644, 0.0924617299460806, 0.028816406847909093, 0.02157369119231589, 0.011165897522005253, 0.04526664444711059, 0.015585026994813234, 0.05659435242705513, 0.027291772057651542, 0.05610154039459303, 0.04341095242125448, 0.036838867381447926, 0.06344279099721462, 0.005888606920052553, 0.03142590940115042, 0.03356933579198085, 0.026454822436789982, 0.02980460430990206, 0.009313893970102072, 0.04088354253326543, 0.02664850628207205, 0.03368408666574396, 0.05927339050685987, 0.11099643030320294, 0.10096240817802027, 0.08197142058634199, 0.015345704778155778, 0.04046192472742405, 0.0660226670152042, 0.0221544755549985, 0.03731717784830835, 0.027130084054078907, 0.01353775418465375, 0.05340854993846733, 0.0016369140803362825, 0.030866988709021825, 0.008581397923990153, 0.01957260687049711, 0.05744227841205429, 0.06120221005403437, 0.016683978865330573, 0.022820100384706166, 0.021543148104683496, 0.007303060147023643, 0.03840063924144488, 0.04617025377228856, 0.004188978346064687, 0.024968372999865096, 0.043753212376032025, 0.02604670986329438, 0.06380314080161043, 0.06495691326563247, 0.01515274916528142, 0.07033196976408362, 0.042866275398409925, 0.050339260924374685, 0.03537632437655702, 0.12632353871595114, 0.10181408943026327, 0.026729981109383516, 0.023466841266781557, 0.029769365282845683, 0.02284780846821377, 0.023952276351337787, 0.07657929469132796, 0.03651483086287044, 0.04412170354044065, 0.03538614670105744, 0.0162497000201256, 0.05812703209812753, 0.03565337923646439, 0.046213257519411854, 0.04526793578406796, 0.011092460154031869, 0.04665667591325473, 0.03565412509487942, 0.01301085716477246, 0.0571029944694601, 0.018113845108018722, 0.03621609044785146, 0.03416120227484498, 0.01266366285562981, 0.04980049510777462, 0.045442373884725384, 0.0648130256740842, 0.025607328752812464, 0.024145858151314314, 0.0185574620263651, 0.020980548215447925, 0.05442532194138039, 0.047271656585508026, 0.004273136964911828, 0.07635803820448928, 0.06601355344173498, 0.007547934555987013, 0.024166695802705362, 0.030710091268701945, 0.0053701662091043545, 0.03142377201584168, 0.03709626274940092, 0.00974615510131116, 0.06765733633073978, 0.06695447795209475, 0.018551259527157526, 0.03205742883437779, 0.034721371630439535, 0.04361998202512041, 0.03337623267725576, 0.021874646918149665, 0.03467266447842121, 0.024395958207605872, 0.01923860330862226, 0.06145759420178365, 0.04031284581287764, 0.012690699295490049, 0.05166370880033355, 0.01648356374062132, 0.029459728284564335, 0.016880035727808718, 0.09211912489263341, 0.015305608394555748, 0.015623520339431707, 0.018301935015188064, 0.008221151092584478, 0.011002360643033171, 0.04584209091262892, 0.035545077626011334, 0.051497968670446426, 0.060224601184017956, 0.002915233071689727, 0.04704727194621228, 0.013419695187621983, 0.027069803109043278, 0.04146876308368519, 0.03248385946790222, 0.051078172837151214, 0.05471143471368123, 0.018078294378938153, 0.015986911093932576, 0.006502718351839576, 0.014160628525132779, 0.046820300922263414, 0.054730181363993324, 0.019825395356747322, 0.08661886065965518, 0.04053148251841776, 0.014513389869534876, 0.08485223006573506, 0.01577661056217039, 0.039318464405369014, 0.02353856798436027, 0.06239532376639545, 0.019496262139000464, 0.04542642142041586, 0.019244143441028427, 0.03752731696295086, 0.05134020662808325, 0.0544044490379747, 0.014399805095308693, 0.060952666608500294, 0.038426844475907274, 0.052425207977648824, 0.02454329121974297, 0.05576128794928081, 0.04675245378166437, 0.06085099979827646, 0.02531672227632953, 0.07745476919808425, 0.03442132874624804, 0.09168496850179508, 0.044851798738818616, 0.09040612931130454, 0.03370080725289881, 0.07828887639334425, 0.09283039922593161, 0.0543270986963762, 0.053758828798891045, 0.018914798711193725, 0.04748223727801815, 0.07206717782537453, 0.0931334774941206, 0.026719368397607468, 0.03361753457284067, 0.017415419206372462, 0.01908239606564166, 0.05847628308401909, 0.07271682421560399, 0.009628709303797223, 0.04822832946956623, 0.05814183423353825, 0.02322186017408967, 0.07309923064894974, 0.02742539389146259, 0.027988526271656156, 0.044565593198058195, 0.03638803493231535, 0.052100295724812895, 0.012665318772633327, 0.012193176480650436, 0.028793917917937506, 0.06922583575942554, 0.005932909425609978, 0.026791195305122528, 0.04098599973076489, 0.07415460917400196, 0.029734649469901342, 0.028411427992978133, 0.024600035831099376, 0.02852346260624472, 0.06989096335018985, 0.05193834054807667, 0.017105104998336174, 0.09277638571802527, 0.02571920009359019, 0.016751161783759017, 0.06171336797706317, 0.06373058102326468, 0.0306271284352988, 0.060418954817578197, 0.05476073929457925, 0.0491201646218542, 0.03908589387719985, 0.04557842810754664, 0.04141728401009459, 0.0188950186202419, 0.008324795726366574, 0.0537668291508453, 0.030585670210712124, 0.036234380677342415, 0.05646651377901435, 0.03766153065953404, 0.04826362601306755, 0.023222281342896167, 0.05189217896258924, 0.029176185198593885, 0.06938890044693835, 0.053941501028020866, 0.05073476997495163, 0.013701144489459693, 0.018878682094509713, 0.05514820717507973, 0.010757613326859428, 0.06837621767772362, 0.04913494078209624, 0.03483664942905307, 0.062117823617882095, 0.026335640941397287, 0.02728241728618741, 0.06521490606246516, 0.028472308222262654, 0.01267243782422156, 0.04796688568603713, 0.08136950913467444, 0.09748143129399978, 0.025058068968064617, 0.04416035830217879, 0.05174315570911858, 0.04572900616039988, 0.025081604326260276, 0.013786365307169035, 0.04530222300672904, 0.03010838947375305, 0.02623568107082974, 0.013659907981491415, 0.060210381634533405, 0.04540105481282808, 0.026931299798889086, 0.02789703430607915, 0.017620606340642553, 0.06630646428675391, 0.03931926592485979, 0.018822731581167318, 0.007409158970403951, 0.020612107146007475, 0.014466237516899128, 0.036870230542263016, 0.008809384762571426, 0.058932603715220466, 0.039856599396443926, 0.018323511103517376, 0.05699895649740938, 0.06190056730702054, 0.024873780712368898, 0.02300220301549416, 0.017162623298645485, 0.06892965946462937, 0.012686472764471546, 0.03202923464414198, 0.09336925038951449, 0.03191865835106, 0.04710569752205629, 0.026264307562087197, 0.03567381056200247, 0.027585885181906633, 0.06800944087444805, 0.04595195103320293, 0.0340972810954554, 0.033802715261117555, 0.03211084862414282, 0.05170421893126331, 0.06257607383304276, 0.018751047537080012, 0.10331680488889106, 0.028588636159838643, 0.06287328913458623, 0.050128131042583846, 0.027328495380061213, 0.04021285996714141, 0.040479305826011114, 0.05493474694958422, 0.014382124354597181, 0.030043763254070655, 0.0525654850207502, 0.012471460522647249, 0.08563526265788823, 0.016502800208400004, 0.0111553302667744, 0.03338114569487516, 0.05190960087929852, 0.030413571730605327, 0.05265565596346278, 0.016941062531259377, 0.022904213547008112, 0.013058921431365889, 0.164195453398861, 0.1670760996057652, 0.19528952630935237, 0.2634180447785184, 0.18818487238604575, 0.19265657931100577, 0.08640098094474524, 0.08544508731574751, 0.1439200234017335, 0.16186678694793954, 0.15246003546053544, 0.12899181194370613, 0.1990616848343052, 0.08549547914299183, 0.19190603052265942, 0.1306557812495157, 0.134852463088464, 0.1703852618811652, 0.17636974778724834, 0.1001379414810799, 0.16272620880044997, 0.16245553269982338, 0.09027655032696202, 0.15456675522727892, 0.13991530548082665, 0.09070265441550873, 0.1666207771631889, 0.1432353921700269, 0.1839798636501655, 0.15468484576558694, 0.06935422730748542, 0.22427701303968206, 0.17709346051560715, 0.17869755334686488, 0.09649053798057139, 0.14614778745453805, 0.11244389286730438, 0.16448456444777548, 0.10310060242773034, 0.15240055974572897, 0.11827284688479267, 0.24647430866025388, 0.12179561410448514, 0.19027726870262995, 0.09607662737835199, 0.05701666043023579, 0.08791383414063603, 0.0914908226695843, 0.18289094005012885, 0.09273599804146215, 0.12750569090712816, 0.20615397457731888, 0.17882400046801195, 0.17152674437966198, 0.10161293030250818, 0.11577722689253278, 0.17935346346348524, 0.11263461739872582, 0.273661048267968, 0.14250909676775336, 0.132623155368492, 0.26581788319163024, 0.140702590579167, 0.1303188016754575, 0.14531460794387385, 0.09245520646800287, 0.09482878769631498, 0.28905423008836806, 0.10617868218105286, 0.12393651719321497, 0.19568669405998662, 0.09233830336597748, 0.18982334149768576, 0.1671604224247858, 0.0850280374288559, 0.3101125219836831, 0.11797724204370752, 0.13891610753489658, 0.21608505339827389, 0.24926867277827114, 0.12593307998031378, 0.1362951536430046, 0.14669179654447362, 0.1888461408088915, 0.14225819148123264, 0.17851419834187254, 0.14772928931051865, 0.1086489949375391, 0.06947222136659548, 0.1719079856411554, 0.08903377951355651, 0.11171385704074055, 0.206317855627276, 0.10069433701573871, 0.16541327320737764, 0.10921088978648186, 0.0976627750787884, 0.16195885778870434, 0.12567816709633917, 0.14271664578700438, 0.19486798642901704, 0.0923041497298982, 0.2258077371516265, 0.10334957813029177, 0.1380599066033028, 0.16858012124430388, 0.09626642422517762, 0.14231983426725492, 0.1256660552462563, 0.1315470560803078, 0.10459772951435298, 0.12995474855415523, 0.17964852653676644, 0.18105799856130034, 0.1188232607091777, 0.09709687263239175, 0.13477948028594255, 0.11272342278971337, 0.0762072486395482, 0.09016666794195771, 0.1391852251254022, 0.1505819268641062, 0.12061398883815855, 0.1256021118024364, 0.08908190036891028, 0.0578912443597801, 0.13686705264262855, 0.14049826248083264, 0.0638188372249715, 0.20971301797544584, 0.15008807211415842, 0.15757650544401258, 0.16690537595422938, 0.1297567435540259, 0.1255335522000678, 0.15747762168757617, 0.07228703165310435, 0.15000888495706022, 0.13525126356398687, 0.15102043224032968, 0.17121207376476377, 0.08001658876310103, 0.09155515203019604, 0.10952314842143096, 0.12784333841409534, 0.11360175456502475, 0.12184655512101017, 0.17139131727162749, 0.11998862551990896, 0.10799758223583922, 0.09918458599713631, 0.17488095501903445, 0.17856319493148476, 0.129147915286012, 0.16748904541600496, 0.09400340073625557, 0.1633413601666689, 0.09123470008489676, 0.12181988975498825, 0.1054942884366028, 0.16524655715329573, 0.0971060455776751, 0.12566467485157773, 0.08239733913796954, 0.2122066490119323, 0.1023171393899247, 0.11396774469176307, 0.12306335076573305, 0.10043768750620075, 0.13059311429969966, 0.16117126098833978, 0.11280231308774091, 0.3145684360060841, 0.0931209055124782, 0.1532909439993091, 0.1467461365973577], [0.024138167646015063, 0.07125048883608542, 0.04434257039974909, 0.02673247658094624, 0.03175009063852485, 0.048728514739195816, 0.029603576913359575, 0.03524861931509804, 0.035850285858032294, 0.05442794914415572, 0.03573974667233415, 0.016012682172004133, 0.03856481343973428, 0.023560403824376408, 0.02865274844225496, 0.04623303946573287, 0.04453859757632017, 0.03900577903550584, 0.019808311117230915, 0.043529985487111844, 0.06794209839426912, 0.012352759567875182, 0.04078360492712818, 0.027489584099384956, 0.04910047173325438, 0.03162055247230455, 0.12228771738591604, 0.019511066129780374, 0.06156270457722712, 0.05253902003460098, 0.0369117759692017, 0.03666742013592739, 0.10654266850906424, 0.08772740664426237, 0.032550285395700485, 0.02998152674990706, 0.0569226414518198, 0.011840924435091438, 0.015182397964963457, 0.014511546560243005, 0.05366987497836817, 0.007679393493162934, 0.02120931338140508, 0.08102685213088989, 0.04559007611533161, 0.04599197876814287, 0.05774594297690783, 0.018733443794189952, 0.026412638762849383, 0.035705533664440736, 0.010424758238514187, 0.06787226229789667, 0.0707839748065453, 0.01577182556502521, 0.12683453707722947, 0.08591646983404644, 0.030589364250772633, 0.028771230463462416, 0.05334835062967613, 0.04185972276900429, 0.06143070990219712, 0.05981222311675083, 0.029211299915914424, 0.03771014875383116, 0.05808176480059046, 0.06610248499782756, 0.036976198098273017, 0.06567672229721211, 0.021117773176229093, 0.015793264356034342, 0.039466088710469194, 0.03155316546326503, 0.033878410613397136, 0.03188589253113605, 0.025695143376651686, 0.03937719055102207, 0.049514556740177795, 0.0068040957103221444, 0.06208807462826371, 0.07451581986970268, 0.034853915494750254, 0.020599015660991427, 0.046915744824218564, 0.06359042643452995, 0.029995163713465445, 0.012857849505962804, 0.0290169203071855, 0.06738076015608385, 0.03732552329893224, 0.08412281022174284, 0.07530839648097754, 0.08427947017480619, 0.011507253911986481, 0.03160857049806509, 0.04250544690876268, 0.04418466363858897, 0.03418239801249001, 0.023739018361084163, 0.025913225326803513, 0.036585308916983195, 0.05969264457235113, 0.06961932987906039, 0.0552405934286071, 0.06975428201258183, 0.05648141239362303, 0.028375109141052235, 0.06891014098073356, 0.024546328459109645, 0.05878310177649837, 0.027160133613506332, 0.026451787052792497, 0.0845095062686596, 0.09269725051126443, 0.045700626433244906, 0.017543491630931385, 0.04767493963299785, 0.03079711921600392, 0.06627334965742193, 0.017250757045985665, 0.024426059717370663, 0.009810017836571205, 0.01468430276872823, 0.037769743212265894, 0.07559094694443047, 0.024026454011618625, 0.05517749974387698, 0.014118101607891731, 0.022191443786141463, 0.04123985876503866, 0.09946966718416661, 0.008589270255470183, 0.028724799849442206, 0.016392418729083147, 0.07688181634875946, 0.03983523667557165, 0.04749377396365162, 0.06529297257657163, 0.055526357391499914, 0.07562358659924939, 0.08089561815722845, 0.04438172240043059, 0.025689232170407195, 0.08068906361586414, 0.05053954060713295, 0.05303940939484164, 0.034063732309732586, 0.02589818941487465, 0.04615287638443988, 0.01045842020175769, 0.03243865896365605, 0.01689367083599791, 0.05656920846377034, 0.10261672956403345, 0.038790444887126796, 0.04284069356799591, 0.024977727771329228, 0.07100920178345405, 0.059485607634996995, 0.036386446736287326, 0.05299151860526763, 0.02176167534344131, 0.007633869226992829, 0.017206938791787252, 0.018581461226858664, 0.022672542872896884, 0.04073820404300932, 0.06442184705520049, 0.04625387526175473, 0.0355315408523893, 0.0532912349444814, 0.04267902782885358, 0.01013413228065474, 0.07633024477399886, 0.0705510591797065, 0.0649157834413927, 0.010382353775639785, 0.01689836677542189, 0.047179585744743235, 0.013736272194364574, 0.026463204994797707, 0.020905873316223733, 0.07387772129732184, 0.006874288965263986, 0.020062168296135496, 0.10920515298494138, 0.09639031835831702, 0.03070392216613982, 0.034066897569573484, 0.03918342321412638, 0.05363448566640727, 0.037998306142981164, 0.030643030804640148, 0.0271984506980516, 0.07370750230620615, 0.03699867032992188, 0.06031430086295586, 0.07888171880040318, 0.02632711923070019, 0.044582703412743285, 0.02531783735321369, 0.0867930130334571, 0.039511808718089014, 0.0432905500929337, 0.018977562140207738, 0.05652376676152926, 0.050174411371699534, 0.03128837088297587, 0.03349676488141995, 0.10158387522096746, 0.041654767555883154, 0.019062855317315552, 0.043546260785660706, 0.010641702847351553, 0.05972195940557867, 0.05997939930239227, 0.015921177218842786, 0.044005850577377714, 0.022820078120275866, 0.020791679053218104, 0.014924937659088755, 0.051026211367570795, 0.009351495809823973, 0.0456153314007679, 0.038361539191100746, 0.04186314035905525, 0.04279715176380705, 0.02867014438379556, 0.08527935831807554, 0.03676852662465535, 0.04527775810856838, 0.02494904190825764, 0.03033907680219272, 0.03962930182751734, 0.01922796462167753, 0.019517105356499087, 0.04612597724189982, 0.0764452776638791, 0.06139879013062455, 0.02388013217569096, 0.04079699698195327, 0.03445829883276019, 0.024263661107397638, 0.04119541154068429, 0.05475100231706165, 0.04569926459225826, 0.04311674281780142, 0.04442820682015736, 0.10069507916341536, 0.014034290870768018, 0.03066942899749847, 0.03927468882466201, 0.04470970714464784, 0.05615626636426896, 0.03782757506996859, 0.025926216621883214, 0.04983273029210977, 0.013347841377253644, 0.05152381767402403, 0.09448559634620324, 0.05382265349908266, 0.028218545667186845, 0.01920165363117121, 0.018912763371190522, 0.014891089231241494, 0.05512805415492039, 0.07289100627531298, 0.07598240757943131, 0.023311253717110958, 0.018404748443572316, 0.048526828686590306, 0.018027908117801417, 0.03329492668854073, 0.06070309718779754, 0.038194452063180506, 0.02416143583104713, 0.0951476366026327, 0.010799958417919697, 0.052235834154998884, 0.10349284973926842, 0.039562063248013146, 0.04482126307266299, 0.0282143506774446, 0.05525470165594015, 0.042047389651997946, 0.03318609444249887, 0.05837634176714346, 0.051267409362480976, 0.0659161242947448, 0.10676656704163179, 0.028835732373408973, 0.03642914991360158, 0.011521454907779116, 0.042311434663133696, 0.027380341816751752, 0.0484638648777036, 0.06984543259022757, 0.043117466411786154, 0.089719716925174, 0.060737336170859635, 0.03770977767999284, 0.03609640429203864, 0.06427834538044408, 0.004253366614648257, 0.026528933303779922, 0.009504455229034647, 0.02664861203811597, 0.019209852507628966, 0.028004927735310048, 0.0882011120847892, 0.0714595741010271, 0.11078200899646617, 0.054501919003087096, 0.03209868853446096, 0.04930813949613366, 0.021525418196688406, 0.03632371299318038, 0.0328855580301024, 0.01761002145940438, 0.0455980690458091, 0.0839844293659553, 0.03552783753548283, 0.03311501524876803, 0.05493142954946961, 0.04529490914137568, 0.08317531028296798, 0.010836461879080161, 0.046509767780662514, 0.031719636608613655, 0.016316561959683895, 0.028345694117888343, 0.013946552317065652, 0.04007206342066638, 0.025635524798417464, 0.059617680235533044, 0.053387346779345535, 0.023862031193857547, 0.03889049752615392, 0.05099595771753229, 0.044641206914093345, 0.04927733665681444, 0.06324707181192935, 0.03424991118663456, 0.021949178953946102, 0.07160294218920171, 0.024157287225534674, 0.03556594310794026, 0.022321800170175266, 0.012647925614146516, 0.005410116018538247, 0.021995930546836462, 0.05437049207102973, 0.04169755236944184, 0.06862090376671404, 0.14609723235480487, 0.149048145103734, 0.09687603916972876, 0.16093004815047607, 0.14341019763378426, 0.12422840387444012, 0.08699795711436309, 0.2480390528216958, 0.18988398980582133, 0.19130578148178756, 0.1371995496447198, 0.10015187901444733, 0.22684509633108974, 0.10868177560041659, 0.23096904769772664, 0.16282432072330266, 0.12388962830300443, 0.10445502193761058, 0.11592564900638536, 0.24837226228555664, 0.12294396889046766, 0.15958429692545906, 0.08542780269635841, 0.12740821723127738, 0.1409746173885651, 0.2064548115595244, 0.10124503285624087, 0.19577788916649297, 0.16088851756649092, 0.1284810362267308, 0.1783851537038572, 0.15234516584314406, 0.22525584645336494, 0.19559689419111237, 0.07900965021690354, 0.17808158561820164, 0.13078739371849224, 0.12125532317440957, 0.06404373765690252, 0.12552127707749605, 0.06123389975982718, 0.13192786689614877, 0.10737157324911095, 0.09479650427238084, 0.09580943195032887, 0.1375188067322597, 0.14600869413698092, 0.10200362652540207, 0.1450649494654499, 0.08511923995683901, 0.18682200723560527, 0.1315987392445095, 0.1407379168085754, 0.26008318935055286, 0.1644974629743956, 0.12815878086257726, 0.05911247804760933, 0.08476091621560045, 0.14313183288322762, 0.18446763278916478, 0.16304178483551368, 0.11746844786102884, 0.1084109659132082, 0.18347686564084142, 0.12836486042942852, 0.1786606092355214, 0.2294701023492962, 0.16806366067612544, 0.25700012978632003, 0.13003359432332218, 0.18210914684459567, 0.11855140459374525, 0.10543956246692687, 0.08461279096081853, 0.14800144970649853, 0.13679270428838208, 0.16557872761040926, 0.14024783216882497, 0.10846012577530928, 0.08798142152954824, 0.2774910052539781, 0.20132026285864413, 0.09078729635803029, 0.16478673729579896, 0.13656477589393035, 0.18842624849639833, 0.14347774791531265, 0.1470862331916578, 0.21533538034418598, 0.18678424676181749, 0.1738850076799281, 0.11534455479704775, 0.20526222477201372, 0.17647718108491972, 0.15894557494902983, 0.15826830582227558, 0.09402914583915845, 0.08458192503894679, 0.24156638217391446, 0.13602544233435765, 0.14310864818980917, 0.17759001668309793, 0.09339201948023401, 0.1732576554059051, 0.06734665847034194, 0.1449685444822535, 0.07788196424371563, 0.11147305980557576, 0.08920066626160406, 0.12426835368387401, 0.22406383854104206, 0.2217868552543223, 0.17451878695283085, 0.14934243634343147, 0.11768440541345626, 0.0952049600891769, 0.1991288788849488, 0.20634075830457732, 0.16260935022728518, 0.15250520256813616, 0.12637747800908983, 0.1786767435260117, 0.20081980299437419, 0.16923016839427873, 0.12882812385214493, 0.0801549176685512, 0.1190527698781807, 0.09298104778281413, 0.1434440098819323, 0.09849993992247619, 0.17948710941709578, 0.20745959045598283, 0.208849573682528, 0.3002121235476807, 0.09539266407955438, 0.13254114805022255, 0.11026054635294713, 0.14410775707801804, 0.17905127577250823, 0.15812569472473115, 0.08933754055760801, 0.09463403330300935, 0.18126446404494345, 0.14369938289746642, 0.10243945274851285, 0.12087289447663352, 0.11340405384544283, 0.24570082750869915, 0.13556541467551142, 0.17686717968899757, 0.08489002022542991, 0.16754690324887633, 0.1083973103959579, 0.10815660221851431, 0.11812834331067279, 0.09135752552538179, 0.1903372787637636, 0.10390421477495693, 0.11881714541232213, 0.17766915931133553, 0.11512516110087745, 0.10240268675261177, 0.09395006258273497, 0.07650720988749526, 0.08227731159422547, 0.06378078731358983, 0.1113276433898136, 0.24746675306232646, 0.17238591390196234, 0.07001751437201165, 0.07975389074999839, 0.2659482340095565, 0.10357499064411968, 0.1523340484709479, 0.17828729411121458], [0.010531931784498738, 0.041279259385191835, 0.02925163193140179, 0.055336319346679375, 0.07069559986121021, 0.054751722200307995, 0.04014489408291411, 0.04622052685590461, 0.027179037970199715, 0.09599712109775282, 0.04201710631605238, 0.020653236970247235, 0.03300112897704821, 0.05912266031373292, 0.061979335150681436, 0.029348630632739514, 0.05274969349557068, 0.021737934039265383, 0.057643634208943695, 0.021306484632077627, 0.044286627307883464, 0.03552017857145984, 0.1176062721060589, 0.05621711134153884, 0.11771970937843435, 0.10451941809151322, 0.04641423482098617, 0.03965862408222165, 0.018717046041274443, 0.04522973373241257, 0.015849808587518055, 0.011285725613561226, 0.012786607967427699, 0.05673046602169052, 0.06616756392759271, 0.07741438152152114, 0.019039370054088067, 0.021732713030360173, 0.010247826521663228, 0.09040425909915939, 0.04536468957667239, 0.03373857885890175, 0.05146294672158547, 0.055814800507505424, 0.022433615849877242, 0.010835040666279383, 0.011194816233910387, 0.028008172776026186, 0.02706249666516669, 0.01604220666195033, 0.0289859801705461, 0.07120728841982782, 0.11492563469801098, 0.013306436958373524, 0.047979457667679526, 0.030298379278974608, 0.03725316761119757, 0.031386115442728624, 0.05653382286254782, 0.07027303581708111, 0.020281012803025078, 0.0896960795216728, 0.05491074960445985, 0.01216293674588087, 0.09014975439640693, 0.039354844484478235, 0.02684981383936247, 0.01410193206538679, 0.06493636319646612, 0.1098426801036112, 0.01895154986414127, 0.03690442499646451, 0.036548335119732656, 0.029945510323159397, 0.051382854144321755, 0.030079924399615265, 0.1604604913154617, 0.0070856785987416515, 0.0378736735729035, 0.07406816381262615, 0.021751524618593976, 0.04656086093746126, 0.0697790103731677, 0.04635026911273599, 0.05878706484509166, 0.06543261508340947, 0.031684751957072876, 0.06733259477186948, 0.06431443602195941, 0.05607244078419171, 0.053580175299430266, 0.011395573674235493, 0.08332198092830367, 0.10092270327731967, 0.03344446944538504, 0.05046747435699217, 0.041903483506757766, 0.03825293701083865, 0.0063123500513029285, 0.024364159035030752, 0.06257779561565258, 0.00955313826125348, 0.07222364482004195, 0.022940181734156795, 0.060575744646484964, 0.03429707096074708, 0.047314022085629404, 0.017207237506227102, 0.060838795179734007, 0.03125128205283545, 0.05054157038102858, 0.02777204179437831, 0.04610028780007269, 0.008633635843580123, 0.03490169867291115, 0.05730032782594208, 0.006102501765781199, 0.05374855005356949, 0.010276375087414635, 0.02316887454071548, 0.03390856036276091, 0.008889199034456396, 0.00841027444039355, 0.0281055945015396, 0.04317434832046274, 0.08839297952363268, 0.029960394094814546, 0.053437278475030325, 0.041807030283962376, 0.029301007016329095, 0.021326819478417747, 0.028565213979163673, 0.028333784503047355, 0.02716744191275211, 0.018905963443103246, 0.047941552475094795, 0.038883443412487395, 0.033788325017667376, 0.016043540672399104, 0.05927589154453017, 0.03781699946557637, 0.033216741430805996, 0.027302703892928548, 0.08886838448233902, 0.04174961031822022, 0.05755666934419423, 0.007726222083874745, 0.009506715996394632, 0.05681858863681555, 0.03677424116176553, 0.041675480897538364, 0.047485862669418566, 0.04943949963490013, 0.06975199619773775, 0.06736572424415499, 0.05095332133350894, 0.016262292410829104, 0.031612281236448325, 0.010133165633305907, 0.07534320320701227, 0.08668759095598944, 0.06240069691557437, 0.036590325835277326, 0.03795192562392913, 0.03335757879540324, 0.03649762787972577, 0.03459200044744648, 0.008914360623748507, 0.10701471896027215, 0.06666699962806888, 0.0413332023890689, 0.042438813179614954, 0.021182406817388255, 0.0921663551707752, 0.004385114061733475, 0.07863922946853563, 0.007413364628519048, 0.062418397137662396, 0.02976552837935742, 0.04789396596606821, 0.03561764482583385, 0.010934157271549338, 0.04372641342342831, 0.03179437087965198, 0.04236309185216669, 0.03893753113516141, 0.017909285088535398, 0.02899046645325143, 0.009698161338747013, 0.020265162384021096, 0.03237686774809845, 0.05162469038623385, 0.031334669765783474, 0.03978405075031333, 0.04029294512292836, 0.022120986141089816, 0.0836878374684602, 0.04414403476403095, 0.058691520753200166, 0.0891508607310243, 0.10200747827184387, 0.03821593723841943, 0.06583112612133846, 0.0329526184941642, 0.016330146972904913, 0.031408472641487606, 0.05526573739189189, 0.041883055891958065, 0.03146193324937485, 0.0424637233663816, 0.042571438680170104, 0.047862049905234016, 0.03091172722633928, 0.0390307745692553, 0.05400542591814883, 0.08640272499178536, 0.05213223776081577, 0.044120438178651966, 0.04665241598559078, 0.018836789713532198, 0.03410799770790618, 0.02604466710181441, 0.029096795806253795, 0.030407157719309907, 0.030761523958062753, 0.022125262767076492, 0.02744201985478867, 0.14572062209481373, 0.07538487479905598, 0.014299540944193723, 0.017293822020292282, 0.01496373621193925, 0.08999856407172047, 0.07482412285753526, 0.03788417125178967, 0.05851894915394951, 0.041445737952017225, 0.05324267622199841, 0.046116173471091315, 0.05393273997469805, 0.041601911798352376, 0.10727558386861347, 0.030740168658667244, 0.03173468736349605, 0.06643736429396085, 0.061187370811239816, 0.032243893438135274, 0.05826568383781705, 0.040313610224984586, 0.04444562131538987, 0.0830373821372632, 0.025844454212347046, 0.0943618654855527, 0.07552977913292125, 0.043674433400155976, 0.023870816366979852, 0.016462624043924734, 0.03378009831067175, 0.0428993677633116, 0.025377021775057074, 0.012605917272594525, 0.05480100080603734, 0.056893649452831596, 0.045849007728975266, 0.012504316327976994, 0.05611731845419854, 0.03856649811496027, 0.02861658729671035, 0.07538963938714005, 0.06103134910517838, 0.03567784784536343, 0.027111261333629955, 0.008897652096493402, 0.03339793678605929, 0.03103724851825973, 0.03965412666730117, 0.06446889921789989, 0.01794825711840531, 0.0665261251560878, 0.01914126693009166, 0.03088361281697871, 0.014174419484334067, 0.0841591828793753, 0.030517941813741345, 0.049270649906247854, 0.037171687217778526, 0.07592970025143586, 0.013598611221823376, 0.05058787668531295, 0.02570842410932528, 0.029959574021631852, 0.04335877572884783, 0.06097839315771125, 0.031570097562507726, 0.05907317390665412, 0.03718586594914086, 0.013896574237151071, 0.08352757809916511, 0.027331736710038967, 0.03172214506776072, 0.01936276090418687, 0.03735546153620817, 0.0602291728137061, 0.043273744158796035, 0.05918254792049993, 0.014472215516434517, 0.03475745856121648, 0.08024144466617145, 0.02572321882325923, 0.04872635137871839, 0.025070679912460037, 0.035955496423412114, 0.007586470110254595, 0.015954584996507037, 0.03299635696748737, 0.08941220803535543, 0.05951507460849825, 0.02083861061692005, 0.017773169638530817, 0.024924910976551473, 0.03597772374632768, 0.05020863922254648, 0.022583596473850776, 0.0068039741836400935, 0.03826371299510356, 0.0736621199757792, 0.029406481044134125, 0.051142954907845706, 0.05792265947093256, 0.023294779894058593, 0.05961232564004604, 0.059979603393003345, 0.038993841590126976, 0.05944151293078903, 0.01619047106942162, 0.024525934240955394, 0.02985633571370272, 0.030614519346272573, 0.010306551739631686, 0.02983196358400164, 0.03279541677329689, 0.017085747931560036, 0.030414406646741554, 0.07175611404818483, 0.03560666104021948, 0.06339540486806072, 0.028082981261832174, 0.09221419401001185, 0.037845471961190924, 0.04224107906338759, 0.03328979102661833, 0.02735928152105771, 0.08145373547449708, 0.18526097381254658, 0.06841403010184877, 0.15139113500481471, 0.17257033759960905, 0.15340903453761712, 0.13447229051962495, 0.1191159563313704, 0.13055400311714038, 0.19145666010444984, 0.08328128897119313, 0.15906137967249379, 0.23396134260110557, 0.21629788650898263, 0.13321187143446878, 0.1765521231573075, 0.16266009828541428, 0.1460539799882099, 0.14631674479460344, 0.08846619239193387, 0.18556308728875592, 0.1293148539843969, 0.2640311775030568, 0.24014384835027158, 0.265207540942356, 0.16085834184195846, 0.20307897473685443, 0.11979850954958238, 0.0770215033844579, 0.12033977269311436, 0.12117195030441508, 0.091761209332617, 0.13995698449434713, 0.14268860744778067, 0.13053544942522421, 0.19043792883167043, 0.14504050312098116, 0.12193712682346813, 0.18292528664460406, 0.21560290973866358, 0.09720830610604025, 0.15925165149383247, 0.1653073390480131, 0.10844749442185275, 0.11945220117922872, 0.24625323771033436, 0.09338546631624922, 0.2873026725137606, 0.07110945109161548, 0.08869699289789423, 0.12141024650190957, 0.272034527733922, 0.22802724852226675, 0.10788260871777311, 0.13041119906120002, 0.07188017145381309, 0.1319578051334247, 0.12905804120237008, 0.08795559479040094, 0.1673025288619101, 0.09759500215295702, 0.16419068881077692, 0.14813426445471123, 0.1109026451013051, 0.13529018178815022, 0.11245482470258139, 0.09345700935227796, 0.1238285272847861, 0.15053132723551244, 0.18457052414305508, 0.09446029653190635, 0.07832366085494868, 0.15662446356145665, 0.15453656465979293, 0.13896741962525994, 0.10650700831320137, 0.24855992174707353, 0.16475666547194123, 0.12427967143594287, 0.18580407748231664, 0.1645729097072035, 0.10883196402573958, 0.1508919961634092, 0.2299379967735149, 0.1152062184701208, 0.12976306665223092, 0.13118552626110613, 0.15102884819498286, 0.18348035373492166, 0.11738223256543279, 0.19386712607229128, 0.1844903573510237, 0.13780398439848796, 0.15639442746760324, 0.11544364635483362, 0.2172247992712073, 0.18275966896908358, 0.18636411696206778, 0.19161647418513894, 0.22708233125740662, 0.27206433238461614, 0.12051966186845675, 0.14292575331637636, 0.11655936890747398, 0.23615406244061887, 0.13530195225030184, 0.18936016713269055, 0.13356142299016938, 0.113165831862716, 0.15615299198543653, 0.15053488954436034, 0.097990017675329, 0.171357519866433, 0.23708817403530702, 0.1317527942592278, 0.1029135069984477, 0.1962036147597246, 0.16061456117313355, 0.08410128051764332, 0.19657225435366854, 0.05209780210861936, 0.25860043766442686, 0.29349185759201646, 0.3367825783789158, 0.21836093830643222, 0.15936096984660253, 0.1729876917670481, 0.11570555769139901, 0.1892562219290994, 0.11476429921458475, 0.18333400221308693, 0.15120172407478094, 0.060791698488174006, 0.10753054128144868, 0.13135056506143883, 0.17539279942866415, 0.11411482351832092, 0.15534915699390694, 0.12256235655513592, 0.20682294649304822, 0.15542093751719221, 0.0657786859665066, 0.1871286626555957, 0.12836189183872193, 0.18006739468546584, 0.13234798185294494, 0.18561165343271568, 0.10362026165239513, 0.16760707658249885, 0.1299470747471787, 0.11951203312491998, 0.08451639339909889, 0.16071645804913715, 0.13522840541554615, 0.1730543069425039, 0.15137546084588394, 0.12975735211512074, 0.13513321755453944, 0.10495768598048016, 0.2203354222001508, 0.13529695017496124, 0.15910075802821666, 0.1410862067132257, 0.12858716334449127, 0.1786894936230965, 0.09935104972100817, 0.158351871650666, 0.1356897540972568, 0.1315291554783471, 0.15112819208297879, 0.14210508641554043, 0.24379566020797938, 0.05729784163122531, 0.16834321286296472, 0.17128792125731707, 0.1375533314421773], [0.02272684210765874, 0.03392203034309205, 0.035956861975137144, 0.045710289195994847, 0.010906355491897557, 0.031038415545481257, 0.028674474815488793, 0.07607868639752269, 0.07563259627204388, 0.0588737254292937, 0.028773981975973584, 0.043449540389701724, 0.018870807907660492, 0.054869578962097876, 0.025219918388756923, 0.05504454027686734, 0.07270584042998962, 0.05309720043442212, 0.010457870084792376, 0.027906040268135257, 0.02533211441914318, 0.04288515563530382, 0.015339432702603517, 0.04671657836297527, 0.04979592347808648, 0.02621106403239537, 0.055355726508423686, 0.0237042413209565, 0.036197555309627205, 0.04690223031502683, 0.032245949187199585, 0.06123308339738287, 0.07432967438944615, 0.06440571276471019, 0.017836009137681685, 0.04607477276294958, 0.005974742898615659, 0.015556799407931976, 0.05277839234622661, 0.04708628293883521, 0.01997240739001427, 0.04723320962511934, 0.00874216937518213, 0.05085095690446906, 0.04457646937225945, 0.018471868279448245, 0.07175583945354447, 0.020170794596197084, 0.02535854229790857, 0.0030654221927761682, 0.06381866653100587, 0.034808358759619296, 0.04765522819070611, 0.03033836248505395, 0.009551620569254737, 0.04567361596855335, 0.04758706192660611, 0.039971676815184765, 0.04915828503726516, 0.09915069953422062, 0.08941073858295567, 0.05223201951594092, 0.025641756983532105, 0.0676738194306381, 0.013394245088420575, 0.04950562499288935, 0.048902210692176595, 0.038834762235637754, 0.06041580068995245, 0.04488434933591634, 0.02108827651682077, 0.05673507846950088, 0.036570677475538105, 0.03270267428888474, 0.1081916835391894, 0.08195812872145325, 0.04128511864109896, 0.014338913733809022, 0.004393275830807397, 0.043517398662515916, 0.07419737914460711, 0.07783673776430078, 0.06640506602707319, 0.017953509668586776, 0.056078455891110934, 0.02114030849043047, 0.021747667306044605, 0.02915988578024553, 0.10787295337649994, 0.011655890320980689, 0.019011745462194085, 0.03755492485652212, 0.039676795568084344, 0.07672036212170497, 0.021523607356357388, 0.05649887883919291, 0.03132211262709461, 0.05335259571438655, 0.018310477134946268, 0.02130947363184532, 0.04918707665638067, 0.021737234565080144, 0.09128478763159364, 0.050096526683773845, 0.02525810559745878, 0.026078397713718005, 0.059727436455432326, 0.030471659629256465, 0.1453244042932056, 0.03371077429619618, 0.01623454907530686, 0.07360374263953418, 0.03626517609518487, 0.030105971927696373, 0.02693606624234235, 0.042394358533783816, 0.03738138846529182, 0.029126268345862627, 0.026080290190293454, 0.011237396956857992, 0.010681304775062017, 0.06089200345741119, 0.04193089102045633, 0.014818330928392243, 0.1383130086469464, 0.017522550078865606, 0.04148617386817932, 0.057740788761293516, 0.02223380743089365, 0.05524269370653201, 0.02345708944631042, 0.013066948686173419, 0.0783997013058979, 0.037643166215275414, 0.04601514861860778, 0.08575736821512692, 0.02955077125079697, 0.05930076462391298, 0.020251310197636485, 0.09894231930957176, 0.046129483889671974, 0.0530038308352232, 0.02511873397452291, 0.0829898178926669, 0.07664361663046293, 0.03858364543702919, 0.03658733498014044, 0.05306339189701248, 0.006794690843889839, 0.08491342014167458, 0.06101318504079245, 0.09447859047213569, 0.06572193393367343, 0.0311632967350306, 0.019507475990394596, 0.022192273136170115, 0.022665063879685476, 0.0235690145927947, 0.039746535185258836, 0.04572326193738263, 0.03591132008295972, 0.05729857635742519, 0.057167895283782855, 0.042383512045489624, 0.033009281469276175, 0.013913208549638512, 0.024836827324179467, 0.06035779071680736, 0.018242218102386687, 0.08242827185313217, 0.050640810368349776, 0.039583715406479314, 0.015534582289546961, 0.04603776185831521, 0.031387380804517306, 0.04649382644856814, 0.042581090310704894, 0.037648249926860444, 0.014414318720810115, 0.0689667223196011, 0.05448134666949045, 0.09592938527930528, 0.02854667884093942, 0.042214038912788965, 0.04472372260352131, 0.059308456984581426, 0.03926719684386626, 0.049224046742892824, 0.022921255113033112, 0.013008546302444302, 0.03749474410142284, 0.03803861960477661, 0.07367153040831909, 0.02502654624549905, 0.024948630016297102, 0.04633271732018329, 0.07530009184847586, 0.029432860683300532, 0.03392300626728684, 0.028123454285378102, 0.01171519255876774, 0.023404213279718533, 0.013706794088648167, 0.03987597687228117, 0.01908980826556217, 0.030851036244712304, 0.03044492746994365, 0.010613196027406957, 0.1025055261561647, 0.016458273203170393, 0.015656078358006198, 0.07064817662467249, 0.034848419891204685, 0.019822068679786753, 0.05745012662373483, 0.047371505133924074, 0.06502073796582408, 0.048283541545970365, 0.017988531617447734, 0.006233417079783976, 0.017555885497131385, 0.030519157080561854, 0.05841670717927627, 0.06518062626128085, 0.017780004818632733, 0.053562775647151284, 0.0229765655240044, 0.008759975353314076, 0.019486968594719656, 0.031710664043202996, 0.011392599517421331, 0.03569231601431966, 0.015812378369446378, 0.04939480379107408, 0.04933667878503911, 0.08402312494581565, 0.0344978033535881, 0.038179887415026315, 0.015794058454048354, 0.03393828708794899, 0.04126525134779513, 0.11328207445330918, 0.06916052676388063, 0.03580065844289493, 0.07671127081266604, 0.02033031552855391, 0.10696016368456185, 0.12714533368125558, 0.012599784349731635, 0.023080642458808143, 0.06251836442970671, 0.08743392434553243, 0.03576913943106774, 0.036543203168548644, 0.06124966668721754, 0.031991117939469405, 0.06293007085332647, 0.10544855729676783, 0.06942203734070063, 0.03550712048308924, 0.0387339860026259, 0.11293794799712487, 0.02840223092789529, 0.033879557231557555, 0.018537850774009712, 0.04925995926896576, 0.03999735512479674, 0.014167254976200638, 0.05798100712127052, 0.038806200682302006, 0.026365833364252467, 0.06074952594644856, 0.022422270267270505, 0.06310453492915258, 0.03170605530613102, 0.07664878197829239, 0.011052415720769204, 0.02616922174638603, 0.02437670875224285, 0.0200725694958237, 0.07936616311781108, 0.032357345553464256, 0.05955039341642987, 0.04923841843265109, 0.026014159266196657, 0.013956624188722344, 0.03518951096339151, 0.045389206425170414, 0.07138204193324782, 0.013047804986854317, 0.06615799764404073, 0.006267809594646678, 0.03096126558375545, 0.056011243286775425, 0.024135139683494344, 0.08256199202151038, 0.020246549320290796, 0.022673867606499698, 0.005606035583696212, 0.02989896838698769, 0.03412981684959959, 0.04911291383905336, 0.030799110027146526, 0.08330567594384775, 0.037583850062219426, 0.05253986979369074, 0.040529330290155485, 0.04818637215066701, 0.04416767958900891, 0.04615083918906748, 0.06261626112973318, 0.03649845537438523, 0.015345413485192694, 0.07079303642967716, 0.049229315991397016, 0.04167915081779938, 0.05910432926611975, 0.028250137038412504, 0.02322108091902919, 0.08020310531719588, 0.03818958728516009, 0.039009756947052665, 0.04418902004545089, 0.03143946101772599, 0.02035962294030469, 0.05401574177085422, 0.06567934949998744, 0.06069473318348173, 0.05912548418564256, 0.01694059683359228, 0.02161940748919733, 0.05287646345095709, 0.012251507432665676, 0.024149082782969344, 0.04381108134111855, 0.025081947569560725, 0.03622074371378403, 0.06598742242204025, 0.054831640372867696, 0.01775235425157007, 0.02810253314237343, 0.033232690184377134, 0.04493804372032173, 0.03207529603969306, 0.022986421245150268, 0.03258666176407132, 0.03409403419937007, 0.02591595271951519, 0.00558322242795839, 0.01836413812270621, 0.03914134715159889, 0.032975220601656474, 0.11138466259581037, 0.06663602238404565, 0.10758586096926592, 0.15220102592138574, 0.1081480378343258, 0.17666620609816164, 0.06534504165756516, 0.19854644138831645, 0.21276235434925184, 0.13673074980033562, 0.07751100914902054, 0.10667324197129346, 0.06238200221559964, 0.23194960289401934, 0.10967882131808437, 0.10208122548647225, 0.17160924151539803, 0.12397548736771569, 0.09893581067444757, 0.1359000342199579, 0.11695793189574033, 0.08712044858839363, 0.16202231141505763, 0.09036403469508514, 0.1322777449968271, 0.12497545714722946, 0.1658414033590816, 0.11667863946058787, 0.14170661248499528, 0.1891936588799581, 0.1477735658409074, 0.15547615330433473, 0.1357913392712362, 0.17615090328035876, 0.16558669827645645, 0.3259711491409689, 0.12847181875258684, 0.1277255150489509, 0.1787274470552802, 0.24161407258361578, 0.13802374916849658, 0.15434005879797041, 0.1154690797557123, 0.14125286339549348, 0.08210986081394367, 0.09667553313192911, 0.16190726368222386, 0.10337009109207429, 0.1290864506154321, 0.121368411637377, 0.1294585783034563, 0.1318352171801962, 0.16333948995452374, 0.17948293854715303, 0.12235751637490466, 0.36833854916039854, 0.07538377642049454, 0.11484394650324248, 0.16121571563417092, 0.24725495895836502, 0.17788500554161146, 0.09316760144429281, 0.15228359727188945, 0.13499743421562016, 0.10990583687089384, 0.19485873926896602, 0.15999938012100756, 0.14415369601920247, 0.22807830828242004, 0.12963293847860768, 0.17350118374451995, 0.21543736627791077, 0.13301775528816506, 0.13219538144767284, 0.18694670288823545, 0.2725812530843541, 0.13547223061323166, 0.12951416516443714, 0.12196532843518071, 0.10052596597233787, 0.2222559816436842, 0.15343134349677712, 0.12616615887964144, 0.16983305948087946, 0.26110177219379693, 0.21220571390585974, 0.13665937003679574, 0.11029211731511168, 0.24042446922976524, 0.11805715650552884, 0.13786035793600604, 0.12377378647215664, 0.17232390004210174, 0.15221175737679005, 0.27627892966847867, 0.12664042093092576, 0.14279198861913756, 0.1443716647918336, 0.1031081797555089, 0.2421466971281916, 0.10688010821468197, 0.12471334543079138, 0.18939469184260815, 0.10482541300007142, 0.21472582477144897, 0.0979910121532157, 0.10173860559007153, 0.1277535385452211, 0.17986953811487183, 0.11570754664717242, 0.14101709792157635, 0.114740075514419, 0.21646553766913712, 0.10817434696946293, 0.19447340135229751, 0.13209073862526566, 0.08720030367840081, 0.10860010967007838, 0.0927365398092661, 0.15361885452875867, 0.10544487624429166, 0.19158579380018637, 0.08488387524266727, 0.1187180019041989, 0.23189639090560377, 0.14043635252164677, 0.24067445425316691, 0.2517638326389715, 0.14395364269148558, 0.2588388748699799, 0.0821198575431481, 0.15519118343945593, 0.2417048966162838, 0.1442921659327112, 0.1283695359597914, 0.14655107050202787, 0.13753906736383215, 0.2555400878190994, 0.18317853711778298, 0.24133242754032835, 0.14294209540821612, 0.130825599480886, 0.1441807101946324, 0.10442357714055106, 0.18593851011246443, 0.18377704953309149, 0.1049786368093919, 0.12586998258484527, 0.12218541232869029, 0.17874696553917602, 0.14565684192348272, 0.17725192388752475, 0.15067959349835292, 0.15069979475811124, 0.12392038290272467, 0.11707533223670907, 0.12818647781386971, 0.12596675864188, 0.11771982070058584, 0.1497098885010928, 0.09556867182254791, 0.16418780927779153, 0.20572735840687528, 0.13045890431385487, 0.08555685475585051, 0.17042674793628976, 0.130097062792629, 0.1329347089631483, 0.12163741790573113, 0.1081469542987179, 0.13979377137729898, 0.10500758056878112, 0.20928644633386284, 0.1257061757496558, 0.11786087328800932, 0.17938795848749578], [0.1091041170002427, 0.045209807067294605, 0.10420180115033872, 0.08605558541603386, 0.04917627098620869, 0.025448095402680337, 0.023164265803643502, 0.03481696025119163, 0.023971529517439194, 0.047438547044293955, 0.006599692469535512, 0.05446858915092889, 0.03289402593509294, 0.12299168156459928, 0.04495168068388011, 0.06290402889135294, 0.027800647876574658, 0.08398756122915074, 0.015367152846010868, 0.06472966764704324, 0.025347909177071415, 0.05608285682683345, 0.05076302353700157, 0.04111618356546387, 0.1107622604467906, 0.028767920484824572, 0.06413384922780097, 0.035479471771395765, 0.019781862829404417, 0.03212974370399024, 0.02846756404323969, 0.03506907894916367, 0.06972956849494949, 0.041596564624342136, 0.06167041618027724, 0.04517819899774622, 0.03514677067869343, 0.027491567489050794, 0.00614992361079203, 0.03209635448001791, 0.015487971704715164, 0.1524383350624703, 0.032225855538854375, 0.14432385563850403, 0.06656177050899714, 0.05130701778398361, 0.046443657265626825, 0.02430264798022108, 0.07764003894408233, 0.08718675948330201, 0.06372692223521881, 0.04756785143399611, 0.06703244798700325, 0.05468884002766572, 0.0218553176819114, 0.012255796118552098, 0.016177568832063116, 0.0493719604855869, 0.011866284548887052, 0.059035090598626994, 0.07627123661222868, 0.0377719548123423, 0.03355662651301827, 0.014565026649506763, 0.05168135707208421, 0.012464359097066335, 0.03647739693406038, 0.03944311181840021, 0.02724000169109786, 0.03963832263252698, 0.03143035115499515, 0.013930250115663512, 0.03533283823344391, 0.04848271171795204, 0.035444609384285286, 0.03431606251979247, 0.025390391565451864, 0.011269344558968442, 0.04181205833447166, 0.05788411232060753, 0.03543355138390325, 0.011047417356166989, 0.024232446376117878, 0.07448987438692711, 0.02817446209519403, 0.03277779076597653, 0.029019482572039124, 0.030216475861379877, 0.04092941097042058, 0.02926058408775134, 0.06501178024336696, 0.10837075635208748, 0.015855033307161648, 0.03563552316336427, 0.027059871317760553, 0.09102808617171831, 0.10543312804657035, 0.02614610941236606, 0.06776943773729727, 0.07648909406270832, 0.015430337443831377, 0.05295243339787703, 0.022601443270104937, 0.04711816931376234, 0.023311917939281557, 0.050905371172120795, 0.031585990655003116, 0.011048768064938486, 0.01983115256734891, 0.06093121111916844, 0.007816801207809476, 0.010698667319957167, 0.031064245995366946, 0.046161514983396046, 0.024143804257619195, 0.011563569933059625, 0.015143423152039759, 0.034467126679373905, 0.011325678206048906, 0.024242895815405063, 0.02149487510905601, 0.017879860788525548, 0.03341629751957953, 0.029092571130604483, 0.040947070374386385, 0.03009314947121311, 0.06910284704645164, 0.059006655210396275, 0.04033648321637884, 0.01623912812647177, 0.01481331864852109, 0.034377430711174384, 0.049753528292058036, 0.048231476175715216, 0.02865467617084505, 0.03568434534827247, 0.02576109804067528, 0.04355627977929544, 0.08739996366784908, 0.049796216626418754, 0.09382643562275916, 0.05967240249447059, 0.026032163768832106, 0.08334631595062092, 0.016085279057733715, 0.0725452767801471, 0.01407964537065709, 0.033668564647086896, 0.04822015842364635, 0.07190182732301764, 0.028998657908232417, 0.02571199569501914, 0.02771940125967376, 0.0619273105985485, 0.044812631895183586, 0.052807477113674395, 0.027299030261929147, 0.0288737711525755, 0.0500263566209469, 0.014996346180851106, 0.027996905118925497, 0.043937376321991906, 0.03181031221174635, 0.023661491759412456, 0.009316953473899048, 0.043683806725312024, 0.04640321392798796, 0.055915109187480994, 0.011844355012726737, 0.039829206725698896, 0.0375555927894311, 0.012550764568004524, 0.051885332650272176, 0.01155710211605765, 0.042659735699999146, 0.07768575524096377, 0.044814620850957, 0.01570708987856051, 0.04700060198956635, 0.045157352069509216, 0.03742702683666721, 0.006922761876921868, 0.11389232764486223, 0.032364848666475154, 0.022846611755085178, 0.005615478021354647, 0.031822665259824134, 0.016908274446905125, 0.04474370121897664, 0.08098175923805684, 0.05570209053985309, 0.10083181987283751, 0.03292578614491504, 0.015143024247663561, 0.0683097583532799, 0.07081371266394854, 0.03074577372899512, 0.08560899063013494, 0.07556151336757466, 0.019258991960668936, 0.11192061938345432, 0.03712072764756158, 0.014922613809176255, 0.04218682806822471, 0.002828241767929285, 0.04981617668818217, 0.03161501605063677, 0.001669627833962295, 0.016610682505415753, 0.024193600511352997, 0.013872845920559485, 0.034310529808863066, 0.05931288389547262, 0.03302739358332474, 0.05461674780235626, 0.00763408584134595, 0.05505429951881524, 0.04018990533950273, 0.015417414797411766, 0.06127535612904467, 0.035987134178867564, 0.08697741446667351, 0.05550604852032848, 0.03129316886770539, 0.014954793332435656, 0.05637778260279447, 0.011446475728007499, 0.07239615704747848, 0.0259530211405945, 0.05792002113594208, 0.07553314848337322, 0.026917941140709445, 0.06420492471079342, 0.02723679004702717, 0.022784043139836285, 0.03449517986155115, 0.04459114534256514, 0.025453655944147613, 0.033918323315447196, 0.04461391443328466, 0.037597861810354516, 0.054177726633497514, 0.02557282816269435, 0.020041627503815107, 0.038848373224027455, 0.04211601604765747, 0.06472839115303941, 0.06257133150938898, 0.058519004815025255, 0.06458384305005893, 0.06797752852435224, 0.050937480191350915, 0.026594587397994474, 0.010119750386365922, 0.030962317578087095, 0.019347385459695943, 0.04862269190198276, 0.025777273149287794, 0.03687604526930954, 0.05765138594142627, 0.022475126024801284, 0.04849986646149773, 0.03339840433909558, 0.07857515243813396, 0.03299438285466749, 0.055652693190495484, 0.07295012575923465, 0.01189144892123295, 0.03180230443831533, 0.015641177888028324, 0.07015978408162482, 0.05804908803838771, 0.040598687701276504, 0.08384189990465529, 0.048547504920861684, 0.04596205908455886, 0.03140387503663078, 0.003839962992060464, 0.010674098521121778, 0.04745704136439599, 0.052861813455820084, 0.023771715532348026, 0.04192540654912591, 0.0584703496133443, 0.08554888408980332, 0.046777222960372455, 0.06419035635190085, 0.06391602888470516, 0.054558745250687934, 0.05080852461105678, 0.032113828347064555, 0.02743306027696235, 0.03935501146770548, 0.07867147578508593, 0.04545539115497377, 0.06444051206926815, 0.017879981387523003, 0.03782968648010865, 0.017010798437695485, 0.032867011759663, 0.02706142982788151, 0.03194868564605713, 0.034056548320222646, 0.012725316773867235, 0.040601066284580156, 0.017588577102287672, 0.025371366609761026, 0.04258133893017657, 0.01821178633690579, 0.045669285536860116, 0.03894621797371656, 0.06273224396863952, 0.04239547546603717, 0.06264413619646803, 0.04546799653326161, 0.027349384981789626, 0.10887317548622377, 0.07697400593315251, 0.05125369076267816, 0.05167982824787032, 0.03007881674420787, 0.01752927764755441, 0.022335539179039188, 0.07318397649214603, 0.014091599514358677, 0.055630447313888, 0.06432382419006899, 0.06235841676243581, 0.015726647325209342, 0.035863266020896845, 0.05527453184186015, 0.026714026789704803, 0.02473878033924848, 0.027293039274809416, 0.038017702172510326, 0.026146063028136268, 0.036169802697259, 0.03983384514867794, 0.020887718528683763, 0.02881546246499056, 0.037223522522253916, 0.02816153017192846, 0.013799454009131296, 0.04774842338520102, 0.029124774773663376, 0.022951070895942394, 0.00585115814828896, 0.018886522884713486, 0.0470563632552512, 0.04593703015416395, 0.06587025214685127, 0.14305715798400342, 0.13065938808722422, 0.16679706692229956, 0.18401999899651855, 0.14491111709503457, 0.09224762776284479, 0.0939118568203412, 0.2846602111821994, 0.11690379964420572, 0.0800149560382124, 0.18728921888396144, 0.09596633681212552, 0.1220613178156782, 0.11362860546796583, 0.14196971867932007, 0.1472188698244281, 0.18941772810649127, 0.15475160937057808, 0.22035326343029737, 0.16635826468700543, 0.0854442932177335, 0.18812692549545318, 0.09529465605737641, 0.18050465325359255, 0.1303677834221162, 0.18635990156326443, 0.09745936724357307, 0.11969495768425986, 0.10948362905764952, 0.15033136296551675, 0.10192605725023896, 0.09353915025712922, 0.13409704581135884, 0.1080872633610852, 0.10777598436106928, 0.08840465350658633, 0.09116038141655736, 0.09666381462011486, 0.08450040753814392, 0.17041111830621958, 0.14680458814837039, 0.10363100795075297, 0.21301268076058477, 0.10535514316870831, 0.19157829810865223, 0.22552244074176997, 0.17217382293893024, 0.17981640034122393, 0.0553967784071574, 0.1110299679567106, 0.1342818108969368, 0.14550502819474787, 0.2168175976839848, 0.20691783749498427, 0.14187939930707216, 0.09976939836633392, 0.10286261793226004, 0.17174919572426006, 0.09399168964591809, 0.13246193120721728, 0.16411292657721788, 0.15026547509478405, 0.09888438726193272, 0.11045518942410126, 0.11823823311715387, 0.11631600384134799, 0.17491751321358606, 0.10843282958376221, 0.1599140776670538, 0.1331264799227938, 0.14853909116936848, 0.1332148103392683, 0.2027121459832415, 0.16927300515817478, 0.1624511688714847, 0.1250993661233224, 0.12518938863649964, 0.15497747459448874, 0.11065420374507084, 0.11597323551541194, 0.15059347468195483, 0.1979024353204295, 0.1909908585366793, 0.11997098466963507, 0.1926509538316168, 0.11734649815480225, 0.10030473174992949, 0.12597128574270755, 0.13243732159025967, 0.10339421089156531, 0.18656191416084766, 0.24485028174240142, 0.2017158127273433, 0.1719842487364076, 0.12412903772201389, 0.10541184325120412, 0.2651513455202803, 0.1890978921437636, 0.15056917676702142, 0.21309578645741567, 0.1547873066738248, 0.14295762113761157, 0.16035718435887247, 0.16661782341543585, 0.20235392614267766, 0.12717070028884336, 0.13200862740632147, 0.1544100878527388, 0.10744828163296916, 0.23235667089466006, 0.11412776657380164, 0.1360007733455859, 0.27575838728807867, 0.1556598793831654, 0.10299515808583237, 0.10381287123891525, 0.14150175004033372, 0.16878842725418508, 0.29466210573446006, 0.1268949033692479, 0.15647405991330743, 0.13533039134927094, 0.138873255928047, 0.11290530834230594, 0.2683354262262583, 0.13273278542328626, 0.11084009689511731, 0.23479208786739036, 0.11459967601695098, 0.17194590938743204, 0.11174141298397444, 0.2265586718567647, 0.10211906759650446, 0.13549069524742663, 0.174583071784582, 0.08446521489531733, 0.11236189297051169, 0.16464265674585477, 0.14175139367580414, 0.21658411802491173, 0.1359293342102319, 0.17307091620750725, 0.21285233233356848, 0.10576615939498879, 0.1751267394865863, 0.12396252946928144, 0.13634781644213945, 0.09663225107942708, 0.17072862392524257, 0.11020513760740869, 0.12438048477633856, 0.13961614575237036, 0.18747000605799258, 0.09269794813008048, 0.14516408555209637, 0.19708720094058663, 0.17234070226550102, 0.12900977191748098, 0.12675650767050683, 0.2030241151805967, 0.16840006137499586, 0.12585076096002012, 0.18302485317690298, 0.1375703711528331, 0.1310690536047332, 0.20961009693564847, 0.10787734689074568, 0.08074457626207732, 0.16440028615761548, 0.07251628849189728, 0.19096635282039642, 0.10716528588091023, 0.09225294896168634, 0.08077927166596055, 0.13365243998123333, 0.18012802815064788, 0.24362253199797124], [0.032587181267444976, 0.02462170839862665, 0.03678624168969691, 0.01150599504398997, 0.055653405652265064, 0.029263059150252957, 0.0832035044732038, 0.04629606264643371, 0.006009617345625884, 0.04281743837054819, 0.03475262717984151, 0.05647171623422764, 0.013602347007690696, 0.029074625999783166, 0.04124368082557339, 0.025322364454041235, 0.022380368609447032, 0.023488252227252815, 0.018495494550734293, 0.021701474179280922, 0.035679792272276245, 0.037382145455922, 0.06157623021863401, 0.01449843002774287, 0.029779994692944456, 0.061776420843671076, 0.016387800715165213, 0.05144139475305565, 0.008427149023191305, 0.03532646318490151, 0.014350343735713977, 0.008703581406734884, 0.01639918340515578, 0.15267604496330023, 0.03661069036752451, 0.03993055070168339, 0.02809229707054328, 0.02126166447851574, 0.08994789022835903, 0.07548150984803215, 0.10102644067956135, 0.01466987263484043, 0.08693781346664764, 0.07997354419785552, 0.021175220972509123, 0.02611656080262037, 0.022047830789233558, 0.0534015626180917, 0.0781596833257936, 0.061592268029926345, 0.06567203934537247, 0.029334594764804933, 0.026026308223663364, 0.06335585581837222, 0.031826201593503356, 0.0099589446108439, 0.041922026066458784, 0.027533732609299477, 0.04834883198782336, 0.014829891733825207, 0.040355437668040395, 0.015120749612833606, 0.036349814326968044, 0.08876565640093759, 0.017992513239732943, 0.015019105067040073, 0.09279967431211844, 0.0540803049079841, 0.08342769244336523, 0.06764333200408146, 0.043830180511577055, 0.04644739397917874, 0.11961784854065627, 0.049856935438583605, 0.014935098588466644, 0.08568684192141518, 0.062754315440543, 0.003667417367978487, 0.058840165511355735, 0.0453728754655458, 0.025508383769192733, 0.016207713015319314, 0.043394721651566215, 0.048869125748751685, 0.034725802252069116, 0.05261767655611038, 0.05338764363841619, 0.034925837026094086, 0.01792568655218929, 0.07321694269194268, 0.04763435528730042, 0.0378494832693832, 0.09288007116992958, 0.02039518851233879, 0.042958928825100884, 0.10917522959061898, 0.0596316994051449, 0.032496854473720305, 0.05069533966889139, 0.054205716733122244, 0.07546562046627514, 0.023326950140472036, 0.02102586189721478, 0.059745051330537535, 0.032457446432090364, 0.03181614178174641, 0.03863154735881835, 0.10625954659190029, 0.011370746051397873, 0.040351845673285425, 0.0856230765930377, 0.05719116161344573, 0.03267209409386851, 0.05323475008481182, 0.09385681172716431, 0.037765772722195834, 0.021506261509784963, 0.05687964512617327, 0.02811411064612912, 0.03754039731575176, 0.009092095715459436, 0.04969117304426618, 0.03489414360956289, 0.062266101012937725, 0.054626143391942605, 0.019070033740717918, 0.055731245811330155, 0.03563967547961511, 0.017784773117455188, 0.024169877760868985, 0.002692796801966324, 0.025345181784359738, 0.04359601065516472, 0.043335553928045556, 0.0378401656053029, 0.014975114263506839, 0.04739376585348509, 0.06048244184057694, 0.07609157750266604, 0.07768051567836665, 0.035777796583715826, 0.01889115388621576, 0.0592388361110352, 0.027188368621864356, 0.024580816061643418, 0.017862197673821356, 0.03325779704027809, 0.037746940724900924, 0.009202003147947835, 0.024910006795835216, 0.01833312006056076, 0.07521580613683909, 0.06189342413563281, 0.02574331247160444, 0.10038053471362218, 0.06004483446304221, 0.043000233054044656, 0.015638645309081767, 0.006665385990345385, 0.04843704737140797, 0.004834693672819412, 0.02427313091175165, 0.04582916270010173, 0.04122705300687812, 0.030175618776411284, 0.009017580377985723, 0.0666241702856496, 0.026250236442137975, 0.03235790216422174, 0.008176200135494582, 0.02709333104576217, 0.021991757821524516, 0.04651772731449455, 0.0077622412936761975, 0.017717788723530248, 0.0728840523515828, 0.023529163117927965, 0.02055282995570451, 0.04282858542865142, 0.019986289262305945, 0.13642691454151645, 0.026392389263492078, 0.05714321887353435, 0.004320500829635421, 0.06287208685535006, 0.013007645520701772, 0.0686731658061035, 0.021614893375954125, 0.036434437715797685, 0.03253765775298234, 0.0327200999163324, 0.025748834050318692, 0.09345896862214431, 0.06309800402959809, 0.04167406710621435, 0.022781796287745237, 0.04884344743913971, 0.05655351204040926, 0.10447051798109896, 0.030758074826735537, 0.03730046468263026, 0.030781176028540358, 0.12166209431597963, 0.033110588337876834, 0.01541015009934199, 0.03506270390062127, 0.06027435476426035, 0.03070375332754338, 0.009886508214549394, 0.10528336264542304, 0.028609182518266607, 0.015173368810792454, 0.012814308629458537, 0.08311427605804056, 0.057893908669939265, 0.016631100843369495, 0.025437996628170367, 0.07676821580389515, 0.023963004096003715, 0.018128732590412255, 0.043114312284160405, 0.026414434760226868, 0.03480385392322205, 0.0025674631342553766, 0.11926922466955148, 0.03744996662135236, 0.022476985104731284, 0.03172400043695234, 0.01828509568440495, 0.04769449893501587, 0.09229936287738383, 0.032044033068814315, 0.013031251382926712, 0.06454620131989941, 0.04283305686840322, 0.020268969601602294, 0.017835103717516176, 0.03989907250797842, 0.038928176363697276, 0.009970790215447778, 0.023528302226623055, 0.05022699624532834, 0.04478729497350287, 0.02789168713206891, 0.0310220066603506, 0.02019413328525843, 0.04956228796800133, 0.0376635530119529, 0.07171781922806986, 0.04207989200949669, 0.018646978023753036, 0.08717964228708297, 0.012673679993895348, 0.039362841125694104, 0.043639545037876815, 0.05696485852240585, 0.020596492358890828, 0.006313180329016177, 0.023065821769705508, 0.07066232938086614, 0.021106915555719752, 0.11516530386870727, 0.08083249107585289, 0.06676623961539008, 0.011062554385716794, 0.032792028869153, 0.03453001998423133, 0.035278141949675046, 0.04072625175467692, 0.019029035647690762, 0.022130956895125564, 0.01380819743644679, 0.024377293193538208, 0.0317953616468003, 0.03914174791134428, 0.05727403724449687, 0.06080999242840335, 0.034193752871942706, 0.05510577488166746, 0.08426061962381937, 0.018333687803533394, 0.040611096410430036, 0.029371742966759484, 0.026201419823337346, 0.06991149857640266, 0.0577246359171113, 0.017941761470865458, 0.002559420108809718, 0.07097062494722195, 0.03200225757609587, 0.023617133592779282, 0.02054834181762999, 0.019526191099430434, 0.0422461887501413, 0.018305792327737436, 0.04687444801675156, 0.020842486483161338, 0.04868949261435773, 0.04910518437100109, 0.02085869127768092, 0.016102916197269224, 0.06263129704166204, 0.026914150621450972, 0.04273171660315711, 0.039406564756063744, 0.05244314197625499, 0.019078728000749834, 0.05123704810102936, 0.025926090456778184, 0.014261152427934576, 0.037539655168075114, 0.022821404709247872, 0.04971730406396091, 0.053837069717701524, 0.02858159874449484, 0.03900147457898129, 0.03737024511792697, 0.06838317902293056, 0.02351449085836066, 0.012607986009243177, 0.031115266792767216, 0.05607486018561758, 0.03814156661974266, 0.009673480290075531, 0.07554435491329059, 0.03275065784691833, 0.02156290407583583, 0.055364123909384944, 0.06157223746413365, 0.015904096690064762, 0.08811251449515112, 0.038084261686890386, 0.02842136349499924, 0.05350557461497374, 0.029933840050944127, 0.06640339619480073, 0.03942802766687237, 0.03906202269718051, 0.04378142883069813, 0.06428671680623665, 0.02906428973801667, 0.03041535474039847, 0.03568167732737493, 0.03699542343383655, 0.012645112874452025, 0.04113149036129471, 0.025208934603142552, 0.052385076342034154, 0.00870177613251144, 0.02568788517237408, 0.04169688814727124, 0.05753807112341747, 0.22963889641687274, 0.11867154345964082, 0.10476850511622615, 0.144723606063053, 0.3244146873475984, 0.2148849709192291, 0.22952243860345334, 0.1163167088816408, 0.06487856473540887, 0.0697219317953568, 0.2763542428147048, 0.12736572185531259, 0.10058047671918757, 0.10351137374527752, 0.11881952770636417, 0.12390479038003832, 0.1404287974582985, 0.16378097876440734, 0.23256997897988185, 0.11785329596023075, 0.17555203463416547, 0.10863375122426078, 0.20726930379169062, 0.12285805787541904, 0.11982797281234525, 0.20852298417594284, 0.2347314840881154, 0.25540100934449583, 0.10173143644351512, 0.13358877855353057, 0.13108368875691667, 0.09446458614547737, 0.09420798858627677, 0.20489892864134163, 0.1841548175434582, 0.19642814411781728, 0.1428307287278585, 0.16307736339513212, 0.18960123154101893, 0.11169659468578175, 0.19731420907191932, 0.19494686188409105, 0.17886199842905626, 0.13107720238622278, 0.16155039455043152, 0.054903706623008475, 0.1192334976803977, 0.11311708018183708, 0.17957929900148883, 0.09098369831917807, 0.12075000224285759, 0.1122462515195366, 0.1853531930828467, 0.1610462536336854, 0.10103579916176386, 0.07294096023542807, 0.13346049090614542, 0.09588260771124624, 0.10903082991717383, 0.10584104209556244, 0.10823568547493778, 0.1403865247266367, 0.15022599283838645, 0.14151677110930905, 0.08751343804760836, 0.11633711794274859, 0.216965745203197, 0.10089656483614817, 0.19507443706970662, 0.14561586052877828, 0.08897034815163352, 0.11755841100239195, 0.16777769633335993, 0.17959155928110704, 0.10530188665143214, 0.2578860166249797, 0.12360197186353616, 0.1208676103851758, 0.14576078712707385, 0.152309988043271, 0.1722297808737494, 0.17486568161984906, 0.08635910897282884, 0.15396784205222502, 0.09718834233353846, 0.14452463627094403, 0.2069538168143481, 0.21230965910945088, 0.11163087750901468, 0.1279935787897557, 0.12791028013452888, 0.10551255269092508, 0.19741937139770016, 0.10585693147731945, 0.14018194429809228, 0.22057394846342504, 0.1064687134930864, 0.14555651840055361, 0.12720881699351594, 0.1639732692274265, 0.1744000581675209, 0.1552490858011879, 0.09410464452230372, 0.1413562148809433, 0.1511662791017443, 0.17503147741081193, 0.1974713068921119, 0.15753685991512612, 0.14395969861652702, 0.20098714245250449, 0.1661978123593144, 0.1378448767354712, 0.1328628245391883, 0.12130706571042538, 0.15094324888195843, 0.08032086931052618, 0.11333547197864391, 0.15589981572702527, 0.1789411113713868, 0.12326790892984718, 0.20231822883943096, 0.13499685534043238, 0.1262727758148685, 0.21839374123374, 0.10761933182948269, 0.148003913636785, 0.07867296008043922, 0.14483350329101086, 0.09801263833651319, 0.08954632154200226, 0.10728233741247095, 0.10727341679739766, 0.17672600835794583, 0.08437108088401146, 0.2436984537052922, 0.12441716171451844, 0.14763772313017398, 0.1901035467744805, 0.1636189827695489, 0.14937230036593974, 0.13258910563308746, 0.12576897628605366, 0.12527316226623952, 0.12313130922848359, 0.11046836254536174, 0.1563056220766157, 0.09766491988557391, 0.10001452232245356, 0.09204964502714574, 0.07538442951044999, 0.07056049929815345, 0.11645195045275614, 0.178090535919182, 0.16312002204358578, 0.20815968804527074, 0.18960880144732073, 0.1667773406370543, 0.1650616287952289, 0.1546244349447079, 0.18679226195672527, 0.13189697870984674, 0.07552920025773346, 0.12527641287306324, 0.12201456993352622, 0.14484085055300966, 0.062427302909782156, 0.15944845421472564, 0.11839608050649986, 0.07555809948826209, 0.12743687897454947, 0.21889669471420348, 0.09309075205237605, 0.1012760101002641, 0.18173501535784453, 0.09874081137240864, 0.11143467592773959], [0.07357388603850268, 0.008351549222425092, 0.08643660403322428, 0.09707054865430109, 0.029569178368547, 0.011562106974452036, 0.028436204593162984, 0.03628815298725385, 0.006817673302066396, 0.039983877722988836, 0.03685919851704966, 0.00440451148278953, 0.016076397405413445, 0.08428537024883553, 0.06418910954380408, 0.03166123329719994, 0.035420875501586124, 0.052500914462143555, 0.0375061509112129, 0.053887057074462064, 0.03565444792911876, 0.056004920188570395, 0.031949646727298386, 0.026367015234427527, 0.0357372790313093, 0.032964240526780486, 0.05226226945524104, 0.09270058275433257, 0.01723218294500839, 0.03208397545677144, 0.08399098252994008, 0.008386233494093176, 0.04724519902083557, 0.051952018329757266, 0.030382286495296285, 0.06267138043767773, 0.09981930779758841, 0.05170853452000301, 0.030626733241660986, 0.04367849665868562, 0.010312475005775923, 0.002750191024460946, 0.005027432671340648, 0.05347962542145979, 0.02219216181401862, 0.06826174882007763, 0.010896432049776195, 0.013584502994490322, 0.03938648966141045, 0.03859934557112865, 0.017992810098803602, 0.04114805138669908, 0.006666326662525535, 0.04164145342656411, 0.014683980862173485, 0.024751753080636263, 0.022000778626534157, 0.08324684589751996, 0.08150973051670007, 0.026340884214732796, 0.09441662114113569, 0.026807305475813337, 0.07642984841368161, 0.054226545107667334, 0.011349162541591795, 0.028234635428816546, 0.09075295718503185, 0.04511285289481748, 0.03823852450295817, 0.018653429142432287, 0.03658432557131164, 0.022977866137807723, 0.043918358787777834, 0.04116806710953824, 0.04466974991373718, 0.0711003078322392, 0.07853189265006222, 0.06920631727552973, 0.06813510131905787, 0.03880110954924021, 0.06058949664293323, 0.014198196968209231, 0.07849745699786581, 0.006541987240780145, 0.017779424088075757, 0.03721534776559565, 0.06197847054863814, 0.012014997955702711, 0.11958131261053495, 0.03130692828563042, 0.040450228480040096, 0.009399426489835605, 0.04306553091737442, 0.06067950431315694, 0.09251831128494814, 0.05574288639763836, 0.054575410176767036, 0.03067995079618413, 0.018094365586875938, 0.01106621131839347, 0.015715600457042456, 0.04735911497846246, 0.028371826992952265, 0.0540251076745335, 0.051697636081371456, 0.07894830428995192, 0.14568799728294834, 0.04988078806491103, 0.06053281140339095, 0.06466050690505654, 0.08024226102861576, 0.06344667985104024, 0.034833580648410134, 0.059116648917552084, 0.0846015103161335, 0.008454056514892727, 0.05543401566683315, 0.015010331026132917, 0.02801380011078436, 0.007258902360263164, 0.06412236078176647, 0.002197008989242022, 0.04742154815176036, 0.04910116935207043, 0.04325064110162202, 0.048930416014627554, 0.0461042248934973, 0.03794242613366805, 0.026906946222879924, 0.017350984089716803, 0.03919851478713099, 0.011124355805804953, 0.09250255548977293, 0.022695809202559758, 0.04113176495593507, 0.018452590993547346, 0.02364603838941548, 0.05063970085757319, 0.02288216805027332, 0.01623021122213686, 0.004959429215887212, 0.05282254271151032, 0.023128238244680688, 0.022662529445369728, 0.03659801819594577, 0.06467053332016803, 0.060150375284138136, 0.04592636178131215, 0.07895903574535623, 0.08444985243841074, 0.032075051130959764, 0.026225675064779352, 0.06281169829890132, 0.05618217102892231, 0.01040170713167754, 0.09591692461981438, 0.003878412503581785, 0.06641242071054876, 0.05676698339811992, 0.042636369180399925, 0.03377381603058893, 0.02119105469319038, 0.010418195797683438, 0.02192323903727811, 0.08756421579164453, 0.006169365560708684, 0.03939476460800506, 0.045542934894911014, 0.053579473969875835, 0.0423361778666731, 0.06373783180606551, 0.022129626595415175, 0.04303129193431232, 0.04725236816739198, 0.061014843740849756, 0.030658220712211914, 0.05070715837064199, 0.030902611797500867, 0.01541267525681178, 0.054008817533031106, 0.048684972935006954, 0.02188016107538715, 0.012270276347408071, 0.07425202347803861, 0.016037920759117696, 0.010144045518245548, 0.023116989141271915, 0.07670600156416185, 0.02135434388037538, 0.08246315279393457, 0.02845653387339553, 0.05129285389557481, 0.03019331157702254, 0.04328827912104316, 0.022675203472317662, 0.03311207263323013, 0.06839251524070278, 0.06743980542523786, 0.045093260196154006, 0.019280080086900853, 0.07457352927303873, 0.06605658316402696, 0.03223690982849803, 0.09385039214976132, 0.0890686827187892, 0.01456666957892594, 0.029518565752368886, 0.05579381628194824, 0.012944421032443643, 0.034396032642689534, 0.01819515851821052, 0.06895722282934003, 0.03510076865495648, 0.04337039776146412, 0.021949080619378947, 0.034150441133533604, 0.05228233341767918, 0.061117861259845085, 0.07729862874839455, 0.08107742949505337, 0.052940573878004216, 0.01885820438474184, 0.015132916196307633, 0.10557015077210963, 0.0566206949588377, 0.06700578262098134, 0.047838557220529765, 0.028925730766786728, 0.018838977193809114, 0.0648553206701763, 0.029423303676594514, 0.05274778988678008, 0.01691343237325782, 0.06362512925988995, 0.038744598714401945, 0.12364303489448503, 0.04375172808067873, 0.03389261903066654, 0.026153015096497256, 0.053346023996709846, 0.018137950064556208, 0.039678999746683985, 0.05972225255391095, 0.025955754099413753, 0.03374489453563001, 0.035894618049496785, 0.023883410613052547, 0.03144707174215, 0.015447608147951541, 0.021639597616740502, 0.02772469091723906, 0.03344558637763839, 0.09122635834501125, 0.025641068641562015, 0.06461132477852516, 0.03002547673531808, 0.05262700164166745, 0.04801932584086899, 0.10795182883157395, 0.005669510546795209, 0.012519583233370213, 0.038464645767817274, 0.025071329291677102, 0.04242059716489166, 0.01867015344032552, 0.033623924464336596, 0.028397453352226876, 0.0472669253940694, 0.03739477680937853, 0.06906739465193823, 0.03507615903799888, 0.020356602399260737, 0.0756704606465064, 0.06572473183041438, 0.01314363758865511, 0.04932282288791612, 0.02006900162086822, 0.046277854053187184, 0.06087214729632251, 0.014273539800342405, 0.059797517460538074, 0.06466245875344612, 0.039432398916687816, 0.0721575714123901, 0.02372606973949587, 0.07220015584607609, 0.012339919485384598, 0.022941706847632304, 0.030781612040300388, 0.017649806140980218, 0.11891636313521303, 0.03511046110361349, 0.025388283866050187, 0.014932438916730462, 0.0335594540956663, 0.026136543128814083, 0.08190983717213385, 0.042180519812973216, 0.05014137837861199, 0.003559982214937918, 0.023314257559832186, 0.03416139152250253, 0.00782715138484491, 0.022240941325435415, 0.0271138625612366, 0.07062007149215788, 0.0418760759930592, 0.017981052624236327, 0.06075308825529646, 0.03946550241380464, 0.013039667337579885, 0.05104908806970343, 0.01987246607313864, 0.093272021622397, 0.04606363312632311, 0.028850412054453045, 0.007530431930717896, 0.02347338515392039, 0.04078774611116387, 0.03309718144009821, 0.012489552227634704, 0.03548738306562882, 0.014795224160479847, 0.04834701743675396, 0.06347338232444599, 0.023099888203432783, 0.01603947555850027, 0.07140555317164399, 0.07439779612468556, 0.016800423691165633, 0.05211105315538589, 0.06207648228155449, 0.056783076870488, 0.049616668839007616, 0.061206384634715505, 0.015087868760019774, 0.08020753593882546, 0.049642900048638694, 0.03707429517817218, 0.0847835220338311, 0.03173927383613773, 0.0425146272755228, 0.04294888385629747, 0.03458806335402187, 0.024957220375654288, 0.03144110487482976, 0.01347007031654357, 0.028564273306983523, 0.0772583598154597, 0.0816312497772742, 0.057506040029693395, 0.03001711087563308, 0.12383527340716682, 0.15371601650258526, 0.13548235350754112, 0.2293454363825731, 0.11772045152611099, 0.1056369737489149, 0.082683622604236, 0.23507674603024498, 0.12469575653085485, 0.1394135839655064, 0.21380881225923076, 0.15246946073602885, 0.11229629453737289, 0.16908608784433454, 0.08812919797492214, 0.22116196691058576, 0.08308887976454571, 0.15517182822804898, 0.11184976654476486, 0.18183213280281052, 0.17173144355183467, 0.14184505271259695, 0.1874398154905066, 0.07126043361495249, 0.1494257349986583, 0.10021006339229643, 0.11702819843776524, 0.15366305684437975, 0.14464587351540104, 0.16893755440833047, 0.23128146218368784, 0.12728850881103426, 0.16512800648342818, 0.14507484971545637, 0.11071431028540246, 0.1649279086268507, 0.15914179879473522, 0.1650129142217338, 0.10537596783251502, 0.1864751719404012, 0.20556454604957253, 0.14466272026766092, 0.1441078312927857, 0.13853545999154449, 0.1047135861881543, 0.14450406393734738, 0.08832188177620992, 0.2901964250486344, 0.1663442380959168, 0.24133892875397578, 0.11135674300021492, 0.15982325363438576, 0.07204207096947357, 0.16823340469272807, 0.0539953178667929, 0.17286390153458342, 0.12491890549426898, 0.21994687820551917, 0.17471599043346941, 0.15066185616888106, 0.16720259125577286, 0.20595399546436965, 0.21268033218802884, 0.2065918268635869, 0.10017880413215607, 0.1615773790399544, 0.1938197176787071, 0.12203364312881604, 0.10532944259466603, 0.10029472759924829, 0.119666511163814, 0.14386574272066355, 0.15042797575006261, 0.11330266162985936, 0.09373029039124958, 0.11889816567418166, 0.17438119277358055, 0.17400174750946462, 0.19671787857078016, 0.20740956970257685, 0.1457689655944705, 0.17287234717514366, 0.38150626758579165, 0.056648377067176625, 0.07834458199795336, 0.16639747977023944, 0.21971823734929785, 0.12684060784522444, 0.21618307626340538, 0.11647264152998105, 0.1450552570167929, 0.09668090628110804, 0.19137419265462086, 0.1774297869997099, 0.10120302729774266, 0.11007574415998533, 0.24105949531076476, 0.15395249443827197, 0.10051237724837847, 0.14131409057881683, 0.08859132591169327, 0.1024498205515556, 0.17898301302921027, 0.07439208158757538, 0.2319867251208052, 0.156053158279974, 0.25601565605029464, 0.14354608487337828, 0.21072377858217806, 0.1644029578892514, 0.09909813321428373, 0.1306294498499483, 0.17560546926688403, 0.14938144362531602, 0.17962654412258416, 0.12860007671406493, 0.08818842878099531, 0.08116995304590091, 0.10732996845035814, 0.0669278200075496, 0.227323395665735, 0.09661587188020349, 0.13037182070547715, 0.299233824480325, 0.11714881969965063, 0.09478030318859965, 0.19802257418632507, 0.1575543449143879, 0.10598334149108268, 0.17492828919785097, 0.14046531112398952, 0.1101701230800245, 0.11806774695287459, 0.06276697647990659, 0.07860513520427048, 0.09273604257032275, 0.16037484747357666, 0.15122116834390908, 0.12642592540942132, 0.060731083576683886, 0.07545715998276137, 0.12270292674656957, 0.08173345835530199, 0.08978184952866286, 0.17289124225499108, 0.19515089312335476, 0.08752630688832141, 0.10064758913358673, 0.13972654764074832, 0.16957072512013838, 0.1302129714167677, 0.1307912528864108, 0.15285353700164706, 0.12015561616863124, 0.07388776997686364, 0.17187853722134605, 0.10342739973566495, 0.14581117895431817, 0.17203524912474677, 0.14782398735405877, 0.1929924011346884, 0.15878325240919366, 0.11549820163054392, 0.16824281512526795, 0.17236400570254773, 0.10735057789133862, 0.10489493739441969, 0.1467882312135771, 0.08909491763915867, 0.1120493894268293, 0.4646933334879577, 0.1045992954459507, 0.2092752102180384, 0.22440633969381452, 0.21143193589523435, 0.128136353159789], [0.021674810668628197, 0.028116415014665108, 0.03077897370530991, 0.030455824053206015, 0.05846666856086813, 0.04387787834275514, 0.010923278314294294, 0.011581486305658473, 0.03670151068945415, 0.015148126512940507, 0.04040048603201285, 0.02771765906800283, 0.04378450132207945, 0.01687087948084809, 0.0477187931392109, 0.03951460290409159, 0.04526480392087251, 0.017034023949236143, 0.01706018465483794, 0.04004735732451081, 0.05297962939948775, 0.013022161001572385, 0.0157756569024059, 0.0729022646555677, 0.02548464988649357, 0.027169486529601272, 0.023216876652440988, 0.05674144980730489, 0.06129438479547389, 0.04223628850013483, 0.03901823227351997, 0.011125358632853022, 0.023337137972703204, 0.0795094644126948, 0.01101768042644835, 0.07785219670040533, 0.04005278613476548, 0.07347086109803058, 0.017816383042372763, 0.03771194846194703, 0.06825574484537356, 0.04737621777167078, 0.009788989082153421, 0.04449338222912047, 0.0695654573792126, 0.07803683562087826, 0.03718468222359661, 0.019566884911910165, 0.05339188872312661, 0.049119745308416896, 0.010324292779841926, 0.06992948823608458, 0.004341061103332322, 0.030467353317362722, 0.025142642261926085, 0.012209599281050032, 0.010461080801178468, 0.030578957484976854, 0.043745063594542444, 0.05446801027574111, 0.03690718578582164, 0.04795334149093833, 0.055369207620969974, 0.014375721475516912, 0.06351462347083725, 0.036058491677977145, 0.09594984629075043, 0.015450507162313443, 0.014572160544048529, 0.027239873670623638, 0.009590403351467103, 0.010456467425683513, 0.018515246811148245, 0.035671094301505946, 0.08686310888151638, 0.030430245933530387, 0.026017690033768304, 0.04232001389027573, 0.013361444016481983, 0.10102235886733979, 0.030571335628337692, 0.049209667631657794, 0.04640059043595102, 0.014625303883804008, 0.05295499009662308, 0.0450688064302085, 0.028534160665003583, 0.019384899169381242, 0.012959643408976262, 0.05374505453801248, 0.09138539317063987, 0.02813710794725921, 0.06170016516989563, 0.11483324473374523, 0.019333269810886122, 0.05825869280670304, 0.028195444465382025, 0.040135231320164166, 0.07681917166337371, 0.0070847926599526545, 0.009778621279110666, 0.0672007299726829, 0.032591081253485754, 0.06014716920617502, 0.009392992069479078, 0.0182625102752354, 0.024610457439848687, 0.06609141215449199, 0.02418737389234593, 0.07389453094219789, 0.014287122030509636, 0.04604319066856988, 0.04478290145925712, 0.03715763465152122, 0.09580086756614037, 0.009623226687835995, 0.020247892607585527, 0.010664549863577122, 0.12483799655456096, 0.04104934945644345, 0.08126016109599732, 0.03543142513080966, 0.04500338611251209, 0.056183206324931234, 0.051838555082213134, 0.03214464602933731, 0.05304195496137254, 0.038232780279940926, 0.023600667191203684, 0.12480688572395593, 0.026068113402288873, 0.07063624289003201, 0.02739174677117262, 0.044014103259542026, 0.017894154552777763, 0.06305522663751617, 0.003397033719920728, 0.05935978391789831, 0.015363968104793457, 0.054265266662696376, 0.040193055756390095, 0.03483378102828283, 0.035947544311056845, 0.019507071519910824, 0.07265160427778028, 0.03548288936144672, 0.045143039751565084, 0.04783867596415803, 0.03160621788993012, 0.006279928402364021, 0.006969486103116651, 0.02023123510298319, 0.06603576592169702, 0.015915644507913385, 0.02967089898447739, 0.04150869805016555, 0.02859465683286544, 0.024581504403613508, 0.057716253359103575, 0.03836847085040063, 0.021140783464943524, 0.028044974023941904, 0.04259719491528813, 0.03543425271345768, 0.033687199975247495, 0.08611381432274356, 0.025841506030701566, 0.08789373678155243, 0.053903914958937094, 0.03968934899603482, 0.0315636631421512, 0.09193432269967161, 0.07470618074876256, 0.05336866692232434, 0.02290477201313479, 0.044449699416873045, 0.015987927836249582, 0.02710570079216268, 0.009099006038013613, 0.09234608107362874, 0.05276751617202535, 0.023565860465168953, 0.012653963913180633, 0.052635454703704454, 0.010809505220095161, 0.05631724190607201, 0.011568083118618233, 0.07487212496926077, 0.013561245941673405, 0.027701433864422143, 0.07579949786304496, 0.029013495295657776, 0.04351651921751909, 0.027533951542864088, 0.01394876391714206, 0.06353031247272156, 0.05711115067242645, 0.05501131061464548, 0.008195756654458819, 0.03578024567104876, 0.042802825482795015, 0.04065531356900465, 0.04615908816049341, 0.05111831931571942, 0.10317920328816399, 0.028510491720226128, 0.056291608125320636, 0.017048163717845455, 0.038948429573792964, 0.06308976619038731, 0.05801179511763621, 0.0436269990314031, 0.03327651400468312, 0.05939047914580442, 0.002932380393758649, 0.00819128799776081, 0.08779595882515423, 0.007203903651316068, 0.011494744085212005, 0.08305093375383876, 0.024631612359371502, 0.03422132365813013, 0.033376151041011326, 0.04118277647648938, 0.028783091838704422, 0.021053751806903165, 0.012786102379322983, 0.06960908824112266, 0.008503144017595332, 0.017219017245224677, 0.013124447505106218, 0.02813559396599885, 0.08874147722963244, 0.02815840758557897, 0.12202946483739652, 0.06360177387250587, 0.02766358247754397, 0.0005528959025014046, 0.02968259337649215, 0.0378872845612932, 0.023778970025887247, 0.07634189649252221, 0.0940504454774782, 0.06785450270399451, 0.011277215962763876, 0.042112765440833755, 0.04268269403837621, 0.035516241478035226, 0.03771132505789865, 0.0454765200993279, 0.03276866234955378, 0.06669780617812648, 0.05204714310821146, 0.04578122738166712, 0.06494538771221414, 0.0397578974661883, 0.042346445479779504, 0.057593060555518605, 0.0672424238291569, 0.06043231347575784, 0.043604085221886635, 0.01840678192820633, 0.06487063859822229, 0.014986640744609758, 0.05124623960000463, 0.060545450178324245, 0.026357304232078604, 0.0226034878869541, 0.03441023363848217, 0.043694111445802264, 0.036311051953816786, 0.04803187555808108, 0.052577077367459424, 0.034189871439593844, 0.06597925879759714, 0.03525525040458888, 0.04708396743808407, 0.04342064858064987, 0.009350662749056937, 0.03616773210524116, 0.03376038686838001, 0.00964655053394381, 0.06826457640272565, 0.024316884228028357, 0.007194852232714766, 0.08287802818813361, 0.04760806099511683, 0.027893264195881784, 0.025852500948531087, 0.03984685870818794, 0.03975615341914818, 0.022502678257296793, 0.04188645863905549, 0.047339329321403056, 0.03872609326208476, 0.06161388308100868, 0.0621970330394106, 0.020758434548042715, 0.06063212189474143, 0.0037272789995768107, 0.06984373307204805, 0.015682181547163054, 0.022821870406914968, 0.05398127643275075, 0.00880517214682186, 0.0201990314599243, 0.02630339833558537, 0.031054041464813054, 0.03249881003284827, 0.014310340120573528, 0.03487877002044115, 0.07073535671224818, 0.027666205969580915, 0.06398062541848049, 0.05624038509267848, 0.007753692216283525, 0.07374678418273106, 0.015389571271953173, 0.009027459291246487, 0.04353752941824496, 0.04278363354387693, 0.010359533662267495, 0.048043260103440844, 0.10420608334243298, 0.052493867769953795, 0.02284883077663835, 0.029930691489425953, 0.05367985686461907, 0.008426378117292188, 0.019749317798414268, 0.06501764321001247, 0.017282819680985995, 0.004922722591800266, 0.03475584810075816, 0.06300846391241066, 0.020588831539498642, 0.00786006841735798, 0.00829727781820111, 0.04437369236256927, 0.04718300704553258, 0.014719675382366404, 0.05454946840472985, 0.03312221779196989, 0.019376533309696242, 0.02333714539417997, 0.039190970855997875, 0.05999002685712185, 0.04284404436475597, 0.0471920092968503, 0.01876494239695603, 0.007978753601491917, 0.052757556550204754, 0.06979412049986422, 0.23670029797358438, 0.10457697906531394, 0.19941530335927382, 0.1917521536233835, 0.0905937739298679, 0.1256447852938436, 0.11516611280967481, 0.1441404561046511, 0.08671489456901327, 0.14483711012871936, 0.19680613477248698, 0.10214815236395225, 0.11437484237831086, 0.08673448726767674, 0.18424724461510777, 0.10913783276919276, 0.06654793687630445, 0.12280817813007161, 0.186244779615663, 0.12515778798842803, 0.26718738314229995, 0.10364058165578172, 0.12263228913070634, 0.30335114104673266, 0.12211911627673544, 0.15342513914220035, 0.11982292620814405, 0.1968128141015768, 0.09946277263225056, 0.10236749410978518, 0.07334763489780016, 0.13615288393339142, 0.12530872598290443, 0.11443416224210523, 0.17949864239199087, 0.11514793019159697, 0.1673756749369204, 0.12734667834592983, 0.18484528205590323, 0.1339061209000647, 0.2298736822558567, 0.11744493662263267, 0.21319280000170693, 0.1669348540599458, 0.14399472798686475, 0.0905387956299819, 0.1880953396903351, 0.13503705005859956, 0.12017125322017819, 0.16374827973777428, 0.2113224394270219, 0.09825512766838074, 0.17090878769522533, 0.05928144651988987, 0.14863306190818548, 0.1519989687949419, 0.13189889345085248, 0.2438486643950455, 0.1868704249500297, 0.10820190291269682, 0.12563984259031713, 0.15882499079452828, 0.17218476219568402, 0.18674371065571904, 0.1624906511278823, 0.17183531454065815, 0.18399279186269268, 0.09382086951518431, 0.060758969775633886, 0.08399230355280451, 0.1400051944074221, 0.12868604710092768, 0.12594618630828336, 0.10825102566741407, 0.1375038895639591, 0.15334437863202766, 0.16787609027232975, 0.1507529622176662, 0.18752424221020192, 0.13917176256654784, 0.143264276557602, 0.14646904834080487, 0.11440310336183757, 0.11985052668023854, 0.12477151496568695, 0.1423834660090506, 0.12316501015448011, 0.12871217069914564, 0.13159520662156865, 0.11228531817323528, 0.11935313188587315, 0.12403028013068251, 0.21974425704684108, 0.13673670182470232, 0.21201863331953064, 0.10909910008194856, 0.11396581510780379, 0.36004585039336234, 0.10675597659428604, 0.13437389658065513, 0.14891503349645063, 0.13734422391280532, 0.09919574789819308, 0.10486983053851873, 0.1557391555979848, 0.15002775035100058, 0.12857088062446564, 0.1277107759960927, 0.2113615209236741, 0.08752747948165052, 0.14403100416529924, 0.16605140146566555, 0.12780764111084864, 0.14150126022286713, 0.15354885515989736, 0.0942624473827891, 0.12560491712065414, 0.1749086519703269, 0.1309178929659538, 0.11284697553492151, 0.19762956246268004, 0.23772152286255732, 0.19194938678992912, 0.12249135528691113, 0.07734458995400928, 0.23709086060989648, 0.15087719773873687, 0.113277376658516, 0.1236908885766752, 0.14781977195525542, 0.14708796981722116, 0.12062328052707016, 0.1824319365550764, 0.13761929352767766, 0.17915799660841003, 0.11247620597714558, 0.16885830787941813, 0.12214293179567903, 0.07682476745685562, 0.13001746003283188, 0.1329874905059114, 0.14851408079266548, 0.15815643448149785, 0.2193119263392873, 0.11011714115738869, 0.13033622730290517, 0.24400414433330297, 0.17645444168010727, 0.10329451077268459, 0.09648734674556181, 0.1244980409683194, 0.1298620691522956, 0.08105357686872594, 0.20676719635957852, 0.21707055129809305, 0.06060566804080736, 0.07897563758888282, 0.15851594565901905, 0.08219827286666259, 0.10829540609847754, 0.1171276462264359, 0.18411033321172, 0.12435729266144335, 0.09344148362288252, 0.13418803311651573, 0.1753488791291602, 0.22229481081012636, 0.12335220948443748, 0.2033199797733687, 0.24517712357919663, 0.08544257885660045, 0.1699750917032361, 0.12842053634813055, 0.11436063025030307, 0.1509502250701189], [0.011962121789110824, 0.023751130211167037, 0.053112191817490384, 0.029655196995008737, 0.031087801762623712, 0.014989292067184579, 0.03270785076892935, 0.014323542000056477, 0.05600958458671812, 0.009521734282316174, 0.0900767048005946, 0.05426015326520428, 0.027388444214011542, 0.022975446736381855, 0.05878966978343669, 0.02334941309527494, 0.0361717730993405, 0.057835234474623576, 0.04081297171069309, 0.0379821866954444, 0.047247176844393834, 0.07409345620544627, 0.04611944634234533, 0.06955996548640542, 0.028821952546422835, 0.03594392263039481, 0.039082305593183264, 0.033566233614692464, 0.0250392388261389, 0.02503495848941384, 0.08418636774877086, 0.05545083273318596, 0.06338337465422228, 0.033507845146232285, 0.03136085273581557, 0.038589664254686795, 0.04017145554826129, 0.0796531219384633, 0.04716689873021096, 0.0016253126887022518, 0.01879737425042549, 0.03641375034931116, 0.026171776589762885, 0.05083679672679864, 0.014807216339249862, 0.028657364600803703, 0.01694416470854776, 0.04359667487733532, 0.02848206746421056, 0.07122688111849129, 0.014349885459523648, 0.061460755750886165, 0.0654911705350969, 0.057068080132012255, 0.003211082821508171, 0.06733882881235331, 0.05063576747488696, 0.05332144406565931, 0.03494670621876139, 0.029975606266816612, 0.03484923996438738, 0.04809633108379785, 0.047772628531674854, 0.03753352131752763, 0.03628289116022643, 0.010969938066409668, 0.06345354471704923, 0.025653165648691356, 0.022826310305390507, 0.04765210745972581, 0.007961369719851064, 0.020844586761086248, 0.04397585667902604, 0.08531775703886524, 0.02797164983348921, 0.03607168706366792, 0.03953135688789189, 0.1371465454576537, 0.10511291358852759, 0.06123326893430203, 0.06556625361554325, 0.07403869312838651, 0.02439607138512656, 0.04005805167253129, 0.04471987827855628, 0.015559672447125195, 0.006574100898433244, 0.01818722867028555, 0.10207557774265297, 0.04105244792299345, 0.044777424409403466, 0.06927756345248781, 0.034064225837937556, 0.09116770641412586, 0.07295326504390687, 0.021522930146602448, 0.04352315401774831, 0.042598052095854655, 0.00932202327021514, 0.011901592224603519, 0.061061261367285624, 0.023420649995387066, 0.027394129065214656, 0.028214070516696665, 0.04542408736597281, 0.02919557566201547, 0.056719571293797344, 0.07007255204371177, 0.059581841924227774, 0.04689927285653539, 0.06505528494017199, 0.029180604688008316, 0.03597662907850463, 0.03201003528374713, 0.04930911170959007, 0.008723019182070857, 0.055438661511288956, 0.06104343126935419, 0.033615167121752165, 0.022132370686449576, 0.025358738967042882, 0.04803522635484114, 0.05174262878426816, 0.06179151612741407, 0.04999792123271618, 0.054522725113201886, 0.07930108418804593, 0.08701038066647016, 0.04016928105556872, 0.021938315767329186, 0.053658186152460985, 0.06575050661922432, 0.017175740758830216, 0.03654136635304894, 0.02226738590252353, 0.022383307514246553, 0.060880129094584845, 0.04796551642357372, 0.005845966825290816, 0.0023546133252239088, 0.0505866706953384, 0.03346960227645468, 0.037753093129140325, 0.044133852497907355, 0.028290764057601336, 0.017508362070657313, 0.015191798192972783, 0.02556837527663447, 0.022967906515987124, 0.04277220446965657, 0.012254264511284418, 0.0492120350827463, 0.027644210567814298, 0.05443841342639644, 0.054374536775867455, 0.01920649428939214, 0.08574240651796572, 0.07254805241245776, 0.030923748163331766, 0.06797351350542158, 0.08372438082005829, 0.047435734304599464, 0.04144832433667034, 0.030745899894100148, 0.056725389731582254, 0.04146853301790543, 0.011954853380302666, 0.058064621189259924, 0.03673728591820691, 0.06037890481820796, 0.064554127457086, 0.023823714109312277, 0.03589740481402259, 0.03212792544218246, 0.03482478248770349, 0.029227042723505292, 0.01714959118544357, 0.005355300063456525, 0.03272938047302887, 0.04000433131295722, 0.06787722726585343, 0.007067675951475394, 0.017229826626135036, 0.01355707971015363, 0.04404463521495927, 0.019518240842444357, 0.07633315399289131, 0.04333928693085909, 0.027382466214476153, 0.05395199499616865, 0.061769110689056106, 0.01423116502337507, 0.015468734309251886, 0.09988861696911044, 0.03404792456422001, 0.02775746601400897, 0.022675090294796973, 0.04519985486695077, 0.052249949803808704, 0.04045481495268177, 0.03159731953928713, 0.06341614047414623, 0.07276456657564268, 0.03342140720633324, 0.015328776389651466, 0.05066262951004319, 0.07761848697555251, 0.029210719185357448, 0.07979290545335971, 0.024463104018650483, 0.02870041844289517, 0.03002660294441739, 0.04359051876235753, 0.0663131510373205, 0.03881847580487374, 0.08446951193036512, 0.058378508838359267, 0.02923735672084149, 0.04402670863782987, 0.028324925115157384, 0.04525265125266742, 0.03269700799137354, 0.03832200127362739, 0.042719834818854, 0.0141760939550295, 0.023466095408366527, 0.020621300500351936, 0.04523451687418856, 0.024078671522147488, 0.038890478972462006, 0.04422602723934688, 0.12583440402522683, 0.011088253104389878, 0.057493898493703455, 0.04631880947272293, 0.02718102878134232, 0.03652804109151475, 0.05799793179903645, 0.00923624676943291, 0.05374709173338488, 0.01747622707625851, 0.044437936376198195, 0.0358284407411702, 0.0038207246689125896, 0.08826871431665495, 0.027784819722000975, 0.039157874780357815, 0.031629654913558625, 0.09417627661605366, 0.12295683773118071, 0.02252373298688326, 0.026000635480158962, 0.025383792017237283, 0.041012308865902014, 0.05334650268196128, 0.05793374715722166, 0.028741234709741548, 0.007971990780788474, 0.04702538972196635, 0.05603060591965914, 0.022255387229961343, 0.05699926819943357, 0.07251452218042687, 0.00673139770697162, 0.08626142007415183, 0.051641266254591756, 0.016210998874157667, 0.07222672473290004, 0.04060762687004171, 0.0058757728675118415, 0.05379617366997991, 0.014955577225919114, 0.03699790591781493, 0.011323317248752574, 0.053822816771571524, 0.01951779555383837, 0.07223975684610195, 0.007060235921017011, 0.11623498357948847, 0.05034694215282798, 0.021117737924214453, 0.07522358384449035, 0.028471278492361307, 0.004089871017640689, 0.04311994889576454, 0.008311354504257906, 0.06703370221657678, 0.05922963719058316, 0.029314964958757628, 0.034886417852248996, 0.0747087188938167, 0.03447343122388702, 0.05305984443111811, 0.04370157002995256, 0.01441483544112998, 0.019652341361506842, 0.06267293152632192, 0.03520814258081373, 0.040518609966966324, 0.026446807241882198, 0.07911907247034833, 0.055967727457755245, 0.028950351515959483, 0.03393367092940025, 0.0427607123128837, 0.035085439594695345, 0.018260740253026597, 0.02019166378886439, 0.07516686891904101, 0.081382266653236, 0.03325465033412911, 0.08709424335393123, 0.027678137848852202, 0.07052906192257069, 0.02804874598950846, 0.030212021119950805, 0.08764166632317938, 0.034120569689548574, 0.05804411193821579, 0.038452229637186974, 0.029575987573480234, 0.03418390086153522, 0.030716047003807034, 0.031437483194167726, 0.033381932371412404, 0.05898194169276394, 0.014744990039616823, 0.06887769428431056, 0.057528118923073635, 0.05903245968511328, 0.016895372209546622, 0.028943241741217207, 0.027744586041080765, 0.0255802088213386, 0.03041816562472377, 0.0697512985789217, 0.08281999223981984, 0.021897670194448438, 0.04545738011074718, 0.066229778167326, 0.05867858140845783, 0.026784785004565492, 0.018164602442993782, 0.0292171480396064, 0.02871790529752616, 0.059870849072467536, 0.037828788481419906, 0.04038168743136339, 0.0515553403965896, 0.04627536043699365, 0.057806235054158606, 0.024818841375235934, 0.07527635054429993, 0.10702257088269107, 0.22656273882603273, 0.1106014741526451, 0.07887851272244006, 0.0640989608655218, 0.1178254431579262, 0.08021287198062055, 0.1814845553599298, 0.09399128146469593, 0.1625747067737393, 0.1488614355912432, 0.09248143396689557, 0.10086091206176206, 0.12595267267897725, 0.07236782184918411, 0.1004604269110132, 0.18251805537147447, 0.14633748040068895, 0.10937854836811312, 0.10931536191492341, 0.1755604802747257, 0.17401163291651756, 0.14211408124538139, 0.11462067137472332, 0.11903105463716201, 0.21901554224314168, 0.1178678272117395, 0.17149760766187683, 0.1543171561206691, 0.1561932757613249, 0.13190359866712242, 0.26755563681945205, 0.12898091721581295, 0.12611031968845055, 0.11717072047758847, 0.1255787193076685, 0.16184023290406913, 0.12830443476559594, 0.15014224889455363, 0.271272876416333, 0.09173604310490191, 0.12499323900556192, 0.1265942445024848, 0.11102655407739803, 0.15878347505349666, 0.10945485599222593, 0.2074807119788602, 0.06616821701754816, 0.11945155551075004, 0.13342129066586494, 0.1414114751969464, 0.12959501473233104, 0.11117615620605648, 0.06548777892021462, 0.2745180210331455, 0.10063975205412135, 0.20959164714440703, 0.09458957123570144, 0.1452463897294365, 0.13778330816421658, 0.17650054389378056, 0.17879214748973027, 0.24473753466736525, 0.1221119990805164, 0.13366992498049513, 0.16948613512795419, 0.10539160488406196, 0.1750762586016208, 0.1175959562533535, 0.08430455476627685, 0.1032480745925568, 0.3027348913019523, 0.23248124780366197, 0.10829725404619239, 0.13968819344881922, 0.1800278530572541, 0.31039985187817365, 0.22440859582275152, 0.2528841787716374, 0.13640252756886184, 0.15708042425103486, 0.14186555083142594, 0.19867195340339094, 0.1759173345635645, 0.07886720981332473, 0.17548504838487133, 0.11363624216755852, 0.20480565552134067, 0.10068633666378446, 0.17058709636330605, 0.19720539537956938, 0.10850915947230533, 0.13476914959028363, 0.2968016581144184, 0.16951357974903658, 0.11236815669690259, 0.1717392064165324, 0.10415981785627082, 0.11176076819538139, 0.1216174838191364, 0.1288782781921327, 0.26308381115086377, 0.1688151594134979, 0.11721006172592752, 0.1639438801794313, 0.11162599417730235, 0.17110434360802174, 0.28444412746466696, 0.24961605726275593, 0.237195429217536, 0.2640016400255263, 0.09772303004865535, 0.11049063439713791, 0.17941849044291303, 0.1212588780617807, 0.13682378543308005, 0.22978342225542292, 0.14311612903838977, 0.10356835584389046, 0.11314531147945672, 0.1384072020300664, 0.12090467324014753, 0.11292452254565433, 0.10498458883375861, 0.1393466570880264, 0.17582533793756738, 0.11907968757441267, 0.27279561501927674, 0.11924316044314764, 0.14160948019707575, 0.113398042449262, 0.13476000633090734, 0.13819518528180197, 0.12603554088855162, 0.13860219391062856, 0.1011445905896835, 0.3392577893100679, 0.10582428440102376, 0.11238628736464307, 0.15908172936178744, 0.15949752501910552, 0.11624420847510919, 0.15091993060195819, 0.1269328864873387, 0.12093671917682514, 0.09810041956370696, 0.09374205343192443, 0.16174433258129284, 0.14109769515926018, 0.14273745560785756, 0.12236343129188754, 0.10728000706876628, 0.11398608316085301, 0.13147689343895763, 0.06318030078546144, 0.1325879924115725, 0.16552811313886195, 0.0827718639629893, 0.19058126723393798, 0.13406062120338902, 0.10385912930360064, 0.12197370728245005, 0.13303549261763692, 0.14468442066572607, 0.13511644501704723, 0.16940570116275921, 0.12876202818006277, 0.15800625347765163, 0.12168999164714478, 0.1117442999384366, 0.13947231753263623, 0.13098421128233895, 0.11705029959557578, 0.14756698161363602, 0.14832167158601806], [0.034360736099188216, 0.020221969389240257, 0.03595808651880361, 0.016275819907605182, 0.028561198960233014, 0.026652101987565402, 0.04284335416741669, 0.017944050996447913, 0.05420744222647045, 0.04710942681413144, 0.04020246247819159, 0.05600707983830944, 0.05343550845282152, 0.08022839028853923, 0.11645399135886692, 0.06788046302972361, 0.02469038859999273, 0.029408761292870622, 0.03173382647219114, 0.037399400389404036, 0.017268119590880815, 0.018032657862931956, 0.008008846762095345, 0.033079663044190966, 0.016532718036614824, 0.02224073909019353, 0.017065218271454796, 0.05652969281072728, 0.01525961100924178, 0.032086046048789285, 0.0423334764491301, 0.02919942926382646, 0.013867376292182598, 0.02649620088050142, 0.05776227764727082, 0.06150527347926982, 0.04969859823177103, 0.04898142382444348, 0.053314649703679606, 0.037901244359090924, 0.05557831143960357, 0.08256581408204511, 0.00695414219990198, 0.021389850080595352, 0.023842026603233535, 0.057218342772102915, 0.011115527031506645, 0.020978600077796727, 0.001924894745570782, 0.010509308340260759, 0.01719377309200354, 0.06702594677335583, 0.02584699421277037, 0.024370131468458567, 0.02767034344287822, 0.047330171219073236, 0.09442646201932803, 0.04668432091420982, 0.032080606106319465, 0.016606212921033148, 0.04279917411622591, 0.09044688806170598, 0.04503566953644622, 0.06908133960678242, 0.019887800699507352, 0.039172528486233205, 0.04600737833243329, 0.09823941640206613, 0.028601397389138583, 0.02100512258039089, 0.00697452574968338, 0.054537976247956976, 0.08688495770911686, 0.015757830515212845, 0.009657163245719858, 0.02798296573018888, 0.021296341328707058, 0.03644914708274882, 0.009562057948642178, 0.12673002784140408, 0.11809563686256297, 0.025100046696024947, 0.0780295477306936, 0.08134550807881169, 0.014591304243367631, 0.0919904067995958, 0.02479453232808737, 0.06949425573111512, 0.04562692374747712, 0.04544328301562928, 0.01079625510101323, 0.022642959011136554, 0.11156921988003887, 0.011344397025823127, 0.0828733823436778, 0.030410515937546734, 0.0714857570710592, 0.0244351918445318, 0.01941702674230328, 0.09192059296765365, 0.015891224138613325, 0.02386689968261635, 0.012422733889252413, 0.009277695717173629, 0.016018350324884523, 0.008746519288251875, 0.018027518490271177, 0.024033903318922967, 0.04238238398102112, 0.030573669682780746, 0.026489838819543365, 0.019709542393684387, 0.023433928872691467, 0.028395950503181666, 0.00644827300675388, 0.024405587573710363, 0.021749162733613048, 0.05633892375044525, 0.02910456052632071, 0.036003498535137624, 0.016069228258857038, 0.05921444913838059, 0.019691649213200435, 0.01832465215557022, 0.049747030789148994, 0.024893592344596982, 0.052691275341203436, 0.02804170857416466, 0.04229948979627807, 0.04866071212745737, 0.15322179067879915, 0.016639995483274106, 0.06481171207269654, 0.01273324105568463, 0.03500257138512097, 0.012387954993755557, 0.020136885868851095, 0.06895030601299368, 0.011909829136129702, 0.06352375188726, 0.025425404237466864, 0.013624063176393975, 0.055085610729292966, 0.007867082640586887, 0.045364923353190534, 0.02375289837800665, 0.04732814144517761, 0.0837215903447941, 0.0652270921273157, 0.03719518361322116, 0.04635786870494485, 0.031387069102493115, 0.013579106653196504, 0.04775720299221575, 0.02919788003055146, 0.02295323611178901, 0.05277304146147799, 0.028655141868512146, 0.04154640657361597, 0.06967026347410865, 0.037315099834813736, 0.012852614581788657, 0.06378242745995522, 0.032908972789300606, 0.06023586698574945, 0.06366572473780252, 0.047511359152849764, 0.0304545883773244, 0.05257450211502146, 0.01927094053826295, 0.023569548939121887, 0.11820917061413638, 0.12390971081913449, 0.02004118407057831, 0.036861428670817986, 0.026895916053035762, 0.033285341851296835, 0.03984523340477608, 0.022177329992700834, 0.038828301840112545, 0.02519774487154791, 0.047765284980414435, 0.036109191496507265, 0.03302810604509432, 0.040280109678860754, 0.0032124172957992414, 0.03754075354663655, 0.01883999393612612, 0.039913162181619555, 0.012446301716408925, 0.018240470344608184, 0.008207449191104388, 0.029018833192822058, 0.024279543067677878, 0.0060573606333491625, 0.1608074750402011, 0.05220152095716912, 0.03411474754102528, 0.02309905699803494, 0.014530964854202466, 0.03006844337505754, 0.022467737944680266, 0.05494771969097201, 0.08789370709564537, 0.02712745870667277, 0.03953406572691165, 0.02829657321854029, 0.06479530318756588, 0.036577998762368225, 0.044972271571168676, 0.015562938824587036, 0.04694390190707054, 0.016620482565485872, 0.015178887606452918, 0.011839884500659537, 0.01094560582714621, 0.04411941772559658, 0.06962811690755188, 0.00691487794938439, 0.012038341283187037, 0.030010737682459876, 0.09610717417672276, 0.02636889101268025, 0.01571598451846512, 0.01648892204684671, 0.020927575569658075, 0.009731039408507058, 0.11125680539407767, 0.025214545239578, 0.04811012760910671, 0.021828477911185473, 0.10260944909532554, 0.0588229105778737, 0.024465605056320783, 0.04663388084736653, 0.022020248870830983, 0.033120058142230846, 0.09229583767591976, 0.048927766547421925, 0.05080568589619361, 0.024540602789784316, 0.022073507243476342, 0.056685157906031236, 0.01287125362068764, 0.03951725237129722, 0.022556801231985446, 0.011323786657158053, 0.05452288096421398, 0.05818386947794352, 0.08487925166264176, 0.036509179408312775, 0.03133268081001006, 0.04100380014278926, 0.07133401755709201, 0.047426876772078685, 0.08719593242858537, 0.051893744894186966, 0.021055837241874542, 0.08539080663467757, 0.15080210723681375, 0.035333580381120555, 0.07082227704813704, 0.059994212570018135, 0.018388833086646628, 0.0635202118428424, 0.04968615612597205, 0.007863108439778443, 0.10251597559545189, 0.008606510345998686, 0.025118739540630486, 0.010720103327912511, 0.06172194720420521, 0.024646533238410484, 0.04625705907528754, 0.049391248903702945, 0.07467540388461202, 0.009174561309919227, 0.034031289324047975, 0.03308130690129474, 0.017085781328205485, 0.04316123828175478, 0.012497819752752548, 0.017383970698574558, 0.039151299351942725, 0.041845736996037886, 0.029178116637922358, 0.014581602517864667, 0.0479883819934912, 0.07473488702089526, 0.059251523125567473, 0.058989797325921245, 0.04159870572038926, 0.06966603323235177, 0.0913967406086158, 0.07115922693628818, 0.007499169423681451, 0.04377766243123915, 0.056561631135991774, 0.02021880412939936, 0.042735727911349386, 0.04411952533700969, 0.03780820501560811, 0.04094790157978423, 0.05730339660658501, 0.058754028141265735, 0.012439870079106186, 0.05659621150698513, 0.010442428774695145, 0.01605053726962069, 0.03863201862259302, 0.06385311702615581, 0.013823867884639185, 0.024769820665824227, 0.10216528855380602, 0.05241273989668116, 0.048713515934650786, 0.01742945136356866, 0.07281270969542675, 0.06251737737329677, 0.02693150945560774, 0.05049778366810642, 0.0736015458824113, 0.05370342747482937, 0.04401900514494628, 0.0775210429856088, 0.06371052819304168, 0.04974179122655187, 0.04291146848117933, 0.005874675880477298, 0.03660169924842194, 0.04066548099217471, 0.05023607642215211, 0.06306399140157737, 0.03841527068288997, 0.017242495086975396, 0.03595129957830068, 0.08690726666827686, 0.008386105473618954, 0.03168541246850509, 0.10290303529473022, 0.06442576559493318, 0.018815085604728665, 0.05314762565831188, 0.03355049266247079, 0.028136846340203192, 0.023688461405981798, 0.05494899247423746, 0.0774690555408597, 0.017059641031664796, 0.02600148152851034, 0.041915613910532556, 0.06388958616298623, 0.12849299964727834, 0.19761657487833872, 0.07566414496977814, 0.10250662453472614, 0.1357677241321653, 0.19355379132321104, 0.15160582348471507, 0.08003819268196821, 0.0993983838998247, 0.1399730594130233, 0.14056002401048318, 0.10217665825621225, 0.16532381472643465, 0.11486544652143493, 0.19268466217909008, 0.10354007259593345, 0.10870232566958293, 0.19248306518420577, 0.0931112798571121, 0.2988523605745286, 0.11391316715162247, 0.17698602721793577, 0.11321640180540271, 0.162742001703009, 0.14990388590376824, 0.19396102259634063, 0.12743097147904336, 0.2063425988308154, 0.1319582058931701, 0.19635394419310614, 0.12473663402488455, 0.13210501754656434, 0.17433102359063923, 0.18420688662445173, 0.10859408343094401, 0.20780871156603098, 0.07734162878477946, 0.10753336144261993, 0.17484301642980427, 0.10030263889348134, 0.11821783889899962, 0.1081421303388197, 0.11787495925091207, 0.094773364107823, 0.12940978951519355, 0.1817980979103595, 0.07449808254023083, 0.08458245938527398, 0.09378363596624695, 0.1944829453714192, 0.0813875359017402, 0.18623511685291305, 0.11289046538877301, 0.09289949317462742, 0.15003732405602932, 0.23697913769865409, 0.17265463073272258, 0.14149300754070282, 0.11290502632618882, 0.17122653080150485, 0.10255119050270878, 0.20892062690109015, 0.12625615170691162, 0.15173298306763172, 0.12357365892967209, 0.10365802212618291, 0.14241527445847169, 0.19398802192881703, 0.2765638550044969, 0.08080906147370115, 0.10411668423330411, 0.18542740785051137, 0.18517789780162275, 0.1808080283808522, 0.14863882097415626, 0.10785264079459012, 0.18380240129772574, 0.11758929918869399, 0.12247837512404658, 0.23321671615121886, 0.1944358486798592, 0.13533322635339573, 0.10176050636800937, 0.2840424474561587, 0.08798112467047758, 0.19416713184909895, 0.14351280697155744, 0.199242768867407, 0.15059892204590142, 0.14133199118077755, 0.14262271957704797, 0.1303363757324405, 0.2213163929991424, 0.2001217388897203, 0.1776303449878469, 0.16405012604082003, 0.14138647966319695, 0.1516511241788976, 0.15294312906917185, 0.19096678326604888, 0.12734207703033462, 0.14697453996632248, 0.1615880214376375, 0.09093916945857927, 0.13116845686454326, 0.15014374803286046, 0.2095846857992001, 0.14758029574295506, 0.14596179040381685, 0.11649355525150895, 0.26453812373802066, 0.12502589350333437, 0.15622573730070144, 0.18189132650149986, 0.14166920824209228, 0.08701083337655291, 0.10344392736442387, 0.18269870895892382, 0.15064310951856896, 0.09161422698525712, 0.15758260589791462, 0.12170938396593556, 0.15133771521504968, 0.13229521515313536, 0.15222950954921544, 0.10828897167812102, 0.0925026519689709, 0.10994141543051228, 0.20428889809409156, 0.2080819258117117, 0.3012519021285698, 0.10990268274326809, 0.1587846624897793, 0.17386079882271588, 0.2161796178552322, 0.1456916338065639, 0.09342337521957234, 0.17267358518438414, 0.08638725863420404, 0.14085431525018066, 0.13519632979296148, 0.16722619155189022, 0.19326801993884146, 0.11636716750217602, 0.2146465633995831, 0.14856968249659985, 0.22014224115991965, 0.16131191281601787, 0.14112355158431455, 0.15699025330832228, 0.11091561784269288, 0.08339472624356858, 0.12532594380900264, 0.16169814130989835, 0.10417307261377573, 0.23966301087057218, 0.18917078588856384, 0.22428682423196733, 0.150594899605494, 0.2822791045764461, 0.13650081760715693, 0.061530528764706105, 0.10334309918107465, 0.23049938696203753, 0.12625215895241126, 0.18686948984395713, 0.1209480814577546, 0.15341607009759173, 0.14462365361396223, 0.10274400046910159, 0.15995102177839726, 0.12516595161287114, 0.24885516293579713, 0.1066953876579646, 0.12986526038730517, 0.13748362893238664], [0.025944748049369082, 0.1258037384832278, 0.04916772144497372, 0.03591254833736457, 0.028105230849178042, 0.03596572692913469, 0.027677655452862382, 0.04058482438267674, 0.008941773703554645, 0.0071852673954708735, 0.06759617594070733, 0.012064804413967067, 0.03268514476076234, 0.04029164636449423, 0.02643819090735633, 0.008560305159335257, 0.05400715512223542, 0.057939535909099504, 0.03792792827880476, 0.04003530484624207, 0.07943530901684426, 0.08323593632667325, 0.01542447169413208, 0.024921931253629737, 0.04455608628632035, 0.056321627998840995, 0.06464486985350959, 0.07474768164684065, 0.002605985700938618, 0.03220851896912791, 0.02333732907572994, 0.006269774894462898, 0.03491810755804181, 0.03077903307712404, 0.038220145215746015, 0.02369548583374126, 0.06054254467017017, 0.04395263116748538, 0.009075475318240933, 0.018112277321051806, 0.021035437457612716, 0.046506613653036766, 0.05034347632317804, 0.06510289371362887, 0.12054085760610178, 0.03180522850016132, 0.09514119476079941, 0.014373880949278828, 0.023710399291303474, 0.11905818013474345, 0.03212055962649174, 0.049104653735412285, 0.020301180666137952, 0.033640596811892465, 0.02151723972929176, 0.047640073535148986, 0.05326978316588793, 0.044383611166267656, 0.03579657663067337, 0.07973440195200965, 0.05565068939176854, 0.07295503135537729, 0.062420920439762995, 0.02987516956636682, 0.09282711151172407, 0.03742445900570601, 0.0743365021480713, 0.1576291979290545, 0.07118714653188363, 0.09127153287408873, 0.02913153944973601, 0.08973093077656813, 0.037122902140254155, 0.05981983013043646, 0.03479214654362295, 0.09790721625904553, 0.09345093116280623, 0.3045456425752491, 0.12461584206903353, 0.10943583474727347, 0.08919248779420741, 0.0815692804462742, 0.09779002371942624, 0.029167357351980172, 0.005309850475896383, 0.0541337098547956, 0.029088220289850142, 0.007766773496769019, 0.05034696441725828, 0.10419820915558375, 0.03657674453279469, 0.05541617443668656, 0.01858113468188094, 0.14955915830796584, 0.05781728934380226, 0.04847301926929504, 0.03727767332748044, 0.0536992157867644, 0.05853724680491723, 0.05543874685827177, 0.0669500399089884, 0.013831062078679679, 0.05429471508250572, 0.019590917509049177, 0.05108961675432511, 0.00545065212463669, 0.005118913040860207, 0.06061009124096017, 0.011295422700641211, 0.06570122059201822, 0.0760460615856573, 0.06528905403683893, 0.049734926360542886, 0.02647350414918037, 0.07418894092552364, 0.06776206821086816, 0.0640830492193345, 0.13335638243006542, 0.03286657760327216, 0.07296892435988411, 0.04489946317335125, 0.03448355411819648, 0.05546937900362536, 0.03648372003226541, 0.03345134544360917, 0.013926246228948003, 0.041863318474497646, 0.07284583174623549, 0.024965799602796324, 0.05030766398704145, 0.034289515897398815, 0.01990287742955843, 0.07415001527988352, 0.01899616778246127, 0.046703583357157186, 0.03487171961751301, 0.03174816847604234, 0.05179293155379128, 0.04391017289890442, 0.04517110406595748, 0.009677280086179962, 0.04186328878859058, 0.031157322446233593, 0.02343896991078509, 0.03258373028074857, 0.013951117452961626, 0.05899446172406897, 0.03691552752570715, 0.059714248491218314, 0.06250139893381856, 0.07306892875931226, 0.053134341214899905, 0.022196171266841702, 0.02012268487305846, 0.0511649558757199, 0.04889761679805815, 0.03362274816026911, 0.034991914144484326, 0.02294379042723449, 0.04846582414756995, 0.0045170841531216865, 0.05040834003011696, 0.0035052418661507545, 0.02674742714589229, 0.054327681282302365, 0.06573675462277606, 0.03148659110593144, 0.01441676780814305, 0.00896260115041514, 0.031767364125698805, 0.07617535855388269, 0.05996225569106173, 0.03265189654484857, 0.05443847650894895, 0.06386127322912216, 0.05908594997890759, 0.04800958886335138, 0.04581467597745359, 0.02189273862313712, 0.03206355155271012, 0.023857403903093655, 0.03479791303107049, 0.018753613512672018, 0.06065521381970029, 0.03847123974992428, 0.02503755229554372, 0.03336903755553067, 0.00930312262426014, 0.016470351656607818, 0.04871962381002959, 0.03240223064494785, 0.01577624134370126, 0.07183631052612327, 0.021275735598464962, 0.023450655025953893, 0.05407104290497955, 0.08876706648152322, 0.012402400898281485, 0.041694921455928124, 0.052132256314507686, 0.02683917886315612, 0.03026187860086793, 0.048150537550100125, 0.012813176854251651, 0.036130732332821935, 0.04691878020821605, 0.02479865310306195, 0.0097380239458289, 0.0188773573609069, 0.09492053941357881, 0.002922475505329203, 0.07534681004472077, 0.011269266633462394, 0.025413884250156116, 0.1127546449424699, 0.03852355745038949, 0.06103425090259407, 0.023724114180367906, 0.016625582975393627, 0.028059638862032443, 0.11161996793816797, 0.02356115339352982, 0.08837616245727986, 0.018535112249082886, 0.08086081885267049, 0.028937720162502956, 0.06135383082437329, 0.026441281952429563, 0.05790907445771154, 0.034499658722779714, 0.051067419117316604, 0.01062833584001055, 0.023118586614145897, 0.02801423797791358, 0.042065943343914114, 0.031690177056589164, 0.0085162531286187, 0.018135523241653573, 0.030253598088165745, 0.051640865494846366, 0.09787231305381283, 0.043408217607066035, 0.09692681691376492, 0.11948919724090956, 0.0032154234577319585, 0.05978134606266394, 0.04477664886508137, 0.03139850559819024, 0.10323961410904303, 0.06383852640283294, 0.027033046389988158, 0.041489083087071776, 0.025826197379501536, 0.12311871498241089, 0.06739998920238577, 0.046902779504307546, 0.07681641087401658, 0.052577422466129065, 0.079456259845756, 0.07075613684719428, 0.03931704690330662, 0.00439125904449611, 0.04694268478488084, 0.07466522161848843, 0.06218227914359886, 0.03608764323871583, 0.09369696796056814, 0.05943857773672789, 0.059126359919901006, 0.06174453075800557, 0.029792952591378707, 0.1039673863851931, 0.045101913638063706, 0.04555056046228856, 0.03224715888791252, 0.008441157988272607, 0.024528839749109466, 0.04316379869123921, 0.06881250403239392, 0.05197055346798152, 0.03131297307845671, 0.07150222532800399, 0.04457162685866933, 0.05145238967088517, 0.044666061439784244, 0.08185327067621984, 0.07368865917669609, 0.03927671488781925, 0.051344306993996724, 0.0114764863246819, 0.05565600316913333, 0.08487257233355194, 0.035097499494440854, 0.02506104312487878, 0.014812262015766464, 0.05198247235966846, 0.07132713042665273, 0.12004618649370968, 0.05525946995476261, 0.02525997580960393, 0.06676336008240469, 0.03738965970114805, 0.047647955143474974, 0.0404549411177868, 0.04742467630421743, 0.028133267333032563, 0.027804098863271065, 0.01905815937789157, 0.03080858168686973, 0.03374464220541995, 0.020129486656514928, 0.0068455330620054156, 0.016142311251314823, 0.05183900037081912, 0.06011671888700221, 0.11988989019300789, 0.01269024101929972, 0.05131918900588062, 0.025483223107585218, 0.015977522925822996, 0.03606796519306954, 0.05020102849812247, 0.0074136382954748115, 0.10681970481527969, 0.05101624061353505, 0.048833090768312104, 0.02891630178055493, 0.042955385069944896, 0.0201838044449687, 0.004169537323832628, 0.005453814137581503, 0.055371734633808956, 0.028832880670961458, 0.05402252128988039, 0.0036513579880192992, 0.02907483565650182, 0.036324499669717625, 0.09528687092824839, 0.03735006241186056, 0.051763390365522355, 0.01780367561877938, 0.028298116885707714, 0.0261275093362201, 0.06690036054351367, 0.029158741017454304, 0.024040226417127997, 0.04074115408002399, 0.03983619775681291, 0.03513571267831139, 0.04316094142268412, 0.08756049021030776, 0.023778899521857966, 0.12061879053362645, 0.22753006895072758, 0.12291185616049916, 0.170035665796604, 0.15995989786460996, 0.14434842072660103, 0.13424356060568243, 0.14191594265867025, 0.13824118359480053, 0.10223607459920458, 0.18102813453879207, 0.04508953461481724, 0.07411475584376603, 0.1089129620231688, 0.10793182795168832, 0.06271006117458455, 0.17561946617206559, 0.11151600047014654, 0.09661752686952241, 0.26169798395130783, 0.2152813074644655, 0.1671604224247858, 0.15978797193383798, 0.11411056359065697, 0.20064842625288293, 0.1862944886670448, 0.09659330316935666, 0.23083718289854005, 0.17628821544349194, 0.12093859681044705, 0.11770870332838967, 0.041523292384226806, 0.13784701412077993, 0.17367497988743708, 0.16505269333720207, 0.15662968828110024, 0.10349578864406794, 0.14358858024934307, 0.2239586613723077, 0.11263323700404726, 0.20778689242433757, 0.12773145223036408, 0.07697855529841036, 0.19995432521682233, 0.23542840528534725, 0.11009531459421851, 0.1654085679911077, 0.08827433237456717, 0.160421647306066, 0.16003242053557187, 0.214588601666037, 0.13030327594606206, 0.09112902567721903, 0.12000767645076849, 0.12047152617014945, 0.11300415499135852, 0.1853111429954879, 0.13896074029617012, 0.15437544439919293, 0.10956896119751036, 0.2086245545069687, 0.1970695229829289, 0.1508355187252164, 0.16471752460347489, 0.19085663370788097, 0.09112129991990514, 0.18271500652190298, 0.2528830507071689, 0.19617524987552315, 0.20403077913215384, 0.16475798649480566, 0.25212525855749846, 0.22558310389285907, 0.1452575664734468, 0.17057695862604305, 0.3430770296836272, 0.2052283679950051, 0.36984024045523256, 0.23681322316406295, 0.15859692881349474, 0.3307572298217565, 0.1558283023769036, 0.2902694820659235, 0.17118142306571826, 0.08535438202670775, 0.14953934296499938, 0.21764175267890096, 0.17177214293042198, 0.21352495561586693, 0.1987137511605397, 0.2448643380193971, 0.23310475575271994, 0.10396679266705178, 0.21029523282777518, 0.3340728784678504, 0.17925601947354153, 0.2842539001721889, 0.2892530959798023, 0.1103842920565512, 0.2726295223692432, 0.13333371724002063, 0.20019801682792604, 0.13285172200994566, 0.1307308569084853, 0.15888118621660396, 0.20259928016457707, 0.14438431098824367, 0.1402715512085706, 0.17462132207583636, 0.12263599244761281, 0.14034481602720916, 0.12602829752722755, 0.1795573759591207, 0.1387380069354549, 0.20373311854200438, 0.1145359329530038, 0.14473718736553565, 0.2836674253921956, 0.09856202799710445, 0.12951046926900744, 0.1425466494401917, 0.20638727612094954, 0.14707890077261254, 0.11717751855030656, 0.25586396106518805, 0.1557064417283982, 0.13082359568215907, 0.1296870707301423, 0.06877706648083404, 0.10116877718246542, 0.12071306555299088, 0.12407346570398659, 0.1951729497523047, 0.11100831950898282, 0.09426595774129964, 0.11553635544260032, 0.10969278853735887, 0.13981608033645898, 0.14627781172748655, 0.20125826384173706, 0.14824316720478237, 0.13621992955449969, 0.11601302205235697, 0.08503240125719458, 0.21812070510350168, 0.19529948593117297, 0.13545033725677058, 0.2085502803674899, 0.11347233143169433, 0.15138803282752633, 0.16441596031654626, 0.2804964064853266, 0.12200867728097364, 0.1107041428622324, 0.14604488125769421, 0.2572524599963799, 0.1003080714144744, 0.12541593663627282, 0.1758535989210941, 0.17192564875585958, 0.1253593701403588, 0.2628961962182075, 0.15118438750505447, 0.15794306702446193, 0.1989433864946477, 0.11360266740666702, 0.08534790307749063, 0.245067092764657, 0.11971302898018621, 0.1555415810435079, 0.12140723338234238, 0.19961222482379526, 0.1428991399006918, 0.22212972748093307, 0.18532036046963185, 0.1390018404345028], [0.014581281538994517, 0.030761870912101585, 0.057956668388214894, 0.03185474459314719, 0.06610255179111846, 0.031430677699972875, 0.08287384989671409, 0.07550403403001837, 0.07515309465816244, 0.09013399860123172, 0.07553789822850376, 0.011646070779534057, 0.02054677031992469, 0.03468902883469127, 0.05694648665667046, 0.024697105036466382, 0.05552927774260752, 0.04802382696652785, 0.05135928724484984, 0.03255579955293797, 0.026399293092254084, 0.007565692758362275, 0.026328308522352017, 0.017274980746151414, 0.07112549632438459, 0.05178774394153152, 0.050804739657905884, 0.010231458454654785, 0.07236805933644064, 0.03834954979538452, 0.05499689439602662, 0.030459161862381734, 0.03688801240059547, 0.026051422501041088, 0.01719287880405318, 0.05283255428366829, 0.07876077841501683, 0.055995279690250754, 0.04020212480099872, 0.05093109401059337, 0.06231270788703114, 0.07783267821650952, 0.027235185152676422, 0.1003603037679568, 0.0831980793736875, 0.024425601441180333, 0.00620405818153813, 0.04265639232471585, 0.06552052989718504, 0.031343712835223414, 0.03588971245335415, 0.025913551871781237, 0.007866919368098024, 0.0425071464269422, 0.01978409298317274, 0.05613245455606375, 0.04029905299830716, 0.024191106895159464, 0.013353969661693554, 0.03784254418860655, 0.05640199888148345, 0.02764708267932292, 0.023287840813281946, 0.053922620791126974, 0.03147643481497653, 0.06985070926020853, 0.0663044975954108, 0.015535997008555569, 0.10530786094022915, 0.09267857807572, 0.03751543517864775, 0.06850272417068481, 0.03672218692372553, 0.06553891289513558, 0.03562401245289948, 0.05273748887702823, 0.12276509645744227, 0.1660594463464804, 0.07296238603885286, 0.13469931349391118, 0.14308329642517492, 0.07016402916633524, 0.07849755347706378, 0.0400533130596159, 0.07234683391288854, 0.11545958026545122, 0.10971347961458378, 0.1428632199531421, 0.09909308661008254, 0.05914120658417232, 0.031605843105353415, 0.07921836440800689, 0.035348475284990855, 0.05914541456149891, 0.01046773786583799, 0.04913182005111594, 0.06268824203289114, 0.01736155969410902, 0.020465972702368163, 0.03914331384294201, 0.048230570755549707, 0.03709588425408583, 0.03212819261534605, 0.026991064951289445, 0.016997610473481473, 0.01244000181031879, 0.028917487361468375, 0.032222389709204435, 0.04165973994531669, 0.0051139814695488894, 0.047085689220693894, 0.03958381559641566, 0.05039777184720151, 0.0190199090866372, 0.05343777571397368, 0.027514197427080944, 0.020185780413157772, 0.05685660886229016, 0.009123687086685095, 0.04780791394296102, 0.04209827500744723, 0.03530772766680457, 0.03647132987680379, 0.07005803563515656, 0.07035452363197692, 0.07247904010000639, 0.07601783770951442, 0.06615961552597582, 0.0838021059462335, 0.07035052345599979, 0.054261351833702065, 0.04605012603860814, 0.054545297534787096, 0.034210952144348994, 0.020175420031591784, 0.013153240979590919, 0.0065634854036034085, 0.04090948430530261, 0.01615633042092668, 0.02220016402134206, 0.006992219941821531, 0.06385427477653138, 0.014111739546933677, 0.037708671879954636, 0.10021584472269751, 0.06327789320494048, 0.025435410243517254, 0.06587264186237007, 0.015896936820354313, 0.022939513801247813, 0.07347731036134064, 0.019663668390421662, 0.061432320362655446, 0.013424402259261115, 0.024538149991713, 0.019684454091475345, 0.09485174974543042, 0.053098903663340025, 0.008168867716449313, 0.10250577848637477, 0.027115022166981362, 0.028262965061003342, 0.05818509773234837, 0.012888420424133074, 0.08459494230919518, 0.04833894287003204, 0.03669754762086086, 0.028909388674946968, 0.05179030806175433, 0.06536502769449726, 0.04692399008490611, 0.06650241353781894, 0.01361132050078595, 0.05724064430978615, 0.04819382702407893, 0.00327223579006386, 0.036547830459312536, 0.03844350569124799, 0.05243770203378517, 0.02322876771359006, 0.04052008684084285, 0.041245988904847763, 0.038947316352277994, 0.020173054435872473, 0.048121846120920964, 0.06554093895829283, 0.027254121050646063, 0.035359882094780914, 0.06384525026078336, 0.042967274275724776, 0.019470491060928907, 0.018625654265633784, 0.03198868369509, 0.036337294295663014, 0.042037140592583455, 0.01835594666772522, 0.011429733804106945, 0.016349609795724973, 0.04064141685375944, 0.031404502151417546, 0.08713704301044345, 0.062382558826357126, 0.008999920046335319, 0.041868331682053395, 0.051269932664581574, 0.05304420737957116, 0.036655553194577806, 0.02962748520076275, 0.09234556899173185, 0.08867524797096848, 0.014507700379908783, 0.029577850364148617, 0.04586925351759419, 0.008845402117003687, 0.062166527059162036, 0.030855522527417634, 0.023794378867023624, 0.06032911413058173, 0.05091213584819343, 0.02794579526380403, 0.03714218684763182, 0.07911738037364557, 0.021579457679763436, 0.011139280395582318, 0.005948117423031363, 0.04030707190395333, 0.038823756185593084, 0.0617525793495588, 0.02954648905870272, 0.012180329904367682, 0.06677817335003056, 0.07688676647376269, 0.04384974352433346, 0.04888653653324582, 0.02470675295626279, 0.07395831853500567, 0.034156960900872946, 0.08395466924412176, 0.07949695180286653, 0.06639912884566002, 0.02155692236556206, 0.11858438563649543, 0.01939351364853792, 0.056013113498920575, 0.10952544907922857, 0.10123115469468758, 0.05859901946678292, 0.019662469821923878, 0.07674895707168616, 0.1397547047236003, 0.04968895773345139, 0.0774393547908403, 0.10461043508257717, 0.1559297094354406, 0.06379850237863138, 0.14751222595805302, 0.13477076747221872, 0.08283852366730571, 0.09786440175957978, 0.04348095550085418, 0.1060981146292761, 0.11604764324147254, 0.09241879670298658, 0.12293476625927724, 0.04209885017189663, 0.075206751935184, 0.09161395239061676, 0.1272278605028987, 0.017539478467369918, 0.009390567101945635, 0.07988230456248857, 0.06819268455728889, 0.04491543419135269, 0.043408918936620466, 0.04823543182283174, 0.10600649649859406, 0.051221871181041934, 0.006644265395152615, 0.03924111035303213, 0.010889455861615716, 0.035369659890420735, 0.03412613208638504, 0.046622425797977485, 0.035526854189811274, 0.058683075112639926, 0.08548074751161039, 0.059123283717781305, 0.019662072772916872, 0.029174977353250142, 0.05913436027185526, 0.010975401200994384, 0.04942309817124624, 0.026074314046127256, 0.015489688848902006, 0.036510808422463015, 0.012965042533323867, 0.0539763077540556, 0.02460615854943171, 0.03275285089330282, 0.03306586280814372, 0.015709529689047486, 0.10075123747810721, 0.04967689041222911, 0.08059559011599049, 0.08698914782144129, 0.08344662463059649, 0.03851934576232452, 0.015706167760072276, 0.008448485768894898, 0.07276966513018124, 0.045805822155671194, 0.029866501281503588, 0.07015159077127464, 0.050415505465934984, 0.035916466877097264, 0.012869842612417415, 0.0073583292760304175, 0.01018109816868673, 0.06180738324474078, 0.047158493907772936, 0.04945587512338534, 0.024818511119519826, 0.06024510301358532, 0.006376391829689965, 0.023817582114133984, 0.04089488626050297, 0.06528564757900313, 0.05287707572279032, 0.03846374405839015, 0.019300179301353637, 0.039806623171898536, 0.047097326096263714, 0.07870827888837084, 0.13459339417750016, 0.018345983335166238, 0.04439056880073622, 0.05134461127454415, 0.006795333265472436, 0.01685981962509686, 0.025799975446716417, 0.03924466152966488, 0.05035084584960714, 0.020010017578897532, 0.013034652274654945, 0.02720159183809301, 0.02015146721532801, 0.08248434111010283, 0.04445353632036131, 0.01694946549832821, 0.04026272858027369, 0.014881465431244578, 0.018910108337877318, 0.14924419083399698, 0.14090058073634282, 0.15505498449783772, 0.09734997467603534, 0.129807268967852, 0.11340662167640403, 0.1485507280449383, 0.12499476782977581, 0.16937420441536233, 0.1263589391601272, 0.1717900435323827, 0.1006031567521859, 0.08487442770274356, 0.1045648152648937, 0.15332705690525472, 0.16433681768830866, 0.16240530414506793, 0.12668184761423618, 0.15438479545991868, 0.13466064759995788, 0.08637851613457315, 0.09479453758103773, 0.1670536125311628, 0.09707877165055834, 0.14762613078346476, 0.13426518678897992, 0.1506796825560741, 0.08594104976509698, 0.1738255616510287, 0.19819969515083358, 0.11747990662115626, 0.12231296524987556, 0.10600820343825035, 0.15531668061157688, 0.08070596973993815, 0.16008554346626624, 0.15166926226811484, 0.10170452616875991, 0.13621022226288915, 0.17978839168790728, 0.10740683268522844, 0.12209615422761999, 0.07641590345883742, 0.19945634412579238, 0.16517097683390602, 0.11578006931813434, 0.09070733736734837, 0.12454035080736503, 0.23860208108089864, 0.1593234171741642, 0.1488340354990214, 0.16973663965472952, 0.07697262553847395, 0.14194314979249611, 0.13014715776080266, 0.12778111675288528, 0.14268229919252917, 0.09046289618709125, 0.18261211516801268, 0.1996615034295246, 0.15080060809850693, 0.1896994622074999, 0.1480264007113874, 0.15596917684888467, 0.16159668972250074, 0.1682457243441604, 0.11558375641470775, 0.2296825495432131, 0.21497324196388945, 0.3284236800391227, 0.29745424340944737, 0.16962825640803203, 0.18024335789959878, 0.17933274270035326, 0.0882432512298692, 0.19895103061571717, 0.2365203865338117, 0.22612165077589452, 0.28317039425019175, 0.27397776721045375, 0.24386837583733723, 0.1535178630729206, 0.18279621232068166, 0.2300669820397161, 0.3249518241500482, 0.30482658999972045, 0.2826389274559915, 0.4462972440524027, 0.25434911891352385, 0.13028126384597272, 0.16530163935385644, 0.20561903453199193, 0.127642854640726, 0.19051012495765463, 0.2824119193246588, 0.2040559973102063, 0.17218197172041982, 0.23172747809439898, 0.10694138734834269, 0.2619449113262817, 0.2410215715644881, 0.18725304660620168, 0.2097408485133201, 0.07364199293078855, 0.07468542287824675, 0.17334525851765648, 0.11925187325687148, 0.09770302174729295, 0.16135332465637475, 0.16347083525033668, 0.17523669608635828, 0.17942462058272213, 0.0876410651835613, 0.15993962239008397, 0.11221743392525241, 0.12588758632773533, 0.07322773351916112, 0.1132888205756899, 0.14927138312486932, 0.10088690207339823, 0.11488879448734224, 0.0900408739107661, 0.13651757530169562, 0.15146420686505735, 0.14164593449095264, 0.20666292461100966, 0.1776477409293875, 0.30351189023349434, 0.21435598289826885, 0.20832018490182236, 0.10960810206597671, 0.11814229568699375, 0.13474293693434447, 0.1678777823690325, 0.10190639033680782, 0.14354458573507145, 0.165049962233752, 0.13877478777430952, 0.09224775392794982, 0.1077638947754167, 0.11974262582953088, 0.16946370742516592, 0.13796590617857873, 0.1179880922427401, 0.20294608577387407, 0.15512342535657808, 0.08249909500591457, 0.19247509451815858, 0.10420853985124268, 0.13593782437965274, 0.1700630658888258, 0.18959746143082157, 0.122883958829334, 0.1854253446799703, 0.19494347769068554, 0.08847808901919052, 0.19195817381842062, 0.34300845523830503, 0.08662719497806393, 0.16502983518876135, 0.10637633095029742, 0.05449186290206853, 0.2330230749794282, 0.14210677851224318, 0.17387240601237863, 0.12233951929374598, 0.19975183764472604, 0.113750822347356, 0.09940104078850709, 0.11027833563275635, 0.08810657731373794, 0.17678345058811828, 0.15140630450332537, 0.12826085585402325, 0.17905249289469793, 0.08112897907267325], [0.08926023845560849, 0.03783350854064338, 0.006178133571665967, 0.027412797790020704, 0.07701506154262461, 0.027903643131139688, 0.032639844066579826, 0.07339714356930926, 0.01136702418079949, 0.04200183291686699, 0.04046950205520261, 0.012041785776091274, 0.030634913564426824, 0.03402322960027959, 0.050152402982348576, 0.012536239810287952, 0.022597758506890386, 0.027777106952271424, 0.009666941041359678, 0.022606417514907662, 0.03477495469269343, 0.004744357138406485, 0.06756329137715511, 0.014606855947931763, 0.014307817746157525, 0.0380770220363047, 0.02888365284889005, 0.06804980628658086, 0.06146469655504916, 0.04780192481121048, 0.07660270945052616, 0.0413036352256313, 0.020987938150938135, 0.07000976635026745, 0.07991522623342462, 0.016387713512813207, 0.04852849851886276, 0.05668105382937938, 0.09722617702209391, 0.03168874842231162, 0.042042866261908785, 0.046673630276927724, 0.03354458516696468, 0.06307745396043174, 0.04413029761053622, 0.06629588126088493, 0.020604312740033492, 0.03792772418819368, 0.025530698294460308, 0.01962651833309792, 0.03666570577479433, 0.027655960620904807, 0.057253539125667885, 0.01714576912490884, 0.05612648768874351, 0.051412094762781635, 0.02762926185823744, 0.040676175340195186, 0.07735807477729395, 0.09557673896779306, 0.061672553565585986, 0.10410333299660124, 0.026102003575942945, 0.02277730258356314, 0.04169612002442591, 0.007429767019857536, 0.006163925154396566, 0.051439980961731635, 0.08585450050304644, 0.030572339383070357, 0.05248981193290092, 0.32226459647063166, 0.14218878583051264, 0.1552194295800291, 0.1278770764474757, 0.4590186645509675, 0.3743827185826376, 0.6202825158834457, 0.40006444207392633, 0.3146688634296879, 0.3018607303965837, 0.24610123102320358, 0.28017098957207054, 0.061172279238235205, 0.5246212240308523, 0.09957828049664386, 0.6526137934997678, 0.7833001215476543, 2.1206852048635483, 1.0620273370295763, 0.08940454164985567, 0.16989670606562868, 0.43787826143670827, 0.7402033091057092, 0.4773118923185393, 0.1642756350338459, 0.44104562897700816, 0.08929824383812957, 0.03613883658545092, 0.0541794335731538, 0.03665609867312014, 0.04551595411612652, 0.01167229178463458, 0.10774434660561383, 0.07341684016864747, 0.045824138360330835, 0.0378222390281735, 0.028282270177442115, 0.05551609348913189, 0.013063804763078224, 0.026366761048848275, 0.0642306030204054, 0.051749701451626606, 0.037756696256110445, 0.04211397514154669, 0.009251483988919063, 0.019571302545955405, 0.019123817182844505, 0.02976908512209775, 0.011191233516001375, 0.03168792092765216, 0.02558114949351875, 0.01607692061952548, 0.01958652585017262, 0.04327477203332819, 0.011803058205259731, 0.03999544780526776, 0.07352075568633154, 0.024680143251316622, 0.02254427377920365, 0.03537113305355888, 0.03828061911917757, 0.013131861560395919, 0.051783461749437265, 0.03961808426538482, 0.08342261615325697, 0.030603329614677932, 0.04949034046148881, 0.041895208560163155, 0.019449634855845943, 0.02493996358680306, 0.02866706818167586, 0.020553785470838193, 0.05663376046868507, 0.015124355522857513, 0.10229888997855596, 0.05644152195600327, 0.01960901849088259, 0.010370061954745324, 0.06751080669346265, 0.024458690095343627, 0.0876854604575783, 0.057015899728867225, 0.09601977886632085, 0.11599431993090548, 0.07049818857922219, 0.03859344920783769, 0.026961421717714984, 0.06556624619406648, 0.028126213219366036, 0.014228367126634112, 0.013789777331112418, 0.0040623758377478225, 0.06951893214136362, 0.07407214914564975, 0.08355445126653649, 0.01383744918712182, 0.04279999418940861, 0.023669152578804642, 0.010994773110724054, 0.062009295652387664, 0.00914166375878267, 0.0367659921903396, 0.05282134785375092, 0.07639670409844257, 0.07976325665367767, 0.04363802734587807, 0.07039659598376602, 0.01709979864244815, 0.0839134058333002, 0.02908263933932176, 0.08805939898593351, 0.05972062725049909, 0.01641631402890198, 0.048174442126764916, 0.031009449521661736, 0.034720959738478996, 0.003325074153508467, 0.09505025198450312, 0.13065569219179451, 0.1366933752433397, 0.016379184380639344, 0.013404455185082043, 0.0488982921524439, 0.008083052252914058, 0.043525636501726694, 0.013349397104320815, 0.012916629457322415, 0.14181146310875192, 0.012744686828227714, 0.029052498866803944, 0.01304812967646285, 0.01313030305027496, 0.051917601231252775, 0.004466501686692936, 0.008405251028307248, 0.04082171421032399, 0.0209641541732708, 0.039185460409498774, 0.050216758318128996, 0.027069114767073188, 0.03610233405197505, 0.01821643589209998, 0.06502434480353259, 0.016258240284514613, 0.04832754719245713, 0.018865512683987617, 0.06269278397667222, 0.025469508218520787, 0.04125807106902357, 0.01818660897697555, 0.06003815513395239, 0.0704318776843138, 0.05654151893395465, 0.034447652724338695, 0.04146264407609124, 0.027583888804656453, 0.049595621530897915, 0.01903298016259214, 0.06158355521620251, 0.009968060039682314, 0.05248196372122038, 0.06909856485435739, 0.046430012880591676, 0.030240541855164338, 0.03827932778222021, 0.08920089632738382, 0.10939304993371479, 0.07146434611058794, 0.06319406762486324, 0.042961225772160105, 0.04305841743189376, 0.06364805420162156, 0.04374901924165897, 0.12467001884942874, 0.03521756414556876, 0.059590313539956696, 0.0551698370691156, 0.08879052576958202, 0.12268431368283927, 0.08252106257714331, 0.2887176215881482, 0.3726064623333514, 0.3869176225271076, 0.3044353594304994, 0.3090550802880898, 0.18803757091518492, 0.16320069349603727, 0.20277264586184174, 0.07121514776372351, 0.40098114288412035, 0.26858193799853325, 0.1954196990118362, 0.2468391039292328, 1.110637653619051, 0.5770274775568396, 0.08978665864560753, 0.15871479670749977, 0.21300101419910789, 0.4683083645068109, 0.3300680418033153, 0.1561240036971867, 0.20661239919718355, 0.12756920390529558, 0.04544568757410161, 0.005206466057643411, 0.0297262483582017, 0.03307971499452833, 0.04793063177203294, 0.0890738183807116, 0.032373249778174795, 0.0592820810561534, 0.08041082503041252, 0.01163788117992226, 0.0820751505671069, 0.06325336522422731, 0.013388136285357177, 0.08771123524638824, 0.12165623877081089, 0.09937912516761571, 0.014698596532980446, 0.039072271756595, 0.024442082685709465, 0.016390008604503237, 0.019665636937133968, 0.035064874682575464, 0.0654070258315187, 0.019958759294240735, 0.04358211765065789, 0.055123512211139314, 0.03533858987793792, 0.0834943373047281, 0.007108578029146884, 0.027102285057480913, 0.039572494133608416, 0.051928744578617625, 0.042933821969199926, 0.012417687285051215, 0.03465494199190289, 0.04979863231710624, 0.01710964508674806, 0.03289336913439911, 0.08463455815217458, 0.0034600571325427154, 0.046457383286906406, 0.05019144737161696, 0.025530583261570428, 0.021316262427717447, 0.051712701679207385, 0.08801492207567208, 0.036293240409577265, 0.05197437923925463, 0.033998067083302885, 0.0404859035188565, 0.05135431114467792, 0.0028025391065966687, 0.04484902681724634, 0.02462789234414231, 0.03212477873603348, 0.012021680995530915, 0.10413334544864483, 0.04657342920836527, 0.02530116129491944, 0.017289960997004528, 0.05338977360224817, 0.051909237226936966, 0.059529776553972624, 0.029347474737733137, 0.03018783638253808, 0.05745132148149423, 0.04165078222285956, 0.03608447797887493, 0.030878295328875538, 0.057409000510233454, 0.04545321295154281, 0.04888554947683588, 0.021618669052259065, 0.050778816439560615, 0.05063326643721666, 0.020215772456140257, 0.049509287491673604, 0.019758301496040076, 0.17858796782093123, 0.16852889821166173, 0.08334501719218679, 0.25990115536842495, 0.24933635664638132, 0.2460489541408606, 0.1423166281892918, 0.24003714235732332, 0.0707617326406762, 0.15841250511584803, 0.11509764968650416, 0.06019024716806598, 0.20455051999306306, 0.18363316194154322, 0.14513781352434307, 0.07729035380179994, 0.1509408443234861, 0.10931081254966557, 0.09824585082242265, 0.08351844226126559, 0.2133495861198753, 0.09743025279021822, 0.1866965545923449, 0.12479202792746946, 0.12619091692613438, 0.15757542190840468, 0.14249360072426498, 0.14747951208846644, 0.15550579468254, 0.12381853055558167, 0.15549124858807772, 0.11686659578117542, 0.1394139847252518, 0.21342868421925232, 0.12167376087745652, 0.09020286248414777, 0.13677542709046975, 0.2546746248845011, 0.13394610781688243, 0.19313627388328314, 0.13469235214870423, 0.17062181403161958, 0.07689434380154125, 0.14040433627087623, 0.12426106579368934, 0.11904059123480693, 0.11816596277640201, 0.19027284550247714, 0.08697368888533674, 0.17411482112947851, 0.14522586192470044, 0.14622574264649302, 0.08263994721346535, 0.1431736900121905, 0.17595138429896906, 0.2095235328306444, 0.10066840637591667, 0.1445830729790032, 0.11023224826203659, 0.1359157232218422, 0.18547772546298802, 0.37494686956051737, 0.1836313511012122, 0.18089490418788046, 0.11420066031860188, 0.10492972927750088, 0.24535443750210106, 0.33530665445141494, 0.3246100206160918, 0.20368487894302234, 0.14478134515229613, 0.5927905160933733, 0.3593371290480718, 0.24572698079282418, 0.24043852550676093, 0.7379473582841456, 0.5293342180084437, 0.7250319700688124, 0.4941099596908316, 0.37127804767806083, 0.3892657480901107, 0.45899515331257135, 0.29980581253767014, 0.3734719252679497, 1.5568607719615102, 0.960842507192865, 1.3507148274220526, 1.8085378920659423, 3.7710618088021874, 2.0316709438338876, 0.22580668330192566, 0.3030844428576529, 0.6007691973354667, 0.9275700675789267, 0.6154955446254462, 0.4467286396538839, 0.5912266031373292, 0.38434139045421034, 0.16612674429779872, 0.11891814428963698, 0.0922977746813558, 0.10316444939235225, 0.10685194371035323, 0.16879461676580831, 0.24567433283664286, 0.1504227807163261, 0.21440422249725088, 0.12274655760847963, 0.23043079767376184, 0.17222428898094222, 0.20095880725421011, 0.22537536191521212, 0.22151810873765498, 0.14474440104095265, 0.1312823171610944, 0.10699868857045658, 0.1704130627331324, 0.14958868094254285, 0.18246974155772477, 0.2173899716581218, 0.2283027782686986, 0.07667432670132257, 0.17915533971972764, 0.19207492849091068, 0.1826434041140601, 0.2437083687982522, 0.08785990226897411, 0.19975937786512077, 0.1050456304801628, 0.1102378885843791, 0.12445892236428335, 0.12400880979839712, 0.08829080063151196, 0.3077600325923413, 0.15129952429560944, 0.18049763253657147, 0.19084562023635954, 0.07684087206143886, 0.09054660302354023, 0.1427442833664827, 0.1342170956195332, 0.10849731479538605, 0.13499581633368507, 0.15221883746562526, 0.0783306518860627, 0.2662665559910238, 0.20380173751618713, 0.2064336306648329, 0.1259537265286781, 0.2025811717612669, 0.1321491159615107, 0.1994246247340925, 0.10701004342990927, 0.1505225253640674, 0.21145492763025686, 0.1717155467486009, 0.2880290272878483, 0.14763095474336296, 0.12361383138340898, 0.0926174919004552, 0.1967884271289222, 0.1448926524608396, 0.08104662294499576, 0.13553943950682878, 0.1342186244437471, 0.22613549925154075, 0.1309365505585447, 0.1894061209168285, 0.08296730855363421, 0.15636189171345904, 0.1846903216210194, 0.13637796248076484, 0.11897564589162357, 0.15495742176426575, 0.2155036252224818, 0.16944907227298245], [0.012846498357248493, 0.010902376652666135, 0.04101485443243291, 0.031082706918823533, 0.07975919710588641, 0.057609814539318904, 0.024434913539153058, 0.09280949292588048, 0.053185523429419845, 0.04949904585373588, 0.03245038489694707, 0.029854600943508558, 0.026454573817318305, 0.021656273675034754, 0.04275811108527705, 0.05961926843156107, 0.050524972248240374, 0.035324811906320974, 0.07054820191115141, 0.07754414604278281, 0.02694940263609169, 0.019949027882830705, 0.019516840038704686, 0.016085828247014433, 0.02306970134668518, 0.04715921379101928, 0.0542531770770438, 0.04540807924058754, 0.04857838939642534, 0.03840753750409931, 0.030042538710404187, 0.042330815849709325, 0.04280474393453915, 0.04977978176611941, 0.018058343594020698, 0.013519523326976923, 0.004414301802171394, 0.030137670910335146, 0.01639918154978659, 0.04845968658628408, 0.0655928670312278, 0.03537845805112738, 0.02009419011301361, 0.06724306949763559, 0.039082732328097336, 0.026227651032968424, 0.008571882663090946, 0.03431713492318522, 0.03195389552274719, 0.04432535257365089, 0.01216261576701072, 0.057195414119632915, 0.0332060062646633, 0.08497210175846703, 0.057205362609238364, 0.053028844922664575, 0.007033481961116195, 0.014803597441641614, 0.06754324596840888, 0.08152180525939912, 0.02985098853969248, 0.03399793349672109, 0.042866138101089746, 0.02394659892161144, 0.10434188152430579, 0.05631015439576004, 0.07860506098950282, 0.40651916759088635, 0.6904924765694886, 0.16698811057722196, 0.15616170479916036, 3.534166608005762, 4.329669596627355, 3.64762828219682, 3.416356542147696, 10.909996423870325, 23.633162453770638, 39.24163430929184, 47.03107573091984, 42.01180726289749, 38.530669659376144, 29.77649610489607, 46.794424429535866, 73.02554547786713, 79.83672559261322, 91.39008164405823, 83.11893627047539, 87.83272013068199, 106.74046754837036, 99.79328513145447, 63.00154656171799, 37.73822598159313, 20.632358975708485, 22.532414719462395, 18.44079427421093, 7.107567060738802, 9.497439321130514, 7.704730192199349, 1.3319441908970475, 0.2920407213969156, 0.40091642760671675, 0.22174907993758097, 0.038859067572047934, 0.02836642972397385, 0.029179695557104424, 0.05216230587393511, 0.049474952029413544, 0.01650422884267755, 0.11017209719284438, 0.034934293798869476, 0.017311668816546444, 0.012387822334858356, 0.019665037652885076, 0.12699712679022923, 0.006887550216561067, 0.025623442634241655, 0.07734571059700102, 0.029279375266924035, 0.012972652330063283, 0.026660427029128186, 0.04435411450685933, 0.020430091717571486, 0.017209488069056533, 0.032399573756265454, 0.07294827039004304, 0.02509721725800773, 0.03912345026037656, 0.052492342656478286, 0.07473908757674508, 0.06270619458518922, 0.013438391742965905, 0.02394615363300545, 0.014201390058588004, 0.033679396292427555, 0.049568985850783065, 0.0687485457456205, 0.021408032698673196, 0.024514152646588627, 0.013449543439492118, 0.01638682108023204, 0.03223624560632743, 0.04610391319147311, 0.0352859864506172, 0.021198624599492177, 0.02047377452981891, 0.01340270742730354, 0.09740432957187295, 0.04842323971388396, 0.03276567891589366, 0.05192650329263415, 0.013658796615345636, 0.016000653813534882, 0.038549591990886256, 0.06845646610599943, 0.04214880413201172, 0.027735555959225167, 0.027789901578216814, 0.036490622005658224, 0.041346713187522255, 0.05116550135426223, 0.03626309066021349, 0.00720021610504773, 0.02607688929856522, 0.06314278522040695, 0.07456591483787633, 0.028306252679612953, 0.060614087706198916, 0.03028600025572814, 0.027469262240629178, 0.027392141964810435, 0.00801598993348307, 0.033687853065202944, 0.044769412925234064, 0.015862028049014043, 0.032976782822515815, 0.026163774382439442, 0.0198510068730684, 0.00967718546235119, 0.03755342200747691, 0.03614726367231924, 0.04577517887810245, 0.031016588982311077, 0.041856086245388724, 0.00793436296589789, 0.08755042668781243, 0.05931997511652298, 0.03599408439185936, 0.08362876251339912, 0.020741795597132295, 0.026357497190474533, 0.02783057869237382, 0.03978929773438722, 0.027307390555506572, 0.025015016981342342, 0.004411880545376334, 0.04763839999213815, 0.033642604321357794, 0.04624140347004868, 0.08605682480265386, 0.044198378527653404, 0.02333981898118509, 0.023871964840509463, 0.04011566088593099, 0.035130974065396, 0.023185120153357275, 0.0184057262231363, 0.06228846192243509, 0.10260447670589201, 0.024260616446554195, 0.02277469393447973, 0.043722480040742084, 0.06042523338692263, 0.017849503237812314, 0.04216210712911561, 0.031136631369008683, 0.009078184157260694, 0.03132681413262617, 0.03270739805884659, 0.03046547939447919, 0.012287042391108116, 0.0606290085852379, 0.029109442002663855, 0.034384455138933845, 0.06569266362930648, 0.03970804740674794, 0.07774994359351695, 0.04295849837944843, 0.04482397191168275, 0.08785087775322609, 0.03062586492887931, 0.04967542095982935, 0.04353306911070831, 0.008792985154286725, 0.07780035768519156, 0.06479196352302097, 0.050519487776909955, 0.08492907203617506, 0.050487905682530254, 0.048814318142831326, 0.05537736382393632, 0.08079850071226247, 0.10908514028415084, 0.08773781897616573, 0.15121871925657615, 0.5831925279926509, 0.21145492763025686, 0.19799743022304028, 1.198882337193936, 2.279407437890768, 2.15650730766356, 1.7347027477808297, 8.739626985043287, 21.48943718522787, 36.1735725402832, 43.854643777012825, 41.0867241024971, 36.4833927154541, 28.60830958932638, 46.357698664069176, 73.20013090968132, 87.71376371383667, 93.95200297236443, 86.88252031803131, 92.49137654900551, 108.91917183995247, 99.8998998105526, 58.33632789552212, 33.85930672287941, 16.34706672281027, 18.169743418693542, 15.634211674332619, 6.305389255285263, 7.837583888322115, 5.831814017146826, 0.914887951221317, 0.25346860522404313, 0.31568611040711403, 0.14610064623411745, 0.07205813846667297, 0.01723746147035854, 0.03914533990609925, 0.018880843599617947, 0.07325644721277058, 0.04625008659786545, 0.16725261200917885, 0.08949271621531807, 0.07470845914212987, 0.09617991207051091, 0.04244308052875567, 0.02430562028166605, 0.09564132808009163, 0.06880475601064973, 0.03235274794860743, 0.05730006436351687, 0.020845939325226936, 0.022561541700270027, 0.017323923530057073, 0.0077378696278174175, 0.0055886266545712715, 0.03193688178726006, 0.0416120866429992, 0.04332721218816005, 0.00856088217915385, 0.009268799221899826, 0.03466139496595133, 0.024999743582156952, 0.03896837108186446, 0.010873740884562721, 0.008975914352049585, 0.026790855772560462, 0.017322185049124528, 0.10552194828051142, 0.07372797816060483, 0.016036874330893625, 0.03557338313839864, 0.03548785061866511, 0.01129352836869657, 0.015293760934582679, 0.028339467498881277, 0.10121323924977332, 0.047708629426779225, 0.02574178550275974, 0.0904187087144237, 0.04903330365777947, 0.053175574939814396, 0.052173233998473734, 0.023724707898509223, 0.03911955027433578, 0.020060869537701365, 0.02840173925505951, 0.03678633445815649, 0.0738058888236992, 0.04808731398952659, 0.03316345151688438, 0.01673894603300141, 0.024227379362855572, 0.04163719349890016, 0.05307094696036074, 0.007861974809202366, 0.03854513168334961, 0.04905204659735318, 0.04363826854387298, 0.06069448085327167, 0.04607967464835383, 0.03798806821578182, 0.01473062484365073, 0.054535438102902845, 0.03381763614015654, 0.018168379974667914, 0.040372777948505245, 0.05848463966685813, 0.00875205107149668, 0.08236150824814104, 0.07653474356629886, 0.13292035582708195, 0.10051709730760194, 0.15638869808753952, 0.12791118555469438, 0.12992230185773224, 0.23250569414813071, 0.1155524080968462, 0.14799619530094787, 0.07098540110746399, 0.1635787435225211, 0.13510853372281417, 0.187838185520377, 0.1480087821255438, 0.12437744939234108, 0.14012925181305036, 0.18046714511001483, 0.13984269375214353, 0.11424559736042283, 0.169986758264713, 0.16620554553810507, 0.17366073065204546, 0.16516809730092064, 0.15528176998486742, 0.1439426589058712, 0.11097930153482594, 0.12292153376620263, 0.1220534807362128, 0.07888456122600473, 0.2709780359873548, 0.12576775916386396, 0.13773999642580748, 0.07951330131618306, 0.0885482071316801, 0.16630821424769238, 0.1027075461752247, 0.14848175283987075, 0.1511538852355443, 0.10144665211555548, 0.13998408772749826, 0.1491952090873383, 0.1834657185827382, 0.18247717787744477, 0.12792221386916935, 0.08962013554992154, 0.0999908107041847, 0.15203983144601807, 0.12346730174613185, 0.2234889115788974, 0.1449208243866451, 0.11922344900085591, 0.17378064687363803, 0.09390447987243533, 0.15830020332941785, 0.10480205019121058, 0.11648346204310656, 0.3290176950395107, 0.16245998558588326, 0.15476458211196586, 0.26008547516539693, 0.13047830405412242, 0.10692914191167802, 0.13649278756929561, 0.24555017153033987, 0.13706765515962616, 0.25019137014169246, 0.6555304932408035, 0.9357611218001693, 0.21107892593136057, 0.6135793193243444, 6.135473772883415, 7.064588041976094, 5.317438468337059, 4.99534210190177, 15.078792627900839, 33.21944385766983, 52.14924909174442, 66.40185490250587, 61.77594892680645, 55.0102523714304, 44.89726223051548, 67.58084803819656, 103.34156513214111, 115.23064076900482, 119.57519844174385, 112.02406883239746, 117.84569084644318, 144.10831600427628, 133.05179089307785, 85.54544046521187, 54.088684022426605, 30.260210148990154, 32.47295871376991, 27.832222133874893, 12.466428056359291, 15.46126775443554, 11.475939955562353, 2.170860324986279, 0.43914783862419426, 0.3795953857479617, 0.43445740593597293, 0.37512830982450396, 0.16096501814899966, 0.15318829013267532, 0.170543814310804, 0.12828798877308145, 0.14393415389349684, 0.31411183706950396, 0.3241664241068065, 0.2971352683380246, 0.18118875013897195, 0.07655645138584077, 0.19191984931239858, 0.20673218183219433, 0.12903595488751307, 0.22172672644956037, 0.1642256142804399, 0.10896210704231635, 0.09067660503205843, 0.09104923738050275, 0.07447460840921849, 0.07837840908905491, 0.09103755597607233, 0.1448434332269244, 0.16274563822662458, 0.13799161417409778, 0.2310209089773707, 0.15830766933504492, 0.244724799413234, 0.11660346732242033, 0.0760719105892349, 0.1341136105475016, 0.17412929300917313, 0.13925509090768173, 0.1790608197916299, 0.16335863736458123, 0.0854307044937741, 0.12872493563918397, 0.10106106929015368, 0.17596734047401696, 0.14471793605480343, 0.1803416627808474, 0.13896572752855718, 0.2079409474390559, 0.1119163742987439, 0.19256128754932433, 0.1288262684829533, 0.1881419465644285, 0.1620638123131357, 0.1484017344773747, 0.10983523636241443, 0.059862173366127536, 0.15133329201489687, 0.1498396010720171, 0.1264977504615672, 0.162193970172666, 0.14524653815897182, 0.09727653174195439, 0.1894980581710115, 0.10857674686121754, 0.17076448450097814, 0.12032390557578765, 0.1397611465654336, 0.2468780369963497, 0.26833100302610546, 0.13139108632458374, 0.16709842340787873, 0.0967762351501733, 0.11065165817853995, 0.10351858742069453, 0.12580875540152192, 0.10276206434355117, 0.09522460473817773, 0.12487367901485413, 0.06558105204021558], [0.021434262052935082, 0.05874493683222681, 0.10620063490932807, 0.10822436030139215, 0.10062461224151775, 0.07539438171079382, 0.03290497632406186, 0.027604462993622292, 0.011479515214887215, 0.013962730208731955, 0.035015117391594686, 0.02405770770565141, 0.005763241015301901, 0.02307863123860443, 0.04656124314351473, 0.06465534155722708, 0.049254493351327255, 0.04353004856966436, 0.05828995577758178, 0.04747407365357503, 0.02830592613463523, 0.025068613031180575, 0.04239776870235801, 0.09231653617462143, 0.04657151075662114, 0.026941663891193457, 0.016385830313083716, 0.030931321780371945, 0.10382776614278555, 0.03256533986132126, 0.015533317855442874, 0.049051026144297794, 0.037040197203168646, 0.015031941438792273, 0.016337753986590542, 0.013121391712047625, 0.06969449459575117, 0.06630705058341846, 0.07336811817367561, 0.03328932718432043, 0.019647018307296094, 0.049494782215333544, 0.01653655865084147, 0.008106668319669552, 0.043141727219335735, 0.025728695873112883, 0.09028960470459424, 0.08574881867389195, 0.02092069586069556, 0.05127261552843265, 0.009347343493573135, 0.05447066345368512, 0.013252844619273674, 0.025686951921670698, 0.037710746182710864, 0.0515963069483405, 0.06329507392365485, 0.02971334983158158, 0.01739033090416342, 0.07082051073666662, 0.21460549294715747, 0.37588725972454995, 0.04288929310860112, 0.09260064514819533, 0.08695496449945495, 0.11903378574061207, 1.0864797374233603, 5.896015847101808, 23.518442809581757, 40.414038598537445, 73.14710095524788, 87.78171926736832, 108.01518514752388, 101.7049777507782, 96.51685014367104, 110.10530099272728, 119.29125487804413, 121.16018459200859, 115.22060930728912, 115.31352952122688, 121.99120759963989, 128.05150240659714, 117.65162765979767, 114.69380557537079, 108.39207172393799, 119.96796056628227, 135.802660882473, 130.3798806667328, 115.00094309449196, 130.5396392941475, 128.91366094350815, 132.11290687322617, 134.87519145011902, 125.47091647982597, 121.6833633184433, 118.49411845207214, 113.17281559109688, 109.24374282360077, 88.50462287664413, 63.0939120054245, 34.47757914662361, 11.064681373536587, 3.151223394088447, 1.1682120454497635, 0.19928884139517322, 0.3713922790484503, 0.35532867070287466, 0.017741118135745637, 0.045665704674320295, 0.042339458159403875, 0.1348368334583938, 0.12009826299617998, 0.03738254992640577, 0.04793171530764084, 0.06176057970151305, 0.01926264518260723, 0.03469093615422025, 0.015892604533291887, 0.020104925279156305, 0.06932414064067416, 0.0220506323967129, 0.05299861353705637, 0.027598373671935406, 0.02705079114093678, 0.06502276402898133, 0.01845401962782489, 0.03573356458218768, 0.022197620310180355, 0.021036216712673195, 0.024399097492278088, 0.0043688345886039315, 0.01789267025742447, 0.03322333170217462, 0.03301430580904707, 0.03600108284445014, 0.016484111074532848, 0.04834731429582462, 0.02460277064528782, 0.029962444277771283, 0.07235426281113178, 0.04960755155480001, 0.03941936309274752, 0.017584495290066116, 0.009781991557247238, 0.02556390012614429, 0.009818995040404843, 0.03810367998084985, 0.04938229118124582, 0.0041024968049896415, 0.021495225773833226, 0.10002339840866625, 0.03357753281306941, 0.04932992524118163, 0.029831082283635624, 0.006944925189600326, 0.06568030687049031, 0.015662186233385, 0.025055220976355486, 0.015364636965387035, 0.03614548622863367, 0.006490613923233468, 0.01540591429147753, 0.02025957772275433, 0.04672114628192503, 0.05939513983321376, 0.03321913485706318, 0.03850019093079027, 0.01414398493579938, 0.010790225151140476, 0.03744264533452224, 0.08003242619452067, 0.027728626155294478, 0.09491923323366791, 0.020084484676772263, 0.033595785935176536, 0.0066527954550110735, 0.014303192310762824, 0.03538226897944696, 0.013927388208685443, 0.006226710383998579, 0.05584445672866423, 0.04554599625407718, 0.03798623882175889, 0.06338127437629737, 0.04685815416451078, 0.03979170600359794, 0.04071695635502692, 0.028600009572983254, 0.025272787133872043, 0.023659803373448085, 0.09293758019339293, 0.025060146981559228, 0.007019139029580401, 0.01017210612189956, 0.03657853310869541, 0.03107103108050069, 0.037289540268830024, 0.08630905111203901, 0.04368404050183017, 0.030924690690881107, 0.04925415567413438, 0.04264513023372274, 0.09491538890870288, 0.023734144306217786, 0.028888480519526638, 0.039486575697083026, 0.04661630307964515, 0.09151124657364562, 0.04090333932253998, 0.04544585455732886, 0.009693788233562373, 0.020363385629025288, 0.010122968524228781, 0.014532867535308469, 0.06867675780085847, 0.01620133982214611, 0.03360096612595953, 0.024222772481152788, 0.020578793992171995, 0.015673138477723114, 0.09615092378226109, 0.041983572373283096, 0.040764605946606025, 0.022217509867914487, 0.027268123521935195, 0.049362397912773304, 0.036343134997878224, 0.015682276170991827, 0.011607720298343338, 0.02057427987892879, 0.03950396421714686, 0.01674500381341204, 0.04498387505009305, 0.004986500443919795, 0.07408595309243537, 0.07975193890160881, 0.036107250780332834, 0.3862343420041725, 0.059397325458121486, 0.07142458183807321, 0.12421691542840563, 0.24337279930477962, 0.39964860188774765, 3.7539235409349203, 21.33092489093542, 38.65889757871628, 73.64903122186661, 101.09053552150726, 118.71407344937325, 114.923115670681, 109.03021708130836, 126.50739446282387, 138.6273381114006, 142.2512036561966, 137.08000034093857, 137.45222836732864, 144.70315128564835, 147.3398146033287, 143.40889513492584, 140.4731422662735, 129.23523008823395, 141.8682298064232, 153.4730350971222, 149.28836524486542, 136.65190011262894, 153.34101498126984, 152.09679454565048, 151.36712729930878, 154.18618083000183, 146.20115250349045, 146.45617961883545, 136.7954260110855, 129.73268419504166, 124.11422207951546, 92.724699229002, 63.7988805770874, 32.24534332752228, 9.553452115505934, 2.7053821552544832, 0.5409914581105113, 0.0782411711406894, 0.3741285181604326, 0.19694136892212555, 0.07086274636094458, 0.04339820232416969, 0.09085959638468921, 0.1647849116125144, 0.13161114795366302, 0.02769480834103888, 0.007485148398700403, 0.041339139570482075, 0.0795814156299457, 0.035889500941266306, 0.018409765361866448, 0.06752888541086577, 0.012724065327347489, 0.026977504057867918, 0.029560812508862, 0.037700085231335834, 0.04038699007651303, 0.043800780331366695, 0.05285069237288553, 0.04031651944387704, 0.02242045200546272, 0.03470113697403576, 0.01616585774172563, 0.042415264833834954, 0.06490547501016408, 0.08487053142744116, 0.07227325739222579, 0.02496461216651369, 0.03000632375915302, 0.009212151089741383, 0.0314818858896615, 0.036478376568993554, 0.03750074436538853, 0.036326714980532415, 0.07284530482138507, 0.07238778562168591, 0.0487105473439442, 0.04695232528320048, 0.04567450283502694, 0.02763354033959331, 0.10208616818999872, 0.06169199041323736, 0.03847501728159841, 0.012879509085905738, 0.032358243552153, 0.02406341111054644, 0.021335402416298166, 0.05939846836554352, 0.04582532579661347, 0.09285016261856072, 0.03909772742190398, 0.0356200902024284, 0.1147499238140881, 0.06286526651820168, 0.015234528273140313, 0.01098792865377618, 0.0982133521756623, 0.013935760562162613, 0.03665011696284637, 0.06752658475306816, 0.024318581890838686, 0.027284614043310285, 0.11160619367728941, 0.06764942503650673, 0.09060423079063185, 0.03543988932506181, 0.08838673806167208, 0.06917968901689164, 0.008084474393399432, 0.08039610824198462, 0.11047263731597923, 0.29379046813119203, 0.21054854267276824, 0.2359484281623736, 0.1681740625645034, 0.09498411920503713, 0.10749090317403898, 0.11015533207682893, 0.10431548333144747, 0.10048105119494721, 0.11264943066635169, 0.12842985772294924, 0.10035792889539152, 0.19723499222891405, 0.13643601327203214, 0.14981623826315627, 0.11058152522309683, 0.1423102308763191, 0.07829275782569312, 0.09480639710091054, 0.18986844923347235, 0.14535639085806906, 0.1602583154453896, 0.12074665515683591, 0.09129707759711891, 0.25151408510282636, 0.11956850314163603, 0.22070590232033283, 0.1549950783373788, 0.11244523615459912, 0.30632854846771806, 0.08113285308354534, 0.12384487679810263, 0.08376791520277038, 0.16963478730758652, 0.18696978368097916, 0.2155491930898279, 0.14088952273596078, 0.11452891965745948, 0.1160492240160238, 0.14383307337993756, 0.11241244807024486, 0.12368275463813916, 0.1744266418972984, 0.1208138492074795, 0.15786604693857953, 0.2243607272976078, 0.10381916465121321, 0.20243994105840102, 0.13116673508193344, 0.14074505626922473, 0.13128224294632673, 0.10007068063714541, 0.17016788682667539, 0.17859924846561626, 0.129385654872749, 0.17873175151180476, 0.17339901969535276, 0.2957750897621736, 0.32086849794723094, 0.748560723150149, 0.11251833027927205, 0.15433758002473041, 0.48671184573322535, 0.5012622149661183, 2.0104455202817917, 8.959431890398264, 35.833353996276855, 61.031188890337944, 97.68866926431656, 120.81819534301758, 142.7230927348137, 140.25483638048172, 132.664834856987, 149.9661272764206, 157.46218264102936, 159.03522223234177, 152.2977277636528, 154.42286252975464, 157.86243796348572, 165.37177741527557, 160.43347120285034, 151.48201793432236, 146.38793528079987, 155.44262140989304, 170.4059448838234, 164.9736651778221, 147.18533009290695, 163.11419695615768, 169.21232253313065, 173.59105557203293, 179.54673439264297, 166.84366643428802, 165.89818596839905, 160.76665252447128, 158.05204778909683, 154.58845764398575, 121.16065576672554, 90.2698865532875, 50.440165400505066, 18.033161647617817, 5.142956105992198, 1.6043902840465307, 0.18923468480352312, 0.5014798126649112, 0.6220918125472963, 0.316898453165777, 0.10663585999282077, 0.16567382641369477, 0.2465893267071806, 0.22910578205483034, 0.17539220571052283, 0.14328643708722666, 0.1350106147583574, 0.1238732342608273, 0.17649760498898104, 0.11841851563076489, 0.11647887557046488, 0.1334989193128422, 0.10882741466048174, 0.1472604597802274, 0.10070186239317991, 0.11462079753982835, 0.18468686321284622, 0.1536859743646346, 0.11858124635182321, 0.11338277647155337, 0.21030942269135267, 0.07435922670993023, 0.12809951294912025, 0.09810234172618948, 0.15198886074358597, 0.1365408638957888, 0.12874675478087738, 0.09917950228555128, 0.22752094053430483, 0.15917553682811558, 0.1166899646341335, 0.1495785135193728, 0.2999756159260869, 0.1339574923622422, 0.15023335494333878, 0.09780901527847163, 0.16859408846357837, 0.14068697579205036, 0.16224537132075056, 0.18414610472973436, 0.18216186901554465, 0.14529724168824032, 0.15111468499526381, 0.12902759830467403, 0.11132037776405923, 0.13903195678722113, 0.1606302650179714, 0.14431995194172487, 0.18619909300468862, 0.1168758726271335, 0.10780214506667107, 0.17527500574942678, 0.10112346164532937, 0.14983684028265998, 0.12257722919457592, 0.15319476166041568, 0.10288727207807824, 0.16419894149294123, 0.127893656026572, 0.09438320223125629, 0.09179537781164981, 0.2410469827009365, 0.15276866499334574, 0.10670835297787562, 0.20191972522297874, 0.2289880477474071, 0.13718531525228173, 0.0851085085014347], [0.009256618723156862, 0.021232405306363944, 0.04405356325150933, 0.02154652673198143, 0.031300449336413294, 0.030775537561567035, 0.03032298518519383, 0.04127982341742609, 0.02232911403552862, 0.01670303721766686, 0.037151619544602, 0.049826225367723964, 0.01605376190127572, 0.03195372111804318, 0.08392424118937925, 0.012356605748209404, 0.028973107619094662, 0.03620021961978637, 0.0037995959564796067, 0.06171719745907467, 0.035690557124326006, 0.06787129008444026, 0.07264516985742375, 0.04684010142227635, 0.08141955215251073, 0.0553657269483665, 0.05769390729255974, 0.013907029242545832, 0.0064506989019719185, 0.012248147359059658, 0.039591415188624524, 0.011710460439644521, 0.043333635476301424, 0.1136519608553499, 0.0485438721079845, 0.01663086521148216, 0.03394535233383067, 0.032494754195795394, 0.04184118763078004, 0.04827399010537192, 0.02004578538617352, 0.08989033667603508, 0.13091047148918733, 0.09336886447272263, 0.04778987233294174, 0.00762694174227363, 0.13898055563913658, 0.03996858205937315, 0.09639097886974923, 0.021419367149064783, 0.017315424083790276, 0.03198086888005491, 0.06265893462114036, 0.09979014881537296, 0.036555530241457745, 0.05829775574966334, 0.08488184175803326, 0.05239165548118763, 0.5062015342991799, 1.0344710969366133, 6.693013105541468, 13.94701860845089, 33.547088876366615, 48.23497653007507, 53.46945784986019, 62.251918986439705, 74.95966449379921, 85.34332171082497, 98.00130888819695, 115.1667357981205, 105.57087510824203, 105.87770104408264, 94.90601018071175, 84.29632589221, 102.0841746032238, 93.66187334060669, 88.36305007338524, 100.49186244606972, 98.60876709222794, 91.99910536408424, 88.23462456464767, 77.24302276968956, 94.8419152200222, 100.47017320990562, 73.7038242816925, 104.06972005963326, 77.71810367703438, 85.86057275533676, 111.08678832650185, 101.23855277895927, 99.39206466078758, 91.57537490129471, 103.63644450902939, 105.46827301383018, 92.93224409222603, 93.30670639872551, 88.21731269359589, 97.9748547077179, 102.76268899440765, 124.19414699077606, 115.67810475826263, 99.53471660614014, 97.31084793806076, 67.76694685220718, 32.20234863460064, 15.6581199914217, 5.9759939555078745, 0.7352547871414572, 0.19585625996114686, 0.2673804305959493, 0.04428504282259382, 0.04610966112522874, 0.002492796816113696, 0.04690047513577156, 0.07324311081902124, 0.028259538194106426, 0.02872046756237978, 0.046917674408177845, 0.04955995020281989, 0.026021016710728873, 0.050968420327990316, 0.03126217678072862, 0.005281105241010664, 0.10423332016216591, 0.04446217120857909, 0.07221006351755932, 0.03483075677650049, 0.03032639349839883, 0.008917428476706846, 0.006659895952907391, 0.03468341448751744, 0.030254065641202033, 0.08443638987955637, 0.010363198944105534, 0.046069833770161495, 0.0267544627058669, 0.12982767802895978, 0.012087378690921469, 0.01605524063052144, 0.027644815418170765, 0.06068744529329706, 0.04414176750287879, 0.03035418878425844, 0.06162773526739329, 0.01258698230230948, 0.018216257776657585, 0.03616401765611954, 0.05406317242886871, 0.06348961309413426, 0.028538756414491218, 0.009719442423374858, 0.042128625136683695, 0.06354217199259438, 0.045322119985939935, 0.02757420006673783, 0.07768246010527946, 0.061771036562277004, 0.021996670839143917, 0.04417440344695933, 0.021038120321463794, 0.04615968558937311, 0.022028815110388678, 0.02153572662791703, 0.027371666110411752, 0.04649986010917928, 0.035792954950011335, 0.025068408940569498, 0.03303288918687031, 0.043612564259092323, 0.032567098751314916, 0.03493506563245319, 0.036643593484768644, 0.0406113264762098, 0.09379344715853222, 0.042048465766129084, 0.05927747602981981, 0.022002363111823797, 0.05026731341786217, 0.07569490699097514, 0.07270658257766627, 0.010144778389076237, 0.05175645499548409, 0.0329179379332345, 0.03387712669791654, 0.027197797608096153, 0.03584184392821044, 0.07920606702100486, 0.061799382892786525, 0.028419923728506546, 0.06104872649302706, 0.01889930081233615, 0.030695415298396256, 0.05940216426097322, 0.019865751492034178, 0.047891223730403, 0.05984338960843161, 0.049591662173043005, 0.09241044012014754, 0.07925594676635228, 0.034972770445165224, 0.044281680893618613, 0.04964619147358462, 0.042194449924863875, 0.05311994354997296, 0.028390844527166337, 0.038916023695492186, 0.06982817023526877, 0.002160034264306887, 0.01184582168207271, 0.06495631212601438, 0.028926693703397177, 0.01187075320558506, 0.04158136543992441, 0.034847154529416, 0.05904791862121783, 0.0327908785402542, 0.035087391443084925, 0.05223060572461691, 0.06912460681633092, 0.006709586450597271, 0.048526401951676235, 0.03444401248998474, 0.028735264131682925, 0.09535603909171186, 0.05376298853661865, 0.05462684101075865, 0.024064886129053775, 0.039318501512752846, 0.0598863042978337, 0.03336530826345552, 0.014214229213393992, 0.01608098016731674, 0.13906288950238377, 0.028392529202392325, 0.3060224570799619, 0.4023428651271388, 2.8292685700580478, 10.33140717074275, 30.93550231307745, 46.51529900729656, 54.19560268521309, 68.70846033096313, 80.87488308548927, 94.54355522990227, 116.41419366002083, 127.10736706852913, 125.96957892179489, 118.44356596469879, 110.92846602201462, 98.79401475191116, 118.44603583216667, 106.94182634353638, 112.21611812710762, 121.75613701343536, 113.12117636203766, 110.14591321349144, 105.25449648499489, 106.78677946329117, 107.06174030900002, 109.03956457972527, 104.14640754461288, 126.90568909049034, 111.38527750968933, 116.7795592546463, 131.4836150407791, 125.65227314829826, 118.00535827875137, 121.21561601758003, 122.21008345484734, 124.91066694259644, 113.13754588365555, 110.74624300003052, 107.5076311826706, 120.69410920143127, 123.2516759634018, 149.6169564127922, 137.69584089517593, 117.9805152118206, 110.19623011350632, 76.93664520978928, 38.2511680573225, 18.474944941699505, 5.983974952250719, 0.556989727774635, 0.1608740902156569, 0.24993562605232, 0.030651619308628142, 0.02080460726574529, 0.0905528519069776, 0.027874708648596425, 0.047528896102448925, 0.04239463683916256, 0.056570284577901475, 0.05328360195562709, 0.040047520596999675, 0.07746598304947838, 0.07227479363791645, 0.07020446137175895, 0.014382469453266822, 0.03118531996733509, 0.019254012149758637, 0.042907839379040524, 0.02371725859120488, 0.04274471531971358, 0.03934495536668692, 0.034342902290518396, 0.06274591432884336, 0.008660085986775812, 0.0030047875679883873, 0.014168963771226117, 0.01043574387949775, 0.06760088115697727, 0.12264794844668359, 0.03157526662107557, 0.06049327719665598, 0.007104605219865334, 0.07444131566444412, 0.04073982192494441, 0.1085263847198803, 0.03406423325941432, 0.011306800752208801, 0.032715031047700904, 0.01927103330672253, 0.011271889197814744, 0.023176674512797035, 0.049093488123617135, 0.012632893412956037, 0.046861375085427426, 0.0423936980223516, 0.06161013152450323, 0.030972084241511766, 0.04245180818543304, 0.015722578500572126, 0.029027412419964094, 0.0209502110737958, 0.0818407283804845, 0.023789892584318295, 0.04829939382034354, 0.05107482575112954, 0.050050910576828755, 0.013723388510697987, 0.05041298587457277, 0.010077025872305967, 0.03566922780009918, 0.03456261139945127, 0.025737004216352943, 0.006145816751086386, 0.03812352872046176, 0.0463931800913997, 0.025218734663212672, 0.06077758655010257, 0.026641225813364144, 0.09335376918897964, 0.11846276989672333, 0.19772249419474974, 0.21225352305918932, 0.13654810725711286, 0.16590861225267872, 0.12313866391195916, 0.1186126540414989, 0.12900607602205127, 0.0667988570057787, 0.15113594010472298, 0.1828633321565576, 0.14163316955091432, 0.16003820928744972, 0.17664121056441218, 0.11798875275417231, 0.1511260398547165, 0.10763286860310473, 0.11467605043435469, 0.12177633310784586, 0.15086407656781375, 0.18589917628560215, 0.14176411408698186, 0.10996017692377791, 0.13887450273614377, 0.19460965966572985, 0.12351073964964598, 0.11966444799327292, 0.09098761685891077, 0.08802043623290956, 0.14587386074708775, 0.11667673214105889, 0.19588622788432986, 0.23996528761927038, 0.17071585898520425, 0.10196255607297644, 0.1314743107650429, 0.16156495548784733, 0.17019260034430772, 0.17682337813312188, 0.12247479797224514, 0.15551373566268012, 0.23983144870726392, 0.2526704699266702, 0.13989399099955335, 0.12090678836102597, 0.2706430305261165, 0.13772078964393586, 0.12632935715373605, 0.17962964629987255, 0.09742498354171403, 0.1137719809776172, 0.20842031546635553, 0.09226582522387616, 0.12793100089766085, 0.1461085575283505, 0.24197349470341578, 0.16575304325670004, 0.6278527190443128, 3.676503407768905, 13.096771482378244, 25.970107354223728, 52.87776879966259, 73.81012737751007, 80.12308582663536, 91.99002385139465, 102.75119081139565, 115.27221813797951, 130.6205141544342, 142.95380115509033, 134.81624901294708, 130.21133691072464, 120.02315640449524, 108.35962146520615, 124.64762225747108, 116.45507946610451, 111.26867696642876, 126.63720309734344, 123.5153666138649, 120.48806145787239, 115.49481019377708, 98.25479328632355, 121.47017195820808, 128.46212357282639, 102.58133232593536, 132.14076697826385, 109.17664602398872, 113.4968014061451, 136.82573318481445, 132.30128556489944, 127.52114206552505, 116.72831520438194, 131.26342445611954, 132.69163101911545, 120.39589360356331, 120.84635943174362, 117.75194987654686, 127.37880170345306, 135.28239279985428, 159.54327017068863, 156.3327768445015, 139.88697052001953, 134.5026594400406, 100.61423107981682, 52.37214893102646, 27.33757797628641, 10.327679570764303, 1.4660036098212004, 0.22445024515036494, 0.43484329304192215, 0.11199660046258941, 0.10820625931955874, 0.15476808504899964, 0.19255276769399643, 0.14679732994409278, 0.09286387008614838, 0.09718285044073127, 0.17380935314577073, 0.1255011055036448, 0.17487993085524067, 0.15269756724592298, 0.14691570249851793, 0.06088335743697826, 0.19789571146247908, 0.1529716869117692, 0.21421337180072442, 0.17935917800059542, 0.09493281453615054, 0.10628667951095849, 0.12509474996477365, 0.1714101678226143, 0.14632241480285302, 0.13323648105142638, 0.12390031522954814, 0.09578940138453618, 0.20332360145403072, 0.23691746522672474, 0.08099643149762414, 0.10020816349424422, 0.13613395916763693, 0.19339373975526541, 0.14383013447513804, 0.17333329509710893, 0.12410703304340132, 0.14165521133691072, 0.11344931001076475, 0.10282976305461489, 0.07605539780342951, 0.08622837965958752, 0.1507066225167364, 0.19087502412730828, 0.11771803212468512, 0.18290573847480118, 0.15112390246940777, 0.09149647041340359, 0.14619786757975817, 0.07956604575156234, 0.10772738110972568, 0.17745415912941098, 0.16213060560403392, 0.17738555499818176, 0.11942644865484908, 0.1454835059121251, 0.11881630678544752, 0.0959730680915527, 0.12453370116418228, 0.11639633390586823, 0.12964361056219786, 0.17931976995896548, 0.08484372505336069, 0.15028364286990836, 0.167824154777918, 0.12283413845580071, 0.17031223454978317, 0.08940755476942286, 0.12721220118692145], [0.006522311514345347, 0.06980567573918961, 0.02976296982524218, 0.03684438153868541, 0.03154040423396509, 0.048399939987575635, 0.057601906955824234, 0.00803949189503328, 0.013812198540108511, 0.05594462440058123, 0.083188498247182, 0.0584926585725043, 0.027532409731065854, 0.0643455320096109, 0.02217558223492233, 0.044809544560848735, 0.07628881809068844, 0.034294966972083785, 0.032096673603518866, 0.08671557734487578, 0.05885501959710382, 0.012976151556358673, 0.03134412472718395, 0.12956734746694565, 0.01676802337897243, 0.06562852722709067, 0.07015343871898949, 0.03563799080438912, 0.02452316231938312, 0.12005221273284405, 0.05159074455150403, 0.023311962468142156, 0.03927775760530494, 0.0200232370843878, 0.057527328535798006, 0.05829100962728262, 0.05087113589979708, 0.017300343643000815, 0.020230147856636904, 0.04400327161420137, 0.0658508152991999, 0.049138896429212764, 0.09000025616842322, 0.05800078535685316, 0.03295005808467977, 0.07331610846449621, 0.07705568670644425, 0.06238241781829856, 0.02186572444770718, 0.03569711770978756, 0.058228127454640344, 0.03836028125078883, 0.057006248098332435, 0.07645554156624712, 0.15642305952496827, 0.1302817981922999, 0.46348173287697136, 11.496174819767475, 26.60024654120207, 57.83374786376953, 87.94692680239677, 96.20865628123283, 101.93927317857742, 102.7047573029995, 107.40578144788742, 97.22998067736626, 93.34320724010468, 94.61019605398178, 95.55466577410698, 84.46206539869308, 70.93709394335747, 53.307639732956886, 73.9281490445137, 80.72900891304016, 58.08680668473244, 68.40034246444702, 41.724044904112816, 36.74465909600258, 41.767776757478714, 47.38803617656231, 37.313268184661865, 33.251802921295166, 48.467581048607826, 54.70829397439957, 23.708322420716286, 32.30352580547333, 40.91895550489426, 36.44465759396553, 35.785366371273994, 48.12072046101093, 55.73469489812851, 47.40228161215782, 78.2595594227314, 55.50007648766041, 50.77962398529053, 88.75578939914703, 67.65444248914719, 59.15384642779827, 87.47149631381035, 81.24686032533646, 99.03742209076881, 119.64856490492821, 109.69604015350342, 119.004567861557, 124.7057743370533, 107.8375218808651, 82.82031029462814, 65.33325344324112, 24.248887114226818, 6.567748552188277, 1.0466303257271647, 0.3781695122597739, 0.22132854937808588, 0.034817275663954206, 0.0521186416153796, 0.03261656289396342, 0.01703390335023869, 0.05638272901705932, 0.02906195011746604, 0.08482596545945853, 0.06715614174026996, 0.01575161688379012, 0.038339319289661944, 0.04340674444392789, 0.04029717165394686, 0.05029319952882361, 0.04021900866064243, 0.04374961667053867, 0.045055904192849994, 0.04065482004079968, 0.008635891972517129, 0.020759677645401098, 0.06401601844117977, 0.021565410679613706, 0.0171747481363127, 0.051566914189606905, 0.04308370982471388, 0.054147740156622604, 0.06622539949603379, 0.0089192532323068, 0.04053356053191237, 0.010479853426659247, 0.05414769933850039, 0.0777502627170179, 0.036051719580427743, 0.03372569517523516, 0.0104842460132204, 0.007831001275917515, 0.030613936760346405, 0.02458388113154797, 0.07286754698725417, 0.028988395861233585, 0.010187907373619964, 0.015433524968102574, 0.06380858816555701, 0.031036504515213892, 0.02718117721087765, 0.11569464069907553, 0.057815931213553995, 0.051004388515139, 0.036460026967688464, 0.034153287269873545, 0.05358123285986949, 0.02890210264013149, 0.07120276874047704, 0.046456062264041975, 0.0390525306283962, 0.0651415521861054, 0.03782920408411883, 0.029021846312389243, 0.02774871052679373, 0.054517203534487635, 0.03519993071677163, 0.02709173728362657, 0.040894006815506145, 0.0711710196628701, 0.06071103816793766, 0.11177576699992642, 0.007552375845989445, 0.04564699142065365, 0.016534532587684225, 0.06938240665476769, 0.020296007896831725, 0.023007787676760927, 0.039572093373863026, 0.10894172024563886, 0.08354420962859876, 0.1167371949122753, 0.04405584535561502, 0.06368421163642779, 0.013205028044467326, 0.1816032693022862, 0.12480885983677581, 0.012313922052271664, 0.0230038097652141, 0.026350014486524742, 0.046835288594593294, 0.055091933827497996, 0.0703466049162671, 0.02621107330924133, 0.023282660622498952, 0.062225327419582754, 0.003419580398258404, 0.031194734110613354, 0.018282114106114022, 0.007242215633596061, 0.10787873470690101, 0.012165367279521888, 0.044076703416067176, 0.07685203396249563, 0.03563349710020702, 0.069455107441172, 0.08292105791042559, 0.01096262976716389, 0.026544611173449084, 0.0653251817857381, 0.04433338632225059, 0.0032491489673702745, 0.06562554379343055, 0.02987429754284676, 0.04222351613861974, 0.017572166361787822, 0.021639393526129425, 0.027723915372916963, 0.03511786402668804, 0.022320655407384038, 0.03339723545650486, 0.04957041077432223, 0.10605173039948568, 0.1079621075768955, 0.16677891399012879, 0.02718507905228762, 1.0105218132957816, 6.231712158769369, 19.02719210833311, 52.703635543584824, 91.99597433209419, 103.38379606604576, 114.72604304552078, 116.51728972792625, 120.95302730798721, 109.69920918345451, 108.01539793610573, 111.11326530575752, 111.17605313658714, 103.87564167380333, 100.87428152561188, 104.82830375432968, 130.93524366617203, 117.68599301576614, 107.31904730200768, 113.73575538396835, 82.50669032335281, 87.66709461808205, 86.39896586537361, 79.77516889572144, 80.39100185036659, 68.25318396091461, 92.20669582486153, 109.21064659953117, 55.9175068885088, 72.23907127976418, 67.92295128107071, 73.24188306927681, 78.63890826702118, 91.56994879245758, 87.83278092741966, 75.03706634044647, 109.20414134860039, 90.90886786580086, 95.11252909898758, 117.71486386656761, 96.98826804757118, 92.07931146025658, 114.8107784986496, 106.24738320708275, 118.11160817742348, 129.59052622318268, 124.59564104676247, 137.72648245096207, 142.31987357139587, 124.575684517622, 100.7978980243206, 74.4906784594059, 30.55696852505207, 7.751601152122021, 0.6539219920523465, 0.3270556643838063, 0.11915914190467447, 0.08313961297972128, 0.059111542941536754, 0.01717182221909752, 0.015945925988489762, 0.12359082480543293, 0.023550247533421498, 0.046060044842306525, 0.017829652642831206, 0.06934288729098625, 0.07264320316608064, 0.03701911278767511, 0.04125911378650926, 0.006940864250282175, 0.0530861832521623, 0.051252766788820736, 0.024564813502365723, 0.10832224215846509, 0.03783996893616859, 0.03660751026473008, 0.04232757266436238, 0.040391083020949736, 0.044300549998297356, 0.010649557552824263, 0.04742479133710731, 0.04014619284134824, 0.015600474798702635, 0.05382353665481787, 0.019414683411014266, 0.04861298089963384, 0.02445022590109147, 0.05927699363382999, 0.09343357975012623, 0.03808272544119973, 0.05960435126326047, 0.024065427896857727, 0.07686003431444988, 0.029783390018565115, 0.011894101171492366, 0.04954025360348169, 0.0036096866278967354, 0.06869482167530805, 0.015210776764433831, 0.04053239164932165, 0.045807061542291194, 0.06676493343547918, 0.03815848387603182, 0.0037766158175145392, 0.006781394340578117, 0.06165674582007341, 0.030800727909081616, 0.04381010541692376, 0.04250837468134705, 0.046922379624447785, 0.07576574498671107, 0.03682893002405763, 0.04499739327002317, 0.019181335483153816, 0.009062917251867475, 0.02213597752415808, 0.02363149786106078, 0.04561532769002952, 0.04509736427280586, 0.012030272282572696, 0.20603165379725397, 0.22777131147449836, 0.13781008485239, 0.1633712390321307, 0.19524599192664027, 0.25392668845597655, 0.18524510669521987, 0.12047540760249831, 0.13371108449064195, 0.15971065498888493, 0.30882047256454825, 0.20665682415710762, 0.10657436563633382, 0.1853539649164304, 0.06459370619268157, 0.31811251770704985, 0.2370343534857966, 0.14154503209283575, 0.09470314951613545, 0.1321044089854695, 0.1917789748404175, 0.1581557813915424, 0.20066712837433442, 0.1958780494169332, 0.10033957558334805, 0.2269714989233762, 0.11241492684348486, 0.11039539458579384, 0.13363010133616626, 0.19100087753031403, 0.1442143740132451, 0.07363825992797501, 0.164613920787815, 0.1519777433713898, 0.16177857527509332, 0.16586035781074315, 0.1387471501948312, 0.1330097104073502, 0.08716675860341638, 0.21705691062379628, 0.11932270383113064, 0.17040164850186557, 0.21041718253400177, 0.17084255843656138, 0.165152482513804, 0.15236164152156562, 0.12337549807853065, 0.07829119189409539, 0.10910310025792569, 0.12654089892748743, 0.16224780556512997, 0.14143476379103959, 0.21198060567257926, 0.206912761204876, 0.24033558962401003, 0.1358268881449476, 2.248025396838784, 24.069679230451584, 50.3787986934185, 88.64829316735268, 124.40354615449905, 128.4381240606308, 130.68579465150833, 127.91005879640579, 133.77170026302338, 123.01972880959511, 119.17907729744911, 119.11170691251755, 117.7003638446331, 107.17910081148148, 93.08106690645218, 72.88827404379845, 95.71080699563026, 107.86061704158783, 85.1707349717617, 92.53377467393875, 64.08212497830391, 57.32996329665184, 60.88426977396011, 68.8596922159195, 56.34408339858055, 47.346014231443405, 73.88753682374954, 76.58176705241203, 40.14224298298359, 52.423142194747925, 62.102890983223915, 54.491743594408035, 54.05458465218544, 68.82365494966507, 85.02144858241081, 72.03862443566322, 110.42281195521355, 80.49479708075523, 76.72234430909157, 120.27232423424721, 97.50985085964203, 89.8755969107151, 122.26829633116722, 111.05469524860382, 131.1919578909874, 149.89592224359512, 142.38864988088608, 153.35866123437881, 162.72505223751068, 144.44914251565933, 120.03137156367302, 93.65218386054039, 43.04404467344284, 12.85270867869258, 1.5835620579309762, 0.45185017108451575, 0.395286584389396, 0.15920271427603438, 0.15081534715136513, 0.16995162499370053, 0.14913934021024033, 0.14938340289518237, 0.23086372209945694, 0.16284061828628182, 0.17453267995733768, 0.21297693892847747, 0.22658216825220734, 0.20373616134747863, 0.1536947168642655, 0.11265351990005001, 0.15520093525992706, 0.1870281164883636, 0.09280093596316874, 0.19319410203024745, 0.10361187538364902, 0.09354239344247617, 0.125040142738726, 0.09977582536521368, 0.12249398248968646, 0.12738602701574564, 0.17471475846832618, 0.13361453107791021, 0.11499644300783984, 0.16513033682713285, 0.16253780719125643, 0.08617486339062452, 0.11875293479533866, 0.2268009979161434, 0.19254556886153296, 0.12442545892554335, 0.16646250674966723, 0.12861912022344768, 0.23074429569533095, 0.15283269749488682, 0.18648476048838347, 0.13011362752877176, 0.0953409809153527, 0.15056806354550645, 0.1509501805412583, 0.15750393824419007, 0.10457044074428268, 0.2306098779081367, 0.14316871762275696, 0.19014396413695067, 0.13184476119931787, 0.14343872579047456, 0.11993585882009938, 0.0952543129096739, 0.15751857339637354, 0.1551755834952928, 0.13642915582749993, 0.13534581317799166, 0.09779737840290181, 0.08389151247683913, 0.1740667299600318, 0.2282530692173168, 0.12801924225641415, 0.19921201426768675, 0.13411421910859644, 0.15414600202348083], [0.05991953767079394, 0.023126134256017394, 0.057443313708063215, 0.028284771215112414, 0.008419978948950302, 0.08105699074803852, 0.04221861054247711, 0.019635761782410555, 0.09909401429467835, 0.028284554136916995, 0.01215716469232575, 0.0845606328221038, 0.03509406706143636, 0.05873946720384993, 0.08785049183643423, 0.019767982812481932, 0.029030384721409064, 0.03494174867228139, 0.036206412842147984, 0.041305182603537105, 0.056697010004427284, 0.10171280111535452, 0.10833846550667658, 0.014991561183705926, 0.06015198945533484, 0.03441072716668714, 0.030233240977395326, 0.013480034576787148, 0.01629073707590578, 0.03346836660057306, 0.0429081770562334, 0.029092548866174184, 0.0290327447510208, 0.03797697681875434, 0.06374811797286384, 0.01802453691198025, 0.11741478316253051, 0.015355787782027619, 0.012600596073752968, 0.060112299397587776, 0.05119032248330768, 0.027982605788565706, 0.019110118992102798, 0.04012320852780249, 0.05767228110926226, 0.02211528830230236, 0.019378336728550494, 0.055775266300770454, 0.02335312939976575, 0.030044076811464038, 0.06753062203642912, 0.051544916932471097, 0.035737390353460796, 0.07410769801936112, 2.1576527087017894, 16.469412557780743, 56.3219989836216, 84.55815464258194, 95.7845838367939, 89.91527438163757, 85.1414005458355, 89.3225821852684, 75.00410690903664, 76.66436702013016, 66.222223341465, 68.25272038578987, 70.94207167625427, 52.613853961229324, 45.524935349822044, 35.2591098099947, 25.662211775779724, 20.922045931220055, 19.376693554222584, 18.497941307723522, 28.443086855113506, 20.07214553654194, 53.09693343937397, 38.29895429313183, 33.33868905901909, 53.54158937931061, 31.443234868347645, 45.54204203188419, 30.957679823040962, 26.32224775850773, 51.53272457420826, 44.3607310205698, 67.7454400062561, 62.69261173903942, 38.5999171435833, 47.20595374703407, 43.57579194009304, 65.23999124765396, 27.332151867449284, 30.620865896344185, 25.405368357896805, 26.129592396318913, 28.4773401170969, 26.8142244592309, 23.673643581569195, 42.328398674726486, 42.98554681241512, 72.86210104823112, 84.57636326551437, 89.93526890873909, 94.9993559718132, 94.34491708874702, 110.17175182700157, 100.74919983744621, 97.66119673848152, 84.8141773045063, 58.539077416062355, 32.95668415725231, 5.124582191929221, 0.13815754355164245, 0.11522610060637817, 0.0323990097240312, 0.05222797110036481, 0.03592596265661996, 0.048834998087841086, 0.015260092477547005, 0.056253417205880396, 0.056339725269936025, 0.02362387971516, 0.03700669294630643, 0.015386075756396167, 0.03457045961113181, 0.04985152147128247, 0.03802223669481464, 0.02026691199716879, 0.04384750594908837, 0.04065061206347309, 0.050076340266969055, 0.05147665047843475, 0.016003908131096978, 0.031407222122652456, 0.039895580703159794, 0.0029360194685068564, 0.06010728619003203, 0.021889647578063887, 0.03180351784976665, 0.08883893606252968, 0.03183226865075994, 0.010734714360296493, 0.04038523489725776, 0.029121598381607328, 0.00866795646288665, 0.029007012635702267, 0.03497570563922636, 0.007571171199742821, 0.037360689966590144, 0.03919294125807937, 0.027708079796866514, 0.010008538629335817, 0.02932895629783161, 0.038116815994726494, 0.02744672507105861, 0.04396460572024807, 0.05859274460817687, 0.02955758602183778, 0.019824155970127322, 0.07381951465504244, 0.02096703370625619, 0.056370802703895606, 0.014826348906353815, 0.02967075983178802, 0.012909637498523807, 0.07764595386106521, 0.010190911216341192, 0.06248497520573437, 0.023657781021029223, 0.06233992986381054, 0.033965865295613185, 0.057041845211642794, 0.01747966878610896, 0.023120026380638592, 0.06735212067724206, 0.016943411428655963, 0.05025835940614343, 0.043074273417005315, 0.04060560080688447, 0.08366277514141984, 0.08897330932086334, 0.04098356919712387, 0.009402486921317177, 0.047541004241793416, 0.012522818069555797, 0.002368648497395043, 0.05087919191282708, 0.056318748465855606, 0.018238360789837316, 0.0512019370944472, 0.03711092758749146, 0.04406918174936436, 0.06503243421320803, 0.08570932899601758, 0.11421097617130727, 0.09012172347865999, 0.08102714898996055, 0.01288696952542523, 0.007031813520370633, 0.04998141957912594, 0.06279127439484, 0.021092961324029602, 0.015955920862325, 0.020145559719821904, 0.028973847911402117, 0.05126307893078774, 0.016294956185447518, 0.0966077008342836, 0.093014229205437, 0.0468771383020794, 0.0862626668822486, 0.035769532769336365, 0.03444512571149971, 0.022459015854110476, 0.05133266640768852, 0.03507151690428145, 0.037987934629200026, 0.03373842300788965, 0.0727289509086404, 0.0042330660926381825, 0.04061514111526776, 0.06732893598382361, 0.042232893174514174, 0.04848417745961342, 0.027451871865196154, 0.04011741606518626, 0.04886607923253905, 0.044797803784604184, 0.07609071661136113, 0.63419891288504, 10.695917811244726, 45.72304531931877, 82.60937601327896, 101.05408787727356, 103.45927521586418, 97.58619636297226, 102.08548173308372, 89.11183789372444, 92.10396453738213, 87.63842895627022, 105.78972816467285, 100.57807981967926, 88.8048143684864, 78.44634220004082, 67.24800109863281, 45.16290217638016, 21.900789812207222, 31.110038347542286, 32.730258107185364, 32.06031605601311, 29.009906239807606, 40.0745952129364, 24.745252579450607, 27.035488486289978, 40.63846975564957, 27.062892615795135, 33.01193319261074, 27.786501087248325, 31.83531492948532, 35.26479430496693, 29.754890464246273, 60.05815230309963, 57.752234637737274, 26.50996908545494, 32.166132777929306, 42.815220952034, 49.06223013997078, 36.34757660329342, 31.042637564241886, 26.845470182597637, 45.30888274312019, 38.565133810043335, 37.879608795046806, 45.875660330057144, 66.25255331397057, 80.1813443005085, 120.11369034647942, 127.47687444090843, 117.77198240160942, 115.49291789531708, 112.09514781832695, 126.79877802729607, 117.48685330152512, 118.71848121285439, 105.57919666171074, 75.51234483718872, 42.24131494760513, 6.346073197200894, 0.01583991019288078, 0.09170179298962466, 0.054751755596953444, 0.03532425900630187, 0.03911477455403656, 0.06259614150621928, 0.06635268524405546, 0.07884959122748114, 0.05397202185122296, 0.0251898243004689, 0.09402172436239198, 0.04895986814517528, 0.08596778192440979, 0.02785160373605322, 0.024547933353460394, 0.02565372040407965, 0.034327421089983545, 0.035529288434190676, 0.03339431881613564, 0.023960445541888475, 0.01860792064690031, 0.03184436936862767, 0.024891473512980156, 0.05441951463581063, 0.04880584281636402, 0.025435892639507074, 0.043569464032771066, 0.02338194699404994, 0.01735270030621905, 0.04820337475393899, 0.0401290047011571, 0.02257351625303272, 0.04927731068164576, 0.013609002216981025, 0.06685531960101798, 0.01949015240825247, 0.05086134697194211, 0.058175579688395374, 0.05950567530817352, 0.03923199306882452, 0.056075335160130635, 0.03656375323771499, 0.02587979157397058, 0.02501522292732261, 0.08484975129249506, 0.046735291616641916, 0.051734676671912894, 0.057483489872538485, 0.05867648855200969, 0.01858819065091666, 0.07694780812016688, 0.050610994585440494, 0.022030063773854636, 0.05677039356669411, 0.027365183450456243, 0.009155141160590574, 0.050467307373764925, 0.026291971116734203, 0.02553850568801863, 0.043381170034990646, 0.009796568265301175, 0.035878539420082234, 0.07580177625641227, 0.11682680182275362, 0.12708956870483235, 0.1795833808137104, 0.0881490133178886, 0.27329395234119147, 0.18830535263987258, 0.1831951315398328, 0.1492914359550923, 0.19951565656811, 0.15671500557800755, 0.08966706896899268, 0.2095826671575196, 0.16217379859881476, 0.2599886991083622, 0.25044194888323545, 0.22034694033209234, 0.09061234988621436, 0.15479401568882167, 0.14261992910178378, 0.18509476241888478, 0.2160545511287637, 0.2138629148248583, 0.12448287889128551, 0.038113672999315895, 0.15688224113546312, 0.13517269981093705, 0.1493401505285874, 0.10008547906181775, 0.09197921521263197, 0.1313664618646726, 0.13714237458771095, 0.11021158687071875, 0.1649762224406004, 0.1766654194216244, 0.177399403473828, 0.18913817591965199, 0.20749074581544846, 0.12315004845731892, 0.1175279903691262, 0.13674067973624915, 0.19158064329531044, 0.15631813468644395, 0.18504057079553604, 0.19704092061147094, 0.10094334240420721, 0.15406092221383005, 0.17819835513364524, 0.1777271952596493, 0.09884197352221236, 0.09523229338810779, 0.15555038291495293, 0.12312469669268467, 0.14946903189411387, 0.14188095781719312, 3.974555851891637, 29.097130559384823, 80.94995945692062, 112.59905397891998, 121.8272539973259, 115.16620382666588, 103.3819417655468, 111.19604766368866, 95.0165918469429, 100.73818042874336, 87.50107392668724, 87.62012153863907, 91.87462404370308, 68.61775919795036, 61.90688610076904, 52.32351154088974, 37.86811821162701, 29.825754761695862, 24.737130515277386, 25.583635792136192, 40.780559331178665, 29.3742610886693, 73.85001763701439, 53.50918851792812, 47.50410854816437, 75.51322638988495, 47.25651763379574, 65.78422084450722, 46.19064062833786, 37.15372994542122, 74.39852580428123, 66.34628668427467, 91.10477015376091, 82.60859325528145, 54.74689990282059, 68.51549908518791, 64.0825505554676, 89.73957940936089, 48.24767924845219, 52.41387829184532, 41.78705312311649, 46.716980785131454, 49.28911216557026, 47.215517833828926, 40.31011417508125, 61.23526453971863, 68.52761283516884, 103.16252633929253, 112.67459392547607, 119.75748986005783, 119.7129562497139, 121.10152333974838, 139.60184901952744, 134.32444900274277, 134.48901057243347, 125.52611991763115, 93.2374969124794, 57.93112523853779, 9.751130808144808, 0.29486477142199874, 0.2679194079246372, 0.13110421656165272, 0.16747570160077885, 0.14664395770523697, 0.22171219519805163, 0.18331071361899376, 0.22443365072831511, 0.1972380795632489, 0.11575867320061661, 0.18350846628891304, 0.14118032588157803, 0.12119633727706969, 0.10432781782583334, 0.14690479292767122, 0.11533679193235002, 0.16378890490159392, 0.17462513671489432, 0.11091978129115887, 0.0999274906644132, 0.1370751953800209, 0.13613104994874448, 0.1512081065448001, 0.13353381509659812, 0.18984416616149247, 0.08569258614443243, 0.13222117850091308, 0.21283803856931627, 0.13447439821902663, 0.24168512580217794, 0.14900103356922045, 0.09839380538323894, 0.13352032285183668, 0.06800698436563835, 0.20913317799568176, 0.15005409659352154, 0.19514026556862518, 0.14421413652598858, 0.08781009673839435, 0.160974859027192, 0.16636458778521046, 0.11113396511063911, 0.1384051685454324, 0.10380782463471405, 0.14874549728119746, 0.14134689350612462, 0.23584898037370294, 0.17836749058915302, 0.20359349087812006, 0.16096173785626888, 0.1338295015739277, 0.10781884338939562, 0.17682573816273361, 0.2039698784938082, 0.1733472474734299, 0.1316184803727083, 0.11179719280335121, 0.18910972197772935, 0.1550042661256157, 0.1912177776102908, 0.08196451861294918, 0.12105670219170861, 0.22453295008745044], [0.03824749706836883, 0.035847740291501395, 0.008028074880712666, 0.04956826596753672, 0.033313480380456895, 0.04785945238836575, 0.07397558088996448, 0.012835228844778612, 0.04853006816119887, 0.013476887870638166, 0.019485660559439566, 0.02989801658259239, 0.04503799988015089, 0.02514030820748303, 0.005540273878068547, 0.02456156289554201, 0.023034171026665717, 0.0695742444077041, 0.041867930922308005, 0.024015336639422458, 0.012234531732246978, 0.018984454836754594, 0.056953815364977345, 0.05300065073242877, 0.08289039978990331, 0.023227407727972604, 0.030786649367655627, 0.04754894151119515, 0.055936835560714826, 0.05800767248729244, 0.009644160818425007, 0.043638754650601186, 0.07567630877019837, 0.05506021072505973, 0.041734778496902436, 0.0210292442352511, 0.058970082172891125, 0.03793545736698434, 0.029625004572153557, 0.11296710697934031, 0.05088560406875331, 0.02601977546873968, 0.05548064851609524, 0.06454982300056145, 0.03336440655402839, 0.03326427598949522, 0.0706018517666962, 0.14177532051689923, 0.04004133108537644, 0.01445704787329305, 0.0423329680779716, 0.018177907295466866, 1.0163345513865352, 10.738483127206564, 27.61735126376152, 49.49753098189831, 73.09260427951813, 89.90958228707314, 78.66646438837051, 83.03538635373116, 83.2919029891491, 52.076463997364044, 56.25620171427727, 45.549949407577515, 43.89957256615162, 20.955106057226658, 21.427726596593857, 48.92006076872349, 55.960140600800514, 36.62693001329899, 65.99730581045151, 114.03644844889641, 156.64831191301346, 115.72561740875244, 145.1399302482605, 134.47233706712723, 126.90588667988777, 157.89195477962494, 169.9422025680542, 109.35059309005737, 138.1503877043724, 140.5518588423729, 121.71590477228165, 167.3041409254074, 124.67907696962357, 115.14373183250427, 99.44391667842865, 140.43076694011688, 145.86278825998306, 126.25826463103294, 114.95675146579742, 115.67237466573715, 117.67721548676491, 121.30349010229111, 154.81673419475555, 111.35376960039139, 104.6519324183464, 109.99556288123131, 101.9931922852993, 71.37115985155106, 52.447890266776085, 31.350213959813118, 30.760375410318375, 30.97685929387808, 46.34752281010151, 50.18203765153885, 63.97188529372215, 74.22235205769539, 86.31270289421082, 95.0016738474369, 102.6621387898922, 107.17135682702065, 82.77358800172806, 39.49845492839813, 7.199716391041875, 0.858132237335667, 0.17002239619614556, 0.1934107200941071, 0.12618696870049462, 0.06116271295468323, 0.006813258914917242, 0.027293510538584087, 0.03083264768065419, 0.0464608379843412, 0.04000668392109219, 0.07042053024633788, 0.03416038220166229, 0.09656784008257091, 0.0176498098517186, 0.03042739237571368, 0.03276745635957923, 0.04892724704404827, 0.05930407831328921, 0.008043481866479851, 0.010827395617525326, 0.015451171384484041, 0.007100949214873253, 0.0810461924993433, 0.034174048851127736, 0.011603617149376078, 0.03951377540943213, 0.10348881987738423, 0.05679966387106106, 0.017250478740606923, 0.08381480409298092, 0.057062168925767764, 0.034353080845903605, 0.008910713895602385, 0.03910623985575512, 0.04519973612332251, 0.023209861501527485, 0.02984769525937736, 0.04758608229167294, 0.017829613680078182, 0.02528706048906315, 0.04997338583052624, 0.10746789659606293, 0.057049489332712255, 0.005227254541750881, 0.032433393425890245, 0.07362454503891058, 0.04379152574983891, 0.03775354954996146, 0.05559663877647836, 0.0385962359723635, 0.06845089999842457, 0.0954069578438066, 0.09376799149322324, 0.035360308829694986, 0.018848641811928246, 0.006919526576893986, 0.021983699953125324, 0.0038422970465035178, 0.0267210215315572, 0.06347778326016851, 0.0063191425579134375, 0.029394411867542658, 0.03676910178910475, 0.04887862523901276, 0.01869859068392543, 0.007679475129407365, 0.020487897600105498, 0.07599436357850209, 0.05043311291956343, 0.05354800319764763, 0.04626285153790377, 0.054932305283728056, 0.03264981853135396, 0.07108511606929824, 0.043681235183612444, 0.055521010217489675, 0.007568149267171975, 0.0942207089974545, 0.033161425453727134, 0.060271378752077, 0.06183820092701353, 0.049093269190052524, 0.03679385241412092, 0.03632302650657948, 0.04342228130553849, 0.04761350093758665, 0.10141433158423752, 0.026694602929637767, 0.04975011441274546, 0.025066596244869288, 0.034128510669688694, 0.06543169482029043, 0.017759671827661805, 0.014955140286474489, 0.01451642339816317, 0.05578771211730782, 0.0438451756053837, 0.033012287167366594, 0.05130449448188301, 0.037583219236694276, 0.09813058044528589, 0.050014497101074085, 0.0822697342664469, 0.05528813911951147, 0.04545528725429904, 0.04362261293863412, 0.010400623596069636, 0.03728579613380134, 0.061877163680037484, 0.07627926665009, 0.03153860081511084, 0.09884288636385463, 0.04749766281747725, 0.2030988346086815, 5.601781010627747, 26.35012686252594, 57.29472018778324, 90.0771988928318, 103.57320830225945, 88.34361031651497, 95.46800762414932, 93.06257709860802, 73.69332164525986, 78.94048288464546, 74.29067239165306, 69.41097423434258, 38.362844064831734, 43.62298160791397, 43.086530193686485, 42.784279212355614, 25.872182808816433, 42.27621607482433, 48.88786889612675, 54.27085384726524, 54.79472413659096, 81.27491801977158, 67.42254093289375, 87.0516948401928, 89.55020517110825, 110.0954519212246, 93.12237828969955, 76.86859846115112, 85.66413089632988, 78.91514584422112, 79.96246844530106, 81.07532232999802, 80.46890527009964, 71.81173101067543, 81.26318424940109, 79.83154267072678, 76.91666588187218, 78.40050145983696, 99.33064475655556, 84.55759987235069, 79.3791389465332, 82.02116757631302, 61.626795530319214, 70.69166511297226, 76.49762436747551, 63.67673613131046, 51.185681596398354, 40.50791256129742, 37.242470383644104, 44.9946092069149, 58.288921639323235, 72.55094334483147, 84.11917939782143, 103.35035786032677, 96.96251302957535, 109.75947394967079, 103.40391218662262, 113.08246403932571, 124.13695245981216, 99.972103536129, 46.3716971129179, 8.55786468833685, 0.5045645346399397, 0.10747743319370784, 0.15090566652361304, 0.10460791920195334, 0.058268949287594296, 0.022831969181424938, 0.04599483603669796, 0.0627914747747127, 0.044008696713717654, 0.04249136465659831, 0.05478783881699201, 0.05543794162804261, 0.0193588367983466, 0.07186241185991094, 0.059870181139558554, 0.03354988781211432, 0.089738307724474, 0.011583976211113622, 0.020357314861030318, 0.04888628420303576, 0.008531403145752847, 0.013559812668972882, 0.008687684603501111, 0.08685585809871554, 0.013002415234950604, 0.03683216949866619, 0.11627266983850859, 0.05292857335007284, 0.03470891468168702, 0.06703016217215918, 0.0142701769436826, 0.006850639501863043, 0.04972028007614426, 0.05816862947540358, 0.03012761295394739, 0.019675396179081872, 0.016709031915524974, 0.027823025484394748, 0.02091355825541541, 0.020541512203635648, 0.03160615480737761, 0.036515101746772416, 0.04501456656726077, 0.07761561486404389, 0.017920203936228063, 0.065113090822706, 0.00891628556928481, 0.021425026025099214, 0.07505887158913538, 0.025418075529159978, 0.047511626326013356, 0.0666227305191569, 0.03748669922060799, 0.06304220936726779, 0.03314617802971043, 0.015425646142830374, 0.02409704709862126, 0.032664835889590904, 0.01675148647336755, 0.06306585419224575, 0.0396177131915465, 0.08824436445138417, 0.13180654059397057, 0.1556227868422866, 0.13948919397080317, 0.13891091250116006, 0.1409460892318748, 0.19187886791769415, 0.08954533448559232, 0.12866029457654804, 0.15705026336945593, 0.11094333705841564, 0.1783806414459832, 0.18251052999403328, 0.1416442423942499, 0.10187308274907991, 0.10685195855330676, 0.2000976784620434, 0.0911202015413437, 0.14282692893175408, 0.16093166603241116, 0.08025628761970438, 0.16274924506433308, 0.17102080746553838, 0.1393787475535646, 0.22300721320789307, 0.1238980442576576, 0.10532487838645466, 0.14490952889900655, 0.08194925263524055, 0.21799468842800707, 0.12704014166956767, 0.12404345325194299, 0.14478180528385565, 0.19106710678897798, 0.13127473241183907, 0.16696709295501933, 0.2312926240847446, 0.1845849960227497, 0.14602325507439673, 0.21430884167784825, 0.28124214615672827, 0.12547236954560503, 0.12709118658676744, 0.2000374605995603, 0.12418878060998395, 0.12555885943584144, 0.238635819114279, 0.30153068248182535, 0.1695290906354785, 0.1548760526929982, 0.15628184366505593, 0.17015344463288784, 2.2404476534575224, 18.0042926967144, 52.037842869758606, 75.13281360268593, 96.11968785524368, 109.5405524969101, 97.6436872780323, 103.72865036129951, 106.30824074149132, 76.7029045522213, 78.4390389919281, 64.35837015509605, 61.47730775177479, 27.992157451808453, 31.3288477063179, 64.92978349328041, 73.99856686592102, 59.41905699670315, 95.94453245401382, 163.63457143306732, 221.99799567461014, 164.36664015054703, 209.53724831342697, 187.40732699632645, 185.1073256134987, 233.15267711877823, 243.08139234781265, 151.22089594602585, 200.15074878931046, 201.16099298000336, 177.28859156370163, 236.1265343427658, 186.8503376841545, 170.71299880743027, 143.07651937007904, 199.9636772274971, 206.98167264461517, 184.3729618191719, 162.0181381702423, 167.05899327993393, 168.147254884243, 173.26685696840286, 219.99108016490936, 155.6305593252182, 148.95320802927017, 156.6805949807167, 137.906152009964, 102.176783233881, 70.33758491277695, 42.847994193434715, 47.41931989789009, 47.99352988600731, 71.6095894575119, 75.47489404678345, 85.35139247775078, 103.07415068149567, 113.97458016872406, 119.87430319190025, 126.18717044591904, 138.73917371034622, 118.54660883545876, 62.00579859316349, 14.677862841635942, 1.2428205669857562, 0.3175058861961588, 0.3270683402661234, 0.28133304440416396, 0.16093591111712158, 0.23407152184518054, 0.20300483418395743, 0.12853657855885103, 0.13571271614637226, 0.17373726092046127, 0.1866648203576915, 0.12493772635934874, 0.13361243822146207, 0.14182369370246306, 0.12393292519846, 0.1279044765396975, 0.1529897953150794, 0.10056165585410781, 0.15775677311467007, 0.1040896849008277, 0.09551789407851174, 0.08068511539022438, 0.17312193143879995, 0.16918601060751826, 0.07390622718958184, 0.13927793421316892, 0.18619956797920167, 0.1296892823302187, 0.1104812091216445, 0.15707367070717737, 0.09886523985187523, 0.14857986476272345, 0.13359422591747716, 0.1079067136743106, 0.14414688310353085, 0.1595701219048351, 0.12442618623026647, 0.14669840165879577, 0.08528176287654787, 0.1307228417135775, 0.07902535406174138, 0.21568555530393496, 0.1820572855649516, 0.13544711633585393, 0.1358342354069464, 0.1852104187128134, 0.12655565282329917, 0.11104410586995073, 0.1320124272024259, 0.12771525856805965, 0.17579802690306678, 0.21167374245123938, 0.1379791906219907, 0.20063649251824245, 0.14898092136718333, 0.0980148944654502, 0.10283175943186507, 0.07752037505269982, 0.10502269811695442, 0.21538066619541496, 0.14179417106788605], [0.044237363545107655, 0.022671203296340536, 0.05248672459856607, 0.05236664139374625, 0.038589296891586855, 0.07367735626758076, 0.033532046581967734, 0.03225021282560192, 0.02843587804818526, 0.025458962300035637, 0.030384362653421704, 0.009171890505967895, 0.05264195962809026, 0.03805985616054386, 0.03620512150519062, 0.050847316670115106, 0.06762371704098769, 0.04817549226572737, 0.07737472114968114, 0.02771156418020837, 0.022373564970621374, 0.050675798920565285, 0.03950867314415518, 0.02769857474049786, 0.003806454096775269, 0.040642927124281414, 0.027510319705470465, 0.040604253808851354, 0.00804119605163578, 0.020933531304763164, 0.04900238949630875, 0.08395371929509565, 0.041854895098367706, 0.08121143910102546, 0.021278275598888285, 0.06011806217429694, 0.013992836356919724, 0.01929528298205696, 0.023853041930124164, 0.08377573001780547, 0.021796207474835683, 0.042626557988114655, 0.03189012277289294, 0.07675049331737682, 0.016983760142466053, 0.01971520126971882, 0.06921356805833057, 0.1103645063994918, 0.034519845139584504, 0.17393376678228378, 0.718746988568455, 9.170728102326393, 28.193292059004307, 66.67369991540909, 97.12404236197472, 60.6038486212492, 57.27980978786945, 76.35874181985855, 72.35010132193565, 41.17609530687332, 40.94129830598831, 43.05175065994263, 11.204109191894531, 19.131352119147778, 29.00056254118681, 70.40081351995468, 61.52280651032925, 92.28872582316399, 115.80203130841255, 105.43605834245682, 81.23363703489304, 44.60702620446682, 48.76045033335686, 42.653851211071014, 13.207354098558426, 20.241236463189125, 10.448989011347294, 9.890044704079628, 11.551709789782763, 7.631385577842593, 13.4004663862288, 12.620399594306946, 8.433626554906368, 9.855861738324165, 7.114520212635398, 4.662810070440173, 6.376642556861043, 8.059787414968014, 4.31278140284121, 4.214370958507061, 5.317555787041783, 4.925044924020767, 9.484955091029406, 7.946566790342331, 8.532236963510513, 14.786861892789602, 15.970182046294212, 31.624838523566723, 53.177055940032005, 80.87500467896461, 111.17375046014786, 121.60642504692078, 107.83260494470596, 61.64474956691265, 41.531813219189644, 22.76499453932047, 25.27842476963997, 43.467174768447876, 45.71636527776718, 86.68821394443512, 77.75389775633812, 84.6280100941658, 89.10862326622009, 99.013232588768, 79.29999679327011, 39.53455299139023, 18.42418346554041, 9.504346400499344, 6.306910598650575, 1.2974366988055408, 0.09881652527838014, 0.03776677833229769, 0.12011918413918465, 0.05704706993128639, 0.07159769520512782, 0.04739085663459264, 0.1191269772243686, 0.08479760799673386, 0.03047172456717817, 0.013637965457746759, 0.018582578159112018, 0.06939569109817967, 0.06622158485697582, 0.028664782366831787, 0.005633190303342417, 0.009670878134784289, 0.06175769645778928, 0.06917432328918949, 0.04571871999360155, 0.01083368253603112, 0.0335803455527639, 0.0385627502691932, 0.026826258072105702, 0.007180502343544504, 0.009706939090392552, 0.059365891793277115, 0.03442292436375283, 0.06563416754943319, 0.02123303242115071, 0.05067724981927313, 0.01006664972010185, 0.021027945476816967, 0.05116466272738762, 0.029362265740928706, 0.07048951287288219, 0.05098707420984283, 0.06570032259332947, 0.07520132683566771, 0.024828710083966143, 0.04152022360358387, 0.0722999895515386, 0.06630051968386397, 0.047358606607303955, 0.01563326844916446, 0.041597618474042974, 0.01565145477798069, 0.01560893899295479, 0.027662925676850136, 0.010388420832896372, 0.01099407920264639, 0.08724098821403459, 0.0383144091028953, 0.025377702695550397, 0.054325087476172484, 0.06823480143793859, 0.10282856077537872, 0.05739804641052615, 0.00421222287513956, 0.06780855634133331, 0.04559959787002299, 0.022528722074639518, 0.07851770278648473, 0.03134094462438952, 0.04642860280000605, 0.011149321653647348, 0.02574784328317037, 0.007502429307351122, 0.019200397546228487, 0.05146611569216475, 0.08804906829027459, 0.023982075435924344, 0.03620673196564894, 0.05966206066659652, 0.04513658677751664, 0.05887700572202448, 0.09422120623639785, 0.020642896997742355, 0.03205261971743312, 0.03293623187346384, 0.044956044512218796, 0.07206913709524088, 0.008857664251991082, 0.04854907456319779, 0.016933566839725245, 0.032588246249360964, 0.03068674330279464, 0.011944073685299372, 0.0333635419519851, 0.042732718502520584, 0.02747569295024732, 0.005535020864044782, 0.04185279110970441, 0.032505897543160245, 0.03007329702086281, 0.012647204803215573, 0.009744761719048256, 0.06306580966338515, 0.06419233046472073, 0.02983062029670691, 0.033394856873201206, 0.042999943616450764, 0.05455400292703416, 0.016169284608622547, 0.09701214905362576, 0.013702489632123616, 0.058529320667730644, 0.34682698315009475, 6.0243952833116055, 27.148260734975338, 69.08163070678711, 100.23415267467499, 70.90261459350586, 65.9778280556202, 88.51885691285133, 90.06637707352638, 63.659895434975624, 68.95506709814072, 55.70374175906181, 32.64561004936695, 30.826678052544594, 33.64892341196537, 32.3277723044157, 28.27200673520565, 65.59904158115387, 90.36315634846687, 80.76063081622124, 68.79609122872353, 53.04878242313862, 55.486328825354576, 43.94152991473675, 18.959392346441746, 20.72891179472208, 12.125707939267159, 13.748954236507416, 14.224746655672789, 9.643672574311495, 13.839222192764282, 12.818553261458874, 9.984383191913366, 11.724824700504541, 7.521928176283836, 5.290742525830865, 6.395691409707069, 6.249594949185848, 4.771555010229349, 5.510658100247383, 7.02952922321856, 7.282564295455813, 12.388688027858734, 9.376927837729454, 10.07441271096468, 15.071498919278383, 17.139983475208282, 28.05516567081213, 47.62254819273949, 64.8069740831852, 82.44986057281494, 82.5132791697979, 71.56720653176308, 38.89148689806461, 34.30922158062458, 27.10867825895548, 34.54052656888962, 77.43157625198364, 72.68170952796936, 111.53584823012352, 109.84096437692642, 93.8856965303421, 99.88324150443077, 115.09476006031036, 93.14741894602776, 43.72357361018658, 18.331523537635803, 9.057803861796856, 4.96402133256197, 0.6318432767875493, 0.10145477863261476, 0.0335562888358254, 0.028502469103841577, 0.04597710612870287, 0.06351117248414084, 0.08240204435423948, 0.06323577632429078, 0.07508349604904652, 0.05154490951099433, 0.050309619546169415, 0.06052590942999814, 0.01785614360414911, 0.026767416893562768, 0.05545171588892117, 0.02012657558225328, 0.10425566622870974, 0.021236667089397088, 0.021180980038479902, 0.0691142538562417, 0.06562195922015235, 0.04891119067906402, 0.008201051878131693, 0.04830288562516216, 0.07506923197070137, 0.026418540692247916, 0.07227653768495657, 0.07145108393160626, 0.019139723262924235, 0.03581295211915858, 0.03780695820751134, 0.05230317292443942, 0.039294964299187995, 0.06370092480210587, 0.041723765025381, 0.016136496524268296, 0.057442775650997646, 0.10546619072556496, 0.0211615710213664, 0.028915628281538375, 0.029470645276887808, 0.04291301214834675, 0.07947413076180965, 0.0805803612456657, 0.0427562408731319, 0.014832004999334458, 0.05081635055830702, 0.032232831727014855, 0.13452536892145872, 0.02181204119551694, 0.022505689521494787, 0.1249888158054091, 0.039096053878893144, 0.009257315414288314, 0.01618206995772198, 0.08850244630593807, 0.05269357599900104, 0.14695730729727075, 0.08656734818941914, 0.11939622840145603, 0.09210214455379173, 0.17265375499846414, 0.23593573743710294, 0.14763747079996392, 0.11960893534705974, 0.060422658134484664, 0.08980774306110106, 0.15031518414616585, 0.08789561441517435, 0.2737996220821515, 0.22880573174916208, 0.19580006453907117, 0.1626679056789726, 0.15053468174301088, 0.16262208548141643, 0.17540926026413217, 0.15628362481947988, 0.07321575525566004, 0.11141510549350642, 0.14977021026425064, 0.12638668064028025, 0.16054327046731487, 0.24620153970317915, 0.0924270271207206, 0.20170347823295742, 0.11773586593335494, 0.12233695146278478, 0.11817336941021495, 0.16074020677478984, 0.06948011039639823, 0.2338640470406972, 0.14462108578300104, 0.17174892855109647, 0.11079351970693097, 0.12626621522940695, 0.13872973941033706, 0.20378205575980246, 0.20169858005829155, 0.1624539593467489, 0.12487574218539521, 0.1512252798420377, 0.22041585616534576, 0.13619903067592531, 0.0739819707814604, 0.271318830200471, 0.0882692560844589, 0.20723338384414092, 1.6584848938509822, 14.767142850905657, 48.43527518212795, 94.72019255161285, 124.60937350988388, 85.16686677932739, 78.49871098995209, 100.29069364070892, 101.32429137825966, 61.58377043902874, 61.71839341521263, 56.87899209558964, 21.17933202534914, 30.147403702139854, 44.66273121535778, 103.99908944964409, 90.08950263261795, 131.12435191869736, 154.665167927742, 150.43421655893326, 120.01777589321136, 68.08799162507057, 76.2733756005764, 63.12450796365738, 22.79545370489359, 32.69488960504532, 19.042320996522903, 16.79396264255047, 19.521461986005306, 13.27093418687582, 21.75937470048666, 20.50665982067585, 13.718602415174246, 18.332828767597675, 12.021624874323606, 7.587098479270935, 12.568004205822945, 14.933544471859932, 7.709175478667021, 7.595499828457832, 8.898262772709131, 8.948506526648998, 16.476445980370045, 14.158869590610266, 15.722935013473034, 25.779942758381367, 26.061566546559334, 49.96722377836704, 83.00355926156044, 123.22945475578308, 165.87552398443222, 175.75449228286743, 158.36357027292252, 86.27088993787766, 60.84566004574299, 34.14914757013321, 37.86343306303024, 66.58312037587166, 65.4945395886898, 116.29013791680336, 106.73759490251541, 108.84070605039597, 107.88017839193344, 127.82193392515182, 111.46807506680489, 60.45715369284153, 26.902795806527138, 16.13136749714613, 10.910834278911352, 1.9468127097934484, 0.4986671917140484, 0.18000069045228884, 0.23028912168229, 0.17657088465057313, 0.1898449973668903, 0.19745659752516076, 0.2269383694510907, 0.1881399130797945, 0.21644806751282886, 0.13540273590479046, 0.09137481014477089, 0.18292283755727112, 0.1579784823115915, 0.1574381988029927, 0.11023189945262857, 0.14999245380749926, 0.13606955559225753, 0.08630644617369398, 0.12577696179505438, 0.1887678145430982, 0.20767494686879218, 0.1081680684001185, 0.1276808526017703, 0.1421672190190293, 0.10079040803248063, 0.1818428494152613, 0.14579164562746882, 0.24458055559080094, 0.1146127526590135, 0.12569519196404144, 0.16041887167375535, 0.07546536813606508, 0.19154482724843547, 0.08641461419756524, 0.26646182988770306, 0.1320132880937308, 0.2118129693553783, 0.19032948621315882, 0.12865624245023355, 0.15704428165918216, 0.19351864320924506, 0.15960133663611487, 0.20100965921301395, 0.08871156867826357, 0.15818644693354145, 0.11384750934666954, 0.09363292061607353, 0.17332235584035516, 0.07161818590248004, 0.14061777794267982, 0.21446095226565376, 0.10242676202324219, 0.18577523762360215, 0.12757738237269223, 0.22243541810894385, 0.21546010568272322], [0.0542450542707229, 0.03502124010992702, 0.03663144823804032, 0.028244678542250767, 0.0697851182485465, 0.053507418851950206, 0.06910122174303979, 0.07715818472206593, 0.002023945485234435, 0.02147885214071721, 0.04501109702687245, 0.012268510963622248, 0.02334833512577461, 0.028956720998394303, 0.04644570188247599, 0.07717549160588533, 0.0724808732047677, 0.09706596960313618, 0.02482038504240336, 0.01981527060706867, 0.07735269420663826, 0.0059546251304709585, 0.09614294569473714, 0.06647249756497331, 0.032284830303979106, 0.071197907673195, 0.06098279409343377, 0.0627505527518224, 0.04750147745653521, 0.06921069594682194, 0.020672319442383014, 0.05776754318503663, 0.019047010464419145, 0.03998090913228225, 0.029397194921330083, 0.012182925565866753, 0.099840867187595, 0.07778037164825946, 0.057502919298713095, 0.07271832335391082, 0.16232013527769595, 0.029410987735900562, 0.08283225994091481, 0.06292051199125126, 0.055585573354619555, 0.010038423060905188, 0.1750425502541475, 0.2166902451426722, 1.8724167393520474, 6.560408771038055, 21.154012084007263, 47.96521380543709, 77.31367617845535, 79.49146091938019, 83.14228221774101, 65.20945608615875, 34.33275751769543, 53.284913152456284, 24.82328899204731, 38.336819261312485, 47.41019278764725, 31.797157377004623, 51.68181337416172, 65.8477534353733, 99.94824081659317, 91.21316313743591, 101.36336848139763, 42.39622123539448, 24.44163177162409, 11.563163325190544, 3.1884723203256726, 0.8261598029639572, 0.21224047610303387, 0.9875305532477796, 0.11838034697575495, 0.2864760090596974, 0.017204237374244258, 0.038709090658812784, 0.11983491931459866, 0.15823786292457953, 0.2429655086598359, 0.20758228230988607, 0.212667329760734, 0.16759656777139753, 0.16357605694793165, 0.03623609874921385, 0.19491334649501368, 0.08537257948773913, 0.21423067868454382, 0.09830370123381726, 0.07264292857144028, 0.021373359559220262, 0.2690362511202693, 0.3552139940438792, 0.5797563248779625, 0.8309075888246298, 0.7382246840279549, 0.40459528332576156, 0.8309432119131088, 0.2647209889255464, 1.1908769980072975, 9.54294852912426, 35.12026906013489, 89.53920856118202, 80.47069117426872, 93.85129317641258, 86.33937746286392, 37.526824325323105, 31.864903941750526, 27.820672653615475, 31.725856103003025, 67.50294461846352, 76.37818917632103, 67.78367355465889, 88.50199341773987, 98.78374770283699, 89.83977243304253, 78.07471454143524, 65.27253270149231, 31.769823543727398, 8.47421407699585, 1.1236410308629274, 0.024129261873895302, 0.15451899060280994, 0.028908386775583494, 0.05459437204990536, 0.1065766959800385, 0.09252365474822, 0.02779414295218885, 0.07345848949626088, 0.0395600817137165, 0.06193503264512401, 0.04696537223935593, 0.10981593310134485, 0.11224557616515085, 0.011160950180055806, 0.005592613842964056, 0.06668721573078074, 0.07151533907745034, 0.027815462999569718, 0.02941768747405149, 0.03047876940399874, 0.05055732617620379, 0.05281293189909775, 0.07889564891229384, 0.04793631662323605, 0.051728906473726965, 0.043082774718641303, 0.010664682522474322, 0.06404757456039079, 0.0313281796843512, 0.04004627378890291, 0.06834170038928278, 0.020332467756816186, 0.09780387219507247, 0.06785370118450373, 0.04228868412610609, 0.05004953760362696, 0.004778633228852414, 0.018102024550898932, 0.07241422834340483, 0.03037287235201802, 0.047354406051454134, 0.06970551548874937, 0.017759853653842583, 0.0605663750320673, 0.02927904686657712, 0.03187133159372024, 0.01444693332814495, 0.02934386418928625, 0.008693080944794929, 0.04085657659743447, 0.04607551862136461, 0.019737790389626753, 0.038158290917635895, 0.06224969583854545, 0.018427903451083694, 0.03579017931770068, 0.005257267457636772, 0.07354932095040567, 0.07031352739431895, 0.0704409541503992, 0.037138876868993975, 0.00973866126514622, 0.011098001214122633, 0.02230562320619356, 0.007205781748780282, 0.04973857030563522, 0.07178854590165429, 0.039770072398823686, 0.020953684324922506, 0.08215519119403325, 0.01345996040981845, 0.019248457174398936, 0.009194168851536233, 0.028212756915309, 0.05736148450523615, 0.04507866586209275, 0.04071430317708291, 0.047570311653544195, 0.05781661027867813, 0.053147020807955414, 0.032610314010526054, 0.05194269695493858, 0.0325886804057518, 0.032521504908800125, 0.02437193488731282, 0.06992571070441045, 0.020493920128501486, 0.052686729686683975, 0.0034828837397071766, 0.008282659364340361, 0.03377915949386079, 0.06289124910836108, 0.09332615387393162, 0.062323261226993054, 0.12925086601171643, 0.01077405468095094, 0.027182080775673967, 0.03219525307940785, 0.019803322029474657, 0.04243585201038513, 0.03866558967274614, 0.03077710349316476, 0.31519406649749726, 4.268212644383311, 17.664666920900345, 49.732711762189865, 85.40407285094261, 93.6211471259594, 100.70951476693153, 77.24121406674385, 57.00706422328949, 75.69418027997017, 42.57990337908268, 39.810482785105705, 44.45830598473549, 45.490687787532806, 25.16416870057583, 34.427562430500984, 55.42259864509106, 72.58790016174316, 81.04999288916588, 51.24226436018944, 31.304787397384644, 15.231928210705519, 4.583052825182676, 1.1829527607187629, 0.10690895549487323, 0.6291190010961145, 0.3497972956392914, 0.3368520434014499, 0.0466139022319112, 0.12221459357533604, 0.1056379682268016, 0.22400047397240996, 0.4435397795168683, 0.3685821813996881, 0.28305524261668324, 0.5722155701369047, 0.2246780548011884, 0.11269696522504091, 0.4579651413951069, 0.10047113610198721, 0.20809007459320128, 0.13488728465745226, 0.1066320453537628, 0.13749372214078903, 0.41996522108092904, 0.3702773654367775, 0.6260995881166309, 0.9750633628573269, 0.5664865463040769, 0.5463261343538761, 0.772996440064162, 0.26653470878954977, 2.1436694590374827, 12.800171747803688, 40.1268196105957, 70.5605037510395, 71.53308436274529, 60.067294612526894, 51.01720243692398, 31.60424742847681, 29.77679818868637, 55.01649923622608, 51.397258043289185, 95.38142547011375, 96.56824618577957, 83.14697876572609, 98.60639601945877, 117.39026248455048, 104.35112535953522, 90.0952023267746, 73.71837750077248, 33.7614543735981, 6.969008445739746, 0.7062195357866585, 0.08710751295438968, 0.17155378824099898, 0.08154454466421157, 0.05412199876445811, 0.053148434599279426, 0.0521286457660608, 0.04377527642645873, 0.020765826338902116, 0.03429437325394247, 0.030041334575798828, 0.08228927501477301, 0.03783966094488278, 0.03940775219234638, 0.030594954478146974, 0.03796770739427302, 0.04426989187777508, 0.02272108118631877, 0.08882273497874849, 0.008334708963957382, 0.05793135002022609, 0.06965776570723392, 0.020954175997758284, 0.013078746051178314, 0.04455938142200466, 0.06119932309957221, 0.06449894135585055, 0.04020228807348758, 0.04174293841060717, 0.012714457297988702, 0.03400469446205534, 0.07200493389973417, 0.05254522438917775, 0.03072494535445003, 0.014585690823878394, 0.034659472803468816, 0.01079093668522546, 0.028310015368333552, 0.035512304384610616, 0.0678078067721799, 0.008866128446243238, 0.021817082233610563, 0.08511115796864033, 0.08255578024545684, 0.057604675166658126, 0.045104585369699635, 0.06497531110653654, 0.02760465780738741, 0.09527791320579126, 0.05586341489106417, 0.05861497935256921, 0.04283645219402388, 0.03623829179559834, 0.040628700153320096, 0.026126884076802526, 0.1304971397621557, 0.09275116753997281, 0.16280511394143105, 0.10689940405427478, 0.24939397699199617, 0.10875105508603156, 0.3027180297067389, 0.1799502392532304, 0.07742857138509862, 0.07586751569760963, 0.13190903118811548, 0.14988956245360896, 0.1465908793034032, 0.13127315905876458, 0.16279096860671416, 0.14476066891802475, 0.19402152247494087, 0.21418585296487436, 0.09509720024652779, 0.14136651589069515, 0.1482911841594614, 0.11237511804210953, 0.1651298618526198, 0.15576312696794048, 0.16385130467824638, 0.1771649144939147, 0.15716122929006815, 0.2694911282742396, 0.11158783294376917, 0.2973874204326421, 0.10716329692513682, 0.22467421047622338, 0.14154497272102162, 0.10842836927622557, 0.14440773316891864, 0.19316272402647883, 0.1541988577810116, 0.23926284484332427, 0.18661474023247138, 0.23573537240736187, 0.231121321558021, 0.3008685086388141, 0.16170860559213907, 0.2674552093958482, 0.15570133575238287, 0.07129757068469189, 0.21800942748086527, 0.5188704701140523, 3.35254751611501, 12.119276784360409, 32.95400530099869, 69.8334127664566, 109.10856127738953, 105.31814306974411, 109.86470550298691, 95.59612914919853, 65.25937020778656, 79.17414754629135, 40.295367166399956, 51.85344636440277, 57.99980655312538, 44.72547724843025, 70.33047169446945, 93.12667205929756, 134.71075147390366, 123.70374530553818, 144.6123817563057, 62.14614786207676, 39.14237983524799, 17.464590556919575, 6.980044478550553, 2.2800439037382603, 0.5227163387462497, 1.0642447555437684, 0.338822475168854, 0.45884529885370284, 0.24642456992296502, 0.1358975109178573, 0.10875679188757204, 0.34996077592950314, 0.35208584158681333, 0.44635536905843765, 0.3274808556307107, 0.36228612705599517, 0.3545527107780799, 0.20077831693924963, 0.3867166192503646, 0.1981625729240477, 0.2726778807118535, 0.19959237979492173, 0.11604005849221721, 0.18842580320779234, 0.29716706194449216, 0.464139572577551, 0.5888560053426772, 1.4550774148665369, 0.7258213777095079, 0.6797409534920007, 1.1050157365389168, 0.8728283050004393, 3.1352003663778305, 17.80152227729559, 56.037926226854324, 138.5780167579651, 119.29399073123932, 134.8545205593109, 120.02865090966225, 52.62508995831013, 50.882172882556915, 46.71784333884716, 42.99344278872013, 91.44957885146141, 105.11806860566139, 92.86982864141464, 111.84765189886093, 128.59323173761368, 119.17962446808815, 109.37792882323265, 92.84296408295631, 47.8373696655035, 13.7407086789608, 2.0382602652534842, 0.16393534548114985, 0.23106999462470412, 0.14645741146523505, 0.20776710676727816, 0.29917314648628235, 0.18816811469150707, 0.16818905394757167, 0.10016128202551045, 0.10057902953121811, 0.15341693098889664, 0.20107395888771862, 0.19061928003793582, 0.2329808022477664, 0.09038186850375496, 0.09119902504608035, 0.1865984871983528, 0.1582676824182272, 0.25409542315173894, 0.10512730383197777, 0.22889431449584663, 0.14202537975506857, 0.17352010851027444, 0.2065778151154518, 0.07439675711793825, 0.1409369905013591, 0.10639945627190173, 0.23863037175033242, 0.14748610235983506, 0.16767523542512208, 0.13196144165704027, 0.2803069807123393, 0.14320923888590187, 0.13334720948478207, 0.18448838323820382, 0.09650448293541558, 0.21048535621957853, 0.11069750806200318, 0.1558233448304236, 0.1899322442477569, 0.1034813019214198, 0.2401394845219329, 0.1319134989171289, 0.08760616939980537, 0.1400642842054367, 0.14990338124334812, 0.12434707328793593, 0.13772119040368125, 0.2545349230058491, 0.12389237424940802, 0.12386973132379353, 0.1738535999902524, 0.1349509906140156, 0.1623143465258181, 0.13517697458155453], [0.025775757312658243, 0.045615268318215385, 0.034045609063468874, 0.02115576742653502, 0.03469462833891157, 0.043000129153369926, 0.047353660193039104, 0.029865234064345714, 0.052212437949492596, 0.05182821325433906, 0.00905365153812454, 0.02283955578604946, 0.022279109980445355, 0.052247229832573794, 0.048958016486722045, 0.05557674179726746, 0.06406777582014911, 0.04707461266661994, 0.03963666022173129, 0.03967987919168081, 0.013748899837082718, 0.03958425346354488, 0.02573012450739043, 0.01442555854737293, 0.010309014742233558, 0.06842214919743128, 0.04560937195492443, 0.061802915515727364, 0.055154738074634224, 0.057178029310307465, 0.020325016594142653, 0.038363453932106495, 0.04192180342215579, 0.06871885241707787, 0.020126503222854808, 0.04713505688414443, 0.05320541298715398, 0.055614364973735064, 0.062468833493767306, 0.04190466723230202, 0.028047450941812713, 0.03518027864629403, 0.030129844963084906, 0.027024749178963248, 0.12596948974533007, 1.2091280124150217, 4.9242892395704985, 12.5706878118217, 20.774416252970695, 44.37996558845043, 78.51344659924507, 81.19598105549812, 80.62696918845177, 73.16599354147911, 59.004753828048706, 30.17086174339056, 13.967034984380007, 12.750774398446083, 37.6183196157217, 57.9540304094553, 72.787214666605, 62.272783666849136, 97.5251716375351, 96.62942290306091, 64.31814551353455, 30.283563695847988, 9.929658528417349, 3.3455789275467396, 0.4915468191029504, 0.13814498641295359, 0.09627749706851318, 0.047135368586168624, 0.08668948343256488, 0.33714973367750645, 0.0798331001715269, 0.10446829895954579, 0.0988204512395896, 0.09335611437563784, 0.21401171543402597, 0.12516301270807162, 0.39499943261034787, 0.07689185760682449, 0.11851923249196261, 0.20450904878089204, 0.02812642473145388, 0.06420668360078707, 0.247521523560863, 0.16174893389688805, 0.397490881732665, 0.1760441082296893, 0.03851321562251542, 0.08070248164585792, 0.19616721983766183, 0.1652602423564531, 0.44026233663316816, 0.26805165864061564, 0.3730182652361691, 0.40593931276816875, 0.5103887908626348, 0.278382888645865, 0.06008525924698915, 0.26546770823188126, 0.17615305550862104, 0.03428969401284121, 9.578248634934425, 41.91356733441353, 72.37709507346153, 95.623290091753, 84.83745485544205, 58.90035443007946, 45.538356229662895, 23.4572945907712, 28.05960763245821, 53.41507136821747, 58.59135881066322, 67.0231519639492, 74.32070598006248, 86.43414437770844, 84.20767664909363, 74.39774304628372, 51.310014724731445, 22.02419389039278, 4.471262348815799, 0.0340271444292739, 0.047126659483183175, 0.10779813746921718, 0.03800093705649488, 0.014538960567733739, 0.07475738151697442, 0.06363003485603258, 0.042493680157349445, 0.05092283390695229, 0.07666864927159622, 0.027901921348529868, 0.024252514049294405, 0.060706236472469755, 0.04151492095843423, 0.03604377488954924, 0.054497454984812066, 0.02117326541338116, 0.05676316133758519, 0.02385985484579578, 0.04233474552165717, 0.07037194925942458, 0.06171771325170994, 0.03197121353878174, 0.0488691443024436, 0.015344919956987724, 0.08095153156318702, 0.05823693674756214, 0.041841146812657826, 0.04097602897672914, 0.03030487863725284, 0.038264555332716554, 0.04268087577656843, 0.046408587077166885, 0.007140374882510514, 0.025454952847212553, 0.028251962721697055, 0.02375533447775524, 0.044569723249878734, 0.08022101334063336, 0.013653923488163855, 0.033347815842716955, 0.06633433935348876, 0.06656236422713846, 0.03806328859354835, 0.04732290930405725, 0.0412080466048792, 0.027397361118346453, 0.10830324317794293, 0.0385022207046859, 0.020596124995790888, 0.05399864268838428, 0.023787217141943984, 0.017988611398322973, 0.0969824631465599, 0.0433592469926225, 0.007406440390695934, 0.025733677539392374, 0.05350491410354152, 0.0904833126696758, 0.05160777684068307, 0.07070676918374375, 0.044311830642982386, 0.02395694074948551, 0.022066304700274486, 0.03612931483075954, 0.007916434533399297, 0.052172707073623314, 0.029675257246708497, 0.018745974957710132, 0.09493105564615689, 0.04194534805719741, 0.03886113074258901, 0.10142788320081308, 0.07696649539866485, 0.017604358872631565, 0.06715439027175307, 0.04888790579570923, 0.03671193786431104, 0.038546252326341346, 0.05700759509636555, 0.03055411780223949, 0.060962615098105744, 0.04893411933153402, 0.037623016905854456, 0.05840923375217244, 0.054208162109716795, 0.038242661976255476, 0.019962566511821933, 0.05575089046033099, 0.0017976437857214478, 0.02541684913012432, 0.026190185562882107, 0.023276693755178712, 0.0627531651116442, 0.057324562658322975, 0.07882061778218485, 0.06380381615599617, 0.19914462725864723, 0.5886447010561824, 3.115868428722024, 8.437600191682577, 16.994386687874794, 42.09664151072502, 80.55029690265656, 90.95204874873161, 96.11619964241982, 87.29690328240395, 74.6799387037754, 56.15727782249451, 27.58325569331646, 26.621424704790115, 33.985220566391945, 53.781846687197685, 61.29125453531742, 27.166152074933052, 56.48170441389084, 75.54366275668144, 65.35179644823074, 34.41856071352959, 14.322114530950785, 4.21008431352675, 0.6491761060897261, 0.16139770508743823, 0.054414312180597335, 0.034819168140529655, 0.20989966811612248, 0.1402949437033385, 0.06592669989913702, 0.07113568601198494, 0.14520576456561685, 0.34942681551910937, 0.21497625508345664, 0.14230622327886522, 0.4700397653505206, 0.4321727785281837, 0.3478759346762672, 1.0091061517596245, 0.44714804214891046, 0.42313579469919205, 1.7746641347184777, 1.2803232483565807, 0.7356083462946117, 0.5101315921638161, 0.15399430703837425, 0.15317110199248418, 0.22892627137480304, 0.279257197980769, 0.25103617168497294, 0.6248205411247909, 0.5271584785077721, 0.6343915150500834, 0.49425176926888525, 0.1860279982793145, 0.017657504067756236, 0.41936040041036904, 0.4282265418441966, 0.48847637604922056, 11.627950798720121, 42.04284779727459, 65.23352399468422, 63.35738606750965, 65.12384667992592, 49.053908586502075, 51.14066541194916, 39.77940425276756, 54.22497130930424, 82.7780869603157, 75.81632852554321, 81.89460396766663, 82.30118975043297, 100.54683029651642, 96.48756891489029, 86.6763585805893, 59.102628976106644, 24.193721674382687, 3.8312090188264847, 0.048223316262010485, 0.046436072516371496, 0.11379121002391912, 0.04682611564930994, 0.09423570780199952, 0.1131476418231614, 0.05293510424962733, 0.06084666194510646, 0.06677928657154553, 0.038300842643366195, 0.05359701463021338, 0.03438860745518468, 0.032869564747670665, 0.034122291472158395, 0.020360097914817743, 0.027562663381104358, 0.05378082234528847, 0.023811223763914313, 0.05511995361302979, 0.040534128274885006, 0.07009908382315189, 0.012578033856698312, 0.08477647163090296, 0.005154801910975948, 0.03282342913735192, 0.07942546813865192, 0.05846320644195657, 0.07157787986216135, 0.0764474892639555, 0.05366735167626757, 0.04568562020722311, 0.02449773262924282, 0.026920946838799864, 0.03134533442789689, 0.017914327981998213, 0.024573494774813298, 0.029818964867445175, 0.009491065957263345, 0.12989843438845128, 0.02987933301483281, 0.06409576963051222, 0.024378254274779465, 0.05621531163342297, 0.01961387399205705, 0.04690815636422485, 0.03532779905071948, 0.013305705015227431, 0.023738265081192367, 0.03282542180386372, 0.03365325042977929, 0.043223608372500166, 0.03569594511645846, 0.03715818384080194, 0.1303627813467756, 0.17660006589721888, 0.13092022330965847, 0.07670919279917143, 0.17794004321331158, 0.23939356673508883, 0.11815681209554896, 0.19431017339229584, 0.15228601667331532, 0.06753370937076397, 0.09095452449400909, 0.126715793448966, 0.11589479792746715, 0.13860253529855981, 0.1516046212054789, 0.11273147509200498, 0.16993771714624017, 0.11964704463025555, 0.09696147521026433, 0.15349950233940035, 0.17891203402541578, 0.11494300095364451, 0.10313189879525453, 0.12868235120549798, 0.10694184005842544, 0.09809958835830912, 0.1723516860511154, 0.11679220289806835, 0.19165362609783188, 0.16139194602146745, 0.15482763497857377, 0.15584609907818958, 0.17323068575933576, 0.14778643468162045, 0.2063642695429735, 0.1818903023377061, 0.15874191478360444, 0.16351922327885404, 0.12624654831597582, 0.1444711719523184, 0.09717433058540337, 0.19195314205717295, 0.13811923388857394, 0.19494816806400195, 0.22018907067831606, 2.604374075308442, 7.450702898204327, 19.141470976173878, 32.17274822294712, 60.53145490586758, 105.1009239256382, 110.00458359718323, 106.7717170715332, 101.25670060515404, 88.75226318836212, 53.99650476872921, 33.79258990287781, 31.956433430314064, 58.78652773797512, 83.92031326889992, 101.07488796114922, 95.75440585613251, 139.25398528575897, 131.16824716329575, 93.39556843042374, 47.59422831237316, 15.389901883900166, 7.3225766234099865, 1.4148505171760917, 0.347159257507883, 0.2159049638430588, 0.21286264818627387, 0.29021646303590387, 0.6231130671221763, 0.2829895180184394, 0.5481395276729017, 0.37308918486814946, 0.6258024915587157, 0.3739537869114429, 0.3735635062912479, 0.834345038747415, 0.3528241004096344, 0.31654608144890517, 0.8519346511457115, 0.27028516691643745, 0.19546317402273417, 0.8617783791851252, 0.8147589897271246, 0.963684517191723, 0.5814882006961852, 0.3657000954262912, 0.31300841190386564, 0.702484454959631, 0.87823232752271, 0.9798086551018059, 1.1886985274031758, 0.7592309662140906, 1.151734348386526, 0.9898849425371736, 0.46807817998342216, 0.22744099638657644, 0.38026833557523787, 0.5436531559098512, 0.5898791004437953, 16.838097274303436, 65.18395185470581, 105.20058497786522, 136.49113833904266, 113.17793771624565, 79.2012856900692, 68.06395411491394, 39.710460752248764, 44.098256304860115, 73.87581825256348, 85.27665808796883, 91.66395574808121, 96.88008785247803, 109.47771906852722, 107.55354791879654, 102.78297230601311, 74.92649227380753, 35.30674785375595, 6.2113747000694275, 0.149229095550254, 0.13468227378325537, 0.2611081546638161, 0.21082404273329303, 0.1362514856737107, 0.22906171332579106, 0.1965401045163162, 0.1694792925263755, 0.12379369087284431, 0.28030030138324946, 0.2621788065880537, 0.10592330174404196, 0.1333521818742156, 0.09627888488466851, 0.10246955425827764, 0.10884785340749659, 0.17252843594178557, 0.17229664837941527, 0.10675795812858269, 0.13037323078606278, 0.1732641863054596, 0.09713548657600768, 0.1453446946106851, 0.1359637253335677, 0.09160662739304826, 0.18182646279456094, 0.14528309635352343, 0.20633197127608582, 0.16112051293021068, 0.12372587341815233, 0.09494109690422192, 0.06772795910364948, 0.18176489422330633, 0.17060689686331898, 0.11488533607916906, 0.13405800884356722, 0.11295869844616391, 0.12099003506591544, 0.30200862558558583, 0.09600861696526408, 0.21098563796840608, 0.13305259170010686, 0.14982680644607171, 0.08530261722626165, 0.12642855261219665, 0.12417873193044215, 0.1032273612509016, 0.18466707755578682, 0.1005472952965647, 0.13237263599876314, 0.16219196637393907, 0.20363404182717204, 0.10879939116421156], [0.023365712513623293, 0.017148598562926054, 0.05798109246825334, 0.05118744295032229, 0.08312148973345757, 0.011399442119000014, 0.0164676335407421, 0.008560151163692353, 0.022606647580687422, 0.07451977551681921, 0.0677803621510975, 0.028481141634983942, 0.04704229213530198, 0.0171658071121783, 0.05270968802506104, 0.12361228771624155, 0.071790779766161, 0.0887886481359601, 0.07860565470764413, 0.02912138130341191, 0.05812076837173663, 0.016474455733259674, 0.04971840244252235, 0.10995255506713875, 0.02410105284070596, 0.11445444513810799, 0.055244582472369075, 0.037355112726800144, 0.05867684849363286, 0.019946619613619987, 0.051645878702402115, 0.06674947449937463, 0.05598197298240848, 0.04888672207016498, 0.05317230949003715, 0.10478470620000735, 0.022143751521070953, 0.05557338357903063, 0.02875878279155586, 0.053732044689240865, 0.010767321546154562, 0.08338920466485433, 0.10922352856141515, 0.5818391474895179, 6.855343244969845, 20.6565959751606, 32.749390080571175, 42.46104575693607, 65.5344070494175, 67.5133028626442, 75.41177183389664, 73.9422158896923, 55.649093091487885, 33.0417387932539, 28.796863071620464, 18.768560886383057, 40.84346875548363, 52.08606228232384, 49.07676815986633, 38.819784745574, 44.08940277993679, 77.68015131354332, 35.94316050410271, 12.317541595548391, 2.3517961660400033, 0.06407847758964635, 0.29696086363401264, 0.13668020954355597, 0.05527080997126177, 0.11139723457745276, 0.05178012579563074, 0.02293939691298874, 0.018877696893468965, 0.06221907111466862, 0.07555128657259047, 0.13444117968901992, 0.0941583389067091, 0.10441409249324352, 0.12500690936576575, 0.10342621972085908, 0.1760094944620505, 0.1548682156135328, 0.11654428846668452, 0.7089055760297924, 0.08874160339473747, 0.5640810378827155, 1.2949941423721611, 0.2568056574091315, 0.019151417654938996, 0.045557592311524786, 0.07471372839063406, 0.16968373936833814, 0.044038742562406696, 0.10256117238895968, 0.15585461893351749, 0.12417993420967832, 0.028168042517791037, 0.07329079380724579, 0.1908507410553284, 0.11793051642598584, 0.29634384205564857, 0.18432836135616526, 0.20512676797807217, 0.10201806129771285, 0.1652632703189738, 0.11255180856096558, 5.113950837403536, 30.66754639148712, 55.33531352877617, 95.47851026058197, 63.859114944934845, 40.38428619503975, 29.33286041021347, 19.939177371561527, 32.23759934306145, 43.41767102479935, 49.417666867375374, 41.69483967125416, 59.322222992777824, 74.25816133618355, 74.77405205368996, 61.76245965063572, 37.32173413038254, 10.460684783756733, 0.16686437971657142, 0.03400485402380582, 0.04770654399180785, 0.0771431859175209, 0.09591667228960432, 0.028425968521332834, 0.03392081693164073, 0.03454806159425061, 0.03836296782537829, 0.10128973983228207, 0.01791801831132034, 0.019645853135443758, 0.10405619177618064, 0.030157072505971882, 0.08091590847470798, 0.016793273098301142, 0.02659848367329687, 0.05101623319205828, 0.017965102015295997, 0.01272080729904701, 0.02642071518494049, 0.051997964692418464, 0.021209478509263135, 0.040046993672149256, 0.032664468526490964, 0.04220805720251519, 0.09808791437535547, 0.024861958299879916, 0.03106826843577437, 0.02140982869605068, 0.03271278976171743, 0.024743058820604347, 0.012417471134540392, 0.05267429500236176, 0.03107896278379485, 0.09378401446156204, 0.08418899495154619, 0.01616395042219665, 0.024540335616620723, 0.11179098102729768, 0.014614629017160041, 0.043555441152420826, 0.07067185113555752, 0.07726032650680281, 0.025775312024052255, 0.009186939405481098, 0.025988898414652795, 0.041906166370608844, 0.009783431323739933, 0.02458343398757279, 0.03813414143223781, 0.01891964864626061, 0.007976208034961019, 0.03502248691802379, 0.015988206141628325, 0.04182362841675058, 0.03417468709812965, 0.06459192503825761, 0.02426696923066629, 0.00979679090960417, 0.023977396194823086, 0.08400052654906176, 0.019774411666730884, 0.04605267531587742, 0.021006150454923045, 0.07287246000487357, 0.03462672553723678, 0.03393417930055875, 0.059683493891498074, 0.06701546022668481, 0.01903138640045654, 0.058319912568549626, 0.027330360026098788, 0.02591851312899962, 0.03400728826818522, 0.04172482258582022, 0.02538280310545815, 0.034795400861185044, 0.052017820853507146, 0.04645866349164862, 0.05136634506925475, 0.010478363565198379, 0.06743161953636445, 0.04337918107921723, 0.030002613020769786, 0.03434484671743121, 0.05834620686073322, 0.03415610372030642, 0.03155090562358964, 0.02060698447166942, 0.018250294524477795, 0.0032951751109067118, 0.056502014413126744, 0.10219680756563321, 0.11726065393304452, 0.2708148822421208, 4.127176562324166, 16.156919226050377, 27.67917014658451, 41.09476447105408, 68.23575809597969, 79.1203424334526, 91.91821530461311, 92.11403399705887, 71.11234813928604, 55.06525442004204, 46.13826043903828, 28.567828461527824, 37.02935881912708, 33.052420020103455, 41.59539520740509, 32.4000596255064, 45.68042680621147, 69.59912493824959, 42.73147724568844, 19.436557441949844, 3.7232805602252483, 0.62261808430776, 0.18302651558769867, 0.26452785241417587, 0.08159366741892882, 0.05258441349724308, 0.18815687857568264, 0.32778498774860054, 0.25455795926973224, 0.23350744508206844, 0.5439510243013501, 0.435677882633172, 0.7056018314324319, 1.2258442654274404, 0.7118340313900262, 0.7497697114013135, 0.9883198421448469, 1.2041621538810432, 1.304372870363295, 2.0398115320131183, 2.4626210192218423, 2.0789491944015026, 3.6725551821291447, 2.3670402355492115, 0.2148627510177903, 0.2883451525121927, 1.2311858288012445, 2.0565721951425076, 0.5005775985773653, 0.611250875517726, 0.5802139628212899, 0.6731144059449434, 0.7200117863249034, 0.5756731471046805, 0.9207134542521089, 0.26481803215574473, 0.16137647966388613, 0.21148701809579507, 0.34886940324213356, 0.06228369733435102, 0.24182347697205842, 0.1534581498708576, 5.268187411129475, 29.41417034715414, 54.689693972468376, 69.10896643996239, 48.110088631510735, 32.449232786893845, 27.123280875384808, 33.970564752817154, 51.867623403668404, 72.9527185857296, 72.42117270827293, 65.38881406188011, 73.33769872784615, 86.58029973506927, 89.12949934601784, 75.84203034639359, 42.39230364561081, 9.644445832818747, 0.22256453696172684, 0.016098938285722397, 0.08053258177824318, 0.08543339106836356, 0.09973876993171871, 0.05604539692285471, 0.04060888481035363, 0.04747507184220012, 0.07729916309472173, 0.048830003433977254, 0.019567007366276812, 0.010611887064442271, 0.05408022698247805, 0.08177176059689373, 0.0419370285817422, 0.01248639253390138, 0.03340932133141905, 0.052222315935068764, 0.02655796612089034, 0.04475842171814293, 0.019582466302381363, 0.039781134109944105, 0.04160934069659561, 0.033249997068196535, 0.02094657455018023, 0.017262371657125186, 0.0454381213785382, 0.016102135086839553, 0.02622994241392007, 0.022120505600469187, 0.08546276527340524, 0.039953820742084645, 0.0015525002322647197, 0.06239928683498874, 0.031968682815204374, 0.03922563657397404, 0.05681132672179956, 0.03550220746546984, 0.048710346964071505, 0.05311649998475332, 0.016602500327280723, 0.10256701309117489, 0.03858682182908524, 0.04763530152558815, 0.024055946960288566, 0.04512273088039365, 0.07118421504856087, 0.033203393904841505, 0.05375142958655488, 0.06615243153646588, 0.03586430502764415, 0.012960777967236936, 0.13267203321447596, 0.07564577681478113, 0.21595124417217448, 0.12551164400065318, 0.1302678309730254, 0.08102098916424438, 0.12080006752512418, 0.12555137858726084, 0.11308488581562415, 0.244101959397085, 0.15734685526695102, 0.13011708593694493, 0.1207745673309546, 0.11295497286482714, 0.1370573986787349, 0.250137074617669, 0.20140102336881682, 0.16475194541271776, 0.15058734454214573, 0.17024156724801287, 0.132816944969818, 0.12606547912582755, 0.14163085405016318, 0.20056753215612844, 0.10464246617630124, 0.21970380999846384, 0.1714525296119973, 0.15624350431608036, 0.1809257033164613, 0.0983805803116411, 0.2548148314235732, 0.17572350043337792, 0.08621228989795782, 0.2119720116024837, 0.1423890024307184, 0.20884703553747386, 0.14739529317012057, 0.08403910338529386, 0.19735343899810687, 0.17635082302149385, 0.1204532767587807, 0.21514544991077855, 0.2566673804540187, 1.6724536567926407, 11.803521327674389, 31.412621811032295, 45.251464024186134, 59.737305119633675, 88.4472307562828, 96.63976594805717, 105.59771686792374, 105.24342387914658, 86.27234905958176, 54.42546755075455, 48.382591009140015, 33.535742685198784, 61.10854893922806, 78.83173272013664, 70.74509024620056, 59.71822254359722, 66.82427823543549, 112.78368607163429, 51.70451335608959, 23.40278271585703, 5.543790897354484, 1.0725139430724084, 0.47832305368501693, 0.4222282668342814, 0.2540845877956599, 0.27592738915700465, 0.2562460186891258, 0.35052142397034913, 0.1457846100674942, 0.1075931265950203, 0.39276812109164894, 0.2317139264778234, 0.3064983815420419, 0.6959250569343567, 0.42683528212364763, 0.36215334199368954, 0.3196967061376199, 0.4860569449374452, 0.8123916573822498, 1.042731141205877, 1.6453118319623172, 1.620533955283463, 3.2202086923643947, 0.6934398121666163, 0.14535655413055792, 0.09955312169040553, 0.3380691952770576, 0.6334952381439507, 0.1045238264487125, 0.30547213973477483, 0.24485390342306346, 0.34490241610910743, 0.39932095853146166, 0.26536187797319144, 0.6754135200753808, 0.2166298936936073, 0.5290587921626866, 0.5031482793856412, 0.6514793168753386, 0.30048766813706607, 0.36191876395605505, 0.31800134398508817, 9.44846659898758, 45.49679405987263, 80.8898314833641, 133.59415858983994, 86.81698143482208, 59.301970079541206, 43.058145716786385, 30.336848236620426, 47.784370109438896, 60.93023970723152, 71.91019132733345, 66.2873974442482, 83.3816085755825, 102.7869088947773, 104.43734273314476, 92.1739187836647, 55.42698360979557, 12.769078016281128, 0.289958729990758, 0.1311327298753895, 0.16781527869170532, 0.21178506460273638, 0.2192359749460593, 0.15093370486283675, 0.11061593118938617, 0.13935289112851024, 0.30769353616051376, 0.16205783060286194, 0.12962953944224864, 0.11423320349422283, 0.15142355201533064, 0.14490816334728152, 0.15018290374428034, 0.1229673316993285, 0.15175061649642885, 0.18257980205817148, 0.1202216895762831, 0.1147266426414717, 0.07004206461715512, 0.12979871942661703, 0.1538011705270037, 0.09580840036505833, 0.09788628027308732, 0.11872943839989603, 0.18669941928237677, 0.08727127526071854, 0.17253674799576402, 0.17539599066367373, 0.2966534660663456, 0.08082144049694762, 0.073054954118561, 0.15961301804054528, 0.14145466819172725, 0.17493220773758367, 0.2938971889670938, 0.08372210984816775, 0.19158570474246517, 0.19369554152945057, 0.12304279327508993, 0.12220079705002718, 0.2296771467081271, 0.12207410502014682, 0.14152270829072222, 0.20472642383538187, 0.1088536941097118, 0.2181127789663151, 0.08743348647840321, 0.14670942997327074, 0.18068184843286872, 0.19390653411392123], [0.03984402370406315, 0.024780579951766413, 0.00772693593717122, 0.02649236768775154, 0.023839052446419373, 0.04495478657190688, 0.008168040221789852, 0.01984280243050307, 0.059551558588282205, 0.01618320915440563, 0.018427183567837346, 0.02983888040034799, 0.07997358130523935, 0.034812088051694445, 0.034958346805069596, 0.09801322463317774, 0.060823462408734486, 0.07158654814702459, 0.05242410217761062, 0.08799907722277567, 0.015420790641655913, 0.04621080843207892, 0.029466890009643976, 0.046569247206207365, 0.09070229818462394, 0.07647753882338293, 0.07794084624038078, 0.0107271657907404, 0.07089842139976099, 0.030767952812311705, 0.04228383048030082, 0.062133397586876526, 0.10158653210964985, 0.06347132657538168, 0.01653909494052641, 0.02760341842076741, 0.018784780004352797, 0.11040181416319683, 0.02582842753326986, 0.009566522894601803, 0.2309060690458864, 0.42764612298924476, 7.691014828160405, 24.81346271932125, 38.337058648467064, 56.085184291005135, 66.52734696865082, 71.23111456632614, 65.62671929597855, 56.971182748675346, 60.55280975997448, 36.89277894794941, 37.28237584233284, 26.46700669080019, 38.736010640859604, 75.00121906399727, 53.00136096775532, 42.54513904452324, 30.84186013787985, 40.160238817334175, 34.163028225302696, 11.096302326768637, 0.35910486651118845, 0.10106225672643632, 0.15834762656595558, 0.02206695036875317, 0.09645842525060289, 0.1210607765824534, 0.11314923744066618, 0.037563893711194396, 0.07635493602720089, 0.02724053047131747, 0.10797333627124317, 0.3742425120435655, 0.24855805153492838, 0.30715464788954705, 0.6864256260450929, 0.9680713817942888, 0.5006359016988426, 0.4285987437469885, 0.6124039948917925, 2.0209581311792135, 1.670773671939969, 2.7945849811658263, 2.7749986946582794, 2.1500528790056705, 4.616988804191351, 5.111331827938557, 2.4395918799564242, 2.377260737121105, 1.1037822277285159, 1.441673159133643, 0.8206263498868793, 1.0033151437528431, 0.8405695797409862, 1.1862958688288927, 0.31985573354177177, 0.24104117910610512, 0.38037716411054134, 0.18365973082836717, 0.16330327314790338, 0.07274291070643812, 0.06273296385188587, 0.024293360002047848, 0.10615522289299406, 0.08682692176080309, 0.08899236025172286, 0.21291776007274166, 2.3089064424857497, 21.904266625642776, 84.3820720911026, 86.06146797537804, 78.1720957159996, 63.315713703632355, 25.5508416518569, 13.29223869368434, 27.989605888724327, 36.543946266174316, 41.64802238345146, 57.4743327498436, 53.756137266755104, 75.59394165873528, 65.58426037430763, 42.74899050593376, 7.6479389145970345, 1.32656593574211, 0.11162069524289109, 0.05824103711347561, 0.03846264567982871, 0.002714907700465119, 0.09366173821035773, 0.06185738915519323, 0.10588772318442352, 0.03709237389557529, 0.007578011482110014, 0.03529997593432199, 0.011078876996180043, 0.0205129729147302, 0.017892696232593153, 0.005114173500260222, 0.009278329325752566, 0.06895229496876709, 0.05617882023216225, 0.04463277611648664, 0.08012551377760246, 0.03134524537017569, 0.013119367504259571, 0.08591196499764919, 0.010354641981393797, 0.07603596095577814, 0.03629976017691661, 0.026398178015369922, 0.10457735013915226, 0.0771505331795197, 0.03252844027883839, 0.0156708174108644, 0.022781803709222004, 0.01570345335494494, 0.037149433919694275, 0.019449542087386362, 0.05029988999012858, 0.02107396790961502, 0.04585735317959916, 0.018210519119747914, 0.0949095630494412, 0.049909620502148755, 0.027947420567215886, 0.08282915776362643, 0.04371436465589795, 0.03588190877053421, 0.006654939334111987, 0.04160174110438675, 0.010141519433091162, 0.03352311483467929, 0.04815430766029749, 0.029651879594894126, 0.025906134105753154, 0.014462013768934412, 0.04633266908058431, 0.029338936328713316, 0.031113908662518952, 0.029288581608852837, 0.022462362940132152, 0.01023655886456254, 0.04609920797520317, 0.018517734861234203, 0.04330446907260921, 0.01047817524522543, 0.07559862817288376, 0.025262666094931774, 0.0217496599725564, 0.023966928201843984, 0.03481005085632205, 0.015391435917990748, 0.04920661369396839, 0.03793024006881751, 0.028931706910952926, 0.03787713940255344, 0.07566551794297993, 0.012866534489148762, 0.03856457224173937, 0.07579094832180999, 0.005889587018828024, 0.07361059266258962, 0.06291189565672539, 0.02381291957135545, 0.06930169809493236, 0.051336803880985826, 0.030330334302561823, 0.05573561335040722, 0.005231116956565529, 0.025920413027051836, 0.002418427588963823, 0.03195201788912527, 0.06891438606544398, 0.029195740789873526, 0.0571316116838716, 0.3270210209302604, 5.3019144013524055, 18.27562663704157, 37.06396736204624, 56.612652987241745, 70.81097111105919, 77.67059102654457, 81.93931236863136, 77.01867520809174, 80.78276842832565, 58.24744686484337, 54.833147674798965, 31.35316640138626, 43.50224308669567, 46.98044344782829, 53.498625084757805, 47.652182802557945, 35.22016189992428, 50.99125362932682, 40.00617988407612, 13.551462683826685, 1.3548691920004785, 0.20643622818170115, 0.18260451557580382, 0.07202694599982351, 0.06667202396783978, 0.25185069360304624, 0.30302397266495973, 0.17286068061366677, 0.43777067970950156, 0.34138992021325976, 1.2659546756185591, 1.4835910848341882, 2.3662140173837543, 2.3401398165151477, 1.7761810845695436, 2.79750797431916, 3.4893311513587832, 3.6550609208643436, 4.685821635648608, 8.788579758256674, 7.119099916890264, 8.149384707212448, 6.3543320540338755, 8.010845091193914, 12.20411578193307, 9.292905796319246, 9.037872031331062, 9.491586685180664, 4.5611094776540995, 4.064477551728487, 2.472246615216136, 2.199679878540337, 1.8677152041345835, 1.398539061192423, 1.7498386418446898, 1.9890637113712728, 1.601947252638638, 0.9873621154110879, 0.4372494842391461, 0.506957396864891, 0.2859578118659556, 0.0850748892116826, 0.024722859416215215, 0.0980865117162466, 0.11492962003103457, 0.12811754713766277, 2.771920384839177, 21.37107163667679, 55.80483913421631, 60.34398436546326, 50.91395057737827, 32.5035584717989, 39.66620072722435, 24.69980511814356, 35.469200536608696, 49.99998942017555, 55.0831438601017, 71.0489447414875, 66.09802320599556, 89.96287822723389, 85.59283912181854, 53.467402160167694, 9.221336636692286, 1.2041513482108712, 0.11761301080696285, 0.04058875405462459, 0.06173919471621048, 0.0143363292045251, 0.023184544988907874, 0.06787235135561787, 0.10899125118157826, 0.06157898729725275, 0.049070351669797674, 0.014936639472580282, 0.03256699856137857, 0.017175738903461024, 0.035863173252437264, 0.04338486964115873, 0.05852135000168346, 0.03753191456780769, 0.04267966978659388, 0.05272732516459655, 0.04998454402084462, 0.13252707693027332, 0.005871522680536145, 0.03571784218365792, 0.023772646927682217, 0.11211704360903241, 0.11046195038943551, 0.030110241132206284, 0.03272840454883408, 0.027913211270060856, 0.0098492366305436, 0.013550715793826384, 0.05086848643259145, 0.012606260515894974, 0.02353547879465623, 0.04891739874437917, 0.013998659433127614, 0.02341852003155509, 0.016862552583916113, 0.02200554506998742, 0.029524775673053227, 0.027974720469501335, 0.03936740533390548, 0.03144637783407234, 0.028470402758102864, 0.040558719338150695, 0.025029468451975845, 0.031823125391383655, 0.09726027128635906, 0.06719405806506984, 0.015755327622173354, 0.07121152608306147, 0.1315342020825483, 0.09053148547536694, 0.15084727434441447, 0.10847886500414461, 0.1279057827196084, 0.11833326512714848, 0.13589601177955046, 0.11340606506564654, 0.15318420832045376, 0.09271056464058347, 0.20296941889682785, 0.1387863652780652, 0.13285225635627285, 0.09790057403733954, 0.1416821958264336, 0.28355491580441594, 0.1920122466981411, 0.1815027676639147, 0.14421199914067984, 0.20248433633241802, 0.09296531425206922, 0.13366470026085153, 0.1130869118787814, 0.262019838555716, 0.16304537683026865, 0.15060894103953615, 0.1755942331510596, 0.13682979682926089, 0.21366534027038142, 0.09092974418308586, 0.13963875157060102, 0.2112427179235965, 0.19901519670384005, 0.18855124100809917, 0.1152771084161941, 0.15760908572701737, 0.060896641880390234, 0.2002798460307531, 0.1582663317094557, 0.13137187954271212, 0.2725945523707196, 1.4396513113752007, 13.556704502552748, 38.488309532403946, 56.6763299703598, 76.99084550142288, 88.83531153202057, 93.56107234954834, 93.44740524888039, 89.0305070579052, 96.68030217289925, 60.818936079740524, 58.60844649374485, 43.874376118183136, 56.059600263834, 102.46176034212112, 78.5205902159214, 63.35366226732731, 53.89528200030327, 63.05705018341541, 58.910537883639336, 17.871164940297604, 2.614078992046416, 0.4692429065471515, 0.31716527009848505, 0.12520616117399186, 0.28795974038075656, 0.34536851453594863, 0.2988364192424342, 0.1811486147926189, 0.30073913745582104, 0.2496667904779315, 1.499653891660273, 1.8801045580767095, 1.70598519500345, 1.2462080852128565, 1.7068842030130327, 2.3716940358281136, 2.70262255333364, 2.5102336518466473, 4.128706930205226, 8.64165399223566, 7.83190936781466, 10.703249517828226, 10.843209307640791, 13.52726748213172, 20.72230014950037, 17.197329998016357, 13.842584062367678, 7.8895508497953415, 2.669347026385367, 3.8843004824593663, 2.2416339023038745, 3.1642469577491283, 3.7580707808956504, 3.6472454527392983, 1.3854310708120465, 1.552816245239228, 1.0762986587360501, 0.332490797736682, 0.24766365968389437, 0.2251156250713393, 0.16518375661689788, 0.2603301464114338, 0.2894922159612179, 0.2713055309141055, 0.2154697387595661, 0.204225771012716, 5.188323771581054, 35.76080448925495, 124.53732177615166, 122.5750994682312, 107.67724648118019, 90.1486274600029, 41.081590577960014, 19.48639366775751, 40.6139724701643, 53.43187786638737, 62.19232298433781, 82.98797249794006, 82.36127212643623, 106.52770936489105, 102.29279100894928, 67.46574461460114, 14.740000907331705, 2.0636262791231275, 0.22696700150845572, 0.17359349207254127, 0.12043714988976717, 0.1220933637523558, 0.19455818430287763, 0.1467355535714887, 0.26325996732339263, 0.14307875448139384, 0.18105359020410106, 0.1605996588477865, 0.12263172509847209, 0.16777309501776472, 0.16291256208205596, 0.15542826993623748, 0.16393953119404614, 0.16764841420808807, 0.1511180098168552, 0.13928676577052101, 0.14718933234689757, 0.13875494274543598, 0.10700292623369023, 0.16312518739141524, 0.13735795364482328, 0.1748829588177614, 0.21408202650491148, 0.11345808219630271, 0.20029961684485897, 0.2366467594401911, 0.07459660264430568, 0.06385329514159821, 0.09079880706849508, 0.13771912723314017, 0.19601976993726566, 0.11267110137850977, 0.09438183667953126, 0.07160618537454866, 0.17602487176191062, 0.12350220495136455, 0.16253463079920039, 0.20138561638304964, 0.09415519220056012, 0.22381461050827056, 0.16202300903387368, 0.14444898173678666, 0.07172774174250662, 0.20894283195957541, 0.26472520432434976, 0.15185142983682454, 0.1712566619971767, 0.10695320976083167], [0.09880837649689056, 0.008255676730186678, 0.054465839493786916, 0.03775333061639685, 0.01691756242507836, 0.06959224891033955, 0.06401040780474432, 0.04345257948443759, 0.10370845848228782, 0.014632245747634443, 0.03987478201452177, 0.04176047536020633, 0.008289659672300331, 0.022517400611832272, 0.04210807877825573, 0.027290705220366362, 0.02057122594123939, 0.02148270945326658, 0.025779141506063752, 0.01783667892595986, 0.07382665411569178, 0.031213028050842695, 0.04056313140608836, 0.06304833208560012, 0.05508213376742788, 0.0660638116823975, 0.04051382311445195, 0.14104274654528126, 0.043233764663455077, 0.009072455704881577, 0.041897056507878006, 0.05702680929971393, 0.031852492174948566, 0.02834487590007484, 0.03485266126517672, 0.08788390332483687, 0.04690603011113126, 0.039328806233243085, 0.06885989758302458, 0.020197100020595826, 2.687926604412496, 18.549276553094387, 44.86361503601074, 69.62936371564865, 65.78534558415413, 75.13925045728683, 70.7827690243721, 49.99467350542545, 44.86009642481804, 26.899923160672188, 16.453668102622032, 23.92192605882883, 29.2648858577013, 43.42203699052334, 53.539366498589516, 63.62246364355087, 49.01420831680298, 31.471607945859432, 19.972241297364235, 5.445653088390827, 0.5863322876393795, 0.036152399334241636, 0.15692190150730312, 0.019194154228898697, 0.14277631446020678, 0.09538932441500947, 0.09409685197169892, 0.041173774225171655, 0.21176389855099842, 0.15005699096946046, 0.42343627545051277, 0.7103224843740463, 0.8511634112801403, 1.813431791961193, 3.6526744114235044, 2.969529968686402, 3.4996326360851526, 3.4311004634946585, 1.572827990166843, 5.250024860724807, 5.008562067523599, 6.0036759451031685, 5.200314503163099, 4.770738054066896, 7.238990608602762, 5.060447808355093, 5.046983705833554, 14.341655932366848, 7.366937343031168, 10.118188261985779, 13.030050862580538, 13.400275446474552, 8.091910891234875, 1.103291460312903, 2.7089781872928143, 1.0129086789675057, 3.6484782490879297, 3.4099101880565286, 1.6414860310032964, 1.5823110938072205, 0.9144426032435149, 0.6154846795834601, 0.2545381587697193, 0.09424468778888695, 0.05413050748757087, 0.04872175748459995, 0.21722757490351796, 0.13217204832471907, 0.12530854786746204, 0.21250061370665208, 1.2011644709855318, 22.206491008400917, 60.94003178179264, 91.84788107872009, 100.31413838267326, 73.44201073050499, 95.25089487433434, 48.88046309351921, 21.831120550632477, 31.025179401040077, 38.15777666866779, 61.19815193116665, 55.8062032610178, 70.59824332594872, 56.32960617542267, 21.676694937050343, 7.322571873664856, 0.4601741291116923, 0.08827561629004776, 0.023096346303645987, 0.12174762683571316, 0.06568358716322109, 0.08503528079017997, 0.05658756919729058, 0.028229484923940618, 0.02414215854514623, 0.012260767580301035, 0.06257985878619365, 0.03973991522798315, 0.009919967942551011, 0.04907745402306318, 0.0744694282184355, 0.00951296209677821, 0.027920116954192054, 0.0056835046689229785, 0.023418122982548084, 0.03781319595873356, 0.053860239568166435, 0.046259652881417423, 0.10791217588121071, 0.02633664284076076, 0.029455154799507, 0.04663562118366826, 0.05571990579483099, 0.07877209616708569, 0.049185614625457674, 0.049174311716342345, 0.08086862624622881, 0.00890517098014243, 0.0364036051905714, 0.022231677467061672, 0.05266498104901984, 0.026286603533662856, 0.05200302242883481, 0.04023519861220848, 0.025916685590345878, 0.0781085345079191, 0.05573278205702081, 0.010421031729492825, 0.03416843821469229, 0.006884263893880416, 0.03402168964385055, 0.04061416148033459, 0.01978706528461771, 0.02154481608158676, 0.02846599254553439, 0.039712129218969494, 0.0788622819527518, 0.0715387167292647, 0.0763979360635858, 0.009933465753420023, 0.0879087059001904, 0.02806320488161873, 0.00611319333074789, 0.04490617589908652, 0.0437268809764646, 0.06935119192348793, 0.03976681808126159, 0.023284905619220808, 0.03315126916277222, 0.03476413417956792, 0.051928251050412655, 0.03610026717069559, 0.043049496816820465, 0.06988659952185117, 0.03873123263474554, 0.07295055620488711, 0.037631072918884456, 0.052278515067882836, 0.028598178323591128, 0.03505169413983822, 0.08182186298654415, 0.04865934657573234, 0.006659658465650864, 0.032308400914189406, 0.018381934823992196, 0.04642158579372335, 0.007822722618584521, 0.01747621408867417, 0.07118410372640938, 0.07785298337694257, 0.02317405102076009, 0.04991966547095217, 0.02549857999838423, 0.05055849134805612, 0.058380572008900344, 1.4685389050282538, 14.51610267162323, 43.719249442219734, 73.33861827850342, 72.77586087584496, 81.45576551556587, 86.7428170144558, 71.65492862462997, 69.91754025220871, 43.761928752064705, 40.70128798484802, 38.05939234793186, 44.166515842080116, 44.38900910317898, 42.08450876176357, 45.93706503510475, 45.539560765028, 42.31338568031788, 28.350569419562817, 9.14585368707776, 0.5377415043767542, 0.1575365333701484, 0.10561505070654675, 0.10575110121862963, 0.1948326750425622, 0.27443029917776585, 0.5428892187774181, 0.15723695803899318, 1.4005394163541496, 1.7239697487093508, 3.2975411927327514, 3.7522853538393974, 4.001655522733927, 3.367008827626705, 3.5054662730544806, 2.909447830170393, 3.4176057251170278, 2.5224445341154933, 6.520368419587612, 10.32626984640956, 10.314434431493282, 13.523433487862349, 11.521935537457466, 12.477722950279713, 15.817267801612616, 14.992747195065022, 14.246483389288187, 10.325446240603924, 9.996632784605026, 10.720209907740355, 3.238048260100186, 0.8802334545180202, 2.446146528236568, 2.912373198196292, 2.8270798875018954, 2.851444180123508, 2.271551596932113, 2.587236282415688, 1.3015085365623236, 1.6864734794944525, 1.1374734761193395, 1.627820658031851, 1.3717632042244077, 0.8382469543721527, 0.30700957286171615, 0.17369699198752642, 0.08752596550039016, 0.05902338321902789, 0.10763175538158976, 0.11707078287145123, 2.29775570333004, 22.022596076130867, 57.685065641999245, 72.95405611395836, 60.463658943772316, 33.6909681558609, 84.42115679383278, 57.06892870366573, 38.359097465872765, 51.560067906975746, 57.415238320827484, 78.12601178884506, 71.98696240782738, 87.85011559724808, 72.16909423470497, 25.71849435567856, 7.787918653339148, 0.3806387266376987, 0.07197001585154794, 0.02437332455883734, 0.06897753541124985, 0.09240022816811688, 0.09433997212909162, 0.04962860999512486, 0.021539025474339724, 0.05559502089454327, 0.05225651781074703, 0.0038266221918092924, 0.018405490591248963, 0.09991915634600446, 0.012374701163935242, 0.02603449782327516, 0.027947186790697742, 0.018408006471872795, 0.098888795619132, 0.0465078010893194, 0.020208761015965138, 0.05929313905653544, 0.023745228281768505, 0.03866728919092566, 0.0404259713832289, 0.03793911244429182, 0.020968018907296937, 0.031123244880291168, 0.019110989160253666, 0.04062582433107309, 0.02011567157751415, 0.028645866877923254, 0.048394522309536114, 0.025295007035310846, 0.059167085273656994, 0.021307505085133016, 0.03553655777068343, 0.03274705843068659, 0.030711536601302214, 0.09691492028650828, 0.037930896869511344, 0.011001840211974923, 0.08041217573918402, 0.06317007399047725, 0.05116779087984469, 0.03930566235794686, 0.013719033959205262, 0.045811273230356164, 0.03877897499478422, 0.01615799468709156, 0.28317247226368636, 0.2687113982392475, 0.18089572055032477, 0.16864293662365526, 0.10246947262203321, 0.22822387312771752, 0.17787215154385194, 0.10953252916806377, 0.16325472184689716, 0.12713489908492193, 0.14015884866239503, 0.1720072701573372, 0.15047913941089064, 0.10401661304058507, 0.08735758703551255, 0.16322021197993308, 0.16264782316284254, 0.14949364151107147, 0.19567728362744674, 0.19379717123229057, 0.13749151054071262, 0.09627256178646348, 0.2420228920527734, 0.1897289848420769, 0.17331720533547923, 0.20519697514828295, 0.2733965765219182, 0.2634342829696834, 0.2139706746675074, 0.11032900205464102, 0.18708797811996192, 0.09418334186193533, 0.17772109480574727, 0.18544187973020598, 0.14263728051446378, 0.17607910791411996, 0.20332646614406258, 0.22929002763703465, 0.18682061199797317, 0.18095074337907135, 5.838811816647649, 30.768444277346134, 67.52202719449997, 93.54081943631172, 94.00554969906807, 100.67710250616074, 97.96862304210663, 75.38673117756844, 69.68869373202324, 49.1607740521431, 33.83763648569584, 38.331579342484474, 42.42446891963482, 58.74058820307255, 67.42253333330154, 86.98963657021523, 73.07780787348747, 53.171071261167526, 35.566923692822456, 10.191593673080206, 0.9617511928081512, 0.25696768308989704, 0.30614321934990585, 0.3394243569346145, 0.4467274819035083, 0.19907171867089346, 0.16952462290646508, 0.25231607956811786, 0.6861297762952745, 1.4656625781208277, 2.4995709490031004, 3.346002367325127, 3.996934751048684, 5.896394876763225, 9.243209213018417, 9.392035827040672, 12.276500947773457, 9.894638657569885, 8.259999621659517, 12.100425995886326, 12.404443882405758, 21.08067411929369, 17.91130218654871, 16.548288725316525, 22.60656014084816, 16.971114836633205, 16.74029242247343, 30.900547988712788, 24.327730983495712, 27.58513279259205, 34.20412302017212, 34.0801964700222, 30.452096052467823, 14.994286112487316, 15.233109947293997, 15.259113851934671, 14.071758314967155, 13.447559159249067, 6.839712783694267, 4.887892417609692, 2.0996058359742165, 1.8248811713419855, 0.9944176243152469, 0.46599992900155485, 0.26797996717505157, 0.1315313670784235, 0.456595552386716, 0.2163277060026303, 0.2634009753819555, 0.27745431347284466, 3.464631764218211, 37.30688452720642, 91.54673963785172, 127.71873146295547, 129.06913340091705, 100.42155101895332, 112.03378111124039, 60.788495913147926, 34.563093557953835, 47.81832508742809, 61.93080961704254, 89.81895714998245, 86.29970759153366, 106.68115273118019, 91.97376072406769, 35.64215585589409, 11.566873826086521, 1.1045484803617, 0.2349187427898869, 0.12751155387377366, 0.21930839371634647, 0.16888058715267107, 0.1551844150526449, 0.12169376175734214, 0.10564694079221226, 0.12195385483209975, 0.17587200418347493, 0.17724853969411924, 0.11061213139328174, 0.17280009167734534, 0.07958896327181719, 0.1158456974371802, 0.1279636108665727, 0.10691747535020113, 0.1978509154287167, 0.15307027380913496, 0.09458309228648432, 0.18258933123433962, 0.12091479613445699, 0.23087469104211777, 0.10758946038549766, 0.15507436939515173, 0.15343594481237233, 0.15612646762747318, 0.11774060825700872, 0.1943932642461732, 0.1082448213128373, 0.12738657620502636, 0.150685946282465, 0.08735883384360932, 0.1141826187085826, 0.16896949644433334, 0.1404535406618379, 0.15712902008090168, 0.1803676231065765, 0.1998983375960961, 0.17757915164111182, 0.14862645679386333, 0.21071114722872153, 0.2712005318608135, 0.12227458879351616, 0.11576611694181338, 0.09733200728078373, 0.2500606037210673, 0.09851968105067499, 0.09832185416598804], [0.0234305131380097, 0.041040644064196385, 0.06495122841442935, 0.02516929649573285, 0.04811436898307875, 0.022026341903256252, 0.042752032895805314, 0.04385382533655502, 0.04181139411230106, 0.020557267998810858, 0.034578968334244564, 0.019964314269600436, 0.012712892294075573, 0.06131343943707179, 0.037732127457275055, 0.03279422191553749, 0.011870537055074237, 0.02870471176720457, 0.04055503828567453, 0.03838991891825572, 0.017505334108136594, 0.0789354057633318, 0.13665793027030304, 0.04184474622888956, 0.04091650502232369, 0.011237045364396181, 0.10537068374105729, 0.021200849187152926, 0.03800850696279667, 0.09764209142304026, 0.021229201083770022, 0.052716382197104394, 0.017790027523005847, 0.05277225107420236, 0.08212469634599984, 0.03644666830950882, 0.06858704698970541, 0.04602775770763401, 0.4814484156668186, 7.983089480549097, 32.32360392808914, 58.53598438203335, 72.9329140484333, 78.32540228962898, 82.40302428603172, 68.61997827887535, 40.98434999585152, 34.101422131061554, 17.580562233924866, 15.270962566137314, 20.7331732660532, 31.23900342732668, 31.451013050973415, 66.93349957466125, 67.66189768910408, 42.497645393013954, 22.96029455959797, 4.387084040790796, 0.32441617164295167, 0.1843856106279418, 0.09627492181607522, 0.05234448086412158, 0.09073294146219268, 0.05113804931170307, 0.06301258283201605, 0.11921346711460501, 0.16430584044428542, 0.3782558091916144, 2.0320304995402694, 2.6378538412973285, 2.4459947738796473, 4.217832097783685, 1.7482591141015291, 1.3725654361769557, 4.663132103160024, 3.39581151958555, 2.875380520708859, 1.2621964397840202, 6.3450083043426275, 9.269119072705507, 11.542385090142488, 13.924446869641542, 9.907239731401205, 8.635107893496752, 6.599651640281081, 8.163912277668715, 11.664117258042097, 4.444195926189423, 9.394297655671835, 13.640591651201248, 6.267444491386414, 2.2125089401379228, 7.678182916715741, 17.27303333580494, 22.912859804928303, 22.519518211483955, 20.674284026026726, 13.43690263107419, 7.781754909083247, 4.931856533512473, 2.5961596285924315, 2.6807663636282086, 0.6181138416286558, 0.5884645669721067, 0.10131926988833584, 0.11307582419249229, 0.1289589496445842, 0.1919701966107823, 0.14133513788692653, 0.050730780931189656, 0.014837700982752722, 0.4873451648745686, 1.5331900608725846, 19.492604434490204, 73.82050842046738, 89.1714034974575, 45.021948739886284, 47.36260414123535, 32.484802678227425, 18.596821501851082, 18.82073398679495, 28.30209542065859, 47.41008639335632, 60.724153965711594, 61.60525068640709, 56.90234564244747, 40.457994639873505, 14.802264366298914, 2.8686088090762496, 0.10010395853896625, 0.046971895717433654, 0.039570943044964224, 0.05353676337108482, 0.08966982233687304, 0.05220912426011637, 0.06190597756358329, 0.024031626780924853, 0.023657970268686768, 0.05142948699358385, 0.042712762151495554, 0.0608116399962455, 0.05285313032800332, 0.08205935766454786, 0.026658337883418426, 0.07093685722793452, 0.04328888768213801, 0.07419608038617298, 0.05115232081152499, 0.03710881246661302, 0.03731643198989332, 0.0173123868444236, 0.04706777377577964, 0.1181826314132195, 0.008126732282107696, 0.03038192655367311, 0.035801630656351335, 0.03355871194798965, 0.041252096780226566, 0.04056824851431884, 0.016438615566585213, 0.00996581875369884, 0.05523685671505518, 0.03426403054618277, 0.019686797422764357, 0.016765722721174825, 0.06795533088734373, 0.04729978769319132, 0.0282264792258502, 0.026328648054914083, 0.01579832394781988, 0.017220321569766384, 0.07443582377163693, 0.03094427040196024, 0.02414765600406099, 0.01810466288588941, 0.08067359725828283, 0.050749071160680614, 0.013836861962772673, 0.05018700932851061, 0.06112761308031622, 0.05216797217144631, 0.06122546525148209, 0.032672480010660365, 0.015968626430549193, 0.10163900937186554, 0.10354540121625178, 0.03312092645501252, 0.004825694668397773, 0.01234772502357373, 0.05985051051538903, 0.030237627070164308, 0.013098673643980874, 0.020087278862774838, 0.00916886625418556, 0.012469175635487773, 0.03149685500829946, 0.044182659839862026, 0.015052527687657857, 0.08256202912889421, 0.019809468867606483, 0.03418249078094959, 0.01330557699475321, 0.015262690922099864, 0.04475896348594688, 0.05492300617333967, 0.05517632715054788, 0.02679100049135741, 0.05782659958640579, 0.04823037779715378, 0.06626505986787379, 0.03024921941687353, 0.03076457232964458, 0.06720426259562373, 0.08589133329223841, 0.2672830311348662, 6.708333408460021, 32.57617637515068, 62.17920608818531, 79.90664944052696, 90.85854336619377, 91.82309880852699, 83.85646909475327, 59.78653907775879, 37.075742930173874, 25.967692583799362, 31.172153614461422, 37.02145904302597, 42.093635872006416, 28.848006427288055, 46.92405827343464, 52.810364216566086, 48.93057860434055, 30.251996889710426, 7.888319715857506, 0.33093145641032606, 0.24967640871182084, 0.12076263359631412, 0.015681519180361647, 0.2866681065643206, 0.13752599072176963, 0.26892869907896966, 0.5322055576834828, 1.584776567760855, 2.5909486832097173, 3.5143703827634454, 4.914157083258033, 7.3777995351701975, 5.299405110999942, 0.6519479979760945, 0.9091377910226583, 2.717539840377867, 0.9375899517908692, 0.463224237319082, 1.0924847214482725, 2.149937222711742, 4.620022941380739, 7.665425576269627, 16.256817765533924, 16.428889632225037, 18.646304346621037, 17.221297211945057, 12.264488842338324, 11.700108926743269, 5.182317718863487, 4.68995438888669, 2.8758801938965917, 1.401602765545249, 2.7041795197874308, 11.184791028499603, 23.12660973519087, 29.656131863594055, 30.568453408777714, 28.083685040473938, 17.36213095486164, 11.828611381351948, 4.457479538396001, 1.6261980263516307, 0.5034401512239128, 0.1553128066007048, 1.2709169718436897, 0.08649406852782704, 0.21591937635093927, 0.19309734081616625, 0.3550219855969772, 0.11266840738244355, 0.03341264615301043, 0.089119631156791, 0.4454390541650355, 2.2044935077428818, 20.16348123550415, 65.52619189023972, 68.35046634078026, 44.95461255311966, 32.33362779021263, 32.49963328242302, 33.44908453524113, 37.015383169054985, 51.3956393301487, 63.04035767912865, 79.28235054016113, 79.80903267860413, 77.52062067389488, 49.56328645348549, 16.96317706257105, 2.840924682095647, 0.1738379555172287, 0.050995193305425346, 0.0733886162925046, 0.08238227354013361, 0.05569304747041315, 0.003942140492654289, 0.016627601617074106, 0.043981419075862505, 0.016201564321818296, 0.07911852328106761, 0.021325099551177118, 0.03216512930521276, 0.058667226549005136, 0.07034949929220602, 0.04885207490588073, 0.014400454474525759, 0.02737655129749328, 0.017705021928122733, 0.0774217139405664, 0.031205294872052036, 0.04557269130600616, 0.03269744214776438, 0.04985759223927744, 0.02169652776501607, 0.03283510683104396, 0.09194872778607532, 0.008134922809404088, 0.04488003374717664, 0.01164028017228702, 0.05020424199756235, 0.06712437039823271, 0.03726101582287811, 0.022074655717005953, 0.03339863440487534, 0.07091729421517812, 0.05267365675535984, 0.06741916629835032, 0.04854878883634228, 0.0037893513035669457, 0.024553970724809915, 0.055815468440414406, 0.0440019134839531, 0.07947085789055564, 0.011413364809413906, 0.04214021006191615, 0.02832105295965448, 0.07560653946711682, 0.12554990913486108, 0.23080031300196424, 0.14974782709032297, 0.10142952334717847, 0.13103715609759092, 0.10963411434204318, 0.14035697240615264, 0.10288657445926219, 0.2557570917997509, 0.22222427709493786, 0.1636954239802435, 0.131024569272995, 0.0999351050995756, 0.14910521626006812, 0.13968123210361227, 0.17084661056287587, 0.10896890511503443, 0.11952216344070621, 0.13358805124880746, 0.13455579697620124, 0.17553683544974774, 0.13839891966199502, 0.21314408542821184, 0.2591195551212877, 0.2249624754767865, 0.28405491553712636, 0.19047660956857726, 0.08625208385637961, 0.1122539104835596, 0.1820176697219722, 0.16621311544440687, 0.13922231766628101, 0.242473182734102, 0.2152355169528164, 0.19810863363090903, 0.20537739124847576, 0.20295332913519815, 0.17796959553379565, 1.1649923119693995, 18.27654428780079, 53.79175655543804, 84.4407257437706, 96.39087930321693, 105.23851454257965, 105.88450267910957, 94.90145802497864, 61.64589710533619, 50.518232211470604, 33.540416434407234, 28.292204551398754, 32.70264118909836, 46.977718994021416, 46.32182478904724, 90.91750100255013, 94.73660007119179, 66.20770812034607, 37.58365787565708, 9.00863355025649, 1.2476366898044944, 0.476287787896581, 0.35185734916012734, 0.21207663958193734, 0.3933746932307258, 0.19419160787947476, 0.15369021944934502, 0.28094481211155653, 0.9031522215809673, 1.4465668215416372, 5.177157120779157, 11.173975858837366, 11.991835422813892, 17.76347491890192, 11.761872712522745, 10.202877167612314, 14.531321804970503, 14.54499727115035, 13.139672130346298, 14.83999254181981, 22.980256788432598, 22.96313490718603, 27.255920358002186, 27.073457948863506, 25.890817008912563, 29.926232770085335, 17.754562497138977, 19.658292643725872, 36.59910790622234, 24.295514412224293, 25.297799929976463, 30.072319731116295, 21.16012215614319, 16.741565354168415, 16.502275094389915, 23.27767062932253, 27.98721581697464, 28.961071260273457, 36.00942514836788, 26.409177593886852, 18.934653773903847, 18.685447946190834, 13.44131799414754, 13.69419727474451, 7.0138441398739815, 2.761810552328825, 0.2822185750119388, 0.28228907904122025, 0.22630144347203895, 0.40332060016226023, 0.4342733236262575, 0.13144820200977847, 0.2416964658186771, 0.6886434007901698, 4.296336360275745, 31.94072887301445, 109.14468973875046, 123.93235623836517, 61.37070447206497, 68.52642729878426, 46.98519319295883, 27.26024452596903, 31.286360286176205, 51.52693748474121, 75.6609320640564, 88.90784963965416, 96.26664876937866, 96.54740810394287, 64.29362162947655, 26.08279600739479, 4.215320432558656, 0.4031156189739704, 0.26892558205872774, 0.18278006318723783, 0.15965394006343558, 0.21025892696343362, 0.1267496353830211, 0.17694807378575206, 0.15125419391551986, 0.11112969034002163, 0.14395128266187385, 0.14905942574841902, 0.22414019069401547, 0.14472862298134714, 0.17241844965610653, 0.24438927444862202, 0.10953262564726174, 0.10527359598199837, 0.19954753923229873, 0.12753240822348744, 0.16257396462606266, 0.12804564787074924, 0.08372788375709206, 0.1976436038967222, 0.16928545839618891, 0.14648080396000296, 0.16221120284171775, 0.17573366785654798, 0.1131189800798893, 0.07528406145866029, 0.12932322541018948, 0.11408210964873433, 0.09873713774140924, 0.16060592257417738, 0.09870472815237008, 0.15828579082153738, 0.13118092494551092, 0.15439992042956874, 0.16517418291186914, 0.15144066594075412, 0.1514562955708243, 0.20369037083582953, 0.13236709957709536, 0.22567434352822602, 0.1373446692014113, 0.09180517416098155, 0.10602313544950448, 0.14108013594523072], [0.05038994218921289, 0.022995494000497274, 0.022567966843780596, 0.03838861273834482, 0.012021758921036962, 0.0322106897510821, 0.015006805824668845, 0.029659165629709605, 0.048478618773515336, 0.020439728505152743, 0.06341577682178468, 0.04256957588950172, 0.04231317499943543, 0.02682726553757675, 0.06521771138068289, 0.005473191613418749, 0.03918536393030081, 0.021720688382629305, 0.0671534551656805, 0.08381403225939721, 0.03556258860044181, 0.02393644448602572, 0.09227905029547401, 0.05302145684254356, 0.014698924933327362, 0.02675672440091148, 0.048269403632730246, 0.057147679181071, 0.009995466625696281, 0.05322035613062326, 0.04790986276930198, 0.030674336449010298, 0.06055539495719131, 0.08577130574849434, 0.0359206414577784, 0.0062059882293397095, 0.04981538630090654, 0.5917182611301541, 16.176750361919403, 58.759040012955666, 74.39645111560822, 90.31632766127586, 78.77983510494232, 80.23610696196556, 49.47885878384113, 35.283675491809845, 29.559594243764877, 106.59411460161209, 125.43761506676674, 42.155667543411255, 45.9788703918457, 67.7728745341301, 72.84296527504921, 48.98262061178684, 15.834532175213099, 3.0285514891147614, 0.40818499226588756, 0.188418886391446, 0.060759025436709635, 0.20368311263155192, 0.11233696423005313, 0.06947227331693284, 0.02848361855285475, 0.20963105518603697, 0.4764300724491477, 1.849103921558708, 4.169859196990728, 1.679848178755492, 5.129413632676005, 3.430325067602098, 5.752295209094882, 9.470498766750097, 12.6607277803123, 17.874252274632454, 34.24499362707138, 55.67449852824211, 63.21985624730587, 38.5468377918005, 17.34216682612896, 10.987805798649788, 5.872495584189892, 13.259904328733683, 10.095900557935238, 12.639437522739172, 16.71431891620159, 15.974682904779911, 15.434596985578537, 7.0755366794765, 2.601100313477218, 4.337508575990796, 8.36577644571662, 63.31398479640484, 118.89820396900177, 137.9578596353531, 147.11503386497498, 138.26866775751114, 127.72812455892563, 115.96630409359932, 107.92741745710373, 84.18948322534561, 65.13627961277962, 51.76294282078743, 43.82567033171654, 24.956276156008244, 10.447869971394539, 2.7657024934887886, 0.5322659981902689, 0.07492517368518747, 0.03588757506804541, 0.04936357792757917, 0.032753407504060306, 0.2529279061127454, 0.027442589453130495, 0.038096551652415656, 2.1850323770195246, 25.37986982613802, 64.85812693834305, 93.59440416097641, 75.93375742435455, 54.40572001039982, 34.226226434111595, 19.888828173279762, 36.53922691941261, 46.10297553241253, 63.2460368424654, 70.76573073863983, 64.2888642847538, 44.67240549623966, 22.658178471028805, 6.470129890367389, 0.6931612989865243, 0.03875236528983805, 0.08564974938053638, 0.07205360394436866, 0.04757857917866204, 0.0712863048829604, 0.06573360791662708, 0.054699152169632725, 0.03857597534079105, 0.07723301547230221, 0.04995345545466989, 0.04713203634310048, 0.08742225778405555, 0.03826789128652308, 0.01598114275111584, 0.0277845265736687, 0.05296834133332595, 0.018037509653368033, 0.041018483534571715, 0.020004904181405436, 0.039633795531699434, 0.02916170960816089, 0.018545196180639323, 0.01421917841071263, 0.0437132699880749, 0.04421741090482101, 0.003397736209080904, 0.02771424889942864, 0.014545539706887212, 0.03708649608597625, 0.05548673783778213, 0.017125610538641922, 0.01564601669088006, 0.05097307359392289, 0.032274384575430304, 0.06458704912802204, 0.04136346346058417, 0.014901105441822438, 0.07916941234725527, 0.10271090810419992, 0.08691709270351566, 0.04569266318867449, 0.0762308860430494, 0.0422480478300713, 0.024173146921384614, 0.004870947122981306, 0.10215007452643476, 0.025066386588150635, 0.029559545291704126, 0.006241420678634313, 0.02984197886689799, 0.035928048091591336, 0.02429555490380153, 0.035772056071436964, 0.01152858045315952, 0.0319248998130206, 0.05237777360889595, 0.016806759776955005, 0.059456745511852205, 0.011912867303180974, 0.03211166498658713, 0.030523114583047573, 0.047463668743148446, 0.052694084370159544, 0.12774739356245846, 0.03852418827591464, 0.08283077564556152, 0.014769815807085251, 0.021615835903503466, 0.05978365043119993, 0.04513362560828682, 0.03868996922392398, 0.02960789806820685, 0.03369701487827115, 0.05285962783091236, 0.08123329535010271, 0.04789307538885623, 0.042463419085834175, 0.033622911432757974, 0.042340764339314774, 0.05320105658029206, 0.02980732428113697, 0.038506773780682124, 0.3793740179389715, 15.380371995270252, 58.935825526714325, 76.97449877858162, 95.00161305069923, 89.28054884076118, 86.39797791838646, 67.80783265829086, 53.18401336669922, 47.510135024785995, 99.2366985976696, 88.81752848625183, 31.898904517292976, 32.46889293193817, 35.068189054727554, 49.19138140976429, 54.66091811656952, 24.95771437883377, 5.033895308151841, 0.088253299909411, 0.37435460602864623, 0.03467543639999349, 0.14835082314675674, 0.239769286417868, 0.3045725973788649, 0.34454440406989306, 1.588640722911805, 1.9576791767030954, 5.385456243529916, 6.715099895372987, 4.937388086691499, 4.48000805452466, 2.5858384324237704, 5.2979132160544395, 9.168314281851053, 12.542643416672945, 19.468424431979656, 39.288949370384216, 62.13416330516338, 69.95990797877312, 45.517955124378204, 17.700229212641716, 1.9891167897731066, 3.5329516232013702, 7.160563291981816, 8.626643847674131, 8.284494057297707, 8.455141000449657, 4.566214503720403, 3.0861784843727946, 3.447578279301524, 3.3143315417692065, 3.891622214578092, 12.801343984901905, 73.3451235294342, 128.11488300561905, 144.46905344724655, 152.5572082400322, 143.01649779081345, 136.09092861413956, 125.91017290949821, 116.681889295578, 94.88748237490654, 78.67642745375633, 64.10589650273323, 53.25284667313099, 34.34473067522049, 15.633231326937675, 6.133212894201279, 0.3894639015197754, 0.04445694277819712, 0.09177145839203149, 0.15481294045457616, 0.14627542201196775, 0.28891497349832207, 0.037932310660835356, 0.19958170771133155, 2.4151572911068797, 26.29340160638094, 53.15141871571541, 60.35621590912342, 47.06060394644737, 33.85468237102032, 35.58267004787922, 31.76025565713644, 57.98827797174454, 64.9692253768444, 77.18744695186615, 90.48395186662674, 85.4522542655468, 61.45155653357506, 26.92386757582426, 5.883949119597673, 0.3970725182443857, 0.14599230751628056, 0.19974594499217346, 0.08239099377533421, 0.013560057577706175, 0.07756963139399886, 0.013551893953263061, 0.04446346254553646, 0.011698482176143443, 0.05535050921025686, 0.04807014440302737, 0.037828064887435175, 0.04967757689883001, 0.05661286901158746, 0.0791573227616027, 0.039890749321784824, 0.050756611381075345, 0.036458249524002895, 0.0806596597249154, 0.014754355015611509, 0.038258681233855896, 0.04158900956099387, 0.06126215332187712, 0.046885253686923534, 0.01479562863096362, 0.0684896920574829, 0.05270281202683691, 0.02673451748705702, 0.02689739292691229, 0.037860266675124876, 0.04452884204511065, 0.061125642678234726, 0.05710052682843525, 0.03406258940231055, 0.03413768361497205, 0.013212356752774213, 0.04654816279071383, 0.06162943478557281, 0.05172786375624128, 0.04388273569929879, 0.07066741309245117, 0.04805090793524869, 0.02123359274264658, 0.0308877540010144, 0.018864087760448456, 0.07088181213475764, 0.20030827028676867, 0.14937320578610525, 0.10514501889701933, 0.16963028989266604, 0.07750408491119742, 0.14675413694931194, 0.045608358923345804, 0.22037013986846432, 0.08223305732826702, 0.13058953714789823, 0.13992410735227168, 0.07775839665555395, 0.1314827415626496, 0.18306345969904214, 0.14859203598462045, 0.17020545434206724, 0.09883619961328804, 0.16547300125239417, 0.18408955307677388, 0.17067407607100904, 0.16878531023394316, 0.08938874874729663, 0.20159680192591622, 0.12692832970060408, 0.08954906748840585, 0.09287578155635856, 0.1021178653172683, 0.15459353191545233, 0.16603117052000016, 0.13639035634696484, 0.16213372262427583, 0.16154717362951487, 0.1087903740699403, 0.16377646650653332, 0.18574985617306083, 0.13290074828546494, 0.1423482139944099, 1.3170625269412994, 32.57518082857132, 87.09224626421928, 101.60120531916618, 116.09685748815536, 104.76765140891075, 101.38853073120117, 72.75130659341812, 53.47756281495094, 47.410181388258934, 122.44576200842857, 141.67845278978348, 54.90868762135506, 68.0615146458149, 92.6408377289772, 108.83999168872833, 72.67956644296646, 28.215484768152237, 6.306437999010086, 0.7950492098461837, 0.5835897254291922, 0.14001352130435407, 0.34020966792013496, 0.33259894349612296, 0.2516173030016944, 0.17854565056040883, 1.112171346321702, 1.5324717806652188, 4.418644197285175, 10.363334007561207, 9.598917625844479, 13.30107606947422, 14.894257429987192, 16.37035757303238, 21.892105378210545, 21.95082552731037, 24.87365908920765, 41.202963665127754, 60.84432251751423, 74.18895944952965, 46.739619970321655, 26.454372368752956, 34.15874965488911, 23.78118921071291, 30.37978023290634, 24.17346116155386, 28.831747099757195, 41.82787053287029, 34.208055809140205, 38.173701614141464, 18.866470232605934, 16.568002067506313, 13.629833478480577, 12.968476116657257, 67.75294080376625, 129.2496693134308, 149.36043977737427, 164.18640822172165, 146.53807282447815, 140.8031165599823, 124.31938827037811, 116.29964500665665, 89.88225415349007, 74.60894331336021, 58.14862936735153, 58.898241743445396, 38.58912572264671, 18.763528056442738, 8.967104628682137, 1.139773540198803, 0.126819679280743, 0.1612080418271944, 0.26538283622357994, 0.19787788507528603, 0.7435242715291679, 0.10165741463424638, 0.5744724709074944, 3.973972820676863, 39.22507859766483, 95.31847044825554, 126.48948982357979, 104.33722570538521, 74.54107895493507, 48.62048104405403, 31.161307096481323, 54.57261845469475, 67.39030346274376, 90.82789421081543, 108.90660971403122, 108.04704263806343, 80.49815610051155, 37.233449667692184, 9.586567338556051, 1.9725798396393657, 0.41097131150308996, 0.31269041646737605, 0.14296063425717875, 0.1052267145132646, 0.1489947846857831, 0.29878556728363037, 0.15827249153517187, 0.0912243100174237, 0.18550894019426778, 0.15276516205631196, 0.20960086461855099, 0.2181598756578751, 0.13040793361142278, 0.19005806796485558, 0.0959286282886751, 0.15732004889287055, 0.1344442373374477, 0.13842767046298832, 0.09945463869371451, 0.22825921420007944, 0.17508170596556738, 0.1713688747258857, 0.1260326465126127, 0.14480844838544726, 0.11942345037823543, 0.11192347665200941, 0.1387740604695864, 0.19043834443436936, 0.15049358160467818, 0.1492877400596626, 0.1749652184662409, 0.21835549094248563, 0.19565435126423836, 0.07797647675033659, 0.10996848155627958, 0.12543110613478348, 0.14577237947378308, 0.11640894299489446, 0.207133372023236, 0.18473722535418347, 0.11423888834542595, 0.1283027426688932, 0.1117105915909633, 0.10241254247375764, 0.1277532713720575], [0.026541744628048036, 0.01440555117369513, 0.022996926345513202, 0.04625931891496293, 0.05404200637713075, 0.0450303631805582, 0.024864377701305784, 0.02105315066728508, 0.03579875854484271, 0.08212298940634355, 0.04428779619047418, 0.13906458159908652, 0.047011144197313115, 0.028177855565445498, 0.06725101789925247, 0.06108982292062137, 0.013090904285490979, 0.06845130817964673, 0.06994478389970027, 0.04987980100850109, 0.014427743244596059, 0.07316243936656974, 0.019875067300745286, 0.016078809385362547, 0.023952133487910032, 0.10741841018898413, 0.08011582875042222, 0.03772162977838889, 0.02120882913004607, 0.06059266932425089, 0.04088970606971998, 0.08444603779935278, 0.038437323601101525, 0.04377310564450454, 0.02551196277636336, 0.00816286188637605, 0.1800108578754589, 27.91777454316616, 75.9917651116848, 93.08258682489395, 96.43846035003662, 81.61508336663246, 46.17680177092552, 35.676608607172966, 22.32776340097189, 28.614231571555138, 20.58003008365631, 34.210996851325035, 70.13187155127525, 83.16754326224327, 93.92228096723557, 76.94946572184563, 22.74492971599102, 1.8617269629612565, 0.36272153025493026, 0.17131426749983802, 0.1415519043803215, 0.056916566973086447, 0.15166357741691172, 0.22911562293302268, 0.20228662819135934, 0.30797724437434226, 1.0978275910019875, 1.2228711624629796, 3.671470577828586, 5.118052242323756, 4.121189983561635, 7.842352632433176, 4.391992427408695, 15.378623139113188, 29.84002109616995, 62.48437911272049, 81.31236881017685, 115.17345383763313, 123.35816144943237, 130.42742371559143, 128.16634744405746, 135.6246480345726, 116.76867663860321, 52.97864958643913, 15.845881216228008, 11.177333928644657, 11.218409724533558, 10.963508002460003, 10.809614360332489, 3.0931767588481307, 6.173667898401618, 5.869180737063289, 2.6877601258456707, 24.02035977691412, 124.0674389898777, 141.1130279302597, 118.56091126799583, 111.98581248521805, 105.99550992250443, 110.24215444922447, 117.14607998728752, 123.24824094772339, 122.34172359108925, 129.2751431465149, 130.83131164312363, 130.50571471452713, 127.5821515917778, 114.37561064958572, 103.81717041134834, 73.07640194892883, 35.750165060162544, 8.674495629966259, 0.6171000679023564, 0.1609557561459951, 7.344940798357129, 0.25482851662673056, 0.09791120159206912, 0.23147963045630604, 0.028831431627622806, 0.33112533506937325, 7.9929993487894535, 33.08276139199734, 61.834659576416016, 92.33251467347145, 63.338618874549866, 47.44197428226471, 18.120165579020977, 27.204649709165096, 47.741485610604286, 46.98228634893894, 45.066858530044556, 58.20153772830963, 47.9236364364624, 32.19170920550823, 13.320465479046106, 3.368991846218705, 0.15024582302430645, 0.06653778429608792, 0.01870436088211136, 0.04732754772703629, 0.08981573599157855, 0.1256710573215969, 0.02593524299300043, 0.029984615939611103, 0.018928934769064654, 0.032205004899878986, 0.059545383919612505, 0.04918273880321067, 0.02349744929233566, 0.047283601452363655, 0.08424305298831314, 0.024949841572379228, 0.07361733878497034, 0.042296814353903756, 0.04951732866175007, 0.03237910903408192, 0.05707419171812944, 0.012823014949390199, 0.07393796884571202, 0.012628159438463626, 0.04433290763699915, 0.03251149333664216, 0.02220780628704233, 0.0307774485918344, 0.06253167855902575, 0.04614569239492994, 0.005550711721298285, 0.07019216398475692, 0.03804155108809937, 0.013381681455939543, 0.03895155401551165, 0.015469861446035793, 0.054941211055847816, 0.06607544113649055, 0.0160272523862659, 0.023972371855052188, 0.027411341325205285, 0.053730174477095716, 0.06931157608050853, 0.05072828731499612, 0.049085087011917494, 0.04735150796477683, 0.07370969906332903, 0.06502905001980253, 0.061314096237765625, 0.04951433038513642, 0.022978066517680418, 0.011678885766741587, 0.06829680787632242, 0.04639208913431503, 0.027778509611380287, 0.028605104416783433, 0.03968563825765159, 0.045434158309944905, 0.014661938148492482, 0.0629265456518624, 0.022315554997476283, 0.019824232040264178, 0.04904193483525887, 0.05304222213453613, 0.042600564265740104, 0.017608821035537403, 0.10308397831977345, 0.008575309529987862, 0.052800304256379604, 0.08049803480389528, 0.0378829912369838, 0.0819289474748075, 0.025576655789336655, 0.07830062459106557, 0.019065723718085792, 0.07304926184588112, 0.05450270567962434, 0.040996712632477283, 0.06188460742123425, 0.08254058106103912, 0.1805396084091626, 27.4734415858984, 81.07017740607262, 102.914247661829, 103.9740563929081, 100.1189124584198, 64.95591089129448, 61.9503253698349, 38.42046417295933, 35.42710639536381, 29.43407367914915, 57.88588486611843, 87.03243747353554, 46.19600594043732, 43.260367065668106, 56.82790383696556, 28.773942701518536, 3.4744492499157786, 0.28836468583904207, 0.5620235076639801, 0.057878486841218546, 0.2955311012919992, 0.4396336484933272, 0.3709366300608963, 1.1904757632873952, 2.5805621780455112, 4.898281060159206, 5.896527394652367, 8.547962419688702, 10.602424778044224, 4.7301191836595535, 2.4002155428752303, 7.148824771866202, 18.995553106069565, 37.58318670094013, 61.40396028757095, 88.05407345294952, 123.85556995868683, 130.87154388427734, 133.81295084953308, 134.22383040189743, 139.59997951984406, 126.16359651088715, 60.872942581772804, 17.448823302984238, 4.774179244413972, 1.1538709024898708, 2.8743942361325026, 2.131586344912648, 2.5975653156638145, 2.7407565945759416, 4.710594406351447, 5.688118077814579, 31.48477803915739, 134.0672332048416, 139.229134619236, 121.82156950235367, 114.75729256868362, 112.1354028582573, 113.68749037384987, 120.78345000743866, 121.91208064556122, 126.69477760791779, 133.15792679786682, 134.0814444422722, 133.8860285282135, 132.4079230427742, 121.63258284330368, 114.88260984420776, 82.22105205059052, 46.00264951586723, 13.40414173901081, 1.0474219894967973, 0.662674109917134, 11.940256040543318, 0.9370699734427035, 0.0909777834021952, 0.15292028576368466, 0.021863564797968138, 0.5327906075399369, 8.57631554827094, 35.199038833379745, 54.16418977081776, 58.193618953228, 43.114929869771004, 39.24756579101086, 26.569363698363304, 43.647159710526466, 66.7479707300663, 71.69869467616081, 66.36349216103554, 80.09172230958939, 64.77037444710732, 38.34374628961086, 14.560282900929451, 3.2792394747957587, 0.1036931702401489, 0.062196350263548084, 0.10778490497614257, 0.0884241348830983, 0.10939708721707575, 0.06752723784302361, 0.025888901436701417, 0.053550567317870446, 0.03461283624346834, 0.03315456800919492, 0.04602182423695922, 0.040439864387735724, 0.06032382632838562, 0.06016110673954245, 0.14444659202126786, 0.0533353222272126, 0.012661479086091276, 0.05168553165276535, 0.006145928537080181, 0.07091597319231369, 0.01792945109627908, 0.033944257666007616, 0.04470896128623281, 0.05736396698921453, 0.022610139385506045, 0.05064763070549816, 0.03291521054052282, 0.08733638387639076, 0.025179122530971654, 0.040999306438607164, 0.08810608749627136, 0.04528481593297329, 0.02648037643666612, 0.080744999286253, 0.024704543211555574, 0.05939498027146328, 0.03980501271144021, 0.08366268608369865, 0.055561108456458896, 0.06466752020060085, 0.03328094091557432, 0.0489287461823551, 0.025354291647090577, 0.038175423396751285, 0.14171492453897372, 0.07295420014997944, 0.20157147984718904, 0.1360879311687313, 0.17089048633351922, 0.20894510293146595, 0.06640508087002672, 0.13337708835024387, 0.15431087755132467, 0.1103023812174797, 0.13289432128658518, 0.2434511700994335, 0.16679884807672352, 0.17256809631362557, 0.20186879904940724, 0.16381526598706841, 0.11670278894598596, 0.10414341639261693, 0.1396973367081955, 0.1405750450794585, 0.11914887058082968, 0.33214667870197445, 0.28041034704074264, 0.0946532771922648, 0.10802730525028892, 0.17554928868776187, 0.2226792581495829, 0.21532981423661113, 0.09804679197259247, 0.141228090506047, 0.1437378113041632, 0.11445702039054595, 0.1677988178562373, 0.15081948833540082, 0.16907967568840832, 0.19247001822805032, 0.4127420164877549, 51.26416638493538, 107.11730852723122, 114.77721869945526, 123.0030021071434, 106.0476279258728, 70.57425141334534, 57.68103785812855, 39.29178021848202, 41.56091585755348, 31.09472516924143, 45.57779811322689, 81.81450426578522, 113.15265387296677, 132.22025871276855, 109.93513852357864, 37.682688161730766, 3.9288134314119816, 1.4366032811813056, 0.8238888904452324, 0.5140775616746396, 0.5589444853831083, 0.4189050482818857, 0.25693556293845177, 0.7564729079604149, 1.1779238493181765, 3.268873393535614, 4.034197926521301, 8.440498486161232, 16.39711193740368, 18.118210583925247, 22.705482132732868, 12.910823710262775, 22.6763528957963, 40.98047040402889, 68.70485812425613, 87.52834126353264, 125.41924685239792, 132.229226231575, 141.30798786878586, 140.02573907375336, 148.03189426660538, 127.8330597281456, 63.72441977262497, 29.40043218433857, 26.181345619261265, 30.948482416570187, 30.99494632333517, 32.955684810876846, 18.13974592834711, 11.999031286686659, 13.870941940695047, 12.45313921943307, 30.561224296689034, 137.52603560686111, 149.24904495477676, 130.71721136569977, 122.54271000623703, 115.87952435016632, 122.08298787474632, 127.99458146095276, 131.28617763519287, 137.23519921302795, 144.46046590805054, 143.50141257047653, 143.317608833313, 138.30453783273697, 123.39057371020317, 116.58956944942474, 82.01311960816383, 45.29154807329178, 16.042577661573887, 1.8825972243212163, 0.8608388795983046, 11.043578255921602, 0.532481458503753, 0.3066298901103437, 0.31638874614145607, 0.0760880894085858, 1.0029890737496316, 13.384623136371374, 50.95807760953903, 87.27494806051254, 124.89634931087494, 88.22497308254242, 68.28599900007248, 28.098665736615658, 39.25910957157612, 68.36545273661613, 74.99263152480125, 73.99404510855675, 99.56158116459846, 84.24771890044212, 49.28593173623085, 20.89349616318941, 4.941754527390003, 0.3214248118456453, 0.21988021850120276, 0.1871538659906946, 0.12017861532513052, 0.22859223070554435, 0.262256910209544, 0.12696742604020983, 0.20430792676052079, 0.25943838176317513, 0.13666826096596196, 0.11986169600277208, 0.08639709951239638, 0.2453197940485552, 0.17369546316331252, 0.26377614587545395, 0.11561359817278571, 0.1389431959250942, 0.12059948727255687, 0.15552552096778527, 0.12256476111360826, 0.08878824737621471, 0.11133033738587983, 0.1257932890439406, 0.2086050805519335, 0.1984124243608676, 0.22615172259975225, 0.07318167583434843, 0.2225739770801738, 0.11014848947525024, 0.1580633394769393, 0.24586803338024765, 0.2546825213357806, 0.12034714221954346, 0.09052654277184047, 0.17876816127682105, 0.1632864709245041, 0.13681783340871334, 0.14506678999168798, 0.16740592487622052, 0.08089184062555432, 0.14995571749750525, 0.09189374948618934, 0.14608672354370356, 0.12828447099309415], [0.06677067023701966, 0.06391326809534803, 0.03999355532869231, 0.05693690553016495, 0.04695496732892934, 0.06896002814755775, 0.06745680060703307, 0.08183242374798283, 0.03961887465266045, 0.042609755764715374, 0.024193756362365093, 0.04357950158009771, 0.04239195397531148, 0.020886679521936458, 0.0335977637587348, 0.034168067140853964, 0.03906525103957392, 0.10109567563631572, 0.025553795785526745, 0.06211267311300617, 0.04106315340322908, 0.1134622011159081, 0.08122663086396642, 0.11441719674621709, 0.021713446876674425, 0.11109976694569923, 0.11466741925687529, 0.04957297118380666, 0.0659189815632999, 0.07297539588762447, 0.06179158663144335, 0.17066989035811275, 0.0645413996244315, 0.061274101899471134, 0.08675922304973938, 0.21758582442998886, 22.2025753185153, 67.4723182618618, 80.26980355381966, 89.64619562029839, 88.3276055753231, 42.834375724196434, 22.92404070496559, 8.536124154925346, 51.234440580010414, 81.43850684165955, 54.610038846731186, 53.35673689842224, 41.27591215074062, 38.43605473637581, 23.750956133008003, 4.331821706146002, 0.5143859388772398, 0.1689873228315264, 0.03478776787233073, 0.044503876197268255, 0.06971452516154386, 0.11068109175539576, 0.011967213849857217, 0.22529515059432015, 0.4593006509821862, 1.1915211821906269, 2.8470623027533293, 7.600516509264708, 8.505170065909624, 11.954988799989223, 7.532694423571229, 17.051043547689915, 54.65202659368515, 80.23346990346909, 106.56351864337921, 108.45620468258858, 117.51286670565605, 104.19342622160912, 102.08171233534813, 94.54961210489273, 96.47423923015594, 92.08626508712769, 114.20373067259789, 107.3253321647644, 97.22943350672722, 40.97088351845741, 5.542119462043047, 4.164265897125006, 10.757441259920597, 20.794275887310505, 50.84917925298214, 77.0568935573101, 57.69284002482891, 82.13675737380981, 122.22006171941757, 97.24278599023819, 108.86759340763092, 108.16505670547485, 109.13943082094193, 107.13112458586693, 105.61978608369827, 104.7664126753807, 102.991603910923, 101.40334233641624, 102.78006166219711, 98.87341529130936, 104.2104797065258, 109.9477006494999, 116.04144126176834, 120.01884743571281, 114.11493703722954, 79.61696818470955, 26.193430870771408, 3.1396373407915235, 12.524371147155762, 5.909737860783935, 0.18039442948065698, 0.12431292707333341, 0.09933626613928936, 0.025020802022481803, 0.08595841602073051, 1.0531465010717511, 14.704519361257553, 42.65014261007309, 72.92361974716187, 69.8826353251934, 64.5414063334465, 28.565058410167694, 39.6947979927063, 48.97910580039024, 33.072547540068626, 50.25923430919647, 50.16059920191765, 55.65868377685547, 35.61811834573746, 28.736776895821095, 11.953239943832159, 2.833449295721948, 0.1282624588930048, 0.040493696069461294, 0.06460292366682552, 0.040545431184000336, 0.022627603975706734, 0.003704368668877578, 0.036469025508267805, 0.04921295534586534, 0.04488012280489784, 0.006933535078132991, 0.1502415630966425, 0.0517412483895896, 0.04910870215098839, 0.06675478827673942, 0.06439833581680432, 0.04863736416155007, 0.04533055078354664, 0.02529625013266923, 0.035189043410355225, 0.03613236876844894, 0.03571646549971774, 0.0764474002062343, 0.014241366770875175, 0.04111406102310866, 0.021158236922929063, 0.07183861118392088, 0.03432152843743097, 0.0490067162172636, 0.13370962988119572, 0.03617173970269505, 0.04841404079343192, 0.08560323156416416, 0.0626637511595618, 0.0503492836287478, 0.026843466621357948, 0.0331546830420848, 0.03132526675472036, 0.04522036040725652, 0.044256689070607536, 0.09552118921419606, 0.11561068895389326, 0.1185620173055213, 0.057967663306044415, 0.07936622991110198, 0.11414372274884954, 0.0940444489242509, 0.041118461958831176, 0.0755652463703882, 0.07511663294280879, 0.06939209168194793, 0.02833960850693984, 0.033331521990476176, 0.03254450777603779, 0.009862813294603257, 0.0216186171019217, 0.02741765700193355, 0.050239790871273726, 0.024554577430535574, 0.041238359626731835, 0.032844702800503, 0.11184373288415372, 0.06519318339996971, 0.049313156414427795, 0.12010934326099232, 0.06454583766753785, 0.02395673294813605, 0.05913637149205897, 0.0741943289176561, 0.1990727279917337, 0.03092454411671497, 0.017729974788380787, 0.10185176084632985, 0.11259244114626199, 0.15974823734723032, 0.05581443685514387, 0.014291559145931387, 0.07157942352932878, 0.360753710847348, 21.187019012868404, 80.8454954624176, 96.04148045182228, 103.30947205424309, 99.79498744010925, 60.58505102992058, 36.85688227415085, 19.951798394322395, 41.61025620996952, 61.85329757630825, 30.82931511104107, 28.21548856794834, 34.83265109360218, 42.09446422755718, 33.58170501887798, 7.549319956451654, 0.43535469216294587, 0.10409748487290926, 0.04951646777044516, 0.11684667653753422, 0.19727558770682663, 0.20250073779607192, 0.21621978288749233, 1.2274099001660943, 2.802810352295637, 4.96077393181622, 10.713578313589096, 6.57590813934803, 8.813673611730337, 4.496266432106495, 6.499260077252984, 18.41516464948654, 57.536808997392654, 87.06485733389854, 108.17689687013626, 111.70966610312462, 118.2461741566658, 108.2618223130703, 105.07429495453835, 99.45361375808716, 101.17213994264603, 98.65170478820801, 116.72024443745613, 118.40330332517624, 109.17571887373924, 45.52144333720207, 5.420217728242278, 3.177954009734094, 10.032915137708187, 23.477017432451248, 55.479964166879654, 86.87303602695465, 73.8721552491188, 82.87861436605453, 120.05979403853416, 103.98205116391182, 113.19569036364555, 113.68395656347275, 114.61851641535759, 109.9086083471775, 111.8113486468792, 110.66314145922661, 108.42282727360725, 108.53852346539497, 108.02518621087074, 103.9873556792736, 109.76645037531853, 113.38021606206894, 118.5188627243042, 122.68353044986725, 122.98940643668175, 89.15154576301575, 34.00263503193855, 4.076621700078249, 10.318226628005505, 2.7567843720316887, 0.6426098803058267, 0.11896281415829435, 0.10989936534315348, 0.036864994690404274, 0.26182676141615957, 1.5745459729805589, 16.333250664174557, 46.96277819573879, 49.756122305989265, 44.27722290158272, 34.859812036156654, 25.87068758904934, 39.241227731108665, 46.55440270900726, 45.84893636405468, 69.61519047617912, 70.27884006500244, 75.35678878426552, 46.449820920825005, 30.19944190979004, 12.14445423334837, 2.380638518370688, 0.23689205409027636, 0.031347534895758145, 0.07123450297513045, 0.061252817104104906, 0.054118881744216196, 0.03054296517802868, 0.05373775180487428, 0.046481952085741796, 0.08271350889117457, 0.024587410043750424, 0.016086538853414822, 0.12915331812109798, 0.032501834284630604, 0.02899852246628143, 0.059623650813591667, 0.0678635791700799, 0.022978554479777813, 0.044204738733242266, 0.06420110265025869, 0.0651726927026175, 0.047758776345290244, 0.008509024610248161, 0.032961219985736534, 0.09112335566896945, 0.07896414172137156, 0.027158556549693458, 0.043587847030721605, 0.08106279434286989, 0.06103874089603778, 0.034663729020394385, 0.05607848928775638, 0.06598175983526744, 0.02700912140426226, 0.024428907709079795, 0.017711165055516176, 0.055565468574059196, 0.02899267063185107, 0.05558971824939363, 0.04283080816094298, 0.012327842887316365, 0.04394719122501556, 0.03740143758477643, 0.10923696143436246, 0.16794007824501023, 0.192236865113955, 0.27883773611392826, 0.1441207595053129, 0.11705428492859937, 0.1818885063403286, 0.15714603010565042, 0.08152685928507708, 0.1655850952374749, 0.0768901506671682, 0.2372998493956402, 0.08263876719865948, 0.10597338929073885, 0.18339417554670945, 0.13344595965463668, 0.17666283674770966, 0.24171130877221003, 0.14235827751690522, 0.1736881455872208, 0.13167667959351093, 0.20517203898634762, 0.17485417833086103, 0.25059771083761007, 0.11366301885573193, 0.21802519069751725, 0.3712318267207593, 0.1582065739785321, 0.15603705367539078, 0.1829829515190795, 0.19194741267710924, 0.32505361712537706, 0.211512221430894, 0.17520846478873864, 0.12726001034025103, 0.9664761205203831, 43.603511452674866, 100.44430419802666, 106.43405199050903, 114.839246571064, 112.58081495761871, 67.34989643096924, 35.223289132118225, 17.70115826278925, 65.44392630457878, 103.22590693831444, 81.8325836956501, 78.96252170205116, 60.965650007128716, 63.538978323340416, 42.45637580752373, 8.684373199939728, 0.9136082511395216, 0.6186552532017231, 0.16489160276250914, 0.24925593752413988, 0.1348959974711761, 0.27077249076683074, 0.13689834158867598, 0.816978783113882, 2.3178096022456884, 5.306673645973206, 14.149171561002731, 19.765002317726612, 24.366202019155025, 26.428429260849953, 20.149235799908638, 22.915092185139656, 60.81160247325897, 85.63108786940575, 111.16115033626556, 112.54136547446251, 122.26581886410713, 112.58436396718025, 110.92344269156456, 101.75326555967331, 107.16208532452583, 107.61898800730705, 125.28157263994217, 129.60455507040024, 112.72073104977608, 49.54855464398861, 12.596193943172693, 12.795540746301413, 17.98869453370571, 27.479494661092758, 58.08520697057247, 89.6616379916668, 91.41395956277847, 97.26522758603096, 126.8401426076889, 109.04709577560425, 118.53476107120514, 117.19865396618843, 119.21882316470146, 114.20284911990166, 114.77194458246231, 114.61959555745125, 112.10639521479607, 110.41966572403908, 114.5500136911869, 110.46701118350029, 114.33312892913818, 119.37259331345558, 126.12803041934967, 130.41717946529388, 127.71687716245651, 91.5258863568306, 34.854735508561134, 7.9232431668788195, 15.954183004796505, 9.859510492533445, 0.3190517204347998, 0.28957260539755225, 0.30380186217371374, 0.112531265913276, 0.25596910854801536, 3.0519525334239006, 24.838104397058487, 68.15869063138962, 98.88983801007271, 99.41176280379295, 85.81137299537659, 39.31441940367222, 50.321596562862396, 64.56554263830185, 53.28247368335724, 79.94719326496124, 85.21651491522789, 96.55496969819069, 63.46001096069813, 42.201048508286476, 18.30633468925953, 4.858354227617383, 1.0281079821288586, 0.15499739383812994, 0.11178629807545803, 0.09978813759516925, 0.21224003081442788, 0.061047802519169636, 0.18225692328996956, 0.20783280167961493, 0.15251520671881735, 0.13669098552782089, 0.18941658519906923, 0.1821772166294977, 0.23638884827960283, 0.13810764154186472, 0.14055969746550545, 0.18718178558629006, 0.14472930575720966, 0.18456997495377436, 0.12942347471835092, 0.2198207873152569, 0.15720283408882096, 0.14638382010161877, 0.12666611408349127, 0.18806598032824695, 0.17983149562496692, 0.1210223555972334, 0.0708136310277041, 0.19590512296417728, 0.36447676888201386, 0.13215503829997033, 0.14912017795722932, 0.1094322204880882, 0.19538370484951884, 0.16504304541740566, 0.09120864327996969, 0.11554250042536296, 0.2178196157910861, 0.1561196250258945, 0.16648419230477884, 0.46083918248768896, 0.22723304660758004, 0.2508539892733097], [0.051064298386336304, 0.08089804498013109, 0.013883056017220952, 0.19585051573812962, 0.2189031068701297, 0.06555113606736995, 0.022181942440511193, 0.07744903239654377, 0.01481751271057874, 0.02911226958531188, 0.04992297173885163, 0.019471787963993847, 0.035766066939686425, 0.055271848978009075, 0.03319574236229528, 0.008010947040020255, 0.08556434302590787, 0.10083066212246194, 0.19250405312050134, 0.0782387814251706, 0.12884305586339906, 0.3901639545802027, 0.10659442588803358, 0.19681845442391932, 0.06859782297397032, 0.07039397620246746, 0.3792411438189447, 0.567283375421539, 0.124463605316123, 0.14437634032219648, 0.08073531425907277, 0.2114061388419941, 0.22946695564314723, 0.08769591731834225, 0.8500814193394035, 25.250566564500332, 82.44943499565125, 75.59604674577713, 71.22600004076958, 71.12888485193253, 40.01692570745945, 21.281785927712917, 29.352484457194805, 57.29536235332489, 68.95904928445816, 60.77192880213261, 54.003112614154816, 57.86804102361202, 29.30663611739874, 8.454541582614183, 1.4069518097676337, 0.10114297270774841, 0.016571231790294405, 0.07166656650952064, 0.04450109314348083, 0.04114357252547052, 0.04418137592438143, 0.18629261845489964, 1.3050720328465104, 0.9086060570552945, 2.66087110619992, 10.0519635155797, 12.049956154078245, 8.368934076279402, 10.72883639484644, 15.237594656646252, 36.592256873846054, 85.50154522061348, 102.6653154194355, 108.52831721305847, 104.6764487028122, 110.04885882139206, 106.37938052415848, 106.24868273735046, 98.6470690369606, 93.39910224080086, 88.25107008218765, 104.33877602219582, 106.67876645922661, 109.82664674520493, 110.84487810730934, 123.54034647345543, 52.19523422420025, 31.85059580951929, 91.32590308785439, 151.82650744915009, 153.30519050359726, 163.3324572443962, 120.3332881629467, 56.64036110043526, 117.81943425536156, 105.39947390556335, 100.23868963122368, 88.69107127189636, 99.73709374666214, 94.28205326199532, 98.3863878250122, 93.85467499494553, 98.57266142964363, 100.30288338661194, 102.42596626281738, 105.03691256046295, 111.3490578532219, 108.6748069524765, 112.14813217520714, 103.34660366177559, 108.43431025743484, 108.99695366621017, 100.77117025852203, 40.72618044912815, 24.06906556338072, 7.207808531820774, 0.15526014380156994, 0.18550252803834155, 0.05309947140631266, 0.054131205106386915, 0.11452477105194703, 0.04495365108596161, 0.10165114348637871, 3.1502397218719125, 31.77015982568264, 47.25418835878372, 64.66306060552597, 80.49105808138847, 109.47524920105934, 136.280660033226, 32.64362275600433, 30.075148679316044, 37.024198696017265, 55.57071849703789, 54.806237518787384, 60.92612452805042, 43.37844952940941, 24.792096465826035, 7.51355342566967, 1.2929120915941894, 0.2645862742792815, 0.2220993587980047, 0.08012083082576282, 0.13612683454994112, 0.18197797966422513, 0.1649141640518792, 0.05353692664357368, 0.21011723612900823, 0.2886462863534689, 0.208784235001076, 0.8499891555402428, 0.13458459230605513, 0.30098743038251996, 0.19743734621442854, 0.08452761467196979, 0.051105279781040736, 0.05139498825883493, 0.011787936946348054, 0.04700534431322012, 0.03589799853216391, 0.18276988092111424, 0.13232792902272195, 0.07505034431233071, 0.007138183691495215, 0.08008081422303803, 0.039082546791178174, 0.10984951528371312, 0.21527943725232035, 0.2295426992350258, 0.04321418309700675, 0.060344717785483226, 0.04865019589487929, 0.07723236238234676, 0.032842643340700306, 0.0935934903100133, 0.059191724576521665, 0.11446996344602667, 0.039321577714872546, 0.05443579735583626, 0.04927171117742546, 0.08134845440508798, 0.09111128834774718, 0.013714610759052448, 0.14892494858941063, 0.1515171368373558, 0.03592506094719283, 0.023349633884208743, 0.021997227449901402, 0.044630590491578914, 0.04069055074069183, 0.036988499196013436, 0.08987872948637232, 0.029063024376227986, 0.0587113657820737, 0.012955544898431981, 0.04695382813224569, 0.09927581078954972, 0.03961565744248219, 0.04179404269962106, 0.03751993259356823, 0.08444730687187985, 0.25424685096368194, 0.050065953910234384, 0.07728242766461335, 0.13261591200716794, 0.07999531881068833, 0.3684953798074275, 0.43265624321065843, 0.04832521684875246, 0.16204515472054482, 0.16493693314259872, 0.21771052008261904, 0.15586117951897904, 0.14405359514057636, 0.8165732736233622, 23.56967356055975, 98.2896526157856, 84.99310210347176, 85.4773861169815, 81.65371969342232, 68.17998468875885, 33.757069408893585, 28.60420010983944, 31.057658158242702, 60.13797082006931, 61.4039146900177, 43.13346907496452, 55.54746754467487, 34.77565795183182, 12.742069065570831, 1.0968302632682025, 0.33905812189914286, 0.032471228114445694, 0.05096511034935247, 0.17410158121492714, 0.516393359284848, 0.31416393583640456, 1.7394063016399741, 2.9844930907711387, 4.754473501816392, 3.8117353012785316, 5.5599267315119505, 4.956016112118959, 3.8806545780971646, 6.730186035856605, 14.612108319997787, 41.87024965882301, 91.66919946670532, 108.02344590425491, 111.81996658444405, 106.77650481462479, 111.57043397426605, 110.00228852033615, 112.44185641407967, 103.33183005452156, 99.09134119749069, 93.3343081176281, 108.57554867863655, 113.97374421358109, 116.47853940725327, 113.17968562245369, 130.39182722568512, 59.28162597119808, 37.99413464963436, 103.90611603856087, 163.01470309495926, 167.259880900383, 172.89745599031448, 130.14959782361984, 62.226726338267326, 121.76017999649048, 109.49778199195862, 103.3799658715725, 91.28754034638405, 102.90845677256584, 98.35788935422897, 104.62221801280975, 98.04952830076218, 105.48642843961716, 106.31943494081497, 109.6822164952755, 111.12975642085075, 115.72229638695717, 113.75318884849548, 120.00822320580482, 110.51175758242607, 111.6289584338665, 114.59784552454948, 107.09515571594238, 52.32671096920967, 22.795014828443527, 5.250487960875034, 1.409840842243284, 0.22296731534879655, 0.3057295165490359, 0.1293199005885981, 0.04055141289427411, 0.06987515560467727, 0.059379766244092025, 4.3743955716490746, 34.85490269958973, 44.493974670767784, 57.65819728374481, 54.36452642083168, 95.10194286704063, 153.22604835033417, 50.51082260906696, 47.902045994997025, 56.00974693894386, 74.60800856351852, 75.85748791694641, 76.81092515587807, 50.45568376779556, 28.744935058057308, 7.3621738236397505, 1.2954530864953995, 0.2606581459986046, 0.2979889459675178, 0.13936636853031814, 0.14293782063759863, 0.15220990200759843, 0.07905598991783336, 0.1063126398366876, 0.0776500059873797, 0.23713044676696882, 0.2689747716067359, 0.6261657876893878, 0.2566955523798242, 0.2555847947951406, 0.12111178439226933, 0.10263952091918327, 0.06592717487365007, 0.0935735265375115, 0.046037472420721315, 0.04968199638824444, 0.09726041229441762, 0.09917456700350158, 0.033862205818877555, 0.07164718903368339, 0.07717604821664281, 0.05540073034353554, 0.03642241863417439, 0.05606881168205291, 0.20678350876551121, 0.10821644158568233, 0.0322700689866906, 0.022713509424647782, 0.008705835680302698, 0.023473819310311228, 0.08105678294668905, 0.011872618779307231, 0.02781364102702355, 0.05233797593973577, 0.02953864084702218, 0.02152699340513209, 0.020889406914648134, 0.22416149033233523, 0.23135005147196352, 0.12797260569641367, 0.301361057208851, 0.39468556351494044, 0.11812149328761734, 0.17809484037570655, 0.15013160649687052, 0.14443131862208247, 0.18628745310707018, 0.16202575498027727, 0.20999521220801398, 0.15418205555761233, 0.15109967876924202, 0.07615533540956676, 0.16590212588198483, 0.12840944866184145, 0.16585976409260184, 0.37678614899050444, 0.1335047822794877, 0.17240849003428593, 0.39247811946552247, 0.20957393950084224, 0.2578803466167301, 0.22052529326174408, 0.30955653463024646, 0.4136487131472677, 0.4869227937888354, 0.15119163086637855, 0.24132720282068476, 0.27927355491556227, 0.31983489403501153, 0.4354459763271734, 0.18253853864734992, 2.0653506740927696, 47.02703274786472, 117.79402881860733, 102.17654004693031, 96.273283213377, 94.08769369125366, 57.4475821852684, 37.841842621564865, 40.04836522042751, 82.97413364052773, 94.14035126566887, 80.81669300794601, 82.69637614488602, 88.16829532384872, 51.08679950237274, 16.4845547452569, 2.4628117214888334, 0.747849567560479, 0.14523482706863433, 0.13400965050095692, 0.2256208792096004, 0.28490684169810265, 0.18426655529765412, 1.2601609365083277, 3.4190330235287547, 5.842711357399821, 8.990171290934086, 23.315241113305092, 30.798259377479553, 25.650578700006008, 26.77102267742157, 24.955267310142517, 43.93324255943298, 94.96117562055588, 114.03296783566475, 114.12083432078362, 110.55561482906342, 110.65418154001236, 114.19239968061447, 116.44540518522263, 107.62213423848152, 103.2317966222763, 99.78778302669525, 110.87013155221939, 118.36261510848999, 116.50157377123833, 121.21556282043457, 135.19169926643372, 65.18066883087158, 43.17779749631882, 125.91973319649696, 159.18911397457123, 165.27143239974976, 168.75459909439087, 130.26029348373413, 72.7014684677124, 126.05535551905632, 117.83937558531761, 109.37884837388992, 97.51638650894165, 110.00900655984879, 105.1338529586792, 110.54961875081062, 103.0508503317833, 110.93288898468018, 112.95627281069756, 112.91075125336647, 115.29378578066826, 122.17771679162979, 115.86226567626, 123.64832907915115, 114.13349524140358, 120.8037257194519, 122.26079553365707, 119.44909080862999, 51.229193061590195, 36.633925437927246, 14.335823245346546, 1.2591687147505581, 0.25906080671120435, 0.2913290314609185, 0.22848617780255154, 0.19397248135646805, 0.3126598399830982, 0.19721998600289226, 6.9007987808436155, 54.26252469420433, 72.06832364201546, 90.18805414438248, 106.67878165841103, 117.68868327140808, 144.14116144180298, 44.49762627482414, 47.11921580135822, 66.12722083926201, 91.03501349687576, 93.88507336378098, 91.60484611988068, 64.99149978160858, 39.727388843894005, 13.096951972693205, 2.2621053038164973, 0.5363003129605204, 0.4232233384391293, 0.17132596374722198, 0.2634789008880034, 0.4264193231938407, 0.3262367192655802, 0.18412014440400526, 0.28753582562785596, 0.40465729718562216, 0.4294409626163542, 0.6726356910075992, 0.3904725395841524, 0.4197499091969803, 0.3476727643283084, 0.16859817027579993, 0.18577359005576, 0.1613231489318423, 0.14128670532954857, 0.11692269472405314, 0.2634152543032542, 0.29102872882504016, 0.20634740794776008, 0.23193008441012353, 0.15464067313587293, 0.17181441566208377, 0.2816457854351029, 0.23118127224734053, 0.24227553396485746, 0.5797522282227874, 0.08918676583562046, 0.18233465583762154, 0.13572393741924316, 0.12264824530575424, 0.22017443552613258, 0.14062404166907072, 0.18619428388774395, 0.2580410067457706, 0.15469942154595628, 0.10754318005638197, 0.13530646450817585], [0.013321377318789018, 0.057804431635304354, 0.05859769844391849, 0.0759953135275282, 0.04976133939635474, 0.07821063176379539, 0.06476572118117474, 0.00936919324885821, 0.06926625312189572, 0.04779245500685647, 0.05694038620276842, 0.06902277673361823, 0.061198317489470355, 0.027729813591577113, 0.050520957229309715, 0.05335154928616248, 0.006971251486902474, 0.07698659275774844, 0.0918332496075891, 0.12566137971589342, 0.12405166882672347, 0.13186303287511691, 0.06703791761538014, 0.23026905400911346, 0.3959766332991421, 0.17475646716775373, 0.4794545320328325, 0.46970956900622696, 0.21758094109827653, 0.17560459353262559, 0.06287218333454803, 0.1340972536127083, 0.10531223961152136, 1.894748853519559, 35.41772849857807, 96.53642669320107, 101.07768461108208, 103.33355516195297, 71.60933867096901, 57.64310449361801, 17.858287431299686, 23.9715513959527, 66.35137841105461, 66.61006093025208, 38.43102000653744, 32.77080953121185, 30.704558305442333, 12.304236609488726, 2.38032930996269, 0.26164962560869753, 0.16746884415624663, 0.21486588288098574, 0.12110213647247292, 0.12591295293532312, 0.061100806706235744, 0.2380827855085954, 0.6963426782749593, 0.9215378912631422, 2.7833081362769008, 4.198901513591409, 3.536565941758454, 6.542127951979637, 11.642058491706848, 10.901664420962334, 21.919606402516365, 71.47414952516556, 105.7758741080761, 98.63616362214088, 95.27557834982872, 99.36542809009552, 96.09765663743019, 111.58301129937172, 106.39974743127823, 98.16618204116821, 80.85814118385315, 74.76664245128632, 79.15022403001785, 83.80680575966835, 91.45229950547218, 97.23577916622162, 89.459268450737, 106.64344355463982, 89.98653575778008, 47.90720991790295, 115.91455087065697, 93.82613092660904, 92.63870984315872, 83.66191193461418, 112.35585182905197, 73.2824344933033, 112.04274863004684, 90.15633344650269, 90.33510625362396, 92.9961870610714, 102.28035807609558, 103.68488430976868, 102.94901579618454, 95.71096658706665, 98.42533573508263, 98.48109394311905, 104.37817990779877, 102.75496780872345, 107.12910309433937, 109.40720245242119, 106.81955650448799, 110.61850145459175, 108.76877591013908, 102.12460443377495, 104.24287676811218, 102.35662758350372, 66.84920489788055, 35.767986103892326, 13.072275146842003, 1.163792407605797, 0.04641755222110078, 0.03533701652486343, 0.055099047312978655, 0.007828376856195973, 0.023993782815523446, 0.06945890723727643, 0.4175850050523877, 9.770066142082214, 30.96467524766922, 46.86572380363941, 39.82172638177872, 30.429719053208828, 25.92720005661249, 13.993644006550312, 26.075485199689865, 30.52884053438902, 43.991007059812546, 58.172317296266556, 60.914356559515, 63.869860768318176, 46.39286957681179, 16.905034482479095, 4.474570071324706, 0.22386903961887583, 0.21777737274533138, 0.04940038845234085, 0.3500061953673139, 0.05081466217234265, 0.0819461207720451, 0.2442006947239861, 0.2995778841432184, 0.3369130182545632, 0.7392506883479655, 0.4375802743015811, 0.46438175020739436, 0.20572498353431, 0.21377201657742262, 0.0712712095992174, 0.042784728211699985, 0.06917539940332063, 0.1154430081078317, 0.12389104580506682, 0.15451214800123125, 0.1759953491273336, 0.21408696920843795, 0.0481930366368033, 0.01103947173760389, 0.11569105612579733, 0.10272219617036171, 0.07338887604419142, 0.030085946928011253, 0.036790416270378046, 0.026285764906788245, 0.008623008288850542, 0.03804140265856404, 0.04424556056619622, 0.048755573443486355, 0.08855477513861842, 0.037416877967189066, 0.05259245837805793, 0.0026752199619295425, 0.0847975783108268, 0.06782923999708146, 0.021946106462564785, 0.014960536627768306, 0.043123470386490226, 0.10127327157533728, 0.13389429106609896, 0.058966145079466514, 0.032176153908949345, 0.03660601854790002, 0.04488313221372664, 0.031947004681569524, 0.0679651643440593, 0.045294898009160534, 0.030647620988020208, 0.024190936201193836, 0.11270544055150822, 0.04478059337998275, 0.08328013864229433, 0.1110452858847566, 0.08549480378860608, 0.08630864293081686, 0.09530682727927342, 0.049159735935973004, 0.2313946990761906, 0.3011225309455767, 0.12759789533447474, 0.44898007821757346, 0.4685903509380296, 0.12679220497375354, 0.21830417885212228, 0.13766959629720077, 0.12328399869147688, 0.2521430404158309, 1.7227335087954998, 39.90389697253704, 104.52071785926819, 112.85584419965744, 110.66495016217232, 86.6398273408413, 68.43168318271637, 29.995753839612007, 32.08691082894802, 42.62844957411289, 52.10081689059734, 37.3767513781786, 35.57551123201847, 36.84627704322338, 19.673909805715084, 2.962942784652114, 0.2593723899917677, 0.18758098682155833, 0.20337543304776773, 0.22407428798032925, 0.28718342422507703, 0.11406523321056738, 2.02840359415859, 3.4070874145254493, 3.123786491341889, 5.233852453529835, 4.4789279624819756, 3.051562341861427, 4.114328026771545, 7.168788425624371, 13.587244413793087, 27.311879955232143, 73.69014501571655, 109.30651545524597, 100.07630914449692, 97.26477161049843, 102.17429056763649, 99.43499475717545, 114.12084951996803, 109.06567677855492, 99.75854739546776, 82.7879436314106, 77.88078054785728, 82.01441153883934, 88.10651063919067, 95.78364908695221, 102.56234854459763, 95.49512296915054, 111.2408472597599, 96.07723653316498, 54.523848071694374, 125.07343500852585, 104.65735852718353, 101.2692703306675, 96.82099342346191, 116.30885571241379, 84.0231129527092, 112.42669522762299, 95.44495806097984, 95.12508362531662, 95.08642449975014, 107.35041081905365, 108.8697136938572, 108.88557404279709, 101.08949437737465, 105.32372877001762, 105.0836880505085, 108.44570204615593, 107.39296853542328, 112.94523820281029, 115.01377120614052, 113.77891346812248, 115.17431259155273, 116.36596664786339, 110.76679989695549, 113.32139521837234, 109.90182191133499, 79.10827428102493, 39.96775634586811, 14.203994069248438, 2.7188709564507008, 0.2597333409357816, 0.041791467447183095, 0.0715874980960507, 0.17045208485797048, 0.03996931678557303, 0.12136359509895556, 0.5093547119759023, 11.847682558000088, 36.60088241100311, 48.34449045360088, 53.01310233771801, 33.62281881272793, 25.688067488372326, 29.303368292748928, 44.20750044286251, 50.70896677672863, 58.18103402853012, 77.35629469156265, 76.39339596033096, 73.18209707736969, 53.516453728079796, 18.759562969207764, 3.6503192503005266, 0.2372342286980711, 0.14695328485686332, 0.1081656118913088, 0.24455625767586753, 0.04719715238024946, 0.050223827274749056, 0.25952838943339884, 0.30497852247208357, 0.31044351984746754, 0.5308931437321007, 0.22946128563489765, 0.3743827185826376, 0.2329104466480203, 0.11684562268783338, 0.030596778306062333, 0.025473855348536745, 0.045983948730281554, 0.12997782934689894, 0.03158045423333533, 0.05252432179986499, 0.06450265209423378, 0.051247074516140856, 0.09232309676008299, 0.011470228164398577, 0.072391659632558, 0.06531280276249163, 0.06571184072527103, 0.06614404526771978, 0.03651512030046433, 0.026876241718127858, 0.02886431619117502, 0.03838130258372985, 0.030315476506075356, 0.04723313541035168, 0.058318098017480224, 0.007995397190825315, 0.07148238029913045, 0.023675251177337486, 0.07436833286192268, 0.12505788006819785, 0.2159953277441673, 0.1441662828437984, 0.1725600811187178, 0.21767167607322335, 0.2290615055244416, 0.12686373316682875, 0.11575832439120859, 0.20709466160042211, 0.22578035190235823, 0.14816996175795794, 0.1334932938334532, 0.14702359592774883, 0.2546968893148005, 0.22701026871800423, 0.24236049503087997, 0.10530412051593885, 0.19193038780940697, 0.2458338055294007, 0.2719118952518329, 0.4083194397389889, 0.19971241476014256, 0.12753402610542253, 0.3607718489365652, 0.5455640971194953, 0.3418039495591074, 0.6940527074038982, 0.6281612149905413, 0.3909837902756408, 0.383788698236458, 0.3826635726727545, 0.36060231272131205, 0.375211252248846, 7.2395396791398525, 62.250212877988815, 125.13217225670815, 126.02876454591751, 130.43807834386826, 99.30732920765877, 83.88525635004044, 28.858714252710342, 37.18207262456417, 99.09535378217697, 92.61172369122505, 57.99840822815895, 52.26160906255245, 52.13705934584141, 23.17450426518917, 4.373750556260347, 0.5786092020571232, 0.6652058428153396, 0.2934885327704251, 0.34788041724823415, 0.3039228025591001, 0.13774387043667957, 1.4813432679511607, 3.9263941487297416, 3.3971205493435264, 9.759215824306011, 10.624582339078188, 13.620295990258455, 19.83755562454462, 24.478503093123436, 19.91222731769085, 32.235327064991, 81.67349383234978, 117.30306476354599, 103.79399925470352, 100.26067525148392, 105.82520306110382, 101.62341132760048, 116.58891588449478, 110.31079396605492, 104.38586309552193, 88.15569519996643, 80.6478300690651, 86.42307937145233, 91.42339825630188, 101.63769096136093, 110.26717990636826, 101.15643918514252, 116.2299719452858, 101.2967124581337, 73.43517869710922, 125.96203252673149, 110.3460256755352, 111.32730782032013, 107.21245542168617, 121.44266903400421, 98.98582085967064, 115.82155466079712, 102.55175471305847, 97.03961849212646, 102.93402940034866, 112.90789380669594, 115.09562641382217, 113.98376047611237, 104.42644491791725, 106.71805635094643, 107.69052296876907, 109.85334411263466, 111.09889447689056, 119.85421746969223, 124.40489128232002, 118.54199588298798, 120.31737461686134, 122.65500158071518, 117.59980604052544, 114.83132019639015, 114.9214893579483, 75.57326316833496, 42.40827418863773, 20.783919543027878, 3.6254054121673107, 0.5164250638335943, 0.1797973271459341, 0.22885296202730387, 0.18458443199051544, 0.12056131119607016, 0.34738154557999223, 1.1016003135591745, 18.323165886104107, 52.35304735600948, 69.34386223554611, 59.93993304669857, 41.67614467442036, 36.064411997795105, 22.998706698417664, 42.35605739057064, 51.635520458221436, 71.03568345308304, 93.63398283720016, 93.05885329842567, 85.3239731490612, 67.05510064959526, 30.76844807714224, 7.127363998442888, 0.5997649824712425, 0.3534400532953441, 0.30731067701708525, 0.5815090995747596, 0.22519862686749548, 0.1477475164574571, 0.4547470109537244, 0.5594467709306628, 0.5969216069206595, 0.9288511925842613, 0.5305633926764131, 0.7263477088417858, 0.5094979167915881, 0.4856660112272948, 0.16290232044411823, 0.2840662852395326, 0.14230264612706378, 0.3175101609667763, 0.25537236244417727, 0.31035757914651185, 0.21612829092191532, 0.22614645335124806, 0.23550889862235636, 0.06445040489779785, 0.2872312779072672, 0.2527912025107071, 0.21339853818062693, 0.17034629912814125, 0.12848033860791475, 0.13018914847634733, 0.055624729066039436, 0.11920535544049926, 0.1241904727066867, 0.12789123662514612, 0.14562705211574212, 0.11381709613488056, 0.19808614655630663, 0.261027438682504, 0.12321535745286383], [0.0945317727746442, 0.07282525941263884, 0.10966156638460234, 0.022319583003991283, 0.09436258536879905, 0.14812096516834572, 0.046215324400691316, 0.05271019268548116, 0.030879842706781346, 0.07894518726971, 0.034385902326903306, 0.05281988953356631, 0.023176448157755658, 0.03528888824803289, 0.006970675394768477, 0.05560219375183806, 0.05376323344535194, 0.056199949176516384, 0.15297477424610406, 0.009201728553307476, 0.08520892850356176, 0.1466070581227541, 0.054086898890091106, 0.20887502934783697, 0.33881989249493927, 0.14857751957606524, 0.29315388354007155, 0.2381503803189844, 0.20234792958945036, 0.2992645197082311, 0.10251990155666135, 0.06941587009350769, 5.852761343121529, 50.9618204087019, 103.94069418311119, 101.24292254447937, 93.89206498861313, 84.57991987466812, 61.37644216418266, 37.2345782071352, 55.48564866185188, 64.52115342020988, 58.52477118372917, 45.35231061279774, 42.88558177649975, 29.072532579302788, 6.774574778974056, 0.4275301698362455, 0.1587697898503393, 0.018271512526553124, 0.4541558458004147, 0.1875858404673636, 0.1534424163401127, 0.30378411000128835, 1.8642440903931856, 2.402580203488469, 1.7323472304269671, 3.2404791796579957, 4.087148085236549, 6.925594350323081, 7.0715088956058025, 15.308311711996794, 33.64573538303375, 67.51505836844444, 75.76712876558304, 96.33610144257545, 88.77576872706413, 92.01426655054092, 88.36280688643456, 94.44758757948875, 97.27489426732063, 107.8088866174221, 104.01075482368469, 96.1694423854351, 81.27771466970444, 80.33617079257965, 86.89627557992935, 90.24150967597961, 91.89534813165665, 92.11031779646873, 101.24913141131401, 111.88598424196243, 105.47505185008049, 30.488131418824196, 88.07246446609497, 92.6060999929905, 97.98465058207512, 76.57139360904694, 93.7855415046215, 54.49964717030525, 115.45437276363373, 106.70244678854942, 93.64288955926895, 85.92418134212494, 90.07497981190681, 94.0010279417038, 99.82138842344284, 97.04284071922302, 101.18539363145828, 100.47347143292427, 106.66800543665886, 107.34056934714317, 106.44041284918785, 110.2257089316845, 114.37029093503952, 107.53155469894409, 99.8391030728817, 100.71593642234802, 100.52739813923836, 107.67151638865471, 98.7407112121582, 75.48483431339264, 49.43824656307697, 19.449761733412743, 4.944785814732313, 0.3127800382208079, 0.06398099649231881, 0.05505418448592536, 0.048097655817400664, 0.08214043729822151, 0.12258005677722394, 0.0924131489591673, 4.200045727193356, 24.54040367156267, 34.22765135765076, 74.56899225711823, 71.3274697959423, 49.87760178744793, 20.29391873627901, 15.22772278636694, 33.90898145735264, 30.431356765329838, 56.91607050597668, 61.70058377087116, 74.2875337600708, 56.59233547747135, 30.434389002621174, 9.464503638446331, 0.37005092133767903, 0.2266633146791719, 0.1635860017267987, 0.00901421473827213, 0.10578287998214364, 0.26505127432756126, 0.4027440107893199, 0.14332326245494187, 0.40895931946579367, 0.20951047103153542, 0.11728641387890093, 0.2003816093201749, 0.04591567485476844, 0.08783591605606489, 0.08017303349333815, 0.0555974254530156, 0.026328315943828784, 0.08335817547049373, 0.024475076716043986, 0.12666177994105965, 0.06366688990965486, 0.011240783005632693, 0.05369087775761727, 0.06137275559012778, 0.1136854020296596, 0.13744045078055933, 0.06769344181520864, 0.047971928579499945, 0.06257018860196695, 0.05288673477480188, 0.037390977013274096, 0.07612766814418137, 0.05593613794189878, 0.06172221066663042, 0.030427305173361674, 0.12919075204990804, 0.040939211030490696, 0.06387073561199941, 0.023728602318442427, 0.017308787428191863, 0.05173647266929038, 0.02168013743357733, 0.10867350807529874, 0.10047116578789428, 0.04000587126938626, 0.012300247981329449, 0.08809218707028776, 0.10542808886384591, 0.061655695681110956, 0.0433543562394334, 0.028900757497467566, 0.054016676876926795, 0.04319108003983274, 0.05297561066981871, 0.05995352803438436, 0.04838821405428462, 0.11900501267518848, 0.037477504010894336, 0.19315313547849655, 0.13414003100479022, 0.08072070137131959, 0.14734601456439123, 0.2894199307775125, 0.0885532982647419, 0.24357997725019231, 0.3258359298342839, 0.15698685427196324, 0.16997341444948688, 0.20903732220176607, 0.11684275799780153, 6.02877264842391, 58.860441371798515, 115.86468234658241, 112.8060744702816, 110.15339121222496, 101.25110730528831, 82.57751852273941, 58.98898847401142, 30.469489619135857, 30.02495337277651, 51.073777601122856, 43.809487000107765, 44.88445311784744, 36.24992564320564, 11.577392611652613, 1.2068715272471309, 0.15796277846675366, 0.09190884476993233, 0.18486583954654634, 0.6280241848435253, 0.42444788210559636, 1.565048263873905, 3.7116876197978854, 4.441370302811265, 1.8832783377729356, 2.941658226773143, 2.8874320490285754, 2.8740954771637917, 6.019722484052181, 16.52416381984949, 37.52910040318966, 71.151242852211, 86.48104146122932, 103.12774300575256, 96.19136720895767, 95.96111476421356, 92.12159559130669, 96.94435000419617, 101.5024334192276, 109.09048944711685, 109.34452101588249, 99.0150336921215, 82.44304373860359, 81.92871853709221, 89.71259325742722, 93.13930258154869, 96.27691581845284, 97.9631133377552, 105.23466914892197, 119.76391151547432, 106.73491984605789, 36.69055759906769, 94.07112658023834, 105.16675159335136, 105.11158615350723, 88.12052428722382, 100.74895665049553, 64.49853703379631, 117.81493529677391, 111.01653009653091, 96.85657471418381, 88.2662844657898, 92.94369667768478, 100.63285008072853, 105.12432307004929, 100.7298132777214, 105.55500715970993, 103.26350972056389, 110.75246706604958, 114.10730704665184, 112.36017599701881, 115.4123318195343, 120.52767813205719, 115.45352920889854, 107.93719053268433, 104.41581308841705, 104.57894593477249, 111.61306768655777, 101.82625964283943, 83.71949404478073, 54.39527057111263, 24.252947196364403, 5.621346160769463, 1.0243453527800739, 0.25437043339479715, 0.4037282173521817, 0.09464837901759893, 0.09237898790161125, 0.15071146131958812, 0.24218977137934417, 4.619499994441867, 24.198995791375637, 36.09121575951576, 51.78710952401161, 47.213716730475426, 30.763067565858364, 22.620997466146946, 29.108706638216972, 52.57909722626209, 48.48974525928497, 72.18338906764984, 77.88436755537987, 87.75485470890999, 65.77379420399666, 33.81809413433075, 9.27581811323762, 0.37747314025182277, 0.20642469520680606, 0.1311789805185981, 0.037739114777650684, 0.05465532092784997, 0.2656231139553711, 0.3671037935419008, 0.18457938538631424, 0.23502638388890773, 0.15602335362927988, 0.10766504812636413, 0.16583990422077477, 0.07541356622823514, 0.030128119469736703, 0.08032341487705708, 0.023746226470393594, 0.012612245009222534, 0.028865973035863135, 0.01681436307990225, 0.048845577402971685, 0.09050113905686885, 0.06990459660300985, 0.06799312104703858, 0.008696928052813746, 0.10167224274482578, 0.1252912706695497, 0.0602563279971946, 0.04081828548805788, 0.07764450667309575, 0.03982574460678734, 0.0982314976863563, 0.05547019907680806, 0.05112786704557948, 0.028566236287588254, 0.069377026084112, 0.1189374401292298, 0.0672004182706587, 0.09490906581049785, 0.23984520812518895, 0.2632789663039148, 0.2633328759111464, 0.12436496646841988, 0.26651419582776725, 0.2553983376128599, 0.14989407471148297, 0.26722321403212845, 0.2658224548213184, 0.2056744581204839, 0.1265091053210199, 0.2064819890074432, 0.12002473100437783, 0.14883445110172033, 0.1629690988920629, 0.11892838592757471, 0.14117093029199168, 0.13359404780203477, 0.2876608626684174, 0.23264254617970437, 0.3407986956881359, 0.2831742831040174, 0.1938803808297962, 0.25942662614397705, 0.5058999254833907, 0.23302123445319012, 0.5757043173070997, 0.6010722904466093, 0.3026127634802833, 0.34719829447567463, 0.3233898407779634, 0.1533841429045424, 15.796461068093777, 87.11613178253174, 133.3906415104866, 126.00257635116577, 122.77227088809013, 110.81998184323311, 88.88118267059326, 60.304580479860306, 82.28316351771355, 88.10174569487572, 79.91899877786636, 64.09099370241165, 68.31357032060623, 48.805519714951515, 14.33195885270834, 2.634873613715172, 0.476031361031346, 0.2860357373720035, 0.5575066187884659, 0.7029709476046264, 0.2866667410125956, 0.8860273123718798, 4.442412871867418, 8.425518739968538, 7.542069470509887, 11.730080768465996, 12.566034961491823, 18.091617710888386, 16.010727770626545, 22.79682733118534, 40.788447707891464, 81.84024408459663, 90.74217081069946, 108.70469614863396, 99.21750202775002, 102.35009953379631, 96.4244695007801, 101.87178120017052, 103.21251645684242, 112.65505537390709, 112.64532789587975, 103.43235746026039, 84.47025775909424, 87.16235250234604, 91.65376469492912, 97.67522558569908, 98.9437647163868, 101.6300305724144, 110.97440555691719, 126.17875009775162, 108.34887564182281, 46.01463407278061, 107.00035840272903, 117.53285363316536, 114.60758060216904, 95.7043169438839, 104.65005531907082, 74.0236759185791, 120.51518440246582, 119.25274014472961, 100.71329936385155, 96.69507578015327, 98.03607702255249, 104.50335279107094, 111.87936499714851, 106.91392064094543, 111.5371173620224, 107.42905139923096, 114.3745619058609, 118.7501411139965, 115.94079986214638, 118.70180010795593, 123.33093971014023, 119.55409437417984, 112.73846089839935, 108.89704942703247, 110.94480514526367, 119.40214812755585, 108.98319080471992, 81.24787107110023, 60.53060755133629, 28.133796751499176, 10.22736020386219, 2.362562413327396, 0.15969600499374792, 0.4663534287828952, 0.17873464588774368, 0.13288979418575764, 0.2233635331504047, 0.5362188548315316, 8.009438216686249, 42.59810820221901, 57.04389184713364, 104.35249328613281, 98.17166894674301, 69.12296488881111, 28.264025263488293, 27.88783024996519, 55.96977688372135, 56.352302357554436, 88.14653769135475, 94.37685817480087, 98.8241395354271, 78.9497771859169, 44.46629695594311, 15.72199646383524, 0.7771264621987939, 0.27355263533536345, 0.40100937418174, 0.2017659819102846, 0.2547171647893265, 0.33317496883682907, 0.5140681809280068, 0.35832302877679467, 0.5929559259675443, 0.3743774344911799, 0.3045480768196285, 0.4458061797777191, 0.23854745901189744, 0.2261500305030495, 0.17098855372751132, 0.13892005576053634, 0.15040539961773902, 0.16152482014149427, 0.10497265509911813, 0.22353298030793667, 0.21892314485739917, 0.13495532475644723, 0.0996859883889556, 0.08384038592339493, 0.24530178954591975, 0.22254846204305068, 0.1432121332618408, 0.1813469166518189, 0.18168760696426034, 0.2879403851693496, 0.17767169745638967, 0.23776985151926056, 0.25074575445614755, 0.16309615457430482, 0.13201781519455835, 0.17125203099567443, 0.20596171380020678, 0.14824009471340105], [0.033810403911047615, 0.014102231707511237, 0.030297759585664608, 0.1251997341751121, 0.030667046703456435, 0.11994233776931651, 0.048255518049700186, 0.027811986037704628, 0.003905781750290771, 0.04100055695744231, 0.07576324394904077, 0.07526837245677598, 0.02440190095512662, 0.05384076932386961, 0.05381673858209979, 0.04455987495020963, 0.051460627510095946, 0.030998198562883772, 0.13362204161239788, 0.04366085951915011, 0.027923977977479808, 0.13234335085144266, 0.1229401542514097, 0.05977418062684592, 0.11112551947007887, 0.11179548586369492, 0.23410583875374869, 0.3222938074031845, 0.08761275224969722, 0.3036948147928342, 0.1676004714681767, 25.37913266569376, 88.51400077342987, 106.97853237390518, 97.18898847699165, 86.25392004847527, 73.22201013565063, 42.934029176831245, 22.191781997680664, 21.43527489155531, 65.24246871471405, 69.50942695140839, 38.84068362414837, 33.326818495988846, 15.224882438778877, 2.006586352363229, 0.13101545569952577, 0.38768521102610976, 0.26063644560053945, 0.2082335762679577, 0.33442070824094117, 0.45873074093833566, 0.35942283226177096, 1.122907076496631, 5.467054964974523, 4.66122318059206, 3.741451660171151, 4.224044289439917, 8.5849629342556, 19.32259775698185, 39.62974928319454, 65.20817175507545, 81.90025806427002, 80.37980005145073, 81.87457904219627, 95.05669489502907, 96.73786908388138, 88.25523465871811, 83.10390427708626, 89.25541698932648, 95.85792750120163, 101.07283607125282, 102.47221738100052, 83.47728744149208, 71.52559116482735, 72.7539512515068, 81.63004696369171, 82.6974704861641, 90.28364181518555, 98.12308475375175, 104.58565637469292, 99.19774308800697, 107.98534914851189, 47.9740559309721, 54.63324420154095, 88.023272305727, 69.89949122071266, 77.43909984827042, 90.10853961110115, 57.23222494125366, 112.7481959760189, 96.69487819075584, 94.91742476820946, 83.31277906894684, 80.91951549053192, 93.21266144514084, 101.55658051371574, 100.76655730605125, 97.86280632019043, 93.71825471520424, 97.98072159290314, 98.97340312600136, 100.30511006712914, 101.50182545185089, 103.79474401473999, 99.88235235214233, 102.1100664138794, 106.4939671754837, 92.58150771260262, 95.63285037875175, 99.7600369155407, 99.93508592247963, 74.33307811617851, 48.33350904285908, 17.308128252625465, 4.25424269400537, 0.8952947775833309, 0.12813672423362732, 0.04092679861059878, 0.04502106035943143, 0.012898018248961307, 0.038922999883652665, 0.023244347248692065, 1.956180038396269, 16.76113050431013, 34.09375414252281, 57.093505784869194, 78.01692724227905, 46.75864174962044, 33.140582889318466, 10.203588679432869, 24.88171085715294, 28.726511746644974, 35.051458552479744, 54.846883937716484, 67.09979385137558, 69.4573925435543, 38.619482293725014, 12.375917863100767, 1.4416410983540118, 0.15836505219340324, 0.05865604609425645, 0.0980666147370357, 0.030838130296615418, 0.1953090596362017, 0.13817670580465347, 0.48986825917381793, 0.11707140627549961, 0.16062244278145954, 0.06662615924142301, 0.03171113530697767, 0.06617777587962337, 0.040384540989180095, 0.04321382686612196, 0.08598230575444177, 0.11184396294993348, 0.038607657625107095, 0.051472227278281935, 0.055042347230482846, 0.07786726971971802, 0.09365937075926922, 0.0399690570338862, 0.1150539742957335, 0.019814830884570256, 0.04307686351239681, 0.05078112822957337, 0.05478685176058207, 0.0520796009368496, 0.043262957042315975, 0.028054950344085228, 0.11058745498303324, 0.009030879664351232, 0.04228164856613148, 0.09212722172378562, 0.03700386907439679, 0.09575323652825318, 0.05621459546091501, 0.03741598367923871, 0.008884587514330633, 0.121138902468374, 0.08261651018983684, 0.05594118825683836, 0.08023442394915037, 0.04946772722178139, 0.040041208631009795, 0.06778641807613894, 0.0363265628402587, 0.08896939078113064, 0.0638054711453151, 0.032386975799454376, 0.013499592951120576, 0.0482272088265745, 0.06529485021019354, 0.04048941016662866, 0.19711614469997585, 0.01420590788256959, 0.07563372433651239, 0.19981949182692915, 0.03852088200801518, 0.06832484621554613, 0.07502937864046544, 0.1798145895008929, 0.20937289169523865, 0.35001815878786147, 0.02785714386845939, 0.22620735398959368, 0.30522363900672644, 27.584591321647167, 98.897126019001, 118.33942875266075, 113.42758432030678, 101.68708071112633, 84.76038739085197, 70.03401920199394, 47.630402371287346, 34.90264713764191, 58.415595442056656, 53.666192293167114, 46.0611891746521, 39.469249695539474, 24.16715729981661, 3.4456508327275515, 0.18876728019677103, 0.5063008039724082, 0.26578980032354593, 0.18294474575668573, 0.6199655891396105, 1.1734539829194546, 1.1329963663592935, 4.6786499954760075, 3.0177030712366104, 2.2040187707170844, 1.8542427895590663, 4.028781317174435, 8.773717805743217, 23.088393285870552, 45.09516321122646, 73.13700869679451, 90.16093119978905, 91.25793233513832, 91.9936640560627, 100.90290158987045, 101.21829986572266, 89.6236552298069, 86.47611692547798, 92.99368679523468, 100.24315059185028, 104.00314003229141, 107.49834448099136, 87.10061341524124, 75.2472634613514, 75.53002148866653, 84.95153233408928, 85.0609664618969, 95.03676116466522, 102.38907024264336, 111.06708258390427, 104.03762698173523, 113.81464675068855, 53.94879452884197, 62.060907036066055, 103.24619024991989, 76.18724182248116, 88.09210941195488, 95.33296287059784, 65.01714840531349, 112.63978779315948, 104.74248915910721, 99.67432871460915, 87.29846119880676, 82.04347237944603, 98.99206012487411, 105.78607276082039, 105.94940319657326, 101.12635999917984, 98.89698922634125, 100.3145943582058, 105.01546651124954, 104.10019442439079, 105.55391281843185, 105.05840420722961, 104.91222605109215, 108.85880067944527, 110.02213105559349, 97.94577106833458, 101.3306750357151, 104.36112642288208, 108.0622798204422, 81.78974479436874, 53.50862234830856, 20.478870011866093, 5.1942528784275055, 1.647672455292195, 0.8352754544466734, 0.308468813309446, 0.0636488854070194, 0.0704975206463132, 0.0032206808782575536, 0.12904076400445774, 2.46166180819273, 20.360000990331173, 40.95242030918598, 45.94399966299534, 61.72787770628929, 37.958207577466965, 30.703967437148094, 23.347750268876553, 31.949582397937775, 40.2176309376955, 47.59745053946972, 69.13945600390434, 80.54062262177467, 76.78738161921501, 44.44606304168701, 13.316727429628372, 1.819278015755117, 0.23687231296207756, 0.014977917726355372, 0.07285314190085046, 0.13766557385679334, 0.13257761718705297, 0.2697213721694425, 0.3548342816065997, 0.05057790222053882, 0.05841050653543789, 0.06667405745247379, 0.031226969294948503, 0.012361671833787113, 0.027425456974015106, 0.039251826965482906, 0.024824513238854706, 0.08258105779532343, 0.024351592619495932, 0.07424566327244975, 0.04531192658760119, 0.018835659793694504, 0.059289224227541126, 0.03861598081130069, 0.12330558776739053, 0.08007182681467384, 0.10416268254630268, 0.016723641092539765, 0.022373073297785595, 0.08277176006231457, 0.013603658753709169, 0.021440221498778556, 0.08917112878407352, 0.02760707720881328, 0.0528797808510717, 0.05863906204467639, 0.05842756108904723, 0.06387743720551953, 0.14058466331334785, 0.1056441651599016, 0.11943939913180657, 0.29890724981669337, 0.13621498685097322, 0.22632186737610027, 0.19289886084152386, 0.16554308967897668, 0.10413543830509298, 0.06041730724973604, 0.21753002976765856, 0.18815716059179977, 0.09084102042834274, 0.13036082207690924, 0.08659952029120177, 0.1382487831870094, 0.14789544133236632, 0.0732170688570477, 0.27824841148685664, 0.1364644375280477, 0.207265414937865, 0.2626998833147809, 0.23421465244609863, 0.181246682186611, 0.2626817155396566, 0.25692131370306015, 0.31324174313340336, 0.5597901181317866, 0.20197713776724413, 0.39572777634020895, 0.5585374915972352, 45.66388629376888, 129.77179169654846, 135.40450304746628, 124.3618243932724, 112.8094182908535, 97.36020728945732, 64.71868962049484, 38.8138722628355, 37.035628482699394, 92.20699220895767, 99.48511406779289, 60.981377363204956, 55.4881489276886, 28.815428875386715, 4.6591290179640055, 0.48417800513561815, 0.4515716579044238, 0.4067192506045103, 0.32842397689819336, 0.6657307490240782, 0.7285150769166648, 2.052340409718454, 7.557166535407305, 14.057547077536583, 13.386388141661882, 11.122431624680758, 12.366241682320833, 16.887925900518894, 25.846881866455078, 49.44128639996052, 76.64521604776382, 92.62400463223457, 91.48208230733871, 92.11573630571365, 105.6499108672142, 107.19904214143753, 95.89367598295212, 88.24925377964973, 97.2183609008789, 104.48849558830261, 106.07390731573105, 109.52836275100708, 89.45131927728653, 78.16663160920143, 79.09334108233452, 87.94695720076561, 90.26291012763977, 102.59612113237381, 109.19289395213127, 116.32321134209633, 107.44159072637558, 118.48903432488441, 61.002093851566315, 69.99004796147346, 116.73220619559288, 88.02321150898933, 95.1425550878048, 104.64593634009361, 79.75179255008698, 116.50338247418404, 109.98023450374603, 100.80694913864136, 92.93125614523888, 86.46551549434662, 102.15391606092453, 113.92464324831963, 112.7036015689373, 103.05537208914757, 99.62690725922585, 105.3391483426094, 106.73719972372055, 107.39888101816177, 111.5705555677414, 108.41423213481903, 111.35512992739677, 115.4460284113884, 116.9689790904522, 103.43449294567108, 105.53318113088608, 110.78711360692978, 111.5140450000763, 83.46194386482239, 55.7077619433403, 22.442977018654346, 8.401035703718662, 4.5571700390428305, 0.9963212627917528, 0.29773474554531276, 0.12916682520881295, 0.16997077240375802, 0.0793595654249657, 0.37406442628707737, 3.583738273009658, 31.368690468370914, 53.88462737202644, 78.93852978944778, 108.870580047369, 71.23816698789597, 47.78520606458187, 21.143028773367405, 39.47987772524357, 49.8626571893692, 60.34592226147652, 82.32372254133224, 92.9634328186512, 91.79327040910721, 56.837065145373344, 24.25780713558197, 2.5775760132819414, 0.2689023973653093, 0.1223104790551588, 0.19806989352218807, 0.34173896710854024, 0.3599274926818907, 0.4171116929501295, 0.6845288746990263, 0.3290393657516688, 0.3757545043481514, 0.20290299667976797, 0.11511649281601422, 0.161494956118986, 0.1737930258968845, 0.20144353358773515, 0.2776800451101735, 0.2120014006504789, 0.22732085752068087, 0.1868257625028491, 0.14569950057193637, 0.17687247862340882, 0.16872632433660328, 0.19664511841256171, 0.20006134291179478, 0.15092248358996585, 0.21510515129193664, 0.13085424638120458, 0.2008708330686204, 0.1535369362682104, 0.12397539088851772, 0.09628051018808037, 0.22803861822467297, 0.09887504362268373, 0.12242994256666861, 0.13214147184044123, 0.11902355894562788, 0.16854081710334867], [0.07386233657598495, 0.03374133964825887, 0.046136875680531375, 0.06712830378091894, 0.12514206930063665, 0.07025012571830302, 0.06626143818721175, 0.012213799836899852, 0.01707497565803351, 0.05017417759518139, 0.05059390292444732, 0.06422291437047534, 0.04738312716654036, 0.06513375963550061, 0.04217260480800178, 0.01266170173039427, 0.014505772651318694, 0.09439216737519018, 0.0341295942052966, 0.01839893557189498, 0.1258524678996764, 0.16307875863276422, 0.18857362418202683, 0.07128534751245752, 0.03291830529633444, 0.10914217433310114, 0.16713475895812735, 0.211915370891802, 0.1211143151158467, 0.6134302366990596, 32.67165765166283, 119.25304412841797, 111.7582654953003, 104.78652119636536, 78.40732589364052, 55.640904530882835, 40.68267658352852, 13.311884589493275, 27.236814983189106, 38.55634868144989, 30.470810048282146, 27.95174852013588, 27.028109282255173, 12.049480229616165, 0.6325625069439411, 0.10672797536244616, 0.02435014543152647, 0.2316593489376828, 0.055570322219864465, 0.13959186268039048, 0.252551399753429, 1.706002769060433, 2.296563279815018, 3.862715740688145, 5.303523615002632, 6.404943913221359, 7.552664251998067, 20.844357199966908, 44.64555613696575, 64.71017047762871, 78.97993996739388, 83.01977679133415, 85.41345074772835, 90.40240824222565, 100.11542424559593, 90.72295904159546, 88.21754068136215, 79.1138219833374, 79.33569207787514, 82.51532346010208, 91.89910233020782, 93.77931743860245, 87.62527406215668, 73.67489263415337, 76.82547077536583, 80.77336773276329, 85.276810079813, 86.25553876161575, 85.64055696129799, 88.4104411303997, 103.36880967020988, 99.49450716376305, 103.23096066713333, 83.20403650403023, 33.204552456736565, 95.57341396808624, 82.2507056593895, 100.01003310084343, 67.58184358477592, 41.885840222239494, 96.49173349142075, 106.56425580382347, 96.51300475001335, 91.39517337083817, 80.51823422312737, 76.80938243865967, 86.60144940018654, 98.47027972340584, 98.8370968401432, 100.34382998943329, 99.76214200258255, 100.73767885565758, 101.11648052930832, 102.82376691699028, 105.63620880246162, 99.13544923067093, 98.255355656147, 98.51862072944641, 101.15976020693779, 96.82375967502594, 99.02225330471992, 103.67661595344543, 94.9561370909214, 64.89837437868118, 32.45535045862198, 15.971810258924961, 4.32390340603888, 1.422525392845273, 0.1698743674205616, 0.2837094903225079, 0.09608018968719989, 0.03819278223090805, 0.0862079334910959, 0.0845929681963753, 0.6743683980312198, 9.946881104260683, 26.33476808667183, 36.27828732132912, 46.63345366716385, 61.270359456539154, 43.7693003565073, 23.402566127479076, 40.98715804517269, 32.15315267443657, 36.7459624260664, 60.68511106073856, 74.51997488737106, 76.88757464289665, 64.84015390276909, 28.412967771291733, 2.111342456191778, 0.20449459174415097, 0.014560715699190041, 0.06273337203310803, 0.048304945084964857, 0.0899019735516049, 0.3464523470029235, 0.05057069596659858, 0.05780275067081675, 0.052842870136373676, 0.04149599619267974, 0.06389553076587617, 0.08553464227588847, 0.030442799361480866, 0.04256110798451118, 0.04257501583197154, 0.05956205255642999, 0.027394103090045974, 0.08840408205287531, 0.012856498797191307, 0.05376255066948943, 0.03952362370910123, 0.06348882641759701, 0.0823428135481663, 0.033589678059797734, 0.10040527791716158, 0.03340229690365959, 0.02857200463040499, 0.06839896450401284, 0.04082729516085237, 0.04709604960225988, 0.014138986571197165, 0.058880363940261304, 0.011538039125298383, 0.03199303268047515, 0.023755789043207187, 0.052667107302113436, 0.01752791209582938, 0.047900559948175214, 0.04651811694202479, 0.07343390956521034, 0.06344653884298168, 0.030786918396188412, 0.06464387537562288, 0.07291692207218148, 0.06809197511756793, 0.02919637903687544, 0.04352592593932059, 0.025153570386464708, 0.04388313645904418, 0.03516972159559373, 0.005097186667626374, 0.020936939617968164, 0.07789791299728677, 0.07672784297028556, 0.02689341130462708, 0.043486469658091664, 0.12412091862643138, 0.13188937911763787, 0.1023881851870101, 0.07331583386985585, 0.11131668186862953, 0.17715787893394008, 0.17925878026289865, 0.1366172160487622, 0.43625325488392264, 37.647452652454376, 133.6291167140007, 128.68994414806366, 119.64355677366257, 93.33806991577148, 74.02094006538391, 66.14957883954048, 34.30828683078289, 34.00067813694477, 30.607978887856007, 40.34438453614712, 40.11646896600723, 36.81351900100708, 18.575071468949318, 1.2564819026738405, 0.05625573641736992, 0.031548040933557786, 0.117363062890945, 0.3974723577266559, 0.822578554507345, 2.387409280054271, 3.056705128401518, 1.696798950433731, 2.8909074375405908, 4.778866767883301, 6.837695091962814, 11.124117784202099, 25.20005777478218, 49.92944620549679, 70.04133000969887, 84.24747571349144, 88.45696583390236, 91.27442345023155, 96.38942778110504, 103.38301330804825, 96.22581616044044, 94.82029438018799, 83.31724762916565, 82.39330440759659, 86.15622729063034, 95.26425495743752, 96.41396686434746, 93.96477028727531, 77.1507029235363, 79.63085263967514, 83.33730295300484, 88.56622517108917, 90.305635035038, 90.22172793745995, 94.44621205329895, 106.95742070674896, 102.32391893863678, 105.88043689727783, 85.06640776991844, 42.89690896868706, 102.69654214382172, 91.37566521763802, 109.83188286423683, 76.69180914759636, 47.157335355877876, 100.75239926576614, 109.90985468029976, 102.89180606603622, 97.40938425064087, 83.06285887956619, 81.86852216720581, 90.68264320492744, 104.32798460125923, 104.3686956167221, 105.35395994782448, 105.48248425126076, 104.87869665026665, 106.45375773310661, 105.72323933243752, 107.78276681900024, 105.2708888053894, 103.1008480489254, 102.75705009698868, 104.91670981049538, 102.46330305933952, 101.1300989985466, 105.54729357361794, 100.71434050798416, 70.76985731720924, 37.49858804047108, 17.437722198665142, 4.346778178587556, 2.39878848195076, 1.3680027122609317, 0.7212111563421786, 0.6504748051520437, 0.24846650019753724, 0.08327757081133313, 0.12877572822617367, 0.4930976702598855, 11.388960722833872, 29.31250110268593, 32.48721934854984, 40.87963901460171, 42.57781349122524, 32.04422011971474, 37.29539394378662, 52.835762053728104, 41.256970167160034, 48.6034769564867, 75.24097859859467, 84.750637114048, 88.63470509648323, 73.86716231703758, 35.57316675782204, 3.367665004916489, 0.0745227886363864, 0.05961970629869029, 0.018652889229997527, 0.09046909312019125, 0.07130321842851117, 0.10503818673896603, 0.034977980321855284, 0.0757013339898549, 0.06121336453361437, 0.015429622199008008, 0.03986158662883099, 0.07755823200568557, 0.03147104682284407, 0.010823999364220072, 0.02128527034074068, 0.011544333465280943, 0.02278391140862368, 0.02378868102823617, 0.011798820542026078, 0.03702983682160266, 0.04715757735539228, 0.04313298843044322, 0.13818909967085347, 0.027382573825889267, 0.1089489487640094, 0.011514264424477005, 0.03760009567486122, 0.032779972680145875, 0.05977289671136532, 0.004148116622673115, 0.01587944439961575, 0.09352619978017174, 0.0444184364459943, 0.0695975478447508, 0.06895146376336925, 0.13239184278063476, 0.1258739159675315, 0.09279285397497006, 0.09495858932496049, 0.14730371214682236, 0.2193151175742969, 0.18868788523832336, 0.27475259907078, 0.2151605748804286, 0.1773126018815674, 0.14193023642292246, 0.20145889604464173, 0.12202314173919149, 0.14608313154894859, 0.14612950093578547, 0.12601761060068384, 0.09893523179925978, 0.2557450393214822, 0.28691058105323464, 0.10642716064467095, 0.19904053362552077, 0.21918188722338527, 0.3217089653480798, 0.21296950260875747, 0.24290043715154752, 0.21362033643526956, 0.31887520803138614, 0.3082418051781133, 0.20535150513751432, 2.007745527662337, 60.70050023496151, 155.42777180671692, 138.42184513807297, 132.19432890415192, 104.22738119959831, 78.99631708860397, 63.218959495425224, 25.532211251556873, 41.63021273910999, 61.71967014670372, 49.9279110878706, 48.28149363398552, 46.43831513822079, 23.474108688533306, 2.1768112806603312, 0.3507738729240373, 0.1591298947460018, 0.4905583377694711, 0.4002146824495867, 0.6172084808349609, 1.446144925430417, 5.7754511665552855, 8.99130742996931, 12.894032411277294, 18.139690831303596, 14.481395334005356, 13.386552482843399, 26.951026618480682, 51.41263961791992, 69.14982184767723, 86.82341068983078, 90.3804986178875, 93.36224421858788, 102.84116998314857, 112.06917241215706, 99.79934960603714, 98.2029640674591, 86.32198959589005, 87.86893218755722, 90.40745437145233, 97.83801645040512, 98.85898366570473, 95.47565281391144, 80.92854380607605, 83.91383081674576, 86.93716898560524, 92.18430742621422, 92.35651418566704, 94.31984603404999, 98.63810911774635, 112.90876016020775, 107.77064546942711, 115.12233138084412, 89.04938444495201, 51.65215216577053, 116.81843876838684, 101.34402751922607, 118.0294717848301, 87.78488829731941, 56.798915192484856, 106.50842159986496, 117.19617649912834, 108.25869888067245, 101.63704499602318, 87.77447685599327, 89.04683858156204, 98.25064390897751, 109.93437856435776, 109.8814170062542, 111.49011388421059, 109.91273492574692, 109.52307343482971, 108.68903338909149, 109.27501514554024, 111.07848197221756, 110.2145679295063, 106.09472259879112, 108.48168611526489, 113.75017181038857, 109.83321279287338, 106.48981779813766, 109.71903651952744, 104.2983689904213, 73.1009030342102, 38.179481104016304, 21.94440957158804, 9.663381166756153, 6.209505200386047, 1.9039890076965094, 0.3841469477629289, 0.3930176905123517, 0.20880888914689422, 0.32288158836308867, 0.2667897701030597, 1.2618873501196504, 20.147837474942207, 45.81585913896561, 53.21479931473732, 67.20767006278038, 80.54727986454964, 61.13410636782646, 37.00093634426594, 56.50099217891693, 48.86165030300617, 59.00016747415066, 87.70193874835968, 96.60243675112724, 99.61792454123497, 85.72966977953911, 50.27539484202862, 5.946898916736245, 0.3935698780696839, 0.13138753885868937, 0.23080354876583442, 0.23730094777420163, 0.20647398865548894, 0.44504307385068387, 0.2904731867602095, 0.2638037834549323, 0.20150729891611263, 0.126482566120103, 0.17683796875644475, 0.15802777576027438, 0.15042853978229687, 0.22800498409196734, 0.16241238423390314, 0.11226191825699061, 0.11119556336780079, 0.19878836668794975, 0.16055985004641116, 0.18013681517913938, 0.10533989945542999, 0.2210083423415199, 0.18082463764585555, 0.09721399837872013, 0.19713471323484555, 0.20270600100047886, 0.08720885321963578, 0.19886249239789322, 0.16641578113194555, 0.17556272156070918, 0.057952516071964055, 0.2504317963030189, 0.18383944930974394, 0.15418143215356395, 0.19630653579952195], [0.0793469934433233, 0.10062095345347188, 0.03465732799668331, 0.02195447974372655, 0.10887983997236006, 0.08884121445589699, 0.0553142924036365, 0.004579015449053259, 0.04668956789828371, 0.013780436474917224, 0.0030342997661136906, 0.05463567627884913, 0.047708228667033836, 0.052579682305804454, 0.020608997547242325, 0.01978517095267307, 0.009199992855428718, 0.03277603929745965, 0.041653368607512675, 0.07643238655873574, 0.03155890226480551, 0.18769940390484408, 0.07951100807986222, 0.08952925956691615, 0.024044553138082847, 0.06537639739690349, 0.17350425623590127, 0.339543130248785, 0.8431112871039659, 57.99870081245899, 119.44586098194122, 109.81841638684273, 99.9712523818016, 82.12587475776672, 54.550887420773506, 21.03301327675581, 18.32375295460224, 36.39843687415123, 74.22470033168793, 56.77904225885868, 45.74537292122841, 33.203351721167564, 14.639265462756157, 0.6102376361377537, 0.13678237359272316, 0.141442155581899, 0.04767159996845294, 0.15331503411289304, 0.17685113445622846, 0.2657520695356652, 2.0536173786967993, 2.7282481407746673, 2.1928827557712793, 10.052703525871038, 21.52065820991993, 33.58217619359493, 51.44294299185276, 74.44507330656052, 85.21190956234932, 92.43394643068314, 87.49003171920776, 91.3222324848175, 89.78131636977196, 85.61241567134857, 88.58016282320023, 93.70963677763939, 86.26452147960663, 83.15214648842812, 75.29012516140938, 76.97110936045647, 77.56424993276596, 80.78129410743713, 72.14144691824913, 71.48445457220078, 73.53904232382774, 83.00488159060478, 81.38409376144409, 82.36558869481087, 82.61383697390556, 85.24236872792244, 82.14697882533073, 90.95035403966904, 88.30014064908028, 104.3542031943798, 56.243020221590996, 56.050651744008064, 75.98226562142372, 89.83788013458252, 48.096299171447754, 57.33731210231781, 95.97918659448624, 93.94330903887749, 99.07752513885498, 98.02270174026489, 100.78269883990288, 84.03740018606186, 76.11091911792755, 83.46842631697655, 95.69140523672104, 95.21859660744667, 95.64084514975548, 94.72455471754074, 99.74646404385567, 98.00483509898186, 97.5436082482338, 98.0450065433979, 100.55039450526237, 101.50604322552681, 96.82356968522072, 99.43810299038887, 97.67195776104927, 96.60166919231415, 98.10570448637009, 80.47927111387253, 49.570167884230614, 23.91318652778864, 8.39724825695157, 2.71444751881063, 1.0677848593331873, 0.8708168473094702, 0.0907869846560061, 0.08967952220700681, 0.03938999630918261, 0.12933268037158996, 0.07105358963599429, 0.11376564303645864, 3.9687509508803487, 26.815683580935, 40.64732328057289, 48.356539607048035, 62.73313656449318, 39.53897215425968, 22.593429945409298, 19.985329695045948, 26.901507675647736, 42.221027836203575, 64.55963015556335, 71.59898042678833, 72.73366793990135, 74.4539724290371, 46.71698458492756, 8.519805930554867, 0.31429152586497366, 0.06590018296265043, 0.04225839707942214, 0.27536668174434453, 0.04257793989381753, 0.09430307254660875, 0.05696995707694441, 0.046711156974197365, 0.030042091566429008, 0.07359177921898663, 0.024720321271161083, 0.02237608641735278, 0.059047911199741066, 0.013055149465799332, 0.04507612029556185, 0.041119055676972494, 0.07958192029036582, 0.03570409389794804, 0.15983068995410576, 0.025994978459493723, 0.024628628925711382, 0.13941943208919838, 0.11610526358708739, 0.06856658597826026, 0.05126773219672032, 0.08320545632159337, 0.04124801867874339, 0.032198255066759884, 0.040794900414766744, 0.019511032733134925, 0.04121873353142291, 0.04244461677444633, 0.03582670782634523, 0.09839702630415559, 0.12342744099441916, 0.09525066896458156, 0.016364090952265542, 0.04141041914408561, 0.11502860768814571, 0.04644113767426461, 0.037825148247065954, 0.04290524928364903, 0.05308169325871859, 0.028578208984981757, 0.06965255583054386, 0.10337780200643465, 0.059010844634030946, 0.022746525719412602, 0.04731397384603042, 0.07437304549966939, 0.03851022476737853, 0.009660441683081444, 0.04847509728278965, 0.037762637148262, 0.055486240598838776, 0.08062029621214606, 0.10018509754445404, 0.09695653992821462, 0.003569519276425126, 0.11898989512701519, 0.13160430535208434, 0.3786770818987861, 0.7904307951685041, 68.3609689772129, 134.17598336935043, 125.74260950088501, 113.0779042840004, 97.6793521642685, 76.5859392285347, 48.97627115249634, 31.52322057634592, 28.15590586513281, 42.40805000066757, 45.856117978692055, 44.9906612187624, 38.44268538057804, 22.772064059972763, 1.1310237972065806, 0.18919788912171498, 0.1209640153683722, 0.3000651189358905, 0.235512119543273, 1.136373553890735, 2.2270051622763276, 3.558883094228804, 2.5502664037048817, 2.3485409282147884, 13.370706383138895, 25.41785068809986, 37.68506683409214, 56.30178786814213, 76.81941390037537, 88.42597469687462, 94.28193926811218, 92.97288671135902, 95.08521616458893, 92.6522447168827, 92.92301818728447, 95.66337794065475, 96.53605431318283, 90.17759710550308, 84.87245097756386, 78.40509161353111, 79.83403533697128, 81.9326551258564, 85.66659316420555, 77.70787462592125, 75.77212169766426, 76.37597009539604, 86.81698903441429, 84.30537700653076, 85.4057827591896, 87.40263640880585, 90.74556022882462, 85.93127936124802, 94.33499202132225, 93.45438167452812, 109.28780525922775, 62.54153184592724, 64.38607826828957, 85.94483703374863, 98.85450750589371, 55.120020881295204, 66.01185902953148, 101.65845304727554, 93.71320098638535, 103.42348873615265, 103.45743611454964, 105.85118606686592, 87.83066064119339, 79.46263566613197, 86.22593834996223, 99.21634688973427, 100.70534259080887, 99.41919520497322, 99.55645903944969, 102.65436440706253, 102.2965756058693, 101.27523601055145, 103.79250213503838, 105.19726395606995, 106.57151341438293, 102.13431671261787, 103.3789475262165, 100.05664899945259, 100.10632753372192, 96.27427116036415, 84.68898922204971, 53.974952325224876, 27.143892869353294, 9.484643507748842, 3.639827538281679, 1.423962665721774, 2.6713096210733056, 1.156616136431694, 0.38291723874863237, 0.04772681204485707, 0.09141904214629903, 0.025566339936631266, 0.02416658819129225, 4.93054180406034, 31.487815976142883, 36.21258124709129, 44.42445360124111, 48.5551093518734, 36.81955307722092, 27.172550931572914, 29.681746289134026, 40.34821853041649, 55.81419423222542, 75.46309188008308, 79.34841379523277, 84.30905520915985, 84.67169255018234, 57.536774799227715, 11.483815982937813, 0.5168051028158516, 0.008011220706976019, 0.06193764871568419, 0.26638114359229803, 0.1100098859751597, 0.11299033620161936, 0.057004904811037704, 0.020784240878128912, 0.03182556705723982, 0.05062273907242343, 0.05451053162687458, 0.03234931922634132, 0.02737153623456834, 0.056344649419770576, 0.0471363704855321, 0.07586177147459239, 0.06138800672488287, 0.03569237167539541, 0.05306905077304691, 0.02660623169504106, 0.09247119975043461, 0.06870230252388865, 0.05993047321680933, 0.029220656542747747, 0.05724484486563597, 0.03361798357218504, 0.04314302226703148, 0.07343008008319885, 0.03746689129911829, 0.038027914124540985, 0.020050436796736903, 0.0805307857808657, 0.03073501073231455, 0.10104002198204398, 0.18026808626018465, 0.22179869993124157, 0.10234137793304399, 0.12085387323168106, 0.25397148448973894, 0.17719688621582463, 0.1282314519630745, 0.09716479398775846, 0.14704908127896488, 0.1194531585497316, 0.13234939193353057, 0.20687182433903217, 0.2229963630088605, 0.13901169615564868, 0.15043155290186405, 0.11250581766944379, 0.15321263257646933, 0.1245722483145073, 0.15694606583565474, 0.2298786398023367, 0.23541528411442414, 0.28474499413277954, 0.1778423023642972, 0.20588387735188007, 0.08778721632552333, 0.22953119594603777, 0.23445730505045503, 0.5731162405572832, 1.8107130378484726, 94.81334835290909, 156.37521296739578, 137.13400304317474, 127.1849437057972, 111.06045573949814, 75.31253635883331, 37.863710448145866, 27.24506814032793, 54.07697305083275, 101.11164718866348, 80.8435195684433, 76.0187740623951, 55.09775027632713, 30.925493650138378, 1.8526722863316536, 0.3596574399853125, 0.37135309365112334, 0.41476472513750196, 0.3593004966387525, 0.5398940888699144, 1.621784563176334, 8.047326933592558, 12.820781841874123, 7.907369518652558, 19.462318159639835, 30.38108356297016, 39.2037807404995, 55.73149926960468, 79.82116162776947, 89.10976320505142, 96.3351970911026, 94.36192497611046, 96.29747271537781, 93.1276448071003, 97.0193275809288, 100.09371981024742, 102.50029027462006, 93.77117827534676, 90.00561073422432, 82.8254172205925, 83.47236290574074, 85.62109440565109, 90.85276767611504, 79.62354943156242, 77.82069817185402, 80.00039801001549, 90.33312276005745, 90.01513302326202, 91.13543450832367, 93.44182714819908, 96.1553755402565, 91.12492427229881, 98.35728138685226, 98.08218374848366, 116.10161483287811, 67.75176286697388, 72.6515543460846, 95.31293034553528, 109.76506724953651, 65.54395973682404, 70.23588716983795, 106.68327301740646, 100.1936848461628, 108.01624909043312, 107.05928564071655, 111.20493158698082, 92.72627234458923, 84.29393202066422, 91.557447463274, 103.87217625975609, 104.01903077960014, 103.27361717820168, 102.64435574412346, 106.09935075044632, 106.99851170182228, 107.04309850931168, 110.31938910484314, 110.25652527809143, 110.60479938983917, 107.35527455806732, 108.93663570284843, 103.36235761642456, 105.70471152663231, 101.14641532301903, 86.88522577285767, 55.420444160699844, 28.92518788576126, 13.47362196072936, 8.880105447024107, 4.006128357723355, 4.270422700792551, 0.8424523787107319, 0.28164067945908755, 0.24150539247784764, 0.4057612270116806, 0.17970081826206297, 0.6918229395523667, 8.501028288155794, 50.56133709847927, 62.05702744424343, 72.90682464838028, 81.96032524108887, 54.220654740929604, 31.87197346240282, 29.486396871507168, 41.03516086935997, 62.5382374227047, 89.59463998675346, 90.00191733241081, 94.7138848900795, 94.72722977399826, 75.23988425731659, 16.66687846183777, 0.8226460008881986, 0.23319264088058844, 0.10781124379718676, 0.5708949035033584, 0.2112498870701529, 0.266988665680401, 0.09692853869637474, 0.16625295393168926, 0.07888656502473168, 0.1356984520680271, 0.09416472137672827, 0.10604387847706676, 0.17162623669719324, 0.11022756531019695, 0.1782657124567777, 0.127724876801949, 0.15337875491240993, 0.1145483045547735, 0.24415330117335543, 0.10726212873123586, 0.22623401193413883, 0.28102342039346695, 0.1859652719576843, 0.13326031883480027, 0.19958846125518903, 0.2505608112551272, 0.09260765844373964, 0.20032140630064532, 0.1490988041041419, 0.14921831956598908, 0.17383826721925288, 0.203687654575333, 0.08227465470554307, 0.17937676690053195], [0.10748158922069706, 0.046178461925592273, 0.030345138293341734, 0.051484851210261695, 0.04901777792838402, 0.09562692299368791, 0.02616090227093082, 0.03580509277526289, 0.04526255150267389, 0.0166579239157727, 0.057732870045583695, 0.054808511340525, 0.11662346820230596, 0.021530650337808765, 0.018676973777473904, 0.06344222696498036, 0.049956201401073486, 0.030759193614358082, 0.03981404093792662, 0.06566256211954169, 0.021415877199615352, 0.005063440748926951, 0.004988207383576082, 0.020395596693560947, 0.05500549217686057, 0.015105333350220462, 0.05857914104126394, 0.1981457558576949, 58.717956617474556, 134.53314900398254, 110.78978106379509, 105.1108717918396, 86.31573513150215, 49.20374594628811, 31.55973471701145, 28.175136633217335, 42.786536291241646, 83.35858181118965, 72.09486901760101, 38.18872220814228, 28.014410957694054, 17.694679610431194, 0.779937895713374, 0.12244819197803736, 0.07456920997356065, 0.059657366582541727, 0.10284309944836423, 0.13747096789302304, 0.7761109666898847, 2.9640473378822207, 4.179855985566974, 7.242522044107318, 20.059408619999886, 36.39958821237087, 53.861433416604996, 72.87886574864388, 85.08063420653343, 89.43193271756172, 91.34320735931396, 88.43612015247345, 98.18800047039986, 96.91115498542786, 97.42313951253891, 97.76899695396423, 98.812565356493, 93.17336395382881, 89.32466447353363, 82.31660172343254, 77.47134491801262, 69.48170363903046, 72.53119960427284, 69.593136459589, 70.97659662365913, 70.35362765192986, 82.40351065993309, 85.70573106408119, 89.15603712201118, 85.4614269733429, 85.84905177354813, 78.55623990297318, 78.1191873550415, 73.99654537439346, 82.55601167678833, 88.25300797820091, 96.66020885109901, 43.39891903102398, 77.89138957858086, 77.31201946735382, 43.69045838713646, 101.59612879157066, 92.96199649572372, 97.78764635324478, 93.74734595417976, 96.95850804448128, 97.37232863903046, 82.94955655932426, 71.71799764037132, 71.44526347517967, 81.08982235193253, 90.93551963567734, 92.78885498642921, 95.30582472681999, 93.66229891777039, 92.91712090373039, 87.51606032252312, 87.81126648187637, 94.14524540305138, 98.97323593497276, 95.49710646271706, 87.77050226926804, 83.88486117124557, 85.69753870368004, 90.55142104625702, 87.3235322535038, 66.78490474820137, 40.284218564629555, 15.242500193417072, 4.849023828282952, 2.4401946226134896, 1.8399485503323376, 1.0913605755195022, 0.17442365846363828, 0.1740165607770905, 0.10837299021659419, 0.06523252464830875, 0.04695766503573395, 0.0833877500554081, 2.67688843421638, 22.47527528554201, 31.111993342638016, 40.59694178402424, 56.90061293542385, 82.4650901556015, 45.15996113419533, 14.416798800230026, 27.6386871188879, 44.72941003739834, 49.51746851205826, 70.36970838904381, 80.16555234789848, 77.78786793351173, 62.83422254025936, 24.449835531413555, 3.710458385758102, 0.2142290904885158, 0.08005748110008426, 0.09154634273727424, 0.11796518956543878, 0.1923086604801938, 0.16796121461084113, 0.09869328423519619, 0.04850329889450222, 0.021563575719483197, 0.04116050462471321, 0.021834415092598647, 0.03082141342019895, 0.013687286736967508, 0.01920105620229151, 0.02918896312621655, 0.07176925748353824, 0.05428414689959027, 0.047388604216394015, 0.03410214587347582, 0.06107597073423676, 0.029982415471749846, 0.09551471026497893, 0.07676013381569646, 0.047061844015843235, 0.0415619805426104, 0.022756305370421614, 0.020102110684092622, 0.053849370815441944, 0.021596139304165263, 0.01959010485734325, 0.04343024455010891, 0.08969677714048885, 0.07916418762761168, 0.08720756930415519, 0.04461177333723754, 0.032040259247878566, 0.08816130328341387, 0.08486520280712284, 0.003317992673146364, 0.03542972932336852, 0.06810940816649236, 0.06896431776112877, 0.015262885735864984, 0.02278203006426338, 0.034212811224278994, 0.04699419725511689, 0.08350031159352511, 0.08820332368486561, 0.10290828227880411, 0.10597288463031873, 0.09207613227772526, 0.025172456189466175, 0.02961000947834691, 0.10356399943702854, 0.027479494601720944, 0.0492608572676545, 0.10426690234453417, 0.08415486357989721, 0.06654030759818852, 0.10613712191116065, 72.08309724926949, 152.89539009332657, 124.67949494719505, 123.96699517965317, 102.88776308298111, 77.37393334507942, 42.98829786479473, 30.880686454474926, 34.07357342541218, 50.273650735616684, 55.419862791895866, 42.310562431812286, 39.7467640042305, 23.889684788882732, 1.2682345532812178, 0.1523821396403946, 0.10288296020007692, 0.060075288492953405, 0.06647800430073403, 0.7081796962302178, 2.2860637307167053, 3.4072097204625607, 2.6218766486272216, 9.833713676780462, 23.66840936243534, 44.50069651007652, 58.39431278407574, 77.2698949277401, 90.52890345454216, 92.90827497839928, 95.16398593783379, 93.87367397546768, 101.12974181771278, 100.51238894462585, 100.56332901120186, 100.67285433411598, 102.53021746873856, 97.56713658571243, 94.29938793182373, 89.41114023327827, 82.46555373072624, 74.14411425590515, 74.51394081115723, 72.91880160570145, 73.4415927529335, 75.02058282494545, 86.36042833328247, 91.9799391925335, 94.32373702526093, 89.44064944982529, 90.51017805933952, 83.046914935112, 79.70517665147781, 76.71776935458183, 85.968137383461, 91.66997462511063, 101.92564710974693, 54.796806424856186, 85.2647115290165, 86.23382672667503, 53.1028763204813, 103.97819817066193, 97.79333844780922, 102.2291748225689, 99.02589350938797, 101.51414439082146, 100.63168734312057, 87.94261783361435, 76.34092837572098, 75.46987071633339, 84.42716047167778, 94.88675281405449, 96.38498961925507, 98.8445520401001, 94.80102941393852, 94.36042785644531, 92.83577486872673, 92.55858734250069, 97.18982443213463, 102.92676419019699, 101.50833830237389, 88.4020283818245, 83.90857949852943, 84.12319958209991, 91.7088009417057, 89.46308344602585, 70.45578137040138, 43.91908071935177, 18.663754910230637, 5.133056212216616, 1.2671766662970185, 2.0054760994389653, 2.003939556889236, 0.7236506254412234, 0.6648430216591805, 0.22697210748447105, 0.29046965413726866, 0.006871517043691711, 0.19217491062590852, 2.8148407442495227, 25.310863628983498, 34.164631739258766, 31.168616004288197, 33.4660430252552, 47.40903005003929, 47.358610555529594, 19.928936921060085, 40.87646618485451, 60.7544307410717, 59.34189833700657, 83.18039417266846, 90.19163355231285, 90.26272773742676, 72.80777156352997, 29.383825175464153, 4.140348080545664, 0.17672753718215972, 0.08526082689058967, 0.1261321091442369, 0.05331191117875278, 0.06523851378005929, 0.0036639874861066346, 0.08200037176720798, 0.0227738367539132, 0.04707477222837042, 0.042070236668223515, 0.020610650681192055, 0.02105193168972619, 0.04877193408901803, 0.021445750498969574, 0.07096171175362542, 0.06487538092187606, 0.049039771474781446, 0.06291693483944982, 0.05152361358341295, 0.026910642118309624, 0.06017063220497221, 0.059533186722546816, 0.11487786265206523, 0.05693190345482435, 0.0634485055343248, 0.013295638709678315, 0.007320942659134744, 0.034400233198539354, 0.009072380562429316, 0.03715887403814122, 0.05327189828676637, 0.027013258877559565, 0.1504313896293752, 0.2519999543437734, 0.1528927669278346, 0.08093795026070438, 0.29859231202863157, 0.1981934462673962, 0.07975428408826701, 0.14459126628935337, 0.15025158209027722, 0.22930101142264903, 0.17681704019196332, 0.10326544084819034, 0.20480377046624199, 0.15089508349774405, 0.18326551682548597, 0.2235015874612145, 0.11687673351843841, 0.19534471241058782, 0.28529988310765475, 0.1912049829843454, 0.25235853041522205, 0.14241389406379312, 0.12071606382960454, 0.13968225626740605, 0.15157877962337807, 0.14648760203272104, 0.1700536406133324, 0.5367468483746052, 96.02372780442238, 168.33792865276337, 134.88266944885254, 137.34262704849243, 113.2169084250927, 76.67188301682472, 44.99034583568573, 39.17382314801216, 62.78179295361042, 111.55705869197845, 102.26813033223152, 64.79284644126892, 51.5524835139513, 31.548986993730068, 1.8017556122504175, 0.19805613410426304, 0.27580359892454, 0.2290824637748301, 0.2064815437188372, 0.4677863378310576, 2.9729825584217906, 11.93787356838584, 16.670520566403866, 15.567191820591688, 26.502359993755817, 42.824473455548286, 60.20443305373192, 76.0771769285202, 91.00416675209999, 93.79123359918594, 98.4605522453785, 95.93440219759941, 106.16238176822662, 103.81296783685684, 104.45810481905937, 103.91434639692307, 106.95948779582977, 99.99588266015053, 97.79513195157051, 92.37526997923851, 85.74358463287354, 77.51408502459526, 81.26059278845787, 76.5919429063797, 78.68790283799171, 78.4461598098278, 89.91464361548424, 96.55657321214676, 97.62898966670036, 91.74357667565346, 92.2954286634922, 87.32191354036331, 84.08505722880363, 82.25281074643135, 91.3446892797947, 99.34496998786926, 106.00040405988693, 62.29576863348484, 93.01134824752808, 96.34859517216682, 62.261103093624115, 106.31235972046852, 106.22580036520958, 108.0230887234211, 105.78238695859909, 105.67691221833229, 107.36002430319786, 93.19002985954285, 80.35295829176903, 79.49137732386589, 91.05694591999054, 102.05306187272072, 103.24993684887886, 104.6791161596775, 101.41931667923927, 100.43035134673119, 96.3913656771183, 98.05024266242981, 103.79707708954811, 107.22599789500237, 106.01596802473068, 94.04974892735481, 86.05442315340042, 85.94213917851448, 96.0995565354824, 92.5177775323391, 73.60950574278831, 46.02008678019047, 20.350148119032383, 9.158734045922756, 7.726916251704097, 6.446320367977023, 4.738371865823865, 1.8384616426192224, 0.8262113970704377, 0.2687809820054099, 0.5043576238676906, 0.12633038131752983, 0.4773974767886102, 4.741321932524443, 38.19598741829395, 48.56212757527828, 60.07216215133667, 74.77958455681801, 104.5328240096569, 61.772221326828, 22.422583512961864, 41.85038812458515, 66.55531346797943, 71.54031157493591, 94.84531983733177, 99.71184030175209, 100.01350611448288, 87.3400841653347, 38.14336784183979, 6.370931938290596, 0.46920755063183606, 0.2155443246010691, 0.27054304839111865, 0.1250185165554285, 0.18322278396226466, 0.2515353402122855, 0.25645705580245703, 0.07567352571641095, 0.141758993268013, 0.16859466733876616, 0.13234893180197105, 0.15603454521624371, 0.1946991033037193, 0.13121075928211212, 0.1285638302215375, 0.20309548010118306, 0.14059578068554401, 0.09297041280660778, 0.1393166891648434, 0.15036435885122046, 0.17370950459735468, 0.19893299642717466, 0.2882746187970042, 0.14089461386902258, 0.17824378941440955, 0.12423528358340263, 0.2307334158103913, 0.15455100685358047, 0.09128601217526011, 0.15614294330589473, 0.14064275863347575, 0.18308907863683999], [0.10496248767594807, 0.01640754926484078, 0.04543540511804167, 0.021790496648463886, 0.073228690889664, 0.05747563795011956, 0.0059695951767935185, 0.01114537528337678, 0.0759035321243573, 0.020365226155263372, 0.04513176652835682, 0.06452477551647462, 0.01436680271581281, 0.10843291122000664, 0.0066576996596268145, 0.1267146653844975, 0.0667292732396163, 0.010990983519150177, 0.03798816840571817, 0.050556587739265524, 0.03983514761785045, 0.054236953728832304, 0.04428775908309035, 0.022969901037868112, 0.10177883741562255, 0.03988245953223668, 0.047612324633519165, 46.37679263949394, 136.2869068980217, 98.68641212582588, 105.90182974934578, 69.2277480661869, 43.46358776092529, 22.531010694801807, 30.190307199954987, 72.11949169635773, 65.8532327413559, 62.99205467104912, 41.72243759036064, 31.09567701816559, 15.206223540008068, 0.16986794042168185, 0.043943398850387894, 0.07804412351106293, 0.18931716709630564, 0.22227029025088996, 0.10530127066886052, 0.5882980884052813, 3.286187876947224, 5.838035708293319, 13.807049319148064, 37.23342306911945, 54.396832287311554, 75.33262968063354, 89.1333219408989, 97.08350613713264, 92.31628194451332, 93.19586634635925, 92.47525781393051, 96.59679785370827, 92.09498181939125, 94.5237734913826, 94.33816865086555, 96.11590325832367, 96.32451206445694, 95.39350122213364, 92.19510644674301, 86.61423951387405, 76.40639126300812, 70.07374987006187, 72.35669016838074, 68.47649037837982, 72.66504362225533, 76.21100574731827, 82.85687193274498, 89.78162035346031, 91.67785540223122, 88.77618670463562, 86.72631829977036, 80.13063982129097, 74.12022113800049, 74.73780959844589, 75.0076787173748, 80.63608109951019, 91.25713437795639, 75.91057866811752, 43.3047790825367, 42.982267588377, 81.19842812418938, 92.56769925355911, 79.80929866433144, 87.90667936205864, 90.78099712729454, 95.11093318462372, 93.50542053580284, 84.96808424592018, 75.22237479686737, 71.85807332396507, 69.29219260811806, 74.45178374648094, 79.95303735136986, 85.0836968421936, 81.37426748871803, 78.57234343886375, 79.22198697924614, 82.07576304674149, 88.50542083382607, 95.63221961259842, 85.82223281264305, 86.88149437308311, 87.66315042972565, 93.43955487012863, 92.31438964605331, 90.56635424494743, 82.65568032860756, 70.78561127185822, 37.87259057164192, 11.124741900712252, 1.5591117949225008, 2.598956278525293, 2.4991346849128604, 1.7757538449950516, 0.8346861891914159, 0.15200655354419723, 0.0715428356488701, 0.06008537799061742, 0.04190943182038609, 0.14844209246803075, 2.925056917592883, 18.485631868243217, 36.944072395563126, 58.30002464354038, 89.87743601202965, 71.02370649576187, 38.772644475102425, 16.76939506083727, 17.447459176182747, 28.50508812814951, 51.77479438483715, 63.86081725358963, 78.10015797615051, 70.84444731473923, 71.37636557221413, 49.280756413936615, 6.456143790856004, 0.30744070129003376, 0.063800357747823, 0.08670935814734548, 0.014891803548380267, 0.14117415121290833, 0.03166512957250234, 0.02137435403710697, 0.028564768690557685, 0.005855338295077672, 0.04564331778965425, 0.02552426387410378, 0.05646638761390932, 0.04442814002686646, 0.05781909276265651, 0.010940990596282063, 0.038114062626846135, 0.0257348445666139, 0.028465814430091996, 0.0747322004463058, 0.06737935749697499, 0.03775424716877751, 0.07059451192617416, 0.058542211772874, 0.05097777881019283, 0.05483374807226937, 0.12882726296084002, 0.07716945052379742, 0.01499269110354362, 0.02838750857335981, 0.0215752830990823, 0.11268868285696954, 0.07889902568422258, 0.020248681139491964, 0.019176834357494954, 0.011081044067395851, 0.030803585177636705, 0.022497449826914817, 0.038922895982977934, 0.021020267959102057, 0.11374643625458702, 0.05127097538206726, 0.04200381074042525, 0.10817281072377227, 0.02211547198385233, 0.016137054990394972, 0.025201739481417462, 0.12064111433573999, 0.04402518352435436, 0.01628886315302225, 0.05709389573894441, 0.0504483232361963, 0.06432498194044456, 0.03637132918811403, 0.010010888454417, 0.011710158014466288, 0.05263085709884763, 0.06883708396344446, 0.036612152398447506, 57.938025668263435, 154.13330286741257, 114.7144004702568, 119.60331693291664, 87.29695647954941, 71.18856444954872, 41.624193862080574, 38.88207860291004, 43.144705072045326, 52.71109454333782, 49.910834804177284, 45.273761227726936, 39.46902170777321, 20.552869141101837, 0.389181143254973, 0.12406620007823221, 0.09846301807556301, 0.3723728936165571, 0.5076725303661078, 1.3645450165495276, 2.2825467819347978, 2.149555580690503, 4.151656748726964, 14.12868496030569, 39.71602365374565, 62.22723551094532, 80.86577117443085, 90.55762231349945, 99.04339537024498, 94.17546898126602, 95.22763252258301, 96.62990167737007, 101.78363353013992, 95.10545387864113, 96.77555546164513, 97.06689342856407, 99.75238412618637, 98.76161769032478, 97.6455719769001, 96.51416748762131, 90.84057033061981, 80.93052729964256, 73.36718514561653, 75.55763080716133, 71.968282610178, 74.41240265965462, 78.5301961004734, 89.00856703519821, 94.02509585022926, 95.78943997621536, 93.77633079886436, 92.48765274882317, 84.67041581869125, 79.4023784995079, 78.47886085510254, 78.31477046012878, 83.79962414503098, 92.76865527033806, 81.03608563542366, 52.3005835711956, 52.06137880682945, 85.96540153026581, 97.88260325789452, 83.41454520821571, 91.4612290263176, 96.11676201224327, 97.91332080960274, 96.14181026816368, 87.46122926473618, 77.86726847290993, 77.16642647981644, 73.94935190677643, 78.12342032790184, 82.85149902105331, 88.59791547060013, 85.21803483366966, 81.85593724250793, 83.3221797645092, 86.97259828448296, 95.15998855233192, 100.3608226776123, 89.3860387802124, 88.75325113534927, 92.43873417377472, 97.2025765478611, 93.70883882045746, 93.31798419356346, 85.30783161520958, 71.48251667618752, 42.33052656054497, 13.727347645908594, 1.5040504932403564, 0.8194798207841814, 0.45493516023270786, 1.9105817726813257, 2.258393852971494, 1.005318348761648, 0.34896074677817523, 0.18692060897592455, 0.020783621184818912, 0.08661948406370357, 3.119579879567027, 21.68420523405075, 36.291020438075066, 40.51085740327835, 87.02258080244064, 74.13060978055, 26.82299818843603, 25.77727910131216, 35.48709757626057, 45.03521002829075, 62.00524002313614, 74.09208744764328, 87.40873888134956, 82.45923846960068, 84.12846609950066, 58.33295747637749, 9.311110619455576, 0.1867239101557061, 0.060472523036878556, 0.0809757033130154, 0.04534056977718137, 0.06789693870814517, 0.043280215686536394, 0.027404385546105914, 0.04233874940837268, 0.030559323968191165, 0.04211017534544226, 0.0651513336924836, 0.014499771459668409, 0.010685609231586568, 0.03260069206589833, 0.02592553570138989, 0.014752538609172916, 0.028798240928153973, 0.017448595062887762, 0.044575760621228255, 0.02964616876852233, 0.05481475651322398, 0.03844655220746063, 0.08454982715193182, 0.047216618913807906, 0.049356123054167256, 0.1044195175927598, 0.05011332890717313, 0.05356325062166434, 0.034786932956194505, 0.03325767829664983, 0.06431451765820384, 0.27308974298648536, 0.1324738352559507, 0.1288823748473078, 0.16755208343965933, 0.19357069744728506, 0.09554279313306324, 0.14180980069795623, 0.09926740225637332, 0.17169104103231803, 0.09928513958584517, 0.13653422909555957, 0.1157990237697959, 0.10581298149190843, 0.19564005749998614, 0.10849456884898245, 0.25643722561653703, 0.11838840669952333, 0.0854890669870656, 0.13184593379264697, 0.17026553861796856, 0.2019818578264676, 0.1167484384495765, 0.1753870997345075, 0.21230370708508417, 0.32396444119513035, 0.11725450152880512, 0.16524007078260183, 77.67939135432243, 171.13894075155258, 124.21179324388504, 138.81149142980576, 97.35805660486221, 68.54332119226456, 36.22223272919655, 50.61611495912075, 95.40159478783607, 93.44944953918457, 89.78437140583992, 66.67729452252388, 53.75516451895237, 29.219936169683933, 1.318617237266153, 0.3420284343883395, 0.28300914040300995, 0.4617028048960492, 0.45409359445329756, 0.9232696483377367, 3.0685372184962034, 12.165803387761116, 14.276005905121565, 20.831576585769653, 42.64417313039303, 57.21298657357693, 80.56926548480988, 92.04585045576096, 101.86529114842415, 97.75917068123817, 96.1596617102623, 100.09000360965729, 107.47837275266647, 98.90185296535492, 104.09673660993576, 104.35310885310173, 102.19278037548065, 101.32534012198448, 103.86442467570305, 100.799949914217, 96.18850976228714, 84.7304829955101, 77.06741899251938, 78.63916665315628, 77.37576484680176, 79.90525111556053, 84.79202449321747, 91.99959173798561, 98.52467760443687, 100.33247619867325, 99.18274149298668, 95.06989538669586, 92.7530001103878, 82.75918677449226, 81.52199596166611, 83.44517916440964, 89.3805442750454, 101.0591872036457, 86.27181708812714, 58.282363191246986, 59.86973561346531, 87.37363636493683, 106.215008944273, 89.44111302495003, 98.23061898350716, 100.48763707280159, 104.88982245326042, 100.815050303936, 93.56183990836143, 81.38692080974579, 79.90535750985146, 76.31240710616112, 82.15788424015045, 88.41031193733215, 94.59566563367844, 89.37940433621407, 89.44302052259445, 90.31397178769112, 91.8941093981266, 98.30978393554688, 106.24238267540932, 90.37010997533798, 91.70592829585075, 93.87270122766495, 104.5851320028305, 99.04275700449944, 99.91132959723473, 87.60672345757484, 77.37217023968697, 42.10981920361519, 16.655283384025097, 5.580293163657188, 10.077760331332684, 8.89886599034071, 7.581723192706704, 3.754374054260552, 1.5521299070678651, 0.6203775107860565, 0.2849345683353022, 0.15379980497527868, 0.512095611775294, 6.272236984223127, 32.57809527218342, 56.68617524206638, 79.8179318010807, 99.46103096008301, 86.99762374162674, 55.23868851363659, 26.52411002665758, 31.47859577089548, 46.93848989903927, 73.59598606824875, 86.42838388681412, 98.37245017290115, 91.26822978258133, 97.25850194692612, 69.87518012523651, 15.497048534452915, 0.4890855902340263, 0.20311026368290186, 0.12946343194926158, 0.09616555893444456, 0.19750229897908866, 0.13401411822997034, 0.10128478970727883, 0.1606674466165714, 0.08977910358225927, 0.20985350653063506, 0.14689274044940248, 0.13827003829646856, 0.13647910236613825, 0.07986455981153995, 0.09713269610074349, 0.21623717882903293, 0.21270630735671148, 0.11172387603437528, 0.21075293014291674, 0.15513089136220515, 0.1294803380733356, 0.10590508944005705, 0.23393855866743252, 0.2316910238005221, 0.2179045174852945, 0.21504715987248346, 0.2068201857036911, 0.18513133545638993, 0.09960375842638314, 0.136426261451561, 0.16130873642396182], [0.08458689000690356, 0.04545714633422904, 0.08731063877348788, 0.06322231376543641, 0.011304138297418831, 0.0592369325022446, 0.12087794850231148, 0.07188526258687489, 0.02199712354922667, 0.032365813458454795, 0.026270272574038245, 0.04813761304831132, 0.031991385112633, 0.06755041511496529, 0.09219730272889137, 0.014103077755862614, 0.023653385651414283, 0.019890355542884208, 0.032499860171810724, 0.04900491279840935, 0.07642322103492916, 0.06833877632743679, 0.08073620483628474, 0.14165688859065995, 0.2835686306934804, 0.1453533035237342, 39.202184826135635, 127.75026977062225, 98.25139626860619, 103.71741056442261, 72.9005017876625, 54.40735012292862, 15.597773529589176, 27.254248447716236, 53.08003954589367, 62.744889333844185, 65.87312087416649, 45.63670635223389, 29.892612174153328, 9.266990236938, 0.28377836162690073, 0.1718774833716452, 0.0757697228982579, 0.12516274553490803, 0.12548498605610803, 0.08159026096109301, 0.296779838972725, 2.1462003607302904, 5.80918338149786, 16.436964198946953, 42.676600590348244, 77.44357600808144, 95.19433110952377, 100.14663577079773, 92.63111025094986, 93.87891009449959, 93.79926636815071, 95.72968438267708, 93.01909983158112, 88.06632399559021, 81.52510419487953, 84.85571667551994, 81.17322787642479, 90.98192274570465, 92.80883431434631, 92.38255798816681, 91.50741174817085, 89.4914299249649, 77.25745439529419, 69.028539955616, 67.55351230502129, 70.45473262667656, 71.65079444646835, 83.88260409235954, 89.80154648423195, 94.54129815101624, 89.58416014909744, 92.91959077119827, 89.16742891073227, 85.6322506070137, 82.22585499286652, 93.11644300818443, 86.9299341738224, 86.32747650146484, 77.75776594877243, 102.45296001434326, 47.58556477725506, 35.47235816717148, 104.54298466444016, 80.60623750090599, 82.61881470680237, 67.46798649430275, 76.07427388429642, 74.53942984342575, 78.24751406908035, 68.96016642451286, 74.92858216166496, 71.19858831167221, 70.58170661330223, 67.11351111531258, 70.1750448346138, 71.00037574768066, 72.74242267012596, 69.84317824244499, 75.23540049791336, 83.04755330085754, 87.03214108943939, 89.26677837967873, 92.71839156746864, 93.92173379659653, 92.33121514320374, 86.74629762768745, 85.78228175640106, 89.17961865663528, 88.48946169018745, 77.49127864837646, 73.84646862745285, 54.837186858057976, 16.926594525575638, 1.1901659611612558, 1.9242090289480984, 0.7563498301897198, 1.168706612661481, 1.0100044473074377, 0.3279674967052415, 0.2796725928783417, 0.057510196056682616, 0.033217899181181565, 0.0809483922785148, 1.118839276023209, 10.26093140244484, 24.602893218398094, 20.487326458096504, 37.16864034533501, 51.152505576610565, 37.37554684281349, 19.35671802610159, 24.767407290637493, 22.290698289871216, 44.37301576137543, 65.60904264450073, 76.74098610877991, 84.0893965959549, 85.09227678179741, 58.84937256574631, 20.998013354837894, 0.868079747306183, 0.050756485215970315, 0.052513779592118226, 0.006904043520989944, 0.071277228416875, 0.024084649521682877, 0.09787903691176325, 0.019706041312019806, 0.02145701444533188, 0.02502826988347806, 0.03442278706643265, 0.03209925256669521, 0.0705448622466065, 0.039741232540109195, 0.03399862369406037, 0.05563039536355063, 0.0643582598422654, 0.03578847237804439, 0.052968482341384515, 0.04661052174924407, 0.054416620259871706, 0.1149372270447202, 0.07985560951055959, 0.03793811425566673, 0.05235676340817008, 0.047257125333999284, 0.1009973930194974, 0.03275004186434671, 0.050163935957243666, 0.05469181603984907, 0.030333896611409727, 0.031198730575852096, 0.043647515703924, 0.0460175791522488, 0.015204190203803591, 0.04196575711830519, 0.041407673197682016, 0.01698905722150812, 0.056458016188116744, 0.03763974491448607, 0.07897363379015587, 0.02466174355504336, 0.07291789428563789, 0.03944223979488015, 0.014759275454707677, 0.03917293666745536, 0.05075894914625678, 0.04045026558742393, 0.03536339987476822, 0.018576264337752946, 0.08869567929650657, 0.03227531226002611, 0.08330410259077325, 0.1216791637125425, 0.2503836457617581, 0.18874272995162755, 48.9274437725544, 146.4251884818077, 110.87518528103828, 117.88305804133415, 90.62468111515045, 78.58460158109665, 34.74469341337681, 35.61388537287712, 30.869271866977215, 58.262269869446754, 48.14446918666363, 47.58044645190239, 36.959146186709404, 14.26294220611453, 0.0547354320588056, 0.2185275949887, 0.16307921876432374, 0.13133931410266086, 0.6485476554371417, 0.4356340365484357, 1.1480063921771944, 1.4194373460486531, 4.191838642582297, 19.571944177150726, 47.32464037835598, 83.18863213062286, 95.67770317196846, 99.10263419151306, 91.37526243925095, 93.99035051465034, 95.37960156798363, 97.93314054608345, 96.00639313459396, 93.25374484062195, 86.48627758026123, 87.19297125935555, 86.65488973259926, 94.98053938150406, 96.64036631584167, 98.35043415427208, 95.708177536726, 95.07154449820518, 81.28550425171852, 73.25709745287895, 71.03250682353973, 75.4701367020607, 75.53665593266487, 90.1838743686676, 91.87419086694717, 96.82952016592026, 93.90474870800972, 98.05750027298927, 91.20975092053413, 90.38423761725426, 87.4965749680996, 98.23270127177238, 91.41944646835327, 91.40836626291275, 83.29510241746902, 105.84012106060982, 55.222459584474564, 40.28496332466602, 104.38285365700722, 84.68218758702278, 87.27323815226555, 69.93935868144035, 81.05623975396156, 78.58020901679993, 81.2180046737194, 72.58280083537102, 77.10145756602287, 74.07163694500923, 75.11287227272987, 73.01388770341873, 73.80361452698708, 74.61267471313477, 75.02564415335655, 71.10525771975517, 77.05975100398064, 87.06613406538963, 92.33619287610054, 92.55297124385834, 94.04191374778748, 97.0483048260212, 95.35621762275696, 89.6661901473999, 89.77964445948601, 95.1285870373249, 90.92471301555634, 80.11837407946587, 77.06152930855751, 61.4792912453413, 22.571752108633518, 1.5910711674951017, 0.6604275992140174, 1.0344048379920423, 1.1017823475413024, 1.4859049231745303, 1.189208293799311, 0.6159566855058074, 0.23864873248385265, 0.12040122994221747, 0.16150222916621715, 0.852618555072695, 12.317143566906452, 30.635871291160583, 23.157673068344593, 24.277748465538025, 44.24272835254669, 24.116842299699783, 21.585815213620663, 36.2378840893507, 34.87369269132614, 61.44561745226383, 73.24349418282509, 85.95328018069267, 93.88497456908226, 96.84357181191444, 72.91280552744865, 28.859611004590988, 1.0911894659511745, 0.05777970698545687, 0.023778654613124672, 0.03308373372419737, 0.026593932452669833, 0.015456732853635913, 0.0382014690694632, 0.00924377585761249, 0.0422014817741001, 0.024320027223438956, 0.03507468958559912, 0.021019290179538075, 0.031071374323801138, 0.013382799315877492, 0.04354544071247801, 0.004324950004956918, 0.03165288042509928, 0.009753223130246624, 0.043482647597556934, 0.02393605300312629, 0.013542336946557043, 0.028460613830247894, 0.06557884044013917, 0.015909185967757367, 0.05011697285226546, 0.02513716150133405, 0.031804096724954434, 0.046111271585687064, 0.06513834610814229, 0.013739409623667598, 0.13204079208662733, 0.12705344095593318, 0.1745717614539899, 0.1012326093041338, 0.126703176938463, 0.09090298975934274, 0.24201196763897315, 0.22914818837307394, 0.24798511352855712, 0.15667767554987222, 0.10815417539561167, 0.169594444159884, 0.14324627205496654, 0.28351201966870576, 0.12382067536236718, 0.13980603165691718, 0.18334627733565867, 0.1131227205041796, 0.09655244793975726, 0.2249793370719999, 0.23761297634337097, 0.18798130127834156, 0.20025085774250329, 0.38237140397541225, 0.28683820681180805, 0.24149837176082656, 60.40567025542259, 166.71734601259232, 120.19215613603592, 134.01982694864273, 96.4417889714241, 78.91009971499443, 29.272141568362713, 41.536486968398094, 73.40221166610718, 86.65635645389557, 88.48759219050407, 74.30113703012466, 50.73790222406387, 18.001087568700314, 1.2972768698818982, 0.37077689019497484, 0.2812578796874732, 0.2953245467506349, 0.3854082722682506, 0.2163939204183407, 3.3040324319154024, 8.54310343042016, 14.673721063882113, 20.729612857103348, 45.06220377981663, 82.24516555666924, 95.69352552294731, 100.92511519789696, 93.4426099061966, 95.1886086165905, 95.35098150372505, 100.31945049762726, 102.88382649421692, 96.55519768595695, 93.79681169986725, 91.59862965345383, 91.1393178999424, 100.67495942115784, 103.42897564172745, 100.6088125705719, 98.4085938334465, 98.0892513692379, 86.5633450448513, 77.18427032232285, 76.63134679198265, 79.13652196526527, 81.34267598390579, 94.23970833420753, 96.66020885109901, 102.08946391940117, 98.85804131627083, 101.99960634112358, 98.06228801608086, 93.1808191537857, 92.67759695649147, 102.77219608426094, 98.63804832100868, 96.33580505847931, 89.75804641842842, 111.81136384606361, 59.81983669102192, 46.70487843453884, 108.0654564499855, 90.09596988558769, 88.3800807595253, 75.05856558680534, 83.92495661973953, 83.84485691785812, 85.61834335327148, 77.58347690105438, 81.92792057991028, 80.82177713513374, 79.46344122290611, 77.15437352657318, 77.42066323757172, 78.29224526882172, 79.90108653903008, 75.97120821475983, 81.95547670125961, 91.84997856616974, 97.56851211190224, 97.50117212533951, 95.39179131388664, 102.83928528428078, 101.72535985708237, 96.02864474058151, 95.22888645529747, 100.48263654112816, 96.8093204498291, 81.20408982038498, 77.29350686073303, 58.39058518409729, 19.827336072921753, 6.628458369523287, 6.325205666944385, 4.345165165141225, 5.45713322237134, 3.095383490435779, 3.4538488928228617, 0.6522948481142521, 0.22108963719801977, 0.24739847547607496, 0.5514686834067106, 2.233002665452659, 19.4674326851964, 42.61051073670387, 35.210521817207336, 51.91734753549099, 67.70772323012352, 50.2711770683527, 28.897827453911304, 36.28763101994991, 36.09405800700188, 66.90053254365921, 88.02188917994499, 99.9510070681572, 104.8960693180561, 105.9406940639019, 86.61750733852386, 39.04409430921078, 1.7714669625274837, 0.12305993688642047, 0.17301780811976641, 0.09947970102075487, 0.18760617531370372, 0.10983539221342653, 0.14029418671270832, 0.11972511114436202, 0.10869212113902904, 0.13178101071389392, 0.21341832383768633, 0.1491687589441426, 0.14403642184333876, 0.09972205676604062, 0.16122212779009715, 0.11710002348991111, 0.245522964396514, 0.08520642746589147, 0.1927030080696568, 0.19590412848629057, 0.09754613172844984, 0.1565821611438878, 0.1795247511472553, 0.04782138021255378, 0.20168127317447215, 0.1500331235001795, 0.21349020826164633, 0.20125140639720485, 0.16046362317865714, 0.1944710116367787], [0.06544550618855283, 0.03920720533642452, 0.040185515535995364, 0.030317253949760925, 0.06323934605461545, 0.047315124174929224, 0.03272019268479198, 0.026462351524969563, 0.04568095951981377, 0.04509022110141814, 0.016224086648435332, 0.014112545704847435, 0.031811191656743176, 0.06224712429684587, 0.009284627376473509, 0.13511064142221585, 0.020822504156967625, 0.08005018578842282, 0.07550142909167334, 0.08763486082898453, 0.029820883319189306, 0.05489264862262644, 0.11621733530773781, 0.19832597899949178, 0.6159408332314342, 30.286877118051052, 134.08547222614288, 103.3424086868763, 109.8643559217453, 74.27283614873886, 52.33072355389595, 19.713697470724583, 43.290191665291786, 63.54163438081741, 75.90932473540306, 59.09390464425087, 51.9953915476799, 27.443981766700745, 10.869914274662733, 0.5677734897471964, 0.10662522501661442, 0.2373234645347111, 0.2389272308209911, 0.18891787680331618, 2.1301343478262424, 4.66095102019608, 4.219280295073986, 4.032501317560673, 16.389877125620842, 62.613465785980225, 89.74442794919014, 102.93370261788368, 101.08531460165977, 99.8983646929264, 96.38396367430687, 97.05258339643478, 92.89230823516846, 91.077411621809, 93.85136917233467, 87.11615458130836, 76.4971075952053, 77.13628649711609, 73.81522670388222, 74.15653198957443, 78.27729687094688, 87.31074213981628, 90.74988439679146, 86.86510965228081, 74.33364808559418, 69.37508136034012, 69.72079440951347, 70.29248133301735, 76.7406365275383, 86.29984438419342, 85.94320312142372, 88.00070151686668, 83.93947184085846, 86.63899138569832, 82.770456969738, 87.12507650256157, 84.8008020222187, 91.62860244512558, 85.44270917773247, 93.66923734545708, 80.89021146297455, 94.14436385035515, 65.85327833890915, 39.20662298798561, 97.77981877326965, 80.66055178642273, 76.7421792447567, 67.12575405836105, 78.43523919582367, 80.85684165358543, 85.8548654615879, 79.32660296559334, 74.80734586715698, 70.33150523900986, 70.69430217146873, 66.2008760869503, 67.94460251927376, 66.8485589325428, 67.58915439248085, 66.73554539680481, 71.90032705664635, 82.56123259663582, 90.01755729317665, 91.55147418379784, 90.88611468672752, 87.58654654026031, 82.4367892742157, 77.05938622355461, 81.40540301799774, 85.87935134768486, 85.25103986263275, 79.553382396698, 82.62563154101372, 94.39251333475113, 88.96763563156128, 39.40063297748566, 2.126406985335052, 0.9304070903453976, 1.0677789221517742, 0.5837918270844966, 0.30592220777180046, 1.2470787134952843, 1.1963703157380223, 0.1002906754729338, 0.03068466714466922, 0.023876844461483415, 0.2008994948118925, 7.2731878235936165, 29.554293528199196, 54.62996877729893, 41.71415023505688, 58.01018759608269, 70.2871236205101, 29.923753403127193, 17.18499395996332, 17.44167398661375, 34.59483325481415, 58.19629020988941, 65.2912124991417, 65.68420261144638, 84.14931178092957, 80.47021239995956, 25.663621500134468, 0.6495018198620528, 0.04967813722032588, 0.028600848199857865, 0.07761726985336281, 0.0007694452597206691, 0.03598558309022337, 0.03597046925278846, 0.03530751615471672, 0.01639812584471656, 0.06597240135306492, 0.03385873627848923, 0.09771518554771319, 0.09402577648870647, 0.016609684316790663, 0.03280261931649875, 0.1082225346181076, 0.009709547739475965, 0.06966951390495524, 0.07981354458024725, 0.02231253260106314, 0.03277636213169899, 0.05184556466701906, 0.03669589263154194, 0.015852560100029223, 0.0664568308275193, 0.06001513742376119, 0.046639317079097964, 0.03180447150953114, 0.05384881420468446, 0.05819038924528286, 0.03057223919313401, 0.054948369070189074, 0.04860039407503791, 0.02102870803355472, 0.021915600482316222, 0.017789014491427224, 0.01295904876315035, 0.01775777378497878, 0.07711876925895922, 0.09367475548060611, 0.035076351996394806, 0.06170582775666844, 0.021818863388034515, 0.03834675932012033, 0.017331534254481085, 0.08463420192128979, 0.0636860892700497, 0.013501684879884124, 0.05410706675320398, 0.09672332744230516, 0.07913732188171707, 0.09427980621694587, 0.33472679962869734, 0.5873765191063285, 38.63706775009632, 154.57271128892899, 116.75573453307152, 124.04250472784042, 86.51269376277924, 69.55129310488701, 42.85780526697636, 38.56548719108105, 31.339749321341515, 71.28411412239075, 53.92916098237038, 51.07880473136902, 38.53574998676777, 13.635090496391058, 0.3218965802807361, 0.22236111428355798, 0.1455409629852511, 0.16105811315355822, 0.24768610222963616, 3.5474150720983744, 5.502242976799607, 2.22267790697515, 4.616141449660063, 21.40184048563242, 68.01121294498444, 93.51249575614929, 103.5856868326664, 103.59334722161293, 100.82248270511627, 99.16985258460045, 101.80270850658417, 91.06835290789604, 94.33678552508354, 95.28333753347397, 90.53850933909416, 80.5726321041584, 78.69211301207542, 77.731152176857, 79.19004589319229, 81.58948794007301, 90.82870736718178, 96.50196254253387, 92.16429010033607, 79.43869695067406, 72.08878174424171, 71.30451142787933, 75.88540881872177, 81.75520464777946, 92.85399109125137, 89.6507477760315, 91.40455886721611, 88.1151133775711, 92.91563898324966, 87.21645399928093, 91.30397066473961, 89.45022493600845, 93.51467683911324, 90.45692771673203, 96.58400774002075, 84.79344561696053, 97.022063434124, 68.96506816148758, 41.88805550336838, 104.8097987473011, 84.31332617998123, 79.40611749887466, 70.57384103536606, 83.09993728995323, 83.35950896143913, 90.61851784586906, 83.41631591320038, 78.65520939230919, 73.53800117969513, 73.7972004711628, 68.57600703835487, 70.62648341059685, 68.4178139269352, 71.02394968271255, 70.43963223695755, 76.44713267683983, 84.54058438539505, 94.19413357973099, 94.69774335622787, 94.40823689103127, 89.62165653705597, 87.23104521632195, 81.37647897005081, 85.32464191317558, 90.05669519305229, 90.00455439090729, 79.7103975713253, 85.3111906349659, 98.0507518351078, 95.29690280556679, 49.033705070614815, 3.8753229891881347, 0.7691503339447081, 0.78932297648862, 1.0751806874759495, 0.45201228582300246, 2.689383113756776, 2.914706510491669, 0.1373284458531998, 0.0672563019907102, 0.00439916662799078, 0.15885328146396205, 7.1476981323212385, 34.26551632583141, 43.09636786580086, 30.021493658423424, 46.876720413565636, 38.24251972138882, 24.990502819418907, 28.51837981492281, 33.548563197255135, 51.711368188261986, 73.7800557911396, 77.6304879784584, 74.91706877946854, 95.77980369329453, 97.13977351784706, 34.82559107244015, 0.679495451040566, 0.06649718881817535, 0.025274338222516235, 0.028983831653022207, 0.02068993060674984, 0.060327986066113226, 0.06491964260931127, 0.03045297049538931, 0.08602249305113219, 0.019661480910144746, 0.009452481699554482, 0.027792751425295137, 0.06480276919319294, 0.020557566713250708, 0.05228475281910505, 0.05986059630231466, 0.008023871541809058, 0.03514388372423127, 0.03191407929989509, 0.03247058986744378, 0.02536076688556932, 0.08718816214241087, 0.07583693179185502, 0.0103480461439176, 0.05487251044542063, 0.042291845675208606, 0.01889927854790585, 0.11595891948672943, 0.06815117623773403, 0.1940857627778314, 0.10071928802062757, 0.10905471965088509, 0.20019044692162424, 0.08657123704324476, 0.1617403991986066, 0.0555937963508768, 0.09328166954219341, 0.18151379597838968, 0.1420253945980221, 0.15153576474403962, 0.14305515418527648, 0.1940363208996132, 0.1569548825500533, 0.1844372641062364, 0.2724418183788657, 0.09222269160090946, 0.1441926439292729, 0.1476796841598116, 0.29872868908569217, 0.14840134856058285, 0.22755957674235106, 0.2568058355245739, 0.37403251393698156, 0.7880097907036543, 49.550952315330505, 171.98948711156845, 128.1162053346634, 141.23542696237564, 99.68480855226517, 79.383425116539, 31.14328846335411, 62.18241311609745, 82.12329089641571, 103.15936490893364, 79.99949365854263, 84.63355779647827, 46.592100486159325, 19.091551154851913, 0.7592240197118372, 0.45445748430211097, 0.6508424354251474, 0.4872429562965408, 0.37845238926820457, 4.241211768239737, 11.061418298631907, 10.915039703249931, 11.00315222516656, 19.44400694221258, 70.00927492976189, 94.79593008756638, 106.7695739865303, 107.3935841023922, 105.53369030356407, 102.87353664636612, 103.44871938228607, 91.57901510596275, 93.37951049208641, 100.39413928985596, 96.26085788011551, 83.75529572367668, 85.35285919904709, 83.06408241391182, 83.05731877684593, 86.19405806064606, 96.56253889203072, 100.97096353769302, 95.07458433508873, 82.39226326346397, 74.94761154055595, 75.70082232356071, 79.6568052470684, 86.45119026303291, 94.67267990112305, 94.8059843480587, 96.61176145076752, 93.59897911548615, 96.60457223653793, 92.81450361013412, 96.34740203619003, 92.04788714647293, 95.64728200435638, 94.081811606884, 101.26118436455727, 89.48171004652977, 101.74839422106743, 71.78129464387894, 47.412309274077415, 106.09042882919312, 90.41558593511581, 83.57803523540497, 75.35918265581131, 85.5021607875824, 89.20383855700493, 93.08911487460136, 88.36205452680588, 82.34164997935295, 76.91369444131851, 77.65939682722092, 72.80624404549599, 73.85247990489006, 72.71567970514297, 76.62777498364449, 76.77495628595352, 80.24659439921379, 91.9417816400528, 99.13964420557022, 97.24601581692696, 98.19366216659546, 96.18455797433853, 93.08810412883759, 86.9018004834652, 90.19892156124115, 93.64089846611023, 93.79319429397583, 81.18688434362411, 87.58020848035812, 103.4838218986988, 96.5367078781128, 43.99193421006203, 3.014395348727703, 2.576809166930616, 4.360262230038643, 4.558969242498279, 1.7134312517009676, 5.691902199760079, 4.234831435605884, 0.3518990578595549, 0.24189046322135255, 0.2689577912678942, 0.6778194440994412, 13.362744860351086, 47.30559580028057, 83.43279182910919, 57.884319350123405, 80.63593670725822, 90.12182369828224, 41.263068839907646, 27.84456767141819, 30.513690747320652, 53.57602693140507, 79.5515812933445, 89.41808626055717, 88.53969499468803, 104.01471421122551, 108.98493871092796, 45.448282063007355, 1.0896013886667788, 0.13707377045648172, 0.09370754356496036, 0.1572078064782545, 0.08891069432138465, 0.1281793977250345, 0.1050394112826325, 0.17211547528859228, 0.20687844429630786, 0.16314149979734793, 0.18191767274402082, 0.17812918697018176, 0.12975454679690301, 0.09548579619149677, 0.09592458358383738, 0.2720758208306506, 0.13402529497398064, 0.16785715066362172, 0.10759747558040544, 0.13553460070397705, 0.17964309401577339, 0.14447607012698427, 0.18954735161969438, 0.08070688258158043, 0.28039805707521737, 0.18423255009111017, 0.13432819512672722, 0.25637651793658733, 0.14725573972100392], [0.018310705345356837, 0.10322617381461896, 0.034234467093483545, 0.09091464889934286, 0.04459873009182047, 0.020497226396400947, 0.024682495859451592, 0.011550732633622829, 0.012230057509441394, 0.019825246927211992, 0.03199028673407156, 0.006432578438761993, 0.0474243497592397, 0.019303941990074236, 0.0414081852795789, 0.07151760262786411, 0.05549275294470135, 0.10275165943312459, 0.05332632739737164, 0.03675079300592188, 0.03549733155523427, 0.043427543132565916, 0.07734091632300988, 0.07346730621065944, 8.03376641124487, 107.3760062456131, 99.89745274186134, 96.05214267969131, 92.01555848121643, 79.9477556347847, 34.433661103248596, 40.12852191925049, 76.04820728302002, 70.12129291892052, 33.810536339879036, 51.31544463336468, 33.25429938733578, 10.934497509151697, 0.2655174914980307, 0.017833589736255817, 0.18957185733597726, 0.06343427856336348, 0.1978544777375646, 0.07015750568825752, 4.2698627058416605, 7.130378186702728, 1.8043753341771662, 17.422365322709084, 61.70976787805557, 94.18263539671898, 102.76464968919754, 100.69101735949516, 99.44438025355339, 96.50051102042198, 92.89152547717094, 96.72323986887932, 94.57507833838463, 88.68677750229836, 91.77958354353905, 85.65201714634895, 75.37157759070396, 69.88834261894226, 65.572739392519, 66.64151564240456, 67.66037777066231, 74.39268171787262, 77.20114901661873, 76.80622100830078, 69.00336250662804, 68.6516609787941, 67.0740008354187, 72.56348267197609, 76.78865075111389, 84.27444666624069, 83.13082963228226, 75.118807554245, 73.55959162116051, 81.51840135455132, 84.49537441134453, 85.37372007966042, 87.50450134277344, 85.66010311245918, 79.62576851248741, 81.24619916081429, 82.59901776909828, 90.00724464654922, 83.07031407952309, 48.23209248483181, 87.3756730556488, 84.72308099269867, 83.52611482143402, 76.96927025914192, 86.24381259083748, 89.78224352002144, 92.99565508961678, 92.35316276550293, 78.6417505145073, 66.96165606379509, 70.89895159006119, 65.1317198574543, 68.40346589684486, 66.81429237127304, 66.82868599891663, 65.11418759822845, 73.08345437049866, 81.28731295466423, 89.90001440048218, 87.97698318958282, 86.11596465110779, 73.81198167800903, 69.61672559380531, 68.94898742437363, 77.83338949084282, 86.23847007751465, 84.77158918976784, 75.4590716958046, 87.50874191522598, 84.41565468907356, 87.52220839262009, 101.72621101140976, 69.75461259484291, 10.020352061837912, 0.5447082524187863, 1.0865401779301465, 0.5611039570067078, 1.4422687771730125, 2.1155683044344187, 0.6478413089644164, 0.03700779503560625, 0.03796407087065745, 0.17754815955413505, 0.1279998425161466, 4.974209060892463, 17.868018709123135, 43.428439646959305, 36.771865636110306, 67.95140415430069, 64.12604302167892, 27.052070796489716, 21.99596520513296, 12.027217224240303, 29.54809606075287, 41.43989235162735, 55.655328556895256, 75.96059158444405, 76.3941179215908, 79.07849907875061, 21.347305811941624, 0.14773671078728512, 0.1333618743228726, 0.08736410309211351, 0.05799869992188178, 0.09202116139931604, 0.026405265525681898, 0.06069106326322071, 0.02925290842540562, 0.05581673380220309, 0.047360580720123835, 0.05590334243606776, 0.040694851486478, 0.0920737796695903, 0.005660441502186586, 0.07553606512374245, 0.020711521538032684, 0.04559160865028389, 0.017871365052997135, 0.025438477168790996, 0.06340599531540647, 0.044533714244607836, 0.03687165917654056, 0.02605639303510543, 0.021324336994439363, 0.007746187711745733, 0.009421116683370201, 0.011855738630401902, 0.07918769886600785, 0.045779279244015925, 0.13537356950109825, 0.04474332643439993, 0.07795785626512952, 0.05676235610735603, 0.019960202771471813, 0.022369180733221583, 0.06429428671253845, 0.04884136200416833, 0.026322978046664502, 0.05002888363378588, 0.04849552489758935, 0.03297714647487737, 0.06015692473738454, 0.01908370595629094, 0.022101961185398977, 0.0669141644902993, 0.04769763079821132, 0.0533154029835714, 0.04983266720955726, 0.03569303960830439, 0.04507904435740784, 0.12296255226829089, 0.11414531836635433, 11.414748039096594, 132.11535394191742, 113.17970082163811, 111.01156756281853, 106.80728316307068, 99.39401015639305, 57.959464117884636, 32.234339118003845, 55.93632347881794, 78.49112659692764, 43.515899553895, 43.691982105374336, 40.94072073698044, 14.470148887485266, 0.1060519010934513, 0.17323662294074893, 0.12206655737827532, 0.0598616724164458, 0.21793438150780275, 0.21153657871764153, 3.9122304087504745, 8.472760654985905, 2.1813097642734647, 21.348852328956127, 66.43492832779884, 100.80135583877563, 104.83660250902176, 104.41442236304283, 101.71491801738739, 99.17986884713173, 95.3796699643135, 101.24973937869072, 98.10433655977249, 89.09507319331169, 95.90933874249458, 91.2394805252552, 80.76216593384743, 74.91676479578018, 69.09812182188034, 68.7746299803257, 71.02065145969391, 78.60862389206886, 80.68097949028015, 80.31413197517395, 71.48117914795876, 69.20187905430794, 70.5557844042778, 76.45944401621819, 81.49436384439468, 85.27039602398872, 87.01717749238014, 78.47398951649666, 74.15028512477875, 84.53118368983269, 87.56022155284882, 88.74929934740067, 89.06639993190765, 88.9490394294262, 83.67776468396187, 85.4026897251606, 85.3610135614872, 93.6653083562851, 87.74230778217316, 51.986082047224045, 89.57890883088112, 90.18183767795563, 85.52864536643028, 79.26807090640068, 92.05245450139046, 94.29268509149551, 94.99313190579414, 95.52573412656784, 81.54389038681984, 70.73931455612183, 73.2616876065731, 68.6070665717125, 72.25069105625153, 69.0926045179367, 68.5307514667511, 68.61889153718948, 76.40864834189415, 83.64026069641113, 93.07078465819359, 89.96221706271172, 87.61700570583344, 79.30325701832771, 72.70539745688438, 71.33848160505295, 81.3863280415535, 90.58539122343063, 87.53660202026367, 77.9448527097702, 93.16843181848526, 89.70182463526726, 89.96321260929108, 104.50598984956741, 79.51075628399849, 15.785447359085083, 1.0541033372282982, 0.40124980034306645, 0.36131792119704187, 0.9424212737940252, 1.900052062701434, 0.7218970195390284, 0.03655787913885433, 0.13359367672819644, 0.17084595747292042, 0.1056863043049816, 5.4489850345999, 23.555359728634357, 39.931855872273445, 28.296361528337002, 58.769166469573975, 39.43151772022247, 29.374884255230427, 32.64049552381039, 25.137431435287, 46.45849585533142, 53.94134692847729, 67.11668774485588, 85.54292500019073, 85.71229711174965, 97.21787452697754, 27.771812975406647, 0.21301455097272992, 0.10976728532114066, 0.07309635853744112, 0.055113678754423745, 0.03300183772807941, 0.02810457404848421, 0.06876580067910254, 0.05226698951446451, 0.0517535309336381, 0.027725934014597442, 0.0851929426426068, 0.10942294364213012, 0.10234423520159908, 0.04730497530545108, 0.03175476616888773, 0.020358851106720977, 0.014400476738956058, 0.04728635110950563, 0.031458415469387546, 0.08612497622380033, 0.02689756547624711, 0.04889180949248839, 0.014181863225530833, 0.024940909825090785, 0.010622957124724053, 0.05996568070258945, 0.030992840256658383, 0.01763508378644474, 0.18366752337897196, 0.26041552308015525, 0.13452893123030663, 0.21635148441419005, 0.17438358248909935, 0.14709264534758404, 0.12317852466367185, 0.16202462691580877, 0.10974050863296725, 0.19525026669725776, 0.17473145679105073, 0.27818360715173185, 0.135672491742298, 0.1675219225580804, 0.08639427192974836, 0.11316143092699349, 0.12304090079851449, 0.2632395434193313, 0.12804845318896696, 0.16406661656219512, 0.11644994665402919, 0.19123434234643355, 0.2812009718036279, 0.3339564800262451, 17.859195582568645, 154.26241993904114, 127.14630737900734, 130.1273614168167, 119.08108815550804, 106.29678055644035, 52.77780756354332, 57.445758283138275, 95.52962511777878, 97.01352149248123, 47.68006190657616, 79.69602674245834, 53.69399920105934, 20.61094142496586, 0.7493002584669739, 0.40659118560142815, 0.5723102088086307, 0.25809381797444075, 0.42896206956356764, 0.2420288886060007, 12.513171248137951, 17.04586062580347, 4.394260430708528, 22.602652050554752, 66.47671088576317, 101.27685472369194, 107.53557488322258, 111.27069845795631, 108.61608490347862, 104.21434789896011, 99.70909684896469, 104.57617968320847, 100.69290205836296, 90.68631380796432, 99.01474490761757, 95.60774132609367, 85.20878612995148, 78.14529955387115, 74.3716612458229, 73.79101440310478, 76.0472421348095, 82.67527967691422, 83.89254435896873, 83.33525866270065, 74.53468009829521, 75.74148774147034, 73.84732738137245, 81.8411560356617, 85.70058614015579, 91.98943108320236, 92.1685154736042, 84.3728081882, 79.51907023787498, 88.90113919973373, 93.58215361833572, 94.82551530003548, 94.89584192633629, 94.69465032219887, 87.81581103801727, 92.10603922605515, 92.57910624146461, 102.29117229580879, 93.77392172813416, 58.48399557173252, 95.0338277220726, 94.73222270607948, 90.8060909807682, 85.39287105202675, 95.43915957212448, 99.48747754096985, 98.24716329574585, 101.7145000398159, 85.91449946165085, 75.39534151554108, 77.81643480062485, 72.94287711381912, 77.79319524765015, 74.23255071043968, 73.55956122279167, 72.69753947854042, 80.42889341711998, 89.35531362891197, 98.3258418738842, 94.90917161107063, 96.2603411078453, 82.90032640099525, 78.61143574118614, 76.65033057332039, 87.68709674477577, 96.53477758169174, 90.53831174969673, 78.49061742424965, 97.46065109968185, 95.17136514186859, 95.40771245956421, 111.3390339910984, 79.82927799224854, 12.256542518734932, 3.549708011560142, 3.8167645689100027, 2.1339417435228825, 4.919695761054754, 6.331372736021876, 1.9284374895505607, 0.28512907039839774, 0.42144265898969024, 0.45677066955249757, 0.5866839468944818, 10.675232671201229, 31.461850069463253, 67.7185070514679, 54.180308505892754, 93.25022622942924, 85.61986327171326, 39.23029951751232, 30.33865313977003, 21.061435751616955, 45.64880110323429, 61.98667421936989, 76.57022327184677, 97.6568041741848, 97.95738324522972, 109.14202988147736, 32.45455250144005, 0.5475313228089362, 0.27447996370028704, 0.09784864596440457, 0.19488092948449776, 0.1786711032036692, 0.16327991033904254, 0.14631227706559002, 0.0919620122294873, 0.1822676695883274, 0.13395796733675525, 0.1616370477131568, 0.2123946201754734, 0.23740122676827013, 0.0800324633019045, 0.1709110289812088, 0.10320900051738136, 0.12885451462352648, 0.195082942082081, 0.15612910967320204, 0.1255206685164012, 0.12522652570623904, 0.10085773566970602, 0.17137711256509647, 0.11152788967592642, 0.08324556940351613, 0.18457951897289604, 0.1331152586499229, 0.2597305801464245], [0.014447514058701927, 0.03440722794039175, 0.08169812470441684, 0.03533223338308744, 0.030801484899711795, 0.008565579046262428, 0.07550993410404772, 0.0706711906241253, 0.037348778496379964, 0.02356723343837075, 0.04544332383375149, 0.03520996084262151, 0.017056620490620844, 0.03243383500375785, 0.015612870520271827, 0.04402782185934484, 0.04442353871127125, 0.03352177154738456, 0.024773433069640305, 0.08377441641641781, 0.02319833594810916, 0.06765075348084792, 0.054325640376191586, 0.09059761083335616, 71.18978798389435, 103.28962191939354, 109.16172042489052, 95.32408654689789, 55.13990141451359, 38.539485186338425, 21.664501391351223, 103.74744415283203, 84.92965310811996, 22.265315651893616, 62.72426784038544, 37.475732266902924, 12.286097332835197, 0.21889550727792084, 0.019633090050774626, 0.09595918250852264, 0.10848562596947886, 0.14327067387057468, 0.16071443940745667, 0.15653007721994072, 4.672740362584591, 2.204000484198332, 2.9629722330719233, 50.55146902799606, 95.82972541451454, 104.26072061061859, 96.99320018291473, 91.65471464395523, 91.57310262322426, 91.04546293616295, 89.19372349977493, 91.20403602719307, 95.6873470544815, 87.5053296983242, 88.05385306477547, 86.77965983748436, 81.52355387806892, 71.59016489982605, 65.70183366537094, 64.75747033953667, 63.35932396352291, 66.1183825135231, 66.43064975738525, 65.58951929211617, 64.51055958867073, 68.76680999994278, 68.05779084563255, 67.68158063292503, 70.08978500962257, 73.00865158438683, 70.31824395060539, 65.3623978793621, 65.17195209860802, 64.87234577536583, 73.00114318728447, 75.27369484305382, 76.23289257287979, 67.83985733985901, 67.76294186711311, 67.28954046964645, 74.75785732269287, 72.51686677336693, 87.07801222801208, 48.55278007686138, 78.48533570766449, 83.841323107481, 75.84388464689255, 76.63855880498886, 84.69350337982178, 84.43450927734375, 83.46326619386673, 88.24495241045952, 82.29510247707367, 68.64959388971329, 66.03236272931099, 64.98830795288086, 62.91900359094143, 64.31917905807495, 63.55488806962967, 65.25861784815788, 68.30023303627968, 75.28463825583458, 78.22815030813217, 76.67646557092667, 67.96920239925385, 66.01919263601303, 64.99399244785309, 69.40129235386848, 77.30423748493195, 84.3042066693306, 82.5294055044651, 78.22794511914253, 86.15617409348488, 81.12090468406677, 79.6754090487957, 79.16024029254913, 93.12414139509201, 81.10363841056824, 22.458195202052593, 1.0456156614236534, 0.4749999538762495, 0.722755832830444, 0.8076475525740534, 0.2547879656776786, 0.03242048005631659, 0.15313890762627125, 0.024123460134433117, 0.12422974716173485, 0.5967997759580612, 4.547468684613705, 19.101481921970844, 39.47881378233433, 32.07000553607941, 40.90188302099705, 54.194603338837624, 40.763923823833466, 30.54294727742672, 10.808237884193659, 17.372392304241657, 35.370120853185654, 64.36007246375084, 79.88872960209846, 83.08723837137222, 69.69691649079323, 3.6895224591717124, 0.149181330925785, 0.018401846646156628, 0.034169629361713305, 0.027822422489407472, 0.04258779932570178, 0.04438826443220023, 0.04805642209248617, 0.023073282209225, 0.035961726753157564, 0.019625236272986513, 0.0783277946175076, 0.07244131673360243, 0.04318730250815861, 0.06520370705402456, 0.12286375756957568, 0.06129647765192203, 0.00963243674050318, 0.07023438476608135, 0.044459428972913884, 0.017637302807997912, 0.12818842224078253, 0.04958470082783606, 0.01831824927648995, 0.07468894807971083, 0.05914519933867268, 0.08675273667904548, 0.049674964539008215, 0.033500594363431446, 0.004442527069841162, 0.08212907501729205, 0.058321519318269566, 0.08509412567946129, 0.01578202824020991, 0.0630527181783691, 0.031476683434448205, 0.031829574654693715, 0.041755963102332316, 0.06341110871289857, 0.06628917224588804, 0.05520137092389632, 0.06295023500570096, 0.04933014417474624, 0.04768395301653072, 0.005253471836113022, 0.05518266880244482, 0.03862442645186093, 0.11306648797472008, 0.0672143409610726, 0.08366410358576104, 0.07907303704996593, 0.49538660212419927, 92.93231248855591, 120.45573279261589, 125.4975226521492, 108.04106175899506, 72.32396632432938, 63.69968689978123, 40.461767837405205, 77.866470515728, 64.52515080571175, 20.820971354842186, 36.24583326280117, 46.07469744980335, 17.856930904090405, 0.243403390632011, 0.0636516758822836, 0.011741379239538219, 0.08377834237762727, 0.48356665356550366, 0.25825228134635836, 0.4183385818032548, 2.350528696551919, 0.41576944466214627, 4.456989364698529, 55.70056512951851, 99.59744364023209, 106.55027255415916, 97.37738236784935, 96.51086166501045, 94.32536333799362, 96.69631451368332, 94.27541881799698, 94.54652667045593, 97.79197812080383, 87.23169878125191, 91.3631258904934, 93.46595585346222, 83.86846125125885, 76.12869456410408, 68.5567344725132, 68.43153119087219, 66.59784838557243, 67.1547769010067, 69.17642042040825, 68.94714072346687, 68.60162526369095, 70.53941488265991, 71.9250637292862, 71.73252806067467, 73.89726430177689, 76.56040459871292, 74.421476572752, 66.85266271233559, 67.75677859783173, 68.13516229391098, 75.63738092780113, 78.93372684717178, 81.0533595085144, 70.28805077075958, 70.21529987454414, 71.16917788982391, 77.48357266187668, 76.43951028585434, 88.5250885784626, 51.412461027503014, 81.76601886749268, 88.60274881124496, 78.84577676653862, 80.51079422235489, 87.62762233614922, 89.94152337312698, 86.85811802744865, 92.63623997569084, 84.71672773361206, 71.91473588347435, 69.18351843953133, 68.55629369616508, 66.80667757987976, 68.49865078926086, 68.58808279037476, 70.13561055064201, 70.08802950382233, 77.83664971590042, 80.31380519270897, 79.83221143484116, 70.52767351269722, 67.13510155677795, 68.92802774906158, 73.71340736746788, 81.30755066871643, 90.65213084220886, 85.31545400619507, 80.18848031759262, 91.25796273350716, 86.45334094762802, 83.662269115448, 84.74372148513794, 94.57108855247498, 89.81804519891739, 31.664698384702206, 1.9502736115828156, 0.4698748007649556, 0.5291767045855522, 0.9383421333041042, 0.4909957299241796, 0.16455112025141716, 0.05528057663468644, 0.09972128493245691, 0.011981674597336678, 0.3528850752627477, 4.380292855203152, 23.747844099998474, 39.809753224253654, 28.637286834418774, 43.0202579498291, 28.754768930375576, 20.53045604377985, 26.64313293993473, 18.81733126938343, 30.48322208225727, 45.67946545779705, 70.44469356536865, 89.47506800293922, 93.61131325364113, 86.05186969041824, 4.944318439811468, 0.09459330423851497, 0.02875864734960487, 0.021200891860644333, 0.04724302081740461, 0.02083302038954571, 0.008799975257716142, 0.01990200355066918, 0.11235328405746259, 0.09107998455874622, 0.058026638071169145, 0.09127172583248466, 0.002103389610965678, 0.027593427257670555, 0.06129861874796916, 0.08511564796208404, 0.05091402832476888, 0.01606624668056611, 0.06439582735765725, 0.1110141008393839, 0.04785877332324162, 0.023959644022397697, 0.011757564552681288, 0.05835348732944112, 0.0921307246608194, 0.015359118169726571, 0.033593351690797135, 0.031947991737979464, 0.11225705718970858, 0.12083762761903927, 0.258161531528458, 0.26209622039459646, 0.16063917079009116, 0.08850583049934357, 0.13763093040324748, 0.12138523612520657, 0.10623380891047418, 0.12351715180557221, 0.19600902363890782, 0.09947928541805595, 0.16431344003649428, 0.2229712635744363, 0.16369431075872853, 0.1301959465490654, 0.08263212497695349, 0.18541315861511976, 0.18069903657305986, 0.17565813206601888, 0.2547684917226434, 0.15893266157945618, 0.1267194448155351, 1.5015959437005222, 115.40480062365532, 135.1049879193306, 137.2096797823906, 124.65985760092735, 79.48923423886299, 58.76952365040779, 32.30147771537304, 134.57275807857513, 112.22609639167786, 28.869494274258614, 97.21017614006996, 60.37622943520546, 24.65997565537691, 0.5316662241239101, 0.08484788850182667, 0.393557291245088, 0.26511162577662617, 1.0039170552045107, 0.45993117964826524, 1.005511307157576, 21.560424976050854, 7.74127853102982, 3.9661404909566045, 55.379060581326485, 102.58133992552757, 112.21924155950546, 105.78516840934753, 99.81648668646812, 100.1431779563427, 103.44491198658943, 98.86278346180916, 98.59113603830338, 101.45345404744148, 89.68583509325981, 94.67926114797592, 97.0296098291874, 88.69474187493324, 80.7420802116394, 72.63000950217247, 73.41139197349548, 72.1166418492794, 72.58967086672783, 74.61842000484467, 72.1613958477974, 71.11991733312607, 75.0871704518795, 75.75541779398918, 77.0424847304821, 77.44884252548218, 80.58872044086456, 78.30098479986191, 70.38139656186104, 72.20585346221924, 70.8345678448677, 80.27094349265099, 84.20626312494278, 86.69269010424614, 74.08528581261635, 75.11386021971703, 76.05687841773033, 82.62697666883469, 80.73696568608284, 95.08312627673149, 57.83405564725399, 85.8304251730442, 93.21958467364311, 84.10066679120064, 83.95932957530022, 92.15257912874222, 89.99126270413399, 91.19803994894028, 95.7286736369133, 90.06938651204109, 75.20769238471985, 73.59541609883308, 72.84135416150093, 72.24165514111519, 71.95905670523643, 72.20272243022919, 73.2843191921711, 77.08051308989525, 83.9075155556202, 85.70894569158554, 85.14077737927437, 77.18213483691216, 73.18534210324287, 73.35710808634758, 77.14317932724953, 85.12452185153961, 95.78804165124893, 88.16546067595482, 81.39199733734131, 95.79365774989128, 90.59460192918777, 89.0375442802906, 85.82236960530281, 100.43489590287209, 92.88258075714111, 28.18122960627079, 1.64650556165725, 2.0856012124568224, 3.084336295723915, 3.1139307701960206, 1.9459930225275457, 0.29988946742378175, 0.2110032268683426, 0.5118666146881878, 0.3535135556012392, 1.0885611944831908, 9.194799810647964, 35.54501786828041, 62.73237660527229, 46.21590927243233, 60.37784814834595, 73.40636864304543, 56.146060824394226, 43.82594391703606, 19.659092500805855, 28.983794040977955, 51.82741016149521, 86.78709223866463, 104.2611537873745, 101.54106974601746, 95.65371125936508, 7.033264897763729, 0.3058492694981396, 0.08877726359060034, 0.12859838461736217, 0.17317426769295707, 0.18568855477496982, 0.22554552153451368, 0.14453866286203265, 0.21087228233227506, 0.1905465792515315, 0.12371183940558694, 0.26887312706094235, 0.12000835180515423, 0.13859143276931718, 0.1958097718306817, 0.2831483376212418, 0.21327624708646908, 0.1397396094398573, 0.13007945904973894, 0.23204158467706293, 0.1353767458931543, 0.22204724518815055, 0.1378830082830973, 0.19349093141499907, 0.2631020382978022, 0.16568473598454148, 0.21995787683408707, 0.12149514819611795], [0.01291553942792234, 0.01892981606943067, 0.0308542460334138, 0.04752363056468312, 0.018751182979031, 0.03721853900060523, 0.001715606897505495, 0.015214385457511526, 0.04355916302301921, 0.03184387955116108, 0.06741866905940697, 0.05075553526694421, 0.05649912745866459, 0.03638008653069846, 0.007971142877067905, 0.10657324499334209, 0.009577012224326609, 0.09878118420601822, 0.035337962763151154, 0.054817179625388235, 0.09605700499378145, 0.08269945261417888, 0.2873314678436145, 39.02435056865215, 109.91384446620941, 111.69135108590126, 100.61654135584831, 77.83163398504257, 49.84514772891998, 28.393805399537086, 65.3885480761528, 103.3799658715725, 109.87466096878052, 76.49359658360481, 49.67610239982605, 10.266339462250471, 0.41485301102511585, 0.08216538088163361, 0.13175663858419284, 0.02195594734075712, 0.15971948654623702, 0.2687525429064408, 0.06849881305242889, 0.5527810973580927, 2.57705710362643, 2.6827546069398522, 19.50578212738037, 86.59196510910988, 100.1659007370472, 93.5450904071331, 90.81548407673836, 85.60239940881729, 85.74694365262985, 81.82236984372139, 85.67037776112556, 84.75176185369492, 91.50535985827446, 85.7956874370575, 89.54170122742653, 84.75410252809525, 79.71719920635223, 72.36029997467995, 68.73798474669456, 66.58473908901215, 68.05267632007599, 62.55248665809631, 64.69600483775139, 64.08681392669678, 64.33410465717316, 63.8584765791893, 66.0917155444622, 65.002321600914, 66.44310548901558, 64.75538045167923, 65.98602801561356, 65.24259030818939, 65.79433590173721, 61.659682765603065, 63.85852977633476, 62.127141281962395, 63.42181921005249, 61.68541118502617, 68.87043043971062, 71.16862311959267, 84.87618997693062, 77.33161121606827, 94.2473155260086, 40.20975396037102, 66.14070251584053, 87.05905124545097, 80.99282875657082, 88.61148834228516, 82.22290635108948, 84.92555692791939, 79.32539463043213, 85.94888761639595, 77.33907401561737, 68.23160111904144, 65.53093403577805, 67.18315377831459, 61.817689687013626, 65.27899995446205, 66.27361938357353, 68.20093676447868, 65.80663964152336, 66.0548347234726, 60.893153697252274, 61.443854346871376, 61.367748230695724, 63.40352699160576, 68.32227185368538, 77.88426876068115, 77.773177921772, 87.11145803332329, 78.22976142168045, 77.96781107783318, 87.68786430358887, 81.45410120487213, 68.73466372489929, 80.92476680874825, 86.59128874540329, 90.06877854466438, 65.8327366411686, 23.657357655465603, 0.8250410598702729, 0.4625288746319711, 0.15851625736104324, 0.1628723822068423, 0.08020247449167073, 0.08881690911948681, 0.03251843612815719, 0.02463582033669809, 0.09118268295424059, 0.26826750487089157, 0.38160230149514973, 10.385288279503584, 34.42363724112511, 26.37727450579405, 71.46547839045525, 107.50560969114304, 73.2320111989975, 66.9549760222435, 17.927848398685455, 19.478980265557766, 47.53102250397205, 71.93290650844574, 69.41266134381294, 92.30071038007736, 36.280840784311295, 0.4761742689879611, 0.036304728855611756, 0.04573551479552407, 0.03522602462908253, 0.09073527922737412, 0.06304329290287569, 0.05069054910563864, 0.03832204580248799, 0.026239749895466957, 0.00260149246059882, 0.026618378797138575, 0.023518683992733713, 0.05195157304115128, 0.08062189182965085, 0.042111192087759264, 0.038754157576477155, 0.014585603621526388, 0.03942756382457446, 0.04835949293919839, 0.00563617744774092, 0.03407035597774666, 0.053076353506185114, 0.02252983900689287, 0.0288886215275852, 0.033893969739438035, 0.03746389673324302, 0.038211514038266614, 0.06935648343642242, 0.061573354396387, 0.0587187130440725, 0.03144366528431419, 0.023308910385821946, 0.05945289376541041, 0.010331277317163767, 0.04204407596262172, 0.040650960872881114, 0.023322866472881287, 0.07328567298827693, 0.025239828355552163, 0.039774350880179554, 0.042905004374915734, 0.04460325348190963, 0.09424324060091749, 0.04414222021296155, 0.13198122731409967, 0.05979167304758448, 0.07190634700236842, 0.07091129024047405, 0.24410681304289028, 0.22416707128286362, 55.678849294781685, 128.36949974298477, 124.07469660043716, 111.88297480344772, 100.00171914696693, 73.2849195599556, 40.69951348006725, 41.23485155403614, 91.36766284704208, 107.22181051969528, 37.47858591377735, 59.528388530015945, 15.107085909694433, 0.41974038002081215, 0.11595917923841625, 0.21487174584763125, 0.07034083842881955, 0.14777648990275338, 0.29888326360378414, 0.16150813666172326, 0.8385144837666303, 2.151496564038098, 1.598870367743075, 24.950487166643143, 90.30058890581131, 102.82817468047142, 95.78668132424355, 96.37056559324265, 88.95472392439842, 89.38516482710838, 83.17789390683174, 89.88687470555305, 87.34534308314323, 94.8414820432663, 89.63451504707336, 90.80756530165672, 87.17504382133484, 82.53309890627861, 77.26976573467255, 72.21847638487816, 70.22167593240738, 72.78617352247238, 66.34355083107948, 67.95423120260239, 65.19204542040825, 67.76640728116035, 66.06436461210251, 69.42604422569275, 66.49618104100227, 71.15530103445053, 67.8931836783886, 68.26563209295273, 68.71447160840034, 69.38577398657799, 64.57182750105858, 66.2221397459507, 65.24341866374016, 66.58327996730804, 64.13653805851936, 72.86366656422615, 74.83570754528046, 89.8326364159584, 82.9554158449173, 101.74983814358711, 43.156674429774284, 67.47421815991402, 90.45314311981201, 83.34421098232269, 91.21621057391167, 87.62433931231499, 86.08884170651436, 81.23671486973763, 88.5329769551754, 80.58921441435814, 72.41244837641716, 69.7394286096096, 69.5656107366085, 66.439518481493, 69.19475063681602, 70.848877876997, 70.07431223988533, 68.58370542526245, 69.83368635177612, 64.30743008852005, 65.13624161481857, 65.3647917509079, 67.46704414486885, 71.38198927044868, 80.20505502820015, 81.7434024810791, 91.17796942591667, 78.40026587247849, 80.7776691019535, 92.385985404253, 85.8599191904068, 73.22080180048943, 84.69099551439285, 90.98759204149246, 91.09709456562996, 74.06330779194832, 32.91866719722748, 1.8940243986435235, 0.10353866251534782, 0.37653652019798756, 0.4844128800323233, 0.23289777076570317, 0.11256144163780846, 0.01778274519892875, 0.04675932235841174, 0.10676449644961394, 0.22965914220549166, 0.30407948477659374, 11.915379725396633, 40.79246409237385, 26.94514263421297, 67.18151986598969, 88.19004535675049, 43.07352349162102, 41.76022656261921, 26.12381860613823, 34.825435280799866, 59.55025635659695, 80.53211107850075, 79.26555544137955, 105.10121271014214, 48.09420548379421, 0.47964401717763394, 0.050974535624845885, 0.07854782656067982, 0.059059707637061365, 0.017085195031540934, 0.029428893903968856, 0.04499716320424341, 0.03204303859092761, 0.017631052069191355, 0.034963293219334446, 0.07044795260298997, 0.03755241268663667, 0.025173613939841744, 0.055239877256099135, 0.030900702622602694, 0.05172771903744433, 0.03965061259805225, 0.04122461876249872, 0.05611730732198339, 0.01913894957397133, 0.02939667356258724, 0.06629939161939546, 0.0198081812413875, 0.048471330883330666, 0.02857892515748972, 0.006212187945493497, 0.0340544331993442, 0.16031552018830553, 0.18240680743474513, 0.18558808282250538, 0.0798529526218772, 0.18141739099519327, 0.15883328800555319, 0.19369332992937416, 0.23677449789829552, 0.10927848459687084, 0.14157418365357444, 0.1612491864943877, 0.11505948103149422, 0.17112861183704808, 0.15901499544270337, 0.14448381814872846, 0.21876374637940899, 0.16265074722468853, 0.17187481164000928, 0.20305449870647863, 0.1314877436379902, 0.228375286096707, 0.2658568014157936, 0.35704243811778724, 71.66606202721596, 145.0534924864769, 135.0705921649933, 129.41841065883636, 105.02017825841904, 73.90975043177605, 42.22873382270336, 91.44086211919785, 125.92622324824333, 129.56137418746948, 111.29653707146645, 73.03860917687416, 21.25734753906727, 0.9507560078054667, 0.14933223923435435, 0.5010226496960968, 0.1449160004267469, 0.3039740107487887, 0.5744697398040444, 1.1566168488934636, 1.8561881664209068, 11.706262696534395, 8.601572792977095, 23.299439661204815, 94.3903398513794, 105.51629483699799, 101.22299641370773, 99.38132643699646, 95.06134584546089, 94.25634384155273, 90.67809864878654, 95.29126390814781, 93.38616773486137, 98.43579277396202, 91.1887988448143, 91.80053561925888, 92.34411925077438, 87.40984842181206, 80.58542221784592, 76.41824662685394, 75.50343051552773, 77.80806764960289, 69.19228836894035, 71.25015154480934, 70.39835125207901, 71.0658386349678, 70.37571966648102, 72.8910630941391, 70.40370136499405, 73.9468364417553, 72.04490929841995, 71.02432206273079, 72.79097646474838, 71.99868097901344, 69.745082706213, 71.96882978081703, 68.63447830080986, 70.48902958631516, 66.25122338533401, 76.93899348378181, 80.5141532421112, 91.89986988902092, 85.81505119800568, 102.87996590137482, 49.032401740550995, 74.54293325543404, 95.5132631957531, 89.1756896674633, 95.48561587929726, 91.91766813397408, 87.79706284403801, 83.08941945433617, 94.94349136948586, 86.64271518588066, 75.84970593452454, 73.35401505231857, 74.75629180669785, 70.5452361702919, 73.78694102168083, 74.94938224554062, 74.78390872478485, 71.97093486785889, 75.4980880022049, 67.9165144264698, 68.18958297371864, 68.84149879217148, 71.19421854615211, 76.63377866148949, 86.18627607822418, 85.07861271500587, 95.44471487402916, 80.90627700090408, 82.93536812067032, 97.51098319888115, 88.88714835047722, 76.9846062362194, 90.99184781312943, 96.65808856487274, 95.40102481842041, 83.11338856816292, 32.662918120622635, 1.1568038701079786, 1.0868385806679726, 1.6947633284144104, 0.7661657128483057, 0.5009294953197241, 0.3976938145933673, 0.17830175114795566, 0.19831627170788124, 0.25310884171631187, 0.5725275096483529, 1.2974775466136634, 20.23548737168312, 56.56424358487129, 39.606684520840645, 96.18711903691292, 140.5956780910492, 98.51884111762047, 90.88916972279549, 27.78423260897398, 32.81773701310158, 68.93973872065544, 93.08058053255081, 91.9924633204937, 116.97847098112106, 54.072356298565865, 0.8319787157233804, 0.18907742371084169, 0.2353575301822275, 0.1506032858742401, 0.1431940248585306, 0.13931268156738952, 0.13496538827894256, 0.11230701114982367, 0.22630717285210267, 0.09953533241059631, 0.19270694145234302, 0.1283762152888812, 0.09941005046130158, 0.18832353525795043, 0.17307281610555947, 0.22818237222963944, 0.052364982693688944, 0.11030527559341863, 0.16053163359174505, 0.13074587797746062, 0.1129145480808802, 0.18200638907728717, 0.3048602835042402, 0.12638519634492695, 0.13378148461924866, 0.10949550342047587, 0.16992284450680017], [0.051808650241582654, 0.010460908251843648, 0.05997241198201664, 0.03749547882762272, 0.11642822399153374, 0.0747036277607549, 0.07655092980712652, 0.07685201911954209, 0.06518329057144001, 0.051068087050225586, 0.03374629348400049, 0.01674458821071312, 0.02830888730386505, 0.0222725493949838, 0.07543119965703227, 0.03218655510863755, 0.19388716405956075, 0.036298999475548044, 0.16612864419585094, 0.0432402658771025, 0.2338549483101815, 0.3180510678794235, 7.524178605526686, 100.16502678394318, 108.62647354602814, 103.57957676053047, 88.5226871073246, 48.09688054025173, 30.392551347613335, 33.88881973922253, 79.68093395233154, 72.26339757442474, 39.08159449696541, 44.50025953352451, 9.852760154753923, 0.70996358175762, 0.07009661247138865, 0.2979456342291087, 0.06813255575252697, 0.11281721541308798, 0.025576036096026655, 0.04196500754915178, 0.09704756434075534, 0.3263838426209986, 0.4952330666128546, 1.3968672696501017, 50.12725219130516, 102.9277141392231, 94.65558841824532, 89.49769198894501, 79.91186276078224, 76.36653900146484, 72.21022322773933, 76.12959131598473, 76.0143207013607, 87.93205440044403, 90.08383333683014, 92.688859552145, 87.14599817991257, 85.71824759244919, 81.99415862560272, 75.038031488657, 70.7482972741127, 69.9913626909256, 69.74184527993202, 67.55554899573326, 62.191627621650696, 63.209467604756355, 64.68300193548203, 64.73371401429176, 66.69382363557816, 65.41745692491531, 66.55968323349953, 66.28498077392578, 67.35143154859543, 63.27571325004101, 64.17176976799965, 62.68740601837635, 63.58297996222973, 61.585772931575775, 65.47126203775406, 61.839314326643944, 65.85131764411926, 71.53202041983604, 86.83120787143707, 76.5445214509964, 97.04423144459724, 42.567242458462715, 50.743700712919235, 91.02559000253677, 71.2405076622963, 79.26369354128838, 78.05310130119324, 85.2662542462349, 77.56649941205978, 83.91028180718422, 77.14619636535645, 68.02127480506897, 61.615392342209816, 66.30071952939034, 63.770214915275574, 65.11344283819199, 60.54223112761974, 67.70491898059845, 63.35278831422329, 64.56607460975647, 61.734698340296745, 64.17791023850441, 60.94150610268116, 69.96193706989288, 74.19008418917656, 80.33667236566544, 82.21347525715828, 82.72651612758636, 72.03895881772041, 76.08190387487411, 83.39089527726173, 83.35868060588837, 71.41775295138359, 65.09822085499763, 78.05498600006104, 87.70783603191376, 76.9961728155613, 51.23450517654419, 25.303847305476665, 2.9791581770405173, 0.13721246301429346, 0.41654335625935346, 0.12463117484003305, 0.028201170134707354, 0.1349632508936338, 0.1039584657701198, 0.17513564525870606, 0.2000095261610113, 0.028909008324262686, 0.20463073131395504, 3.763385033234954, 35.13917304575443, 28.890463449060917, 35.4040302336216, 130.05074232816696, 144.69880431890488, 74.06336858868599, 14.339671488851309, 34.00823973119259, 57.2049880027771, 82.46095597743988, 76.22894078493118, 87.50675842165947, 7.126852925866842, 0.23748348641674966, 0.030306433436635416, 0.09653462897404097, 0.009431452945136698, 0.010934839119727258, 0.026031293600681238, 0.04025526999612339, 0.031232895344146527, 0.03207921086868737, 0.013165185846446548, 0.005868408443348017, 0.08039969281526282, 0.09441335569135845, 0.067231425200589, 0.021279338725435082, 0.031117331818677485, 0.03330894585815258, 0.06681134735117666, 0.05911181382543873, 0.03191641335433815, 0.014071197874727659, 0.019276022394478787, 0.01463123920984799, 0.05250193862593733, 0.048958109255181625, 0.06212569038325455, 0.049495862040203065, 0.030888342153048143, 0.05155021957762074, 0.0044877308209834155, 0.026720550267782528, 0.031568019549013115, 0.021047694026492536, 0.0647326436592266, 0.07887367391958833, 0.03741049178643152, 0.13182015158236027, 0.04536569147603586, 0.047767155192559585, 0.08767327439272776, 0.05566708343394566, 0.027503126439114567, 0.13746746495598927, 0.061105111162760295, 0.16837782663060352, 0.12825039157178253, 0.128299729549326, 0.32118750270456076, 12.446533273905516, 123.79147499799728, 119.22282814979553, 115.35872429609299, 96.68542429804802, 67.09499850869179, 51.23490035533905, 38.64812895655632, 43.35088200867176, 83.39337274432182, 51.7437956482172, 52.671721056103706, 14.658143799751997, 0.1042038643208798, 0.05325788653863128, 0.18214028736110777, 0.05814281015773304, 0.06277174106799066, 0.10898824548348784, 0.024095924600260332, 0.05927857811911963, 1.0871084849350154, 1.362932596821338, 2.2654928220435977, 53.63715045154095, 106.25955775380135, 96.63965955376625, 92.8734764456749, 81.22903928160667, 78.31517323851585, 76.57495781779289, 78.19955304265022, 79.40817698836327, 87.28527590632439, 91.665840446949, 92.81571954488754, 88.61895874142647, 89.73866745829582, 85.58059617877007, 79.06765446066856, 74.04598832130432, 74.3208883702755, 72.56733566522598, 68.1230029463768, 63.81872311234474, 65.49302726984024, 67.59464889764786, 66.75695344805717, 67.99533739686012, 69.27193969488144, 71.21773928403854, 68.14271628856659, 71.69864147901535, 64.92365822196007, 66.2817357480526, 64.48491096496582, 68.99066358804703, 64.23970252275467, 69.65074896812439, 64.85198646783829, 69.7094102203846, 75.06637036800385, 88.48662704229355, 82.95417711138725, 98.04403379559517, 43.98037143051624, 52.10710555315018, 97.740498483181, 76.024010181427, 83.46382856369019, 82.31824323534966, 86.78617268800735, 78.37272495031357, 87.93095245957375, 80.23892641067505, 70.037150233984, 64.07428979873657, 69.16440546512604, 66.60726428031921, 67.19217449426651, 66.34823977947235, 71.75455927848816, 67.00998187065125, 68.47832188010216, 67.62905985116959, 66.55231922864914, 65.58813616633415, 74.81135845184326, 80.96577420830727, 87.84995600581169, 87.38641127943993, 84.21089887619019, 70.9271688759327, 77.74858564138412, 86.79643213748932, 86.63123980164528, 75.0467786192894, 67.54053980112076, 82.11164072155952, 90.26108622550964, 82.02603131532669, 58.668604865670204, 32.523940578103065, 6.200051307678223, 1.0299543268047273, 0.21002881665481254, 0.18866096012061462, 0.2004724185098894, 0.05259666264464613, 0.12036210391670465, 0.08135613563354127, 0.1530052616726607, 0.014892344388499623, 0.38478667906019837, 5.137968398630619, 35.776319056749344, 25.921150781214237, 35.09378828108311, 104.13440018892288, 120.21848112344742, 50.837692469358444, 20.639050416648388, 43.28909732401371, 62.874580174684525, 90.70579156279564, 86.62123113870621, 105.99270567297935, 10.639719776809216, 0.35270838474389166, 0.1589454710483551, 0.03764050932659302, 0.0468530370562803, 0.07312310553970747, 0.08100492166704498, 0.08075348203419708, 0.04513539191975724, 0.036337041965452954, 0.024133911429089494, 0.048712376737967134, 0.04255734529579058, 0.07867963198805228, 0.03009368752827868, 0.03952839942940045, 0.030931353321648203, 0.0060548772216861835, 0.07717224099906161, 0.035429117051535286, 0.04255009822372813, 0.025541789691487793, 0.04896864775219001, 0.053565566122415476, 0.020914458109473344, 0.042769187639351, 0.032276084093609825, 0.12719418184133247, 0.19002326123882085, 0.31931093777529895, 0.06618447747314349, 0.2666608738945797, 0.17909801623318344, 0.19113447895506397, 0.19515218446031213, 0.19917005323804915, 0.14019171096151695, 0.3000047674868256, 0.15254674799507484, 0.1413293046061881, 0.1725195301696658, 0.2006012256606482, 0.16872577514732257, 0.2215084311319515, 0.18325916404137388, 0.3197298356099054, 0.35631575679872185, 0.5828825477510691, 0.7799917459487915, 19.075289927423, 141.1281207203865, 135.70983946323395, 132.3929214477539, 114.39530119299889, 69.6553011238575, 46.04500204324722, 52.158588990569115, 115.67749679088593, 94.21744912862778, 58.792311027646065, 68.41234222054482, 18.944966420531273, 1.6895827814005315, 0.15551213262369856, 0.6867780571337789, 0.10122917316039093, 0.5974671745207161, 0.352425953024067, 0.21763173368526623, 0.4812032694462687, 2.2814885387197137, 2.5488790031522512, 1.95816436316818, 55.361722111701965, 111.93362608551979, 100.12736320495605, 99.03121322393417, 85.68461179733276, 83.32132861018181, 80.02594023942947, 85.02376645803452, 81.63219764828682, 94.96417745947838, 96.54851004481316, 98.07461455464363, 89.18010503053665, 95.2140748500824, 88.55491697788239, 84.57863554358482, 77.60331183671951, 79.7826012969017, 76.65138691663742, 73.39692234992981, 68.04826095700264, 69.69698488712311, 69.50579434633255, 69.77893888950348, 70.4699394106865, 74.0848146378994, 71.16251304745674, 72.9311053454876, 74.33209776878357, 69.91725146770477, 70.11933982372284, 69.05750960111618, 71.1054477095604, 69.91405203938484, 73.73864561319351, 71.10696762800217, 71.71485900878906, 78.72310414910316, 92.35291957855225, 88.34740251302719, 100.29535979032516, 49.429681822657585, 58.70468012988567, 101.05044767260551, 81.45704984664917, 86.77170306444168, 85.95197305083275, 91.61002144217491, 80.86792945861816, 91.07530653476715, 84.08889502286911, 72.38883644342422, 66.27551928162575, 72.79679015278816, 70.43031513690948, 71.90403565764427, 69.24203529953957, 75.66842526197433, 70.63165873289108, 72.70913645625114, 71.71055004000664, 72.2033379971981, 68.8131295144558, 79.17944446206093, 83.10861602425575, 90.39058327674866, 90.57713806629181, 87.47917950153351, 72.01766476035118, 80.71209982037544, 90.10033205151558, 91.24002769589424, 79.00445625185966, 71.78710073232651, 84.90211218595505, 95.68920895457268, 87.54808500409126, 68.24181497097015, 33.84089671075344, 5.587316136807203, 2.7926033874973655, 1.1360581708140671, 0.3751601034309715, 0.5412955605424941, 0.282937953597866, 0.3763139055809006, 0.2956787886796519, 0.4971625318285078, 0.1570131559856236, 0.4237997200107202, 7.858825698494911, 62.30711482465267, 38.949198201298714, 41.99523255228996, 144.13264989852905, 155.09860306978226, 93.20795729756355, 21.13275222480297, 49.6346390247345, 78.2266303896904, 106.91214233636856, 97.07589894533157, 116.9604903459549, 12.773756515234709, 0.45001118851359934, 0.35258435702417046, 0.21800724556669593, 0.10627442665281706, 0.13187158241635188, 0.1712193468119949, 0.12971445597941056, 0.10916662067756988, 0.12253559470991604, 0.1640379845048301, 0.08587430100305937, 0.17386615712894127, 0.22894145571626723, 0.14072783844312653, 0.1388167339609936, 0.10491306806216016, 0.08833623491227627, 0.18159464554628357, 0.08670906128827482, 0.1995813217945397, 0.09208197297994047, 0.2312901898403652, 0.14119114639470354, 0.10450596295413561, 0.1513571001123637, 0.23357094323728234], [0.025020456923812162, 0.060943990902160294, 0.03283539626863785, 0.05369215054088272, 0.008279510802822188, 0.09837543722824194, 0.025021822475537192, 0.020446114685910288, 0.0769780357950367, 0.02191471547121182, 0.04094417228770908, 0.0384047952684341, 0.10038219712441787, 0.03751872660359368, 0.040087800662149675, 0.06552742444910109, 0.08124641652102582, 0.04878242434642743, 0.0905860036436934, 0.047067491759662516, 0.05481194006279111, 0.08812858941382729, 46.65502890944481, 118.79545748233795, 101.26257508993149, 94.23464700579643, 64.98331502079964, 42.710566967725754, 36.19464620947838, 53.54011885821819, 54.118003249168396, 36.79225534200668, 40.07358826696873, 13.914081025868654, 0.3053097875090316, 0.18986853829119354, 0.15246319700963795, 0.19741184602025896, 0.11233854500460438, 0.02387633423495572, 0.049788780306698754, 0.0877427394152619, 0.1730763041996397, 0.19737548078410327, 0.5685542291030288, 13.765609692782164, 78.98342058062553, 98.74633491039276, 91.62686213850975, 81.5100722014904, 74.43281516432762, 73.02910968661308, 69.10034850239754, 68.82937744259834, 70.69691643118858, 81.7445196211338, 87.82902672886848, 88.5127392411232, 83.48620176315308, 84.03627544641495, 76.11643642187119, 75.79182744026184, 74.7637090086937, 76.70600518584251, 74.80280131101608, 70.85988208651543, 65.99501833319664, 61.64658106863499, 62.76040390133858, 62.70971842110157, 62.803596183657646, 63.76104220747948, 65.0326743721962, 63.22761923074722, 68.73022556304932, 65.47330632805824, 66.47612571716309, 62.60439187288284, 64.70580071210861, 65.1210044324398, 62.81777322292328, 62.48997621238232, 65.18361747264862, 59.43298324942589, 72.07741275429726, 72.58520990610123, 87.64472901821136, 60.92796362936497, 44.7760259360075, 90.52189663052559, 71.0001553595066, 82.7278384566307, 78.05206015706062, 79.57359731197357, 78.29042136669159, 80.86302772164345, 78.82943764328957, 73.73182117938995, 60.33104985952377, 62.65764221549034, 63.15395638346672, 65.23759737610817, 63.748065903782845, 68.27608913183212, 66.19987294077873, 63.96048590540886, 60.98029442131519, 62.14305482804775, 66.15013360977173, 80.63378602266312, 81.64644688367844, 80.97148910164833, 76.64986699819565, 75.30505076050758, 73.50331664085388, 73.98476600646973, 80.1805691421032, 81.7789077758789, 77.29472279548645, 65.5017364025116, 67.65346214175224, 80.85906073451042, 85.28476685285568, 84.6841710805893, 73.22441920638084, 30.838212333619595, 1.9412575266323984, 0.4154527554055676, 0.5856414965819567, 0.038535865969606675, 0.12284144861041568, 0.01207771128974855, 0.09368942031869665, 0.03897201131621841, 0.10750055851531215, 0.16258549760095775, 0.2678064233623445, 5.895890928804874, 38.33817958831787, 75.1374189555645, 116.53369724750519, 95.02571895718575, 133.44943195581436, 41.678432151675224, 38.588783740997314, 50.887078419327736, 63.55973280966282, 70.49319416284561, 87.50058755278587, 45.13550564646721, 0.38379448698833585, 0.013670032731170068, 0.05000244462280534, 0.020137334868195467, 0.10213441521045752, 0.0801491882884875, 0.07861597798182629, 0.04170404245087411, 0.035044369142269716, 0.05834230687469244, 0.01551687928440515, 0.05018482741434127, 0.007915057849459117, 0.03235846248571761, 0.0723213262972422, 0.03657385386759415, 0.016864619465195574, 0.05478028746438213, 0.06619468942517415, 0.02165535155654652, 0.041850026609608904, 0.017570342533872463, 0.03116966807283461, 0.03044332072022371, 0.01654150320973713, 0.01242497888597427, 0.0033399161793568055, 0.005401508033173741, 0.03032918211829383, 0.02582842753326986, 0.04152459114266094, 0.025470549080637284, 0.060967012323089875, 0.017464644006395247, 0.03873401939927135, 0.026372612883278634, 0.05787448666524142, 0.005773041075372021, 0.06424615843570791, 0.039026225203997456, 0.05571382018388249, 0.08205338337575085, 0.01866620521468576, 0.10030075383838266, 0.13339240627828985, 0.027079174578830134, 0.19214872765587643, 0.07827734341844916, 64.07549813389778, 133.64928603172302, 115.36839097738266, 102.45313480496407, 84.31560605764389, 59.362835213541985, 48.211660981178284, 38.716339096426964, 67.66289323568344, 52.63743169605732, 37.38826856017113, 20.054879263043404, 0.3344171162461862, 0.05078325077192858, 0.11646913859294727, 0.07543445768533275, 0.20167771086562425, 0.0993037452280987, 0.09794545170734636, 0.07309966851607896, 0.16066306794527918, 0.7294714380986989, 1.0720260255038738, 17.13781949132681, 84.4631977379322, 101.95907011628151, 96.4028562605381, 85.52631229162216, 78.68936195969582, 74.81879085302353, 71.40622437000275, 73.44179794192314, 74.08598497509956, 85.70895329117775, 91.90547838807106, 91.33587375283241, 85.8727777004242, 86.7519973218441, 83.47226411104202, 79.91234913468361, 79.28393125534058, 82.03980937600136, 78.38103890419006, 77.24577382206917, 69.32281896471977, 64.81200501322746, 66.33408933877945, 66.49232044816017, 65.94464063644409, 67.17319071292877, 68.49220633506775, 66.84322401881218, 71.46948337554932, 69.81581211090088, 69.84068557620049, 65.33630087971687, 68.07090014219284, 67.12619483470917, 63.95955875515938, 66.01960301399231, 68.64590048789978, 63.920762836933136, 75.5129300057888, 77.48908996582031, 91.8754144012928, 64.42551255226135, 46.12175032496452, 90.85998728871346, 74.10664066672325, 83.99083748459816, 80.35097479820251, 82.54400432109833, 79.88913238048553, 83.00615072250366, 81.48938611149788, 75.75801685452461, 63.91237288713455, 65.95506727695465, 65.55922731757164, 68.84627133607864, 66.08242884278297, 70.37283942103386, 67.95856297016144, 67.32615530490875, 63.94198089838028, 65.51035434007645, 68.61824557185173, 85.14323204755783, 84.88925367593765, 84.51653927564621, 77.50728338956833, 75.73698878288269, 75.37293791770935, 77.19483375549316, 82.88247495889664, 86.06492578983307, 79.52204927802086, 69.65383440256119, 71.31355494260788, 82.36439555883408, 86.96292400360107, 88.0202704668045, 79.937032610178, 40.5726382881403, 2.634227885864675, 0.6197888392489403, 1.0466420813463628, 0.023947313238750212, 0.2851537097012624, 0.060515979494084604, 0.32541023392695934, 0.03145163595036138, 0.14394259953405708, 0.16465131018776447, 0.31616384570952505, 6.550227692350745, 32.898710668087006, 56.21894471347332, 122.4925222992897, 90.30441910028458, 102.1832200884819, 23.37021466344595, 45.476829931139946, 58.38892087340355, 72.42195546627045, 78.4740199148655, 100.10366007685661, 59.68800276517868, 0.2837013266980648, 0.13017440942348912, 0.06714987801387906, 0.02960066954983631, 0.050119180741603486, 0.033456054370617494, 0.01189387017802801, 0.0704270982532762, 0.04410216279211454, 0.08265021853731014, 0.08691373077454045, 0.0677679460204672, 0.07944083801703528, 0.01239680696016876, 0.04807070843526162, 0.04628103786672, 0.028517441933217924, 0.058201632782584056, 0.034924597639474086, 0.05239959275058936, 0.02313986769877374, 0.012055139795847936, 0.051534508311306126, 0.050761695092660375, 0.01878114719147561, 0.03159236570354551, 0.15010520088253543, 0.11104063261882402, 0.1376041685580276, 0.130944580596406, 0.09754806131240912, 0.13373164198128507, 0.11409360551624559, 0.1814076688606292, 0.18359424371737987, 0.1101945545815397, 0.22747826704289764, 0.12150815804488957, 0.1634735960396938, 0.11580841193790548, 0.07777453836752102, 0.17918707395438105, 0.13879031350370497, 0.20693262107670307, 0.1889149082126096, 0.12128908347222023, 0.23598351690452546, 0.14054906991077587, 75.7021826505661, 152.41885006427765, 126.1922013759613, 121.32036879658699, 88.63580703735352, 61.25889167189598, 51.68092042207718, 77.06517711281776, 72.84903734922409, 54.49040226638317, 67.82737120985985, 26.10156510025263, 1.3850843394175172, 0.36400782060809433, 0.39220702776219696, 0.5233840935397893, 0.3276668081525713, 0.18209773261332884, 0.41963460913393646, 0.431699703913182, 0.6978479318786412, 2.5768630765378475, 2.7289900509640574, 17.772645726799965, 88.44356015324593, 107.20226436853409, 104.32898014783859, 89.07910645008087, 82.13025972247124, 80.0125041604042, 75.6217485666275, 75.0238886475563, 79.36424374580383, 87.44987547397614, 96.5128755569458, 95.34952998161316, 86.82956635951996, 91.01904675364494, 86.14648461341858, 83.68436112999916, 83.64513203501701, 85.35435631871223, 82.25977957248688, 79.90910410881042, 72.11215049028397, 70.11239379644394, 70.07724568247795, 69.48447749018669, 70.0557616353035, 71.05621755123138, 71.6536670923233, 70.81547006964684, 76.00275412201881, 72.09869921207428, 73.90103369951248, 69.85005587339401, 72.19239458441734, 70.85140854120255, 68.67639005184174, 70.06111174821854, 72.51517206430435, 66.54149740934372, 79.09359186887741, 81.19880810379982, 96.727085262537, 70.23778706789017, 50.84585063159466, 95.67973986268044, 79.51137945055962, 88.6688880622387, 86.59647926688194, 84.49562519788742, 84.5155893266201, 86.30661562085152, 87.18594923615456, 79.59472417831421, 67.75486350059509, 66.94690525531769, 70.3693588078022, 71.09432950615883, 68.86658504605293, 73.95255133509636, 72.4658203125, 71.53638258576393, 68.00729915499687, 68.64283785223961, 74.19076055288315, 89.53734666109085, 89.99704599380493, 86.60722509026527, 82.76069909334183, 78.56481224298477, 77.86783084273338, 77.64852181077003, 85.22590801119804, 90.03161653876305, 83.18735539913177, 74.64618131518364, 75.62968254089355, 87.94349938631058, 95.66455587744713, 93.85650649666786, 84.76299405097961, 42.27111294865608, 3.401993550360203, 1.6555354208685458, 2.590778167359531, 0.19413287431234494, 0.5114431749098003, 0.1466379759949632, 0.4363336740061641, 0.1749515629489906, 0.20343832264188677, 0.3832977230194956, 0.3241044102469459, 9.779418390244246, 74.61889117956161, 85.03142684698105, 116.57112523913383, 97.84319177269936, 148.41979265213013, 59.629892483353615, 53.637063056230545, 69.68424037098885, 85.92739596962929, 93.18725600838661, 113.36600482463837, 67.71354451775551, 0.6546264386270195, 0.2182078777696006, 0.1696455929777585, 0.11850435985252261, 0.28285937500186265, 0.17444679862819612, 0.1861405820818618, 0.12765057297656313, 0.10062545086839236, 0.16472935443744063, 0.1622761704493314, 0.13580481667304412, 0.1844964429619722, 0.11254900324274786, 0.2347547875251621, 0.15678644471336156, 0.12928383221151307, 0.20775416371179745, 0.1523903923225589, 0.20898080023471266, 0.16543725942028686, 0.10595872445264831, 0.1665101377875544, 0.24430293298792094, 0.09053972331457771, 0.13802061730530113], [0.039004283607937396, 0.08055002224864438, 0.019256583691458218, 0.02488720987457782, 0.05047589402238373, 0.04132392554311082, 0.03382526170753408, 0.05995962106680963, 0.029754472234344576, 0.00902748062799219, 0.04625942281563766, 0.028350894717732444, 0.017440655938116834, 0.048658489395165816, 0.04167368861089926, 0.030601906546507962, 0.06354629833367653, 0.027151519134349655, 0.07079429065925069, 0.07277080061612651, 0.27961236017290503, 3.062435695901513, 90.57478979229927, 98.50148364901543, 88.70904430747032, 77.48463660478592, 49.901643097400665, 31.9482334703207, 47.666348442435265, 61.13681182265282, 34.372438788414, 49.32483024895191, 32.055547311902046, 0.23810781072825193, 0.0487261287344154, 0.036676563395303674, 0.0628644649987109, 0.08086926449323073, 0.07046648403047584, 0.015352696736954385, 0.08645938796689734, 0.09352783250506036, 0.27606786286924034, 0.21766988007584587, 6.022592755034566, 48.37213397026062, 94.81058970093727, 98.12728732824326, 90.6715402007103, 89.35352772474289, 79.52746018767357, 70.03630667924881, 67.03675523400307, 65.83893030881882, 67.32758402824402, 77.0242989063263, 88.65121901035309, 89.54663336277008, 83.16540777683258, 85.7293201982975, 83.41451480984688, 78.95347818732262, 81.08506500720978, 79.1708493232727, 81.5949596464634, 76.76263734698296, 68.93457099795341, 60.003085657954216, 60.51565535366535, 60.74725292623043, 62.28203237056732, 59.36085171997547, 62.86723516881466, 61.67947590351105, 67.30923861265182, 65.50241276621819, 62.00612537562847, 61.236678063869476, 64.44134250283241, 59.782024919986725, 60.99160261452198, 64.82537269592285, 68.2523176074028, 63.08137267827988, 63.08110289275646, 64.3814805150032, 81.99918195605278, 69.34947833418846, 47.693668976426125, 84.1165043413639, 69.8910328745842, 75.69680973887444, 78.14852938055992, 79.70745652914047, 76.10408708453178, 83.38281691074371, 81.1098700761795, 81.06109589338303, 71.24818325042725, 61.94421909749508, 60.32283470034599, 62.31143519282341, 62.89271280169487, 66.98118701577187, 64.82908129692078, 61.99578233063221, 62.671013697981834, 62.96146631240845, 74.66448873281479, 80.93814969062805, 80.71784511208534, 74.08343151211739, 70.91347441077232, 76.79463922977448, 72.86368936300278, 77.4334305524826, 79.26288038492203, 79.68233987689018, 78.5024955868721, 66.99235081672668, 59.08138811588287, 74.57442596554756, 79.5809157192707, 80.66302925348282, 80.6511814892292, 85.79026892781258, 32.53160856664181, 0.11385075995349325, 0.4621022881474346, 0.006252764869714156, 0.26055754045955837, 0.0500530479621375, 0.10583232928183861, 0.024337469549209345, 0.06592527497559786, 0.19553924415959045, 0.04554202205326874, 0.21642644132953137, 6.469681039452553, 36.17998659610748, 70.87550684809685, 92.15542137622833, 83.3389064669609, 97.96518802642822, 20.31704619526863, 23.864752426743507, 41.721172258257866, 78.7805038690567, 70.8873850107193, 88.11718046665192, 9.778074212372303, 0.3168625332182273, 0.08021106114028953, 0.09548259011353366, 0.018368917553743813, 0.10728903900599107, 0.043812784570036456, 0.03982312853622716, 0.05032133434724528, 0.08675866643898189, 0.09504644476692192, 0.02530636189476354, 0.04250988124113064, 0.0011441747551543813, 0.0226391202522791, 0.03554682909452822, 0.03451680975558702, 0.03529052839439828, 0.015388835618068697, 0.038880426582181826, 0.011583983632590389, 0.05569213091803249, 0.017447684076614678, 0.048759072669781744, 0.061634681769646704, 0.031162784653133713, 0.05403649964137003, 0.07435501131112687, 0.05750498989073094, 0.03502067607769277, 0.052030993974767625, 0.06358409591484815, 0.05411619145888835, 0.013680145420948975, 0.015051156569825253, 0.0936726997315418, 0.04807552497368306, 0.05042925004090648, 0.03624401375418529, 0.005073967186035588, 0.013972017259220593, 0.0772308038722258, 0.02171093841752736, 0.07576520321890712, 0.04268924349162262, 0.09013710819999687, 0.19063302461290732, 4.9753442499786615, 116.28435462713242, 107.8444755077362, 102.62143537402153, 91.61184534430504, 70.79613670706749, 40.51646210253239, 47.484596595168114, 51.419331058859825, 41.027789264917374, 42.99756556749344, 38.35841730237007, 0.32357419026084244, 0.09205869922880083, 0.08349409981747158, 0.08291868303786032, 0.25542472838424146, 0.3523691341979429, 0.2065331526682712, 0.22853493690490723, 0.13820447697071359, 0.19087190710706636, 0.750504556344822, 9.133246913552284, 50.42011007666588, 93.84930968284607, 100.98988652229309, 95.4829104244709, 93.72906893491745, 83.0304466187954, 73.17590340971947, 71.20982050895691, 69.41131621599197, 69.89319875836372, 81.9271682202816, 91.16371259093285, 91.11715748906136, 83.41035783290863, 87.47032597661018, 85.59232994914055, 82.87242069840431, 85.65135598182678, 84.80950355529785, 84.74691331386566, 81.22804373502731, 71.19348898530006, 62.876286283135414, 63.73029425740242, 62.81998850405216, 65.70089891552925, 62.088896334171295, 66.65934428572655, 63.846431225538254, 69.6619887650013, 69.09009665250778, 65.52963450551033, 64.60093393921852, 69.01783213019371, 61.72350034117699, 65.14352962374687, 69.86523985862732, 71.10980987548828, 66.49545148015022, 66.22872099280357, 67.37315878272057, 86.34240210056305, 73.0829755961895, 50.529054030776024, 87.10226252675056, 74.15776312351227, 76.43764078617096, 81.87302872538567, 84.86954793334007, 79.46028739213943, 84.98744800686836, 85.51071792840958, 84.42617252469063, 74.48292687535286, 64.7031332552433, 63.5550856590271, 65.49563392996788, 65.3961780667305, 68.90113279223442, 68.78599897027016, 64.22286182641983, 66.32483303546906, 65.19877105951309, 78.67453515529633, 84.229084700346, 84.02592480182648, 77.34852030873299, 74.71120342612267, 79.59666207432747, 77.27041929960251, 76.98505461215973, 82.23303660750389, 83.38412404060364, 82.53673911094666, 71.1009107530117, 63.0482080578804, 78.50957840681076, 81.88865348696709, 84.52548399567604, 85.62613293528557, 90.23908540606499, 42.07011893391609, 0.48338043387047946, 0.42787817772477865, 0.20020919357193634, 0.20031159510836005, 0.27398349659051746, 0.2445508845266886, 0.09225521993357688, 0.026780025982588995, 0.3559424268314615, 0.09894687609630637, 0.2967188641196117, 7.857530917972326, 37.247144132852554, 75.30443519353867, 96.0818798840046, 73.5799053311348, 63.72780539095402, 20.881143026053905, 44.07334864139557, 48.705258294939995, 90.35535156726837, 79.99193966388702, 106.61978602409363, 15.12238958850503, 0.34848517854698, 0.06181224431202281, 0.04758007460623048, 0.03827859676675871, 0.037442478351294994, 0.07902023324277252, 0.023354984768957365, 0.05679904788848944, 0.009992548129957868, 0.03880590382323135, 0.0345070987532381, 0.04549967881757766, 0.015511648998653982, 0.02688057214982109, 0.047312797541962937, 0.01699699820164824, 0.07820531056495383, 0.029600190864584874, 0.05247854613116942, 0.029053897815174423, 0.05689385725418106, 0.02378904839133611, 0.061057120183249936, 0.03727064889972098, 0.03221014056180138, 0.1456500290078111, 0.14551647211192176, 0.23219535767566413, 0.18890082224970683, 0.20326308673247695, 0.1300861086929217, 0.1375033997464925, 0.1749541307799518, 0.23737820534734055, 0.2679916040506214, 0.15808696945896372, 0.20161403459496796, 0.233216775523033, 0.13396706606727093, 0.0911821263434831, 0.1896540427696891, 0.1678646166692488, 0.21845284587470815, 0.1803252613171935, 0.23581378773087636, 0.6790761672891676, 7.066438067704439, 134.5989614725113, 123.48504424095154, 117.5308321416378, 100.9241196513176, 69.35261696577072, 45.55574789643288, 69.27478954195976, 81.45245209336281, 48.888579457998276, 79.19112503528595, 51.745744943618774, 0.6916800909675658, 0.12555985391372815, 0.28104238968808204, 0.179010383435525, 0.4351274168584496, 0.5512881930917501, 0.23147347063058987, 0.40135764924343675, 0.4000947216991335, 0.6552506738808006, 1.768568311817944, 8.756692819297314, 51.9663193076849, 96.95611417293549, 105.91713532805443, 100.6952503323555, 99.15339946746826, 88.71105059981346, 77.55189299583435, 76.16525620222092, 74.94515687227249, 73.07686552405357, 85.16662359237671, 94.85924988985062, 95.88342413306236, 87.43342235684395, 92.06988796591759, 91.61141976714134, 88.831397742033, 88.81309032440186, 86.38307511806488, 88.3841921389103, 85.11325925588608, 74.60733979940414, 65.62271431088448, 66.30758196115494, 66.5762959420681, 69.13168922066689, 66.00307390093803, 69.93172109127045, 67.43598461151123, 72.99434155225754, 71.37843266129494, 68.02518859505653, 66.43470034003258, 73.47849637269974, 65.95664039254189, 67.0397038757801, 72.56498739123344, 75.49254029989243, 70.35779982805252, 70.70759385824203, 72.76296436786652, 91.13189309835434, 77.8973400592804, 54.621510431170464, 89.28757086396217, 79.41750168800354, 83.48202958703041, 85.43703988194466, 88.89906451106071, 82.55978107452393, 88.60730096697807, 90.46421572566032, 88.96208792924881, 78.57510209083557, 67.80401766300201, 65.89189186692238, 68.91203060746193, 69.2502124607563, 73.1473821401596, 72.69865661859512, 68.86463955044746, 70.79343885183334, 71.01441979408264, 84.52023267745972, 88.49566295742989, 87.18086510896683, 79.84548792243004, 77.36270874738693, 83.86750370264053, 78.84022146463394, 79.67031732201576, 85.4584327340126, 89.08919870853424, 87.58599936962128, 75.49288988113403, 67.75459751486778, 81.90436944365501, 87.89771184325218, 89.49277505278587, 90.97685381770134, 93.45534682273865, 42.79327712953091, 0.8851822733413428, 1.703500128351152, 0.534591592149809, 0.3529939037980512, 0.23617972590727732, 0.29010522994212806, 0.10498887102585286, 0.3706789860734716, 0.3177632036386058, 0.32143496442586184, 0.5067159910686314, 15.465783812105656, 56.29924580454826, 79.56902235746384, 101.48900493979454, 95.20820036530495, 116.87478214502335, 31.78673643618822, 41.894682347774506, 61.78290255367756, 102.45347678661346, 91.26756101846695, 116.18663907051086, 15.681475438177586, 0.49100169679149985, 0.13196086278185248, 0.2072181401308626, 0.11565409717150033, 0.21957253891741857, 0.1739868154982105, 0.1256808833568357, 0.18861208227463067, 0.18568018334917724, 0.28127313824370503, 0.21971932088490576, 0.16906961216591299, 0.12360154141788371, 0.1284794183447957, 0.13326725049410015, 0.17857723636552691, 0.13676447299076244, 0.11849959526443854, 0.1508597721112892, 0.12319882240262814, 0.09218972540111281, 0.0769394812232349, 0.1971708409837447, 0.1608647539978847, 0.08343203400727361], [0.0687302221194841, 0.030941806471673772, 0.02136531467840541, 0.04153171576035675, 0.04103025028598495, 0.06466210252256133, 0.02182546664698748, 0.05439285669126548, 0.06717410913552158, 0.018760693601507228, 0.0202684816395049, 0.050917594344355166, 0.05779526611149777, 0.10643361732945777, 0.05498680489836261, 0.005703031501980149, 0.04454234913282562, 0.08569963654736057, 0.08393567768507637, 0.2814581408165395, 0.47205745708197355, 26.725947596132755, 106.55123770236969, 94.74233016371727, 80.7262122631073, 53.63768242299557, 33.80809307098389, 51.49019345641136, 79.24574330449104, 56.258584186434746, 59.730256497859955, 44.02951419353485, 1.3838184135966003, 0.19783029856625944, 0.09763767564436421, 0.056849224492907524, 0.21580501139396802, 0.12835184315918013, 0.02851619698049035, 0.1741210403270088, 0.09326445171609521, 0.09106598765356466, 0.21396488591562957, 9.168117642402649, 53.21670301258564, 87.02885806560516, 95.97419366240501, 93.21925789117813, 94.79519292712212, 88.26609447598457, 89.00110423564911, 78.61683145165443, 68.97625476121902, 65.39101034402847, 63.91694784164429, 72.50558137893677, 84.72543686628342, 86.8612490594387, 84.86469179391861, 79.10775750875473, 83.12484115362167, 79.73464787006378, 81.60042375326157, 84.77600455284119, 88.1940807402134, 79.2757996916771, 69.50975373387337, 57.70422801375389, 62.32238620519638, 57.986826449632645, 61.35759897530079, 59.18970130383968, 60.063213631510735, 59.47211354970932, 64.3853411078453, 62.247005850076675, 63.998924642801285, 63.28272767364979, 64.67645108699799, 59.355076029896736, 71.76003098487854, 76.22165277600288, 79.79840844869614, 76.98532059788704, 75.32012075185776, 69.96253743767738, 81.50077030062675, 69.89667937159538, 38.08031402528286, 84.14636313915253, 69.55039635300636, 71.34013831615448, 74.93883401155472, 80.50681963562965, 77.58789226412773, 74.72172126173973, 78.91313195228577, 81.74609273672104, 78.27326908707619, 70.6732665002346, 56.78579829633236, 61.76294602453709, 61.76388077437878, 64.66533288359642, 62.96824514865875, 61.88140466809273, 60.772065594792366, 63.188089951872826, 74.31787893176079, 78.214281052351, 77.30007290840149, 76.48474305868149, 77.71977558732033, 73.8032877445221, 76.98741048574448, 79.45830389857292, 80.9123794734478, 76.52876749634743, 76.25711247324944, 71.90519839525223, 62.66486182808876, 64.80295389890671, 75.33161893486977, 77.67424643039703, 81.23247429728508, 80.62707558274269, 93.6417344212532, 17.87661574780941, 0.263688275590539, 0.4931015591137111, 0.20649944432079792, 0.19228367978939787, 0.42715369316283613, 0.057480610339553095, 0.11087593520642258, 0.058554442366585135, 0.20764702727319673, 0.22694115992635489, 0.10749203865998425, 9.109282549470663, 19.039841629564762, 34.8866081982851, 61.950956135988235, 89.93559569120407, 53.12823995947838, 16.17422729730606, 44.086275547742844, 64.29413840174675, 75.4464715719223, 85.4033812880516, 59.27473694086075, 0.791853996925056, 0.11708700621966273, 0.05377121895435266, 0.016053821273089852, 0.09934354660799727, 0.01938919805979822, 0.052754803182324395, 0.019422069635766093, 0.01410742766893236, 0.018764556480164174, 0.014442187293752795, 0.06888602118124254, 0.02151360320567619, 0.014043017599760788, 0.08129903479130007, 0.04806704222573899, 0.09863836530712433, 0.06194589768711012, 0.13969083549454808, 0.03367709934536833, 0.011635984992608428, 0.042918121835100465, 0.046494828347931616, 0.00921438031582511, 0.04677255856222473, 0.007313738724405994, 0.03521362705214415, 0.03305131300294306, 0.0709404714871198, 0.025892732774082106, 0.034662485923036, 0.02813577579217963, 0.07457286134012975, 0.11705383221851662, 0.05621832846372854, 0.06437832009396516, 0.06884277623612434, 0.03528443165123463, 0.04008247204183135, 0.05808542358863633, 0.0494666177110048, 0.025048940551641863, 0.06658059879555367, 0.06630232310271822, 0.42602500529028475, 0.40846591000445187, 42.11117573082447, 123.82354527711868, 106.75898015499115, 93.1375926733017, 73.64757969975471, 54.60268624126911, 48.819677755236626, 63.84631723165512, 49.30245324969292, 45.58915190398693, 45.29944404959679, 1.833520601503551, 0.24117055028909817, 0.061678360871155746, 0.6323702610097826, 0.6232245673891157, 0.6109685031697154, 1.06906064087525, 2.4083473440259695, 0.33421041327528656, 0.29254505527205765, 0.47606941836420447, 11.98725001886487, 57.71662674844265, 89.5799195766449, 95.3803539276123, 93.25054541230202, 96.97886735200882, 91.15719214081764, 92.25151062011719, 83.22460100054741, 70.51088601350784, 68.29402416944504, 67.16033980250359, 76.72791481018066, 89.9934209883213, 88.73141750693321, 86.70604258775711, 82.7672727406025, 86.36767834424973, 81.66584104299545, 87.10278689861298, 86.39554604887962, 89.94731426239014, 84.00546669960022, 73.17160204052925, 62.145072519779205, 62.82021649181843, 62.037770077586174, 64.44524869322777, 61.52862399816513, 62.56277650594711, 63.04012209177017, 66.78049698472023, 64.20000985264778, 67.77402207255363, 64.22662362456322, 65.96620827913284, 63.05293120443821, 73.99269998073578, 81.71535238623619, 83.57258632779121, 79.16347771883011, 78.90070661902428, 75.41892305016518, 87.18501448631287, 73.3356012403965, 41.22081130743027, 87.36880302429199, 71.80346265435219, 75.75973436236382, 78.69532763957977, 83.48565459251404, 79.77890029549599, 76.24930769205093, 83.6235111951828, 85.51729157567024, 82.24915534257889, 74.45932254195213, 58.666222393512726, 63.825243562459946, 63.84926587343216, 66.74252942204475, 64.64400082826614, 65.56602135300636, 63.77204641699791, 67.502161860466, 78.14203932881355, 81.30483001470566, 79.0119418501854, 79.35173481702805, 79.59035441279411, 76.12959131598473, 81.64190992712975, 82.41675674915314, 81.37850806117058, 79.70462188124657, 79.55075293779373, 77.42510139942169, 66.18730321526527, 67.74233937263489, 79.77532088756561, 79.10554602742195, 85.01206308603287, 82.78830841183662, 99.41940799355507, 22.621012665331364, 0.31144921900704503, 0.18141939479392022, 0.51318449084647, 0.3792360081570223, 1.057634772732854, 0.41346896497998387, 0.30470953846815974, 0.22678331995848566, 0.47831937263254076, 0.25438399985432625, 0.25208028440829366, 12.341263722628355, 22.021266147494316, 41.83355122804642, 70.35532996058464, 84.43039789795876, 42.75565914809704, 21.037719324231148, 52.623843625187874, 69.13567140698433, 84.26697626709938, 94.61366906762123, 77.72314980626106, 0.8202702377457172, 0.10662483909982257, 0.05654778637108393, 0.07879856857471168, 0.04911540374450851, 0.04098373246961273, 0.02396334362856578, 0.03585641970857978, 0.08799653907772154, 0.014680342483188724, 0.049282412946922705, 0.05293133785016835, 0.028183004214952234, 0.03553069109329954, 0.06726068066200241, 0.05527436485863291, 0.045736761603620835, 0.05101850416394882, 0.04272128200682346, 0.08891098375897855, 0.02258745749713853, 0.033144868139061145, 0.05032481130911037, 0.0297178824985167, 0.0336151374358451, 0.21488458500243723, 0.21453685913002118, 0.07378227368462831, 0.15837979124626145, 0.12237352450028993, 0.12271109779248945, 0.1359456911450252, 0.2128767193062231, 0.26196916471235454, 0.13429508049739525, 0.15090458298800513, 0.2199316641781479, 0.11729925303370692, 0.14433964854106307, 0.1885488661355339, 0.23224652133649215, 0.1339089113753289, 0.2551203587790951, 0.20598154398612678, 0.6117903278209269, 0.6907390477135777, 50.5211428552866, 140.58578342199326, 118.75245898962021, 110.25801479816437, 77.70073860883713, 52.553733587265015, 68.19192364811897, 102.43190914392471, 74.90418747067451, 91.35834574699402, 74.39890578389168, 2.092776889912784, 0.3397481411229819, 0.20022572862217203, 0.5835927533917129, 0.8814183971844614, 0.8494134270586073, 0.709770267130807, 1.7659766133874655, 0.21725714206695557, 0.49560007348190993, 0.4965030890889466, 11.551598645746708, 60.25232568383217, 94.88577246665955, 99.38119724392891, 97.13169515132904, 102.01880291104317, 97.30646297335625, 97.17425286769867, 88.76057714223862, 76.42408311367035, 72.95515805482864, 70.5810834467411, 79.85676571726799, 91.84619396924973, 92.31706470251083, 89.92106527090073, 87.77807146310806, 92.2738990187645, 85.96493035554886, 88.62374648451805, 88.4070897102356, 93.36035951972008, 87.34452992677689, 77.53724858164787, 64.04442340135574, 68.8439230620861, 65.87078779935837, 68.37560579180717, 66.9947674870491, 67.54947692155838, 67.6326696574688, 70.09245246648788, 68.38225543498993, 69.85918298363686, 69.28995832800865, 69.79763388633728, 67.28146970272064, 76.97683945298195, 82.83436954021454, 89.27277445793152, 84.55472722649574, 84.79700982570648, 79.94695767760277, 89.72187235951424, 77.42169678211212, 46.06046341359615, 92.95888066291809, 77.62683257460594, 80.81109210848808, 83.71922805905342, 88.37102204561234, 84.0431834757328, 78.58466997742653, 84.43706274032593, 89.82151821255684, 84.99264612793922, 78.397446423769, 62.05576591193676, 67.50015556812286, 66.56196311116219, 69.59403321146965, 68.73988464474678, 69.57089245319366, 67.5367172062397, 70.97049415111542, 82.4655233323574, 84.63535130023956, 83.56399118900299, 83.32011267542839, 86.43611267209053, 81.18427768349648, 85.32496869564056, 87.89783343672752, 87.56152108311653, 82.17234626412392, 84.00149211287498, 81.26604929566383, 71.65027007460594, 72.88494542241096, 83.85260850191116, 82.3457233607769, 89.35699313879013, 89.7079499065876, 103.87616604566574, 22.888476513326168, 0.9208253701217473, 0.9784443501848727, 0.6717970047611743, 0.6076503312215209, 0.7453282841015607, 0.6935070804320276, 0.5590424488764256, 0.4649453074671328, 0.49952452071011066, 0.9697489917743951, 0.3851737536024302, 18.650246635079384, 35.28522580862045, 45.63572600483894, 70.13111919164658, 102.58889392018318, 63.434651121497154, 25.54229211062193, 61.24191038310528, 83.31140354275703, 98.12555462121964, 106.71445414423943, 81.38623684644699, 0.9975250856950879, 0.2720858249813318, 0.13284109445521608, 0.166619470983278, 0.17359343270072713, 0.26156463485676795, 0.14588720456231385, 0.08841274291626178, 0.1256035515689291, 0.1320598801248707, 0.21331509109586477, 0.18017926602624357, 0.09074463770957664, 0.16947932221228257, 0.1485732151195407, 0.2346912893699482, 0.1821943453978747, 0.09714513449580409, 0.15624215360730886, 0.19957968906965107, 0.1468259174725972, 0.3229585342342034, 0.20626370853278786, 0.07016316827503033, 0.17200737405801192], [0.09087224258109927, 0.05760433748946525, 0.03287674502644222, 0.01553114985654247, 0.07113981977454387, 0.021029247945989482, 0.07162155525293201, 0.05757759790867567, 0.0907395985268522, 0.03960754576837644, 0.04561877496598754, 0.028326873252808582, 0.04595967307977844, 0.0185676869659801, 0.02669886285730172, 0.09129330006544478, 0.04489379316510167, 0.04638297927158419, 0.0406460070371395, 0.04141941397392657, 0.559097130317241, 74.58615973591805, 105.09538382291794, 92.882831543684, 86.58172085881233, 41.66672118008137, 33.633028864860535, 54.853316992521286, 68.51112931966782, 57.12700858712196, 48.40642333030701, 8.148545902222395, 0.06475420304923318, 0.10100238025188446, 0.01897579768410651, 0.1695613146875985, 0.04003845155239105, 0.35209685505833477, 1.0394759033806622, 0.8827316423412412, 0.1737315909122117, 0.5415945569984615, 17.327311523258686, 66.33322298526764, 86.41449943184853, 87.35944032669067, 90.56433275341988, 89.91776704788208, 90.13932555913925, 93.9052426815033, 87.6274399459362, 87.39849463105202, 71.70342162251472, 64.30192038416862, 64.00054335594177, 69.63130921125412, 82.261603474617, 84.8323555290699, 85.97511380910873, 82.81812161207199, 83.19524377584457, 80.3770337998867, 81.79281502962112, 78.32949846982956, 80.62766835093498, 76.89955919981003, 67.23853200674057, 58.85482907295227, 60.973694175481796, 59.86513786017895, 60.6119953840971, 59.80099730193615, 60.613500103354454, 60.84015794098377, 59.99738596379757, 60.093536004424095, 61.86441957950592, 61.82463191449642, 62.664804831147194, 65.40084421634674, 77.92479738593102, 79.02230769395828, 81.29479095339775, 79.48657438158989, 83.28845277428627, 74.86380323767662, 84.41456034779549, 68.43646332621574, 30.283269211649895, 76.00571036338806, 70.73530197143555, 69.4690503180027, 66.9241900742054, 78.07837754487991, 76.24318242073059, 75.74464157223701, 71.89901232719421, 81.24768108129501, 79.21618849039078, 76.37128114700317, 65.3189206123352, 59.478428810834885, 64.3218845129013, 60.57249270379543, 59.578982815146446, 60.44618368148804, 60.61908960342407, 60.927249267697334, 72.17088773846626, 73.58425989747047, 75.65609872341156, 72.78308048844337, 72.51112148165703, 68.69386151432991, 73.58255758881569, 79.39876109361649, 80.4320852458477, 76.53186812996864, 78.20147573947906, 72.35555782914162, 61.458320170640945, 60.474708750844, 64.51407060027122, 65.90154334902763, 74.9069993197918, 78.88193562626839, 83.21416676044464, 79.26112487912178, 3.342794389463961, 0.3843144653365016, 0.1080219098366797, 1.0919246077537537, 0.7831671880558133, 0.30003071296960115, 0.1337007834808901, 0.23028063151286915, 0.21967948239762336, 0.06726282546878792, 0.05435084371129051, 0.19059165730141103, 25.95786441117525, 38.254420682787895, 67.70598292350769, 64.8097251355648, 92.57861226797104, 50.08568622171879, 45.99597327411175, 63.89093443751335, 61.892686262726784, 77.03015819191933, 91.34449928998947, 16.12419158220291, 0.7934773410670459, 0.24081804498564452, 0.20258804404875264, 0.09186384093482047, 0.16601310664555058, 0.043510511532076634, 0.050297845373279415, 0.06635818455833942, 0.03584152480470948, 0.026544818974798545, 0.01842202564148465, 0.08600282613770105, 0.06896273698657751, 0.030805008245806675, 0.028490281183621846, 0.007708767234362313, 0.052861653894069605, 0.01886125646706205, 0.0036610110100809834, 0.041915636174962856, 0.10437069169711322, 0.031050757461343892, 0.15683009783970192, 0.011457684013294056, 0.07057010268908925, 0.004161671486144769, 0.044544434567797, 0.057859769876813516, 0.025201776588801295, 0.007929936982691288, 0.0507352857675869, 0.036860935142613016, 0.0909527952899225, 0.031755074160173535, 0.03980820023571141, 0.017694904599920847, 0.03600065239879768, 0.02069332778773969, 0.038565715149161406, 0.06252407154534012, 0.07166534938733093, 0.07335165733820759, 0.024930653344199527, 0.07889390486525372, 1.7308593727648258, 95.58625727891922, 115.58954671025276, 102.09941178560257, 95.6698527932167, 48.89208287000656, 38.587602004408836, 38.70956026017666, 44.819780588150024, 59.06415984034538, 50.33616878092289, 10.822607763111591, 0.14603374904254451, 0.0634992535924539, 0.18223443621536717, 0.34356482850853354, 0.3236648510210216, 0.8578175073489547, 2.8445665491744876, 3.5693512950092554, 0.7043765753041953, 1.1402422212995589, 21.024220548570156, 70.51995992660522, 90.21811053156853, 93.42613399028778, 92.98937022686005, 91.42532855272293, 92.3664240539074, 99.00966838002205, 92.85585299134254, 91.79559588432312, 72.75269731879234, 67.95000582933426, 66.52142688632011, 74.6109040081501, 87.58655413985252, 86.26702174544334, 89.88350048661232, 87.15403854846954, 86.23106807470322, 83.73529359698296, 84.99098941683769, 82.35874906182289, 83.15815016627312, 81.62014469504356, 69.62658226490021, 62.81794421374798, 61.77198953926563, 63.38162496685982, 63.67980636656284, 62.67013594508171, 62.785965129733086, 64.99510958790779, 63.079620972275734, 64.24064487218857, 66.31726384162903, 66.17702096700668, 65.05928814411163, 66.4418363571167, 81.6217178106308, 80.0931966304779, 85.01289144158363, 82.66106843948364, 85.57577803730965, 78.53189080953598, 87.561756670475, 71.37140303850174, 33.346471041440964, 81.15802869200706, 74.10486996173859, 71.9618533551693, 70.84690198302269, 79.34489518404007, 80.16501277685165, 79.35861244797707, 72.43523955345154, 83.12386840581894, 80.90537264943123, 79.74283263087273, 68.61408099532127, 60.176303163170815, 65.93438118696213, 64.99311089515686, 62.78625771403313, 64.12898406386375, 63.43249283730984, 64.47627782821655, 75.35937264561653, 75.25319114327431, 80.47226428985596, 78.12884643673897, 78.45777958631516, 73.74005153775215, 76.79553598165512, 82.47603356838226, 81.56619518995285, 81.05535820126534, 81.72738254070282, 76.65384918451309, 65.90612590312958, 65.41348993778229, 68.30979332327843, 70.8152724802494, 77.94463992118835, 83.9961875975132, 85.14591470360756, 85.78374087810516, 5.360555229708552, 0.37770555121824145, 0.34688706742599607, 1.8737954716198146, 0.4961162223480642, 1.1232015606947243, 0.26628285355400294, 0.7471981993876398, 0.45310285699088126, 0.10431244794744998, 0.07139795357943512, 0.3715587279293686, 26.06030121445656, 33.027071580290794, 74.04778182506561, 74.8706428706646, 79.07012432813644, 42.966494634747505, 62.8274817019701, 66.77731275558472, 73.32154959440231, 85.420351177454, 108.75655576586723, 21.492366828024387, 1.1685359780676663, 0.2594045695150271, 0.21903057815507054, 0.09738611726788804, 0.07617774826940149, 0.08856950676999986, 0.035052606981480494, 0.017158528498839587, 0.0457056953018764, 0.02869644609745592, 0.05536567870876752, 0.04643061402020976, 0.007369719851340051, 0.04581676141242497, 0.017155968089355156, 0.025617282808525488, 0.04366193192254286, 0.04917338774248492, 0.058796946541406214, 0.0411380880541401, 0.043313842397765256, 0.03104908948444063, 0.10653437129803933, 0.04442511206434574, 0.2147235389566049, 0.1490721313166432, 0.11353227469953708, 0.10282800416462123, 0.2035338815767318, 0.18162416818086058, 0.221366458281409, 0.16149137896718457, 0.2108477766159922, 0.15526321629295126, 0.09098929411265999, 0.1088001110474579, 0.17562901019118726, 0.1107313648390118, 0.25515805988106877, 0.27645888563711196, 0.13995055749546736, 0.20756659330800176, 0.26678338763304055, 0.3961811098270118, 2.422207575291395, 115.1105672121048, 131.91869169473648, 118.26946690678596, 112.36303344368935, 59.37363423407078, 48.561709597706795, 74.75078970193863, 93.53820517659187, 82.05094277858734, 76.02822035551071, 15.730727445334196, 0.24679018155438825, 0.28923287987709045, 0.32461450318805873, 1.0455142543651164, 1.32969364291057, 1.4447416132315993, 4.867160730063915, 6.759224077686667, 1.715902544092387, 1.8350753118284047, 20.14784887433052, 78.05430963635445, 95.32935306429863, 96.23500406742096, 99.14389237761497, 92.22162142395973, 94.97781112790108, 102.637098133564, 97.42531299591064, 95.31615257263184, 78.75318333506584, 72.60982498526573, 69.98763129115105, 76.58376574516296, 89.86399993300438, 90.01186519861221, 92.6610754430294, 91.49788945913315, 87.81590983271599, 87.04553157091141, 87.44005680084229, 83.64428848028183, 86.12762242555618, 85.50331592559814, 75.40193036198616, 66.88698247075081, 65.98929584026337, 67.52913281321526, 66.82744726538658, 66.95793226361275, 65.82528904080391, 69.20193985104561, 65.04370898008347, 64.97792690992355, 69.44432884454727, 70.05091309547424, 68.23163151741028, 71.40479564666748, 84.11423206329346, 84.68386709690094, 89.00656834244728, 87.6306925714016, 90.26264414191246, 82.30312004685402, 87.98143655061722, 75.0200280547142, 37.54668965935707, 83.92999514937401, 78.29347640275955, 76.38372167944908, 75.61373859643936, 83.2295635342598, 83.08772474527359, 79.1522379219532, 74.49706971645355, 86.87900170683861, 85.3764483332634, 82.98008412122726, 71.66955783963203, 62.98986978828907, 70.0154609978199, 68.98520708084106, 67.1461969614029, 68.39917212724686, 67.02936083078384, 67.8583699464798, 79.45204183459282, 78.53952080011368, 84.11181539297104, 83.88530194759369, 82.51529306173325, 79.34653669595718, 81.86458557844162, 88.15375730395317, 84.83668729662895, 84.53648060560226, 85.34847423434258, 80.70303350687027, 69.5194660127163, 68.22926044464111, 72.78032943606377, 74.39536437392235, 83.00851419568062, 86.59441977739334, 87.801174223423, 88.15181940793991, 5.996090127155185, 0.9552664845250547, 2.4077726248651743, 3.640341223217547, 1.5425472962670028, 0.6681876140646636, 0.7958429516293108, 0.7955795782618225, 1.187263154424727, 0.3453035617712885, 0.27449370827525854, 1.1342387809418142, 43.18057894706726, 56.64559341967106, 80.9170988202095, 75.86261004209518, 103.89451906085014, 63.07349190115929, 64.15128886699677, 81.75192162394524, 85.7107999920845, 97.49643757939339, 116.02089956402779, 23.09833165258169, 1.1947552836500108, 0.6373650336172432, 0.38715908769518137, 0.18146944523323327, 0.2889246214181185, 0.2143861140939407, 0.23789995000697672, 0.21077127603348345, 0.2038501700735651, 0.10497410228708759, 0.1185793687182013, 0.1871990627842024, 0.15090251981746405, 0.17984823847655207, 0.23792956169927493, 0.13351247092941776, 0.1688022312009707, 0.13810841337544844, 0.0809176525217481, 0.07485383845050819, 0.13774799677776173, 0.1368953284691088, 0.24689017853233963, 0.21419239870738238], [0.04632898431736976, 0.02882153323298553, 0.034472106490284204, 0.027565023410716094, 0.060858966753585264, 0.025532976687827613, 0.08220970194088295, 0.13867862027836964, 0.011110713276138995, 0.06897119747009128, 0.04902796761598438, 0.042847476797760464, 0.025902898341882974, 0.028704001160804182, 0.011620095610851422, 0.03192872187355533, 0.06475156842498109, 0.013679532221431145, 0.19626484194304794, 0.23603331501362845, 9.600405246019363, 94.69498470425606, 88.02013367414474, 82.38728553056717, 73.55134606361389, 53.29371728003025, 73.49913686513901, 147.17519223690033, 113.23031410574913, 51.529384553432465, 22.497213408350945, 0.2631911257049069, 0.09606942112441175, 0.033036904205800965, 0.04428226347954478, 0.4289168876130134, 0.3826052992371842, 0.15920277364784852, 3.4421075228601694, 4.924301113933325, 1.4127589669078588, 19.20386552810669, 76.2056252360344, 90.35495638847351, 84.5596593618393, 86.78876414895058, 85.88859245181084, 90.83535701036453, 89.37741324305534, 88.32227826118469, 92.87760302424431, 87.21658319234848, 77.66426056623459, 64.67283368110657, 61.08360327780247, 60.31976446509361, 74.03426975011826, 80.52844807505608, 83.42580020427704, 80.00524654984474, 81.04256048798561, 81.8338680267334, 82.40857198834419, 77.0303025841713, 82.99162790179253, 77.04588934779167, 69.33318480849266, 65.69618716835976, 61.853643357753754, 62.81895495951176, 62.78390184044838, 63.43554027378559, 58.78951817750931, 57.80334569513798, 59.5878629386425, 61.24645113945007, 60.208153054118156, 62.93066896498203, 61.99194833636284, 59.48732413351536, 73.99243399500847, 77.32839658856392, 76.50031462311745, 79.0086056292057, 80.9327843785286, 78.14016222953796, 75.56713789701462, 54.64909315109253, 28.204953633248806, 78.53332713246346, 73.2074037194252, 73.0375224351883, 63.82500797510147, 70.31325861811638, 76.25518217682838, 73.69741022586823, 66.86875864863396, 70.54139837622643, 78.01758840680122, 77.57127195596695, 73.75682383775711, 60.27978301048279, 58.54617543518543, 63.173339143395424, 58.59110042452812, 58.840032666921616, 58.186148554086685, 57.761513739824295, 65.06904602050781, 68.47614079713821, 67.80856221914291, 71.32886812090874, 69.4295172393322, 69.52560648322105, 68.57261002063751, 72.77132391929626, 76.19378507137299, 80.11430829763412, 78.67963448166847, 75.74842616915703, 61.84607036411762, 60.69377459585667, 63.10493141412735, 62.91557617485523, 67.77885541319847, 80.11785730719566, 79.69585955142975, 89.16267156600952, 52.08745300769806, 0.7540796301327646, 0.30817679304163903, 1.872630121652037, 1.3857863517478108, 1.1008021188899875, 0.19590159034123644, 0.04647615962312557, 0.17957840842427686, 0.13523714791517705, 0.04721860044810455, 0.15237575717037544, 2.0253274217247963, 24.472835697233677, 39.70203660428524, 75.89253723621368, 69.82520520687103, 41.04343302547932, 16.901092194020748, 38.67524050176144, 61.16069734096527, 74.97746273875237, 92.6456406712532, 37.17437423765659, 0.795017802156508, 0.08898749176296405, 0.10892724836594425, 0.10626618139212951, 0.07539074518717825, 0.053747295823995955, 0.0695344504492823, 0.05514430347830057, 0.04463017117814161, 0.07163380068959668, 0.02622719832288567, 0.017200433867401443, 0.013239575946499826, 0.05897365932469256, 0.03779491315071937, 0.05472408091009129, 0.05937668633123394, 0.0316044515784597, 0.017382569894834887, 0.05565440013015177, 0.025682786617835518, 0.04096017299161758, 0.04740106116514653, 0.02917379362770589, 0.020501584658632055, 0.05096813831187319, 0.06432965747080743, 0.04347371213953011, 0.03908769358531572, 0.062237023666966707, 0.02313552984560374, 0.03667291945021134, 0.025617243845772464, 0.06993261267780326, 0.06695802541798912, 0.043412566592451185, 0.0547875530901365, 0.023644474313186947, 0.06538244590046816, 0.047335574054159224, 0.0772927732032258, 0.06971616530790925, 0.3437125455820933, 0.3355082811322063, 15.487026572227478, 116.44242614507675, 98.73701021075249, 97.38405480980873, 86.07532203197479, 64.15935963392258, 56.647029742598534, 107.76033282279968, 83.55494767427444, 53.63885655999184, 27.84011621028185, 0.1391423141467385, 0.117466154624708, 0.5225737276487052, 0.5960645747836679, 0.6839111703447998, 1.3007098669186234, 3.031064816750586, 4.2936584539711475, 1.8267226475290954, 1.3361945003271103, 23.686654083430767, 79.39202785491943, 94.06938627362251, 89.39180687069893, 92.70419552922249, 92.02915415167809, 94.61992353200912, 90.8011968433857, 89.76700633764267, 97.45698049664497, 91.70852735638618, 80.87663859128952, 67.6647399365902, 64.00242045521736, 63.102020770311356, 79.25447523593903, 84.14443284273148, 86.09206393361092, 84.61013585329056, 82.49958470463753, 84.78461489081383, 84.94973123073578, 81.19437754154205, 86.77093550562859, 81.9960205256939, 75.48104211688042, 68.39863255620003, 64.85797494649887, 66.56862035393715, 66.92610517144203, 66.37481555342674, 61.12484626471996, 59.59613509476185, 60.55931881070137, 65.41174203157425, 61.731654703617096, 65.63057988882065, 65.22786229848862, 63.18131111562252, 78.02885100245476, 80.38516536355019, 79.53827440738678, 82.27968290448189, 81.99744924902916, 81.54553189873695, 78.87647151947021, 61.0637379437685, 30.38897953927517, 78.25354054570198, 75.96427738666534, 75.65434321761131, 67.88000598549843, 73.09124395251274, 79.93052735924721, 76.74652621150017, 68.95150288939476, 72.42416694760323, 81.22258722782135, 80.84297999739647, 78.12538862228394, 64.10642087459564, 60.633764415979385, 66.04019030928612, 60.75642563402653, 61.41398414969444, 60.28229847550392, 61.22862629592419, 66.02597147226334, 72.79555901885033, 73.0744868516922, 73.50300505757332, 74.83438521623611, 74.87964078783989, 73.60969573259354, 77.73847058415413, 77.89392784237862, 81.77160456776619, 81.9499821960926, 77.0639155805111, 65.40932536125183, 63.175193443894386, 67.43615940213203, 64.90609556436539, 71.91110327839851, 83.64266976714134, 84.01843160390854, 91.15067929029465, 61.95772737264633, 1.4950719312764704, 0.4371252190321684, 0.9155584964901209, 2.4758920446038246, 3.0244895070791245, 0.7815820793621242, 0.5076717585325241, 0.11046157931559719, 0.3360988525673747, 0.11034536641091108, 0.3644127066945657, 2.688351469114423, 25.924101322889328, 39.66525077819824, 81.58134117722511, 68.977782279253, 35.30389800667763, 27.795022130012512, 48.09776209294796, 70.38510516285896, 82.03852504491806, 99.22771587967873, 54.12277579307556, 0.6209185067564249, 0.1205039802880492, 0.10155091644264758, 0.06082608219003305, 0.061912556702736765, 0.020530411529762205, 0.046818890841677785, 0.05596168266492896, 0.03366872791957576, 0.03650920909421984, 0.034847707429435104, 0.004680577894760063, 0.017663368889770936, 0.013138378544681473, 0.059584172267932445, 0.05907420920266304, 0.03874456160701811, 0.10857126981136389, 0.024435243794869166, 0.053177949812379666, 0.020287950028432533, 0.05330096450052224, 0.07902355064288713, 0.02927672023361083, 0.10387067712144926, 0.16623597359284759, 0.15248145384248346, 0.17893049865961075, 0.259338280884549, 0.13883001840440556, 0.12992685864446685, 0.19123967096675187, 0.19493849045829847, 0.19661540281958878, 0.22003629215760157, 0.19362324150279164, 0.13367492705583572, 0.15026177919935435, 0.21076979173813015, 0.08142031656461768, 0.15668667037971318, 0.20166956208413467, 0.4463355685584247, 0.6274960725568235, 21.702765338122845, 134.65512245893478, 111.35845854878426, 111.18181362748146, 95.10040014982224, 73.09638127684593, 93.96189004182816, 168.22487711906433, 131.35688424110413, 74.2266534268856, 38.95503468811512, 0.9395236324053258, 0.26200170046649873, 0.538095241645351, 1.0961809731088579, 2.873856327496469, 1.677828705869615, 3.6361122876405716, 12.085052970796824, 17.573205828666687, 5.450088400393724, 22.357274517416954, 83.24269562959671, 98.93242612481117, 97.87142425775528, 98.489278703928, 95.38900226354599, 100.90588063001633, 92.84133777022362, 92.08519354462624, 101.13369360566139, 96.000245064497, 84.60928469896317, 70.50718501210213, 66.90530508756638, 68.22413071990013, 83.08270141482353, 89.2152151465416, 88.3839413523674, 87.44919911026955, 87.31423795223236, 88.75112324953079, 89.64870348572731, 85.97477182745934, 88.64784479141235, 85.95763474702835, 77.88111492991447, 73.71001794934273, 66.65787756443024, 69.76450726389885, 69.19340550899506, 70.63019961118698, 65.0811293721199, 63.54804463684559, 64.20966893434525, 68.555016964674, 64.42330107092857, 67.96114683151245, 66.72136455774307, 66.57455563545227, 81.20994910597801, 84.65868964791298, 85.75429245829582, 85.53959637880325, 87.91944667696953, 86.33917987346649, 84.27104204893112, 67.33856543898582, 36.23724192380905, 85.76153486967087, 82.26589724421501, 80.17557621002197, 73.38852480053902, 76.10225558280945, 84.29016262292862, 79.4257852435112, 70.58626636862755, 73.61091166734695, 84.28041994571686, 83.53641226887703, 80.4341447353363, 66.6581055521965, 62.9150328040123, 68.11577573418617, 65.06990477442741, 64.75042551755905, 64.04384583234787, 64.27638575434685, 72.43967771530151, 74.84165042638779, 76.87453374266624, 80.33886104822159, 78.66829589009285, 78.59163120388985, 76.71332359313965, 81.61807000637054, 84.92937952280045, 85.50656095147133, 86.32661014795303, 84.00273084640503, 68.99206191301346, 66.25595033168793, 72.39553928375244, 68.89015898108482, 75.2533583343029, 87.59206384420395, 88.81733849644661, 93.22793662548065, 62.28923678398132, 1.707463434431702, 2.3394622653722763, 4.648019364103675, 4.009940978139639, 4.795114696025848, 1.0210696910507977, 1.1671340907923877, 1.0955085279420018, 0.4982163815293461, 0.24123033770592883, 0.384838332538493, 5.422279117628932, 41.63720056414604, 56.19588755071163, 89.61690679192543, 81.01803660392761, 50.34019276499748, 28.200914449989796, 57.52127543091774, 81.49107322096825, 96.08345299959183, 111.73592269420624, 66.1816719174385, 0.7558926672209054, 0.19826141215162352, 0.1645857043331489, 0.17100105149438605, 0.1839425039361231, 0.09471206270973198, 0.09562413993990049, 0.20154265483142808, 0.13927799358498305, 0.12118904196540825, 0.10915142891462892, 0.09525133689749055, 0.11991231789579615, 0.10750546411145478, 0.12129122085752897, 0.2815677708713338, 0.18911720282630995, 0.17748957441654056, 0.15505876945098862, 0.12804285739548504, 0.19447360915364698, 0.2105452326941304, 0.19142584613291547, 0.155949717736803], [0.06424850362236612, 0.06998229946475476, 0.008895207647583447, 0.017481923059676774, 0.053912364310235716, 0.02185844954510685, 0.036610074384952895, 0.0211859598493902, 0.02305233880179003, 0.040456228744005784, 0.02941224753158167, 0.06678629244561307, 0.048182943428400904, 0.01763317090080818, 0.11848015841678716, 0.052801922138314694, 0.1073104128590785, 0.007466614188160747, 0.13778486667433754, 0.27571952843572944, 32.71636985242367, 106.93158209323883, 83.97632986307144, 78.35449352860451, 37.68053747713566, 20.879900492727757, 57.908508852124214, 125.53187280893326, 90.33579021692276, 52.072690799832344, 4.124290617182851, 0.15724191558547318, 0.15058298071380705, 0.04093973053386435, 0.22778501152060926, 0.4425627866294235, 0.12876665918156505, 0.7666685921140015, 2.11375888902694, 1.251177981030196, 15.806619822978973, 80.56760117411613, 92.15374946594238, 87.6159493625164, 84.44691181182861, 82.02628210186958, 85.21879479289055, 87.2922295331955, 90.29120340943336, 88.62145140767097, 88.27801063656807, 90.02414613962173, 81.91575363278389, 65.14434278011322, 58.33963751792908, 61.47293798625469, 62.911745980381966, 74.65254977345467, 73.26440066099167, 75.14722242951393, 74.31458070874214, 79.65734481811523, 76.71998083591461, 79.26004573702812, 81.31647258996964, 80.16268730163574, 74.24426168203354, 72.57618919014931, 68.68110179901123, 70.2441555261612, 69.17512848973274, 65.48136949539185, 58.83196949958801, 57.41910271346569, 59.50021684169769, 61.79438553750515, 59.900095984339714, 63.01374010741711, 60.50371639430523, 56.217181608080864, 58.11603091657162, 59.417563676834106, 60.24762533605099, 71.13922789692879, 70.37754356861115, 75.20779117941856, 70.02871468663216, 49.79308292269707, 23.603163063526154, 57.0453167706728, 71.98137670755386, 72.49186411499977, 64.34333056211472, 68.3362627029419, 74.10656467080116, 76.63994193077087, 67.9618763923645, 74.46259796619415, 71.10011279582977, 77.20868021249771, 77.46988579630852, 70.03685384988785, 58.85543704032898, 60.19616089761257, 58.40556778013706, 55.67854531109333, 55.24253010749817, 58.26385818421841, 61.49765186011791, 63.834378272295, 63.42087686061859, 66.66138857603073, 65.27637809515, 66.5924982726574, 69.01698857545853, 71.75806269049644, 73.57496559619904, 75.9914231300354, 75.55677965283394, 69.63692530989647, 57.685871198773384, 61.93614833056927, 59.449994936585426, 63.06920573115349, 72.28221416473389, 77.24252119660378, 80.78487351536751, 85.92016115784645, 75.26685521006584, 41.98935426771641, 0.46821040101349354, 0.5319695547223091, 1.165539720095694, 1.2111100810579956, 0.4017289011972025, 0.44125144137069583, 0.4691943700890988, 0.17551709432154894, 0.10369760086177848, 0.25207315979059786, 0.08194122259737924, 10.201924368739128, 22.40258328616619, 50.99528521299362, 43.987275660037994, 38.85636158287525, 32.45379254221916, 35.714450776576996, 52.97601632773876, 63.24305400252342, 74.57516312599182, 71.70570909976959, 5.462798718363047, 0.38724434562027454, 0.11209023723495193, 0.09915428410749882, 0.04498301786952652, 0.06306138646323234, 0.07659090188099071, 0.037705343347624876, 0.040681385216885246, 0.12100075909984298, 0.04279841341485735, 0.029122516789357178, 0.004135879999012104, 0.061933214383316226, 0.05280711717205122, 0.013984647684992524, 0.015024395652289968, 0.08218440212658606, 0.03283488047600258, 0.04517971297900658, 0.06103820283897221, 0.02590945892734453, 0.029465836159943137, 0.02681553589354735, 0.00880194751516683, 0.057456097201793455, 0.017072771479433868, 0.03159506341035012, 0.0447469629580155, 0.0495900925307069, 0.043429057113826275, 0.05760082342021633, 0.07045000835205428, 0.05124713759869337, 0.08686040004249662, 0.0356566298432881, 0.02881478711060481, 0.04020554981252644, 0.10881911744945683, 0.05551550719246734, 0.06301733999862336, 0.03628342179581523, 0.08207455684896559, 0.21964963321806863, 45.50867222249508, 123.60305830836296, 95.82456529140472, 89.27211329340935, 49.68290403485298, 33.459047600626945, 57.7319323271513, 131.09491109848022, 95.79870387911797, 51.48595668375492, 6.177176535129547, 0.3470005269628018, 0.11582053863094188, 0.8463240147102624, 0.2185966444085352, 1.2926827976480126, 1.1872201692312956, 3.0303571047261357, 0.6107330939266831, 1.5351753355935216, 18.41242879629135, 85.50149202346802, 95.77216610312462, 92.12879240512848, 88.19819211959839, 84.99975174665451, 88.30934375524521, 92.4004778265953, 92.06854283809662, 91.25839591026306, 89.92597460746765, 92.85360351204872, 85.84560915827751, 67.92617350816727, 61.5490061044693, 64.67458918690681, 65.5374164879322, 78.55732664465904, 77.08452567458153, 79.61660340428352, 77.1330338716507, 80.55737972259521, 80.63125535845757, 81.85357376933098, 84.86248791217804, 83.21852132678032, 77.51126557588577, 78.0140469968319, 71.57311901450157, 74.32849556207657, 73.38404104113579, 68.8287390768528, 62.72913917899132, 60.04503920674324, 61.94234199821949, 64.72479969263077, 62.137860506772995, 63.42988237738609, 64.3363769352436, 59.53654669225216, 59.87087555229664, 62.779250890016556, 63.53402718901634, 71.49203136563301, 73.7564666569233, 77.70643070340157, 73.09156313538551, 58.009610027074814, 27.5740734860301, 67.13266968727112, 76.49146869778633, 77.87994459271431, 68.55580732226372, 71.20898455381393, 77.90864065289497, 79.23323437571526, 68.26201468706131, 74.04787302017212, 71.84140741825104, 79.61158767342567, 81.0320882499218, 74.15423691272736, 61.19078032672405, 64.08644154667854, 62.64213904738426, 58.854806274175644, 57.46321074664593, 59.28560055792332, 65.19458368420601, 66.27816393971443, 67.03465014696121, 69.78938832879066, 68.40102642774582, 71.6010931134224, 71.5556551516056, 75.92475190758705, 77.12481871247292, 79.49674263596535, 79.43406879901886, 74.6066178381443, 61.54361039400101, 65.49895495176315, 62.88880281150341, 67.50734478235245, 77.10661768913269, 81.4918103814125, 85.45803755521774, 88.73637244105339, 78.43023106455803, 49.27363559603691, 1.7355819256044924, 0.2941204863600433, 0.6791111966595054, 1.3143168180249631, 1.1579218413680792, 0.5838266189675778, 0.7336608914192766, 0.4893318942049518, 0.14303355768788606, 0.42728255968540907, 0.16933303006226197, 12.121849246323109, 26.165891848504543, 50.94539389014244, 55.800024792551994, 33.526319190859795, 32.09860660135746, 46.99424050748348, 59.04429830610752, 72.79309675097466, 81.49621054530144, 94.27435487508774, 11.005016975104809, 0.6925956637132913, 0.18061873619444668, 0.07997387074283324, 0.040270346726174466, 0.1035521696030628, 0.04859129163378384, 0.027287714365229476, 0.053706566759501584, 0.06471978966146708, 0.024177243576559704, 0.0454256829834776, 0.1333908032393083, 0.02994122256495757, 0.04515620916208718, 0.04174004774540663, 0.00869635845447192, 0.03406429634196684, 0.07569922629045323, 0.0605261394957779, 0.03846728410280775, 0.026099522947333753, 0.056873266366892494, 0.05328079292667098, 0.19199280242901295, 0.09112601997912861, 0.13801842054817826, 0.075454851903487, 0.11596766940783709, 0.16040135698858649, 0.17810117831686512, 0.10708089626859874, 0.17756948887836188, 0.19647763052489609, 0.20356919296318665, 0.13078635471174493, 0.13369736960157752, 0.17266562936129048, 0.3099013364408165, 0.16043307638028637, 0.1452791184419766, 0.10202789475442842, 0.2831935492577031, 0.337848539929837, 57.34076611697674, 138.62764209508896, 109.96831834316254, 105.71778282523155, 56.6249643266201, 33.35000105202198, 74.76497054100037, 131.59238040447235, 99.75619912147522, 80.21867349743843, 8.298985529690981, 0.4239837726345286, 0.24572971189627424, 1.4255456370301545, 0.941435523563996, 2.1562344348058105, 1.4564389293082058, 7.167502669617534, 9.006474316120148, 10.514369253069162, 17.982926443219185, 87.87264078855515, 101.91414892673492, 97.20502361655235, 91.69707477092743, 88.65588515996933, 93.3862741291523, 94.95104536414146, 96.62809297442436, 96.22854441404343, 91.4032593369484, 96.40746921300888, 90.71351274847984, 71.79779335856438, 65.05367204546928, 68.56920540332794, 69.64805111289024, 82.07006335258484, 80.51589354872704, 84.12933245301247, 81.88625201582909, 87.59566605091095, 84.69942346215248, 85.30644848942757, 87.82746881246567, 87.70819321274757, 82.54230201244354, 81.31903365254402, 74.14957836270332, 76.0002538561821, 77.08394810557365, 73.30453410744667, 66.43134132027626, 62.31229014694691, 63.60806241631508, 67.15244382619858, 65.14146253466606, 66.73933759331703, 66.89063787460327, 61.940803080797195, 64.75997820496559, 66.98955416679382, 68.23236867785454, 77.68565341830254, 75.4282933473587, 82.06995695829391, 76.84204548597336, 60.18334798514843, 33.31448815762997, 73.51539239287376, 80.41408181190491, 80.27186304330826, 72.73014932870865, 74.8504963517189, 82.15315729379654, 83.53648066520691, 74.5531091094017, 76.35937258601189, 76.9561305642128, 83.48795726895332, 83.91599670052528, 74.2898440361023, 64.39017444849014, 67.38040879368782, 64.48215991258621, 62.60428547859192, 59.863994121551514, 63.5178704559803, 67.79112115502357, 70.61145901679993, 70.79071819782257, 74.98619467020035, 72.75253772735596, 73.88668566942215, 76.53755262494087, 79.4495339691639, 82.54858687520027, 84.86841559410095, 83.10247555375099, 77.79399320483208, 63.63407202064991, 68.87910917401314, 65.25671795010567, 70.90216621756554, 79.7063697874546, 84.8321807384491, 85.04662603139877, 93.18231627345085, 77.39316031336784, 49.41302351653576, 1.4963087649084628, 4.125179769471288, 3.1130860280245543, 3.6009128764271736, 1.1674157506786287, 1.258566090837121, 1.9329159054905176, 0.8946702454704791, 0.20876424154266715, 0.8683987520635128, 0.2868600853253156, 20.488101616501808, 40.149580389261246, 66.25626191496849, 56.04748651385307, 49.91161376237869, 46.12702064216137, 53.44874896109104, 70.71369633078575, 82.40076720714569, 93.31793859601021, 106.6810691356659, 11.663355398923159, 0.8809994696639478, 0.3107215283671394, 0.21543752955039963, 0.20031772524816915, 0.2522153255995363, 0.09850380651187152, 0.1404909003758803, 0.12686202622717246, 0.16871489526238292, 0.2320350834634155, 0.1647022066754289, 0.15817394916666672, 0.16601849463768303, 0.23600897256983444, 0.1297127638827078, 0.08837157598463818, 0.16823051031678915, 0.1824034083983861, 0.14475755189778283, 0.1597487271646969, 0.1108169493090827, 0.21109391731442884, 0.13348901906283572], [0.06487180377007462, 0.046917203144403175, 0.01381040161504643, 0.043776037127827294, 0.010193722100666491, 0.04747251143271569, 0.035988993258797564, 0.028201179411553312, 0.05427784606581554, 0.11796403181506321, 0.011272657320660073, 0.05331970372935757, 0.03260477758885827, 0.02733483888732735, 0.02024661240284331, 0.08053773970459588, 0.007500130968765006, 0.0694516787189059, 0.089292128541274, 0.5035949335433543, 68.2775254547596, 89.93953987956047, 85.88131964206696, 69.79582518339157, 45.415987595915794, 41.19716137647629, 50.14696553349495, 36.430659145116806, 27.821975983679295, 22.304083071649075, 0.017141141834144946, 0.07023140133242123, 0.045190262608230114, 0.302535105147399, 0.6099028384778649, 0.6424691097345203, 0.8936279732733965, 0.6073816737625748, 0.4158919880865142, 8.586127571761608, 75.35316377878189, 93.65676641464233, 88.87767165899277, 87.47517451643944, 78.11553195118904, 71.90864101052284, 74.22756537795067, 80.7794626057148, 85.01023158431053, 87.86894738674164, 86.27825394272804, 86.40749260783195, 82.23710238933563, 66.629888266325, 58.946947529911995, 62.59901136159897, 61.25029653310776, 61.89083956182003, 66.8610754609108, 67.78781533241272, 67.99639374017715, 69.2582680284977, 70.15040695667267, 74.17839601635933, 75.594222843647, 78.972849547863, 77.39813804626465, 78.75029549002647, 73.64252597093582, 74.78409871459007, 67.54747062921524, 66.27913668751717, 59.20978702604771, 55.96259906888008, 57.36123561859131, 58.66661377251148, 58.080860003829, 60.401015505194664, 59.60500381886959, 57.49703273177147, 57.96412646770477, 61.81016609072685, 58.00532005727291, 64.57495093345642, 64.08497482538223, 71.08303651213646, 70.48332989215851, 67.37328037619591, 27.78092298656702, 66.81963488459587, 77.16899514198303, 71.51858434081078, 65.18294110894203, 62.31843821704388, 69.86448749899864, 71.06348276138306, 61.833390444517136, 63.62114891409874, 67.94279381632805, 70.53905010223389, 73.18482533097267, 75.89887529611588, 65.5375836789608, 55.95991261303425, 56.58792771399021, 53.86913180351257, 53.1401751190424, 54.11912798881531, 55.8248982578516, 58.831011950969696, 59.99414473772049, 58.8813516497612, 55.912016183137894, 60.874899476766586, 60.67018926143646, 69.47970494627953, 74.27377849817276, 74.24811467528343, 75.9618379175663, 74.19323801994324, 59.047106355428696, 57.439070641994476, 60.77364630997181, 71.69181704521179, 75.58185070753098, 78.45235347747803, 83.21551188826561, 72.98025190830231, 76.6291581094265, 78.57026115059853, 42.1621385961771, 0.5941201478708535, 2.782884221524, 2.0745775289833546, 0.7248693506699055, 0.04268176264304202, 0.30317807220853865, 0.2817577013047412, 0.21077703509945422, 0.12015130429062992, 0.12497472984250635, 0.5513704824261367, 20.62643699347973, 29.613249264657497, 31.02469302713871, 28.062586672604084, 35.566391721367836, 18.388482481241226, 45.38551703095436, 66.70931160449982, 64.64753463864326, 87.24879786372185, 34.52215455472469, 0.5634153017308563, 0.08968810885562561, 0.06625135240028612, 0.0018247783282276941, 0.07529770955443382, 0.026146691998292226, 0.02652904462593142, 0.025585891817172524, 0.02704213955439627, 0.016541018958378118, 0.01659742403717246, 0.09621444420190528, 0.06905238842591643, 0.06624045767239295, 0.06493749126093462, 0.037181761872489005, 0.08063536180998199, 0.026121388473256957, 0.015310783019231167, 0.05806184184621088, 0.0345733391441172, 0.01843729718530085, 0.03306797421828378, 0.0979194616957102, 0.09430917300051078, 0.0689418232650496, 0.026306789950467646, 0.060741525594494306, 0.026122342133021448, 0.026258040124957915, 0.058411534409970045, 0.0610678405064391, 0.05505089677171782, 0.06617252889554948, 0.04944422340486199, 0.06668052155873738, 0.03744018140423577, 0.0765094808593858, 0.042621014144970104, 0.031772562870173715, 0.03848339612886775, 0.06526569864945486, 1.2981074815616012, 88.52720886468887, 101.65434926748276, 97.14403688907623, 84.74773406982422, 59.538249000906944, 45.52435778081417, 40.52533842623234, 41.92756198346615, 38.51042814552784, 26.561682410538197, 0.04961950013239402, 0.0832094787620008, 0.19959269149694592, 0.6450828351080418, 0.9228521457407624, 1.7214481090195477, 2.029678663238883, 1.1816883785650134, 0.6835551175754517, 10.66411066800356, 79.47617053985596, 99.60404008626938, 93.91180112957954, 91.56599700450897, 82.21937254071236, 75.57757213711739, 77.45492219924927, 86.15455538034439, 89.37159955501556, 90.92921957373619, 89.47158738970757, 90.75203508138657, 86.11341118812561, 70.32224893569946, 63.487859666347504, 65.25677874684334, 65.01898750662804, 66.62269905209541, 68.8055831193924, 70.75999304652214, 71.6926757991314, 73.26769888401031, 72.90586709976196, 78.03914085030556, 80.33555522561073, 82.69949957728386, 81.66188925504684, 80.34164249897003, 78.21241155266762, 77.16289266943932, 70.8406475186348, 68.68033424019814, 60.39506122469902, 59.86007273197174, 59.30656783282757, 61.3715860247612, 60.435977429151535, 61.534262895584106, 62.078838273882866, 59.86443109810352, 60.64823403954506, 62.38783769309521, 61.35363958775997, 67.14230597019196, 68.62854301929474, 74.48746383190155, 73.91491815447807, 71.37782469391823, 29.859312660992146, 73.21843072772026, 81.39003664255142, 76.24698981642723, 67.74102464318275, 66.39016672968864, 72.99786776304245, 73.83482605218887, 66.08625903725624, 67.98098176717758, 71.71938836574554, 72.40908935666084, 77.01558217406273, 78.1953276693821, 68.75701412558556, 59.32834066450596, 58.32357197999954, 56.72744482755661, 56.87061354517937, 56.773445159196854, 58.51540468633175, 63.78560408949852, 61.939507350325584, 60.790790989995, 60.21691158413887, 63.938469886779785, 63.28922152519226, 71.2261064350605, 78.70638504624367, 80.00938072800636, 77.70991891622543, 76.55015274882317, 63.19275230169296, 61.36408142745495, 65.10344177484512, 74.80500519275665, 80.44762641191483, 83.12361761927605, 87.05416470766068, 74.47076752781868, 79.43146973848343, 83.40264424681664, 50.84330856800079, 1.4880508580245078, 0.7583754777442664, 4.587360369041562, 1.6622630786150694, 0.9635850694030523, 0.3325891471467912, 0.6650731468107551, 0.430362056940794, 0.36125748069025576, 0.22764588851714507, 0.3925526310922578, 23.731183893978596, 33.58404189348221, 36.55058830976486, 25.775094218552113, 35.63790388405323, 33.31755839288235, 55.9136500954628, 73.68703678250313, 73.08017134666443, 96.6325843334198, 49.4028552621603, 0.5311792565044016, 0.03625132761953864, 0.0466647393477615, 0.017410858708899468, 0.07253583666170016, 0.027656118327286094, 0.08186867766198702, 0.05766832546214573, 0.02311934546014527, 0.010042261819762643, 0.05463817360578105, 0.062346201011678204, 0.04155117116170004, 0.03517952536640223, 0.09388841237523593, 0.028540622915897984, 0.028078348404960707, 0.0400528269528877, 0.04342588072177023, 0.05733753911044914, 0.02176625253923703, 0.013764329087280203, 0.07415902495267801, 0.2827405126299709, 0.12898412329377607, 0.18341275892453268, 0.14584659424144775, 0.12682822882197797, 0.13291162817040458, 0.12262768781511113, 0.11409008773625828, 0.21609599265502766, 0.1586097085964866, 0.20359026995720342, 0.1827676544780843, 0.21608926879707724, 0.09456936997594312, 0.09711520368000492, 0.2036669634981081, 0.2139563363743946, 0.11994017811957747, 0.2517073997296393, 1.6180093470029533, 102.86908328533173, 116.38774707913399, 113.36407452821732, 92.70409673452377, 64.72526326775551, 57.93009549379349, 74.53602522611618, 53.470343202352524, 50.23486241698265, 36.54378667473793, 0.3257176314946264, 0.18798272620188072, 0.30731441744137555, 1.5004793973639607, 2.0910907303914428, 2.0632235007360578, 3.524356009438634, 3.753898129798472, 4.118343461304903, 12.057599443942308, 80.78095972537994, 103.38064983487129, 98.32973286509514, 96.26512885093689, 87.26123839616776, 81.0456383228302, 80.71555003523827, 90.81546887755394, 95.48886090517044, 96.14902228116989, 91.54854834079742, 95.91262936592102, 91.61865457892418, 72.71987468004227, 63.8712514936924, 69.49228227138519, 67.97373175621033, 69.95959639549255, 73.79470780491829, 75.77533632516861, 76.03717267513275, 76.5942531824112, 76.26225739717484, 80.07451683282852, 84.22473013401031, 85.94051286578178, 84.94072571396828, 83.47728744149208, 80.89389726519585, 80.98220452666283, 75.3016385436058, 74.80986133217812, 65.1905483007431, 64.16567489504814, 63.0775348842144, 65.07707118988037, 62.86417253315449, 65.0174143910408, 66.98470562696457, 63.09958890080452, 65.96078217029572, 68.3251217007637, 64.80353906750679, 69.73598599433899, 70.70926576852798, 77.34709918498993, 77.35088378190994, 72.97039523720741, 35.30530393123627, 74.85972225666046, 86.18558451533318, 82.22296714782715, 71.55294209718704, 70.09847894310951, 77.42482021450996, 79.94771003723145, 71.21163681149483, 72.32205882668495, 75.5131807923317, 76.64162904024124, 80.1158282160759, 83.87212425470352, 71.21726050972939, 62.81872697174549, 61.787230521440506, 61.35177008807659, 58.81850302219391, 59.7478723526001, 62.62964531779289, 66.91122516989708, 65.36354541778564, 62.638711631298065, 62.378797978162766, 68.2084147632122, 66.16008147597313, 74.88013476133347, 81.9165287911892, 81.60077333450317, 83.64463806152344, 81.94343134760857, 66.08722418546677, 64.26773741841316, 67.91339859366417, 78.50279197096825, 82.31126680970192, 87.52370551228523, 86.96647301316261, 79.31716427206993, 81.87229916453362, 85.40091902017593, 50.70784963667393, 1.130657591857016, 8.273359704762697, 7.668934212997556, 3.6493678763508797, 1.3107186486013234, 1.0172456712462008, 1.435644426383078, 1.2439708365127444, 0.39813672832679003, 0.49187431402970105, 1.0808147164061666, 34.56916183233261, 47.269060760736465, 43.899029195308685, 40.9571548551321, 48.56669493019581, 30.438281893730164, 63.587649911642075, 85.10635882616043, 83.69595050811768, 109.76090267300606, 54.28824171423912, 0.8167189126834273, 0.12659151339903474, 0.16086310643004254, 0.1010529205086641, 0.21399492805358022, 0.0864137161988765, 0.17483295290730894, 0.15637360280379653, 0.12843960954342037, 0.09438110937480815, 0.16068368480773643, 0.30920229270122945, 0.08322131601744331, 0.20267445972422138, 0.29364868823904544, 0.14547841477906331, 0.13341066311113536, 0.11895218660356477, 0.12994170159799978, 0.21720808610552922, 0.07356141795753501, 0.16302700125379488, 0.21491492399945855], [0.05139963781402912, 0.06276023777900264, 0.030037443866604008, 0.08067700371611863, 0.05417804204626009, 0.023985390980669763, 0.02718810887017753, 0.13248898991150782, 0.03454778699961025, 0.04539618261333089, 0.06819115573307499, 0.03515092670568265, 0.06181261167512275, 0.09816054094699211, 0.02522552531445399, 0.021582506051345263, 0.06778466660762206, 0.18008496874244884, 0.31158271653112024, 5.188699001446366, 95.82409411668777, 81.66131928563118, 94.17076483368874, 57.233984246850014, 35.89625582098961, 35.38297936320305, 71.04956030845642, 80.04218816757202, 50.614283457398415, 4.521918380632997, 0.13272322656121105, 0.2649758127517998, 0.2163785876473412, 0.24180988082662225, 0.23198736336780712, 1.1619525938294828, 0.8211135549936444, 1.5507364505901933, 1.0146007756702602, 54.70114655792713, 97.88708701729774, 87.75054574012756, 85.33493936061859, 75.86006417870522, 71.21758729219437, 68.86565789580345, 63.40815134346485, 64.64631110429764, 73.76921117305756, 79.51718553900719, 81.27883940935135, 82.13788971304893, 74.65337052941322, 63.68927925825119, 61.926105469465256, 59.81007881462574, 60.64944997429848, 59.772848412394524, 59.315869733691216, 60.43091610074043, 62.95165903866291, 65.15483781695366, 66.03648170828819, 69.56237331032753, 73.03762122988701, 73.60754504799843, 78.07876512408257, 78.26588988304138, 75.89672461152077, 67.54198372364044, 68.0366563796997, 63.65656301379204, 54.93837162852287, 56.906962394714355, 56.812917441129684, 57.1395593136549, 60.01472443342209, 56.65074214339256, 57.33775667846203, 56.866726353764534, 68.65881219506264, 72.96042457222939, 71.64324045181274, 71.08961775898933, 68.26262265443802, 69.2289412021637, 72.49735862016678, 67.83549517393112, 38.625219985842705, 75.01549869775772, 68.73375177383423, 63.71251121163368, 61.471490263938904, 62.70738534629345, 69.63569417595863, 70.13007804751396, 66.51426047086716, 62.95427709817886, 68.63094449043274, 65.24048522114754, 71.53740853071213, 73.02314400672913, 68.21074023842812, 57.921637147665024, 53.812408447265625, 54.66050013899803, 54.44467552006245, 53.33769232034683, 54.172112345695496, 54.431022852659225, 55.87603211402893, 55.90122476220131, 57.5480791926384, 55.93132294714451, 61.61550633609295, 65.27407541871071, 75.08934393525124, 72.19652876257896, 74.15167585015297, 70.51893398165703, 57.11904801428318, 56.96508027613163, 58.94201159477234, 74.14481341838837, 80.2992595732212, 81.25802412629128, 73.90344277024269, 68.9579625427723, 81.31299957633018, 76.62646785378456, 84.60878312587738, 40.794553980231285, 0.4939494183054194, 0.6936966546345502, 1.1569227324798703, 0.935982697410509, 0.2609761414350942, 0.21448424085974693, 0.2262361641624011, 0.24808070214930922, 0.1250643515959382, 0.21707878913730383, 4.62993043474853, 27.94764094054699, 39.958937019109726, 47.624220103025436, 36.901959255337715, 17.42411132901907, 37.64294609427452, 53.71062330901623, 63.11100348830223, 67.87448108196259, 71.01293787360191, 7.438150746747851, 0.3281215962488204, 0.10598176071653143, 0.0552108926785877, 0.06373109310516156, 0.03833148963167332, 0.035469074282445945, 0.10925477297860198, 0.04603475987096317, 0.0310606261700741, 0.010504286783543648, 0.10135804710444063, 0.03834860726783518, 0.06109071349783335, 0.04042575244966429, 0.07308544154511765, 0.04010337092040572, 0.05514405856956728, 0.043223882967140526, 0.05041802134655882, 0.009337833798781503, 0.07433921840856783, 0.01792925628251396, 0.09185669405269437, 0.029488716572814155, 0.06129044770204928, 0.03875892216456123, 0.03968623197579291, 0.025392894458491355, 0.04216482338961214, 0.03464910128968768, 0.022442169101850595, 0.01788136549293995, 0.010217240760539426, 0.08669306800584309, 0.035626153548946604, 0.02033550128544448, 0.06447748586651869, 0.06262440248974599, 0.09382455798913725, 0.21926463668933138, 0.14344930881634355, 9.607883244752884, 116.07912003993988, 91.18332713842392, 103.26303094625473, 65.95213383436203, 46.41890957951546, 45.14288865029812, 76.83835968375206, 82.13214442133904, 55.54828830063343, 4.973676614463329, 0.058194437660858966, 0.22530231974087656, 0.9715721220709383, 0.611420797649771, 0.554147717775777, 3.284236444160342, 2.8902113623917103, 0.9600138547830284, 1.9551698863506317, 60.516137927770615, 101.2486070394516, 92.41014450788498, 89.77911248803139, 80.15628844499588, 76.638672798872, 72.51737594604492, 66.36897146701813, 68.79319578409195, 77.0618636906147, 81.36953294277191, 84.55218896269798, 83.69645968079567, 79.11717340350151, 67.27180302143097, 64.17135179042816, 62.20508649945259, 62.786709889769554, 63.70462663471699, 63.216311037540436, 63.037089854478836, 64.24543261528015, 66.19742587208748, 69.8557859659195, 71.87827304005623, 75.05687087774277, 76.61409571766853, 80.28127893805504, 83.01714733242989, 79.62712123990059, 70.94336360692978, 73.02722498774529, 66.58229202032089, 58.23593728244305, 59.552338644862175, 62.14645944535732, 60.63563011586666, 62.15608812868595, 60.97025156021118, 59.78881895542145, 60.8821114897728, 72.15235233306885, 77.73286208510399, 76.54148161411285, 74.0260697901249, 71.99944093823433, 72.57649317383766, 74.37763452529907, 70.23600116372108, 43.078615218400955, 77.60575130581856, 72.31401085853577, 67.05426469445229, 64.71216157078743, 68.25293317437172, 72.89765194058418, 73.83284255862236, 70.32547876238823, 68.69266837835312, 70.95508217811584, 68.1429822742939, 73.682119846344, 75.67398816347122, 70.41324645280838, 60.004894360899925, 57.31287181377411, 57.02832788228989, 57.16568671166897, 55.8583402633667, 57.42705188691616, 56.8797292560339, 59.28732946515083, 57.10222251713276, 60.01870281994343, 59.701298251748085, 64.00525510311127, 70.04625454545021, 77.24221721291542, 74.45022583007812, 78.456791639328, 74.7353321313858, 61.28888726234436, 60.0233119726181, 63.26432526111603, 79.48354974389076, 82.23620563745499, 84.44388717412949, 77.92276829481125, 70.4323822259903, 83.60410943627357, 80.18770515918732, 89.9340757727623, 51.013269647955894, 1.0674177040345967, 0.2765597583493218, 1.4041913766413927, 1.3991991570219398, 0.6002328917384148, 1.0100540821440518, 1.3176763127557933, 0.6115362758282572, 0.5884437274653465, 0.2305740470183082, 4.695940967649221, 32.90835455060005, 37.76192910969257, 41.655887961387634, 34.23863656818867, 27.27232787758112, 53.111197873950005, 57.271989807486534, 72.60986298322678, 75.28035968542099, 85.7703123986721, 13.69827825576067, 0.5874088173732162, 0.09840561295277439, 0.06222484131285455, 0.0746887773857452, 0.05671317398082465, 0.041050132422242314, 0.06298314183368348, 0.07926068909000605, 0.06490236541139893, 0.029465604238794185, 0.0128940802278521, 0.030711976323800627, 0.02583328117907513, 0.012119080456614029, 0.06832191473222338, 0.0941846777277533, 0.01583111017680494, 0.028604965264094062, 0.03287806233856827, 0.01692418609309243, 0.025007426665979438, 0.05171120254090056, 0.15688307234086096, 0.14680273277917877, 0.16960140550509095, 0.1425758603727445, 0.13221988716395572, 0.07980051246704534, 0.0858098232129123, 0.3724257048452273, 0.10989968446665443, 0.11507839095429517, 0.12375481717754155, 0.14480144251137972, 0.18804448773153126, 0.1849754696013406, 0.11296344819129445, 0.172252579650376, 0.1671144537976943, 0.4273042007116601, 0.6848216964863241, 12.181866075843573, 134.20676171779633, 103.6089339852333, 117.03992128372192, 76.80347755551338, 50.62107369303703, 51.04373641312122, 101.67686685919762, 103.3272323012352, 77.73221611976624, 7.897858154028654, 0.22297515242826194, 0.7102869206573814, 1.4505366585217416, 3.199054514989257, 0.973997995024547, 4.0571244712919, 5.378384348005056, 7.084484724327922, 2.2370427986606956, 64.43405449390411, 106.31166815757751, 95.60383513569832, 94.52115163207054, 84.94704097509384, 80.31144171953201, 75.5232198536396, 70.02958104014397, 69.43828716874123, 80.34371718764305, 86.3930381834507, 89.1078633069992, 88.05158838629723, 81.25150367617607, 71.3858650624752, 67.63908371329308, 65.8347125351429, 66.76788926124573, 66.25211253762245, 68.42988967895508, 67.09047675132751, 67.35262468457222, 71.11439242959023, 73.9103128015995, 75.97121581435204, 79.38306033611298, 82.01922968029976, 85.3330546617508, 85.67053735256195, 84.23999771475792, 75.54252281785011, 75.59128180146217, 71.84632435441017, 60.415500327944756, 63.31302344799042, 63.95120680332184, 64.50566545128822, 66.04106426239014, 63.606052324175835, 62.988828644156456, 63.750843554735184, 75.44774070382118, 80.22092297673225, 77.67389684915543, 78.22773233056068, 76.12456038594246, 77.11071386933327, 77.5250968337059, 73.13187137246132, 48.18989954888821, 82.2805568575859, 76.82613953948021, 70.9622409939766, 67.73462578654289, 70.39287954568863, 77.23324969410896, 76.52087911963463, 71.57799795269966, 68.78865882754326, 73.5142220556736, 69.24486994743347, 77.46252939105034, 78.38028654456139, 73.36030751466751, 63.25700305402279, 60.213647559285164, 61.5757604688406, 60.90341694653034, 60.02110429108143, 60.02393513917923, 59.7578240185976, 64.55774545669556, 60.73810301721096, 64.85480591654778, 62.058095186948776, 66.71840071678162, 72.0082488656044, 81.39870017766953, 78.90294849872589, 81.97959780693054, 78.62809404730797, 64.75687757134438, 65.2084681391716, 66.9089224934578, 81.44115909934044, 88.6429962515831, 86.49116411805153, 78.744056224823, 72.56251752376556, 88.24480801820755, 82.67945945262909, 93.80575641989708, 47.56692677736282, 0.9216661343816668, 4.3740773387253284, 7.338168136775494, 2.636082423850894, 1.0589781193993986, 1.4252404659055173, 3.3079728204756975, 2.3884221632033587, 0.7357267336919904, 0.5349779839161783, 7.8606258518993855, 46.60661570727825, 57.34698258340359, 68.49896237254143, 48.985204473137856, 26.07983596622944, 53.20373810827732, 72.34165817499161, 82.94438883662224, 85.6043753027916, 97.0351955294609, 13.337494265288115, 0.7156014698557556, 0.31375717953778803, 0.21252854814520106, 0.2741620276356116, 0.33139417064376175, 0.21932960429694504, 0.21155001159058884, 0.15254097408615053, 0.17692482972051948, 0.0733762001618743, 0.21327877038856968, 0.20746560185216367, 0.1633018779102713, 0.14609631209168583, 0.18088877404807135, 0.21849646931514144, 0.16609521786449477, 0.09416546352440491, 0.15446598641574383, 0.12864135496784002, 0.15680686861742288, 0.12295308246393688], [0.0719457476225216, 0.058974776256945916, 0.10466458217706531, 0.07895942166214809, 0.031990268180379644, 0.0590670252131531, 0.018764617707347497, 0.03950857666495722, 0.06948853377252817, 0.06372372357873246, 0.0560772907192586, 0.04448174164281227, 0.01493173109338386, 0.07466713635949418, 0.021487336744030472, 0.062300380814122036, 0.10140685815713368, 0.18799467477947474, 0.5187231092713773, 28.828340582549572, 92.89806112647057, 76.63519218564034, 73.39042469859123, 53.41366924345493, 39.05241586267948, 39.9772672355175, 44.87870782613754, 55.89585565030575, 23.432930298149586, 0.06935187469935045, 0.2854047337314114, 0.2015310773276724, 0.3453901852481067, 0.9785761556122452, 0.40151854685973376, 1.1349906655959785, 0.8804992621298879, 0.36931076261680573, 24.94029801338911, 89.9822647869587, 91.25073552131653, 83.6151972413063, 74.37331035733223, 69.27611947059631, 68.95499870181084, 69.11883071064949, 66.28013223409653, 61.74824841320515, 57.4168798327446, 61.09488487243652, 69.77720618247986, 69.53093379735947, 67.98283606767654, 63.90436291694641, 60.51697388291359, 59.033085107803345, 60.53021617233753, 58.833523616194725, 59.37398761510849, 63.0479496717453, 61.487939581274986, 63.14792610704899, 61.57131850719452, 62.92739734053612, 67.43712455034256, 70.80022528767586, 75.33954530954361, 75.39631426334381, 72.61610984802246, 70.06361961364746, 67.04300969839096, 57.24925942718983, 54.92576390504837, 52.61002756655216, 55.46050541102886, 62.58489891886711, 66.00813522934914, 60.98339885473251, 56.999685019254684, 56.02808475494385, 71.41333758831024, 74.14121881127357, 74.38459575176239, 72.91500940918922, 72.3034094274044, 68.61132994294167, 70.65347716212273, 65.41972920298576, 44.64858457446098, 68.09226259589195, 65.1503312587738, 63.22231091558933, 59.65527132153511, 65.44683694839478, 67.99979835748672, 71.24482423067093, 71.74355506896973, 71.07322543859482, 67.92903855443001, 65.61108693480492, 67.1646335721016, 73.1957383453846, 66.63890138268471, 57.84526504576206, 55.63346453011036, 53.14534284174442, 52.38420948386192, 54.11231875419617, 52.15436741709709, 52.96014077961445, 53.31180050969124, 57.17577137053013, 59.29605759680271, 62.093140706419945, 64.47462871670723, 66.5636958181858, 72.43403121829033, 68.43353748321533, 75.84215953946114, 68.60962763428688, 56.72468237578869, 57.69773796200752, 62.6703867316246, 75.82332015037537, 75.74457317590714, 73.74933063983917, 71.75249978899956, 75.99306464195251, 75.64931988716125, 77.78855189681053, 74.81774970889091, 88.03154066205025, 38.426000475883484, 0.12377584964269772, 1.7285132361575961, 0.6278853735420853, 0.3887045063311234, 0.19000564265297726, 0.8461198350414634, 1.6392990108579397, 0.5683058768045157, 0.05569305118115153, 0.05331869069777895, 12.527913507074118, 32.11515471339226, 48.370036482810974, 43.47885154187679, 29.95433796197176, 21.013790108263493, 47.00036197900772, 62.03454405069351, 61.5664167702198, 82.18749225139618, 40.31585946679115, 0.7153093605302274, 0.0858300986874383, 0.054047398080001585, 0.03017644070496317, 0.04450704145710915, 0.015063246155477827, 0.027149431844009086, 0.01637863890209701, 0.018416914099361748, 0.025335444806842133, 0.022394912848540116, 0.054969486882328056, 0.04005314607638866, 0.059120871737832204, 0.065075909224106, 0.09298541903262958, 0.07320026663364843, 0.04943106141581666, 0.010210849013674306, 0.061934245968586765, 0.045648434897884727, 0.07690409562201239, 0.04724003738374449, 0.035807311796816066, 0.04022299399366602, 0.0690241125994362, 0.04999249242246151, 0.040428424181300215, 0.012240825144544942, 0.03808590554399416, 0.05164575995877385, 0.06480332580395043, 0.044589071039808914, 0.00397797184632509, 0.06366419591358863, 0.03597502232878469, 0.04239911570039112, 0.15237409475957975, 0.09929804553394206, 0.23545552336145192, 0.5292076373007149, 39.50386583805084, 109.81280788779259, 85.62362506985664, 86.21214509010315, 65.54571524262428, 48.32942046225071, 37.11995355784893, 48.269828259944916, 65.13218343257904, 28.056128919124603, 0.026496555256017018, 0.3419835492968559, 0.922807379392907, 0.918257717275992, 2.0346958190202713, 1.4853340038098395, 4.523840127512813, 2.9255254799500108, 0.4348410665988922, 27.474800013005733, 95.6736221909523, 95.31036168336868, 89.15505677461624, 77.96683073043823, 71.3398951292038, 73.99517744779587, 72.11564630270004, 70.4707145690918, 65.92146188020706, 61.710926815867424, 65.11142134666443, 72.94828042387962, 73.13807263970375, 69.89990919828415, 66.35799765586853, 63.883904814720154, 64.03813853859901, 62.50153139233589, 60.737445652484894, 63.956701308488846, 65.75286492705345, 65.15733048319817, 65.22386491298676, 64.16326582431793, 65.33782839775085, 70.4368431866169, 73.41979712247849, 77.6417125761509, 80.32533377408981, 75.38174584507942, 72.08392560482025, 69.22572657465935, 60.41933052241802, 55.809296295046806, 56.07510343194008, 58.35283800959587, 65.44296115636826, 69.60715010762215, 64.53549385070801, 58.2132562994957, 57.801267206668854, 75.27493357658386, 77.30506584048271, 77.90348812937737, 75.65828740596771, 76.01673737168312, 70.42931959033012, 72.33069196343422, 69.65622067451477, 47.61396065354347, 71.76158890128136, 70.12786656618118, 66.24634444713593, 62.38479405641556, 68.92713859677315, 71.46262854337692, 72.89230182766914, 72.87215530872345, 71.97483345866203, 70.64422085881233, 69.09170776605606, 69.48732733726501, 75.88129743933678, 70.53333520889282, 62.164451479911804, 56.738475635647774, 56.973531022667885, 54.8942331969738, 57.38440677523613, 55.30467577278614, 56.018657460808754, 57.69264243543148, 60.880659967660904, 63.0031006783247, 66.07892543077469, 66.75284966826439, 68.09349372982979, 74.2365100979805, 71.47420272231102, 76.93892508745193, 72.86505728960037, 59.34897355735302, 60.844174325466156, 66.61070689558983, 79.76989477872849, 79.22511041164398, 78.41433271765709, 75.36164492368698, 77.54840478301048, 80.14548942446709, 81.17620691657066, 78.50271597504616, 91.05068385601044, 48.67349959909916, 0.3774945734767243, 1.4441720000468194, 0.7913131196983159, 1.1573068681173027, 0.4726094368379563, 1.8500376027077436, 0.8917517052032053, 1.225846759043634, 0.0480448631424224, 0.04098300516488962, 13.890303801745176, 34.702663868665695, 43.12251426279545, 27.77899269014597, 26.81427575647831, 32.543885707855225, 56.71232543885708, 70.00476837158203, 69.26554843783379, 89.614999294281, 55.418206080794334, 0.8440985216293484, 0.07810034119756892, 0.0712587489397265, 0.059110719157615677, 0.07882058067480102, 0.019835451457765885, 0.03025600264663808, 0.018558237570687197, 0.07592563328216784, 0.012290829199628206, 0.017303679596807342, 0.08019465967663564, 0.049451440791017376, 0.03474378820101265, 0.048659899475751445, 0.007138826113077812, 0.017374510171066504, 0.046791520435363054, 0.02472831791237695, 0.042381137172924355, 0.049162170180352405, 0.03194517899828497, 0.136994123167824, 0.17485621181549504, 0.17006867652526125, 0.17050761234713718, 0.0835674611153081, 0.17563300294568762, 0.1319210688234307, 0.08017570522497408, 0.19466630037641153, 0.17365473409881815, 0.12200146360555664, 0.3219237725716084, 0.1714044384425506, 0.24366563593503088, 0.13699878385523334, 0.23880398977780715, 0.23893080797279254, 0.37680508859921247, 0.8571058767847717, 46.64191961288452, 125.86088195443153, 100.16003385186195, 98.34804028272629, 73.34914371371269, 52.64961004257202, 56.551795452833176, 59.82131101191044, 75.13984322547913, 40.04446282982826, 0.12281711358809844, 0.6092022510711104, 1.0327609512023628, 2.5560950534418225, 2.5714255683124065, 1.272636498324573, 6.28413699567318, 9.366308357566595, 3.8003010023385286, 29.558226317167282, 99.57946300506592, 99.76571381092072, 91.58776223659515, 81.92351281642914, 76.75746962428093, 78.32459673285484, 75.58892592787743, 74.28805813193321, 70.76149016618729, 66.16299211978912, 68.69706094264984, 76.16280153393745, 76.40238627791405, 73.7962657213211, 71.17246851325035, 66.95347890257835, 66.72287687659264, 66.0129913687706, 65.60377612709999, 67.26587533950806, 70.26587516069412, 68.18548679351807, 69.87657845020294, 66.7340786755085, 69.3858727812767, 74.48738023638725, 76.57438024878502, 83.93186464905739, 84.4444951415062, 78.91475066542625, 75.8298709988594, 75.15531599521637, 63.47925692796707, 60.856736451387405, 60.356614887714386, 61.112637519836426, 70.90544164180756, 75.03664836287498, 66.53944551944733, 62.351690232753754, 61.61951132118702, 81.12403571605682, 82.7859753370285, 82.1797026693821, 78.82504507899284, 79.52456474304199, 74.62364852428436, 77.14409127831459, 71.81431487202644, 54.36448462307453, 74.56796631217003, 73.15853834152222, 69.6150004863739, 64.3057581782341, 73.18701401352882, 74.66803014278412, 77.64289811253548, 78.69173303246498, 75.09356170892715, 71.95839554071426, 72.01061993837357, 71.62813246250153, 79.5316855609417, 73.37108373641968, 64.82641384005547, 61.00077532231808, 60.4861993342638, 59.319240152835846, 61.38062573969364, 60.34088373184204, 58.2102582603693, 61.21658854186535, 63.66349384188652, 66.42933502793312, 67.73961871862411, 71.26509994268417, 71.16252064704895, 80.7402791082859, 75.67021116614342, 82.29735195636749, 76.91679507493973, 62.67093010246754, 65.5575630068779, 71.53616219758987, 82.67708078026772, 81.44439652562141, 82.14392378926277, 76.88987731933594, 80.40047854185104, 82.93080076575279, 85.10686799883842, 80.20040407776833, 96.91112458705902, 44.56995539367199, 0.32571647374425083, 5.186310354620218, 3.572547398507595, 3.688831371255219, 0.9657506563235074, 2.8065704880282283, 6.622319798916578, 1.8493480584584177, 0.15420685813296586, 0.1894597930368036, 23.610399775207043, 49.433455020189285, 65.15580296516418, 60.064250975847244, 40.91698341071606, 34.03562106192112, 62.82091185450554, 82.24988490343094, 80.43564945459366, 103.4070660173893, 60.80554559826851, 0.9649024112150073, 0.17568584386026487, 0.20423544861841947, 0.0911709718639031, 0.1270933388150297, 0.08845186152029783, 0.08578307621064596, 0.1403512281831354, 0.18674547696718946, 0.06239677095436491, 0.13725329597946256, 0.14360750501509756, 0.1985313164186664, 0.10500757314730436, 0.13045189843978733, 0.2053002078901045, 0.1935692279948853, 0.13547821232350543, 0.15292171068722382, 0.15209350356599316, 0.10130926573765464, 0.22380855458322912], [0.033334089821437374, 0.025658180711616296, 0.022437167026509997, 0.06099386322603095, 0.014083654823480174, 0.028633346846618224, 0.11797609171480872, 0.03312429951620288, 0.00514707522597746, 0.0138225589216745, 0.023989812325453386, 0.02949720303149661, 0.05213680567976553, 0.04576075523800682, 0.04897164231806528, 0.046053183687035926, 0.03418482112465426, 0.05710723955417052, 0.43535017990507185, 69.65088576078415, 89.38315093517303, 83.89316752552986, 83.0042052268982, 41.10717460513115, 28.211247995495796, 63.21212366223335, 51.360411420464516, 54.06446032226086, 7.162406193092465, 0.1172553030482959, 0.17729048588080332, 0.51217315136455, 0.5621423106640577, 0.1838494831463322, 0.36285241541918367, 3.9461602130904794, 1.9131732336245477, 3.735439432784915, 64.69476610422134, 93.76712009310722, 87.95307487249374, 86.6924849152565, 82.73315817117691, 81.26820757985115, 82.36777737736702, 80.53881391882896, 80.43313398957253, 72.26332157850266, 67.489462941885, 58.21053944528103, 60.662251487374306, 60.20757168531418, 61.068362295627594, 61.47109128534794, 59.27577428519726, 61.90742947161198, 62.06552378833294, 62.190890461206436, 64.56176564097404, 67.62776032090187, 66.20467588305473, 67.85572528839111, 65.94552978873253, 64.0738870203495, 62.824886441230774, 66.86895623803139, 67.09293901920319, 68.33252370357513, 69.92301195859909, 64.01024803519249, 58.327329978346825, 52.606455758214, 52.857637479901314, 52.8489625453949, 58.00601162016392, 62.568540796637535, 68.5290415585041, 67.96069085597992, 64.55184057354927, 49.719659462571144, 58.56895141303539, 70.61572998762131, 72.8298331797123, 72.77489572763443, 70.96930101513863, 72.20706179738045, 71.79093852639198, 67.02911764383316, 46.95813104510307, 71.39947593212128, 63.84118750691414, 61.37131243944168, 59.558057337999344, 66.8705977499485, 70.36710172891617, 68.204804956913, 67.70621091127396, 68.48497912287712, 69.27135452628136, 68.11097279191017, 68.46663370728493, 71.48320823907852, 64.70188692212105, 59.62967969477177, 56.13501861691475, 56.36040352284908, 51.39319986104965, 54.2500651627779, 52.275185734033585, 51.41906127333641, 55.73592223227024, 60.198239386081696, 60.8577623963356, 62.24765941500664, 61.36331766843796, 62.78258331120014, 60.92385224997997, 70.06936490535736, 74.0466570854187, 59.76480044424534, 54.70344163477421, 55.12393467128277, 65.92565685510635, 73.6168621480465, 75.48139929771423, 68.40532779693604, 75.71219891309738, 76.15365922451019, 75.03883704543114, 73.30543085932732, 74.82625365257263, 75.91213658452034, 83.8076189160347, 54.01850938796997, 1.3472133153118193, 1.0470556654036045, 0.8755680173635483, 0.498361011268571, 0.4034142888849601, 0.20719122985610738, 1.7124461545608938, 0.005963667736068601, 0.20252040470950305, 2.6770473131909966, 22.379518523812294, 33.5625122487545, 58.059474751353264, 49.91004824638367, 23.80490943789482, 29.88437231630087, 52.96949967741966, 66.91332265734673, 64.4550521671772, 71.4402325451374, 8.039938230067492, 0.5388535384554416, 0.05844306455401238, 0.10508235194720328, 0.03496383869787678, 0.14024060365045443, 0.03932623098080512, 0.037764496228192, 0.028986983925278764, 0.00885474111782969, 0.022847596956125926, 0.031445884305867366, 0.011524140554683981, 0.03892376429575961, 0.08441401412710547, 0.16129772295244038, 0.06691733346087858, 0.019432862318353727, 0.016617111359664705, 0.08201140750315972, 0.034150418869103305, 0.031241593314916827, 0.03824907784292009, 0.00666063531753025, 0.044064561880077235, 0.043083004784421064, 0.03459394858509768, 0.02390234836639138, 0.034922794220619835, 0.06040578169631772, 0.008518268987245392, 0.08255560955149122, 0.03890700660122093, 0.02474395867466228, 0.012214135658723535, 0.010685381948860595, 0.06876674320665188, 0.050681446664384566, 0.041349318125867285, 0.08355317477253266, 1.0916428291238844, 86.11028775572777, 98.57807993888855, 95.02629652619362, 94.36963856220245, 54.381355717778206, 38.42579148709774, 52.217698618769646, 44.92578350007534, 57.429498955607414, 7.937766462564468, 0.051194014667999, 0.30526252754498273, 1.7281380062922835, 2.4736926751211286, 0.9200354875065386, 2.6450052950531244, 6.530245039612055, 0.4474557959474623, 4.690830716863275, 68.02512019872665, 97.1651865541935, 93.60453441739082, 90.58611318469048, 86.40933930873871, 87.28230446577072, 85.01024678349495, 85.59872880578041, 84.91799533367157, 77.41055577993393, 70.86479142308235, 62.519071251153946, 62.42389775812626, 61.3612087816, 63.44698525965214, 64.55183297395706, 63.701108023524284, 63.231882601976395, 65.35503387451172, 67.60433837771416, 67.71007910370827, 71.41530588269234, 69.11211267113686, 70.83642214536667, 68.07235926389694, 66.3413317501545, 65.31212657690048, 68.73793914914131, 70.73007345199585, 73.66309806704521, 71.75585880875587, 67.24864706397057, 60.49342654645443, 57.079495936632156, 56.931683868169785, 56.02754518389702, 60.34661762416363, 65.05808740854263, 71.05476602911949, 70.26180177927017, 65.30936032533646, 53.73771205544472, 61.233007460832596, 72.41887763142586, 77.24483907222748, 75.4440701007843, 73.35389345884323, 73.64780768752098, 73.02782535552979, 67.68233299255371, 50.18461391329765, 73.43774735927582, 67.5399698317051, 65.88346391916275, 62.65252389013767, 69.38914060592651, 72.610052973032, 71.6402006149292, 71.00227564573288, 70.597635358572, 70.9684194624424, 71.6052120923996, 71.07345342636108, 75.31848683953285, 67.65198782086372, 63.23442846536636, 58.36250849068165, 58.628729805350304, 54.05743069946766, 57.74268575012684, 54.818457663059235, 54.445222690701485, 59.52649623155594, 64.60394337773323, 63.211534693837166, 65.71434259414673, 66.14678978919983, 66.95771187543869, 65.1168854534626, 73.47118556499481, 75.02746045589447, 64.40984979271889, 56.90226584672928, 58.10307361185551, 69.91301849484444, 78.23822736740112, 78.79759535193443, 73.290064483881, 77.56212964653969, 78.94553661346436, 77.48846679925919, 75.9459775686264, 77.90580600500107, 79.53162476420403, 87.35755562782288, 68.08453381061554, 3.3749888744205236, 0.8423500810749829, 0.6903034367132932, 0.5724430235568434, 0.858713606139645, 0.8702754357364029, 1.2645177589729428, 1.575715122744441, 0.3086401306791231, 2.0070257037878036, 28.15596666187048, 38.189531564712524, 44.24843184649944, 32.76758350431919, 24.67085637152195, 40.36699332296848, 57.13119216263294, 77.96481683850288, 67.7116522192955, 85.80877393484116, 12.494536098092794, 0.4085076187038794, 0.15037923149066046, 0.048542020449531265, 0.009446537096664542, 0.042528301346465014, 0.029474231705535203, 0.05561273224884644, 0.023357637946901377, 0.0461693594843382, 0.058856518735410646, 0.051899563331971876, 0.003216515110580076, 0.03980264154961333, 0.03839925513602793, 0.05655648434185423, 0.030137761823425535, 0.03015225967828883, 0.008274850115412846, 0.025868427437671926, 0.05742936875321902, 0.016558951101615094, 0.08814353626803495, 0.07677230503759347, 0.1592963287839666, 0.14478964236332104, 0.050623195493244566, 0.2003941367729567, 0.19709276704816148, 0.1446807396132499, 0.16933918988797814, 0.15810297016287223, 0.15828279254492372, 0.07999527428182773, 0.1829634775640443, 0.15810586453881115, 0.11031778078177013, 0.19420876633375883, 0.18678642867598683, 0.15949213702697307, 1.2825032626278698, 97.12423235177994, 113.58472108840942, 107.56965145468712, 101.68197378516197, 60.31363919377327, 39.393873140215874, 88.63610342144966, 75.73600083589554, 83.4891428053379, 12.736716102808714, 0.19950035348301753, 0.6277786230202764, 1.7442264617420733, 3.9389538997784257, 1.4829414384439588, 2.7634831750765443, 11.126692146062851, 9.265342075377703, 5.835691234096885, 71.86681285500526, 101.62550121545792, 97.29075461626053, 95.41166424751282, 90.69722682237625, 89.54386711120605, 89.40926313400269, 87.52449586987495, 88.89734700322151, 79.47019726037979, 75.19501626491547, 64.9098801612854, 67.1424275636673, 65.8130232989788, 67.73295387625694, 67.70037442445755, 66.34957730770111, 67.72026255726814, 69.34039682149887, 69.39653500914574, 70.40601924061775, 74.72175166010857, 72.39927068352699, 75.0467786192894, 70.03749221563339, 69.29115906357765, 68.69083687663078, 73.434988707304, 73.04139822721481, 75.52156314253807, 74.64558854699135, 70.1866190135479, 63.92954036593437, 59.11869831383228, 58.675345703959465, 58.73453512787819, 65.16097828745842, 67.87816688418388, 76.14237383008003, 74.34817090630531, 70.86014807224274, 56.65818974375725, 65.04838272929192, 77.8753088414669, 80.22447198629379, 79.10973340272903, 76.81836515665054, 78.16738396883011, 76.76734149456024, 71.10600247979164, 56.09171614050865, 78.19411933422089, 71.48959949612617, 68.58308225870132, 64.8550871014595, 73.31843376159668, 75.14048159122467, 74.4129878282547, 72.45806872844696, 73.91750201582909, 75.13102769851685, 71.34740352630615, 73.38984712958336, 78.39325904846191, 71.1209736764431, 66.40544950962067, 62.44875222444534, 62.746519446372986, 57.63492353260517, 61.28850348293781, 58.4477075189352, 58.35717357695103, 64.06722217798233, 69.60011288523674, 66.4530761539936, 69.64105948805809, 69.77178767323494, 71.22514128684998, 69.72755804657936, 77.3849755525589, 79.45577323436737, 67.89908856153488, 60.867368280887604, 62.894114926457405, 72.36854553222656, 82.51121208071709, 80.50589248538017, 76.16201117634773, 79.32683855295181, 80.01368209719658, 82.26924866437912, 78.3059549331665, 82.43057280778885, 82.10224002599716, 92.28038147091866, 64.9897974729538, 1.4982898836024106, 2.0376366237178445, 2.4747563805431128, 2.943645757623017, 1.03279123082757, 1.7079462460242212, 6.0661873407661915, 2.112335152924061, 0.2944118238519877, 4.626598488539457, 39.16112042963505, 51.22848629951477, 81.9908756017685, 71.17866218090057, 35.08319064974785, 45.41104406118393, 69.03806984424591, 90.00237330794334, 81.95883572101593, 95.11560693383217, 12.621499635279179, 0.7842820719815791, 0.3065066639101133, 0.20587575825629756, 0.21633079333696514, 0.17115754075348377, 0.1962994853965938, 0.09816664140089415, 0.1023778693343047, 0.1236190041527152, 0.09397117668413557, 0.13390036183409393, 0.13385547674261034, 0.14132028009044006, 0.17043639585608616, 0.25023215857800096, 0.21760289382655174, 0.13968869810923934, 0.12674855184741318, 0.14523678633850068, 0.15979430987499654, 0.1289973928942345], [0.054690784454578534, 0.039439063402824104, 0.04952890616550576, 0.046747258747927845, 0.052633402665378526, 0.023389594825857785, 0.04355580480478238, 0.038228293997235596, 0.07161615983932279, 0.033810815803008154, 0.07030338223557919, 0.011185795428900747, 0.14596250286558643, 0.034560540807433426, 0.0704293098533526, 0.06688081979518756, 0.21333647979190573, 0.5009175615850836, 15.738301388919353, 98.64113375544548, 75.98185524344444, 75.40226474404335, 55.98640479147434, 46.375132128596306, 38.73445272445679, 60.07611773908138, 46.59887932240963, 27.794653549790382, 0.08836926048388705, 0.025184872320096474, 0.20829544169828296, 0.990244735730812, 0.2896089112618938, 0.6845713255461305, 2.604395211674273, 6.245533442124724, 1.0801886999979615, 28.6605491861701, 86.0540659725666, 89.62281167507172, 89.89079609513283, 85.02673029899597, 88.53736951947212, 86.46249085664749, 86.07219099998474, 85.70928767323494, 86.63083702325821, 81.52923077344894, 76.65097653865814, 70.71357473731041, 60.870525911450386, 60.548493191599846, 58.09976778924465, 59.8359440267086, 58.245368376374245, 56.92227937281132, 63.943075239658356, 66.07547521591187, 68.77032861113548, 69.1937018930912, 70.4227763414383, 69.38800066709518, 71.20405241847038, 68.53978738188744, 66.94199591875076, 65.40503919124603, 66.37407839298248, 68.5454186797142, 62.20748037099838, 57.79477335512638, 54.81541022658348, 52.91836962103844, 54.94201943278313, 53.19243751466274, 54.140555039048195, 61.73120252788067, 71.56463027000427, 70.39906561374664, 65.54669559001923, 56.721034571528435, 54.23363484442234, 62.0802365988493, 67.68204420804977, 72.2997236251831, 68.79175186157227, 68.94008070230484, 69.78748083114624, 66.970494389534, 45.27061499655247, 69.45517346262932, 63.75104874372482, 64.52157899737358, 63.3209840208292, 66.08292281627655, 70.78003317117691, 67.46076688170433, 67.46375352144241, 68.11517536640167, 67.8467045724392, 70.50957888364792, 69.51597779989243, 67.01288491487503, 60.89740566909313, 54.4335763156414, 56.30676180124283, 54.11496341228485, 50.38297466933727, 50.45868180692196, 50.470924749970436, 52.1590069681406, 57.42868959903717, 57.80462622642517, 61.43576838076115, 62.80314780771732, 64.52625274658203, 64.05671954154968, 66.04553282260895, 69.83496308326721, 65.66224738955498, 58.645350113511086, 54.184100702404976, 53.715920224785805, 65.488361120224, 76.68080493807793, 72.90797978639603, 74.36777785420418, 67.73348584771156, 78.61899733543396, 74.29780840873718, 69.5891922712326, 66.69991090893745, 73.47490176558495, 73.64377230405807, 82.00049668550491, 77.31744557619095, 10.720829274505377, 0.3880392451537773, 0.8239309256896377, 0.8992583805229515, 0.0814491490018554, 0.2753652271348983, 0.33507685584481806, 0.1416919328039512, 0.1180905383080244, 9.86395625397563, 23.38355954736471, 38.34084324538708, 57.48134717345238, 24.060274735093117, 23.17364551126957, 46.84594586491585, 67.19579190015793, 58.22894185781479, 71.90630033612251, 36.346406266093254, 0.44216345180757344, 0.040260465029859915, 0.12546051002573222, 0.03980422603490297, 0.09290571237215772, 0.0287795777694555, 0.03534953655616846, 0.03881161093886476, 0.05336239206371829, 0.07156835810746998, 0.03504846208670642, 0.029982079649926163, 0.042005881332443096, 0.056481827996321954, 0.04212249128613621, 0.018077203421853483, 0.02515442385629285, 0.0351727384258993, 0.01278909972825204, 0.03927167570509482, 0.003650438420663704, 0.02625946690386627, 0.019608727197919507, 0.051481719347066246, 0.04964447711245157, 0.07869730252423324, 0.02067716752208071, 0.05649651509884279, 0.009058084942807909, 0.14609448640840128, 0.03645576332928613, 0.04777336696861312, 0.05598465955699794, 0.11150684978929348, 0.0947882812761236, 0.07287749176612124, 0.05807150460896082, 0.26303981663659215, 0.5990004516206682, 22.982614561915398, 116.33800774812698, 87.68508285284042, 86.00504860281944, 66.43833294510841, 61.86143293976784, 31.17724534124136, 31.373229324817657, 50.74388310313225, 32.874904945492744, 0.1565237986505963, 0.014273777287598932, 0.5320134304929525, 1.2489045155234635, 1.2642400176264346, 1.9745420780964196, 3.063138658180833, 0.9216947515960783, 1.1095662298612297, 32.26087689399719, 87.14522302150726, 95.94381049275398, 93.20025891065598, 88.0880056321621, 92.5985535979271, 90.19610971212387, 89.71331521868706, 90.39575859904289, 90.88925331830978, 85.54765954613686, 81.9452552497387, 74.63805735111237, 62.84200832247734, 63.16553436219692, 61.09051130712032, 62.787097468972206, 62.64104090631008, 60.26400625705719, 64.92859035730362, 70.67946016788483, 72.50299751758575, 73.05895328521729, 73.14559623599052, 72.40259930491447, 73.25892895460129, 72.4529542028904, 70.27797371149063, 69.28789123892784, 69.34018403291702, 71.06428071856499, 64.34681117534637, 59.97616410255432, 56.340819373726845, 55.73621101677418, 58.68707187473774, 55.345994755625725, 56.96512967348099, 65.81394284963608, 73.06273028254509, 74.53293219208717, 69.01462510228157, 60.15950806438923, 57.621901631355286, 64.42390903830528, 70.13444781303406, 76.90014436841011, 73.21269303560257, 72.32316076755524, 73.11962842941284, 69.7275048494339, 49.967406168580055, 74.90007609128952, 66.18479534983635, 67.14921399950981, 66.55398353934288, 69.43289905786514, 72.01741397380829, 69.73081067204475, 67.60413318872452, 68.52952033281326, 70.75151950120926, 71.1131688952446, 71.17061421275139, 68.99879515171051, 64.51270267367363, 57.92398162186146, 57.4961131811142, 57.473823577165604, 53.95364306867123, 55.82785449922085, 54.92147393524647, 57.51229651272297, 60.99459305405617, 61.51615686714649, 64.88490030169487, 65.672218054533, 68.85238900780678, 70.07220715284348, 70.35592272877693, 71.11354127526283, 69.8859715461731, 60.844953283667564, 58.020853623747826, 57.63921730220318, 68.98234203457832, 79.69520598649979, 76.68447554111481, 75.27738064527512, 74.12708356976509, 80.50772398710251, 76.85077741742134, 72.57960140705109, 70.13535976409912, 75.97000747919083, 76.84614926576614, 82.91111022233963, 89.3309873342514, 19.137137308716774, 0.5906309850979596, 0.7091878890059888, 1.1579886940307915, 0.8652065077330917, 1.1883406341075897, 1.3328550732694566, 0.29773554706480354, 0.07724491952103563, 9.807971958070993, 30.42385406792164, 35.39441294968128, 40.97943305969238, 14.527020435780287, 28.474488370120525, 56.2001509219408, 72.17977926135063, 66.04259938001633, 82.31466382741928, 50.85733741521835, 0.5232782929670066, 0.029364540423557628, 0.03757079197384883, 0.028808408351324033, 0.08730536210350692, 0.025266387965530157, 0.030600140235037543, 0.043686159333446994, 0.03701829271449242, 0.03858806492644362, 0.04296397542930208, 0.07152248595957644, 0.07220202605822124, 0.11741803376935422, 0.03307112834590953, 0.023208848469948862, 0.028144124953541905, 0.050831501503125764, 0.04580097593134269, 0.0088937131476996, 0.017675992821750697, 0.11078035400714725, 0.11296595665044151, 0.15746675664559007, 0.17210722260642797, 0.1736972146318294, 0.143043665739242, 0.1443208722048439, 0.12537669186713174, 0.17871668591396883, 0.15282279724488035, 0.0840710305783432, 0.1450200198451057, 0.2987558813765645, 0.14456965494900942, 0.20380693254992366, 0.28118143847677857, 0.38972377195023, 1.1719131655991077, 26.766335628926754, 133.84731620550156, 98.63440051674843, 99.19641315937042, 75.89774295687675, 62.3301187902689, 55.96330963075161, 84.77509260177612, 69.17037114501, 46.751368939876556, 0.6369030615314841, 0.1735874213045463, 0.7915193773806095, 2.1429607970640063, 1.8964933161623776, 3.6522908695042133, 11.680330038070679, 16.208761744201183, 4.353345176205039, 32.29721054434776, 90.56446194648743, 97.41208210587502, 98.78520682454109, 91.11122220754623, 95.88437408208847, 94.51169773936272, 92.18740805983543, 93.34158092737198, 94.81662377715111, 89.1000585258007, 83.48582938313484, 78.27412024140358, 66.27905309200287, 68.17375302314758, 64.68831405043602, 64.08962577581406, 64.79588627815247, 62.653135657310486, 70.97440794110298, 74.84830006957054, 75.5249373614788, 75.40892958641052, 76.52000516653061, 74.7199809551239, 77.12941646575928, 75.88733151555061, 74.36747387051582, 72.01276302337646, 74.35865834355354, 74.43429708480835, 68.04275885224342, 63.785307705402374, 59.684457555413246, 57.64144778251648, 62.84668207168579, 59.353453516960144, 60.94495251774788, 69.22584816813469, 77.94299840927124, 78.32646623253822, 73.01898702979088, 65.02622991800308, 59.686361253261566, 68.44085589051247, 71.89566850662231, 81.31178364157677, 77.00208529829979, 75.42726740241051, 77.52084866166115, 73.02275642752647, 54.03032675385475, 77.53146529197693, 70.89319869875908, 72.18981072306633, 69.78843078017235, 72.42331579327583, 77.49638557434082, 74.18748512864113, 70.97997084259987, 72.52479314804077, 74.49406787753105, 76.21397718787193, 74.76395979523659, 74.33582156896591, 67.82868593931198, 59.273388013243675, 59.640148133039474, 59.58047233521938, 57.22503952682018, 58.72873663902283, 57.42446422576904, 60.05453869700432, 66.77673518657684, 64.35235127806664, 69.99733597040176, 68.36060419678688, 74.2926786839962, 74.61530417203903, 73.74889746308327, 74.92893174290657, 73.11098009347916, 64.69126269221306, 60.56481331586838, 60.598870888352394, 73.00381824374199, 83.88323485851288, 81.34546503424644, 78.16479250788689, 79.12169516086578, 80.26890680193901, 81.14653050899506, 77.40140587091446, 72.5578285753727, 81.16087093949318, 78.39991629123688, 87.40925565361977, 90.53212568163872, 13.815268278121948, 1.2003381340764463, 3.094654167070985, 5.100944610312581, 0.552784422179684, 3.7786253029480577, 3.3701277477666736, 0.6008401466533542, 0.1777186308754608, 16.533325128257275, 40.56382656097412, 53.81520129740238, 82.32803151011467, 34.713451489806175, 35.98180063068867, 65.72119742631912, 83.90136748552322, 77.17615395784378, 95.2474294602871, 55.01991145312786, 0.6540564692113549, 0.18442323751514778, 0.16470570961246267, 0.13718301459448412, 0.16526707011507824, 0.11671079671941698, 0.13365097052883357, 0.10285708893206902, 0.1724683665088378, 0.18368333112448454, 0.09826005552895367, 0.15013536176411435, 0.09273904826841317, 0.17760175745934248, 0.15300990751711652, 0.08629595962702297, 0.13605150656076148, 0.1428272109478712, 0.18460463325027376, 0.11418436275562271, 0.07354844521614723], [0.008184674534277292, 0.059278010376146995, 0.030007154964550864, 0.022618093353230506, 0.10004290204960853, 0.022917984097148292, 0.04694745679444168, 0.02145681963156676, 0.030961722004576586, 0.07348093204200268, 0.050338492801529355, 0.02182243868446676, 0.03941528128052596, 0.05791234732896555, 0.09351941655040719, 0.04144728161918465, 0.10053998514194973, 0.22120809881016612, 60.269139781594276, 87.09008798003197, 83.10426145792007, 72.77681082487106, 60.092768445611, 21.09728492796421, 88.44429731369019, 133.80719035863876, 47.853579595685005, 9.77815305814147, 0.15593775431625545, 0.3640922176418826, 0.4157162772025913, 1.546573298983276, 2.8348326589912176, 0.48946162161882967, 2.7408268908038735, 3.1434383243322372, 7.4856629222631454, 74.49409827589989, 82.61749237775803, 90.04714250564575, 85.30130356550217, 92.61152610182762, 86.7261891067028, 87.74385809898376, 87.46933802962303, 82.8364746272564, 79.42298859357834, 84.31075751781464, 80.44951111078262, 80.27066230773926, 71.64121896028519, 61.56650796532631, 58.54268342256546, 59.225297793745995, 58.71821880340576, 58.44918183982372, 61.27684570848942, 69.43777799606323, 72.77928829193115, 74.34823170304298, 70.98142236471176, 70.64597636461258, 71.43366649746895, 69.29163783788681, 64.30282473564148, 64.75593522191048, 63.16656410694122, 59.60314191877842, 55.80881752073765, 52.39186227321625, 53.564851731061935, 52.477954253554344, 54.73637446761131, 52.491717115044594, 54.23238091170788, 65.49087658524513, 68.680729418993, 71.99468359351158, 69.7403709590435, 63.22655148804188, 55.95219522714615, 57.42244653403759, 61.674277782440186, 68.00674438476562, 67.73404821753502, 67.82436177134514, 70.73008105158806, 66.61053970456123, 52.431923523545265, 69.66676890850067, 63.04920740425587, 60.67366607487202, 64.60024237632751, 69.5094345510006, 65.09166240692139, 65.17780378460884, 66.91105037927628, 67.2290401160717, 68.75392109155655, 68.13556507229805, 64.9214619398117, 63.49305018782616, 55.03382630646229, 52.326285392045975, 54.74011346697807, 56.20303116738796, 53.98897357285023, 50.861471593379974, 48.37414026260376, 52.38652355968952, 54.39645990729332, 56.50204472243786, 62.959004044532776, 63.22644889354706, 65.11472716927528, 65.49516275525093, 64.78925943374634, 61.77403002977371, 59.72682908177376, 54.54060137271881, 54.04693566262722, 53.95117700099945, 63.61582539975643, 71.5980912744999, 72.84154415130615, 76.10503703355789, 68.51338639855385, 68.58507335186005, 72.4229434132576, 70.72717040777206, 66.8880008161068, 65.48348218202591, 74.10990089178085, 74.93428185582161, 79.83018234372139, 92.32070490717888, 24.919513128697872, 0.2478868086473085, 0.6701828038785607, 0.6868757237680256, 0.21834707498783246, 0.49401840835344046, 0.21962486032862216, 0.02927140645624604, 0.897334615001455, 19.53310266137123, 29.562687277793884, 48.253139555454254, 51.48843415081501, 30.115453116595745, 38.04953947663307, 50.39138361811638, 59.254119247198105, 61.27084583044052, 62.632597759366035, 4.686551196500659, 0.21265294693876058, 0.11614787770668045, 0.07704084375291131, 0.027153227929375134, 0.050023551302729174, 0.01665258787397761, 0.0287064094300149, 0.015093634319782723, 0.03313067827548366, 0.10194024711381644, 0.024816206750983838, 0.03521081802318804, 0.010448383582115639, 0.034964335936820135, 0.07713538594543934, 0.02517980530683417, 0.0077606581999134505, 0.0180331124283839, 0.054809364810353145, 0.06108223446062766, 0.01937109151185723, 0.0025514276421745308, 0.03599640360334888, 0.008085666468105046, 0.08185244689229876, 0.052236984483897686, 0.023945034845382906, 0.019819419212581124, 0.10172687223530374, 0.005850860825376003, 0.06401717619155534, 0.021419747499749064, 0.00942860866416595, 0.07762696230201982, 0.00956108573518577, 0.02981208701385185, 0.07127566248527728, 0.5775374814402312, 76.40943109989166, 98.63380774855614, 92.17189729213715, 83.45274075865746, 74.82835873961449, 30.965594798326492, 75.80564349889755, 111.12234681844711, 55.05143456161022, 11.524405404925346, 0.20134291320573539, 0.9089124156162143, 1.821663100272417, 1.3359815930016339, 2.117893067188561, 2.155071459710598, 1.4782567648217082, 0.701954027172178, 9.87700380384922, 78.86515572667122, 84.96015027165413, 90.21390795707703, 89.89674657583237, 98.42006921768188, 91.01126477122307, 91.088727414608, 89.70805630087852, 87.34552547335625, 83.32360848784447, 86.44883438944817, 83.81038516759872, 82.57317155599594, 75.60715734958649, 62.51154765486717, 58.8090643286705, 62.638840824365616, 61.837368831038475, 63.27548526227474, 64.30662453174591, 71.23431399464607, 74.93792206048965, 75.86058855056763, 74.26903635263443, 73.07977616786957, 74.67553853988647, 73.17655697464943, 67.49257877469063, 67.30009630322456, 66.3277892768383, 62.98841446638107, 57.901692017912865, 56.10771708190441, 55.61914689838886, 55.00033110380173, 56.7183481156826, 56.1120830476284, 56.7998955398798, 67.82103314995766, 72.39759877324104, 74.13337603211403, 74.09273341298103, 66.24377578496933, 58.144662380218506, 60.088862255215645, 65.18593534827232, 70.44264927506447, 72.85802006721497, 71.03537186980247, 71.49947136640549, 68.26351180672646, 55.52226349711418, 72.18407303094864, 65.29316559433937, 61.83619849383831, 66.95391967892647, 71.33038803935051, 67.66813695430756, 66.64730653166771, 67.57785379886627, 70.13965353369713, 70.01390308141708, 70.28381779789925, 69.36693459749222, 64.69779834151268, 56.39743633568287, 55.11696204543114, 56.583994925022125, 58.56048546731472, 56.678948029875755, 52.983239740133286, 50.99581338465214, 54.94367614388466, 58.076231852173805, 59.99803952872753, 64.12452310323715, 67.69484952092171, 67.28514790534973, 68.62427204847336, 66.88883677124977, 64.85556587576866, 62.488585487008095, 56.866555362939835, 56.75430938601494, 55.38671717047691, 66.80719435214996, 75.74440598487854, 76.79479122161865, 78.55579912662506, 70.73685988783836, 72.82507583498955, 76.44300609827042, 72.07566484808922, 71.17797821760178, 67.35713884234428, 77.52504363656044, 80.03297746181488, 79.42368015646935, 97.26263612508774, 35.08536793291569, 0.5737737833987921, 0.17915251955855638, 0.48942041757982224, 0.49671786662656814, 0.9542456455528736, 1.0506799584254622, 0.0668399126152508, 0.6008628266863525, 25.801745988428593, 35.93111515045166, 40.79070098698139, 43.258539363741875, 46.32765367627144, 55.56364707648754, 57.62229681015015, 67.81107768416405, 67.2830580174923, 77.79498875141144, 9.884331710636616, 0.36049775895662606, 0.09538207363220863, 0.13019081088714302, 0.040014287224039435, 0.062161662281141616, 0.00932781758820056, 0.05728879856178537, 0.041595989459892735, 0.056373222105321474, 0.027724319843400735, 0.03043200667889323, 0.03139031228784006, 0.0208103589102393, 0.019572694072849117, 0.042474206202314235, 0.043787640606751665, 0.030664729347336106, 0.04669479632866569, 0.04361802646599244, 0.005983735409245128, 0.08266452714451589, 0.13642952690133825, 0.11687660735333338, 0.1028650818625465, 0.22430419048760086, 0.08902011657482944, 0.1252661712351255, 0.12849218328483403, 0.1663966485648416, 0.23257561930222437, 0.16893528343643993, 0.11554768803762272, 0.10797678725793958, 0.2058359346119687, 0.2427501225611195, 0.13096659269649535, 0.26041412784252316, 0.5043322721030563, 87.76170194149017, 109.1975449025631, 105.79975202679634, 92.8160311281681, 82.29593843221664, 29.958054162561893, 115.94924300909042, 161.7588096857071, 70.76331406831741, 17.751790545880795, 0.3952924028271809, 0.8484935201704502, 2.174920169636607, 5.514989867806435, 7.332181083038449, 6.199554484337568, 10.63874987885356, 10.343293882906437, 9.230738282203674, 82.86792933940887, 84.66549888253212, 92.11476355791092, 91.29392400383949, 102.22748771309853, 94.11037087440491, 93.95754307508469, 93.58735173940659, 89.73359853029251, 84.89715725183487, 89.57370311021805, 88.44409972429276, 88.28420430421829, 79.75141257047653, 66.7742957174778, 62.32673317193985, 64.94746774435043, 64.7014993429184, 66.04538843035698, 68.03626120090485, 75.09765788912773, 79.29062649607658, 78.77616450190544, 75.74184492230415, 76.0119192302227, 76.88442841172218, 77.38311365246773, 70.13723686337471, 71.40088185667992, 67.74803906679153, 66.39598041772842, 61.6619436442852, 58.407756462693214, 60.612162575125694, 58.382427021861076, 61.81611657142639, 57.97041893005371, 59.8499196767807, 70.5870795249939, 74.69927206635475, 80.89355528354645, 77.7970178425312, 69.41393047571182, 62.67482869327068, 63.59319381415844, 68.980001360178, 74.24410209059715, 74.8416656255722, 73.5745020210743, 77.28890150785446, 72.43943452835083, 60.80915540456772, 75.50605237483978, 71.42638608813286, 66.4894326031208, 70.18195286393166, 75.04349559545517, 70.88578149676323, 67.6833513379097, 71.07142433524132, 72.55601227283478, 72.12652131915092, 73.5468091070652, 71.75164103507996, 68.84939476847649, 59.27029877901077, 57.02354393899441, 58.7113069742918, 62.52413257956505, 58.96752342581749, 57.683967500925064, 53.55474427342415, 58.50039169192314, 61.51117533445358, 62.733440548181534, 68.88032510876656, 68.20135474205017, 71.97207480669022, 71.93358287215233, 71.47896006703377, 69.85211536288261, 64.95846435427666, 59.7191496938467, 60.231666192412376, 59.106660559773445, 72.13827788829803, 78.59606936573982, 80.64281433820724, 80.85066318511963, 74.014503210783, 77.88241446018219, 76.98962956666946, 77.40885347127914, 74.91203024983406, 72.35115006566048, 82.87124276161194, 83.17439809441566, 85.75197458267212, 103.8059838116169, 30.874160304665565, 0.8002585521899164, 5.3718729224056005, 3.328840588219464, 0.6123134528752416, 3.156603192910552, 1.1862499150447547, 0.16735351440729573, 1.6636161622591317, 36.90130949020386, 45.49621269106865, 67.87463307380676, 73.40478792786598, 43.82571592926979, 53.924905210733414, 69.68041017651558, 79.48969021439552, 77.53483951091766, 86.1057735979557, 8.59436932951212, 0.4607996705453843, 0.34704989462625235, 0.22185666166478768, 0.10524664859985933, 0.09931813547154889, 0.12323199640377425, 0.14788266154937446, 0.12661315442528576, 0.14818809984717518, 0.21817783563164994, 0.1920666461228393, 0.10095352467033081, 0.16186972585273907, 0.10011072692577727, 0.17264850059291348, 0.10203551661106758, 0.20410340570379049, 0.16233577975071967, 0.1355912265717052, 0.2189414165331982], [0.0258607758951257, 0.04534927888016682, 0.048170928057515994, 0.08673309945152141, 0.034004482949967496, 0.08391440031118691, 0.059383599436841905, 0.08693577998201363, 0.03522166080074385, 0.061310433738981374, 0.0497592910687672, 0.0740329414838925, 0.012134699882153654, 0.07036752605927177, 0.006666178232990205, 0.2094932977342978, 0.1729219820117578, 8.945871368050575, 91.96821302175522, 77.98289626836777, 72.93181970715523, 53.95110100507736, 32.282239347696304, 36.240418553352356, 53.63253749907017, 42.827414497733116, 31.01817637681961, 0.5785791005473584, 0.02253307291539386, 0.13779289671219885, 1.34159175446257, 1.3833813183009624, 0.9006033302284777, 0.5477319401688874, 0.821573567809537, 0.7067636190913618, 44.06515248119831, 91.10307544469833, 87.31936767697334, 86.59407019615173, 84.84014511108398, 85.9113684296608, 83.51038366556168, 85.9190060198307, 82.24075019359589, 85.87633430957794, 82.82733991742134, 76.9154879450798, 79.17467191815376, 79.38263475894928, 79.91515338420868, 67.82966628670692, 57.404116317629814, 58.694641068577766, 56.18876293301582, 57.89053201675415, 61.837600618600845, 67.16476276516914, 69.27840694785118, 68.4775847196579, 70.15133410692215, 69.69458341598511, 67.97994822263718, 66.27320900559425, 64.34565603733063, 60.04237934947014, 55.93993328511715, 55.651399567723274, 54.78143244981766, 53.31959769129753, 51.84692591428757, 52.969340085983276, 51.972395181655884, 51.93396024405956, 60.88214568793774, 66.6900086402893, 71.95649564266205, 67.67376065254211, 70.51863759756088, 67.36090064048767, 61.115646958351135, 55.0330625474453, 57.77595676481724, 62.29320377111435, 67.20000207424164, 66.13627955317497, 63.40557508170605, 67.53356337547302, 54.81281876564026, 68.47209021449089, 59.9443332105875, 62.22035028040409, 62.016814202070236, 64.87211018800735, 62.15016804635525, 62.99414075911045, 65.31180739402771, 65.80755159258842, 65.19839107990265, 65.53113162517548, 64.2260080575943, 60.59944085776806, 54.76173810660839, 52.039058804512024, 50.20808905363083, 52.78535395860672, 52.41958938539028, 50.76882116496563, 49.75832998752594, 47.891395166516304, 53.41153375804424, 52.15627871453762, 55.6578516215086, 54.681520611047745, 54.106459468603134, 54.61292289197445, 55.681756138801575, 54.975066259503365, 54.11602735519409, 53.937854915857315, 55.66345252096653, 52.94930376112461, 63.760791420936584, 70.08463248610497, 73.32246914505959, 73.69753181934357, 72.96346440911293, 71.24528780579567, 69.70275297760963, 69.33877810835838, 69.55704599618912, 68.96804720163345, 64.82797175645828, 70.82214251160622, 75.296151638031, 72.94119000434875, 88.34915801882744, 20.070323534309864, 0.3686111548449844, 1.6238130605779588, 0.9096965985372663, 0.1907754724379629, 0.30047864362131804, 0.06307274132268503, 0.13823561748722568, 5.988900912925601, 22.857793159782887, 31.77941232919693, 35.602098405361176, 14.558349754661322, 17.581605277955532, 43.96969400346279, 60.73671989142895, 65.04002317786217, 68.8080757856369, 34.45269428193569, 0.6015761790331453, 0.02210854960139841, 0.045075311354594305, 0.05106711854750756, 0.04311007462092675, 0.03453707409789786, 0.04041865009639878, 0.055251595767913386, 0.014455994023592211, 0.0362474202120211, 0.08783973069512285, 0.06553109808010049, 0.07867433305364102, 0.12569997139507905, 0.014903791088727303, 0.06541075141285546, 0.027540662413230166, 0.028241474319656845, 0.017523986134619918, 0.044718646313413046, 0.019380999183340464, 0.022096636275819037, 0.02488038026058348, 0.01621109535335563, 0.0390994714689441, 0.047759637236595154, 0.06194852488988545, 0.07099765396560542, 0.09204967471305281, 0.039233948627952486, 0.04115335032111034, 0.05710641205951106, 0.06901333661517128, 0.09976444081985392, 0.04177475428150501, 0.19263370631961152, 0.28494041645899415, 12.56330480799079, 108.80871936678886, 84.70152094960213, 85.60790911316872, 61.958004757761955, 46.84823714196682, 39.142440631985664, 52.29409731924534, 49.667617455124855, 35.93416638672352, 0.8833064802456647, 0.15584143839078024, 0.4470961511833593, 1.5751683083362877, 2.1879382710903883, 2.823478630743921, 1.7290086345747113, 0.20417350897332653, 1.2178806052543223, 49.084033370018005, 94.65748071670532, 89.6295677125454, 86.59368261694908, 86.42033591866493, 88.72842326760292, 86.32911041378975, 89.30372759699821, 85.8093287050724, 85.13009995222092, 85.47676295042038, 80.17819806933403, 84.34060111641884, 83.90618562698364, 83.26701432466507, 72.77405217289925, 61.5447161346674, 61.31990499794483, 59.390858709812164, 62.191566824913025, 64.51992988586426, 69.35099825263023, 71.34250938892365, 72.87658587098122, 72.02674627304077, 71.68260633945465, 71.50230601429939, 68.94712552428246, 68.39802458882332, 62.51125507056713, 60.316002666950226, 56.25828020274639, 57.39620514214039, 57.734364196658134, 55.82272857427597, 55.772928446531296, 55.25732271373272, 56.40228107571602, 63.92221435904503, 70.2229830622673, 75.56415885686874, 70.24571344256401, 71.86165273189545, 70.28561890125275, 62.84719504415989, 58.089987114071846, 61.33151717483997, 66.34735822677612, 68.1340603530407, 67.89794102311134, 68.01797658205032, 68.9135505259037, 58.55852097272873, 73.25838938355446, 63.02503690123558, 65.27357384562492, 65.71077078580856, 68.36929053068161, 65.49525395035744, 66.3747775554657, 68.63274559378624, 67.21931263804436, 68.09433728456497, 67.61384546756744, 66.26249358057976, 62.18769483268261, 57.51165434718132, 54.41764377057552, 53.73704709112644, 53.714624494314194, 55.06049707531929, 51.6865099221468, 54.38487432897091, 51.959738060832024, 56.171424463391304, 55.11242128908634, 58.96455578505993, 58.882529586553574, 57.56143547594547, 56.77744634449482, 58.522871285676956, 57.44665503501892, 56.55443251132965, 57.359415516257286, 57.82862953841686, 56.57147079706192, 63.8282909989357, 73.54572236537933, 75.43200194835663, 75.46638250350952, 76.46084234118462, 73.28128695487976, 72.88432225584984, 73.64780008792877, 72.54765272140503, 72.96659544110298, 66.78911492228508, 74.42178055644035, 80.16629710793495, 74.62584480643272, 90.16065761446953, 27.80948795378208, 0.6541976553853601, 0.5383360537234694, 1.4656796772032976, 0.5472676525823772, 0.9895433171186596, 0.21794518717797473, 0.21860783599549904, 7.546151876449585, 40.32477758824825, 35.562318339943886, 39.64791610836983, 21.21473092585802, 31.877800449728966, 50.62214143574238, 70.0164033472538, 72.89195984601974, 79.32231679558754, 50.67560836672783, 0.5773650063201785, 0.005539307694562012, 0.04074341391969938, 0.06023333997291047, 0.07948168582515791, 0.10030371500761248, 0.041665795870358124, 0.0515678233205108, 0.028269030262890738, 0.13208781456341967, 0.02066587574518053, 0.08611195153207518, 0.06871933481306769, 0.06333102355711162, 0.023988958855625242, 0.032151629638974555, 0.04202288022497669, 0.03353144915308803, 0.031148821144597605, 0.07049227366223931, 0.09627229461329989, 0.11634215712547302, 0.1389794869464822, 0.23118722427170724, 0.15178281086264178, 0.14045008225366473, 0.16094149206764996, 0.159308678121306, 0.1929245688370429, 0.20714656740892678, 0.14676480903290212, 0.20710264710942283, 0.2108564745867625, 0.20654158346587792, 0.27024081617128104, 0.3982099931454286, 0.5789307598024607, 16.427113227546215, 122.09007829427719, 98.40595677495003, 96.41655072569847, 73.25450599193573, 46.71724297106266, 54.779612347483635, 75.05049481987953, 56.48333452641964, 50.83500601351261, 1.4434319897554815, 0.2546850743237883, 0.4178204439813271, 3.7925275694578886, 4.987061871215701, 5.8047642186284065, 6.8469594698399305, 5.19882308319211, 1.0756990034133196, 52.70648159086704, 95.67628964781761, 91.06350436806679, 87.61040925979614, 87.60907173156738, 88.59310492873192, 87.28266164660454, 91.94660738110542, 86.32042407989502, 86.78059458732605, 85.0494834780693, 83.65552067756653, 88.02440464496613, 87.35257029533386, 86.60379007458687, 74.50419053435326, 63.74752253293991, 64.0789483487606, 61.71988293528557, 65.27641609311104, 69.25843521952629, 74.98713701963425, 75.25726452469826, 75.70926547050476, 75.76113268733025, 74.99235033988953, 75.21705508232117, 72.5989043712616, 72.87861496210098, 63.91675025224686, 62.29645639657974, 59.49531890451908, 60.889912471175194, 61.37590639293194, 59.623915404081345, 59.28233653306961, 57.41629086434841, 58.41659098863602, 67.13319405913353, 75.42890131473541, 81.46460384130478, 74.57537591457367, 75.86628824472427, 74.1499051451683, 66.84730499982834, 61.427963599562645, 64.73543912172318, 69.52233105897903, 72.43313446640968, 74.60260525345802, 71.74931555986404, 72.74645805358887, 61.47502787411213, 75.84380865097046, 67.35697165131569, 69.11272823810577, 70.29495120048523, 73.14253360033035, 68.87534737586975, 69.36484470963478, 70.86280032992363, 70.13659849762917, 72.87432879209518, 71.71995833516121, 69.81553092598915, 66.9452029466629, 59.83305998146534, 56.21832154691219, 55.16832008957863, 56.73632875084877, 57.430467903614044, 56.502135917544365, 57.520979046821594, 54.110559448599815, 59.16795887053013, 59.12401802837849, 63.515104204416275, 61.705705896019936, 61.87706150114536, 61.86415359377861, 62.17762917280197, 60.01150980591774, 58.74425880610943, 59.65044178068638, 61.47275559604168, 58.53126123547554, 69.2266309261322, 78.15024688839912, 79.27857354283333, 80.83375409245491, 78.1112989783287, 75.72247356176376, 78.24689850211143, 75.8254936337471, 76.28099039196968, 76.42700895667076, 69.15001183748245, 77.14083105325699, 86.42604321241379, 77.41336762905121, 97.63767600059509, 25.517798624932766, 1.5656701242551208, 7.219476280733943, 2.6988495932891965, 1.042702286504209, 1.3716423232108355, 0.2994646324077621, 0.339865816058591, 11.334014721214771, 45.719481110572815, 45.92221923172474, 53.28372001647949, 20.892633609473705, 31.02152019739151, 60.050761699676514, 81.80841699242592, 82.23660841584206, 91.85550346970558, 53.517901450395584, 0.8615278301294893, 0.19539832515874878, 0.14357450912939385, 0.11055211391067132, 0.13493009173544124, 0.2421298949047923, 0.13326074928045273, 0.1539412880083546, 0.16025919117964804, 0.18953746621264145, 0.15742813528049737, 0.17858059087302536, 0.13908442662796006, 0.2948609122540802, 0.1210769999306649, 0.1406591897830367, 0.2031511560198851, 0.11799348023487255, 0.07461487432010472, 0.15068181994138286], [0.03333893975650426, 0.031758113254909404, 0.025487618477200158, 0.04052569005580153, 0.026931687571050134, 0.032696176785975695, 0.02315518748218892, 0.08132902497891337, 0.03162710192555096, 0.21021341846790165, 0.03794119045778643, 0.11256309662712738, 0.00890624431121978, 0.14083237736485898, 0.029766500592813827, 0.17030077578965575, 0.04713101589004509, 42.964119762182236, 88.78618776798248, 77.20903739333153, 69.89604860544205, 64.53724935650826, 28.022363930940628, 38.2971265912056, 46.30661800503731, 32.614261731505394, 15.9760033339262, 0.12993469572393224, 0.2762966224690899, 1.5120852808468044, 1.1827516090124846, 0.8905318519100547, 0.30935084098018706, 1.445031703915447, 0.2816491696285084, 20.201095417141914, 86.46145731210709, 84.43863585591316, 89.34244751930237, 79.7098807990551, 82.65651628375053, 77.91662782430649, 88.17253589630127, 82.48114049434662, 80.3927193582058, 71.98777556419373, 78.71040523052216, 86.51975378394127, 79.73807528614998, 77.36279234290123, 81.39914855360985, 72.60547041893005, 62.980510890483856, 55.61918869614601, 58.40485341846943, 57.017787247896194, 61.03484429419041, 61.02362349629402, 61.76798075437546, 61.243236511945724, 60.097670182585716, 59.78340804576874, 60.80637015402317, 56.017285734415054, 54.89093117415905, 54.77739326655865, 54.70431938767433, 53.34631785750389, 52.749316692352295, 51.006411015987396, 51.378186866641045, 53.2889561355114, 52.376408502459526, 58.45784917473793, 64.66122910380363, 66.13165900111198, 65.03991678357124, 62.84527614712715, 64.58656311035156, 67.88085713982582, 63.57311949133873, 59.50038783252239, 54.2294854670763, 57.09537148475647, 59.361531883478165, 58.72693173587322, 65.36854594945908, 65.20991206169128, 58.21624293923378, 68.82680118083954, 60.42073264718056, 58.39785039424896, 66.47856518626213, 61.2368718534708, 62.75867499411106, 62.61734917759895, 64.77133199572563, 62.81670928001404, 62.95845687389374, 66.36375814676285, 62.18232572078705, 60.205029621720314, 59.8160482943058, 55.72793126106262, 54.265203550457954, 53.6192724108696, 52.619188874959946, 50.51465280354023, 49.02563810348511, 49.23284098505974, 48.345178216695786, 49.669813737273216, 52.0319189876318, 52.43082918226719, 52.464613169431686, 51.44700117409229, 51.162495240569115, 53.76149497926235, 53.64202938973904, 53.50248567759991, 53.32616373896599, 53.948144763708115, 58.12557600438595, 66.55150607228279, 71.371631026268, 71.33430942893028, 70.41419640183449, 75.9271989762783, 72.0837052166462, 71.77460700273514, 73.22512596845627, 70.92988193035126, 70.49696356058121, 70.45017287135124, 75.04087373614311, 78.0136290192604, 73.41536656022072, 75.5546061694622, 10.513871479779482, 0.29136952303815633, 0.5962604423984885, 0.6564514094498008, 0.8289996162056923, 0.10992795287165791, 0.09450250247027725, 1.0484032868407667, 14.436811376363039, 21.6495605930686, 47.493909895420074, 55.197962298989296, 22.57750879973173, 25.916921608150005, 49.635049402713776, 58.44636619091034, 58.25310096144676, 66.23724013566971, 7.338628387078643, 0.37923464260529727, 0.10274959626258351, 0.06389961257809773, 0.04931501920509618, 0.033082130685215816, 0.05548957284190692, 0.10729574059951119, 0.03055580804357305, 0.046202563171391375, 0.06048020426533185, 0.05445615817734506, 0.07821443155989982, 0.03640776121756062, 0.04139937227591872, 0.10758591291960329, 0.042933499134960584, 0.012490378794609569, 0.04634481061657425, 0.02537032760301372, 0.07104685093509033, 0.06363098480505869, 0.03872460525599308, 0.009014813094836427, 0.051318302139407024, 0.0854801686364226, 0.045767905830871314, 0.06245750832022168, 0.031420291343238205, 0.0719850072346162, 0.04929730042931624, 0.0897148707008455, 0.0755462548113428, 0.030883974613971077, 0.12129459762945771, 0.09211734373820946, 0.06384173990227282, 57.3355907946825, 100.16121178865433, 84.71815645694733, 82.51664578914642, 76.73203378915787, 40.394237861037254, 39.74281221628189, 38.0382426828146, 40.38987949490547, 18.378751203417778, 0.15549000177998096, 0.3905712452251464, 2.6835038792341948, 2.898427709005773, 3.129069395363331, 4.110487857833505, 0.6283812469337136, 0.6507714267354459, 23.38460449129343, 91.00088372826576, 89.9897351861, 93.99419590830803, 83.2101009786129, 87.28423476219177, 79.7124494612217, 87.90188401937485, 84.18876886367798, 82.99465253949165, 74.27364930510521, 83.1679156422615, 88.88539284467697, 82.43135556578636, 79.74561408162117, 83.4435148537159, 74.95447397232056, 64.67170134186745, 57.93673373758793, 60.611254423856735, 59.05618406832218, 62.24194452166557, 65.29348477721214, 66.85551255941391, 64.2820854485035, 62.50766046345234, 61.83314725756645, 63.39346893131733, 57.60014399886131, 58.31583559513092, 57.6177142560482, 56.834390088915825, 56.27373397350311, 53.8995111733675, 52.93160431087017, 54.96302850544453, 57.54924952983856, 56.39451049268246, 61.035364866256714, 67.6429671049118, 69.10052329301834, 69.33268323540688, 67.20208436250687, 66.78978368639946, 68.30703467130661, 65.86380377411842, 63.66585731506348, 57.50415734946728, 61.66946344077587, 60.61257675290108, 62.326429188251495, 70.13718366622925, 70.04450663924217, 61.8768373131752, 70.79321846365929, 62.14959427714348, 61.88253700733185, 70.05592122673988, 67.16245248913765, 66.36335536837578, 65.11934772133827, 66.05678781867027, 64.51084837317467, 66.63345247507095, 68.69373992085457, 64.89402741193771, 63.31996187567711, 62.36593946814537, 57.911411896348, 57.107922211289406, 58.040266782045364, 55.51028273999691, 52.571569830179214, 51.86245568096638, 51.023517698049545, 50.46130746603012, 52.839527651667595, 53.73328909277916, 54.68768008053303, 54.78974260389805, 53.99548262357712, 53.34140092134476, 57.16797798871994, 57.6101678609848, 55.85771709680557, 56.31698705255985, 55.852625370025635, 59.73488084971905, 72.2080497443676, 74.29178193211555, 74.95469436049461, 73.9097048342228, 77.00156852602959, 73.3387778699398, 75.00035271048546, 74.29747402667999, 73.06690245866776, 74.33766067028046, 75.31412467360497, 76.5355995297432, 83.66817399859428, 74.57748860120773, 80.10757505893707, 16.6856836527586, 0.1974910925491713, 0.8929647307377309, 0.740150052588433, 1.3302653934806585, 0.7831349491607398, 0.12956050486536697, 0.39340728835668415, 19.497939348220825, 29.183517023921013, 46.51532180607319, 41.821201890707016, 25.3431523963809, 38.790978491306305, 57.1169201284647, 67.52806887030602, 62.85960517823696, 79.1522379219532, 15.14119952917099, 0.48199615033809096, 0.09358307797810994, 0.10990689072059467, 0.050239412375958636, 0.0595442113262834, 0.025177894276566803, 0.02717880233831238, 0.022969019737502094, 0.06451612207456492, 0.04884530651906971, 0.05602256474958267, 0.030343453618115745, 0.018685857285163365, 0.024087185811367817, 0.050883084477391094, 0.05971530976239592, 0.03234777926991228, 0.01586484635481611, 0.024736505656619556, 0.14317167137051, 0.14477999444352463, 0.1374021262745373, 0.24377005611313507, 0.12241435746545903, 0.15379089920315892, 0.17469017853727564, 0.13633709982968867, 0.09900497141643427, 0.28288546891417354, 0.22800790815381333, 0.3402571950573474, 0.19867793511366472, 0.18863473262172192, 0.2176390215754509, 0.2113058598479256, 0.1682128175161779, 64.57035318017006, 112.9041700065136, 98.41336637735367, 94.17895719408989, 85.85026010870934, 39.01703216135502, 53.15565548837185, 67.58764207363129, 54.365233182907104, 26.164364330470562, 0.2871852944372222, 1.1720310780219734, 6.649934342131019, 6.1104644648730755, 3.628520295023918, 6.54661076143384, 6.35953065007925, 2.380048125050962, 26.145150661468506, 92.25705832242966, 89.66991394758224, 95.91710552573204, 85.31394928693771, 91.73697263002396, 82.32373774051666, 89.90827515721321, 86.14260122179985, 84.88241404294968, 75.51334798336029, 84.75649639964104, 85.79544425010681, 86.58620461821556, 82.33101055026054, 87.82727122306824, 77.64455482363701, 68.75827565789223, 61.490219458937645, 63.88478636741638, 62.85721890628338, 66.64891764521599, 69.023227840662, 70.49735113978386, 67.37050652503967, 65.18440023064613, 65.13045832514763, 65.16122907400131, 60.15234164893627, 60.06706662476063, 60.43205603957176, 58.04533191025257, 56.83047629892826, 58.754495456814766, 57.34765514731407, 58.58174912631512, 61.399115547537804, 58.59100162982941, 65.49707785248756, 69.72615212202072, 73.33024352788925, 73.61445307731628, 72.0732481777668, 73.04522842168808, 72.54075229167938, 69.26729634404182, 65.21394744515419, 60.96750430762768, 64.37131986021996, 63.94177570939064, 65.52837297320366, 73.2611708343029, 71.90995573997498, 65.75998574495316, 76.07033729553223, 67.08305954933167, 66.00438863039017, 72.77338340878487, 69.10351753234863, 70.21765574812889, 69.37635809183121, 69.52132791280746, 66.6690793633461, 67.71510243415833, 71.98136910796165, 67.42286771535873, 66.24911069869995, 65.68257629871368, 61.22335597872734, 58.89386057853699, 59.06407244503498, 57.81300477683544, 55.772096291184425, 54.80163216590881, 53.69773440063, 53.3980330824852, 56.263831704854965, 57.17265173792839, 57.48418942093849, 59.36931386590004, 56.2115541100502, 57.24192962050438, 60.592183247208595, 59.06439162790775, 59.02256727218628, 58.795210272073746, 61.06797091662884, 62.956705167889595, 73.77323135733604, 78.90096500515938, 78.08727666735649, 75.35729795694351, 79.36787635087967, 76.55059352517128, 78.69145184755325, 78.05247813463211, 76.96658000349998, 78.01657766103745, 80.16720905900002, 81.21462285518646, 87.14486584067345, 79.16875943541527, 84.52071145176888, 15.074504557996988, 1.9282935722731054, 5.3937288746237755, 1.5289978170767426, 3.405645629391074, 1.3552405033260584, 0.26000864803791046, 2.041726866737008, 25.84462858736515, 36.38962134718895, 65.3195209801197, 76.40322983264923, 31.548230834305286, 41.325537487864494, 64.1486594080925, 78.99579271674156, 74.77188616991043, 89.25985515117645, 13.462349865585566, 0.4697374440729618, 0.239672391617205, 0.28152057027909905, 0.27327676420100033, 0.27871118509210646, 0.1812750767567195, 0.23959782061865553, 0.11272490708506666, 0.1904195235692896, 0.17355018033413216, 0.22016242757672444, 0.1618634324404411, 0.16446869733044878, 0.18495791038731113, 0.1599066858761944, 0.1280285487882793, 0.12123104752390645, 0.1880153955426067, 0.13543947221478447], [0.04103392391698435, 0.036213014245731756, 0.05507146910531446, 0.050965021291631274, 0.03619935872848146, 0.07039650692604482, 0.037704385977122, 0.009246974514098838, 0.0836307143617887, 0.020339212023827713, 0.060326561142574064, 0.014491967776848469, 0.04465830970730167, 0.04865370996412821, 0.09184687543893233, 0.048504104124731384, 2.6429645670577884, 79.22708630561829, 78.85719895362854, 79.31675389409065, 57.52326272428036, 27.54267957061529, 27.725096382200718, 65.65575733780861, 51.04031279683113, 36.884552389383316, 2.7651999704539776, 0.06941155079402961, 0.2675950003322214, 1.5718552423641086, 0.47050633875187486, 1.5981899667531252, 2.003685920499265, 0.642491492908448, 4.421752905473113, 64.2518998682499, 90.19284948706627, 90.47984808683395, 85.80630406737328, 81.67595610022545, 85.16861468553543, 84.17841821908951, 82.36936569213867, 77.39686891436577, 79.67749133706093, 82.60470986366272, 69.77345958352089, 75.53554639220238, 86.65599167346954, 72.58568868041039, 77.56875649094582, 75.76148986816406, 61.61596231162548, 56.38872340321541, 57.22643785178661, 55.449026226997375, 55.25509983301163, 56.26817487180233, 59.78317625820637, 57.767061442136765, 56.15356162190437, 56.74926705658436, 56.55676178634167, 57.76125155389309, 58.11843618750572, 55.33880554139614, 55.651467964053154, 53.73917117714882, 52.48790591955185, 50.935518220067024, 53.41067120432854, 53.425452411174774, 52.34944134950638, 56.04679115116596, 61.78531922399998, 62.13980980217457, 67.31622263789177, 67.21879586577415, 63.24262462556362, 65.62583014369011, 67.13095217943192, 66.25364005565643, 62.81510956585407, 54.624067693948746, 56.90448872745037, 58.925733268260956, 66.30253583192825, 60.78455172479153, 55.9663038700819, 65.70725217461586, 59.513390734791756, 58.05601693689823, 63.390128910541534, 65.01829594373703, 57.878410667181015, 59.38213437795639, 59.78450618684292, 61.46305091679096, 63.043074533343315, 66.02412477135658, 64.4205804169178, 67.09979385137558, 64.19746398925781, 66.80060550570488, 64.64385643601418, 64.40984979271889, 64.60335820913315, 55.61959907412529, 50.35484857857227, 49.125880524516106, 50.49783870577812, 51.98075853288174, 49.68418076634407, 49.77277681231499, 50.07336728274822, 50.72603926062584, 53.17557401955128, 54.607774168252945, 54.67560052871704, 51.012825071811676, 53.877905532717705, 54.1801755130291, 57.16472536325455, 66.81205049157143, 72.00477585196495, 69.84864234924316, 74.04727265238762, 73.26484903693199, 73.57363566756248, 72.62922674417496, 71.31902664899826, 69.78599891066551, 67.52915561199188, 69.28317949175835, 73.78318682312965, 71.76940888166428, 76.35170459747314, 75.56733548641205, 71.84987336397171, 5.959766451269388, 1.8863429920747876, 1.1063539772294462, 0.3187224146677181, 0.811581410234794, 0.016837540351843927, 0.18667354801436886, 18.967031836509705, 25.31822383403778, 34.451504945755005, 68.40292632579803, 29.172963090240955, 15.507585369050503, 49.22219015657902, 56.498731300234795, 54.37078848481178, 66.45419329404831, 41.632462218403816, 1.0941671999171376, 0.1714196227840148, 0.013042932787357131, 0.12220812204759568, 0.03991856501670554, 0.08754185488214716, 0.04693950468208641, 0.08311950819916092, 0.016631397702440154, 0.07173420584877022, 0.021788498415844515, 0.03987395451986231, 0.02811567286698846, 0.024018108560994733, 0.07095074281096458, 0.03407087548112031, 0.03755050536710769, 0.05438526452053338, 0.08939607374486513, 0.026806715468410403, 0.07241728599183261, 0.05555910094699357, 0.05136971813044511, 0.1119660610856954, 0.049577112367842346, 0.005818387689942028, 0.02860855540347984, 0.06953274350962602, 0.055106517029344104, 0.06810643957578577, 0.04396476528199855, 0.10544028977164999, 0.03960445101256482, 0.13461142836604267, 0.19287849630927667, 4.978133300319314, 97.90378332138062, 85.75205057859421, 89.70441609621048, 66.53853356838226, 46.15344062447548, 39.88365925848484, 46.742956191301346, 46.29341371357441, 44.604750126600266, 2.689015483483672, 0.2097376572783105, 1.1345980991609395, 6.370822694152594, 4.003229113295674, 4.417263446375728, 4.070383384823799, 0.42337800201494247, 5.4397425055503845, 69.02350142598152, 91.64865016937256, 91.65894001722336, 87.57829338312149, 86.44767165184021, 89.1209726035595, 87.04379126429558, 85.89551568031311, 84.55535799264908, 83.97395119071007, 84.42891597747803, 73.25905054807663, 82.91553318500519, 85.99224328994751, 75.17442137002945, 81.34978920221329, 80.47621607780457, 67.89260610938072, 58.02572876214981, 60.679453164339066, 58.54788914322853, 59.53629970550537, 59.78337004780769, 62.293876335024834, 59.671773836016655, 56.866958141326904, 58.48841853439808, 60.24301618337631, 58.37939478456974, 59.938606917858124, 58.932713493704796, 58.103286400437355, 55.61707600951195, 54.80981692671776, 54.51182931661606, 55.97912058234215, 55.63908442854881, 54.873691499233246, 59.29120145738125, 63.14539924263954, 67.94802233576775, 69.83965203166008, 70.26786625385284, 65.58735340833664, 70.43560445308685, 70.93792229890823, 67.56444811820984, 67.22831055521965, 59.186194092035294, 61.06846868991852, 61.709076315164566, 69.76347371935844, 64.54052478075027, 58.43178257346153, 68.34305673837662, 61.63610503077507, 61.939233765006065, 64.80142638087273, 68.65020185709, 64.3325999379158, 63.183894976973534, 63.318818137049675, 63.62567447125912, 65.57593882083893, 69.2645300924778, 68.37258115410805, 69.852784126997, 68.6740417778492, 69.4375728070736, 68.37334111332893, 68.60436871647835, 66.65305182337761, 60.25641806423664, 51.734356954693794, 51.24251514673233, 53.497682735323906, 53.24468471109867, 53.22417341172695, 53.22714865207672, 53.87106969952583, 52.755552157759666, 55.84769323468208, 55.82504265010357, 57.761821523308754, 54.38134051859379, 55.94542019069195, 57.76894994080067, 59.79606136679649, 69.0636196732521, 75.12268334627151, 74.22083973884583, 76.01892605423927, 76.6054929792881, 75.09125143289566, 75.2871385216713, 74.2678052186966, 72.52649545669556, 70.88701263070107, 71.78164422512054, 78.64872694015503, 75.73933705687523, 80.6360051035881, 76.70448526740074, 80.81535547971725, 9.756407774984837, 1.0881302738562226, 0.055648952766205184, 1.545486794784665, 1.6290282807312906, 0.09083828932489268, 0.21467293932801113, 12.762664910405874, 34.79816034436226, 35.29431492090225, 56.490318551659584, 31.059282571077347, 31.45937830209732, 62.162737771868706, 64.58373606204987, 61.659184992313385, 75.05525216460228, 56.85929395258427, 1.797200725413859, 0.04287341485905927, 0.047390073668793775, 0.10728678287705407, 0.018220736637886148, 0.07157655883929692, 0.02395983141468605, 0.06428003005567007, 0.03312225118861534, 0.039111535079427995, 0.037814409370184876, 0.05247809713182505, 0.04876228987996001, 0.05153865691681858, 0.17458552087191492, 0.04781945433933288, 0.036792100945604034, 0.039630262908758596, 0.03598320450691972, 0.12233176385052502, 0.10041492583695799, 0.2684393269009888, 0.1496491362922825, 0.20691969286417589, 0.22399407665943727, 0.1434791283099912, 0.09344823716674, 0.15937728225253522, 0.10528236074605957, 0.18725135450949892, 0.15807462012162432, 0.17747059027897194, 0.17801523761590943, 0.26330339780543, 0.33602279727347195, 5.330381523817778, 112.51611202955246, 97.97291681170464, 103.72820198535919, 75.85872665047646, 42.50337168574333, 35.496787056326866, 90.9985126554966, 71.76998645067215, 58.50563161075115, 4.807517230510712, 0.22170196840306744, 0.8575735485646874, 7.149433214217424, 5.9859703201800585, 5.536346146836877, 8.178114015609026, 4.010096769779921, 6.302216425538063, 72.37752825021744, 92.35022932291031, 97.4555441737175, 91.38992965221405, 90.06629347801208, 94.02755051851273, 92.39526450634003, 86.61475628614426, 87.6424415409565, 88.0934165418148, 86.24280944466591, 74.6923640370369, 86.90632224082947, 84.63397577404976, 76.19889959692955, 84.0290330350399, 84.38294604420662, 68.6988240480423, 60.761464163661, 62.77204267680645, 62.208836898207664, 62.83737637102604, 64.35971528291702, 66.51707991957664, 63.096875846385956, 60.545198768377304, 63.526302203536034, 60.49092248082161, 61.911742240190506, 64.00188088417053, 61.98174208402634, 61.471311673521996, 58.986590802669525, 57.978938072919846, 56.80408291518688, 58.771328553557396, 58.611854910850525, 59.045537039637566, 62.635641396045685, 67.41639286279678, 69.52043876051903, 73.59142631292343, 75.94982296228409, 69.07609820365906, 71.27454623579979, 73.39070588350296, 73.59581127762794, 68.32676321268082, 61.06298938393593, 61.64759561419487, 64.98481214046478, 71.50628820061684, 65.84390804171562, 64.06339198350906, 72.8194597363472, 65.66976338624954, 63.70135501027107, 68.66866126656532, 71.06263920664787, 67.43975400924683, 68.97152781486511, 70.26168018579483, 67.75988683104515, 69.83630061149597, 73.35269272327423, 71.1498749256134, 73.96736294031143, 71.71203956007957, 75.06032109260559, 71.53613179922104, 71.22144788503647, 70.22507295012474, 63.19682948291302, 55.69295413792133, 54.30583477020264, 55.73456570506096, 58.12121383845806, 54.30330790579319, 56.92391328513622, 55.561120212078094, 57.3686908185482, 59.26866866648197, 59.77367676794529, 59.72715586423874, 55.6262943148613, 60.35031482577324, 60.515305772423744, 64.54006120562553, 73.50843876600266, 77.25295543670654, 77.82100975513458, 79.53873798251152, 79.37831059098244, 78.4327845275402, 78.05048704147339, 78.16007316112518, 77.50217646360397, 74.52190518379211, 74.9967049062252, 82.66062006354332, 78.77136915922165, 83.88533234596252, 82.6780991256237, 81.22868210077286, 8.590048011392355, 5.297334222123027, 5.20028505474329, 2.203377792611718, 2.5776859698817134, 0.14955659047700465, 0.6638492562342435, 26.04547630995512, 42.46834896504879, 50.68733073771, 92.07639321684837, 42.77396656572819, 25.191380940377712, 63.98163557052612, 76.7498928308487, 71.99494197964668, 87.37621262669563, 62.485712841153145, 1.5599168767221272, 0.25270015583373606, 0.12911152036394924, 0.23453428060747683, 0.2033306666999124, 0.19430101528996602, 0.2109305260819383, 0.21807108510984108, 0.08596830142778344, 0.13864632201148197, 0.14873504784191027, 0.1952734959195368, 0.17725192388752475, 0.15063914644997567, 0.2778447128366679, 0.1908638622262515, 0.2158900912036188, 0.12447985092876479, 0.16140668507432565], [0.044932815289939754, 0.017615606120671146, 0.0410096779523883, 0.05300702207023278, 0.0669301206653472, 0.04231117491144687, 0.018687751617108006, 0.03312886743515264, 0.07883104495704174, 0.027667098402162082, 0.12323415605351329, 0.02783334319246933, 0.061779782772646286, 0.03885384285240434, 0.17323098261840641, 0.3942577895941213, 17.333431094884872, 90.24540066719055, 67.31794014573097, 69.71631065011024, 56.11728496849537, 24.118943586945534, 46.690560802817345, 67.4458184838295, 34.10945110023022, 20.246339589357376, 0.052477651843219064, 0.15163095260504633, 0.09655431815190241, 0.9173457662109286, 3.3151287864893675, 3.0106990970671177, 4.166900580748916, 0.3869990509701893, 28.319365493953228, 87.86213055253029, 79.45238381624222, 80.71374893188477, 75.25439947843552, 83.43446373939514, 80.7533124089241, 77.40813910961151, 83.78502532839775, 80.84285080432892, 77.39110842347145, 79.18218031525612, 80.64232036471367, 71.82581305503845, 80.5163723230362, 90.3293077647686, 74.53417092561722, 77.72339299321175, 64.22708719968796, 57.32557073235512, 54.14902098476887, 55.88580138981342, 54.792706444859505, 55.96447616815567, 55.06169781088829, 55.654728189110756, 52.91899658739567, 54.335640370845795, 55.42940028011799, 56.37871854007244, 54.192726239562035, 56.25669948756695, 51.86769559979439, 51.641068160533905, 52.259123995900154, 52.12958514690399, 54.310660511255264, 53.61384630203247, 51.258744075894356, 58.000118136405945, 58.02564136683941, 64.2070546746254, 63.97991806268692, 67.27022230625153, 64.46358650922775, 63.34274925291538, 66.670713275671, 66.24960467219353, 64.32269766926765, 60.485769957304, 57.187892720103264, 58.83413918316364, 68.3655895292759, 62.85231716930866, 51.064274311065674, 67.63751059770584, 54.75130386650562, 59.69190515577793, 62.470019683241844, 65.49631029367447, 62.818593978881836, 63.252162113785744, 60.67652352154255, 59.483566135168076, 59.826615527272224, 60.51609233021736, 62.698839604854584, 63.051392287015915, 62.81572513282299, 64.41665902733803, 64.85324800014496, 69.08518731594086, 65.2606089413166, 60.085955411195755, 51.27839282155037, 50.41600629687309, 47.83472120761871, 50.74605658650398, 51.49729907512665, 53.261931985616684, 53.25790420174599, 52.599756717681885, 51.41510188579559, 54.10575270652771, 51.49963214993477, 53.565554693341255, 52.08897292613983, 53.443410247564316, 52.31316089630127, 59.633460491895676, 69.1875310242176, 69.67180743813515, 71.42549693584442, 71.87597796320915, 70.23963376879692, 70.8227276802063, 69.94448840618134, 66.5466271340847, 64.04247030615807, 59.85772825777531, 66.48047268390656, 76.3684692978859, 74.42282170057297, 75.39591908454895, 74.15004953742027, 70.3374557197094, 2.182659166865051, 0.2985728974454105, 0.9798132267314941, 0.3504048177273944, 0.06456028728280216, 0.027327359894115943, 2.5680860225111246, 38.71188573539257, 26.63558654487133, 43.6080028116703, 44.78171043097973, 17.74049185216427, 12.532216776162386, 41.59554339945316, 57.570235803723335, 58.67864012718201, 65.93514874577522, 19.83415860682726, 0.5005328916013241, 0.13612730952445418, 0.04571974786813371, 0.027471661232993938, 0.128924157761503, 0.06377390760462731, 0.08058957129833288, 0.02926108874817146, 0.1747057933243923, 0.17611949559068307, 0.022245047257456463, 0.03288749503553845, 0.030934396127122454, 0.010520438700041268, 0.008410311547777383, 0.042639686580514535, 0.016134910183609463, 0.08984375206637196, 0.060566972460947, 0.048667291266610846, 0.07487025475711562, 0.022237041339394636, 0.05240906997642014, 0.04228615711326711, 0.08938294515246525, 0.015533641617366811, 0.10830600396730006, 0.022825226769782603, 0.1647030675667338, 0.0035312926411279477, 0.02489993770723231, 0.07790941628627479, 0.30283175641670823, 0.37627733254339546, 25.698277540504932, 104.19550850987434, 73.58794569969177, 79.69695389270782, 65.73299199342728, 33.207820281386375, 31.631415970623493, 51.89264126121998, 42.31376565992832, 23.224353790283203, 0.06454072427004576, 0.2238751103868708, 2.9074465250596404, 1.977656960953027, 4.949229201301932, 4.305376075208187, 0.1627848978387192, 0.948089025914669, 32.06494800746441, 93.21450054645538, 83.42529103159904, 87.06570088863373, 79.98500883579254, 87.99541220068932, 86.39600202441216, 82.35013872385025, 85.77134594321251, 84.76003780961037, 81.23578011989594, 81.72978401184082, 81.1028404533863, 75.28551980853081, 84.97181564569473, 86.49072334170341, 77.8142461180687, 80.15705600380898, 68.24581235647202, 59.93476912379265, 57.191985100507736, 59.76859264075756, 55.353111773729324, 60.300849080085754, 57.52725251019001, 57.9198132455349, 55.113804414868355, 57.55255155265331, 57.73388162255287, 59.34762462973595, 55.7141076028347, 58.40620994567871, 54.52800504863262, 54.78310815989971, 53.82541514933109, 55.06536841392517, 57.1410146355629, 54.75345075130463, 54.57502752542496, 60.25991387665272, 61.71566516160965, 65.09556099772453, 66.7674332857132, 70.54601892828941, 66.15658566355705, 66.58940523862839, 70.33553302288055, 68.51944327354431, 68.79453331232071, 63.13984014093876, 59.91576634347439, 62.03740529716015, 70.25186911225319, 67.23833441734314, 54.72141467034817, 71.5847235918045, 57.84848727285862, 62.9291832447052, 63.26366409659386, 68.37416186928749, 65.70425793528557, 67.29019403457642, 64.54022079706192, 64.3769283592701, 64.29711744189262, 62.6881317794323, 63.89228716492653, 65.17481714487076, 64.58923056721687, 66.77120268344879, 69.07331675291061, 71.69363334774971, 69.47537317872047, 64.69747915863991, 54.308312237262726, 52.80241124331951, 50.70470720529556, 53.61413888633251, 53.42699892818928, 56.072751358151436, 55.043306797742844, 55.811777561903, 53.27207364141941, 55.72210997343063, 54.00348499417305, 56.87769256532192, 54.201131388545036, 55.904686376452446, 55.29075711965561, 63.06845337152481, 70.87072670459747, 71.3892012834549, 74.1207455098629, 75.11111676692963, 73.19542676210403, 74.12247821688652, 71.4780481159687, 68.50292176008224, 68.44536244869232, 65.71010202169418, 68.37995275855064, 79.93846133351326, 75.23906350135803, 80.52508145570755, 76.43280744552612, 81.30614474415779, 3.876708964817226, 0.5739910842385143, 0.661176930880174, 0.905410012928769, 1.1678657890297472, 0.19353928975760937, 0.8666466898284853, 39.207371547818184, 34.994245022535324, 34.1108114272356, 32.362057864665985, 23.3657993003726, 27.4587344750762, 48.55740062892437, 64.4415020942688, 66.73942118883133, 78.71745765209198, 36.19559995830059, 0.9374116582330316, 0.11406893652747385, 0.028089187471778132, 0.0924873785697855, 0.06446455023251474, 0.04486382153118029, 0.1296871152590029, 0.08943281005485915, 0.06279861423536204, 0.14548470819136128, 0.028459281675168313, 0.049688965154928155, 0.04434326430782676, 0.019284100671939086, 0.11909517619642429, 0.07673116779187694, 0.013263525979709812, 0.08183730707969517, 0.19574683770770207, 0.11010593472747132, 0.17347197281196713, 0.18392341589787975, 0.23257818713318557, 0.11096393165644258, 0.12152777300798334, 0.11779124499298632, 0.3283754107542336, 0.14642857160652056, 0.22345544071868062, 0.1728347796597518, 0.12668040784774348, 0.22722384397638962, 0.4872001492185518, 0.7328846643213183, 30.307817794382572, 118.53277757763863, 85.56312471628189, 89.90740120410919, 74.91148307919502, 36.46133489906788, 64.3682724237442, 92.63532802462578, 49.45273518562317, 34.65141601860523, 0.20954312552930787, 0.3674425691133365, 3.6976613849401474, 6.085627572610974, 6.973046204075217, 13.581280633807182, 12.122904639691114, 1.556898057460785, 35.92327997088432, 95.61186030507088, 88.55876997113228, 92.71362662315369, 88.26443776488304, 93.84313881397247, 90.03765821456909, 84.51625049114227, 88.86001020669937, 90.91380000114441, 86.1735163629055, 85.43872699141502, 84.74518060684204, 79.09514218568802, 88.00981342792511, 87.98528954386711, 82.33220368623734, 82.62054741382599, 70.73531717061996, 62.630333080887794, 58.6018842458725, 61.9330894947052, 58.45663703978062, 63.81254464387894, 60.78233644366264, 61.81656874716282, 59.088816717267036, 60.51674209535122, 62.60142043232918, 60.793477445840836, 58.909268751740456, 61.78403489291668, 57.202404141426086, 56.781652718782425, 57.089588195085526, 57.62852467596531, 61.87005467712879, 57.214468494057655, 57.97617182135582, 65.43743625283241, 64.07129555940628, 69.43786919116974, 70.84662079811096, 74.11495462059975, 69.15389522910118, 67.94843271374702, 73.53065237402916, 71.05687111616135, 70.58250457048416, 65.75572237372398, 63.47483776509762, 66.42776191234589, 73.64846885204315, 68.22456389665604, 57.83772625029087, 74.59553003311157, 62.059029936790466, 65.13109669089317, 67.5069572031498, 70.32929375767708, 70.58517962694168, 69.57134082913399, 67.47184708714485, 67.53848791122437, 65.1906318962574, 65.4764449596405, 66.9658662378788, 67.59204983711243, 67.61053204536438, 70.88024139404297, 71.43435046076775, 76.54950678348541, 73.09423819184303, 66.46501511335373, 57.395122200250626, 55.497561022639275, 53.897269293665886, 57.06318341195583, 58.91215659677982, 59.201142489910126, 58.557985201478004, 58.870130851864815, 56.16228215396404, 59.85889099538326, 57.41369940340519, 59.83719415962696, 58.69660556316376, 59.779855236411095, 58.57567325234413, 67.15894147753716, 76.33916527032852, 75.35749554634094, 78.42577770352364, 79.01112869381905, 76.08092352747917, 78.95710319280624, 77.41669625043869, 72.09527179598808, 72.53320589661598, 68.58480736613274, 74.45730865001678, 85.10206505656242, 80.72645545005798, 83.09024780988693, 79.7362893819809, 78.20858135819435, 2.8730935184285045, 3.8307632552459836, 4.195919623598456, 1.4009323390200734, 1.198339678812772, 0.3317376069026068, 4.856197368353605, 49.49118532240391, 42.93068155646324, 59.7785747051239, 59.371582344174385, 25.595379061996937, 23.027368560433388, 56.756904646754265, 77.34528288245201, 73.78591507673264, 91.6320526599884, 34.632819816470146, 0.8720078459009528, 0.2825185807887465, 0.1471338197006844, 0.18104535236489028, 0.22275906871072948, 0.12274364096811041, 0.2384143919334747, 0.1580632949480787, 0.24425349110970274, 0.2641823678277433, 0.12166909276857041, 0.1923541838186793, 0.10502362580155022, 0.09868998909951188, 0.22548715904122218, 0.17045460816007107, 0.18873844033805653, 0.15612498333211988], [0.035750986498896964, 0.030244786939874757, 0.01658275734371273, 0.029843038282706402, 0.035504430197761394, 0.039785538756405, 0.02106523283146089, 0.026566003580228426, 0.058054513137903996, 0.005160680648259586, 0.07733085280051455, 0.0948268135834951, 0.07184281916124746, 0.04020737178507261, 0.023286300856852904, 0.04148749489104375, 54.54259626567364, 82.81554535031319, 78.7361678481102, 68.71184974908829, 44.56873565912247, 34.88115169107914, 84.26808580756187, 49.85004186630249, 34.44268561899662, 5.8842939510941505, 0.23420455923769623, 0.35006277670618147, 2.8365803277119994, 5.408824989572167, 3.9160527661442757, 3.173210439272225, 1.801370051689446, 4.06768505461514, 66.29680573940277, 81.42029821872711, 78.44318836927414, 79.93499591946602, 76.872778236866, 73.83327573537827, 79.14660662412643, 81.86821058392525, 77.37587884068489, 76.54085084795952, 71.6377155482769, 80.30704155564308, 74.80870619416237, 81.5048436820507, 67.58512660861015, 86.37685105204582, 80.39382889866829, 76.52632802724838, 66.21640965342522, 56.933621764183044, 59.29266817867756, 55.4008562117815, 53.939868807792664, 54.293124452233315, 53.60984891653061, 52.78597332537174, 53.125895485281944, 55.55065177381039, 53.649796172976494, 56.57924897968769, 53.69227409362793, 55.509910359978676, 51.54230386018753, 51.19840711355209, 52.9923402518034, 51.529984921216965, 52.24548652768135, 49.288268610835075, 48.81790705025196, 52.868675887584686, 56.41209974884987, 57.19285145401955, 61.906175538897514, 64.30037006735802, 68.64862114191055, 63.707206696271896, 58.54892648756504, 68.20380181074142, 68.17970350384712, 60.80974817276001, 58.53412628173828, 57.60807417333126, 67.72600784897804, 62.796555161476135, 50.55497244000435, 64.9108225107193, 56.62078455090523, 64.06308799982071, 66.41810283064842, 65.45224025845528, 61.06228642165661, 65.44955000281334, 64.15944322943687, 65.29872849583626, 56.10889881849289, 55.439310148358345, 57.11625136435032, 59.48518864810467, 58.36111016571522, 62.39968165755272, 62.39604525268078, 69.48985040187836, 63.189324885606766, 59.767137318849564, 54.18155483901501, 50.720787942409515, 49.17970843613148, 48.731343895196915, 46.96421831846237, 50.50247065722942, 50.2473371475935, 51.864366978406906, 52.673161178827286, 52.457632943987846, 51.37128263711929, 55.08950471878052, 51.262790858745575, 55.43307468295097, 51.37024909257889, 53.55835407972336, 58.584234192967415, 64.95820596814156, 58.72268356382847, 59.39481809735298, 53.36194261908531, 58.22314716875553, 52.4385541677475, 56.934951692819595, 50.75768396258354, 55.97510799765587, 51.4963149279356, 60.32234452664852, 64.85621184110641, 77.51657009124756, 71.19348898530006, 83.84334459900856, 47.295841723680496, 0.08362318156287074, 2.494739033281803, 1.4120880654081702, 0.18537860421929508, 0.15870125993387774, 0.03579208663722966, 18.497221246361732, 60.14307774603367, 30.75409434735775, 70.67331209778786, 49.97869536280632, 24.765271805226803, 38.686130717396736, 50.68207561969757, 63.189967051148415, 60.78644782304764, 60.67612074315548, 6.67537777684629, 0.4180599201936275, 0.05201410640438553, 0.06326490562059917, 0.037164328823564574, 0.02909311660914682, 0.08344447240233421, 0.058986847288906574, 0.016893954707484227, 0.062241257619461976, 0.020336462366685737, 0.05731236917199567, 0.08841067232424393, 0.08447990941931494, 0.038943290201132186, 0.017100817240134347, 0.009465888597333105, 0.03561570410965942, 0.023698552759015, 0.027976633355137892, 0.015616093296557665, 0.04874746176938061, 0.07961686060298234, 0.04479419694689568, 0.0553427982958965, 0.09801076070289128, 0.01684524570009671, 0.021614058459817898, 0.13655949180247262, 0.03734154626727104, 0.039240167825482786, 0.06347954215016216, 0.02869371684937505, 0.07488710893085226, 70.5529573559761, 90.70959135890007, 86.87663063406944, 78.5719482600689, 59.42903906106949, 41.64294205605984, 57.20202796161175, 45.78662730753422, 41.40582337975502, 6.395382676273584, 0.4675259627401829, 0.9377194417174906, 2.78053333517164, 3.888374101370573, 5.423338310793042, 5.129197044298053, 0.9682070463895798, 7.346682529896498, 72.80109912157059, 86.95928379893303, 88.78975957632065, 84.42986592650414, 83.36400032043457, 81.48651346564293, 84.60088714957237, 86.60978615283966, 83.96004393696785, 80.19844338297844, 77.89562255144119, 80.86640954017639, 80.15737518668175, 81.62139862775803, 72.47313112020493, 87.75911048054695, 81.74368366599083, 80.2047510445118, 69.17604804039001, 60.20353250205517, 60.6038486212492, 57.303718104958534, 55.678590908646584, 56.463332399725914, 56.221391782164574, 55.956169813871384, 56.04973219335079, 59.16140042245388, 55.98959282040596, 58.532997742295265, 55.614362955093384, 56.59583508968353, 54.83700826764107, 54.5049174875021, 54.21663835644722, 54.73220229148865, 55.015917867422104, 52.61505089700222, 52.71423697471619, 53.79195034503937, 58.65541197359562, 59.1592763364315, 65.40405884385109, 68.65682870149612, 70.89254513382912, 65.57707875967026, 62.61796094477177, 70.39261355996132, 69.89916443824768, 64.60119992494583, 60.84957763552666, 61.12392671406269, 71.62586778402328, 66.24292463064194, 53.24283801019192, 68.36603790521622, 60.63902333378792, 67.70220592617989, 66.6562132537365, 68.9496485888958, 64.5214270055294, 67.36776307225227, 65.93645587563515, 66.12874075770378, 57.581657990813255, 57.174164056777954, 58.008565083146095, 60.178944021463394, 58.77035580575466, 64.14878100156784, 63.9149871468544, 70.10517418384552, 66.80161625146866, 62.787971422076225, 56.731677800416946, 53.05775374174118, 52.79836066067219, 52.06469222903252, 51.51839554309845, 52.52913370728493, 53.03261049091816, 54.57589387893677, 55.144590362906456, 54.21166442334652, 55.766495391726494, 57.07938194274902, 54.0861039608717, 56.95421285927296, 54.440077766776085, 54.47404034435749, 61.07731081545353, 66.12949311733246, 61.49245373904705, 60.16767002642155, 57.27129824459553, 59.5416422188282, 53.70732128620148, 58.839105516672134, 54.06542547047138, 58.70267763733864, 55.042037665843964, 61.88066750764847, 67.08176761865616, 78.89844194054604, 73.8785845041275, 84.79650065302849, 57.49463126063347, 0.05563461447309237, 0.4654769820626825, 2.500432077795267, 0.9902357705868781, 0.4122756508877501, 0.0246601850449224, 14.970404393970966, 71.82749256491661, 34.76070195436478, 48.02924796938896, 33.28292705118656, 30.919858552515507, 52.30282545089722, 59.17143188416958, 70.8144973218441, 63.366410583257675, 75.18849581480026, 14.836605973541737, 0.5178904789499938, 0.16148848459124565, 0.12199404955026694, 0.01848232885095058, 0.04865987350058276, 0.017713502820697613, 0.05226405803114176, 0.006897143866808619, 0.063024501723703, 0.08104306805762462, 0.01583948716870509, 0.03505652552121319, 0.02197500940383179, 0.07581831130664796, 0.11235704674618319, 0.05295020695484709, 0.03212974741472863, 0.14534997870214283, 0.15881632250966504, 0.06968996749492362, 0.1974958274513483, 0.17183440912049264, 0.19358853867743164, 0.19389474880881608, 0.1548156121862121, 0.2364897061488591, 0.13070379820419475, 0.2374059913563542, 0.19935671822167933, 0.11714974738424644, 0.13314240641193464, 0.0663338421145454, 0.11151139915455133, 78.01072597503662, 103.46483051776886, 99.2835196852684, 88.05867120623589, 65.07122710347176, 52.66228996217251, 112.61183649301529, 70.82879215478897, 56.50889955461025, 8.788909390568733, 0.6499873625580221, 1.5355658833868802, 6.104036159813404, 11.168601047247648, 9.906575717031956, 15.237189028412104, 8.01289128139615, 9.537625014781952, 80.48443883657455, 90.07875680923462, 90.78186348080635, 87.17214837670326, 86.72036021947861, 83.78731280565262, 89.26955223083496, 90.2528178691864, 90.25267347693443, 84.9335440993309, 82.79555082321167, 84.31783273816109, 84.70220491290092, 83.59108373522758, 77.01600775122643, 88.48638385534286, 82.05047160387039, 84.50785294175148, 71.32828295230865, 63.13589595258236, 62.51423791050911, 60.20206198096275, 58.916290774941444, 60.67372307181358, 58.54741036891937, 58.12713012099266, 58.39758060872555, 61.43286153674126, 60.07834441959858, 62.857773676514626, 60.427830666303635, 60.724172964692116, 56.90573126077652, 56.52897767722607, 57.12847150862217, 56.8404583632946, 57.37458810210228, 55.344296246767044, 56.12192451953888, 59.12939853966236, 62.043268382549286, 62.67223723232746, 68.62953096628189, 72.63909101486206, 74.07476797699928, 69.87629726529121, 65.20159810781479, 73.68436172604561, 73.77606600522995, 68.19181725382805, 63.138422816991806, 63.30866128206253, 74.16081815958023, 71.34696274995804, 56.523517370224, 71.37824267148972, 63.26157420873642, 70.70956975221634, 72.99411356449127, 71.5785451233387, 67.84656777977943, 70.92815682291985, 69.87586408853531, 67.99940317869186, 61.021526008844376, 60.12013077735901, 58.990364000201225, 61.00582145154476, 61.39914974570274, 65.70723697543144, 66.62006959319115, 72.41840645670891, 68.36523234844208, 65.77333822846413, 58.943998888134956, 55.56038685142994, 55.9710194170475, 55.350265726447105, 53.53027358651161, 55.69873362779617, 56.56447157263756, 56.118147522211075, 58.470415100455284, 57.570467591285706, 58.411195278167725, 60.088923051953316, 56.55718736350536, 60.843254774808884, 58.20984408259392, 59.27547410130501, 64.05038148164749, 72.00432747602463, 66.83261498808861, 65.18125399947166, 60.974963307380676, 63.113784939050674, 57.69680701196194, 63.12005080282688, 56.671728417277336, 61.65730029344559, 58.547395169734955, 66.03077441453934, 73.19263011217117, 84.51556652784348, 77.75256022810936, 90.9135340154171, 55.834025368094444, 0.08182058649254031, 8.955628294497728, 4.975887620821595, 1.2213787925429642, 0.3656086331466213, 0.09271463903132826, 25.232783518731594, 78.64345282316208, 48.124778643250465, 91.16646364331245, 67.75988683104515, 34.65122602880001, 56.00308209657669, 67.73072719573975, 82.50425085425377, 74.72404673695564, 85.80128073692322, 12.363465931266546, 0.7348493370227516, 0.18317346082767472, 0.22396639455109835, 0.09736075808177702, 0.12836564710596576, 0.11505222282721661, 0.16663958318531513, 0.06826993470895104, 0.19430039188591763, 0.2082868476281874, 0.14770960755413398, 0.13670801039552316, 0.16376846615457907, 0.16871615691343322, 0.15584470384055749, 0.17652191774686798, 0.17528601922094822], [0.0333119292918127, 0.020797495635633823, 0.06704272673232481, 0.06679866404738277, 0.03051816445804434, 0.009996036224038107, 0.030761100933887064, 0.0574438480543904, 0.05263651968562044, 0.05278402524709236, 0.09611465502530336, 0.08663279819302261, 0.1354995119618252, 0.14933823578758165, 0.17355973919620737, 5.317625608295202, 82.42078453302383, 73.47037240862846, 69.05839115381241, 60.79049080610275, 28.874168023467064, 36.95452183485031, 53.0573433637619, 35.26973403990269, 23.87890476733446, 0.07654145258129574, 0.13155621418263763, 0.2538745600031689, 1.8897715955972672, 1.3683101395145059, 5.4899948090314865, 1.8336527631618083, 0.2258191365399398, 27.61975083500147, 79.89230901002884, 84.18163284659386, 87.89862379431725, 82.38486886024475, 85.8987683057785, 82.3162293434143, 74.26608011126518, 75.03483965992928, 77.31392696499825, 70.1801061630249, 76.79112061858177, 76.38059064745903, 76.57483622431755, 75.9441764652729, 71.79253444075584, 76.28767803311348, 81.78925082087517, 70.5535577237606, 64.01670008897781, 55.42258724570274, 60.104855597019196, 55.649298280477524, 54.78407330811024, 53.73844161629677, 56.376792043447495, 52.1014666557312, 54.57834854722023, 54.88991662859917, 54.334808215498924, 51.095094457268715, 52.48048111796379, 50.218777880072594, 52.64051713049412, 50.20815744996071, 52.00330652296543, 51.89235247671604, 51.32432855665684, 47.341382279992104, 50.37083052098751, 48.47044609487057, 52.13077448308468, 55.169080048799515, 60.31189128756523, 63.020469546318054, 69.28106680512428, 62.92578622698784, 60.0063306838274, 64.77290511131287, 70.35902336239815, 63.87653321027756, 61.37667775154114, 54.60445694625378, 67.91569367051125, 57.75390274822712, 49.39225383102894, 65.58521792292595, 57.98185631632805, 67.99526140093803, 64.07589331269264, 66.17066770792007, 63.506357073783875, 62.1412119269371, 63.02243784070015, 60.48285931348801, 60.13437621295452, 58.89084354043007, 56.06590412557125, 59.467553794384, 59.77779574692249, 60.383779630064964, 64.27984356880188, 64.23451200127602, 60.765222162008286, 56.54827304184437, 53.730549439787865, 51.45157992839813, 50.25324963033199, 45.69069005548954, 49.86195042729378, 47.46457926928997, 49.34296667575836, 49.617555141448975, 52.617007791996, 49.06975373625755, 54.014869183301926, 50.30680775642395, 51.656236946582794, 51.5130340307951, 53.415899723768234, 50.52451327443123, 52.49672904610634, 51.332368925213814, 52.84487396478653, 48.699136823415756, 51.31570301949978, 50.00369042158127, 54.807909429073334, 51.962105333805084, 59.39983382821083, 55.990120992064476, 60.524626672267914, 54.6866275370121, 57.56829410791397, 58.127506300807, 71.99971452355385, 68.81839603185654, 88.18457365036011, 11.360561046749353, 1.610343020875007, 0.83720468217507, 1.5179550158791244, 0.09809709474211559, 0.1021636558289174, 2.5624293135479093, 61.35894790291786, 46.36973261833191, 38.34321431815624, 80.50636366009712, 32.15310327708721, 22.844279184937477, 36.690143421292305, 44.077023044228554, 55.11672265827656, 63.00487898290157, 50.202495753765106, 1.3671996491029859, 0.02917993304436095, 0.01094569859560579, 0.04039663799630944, 0.026761999215523247, 0.095241852250183, 0.02313781009434024, 0.03815242052951362, 0.04622557346010581, 0.014128103903203737, 0.0845694421150256, 0.049894002004293725, 0.08215873865992762, 0.05493007141922135, 0.03692769132612739, 0.09061582313734107, 0.0766285955614876, 0.07384485157672316, 0.024093345637083985, 0.05436138962977566, 0.08618030333309434, 0.06283342096139677, 0.029126932568033226, 0.018505777006794233, 0.06535795502713881, 0.059914650628343225, 0.04020344582386315, 0.035797912496491335, 0.10269156031426974, 0.13632522546686232, 0.19938980316510424, 0.4093618009937927, 8.850403390824795, 98.74073401093483, 82.54673257470131, 80.72085455060005, 67.52217918634415, 44.83809180557728, 39.106323570013046, 45.20050875842571, 44.30110462009907, 29.27643533796072, 0.05362893811252434, 0.2585082332370803, 2.9373340588063, 2.698776447214186, 5.762873366475105, 4.611410228535533, 1.47487387759611, 0.2211355761392042, 37.14688651263714, 87.17153280973434, 86.74541607499123, 89.04607102274895, 85.0028295814991, 89.48304757475853, 84.60385099053383, 80.34251645207405, 81.2339486181736, 81.361895352602, 78.11372324824333, 82.28190198540688, 79.41383868455887, 79.96196687221527, 77.28801235556602, 75.494744181633, 79.43137854337692, 82.39506751298904, 73.99175003170967, 67.20016926527023, 57.04728126525879, 62.34378285706043, 57.75847390294075, 58.00364814698696, 56.02834694087505, 57.063080817461014, 55.332832261919975, 58.19460690021515, 57.675436958670616, 57.3589975386858, 54.29367162287235, 55.00066928565502, 52.72870659828186, 56.16051144897938, 53.46604563295841, 54.33128960430622, 53.973664194345474, 55.7110221683979, 49.892219603061676, 53.89775186777115, 53.419235944747925, 54.80686828494072, 55.3689569234848, 64.97433230280876, 66.20824009180069, 71.67940691113472, 65.45659482479095, 63.760859817266464, 66.45119145512581, 73.28219130635262, 66.84840694069862, 64.52706590294838, 57.77929678559303, 72.91502460837364, 59.8051580786705, 52.039548978209496, 67.98493355512619, 60.875344052910805, 69.08055156469345, 65.87120577692986, 66.37344002723694, 65.41687935590744, 65.12839123606682, 64.98915910720825, 63.68011794984341, 63.71664918959141, 60.245463252067566, 59.52961206436157, 62.09178037941456, 60.75346939265728, 63.37587207555771, 66.12261548638344, 67.49599099159241, 64.24851045012474, 59.614165127277374, 55.84888257086277, 54.98567149043083, 52.60734111070633, 50.70983313024044, 52.355878204107285, 49.05628725886345, 51.52326688170433, 52.9535823315382, 54.80791702866554, 52.798007279634476, 55.983106568455696, 52.82750129699707, 54.497823268175125, 52.97508917748928, 57.222581058740616, 53.3614182472229, 55.11558271944523, 54.515701308846474, 55.944542437791824, 52.496683448553085, 54.04722444713116, 54.011171981692314, 57.08670414984226, 54.598863646388054, 62.73325055837631, 59.26916643977165, 62.94424183666706, 57.89226472377777, 59.90525610744953, 60.02375654876232, 74.90651294589043, 71.85134768486023, 92.80491292476654, 14.823091048747301, 1.2843265710398555, 1.7108931066468358, 1.732695505488664, 0.6137969763949513, 0.15195896703517064, 1.4755633031018078, 62.29527845978737, 58.19488428533077, 36.47843398153782, 62.39241264760494, 31.82021263986826, 36.63535796105862, 48.79065491259098, 51.05138920247555, 66.14200204610825, 72.09860801696777, 67.65638038516045, 3.3406646037474275, 0.1264593072119169, 0.07368900056462735, 0.06357893056701869, 0.020586434402503073, 0.07234625503770076, 0.012505311733548297, 0.03962873779528309, 0.030418989408644848, 0.015246606726577738, 0.03983793438237626, 0.04004900489235297, 0.021290326221787836, 0.02019630035647424, 0.07118857145542279, 0.013760513520537643, 0.15600886690663174, 0.08600038447184488, 0.11512372133438475, 0.2223812710144557, 0.2190937942941673, 0.18646838871063665, 0.14737580437213182, 0.12141063241870143, 0.14976701902924106, 0.16976175393210724, 0.22333596978569403, 0.19064163352595642, 0.17267918097786605, 0.35780017089564353, 0.31017961213365197, 0.6749583163764328, 9.89860374480486, 111.03887289762497, 93.70314672589302, 89.57334592938423, 78.96231651306152, 42.84962810575962, 51.15783289074898, 76.07301995158195, 50.95270089805126, 40.93766950070858, 0.18565913604106754, 0.3675063047558069, 1.9342850195243955, 6.924345642328262, 4.2417665384709835, 14.135213010013103, 9.02250375598669, 0.31346468429546803, 46.74090810120106, 87.39858582615852, 90.12471154332161, 91.32358521223068, 92.10430651903152, 93.18899631500244, 88.21830824017525, 83.9712381362915, 86.47824481129646, 88.9220380783081, 82.74624466896057, 84.28949385881424, 82.71855935454369, 81.71170458197594, 79.46879133582115, 77.06212967634201, 85.78114181756973, 85.65982192754745, 78.8542503118515, 68.76306340098381, 60.355455949902534, 64.71628054976463, 60.19321985542774, 59.82400506734848, 60.87819769978523, 62.072329223155975, 57.86092400550842, 60.61022087931633, 63.92028406262398, 59.08820874989033, 55.74936591088772, 59.13343392312527, 56.773095577955246, 59.63208116590977, 57.464871257543564, 56.97531312704086, 57.169243320822716, 58.60129527747631, 52.79225058853626, 55.91627575457096, 55.312997326254845, 55.71451038122177, 59.144495129585266, 65.65115198493004, 68.84207636117935, 74.30016428232193, 67.49579340219498, 66.03199794888496, 67.96374589204788, 76.84876352548599, 69.8390744626522, 67.35684245824814, 61.22701518237591, 75.87448060512543, 61.731320321559906, 57.826915830373764, 70.00390201807022, 62.698136642575264, 72.77896150946617, 68.93763363361359, 70.617356300354, 68.3596770465374, 68.00562724471092, 67.76657447218895, 64.56707015633583, 64.89813879132271, 61.98851332068443, 62.78839699923992, 65.61872452497482, 65.75689271092415, 66.54790386557579, 68.48655983805656, 71.71814203262329, 67.99683451652527, 63.17476786673069, 58.9791925996542, 58.25436629354954, 57.109001353383064, 51.10719680786133, 53.45117323100567, 52.65175312757492, 54.167267605662346, 55.54489888250828, 58.56394708156586, 55.505578592419624, 59.42474149167538, 55.00449948012829, 56.26539722084999, 55.84645450115204, 59.93099972605705, 57.32709065079689, 57.13090717792511, 56.90459132194519, 59.51818227767944, 57.38955929875374, 57.69742637872696, 57.195815294981, 59.37242969870567, 56.939701437950134, 67.66176089644432, 63.69388461112976, 66.20694816112518, 61.24814584851265, 63.6305496096611, 66.12627848982811, 78.88146445155144, 76.36929765343666, 97.51430422067642, 14.968511145561934, 3.2338967453688383, 6.9353375025093555, 4.638924077153206, 0.6423845048993826, 0.27090284158475697, 3.747998708859086, 72.84778341650963, 62.57327914237976, 56.79613374173641, 106.65155231952667, 43.40852491557598, 35.2928102016449, 51.994263008236885, 61.351283714175224, 74.0446811914444, 84.88788574934006, 73.98641511797905, 2.7590939356014132, 0.3067025018390268, 0.1378551183734089, 0.14504212100291625, 0.20715686841867864, 0.14329543191706762, 0.12662409368203953, 0.13718440983211622, 0.16866015444975346, 0.11181134555954486, 0.21870643773581833, 0.1371749400277622, 0.12732120783766732, 0.19533065613359213, 0.1350678046583198, 0.18072532344376668, 0.17729248967953026], [0.051845980269717984, 0.009280840567953419, 0.017954383547476027, 0.04247580553055741, 0.018176371049776208, 0.08530371560482308, 0.04479738818190526, 0.07581759884487838, 0.057143337617162615, 0.0354099473770475, 0.013976553636894096, 0.1001321007788647, 0.005984434419588069, 0.1976103408378549, 0.2977424638811499, 29.518704637885094, 84.83508378267288, 68.73418495059013, 71.92081555724144, 60.585374012589455, 28.157402984797955, 44.25223544239998, 47.94590324163437, 39.208374693989754, 9.790570791810751, 0.08148080160026439, 0.09835387041675858, 1.045558308251202, 0.5220028676558286, 20.57379461824894, 6.731429044157267, 0.3548319364199415, 7.750681126490235, 61.93605333566666, 86.85393065214157, 84.70282807946205, 83.65083932876587, 80.11392071843147, 83.31281706690788, 82.97919496893883, 82.52930670976639, 73.32639053463936, 72.1914142370224, 72.28072464466095, 75.56933417916298, 74.36387926340103, 72.57457047700882, 72.70402953028679, 76.10365390777588, 72.0051558315754, 76.77617982029915, 70.93757271766663, 63.340400978922844, 55.06602957844734, 56.90287761390209, 54.378319680690765, 55.4000810533762, 53.76749485731125, 54.60251905024052, 53.242621421813965, 53.99821847677231, 52.56637170910835, 51.48083075881004, 51.59910701215267, 52.2623348236084, 49.8399306088686, 50.5966904014349, 49.24265205860138, 50.132925286889076, 51.06373853981495, 48.664570078253746, 47.677702233195305, 51.14573813974857, 48.924996703863144, 50.371742472052574, 53.93560163676739, 59.726620092988014, 59.16980177164078, 67.19194650650024, 62.36072614789009, 58.99313025176525, 59.20888267457485, 66.62794277071953, 66.34418919682503, 65.43876618146896, 55.58126673102379, 66.93244323134422, 58.197965919971466, 48.83686423301697, 64.35264766216278, 60.42092263698578, 66.3710005581379, 62.88893200457096, 58.91797788441181, 62.60380670428276, 61.257128566503525, 62.190331891179085, 62.83290781080723, 62.98479326069355, 61.259993612766266, 61.7320840805769, 57.38251447677612, 59.61353816092014, 60.034753158688545, 59.38138581812382, 62.82351851463318, 58.680604621768, 51.362178325653076, 51.27249173820019, 49.9538104981184, 53.37482012808323, 48.29042695462704, 48.48814554512501, 46.67053587734699, 48.17326404154301, 49.289400950074196, 49.705433025956154, 50.15796214342117, 50.01664772629738, 50.95352165400982, 54.08513881266117, 51.82375095784664, 49.671158865094185, 51.610016226768494, 52.65304125845432, 50.07644131779671, 51.4178529381752, 49.59968850016594, 53.56976106762886, 59.043701738119125, 62.330073192715645, 64.83297988772392, 66.04751631617546, 63.39380331337452, 69.30347800254822, 62.40842118859291, 66.1652871966362, 58.4237802028656, 65.80381259322166, 64.12459149956703, 84.76319923996925, 30.631535723805428, 0.1762497573508881, 0.6023877917323261, 2.3909922502934933, 0.5629340931773186, 0.03021491735125892, 0.11194066479220055, 20.43024592101574, 77.11509883403778, 30.013080909848213, 48.06924842298031, 40.613858476281166, 13.65916220471263, 14.747768640518188, 46.18011139333248, 59.10625018179417, 55.86924187839031, 64.62272956967354, 24.13663163781166, 0.22157513536512852, 0.08832293562591076, 0.07657207359443419, 0.059661140403477475, 0.06379908867529593, 0.022034594585420564, 0.027737197960959747, 0.05801978433737531, 0.05785626322904136, 0.056269173001055606, 0.07183811394497752, 0.03918461065040901, 0.020260620440240018, 0.05437370185973123, 0.03391410791664384, 0.01821833950089058, 0.06609913791180588, 0.034003369728452526, 0.043848107088706456, 0.036753590902662836, 0.058739007072290406, 0.019539113745850045, 0.03709966920723673, 0.05425492854556069, 0.09299968311097473, 0.0544782593351556, 0.04043481036205776, 0.17108878819271922, 0.05866623207111843, 0.16736117337131873, 0.18855213158531114, 40.54566353559494, 96.84935510158539, 74.86285328865051, 84.0696756541729, 74.70877155661583, 38.47067467868328, 38.00125926733017, 49.5946841686964, 46.8811471760273, 14.533619731664658, 0.1683368007070385, 0.1751380498171784, 2.3851916240528226, 3.074169703759253, 25.412101596593857, 3.6211738642305136, 0.5317977326922119, 13.023045938462019, 75.93922153115273, 89.5509423315525, 87.3590375483036, 86.43344521522522, 84.37831029295921, 86.38008087873459, 83.74303758144379, 84.4826602935791, 78.26408118009567, 78.10936868190765, 76.66271030902863, 78.82437631487846, 76.58329457044601, 77.74919360876083, 76.34126275777817, 75.92401474714279, 75.07668301463127, 79.71615806221962, 73.46281081438065, 66.48066267371178, 58.7948264926672, 58.01052577793598, 58.165215477347374, 57.156251817941666, 56.2125838547945, 58.31463485956192, 55.2627944201231, 55.27478277683258, 55.043967962265015, 54.58447761833668, 52.87003241479397, 56.074396669864655, 52.52660684287548, 53.80081906914711, 52.27574050426483, 52.10766412317753, 53.065064549446106, 51.52285650372505, 51.33513517677784, 52.31174357235432, 51.31487086415291, 54.381902888417244, 57.479888051748276, 62.437820211052895, 64.24653455615044, 69.63456943631172, 63.890645653009415, 61.59065566956997, 61.315550431609154, 70.67648872733116, 70.83625495433807, 67.74211138486862, 60.43242081999779, 69.73974019289017, 62.964422553777695, 51.10302843153477, 67.40982681512833, 63.59692141413689, 68.90915036201477, 65.07347658276558, 62.96020098030567, 62.69538179039955, 62.33439356088638, 65.06387829780579, 64.44606944918633, 65.90963691473007, 63.543522879481316, 62.17322900891304, 61.70439876616001, 62.39668361842632, 63.458483442664146, 63.52763593196869, 64.98238787055016, 61.04930631816387, 54.26565192639828, 53.29528659582138, 52.4486730247736, 56.496622413396835, 51.78547561168671, 51.035281866788864, 49.02343422174454, 49.54370230436325, 51.37365750968456, 53.59245344996452, 52.10881166160107, 53.349038511514664, 54.757368341088295, 54.352294877171516, 54.37865786254406, 51.91093347966671, 54.056594744324684, 55.82446128129959, 52.130858078598976, 55.353978127241135, 51.01826258003712, 57.2075604647398, 61.541482508182526, 68.813646286726, 66.84925049543381, 69.09810662269592, 67.52054527401924, 73.88522654771805, 66.33929505944252, 70.3392568230629, 61.579529866576195, 71.49883300065994, 67.60787218809128, 87.84760013222694, 33.8532954454422, 0.13299701968207955, 2.5078231561928988, 3.4144770679995418, 0.9407105343416333, 0.24789112794678658, 0.13631464244099334, 18.438749983906746, 85.60208782553673, 40.206330344080925, 42.694497630000114, 29.47165746241808, 21.22179474681616, 24.537232741713524, 60.94114892184734, 65.49649268388748, 60.9086112678051, 72.74787917733192, 42.98203580081463, 0.8050002227537334, 0.027328369214956183, 0.07070612351526506, 0.05587368992564734, 0.07600868702866137, 0.06406798362149857, 0.05154607097210828, 0.07800251129083335, 0.05620306990749668, 0.020659328147303313, 0.05767284514149651, 0.04605240443197545, 0.04219183756504208, 0.04659027967136353, 0.10136818484170362, 0.01031133580909227, 0.1072207985271234, 0.11271939292782918, 0.10326457253540866, 0.12914447172079235, 0.15087154257344082, 0.23089974594768137, 0.17533875623485073, 0.26479437248781323, 0.16590083454502746, 0.15187072567641735, 0.12280652314075269, 0.3307630482595414, 0.13852977514034137, 0.3559110191417858, 0.5715608177706599, 44.20521296560764, 110.20074427127838, 86.13845944404602, 94.30813506245613, 79.01971623301506, 40.580959841609, 63.65757755935192, 67.5096246600151, 60.03382980823517, 18.160743601620197, 0.3310953523032367, 0.6676084420178086, 5.3686730191111565, 4.105836432427168, 27.78596341609955, 22.43771620094776, 2.9851744417101145, 19.629731476306915, 76.9412125647068, 89.5767505466938, 88.66076409816742, 89.47947576642036, 87.68376812338829, 91.7491015791893, 88.54723379015923, 87.59496688842773, 80.18678560853004, 80.78202366828918, 79.42223623394966, 81.86614349484444, 80.72646304965019, 80.70163518190384, 77.25920230150223, 79.15425181388855, 77.89015844464302, 84.42808002233505, 75.89609384536743, 73.41510057449341, 60.030474588274956, 61.639642640948296, 60.00615209341049, 60.75207866728306, 59.30456154048443, 60.774850845336914, 57.1313289552927, 59.76243697106838, 57.470111176371574, 58.14761862158775, 57.12370276451111, 59.99121509492397, 55.90350463986397, 55.68745583295822, 55.40088281035423, 56.025215908885, 56.91586911678314, 56.13252595067024, 53.967652916908264, 55.68093538284302, 53.1140211224556, 57.33515001833439, 59.54962559044361, 67.3803099989891, 66.91609650850296, 72.44809046387672, 68.08277830481529, 64.46286454796791, 62.833162397146225, 73.0011659860611, 72.92763233184814, 70.61004549264908, 63.10116581618786, 73.08324918150902, 66.63428083062172, 55.15523359179497, 70.01342430710793, 67.7648113667965, 72.66968697309494, 69.76243257522583, 65.32845050096512, 67.99688011407852, 67.3954027891159, 69.3261855840683, 68.13583105802536, 70.58693513274193, 66.71947985887527, 65.00322595238686, 65.14159172773361, 64.66631323099136, 66.7835596203804, 67.50245064496994, 68.59647274017334, 66.31971850991249, 56.321706399321556, 57.9252165555954, 54.77623052895069, 58.214745819568634, 53.90029773116112, 54.440780729055405, 51.8297204375267, 53.12764339148998, 54.92262527346611, 56.65875971317291, 54.537500739097595, 55.703570768237114, 55.233368799090385, 57.587103098630905, 58.58848236501217, 56.477954015135765, 57.3369587212801, 58.15380848944187, 56.432660445570946, 58.961379155516624, 54.2805091291666, 59.30874891579151, 64.99925136566162, 70.37898749113083, 69.94730785489082, 71.67657986283302, 70.28747320175171, 76.57018527388573, 68.83253887295723, 73.29305112361908, 65.14859855175018, 74.52353909611702, 73.55153605341911, 92.97771245241165, 35.644887909293175, 0.5014330276753753, 5.565463984385133, 5.755361169576645, 1.257911694701761, 0.357121640117839, 0.2931850834283978, 26.86088975518942, 91.97691455483437, 46.91411420702934, 63.165142983198166, 53.37137371301651, 21.563075333833694, 26.691261157393456, 64.76208329200745, 77.70950853824615, 70.34014597535133, 87.09135711193085, 46.316828057169914, 0.7743594388011843, 0.15315670432755724, 0.23967304470716044, 0.14536008675349876, 0.19511834252625704, 0.14216129668056965, 0.13475770567310974, 0.12950796080986038, 0.29122364649083465, 0.15628041874151677, 0.12092324177501723, 0.15781990019604564, 0.2280997860361822, 0.18729454750427976, 0.1497014131746255, 0.12998446414712816], [0.054281823977362365, 0.06381156417774037, 0.07738010172033682, 0.03258962664403953, 0.026969904465659056, 0.06814078617026098, 0.05150616940227337, 0.05849874047271442, 0.013871129704057239, 0.03606727870646864, 0.04720229175291024, 0.03462795750238001, 0.028486409028118942, 0.03315801157441456, 0.2749106171540916, 64.65115204453468, 78.0312828719616, 70.6820896267891, 56.39984540641308, 22.04543475061655, 29.622102789580822, 47.39396005868912, 36.675153225660324, 35.09021647274494, 5.4511114954948425, 0.1615163596579805, 0.5599453754257411, 5.646434789523482, 2.721372409723699, 9.376329369843006, 2.474420336075127, 1.9338974403217435, 34.440306946635246, 81.55449941754341, 82.89107009768486, 87.01301291584969, 84.69365537166595, 85.94872042536736, 86.74752876162529, 82.79267817735672, 83.56611907482147, 82.46062159538269, 81.588613986969, 79.29719254374504, 76.49257823824883, 74.66494470834732, 76.16631254553795, 74.3164274096489, 71.38755217194557, 72.19773709774017, 71.339211165905, 70.56094452738762, 61.08905978500843, 54.91580083966255, 55.46932473778725, 52.834150940179825, 55.634634867310524, 54.239547327160835, 54.78715494275093, 53.68122048676014, 53.22733484208584, 52.3632650077343, 52.766088992357254, 50.15591025352478, 49.24104854464531, 49.63422104716301, 51.448847874999046, 48.5738081485033, 49.714351147413254, 51.73765517771244, 50.25138773024082, 48.1568793207407, 52.21057020127773, 52.35712833702564, 52.363785579800606, 53.80076207220554, 56.756262481212616, 59.436642453074455, 63.375929072499275, 59.368443712592125, 68.92960846424103, 61.80676527321339, 60.737267062067986, 62.48999901115894, 69.11562368273735, 61.08836442232132, 64.84819427132607, 58.516860008239746, 51.74959033727646, 66.27551928162575, 61.294138580560684, 65.79600781202316, 63.2686760276556, 63.8284657895565, 57.35690005123615, 59.22447703778744, 61.085848957300186, 61.272950917482376, 59.941574558615685, 60.199671909213066, 60.988528579473495, 62.563293278217316, 57.499901577830315, 63.62309440970421, 60.633737817406654, 57.80254393815994, 54.10502314567566, 51.494973599910736, 48.071611896157265, 50.400666519999504, 56.00076802074909, 51.51082634925842, 49.056849628686905, 49.92855325341225, 47.25261904299259, 48.979869559407234, 48.82679097354412, 50.344980508089066, 52.26107329130173, 50.25643765926361, 51.486370861530304, 50.306435376405716, 50.1822542399168, 50.48755265772343, 52.894776687026024, 50.671755373477936, 49.95781168341637, 54.67678606510162, 64.25948426127434, 66.01511165499687, 70.3218461573124, 67.61443823575974, 70.59689059853554, 69.12256211042404, 72.46446758508682, 70.44084817171097, 72.02800780534744, 69.81241509318352, 71.07786118984222, 65.93240529298782, 83.10945957899094, 46.50952711701393, 0.10192198285949416, 0.7372559735085815, 0.862118104705587, 1.2417382188141346, 0.10211285582045093, 0.06804884149460122, 0.729723887052387, 59.81290966272354, 61.56285636126995, 36.93557605147362, 70.76123178005219, 26.98652621358633, 19.489104822278023, 23.25908202677965, 34.02926780283451, 56.35832883417606, 57.31952525675297, 66.92172780632973, 15.127640906721354, 0.4829065874218941, 0.09189061020151712, 0.09398697700817138, 0.11968004051595926, 0.04627852569683455, 0.027801800060842652, 0.03741213193279691, 0.034056121585308574, 0.02228164998086868, 0.07514087890740484, 0.05093901272630319, 0.024120242924254853, 0.05677883549651597, 0.06124549581727479, 0.04456730013771448, 0.057390710280742496, 0.05947018951701466, 0.04150968510657549, 0.04667412751587108, 0.02383317463682033, 0.1385300571564585, 0.08156459749443457, 0.022853265109006315, 0.04114151306566782, 0.06998677461524494, 0.09726790798595175, 0.09024696832057089, 0.03516700162435882, 0.020336475354270078, 1.0294933640398085, 80.9581746160984, 85.65499618649483, 84.94118168950081, 65.07628083229065, 40.207306891679764, 40.03183230757713, 32.32273757457733, 41.60863749682903, 53.372878432273865, 5.423378208652139, 0.17371930094668642, 3.3402152778580785, 5.768565461039543, 3.7717961193993688, 4.520911909639835, 1.5744260419160128, 1.2609341950155795, 47.72565945982933, 85.30051320791245, 86.8610742688179, 87.56156668066978, 87.56773754954338, 86.31241410970688, 87.65713915228844, 86.19753107428551, 85.7030788064003, 82.74025619029999, 83.6409142613411, 80.51867499947548, 80.30718594789505, 77.0056115090847, 75.45019537210464, 76.0817214846611, 75.15811264514923, 72.47790366411209, 74.32366222143173, 73.88991549611092, 64.31966543197632, 57.61810943484306, 58.049211502075195, 54.44918967783451, 57.567458152770996, 56.00911997258663, 58.591677993535995, 56.56205490231514, 57.32724644243717, 55.11405520141125, 55.48314459621906, 52.3705530166626, 52.584819719195366, 50.777830481529236, 53.40559087693691, 50.33105805516243, 54.45191793143749, 52.433424443006516, 51.77813060581684, 51.210045889019966, 55.438648983836174, 53.87784093618393, 54.277248904109, 57.311161905527115, 59.32289935648441, 63.37333761155605, 65.5534440279007, 63.62048774957657, 71.06436431407928, 64.94192764163017, 63.18239785730839, 64.29496675729752, 71.68931677937508, 63.5688067227602, 65.55515393614769, 62.793177142739296, 54.55490380525589, 69.93490532040596, 62.40856558084488, 69.09703508019447, 64.34709995985031, 64.89148914813995, 58.23220208287239, 62.66716070473194, 63.605812937021255, 63.6009605973959, 63.695887103676796, 64.02537882328033, 64.02061387896538, 63.943341225385666, 61.329092904925346, 65.12690171599388, 62.902269288897514, 59.95204299688339, 57.583063915371895, 52.516689375042915, 51.445743441581726, 53.08208003640175, 57.38976448774338, 53.45324791967869, 50.658908262848854, 52.3877888917923, 49.59645487368107, 51.54341720044613, 49.84056897461414, 52.99650862812996, 53.59604425728321, 51.9941870123148, 53.51841822266579, 53.47005821764469, 54.544815346598625, 53.81909228861332, 52.89176344871521, 53.0003160238266, 51.5107237547636, 59.50054742395878, 67.66873732209206, 69.33614864945412, 73.98893818259239, 69.74379077553749, 76.11092671751976, 73.19391444325447, 78.3213821053505, 74.75215762853622, 76.18596509099007, 73.78975287079811, 74.8661059141159, 71.60595685243607, 86.6154782474041, 50.00111036002636, 0.08065906600677408, 1.7396236024796963, 2.833108026534319, 1.8071267427876592, 0.38116176263429224, 0.18156758684199303, 0.5548619013279676, 60.19691325724125, 72.17292442917824, 42.01106630265713, 51.751695424318314, 29.841537214815617, 33.30310016870499, 37.860476821660995, 43.906009420752525, 66.04976579546928, 62.15978913009167, 83.62312361598015, 26.200145110487938, 0.6064271531067789, 0.07045805323286913, 0.008469559979857877, 0.06775630914489739, 0.03600993295549415, 0.07340221243794076, 0.00981098170086625, 0.037575987007585354, 0.041860598503262736, 0.043977103487122804, 0.010856300414161524, 0.0038671107540722005, 0.01876472346339142, 0.051811129014822654, 0.03292123306891881, 0.1805687154410407, 0.1716635815682821, 0.17497011664090678, 0.11831912721390836, 0.12061981469742022, 0.2204207840259187, 0.14625296462327242, 0.08513540393323638, 0.07610377098899335, 0.12658228108193725, 0.1884377666283399, 0.3044858848443255, 0.14075627754209563, 0.09875794014078565, 1.065631324891001, 93.03448140621185, 99.89291578531265, 92.37300530076027, 76.78276866674423, 38.07066634297371, 41.950387358665466, 66.75742462277412, 52.45688058435917, 59.81663726270199, 8.207893967628479, 0.3049042186466977, 2.7463382575660944, 15.077796131372452, 6.819108864292502, 21.254127211868763, 5.884675355628133, 2.8525494458153844, 58.169581443071365, 88.31202641129494, 88.6909344792366, 91.02402448654175, 92.24727764725685, 90.96236139535904, 91.72402292490005, 89.43478256464005, 89.72585454583168, 88.17490696907043, 85.62805563211441, 83.47389042377472, 80.42292013764381, 78.93790662288666, 77.68585100769997, 80.00848397612572, 75.2756479382515, 76.43445655703545, 76.68616265058517, 76.41145259141922, 68.46536457538605, 61.23323544859886, 60.665200129151344, 57.56347216665745, 60.35125717520714, 59.0224152803421, 61.65020227432251, 60.14459766447544, 58.750403076410294, 57.992066368460655, 59.0493406355381, 55.3594384342432, 54.17726866900921, 55.404545813798904, 57.24724933505058, 54.78031150996685, 56.63644351065159, 58.30066680908203, 55.616893619298935, 55.128828808665276, 59.13854844868183, 58.48438315093517, 57.728508710861206, 60.49963541328907, 62.46034920215607, 65.53614735603333, 69.7308486700058, 65.28245776891708, 74.16266486048698, 67.12206825613976, 64.51908633112907, 68.26656684279442, 73.15818876028061, 67.1122495830059, 70.5822005867958, 66.64227560162544, 59.43000800907612, 70.14287576079369, 67.3845049738884, 73.41364905238152, 68.04465875029564, 68.10168609023094, 61.35125331580639, 65.08664667606354, 68.57547506690025, 65.3168611228466, 66.81813016533852, 66.19814023375511, 66.85178115963936, 67.58631214499474, 63.21967385709286, 71.07107475399971, 66.76552578806877, 64.82607945799828, 60.96467345952988, 56.08529828488827, 53.6933608353138, 55.999818071722984, 60.9925601631403, 55.59494599699974, 53.40501710772514, 57.17448703944683, 51.9254145026207, 55.352803990244865, 52.99042895436287, 56.51171900331974, 57.26932615041733, 55.05352444946766, 56.24094933271408, 55.97531698644161, 56.431220322847366, 57.39341989159584, 57.69533649086952, 56.94864995777607, 55.05507856607437, 61.641614735126495, 71.22569605708122, 71.89620047807693, 77.5516802072525, 71.5788871049881, 79.3701334297657, 76.48763090372086, 81.18388250470161, 79.40684705972672, 78.5818961262703, 78.4401485323906, 78.30130398273468, 73.96775051951408, 88.03264260292053, 55.33743381500244, 0.1728733564959839, 4.928042963147163, 5.924967918545008, 3.689813381060958, 0.32457611931022257, 0.2412925148382783, 1.3311478961259127, 73.9655390381813, 75.23147910833359, 56.51019908487797, 93.79087641835213, 41.14712946116924, 30.246540382504463, 36.61183722317219, 50.775068029761314, 78.14683467149734, 71.7642031610012, 94.54286366701126, 24.448537901043892, 0.848123871255666, 0.218520381313283, 0.1802298953407444, 0.22129632532596588, 0.33637279411777854, 0.14859806222375482, 0.12966934824362397, 0.13935884315287694, 0.2136752850492485, 0.2428292206604965, 0.1699004168040119, 0.1603211456676945, 0.12404255525325425, 0.17059289995813742, 0.1301479889662005], [0.09572006252710707, 0.0386689182050759, 0.030512310768244788, 0.05791651448816992, 0.05477576778503135, 0.09112919637118466, 0.06610683398321271, 0.13701292918995023, 0.09752220488735475, 0.057693139169714414, 0.025341146356367972, 0.09010446112370118, 0.4282799764769152, 0.4631246707867831, 12.141308952122927, 77.93013989925385, 69.86810490489006, 60.882248282432556, 41.27762205898762, 63.744995668530464, 41.83366522192955, 56.13363929092884, 36.020851135253906, 37.582624331116676, 1.2764125457033515, 0.0309578461383353, 0.10068772447993979, 1.674478710629046, 1.8379318085499108, 4.878967646509409, 1.7505717650055885, 20.59307098388672, 75.93788400292397, 81.26189231872559, 83.40974226593971, 82.90770560503006, 82.43659168481827, 79.91139158606529, 81.19135290384293, 83.57323989272118, 80.85251748561859, 78.23617547750473, 82.36108973622322, 81.19031935930252, 80.1947271823883, 81.91819310188293, 74.5699954032898, 77.55491763353348, 73.49146127700806, 70.32162576913834, 73.37606906890869, 69.45145726203918, 58.87863479554653, 51.204642578959465, 54.43040728569031, 51.97776049375534, 54.34006713330746, 51.13286443054676, 53.96328695118427, 54.4188217073679, 51.70883372426033, 50.29449261724949, 51.10368199646473, 51.86044558882713, 49.76484663784504, 47.43328794836998, 49.39015254378319, 48.38675178587437, 50.98803140223026, 50.17975777387619, 50.27669057250023, 51.770629808306694, 51.482392475008965, 54.371149465441704, 53.82444620132446, 56.11495189368725, 56.44751764833927, 60.157729759812355, 59.29237939417362, 63.70702810585499, 63.00829879939556, 63.76564756035805, 62.94045723974705, 60.92151157557964, 61.6199216991663, 63.08335617184639, 65.89557766914368, 57.55523040890694, 50.39115563035011, 64.43894863128662, 59.98820945620537, 63.37046876549721, 58.77859756350517, 58.16430352628231, 58.71827960014343, 59.2181845754385, 57.68092766404152, 59.83732335269451, 60.97632363438606, 62.58262664079666, 61.1879912763834, 61.612766683101654, 61.37419268488884, 58.68022084236145, 62.328237891197205, 61.77175395190716, 56.65738798677921, 51.47229261696339, 47.47344799339771, 48.19506347179413, 51.69116087257862, 54.05754469335079, 46.351531594991684, 47.29332245886326, 47.09778495132923, 47.52323292195797, 47.46332913637161, 49.04162384569645, 49.57312032580376, 53.52418631315231, 49.608234241604805, 51.28968961536884, 50.91194428503513, 52.071216478943825, 50.811709463596344, 52.268676683306694, 54.54143352806568, 62.81081199645996, 65.54629281163216, 71.04452937841415, 70.7812263071537, 70.08497446775436, 69.21394720673561, 70.10779604315758, 69.24278765916824, 72.465311139822, 70.22142514586449, 68.56819465756416, 68.13753336668015, 71.70438677072525, 78.02527159452438, 45.793295949697495, 0.1681652310071513, 1.1826321529224515, 2.2484163008630276, 1.1832531820982695, 0.6264542159624398, 0.05647773505188525, 0.0340817442338448, 17.067029289901257, 79.94489818811417, 46.704042479395866, 37.00946308672428, 47.915105894207954, 17.737495712935925, 15.085139237344265, 20.825586207211018, 40.19697904586792, 57.78517127037048, 64.38877612352371, 61.38900049030781, 2.182459202595055, 0.017024298103933688, 0.03111006062681554, 0.021312831850082148, 0.05978239991236478, 0.0322833051905036, 0.014969534240663052, 0.04229556754580699, 0.01334178266915842, 0.058063188844243996, 0.06117611614172347, 0.01666587973886635, 0.05435286235297099, 0.11974898603511974, 0.0874522999220062, 0.06482832133769989, 0.05118725741340313, 0.07796078774845228, 0.052575678419088945, 0.02157329970941646, 0.03532502341840882, 0.07788340401020832, 0.11109854240203276, 0.13145307049853727, 0.02111712750775041, 0.07786042711813934, 0.14447911293245852, 0.45456432388164103, 0.4273798404028639, 18.082674890756607, 90.66987589001656, 75.02005845308304, 68.541299700737, 54.84302714467049, 56.79970175027847, 32.24464416503906, 52.721095606684685, 48.3806037157774, 43.39691273868084, 0.4255109641235322, 0.0946222034690436, 1.4200478070415556, 2.655449747107923, 2.945369677618146, 1.802215981297195, 3.2676698081195354, 34.723433554172516, 89.33171689510345, 84.29348364472389, 85.56134641170502, 86.20178684592247, 85.30798360705376, 84.98278945684433, 83.15644785761833, 85.4036320745945, 84.46783348917961, 81.69267520308495, 85.0053982436657, 82.61288702487946, 80.37973165512085, 83.37467774748802, 78.43356728553772, 80.90927883982658, 74.78393152356148, 74.91957664489746, 75.43997392058372, 71.13576248288155, 61.142659708857536, 53.5118255764246, 56.44601672887802, 56.51454605162144, 56.37026399374008, 54.35285344719887, 57.2192220389843, 56.84635944664478, 54.206876680254936, 54.692505821585655, 54.41160209476948, 53.48213776946068, 52.756521105766296, 51.46924898028374, 51.66903845965862, 51.68245553970337, 53.30345615744591, 50.659508630633354, 51.32169909775257, 54.13434237241745, 52.15049162507057, 55.35955622792244, 56.40528291463852, 60.57789221405983, 59.879523888230324, 63.197471648454666, 62.84213751554489, 67.45385885238647, 65.86856871843338, 65.62972113490105, 64.2334632575512, 64.53649699687958, 63.953167498111725, 65.3972952067852, 69.91500958800316, 59.89509545266628, 53.08841049671173, 68.34817886352539, 61.66480489075184, 67.12228864431381, 61.969236955046654, 62.241021171212196, 62.3946051299572, 62.864009141922, 62.55726680159569, 63.898997604846954, 65.79326435923576, 66.02196648716927, 64.42211553454399, 65.56740447878838, 64.84356611967087, 60.61779387295246, 63.206431567668915, 63.877809941768646, 59.14679780602455, 53.98556515574455, 50.720597952604294, 51.69190563261509, 53.87612722814083, 56.606512516736984, 48.36720183491707, 51.06588162481785, 50.515310168266296, 51.06354855000973, 49.39818911254406, 51.14925295114517, 52.23021134734154, 54.76322002708912, 51.725001856684685, 54.04455319046974, 53.020044565200806, 53.99468466639519, 52.08746440708637, 54.065471068024635, 59.3739116191864, 67.44790077209473, 70.11991739273071, 71.90297931432724, 71.9266064465046, 72.42521569132805, 71.08619034290314, 71.77378624677658, 72.2205738723278, 73.83003830909729, 73.97383779287338, 71.29658505320549, 71.56938001513481, 76.33601143956184, 78.82700577378273, 50.78082852065563, 0.7872282795142382, 0.600649859989062, 3.1887299939990044, 2.5117452582344413, 1.2288567912764847, 0.39406898722518235, 0.3001225314801559, 15.28015997260809, 83.2483421266079, 58.17194111645222, 33.53328801691532, 32.96047255396843, 25.31836062669754, 26.47542703896761, 35.585143715143204, 46.206842958927155, 65.85172042250633, 67.4277314543724, 75.14723762869835, 4.4118948094546795, 0.06000592366035562, 0.09091593281482346, 0.11432916318881325, 0.04547634569462389, 0.028051595836586785, 0.046075767240836285, 0.056178007580456324, 0.019972199588664807, 0.08811972817056812, 0.05551853886572644, 0.006415764619305264, 0.05763141845818609, 0.03404384646273684, 0.030355194394360296, 0.2228351982193999, 0.1341841887915507, 0.17829814431024715, 0.1524621431599371, 0.17716948612360284, 0.19143705256283283, 0.2991222351556644, 0.3072389558656141, 0.25742184778209776, 0.13236614962806925, 0.30658999225124717, 0.12946395145263523, 0.6272013508714736, 0.5337629397399724, 20.061295218765736, 106.7383548617363, 87.92381644248962, 79.14321720600128, 53.62086072564125, 77.90971219539642, 54.77511718869209, 79.37888815999031, 57.49852605164051, 53.582885563373566, 2.24542039912194, 0.3190902527421713, 3.639025306329131, 5.456182798370719, 9.454943351447582, 11.64072286337614, 6.261694924905896, 40.44010899960995, 92.43916735053062, 87.54925534129143, 85.67158609628677, 91.09612941741943, 88.23502734303474, 86.6126511991024, 86.72519356012344, 89.83423992991447, 88.00941824913025, 84.77544218301773, 90.89541658759117, 87.28939488530159, 84.39309909939766, 86.61610141396523, 79.58711698651314, 83.01643297076225, 78.67439076304436, 76.7181721329689, 79.54869344830513, 75.08310467004776, 64.41814854741096, 57.103541046381, 58.82417231798172, 58.32126170396805, 58.242066353559494, 56.39494746923447, 61.328139156103134, 60.10418303310871, 56.00572295486927, 57.60698743164539, 58.76689039170742, 58.04965987801552, 56.25141777098179, 51.985971853137016, 55.38014352321625, 54.7493127733469, 55.41154883801937, 54.43658575415611, 55.67651242017746, 58.492043539881706, 57.14339330792427, 58.89340080320835, 58.93543414771557, 63.20268116891384, 62.84002862870693, 66.80606201291084, 64.13462296128273, 71.6949100792408, 69.9614354968071, 68.809534907341, 66.95110023021698, 66.42041310667992, 68.37429106235504, 69.30653303861618, 70.96912622451782, 64.06568706035614, 55.65010003745556, 69.63384747505188, 64.42883357405663, 70.99265456199646, 65.07194146513939, 64.26668107509613, 66.89976498484612, 66.70789808034897, 66.20535224676132, 66.39877706766129, 67.74314492940903, 69.8947186768055, 67.19417318701744, 68.53487804532051, 67.392058968544, 63.85342285037041, 67.62741073966026, 68.67235466837883, 62.12256632745266, 56.758147180080414, 54.54803757369518, 54.072219505906105, 56.766654923558235, 58.307753428816795, 49.990121349692345, 54.052977338433266, 52.50265672802925, 54.04508896172047, 51.18526741862297, 54.05963838100433, 55.82628898322582, 57.67348386347294, 54.40847106277943, 55.9578151255846, 55.201872289180756, 57.766187489032745, 57.64797583222389, 59.99018155038357, 61.20537534356117, 69.01474669575691, 73.91758561134338, 76.39556184411049, 76.81993067264557, 78.05599674582481, 72.46294006705284, 73.67459625005722, 74.91305619478226, 77.13178753852844, 75.64501851797104, 74.0788185596466, 72.56384745240211, 80.19462078809738, 83.70367169380188, 54.102705270051956, 1.0875248000957072, 5.338352071121335, 10.607698895037174, 5.821067243814468, 1.8884299113415182, 0.3818695340305567, 0.4426238208543509, 23.305306546390057, 95.45571908354759, 62.10153825581074, 53.78911569714546, 59.939499869942665, 25.209714956581593, 22.86998860538006, 35.395100712776184, 57.23272651433945, 78.42963829636574, 79.88625973463058, 82.52977028489113, 4.526532283052802, 0.19119345000945032, 0.21229414822300896, 0.13446801574900746, 0.11499593092594296, 0.17385474289767444, 0.11110488776466809, 0.19571278797229752, 0.09560480699292384, 0.18760540348012, 0.14073555677896366, 0.10396045472589321, 0.1449200080242008, 0.1864565143478103, 0.09761931491084397], [0.06474802095908672, 0.05534716212423518, 0.030701797768415418, 0.008530583072570153, 0.02981684789119754, 0.021783290394523647, 0.018197268072981387, 0.017597840960661415, 0.08650517847854644, 0.039411555699189194, 0.0422839900420513, 0.058254236209904775, 0.06022932495397981, 0.13038301229244098, 42.986732348799706, 78.66452649235725, 65.03418669104576, 53.436874598264694, 31.953066810965538, 117.04011127352715, 105.84643632173538, 28.07965725660324, 44.97726693749428, 33.4002685546875, 0.06384074542438611, 0.3573492122814059, 3.474149303510785, 0.8020953380037099, 1.8074414134025574, 1.0456815641373396, 9.974758308380842, 66.22069582343102, 68.641796708107, 87.58555099368095, 82.48230323195457, 84.08847704529762, 82.5805127620697, 81.55332148075104, 75.11490136384964, 77.53751456737518, 75.67612364888191, 77.01129600405693, 76.16698130965233, 75.59082582592964, 72.51492887735367, 72.0573802292347, 71.5104603767395, 69.47025865316391, 71.70650705695152, 70.64175099134445, 67.05102726817131, 64.52520400285721, 55.18902137875557, 52.491709515452385, 54.62399549782276, 54.38167870044708, 54.18275557458401, 51.72698155045509, 50.69070875644684, 54.00791935622692, 52.96859912574291, 49.81676705181599, 48.50261516869068, 47.83950135111809, 50.83538979291916, 47.697339579463005, 47.935556396842, 51.015978902578354, 52.19219818711281, 50.14794208109379, 49.95623856782913, 48.672568649053574, 50.05796290934086, 50.55053807795048, 54.48043920099735, 54.88050453364849, 56.278932094573975, 56.33754014968872, 59.599767699837685, 56.207913905382156, 62.23581925034523, 63.22816640138626, 64.73344802856445, 63.16432222723961, 64.87979337573051, 53.78115512430668, 70.09318962693214, 55.428359135985374, 50.126192048192024, 64.99339208006859, 58.29723559319973, 60.63708923757076, 59.53372344374657, 59.906228855252266, 59.3986938893795, 59.85205136239529, 58.48426915705204, 60.56918688118458, 62.25006468594074, 63.26932579278946, 61.0006233304739, 61.382677629590034, 61.5851079672575, 61.377791091799736, 58.30991171300411, 57.84415930509567, 57.09080412983894, 56.34879134595394, 50.62685698270798, 48.439641147851944, 47.514413595199585, 53.385596349835396, 47.83418543636799, 45.72103902697563, 48.52314166724682, 48.78002308309078, 48.698544055223465, 48.18736508488655, 49.308719113469124, 51.47239901125431, 51.20542913675308, 47.72858530282974, 49.51017290353775, 49.10241298377514, 48.181767985224724, 53.38745065033436, 59.685939475893974, 62.81244970858097, 65.06930440664291, 66.31477117538452, 67.36203297972679, 67.79161512851715, 70.11166423559189, 71.50492027401924, 66.95736989378929, 69.24148812890053, 65.91740369796753, 68.92960086464882, 71.06545865535736, 70.37280142307281, 63.867725282907486, 58.344334065914154, 1.5475399908609688, 0.6291110452730209, 1.4810424903407693, 0.6134410423692316, 1.2218674225732684, 0.24247437017038465, 0.04857120169617701, 0.8910252316854894, 48.906518295407295, 72.1505132317543, 43.93114127218723, 61.19355037808418, 50.178158059716225, 22.15604491531849, 11.69306505471468, 24.517097622156143, 42.29002833366394, 54.33003567159176, 70.9506668150425, 15.546169448643923, 0.6157281040214002, 0.1445700111798942, 0.19946047046687454, 0.08443495753454044, 0.18161716230679303, 0.01778668043698417, 0.09736788269947283, 0.03192442854924593, 0.029107341724738944, 0.036711518550873734, 0.014673099121864652, 0.04968468667357229, 0.07132764250854962, 0.021216304412519094, 0.046981168852653354, 0.02572079571109498, 0.05659248592564836, 0.016662189409544226, 0.07612112982315011, 0.016800399571366142, 0.0353950079443166, 0.023712544098088983, 0.07861257894546725, 0.015987308142939582, 0.064729897712823, 0.01893851218483178, 0.04618934923200868, 0.048754148519947194, 55.90798079967499, 87.52317354083061, 76.69316947460175, 57.22484953701496, 38.22127886116505, 127.89101421833038, 72.72592395544052, 30.15521988272667, 54.724766090512276, 28.59254613518715, 0.1537072888459079, 1.4421163103543222, 3.3901778468862176, 1.4400663203559816, 1.3185254484415054, 1.0800045286305249, 18.762866891920567, 74.71392408013344, 73.4478548169136, 90.56556388735771, 84.42424982786179, 88.84539619088173, 86.02870613336563, 85.8487705886364, 78.69985699653625, 81.70122474431992, 79.48421090841293, 80.97349539399147, 78.49704667925835, 77.93734431266785, 75.49865037202835, 76.48408189415932, 72.93716982007027, 73.36536884307861, 75.33826857805252, 73.37267965078354, 69.98307153582573, 67.42846101522446, 58.294024765491486, 55.25046408176422, 56.72465197741985, 58.594223856925964, 55.086647272109985, 54.989163503050804, 54.49195258319378, 55.93813978135586, 55.3152772039175, 53.39033089578152, 52.78509557247162, 50.46901725232601, 52.80169688165188, 49.74419854581356, 51.19899608194828, 53.855292946100235, 54.40445847809315, 52.45254501700401, 51.977205723524094, 52.082638666033745, 51.119139567017555, 53.80600959062576, 56.55669339001179, 59.597290232777596, 59.168658033013344, 58.897683173418045, 61.499183177948, 60.135751739144325, 65.44360712170601, 65.83347380161285, 67.78778493404388, 65.53879961371422, 68.22140246629715, 58.43430943787098, 71.5791454911232, 58.74193713068962, 51.93510018289089, 67.8867620229721, 59.39023174345493, 63.88337284326553, 61.26972109079361, 63.44260409474373, 62.79431328177452, 62.71468475461006, 62.61568106710911, 63.520883694291115, 64.95866194367409, 65.3059633076191, 62.34163597226143, 63.13612014055252, 63.4376073628664, 65.58458715677261, 60.863853469491005, 59.483102560043335, 58.8307573646307, 58.79113309085369, 52.982115000486374, 50.203248113393784, 48.86745639145374, 55.55193990468979, 50.550895258784294, 46.6830600053072, 49.845535308122635, 50.26895418763161, 50.967968478798866, 51.78520582616329, 50.358545780181885, 54.20863598585129, 52.57474645972252, 53.092632070183754, 51.22708797454834, 52.76665896177292, 49.78715904057026, 54.89458657801151, 61.15851625800133, 65.90172573924065, 68.61587449908257, 70.2924433350563, 71.70174971222878, 72.84267649054527, 71.51236027479172, 72.70380914211273, 71.02077305316925, 70.95002844929695, 68.05436342954636, 71.14759504795074, 71.76370918750763, 71.85916766524315, 66.21936589479446, 64.01983872056007, 2.8339952789247036, 0.4686137434327975, 0.4831919283606112, 2.213167017325759, 2.7412956906482577, 0.6589486473239958, 0.0720523794007022, 0.40229281468782574, 49.43836435675621, 80.8394081890583, 51.56076326966286, 38.70685860514641, 30.5051127076149, 15.971914753317833, 20.084741860628128, 35.765516236424446, 50.90628258883953, 61.789134219288826, 80.35009324550629, 24.124519787728786, 0.9510252589825541, 0.17123999336035922, 0.18124850786989555, 0.02830847355653532, 0.12323983348323964, 0.08427972992649302, 0.10056620521936566, 0.008675511526234914, 0.10154670846532099, 0.023640249637537636, 0.022140792207210325, 0.016264722944470122, 0.01545385424833512, 0.0604077558091376, 0.11233193246880546, 0.23528221703600138, 0.11408316349843517, 0.07686378958169371, 0.14165783853968605, 0.11105618803412654, 0.14858446607831866, 0.16457568533951417, 0.2077719900989905, 0.2079646071069874, 0.12572081090183929, 0.13157417415641248, 0.18151384050725028, 0.21569388220086694, 65.69635435938835, 103.19604054093361, 84.85111132264137, 74.45688307285309, 43.77580180764198, 123.47039222717285, 127.6518702507019, 44.45253789424896, 61.79872490465641, 41.029282584786415, 0.27073021803516895, 1.2085829791612923, 12.873479314148426, 6.5326830837875605, 7.755286479368806, 2.9232674511149526, 24.391436465084553, 73.93995121121407, 75.65685868263245, 91.4709185063839, 86.90032616257668, 89.65430438518524, 89.17593285441399, 90.78868791460991, 80.82056879997253, 83.92985075712204, 83.35509359836578, 85.46729385852814, 81.30749747157097, 80.51882699131966, 79.35970678925514, 80.2195094525814, 76.53789460659027, 74.94451090693474, 77.8839647769928, 76.71332359313965, 74.23825040459633, 71.33656650781631, 61.18014469742775, 58.43632712960243, 60.25210529565811, 61.61120496690273, 57.590473517775536, 56.3024490326643, 56.8124158680439, 60.948585122823715, 59.4654107093811, 56.28452159464359, 56.23486585915089, 52.72491820156574, 55.95175065100193, 53.84126789867878, 53.32004226744175, 57.28322960436344, 56.503344252705574, 55.641805082559586, 55.508751422166824, 54.725982025265694, 55.34876100718975, 57.5590606033802, 58.18977735936642, 62.05297686159611, 64.51272547245026, 61.975575014948845, 66.24892830848694, 64.14343848824501, 69.34575453400612, 70.58951899409294, 71.41298800706863, 67.53132149577141, 70.29079422354698, 61.649202927947044, 73.03468778729439, 61.938143223524094, 56.71159967780113, 69.61090430617332, 61.535068452358246, 66.27811834216118, 66.75044059753418, 65.75629234313965, 66.38257473707199, 66.4733062684536, 64.9847437441349, 67.06055715680122, 68.16100090742111, 69.09934535622597, 66.11684739589691, 65.97983434796333, 67.51468598842621, 68.27608913183212, 65.7627671957016, 63.00998590886593, 64.10391300916672, 62.11372420191765, 56.06644369661808, 52.177728563547134, 50.641527995467186, 57.79442377388477, 53.60351845622063, 48.92414174973965, 55.09936898946762, 53.152934834361076, 55.17891392111778, 54.92576390504837, 53.497827127575874, 58.61885793507099, 57.29103818535805, 55.23455813527107, 54.14023205637932, 55.834789127111435, 53.597685769200325, 59.12618391215801, 65.93862175941467, 67.9548391699791, 71.09705775976181, 71.49805784225464, 74.94476169347763, 74.03240785002708, 75.69953799247742, 76.25002205371857, 72.9772500693798, 75.27718305587769, 72.52170011401176, 74.2084676027298, 74.35909911990166, 73.77929583191872, 66.83909744024277, 63.404982313513756, 3.5463416296988726, 2.9559034248813987, 8.852416332811117, 7.681611282750964, 5.011710673570633, 0.7392072875518352, 0.16583988937782124, 1.4271077094599605, 60.592947006225586, 85.55538073182106, 62.7187467366457, 80.03288626670837, 62.91137360036373, 32.19294413924217, 21.020960323512554, 38.600566908717155, 61.29225008189678, 71.4845609664917, 93.28947812318802, 29.87652573734522, 0.9263591794297099, 0.2804236166412011, 0.3162848751526326, 0.3102004813263193, 0.24354951950954273, 0.20576327835442498, 0.2864344191038981, 0.07032258901745081, 0.13988363061798736, 0.12344779810518958, 0.08008470307686366, 0.131341852247715, 0.1609064923832193, 0.14786525076488033], [0.034019433514913544, 0.04745232130517252, 0.11305604595690966, 0.05399752204539254, 0.0059680023423425155, 0.017103394347941503, 0.0374855897098314, 0.05655140434100758, 0.03611045685829595, 0.07723831440671347, 0.06524776836158708, 0.03872456814860925, 0.10004686511820182, 3.588360487483442, 74.4665877521038, 69.74214926362038, 67.65218541026115, 39.76900041103363, 39.689573273062706, 3.860974721610546, 43.622377440333366, 33.567136600613594, 60.29869459569454, 9.48474895209074, 0.2322029127390124, 0.5828487651888281, 1.2225602916441858, 2.081336653791368, 0.4982390021905303, 3.9317361870780587, 64.69188585877419, 91.68197438120842, 81.31307557225227, 87.49602019786835, 83.20519164204597, 84.23002704977989, 78.08457881212234, 82.35479727387428, 77.77481183409691, 77.90178582072258, 72.85011649131775, 70.94325721263885, 66.50147035717964, 66.582732796669, 66.457529515028, 66.99002534151077, 64.43348452448845, 64.42017763853073, 62.932291477918625, 64.27296593785286, 63.00130717456341, 59.553204998373985, 51.77373804152012, 53.48577417433262, 53.26860822737217, 55.0055406242609, 53.42850744724274, 54.41803514957428, 48.38929384946823, 51.034134328365326, 50.245319455862045, 47.223011031746864, 50.15447773039341, 48.327452167868614, 50.098400339484215, 48.64273265004158, 49.89966720342636, 51.124455481767654, 53.237734884023666, 52.79907502233982, 51.84413306415081, 50.226719453930855, 48.213161900639534, 48.5747466981411, 52.86786273121834, 50.66597208380699, 53.012197986245155, 52.107679322361946, 52.05679625272751, 57.21660777926445, 56.40981987118721, 57.010997012257576, 63.26600097119808, 64.45365384221077, 64.15424510836601, 56.34847976267338, 62.89725735783577, 54.99783843755722, 47.55040146410465, 67.38600209355354, 55.71640267968178, 60.172119587659836, 53.07240575551987, 59.70854826271534, 55.33179871737957, 57.526477351784706, 57.446256056427956, 60.30798129737377, 56.48088365793228, 61.10845774412155, 59.83210623264313, 59.159226939082146, 58.59012007713318, 60.947247594594955, 58.35118509829044, 59.174730107188225, 58.426329866051674, 55.53730309009552, 54.257710352540016, 51.53912343084812, 46.62724860012531, 51.17373123764992, 48.3024875074625, 45.518677085638046, 46.30871169269085, 46.83332674205303, 48.29793155193329, 45.853511318564415, 45.74508033692837, 51.79608844220638, 49.887751042842865, 49.552916809916496, 47.687384113669395, 48.59615094959736, 48.52056160569191, 54.20523516833782, 57.885561883449554, 66.21106714010239, 64.20492678880692, 67.65857666730881, 66.3638873398304, 67.99575537443161, 65.09752169251442, 65.66782549023628, 65.89669480919838, 67.9000461101532, 66.40692383050919, 67.11098045110703, 67.69340559840202, 73.28499555587769, 69.72375065088272, 76.75904273986816, 23.541859053075314, 0.3390415571630001, 1.3210204895585775, 0.3112218843307346, 0.7498986076097935, 1.0067861387506127, 0.3994153894018382, 0.12119475650251843, 15.441775750368834, 73.4083141386509, 54.46620136499405, 34.03489910066128, 95.62724187970161, 139.76198762655258, 49.30244944989681, 8.763182871043682, 33.43906827270985, 50.36394149065018, 65.83975866436958, 34.881592467427254, 0.874045011587441, 0.10607256248476915, 0.07171462799306028, 0.016863955243024975, 0.04527835553744808, 0.03969231758674141, 0.1537218943121843, 0.03602808959840331, 0.03963587725593243, 0.029556446825154126, 0.02138795389328152, 0.00036996655978782655, 0.025626769311202224, 0.03549366905645002, 0.018286860140506178, 0.025269735051551834, 0.016148452523339074, 0.009472241381445201, 0.038220694405026734, 0.03651967337646056, 0.03963054121413734, 0.14591662329621613, 0.049691915191942826, 0.05300279924995266, 0.06246532313525677, 0.07959798778756522, 0.19777634443016723, 6.37196215800941, 86.41671851277351, 77.10926234722137, 73.3476921916008, 51.70072875916958, 48.4395195543766, 13.46354490146041, 45.5047470331192, 39.19290952384472, 65.66724792122841, 7.811197154223919, 0.22486489790026098, 1.4193945983424783, 2.745180744677782, 2.3893901612609625, 1.7784351948648691, 9.105145521461964, 74.02240678668022, 92.85355031490326, 90.32626792788506, 87.55364790558815, 87.56396055221558, 84.23087820410728, 83.43208506703377, 84.83414143323898, 82.59172216057777, 80.68355575203896, 77.40902826189995, 74.21058028936386, 71.48449257016182, 67.62583762407303, 69.81933832168579, 67.96456664800644, 66.99266240000725, 65.84966853260994, 66.17982521653175, 68.01498994231224, 66.76256194710732, 61.400274485349655, 54.784749671816826, 54.66932326555252, 56.15256987512112, 56.42064929008484, 55.39709061384201, 54.88535687327385, 53.54323089122772, 53.60284209251404, 53.80623757839203, 51.203449442982674, 52.72756285965443, 50.95800921320915, 52.2819759696722, 49.78698804974556, 53.15760478377342, 53.16762864589691, 55.773407220840454, 53.923096507787704, 55.21672949194908, 53.09486635029316, 50.69952808320522, 50.986978858709335, 54.72480408847332, 54.92147393524647, 56.55026413500309, 53.70074763894081, 56.94538973271847, 60.19295386970043, 60.47282785177231, 59.507960826158524, 66.29281595349312, 65.99422797560692, 66.27589166164398, 58.00217382609844, 65.5256599187851, 56.360388323664665, 50.40471710264683, 69.49375659227371, 59.7327833622694, 63.60807001590729, 56.631663367152214, 61.095751225948334, 57.04251632094383, 61.705945283174515, 61.44373655319214, 63.584116101264954, 58.27795922756195, 62.88466103374958, 64.13547411561012, 60.370590537786484, 62.81461179256439, 63.49435351788998, 61.174293011426926, 60.191464349627495, 61.5032147616148, 59.036121144890785, 55.68284288048744, 53.845732659101486, 50.1422081887722, 51.79652161896229, 50.403858348727226, 47.25361838936806, 48.49013663828373, 49.38618175685406, 51.23020000755787, 48.51139649748802, 49.79158580303192, 52.966448441147804, 53.434894904494286, 50.43172985315323, 49.55811873078346, 50.95434620976448, 52.250574454665184, 58.29485312104225, 61.00093111395836, 67.63246446847916, 65.93784660100937, 68.90693128108978, 69.21681985259056, 68.85276898741722, 68.56533721089363, 68.15638795495033, 70.24552345275879, 69.46252226829529, 68.87086361646652, 69.68118533492088, 71.659404784441, 75.23818954825401, 72.34763905405998, 78.52268010377884, 30.282744839787483, 0.18883616634411737, 0.9832917619496584, 1.2673557316884398, 3.2792848348617554, 1.6476507252082229, 1.1149828392080963, 0.16419637366198003, 14.920793306082487, 77.02355414628983, 65.07393255829811, 37.43745692074299, 64.18028131127357, 102.71097376942635, 44.53136466443539, 19.04351983219385, 44.135463908314705, 57.034190967679024, 72.2937123477459, 48.56790706515312, 0.8208496472798288, 0.12362858527922072, 0.016105693684949074, 0.04620486382918898, 0.015623240178683773, 0.027786916289187502, 0.03838953300146386, 0.08911194250686094, 0.07633065295522101, 0.04441504483111203, 0.03230154718039557, 0.034006616624537855, 0.010378344322816702, 0.05540056707104668, 0.12466114276321605, 0.1820537232561037, 0.1214982132660225, 0.08950312112574466, 0.1316393940942362, 0.14769273111596704, 0.10228044760879129, 0.13971025007776916, 0.1906199924997054, 0.1506892711040564, 0.12983270979020745, 0.2259087879792787, 0.4212549253134057, 7.9563631396740675, 102.52774000167847, 88.47591921687126, 88.03971782326698, 57.19931870698929, 56.34111575782299, 8.015452343970537, 62.36335560679436, 52.28568457067013, 78.03550824522972, 11.324732769280672, 0.24604453094070777, 2.6728535257279873, 4.112443802878261, 8.598274569958448, 4.026253502815962, 13.523187451064587, 76.18325963616371, 97.56420314311981, 90.98794922232628, 91.74531698226929, 91.6201288998127, 88.4865890443325, 85.13937145471573, 86.65613606572151, 85.11428520083427, 83.71150687336922, 79.50441062450409, 76.00755706429482, 74.01591673493385, 71.1936865746975, 73.74305337667465, 72.51556724309921, 72.19126984477043, 69.3906757235527, 69.27032858133316, 70.36785408854485, 70.04158839583397, 65.67392036318779, 56.2332471460104, 56.7187774926424, 59.09219093620777, 58.81750747561455, 60.05267299711704, 58.638369888067245, 54.831981137394905, 57.057669907808304, 56.99692256748676, 53.152095079422, 55.19023351371288, 52.71615207195282, 56.42826408147812, 52.56397403776646, 54.85994763672352, 57.376248612999916, 58.77171233296394, 56.151186749339104, 57.96717010438442, 56.58711835741997, 54.18903283774853, 54.54381600022316, 59.08709540963173, 57.53141708672047, 60.865096002817154, 58.17997008562088, 59.566591680049896, 64.48422700166702, 64.4505076110363, 63.954573422670364, 69.88247573375702, 69.73242938518524, 69.58908587694168, 61.971372440457344, 68.68445321917534, 60.93389891088009, 54.58975933492184, 71.81220218539238, 61.8306127935648, 66.1543969810009, 62.01443932950497, 65.290786921978, 60.66186770796776, 65.79162284731865, 65.97432464361191, 68.17363142967224, 61.431941986083984, 65.44451907277107, 66.75892174243927, 65.12399107217789, 65.49526154994965, 67.56297379732132, 64.50320318341255, 64.30648773908615, 64.80692088603973, 61.1987940967083, 59.71919909119606, 57.364834025502205, 54.360293447971344, 55.470035299658775, 54.016411900520325, 50.621134489774704, 51.476217806339264, 51.68725848197937, 54.7929572314024, 50.50438575446606, 53.39329853653908, 55.165265053510666, 54.964673817157745, 53.59868511557579, 51.24712809920311, 53.92026945948601, 55.28422527015209, 61.00996322929859, 63.99255618453026, 70.2170629799366, 70.16394183039665, 73.21232065558434, 73.0568177998066, 73.02248284220695, 71.6792169213295, 71.32913410663605, 74.38953548669815, 74.59479287266731, 72.03441426157951, 72.88298472762108, 76.03654950857162, 79.35380190610886, 77.79219970107079, 82.34650611877441, 31.14768672734499, 0.41484579734969884, 6.20149428024888, 7.318044416606426, 8.090276028960943, 2.73351869545877, 0.9079099225345999, 0.2723850292386487, 20.938022173941135, 86.08705580234528, 68.3976674079895, 53.444713577628136, 116.51087567210197, 149.73093509674072, 61.2143162637949, 18.009211532771587, 49.61468629539013, 67.20655292272568, 83.95533978939056, 56.569304913282394, 1.5091341454535723, 0.25798813614528626, 0.1884210534626618, 0.1654124865308404, 0.22193019365658984, 0.11579713129322045, 0.252623061533086, 0.178990330605302, 0.18191231443779543, 0.08219223920605145, 0.10888397373491898, 0.13343561411602423, 0.10635622616973706, 0.15244170441292226], [0.0938100712664891, 0.02177858888899209, 0.052082714246353135, 0.05766561291238759, 0.04968945497239474, 0.026825720015040133, 0.0562614286900498, 0.026120514594367705, 0.023400072095682845, 0.10472644018591382, 0.029219138850749005, 0.1282884637475945, 0.22387003409676254, 20.893670953810215, 81.98217406868935, 69.15003463625908, 59.56772021949291, 38.0149195343256, 20.159436352550983, 58.99982929229736, 48.64092394709587, 37.50199645757675, 55.067275911569595, 0.43526192370336503, 0.10289554702467285, 1.9710848573595285, 0.8141905046068132, 1.4525262080132961, 1.3457724801264703, 35.11666305363178, 88.50123345851898, 78.58935132622719, 91.529321372509, 80.07479801774025, 85.16828790307045, 81.17586493492126, 83.68873849511147, 78.06019932031631, 81.99476659297943, 74.8741614818573, 73.87524828314781, 70.1578925549984, 67.4018320441246, 62.3750551789999, 61.03534586727619, 57.89103738963604, 58.7021304666996, 56.82428263127804, 57.7346795797348, 53.48614655435085, 56.439287289977074, 52.86792352795601, 53.327721655368805, 53.08770753443241, 55.70517048239708, 52.42954485118389, 52.93125852942467, 51.922925636172295, 51.13524690270424, 47.50999443233013, 51.43074944615364, 49.11286622285843, 48.49777802824974, 46.36356934905052, 49.85867120325565, 48.75815145671368, 49.97866116464138, 53.82423721253872, 56.346066892147064, 53.453931882977486, 52.36980825662613, 48.44038590788841, 47.99751967191696, 46.61506645381451, 50.277423933148384, 47.196393460035324, 48.73072072863579, 49.332053661346436, 51.18115223944187, 53.35946895182133, 55.7855361700058, 53.406244441866875, 56.9826353341341, 60.6168857216835, 63.206321373581886, 56.22369445860386, 64.72055912017822, 46.260351687669754, 46.79146818816662, 67.2666808962822, 54.77286010980606, 58.6998125910759, 54.19240705668926, 57.69426874816418, 54.24086585640907, 56.063567250967026, 56.73235796391964, 58.269816264510155, 56.88421681523323, 56.705831587314606, 57.08415448665619, 58.856531381607056, 57.295666337013245, 55.297003984451294, 57.912171855568886, 60.41195511817932, 57.02775411307812, 57.706143110990524, 56.02634824812412, 53.55857826769352, 47.62048490345478, 49.98337671160698, 47.57087856531143, 43.333744928240776, 45.10820411145687, 46.443038284778595, 48.283986300230026, 44.96484540402889, 47.03414976596832, 46.27672880887985, 48.59371908009052, 48.26911009848118, 49.771325290203094, 46.58053010702133, 49.779035076498985, 52.08378240466118, 58.30147236585617, 58.416735380887985, 60.56484751403332, 56.66596792638302, 62.09445163607597, 58.923392593860626, 60.819604843854904, 56.5672492235899, 61.50558203458786, 59.17833611369133, 62.9119473695755, 62.19396449625492, 65.062685161829, 67.22759619355202, 67.26022124290466, 66.6026209294796, 72.60582759976387, 17.212211899459362, 0.30532314616721123, 0.8296095428522676, 1.8023878033272922, 0.7905315491370857, 0.30217890394851565, 0.09189697782858275, 1.4824188477359712, 47.628396078944206, 81.28620341420174, 40.599195063114166, 70.2734063565731, 115.58301106095314, 123.69687527418137, 31.882215812802315, 13.314043823629618, 53.54217454791069, 52.86807931959629, 61.84350550174713, 3.347108820453286, 0.15732646104879677, 0.03290518783614971, 0.022244360770855565, 0.01557596908241976, 0.028910644759889692, 0.07763778281514533, 0.07283185710548423, 0.04905157533357851, 0.10905734685366042, 0.025073340511880815, 0.05240570804744493, 0.021348785194277298, 0.0487366412562551, 0.06274751736782491, 0.04293931015126873, 0.017927536355273332, 0.021082521161588375, 0.07333035769988783, 0.019950137393607292, 0.05070697654446121, 0.09346070524770766, 0.043034212285419926, 0.06333877900033258, 0.06304347843979485, 0.22322709672152996, 0.2385414921445772, 30.543682537972927, 94.99541938304901, 74.28991243243217, 70.9318958222866, 52.53050923347473, 31.89732000231743, 41.7705088108778, 43.09464655816555, 46.95898599922657, 57.70765163004398, 0.34033526899293065, 0.02043567452346906, 3.3621545881032944, 2.903805607929826, 0.7558218366466463, 1.467604273930192, 45.84393963217735, 90.6922110915184, 82.32945263385773, 92.12594255805016, 84.39523458480835, 85.57493448257446, 85.2961814403534, 87.07931935787201, 79.15948033332825, 84.82499912381172, 78.07424336671829, 75.78871920704842, 71.20076939463615, 70.99558800458908, 65.61490952968597, 63.11198003590107, 61.48041978478432, 61.3088171929121, 59.78164494037628, 60.66095195710659, 56.71384155750275, 58.05960014462471, 55.586502850055695, 54.96568836271763, 54.81309615075588, 57.4691042304039, 55.26204966008663, 56.286983862519264, 54.13900092244148, 54.08899940550327, 51.4554139226675, 54.90627475082874, 51.63220323622227, 48.97374428808689, 50.66592648625374, 51.41861669719219, 50.77156841754913, 52.64491729438305, 56.2767244130373, 58.37089464068413, 54.6811368316412, 55.57799130678177, 49.109389409422874, 50.27543283998966, 49.62104335427284, 52.51749113202095, 48.76247562468052, 51.854194924235344, 50.863933861255646, 54.82447274029255, 56.64671815931797, 61.26978188753128, 57.7806381136179, 59.01019133627415, 61.89292185008526, 64.83924955129623, 60.61577998101711, 67.60808497667313, 50.51198534667492, 50.3682466596365, 69.3980473279953, 56.53822638094425, 61.21845044195652, 58.6227261275053, 60.42237035930157, 58.274482414126396, 58.17511014640331, 61.70111194252968, 61.180938854813576, 60.62807232141495, 58.28775890171528, 58.92238564789295, 60.315615087747574, 60.161673948168755, 57.24538743495941, 59.42764073610306, 63.713723346590996, 60.26550717651844, 61.350580751895905, 58.15184399485588, 54.695154279470444, 51.458442360162735, 50.82945071160793, 49.979694709181786, 46.28137215971947, 48.465076982975006, 50.37226304411888, 51.79359957575798, 49.067534655332565, 48.7849286198616, 49.15751002728939, 52.09176577627659, 51.21438905596733, 50.90661317110062, 50.23176558315754, 53.42490904033184, 54.25038434565067, 59.327204525470734, 61.62769228219986, 61.59107744693756, 60.18904387950897, 64.80538576841354, 62.694013863801956, 61.81276135146618, 59.27024558186531, 61.747389659285545, 63.017889484763145, 63.41481998562813, 64.7683073580265, 67.02779531478882, 69.2187425494194, 71.28007873892784, 71.56650736927986, 75.87356865406036, 24.855237677693367, 0.281258710892871, 0.9182352153584361, 1.279338151216507, 2.9671767074614763, 0.8227429550606757, 0.06534571701195091, 1.2053100485354662, 47.03103393316269, 87.6720267534256, 48.7357896566391, 65.36540731787682, 105.85753172636032, 102.618577927351, 38.705749064683914, 21.083767153322697, 61.11843980848789, 58.29358398914337, 74.65641796588898, 6.99648667126894, 0.23434828355675563, 0.09670019469922408, 0.06197867092851084, 0.027698808517016005, 0.003810977023022133, 0.06438479904318228, 0.11875640804646537, 0.019350213042343967, 0.049420741852372885, 0.04016915860120207, 0.04284686081518885, 0.013063436472293688, 0.01921781018609181, 0.28615317482035607, 0.11068091363995336, 0.1471211586613208, 0.12302352712140419, 0.2714739093789831, 0.2458734213723801, 0.14121597865596414, 0.14645721850683913, 0.24654218548676, 0.18382071750238538, 0.21302299661329016, 0.4028159991139546, 0.33355827326886356, 39.894709065556526, 107.84394353628159, 84.9791644513607, 81.73206388950348, 53.67906220257282, 31.640636175870895, 74.10361602902412, 67.28428915143013, 56.310899779200554, 67.58926838636398, 0.7437155081424862, 0.23445371305570006, 5.974184777587652, 6.947429878637195, 5.039343740791082, 5.502178855240345, 47.268186807632446, 97.49935582280159, 86.19062304496765, 94.91953745484352, 85.80579489469528, 89.38897982239723, 86.54257535934448, 90.42182520031929, 83.7189544737339, 88.86513993144035, 81.66783213615417, 80.09920790791512, 76.54924839735031, 74.72371995449066, 69.58870589733124, 66.74961224198341, 65.10254502296448, 63.61433207988739, 62.182451114058495, 63.94117534160614, 59.242362678050995, 61.74379125237465, 58.660218715667725, 56.68156608939171, 58.45394678413868, 60.2143619209528, 58.49791802465916, 58.985382467508316, 58.68166096508503, 57.29094699025154, 53.587730303406715, 58.97446945309639, 55.09825184941292, 50.507497787475586, 52.988194674253464, 55.485633462667465, 55.59526897966862, 56.30136989057064, 60.4377481341362, 61.894479766488075, 58.89825314283371, 58.10871630907059, 51.33946314454079, 52.69725188612938, 51.469856947660446, 56.47313967347145, 52.5392297655344, 55.70722997188568, 54.29416939616203, 58.30820560455322, 60.52213400602341, 63.004932180047035, 59.729690328240395, 62.405149564146996, 67.9682144522667, 66.97281986474991, 61.8434789031744, 69.29144784808159, 55.682485699653625, 56.98176898062229, 71.79864451289177, 61.584838181734085, 64.3285645544529, 61.021054834127426, 64.80617612600327, 62.80445493757725, 59.81644727289677, 64.37679916620255, 64.56774652004242, 63.158299550414085, 61.40114463865757, 60.978907495737076, 64.20961573719978, 62.52208448946476, 62.85935819149017, 64.55532118678093, 67.16929212212563, 64.08804506063461, 65.34243375062943, 63.034566789865494, 57.58755907416344, 54.38507191836834, 54.91821750998497, 52.27645106613636, 49.53973151743412, 50.941126719117165, 52.328781858086586, 55.44524922966957, 49.60627734661102, 51.61000482738018, 52.855494394898415, 53.84735897183418, 53.308718875050545, 54.8566760122776, 55.120959430933, 55.592384934425354, 56.91571332514286, 63.81486251950264, 66.24715760350227, 63.97504672408104, 64.59693655371666, 69.9255958199501, 66.37574270367622, 68.24552357196808, 64.06330838799477, 66.45815268158913, 65.7102844119072, 68.29616725444794, 69.6665409207344, 70.72450295090675, 73.25839698314667, 75.35966902971268, 74.78389352560043, 77.18531146645546, 24.073606319725513, 0.6852038728538901, 6.463618939742446, 7.292061885818839, 5.108511904254556, 1.3717722287401557, 0.20068575628101826, 2.1136826556175947, 61.34722173213959, 95.36535993218422, 57.66137391328812, 78.23448076844215, 115.39188891649246, 127.30203062295914, 45.901069566607475, 24.009853340685368, 73.6226150393486, 68.1482183933258, 88.6669197678566, 8.141965605318546, 0.35445596440695226, 0.29702667728997767, 0.148415612638928, 0.08777430295594968, 0.08193119618226774, 0.2305044187232852, 0.1888300510472618, 0.14042707567568868, 0.2122320601483807, 0.14876835542963818, 0.13773235230473801, 0.15409213694510981, 0.23180295451311395], [0.019507394354150165, 0.021120457895449363, 0.07777010774589144, 0.009932496323017403, 0.03719992222613655, 0.0433934191823937, 0.031079126056283712, 0.09495720150880516, 0.033543939498486, 0.10965446403133683, 0.03416348437895067, 0.08927013128413819, 0.24683050985913724, 51.98600225150585, 71.36397063732147, 69.7829894721508, 47.31905847787857, 20.211438462138176, 28.716696873307228, 76.5879987180233, 42.22632475197315, 64.4505912065506, 35.20890690386295, 0.359913184074685, 0.9823805233463645, 0.9239618049468845, 3.1987975537776947, 0.41492544463835657, 7.864915346726775, 69.3153789639473, 84.78893905878067, 84.1975311934948, 84.06612664461136, 83.23790028691292, 80.15202507376671, 76.39928564429283, 81.97357892990112, 78.6383306980133, 82.31977075338364, 77.73987650871277, 78.49510118365288, 70.81851750612259, 67.21749633550644, 61.87948577105999, 60.54737225174904, 52.746402248740196, 53.915268927812576, 53.61693173646927, 54.17129538953304, 51.94036290049553, 54.92075577378273, 53.96270178258419, 55.630177706480026, 53.219674453139305, 52.93856553733349, 51.28926023840904, 52.91503719985485, 49.50431361794472, 49.36827331781387, 49.26301136612892, 49.056439250707626, 51.04342482984066, 49.57867182791233, 47.55863182246685, 48.254142701625824, 46.589159443974495, 50.50625905394554, 55.09206958115101, 56.57024346292019, 54.92007181048393, 56.573351696133614, 51.01847156882286, 48.849946931004524, 46.42581380903721, 50.217098370194435, 48.87716107070446, 48.3986983448267, 43.51877599954605, 49.515192434191704, 51.98562607169151, 56.57811664044857, 49.83533285558224, 55.1631523668766, 52.35033430159092, 63.163026496768, 52.716877833008766, 68.6278286576271, 28.670981526374817, 30.402706302702427, 70.9761406481266, 49.77147728204727, 60.940096378326416, 53.09315264225006, 60.51536276936531, 55.62341406941414, 55.3362824767828, 54.77284871041775, 58.99136334657669, 58.559683710336685, 60.984884575009346, 55.822937563061714, 57.89368584752083, 58.532826751470566, 55.94035506248474, 51.17282688617706, 55.66208839416504, 56.97319284081459, 57.293025478720665, 56.103484109044075, 54.5079231262207, 49.763881489634514, 47.45771303772926, 48.45690742135048, 46.779620423913, 42.48322516679764, 45.85451066493988, 45.56737147271633, 46.523027792572975, 46.4556460082531, 46.16043984889984, 48.03538843989372, 48.42789977788925, 48.86768817901611, 48.94154101610184, 47.25148290395737, 53.03405061364174, 52.82030068337917, 56.30978263914585, 56.059056892991066, 53.39459426701069, 52.69856281578541, 53.34470294415951, 52.1073829382658, 55.52602529525757, 54.421006590127945, 56.71026594936848, 56.67046308517456, 60.235781371593475, 59.57293353974819, 59.44975554943085, 62.39771716296673, 68.93462419509888, 67.37561345100403, 75.54284200072289, 17.936918511986732, 0.5025099136400968, 2.060782606713474, 1.2958802073262632, 1.7340447893366218, 0.11952198532526381, 0.07475013073417358, 12.714622188359499, 74.24418568611145, 57.3191224783659, 41.32547669112682, 63.07250775396824, 65.18338188529015, 20.840614400804043, 21.789603978395462, 45.705950036644936, 52.29661278426647, 67.82109394669533, 21.278086826205254, 0.8976910240016878, 0.0992843603307847, 0.19666497828438878, 0.0031941112956701545, 0.13361142890062183, 0.023132904498197604, 0.08099087281152606, 0.07704885152634233, 0.06542360541061498, 0.036252993741072714, 0.10429928224766627, 0.018346378528804053, 0.07355705412919633, 0.06660446626483463, 0.03848391934297979, 0.04901049745967612, 0.02497036195563851, 0.04764319797686767, 0.006899865229570423, 0.017221047019120306, 0.04843518829147797, 0.08622031251434237, 0.06344430497847497, 0.07811945892171934, 0.09486114533501677, 0.38123576960060745, 65.37584155797958, 79.18776601552963, 78.53700533509254, 56.8792998790741, 32.70552143454552, 27.988872528076172, 53.93514946103096, 47.84808129072189, 75.65528556704521, 37.29969911277294, 0.6175673240795732, 1.623136221896857, 2.051164610311389, 3.829429051838815, 1.5624526469036937, 13.527633212506771, 81.5147839486599, 85.28879463672638, 89.8363146185875, 84.82502192258835, 87.54697546362877, 83.00830900669098, 81.58661529421806, 83.73852342367172, 81.98403596878052, 84.13966789841652, 82.26455971598625, 80.41378542780876, 72.9426871240139, 70.16659408807755, 65.99941849708557, 63.36209401488304, 58.218819200992584, 56.90508529543877, 57.146474942564964, 56.48359291255474, 53.98619592189789, 56.38799764215946, 56.325418800115585, 57.84617319703102, 55.45352518558502, 55.63730612397194, 54.92267467081547, 53.510054871439934, 52.51199282705784, 51.15651436150074, 53.105152398347855, 51.02801285684109, 52.47141480445862, 49.6019683778286, 49.38148520886898, 51.69080749154091, 50.076619908213615, 52.432763278484344, 56.534122601151466, 60.09144611656666, 58.36835257709026, 58.02772365510464, 53.567458391189575, 51.51747599244118, 49.057845175266266, 51.37332692742348, 53.23135882616043, 51.62689492106438, 48.72758209705353, 51.03913865983486, 54.46410767734051, 58.861273527145386, 56.05353958904743, 58.00347335636616, 54.494779631495476, 63.39379571378231, 59.665469974279404, 66.9713607430458, 50.677166283130646, 46.8983868509531, 69.17480930685997, 55.494088008999825, 62.38367311656475, 58.208495154976845, 60.15763856470585, 56.411419585347176, 58.128239661455154, 59.96710158884525, 62.04974703490734, 61.40736110508442, 63.430980518460274, 59.184240996837616, 60.89381866157055, 62.96208567917347, 58.47690895199776, 56.152148097753525, 58.30575093626976, 61.36675268411636, 61.92384459078312, 59.783362448215485, 56.12506315112114, 54.18876305222511, 48.72126303613186, 50.3760552406311, 48.5537414252758, 44.48183812201023, 46.643705517053604, 48.97326551377773, 49.309148490428925, 46.47873356938362, 48.87209594249725, 50.40626361966133, 49.85094241797924, 50.508945509791374, 53.21239024400711, 50.259390100836754, 54.2034150660038, 54.02080066502094, 58.899628669023514, 58.1571751087904, 55.80110013484955, 55.65601631999016, 56.052445247769356, 55.63814587891102, 56.5014785528183, 57.69879050552845, 58.27854819595814, 60.38165934383869, 61.26392640173435, 62.966729030013084, 62.09586136043072, 65.29006496071815, 71.96668669581413, 68.93992111086845, 79.91307109594345, 25.08664146065712, 0.5677528283558786, 0.8167362492531538, 1.477535990998149, 2.5125463027507067, 0.37178719067014754, 0.13736245105974376, 11.458478942513466, 77.54981070756912, 63.617542907595634, 46.532322093844414, 66.17208883166313, 72.82598778605461, 28.728193156421185, 30.543722435832024, 56.11950784921646, 59.00115542113781, 76.18435397744179, 30.25470994412899, 0.836448878981173, 0.09692956286016852, 0.14038524823263288, 0.020648004829126876, 0.1646127927233465, 0.024878725271264557, 0.14153303898638114, 0.04010619108157698, 0.034499235698604025, 0.046714107011212036, 0.11228714385651983, 0.07175230683060363, 0.05279128716210835, 0.2890819567255676, 0.1240508227783721, 0.12042090427712537, 0.11333570946590044, 0.19328566821059212, 0.2629603474633768, 0.08096214427496307, 0.13467549055349082, 0.22856742813019082, 0.15034055075375363, 0.12776133109582588, 0.2020005154190585, 0.8717017841991037, 78.96892815828323, 91.2321013212204, 87.36326292157173, 66.77517727017403, 31.29152610898018, 42.011408284306526, 97.75913268327713, 62.339154705405235, 83.30490589141846, 44.77750405669212, 0.7023573399055749, 2.0589021826162934, 3.9241921668872237, 7.3918478563427925, 3.6035226238891482, 15.101337768137455, 87.25869253277779, 88.73321861028671, 94.05220359563828, 85.15268594026566, 92.22979858517647, 86.31510436534882, 87.63106495141983, 85.42527571320534, 86.28415122628212, 86.16585597395897, 84.22854512929916, 82.69015207886696, 76.58235982060432, 72.93011739850044, 69.81423139572144, 67.37847089767456, 62.21140556037426, 59.39587064087391, 60.52739292383194, 59.46891412138939, 58.79443131387234, 58.834021389484406, 61.100117191672325, 60.747933089733124, 59.33921568095684, 56.704870238900185, 58.289692997932434, 57.54680626094341, 56.898523047566414, 53.98059502243996, 56.66497617959976, 54.55081522464752, 55.70677399635315, 53.12329642474651, 53.955949544906616, 54.821862280368805, 52.966672629117966, 55.2299489825964, 59.24440696835518, 64.72438171505928, 61.91901884973049, 59.883494675159454, 56.17080509662628, 55.11793479323387, 53.005681335926056, 53.7975512444973, 56.44612692296505, 53.47990348935127, 53.54517638683319, 53.60948793590069, 57.80820943415165, 61.593729704618454, 58.79682898521423, 60.96205919981003, 58.46162997186184, 67.64302030205727, 61.53849586844444, 68.68633791804314, 54.06925946474075, 47.82262645661831, 72.30892673134804, 57.96135261654854, 65.36855354905128, 63.497963324189186, 63.270180746912956, 61.76589846611023, 59.78924073278904, 63.544130846858025, 65.45932307839394, 65.63161343336105, 65.52793979644775, 60.753059014678, 62.86267161369324, 65.14207050204277, 60.65845549106598, 58.42475675046444, 62.00311593711376, 64.62850525975227, 64.12717536091805, 63.62616844475269, 61.01551093161106, 56.8762144446373, 51.76119491457939, 54.3695193529129, 52.29799211025238, 47.367528676986694, 51.60694979131222, 51.10186569392681, 51.890467777848244, 51.95830173790455, 51.82872109115124, 53.57112139463425, 52.994840517640114, 52.855786979198456, 56.60593494772911, 54.00389537215233, 58.49007524549961, 57.73688346147537, 61.76577307283878, 62.83619463443756, 60.32445341348648, 59.960406348109245, 61.083789467811584, 59.581391885876656, 60.35436540842056, 60.72199188172817, 61.60662621259689, 62.63301953673363, 65.35514026880264, 66.04052469134331, 65.69316253066063, 66.19481921195984, 75.83522871136665, 72.8013727068901, 81.90667971968651, 24.516825936734676, 1.5785791003145278, 7.83811965957284, 8.19649362936616, 5.482995584607124, 0.5336172413080931, 0.2172037964919582, 17.556790709495544, 87.9953970015049, 71.94559022784233, 55.79215921461582, 69.0878775715828, 75.33012181520462, 29.60044015198946, 34.370846673846245, 67.24274218082428, 69.441699385643, 89.10849407315254, 35.33953629434109, 1.1085968068800867, 0.1702056621434167, 0.22280263277934864, 0.07241701139719225, 0.19987749808933586, 0.0927554423105903, 0.2259516395861283, 0.248758654051926, 0.1178909970622044, 0.14602859853766859, 0.18072931619826704, 0.14198315155226737, 0.1584220491349697], [0.054494571741088293, 0.042126565676881, 0.0775535119464621, 0.001179407752260886, 0.11366974271368235, 0.039504509695689194, 0.04575898150505964, 0.14491150301182643, 0.028733694489346817, 0.02265352348331362, 0.04252375569194555, 0.3049097105395049, 8.237236943095922, 71.84539720416069, 68.9228980243206, 66.35358229279518, 51.53822287917137, 24.32413637638092, 40.41816517710686, 52.105714827775955, 37.29124456644058, 80.08099928498268, 8.474258724600077, 0.1802785208565183, 0.5816010665148497, 3.459125147201121, 0.9383466455619782, 0.4055478743975982, 38.00988480448723, 80.564394146204, 77.9208379983902, 83.35399925708771, 80.51967054605484, 84.33940798044205, 87.7871985733509, 79.56833839416504, 80.06169632077217, 83.90240103006363, 79.8861001431942, 80.6258824467659, 77.6998570561409, 71.53111606836319, 66.03281870484352, 60.62429152429104, 58.19873347878456, 52.946263924241066, 55.741534531116486, 51.85821890830994, 55.24192973971367, 51.92107893526554, 52.754469215869904, 52.85840503871441, 52.64348857104778, 53.82012203335762, 52.05362342298031, 51.89539611339569, 52.35848866403103, 49.48853686451912, 50.622000843286514, 46.747474148869514, 51.34815327823162, 48.30999590456486, 51.37989677488804, 45.72798125445843, 48.199699223041534, 47.94563725590706, 48.56465823948383, 55.00560142099857, 58.81627254188061, 55.54394133388996, 60.878672674298286, 51.86514213681221, 49.65464495122433, 50.2534244209528, 54.205588549375534, 50.57027421891689, 52.69919738173485, 45.587115213274956, 50.98630249500275, 47.08433747291565, 60.698334351181984, 48.632910177111626, 60.6168819218874, 50.03394439816475, 63.16205754876137, 45.08363462984562, 79.51406970620155, 8.445254880934954, 10.438279286026955, 79.56516936421394, 45.44879883527756, 66.74427732825279, 50.03506913781166, 64.37184423208237, 50.46091988682747, 56.7890053242445, 52.65725143253803, 61.189932972192764, 56.13076664507389, 60.11415749788284, 56.312222108244896, 58.59166279435158, 57.94248282909393, 58.68958353996277, 47.327079847455025, 50.00994488596916, 47.91969984769821, 53.97568568587303, 50.90750612318516, 54.82189267873764, 47.448411136865616, 48.85216981172562, 45.09031467139721, 49.16083864867687, 39.381371811032295, 44.01364244520664, 45.89908987283707, 48.04964527487755, 45.231116116046906, 44.20473039150238, 48.131226897239685, 50.92196434736252, 46.7653863877058, 49.5734167098999, 46.580841690301895, 51.054379642009735, 48.69130924344063, 48.38748134672642, 50.44052638113499, 49.350334480404854, 49.289803728461266, 51.29553370177746, 51.99930913746357, 56.463488191366196, 58.35546746850014, 57.698528319597244, 58.10775876045227, 62.74113893508911, 59.87532511353493, 59.730127304792404, 58.400400057435036, 67.10861697793007, 65.94169959425926, 72.1013742685318, 61.949421018362045, 13.61896701157093, 0.7184530387166888, 3.1212859880179167, 1.0065398644655943, 0.27379885024856776, 0.05724126771383453, 0.7238639483693987, 47.71863743662834, 78.54078233242035, 46.216388046741486, 38.70817333459854, 33.38250830769539, 19.88868948072195, 16.796318516135216, 31.291051134467125, 57.23621852695942, 51.769995242357254, 50.32573454082012, 2.352133160457015, 0.09476805033045821, 0.09509599054581486, 0.03855135088087991, 0.0400279946916271, 0.027891759491467383, 0.07556122392998077, 0.11717674671672285, 0.0043480256954353536, 0.03310024279926438, 0.03788499132497236, 0.05942181633145083, 0.03395059931790456, 0.12499013682827353, 0.018487384731997736, 0.030586798275180627, 0.04157865660090465, 0.13304509600857273, 0.10986632492858917, 0.053658312317566015, 0.09157570952083915, 0.08148725828505121, 0.051952693684143014, 0.1344950299244374, 0.2510629186872393, 11.647717338055372, 83.58505725860596, 73.29270154237747, 75.98089009523392, 68.04331362247467, 35.06107583642006, 37.941579669713974, 47.16202810406685, 41.56342752277851, 91.03440552949905, 8.295135386288166, 0.2574911346891895, 1.2540630949661136, 5.0331951957196, 0.8936393132898957, 2.457614312879741, 47.56204403936863, 85.37836343050003, 85.03137364983559, 87.68273457884789, 82.3110768198967, 90.68566784262657, 88.53379771113396, 85.58164492249489, 83.1615699827671, 85.90086579322815, 80.76275110244751, 84.00637865066528, 79.13333013653755, 71.5059158205986, 67.51600831747055, 61.763964369893074, 61.990504413843155, 57.33500562608242, 57.8097103536129, 54.08724769949913, 57.72521808743477, 55.010438561439514, 57.2142481058836, 56.24534949660301, 53.571668565273285, 56.144259721040726, 55.98404511809349, 56.274851113557816, 52.583413794636726, 52.25767247378826, 54.23783361911774, 49.64446909725666, 52.73486986756325, 50.15236884355545, 52.87982828915119, 48.357911333441734, 49.848974123597145, 50.00330664217472, 52.32743293046951, 57.18129627406597, 59.03593495488167, 58.91151063144207, 60.528890043497086, 56.08662061393261, 53.19250591099262, 51.825700253248215, 55.75551018118858, 54.91236202418804, 56.79280512034893, 47.19237707555294, 51.89995586872101, 51.915037259459496, 61.46331690251827, 51.96676768362522, 62.05094777047634, 52.78317287564278, 64.79554429650307, 52.9693628847599, 79.0700027346611, 28.377340883016586, 26.080046854913235, 76.16299152374268, 51.61222770810127, 64.62196201086044, 56.32274754345417, 65.88623777031898, 53.09225969016552, 60.32561235129833, 58.725708201527596, 63.968868255615234, 58.725202828645706, 62.7563913166523, 59.83090169727802, 59.37483496963978, 59.14513349533081, 60.43962903320789, 51.242853328585625, 50.688227489590645, 52.32803709805012, 56.222626715898514, 54.019782319664955, 55.23496091365814, 51.03069931268692, 50.081928223371506, 47.97440931200981, 50.1039632409811, 41.51571348309517, 45.72475902736187, 48.27759504318237, 50.57759642601013, 47.9344392567873, 45.26201605796814, 50.049333572387695, 51.120040118694305, 49.89297956228256, 50.07644511759281, 50.04162758588791, 53.681509271264076, 51.478414088487625, 52.84314885735512, 53.44028301537037, 51.08184076845646, 53.125690296292305, 53.97326521575451, 53.97050656378269, 58.89984145760536, 60.31106673181057, 60.8073391020298, 61.10614746809006, 64.70523074269295, 63.157398998737335, 60.589739978313446, 60.847818329930305, 69.77508589625359, 69.3789267539978, 73.51436644792557, 69.19250875711441, 19.327372200787067, 1.5264591970480978, 1.3256868766620755, 1.9320347090251744, 1.2065928359515965, 0.21808104473166168, 0.49115241214167327, 47.39705689251423, 84.11447525024414, 57.01595574617386, 43.40801574289799, 36.72501415014267, 20.22937349975109, 23.088737167418003, 41.40097104012966, 64.38316762447357, 60.703464075922966, 62.533331885933876, 3.587872926145792, 0.1588363604969345, 0.05953703846898861, 0.02747093021753244, 0.04048958457133267, 0.06797037422074936, 0.10042582798632793, 0.09683664597105235, 0.02051626805041451, 0.016606786230113357, 0.06236171931959689, 0.021826681913807988, 0.06340070380247198, 0.211784663842991, 0.1485320259234868, 0.15990279702236876, 0.2688765409402549, 0.21220278984401375, 0.1153945607075002, 0.28808376810047776, 0.21924367843894288, 0.12601039692526683, 0.12794808513717726, 0.41929348837584257, 0.3910928266122937, 15.682281944900751, 100.02901688218117, 86.19424045085907, 87.10361525416374, 70.05340576171875, 36.388485208153725, 52.54556022584438, 73.0661652982235, 50.31797915697098, 98.298399746418, 10.06473083049059, 0.1691587144159712, 2.995379981584847, 8.965748101472855, 7.696073781698942, 5.8377948962152, 51.135174706578255, 87.08865165710449, 89.0055499970913, 90.45394867658615, 85.92098951339722, 92.11522713303566, 92.03899562358856, 85.35793572664261, 82.78869599103928, 86.9706679880619, 85.14014661312103, 86.75607070326805, 83.99799630045891, 78.64260166883469, 71.33994832634926, 67.54052460193634, 65.67573666572571, 59.63312990963459, 62.43981510400772, 57.69262343645096, 61.277966648340225, 58.527244850993156, 59.10668335855007, 58.52560713887215, 56.77566424012184, 60.69470174610615, 58.422788456082344, 58.039685413241386, 55.74592709541321, 56.04194261133671, 57.434567883610725, 53.15312102437019, 54.453711435198784, 53.6370250582695, 56.35659992694855, 49.89055149257183, 53.17589320242405, 54.14892219007015, 54.4713918864727, 61.382069662213326, 64.74037125706673, 61.488786935806274, 66.38654932379723, 58.914748057723045, 56.166769713163376, 55.355703234672546, 61.38132870197296, 57.25586727261543, 58.65615293383598, 50.39128862321377, 54.78188842535019, 54.63916428387165, 66.52713418006897, 54.88124169409275, 66.17601782083511, 56.4691498875618, 68.96737843751907, 52.068343833088875, 81.06255501508713, 21.399587206542492, 20.756564810872078, 82.61080473661423, 53.58389250934124, 70.9561613202095, 59.56306166946888, 68.70994225144386, 56.027928963303566, 63.12104254961014, 58.97840604186058, 68.25741693377495, 62.573754116892815, 65.58150932192802, 62.94464461505413, 63.528164103627205, 63.7321637570858, 65.17913371324539, 55.451271906495094, 55.93383461236954, 54.769520089030266, 60.63073217868805, 57.10424020886421, 62.31436863541603, 55.2287520468235, 53.918190971016884, 49.87956628203392, 54.62525703012943, 43.45941558480263, 50.01776486635208, 50.72738438844681, 55.87651088833809, 52.444956824183464, 49.38898980617523, 53.934879675507545, 54.67657707631588, 53.193999230861664, 55.12489601969719, 53.91898512840271, 56.87324680387974, 54.75842848420143, 56.524174734950066, 59.17742796242237, 53.55689495801926, 55.824233293533325, 58.865415304899216, 58.045772686600685, 62.33764998614788, 63.57707507908344, 65.28552040457726, 64.39351066946983, 68.43425184488297, 66.66870698332787, 64.12999480962753, 64.31237742304802, 75.30205652117729, 73.86816546320915, 77.66741439700127, 70.08163064718246, 18.465365655720234, 2.7157026389613748, 10.755474865436554, 6.064839838072658, 1.570820629131049, 0.3137097414582968, 0.9692585212178528, 59.85907718539238, 89.26867827773094, 64.42732885479927, 53.47710303962231, 45.86834192276001, 28.979602865874767, 26.81914709508419, 46.06903575360775, 73.33364814519882, 70.43910026550293, 75.47984138131142, 4.800577852874994, 0.29177583404816687, 0.14284818404121324, 0.1832487146020867, 0.13297891127876937, 0.17950615292647853, 0.30984635814093053, 0.32189245393965393, 0.14011212304467335, 0.10066908173030242, 0.1742347818799317, 0.10434575553517789, 0.22402889822842553], [0.046667273782077245, 0.08568932811613195, 0.09307006097515114, 0.05096804925415199, 0.07280298013938591, 0.0555071506096283, 0.304578504874371, 0.03560140663466882, 0.08087209949735552, 0.09530002178507857, 0.2822267386363819, 0.19518154382240027, 30.844050720334053, 79.39476370811462, 66.79725408554077, 53.699018731713295, 24.292677864432335, 21.583014763891697, 47.11500182747841, 32.99434393644333, 59.23082649707794, 69.57854524254799, 1.2645969609729946, 0.18427130504278466, 0.9048010362312198, 1.4174600271508098, 0.7484808086883277, 9.105736389756203, 72.84864977002144, 73.99113446474075, 84.63271424174309, 91.77857279777527, 82.56731227040291, 79.45542365312576, 79.50438782572746, 72.75075942277908, 69.8672841489315, 74.08938959240913, 75.55800318717957, 75.00694915652275, 74.39108580350876, 66.59166231751442, 64.63603645563126, 63.16687949001789, 57.9681770503521, 51.92980706691742, 49.97155174612999, 47.935377806425095, 53.785714879631996, 49.84239287674427, 53.03900554776192, 53.136470317840576, 54.48778800666332, 53.92891399562359, 53.593604788184166, 54.0395450592041, 51.06955602765083, 46.86204180121422, 49.386402145028114, 47.523365914821625, 50.49399331212044, 50.47836475074291, 50.33698953688145, 46.8886935710907, 46.56434677541256, 48.639366030693054, 48.81085082888603, 54.04237970709801, 59.64605301618576, 56.424213498830795, 61.553702652454376, 55.75237154960632, 53.094125390052795, 51.08377106487751, 56.33086010813713, 51.647972390055656, 58.64365540444851, 47.51244530081749, 55.180734023451805, 49.68766137957573, 58.086126521229744, 48.67903210222721, 64.77457702159882, 52.55347900092602, 63.85655388236046, 46.12882174551487, 75.99424257874489, 5.041986498981714, 3.866229127161205, 80.24065151810646, 46.4529899507761, 62.153166085481644, 49.25451882183552, 62.52754859626293, 52.52991646528244, 59.17197145521641, 53.05524207651615, 61.10571809113026, 57.9806137830019, 57.13379502296448, 51.50841727852821, 51.85153126716614, 51.89850814640522, 48.926824405789375, 44.1892272233963, 45.186130329966545, 43.78975085914135, 43.443783223629, 42.76374891400337, 47.53198765218258, 45.165147855877876, 45.379585549235344, 43.71001213788986, 45.37041664123535, 41.894758343696594, 42.5809521228075, 46.94618448615074, 46.81604906916618, 45.604529678821564, 43.45446065068245, 46.50871776044369, 50.11668875813484, 47.833049297332764, 47.087745890021324, 45.665011033415794, 49.267707914114, 47.53710977733135, 47.10631549358368, 49.96985323727131, 48.60239781439304, 50.84471069276333, 52.420261949300766, 55.244232416152954, 57.83404044806957, 63.29772546887398, 60.765590742230415, 61.73839174211025, 62.996340841054916, 62.55965307354927, 60.54996371269226, 61.37033969163895, 58.933887630701065, 66.45033270120621, 67.37286999821663, 70.92631012201309, 66.72376602888107, 16.995063051581383, 0.03879743591824081, 0.4544875561259687, 1.0102654458023608, 0.20405488408869132, 0.21821911388542503, 17.160361781716347, 70.72131112217903, 69.64466169476509, 40.80347590148449, 32.765288427472115, 32.92753592133522, 21.29891160875559, 24.65439945459366, 36.199411153793335, 55.640630945563316, 51.95628024637699, 19.780243299901485, 0.40523587551433593, 0.06357798061799258, 0.13427051540929824, 0.006119459376350278, 0.042066047244588844, 0.05581847042776644, 0.053149581217439845, 0.07573735041660257, 0.06340045889373869, 0.07305332139367238, 0.02961185742606176, 0.1184381009079516, 0.03966977114032488, 0.09476406499743462, 0.0357397132756887, 0.06055805926735047, 0.05972002611088101, 0.018647851902642287, 0.15005607070634142, 0.04253212711773813, 0.07336844471865334, 0.11307240289170295, 0.28282033803407103, 0.3062980610411614, 42.252113968133926, 90.03338724374771, 75.5347104370594, 61.97449587285519, 38.162598609924316, 29.624832943081856, 35.15187956392765, 40.481139197945595, 65.74130594730377, 76.69614851474762, 1.0354143963195384, 0.2189901311066933, 2.111793919466436, 3.493055901490152, 0.7603158080019057, 14.106254763901234, 76.69028162956238, 78.62470462918282, 88.7910059094429, 92.27163434028625, 86.00531458854675, 85.9292882680893, 82.91789665818214, 74.5461630821228, 75.64214587211609, 76.84830754995346, 78.21628734469414, 77.99743428826332, 76.25388264656067, 67.28708580136299, 67.55554139614105, 64.16483134031296, 62.07169085741043, 56.41320548951626, 53.950306847691536, 51.10589727759361, 56.05062514543533, 52.57982678711414, 57.803961262106895, 56.10963977873325, 57.61627413332462, 56.55366115272045, 56.25798001885414, 54.21957939863205, 53.24892148375511, 48.80409099161625, 53.888031989336014, 50.45656532049179, 53.85013282299042, 51.85886487364769, 53.37399557232857, 48.09969238936901, 48.77674765884876, 50.00416919589043, 50.8615779876709, 56.073093339800835, 61.952498853206635, 58.31181921064854, 63.20629857480526, 57.94119089841843, 55.199581012129784, 53.0706350505352, 57.85314202308655, 55.6419038772583, 59.18595090508461, 49.96597744524479, 58.44629019498825, 52.59070560336113, 59.24141272902489, 51.51387378573418, 66.38727888464928, 55.559106320142746, 66.33740276098251, 51.024334654212, 77.41067737340927, 12.418619971722364, 10.578601956367493, 82.64697879552841, 50.963157936930656, 66.3578912615776, 53.2782407104969, 65.31328931450844, 54.49135981500149, 60.82871675491333, 57.49776229262352, 61.35614365339279, 58.50762650370598, 58.233106434345245, 52.06085063517094, 53.71229141950607, 53.269033804535866, 50.796498879790306, 46.3325934112072, 47.54335664212704, 45.85577219724655, 45.99832534790039, 44.26592230796814, 50.14025129377842, 47.96911619603634, 47.991390600800514, 46.15511633455753, 48.33571292459965, 44.87911060452461, 43.84903147816658, 47.834937795996666, 49.35921460390091, 48.02538737654686, 43.54093261063099, 49.42908525466919, 50.70898197591305, 50.32163456082344, 49.44283291697502, 47.5649356842041, 53.142515793442726, 49.17299419641495, 50.29640771448612, 52.454441115260124, 51.20772421360016, 54.18885424733162, 56.541281417012215, 57.7838983386755, 61.020728051662445, 65.12169599533081, 62.966147661209106, 64.6944697201252, 64.7492703795433, 65.31202018260956, 63.93036872148514, 63.9011786878109, 61.20523475110531, 69.61056232452393, 71.59467905759811, 74.39546316862106, 71.97176322340965, 22.014251723885536, 1.153833142016083, 2.2234563902020454, 1.9558381754904985, 0.35800185694824904, 0.3666619781870395, 15.954994261264801, 75.49212232232094, 78.3629746735096, 50.452195554971695, 36.68676920235157, 23.36714442819357, 32.878241166472435, 37.03694321215153, 44.26092557609081, 62.20490410923958, 62.35454387962818, 28.04950587451458, 0.45468674856238067, 0.06253286599530838, 0.09920803786371835, 0.022820280355517752, 0.059402064071036875, 0.027585007592279, 0.04979283985449001, 0.04673306888435036, 0.01574762227392057, 0.09263903644750826, 0.032631821450195275, 0.023157736759458203, 0.18951052625197917, 0.20772968768142164, 0.18472486117389053, 0.16182248073164374, 0.19394644681597129, 0.10443309889524244, 0.6215005286503583, 0.20485003595240414, 0.1390063378494233, 0.2787295903544873, 0.4173937387531623, 0.3403119358699769, 52.45824471116066, 102.88730710744858, 83.41317728161812, 75.03246858716011, 38.85703794658184, 32.419871762394905, 65.71177393198013, 53.940263986587524, 75.30131936073303, 84.81360733509064, 1.7788918828591704, 0.20992001780541614, 4.193173320963979, 8.620182294398546, 5.92608030885458, 15.576105192303658, 82.24854737520218, 81.10642746090889, 91.71112641692162, 94.19404998421669, 89.59283888339996, 87.12911948561668, 89.13738012313843, 76.64233580231667, 75.83350360393524, 79.1290819644928, 82.40056201815605, 81.53885945677757, 80.17239958047867, 71.86584770679474, 72.34967574477196, 69.06043544411659, 65.46422481536865, 58.55743043124676, 57.67398163676262, 53.52792151272297, 61.458354368805885, 55.72666972875595, 59.738198071718216, 58.3314223587513, 63.08190084993839, 59.660059064626694, 57.93879322707653, 58.466102331876755, 57.987821996212006, 52.7542070299387, 56.849190294742584, 53.379619270563126, 55.15482321381569, 55.434267818927765, 55.52792899310589, 50.859697088599205, 51.03382654488087, 53.481320813298225, 52.83804573118687, 60.59275321662426, 65.2643783390522, 62.20944486558437, 66.81471034884453, 60.27011252939701, 58.761954456567764, 55.45920968055725, 62.54690855741501, 57.76644587516785, 63.40574607253075, 52.162730768322945, 63.03463138639927, 56.394689083099365, 66.6520182788372, 53.10395926237106, 71.41396075487137, 56.897649094462395, 71.94869846105576, 50.37205025553703, 87.54729464650154, 7.0431567169725895, 5.553577272221446, 90.30242800712585, 52.08242207765579, 73.03536415100098, 54.67053920030594, 72.88474023342133, 59.043675139546394, 64.8842391371727, 58.663984313607216, 65.38644298911095, 62.96119272708893, 63.57891038060188, 55.56507959961891, 57.45690308511257, 59.06492359936237, 54.89000402390957, 48.167860731482506, 50.69852113723755, 48.34937699139118, 49.30617704987526, 46.60463601350784, 53.189686462283134, 51.84761367738247, 51.07312023639679, 49.59726043045521, 50.38921773433685, 47.587586268782616, 49.125743731856346, 51.61835677921772, 51.9644346088171, 51.365522146224976, 47.07824259996414, 52.88303151726723, 54.74880740046501, 53.50639946758747, 51.682056561112404, 50.53861051797867, 59.19395327568054, 53.63948352634907, 53.29508900642395, 55.16461908817291, 53.81984084844589, 57.40414671599865, 59.139657989144325, 60.84756374359131, 65.01033917069435, 69.673220962286, 66.73669293522835, 67.75353357195854, 69.25752326846123, 68.640595972538, 68.46373826265335, 68.83935570716858, 65.19530564546585, 72.80884310603142, 75.0123904645443, 77.29029223322868, 73.51057425141335, 21.35225884616375, 4.229527870193124, 6.643871767446399, 4.230642160400748, 0.99288399098441, 0.38448245788458735, 22.546622157096863, 85.02217054367065, 83.04205119609833, 56.67412608861923, 50.46622820198536, 48.53092364966869, 31.42730802297592, 37.666189447045326, 55.89280441403389, 72.20172688364983, 74.73711803555489, 33.179093822836876, 0.6465231953188777, 0.1346260932041332, 0.2011983428383246, 0.10431590635562316, 0.1599051570519805, 0.13560305640567094, 0.20170240954030305, 0.18616620101965964, 0.14591518352972344, 0.13454003375954926, 0.13325102714588866, 0.20307389844674617], [0.017868177528725937, 0.03118441454716958, 0.027263485098956153, 0.03538113349350169, 0.04646786612283904, 0.039333247987087816, 0.06850616031442769, 0.02227017452241853, 0.09972021623980254, 0.02631145434861537, 0.10761349112726748, 1.1159923975355923, 55.99612087011337, 73.94673764705658, 66.62814795970917, 47.85191908478737, 22.108910344541073, 39.38778966665268, 72.40440040826797, 38.724717646837234, 79.72316488623619, 42.35592819750309, 0.06317261213553138, 0.080129246780416, 1.6400158661417663, 4.9914720095694065, 0.8327702013775706, 35.6744921207428, 79.38417747616768, 78.57187986373901, 87.70990312099457, 77.78102070093155, 81.72283038496971, 75.72441905736923, 79.49671223759651, 75.95099329948425, 80.08049011230469, 74.98158931732178, 73.95742267370224, 74.52094003558159, 72.77219787240028, 67.87013411521912, 64.70247209072113, 58.63857887685299, 57.66317881643772, 50.83676151931286, 52.11895331740379, 48.769984021782875, 54.05956618487835, 50.355467945337296, 53.10249254107475, 52.63994716107845, 51.91522724926472, 52.028221786022186, 51.30932696163654, 52.08312124013901, 50.514649003744125, 45.993492007255554, 48.71557094156742, 48.41202802956104, 50.43150186538696, 48.3641391992569, 48.61640006303787, 45.332756862044334, 46.27060353755951, 46.927854269742966, 48.76190945506096, 50.02423971891403, 54.21136423945427, 52.51980520784855, 55.922203436493874, 53.62863510847092, 55.06709352135658, 54.71279293298721, 57.97776013612747, 51.68760046362877, 56.69246390461922, 49.42891426384449, 57.53595024347305, 53.63788761198521, 62.49384440481663, 51.02077044546604, 63.09763200581074, 55.854065492749214, 62.534703612327576, 49.524334743618965, 66.71239703893661, 8.351290673017502, 4.903330514207482, 74.12344336509705, 46.72377482056618, 60.02912946045399, 52.29202263057232, 58.39715503156185, 52.64157347381115, 61.58606171607971, 53.30275699496269, 60.24551644921303, 56.31584331393242, 56.046502366662025, 49.37204271554947, 48.56349550187588, 46.456333771348, 47.21628159284592, 41.92696161568165, 49.44235034286976, 48.36986169219017, 48.037740513682365, 40.32523736357689, 42.81108297407627, 39.83447089791298, 42.137607112526894, 42.197875678539276, 43.355396166443825, 42.343670055270195, 42.61715658009052, 45.45761436223984, 46.3526601344347, 44.987606182694435, 41.03649079799652, 44.102398082613945, 48.81891019642353, 47.84175083041191, 45.78012205660343, 45.36267265677452, 49.964704513549805, 48.94504822790623, 46.73380248248577, 48.4646438062191, 52.81852997839451, 53.784084767103195, 53.55686075985432, 59.09190595149994, 61.78994357585907, 63.25467377901077, 64.889125674963, 62.08126254379749, 64.77019965648651, 64.05076146125793, 63.859586119651794, 61.863823011517525, 61.40080265700817, 64.61253091692924, 67.5687874853611, 69.24016579985619, 69.61734876036644, 55.99060736596584, 4.525347221642733, 1.3329279818572104, 1.6366917570121586, 0.2004535382729955, 0.03421166089538019, 1.1639719479717314, 50.958757773041725, 68.58448058366776, 64.18846607208252, 40.22057957947254, 45.33844135701656, 15.77562678605318, 13.558096177875996, 30.828857235610485, 45.190735682845116, 54.941396266222, 50.47105394303799, 2.202060450799763, 0.17404863639967516, 0.1141216883843299, 0.09008952911244705, 0.057521142734913155, 0.00755951020437351, 0.04789808859641198, 0.032921800811891444, 0.09236773694283329, 0.09495563557720743, 0.05644786360790022, 0.017458283800806385, 0.06458202478825115, 0.06851701793493703, 0.05952077801339328, 0.055440049327444285, 0.16910588834434748, 0.06052575357898604, 0.07559305464383215, 0.044677668629447, 0.057661776008899324, 0.0945019161736127, 0.08688440109835938, 1.5445552510209382, 68.23129713535309, 79.51027750968933, 76.14703997969627, 56.33749075233936, 33.84038753807545, 33.811752274632454, 49.10971239209175, 46.55154526233673, 87.92118698358536, 45.09420946240425, 0.0925769038440194, 0.43286181811708957, 3.8106725458055735, 5.160083211958408, 1.0719807841815054, 38.841941356658936, 81.63086012005806, 81.48139894008636, 86.85812562704086, 82.92553424835205, 83.71694058179855, 81.55156597495079, 81.30258053541183, 80.7510781288147, 82.20101952552795, 79.54536482691765, 77.0318453013897, 77.56236523389816, 73.69794979691505, 69.43922191858292, 66.90740257501602, 60.49381032586098, 61.49914138019085, 53.45685012638569, 55.25924161076546, 51.27324029803276, 56.21136412024498, 53.747473731637, 56.44980892539024, 55.42138651013374, 53.349992260336876, 55.54438591003418, 52.90720961987972, 55.95912605524063, 52.14800275862217, 49.54315513372421, 52.2235769033432, 51.15282095968723, 52.60468125343323, 50.4091552644968, 50.51124818623066, 46.55214183032513, 48.767806738615036, 49.90009658038616, 50.752748027443886, 52.87548132240772, 56.83270677924156, 56.50643348693848, 57.07167595624924, 56.70883722603321, 59.015883430838585, 56.18973568081856, 60.23464523255825, 54.745182394981384, 58.82461689412594, 53.30121047794819, 58.52807700634003, 58.20257507264614, 64.19491052627563, 55.63510984182358, 66.18848875164986, 60.05424231290817, 66.59650325775146, 52.308384552598, 69.42876487970352, 12.813776917755604, 10.211804788559675, 76.25788003206253, 50.98099038004875, 64.0139490365982, 56.13248035311699, 61.1096128821373, 54.70393180847168, 65.40125459432602, 56.405347511172295, 61.912608593702316, 57.334640845656395, 56.23250998556614, 52.15899936854839, 50.51382064819336, 49.31293308734894, 48.52140516042709, 45.54893486201763, 51.66728675365448, 50.31007558107376, 50.60388341546059, 43.97325061261654, 45.749229714274406, 42.11078055202961, 45.58968007564545, 44.83434900641441, 46.912461295723915, 45.694698840379715, 45.24221532046795, 46.7761018127203, 48.105304688215256, 46.348514556884766, 42.98485524952412, 47.13604889810085, 50.61664693057537, 51.129095032811165, 48.927185386419296, 49.763710498809814, 53.364689871668816, 50.1018163561821, 49.5217052847147, 50.83944037556648, 55.258322060108185, 58.200485184788704, 58.44543904066086, 59.98766988515854, 63.93331736326218, 65.79771012067795, 68.50325614213943, 65.60865506529808, 68.61170992255211, 66.7510637640953, 65.74464976787567, 62.847955003380775, 64.06276121735573, 67.74838104844093, 70.18316879868507, 71.55113339424133, 71.52359247207642, 62.54215881228447, 7.9436110239475965, 0.8016257069539279, 1.384056257084012, 0.8813716715667397, 0.04577225110551808, 0.6354358652606606, 54.59446728229523, 75.61189949512482, 70.12810215353966, 46.50524474680424, 36.04805767536163, 16.068068593740463, 22.205440364778042, 39.69111979007721, 52.31602594256401, 63.47201071679592, 61.743924245238304, 3.644820707850158, 0.24280272598844022, 0.03180647901899647, 0.17424984747776762, 0.02498100064258324, 0.03643180309154559, 0.08475815542624332, 0.015985304344212636, 0.06929145645699464, 0.11574089876376092, 0.014607357825298095, 0.017453417167416774, 0.18728714087046683, 0.13958784023998305, 0.2629900333704427, 0.09196732600685209, 0.27181399113032967, 0.14458102465141565, 0.18037364934571087, 0.09836106182774529, 0.16619132598862052, 0.24473046942148358, 0.2740417403401807, 2.031667619012296, 82.65557393431664, 91.4206700026989, 87.03732401132584, 64.72385734319687, 34.98566888272762, 55.185468569397926, 98.7154121696949, 56.29877083003521, 95.74184373021126, 50.86891159415245, 0.1302846331964247, 0.5150289949961007, 4.715907946228981, 12.009554821997881, 2.643606257624924, 41.79313279688358, 88.02434384822845, 77.2557444870472, 91.56930282711983, 84.87100705504417, 87.01837822794914, 84.48849678039551, 87.10268810391426, 80.47870874404907, 83.90576764941216, 82.83798694610596, 79.69546437263489, 80.05842089653015, 79.7115071117878, 73.52990001440048, 69.82968136668205, 64.14429724216461, 65.90025901794434, 56.5493293851614, 60.09584628045559, 54.25441972911358, 61.42898954451084, 56.82308569550514, 59.43362921476364, 58.09428088366985, 56.29239857196808, 57.724169343709946, 54.56676296889782, 57.529881969094276, 56.424186900258064, 50.70536457002163, 55.87869197130203, 53.52762892842293, 54.86292287707329, 53.41204673051834, 54.912331625819206, 49.34997729957104, 50.87038591504097, 50.1324313133955, 54.661685675382614, 55.897816345095634, 60.41662886738777, 56.6424585878849, 61.294944137334824, 58.06248039007187, 58.71364764869213, 58.864385560154915, 63.54880839586258, 54.59301955997944, 61.384752318263054, 54.666291028261185, 64.55811023712158, 59.138130471110344, 68.66708055138588, 55.4042874276638, 68.93532335758209, 64.1387951374054, 71.95087194442749, 51.04874834418297, 80.67328110337257, 9.32693487033248, 6.465617157518864, 87.64178037643433, 51.85050152242184, 67.54464358091354, 59.06565696001053, 66.6081154346466, 57.17276573181152, 68.8765861093998, 55.86272902786732, 65.39067596197128, 61.09653778374195, 59.95618097484112, 54.35388319194317, 54.828850105404854, 54.548983722925186, 52.077923119068146, 46.019140630960464, 55.30396141111851, 52.142090275883675, 55.353704541921616, 44.816797748208046, 48.16898927092552, 45.13852268457413, 47.11633175611496, 45.69618456065655, 51.20368503034115, 47.844129502773285, 49.27752658724785, 49.74259503185749, 50.70680849254131, 48.53571519255638, 44.61937554180622, 51.69007793068886, 53.83260056376457, 53.250570595264435, 52.29708015918732, 50.99100664258003, 58.13138209283352, 52.760146111249924, 51.36255070567131, 54.39368225634098, 58.76451171934605, 59.7138337790966, 60.14467366039753, 64.245645403862, 66.35776966810226, 69.97348845005035, 72.46059939265251, 69.82137501239777, 72.07465410232544, 69.45993840694427, 68.51493671536446, 67.34932646155357, 69.73318934440613, 75.35416692495346, 76.06640070676804, 74.7377260029316, 75.16001254320145, 65.04275143146515, 7.252254746854305, 6.337393037974834, 7.729940414428711, 1.670539272017777, 0.14521183533361182, 1.5264783147722483, 65.44766530394554, 80.51079422235489, 77.87528604269028, 57.2493202239275, 60.497093349695206, 22.3184671998024, 23.7124926969409, 46.24827213585377, 64.3618431687355, 70.15273243188858, 73.66238370537758, 5.159070091322064, 0.3974246821599081, 0.2519905142253265, 0.14731241011759266, 0.13912189024267718, 0.08204803249100223, 0.17798360728193074, 0.14330288307974115, 0.21956001146463677, 0.2974254480795935, 0.11236080943490379, 0.15261732623912394], [0.050489200730226, 0.08896770610590465, 0.013453709671011893, 0.05782479245681316, 0.06289418059168383, 0.047558481819578446, 0.05007916784961708, 0.02473435157298809, 0.12007587240077555, 0.1180659509554971, 0.2691069629509002, 8.392133731395006, 78.27059403061867, 70.33081367611885, 73.07233616709709, 30.737000964581966, 19.21661004424095, 50.136405900120735, 54.12477068603039, 43.85086677968502, 96.78206071257591, 16.180388666689396, 0.022320776006381493, 0.38284394424408674, 0.8599735354073346, 8.388702515512705, 4.808487603440881, 56.47897616028786, 75.56707710027695, 91.85426473617554, 73.65495130419731, 79.71226707100868, 80.75222566723824, 80.96385151147842, 77.6029546558857, 78.39673966169357, 75.92235803604126, 74.30338650941849, 72.98940181732178, 71.7809222638607, 66.51682153344154, 59.727391451597214, 57.27244958281517, 54.64130736887455, 52.912863716483116, 53.19921255111694, 50.52707813680172, 51.46196857094765, 52.32283137738705, 50.557772889733315, 52.273437827825546, 53.69332283735275, 51.71284630894661, 53.19529876112938, 51.08220174908638, 53.5194555670023, 48.96686665713787, 47.60641045868397, 48.1140024214983, 47.17158459126949, 49.372544288635254, 46.874463334679604, 48.47824327647686, 44.723961129784584, 46.86684854328632, 47.75927245616913, 48.35272841155529, 51.38730637729168, 52.13083527982235, 51.127825900912285, 49.439344704151154, 56.21711701154709, 57.70477898418903, 56.61972060799599, 58.371407613158226, 51.007721945643425, 54.54214408993721, 52.82018668949604, 59.639718756079674, 62.65936352312565, 61.17047421634197, 58.33060160279274, 59.22342449426651, 61.0383553057909, 63.680836111307144, 56.11391834914684, 50.208719819784164, 7.393321702256799, 7.447787504643202, 60.977809354662895, 51.84718430042267, 58.570334538817406, 49.83518846333027, 53.232810348272324, 56.454980447888374, 61.20736263692379, 52.11515732109547, 56.54036946594715, 55.84275349974632, 55.323116183280945, 49.94026802480221, 49.28933635354042, 46.58012352883816, 49.69361186027527, 49.94665548205376, 57.57371261715889, 59.01530586183071, 55.224826857447624, 48.655085787177086, 43.415455743670464, 41.27712808549404, 40.69649264216423, 39.56508055329323, 41.95145510137081, 43.56835573911667, 43.459901958703995, 43.52321036159992, 49.142044857144356, 44.396414905786514, 44.06517527997494, 41.948628053069115, 48.28728072345257, 46.85297168791294, 47.09898188710213, 46.65446653962135, 49.83113408088684, 48.970138281583786, 52.35629238188267, 52.844801768660545, 58.0942352861166, 57.00551010668278, 62.01733477413654, 58.6676587164402, 64.61520597338676, 61.26228488981724, 64.19894590973854, 61.180946454405785, 64.03121531009674, 62.349908128380775, 60.04298351705074, 59.99719597399235, 61.42115816473961, 60.83795785903931, 63.59219066798687, 64.3951977789402, 71.62217438220978, 73.34328442811966, 35.546967163681984, 0.915412976173684, 0.6113060913048685, 0.6332411267794669, 0.24397300381679088, 0.4204135376494378, 16.610071510076523, 72.74990826845169, 61.158136278390884, 53.075122609734535, 57.965346202254295, 43.99447247385979, 23.324976190924644, 15.469645354896784, 43.567470386624336, 49.03989113867283, 61.00941225886345, 16.587109342217445, 0.430215586675331, 0.050552676621009596, 0.06622905828407966, 0.034352642978774384, 0.02921691797382664, 0.06265048898058012, 0.04732068286102731, 0.12166835062089376, 0.14342101814690977, 0.03998910615337081, 0.059530511280172504, 0.054143138841027394, 0.06006760355376173, 0.06761952390661463, 0.08153961680363864, 0.08186101869796403, 0.07998319211765192, 0.10807829079567455, 0.028864421947218943, 0.012014445983368205, 0.09522749911411665, 0.23475597496144474, 11.985883042216301, 91.7485848069191, 75.18721148371696, 80.12258425354958, 40.18917426466942, 30.81286959350109, 39.81328323483467, 53.13964694738388, 51.06391333043575, 105.70828333497047, 17.055082730948925, 0.012010998707410181, 0.8901243237778544, 4.743095487356186, 11.249347664415836, 5.253304559737444, 61.35536469519138, 77.45955035090446, 89.79202419519424, 74.79802116751671, 82.73080229759216, 81.91320016980171, 85.52837938070297, 80.69633066654205, 80.79773962497711, 78.74709606170654, 78.0043575167656, 75.0343456864357, 72.57589280605316, 69.9280808866024, 62.51934863626957, 61.26252807676792, 58.96029241383076, 57.13452458381653, 56.4524269849062, 52.756323516368866, 54.32829536497593, 53.427880480885506, 52.88951016962528, 56.062674298882484, 56.49183847010136, 54.33664731681347, 55.29893048107624, 54.6132230758667, 55.612322464585304, 51.61982350051403, 50.03167971968651, 51.70954808592796, 49.89424109458923, 50.25935970246792, 48.28347712755203, 51.54435195028782, 47.310436740517616, 50.10334387421608, 50.52565321326256, 49.96832191944122, 53.53124253451824, 53.52598361670971, 53.4597759693861, 54.33059424161911, 59.393852949142456, 60.01177579164505, 57.20825582742691, 59.93797615170479, 54.386998414993286, 55.32626621425152, 54.7434800863266, 64.0349543094635, 65.5517341196537, 65.81673949956894, 58.60747754573822, 61.81677773594856, 62.7154029160738, 67.0940713584423, 58.4391275793314, 53.43809433281422, 10.068146847188473, 11.467965133488178, 61.14659249782562, 57.39948816597462, 62.085902094841, 53.36269497871399, 55.98952442407608, 58.73324699699879, 63.64337012171745, 54.115704372525215, 58.65343987941742, 58.00525926053524, 58.86042237281799, 54.359153509140015, 51.88332036137581, 48.9875565469265, 50.84472969174385, 52.159044966101646, 60.88684223592281, 61.424859166145325, 59.78748142719269, 50.53588606417179, 45.92419132590294, 44.23155315220356, 43.78872111439705, 43.406264036893845, 44.528678208589554, 45.071232095360756, 46.78589768707752, 46.75798058509827, 51.84425845742226, 45.95756493508816, 46.73920199275017, 45.58661364018917, 48.533309921622276, 49.16033707559109, 50.00288486480713, 50.48959694802761, 52.641577273607254, 51.893032640218735, 54.72639620304108, 55.14131113886833, 59.53526996076107, 58.551536947488785, 63.67081604897976, 60.90562462806702, 66.29915401339531, 65.2291390299797, 68.04139092564583, 64.14270892739296, 67.71721512079239, 64.88721817731857, 64.31455850601196, 61.478538885712624, 63.749840408563614, 63.676147162914276, 67.82723441720009, 68.76687079668045, 75.0661651790142, 76.53224810957909, 41.58162474632263, 1.525190540123731, 0.6646546942647547, 1.3892455911263824, 0.29486391053069383, 0.3974307083990425, 15.532053206115961, 77.12864890694618, 69.33155849575996, 61.08194276690483, 53.98255571722984, 36.24324560165405, 29.174976982176304, 24.514173679053783, 51.797403171658516, 55.875408947467804, 69.51438948512077, 24.26813878118992, 0.43345126148778945, 0.0773733555979561, 0.08085367939202115, 0.003048638754989952, 0.024586530598753598, 0.04261318448698148, 0.016370833363907877, 0.04377441553515382, 0.09087850630749017, 0.010828463382495102, 0.011626363047980703, 0.13400669675320387, 0.1956850168062374, 0.26568732457235456, 0.2796416007913649, 0.16363585920771584, 0.16116857441375032, 0.15039248624816537, 0.1849964278517291, 0.2112815619329922, 0.36764351301826537, 0.5666507687419653, 15.561076998710632, 108.21599677205086, 84.8435041308403, 92.43051141500473, 46.10827624797821, 29.83910344541073, 64.62332993745804, 76.04145884513855, 57.99061104655266, 115.38770154118538, 20.886276550590992, 0.12303433279157616, 1.2915518833324313, 8.986342046409845, 11.508301869034767, 5.820732861757278, 66.55719816684723, 78.22061151266098, 94.05586659908295, 78.22658479213715, 84.97876167297363, 85.81666991114616, 88.91283497214317, 84.29783821105957, 83.01692694425583, 82.71504074335098, 82.44868263602257, 77.34251663088799, 78.75465005636215, 74.10774260759354, 65.19436329603195, 64.11394447088242, 62.00261436402798, 59.511357843875885, 58.66553083062172, 57.000954151153564, 57.42521658539772, 57.59415552020073, 57.176626324653625, 57.74029567837715, 58.70338439941406, 58.57022054493427, 56.56796358525753, 58.46910037100315, 60.120058581233025, 55.50867162644863, 53.4313078969717, 55.37436783313751, 51.30883678793907, 54.28528547286987, 50.3094258159399, 54.43027049303055, 48.57671499252319, 52.211121171712875, 52.488700076937675, 53.46702218055725, 57.099182680249214, 58.02618473768234, 57.122627422213554, 57.094759717583656, 61.192163452506065, 63.12390759587288, 60.16493797302246, 64.01689767837524, 56.702700555324554, 59.50966693460941, 57.351268753409386, 68.87038484215736, 69.34131637215614, 68.76625522971153, 60.34077733755112, 67.51429840922356, 66.23606219887733, 70.91684862971306, 56.97801098227501, 61.09698995947838, 8.342650886625051, 9.359385129064322, 71.03654980659485, 57.82794177532196, 67.07223013043404, 57.8423848003149, 60.673647075891495, 61.72173723578453, 66.69183254241943, 54.88186866044998, 61.903166100382805, 60.01964136958122, 60.356664285063744, 56.43320381641388, 55.69633215665817, 51.947065740823746, 54.18760411441326, 53.82798381149769, 63.551703840494156, 64.62456107139587, 62.89224922657013, 53.5682525485754, 49.65690962970257, 46.97747200727463, 45.088296979665756, 45.67595064640045, 47.46302515268326, 46.87698259949684, 49.149804040789604, 48.88787269592285, 54.78025831282139, 50.42465463280678, 49.53365184366703, 48.19951303303242, 53.15565548837185, 51.98365397751331, 49.393450766801834, 52.368569523096085, 55.86198806762695, 54.99205134809017, 57.46402010321617, 59.559258073568344, 62.6471471786499, 62.422693222761154, 67.86910817027092, 63.07474583387375, 69.92142364382744, 69.95051488280296, 71.80821239948273, 69.14539128541946, 70.55571600794792, 69.90387618541718, 67.35664486885071, 65.66661715507507, 67.9700231552124, 66.59499853849411, 70.908732265234, 72.68893674015999, 78.3303040266037, 79.30046036839485, 41.763103008270264, 2.1061744960024953, 4.046350149437785, 3.3620892791077495, 0.7765785790979862, 0.6574088393244892, 22.13654436171055, 85.9018537402153, 73.50128754973412, 70.33405870199203, 75.48611864447594, 59.059497490525246, 35.65435320138931, 27.555213198065758, 62.131248861551285, 63.802193999290466, 78.52157056331635, 32.13882364332676, 0.8035508380271494, 0.10961548643535934, 0.14013833570061252, 0.2000788427540101, 0.1581672698375769, 0.13280118175316602, 0.19453007174888626, 0.25349754898343235, 0.3425587434321642, 0.12989288312382996, 0.09369166902615689], [0.025966257344407495, 0.030624781393271405, 0.03604057623306289, 0.07666220000828616, 0.08463334102998488, 0.01375832975099911, 0.027209788859181572, 0.009426849774172297, 0.11680949493893422, 0.06884450544021092, 0.05858700780663639, 31.59959837794304, 76.73466324806213, 59.983995482325554, 65.17213448882103, 25.195568315684795, 38.425099924206734, 41.78016409277916, 38.59730288386345, 65.70662140846252, 76.73454165458679, 3.1793117243796587, 0.12657260347623378, 1.3358286512084305, 8.09805991128087, 17.08669513463974, 15.484911035746336, 71.5194582939148, 78.36024641990662, 60.94014957547188, 72.54536524415016, 85.66915422677994, 76.06103539466858, 78.21201637387276, 71.41440913081169, 78.94564300775528, 74.0115849673748, 78.84679511189461, 67.72069573402405, 64.10176232457161, 56.50840938091278, 55.89885748922825, 51.57624363899231, 52.769846990704536, 49.921994805336, 49.91625711321831, 53.36217440664768, 54.44862350821495, 51.533792316913605, 52.478007450699806, 52.597476840019226, 52.90473215281963, 52.366099655628204, 51.82962164282799, 50.69490373134613, 49.11805294454098, 49.11360718309879, 50.25334842503071, 49.915364161133766, 48.037584722042084, 45.21780543029308, 48.45554329454899, 47.44947887957096, 44.644796177744865, 45.65608151257038, 47.678276002407074, 50.12208066880703, 54.87415887415409, 49.405978694558144, 51.024881824851036, 53.26024487614632, 58.59252154827118, 58.09960059821606, 59.08444695174694, 56.88070960342884, 55.249027758836746, 56.18516832590103, 59.421215280890465, 59.577250108122826, 61.20383642613888, 63.446966260671616, 58.47112186253071, 59.41600576043129, 64.57815036177635, 58.55717584490776, 58.67265924811363, 36.188418343663216, 13.604561034590006, 17.698481306433678, 52.140254974365234, 55.64325660467148, 55.007660910487175, 52.928401082754135, 49.09249551594257, 55.816428512334824, 61.128904446959496, 58.20780739188194, 56.30008555948734, 56.140494123101234, 55.8097180724144, 52.51125566661358, 50.504340156912804, 47.68136903643608, 55.04130430519581, 56.064767986536026, 59.834667295217514, 52.880481854081154, 55.90225450694561, 54.00303661823273, 44.23492357134819, 41.56034208834171, 41.45832896232605, 41.522347927093506, 42.013946548104286, 44.20593872666359, 43.33482787013054, 42.295967414975166, 47.06273563206196, 43.987412452697754, 45.371089205145836, 42.126785293221474, 45.63514843583107, 49.309577867388725, 44.96260732412338, 48.13304699957371, 48.489334881305695, 51.6661886125803, 52.60104864835739, 61.783464923501015, 61.80683746933937, 58.12081106007099, 62.3862873762846, 62.178978100419044, 62.220962047576904, 61.71139799058437, 65.33844396471977, 64.50593903660774, 66.40037298202515, 62.90134213864803, 63.153249621391296, 60.12611925601959, 62.49594569206238, 60.54283529520035, 65.26687100529671, 65.53928598761559, 69.35951739549637, 73.47291067242622, 67.23044604063034, 10.30861884355545, 0.454930262058042, 0.40034161938820034, 0.3160885919351131, 0.012388183204166126, 1.7613471555523574, 53.586236983537674, 70.0182956457138, 60.79804100096226, 43.10834862291813, 41.96716345846653, 18.626974783837795, 20.876493975520134, 29.454161301255226, 50.857459008693695, 54.60393637418747, 50.40344797074795, 1.6346562537364662, 0.061695114854956046, 0.05464212554215919, 0.02470669543981785, 0.04629048169590533, 0.02700036591704702, 0.11221955646760762, 0.03050487815926317, 0.02855001850548433, 0.052450993898673914, 0.08132435687002726, 0.035371715639485046, 0.04953025316353887, 0.06852850638097152, 0.08589118486270308, 0.02198610636696685, 0.013932522942923242, 0.044700753132929094, 0.05482530243170913, 0.05193787670577876, 0.02678217821085127, 0.005757279250246938, 39.32347431778908, 89.60670813918114, 67.83805623650551, 77.2500903904438, 34.06189285218716, 30.53778525441885, 34.177733436226845, 46.773525550961494, 73.29318791627884, 82.54430830478668, 2.7452223049476743, 0.1462223584530875, 2.7719206223264337, 11.288107484579086, 18.562190160155296, 17.212584279477596, 74.09906387329102, 80.36615878343582, 63.739721551537514, 72.43147015571594, 88.43366548418999, 77.78712317347527, 81.58916875720024, 76.3455793261528, 83.04180800914764, 77.82421678304672, 81.30027785897255, 71.46524280309677, 67.56641641259193, 60.999426394701004, 57.752724811434746, 54.92224529385567, 55.55892392992973, 52.04741835594177, 55.543823540210724, 53.8724984228611, 55.72580337524414, 53.296190947294235, 54.60014797747135, 55.52014321088791, 54.63102512061596, 55.41675075888634, 53.15350100398064, 53.70740868151188, 51.55166655778885, 49.452887177467346, 51.72220520675182, 54.55371826887131, 50.56652382016182, 48.27532276511192, 50.42916879057884, 49.55202005803585, 47.521887794137, 47.94942945241928, 51.031440272927284, 52.334466353058815, 55.463362857699394, 52.68376260995865, 53.08494508266449, 56.35872021317482, 61.592718958854675, 60.97025156021118, 60.932618379592896, 58.33432920277119, 55.809106305241585, 59.18776720762253, 62.38494984805584, 62.58456453680992, 64.98678043484688, 68.34054887294769, 60.544161424040794, 61.19889289140701, 65.23106172680855, 62.41772688925266, 58.90295349061489, 39.97307226061821, 17.362716123461723, 22.418122552335262, 54.80315588414669, 58.7406338006258, 57.922495901584625, 55.26933006942272, 53.461820259690285, 57.80615754425526, 63.65932546555996, 60.594755709171295, 58.66021491587162, 61.01684086024761, 58.77907633781433, 55.57363674044609, 54.98805396258831, 51.586290299892426, 57.429498955607414, 59.04530145227909, 61.40460625290871, 55.77684223651886, 58.35778534412384, 58.18265274167061, 47.73888275027275, 44.04666647315025, 44.43200379610062, 43.88111315667629, 42.04754814505577, 44.51874554157257, 45.79287797212601, 45.24226471781731, 48.024878203868866, 47.14175999164581, 48.1023408472538, 45.38264438509941, 48.31683173775673, 50.18032394349575, 47.06346519291401, 50.68616420030594, 51.29393398761749, 54.52092222869396, 55.70495389401913, 64.32286486029625, 66.73842564225197, 60.50448015332222, 65.35273879766464, 65.87532475590706, 63.93487527966499, 64.59985479712486, 68.47485646605492, 66.82638332247734, 68.30695867538452, 65.90819299221039, 65.49159854650497, 63.544089049100876, 66.31091058254242, 64.11395207047462, 68.21522399783134, 69.63640093803406, 70.72424456477165, 72.38822847604752, 71.84209898114204, 14.238792601972818, 0.1053097311523743, 2.0507055474445224, 1.2931784335523844, 0.10232299493509345, 1.5327674522995949, 57.26084120571613, 75.50146982073784, 67.96816125512123, 49.739889577031136, 34.92741420865059, 23.347434885799885, 29.771288484334946, 35.89867629110813, 57.21462808549404, 60.634406581521034, 61.29345081746578, 3.3021667320281267, 0.10829630409716628, 0.025434081799176056, 0.06183202625834383, 0.04002520421636291, 0.04954357471433468, 0.04164754645898938, 0.023756221344228834, 0.03231384456739761, 0.034157625123043545, 0.017763701689545996, 0.09703284755232744, 0.13360335433389992, 0.1835310721071437, 0.2140322283958085, 0.24896829592762515, 0.09671148276538588, 0.09117660476476885, 0.18610345985507593, 0.20788662222912535, 0.19441159529378638, 0.11038686730898917, 50.03422938287258, 97.71831527352333, 76.7666195333004, 84.95256587862968, 39.211585521698, 51.88710875809193, 58.76019895076752, 58.419984206557274, 80.35050362348557, 91.75198182463646, 3.8259372767060995, 0.31913089274894446, 3.251677416265011, 16.473512537777424, 21.52151506394148, 17.26670667529106, 78.15049767494202, 81.76523610949516, 73.57880339026451, 72.33862593770027, 89.57266956567764, 81.92328482866287, 84.17398765683174, 77.61898219585419, 86.11296281218529, 80.63834577798843, 84.94295999407768, 73.83976578712463, 71.44479990005493, 64.32521313428879, 61.077633798122406, 57.21664197742939, 59.08586807549, 55.36942049860954, 56.184115782380104, 57.12723657488823, 60.58174900710583, 55.97588315606117, 57.193630412220955, 58.23793217539787, 57.67072141170502, 57.86284290254116, 56.73159420490265, 55.2591048181057, 55.140782967209816, 51.90376706421375, 55.39354920387268, 59.145479276776314, 52.2367811948061, 51.98325879871845, 53.45841944217682, 53.441704139113426, 49.99887987971306, 52.0313224196434, 52.798178270459175, 53.055116683244705, 58.05639311671257, 53.238487243652344, 55.619526877999306, 59.44217495620251, 64.58062782883644, 64.06254082918167, 62.80243344604969, 61.31191022694111, 60.19898034632206, 61.844683438539505, 65.50627335906029, 65.55692464113235, 65.68801000714302, 69.78398501873016, 65.13384014368057, 64.80651810765266, 66.93766415119171, 65.31185299158096, 60.04136100411415, 43.12241926789284, 14.791637286543846, 21.30377534776926, 60.915314108133316, 63.37736539542675, 60.997385904192924, 57.43807889521122, 54.99219574034214, 59.9336101859808, 67.73006603121758, 64.86736804246902, 62.203118205070496, 63.28289866447449, 64.98168110847473, 58.89964006841183, 57.93163821101189, 53.62208805978298, 60.778289660811424, 61.73999525606632, 65.41339114308357, 58.998415768146515, 60.1103463023901, 60.7170445472002, 51.23439118266106, 45.659060552716255, 47.71313913166523, 46.143599152565, 45.607592314481735, 48.74829858541489, 48.908524587750435, 46.208617463707924, 51.30360446870327, 49.08118352293968, 52.463085651397705, 48.28959859907627, 50.93023270368576, 53.68530906736851, 50.72500951588154, 54.07627768814564, 53.786915615200996, 58.18400926887989, 58.21869380772114, 65.92991262674332, 66.8685382604599, 64.33805644512177, 69.44567397236824, 69.05491814017296, 66.82157278060913, 68.08975473046303, 72.62118637561798, 70.29000386595726, 70.7194796204567, 69.08358380198479, 68.97911220788956, 67.19933331012726, 70.41994169354439, 67.09698960185051, 71.77326187491417, 74.96923997998238, 76.30869850516319, 77.49007791280746, 74.67167794704437, 13.672182206064463, 2.0049047050997615, 4.126140167936683, 1.362881655804813, 0.22519626683788374, 2.58760676253587, 69.41466003656387, 81.98267564177513, 75.19680976867676, 61.08429104089737, 57.93126203119755, 27.64869388192892, 32.646024227142334, 43.70005667209625, 67.33196899294853, 70.89176997542381, 73.4084053337574, 4.151154225692153, 0.5609621771145612, 0.13541668828111142, 0.13370062020840123, 0.12370004667900503, 0.11477573571028188, 0.19978141965111718, 0.26996901200618595, 0.24047977407462895, 0.1394085373613052, 0.14826465980149806], [0.03559730997949373, 0.09072562388610095, 0.029387608228717, 0.022527994769916404, 0.04831537968129851, 0.016789382389106322, 0.02870750038709957, 0.05874215748917777, 0.05963640833215322, 0.11371684682671912, 0.8463597565423697, 59.85381066799164, 71.57377257943153, 60.344204753637314, 32.87713922560215, 45.822151601314545, 112.73617342114449, 46.72651827335358, 42.322831973433495, 80.47494694590569, 53.09631787240505, 0.06260492853471078, 0.07663785756449215, 0.43527923058718443, 1.0765411332249641, 1.75846750382334, 31.577873043715954, 77.75309979915619, 78.76940846443176, 71.5621680021286, 76.40704482793808, 82.58751958608627, 78.03433790802956, 77.84334495663643, 77.40247741341591, 78.52018743753433, 73.73253554105759, 69.09569755196571, 64.41891610622406, 57.864389419555664, 52.96149730682373, 51.48488134145737, 53.284802958369255, 56.31051979959011, 56.138677820563316, 55.47429107129574, 51.53487525880337, 52.19714932143688, 54.19037036597729, 53.031964525580406, 51.137351989746094, 53.542402535676956, 52.083178237080574, 51.22890047729015, 50.089706405997276, 49.791236221790314, 49.00490641593933, 46.86052568256855, 49.99099150300026, 48.86472053825855, 46.23127184808254, 48.43328408896923, 44.04710344970226, 45.729402378201485, 44.125987216830254, 50.29833801090717, 59.294792264699936, 61.45308405160904, 58.80860075354576, 55.110768377780914, 57.68053628504276, 60.10198675096035, 58.6040311306715, 56.981335803866386, 56.38620413839817, 58.494623601436615, 59.38603296875954, 60.28169430792332, 61.39916114509106, 64.03559267520905, 56.624960526824, 56.94285906851292, 62.88299672305584, 62.060006484389305, 58.16399194300175, 58.58147174119949, 33.613923490047455, 30.991896986961365, 24.126586876809597, 38.05117338895798, 63.54585975408554, 50.359282940626144, 54.60348799824715, 53.5213478654623, 54.74084682762623, 52.63791427016258, 55.744141191244125, 55.789503157138824, 58.515701070427895, 57.19795078039169, 56.08406335115433, 52.57477305829525, 53.7079406529665, 54.50063891708851, 61.87212556600571, 47.674236819148064, 39.301348105072975, 62.781762555241585, 56.42379552125931, 48.8613311201334, 43.47264267504215, 43.16713146865368, 38.45543749630451, 41.568602845072746, 42.97151796519756, 43.24880428612232, 42.57249757647514, 44.14427563548088, 45.72312891483307, 44.284028336405754, 42.75411643087864, 44.829625859856606, 50.40894627571106, 46.9878264516592, 49.123152270913124, 47.648204416036606, 51.97510443627834, 56.598521545529366, 64.42665249109268, 67.3359739780426, 60.05147226154804, 63.78153070807457, 64.21884164214134, 63.09149533510208, 64.50850009918213, 61.962686106562614, 64.88809213042259, 61.8350737541914, 62.93635345995426, 63.848353922367096, 64.3266798555851, 62.68535792827606, 63.521742448210716, 61.62195459008217, 62.005468010902405, 66.21169030666351, 68.6354510486126, 70.19655928015709, 33.640009090304375, 0.35062630428001285, 0.3890002373373136, 0.709072588942945, 0.07847190485335886, 0.24305453669512644, 26.06807179749012, 65.69226577877998, 66.73387348651886, 55.433796644210815, 58.11943173408508, 39.73705552518368, 10.913040060549974, 23.850651383399963, 48.18431384861469, 50.31906209886074, 59.974169209599495, 19.471511766314507, 0.7307888986542821, 0.1522478405968286, 0.14087662420934066, 0.07896207855083048, 0.041490033036097884, 0.07617486131493933, 0.056644944634172134, 0.025171916277031414, 0.053233647995512, 0.07694643514696509, 0.06720966543070972, 0.01565772035974078, 0.036847368683083914, 0.14271256397478282, 0.07480057451175526, 0.04833578132092953, 0.06598513660719618, 0.002195821552959387, 0.02233025323221227, 0.06286567469942383, 1.3727307273074985, 74.3366727232933, 79.84585270285606, 70.94429835677147, 45.67508429288864, 45.360738560557365, 89.516212195158, 43.97075034677982, 50.696340054273605, 88.86387839913368, 56.62173070013523, 0.08651743875816464, 0.07296561438124627, 1.5927464026026428, 1.6107093449681997, 2.292006374336779, 34.88510727882385, 79.36175107955933, 82.28601336479187, 73.08574944734573, 77.69854992628098, 82.71792098879814, 81.97843506932259, 80.26378467679024, 79.9073638021946, 80.43400034308434, 77.76866376399994, 71.72688916325569, 66.69001623988152, 59.325756803154945, 53.26347850263119, 53.43904808163643, 57.171952575445175, 57.226886227726936, 58.35179686546326, 57.17113561928272, 54.09753754734993, 54.17474180459976, 56.139456778764725, 56.5693125128746, 52.70281478762627, 56.55774213373661, 53.07827644050121, 52.51347854733467, 50.97844071686268, 53.23011249303818, 50.56149668991566, 49.610377326607704, 53.105118200182915, 50.77742010354996, 48.826255202293396, 50.998142659664154, 47.81603001058102, 46.4005945622921, 47.792832255363464, 51.690222322940826, 61.42782300710678, 65.42646244168282, 62.059482112526894, 58.87038543820381, 60.48876419663429, 62.80991904437542, 61.82997062802315, 60.69624826312065, 57.84539423882961, 60.59151068329811, 61.73116073012352, 62.08988048136234, 65.96189171075821, 65.27134716510773, 55.362656861543655, 61.036652997136116, 61.55147597193718, 64.04942393302917, 60.6026478856802, 59.73823606967926, 36.32129721343517, 33.931043073534966, 27.155537344515324, 40.93392290174961, 66.45848706364632, 56.28702946007252, 58.83193530142307, 55.98600581288338, 57.52268895506859, 55.053425654768944, 57.02808849513531, 59.35505323112011, 61.24431945383549, 60.05245640873909, 58.0222025513649, 57.617938444018364, 55.29508888721466, 57.58181378245354, 64.2814090847969, 49.81128394603729, 44.737511202692986, 63.74227501451969, 58.88901203870773, 52.465194538235664, 45.33448576927185, 45.055033564567566, 41.40987016260624, 45.26800073683262, 45.864127948880196, 45.687752813100815, 45.49937792122364, 47.424537017941475, 47.69766256213188, 46.647539511322975, 45.04850551486015, 47.79034338891506, 51.1163467168808, 49.29857365787029, 52.225510999560356, 52.41580478847027, 55.70360116660595, 60.391113236546516, 67.12736517190933, 69.77744176983833, 63.28596889972687, 67.09671601653099, 66.56022280454636, 66.86232179403305, 65.97883880138397, 64.54767599701881, 68.99526134133339, 64.63779956102371, 65.8018746972084, 67.29619771242142, 66.21488213539124, 65.11798739433289, 66.87783256173134, 65.30945152044296, 65.86042955517769, 67.62339815497398, 71.7663386464119, 72.67892807722092, 39.40052278339863, 0.992122784955427, 0.8053628064226359, 0.8337457990273833, 0.5391166149638593, 0.28194493032060564, 25.471389815211296, 74.44919228553772, 73.83211299777031, 63.05817112326622, 50.85993267595768, 23.615029826760292, 18.726386949419975, 35.42837932705879, 56.212697848677635, 58.19623701274395, 69.19962957501411, 25.544887371361256, 0.7745267485734075, 0.21122734062373638, 0.13675648748176172, 0.05510753006092273, 0.04437617113580927, 0.07529776150477119, 0.02443563713313779, 0.04832983671803959, 0.09026451269164681, 0.11845241693663411, 0.18494619929697365, 0.17727599915815517, 0.1919385662768036, 0.15732245345134288, 0.27940411353483796, 0.1645008916966617, 0.1658263526041992, 0.13990527164423838, 0.2015510856290348, 0.37652592232916504, 2.0937952352687716, 87.19026580452919, 90.51966235041618, 80.96369951963425, 45.669958367943764, 56.82217754423618, 118.1617958843708, 67.12472051382065, 59.117877557873726, 93.62116992473602, 65.0191242992878, 0.35409893200267106, 0.24946646997705102, 2.842302583158016, 3.391970875672996, 2.776136021129787, 37.27251537144184, 82.09496721625328, 86.95109143853188, 72.5065465271473, 80.12348860502243, 86.33639842271805, 84.96148779988289, 83.24907928705215, 83.07843044400215, 82.5981742143631, 81.3958503305912, 75.36061897873878, 69.80230763554573, 63.27268861234188, 56.475757732987404, 56.03117398917675, 59.6763601899147, 60.40641501545906, 59.788533970713615, 59.45526525378227, 57.083972096443176, 57.42001086473465, 58.903987035155296, 58.95347557961941, 55.10398954153061, 59.329032227396965, 57.092126458883286, 55.85094206035137, 54.31556984782219, 56.54263034462929, 53.75429056584835, 51.76374837756157, 57.71914221346378, 54.98334601521492, 50.92427462339401, 54.4068219512701, 51.27601034939289, 51.11709527671337, 48.64848934113979, 55.91761328279972, 63.612302988767624, 68.76817032694817, 63.783301413059235, 59.790445268154144, 64.00092333555222, 65.67020416259766, 63.9039221405983, 61.77980192005634, 60.92324808239937, 62.47953437268734, 63.46228323876858, 66.51677593588829, 70.04654332995415, 69.33456033468246, 59.52312581241131, 61.91531024873257, 65.99251046776772, 66.52379795908928, 62.560120448470116, 61.51615686714649, 41.57033175230026, 32.029127329587936, 30.5487609654665, 46.82320028543472, 71.320690959692, 58.24977234005928, 61.52909517288208, 59.36655521392822, 60.046536326408386, 58.338588774204254, 61.43963277339935, 64.04239431023598, 63.981688767671585, 66.36404693126678, 64.52679231762886, 60.89112840592861, 57.23503679037094, 59.47486460208893, 66.8662279844284, 51.957192197442055, 45.11327303946018, 67.62099668383598, 62.363834381103516, 55.23608945310116, 48.11891935765743, 48.55786420404911, 44.042672887444496, 47.152608409523964, 50.25829955935478, 47.515629529953, 48.195181265473366, 50.90621419250965, 50.38150034844875, 48.40036265552044, 48.405674770474434, 50.62930025160313, 54.290175810456276, 49.98177319765091, 55.58378219604492, 53.94484654068947, 57.038488537073135, 61.445860639214516, 71.00459352135658, 69.89872366189957, 65.53402706980705, 70.4707145690918, 68.24439123272896, 69.25603374838829, 69.02583450078964, 67.82563850283623, 73.75040978193283, 70.03126814961433, 68.78695651888847, 71.66550725698471, 70.15681341290474, 67.59920105338097, 71.15086287260056, 69.5616665482521, 70.7539589703083, 73.3853405714035, 76.5386925637722, 76.6489626467228, 41.23694524168968, 1.462753952946514, 4.253351166844368, 1.785204412881285, 0.6558804307132959, 0.3987694240640849, 34.08026106655598, 79.38674613833427, 79.56588372588158, 74.38132792711258, 78.36104437708855, 52.68829956650734, 20.49729712307453, 35.93202330172062, 65.75454443693161, 66.07411488890648, 79.64708536863327, 31.423510126769543, 0.920555762713775, 0.31313208339270204, 0.1887590720434673, 0.19037843827391043, 0.13769759010756388, 0.22265574691118672, 0.1922087970888242, 0.11108807811979204, 0.16515583702130243, 0.24026582774240524], [0.016581735035288148, 0.041183629946317524, 0.05512452895345632, 0.024925100224209018, 0.061427351683960296, 0.05413714599853847, 0.07383363030385226, 0.07206518144812435, 0.09915485556120984, 0.24911813554354012, 9.120542295277119, 76.10820606350899, 60.71282297372818, 60.186285227537155, 26.769381165504456, 44.0384741127491, 48.31230618059635, 39.443722665309906, 55.644043162465096, 90.90554684400558, 24.91470068693161, 0.3058156056795269, 0.15398949792142957, 1.2067703576758504, 0.5259149358607829, 5.066034933552146, 48.906594291329384, 82.31508180499077, 75.91228097677231, 75.73404774069786, 80.18199786543846, 75.80938249826431, 78.47297117114067, 75.66618338227272, 76.4748939871788, 75.1684632897377, 76.31205752491951, 65.65820440649986, 57.59588062763214, 54.41962346434593, 57.784350514411926, 60.051483660936356, 65.16982421278954, 68.00884947180748, 67.26612612605095, 62.565702348947525, 63.34184110164642, 55.06289854645729, 52.31401205062866, 52.223854288458824, 52.29951582849026, 52.13287577033043, 53.8360545784235, 51.07052497565746, 50.78821912407875, 46.66436120867729, 48.0093864351511, 47.62715354561806, 52.9691044986248, 49.40331123769283, 44.56973120570183, 46.76828183233738, 46.39468967914581, 42.567911222577095, 43.535749688744545, 52.10380733013153, 63.34569409489632, 63.207229524850845, 65.42849913239479, 63.141645044088364, 61.81641675531864, 58.99909593164921, 63.11997480690479, 58.64181250333786, 61.34275697171688, 60.38770481944084, 59.675075858831406, 60.879109650850296, 64.7716435790062, 52.062195762991905, 40.4297811537981, 60.68178243935108, 59.57224577665329, 60.67556597292423, 63.41379024088383, 55.15934497117996, 30.973726361989975, 41.947590708732605, 30.53348198533058, 26.308446899056435, 56.60451762378216, 58.611588925123215, 58.17888334393501, 56.41436442732811, 55.8916150778532, 56.00068062543869, 56.86859965324402, 54.87532161176205, 56.708867624402046, 58.78321811556816, 54.95924390852451, 54.74211595952511, 53.66220250725746, 56.09826318919659, 52.66436845064163, 45.53987234830856, 60.84205403923988, 58.46700668334961, 54.669935032725334, 46.038648784160614, 42.87446357309818, 40.99078305065632, 40.462668389081955, 41.556580290198326, 43.13819222152233, 41.058548614382744, 40.71155123412609, 46.41743905842304, 45.69243036210537, 44.26427699625492, 42.54792049527168, 42.89689376950264, 46.35450683534145, 47.90927700698376, 48.2296834141016, 49.369105473160744, 56.57529339194298, 63.19909416139126, 61.95613145828247, 64.92401540279388, 62.2055234760046, 61.09962701797485, 64.55459922552109, 61.71627692878246, 63.36539603769779, 60.96583239734173, 65.36497414112091, 63.01361471414566, 64.03659582138062, 63.48242215812206, 61.325866878032684, 62.440814450383186, 64.0341791510582, 61.11437402665615, 63.047379702329636, 62.13787570595741, 69.07852247357368, 68.94955739378929, 56.52131348848343, 2.8302111569792032, 1.4075913629494607, 1.1307712295092642, 0.0688404607353732, 0.06064784058253281, 2.575474251061678, 63.88411000370979, 64.82359439134598, 57.98271507024765, 47.20106340944767, 58.934898376464844, 21.100974529981613, 7.138547273352742, 26.44749853760004, 48.33219051361084, 58.12068186700344, 50.05876466631889, 1.4776777708902955, 0.11260641578701325, 0.0618009599565994, 0.020484806555032264, 0.04858906890149228, 0.033408337985747494, 0.055117742012953386, 0.028352455083222594, 0.06381713770679198, 0.042858000451815315, 0.0817852676846087, 0.01229439614689909, 0.02849003441951936, 0.1315316342515871, 0.026836948709387798, 0.1020233824965544, 0.08487122162478045, 0.10702590312575921, 0.17003747663693503, 0.4129221208859235, 10.84089808166027, 89.96695920825005, 65.76810970902443, 68.77174973487854, 30.561970956623554, 57.095436081290245, 49.174981489777565, 37.98894792795181, 67.24109306931496, 95.89386597275734, 26.678206957876682, 0.3966905199922621, 0.004374366835691035, 1.3446756452322006, 1.3608003174886107, 6.61616887897253, 55.1982206851244, 82.5594162940979, 80.60930013656616, 75.80329522490501, 83.29170539975166, 75.98296478390694, 80.5680799484253, 77.6213988661766, 78.55853497982025, 76.59848615527153, 78.83184671401978, 66.8743671476841, 60.31824454665184, 55.35310037434101, 61.39014042913914, 62.18741364777088, 69.59985449910164, 70.53442195057869, 67.68299415707588, 65.97823843359947, 66.73300713300705, 56.84068635106087, 54.4614440202713, 53.981332182884216, 55.938325971364975, 53.762619718909264, 56.422154009342194, 53.06107856333256, 53.47905993461609, 49.928139075636864, 51.01869575679302, 51.182140186429024, 54.991686567664146, 52.874565571546555, 46.89070746302605, 49.42159205675125, 48.60726535320282, 45.39255425333977, 46.39806009829044, 54.151274263858795, 66.10451325774193, 66.93352237343788, 67.21750393509865, 64.83413502573967, 66.12184792757034, 63.52688357234001, 63.72888833284378, 61.05376347899437, 62.03377649188042, 64.0096552670002, 63.4838280826807, 63.28123055398464, 67.65087068080902, 53.91029879450798, 42.62806959450245, 61.034851893782616, 62.251782193779945, 64.17064502835274, 66.41864240169525, 56.2950774282217, 34.97411370277405, 43.76275330781937, 34.33235473930836, 29.58248421549797, 57.28452153503895, 63.775808215141296, 61.44981622695923, 60.20092584192753, 59.43268686532974, 59.83003914356232, 58.48170809447765, 58.186509534716606, 60.96727252006531, 61.854460313916206, 56.86490625143051, 56.42640978097916, 57.23417803645134, 61.282716393470764, 52.98795908689499, 48.320240154862404, 62.337216809391975, 60.74091486632824, 57.070517018437386, 47.6070412248373, 45.11887773871422, 45.0903944671154, 43.234228268265724, 42.42725037038326, 44.775129184126854, 42.92104907333851, 43.992781564593315, 48.233433812856674, 49.3201868981123, 45.61945527791977, 47.03268304467201, 45.341845974326134, 48.74997429549694, 50.16719564795494, 51.845432594418526, 52.321672439575195, 60.45557297766209, 64.80722486972809, 63.42578239738941, 70.50261005759239, 64.86557453870773, 63.680030554533005, 67.32058480381966, 65.92564925551414, 66.7030343413353, 63.202453181147575, 66.43739059567451, 65.43256491422653, 65.88373750448227, 65.40181696414948, 65.32863289117813, 64.93864461779594, 68.91510084271431, 64.83513817191124, 64.89892914891243, 65.15596255660057, 70.12586027383804, 71.51720881462097, 61.54093153774738, 4.656986407935619, 1.081982203759253, 3.165160333737731, 0.5733911320567131, 0.044946014386368915, 2.2500098403543234, 65.18518298864365, 71.01930633187294, 65.12959197163582, 56.37744940817356, 47.57354222238064, 24.718840196728706, 20.465563125908375, 34.731397926807404, 54.58178736269474, 65.51286220550537, 58.271017000079155, 2.1123755257576704, 0.018855651396734174, 0.05958125191682484, 0.023494072520406917, 0.023440398545062635, 0.06985893967794254, 0.03826924570603296, 0.0635984045220539, 0.04071480783750303, 0.08297593973111361, 0.11759926623199135, 0.2020114695187658, 0.08538794936612248, 0.12436127057299018, 0.14231119566829875, 0.18475374556146562, 0.1752871769713238, 0.1972368179121986, 0.3718599211424589, 0.49732432002201676, 14.090510308742523, 104.20288011431694, 74.3684010207653, 79.77111831307411, 37.913487777113914, 54.423237070441246, 57.71625056862831, 57.44630925357342, 71.96947574615479, 104.61781784892082, 31.673787496984005, 0.467483215034008, 0.47437055327463895, 4.423174979165196, 2.2807466285303235, 8.950286731123924, 59.09062162041664, 87.78718337416649, 83.68656501173973, 80.40775135159492, 85.07162109017372, 80.25437638163567, 84.33898240327835, 82.76447609066963, 81.62338212132454, 80.49661338329315, 81.89491555094719, 70.63748762011528, 61.58074200153351, 58.62655632197857, 63.04976977407932, 65.54554805159569, 69.02056038379669, 73.39361652731895, 70.70814862847328, 67.8970442712307, 70.73186695575714, 58.46601873636246, 56.78573749959469, 56.66296228766441, 58.39785799384117, 57.10875056684017, 58.82402792572975, 56.41103960573673, 55.449721589684486, 52.7312258630991, 53.53337042033672, 53.29073444008827, 60.001052767038345, 54.261886328458786, 49.945393949747086, 52.49394379556179, 50.89434362947941, 48.47238019108772, 48.02724927663803, 58.446791768074036, 68.67648884654045, 68.96367743611336, 69.97461318969727, 70.41865736246109, 68.76867949962616, 65.81094101071358, 67.30492204427719, 64.08997535705566, 64.80179876089096, 66.19880139827728, 65.10249182581902, 67.86983013153076, 68.9021435379982, 55.69154441356659, 46.039249151945114, 63.33288878202438, 64.53284919261932, 66.6280871629715, 66.66498318314552, 60.45733228325844, 37.86831580102444, 44.56929802894592, 36.89829245209694, 34.4099123775959, 60.25150492787361, 66.38483181595802, 62.29889966547489, 62.09924317896366, 62.08887733519077, 62.78899736702442, 61.79847031831741, 61.20206572115421, 63.71816910803318, 66.21818035840988, 60.013341307640076, 59.617706537246704, 59.71680901944637, 61.6073177754879, 54.118003249168396, 50.38479097187519, 61.298641338944435, 65.44967919588089, 61.20607830584049, 50.604764968156815, 48.14629688858986, 47.772184163331985, 45.91572917997837, 45.72857782244682, 47.29586072266102, 44.78660076856613, 46.91214211285114, 52.487240955233574, 52.10733354091644, 48.133928552269936, 48.73446352779865, 47.14597016572952, 50.774604454636574, 54.046175703406334, 53.762114346027374, 53.74185383319855, 63.065645322203636, 67.98917412757874, 67.15198025107384, 71.1540699005127, 66.22510358691216, 66.85051202774048, 71.35741978883743, 67.26552575826645, 69.42324757575989, 67.0635361969471, 72.46417120099068, 67.60346442461014, 71.07803598046303, 68.13099771738052, 67.62887746095657, 69.40685525536537, 70.20901501178741, 67.0269213616848, 69.57232117652893, 69.71358999609947, 74.57918331027031, 73.50557371973991, 67.40551024675369, 4.8553177155554295, 4.94611669331789, 6.757150813937187, 1.6879575373604894, 0.20380608650157228, 3.6249852972105145, 78.94927561283112, 73.97452935576439, 73.31002101302147, 64.772509932518, 80.08854568004608, 30.248734764754772, 16.732936017215252, 41.63855329155922, 66.74629881978035, 72.29951843619347, 69.63476702570915, 2.6979179307818413, 0.3350274881813675, 0.10891536658164114, 0.1035815363866277, 0.14894010324496776, 0.14366972667630762, 0.17592154996236786, 0.23654371965676546, 0.2539721375796944, 0.22150440869154409], [0.10249000784824602, 0.04615700643626042, 0.0404139968304662, 0.07544494423200376, 0.07475286183762364, 0.04015624523162842, 0.15368297608802095, 0.06179204305226449, 0.13305615400895476, 0.265571252675727, 28.082233518362045, 75.88600918650627, 63.941213339567184, 45.45898608863354, 24.931146204471588, 9.816859681159258, 39.30543668568134, 52.25422605872154, 63.34502153098583, 81.11349508166313, 6.501558478921652, 0.07002518075751141, 0.2536923479055986, 0.5585456255357713, 0.8117015787865967, 12.704831063747406, 63.19968692958355, 80.29651612043381, 75.20618006587029, 76.17037072777748, 80.02007335424423, 77.90512964129448, 75.12510761618614, 77.8729073703289, 77.20853582024574, 69.29080948233604, 60.01127041876316, 53.4967365860939, 55.997344404459, 60.40402874350548, 65.96620827913284, 70.914226770401, 71.12738013267517, 68.64002600312233, 72.73709535598755, 74.37393352389336, 66.95948258042336, 63.9440555870533, 59.76954638957977, 51.36016443371773, 51.61293067038059, 51.54634304344654, 51.09861686825752, 51.9186432659626, 50.26630952954292, 46.910557597875595, 47.503728568553925, 47.80733607709408, 50.00943571329117, 49.73230138421059, 47.26213753223419, 43.79474759101868, 44.764900133013725, 41.65205396711826, 42.70818069577217, 52.27132134139538, 61.7745316028595, 64.54573810100555, 64.88186046481133, 62.622186318039894, 62.61253483593464, 63.288085386157036, 62.20110431313515, 59.36472751200199, 61.45445577800274, 58.67505691945553, 64.47491750121117, 63.03815379738808, 64.28837791085243, 59.225126802921295, 59.635174199938774, 57.560724914073944, 64.95398059487343, 56.62817135453224, 68.24058383703232, 42.88838602602482, 31.047953478991985, 44.86595571041107, 39.65349420905113, 28.440932370722294, 49.44748766720295, 61.816101372241974, 61.533765122294426, 59.080970138311386, 56.48334592580795, 58.29247444868088, 52.058517560362816, 54.31955963373184, 53.584633469581604, 55.29704958200455, 56.21162250638008, 56.55615381896496, 56.78761459887028, 53.31420578062534, 45.54817110300064, 58.961447551846504, 58.20430018007755, 57.79093936085701, 53.042793944478035, 46.878023743629456, 42.267058566212654, 40.250381380319595, 40.140027701854706, 40.8512507379055, 40.635912492871284, 43.73499199748039, 43.24697658419609, 44.38456334173679, 44.55069042742252, 44.40507464110851, 42.68614947795868, 43.49348075687885, 46.77688457071781, 50.411290749907494, 47.48675487935543, 52.05040879547596, 58.02230514585972, 62.446593940258026, 59.85825642943382, 62.476836517453194, 63.98747965693474, 61.41717217862606, 61.749456748366356, 59.8735848069191, 63.4698486328125, 61.1087579280138, 64.22213986515999, 64.18168723583221, 62.88064084947109, 64.0076793730259, 65.4233618080616, 62.74746559560299, 64.76173371076584, 61.9324017316103, 62.831395491957664, 65.95809191465378, 67.70202353596687, 68.49892437458038, 68.3038580417633, 13.939834143966436, 1.242016910109669, 1.2408797023817897, 1.8803623504936695, 0.15102849196409807, 0.13069112232187763, 29.54566989094019, 70.89636772871017, 68.33958372473717, 49.86318916082382, 44.1797087341547, 36.82500198483467, 19.05548918992281, 17.514128498733044, 43.42652074992657, 48.85437749326229, 61.70012779533863, 11.151633057743311, 0.4151306633139029, 0.0647968913835939, 0.029586355376522988, 0.03755973026272841, 0.05854019313119352, 0.07181998327723704, 0.013486336338246474, 0.046546559751732275, 0.03712536235980224, 0.047225235248333775, 0.0407457553956192, 0.0678809973760508, 0.022472968230431434, 0.05125893403601367, 0.0445097540068673, 0.11844728127471171, 0.03530954592861235, 0.15833426790777594, 0.24305238446686417, 34.37052749097347, 87.80019387602806, 70.07409945130348, 59.45025332272053, 35.306778252124786, 19.227882139384747, 35.28412386775017, 60.94888150691986, 70.47014459967613, 88.6245596408844, 6.99273532256484, 0.07430093100992963, 0.37627192970830947, 1.6889973753131926, 0.6539078615605831, 14.359049499034882, 65.65748244524002, 84.07151475548744, 75.62905177474022, 76.71321719884872, 83.452869951725, 79.56975191831589, 78.54908868670464, 78.89775797724724, 78.82480189204216, 70.20064786076546, 63.604243621230125, 56.56315304338932, 61.10062636435032, 64.4419352710247, 70.17713472247124, 72.9086485505104, 75.47069147229195, 71.86263307929039, 76.43118113279343, 75.46843439340591, 70.36105245351791, 69.19111043214798, 60.19879035651684, 53.56797136366367, 53.5613065212965, 53.837293311953545, 52.914098650217056, 53.76266151666641, 52.143796384334564, 49.34149995446205, 50.53791135549545, 50.313389003276825, 53.410207629203796, 51.53093487024307, 51.26809537410736, 45.005803406238556, 46.742143034935, 43.925810158252716, 47.21466667950153, 53.78720439970493, 65.60775831341743, 65.71747362613678, 66.793332695961, 64.46861743927002, 66.7801322042942, 65.88404148817062, 64.57229867577553, 63.00397463142872, 62.01837591826916, 61.947593316435814, 66.54370129108429, 65.04942387342453, 64.9134823679924, 61.25112868845463, 61.597761288285255, 61.16125971078873, 67.14863643050194, 59.251580983400345, 69.24756020307541, 46.37638986110687, 34.94712375104427, 48.54266121983528, 41.58851757645607, 31.61471776664257, 51.86291925609112, 64.1369104385376, 63.72300244867802, 60.235857367515564, 59.61361415684223, 60.644517838954926, 52.967383190989494, 56.64972759783268, 56.04932941496372, 58.930756598711014, 57.611714377999306, 59.316846281290054, 59.97550293803215, 55.069153010845184, 48.35481069982052, 60.52798189222813, 60.830077081918716, 60.81064112484455, 56.830909475684166, 48.19804251194, 44.82612244784832, 44.024449065327644, 42.93807215988636, 43.86109583079815, 43.52958641946316, 44.81605678796768, 45.040404349565506, 49.286167323589325, 46.451211646199226, 47.145962566137314, 43.79578113555908, 44.7212290763855, 48.27035263180733, 52.926668375730515, 48.78753527998924, 55.931585133075714, 60.30797369778156, 63.43039534986019, 61.828614100813866, 66.06917515397072, 65.01177549362183, 65.63633278012276, 65.42999625205994, 63.6211983114481, 64.84636276960373, 65.51144868135452, 66.53929352760315, 66.91763162612915, 66.61727294325829, 68.7363888323307, 68.41111108660698, 65.93638747930527, 65.06453946232796, 66.31154134869576, 64.52728629112244, 69.7489432990551, 69.78908434510231, 72.61775895953178, 71.21553540229797, 17.799964360892773, 0.8398066519293934, 0.9573558974079788, 1.4639855618588626, 0.6124111195094883, 0.19510658690705895, 29.56005211919546, 77.8139953315258, 72.91565537452698, 58.93366724252701, 50.74695333838463, 34.11611594259739, 24.262459985911846, 27.157477140426636, 51.69555343687534, 56.77263580262661, 69.63765487074852, 14.71177127212286, 0.48798044328577816, 0.18209874193416908, 0.03287856328825001, 0.028133959385741036, 0.03161358370562084, 0.09007232612930238, 0.0769917358411476, 0.09335345748695545, 0.07028110296232626, 0.17262389097595587, 0.1277666151872836, 0.20682619709987193, 0.20053609478054568, 0.19902952015399933, 0.191634523216635, 0.39837163290940225, 0.2710915548959747, 0.18427178001729771, 0.3649917006259784, 44.00361858308315, 98.60812112689018, 77.98332184553146, 68.63976001739502, 37.377359345555305, 16.623374596238136, 57.49935440719128, 75.20377859473228, 75.66287755966187, 97.18160167336464, 8.58776718378067, 0.3492668381659314, 1.065159437712282, 5.242837546393275, 3.2591969752684236, 17.657084427773952, 67.93756529688835, 87.39100143313408, 81.05073004961014, 78.15900921821594, 84.34734955430031, 84.54124554991722, 80.38502097129822, 84.36814963817596, 82.3651859164238, 74.46441426873207, 65.9605161845684, 59.70245338976383, 61.922811046242714, 65.11824578046799, 72.42305740714073, 77.09423795342445, 78.20134654641151, 73.21612045168877, 76.69452980160713, 77.93932020664215, 73.30999821424484, 70.47645226120949, 65.1558181643486, 55.81226773560047, 55.97107261419296, 55.38259819149971, 56.277499571442604, 55.88514402508736, 55.4020569473505, 51.49944595992565, 53.47204931080341, 52.60430887341499, 55.66012769937515, 53.29503580927849, 54.33498680591583, 47.38053157925606, 51.04734241962433, 47.14213617146015, 49.567785412073135, 57.573047652840614, 68.92746537923813, 70.43840870261192, 69.8897485435009, 68.95679980516434, 68.09944421052933, 67.21276178956032, 67.16338723897934, 64.92371901869774, 64.74547818303108, 65.3455875813961, 69.69006165862083, 68.29166829586029, 69.24714982509613, 64.25298660993576, 62.071421071887016, 62.732984572649, 69.64255660772324, 62.5668802857399, 73.48417326807976, 48.09175841510296, 35.86149528622627, 49.109450206160545, 44.37348313629627, 36.24658182263374, 55.46522095799446, 67.72246643900871, 68.1959742307663, 64.29226130247116, 62.86596983671188, 63.88144254684448, 56.443987637758255, 59.835997223854065, 60.929977521300316, 63.49072091281414, 62.794617265462875, 62.27550812065601, 62.03297473490238, 57.28355258703232, 51.81963957846165, 59.703369140625, 63.499179258942604, 64.6393346786499, 58.70930068194866, 51.71984173357487, 46.47104278206825, 45.62052682042122, 47.2810985147953, 48.28457906842232, 45.64339779317379, 47.55583897233009, 49.07220080494881, 53.58110725879669, 50.17231397330761, 49.28625091910362, 46.61389611661434, 47.64117859303951, 52.84500315785408, 56.14482209086418, 52.385231629014015, 58.58692064881325, 64.56266239285469, 66.0050193965435, 65.48275262117386, 70.33975079655647, 63.840746730566025, 70.24615421891212, 66.09764322638512, 68.97440046072006, 67.37825810909271, 68.75971958041191, 69.18471917510033, 71.9855260848999, 69.52711120247841, 75.2636405825615, 72.5585125386715, 69.05736520886421, 69.11670282483101, 69.11741718649864, 68.0074055492878, 74.88628283143044, 74.41082954406738, 74.732246696949, 74.11608695983887, 19.65354099869728, 3.5090587427839637, 4.261563001200557, 3.237489452585578, 0.943701567593962, 0.17014496930642053, 38.362794667482376, 84.97850328683853, 80.68613201379776, 65.92442572116852, 61.423445641994476, 47.78053231537342, 27.82656043767929, 29.354076571762562, 60.589584186673164, 63.470042422413826, 81.42003983259201, 20.116808339953423, 0.7541393581777811, 0.3501795313786715, 0.10303802453563549, 0.10269444726873189, 0.20709987147711217, 0.24037382507231086, 0.13398582756053656, 0.23351782030658796, 0.19412211317103356], [0.024105255251924973, 0.06834528496256098, 0.04558134103717748, 0.05447231473226566, 0.03822379658231512, 0.0273063886561431, 0.048032762424554676, 0.043174066304345615, 0.1225297391647473, 0.12304990304983221, 50.012521147727966, 71.42095237970352, 59.03139799833298, 40.69196328520775, 15.400726553052664, 31.75428807735443, 61.345960199832916, 48.87752965092659, 76.09399482607841, 61.432842537760735, 0.5507450003642589, 0.05857708529219963, 0.1445700557087548, 0.9412252879701555, 3.2888503465801477, 24.818286560475826, 73.10257494449615, 79.55065414309502, 74.09179866313934, 76.2834906578064, 80.74553802609444, 72.90866374969482, 71.89673244953156, 67.00329422950745, 62.15094320476055, 56.821193397045135, 60.02642020583153, 66.33192345499992, 68.77544313669205, 71.50120407342911, 72.86805152893066, 72.03768968582153, 67.85199388861656, 73.75160291790962, 83.52968662977219, 68.22948843240738, 72.04505369067192, 68.6028715968132, 68.49702447652817, 58.50135684013367, 53.36007311940193, 46.890646666288376, 49.98319432139397, 50.75878590345383, 49.92898263037205, 45.66108964383602, 48.478418067097664, 49.70584720373154, 50.14238677918911, 47.0732344686985, 48.550184816122055, 43.742549791932106, 42.54161283373833, 41.03275179862976, 41.16334319114685, 47.21501246094704, 59.5250029116869, 61.975575014948845, 61.02897360920906, 62.12014965713024, 63.596438840031624, 57.62064389884472, 60.31952507793903, 57.82948449254036, 60.27804270386696, 59.8796720802784, 61.7410060018301, 61.9047050178051, 58.77631388604641, 63.6964076757431, 64.69057872891426, 59.78029601275921, 61.34241499006748, 54.56824488937855, 65.63365012407303, 47.337875068187714, 41.29841074347496, 45.509910956025124, 40.79426519572735, 33.21293480694294, 51.72271437942982, 59.0436789393425, 58.98353956639767, 62.30519212782383, 58.31164821982384, 57.22880892455578, 55.6238928437233, 48.39894153177738, 52.80500270426273, 56.91355504095554, 51.832954064011574, 52.620070427656174, 51.92391358315945, 52.018144726753235, 58.242719918489456, 59.861148074269295, 55.222151800990105, 56.941494941711426, 49.279969856143, 46.13531559705734, 44.44371096789837, 40.079565346241, 40.93268036842346, 40.98050460219383, 41.496562510728836, 43.49150486290455, 42.16628797352314, 44.18761231005192, 43.88570711016655, 44.01921294629574, 44.13455955684185, 42.232123240828514, 43.39990697801113, 47.121738865971565, 47.439158633351326, 48.83178010582924, 58.39679405093193, 60.93179762363434, 62.12367206811905, 55.93167632818222, 67.74429246783257, 60.01733109354973, 60.03043659031391, 63.05194325745106, 60.585503205657005, 62.74717681109905, 64.34693276882172, 65.18584415316582, 65.09068205952644, 63.805803805589676, 63.751033544540405, 65.00116646289825, 64.37052190303802, 67.2369284927845, 66.92384049296379, 68.87878239154816, 66.55101209878922, 72.92452409863472, 68.17004442214966, 27.408077493309975, 0.4954316356452182, 1.3259826670400798, 0.8490336849354208, 0.07275224692421034, 0.1970695675117895, 7.5824670027941465, 65.85894763469696, 61.64972350001335, 64.46670234203339, 49.09303888678551, 64.28911507129669, 34.143193289637566, 11.80724797770381, 30.601853616535664, 46.327102705836296, 62.29413852095604, 39.99239802360535, 0.9128522698301822, 0.1648766262223944, 0.05034119792981073, 0.04584075133607257, 0.031070175755303353, 0.014971014825277962, 0.06498597576864995, 0.030164501404215116, 0.03354784690600354, 0.07850368361687288, 0.054742749634897336, 0.026115709188161418, 0.04230103346344549, 0.016921853894018568, 0.05431305355159566, 0.08446981621091254, 0.020249163535481784, 0.1097969118563924, 0.1753847990767099, 60.02104729413986, 81.34706854820251, 64.84038189053535, 45.249784514307976, 25.674029141664505, 29.0027854219079, 53.318203166127205, 59.502173736691475, 85.31087145209312, 68.04060816764832, 0.2507984172552824, 0.030513789497490507, 0.7220719882752746, 1.6491143591701984, 2.9925828566774726, 28.186036348342896, 76.03914096951485, 80.7116286456585, 74.72441151738167, 80.39183020591736, 83.33848848938942, 74.86055821180344, 72.27325424551964, 71.33173316717148, 62.440221682190895, 60.18471211194992, 62.65870615839958, 70.0242917239666, 71.09151765704155, 74.98921930789948, 75.67540928721428, 75.9470871090889, 68.19284319877625, 74.67707365751266, 78.78619596362114, 70.2991233766079, 74.08144801855087, 71.66651040315628, 70.35070180892944, 62.46487095952034, 53.57998251914978, 49.280395433306694, 53.84004436433315, 52.42922566831112, 52.98838086426258, 46.4459565281868, 51.61516495049, 50.334569066762924, 51.98263183236122, 48.70384097099304, 49.27163690328598, 47.11200758814812, 45.33866174519062, 44.02906961739063, 41.77361324429512, 48.72347831726074, 61.4595665037632, 64.23366844654083, 64.26023662090302, 62.510700300335884, 68.16105410456657, 60.00536933541298, 60.86775965988636, 58.152508959174156, 62.74680823087692, 62.77295842766762, 64.2555020749569, 64.532400816679, 63.30881327390671, 65.4733519256115, 63.5715501755476, 63.21062654256821, 63.03257569670677, 60.42674772441387, 68.65765705704689, 50.57354584336281, 43.979413881897926, 47.6000951975584, 42.36272223293781, 36.61884404718876, 55.62112659215927, 61.70786798000336, 62.022130116820335, 63.16861219704151, 59.54484544694424, 56.92751169204712, 54.77284871041775, 50.168597772717476, 54.810698479413986, 58.55960011482239, 53.62713038921356, 56.097412034869194, 54.18785110116005, 52.647789940238, 60.15223145484924, 60.27504846453667, 57.14919179677963, 56.9017680734396, 51.64349623024464, 48.59786465764046, 46.943159848451614, 43.014748245477676, 42.958811447024345, 45.35584822297096, 42.8302301466465, 45.77504552900791, 43.59938107430935, 47.1698746830225, 46.427679508924484, 46.29903361201286, 45.81381864845753, 44.56805929541588, 45.611209720373154, 49.158980548381805, 48.619291707873344, 51.533013358712196, 59.96601104736328, 62.909515500068665, 63.446194902062416, 60.34613884985447, 70.3223705291748, 63.394966050982475, 62.76144504547119, 65.29367476701736, 62.789350748062134, 64.00349959731102, 65.4978834092617, 69.61804032325745, 67.94679880142212, 65.18422544002533, 66.93855330348015, 68.89771297574043, 68.95624503493309, 70.35414442420006, 69.80489909648895, 71.45426139235497, 70.06482794880867, 74.28254842758179, 69.05317023396492, 32.960407957434654, 0.7938868878409266, 0.5798889615107328, 1.7560909688472748, 1.7623863997869194, 0.32404720550403, 6.6564638167619705, 72.2878910601139, 69.36103731393814, 70.62448471784592, 55.102811604738235, 46.63533456623554, 21.32086683064699, 19.830641895532608, 38.99489834904671, 54.34466488659382, 69.14960905909538, 48.197529539465904, 0.9237316797953099, 0.026162000649492256, 0.05997955144266598, 0.0861323309072759, 0.053284466557670385, 0.025542940020386595, 0.05420352368673775, 0.06156962139357347, 0.03638103276898619, 0.14114244666416198, 0.16231976420385763, 0.19268829870270565, 0.20354814565507695, 0.13350545021239668, 0.09740678608068265, 0.10726159438490868, 0.1857177063357085, 0.18633552943356335, 0.311796692549251, 72.79026970267296, 90.58747351169586, 73.26633095741272, 54.797019213438034, 25.2867691218853, 45.37165157496929, 82.26221144199371, 64.01817440986633, 95.13362556695938, 74.79018598794937, 0.6361153756733984, 0.3494172863429412, 1.1945389327593148, 4.551455620676279, 6.239817598834634, 30.345061495900154, 80.18027275800705, 81.54148891568184, 77.4167874455452, 82.92996481060982, 88.64903032779694, 78.38893488049507, 76.77021414041519, 73.94391819834709, 67.80111461877823, 61.75722353160381, 66.81445196270943, 71.03982523083687, 74.94004994630814, 78.02902579307556, 77.86644011735916, 76.57274633646011, 69.05407458543777, 76.24543949961662, 84.15185764431953, 74.28485110402107, 77.78847590088844, 73.81939128041267, 72.98063948750496, 65.24579733610153, 57.22203768789768, 51.20242349803448, 54.50495548546314, 53.583862110972404, 54.362326338887215, 49.90008518099785, 55.24099498987198, 54.72067750990391, 53.99605259299278, 52.39887289702892, 54.17204014956951, 49.611612260341644, 46.77948363125324, 46.400351375341415, 45.19633658230305, 51.089607551693916, 66.17281079292297, 67.49999597668648, 66.57148540019989, 65.14245808124542, 70.08564323186874, 64.04885396361351, 62.39071033895016, 61.573852971196175, 66.87201127409935, 63.456990122795105, 66.54073745012283, 67.17579737305641, 66.16800025105476, 68.54525908827782, 67.25894451141357, 66.55258521437645, 67.35006362199783, 62.423749566078186, 71.97151243686676, 52.81126856803894, 46.751615926623344, 48.40418145060539, 44.27918739616871, 39.07014571130276, 56.59563370049, 62.09429584443569, 64.77016925811768, 66.51802986860275, 64.26498636603355, 60.731229186058044, 57.31943406164646, 53.141622841358185, 55.38468427956104, 59.6224220842123, 55.556514859199524, 56.45754911005497, 56.43084794282913, 56.271385699510574, 61.571478098630905, 62.40796521306038, 60.27565263211727, 60.381267964839935, 55.83698160946369, 51.057263687253, 49.41840022802353, 46.34051598608494, 47.03745938837528, 48.81512559950352, 47.935336008667946, 48.92553247511387, 46.537949591875076, 50.402125641703606, 49.01415511965752, 50.05335755646229, 49.59083117544651, 47.59727194905281, 47.21660457551479, 52.09441423416138, 50.75649082660675, 52.693440690636635, 63.388612791895866, 68.20409059524536, 65.3924010694027, 64.51888114213943, 70.83805605769157, 63.338360488414764, 65.61402037739754, 68.63445550203323, 67.35379502177238, 69.08940508961678, 71.1047713458538, 71.70342162251472, 69.90056276321411, 68.80359962582588, 72.00095325708389, 71.50688096880913, 72.13851347565651, 74.26020562648773, 72.92014673352242, 75.73624402284622, 72.51074150204659, 77.9276168346405, 73.78409877419472, 36.37419417500496, 1.6304029757156968, 8.329648934304714, 4.630577825009823, 1.21103456011042, 0.473221322754398, 9.661283679306507, 84.18856367468834, 72.69362568855286, 81.33297890424728, 65.98594442009926, 81.55619412660599, 46.927527487277985, 22.919463850557804, 42.56297528743744, 63.62327300012112, 76.08676761388779, 58.85506086051464, 1.339782695285976, 0.2788019645959139, 0.12829934363253415, 0.27112848416436464, 0.19626893859822303, 0.15768980170832947, 0.1827772578690201, 0.19965246407082304, 0.09967251840862446], [0.036204427597112954, 0.09952673834050074, 0.037328718244680203, 0.07402579460176639, 0.07842857827199623, 0.09720901114633307, 0.10306687923730351, 0.1951478503178805, 0.08781746626482345, 2.5200824858620763, 68.83257687091827, 61.487012431025505, 51.24678231775761, 37.43279457092285, 27.65123214572668, 33.96895743906498, 57.766985446214676, 51.95944167673588, 86.53961911797523, 31.48368939757347, 0.10685730943805538, 0.1161609023984056, 0.14349633129313588, 0.46089980110991746, 2.2934555215761065, 44.16877672076225, 80.72821855545044, 79.30250465869904, 72.30097755789757, 75.7357956469059, 74.98107254505157, 74.47981864213943, 67.05681815743446, 64.24863204360008, 63.38154137134552, 68.56763228774071, 70.50385639071465, 70.40008395910263, 72.83160388469696, 74.33336690068245, 70.83373188972473, 71.5529116988182, 65.42440295219421, 70.16790121793747, 57.45962753891945, 62.87359602749348, 71.8526092171669, 66.11431673169136, 69.20900747179985, 65.62428742647171, 57.26962633430958, 49.89679075777531, 49.78473477065563, 50.678177028894424, 51.82496689260006, 45.53234115242958, 45.957348346710205, 46.89625896513462, 50.29411643743515, 46.69471777975559, 45.07254682481289, 43.806257173419, 45.606596767902374, 42.56617471575737, 39.553776159882545, 43.19567173719406, 51.65554538369179, 59.721440970897675, 62.91781805455685, 59.43041078746319, 62.67113149166107, 56.94961130619049, 44.33660991489887, 42.79754810035229, 59.27691042423248, 58.39104115962982, 59.685631692409515, 63.40306721627712, 58.02227474749088, 57.6332326233387, 59.77712698280811, 59.33780215680599, 55.930403396487236, 52.62645408511162, 62.814501598477364, 46.81705981492996, 39.15771201252937, 43.078049048781395, 39.59317624568939, 36.87735177576542, 53.613207936286926, 59.368082731962204, 54.311082288622856, 57.28097252547741, 59.563787430524826, 40.04395745694637, 38.355392664670944, 43.62290181219578, 49.22386206686497, 54.98943328857422, 49.921614825725555, 52.50104941427708, 54.159018248319626, 59.73478965461254, 56.51741109788418, 55.66023029386997, 53.49703297019005, 53.33045370876789, 49.70889464020729, 47.754750698804855, 41.74089699983597, 36.76270812749863, 37.56851188838482, 37.387880980968475, 39.35156241059303, 39.37787599861622, 40.82687124609947, 41.814069673419, 44.973113760352135, 46.20479106903076, 44.89156253635883, 41.85842089354992, 46.75149813294411, 44.91078570485115, 46.853876039385796, 45.450417548418045, 49.55327019095421, 57.37963803112507, 63.11844728887081, 57.943615168333054, 54.881450682878494, 69.82009068131447, 60.2858816832304, 61.569532603025436, 60.36246657371521, 63.21693040430546, 64.56377193331718, 64.06181886792183, 65.2232113480568, 64.51823517680168, 63.87091711163521, 65.12321591377258, 67.8353887796402, 64.5366033911705, 64.8726649582386, 68.14411461353302, 70.81769675016403, 64.67830538749695, 64.49741989374161, 57.589675560593605, 2.1261452743783593, 0.9361676999833435, 0.5984394473489374, 0.8732597006019205, 0.09956986454199068, 0.041412229984416626, 45.11187091469765, 70.36463186144829, 62.006661146879196, 47.49940440058708, 63.609893918037415, 41.124896854162216, 14.471032340079546, 27.492457665503025, 38.57004314661026, 53.306978568434715, 65.18167957663536, 3.5124044632539153, 0.14630458841565996, 0.03128754338831641, 0.04811241713468917, 0.08774203437496908, 0.05152974743396044, 0.055515766944154166, 0.02170960811781697, 0.055739992021699436, 0.01840077053202549, 0.051409961088211276, 0.08622469118563458, 0.07512799522373825, 0.033273693843511865, 0.019557626619643997, 0.04123244470974896, 0.12493604910559952, 0.13682106917258352, 3.621476422995329, 81.2979219853878, 67.28579387068748, 62.468647956848145, 48.637549728155136, 35.64247123897076, 30.646341629326344, 61.68361008167267, 61.946248188614845, 92.78664350509644, 32.09963634610176, 0.0625086051877588, 0.19054519885685295, 1.842013264540583, 1.1210118094459176, 3.6098205484449863, 49.56520915031433, 81.35666683316231, 82.31312870979309, 74.60810735821724, 77.7375054359436, 77.80062764883041, 77.36806645989418, 69.83060851693153, 66.38784885406494, 64.87045347690582, 71.1306631565094, 73.3145123720169, 71.83703005313873, 73.169154971838, 76.26047909259796, 72.64232844114304, 70.754384547472, 65.7269275188446, 71.81622236967087, 60.12967586517334, 63.83462905883789, 73.4769156575203, 70.27579262852669, 71.72245100140572, 67.4803814291954, 58.9938560128212, 53.37499491870403, 53.42506863176823, 51.6540102660656, 53.68846669793129, 48.691126853227615, 49.60156559944153, 50.59081591665745, 51.794728115200996, 50.12766636908054, 46.99163004755974, 47.061515897512436, 47.6670628041029, 45.71350783109665, 44.01641249656677, 47.076848074793816, 55.045666471123695, 61.36285029351711, 64.72753554582596, 61.11313149333, 64.42802041769028, 58.011095747351646, 46.350855231285095, 47.85087414085865, 62.729386165738106, 63.167381063103676, 60.47924570739269, 65.18704488873482, 60.67984074354172, 63.832257986068726, 63.46230983734131, 61.92996986210346, 60.09635165333748, 55.83596706390381, 64.57211628556252, 47.894397005438805, 40.99147841334343, 43.03918853402138, 42.30589248239994, 39.66407664120197, 56.28138296306133, 60.88090315461159, 55.75549118220806, 60.026632994413376, 61.436908319592476, 44.9880051612854, 41.11045382916927, 46.17462068796158, 49.38246935606003, 56.43555209040642, 51.045434921979904, 53.07907819747925, 53.97809095680714, 61.377893686294556, 58.330366015434265, 56.69239170849323, 55.62596373260021, 55.5960251390934, 50.22973269224167, 49.124808982014656, 44.476526007056236, 41.00555665791035, 39.3143168091774, 41.995259150862694, 41.74559734761715, 42.54506304860115, 42.19382889568806, 44.06363256275654, 47.660242170095444, 48.28177101910114, 46.833201348781586, 44.004967510700226, 48.28615218400955, 47.625607028603554, 49.291449040174484, 48.35381515324116, 51.05832003057003, 59.67759892344475, 65.44036969542503, 59.875271916389465, 61.04682885110378, 71.80305227637291, 62.47209817171097, 62.825916185975075, 62.28503800928593, 65.76969042420387, 66.42950981855392, 67.55193918943405, 67.9895769059658, 67.20861241221428, 67.41275265812874, 68.29372778534889, 69.81163993477821, 66.58638820052147, 69.66629773378372, 69.95810687541962, 72.21400782465935, 69.12082180380821, 67.77005508542061, 61.023042127490044, 4.840304721146822, 1.059912987984717, 0.7548200560268015, 1.8498796736821532, 0.4745450470363721, 0.06167670217109844, 46.15617647767067, 77.04245433211327, 68.53382930159569, 56.104760840535164, 59.32273596525192, 33.183303996920586, 18.209219500422478, 34.76697161793709, 47.76443637907505, 59.8771034181118, 75.22507265210152, 5.091851223260164, 0.23350214614765719, 0.09626096943975426, 0.08777405062573962, 0.14084034803090617, 0.035046020420850255, 0.08423267776379362, 0.03552700633008499, 0.05362121606594883, 0.1220550986181479, 0.2413724738289602, 0.22688233730150387, 0.14537432114593685, 0.19537157815648243, 0.1294650201452896, 0.19953992479713634, 0.3304979234235361, 0.3223012882517651, 5.50878812558949, 91.91541865468025, 76.49277582764626, 69.95613858103752, 52.81604491174221, 38.480136170983315, 46.79141879081726, 76.47731825709343, 68.12607318162918, 102.17244386672974, 39.282318726181984, 0.15112074092030525, 0.3528609999921173, 2.8032079059630632, 3.103700294159353, 3.481639176607132, 52.94515438377857, 83.51008728146553, 84.07450899481773, 74.73274067044258, 77.16687485575676, 81.1537729203701, 81.94733753800392, 71.11406564712524, 69.88015025854111, 69.12603512406349, 75.04002258181572, 76.80523306131363, 75.770692974329, 77.57205471396446, 78.56051847338676, 73.23685213923454, 73.17425429821014, 66.79784685373306, 72.10423931479454, 65.1675671339035, 67.66616865992546, 76.4784125983715, 71.3607332110405, 73.78299683332443, 70.68697616457939, 61.77758663892746, 54.51908692717552, 55.94245254993439, 52.73990459740162, 57.95242689549923, 51.67977288365364, 53.41916374862194, 52.91343368589878, 54.35577169060707, 52.08907552063465, 49.63941916823387, 47.94893927872181, 51.27583555877209, 46.55281059443951, 47.73750342428684, 50.48697888851166, 56.950413063168526, 66.55369475483894, 70.2698877453804, 64.67025741934776, 68.30473199486732, 59.20285999774933, 50.09997345507145, 51.458924934268, 65.11117815971375, 65.87319687008858, 64.80008125305176, 69.46898952126503, 63.69385801255703, 65.38968041539192, 65.36226108670235, 65.34292012453079, 61.96754224598408, 58.44258539378643, 65.40908977389336, 51.06354855000973, 42.98391669988632, 44.049197137355804, 44.78227660059929, 40.731697753071785, 61.12600140273571, 63.43293361365795, 59.019322246313095, 62.596891075372696, 65.3521004319191, 46.90345197916031, 43.97476673126221, 50.73322847485542, 54.08005088567734, 58.90531316399574, 52.35192261636257, 55.49690745770931, 55.49572192132473, 64.72089350223541, 60.46488247811794, 60.55078446865082, 56.57903619110584, 58.56788747012615, 52.0553295314312, 53.29252414405346, 46.66542895138264, 44.07694324851036, 42.02344223856926, 44.0493643283844, 44.440260753035545, 46.22749105095863, 45.06933979690075, 47.36197717487812, 49.36957664787769, 50.89348867535591, 49.0546153485775, 46.135763972997665, 52.379520535469055, 50.93814007937908, 50.79966031014919, 50.35326026380062, 54.37259718775749, 62.19470925629139, 70.09454235434532, 63.33845168352127, 65.55774539709091, 69.11235585808754, 65.83775997161865, 68.12433287501335, 64.30251315236092, 68.16786333918571, 70.33366352319717, 70.16071200370789, 72.1178349852562, 72.19465166330338, 69.28859800100327, 70.33556342124939, 72.7996475994587, 70.25186911225319, 72.01188147068024, 77.0411092042923, 76.47724226117134, 74.51362922787666, 67.59537845849991, 61.968252807855606, 4.860719600692391, 5.551347741857171, 7.118499549105763, 2.9439777648076415, 0.49042017955798656, 0.09385696757817641, 57.55988135933876, 84.9948500096798, 75.67660242319107, 64.16462615132332, 84.71168160438538, 57.083155140280724, 23.806501552462578, 39.0989101678133, 55.1726670563221, 67.1500651538372, 88.80213171243668, 7.39908124320209, 0.6778065604157746, 0.3494173160288483, 0.187467037467286, 0.2861536497948691, 0.11516117010614835, 0.24323394347447902, 0.06628071918385103, 0.2774834947194904], [0.0434666543151252, 0.049093476991401985, 0.033733758609741926, 0.05096434222650714, 0.04996348186978139, 0.03616971735027619, 0.07644104000064544, 0.1321578584611416, 0.5144903145264834, 9.817188363522291, 78.55324566364288, 51.57699979841709, 42.224569246172905, 24.738846123218536, 32.024085000157356, 44.630071967840195, 46.31463177502155, 58.362162709236145, 81.10589548945427, 12.167639639228582, 0.19850715209031478, 0.3033155179582536, 1.132468432188034, 0.9465110418386757, 8.536769170314074, 59.119796454906464, 77.91112571954727, 81.2755411863327, 69.60300073027611, 74.2194414138794, 78.30250471830368, 75.42507112026215, 71.5538540482521, 74.59055989980698, 72.01463252305984, 71.32877692580223, 73.6896738409996, 80.70519179105759, 77.57624968886375, 75.28010129928589, 69.46755319833755, 68.51155489683151, 72.13362693786621, 68.54587465524673, 68.13339918851852, 68.73033195734024, 69.5940712094307, 68.69109526276588, 66.91625609993935, 66.70142322778702, 59.991165697574615, 51.69677697122097, 47.73840397596359, 50.011996775865555, 47.300891652703285, 46.28160774707794, 45.76955862343311, 49.004473239183426, 50.719150230288506, 46.948133781552315, 45.02550534904003, 43.31922970712185, 45.2286272495985, 41.894587352871895, 42.49954529106617, 40.77805906534195, 44.484851360321045, 49.35024328529835, 55.54151326417923, 57.615297585725784, 60.04709869623184, 63.39771710336208, 55.27446359395981, 60.79675666987896, 63.060610592365265, 59.207856729626656, 62.383787110447884, 55.20270824432373, 55.86269862949848, 58.55454258620739, 61.76208347082138, 55.922169238328934, 50.793462842702866, 56.31670966744423, 62.713316828012466, 50.69138512015343, 44.81504984200001, 47.56529286503792, 40.45158438384533, 36.150446981191635, 46.44358545541763, 60.466729179024696, 53.34029518067837, 53.78365159034729, 60.47661244869232, 57.59794011712074, 40.721810683608055, 49.101045057177544, 56.43058195710182, 55.02876877784729, 53.558110892772675, 51.0687542706728, 52.81326346099377, 60.038560554385185, 53.98990072309971, 55.83257004618645, 54.32723142206669, 51.373581513762474, 47.36369468271732, 45.78441582620144, 39.32094365358353, 36.03694327175617, 36.93733535706997, 40.790822580456734, 39.69472959637642, 38.89308661222458, 39.41768266260624, 45.78349247574806, 42.23968483507633, 45.18177956342697, 43.685602247714996, 43.77229459583759, 42.24577210843563, 48.46092380583286, 46.904785707592964, 49.359169006347656, 46.541825383901596, 53.54201875627041, 58.06678555905819, 64.07434299588203, 56.30417414009571, 56.43479973077774, 71.1648765206337, 63.54432463645935, 60.888840928673744, 61.998119205236435, 63.756178468465805, 63.51554878056049, 66.92439526319504, 64.46987897157669, 66.83737993240356, 61.20984770357609, 61.73638924956322, 65.59904918074608, 71.46442204713821, 68.2640589773655, 66.28188773989677, 61.797964945435524, 56.96824170649052, 63.669406324625015, 41.28087468445301, 0.2975170884747058, 0.43084044533316046, 3.8096921984106302, 0.8341454900801182, 0.6157291727140546, 12.705994751304388, 66.94862276315689, 66.72514915466309, 56.87348999083042, 48.159919157624245, 46.98141239583492, 23.932158909738064, 21.69263318181038, 44.63663801550865, 47.76892013847828, 70.31479373574257, 14.168395679444075, 0.20976214815163985, 0.2232702897163108, 0.09462019224883988, 0.1136967568891123, 0.038570717224502005, 0.044419174882932566, 0.010096638052345952, 0.07057215843815356, 0.04957909390213899, 0.04271337442332879, 0.024599757525720634, 0.0441062000754755, 0.047710384606034495, 0.08497742295730859, 0.07289138477062806, 0.1491452328627929, 0.549117618938908, 12.438511904329062, 88.39726343750954, 59.890630692243576, 51.267096027731895, 34.76339600980282, 25.903559625148773, 30.85912261158228, 58.52583512663841, 62.975115180015564, 91.7846828699112, 12.171387188136578, 0.20615259418264031, 0.1794583586161025, 1.7396868928335607, 1.1737443110905588, 9.646787457168102, 63.90388414263725, 77.68028050661087, 80.95492959022522, 70.21985203027725, 74.81186002492905, 80.27787432074547, 77.12937846779823, 75.0232806801796, 75.40311589837074, 75.05496338009834, 76.06086820363998, 74.19335201382637, 79.52444314956665, 78.8254402577877, 75.6539860367775, 70.41013821959496, 71.53915643692017, 70.65625861287117, 68.677127212286, 70.613754093647, 71.7594002187252, 70.26332169771194, 71.76166489720345, 68.37592497467995, 69.781104773283, 63.46272021532059, 53.786357045173645, 50.68404771387577, 51.88198283314705, 48.85336674749851, 49.86932583153248, 48.50330293178558, 50.574032217264175, 51.3738588988781, 48.7881850451231, 48.848240822553635, 46.22339107096195, 45.03919221460819, 44.23590391874313, 45.596846491098404, 46.06571093201637, 46.92790366709232, 51.48750700056553, 57.172647938132286, 62.93950729072094, 63.82810860872269, 64.62459146976471, 61.74363926053047, 64.85571026802063, 64.40452247858047, 61.47624380886555, 62.42120750248432, 57.90230378508568, 57.590610310435295, 62.23764695227146, 63.109369575977325, 59.02835056185722, 53.75631965696812, 58.072568848729134, 63.57112839818001, 54.12253260612488, 44.57664683461189, 48.08701626956463, 42.73047789931297, 38.115484938025475, 49.30663302540779, 64.02241498231888, 56.64915382862091, 57.04567775130272, 61.21118903160095, 62.68134914338589, 45.91723009943962, 51.62136621773243, 57.69819013774395, 58.563893884420395, 57.48285949230194, 54.2476636916399, 54.494008272886276, 62.17164069414139, 56.81468054652214, 56.66971832513809, 55.780756026506424, 53.61653655767441, 49.22590635716915, 49.22546178102493, 41.5444665402174, 40.57476997375488, 39.6592964977026, 42.7496250718832, 42.423017397522926, 42.11974427103996, 41.62085384130478, 48.43460641801357, 44.955619499087334, 46.712265238165855, 47.56693057715893, 45.98261699080467, 46.767445877194405, 48.79602022469044, 49.855429977178574, 51.288378685712814, 48.340565264225006, 52.880474254488945, 60.93273237347603, 66.30949705839157, 57.88965046405792, 60.87235361337662, 72.81534075737, 65.2992756664753, 62.44932599365711, 64.25712838768959, 64.24209639430046, 63.87531727552414, 68.44558283686638, 65.78467682003975, 69.50955614447594, 65.84778383374214, 67.42753386497498, 70.70306450128555, 75.41821628808975, 69.15741384029388, 68.59855502843857, 64.31593403220177, 59.261160269379616, 65.77452376484871, 49.49785016477108, 0.43215784651692957, 0.7897396478801966, 1.1063551646657288, 1.3039101264439523, 0.5449694884009659, 12.632308155298233, 75.42086094617844, 72.66534760594368, 65.159762352705, 53.36937502026558, 46.216190457344055, 28.07234074920416, 33.09494733810425, 49.398656487464905, 53.60813520848751, 79.04154226183891, 17.728868275880814, 0.502693431917578, 0.07163820904679596, 0.09799870080314577, 0.11174953207955696, 0.028947980354132596, 0.09392417647177354, 0.043298164528096095, 0.05911683816520963, 0.1221022621029988, 0.10910184602835216, 0.1819489468471147, 0.12915328843519092, 0.19562433881219476, 0.2778882026905194, 0.17975515831494704, 0.32858855556696653, 0.8053786586970091, 15.310776829719543, 103.38368967175484, 67.16930732131004, 59.2499964684248, 35.85416927933693, 46.30982123315334, 62.88835443556309, 67.67988592386246, 70.10477900505066, 97.51108959317207, 16.084441915154457, 0.22694865561788902, 0.5114303505979478, 2.799729905091226, 4.316769763827324, 13.174783196300268, 66.41883999109268, 81.55923396348953, 83.68991643190384, 71.83145955204964, 76.42634019255638, 82.81787842512131, 81.39248371124268, 78.69899064302444, 79.53945994377136, 77.97886088490486, 79.47618573904037, 79.4411288201809, 81.88283979892731, 77.40194544196129, 77.48807922005653, 70.32423242926598, 73.17735493183136, 74.00350660085678, 72.6254041492939, 74.47050154209137, 76.00259453058243, 75.14276146888733, 75.17829716205597, 71.35906130075455, 73.9453849196434, 66.2588457763195, 57.47248984873295, 52.042721807956696, 55.08206471800804, 50.44780299067497, 51.68897598981857, 50.74368171393871, 53.068571761250496, 54.61290769279003, 52.20187246799469, 50.353305861353874, 48.34463104605675, 50.09048156440258, 46.003344878554344, 48.24667990207672, 47.98033319413662, 50.822599679231644, 53.731674179434776, 59.985986575484276, 64.3315663933754, 67.72510349750519, 67.1744978427887, 63.523611947894096, 65.72324931621552, 66.91537454724312, 65.13013914227486, 67.61677131056786, 62.312202751636505, 61.79326839745045, 65.3971204161644, 65.81762105226517, 63.69274087250233, 54.84782248735428, 60.74953280389309, 67.43426710367203, 56.36364854872227, 47.23053462803364, 49.36059772968292, 43.22553813457489, 40.77917620539665, 52.65599749982357, 65.65588653087616, 59.46719281375408, 59.01757054030895, 66.38835042715073, 61.89155772328377, 43.57975132763386, 52.80199706554413, 58.9135967195034, 59.45622280240059, 60.037017837166786, 55.207412391901016, 55.04264563322067, 66.34963810443878, 58.6241814494133, 59.25199516117573, 58.98310258984566, 57.154690101742744, 51.97096265852451, 50.44870734214783, 44.54939469695091, 42.483779937028885, 42.396494820714, 46.38307750225067, 46.6195198148489, 43.44521574676037, 45.02159155905247, 51.14864118397236, 46.96286179125309, 49.41486641764641, 50.31421355903149, 47.53671459853649, 47.694725319743156, 52.89305537939072, 52.621639743447304, 53.7859770655632, 50.460505709052086, 56.834048107266426, 64.23661708831787, 71.46971896290779, 61.8078938126564, 67.93616697192192, 70.5518326163292, 64.63886350393295, 66.64311155676842, 70.90448409318924, 68.85271579027176, 67.40408152341843, 70.99811866879463, 67.39528879523277, 73.60655710101128, 69.08795356750488, 71.62012249231339, 74.83386844396591, 81.27529799938202, 73.90404313802719, 72.59006604552269, 65.15733808279037, 62.402113527059555, 66.26333713531494, 47.65303015708923, 0.2693230763543397, 5.026069153100252, 11.492664758116007, 2.333368817344308, 0.5593108688481152, 17.362706623971462, 83.5263580083847, 78.46532598137856, 72.95532524585724, 65.75015187263489, 64.57189589738846, 35.20123891532421, 33.98396663367748, 58.85131426155567, 64.02189061045647, 88.88255819678307, 25.796506069600582, 0.670235704164952, 0.36162478441838175, 0.23329137620748952, 0.2371622552163899, 0.15561687934678048, 0.18280399002833292, 0.12005066906567663, 0.19162698299624026], [0.15307570633012801, 0.001719699957902776, 0.053762914321850985, 0.041846482854452915, 0.08363059561816044, 0.04770891886437312, 0.08952921503805555, 0.27294650848489255, 0.38727017235942185, 18.331398144364357, 73.84782895445824, 54.88259822130203, 41.83245688676834, 28.813544176518917, 44.22822453081608, 62.35412210226059, 48.76267321407795, 69.46598768234253, 71.2467773258686, 2.0707264356315136, 0.029349949800234754, 0.04659443940909114, 2.4352608248591423, 1.431543615180999, 18.279620222747326, 69.60502982139587, 72.47256875038147, 73.62505450844765, 70.41868016123772, 72.70563304424286, 74.77637752890587, 77.75582805275917, 73.59154030680656, 76.17962703108788, 74.09109190106392, 75.55667325854301, 73.37752059102058, 58.311868607997894, 60.88791757822037, 68.41599762439728, 71.00878089666367, 75.38136586546898, 72.49450117349625, 66.07770949602127, 66.14357516169548, 65.01656323671341, 65.59912517666817, 66.59518092870712, 67.0535047352314, 65.36252707242966, 59.0790094435215, 51.85643680393696, 48.35289940237999, 51.39930613338947, 48.84729467332363, 44.34539504349232, 44.723345562815666, 46.546214148402214, 47.99012906849384, 47.677162662148476, 44.1058748960495, 44.27438825368881, 45.24755783379078, 42.63099543750286, 43.29121381044388, 42.14561328291893, 42.68820136785507, 46.836518570780754, 46.895457208156586, 54.586928486824036, 61.85672119259834, 60.74126064777374, 64.16917070746422, 61.6829527169466, 61.09857067465782, 60.0825621932745, 55.96011020243168, 48.82126986980438, 50.1921147108078, 51.56694933772087, 53.38001444935799, 47.95440338551998, 54.69328857958317, 58.82514886558056, 62.556784227490425, 47.18515366315842, 41.366484090685844, 47.71544560790062, 42.60943539440632, 37.728160321712494, 44.9410966783762, 63.17007131874561, 53.979094102978706, 51.453358232975006, 53.751714304089546, 63.30877527594566, 63.84117230772972, 60.18503129482269, 62.092661932110786, 57.60718122124672, 57.573914006352425, 57.542641684412956, 52.709331437945366, 58.323780968785286, 58.20790618658066, 53.835150226950645, 53.44632089138031, 52.24820718169212, 47.9825446754694, 42.930685356259346, 38.04907210171223, 37.78592862188816, 40.30755311250687, 38.32367956638336, 40.309559404850006, 38.53666573762894, 39.91701386868954, 41.47748373448849, 46.3287366181612, 44.53604221343994, 44.68879781663418, 44.79442074894905, 41.32998324930668, 47.054269686341286, 50.780608132481575, 47.619880735874176, 49.06303949654102, 45.903573632240295, 54.66649241745472, 62.34939135611057, 63.7902170419693, 56.64803668856621, 56.04782089591026, 71.29808977246284, 67.72077932953835, 64.56427350640297, 63.62944766879082, 60.23471362888813, 61.886093616485596, 60.62436752021313, 64.97850447893143, 68.64070236682892, 69.36890289187431, 63.27631361782551, 65.22478446364403, 57.06763297319412, 61.045434325933456, 61.868264973163605, 68.07315722107887, 58.981806859374046, 71.36935114860535, 32.053814604878426, 0.4350546863861382, 2.106459243223071, 0.9017935569863766, 0.02536425497964956, 0.4023865330964327, 54.46654714643955, 67.48378604650497, 63.90643000602722, 49.02414858341217, 56.417594254016876, 22.794448658823967, 10.381041057407856, 31.04698833078146, 45.6233386695385, 63.54575715959072, 33.882310688495636, 0.21345198765629902, 0.02024589994107373, 0.032392642096965574, 0.008621716024208581, 0.029518543487938587, 0.052261542150517926, 0.028345616192382295, 0.09067620427231304, 0.07267386128660291, 0.0377374078379944, 0.0478472922986839, 0.08524450706318021, 0.06869427248602733, 0.05444292568427045, 0.11210662385565229, 0.2779130497947335, 0.39017529459670186, 23.314199969172478, 84.48285028338432, 59.941813945770264, 47.40369513630867, 40.92558994889259, 40.57372882962227, 58.33790101110935, 60.373113602399826, 75.9424589574337, 78.66384252905846, 2.1717219287529588, 0.04791174782440066, 0.423191218287684, 0.9537087462376803, 1.5908017382025719, 20.613227002322674, 73.0922394990921, 73.70231196284294, 74.20500978827477, 72.09655612707138, 73.24977904558182, 76.13495662808418, 79.11710500717163, 77.35870376229286, 79.63924258947372, 77.03972607851028, 78.3726641535759, 78.03602501749992, 62.95669376850128, 62.69359588623047, 70.81661760807037, 74.69376236200333, 76.50824099779129, 74.16682943701744, 70.89567616581917, 68.49196314811707, 68.05376306176186, 68.83677944540977, 68.82058471441269, 70.50006419420242, 68.61706003546715, 62.1122270822525, 53.075532987713814, 51.13764837384224, 55.54425671696663, 50.94420075416565, 48.83599027991295, 48.12787927687168, 48.96048679947853, 50.5381203442812, 48.66428889334202, 47.30392388999462, 45.470450073480606, 48.350083753466606, 47.865233570337296, 45.22809527814388, 44.35765698552132, 45.030832663178444, 48.51723298430443, 48.762137442827225, 55.80727480351925, 63.851697742938995, 64.14442643523216, 65.14488995075226, 62.32945002615452, 62.00176700949669, 61.89677104353905, 58.28154243528843, 51.80463798344135, 54.47231903672218, 52.56848059594631, 54.94656398892403, 50.98255969583988, 59.11758117377758, 59.97421860694885, 64.83871757984161, 49.04760852456093, 39.92657035589218, 44.481986314058304, 44.87321712076664, 41.27925217151642, 46.9700738042593, 62.92965441942215, 55.29162347316742, 54.62321273982525, 55.92827931046486, 61.43896020948887, 65.15086323022842, 61.53750032186508, 62.347130477428436, 59.87616866827011, 58.39134134352207, 58.984421119093895, 55.92621222138405, 60.88624186813831, 60.08343234658241, 56.11786253750324, 53.95680829882622, 54.34274218976498, 50.43982721865177, 45.34436143934727, 40.710095912218094, 41.12422429025173, 42.86437511444092, 40.16412980854511, 41.643994599580765, 40.89183636009693, 43.666382879018784, 46.263782903552055, 48.26491132378578, 46.856509298086166, 46.82105340063572, 47.01524578034878, 43.97497572004795, 47.95970030128956, 52.846515476703644, 49.10341992974281, 51.10917270183563, 49.23852548003197, 55.83344779908657, 65.07875069975853, 65.52208811044693, 59.75440800189972, 61.432173773646355, 70.24490028619766, 67.79549092054367, 66.0866542160511, 64.66052994132042, 61.85322917997837, 65.18388345837593, 66.09523415565491, 69.0672142803669, 70.81469491124153, 68.16078051924706, 64.15366753935814, 64.80669289827347, 58.67202088236809, 61.28876946866512, 62.479393780231476, 70.3685000538826, 62.51461789011955, 73.18557769060135, 39.8807942122221, 0.28357020404655486, 0.7063460571225733, 1.0995594668202102, 0.1034476603672374, 0.5153489497024566, 56.82959854602814, 73.09708803892136, 68.47669556736946, 57.54857316613197, 52.43336744606495, 24.049285724759102, 21.213853172957897, 35.73414131999016, 51.772765293717384, 70.13111919164658, 40.674123242497444, 0.3570755082182586, 0.0715090827725362, 0.05914404900977388, 0.05332486536644865, 0.054374076644307934, 0.11169108052854426, 0.024418064931523986, 0.0540635731886141, 0.29215584334451705, 0.13548026065109298, 0.16507206339156255, 0.14305009273812175, 0.2189145507873036, 0.20025801204610616, 0.18884404795244336, 0.49949115375056863, 0.5995274358429015, 28.519669845700264, 95.74978530406952, 68.83845135569572, 58.199672028422356, 42.121332585811615, 60.988836362957954, 82.8153857588768, 66.68776676058769, 81.52499780058861, 85.68325906991959, 3.187818042933941, 0.1012513782188762, 1.4662416907958686, 5.822580512613058, 3.846957036294043, 21.97757989168167, 75.70022955536842, 76.27005457878113, 75.92046573758125, 71.41700059175491, 74.72454071044922, 77.84066990017891, 83.5608221590519, 80.03697484731674, 81.5631477534771, 80.97822993993759, 81.82983264327049, 76.62400558590889, 62.4674092233181, 65.75416445732117, 72.97830641269684, 76.14342257380486, 79.70913603901863, 77.56862729787827, 71.35765537619591, 75.77402919530869, 71.53330475091934, 73.22573393583298, 72.93292164802551, 72.12240993976593, 71.10183790326118, 63.35642471909523, 56.758310571312904, 53.742416203022, 58.33268769085407, 54.28961344063282, 51.11140318214893, 50.75351178646088, 52.40491457283497, 53.336107805371284, 51.19854390621185, 49.314061626791954, 48.372042775154114, 51.36650629341602, 50.30785650014877, 49.46194589138031, 48.01113814115524, 48.21424104273319, 53.28391760587692, 52.28607974946499, 59.2733234167099, 68.10733258724213, 68.58044520020485, 68.58608409762383, 65.14952570199966, 65.08619830012321, 65.71086958050728, 62.01324239373207, 54.42853018641472, 56.56400419771671, 57.38759480416775, 59.24244627356529, 55.176584646105766, 60.365703999996185, 63.430999517440796, 68.58359143137932, 54.69489969313145, 40.2764517813921, 46.865966990590096, 45.63759930431843, 42.32800729572773, 49.53870177268982, 65.4904206097126, 57.438116893172264, 57.465935200452805, 60.11865645647049, 69.7468838095665, 68.58617529273033, 61.29234127700329, 67.88128271698952, 63.73722888529301, 62.19550721347332, 61.435905173420906, 56.981746181845665, 63.82379204034805, 63.38205814361572, 57.05995358526707, 58.90958033502102, 56.66477479040623, 52.10799090564251, 48.624660819768906, 43.310915753245354, 43.37665222585201, 46.196629106998444, 42.08884812891483, 45.76655678451061, 42.77867451310158, 45.6185357272625, 48.01390819251537, 50.29357306659222, 50.455539375543594, 50.084679275751114, 51.33067041635513, 47.38496974110603, 50.85147053003311, 55.69562539458275, 51.69610820710659, 53.790191039443016, 52.78544895350933, 57.89836339652538, 67.90640696883202, 66.72649428248405, 63.7798435986042, 67.15543046593666, 74.62023630738258, 67.28041335940361, 67.86068022251129, 68.16614583134651, 65.9721739590168, 69.3772092461586, 68.36940452456474, 73.33636119961739, 74.4951394200325, 70.00813499093056, 66.60804703831673, 68.41605842113495, 60.16609691083431, 62.81915634870529, 63.56963887810707, 70.82490116357803, 64.78900104761124, 76.71487390995026, 39.13236357271671, 0.5522506695706397, 8.739501591771841, 3.3366914419457316, 0.2511745970696211, 0.8130293106660247, 66.02274924516678, 77.70236492156982, 78.65970835089684, 64.75996300578117, 75.65118938684464, 32.62324444949627, 20.06899930536747, 45.616271048784256, 62.586540430784225, 80.14019250869751, 52.24557012319565, 0.7050782907754183, 0.20973494101781398, 0.3787667927099392, 0.14278329064836726, 0.1949314697412774, 0.1781543012475595, 0.12813568522688001, 0.20317879359936342], [0.046112581476336345, 0.06737335352227092, 0.09972453553928062, 0.1493661999120377, 0.06693223578622565, 0.050351231766398996, 0.12179682380519807, 0.144394374510739, 0.15107964078197256, 30.635909289121628, 69.49049636721611, 59.0384466201067, 38.084657192230225, 27.213402539491653, 45.866742208600044, 58.59904959797859, 48.19601722061634, 77.82382920384407, 47.66655743122101, 0.13356808747630566, 0.09516538877505809, 0.3556314669549465, 0.8466141053941101, 4.444787744432688, 40.32839119434357, 74.56111907958984, 73.27047273516655, 71.88352435827255, 71.3934114575386, 70.2150870859623, 67.59765833616257, 70.65409272909164, 70.55649116635323, 73.47013682126999, 72.41467505693436, 63.044153675436974, 46.61973640322685, 58.45586188137531, 69.07423630356789, 71.33926436305046, 71.89628407359123, 71.2471117079258, 66.99231281876564, 62.85636015236378, 61.25657379627228, 64.45062160491943, 64.37610760331154, 65.87489157915115, 65.02052262425423, 65.08317366242409, 60.3025171905756, 48.17438878118992, 49.718245938420296, 47.57562071084976, 46.954240053892136, 46.25034682452679, 45.71198031306267, 46.18992246687412, 48.49970072507858, 46.888784766197205, 44.78217400610447, 43.24808992445469, 41.379680782556534, 40.80919459462166, 43.53651724755764, 43.00760082900524, 42.03038066625595, 42.383921295404434, 46.52254901826382, 47.730602994561195, 55.87279088795185, 59.97011862695217, 63.78542169928551, 59.07821148633957, 60.431193485856056, 50.366855934262276, 50.357003062963486, 47.1150778234005, 49.00115601718426, 47.65310235321522, 47.38590449094772, 48.45274284482002, 60.15046834945679, 52.857063710689545, 62.478637620806694, 32.19521261751652, 30.49533773213625, 60.098354145884514, 47.05525383353233, 44.25956904888153, 46.28775201737881, 62.36650563776493, 54.989858865737915, 50.73298528790474, 51.80040121078491, 57.29051761329174, 52.913532480597496, 60.531272515654564, 53.381701558828354, 53.96042190492153, 56.950618252158165, 62.111733108758926, 54.52916398644447, 55.44317074120045, 55.38904644548893, 52.93896831572056, 52.75167636573315, 53.538104966282845, 43.88905473053455, 41.279685348272324, 36.59156911075115, 38.654983788728714, 38.23716960847378, 37.56224982440472, 38.45853053033352, 41.40470623970032, 39.29011210799217, 47.142345160245895, 45.25905221700668, 48.51513929665089, 47.33155220746994, 45.804254561662674, 43.04774567484856, 45.14245547354221, 44.538728669285774, 47.02710874378681, 45.574021115899086, 48.037637919187546, 48.34822565317154, 59.13235858082771, 62.709148451685905, 66.10761389136314, 60.85796758532524, 57.127996534109116, 58.95096391439438, 66.86865985393524, 65.84184855222702, 66.21105954051018, 68.8661290705204, 73.38676929473877, 68.26905950903893, 66.81107014417648, 60.909705609083176, 61.147101670503616, 62.243840619921684, 69.22973155975342, 66.05119451880455, 71.31698235869408, 66.45570561289787, 75.24119138717651, 61.77178435027599, 77.2616645693779, 22.848253771662712, 0.3733146790182218, 2.233047313056886, 0.4013729374855757, 0.4838727746391669, 22.43794608861208, 70.19620969891548, 66.42610520124435, 51.93349666893482, 51.43652133643627, 46.99134886264801, 18.546666093170643, 16.091642528772354, 46.65676161646843, 52.6120300590992, 60.1554536819458, 1.4571304921992123, 0.12423815569491126, 0.07237415236886591, 0.04131514593609609, 0.04590762997395359, 0.031112370561459102, 0.06440346405724995, 0.03539758690749295, 0.033068601333070546, 0.005571832780333352, 0.09816263380344026, 0.15012982534244657, 0.03462850669166073, 0.038618467006017454, 0.03153034813294653, 0.16758142795879394, 0.13879273290513083, 36.910037621855736, 81.22824132442474, 65.73632061481476, 38.90691787004471, 25.64907018095255, 38.63178603351116, 61.50025472044945, 56.693071871995926, 85.88325753808022, 52.18845158815384, 0.027697648911271244, 0.1522606797516346, 0.7058477494865656, 1.4232817897573113, 5.422711819410324, 43.313685804605484, 75.77174931764603, 73.66158574819565, 73.81170809268951, 72.37391844391823, 72.90653586387634, 66.82734847068787, 70.35350605845451, 73.29138681292534, 75.35053431987762, 73.18148910999298, 65.25646716356277, 51.566162779927254, 61.76672302186489, 72.59331867098808, 71.55288130044937, 74.51109856367111, 73.45193579792976, 70.12826174497604, 64.25304740667343, 63.273866549134254, 65.59656411409378, 67.69472792744637, 67.9527036845684, 66.05202287435532, 66.3301907479763, 62.880618050694466, 50.86840242147446, 51.60319559276104, 49.94521915912628, 49.87166650593281, 47.707424238324165, 46.647573709487915, 50.13450600206852, 51.06130287051201, 47.67334386706352, 48.74946512281895, 45.56550197303295, 45.591420382261276, 44.41308841109276, 46.26807667315006, 43.78078334033489, 44.9930664896965, 44.34015512466431, 50.12974105775356, 49.99421752989292, 57.682827562093735, 61.71334728598595, 65.30299946665764, 61.723903119564056, 61.023866683244705, 53.26585337519646, 50.765180960297585, 50.916234254837036, 52.272605672478676, 49.656221866607666, 49.655499905347824, 51.33240692317486, 62.21934713423252, 57.79346622526646, 63.48536320030689, 36.74281619489193, 27.434942051768303, 50.89144058525562, 47.10357964038849, 45.95230981707573, 47.96085923910141, 63.946616649627686, 57.56568744778633, 55.10467730462551, 53.51871460676193, 59.576075971126556, 55.57803690433502, 62.38075867295265, 55.43235272169113, 54.87861983478069, 58.28299395740032, 62.87746421992779, 56.3089656829834, 58.859138041734695, 57.28269383311272, 56.00946195423603, 56.27311460673809, 54.640847593545914, 47.39152438938618, 44.53778252005577, 38.96861895918846, 41.25463329255581, 40.65974101424217, 40.22365741431713, 40.86206115782261, 44.30187977850437, 42.8038215637207, 48.389039263129234, 46.8162352591753, 50.35751223564148, 50.4812715947628, 47.05081187188625, 45.94409465789795, 47.864025235176086, 48.25101926922798, 49.41893979907036, 47.61918917298317, 49.557400569319725, 50.22403299808502, 62.01839491724968, 63.292569145560265, 66.88391223549843, 61.89841255545616, 62.89850369095802, 62.627392038702965, 70.46277299523354, 66.89287975430489, 68.18360969424248, 70.8896952867508, 72.43277728557587, 68.67734000086784, 69.50589314103127, 64.73658666014671, 64.84232738614082, 66.95450484752655, 74.04962852597237, 68.03148105740547, 73.15760359168053, 67.16254368424416, 76.5787348151207, 65.3096491098404, 81.5475381910801, 30.658888556063175, 0.25290308869443834, 1.491040347609669, 0.43831541610416025, 0.4147398780332878, 24.369428046047688, 76.9006459414959, 71.907227486372, 59.99726057052612, 56.41074322164059, 35.27611769735813, 19.406178072094917, 28.05598832666874, 52.84274607896805, 61.467838659882545, 66.4385837316513, 1.4798006694763899, 0.13121585041517392, 0.07744533650111407, 0.048628547447151504, 0.051754406667896546, 0.08782642398728058, 0.0842306442791596, 0.04098059318494052, 0.14840427262242883, 0.2156801227829419, 0.1621316297678277, 0.26494455349165946, 0.21597195009235293, 0.14154893578961492, 0.19267731491709128, 0.2280173185863532, 0.2383193079731427, 45.12909919023514, 90.70029705762863, 72.2528949379921, 52.739395424723625, 36.89823545515537, 64.11623194813728, 73.87639582157135, 62.744281366467476, 89.7458566725254, 59.40891534090042, 0.28363500838167965, 0.22215947275981307, 1.7870854306966066, 5.174153381958604, 6.427756464108825, 45.62515877187252, 78.64068657159805, 77.14371129870415, 75.95296919345856, 76.24368399381638, 75.26443094015121, 68.31435307860374, 72.29632660746574, 74.61003005504608, 78.63462209701538, 75.27716025710106, 63.657322973012924, 50.21067291498184, 66.58883526921272, 74.78071689605713, 76.49964585900307, 76.68330520391464, 77.73195013403893, 70.89126840233803, 66.00292950868607, 65.4788388311863, 69.4320099055767, 68.41778352856636, 70.01653254032135, 68.9200709760189, 70.35089939832687, 67.20036685466766, 51.51371419429779, 53.9351000636816, 52.968188747763634, 50.93378931283951, 51.83700084686279, 49.98156040906906, 51.22102349996567, 52.88668692111969, 52.65361502766609, 51.26231208443642, 49.081202521920204, 47.28705279529095, 46.10403187572956, 49.397052973508835, 48.01515832543373, 48.00308637320995, 46.6833183914423, 50.36285474896431, 53.623702973127365, 63.605512753129005, 64.89748522639275, 70.9177453815937, 66.54386848211288, 64.40207540988922, 56.062461510300636, 56.619298830628395, 52.90945149958134, 55.10506868362427, 51.97353512048721, 52.265606448054314, 55.281542614102364, 66.24102473258972, 59.80861209332943, 66.17680817842484, 40.23180417716503, 34.94766712188721, 56.38072483241558, 48.06017071008682, 48.537322506308556, 52.14808635413647, 67.67133638262749, 60.26879400014877, 57.73340284824371, 55.882742553949356, 61.66640840470791, 58.967888206243515, 67.1329128742218, 57.22307503223419, 58.1126718968153, 63.83663535118103, 67.98782140016556, 57.693288400769234, 62.49960109591484, 61.22832991182804, 56.97979688644409, 58.092506378889084, 61.44338317215443, 48.6722494661808, 45.81300929188728, 43.77715453505516, 43.53482633829117, 43.35473880171776, 42.63270154595375, 45.44844165444374, 48.26695941388607, 44.634795114398, 50.43343596160412, 50.2229880541563, 51.73663683235645, 53.292075768113136, 50.236769914627075, 48.21808643639088, 52.360559552907944, 50.149397403001785, 51.53960220515728, 48.963724225759506, 52.96913109719753, 53.56938488781452, 63.817491978406906, 67.76364862918854, 68.67100954055786, 65.38095608353615, 69.47843581438065, 67.00054317712784, 72.88796246051788, 70.59897288680077, 70.9504084289074, 71.8132509291172, 74.99207675457001, 70.87584882974625, 70.27114927768707, 67.22099974751472, 67.6238465309143, 68.89344960451126, 76.53832018375397, 72.38100126385689, 75.83382278680801, 70.09327322244644, 78.52532476186752, 69.25771325826645, 82.07829371094704, 29.086776115000248, 0.36379758501425385, 7.6009477861225605, 1.5406383736990392, 0.59374088072218, 29.988952204585075, 86.2161348760128, 78.15121963620186, 67.81050011515617, 69.47558596730232, 62.11008779704571, 29.900749437510967, 31.690069623291492, 63.94866093993187, 70.7585871219635, 78.54801714420319, 2.8568311035633087, 0.24550501926569268, 0.21321935404557735, 0.17066951928427443, 0.1310676138382405, 0.17163103097118437, 0.15903460298432037, 0.2251608663937077], [0.035555694048525766, 0.04232710511132609, 0.03706057286763098, 0.05255361436866224, 0.11310219269944355, 0.06688677924103104, 0.007806346202414716, 0.046402093284996226, 0.04290230666811112, 40.25279805064201, 64.01200354099274, 50.430654510855675, 48.18890020251274, 42.39050634205341, 66.63447082042694, 60.30006632208824, 52.11845934391022, 88.86795178055763, 22.481220066547394, 0.08601522000390105, 0.11071788001572713, 0.3889142075786367, 0.7824461767449975, 10.910779181867838, 67.90547981858253, 70.60694485902786, 71.31130546331406, 68.65093901753426, 68.39581310749054, 66.08976244926453, 68.36824178695679, 67.25234806537628, 67.7282041311264, 67.77563318610191, 70.18398955464363, 60.8009098470211, 66.95974856615067, 73.14098328351974, 69.10123765468597, 68.09037029743195, 70.81625282764435, 68.50679755210876, 69.8002177476883, 60.91610446572304, 53.49737115204334, 52.965867072343826, 58.52915994822979, 62.44021028280258, 65.93714743852615, 61.41292400658131, 51.61267228424549, 47.522860541939735, 49.615085273981094, 51.153672114014626, 48.67371238768101, 45.44491924345493, 46.61778710782528, 48.36938291788101, 46.582300812006, 44.93619494140148, 45.72363808751106, 44.96875159442425, 42.18055620789528, 45.06914220750332, 42.099217772483826, 40.211809650063515, 40.91046676039696, 40.23542918264866, 42.70974241197109, 45.68556413054466, 47.07070380449295, 49.23637479543686, 55.20177349448204, 54.54345881938934, 49.21807877719402, 48.26092153787613, 49.90295022726059, 48.56315732002258, 47.850775346159935, 48.82358394563198, 50.07345847785473, 52.59176954627037, 60.79283148050308, 57.248571664094925, 61.67590409517288, 37.92134955525398, 7.962751546874642, 43.18040415644646, 55.90602770447731, 40.04426524043083, 38.95762614905834, 57.780980095267296, 56.38544797897339, 49.06846180558205, 51.687357276678085, 57.734261602163315, 57.98679605126381, 59.23965722322464, 54.85362857580185, 51.58817879855633, 52.87545092403889, 57.07548715174198, 56.588273495435715, 54.79575388133526, 55.40933735668659, 53.32646392285824, 53.79481919109821, 46.29396088421345, 44.55154538154602, 38.59915338456631, 38.5292599350214, 39.8388596624136, 38.80831316113472, 40.20902819931507, 39.735132828354836, 39.75341744720936, 41.46992973983288, 48.57947364449501, 48.10668021440506, 48.1986390799284, 48.92789974808693, 45.251388028264046, 41.85204863548279, 45.355259254574776, 45.613140016794205, 46.611376851797104, 46.35009527206421, 45.95817290246487, 45.574860870838165, 52.077930718660355, 58.828910663723946, 62.05117575824261, 63.5808140784502, 62.332406267523766, 61.18845485150814, 59.415804371237755, 65.00450268387794, 66.21029198169708, 67.99745008349419, 65.71686565876007, 61.77479758858681, 61.164911314845085, 69.11930188536644, 68.71330127120018, 68.66385832428932, 70.90098068118095, 69.35976058244705, 68.71293649077415, 68.51136490702629, 67.40175604820251, 70.80992996692657, 69.66975554823875, 73.69513794779778, 12.374357096850872, 0.39149444724898785, 0.6699786835815758, 0.40284995979163796, 3.810676345601678, 59.633958265185356, 62.86159247159958, 60.38273088634014, 46.327452287077904, 61.08125880360603, 32.981683015823364, 17.162305377423763, 37.52581737935543, 52.68167272210121, 70.9029033780098, 6.9341647904366255, 0.25575349980499595, 0.10061270077130757, 0.06384936175891198, 0.03849702938168775, 0.10680916631827131, 0.025221677278750576, 0.05488335322297644, 0.02708271647861693, 0.02288818130182335, 0.0726235807815101, 0.05357595618988853, 0.0796937990526203, 0.07697845881921239, 0.0172428921359824, 0.09546315326588228, 0.07657100490177982, 47.18841768801212, 74.60252165794373, 56.030569821596146, 67.64316469430923, 44.27344210445881, 45.50624795258045, 71.45819038152695, 59.21834036707878, 97.75284022092819, 24.83915314078331, 0.14805562648689374, 0.36289356008637697, 0.4240361088886857, 0.9689366072416306, 14.520453438162804, 70.35642430186272, 69.78099077939987, 73.51615235209465, 69.43105235695839, 70.62938645482063, 66.75454437732697, 70.34974426031113, 67.0294064283371, 68.35040554404259, 66.47221952676773, 67.8805759549141, 62.45031014084816, 69.05757039785385, 75.71348324418068, 72.38541662693024, 70.05557924509048, 72.60189101099968, 71.43599957227707, 69.94590193033218, 63.88252168893814, 55.02571754157543, 56.41050383448601, 60.317442789673805, 64.8559382557869, 67.0673131942749, 63.62233065068722, 56.264603063464165, 49.15682606399059, 52.98676215112209, 52.583558186888695, 51.11190475523472, 48.260549157857895, 50.34968465566635, 50.86267992854118, 48.69653396308422, 47.44649603962898, 47.44995005428791, 47.49987177550793, 45.28728470206261, 45.71237929165363, 44.8395699262619, 45.35352274775505, 44.065730050206184, 44.330986216664314, 44.581510573625565, 47.8379662334919, 49.511673822999, 50.99062666296959, 55.550195798277855, 56.50736063718796, 52.76708073914051, 49.3499469012022, 51.121043264865875, 49.99622002243996, 50.78083612024784, 51.47896125912666, 52.147957161068916, 54.56886425614357, 62.714696153998375, 60.319817662239075, 64.21183481812477, 42.290761694312096, 10.301194991916418, 36.78934849798679, 52.42015175521374, 41.93274490535259, 44.9117736518383, 60.69653704762459, 59.031139612197876, 51.609837636351585, 52.980838268995285, 60.63859775662422, 59.55417014658451, 62.90425278246403, 57.87430688738823, 53.78342740237713, 55.64500451087952, 58.442296609282494, 59.047938510775566, 57.605668902397156, 57.99473002552986, 56.09896995127201, 55.81990532577038, 49.73657235503197, 45.74641406536102, 41.074876338243484, 42.68957309424877, 40.72889730334282, 42.07383133471012, 41.944281086325645, 43.329515755176544, 43.27752314507961, 44.37935382127762, 50.89158117771149, 49.2268905043602, 49.14016015827656, 51.29657484591007, 48.239608481526375, 45.19192881882191, 47.48333886265755, 49.0415820479393, 48.59512880444527, 48.84964294731617, 48.186734318733215, 49.04834568500519, 52.388799637556076, 61.940578892827034, 63.06472197175026, 63.9608658850193, 63.87979343533516, 64.1989155113697, 62.573446333408356, 68.76538887619972, 69.99947905540466, 68.75785008072853, 67.202889919281, 65.03005251288414, 65.21428942680359, 71.68861761689186, 70.73579594492912, 68.73618364334106, 71.76227286458015, 71.38306081295013, 70.24444431066513, 73.54041785001755, 71.31542444229126, 74.7008527815342, 71.34174183011055, 83.75157952308655, 18.431366980075836, 0.3911031276220456, 0.4703380196588114, 0.41723209898918867, 4.28817012347281, 66.32947638630867, 70.2545365691185, 66.05647623538971, 54.806100726127625, 54.136721044778824, 24.748507104814053, 22.642067335546017, 43.53747099637985, 59.74369257688522, 81.4230340719223, 7.7052507642656565, 0.28634844871703535, 0.16864360455656424, 0.15763903880724683, 0.10352723344112746, 0.011052307181671495, 0.0823565581231378, 0.030155996391840745, 0.11025398576748557, 0.11021250713383779, 0.23119151388527825, 0.19429202046012506, 0.14888460544170812, 0.3250992443645373, 0.09202124303556047, 0.22535044059623033, 0.2321221967577003, 56.218245550990105, 83.88493716716766, 66.37980848550797, 68.63019213080406, 60.70965014398098, 99.65376421809196, 79.83803272247314, 67.1854716539383, 101.88382655382156, 30.906023494899273, 0.2792960568331182, 0.6374530226457864, 2.2417208226397634, 4.075756771489978, 15.963857285678387, 75.59822022914886, 77.58374288678169, 76.3513246178627, 74.46952879428864, 73.99771571159363, 67.42314130067825, 70.98130077123642, 68.19930285215378, 68.4208157658577, 70.96655756235123, 70.23692831397057, 62.6652380079031, 73.63827019929886, 74.19389918446541, 73.03746163845062, 71.52163937687874, 77.4661847949028, 74.85442534089088, 75.63664376735687, 66.75280407071114, 58.56213837862015, 60.35009063780308, 66.16047665476799, 66.84879451990128, 72.78529956936836, 66.58359155058861, 59.533978030085564, 51.43527880311012, 56.82666130363941, 58.15513841807842, 52.82544940710068, 51.10778957605362, 52.13169023394585, 53.40518429875374, 51.45375341176987, 48.98395054042339, 50.07510758936405, 50.147296115756035, 47.48820640146732, 50.45448683202267, 47.72850550711155, 46.12878754734993, 46.434188559651375, 45.38103327155113, 48.109583258628845, 51.673001646995544, 52.59183794260025, 54.38187628984451, 61.02347910404205, 61.094071716070175, 56.45899683237076, 53.169216960668564, 55.083679631352425, 53.980739414691925, 54.00694280862808, 52.340204045176506, 53.61739531159401, 57.13262468576431, 66.33736476302147, 62.79747851192951, 68.47702234983444, 42.96450734138489, 14.572555292397738, 48.151798993349075, 55.49639068543911, 44.22378256917, 47.98131734132767, 64.32857975363731, 63.55162404477596, 55.41842646896839, 57.6717359572649, 63.210565745830536, 63.893791884183884, 65.99452435970306, 59.8904787003994, 54.41151849925518, 56.76575057208538, 61.62079945206642, 62.32272058725357, 60.65225802361965, 62.02540174126625, 57.37142287194729, 59.261965826153755, 50.51379404962063, 50.324887186288834, 44.181692227721214, 45.104073733091354, 44.8974522203207, 45.55689163506031, 44.56098407506943, 46.97480455040932, 45.800181180238724, 45.56783884763718, 54.302601143717766, 53.98634411394596, 52.4372698366642, 54.43924181163311, 51.26388140022755, 47.38244667649269, 51.10239006578922, 51.82120129466057, 51.86647966504097, 52.65289306640625, 50.74843905866146, 50.364990234375, 57.28836312890053, 66.201301664114, 67.10668668150902, 67.37372875213623, 63.699109330773354, 66.9072961807251, 63.93006473779678, 72.15615972876549, 72.1108965575695, 70.69594368338585, 69.35881063342094, 69.66289311647415, 65.89904308319092, 76.12710624933243, 74.42972213029861, 72.75160297751427, 77.23738387227058, 76.98249354958534, 73.14519345760345, 75.9558342397213, 73.92194777727127, 76.60714969038963, 74.43824887275696, 86.70120924711227, 19.814139381051064, 0.9340155904646963, 1.7507717292755842, 0.4757814353797585, 6.113362284377217, 75.48861891031265, 75.81209555268288, 75.84621012210846, 63.893389105796814, 81.19564667344093, 47.83423863351345, 29.277041405439377, 53.48926618695259, 68.07267844676971, 89.76829826831818, 11.275994684547186, 0.867504671914503, 0.4615877423202619, 0.29867843084502965, 0.1864152360940352, 0.18270914355525747, 0.16448356996988878, 0.10020170680945739], [0.033593292318983003, 0.11078890354838222, 0.09016653435537592, 0.052372856880538166, 0.047139146117842756, 0.06823719115345739, 0.04761632109875791, 0.1685571888810955, 0.05784465232864022, 50.52735552191734, 63.39098386466503, 48.75130042433739, 20.239589251577854, 18.51431842893362, 48.11955012381077, 56.426595970988274, 63.98658290505409, 81.46783366799355, 11.10220531001687, 0.0876047890051268, 0.10351680626627058, 0.940940243890509, 1.1583053832873702, 29.906766414642334, 64.78384092450142, 58.94203059375286, 66.20677337050438, 61.32207468152046, 68.18972736597061, 63.65882769227028, 65.19537404179573, 65.38559943437576, 73.35159838199615, 69.3558543920517, 75.36495834589005, 68.80112215876579, 74.49480503797531, 68.39333564043045, 74.39604833722115, 67.89951413869858, 70.60476377606392, 69.60872322320938, 70.80580338835716, 60.29058963060379, 53.70585836470127, 51.95593446493149, 50.004545375704765, 50.80759048461914, 51.430658251047134, 50.56184247136116, 47.147216498851776, 48.54002796113491, 48.80266986787319, 49.136599749326706, 50.70872738957405, 44.08003248274326, 48.03027391433716, 50.14905162155628, 48.707823157310486, 46.8488185107708, 44.09296318888664, 43.07390347123146, 42.88705229759216, 41.3603588193655, 41.653881669044495, 42.26153366267681, 43.261370211839676, 40.86633212864399, 42.64581084251404, 40.00401400029659, 43.95900517702103, 47.463906705379486, 45.7735788077116, 46.80895484983921, 47.728767693042755, 46.17776691913605, 47.660671547055244, 48.30854058265686, 50.08790910243988, 48.44266578555107, 48.086146116256714, 50.87320916354656, 57.88514010608196, 57.89482578635216, 61.17312267422676, 42.5210977345705, 13.149953428655863, 9.709955267608166, 38.747854605317116, 41.07475474476814, 37.892668694257736, 59.82098422944546, 56.00427523255348, 48.888484463095665, 46.394647881388664, 54.37358133494854, 56.322956532239914, 54.22157049179077, 53.70013207197189, 46.79206095635891, 51.62755608558655, 56.69208012521267, 59.095435962080956, 55.643518790602684, 57.278457060456276, 52.94420063495636, 46.93891167640686, 42.51214921474457, 40.11630177497864, 38.02147798240185, 39.171452075242996, 37.294265404343605, 38.44594940543175, 38.19430410861969, 42.04958863556385, 41.13195687532425, 46.27587005496025, 49.49644424021244, 47.84769371151924, 45.77537231147289, 48.027348071336746, 45.71951910853386, 44.619721323251724, 43.7238509953022, 46.34864754974842, 46.63269750773907, 48.130387142300606, 46.52077831327915, 47.68780589103699, 46.48530721664429, 47.979531437158585, 53.862368166446686, 61.83102697134018, 59.37080338597298, 65.63399970531464, 63.89750048518181, 66.67556941509247, 64.4938936829567, 64.89301666617393, 65.36818876862526, 67.57516354322433, 66.30359217524529, 64.15656298398972, 63.467108979821205, 67.3915345966816, 65.09499102830887, 70.21355956792831, 65.22414609789848, 68.07078614830971, 68.61769840121269, 70.6323578953743, 67.29419901967049, 78.37501242756844, 51.980139166116714, 1.4251820440404117, 0.04401920552481897, 0.16252994042588398, 0.3653646446764469, 34.624011889100075, 72.25008308887482, 60.60358643531799, 50.26665911078453, 53.85025441646576, 31.83960109949112, 20.627299547195435, 31.472559794783592, 47.09503389894962, 69.41711470484734, 15.9361282736063, 0.4774939263006672, 0.19276321108918637, 0.13546187023166567, 0.0463621063681785, 0.12589947553351521, 0.010753842288977467, 0.029146087399567477, 0.06490041356300935, 0.05431871613836847, 0.09810223040403798, 0.0038754819479436264, 0.048157688142964616, 0.04819780122488737, 0.08491948348819278, 0.17688723251922056, 0.14544102537911385, 59.98656414449215, 70.7428939640522, 56.8872794508934, 28.796709179878235, 20.519579127430916, 50.64255394041538, 64.52638193964958, 70.28476014733315, 85.8913967013359, 11.660581547766924, 0.32254310965072364, 0.38546247873455286, 1.1146642500534654, 1.6512943734414876, 35.21011143922806, 71.2546657025814, 66.26934081315994, 70.3513553738594, 65.28485164046288, 69.71420556306839, 66.58909365534782, 67.93766409158707, 67.35677406191826, 74.32133674621582, 72.02005103230476, 75.38080349564552, 71.62081405520439, 75.73847830295563, 70.47576069831848, 73.93958643078804, 71.1237171292305, 71.1960120499134, 70.437793135643, 72.06534460186958, 63.69352363049984, 57.052680775523186, 54.306853115558624, 53.64769488573074, 51.19589164853096, 55.10447971522808, 52.677276358008385, 48.876788690686226, 50.00478096306324, 49.7713328897953, 51.18490643799305, 53.01809147000313, 47.17354528605938, 50.35736404359341, 52.12721407413483, 49.147353172302246, 48.413958325982094, 46.35104142129421, 44.663171991705894, 45.77096074819565, 43.46845529973507, 43.47090616822243, 44.6110387891531, 44.84867423772812, 43.78392577171326, 45.82152463495731, 44.38884571194649, 46.109883561730385, 46.87556907534599, 48.67141351103783, 48.86054456233978, 48.12817566096783, 49.28539976477623, 48.74362863600254, 51.21034987270832, 51.59660294651985, 51.27723388373852, 50.5438694357872, 54.773867055773735, 59.7299525141716, 59.3919188529253, 62.74277284741402, 45.17353780567646, 16.766212731599808, 9.938199520111084, 39.47573594748974, 45.08120656013489, 40.917659774422646, 61.510396376252174, 58.86575348675251, 52.06392467021942, 48.71235631406307, 57.48084180057049, 59.46314223110676, 57.030341774225235, 56.315429136157036, 49.281554371118546, 52.203635573387146, 58.856041207909584, 60.27574002742767, 57.612424939870834, 58.992894664406776, 55.770226791501045, 48.55222150683403, 45.291133895516396, 42.15257830917835, 40.6262382119894, 41.73484392464161, 40.92530496418476, 42.24273607134819, 40.818409100174904, 44.36935655772686, 42.18076519668102, 49.164991825819016, 51.02719210088253, 49.83039692044258, 46.49625442922115, 50.09561888873577, 48.71642969548702, 45.9735506772995, 45.892717614769936, 48.69532562792301, 47.61238753795624, 49.04401771724224, 48.672260865569115, 48.99668745696545, 48.275854736566544, 50.96420668065548, 55.22760450839996, 62.44928039610386, 60.82018621265888, 66.09851717948914, 65.5394683778286, 68.23913231492043, 68.1736846268177, 67.44359940290451, 68.25498506426811, 69.97512996196747, 68.4943038225174, 64.94258880615234, 68.60500708222389, 69.93844673037529, 68.42466875910759, 73.5025642812252, 70.0022529065609, 72.19797268509865, 70.53248405456543, 73.84114891290665, 71.43511801958084, 79.2605473101139, 65.79095408320427, 3.550817077048123, 0.01991841614653822, 0.3612369380425662, 0.4720096033997834, 37.71185539662838, 80.96217200160027, 67.1751058101654, 60.65768413245678, 53.88497695326805, 28.62069122493267, 24.409396201372147, 40.03373220562935, 53.478387370705605, 78.46929296851158, 19.173315167427063, 0.6017174245789647, 0.1668877128395252, 0.18753877346171066, 0.02970385776279727, 0.13943109865067527, 0.01976652449229732, 0.07954732136568055, 0.11421775940107182, 0.23428193555446342, 0.28361449541989714, 0.0876336733927019, 0.13644860009662807, 0.20459356455830857, 0.16560685500735417, 0.3381712851114571, 0.47213235462550074, 69.08172950148582, 81.45650267601013, 67.45186775922775, 29.480015113949776, 26.838341765105724, 67.18305498361588, 72.26794973015785, 77.48793482780457, 92.20886930823326, 14.479791820049286, 0.32028959307353944, 0.9038224699907005, 3.903123722411692, 4.468126567080617, 35.11938750743866, 77.27310955524445, 72.38084927201271, 79.92054149508476, 71.57463133335114, 78.10430735349655, 73.06210711598396, 73.5726173222065, 70.99146902561188, 79.97912675142288, 71.32126092910767, 77.96795547008514, 74.51595470309258, 78.18889081478119, 74.00354459881783, 78.3273097872734, 72.72998973727226, 75.27783662080765, 72.24239230155945, 78.48590567708015, 65.05144536495209, 58.32670301198959, 55.90326905250549, 53.715981021523476, 54.71647493541241, 57.67720386385918, 55.86252003908157, 50.601858124136925, 50.675201788544655, 54.30278733372688, 52.96486772596836, 57.998187839984894, 49.819654896855354, 53.65678779780865, 54.35249626636505, 52.26606622338295, 52.829674780368805, 48.39035779237747, 46.85801021754742, 46.614602878689766, 45.242580100893974, 46.779365837574005, 47.475241497159004, 47.94090270996094, 46.39139145612717, 47.853081822395325, 45.74363261461258, 50.017099902033806, 50.348890498280525, 52.39148609340191, 51.23825937509537, 50.405005887150764, 51.78431287407875, 51.83894254267216, 55.34778445959091, 52.168647050857544, 51.60340078175068, 52.81289488077164, 56.79917357861996, 61.82005695998669, 63.73545438051224, 65.84918215870857, 49.03503879904747, 19.162666238844395, 14.283321462571621, 46.52628041803837, 47.12801992893219, 45.64147129654884, 65.24280309677124, 62.21506476402283, 55.95364674925804, 53.234398663043976, 59.174464121460915, 63.29322651028633, 58.41197803616524, 59.159071147441864, 52.45632961392403, 56.818362548947334, 60.58393768966198, 64.77462261915207, 60.465638637542725, 62.808957695961, 58.35720777511597, 51.50479607284069, 47.462386786937714, 44.49421405792236, 42.9080081731081, 45.287660881876945, 43.592818826437, 45.53781285881996, 44.92587089538574, 46.21530890464783, 44.3007892370224, 50.43304078280926, 54.06097590923309, 50.745414420962334, 50.62989301979542, 53.8960837572813, 50.677268877625465, 49.45528484880924, 48.841929361224174, 51.378186866641045, 49.3357090651989, 53.56037177145481, 52.013007402420044, 52.02415980398655, 51.68758526444435, 54.96596194803715, 58.14943492412567, 65.547014772892, 66.66353926062584, 69.84813317656517, 68.87628972530365, 73.23953479528427, 72.29821130633354, 70.93665316700935, 71.78515523672104, 73.79104480147362, 71.96483999490738, 68.46570655703545, 70.95711886882782, 74.28849130868912, 73.25866296887398, 78.34298014640808, 72.0947702229023, 74.78049650788307, 76.1630979180336, 75.68659588694572, 73.01609918475151, 82.71439477801323, 71.29087775945663, 4.641456641256809, 0.10019741719588637, 0.9386391704902053, 0.49205106392037123, 44.579238295555115, 87.62170225381851, 74.48533594608307, 67.48377084732056, 69.6548679471016, 47.70057700574398, 32.62171313166618, 48.193585351109505, 61.70944109559059, 89.53040823340416, 25.00076226890087, 0.8305643009953201, 0.30223411973565817, 0.30093387700617313, 0.16350899648386985, 0.3045278013451025, 0.14211091969627887, 0.14433832751819864], [0.04379385609354358, 0.06232807776541449, 0.036709707710542716, 0.026879727956838906, 0.0758093387412373, 0.16303265641909093, 0.06394415628165007, 0.0509937424067175, 0.41665251133963466, 46.89471244812012, 57.8260912746191, 48.05436082184315, 46.214586943387985, 42.866199016571045, 45.86053714156151, 53.633248060941696, 69.41250175237656, 71.32632985711098, 3.3841138472780585, 0.20989894081139937, 0.31423945678398013, 0.83922736113891, 7.970857936888933, 61.16759777069092, 74.24946740269661, 61.98352798819542, 58.43190036714077, 57.07253471016884, 62.327303141355515, 62.22880482673645, 63.5929886251688, 69.29665356874466, 71.28396973013878, 75.17714202404022, 72.4229434132576, 71.10134392976761, 71.28710836172104, 69.34567853808403, 67.67088040709496, 68.36033061146736, 70.12291923165321, 69.8614552617073, 67.15499728918076, 64.77453902363777, 53.42836685478687, 49.39456410706043, 50.41985169053078, 47.907817885279655, 48.37539799511433, 48.898595720529556, 49.4525071978569, 48.756658136844635, 47.4416247010231, 46.86980098485947, 47.19550050795078, 42.648330107331276, 45.01478232443333, 50.083163157105446, 47.83744566142559, 48.82815510034561, 48.50742571055889, 43.74857246875763, 45.53343169391155, 41.72433748841286, 40.852941647171974, 39.752437099814415, 43.81808213889599, 40.26939556002617, 40.508452132344246, 42.55198247730732, 43.319655284285545, 42.91664510965347, 46.42715513706207, 45.118934735655785, 44.155994206666946, 46.149800419807434, 49.74786914885044, 48.460384234786034, 49.027583599090576, 46.296111568808556, 47.72540867328644, 51.70241206884384, 56.83833047747612, 54.78803649544716, 60.10902397334576, 51.11141838133335, 21.637002266943455, 12.37356198951602, 13.426263201981783, 37.02228359878063, 38.57975922524929, 54.10558171570301, 54.62724432349205, 52.0814873278141, 42.082255482673645, 50.30244559049606, 52.08013840019703, 51.90993793308735, 49.109260216355324, 47.819879204034805, 43.923648074269295, 46.778062507510185, 50.44883273541927, 52.92404271662235, 46.92500062286854, 46.36601261794567, 41.2911569327116, 38.336921855807304, 39.038672000169754, 39.07962240278721, 38.25828127563, 38.69679294526577, 39.782561883330345, 41.05531498789787, 40.99257655441761, 43.403357192873955, 45.11874094605446, 47.83838801085949, 48.18852782249451, 44.77265551686287, 43.39639596641064, 44.686384946107864, 44.489388316869736, 44.100733771920204, 46.61510445177555, 45.1618230342865, 47.80534118413925, 46.45532302558422, 44.263053461909294, 45.90937212109566, 46.26798167824745, 46.46150529384613, 49.05241146683693, 52.970358431339264, 54.47397954761982, 58.97073805332184, 56.735834777355194, 57.20308430492878, 60.46177804470062, 58.6766642332077, 58.30748364329338, 56.61584861576557, 58.296699821949005, 60.90498626232147, 60.41101276874542, 58.09114225208759, 61.26132734119892, 62.305298522114754, 62.814718186855316, 64.37955781817436, 68.93191874027252, 67.81331196427345, 75.28710052371025, 73.90897527337074, 11.465962640941143, 0.8949425839819014, 0.1891483284998685, 0.18107726471498609, 8.485508970916271, 65.05224332213402, 62.7535604685545, 57.71524742245674, 53.620822727680206, 42.58108131587505, 14.440851509571075, 29.33107640594244, 46.25905975699425, 69.48861166834831, 23.85019540786743, 0.49336680269334465, 0.3932757204165682, 0.06804256292525679, 0.041501154119032435, 0.049179592097061686, 0.05474880184920039, 0.05110809623147361, 0.02886095240683062, 0.03248618610086851, 0.06861551577458158, 0.08953281445428729, 0.025554142739565577, 0.10328360862331465, 0.08380428786040284, 0.04515849497693125, 0.8657886483706534, 57.74748869240284, 66.23872965574265, 55.992332473397255, 46.120963767170906, 35.12824863195419, 50.70460841059685, 62.302513271570206, 76.74204245209694, 77.57080078125, 3.2440025405958295, 0.29406684392597526, 0.31297056237235665, 0.5992728495039046, 9.69793176278472, 65.6926229596138, 77.46385172009468, 70.31409457325935, 66.01977780461311, 64.63252544403076, 67.7301724255085, 68.21517840027809, 70.52685275673866, 73.2891297340393, 74.66418474912643, 76.16217836737633, 75.57464629411697, 73.45444366335869, 73.43002617359161, 71.06084570288658, 71.42486616969109, 70.43670639395714, 69.01942044496536, 71.21631056070328, 68.36692705750465, 66.90022855997086, 55.31139761209488, 51.39003083109856, 52.557077407836914, 49.85847361385822, 47.900176495313644, 51.334299221634865, 51.041585728526115, 50.9027411788702, 49.008691012859344, 50.479489490389824, 49.527849555015564, 45.396103262901306, 47.410671561956406, 51.93533197045326, 48.70153069496155, 51.559482738375664, 49.931596890091896, 45.97510099411011, 46.70212738215923, 44.384863525629044, 43.83640855550766, 42.785498946905136, 45.89417293667793, 42.99562007188797, 41.94159463047981, 44.18234579265118, 45.470294281840324, 45.53253494203091, 47.888290733098984, 47.7540173381567, 46.820654422044754, 49.283971041440964, 49.845098331570625, 51.65935277938843, 48.69914062321186, 50.17440386116505, 47.892348915338516, 54.409208223223686, 61.07178971171379, 57.59637080132961, 60.83571597933769, 53.67234796285629, 26.205058246850967, 12.705307938158512, 15.223184879869223, 40.56866370141506, 42.05612428486347, 56.62957727909088, 57.133244052529335, 53.72806057333946, 46.65796235203743, 52.23338797688484, 55.84783002734184, 55.11800318956375, 50.929267555475235, 50.40296919643879, 48.32228064537048, 48.67431655526161, 53.04974377155304, 55.057293847203255, 49.043462947010994, 48.35432052612305, 43.680977895855904, 41.65627174079418, 40.28796896338463, 41.65298871695995, 42.17278182506561, 40.78063152730465, 41.94105885922909, 42.66153819859028, 43.83257456123829, 45.88555499911308, 48.98739315569401, 49.99213524162769, 50.5356352776289, 46.014064103364944, 45.93790479004383, 48.161427676677704, 48.73095631599426, 48.425775691866875, 51.21766448020935, 47.81423270702362, 50.54779842495918, 47.33651094138622, 44.120842292904854, 47.325844913721085, 49.07781310379505, 48.22947442531586, 50.10779343545437, 53.96680936217308, 56.58083729445934, 60.209790766239166, 58.543124198913574, 59.74097952246666, 60.736769288778305, 60.22133834660053, 60.458882600069046, 60.25839775800705, 61.28690756857395, 63.32697629928589, 62.35346853733063, 61.24679692089558, 62.29595482349396, 65.0168140232563, 64.51736122369766, 68.92054975032806, 70.35627231001854, 70.00241249799728, 74.04916495084763, 79.08957928419113, 21.249928437173367, 1.1245219898410141, 0.35077877109870315, 0.21008928684750572, 8.474879041314125, 70.3622379899025, 68.3335268497467, 65.43603032827377, 61.1234175413847, 41.26641646027565, 22.233577854931355, 41.447871923446655, 50.11391870677471, 80.99209919571877, 27.003125622868538, 0.3851050604134798, 0.2078241779236123, 0.06721385114360601, 0.0025670176137282397, 0.060054252317058854, 0.06769897823687643, 0.09882307102088816, 0.18635175278177485, 0.10761916855699383, 0.15783207141794264, 0.1583403832046315, 0.23328653740463778, 0.32909689703956246, 0.2394366409862414, 0.24121957656461746, 0.8956853253766894, 67.1540017426014, 75.47514483332634, 66.42686516046524, 63.11059311032295, 62.91217155754566, 63.28237809240818, 70.67885220050812, 81.63763895630836, 86.71643882989883, 3.736951039172709, 0.37056882167235017, 0.7377847388852388, 2.9198139114305377, 10.324142910540104, 66.15410059690475, 81.61913394927979, 73.99440988898277, 69.96702879667282, 71.34969860315323, 73.68934705853462, 72.91570857167244, 71.02217137813568, 76.91825419664383, 76.04003772139549, 77.8554131090641, 76.47468119859695, 74.75674778223038, 77.65478387475014, 73.15319582819939, 73.0947245657444, 73.21809634566307, 73.06735843420029, 74.2862494289875, 70.1292572915554, 69.41832304000854, 57.044043838977814, 53.500521183013916, 56.9624850153923, 51.77911855280399, 52.738460674881935, 54.242720156908035, 52.66474463045597, 52.94531397521496, 52.46576830744743, 53.30736234784126, 52.80731298029423, 45.994282364845276, 50.21734155714512, 55.3784716129303, 51.8616159260273, 53.270112946629524, 54.48662526905537, 48.35274741053581, 50.24783492088318, 47.354571372270584, 46.88435420393944, 44.54953908920288, 50.29722847044468, 45.30114255845547, 44.62327033281326, 48.19641999900341, 46.900241151452065, 49.69504818320274, 51.15049168467522, 50.818039923906326, 51.63287200033665, 51.179373934865, 53.35269771516323, 54.70126815140247, 52.80161328613758, 50.927500650286674, 52.42842771112919, 57.682759165763855, 63.166909888386726, 60.18471211194992, 63.78034517168999, 59.124059826135635, 30.321850441396236, 16.76459401845932, 19.819158911705017, 44.816565960645676, 50.12363098561764, 60.31702481210232, 60.937960892915726, 56.48859724402428, 49.27309222519398, 55.62407523393631, 58.32557447254658, 57.29438200592995, 55.16691796481609, 53.508409559726715, 51.75394110381603, 49.61130827665329, 56.69969491660595, 58.920713737607, 51.67671784758568, 51.746979877352715, 47.639662474393845, 43.85559372603893, 44.83129397034645, 43.69160592556, 44.09062251448631, 44.56289917230606, 45.80417476594448, 45.926889181137085, 47.26979412138462, 47.32549153268337, 50.568818897008896, 50.79852037131786, 53.400062173604965, 48.281885012984276, 47.23149977624416, 50.90738832950592, 50.65729334950447, 49.54542741179466, 52.45440311729908, 48.201097548007965, 53.50424498319626, 50.391345620155334, 46.91110476851463, 49.9478068202734, 50.38757622241974, 51.32706820964813, 53.20392429828644, 56.774706691503525, 60.049982741475105, 64.84210699796677, 63.17602559924126, 62.262201234698296, 64.46678593754768, 64.75421771407127, 64.82126891613007, 64.4173201918602, 63.20373751223087, 68.2044705748558, 65.23310601711273, 64.66722518205643, 66.30169987678528, 69.5474325120449, 69.20686438679695, 72.73395672440529, 74.5120333135128, 73.71374934911728, 76.39590382575989, 83.00468400120735, 27.68744420260191, 1.1677608196623623, 0.8152066532056779, 0.3317490656627342, 11.900397129356861, 80.02106130123138, 74.5086818933487, 74.54745501279831, 69.58555206656456, 61.73601686954498, 23.520038723945618, 47.38332062959671, 58.06142024695873, 90.00589191913605, 34.68163579702377, 0.6899639486800879, 0.45975199551321566, 0.20191755815176293, 0.11836827965453267, 0.20166870119282976, 0.1902644889196381, 0.22270940418820828], [0.02749867726379307, 0.10715732263633981, 0.02012695222219918, 0.08044509741012007, 0.05462261447974015, 0.01832929800002603, 0.11602267739363015, 0.16936768835876137, 1.5886544971726835, 53.372905030846596, 49.721065387129784, 47.476639822125435, 24.406274668872356, 21.814756728708744, 43.27326737344265, 52.84308426082134, 75.42953968048096, 52.69576996564865, 0.605218046111986, 0.051016893703490496, 0.6791014596819878, 0.5724486045073718, 26.88077788800001, 81.13740339875221, 74.86811220645905, 77.55164980888367, 73.78615826368332, 69.06622633337975, 64.61497038602829, 64.60268944501877, 65.7305221259594, 74.66900289058685, 74.06327739357948, 72.31385126709938, 70.94745978713036, 70.18976524472237, 66.48996457457542, 66.01457968354225, 62.98470586538315, 65.11867895722389, 66.39257580041885, 66.80346295237541, 65.06485104560852, 60.22171072661877, 51.87471762299538, 49.99120429158211, 51.50601580739021, 48.46245892345905, 47.67225332558155, 48.247181475162506, 48.1900667399168, 48.910986855626106, 47.57355362176895, 49.457671120762825, 46.61367192864418, 45.60180522501469, 46.74224942922592, 48.690834268927574, 47.74979576468468, 46.905952244997025, 51.19186766445637, 53.86378929018974, 48.5455946624279, 41.75752490758896, 39.73753809928894, 41.89942829310894, 39.71654802560806, 40.43853208422661, 41.73512510955334, 41.122434586286545, 40.82073837518692, 41.53436668217182, 42.65690624713898, 44.82613764703274, 44.47962664067745, 47.53811672329903, 47.87911802530289, 46.42761491239071, 44.51744221150875, 44.90031726658344, 42.78773322701454, 45.96569649875164, 49.988381043076515, 57.71607577800751, 56.01646117866039, 52.692608535289764, 25.714614763855934, 19.197402074933052, 23.7412191554904, 32.0615091919899, 43.3668677508831, 51.453092247247696, 56.753070652484894, 52.666017562150955, 46.89284294843674, 43.22071619331837, 44.40290875732899, 45.146323665976524, 44.673891216516495, 44.706622660160065, 46.69648848474026, 43.88989828526974, 43.445762917399406, 43.13411124050617, 42.04407513141632, 42.91165977716446, 40.50276763737202, 37.83333107829094, 39.62707422673702, 40.21142587065697, 39.266541972756386, 39.98975336551666, 39.21940170228481, 39.712698832154274, 44.379616007208824, 45.205760076642036, 44.294147193431854, 48.13142828643322, 49.736260771751404, 45.36990366876125, 47.20137119293213, 45.1039407402277, 43.72132793068886, 44.516674652695656, 45.46472378075123, 46.48320592939854, 46.30237743258476, 45.84991671144962, 45.514577105641365, 48.47923122346401, 47.40532144904137, 47.41930469870567, 45.346272736787796, 44.423435255885124, 46.838148683309555, 48.44214901328087, 47.915577068924904, 49.470533430576324, 47.82085955142975, 49.73941460251808, 53.24401214718819, 52.183363661170006, 49.88756485283375, 50.21027773618698, 50.357531234622, 51.69848307967186, 52.325282245874405, 53.70773546397686, 56.26191660761833, 60.85817277431488, 63.503123447299004, 72.01783955097198, 67.15245142579079, 82.08784639835358, 25.39611965417862, 0.6648141669575125, 0.836344740819186, 0.11059774114983156, 3.5874252626672387, 57.230059057474136, 65.11627748608589, 59.99985583126545, 55.21512597799301, 43.6304672062397, 20.38264587521553, 27.96386417001486, 38.915490210056305, 64.87862303853035, 31.651826575398445, 0.41191570926457644, 0.195662975020241, 0.07654860688489862, 0.024800938917906024, 0.04741420460049994, 0.08528061996912584, 0.010829584953171434, 0.08191255343263038, 0.03545836509147193, 0.025096139288507402, 0.03008302843227284, 0.048081866625580005, 0.04596535422024317, 0.07487077426048927, 0.2693069272208959, 2.1983722737058997, 63.364609479904175, 59.698718190193176, 52.46147833764553, 33.45477283000946, 27.97824639827013, 47.784978076815605, 61.22286960482597, 81.31470948457718, 59.06064122915268, 0.5635055468883365, 0.397267792141065, 0.7600399665534496, 0.2278056283830665, 30.237411372363567, 84.1147792339325, 79.15036842226982, 81.25103250145912, 74.96116921305656, 73.97443816065788, 69.78491216897964, 70.89112401008606, 70.07219195365906, 75.96031799912453, 75.21961614489555, 74.11982595920563, 72.38673135638237, 73.24243023991585, 69.23860788345337, 69.14892509579659, 64.73925411701202, 69.04555544257164, 69.3263527750969, 69.44917738437653, 66.28368884325027, 60.25002300739288, 53.20674754679203, 52.43528634309769, 50.57553693652153, 51.53493985533714, 50.85733361542225, 50.668890327215195, 50.03756180405617, 50.9569376707077, 48.76609303057194, 50.69551929831505, 48.749069944024086, 46.38871639966965, 51.01079598069191, 50.38629949092865, 49.30425815284252, 48.84925536811352, 52.47385427355766, 54.93881240487099, 50.23957796394825, 44.552286341786385, 43.81799854338169, 44.75456468760967, 42.96874791383743, 44.485527724027634, 43.71024392545223, 43.92498180270195, 43.36268797516823, 44.73913371562958, 46.733874678611755, 49.42567303776741, 47.981374338269234, 49.22224335372448, 47.94402614235878, 47.10403561592102, 49.28804822266102, 47.883248403668404, 46.86518423259258, 48.17907772958279, 53.82594712078571, 58.697658106684685, 57.310200557112694, 53.31144332885742, 28.770802170038223, 22.09513608366251, 26.80861786007881, 35.66820725798607, 47.06650123000145, 51.84365049004555, 57.75848910212517, 57.36060865223408, 49.19716089963913, 45.635410621762276, 47.35422559082508, 47.66607865691185, 46.90115690231323, 47.294382601976395, 48.32736857235432, 47.57902532815933, 45.33657945692539, 45.37127159535885, 43.461744859814644, 46.02836653590202, 41.788341253995895, 39.516815543174744, 41.66965462267399, 41.28176383674145, 40.620914697647095, 42.86675378680229, 41.0935865342617, 41.190496534109116, 46.97971008718014, 44.956375658512115, 45.792790576815605, 50.58627896010876, 50.809471383690834, 48.71050961315632, 48.903421461582184, 46.90003976225853, 46.066322699189186, 45.7412501424551, 48.57589043676853, 49.541331231594086, 48.17300945520401, 48.65699328482151, 47.58031725883484, 47.80491180717945, 48.68415802717209, 50.38348764181137, 47.76772700250149, 46.38634912669659, 48.3108052611351, 50.78859530389309, 48.60634200274944, 51.96591652929783, 49.79708410799503, 51.92367799580097, 55.09116142988205, 54.193087220191956, 51.3492514193058, 53.765040189027786, 53.33746053278446, 53.51655252277851, 54.50296439230442, 57.77628734707832, 58.430300652980804, 64.08245176076889, 67.37577304244041, 74.20402944087982, 69.91621032357216, 85.13284340500832, 36.483962684869766, 1.939480290748179, 0.8583424135576934, 0.11313379334751517, 3.3000552328303456, 62.660887241363525, 71.02453485131264, 66.56023040413857, 64.02708873152733, 47.61387325823307, 25.948076136410236, 34.54113453626633, 44.65853624045849, 73.54813143610954, 38.385878428816795, 0.3569704794790596, 0.15392601460916921, 0.0675387262890581, 0.029971743388159666, 0.04121775389648974, 0.0837848435912747, 0.08263354247901589, 0.20068961544893682, 0.16123753477586433, 0.10931588141829707, 0.2100885595427826, 0.19321848900290206, 0.14756609103642404, 0.17918793484568596, 0.46560662041883916, 2.3152984119951725, 75.82096427679062, 69.15680587291718, 69.69326868653297, 37.227172404527664, 32.45087809860706, 64.97524425387383, 67.57574871182442, 89.30915370583534, 63.37714120745659, 1.0736845177598298, 0.3864276863168925, 2.0620930613949895, 2.426588502712548, 31.801593638956547, 87.42852821946144, 84.0198527276516, 86.53964951634407, 82.33449876308441, 77.63970628380775, 75.16787052154541, 72.61169448494911, 73.54471161961555, 79.77809473872185, 77.90178582072258, 77.33976557850838, 75.77426478266716, 76.32069826126099, 71.94527104496956, 72.15810522437096, 64.85755696892738, 70.02401053905487, 71.60320580005646, 73.3902271091938, 70.1702418923378, 63.91330003738403, 56.98356628417969, 54.743776470422745, 55.31542159616947, 51.51466794312, 52.144997119903564, 52.05352082848549, 51.57787375152111, 54.51519213616848, 50.56703299283981, 54.083778485655785, 51.77733264863491, 49.46406997740269, 54.74335469305515, 52.53319948911667, 53.69306445121765, 50.08840687572956, 55.777317211031914, 56.95923998951912, 52.14977726340294, 47.439603209495544, 45.23673601448536, 48.59820283949375, 45.25236837565899, 46.55576303601265, 48.723318725824356, 46.70648194849491, 47.71528981626034, 47.72716037929058, 49.63995113968849, 51.4288305491209, 50.057943910360336, 52.490843161940575, 53.07945817708969, 52.33975566923618, 51.06535725295544, 50.32928355038166, 48.15844863653183, 49.968606904149055, 56.38516679406166, 61.91436789929867, 62.16718353331089, 59.50328327715397, 33.314324766397476, 26.96838218718767, 30.15879739075899, 37.913480177521706, 50.922636911273, 55.49951791763306, 61.72104947268963, 58.36821958422661, 52.25081384181976, 48.277914226055145, 49.66701328754425, 51.15920081734657, 50.17428606748581, 49.6258956938982, 52.592415511608124, 49.44670490920544, 48.858686462044716, 48.14295306801796, 47.2898418456316, 49.64335575699806, 46.34933531284332, 42.94413663446903, 44.3457256257534, 45.05501836538315, 43.91926310956478, 44.85941246151924, 42.61414714157581, 45.82328774034977, 49.08478192985058, 48.39303284883499, 47.854977920651436, 50.94560667872429, 52.60410748422146, 51.29736140370369, 53.061960116028786, 51.114028841257095, 50.097628980875015, 50.16611650586128, 50.29312089085579, 52.55933828651905, 51.81263655424118, 50.53079433739185, 51.47344395518303, 51.18918880820274, 52.32611060142517, 53.14082868397236, 49.659368097782135, 49.14286561310291, 52.26711496710777, 54.42955993115902, 51.84024967253208, 55.5829082429409, 52.42256082594395, 54.70368482172489, 58.30840319395065, 56.69134296476841, 55.3039538115263, 56.27834692597389, 57.258390337228775, 56.931710466742516, 59.149605855345726, 60.732961893081665, 62.27787159383297, 66.96661099791527, 71.21669054031372, 78.35781455039978, 74.59306016564369, 87.55081325769424, 42.5607106089592, 5.080917784944177, 2.1596708754077554, 0.16957652871496975, 4.275164846330881, 70.662110298872, 76.59074977040291, 75.36314964294434, 73.4764064848423, 60.66030599176884, 31.593191921710968, 41.84393607079983, 53.090891763567924, 82.53036305308342, 48.95142048597336, 0.5942138959653676, 0.3867387946229428, 0.1646426715888083, 0.1925710096838884, 0.17588592687388882, 0.29489154811017215, 0.22436080151237547], [0.05034710542531684, 0.035836136812577024, 0.14151559851597995, 0.02787293491564924, 0.06857703541754745, 0.033509244094602764, 0.12182197518995963, 0.06537756256875582, 2.019699211232364, 51.18291154503822, 50.392614752054214, 38.77113215625286, 31.397853903472424, 38.889773190021515, 50.36766529083252, 56.07731871306896, 76.8866702914238, 36.99048310518265, 0.15550649230135605, 0.057783350930549204, 0.6062870949972421, 3.0598435224965215, 59.634763821959496, 81.28892406821251, 74.28339198231697, 73.96575182676315, 70.25750800967216, 71.40180140733719, 71.85925126075745, 72.8651636838913, 70.76861098408699, 67.47630804777145, 69.18608710169792, 72.48146027326584, 70.79089298844337, 68.28985199332237, 65.25925621390343, 64.35616627335548, 60.12494131922722, 59.157760217785835, 58.90258491039276, 59.51311714947224, 55.582129284739494, 50.67998953163624, 49.07975099980831, 48.48431155085564, 48.95270101726055, 48.97353529930115, 48.18675331771374, 49.62904952466488, 46.41406483948231, 48.814574629068375, 46.49930186569691, 47.982069700956345, 45.69962717592716, 45.12793645262718, 46.06778562068939, 48.72604697942734, 47.27553941309452, 47.47649163007736, 47.35300965607166, 52.793341130018234, 53.379619270563126, 47.12436832487583, 42.533283680677414, 40.49465887248516, 40.016458332538605, 41.30292870104313, 39.95332092046738, 41.368140801787376, 40.413806810975075, 40.21383114159107, 41.24552138149738, 42.436077296733856, 45.36358840763569, 48.63206282258034, 45.39992965757847, 42.777515575289726, 40.54627150297165, 44.86127056181431, 44.33139659464359, 45.80510571599007, 48.55783000588417, 53.52854087948799, 57.265207171440125, 55.51175706088543, 38.181107416749, 40.64363747835159, 34.84857603907585, 41.81513361632824, 41.70484833419323, 39.55664500594139, 53.905423656105995, 52.13348373770714, 47.45513677597046, 41.238130778074265, 44.53671857714653, 43.48654992878437, 42.85250075161457, 42.1799710392952, 45.954920276999474, 45.51910266280174, 45.81428602337837, 43.35153177380562, 42.674389109015465, 39.65217188000679, 38.73590424656868, 37.87571780383587, 40.10888837277889, 38.68373304605484, 40.30999258160591, 40.376394018530846, 39.04774971306324, 41.8994776904583, 46.208343878388405, 41.53560921549797, 43.80106285214424, 48.19459609687328, 51.14367485046387, 45.157814249396324, 46.32405906915665, 44.70026560127735, 42.4542935192585, 43.84300120174885, 43.12272325158119, 44.52910378575325, 45.93343622982502, 45.510564520955086, 44.0197791159153, 45.86258143186569, 46.10296033322811, 47.2497083991766, 47.82932169735432, 49.36428353190422, 47.84038670361042, 46.97133153676987, 47.36579217016697, 48.290312960743904, 50.013824477791786, 51.804083213210106, 48.829538226127625, 47.91255243122578, 50.11477746069431, 51.87016546726227, 51.11147537827492, 52.41896241903305, 50.53467772901058, 56.29585258662701, 55.44398009777069, 60.160697400569916, 64.21609818935394, 68.30936774611473, 68.03386732935905, 75.9203289449215, 49.1661773622036, 2.4488959182053804, 1.958209841977805, 0.14993999880971387, 0.5423055938445032, 39.547772482037544, 69.05574649572372, 60.406924188137054, 59.21511813998222, 44.20027703046799, 21.738344728946686, 22.159181647002697, 37.13577590882778, 61.13208867609501, 39.386740922927856, 0.5516119475942105, 0.14914557425072417, 0.030136316490825266, 0.03656233944639098, 0.0842282990925014, 0.004879533307757811, 0.008161090008798055, 0.03901978336216416, 0.0365298667747993, 0.13824994093738496, 0.04903048349660821, 0.024867060565156862, 0.07562861836049706, 0.08488138162647374, 0.06380843973602168, 2.449862966313958, 58.99467296898365, 58.385634049773216, 48.78745548427105, 35.67986503243446, 32.99685560166836, 59.16904181241989, 62.1290335804224, 87.24616080522537, 40.805307403206825, 0.1867239992134273, 0.30484327347949147, 1.2039621896110475, 3.64868201315403, 64.85640183091164, 84.95344743132591, 78.54362457990646, 78.65677490830421, 72.47817724943161, 75.25214239954948, 74.26383823156357, 73.22039142251015, 71.94405511021614, 69.01440471410751, 71.47205203771591, 72.2518689930439, 72.60578960180283, 70.7163941860199, 68.69142204523087, 66.04629278182983, 62.925869822502136, 61.776074320077896, 63.0732449144125, 60.94310201704502, 57.443759590387344, 53.07870961725712, 49.90500971674919, 52.78579853475094, 50.69071255624294, 51.90236873924732, 50.83064004778862, 51.06999680399895, 48.607200756669044, 49.88069102168083, 49.769755974411964, 51.27909578382969, 48.398447558283806, 47.71595098078251, 49.29342873394489, 51.34931981563568, 50.463993921875954, 48.30613151192665, 48.691590428352356, 53.235983178019524, 53.30206923186779, 49.29293856024742, 44.64350804686546, 43.387854024767876, 42.53371685743332, 43.2938052713871, 42.79160901904106, 43.13124619424343, 44.33434143662453, 42.75008864700794, 42.43944771587849, 44.47037793695927, 48.870074450969696, 48.89542669057846, 47.54826597869396, 46.47431060671806, 44.53880466520786, 48.24988692998886, 45.52920252084732, 47.459631934762, 51.73837333917618, 56.84562988579273, 60.400399938225746, 57.1299534291029, 41.79873749613762, 44.26122575998306, 37.10741803050041, 43.185803666710854, 43.46244402229786, 40.74126563966274, 56.568370163440704, 55.81930875778198, 49.14266802370548, 45.91709330677986, 46.689660251140594, 45.91522380709648, 46.985880956053734, 45.805018320679665, 46.71184346079826, 47.526162564754486, 47.055770605802536, 44.51639726758003, 44.6744953840971, 44.460540264844894, 41.67634606361389, 41.50365673005581, 42.734570279717445, 42.03768007457256, 42.70406171679497, 42.18885876238346, 42.98575200140476, 42.78355345129967, 46.92758448421955, 42.38093085587025, 45.256274566054344, 46.626633033156395, 54.20610912144184, 47.95718863606453, 47.01508618891239, 46.82687468826771, 44.37458887696266, 45.459601655602455, 47.25375138223171, 45.70656180381775, 47.63647824525833, 47.48279929161072, 47.24118545651436, 47.84643217921257, 49.64101888239384, 48.749875500798225, 49.86131966114044, 50.8549777418375, 49.650107994675636, 49.360521733760834, 51.50820828974247, 50.71286916732788, 51.461204811930656, 52.00994096696377, 51.17106758058071, 49.820677042007446, 53.31760659813881, 55.47018729150295, 53.82349245250225, 55.27919813990593, 56.91167414188385, 57.89324127137661, 58.626510724425316, 60.975236892700195, 66.92841544747353, 70.76749384403229, 73.00397783517838, 76.65260285139084, 60.424144864082336, 4.258137010037899, 0.9157580451574177, 0.2391381046618335, 0.6044337444473058, 45.134969875216484, 75.98766133189201, 66.16682231426239, 68.75313073396683, 45.084573179483414, 25.77886551618576, 30.409511737525463, 45.90064398944378, 67.67624571919441, 51.05640113353729, 0.6723400787450373, 0.10473818096215837, 0.032384322621510364, 0.04455386726476718, 0.0943603589257691, 0.07428149416227825, 0.05155370767170098, 0.24288117099786177, 0.09685905883088708, 0.23603172681760043, 0.16149348666658625, 0.12043164315400645, 0.20137096638791263, 0.28987406578380615, 0.2120109149836935, 3.077798984013498, 73.11563864350319, 70.79418361186981, 58.07958327233791, 45.34942276775837, 61.28770552575588, 69.45477068424225, 69.99083831906319, 92.16264098882675, 46.51007428765297, 0.28931914712302387, 0.26764932554215193, 1.5133381448686123, 4.1775537841022015, 66.67622298002243, 86.93925887346268, 80.98946213722229, 81.2742568552494, 74.28314119577408, 79.19675633311272, 77.0605717599392, 77.06706941127777, 76.05355739593506, 73.67797806859016, 74.56368014216423, 74.5814099907875, 75.26696920394897, 74.76789638400078, 70.46181544661522, 69.06444042921066, 64.80238392949104, 65.3158351778984, 64.1551798582077, 65.53840443491936, 59.34376783668995, 55.64555548131466, 51.85711696743965, 54.19113412499428, 54.20594573020935, 53.71247000992298, 53.665215745568275, 53.55211861431599, 51.01831957697868, 53.15405577421188, 51.53426729142666, 52.81899735331535, 49.96120110154152, 52.325324043631554, 50.936186984181404, 53.64973917603493, 52.282200157642365, 51.620830446481705, 50.16487777233124, 55.94167359173298, 54.923856407403946, 49.04264599084854, 48.773920610547066, 44.915394857525826, 48.29483091831207, 48.63082408905029, 45.9568277746439, 46.67016349732876, 46.10718570649624, 45.50334110856056, 47.27549761533737, 49.77992422878742, 51.19608923792839, 51.88608281314373, 50.80136261880398, 47.91995823383331, 46.804440692067146, 50.87616540491581, 48.90735425055027, 50.75783595442772, 54.54930290579796, 58.73618423938751, 62.741374522447586, 62.05593690276146, 44.942825585603714, 44.543805196881294, 38.9502165466547, 44.384821727871895, 48.301427364349365, 46.76809184253216, 58.28532323241234, 56.566158682107925, 51.92994385957718, 48.19483168423176, 49.978596568107605, 48.21071483194828, 48.44722554087639, 47.28672981262207, 49.46299843490124, 51.27175837755203, 51.48052677512169, 47.1842835098505, 48.72963398694992, 46.854381412267685, 44.162887036800385, 44.72159385681152, 45.88712051510811, 45.42801395058632, 45.51868088543415, 45.76559543609619, 45.269231870770454, 45.362820848822594, 47.3153954744339, 42.920403108000755, 46.52797132730484, 48.75221237540245, 56.36682137846947, 49.19264294207096, 50.93084067106247, 48.94441746175289, 46.52711257338524, 48.20347622036934, 48.72807987034321, 48.30250270664692, 50.273050367832184, 51.02504141628742, 49.50330667197704, 49.543063938617706, 51.374611258506775, 53.57254631817341, 52.72631272673607, 53.40857371687889, 52.81392842531204, 50.65063610672951, 53.06935831904411, 53.03959831595421, 56.58699296414852, 56.376997232437134, 54.48164373636246, 53.39114785194397, 57.559744566679, 57.99795985221863, 55.72642654180527, 57.66182228922844, 59.42537605762482, 61.804663985967636, 61.757987290620804, 64.43257257342339, 70.6597164273262, 73.30792352557182, 77.30353072285652, 82.11638286709785, 63.677750676870346, 6.283276341855526, 3.1082123145461082, 0.46682775020599365, 0.7588988996576518, 56.52449771761894, 80.72682783007622, 73.24948266148567, 75.96962749958038, 59.28478740155697, 31.87873899936676, 34.45248909294605, 55.031003057956696, 77.41734221577644, 62.96086594462395, 1.2224791897460818, 0.19158209790475667, 0.17938022530870512, 0.10680829800548963, 0.18670002784347162, 0.13199090491980314, 0.10303658476914279], [0.06913723816978745, 0.04405571919050999, 0.009365138339489931, 0.06044333065801766, 0.14217232499504462, 0.06113372466643341, 0.044187858584336936, 0.10306776981451549, 2.819607825949788, 37.6693394780159, 45.34133680164814, 27.536482103168964, 21.436602920293808, 43.466186821460724, 52.85384528338909, 60.44233828783035, 76.32993936538696, 19.88986361771822, 0.6442411802709103, 1.75981868756935, 2.626951988786459, 18.013516701757908, 82.42031335830688, 75.78001007437706, 74.73349303007126, 74.58400145173073, 70.8439077436924, 73.25762182474136, 72.03968077898026, 68.96146595478058, 71.50938123464584, 73.8812443614006, 70.77969118952751, 70.59887409210205, 69.4049021601677, 68.87342467904091, 66.14261761307716, 61.950861141085625, 59.532059133052826, 55.60656197369099, 53.818814903497696, 51.50761552155018, 50.3595869243145, 51.267259418964386, 51.669733822345734, 48.593479692935944, 51.78386069834232, 51.22112989425659, 49.35188099741936, 46.865735203027725, 46.94414399564266, 46.648250073194504, 47.004180774092674, 48.95776994526386, 44.74859140813351, 44.48647007346153, 45.27946852147579, 47.63846553862095, 46.735907569527626, 45.73976822197437, 50.39619795978069, 44.07055579125881, 45.28303273022175, 46.82406663894653, 46.11340217292309, 42.78084419667721, 40.0117389857769, 42.0814461261034, 39.779164865612984, 41.79475151002407, 39.89240638911724, 39.824838414788246, 40.5453709512949, 44.085625782608986, 40.29582314193249, 42.957071140408516, 45.28937079012394, 46.93970203399658, 48.61251287162304, 49.64812070131302, 50.36814406514168, 50.313620790839195, 48.58858935534954, 49.97211031615734, 54.10713963210583, 56.063548251986504, 52.1643228828907, 45.50861142575741, 44.81169082224369, 46.71522527933121, 41.640153005719185, 33.56477312743664, 55.90040020644665, 53.44975210726261, 49.79557178914547, 41.29283644258976, 43.5716387629509, 42.15804621577263, 41.45172491669655, 40.86983934044838, 46.17006853222847, 44.45770561695099, 43.52648578584194, 41.57375916838646, 39.16683912277222, 38.202120289206505, 39.597603008151054, 38.17882373929024, 39.693730250000954, 37.32657507061958, 40.1861572265625, 37.48980671167374, 44.05456244945526, 44.429165348410606, 44.12678137421608, 42.60340891778469, 41.7336355894804, 45.112425684928894, 45.23988224565983, 44.41466152667999, 47.655655816197395, 43.44986669719219, 44.183827713131905, 44.092552810907364, 44.53808270394802, 44.91140507161617, 45.76020732522011, 45.37185296416283, 46.24850772321224, 46.904854103922844, 46.285133957862854, 47.317055985331535, 44.680461063981056, 47.24272057414055, 48.29559087753296, 47.8488602489233, 47.910656332969666, 44.86253209412098, 48.771519139409065, 49.248393550515175, 49.90755558013916, 51.96970492601395, 52.172275856137276, 54.06849570572376, 53.39233338832855, 54.19317841529846, 53.36446188390255, 55.09634055197239, 56.46229885518551, 63.62664341926575, 66.6350331902504, 69.47649791836739, 69.00572597980499, 73.95831182599068, 59.59938012063503, 10.324057415127754, 0.46083517489023507, 0.3682362218387425, 0.25981678802054375, 22.68116533756256, 71.81154862046242, 59.81676645576954, 57.77958557009697, 55.875435546040535, 41.7183718085289, 19.43344920873642, 36.68421573936939, 59.28804002702236, 39.15209211409092, 1.1391342245042324, 0.24400123511441052, 0.06960824961424805, 0.07287703163456172, 0.025489507243037224, 0.06177544863021467, 0.047895498501020484, 0.10315538034774363, 0.025122133010881953, 0.027054629899794236, 0.06916499449289404, 0.09908684514812194, 0.06053479664842598, 0.09421567723620683, 0.06653461532550864, 3.6550535587593913, 48.26364979147911, 57.70278409123421, 42.039294987916946, 29.783506728708744, 52.40486517548561, 60.04399046301842, 67.52724051475525, 82.9575589299202, 22.64911025762558, 0.8408746914938092, 1.0877145524136722, 2.0645453548058867, 20.656523779034615, 86.89086467027664, 79.54604879021645, 78.01668405532837, 77.40908145904541, 74.5134848356247, 75.63548862934113, 73.36010992527008, 73.20906043052673, 72.19669595360756, 76.82924777269363, 74.7031706571579, 71.45707324147224, 71.54076755046844, 70.90712115168571, 69.1198642551899, 66.1929041147232, 62.784942984580994, 58.504803255200386, 56.82937055826187, 54.493183717131615, 52.45928205549717, 53.429081216454506, 53.921014219522476, 51.62205398082733, 52.70942263305187, 52.370104640722275, 51.33565574884415, 50.460718497633934, 50.18612243235111, 49.07168783247471, 47.87815287709236, 51.98528788983822, 48.103742972016335, 46.37213408946991, 46.563442423939705, 49.00593616068363, 49.07224640250206, 48.23683463037014, 50.4735542088747, 45.63606038689613, 46.468420922756195, 47.75832250714302, 48.25621739029884, 46.11440531909466, 42.52096854150295, 43.74474607408047, 43.23818385601044, 44.86745283007622, 42.363983765244484, 42.351645827293396, 42.906340062618256, 45.36714881658554, 43.67144040763378, 45.98519705235958, 47.59061090648174, 49.70767870545387, 51.5812935680151, 53.926991298794746, 54.081506207585335, 53.160618022084236, 51.416287422180176, 53.04905220866203, 56.37456156313419, 58.53169821202755, 52.59262830018997, 46.31859876215458, 45.89160047471523, 47.357968389987946, 43.48936937749386, 36.76756426692009, 59.92055408656597, 55.906795263290405, 50.47074995934963, 42.988145872950554, 45.15242613852024, 44.035692662000656, 44.37773510813713, 44.31224562227726, 48.452359065413475, 48.506905138492584, 47.5429804623127, 44.25013415515423, 41.1317440867424, 39.70720052719116, 41.81488282978535, 39.5683977752924, 42.38309673964977, 41.3022181391716, 43.21014516055584, 40.66750019788742, 46.8287517875433, 46.30485109984875, 44.36700828373432, 42.37811520695686, 42.13101826608181, 44.606258645653725, 47.571695521473885, 46.8459040671587, 48.610502779483795, 45.628164410591125, 46.100289076566696, 45.07673420011997, 45.960426181554794, 48.43314729630947, 46.6477333009243, 48.883046954870224, 48.25093187391758, 48.69575120508671, 48.55500675737858, 49.9364872276783, 48.37670512497425, 49.88591194152832, 50.803847685456276, 49.50869858264923, 50.322865694761276, 48.28231059014797, 50.75620964169502, 51.550686210393906, 52.87836156785488, 54.16115753352642, 53.91798198223114, 55.44012330472469, 55.35422131419182, 55.65752863883972, 56.44760504364967, 59.0252461284399, 60.116980746388435, 65.68171754479408, 69.31412503123283, 73.06662127375603, 72.8499872982502, 75.90338945388794, 63.37051436305046, 15.319609455764294, 1.0316384676843882, 0.4652177944080904, 0.3952655370812863, 25.255164317786694, 76.76015987992287, 67.18313097953796, 66.55240282416344, 57.854186967015266, 34.31201443076134, 26.291330717504025, 42.53476180136204, 68.03616240620613, 52.695549577474594, 1.227018521167338, 0.1562968350481242, 0.15389573498396203, 0.052098058149567805, 0.028386927842802834, 0.07531642651883885, 0.033537282433826476, 0.20249111956218258, 0.1196451076248195, 0.1654172214330174, 0.13677992450539023, 0.2661960222758353, 0.23826462653232738, 0.20296924078138545, 0.2474723191699013, 5.138636687770486, 63.599011301994324, 67.65327215194702, 43.09521272778511, 32.98513323068619, 69.77187126874924, 67.78455510735512, 75.62836021184921, 90.29551237821579, 25.638983622193336, 0.9185865777544677, 3.241543360054493, 7.722960663959384, 20.650596097111702, 89.78102758526802, 80.54120019078255, 79.93168249726295, 81.6401544213295, 78.03784891963005, 77.78298899531364, 77.94059693813324, 77.18139007687569, 75.13576984405518, 79.3618954718113, 75.84426462650299, 74.13659825921059, 73.27083751559258, 74.35228228569031, 72.46742382645607, 68.90075281262398, 65.53318351507187, 61.58191613852978, 58.90795782208443, 58.69341753423214, 54.103347435593605, 55.96020519733429, 55.13454370200634, 52.38026909530163, 54.0393740683794, 55.49507975578308, 55.171386525034904, 52.32641838490963, 52.46161513030529, 51.89000800251961, 51.97059407830238, 55.83747178316116, 50.86619094014168, 49.080963134765625, 49.72170375287533, 53.538697734475136, 50.95160275697708, 50.626879781484604, 52.634072676301, 45.45791454613209, 46.34715422987938, 48.60066890716553, 48.07115212082863, 48.79328437149525, 45.291612669825554, 47.27993577718735, 46.476909667253494, 47.37161345779896, 47.24632278084755, 44.71944697201252, 46.95809684693813, 50.87342955172062, 45.22732771933079, 48.50947380065918, 50.98425820469856, 52.84001022577286, 53.01297314465046, 56.407353803515434, 57.315303683280945, 56.0626856982708, 54.1022302955389, 55.375553369522095, 59.85732167959213, 60.871871039271355, 56.386508122086525, 50.44075056910515, 46.070943251252174, 45.74729561805725, 42.617449164390564, 40.245631635189056, 60.242358818650246, 59.6770441532135, 54.613751247525215, 45.163251757621765, 48.23411017656326, 47.47825473546982, 47.74665333330631, 46.54509320855141, 51.507262140512466, 50.9011946618557, 48.90741124749184, 47.53889188170433, 43.259242326021194, 42.623395845294, 45.83290122449398, 43.56913849711418, 46.208651661872864, 43.99968579411507, 46.32738009095192, 43.67101103067398, 47.68810227513313, 48.150556460022926, 44.53387252986431, 42.941879555583, 42.47735448181629, 46.13794885575771, 49.96441192924976, 49.146965593099594, 50.86429484188557, 47.56125748157501, 49.822656735777855, 50.2156088501215, 50.68825788795948, 51.16156809031963, 49.96759995818138, 51.66661038994789, 50.31287983059883, 50.28246246278286, 51.045632511377335, 50.9650844335556, 50.32603472471237, 53.90578083693981, 54.55879099667072, 52.48205803334713, 51.6603597253561, 50.493871718645096, 54.243259727954865, 54.52202416956425, 55.52135534584522, 56.973401829600334, 57.25319981575012, 60.4882550239563, 60.03530412912369, 59.53492037951946, 59.111338108778, 62.278981134295464, 61.54036156833172, 71.11425563693047, 72.07149267196655, 78.09840247035027, 76.95996075868607, 79.46124494075775, 65.9842649102211, 17.182966768741608, 1.9274221127852798, 1.5660611470229924, 0.5547063471749425, 33.35609592497349, 83.52081790566444, 74.76095035672188, 72.68590450286865, 76.863172352314, 57.6845146715641, 28.815092593431473, 52.04853169620037, 73.88135835528374, 70.7630404829979, 2.3429839638993144, 0.30606075190007687, 0.2342095909989439, 0.2902146818814799, 0.21550735080381855, 0.17097458650823683, 0.12771693582180887], [0.06911639866302721, 0.023369556838588323, 0.14717759157065302, 0.026580666562949773, 0.04665957771067042, 0.031159240897977725, 0.03362963529070839, 0.08840259775752202, 4.14038322865963, 45.33462256193161, 39.07728552818298, 38.90234671533108, 33.76868158578873, 36.15286365151405, 56.9957522302866, 59.39880408346653, 74.13390040397644, 8.421609699726105, 0.5189275264274329, 0.30125113029498607, 0.2848746324889362, 51.60341218113899, 83.330068141222, 73.61702173948288, 74.44087073206902, 71.11601874232292, 73.84819373488426, 72.90040299296379, 71.51752799749374, 70.19611850380898, 67.67018124461174, 67.2345270216465, 65.86604565382004, 75.76269060373306, 68.1465008854866, 67.99189478158951, 63.8926063477993, 63.935931622982025, 59.11952666938305, 59.32982258498669, 56.022267267107964, 57.028430476784706, 54.252314642071724, 54.82131130993366, 51.96487918496132, 50.17562359571457, 51.2493471801281, 51.08331508934498, 47.48982131481171, 49.54370990395546, 46.20917983353138, 47.068830505013466, 45.94537898898125, 48.67381878197193, 46.08774594962597, 46.22255511581898, 44.34815749526024, 49.10782769322395, 43.3528883010149, 47.92965151369572, 50.574776977300644, 48.816178143024445, 44.49688531458378, 46.48999236524105, 45.22251717746258, 46.730230674147606, 44.7268033772707, 41.300223246216774, 38.991045355796814, 39.77165646851063, 39.96605023741722, 40.33357411623001, 42.36760497093201, 40.471879094839096, 40.99544160068035, 43.124140575528145, 40.61638914048672, 42.71256946027279, 47.97162406146526, 48.16055752336979, 52.62208051979542, 61.02585017681122, 55.0263749063015, 60.31645104289055, 53.82551774382591, 64.35310363769531, 45.4424911737442, 37.00497552752495, 49.85307030379772, 46.325233206152916, 37.62443348765373, 40.384806767106056, 58.44730854034424, 50.76044641435146, 50.4822139441967, 51.257121562957764, 50.46029292047024, 44.38777416944504, 44.453389048576355, 42.87546671926975, 44.82132710516453, 43.71530905365944, 39.57855463027954, 39.55679699778557, 38.34493562579155, 37.16536492109299, 40.22447817027569, 40.854237377643585, 39.130589067935944, 41.79959625005722, 39.31520216166973, 43.32727387547493, 48.623802065849304, 41.69557303190231, 44.304771423339844, 40.77245436608791, 41.23673625290394, 41.678751334548, 48.168863877654076, 45.38338914513588, 44.82918508350849, 46.04527562856674, 44.945664033293724, 42.683675810694695, 42.98984818160534, 47.31379196047783, 45.52040599286556, 44.960886016488075, 44.390137642621994, 46.34167492389679, 46.71401694417, 47.729197070002556, 46.14958383142948, 49.27912250161171, 48.713378459215164, 50.259648486971855, 49.63113181293011, 49.53813940286636, 50.25017559528351, 52.27917551994324, 50.67328289151192, 56.441844552755356, 58.43575716018677, 58.109898045659065, 56.31020821630955, 56.40710301697254, 52.857363894581795, 59.55770395696163, 61.272719129920006, 64.7239637374878, 68.39501515030861, 68.18604916334152, 71.2988269329071, 65.72706431150436, 72.98709914088249, 21.68741036206484, 0.7032539136707783, 0.4638313438044861, 0.23057523445459083, 9.203273355960846, 63.068989142775536, 62.23863869905472, 58.44113007187843, 51.10162630677223, 46.476567685604095, 27.07772321999073, 40.980060026049614, 53.320433646440506, 56.22155897319317, 2.4086757889017463, 0.1709258125629276, 0.030383828307094518, 0.049055731360567734, 0.020692852813226636, 0.06364979082718492, 0.060078798851463944, 0.004443270609044703, 0.11239479237701744, 0.07293508242582902, 0.041767496077227406, 0.08445578219834715, 0.07283415034180507, 0.17108443920733407, 0.15097259340109304, 5.860838759690523, 58.02281431853771, 48.69792468845844, 44.49605315923691, 24.221891462802887, 38.044500946998596, 67.65612199902534, 67.7493765950203, 83.17144945263863, 8.809794969856739, 0.5149623204488307, 0.5331763462163508, 0.8717071870341897, 58.61528232693672, 85.73038414120674, 78.3377668261528, 74.72934365272522, 74.38808396458626, 76.1572614312172, 74.68171700835228, 73.77807229757309, 74.13199290633202, 68.71277689933777, 68.48558709025383, 67.27441728115082, 74.58014085888863, 72.15074881911278, 71.76049456000328, 66.3261553645134, 65.33759281039238, 61.90895698964596, 62.446593940258026, 59.23958882689476, 58.55887055397034, 57.15732716023922, 60.508146956562996, 56.06422461569309, 52.06018567085266, 51.701515316963196, 54.309691563248634, 49.15303386747837, 52.17592366039753, 48.66550862789154, 51.90139599144459, 50.027689933776855, 50.91125652194023, 47.07860738039017, 49.184971153736115, 47.00186289846897, 51.82619422674179, 45.09273514151573, 50.42815804481506, 51.35808974504471, 47.75899887084961, 46.293615102767944, 46.222699508070946, 45.261909663677216, 47.526075169444084, 47.53753915429115, 43.95205534994602, 41.928614526987076, 42.271527126431465, 43.62284481525421, 42.62754142284393, 43.38799461722374, 43.12389738857746, 44.1260290145874, 44.83007803559303, 43.66402320563793, 44.17335167527199, 50.71114405989647, 53.26244495809078, 58.33492957055569, 62.597559839487076, 59.55965705215931, 59.45806950330734, 57.810238525271416, 67.14333951473236, 50.6615187227726, 41.06547184288502, 50.00297226011753, 48.3710890263319, 38.89011897146702, 44.68415826559067, 60.29353067278862, 52.373182475566864, 54.87076945602894, 54.49427045881748, 53.4098694473505, 49.15238790214062, 46.38285331428051, 44.80090320110321, 45.491759330034256, 45.807324796915054, 41.2385905534029, 43.031699135899544, 41.02210856974125, 40.61882480978966, 41.9393527507782, 41.73525430262089, 41.29212588071823, 43.754272162914276, 40.97919747233391, 46.852048337459564, 47.96191558241844, 42.11296163499355, 41.5438661724329, 41.92291483283043, 41.246672719717026, 42.7861563116312, 49.21777479350567, 46.526063829660416, 45.603860914707184, 47.44578167796135, 46.557301953434944, 47.430848479270935, 45.48355557024479, 49.03750866651535, 48.18038485944271, 48.19751434028149, 45.879657715559006, 47.04449661076069, 49.49136771261692, 48.568252846598625, 46.85101859271526, 51.06700636446476, 51.01221330463886, 51.5196380764246, 51.78587459027767, 52.16438747942448, 53.538344353437424, 54.23768162727356, 55.10359816253185, 58.09281416237354, 61.432644948363304, 59.718971103429794, 58.81053484976292, 58.52960832417011, 57.02418610453606, 62.553242817521095, 64.8673452436924, 68.31642016768456, 71.95252865552902, 72.37047582864761, 72.78985172510147, 67.54449158906937, 72.14820295572281, 27.872338481247425, 0.9148751862812787, 0.3597863361937925, 0.25499873561784625, 10.354152750223875, 70.82405760884285, 68.5967007279396, 65.52486956119537, 60.05794711410999, 41.2270125746727, 24.702715761959553, 48.345315009355545, 60.34844912588596, 67.23244473338127, 3.6765751289203763, 0.1324623022810556, 0.06524051757878624, 0.07780463987728581, 0.07625159196322784, 0.08063656408921815, 0.07340550757362507, 0.10003586648963392, 0.20255409821402282, 0.23146493593230844, 0.25836847198661417, 0.13478050444973633, 0.26545224187429994, 0.22786597983213142, 0.30718985537532717, 8.58049152418971, 74.33905899524689, 56.42002232372761, 55.38631819188595, 44.48933891952038, 50.19347503781319, 76.07858285307884, 73.69583711028099, 89.80581745505333, 11.908432748168707, 0.8471042790915817, 3.337474912405014, 5.541777005419135, 59.575714990496635, 88.5617034137249, 81.92935690283775, 77.77073845267296, 77.62753173708916, 76.42868846654892, 82.4234139919281, 75.62475800514221, 76.4337269961834, 71.8128253519535, 71.62525981664658, 67.74450525641441, 73.73557537794113, 75.35713076591492, 72.731654047966, 68.71754184365273, 68.16981643438339, 63.834135085344315, 64.1414625942707, 61.44521847367287, 61.53199061751366, 61.35423995554447, 62.83334098756313, 58.650460839271545, 55.64322240650654, 55.6840056180954, 56.93945065140724, 52.112831845879555, 54.11549538373947, 51.16678901016712, 53.97241026163101, 51.032238230109215, 53.597514778375626, 49.58330757915974, 51.32503531873226, 48.6899109184742, 55.69061726331711, 46.329211592674255, 52.847203239798546, 54.20800521969795, 49.14016775786877, 46.56960189342499, 45.21012224256992, 44.34147745370865, 46.846474036574364, 49.87116873264313, 47.8159312158823, 43.009474128484726, 44.30373027920723, 47.00976647436619, 46.80460788309574, 47.42905877530575, 45.980466306209564, 48.89517590403557, 48.6964313685894, 45.19283317029476, 48.576604798436165, 54.3274100124836, 54.12924684584141, 61.248134449124336, 66.51763468980789, 61.31449408829212, 64.03069093823433, 61.50586701929569, 67.74798586964607, 56.03957153856754, 47.37412512302399, 47.98910312354565, 50.13605631887913, 42.69252933561802, 47.61666610836983, 64.5715083181858, 55.80662503838539, 56.74370415508747, 58.097480311989784, 55.86188927292824, 50.18630862236023, 47.439766600728035, 47.82264545559883, 48.0960787832737, 48.367900997400284, 43.82316246628761, 46.40476293861866, 43.18531349301338, 43.25900673866272, 46.247626170516014, 46.063621044158936, 43.43464091420174, 47.284727320075035, 42.61725157499313, 50.27680076658726, 50.11153623461723, 42.96015277504921, 43.37581627070904, 41.18750609457493, 41.175806522369385, 43.20473425090313, 52.29883186519146, 48.54309059679508, 48.05481679737568, 50.68226560950279, 49.272499457001686, 48.384597301483154, 48.38214263319969, 52.765557020902634, 50.67164897918701, 49.783674627542496, 49.46450315415859, 50.46981520950794, 51.869219318032265, 52.25726589560509, 50.70000685751438, 54.03074473142624, 53.45565319061279, 55.03943860530853, 54.840530678629875, 54.86937873065472, 55.849881917238235, 58.07621665298939, 56.05553448200226, 62.64512948691845, 64.012740701437, 62.44263835251331, 61.87900699675083, 62.90248967707157, 59.52284462749958, 66.71327099204063, 68.45415517687798, 72.68913432955742, 75.84115639328957, 78.53562220931053, 75.87571933865547, 72.39208906888962, 69.80868369340897, 29.624851942062378, 1.6742014442570508, 0.8797909563872963, 0.2873996563721448, 12.20773508772254, 78.36687326431274, 75.34174919128418, 73.88049960136414, 69.63621854782104, 61.962283328175545, 39.22905318439007, 60.846609994769096, 66.90079092979431, 82.62199133634567, 6.992345368489623, 0.4671486251754686, 0.16585664707235992, 0.13097566174110398, 0.18751484662061557, 0.16463890147861093, 0.15428821236127988], [0.10147508379304782, 0.028498775063781068, 0.11187340394826606, 0.0444439106649952, 0.06571870559128001, 0.016890557526494376, 0.18341859220527112, 0.27969025599304587, 5.292375963181257, 41.01825177669525, 42.95704834163189, 44.13243167102337, 41.873741671442986, 47.49808207154274, 55.02618111670017, 63.830928057432175, 64.41985845565796, 1.805088627152145, 0.08087342794169672, 0.6405419006478041, 9.430354870855808, 84.65837806463242, 73.10265854001045, 78.73574987053871, 68.99778440594673, 71.85259401798248, 69.6769979596138, 79.82869282364845, 70.73868378996849, 71.53500705957413, 63.53048577904701, 72.37016424536705, 82.64760196208954, 71.03918686509132, 65.03871604800224, 72.91779085993767, 62.76431769132614, 67.51162335276604, 61.72491766512394, 62.75800243020058, 60.269052386283875, 62.269987016916275, 62.253959476947784, 64.31248381733894, 58.49389024078846, 53.71681697666645, 47.25458353757858, 50.98336525261402, 49.434097185730934, 48.4053897857666, 45.6891093403101, 49.033602476119995, 46.76602095365524, 47.89213612675667, 44.23936553299427, 48.05709287524223, 45.40575094521046, 46.29911720752716, 43.862634748220444, 46.261244639754295, 50.29337167739868, 49.557434767484665, 47.033028826117516, 46.370123997330666, 39.87257145345211, 38.89690160751343, 47.03250825405121, 49.10463586449623, 39.61789771914482, 39.12546694278717, 39.39458750188351, 41.92071095108986, 39.345938712358475, 39.7717210650444, 39.69099819660187, 41.11718326807022, 41.383909955620766, 38.53002369403839, 38.84677469730377, 40.18006235361099, 40.62466509640217, 45.92268280684948, 49.158817157149315, 54.186380580067635, 52.28238634765148, 53.09055358171463, 40.372062250971794, 46.26247577369213, 44.08617675304413, 48.41347195208073, 37.417010217905045, 39.32850904762745, 51.92331701517105, 56.824898198246956, 52.50840961933136, 51.69530265033245, 46.803676933050156, 50.329921916127205, 41.457398012280464, 43.671478405594826, 39.68995325267315, 42.2761894762516, 39.92480345070362, 40.853895395994186, 38.76602903008461, 39.050360172986984, 40.02926744520664, 40.283823385834694, 40.52634537220001, 42.1756886690855, 44.94134746491909, 46.80947922170162, 41.502915769815445, 42.869706228375435, 41.079344898462296, 44.90929618477821, 39.59941931068897, 44.40895043313503, 48.57523687183857, 44.077186435461044, 45.01631364226341, 46.081491485238075, 43.59458573162556, 42.66933158040047, 43.88213150203228, 46.02022737264633, 45.81721946597099, 46.15099735558033, 45.47000929713249, 45.92346556484699, 44.47952784597874, 47.17135280370712, 46.42679035663605, 48.933143466711044, 48.34674373269081, 52.7988850325346, 52.24427819252014, 52.870921567082405, 55.561481192708015, 56.86943180859089, 57.88878411054611, 59.98664774000645, 58.501972407102585, 58.17044019699097, 56.52035973966122, 57.5401908159256, 60.05036272108555, 64.81847986578941, 63.67810405790806, 66.81987047195435, 68.66394191980362, 71.4913322031498, 66.89301654696465, 76.79722309112549, 57.518794164061546, 27.671080380678177, 0.6433181266766042, 0.12830701743951067, 0.10120405146153644, 3.082554191350937, 62.01828092336655, 60.38945272564888, 62.90511153638363, 47.784548699855804, 65.85547462105751, 30.594797395169735, 26.739077791571617, 47.95709364116192, 67.1221974492073, 8.679287172853947, 0.3751133778132498, 0.21205513214226812, 0.03069080656132428, 0.05827581415360328, 0.10885612093261443, 0.08848917670547962, 0.055839599372120574, 0.016421854161308147, 0.058011249639093876, 0.03828492357570212, 0.07909976920927875, 0.039445249203708954, 0.13609792047645897, 0.130317450966686, 7.866186378523707, 57.149237394332886, 53.190389424562454, 53.573332875967026, 41.69062189757824, 52.64420673251152, 66.48758590221405, 70.89404985308647, 71.55924215912819, 1.8813524348661304, 0.045688792888540775, 0.8043313992675394, 12.220822535455227, 87.94402375817299, 76.81996867060661, 81.40533462166786, 72.55227327346802, 73.41261550784111, 70.73473200201988, 81.98760017752647, 72.88114562630653, 73.1727647781372, 68.1922048330307, 71.80929154157639, 76.94038420915604, 73.55841368436813, 68.21787625551224, 74.60794776678085, 65.81398084759712, 68.52527976036072, 64.39345747232437, 66.23508185148239, 63.39735992252827, 64.6559625864029, 64.84249457716942, 67.15267181396484, 61.46615155041218, 56.34499914944172, 48.90195474028587, 53.50336343050003, 51.79855450987816, 50.146900936961174, 48.27365085482597, 51.179902106523514, 49.81430858373642, 48.30198213458061, 47.809194177389145, 50.43804131448269, 46.032835096120834, 51.28971241414547, 44.68730069696903, 49.43791978061199, 51.701386123895645, 51.00780934095383, 48.365313336253166, 46.879634857177734, 42.82080665230751, 40.61345189809799, 48.22317436337471, 51.79594025015831, 41.14760063588619, 41.48317962884903, 43.624930903315544, 44.270033687353134, 42.25353129208088, 43.81707899272442, 44.86404821276665, 43.78388397395611, 43.3466300368309, 42.28188917040825, 41.593985483050346, 44.17758844792843, 42.79187500476837, 48.542505428195, 50.983574241399765, 55.065877586603165, 54.8693673312664, 51.4468339830637, 44.65259335935116, 50.46254999935627, 46.721190959215164, 49.67179723083973, 41.85245521366596, 42.585720866918564, 56.425961405038834, 58.702605441212654, 55.77368840575218, 53.68250101804733, 47.150533720850945, 52.55089893937111, 44.24257256090641, 44.6613746881485, 41.37411788105965, 44.156799763441086, 42.09623113274574, 42.64265701174736, 43.379004299640656, 41.12763270735741, 40.947396978735924, 43.49978841841221, 42.67068050801754, 45.008007287979126, 46.3249596208334, 47.57491394877434, 42.28652872145176, 44.62952099740505, 42.667743265628815, 45.26431493461132, 40.593525767326355, 44.73319463431835, 49.82006527483463, 45.87206572294235, 46.460103169083595, 47.081487625837326, 46.66452459990978, 45.0797588378191, 45.80810375511646, 47.956018298864365, 46.97433337569237, 46.94309525191784, 45.174381360411644, 49.333254396915436, 46.672097593545914, 49.853579476475716, 49.226415529847145, 50.7463301718235, 51.3273835927248, 55.0162560492754, 55.186787098646164, 55.56319110095501, 57.810519710183144, 60.096169263124466, 60.031812116503716, 62.55140371620655, 60.71716234087944, 61.12890064716339, 58.71647849678993, 60.05697816610336, 62.15837940573692, 67.92829379439354, 66.21894031763077, 70.19333705306053, 71.63833871483803, 74.94518727064133, 67.84185603260994, 76.39015093445778, 59.93343539535999, 34.24868322908878, 1.5906425029970706, 0.13568007649155334, 0.05535123280424159, 3.1290133483707905, 68.81996154785156, 66.66173055768013, 70.90243980288506, 55.19189402461052, 51.58494897186756, 29.660549126565456, 37.297472432255745, 52.386732548475266, 79.62488695979118, 11.708337385207415, 0.31677570194005966, 0.2547608327586204, 0.05858110773260705, 0.10624018395901658, 0.18239963828818873, 0.03817796896328218, 0.19193754211300984, 0.1759588354616426, 0.2219558719662018, 0.25786942220292985, 0.37949976744130254, 0.1773497389513068, 0.3784405149053782, 0.5389198567718267, 11.057137828320265, 68.55925753712654, 63.368485271930695, 64.00705620646477, 54.74987894296646, 69.4248814880848, 72.96284884214401, 75.8783183991909, 79.51018631458282, 2.6932572433725, 0.20849077496677637, 1.3850723463110626, 10.440771002322435, 91.18518143892288, 76.56392320990562, 85.22760272026062, 74.5176874101162, 77.252317070961, 73.93940404057503, 81.93225994706154, 75.99814876914024, 77.00842335820198, 70.27779132127762, 72.84319326281548, 72.01669961214066, 79.64507147669792, 69.12392243742943, 80.57699427008629, 66.86923742294312, 72.42255583405495, 64.80163916945457, 68.31547021865845, 65.91919720172882, 68.32337379455566, 66.58001974225044, 70.14335453510284, 64.69818592071533, 58.52410241961479, 50.83547718822956, 54.758097901940346, 53.856964856386185, 52.27369241416454, 50.12230105698109, 53.78777056932449, 53.43220464885235, 51.4770195633173, 50.12510910630226, 54.8158548027277, 49.203039184212685, 54.61020603775978, 46.81381858885288, 50.42018987238407, 54.18846666812897, 52.18775622546673, 47.627305537462234, 46.8188951164484, 43.45978796482086, 40.76761722564697, 49.09094899892807, 53.216174840927124, 46.33998021483421, 43.11512365937233, 46.795188188552856, 49.55292820930481, 43.55657257139683, 46.0538175702095, 45.18174156546593, 46.49917647242546, 47.80399985611439, 45.806082263588905, 43.07980075478554, 47.05219879746437, 46.279612854123116, 53.102184757590294, 54.79394517838955, 59.09561835229397, 57.985549718141556, 53.798687383532524, 44.93051044642925, 51.45255267620087, 49.188915342092514, 54.52776186168194, 43.22037421166897, 46.752740666270256, 59.686239659786224, 62.6298239082098, 57.22168430685997, 56.05597145855427, 52.21949212253094, 57.5810956209898, 46.79421164095402, 49.2209742218256, 44.37480926513672, 48.85518305003643, 45.48666760325432, 45.08031740784645, 46.60254992544651, 44.001441299915314, 44.1325456649065, 46.78432837128639, 45.93293085694313, 48.81547898054123, 48.38625021278858, 49.659907668828964, 42.75834180414677, 46.2850009649992, 43.17412309348583, 45.68943992257118, 39.163210317492485, 45.718607157468796, 52.834348529577255, 48.968181386590004, 48.98838110268116, 50.44507093727589, 49.068013429641724, 47.70260989665985, 48.43314729630947, 50.214130729436874, 48.992047905921936, 49.81673665344715, 48.51444013416767, 50.60154654085636, 49.43501673638821, 53.46529707312584, 50.907650515437126, 54.746322333812714, 53.09404939413071, 59.19727809727192, 57.65134625136852, 58.38692218065262, 61.20727904140949, 63.559162840247154, 63.93630400300026, 65.2720159292221, 64.00164529681206, 63.9430296421051, 62.39847332239151, 64.35299724340439, 65.9876999258995, 72.19462886452675, 69.12443161010742, 73.83002310991287, 74.53834310173988, 78.55468958616257, 70.8050662279129, 73.5823979973793, 62.870730981230736, 37.1974465996027, 1.808836532291025, 0.3195581026375294, 0.2681787736946717, 3.7618454033508897, 77.65888005495071, 72.60281816124916, 79.51888784766197, 64.63877230882645, 83.49868029356003, 39.08113472163677, 45.1287230104208, 60.46668738126755, 92.54048511385918, 17.31645740568638, 0.5649544566404074, 0.5381039693020284, 0.13417563925031573, 0.18448537011863664, 0.3340845450293273, 0.18125756207155064], [0.0857557354902383, 0.10413435476948507, 0.0347884395159781, 0.08774032743531279, 0.060342157375998795, 0.06859526998596266, 0.09715930209495127, 0.16564415534958243, 5.297123808413744, 49.96398255228996, 40.55056907236576, 52.841731533408165, 46.699000149965286, 48.14285807311535, 59.92384850978851, 67.13970690965652, 51.712568923830986, 0.45824822620488703, 0.11798501975135878, 9.154769908636808, 50.61758928000927, 86.7790062725544, 73.4162025153637, 77.63367980718613, 69.90241706371307, 73.63877937197685, 64.38436836004257, 71.35717660188675, 74.32450577616692, 73.06911394000053, 64.63815674185753, 67.71892502903938, 54.527545273303986, 59.33145649731159, 72.4176236987114, 67.8376230597496, 68.65154698491096, 66.13643914461136, 66.12997189164162, 63.668745160102844, 67.2398467361927, 64.23457279801369, 69.3323564529419, 64.41849052906036, 63.814961314201355, 55.8210414648056, 48.99701803922653, 49.22667771577835, 47.627864107489586, 48.47552642226219, 45.798562467098236, 45.602755174040794, 48.426178470253944, 47.835245579481125, 45.62515877187252, 44.89354982972145, 46.89267195761204, 44.80620391666889, 48.01080375909805, 46.94059118628502, 48.49961332976818, 50.68760812282562, 52.75196135044098, 42.24936291575432, 38.8866763561964, 44.71478842198849, 42.81271688640118, 48.039017245173454, 46.65661722421646, 42.2367437928915, 40.99302493035793, 38.74179393053055, 39.80776973068714, 39.98082384467125, 40.60085937380791, 41.13163389265537, 38.79546605050564, 38.6050658673048, 39.10305194556713, 38.03509645164013, 39.061774760484695, 39.84123453497887, 37.67919234931469, 40.39329171180725, 40.44710822403431, 39.243336617946625, 42.156929075717926, 41.559023559093475, 45.6650148332119, 45.11281706392765, 43.53823475539684, 39.96169947087765, 41.71233393251896, 43.107676059007645, 38.475728407502174, 38.1925980001688, 42.12344527244568, 42.19793647527695, 39.87864352762699, 39.39760074019432, 37.134449779987335, 40.34982584416866, 37.63956427574158, 39.66856800019741, 38.296370431780815, 38.3172807097435, 39.24164950847626, 39.10237558186054, 40.49588620662689, 46.624995321035385, 47.1611275523901, 46.38256072998047, 42.724827602505684, 42.2473756223917, 37.436286583542824, 38.24717827141285, 40.888196155428886, 43.285886496305466, 45.47007009387016, 44.16750378906727, 45.19194021821022, 44.628175869584084, 43.54490339756012, 41.8505135178566, 43.577957823872566, 45.55925130844116, 43.25590990483761, 44.82364498078823, 45.4661563038826, 45.499484315514565, 45.730937495827675, 47.635976672172546, 49.70046669244766, 52.79609218239784, 52.917313277721405, 53.118911460042, 55.03333233296871, 53.71920704841614, 55.36611847579479, 59.77007456123829, 58.73973324894905, 58.59326630830765, 57.78411492705345, 60.544024631381035, 60.82332104444504, 61.52053043246269, 59.59728263318539, 65.41850566864014, 73.4860047698021, 66.70583099126816, 67.60114654898643, 67.43521705269814, 84.27309393882751, 55.93632347881794, 56.69727064669132, 46.78921490907669, 4.264802802354097, 0.37050116749014705, 0.13326883869012818, 0.9405153198167682, 49.33291621506214, 65.56975275278091, 63.24228264391422, 53.2253323495388, 71.71479061245918, 24.83603160828352, 38.93081858754158, 55.86082153022289, 64.14627313613892, 12.663795165717602, 0.504391643917188, 0.18679426575545222, 0.12046369651216082, 0.03834607283351943, 0.04652851072023623, 0.02839436045178445, 0.058225132888765074, 0.04938579040754121, 0.08494067180436105, 0.12955027807038277, 0.026196705330221448, 0.09594678864232264, 0.06307121249847114, 0.1660807162988931, 9.211042039096355, 65.12766927480698, 46.77949123084545, 59.71156910061836, 48.155101016163826, 51.58237650990486, 69.81683805584908, 73.90836730599403, 58.76877889037132, 0.5128373438492417, 0.07456856430508196, 11.96404941380024, 58.40350829064846, 87.14955478906631, 78.74400302767754, 80.28430357575417, 71.72856107354164, 73.85143876075745, 69.27701622247696, 72.61462792754173, 75.98656699061394, 72.13412091135979, 67.10288688540459, 62.58409336209297, 54.71927538514137, 63.074278458952904, 74.57080855965614, 70.0537933409214, 70.82440719008446, 69.61095750331879, 67.35719963908195, 67.01373606920242, 69.07573342323303, 66.40423357486725, 71.52848660945892, 66.41892358660698, 66.00419864058495, 57.42400825023651, 52.38912262022495, 51.87157519161701, 49.16440285742283, 49.89638797938824, 48.97504761815071, 48.30655328929424, 49.294013902544975, 49.46160390973091, 47.543174251914024, 46.3850761950016, 48.81475321948528, 46.85623571276665, 50.59950225055218, 48.15238416194916, 52.630945444107056, 53.124394565820694, 50.24076350033283, 44.58160936832428, 40.52352212369442, 47.67125017940998, 43.28500494360924, 49.17474590241909, 49.29754391312599, 43.43477390706539, 43.205801993608475, 43.374262154102325, 43.169624134898186, 42.55830533802509, 43.335519433021545, 43.93834948539734, 42.00016088783741, 41.90724067389965, 42.58381336927414, 40.70959813892841, 41.67928330600262, 42.70889885723591, 39.83133986592293, 42.064461037516594, 41.335390359163284, 42.51507505774498, 45.16746573150158, 43.084463104605675, 46.53174452483654, 47.345087081193924, 45.1895197480917, 43.811998665332794, 45.054011419415474, 45.24370864033699, 42.361137717962265, 42.96624384820461, 45.12148059904575, 44.09332416951656, 42.5800933688879, 41.1823345720768, 40.37320978939533, 42.76820607483387, 40.801097229123116, 42.463097646832466, 41.43700070679188, 41.61792039871216, 42.26618081331253, 42.35252358019352, 42.47073903679848, 48.572489619255066, 47.01528377830982, 46.738221645355225, 44.81846585869789, 42.667177096009254, 39.815490916371346, 39.48563441634178, 42.53692768514156, 44.86994169652462, 47.59861707687378, 46.56025439500809, 45.69398067891598, 46.11282840371132, 46.25871017575264, 43.99935521185398, 45.25251656770706, 47.66823694109917, 46.58059470355511, 46.93368695676327, 47.276907339692116, 47.102443501353264, 47.28357218205929, 50.23624934256077, 51.552802696824074, 54.58807222545147, 54.88751135766506, 55.60378432273865, 57.31821812689304, 55.35232901573181, 59.03371587395668, 61.92029558122158, 60.36986477673054, 60.8233742415905, 61.117360666394234, 63.58025550842285, 64.56222921609879, 65.08659347891808, 64.41481992602348, 67.60731741786003, 74.88667041063309, 69.98339831829071, 71.12915083765984, 70.31476333737373, 80.66051378846169, 60.33560961484909, 59.259256571531296, 53.46630401909351, 4.643820114433765, 0.2367949069594033, 0.06988962748437189, 0.6960847671143711, 56.051073521375656, 72.98948541283607, 70.97275882959366, 58.697057738900185, 64.80918556451797, 22.200154848396778, 42.609587386250496, 60.80024108290672, 74.07016262412071, 17.559980638325214, 0.6665019888896495, 0.2840372227365151, 0.04177031994913705, 0.09497479783021845, 0.09535646953736432, 0.05048944934969768, 0.160231449699495, 0.2437908956198953, 0.167390369460918, 0.2958683035103604, 0.1260528774582781, 0.1549489761237055, 0.25045141868758947, 0.506503974320367, 13.538079801946878, 77.91645303368568, 56.138085052371025, 67.24991619586945, 59.01715636253357, 64.63782995939255, 75.5549405515194, 80.79617410898209, 68.22847008705139, 0.7436472305562347, 0.3063229675171897, 16.0313131660223, 61.6585960239172, 88.56526762247086, 79.94134157896042, 80.63232690095901, 75.6548447906971, 76.52416974306107, 73.50754201412201, 74.28429633378983, 74.82841953635216, 75.45943647623062, 69.46009039878845, 68.07073295116425, 61.41709238290787, 68.62738028168678, 76.11414134502411, 72.8256306052208, 73.0677156150341, 70.96544042229652, 70.52340254187584, 68.72890323400497, 72.13157504796982, 68.4139609336853, 73.19722026586533, 70.18995523452759, 70.27810290455818, 62.65555612742901, 53.4947606921196, 54.386911019682884, 52.86349676549435, 52.3205628991127, 51.45051218569279, 50.13638310134411, 52.78702586889267, 54.07432459294796, 49.067002683877945, 51.12896963953972, 53.195492550730705, 47.955117747187614, 53.37620325386524, 50.43321177363396, 53.5551318526268, 55.897945538163185, 51.67177051305771, 46.72657527029514, 42.58518889546394, 49.14155848324299, 45.2960242331028, 50.30211880803108, 51.96444220840931, 48.344604447484016, 46.30807712674141, 46.788481548428535, 45.485360473394394, 45.10512247681618, 46.395609229803085, 46.97329983115196, 42.62553513050079, 46.14112548530102, 45.094410851597786, 42.889670357108116, 45.97194716334343, 44.01542454957962, 44.25704978406429, 46.78344301879406, 46.57972075045109, 45.30112735927105, 47.24295616149902, 46.23708933591843, 51.85421012341976, 50.76162815093994, 46.97098955512047, 44.97110366821289, 48.21130000054836, 49.471563175320625, 43.67655873298645, 45.085241943597794, 49.07446928322315, 46.59733660519123, 44.85576465725899, 44.14220854640007, 42.44528040289879, 44.95249606668949, 43.06552492082119, 45.46034261584282, 44.556675106287, 43.40149149298668, 46.144989877939224, 44.292802065610886, 46.5803325176239, 50.41568711400032, 47.00135372579098, 47.294914573431015, 44.865032359957695, 44.22509349882603, 40.309696197509766, 41.204859763383865, 41.64118655025959, 45.125211998820305, 49.99146267771721, 47.38283805549145, 49.727095663547516, 49.12760183215141, 49.19757127761841, 47.77563437819481, 46.92116282880306, 50.20436905324459, 49.29133124649525, 47.302305176854134, 49.338931292295456, 49.47978213429451, 48.30803140997887, 53.113926127552986, 54.38268944621086, 56.259499937295914, 59.9175750464201, 58.6612256616354, 61.25305898487568, 58.67059215903282, 62.692425549030304, 66.20225921273232, 64.2071458697319, 64.97526705265045, 63.877011984586716, 67.93998956680298, 65.45608565211296, 67.43302077054977, 65.78874260187149, 69.85279932618141, 75.66731572151184, 74.3725124001503, 74.54550951719284, 73.3838738501072, 80.43640181422234, 64.07658487558365, 65.39621606469154, 56.88785322010517, 5.689728241413832, 0.6423326733056456, 0.22552698268555105, 1.24015690991655, 64.79871332645416, 80.45055985450745, 81.90117001533508, 68.62219735980034, 90.24410113692284, 35.43222092092037, 57.01587215065956, 67.61581376194954, 83.69499295949936, 23.264225050807, 0.9879124921280891, 0.3428346145665273, 0.3963223850587383, 0.1707447730586864, 0.25812302890699357, 0.1736022939439863], [0.018952690916194115, 0.04370162198028993, 0.09607481653802097, 0.07735114311799407, 0.0833667695405893, 0.034102784120477736, 0.0805966959160287, 0.23552237602416426, 6.594450669363141, 47.25643403828144, 36.429636999964714, 45.27860976755619, 44.61426101624966, 54.290791377425194, 56.178138703107834, 71.59084126353264, 36.21834933757782, 0.05228518697549589, 0.1481275405967608, 2.216261001303792, 60.795844718813896, 76.30375877022743, 75.8848312497139, 72.34430283308029, 72.37304449081421, 73.01553681492805, 73.750379383564, 62.27691024541855, 64.68281954526901, 66.89382210373878, 64.08840984106064, 39.25233833491802, 48.80914092063904, 67.01188936829567, 66.73895761370659, 71.9699165225029, 68.6534620821476, 69.1594809293747, 65.64663782715797, 67.89260610938072, 64.96515199542046, 62.060667648911476, 65.27956232428551, 61.723781526088715, 61.456450670957565, 55.533499494194984, 47.46039189398289, 49.09477159380913, 49.746398627758026, 47.77759127318859, 47.58952796459198, 47.66583926975727, 48.60893726348877, 46.22089080512524, 45.54702736437321, 46.34935811161995, 46.316280886530876, 45.13254180550575, 48.70950646698475, 46.79752126336098, 51.07360281050205, 50.435164868831635, 44.210950657725334, 39.00210276246071, 38.365511521697044, 49.18751701712608, 47.6777820289135, 46.465514078736305, 44.661560878157616, 44.8836475610733, 38.5778821259737, 41.35218545794487, 38.62938456237316, 40.324469804763794, 38.74226130545139, 40.662632659077644, 39.967022985219955, 39.7393885999918, 37.3210159689188, 41.02597676217556, 39.53518755733967, 36.89466744661331, 38.70138309895992, 41.26623027026653, 39.97001342475414, 44.24562759697437, 41.10017158091068, 42.953810915350914, 43.679598569869995, 39.82472062110901, 41.11791282892227, 41.74191914498806, 38.17248187959194, 38.53625535964966, 37.667800560593605, 39.607851058244705, 38.52852277457714, 40.47389678657055, 39.146772399544716, 41.02451004087925, 37.754565104842186, 40.75827732682228, 37.933151721954346, 40.957105457782745, 37.84002631902695, 39.53158915042877, 41.20020881295204, 39.690713211894035, 40.46893425285816, 43.9600121229887, 42.91183076798916, 45.79768851399422, 45.23270063102245, 48.80710043013096, 39.93874490261078, 41.70252665877342, 40.95752723515034, 45.91021187603474, 47.81854547560215, 43.53617526590824, 47.71329112350941, 41.97456546127796, 43.34683142602444, 41.012175902724266, 45.091845989227295, 45.77362820506096, 45.083288848400116, 46.21857672929764, 44.85710598528385, 45.911864787340164, 47.92875096201897, 52.23825931549072, 53.966015204787254, 52.68340542912483, 54.65834565460682, 56.83054469525814, 53.29109162092209, 58.22624400258064, 57.01951615512371, 59.53176274895668, 60.43015994131565, 61.11914277076721, 59.49495032429695, 60.92082381248474, 61.834731772542, 62.61535048484802, 67.1958526968956, 65.92104390263557, 81.03726357221603, 73.50051999092102, 69.5770101249218, 80.23154720664024, 55.972163155674934, 53.04144501686096, 71.43355250358582, 49.757931008934975, 7.136958483606577, 0.11522470536874607, 0.06027059207553975, 0.10735316798673011, 36.098705157637596, 67.46413350105286, 61.776587292551994, 56.34991988539696, 38.7216018140316, 25.325122363865376, 26.33427031338215, 43.34191828966141, 64.25937786698341, 16.748792566359043, 0.5345847050193697, 0.12701274157734588, 0.00917699277124484, 0.03923141419363674, 0.03599822928663343, 0.08307972166221589, 0.008979853300843388, 0.08093671087408438, 0.0967752852011472, 0.0889338567503728, 0.10018367262091488, 0.08529527738573961, 0.1454499311512336, 0.43063754215836525, 9.85401313751936, 62.03734830021858, 43.633180260658264, 48.31360571086407, 50.6485728174448, 62.3899731785059, 62.34777644276619, 79.60512802004814, 40.008113980293274, 0.11290921946056187, 0.24279169767396525, 2.7208727365359664, 65.52819058299065, 79.22368168830872, 79.99007016420364, 76.96389734745026, 73.59242185950279, 73.53362381458282, 76.8559679389, 65.72648674249649, 69.41275253891945, 69.0014474093914, 66.33621722459793, 42.90772318840027, 52.81956732273102, 67.87212520837784, 69.84941750764847, 72.72656992077827, 71.0261307656765, 69.77646142244339, 68.19279000163078, 69.25345748662949, 67.14673653244972, 67.36691951751709, 66.59357741475105, 64.33112561702728, 64.71087723970413, 58.70566047728062, 49.34032961726189, 50.32982312142849, 49.90817114710808, 50.32532036304474, 49.62027579545975, 48.02927076816559, 48.770781978964806, 50.51052622497082, 46.38463541865349, 48.22637379169464, 48.877989426255226, 48.19139286875725, 49.91917535662651, 50.92309668660164, 53.12556490302086, 52.68041878938675, 45.365188121795654, 41.852911189198494, 38.434671610593796, 50.583292320370674, 48.856079801917076, 46.46752417087555, 46.51539780199528, 47.434929460287094, 42.92441949248314, 44.44558806717396, 42.016526609659195, 42.05562651157379, 41.36899195611477, 42.44279533624649, 42.24151633679867, 41.09474927186966, 40.70728786289692, 42.109234035015106, 42.0910520106554, 41.59707851707935, 41.05170898139477, 42.545040249824524, 43.009747713804245, 44.919734224677086, 43.192981481552124, 46.832695975899696, 45.98605200648308, 43.149652406573296, 44.22317460179329, 43.419624119997025, 41.7908301204443, 42.29225501418114, 40.55062606930733, 42.02530413866043, 40.09386017918587, 43.72947469353676, 44.214587062597275, 42.27647066116333, 40.653501749038696, 42.121708765625954, 41.13822653889656, 43.17064248025417, 41.724782064557076, 42.947062477469444, 42.61591024696827, 41.901123002171516, 42.82814405858517, 44.6502260863781, 42.547304928302765, 47.694759517908096, 47.96577997505665, 48.280486688017845, 40.80428145825863, 42.21783600747585, 40.33752590417862, 47.19436816871166, 48.44491146504879, 44.01697866618633, 47.83105820417404, 44.58466820418835, 45.53768366575241, 43.41626890003681, 46.54665872454643, 48.649880066514015, 49.27517831325531, 48.15743789076805, 48.06360952556133, 46.537657007575035, 52.53611773252487, 55.00867545604706, 56.85202494263649, 56.56987868249416, 56.776583790779114, 58.51618364453316, 57.1959862858057, 59.62633207440376, 59.71208207309246, 62.76536263525486, 62.5547019392252, 63.502120301127434, 61.990436017513275, 63.85340765118599, 63.558999449014664, 67.30406329035759, 68.74321326613426, 69.78906914591789, 78.6457858979702, 75.16055211424828, 70.70546597242355, 78.28035190701485, 57.24850706756115, 55.40514998137951, 75.39824455976486, 55.814714804291725, 9.564302433282137, 0.43647842248901725, 0.09403122385265306, 0.1332062904839404, 40.96059367060661, 73.25666427612305, 69.10618498921394, 64.24899682402611, 46.02614365518093, 24.760482162237167, 36.61644637584686, 49.84020039439201, 74.24831226468086, 22.818223983049393, 0.47208936943206936, 0.18841575452825055, 0.05030012376664672, 0.08744798804400489, 0.023344950932369102, 0.054940865957178175, 0.1059184926270973, 0.2894715842558071, 0.1278457132866606, 0.21728872787207365, 0.1982561725890264, 0.20930969039909542, 0.29318920976947993, 0.5972423928324133, 16.42799288034439, 79.58847731351852, 52.63812705874443, 59.429122656583786, 57.871935814619064, 78.83909672498703, 67.20231994986534, 86.64499506354332, 44.68643434345722, 0.21827790682436898, 0.45970233099069446, 5.04917286336422, 69.89151164889336, 79.16803747415543, 86.02277085185051, 78.42992708086967, 76.91193893551826, 77.5172008574009, 78.19402053952217, 70.97951486706734, 71.81464165449142, 72.35458508133888, 67.4455676972866, 48.03885005414486, 55.34206196665764, 67.67885997891426, 75.5735595524311, 75.86191847920418, 72.24000602960587, 72.76862606406212, 70.02164706587791, 71.11073702573776, 69.52289342880249, 67.6893550157547, 72.76317715644836, 67.73498296737671, 65.61715140938759, 61.19454212486744, 51.95412576198578, 53.57506938278675, 51.98476731777191, 51.58024862408638, 52.05025680363178, 50.91230906546116, 53.01184840500355, 52.74487853050232, 49.789290726184845, 51.522636115550995, 51.81639835238457, 51.49792604148388, 53.229234740138054, 53.65129329264164, 54.765325114130974, 55.37926197052002, 46.37857474386692, 42.8449771553278, 42.77052395045757, 53.59455853700638, 50.50291523337364, 47.061926275491714, 45.609640404582024, 49.609700962901115, 44.59883764386177, 48.1290116161108, 45.10278940200806, 45.544967874884605, 45.15914797782898, 45.50293833017349, 46.152023300528526, 43.97675782442093, 44.465711787343025, 46.30422033369541, 45.44866964221001, 42.419354394078255, 45.328269302845, 46.62774257361889, 46.032268926501274, 48.61732721328735, 45.51385134458542, 48.90156336128712, 47.21281997859478, 45.685009360313416, 47.83432602882385, 46.4915806800127, 44.89046059548855, 43.07679131627083, 43.00119437277317, 44.98566448688507, 43.67166079580784, 48.323773965239525, 45.445341020822525, 46.10910080373287, 42.61061333119869, 46.653394997119904, 44.316444396972656, 48.28514903783798, 45.541331470012665, 47.54816338419914, 45.134669691324234, 44.11119841039181, 43.417883813381195, 45.76820209622383, 42.33637444674969, 48.641664907336235, 47.16002941131592, 49.2732822149992, 40.9270528703928, 42.914536222815514, 40.88394798338413, 48.054968789219856, 52.670330330729485, 48.3846390992403, 51.65009647607803, 48.307446241378784, 47.02423229813576, 45.69644294679165, 49.044800475239754, 50.95519736409187, 50.0508838891983, 50.65203823149204, 49.34607490897179, 49.563069865107536, 53.53226087987423, 58.16562205553055, 58.32854971289635, 60.96370451152325, 60.69434076547623, 61.9017069786787, 58.99525433778763, 63.905738443136215, 62.44568958878517, 64.86726924777031, 65.08185893297195, 68.08314308524132, 64.70163613557816, 67.53518968820572, 67.27735072374344, 70.89928597211838, 72.06137001514435, 74.41277503967285, 83.1612204015255, 74.38362300395966, 75.33690065145493, 77.09536269307137, 66.29745930433273, 61.61791920661926, 75.79374253749847, 58.452366068959236, 10.103977974504232, 0.7602921186480671, 0.5307836621068418, 0.1827171735931188, 47.34121508896351, 81.73647925257683, 77.0261000096798, 72.92712315917015, 57.21996679902077, 35.62186114490032, 41.535217836499214, 58.36839817464352, 85.65130278468132, 31.072420366108418, 0.8438016031868756, 0.3339354624040425, 0.1274455917882733, 0.16730534902308136, 0.20158670871751383, 0.15454567823326215], [0.03345856654050294, 0.10344213878852315, 0.006638770255449344, 0.04778353439178318, 0.013609364941657986, 0.041342627664562315, 0.05962781797279604, 0.0713975602411665, 2.9426198126748204, 43.71074549853802, 35.821776017546654, 46.069039553403854, 34.58502598106861, 50.98295107483864, 59.288351610302925, 75.41478127241135, 38.39189350605011, 0.47714244516100734, 0.31176745193079114, 3.410163586959243, 75.10618463158607, 76.64696395397186, 77.07465380430222, 72.13692516088486, 71.33731126785278, 72.35399231314659, 71.67936131358147, 71.76415756344795, 68.46031084656715, 68.3996433019638, 72.35865086317062, 67.75453671813011, 68.39060738682747, 60.716523975133896, 62.4603758007288, 62.99036756157875, 66.21164470911026, 66.74944505095482, 69.1249331831932, 64.02358531951904, 67.16525673866272, 63.85391682386398, 65.31327411532402, 62.27698244154453, 64.73093256354332, 53.63041341304779, 49.00047205388546, 50.43934464454651, 47.7081385999918, 47.91527308523655, 47.95698344707489, 45.370317846536636, 48.015393912792206, 46.14010713994503, 45.91650053858757, 46.46262243390083, 45.71516074240208, 46.15934170782566, 46.22256651520729, 44.230777993798256, 47.55534879863262, 48.02237793803215, 46.18683323264122, 39.88240532577038, 38.24812062084675, 43.2978368550539, 53.51147219538689, 52.41796687245369, 47.609195709228516, 46.25468999147415, 44.23838898539543, 40.990513265132904, 38.26740078628063, 38.88270556926727, 38.26739318668842, 40.38488656282425, 39.936092644929886, 41.23917192220688, 40.574956163764, 40.29576234519482, 40.6830907613039, 39.61971402168274, 38.314001485705376, 40.86629793047905, 39.86701235175133, 41.235087141394615, 42.479645758867264, 40.59612102806568, 41.262202486395836, 39.860123321413994, 40.887690782547, 40.026516392827034, 38.92519868910313, 39.221563786268234, 38.450372368097305, 37.4294925481081, 37.71320812404156, 41.17495156824589, 41.53840206563473, 41.107265800237656, 40.89385785162449, 40.26575915515423, 40.52288755774498, 39.9313011020422, 40.04465661942959, 38.94974537193775, 39.314305409789085, 40.17708331346512, 42.40123316645622, 42.05643206834793, 45.97752146422863, 46.99542224407196, 40.42027026414871, 38.274502605199814, 33.793376460671425, 39.76877622306347, 40.09526610374451, 47.23319448530674, 46.23188741505146, 43.41916434466839, 44.229911640286446, 42.40737743675709, 43.13163757324219, 40.47515071928501, 43.76076981425285, 46.9162192940712, 47.022077813744545, 46.07261136174202, 45.64745217561722, 46.52104429900646, 52.62698605656624, 59.39110949635506, 60.004198998212814, 57.97534726560116, 56.356143951416016, 55.891162902116776, 55.846940875053406, 57.49960899353027, 56.629915460944176, 57.47632384300232, 60.78916847705841, 59.072291404008865, 64.56900805234909, 61.61068059504032, 63.81525009870529, 64.95056077837944, 67.53420174121857, 64.20298889279366, 67.06457734107971, 83.42905282974243, 66.51736870408058, 49.43193510174751, 51.280858889222145, 70.76728865504265, 67.06860512495041, 61.197118386626244, 14.183607213199139, 0.25068112823646516, 0.06654759548837319, 0.11790270815254189, 23.409837037324905, 70.04164159297943, 59.96298260986805, 57.32872076332569, 39.744856506586075, 19.416133537888527, 33.68652619421482, 46.16874620318413, 61.67931251227856, 21.709597371518612, 0.4026515095029026, 0.1722786290338263, 0.029216762122814544, 0.07505208835937083, 0.014677980598207796, 0.028686495752481278, 0.006288149543252075, 0.08633040270069614, 0.023624100504093803, 0.10122725841938518, 0.02793651099636918, 0.0634544352942612, 0.10537748923525214, 0.3048133500851691, 9.284575693309307, 58.74993570148945, 47.70867817103863, 47.93201878666878, 37.62341134250164, 56.9857207685709, 65.75510680675507, 83.25227111577988, 43.46574604511261, 0.3519385104300454, 0.1421251689316705, 4.546091733500361, 79.45514246821404, 81.20773002505302, 79.62209030985832, 73.8457390666008, 74.9635174870491, 74.41191628575325, 74.48883175849915, 74.46477144956589, 70.90784311294556, 71.34107306599617, 72.9818706214428, 69.03024986386299, 69.74351719021797, 63.64029988646507, 65.55982768535614, 64.36596974730492, 68.13746497035027, 66.86787709593773, 71.13010078668594, 65.2702072262764, 69.02369901537895, 65.6713593006134, 64.61590513586998, 65.0763188302517, 66.68266743421555, 53.83136183023453, 50.385094955563545, 52.009937167167664, 50.25447316467762, 51.19552306830883, 50.32469719648361, 47.04120218753815, 49.00141440331936, 48.14706824719906, 47.849779799580574, 46.83933041989803, 48.39819677174091, 48.28705653548241, 47.7627644687891, 47.33878321945667, 49.446883499622345, 50.19506335258484, 44.96243253350258, 41.27693809568882, 42.12676249444485, 45.7391032576561, 54.21384930610657, 53.86322312057018, 47.675266563892365, 47.245908603072166, 45.79008512198925, 43.01918640732765, 41.03615261614323, 40.92723146080971, 40.93443967401981, 42.45672158896923, 42.79336832463741, 43.48112002015114, 42.45256081223488, 43.32163117825985, 41.50972880423069, 42.46292285621166, 41.71081401407719, 44.51335743069649, 42.82164640724659, 43.330914080142975, 43.37117291986942, 41.98070973157883, 44.80844959616661, 42.21199952065945, 44.27405767142773, 43.499526232481, 41.432771533727646, 40.73646269738674, 40.90650737285614, 38.38328696787357, 41.5169408172369, 41.90900377929211, 42.905336916446686, 43.33823248744011, 44.85713638365269, 41.81240156292915, 42.31225714087486, 41.78472004830837, 43.08614641427994, 40.78491389751434, 42.36603945493698, 43.616073578596115, 43.02791453897953, 43.6000270396471, 46.42038010060787, 48.898664116859436, 43.80563400685787, 38.608079105615616, 34.96152497828007, 40.307990089058876, 41.34006030857563, 49.41100962460041, 48.52137476205826, 45.8058200776577, 45.131952837109566, 44.832574501633644, 44.256692603230476, 44.50191244482994, 45.715981498360634, 48.673229813575745, 50.71218520402908, 48.02527338266373, 46.60484120249748, 48.978824615478516, 55.51294259727001, 59.603609293699265, 61.248039454221725, 60.20189858973026, 59.113906770944595, 58.11574973165989, 60.65861128270626, 59.92166742682457, 58.099744990468025, 59.64576043188572, 62.60368891060352, 62.021297961473465, 65.37230774760246, 64.3684396147728, 65.14024659991264, 69.59139615297318, 67.96243116259575, 68.10402676463127, 69.98709172010422, 78.00525426864624, 67.0061668753624, 49.69575114548206, 56.062305718660355, 71.99541315436363, 69.18948411941528, 67.52541661262512, 18.53777837008238, 0.2844525285763666, 0.09523735483526252, 0.26209954521618783, 27.157933115959167, 76.59320443868637, 67.19303324818611, 66.79412305355072, 48.12070906162262, 19.75462507456541, 37.51911833882332, 52.87900373339653, 70.71779251098633, 30.12314200401306, 0.45761000888887793, 0.19798374501988292, 0.05505551664100494, 0.1290063580381684, 0.02452882119541755, 0.052436570258578286, 0.14923914422979578, 0.25972214934881777, 0.1901865188847296, 0.2607506769709289, 0.18662866292288527, 0.16280444600852206, 0.3193795419065282, 0.6070118467323482, 14.827217627316713, 77.83921837806702, 52.72358447313309, 58.39294485747814, 44.1705322265625, 68.14654648303986, 72.07837030291557, 90.09394079446793, 47.27684274315834, 0.878203057218343, 0.48419833998195827, 5.855467272922397, 84.53827410936356, 82.36023858189583, 84.31587964296341, 78.15799087285995, 77.15220764279366, 76.65657743811607, 75.97612515091896, 75.65412282943726, 71.97915002703667, 73.29365149140358, 74.33436244726181, 70.4934373497963, 70.90152785181999, 64.19320061802864, 69.50406163930893, 66.27915188670158, 70.3634463250637, 68.10851812362671, 74.56045791506767, 69.1395927965641, 72.8352364897728, 68.56390848755836, 68.10644343495369, 67.1091565489769, 70.92918276786804, 56.75280846655369, 53.342582657933235, 53.64805966615677, 52.193816900253296, 54.204988181591034, 52.452324628829956, 50.57501636445522, 53.184362947940826, 50.73784522712231, 49.478380009531975, 50.9616494178772, 49.58080731332302, 48.9495699852705, 51.102743446826935, 50.07313549518585, 52.05007441341877, 51.74651250243187, 46.9755607098341, 45.04652202129364, 43.30147325992584, 47.540259808301926, 56.75782799720764, 57.283636182546616, 47.43222400546074, 46.806222796440125, 46.95063404738903, 46.96851588785648, 44.30547438561916, 43.74165304005146, 43.13351467251778, 47.111646607518196, 47.51941792666912, 47.83546216785908, 44.73089575767517, 45.99058896303177, 44.602622240781784, 46.315703317523, 43.417146652936935, 47.43481546640396, 44.82433274388313, 46.11541606485844, 47.61358827352524, 45.95615901052952, 46.624060571193695, 46.68649882078171, 46.22623331844807, 44.357090815901756, 43.31715501844883, 45.92174045741558, 43.229254335165024, 40.54882876574993, 42.00872182846069, 46.72527574002743, 45.53280472755432, 47.192654460668564, 47.1065054833889, 45.520956963300705, 45.90970270335674, 45.34178897738457, 47.078288197517395, 45.36910571157932, 46.044386476278305, 45.258942022919655, 43.92993673682213, 43.88368561863899, 48.59081223607063, 51.32786236703396, 47.09018915891647, 41.4182411134243, 36.67552940547466, 41.04066677391529, 42.09875799715519, 50.58637775480747, 51.8624746799469, 48.783180713653564, 48.410975486040115, 47.65842966735363, 47.10370883345604, 46.31083957850933, 48.41406092047691, 50.95190294086933, 52.11746759712696, 50.397915467619896, 49.68279384076595, 51.283123567700386, 58.419547230005264, 63.471490144729614, 63.44211392104626, 63.58297236263752, 61.538275480270386, 60.90163104236126, 64.17853340506554, 63.86140242218971, 62.144498750567436, 61.759043633937836, 66.14663019776344, 65.76639220118523, 70.19475057721138, 67.64316469430923, 68.701651096344, 72.9276779294014, 73.0789478123188, 68.44956502318382, 77.61715829372406, 77.23048344254494, 66.23563662171364, 55.751626789569855, 58.801734521985054, 73.50186511874199, 73.63452360033989, 71.7845168709755, 20.750310346484184, 0.4467889911029488, 0.4310902225552127, 0.2750695258146152, 30.740139596164227, 86.71018436551094, 75.75129121541977, 78.26851934194565, 57.43792690336704, 26.91137194633484, 46.849004700779915, 62.09888219833374, 81.26227989792824, 39.60900999605656, 0.6516006728634238, 0.279760611592792, 0.16848856990691274, 0.2221395238302648, 0.21666470041964203, 0.1134447161166463], [0.028903496022394393, 0.06217106900294311, 0.1272498577600345, 0.015058168010000372, 0.02468678547302261, 0.06030451935657766, 0.035816262097796425, 0.16699853033060208, 10.991335809230804, 41.15752570331097, 38.774377182126045, 37.936795726418495, 38.23803596198559, 45.72048805654049, 59.280786216259, 75.43752685189247, 26.77707575261593, 0.08213914596126415, 0.23437731637386605, 3.93106528557837, 71.72476127743721, 75.318783223629, 75.17639726400375, 69.29736793041229, 72.79749691486359, 70.05213662981987, 76.03582754731178, 69.9723257124424, 72.71962389349937, 69.27481234073639, 69.89602580666542, 65.83004638552666, 63.47906693816185, 60.725578889250755, 62.66728609800339, 62.2341663390398, 62.02519655227661, 59.4112104177475, 58.87537457048893, 60.8039078861475, 67.95306846499443, 62.6972246915102, 60.81530347466469, 60.21723456680775, 58.32460552453995, 52.01405994594097, 50.61199218034744, 48.63573722541332, 47.39904798567295, 46.722528487443924, 46.78113654255867, 47.10833698511124, 46.19185656309128, 46.71160787343979, 45.70879228413105, 44.16579768061638, 45.280080288648605, 42.82378949224949, 43.62314119935036, 46.058312729001045, 46.969633027911186, 49.90643464028835, 48.53810526430607, 45.07270261645317, 45.93254707753658, 40.72141170501709, 45.9165271371603, 46.05623044073582, 49.076521173119545, 46.831632032990456, 44.3238577991724, 45.846660286188126, 37.9265932738781, 39.50446240603924, 37.98514813184738, 41.14763483405113, 40.25353901088238, 38.41192603111267, 40.57560592889786, 43.605251759290695, 40.360039696097374, 39.62621167302132, 40.71941301226616, 39.649971798062325, 40.14415808022022, 43.07533219456673, 40.98921753466129, 41.90380945801735, 41.820833310484886, 36.968698874115944, 42.40982450544834, 40.85760399699211, 42.02280767261982, 38.87828640639782, 39.363611564040184, 37.77340069413185, 38.34071785211563, 39.774852097034454, 39.67496685683727, 37.67498217523098, 38.42727340757847, 40.21183244884014, 40.46123966574669, 40.79057939350605, 38.662788569927216, 43.19559574127197, 43.565779477357864, 42.996516823768616, 37.22716100513935, 41.147688031196594, 49.85591635107994, 42.46492154896259, 42.210779786109924, 41.06610640883446, 37.74178259074688, 38.793645948171616, 41.597610488533974, 47.45697967708111, 42.7141197770834, 43.514748215675354, 43.441989719867706, 41.55047781765461, 41.99240170419216, 42.44407966732979, 44.87060286104679, 45.436483696103096, 43.407137989997864, 44.834573194384575, 45.70528507232666, 51.9293586909771, 58.51649522781372, 57.7870711684227, 60.68017892539501, 57.09675461053848, 59.68852713704109, 57.90976278483868, 59.281766563653946, 58.79065431654453, 57.56581284105778, 60.60461238026619, 59.90160070359707, 61.618538573384285, 62.25079044699669, 61.71183496713638, 65.8731360733509, 65.61224207282066, 67.49785289168358, 69.29143264889717, 55.292793810367584, 57.866749092936516, 59.49148491024971, 52.374417409300804, 72.33463615179062, 66.71079352498055, 70.03953650593758, 61.83191232383251, 26.305952332913876, 0.5583650758489966, 0.3492192516569048, 0.6476782739628106, 16.52360524982214, 65.73527947068214, 54.760609567165375, 58.77461537718773, 43.63422520458698, 34.411854073405266, 34.9574363976717, 40.748606845736504, 61.35909989476204, 34.31022472679615, 0.31385440088342875, 0.1259493181714788, 0.05574854898441117, 0.0567403625609586, 0.039318605413427576, 0.11602282582316548, 0.04144903679843992, 0.083498122257879, 0.03973636405135039, 0.05369320067984518, 0.025744388585735578, 0.010521056537982076, 0.03659949878056068, 0.19401703990297392, 19.766022562980652, 57.85480633378029, 47.58035525679588, 41.861092150211334, 38.33588071167469, 54.00978125631809, 66.67137444019318, 82.61819913983345, 29.8901005089283, 0.0047454889136133716, 0.16335292282747105, 4.9116691667586565, 74.38884392380714, 76.0678294301033, 79.09842520952225, 72.38951280713081, 75.26774436235428, 73.51172938942909, 77.62930244207382, 70.14665275812149, 75.52701964974403, 72.97794923186302, 70.81314459443092, 67.07990571856499, 64.33481901884079, 62.19892702996731, 63.54311250150204, 64.6613734960556, 61.88073970377445, 60.246876776218414, 59.17024254798889, 63.18668022751808, 70.51525577902794, 66.32458984851837, 63.40205267071724, 63.01651015877724, 58.56641314923763, 52.32452228665352, 52.29223161935806, 48.84518578648567, 50.44229708611965, 48.048794120550156, 50.11808708310127, 49.27700221538544, 47.54488795995712, 49.881481379270554, 48.23923610150814, 47.129627242684364, 47.53744415938854, 44.65817146003246, 47.477445378899574, 48.81450243294239, 48.56211617588997, 50.536798015236855, 47.76484675705433, 44.818872436881065, 47.42210514843464, 44.0228645503521, 46.72461077570915, 48.037603721022606, 50.44659845530987, 47.136941850185394, 44.052103981375694, 49.1137819737196, 40.55732510983944, 41.50357313454151, 43.60334426164627, 43.02272401750088, 41.573489382863045, 40.231788977980614, 42.85720109939575, 45.08534453809261, 43.28033119440079, 40.89572735130787, 42.589452266693115, 42.557963356375694, 43.68276000022888, 44.48185332119465, 43.42042587697506, 43.28900992870331, 45.16210041940212, 39.83370713889599, 43.5895624011755, 44.602983221411705, 43.37391257286072, 41.80419020354748, 41.53618298470974, 40.34956745803356, 40.44758319854736, 41.39810599386692, 41.64220489561558, 40.6270931661129, 41.9341242313385, 41.14457219839096, 44.608530923724174, 41.64318524301052, 40.441925302147865, 45.48852950334549, 46.90309099853039, 44.222372844815254, 40.69048136472702, 43.003968223929405, 50.66217228770256, 45.56256853044033, 43.66504915058613, 43.642356768250465, 37.48316086828709, 37.27708272635937, 39.79125201702118, 49.287660643458366, 44.30703230202198, 44.880030155181885, 44.386588633060455, 43.69513973593712, 44.35616746544838, 45.195185244083405, 46.63223393261433, 47.579610496759415, 45.59691868722439, 45.30992768704891, 48.51178027689457, 54.63727958500385, 60.78042134642601, 61.31407231092453, 63.261741399765015, 58.286751955747604, 63.07218097150326, 61.00485250353813, 61.8650009483099, 60.32942734658718, 60.71188062429428, 62.70866207778454, 61.2834307551384, 62.47871741652489, 65.71118876338005, 64.94338676333427, 69.27449315786362, 67.0274305343628, 70.44486835598946, 69.0418392419815, 59.476627707481384, 57.50839792191982, 58.28513704240322, 57.28409595787525, 73.67439866065979, 67.8720872104168, 73.7501285970211, 66.03381425142288, 32.656067088246346, 0.5679162789601833, 0.385626137140207, 0.6699966732412577, 18.016448244452477, 74.63382437825203, 62.33717121183872, 67.54533514380455, 48.06685835123062, 32.989229410886765, 44.575404301285744, 49.534195214509964, 71.71955555677414, 45.082635283470154, 0.43138084758538753, 0.13179978705011308, 0.0459903794398997, 0.0454499623447191, 0.046321347617777064, 0.06411925118300132, 0.12385444308165461, 0.1736178048304282, 0.17480209440691397, 0.1060993540158961, 0.14371017372468486, 0.10004088340792805, 0.19247432268457487, 0.25593719619791955, 27.92570471763611, 74.63360399007797, 55.4920969158411, 55.84663309156895, 52.726411521434784, 66.00204035639763, 72.00232118368149, 90.23973137140274, 36.55074030160904, 0.21246746939141303, 0.451389238005504, 6.756500098854303, 79.28943336009979, 79.78370323777199, 81.21041268110275, 74.52318951487541, 79.01176705956459, 75.13839930295944, 81.3425923883915, 75.23670762777328, 79.07906904816628, 74.63801175355911, 73.56364980340004, 70.5038183927536, 67.09995344281197, 63.283643424510956, 65.77651485800743, 65.41685655713081, 65.09632855653763, 62.04344317317009, 60.19923113286495, 65.19136145710945, 72.34140738844872, 67.58061245083809, 66.16955816745758, 67.02669337391853, 61.19923487305641, 55.6671991199255, 54.36830721795559, 52.4250952899456, 52.096960097551346, 49.7510077804327, 52.506331130862236, 53.65334898233414, 50.07941275835037, 52.264056131243706, 49.51252117753029, 50.1224834471941, 50.36414287984371, 47.02664516866207, 48.6927455663681, 50.77115423977375, 52.16734752058983, 54.18039970099926, 50.57067699730396, 43.55240039527416, 49.03611794114113, 46.20725333690643, 52.037945464253426, 52.315129190683365, 53.75412717461586, 47.1179960668087, 45.483312383294106, 49.04242180287838, 42.96554088592529, 44.63793374598026, 45.57424150407314, 46.52248442173004, 45.54595582187176, 43.639244735240936, 45.99185809493065, 49.97674606740475, 46.098187789320946, 44.27668713033199, 46.956915110349655, 45.5812369287014, 46.68019875884056, 46.17890685796738, 45.962622463703156, 46.129513308405876, 47.93226197361946, 41.5263757109642, 48.36638867855072, 48.18825043737888, 46.99068769812584, 44.68656353652477, 45.27532674372196, 43.384817987680435, 44.16821055114269, 44.81188841164112, 44.84973058104515, 43.0456405878067, 44.86219011247158, 44.96595114469528, 47.786452397704124, 46.51522681117058, 44.49614055454731, 49.72257010638714, 47.01064422726631, 45.46566992998123, 42.73299716413021, 42.57931441068649, 53.381701558828354, 47.33257055282593, 45.36396838724613, 44.85413074493408, 40.17682112753391, 37.76857115328312, 40.9009862691164, 51.09805829823017, 45.97483120858669, 46.66105158627033, 48.308768570423126, 45.750943422317505, 45.527937188744545, 47.585655972361565, 49.01357375085354, 48.17055098712444, 48.34516301751137, 48.01431857049465, 49.67660017311573, 57.46306635439396, 63.78037557005882, 60.72231866419315, 66.11430913209915, 61.845454797148705, 65.3552694618702, 62.61313900351524, 65.86511850357056, 63.68283100426197, 62.80648022890091, 66.61964401602745, 65.21307349205017, 65.84747225046158, 67.97467410564423, 66.32632255554199, 73.3078171312809, 71.16090193390846, 74.8834253847599, 70.3453440964222, 62.654317393898964, 65.65967872738838, 59.89659637212753, 57.232749313116074, 77.21984401345253, 73.14027652144432, 78.7373685836792, 71.22789993882179, 35.76597601175308, 0.8287954365368932, 0.6190687185153365, 0.6747631612233818, 21.195579953491688, 82.8943607211113, 72.63985857367516, 76.78408339619637, 62.10638679563999, 48.381485268473625, 45.189595744013786, 58.22396032512188, 79.04896706342697, 56.354187056422234, 0.761867668479681, 0.31639135850127786, 0.20144089154200628, 0.1558863086393103, 0.13281360530527309, 0.18283216195413843], [0.047088019564398564, 0.06101362290792167, 0.03536879157763906, 0.014993085369496839, 0.05866331914148759, 0.07039809512207285, 0.012548580798465991, 0.13872138282749802, 13.691231533885002, 43.846497014164925, 45.11486895382404, 36.01897783577442, 32.92185142636299, 45.17544910311699, 60.712013617157936, 77.32214972376823, 15.29007364064455, 0.1611293148016557, 0.07541065700934269, 3.3143818890675902, 71.15436628460884, 73.27010035514832, 76.75801679491997, 70.66970989108086, 73.78308802843094, 68.48819375038147, 72.30293065309525, 71.529071778059, 72.87887334823608, 69.77994203567505, 69.733075350523, 66.83725073933601, 67.40544185042381, 62.420960515737534, 69.60120722651482, 68.8101352751255, 69.75563853979111, 66.52262762188911, 64.24356311559677, 63.07145521044731, 64.64226812124252, 61.81000269949436, 62.8357158601284, 57.20360107719898, 54.456283897161484, 46.48496523499489, 48.73212285339832, 49.94895435869694, 46.214286759495735, 49.493875578045845, 45.96708722412586, 45.403691455721855, 45.62088020145893, 46.17247000336647, 45.72421945631504, 44.39658209681511, 46.37134753167629, 43.70786905288696, 44.79614585638046, 45.60002692043781, 44.70026180148125, 47.05398090183735, 48.02095681428909, 43.39515723288059, 47.96208657324314, 46.15625627338886, 40.58208078145981, 46.25939793884754, 44.57877092063427, 47.63900890946388, 47.403698936104774, 44.8371684551239, 45.87463438510895, 38.49608011543751, 39.06132638454437, 39.731238037347794, 39.83216442167759, 39.46895711123943, 41.0854359716177, 40.89578054845333, 41.11619912087917, 40.088095888495445, 39.3664576113224, 40.54732024669647, 42.78698466718197, 42.31441542506218, 40.90660996735096, 41.418115720152855, 39.98681232333183, 38.380604311823845, 41.8508592993021, 38.249686136841774, 39.77626942098141, 39.940515607595444, 38.65461140871048, 38.302982077002525, 40.355890318751335, 38.40181477367878, 39.72769282758236, 39.00537058711052, 37.41413377225399, 39.05530370771885, 38.98992441594601, 39.54999536275864, 43.41498836874962, 47.331521809101105, 46.484885439276695, 44.54025238752365, 45.880421474575996, 44.20722305774689, 47.637158408761024, 43.375668078660965, 42.52440735697746, 42.5941564142704, 38.68012323975563, 37.04522296786308, 39.34535354375839, 48.232818245887756, 43.678637221455574, 43.21507729589939, 41.95866711437702, 41.39746002852917, 41.308062225580215, 41.200056821107864, 46.50161974132061, 46.67922981083393, 44.90478202700615, 45.36931090056896, 50.6423981487751, 56.466607823967934, 59.317344054579735, 63.14325235784054, 59.2500002682209, 59.71828334033489, 62.42425113916397, 59.93577606976032, 60.66874913871288, 57.16733202338219, 60.216375812888145, 60.493525341153145, 62.05361142754555, 60.00287286937237, 65.49846097826958, 65.1164522767067, 66.62858113646507, 66.98607355356216, 65.66031709313393, 60.53177408874035, 63.40410456061363, 49.77534547448158, 63.037021458148956, 72.44484543800354, 67.94885069131851, 66.3331925868988, 69.4386975467205, 63.98485779762268, 42.66947217285633, 2.80867510009557, 0.3921750857261941, 0.6009898823685944, 10.32476607710123, 65.99431157112122, 57.71451026201248, 57.566002830863, 52.21872076392174, 30.348295122385025, 20.21472528576851, 43.02866689860821, 58.64487133920193, 47.19039358198643, 0.8164550049696118, 0.06311604563961737, 0.034208428842248395, 0.06145477032987401, 0.012169359106337652, 0.04586771727190353, 0.06471516608144157, 0.11385571007849649, 0.02693807746254606, 0.04033039389469195, 0.00825481305582798, 0.09023614780744538, 0.0713714885932859, 0.639863993274048, 20.527475103735924, 60.74955940246582, 50.286060869693756, 43.306466192007065, 35.12287952005863, 51.91432669758797, 68.0001175403595, 83.08105230331421, 16.185731180012226, 0.16106011695228517, 0.05256578187982086, 4.145827861502767, 75.66999077796936, 75.29644802212715, 80.17733171582222, 72.83202186226845, 75.92500269412994, 71.16732358932495, 74.93229076266289, 70.74759811162949, 75.64736679196358, 70.46353295445442, 72.42718398571014, 67.38452017307281, 69.18587431311607, 63.99780750274658, 73.43976885080338, 70.93297496438026, 71.04209750890732, 67.42713868618011, 67.05177962779999, 64.98864233493805, 67.97641441226006, 61.92332781851292, 64.87007349729538, 58.17083917558193, 55.456348434090614, 49.64836768805981, 50.61395667493343, 51.76518850028515, 50.46601541340351, 50.29569715261459, 48.41275379061699, 48.38570684194565, 48.37566398084164, 48.77858676016331, 46.15051098167896, 47.28424094617367, 47.62066349387169, 45.95344975590706, 48.421804904937744, 46.897961273789406, 46.52792572975159, 48.30587312579155, 47.27442987263203, 42.00422286987305, 48.37131321430206, 46.785179525613785, 42.968508526682854, 47.92693465948105, 47.84573681652546, 47.94573225080967, 46.788781732320786, 44.836913868784904, 48.76339137554169, 42.464203387498856, 42.32348553836346, 40.43613061308861, 42.35297575592995, 41.240593045949936, 44.32481534779072, 42.77797155082226, 42.42910847067833, 42.648843079805374, 43.21427173912525, 45.202792435884476, 44.15152184665203, 45.52452117204666, 43.094410970807076, 43.484023064374924, 42.03991815447807, 41.29245646297932, 43.57860378921032, 41.951090320944786, 43.05059552192688, 41.68980114161968, 41.089608147740364, 40.75101211667061, 42.20821492373943, 40.86045004427433, 42.554577738046646, 42.8039887547493, 40.23691490292549, 41.26139312982559, 40.80739729106426, 41.375736594200134, 46.69731684029102, 48.59585456550121, 47.56772853434086, 42.551370710134506, 45.69664053618908, 45.93644566833973, 49.66685749590397, 42.98396609723568, 42.789443135261536, 42.261469066143036, 39.00002047419548, 36.31672225892544, 39.48647037148476, 48.88305455446243, 45.77979527413845, 43.387800827622414, 45.26460371911526, 43.07715989649296, 44.34408411383629, 43.302882984280586, 49.390707314014435, 47.13141694664955, 47.01815642416477, 47.04891197383404, 53.13827142119408, 60.97397156059742, 62.211701944470406, 64.0891546010971, 61.04934811592102, 63.23092505335808, 63.93135666847229, 62.603039145469666, 63.46612103283405, 59.76447366178036, 63.28101396560669, 63.72841715812683, 65.79990640282631, 61.930194050073624, 68.5515059530735, 66.50216192007065, 69.75147396326065, 68.1960578262806, 66.17546305060387, 63.13771225512028, 65.31713470816612, 56.20732493698597, 65.05869537591934, 71.57051235437393, 70.11316895484924, 70.35005584359169, 74.06854391098022, 68.79904747009277, 48.99015560746193, 3.782290918752551, 0.2597406436689198, 0.6072966533247381, 11.094818506389856, 73.4264999628067, 65.34130901098251, 68.7296099960804, 59.36525568366051, 31.23411688953638, 13.971332553774118, 52.13207021355629, 64.8897336423397, 59.43639926612377, 1.0644263145513833, 0.13979185663629323, 0.06652774303802289, 0.020973249193048105, 0.059810107995872386, 0.05847859116329346, 0.2546955831348896, 0.19357543234946206, 0.13857992948032916, 0.09332760848337784, 0.14871443097945303, 0.2146320469910279, 0.21583512774668634, 0.8457602793350816, 32.28439383208752, 73.71714636683464, 64.26626309752464, 50.43806031346321, 48.12486983835697, 61.5158186852932, 72.9823037981987, 92.73590102791786, 20.696674324572086, 0.2450440713437274, 0.17860227642813697, 5.16120795160532, 79.42549645900726, 79.03810724616051, 84.19115513563156, 75.05966752767563, 79.53646570444107, 72.93900892138481, 78.05689349770546, 75.04449114203453, 78.31796988844872, 73.10245335102081, 74.64775443077087, 68.29816594719887, 71.3755676150322, 66.9578030705452, 74.47605684399605, 73.66170734167099, 73.83970499038696, 69.97149735689163, 68.88753712177277, 68.45414757728577, 72.24296987056732, 65.71864396333694, 70.37336379289627, 63.162714913487434, 61.24393567442894, 52.82711751759052, 52.54739932715893, 54.638069942593575, 52.2947508841753, 53.23134362697601, 48.561907187104225, 50.39712890982628, 50.1024167239666, 50.90464487671852, 48.65291230380535, 49.472437128424644, 50.925862938165665, 48.709700256586075, 49.94764722883701, 49.2220913618803, 48.59425485134125, 50.17696872353554, 49.52797494828701, 43.81892569363117, 50.505970269441605, 47.71107204258442, 47.6382527500391, 50.23188717663288, 48.49017843604088, 48.59699830412865, 47.54131235182285, 45.26602864265442, 51.32482632994652, 46.32849343121052, 45.37518538534641, 44.208936765789986, 46.55259020626545, 44.682079777121544, 45.96594728529453, 45.697529688477516, 45.58201588690281, 44.90238055586815, 45.74718922376633, 46.81301683187485, 47.16576710343361, 48.84213075041771, 46.916629672050476, 47.66602545976639, 45.167161747813225, 44.11424204707146, 45.22154442965984, 44.60420295596123, 44.63461272418499, 44.1022764891386, 44.37677375972271, 41.76766276359558, 45.91119222342968, 42.819602116942406, 43.44814158976078, 44.907582476735115, 42.44979076087475, 46.13038346171379, 44.72481608390808, 44.00205686688423, 48.761810660362244, 50.32166115939617, 49.051028341054916, 45.05791760981083, 47.38373100757599, 47.30157941579819, 49.54599738121033, 43.92158858478069, 45.4300582408905, 42.67379254102707, 39.754648581147194, 36.62639044225216, 41.01444058120251, 51.86982348561287, 48.74120436608791, 46.60443462431431, 48.55417460203171, 48.76358136534691, 47.14976616203785, 46.829960122704506, 53.82371284067631, 50.63450217247009, 49.80515867471695, 48.9202431589365, 55.566591918468475, 63.40429075062275, 64.08967897295952, 66.30125150084496, 67.64650851488113, 63.96895945072174, 66.38065204024315, 65.05807980895042, 66.54858022928238, 62.98265017569065, 65.83779036998749, 66.52147248387337, 68.27381685376167, 64.15802210569382, 71.61367043852806, 70.3577770292759, 73.46211925148964, 71.26533553004265, 68.2364572584629, 64.20427322387695, 67.13525354862213, 59.72809821367264, 72.08517953753471, 70.5388069152832, 73.68026554584503, 73.25574472546577, 81.51083216071129, 70.12677982449532, 55.107014179229736, 4.088838519528508, 0.37284834310412407, 0.8125032763928175, 12.143452037125826, 82.13086009025574, 72.36859112977982, 78.82854849100113, 71.7560487985611, 42.83012755215168, 29.979177229106426, 63.35827901959419, 74.58711728453636, 69.081189930439, 1.6076661832630634, 0.31299588445108384, 0.18966848496347666, 0.25506499456241727, 0.11425451797549613, 0.15814758808119223], [0.061180620978120714, 0.09411988081410527, 0.06509473008918576, 0.07501646527089179, 0.01908573573018657, 0.06518150941701606, 0.08351341792149469, 0.6043460522778332, 15.072587560862303, 49.696875885128975, 41.444870084524155, 28.49665068089962, 26.83606568723917, 50.54107278585434, 61.63982883095741, 67.47060835361481, 4.225393692031503, 0.08694499745615758, 0.043811485811602324, 2.812149776145816, 61.10903151333332, 68.4734733402729, 71.68617814779282, 70.23511961102486, 74.11979556083679, 71.78751111030579, 73.32256034016609, 69.3983893096447, 70.70181056857109, 68.60572904348373, 68.02556857466698, 63.31450156867504, 67.69456833600998, 68.44274818897247, 65.85197120904922, 63.92732888460159, 64.18940082192421, 63.734637424349785, 63.95615413784981, 62.26261541247368, 59.048975855112076, 56.714749708771706, 53.46941985189915, 49.450398311018944, 48.224078714847565, 49.57834504544735, 48.237199410796165, 48.09410288929939, 47.34115809202194, 45.23592285811901, 46.33571684360504, 45.06184279918671, 46.63764864206314, 47.02395871281624, 45.59858299791813, 45.12179218232632, 44.57803376019001, 44.16169010102749, 43.14406290650368, 45.02278469502926, 43.01253296434879, 48.743624836206436, 50.06595388054848, 44.319032058119774, 45.519551038742065, 45.22668935358524, 44.14128519594669, 43.839721977710724, 50.577083453536034, 49.40696284174919, 43.066550865769386, 44.33233514428139, 46.21247425675392, 48.065163642168045, 38.56297552585602, 37.91340038180351, 38.755837976932526, 40.36269195377827, 39.68795835971832, 38.903159871697426, 40.330583676695824, 37.73685045540333, 38.40490020811558, 40.61682991683483, 42.04994961619377, 40.914486944675446, 39.575446397066116, 41.31455987691879, 38.70275102555752, 40.47861613333225, 41.28533564507961, 40.93037389218807, 39.989411383867264, 38.76197464764118, 40.71122445166111, 38.43557596206665, 40.170228481292725, 40.32317407429218, 40.379103273153305, 39.938611909747124, 40.729999244213104, 39.96564745903015, 40.21269500255585, 43.57531316578388, 43.49087409675121, 42.825423404574394, 43.273005187511444, 43.83234657347202, 46.4555624127388, 43.59649322926998, 41.80474877357483, 42.59187653660774, 41.92188888788223, 41.414308324456215, 37.24749371409416, 39.24879312515259, 40.936335772275925, 42.822550758719444, 42.89245180785656, 42.86626361310482, 39.84626166522503, 39.56926792860031, 41.88564643263817, 39.74370136857033, 46.013885512948036, 43.622711822390556, 45.70379175245762, 44.04058299958706, 52.475879564881325, 56.41607813537121, 60.31364679336548, 45.550686568021774, 47.44069755077362, 63.32257613539696, 60.91939888894558, 64.37962621450424, 62.151125594973564, 61.9110506772995, 61.87478542327881, 62.02629089355469, 62.604882046580315, 63.66184093058109, 65.63919022679329, 64.61681708693504, 63.89909639954567, 65.70722177624702, 66.15312784910202, 66.21492013335228, 66.72511115670204, 67.42238894104958, 59.06889818608761, 62.04862989485264, 75.43965473771095, 71.72691196203232, 71.47516027092934, 66.5042594075203, 54.989824667572975, 6.400905679911375, 0.4378414509119466, 0.22806014050729573, 5.0338368862867355, 63.84566366672516, 58.26449654996395, 58.55662867426872, 50.93625918030739, 41.66560024023056, 48.83660584688187, 44.10422958433628, 56.756140887737274, 42.83643141388893, 1.5401054522953928, 0.10267927777022123, 0.09998440596973523, 0.13508457719581202, 0.06561266010976397, 0.08312322635902092, 0.046645424954476766, 0.07287766988156363, 0.04493153508519754, 0.01221800781422644, 0.04346896239439957, 0.09495585080003366, 0.14620186033425853, 0.5444229114800692, 23.859193325042725, 61.70373000204563, 50.447692796587944, 32.61192485690117, 30.43991580605507, 63.056700602173805, 69.13224399089813, 72.3235559463501, 4.186053453013301, 0.06537679815664887, 0.06499869617982768, 3.8478488009423018, 64.27528381347656, 72.3336786031723, 77.24809169769287, 71.79542988538742, 76.79862901568413, 73.72178211808205, 74.96192157268524, 70.8129470050335, 72.33663484454155, 69.58965584635735, 70.41930332779884, 64.73442077636719, 70.28881072998047, 70.2943280339241, 69.11925628781319, 65.0788114964962, 66.63944855332375, 66.91257029771805, 65.79290717840195, 64.37920823693275, 62.887142300605774, 56.877103596925735, 55.14821536839008, 50.63003361225128, 49.86912064254284, 51.11187055706978, 50.33423848450184, 47.4928193539381, 48.26314441859722, 47.65750251710415, 47.33013108372688, 46.638552993535995, 48.17336663603783, 48.545872047543526, 48.03431309759617, 45.849076956510544, 45.99731460213661, 46.70593857765198, 45.2023820579052, 46.6561384499073, 46.32423385977745, 49.69705827534199, 51.48938409984112, 43.81288401782513, 45.70023134350777, 44.095144271850586, 44.87306512892246, 43.027317970991135, 50.36813646554947, 51.055785566568375, 44.392273128032684, 46.360381320118904, 46.9037027657032, 49.56767141819, 41.51839233934879, 41.909585148096085, 40.741087049245834, 43.46425272524357, 40.67233733832836, 41.0441017895937, 42.80444473028183, 40.38463577628136, 41.55430421233177, 42.831237092614174, 45.20352199673653, 44.283720552921295, 42.09011726081371, 43.91314923763275, 42.34115079045296, 41.3472381234169, 45.31834803521633, 42.81240150332451, 42.95101046562195, 42.69982494413853, 41.84272773563862, 40.54122917354107, 42.053270637989044, 40.82887373864651, 41.805979907512665, 41.47928103804588, 43.73537577688694, 41.785176023840904, 42.93825075030327, 44.60436634719372, 45.62498398125172, 43.546503111720085, 44.500552117824554, 44.94422011077404, 45.475139021873474, 44.72941383719444, 45.32262280583382, 43.580777272582054, 43.907122761011124, 41.79901488125324, 38.670281767845154, 40.09349539875984, 43.10028165578842, 45.57399071753025, 43.24628122150898, 45.37685349583626, 41.98053494095802, 42.44011647999287, 44.418085142970085, 42.36824333667755, 48.44531424343586, 46.798163428902626, 47.465517818927765, 45.63527762889862, 54.77170877158642, 59.453946724534035, 63.03297087550163, 49.855277985334396, 52.63832464814186, 63.98858159780502, 63.3170398324728, 66.61556303501129, 64.26867976784706, 65.50060406327248, 65.39589688181877, 63.05479310452938, 64.68477264046669, 63.81304621696472, 69.18356403708458, 64.58418443799019, 67.34014615416527, 66.20755612850189, 67.10515156388283, 67.20534458756447, 69.69003885984421, 68.68511438369751, 65.57501927018166, 63.27842250466347, 78.31884384155273, 73.91526773571968, 76.25703647732735, 69.25674811005592, 59.56097178161144, 6.575406566262245, 0.12655019061639905, 0.18475767894415185, 5.398331852629781, 71.37704193592072, 64.83900636434555, 69.39446792006493, 57.990360260009766, 33.603162467479706, 50.39035387337208, 52.07406632602215, 60.394164472818375, 56.811245530843735, 1.9982479372993112, 0.09078606439288706, 0.14407995622605085, 0.1324031679541804, 0.050685610112850554, 0.0695161713520065, 0.27927931398153305, 0.15887982066487893, 0.2113890100736171, 0.13696087495191023, 0.23777731752488762, 0.22670971375191584, 0.3306392580270767, 0.8236701053101569, 36.18243366479874, 76.41262292861938, 60.09863533079624, 41.98314160108566, 40.19894354045391, 75.26847392320633, 71.62207558751106, 79.77382376790047, 6.08567507006228, 0.19525987008819357, 0.2176200077519752, 5.584626831114292, 72.88294672966003, 75.55429458618164, 77.67626792192459, 74.52889680862427, 80.96436068415642, 76.79542198777199, 79.33792635798454, 73.65087792277336, 75.05545735359192, 71.18495464324951, 73.57023864984512, 67.40009173750877, 74.00167509913445, 70.98406702280045, 70.29220014810562, 68.60234722495079, 70.11310815811157, 72.335304915905, 70.87854668498039, 68.25181603431702, 64.9595282971859, 59.85083922743797, 57.88082733750343, 54.41881790757179, 52.37233132123947, 54.479797035455704, 53.628076538443565, 50.66797077655792, 51.9569756090641, 49.344752579927444, 49.945393949747086, 47.76911772787571, 49.7173073887825, 51.29215948283672, 49.23110447824001, 48.82392592728138, 49.20620821416378, 49.7591507434845, 48.59916418790817, 51.32526330649853, 47.13234029710293, 54.03987564146519, 52.39671841263771, 44.69750314950943, 46.66425101459026, 44.342932775616646, 44.81663815677166, 43.589148223400116, 52.26364195346832, 51.15349352359772, 42.7274114638567, 46.04924641549587, 46.335967630147934, 52.73445948958397, 44.28388014435768, 44.66735936701298, 43.739221170544624, 44.62694473564625, 44.06211644411087, 42.71378919482231, 46.50638468563557, 43.66686925292015, 45.494631975889206, 46.39967501163483, 48.02565336227417, 47.28475011885166, 44.78274777531624, 47.648067623376846, 43.76795522868633, 44.76868472993374, 47.959381118416786, 44.653611704707146, 45.299854427576065, 44.162184074521065, 46.376667246222496, 45.52720382809639, 46.13277353346348, 45.16584701836109, 43.38079020380974, 45.85563160479069, 46.668240800499916, 45.37065602838993, 44.73395459353924, 47.401400059461594, 45.75717508792877, 45.18264591693878, 45.12686491012573, 45.52204750478268, 48.179290518164635, 45.65021462738514, 47.88137510418892, 44.26205791532993, 44.24635335803032, 43.43875229358673, 38.7149977684021, 40.36298833787441, 44.786406978964806, 47.13343843817711, 45.446317568421364, 46.36486127972603, 43.998903036117554, 44.30922478437424, 47.87574760615826, 44.97620299458504, 51.677109226584435, 46.50489516556263, 49.39715176820755, 47.97876387834549, 57.71159581840038, 63.56692582368851, 64.30830404162407, 54.28379215300083, 55.524471178650856, 68.91913622617722, 65.78032985329628, 67.49105885624886, 68.28081607818604, 66.07331693172455, 66.15989908576012, 66.74667879939079, 67.31733977794647, 66.74395814538002, 70.31385138630867, 66.9575446844101, 68.49418982863426, 68.11353385448456, 69.63776126503944, 69.81834277510643, 75.37969395518303, 71.00539907813072, 69.84100475907326, 69.09575074911118, 79.03810724616051, 73.53113114833832, 81.13292723894119, 73.58772531151772, 63.549446761608124, 7.878617411479354, 0.5317406763788313, 0.30774156795814633, 6.050404887646437, 80.07931217551231, 72.26278960704803, 77.77124762535095, 69.86137166619301, 64.53757613897324, 61.89494714140892, 62.07354515790939, 71.49415925145149, 70.87540805339813, 3.183467276394367, 0.21640408784151077, 0.23729321459541097, 0.30410234292503446, 0.16743305779527873, 0.2053415306727402], [0.07857344549847767, 0.06238704881980084, 0.025945393717847764, 0.03339094575494528, 0.019690994267875794, 0.035483546162140556, 0.10887889744481072, 0.08756810464547016, 17.643673047423363, 52.54525624215603, 40.55067926645279, 33.14887784421444, 29.019903503358364, 43.06297525763512, 71.4153590798378, 58.227266147732735, 2.74890691973269, 0.01843127280153567, 0.29055108258035034, 1.2994471471756697, 49.532447308301926, 70.83264514803886, 71.7081181704998, 72.94232234358788, 71.66320458054543, 68.4606072306633, 68.89612466096878, 69.5103769004345, 68.8699060678482, 67.79568091034889, 65.4118712246418, 72.65986070036888, 69.01999801397324, 62.37311348319054, 65.49305006861687, 62.00110584497452, 59.58711817860603, 60.11967100203037, 57.54584491252899, 55.96134893596172, 52.096633315086365, 47.61649511754513, 47.63001099228859, 47.869675531983376, 47.63491652905941, 48.35399754345417, 45.02647429704666, 46.28177873790264, 46.108580231666565, 45.989950597286224, 46.980823427438736, 46.48447886109352, 44.209905713796616, 46.06974631547928, 44.8596366494894, 44.32058237493038, 43.058119118213654, 43.77222619950771, 42.22522281110287, 45.893127992749214, 43.882701471447945, 47.94053792953491, 55.4731435328722, 45.44097885489464, 44.30995054543018, 41.38909287750721, 42.32838347554207, 43.194919377565384, 44.570947140455246, 48.68123218417168, 49.51778769493103, 45.080089420080185, 46.768844202160835, 47.387561202049255, 44.66629542410374, 38.19855988025665, 38.713595643639565, 37.72627182304859, 40.69926269352436, 41.44486628472805, 39.089429676532745, 39.82459142804146, 41.18272975087166, 41.57994143664837, 40.46791970729828, 41.268460750579834, 41.42363302409649, 38.49065400660038, 39.840417578816414, 42.76211500167847, 42.69113481044769, 41.178705766797066, 39.202382415533066, 41.397775411605835, 38.96503195166588, 37.27305494248867, 40.82005061209202, 39.31540735065937, 39.35275934636593, 38.94252195954323, 40.178135856986046, 39.891475439071655, 43.6734277009964, 39.64596301317215, 41.654387041926384, 44.4953615963459, 43.85940492153168, 42.80990883708, 42.60763429105282, 43.65320138633251, 39.19441044330597, 38.280677273869514, 38.7297485768795, 39.06476520001888, 37.44995065033436, 38.73702898621559, 44.47279080748558, 41.334288418293, 41.80210031569004, 43.19355145096779, 40.69079674780369, 41.1766766756773, 39.579098001122475, 40.937905088067055, 46.74813911318779, 45.168233290314674, 44.60530489683151, 43.82560953497887, 50.35005323588848, 57.22438596189022, 56.76795445382595, 53.942760452628136, 58.95788714289665, 55.289278998970985, 57.20388226211071, 57.80778005719185, 61.73384718596935, 63.025101497769356, 63.016981333494186, 57.20237374305725, 60.888362154364586, 59.49300482869148, 63.24384056031704, 63.26535880565643, 66.1289231479168, 64.78132545948029, 66.16094782948494, 65.3516748547554, 66.64070248603821, 62.35643997788429, 69.85048145055771, 62.36254625022411, 59.283233284950256, 69.84612688422203, 78.99354323744774, 70.86913079023361, 60.00505395233631, 10.077293906360865, 0.1360246556578204, 0.21217795758275315, 1.7404164536856115, 58.69172282516956, 60.437588542699814, 59.6245613694191, 53.837688490748405, 41.061919033527374, 14.090274721384048, 36.886163502931595, 56.9681391119957, 41.71107240021229, 1.8955270992591977, 0.08324173250002787, 0.07665239623747766, 0.06289136785198934, 0.022755065983801614, 0.07379192160442472, 0.04969219349732157, 0.05287412568577565, 0.04632298405340407, 0.07978215915500186, 0.07153850150643848, 0.06359288294333965, 0.06016236096911598, 0.12887761025922373, 26.994541883468628, 64.42258670926094, 49.90576587617397, 39.90828953683376, 28.094316869974136, 51.3457328081131, 74.94790032505989, 67.63218328356743, 3.3421379746869206, 0.06804249613196589, 0.14706101501360536, 1.675203402992338, 54.26437899470329, 75.06583079695702, 75.94397127628326, 73.33890706300735, 72.92568683624268, 71.06042012572289, 71.25255301594734, 69.41638514399529, 69.91981253027916, 67.42906898260117, 68.67396578192711, 71.99732825160027, 71.79341599345207, 66.40145972371101, 67.85918310284615, 65.42575567960739, 62.65453398227692, 61.22375875711441, 59.29518364369869, 56.701560616493225, 53.52740854024887, 51.0248514264822, 49.995368868112564, 50.43371334671974, 48.822094425559044, 50.89715927839279, 48.84090721607208, 48.69168542325497, 47.86681428551674, 47.581650987267494, 48.75762328505516, 47.38308124244213, 46.836510971188545, 47.84656137228012, 47.763060852885246, 47.03923009335995, 46.45758770406246, 45.82179822027683, 44.47626382112503, 48.63186523318291, 47.52545200288296, 49.310288429260254, 57.34130568802357, 47.02148124575615, 43.94466854631901, 42.34842739999294, 43.04519981145859, 43.836815133690834, 44.27898220717907, 49.447578862309456, 48.26656423509121, 46.62497632205486, 47.236002534627914, 48.64117853343487, 46.2315758317709, 41.55611291527748, 41.61297306418419, 40.78070752322674, 42.80005216598511, 42.788215801119804, 41.939170360565186, 42.16182321310043, 42.357991486787796, 44.22299221158028, 43.97642344236374, 44.03583325445652, 44.485812708735466, 41.82660140097141, 42.17116691172123, 45.99618226289749, 44.952936843037605, 42.504078447818756, 42.13803268969059, 42.03175239264965, 42.70887225866318, 39.65242646634579, 44.14145618677139, 41.921573504805565, 41.22699737548828, 40.55520482361317, 40.928120613098145, 42.816558480262756, 45.56028865277767, 38.682665303349495, 41.14999830722809, 44.402589574456215, 43.60417641699314, 43.974971920251846, 43.00093598663807, 45.05091458559036, 39.867662116885185, 38.81839781999588, 39.306534826755524, 40.421018823981285, 37.46214039623737, 38.13184306025505, 46.605365574359894, 43.00177954137325, 42.489259243011475, 45.46258829534054, 42.62487396597862, 43.195375353097916, 43.486648723483086, 45.48177346587181, 48.40827003121376, 46.65763936936855, 47.50127010047436, 45.50211377441883, 52.9225417971611, 59.903793185949326, 60.96433527767658, 58.81434224545956, 61.66090629994869, 56.284077018499374, 61.112284138798714, 59.7134044021368, 63.63186053931713, 63.69518034160137, 64.58625912666321, 58.132408037781715, 63.12833055853844, 61.19595564901829, 63.68124268949032, 64.45045441389084, 69.01588663458824, 67.21716195344925, 69.36418354511261, 69.16794687509537, 69.89311516284943, 65.91479703783989, 73.76109480857849, 64.92605209350586, 63.58973599970341, 71.16087913513184, 81.51945009827614, 73.43650862574577, 66.09740003943443, 11.375549342483282, 0.1977759733563289, 0.02166550784750143, 1.6717465384863317, 66.51557520031929, 68.91994178295135, 69.5511943101883, 61.982813626527786, 45.327011570334435, 21.591055132448673, 45.90857036411762, 66.11903607845306, 55.516161024570465, 2.41813110653311, 0.12617187341675162, 0.09505955851636827, 0.08669573231600225, 0.012172109691164223, 0.0638559965591412, 0.132873734110035, 0.09975007284083404, 0.16801904275780544, 0.12196394804050215, 0.1517597894417122, 0.1795716251945123, 0.2822151017608121, 0.24648489168612286, 36.570734828710556, 77.05104187130928, 56.787090227007866, 49.289742931723595, 43.26135501265526, 60.1549369096756, 79.88076522946358, 75.68001464009285, 4.510413547977805, 0.12252833650563844, 0.35877567948773503, 2.4066113121807575, 61.11296430230141, 77.9695437848568, 79.4417367875576, 78.36757242679596, 76.97012901306152, 72.22673714160919, 73.95242974162102, 71.60068273544312, 73.19861859083176, 71.94859206676483, 72.92070910334587, 75.80229967832565, 75.61967387795448, 68.35601404309273, 70.58913141489029, 68.74224051833153, 66.78337723016739, 65.1781989634037, 63.24081592261791, 59.87214848399162, 57.853423207998276, 52.41880662739277, 52.90428377687931, 53.11071150004864, 51.045605912804604, 54.26030941307545, 50.40919706225395, 51.16126410663128, 51.87425784766674, 51.081829369068146, 52.246459275484085, 50.31701020896435, 48.926695212721825, 49.418035447597504, 49.26465667784214, 49.77318339049816, 48.187695667147636, 48.81360188126564, 47.707355841994286, 51.79615303874016, 49.256532713770866, 52.484189718961716, 61.011844128370285, 46.59494273364544, 43.48240055143833, 42.85676792263985, 44.18170742690563, 44.69224043190479, 44.615176767110825, 51.35051675140858, 48.90409782528877, 46.70329011976719, 48.697533309459686, 48.21183957159519, 47.4898137152195, 43.499108254909515, 44.785772413015366, 44.74391385912895, 45.87623409926891, 46.39025151729584, 44.637044593691826, 45.25765389204025, 45.69738529622555, 47.62578941881657, 46.29030928015709, 47.73886755108833, 48.61117534339428, 44.43523742258549, 45.17576448619366, 50.42826063930988, 47.812530398368835, 47.76100516319275, 45.634312480688095, 46.86866104602814, 46.24370098114014, 42.829565182328224, 47.08544321358204, 45.76750673353672, 43.732807114720345, 44.51833136379719, 43.580530285835266, 45.04924647510052, 46.16978354752064, 41.09539143741131, 42.2287642210722, 46.426942348480225, 44.89437058568001, 44.51330803334713, 42.857109904289246, 46.0310073941946, 41.05202056467533, 39.85597014427185, 40.722471848130226, 38.840337842702866, 38.34434285759926, 39.126774072647095, 49.02695283293724, 45.02846919000149, 45.16476787626743, 47.338091656565666, 44.311436265707016, 45.9208133071661, 46.117198169231415, 45.33497974276543, 51.54295362532139, 49.56427440047264, 48.58813717961311, 48.603693544864655, 55.604031309485435, 64.90912780165672, 61.93191535770893, 61.09618440270424, 60.43936684727669, 59.53281529247761, 64.49067905545235, 63.872064650058746, 67.35274627804756, 66.65816634893417, 69.26554843783379, 61.27568677067757, 66.46840453147888, 63.217827156186104, 65.9954135119915, 65.84694787859917, 72.07947984337807, 70.006622672081, 71.77889317274094, 71.58530116081238, 73.06490376591682, 67.90312394499779, 76.04762971401215, 68.07553589344025, 70.61387568712234, 74.06209945678711, 81.2517848610878, 75.32571405172348, 70.81124469637871, 12.599842697381973, 0.44027643743902445, 0.3391419252147898, 1.8707928014919162, 74.97943863272667, 77.13038921356201, 77.1762527525425, 76.44847020506859, 60.79795740544796, 22.37854577600956, 55.55334962904453, 73.74254420399666, 71.32590427994728, 3.5561282420530915, 0.23998397489776835, 0.214127327199094, 0.24444815644528717, 0.10051326782559045, 0.167301578912884], [0.0387027786928229, 0.04741886899864767, 0.08347885610419326, 0.05773412427515723, 0.05300125929352362, 0.06222555006388575, 0.06684369014692493, 0.06101004204538185, 28.817264176905155, 54.042531698942184, 44.026189371943474, 24.607464373111725, 47.77962036430836, 57.26251311600208, 62.6456006616354, 65.34649193286896, 4.719897257164121, 0.0279060309912893, 0.21443427947815508, 0.9262954734731466, 36.3321266323328, 69.59277927875519, 69.22091603279114, 70.18110170960426, 69.63384747505188, 71.15470066666603, 68.88744592666626, 65.33076077699661, 64.20532196760178, 68.36968570947647, 64.86429780721664, 66.26584500074387, 62.80842952430248, 62.14753478765488, 57.83595934510231, 53.28085497021675, 49.173514768481255, 48.68220113217831, 48.985873237252235, 48.72688673436642, 48.290578946471214, 48.87387424707413, 47.46242858469486, 47.23943755030632, 45.78162297606468, 46.167765855789185, 47.340474128723145, 47.135425731539726, 47.98703223466873, 47.831875160336494, 46.44993871450424, 44.18083727359772, 46.170836091041565, 43.377176597714424, 47.864074632525444, 44.28714416921139, 44.31647479534149, 44.37144264578819, 42.0383108407259, 46.99086628854275, 44.932562336325645, 48.535521402955055, 54.224610328674316, 48.374907821416855, 46.15133933722973, 43.004697784781456, 44.29191291332245, 45.25291174650192, 49.81315344572067, 48.79643440246582, 48.31520922482014, 51.13239325582981, 46.75383500754833, 48.24349947273731, 47.03019417822361, 46.934739500284195, 41.970537677407265, 38.85020591318607, 40.86143419146538, 40.0315473228693, 38.254625871777534, 40.05712755024433, 40.74408508837223, 41.16859070956707, 39.89067368209362, 41.72722913324833, 39.31479938328266, 40.754264742136, 40.159801840782166, 41.86754800379276, 42.16362051665783, 38.983852341771126, 39.312245920300484, 41.167078390717506, 39.88723486661911, 39.15280267596245, 38.21530178189278, 40.388792753219604, 39.281045794487, 40.6264927983284, 42.09394745528698, 42.07248620688915, 38.2031462341547, 40.10180555284023, 42.88667231798172, 44.40899983048439, 42.79093265533447, 43.78832973539829, 42.05994687974453, 41.256688982248306, 40.824773758649826, 37.97930404543877, 37.57315143942833, 37.82265365123749, 35.43217912316322, 38.963158652186394, 44.55097161233425, 39.99746695160866, 40.797221437096596, 41.01619228720665, 42.261700853705406, 42.69246093928814, 41.96427181363106, 40.791012570261955, 45.01536749303341, 43.983734250068665, 45.10521747171879, 44.33233894407749, 46.11983522772789, 53.964575082063675, 58.36342044174671, 62.60276935994625, 60.65972462296486, 60.57873196899891, 57.70968072116375, 59.89564262330532, 59.30076174438, 57.51741483807564, 52.93459855020046, 58.958001136779785, 58.75845104455948, 62.04665780067444, 63.372961431741714, 64.9991449713707, 64.51308265328407, 63.51808324456215, 65.19021391868591, 62.74244226515293, 65.11082857847214, 65.57099148631096, 64.4497400522232, 67.63925850391388, 67.85470694303513, 55.38548223674297, 67.15832591056824, 81.57306522130966, 67.6695504784584, 13.026151321828365, 0.22740341402823105, 0.10300687659764662, 0.3676724567776546, 49.039674550294876, 63.54637652635574, 60.232969522476196, 53.7159164249897, 35.809438079595566, 46.75885073840618, 44.7896596044302, 48.95826391875744, 57.55336470901966, 4.203682132065296, 0.08648148912470788, 0.06964485975913703, 0.0780021921673324, 0.0378148472373141, 0.02399338762188563, 0.11062998746638186, 0.04853742655541282, 0.05417348525952548, 0.08115378906950355, 0.004518266950981342, 0.018688579111767467, 0.01103154838347109, 0.12729820125969127, 39.75276008248329, 62.757709845900536, 48.39375481009483, 38.69495764374733, 50.84431551396847, 63.591681495308876, 69.6777655184269, 70.95325067639351, 4.933479521423578, 0.21688958600861952, 0.21046653535449877, 1.1360476026311517, 43.31254966557026, 71.91518425941467, 71.65774807333946, 73.9031919836998, 71.40423327684402, 73.0941241979599, 71.12230360507965, 66.50704845786095, 65.04454493522644, 70.14951020479202, 69.1580294072628, 66.673114746809, 66.4591558277607, 64.0584446489811, 60.18804833292961, 54.77455101907253, 51.46947696805, 49.300488755106926, 50.71695774793625, 50.73185674846172, 50.06191089749336, 50.262889713048935, 49.49930168688297, 48.71291108429432, 47.38283805549145, 49.484923258423805, 48.74143995344639, 48.55300806462765, 49.920550882816315, 49.350600466132164, 48.182334154844284, 47.19282545149326, 46.74873188138008, 47.815342247486115, 48.546404018998146, 45.52051618695259, 45.48842690885067, 44.51074697077274, 43.90024892985821, 47.82043397426605, 48.32671880722046, 51.32642604410648, 57.68007270991802, 50.67428223788738, 44.94659498333931, 42.211570143699646, 44.67296026647091, 44.687878265976906, 50.79828478395939, 50.51594093441963, 47.224116772413254, 52.35907003283501, 47.58917838335037, 49.62638586759567, 46.64916202425957, 49.702047407627106, 42.03289993107319, 41.87626093626022, 43.25027480721474, 41.84105962514877, 41.116286516189575, 43.95620472729206, 43.45430865883827, 42.91243113577366, 41.82200364768505, 44.641767740249634, 42.76624917984009, 41.91952161490917, 42.03243635594845, 42.96767257153988, 45.741029754281044, 41.36182174086571, 41.65959656238556, 44.23652708530426, 41.897801980376244, 41.474060118198395, 41.405887976288795, 44.03582565486431, 42.71195389330387, 43.20064567029476, 45.90627148747444, 43.34992066025734, 39.42411571741104, 40.76751463115215, 43.420551270246506, 44.0286972373724, 43.936973959207535, 46.77096828818321, 43.424161076545715, 42.81394802033901, 39.95400108397007, 37.323086857795715, 37.15160205960274, 39.37174312770367, 35.506989508867264, 39.50249411165714, 47.27158762514591, 41.499777138233185, 41.38964764773846, 42.92345054447651, 44.66354437172413, 44.623787105083466, 43.492891788482666, 43.68714116513729, 45.95310017466545, 47.76081897318363, 45.82127004861832, 46.13670252263546, 46.7856203019619, 54.71657373011112, 59.77619983255863, 62.33937509357929, 62.09619574248791, 62.623926624655724, 62.18002304434776, 62.43535794317722, 60.74678935110569, 59.15340185165405, 56.38523519039154, 62.328804060816765, 60.07952995598316, 62.418236061930656, 65.85128724575043, 66.16841062903404, 66.19253173470497, 66.56375661492348, 67.74616956710815, 65.47028928995132, 68.47215101122856, 68.16186726093292, 68.09040829539299, 71.01844757795334, 70.77896162867546, 58.61295685172081, 71.42322465777397, 82.73918464779854, 72.35523104667664, 15.828634891659021, 0.16854768939083442, 0.11008757399395108, 0.3608138841809705, 54.686904922127724, 71.38729378581047, 69.15371283888817, 61.17257170379162, 39.37531113624573, 48.40449683368206, 55.27007482945919, 54.99273531138897, 72.88904160261154, 5.511914882808924, 0.07584538485389203, 0.08509959530783817, 0.08830202932585962, 0.11524268760695122, 0.08457367235678248, 0.15497775661060587, 0.15735259948996827, 0.1979302807012573, 0.22635165718384087, 0.13277076854137704, 0.13587941735750064, 0.26280975085683167, 0.21510394901270047, 48.99302825331688, 77.05181702971458, 61.04302905499935, 35.09141720831394, 58.717287853360176, 77.12787374854088, 73.33886906504631, 80.55164203047752, 5.390778332948685, 0.42962584644556046, 0.19621240178821608, 2.2426353860646486, 49.175650253891945, 73.94679084420204, 73.65118190646172, 77.03268885612488, 74.30670753121376, 75.73418453335762, 71.92588448524475, 68.18578317761421, 68.03516685962677, 72.4993497133255, 70.19342064857483, 71.19305580854416, 70.82207411527634, 68.0945348739624, 63.6518170684576, 57.97373615205288, 54.1425347328186, 51.828736290335655, 52.15927295386791, 54.06905047595501, 52.14611046016216, 53.08925025165081, 52.70047031342983, 53.64676773548126, 50.436563193798065, 51.377476304769516, 50.370663329958916, 51.97679914534092, 51.815813183784485, 53.33716794848442, 50.036839842796326, 48.486633226275444, 49.971205964684486, 47.23700188100338, 51.871913373470306, 48.356076031923294, 46.90708838403225, 46.63041763007641, 47.49093845486641, 52.445515394210815, 50.77263996005058, 52.28982634842396, 59.440681636333466, 50.80191358923912, 46.96247421205044, 41.033450961112976, 42.99259923398495, 45.96455276012421, 51.281793639063835, 51.308316215872765, 49.74459372460842, 53.91646586358547, 48.17553251981735, 51.47289298474789, 48.20864014327526, 51.28391392529011, 46.55111588537693, 45.272609889507294, 47.90844485163689, 44.66373436152935, 42.64838710427284, 47.713374719023705, 47.518057599663734, 48.240269646048546, 44.1535547375679, 46.56182371079922, 45.55874593555927, 45.00936761498451, 44.666208028793335, 46.783841997385025, 48.32574225962162, 45.65925434231758, 44.61082220077515, 47.379851415753365, 45.20588926970959, 44.1899111866951, 45.53023226559162, 45.85021689534187, 46.11346676945686, 45.90879835188389, 48.194451704621315, 43.88611748814583, 40.106239914894104, 42.08657965064049, 45.038671642541885, 45.7764932513237, 46.0266300290823, 45.60026630759239, 44.655010029673576, 44.293641820549965, 40.12394696474075, 37.95194931328297, 39.15488876402378, 39.243678599596024, 38.25955040752888, 39.47554975748062, 50.35794161260128, 43.50242167711258, 44.59004871547222, 46.19388185441494, 49.14099611341953, 47.13963210582733, 46.447575241327286, 46.252102330327034, 48.18022146821022, 50.66581629216671, 49.63458202779293, 48.14832977950573, 50.14254257082939, 58.36641848087311, 63.285725712776184, 66.85366585850716, 65.80647245049477, 65.42728319764137, 63.5286732763052, 65.29334798455238, 63.35227534174919, 63.06959331035614, 58.445701226592064, 64.70653027296066, 62.17301622033119, 64.86938953399658, 69.31816801428795, 69.15602311491966, 71.14724546670914, 68.40763047337532, 69.2863105237484, 68.95583465695381, 72.92518526315689, 71.80085599422455, 72.82167881727219, 76.60702049732208, 73.35779964923859, 63.55452708899975, 77.77234956622124, 83.00573274493217, 71.73394158482552, 17.619724832475185, 0.4773690673755482, 0.22955087770242244, 0.38025990477763116, 61.54364839196205, 78.70428755879402, 76.48798808455467, 71.44849330186844, 54.36323069036007, 60.2393189817667, 63.69310185313225, 64.16730880737305, 82.69118562340736, 6.93020730279386, 0.3401960717746988, 0.23819030786398798, 0.2752504911040887, 0.2601360302651301, 0.15544376597972587], [0.020761186060553882, 0.020958317181793973, 0.12050562785589136, 0.16919843415962532, 0.07169076794525608, 0.058266388878109865, 0.04882539840764366, 0.14584316551918164, 28.856280483305454, 59.17680099606514, 35.76905384659767, 25.83615504205227, 32.5195138156414, 53.63965831696987, 63.65666180849075, 66.32273554801941, 6.694407630711794, 0.22382500057574362, 0.264077665633522, 0.559900727821514, 28.910577669739723, 68.25895205140114, 68.80753621459007, 71.21040567755699, 68.86049017310143, 71.72361373901367, 65.56025326251984, 64.14584755897522, 66.50354504585266, 69.43426698446274, 67.49450147151947, 63.37634705007076, 59.54971678555012, 52.32265658676624, 48.313613310456276, 47.94293940067291, 48.568629026412964, 48.55316765606403, 47.41356320679188, 46.69758662581444, 47.60606847703457, 46.04823186993599, 45.38892924785614, 46.61258138716221, 46.62843033671379, 46.04767709970474, 46.63196034729481, 49.865241050720215, 50.405974835157394, 51.4272840321064, 49.19738508760929, 48.61476615071297, 49.47846740484238, 44.44566406309605, 45.03597378730774, 45.64779795706272, 44.12978321313858, 44.60777096450329, 42.829694375395775, 41.64301045238972, 44.22294661402702, 46.47546574473381, 47.98599109053612, 54.20675128698349, 49.919437542557716, 43.92061583697796, 49.14326459169388, 51.82924546301365, 53.01469065248966, 60.40115989744663, 51.14402063190937, 51.391907930374146, 54.461645409464836, 53.80434148013592, 52.4776578694582, 45.22576220333576, 43.2180867344141, 41.5721670538187, 40.58818705379963, 38.96302945911884, 38.76961603760719, 40.22073917090893, 40.173306316137314, 40.518149212002754, 42.06628113985062, 41.1661322414875, 40.172493159770966, 39.232077822089195, 40.376101434230804, 41.32548049092293, 41.607258170843124, 40.126899406313896, 40.26870019733906, 38.956668600440025, 39.57750968635082, 37.407579123973846, 39.398505091667175, 40.17714411020279, 41.85829930007458, 43.707329481840134, 41.986873000860214, 39.75057899951935, 40.1082956045866, 38.257635310292244, 41.90271511673927, 46.25606171786785, 43.73223714530468, 46.539123728871346, 42.08472155034542, 39.902536645531654, 42.04842209815979, 42.02024281024933, 36.96710675954819, 38.32013435661793, 36.84343099594116, 42.85203717648983, 44.952370673418045, 42.42717057466507, 42.68768459558487, 41.175540536642075, 39.29321274161339, 42.05398119986057, 40.13991750776768, 43.07709909975529, 42.7996189892292, 45.44759429991245, 44.24649775028229, 43.95326368510723, 45.33734321594238, 43.089634627103806, 49.25291910767555, 50.400221943855286, 58.808399364352226, 57.51728564500809, 60.13827480375767, 61.655153408646584, 61.24725669622421, 61.04067698121071, 60.35150796175003, 57.4263147264719, 60.54258070886135, 61.0272940993309, 62.831517085433006, 62.444234266877174, 62.56012424826622, 62.13711194694042, 63.98320868611336, 60.80108843743801, 61.57270923256874, 59.32397849857807, 63.3898439258337, 61.6714621335268, 66.64170563220978, 68.2875645160675, 60.36094285547733, 63.87036234140396, 83.95287752151489, 18.695564903318882, 0.582388574257493, 0.20936886925483122, 0.034805167524609715, 44.054505452513695, 64.84941020607948, 63.474518582224846, 54.89184312522411, 44.52558897435665, 18.37900009006262, 20.321248769760132, 50.1332026720047, 60.47563590109348, 6.354231834411621, 0.3307129384484142, 0.16812603076687083, 0.02550754143157974, 0.11840481558465399, 0.04895001613476779, 0.02299692263477482, 0.020004970974696334, 0.0661555262922775, 0.042150774534093216, 0.1097954275610391, 0.06235524779185653, 0.038918569262023084, 0.0466794116073288, 36.349940076470375, 68.92482072114944, 40.91317221522331, 26.78244486451149, 38.16606782376766, 59.82338950037956, 69.3917852640152, 74.63340640068054, 7.233233917504549, 0.31272443651687354, 0.11961226759012789, 0.49779181368649006, 33.745381236076355, 72.42118030786514, 70.20075425505638, 74.05921161174774, 70.71799010038376, 72.47101843357086, 66.04361772537231, 65.04164189100266, 69.16654855012894, 71.07838556170464, 68.85928183794022, 66.68781235814095, 61.032245233654976, 54.9016921967268, 52.26681858301163, 50.11177942156792, 49.471897557377815, 51.029072999954224, 49.915991127491, 49.87773858010769, 48.920581340789795, 46.793052703142166, 48.07009197771549, 48.198832869529724, 50.01899600028992, 47.21518725156784, 49.85296010971069, 52.06054665148258, 51.595816388726234, 54.74491260945797, 53.89645613729954, 52.27800518274307, 52.59698286652565, 47.63681262731552, 47.68465965986252, 48.29469032585621, 46.982829719781876, 45.400879606604576, 44.43676874041557, 44.13447596132755, 46.09829418361187, 47.12749555706978, 49.43800337612629, 57.461949214339256, 49.75176773965359, 44.47648420929909, 49.47472840547562, 53.06545212864876, 54.50216643512249, 62.615627869963646, 52.919627353549004, 52.39590525627136, 54.9410504847765, 55.084975361824036, 55.24843879044056, 45.755043402314186, 44.84694913029671, 44.81234058737755, 43.44917893409729, 43.461361080408096, 41.51491552591324, 42.502311542630196, 42.61251322925091, 43.53541910648346, 42.97466799616814, 43.56732599437237, 44.181221053004265, 41.79714538156986, 41.978445053100586, 43.44058379530907, 43.72692123055458, 43.29188257455826, 41.88319556415081, 42.78582952916622, 41.43947817385197, 40.27998559176922, 43.32223154604435, 41.79079592227936, 45.16794830560684, 45.497504621744156, 43.87821011245251, 40.21572723984718, 40.29529497027397, 36.83620758354664, 42.731697633862495, 47.71279715001583, 45.89602343738079, 46.33141167461872, 43.04365709424019, 40.519273951649666, 42.46900252997875, 41.06196463108063, 37.449939250946045, 38.857607915997505, 37.08309553563595, 44.64767262339592, 48.10405075550079, 43.62203545868397, 44.25063952803612, 44.496273547410965, 42.84761801362038, 43.97686801850796, 43.540655225515366, 46.49299040436745, 45.09817644953728, 46.08984723687172, 46.05275742709637, 45.62731705605984, 45.64281642436981, 44.96795743703842, 50.48841141164303, 55.329066663980484, 60.42115442454815, 59.12809520959854, 60.79973191022873, 63.37100453674793, 63.71925204992294, 63.56502592563629, 62.47930258512497, 60.05087569355965, 63.85648548603058, 62.51602001488209, 64.73611548542976, 64.71094563603401, 62.84543953835964, 63.75311583280563, 65.92862829566002, 63.948280960321426, 62.702263221144676, 62.06820644438267, 63.69335263967514, 64.5943982899189, 68.73332619667053, 70.95059841871262, 63.64462785422802, 67.79177471995354, 82.45029374957085, 21.97580348700285, 0.6186068651732057, 0.2652927691815421, 0.01661190890445141, 47.927934005856514, 71.17569833993912, 71.54053956270218, 64.56535264849663, 50.06647825241089, 28.68367664515972, 34.06644880771637, 57.699360474944115, 73.28596830368042, 7.985396906733513, 0.2182813355466351, 0.18121796107152477, 0.048323268711101264, 0.12335356019320898, 0.006605970111195347, 0.1291553961345926, 0.09822520427405834, 0.15378214186057448, 0.3390588640468195, 0.19301188993267715, 0.15429208637215197, 0.1623019971884787, 0.36309500865172595, 51.659204587340355, 79.11171689629555, 50.11544622480869, 32.86227062344551, 42.87699803709984, 69.3176132440567, 73.80481526255608, 82.1714799106121, 7.645147014409304, 0.2789907075930387, 0.2047238263185136, 0.9363369096536189, 40.10674148797989, 76.27171888947487, 77.06447795033455, 77.27643057703972, 74.43911522626877, 74.83314648270607, 68.18544119596481, 65.71336224675179, 73.48718270659447, 75.6697703897953, 73.93575623631477, 68.74373003840446, 65.18275871872902, 56.3174544274807, 54.78499285876751, 53.010070100426674, 52.87868835031986, 54.48049999773502, 53.39680954813957, 52.98250637948513, 53.47734622657299, 51.0361710190773, 50.875869020819664, 50.76495677232742, 52.22993016242981, 50.584690645337105, 53.835913985967636, 55.80208048224449, 55.73845289647579, 55.78088141977787, 54.890927374362946, 53.08185584843159, 56.88918314874172, 47.3785936832428, 51.68178677558899, 50.80562599003315, 49.150233417749405, 48.32172967493534, 47.978262305259705, 47.73666746914387, 51.551533564925194, 51.769695058465004, 52.42592744529247, 59.744714722037315, 51.242518946528435, 44.73411038517952, 49.43139933049679, 53.817845955491066, 53.63022342324257, 65.58119773864746, 53.438538908958435, 54.07627008855343, 56.70411787927151, 56.16962715983391, 56.684598326683044, 47.321102768182755, 47.298114001750946, 47.240744680166245, 44.747998639941216, 45.054870173335075, 44.78928342461586, 45.057913810014725, 45.93012660741806, 47.919547855854034, 47.15919345617294, 45.25774508714676, 47.016058936715126, 45.237066596746445, 47.47228905558586, 47.2871819883585, 47.47531369328499, 46.20583601295948, 43.42086285352707, 45.48920586705208, 44.184918254613876, 43.991204649209976, 45.690025091171265, 45.21810941398144, 46.61088667809963, 48.646612241864204, 45.61621405184269, 41.14933714270592, 41.7557618021965, 37.579888477921486, 45.17675623297691, 49.88533437252045, 47.984041795134544, 47.998568415641785, 44.27748128771782, 41.102497056126595, 43.569339886307716, 43.52079749107361, 37.12818771600723, 38.93779881298542, 36.46440893411636, 45.900469198822975, 50.66747300326824, 48.17449137568474, 46.36212922632694, 46.39903284609318, 46.3496582955122, 48.38571824133396, 45.6524109095335, 48.299652859568596, 46.6906064003706, 49.48765531182289, 48.39567370712757, 48.05082321166992, 48.30708526074886, 46.78619027137756, 53.09135153889656, 56.96366675198078, 62.923912927508354, 63.33078749477863, 64.81102466583252, 67.76468977332115, 65.9233009815216, 65.94998314976692, 66.41126319766045, 62.8632377833128, 66.14105209708214, 66.90153568983078, 67.90054768323898, 66.95878341794014, 66.60280331969261, 67.95914053916931, 69.19990316033363, 68.38046193122864, 66.41587615013123, 65.46230971813202, 68.1386961042881, 68.348528444767, 75.0063107907772, 75.24235412478447, 67.96784207224846, 78.56977477669716, 82.07993522286415, 22.771034315228462, 1.0242655570618808, 0.5302869575098157, 0.18858566181734204, 56.2672059237957, 78.22404652833939, 80.80601558089256, 71.41453072428703, 68.86074855923653, 26.322084367275238, 35.59164896607399, 65.3508161008358, 85.15550538897514, 11.280881222337484, 0.6715925876051188, 0.2865491551347077, 0.11067125829868019, 0.26622342236805707, 0.166658908710815], [0.05698251050489489, 0.050073367965524085, 0.050040858186548576, 0.03521859944157768, 0.13414437999017537, 0.06996198688284494, 0.028839543301728554, 0.045937850227346644, 24.039012975990772, 58.22314716875553, 41.888446882367134, 45.494339391589165, 39.0261896699667, 55.285771787166595, 62.32535384595394, 68.29478412866592, 10.15833405777812, 0.40746965096332133, 0.43947800528258085, 0.4267640062607825, 18.793289959430695, 66.50362864136696, 66.56344503164291, 71.27147600054741, 67.77901500463486, 67.2703742980957, 67.79297545552254, 70.43435052037239, 69.3013197183609, 65.79405471682549, 62.206203639507294, 54.834245815873146, 48.98336537182331, 49.46489833295345, 47.41630665957928, 47.43616819381714, 45.989540219306946, 45.87521955370903, 46.618341878056526, 45.98874606192112, 45.45830972492695, 47.314217537641525, 46.74213923513889, 47.4320188164711, 46.579333171248436, 48.11010003089905, 53.60607571899891, 60.11528983712196, 58.34143862128258, 57.68758110702038, 55.6899257004261, 54.04335245490074, 49.63046304881573, 48.28318074345589, 44.76287104189396, 45.948472023010254, 44.33636672794819, 43.13922956585884, 42.6567542552948, 42.59112797677517, 44.761461317539215, 45.43822780251503, 48.5226096957922, 53.68052892386913, 57.032279670238495, 47.178978994488716, 44.09716196358204, 49.88325208425522, 55.157357677817345, 59.35815766453743, 61.11204855144024, 57.051711827516556, 53.4790713340044, 53.842609226703644, 48.51800434291363, 44.86035481095314, 43.73248413205147, 45.87410621345043, 47.248291075229645, 40.647361278533936, 40.246178805828094, 38.408567011356354, 39.09538775682449, 40.213378965854645, 39.49789635837078, 40.71091286838055, 42.012213841080666, 38.62791784107685, 41.803768426179886, 39.55001436173916, 41.55079700052738, 41.672379076480865, 40.10045662522316, 40.07295370101929, 41.56842805445194, 39.504409208893776, 38.93772281706333, 40.16777381300926, 44.98342640697956, 41.41764834523201, 39.777929931879044, 39.552438631653786, 41.43825463950634, 38.705182895064354, 43.728691935539246, 43.46438191831112, 40.22764340043068, 41.976313367486, 39.23076689243317, 43.54785203933716, 43.770212307572365, 39.916326105594635, 41.68109580874443, 41.40240736305714, 42.1186613291502, 50.094087570905685, 45.361810103058815, 40.2994329482317, 39.47216033935547, 40.590789914131165, 40.19007861614227, 39.9980179220438, 41.006669998168945, 42.5750320404768, 44.60367478430271, 41.46747127175331, 42.96732299029827, 42.64628581702709, 44.024004489183426, 42.24509574472904, 43.44474837183952, 44.903946071863174, 46.91228650510311, 46.825765147805214, 49.69611592590809, 52.61969804763794, 54.62412089109421, 57.43152804672718, 60.95381364226341, 61.093908324837685, 61.27350188791752, 60.120529755949974, 59.3119141459465, 56.771739050745964, 57.02808849513531, 54.81896683573723, 56.7166306078434, 58.17627288401127, 60.637013241648674, 59.28091160953045, 59.912437722086906, 61.20448999106884, 65.93305125832558, 64.65139523148537, 75.16212522983551, 58.2426743209362, 68.06601360440254, 27.252738028764725, 0.36017884325701743, 0.18053089559543878, 0.25468554929830134, 34.2472393065691, 68.95717978477478, 58.935696333646774, 59.68452975153923, 34.40863944590092, 26.12924661487341, 31.129248216748238, 43.481518998742104, 63.64260636270046, 12.206518203020096, 0.22426303097745404, 0.10003407049225643, 0.029091057149344124, 0.13806205883156508, 0.03131662815576419, 0.06041659849870484, 0.0453593757993076, 0.006763537339793402, 0.031739455662318505, 0.11123615884571336, 0.03163971472531557, 0.05647070320264902, 0.057032698241528124, 32.82986596226692, 67.51204133033752, 47.159178256988525, 43.42661194503307, 41.95175148546696, 63.44525255262852, 67.52543181180954, 77.3492194712162, 11.074745133519173, 0.5076803674455732, 0.23925261804834008, 0.5041947669815272, 23.68781302124262, 70.03825217485428, 68.64753440022469, 73.21030676364899, 69.74200487136841, 69.86171364784241, 69.99026834964752, 72.07732915878296, 70.37977024912834, 68.0467714369297, 64.41168889403343, 58.57205964624882, 51.24003767967224, 51.34365811944008, 49.87613886594772, 49.17857989668846, 48.338874354958534, 48.403839468955994, 48.05962733924389, 47.11938679218292, 48.80828596651554, 50.55088385939598, 49.53838258981705, 47.036775425076485, 47.57858835160732, 51.0261395573616, 55.41562221944332, 57.858180552721024, 58.73457692563534, 60.43716676533222, 57.73247189819813, 55.76766572892666, 51.889628022909164, 48.76030974090099, 46.47158235311508, 48.477775901556015, 44.95696842670441, 45.62946014106274, 46.920315474271774, 46.08214884996414, 47.41406098008156, 47.37241521477699, 48.64441975951195, 55.88366970419884, 58.72594378888607, 49.600714445114136, 44.47808012366295, 51.1284376680851, 56.056887209415436, 62.23929986357689, 62.93079815804958, 58.69510844349861, 54.45317566394806, 54.89165313541889, 50.65702736377716, 46.03356845676899, 44.50557924807072, 47.22452335059643, 48.98056112229824, 44.65167000889778, 42.31839761137962, 42.73767091333866, 42.53762684762478, 42.265774235129356, 43.64899881184101, 43.85201431810856, 44.48463477194309, 41.762092262506485, 45.02737104892731, 43.15528370440006, 45.1715999096632, 43.78850072622299, 42.45022013783455, 42.77804374694824, 43.405656069517136, 42.478239834308624, 42.15250611305237, 43.44543233513832, 46.83272637426853, 42.149295285344124, 40.31780116260052, 40.94386696815491, 40.69791756570339, 39.43689063191414, 45.21760784089565, 44.728756472468376, 41.91506065428257, 42.3663966357708, 39.403976798057556, 43.05749595165253, 43.47802318632603, 41.33088380098343, 42.237321361899376, 41.231287345290184, 43.18337179720402, 53.01765829324722, 46.55688777565956, 42.190165892243385, 41.202294901013374, 42.815958112478256, 41.63971982896328, 42.43204191327095, 43.81793014705181, 44.27533060312271, 45.600304305553436, 43.21472771465778, 45.28758488595486, 45.17457515001297, 46.18791997432709, 44.84524302184582, 45.806253254413605, 45.244681388139725, 48.806652054190636, 49.599623903632164, 52.738700062036514, 54.24443766474724, 58.12945179641247, 59.533833637833595, 62.08145633339882, 63.361573442816734, 63.31327423453331, 63.17183442413807, 61.11780904233456, 58.90852779150009, 59.51858885586262, 57.49727971851826, 58.54195386171341, 61.318183690309525, 62.07504987716675, 62.53985993564129, 63.95521938800812, 65.50434306263924, 67.60955929756165, 69.08736079931259, 76.00799024105072, 64.24784168601036, 68.31797048449516, 29.91037242114544, 0.12696021236479282, 0.24054900160990655, 0.22395061649149284, 38.46502058207989, 77.6637589931488, 65.93971610069275, 66.48519963026047, 38.91413748264313, 20.15766564756632, 35.03873683512211, 47.67788462340832, 77.13300347328186, 15.84166819229722, 0.40316890517715365, 0.12368940428132191, 0.00445722530457715, 0.13573040894698352, 0.01643717580009252, 0.14462770574027672, 0.11738737564883195, 0.2743899857159704, 0.14230404136469588, 0.26370187173597515, 0.15721534669864923, 0.17137873044703156, 0.18109418568201363, 46.091146767139435, 79.15336266160011, 57.29318127036095, 63.50969709455967, 58.64603027701378, 75.2561017870903, 73.49966123700142, 84.30582538247108, 12.662744522094727, 0.47934715810697526, 0.49464959010947496, 0.792734184069559, 29.29994087666273, 75.14988988637924, 73.4199795126915, 77.26512238383293, 73.33082109689713, 72.54983380436897, 72.81470999121666, 76.70578479766846, 74.0932197868824, 71.78671315312386, 68.05144518613815, 61.01209111511707, 52.85364769399166, 53.95232833921909, 53.08111108839512, 51.89244367182255, 51.17623150348663, 50.569331869482994, 51.14460200071335, 50.512049943208694, 49.801218286156654, 54.017836824059486, 51.945074647665024, 50.2895300835371, 51.76599405705929, 51.48858994245529, 57.67349146306515, 61.88142366707325, 61.83708764612675, 63.87670040130615, 61.49032965302467, 57.432831376791, 54.02562640607357, 52.24745102226734, 50.121879279613495, 50.89995592832565, 48.157339096069336, 47.824560552835464, 49.076152592897415, 48.08586873114109, 49.41740468144417, 50.182079449296, 52.91460022330284, 57.565261870622635, 62.476528733968735, 49.72427241504192, 44.139700680971146, 51.61065839231014, 58.491982743144035, 65.34384727478027, 65.09217917919159, 60.80707311630249, 56.45365431904793, 56.54016427695751, 51.66601002216339, 46.649382412433624, 46.36765792965889, 49.25711028277874, 52.222972735762596, 47.066630423069, 44.512772262096405, 45.69958917796612, 47.346477806568146, 44.81484465301037, 45.212926492094994, 47.098104134202, 47.98908792436123, 44.11278672516346, 48.074811324477196, 44.62725251913071, 49.23410251736641, 47.855981066823006, 45.128719210624695, 44.90916699171066, 45.4269690066576, 45.54389253258705, 45.80019257962704, 46.28540754318237, 47.98776939511299, 42.326829358935356, 39.70250777900219, 41.77357144653797, 40.892584919929504, 39.85577255487442, 44.762988835573196, 45.63325233757496, 41.47627539932728, 42.67782412469387, 39.759219735860825, 44.15156364440918, 44.53279338777065, 41.067964509129524, 42.85842843353748, 41.55738204717636, 44.59034509956837, 54.32030439376831, 49.38148520886898, 45.272792279720306, 42.81415320932865, 45.74637986719608, 43.04517321288586, 44.82286222279072, 45.444269478321075, 47.90583819150925, 48.065798208117485, 44.73689563572407, 46.34576350450516, 47.383917197585106, 47.78757333755493, 47.84087687730789, 47.8537467867136, 48.96813578903675, 51.473071575164795, 53.27503748238087, 54.41437214612961, 58.95131729543209, 61.121802628040314, 62.34972953796387, 67.41521492600441, 67.46977999806404, 66.56697884202003, 64.96264412999153, 64.8866406083107, 62.35934302210808, 63.071200624108315, 62.969293892383575, 61.835765317082405, 64.55140739679337, 65.80439776182175, 65.87416961789131, 67.06978306174278, 68.3402068912983, 70.10072082281113, 74.39906537532806, 80.92580035328865, 65.99856734275818, 76.10113844275475, 31.55024092644453, 0.5409684812184423, 0.6873820465989411, 0.46874302555806935, 44.699368849396706, 82.68253728747368, 75.34864202141762, 74.67106997966766, 53.24334338307381, 36.03063181042671, 48.01792077720165, 58.59449364244938, 90.94841614365578, 20.581874884665012, 0.6604474887717515, 0.3070079698227346, 0.13794600177789107, 0.3159559256164357, 0.11166490497998893], [0.0874946839758195, 0.030866279957990628, 0.08263988784165122, 0.04862123358179815, 0.10901945279329084, 0.04549421661067754, 0.12078684245352633, 0.140614022675436, 24.229502454400063, 56.24188408255577, 41.488894522190094, 33.7726903706789, 34.45612169802189, 57.4841134250164, 61.368082612752914, 69.97418001294136, 10.395812764763832, 0.41886794089805335, 0.416223164065741, 0.3038964414736256, 11.974738240242004, 63.8832588493824, 65.69817826151848, 68.22690457105637, 68.28274637460709, 70.65240561962128, 69.16446626186371, 69.11657363176346, 66.07726112008095, 64.59765091538429, 54.87280614674091, 49.85790744423866, 50.39465144276619, 46.22064761817455, 46.66653469204903, 46.03221192955971, 46.69885955750942, 47.893865033984184, 49.389293789863586, 48.94427686929703, 52.28235974907875, 50.70015124976635, 51.63849949836731, 52.106459587812424, 55.165230855345726, 55.68370923399925, 56.54794625937939, 61.6902407258749, 62.330605164170265, 61.717633455991745, 58.38948704302311, 56.187820583581924, 53.97341340780258, 48.74476097524166, 48.1940945237875, 45.58717980980873, 44.2388753592968, 42.48861327767372, 42.0510021597147, 41.94925881922245, 41.63137927651405, 44.55798603594303, 43.64852383732796, 52.287835255265236, 57.915413081645966, 59.10491645336151, 52.4089689552784, 43.88673685491085, 50.556503757834435, 56.541752591729164, 56.15353882312775, 56.19047284126282, 55.493814423680305, 54.15480047464371, 48.733718767762184, 49.941818341612816, 47.02696435153484, 45.34363567829132, 45.315760374069214, 42.41463504731655, 41.2454529851675, 42.11740359663963, 39.89339053630829, 40.641794577240944, 40.395696982741356, 38.187730461359024, 39.84021618962288, 37.602337673306465, 41.36325426399708, 39.56911213696003, 40.938273668289185, 40.08363112807274, 39.81036119163036, 39.64948922395706, 42.131622433662415, 41.95111691951752, 42.70274318754673, 46.176847368478775, 39.62800897657871, 44.15628299117088, 45.37490800023079, 42.049763426184654, 41.458632946014404, 43.950189650058746, 48.81266713142395, 47.712679356336594, 55.64239785075188, 49.454600885510445, 46.254606395959854, 51.49642892181873, 53.52592281997204, 50.59746935963631, 46.22491858899593, 45.808061957359314, 50.15561766922474, 50.733745247125626, 41.95713199675083, 40.5193879455328, 38.739008679986, 40.285016521811485, 39.11122150719166, 40.1151542365551, 41.44205443561077, 43.285020142793655, 44.21587139368057, 41.717133074998856, 43.5744734108448, 42.93726660311222, 43.64100404083729, 42.46906712651253, 42.699874341487885, 42.66536459326744, 42.63613276183605, 46.39389932155609, 42.72617653012276, 45.32961443066597, 46.55849888920784, 49.91782262921333, 51.14169515669346, 52.55117632448673, 52.151430174708366, 53.166868686676025, 51.66374534368515, 50.517700240015984, 51.2792781740427, 52.54385031759739, 54.43128123879433, 57.915842458605766, 57.955922707915306, 58.516696617007256, 60.074601620435715, 62.01020635664463, 61.242867931723595, 66.76567777991295, 67.5225667655468, 75.55084437131882, 63.33659738302231, 28.832037784159184, 0.6289820303209126, 0.4701043025124818, 0.4838009941158816, 22.892390303313732, 70.94950407743454, 62.81718425452709, 56.03603012859821, 49.85954135656357, 32.03511580824852, 34.86159794032574, 46.15027539432049, 63.601112589240074, 15.598493590950966, 0.3625916544115171, 0.19665803178213537, 0.07042587370960973, 0.10402257990790531, 0.051619621517602354, 0.08064287976594642, 0.04233083069266286, 0.0409539055544883, 0.05516061217349488, 0.030307374108815566, 0.06308431882644072, 0.03731907403562218, 0.04130447756324429, 34.81207139790058, 65.14806658029556, 47.39776745438576, 40.08791729807854, 39.456816762685776, 65.00436589121819, 67.81807690858841, 77.40121588110924, 11.805907599627972, 0.3969913866603747, 0.19037500955164433, 0.46317890693899244, 15.234958548098803, 70.8566902577877, 67.94658601284027, 70.20880982279778, 71.38293921947479, 72.94409304857254, 71.56471386551857, 70.44946610927582, 70.21738216280937, 66.03060722351074, 57.63941869139671, 53.11449609696865, 51.744707599282265, 49.76028688251972, 49.21467415988445, 48.29557567834854, 48.623631075024605, 50.64267173409462, 53.29818204045296, 52.06009067595005, 54.613819643855095, 54.290012419223785, 54.97100807726383, 55.770629569888115, 56.47253170609474, 58.12033988535404, 61.42464637756348, 63.50316904485226, 61.60832852125168, 61.94269917905331, 59.6150428801775, 58.43198016285896, 54.944736286997795, 50.31661503016949, 48.782280161976814, 47.18164645135403, 45.75617574155331, 45.225009843707085, 44.39416162669659, 42.201656475663185, 43.57574254274368, 46.096755266189575, 45.08591070771217, 54.72388833761215, 60.56555047631264, 60.98277188837528, 53.07308591902256, 45.98065249621868, 50.94958886504173, 58.05289730429649, 57.36468203365803, 57.43470847606659, 56.38503760099411, 54.03916887938976, 51.12352833151817, 51.74104079604149, 48.96404340863228, 47.16093756258488, 47.88145869970322, 44.51271526515484, 44.467007517814636, 42.930761352181435, 43.1287345290184, 43.59455153346062, 44.38908509910107, 40.35851217806339, 42.39033155143261, 39.37577471137047, 42.7565710991621, 41.82510048151016, 43.33054929971695, 41.17137975990772, 42.44371108710766, 40.937209725379944, 42.47351288795471, 44.88311178982258, 45.39528630673885, 48.491565361618996, 40.148653239011765, 44.647368639707565, 46.59811556339264, 42.47457683086395, 40.03173351287842, 45.70188045501709, 49.05114993453026, 49.12485457956791, 58.17974969744682, 49.45641718804836, 47.05398090183735, 53.5353197157383, 55.238882303237915, 50.34533008933067, 46.84567987918854, 48.88150043785572, 53.33054110407829, 52.74935469031334, 44.876025170087814, 42.50106520950794, 41.035438254475594, 43.54408264160156, 42.019140869379044, 43.5167621076107, 42.1966977417469, 43.831054642796516, 45.96332162618637, 44.80830520391464, 45.41940361261368, 46.51947118341923, 44.962918907403946, 45.56129179894924, 44.50784012675285, 44.53858807682991, 44.62560720741749, 48.846663907170296, 45.484950095415115, 46.8383576720953, 46.870956122875214, 50.63289485871792, 51.76989644765854, 55.88387489318848, 54.01187114417553, 54.67579431831837, 52.2024842351675, 53.39024730026722, 52.689975276589394, 55.63654996454716, 57.233478873968124, 61.239961087703705, 59.66979794204235, 62.60566860437393, 61.14085100591183, 63.319863080978394, 65.35010933876038, 71.10812276601791, 70.1619279384613, 79.67753693461418, 67.81934604048729, 31.35565336793661, 0.8871034858748317, 0.2021395493648015, 0.5361594236455858, 24.2417548969388, 78.40453684329987, 69.90879312157631, 66.10975697636604, 53.19271109998226, 28.15186098217964, 38.680924996733665, 51.29892311990261, 75.65303608775139, 21.166232228279114, 0.3610149468295276, 0.18360862653935328, 0.05001182165869977, 0.1430051779607311, 0.07594001610414125, 0.19501365517498925, 0.11229386029299349, 0.16960608103545383, 0.1760550623293966, 0.23199629882583395, 0.20316147187259048, 0.1948434064979665, 0.23433400463545695, 46.677398309111595, 76.60075083374977, 55.25461345911026, 42.93805316090584, 50.25431737303734, 75.15118941664696, 72.41075366735458, 88.04604828357697, 12.703057508915663, 0.4857722867745906, 0.35466219240333885, 0.4580452339723706, 20.062579549849033, 76.3902573287487, 73.44897955656052, 73.48248615860939, 74.01957213878632, 74.74711149930954, 74.3958355486393, 74.28119570016861, 73.92383247613907, 71.17566034197807, 59.27276864647865, 55.772936046123505, 54.40877504646778, 51.22134268283844, 51.307845041155815, 50.08364953100681, 50.36378189921379, 52.61693559587002, 53.951781168580055, 53.57131518423557, 58.07909309864044, 57.354870960116386, 58.22237581014633, 56.786531656980515, 60.67153058946133, 60.06453976035118, 62.025234550237656, 68.39642867445946, 63.381434977054596, 62.28762947022915, 61.82730697095394, 62.61097311973572, 57.92110897600651, 53.280402794480324, 52.984679862856865, 50.158615708351135, 48.319932371377945, 47.21016012132168, 47.396882101893425, 46.43940567970276, 45.82353852689266, 50.11825427412987, 47.36365668475628, 57.15544246137142, 60.83661653101444, 64.9726451933384, 55.276929661631584, 44.52184237539768, 51.42832897603512, 62.270594984292984, 59.426489397883415, 60.60280367732048, 60.95893196761608, 56.970050409436226, 51.60914607346058, 53.89061205089092, 51.04487635195255, 48.46356846392155, 49.510777071118355, 45.75012646615505, 46.921747997403145, 47.347024977207184, 44.91797871887684, 46.714864298701286, 46.41206234693527, 42.232594415545464, 46.800108924508095, 42.97042362391949, 46.38380326330662, 44.45991709828377, 46.865237429738045, 44.154930263757706, 44.8522574454546, 43.8374724984169, 45.651810541749, 47.84938462078571, 48.216619715094566, 50.8271062374115, 43.1547137349844, 46.69822879135609, 46.457306519150734, 43.21326479315758, 41.57514609396458, 46.38547137379646, 50.61503581702709, 50.77757589519024, 59.831125885248184, 51.14522136747837, 48.68541955947876, 54.63801294565201, 56.77723355591297, 51.16350218653679, 51.4156224578619, 52.1504270285368, 55.64424455165863, 56.156795248389244, 47.82160811126232, 45.43989971280098, 43.31743620336056, 46.35244734585285, 44.9342380464077, 45.4181344807148, 45.074651911854744, 47.77770906686783, 47.69831232726574, 46.74587443470955, 47.60538451373577, 48.0405979603529, 47.08688713610172, 47.541802525520325, 48.63416410982609, 49.339341670274734, 46.04554921388626, 53.3512993901968, 47.6057492941618, 50.07316209375858, 49.558567106723785, 54.916515201330185, 56.44597493112087, 59.488540068268776, 56.703798696398735, 58.99863615632057, 55.973493084311485, 57.04044923186302, 56.12738862633705, 58.05422343313694, 59.959634989500046, 65.32144367694855, 63.077709674835205, 65.87612271308899, 64.51356902718544, 67.92948693037033, 68.90115559101105, 76.40456736087799, 74.5481313765049, 82.69667252898216, 69.11503091454506, 37.24411189556122, 1.2974090315401554, 0.9155415755230933, 0.65977439051494, 28.37597105652094, 85.54097950458527, 78.53338792920113, 72.53306150436401, 72.81007423996925, 46.21720880270004, 52.96634204685688, 63.11324156820774, 89.17356178164482, 26.965743228793144, 0.5613651929888874, 0.42728632979560643, 0.1560536480974406, 0.2546580304624513, 0.1184689297224395], [0.04589064221363515, 0.01574834401253611, 0.07972030856763013, 0.0669564817508217, 0.03407672360481229, 0.017054152849595994, 0.03012744968145853, 0.12251152686076239, 33.1049408018589, 56.19103901088238, 45.083494037389755, 37.54831597208977, 28.96934911608696, 55.674570724368095, 59.15483057498932, 67.99107402563095, 12.09495808929205, 0.4804013343527913, 0.38041064981371164, 0.2175509138032794, 4.006690252572298, 54.09487769007683, 66.23515784740448, 67.5791609287262, 68.00191104412079, 67.12425693869591, 66.52960404753685, 63.155290111899376, 61.34709633886814, 52.48866967856884, 50.68373613059521, 45.78517198562622, 47.150723710656166, 48.39333303272724, 47.77764447033405, 48.63988280296326, 48.89024376869202, 48.58113035559654, 51.70805096626282, 53.5859140008688, 58.18028926849365, 60.63836216926575, 59.278798922896385, 58.70271563529968, 57.543618232011795, 56.65781356394291, 60.657874122262, 57.48375244438648, 51.378008276224136, 47.02727973461151, 49.70793329179287, 51.04617968201637, 52.40979351103306, 51.166192442178726, 48.68783622980118, 47.254971116781235, 45.036536157131195, 43.95765624940395, 42.00860023498535, 40.82631267607212, 43.41777741909027, 42.6495536416769, 42.87300065159798, 45.71247808635235, 49.28361766040325, 57.74378389120102, 57.94318579137325, 51.70173570513725, 48.84719207882881, 52.24718123674393, 52.69224375486374, 50.96384949982166, 56.739566177129745, 52.49611347913742, 48.002869784832, 47.383487820625305, 46.66699446737766, 42.560030445456505, 42.63906240463257, 41.783135533332825, 41.572193652391434, 39.49579507112503, 37.470306158065796, 40.229140520095825, 41.288690865039825, 40.074762403964996, 39.424883276224136, 39.01850648224354, 40.48463121056557, 40.58959297835827, 40.80979876220226, 40.084432885050774, 41.28361813724041, 40.23259073495865, 43.456755727529526, 40.70355266332626, 41.909851133823395, 42.8348620980978, 39.84033018350601, 41.413073390722275, 39.29125964641571, 40.31524769961834, 41.875174194574356, 42.05373041331768, 44.40685674548149, 43.40379796922207, 51.21347710490227, 53.20729851722717, 55.93843996524811, 58.65062803030014, 50.66643945872784, 43.327235877513885, 45.049801245331764, 51.51397258043289, 54.16010499000549, 46.75237588584423, 41.34113185107708, 39.713059812784195, 40.335310623049736, 37.39143379032612, 40.335986986756325, 39.11342538893223, 41.89806416630745, 43.873141184449196, 44.37429629266262, 42.94249892234802, 44.51485455036163, 42.34963193535805, 43.14041130244732, 40.643363893032074, 41.321258917450905, 43.3768118172884, 43.00528295338154, 44.04088698327541, 43.34458574652672, 45.29953144490719, 45.46285808086395, 42.543197348713875, 44.821916073560715, 44.262118712067604, 46.79154418408871, 45.22128984332085, 44.071912318468094, 46.45133703947067, 50.30499905347824, 52.60528162121773, 55.46229511499405, 59.270576164126396, 60.30222460627556, 59.082607850432396, 57.16443657875061, 62.09829702973366, 61.20420500636101, 66.12788200378418, 70.64191818237305, 71.89043998718262, 73.63088339567184, 25.106882974505424, 0.36170698469504714, 0.4170763964066282, 0.499945170013234, 12.842237390577793, 71.29184290766716, 63.09793598949909, 57.20119200646877, 38.9581049233675, 28.274315111339092, 36.38515278697014, 42.275634706020355, 63.82880017161369, 23.870322927832603, 0.2582537359558046, 0.19089028268354014, 0.12834329361794516, 0.03211475603166036, 0.03845966224616859, 0.06170077744172886, 0.02930999999080086, 0.046798967887298204, 0.01875273035693681, 0.03827587308478542, 0.04918064965750091, 0.03242402752221096, 0.1480036464636214, 42.95788049697876, 64.65857684612274, 52.744247764348984, 37.259535267949104, 33.92629332840443, 64.03164848685265, 65.54379254579544, 76.24918609857559, 13.013362158089876, 0.5647567484993488, 0.7179757487028837, 0.23581807734444737, 5.6138805113732815, 61.910549104213715, 69.5734991133213, 69.69747886061668, 70.89980274438858, 69.70832347869873, 68.64144712686539, 67.19443917274475, 62.40802600979805, 56.272149458527565, 53.989923521876335, 48.651320189237595, 51.221183091402054, 50.21444991230965, 48.56955997645855, 50.523886308074, 51.0838508605957, 50.58051846921444, 53.840336948633194, 56.421382650732994, 59.3505846709013, 61.535714417696, 60.679247975349426, 62.8501208871603, 61.57123111188412, 59.737837091088295, 63.43989484012127, 60.475791692733765, 54.72120948135853, 52.15589493513107, 54.07888814806938, 54.76125933229923, 54.574081376194954, 53.54703448712826, 51.76406376063824, 48.924894109368324, 46.27374976873398, 46.25367544591427, 44.18831147253513, 43.68897266685963, 43.40510509908199, 45.50205297768116, 44.481180757284164, 47.92707905173302, 52.775907665491104, 61.22351557016373, 58.62263113260269, 53.03069919347763, 50.431779250502586, 53.58287036418915, 54.88487809896469, 52.674198523163795, 58.64480674266815, 56.156445667147636, 51.99460119009018, 51.107158809900284, 48.36024820804596, 43.824484795331955, 46.4172338694334, 43.75110313296318, 43.65470230579376, 42.23042093217373, 40.302484184503555, 42.334751933813095, 43.052598014473915, 42.79208019375801, 41.28331795334816, 39.9494831264019, 42.999321073293686, 42.542365193367004, 43.75082574784756, 44.68230776488781, 43.61534781754017, 44.34594601392746, 45.86291201412678, 41.78563579916954, 46.04148343205452, 45.13862527906895, 41.692119017243385, 41.369288340210915, 39.31883096694946, 39.56270948052406, 42.39435933530331, 43.6313221603632, 45.8720239251852, 45.66970378160477, 53.21327559649944, 56.4793561398983, 56.29611857235432, 59.860650300979614, 52.097275480628014, 45.361544117331505, 49.733156338334084, 54.23710785806179, 55.87421201169491, 48.70655782520771, 43.617711290717125, 41.88215062022209, 41.62469923496246, 40.275566428899765, 41.97967618703842, 42.036566734313965, 43.857809007167816, 44.76972967386246, 46.98925897479057, 45.705760046839714, 45.17653204500675, 43.241542875766754, 42.87041679024696, 42.56440781056881, 43.17021690309048, 44.07038860023022, 44.79567468166351, 45.54057911038399, 45.87711185216904, 47.88723058998585, 46.62983626127243, 46.411249190568924, 46.477202251553535, 47.266788482666016, 46.81710161268711, 49.33414354920387, 47.38110154867172, 49.28201414644718, 53.0946459621191, 56.00899077951908, 55.646076053380966, 61.54139891266823, 62.74529591202736, 62.01370596885681, 61.48098975419998, 64.8475331068039, 65.34595996141434, 68.2793341577053, 71.57705560326576, 76.4971911907196, 76.93262502551079, 29.180344194173813, 0.42042182001750916, 0.09373872118885629, 0.3436501754913479, 14.904118850827217, 78.52199614048004, 69.67405691742897, 66.64925202727318, 46.28813959658146, 29.053499400615692, 44.89840216934681, 50.822025910019875, 75.13371035456657, 30.893411971628666, 0.422112729283981, 0.26334516587667167, 0.0399101416405756, 0.08860156012815423, 0.021118637778272387, 0.16704567155102268, 0.13334133167518303, 0.23578042077133432, 0.09943438548361883, 0.12090750824427232, 0.21224966389127076, 0.15265087131410837, 0.6121330813039094, 57.432690784335136, 74.38259705901146, 61.505483239889145, 51.30198195576668, 43.78054395318031, 71.59671574831009, 71.53195962309837, 84.59015652537346, 14.686469379812479, 0.8052279136609286, 1.0710740578360856, 0.3471021418226883, 7.612135810777545, 70.39316073060036, 73.34198489785194, 75.48438593745232, 74.44213226437569, 73.41079920530319, 73.48291173577309, 70.5773900449276, 65.72899460792542, 58.95524628460407, 57.5449101626873, 50.545142367482185, 53.03422540426254, 52.47626714408398, 51.853347569704056, 54.28475730121136, 55.02086520195007, 51.20546713471413, 55.89642181992531, 59.295426830649376, 63.36937442421913, 64.65197280049324, 64.14686590433121, 64.47085171937943, 63.988710790872574, 63.82275089621544, 66.10464245080948, 63.87851670384407, 60.777115523815155, 56.89759969711304, 56.807327941060066, 56.31112016737461, 56.20620019733906, 57.24464647471905, 54.68374349176884, 51.81442625820637, 49.94371064007282, 48.13284181058407, 45.283731892704964, 45.32848209142685, 46.926763728260994, 46.53707183897495, 46.37776918709278, 50.20555458962917, 53.6664392799139, 64.21970039606094, 61.67905032634735, 54.00381937623024, 50.52876524627209, 55.707431361079216, 59.5340920239687, 54.605311900377274, 60.56880310177803, 58.23012359440327, 53.3398924022913, 51.607975736260414, 51.11485339701176, 46.55800111591816, 48.480545952916145, 46.698783561587334, 47.63758398592472, 46.88469998538494, 43.71738374233246, 44.36223953962326, 46.69222131371498, 46.41950614750385, 44.16837014257908, 43.546571508049965, 44.62524622678757, 45.88335491716862, 47.447347193956375, 47.83515438437462, 46.98290191590786, 44.499909952282906, 49.91540215909481, 45.860457345843315, 49.28237892687321, 46.97511613368988, 43.10498580336571, 42.743051424622536, 40.096911415457726, 41.0180389881134, 43.74427489936352, 45.64530149102211, 47.77891740202904, 46.18846334517002, 55.36504693329334, 58.934761583805084, 57.324016615748405, 62.41137742996216, 54.15336035192013, 50.094961524009705, 51.12859345972538, 57.034114971756935, 58.124124482274055, 50.42692311108112, 45.82113325595856, 45.06965897977352, 43.22462238371372, 43.41061860322952, 44.620314091444016, 45.41960500180721, 47.072406113147736, 48.31527382135391, 48.659843131899834, 47.05225199460983, 48.31902042031288, 45.964799746870995, 46.54228135943413, 44.98832814395428, 45.794804468750954, 47.55528800189495, 49.33312140405178, 50.65591782331467, 49.23154525458813, 50.90734273195267, 49.612376019358635, 49.76261615753174, 49.85128439962864, 50.38701005280018, 51.85905106365681, 52.93125472962856, 49.30923588573933, 51.01958870887756, 57.366110756993294, 60.98839558660984, 60.075631365180016, 65.82696855068207, 65.79318836331367, 66.04100346565247, 64.02489244937897, 70.95871478319168, 70.00737503170967, 74.2076088488102, 75.68731024861336, 80.8236238360405, 78.83060798048973, 33.76867398619652, 0.8197346446104348, 0.6630826473701745, 0.5930782912764698, 17.75669038295746, 85.499417334795, 77.57374942302704, 74.6169076859951, 59.274030178785324, 39.23115827143192, 47.175513580441475, 60.80773048102856, 89.90339621901512, 37.499864771962166, 0.5071951809804887, 0.31435466778930277, 0.14323610463179648, 0.19271379889687523, 0.12872226390754804], [0.041948123689508066, 0.07827550289221108, 0.045277513199835084, 0.025774313835427165, 0.0909741097711958, 0.09214856589096598, 0.037485812354134396, 0.28983971918933094, 30.200834535062313, 54.85546387732029, 51.30091041326523, 42.14309021830559, 29.309615157544613, 58.09715732932091, 59.81269307434559, 71.47343516349792, 14.888178706169128, 0.4286924621555954, 0.4759283212479204, 0.19256683881394565, 1.511901703197509, 41.491432785987854, 67.28875011205673, 64.03290241956711, 66.20976001024246, 61.59584999084473, 61.67904272675514, 57.614492028951645, 53.78439635038376, 49.86526004970074, 54.13913771510124, 47.98759460449219, 49.721057787537575, 45.8027308434248, 47.496877536177635, 47.08567500114441, 50.67148558795452, 50.117144733667374, 54.58291210234165, 57.172081768512726, 59.87712621688843, 59.33287762105465, 62.407224252820015, 62.507185488939285, 67.92368084192276, 65.42265504598618, 58.23991946876049, 57.28943467140198, 53.47310945391655, 56.90290041267872, 56.00405864417553, 52.295982018113136, 53.831977397203445, 52.17610225081444, 50.3158550709486, 45.55534511804581, 44.05306152999401, 40.65728634595871, 42.90246807038784, 40.566368624567986, 41.96633130311966, 41.198992878198624, 43.05286779999733, 42.2194205224514, 43.52323696017265, 44.66210424900055, 51.247131898999214, 50.29361866414547, 49.232631996273994, 48.42172130942345, 50.008755549788475, 53.1852862983942, 54.81412589550018, 51.73323981463909, 51.04693964123726, 49.952887147665024, 46.805751621723175, 42.416249960660934, 43.13604913651943, 41.44309177994728, 39.39782872796059, 37.221917286515236, 44.29703503847122, 43.023502975702286, 42.38957919180393, 40.52063807845116, 44.38313841819763, 39.30633343756199, 38.38980741798878, 43.64892281591892, 44.49240915477276, 42.00522601604462, 44.140833020210266, 42.52668343484402, 37.03419215977192, 40.09489752352238, 41.604172736406326, 39.67765711247921, 41.71164996922016, 37.900522872805595, 40.991303622722626, 39.10934440791607, 44.393139481544495, 43.76434162259102, 44.41074013710022, 43.55374172329903, 50.397246703505516, 48.8520710170269, 48.30365024507046, 43.32878239452839, 39.69388984143734, 44.801549166440964, 53.753933385014534, 55.461759343743324, 51.55204653739929, 42.86070451140404, 38.408285826444626, 39.42840948700905, 39.05474133789539, 39.78188931941986, 38.63004572689533, 39.61660198867321, 41.66572563350201, 42.04939104616642, 43.61178740859032, 42.02612869441509, 44.310079738497734, 42.49889552593231, 42.2345133125782, 39.93006996810436, 41.597002521157265, 41.27140559256077, 41.42247408628464, 42.66956716775894, 44.25622522830963, 43.94353240728378, 45.120599046349525, 45.32910905778408, 45.79461447894573, 45.23154929280281, 45.92517927289009, 45.06296753883362, 46.82115599513054, 48.731944262981415, 49.5102147012949, 54.07263748347759, 55.341020822525024, 58.20401519536972, 58.15674193203449, 59.47067342698574, 60.66190950572491, 59.74973425269127, 60.509853065013885, 65.82839727401733, 67.61777445673943, 71.44195005297661, 79.10750672221184, 28.202979639172554, 0.25987443805206567, 0.5257471511140466, 0.5218962952494621, 12.615342065691948, 71.34894624352455, 64.56372633576393, 54.44160908460617, 47.185735031962395, 29.664897993206978, 42.73717314004898, 50.47722861170769, 59.97138395905495, 19.645415134727955, 0.361080018337816, 0.13297864410560578, 0.005295193523124908, 0.06619907551794313, 0.0036303781689639436, 0.0238550475842203, 0.05941765659372322, 0.03255062678363174, 0.062298154371092096, 0.06791391162551008, 0.07459822794771753, 0.140026553417556, 0.22155211394419894, 42.95000731945038, 63.054462522268295, 62.27132074534893, 44.13618206977844, 29.04226340353489, 68.10935407876968, 63.80529463291168, 80.54796382784843, 15.747787579894066, 0.2309645205968991, 0.7561538438312709, 0.2866485732374713, 1.8127617216669023, 48.229687213897705, 72.17385157942772, 66.57076343894005, 69.94720906019211, 63.9574308693409, 65.43175175786018, 57.854338958859444, 55.699653178453445, 53.645270615816116, 55.22931821644306, 50.06257206201553, 53.04718650877476, 46.238795444369316, 49.399633035063744, 49.25019845366478, 52.02939972281456, 52.45181545615196, 55.22367551922798, 61.19412034749985, 63.81250664591789, 61.9486116617918, 65.54515287280083, 64.10982549190521, 68.35798993706703, 63.54768745601177, 58.6509358137846, 58.26815955340862, 57.02181503176689, 61.16962306201458, 57.877715304493904, 55.294826701283455, 55.46518296003342, 54.707435220479965, 53.192285522818565, 47.4458272755146, 47.24984139204025, 42.73885264992714, 44.47814851999283, 43.018597438931465, 44.71233755350113, 43.737788647413254, 46.59256026148796, 45.34149259328842, 46.52408413589001, 47.48086899518967, 52.811230570077896, 53.238848224282265, 50.913103222846985, 49.72747564315796, 52.031736597418785, 53.715988621115685, 55.70377595722675, 56.03348806500435, 51.53930962085724, 51.42536133527756, 48.397254422307014, 44.69471409916878, 44.877450093626976, 44.26118016242981, 43.291126415133476, 41.37148082256317, 46.43808335065842, 42.52617806196213, 44.1126499325037, 43.065992295742035, 45.11777579784393, 42.55218766629696, 41.629125997424126, 44.84319493174553, 46.573329493403435, 45.378616601228714, 44.44385536015034, 42.69677750766277, 39.89043429493904, 44.0070877969265, 44.52805504202843, 42.6790476590395, 41.275596767663956, 39.842211082577705, 43.47656786441803, 42.004211470484734, 45.16607120633125, 44.30938817560673, 45.958393290638924, 46.14406272768974, 53.181326910853386, 51.66039012372494, 49.17727276682854, 45.744305178523064, 44.258098527789116, 48.31401228904724, 56.73255555331707, 55.79444669187069, 53.55414770543575, 47.117775678634644, 42.544200494885445, 43.54845620691776, 40.82570090889931, 41.95961706340313, 42.12385565042496, 42.318511605262756, 42.92989119887352, 44.534887075424194, 43.4430118650198, 44.8031222820282, 46.11698918044567, 46.797597259283066, 44.80236992239952, 42.02683925628662, 45.1107157766819, 42.63612516224384, 45.51472149789333, 45.810721814632416, 44.911716654896736, 45.494837164878845, 47.47433714568615, 47.54333384335041, 47.95082397758961, 46.98104381561279, 50.29028624296188, 46.9719585031271, 47.85774037241936, 50.41007861495018, 51.3206085562706, 56.025227308273315, 57.85276584327221, 60.69785937666893, 60.45780345797539, 62.59357385337353, 64.05291214585304, 62.80367597937584, 64.06458511948586, 68.34777608513832, 72.29783892631531, 75.32996982336044, 80.3672607243061, 29.958776123821735, 0.5908985144924372, 0.37555388698820025, 0.4327821411425248, 13.297124281525612, 79.38872963190079, 72.19240218400955, 62.40226931869984, 55.515724048018456, 33.511416390538216, 47.36719809472561, 56.96783512830734, 72.07921385765076, 27.63093363493681, 0.4224094102391973, 0.16506882762769237, 0.0878815061878413, 0.22634601686149836, 0.01821467885747552, 0.06744190570316277, 0.22772632248234004, 0.17109393869759515, 0.23222571151563898, 0.14969902345910668, 0.2020549593726173, 0.264873129199259, 1.16115546785295, 57.2045624256134, 73.61876204609871, 64.46223378181458, 53.58116805553436, 44.29682984948158, 76.8101803958416, 71.46073624491692, 88.28428789973259, 17.714748233556747, 0.4387073591351509, 1.843342361971736, 0.3602143476018682, 3.0712811462581158, 55.96138313412666, 75.53219497203827, 71.50692656636238, 72.19946220517159, 68.79622042179108, 68.52328106760979, 61.984056159853935, 57.34688758850098, 55.15068903565407, 58.73724818229675, 51.09010152518749, 54.913615956902504, 50.31069874763489, 52.47027486562729, 51.07035778462887, 56.802019625902176, 54.96448762714863, 58.13443712890148, 64.12568584084511, 66.96930885314941, 64.66269582509995, 68.3181756734848, 66.54409646987915, 67.91547328233719, 66.83343574404716, 62.6492864638567, 63.024698719382286, 57.322644889354706, 62.43398241698742, 61.36827640235424, 58.078975304961205, 57.22825035452843, 58.05852860212326, 55.588243156671524, 49.96314659714699, 50.08021831512451, 43.7148492783308, 47.249260023236275, 45.16407631337643, 46.5480000525713, 47.93288893997669, 50.10898657143116, 47.83292390406132, 49.54516142606735, 49.40578110516071, 54.72887746989727, 56.35983355343342, 53.26658293604851, 51.78194560110569, 53.57244752347469, 56.41293950378895, 60.39770968258381, 58.11958372592926, 54.80147257447243, 53.875393867492676, 51.7522007972002, 47.86957673728466, 47.974283918738365, 45.73411412537098, 43.5465145111084, 42.910523638129234, 50.51422342658043, 47.91441433131695, 45.59220694005489, 44.831407964229584, 48.502653166651726, 44.39228072762489, 42.89353474974632, 49.244422763586044, 47.7642197906971, 45.73059931397438, 47.7252072840929, 43.68789352476597, 45.02294808626175, 46.97261206805706, 44.351896494627, 43.89718249440193, 41.49142138659954, 40.1741536706686, 45.372255742549896, 43.11051830649376, 45.28785087168217, 44.70420219004154, 47.683618515729904, 47.051370441913605, 56.60797543823719, 53.72270666062832, 53.80352832376957, 48.95272381603718, 45.540267527103424, 49.20866668224335, 58.82976941764355, 59.67887185513973, 57.647565454244614, 49.11351598799229, 44.16994325816631, 44.074477180838585, 43.54678809642792, 45.23348718881607, 44.79111112654209, 44.24645975232124, 46.077589094638824, 46.064768582582474, 46.70782707631588, 47.0349857211113, 50.648713409900665, 48.240379840135574, 46.658893302083015, 43.63340064883232, 47.1894246339798, 46.518224850296974, 47.20270872116089, 48.68144877254963, 47.07870617508888, 48.1029412150383, 51.108659729361534, 50.37808433175087, 49.89568881690502, 50.90638518333435, 53.266092762351036, 50.85759960114956, 50.84363915026188, 54.98523071408272, 54.18593980371952, 60.39181239902973, 61.24886780977249, 64.71827924251556, 63.1389319896698, 66.19943216443062, 66.91838398575783, 67.30206459760666, 67.70228192210197, 72.95431450009346, 75.58014839887619, 81.6427230834961, 82.96654924750328, 35.56949995458126, 0.6570665014442056, 1.061690580099821, 0.550720242317766, 16.06743022799492, 85.15526220202446, 79.35703933238983, 72.1066863834858, 67.07992851734161, 48.782006576657295, 61.013911217451096, 66.90563187003136, 83.61250698566437, 35.75807623565197, 0.9204409376252443, 0.36871027608867735, 0.1876521439407952, 0.31305371259804815, 0.11042092446587048], [0.05366310288081877, 0.03298615985841025, 0.15137268521357328, 0.05591450062638614, 0.07110172533430159, 0.06339751998893917, 0.03603996396122966, 0.28805351816117764, 38.393869400024414, 53.83421167731285, 39.79023367166519, 41.36691726744175, 32.82237656414509, 58.42023879289627, 57.4469780176878, 74.47753116488457, 15.75225044041872, 0.4137929272837937, 1.2613933766260743, 0.25180744123645127, 0.37335419096052647, 19.773384667932987, 71.69035792350769, 60.64006447792053, 68.95053014159203, 57.04772964119911, 61.97691634297371, 55.099604576826096, 56.51157461106777, 54.90713730454445, 54.33966055512428, 47.73721843957901, 49.5266792178154, 47.484752386808395, 46.77982181310654, 48.84528078138828, 50.25880113244057, 50.95026522874832, 56.19092121720314, 57.90108025074005, 58.799188658595085, 54.03356797993183, 51.300857216119766, 49.78159233927727, 49.54219378530979, 63.06553512811661, 60.58338671922684, 49.02781918644905, 57.42454022169113, 59.31528076529503, 58.135976046323776, 54.52371507883072, 54.006817415356636, 50.86584135890007, 48.97985816001892, 43.59693020582199, 42.61017635464668, 42.91818022727966, 41.00294999778271, 40.22979028522968, 44.0984158962965, 41.739719063043594, 42.88946516811848, 44.185370430350304, 42.687646597623825, 42.40433759987354, 44.85065013170242, 47.557434886693954, 48.36200751364231, 47.644275426864624, 49.861030876636505, 49.06935475766659, 51.14346586167812, 50.822918862104416, 53.02734397351742, 49.165633991360664, 48.50353091955185, 45.340964421629906, 45.88704451918602, 42.814457193017006, 42.93924629688263, 41.83672405779362, 47.42057763040066, 45.60794949531555, 44.07817058265209, 46.19673170149326, 48.19055311381817, 41.796051040291786, 40.33147282898426, 42.54643477499485, 44.20662268996239, 48.52605231106281, 45.80929309129715, 38.535867780447006, 38.932897076010704, 37.70150475203991, 43.421056643128395, 43.89563597738743, 40.73580153286457, 42.57200360298157, 44.058081060647964, 44.806359708309174, 44.11206096410751, 45.203161016106606, 43.95381085574627, 49.236439391970634, 49.036604315042496, 42.439918890595436, 41.156093180179596, 43.08001734316349, 46.21266044676304, 51.6523801535368, 50.48653431236744, 50.30492305755615, 45.10441191494465, 40.01859001815319, 39.15638968348503, 38.75643074512482, 39.430096596479416, 39.752034321427345, 38.92956085503101, 40.88915750384331, 41.28009952604771, 42.48215742409229, 43.195743933320045, 41.77513316273689, 41.17588631808758, 41.10853873193264, 42.7270732820034, 42.463869005441666, 43.49986061453819, 43.08927744626999, 43.88973489403725, 42.01350577175617, 44.43867243826389, 43.84693019092083, 44.232347309589386, 43.774893656373024, 43.59341159462929, 43.08288998901844, 47.65576221048832, 45.43972872197628, 45.26143088936806, 45.81194154918194, 47.37467609345913, 46.27688080072403, 53.345823884010315, 55.763451755046844, 53.80332313477993, 56.94084897637367, 61.1577221006155, 59.25071083009243, 63.59445534646511, 60.888962522149086, 70.45304551720619, 68.90131518244743, 82.96815276145935, 19.92832325398922, 0.6715861160773784, 0.23950083676027134, 0.27186499151866883, 6.306572891771793, 67.74733990430832, 64.72972422838211, 56.09948672354221, 45.4780762642622, 35.9199133515358, 41.714997589588165, 39.24539230763912, 62.50776305794716, 22.804744206368923, 0.33167796791531146, 0.14685532136354595, 0.07958377565955743, 0.02777024950773921, 0.012390713000058895, 0.11007927678292617, 0.012617694228538312, 0.06579821929335594, 0.018031225517916027, 0.055092598049668595, 0.06094258453231305, 0.02431387110846117, 0.7203683734405786, 47.922317907214165, 64.02581200003624, 48.86076495051384, 34.441625475883484, 35.46799600124359, 65.99348321557045, 62.10301637649536, 81.38286262750626, 16.459743976593018, 0.5263713863678277, 0.866932743228972, 0.4707064217654988, 0.49272677453700453, 24.657011814415455, 75.88284775614738, 63.988710790872574, 71.64333924651146, 60.28255686163902, 63.42739351093769, 57.518604174256325, 59.91356246173382, 56.03530816733837, 56.90253563225269, 51.59822925925255, 51.65812164545059, 48.51887829601765, 50.628414899110794, 50.73125258088112, 54.29655186831951, 53.472900465130806, 58.441662043333054, 59.0659761428833, 60.790604799985886, 55.88553540408611, 54.57590527832508, 51.91931962966919, 55.08101977407932, 66.47240191698074, 61.416746601462364, 50.52144303917885, 59.39442291855812, 60.382012724876404, 59.454178512096405, 54.77989733219147, 57.27311834692955, 51.38461232185364, 50.00828057527542, 47.730276212096214, 44.98445615172386, 44.873923882842064, 44.89321544766426, 42.225811779499054, 46.01511284708977, 45.4712176322937, 44.49367068707943, 44.043486043810844, 45.30493475496769, 44.228437319397926, 47.08345212042332, 49.47495639324188, 51.75395630300045, 50.787664353847504, 52.99040235579014, 51.100205183029175, 54.16648104786873, 53.310158997774124, 55.418464466929436, 50.09832054376602, 52.91258253157139, 46.93396434187889, 49.634585827589035, 45.45410715043545, 45.60366712510586, 42.65424259006977, 50.02720355987549, 46.05254843831062, 45.01481272280216, 45.730561316013336, 48.14893774688244, 42.81267128884792, 42.16486304998398, 43.32519918680191, 45.10992921888828, 48.51724058389664, 46.47551514208317, 39.03125859797001, 43.9010126888752, 42.08458475768566, 46.071277633309364, 45.63495084643364, 42.338927909731865, 45.74641026556492, 45.10956443846226, 46.565551310777664, 45.664308071136475, 48.37085723876953, 47.00699642300606, 50.44552691280842, 49.44954715669155, 44.71860721707344, 45.28957977890968, 45.153262093663216, 48.66417869925499, 53.83814066648483, 52.970214039087296, 54.06370796263218, 46.87781475484371, 43.640453070402145, 43.13822641968727, 40.47744959592819, 41.697735115885735, 41.178413182497025, 41.582734286785126, 43.375607281923294, 44.550812020897865, 43.22956971824169, 45.352489203214645, 45.66766709089279, 44.32108774781227, 44.43614177405834, 43.985440358519554, 43.68141867220402, 45.58898851275444, 46.66748844087124, 46.06518656015396, 45.80322481691837, 45.94631753861904, 45.80775037407875, 47.965107411146164, 45.59357486665249, 46.07890002429485, 46.5198777616024, 49.1136109828949, 48.83225508034229, 47.0682567358017, 48.56451004743576, 50.12326240539551, 49.75871756672859, 55.75987234711647, 57.58313991129398, 57.98418179154396, 60.35142056643963, 64.04337465763092, 61.72537364065647, 65.71519374847412, 64.2630560696125, 73.73473942279816, 70.66626727581024, 85.01132592558861, 21.936806179583073, 0.6739807594567537, 0.48465550295077264, 0.5110744759440422, 7.381532834842801, 74.12956103682518, 70.86570337414742, 62.63920180499554, 54.94177624583244, 43.812830820679665, 49.89216260612011, 47.61315509676933, 74.39813062548637, 30.60930121690035, 0.4237762978300452, 0.15821307519217953, 0.01947255979757756, 0.03812852708506398, 0.013362245535972761, 0.26838084566406906, 0.09242909771273844, 0.21876874845474958, 0.15379122574813664, 0.2147298026829958, 0.166635011555627, 0.09379997063660994, 1.4623180450871587, 63.618416860699654, 71.86230629682541, 54.66157928109169, 53.25590930879116, 48.26957367360592, 78.08817341923714, 69.27448555827141, 89.74866852164268, 18.208263851702213, 0.750532461097464, 3.526334990747273, 1.00086736259982, 0.49158407491631806, 29.064925387501717, 79.55727338790894, 68.03575962781906, 75.33634588122368, 63.999122232198715, 66.15172952413559, 60.18329098820686, 63.24873469769955, 59.71321441233158, 59.027229622006416, 54.284301325678825, 54.50481869280338, 51.11601613461971, 52.24704444408417, 54.13886032998562, 57.18469329178333, 57.13846117258072, 62.185684740543365, 61.80431820452213, 62.84591071307659, 56.787405610084534, 57.440845146775246, 56.47941313683987, 56.86347372829914, 66.31238490343094, 61.88702076673508, 53.1575857847929, 60.95357425510883, 63.369891196489334, 61.73219807446003, 59.10225659608841, 60.88922470808029, 55.29579184949398, 54.31723415851593, 49.18730802834034, 46.413677260279655, 48.076627627015114, 45.56132219731808, 43.858356177806854, 48.90799641609192, 47.83727467060089, 45.585948675870895, 48.23650784790516, 47.44347520172596, 47.58527219295502, 50.000111013650894, 53.5145728290081, 54.60101053118706, 53.08796972036362, 56.43215127289295, 54.42815400660038, 58.09879884123802, 57.688846439123154, 56.70416347682476, 53.92238974571228, 54.34583902359009, 48.195755034685135, 51.94309875369072, 47.86988452076912, 47.203404083848, 47.9973790794611, 49.60732229053974, 44.7408702224493, 45.40380924940109, 46.59561149775982, 48.97291213274002, 45.218485593795776, 42.89300657808781, 45.52492395043373, 44.668446108698845, 50.280623361468315, 48.253124356269836, 42.996927201747894, 46.7455742508173, 41.13770216703415, 46.279612854123116, 46.980762630701065, 43.957382664084435, 46.33811071515083, 46.601611375808716, 50.41190631687641, 47.75752454996109, 49.72933754324913, 47.656297981739044, 53.93682137131691, 53.02460812032223, 46.79967574775219, 47.47432954609394, 46.80116906762123, 48.38487088680267, 56.854832991957664, 55.62625631690025, 56.470939591526985, 51.92960947751999, 46.64907842874527, 45.15106961131096, 43.56722719967365, 43.83974477648735, 43.27783852815628, 42.31403924524784, 46.66183814406395, 46.997937709093094, 46.544371247291565, 48.799877017736435, 47.96186998486519, 46.893450915813446, 48.02700988948345, 48.30502197146416, 46.8501902371645, 47.814901471138, 49.52422454953194, 49.54398728907108, 49.32635396718979, 49.88879218697548, 48.61446976661682, 48.377807065844536, 49.82283152639866, 47.998165637254715, 49.90035876631737, 54.65363010764122, 51.33131258189678, 49.566653072834015, 50.81287980079651, 52.36118271946907, 52.36143350601196, 60.601143166422844, 60.60289867222309, 60.92043623328209, 64.07247349619865, 70.23861542344093, 66.20091408491135, 70.51897197961807, 69.383554905653, 75.30885815620422, 75.44245138764381, 88.37424427270889, 26.93155076354742, 0.9819323848932981, 0.8235999278258532, 0.47211000113748014, 8.91277989372611, 81.96277230978012, 76.9522775709629, 73.89097183942795, 64.71754968166351, 50.54656349122524, 57.24953681230545, 56.32471963763237, 85.66638797521591, 40.23797884583473, 0.6806587823666632, 0.22868384141474962, 0.2565022080671042, 0.19575759884901345, 0.12924504757393152], [0.021678328448615503, 0.007900555356172845, 0.048252638516714796, 0.1378433479112573, 0.08968167443526909, 0.03263005884946324, 0.10560527662164532, 0.21058747573988512, 45.144283175468445, 48.73547427356243, 49.05170850455761, 34.3648923933506, 31.727655306458473, 56.023836582899094, 58.792854398489, 75.76639160513878, 11.29551138728857, 0.333427328732796, 0.541524023283273, 0.9587146213743836, 0.12506194703746587, 5.404843278229237, 61.70442536473274, 64.27903041243553, 64.60598766803741, 60.21808572113514, 65.25708273053169, 61.20098277926445, 62.47927978634834, 60.7429401576519, 59.75541494786739, 50.43364495038986, 50.08699715137482, 47.24292576313019, 49.37489256262779, 47.45009824633598, 50.11429488658905, 52.20854111015797, 55.234850719571114, 54.030569940805435, 58.3844181150198, 58.612284287810326, 60.402687415480614, 59.8023272305727, 48.91431547701359, 42.3043117672205, 53.24433892965317, 55.12263894081116, 60.778418853878975, 55.49374222755432, 55.42328640818596, 53.02143529057503, 51.76169268786907, 47.773487493395805, 45.216331109404564, 42.371856942772865, 41.42494395375252, 41.74191154539585, 42.28609174489975, 40.89757025241852, 42.7016868442297, 39.692651107907295, 40.87782271206379, 40.772385969758034, 42.959617003798485, 44.34348374605179, 46.061819940805435, 47.135106548666954, 48.9036950469017, 49.32148642838001, 49.97602790594101, 50.567796751856804, 50.29700808227062, 48.06739792227745, 51.95739358663559, 49.79226216673851, 50.337707698345184, 45.76124846935272, 44.373030960559845, 44.42986451089382, 43.68864208459854, 38.405850157141685, 39.691416174173355, 41.3500689715147, 42.99028515815735, 39.66397404670715, 46.84143930673599, 48.56100283563137, 40.92641830444336, 41.182410567998886, 46.32158920168877, 47.43160843849182, 51.157316118478775, 56.11677199602127, 37.87666015326977, 38.39791238307953, 42.82224677503109, 43.92443463206291, 42.96845152974129, 43.849540650844574, 46.73866622149944, 47.274049893021584, 46.48178480565548, 48.757490292191505, 45.84674388170242, 47.059388011693954, 42.89387293159962, 44.83580432832241, 48.3221248537302, 43.63968551158905, 45.73707416653633, 42.83324718475342, 46.99796050786972, 40.60322284698486, 38.954909294843674, 38.79434131085873, 39.4955974817276, 38.04262384772301, 38.915824592113495, 40.53351178765297, 40.960149094462395, 41.530768275260925, 41.78074546158314, 41.02992095053196, 43.03183972835541, 41.510135382413864, 41.11743405461311, 41.45498514175415, 42.81922213733196, 41.43463723361492, 43.10299851000309, 44.672458693385124, 45.768935456871986, 46.5860740095377, 46.69068239629269, 45.901088565588, 44.78864885866642, 44.269364923238754, 47.40201562643051, 47.74553619325161, 50.82643747329712, 51.06663018465042, 51.42731063067913, 48.86928789317608, 48.14352683722973, 47.29861557483673, 51.0621502250433, 50.24593882262707, 54.60057355463505, 56.14161506295204, 58.067914098501205, 56.84660263359547, 61.58679887652397, 61.30592554807663, 68.8169901072979, 68.0186377465725, 82.61066034436226, 14.122170209884644, 0.5453707231208682, 0.1478541927644983, 0.26645443809684366, 4.657579651102424, 64.95869234204292, 65.72433605790138, 53.82832199335098, 49.859754145145416, 25.264475718140602, 30.56045863777399, 47.34719596803188, 54.48435299098492, 14.969330001622438, 0.5146846384741366, 0.22178982384502888, 0.04820920432393905, 0.02775523029413307, 0.04409760971611831, 0.043618200870696455, 0.023710390014457516, 0.07834111616830342, 0.009468743082834408, 0.13247062917798758, 0.017769228834367823, 0.024717905580473598, 0.5060304247308522, 57.02571742236614, 55.18734946846962, 52.464559972286224, 41.61520354449749, 36.319404914975166, 65.32570704817772, 62.08811357617378, 82.7230279147625, 12.343203518539667, 0.3438793803798035, 0.6544861430302262, 0.8958846365567297, 0.4408924200106412, 6.55241210013628, 67.4753201007843, 66.56577810645103, 68.99726763367653, 63.72862234711647, 65.75986415147781, 63.35490480065346, 63.62991504371166, 62.212078124284744, 62.657311633229256, 51.96105279028416, 51.620222479104996, 50.60816578567028, 48.82484547793865, 50.548881366848946, 51.92750059068203, 53.794135227799416, 55.293686762452126, 57.58872181177139, 60.65729275345802, 60.98939873278141, 62.37003564834595, 59.97505836188793, 52.078496888279915, 49.187030643224716, 56.68791174888611, 55.95490828156471, 61.29562050104141, 57.28752717375755, 59.464073181152344, 54.39000025391579, 52.58848272264004, 48.84620413184166, 48.00157405436039, 44.851311296224594, 44.64301407337189, 43.38989831507206, 45.92843949794769, 43.36410529911518, 44.18736532330513, 42.44044706225395, 43.30569103360176, 43.831130638718605, 45.91839663684368, 46.14699237048626, 48.35828751325607, 48.822789788246155, 51.58784441649914, 50.92641390860081, 51.81912660598755, 51.40093244612217, 54.477593153715134, 50.099893659353256, 53.12361940741539, 50.57378903031349, 51.96681708097458, 48.73286001384258, 46.502748280763626, 45.53232595324516, 45.669418796896935, 40.605624318122864, 42.496144473552704, 42.37441040575504, 43.13343107700348, 40.97202345728874, 46.727605015039444, 47.09840051829815, 41.08919396996498, 42.16593839228153, 46.89698472619057, 48.073112815618515, 52.60027348995209, 56.46133370697498, 39.40750300884247, 40.57161994278431, 44.72601681947708, 47.055949196219444, 44.601087123155594, 46.05847992002964, 47.20041364431381, 49.1605194658041, 49.33137729763985, 48.98346036672592, 49.621199145913124, 47.93422266840935, 45.837115198373795, 48.596815913915634, 51.80719144642353, 46.48166321218014, 46.5251062810421, 45.5417038500309, 47.155397459864616, 43.05113889276981, 41.07898011803627, 41.82913586497307, 42.25019887089729, 41.55129097402096, 42.40227051079273, 42.9796951264143, 42.06374667584896, 43.11633959412575, 43.95864799618721, 44.273772686719894, 45.05515895783901, 43.35975833237171, 43.582148998975754, 43.64715591073036, 44.93722848594189, 45.27228310704231, 47.121643871068954, 48.10488671064377, 47.31854930520058, 48.30585412681103, 49.689321890473366, 47.23286770284176, 48.87271150946617, 47.36697390675545, 49.64834488928318, 51.28354914486408, 54.09224823117256, 54.7822380065918, 54.351059943437576, 53.2748930901289, 51.25704936683178, 50.36377809941769, 52.388514652848244, 53.38767483830452, 56.5392941236496, 58.56185719370842, 59.59584251046181, 59.094911590218544, 62.52885952591896, 63.47717463970184, 73.02842572331429, 69.84940230846405, 85.64971446990967, 16.06164313852787, 0.9011488978285342, 0.322407623170875, 0.37462367909029126, 5.5829815194010735, 73.31383600831032, 71.99862018227577, 62.45993882417679, 56.12223990261555, 29.211489222943783, 36.02551728487015, 52.320513501763344, 68.75768288969994, 25.423394590616226, 0.5074480455368757, 0.21307445713318884, 0.05192285192606505, 0.0854554922261741, 0.08700661797774956, 0.17024095868691802, 0.1197916001547128, 0.156400854466483, 0.24659747548867017, 0.14913825667463243, 0.1235050251125358, 0.18647261895239353, 1.5854091150686145, 71.504365503788, 65.5034539103508, 60.80307573080063, 46.55996561050415, 46.09345704317093, 73.52255120873451, 68.51030856370926, 91.7443898320198, 14.734978526830673, 0.49851163756102324, 0.9594849112909287, 1.6109033720567822, 0.44593492755666375, 8.459148835390806, 74.39671710133553, 70.46673238277435, 71.68910399079323, 65.97142919898033, 71.51318863034248, 65.98510086536407, 67.38974869251251, 65.94828844070435, 66.40150532126427, 53.65126669406891, 54.342347010970116, 53.448262587189674, 52.15938314795494, 53.86036567389965, 54.78054329752922, 55.90882055461407, 58.145030960440636, 59.51454967260361, 64.04249310493469, 64.72000434994698, 64.59633618593216, 62.55032457411289, 53.488943204283714, 49.30983245372772, 54.330803230404854, 55.73673538863659, 65.04627004265785, 59.714650735259056, 63.04242096841335, 57.13311105966568, 55.710079818964005, 52.35004931688309, 50.08253999054432, 46.60746306180954, 45.959457233548164, 45.06308153271675, 48.662134408950806, 44.32003900408745, 48.29549968242645, 44.12292078137398, 46.76274552941322, 46.57950796186924, 46.47398382425308, 49.20398533344269, 52.60327532887459, 50.590945109725, 55.39071835577488, 54.49903920292854, 55.1991668343544, 55.521872118115425, 56.19947075843811, 53.705371990799904, 56.82471960783005, 54.70216490328312, 55.20872712135315, 50.43123967945576, 49.35353770852089, 50.43037712574005, 48.7656332552433, 41.68662071228027, 44.770972207188606, 44.02200199663639, 44.36500199139118, 41.78195759654045, 47.25620985031128, 48.03702995181084, 41.57923847436905, 41.256293803453445, 47.74455964565277, 49.50418442487717, 53.55451628565788, 56.747017577290535, 39.99451071023941, 42.37041302025318, 47.44669742882252, 47.70416781306267, 46.861232444643974, 48.86535130441189, 52.209293469786644, 50.59724137187004, 52.91733227670193, 51.64880074560642, 51.89562030136585, 49.698008224368095, 49.01772692799568, 49.66904617846012, 53.5036788135767, 47.47399516403675, 48.44144985079765, 50.39027787744999, 49.263417944312096, 46.334698498249054, 45.93364521861076, 45.192570984363556, 45.075149685144424, 44.2186376452446, 45.39698861539364, 47.64532797038555, 44.66395474970341, 45.2119879424572, 45.10755434632301, 45.92813551425934, 48.1989848613739, 45.53270973265171, 47.234760001301765, 45.71649447083473, 47.38116234540939, 46.090641394257545, 49.1419118642807, 50.65584562718868, 49.68373239040375, 50.93060128390789, 51.90855100750923, 50.13031482696533, 50.57873636484146, 49.91825960576534, 52.35844686627388, 53.35805542767048, 56.69282488524914, 58.16497229039669, 56.65381997823715, 54.6912594884634, 53.83137322962284, 53.32747466862202, 56.25728465616703, 57.22259245812893, 60.53743578493595, 63.391363844275475, 62.84924313426018, 63.6171705275774, 67.53558486700058, 67.83828422427177, 76.43382579088211, 76.46534129977226, 89.62874695658684, 19.80751633644104, 1.150139740202576, 1.4914051280356944, 0.4888563259737566, 7.224061684682965, 77.52945899963379, 79.50789123773575, 69.72165316343307, 69.79324892163277, 39.718504920601845, 46.71074151992798, 67.74236217141151, 79.86486688256264, 39.324329271912575, 0.6724037847016007, 0.27022855589166284, 0.1723133318591863, 0.16036113258451223, 0.1611231846618466], [0.027958743885392323, 0.02879637999285478, 0.06424457023967989, 0.14907567878253758, 0.0788672394992318, 0.040282751724589616, 0.03786937282711733, 1.4179858239367604, 41.49982273578644, 54.88228663802147, 47.05338813364506, 17.162468768656254, 35.88211677968502, 53.224709182977676, 60.87772272527218, 74.67135116457939, 9.999256543815136, 0.34417258808389306, 0.1684516406385228, 0.6785574357490987, 0.21101165766594931, 0.3804222570033744, 37.54361182451248, 70.93495085835457, 64.26006942987442, 61.44939824938774, 65.94872161746025, 63.894316256046295, 67.2155736386776, 61.2379015982151, 59.81257148087025, 51.85786172747612, 47.11417347192764, 46.507532224059105, 49.713613986968994, 49.62660625576973, 52.095637768507004, 50.91770477592945, 52.84687265753746, 54.13776978850365, 58.493327870965004, 57.27944880723953, 60.50476513803005, 53.97383138537407, 58.25941622257233, 43.83711151778698, 42.04649940133095, 59.704531878232956, 55.37755586206913, 55.17063796520233, 55.50686672329903, 53.39233718812466, 45.85008770227432, 44.20668728649616, 43.0510438978672, 44.88229863345623, 42.912127152085304, 44.3651007860899, 45.051704943180084, 41.626716926693916, 42.40342564880848, 43.008307591080666, 42.173025012016296, 42.12109699845314, 42.00708031654358, 43.19741204380989, 44.80741985142231, 47.29508936405182, 49.62635546922684, 48.626940697431564, 47.31940045952797, 51.169175282120705, 49.86923083662987, 51.569559797644615, 48.49343866109848, 51.25891886651516, 49.355433806777, 47.464875653386116, 48.97784426808357, 46.76753327250481, 44.671721532940865, 46.57183237373829, 43.69005560874939, 39.81295645236969, 41.96362964808941, 38.70057754218578, 49.597252830863, 53.9021710306406, 38.895552679896355, 39.377431422472, 44.379137232899666, 51.32012978196144, 35.833429992198944, 43.997052535414696, 37.98062637448311, 37.39044204354286, 42.53448061645031, 45.49871675670147, 44.38256464898586, 43.25404040515423, 46.78807497024536, 44.168119356036186, 50.03593169152737, 48.06482546031475, 47.47467152774334, 46.75305984914303, 47.068803906440735, 46.33133187890053, 46.28944292664528, 43.84688459336758, 45.15022985637188, 45.23209646344185, 44.73425857722759, 40.39022907614708, 38.909342139959335, 39.16851103305817, 40.36934159696102, 37.589577957987785, 39.71080273389816, 40.94767436385155, 40.84329016506672, 42.70132206380367, 43.06204430758953, 41.339026764035225, 42.666432335972786, 41.40368789434433, 44.87135522067547, 41.33140057325363, 43.01054187119007, 41.10972806811333, 45.84133297204971, 46.57414644956589, 49.13066826760769, 48.44058349728584, 49.63224895298481, 49.22780625522137, 46.96411192417145, 47.018133625388145, 49.38175119459629, 52.15331107378006, 58.05389665067196, 59.42026533186436, 57.01016865670681, 53.30770432949066, 54.40968319773674, 49.568017199635506, 48.820741698145866, 46.741618663072586, 50.31865932047367, 50.09894751012325, 54.3178079277277, 53.48293572664261, 59.10778529942036, 59.40933711826801, 69.48958441615105, 68.84176477789879, 84.64295089244843, 10.614896658807993, 0.49601508246269077, 0.4694789391942322, 0.4781416431069374, 8.513877298682928, 72.6901450753212, 63.37503232061863, 54.31528106331825, 43.749708607792854, 29.567611813545227, 28.906445391476154, 39.83867347240448, 56.74375735223293, 33.5138026624918, 0.4667654394870624, 0.10266185956425034, 0.022163709727465175, 0.1260191245819442, 0.08527180325472727, 0.020425944967428222, 0.03720560336660128, 0.06957491976208985, 0.05859579854586627, 0.04124912076804321, 0.08330733835464343, 0.041850371708278544, 1.5890268771909177, 56.71058893203735, 59.0345062315464, 56.236142590641975, 25.0876959040761, 38.17361041903496, 62.99448274075985, 66.2819105386734, 83.19031164050102, 10.768953692167997, 0.25129699206445366, 0.1433556349365972, 1.9708491512574255, 0.9061357739847153, 0.3699143067933619, 44.770105853676796, 71.90967455506325, 66.53139755129814, 64.59810689091682, 68.40997874736786, 66.1189752817154, 69.5241929590702, 65.60502246022224, 62.97071121633053, 53.92362467944622, 49.64297577738762, 49.68817815184593, 50.665614902973175, 51.2274831533432, 51.4762482047081, 52.781721353530884, 55.66517382860184, 56.6305386275053, 60.12472093105316, 61.776340305805206, 63.598027154803276, 57.18188524246216, 59.06852960586548, 45.818541795015335, 44.127317145466805, 61.399810910224915, 59.0392179787159, 59.18606869876385, 56.792379543185234, 53.59947547316551, 48.00005793571472, 46.59829795360565, 45.61103492975235, 44.19919028878212, 45.42911969125271, 45.32138027250767, 46.3796728849411, 45.226750150322914, 44.5252887904644, 43.55532243847847, 43.33817929029465, 45.19041270017624, 43.59568767249584, 45.34236654639244, 46.67296014726162, 49.9128220975399, 52.34116159379482, 51.31967380642891, 49.89597760140896, 52.96734519302845, 53.41323606669903, 52.83669300377369, 51.85422532260418, 54.344562292099, 51.2186486274004, 50.61837963759899, 50.81906206905842, 49.830864295363426, 46.917606219649315, 47.069902047514915, 45.95815770328045, 41.095782816410065, 42.19062186777592, 40.46083688735962, 49.37276087701321, 53.107949048280716, 42.41909600794315, 42.20760315656662, 45.229478403925896, 50.96832565963268, 40.01236975193024, 46.89362570643425, 42.13262937963009, 39.028974920511246, 46.30951724946499, 47.28842452168465, 45.94363108277321, 44.12943363189697, 48.24767544865608, 47.42173656821251, 51.27179257571697, 50.85580229759216, 49.776196628808975, 49.05249126255512, 51.481792107224464, 49.976461082696915, 46.97668544948101, 46.95720009505749, 46.95335850119591, 45.60213200747967, 44.71733808517456, 43.62487770617008, 42.87078537046909, 41.88300557434559, 43.02702538669109, 40.22926211357117, 40.83153739571571, 42.63863682746887, 43.263752683997154, 42.20376916229725, 45.9536549448967, 42.79227398335934, 46.06073699891567, 45.602644979953766, 45.93703083693981, 46.10547199845314, 44.804775193333626, 43.15670482814312, 46.72108456492424, 49.60354909300804, 52.2275210916996, 50.91195188462734, 52.653934210538864, 52.57810927927494, 49.59983669221401, 48.82283538579941, 50.42099542915821, 55.99867433309555, 59.292801171541214, 62.73108847439289, 61.38803914189339, 56.95061445236206, 55.99376119673252, 53.41890536248684, 51.59843444824219, 50.31865172088146, 53.20319853723049, 53.00296448171139, 56.19425743818283, 57.09137789905071, 62.05301485955715, 61.388825699687004, 74.08685132861137, 71.49246454238892, 86.49318560957909, 12.233929932117462, 0.605222973972559, 0.5528180266264826, 0.5307557573541999, 10.276732854545116, 78.34730431437492, 71.74094080924988, 62.600139901041985, 54.3675472587347, 22.414461448788643, 38.91639456152916, 56.72266088426113, 64.42056521773338, 44.221806675195694, 0.6132145982701331, 0.12696264660917222, 0.05017551717173774, 0.17412086221156642, 0.006503089425677899, 0.07344450743403286, 0.11547437869012356, 0.16450026829261333, 0.1863681839313358, 0.19542027788702399, 0.31745601387228817, 0.2675677486695349, 2.8798203449696302, 68.22073370218277, 72.67483949661255, 64.81688395142555, 27.049437537789345, 50.687429532408714, 69.69267591834068, 74.72218483686447, 90.48687011003494, 13.074771612882614, 0.4297794116428122, 0.2754747384460643, 2.3992385203018785, 0.8303030650131404, 0.6446921685710549, 45.87672047317028, 75.24553835391998, 71.13225907087326, 69.7225347161293, 70.788514316082, 70.72039917111397, 72.54443049430847, 68.85947942733765, 65.30045360326767, 56.885755732655525, 51.15242958068848, 51.75287336111069, 55.08201912045479, 54.9028093367815, 54.968215227127075, 55.502398163080215, 57.697730362415314, 59.11511890590191, 63.21651242673397, 62.48253621160984, 65.7276950776577, 58.464369624853134, 59.42225642502308, 44.63971205055714, 45.89933305978775, 61.743950843811035, 61.558425799012184, 62.67274260520935, 60.77145762741566, 58.10222625732422, 51.176755875349045, 47.6361096650362, 47.43734993040562, 48.853910118341446, 47.84981779754162, 48.10899809002876, 49.91859398782253, 46.03765703737736, 45.44829346239567, 45.80726400017738, 46.553384363651276, 47.20740146934986, 45.9606009721756, 47.04948954284191, 49.847062826156616, 50.825704112648964, 55.19593320786953, 54.78819988667965, 53.69415119290352, 56.11720137298107, 57.57296785712242, 55.130166336894035, 52.765386030077934, 56.683853566646576, 53.74924063682556, 54.00513790547848, 54.15204182267189, 53.044002279639244, 48.86308662593365, 47.89708346128464, 45.70910766720772, 41.36951632797718, 42.80823312699795, 40.6151732057333, 50.76353944838047, 53.83823566138744, 43.48127581179142, 42.3170068860054, 46.15615367889404, 50.675699561834335, 41.16675540804863, 49.85927917063236, 42.527633383870125, 42.635954171419144, 47.7341216057539, 50.6387085467577, 49.32889603078365, 45.799907594919205, 52.01711878180504, 50.117000341415405, 54.47956524789333, 54.14715528488159, 52.44864262640476, 52.020382806658745, 53.86914700269699, 51.17379583418369, 51.087772250175476, 48.64953048527241, 48.52899715304375, 49.59734782576561, 49.32208679616451, 45.89472010731697, 44.487028643488884, 45.63134104013443, 45.641387701034546, 42.46954210102558, 43.138443008065224, 45.434458404779434, 45.656248703598976, 45.07472410798073, 47.51154474914074, 44.65120643377304, 48.632446601986885, 47.215628027915955, 49.896205589175224, 49.39752034842968, 47.43807949125767, 45.882401168346405, 51.380649134516716, 54.08470943570137, 54.80964973568916, 52.98507884144783, 55.001452043652534, 52.85035327076912, 51.69151425361633, 51.46521359682083, 54.88473750650883, 57.98640847206116, 64.18286517262459, 66.00521698594093, 63.638285994529724, 59.33261923491955, 58.91249477863312, 55.93507334589958, 53.067610412836075, 52.31257572770119, 56.72428719699383, 55.700363740324974, 58.90872538089752, 59.191031232476234, 65.7667949795723, 64.88461911678314, 77.31196627020836, 74.97978061437607, 91.01852998137474, 14.033594112843275, 0.8592790632974356, 1.5157033991999924, 0.6136275292374194, 11.951056960970163, 87.29675129055977, 77.9843857884407, 71.01071119308472, 64.31972622871399, 45.28908580541611, 43.63485597074032, 57.65134625136852, 80.13943254947662, 56.35371968150139, 0.7636359985917807, 0.1941129402257502, 0.14392383804079145, 0.23185664147604257, 0.10526857164222747], [0.048994544995366596, 0.010622298468661029, 0.05546880383917596, 0.12334224986261688, 0.039157140054157935, 0.04208054881019052, 0.03809067013207823, 0.9763692459091544, 41.519824862480164, 49.88847300410271, 28.632056415081024, 33.79641629755497, 45.77446036040783, 49.625067338347435, 64.14389446377754, 71.9741190969944, 13.162108976393938, 0.29455226787831634, 0.47844794229604304, 1.0695483209565282, 0.14275431720307097, 0.25767554354388267, 10.306365564465523, 54.303775280714035, 63.8100291788578, 65.49909174442291, 65.10002955794334, 65.57064950466156, 66.06473699212074, 62.94811762869358, 59.75510336458683, 52.68025539815426, 53.07306312024593, 47.67501197755337, 49.51091766357422, 49.7630151361227, 52.47658632695675, 52.75286190211773, 55.523380637168884, 56.377426609396935, 60.542215928435326, 58.29150930047035, 62.0112095028162, 58.308866769075394, 50.68413510918617, 48.00005033612251, 52.42666080594063, 58.382468819618225, 54.4105077534914, 52.58898049592972, 48.66960860788822, 46.25962972640991, 45.025113970041275, 43.056166023015976, 42.73227520287037, 43.35210934281349, 42.514505088329315, 41.47344835102558, 43.10956835746765, 42.55883350968361, 42.07122467458248, 41.132648438215256, 43.392166793346405, 42.29228161275387, 41.56197600066662, 44.19002138078213, 43.2703111320734, 47.39121660590172, 47.029187232255936, 50.91178469359875, 50.02132907509804, 49.973425045609474, 50.695336908102036, 50.10631151497364, 52.73627199232578, 51.112835705280304, 51.019204929471016, 51.23810738325119, 53.38784582912922, 50.41295886039734, 51.62158280611038, 51.6100200265646, 45.68801499903202, 41.64672665297985, 42.420513331890106, 38.20672944188118, 39.564297795295715, 62.244243398308754, 38.66861365735531, 42.73552022874355, 47.49392129480839, 50.819924622774124, 38.10074932873249, 36.101292818784714, 42.83893167972565, 37.93830044567585, 43.391859009861946, 42.37537555396557, 45.78138738870621, 44.43135403096676, 49.01553824543953, 47.28477671742439, 49.0155990421772, 46.23180001974106, 46.89153961837292, 46.84657663106918, 46.473170667886734, 46.60273611545563, 47.63838954269886, 45.40230073034763, 45.06891421973705, 40.78709118068218, 45.29595963656902, 39.81675244867802, 40.20002268254757, 37.749986350536346, 40.38149334490299, 40.749841779470444, 39.86746832728386, 41.72542043030262, 43.957185074687004, 42.164217084646225, 42.820517867803574, 42.06486761569977, 43.83317872881889, 43.148561865091324, 41.42302505671978, 42.04812191426754, 43.82319286465645, 42.31891818344593, 42.36533269286156, 45.08882515132427, 48.764204531908035, 51.7172122746706, 53.96867126226425, 52.624204605817795, 50.94429574906826, 47.60445736348629, 50.30876465141773, 49.9535521119833, 55.509788766503334, 50.540973991155624, 60.559383407235146, 61.205386742949486, 59.97235290706158, 55.69684512913227, 54.78390231728554, 51.28681696951389, 49.811139553785324, 47.11639255285263, 50.86536258459091, 52.78845839202404, 58.4483040869236, 64.07302066683769, 70.1781378686428, 68.04335162043571, 87.87362113595009, 9.058134444057941, 0.5462933017406613, 0.21176327514695004, 0.055223364470293745, 13.6687633395195, 76.19933277368546, 63.69243308901787, 58.835119530558586, 45.60680575668812, 29.1597967967391, 34.906093552708626, 34.470515325665474, 57.02460028231144, 39.99427892267704, 0.27672905707731843, 0.09597901269444264, 0.07697405046201311, 0.018912318082584534, 0.007562224145658547, 0.07996593718416989, 0.0720722095866222, 0.08384869797737338, 0.03238968834921252, 0.024256313845398836, 0.1439161048620008, 0.04732443812827114, 2.4809961207211018, 53.44359643757343, 60.19926533102989, 35.35180203616619, 31.506642065942287, 48.83308723568916, 57.34531067311764, 68.030044734478, 78.2858844101429, 15.290321577340364, 0.27523333264980465, 0.4247803642647341, 2.0739370258525014, 1.179757488425821, 0.8532821538392454, 10.824463963508606, 59.51879024505615, 66.8802036345005, 67.50621244311333, 67.6981021463871, 66.4292286336422, 67.49154523015022, 64.78203982114792, 61.31894364953041, 53.61076466739178, 53.94472874701023, 50.28784677386284, 49.07784730195999, 50.45648172497749, 53.03140975534916, 54.300499856472015, 56.97661645710468, 58.179612904787064, 63.64568039774895, 59.11008037626743, 64.48526814579964, 59.15036961436272, 51.42262168228626, 48.56645554304123, 55.019622668623924, 58.94169241189957, 58.101014122366905, 54.61204133927822, 51.98034815490246, 48.08641970157623, 48.33441719412804, 45.11798098683357, 46.247645169496536, 46.751976907253265, 45.16478307545185, 44.34777371585369, 45.009325817227364, 45.674419328570366, 45.27531534433365, 43.685043677687645, 45.03110244870186, 43.58771190047264, 43.64111043512821, 46.94355122745037, 45.74130713939667, 49.48308415710926, 51.36934854090214, 52.659835293889046, 52.00018689036369, 52.73430369794369, 52.876727655529976, 52.72451162338257, 54.11298751831055, 54.31563064455986, 52.942369133234024, 53.34998466074467, 54.33927297592163, 52.92865186929703, 52.4675390124321, 53.227418437600136, 47.07369424402714, 42.21225790679455, 43.150929138064384, 40.35485677421093, 43.25947791337967, 60.631233751773834, 41.62427365779877, 42.82976657152176, 46.85780122876167, 50.404329523444176, 39.69328947365284, 40.410770773887634, 45.87442919611931, 37.926445081830025, 45.66205099225044, 45.07312059402466, 48.19103188812733, 46.61533623933792, 49.61122088134289, 50.690936744213104, 52.502299547195435, 50.29262691736221, 51.13576367497444, 50.92379204928875, 48.32158148288727, 49.300591349601746, 51.15643076598644, 47.93453425168991, 46.22681848704815, 43.14109526574612, 45.46520635485649, 42.4792505800724, 41.72567121684551, 39.71161209046841, 43.02563466131687, 41.32201127707958, 41.812454760074615, 42.69123360514641, 45.33222109079361, 43.44812639057636, 44.54219028353691, 43.35518717765808, 47.71156221628189, 44.97787870466709, 43.94931569695473, 42.402821481227875, 45.11360742151737, 43.971145525574684, 44.747227281332016, 48.662837371230125, 50.891151800751686, 54.769390895962715, 56.908763498067856, 55.87331525981426, 53.06992448866367, 50.558468252420425, 54.07309725880623, 53.93403612077236, 59.367448166012764, 55.54837189614773, 65.07113590836525, 63.33597041666508, 62.45290160179138, 58.54661241173744, 57.394282445311546, 53.858473375439644, 52.851652801036835, 51.944124698638916, 53.452541157603264, 56.646216586232185, 62.59721785783768, 67.75746256113052, 72.15272471308708, 70.46090349555016, 88.59590917825699, 10.534986946731806, 0.4910437617218122, 0.3886539809172973, 0.10916937404545024, 16.14693146198988, 83.2756170630455, 70.72745159268379, 66.98892340064049, 54.37139645218849, 31.391760930418968, 41.213287711143494, 44.30009767413139, 67.70085319876671, 51.29863053560257, 0.30236399557907134, 0.07332503650104627, 0.09015037780045532, 0.0466000463347882, 0.12441195925930515, 0.11691625288221985, 0.20036057685501873, 0.1507845480227843, 0.19216941873310134, 0.22970126650761813, 0.3817086957860738, 0.1773820075322874, 4.224394345656037, 68.57678979635239, 66.36964023113251, 44.69512067735195, 46.61193162202835, 62.15562455356121, 67.07404643297195, 75.12450724840164, 83.35611194372177, 17.358505949378014, 0.41991457692347467, 1.0337352426722646, 2.528716097585857, 1.0963203781284392, 0.5187880026642233, 13.810688573867083, 63.58503945171833, 69.52434495091438, 71.13397657871246, 71.24184519052505, 68.06757912039757, 71.39259070158005, 67.09334179759026, 66.4934603869915, 55.24514816701412, 60.3172641992569, 52.226863726973534, 52.398283928632736, 54.97339054942131, 56.337201967835426, 55.99386379122734, 60.96489764750004, 61.92908450961113, 64.88934606313705, 62.26492568850517, 67.81839609146118, 60.88335022330284, 52.372008338570595, 48.41192923486233, 57.19970628619194, 61.07601888477802, 60.585442408919334, 57.52052687108517, 54.28967423737049, 49.23112727701664, 49.9782507866621, 48.248545601964, 48.670752346515656, 49.4242899119854, 46.60815842449665, 45.46267569065094, 48.371073827147484, 47.813396751880646, 45.92163786292076, 45.96435897052288, 48.48463073372841, 47.32861116528511, 47.15125188231468, 48.67426335811615, 47.91971504688263, 51.25255040824413, 52.412422969937325, 57.06999644637108, 55.768357291817665, 57.23445922136307, 57.76464857161045, 55.66820986568928, 56.88764803111553, 58.0202304571867, 57.56675139069557, 54.682626351714134, 57.78639480471611, 54.504108130931854, 55.24951793253422, 55.76580762863159, 50.57897575199604, 42.85589396953583, 42.5063469260931, 41.011548936367035, 45.647079795598984, 63.367345333099365, 42.04523026943207, 45.577801913022995, 48.12568299472332, 51.408870220184326, 40.541498959064484, 42.813264057040215, 48.57263781130314, 40.64798444509506, 46.28262609243393, 46.17389872670174, 50.69270744919777, 48.98920565843582, 53.82883496582508, 50.90535543859005, 55.83998344838619, 51.30408324301243, 53.85343864560127, 52.97346666455269, 51.322850435972214, 51.64060078561306, 54.71851542592049, 52.443345710635185, 48.516689613461494, 45.291365683078766, 49.047923907637596, 44.61326166987419, 43.943790793418884, 41.939383149147034, 45.542171224951744, 44.74245473742485, 43.84409934282303, 45.41480965912342, 48.96698825061321, 46.39593221247196, 46.856680288910866, 46.63068741559982, 50.316630229353905, 46.92362889647484, 45.90681865811348, 45.8175690472126, 48.5759474337101, 46.84303142130375, 46.87073573470116, 51.15631677210331, 53.879946023225784, 58.456276059150696, 59.57965537905693, 60.174768045544624, 54.5536270737648, 54.64470438659191, 56.92199818789959, 56.39566943049431, 64.53905045986176, 59.46570709347725, 68.6893093585968, 67.31363877654076, 64.24240037798882, 61.36589013040066, 60.80054886639118, 56.974689960479736, 56.120017021894455, 54.03159208595753, 56.279866844415665, 60.40156647562981, 65.928955078125, 69.87549930810928, 76.4825239777565, 74.72050532698631, 94.53754395246506, 12.995247580111027, 0.7782967993989587, 0.4909645003499463, 0.14418632083106786, 19.173660948872566, 90.32640472054482, 78.26216608285904, 75.09801506996155, 64.59407910704613, 44.48277287185192, 46.48953638970852, 52.5743892788887, 78.1406258046627, 63.284422382712364, 0.9634750534314662, 0.157209157187026, 0.20239746052538976, 0.17219464760273695, 0.16458485828479752], [0.08076538608293049, 0.04222818424750585, 0.05720501379983034, 0.039218051824718714, 0.07831154900486581, 0.04335522826295346, 0.1325106606236659, 1.543894442729652, 45.81966653466225, 50.84675118327141, 38.02147798240185, 21.734778620302677, 32.30618566274643, 52.69201576709747, 58.60730655491352, 77.33814686536789, 18.007699213922024, 0.13974391389638186, 0.2242520175059326, 2.6640850212424994, 1.3877014489844441, 0.982962604612112, 0.8956537395715714, 18.711888827383518, 55.06804347038269, 54.835495948791504, 62.001824006438255, 62.72445023059845, 66.44941315054893, 58.733091205358505, 58.33172254264355, 48.7411929666996, 48.297338783741, 45.08248329162598, 50.55753730237484, 52.7186219394207, 53.76717567443848, 54.3042616546154, 57.30830825865269, 57.36693151295185, 59.79098483920097, 58.03514085710049, 60.182204246520996, 53.396391570568085, 58.55751782655716, 58.84562976658344, 58.162266835570335, 53.41204293072224, 53.28061558306217, 47.372734397649765, 45.50871022045612, 41.528674587607384, 40.81524766981602, 42.21631608903408, 44.19478252530098, 41.12593799829483, 47.743465304374695, 47.547642812132835, 50.84601402282715, 47.724367529153824, 46.50694325566292, 40.605745911598206, 44.372723177075386, 43.281873911619186, 40.83247974514961, 40.54163195192814, 42.494799345731735, 46.62770077586174, 50.68834908306599, 50.2223838865757, 50.79900674521923, 49.55182246863842, 52.2404707968235, 51.52616612613201, 49.68464434146881, 51.60126529633999, 49.15420040488243, 49.75033521652222, 53.74538004398346, 48.857424929738045, 51.52723386883736, 52.148325741291046, 52.65258148312569, 45.092575550079346, 47.31884948909283, 41.881766840815544, 36.257320046424866, 54.02809627354145, 43.577938824892044, 40.74387229979038, 50.891923159360886, 45.30814178287983, 37.226925417780876, 34.78041149675846, 42.68683724105358, 39.5171195268631, 44.574188366532326, 45.74009120464325, 46.21800675988197, 48.15614216029644, 47.635015323758125, 47.58796624839306, 47.51483537256718, 46.749180257320404, 47.34281860291958, 47.18168444931507, 49.43549171090126, 46.69656828045845, 47.452123537659645, 46.18687503039837, 45.8216842263937, 43.97818274796009, 43.26749548316002, 39.41819943487644, 39.34207811951637, 37.769939079880714, 41.78505823016167, 39.90596406161785, 42.60760009288788, 41.369022354483604, 44.729106053709984, 43.02276201546192, 44.71809804439545, 43.88976149260998, 46.80338814854622, 47.0304411649704, 48.233794793486595, 45.19933462142944, 43.8423590362072, 40.85008420050144, 42.56924495100975, 43.05319458246231, 47.97232322394848, 52.31775484979153, 54.519459307193756, 53.73227834701538, 54.08508941531181, 50.509306490421295, 53.208560049533844, 54.963518679142, 57.44999885559082, 54.18926082551479, 54.1363562643528, 54.17349547147751, 60.276264399290085, 59.776682406663895, 56.99970401823521, 55.6423332542181, 51.3336456567049, 50.464389100670815, 51.868440359830856, 53.39007630944252, 58.356246426701546, 63.6094531416893, 72.02749863266945, 71.60025715827942, 79.98709872364998, 8.588771279901266, 0.5715921067167073, 0.5501063377596438, 0.5267513659782708, 22.78490737080574, 72.18092679977417, 64.39120799303055, 54.93346989154816, 51.52504898607731, 30.70335566997528, 43.77870865166187, 50.36891542375088, 58.018691539764404, 37.28279002010822, 0.8022399083711207, 0.22077809844631702, 0.13015183329116553, 0.08357324244570918, 0.05973563718725927, 0.0885915856633801, 0.01599265346158063, 0.02821769034198951, 0.09138711495324969, 0.05009175467421301, 0.11758877226384357, 0.15711097104940563, 3.5797316255047917, 56.32399767637253, 60.928142219781876, 44.206964671611786, 35.864823907613754, 46.041806414723396, 56.876830011606216, 68.73929187655449, 83.44096899032593, 21.581289656460285, 0.22593476314796135, 0.3572928684297949, 3.6191236367449164, 4.528956552967429, 1.7801523464731872, 0.9605255804490298, 20.57835627347231, 61.14283449947834, 55.21332487463951, 64.31851789355278, 63.05144548416138, 67.86031544208527, 60.716394782066345, 60.596522614359856, 49.914771392941475, 51.80449739098549, 48.60941223800182, 54.421914741396904, 53.747743517160416, 57.43690475821495, 55.76728954911232, 59.79823485016823, 59.61285799741745, 63.601883947849274, 58.77779200673103, 61.18998236954212, 54.77662950754166, 59.859305173158646, 59.496059864759445, 58.29277083277702, 58.33524115383625, 56.101219430565834, 50.0696624815464, 49.98767428100109, 44.393808245658875, 42.4994844943285, 44.07653287053108, 45.867008194327354, 44.14852760732174, 49.70472626388073, 48.54414314031601, 52.89746694266796, 48.708267733454704, 48.569187596440315, 42.156226113438606, 46.385900750756264, 45.237256586551666, 42.210240215063095, 42.58088372647762, 43.64301413297653, 46.78709462285042, 51.69599041342735, 52.71019399166107, 53.67273174226284, 53.19988511502743, 55.23467592895031, 54.461318626999855, 53.43615263700485, 55.060630068182945, 50.97230404615402, 53.15554529428482, 56.095234751701355, 52.36028976738453, 52.687437012791634, 53.98777663707733, 54.89381141960621, 47.55393147468567, 45.438729375600815, 42.755723744630814, 41.99694246053696, 53.59276883304119, 48.22122886776924, 41.72049969434738, 50.92307768762112, 46.06052801012993, 39.96760435402393, 37.7157311886549, 45.399017706513405, 42.63349190354347, 47.96340510249138, 47.83785603940487, 48.19009713828564, 50.22472836077213, 50.77586218714714, 50.7638244330883, 51.197996735572815, 49.257611855864525, 50.41517794132233, 49.73086506128311, 53.02993543446064, 49.37220610678196, 49.34246130287647, 49.78275127708912, 48.66389371454716, 46.21423356235027, 44.958355352282524, 42.289868742227554, 41.125246435403824, 39.70990218222141, 43.60673367977142, 41.07144132256508, 45.23544028401375, 43.591325506567955, 45.827528312802315, 43.98412182927132, 47.611502185463905, 45.96027418971062, 49.753223061561584, 50.324769392609596, 49.989999756217, 48.16559985280037, 45.65152555704117, 43.65789033472538, 45.37505619227886, 46.01411730051041, 49.79592517018318, 53.51462982594967, 57.040570825338364, 56.60639472305775, 57.09575146436691, 53.757296204566956, 55.03235578536987, 58.133452981710434, 59.81214590370655, 57.67746604979038, 58.76157447695732, 57.82392919063568, 64.23117578029633, 62.53655031323433, 59.626924842596054, 59.1254011541605, 56.98943316936493, 54.18984219431877, 53.660747185349464, 55.507980063557625, 60.19525274634361, 66.4842800796032, 76.48575380444527, 74.64980632066727, 84.47801694273949, 9.464726876467466, 0.5396941245999187, 0.5635871237609535, 0.8691687451209873, 26.684193536639214, 80.56144550442696, 70.75192987918854, 65.55454596877098, 60.979918241500854, 36.17427550256252, 43.29409785568714, 54.4351190328598, 68.84609654545784, 47.24547162652016, 0.6188083137385547, 0.17038385180057958, 0.07615807393449359, 0.09796221682336181, 0.12377879596897401, 0.17307329108007252, 0.17951931862626225, 0.20267814077669755, 0.30958993127569556, 0.37558372132480145, 0.23419857752742246, 0.2833301341161132, 5.452473247423768, 76.2983326613903, 69.54981118440628, 54.19049195945263, 31.200893372297287, 49.727342650294304, 67.68275856971741, 72.1056604385376, 91.3040466606617, 24.0895863622427, 0.21422597346827388, 0.7257122523151338, 9.314446840435266, 6.084674298763275, 1.6999033838510513, 2.015162017196417, 24.56694144755602, 64.97380793094635, 59.22106482088566, 63.845162093639374, 67.41760119795799, 72.41098165512085, 64.88601744174957, 64.98281344771385, 53.80153343081474, 53.28494355082512, 49.39356476068497, 56.583523750305176, 56.863238140940666, 58.28278876841068, 58.85726474225521, 63.6580715328455, 61.78970418870449, 65.9527114033699, 61.20707385241985, 64.05245617032051, 56.552103236317635, 59.39243942499161, 62.833872959017754, 60.99231697618961, 61.19665861129761, 59.30291622877121, 53.91149953007698, 52.37194374203682, 46.02079354226589, 44.509591832756996, 47.07206793129444, 49.37061779201031, 45.628893971443176, 52.94257812201977, 50.87695196270943, 55.940271466970444, 52.48421251773834, 53.039089143276215, 46.23086906969547, 49.682581052184105, 47.012825310230255, 44.30638253688812, 45.56684710085392, 45.862592831254005, 50.00411979854107, 55.3548064827919, 56.36063911020756, 56.24014377593994, 54.270101487636566, 60.418106988072395, 56.97936750948429, 55.108230113983154, 58.752557560801506, 54.23201613128185, 55.68354584276676, 60.07970094680786, 55.07934406399727, 57.281876876950264, 56.03299029171467, 56.17606021463871, 48.40208016335964, 48.371374011039734, 43.01029108464718, 44.16763298213482, 57.42866300046444, 47.93434426188469, 44.01728264987469, 51.72370232641697, 49.02808137238026, 42.09466941654682, 38.41744713485241, 49.18234549462795, 42.66154959797859, 50.55411368608475, 48.51569786667824, 50.86850881576538, 53.68553325533867, 53.72961848974228, 52.82571919262409, 53.399796187877655, 53.11755873262882, 53.976468443870544, 53.48786026239395, 55.298805087804794, 52.779414877295494, 53.101835176348686, 52.21336305141449, 51.75043769180775, 47.852652445435524, 46.639822125434875, 45.29493369162083, 42.7569966763258, 40.786741599440575, 48.25418069958687, 42.54358112812042, 47.92918413877487, 44.44368056952953, 47.96945817768574, 46.657358184456825, 48.024524822831154, 48.15622575581074, 51.39456778764725, 53.69254007935524, 52.644776701927185, 51.134182959795, 47.88939647376537, 46.22785963118076, 47.74690791964531, 48.97367209196091, 53.91446717083454, 58.09847965836525, 61.54235266149044, 58.4551665186882, 58.91570180654526, 55.26230804622173, 58.248138427734375, 62.213803231716156, 61.830928176641464, 61.2995532900095, 62.784008234739304, 62.577382922172546, 67.36879661679268, 66.60068303346634, 62.190297693014145, 64.20754864811897, 59.517429918050766, 55.85895203053951, 56.43864892423153, 59.511392042040825, 63.15810576081276, 71.30862280726433, 78.87505039572716, 79.19893741607666, 86.03376746177673, 11.734696570783854, 0.736683807335794, 1.2926706857979298, 1.4710807311348617, 30.200089775025845, 85.95970943570137, 77.17885941267014, 71.88388153910637, 71.48425698280334, 49.17182005941868, 58.53098385035992, 64.57199469208717, 77.85844534635544, 63.14606800675392, 0.7762020430527627, 0.2795558678917587, 0.27716217446140945, 0.19668412569444627, 0.16008622624212876], [0.044185446604387835, 0.060071421903558075, 0.056590285457787104, 0.07775968799251132, 0.056766590059851296, 0.11283915329840966, 0.12633719423320144, 5.819665119051933, 56.501972526311874, 39.14236083626747, 38.876705691218376, 21.482287868857384, 31.914525479078293, 52.5101575255394, 61.478170305490494, 76.05288863182068, 31.25047691166401, 0.25513095664791763, 0.1696555525995791, 2.517244038172066, 2.5127056566998363, 2.3008796107023954, 0.4300934885395691, 6.001362344250083, 44.863394647836685, 61.811180636286736, 65.99546670913696, 63.851104974746704, 62.60139003396034, 58.550792187452316, 51.69021852314472, 48.82142186164856, 51.6779375821352, 51.15791268646717, 51.70691102743149, 56.66806161403656, 57.48722545802593, 58.458111360669136, 57.44974806904793, 58.33689786493778, 57.363264709711075, 59.42036792635918, 59.27996926009655, 59.248271360993385, 58.455854281783104, 54.884057343006134, 54.09868888556957, 51.44104689359665, 48.33311386406422, 43.211110308766365, 42.33841873705387, 41.65189057588577, 44.646243900060654, 42.44377188384533, 48.25175642967224, 50.197734609246254, 55.94796605408192, 53.701883777976036, 53.63920994102955, 50.56479871273041, 46.144818887114525, 39.59770940244198, 42.73451708257198, 42.74388737976551, 41.2650903314352, 41.624813228845596, 41.27504959702492, 40.92532776296139, 47.62054570019245, 50.63813857734203, 54.68754328787327, 50.6768698990345, 51.57684400677681, 51.098464876413345, 52.44299232959747, 53.62012356519699, 53.223911225795746, 52.59056121110916, 52.37042382359505, 52.691673785448074, 51.23754121363163, 49.20536085963249, 53.18525590002537, 50.534457340836525, 46.54228515923023, 42.635851576924324, 41.45796798169613, 47.3760212212801, 45.3245835006237, 40.03998287022114, 54.39527057111263, 45.52225649356842, 40.898698791861534, 40.415634512901306, 37.160672172904015, 47.21874766051769, 45.96867933869362, 49.58561025559902, 48.4931118786335, 49.54016849398613, 49.519729390740395, 48.04719440639019, 47.849240228533745, 47.31138288974762, 45.34188777208328, 47.87574760615826, 48.08301508426666, 45.72402186691761, 48.60514886677265, 47.49599978327751, 46.2466724216938, 44.14275571703911, 41.48662604391575, 38.83956268429756, 37.96806424856186, 39.651199132204056, 40.75536668300629, 40.25377459824085, 42.21612609922886, 42.25252814590931, 42.262703999876976, 42.639685571193695, 44.47073131799698, 45.99717780947685, 48.15827004611492, 49.63056564331055, 53.45937319099903, 53.439207673072815, 51.378247663378716, 45.46682506799698, 43.50951589643955, 41.18341751396656, 44.13207069039345, 45.64451113343239, 53.49995881319046, 53.941001147031784, 54.564418494701385, 51.70063756406307, 52.73840747773647, 53.107588067650795, 56.05279862880707, 61.71359807252884, 66.95277974009514, 62.45827451348305, 59.67906564474106, 66.50416061282158, 63.32197196781635, 59.650206193327904, 55.695416405797005, 53.28829497098923, 51.72600880265236, 53.569901660084724, 58.12751390039921, 63.72757360339165, 70.34290462732315, 69.31291669607162, 78.83488655090332, 7.366979140788317, 0.4689115227665752, 0.17160775722004473, 0.4690478404518217, 32.31134958565235, 74.0890172123909, 64.87193539738655, 62.233877554535866, 52.899640426039696, 32.167443707585335, 22.700225114822388, 47.581369802355766, 56.69910974800587, 60.61758868396282, 1.2424646923318505, 0.0754411518573761, 0.04918909900879953, 0.005541382925002836, 0.005986166870570742, 0.02541973979532486, 0.014102364366408437, 0.013213302063377341, 0.12247599283000454, 0.016486521199112758, 0.20586731261573732, 0.20885954814730212, 9.695654734969139, 70.01927599310875, 47.57670745253563, 44.3512961268425, 26.854986771941185, 39.42040711641312, 59.01489928364754, 67.53239303827286, 82.02287748456001, 35.98864026367664, 0.2575751458061859, 0.11745879251975566, 4.987850328907371, 4.395575160160661, 3.5049081780016422, 0.77476762002334, 4.678849959746003, 51.292022690176964, 64.07792240381241, 67.34719857573509, 65.17918691039085, 66.05548828840256, 57.746626138687134, 54.65651795268059, 51.29122473299503, 54.72823530435562, 52.3507446795702, 55.52359342575073, 58.72346252202988, 59.53502677381039, 60.028278306126595, 61.090427711606026, 61.116760298609734, 61.21112823486328, 60.49368493258953, 58.48685681819916, 61.47478088736534, 60.25166451931, 56.521473079919815, 56.17983341217041, 53.78272444009781, 49.849943071603775, 46.12186811864376, 45.19889384508133, 44.069640040397644, 45.60002312064171, 44.25953485071659, 49.73639376461506, 53.45635615289211, 59.83385033905506, 55.83795815706253, 56.52057632803917, 52.70267799496651, 47.84516304731369, 41.87382146716118, 44.68537800014019, 43.559392020106316, 44.08852122724056, 44.0482509881258, 43.06017480790615, 42.845832109451294, 49.37968410551548, 51.95313781499863, 55.75728848576546, 53.377852365374565, 54.03706759214401, 54.34908024966717, 54.64044101536274, 55.68147495388985, 56.2601763010025, 53.53724621236324, 55.863815769553185, 53.573743253946304, 53.204737454652786, 51.140380427241325, 53.820657804608345, 50.84704376757145, 49.81608688831329, 42.37747684121132, 43.30672837793827, 49.47632052004337, 47.991622388362885, 42.261571660637856, 53.24182726442814, 47.33300372958183, 42.24345423281193, 41.549136489629745, 39.84456695616245, 50.13914555311203, 48.53162281215191, 51.14225372672081, 49.10777449607849, 49.54249396920204, 50.93121685087681, 52.710205391049385, 50.28428256511688, 49.24597308039665, 49.36794653534889, 50.5623060464859, 49.97935272753239, 49.67086248099804, 50.838988199830055, 51.53688155114651, 49.31250371038914, 45.75038485229015, 44.25768435001373, 41.65001727640629, 41.898052766919136, 42.632002383470535, 43.41105937957764, 41.96062780916691, 43.237701281905174, 43.510830625891685, 44.861635342240334, 44.7826261818409, 45.911659598350525, 47.17195697128773, 51.510005593299866, 52.86670379340649, 54.71994794905186, 55.712317898869514, 52.271617725491524, 47.71561659872532, 44.13188450038433, 45.45045554637909, 45.147053226828575, 49.68342460691929, 55.215961933135986, 56.1176573485136, 57.60828696191311, 55.14507673680782, 56.30936086177826, 56.828713193535805, 58.81895139813423, 63.903602957725525, 70.13880997896194, 66.89292535185814, 63.744361102581024, 66.94433659315109, 65.96003741025925, 62.17708960175514, 59.20236602425575, 55.33059798181057, 55.81441842019558, 55.007687509059906, 61.19712218642235, 66.45088747143745, 74.06599804759026, 73.76088201999664, 82.61392816901207, 8.732920344918966, 0.5593578319530934, 0.4583700274815783, 0.9044057980645448, 36.19450181722641, 82.66055926680565, 70.73819741606712, 69.80109930038452, 60.26425704360008, 43.77756871283054, 32.765554413199425, 53.44133175909519, 63.64376150071621, 72.60669395327568, 2.079960177652538, 0.008301680609292816, 0.05445000948384404, 0.04443263744178694, 0.08919204250560142, 0.12785654864273965, 0.1590418315026909, 0.17188064492074773, 0.35832635359838605, 0.16871223837370053, 0.3742154681822285, 0.3495592740364373, 13.266711663454771, 84.60266545414925, 55.22428348660469, 54.65334132313728, 27.91166827082634, 48.08643490076065, 69.59575831890106, 73.40650543570518, 89.74660903215408, 42.802913412451744, 0.8034513902384788, 0.2984009269857779, 8.590594232082367, 8.701910208910704, 5.23236483335495, 0.5987427779473364, 8.232657238841057, 58.775470331311226, 66.55412033200264, 70.30905604362488, 70.50273925065994, 69.27330762147903, 63.87867629528046, 57.01141878962517, 54.73304584622383, 56.05139270424843, 56.90618723630905, 57.24888704717159, 61.3137873262167, 61.57786935567856, 61.38546288013458, 62.47879721224308, 61.83396801352501, 60.923529267311096, 63.20428088307381, 60.5149219930172, 64.07768681645393, 64.04579892754555, 59.05643865466118, 59.72939394414425, 55.53921818733215, 54.006395637989044, 49.152437299489975, 45.015036910772324, 46.88475698232651, 48.8848290592432, 46.185370311141014, 52.583132609725, 55.22877484560013, 61.637035980820656, 56.73740789294243, 60.52398070693016, 56.06393963098526, 51.51454254984856, 42.8850270062685, 46.95860221982002, 47.958214581012726, 46.06740564107895, 46.089904233813286, 45.39948508143425, 45.73931224644184, 52.496254071593285, 54.30755227804184, 60.08992999792099, 56.05667442083359, 56.766388937830925, 58.17291386425495, 57.814885675907135, 59.26503986120224, 58.79927225410938, 55.80581948161125, 57.15603902935982, 55.63926301896572, 56.76347829401493, 54.33989614248276, 56.59836955368519, 53.39798368513584, 50.6042367964983, 42.30455495417118, 44.75893825292587, 52.611342296004295, 49.11831133067608, 42.63485603034496, 54.73069377243519, 52.01328858733177, 44.28139507770538, 42.2294557839632, 43.95377665758133, 52.87208430469036, 49.897364526987076, 55.2785711735487, 53.113306760787964, 52.51472108066082, 54.56979900598526, 56.32959097623825, 54.33814063668251, 53.243753761053085, 50.605597123503685, 53.45398887991905, 54.22263823449612, 53.54973614215851, 52.887796461582184, 55.31549759209156, 52.315163388848305, 49.53856498003006, 45.55416338145733, 42.46161192655563, 44.13063816726208, 44.77058842778206, 45.47238416969776, 42.733137756586075, 47.42657370865345, 46.73779606819153, 46.97142653167248, 47.59284518659115, 47.562477216124535, 50.72920449078083, 52.16213800013065, 55.12920118868351, 57.54639208316803, 60.4209378361702, 55.159990936517715, 50.16569472849369, 46.83215260505676, 46.515318006277084, 47.40608140826225, 51.7047793418169, 60.15897989273071, 58.58067378401756, 60.45246094465256, 56.43291883170605, 58.34693692624569, 60.513994842767715, 61.64639487862587, 65.98147585988045, 70.92908397316933, 68.39197531342506, 64.91695538163185, 71.35374158620834, 69.16836485266685, 67.09279462695122, 61.5519205480814, 56.67968899011612, 59.06266652047634, 59.6003794670105, 63.684396520256996, 69.04992520809174, 77.66280144453049, 76.79867461323738, 84.81801509857178, 10.307178720831871, 0.6462931889109313, 0.9540962660685182, 2.142089931294322, 39.81624327600002, 87.66666144132614, 79.10911023616791, 75.9792409837246, 72.21752643585205, 48.149758502840996, 33.81777495145798, 67.4008820950985, 73.09409379959106, 87.61986315250397, 2.592964000068605, 0.29101186722982675, 0.19977941585239023, 0.13030044094193727, 0.1434945352957584], [0.016828285770316143, 0.0112257758519263, 0.06567875578184612, 0.1330376003170386, 0.0389588901452953, 0.11371778935426846, 0.26876649528276175, 6.942378049716353, 59.19512741267681, 46.549208387732506, 36.33020393550396, 43.513410687446594, 45.88740549981594, 47.96266034245491, 64.69633921980858, 71.6538418829441, 41.437255293130875, 0.028277659585000947, 0.15502762893447652, 2.5309729389846325, 3.2890111254528165, 4.0442911349236965, 0.15488057979382575, 3.4324669651687145, 43.66268947720528, 63.93970862030983, 63.46031114459038, 59.92902383208275, 59.64465469121933, 51.27316050231457, 50.03641426563263, 49.48051929473877, 53.00018683075905, 54.41671662032604, 58.328359723091125, 60.71730673313141, 61.19365677237511, 58.94126683473587, 61.85946084558964, 58.522168323397636, 58.43167617917061, 59.68886911869049, 59.79296833276749, 54.50506187975407, 54.168012365698814, 54.57453355193138, 51.467352882027626, 45.209001302719116, 42.63584017753601, 40.530703738331795, 43.476339876651764, 42.801043912768364, 42.87700183689594, 46.90486930310726, 52.80909888446331, 54.69445511698723, 56.49437673389912, 54.70304265618324, 54.6634753793478, 54.42758783698082, 46.69528394937515, 43.00982750952244, 41.73163689672947, 42.80513249337673, 42.51849107444286, 41.14152476191521, 40.37093371152878, 41.397133246064186, 44.577402994036674, 48.83828155696392, 48.36449258029461, 50.53655482828617, 50.37410594522953, 52.901388332247734, 51.85960203409195, 53.1905148178339, 51.85367435216904, 52.174445539712906, 52.848153188824654, 50.34917168319225, 49.75931793451309, 52.55256325006485, 53.13693009316921, 53.52282218635082, 50.0882700830698, 48.04301843047142, 41.456197276711464, 40.60166113078594, 40.56120090186596, 42.497064024209976, 53.46934385597706, 43.85180912911892, 37.65807308256626, 41.214651837944984, 42.57969059050083, 40.94790995121002, 52.074028328061104, 49.176679998636246, 50.36139942705631, 47.1294030547142, 49.11818213760853, 48.64961788058281, 50.620192140340805, 45.885566398501396, 48.187368884682655, 47.08858944475651, 49.585861042141914, 48.827702924609184, 48.39413858950138, 47.423910051584244, 48.62075462937355, 42.35481485724449, 40.993439108133316, 39.00122880935669, 39.51434947550297, 41.341967806220055, 42.45587423443794, 40.77977277338505, 41.46221615374088, 42.31330208480358, 43.75930689275265, 41.912826374173164, 42.65884414315224, 42.59832099080086, 47.05516263842583, 51.42460897564888, 52.8804362565279, 56.4205314964056, 53.67023527622223, 52.44196638464928, 50.9802570194006, 43.943190425634384, 43.772982358932495, 43.89760047197342, 47.59249560534954, 50.79244829714298, 56.01292356848717, 54.1511944681406, 53.37964206933975, 52.241071164608, 52.09708169102669, 53.69583450257778, 58.062168806791306, 63.77305716276169, 66.15078717470169, 62.72847801446915, 64.14739787578583, 60.477653592824936, 58.09343732893467, 55.511304885149, 55.05732424557209, 54.59741972386837, 59.91489239037037, 65.68025082349777, 69.25474181771278, 73.8163286447525, 72.18512177467346, 3.672440475784242, 0.3624326270073652, 0.2707830292638391, 1.3876655884087086, 48.412544801831245, 70.55354252457619, 68.76092031598091, 65.12788966298103, 46.30067132413387, 32.4209813028574, 37.3544579744339, 46.615579426288605, 61.07954129576683, 57.91723698377609, 2.347469860687852, 0.12110411800676957, 0.030995870074548293, 0.08373615870368667, 0.1168350619263947, 0.03428008691116702, 0.1282339307363145, 0.044775795395253226, 0.1092044850520324, 0.08903848472982645, 0.17772375169442967, 0.09980209739296697, 9.761714190244675, 70.76307088136673, 50.96707932651043, 49.53331746160984, 33.266173750162125, 45.47947458922863, 57.431592643260956, 68.94898742437363, 79.73739132285118, 46.58363074064255, 0.13647573301568627, 0.1179395780491177, 4.1528247110545635, 5.829438669607043, 2.364343092776835, 2.4892371660098433, 4.3908577132970095, 47.50573106110096, 66.8650272488594, 66.34967610239983, 63.18109832704067, 63.03792580962181, 55.19836127758026, 50.227680802345276, 51.894772946834564, 53.88621188700199, 56.05783335864544, 60.41284807026386, 62.199679389595985, 63.001827746629715, 59.131469428539276, 63.91620308160782, 60.55466786026955, 60.730165243148804, 60.08750572800636, 62.26092830300331, 57.469913586974144, 58.684100434184074, 57.51426100730896, 54.53758053481579, 49.85223054885864, 45.15996873378754, 43.6692251265049, 45.29716037213802, 44.29388880729675, 44.419312477111816, 49.67445328831673, 54.35700282454491, 57.15034693479538, 57.984390780329704, 57.66320161521435, 57.819069251418114, 57.49627657234669, 47.577501609921455, 44.66971904039383, 43.79931874573231, 43.915888890624046, 45.74983388185501, 42.528731524944305, 43.13268631696701, 42.45235562324524, 46.91487796604633, 51.11288130283356, 52.347260266542435, 52.34463840723038, 52.65083357691765, 55.420470759272575, 56.11706458032131, 55.71028880774975, 55.84949053823948, 54.029806181788445, 53.357743844389915, 51.796407625079155, 54.014379009604454, 54.17249232530594, 54.847476705908775, 54.36642251908779, 51.603096798062325, 48.809995874762535, 41.900606229901314, 44.823124408721924, 44.737089425325394, 44.78018291294575, 51.66904225945473, 47.618284821510315, 38.19513626396656, 41.31480686366558, 44.6880454570055, 47.142455354332924, 55.27059160172939, 51.77843078970909, 51.36508136987686, 50.38440719246864, 52.086438462138176, 51.57630443572998, 51.300222650170326, 50.10639131069183, 52.26300358772278, 51.03269800543785, 51.343456730246544, 49.06292550265789, 52.739771604537964, 49.58588384091854, 50.37214145064354, 45.354427099227905, 43.93685236573219, 42.753041088581085, 42.32414290308952, 43.404968306422234, 45.76873026788235, 43.660029619932175, 43.45236696302891, 44.91501487791538, 46.0616185516119, 45.00598579645157, 45.08167013525963, 45.99359080195427, 49.630041271448135, 52.36514210700989, 55.99243126809597, 58.62650692462921, 57.34952464699745, 56.28651648759842, 53.03859516978264, 45.80901950597763, 45.331058353185654, 45.27435019612312, 50.64710229635239, 53.796544298529625, 57.2675896435976, 56.90508529543877, 56.247127801179886, 54.75664637982845, 55.85115484893322, 57.63668283820152, 59.85889479517937, 65.71495816111565, 67.20758646726608, 65.4583503305912, 67.0747683942318, 63.209194019436836, 60.59469871222973, 59.56286408007145, 58.1498908996582, 58.08189354836941, 61.71594254672527, 68.23099315166473, 73.84965285658836, 75.64064115285873, 73.27203825116158, 4.051961023360491, 0.3044899518135935, 0.5100434250198305, 2.3027913831174374, 53.50552171468735, 76.9194321334362, 76.92086845636368, 70.68401992321014, 57.50201426446438, 34.284211322665215, 37.93591417372227, 60.227060839533806, 64.5407223701477, 69.67556923627853, 2.9168928181752563, 0.14048407261725515, 0.07842630730010569, 0.08180913515388966, 0.03249503250117414, 0.0927552864595782, 0.16031409526476637, 0.1560714893275872, 0.30771998630370945, 0.27597479755058885, 0.47728535311762244, 0.4481759760528803, 15.71833061054349, 82.18194454908371, 62.088288366794586, 54.786660969257355, 56.93541146814823, 68.85056510567665, 63.426394164562225, 76.21795937418938, 83.02392616868019, 52.58554928004742, 0.17741871415637434, 0.1999173068907112, 7.453296259045601, 14.191074762493372, 10.590786952525377, 3.0092843854799867, 5.338848419487476, 52.82774828374386, 65.47869443893433, 69.99750316143036, 64.8204405605793, 66.5688407421112, 57.79812477529049, 52.730982676148415, 54.35963608324528, 57.29244031012058, 57.266734689474106, 63.793393671512604, 65.47777488827705, 65.44803008437157, 61.331577971577644, 68.0412845313549, 61.45632907748222, 61.29742160439491, 62.58772976696491, 66.15401700139046, 60.495953410863876, 61.89668744802475, 60.58417707681656, 57.266905680298805, 50.54719425737858, 46.264314875006676, 46.754009798169136, 46.552293822169304, 46.20520144701004, 46.49280421435833, 51.99073299765587, 59.44439023733139, 60.636663660407066, 60.5700646340847, 59.83872167766094, 59.48028691112995, 59.91207294166088, 50.11434808373451, 48.285958394408226, 47.53461331129074, 46.825415566563606, 49.153296053409576, 45.553061440587044, 45.322793796658516, 44.13259506225586, 49.83206883072853, 53.345523700118065, 54.5504504442215, 56.04963339865208, 55.4904668033123, 58.98460350930691, 58.77718023955822, 59.402968659996986, 58.44463728368282, 56.847940161824226, 56.40355780720711, 54.19204227626324, 55.37688709795475, 56.979800686240196, 58.15636195242405, 57.42633752524853, 52.358914241194725, 48.91820266842842, 43.02760675549507, 46.78676404058933, 46.14817790687084, 46.170193925499916, 56.4169292896986, 51.596074774861336, 39.89190101623535, 42.32533983886242, 45.028928965330124, 49.28575314581394, 59.505148977041245, 53.67841623723507, 54.76846754550934, 54.00626644492149, 54.57230307161808, 55.93447297811508, 56.94349743425846, 53.40413935482502, 55.94806484878063, 53.12164731323719, 56.94388501346111, 54.21592019498348, 56.24939247965813, 51.855593249201775, 53.45458164811134, 47.841332852840424, 45.550808161497116, 44.5873698592186, 45.0094436109066, 45.4291994869709, 46.376633048057556, 46.93769574165344, 44.94613900780678, 45.647645965218544, 49.359803572297096, 46.173408553004265, 46.24755397439003, 49.6486184746027, 50.57198032736778, 55.305606722831726, 58.486047461628914, 62.14728780090809, 59.69335287809372, 58.9042492210865, 55.16843028366566, 48.993161246180534, 48.96651327610016, 48.833919391036034, 52.611821070313454, 56.37897692620754, 61.66007414460182, 59.93203327059746, 56.68771415948868, 58.014815747737885, 57.44170010089874, 59.70481686294079, 63.04085925221443, 67.97022834420204, 69.2370043694973, 68.41797351837158, 71.4373978972435, 67.12035834789276, 64.08033907413483, 61.756239384412766, 62.65766501426697, 61.3302556425333, 66.17573663592339, 72.61110931634903, 76.60027205944061, 81.21862784028053, 78.4697413444519, 6.123665906488895, 0.4538781044539064, 1.1104931426234543, 3.524318723939359, 58.1563201546669, 85.08135616779327, 84.40123066306114, 79.98558640480042, 67.13346764445305, 47.43346653878689, 47.106953859329224, 65.07925227284431, 75.57085409760475, 85.12728810310364, 3.9153393544256687, 0.3362561285030097, 0.17159294395241886, 0.20749478309880942, 0.24934570770710707], [0.022680346555716824, 0.06242267932975665, 0.07721556758042425, 0.03009010852110805, 0.0483119732234627, 0.24988462566398084, 0.17123586701927707, 7.010858925059438, 55.12883260846138, 44.90245655179024, 27.367142289876938, 29.17889267206192, 39.69024583697319, 46.990691497921944, 66.72014862298965, 67.70263150334358, 50.55113844573498, 0.2597956219688058, 0.1367243376444094, 3.639859836548567, 2.705564070492983, 2.556121414527297, 1.9323253934271634, 4.853156581521034, 47.46712513267994, 67.90186241269112, 62.01221264898777, 62.01640762388706, 56.2990216165781, 51.71389505267143, 52.819650918245316, 54.00423355400562, 57.940727323293686, 60.33092826604843, 62.552669048309326, 61.59464545547962, 60.17078585922718, 57.5664322078228, 59.35646295547485, 57.91410595178604, 60.45289032161236, 57.07696907222271, 54.31487828493118, 52.916044145822525, 53.450337275862694, 50.40318198502064, 45.38104087114334, 43.909714221954346, 44.51004020869732, 43.39476965367794, 42.61428393423557, 42.08851754665375, 51.96372404694557, 51.90700449049473, 54.863975420594215, 53.59407976269722, 56.82370886206627, 56.27960465848446, 54.43096585571766, 53.73646192252636, 46.181186735630035, 40.58613896369934, 40.89396424591541, 41.597507894039154, 40.40961943566799, 40.16723804175854, 42.38126523792744, 41.62642814218998, 44.14193496108055, 45.41107065975666, 47.309004217386246, 48.730933517217636, 51.015097349882126, 50.502463057637215, 52.52380259335041, 52.52202808856964, 53.5812858492136, 53.154956325888634, 52.696339935064316, 51.257714331150055, 53.58848266303539, 50.37748396396637, 51.412992998957634, 53.895308598876, 52.992895022034645, 56.864119693636894, 42.71756999194622, 41.09439589083195, 46.90885528922081, 44.054874032735825, 52.044291123747826, 40.86285151541233, 38.529305532574654, 43.29061344265938, 53.291046023368835, 47.93474704027176, 47.808525413274765, 48.12513202428818, 48.94046187400818, 48.19991581141949, 48.127951472997665, 47.884304746985435, 49.18203391134739, 48.626469522714615, 49.24045957624912, 48.390532582998276, 50.16243830323219, 48.280657678842545, 47.77500741183758, 48.43708008527756, 45.66936559975147, 40.57188592851162, 41.19417853653431, 37.335382997989655, 38.58175791800022, 40.84213122725487, 41.4339342713356, 41.90081141889095, 42.15388163924217, 45.86793154478073, 50.3930327296257, 49.862573593854904, 48.93526375293732, 43.77295956015587, 48.01663264632225, 48.97654853761196, 52.71482974290848, 62.589591667056084, 56.54579557478428, 54.58855099976063, 53.10916118323803, 50.057119354605675, 45.16677416861057, 43.748295083642006, 43.88392120599747, 45.4122181981802, 49.249689280986786, 50.36563239991665, 51.38995103538036, 51.424270793795586, 51.665550246834755, 54.12251740694046, 58.94716791808605, 60.579621121287346, 64.24629136919975, 64.98185589909554, 61.48859694600105, 63.76757025718689, 61.85950644314289, 61.01698525249958, 60.932625979185104, 61.76958046853542, 61.23993068933487, 68.10500711202621, 66.17080450057983, 75.08415341377258, 72.3729456961155, 1.7108815885148942, 0.0807489178259857, 0.2128140375134535, 3.062519528903067, 55.97841762006283, 69.52653363347054, 64.42638650536537, 66.26204520463943, 43.449517115950584, 35.43160155415535, 39.54895421862602, 32.18433000147343, 60.92157617211342, 66.95314452052116, 6.032033823430538, 0.1655893848510459, 0.16419539402704686, 0.04330023512011394, 0.009781543485587463, 0.026487076174817048, 0.07220130617497489, 0.0814073438232299, 0.0903566725901328, 0.048196209318120964, 0.23065406538080424, 0.24943862459622324, 10.987861845642328, 67.69133850932121, 53.944895938038826, 39.01140086352825, 26.00154686719179, 45.069165006279945, 55.51660940051079, 70.37242144346237, 74.2036646604538, 57.217280343174934, 0.40172667475417256, 0.08868799064657651, 1.9711989699862897, 4.185888161882758, 1.619759628083557, 2.901636636815965, 5.411984995007515, 51.92715480923653, 68.41547325253487, 63.48954297602177, 62.0198730379343, 57.01052583754063, 53.94700862467289, 52.92740173637867, 54.72187824547291, 59.62575450539589, 63.35623852908611, 63.81338059902191, 61.70871913433075, 61.89780838787556, 60.660321190953255, 61.28492787480354, 59.85717348754406, 63.40042255818844, 58.908197209239006, 56.96658119559288, 56.364461705088615, 57.93478824198246, 52.86818191409111, 47.37479388713837, 46.942886263132095, 45.91116942465305, 44.710395857691765, 44.27612476050854, 46.16903878748417, 53.31638306379318, 54.669129475951195, 56.34987808763981, 55.70514768362045, 60.821318551898, 56.62819795310497, 58.07076774537563, 57.11253896355629, 49.200295731425285, 43.03509995341301, 43.4963534027338, 43.24446111917496, 40.82476615905762, 41.520307436585426, 43.934906870126724, 45.57187423110008, 45.61233825981617, 46.71757735311985, 50.260043665766716, 51.27466142177582, 52.08453856408596, 53.02642822265625, 55.79458348453045, 55.83895370364189, 54.34707395732403, 55.02414062619209, 55.10704077780247, 53.93084429204464, 55.447019934654236, 53.00908975303173, 55.15742987394333, 52.09720328450203, 54.366057738661766, 57.673901841044426, 43.735174387693405, 44.18267257511616, 46.620123982429504, 45.01917488873005, 52.433903217315674, 44.760123789310455, 39.532713890075684, 45.77096454799175, 54.59329694509506, 50.284157171845436, 49.09879557788372, 51.62257835268974, 52.78342746198177, 51.02091483771801, 52.18516856431961, 49.15692865848541, 52.13870085775852, 51.39977730810642, 51.67959049344063, 51.63861349225044, 53.82916174829006, 50.226343274116516, 50.65212942659855, 51.86366021633148, 48.46376605331898, 42.34528496861458, 43.637588024139404, 39.74009916186333, 40.94076633453369, 43.09798277914524, 43.81261043250561, 42.05115035176277, 43.755051121115685, 48.59191797673702, 52.95914143323898, 53.68934825062752, 50.46485647559166, 47.30713091790676, 49.62771579623222, 51.17902435362339, 54.61591713130474, 63.58058989048004, 58.986590802669525, 57.89313107728958, 56.0630276799202, 51.38596124947071, 47.84349873661995, 45.00196561217308, 46.01765111088753, 47.56987541913986, 51.23101316392422, 51.09194062650204, 53.99166002869606, 52.65970230102539, 53.293686881661415, 56.19012326002121, 62.12156318128109, 62.17792555689812, 65.09523421525955, 66.26781329512596, 65.39091154932976, 66.87274843454361, 64.90452244877815, 64.595165848732, 63.84097471833229, 65.32182365655899, 65.85570260882378, 69.48060929775238, 70.97140610218048, 78.48907470703125, 74.82413336634636, 1.6733758198097348, 0.03903799195541069, 0.36293550627306104, 4.490924393758178, 62.59414002299309, 75.2117657661438, 73.78097534179688, 72.20279082655907, 54.294796362519264, 36.32166959345341, 34.66604523360729, 45.74568450450897, 64.86916154623032, 82.80571907758713, 6.949877422302961, 0.29866937664337456, 0.1534942034049891, 0.04182763601420447, 0.09238752259989269, 0.1175687788054347, 0.18069830926833674, 0.21054756303783506, 0.19062664214288816, 0.2579329500440508, 0.7226243836339563, 0.636073756031692, 17.606989815831184, 81.48101136088371, 62.76315115392208, 42.409801706671715, 43.55481706559658, 60.79860337078571, 61.40226557850838, 80.72433516383171, 79.47115480899811, 63.295605182647705, 0.49486605974379927, 0.19677969947224483, 10.461224354803562, 13.214248828589916, 8.067862931638956, 6.704976763576269, 7.47495224699378, 55.90006202459335, 73.19970533251762, 66.7963345348835, 67.41190150380135, 60.068582743406296, 57.2000976651907, 57.68756590783596, 56.29386909306049, 63.1334412842989, 65.0260703265667, 67.92519316077232, 67.1546933054924, 63.86050567030907, 62.1894845366478, 61.74420163035393, 61.90334849059582, 67.47923389077187, 61.01725123822689, 61.1954540759325, 59.053615406155586, 59.88200895488262, 56.38123780488968, 49.37127135694027, 48.346850126981735, 50.36126643419266, 48.16554665565491, 46.65002077817917, 48.13615903258324, 57.17190317809582, 56.666564494371414, 59.407953992486, 57.58454583585262, 61.137932762503624, 59.360570535063744, 58.61340902745724, 58.889931589365005, 51.241952776908875, 45.50041526556015, 45.50814025104046, 45.2462013065815, 43.19689527153969, 43.979562073946, 46.205729618668556, 48.466114327311516, 48.65767724812031, 49.017472341656685, 53.986579701304436, 54.26506295800209, 55.47044947743416, 54.76050317287445, 59.89570342004299, 56.23982459306717, 58.00199143588543, 59.34933453798294, 57.65873305499554, 56.212868839502335, 59.35498483479023, 55.2497611194849, 58.43883879482746, 57.34938025474548, 56.29725091159344, 60.6073634326458, 44.465780183672905, 45.432607904076576, 50.32182075083256, 46.72646127641201, 57.063947170972824, 48.423632606863976, 41.52766764163971, 45.841378569602966, 58.20500314235687, 53.1146214902401, 51.836985647678375, 56.90906748175621, 55.74609808623791, 52.380147501826286, 53.92460882663727, 52.67264820635319, 56.91228210926056, 55.23498751223087, 53.51368747651577, 54.439975172281265, 56.390676498413086, 52.81552813947201, 52.085503712296486, 54.98502552509308, 50.835617780685425, 44.67410400509834, 46.696040108799934, 42.56436601281166, 44.30122621357441, 46.02362059056759, 45.545541644096375, 47.290377616882324, 47.30475604534149, 51.83758221566677, 55.66513583064079, 53.92683930695057, 52.11144112050533, 49.918818175792694, 53.95806983113289, 55.63030689954758, 59.04285438358784, 66.65495172142982, 62.09138140082359, 62.53406144678593, 59.821607396006584, 52.73605540394783, 49.00937497615814, 48.164497911930084, 48.41916784644127, 50.81978403031826, 53.83042708039284, 56.53997428715229, 57.46041029691696, 56.8577816337347, 57.17932417988777, 59.246546253561974, 64.38076615333557, 65.27485057711601, 69.43074077367783, 69.27539750933647, 66.41827002167702, 69.85045865178108, 70.4462742805481, 67.36463963985443, 68.94769549369812, 67.65223860740662, 68.65047544240952, 71.61958292126656, 74.44682881236076, 79.63634714484215, 81.2721137702465, 2.7461385307833552, 0.20160618267254904, 0.8009172230958939, 7.70832764916122, 66.27503290772438, 84.18936923146248, 76.08868271112442, 82.94233694672585, 59.75523255765438, 59.74717698991299, 55.52192531526089, 51.37318633496761, 76.03642031550407, 97.4531427025795, 8.748425412923098, 0.43030155706219375, 0.47782352892681956, 0.2407684101490304, 0.22859613440232351], [0.09934235175023787, 0.03214077943994198, 0.0179349800964701, 0.15878623584285378, 0.02849477117706556, 0.08792363791144453, 0.08207572202081792, 7.2392841428518295, 66.18677124381065, 37.02240899205208, 60.74887923896313, 34.80370044708252, 30.964403562247753, 47.40445889532566, 65.17123013734818, 65.90918853878975, 63.66709604859352, 2.260969877243042, 0.05017858595238067, 1.4838317781686783, 3.1835907697677612, 0.40494528017006814, 3.4294587140902877, 4.504992188885808, 46.99987180531025, 64.9033597111702, 60.95739305019379, 59.369439259171486, 53.45746949315071, 54.33828882873058, 54.50978122651577, 61.44413933157921, 59.26555283367634, 61.407391503453255, 63.76463681459427, 62.972466722130775, 57.55932658910751, 58.588368371129036, 57.33135022222996, 59.5840023458004, 56.43144451081753, 55.06908841431141, 52.42482170462608, 50.93683674931526, 45.62401123344898, 44.32835675776005, 43.031991720199585, 44.06467370688915, 41.681202203035355, 41.96259990334511, 44.894119799137115, 50.00147134065628, 50.27836248278618, 54.341317266225815, 56.64455607533455, 56.47460639476776, 54.72113348543644, 54.99714307487011, 56.066413298249245, 53.01109604537487, 44.23383682966232, 41.46785885095596, 39.22241874039173, 41.441799849271774, 38.86890470981598, 40.2147962898016, 38.338654562830925, 40.87950982153416, 41.94136284291744, 41.19887128472328, 44.83184114098549, 45.95658838748932, 48.79522606730461, 53.28778199851513, 50.842693001031876, 51.873927265405655, 51.848081052303314, 50.4394244402647, 50.95519356429577, 49.7019562125206, 50.6926466524601, 51.3038020581007, 54.124417304992676, 52.68487595021725, 53.04108023643494, 55.20466893911362, 49.72982011735439, 39.388728216290474, 44.48774300515652, 45.48770114779472, 48.69491904973984, 38.89587186276913, 42.08678103983402, 49.12144996225834, 52.34874978661537, 51.40335291624069, 51.714677810668945, 48.8576453179121, 48.41305397450924, 50.80648094415665, 47.85045616328716, 51.12058728933334, 50.506407245993614, 48.34954418241978, 50.353864431381226, 49.49443034827709, 47.779764756560326, 48.95083151757717, 47.42971993982792, 46.314711570739746, 42.62157194316387, 38.86612705886364, 40.4251492023468, 37.69761376082897, 37.40961581468582, 39.22246053814888, 41.126868948340416, 41.32397957146168, 43.827794417738914, 53.03213931620121, 56.542071774601936, 53.866673335433006, 52.87622608244419, 50.853378027677536, 46.69374123215675, 48.96949611604214, 51.697320342063904, 53.83040048182011, 56.252538710832596, 56.21542990207672, 53.661716133356094, 52.97914735972881, 49.63816523551941, 48.77268187701702, 46.123885810375214, 43.66282247006893, 44.31910425424576, 44.54730860888958, 46.232955157756805, 47.86895737051964, 47.09023475646973, 49.16533760726452, 55.34023806452751, 59.60859462618828, 62.989394813776016, 65.13960063457489, 63.29511500895023, 63.94369840621948, 64.01028603315353, 63.61854985356331, 62.12578855454922, 67.4441845715046, 65.4354527592659, 68.70537489652634, 65.96437677741051, 87.84152045845985, 55.6137777864933, 0.9384349314495921, 0.0464409187407, 0.39422581787221134, 2.6316606486216187, 55.48121429979801, 65.61643704771996, 64.42896276712418, 69.75813120603561, 38.762130439281464, 60.11389531195164, 36.32907159626484, 39.528872296214104, 58.83728161454201, 66.55617222189903, 5.7013860158622265, 0.3127114934613928, 0.18458325939718634, 0.050939294742420316, 0.09157573178526945, 0.05429381337307859, 0.06684443971607834, 0.035868327468051575, 0.06908544368343428, 0.021338211445254274, 0.16541851276997477, 0.1473147256183438, 11.790875606238842, 76.6595184803009, 46.00646071135998, 54.61551435291767, 28.987153060734272, 39.92313914000988, 52.05958150327206, 72.68574491143227, 71.31844907999039, 71.3890340924263, 2.5982314674183726, 0.125465823803097, 1.6382791218347847, 3.1129026878625154, 1.4455368393100798, 3.8682237826287746, 5.043385773897171, 51.7291322350502, 67.65058189630508, 64.27563339471817, 60.70481680333614, 56.30509369075298, 54.585264176130295, 56.152911856770515, 63.04891861975193, 62.60179281234741, 62.71071396768093, 65.58186650276184, 63.64822246134281, 59.82907399535179, 58.7390872836113, 61.43569238483906, 59.74587365984917, 58.45368839800358, 57.521708607673645, 55.69038547575474, 52.78733365237713, 49.75977011024952, 45.84112398326397, 45.715400129556656, 46.64047949016094, 43.8514519482851, 44.968569204211235, 48.126252964138985, 51.20602950453758, 51.492306143045425, 57.997838258743286, 59.416575729846954, 58.895676881074905, 57.04522177577019, 57.69453853368759, 57.17723049223423, 55.17940029501915, 46.32188938558102, 43.59911508858204, 42.26687617599964, 42.62499935925007, 40.86421564221382, 41.804209202528, 40.460266917943954, 43.5249050706625, 43.37202787399292, 44.35614086687565, 48.01320143043995, 47.34032593667507, 51.31944961845875, 55.31009428203106, 53.33171524107456, 54.99699868261814, 55.01367598772049, 51.918913051486015, 51.94431088864803, 50.836354941129684, 53.94789397716522, 52.91232034564018, 56.284077018499374, 55.997667387127876, 53.97252045571804, 57.30083405971527, 49.6590793132782, 40.644686222076416, 46.320266872644424, 49.02881473302841, 48.79809871315956, 42.43684485554695, 42.438725754618645, 49.96759615838528, 54.50613722205162, 51.834652572870255, 54.845614805817604, 49.861194267868996, 51.31150804460049, 53.58432188630104, 53.23395028710365, 53.46477650105953, 53.066246286034584, 52.26054131984711, 53.31423617899418, 51.4607298374176, 49.99691918492317, 50.303570330142975, 51.37727491557598, 47.815847620368004, 43.8552251458168, 40.71382351219654, 41.58796280622482, 39.172162637114525, 38.49791921675205, 41.19155667722225, 43.323736265301704, 41.75244078040123, 48.24227973818779, 56.225791946053505, 57.194264978170395, 56.61825388669968, 53.79570074379444, 52.415922582149506, 49.70132924616337, 50.5387207120657, 54.3339304625988, 57.3722892254591, 59.222561940550804, 57.227965369820595, 58.23586888611317, 56.7861744761467, 52.9286290705204, 51.221312284469604, 46.699942499399185, 44.7588736563921, 45.77684663236141, 48.789397180080414, 46.952378153800964, 51.587035059928894, 49.690119847655296, 49.36956524848938, 56.90694339573383, 62.65756621956825, 65.1980111002922, 67.63101294636726, 65.67422434687614, 66.7767807841301, 66.57309651374817, 67.89898976683617, 65.88877603411674, 70.71368873119354, 68.04588228464127, 71.31158664822578, 69.51134204864502, 90.09808257222176, 59.1237748414278, 0.867371263448149, 0.03577559611585457, 0.6571010558400303, 4.321504309773445, 63.67070585489273, 72.39672482013702, 72.62903675436974, 75.33973529934883, 47.65056028962135, 48.45016658306122, 30.440658666193485, 44.30192157626152, 64.78538364171982, 78.91532063484192, 6.667539272457361, 0.40747434133663774, 0.18305295088794082, 0.02836576179106487, 0.09090475607081316, 0.1455152698326856, 0.2017467305995524, 0.10446662912727334, 0.3512072277953848, 0.17963595455512404, 0.23982834652997553, 0.26562106562778354, 16.920265965163708, 92.11533352732658, 54.129630625247955, 80.26098042726517, 47.071041986346245, 49.02648165822029, 60.76072320342064, 79.9697944521904, 75.67361578345299, 78.45436736941338, 3.2555897813290358, 0.17739069066010416, 5.905299223959446, 8.42395132407546, 3.8055442459881306, 9.022229220718145, 5.949112297967076, 54.410921931266785, 69.59140375256538, 67.55490303039551, 63.228211998939514, 59.86405111849308, 58.0183457583189, 59.22475442290306, 67.20895439386368, 65.96208930015564, 65.27696326375008, 67.19973608851433, 65.68453699350357, 61.590522676706314, 61.5197666734457, 62.038773223757744, 64.65282395482063, 62.33807176351547, 59.297064542770386, 59.1459808498621, 56.453969702124596, 50.53230285644531, 48.9730641245842, 47.02460087835789, 49.26782950758934, 44.96809422969818, 48.38035672903061, 49.462876841425896, 53.93591322004795, 54.583995044231415, 60.586874932050705, 62.96904690563679, 60.14114364981651, 58.5158758610487, 60.413733422756195, 59.68714401125908, 58.98771174252033, 48.27569894492626, 46.61107286810875, 44.349491223692894, 46.143686547875404, 41.23746961355209, 43.74204061925411, 42.903372421860695, 46.31709024310112, 46.586389392614365, 46.68692819774151, 51.6407223790884, 49.229915142059326, 53.72284345328808, 58.51792015135288, 57.5471406430006, 57.6713939756155, 57.249077036976814, 56.15573510527611, 55.73485068976879, 54.24848824739456, 55.72114482522011, 55.86868330836296, 58.9049331843853, 57.87182182073593, 57.25470833480358, 59.599589109420776, 50.264561623334885, 41.603880152106285, 48.62484320998192, 50.45651592314243, 52.552833035588264, 43.80878783762455, 43.179682195186615, 50.13228312134743, 57.98330403864384, 55.06611317396164, 58.40597815811634, 54.22336399555206, 53.81018176674843, 55.961759313941, 55.340625643730164, 56.70478284358978, 56.66323967278004, 54.91004794836044, 56.507854610681534, 56.57971255481243, 53.99582840502262, 54.74563457071781, 54.01691347360611, 49.476305320858955, 46.73076644539833, 42.6309460401535, 45.43052941560745, 42.05184951424599, 42.9197533428669, 42.805539071559906, 46.90463751554489, 46.363185569643974, 49.920243099331856, 58.200116604566574, 61.75120085477829, 59.21527773141861, 56.93410433828831, 54.634501934051514, 51.37346372008324, 53.98249492049217, 58.094273284077644, 58.568472638726234, 60.562229454517365, 59.97849717736244, 59.181170761585236, 60.876639783382416, 52.53147818148136, 53.927040696144104, 49.71843212842941, 47.14374728500843, 47.72410914301872, 51.07263006269932, 51.97877123951912, 54.12914805114269, 50.999130606651306, 52.962272465229034, 62.37964153289795, 66.34166613221169, 68.57893288135529, 69.58221584558487, 71.00210085511208, 68.9933006465435, 70.61085104942322, 71.23550713062286, 70.30357673764229, 74.30397167801857, 74.00428175926208, 72.19402849674225, 73.60370725393295, 88.63447710871696, 59.551411494612694, 1.913981877733022, 0.11121964605990797, 1.2113998155109584, 7.9282964207232, 69.52203467488289, 81.35463014245033, 75.19106447696686, 85.42545050382614, 53.069050535559654, 78.01699563860893, 49.033260494470596, 55.88789887726307, 74.97776672244072, 92.2360834479332, 7.774511072784662, 0.6095893552992493, 0.3267298318678513, 0.12473639653762802, 0.10220526062767021], [0.05302350145939272, 0.059061681749881245, 0.024121528695104644, 0.07308174564968795, 0.028991106555622537, 0.026690010890888516, 0.027837111447297502, 15.536182634532452, 55.67616663873196, 38.5009628534317, 42.925574630498886, 18.844492211937904, 32.12630331516266, 43.22922393679619, 66.5570841729641, 58.7554682046175, 74.01397123932838, 7.8703908529132605, 0.11024903564248234, 0.25541421957314014, 1.2642186437733471, 0.41349464328959584, 4.474500250071287, 3.0700642615556717, 42.19574399292469, 68.94033148884773, 59.18514534831047, 59.4271619617939, 55.70211924612522, 59.969666451215744, 58.991564735770226, 61.496933698654175, 59.43384200334549, 61.26051038503647, 53.52639399468899, 57.47874431312084, 58.427591398358345, 58.226126208901405, 56.56876154243946, 56.44223973155022, 52.667560279369354, 50.7461591809988, 45.67918047308922, 44.46576498448849, 43.33806909620762, 43.630129024386406, 43.96597780287266, 45.586051270365715, 42.51720294356346, 44.87873822450638, 49.65727441012859, 56.183766201138496, 57.21855707466602, 62.388194873929024, 55.986362993717194, 48.18719029426575, 55.26020295917988, 55.119105130434036, 51.76926948130131, 45.74007600545883, 43.082225024700165, 41.80767081677914, 40.929560735821724, 40.756419226527214, 41.67036138474941, 38.05336967110634, 39.070537090301514, 38.730694726109505, 40.90359292924404, 39.954544454813, 43.90456549823284, 46.53302505612373, 47.62593001127243, 48.25217440724373, 49.25070382654667, 50.45762546360493, 49.80010114610195, 48.63154225051403, 49.49689261615276, 50.466361194849014, 53.45846883952618, 50.66931210458279, 52.96419516205788, 51.89125433564186, 53.73929277062416, 54.864317402243614, 54.0908233076334, 39.302548840641975, 43.55613559484482, 43.87071691453457, 45.28751648962498, 40.22233888506889, 47.76901513338089, 52.497557401657104, 50.93979299068451, 48.2559210062027, 49.14794594049454, 48.578645288944244, 49.74705599248409, 51.25213623046875, 49.612771198153496, 48.34181919693947, 49.873661398887634, 49.43971708416939, 49.22533258795738, 48.20251107215881, 44.85305540263653, 46.051796078681946, 46.56452536582947, 42.25062444806099, 40.778116062283516, 38.65899637341499, 42.1354716271162, 37.51452438533306, 37.82545030117035, 39.64459128677845, 41.12421669065952, 38.208123967051506, 46.11463710665703, 57.33769588172436, 54.55441363155842, 53.34167070686817, 56.08265742659569, 54.35684323310852, 52.649211063981056, 47.69464932382107, 47.56305858492851, 48.01100894808769, 54.28620882332325, 56.64677135646343, 54.014113023877144, 54.356812834739685, 52.56477579474449, 53.293162509799004, 52.809402868151665, 49.36012655496597, 47.72732377052307, 45.720784440636635, 42.910523638129234, 45.836549028754234, 43.78612585365772, 44.54524911940098, 48.7366484105587, 55.31324051320553, 61.42343044281006, 63.49311098456383, 63.80151003599167, 64.50927525758743, 65.74618488550186, 66.57833263278008, 69.55093592405319, 65.03307715058327, 68.82107108831406, 71.91763132810593, 73.27459171414375, 48.986002430319786, 38.136759996414185, 0.6891063821967691, 0.10107865819009021, 0.8410372515209019, 5.924944644793868, 62.46130675077438, 62.320771291852, 71.90797984600067, 64.75152745842934, 41.42167992889881, 83.84794995188713, 45.317417085170746, 32.87321403622627, 53.820718601346016, 72.27143034338951, 3.3175214705988765, 0.02705955961573636, 0.15016500314231962, 0.024773228979029227, 0.11129505568533204, 0.052983859641244635, 0.09469261844060384, 0.035889259743271396, 0.03319464027299546, 0.040924794811871834, 0.07421011439873837, 0.07201161322882399, 19.983258806169033, 68.7115229666233, 48.82084049284458, 52.2173186391592, 25.93932330608368, 41.86260066926479, 51.115864142775536, 71.45956590771675, 64.884322732687, 80.11607900261879, 8.467013463377953, 0.25930310308467597, 0.7328148430678993, 3.682107632048428, 0.4319797607604414, 3.194415676407516, 2.8943274915218353, 45.202458053827286, 69.59018781781197, 63.087133169174194, 61.85348376631737, 57.78701797127724, 62.60913401842117, 62.7853761613369, 63.4574119001627, 62.01556406915188, 63.51227715611458, 56.42274297773838, 60.70736646652222, 59.69116039574146, 60.94937928020954, 57.93364830315113, 58.67089994251728, 54.8021375387907, 51.98162488639355, 48.07966746389866, 47.012893706560135, 46.300260946154594, 46.63112059235573, 47.06541448831558, 48.175251334905624, 43.61422307789326, 48.102131858468056, 53.78714360296726, 58.960565999150276, 60.84556505084038, 61.781390234827995, 57.24023871123791, 51.316120997071266, 57.47175268828869, 57.70531475543976, 53.483969271183014, 47.27923281490803, 44.237070456147194, 42.450311332941055, 42.739981189370155, 43.360970467329025, 42.40954332053661, 40.973338186740875, 42.65749901533127, 41.91074788570404, 42.77068734169006, 41.39116756618023, 45.49555532634258, 46.7838191986084, 49.02419038116932, 49.79309432208538, 52.37787142395973, 54.659371599555016, 51.359655261039734, 52.19598278403282, 51.73236586153507, 54.898979142308235, 54.05442126095295, 52.98293575644493, 55.497561022639275, 52.57276676595211, 55.91777667403221, 55.19974820315838, 55.36270245909691, 39.78244788944721, 44.667914137244225, 47.015371173620224, 45.686183497309685, 42.05950990319252, 48.500061705708504, 54.53799091279507, 52.760328501462936, 51.185700595378876, 49.42970462143421, 49.92233298718929, 52.29128547012806, 53.76706548035145, 52.738468274474144, 50.523259341716766, 51.282333210110664, 49.35951478779316, 50.48512078821659, 53.1924869120121, 48.019243106245995, 47.924624383449554, 49.4703434407711, 42.357596307992935, 41.98023475706577, 41.885334849357605, 43.90586882829666, 39.16221857070923, 39.69537556171417, 40.8413864672184, 43.47194731235504, 41.21842123568058, 48.51865030825138, 61.11840941011906, 56.55999921262264, 58.22859987616539, 56.63593053817749, 57.4672195315361, 52.97349326312542, 48.22413571178913, 50.4584614187479, 53.83426867425442, 56.700188890099525, 58.49522016942501, 57.47375898063183, 56.08473211526871, 55.8847526460886, 56.91078118979931, 54.61297608911991, 52.45529226958752, 49.3231925368309, 49.00760807096958, 45.430575013160706, 47.388864532113075, 45.32863408327103, 48.64877052605152, 51.867547407746315, 57.360065281391144, 63.56421656906605, 66.1346684396267, 66.48377850651741, 65.53190678358078, 67.7863410115242, 68.30575793981552, 72.31638953089714, 68.44417691230774, 72.22166821360588, 73.18755358457565, 75.31270354986191, 53.4686066955328, 41.288451477885246, 0.8620458492077887, 0.10233559660264291, 1.1723458673804998, 7.291679056361318, 69.94344726204872, 69.7883927822113, 78.69943141937256, 71.92777678370476, 48.02067182958126, 93.76183077692986, 46.027963757514954, 39.24638405442238, 65.04658162593842, 81.7668928205967, 4.919647788628936, 0.2681716490769759, 0.12219310097862035, 0.002001226257561939, 0.11814924961072393, 0.18981373810674995, 0.13456179352942854, 0.11326444102451205, 0.21626109082717448, 0.1568854323704727, 0.21043149114120752, 0.16931977530475706, 27.99848221242428, 82.02304467558861, 56.12126335501671, 61.085461378097534, 30.01421134918928, 51.903588473796844, 57.82819256186485, 79.71884071826935, 67.55715250968933, 88.49912837147713, 10.58326905593276, 0.26180529850535095, 1.569535348098725, 5.864993361756206, 3.1785211293026805, 8.579992800951004, 4.9860340263694525, 50.264964401721954, 73.19860339164734, 64.59806129336357, 65.20776137709618, 60.503344014286995, 65.88082686066628, 64.98572409152985, 64.56931203603745, 65.21311149001122, 66.93305879831314, 57.875496223568916, 62.14154630899429, 61.54067315161228, 62.44989976286888, 62.10955582559109, 61.67079716920853, 56.19032844901085, 56.491621881723404, 50.65329596400261, 49.75157015025616, 49.242408871650696, 49.0912301838398, 48.15380148589611, 51.52312248945236, 46.7817597091198, 50.33193960785866, 55.57399772107601, 59.47161577641964, 61.91127486526966, 61.91942922770977, 57.03006438910961, 49.970818385481834, 60.761783346533775, 60.83646833896637, 55.9669878333807, 50.8363701403141, 47.946568205952644, 45.448221266269684, 45.72858162224293, 44.97877925634384, 45.88936619460583, 41.774380803108215, 44.24934759736061, 43.06660786271095, 44.91227142512798, 43.84483650326729, 48.39160032570362, 50.37474811077118, 51.95539489388466, 51.60011015832424, 54.03906248509884, 56.709107011556625, 55.09007848799229, 53.25211711227894, 55.59162117540836, 56.82970494031906, 59.76286254823208, 56.424992457032204, 58.692342191934586, 56.80818289518356, 57.51323886215687, 57.48101659119129, 57.5993612408638, 41.31301335990429, 47.48533375561237, 48.40287812054157, 50.213051587343216, 44.44200485944748, 49.18952330946922, 56.248035952448845, 53.94388519227505, 53.74733313918114, 53.81645143032074, 54.24902781844139, 56.16332709789276, 58.71188834309578, 54.869865104556084, 53.123615607619286, 53.92728768289089, 53.101474195718765, 53.12711521983147, 55.509139001369476, 50.591663271188736, 51.50568522512913, 51.048603951931, 45.9711492061615, 46.784408167004585, 43.0654489248991, 45.437589436769485, 41.29036657512188, 42.31115520000458, 44.38161090016365, 46.78206369280815, 43.91434617340565, 50.81119269132614, 65.31364649534225, 59.34620350599289, 61.196331828832626, 58.64824175834656, 61.28153845667839, 58.25240179896355, 52.541110664606094, 54.06689219176769, 56.67756490409374, 58.83784778416157, 61.57316140830517, 59.701393246650696, 58.171279951930046, 58.9732763171196, 59.28343087434769, 57.75478430092335, 54.418726712465286, 51.034734696149826, 51.325776278972626, 47.52778507769108, 51.96864478290081, 47.818344086408615, 49.50739525258541, 54.87484283745289, 60.49433469772339, 67.35456258058548, 67.65938982367516, 70.1105622947216, 68.94415408372879, 68.28973799943924, 71.34671196341515, 75.59135019779205, 71.27895399928093, 77.07565695047379, 78.52613031864166, 78.32442194223404, 52.716961428523064, 47.01417423784733, 1.3539547473192215, 0.18444781744619831, 1.6803586576133966, 11.038780063390732, 79.03643533587456, 75.35572484135628, 87.10399523377419, 79.29875046014786, 58.09744231402874, 94.25131291151047, 58.56687672436237, 49.65524911880493, 74.15416851639748, 97.72615805268288, 6.161314286291599, 0.6496115389745682, 0.3282786050112918, 0.08323981033754535, 0.32481740636285394], [0.13845553068676963, 0.04963571976986714, 0.06809139624238014, 0.05703247559722513, 0.10215638278168626, 0.16546406579436734, 0.0777775292226579, 20.77080074697733, 53.582687973976135, 36.53875574469566, 28.76032043248415, 14.699608124792576, 23.863112814724445, 40.33901162445545, 74.09245982766151, 59.83650639653206, 76.45578101277351, 19.662168435752392, 0.15478288347367197, 0.9817244648002088, 2.000825861468911, 0.13738844107137993, 2.1525609819218516, 0.597107500070706, 29.46953907608986, 67.9496182501316, 58.05220954120159, 60.53683161735535, 57.28491671383381, 60.98968371748924, 59.59421619772911, 63.1302722543478, 57.6494387537241, 58.27004425227642, 58.59214536845684, 60.51664710044861, 59.64948423206806, 53.31006780266762, 53.836255967617035, 53.56193728744984, 46.81453675031662, 45.52598029375076, 43.89237955212593, 47.333759889006615, 48.37094843387604, 43.771842420101166, 42.631812393665314, 43.07281672954559, 43.51225174963474, 47.388074174523354, 55.64360238611698, 42.43013821542263, 44.78731133043766, 66.83262258768082, 45.46058960258961, 55.01896150410175, 55.79523324966431, 52.38388650119305, 49.67870146036148, 47.25711040198803, 42.464674562215805, 40.20964376628399, 42.50546917319298, 42.516279593110085, 38.86889711022377, 39.18326184153557, 39.714070558547974, 40.1881293207407, 42.081328332424164, 39.8957160115242, 41.21527120471001, 45.201033130288124, 44.41228285431862, 48.661773428320885, 48.92237104475498, 50.31732939183712, 45.87283328175545, 48.12395788729191, 48.74598070979118, 52.02658407390118, 52.40035101771355, 52.097431272268295, 53.77860926091671, 52.20062233507633, 56.589850410819054, 58.40322710573673, 58.50039929151535, 44.54948969185352, 45.43167695403099, 44.96449202299118, 40.701675564050674, 43.11839908361435, 51.23994268476963, 55.83171509206295, 50.841499865055084, 53.55254039168358, 52.229401990771294, 52.65331484377384, 49.081939682364464, 49.42964382469654, 45.3389011323452, 48.307567834854126, 48.47931481897831, 46.16112761199474, 46.419395953416824, 47.685985788702965, 47.94047333300114, 43.91868554055691, 41.942548379302025, 39.8609022796154, 37.66734838485718, 40.87376073002815, 37.777458876371384, 37.94622302055359, 38.24047923088074, 38.363642022013664, 39.0997689217329, 40.623658150434494, 42.16871224343777, 54.531291872262955, 55.01125171780586, 55.966657251119614, 56.36052131652832, 56.74654260277748, 53.48311811685562, 51.385440677404404, 49.21560890972614, 42.56782382726669, 49.844634756445885, 55.38694515824318, 55.22833026945591, 58.177694007754326, 57.431060671806335, 56.34900413453579, 56.412464529275894, 54.89733003079891, 53.68440851569176, 49.14229944348335, 45.36176070570946, 46.71288840472698, 45.26483550667763, 46.3480281829834, 44.29402180016041, 48.68617571890354, 57.034578546881676, 61.00848510861397, 60.47330662608147, 65.49102857708931, 66.04199901223183, 67.04948455095291, 65.5513009428978, 69.85163658857346, 65.80835714936256, 68.26006919145584, 61.02577418088913, 68.10244604945183, 38.806850239634514, 0.12638384563615546, 0.06481976437498815, 0.1153080930816941, 7.9319860227406025, 67.9675380885601, 59.542348980903625, 70.1074692606926, 64.1020131111145, 40.385783314704895, 38.84074442088604, 38.22360433638096, 52.48030632734299, 52.030775249004364, 65.40864139795303, 1.7453083349391818, 0.06464253208832815, 0.18401189474388957, 0.03454516350757331, 0.07557320961495861, 0.07182747896877117, 0.061462889425456524, 0.025109188100032043, 0.038984568454907276, 0.125717070477549, 0.14822679542703554, 0.11308076689601876, 26.587826907634735, 65.01251265406609, 44.96110640466213, 39.72267709672451, 18.269592560827732, 30.67926686257124, 47.80214935541153, 79.44178998470306, 64.69634681940079, 82.78524577617645, 22.587070986628532, 0.24010510824155062, 0.8191050065215677, 3.4699550410732627, 1.461942340247333, 2.7321844920516014, 0.8270553080365062, 32.35603138804436, 69.62127774953842, 59.931345507502556, 64.94343996047974, 60.44551871716976, 62.15327247977257, 62.21425540745258, 67.48932614922523, 60.60860976576805, 60.761312171816826, 61.4533082395792, 62.98404850065708, 60.83444684743881, 53.83023329079151, 56.66746124625206, 53.337042555212975, 48.78207877278328, 48.433485478162766, 45.812891498208046, 52.17660382390022, 49.20636020600796, 47.544948756694794, 45.81378825008869, 46.157244220376015, 45.93896113336086, 49.26266558468342, 58.118291795253754, 43.43446612358093, 42.033059522509575, 67.0553894340992, 47.46393710374832, 55.04165768623352, 57.97165386378765, 56.943030059337616, 51.54155150055885, 47.877788096666336, 44.83635529875755, 39.94700185954571, 44.76946748793125, 44.606923609972, 40.36195859313011, 41.051431596279144, 40.53886190056801, 41.256928369402885, 43.70027706027031, 42.68792398273945, 43.374562337994576, 48.039146438241005, 46.121503338217735, 50.74471905827522, 49.51046548783779, 52.402030527591705, 48.03701475262642, 51.18208698928356, 50.072409734129906, 54.39743645489216, 53.923765271902084, 52.86975122988224, 56.01548083126545, 54.64565433561802, 59.00528199970722, 60.97151689231396, 59.83884707093239, 44.116187542676926, 44.95409198105335, 48.341074436903, 42.32628598809242, 44.14105720818043, 52.10913464426994, 56.03262931108475, 53.63884516060352, 55.797820910811424, 53.91016200184822, 55.00297576189041, 52.24250748753548, 51.70600667595863, 48.555835112929344, 47.85669542849064, 50.68279758095741, 50.27148485183716, 48.575172275304794, 49.31713566184044, 50.152277648448944, 48.50590579211712, 43.96434769034386, 42.806884199380875, 38.61572429537773, 41.293569803237915, 40.06068795919418, 39.29884023964405, 41.68539337813854, 41.620549857616425, 41.14192374050617, 42.18043461441994, 43.89391086995602, 55.49205131828785, 56.64956420660019, 58.37626375257969, 57.527617290616035, 56.224386021494865, 54.3001464754343, 51.94979399442673, 51.613413244485855, 47.687992081046104, 53.90541225671768, 55.85509143769741, 57.89514496922493, 59.33028616011143, 60.01316271722317, 58.91948260366917, 57.747355699539185, 56.82550236582756, 56.50357984006405, 53.039579316973686, 47.10523635149002, 47.94220983982086, 48.36156293749809, 49.402634873986244, 46.597348004579544, 51.497785449028015, 59.45414051413536, 64.71279233694077, 62.992582842707634, 68.3323261141777, 67.72290721535683, 69.33823853731155, 66.9134670495987, 74.10233929753304, 68.07630345225334, 69.97117057442665, 64.31934624910355, 70.06214529275894, 40.884422957897186, 0.2274461617344059, 0.09321889869170263, 0.459077027044259, 11.286024246364832, 76.89388990402222, 67.33153581619263, 74.96682330965996, 70.92119559645653, 47.56046712398529, 60.06004460155964, 40.42373947799206, 47.669642865657806, 61.555545553565025, 77.03702062368393, 3.01582264713943, 0.22307016217382625, 0.17120837786933407, 0.036910558847012, 0.1512343340436928, 0.23511918203439564, 0.17272403638344258, 0.11069756001234055, 0.16622046270640567, 0.1524887714185752, 0.3702498762868345, 0.45470319455489516, 35.360902547836304, 78.25814589858055, 54.06066432595253, 43.196652084589005, 25.031713508069515, 40.7267352193594, 54.845580607652664, 89.4030998647213, 71.13953188061714, 89.78036642074585, 25.790401697158813, 0.3235351829789579, 1.4771923469379544, 6.846134914085269, 3.659778367727995, 6.450687758624554, 1.1511775595135987, 36.636676490306854, 74.07732143998146, 63.14460888504982, 67.24188342690468, 63.38178835809231, 64.56947922706604, 65.19401371479034, 70.27291998267174, 64.4568532705307, 63.607587441802025, 61.97121664881706, 66.09356984496117, 65.07802113890648, 57.50958725810051, 59.89825688302517, 57.26886257529259, 51.47604301571846, 51.525482162833214, 48.71379263699055, 53.80520783364773, 52.77585826814175, 48.5208959877491, 48.442103415727615, 48.40373307466507, 49.198787212371826, 51.67892932891846, 62.22923420369625, 46.23687654733658, 42.98244617879391, 68.33594352006912, 47.91003316640854, 55.290992707014084, 60.381507351994514, 58.71150456368923, 54.19326201081276, 52.09598734974861, 47.165599912405014, 43.393367528915405, 46.77077829837799, 47.69085332751274, 43.323538675904274, 42.36870691180229, 42.653114050626755, 44.31907005608082, 46.18581108748913, 44.59905803203583, 46.94508634507656, 51.20461978018284, 46.85188114643097, 54.32323023676872, 51.809304133057594, 54.56726834177971, 49.22807604074478, 52.84752622246742, 52.25569657981396, 56.72144874930382, 55.97013406455517, 57.40900665521622, 60.14386050403118, 57.84278757870197, 61.45137034356594, 64.4650000333786, 63.05597484111786, 46.10926799476147, 47.900244891643524, 49.388511031866074, 46.331491470336914, 44.99191515147686, 55.9843946993351, 59.29569661617279, 55.34027986228466, 59.236617386341095, 56.73771567642689, 60.632537081837654, 54.51239928603172, 55.32861068844795, 50.52370771765709, 52.681144550442696, 54.14562776684761, 53.13466541469097, 51.792436838150024, 54.33511219918728, 53.92334349453449, 50.519022569060326, 46.419114768505096, 45.14723941683769, 40.792049914598465, 43.77997398376465, 42.79182180762291, 42.01548546552658, 42.84809298813343, 43.216650411486626, 43.89388047158718, 43.629673048853874, 47.33693651854992, 60.46522065997124, 59.91717606782913, 60.56101731956005, 59.02653805911541, 59.56800140440464, 56.89845845103264, 57.11616016924381, 54.10613268613815, 50.60678265988827, 53.467858135700226, 60.36248177289963, 60.802840143442154, 62.716599851846695, 62.914789617061615, 62.30497933924198, 62.356022000312805, 61.09521925449371, 58.50703753530979, 53.98465320467949, 50.83963796496391, 51.67316123843193, 51.49339288473129, 52.43954211473465, 49.207815527915955, 53.754370361566544, 62.50507280230522, 67.48006224632263, 67.14605256915092, 71.49451643228531, 70.92831641435623, 73.28064858913422, 68.94955739378929, 76.56140014529228, 70.54641410708427, 72.37668469548225, 67.70782962441444, 70.09492233395576, 45.8516988158226, 0.45951795182190835, 0.2500319271348417, 1.427642886992544, 13.534741681069136, 84.50380995869637, 73.96418631076813, 83.2793864607811, 78.37074905633926, 57.53285340964794, 59.086054265499115, 50.8506915718317, 68.94593238830566, 72.02521875500679, 90.53960368037224, 4.753551101312041, 0.5552745354361832, 0.37891032407060266, 0.18511211383156478, 0.30787628260441124], [0.03567601474060211, 0.009429798883502372, 0.028996474138693884, 0.03578031617507804, 0.014912614296918036, 0.17433721310226247, 0.08660776555188932, 25.605423822999, 61.599528193473816, 35.39993405342102, 31.68256502598524, 21.203802712261677, 48.07298742234707, 38.29932667315006, 68.25413390994072, 58.11050981283188, 73.35682690143585, 35.8729212731123, 0.07793931741616689, 0.43130081437993795, 1.521768111269921, 0.260000335983932, 1.2661674642004073, 0.07390351835056208, 17.22166959196329, 62.34312169253826, 61.52878738939762, 63.07735249400139, 60.35677447915077, 60.81859029829502, 59.769660383462906, 58.68538856506348, 56.91538654267788, 61.89130313694477, 60.65568923950195, 58.679084703326225, 53.48298132419586, 54.63442213833332, 49.20508347451687, 49.08819414675236, 48.495638743042946, 49.815342128276825, 52.39598885178566, 49.724462404847145, 48.244909197092056, 45.59601813554764, 46.17173284292221, 47.00026698410511, 46.87597565352917, 51.92949928343296, 56.030714213848114, 47.86650650203228, 34.71566677093506, 42.7268148958683, 49.29088667035103, 56.9953228533268, 56.88826359808445, 55.88761769235134, 49.528947696089745, 45.873817428946495, 40.606312081217766, 41.40176139771938, 42.701306864619255, 39.386311545968056, 39.14805293083191, 38.42684023082256, 38.79046931862831, 39.09611351788044, 39.67248558998108, 39.72467578947544, 40.700140446424484, 42.55015857517719, 47.0524799823761, 47.32231490314007, 47.74807445704937, 48.20214629173279, 47.52976857125759, 49.89754691720009, 49.012866988778114, 53.3834532648325, 52.29879766702652, 48.88289496302605, 52.45822571218014, 51.17329806089401, 55.98767392337322, 54.892348498106, 57.849220633506775, 45.8601039648056, 44.64633509516716, 46.078447848558426, 40.946051850914955, 43.756981417536736, 53.047570288181305, 57.23163977265358, 51.18596278131008, 50.16903094947338, 49.46386098861694, 49.23902705311775, 48.308407589793205, 49.02236267924309, 47.37764373421669, 45.29917426407337, 47.32093557715416, 48.402786925435066, 44.884240329265594, 43.98192934691906, 45.21457180380821, 43.81030015647411, 39.41575616598129, 37.64924235641956, 39.56791140139103, 39.008068442344666, 38.57383914291859, 37.29533314704895, 34.91637580096722, 39.211308136582375, 38.40486221015453, 39.54716831445694, 41.64991468191147, 47.91408754885197, 57.04410083591938, 56.44154816865921, 53.262551352381706, 50.63196010887623, 58.25984939932823, 53.72038498520851, 54.857724756002426, 45.4514054954052, 45.490463599562645, 51.63851849734783, 51.76388517022133, 55.63270457088947, 55.73517747223377, 58.82037632167339, 58.14190372824669, 58.963719829916954, 56.84494972229004, 53.687330558896065, 52.0946080237627, 51.55952073633671, 47.80431143939495, 47.51700505614281, 47.285027503967285, 44.96944695711136, 46.35684370994568, 55.133031383156776, 58.403075113892555, 62.67130248248577, 61.78812727332115, 67.77636274695396, 63.90697717666626, 65.90010702610016, 65.89262142777443, 66.54871702194214, 64.22982305288315, 72.17549309134483, 21.788809821009636, 0.2957557642366737, 0.09265041357139125, 0.22584432503208518, 14.67796353623271, 70.33628538250923, 56.98968395590782, 70.38166254758835, 53.44092898070812, 42.357603907585144, 46.69783741235733, 38.4638312458992, 46.346523463726044, 58.35990563035011, 45.101664662361145, 0.7222749211359769, 0.06640337393037044, 0.048951578355627134, 0.03126674841041677, 0.05976098524115514, 0.07646841782843694, 0.01770218506862875, 0.010779402782645775, 0.08399054466281086, 0.016926256685110275, 0.19370327470824122, 0.09409376463736407, 33.4043837338686, 72.33877032995224, 44.46849323809147, 38.64594027400017, 17.484195604920387, 45.28472363948822, 44.90109242498875, 73.18014398217201, 65.62879398465157, 79.26900565624237, 39.05460834503174, 0.10112076022778638, 0.43442650290671736, 3.0708669684827328, 1.8695864849723876, 2.6226964546367526, 1.0863136150874197, 19.081641286611557, 64.10388261079788, 63.59072394669056, 66.5477366745472, 62.260270938277245, 63.50645586848259, 61.70886732637882, 60.36079466342926, 60.50853073596954, 64.92321744561195, 63.15405137836933, 61.05201557278633, 55.98261259496212, 54.89786200225353, 52.61386156082153, 51.613610833883286, 50.446750447154045, 51.6679061204195, 53.362698778510094, 53.46419133245945, 52.390437349677086, 48.20966988801956, 48.49509537220001, 49.26120266318321, 50.279791206121445, 53.98551195859909, 56.97618708014488, 50.32475799322128, 36.65723338723183, 45.609591007232666, 48.83464515209198, 58.34915220737457, 59.10891003906727, 57.89968192577362, 49.49816174805164, 48.097621500492096, 43.355696350336075, 44.29005101323128, 43.81849251687527, 41.85210943222046, 41.47144205868244, 40.80170899629593, 40.06700702011585, 41.940808072686195, 41.50306776165962, 42.37194433808327, 40.73569513857365, 44.905944764614105, 49.36886988580227, 49.811139553785324, 51.22925005853176, 49.159915298223495, 50.53020156919956, 50.498594865202904, 50.72414316236973, 55.22227719426155, 53.31917591392994, 51.919452622532845, 53.59265483915806, 52.86095090210438, 57.621479853987694, 58.29397916793823, 58.03821109235287, 47.059251219034195, 44.36897657811642, 47.184287309646606, 43.642022386193275, 44.576270654797554, 53.42610977590084, 58.107701763510704, 54.092491418123245, 53.92502300441265, 52.37786762416363, 51.399754509329796, 50.402004048228264, 50.178313851356506, 47.08233118057251, 47.90145702660084, 47.7433817088604, 50.30225180089474, 48.63474167883396, 48.0437707901001, 47.89821580052376, 45.54222822189331, 42.77197167277336, 39.82948176562786, 40.62918685376644, 40.5463171005249, 39.61244881153107, 39.34288367629051, 38.3891424536705, 41.3019635528326, 41.58354364335537, 42.03753188252449, 43.69931571185589, 51.38962425291538, 57.12634362280369, 57.46166042983532, 57.810778096318245, 54.41537529230118, 58.706481233239174, 56.35625794529915, 56.58161625266075, 50.34702479839325, 50.45284911990166, 54.7592606395483, 55.21318048238754, 57.74862103164196, 56.9248366355896, 62.80773416161537, 59.85295571386814, 62.08200730383396, 58.911248445510864, 58.89001898467541, 54.828671514987946, 53.23477864265442, 51.60023555159569, 49.11866091191769, 49.509944915771484, 47.252398654818535, 49.42916505038738, 57.91936866939068, 61.267220824956894, 64.28325578570366, 63.89742448925972, 67.91448533535004, 69.26632359623909, 68.26366379857063, 67.53262102603912, 71.02663233876228, 66.33666560053825, 72.30407059192657, 23.08093998581171, 0.30820843821857125, 0.26978671085089445, 0.19495536689646542, 16.760604232549667, 75.96578970551491, 60.579955503344536, 76.26892983913422, 62.61421054601669, 50.48883318901062, 56.647725105285645, 48.18888120353222, 50.03052458167076, 65.29891848564148, 59.65795397758484, 1.52389754075557, 0.16159348364453763, 0.07296473122551106, 0.01703945832559839, 0.026457772473804653, 0.1789896033005789, 0.07642979646334425, 0.12357918792986311, 0.15510102733969688, 0.07856948985136114, 0.31664499489124864, 0.17873040080303326, 44.33671250939369, 81.92139253020287, 51.99423260986805, 46.335659846663475, 31.26851264387369, 65.4581831395626, 54.423883035779, 80.53136631846428, 68.7110061943531, 87.24090188741684, 43.17922241985798, 0.47208702424541116, 0.7734419661574066, 10.90675139799714, 2.9731110390275717, 4.156043138355017, 1.4847819646820426, 22.140011675655842, 66.17218002676964, 64.71846163272858, 69.55999463796616, 64.75088149309158, 64.45054560899734, 66.0576693713665, 61.171085983514786, 62.532731518149376, 67.12899908423424, 66.00965514779091, 64.40440088510513, 58.08117538690567, 57.72205285727978, 53.99858705699444, 53.96956041455269, 52.13894784450531, 55.14335922896862, 57.75615602731705, 55.54052151739597, 54.28439252078533, 51.69779531657696, 51.118299812078476, 52.24597290158272, 53.00890356302261, 56.514466255903244, 61.86609908938408, 51.86605788767338, 39.12268549203873, 49.28402043879032, 48.53940859436989, 59.37436379492283, 60.60730643570423, 59.70740832388401, 53.1587865203619, 50.29981233179569, 46.135832369327545, 45.11907532811165, 46.272503435611725, 44.16303522884846, 44.7653903067112, 43.867437690496445, 42.41565719246864, 43.532740250229836, 43.56548689305782, 45.15149898827076, 44.114413037896156, 47.07028962671757, 52.32756592333317, 52.83168487250805, 53.84148068726063, 52.21124656498432, 52.5568076223135, 54.48130175471306, 54.02498044073582, 58.06944161653519, 56.364366710186005, 53.70782285928726, 58.43920357525349, 55.096526741981506, 61.904933005571365, 60.31331621110439, 61.4539086073637, 48.43690529465675, 46.77343435585499, 48.358298912644386, 45.993750393390656, 48.41284118592739, 55.955869629979134, 63.08427192270756, 56.87045015394688, 57.257128804922104, 55.786835700273514, 54.95797097682953, 53.441806733608246, 52.65900693833828, 49.24082435667515, 49.02497313916683, 50.328379198908806, 52.64947324991226, 53.15811775624752, 50.42565017938614, 50.950774401426315, 49.06982973217964, 44.38261404633522, 43.17797988653183, 43.559734001755714, 43.76711547374725, 42.613033801317215, 42.44115762412548, 38.21143738925457, 43.830933049321175, 42.95256458222866, 45.01492291688919, 45.20615145564079, 54.55933056771755, 61.29354201257229, 61.342323794960976, 57.635029926896095, 56.19459182024002, 61.472444012761116, 59.83832649886608, 62.03647434711456, 52.69223615527153, 51.39610290527344, 57.38522753119469, 58.34474824368954, 60.259397104382515, 61.15451507270336, 63.60798642039299, 62.22739890217781, 64.01017963886261, 63.795050382614136, 61.10278084874153, 57.188211902976036, 55.93884654343128, 53.984546810388565, 51.642842665314674, 50.9767460078001, 49.133563712239265, 52.53091961145401, 61.286352798342705, 65.44146403670311, 68.73310580849648, 67.34562546014786, 73.76117080450058, 72.6979498565197, 72.70520746707916, 70.4058900475502, 72.98245579004288, 68.2709214091301, 73.92899259924889, 26.434945911169052, 0.3764449985465035, 0.4750116798095405, 0.5069695680867881, 19.17554944753647, 86.4347143471241, 68.29748198390007, 82.22422108054161, 68.70564088225365, 60.405381470918655, 64.88720297813416, 48.67774777114391, 64.36202555894852, 75.60550823807716, 74.69737216830254, 3.009067797102034, 0.3336406813468784, 0.28185073693748564, 0.19314571400173008, 0.14116947568254545], [0.0624604472250212, 0.04818259461899288, 0.01967454270925373, 0.02581376083981013, 0.09674234868725762, 0.19007329683518037, 0.08703368410351686, 29.23676736652851, 57.03206688165665, 40.498101487755775, 27.638134248554707, 42.34425142407417, 95.11106997728348, 43.69559571146965, 60.92715807259083, 57.899358943104744, 62.88841903209686, 55.551472529768944, 1.122729554772377, 0.16213547409279272, 1.3557439763098955, 0.6543633621186018, 0.9182454866822809, 0.25677086552605033, 8.507490791380405, 50.192274302244186, 57.25570008158684, 58.333668038249016, 60.46367034316063, 54.187212735414505, 61.368888169527054, 63.47715184092522, 61.68568097054958, 60.798527374863625, 57.17011347413063, 55.556978434324265, 52.361186519265175, 51.33322387933731, 51.97654075920582, 52.56175875663757, 55.459924042224884, 52.79135763645172, 53.047562688589096, 55.675744861364365, 53.880314603447914, 50.59787213802338, 47.38939270377159, 47.47351638972759, 48.80168192088604, 51.92706361413002, 56.67656175792217, 52.75593973696232, 54.81914162635803, 56.516955122351646, 55.77414818108082, 57.07211293280125, 56.65335260331631, 53.389171957969666, 47.988354563713074, 43.27294819056988, 41.85783192515373, 47.556621730327606, 41.514577344059944, 37.68747590482235, 38.39657485485077, 38.86049196124077, 36.70449145138264, 38.970062881708145, 39.970625191926956, 40.51958553493023, 40.11591039597988, 44.88044433295727, 45.698601230978966, 45.78158497810364, 47.12566785514355, 48.44528764486313, 47.757931128144264, 48.91599498689175, 47.77257174253464, 50.2439097315073, 51.835560724139214, 51.69124826788902, 51.84370368719101, 53.307115361094475, 52.97839879989624, 55.113606825470924, 54.30821344256401, 48.12651515007019, 44.204289615154266, 45.2022148668766, 42.034191861748695, 46.27485170960426, 55.88484764099121, 53.12956228852272, 51.0845348238945, 50.199767500162125, 49.84612047672272, 48.63625019788742, 49.76760149002075, 47.472969219088554, 47.25060895085335, 45.652619898319244, 48.06708633899689, 46.584588289260864, 45.86614564061165, 44.665368273854256, 43.31157311797142, 41.468683406710625, 40.777318105101585, 38.24497438967228, 39.27584767341614, 37.78226561844349, 36.94449797272682, 38.731424286961555, 36.9380497187376, 40.76363503932953, 44.132788851857185, 38.789257183671, 40.925076976418495, 41.90725587308407, 52.01644241809845, 54.27112743258476, 55.23808814585209, 51.273475885391235, 50.87209962308407, 57.020017728209496, 55.16174644231796, 52.21842058002949, 45.06597317755222, 53.665816113352776, 49.38248075544834, 51.64004981517792, 56.898686438798904, 56.379417702555656, 54.92998547852039, 57.27646976709366, 59.354620054364204, 58.02230514585972, 54.30252894759178, 54.921489134430885, 51.789032220840454, 53.06009441614151, 47.639696672558784, 49.50866058468819, 46.94148413836956, 48.70677061378956, 50.369572788476944, 55.641436502337456, 58.88206221163273, 60.24799011647701, 59.571478217840195, 61.56129464507103, 60.48402965068817, 69.10685375332832, 64.49864342808723, 65.61212807893753, 13.31721380352974, 0.345605734619312, 0.3680407104548067, 0.07847803499316797, 23.700426444411278, 69.84274506568909, 54.71155799925327, 69.27510112524033, 44.14859600365162, 39.76979836821556, 50.81472270190716, 25.468524768948555, 34.27170619368553, 66.48244097828865, 49.25806403160095, 2.135858265683055, 0.0911142049881164, 0.10106460933457129, 0.048284573131240904, 0.08903000940335914, 0.05432053811091464, 0.08408424822846428, 0.05519976417417638, 0.04679183955886401, 0.036804520786972716, 0.2088801353238523, 0.1498572196578607, 40.84375374019146, 64.90368649363518, 49.42679777741432, 32.546279579401016, 36.02647863328457, 94.90807726979256, 48.192137628793716, 70.27098968625069, 65.66654115915298, 68.84434103965759, 62.41268076002598, 1.217788578942418, 0.06643379456363618, 1.1101655289530754, 2.009552805684507, 2.5076165422797203, 1.0997918481007218, 9.895467963069677, 54.45529215037823, 56.28909654915333, 60.68966321647167, 59.13473345339298, 55.47350071370602, 61.026404947042465, 64.31357055902481, 61.83898754417896, 65.08701145648956, 58.687410056591034, 57.28006437420845, 55.7777351886034, 53.901411071419716, 53.006315901875496, 55.51467910408974, 57.38528452813625, 55.55114954710007, 57.20546677708626, 57.69760116934776, 56.146437004208565, 51.8574133515358, 49.350087493658066, 48.95212724804878, 50.470339581370354, 54.78699155151844, 58.51320460438728, 54.02293235063553, 53.248503506183624, 56.87572427093983, 58.62553037703037, 60.02501428127289, 59.03897479176521, 56.16608954966068, 49.92509163916111, 44.58495318889618, 44.53672617673874, 48.913506120443344, 43.679229989647865, 40.17968237400055, 39.963618367910385, 41.139301881194115, 40.7665228843689, 40.911948680877686, 41.95045955479145, 41.80730223655701, 43.36920082569122, 47.340371534228325, 47.41893991827965, 49.72511976957321, 50.35674847662449, 50.62900386750698, 50.84102489054203, 49.06582474708557, 50.90273357927799, 54.38284903764725, 52.44797006249428, 53.03177833557129, 54.64225731790066, 56.43947347998619, 55.08369103074074, 58.52142736315727, 55.77045477926731, 48.95738996565342, 44.2596298456192, 46.55965402722359, 44.0681467205286, 49.758067801594734, 58.16011235117912, 56.94231189787388, 53.49689617753029, 54.36365246772766, 51.925019323825836, 51.151912808418274, 51.30017325282097, 50.239574164152145, 50.89062362909317, 47.583391293883324, 51.055812165141106, 50.58694772422314, 48.142744079232216, 46.77582822740078, 46.72970250248909, 44.26923952996731, 41.80479057133198, 41.77957892417908, 39.69597972929478, 39.86250199377537, 39.64324615895748, 40.037106424570084, 39.67444248497486, 43.553080558776855, 47.0833495259285, 41.41735576093197, 43.141916021704674, 43.73322509229183, 53.395886197686195, 56.48747630417347, 56.63042463362217, 55.25848925113678, 54.41409096121788, 58.12588758766651, 57.06783816218376, 54.710068479180336, 48.17549832165241, 57.04468980431557, 51.66074350476265, 55.465129762887955, 57.8236898034811, 59.553315192461014, 56.80467188358307, 60.576611682772636, 60.437922924757004, 61.27268113195896, 56.76176458597183, 57.98002861440182, 53.95512118935585, 55.477023124694824, 50.62530666589737, 50.98897375166416, 48.80563750863075, 51.916143000125885, 53.588699251413345, 59.212640672922134, 60.873132571578026, 62.2444561868906, 63.024432733654976, 68.1935727596283, 63.265738785266876, 70.05374014377594, 66.10433846712112, 67.94667720794678, 14.684458337724209, 0.2814187773037702, 0.38219658366870135, 0.42044402507599443, 26.892564855515957, 75.7087790966034, 62.69755907356739, 74.51792299747467, 51.211827993392944, 47.501114308834076, 60.1858102530241, 28.07442683726549, 40.829550102353096, 76.32357850670815, 60.24642080068588, 3.4811855759471655, 0.19382921716896817, 0.16939526656642556, 0.03665606156573631, 0.11428509445977397, 0.18400610599201173, 0.1672159499139525, 0.16995870508253574, 0.18140925705665722, 0.15897297504125163, 0.38534985040314496, 0.22780390660045668, 50.981062576174736, 77.16528654098511, 57.219142243266106, 39.264885261654854, 55.41384771466255, 103.90169307589531, 57.04160816967487, 77.19635367393494, 71.3998407125473, 73.83997097611427, 67.00487494468689, 1.793409122619778, 0.3784395946422592, 6.752234827727079, 5.901583973318338, 4.221473727375269, 2.6937937270849943, 12.074259649962187, 57.35873535275459, 57.0376031845808, 61.61805599927902, 62.000228092074394, 57.27362371981144, 62.03580558300018, 66.22722387313843, 64.96517479419708, 67.94227704405785, 61.04181312024593, 58.79598543047905, 59.06862460076809, 57.78882287442684, 57.91790954768658, 58.1266475468874, 59.85471501946449, 60.10320648550987, 59.91768144071102, 62.26092830300331, 60.81959344446659, 54.08909060060978, 52.245532125234604, 52.73677736520767, 54.03348058462143, 56.55966863036156, 61.71988293528557, 57.2929684817791, 56.177420541644096, 60.46150825917721, 60.87051071226597, 60.89722327888012, 62.92624220252037, 59.33427594602108, 53.47146034240723, 47.664566338062286, 46.79321609437466, 51.132275462150574, 48.32624763250351, 41.971472427248955, 42.490752562880516, 42.8581016510725, 42.792950347065926, 42.0033223181963, 43.10068063437939, 44.24012929201126, 45.71103036403656, 49.48297776281834, 49.97182913124561, 51.058513820171356, 51.42029620707035, 54.9130991846323, 51.32486812770367, 53.833022341132164, 52.65364542603493, 57.58294612169266, 55.991724506020546, 56.30206145346165, 57.65788950026035, 59.29356873035431, 59.11584846675396, 59.28792983293533, 57.06376478075981, 51.04702703654766, 47.0457049459219, 49.16032187640667, 45.04309460520744, 51.75734952092171, 60.276530385017395, 57.8753100335598, 55.87151415646076, 55.78306630253792, 56.6012080013752, 55.19064389169216, 54.598384872078896, 52.649553045630455, 53.195089772343636, 49.8599973320961, 52.83743776381016, 51.67491294443607, 51.78228758275509, 51.34220279753208, 50.937748700380325, 46.61535903811455, 46.69437579810619, 44.00917008519173, 42.31209754943848, 40.73768623173237, 39.89012271165848, 43.58104705810547, 41.48042477667332, 46.19639731943607, 48.947833478450775, 43.401248306035995, 45.314191058278084, 47.084470465779305, 56.57313130795956, 58.451780900359154, 59.16629455983639, 57.327402234077454, 55.49507975578308, 59.08760838210583, 58.9141970872879, 57.06789895892143, 50.4545172303915, 58.17481376230717, 54.34514366090298, 57.97577664256096, 59.866764172911644, 60.44730082154274, 57.874766662716866, 60.96063807606697, 63.700560852885246, 64.88429993391037, 59.080814346671104, 61.18847385048866, 56.610053926706314, 60.15316620469093, 53.05113449692726, 53.92646312713623, 51.10521711409092, 54.32831056416035, 56.106280758976936, 63.115251660346985, 64.52438324689865, 67.88945987820625, 67.21267059445381, 69.99077752232552, 67.8819590806961, 75.3547140955925, 68.11239391565323, 71.0019488632679, 19.306448623538017, 0.45559451391454786, 0.7174266187939793, 0.7466370763722807, 29.85692448914051, 83.95106121897697, 70.38996890187263, 81.24310612678528, 59.913155883550644, 57.4840222299099, 68.57214644551277, 34.7938247770071, 54.36662010848522, 82.62935534119606, 78.95049914717674, 5.005813390016556, 0.4109512735158205, 0.34599812293890864, 0.15128349390579388, 0.24476394028170034], [0.043458642830955796, 0.02956255841127131, 0.03042939988517901, 0.04222196504997555, 0.03923588192265015, 0.24319560412550345, 0.14444427652051672, 26.117501445114613, 63.00503097474575, 40.57808339595795, 25.55655464529991, 63.95218715071678, 101.68708071112633, 45.20758397877216, 50.44098995625973, 65.6373131275177, 55.31511381268501, 70.5605037510395, 3.331292406655848, 0.04682980041252449, 0.4855350963771343, 2.177182473242283, 2.2938530752435327, 0.296773545560427, 3.827758328989148, 43.15304182469845, 57.56705917418003, 57.38949090242386, 56.69697806239128, 59.95357431471348, 62.86918446421623, 61.175672337412834, 58.8306699693203, 57.05853246152401, 57.317480966448784, 52.41112343966961, 52.83185966312885, 56.98072023689747, 55.205919072031975, 54.19679582118988, 54.568320885300636, 54.79111813008785, 55.92924825847149, 55.071178302168846, 53.9537038654089, 51.30357787013054, 48.76428432762623, 49.34764422476292, 50.65390393137932, 53.94128993153572, 54.59419749677181, 52.1570310741663, 54.114374443888664, 53.552692383527756, 56.24212346971035, 56.22526377439499, 53.861672803759575, 52.3679805546999, 45.897535756230354, 44.99703727662563, 46.12102456390858, 43.89540039002895, 36.82158596813679, 39.28410843014717, 38.618213161826134, 38.866697028279305, 37.748759016394615, 37.172162756323814, 38.34418706595898, 35.802636444568634, 40.67118600010872, 43.35405483841896, 45.60311995446682, 46.40681862831116, 46.68832652270794, 47.8530590236187, 47.02306196093559, 48.52488577365875, 47.57424898445606, 51.34764790534973, 51.84634454548359, 52.950147315859795, 52.70750753581524, 52.39212065935135, 55.429662466049194, 54.72732335329056, 53.30026812851429, 50.54706506431103, 47.20483660697937, 45.296605601906776, 45.558054372668266, 48.73230144381523, 55.709943026304245, 52.64387995004654, 49.687520787119865, 47.77645133435726, 46.76647312939167, 48.83292764425278, 47.84073628485203, 47.876268178224564, 47.37828589975834, 44.926961436867714, 46.27181947231293, 46.12385921180248, 42.73882605135441, 43.36710333824158, 40.95770202577114, 42.765363827347755, 38.98567624390125, 38.146012499928474, 37.80856400728226, 38.22482027113438, 39.927421510219574, 37.54423879086971, 36.18452735245228, 40.69079674780369, 47.75231882929802, 41.5185671299696, 37.79832735657692, 42.20628082752228, 46.617388129234314, 52.992724031209946, 53.382902294397354, 55.56156098842621, 52.41903081536293, 50.638586953282356, 54.61122818291187, 57.20898158848286, 52.49844655394554, 50.5177990347147, 50.75828433036804, 49.675627425312996, 52.10359074175358, 54.419368878006935, 55.45066773891449, 55.95384053885937, 54.48662146925926, 58.885394632816315, 58.081787154078484, 56.230226308107376, 54.35617446899414, 55.44173821806908, 55.77302344143391, 53.83866123855114, 51.43852382898331, 49.42897506058216, 48.89304421842098, 49.51950900256634, 50.01464903354645, 52.18033902347088, 56.769759356975555, 56.942239701747894, 62.16613858938217, 61.02558419108391, 68.76624763011932, 58.992206901311874, 5.313172722235322, 0.2452796883881092, 0.36381480284035206, 0.596545486478135, 28.68667658418417, 68.15676033496857, 57.95487776398659, 69.48750972747803, 51.96535415947437, 41.7732522636652, 47.91441813111305, 58.481727093458176, 45.24870537221432, 64.32117015123367, 56.27354398369789, 2.2217906545847654, 0.059543079551076517, 0.08273546161944978, 0.06313506688456982, 0.07692638231674209, 0.03368566001881845, 0.051199057561461814, 0.0531339664303232, 0.08730151035706513, 0.012497457028075587, 0.19078158773481846, 0.23690195434028283, 33.86956997215748, 71.88632100820541, 46.69722944498062, 34.044406190514565, 73.57187256217003, 103.36748734116554, 52.69810304045677, 57.2713590413332, 70.28110474348068, 61.978918835520744, 75.13669699430466, 3.311794465407729, 0.18491974915377796, 0.31939337553922087, 3.3394641056656837, 2.9563092906028032, 1.1150130000896752, 4.475061194971204, 46.51958517730236, 58.3792731910944, 57.22727760672569, 56.883878633379936, 63.059873431921005, 63.7205021828413, 62.141325920820236, 62.50733368098736, 59.35330532491207, 59.512265995144844, 54.123284965753555, 54.987012818455696, 57.02245719730854, 56.4525181800127, 58.0846294015646, 55.81240072846413, 58.81498821079731, 58.88130605220795, 56.85799062252045, 56.78329423069954, 54.5856973528862, 50.744479671120644, 50.80493062734604, 52.52376079559326, 56.19887039065361, 56.65552608668804, 53.17220740020275, 56.56419038772583, 55.162065625190735, 58.23895052075386, 57.13155694305897, 58.159967958927155, 53.41297008097172, 47.21847787499428, 46.54066264629364, 49.57128502428532, 46.255157366395, 40.33427707850933, 40.041430592536926, 40.70412263274193, 41.478536278009415, 40.02812370657921, 40.4049076884985, 39.06047523021698, 38.90704706311226, 41.55137836933136, 44.872913137078285, 47.69962705671787, 49.33144569396973, 49.82909359037876, 49.4433268904686, 50.39947338402271, 52.195249423384666, 49.4933246076107, 51.797418370842934, 54.110190868377686, 54.62350532412529, 55.280471071600914, 57.882354855537415, 57.55677692592144, 54.533168971538544, 55.10879248380661, 54.10683564841747, 47.21795730292797, 48.23858633637428, 48.33953931927681, 50.63059598207474, 56.992138624191284, 54.73607048392296, 52.209783643484116, 52.60959818959236, 50.275383442640305, 51.34874984622002, 50.59389375150204, 50.60888014733791, 47.93662413954735, 47.121336087584496, 48.8781376183033, 46.90633602440357, 46.25488378107548, 46.12125255167484, 46.05779215693474, 45.22687554359436, 40.5698948353529, 39.980991035699844, 38.93621809780598, 39.11545068025589, 41.948301270604134, 39.98636394739151, 39.430294185876846, 42.12927795946598, 49.82722029089928, 44.105836898088455, 40.48672489821911, 44.494069665670395, 47.075776532292366, 56.58645339310169, 55.77316403388977, 56.59219868481159, 52.94058322906494, 53.01108464598656, 56.363363564014435, 56.891432628035545, 53.90350855886936, 53.02023835480213, 53.58256638050079, 51.045434921979904, 54.88066412508488, 56.411761566996574, 57.21568442881107, 56.594292372465134, 56.64954520761967, 62.16503284871578, 62.126480117440224, 60.72830334305763, 57.65281677246094, 56.80201202630997, 58.61919991672039, 56.42099507153034, 55.259993970394135, 52.7442629635334, 53.311196342110634, 51.74595393240452, 53.753701597452164, 56.03720046579838, 60.59763215482235, 60.05497187376022, 64.21463146805763, 65.62838360667229, 71.55375525355339, 62.102549001574516, 6.382417771965265, 0.335522114764899, 0.46712223440408707, 1.09548335429281, 33.027329966425896, 74.40622419118881, 64.30339470505714, 76.5098749101162, 56.92995496094227, 46.5484294295311, 56.18035018444061, 44.67951111495495, 49.96932506561279, 71.1105926334858, 70.28882592916489, 3.2896844018250704, 0.18536420655436814, 0.08197831513825804, 0.03427048723096959, 0.061100528400857, 0.16434336343081668, 0.1421621278859675, 0.20615053101209924, 0.2194606527336873, 0.10591296362690628, 0.2542383607942611, 0.2620421029860154, 45.372126549482346, 82.97147378325462, 57.99045905470848, 39.51271176338196, 75.53714230656624, 104.86665889620781, 61.550674214959145, 63.93255740404129, 77.24378272891045, 68.64727601408958, 80.7948137819767, 4.256577668711543, 0.30016646662261337, 2.822396163828671, 6.208354337140918, 8.301834426820278, 1.987507101148367, 6.065728040412068, 51.06287978589535, 58.20052318274975, 61.9990311563015, 59.53534975647926, 64.86126556992531, 67.72938966751099, 65.98282858729362, 66.65106073021889, 61.70828975737095, 63.2122490555048, 57.33820125460625, 58.02858620882034, 61.241237819194794, 58.61709862947464, 60.56617744266987, 60.53330920636654, 62.36816614866257, 61.39435060322285, 58.97128142416477, 59.84535992145538, 56.97804518043995, 53.85196432471275, 55.25806747376919, 55.20212307572365, 58.60777772963047, 58.858564272522926, 55.31204357743263, 58.92357498407364, 58.681820556521416, 59.97620590031147, 59.065387174487114, 59.988129660487175, 56.549169793725014, 49.973793625831604, 48.78960996866226, 52.3726125061512, 49.742804020643234, 41.728015691041946, 42.789496332407, 42.74493232369423, 42.58677341043949, 42.60532021522522, 41.90133959054947, 42.787444442510605, 39.744522124528885, 43.473091050982475, 48.29646483063698, 50.750878527760506, 50.54788962006569, 51.51576988399029, 51.73743098974228, 51.87176138162613, 53.36022511124611, 51.280661299824715, 56.15173012018204, 55.85114344954491, 55.27296267449856, 58.48298102617264, 59.38946418464184, 61.52300789952278, 57.997682467103004, 58.54200705885887, 55.58658264577389, 49.020318388938904, 50.99876582622528, 52.66361229121685, 50.59428513050079, 59.89585921168327, 57.21780851483345, 56.08513109385967, 56.71042934060097, 52.54507765173912, 54.699322655797005, 55.35512946546078, 54.76657524704933, 50.70932015776634, 48.564745634794235, 50.65163545310497, 50.316295847296715, 49.182603880763054, 49.23061430454254, 46.54179498553276, 48.04292343556881, 43.627522364258766, 41.997162848711014, 41.508702859282494, 41.39606550335884, 45.7559135556221, 41.48810036480427, 40.62343776226044, 44.56397831439972, 52.87305325269699, 47.07274429500103, 43.719112649559975, 46.13473802804947, 50.656803175807, 58.55405241250992, 57.60056957602501, 57.33918160200119, 57.171610593795776, 56.82737186551094, 59.763451516628265, 59.026234075427055, 56.99061870574951, 55.44157862663269, 55.84214173257351, 52.89490967988968, 58.370404466986656, 58.57579104602337, 58.81656892597675, 60.063152834773064, 58.65367166697979, 64.60550129413605, 64.69821631908417, 63.11746694147587, 60.92948354780674, 59.591442346572876, 62.198649644851685, 61.4364143460989, 59.679346829652786, 55.21424822509289, 56.550970897078514, 54.725476652383804, 56.14658139646053, 57.635801285505295, 64.47272881865501, 61.944754868745804, 68.5104301571846, 68.00917625427246, 74.23192754387856, 68.09346333146095, 8.12770402058959, 0.5061255977489054, 0.7764471299014986, 1.7180002690292895, 38.63991379737854, 81.31304517388344, 71.88643500208855, 84.5821313560009, 65.70893928408623, 57.1086023747921, 70.159952044487, 68.54957565665245, 64.31418612599373, 79.92115706205368, 83.9761246740818, 4.145514378324151, 0.48168670444283634, 0.20934660482453182, 0.13596218166640028, 0.2933548571309075], [0.026510079042054713, 0.07402954244753346, 0.030426329249166884, 0.0978957129700575, 0.054232994370977394, 0.2556535176699981, 0.23153398535214365, 35.174317359924316, 59.20036353170872, 47.06020876765251, 25.176565535366535, 37.536472007632256, 68.95838811993599, 35.99729999899864, 55.40889658033848, 66.59854754805565, 50.01752927899361, 70.79733744263649, 11.425126232206821, 0.22321586060570553, 0.289634233340621, 0.8417522662784904, 1.387419670354575, 0.892854833509773, 4.232455138117075, 47.67793022096157, 60.76125517487526, 56.87805734574795, 63.471645936369896, 61.78924821317196, 58.70157569646835, 59.35543701052666, 57.779650166630745, 56.45657256245613, 56.01098567247391, 54.64224971830845, 54.973033368587494, 55.48642382025719, 54.418844506144524, 58.812487944960594, 58.78965117037296, 52.926094606518745, 54.21217359602451, 54.84328553080559, 51.13606385886669, 48.17811258137226, 47.341735661029816, 49.68178689479828, 50.951108783483505, 52.58003957569599, 54.24870863556862, 56.41745746135712, 58.36644887924194, 52.860570922493935, 55.469579324126244, 53.20350632071495, 53.67405407130718, 48.2448597997427, 45.30387461185455, 40.80632574856281, 46.695998311042786, 46.7291097342968, 45.59031084179878, 42.92642578482628, 39.12479057908058, 38.003193363547325, 37.262795493006706, 40.2690801769495, 38.74931372702122, 37.896954864263535, 40.52825666964054, 41.97501763701439, 46.54599376022816, 46.622191071510315, 46.03095419704914, 47.04711467027664, 49.15480837225914, 49.973178058862686, 47.78648279607296, 47.707021459937096, 53.94855514168739, 53.090291395783424, 54.907304495573044, 51.24450244009495, 50.61592876911163, 52.75817021727562, 53.30238461494446, 51.79353877902031, 47.78413452208042, 44.53916184604168, 47.713948488235474, 46.457899287343025, 56.1068507283926, 53.07825364172459, 52.58869171142578, 51.78482584655285, 48.420604169368744, 50.22303745150566, 48.83623346686363, 47.22723640501499, 45.65744183957577, 44.54304903745651, 46.89590558409691, 46.33777253329754, 43.279575034976006, 43.3745851367712, 41.22648440301418, 40.18965303897858, 37.764220386743546, 36.574979200959206, 36.20277017354965, 38.41131806373596, 38.03654037415981, 38.15648473799229, 39.374862760305405, 37.316106632351875, 46.268988624215126, 46.74831010401249, 39.51279915869236, 43.75287003815174, 42.80092611908913, 48.6111905425787, 56.36318497359753, 55.077531561255455, 55.112398490309715, 51.859385445714, 48.482981622219086, 53.612778559327126, 53.87929625809193, 56.29635415971279, 53.31781178712845, 52.607679292559624, 48.18412385880947, 52.14259184896946, 54.02100205421448, 55.81064522266388, 53.75574588775635, 55.55882513523102, 59.06759865581989, 58.441149070858955, 57.636299058794975, 56.269303411245346, 55.47378949820995, 57.012942507863045, 58.9532969892025, 55.20004838705063, 54.74623493850231, 52.877567410469055, 56.95979855954647, 51.41787953674793, 57.47068874537945, 59.86682116985321, 64.66201186180115, 62.71725341677666, 72.21927434206009, 46.850308030843735, 2.8162647178396583, 0.17405297054210678, 0.31397320388350636, 1.2436825269833207, 41.31157323718071, 64.58859980106354, 61.065679639577866, 66.95246815681458, 61.548975706100464, 42.05159492790699, 46.45259477198124, 54.48962710797787, 34.39210653305054, 61.42098717391491, 52.83470191061497, 1.3843648717738688, 0.02244293351395754, 0.1267934072529897, 0.07101019626134075, 0.0832765837549232, 0.00334511399614712, 0.07496631835238077, 0.06924147281097248, 0.0030175105302987504, 0.018696071092563216, 0.31674248341005296, 0.34558899176772684, 44.043185859918594, 66.2897077202797, 55.16741193830967, 28.58368881046772, 67.69538149237633, 86.31698906421661, 40.86019165813923, 63.39534603059292, 72.11335882544518, 57.815717831254005, 77.64656111598015, 12.368249874562025, 0.23251341248396784, 0.11418524591135792, 1.9099800987169147, 1.1486320523545146, 1.1495513655245304, 5.466173887252808, 49.12569813430309, 61.84921659529209, 58.94728571176529, 64.9399821460247, 62.95778430998325, 62.46176652610302, 58.95629122853279, 60.62179885804653, 58.88865485787392, 58.25559362769127, 57.494163885712624, 55.99081635475159, 55.90564012527466, 58.44340994954109, 58.099505603313446, 62.30248287320137, 53.858670964837074, 56.24343819916248, 55.559372305870056, 55.75813204050064, 51.414254531264305, 50.457245483994484, 53.463613763451576, 53.413551449775696, 55.06120003759861, 55.870385617017746, 58.2596480101347, 60.71031130850315, 56.46495871245861, 57.14643694460392, 54.60187688469887, 55.40775664150715, 49.75565493106842, 47.79285125434399, 43.344616144895554, 47.93304093182087, 48.91803927719593, 49.43207949399948, 44.17873218655586, 39.909269884228706, 40.003029853105545, 39.018529281020164, 42.22175359725952, 40.49750491976738, 39.07697394490242, 41.73934668302536, 44.01243411004543, 47.419631481170654, 48.800203800201416, 48.305002972483635, 49.74413014948368, 52.095295786857605, 51.79071933031082, 49.771891459822655, 49.96736437082291, 55.96479535102844, 57.109404131770134, 55.63628777861595, 53.30393873155117, 53.328553810715675, 55.31283013522625, 55.881876200437546, 54.75498586893082, 50.3436353802681, 47.85433195531368, 50.74708253145218, 49.99177426099777, 57.90088266134262, 54.581585973501205, 54.095861837267876, 54.25661601126194, 51.902414336800575, 53.03012162446976, 51.61834917962551, 50.90969480574131, 48.441062271595, 46.611198261380196, 51.50404371321201, 48.829093649983406, 45.68579211831093, 46.558992862701416, 44.650248885154724, 43.394043892621994, 39.243370816111565, 37.74155840277672, 38.33568312227726, 41.67667284607887, 39.780160412192345, 40.79423479735851, 40.26837721467018, 40.28275944292545, 47.48855218291283, 48.572626411914825, 40.978209525346756, 45.42664222419262, 45.479504987597466, 49.28548336029053, 56.68221205472946, 55.88857904076576, 56.14074870944023, 52.96236366033554, 53.14782030880451, 54.058156460523605, 54.09395053982735, 57.29145236313343, 55.34752607345581, 55.21619372069836, 50.97132749855518, 55.25054007768631, 56.83387711644173, 57.11916960775852, 56.49390555918217, 55.20316421985626, 61.925402507185936, 61.44666239619255, 60.16579292714596, 58.43065023422241, 57.382028102874756, 57.634927332401276, 62.227573692798615, 57.92792201042175, 57.96412646770477, 56.85868978500366, 59.50359106063843, 55.3967410326004, 57.62489967048168, 62.10088849067688, 67.16885134577751, 65.8600115776062, 74.03414815664291, 50.06105214357376, 3.7654637591913342, 0.3274252242408693, 0.5079274135641754, 1.703853984363377, 45.84699086844921, 72.0749580860138, 67.91296541690826, 72.73239120841026, 67.14111283421516, 50.098366141319275, 61.97806008160114, 59.65318903326988, 42.79810667037964, 68.1736010313034, 63.69791999459267, 2.0888517005369067, 0.09682365096523426, 0.13166976277716458, 0.03898419367033057, 0.12206445710035041, 0.12659283442189917, 0.23517677269410342, 0.1449746746220626, 0.23622608045116067, 0.10522869604756124, 0.42688337329309434, 0.3683907072991133, 57.65317015349865, 80.89614674448967, 65.65959513187408, 39.779092669487, 52.47616834938526, 78.33693847060204, 51.399830505251884, 71.46588116884232, 79.43849176168442, 65.37160098552704, 82.79968500137329, 15.500959474593401, 0.49560440762434155, 0.3643909766105935, 4.008213495835662, 7.28288110345602, 2.794654327444732, 5.819840859621763, 54.93664272129536, 63.51065844297409, 62.45243422687054, 67.38360062241554, 67.48047262430191, 63.41269209980965, 63.373098224401474, 62.06229776144028, 61.93726547062397, 60.593178793787956, 60.5881554633379, 58.86037677526474, 58.81992794573307, 60.37097051739693, 60.55890083312988, 62.498567551374435, 56.302779614925385, 57.29599691927433, 59.16923180222511, 55.729211792349815, 54.65544641017914, 53.02193686366081, 58.19051831960678, 54.36662010848522, 57.96753488481045, 56.97999447584152, 61.819866970181465, 62.96332821249962, 57.94261962175369, 59.011107087135315, 58.16402234137058, 59.505312368273735, 53.371616899967194, 49.87918250262737, 44.1851956397295, 50.880079194903374, 50.743339732289314, 53.51402185857296, 46.342932656407356, 42.98844985663891, 43.20218078792095, 40.596603602170944, 44.15296956896782, 43.62260922789574, 42.71014139056206, 43.83325472474098, 48.471988812088966, 49.71318461000919, 52.50403605401516, 52.74849213659763, 50.879995599389076, 55.96974268555641, 55.83665482699871, 52.96251945197582, 52.733110561966896, 57.38654986023903, 59.526028856635094, 58.93070340156555, 58.16500648856163, 58.51681441068649, 57.049154564738274, 59.20074351131916, 58.68218153715134, 50.6147014349699, 50.27353674173355, 54.43745590746403, 50.142895951867104, 60.428389236330986, 57.67110899090767, 58.14067639410496, 57.81154565513134, 54.71888020634651, 55.9733334928751, 55.13105168938637, 51.87368407845497, 51.30578175187111, 48.353495970368385, 53.012463971972466, 51.5427066385746, 48.625766560435295, 48.20761039853096, 46.42101086676121, 44.645533338189125, 39.97591830790043, 39.717459976673126, 39.352611154317856, 41.85208663344383, 42.15106599032879, 43.06627728044987, 43.25942851603031, 41.68082982301712, 49.268958047032356, 51.44997641444206, 44.9639068543911, 49.81920272111893, 49.77710098028183, 54.091651663184166, 59.73421968519688, 58.73200446367264, 58.378532230854034, 54.738658145070076, 54.72589083015919, 55.946411937475204, 55.09143501520157, 59.38636735081673, 58.045499101281166, 57.84835807979107, 53.448828756809235, 57.08195060491562, 60.414162799715996, 60.02712696790695, 58.00942003726959, 58.27145777642727, 64.0164265036583, 65.56928157806396, 63.90011474490166, 61.290331184864044, 61.43812045454979, 60.45938417315483, 65.96284925937653, 60.755498483777046, 59.67956721782684, 59.45673957467079, 63.33342835307121, 59.23098988831043, 60.3361339867115, 67.0005051791668, 71.05349689722061, 70.78610524535179, 77.50023856759071, 54.389536678791046, 4.943461585789919, 0.3027293103514239, 0.7781769870780408, 2.3736077081412077, 50.83047665655613, 78.96069020032883, 74.50035274028778, 80.02948924899101, 74.74016547203064, 58.51695120334625, 70.60931593179703, 69.34369504451752, 51.134274154901505, 77.62008413672447, 75.49788281321526, 3.2278933050110936, 0.4244683950673789, 0.19546856201486662, 0.22420125460484996, 0.15340036625275388], [0.0390115863410756, 0.05692724276741501, 0.03920943177945446, 0.08735663708648644, 0.09449446501093917, 0.2787887246813625, 0.25030269229318947, 36.3946408778429, 65.80711841583252, 50.2845561504364, 36.17484547197819, 21.800138913094997, 30.213233269751072, 45.409942120313644, 55.48785634338856, 67.1455965936184, 53.619329407811165, 69.8028016090393, 23.708115331828594, 0.08629249379737303, 0.30665429192595184, 2.7678189799189568, 0.20514493575319648, 1.4310044003650546, 6.853922596201301, 51.69049970805645, 61.01720564067364, 61.87766946852207, 61.16580806672573, 60.707776844501495, 60.2617833763361, 59.556856602430344, 58.254088908433914, 57.44182549417019, 57.57400520145893, 57.05109626054764, 55.242594704031944, 60.41265428066254, 58.576611801981926, 56.080271154642105, 53.53939689695835, 54.01369124650955, 54.86631989479065, 53.03973890841007, 50.05300797522068, 53.40480051934719, 49.67404291033745, 65.81170096993446, 60.678457617759705, 52.3479176312685, 57.04234533011913, 54.77976813912392, 54.193455800414085, 53.69748741388321, 52.5793632119894, 48.48499171435833, 47.351432740688324, 45.966490656137466, 46.24513350427151, 42.37354405224323, 49.57886941730976, 49.98796306550503, 54.91319417953491, 41.32675722241402, 35.6637728959322, 36.54225155711174, 37.53074571490288, 37.46897242963314, 37.85455673933029, 36.06463998556137, 38.065475821495056, 41.756552159786224, 43.529396429657936, 44.88671399652958, 46.3277068734169, 43.88693064451218, 47.56508767604828, 49.536323100328445, 48.33008922636509, 49.82721649110317, 51.28711335361004, 50.84824450314045, 52.74431996047497, 50.53535409271717, 50.86399845778942, 52.94024124741554, 53.686627596616745, 50.27492366731167, 48.83053757250309, 46.68472431600094, 44.576270654797554, 47.50590205192566, 52.836347222328186, 51.86927251517773, 48.73440273106098, 47.45720386505127, 50.53345039486885, 49.46544550359249, 49.917112067341805, 47.42854580283165, 46.156541258096695, 47.36725889146328, 46.81047856807709, 41.91976860165596, 43.07024426758289, 44.12194803357124, 43.701181411743164, 40.240072533488274, 39.13041427731514, 36.318409368395805, 37.77803264558315, 38.21916997432709, 38.63842807710171, 34.94579002261162, 38.308924958109856, 37.50556826591492, 43.572930693626404, 49.14704538881779, 44.94657978415489, 43.76341827213764, 44.52173598110676, 45.35997100174427, 50.99025808274746, 54.265169352293015, 55.918988808989525, 52.92461648583412, 56.891159042716026, 53.52133646607399, 52.9823961853981, 54.89687405526638, 56.01940602064133, 56.219453886151314, 54.15907524526119, 51.37944079935551, 52.778335735201836, 54.14369747042656, 57.45355926454067, 51.06499247252941, 54.620970860123634, 55.59570595622063, 58.17403860390186, 58.46706748008728, 71.45075038075447, 71.41247123479843, 58.009199649095535, 60.547566041350365, 59.65319663286209, 59.35647435486317, 61.44252061843872, 62.39634543657303, 59.75832179188728, 62.14599587023258, 68.64221468567848, 61.1666402220726, 74.4678644835949, 31.33201103657484, 0.5603307578712702, 0.10593870872980915, 0.3467949520563707, 2.787100332789123, 49.01819810271263, 64.80985432863235, 62.84895434975624, 67.62764632701874, 62.7151483297348, 44.95990946888924, 38.46248611807823, 40.68221680819988, 44.46717090904713, 61.58722445368767, 61.02685712277889, 1.069702806416899, 0.15729255974292755, 0.09949518222128972, 0.027139581688970793, 0.09208019924699329, 0.023725218125036918, 0.024980063681141473, 0.02262173544295365, 0.1194221070909407, 0.01594882593053626, 0.4882924124831334, 0.3620644030161202, 46.874892711639404, 70.01298353075981, 57.20992773771286, 35.13720475137234, 34.94322516024113, 44.7224298119545, 47.81531564891338, 63.99650037288666, 72.13013112545013, 57.48507857322693, 75.60426190495491, 25.908543057739735, 0.06608946030610241, 0.28395282570272684, 2.070762771181762, 1.1904668575152755, 1.3786018872633576, 7.669151751324534, 53.41041661798954, 62.74142771959305, 63.54639932513237, 62.63979837298393, 62.01396815478802, 63.08832250535488, 60.45595295727253, 61.63276121020317, 58.87798883020878, 59.08815175294876, 59.591176360845566, 57.70182654261589, 59.15784381330013, 59.92819547653198, 58.11084799468517, 55.329496040940285, 54.50666919350624, 56.8726122379303, 55.29976263642311, 53.23021128773689, 52.41320572793484, 53.84434573352337, 60.248009115457535, 59.18857656419277, 55.59631012380123, 59.605581387877464, 56.10120803117752, 57.24742792546749, 56.14330977201462, 53.90056371688843, 50.13476058840752, 48.197700530290604, 47.37221382558346, 48.12022268772125, 44.20542575418949, 49.499491676688194, 52.96321101486683, 56.039898321032524, 44.49892960488796, 36.79288990795612, 39.2577188462019, 41.06212802231312, 39.00100462138653, 39.75882835686207, 37.121184691786766, 40.08687235414982, 43.9695306122303, 47.73880295455456, 47.51410961151123, 49.08521510660648, 47.00122833251953, 48.78972016274929, 52.06034906208515, 50.16728304326534, 51.54914349317551, 54.190127179026604, 54.23899255692959, 54.82281222939491, 52.9248558729887, 53.929271176457405, 54.75244000554085, 55.35146266222, 55.416465774178505, 49.10438887774944, 47.94912166893482, 46.338893473148346, 50.20781546831131, 56.50121256709099, 52.2956932336092, 52.69635133445263, 51.01985089480877, 52.88622334599495, 52.485793232917786, 52.654431983828545, 50.53376577794552, 48.87416683137417, 49.790586456656456, 48.929602056741714, 46.05717658996582, 45.15614613890648, 46.12015821039677, 45.475370809435844, 41.4926715195179, 39.51118044555187, 37.67443500459194, 39.9720349162817, 40.00617228448391, 41.976685747504234, 36.34477235376835, 40.8660851418972, 38.05921755731106, 46.78737960755825, 53.23702052235603, 46.290734857320786, 44.745331183075905, 46.04212939739227, 47.244681268930435, 51.99823759496212, 55.75413465499878, 58.533290326595306, 55.71112856268883, 58.03337015211582, 54.10794898867607, 52.52821795642376, 54.165500700473785, 56.806324794888496, 56.35239355266094, 54.45798620581627, 55.246934071183205, 55.20746938884258, 57.20983274281025, 58.18536579608917, 53.905123472213745, 54.568465277552605, 58.01133893430233, 62.02114216983318, 61.056297942996025, 70.401771068573, 74.9095755815506, 62.06550858914852, 64.64818060398102, 61.53426669538021, 61.2048851698637, 64.35196369886398, 65.26821613311768, 64.36685130000114, 62.80996084213257, 73.88223990797997, 65.10597243905067, 73.99627178907394, 34.186412170529366, 0.43768266099505126, 0.15369125845609233, 0.5152386368717998, 3.501975922845304, 55.51236502826214, 71.88353195786476, 68.87878239154816, 77.18424752354622, 69.36887249350548, 54.61362965404987, 45.18588714301586, 49.97496396303177, 51.61008842289448, 70.12725859880447, 71.52524158358574, 1.9006588426418602, 0.1616576497326605, 0.18842921708710492, 0.013496502833731938, 0.07886222258093767, 0.15152541920542717, 0.25012430967763066, 0.21406047453638166, 0.23394685587845743, 0.14674146106699482, 0.4376983648398891, 0.41894675698131323, 54.34969201683998, 84.20864939689636, 66.16945937275887, 50.88175490498543, 34.3601730465889, 40.94438374042511, 60.71614019572735, 67.07330167293549, 80.03868475556374, 63.95727127790451, 85.55300205945969, 29.291419833898544, 0.1932190085062757, 0.47345017141196877, 7.634905613958836, 5.965969143435359, 3.7072354461997747, 8.885655999183655, 57.18081749975681, 63.986157327890396, 67.83997133374214, 64.90563958883286, 65.3889736533165, 65.05596712231636, 63.841742277145386, 67.01401725411415, 62.13129825890064, 60.51336407661438, 63.25123496353626, 60.650373324751854, 63.93236741423607, 60.25109454989433, 58.32594685256481, 57.43456408381462, 56.72652907669544, 60.35871237516403, 57.53385275602341, 54.42329406738281, 57.8958061337471, 55.560177862644196, 60.85866294801235, 61.92986346781254, 57.04435162246227, 60.437117367982864, 60.21770194172859, 59.587634950876236, 58.79197284579277, 57.04096220433712, 52.86958783864975, 52.43635028600693, 49.97988469898701, 51.072679460048676, 46.59655764698982, 53.39677914977074, 54.87030208110809, 59.80139248073101, 46.0441242903471, 37.81313896179199, 40.724478140473366, 41.73792935907841, 41.66030712425709, 42.382420375943184, 39.816896840929985, 41.82455711066723, 48.02075922489166, 49.253872856497765, 49.56032261252403, 50.920015051960945, 49.442946910858154, 51.19192846119404, 56.405845284461975, 53.93984600901604, 56.951047629117966, 55.913672894239426, 55.83116792142391, 59.515036046504974, 55.69063626229763, 55.10680139064789, 57.453065291047096, 59.07654717564583, 58.53969298303127, 51.55144616961479, 52.7512089908123, 50.34857511520386, 52.52239666879177, 59.24899712204933, 55.55352441966534, 54.358819127082825, 54.25593584775925, 55.924099534749985, 57.29435920715332, 54.59389731287956, 54.55974854528904, 52.740622758865356, 51.25632360577583, 50.80730549991131, 48.835705295205116, 48.09564180672169, 49.105376824736595, 48.200668171048164, 45.102599412202835, 43.02455931901932, 39.433706402778625, 42.399416863918304, 43.41502636671066, 44.276166558265686, 38.35229203104973, 41.783899292349815, 41.18600897490978, 49.78467397391796, 55.76222442090511, 49.595413729548454, 48.49158436059952, 49.05168570578098, 51.95787996053696, 54.90725129842758, 56.7000786960125, 60.92721126973629, 58.03956001996994, 59.270378574728966, 56.94385461509228, 56.4676907658577, 57.198809534311295, 55.842764899134636, 59.286679700016975, 57.991902977228165, 58.13555046916008, 58.671367317438126, 60.39388708770275, 61.131818890571594, 56.30736216902733, 57.120415940880775, 61.03391334414482, 65.3707118332386, 63.80666255950928, 70.61299413442612, 76.21817976236343, 64.86470058560371, 66.24635964632034, 66.9618308544159, 64.37163144350052, 68.86447995901108, 68.56200098991394, 69.15539234876633, 64.45062920451164, 74.97762992978096, 68.58464777469635, 78.41988041996956, 38.55149254202843, 0.9101591049693525, 0.1896047344780527, 0.7734484970569611, 4.912583017721772, 60.777544900774956, 79.39386695623398, 75.05045682191849, 82.2400814294815, 74.65057387948036, 64.5487779378891, 57.46400870382786, 57.17963956296444, 60.006490275263786, 77.52575799822807, 84.90784227848053, 3.204908100888133, 0.3638417279580608, 0.40751275490038097, 0.18995467195054516, 0.2026849240064621], [0.027169007844349835, 0.06705550651531667, 0.018909130558313336, 0.12173735551186837, 0.05012703266402241, 0.20045523036969826, 0.10205354337813333, 14.815195072442293, 69.92219880223274, 47.82454535365105, 41.95769436657429, 29.81029339134693, 29.095228761434555, 47.191301733255386, 52.6173497736454, 72.5750720500946, 56.870336160063744, 63.24861690402031, 42.34014384448528, 0.10315456398529932, 0.23746159306028858, 1.3098412519320846, 0.4599110229173675, 1.0408072569407523, 9.294221475720406, 58.826585188508034, 61.69360354542732, 60.87108448147774, 59.838603883981705, 58.772495090961456, 62.20388576388359, 60.29354587197304, 59.69220533967018, 57.659804597496986, 58.82164165377617, 57.75313138961792, 60.252580270171165, 54.230671003460884, 53.58898803591728, 52.22434066236019, 53.35750065743923, 55.38581281900406, 54.38424356281757, 50.97985044121742, 52.606866136193275, 50.99045567214489, 55.474408864974976, 75.51036134362221, 52.49115474522114, 55.03881923854351, 54.78501945734024, 53.424947038292885, 54.69656780362129, 51.211751997470856, 46.40326961874962, 45.30412919819355, 46.94354362785816, 48.918780237436295, 44.814198687672615, 44.92530472576618, 49.657403603196144, 51.01606249809265, 48.724690452218056, 39.07649137079716, 37.02572621405125, 38.7208266556263, 38.178135976195335, 38.03933322429657, 37.22957007586956, 36.65054574608803, 36.609355956315994, 39.65833894908428, 43.266420140862465, 46.691795736551285, 47.55045086145401, 46.57066963613033, 49.707929491996765, 46.668180003762245, 50.464955270290375, 49.89754691720009, 49.9841632694006, 51.28384552896023, 50.78574925661087, 51.783666908741, 49.06594634056091, 51.96565434336662, 54.89276647567749, 53.145259246230125, 47.73911073803902, 45.18250152468681, 44.41339999437332, 46.11131988465786, 54.35772858560085, 49.65623326599598, 48.80054198205471, 48.22579622268677, 51.05124481022358, 49.43495213985443, 49.48623798787594, 46.33236162364483, 45.4888790845871, 48.35444591939449, 47.14095063507557, 43.99380750954151, 43.37388597428799, 42.711691707372665, 44.084691032767296, 38.986493200063705, 38.26295882463455, 37.53639221191406, 37.152225226163864, 35.85865303874016, 37.52129182219505, 36.456007584929466, 36.52133367955685, 36.04806147515774, 40.90508624911308, 50.93863785266876, 48.41495767235756, 41.46796144545078, 45.75229234993458, 45.477909073233604, 48.69071267545223, 49.72494497895241, 52.41661794483662, 55.211535170674324, 55.327592343091965, 54.587327465415, 55.93183971941471, 54.43420708179474, 49.68773737549782, 57.17903919517994, 54.84647735953331, 53.12069736421108, 50.72239525616169, 52.80189827084541, 54.848016276955605, 57.6433514803648, 53.64547960460186, 50.182489827275276, 53.85494336485863, 53.62024895846844, 72.03125283122063, 55.756676718592644, 65.0753764808178, 59.33453433215618, 63.44974771142006, 62.140022590756416, 65.27383223176003, 55.447491109371185, 69.48055610060692, 74.29536893963814, 66.94685205817223, 68.46891358494759, 70.64264014363289, 10.593080129474401, 0.19437242473941296, 0.4180711414664984, 0.1376974565209821, 5.398474344983697, 55.636872947216034, 62.814889177680016, 65.68461298942566, 65.42599126696587, 63.75309303402901, 41.602645218372345, 74.76175591349602, 44.05981756746769, 34.168017357587814, 73.58834087848663, 58.546262830495834, 1.50948918890208, 0.11489237163914368, 0.13173900515539572, 0.04756633745273575, 0.09902780730044469, 0.04110116991796531, 0.15359509096015245, 0.08007291035028175, 0.19431774329859763, 0.014424718992813723, 0.23698663339018822, 0.1865709832054563, 22.91979443281889, 78.8619638979435, 53.900544717907906, 42.80583545565605, 27.392694018781185, 33.33035230636597, 53.96541103720665, 56.17323696613312, 78.34317773580551, 60.62386594712734, 69.21466156840324, 43.79079960286617, 0.2759389963466674, 0.33735073695424944, 1.4938263106159866, 0.5958073167130351, 1.1600813129916787, 9.961922597140074, 59.91463020443916, 63.4911996871233, 61.7554984241724, 62.381207048892975, 61.76093593239784, 64.20831620693207, 62.05861195921898, 59.99040573835373, 59.77778434753418, 61.531663835048676, 59.34795901179314, 61.09956622123718, 56.50872476398945, 55.96363261342049, 53.660412803292274, 53.95630292594433, 56.776143014431, 56.226350516080856, 53.63538734614849, 53.93130786716938, 51.274376437067986, 56.797524467110634, 68.93589332699776, 55.164904072880745, 58.49561534821987, 57.319935634732246, 55.870393216609955, 58.10601845383644, 55.5007566511631, 49.128278195858, 46.55388593673706, 48.45684662461281, 50.10523997247219, 47.26974852383137, 45.99774397909641, 51.665447652339935, 54.29237209260464, 50.7247207313776, 41.51660643517971, 38.98229822516441, 41.017218232154846, 42.01246842741966, 40.510937198996544, 38.062652572989464, 39.04696695506573, 39.81882333755493, 41.6450509428978, 46.34387880563736, 48.47739592194557, 49.73513223230839, 48.45235526561737, 49.7684982419014, 48.996592462062836, 51.80444419384003, 49.91574414074421, 52.850246876478195, 53.25021341443062, 55.04427954554558, 54.484755769371986, 53.24880748987198, 55.560880824923515, 56.042660772800446, 56.801058277487755, 48.70366618037224, 47.672462314367294, 46.69024921953678, 49.68646064400673, 55.260267555713654, 53.34182649850845, 54.03077132999897, 52.19550400972366, 52.9938867688179, 52.334424555301666, 52.185179963707924, 49.651057943701744, 48.41170884668827, 52.108921855688095, 49.390004351735115, 46.204878464341164, 45.65004363656044, 44.54070456326008, 46.62866212427616, 40.15810713171959, 38.37157219648361, 37.59265959262848, 39.03799183666706, 38.723638504743576, 39.35456044971943, 39.486409574747086, 38.208834528923035, 37.90508262813091, 42.45269000530243, 52.05923952162266, 49.84178490936756, 44.129882007837296, 48.18679131567478, 46.31668746471405, 49.35896381735802, 51.47595562040806, 55.12314811348915, 56.653367802500725, 58.026496320962906, 55.36995247006416, 56.39198362827301, 56.84070535004139, 50.707564651966095, 59.51935641467571, 56.892564967274666, 55.009503811597824, 53.43564346432686, 53.82759243249893, 57.77532979846001, 59.951564222574234, 54.5261013507843, 51.43668472766876, 56.850983798503876, 56.22259631752968, 72.0315720140934, 58.57236362993717, 66.20459988713264, 61.799636855721474, 65.19429489970207, 66.11748576164246, 69.40000802278519, 61.81368850171566, 66.35725289583206, 74.88474011421204, 70.57575613260269, 67.27906823158264, 73.0731113255024, 11.86817865818739, 0.13967824866995215, 0.3053445793921128, 0.49003194726537913, 6.866319430992007, 60.8518423140049, 71.9892954826355, 69.81012761592865, 74.10131335258484, 72.63128623366356, 52.04232282936573, 74.68129143118858, 48.144913762807846, 36.72215670347214, 79.50847640633583, 69.24622267484665, 2.09107244387269, 0.06127639142505359, 0.06420828663976863, 0.026833596057258546, 0.10408937319880351, 0.14883884461596608, 0.17359925113851205, 0.17614265059819445, 0.43105943826958537, 0.16335837019141763, 0.4939640831435099, 0.3670045832404867, 30.512862391769886, 92.85902962088585, 62.359631806612015, 57.004316970705986, 42.33306482434273, 40.037740990519524, 63.717093765735626, 60.95154516398907, 85.47572940587997, 69.78164434432983, 76.81212589144707, 48.10033455491066, 0.8572931948583573, 0.3529442986473441, 5.044488189741969, 3.465406922623515, 2.9146818118169904, 11.802655924111605, 63.50503854453564, 67.58566617965698, 66.87829613685608, 67.8733791410923, 62.511258870363235, 67.47061595320702, 64.94476988911629, 64.59664776921272, 63.75984147191048, 63.760593831539154, 62.3695682734251, 63.515514582395554, 59.42714676260948, 56.57246254384518, 57.222588658332825, 56.662578508257866, 61.411430686712265, 59.510054513812065, 56.79483041167259, 58.570976704359055, 54.66754876077175, 58.51217485964298, 76.78918272256851, 57.42549777030945, 57.970783710479736, 61.10533431172371, 59.02098275721073, 59.05287444591522, 58.20570610463619, 52.021610140800476, 49.42855328321457, 51.18799187242985, 53.71012553572655, 51.524102836847305, 48.938691169023514, 56.459114626049995, 56.722064316272736, 55.01058295369148, 44.73750740289688, 41.126671358942986, 44.08004388213158, 43.90576623380184, 43.08941803872585, 40.24957962334156, 40.66803216934204, 41.67864874005318, 43.8255525380373, 48.256775960326195, 50.75311280786991, 51.9820162653923, 50.20299732685089, 52.77102492749691, 50.30154503881931, 55.657247453927994, 51.71621672809124, 54.298474565148354, 56.72361463308334, 56.6009534150362, 56.26502484083176, 55.18769524991512, 59.21223409473896, 59.9612271040678, 58.80036659538746, 51.61676086485386, 49.964438527822495, 51.70467294752598, 51.98970325291157, 60.110566690564156, 56.17499627172947, 54.9419092386961, 53.64742510020733, 57.03536130487919, 56.222216337919235, 54.769485890865326, 51.15418888628483, 51.634129732847214, 54.75376233458519, 53.50695043802261, 48.53603817522526, 50.08850187063217, 48.82573463022709, 50.75110271573067, 43.964457884430885, 40.85511513054371, 40.11553041636944, 40.81890307366848, 39.77794133126736, 41.22850589454174, 41.60687439143658, 41.08374126255512, 39.35043007135391, 44.93137300014496, 54.90410886704922, 51.90573915839195, 47.39026665687561, 51.034073531627655, 49.246360659599304, 51.81235536932945, 54.0633849799633, 58.46846580505371, 58.97691652178764, 61.05772286653519, 58.02705489099026, 59.45186443626881, 60.16386263072491, 53.86897601187229, 60.69559469819069, 60.526351779699326, 57.91018836200237, 55.49170173704624, 56.87627524137497, 60.773615911602974, 62.678381502628326, 56.3275732845068, 53.94112654030323, 59.158960953354836, 59.31494638323784, 74.27738070487976, 62.47033506631851, 68.25030371546745, 64.62946280837059, 69.22190397977829, 68.90393704175949, 71.01283147931099, 64.73608508706093, 69.64302018284798, 74.05425667762756, 76.68776616454124, 70.16014203429222, 79.68777358531952, 14.132706094533205, 0.31545280886348337, 0.6796533206943423, 1.1597626050934196, 8.55091106146574, 66.27345979213715, 78.39406460523605, 76.43669843673706, 82.07784533500671, 77.38249808549881, 58.89406956732273, 92.48343497514725, 60.23736208677292, 49.04597461223602, 89.17495250701904, 84.20797303318977, 3.9637323701754212, 0.29690668685361743, 0.2385470730951056, 0.19695172930369154, 0.15311947820009664], [0.032809602926135994, 0.07884714956162497, 0.09056027338374406, 0.030817125661997125, 0.05243549414444715, 0.0698802393162623, 0.13170088845072314, 11.561754550784826, 70.7525834441185, 48.957549557089806, 34.43174600601196, 22.283788360655308, 33.586363568902016, 45.43721705675125, 48.69649216532707, 66.94043040275574, 61.014758571982384, 56.527826339006424, 54.821220114827156, 2.2073160437867045, 0.42724334460217506, 0.7600911450572312, 0.22647703561233357, 0.2950596297159791, 7.981940992176533, 62.973572462797165, 62.30992667376995, 59.16523441672325, 58.12083765864372, 60.23428425192833, 60.231768786907196, 59.818924739956856, 57.71687753498554, 58.78774747252464, 57.73881755769253, 57.55015768110752, 53.52253720164299, 54.58674609661102, 51.53233699500561, 50.55764749646187, 51.52655370533466, 51.16708159446716, 50.518935173749924, 49.173146188259125, 53.89739088714123, 53.523905128240585, 53.688136115670204, 27.643271572887897, 51.21781267225742, 54.593376740813255, 53.68179425597191, 51.89184710383415, 50.08060969412327, 46.20967000722885, 46.9971739500761, 44.73505273461342, 46.9008719176054, 46.6922365128994, 43.08173105120659, 42.64359936118126, 47.51507855951786, 48.59280712902546, 45.87106257677078, 40.63085116446018, 38.675153106451035, 38.49709466099739, 38.726982325315475, 39.072596579790115, 39.3192033469677, 39.15297366678715, 38.44658397138119, 38.35643380880356, 41.216924116015434, 45.407096073031425, 45.56265212595463, 47.650142312049866, 45.172074884176254, 48.66466127336025, 49.49810475111008, 52.190222293138504, 49.452165216207504, 49.55526128411293, 50.616255551576614, 49.04006972908974, 51.67217329144478, 50.913977175951004, 52.777469381690025, 54.15014952421188, 47.46978119015694, 46.2090240418911, 48.22960361838341, 49.768179059028625, 52.154671400785446, 48.971175625920296, 50.334132090210915, 50.825498923659325, 49.0613029897213, 48.19089129567146, 46.885748729109764, 45.56673310697079, 47.31269761919975, 47.15689457952976, 47.738920748233795, 45.98661817610264, 45.19483186304569, 43.00746403634548, 40.39098143577576, 37.57369101047516, 37.256997004151344, 36.790834218263626, 38.56100723147392, 37.10495576262474, 36.83632917702198, 37.14246354997158, 37.47781075537205, 39.028940722346306, 39.88625071942806, 47.3755918443203, 48.03752012550831, 43.23590397834778, 41.00746415555477, 47.07434020936489, 44.42367844283581, 48.72591018676758, 52.445644587278366, 54.023023545742035, 54.13004860281944, 55.19084148108959, 57.77308411896229, 56.75234489142895, 52.392477840185165, 48.97717550396919, 56.2249331921339, 58.396626859903336, 55.217436254024506, 54.28770214319229, 54.443755969405174, 54.348734468221664, 53.86813245713711, 50.92626951634884, 49.29711453616619, 52.04634681344032, 53.50459076464176, 51.18294194340706, 56.23730152845383, 53.56381818652153, 62.14199088513851, 60.724773332476616, 59.946343302726746, 66.99564903974533, 74.69216644763947, 52.62350544333458, 63.58806788921356, 73.80651757121086, 49.474264830350876, 1.4010672317817807, 0.1088610636361409, 0.44813120970502496, 0.7527660287450999, 8.245260212570429, 64.6705462038517, 63.16450461745262, 66.0910315811634, 64.79244366288185, 55.893074199557304, 48.820715099573135, 51.9306468218565, 32.313086092472076, 51.77257530391216, 67.12324619293213, 54.92264427244663, 1.2825412605889142, 0.040505091747036204, 0.08319024229422212, 0.05861229648871813, 0.10603500239085406, 0.045996824992471375, 0.048352275553043, 0.0525431537971599, 0.11615764437010512, 0.06444837141316384, 0.23789545259205624, 0.10236042886390351, 14.531545042991638, 81.8469013273716, 53.165306970477104, 44.648512378335, 20.147622786462307, 29.86023411154747, 55.777533799409866, 53.059524446725845, 73.92596036195755, 65.68776682019234, 62.23033234477043, 59.6064667403698, 3.2715323008596897, 0.6852639571297914, 0.67304523778148, 0.5224757641553879, 0.38863429916091263, 8.88766324147582, 66.55583783984184, 63.80455747246742, 63.36684376001358, 60.50614446401596, 62.2841602563858, 62.312012761831284, 63.379565477371216, 58.64378459751606, 60.78790694475174, 60.207670480012894, 60.330099910497665, 55.15766926109791, 55.261855870485306, 50.8952783793211, 51.519052907824516, 54.372179210186005, 52.74018578231335, 54.06525827944279, 51.12571321427822, 54.80192095041275, 57.00804837048054, 54.38851073384285, 29.707222022116184, 53.517722859978676, 57.513561844825745, 56.27049654722214, 53.863508105278015, 52.143549397587776, 47.787645533680916, 48.35313118994236, 47.56449490785599, 49.82033506035805, 49.174054339528084, 44.75119046866894, 47.33670853078365, 50.8797562122345, 51.93106859922409, 48.724302873015404, 42.559669464826584, 40.90428829193115, 39.90458093583584, 40.64464442431927, 41.903539672493935, 41.1800242960453, 39.23582822084427, 38.730687126517296, 40.529666393995285, 44.437619894742966, 48.02972674369812, 48.25750932097435, 49.45615880191326, 48.59533779323101, 50.017973855137825, 50.80528020858765, 52.593050077557564, 50.460669100284576, 52.14560128748417, 52.42486350238323, 52.506502121686935, 53.40519569814205, 54.91522327065468, 55.189325362443924, 55.388776659965515, 49.37036320567131, 49.03312750160694, 49.70213480293751, 51.73824794590473, 54.96893338859081, 50.62668219208717, 54.70439538359642, 52.56356365978718, 51.306173130869865, 50.906354784965515, 50.683793127536774, 49.07535083591938, 49.1443095356226, 50.13739384710789, 50.017631873488426, 48.827763721346855, 47.87429988384247, 46.339440643787384, 43.04166220128536, 39.457580521702766, 40.141973197460175, 38.70800994336605, 41.04072757065296, 39.65667463839054, 39.644956067204475, 39.580804109573364, 38.80034498870373, 42.580841928720474, 42.2927375882864, 49.39280480146408, 49.92764130234718, 44.63171347975731, 42.863565757870674, 48.963739424943924, 46.61948561668396, 50.616779923439026, 55.33850155770779, 56.84091433882713, 55.98734334111214, 57.1136637032032, 58.417662531137466, 58.55752922594547, 54.57188129425049, 50.60759201645851, 57.60375760495663, 59.564137011766434, 56.80412471294403, 58.23592588305473, 57.298736572265625, 56.276283636689186, 57.81681977212429, 52.43062399327755, 51.57016396522522, 54.637701362371445, 58.450340777635574, 52.04472430050373, 58.72104585170746, 55.27776561677456, 65.15295311808586, 61.664725095033646, 62.418011873960495, 66.01495206356049, 73.95517319440842, 57.833595871925354, 65.29551386833191, 76.00626513361931, 54.060120955109596, 1.3416149094700813, 0.09756735715200193, 0.07203318746178411, 1.3875578879378736, 9.651491604745388, 69.56399202346802, 69.82705190777779, 71.69853508472443, 73.68660360574722, 66.26111045479774, 54.68522921204567, 71.92831635475159, 42.23095290362835, 50.77113524079323, 75.98785132169724, 66.32503062486649, 1.8055626517161727, 0.11900312019861303, 0.13412685046205297, 0.023445823644578923, 0.1290766245801933, 0.16216130083194003, 0.14789747481700033, 0.13965120480861515, 0.21034442237578332, 0.31272841442842036, 0.4463548643980175, 0.32870379625819623, 19.610341116786003, 93.35828483104706, 61.444538310170174, 51.554030030965805, 28.60632609575987, 49.053437411785126, 63.13037484884262, 57.71202139556408, 75.89790254831314, 71.45405620336533, 67.04652070999146, 64.74156439304352, 4.655123082920909, 1.1202301201410592, 1.8902308959513903, 3.2622030889615417, 0.9134754363913089, 11.701427455991507, 72.15327188372612, 66.8049144744873, 63.82943853735924, 61.678214371204376, 65.1745131611824, 66.19248613715172, 66.2956278026104, 62.79091626405716, 65.71253389120102, 63.00836339592934, 62.35484026372433, 56.961645260453224, 55.66373750567436, 52.73467227816582, 52.728683799505234, 56.871597692370415, 57.47837953269482, 55.99575228989124, 53.26817125082016, 57.883813977241516, 57.0594672113657, 59.138164669275284, 38.37397746741772, 54.85476851463318, 59.84579689800739, 59.75296787917614, 58.04850473999977, 56.174684688448906, 50.34309200942516, 52.35817328095436, 49.74200986325741, 52.84404180943966, 50.50762698054314, 47.2414780408144, 46.94904953241348, 52.76420809328556, 55.16027212142944, 51.73040136694908, 45.84018163383007, 42.800804525613785, 42.941180393099785, 42.61631302535534, 41.99088558554649, 45.558799132704735, 42.54497945308685, 40.61390407383442, 42.01998062431812, 47.19709262251854, 52.120309844613075, 50.43060131371021, 53.70327450335026, 50.13413742184639, 52.45505668222904, 54.76352021098137, 56.04539282619953, 53.961626440286636, 55.89588984847069, 56.457621306180954, 55.5053848028183, 57.30607017874718, 57.09931567311287, 59.49111633002758, 57.31408014893532, 51.51480473577976, 52.272818461060524, 53.904789090156555, 53.32530878484249, 59.83512707054615, 55.251942202448845, 55.977566465735435, 56.757341623306274, 54.846781343221664, 53.928363025188446, 52.2623386234045, 52.340587824583054, 53.054140135645866, 51.76494911313057, 54.784130305051804, 50.80198958516121, 50.99300533533096, 49.477008283138275, 44.873992279171944, 42.50606194138527, 41.8373092263937, 41.15634776651859, 43.3949938416481, 40.32334126532078, 41.34091906249523, 41.134886518120766, 40.379137471318245, 44.41659942269325, 44.53452989459038, 52.168742045760155, 51.97433687746525, 47.5442685931921, 44.00535129010677, 52.628346383571625, 48.25524844229221, 54.04929533600807, 55.97671531140804, 58.8888144493103, 58.500395491719246, 59.67512905597687, 62.29082889854908, 59.737897887825966, 54.38067555427551, 51.177964210510254, 59.189625307917595, 62.45245702564716, 58.52612391114235, 61.35364718735218, 61.15063168108463, 60.36439307034016, 59.35099504888058, 55.83387717604637, 54.48805019259453, 54.784422889351845, 61.96429342031479, 52.45976842939854, 61.04717083275318, 59.120123237371445, 66.0064785182476, 65.54876267910004, 63.67679312825203, 66.26504704356194, 73.46870809793472, 65.70082291960716, 69.41049546003342, 76.73461005091667, 58.47415030002594, 2.7692686021327972, 0.16775899421190843, 1.8626284645870328, 2.4032777035608888, 12.297426424920559, 75.28217598795891, 77.96468764543533, 76.06078460812569, 78.92596766352654, 67.5148531794548, 65.83878591656685, 73.63871857523918, 43.24725016951561, 69.35203179717064, 82.91953057050705, 78.5496586561203, 3.161256993189454, 0.37379544228315353, 0.25840154208708555, 0.1403145067160949, 0.2507308521308005], [0.035412741563050076, 0.029159841251384933, 0.10128418856766075, 0.07204545516287908, 0.17053608113201335, 0.23081117804395035, 0.098826603643829, 10.032881889492273, 74.84554141759872, 53.95026504993439, 43.54932636022568, 35.91282673180103, 48.538052067160606, 40.954677388072014, 45.79711094498634, 65.22350773215294, 67.60203570127487, 52.14944668114185, 66.49212285876274, 4.511282751336694, 0.41072865889873356, 0.1668785250512883, 0.093594707432203, 0.3485330322291702, 5.181727325543761, 62.152584716677666, 62.36749358475208, 58.93199913203716, 57.91755236685276, 62.813198268413544, 59.58842530846596, 61.96159176528454, 54.758166298270226, 57.68663875758648, 51.48283705115318, 53.28489415347576, 51.73809215426445, 44.40771169960499, 45.13986021280289, 51.86043418943882, 49.981229826807976, 54.65940959751606, 54.471874460577965, 58.170713782310486, 53.649583384394646, 55.5403733253479, 40.151613280177116, 36.77364394068718, 56.81039817631245, 53.57201434671879, 52.20427393913269, 51.631815657019615, 50.392641350626945, 47.68109165132046, 45.707314163446426, 45.1984416693449, 48.184203654527664, 46.814198568463326, 43.513178899884224, 44.12650018930435, 50.518688187003136, 49.311242178082466, 47.777724266052246, 48.53038787841797, 42.06350728869438, 39.06364805996418, 38.948746025562286, 39.318241998553276, 39.50886256992817, 37.5155845284462, 38.531965389847755, 39.84042517840862, 40.852497071027756, 42.034526243805885, 46.044162288308144, 44.63914208114147, 48.69307994842529, 47.06526629626751, 48.61102715134621, 46.9532673060894, 47.68192760646343, 50.016575530171394, 50.858161970973015, 50.15236884355545, 50.727707371115685, 51.238316372036934, 51.33673869073391, 52.54663556814194, 46.08949385583401, 44.76758658885956, 48.421641513705254, 52.736188396811485, 51.23716503381729, 53.56519751250744, 51.00082911550999, 50.658668875694275, 48.651947155594826, 46.97869934141636, 44.78993698954582, 45.182554721832275, 47.55703590810299, 45.56596174836159, 45.574526488780975, 43.526599779725075, 44.087974056601524, 45.757220685482025, 41.02913439273834, 35.85932940244675, 36.8950854241848, 38.12187999486923, 38.17987248301506, 36.80004872381687, 38.51631782948971, 37.66585126519203, 38.20289924740791, 38.49953033030033, 43.755507096648216, 50.73167435824871, 49.7720168530941, 44.46476563811302, 41.35011076927185, 46.482708156108856, 46.21375858783722, 42.84871615469456, 48.359902426600456, 49.289742931723595, 53.150198981165886, 51.41719937324524, 53.27148087322712, 53.932880982756615, 56.707313507795334, 53.24428953230381, 50.454570427536964, 61.181786209344864, 52.65966050326824, 54.125530645251274, 54.04138036072254, 58.660116121172905, 54.14838261902332, 52.50941276550293, 49.59653086960316, 53.75213988125324, 50.11658996343613, 52.999651059508324, 55.885349214076996, 58.78464683890343, 58.20667125284672, 60.362804755568504, 63.373185619711876, 65.202297270298, 43.761191591620445, 57.97037713229656, 62.95355513691902, 73.27127069234848, 25.5233159288764, 0.02114577069733059, 0.12258082861080766, 0.42914739868137985, 0.41381489485502243, 9.842682145535946, 67.2719094157219, 61.43319591879845, 69.37819719314575, 64.01689007878304, 44.36699688434601, 53.509712889790535, 33.39971758425236, 21.934655494987965, 45.989513620734215, 68.26687082648277, 42.816908061504364, 1.163225881755352, 0.0929870962863788, 0.0894246538518928, 0.04097009550605435, 0.047862517458270304, 0.08027913834666833, 0.06489744497230276, 0.07136271640774794, 0.026084650307893753, 0.07058254850562662, 0.3625547548290342, 0.19886808819137514, 13.31553714349866, 85.1267409324646, 58.157900869846344, 48.12406048178673, 29.119762144982815, 52.948141023516655, 51.750650480389595, 50.31296342611313, 72.31279492378235, 72.80208706855774, 59.075395837426186, 71.97450667619705, 4.8930202424526215, 0.5015488027129322, 0.45558652840554714, 0.6424745125696063, 0.41877158044371754, 6.220001187175512, 66.55585303902626, 62.39968925714493, 61.936163529753685, 62.01925367116928, 64.58010345697403, 62.19441667199135, 63.34186390042305, 59.417312890291214, 60.73145717382431, 53.19771163165569, 54.90096263587475, 51.32544569671154, 42.9744628071785, 46.24004177749157, 53.853982016444206, 52.84802779555321, 55.928970873355865, 53.8840726017952, 59.2069523781538, 56.020048186182976, 56.922055184841156, 42.37173534929752, 37.72234283387661, 58.13997343182564, 54.869462326169014, 54.063540771603584, 54.038792699575424, 51.663346365094185, 49.64091248810291, 47.42098040878773, 45.87426200509071, 49.94897335767746, 48.258782252669334, 44.94814909994602, 45.9009175747633, 52.275383323431015, 53.11035431921482, 49.52203206717968, 50.129364877939224, 44.534320905804634, 40.34105971455574, 40.14507383108139, 40.23353688418865, 40.76119937002659, 39.45027731359005, 40.374988093972206, 41.64404399693012, 44.3098783493042, 45.020432621240616, 47.07492917776108, 49.00834523141384, 50.22333763539791, 48.244787603616714, 50.9314676374197, 48.19564864039421, 48.5854659229517, 51.84908799827099, 53.579507544636726, 52.46259927749634, 52.01715297996998, 54.475381672382355, 53.36060509085655, 52.68747881054878, 48.04932989180088, 47.04743765294552, 51.1521065980196, 53.241986855864525, 53.30215282738209, 55.167913511395454, 52.25809805095196, 52.669912353158, 50.39202198386192, 50.6122125685215, 49.302495047450066, 48.767479956150055, 49.431946501135826, 47.40900345146656, 49.063788056373596, 46.54909819364548, 46.706595942378044, 47.207515463232994, 43.19046601653099, 38.09213139116764, 38.66677075624466, 41.15544341504574, 39.54819045960903, 38.70377317070961, 39.38019387423992, 40.227229222655296, 38.90779182314873, 41.26096375286579, 45.852971747517586, 51.95232845842838, 51.187045723199844, 47.30305373668671, 42.71391458809376, 49.280980601906776, 49.40670445561409, 45.2954276651144, 49.69387784600258, 50.36269135773182, 55.64092732965946, 53.30279119312763, 56.151521131396294, 56.5637344121933, 57.863222882151604, 54.606607630848885, 49.97881695628166, 59.8857631534338, 55.14528572559357, 58.669205233454704, 56.20488926768303, 60.25508053600788, 57.59005554020405, 55.76172664761543, 51.377647295594215, 56.00118599832058, 54.36026684939861, 55.81794463098049, 59.98023368418217, 61.68495520949364, 58.9261132478714, 60.86427144706249, 63.71130667626858, 65.78719228506088, 47.415892481803894, 60.81856369972229, 64.54994827508926, 76.35074704885483, 28.770509585738182, 0.1332212967099622, 0.09471258221310563, 0.2926864492474124, 0.7895342807751149, 11.056433916091919, 73.27611923217773, 67.36185058951378, 75.1594577729702, 71.22245863080025, 47.03438155353069, 59.11231845617294, 43.829397931694984, 26.993392445147038, 53.7178011238575, 75.5545225739479, 53.92628073692322, 1.2433202401734889, 0.07662930060178041, 0.08801308154943399, 0.06727587984642014, 0.07327178740524687, 0.12973726959899068, 0.26012555113993585, 0.18505450832890347, 0.12196542491437867, 0.2664917829679325, 0.498055899515748, 0.3548123734071851, 15.83705523982644, 100.61505183577538, 66.76791206002235, 62.4830187857151, 47.0386753231287, 71.35420516133308, 56.47089399397373, 60.04241734743118, 78.35507869720459, 80.62711358070374, 62.86707937717438, 79.48413491249084, 6.048255627974868, 1.0123556898906827, 1.2742199446074665, 1.7545026540756226, 0.7427250675391406, 7.861497430130839, 69.22182038426399, 62.33468234539032, 63.38194414973259, 63.86501222848892, 67.01151698827744, 63.79302129149437, 65.33901393413544, 61.42246149480343, 64.1378603875637, 53.838528245687485, 57.06321761012077, 52.38765589892864, 45.70680879056454, 51.061086282134056, 58.39279666543007, 55.729717165231705, 57.68120504915714, 59.306788221001625, 60.448505356907845, 56.740740314126015, 57.59940683841705, 43.808312863111496, 39.04110386967659, 60.8286901563406, 58.039066046476364, 56.17848068475723, 57.95064099133015, 54.109468907117844, 51.93329147994518, 50.470939949154854, 48.42770218849182, 53.404340744018555, 50.67987933754921, 49.06072162091732, 49.12442520260811, 56.01401790976524, 55.952153429389, 53.38280349969864, 52.138317078351974, 45.757015496492386, 43.25350843369961, 41.79212965071201, 41.4486812800169, 42.99021676182747, 42.36988864839077, 43.53078715503216, 43.34121532738209, 44.66442972421646, 46.39715954661369, 49.42709416151047, 50.61595916748047, 52.41820625960827, 50.900875478982925, 55.502527356147766, 51.11070781946182, 52.13543303310871, 54.381587505340576, 56.59695602953434, 54.6625292301178, 56.34137414395809, 56.81256026029587, 55.83859272301197, 56.94780260324478, 49.18421879410744, 49.470339640975, 54.9953343719244, 57.64417223632336, 54.90918539464474, 59.68343161046505, 56.724731773138046, 54.496812522411346, 53.29548418521881, 54.834880381822586, 53.96072208881378, 51.85193404555321, 53.740402311086655, 50.196818858385086, 50.82017160952091, 49.02757219970226, 51.05917878448963, 51.60625442862511, 45.90506315231323, 39.3698850274086, 41.38678640127182, 41.49785824120045, 41.38826832175255, 40.68172663450241, 42.48257540166378, 42.189299538731575, 41.83498755097389, 43.476073890924454, 48.3978395909071, 53.40092472732067, 54.53889146447182, 50.46783931553364, 46.05565287172794, 52.23293960094452, 51.45245388150215, 49.655997678637505, 52.008987218141556, 53.255346938967705, 57.51469038426876, 55.05462259054184, 56.11790433526039, 57.687930688261986, 59.91212233901024, 55.71644447743893, 51.259659826755524, 57.63612426817417, 57.94633202254772, 60.123087018728256, 58.7648992985487, 63.06259408593178, 59.03490141034126, 57.38888293504715, 55.9013007581234, 56.67265556752682, 54.90214817225933, 59.2765836417675, 60.590553134679794, 65.36831796169281, 61.22387275099754, 60.572150722146034, 63.35630312561989, 68.77869576215744, 54.30195137858391, 63.612131997942924, 65.82264438271523, 78.42675045132637, 32.8000907599926, 0.21221228933427483, 0.32552443561144173, 0.8935076266061515, 1.5399294742383063, 12.512506283819675, 78.6552245914936, 75.86280763149261, 81.03145748376846, 76.66229233145714, 55.39436616003513, 71.98152869939804, 48.27931635081768, 28.895306289196014, 66.29792287945747, 83.18399637937546, 70.80303713679314, 2.0988256903365254, 0.25599511340260506, 0.17630436457693577, 0.21256593754515052, 0.19488409103360027], [0.0797856027202215, 0.015290758947230643, 0.13732445309869945, 0.04075783755979501, 0.07016234449110925, 0.08370371200726368, 0.08618563195341267, 3.3842126419767737, 72.20732778310776, 56.652022674679756, 44.96201455593109, 24.663437269628048, 27.02109295874834, 40.70474959909916, 42.83748395740986, 67.0809468626976, 65.28725311160088, 50.724234357476234, 71.98639243841171, 14.238331876695156, 0.4716931813163683, 0.1421150757232681, 0.21292173798428848, 0.30234357167501, 2.303717345930636, 55.47069266438484, 65.87733864784241, 62.17291742563248, 55.9975191950798, 65.02446681261063, 59.263972118496895, 60.27526505291462, 58.08374784886837, 57.573169246315956, 54.56549383699894, 53.27159106731415, 42.879878282547, 48.652581721544266, 54.853085204958916, 56.027165204286575, 55.575981214642525, 55.09461164474487, 50.154515728354454, 53.56520891189575, 53.61240617930889, 53.08381274342537, 44.76422756910324, 52.779878452420235, 57.305709198117256, 54.04298007488251, 50.56717358529568, 51.57247804105282, 47.81468868255615, 47.844197899103165, 48.99101436138153, 48.442137613892555, 47.79759339988232, 45.93201890587807, 45.156100541353226, 44.62282195687294, 48.18568177521229, 48.872217535972595, 50.43088249862194, 52.57669195532799, 45.773582607507706, 37.39324249327183, 38.40185657143593, 38.649538680911064, 38.64827714860439, 38.563891276717186, 40.425434187054634, 39.329105615615845, 40.09284943342209, 42.7538238465786, 45.88414907455444, 44.226282835006714, 46.816710233688354, 47.23584294319153, 44.666637405753136, 45.21496318280697, 46.76411725580692, 46.72639288008213, 48.50997157394886, 48.444212302565575, 50.67348428070545, 51.03996321558952, 51.89424857497215, 51.788382455706596, 47.47490331530571, 48.030091524124146, 46.93906366825104, 52.54012651741505, 53.969959393143654, 49.193410500884056, 49.65624086558819, 42.47299611568451, 47.6989620923996, 45.608561262488365, 44.07218590378761, 45.927523747086525, 48.42827595770359, 45.81678628921509, 45.97537077963352, 43.995456621050835, 44.460308477282524, 45.5230126529932, 41.36380523443222, 36.02212406694889, 36.38869419693947, 38.70523989200592, 37.767993584275246, 38.77072177827358, 36.379532888531685, 37.547027841210365, 36.86418928205967, 47.02156864106655, 49.70037929713726, 49.55484710633755, 51.863740012049675, 45.5875825881958, 41.79499089717865, 45.55029898881912, 49.192312359809875, 45.56910417973995, 45.050762593746185, 46.7290223389864, 50.27350254356861, 45.248728170990944, 54.572702050209045, 48.372130170464516, 38.37519720196724, 39.9835254997015, 54.932550340890884, 59.50295649468899, 53.60064961016178, 60.890797823667526, 51.487408205866814, 56.112900003790855, 52.82389909029007, 56.411685571074486, 51.86506234109402, 54.91376414895058, 46.19515858590603, 56.030809208750725, 58.0408139526844, 60.91708101332188, 60.841848850250244, 62.678199112415314, 51.24978415668011, 48.51025655865669, 53.2432521879673, 67.08022490143776, 50.86074583232403, 66.82291030883789, 9.191351495683193, 0.07227275273180567, 0.04213074025756214, 0.24493095319485292, 0.41726386290974915, 10.492205042392015, 66.82990953326225, 63.876745998859406, 69.69231873750687, 66.79235994815826, 59.399032071232796, 42.118425741791725, 35.51118068397045, 40.960304886102676, 47.89196893572807, 73.81441354751587, 43.132082149386406, 0.8941655850503594, 0.056802428371156566, 0.023354608129011467, 0.08922822220483795, 0.08870477802702226, 0.07281247220817022, 0.023976197626325302, 0.22978720720857382, 0.04096190590644255, 0.09513502009212971, 0.16028104000724852, 0.18272558954777196, 6.265738857910037, 85.23688182234764, 63.125628903508186, 48.9640624076128, 33.891734182834625, 38.71343985199928, 46.41583174467087, 50.8098703622818, 69.98353511095047, 72.73788571357727, 56.4095538854599, 78.09704974293709, 15.28111182153225, 0.45704318617936224, 0.31868195277638733, 0.38622602995019406, 0.2863115491345525, 3.188721206970513, 60.4512108117342, 66.53138235211372, 64.72125068306923, 58.261878490448, 66.59562930464745, 60.33814787864685, 62.498138174414635, 59.44827362895012, 60.93220800161362, 57.05355852842331, 56.28006063401699, 46.61193162202835, 51.925600692629814, 54.33755926787853, 55.89356057345867, 55.71739062666893, 54.857827350497246, 53.38754564523697, 55.735386461019516, 54.67334344983101, 54.552471935749054, 46.435415893793106, 54.04969431459904, 59.7442739456892, 55.55862754583359, 52.57028169929981, 53.34586188197136, 50.36286614835262, 50.59675879776478, 49.00934457778931, 49.674460887908936, 49.90826614201069, 49.727661833167076, 47.2762955725193, 47.11543880403042, 51.22290059924126, 51.486671045422554, 52.934119775891304, 56.299667581915855, 46.94778420031071, 40.11440187692642, 39.07308295369148, 39.74521368741989, 38.18457283079624, 40.27484446763992, 41.94760210812092, 40.91123811900616, 43.316687643527985, 44.28674899041653, 47.04614572227001, 46.39683276414871, 49.699782729148865, 49.700907468795776, 48.88404630124569, 48.93213652074337, 48.03603820502758, 48.76560665667057, 51.07446916401386, 50.101367980241776, 54.52085003256798, 53.93386512994766, 53.89728829264641, 53.867847472429276, 49.205243065953255, 49.64916184544563, 49.212094098329544, 54.73508633673191, 57.3330145329237, 52.92610980570316, 52.034567445516586, 46.15212969481945, 51.44669719040394, 48.10563147068024, 48.354293927550316, 49.88946855068207, 49.351330026984215, 48.70506450533867, 48.591199815273285, 47.13475316762924, 46.41617372632027, 46.32810965180397, 41.94877624511719, 38.4248111397028, 39.022834450006485, 43.01400348544121, 39.226134940981865, 39.00454983115196, 38.151579201221466, 39.53405901789665, 39.15514715015888, 49.92102585732937, 51.030695512890816, 51.83116056025028, 54.01332266628742, 48.35433192551136, 44.474937692284584, 47.96220436692238, 51.817606687545776, 49.003401696681976, 46.00107640028, 48.12566019594669, 53.53771358728409, 49.84539471566677, 56.086343228816986, 51.800120025873184, 40.34610204398632, 40.694832131266594, 49.24501173198223, 59.344037622213364, 55.42024277150631, 60.33603139221668, 55.840732008218765, 57.883692383766174, 56.140733510255814, 58.56726810336113, 52.86139167845249, 56.689401268959045, 51.36859618127346, 57.10276208817959, 59.59788680076599, 63.61331753432751, 62.35852226614952, 63.18907409906387, 53.66514354944229, 53.945579901337624, 57.02160604298115, 68.82125347852707, 55.37723667919636, 71.71599134802818, 11.30739999935031, 0.09537372447084635, 0.3641772083938122, 0.16798330092569813, 0.816903084050864, 10.848114844411612, 75.93115836381912, 68.17276507616043, 76.0124360024929, 72.16698154807091, 61.388913094997406, 51.06310397386551, 44.42494377493858, 26.61007471382618, 51.03804051876068, 80.7509109377861, 52.24764861166477, 1.004168672952801, 0.1297053275629878, 0.038599557083216496, 0.07404182499158196, 0.07091938707162626, 0.1383725882624276, 0.3155491396319121, 0.3882197057828307, 0.14755396434338763, 0.1779621740570292, 0.2610829216428101, 0.3111224068561569, 8.627588097006083, 99.77682441473007, 69.00643274188042, 63.20001371204853, 31.26113533973694, 41.923013627529144, 54.392682909965515, 54.51654486358166, 77.82966569066048, 76.1293937265873, 60.448136776685715, 86.19698390364647, 16.65347658097744, 0.5236876616254449, 0.2845733502181247, 1.0428698337636888, 0.9261741174850613, 3.927243878133595, 63.829050958156586, 66.32952958345413, 67.70599812269211, 60.945207104086876, 68.07071015238762, 62.36432455480099, 63.599733263254166, 61.29472374916077, 62.260529324412346, 58.705109506845474, 59.140360951423645, 50.844767689704895, 55.14921471476555, 56.29809446632862, 57.05505944788456, 55.86495950818062, 56.75999008119106, 52.86128148436546, 57.75839790701866, 58.80439817905426, 55.431919544935226, 46.8537962436676, 54.727475345134735, 63.07819984853268, 58.276864886283875, 54.95209649205208, 55.73551945388317, 51.68592095375061, 53.316489458084106, 49.91515137255192, 52.7880784124136, 51.56590819358826, 51.31104066967964, 51.82795733213425, 50.03478795289993, 53.528210297226906, 54.721961840987206, 56.282431706786156, 58.816158547997475, 49.51615758240223, 43.36749851703644, 42.882731929421425, 43.70662271976471, 41.213124319911, 42.825715988874435, 43.25722083449364, 42.2760146856308, 45.85934020578861, 46.28720864653587, 51.10743619501591, 50.60373142361641, 49.91137817502022, 52.513611540198326, 51.46721608936787, 48.11855837702751, 51.248059049248695, 52.95021951198578, 53.30556124448776, 50.95272369682789, 56.66993111371994, 55.90340964496136, 57.07411162555218, 55.351439863443375, 48.629976734519005, 53.436908796429634, 52.017673552036285, 56.27814173698425, 60.08351594209671, 54.34874966740608, 56.330692917108536, 48.85746292769909, 53.82986091077328, 51.64292626082897, 51.476639583706856, 49.96759235858917, 52.44324691593647, 49.21221949160099, 51.716376319527626, 48.63409951329231, 51.49516358971596, 51.695469841361046, 45.66334292292595, 41.01256728172302, 40.704206228256226, 46.02183848619461, 41.52721926569939, 42.220898643136024, 38.869022503495216, 40.257730185985565, 40.38079798221588, 51.84655733406544, 54.32022839784622, 55.551172345876694, 56.400700360536575, 50.119246020913124, 47.66632564365864, 50.899416357278824, 55.409021973609924, 52.61608824133873, 47.27115444839001, 51.935179978609085, 56.22363366186619, 50.72203427553177, 58.51951986551285, 53.35900537669659, 43.41716945171356, 43.807986080646515, 50.471266731619835, 61.51628606021404, 55.10224923491478, 61.82087391614914, 57.67957493662834, 61.65135361254215, 57.826900631189346, 60.31603306531906, 56.75969369709492, 55.945933163166046, 50.92553235590458, 59.161875396966934, 62.645365074276924, 65.58451116085052, 63.56212668120861, 64.11038786172867, 57.94188246130943, 58.27543996274471, 57.852461859583855, 68.60865488648415, 58.09284836053848, 75.22036850452423, 14.662702605128288, 0.12948490970302373, 0.2897271205438301, 0.3356606588931754, 1.3548767915926874, 12.057861629873514, 84.39464941620827, 74.25275802612305, 81.86324805021286, 79.98641476035118, 71.80734604597092, 59.14670281112194, 56.114708706736565, 47.84631438553333, 68.19693937897682, 89.40851077437401, 67.3996889591217, 1.2461520382203162, 0.186839017260354, 0.12169688619906083, 0.1874020995455794, 0.16804132203105837], [0.08115143646136858, 0.14314229716546834, 0.058657437621150166, 0.07966275501530617, 0.12405776928062551, 0.05823131497891154, 0.07069062005029991, 3.0061913514509797, 62.45811492204666, 54.6748785674572, 36.04526102542877, 22.011149190366268, 30.058041997253895, 33.03584150969982, 31.82944804430008, 63.220084235072136, 65.1931169629097, 49.54759329557419, 69.35412928462029, 25.562189742922783, 0.050350738238194026, 0.5647810315713286, 0.39281544042751193, 0.3935794666176662, 0.6606087426189333, 48.64149011671543, 67.74986296892166, 58.22430230677128, 61.06467269361019, 58.2957498729229, 55.216577500104904, 60.67282631993294, 57.45045863091946, 59.5805749297142, 59.415306597948074, 56.00356087088585, 58.418570682406425, 65.6208448112011, 57.98654146492481, 54.56501126289368, 53.44950892031193, 54.09213803708553, 49.86238360404968, 56.81100994348526, 54.6159703284502, 55.121084824204445, 50.17650134861469, 53.52067910134792, 56.70217998325825, 54.317728132009506, 52.674008533358574, 52.995391488075256, 56.84567928314209, 53.87760914862156, 50.51137737929821, 53.679149597883224, 51.12168163061142, 47.98381760716438, 46.5130191296339, 44.468276649713516, 48.21421444416046, 48.83449696004391, 46.79718688130379, 50.19962690770626, 50.74905842542648, 45.23393176496029, 37.61349767446518, 37.052556574344635, 38.95671419799328, 38.484099358320236, 37.508121728897095, 36.63253851234913, 39.87132132053375, 41.534275487065315, 45.75082182884216, 47.67148196697235, 45.30188351869583, 47.491842806339264, 47.431353852152824, 46.846337243914604, 44.51595649123192, 46.27769395709038, 49.05939929187298, 49.0483532845974, 51.05847202241421, 54.27113123238087, 53.71697656810284, 54.01372164487839, 49.22425724565983, 49.59397740662098, 48.14286947250366, 53.553927317261696, 57.08667375147343, 52.07920365035534, 50.401859655976295, 47.74543359875679, 49.194345250725746, 46.38718508183956, 47.32489116489887, 48.67158070206642, 44.297217428684235, 46.79148718714714, 47.244913056492805, 43.864359855651855, 46.86441287398338, 43.59682381153107, 38.69441047310829, 36.49446152150631, 39.34032641351223, 38.1332565844059, 38.43989633023739, 39.433216229081154, 37.07710325717926, 38.075594678521156, 41.723710522055626, 45.86973264813423, 50.88635265827179, 49.535422548651695, 48.75780947506428, 45.056215301156044, 42.73475266993046, 46.10122002661228, 46.46642602980137, 45.6651858240366, 45.92139847576618, 46.84994325041771, 46.920874044299126, 49.797745272517204, 52.05385901033878, 55.236720219254494, 49.48213040828705, 42.525988072156906, 34.980406165122986, 33.35065841674805, 53.877305164933205, 51.53341993689537, 51.28722354769707, 55.58443196117878, 52.06355229020119, 53.98346766829491, 53.17362852394581, 51.61783240735531, 41.95695720613003, 57.196297869086266, 57.47242145240307, 63.946092277765274, 55.540042743086815, 57.22082555294037, 52.960893139243126, 67.14227557182312, 57.24212720990181, 62.29782052338123, 51.96209013462067, 54.63762156665325, 3.1570689054206014, 0.033783812759793364, 0.5237304687034339, 0.3847670566756278, 0.4840902832802385, 11.531738061457872, 72.78168216347694, 65.87879776954651, 67.84038931131363, 67.55238756537437, 58.426398262381554, 33.65058772265911, 33.67837183177471, 35.65741203725338, 49.691540971398354, 75.00289097428322, 37.77526639401913, 1.135636274702847, 0.18186373345088214, 0.040855975457816385, 0.14636817562859505, 0.1718583211186342, 0.10729784829891287, 0.06466772800195031, 0.09401052535395138, 0.05083962059870828, 0.12951765325851738, 0.1887053850805387, 0.0675139385566581, 4.240609500557184, 75.57545185089111, 63.21237824857235, 43.135228380560875, 22.594077810645103, 43.497649133205414, 36.39714494347572, 40.82934111356735, 70.87412372231483, 69.65097695589066, 54.03704099357128, 76.05984225869179, 27.901365123689175, 0.15459512011148036, 0.35443405620753765, 0.8954155398532748, 0.05559915836784057, 0.7659228227566928, 52.957461923360825, 67.7777686715126, 63.017467707395554, 61.78776629269123, 61.371779814362526, 60.16933053731918, 62.70476348698139, 59.340864792466164, 61.32481813430786, 61.218420043587685, 58.567366898059845, 59.63599115610123, 63.57324868440628, 56.82281970977783, 55.75229935348034, 53.34188349545002, 55.952594205737114, 52.219910100102425, 56.77134767174721, 55.90393781661987, 57.62754052877426, 51.225765645504, 56.40428736805916, 56.85499258339405, 56.84542089700699, 56.15688644349575, 56.527142375707626, 57.36242115497589, 55.699292197823524, 52.36716739833355, 56.54090903699398, 52.71137572824955, 50.14940120279789, 46.95893660187721, 47.062397450208664, 49.87257845699787, 51.13465793430805, 49.56199832260609, 52.84555412828922, 50.78693479299545, 45.28533920645714, 38.51480171084404, 40.20884580910206, 39.692822098731995, 39.265538826584816, 38.953503370285034, 39.30129870772362, 41.31189621984959, 44.40941020846367, 48.941195234656334, 50.14559380710125, 46.22592933475971, 48.239874467253685, 50.09979106485844, 47.320323809981346, 47.55845323204994, 47.7733089029789, 49.25702668726444, 50.60177452862263, 52.32172183692455, 56.74894027411938, 55.33425338566303, 55.283841490745544, 50.2737495303154, 50.45111261308193, 51.14529736340046, 55.13207383453846, 57.651597037911415, 54.054314866662025, 53.52152645587921, 50.878973454236984, 51.6220273822546, 48.264459148049355, 48.266328647732735, 51.538534462451935, 46.44682288169861, 48.732776418328285, 48.65247152745724, 45.13732574880123, 47.10136815905571, 47.15407893061638, 43.1792414188385, 38.80856774747372, 40.5011261254549, 40.47753319144249, 41.44208863377571, 41.80156074464321, 39.71807174384594, 42.23352536559105, 43.11988100409508, 47.06253804266453, 53.95398125052452, 51.705896481871605, 51.280516907572746, 46.95439204573631, 45.206539034843445, 48.12491163611412, 48.451656103134155, 46.74914985895157, 47.224367558956146, 49.665972143411636, 50.389707908034325, 52.0220623165369, 52.92197182774544, 57.23000206053257, 54.17335107922554, 45.211581364274025, 39.650461971759796, 38.22244919836521, 51.97693973779678, 46.83426149189472, 53.45090724527836, 57.65582621097565, 54.64172914624214, 54.456344693899155, 53.93384613096714, 57.777119502425194, 44.898725152015686, 57.502344846725464, 58.27033683657646, 65.10259062051773, 57.3754658550024, 60.799959897994995, 57.36378528177738, 69.41756308078766, 57.72837191820145, 64.12089809775352, 55.228953436017036, 60.32685108482838, 3.519990756176412, 0.04037383550894447, 2.3636705288663507, 0.4401462053647265, 0.5532590404618531, 12.51142144203186, 80.15634924173355, 69.13548901677132, 74.79017078876495, 73.23545381426811, 66.00319549441338, 40.61201937496662, 44.572987630963326, 33.467570543289185, 55.37206135690212, 84.31941345334053, 45.916325747966766, 0.8989537437446415, 0.14868749101879075, 0.07767095681629144, 0.06496952977613546, 0.06495502078905702, 0.3299778263317421, 0.2640093583613634, 0.30008298985194415, 0.11879443569341674, 0.20676958607509732, 0.42648213857319206, 0.22335872403346002, 5.453181434422731, 87.80857622623444, 67.19093576073647, 57.68499344587326, 25.211620554327965, 49.45575222373009, 46.55907265841961, 42.26691037416458, 75.44105306267738, 79.29545223712921, 59.004187658429146, 85.87039142847061, 30.146805234253407, 0.4470319702522829, 1.1060683988034725, 1.3422030466608703, 0.43726616771891713, 0.8109257672913373, 57.83931076526642, 68.03895905613899, 64.62602019309998, 63.11506167054176, 65.5439293384552, 61.97091266512871, 66.6369178891182, 61.07318043708801, 63.94009619951248, 62.1075115352869, 61.96604132652283, 62.901790514588356, 62.92305037379265, 57.42526598274708, 58.13829392194748, 56.98691390454769, 58.78264054656029, 54.783685728907585, 60.85745841264725, 59.808505699038506, 58.2249216735363, 52.31514059007168, 58.93476538360119, 59.858165234327316, 61.0823455452919, 56.84556528925896, 60.05673497915268, 61.67353682219982, 58.41638199985027, 55.01635104417801, 60.94920828938484, 56.81503012776375, 52.17510290443897, 50.70874638855457, 49.88792963325977, 53.70748087763786, 54.46938559412956, 51.89508073031902, 55.66356651484966, 54.27007108926773, 48.65152157843113, 42.74832174181938, 42.06554017961025, 43.009842708706856, 42.50522218644619, 41.88745513558388, 40.87203562259674, 44.713758677244186, 47.926383689045906, 51.25916965305805, 51.11730806529522, 48.765173479914665, 50.73534116148949, 51.96654349565506, 51.11307509243488, 50.74449107050896, 50.086309388279915, 53.743780329823494, 53.79830360412598, 56.13605976104736, 58.97933319211006, 58.56881842017174, 57.71623916924, 51.67603388428688, 58.10811594128609, 55.54719775915146, 57.48471759259701, 61.207024455070496, 57.88656882941723, 57.75453731417656, 51.689371168613434, 54.18192341923714, 51.1968719959259, 50.99246956408024, 55.11420339345932, 48.6225139349699, 52.047505751252174, 51.410283744335175, 48.04558329284191, 52.594748586416245, 49.19158659875393, 45.088836550712585, 39.81634587049484, 43.95452901721001, 42.657890394330025, 42.53726206719875, 43.314251974225044, 41.843160912394524, 45.257699489593506, 48.36273707449436, 49.98439505696297, 55.61277464032173, 54.41694460809231, 54.494479447603226, 49.38466563820839, 46.78112134337425, 51.041661724448204, 51.90684489905834, 48.585154339671135, 50.20381048321724, 52.589698657393456, 54.80901516973972, 53.063529431819916, 55.151768177747726, 57.94597864151001, 52.82376989722252, 41.7379255592823, 43.75022917985916, 46.37730561196804, 53.94853234291077, 48.641467317938805, 52.645111083984375, 57.747047916054726, 54.5631455630064, 56.85119278728962, 53.74365493655205, 53.86757008731365, 46.32975876331329, 60.60041360557079, 59.962652027606964, 66.11060053110123, 59.22013007104397, 65.23461073637009, 60.840898901224136, 72.54112467169762, 60.18748216331005, 67.5199145078659, 59.05081495642662, 69.06614273786545, 4.6718027628958225, 0.08549713413231075, 2.0373278902843595, 0.3469731565564871, 1.2637610058300197, 13.388309888541698, 85.744838565588, 77.15292200446129, 79.46744620800018, 78.09429109096527, 73.2244648039341, 48.18559058010578, 53.799424543976784, 45.2292238175869, 70.20657554268837, 91.86062559485435, 58.89205567538738, 1.5205514640547335, 0.2387453749543056, 0.2366761484881863, 0.2139098334009759, 0.17197274544741958], [0.043766571034211665, 0.0661057504476048, 0.09995026717660949, 0.02140681001037592, 0.03005689741257811, 0.24720188055653125, 0.03775254765059799, 3.0247590551152825, 59.86671857535839, 57.43735693395138, 47.751912251114845, 47.652422189712524, 28.86732079088688, 44.3727345764637, 31.87739387154579, 48.40963415801525, 75.49210712313652, 52.352971360087395, 68.33383843302727, 35.54722175002098, 0.21819106070324779, 0.6781177874654531, 0.24691293278010562, 0.24044634774327278, 0.008473812486045063, 32.371371164917946, 70.90012192726135, 54.746170341968536, 53.34650404751301, 56.57958336174488, 65.80055996775627, 58.96265588700771, 57.95173153281212, 54.89370882511139, 55.81878058612347, 56.13373428583145, 63.58549922704697, 55.88909961283207, 56.280433014035225, 53.00332926213741, 55.281432420015335, 57.03196428716183, 55.25215499103069, 55.14756940305233, 54.270511865615845, 53.076802119612694, 54.45326305925846, 54.67063419520855, 56.361623257398605, 54.41944107413292, 54.671367555856705, 56.38765946030617, 51.353773176670074, 50.98675087094307, 58.106698617339134, 55.473481714725494, 51.850045546889305, 48.55331964790821, 44.702439084649086, 43.83418947458267, 49.53083999454975, 49.82354588806629, 46.8095476180315, 48.26135091483593, 52.64340117573738, 46.62576287984848, 37.14785546064377, 39.04240719974041, 36.80200181901455, 40.396981313824654, 37.57191650569439, 38.015645295381546, 41.381611078977585, 41.592252776026726, 45.255305618047714, 45.96576489508152, 46.19893938302994, 45.8521281927824, 46.92065365612507, 47.27611318230629, 45.31464323401451, 46.8025141954422, 46.03030063211918, 47.504097148776054, 50.111733824014664, 53.25080618262291, 50.64946196973324, 52.928564473986626, 49.73229378461838, 51.37985497713089, 48.80355142056942, 50.67264452576637, 56.632522121071815, 50.18844410777092, 51.9086080044508, 49.58339497447014, 48.98966923356056, 45.36032818257809, 46.74021273851395, 44.55000266432762, 46.62923589348793, 43.36896903812885, 46.24700300395489, 41.78741030395031, 44.92201790213585, 41.03039212524891, 39.26392011344433, 37.09690399467945, 37.692506834864616, 37.8292652964592, 39.443069100379944, 39.366415813565254, 38.468645587563515, 36.07413187623024, 44.2406764626503, 52.3071002215147, 50.52134424448013, 48.92465852200985, 49.717523977160454, 45.70868209004402, 42.07390733063221, 45.93375161290169, 45.1398716121912, 45.26756376028061, 46.36617600917816, 48.2727313041687, 49.98581238090992, 48.02483260631561, 49.54755909740925, 52.41983637213707, 57.203749269247055, 60.98123677074909, 58.81647773087025, 48.656164929270744, 50.475032329559326, 68.33764582872391, 43.34223747253418, 45.25195799767971, 52.34320588409901, 55.549663826823235, 55.74039839208126, 44.261183962225914, 53.843004405498505, 64.90641474723816, 57.158094719052315, 57.62302257120609, 56.619230434298515, 60.935069248080254, 58.295369893312454, 57.86245912313461, 55.34349448978901, 57.36162319779396, 52.61680640280247, 47.077824622392654, 0.2988251089118421, 0.08097605212242343, 1.1426099692471325, 0.6619542860426009, 0.06964163883822039, 14.326637238264084, 74.5134088397026, 64.52800065279007, 65.77523812651634, 73.72794538736343, 68.38473290205002, 36.62440314888954, 33.850479796528816, 34.664760902523994, 47.9775707423687, 67.46655017137527, 27.436862848699093, 0.8656465716194361, 0.20300695672631264, 0.11097697861259803, 0.13616971584269777, 0.16384475893573835, 0.0543783773900941, 0.0596130640769843, 0.05617168077151291, 0.0679962825961411, 0.05481014777615201, 0.34277806291356683, 0.09360753916553222, 3.9311374817043543, 71.66458770632744, 62.78471119701862, 53.4291648119688, 39.177299961447716, 37.806941494345665, 47.80947536230087, 30.880942940711975, 57.09843032062054, 80.43486669659615, 58.23708862066269, 73.85561853647232, 39.61608901619911, 0.602831180440262, 0.5863602517638355, 0.4457476391689852, 0.16765665204729885, 0.19607633643317968, 38.89153629541397, 68.52548494935036, 57.91470251977444, 55.69974437355995, 59.4203033298254, 66.92467644810677, 62.21350684762001, 60.04555977880955, 57.94574685394764, 58.102119863033295, 58.95281821489334, 63.518953397870064, 56.20437249541283, 57.98901133239269, 56.45899683237076, 59.04332935810089, 56.87811054289341, 55.548558086156845, 57.48129017651081, 56.50763802230358, 55.63885264098644, 58.2267227768898, 55.02747684717178, 58.31119604408741, 57.224389761686325, 56.313833221793175, 56.53289146721363, 56.81693762540817, 53.09995427727699, 59.602134972810745, 57.13480196893215, 56.20784170925617, 51.058931797742844, 48.05577054619789, 47.53390274941921, 52.750859409570694, 51.76161289215088, 50.502831637859344, 51.15620657801628, 56.27806194126606, 48.65838021039963, 38.82084108889103, 41.22676178812981, 38.83964627981186, 40.36018408834934, 41.977612897753716, 39.81690064072609, 43.69573250412941, 44.432284981012344, 45.526592060923576, 45.78141398727894, 45.78860700130463, 48.56989435851574, 48.028598204255104, 49.00725468993187, 46.68663941323757, 48.72616097331047, 48.48944887518883, 48.819951340556145, 52.82428666949272, 54.02510583400726, 53.886797055602074, 54.490808844566345, 51.113865450024605, 51.88198663294315, 51.7010023444891, 53.41112717986107, 57.942646220326424, 53.41585412621498, 53.8311680406332, 50.990930646657944, 51.990087032318115, 45.870344415307045, 50.00636167824268, 48.44016931951046, 50.40938325226307, 45.9402796626091, 48.36641527712345, 42.58465692400932, 45.253360122442245, 43.72836895287037, 40.9662439674139, 39.4419139623642, 39.78966370224953, 38.72448205947876, 41.22043892741203, 40.274031311273575, 41.75979718565941, 37.87424348294735, 46.426402777433395, 54.195796474814415, 52.320163920521736, 52.124691009521484, 51.17493197321892, 48.82260739803314, 44.20551314949989, 48.11574272811413, 47.72163547575474, 47.90477804839611, 49.44257453083992, 49.95512902736664, 50.85945010185242, 52.38169401884079, 50.93290016055107, 52.515918016433716, 59.21311564743519, 63.45632515847683, 60.902501195669174, 51.44810691475868, 52.71937809884548, 58.95764775574207, 46.763193905353546, 44.9315781891346, 54.059801772236824, 55.758101642131805, 60.778418853878975, 48.19133207201958, 55.28645195066929, 68.17774280905724, 62.05427639186382, 60.733596459031105, 58.302068933844566, 64.26070019602776, 61.306385323405266, 61.11979253590107, 58.326319232583046, 61.99677027761936, 54.97584901750088, 52.24253788590431, 0.33445125503931195, 0.10218859199085273, 1.9397420017048717, 0.4693030205089599, 0.15904540865449235, 15.542704984545708, 81.76557809114456, 70.09661704301834, 70.66096276044846, 80.68303897976875, 73.17809209227562, 40.578596368432045, 46.005472764372826, 32.20253862440586, 55.529255121946335, 76.82180777192116, 34.85834151506424, 0.8289804984815419, 0.2693135174922645, 0.1168599164520856, 0.07478864819859155, 0.13478097942424938, 0.11273671465460211, 0.22442220681114122, 0.18319315742701292, 0.21688798296963796, 0.10967379697831348, 0.5221830017399043, 0.26417649001814425, 4.547472484409809, 83.51291432976723, 71.0209858417511, 67.13564872741699, 57.32890695333481, 46.88556253910065, 61.22009955346584, 38.713124468922615, 62.91132800281048, 88.39969530701637, 62.21164494752884, 80.50535291433334, 42.51391991972923, 1.1051765154115856, 1.2333301012404263, 0.698485525790602, 0.4689489566953853, 0.24380293325521052, 42.64007315039635, 75.26413455605507, 60.86079463362694, 60.46282298862934, 61.395524740219116, 67.6752045750618, 62.58581466972828, 60.871692448854446, 58.004997074604034, 60.695651695132256, 61.330681219697, 62.479203790426254, 58.77002902328968, 62.699861750006676, 58.719833716750145, 58.75869803130627, 59.4335950165987, 58.54758135974407, 57.54085198044777, 59.11111392080784, 60.157231986522675, 60.92968113720417, 57.878574058413506, 61.301179602742195, 58.704064562916756, 59.12046521902084, 57.10352964699268, 57.85470753908157, 55.32530106604099, 59.724218621850014, 60.1563960313797, 57.30055287480354, 54.15309816598892, 52.467759400606155, 50.02183824777603, 55.08042700588703, 54.83379743993282, 53.76587234437466, 57.48987391591072, 60.41346363723278, 53.41019622981548, 41.00589103996754, 41.84394747018814, 40.191340148448944, 44.3233410269022, 42.4980291724205, 43.06592769920826, 45.3816906362772, 47.5047393143177, 50.40291599929333, 50.02196364104748, 51.81365109980106, 52.77555048465729, 50.419027134776115, 51.62739649415016, 47.23640911281109, 50.91710440814495, 51.32242105901241, 51.77168235182762, 54.85687740147114, 56.55792832374573, 56.33125528693199, 56.510221883654594, 51.98145389556885, 57.864055037498474, 54.526344537734985, 53.90784032642841, 61.15842506289482, 55.746352672576904, 57.61965215206146, 53.62144589424133, 55.07723517715931, 49.78527054190636, 52.77762897312641, 51.140790805220604, 52.626750469207764, 48.32892648875713, 50.72293482720852, 45.14318123459816, 48.87156017124653, 45.97432963550091, 44.55033704638481, 39.94737423956394, 41.55529595911503, 41.522879898548126, 43.58115345239639, 44.27189938724041, 43.2504989951849, 40.06564289331436, 49.98930439352989, 60.38136675953865, 55.35275839269161, 54.86531674861908, 55.76176464557648, 51.43564358353615, 47.249628603458405, 51.01848676800728, 50.13653129339218, 50.87753713130951, 51.164562329649925, 53.30914065241814, 52.86473169922829, 51.71663470566273, 52.143515199422836, 56.56170152127743, 61.170725002884865, 66.49976804852486, 59.17187266051769, 48.24596934020519, 53.87408293783665, 67.90224239230156, 47.34751135110855, 48.23486253619194, 54.868656769394875, 57.76465617120266, 57.411655113101006, 48.12709651887417, 56.60313829779625, 65.14362081885338, 63.79775583744049, 64.90693911910057, 63.115441650152206, 67.5222247838974, 65.8555506169796, 67.13572472333908, 63.181881085038185, 66.33417293429375, 58.66999939084053, 57.57681705057621, 0.9408540360163897, 0.18055079999612644, 3.8979635993018746, 0.755721676396206, 0.39099554589483887, 17.034972310066223, 87.32460379600525, 75.9965680539608, 76.40501573681831, 86.37156933546066, 81.10845655202866, 54.576353654265404, 50.86005426943302, 41.77341565489769, 69.48409751057625, 85.84152817726135, 45.780494436621666, 1.0198359447531402, 0.3323035390349105, 0.38615724770352244, 0.24287385342177004, 0.3689450619276613], [0.015965242237143684, 0.14766488573513925, 0.039595226116944104, 0.10947496077278629, 0.025726319145178422, 0.16559647978283465, 0.022282416248344816, 2.745499452576041, 60.06923250854015, 64.2054283618927, 53.0931032449007, 57.23550036549568, 29.804166220128536, 56.22033163905144, 60.462123826146126, 53.46704117953777, 67.51255810260773, 60.68544924259186, 62.88018487393856, 50.54330326616764, 1.7028451384976506, 0.7310756645165384, 0.34107349812984467, 0.9291569574270397, 0.1008050431846641, 17.80810732394457, 65.37830382585526, 47.39047184586525, 54.042995274066925, 64.92184191942215, 62.45696738362312, 56.7449314892292, 55.69201558828354, 55.76434090733528, 56.490242555737495, 54.3636030703783, 53.60636070370674, 58.30753304064274, 61.32067255675793, 55.84860518574715, 57.33188599348068, 52.49035678803921, 53.84659141302109, 55.753025114536285, 56.068541184067726, 51.743867844343185, 54.48117636144161, 53.23081165552139, 53.327413871884346, 53.590773940086365, 55.17751559615135, 52.06357888877392, 59.83838729560375, 65.3772246837616, 58.03964361548424, 54.104377180337906, 52.02101357281208, 48.55380222201347, 44.781543239951134, 44.80862818658352, 49.58955064415932, 50.12141190469265, 49.6748598664999, 49.01333436369896, 49.12200093269348, 43.498010113835335, 39.27425175905228, 40.619637966156006, 38.269213289022446, 37.98039838671684, 38.38932104408741, 38.00108067691326, 41.41312658786774, 40.87025351822376, 41.62846863269806, 45.72617255151272, 43.29151399433613, 44.31359834969044, 47.64885038137436, 44.55372266471386, 44.763030633330345, 46.459973976016045, 45.7465660572052, 46.785814091563225, 43.96370552480221, 51.68727748095989, 50.14413468539715, 52.710444778203964, 52.513816729187965, 48.16316418349743, 46.61152124404907, 51.444086730480194, 53.885246738791466, 51.21362529695034, 51.56935080885887, 48.42543751001358, 51.09646238386631, 47.5530993193388, 42.5937270373106, 44.601843282580376, 45.17754279077053, 45.853074342012405, 44.761324524879456, 44.94173124432564, 43.55581261217594, 39.5551934838295, 36.91219210624695, 36.62115432322025, 38.89660902321339, 37.45991751551628, 36.83745391666889, 37.833300679922104, 36.16155378520489, 41.646593660116196, 48.2844802737236, 48.27093780040741, 51.896144673228264, 50.27371533215046, 49.37181852757931, 45.09439945220947, 44.58985112607479, 47.17990234494209, 46.826099529862404, 44.87235076725483, 49.061120599508286, 48.7381075322628, 52.09686130285263, 54.88169766962528, 50.46723514795303, 50.843506157398224, 51.09965801239014, 55.07205605506897, 56.15620627999306, 55.45388236641884, 52.19798527657986, 54.20746944844723, 58.73882509768009, 49.15087178349495, 41.98671340942383, 50.43167665600777, 46.338832676410675, 50.937592908740044, 56.302650421857834, 48.57736475765705, 51.28707155585289, 57.96823024749756, 57.166112288832664, 56.954801827669144, 56.32396727800369, 61.12160123884678, 55.31494282186031, 49.31202493607998, 62.85796366631985, 29.93444412946701, 0.05145484989043325, 0.3647312364773825, 2.1847146190702915, 2.591387084685266, 0.2273523691110313, 17.2384000942111, 75.09233817458153, 63.077819868922234, 68.91356572508812, 71.36632651090622, 69.3265351653099, 42.8231967240572, 36.67802207171917, 36.42617918550968, 45.6201696395874, 66.01130425930023, 16.17295816540718, 0.7877210655715317, 0.2197014054399915, 0.12306248987442814, 0.0530775966035435, 0.1426597379031591, 0.09203181121847592, 0.028486447990871966, 0.05848866952874232, 0.08682183062774129, 0.04808116900676396, 0.31985478359274566, 0.12708872265648097, 3.578053303062916, 72.66048386693001, 67.40326836705208, 62.10552804172039, 48.46037283539772, 33.04889000952244, 64.55215215682983, 59.53147396445274, 57.95762121677399, 75.32965824007988, 66.1862164735794, 67.39191457629204, 55.86252763867378, 2.2380005847662687, 0.9222800389397889, 0.42946034751366824, 1.5952033270150423, 0.12122033833293244, 20.45992612838745, 67.84548103809357, 49.80027973651886, 60.41720263659954, 66.26566261053085, 63.54259192943573, 57.18594342470169, 59.99601423740387, 58.6515361815691, 57.29508496820927, 55.03214679658413, 55.20827114582062, 61.32034197449684, 62.265450060367584, 59.19462203979492, 60.15280522406101, 52.96913109719753, 56.37226268649101, 57.18778632581234, 57.564558908343315, 55.03094606101513, 56.21414937078953, 55.916518941521645, 55.26006616652012, 56.65495611727238, 57.67033763229847, 54.07794959843159, 57.906795144081116, 66.30405575037003, 60.49453228712082, 55.379258170723915, 56.645487025380135, 49.88907337188721, 47.87942960858345, 47.11618736386299, 53.341252729296684, 52.48048111796379, 53.40524509549141, 50.992157980799675, 52.38678954541683, 45.03611817955971, 39.70499284565449, 41.398736760020256, 41.064525693655014, 41.53601959347725, 40.07108420133591, 39.62768979370594, 43.470716178417206, 41.15589939057827, 45.507194101810455, 46.1471101641655, 45.41635237634182, 45.566653311252594, 48.9556572586298, 46.442396119236946, 48.67277003824711, 49.252672120928764, 48.23511332273483, 48.07076454162598, 46.919183135032654, 53.53240147233009, 53.72365280985832, 55.13131767511368, 54.122650399804115, 51.645202338695526, 50.7657927274704, 54.59903463721275, 57.508287727832794, 51.18019849061966, 53.75818155705929, 52.1487171202898, 53.009864911437035, 48.83566729724407, 45.900340005755424, 46.07853144407272, 48.168058320879936, 47.71043747663498, 47.70954832434654, 48.71065020561218, 46.40638165175915, 41.71110659837723, 38.927307575941086, 38.69022309780121, 41.18801526725292, 39.117247983813286, 38.79857428371906, 37.92626269161701, 38.32354657351971, 44.54435236752033, 51.67582109570503, 51.950014382600784, 54.453027471899986, 52.24494695663452, 52.76910603046417, 48.01394239068031, 47.111259028315544, 47.167469412088394, 50.17378829419613, 47.12028354406357, 50.99051646888256, 49.98963497579098, 53.859073743224144, 54.78389851748943, 53.508204370737076, 52.26418912410736, 54.37439449131489, 56.072853952646255, 57.346131429076195, 55.39261445403099, 50.658558681607246, 47.56048992276192, 62.801331505179405, 53.91536772251129, 44.166075065732, 50.219602435827255, 48.36207590997219, 52.594011425971985, 59.27904970943928, 52.23680779337883, 54.64630410075188, 59.92435768246651, 62.15761944651604, 61.565561816096306, 60.426390543580055, 63.7989641726017, 58.43629293143749, 55.859597995877266, 64.4866056740284, 34.841839000582695, 0.07031616944004782, 0.5541906435973942, 5.267741410061717, 2.856825403869152, 0.30731248785741627, 18.993415720760822, 81.96684569120407, 70.10364666581154, 71.38562947511673, 79.73305955529213, 72.28844583034515, 47.932360768318176, 43.10168378055096, 33.01926299929619, 52.73434929549694, 75.2573025226593, 22.344807386398315, 0.8213652914855629, 0.3603782138088718, 0.12940591550432146, 0.05270352077786811, 0.11127063902677037, 0.1903610274894163, 0.2562076348112896, 0.11106433681561612, 0.2736912982072681, 0.18034023785730824, 0.44161663739942014, 0.33311948587652296, 4.230912420898676, 85.33887594938278, 76.45960360765457, 72.12781324982643, 65.51887348294258, 47.73648127913475, 72.98447728157043, 71.91839888691902, 67.52310633659363, 80.82974910736084, 70.48087522387505, 72.93543711304665, 60.61248175799847, 3.231073971837759, 1.3702714280225337, 3.5445312643423676, 2.253627246245742, 0.27315689250826836, 24.25890527665615, 72.46754541993141, 54.489486515522, 59.975746124982834, 67.43565782904625, 65.3930926322937, 59.51524883508682, 61.08425684273243, 60.493088364601135, 61.623580902814865, 55.11045679450035, 57.77221016585827, 63.14835548400879, 64.77691769599915, 60.390417873859406, 64.75833669304848, 55.35994000732899, 57.063768580555916, 61.80130876600742, 61.7249708622694, 58.05853620171547, 58.71268630027771, 59.05230447649956, 57.552768141031265, 58.33264969289303, 60.18820412456989, 56.23227059841156, 59.21539932489395, 63.92449423670769, 61.385516077280045, 59.307627975940704, 57.722573429346085, 53.9092842489481, 52.30091795325279, 49.61139187216759, 57.013911455869675, 56.65980465710163, 56.74474909901619, 56.3476400077343, 55.39839394390583, 47.524429857730865, 41.08370326459408, 43.82671147584915, 43.292463943362236, 41.713025495409966, 43.73976074159145, 41.94031409919262, 46.47481977939606, 44.185465425252914, 48.42733360826969, 49.07095067203045, 49.38704051077366, 48.33855897188187, 51.00636161863804, 49.47453461587429, 50.064794942736626, 49.35596577823162, 50.42799085378647, 51.60865969955921, 50.57655148208141, 57.445800080895424, 57.47246325016022, 55.387917906045914, 55.305743515491486, 55.33245988190174, 52.641132697463036, 54.22520689666271, 59.993848353624344, 55.366506054997444, 58.9129963517189, 54.347970709204674, 54.82053615152836, 51.54886230826378, 48.48357439041138, 50.3589029610157, 49.931802079081535, 51.32351540029049, 49.778905883431435, 51.732540652155876, 50.04107281565666, 42.57078006863594, 40.71565881371498, 42.02772460877895, 44.020102098584175, 41.661059483885765, 40.6992968916893, 41.53899863362312, 41.52924455702305, 48.49364385008812, 55.16475588083267, 56.173757538199425, 57.59096369147301, 55.62182575464249, 54.739205315709114, 49.46696162223816, 50.97608104348183, 49.44886699318886, 53.53535771369934, 48.54382775723934, 54.16127912700176, 51.876473128795624, 56.807137951254845, 56.455983594059944, 55.58972887694836, 53.66219110786915, 54.862835481762886, 59.870392978191376, 60.9943650662899, 57.45403803884983, 51.53720833361149, 61.79409675300121, 62.93368220329285, 52.140942737460136, 46.53809778392315, 52.63391688466072, 47.400818690657616, 54.980169385671616, 56.6670660674572, 56.12752161920071, 59.265248849987984, 64.49105143547058, 63.50997447967529, 63.78673642873764, 62.18637630343437, 68.3414988219738, 61.46641753613949, 60.84083430469036, 67.8330785036087, 41.133719980716705, 0.1109184231609106, 0.6813197687733918, 10.65381322056055, 5.2658419869840145, 0.5281985539477319, 20.496254079043865, 90.28955429792404, 75.49161314964294, 80.83987176418304, 84.58565756678581, 83.02275583148003, 60.120582953095436, 55.41236199438572, 47.090078964829445, 62.69737668335438, 86.29823327064514, 31.54539618641138, 1.1752531863749027, 0.5380467348732054, 0.18419324595015496, 0.22337368573062122, 0.17004207795253024], [0.022666371914965566, 0.04610954238160048, 0.05225444721872918, 0.021859449589101132, 0.04212597195873968, 0.2056701685069129, 0.031049536628415808, 1.4367501670494676, 59.324358478188515, 58.54854270815849, 42.25255474448204, 33.71659018099308, 29.308955892920494, 48.29833813011646, 48.332581892609596, 55.08643828332424, 64.05706152319908, 64.48765441775322, 55.035642609000206, 61.81667894124985, 6.729977047070861, 1.0795141174457967, 0.029340003165998496, 0.3478437551530078, 0.21758068876806647, 6.522311540320516, 61.145007982850075, 45.393872782588005, 62.63772368431091, 54.18837167322636, 61.81651175022125, 55.54009974002838, 55.6551917642355, 53.52976821362972, 59.12415102124214, 54.4320297986269, 57.30726711452007, 54.80645410716534, 58.66149544715881, 57.40648739039898, 60.190290212631226, 50.4568313062191, 55.059995502233505, 54.31400813162327, 54.319612830877304, 51.31038710474968, 54.694451317191124, 53.2298769056797, 54.476274624466896, 52.656559869647026, 53.624044954776764, 58.843976855278015, 62.07924485206604, 45.55238127708435, 48.60730715095997, 52.34289050102234, 52.64112509787083, 44.897197633981705, 44.03964824974537, 43.99951860308647, 50.1136527210474, 48.751608207821846, 52.24986769258976, 47.98547051846981, 50.77189140021801, 48.935905918478966, 40.65027192234993, 39.0810739248991, 40.29143437743187, 36.80543303489685, 40.72414755821228, 39.214173182845116, 41.495635360479355, 41.25212922692299, 41.155329421162605, 42.07548804581165, 44.39519517123699, 45.86779095232487, 46.86518803238869, 46.41278810799122, 46.72950491309166, 44.782770574092865, 47.8179869055748, 47.42389865219593, 50.116597563028336, 52.17462792992592, 51.81736350059509, 51.20750002563, 51.530877873301506, 45.137158557772636, 46.276952996850014, 49.27130252122879, 55.18876679241657, 50.80183759331703, 49.520622342824936, 45.99021278321743, 48.28926041722298, 47.6769232749939, 46.35347329080105, 44.82367157936096, 44.982822239398956, 43.09118114411831, 45.52734822034836, 42.13670276105404, 41.752478778362274, 39.37192551791668, 37.638207748532295, 38.58109675347805, 37.11608536541462, 37.0710463821888, 37.23167896270752, 37.13800258934498, 37.004587948322296, 40.81233322620392, 51.81612476706505, 48.39774079620838, 48.38495448231697, 47.999358773231506, 51.03237882256508, 47.565479055047035, 43.94270405173302, 46.396053805947304, 48.03769871592522, 52.74848073720932, 54.135075733065605, 53.13324809074402, 55.04194267094135, 58.71871277689934, 52.79288895428181, 53.37063655257225, 54.473648965358734, 56.59205049276352, 54.420432820916176, 50.79311326146126, 44.152099415659904, 25.977786742150784, 56.73127122223377, 64.91338357329369, 61.903492882847786, 52.47344769537449, 45.98279558122158, 49.3669243901968, 43.237230107188225, 55.13218402862549, 58.00880067050457, 57.739208936691284, 55.86620584130287, 60.18356457352638, 59.60820324718952, 61.887431144714355, 63.670667856931686, 54.379615411162376, 62.61796474456787, 20.418314561247826, 0.5046927777584642, 0.5466768436599523, 0.8757857338059694, 1.530190953053534, 0.30557414051145315, 20.409196950495243, 73.51228415966034, 61.68030425906181, 67.23942875862122, 66.90071493387222, 69.81731683015823, 45.665611401200294, 40.522093400359154, 28.429493084549904, 46.59746579825878, 65.23018017411232, 8.284380063414574, 0.8507777319755405, 0.1736522256396711, 0.06988530076341704, 0.09354886497021653, 0.08250827537267469, 0.057845379633363336, 0.06770032152417116, 0.06822375085903332, 0.08753037385758944, 0.050970887969015166, 0.2596328838262707, 0.12136018121964298, 1.8484853859990835, 71.09107688069344, 66.35640174150467, 54.06514808535576, 39.06103380024433, 34.78841386735439, 57.765184342861176, 52.5609266012907, 59.76370610296726, 67.75565385818481, 71.0812658071518, 61.63677379488945, 68.31438347697258, 6.268235323950648, 1.2698037503287196, 0.14012022729730234, 0.9175817098002881, 0.1336965087102726, 8.033752162009478, 64.04110237956047, 47.63300523161888, 67.26689368486404, 55.1948768645525, 63.98565575480461, 56.62626385688782, 57.626617178320885, 55.43109118938446, 61.53582081198692, 56.154180988669395, 59.912084341049194, 57.448159754276276, 59.44596715271473, 57.80963055789471, 60.38488157093525, 52.111821100115776, 57.94707678258419, 56.70811526477337, 56.89734511077404, 53.62108111381531, 58.636766374111176, 55.72886981070042, 56.92450225353241, 52.50125080347061, 54.30873401463032, 55.2705954015255, 61.534646674990654, 47.33729749917984, 51.52308829128742, 54.78750452399254, 56.0940758138895, 47.66582407057285, 45.58109633624554, 46.01055309176445, 51.964841187000275, 50.44984728097916, 54.75733034312725, 50.71632698178291, 55.2723129093647, 52.12284430861473, 43.756141662597656, 41.00872188806534, 41.28038831055164, 37.51007862389088, 40.117183327674866, 40.648843199014664, 42.24460557103157, 43.01495723426342, 42.50035084784031, 45.75062803924084, 47.44266204535961, 46.93837970495224, 49.91358205676079, 49.376507475972176, 48.99821877479553, 47.93969437479973, 49.23019252717495, 49.727661833167076, 50.565421879291534, 52.661104425787926, 53.592609241604805, 52.09145039319992, 52.791300639510155, 49.56161454319954, 50.030338391661644, 52.6181211322546, 54.301913380622864, 52.021309956908226, 52.31843501329422, 48.228323087096214, 51.36778682470322, 49.21546071767807, 46.48572899401188, 47.99113221466541, 46.07068866491318, 44.768734127283096, 47.508102133870125, 44.95211988687515, 44.15982060134411, 41.73924408853054, 39.541058242321014, 40.141106843948364, 39.20543745160103, 39.5006588101387, 38.35556745529175, 38.906803876161575, 39.61037032306194, 44.48102116584778, 51.570065170526505, 50.97971744835377, 51.22635081410408, 52.00412727892399, 55.644438341259956, 49.736553356051445, 46.80547423660755, 45.73434591293335, 51.00740656256676, 53.524300307035446, 55.61711400747299, 53.929597958922386, 58.410697504878044, 60.2386312186718, 57.141493409872055, 55.55662125349045, 57.10729144513607, 58.84923197329044, 58.96994769573212, 52.65264227986336, 46.80461548268795, 28.65458730608225, 56.356288343667984, 66.34355083107948, 62.113344222307205, 54.76622946560383, 48.99226449429989, 53.551799431443214, 47.60980747640133, 56.68478451669216, 61.14063061773777, 62.134592682123184, 59.34933453798294, 62.697433680295944, 62.328709065914154, 63.723017647862434, 64.97348874807358, 59.56972271203995, 66.7790150642395, 24.937326572835445, 0.5369268043432385, 0.528815605212003, 2.6606431184336543, 2.4932461883872747, 0.28815290657803416, 23.17746240645647, 81.60695180296898, 67.43331715464592, 73.0259482562542, 74.46457386016846, 76.44687429070473, 54.804994985461235, 46.126982644200325, 26.854215413331985, 52.65720583498478, 77.81223982572556, 13.392715752124786, 0.9806880110409111, 0.26873562193941325, 0.1212366136314813, 0.057701195182744414, 0.12095739541109651, 0.15186720789643005, 0.1939907085034065, 0.1250485290074721, 0.19410249078646302, 0.16502235434018075, 0.4901329684071243, 0.33825422753579915, 2.647192315198481, 84.63263064622879, 75.06888583302498, 58.346040174365044, 44.078276976943016, 44.66548606753349, 64.9341532588005, 56.71518288552761, 66.14121928811073, 75.71395441889763, 76.53882175683975, 66.83530524373055, 74.6920220553875, 7.569005750119686, 1.7807923746295273, 1.5571750863455236, 1.7953923786990345, 0.27043953363317996, 9.21561224386096, 72.58961766958237, 52.343642860651016, 67.43924483656883, 59.37838397920132, 66.73489943146706, 60.98361164331436, 60.17770528793335, 57.38178491592407, 63.723173439502716, 57.854057773947716, 63.064357191324234, 60.16549654304981, 63.90357255935669, 61.84481643140316, 62.803508788347244, 54.3229528516531, 59.7748889029026, 57.419980466365814, 59.90159310400486, 55.648861303925514, 63.021275103092194, 60.724009573459625, 59.96112830936909, 54.654029086232185, 57.95774281024933, 54.691571071743965, 62.237529158592224, 52.213822826743126, 53.92321430146694, 56.42175503075123, 60.75236365199089, 49.467584788799286, 49.35863323509693, 49.34038661420345, 55.24071380496025, 53.1342626363039, 58.48498731851578, 53.968724459409714, 57.497595101594925, 56.07059687376022, 45.29568985104561, 44.16430816054344, 45.37529557943344, 40.77908881008625, 43.55236239731312, 44.54291604459286, 44.7331490367651, 45.8047903329134, 43.43057133257389, 47.63286843895912, 49.40076157450676, 49.695811942219734, 52.93055936694145, 50.105217173695564, 49.96240183711052, 49.7204802185297, 54.94051091372967, 53.407369181513786, 52.705524042248726, 53.564756736159325, 59.22779805958271, 53.830981850624084, 53.45078565180302, 53.06918352842331, 54.53652799129486, 54.41999964416027, 58.24660710990429, 54.62218679487705, 55.80814875662327, 52.50163838267326, 54.3574246019125, 52.71687023341656, 50.14784328639507, 49.539298340678215, 49.07612219452858, 47.00888492166996, 52.6334685087204, 47.307913675904274, 46.82790823280811, 43.74311976134777, 42.79557980597019, 44.11454223096371, 41.1013875156641, 40.827483013272285, 41.74384564161301, 41.02688491344452, 42.76845306158066, 46.32592096924782, 57.066846415400505, 53.73178817331791, 54.97354634106159, 54.06560406088829, 59.4630092382431, 54.6798525005579, 49.36248242855072, 48.358067125082016, 52.81007543206215, 57.187858521938324, 60.04816263914108, 58.49036782979965, 60.64435824751854, 60.72594366967678, 58.090553283691406, 58.556982055306435, 61.072967648506165, 61.89969688653946, 59.83175665140152, 52.575232833623886, 49.979360327124596, 33.03531713783741, 57.60033778846264, 64.13884833455086, 61.149286553263664, 57.26005844771862, 53.53019379079342, 57.014040648937225, 51.172006130218506, 63.51468622684479, 63.850762993097305, 66.56192511320114, 61.18209019303322, 65.65134197473526, 63.19965273141861, 67.85239666700363, 68.65189656615257, 66.66465640068054, 68.9294944703579, 31.927718371152878, 0.6145699974149466, 1.6986963548697531, 6.221019057556987, 2.779087037779391, 0.4832483909558505, 26.042966544628143, 87.48706787824631, 73.75194489955902, 79.38198119401932, 82.57976040244102, 80.7070916891098, 65.30027881264687, 56.997078359127045, 38.876850083470345, 66.95895820856094, 91.56937882304192, 21.84064093977213, 1.4477676758542657, 0.6427606253419071, 0.30346655985340476, 0.2197130720014684, 0.32774402119684964], [0.06999059667577967, 0.14040602836757898, 0.04595047787006479, 0.09059675736352801, 0.0006884514368721284, 0.20586095983162522, 0.12076995859388262, 1.2159320223145187, 55.363633409142494, 57.68456406891346, 42.902946844697, 27.06785324960947, 24.546547941863537, 49.113952964544296, 57.35466957092285, 64.97769892215729, 62.153021693229675, 65.9103512763977, 53.43910127878189, 65.84539756178856, 8.042348250746727, 0.4393314162734896, 0.26928617677185684, 1.3206865824759007, 0.16532040084712207, 1.2024765880778432, 47.14210197329521, 53.29295352101326, 57.45846100151539, 50.78166447579861, 59.30557228624821, 52.27847635746002, 56.30026414990425, 50.02812311053276, 59.596116095781326, 50.851440131664276, 53.13865900039673, 57.83210635185242, 57.71468885242939, 54.08137321472168, 58.297531977295876, 51.41492709517479, 54.704304188489914, 57.380439788103104, 55.49286067485809, 48.18823903799057, 50.50034277141094, 54.04978930950165, 54.15566302835941, 51.84773527085781, 55.95687657594681, 52.36377038061619, 37.80512139201164, 48.851086869835854, 56.68579526245594, 53.810778334736824, 50.43958403170109, 45.08336864411831, 45.220404490828514, 45.12550838291645, 50.920520424842834, 48.340702056884766, 47.48236991465092, 48.08273009955883, 48.09064507484436, 49.79861922562122, 42.11206488311291, 37.92235270142555, 41.38043314218521, 40.02690777182579, 37.20656231045723, 37.595733627676964, 40.70012144744396, 40.073630064725876, 42.973680049180984, 42.38610617816448, 43.39137263596058, 44.71032366156578, 44.177679643034935, 44.55951355397701, 47.48266629874706, 46.40094414353371, 44.42104138433933, 47.16685004532337, 49.68423776328564, 54.511688724160194, 52.66132101416588, 50.711037665605545, 41.67327202856541, 46.2228325009346, 44.65564079582691, 50.827239230275154, 53.08922365307808, 48.83799657225609, 45.360282585024834, 43.274798691272736, 48.6711323261261, 47.75452271103859, 46.95331670343876, 44.6754415333271, 45.15241473913193, 43.8168890029192, 43.950489833950996, 41.74129977822304, 38.860111981630325, 40.58311052620411, 37.863520458340645, 39.44430783390999, 38.660181909799576, 39.31177854537964, 41.465742364525795, 37.734798565506935, 37.83854439854622, 43.45877721905708, 47.158346101641655, 46.3271065056324, 48.45223747193813, 45.81292949616909, 48.340831249952316, 44.77605253458023, 46.06768682599068, 45.48197105526924, 51.70711621642113, 51.41062952578068, 53.02092991769314, 52.73631379008293, 53.894438445568085, 57.551464810967445, 52.94024884700775, 53.42664174735546, 52.102378606796265, 56.38068303465843, 55.94934158027172, 54.123885333538055, 54.50215503573418, 59.69994932413101, 54.4637580960989, 55.05504436790943, 59.13518562912941, 56.79361067712307, 52.671721056103706, 50.93959540128708, 56.17432750761509, 54.32736821472645, 53.64853464066982, 61.27551957964897, 58.095329627394676, 58.87614592909813, 57.3951032012701, 63.20724472403526, 58.14666487276554, 52.91145399212837, 66.45754471421242, 14.285518694669008, 0.42644743574783206, 0.7128021481912583, 3.678930290043354, 2.224420588463545, 0.27432660630438477, 30.920971892774105, 70.69117113947868, 62.618637308478355, 63.89949157834053, 69.96870070695877, 57.373022586107254, 44.13929410278797, 38.68297688663006, 33.63176353275776, 50.272776782512665, 64.96962815523148, 9.5063241943717, 1.011344944126904, 0.1937203441048041, 0.052805595769314095, 0.1245553421904333, 0.06910975644132122, 0.1816337715717964, 0.026624991332937498, 0.01427066583346459, 0.1311332790646702, 0.01802419552404899, 0.24619585485197604, 0.09014633309561759, 1.734863764140755, 66.65391057729721, 66.03836640715599, 49.43060137331486, 28.111868128180504, 31.515092812478542, 60.173491314053535, 58.76977063715458, 71.14113539457321, 70.06080016493797, 73.19834500551224, 57.84694455564022, 73.45713391900063, 9.65913774445653, 0.31126341491471976, 0.3869636356830597, 1.1006009671837091, 0.1806204579770565, 1.5117779723368585, 50.97113370895386, 54.55521158874035, 60.75608745217323, 53.6873609572649, 60.48485040664673, 54.46568079292774, 58.58580730855465, 51.507672518491745, 60.21880388259888, 52.154937386512756, 56.5638218075037, 58.788674622774124, 60.26088282465935, 56.054922714829445, 60.52063688635826, 52.356014996767044, 54.876298159360886, 59.002291560173035, 58.40584896504879, 48.99469256401062, 54.61868718266487, 56.079678386449814, 55.19362673163414, 53.09418998658657, 55.107622146606445, 52.63943038880825, 40.86174197494984, 48.08043882250786, 58.88647757470608, 56.8873630464077, 53.77468027174473, 46.48833945393562, 46.551609858870506, 47.45451740920544, 52.91681170463562, 51.07075676321983, 52.68763080239296, 51.628669425845146, 50.617646276950836, 52.29727014899254, 44.11888159811497, 39.82890419661999, 43.21481131017208, 39.12787601351738, 38.24202574789524, 38.79126347601414, 41.48076295852661, 41.819803565740585, 44.945664033293724, 44.05154921114445, 46.2342394888401, 46.242618039250374, 47.893667444586754, 47.223672196269035, 49.87659864127636, 48.59898179769516, 46.63526237010956, 50.895361974835396, 52.30653405189514, 55.06687693297863, 54.5227575302124, 51.184731647372246, 45.62416322529316, 48.701819479465485, 49.144385531544685, 52.051913514733315, 54.75872106850147, 51.39603830873966, 49.09631811082363, 46.698536574840546, 51.422511488199234, 51.3268668204546, 49.04816709458828, 48.30176554620266, 48.04157070815563, 46.02957867085934, 46.26290515065193, 43.89299891889095, 40.98844237625599, 40.907138139009476, 39.702245593070984, 40.066957622766495, 40.45766405761242, 41.77240490913391, 42.62745022773743, 38.25410149991512, 40.70902056992054, 44.2753192037344, 48.744559586048126, 47.33336851000786, 50.58934159576893, 48.26739639043808, 51.74341566860676, 48.094482868909836, 48.85371632874012, 47.503230795264244, 52.55901150405407, 52.68024019896984, 55.578211694955826, 55.23075073957443, 56.219043508172035, 59.545916989445686, 55.89793033897877, 56.16142340004444, 55.91054566204548, 57.40501306951046, 58.47337134182453, 56.14531986415386, 54.95788358151913, 61.50965541601181, 56.29595898091793, 55.02019643783569, 59.473481476306915, 58.78795646131039, 56.18867553770542, 53.42891402542591, 58.054014444351196, 58.044708743691444, 56.95328190922737, 61.449512243270874, 59.253784865140915, 60.232847929000854, 60.56384816765785, 66.46403476595879, 62.65647567808628, 57.32594691216946, 66.68145149946213, 16.62099402397871, 0.6928732863161713, 1.272442708723247, 4.144951058551669, 2.8843259532004595, 0.25115141237620264, 34.14774924516678, 77.90647476911545, 68.71989011764526, 69.33953806757927, 80.01854583621025, 64.6528847515583, 53.855893313884735, 36.3274072855711, 26.989548951387405, 59.749259278178215, 74.12084430456161, 13.168046157807112, 0.9541818802244961, 0.3032024740241468, 0.054317903486662544, 0.14834283763775602, 0.029901615998824127, 0.3723961376817897, 0.28796808212064207, 0.18868377374019474, 0.20828521490329877, 0.07381819363217801, 0.4350119683658704, 0.17060539772501215, 2.09526551887393, 75.40623933076859, 77.56478190422058, 60.67191056907177, 40.495665818452835, 36.583726331591606, 67.67732486128807, 65.26195406913757, 80.75397357344627, 73.96547824144363, 80.08884966373444, 62.188770174980164, 79.52993005514145, 9.71870619803667, 0.4448887665057555, 0.9548153181094676, 4.158278368413448, 0.24804988817777485, 1.5371984895318747, 60.54632730782032, 58.355790451169014, 63.277768939733505, 56.0227270424366, 63.36603440344334, 58.443660736083984, 61.47100389003754, 53.61092045903206, 62.31329329311848, 54.151566848158836, 58.16400334239006, 61.675417721271515, 62.59173095226288, 58.30597512423992, 62.131222262978554, 55.07986843585968, 58.66854026913643, 61.728892251849174, 60.47078736126423, 51.55134357511997, 55.9383487701416, 60.51171496510506, 57.01342508196831, 55.43047942221165, 55.8819255977869, 55.75702629983425, 45.7081501185894, 49.20900486409664, 61.97060868144035, 58.51062834262848, 54.62850585579872, 48.49361725151539, 48.26624885201454, 49.85897518694401, 57.04649090766907, 55.159185379743576, 56.25283509492874, 57.09877610206604, 52.646456211805344, 53.78497391939163, 46.549755558371544, 42.04076170921326, 45.48827111721039, 42.2278256714344, 40.018620416522026, 41.28590561449528, 43.70516739785671, 43.28354962170124, 47.27953299880028, 47.055367827415466, 46.63987532258034, 49.17101830244064, 49.59590010344982, 49.33461852371693, 53.296217545866966, 52.03536920249462, 47.6787243783474, 53.90965662896633, 54.70017001032829, 59.65478114783764, 59.189249128103256, 53.89875881373882, 51.22346296906471, 54.64622050523758, 51.071683913469315, 55.34824803471565, 57.06337720155716, 54.70062218606472, 51.37607418000698, 49.53673727810383, 54.57733400166035, 53.24383735656738, 52.37131677567959, 49.789932891726494, 52.11726240813732, 51.084702014923096, 51.79719798266888, 45.611072927713394, 44.4293325394392, 43.656985983252525, 42.17242084443569, 44.83224771916866, 43.732294142246246, 43.764930590987206, 45.24766802787781, 40.49283117055893, 43.901601657271385, 46.73857882618904, 54.912768602371216, 50.254803746938705, 54.271841794252396, 50.170946046710014, 54.127221554517746, 49.82291892170906, 50.66319443285465, 49.776094034314156, 56.5616749227047, 56.81947208940983, 58.516575023531914, 55.34157179296017, 57.456416711211205, 59.617896527051926, 56.68776735663414, 59.38084624707699, 57.267266660928726, 59.9683403223753, 61.04522533714771, 57.94051833450794, 57.79027819633484, 64.16629046201706, 57.72220104932785, 59.07601520419121, 64.22435134649277, 61.549739465117455, 57.187421545386314, 55.76686017215252, 60.933594927191734, 61.34023390710354, 58.015579506754875, 66.66749864816666, 60.6718497723341, 64.25196066498756, 61.09296217560768, 70.23517280817032, 65.26072293519974, 63.038514778018, 72.01112151145935, 20.230853520333767, 0.8406412415206432, 3.904752884991467, 10.21376358345151, 3.841445669531822, 0.4238890449050814, 36.973741203546524, 82.97818422317505, 72.90149733424187, 74.70475897192955, 84.76436197757721, 69.39085811376572, 64.14710149168968, 53.915284126996994, 43.51201616227627, 71.07893273234367, 88.82543206214905, 19.11236073821783, 1.5086600021459162, 0.5255808506626636, 0.33633331186138093, 0.20052239473443478, 0.3089526342228055], [0.021790389037050772, 0.069383223017212, 0.0341239947010763, 0.010046388160844799, 0.04993735085008666, 0.03760329062060919, 0.07846414198866114, 0.7761872594710439, 51.53985679149628, 64.68464344739914, 41.64640747010708, 36.50833457708359, 39.15638968348503, 40.784872099757195, 46.07316613197327, 60.90394511818886, 61.64894834160805, 64.40292656421661, 56.0868676006794, 66.03981032967567, 11.545847654342651, 0.09857206183369271, 1.0442808642983437, 0.8854862570296973, 0.33616101485677063, 0.02712310972128762, 33.218239322304726, 60.02353996038437, 53.925490379333496, 53.03655467927456, 56.396953761577606, 55.73702797293663, 59.16502542793751, 51.30961574614048, 55.426892414689064, 52.682987451553345, 55.90872175991535, 57.82124273478985, 55.95417492091656, 53.97107653319836, 55.98066709935665, 53.552023619413376, 53.720696568489075, 56.56838156282902, 54.0450319647789, 47.03829914331436, 47.80550457537174, 50.10974273085594, 51.99549414217472, 52.05886334180832, 51.844627037644386, 38.16572584211826, 53.044560849666595, 58.09141583740711, 52.18294948339462, 52.81881496310234, 48.67826834321022, 44.32196170091629, 45.507357493042946, 43.578239008784294, 52.06555858254433, 47.215920612215996, 48.57956483960152, 47.97021433711052, 49.62511293590069, 48.82667317986488, 46.21166110038757, 40.96237577497959, 41.123806312680244, 39.54180680215359, 38.31653594970703, 36.830382496118546, 40.064780339598656, 40.67264512181282, 42.01967664062977, 41.87876120209694, 44.499077796936035, 45.547171756625175, 46.959316581487656, 44.56432789564133, 46.41922116279602, 46.82364486157894, 46.32439725100994, 47.79307544231415, 55.65495617687702, 49.00028966367245, 50.81800192594528, 48.89232225716114, 37.15965002775192, 40.1369346678257, 42.30336181819439, 48.28236758708954, 52.92183883488178, 47.56507247686386, 48.37531439960003, 47.754594907164574, 46.27317599952221, 48.55998449027538, 46.134639233350754, 46.398181691765785, 44.73483234643936, 42.463568821549416, 42.59751543402672, 41.111947149038315, 38.78383867442608, 38.25637757778168, 39.16392847895622, 38.42236407101154, 36.29433386027813, 38.295264691114426, 39.91393983364105, 37.13915392756462, 40.76124496757984, 44.844616055488586, 49.97333385050297, 50.77442966401577, 49.11682941019535, 49.10558961331844, 47.65571281313896, 47.15035133063793, 42.33413636684418, 47.80612014234066, 47.49658115208149, 54.63297061622143, 52.414961233735085, 55.32964423298836, 52.30835035443306, 53.79316247999668, 52.557609379291534, 54.92538392543793, 54.69008535146713, 55.06921760737896, 54.03396315872669, 55.663919895887375, 55.52097536623478, 53.55203501880169, 56.523779556155205, 58.22401352226734, 58.04926089942455, 59.52804654836655, 59.805579856038094, 54.08309452235699, 48.504788652062416, 52.72444322705269, 56.769664362072945, 58.34405668079853, 56.767528876662254, 56.927371099591255, 59.73147243261337, 59.516270980238914, 64.00822654366493, 53.21331739425659, 65.66821306943893, 12.672228813171387, 0.6792889558710158, 0.5305471841711551, 1.8466616026125848, 2.3154998011887074, 0.0343726030405378, 40.71786269545555, 68.20246428251266, 63.85936573147774, 65.10696038603783, 69.91529077291489, 54.0107312053442, 41.64574630558491, 46.53671085834503, 44.0015134960413, 49.45989400148392, 53.80404889583588, 3.9917299803346395, 0.5422389192972332, 0.07352699714829214, 0.05616935042780824, 0.05501891391759273, 0.04562075650028419, 0.01917918139952235, 0.028033914168190677, 0.03883684395987075, 0.024157151783583686, 0.10609355042106472, 0.026009081120719202, 0.11942516473936848, 0.9355871623847634, 61.273026913404465, 72.30411618947983, 48.54254722595215, 37.777477875351906, 44.05445985496044, 51.30462661385536, 57.189256846904755, 71.47841289639473, 67.15282380580902, 71.17612391710281, 61.672203093767166, 71.81923180818558, 12.915069982409477, 0.13344797829631716, 1.1950160446576774, 1.5782026830129325, 0.31928573444020003, 0.17700563475955278, 39.52530808746815, 61.714768409729004, 56.1455250531435, 54.03176687657833, 58.43809403479099, 57.724298536777496, 60.26815943419933, 53.509781286120415, 54.48523074388504, 52.38312654197216, 57.24585860967636, 59.81003321707249, 58.39765280485153, 56.22188575565815, 59.12949353456497, 54.17787663638592, 56.473048478364944, 56.83306396007538, 56.85410723090172, 49.15704645216465, 49.38151940703392, 52.61691279709339, 55.202875435352325, 52.82490983605385, 53.62885929644108, 41.388591304421425, 54.10457096993923, 60.256592854857445, 53.635022565722466, 55.42401596903801, 51.32345460355282, 45.68059779703617, 47.30646215379238, 46.56546771526337, 54.1189493983984, 50.334527269005775, 53.37880611419678, 50.822649076581, 52.2398666292429, 52.94238433241844, 47.82581448554993, 41.32772237062454, 41.69708535075188, 40.78154347836971, 39.05601806938648, 38.75898040831089, 41.00668899714947, 41.222806200385094, 43.604658991098404, 43.86097423732281, 44.974709674715996, 46.74905866384506, 48.48563767969608, 46.58056430518627, 48.01741920411587, 48.3817208558321, 49.16296273469925, 48.8813104480505, 55.74306584894657, 52.55358539521694, 51.808103397488594, 50.8004392683506, 41.09151564538479, 43.92429403960705, 46.11848630011082, 49.48122225701809, 54.3538261950016, 49.38740909099579, 52.05820217728615, 49.859127178788185, 47.90032848715782, 49.38066445291042, 48.78236375749111, 48.14931392669678, 47.919703647494316, 45.76434150338173, 46.131758987903595, 44.88790713250637, 41.146874874830246, 42.61963404715061, 41.275862753391266, 39.41390946507454, 39.085956662893295, 39.52197566628456, 40.77346131205559, 39.38019387423992, 43.19760203361511, 47.804623022675514, 54.26585711538792, 52.98840746283531, 50.9253803640604, 51.37477844953537, 51.86558671295643, 48.65187115967274, 46.122213900089264, 49.85503479838371, 52.56517097353935, 55.56225635111332, 54.83475498855114, 56.11442372202873, 56.014473885297775, 54.693147987127304, 53.6905337870121, 57.12915927171707, 58.55013482272625, 59.67919483780861, 57.2116756439209, 56.837030947208405, 58.53658474981785, 56.7541079968214, 58.17686565220356, 61.915789023041725, 60.887127220630646, 59.6344256401062, 59.57065746188164, 55.64688540995121, 51.91532984375954, 54.98188689351082, 59.02713842689991, 59.30970646440983, 58.17750781774521, 57.02191382646561, 61.91858187317848, 62.81622290611267, 65.11063858866692, 57.24294416606426, 68.2512916624546, 14.663871992379427, 0.9671122895088047, 1.8853928055614233, 3.0847250623628497, 3.6622992949560285, 0.027555878295970615, 45.61606965959072, 73.82635250687599, 71.35187208652496, 68.79381895065308, 77.04266712069511, 59.418760612607, 52.551556304097176, 53.968184888362885, 40.01600995659828, 59.02639366686344, 65.30529454350471, 6.860940344631672, 0.4240275890333578, 0.15993665379937738, 0.05529552719963249, 0.08486452745273709, 0.06150976718345191, 0.104866008477984, 0.09931855107424781, 0.15229545679176226, 0.16866287071025, 0.287705302471295, 0.15995684021618217, 0.18671717145480216, 1.185363493859768, 70.6367276608944, 81.84992596507072, 61.78003370761871, 47.23321348428726, 50.00714063644409, 60.007835403084755, 57.94132389128208, 75.44945821166039, 71.83212071657181, 77.57393941283226, 67.79292985796928, 80.10564476251602, 14.992031883448362, 0.19556434359401464, 1.8888540635816753, 3.7614238634705544, 0.836216735187918, 0.3824431844986975, 44.99501958489418, 65.156160145998, 62.23447032272816, 60.54035782814026, 63.20673555135727, 58.15155901014805, 63.70203897356987, 52.45512127876282, 57.39862181246281, 55.80033257603645, 58.20337302982807, 61.38915628194809, 62.094941809773445, 60.13897776603699, 60.20550839602947, 55.58906391263008, 59.59342963993549, 60.46217322349548, 60.510795414447784, 52.45803192257881, 51.739289090037346, 55.9345717728138, 56.97909012436867, 54.69950504601002, 55.72977416217327, 44.851413890719414, 55.449934378266335, 62.32482947409153, 57.61553697288036, 57.26679928600788, 54.84405308961868, 48.975720182061195, 51.452757865190506, 47.87958540022373, 58.68539996445179, 53.93827669322491, 56.97261147201061, 55.28009109199047, 55.185715556144714, 55.21712467074394, 50.32534696161747, 45.75749047100544, 45.422633439302444, 43.39222379028797, 42.09067963063717, 41.79049953818321, 44.47596363723278, 44.164395555853844, 45.54826229810715, 44.65231217443943, 48.25578801333904, 50.43778672814369, 52.5874225795269, 48.80202770233154, 53.38603712618351, 52.09488920867443, 50.56930527091026, 51.84251435101032, 59.55878309905529, 53.89291472733021, 53.01796607673168, 55.77796697616577, 44.07068118453026, 48.12433026731014, 52.17142090201378, 55.55127114057541, 59.320053309202194, 50.79424940049648, 54.427584037184715, 54.2385745793581, 49.864230304956436, 52.14147850871086, 52.23480150103569, 51.13546349108219, 50.49251139163971, 46.65173068642616, 49.10552121698856, 46.71038433909416, 44.48670946061611, 44.11880560219288, 44.179324954748154, 43.18408615887165, 41.53797268867493, 42.47190177440643, 43.00470158457756, 40.53839452564716, 45.30384801328182, 51.061565056443214, 57.27141223847866, 55.721502006053925, 56.000076457858086, 54.40799608826637, 54.18715953826904, 52.504837810993195, 47.756464406847954, 52.34070561826229, 53.02613563835621, 58.297368586063385, 59.53021243214607, 58.72436307370663, 57.825631499290466, 54.80583094060421, 55.18430583178997, 59.86233361065388, 59.85898979008198, 60.62553785741329, 58.91936480998993, 58.582269698381424, 60.31687282025814, 58.306491896510124, 61.23720623552799, 64.41716060042381, 63.55453468859196, 62.49869294464588, 61.910541504621506, 57.04706467688084, 53.10372747480869, 57.632028087973595, 63.04710231721401, 63.23273375630379, 61.42133675515652, 59.88886758685112, 64.59724053740501, 67.04266011714935, 68.79812031984329, 61.55943654477596, 71.16154789924622, 17.01607782393694, 1.1498704296536744, 3.4003781620413065, 4.8709610011428595, 4.6252866089344025, 0.143933100043796, 48.11798460781574, 80.09582608938217, 76.73298373818398, 74.43163722753525, 83.66387262940407, 64.2374150454998, 63.25144775211811, 62.57620118558407, 58.447289541363716, 69.19860363006592, 78.42728242278099, 10.6925293430686, 0.6845511985011399, 0.3461778414202854, 0.23731507826596498, 0.21048329304903746, 0.21720318793086335], [0.05888016356038861, 0.09808043352677487, 0.040788313854136504, 0.06414166404283606, 0.041081039162236266, 0.09458771586650982, 0.20321579708252102, 0.5364854936487973, 51.46274372935295, 64.30791646242142, 42.915721759200096, 39.63241294026375, 73.79498898983002, 43.16867798566818, 40.21741434931755, 63.75235587358475, 63.13180357217789, 62.91041225194931, 53.187782764434814, 63.723112642765045, 26.98466621339321, 0.24092222767649218, 1.228365192655474, 0.7211287482641637, 0.4017146519618109, 0.12140514052589424, 19.385579377412796, 56.43627405166626, 54.72113348543644, 52.445181012153625, 52.69612714648247, 58.78473803400993, 56.671728417277336, 55.48049233853817, 51.75960659980774, 53.637260645627975, 56.51862323284149, 59.1277190297842, 56.88195213675499, 55.59029124677181, 54.825574681162834, 55.76346315443516, 52.273890003561974, 56.93333677947521, 52.44651474058628, 44.37842287123203, 42.97307588160038, 48.472440987825394, 50.46755813062191, 56.94415859878063, 49.400260001420975, 55.421705693006516, 57.66553469002247, 53.39518703520298, 53.730044066905975, 50.75383096933365, 44.77278470993042, 46.98416344821453, 43.13717767596245, 45.56178577244282, 49.2896631360054, 47.24372372031212, 50.43574623763561, 50.40000535547733, 53.123391419649124, 52.86609202623367, 48.461987748742104, 40.95282308757305, 40.47729380428791, 40.256795436143875, 38.451839089393616, 38.138431906700134, 38.35359536111355, 39.12059560418129, 39.4385739415884, 39.96057853102684, 42.35093906521797, 45.92813551425934, 46.10743269324303, 46.425509825348854, 45.12140080332756, 47.51945972442627, 46.26695953309536, 50.213701352477074, 46.968903467059135, 51.82871349155903, 51.73746518790722, 33.95810902118683, 36.16572216153145, 37.011275589466095, 41.80141635239124, 44.75547283887863, 50.70591554045677, 52.533666864037514, 49.293139949440956, 50.09096033871174, 45.7121779024601, 47.28310100734234, 45.888952016830444, 43.102086558938026, 44.94273439049721, 42.956212386488914, 44.42729964852333, 41.95732578635216, 40.25005079805851, 39.83382873237133, 40.45432023704052, 38.016424253582954, 38.99256147444248, 39.921273440122604, 39.34927113354206, 41.51702061295509, 45.183728858828545, 47.35510714352131, 47.53002695739269, 49.55183006823063, 47.53000035881996, 47.557469084858894, 49.3069864064455, 44.01614271104336, 43.74127686023712, 49.05284844338894, 52.06110142171383, 49.27735939621925, 48.63837048411369, 55.54890386760235, 48.93674187362194, 49.15409401059151, 54.275778383016586, 49.701412841677666, 54.83280949294567, 55.967516005039215, 56.67876563966274, 55.375948548316956, 59.5750842243433, 55.79763472080231, 52.38631837069988, 53.96252699196339, 56.01937562227249, 57.95360863208771, 57.441677302122116, 57.03744359314442, 57.14289553463459, 55.994175374507904, 54.3163526058197, 51.66599102318287, 50.77833205461502, 56.6072116792202, 63.78571808338165, 62.21035301685333, 63.13817583024502, 53.4500864893198, 68.17862436175346, 8.363035842776299, 0.19944947183830664, 0.8664005936589092, 1.6308669070713222, 1.8924381025135517, 0.19878265215083957, 48.03608760237694, 62.66030967235565, 65.40187776088715, 62.093133106827736, 73.80669236183167, 44.84270855784416, 39.333205595612526, 27.972599901258945, 29.46377668529749, 51.403364315629005, 48.64252746105194, 1.304228121880442, 0.25258856650907546, 0.059349056173232384, 0.06014362916175742, 0.1319599276757799, 0.21648927155183628, 0.0683445502363611, 0.07623786965268664, 0.045611193927470595, 0.0454881829500664, 0.0822598414379172, 0.09701204515295103, 0.18690600350964814, 0.6365852442104369, 60.55032089352608, 73.3798536658287, 46.54178738594055, 36.75614207983017, 67.10310727357864, 50.889521688222885, 46.14615261554718, 70.67015066742897, 69.94863018393517, 67.7183398604393, 60.748586654663086, 69.32047069072723, 28.555944599211216, 0.23173360823420808, 1.1975948000326753, 0.959190308349207, 0.5824442056473345, 0.32487167220097035, 22.333755679428577, 61.0901465266943, 55.93283526599407, 56.5785726159811, 57.36404366791248, 61.47538125514984, 59.2926187813282, 55.196032002568245, 51.87822483479977, 55.223447531461716, 59.05245266854763, 60.345895662903786, 59.2359372228384, 56.75881214439869, 57.941008508205414, 56.77834689617157, 54.29631628096104, 58.22582222521305, 56.74059212207794, 45.87624549865723, 44.51169312000275, 51.7475688457489, 53.13264012336731, 57.70948313176632, 51.36704586446285, 57.440389171242714, 60.215980634093285, 57.35777400434017, 55.35875827074051, 50.52321374416351, 48.02416764199734, 48.136440217494965, 45.74108675122261, 46.498982682824135, 53.13150778412819, 49.95776228606701, 52.2292347997427, 54.82170268893242, 54.110730439424515, 54.25606124103069, 49.601159021258354, 43.306971564888954, 42.19510182738304, 41.876314133405685, 39.53839838504791, 40.169362127780914, 39.60369408130646, 40.39177939295769, 42.37504877150059, 42.928447276353836, 42.98154942691326, 45.997633785009384, 47.20543697476387, 46.95185758173466, 45.975321382284164, 48.62757906317711, 47.996493726968765, 50.44072017073631, 49.860662296414375, 52.45784193277359, 53.22238750755787, 38.47764350473881, 41.440496519207954, 39.39785532653332, 44.338859394192696, 47.499279007315636, 52.95310355722904, 53.967318534851074, 50.16384802758694, 50.22576570510864, 48.5840068012476, 47.286323234438896, 49.688653126358986, 45.975408777594566, 47.768144980072975, 47.72926926612854, 45.100292935967445, 44.01778042316437, 43.092636466026306, 40.001262947916985, 41.053764671087265, 38.990437388420105, 38.41876186430454, 40.13389863073826, 41.26516252756119, 42.14966006577015, 45.81459000706673, 49.7934553027153, 51.642800867557526, 51.63209304213524, 51.62793606519699, 51.36179834604263, 52.13365092873573, 48.76636661589146, 45.58430716395378, 49.056591242551804, 52.11058996617794, 52.93049097061157, 54.16338801383972, 55.941457003355026, 54.59270037710667, 49.45705935359001, 54.07927952706814, 51.807290241122246, 56.04343593120575, 56.248567923903465, 58.66534844040871, 58.31257916986942, 60.401479080319405, 59.334443137049675, 56.36624000966549, 56.65862292051315, 58.76230403780937, 59.504411816596985, 61.010035425424576, 60.501113533973694, 59.71310801804066, 57.73306466639042, 56.04250878095627, 54.482354298233986, 53.24534587562084, 60.32023563981056, 66.7569762468338, 64.34680357575417, 68.99162113666534, 57.553395107388496, 72.72046744823456, 9.761479552835226, 0.26313861133530736, 2.7655934868380427, 3.255349681712687, 3.3633871469646692, 0.10554975655395538, 54.36879359185696, 68.27064782381058, 73.18975746631622, 69.6210041642189, 80.86875781416893, 51.21807485818863, 49.93152089416981, 34.79927748441696, 33.95058162510395, 59.959471598267555, 58.62794704735279, 2.465167357586324, 0.3020998206920922, 0.22344928089296445, 0.09870887675788254, 0.1000178100366611, 0.18829186039511114, 0.18158299382776022, 0.2913713932503015, 0.1891830758540891, 0.13646602572407573, 0.12159119694842957, 0.19690485525643453, 0.2861649898113683, 0.7480674621183425, 68.8329416513443, 83.6916795372963, 59.99426633119583, 52.135968804359436, 84.85879451036453, 61.14525876939297, 50.542072132229805, 78.28795149922371, 72.71976068615913, 74.65816587209702, 65.4492612183094, 77.52426087856293, 32.03305631875992, 0.19705344806425273, 2.268279022537172, 1.707303961738944, 0.6330868788063526, 0.31406229129061103, 26.262554861605167, 63.948820531368256, 62.007808685302734, 60.039187520742416, 59.90155130624771, 62.27370321750641, 62.61631943285465, 58.2741442322731, 53.84486250579357, 55.783396884799004, 59.7998421639204, 63.440293818712234, 59.26367573440075, 60.30356213450432, 59.005730375647545, 58.46801742911339, 57.000251188874245, 61.295829489827156, 58.93233731389046, 48.670022785663605, 47.407772317528725, 53.00677187740803, 55.427990555763245, 59.680289179086685, 55.23369178175926, 58.84947516024113, 64.21711653470993, 59.24727201461792, 57.53509148955345, 56.684837713837624, 50.78645221889019, 52.72858880460262, 47.51144975423813, 48.18034306168556, 54.44640442728996, 54.12777632474899, 58.85164864361286, 56.705804988741875, 57.43925303220749, 55.97245953977108, 54.69804972410202, 46.10743269324303, 43.92636492848396, 44.39812481403351, 42.96032376587391, 41.074203774333, 42.768681049346924, 41.675149127840996, 44.80161756277084, 45.94410605728626, 47.21306696534157, 47.92779341340065, 51.06566123664379, 50.611969381570816, 49.1457686573267, 50.24868607521057, 49.654660150408745, 52.96842813491821, 54.01356965303421, 54.24201339483261, 57.94971004128456, 45.43883576989174, 43.56243185698986, 45.483217388391495, 50.32509997487068, 51.04318544268608, 55.26224344968796, 58.5380894690752, 53.82017523050308, 53.03587831556797, 50.82245908677578, 49.57162320613861, 53.50378900766373, 49.870009794831276, 49.82043385505676, 50.93826167285442, 47.784985676407814, 46.24732218682766, 45.679476857185364, 43.32582615315914, 45.26950925588608, 40.43084129691124, 42.87544012069702, 43.19275729358196, 44.784073904156685, 45.66815726459026, 49.715107306838036, 52.84827098250389, 53.50470095872879, 55.11646047234535, 54.76253226399422, 53.97628225386143, 55.72268754243851, 51.627613082528114, 47.64312408864498, 54.690704718232155, 56.867490112781525, 56.95676252245903, 57.76510454714298, 58.710417822003365, 55.236146450042725, 52.96359099447727, 53.30710016191006, 53.55357013642788, 58.32308940589428, 59.497902765870094, 62.080886363983154, 60.818894281983376, 63.266183361411095, 61.724708676338196, 57.89759963750839, 60.136557295918465, 60.64321830868721, 62.04373575747013, 63.28246928751469, 58.840306252241135, 61.29325322806835, 60.19968330860138, 58.15461404621601, 55.99088095128536, 54.30466063320637, 63.132761120796204, 69.30924609303474, 67.07719266414642, 70.77580019831657, 61.500467509031296, 74.50149267911911, 11.882987413555384, 0.3185608342755586, 5.016211057081819, 5.732476897537708, 4.1078778728842735, 0.24247766530606896, 58.731195107102394, 75.39987087249756, 77.33698412775993, 73.24676960706711, 89.09707948565483, 55.92080891132355, 59.24352541565895, 37.614831402897835, 45.11103495955467, 69.30074974894524, 76.48822367191315, 4.480899106711149, 0.4550089593976736, 0.30521042877808213, 0.18746466259472072, 0.26662168849725276, 0.2309667767258361], [0.056101488444255665, 0.061335933933150955, 0.10375418220064603, 0.01766239667631453, 0.0908725913905073, 0.0638523897214327, 0.4890093271387741, 0.12864870222983882, 39.21519912779331, 65.84735065698624, 48.25541943311691, 58.08779463171959, 105.01214548945427, 56.812773048877716, 29.49777726083994, 59.683632999658585, 60.69031298160553, 64.69244062900543, 54.291444942355156, 61.456921845674515, 36.89325772225857, 0.14730055059771985, 0.5855421081651002, 0.5032194661907852, 1.029799128882587, 0.22159210086101666, 7.3845764715224504, 54.36505079269409, 56.05426535010338, 54.5599689334631, 55.02287529408932, 57.78494328260422, 56.530391201376915, 53.984185829758644, 48.01285944879055, 57.38085776567459, 60.42902760207653, 55.57880446314812, 55.6255267560482, 52.88234755396843, 56.23987779021263, 57.82528191804886, 57.11823105812073, 55.807476192712784, 47.539264261722565, 40.03392219543457, 44.86319325864315, 50.36180600523949, 54.23093318939209, 52.92965121567249, 54.7774388641119, 54.842175990343094, 53.69294285774231, 54.2112198472023, 48.846036940813065, 47.60500833392143, 44.605992659926414, 47.00262665748596, 45.27592331171036, 46.52180805802345, 49.28454861044884, 46.952009573578835, 47.501729875802994, 47.246645763516426, 49.33440573513508, 49.28839400410652, 52.17998564243317, 46.474037021398544, 39.64803770184517, 40.31981125473976, 37.67865277826786, 39.61211442947388, 40.791046768426895, 41.132895424962044, 39.844312369823456, 40.61925798654556, 39.99122388660908, 43.02264042198658, 44.33727107942104, 40.165984109044075, 43.80610518157482, 46.805375441908836, 46.0521874576807, 46.09973430633545, 51.788390055298805, 48.314958438277245, 37.54197411239147, 38.680769205093384, 43.76348286867142, 40.188486501574516, 41.15056827664375, 45.56368947029114, 50.037216022610664, 52.779551669955254, 50.03414958715439, 49.149530455470085, 44.66472610831261, 45.07348917424679, 44.270900040864944, 45.84223352372646, 45.678758695721626, 44.405469819903374, 43.857045248150826, 41.585253551602364, 39.82219375669956, 40.74272856116295, 39.34067979454994, 37.079535126686096, 38.12467664480209, 40.481199994683266, 41.102728843688965, 42.85478822886944, 50.44191710650921, 50.04045344889164, 49.12723705172539, 47.32373222708702, 47.851710096001625, 47.86028243601322, 47.17500440776348, 43.14858466386795, 41.793056800961494, 45.63279256224632, 52.00218938291073, 50.4390824586153, 55.26805333793163, 54.34333115816116, 52.132393196225166, 43.455896973609924, 54.92356762290001, 49.87507872283459, 53.54011505842209, 54.405571818351746, 55.03961719572544, 53.59506770968437, 52.85309672355652, 50.22518813610077, 48.67018237709999, 50.0273023545742, 51.070570573210716, 54.031770676374435, 55.83555668592453, 57.40793131291866, 58.01778718829155, 58.09798948466778, 58.035577833652496, 51.566694751381874, 52.64776334166527, 60.8101661503315, 64.8357917368412, 61.94517284631729, 65.3665928542614, 54.043656438589096, 64.10069838166237, 5.926974210888147, 0.17275254969717935, 2.77468069922179, 1.8992874724790454, 0.9031598211731762, 1.2233825912699103, 56.14307798445225, 61.618143394589424, 67.10987851023674, 62.44467504322529, 66.96224123239517, 36.476089507341385, 51.01972550153732, 46.13831743597984, 32.27600008249283, 54.52446363866329, 33.09238627552986, 0.48550576670095325, 0.13747494580456987, 0.07456925450242124, 0.009639646705181804, 0.05037380047724582, 0.026069549458043184, 0.08128900837618858, 0.03157737803121563, 0.10150463611353189, 0.019632329349406064, 0.09222957130987197, 0.0010711582081057713, 0.43896535935346037, 0.09963787495507859, 47.66974166035652, 72.86818072199821, 55.3488028049469, 57.47568167746067, 89.5930440723896, 59.636830911040306, 38.235889077186584, 68.1582422554493, 69.09344047307968, 68.32342699170113, 60.6335212290287, 66.38612374663353, 41.45924851298332, 0.09417845110874623, 0.6039480830077082, 0.23603837646078318, 2.207290632650256, 0.26797397062182426, 8.852738365530968, 59.57239016890526, 58.388924673199654, 58.71731445193291, 57.45748445391655, 60.396231561899185, 57.49471105635166, 54.21751610934734, 49.53622430562973, 60.63093736767769, 62.1207120269537, 58.56300853192806, 56.710281148552895, 54.42264810204506, 58.96332465112209, 59.16556879878044, 59.44401405751705, 58.76349717378616, 50.154937505722046, 42.11122892796993, 46.973106041550636, 53.70083123445511, 55.25148622691631, 54.44329999387264, 56.741348281502724, 57.03303582966328, 55.79396791756153, 55.18198035657406, 51.99589692056179, 50.39359129965305, 46.736925914883614, 49.83734294772148, 46.71437792479992, 50.55815286934376, 51.47257760167122, 49.55207705497742, 49.827227890491486, 50.55594138801098, 51.84544779360294, 52.14703381061554, 54.394696801900864, 47.61306390166283, 41.1100472509861, 42.505286782979965, 39.51870784163475, 40.20446464419365, 40.71095086634159, 41.882857382297516, 41.73480972647667, 41.68496400117874, 41.90815642476082, 44.973645731806755, 45.978855192661285, 43.78874771296978, 46.61546543240547, 48.162784203886986, 48.35691958665848, 47.29776442050934, 51.631241887807846, 49.75325345993042, 40.45316129922867, 41.46848201751709, 46.72200031578541, 42.590592205524445, 43.87549325823784, 47.213826924562454, 51.65977455675602, 55.01663222908974, 52.38155722618103, 52.42186926305294, 49.15874496102333, 46.10321491956711, 46.670247092843056, 46.60704888403416, 46.69626049697399, 45.018194541335106, 44.25279401242733, 42.66446404159069, 40.902874767780304, 41.013726219534874, 40.30396990478039, 38.81857641041279, 40.57327665388584, 42.329580411314964, 43.42966318130493, 45.29128588736057, 51.07300244271755, 49.95965838432312, 51.93044163286686, 48.684583604335785, 51.69554963707924, 51.74709007143974, 51.89845494925976, 46.138746812939644, 45.5742073059082, 47.63987146317959, 53.81759896874428, 53.36293816566467, 57.87224739789963, 56.21739059686661, 54.86476957798004, 45.0755562633276, 51.31430469453335, 52.036683931946754, 57.02290557324886, 55.539244785904884, 55.94836123287678, 56.05439454317093, 54.57155831158161, 53.522069826722145, 51.84202037751675, 51.97324253618717, 54.80044282972813, 56.27802014350891, 58.83366800844669, 59.05964948236942, 60.49766331911087, 61.49830162525177, 60.00551372766495, 52.894297912716866, 53.855019360780716, 62.22848944365978, 68.71741265058517, 63.931729048490524, 69.57978397607803, 59.02778439223766, 69.8624812066555, 7.864523017778993, 0.30802898691035807, 3.4576318273320794, 0.8985204482451081, 1.0192696563899517, 1.0204012831673026, 60.94596706330776, 65.99739700555801, 74.03786435723305, 67.8865872323513, 75.71018502116203, 40.567766949534416, 58.860646560788155, 47.26560674607754, 35.55243507027626, 62.77934208512306, 44.96643751859665, 0.4835754109080881, 0.15202489943476394, 0.038745081110391766, 0.041397802633582614, 0.1419532875297591, 0.009142767703451682, 0.16359435830963776, 0.17700290365610272, 0.2337087897467427, 0.11295240503386594, 0.1997172980918549, 0.11176322470419109, 0.531258755363524, 0.21253301587421447, 54.8934580385685, 85.20584508776665, 62.95490026473999, 73.27752515673637, 107.76050001382828, 71.02954298257828, 39.9977633357048, 70.38116097450256, 72.77618005871773, 74.95641186833382, 66.49862810969353, 73.2046602666378, 46.87777675688267, 0.15327727363910526, 0.8626143936999142, 1.6778423613868654, 1.9984536012634635, 0.31671995180658996, 10.978005174547434, 61.9458644092083, 61.557517647743225, 64.1460907459259, 59.936669021844864, 60.841343477368355, 60.493559539318085, 56.60853020846844, 50.69430336356163, 62.460269406437874, 64.0106888115406, 60.698121562600136, 58.95735137164593, 57.40662418305874, 62.08836056292057, 61.27830483019352, 63.426755145192146, 62.319141179323196, 50.44908732175827, 44.98462714254856, 51.084580421447754, 56.83435209095478, 58.810705840587616, 55.51853209733963, 59.39511448144913, 60.09389318525791, 57.078002616763115, 59.542896151542664, 52.73957021534443, 53.3958026021719, 48.998632952570915, 53.06552812457085, 50.628141313791275, 52.92598061263561, 54.893910214304924, 52.98597939312458, 52.35745131969452, 53.090659976005554, 54.16699782013893, 54.30849842727184, 57.672229930758476, 51.61686345934868, 44.27281133830547, 45.55544771254063, 40.067352801561356, 42.613710165023804, 45.29947444796562, 45.24633049964905, 42.68204189836979, 44.26184132695198, 44.80888657271862, 47.903083339333534, 47.267267256975174, 46.02373458445072, 48.14066559076309, 52.45435371994972, 50.32877817749977, 49.463306218385696, 53.404580131173134, 54.5742903649807, 48.21650192141533, 45.374364629387856, 50.557636097073555, 46.116700395941734, 50.076980888843536, 53.83514262735844, 53.61807927489281, 56.871795281767845, 55.45946426689625, 53.53001520037651, 50.54538935422897, 50.61917759478092, 47.28597745299339, 50.365860387682915, 51.277127489447594, 47.76681885123253, 46.44953973591328, 45.96933290362358, 44.02142062783241, 43.21601204574108, 42.06126160919666, 40.05973041057587, 42.007213309407234, 43.33185262978077, 45.828987434506416, 46.491797268390656, 54.84579339623451, 56.18948869407177, 53.9157173037529, 52.85069905221462, 54.61046822369099, 54.95013579726219, 52.767977491021156, 48.569195196032524, 46.902300640940666, 52.250069081783295, 55.570672899484634, 54.401566833257675, 59.88922096788883, 61.90551437437534, 55.275352746248245, 51.888522282242775, 57.695716470479965, 49.90223206579685, 59.59174633026123, 56.51353910565376, 58.801453337073326, 57.447054013609886, 58.57224963605404, 55.46932093799114, 54.37801569700241, 53.00530895590782, 56.55115708708763, 56.83776430785656, 61.87942497432232, 60.89690409600735, 62.49948710203171, 64.84475165605545, 62.91440203785896, 53.545385375618935, 54.55880619585514, 64.94857728481293, 71.43106743693352, 67.60298565030098, 71.27109602093697, 60.562031865119934, 74.2160975933075, 8.654733840376139, 0.35542912781238556, 8.830123879015446, 5.45120601542294, 1.7873368109576404, 1.582216692622751, 66.7296253144741, 71.35403797030449, 80.5882340669632, 72.59242951869965, 80.8861456811428, 47.311781868338585, 70.5635815858841, 63.54536958038807, 48.4173097461462, 73.88568252325058, 61.82216204702854, 1.4185439189895988, 0.2836238167947158, 0.15670075634261593, 0.13064976985333487, 0.30256802681833506, 0.06392670096829534], [0.08148403736413456, 0.07137254244298674, 0.11290252528851852, 0.06798349539167248, 0.2046299446374178, 0.029834444212610833, 0.5357197159901261, 0.0635385577334091, 29.147990830242634, 75.81338748335838, 44.68302592635155, 47.652543783187866, 112.02042862772942, 67.66150251030922, 30.83539668470621, 57.27558821439743, 62.32899025082588, 60.90529404580593, 55.4192890226841, 54.92712043225765, 49.83311377465725, 0.844921296229586, 1.1445863381959498, 0.7966865063644946, 1.305533826816827, 0.11335285307723098, 0.6029157852753997, 40.6000804156065, 56.68045274913311, 54.830111637711525, 52.29533225297928, 56.63401164114475, 56.94345943629742, 56.08191266655922, 51.21006868779659, 58.40453423559666, 55.41369192302227, 56.92097224295139, 51.895004734396935, 53.646615743637085, 53.06232109665871, 54.69686038792133, 55.36094315350056, 56.15120194852352, 46.05696760118008, 43.38669128715992, 52.129691541194916, 53.07764947414398, 53.69573570787907, 54.98003639280796, 55.13183444738388, 54.292645677924156, 53.97323861718178, 52.086370065808296, 51.28805950284004, 46.64793848991394, 46.73016607761383, 49.0563328564167, 42.85387247800827, 46.23058408498764, 50.63967749476433, 49.778940081596375, 46.33803091943264, 49.52163688838482, 49.16245736181736, 48.92477251589298, 48.93934093415737, 46.709563583135605, 43.591025322675705, 40.7407146692276, 37.89509296417236, 39.398334100842476, 39.78495955467224, 39.648402482271194, 39.47093680500984, 40.57978570461273, 40.92898316681385, 42.244248390197754, 42.196777537465096, 42.601079642772675, 44.33107741177082, 46.394818872213364, 48.746197298169136, 51.96549475193024, 46.06296747922897, 35.805828273296356, 40.799888893961906, 44.11671191453934, 43.623714968562126, 42.036574333906174, 42.992553636431694, 46.041806414723396, 45.82929141819477, 52.86090150475502, 51.05674311518669, 51.215122416615486, 47.90716052055359, 46.66302748024464, 48.218641206622124, 43.86394187808037, 43.79549615085125, 42.92600400745869, 43.0296890437603, 39.93733137845993, 39.86237280070782, 39.845657497644424, 40.52862524986267, 39.08991985023022, 39.14047233760357, 40.72981305420399, 39.317546635866165, 46.74268260598183, 51.623866483569145, 46.989714950323105, 48.9410812407732, 48.792475014925, 49.472934901714325, 47.679400742053986, 49.66428883373737, 42.120663821697235, 45.01621104776859, 41.87255993485451, 45.804041773080826, 52.62005902826786, 51.38916067779064, 52.97695867717266, 56.731624603271484, 47.717953473329544, 39.65896591544151, 47.850817143917084, 54.44559887051582, 53.356611505150795, 55.12225516140461, 54.21392910182476, 51.60888388752937, 52.7921973913908, 46.817078813910484, 44.64035041630268, 47.0060046762228, 49.84993927180767, 54.347765520215034, 54.799618273973465, 57.8276301920414, 56.85602232813835, 59.7327833622694, 55.39593547582626, 58.11135716736317, 58.066523373126984, 67.4878366291523, 58.50101865828037, 69.06235054135323, 56.41672410070896, 61.3937958329916, 3.671092023141682, 0.02085861149680568, 3.0534054804593325, 1.0182263748720288, 0.9418965457007289, 2.7004787558689713, 63.50503854453564, 63.97502392530441, 62.23894268274307, 59.06955175101757, 59.2647472769022, 39.192236959934235, 47.62733593583107, 24.824459329247475, 32.754193022847176, 58.38259041309357, 23.44864245504141, 0.988860244397074, 0.10721567028667778, 0.04205392426229082, 0.0901533018623013, 0.06469993721111678, 0.02727946910454193, 0.07952735759317875, 0.09004718958749436, 0.0816798752930481, 0.02005984166316921, 0.19311757176183164, 0.029147187633498106, 0.6213497242424637, 0.14731065864907578, 36.53685204684734, 82.71054178476334, 51.276356130838394, 49.42288398742676, 101.27162620425224, 70.53873851895332, 33.95355686545372, 65.09363070130348, 68.00032272934914, 69.36498150229454, 61.54056675732136, 62.41330772638321, 54.54987667500973, 1.222659561317414, 1.1883976310491562, 0.9022665128577501, 2.5602187821641564, 0.1481192433857359, 1.0006904345937073, 47.66553908586502, 57.267445251345634, 57.57800258696079, 54.55532178282738, 58.9273975789547, 58.994308188557625, 57.34442912042141, 53.76578114926815, 60.95312587916851, 57.13706664741039, 60.972090661525726, 53.6816992610693, 54.54085975885391, 53.39490585029125, 56.80184863507748, 57.67462000250816, 57.70828999578953, 48.170946165919304, 44.62895102798939, 54.21796068549156, 54.738597348332405, 55.39319962263107, 57.3989599943161, 56.23679235577583, 55.86925707757473, 54.19232726097107, 55.61870612204075, 51.66135147213936, 50.19478216767311, 47.35723502933979, 51.03617861866951, 44.16308842599392, 49.978235587477684, 54.453137665987015, 52.37465679645538, 50.74613258242607, 53.15187469124794, 50.98499536514282, 52.833558171987534, 53.18813614547253, 48.94315592944622, 44.89561691880226, 42.68215969204903, 39.49265643954277, 39.44381386041641, 40.11827766895294, 40.94990864396095, 42.30839654803276, 40.98805099725723, 42.06029646098614, 45.64893029630184, 45.018099546432495, 44.712307155132294, 46.12227089703083, 47.515450939536095, 49.93663161993027, 50.661606118083, 50.99103324115276, 40.91596506536007, 44.68268774449825, 47.40366853773594, 45.337601602077484, 44.576871022582054, 45.319620966911316, 47.07243271172047, 47.01186016201973, 55.950709506869316, 53.74876946210861, 52.125891745090485, 49.625272527337074, 48.524399399757385, 49.69885937869549, 45.010226368904114, 44.45602610707283, 45.49403540790081, 44.31256860494614, 43.527963906526566, 41.22243382036686, 41.01072438061237, 42.24811278283596, 40.1195278018713, 40.71701154112816, 41.67963668704033, 42.89181724190712, 48.17997828125954, 54.767950773239136, 50.733452662825584, 51.77187614142895, 52.29854688048363, 51.488240361213684, 51.37245297431946, 51.08396865427494, 45.5816625058651, 47.09242723882198, 44.07969810068607, 48.052464723587036, 54.143161699175835, 52.39749737083912, 55.32133027911186, 57.74735189974308, 50.80471023917198, 41.321532502770424, 50.95774702727795, 55.322120636701584, 56.49405375123024, 57.687398716807365, 56.43790416419506, 54.084481447935104, 56.55407913029194, 50.09068675339222, 46.45405009388924, 48.928830698132515, 53.101269006729126, 55.79882025718689, 57.365536987781525, 60.071333795785904, 60.8060509711504, 61.738745123147964, 57.50354178249836, 59.61954563856125, 61.017889603972435, 70.82681626081467, 61.587110459804535, 69.9207928776741, 60.85722282528877, 67.23336428403854, 4.9187458120286465, 0.05874985727132298, 4.239550782367587, 0.3611313452711329, 1.0810146806761622, 2.9546283558011055, 69.69266831874847, 67.37390354275703, 70.27541264891624, 63.09698984026909, 66.67001411318779, 40.57301826775074, 62.44332991540432, 31.690818183124065, 35.65134756267071, 69.75262150168419, 31.445167064666748, 0.9841694554779679, 0.058287183856009506, 0.04661033621232491, 0.02734897680056747, 0.16934046638198197, 0.016308428021147847, 0.14428746071644127, 0.25549935875460505, 0.12453968287445605, 0.27062124107033014, 0.24541744583984837, 0.16471014765556902, 0.904542887583375, 0.23275092942640185, 43.78519870340824, 95.51213845610619, 59.920736476778984, 63.257865607738495, 112.4741318821907, 78.0783623456955, 42.892258018255234, 70.48139959573746, 75.64273104071617, 73.19170296192169, 69.1700291633606, 64.66449692845345, 62.3601333796978, 1.0936115984804928, 1.7766302917152643, 2.268864903599024, 4.595000334084034, 0.2090583843528293, 1.4025810942985117, 54.18271377682686, 63.250216618180275, 63.257626220583916, 56.72212511301041, 63.655780255794525, 61.71131059527397, 61.357800364494324, 55.044526532292366, 63.23075786232948, 59.809269458055496, 64.82511430978775, 55.93669965863228, 57.10519015789032, 55.75181297957897, 59.354715049266815, 59.87192429602146, 61.75897143781185, 48.79909425973892, 48.28609138727188, 57.231430783867836, 58.94329212605953, 56.99427030980587, 59.465969279408455, 58.97266075015068, 59.89449128508568, 59.328424260020256, 58.64293344318867, 56.20900444686413, 52.83319719135761, 51.55311807990074, 56.11194625496864, 47.29803420603275, 53.013311326503754, 57.017411068081856, 58.46020504832268, 53.512524738907814, 58.35612863302231, 54.59686875343323, 55.11259987950325, 53.43901388347149, 53.25020581483841, 48.83181810379028, 44.174799397587776, 41.32992245256901, 42.69349828362465, 43.060923367738724, 42.92830668389797, 43.75330701470375, 44.263441041111946, 44.26222890615463, 46.34429298341274, 47.139685302972794, 46.63079380989075, 49.81518253684044, 50.582657754421234, 51.079427897930145, 55.026690289378166, 54.85446073114872, 46.10404707491398, 49.89075668156147, 50.806784927845, 48.005069866776466, 47.730481401085854, 49.21580269932747, 51.23473696410656, 49.68224287033081, 57.775439992547035, 55.67606024444103, 53.893332704901695, 51.13351419568062, 51.11301429569721, 51.88146986067295, 47.55560338497162, 47.37650379538536, 49.845276921987534, 47.47234605252743, 45.33072017133236, 43.10256913304329, 44.34982940554619, 45.520554184913635, 41.592028588056564, 42.730838879942894, 45.822144001722336, 45.51417052745819, 51.92031517624855, 57.61121280491352, 54.63925927877426, 56.06241971254349, 55.762646198272705, 54.53832529485226, 53.29096242785454, 54.488570764660835, 49.82435144484043, 50.349996238946915, 48.11161234974861, 49.42516386508942, 58.47060889005661, 54.925372526049614, 59.3410699814558, 59.582395032048225, 54.10751961171627, 46.00439362227917, 53.30565623939037, 56.33044973015785, 58.07281583547592, 61.21692672371864, 60.2849393337965, 54.960634633898735, 59.158155396580696, 51.372243985533714, 48.25752072036266, 51.05061024427414, 54.913866743445396, 58.986024633049965, 60.522988960146904, 62.151691764593124, 64.14227575063705, 67.11994796991348, 57.870358899235725, 60.85813857614994, 62.09275312721729, 75.12248575687408, 63.0272825807333, 74.4913624227047, 61.62871442735195, 70.9510163962841, 5.997572522610426, 0.11454897990915924, 7.1576212998479605, 3.2172282272949815, 1.65043466957286, 3.2328111911192536, 75.0166842341423, 72.56915956735611, 76.24611586332321, 70.71293637156487, 74.98973608016968, 48.66004832088947, 70.72382658720016, 35.745149329304695, 47.3411200940609, 81.90453663468361, 44.55248013138771, 1.2958680954761803, 0.1554802351165563, 0.08867423865012825, 0.09547870125970803, 0.2131693926639855, 0.12917280691908672], [0.13437351066386327, 0.042174905465799384, 0.09857051816652529, 0.09401290022651665, 0.2635614573955536, 0.01621051833353704, 0.8158695395104587, 0.05044244913733564, 15.936841685324907, 68.92777696251869, 57.92728364467621, 58.05057182908058, 86.9229805469513, 69.15586352348328, 33.46448130905628, 54.65013049542904, 55.646288841962814, 62.27161332964897, 60.235017612576485, 53.54777544736862, 55.38415610790253, 3.536299243569374, 0.5988914449699223, 1.5024865209124982, 1.027354672551155, 0.5455823242664337, 0.1168486729147844, 25.20846102386713, 55.51314018666744, 52.508139833807945, 51.977866888046265, 53.12398038804531, 54.82728458940983, 53.158516734838486, 54.877198711037636, 57.76200391352177, 56.65397197008133, 52.48267360031605, 48.412776589393616, 52.48104728758335, 52.86649100482464, 55.45787215232849, 54.57152411341667, 53.44486176967621, 40.786604806780815, 48.45341540873051, 53.04024048149586, 54.11244794726372, 53.44847917556763, 53.07485282421112, 53.24790693819523, 52.65809878706932, 51.26620687544346, 50.73035202920437, 45.69623775780201, 45.627632439136505, 46.05852551758289, 49.26413230597973, 42.635843977332115, 44.345136657357216, 51.598054468631744, 48.798205107450485, 48.718591779470444, 50.86920037865639, 50.64964056015015, 51.62985496222973, 49.418259635567665, 48.74634929001331, 42.51231260597706, 37.650093510746956, 37.68883243203163, 38.64240646362305, 39.222095757722855, 40.313408598303795, 40.77889122068882, 42.68852815032005, 40.59720017015934, 42.36171908676624, 41.34935840964317, 42.94649250805378, 44.59392450749874, 48.0252505838871, 44.19893570244312, 38.702739626169205, 36.170924082398415, 49.205132871866226, 45.59314548969269, 40.02128027379513, 40.06346561014652, 41.8812994658947, 37.30780407786369, 51.618181988596916, 51.24145120382309, 50.48710808157921, 48.80452036857605, 49.60630774497986, 45.548209100961685, 46.00358426570892, 44.16029937565327, 42.28516839444637, 40.99126182496548, 41.96290388703346, 41.60308979451656, 41.093749925494194, 38.8133554905653, 39.76347550749779, 39.225036799907684, 39.47534456849098, 39.69395063817501, 39.624786749482155, 41.81546799838543, 44.487469419837, 51.99773982167244, 51.692638993263245, 47.74444945156574, 49.65752139687538, 48.90961512923241, 47.989049926400185, 46.839759796857834, 43.53739880025387, 44.88008715212345, 43.97731639444828, 40.660489574074745, 44.53196883201599, 49.849247708916664, 51.87167018651962, 54.21699933707714, 55.619663670659065, 47.90256656706333, 51.61840617656708, 58.45210388302803, 50.88151931762695, 53.86060506105423, 52.14109852910042, 55.08102737367153, 51.20856396853924, 46.9532635062933, 46.900138556957245, 47.59646259248257, 44.785042852163315, 51.02978736162186, 49.77054253220558, 53.15097413957119, 54.29992988705635, 60.23716449737549, 55.516237020492554, 60.06545931100845, 59.490683153271675, 65.49171254038811, 56.42753452062607, 65.49631789326668, 54.349095448851585, 58.414238914847374, 4.325190586969256, 0.04385808155348059, 2.7121025696396828, 0.37158416875172406, 0.8862474630586803, 9.329072255641222, 70.20853623747826, 63.250250816345215, 62.23689079284668, 58.60408052802086, 57.731689140200615, 41.799942031502724, 44.47261601686478, 26.90451141446829, 33.15083473920822, 51.692802384495735, 20.534816309809685, 0.758813819848001, 0.060895369097124785, 0.16205671738134697, 0.02386202377238078, 0.07153187412768602, 0.02695196119020693, 0.11353026347933337, 0.005793512755190022, 0.22688809636747465, 0.0690188210865017, 0.1426860099309124, 0.0542128970118938, 0.7466298923827708, 0.09375043227919377, 20.983847714960575, 81.62846624851227, 62.26991482079029, 57.85188049077988, 89.56883177161217, 78.33471938967705, 34.174458011984825, 62.45018094778061, 62.07607202231884, 68.03610920906067, 66.19130820035934, 59.933693781495094, 61.07441157102585, 4.106414001435041, 0.5484098475426435, 1.7748549557290971, 4.370240494608879, 2.563971793279052, 0.15505139250308275, 30.714781656861305, 58.727919682860374, 53.36094707250595, 55.47769948840141, 56.55745714902878, 58.59015427529812, 53.19244511425495, 57.449128702282906, 60.715425834059715, 59.30807255208492, 55.72404786944389, 52.57714793086052, 53.439910635352135, 53.08680698275566, 58.87710727751255, 57.06843473017216, 56.399165242910385, 43.81001517176628, 51.080799624323845, 56.36648699641228, 58.14304746687412, 54.89544913172722, 55.956230610609055, 55.03693453967571, 56.20447888970375, 52.91695989668369, 52.771526500582695, 48.47328454256058, 49.661340191960335, 48.944592252373695, 50.50574988126755, 45.967509001493454, 48.39172571897507, 52.11717501282692, 51.094220504164696, 50.496307387948036, 54.714491441845894, 55.34577436745167, 54.54644165933132, 52.340983003377914, 51.05439864099026, 44.85392555594444, 41.49451822042465, 39.61940623819828, 40.084896460175514, 40.96269115805626, 40.49327194690704, 42.84123055636883, 41.76006317138672, 42.85071104764938, 43.8521359115839, 42.37575173377991, 45.86966045200825, 45.98501466214657, 48.63526225090027, 47.426664903759956, 41.82285100221634, 41.5759364515543, 50.31289502978325, 47.50161588191986, 44.3434951454401, 42.62446738779545, 43.563704788684845, 41.105457097291946, 54.10288006067276, 50.74425928294659, 52.08391919732094, 52.28856481611729, 54.057548493146896, 46.92755028605461, 47.29179114103317, 45.18841400742531, 45.24385683238506, 43.353519067168236, 44.638655707240105, 42.99900949001312, 41.389723643660545, 39.7060339897871, 39.05319482088089, 42.25228875875473, 41.240471452474594, 40.339015424251556, 41.59624256193638, 42.564267218112946, 46.7348550260067, 54.539678022265434, 53.25866416096687, 50.31505711376667, 53.410188630223274, 51.891318932175636, 51.43153980374336, 50.52933521568775, 47.47980885207653, 46.7965143173933, 45.656788274645805, 43.785373494029045, 48.70507970452309, 51.8774800747633, 56.04195021092892, 56.56925931572914, 57.98416279256344, 49.04598221182823, 52.47749827802181, 64.28542166948318, 56.338486298918724, 56.29865303635597, 54.550834223628044, 59.03063043951988, 52.48455069959164, 48.91279175877571, 48.38612861931324, 48.88879984617233, 47.109442725777626, 53.288918137550354, 52.397649362683296, 54.06896688044071, 57.409759014844894, 63.693861812353134, 58.00114028155804, 61.19489170610905, 60.99417507648468, 67.51825779676437, 59.14658881723881, 69.6836020052433, 57.68832206726074, 65.74044719338417, 5.20448287948966, 0.01561967972520506, 3.8830323005095124, 0.8658189873676747, 0.8591933303978294, 9.884900730103254, 77.7619381248951, 67.09333419799805, 71.41499429941177, 63.02933067083359, 64.23301488161087, 46.152304485440254, 56.02186068892479, 24.66187935322523, 36.23541422188282, 60.90009592473507, 26.11154716461897, 0.806858204305172, 0.03730505115527194, 0.07966904100612737, 0.1007904377183877, 0.1581316170631908, 0.05117703432915732, 0.20242754719220102, 0.12655664730118588, 0.3950596653157845, 0.14449759240960702, 0.3009733889484778, 0.15809685486601666, 0.9334484708961099, 0.21280088665662333, 23.406183533370495, 91.89097076654434, 72.69495561718941, 77.94096931815147, 93.38583335280418, 83.41852739453316, 45.7905562967062, 70.3422586619854, 67.99887880682945, 74.67597171664238, 72.49333083629608, 63.51813264191151, 68.44537004828453, 4.490973791107535, 0.7655894500203431, 2.208050829358399, 7.472660494968295, 2.784945610910654, 0.4504470666870475, 38.200843557715416, 63.99674355983734, 59.68815855681896, 58.16119909286499, 60.69999486207962, 59.63600255548954, 58.15184399485588, 58.24561916291714, 64.51518774032593, 61.53962820768356, 59.40689764916897, 54.07713644206524, 56.70779228210449, 55.71318045258522, 59.62162032723427, 57.949311062693596, 60.43669179081917, 47.37897366285324, 54.16738919913769, 58.76471310853958, 61.90751686692238, 56.06588512659073, 58.17748501896858, 54.96620513498783, 59.001056626439095, 54.80371445417404, 55.691267028450966, 50.31687721610069, 50.612774938344955, 50.91711200773716, 53.36320795118809, 49.50494438409805, 50.14664635062218, 56.20262458920479, 55.364955738186836, 55.06209298968315, 58.22606921195984, 57.823606207966805, 56.958369836211205, 55.29839850962162, 52.66028746962547, 46.424293890595436, 42.29495286941528, 42.2555185854435, 41.64793498814106, 42.01332338154316, 44.9433271586895, 45.1848042011261, 47.245958000421524, 45.28492122888565, 47.280912324786186, 45.236937403678894, 48.24181616306305, 48.919878378510475, 51.85661159455776, 52.022449895739555, 44.819670394062996, 44.07353103160858, 53.601827546954155, 52.211865931749344, 45.530809834599495, 43.724797144532204, 46.09556972980499, 43.21939006447792, 58.60109768807888, 56.621373519301414, 56.49511009454727, 54.844999238848686, 56.57606475055218, 49.765101224184036, 48.36327664554119, 47.28233724832535, 47.02940762042999, 45.245084166526794, 47.98689924180508, 45.242640897631645, 45.18791623413563, 41.27110920846462, 43.578094616532326, 45.43353125452995, 44.71221596002579, 42.46859975159168, 44.85449552536011, 47.13263288140297, 49.57989916205406, 58.97669993340969, 58.61962549388409, 50.61025567352772, 55.741105154156685, 54.796445444226265, 55.53752347826958, 52.339079305529594, 49.84897032380104, 48.899169489741325, 49.01241101324558, 46.18236847221851, 50.01721389591694, 54.19246405363083, 59.82147440314293, 57.3773467540741, 58.97652514278889, 51.519018709659576, 53.27289059758186, 61.23600170016289, 57.84662917256355, 58.83651785552502, 56.72364883124828, 60.83408206701279, 54.674035012722015, 53.56650084257126, 50.700120851397514, 50.95989391207695, 49.04924623668194, 56.03965513408184, 54.371339455246925, 58.376275151968, 60.48865780234337, 66.65593966841698, 61.436478942632675, 64.71525460481644, 64.1722409427166, 72.96924769878387, 61.32781997323036, 72.94426783919334, 58.95751476287842, 71.85642421245575, 7.022590795531869, 0.39478705963119864, 9.746965281665325, 2.661372679285705, 1.111985631287098, 11.138015538454056, 82.72769406437874, 72.28776946663857, 76.64505645632744, 71.98327660560608, 70.73959574103355, 53.862067982554436, 62.82503843307495, 37.95604169368744, 49.493001624941826, 71.34742632508278, 36.735531985759735, 1.1498628300614655, 0.23665890097618103, 0.2520176174584776, 0.18316013185540214, 0.37733058852609247, 0.1260042074136436], [0.03219254795112647, 0.0241151425143471, 0.1430420923861675, 0.08134915944538079, 0.06847332027973607, 0.04104183150047902, 0.6966329470742494, 0.1609168082359247, 6.154872206971049, 59.69326168298721, 58.234212175011635, 35.2051755040884, 46.31112836301327, 56.302874609827995, 32.35136143863201, 53.11731934547424, 60.31133271753788, 60.110144913196564, 60.538074150681496, 54.77260932326317, 61.30980893969536, 9.663599655032158, 0.7077367231249809, 1.7898782808333635, 0.7005828351248056, 1.617832062765956, 0.2672862372128293, 9.318945799022913, 53.02164047956467, 51.95847652852535, 53.49019713699818, 52.72096261382103, 57.0625564455986, 51.70978367328644, 59.18863356113434, 56.03109419345856, 54.48340684175491, 51.06191083788872, 50.37092171609402, 50.52638277411461, 53.97424556314945, 53.084067329764366, 55.306951850652695, 48.01740400493145, 39.999488443136215, 50.97200766205788, 55.55206149816513, 52.78183914721012, 48.31508383154869, 52.49005660414696, 55.90889275074005, 54.173218086361885, 52.21628129482269, 49.04397591948509, 46.855745539069176, 45.399952456355095, 44.881470277905464, 47.06974245607853, 43.64331051707268, 45.11576570570469, 50.94230465590954, 47.71335192024708, 48.148857951164246, 49.66812662780285, 48.97021807730198, 49.83136206865311, 49.49655823409557, 49.070399701595306, 41.89036577939987, 36.89660154283047, 38.363368436694145, 39.12491597235203, 38.1496375054121, 41.02687731385231, 40.817671939730644, 42.338901311159134, 40.78483410179615, 38.609511628746986, 43.202363178133965, 45.66356711089611, 46.012863367795944, 47.98849895596504, 46.46807134151459, 43.83659474551678, 52.74755738675594, 57.20804683864117, 50.710642486810684, 41.478863060474396, 41.50798089802265, 38.87623071670532, 44.07254308462143, 49.458503276109695, 62.05190911889076, 52.370610013604164, 42.942491322755814, 43.31221528351307, 49.15762022137642, 45.492333099246025, 43.19475598633289, 43.70466202497482, 41.49230293929577, 40.16460858285427, 40.835561379790306, 40.17490603029728, 38.90755243599415, 40.129840448498726, 37.794242575764656, 38.4891264885664, 39.4340293854475, 38.25897663831711, 40.4852581769228, 47.65526823699474, 49.75418820977211, 50.31523950397968, 53.51109981536865, 44.99644450843334, 49.8385588824749, 48.490999191999435, 50.52523523569107, 42.33281023800373, 45.57313956320286, 45.20986005663872, 41.23226389288902, 43.08892786502838, 45.020535215735435, 49.94759403169155, 51.809870302677155, 54.02329333126545, 57.596294805407524, 51.61947391927242, 42.389298006892204, 50.42282313108444, 56.15416958928108, 54.68984976410866, 58.25376972556114, 53.855232149362564, 48.32773715257645, 41.63088910281658, 44.01787541806698, 44.709958881139755, 47.57362961769104, 45.562743321061134, 51.19511269032955, 54.579484686255455, 57.8018219769001, 56.33920066058636, 61.87062464654446, 57.0213058590889, 64.24696013331413, 54.998784586787224, 61.93224214017391, 58.208099976181984, 59.98169280588627, 6.277857832610607, 0.2628994913538918, 3.0358549347147346, 0.34622005478013307, 0.7794344227295369, 17.473542876541615, 66.2555855512619, 63.909956216812134, 59.483942314982414, 60.551905408501625, 53.636926263570786, 37.42391064763069, 43.791555762290955, 28.713415749371052, 40.25902211666107, 55.54856948554516, 19.328785724937916, 1.039598803035915, 0.05663840631314088, 0.13206514937337488, 0.09731720143463463, 0.0830149395915214, 0.013677722308784723, 0.09596766525646672, 0.08348926101461984, 0.0820320169441402, 0.07364587436313741, 0.10553178915870376, 0.1139715444878675, 0.6002019590232521, 0.14529832522384822, 8.25023889541626, 75.64447894692421, 62.40136116743088, 44.994654804468155, 57.27721832692623, 70.64351409673691, 34.99271370470524, 56.49757236242294, 67.85456255078316, 68.31104725599289, 66.77045792341232, 60.50290323793888, 68.12341332435608, 9.990565460175276, 0.5528702144511044, 2.6608202839270234, 2.059551472775638, 5.589993568137288, 0.4126221447950229, 12.256946247071028, 56.919497922062874, 52.715874686837196, 56.55558004975319, 53.51896159350872, 58.41772332787514, 53.03138695657253, 58.872205540537834, 58.815626576542854, 56.508318185806274, 53.65986183285713, 51.99428200721741, 51.893427819013596, 55.018440932035446, 56.48325093090534, 56.701860800385475, 51.09900824725628, 41.401780396699905, 53.939131647348404, 55.65194293856621, 54.98996905982494, 49.64831829071045, 55.925497859716415, 57.49343812465668, 54.648283794522285, 54.006080254912376, 51.743533462285995, 50.79647608101368, 48.8673309981823, 46.31853796541691, 50.54332986474037, 46.088908687233925, 46.812139078974724, 52.8266691416502, 50.730846002697945, 50.67301690578461, 53.81784975528717, 51.194162741303444, 53.10333229601383, 51.533131152391434, 54.506843984127045, 43.967296332120895, 38.683607652783394, 41.08805403113365, 40.66671743988991, 40.846227407455444, 42.63485603034496, 41.5377788990736, 44.1508074849844, 42.86321997642517, 41.81485243141651, 44.472665414214134, 46.634384617209435, 48.03565442562103, 51.29590608179569, 49.88402344286442, 46.373760402202606, 52.32290357351303, 59.45869266986847, 53.40949326753616, 43.43429893255234, 43.69153372943401, 43.7814749032259, 45.492409095168114, 52.630884647369385, 63.92615854740143, 51.121582835912704, 42.6450052857399, 44.75877866148949, 49.285908937454224, 46.185662895441055, 46.6091425716877, 44.764907732605934, 42.5110624730587, 42.78147876262665, 42.60064646601677, 42.034587040543556, 41.61043480038643, 41.54228165745735, 40.76898135244846, 39.976651668548584, 41.03274039924145, 40.43301858007908, 43.375892266631126, 49.24790717661381, 52.981670424342155, 53.071554601192474, 55.34152239561081, 49.16460044682026, 55.297965332865715, 51.47788591682911, 53.08085270226002, 44.77541036903858, 47.00251266360283, 47.722053453326225, 43.22280988097191, 45.499723702669144, 47.663768380880356, 52.40667387843132, 53.53722721338272, 56.62706941366196, 55.09322851896286, 57.022100016474724, 47.09046274423599, 48.996562063694, 55.4198931902647, 55.31433865427971, 59.210873767733574, 57.176170349121094, 49.6228102594614, 44.28579144179821, 45.96905171871185, 46.67286515235901, 50.27530364692211, 48.26070114970207, 54.95313003659248, 55.00823087990284, 59.720403626561165, 58.67587007582188, 63.14342334866524, 61.00475750863552, 66.98094382882118, 58.344163075089455, 66.17508307099342, 60.650734305381775, 68.48210647702217, 8.335144389420748, 0.245862778974697, 3.915178575553, 0.5203790485393256, 0.40383879735600203, 20.207731761038303, 75.07916048169136, 68.47649797797203, 65.8058188855648, 63.24709318578243, 61.981362104415894, 41.99667647480965, 57.76607349514961, 28.14660206437111, 43.9556385576725, 66.31942212581635, 23.465654142200947, 0.8404544577933848, 0.148420792829711, 0.0909812789177522, 0.09966667028493248, 0.04714493115898222, 0.024304395737999585, 0.20634101063478738, 0.2622161217732355, 0.2186173206428066, 0.1806302394834347, 0.2569336036685854, 0.1755255993339233, 0.7804039644543082, 0.26453942991793156, 10.342769511044025, 88.53302255272865, 72.98231899738312, 52.822101786732674, 55.01683361828327, 74.24403369426727, 44.66534927487373, 66.69258490204811, 73.276856392622, 74.60881412029266, 73.08226883411407, 67.43628859519958, 73.72368961572647, 12.087757475674152, 0.8205390139482915, 3.988104499876499, 4.145556651055813, 7.087755398824811, 0.35729438241105527, 14.56693634390831, 63.619549199938774, 58.265264108777046, 63.11692737042904, 60.311423912644386, 62.23530627787113, 55.93762680888176, 62.241773530840874, 61.59323953092098, 61.34814888238907, 55.688041001558304, 54.28829491138458, 55.33415079116821, 59.40094716846943, 58.097677901387215, 59.18479576706886, 54.201515167951584, 42.474056258797646, 55.99625766277313, 58.04485693573952, 56.67857185006142, 49.96682479977608, 58.179707899689674, 60.054151117801666, 58.0487023293972, 56.7669665068388, 54.40566301345825, 52.09567576646805, 51.5802676230669, 48.56072545051575, 53.452841341495514, 48.20663385093212, 47.13518254458904, 55.90377822518349, 53.69952790439129, 54.067519158124924, 56.098133996129036, 55.38638278841972, 55.30400700867176, 53.81219945847988, 55.47387309372425, 45.32194264233112, 40.64411245286465, 41.00847490131855, 41.90786384046078, 42.19319432973862, 45.626028925180435, 45.7012914866209, 45.003375336527824, 43.765306770801544, 42.6655887812376, 46.08417794108391, 49.88776244223118, 49.29667755961418, 53.87486569583416, 53.43171827495098, 47.11251676082611, 54.13676284253597, 61.32023938000202, 56.72659367322922, 45.19692935049534, 44.28190045058727, 44.74419504404068, 50.00910133123398, 55.33972889184952, 68.28804329037666, 54.03212785720825, 44.52101781964302, 44.82914328575134, 51.57438173890114, 47.96490602195263, 48.79846729338169, 46.32198818027973, 45.7055776566267, 44.95592728257179, 45.678861290216446, 45.47907941043377, 44.240847453475, 43.45186538994312, 42.78689727187157, 44.12235461175442, 42.80277281999588, 43.23390148580074, 45.86342118680477, 51.51396878063679, 56.392158418893814, 57.493650913238525, 59.627886191010475, 51.44037052989006, 59.36638422310352, 53.71833309531212, 56.38479061424732, 47.30886362493038, 50.25238327682018, 49.746406227350235, 45.156263932585716, 49.25041884183884, 50.39406247437, 54.25847411155701, 57.385850697755814, 57.015849351882935, 61.94994919002056, 52.847503423690796, 44.6034049987793, 52.80632123351097, 58.42469595372677, 58.61016780138016, 62.18070700764656, 59.886720702052116, 52.41447485983372, 47.068511322140694, 49.52631823718548, 50.212519615888596, 52.52078555524349, 50.9976676851511, 57.90193520486355, 58.79209443926811, 63.17761391401291, 60.830563455820084, 65.66495284438133, 63.359069377183914, 68.94621357321739, 60.642880126833916, 68.47228780388832, 62.29609541594982, 71.62599697709084, 10.479283835738897, 0.7583850959781557, 10.615430530160666, 1.6472259792499244, 0.8222385321278125, 22.573663406074047, 79.80406254529953, 74.12870988249779, 71.8717297911644, 70.00929772853851, 66.45897343754768, 48.250285908579826, 65.19275978207588, 39.96827691793442, 56.25675268471241, 77.68625378608704, 35.201474502682686, 1.228944780305028, 0.3017839032690972, 0.2541954646585509, 0.12155004485975951, 0.21185534598771483, 0.11340612443746068], [0.07291197194717824, 0.0933418280328624, 0.03169831099512521, 0.013912523918406805, 0.09997901055612601, 0.11195981220225804, 0.14525921404128894, 0.24691674741916358, 1.4025506959296763, 46.56445696949959, 58.90545755624771, 36.406648233532906, 29.412855617702007, 39.95212018489838, 36.649762988090515, 52.43017941713333, 62.29518346488476, 54.80198934674263, 62.01717138290405, 52.25555218756199, 65.14996647834778, 25.170634053647518, 0.24233661271864548, 2.4738674657419324, 2.4815651401877403, 4.447385855019093, 0.14934270351659507, 0.5622233531903476, 43.62284101545811, 48.94624896347523, 48.27551655471325, 49.2615370452404, 52.96419896185398, 55.01559868454933, 59.94509696960449, 54.5554243773222, 55.41251018643379, 49.514113292098045, 47.992952316999435, 47.98356682062149, 54.30755227804184, 53.94703522324562, 51.640536189079285, 41.75795428454876, 39.97664026916027, 53.28839376568794, 56.43478833138943, 51.70234367251396, 47.349760830402374, 56.60297490656376, 55.28014808893204, 52.78976172208786, 51.32984206080437, 51.85822270810604, 52.66583137214184, 51.39879696071148, 47.054037898778915, 46.451698020100594, 44.80816841125488, 41.896962225437164, 49.5890224725008, 49.47338707745075, 52.10810109972954, 50.03318063914776, 48.73056873679161, 49.68836434185505, 49.58826631307602, 47.31306239962578, 40.861293599009514, 38.62227514386177, 38.65697868168354, 40.521082654595375, 39.27720420062542, 40.37460811436176, 42.843312844634056, 42.158806174993515, 41.06076389551163, 40.46764612197876, 43.03593970835209, 43.93656738102436, 48.095983788371086, 50.78967064619064, 54.006448835134506, 45.26956245303154, 44.92552891373634, 41.749735325574875, 47.09729477763176, 47.16854475438595, 42.85498961806297, 46.494806706905365, 46.4012785255909, 48.676642030477524, 53.53979967534542, 45.844729989767075, 46.15501753985882, 49.42199103534222, 46.7629811167717, 44.22372177243233, 44.55643571913242, 41.76317140460014, 40.19973389804363, 38.46146397292614, 39.117548167705536, 39.08797435462475, 40.94088412821293, 40.849434435367584, 38.49573813378811, 39.00451563298702, 40.933318734169006, 38.75719830393791, 46.944086998701096, 49.009462371468544, 51.01506695151329, 48.91058027744293, 50.691597908735275, 47.19810336828232, 51.38205125927925, 46.43810234963894, 49.47662830352783, 40.358223393559456, 46.83817148208618, 45.77295944094658, 41.7533603310585, 44.38914969563484, 51.98422774672508, 49.28418383002281, 53.90153646469116, 51.48934610188007, 54.65127043426037, 31.780567467212677, 36.45017109811306, 57.01522998511791, 54.102241694927216, 54.62560661137104, 56.261654421687126, 52.31590434908867, 43.301648050546646, 41.57042674720287, 44.45804759860039, 42.558050751686096, 48.6257703602314, 47.41669423878193, 50.43313577771187, 48.181467801332474, 54.913881942629814, 55.71034960448742, 62.952529191970825, 59.02914471924305, 67.239238768816, 52.14436635375023, 62.71276965737343, 58.60609821975231, 68.04456755518913, 11.475209444761276, 0.5076722928788513, 1.9405428087338805, 0.4772159771528095, 0.46277749410364777, 23.055297061800957, 67.95097097754478, 64.42562654614449, 55.20382538437843, 63.393928706645966, 48.74444179236889, 46.879969239234924, 37.273959293961525, 21.77895125001669, 44.791722893714905, 52.596215307712555, 9.747300613671541, 1.060616069007665, 0.1351273397449404, 0.0844242780294735, 0.12440450809663162, 0.15136996895307675, 0.0416610424144892, 0.14961928711272776, 0.0537302672455553, 0.05104266478156205, 0.06143530008557718, 0.12463685969123617, 0.06035179045284167, 0.32730766804888844, 0.3209966223221272, 1.8390616541728377, 59.69569355249405, 69.14930507540703, 44.98787596821785, 43.133883252739906, 55.3800181299448, 40.16195632517338, 57.76988849043846, 67.70998790860176, 61.66768133640289, 69.56190973520279, 57.240785881876945, 70.66475495696068, 27.38588098436594, 0.17770395119441673, 3.114148546010256, 1.4976800163276494, 6.464254455640912, 0.2130082278745249, 1.2317365617491305, 49.78500455617905, 51.91982880234718, 53.81718099117279, 53.05563345551491, 54.8048809915781, 55.51246762275696, 61.58149816095829, 57.7780694514513, 58.09084586799145, 52.21853457391262, 52.652452290058136, 49.342617094516754, 53.987358659505844, 56.04148283600807, 54.037884548306465, 44.14533957839012, 43.747899904847145, 54.75979261100292, 55.711082965135574, 53.42206299304962, 48.601010888814926, 55.88482104241848, 56.10781207680702, 54.2667006701231, 53.23445945978165, 54.764040783047676, 54.93241734802723, 53.925300389528275, 48.066991344094276, 48.25297236442566, 47.61924996972084, 44.80050042271614, 51.928895115852356, 52.59986311197281, 53.9493340998888, 54.32924151420593, 53.19289728999138, 54.51213710010052, 51.11476220190525, 48.18935617804527, 44.36109200119972, 41.18095524609089, 39.73174341022968, 42.54326194524765, 41.56338192522526, 43.73399265110493, 42.80085772275925, 42.82247856259346, 42.6075354963541, 41.60784713923931, 44.64445039629936, 45.4267980158329, 49.784180000424385, 53.019151613116264, 55.757535472512245, 43.55482466518879, 43.96513804793358, 44.745931550860405, 48.97591397166252, 48.746907860040665, 43.55627238750458, 48.07570807635784, 49.01160165667534, 54.27317172288895, 56.353803277015686, 46.95469602942467, 46.41153797507286, 49.733885899186134, 47.80130200088024, 43.8181771337986, 46.53747081756592, 43.65980163216591, 43.37274603545666, 41.03042632341385, 40.89277870953083, 40.52009850740433, 42.82888501882553, 42.082016095519066, 40.33599078655243, 41.235155537724495, 42.58529908955097, 40.545127764344215, 49.39921885728836, 49.56864796578884, 53.023593574762344, 49.64117847383022, 52.74030737578869, 48.89394477009773, 53.84974904358387, 50.524133294820786, 53.970593959093094, 41.421030163764954, 46.36991120874882, 46.91658027470112, 44.11765806376934, 47.739897295832634, 54.52696770429611, 51.87824383378029, 55.08242569863796, 52.191483825445175, 56.72522194683552, 36.82015344500542, 37.71519161760807, 57.93451465666294, 55.16550824046135, 56.19771525263786, 60.09102053940296, 54.395855739712715, 47.252425253391266, 43.08390833437443, 46.105415001511574, 44.32954989373684, 51.14286169409752, 49.279985055327415, 54.35656204819679, 50.867775455117226, 57.60405398905277, 57.34038233757019, 66.75211250782013, 61.21000349521637, 70.50345361232758, 56.161905974149704, 67.9033063352108, 62.288465425372124, 76.43479093909264, 13.762222174555063, 0.1101848621328827, 1.493122042156756, 0.29484743485227227, 0.43483174522407353, 24.407163821160793, 75.49806520342827, 68.84180277585983, 61.42547473311424, 66.90775975584984, 55.32737955451012, 51.727969497442245, 48.822645395994186, 23.75483762472868, 48.78125041723251, 64.59241479635239, 13.232366256415844, 0.8627935184631497, 0.1532622377271764, 0.16882549010915682, 0.2368140988983214, 0.23140608362155035, 0.023827725417504553, 0.27585991309024394, 0.11547347326995805, 0.10506055506994016, 0.20956178312189877, 0.2414338939706795, 0.14001412986544892, 0.3102507989387959, 0.4328740487108007, 1.7379074008204043, 72.90134534239769, 78.16760435700417, 53.36452268064022, 39.61065150797367, 57.873702719807625, 48.01222488284111, 64.23413962125778, 71.6850458085537, 66.87386557459831, 75.98168805241585, 63.110748901963234, 74.8854848742485, 31.97643555700779, 0.22436105384258553, 3.8016173942014575, 3.913768851198256, 10.160352699458599, 0.2728881756775081, 2.288198978640139, 57.13297426700592, 59.66108500957489, 59.20748054981232, 57.75719717144966, 57.88500711321831, 57.8534422069788, 64.95097875595093, 59.87585708498955, 61.59056447446346, 55.59393145143986, 54.46814686059952, 51.40205718576908, 58.834294974803925, 59.942509308457375, 56.3607607036829, 44.96559016406536, 45.232951417565346, 59.133509919047356, 61.1846474558115, 55.96365161240101, 47.90052987635136, 59.60245415568352, 58.74822199344635, 58.224032521247864, 56.16991974413395, 58.077808767557144, 57.8760851919651, 57.03199468553066, 51.98779575526714, 50.454167649149895, 51.6536682844162, 47.25061275064945, 54.79085974395275, 56.66966512799263, 57.678214609622955, 58.81607875227928, 56.15386180579662, 57.440039590001106, 55.00896044075489, 53.75180549919605, 46.12832397222519, 42.95006051659584, 41.33311428129673, 44.944695085287094, 43.89549918472767, 45.24623170495033, 46.47220551967621, 44.49459783732891, 45.06340071558952, 44.52441483736038, 47.05766290426254, 49.10162642598152, 53.29757787287235, 57.769470512866974, 58.92390176653862, 45.214412212371826, 43.98478679358959, 43.494141921401024, 50.1316599547863, 52.191388830542564, 46.31111316382885, 52.455565854907036, 52.26343676447868, 55.75294151902199, 56.98449343442917, 48.49910795688629, 46.39398671686649, 54.02909182012081, 54.67644788324833, 48.411446660757065, 48.14136855304241, 45.55922470986843, 44.74680170416832, 43.01590718328953, 42.176076248288155, 44.05445985496044, 47.01224014163017, 44.132633060216904, 44.57304462790489, 43.51885959506035, 44.9068833142519, 41.53646416962147, 51.07099995017052, 53.75998646020889, 56.56460836529732, 53.2030313462019, 56.157524809241295, 50.76538994908333, 58.06993938982487, 52.2343835234642, 56.52035973966122, 44.85155068337917, 50.79860016703606, 49.48673956096172, 46.29078425467014, 49.499894455075264, 57.760613188147545, 54.722862392663956, 59.432595670223236, 55.016039460897446, 58.83337922394276, 35.75953155755997, 38.132739812135696, 60.621844455599785, 57.037827372550964, 59.1118510812521, 63.22867937386036, 57.61186636984348, 48.8705912232399, 45.54963402450085, 49.56503815948963, 47.41129092872143, 55.8499351143837, 51.43177539110184, 58.950420543551445, 52.669756561517715, 62.611432895064354, 61.30070082843304, 71.26480355858803, 63.44119817018509, 72.77944788336754, 58.331840336322784, 70.12897610664368, 65.5081732571125, 76.64259418845177, 15.844012666493654, 0.4663704091217369, 3.665405628271401, 0.989159062737599, 0.4162512469338253, 28.891740180552006, 79.6150454878807, 74.43961679935455, 67.18670278787613, 74.14085403084755, 59.41759407520294, 60.220878571271896, 52.35697254538536, 30.086099691689014, 61.2399572879076, 76.4715425670147, 19.648808352649212, 1.442786855623126, 0.42079470469616354, 0.33904829586390406, 0.4668162914458662, 0.32117862661834806, 0.2080368626047857], [0.038922599123907275, 0.06523738571559079, 0.08045023307204247, 0.08279790592496283, 0.04317343918955885, 0.15555342572042719, 0.06959483900573105, 0.6034939480014145, 0.31347997253760695, 31.694847866892815, 61.230837777256966, 44.38246585428715, 28.822553493082523, 29.36760574579239, 36.78551070392132, 52.37128257751465, 68.5678830742836, 46.96899086236954, 65.07713198661804, 50.93007691204548, 64.77008566260338, 33.3356112241745, 0.20811173046240583, 3.5549189569428563, 0.5219430802389979, 6.024309312924743, 0.5617670807987452, 0.06221845142135862, 23.4994438290596, 53.91710802912712, 43.509800881147385, 50.97230404615402, 52.524638548493385, 60.57122737169266, 56.55984342098236, 56.592046692967415, 51.43127381801605, 50.46106047928333, 47.41565689444542, 48.826262801885605, 50.36958418786526, 48.66270437836647, 47.148588225245476, 42.211269959807396, 42.20837451517582, 48.6423222720623, 54.76196609437466, 52.96619385480881, 51.621791794896126, 53.486097157001495, 53.21488671004772, 52.965677082538605, 54.69454251229763, 52.79489144682884, 53.64015229046345, 52.40964911878109, 51.53754651546478, 45.68758562207222, 48.221103474497795, 42.57154382765293, 47.922188714146614, 49.46005739271641, 48.71167615056038, 48.248526602983475, 49.63047444820404, 48.151327818632126, 51.70818775892258, 47.24176682531834, 45.453058406710625, 42.64739155769348, 41.92249305546284, 39.871503710746765, 40.44795177876949, 40.647292882204056, 41.23239308595657, 40.09245425462723, 41.24085143208504, 41.23929351568222, 46.764976009726524, 49.169578179717064, 53.732111155986786, 52.81101018190384, 43.900203332304955, 38.57610762119293, 44.408908635377884, 38.43058302998543, 44.687243700027466, 54.114708825945854, 42.78784342110157, 52.435191348195076, 47.26472519338131, 40.60740262269974, 41.617635414004326, 39.24252726137638, 40.436909571290016, 47.92841657996178, 49.60150100290775, 49.432493671774864, 51.98893949389458, 45.32197304069996, 44.12738174200058, 38.594255447387695, 40.95275469124317, 40.232339948415756, 40.5738390237093, 38.8130135089159, 39.47831600904465, 39.70488265156746, 40.104062631726265, 37.23905436694622, 48.00615280866623, 49.04718674719334, 48.587324023246765, 48.527211248874664, 50.4004043340683, 48.392314687371254, 48.31540301442146, 48.368786349892616, 49.72137697041035, 42.49649405479431, 46.11548066139221, 44.11281332373619, 49.62898872792721, 50.08478187024593, 52.92683556675911, 52.21533514559269, 52.386508360505104, 54.011206179857254, 52.0025921612978, 31.839397810399532, 49.99045953154564, 54.064809903502464, 53.23331572115421, 52.70533785223961, 53.9000279456377, 44.68199238181114, 43.344205766916275, 42.924940064549446, 40.57185173034668, 45.25250516831875, 48.97532880306244, 48.15160520374775, 53.108830600976944, 48.090143501758575, 52.298030108213425, 53.47276367247105, 63.905008882284164, 57.61049464344978, 66.09176114201546, 52.84735523164272, 60.29101520776749, 56.74627281725407, 69.39088851213455, 12.213100399821997, 0.5976117448881269, 1.239368689712137, 0.15274080476956442, 0.4478601773735136, 42.477966248989105, 67.73653328418732, 60.02033673226833, 51.11560195684433, 66.81809976696968, 49.871210530400276, 45.90893134474754, 40.83801984786987, 29.49154369533062, 39.5106902718544, 47.683447524905205, 1.6535432590171695, 0.46394898905418813, 0.025851189202512614, 0.14545900019584224, 0.033100261352956295, 0.06609192423638888, 0.18743251275736839, 0.06983529485296458, 0.05238790392468218, 0.07764674795907922, 0.062496671453118324, 0.029882034432375804, 0.09337412629975006, 0.080867698561633, 0.7291178195737302, 0.5941935908049345, 41.35012596845627, 70.27697056531906, 47.9664259403944, 31.997794210910797, 46.27117730677128, 39.007468074560165, 56.91148415207863, 74.5582540333271, 55.43755084276199, 72.44587898254395, 56.05605125427246, 70.70390045642853, 37.05696813762188, 0.4283904971089214, 4.907971490174532, 0.3406713728327304, 6.9718673173338175, 0.9031834511552006, 0.14668162912130356, 30.377006381750107, 56.32239416241646, 48.87851759791374, 54.343650341033936, 55.72094723582268, 62.14833654463291, 59.49042096734047, 58.93009543418884, 53.43519128859043, 52.744129970669746, 50.34589245915413, 50.793394446372986, 50.71530483663082, 50.239479169249535, 48.89084793627262, 43.62966924905777, 44.336397126317024, 51.6765658557415, 56.514903232455254, 55.07343538105488, 52.604103684425354, 55.94285912811756, 55.16507126390934, 55.93178652226925, 55.97982734441757, 55.09136661887169, 54.825962260365486, 55.4348111897707, 52.56809301674366, 47.70521655678749, 49.116730615496635, 43.74810889363289, 51.65885120630264, 53.0607745796442, 51.46968215703964, 53.0508229136467, 53.67832884192467, 49.19701650738716, 53.67328271269798, 50.14745570719242, 45.875781923532486, 45.58596007525921, 44.334554225206375, 42.72792063653469, 43.383282870054245, 43.15056815743446, 42.00776427984238, 41.175111159682274, 41.67370520532131, 43.15558768808842, 49.325039237737656, 52.752215936779976, 54.80504058301449, 56.845914870500565, 45.949672758579254, 38.65559555590153, 42.02361322939396, 37.930845245718956, 45.31486742198467, 54.85914207994938, 47.182930782437325, 53.77639777958393, 47.263752445578575, 43.53993706405163, 41.126849949359894, 39.60262633860111, 43.464617505669594, 47.4577434360981, 52.64799892902374, 51.754560470581055, 52.7890245616436, 47.71694652736187, 45.31159579753876, 41.75478145480156, 42.02154614031315, 40.566102638840675, 42.56960213184357, 40.06291463971138, 40.964952036738396, 41.278169229626656, 39.898987635970116, 39.06411923468113, 48.089543133974075, 52.26616121828556, 52.09637492895126, 49.79809485375881, 53.69776099920273, 50.63377261161804, 52.37627550959587, 51.599657982587814, 51.673875600099564, 44.147520661354065, 49.64246280491352, 45.38479506969452, 52.136645168066025, 52.67988681793213, 54.12346735596657, 53.53899411857128, 54.57052856683731, 56.87027536332607, 52.74702161550522, 34.16858732700348, 52.05710023641586, 55.275086760520935, 55.22904083132744, 55.056822672486305, 57.20319449901581, 48.02166357636452, 45.668947622179985, 46.21881611645222, 43.557685911655426, 45.779198706150055, 51.40039287507534, 51.3207795470953, 55.63387490808964, 51.39867156744003, 53.63309606909752, 56.83727793395519, 67.2050254046917, 61.787504106760025, 67.60923251509666, 56.39601141214371, 64.50153887271881, 59.9516212195158, 75.95667779445648, 17.791851796209812, 0.47028431785292923, 1.6992608620785177, 0.015571842741337605, 0.49194841005373746, 45.55474475026131, 73.06935712695122, 65.60806229710579, 56.668023616075516, 71.09654098749161, 57.32149735093117, 49.17317658662796, 54.13947209715843, 33.481025621294975, 46.362687796354294, 59.093710854649544, 3.3470784220844507, 0.4637985408771783, 0.10392642725491896, 0.08584756142226979, 0.07323876183363609, 0.08492261535138823, 0.16127446404425427, 0.17435673158615828, 0.32532248238567263, 0.19703664584085345, 0.2623872016556561, 0.12289592967135832, 0.33147907233797014, 0.1733564946334809, 1.0425019660033286, 0.7578131079208106, 48.59742768108845, 80.55116325616837, 62.77080774307251, 39.014113917946815, 44.867038652300835, 47.76223249733448, 63.87085631489754, 80.49514666199684, 59.1015612334013, 78.35690259933472, 60.41147634387016, 75.63019931316376, 41.3277717679739, 1.0938749718479812, 5.937859201803803, 1.198851226363331, 16.158133260905743, 1.9914210098795593, 0.3498867095913738, 35.164954662323, 61.00582145154476, 54.738509953022, 60.378592908382416, 57.12735056877136, 65.13721436262131, 63.529501631855965, 63.54820042848587, 56.134843826293945, 56.4156411588192, 52.15573914349079, 54.199630469083786, 55.86169548332691, 53.12588028609753, 52.00622096657753, 45.12586556375027, 47.343149185180664, 53.08021813631058, 58.794849291443825, 58.905556350946426, 55.5660979449749, 58.46808202564716, 56.289077550172806, 58.6980988830328, 59.77635942399502, 57.60948769748211, 57.559645771980286, 57.087779492139816, 55.41092187166214, 51.59169740974903, 52.82764948904514, 47.265390157699585, 54.247960075736046, 54.56305056810379, 54.20550115406513, 54.51018400490284, 56.33416973054409, 52.04467490315437, 57.06506431102753, 53.93438570201397, 47.61439763009548, 47.498807832598686, 47.911385893821716, 44.41924788057804, 44.05173920094967, 46.169532760977745, 44.31835189461708, 42.98146963119507, 43.30599121749401, 46.984167248010635, 51.163293197751045, 56.180874556303024, 58.77970710396767, 60.11850826442242, 44.98096413910389, 39.17969763278961, 43.435214683413506, 38.93086418509483, 47.73579731583595, 59.788370579481125, 48.99667225778103, 56.517965868115425, 51.981974467635155, 42.66307711601257, 40.8136023581028, 39.112798422575, 44.153326749801636, 48.87604393064976, 53.92344988882542, 51.56773589551449, 54.500627517700195, 50.5117953568697, 46.5078704059124, 43.07029366493225, 45.07529027760029, 44.13742080330849, 43.91766719520092, 43.759793266654015, 43.30653838813305, 44.709134325385094, 42.58337639272213, 40.90068228542805, 51.48114234209061, 54.39951874315739, 54.39941234886646, 53.435829654335976, 55.687459632754326, 53.73287871479988, 56.22988052666187, 55.80017678439617, 54.963678270578384, 47.054501473903656, 51.6450959444046, 47.95374222099781, 54.04023662209511, 55.926474407315254, 57.82455235719681, 57.4946578592062, 56.36334836483002, 58.58204551041126, 54.660811722278595, 35.00791668891907, 55.266039445996284, 57.320004031062126, 57.69523769617081, 58.96327145397663, 59.34461899101734, 49.07693535089493, 48.80505993962288, 49.40867654979229, 44.8481460660696, 49.59719583392143, 54.177701845765114, 53.953323885798454, 57.8461541980505, 53.67389068007469, 56.865510419011116, 61.05918198823929, 70.00436559319496, 65.0687724351883, 70.94521030783653, 58.20333883166313, 67.3875904083252, 63.46639461815357, 75.71714624762535, 21.66371863335371, 0.512783849844709, 5.4161139484494925, 0.5685339239425957, 1.3590984838083386, 49.85269412398338, 79.10339534282684, 70.8385044336319, 63.3796376734972, 77.94199526309967, 61.562198996543884, 60.97236044704914, 58.4627129137516, 41.02256454527378, 58.30387003719807, 70.9971459209919, 6.349273100495338, 0.8517713786568493, 0.5104830139316618, 0.25203263852745295, 0.22719492990290746, 0.19665360858198255, 0.3815920895431191], [0.11569642185349949, 0.10512737804674543, 0.032615067466394976, 0.13483870367053896, 0.04841093861614354, 0.16504159080795944, 0.08496016060234979, 0.7156091881915927, 0.18622141680680215, 15.959027744829655, 67.39881500601768, 49.55464191734791, 50.91305002570152, 33.194904774427414, 36.52300179004669, 37.113911882042885, 66.7468611896038, 45.28459444642067, 61.4307564496994, 53.72681804001331, 57.54483416676521, 46.73338830471039, 0.3735062124906108, 2.525495057925582, 0.4807795328088105, 2.9912365414202213, 0.7852464483585209, 0.10848817153600976, 9.947676211595535, 51.050545647740364, 45.925357863307, 49.82505060732365, 55.89710958302021, 57.819422632455826, 54.97889265418053, 53.21320720016956, 51.84356689453125, 46.71188145875931, 45.62401883304119, 46.36152885854244, 47.02380672097206, 46.622928231954575, 41.469925940036774, 40.123597383499146, 40.536722615361214, 46.52794472873211, 51.526967883110046, 54.04712185263634, 54.49401207268238, 55.43835259974003, 54.25052493810654, 52.38255277276039, 54.23838458955288, 53.83120983839035, 55.09160600602627, 54.41297762095928, 54.475586861371994, 48.521021381020546, 47.09196746349335, 44.34655778110027, 46.89588278532028, 49.749012887477875, 48.606353402137756, 48.68405923247337, 50.44167771935463, 48.64484153687954, 46.86068147420883, 47.93602757155895, 46.30153767764568, 43.825522139668465, 39.37036760151386, 39.91512916982174, 40.86489200592041, 39.568207785487175, 40.77666074037552, 40.689740404486656, 40.79845257103443, 42.09204375743866, 45.886140167713165, 52.81782701611519, 54.39589373767376, 51.03122368454933, 43.31460915505886, 38.65706987679005, 37.53382734954357, 42.40131676197052, 40.040305852890015, 56.35460503399372, 47.77550518512726, 52.39729978144169, 42.79668554663658, 41.22007794678211, 40.4297811537981, 41.6641753166914, 38.90103578567505, 41.80201672017574, 46.908885687589645, 54.873262122273445, 52.463549226522446, 51.26824736595154, 43.50146792829037, 40.450809225440025, 39.20632280409336, 39.75118316709995, 42.24615968763828, 39.646422788500786, 39.467748776078224, 40.88072955608368, 40.014391243457794, 39.617035165429115, 43.46426032483578, 53.10367047786713, 50.786311626434326, 48.58496055006981, 48.057488054037094, 46.99957922101021, 46.04578100144863, 49.722953885793686, 47.23757945001125, 42.46454156935215, 45.83298102021217, 45.432239323854446, 52.485588043928146, 55.568024441599846, 57.208765000104904, 52.76931121945381, 56.53400860726833, 48.495004177093506, 45.81609472632408, 48.9220404624939, 53.48580837249756, 49.95957098901272, 52.48398832976818, 48.04432176053524, 45.419760793447495, 39.97601330280304, 42.55974926054478, 39.540963247418404, 42.32305996119976, 45.36129333078861, 47.53135308623314, 49.15629409253597, 50.696476846933365, 47.771522998809814, 49.95780408382416, 47.49425567686558, 56.21805176138878, 56.772092431783676, 57.62463368475437, 49.67003412544727, 61.568768844008446, 58.20926271378994, 72.34787464141846, 13.496361840516329, 1.3455410487949848, 0.47198526095598936, 0.5414799693971872, 1.6292575746774673, 56.727551221847534, 66.1670047044754, 58.32953006029129, 53.45308072865009, 64.90028947591782, 44.487021043896675, 56.71470791101456, 32.89782911539078, 23.909069448709488, 47.60676383972168, 41.770683601498604, 0.6980072858277708, 0.2718978835036978, 0.05979110901535023, 0.023009153228485957, 0.1008023417671211, 0.07006784682744183, 0.18987259041750804, 0.11865509746712632, 0.03364654883625917, 0.02347076722799102, 0.18700214131968096, 0.05624406985589303, 0.10352772325859405, 0.12775767972925678, 0.7827048597391695, 0.22361599694704637, 21.452712155878544, 76.47288009524345, 56.39476127922535, 44.05341111123562, 40.879620015621185, 45.06188079714775, 41.156195774674416, 73.35907638072968, 50.156609416007996, 70.77412068843842, 58.34190219640732, 64.61517557501793, 50.673203095793724, 0.8306231978349388, 2.781916460953653, 0.2640425768913701, 7.998508103191853, 2.819597851485014, 0.06725967876263894, 13.618149105459452, 55.74512533843517, 49.120382219552994, 52.58130490779877, 57.99363188445568, 61.1945079267025, 57.09835812449455, 55.06549000740051, 56.17112047970295, 48.79845969378948, 48.410375118255615, 50.097689777612686, 49.505468755960464, 49.0361787378788, 43.82262669503689, 42.388465851545334, 43.75098533928394, 48.79421152174473, 53.689390048384666, 55.47089025378227, 54.87758629024029, 58.060865476727486, 55.213397070765495, 56.124588176608086, 55.287238508462906, 56.62596747279167, 57.63276144862175, 57.094277143478394, 55.267232581973076, 51.252003237605095, 49.09551255404949, 45.84609031677246, 48.558426573872566, 53.147660717368126, 51.54062435030937, 50.88917590677738, 53.58605079352856, 52.628870755434036, 50.53220026195049, 49.4581612944603, 47.800105065107346, 45.79044610261917, 41.54128611087799, 41.382572427392006, 44.61092099547386, 41.72914043068886, 42.2467752546072, 40.934200286865234, 42.00926139950752, 42.50374786555767, 47.34181925654411, 54.721703454852104, 57.635090723633766, 52.87397660315037, 43.655382469296455, 38.33994269371033, 37.92030081152916, 42.27277725934982, 41.585204154253006, 56.3099080324173, 48.276105523109436, 51.859605833888054, 45.27308486402035, 39.79856662452221, 40.703073889017105, 40.7396849244833, 40.85854634642601, 41.27328649163246, 50.125850066542625, 56.62884771823883, 54.12467189133167, 51.71920716762543, 43.973083421587944, 41.32290802896023, 41.68728567659855, 41.541324108839035, 43.28367501497269, 41.9077954441309, 40.154235139489174, 42.66795605421066, 41.90432623028755, 42.05439157783985, 45.47845244407654, 54.05974857509136, 53.65456111729145, 52.02729843556881, 49.32354211807251, 49.7554687410593, 49.46643345057964, 50.91879531741142, 49.59616228938103, 45.44253297150135, 48.37833523750305, 48.1540484726429, 53.203175738453865, 58.8081181794405, 59.57355670630932, 53.80890503525734, 59.540650472044945, 50.08844867348671, 47.029821798205376, 49.522206857800484, 56.461831480264664, 53.1961765140295, 55.4132017493248, 52.13545963168144, 47.54737302660942, 42.72560656070709, 45.40242612361908, 42.427968531847, 45.398880913853645, 45.8835107088089, 50.61147540807724, 52.65188232064247, 53.90670798718929, 50.209149196743965, 54.34312216937542, 50.132898688316345, 60.21906606853008, 58.75853084027767, 60.3377602994442, 51.04023300111294, 64.72915425896645, 61.94026730954647, 77.00231328606606, 18.61011888831854, 1.1304233106784523, 0.5758183705620468, 0.4135353723540902, 2.1622165013104677, 64.14041385054588, 70.4525363445282, 64.15104568004608, 57.19770759344101, 72.4458409845829, 48.340211883187294, 63.327135890722275, 42.35785089433193, 28.094075582921505, 54.42569173872471, 52.09630273282528, 2.0090094348415732, 0.24994245381094515, 0.03462701497483067, 0.02447782451781677, 0.06273279315792024, 0.056269848355441354, 0.12022820563288406, 0.26635338726919144, 0.13877449091523886, 0.07020627963356674, 0.30682457028888166, 0.1576067108544521, 0.2121711743529886, 0.3022152988705784, 0.8558890514541417, 0.49237069208174944, 24.081601090729237, 88.47323656082153, 68.6688968539238, 64.73936811089516, 48.1246380507946, 50.673032104969025, 45.768084302544594, 77.48542696237564, 54.48738142848015, 72.34358087182045, 65.7498250901699, 69.6083964407444, 54.46072205901146, 1.7400136752985418, 4.290967248380184, 0.6458680867217481, 14.972850512713194, 3.6132472520694137, 0.3114720474695787, 17.113240510225296, 59.290726482868195, 53.46834450960159, 55.686566680669785, 61.67393960058689, 64.19221267104149, 58.60140547156334, 58.22101168334484, 57.80327349901199, 53.43638442456722, 52.34664089977741, 52.27360501885414, 52.09648512303829, 52.2590783983469, 46.101094633340836, 45.04483871161938, 45.82182861864567, 51.65989615023136, 54.93623614311218, 59.733531922101974, 59.148370921611786, 60.97492150962353, 57.94272221624851, 56.407011821866035, 56.07085146009922, 59.01900306344032, 60.404773503541946, 59.08136531710625, 57.61076062917709, 52.7236832678318, 52.65741482377052, 48.46893757581711, 51.45156092941761, 55.33055618405342, 53.22469778358936, 55.82509584724903, 58.14669527113438, 55.21758444607258, 52.73283317685127, 53.83709192276001, 51.78516782820225, 47.936107367277145, 43.15364979207516, 45.838840305805206, 46.118972674012184, 44.05184179544449, 43.75062815845013, 43.81503090262413, 43.19314867258072, 45.802419260144234, 50.44957369565964, 56.309459656476974, 60.87138846516609, 55.43669208884239, 44.737682193517685, 38.71296867728233, 37.71951578557491, 41.153820902109146, 41.71554856002331, 60.11678695678711, 51.507877707481384, 55.65714105963707, 47.03652083873749, 40.17422206699848, 39.68136951327324, 43.58001731336117, 38.58763240277767, 41.200588792562485, 49.93065074086189, 60.211565271019936, 58.193968534469604, 55.422211065888405, 49.17729936540127, 44.13946129381657, 43.75352740287781, 45.845296159386635, 45.54588362574577, 42.78054021298885, 43.07296112179756, 45.075039491057396, 44.21056307852268, 44.36306789517403, 47.348518297076225, 58.3868233859539, 56.591514721512794, 55.37336088716984, 52.516696974635124, 54.21897903084755, 50.753914564847946, 53.55266958475113, 51.33804962038994, 46.27554327249527, 49.1197856515646, 50.278153494000435, 55.34174658358097, 60.355326756834984, 63.724647760391235, 57.63156071305275, 61.928985714912415, 52.47712589800358, 47.60166071355343, 52.2685930877924, 58.31277295947075, 54.17670249938965, 56.080107763409615, 52.713446617126465, 50.27004472911358, 45.97837641835213, 47.87507884204388, 44.40114565193653, 46.125010550022125, 49.90731619298458, 54.22070413827896, 55.5345444381237, 57.17774346470833, 53.09254847466946, 57.8165689855814, 53.00077959895134, 62.64470770955086, 61.74343027174473, 63.57725366950035, 54.782500192523, 67.9834896326065, 65.46785742044449, 78.26305523514748, 26.14144206047058, 1.0420177294872701, 3.387022828683257, 0.575840575620532, 3.679652251303196, 70.14972299337387, 75.9262490272522, 70.14251098036766, 65.28807386755943, 77.03749179840088, 53.826137110590935, 73.4653414785862, 46.386501118540764, 33.899709954857826, 66.83053269982338, 64.36953395605087, 3.2641661586239934, 0.4266050085425377, 0.22809981572208926, 0.2517222723690793, 0.24731314333621413, 0.2615976455854252, 0.2977562084561214], [0.036930489222868346, 0.10483768812264316, 0.03915656117897015, 0.14014926011441275, 0.054554440794163384, 0.21081703685922548, 0.12149297370342538, 0.3768426412716508, 0.27442106686066836, 3.4451041370630264, 51.21435105800629, 52.487396746873856, 42.6822204887867, 42.921166867017746, 42.02920272946358, 42.215016558766365, 60.58669254183769, 51.8261144310236, 50.29624052345753, 55.382765382528305, 54.41179968416691, 57.52130962908268, 4.663851214572787, 0.9583210456185043, 0.21253801794955507, 3.3472401509061456, 1.4154366357252002, 0.08702032544533722, 3.1083666812628508, 54.84105885028839, 51.68271392583847, 54.0849906206131, 57.166002094745636, 56.77190624177456, 55.35876207053661, 51.6716793179512, 48.00078369677067, 46.17641419172287, 46.34304665029049, 44.595942199230194, 44.200934395194054, 42.14981585741043, 40.9226831048727, 43.372768834233284, 42.43720583617687, 43.74356433749199, 49.67658117413521, 51.80498756468296, 53.06208550930023, 53.116198405623436, 54.062195643782616, 52.64759615063667, 50.56017816066742, 48.66602540016174, 51.23215690255165, 52.48741194605827, 56.450025513768196, 54.243115335702896, 47.76056818664074, 41.59511402249336, 43.80349852144718, 53.43588665127754, 50.03531992435455, 49.85521338880062, 49.7326585650444, 47.228782922029495, 50.29119439423084, 47.882933020591736, 48.090382888913155, 43.83283294737339, 40.09924829006195, 41.389294266700745, 39.21342082321644, 40.0178262591362, 38.547270968556404, 40.84869347512722, 39.75582651793957, 42.33562968671322, 48.38496968150139, 57.798884734511375, 51.14924915134907, 51.69839948415756, 41.453590616583824, 37.717270106077194, 37.456911876797676, 40.31607985496521, 37.16449476778507, 54.52640153467655, 50.35158075392246, 51.06845788657665, 40.78956484794617, 40.78627422451973, 41.40076965093613, 40.647190287709236, 41.87808483839035, 42.178838700056076, 45.5335608869791, 53.52464608848095, 60.68311236798763, 50.86668111383915, 45.043816566467285, 40.66638305783272, 38.66544462740421, 38.48968505859375, 39.56281967461109, 38.70968945324421, 39.41123440861702, 39.88985292613506, 41.014121398329735, 38.17955709993839, 44.135232120752335, 46.77811190485954, 48.993282839655876, 48.062693774700165, 49.64785471558571, 50.188466906547546, 49.312879890203476, 47.77748107910156, 44.98889051377773, 42.30003319680691, 45.49426719546318, 48.08916695415974, 56.113078594207764, 45.60924142599106, 33.090322986245155, 46.83496065437794, 42.336123660206795, 44.00312460958958, 51.616327688097954, 53.76481220126152, 52.908805534243584, 53.292459547519684, 50.72347439825535, 43.777853697538376, 42.52241626381874, 47.993484288454056, 42.26530306041241, 39.48989778757095, 39.242591857910156, 44.59408409893513, 43.393401727080345, 47.200337648391724, 50.76089859008789, 49.77723017334938, 47.37175025045872, 45.994358360767365, 45.65649949014187, 49.65764679014683, 47.855612486600876, 51.58315546810627, 58.60490508377552, 59.7875764220953, 61.01092837750912, 5.143983475863934, 1.4548799442127347, 0.15448713762452826, 0.6050460459664464, 6.114696962758899, 62.13602900505066, 61.306651309132576, 51.183838695287704, 55.61111032962799, 55.629611536860466, 51.40445105731487, 42.69434563815594, 40.301659628748894, 46.26627936959267, 40.40076591074467, 31.580745689570904, 1.0589969996362925, 0.0440572220395552, 0.10576486805803142, 0.06364770539221354, 0.13293690572027117, 0.04110275440325495, 0.09230190102243796, 0.09930358937708661, 0.03723799811268691, 0.05750427742896136, 0.09389829778228886, 0.07805055793141946, 0.19630230555776507, 0.04312226068577729, 0.49613536975812167, 0.08556835062336177, 5.358625883236527, 63.01437847316265, 63.62743757665157, 45.08899614214897, 45.71856535971165, 53.26576218008995, 42.30539470911026, 66.861592233181, 52.73662157356739, 57.20944136381149, 64.17202055454254, 59.80465270578861, 63.17942641675472, 5.715198274701834, 0.8872782764956355, 0.34924234729260206, 6.513142632320523, 2.674175617285073, 0.27135053474921733, 5.616303356364369, 57.56233222782612, 55.080096423625946, 57.063441798090935, 61.1930526047945, 60.48108100891113, 56.946647465229034, 54.12368394434452, 51.22133508324623, 49.180118814110756, 48.725359216332436, 47.62283317744732, 46.90237283706665, 43.74908164143562, 42.94171616435051, 45.54181784391403, 45.405021384358406, 47.92145535349846, 51.09342634677887, 53.64910461008549, 54.72079150378704, 55.731689259409904, 57.490854263305664, 52.93278984725475, 51.18034668266773, 50.27553163468838, 54.01856638491154, 53.072394356131554, 57.623736932873726, 54.84829746186733, 49.34362404048443, 44.22059454023838, 47.024357691407204, 53.73334228992462, 51.888951659202576, 51.12934201955795, 52.1739249676466, 51.57489091157913, 52.89486028254032, 50.38267448544502, 51.45015500485897, 47.806321531534195, 41.81774027645588, 43.63916493952274, 40.86426503956318, 40.10525196790695, 41.438798010349274, 41.641448736190796, 42.572980150580406, 43.48429284989834, 49.21691223978996, 60.820060819387436, 55.75230695307255, 52.655606120824814, 41.90300390124321, 37.298464179039, 37.599457427859306, 39.68969866633415, 39.12033721804619, 54.50458310544491, 52.84294366836548, 53.354810401797295, 41.38039894402027, 40.975815653800964, 41.2422801554203, 39.813089445233345, 40.33609338104725, 41.95296362042427, 45.7373059540987, 54.51567471027374, 61.674338579177856, 50.65304517745972, 46.48637115955353, 41.932824701070786, 41.12529203295708, 38.587214425206184, 43.54251712560654, 40.944421738386154, 41.44969962537289, 41.61525294184685, 42.161979004740715, 40.703070089221, 47.17686630785465, 49.37974490225315, 50.35002663731575, 49.89525184035301, 50.54330326616764, 53.67335870862007, 52.38735571503639, 50.463017374277115, 48.382625207304955, 44.150685891509056, 47.947324365377426, 50.11183261871338, 57.55274914205074, 46.513877883553505, 33.967323526740074, 48.35666500031948, 44.13999326527119, 45.95333196222782, 53.078432232141495, 56.15970589220524, 54.128163903951645, 54.27185699343681, 51.955581083893776, 44.729672223329544, 45.00630497932434, 50.036437064409256, 43.792961686849594, 42.92972020804882, 43.38695727288723, 46.53905153274536, 45.96169151365757, 48.71972791850567, 54.00702640414238, 52.565045580267906, 51.635828241705894, 47.62457728385925, 48.80562610924244, 50.74224539101124, 51.882237419486046, 54.42934334278107, 62.85351790487766, 62.904575765132904, 67.20184877514839, 10.582289658486843, 1.5600170963443816, 0.6036787130869925, 0.33568906830623746, 6.827599983662367, 70.65169125795364, 67.51334846019745, 63.06225970387459, 63.92910718917847, 63.94931450486183, 54.06254522502422, 49.836753979325294, 42.13479906320572, 36.02692700922489, 51.85658499598503, 39.96394895017147, 0.916235453914851, 0.07124304509488866, 0.02479781447618734, 0.03593374778574798, 0.032546841830480844, 0.02818632903654361, 0.17417217430192977, 0.16222463571466506, 0.1657454139785841, 0.17394550755852833, 0.250804087263532, 0.2119860381935723, 0.35166445013601333, 0.20584335608873516, 0.5501650564838201, 0.34884853404946625, 6.409200634807348, 76.07089206576347, 70.10225594043732, 58.0252917855978, 53.772301599383354, 63.025272488594055, 49.45651598274708, 75.85805028676987, 59.915591552853584, 63.95013526082039, 70.91899931430817, 66.97540372610092, 68.41234982013702, 9.150221552699804, 1.778564981650561, 2.319340445101261, 13.827329780906439, 6.863643424585462, 0.3329027787549421, 6.956330901011825, 62.78162956237793, 57.11556740105152, 60.08769191801548, 62.98168122768402, 63.10484021902084, 60.391952991485596, 58.32214705646038, 53.85607950389385, 52.720795422792435, 51.28679417073727, 50.091325119137764, 48.227217346429825, 46.562199890613556, 44.78568121790886, 48.49196054041386, 47.75334097445011, 48.41449409723282, 53.512954115867615, 55.93965210020542, 58.52142736315727, 57.5172134488821, 60.78284181654453, 56.87770016491413, 54.4691614061594, 51.873798072338104, 55.69763548672199, 56.62751778960228, 61.007436364889145, 57.85203628242016, 50.92551715672016, 45.55982507765293, 48.70719239115715, 58.95747296512127, 56.8209084123373, 55.963640213012695, 56.750885769724846, 55.48622243106365, 55.829180628061295, 52.5932514667511, 56.05286322534084, 51.11799582839012, 45.030532479286194, 45.74190750718117, 42.32228100299835, 42.80181907117367, 42.124273627996445, 44.85400155186653, 44.568306282162666, 45.26983603835106, 52.649321258068085, 62.9853480309248, 58.665553629398346, 56.54745988547802, 41.999283134937286, 37.43583060801029, 37.003600001335144, 39.76936899125576, 38.544219732284546, 57.81547084450722, 54.67606410384178, 56.37898452579975, 42.14362218976021, 40.250742360949516, 41.553217470645905, 41.04522652924061, 42.26338416337967, 41.81951478123665, 45.474975630640984, 55.65154775977135, 62.97961413860321, 53.87800432741642, 48.29309441149235, 45.09969636797905, 42.52139411866665, 41.34978398680687, 45.06302073597908, 43.5217322409153, 43.5857892036438, 43.677162900567055, 46.41450181603432, 41.07464835047722, 50.53729958832264, 51.892295479774475, 54.04809460043907, 53.89614835381508, 54.002983421087265, 57.10192613303661, 54.403846710920334, 53.71464729309082, 50.207374691963196, 46.68085612356663, 48.699984177947044, 53.89516040682793, 59.65305984020233, 50.4576900601387, 36.4345995336771, 51.03201024234295, 44.52944956719875, 46.497268974781036, 55.017103403806686, 58.68082880973816, 55.819817930459976, 57.26974792778492, 54.09632921218872, 48.90787102282047, 46.68798454105854, 51.315657421946526, 46.083661168813705, 45.41031830012798, 44.10278186202049, 50.15572786331177, 49.317021667957306, 51.87843382358551, 56.994395703077316, 54.892101511359215, 53.27749215066433, 51.16001017391682, 50.01952797174454, 53.61896462738514, 54.80029083788395, 56.99102148413658, 65.8498053252697, 64.04072239995003, 67.2893276810646, 20.173858478665352, 1.1388516146689653, 2.086380645632744, 0.6511262920685112, 8.555941041558981, 73.02469432353973, 73.16248252987862, 65.50617456436157, 64.2909237742424, 71.16252824664116, 63.65082532167435, 60.43829910457134, 55.28726510703564, 59.942543506622314, 59.93612565100193, 53.5698826611042, 1.592609016224742, 0.3008220798801631, 0.18645544565515593, 0.21822309179697186, 0.1869410031940788, 0.18269179214257747, 0.3463906893739477], [0.0369673925160896, 0.06458383562858216, 0.09488939889706671, 0.050858619579230435, 0.1409123808844015, 0.0926286686444655, 0.03345652192365378, 0.014311184313555714, 0.25045118120033294, 0.6208756996784359, 41.661652252078056, 60.577949211001396, 45.56646332144737, 39.774441719055176, 40.45757286250591, 44.51334983110428, 48.26120652258396, 65.74449017643929, 53.86890381574631, 55.42873151600361, 48.884145095944405, 67.47279703617096, 19.7278194129467, 0.45883867889642715, 0.5851271585561335, 4.138285266235471, 4.3849271815270185, 0.09521494197542779, 0.30401355237700045, 42.91608273983002, 54.48458097875118, 56.06202833354473, 58.431657180190086, 56.75155073404312, 54.93806764483452, 50.94033256173134, 45.91967336833477, 42.749868258833885, 41.807188242673874, 39.497136399149895, 43.91172431409359, 38.40835802257061, 40.89119419455528, 38.99684764444828, 40.99261835217476, 42.81224951148033, 47.09069833159447, 48.21840561926365, 50.510575622320175, 53.63601051270962, 56.30002096295357, 53.27055372297764, 52.24901653826237, 53.25728863477707, 52.9902009665966, 52.078067511320114, 52.32720874249935, 55.462447106838226, 48.349532783031464, 43.47540892660618, 42.47406005859375, 50.76453119516373, 49.686346650123596, 49.40155953168869, 49.59152273833752, 47.4843268096447, 49.50607292354107, 49.72186714410782, 43.42891842126846, 41.96483038365841, 39.16017048060894, 40.420315861701965, 36.96911685168743, 39.71296101808548, 37.44495011866093, 38.143329843878746, 41.81845083832741, 43.848469108343124, 51.173256263136864, 56.17058850824833, 54.38528850674629, 52.559881657361984, 40.75025595724583, 39.78740282356739, 39.00872200727463, 40.79003602266312, 39.19346809387207, 51.32422216236591, 51.00321538746357, 47.87088006734848, 41.57356157898903, 42.33787156641483, 42.18227371573448, 40.7179918885231, 40.82181751728058, 39.56154674291611, 44.92443457245827, 54.355980679392815, 61.34900003671646, 55.68927213549614, 46.46304801106453, 40.77376909554005, 39.53766502439976, 39.294067695736885, 38.46223533153534, 40.03755860030651, 39.73849564790726, 41.07881672680378, 39.39211763441563, 43.9198786765337, 45.264911502599716, 45.41126444935799, 49.00321550667286, 46.02584347128868, 50.68487986922264, 46.907795146107674, 49.74201746284962, 48.33551153540611, 44.24008369445801, 42.35913522541523, 46.44344866275787, 46.33888587355614, 55.20270064473152, 50.07028564810753, 41.35788895189762, 48.07785876095295, 42.01958544552326, 53.78139071166515, 51.99107117950916, 55.279536321759224, 52.06715069711208, 50.580951645970345, 40.3338249027729, 40.21396033465862, 41.87877260148525, 43.91076296567917, 39.195778369903564, 41.42108716070652, 40.249522626399994, 39.93886649608612, 41.67110234498978, 45.29564805328846, 46.11181765794754, 48.32342058420181, 47.08947479724884, 49.12900775671005, 45.65290868282318, 47.506798803806305, 46.71791933476925, 56.02733239531517, 57.325715124607086, 61.06824830174446, 54.39483739435673, 2.2154039097949862, 0.5586356925778091, 1.300146309658885, 0.7449196872767061, 16.23417668044567, 68.58552172780037, 61.07896752655506, 45.320555716753006, 46.93756654858589, 46.8192370980978, 54.39645230770111, 45.81191875040531, 36.48762948811054, 43.380512818694115, 50.17406567931175, 25.334101282060146, 0.7573137315921485, 0.06753973560989834, 0.1136780992965214, 0.024694873027328867, 0.12812041182769462, 0.07426525597111322, 0.07222672473290004, 0.10750928617198952, 0.06630639007198624, 0.02230943598988233, 0.0013485174645211373, 0.04746386912302114, 0.03967003460275009, 0.02343472297070548, 0.02418009527900722, 0.18799307174049318, 1.1607562517747283, 50.46202942728996, 68.7618550658226, 46.834136098623276, 41.407388895750046, 51.75809808075428, 49.276914820075035, 58.77485476434231, 68.19605022668839, 55.17073296010494, 62.35582061111927, 54.40234199166298, 73.34652945399284, 23.335072249174118, 0.5554053315427154, 0.7051556522492319, 6.267351871356368, 7.777437390759587, 0.10816659152624197, 1.3388149347156286, 46.94500274956226, 56.17298237979412, 59.41557638347149, 61.00412294268608, 59.15579192340374, 59.10161443054676, 53.0339328199625, 49.9466896802187, 45.903383642435074, 43.935473039746284, 41.89501293003559, 44.057602286338806, 38.78424525260925, 41.15152582526207, 41.463162302970886, 43.51979814469814, 45.083228051662445, 49.708366468548775, 50.42849622666836, 52.37108498811722, 55.01883991062641, 57.55254775285721, 55.62521517276764, 54.13595728576183, 54.5346736907959, 54.97502066195011, 54.47573125362396, 52.98212639987469, 55.42952947318554, 50.336096584796906, 47.571995705366135, 45.59434622526169, 52.98387050628662, 52.19026029109955, 52.04895727336407, 55.34477882087231, 49.856562316417694, 51.95029936730862, 50.47686003148556, 47.362949922680855, 45.929290652275085, 42.92997859418392, 42.08480894565582, 39.89771470427513, 40.5873928964138, 39.155371338129044, 40.055269449949265, 44.08254034817219, 45.25877483189106, 52.89128087460995, 58.892872631549835, 57.025763019919395, 55.12680731713772, 42.43900693953037, 39.1046516597271, 39.81898292899132, 40.41189931333065, 37.879092022776604, 52.90273725986481, 54.333892464637756, 50.95731385052204, 41.73036776483059, 41.28816269338131, 42.150024846196175, 39.59772080183029, 39.97637428343296, 39.752178713679314, 45.98059169948101, 54.749289974570274, 62.98611178994179, 56.309117674827576, 49.50493298470974, 42.68698163330555, 41.71264171600342, 41.54929228127003, 40.10886177420616, 42.03797645866871, 41.56129963696003, 43.24601523578167, 41.889142245054245, 43.73316429555416, 46.95766367018223, 46.85193054378033, 51.31861746311188, 48.82655918598175, 52.544576078653336, 50.56841991841793, 52.40287408232689, 50.383696630597115, 46.600418239831924, 43.62192526459694, 48.890825137495995, 47.91491970419884, 57.298272997140884, 50.287637785077095, 42.176437228918076, 49.62513193488121, 43.51355887949467, 54.86818179488182, 53.18812474608421, 58.19891206920147, 54.0045565366745, 51.264565363526344, 42.35821187496185, 41.182452365756035, 43.573162481188774, 45.32211363315582, 41.448704078793526, 44.13779318332672, 42.699042186141014, 42.236531004309654, 42.992109060287476, 46.770474314689636, 46.873581781983376, 51.04212909936905, 49.665044993162155, 51.93530537188053, 49.25731547176838, 50.543082877993584, 50.63944190740585, 60.043766275048256, 62.81638629734516, 63.53934310376644, 60.486940294504166, 1.9259626348502934, 0.6279104284476489, 6.3606074173003435, 1.051656031049788, 20.101193077862263, 72.46723383665085, 68.46138998866081, 52.92867086827755, 55.230135172605515, 53.58217880129814, 59.02808457612991, 56.397424936294556, 47.973691150546074, 51.128870844841, 58.68601553142071, 34.07955430448055, 0.7517898373771459, 0.08834427979309112, 0.0672961182135623, 0.06246176082640886, 0.06778017661417834, 0.007569281506221159, 0.07086326586431824, 0.1521945247077383, 0.19416126888245344, 0.16629179794108495, 0.11797379847848788, 0.29372735589277, 0.21505572425667197, 0.14501828321954235, 0.09173450685921125, 0.32939348893705755, 1.30440125009045, 60.02685338258743, 77.38022580742836, 60.67490480840206, 51.4172487705946, 60.741313844919205, 53.34507152438164, 59.12340246140957, 76.91655188798904, 63.01394149661064, 69.34620290994644, 57.5520233809948, 79.64938044548035, 28.98090809583664, 0.8502061001490802, 1.7477869894355536, 11.009642276912928, 11.199230253696442, 0.2900520624825731, 1.638167502824217, 52.45544046163559, 57.70919814705849, 63.22414241731167, 63.89207437634468, 61.75765670835972, 63.15063156187534, 56.59118413925171, 51.8952327221632, 48.2608113437891, 46.9297693669796, 43.253960609436035, 47.55324751138687, 43.01351711153984, 44.545442909002304, 43.825624734163284, 46.294215470552444, 48.195223063230515, 53.10821883380413, 52.621373757719994, 56.149480640888214, 58.50019410252571, 60.89212015271187, 57.485443353652954, 57.54684425890446, 55.453775972127914, 56.802088022232056, 55.91037467122078, 55.306214690208435, 58.99923652410507, 53.30552704632282, 50.212998390197754, 48.3717729896307, 55.47627076506615, 57.17836283147335, 56.489915773272514, 57.0373447984457, 52.87821337580681, 54.960839822888374, 54.848111271858215, 49.001281410455704, 48.779460713267326, 45.37721827626228, 46.608754992485046, 42.60262995958328, 42.39268362522125, 40.51449380815029, 41.08558036386967, 45.791624039411545, 48.38234022259712, 56.598931923508644, 63.00639130175114, 60.03431998193264, 57.591974437236786, 44.499043598771095, 40.66292144358158, 38.9280941337347, 39.90567147731781, 39.37660686671734, 53.40545028448105, 58.03156904876232, 52.57654756307602, 45.009610801935196, 39.940234422683716, 42.488822266459465, 39.36896927654743, 41.50548443198204, 40.67095801234245, 44.515268728137016, 56.063506454229355, 65.9846068918705, 57.75708697736263, 51.05339929461479, 44.8182188719511, 44.77931275963783, 43.208701238036156, 43.39406669139862, 45.19249118864536, 43.29776465892792, 45.888515040278435, 43.502676263451576, 47.73607090115547, 52.3090685158968, 50.04938296973705, 53.5838583111763, 51.93609952926636, 58.03710155189037, 52.84726403653622, 55.78157298266888, 52.40378223359585, 49.63718868792057, 46.74678638577461, 52.59800121188164, 48.96898314356804, 59.5946341753006, 51.611182764172554, 38.45193788409233, 49.997907131910324, 43.22781041264534, 57.176831513643265, 53.713777139782906, 60.275166258215904, 58.272852301597595, 54.16424296796322, 45.23931987583637, 42.865564450621605, 46.13271653652191, 47.697134390473366, 44.49548698961735, 46.569780483841896, 44.57558289170265, 42.90917091071606, 46.0518416762352, 49.40013460814953, 51.478474885225296, 52.67420992255211, 54.527921453118324, 53.209460601210594, 52.685586512088776, 50.631082355976105, 55.59077002108097, 61.70625686645508, 69.32076707482338, 62.42422454059124, 68.67409497499466, 9.872587490826845, 1.8457023915834725, 8.288461044430733, 1.2476812186650932, 23.70407994836569, 77.76926413178444, 72.69815504550934, 57.35127255320549, 62.347145676612854, 61.10257565975189, 63.4662464261055, 62.90289245545864, 53.48984755575657, 57.79472395777702, 71.09692856669426, 48.0289401859045, 0.871219685068354, 0.17291925090830773, 0.17461274284869432, 0.1532524562207982, 0.20179704821202904, 0.19669125031214207, 0.13479605986503884], [0.17100397555623204, 0.03515888995025307, 0.07263748862897046, 0.03075234173593344, 0.11077667295467108, 0.11066302045946941, 0.1016443528351374, 0.09910021864925511, 0.3712113731307909, 0.21287575451424345, 23.467369750142097, 67.49030649662018, 38.9351237565279, 37.98200570046902, 31.88247799873352, 39.85244393348694, 34.16298642754555, 61.3147296756506, 60.188633501529694, 62.4453704059124, 49.332053661346436, 58.601606860756874, 42.21362963318825, 1.911296253092587, 0.3670458763372153, 2.7478332398459315, 2.846260783262551, 0.08242170384619385, 0.07724302704446018, 29.673067554831505, 59.83664318919182, 54.6373175829649, 57.04851619899273, 52.05973729491234, 52.35298275947571, 47.87384010851383, 43.2282891869545, 42.585918456315994, 40.51391243934631, 41.21413126587868, 41.28973960876465, 41.01320944726467, 40.07701188325882, 40.63722722232342, 40.22801198065281, 43.3070133626461, 46.13237075507641, 48.629737347364426, 48.661104664206505, 50.42207457125187, 51.453324034810066, 54.005753472447395, 53.26364189386368, 53.81613604724407, 55.164106115698814, 53.83526422083378, 54.10520173609257, 53.15894991159439, 52.032834738492966, 43.94434176385403, 43.05488549172878, 46.207469925284386, 51.03906646370888, 49.65674243867397, 47.83476680517197, 48.17626588046551, 51.3724871724844, 47.90595218539238, 47.2501377761364, 43.26828584074974, 43.39158542454243, 40.75633183121681, 39.18417379260063, 39.73869323730469, 36.43241465091705, 41.52333587408066, 42.6812819391489, 45.27185373008251, 50.080761685967445, 54.35786537826061, 53.20029929280281, 51.9742076843977, 42.47666671872139, 37.10562452673912, 38.52262169122696, 40.19508674740791, 38.50192800164223, 45.921641662716866, 50.752713829278946, 50.6177032738924, 41.641646325588226, 43.95942695438862, 40.1437932997942, 38.916170373559, 41.73305802047253, 42.86584943532944, 44.76080775260925, 49.66887138783932, 59.834169521927834, 55.260662734508514, 50.155735462903976, 41.867491006851196, 39.5737174898386, 39.95468504726887, 41.234391778707504, 38.91247697174549, 39.182718470692635, 40.519745126366615, 39.22132059931755, 39.78446178138256, 44.76601727306843, 46.585093662142754, 48.580602183938026, 49.623232036828995, 48.455326706171036, 48.09172801673412, 48.562036380171776, 47.50547267496586, 42.225340604782104, 44.22134689986706, 45.009785592556, 51.26359261572361, 50.741572827100754, 57.945340275764465, 53.85900154709816, 51.09613560140133, 56.676485762000084, 53.08297298848629, 51.90467141568661, 49.64788131415844, 45.82000471651554, 43.59819933772087, 42.118030562996864, 39.703807309269905, 40.55897042155266, 41.665296256542206, 46.96174465119839, 48.16775053739548, 48.77804718911648, 45.518639087677, 41.06625460088253, 39.463736191391945, 43.4860597550869, 45.90672746300697, 47.90766969323158, 49.06783103942871, 47.175274193286896, 47.35864855349064, 49.90157850086689, 56.18796877563, 55.431368574500084, 67.0776030421257, 30.460501201450825, 5.038819843903184, 0.3610961080994457, 1.1451544077135623, 0.11057196636102162, 39.93443213403225, 66.37467116117477, 53.944371566176414, 50.06200969219208, 49.14547607302666, 53.5932894051075, 55.36186270415783, 43.61332632601261, 32.27034218609333, 25.94200786203146, 56.19461081922054, 18.08865386992693, 1.1977281491272151, 0.02901051742810523, 0.012086768274457427, 0.05684848234523088, 0.0969833017734345, 0.043729181634262204, 0.01747676698869327, 0.12431864161044359, 0.0549833093828056, 0.08823082767776214, 0.03317170419904869, 0.08368512862944044, 0.0641906977398321, 0.06812200983404182, 0.047506668779533356, 0.43777922925073653, 0.11122581330710091, 29.90682151168585, 77.05987259745598, 44.24340471625328, 41.88459008932114, 45.840683206915855, 44.006612822413445, 39.73705552518368, 67.42384046316147, 65.50739049911499, 65.25988698005676, 55.68730764091015, 64.10958230495453, 48.10082092881203, 3.3475474594160914, 0.24391688260948285, 3.5253194952383637, 6.64803396910429, 0.854892258066684, 0.1767583066248335, 35.43565213680267, 61.557046473026276, 57.65325754880905, 59.01586823165417, 54.865286350250244, 54.19907569885254, 49.79951597750187, 47.92997069656849, 44.562602788209915, 43.04231196641922, 44.5663645863533, 44.01106618344784, 44.10235248506069, 43.822512701153755, 44.37655337154865, 41.56402409076691, 46.23323634266853, 48.72307173907757, 50.164095014333725, 49.63898219168186, 52.63113923370838, 51.74268990755081, 57.54390701651573, 56.40211008489132, 56.383977457880974, 57.492776960134506, 54.933450892567635, 55.61142571270466, 53.60745504498482, 53.09921711683273, 46.80570222437382, 45.14095075428486, 49.45555463433266, 55.52238129079342, 52.34798602759838, 50.58304913341999, 53.323572278022766, 54.09161366522312, 51.59756049513817, 50.15625603497028, 44.645499140024185, 45.20643264055252, 43.070107474923134, 39.87151511013508, 41.74261070787907, 38.524023815989494, 41.97314813733101, 44.261852726340294, 47.52719230949879, 53.72125893831253, 57.0474636554718, 56.27472572028637, 55.411662831902504, 43.740619495511055, 37.39494100213051, 36.660816594958305, 40.04940636456013, 37.69456632435322, 48.04546169936657, 53.02580885589123, 53.47706124186516, 41.41267441213131, 41.13384537398815, 41.03830710053444, 38.63425210118294, 40.904675871133804, 40.11480085551739, 42.954076901078224, 50.579519122838974, 60.61226896941662, 56.239110231399536, 52.290278524160385, 42.470617443323135, 42.33064815402031, 42.010549530386925, 40.965320616960526, 40.55780008435249, 42.018962278962135, 43.13132978975773, 41.391729936003685, 42.96836033463478, 48.940245285630226, 49.12486217916012, 51.20944932103157, 52.84456618130207, 50.398660227656364, 51.47070050239563, 51.1690004914999, 50.73331966996193, 44.09043252468109, 44.89156633615494, 47.267020270228386, 52.291718646883965, 52.75293789803982, 59.46038357913494, 53.830708265304565, 51.68150179088116, 56.603210493922234, 55.34170858561993, 55.26589885354042, 51.299527287483215, 48.789431378245354, 44.12955142557621, 42.44948297739029, 42.60821186006069, 42.03551799058914, 44.01307627558708, 50.547517240047455, 53.940598368644714, 51.96710206568241, 50.12938767671585, 43.94629865884781, 42.272898852825165, 45.199482813477516, 48.920847326517105, 51.25441610813141, 51.36649489402771, 50.257205218076706, 49.89571921527386, 53.28224949538708, 59.186479076743126, 59.72852759063244, 71.29741340875626, 45.13262540102005, 5.832211095839739, 0.20145240967394784, 1.700491877272725, 0.2152786060469225, 47.302331775426865, 70.42325511574745, 60.45737408101559, 52.183637246489525, 52.57788509130478, 63.68506148457527, 58.40639993548393, 53.458544835448265, 40.05438029766083, 27.03488241881132, 65.43402403593063, 26.053463481366634, 1.0676606534980237, 0.020438847204786725, 0.08268158169812523, 0.023489951745432336, 0.0667047081515193, 0.054271381959551945, 0.019250232762715314, 0.23381378880003467, 0.14461649931035936, 0.14773441012948751, 0.1313437076169066, 0.18516856158385053, 0.1894681347766891, 0.19746189645957202, 0.12937973253428936, 0.7802625407930464, 0.28558053367305547, 35.6618881970644, 88.61472576856613, 55.46884976327419, 45.75781725347042, 46.00692808628082, 54.74953316152096, 46.14484168589115, 73.82042482495308, 73.66432920098305, 71.77939474582672, 61.37752890586853, 68.68190735578537, 54.539465233683586, 6.095318477600813, 0.7542695011943579, 8.96602738648653, 9.350330214947462, 0.7094827888067812, 0.3021843364695087, 38.2492795586586, 62.95177683234215, 58.237419202923775, 62.2683797031641, 57.28850372135639, 57.89132617413998, 52.623425647616386, 49.93201106786728, 48.246349319815636, 46.11731596291065, 47.98776939511299, 47.402129620313644, 47.30987437069416, 45.248420387506485, 46.823143288493156, 44.15179543197155, 50.29113359749317, 51.130493357777596, 54.32804077863693, 52.54871025681496, 55.422579646110535, 54.08794306218624, 59.30552288889885, 59.1290869563818, 59.76062446832657, 61.095914617180824, 57.94619522988796, 59.59461137652397, 54.87345591187477, 56.74820311367512, 49.02855634689331, 49.065896943211555, 51.07073396444321, 55.84903836250305, 55.550332590937614, 52.99228325486183, 57.40852788090706, 58.36826138198376, 52.76062108576298, 52.9890838265419, 46.94788679480553, 46.138397231698036, 45.53496301174164, 42.70502306520939, 42.89894185960293, 40.43289318680763, 45.96424497663975, 46.61806829273701, 50.364051684737206, 55.41030250489712, 58.6407295614481, 58.247762247920036, 58.358997479081154, 46.866464763879776, 36.50439038872719, 36.459480598568916, 39.230797290802, 37.9809645563364, 50.26042744517326, 58.16034033894539, 57.483129277825356, 42.173264399170876, 41.10861852765083, 39.28077220916748, 39.299015030264854, 41.37460045516491, 41.82991862297058, 44.12681557238102, 49.83211822807789, 61.95319041609764, 57.22294203937054, 57.25831054151058, 44.91967722773552, 42.57059767842293, 45.31398206949234, 45.077490359544754, 43.43001276254654, 44.60882730782032, 44.36679169535637, 42.995787262916565, 43.08644279837608, 52.32251599431038, 51.10696122050285, 53.32365967333317, 54.81810808181763, 55.15362247824669, 53.43427553772926, 54.8638766258955, 53.803258538246155, 47.749176397919655, 47.04470939934254, 49.95183080434799, 54.006851613521576, 55.37946715950966, 59.74104031920433, 58.31292875111103, 53.692612275481224, 60.86597375571728, 57.256486639380455, 57.65617959201336, 53.50168012082577, 53.01243357360363, 45.276873260736465, 46.19738906621933, 43.67191158235073, 45.35376973450184, 45.949794352054596, 53.24390575289726, 55.93302525579929, 54.55848701298237, 52.17531569302082, 47.44776137173176, 43.25231149792671, 49.323101341724396, 49.41078923642635, 55.887887477874756, 53.376951813697815, 54.92224909365177, 50.242522805929184, 59.11623604595661, 58.46134878695011, 66.26634657382965, 68.52499097585678, 59.52716879546642, 6.766316397115588, 0.8875275193713605, 4.513609651476145, 0.2668334380723536, 53.56509491801262, 74.46360871195793, 66.71683520078659, 63.39982219040394, 60.18316179513931, 69.74246844649315, 63.30733135342598, 59.54659715294838, 40.675795152783394, 37.60419577360153, 75.66214799880981, 37.10506595671177, 1.4244901249185205, 0.17973483831156045, 0.20322157099144533, 0.15582376043312252, 0.20803566032554954, 0.12324854629696347, 0.08835274027660489], [0.013731832295889035, 0.1674658607225865, 0.07899801334133372, 0.08139550656778738, 0.16366688098059967, 0.10952379408990964, 0.1527950557647273, 0.08817935973638669, 0.5792185349855572, 0.27260235976427794, 9.738211501389742, 70.54842039942741, 43.39391089975834, 29.85293660312891, 19.147499352693558, 43.84156107902527, 41.484555155038834, 54.82240945100784, 62.553003430366516, 59.91616152226925, 56.208917051553726, 54.05605897307396, 58.68431322276592, 20.6923995539546, 0.33800189732573926, 5.402684519067407, 6.949999965727329, 0.391598169808276, 0.12026618875097483, 16.055462770164013, 60.256361067295074, 56.92188419401646, 56.76470182836056, 55.2383579313755, 49.95482124388218, 47.51526854932308, 44.79304902255535, 41.22051492333412, 42.362980619072914, 41.26199349761009, 41.56533122062683, 40.09683541953564, 41.799326464533806, 40.50896890461445, 38.5081634670496, 41.4696941524744, 44.93711069226265, 42.54174202680588, 44.581468775868416, 45.58885172009468, 46.29119083285332, 48.01610827445984, 48.47260817885399, 51.50561682879925, 51.967079266905785, 56.062195524573326, 53.51155959069729, 57.59831249713898, 51.102667450904846, 43.864557445049286, 42.81515635550022, 46.000274643301964, 52.44056425988674, 49.85062703490257, 50.71336694061756, 46.92804045975208, 48.81688490509987, 47.420421838760376, 44.99565415084362, 43.804805651307106, 43.10221575200558, 41.58196672797203, 39.85134959220886, 38.429671078920364, 41.52536116540432, 40.90172342956066, 46.3519761711359, 48.03194582462311, 49.77589264512062, 53.52293998003006, 53.80374111235142, 56.889031156897545, 46.2427282333374, 38.046051263809204, 40.213508158922195, 42.14562468230724, 38.84590454399586, 42.03259214758873, 53.127886578440666, 47.65877164900303, 40.522583574056625, 41.66018173098564, 39.96053673326969, 36.67914681136608, 39.78470116853714, 37.70280048251152, 39.58504468202591, 49.09830540418625, 56.019679605960846, 57.0634987950325, 54.53474208712578, 43.91471095383167, 40.160265415906906, 39.59093056619167, 40.57536654174328, 39.80722635984421, 39.7328719496727, 42.415117621421814, 40.83542078733444, 39.17621321976185, 42.57628217339516, 47.87775009870529, 48.43309409916401, 49.08538609743118, 49.48977179825306, 49.31947633624077, 49.009051993489265, 47.11258515715599, 39.61923144757748, 45.04049554467201, 45.27821458876133, 49.69074301421642, 52.73764371871948, 53.42697232961655, 51.51923529803753, 53.24903927743435, 53.6070104688406, 50.322812497615814, 49.774190336465836, 46.37772358953953, 43.9124196767807, 43.014318868517876, 37.22464554011822, 40.29521897435188, 38.180647641420364, 48.00112187862396, 56.720692589879036, 55.27069799602032, 54.290475994348526, 51.529908925294876, 50.327759832143784, 46.672055795788765, 42.12312988936901, 40.55572159588337, 42.33897350728512, 46.36339455842972, 46.58641219139099, 51.71397864818573, 54.07430939376354, 57.94280581176281, 57.32967831194401, 61.10976107418537, 34.07241828739643, 3.3533117501065135, 0.3049733868101612, 0.5564785958267748, 4.547899961471558, 58.86940509080887, 58.93530875444412, 55.72315491735935, 44.26446698606014, 51.848749816417694, 57.4549575895071, 58.59592616558075, 41.002972796559334, 39.306698217988014, 41.270132660865784, 50.85332863032818, 16.342391073703766, 0.7558479008730501, 0.12970341282198206, 0.3181055118329823, 0.07110050821211189, 0.12519992713350803, 0.06724560022121295, 0.08776521906838752, 0.012291604743950302, 0.10245430312352255, 0.11545493442099541, 0.067057911073789, 0.21664645842975006, 0.16786762978881598, 0.23977874137926847, 0.10529309962294064, 0.6936246366240084, 0.27813323016744107, 12.42334121838212, 78.17259728908539, 48.17012161016464, 32.144428342580795, 29.40568920224905, 53.97115632891655, 44.511476531624794, 58.40670391917229, 69.30312842130661, 65.60991659760475, 61.326098665595055, 59.77228984236717, 65.11167213320732, 22.039322778582573, 0.21549207740463316, 2.13761187158525, 9.953348357230425, 2.5914129707962275, 0.1606013806303963, 20.69708850234747, 60.55250197649002, 60.39886102080345, 59.82315771281719, 57.77271553874016, 51.85500808060169, 49.97051440179348, 47.05449387431145, 45.04688300192356, 43.13349947333336, 44.2895570397377, 42.58308760821819, 42.25916638970375, 42.84984089434147, 42.45208963751793, 40.73470339179039, 45.16444869339466, 47.09951005876064, 46.6807459294796, 46.43874071538448, 48.286034390330315, 50.055918619036674, 51.63193725049496, 51.67354501783848, 52.93290004134178, 53.81417155265808, 56.210159584879875, 55.446214377880096, 58.595048412680626, 53.036816865205765, 45.237537771463394, 45.367221012711525, 47.269634529948235, 53.682793602347374, 52.8410741686821, 53.24717737734318, 49.53606851398945, 52.490200996398926, 49.73978318274021, 47.540389001369476, 45.92372015118599, 45.46551413834095, 42.004333063960075, 42.84176632761955, 40.716692358255386, 43.41906175017357, 41.25481568276882, 47.13331684470177, 51.82666540145874, 51.26136973500252, 56.10236316919327, 57.403971925377846, 58.33083339035511, 47.86588713526726, 36.31107196211815, 38.017659187316895, 41.438551023602486, 39.53777901828289, 42.60964438319206, 54.942266419529915, 50.45675531029701, 39.304957911372185, 40.69964647293091, 39.10341292619705, 39.208591282367706, 39.938262328505516, 35.565635561943054, 39.553236588835716, 49.14447672665119, 58.08967933058739, 57.99271233379841, 56.41794003546238, 44.13634926080704, 40.306591764092445, 41.63291059434414, 41.438798010349274, 40.94173528254032, 41.860921159386635, 43.51746886968613, 42.792220786213875, 40.292733907699585, 43.595725670456886, 50.700979605317116, 51.873539686203, 50.83386987447739, 52.10571102797985, 52.596542090177536, 51.481279134750366, 48.042353466153145, 41.30040183663368, 46.67190380394459, 48.85965161025524, 50.35903975367546, 56.368782073259354, 53.57174836099148, 53.60565774142742, 54.67080518603325, 55.09709291160107, 53.34312982857227, 52.24984489381313, 47.07817040383816, 46.02716960012913, 44.812253192067146, 41.30474880337715, 41.84697970747948, 41.802377700805664, 50.418202579021454, 58.79449971020222, 58.25339734554291, 58.28145503997803, 54.82879690825939, 55.235101506114006, 48.63557003438473, 45.857911482453346, 43.318180963397026, 45.41282616555691, 48.48101332783699, 51.513710394501686, 52.839200869202614, 56.86025530099869, 57.941840663552284, 62.56011664867401, 58.744710981845856, 43.38566154241562, 8.281783852726221, 0.3669855248881504, 0.6901669409126043, 8.687512781471014, 63.11339356005192, 64.9511231482029, 61.27384006977081, 48.21428284049034, 51.7943025380373, 65.4982253909111, 59.40625548362732, 56.087878346443176, 31.651927269995213, 35.45909307897091, 66.58276319503784, 20.75364276766777, 0.7466033531818539, 0.09925433303578757, 0.15907159162452444, 0.032639584314893, 0.11485377995995805, 0.05220554710831493, 0.053499845234910026, 0.16395029233535752, 0.3147209918824956, 0.23987404798390344, 0.16663928632624447, 0.3395789908245206, 0.32298569683916867, 0.44722858001478016, 0.23642456042580307, 0.920347961364314, 0.46541642281226814, 15.331550315022469, 90.38011863827705, 59.402246698737144, 35.6489422917366, 32.5967712700367, 63.14763352274895, 49.358952417969704, 64.1599752008915, 74.34991121292114, 71.72840148210526, 67.0210924744606, 65.3879477083683, 71.4000079035759, 26.94343652576208, 0.3744284942513332, 15.877434723079205, 18.444968350231647, 1.671348747331649, 0.2339835773454979, 25.010590441524982, 62.00104884803295, 62.0096629858017, 62.9764299094677, 61.68255373835564, 53.96345794200897, 51.67214669287205, 50.007889196276665, 47.17997454106808, 47.66616225242615, 47.87530682981014, 45.7537666708231, 43.894560635089874, 46.334117129445076, 45.6499258428812, 44.24678273499012, 47.271804213523865, 50.964708253741264, 47.618455812335014, 49.32281255722046, 49.59552772343159, 53.87556865811348, 54.350208789110184, 54.132708460092545, 55.48515848815441, 55.82735292613506, 60.194234400987625, 58.52206192910671, 61.61642588675022, 55.261924266815186, 47.84009791910648, 49.24938149750233, 49.06509518623352, 55.62117598950863, 57.552973330020905, 56.020177379250526, 52.898200303316116, 55.7654732465744, 50.88355980813503, 49.17519807815552, 48.6794500797987, 48.26943688094616, 45.18353506922722, 45.481906458735466, 43.556648567318916, 46.11988082528114, 44.80105899274349, 50.92695727944374, 52.47168838977814, 54.92030739784241, 57.06357479095459, 60.71466967463493, 60.98560653626919, 50.027887523174286, 38.358257710933685, 38.67851972579956, 41.580230221152306, 39.92657795548439, 43.59421335160732, 57.963176518678665, 52.18985751271248, 39.43738840520382, 40.63029259443283, 38.68242211639881, 36.62890210747719, 40.45339688658714, 36.74770653247833, 38.90811860561371, 50.4517737776041, 61.33596673607826, 61.39925613999367, 59.80705417692661, 48.298288732767105, 44.35739479959011, 43.91709342598915, 43.87650400400162, 42.67998240888119, 45.07636561989784, 45.7169808447361, 44.92887653410435, 44.37010511755943, 48.75059746205807, 55.389874801039696, 55.359225645661354, 55.24842359125614, 56.730914041399956, 56.600037664175034, 55.2619356662035, 53.89212056994438, 44.240870252251625, 49.0137143433094, 49.228311628103256, 52.736222594976425, 58.312993347644806, 56.739163398742676, 55.545822232961655, 54.46764528751373, 60.41040480136871, 54.20942634344101, 55.518672689795494, 50.347818955779076, 50.21342396736145, 47.54012681543827, 42.0643812417984, 43.46229963004589, 43.431654274463654, 52.089618891477585, 63.551050275564194, 59.88221414387226, 61.45574390888214, 56.387944445014, 57.329666912555695, 51.16414055228233, 48.795974627137184, 45.093251913785934, 48.126879930496216, 50.46383433043957, 56.242822632193565, 57.441308721899986, 60.23904159665108, 60.217815935611725, 68.3931152522564, 60.25908552110195, 53.875960037112236, 11.353913303464651, 0.733101787045598, 1.274583893828094, 7.501541320234537, 73.33215102553368, 67.26860359311104, 70.56269243359566, 53.61702673137188, 58.72893802821636, 70.09980887174606, 70.20290493965149, 57.77119942009449, 51.648914739489555, 59.062290340662, 74.40756931900978, 28.739265762269497, 1.3453936879523098, 0.2522475051227957, 0.3539381828159094, 0.16406073875259608, 0.2867627749219537, 0.16599732858594507, 0.12471726397052407], [0.06523881063912995, 0.0713780194928404, 0.07624489036970772, 0.050024976226268336, 0.013342630572878988, 0.06198276758368593, 0.08805459729046561, 0.15010209870524704, 0.29881151276640594, 0.2155084046535194, 2.444608798250556, 57.74992436170578, 48.19749914109707, 46.2126300483942, 36.10674552619457, 44.33535598218441, 48.808202371001244, 50.784054547548294, 64.18731853365898, 54.70444098114967, 61.933917850255966, 51.9529440253973, 52.229401990771294, 45.293003395199776, 0.7758923596702516, 3.0555706517770886, 5.122008305042982, 2.9964952217414975, 0.12170174726634286, 9.890358187258244, 61.64657726883888, 59.52743858098984, 55.232004672288895, 53.926535323262215, 50.60234449803829, 44.30478662252426, 44.06452551484108, 43.8813753426075, 46.46890349686146, 48.201644718647, 49.320297092199326, 43.93476627767086, 45.965932086110115, 41.810429468750954, 42.53212094306946, 43.103165701031685, 42.547228932380676, 40.73620431125164, 41.387493163347244, 42.270884960889816, 43.41152295470238, 43.00055220723152, 45.88088884949684, 49.51449707150459, 52.49591588973999, 55.1696652173996, 52.924266904592514, 52.933006435632706, 50.0826121866703, 44.980489164590836, 44.457367435097694, 44.04993809759617, 51.102101281285286, 52.76830047369003, 51.347830295562744, 49.29547682404518, 48.87808822095394, 47.85801015794277, 46.20978020131588, 42.510758489370346, 42.186221703886986, 38.69727551937103, 41.70838974416256, 41.92307822406292, 40.808487832546234, 42.86301478743553, 49.08367998898029, 50.71358732879162, 51.79651401937008, 50.602519288659096, 58.960881382226944, 54.05825525522232, 49.6967238932848, 38.98544445633888, 39.16103683412075, 39.450436905026436, 39.20567683875561, 40.482974499464035, 51.1215790361166, 44.60033856332302, 40.3141875565052, 40.68308316171169, 42.39835672080517, 40.13438880443573, 37.93507061898708, 40.764771178364754, 41.16809293627739, 52.29297637939453, 56.952753737568855, 55.97444303333759, 56.94217510521412, 49.182999059557915, 41.20553992688656, 38.37083883583546, 37.83648490905762, 37.6738004386425, 40.08543983101845, 39.863486140966415, 41.18007369339466, 41.40795886516571, 40.218755677342415, 46.07476584613323, 49.64862987399101, 47.507706955075264, 47.7775114774704, 50.18636181950569, 48.46316568553448, 44.628939628601074, 41.6264433413744, 43.721179738640785, 46.906913593411446, 48.69553841650486, 53.732308745384216, 57.92406901717186, 55.56714288890362, 54.45556193590164, 54.91400733590126, 49.190914034843445, 50.69118373095989, 44.02633756399155, 42.73317575454712, 40.336621552705765, 39.483810514211655, 40.19976809620857, 42.60734550654888, 53.793466463685036, 54.48689505457878, 53.70274633169174, 54.87472124397755, 54.0365394204855, 55.5922519415617, 55.23244924843311, 51.36256970465183, 46.66867017745972, 42.65305705368519, 44.87482063472271, 44.793987572193146, 51.0153329372406, 59.007702469825745, 60.96224918961525, 60.4174268245697, 53.892861530184746, 18.98050021380186, 2.1825534850358963, 0.9597536874935031, 0.6304004823323339, 15.658525619655848, 63.14139425754547, 56.49217285215855, 60.20857863128185, 60.83236835896969, 60.65820850431919, 60.86071103811264, 56.584424301981926, 33.091367930173874, 37.296708673238754, 34.1615729033947, 51.509500220417976, 13.984132166951895, 0.9276935015805066, 0.06646423746133223, 0.13252167409518734, 0.029796242160955444, 0.07259165358846076, 0.0593049651797628, 0.06706240848870948, 0.04295468745112885, 0.04085138156369794, 0.05625788493489381, 0.01947533728525741, 0.05558595927141141, 0.032249656214844435, 0.12643508351175115, 0.14091726421611384, 0.48130069859325886, 0.07150380610255525, 5.354062803089619, 68.94369050860405, 51.98511689901352, 40.516777485609055, 35.478890016674995, 57.565930634737015, 49.050211384892464, 59.10379931330681, 69.80246722698212, 60.469377636909485, 66.00697249174118, 56.62745699286461, 58.19884367287159, 51.92994385957718, 0.7598933775443584, 1.0427670017816126, 8.753014616668224, 5.885681351646781, 0.16673061501933262, 13.087520878762007, 63.431865870952606, 60.652132630348206, 58.83918531239033, 55.212591513991356, 52.47206836938858, 46.7944548279047, 46.79091341793537, 45.62722206115723, 49.90730099380016, 50.81065692007542, 51.58310607075691, 48.165903836488724, 48.637599125504494, 44.49637234210968, 44.93429884314537, 44.655078426003456, 43.81041035056114, 44.3090233951807, 44.789655804634094, 43.67271713912487, 45.31877361238003, 46.95298232138157, 49.78980369865894, 50.87069369852543, 53.13663750886917, 57.65596300363541, 54.770952612161636, 53.77557322382927, 52.08215609192848, 46.38446822762489, 45.70931665599346, 44.14428323507309, 56.189279705286026, 55.151012018322945, 54.6304589509964, 51.31060749292374, 52.15155556797981, 50.04785545170307, 50.19755221903324, 44.99716266989708, 43.96030090749264, 40.67540377378464, 44.24964398145676, 44.94585782289505, 43.24557825922966, 44.34956721961498, 48.553494438529015, 51.78928680717945, 54.008652716875076, 51.726973950862885, 58.793184980750084, 56.676675751805305, 51.49211995303631, 38.989939615130424, 39.967931136488914, 41.53384231030941, 37.69259802997112, 40.63609108328819, 54.15123626589775, 45.44106625020504, 40.07130078971386, 40.50784416496754, 41.613201051950455, 39.811485931277275, 36.83572120964527, 40.57302966713905, 41.34558521211147, 55.09996555745602, 60.91750279068947, 57.108195796608925, 58.620446249842644, 49.92934361100197, 42.76699014008045, 42.353762313723564, 40.15601724386215, 40.13602651655674, 42.75249771773815, 42.56612151861191, 42.02199451625347, 43.96317355334759, 42.61223964393139, 47.69801214337349, 52.02607870101929, 50.58127082884312, 52.01904907822609, 53.66362363100052, 50.10940834879875, 46.62557668983936, 43.27610582113266, 46.863694712519646, 49.40420038998127, 50.80260135233402, 56.36468209326267, 57.647892236709595, 58.58761601150036, 56.823002099990845, 56.49803973734379, 53.954319432377815, 50.95738984644413, 44.91698697209358, 46.00701168179512, 41.475321650505066, 40.8190056681633, 41.71114079654217, 45.86111091077328, 54.960642233490944, 58.08890797197819, 55.634798258543015, 58.68491359055042, 57.360863238573074, 58.62747207283974, 56.41628332436085, 54.454270005226135, 48.60453709959984, 46.76034785807133, 47.05094866454601, 46.702617555856705, 52.71839775145054, 63.19069281220436, 62.84075438976288, 63.38034823536873, 53.73307630419731, 25.287321992218494, 0.9960591956041753, 1.6347047011367977, 0.2255389906349592, 19.127474427223206, 68.3375546336174, 62.442835941910744, 64.3941642343998, 64.9127984046936, 63.6897998303175, 68.66953521966934, 60.84516987204552, 45.54518826305866, 38.142908066511154, 37.169487699866295, 62.43803679943085, 18.562820926308632, 0.9205821831710637, 0.1307885514688678, 0.17357622971758246, 0.052627676996053196, 0.018573622292024083, 0.09050003325683065, 0.025868022967188153, 0.17217314016306773, 0.1356793788727373, 0.11990651430096477, 0.09368946484755725, 0.14549920975696295, 0.22007996012689546, 0.16248167114099488, 0.3127532615326345, 0.6414133007638156, 0.30752515769563615, 6.624944508075714, 83.93587723374367, 62.78271250426769, 58.09225559234619, 48.01004379987717, 64.21868965029716, 55.33606968820095, 64.56979840993881, 72.18836680054665, 65.5012196302414, 72.64585465192795, 63.0547247081995, 63.73236134648323, 56.82904377579689, 1.3753839349374175, 6.394471200183034, 17.70324245095253, 6.147681567817926, 0.23575610801344737, 18.667174726724625, 64.71216157078743, 64.25890669226646, 60.96117004752159, 60.840374529361725, 56.35064944624901, 49.03750106692314, 48.28945800662041, 49.01497207581997, 53.56615886092186, 54.3856380879879, 55.87217152118683, 50.589801371097565, 51.94404110312462, 47.582209557294846, 49.059790670871735, 49.30908389389515, 47.34615862369537, 45.23520089685917, 46.979364305734634, 46.17182023823261, 48.89250464737415, 48.81069503724575, 52.547087743878365, 52.341507375240326, 57.5177226215601, 60.45222915709019, 57.88297802209854, 56.44616112112999, 54.75202962756157, 48.48368838429451, 50.71313515305519, 48.192787393927574, 58.234204575419426, 59.15323086082935, 58.24890598654747, 54.549093917012215, 56.49197906255722, 54.31633360683918, 51.28444589674473, 45.845493748784065, 46.773871332407, 43.158433735370636, 46.99807070195675, 47.7024807035923, 45.32332956790924, 47.98635967075825, 53.19457679986954, 56.08016476035118, 57.04126998782158, 54.071995317935944, 62.71912291646004, 60.22001601755619, 51.715338975191116, 38.7023900449276, 40.47306843101978, 40.97769655287266, 38.213249891996384, 41.647794395685196, 55.77040538191795, 48.32116350531578, 39.31145936250687, 39.37172032892704, 41.995175555348396, 39.40277986228466, 36.29878722131252, 41.314244493842125, 40.45189216732979, 57.02309936285019, 63.026773408055305, 61.26575030386448, 62.550069987773895, 53.91274966299534, 46.909622848033905, 43.01874563097954, 42.80681200325489, 41.8903885781765, 43.35432082414627, 43.36786329746246, 44.663008600473404, 45.73869667947292, 44.44298140704632, 51.718485206365585, 53.27779233455658, 52.95062229037285, 54.00992564857006, 55.6743161380291, 53.91373760998249, 48.81375387310982, 46.1858756840229, 48.39134953916073, 52.37285189330578, 52.563442066311836, 58.80785219371319, 59.06221814453602, 59.630219265818596, 59.6770403534174, 60.38121096789837, 54.380318373441696, 55.37280231714249, 48.58971789479256, 48.2459731400013, 43.36150623857975, 43.60470838844776, 44.420623406767845, 47.69865810871124, 58.930817395448685, 60.17439566552639, 58.246105536818504, 60.6553852558136, 58.849551156163216, 61.34552322328091, 59.579488188028336, 57.53476470708847, 51.42305105924606, 48.8775410503149, 49.17737156152725, 50.66216088831425, 54.01186354458332, 67.16931492090225, 68.30524116754532, 66.57930538058281, 58.721205443143845, 37.4778563529253, 3.5479582054540515, 1.5702755958773196, 1.6070984699763358, 22.556459829211235, 75.955750644207, 68.45059856772423, 72.34424203634262, 70.7015597820282, 73.95681470632553, 72.70989641547203, 70.41824698448181, 47.36688271164894, 47.86519557237625, 46.75650246441364, 74.64570254087448, 26.465471573174, 1.3447388168424368, 0.21459214913193136, 0.3218259278219193, 0.13207337236963212, 0.16642808594042435, 0.32543980109039694, 0.13140509807271883], [0.034889160087914206, 0.024770701966190245, 0.09185983333736658, 0.042134373070439324, 0.030563624713977333, 0.05859576143848244, 0.11312295056995936, 0.07123945310013369, 0.10830113547854125, 0.23943413252709433, 1.0305007849819958, 44.76697862148285, 57.24424369633198, 38.45760338008404, 26.49624042212963, 33.00374463200569, 55.191084668040276, 49.18911673128605, 64.96757626533508, 58.52941453456879, 58.148108795285225, 57.789373844861984, 51.68675310909748, 46.49764135479927, 8.06554600596428, 1.0830055363476276, 7.198323290795088, 3.819424663670361, 0.07260689730173908, 4.076145300641656, 48.91769729554653, 59.383312314748764, 59.296669363975525, 51.0346283018589, 50.027860924601555, 50.78000396490097, 54.321018755435944, 53.31463895738125, 56.432231068611145, 51.77169755101204, 54.20056901872158, 52.539868131279945, 55.39816215634346, 53.79175275564194, 49.28135298192501, 44.566102400422096, 42.62996569275856, 38.72216038405895, 40.05059950053692, 39.626116678118706, 40.91020077466965, 43.95682409405708, 45.32271400094032, 49.145688861608505, 53.133141696453094, 56.48509383201599, 55.78182756900787, 54.383096024394035, 49.27901230752468, 43.24693098664284, 44.502258226275444, 39.315753132104874, 50.60284227132797, 50.65852448344231, 53.06018941104412, 49.928104877471924, 50.543048679828644, 49.27521251142025, 46.16333529353142, 42.80833192169666, 42.35973559319973, 41.00445091724396, 38.60606141388416, 39.76394668221474, 42.84116975963116, 48.05319048464298, 52.199740782380104, 50.32536596059799, 51.54215946793556, 53.902114033699036, 54.3111202865839, 53.04315112531185, 51.43642634153366, 41.01355142891407, 41.08516238629818, 39.44192536175251, 38.094175681471825, 39.77936625480652, 48.45218427479267, 43.48772406578064, 40.19938811659813, 41.81036487221718, 41.33287109434605, 44.25761595368385, 39.360636323690414, 37.88346938788891, 41.29834994673729, 57.41557650268078, 54.04645688831806, 54.894905760884285, 51.123342141509056, 52.08043098449707, 48.91456626355648, 40.56853450834751, 41.095045655965805, 39.1000235080719, 36.97467215359211, 39.319784715771675, 39.65537890791893, 43.19043181836605, 46.47620290517807, 46.60223834216595, 47.3130813986063, 49.465293511748314, 48.29402916133404, 48.604464903473854, 47.9147145152092, 42.08896592259407, 41.60479590296745, 46.277750954031944, 45.588460341095924, 49.10525143146515, 50.60925252735615, 53.11952322721481, 52.665288001298904, 51.84512101113796, 51.17629610002041, 51.919057443737984, 48.477768301963806, 46.13283433020115, 42.40580052137375, 41.48926690220833, 41.326240450143814, 40.62056131660938, 42.29275278747082, 50.6864719837904, 53.81772056221962, 56.43345080316067, 54.37415890395641, 57.01265372335911, 55.10635681450367, 56.91890515387058, 54.299933686852455, 56.14899426698685, 47.10163414478302, 44.1426607221365, 41.756783947348595, 53.66870015859604, 57.491222843527794, 64.37299937009811, 51.30162097513676, 48.69662895798683, 10.05116555839777, 0.7778154127299786, 0.6891782814636827, 0.17068265529815108, 39.50967192649841, 62.11640305817127, 53.923601880669594, 59.79076065123081, 55.67956745624542, 57.88529209792614, 59.72178675234318, 50.31204767525196, 33.328953981399536, 45.928184911608696, 45.962861850857735, 46.55531845986843, 8.54264935478568, 0.6174075545277447, 0.2605678414693102, 0.08833295461954549, 0.13266982161439955, 0.06110860296757892, 0.11050857210648246, 0.05087744786578696, 0.02763182968919864, 0.018501626545912586, 0.028993253217777237, 0.04018606472527608, 0.04895042431598995, 0.09022712329169735, 0.06895913014886901, 0.030709812963323202, 0.17766532982932404, 0.21053079050034285, 1.7954122088849545, 55.03191880881786, 61.5981450676918, 44.576973617076874, 36.67510382831097, 43.739642947912216, 56.446533501148224, 54.37934182584286, 70.55342853069305, 64.18851166963577, 64.88749176263809, 62.35745832324028, 55.757345482707024, 53.79152476787567, 9.857223015278578, 1.052697531413287, 4.891933975741267, 8.61913450062275, 0.0714732964115683, 6.615714803338051, 52.607637494802475, 60.071121007204056, 61.68892219662666, 53.0534827709198, 54.84512463212013, 51.188786029815674, 54.53644439578056, 54.93992954492569, 59.79291133582592, 54.03104491531849, 56.96978062391281, 54.58507038652897, 58.95403414964676, 56.365822032094, 51.16263963282108, 45.89092791080475, 45.07781334221363, 41.81905120611191, 42.991387099027634, 42.46031619608402, 42.26650379598141, 45.61882831156254, 48.81277732551098, 52.63761028647423, 53.24154607951641, 56.845504492521286, 56.74385614693165, 56.41813762485981, 52.4076884239912, 46.32906340062618, 46.93867228925228, 40.70103719830513, 53.47673445940018, 52.80850991606712, 54.85970064997673, 53.50667305290699, 54.09855209290981, 51.063324362039566, 49.64953042566776, 44.202085733413696, 44.60384577512741, 43.112425804138184, 42.39968664944172, 41.6538854688406, 44.346945360302925, 49.880060255527496, 55.0529620796442, 52.25816644728184, 53.085078075528145, 53.64689692854881, 55.83477392792702, 55.898279920220375, 52.96028517186642, 40.88195689022541, 40.64397946000099, 39.9858395755291, 36.65022276341915, 40.136623084545135, 51.005423069000244, 45.966961830854416, 39.99978482723236, 40.7995431125164, 40.98083518445492, 43.85145574808121, 38.871507570147514, 37.6104312390089, 40.31708300113678, 56.69806480407715, 58.909071162343025, 56.48581579327583, 54.83855098485947, 55.35956382751465, 48.9162115752697, 42.73823708295822, 42.93768838047981, 39.961338490247726, 39.998758882284164, 41.84872381389141, 41.86118334531784, 44.97640058398247, 48.158384039998055, 47.959593906998634, 49.44934196770191, 50.69361940026283, 50.027165561914444, 51.22906006872654, 49.5331084728241, 44.49014827609062, 44.028754234313965, 47.26944833993912, 46.61484606564045, 50.90399131178856, 52.56278470158577, 55.283096730709076, 55.47356151044369, 55.992590859532356, 52.490466982126236, 55.72684831917286, 52.17299021780491, 47.68506623804569, 46.85968592762947, 44.170726016163826, 42.06971235573292, 41.591971591115, 45.59170916676521, 52.02701725065708, 57.71333232522011, 59.30733919143677, 56.04187421500683, 58.492146134376526, 57.78796412050724, 59.236548990011215, 57.43475027382374, 60.464867278933525, 48.908463791012764, 47.41530731320381, 43.6492457985878, 57.406346797943115, 57.90234558284283, 67.0892608165741, 49.23611260950565, 49.32117484509945, 12.462256830185652, 0.6795032287482172, 0.9991828654892743, 0.11725247546564788, 40.69134011864662, 68.49270790815353, 61.02982856333256, 66.92300453782082, 62.745352908968925, 65.75303971767426, 67.25182369351387, 56.63074381649494, 43.65123689174652, 48.65047663450241, 54.23311807215214, 54.781421050429344, 11.98670569807291, 0.7381173991598189, 0.22030769556295127, 0.1984058934613131, 0.08484152829623781, 0.04221066214086022, 0.06819025031290948, 0.07136253087082878, 0.1182124212209601, 0.11479161024908535, 0.14637817977927625, 0.24484719440806657, 0.17679588898317888, 0.18023805896518752, 0.22888392442837358, 0.23346214438788593, 0.20577282237354666, 0.2590555226197466, 2.1205184888094664, 63.963183760643005, 74.83181655406952, 52.30438716709614, 34.34975020587444, 49.503059685230255, 63.856173902750015, 61.4945550262928, 76.07226759195328, 70.8948402106762, 69.1395851969719, 69.77121010422707, 60.60254909098148, 58.835385516285896, 10.378460995852947, 1.931209797039628, 22.701562643051147, 10.648802239447832, 0.14134334604023024, 11.17674021050334, 57.27852925658226, 61.98585346341133, 66.03432342410088, 56.23292036354542, 58.04165370762348, 54.30179178714752, 57.59525366127491, 57.67844259738922, 65.2446573972702, 56.97381220757961, 59.64719295501709, 56.317477226257324, 62.045738250017166, 58.553174659609795, 54.65848244726658, 48.82173724472523, 47.1686739474535, 44.230177626013756, 45.880368277430534, 43.83293554186821, 43.636774867773056, 50.005248337984085, 49.562169313430786, 53.72608847916126, 55.638305470347404, 60.36376230418682, 60.05515806376934, 60.41463777422905, 54.33388486504555, 47.47511990368366, 50.00935211777687, 41.60319618880749, 57.215566635131836, 55.47098904848099, 59.184438586235046, 55.25715932250023, 56.207697317004204, 54.31819170713425, 49.82949636876583, 46.36670038104057, 48.381321877241135, 45.938877537846565, 44.54004339873791, 43.146642968058586, 46.08344458043575, 51.76994204521179, 58.871555775403976, 55.17079755663872, 57.49184601008892, 57.35480256378651, 59.80943284928799, 57.86267191171646, 55.71096517145634, 43.68485368788242, 41.3809385150671, 39.585607051849365, 37.71763488650322, 40.96403248608112, 54.298105984926224, 45.24738684296608, 39.93818253278732, 40.40005914866924, 40.293642058968544, 42.70469628274441, 38.91930140554905, 37.84121185541153, 40.10530136525631, 60.80978997051716, 60.94727419316769, 58.767536357045174, 55.756163746118546, 56.3298075646162, 53.59993904829025, 46.35896399617195, 46.46708719432354, 43.30909565091133, 41.50695115327835, 43.83621856570244, 43.16044382750988, 46.81632645428181, 51.50531284511089, 51.02569118142128, 52.04690918326378, 52.859826162457466, 50.95235511660576, 54.03178207576275, 52.75397144258022, 46.81292563676834, 44.476491808891296, 51.38047814369202, 50.134262815117836, 53.947449401021004, 53.92879620194435, 57.36709490418434, 56.82154297828674, 56.49817653000355, 52.65431419014931, 57.343961745500565, 54.09865468740463, 51.50535084307194, 46.95212736725807, 46.89625896513462, 44.71021346747875, 43.5085279494524, 48.63403491675854, 55.95016233623028, 59.80238422751427, 63.18562388420105, 59.251007214188576, 61.738984510302544, 60.479093715548515, 62.982919961214066, 61.02220617234707, 64.2799423635006, 50.90717934072018, 48.7198381125927, 46.195017993450165, 60.720768347382545, 61.46057724952698, 70.86235955357552, 51.01983189582825, 54.18494425714016, 17.137498408555984, 0.7677539682481438, 3.2390354946255684, 0.24420185247436166, 48.737955540418625, 74.8612953722477, 65.67018136382103, 71.70273005962372, 68.55391502380371, 71.53740093111992, 70.37674561142921, 66.13165900111198, 45.20153470337391, 53.08862708508968, 59.838493689894676, 69.4350877404213, 16.80665396153927, 1.0114321019500494, 0.32393772387877107, 0.30486651754472405, 0.27401166851632297, 0.2191474664141424, 0.23878126521594822, 0.14304645621450618], [0.08076416153926402, 0.14278643735451624, 0.08819835129543208, 0.07365024561295286, 0.06817268367740326, 0.056306295227841474, 0.11419699410907924, 0.07784291243297048, 0.02212672850873787, 0.3416488110087812, 0.201498229871504, 23.975172601640224, 61.616102904081345, 40.958879962563515, 33.40803153812885, 35.454818308353424, 53.635596334934235, 54.280493929982185, 57.51264229416847, 56.17300897836685, 58.75711731612682, 57.368075251579285, 52.18313567340374, 54.75457549095154, 15.875683017075062, 0.24484667490469292, 3.7838310236111283, 9.193460382521152, 0.25042431545443833, 1.9414663966745138, 36.75405599176884, 61.15977019071579, 56.633430272340775, 52.33310982584953, 53.16373385488987, 52.90983147919178, 54.96843941509724, 57.23101660609245, 57.25126951932907, 54.71769466996193, 56.00092001259327, 55.31426265835762, 57.473071217536926, 57.06252984702587, 56.337783336639404, 49.90084894001484, 44.225348085165024, 39.36366096138954, 39.00032065808773, 40.233711674809456, 42.395696863532066, 41.79430313408375, 49.888651594519615, 52.483186572790146, 53.90617221593857, 54.64900195598602, 52.50738747417927, 54.485242143273354, 51.96387603878975, 47.83221334218979, 45.73678158223629, 39.18391540646553, 43.63594651222229, 50.147569701075554, 53.095094338059425, 49.541304633021355, 50.21250061690807, 45.77998906373978, 46.5008407831192, 41.49665370583534, 40.057062953710556, 40.70542976260185, 42.30658024549484, 44.04158614575863, 46.12650007009506, 50.014037266373634, 52.51339115202427, 50.91403417289257, 53.222505301237106, 52.79765009880066, 53.815520480275154, 53.90035092830658, 52.45072491466999, 42.7145491540432, 39.5437902957201, 40.06797596812248, 38.34552459418774, 40.092066675424576, 48.75870242714882, 44.60376977920532, 38.525585532188416, 41.07459135353565, 40.22919751703739, 42.77066454291344, 43.5733562707901, 43.89924198389053, 46.592932641506195, 57.04435922205448, 54.575384706258774, 53.857626020908356, 50.8004354685545, 52.17223025858402, 50.42979955673218, 47.340329736471176, 40.34748136997223, 39.30263243615627, 37.82833054661751, 38.70300941169262, 37.43134304881096, 39.44519318640232, 47.707998007535934, 50.015264600515366, 45.60116685926914, 49.5069544762373, 49.64976981282234, 49.36862289905548, 46.32275573909283, 41.17036521434784, 44.921569526195526, 46.78336322307587, 42.79372550547123, 48.13458971679211, 52.974021434783936, 52.99408435821533, 54.36519518494606, 54.73777279257774, 52.73257479071617, 52.3134458810091, 52.14124292135239, 49.22443203628063, 45.793641731143, 46.100064888596535, 44.870846047997475, 39.32421527802944, 40.39048746228218, 49.04877506196499, 52.504305839538574, 53.9729992300272, 52.89926424622536, 56.08245983719826, 53.436293229460716, 56.94642327725887, 55.685468539595604, 57.66004018485546, 54.16358560323715, 50.83729349076748, 40.0665320456028, 51.05369947850704, 56.7353256046772, 63.458422645926476, 54.32136833667755, 34.77491319179535, 0.576674334006384, 0.0901970366248861, 1.6312182694673538, 3.1609971821308136, 61.516932025551796, 52.44286313652992, 57.624113112688065, 56.6617501527071, 55.39488673210144, 54.56171303987503, 58.67800556123257, 39.52971205115318, 33.65728676319122, 52.17880390584469, 38.18026386201382, 48.15102003514767, 4.116309620440006, 0.25027547031641006, 0.09402758732903749, 0.09782916458789259, 0.08819804701488465, 0.01840908073063474, 0.06477769944467582, 0.020527450360532384, 0.08327256131451577, 0.021382808954513166, 0.02660617232322693, 0.10734963536378928, 0.04734289905172773, 0.018475779397704173, 0.14397029648534954, 0.04469332052394748, 0.11486320523545146, 0.526577940909192, 0.1411507884040475, 28.97751297801733, 71.98462933301926, 38.88910822570324, 29.512786455452442, 47.26666308939457, 59.98444385826588, 59.692003950476646, 64.0016756951809, 63.31058777868748, 64.96834382414818, 62.3745422065258, 57.55276434123516, 57.97844409942627, 17.951380535960197, 0.18920732924016193, 4.315803665667772, 9.989648759365082, 0.10109554204973392, 2.3230723198503256, 42.905884087085724, 62.35982559621334, 59.90389198064804, 56.26989617943764, 56.20633319020271, 54.91503328084946, 57.936919927597046, 59.9220360070467, 60.660476982593536, 56.13766707479954, 59.23916704952717, 57.96748548746109, 59.13403809070587, 58.55134315788746, 57.66379818320274, 50.8259928971529, 45.756757110357285, 42.871499732136726, 42.63254955410957, 43.50516892969608, 43.49082849919796, 44.94417071342468, 51.85914225876331, 54.00899849832058, 57.84691795706749, 56.80575482547283, 55.57166084647179, 56.532766073942184, 54.160492569208145, 47.82342441380024, 47.78285779058933, 41.04515053331852, 45.96224628388882, 52.231590673327446, 54.38428536057472, 50.83055265247822, 52.73514345288277, 48.066493570804596, 47.32034660875797, 44.076304882764816, 42.91910357773304, 43.68410512804985, 45.09162940084934, 45.20323321223259, 48.57523687183857, 52.755096182227135, 53.11081789433956, 53.38643230497837, 53.744278103113174, 55.68981550633907, 55.99715821444988, 57.5377893447876, 54.6752205491066, 43.7712686508894, 38.680168837308884, 39.5529630035162, 39.0216489136219, 40.88367819786072, 51.34988598525524, 44.3778795003891, 38.00913244485855, 39.72531035542488, 39.833695739507675, 41.34367771446705, 43.55625718832016, 43.011092841625214, 44.94033671915531, 59.054531157016754, 56.66820600628853, 55.47501303255558, 53.9182897657156, 54.47359196841717, 52.691141813993454, 49.490873739123344, 41.21641494333744, 40.91738238930702, 40.49156203866005, 38.231773898005486, 39.06344287097454, 42.83157527446747, 49.28856119513512, 51.49981074035168, 47.329010143876076, 49.80160966515541, 51.95161409676075, 51.68630473315716, 48.68068501353264, 42.38470025360584, 45.33866174519062, 48.72821666300297, 45.280224680900574, 49.34340365231037, 53.02470691502094, 55.88495783507824, 56.67014770209789, 55.18442742526531, 56.18821196258068, 54.958457350730896, 53.61930660903454, 52.723557874560356, 48.468618392944336, 47.88186527788639, 46.27791814506054, 42.82743729650974, 40.92355705797672, 50.05450129508972, 55.56225635111332, 56.77319057285786, 54.06198285520077, 58.58632028102875, 54.48719523847103, 58.57997462153435, 58.0956906080246, 59.41022627055645, 57.08255477249622, 52.925657629966736, 42.772017270326614, 55.48509769141674, 59.358051270246506, 63.968936651945114, 55.02238132059574, 38.08554634451866, 0.7202345493715256, 0.32269922783598304, 1.5128037985414267, 4.027122231200337, 70.96615478396416, 60.323883444070816, 62.65144094824791, 64.68001529574394, 62.79968619346619, 62.18064621090889, 61.824479922652245, 46.520223543047905, 40.35214751958847, 49.755917116999626, 46.108804419636726, 56.25299468636513, 5.045801969245076, 0.4728561860974878, 0.09048750580404885, 0.08193519635824487, 0.07780910760629922, 0.10357284583733417, 0.014485671581496717, 0.03707769050379284, 0.15933230810333043, 0.15248513489495963, 0.17866008973214775, 0.23603573441505432, 0.1969303109217435, 0.15072525042342022, 0.23466084647225216, 0.18761568964691833, 0.3170418064109981, 0.6970980658661574, 0.3720310307107866, 33.469979614019394, 81.93735167384148, 51.351098120212555, 40.77984116971493, 52.62304946780205, 66.16521880030632, 64.63071674108505, 70.20357370376587, 69.3641759455204, 72.89750754833221, 69.12712186574936, 61.74851059913635, 66.63030624389648, 21.343827098608017, 0.3371855051955208, 12.90700301527977, 16.75210028886795, 0.26365063386037946, 4.001144925132394, 48.462572917342186, 65.19514605402946, 62.70352095365524, 57.6187402009964, 59.70575921237469, 56.663718447089195, 61.241367012262344, 62.95472167432308, 63.04293014109135, 59.584059342741966, 62.878858745098114, 60.451978370547295, 64.06829372048378, 60.85768640041351, 61.3916527479887, 54.67052400112152, 50.114135295152664, 46.1569744348526, 44.285160675644875, 47.29695126414299, 46.56822256743908, 46.37121453881264, 54.48643147945404, 55.236644223332405, 58.75334411859512, 56.67860604822636, 56.0205839574337, 59.43129613995552, 57.626522183418274, 51.931345984339714, 48.721593618392944, 43.70216555893421, 48.16825211048126, 55.2609059214592, 58.71784262359142, 54.699683636426926, 56.3659930229187, 50.72253964841366, 48.78547579050064, 44.869766905903816, 44.70016300678253, 45.365693494677544, 47.308601438999176, 48.045834079384804, 52.17579826712608, 54.92944970726967, 57.176189348101616, 55.98856307566166, 55.728508830070496, 58.96552853286266, 59.75812800228596, 57.10756503045559, 56.82206355035305, 43.088897466659546, 39.074705466628075, 41.661488860845566, 38.294432535767555, 40.3594621270895, 53.21091592311859, 47.225378304719925, 37.01733626425266, 37.639837861061096, 40.32115638256073, 41.57267242670059, 43.583273738622665, 44.98238906264305, 49.12342205643654, 62.407851219177246, 59.45824049413204, 56.052042469382286, 56.00683629512787, 56.72763101756573, 54.097138568758965, 53.42112444341183, 44.735649302601814, 44.29843716323376, 43.67113642394543, 42.229269593954086, 42.36155189573765, 45.43396823108196, 52.34138198196888, 55.77792137861252, 49.904325753450394, 52.73398071527481, 54.11970175802708, 53.34583528339863, 50.92489019036293, 44.368015229701996, 49.31383743882179, 50.840967893600464, 47.93365649878979, 52.07977741956711, 56.54616415500641, 56.84747278690338, 59.71357919275761, 57.6872543245554, 58.32521729171276, 55.865951254963875, 57.19469055533409, 53.042166978120804, 50.776876732707024, 49.73122224211693, 49.125477746129036, 44.9410966783762, 43.906773179769516, 52.09381766617298, 56.468804106116295, 58.36997129023075, 57.07473859190941, 60.30862346291542, 57.04242132604122, 60.87783671915531, 60.77709272503853, 62.68254987895489, 58.87686789035797, 56.8294807523489, 44.59949500858784, 60.27988560497761, 61.5588703751564, 68.87703448534012, 55.017008408904076, 43.420319482684135, 1.2923249043524265, 0.3372552967630327, 8.001192659139633, 5.3830300737172365, 76.30923807621002, 62.018622905015945, 69.55886229872704, 68.21236655116081, 70.50885692238808, 69.65302124619484, 71.32372319698334, 52.756923884153366, 46.51710771024227, 56.21953748166561, 53.67411486804485, 69.64086189866066, 6.989044770598412, 0.7133089459966868, 0.30964318779297173, 0.24336460599442944, 0.2767437812872231, 0.15198725770460442, 0.17146694211987779, 0.1684112529619597], [0.024572099537181202, 0.13110602740198374, 0.0427898378984537, 0.09804366753087379, 0.04000600485596806, 0.1991335247294046, 0.10189665335929021, 0.11961475378484465, 0.06838602887000889, 0.681310388026759, 0.12109205810702406, 9.682349748909473, 58.083614856004715, 50.63380300998688, 41.341188848018646, 22.147672064602375, 49.985876977443695, 52.62432619929314, 61.69489547610283, 60.13286769390106, 57.22693182528019, 57.65526384115219, 52.61107251048088, 54.780805483460426, 44.43227358162403, 0.9834184020292014, 1.5826312266290188, 8.680422361940145, 0.22314505971735343, 1.3009281177073717, 27.615021988749504, 54.01532135903835, 57.54766881465912, 58.7238235026598, 54.124117121100426, 57.69500210881233, 59.2419409006834, 57.56656900048256, 55.694002881646156, 53.031706139445305, 52.76089087128639, 50.02770133316517, 51.960289031267166, 50.81969663500786, 54.656061977148056, 53.06255288422108, 45.52873894572258, 41.28093548119068, 38.17532032728195, 40.69019258022308, 44.447043389081955, 47.684709057211876, 51.28746673464775, 52.0332907140255, 53.3942636847496, 57.16412119567394, 54.521841779351234, 54.540312588214874, 50.57681366801262, 43.74701075255871, 47.73435719311237, 43.935499638319016, 42.81983010470867, 48.600684106349945, 51.25505067408085, 48.7639195472002, 48.11145655810833, 46.09921373426914, 43.68823170661926, 41.31963640451431, 39.5628272742033, 38.66627298295498, 41.905348375439644, 48.22741113603115, 48.73866610229015, 50.03104515373707, 52.00947359204292, 53.727232217788696, 53.72408598661423, 51.86820097267628, 56.25325687229633, 53.428344056010246, 55.52061438560486, 43.45838963985443, 38.81224974989891, 40.7070142775774, 42.20572225749493, 39.44389745593071, 48.65836501121521, 43.738176226615906, 41.35505050420761, 42.52026557922363, 41.238491758704185, 41.94198980927467, 42.98498444259167, 43.82817439734936, 45.99782757461071, 55.241868942976, 55.72177179157734, 52.986325174570084, 52.586894407868385, 54.70754161477089, 51.368736773729324, 53.559843599796295, 45.06435066461563, 40.76176933944225, 40.28530530631542, 38.08800481259823, 37.799626886844635, 39.024035185575485, 40.79955071210861, 50.09772017598152, 49.90975946187973, 47.94313319027424, 48.38351055979729, 48.41743893921375, 47.3840843886137, 38.65312948822975, 45.406837686896324, 44.910660311579704, 45.64118631184101, 52.91124880313873, 50.843540355563164, 52.05852136015892, 49.459977596998215, 49.59081597626209, 49.057655185461044, 48.096584156155586, 46.55358575284481, 51.73584267497063, 49.59953650832176, 49.31520916521549, 41.49595834314823, 40.92012204229832, 38.90919014811516, 41.517905965447426, 48.44615779817104, 51.061318069696426, 53.536182269454, 56.948938742280006, 56.33214443922043, 55.667385309934616, 49.321231842041016, 58.364127203822136, 58.315474614501, 56.835153847932816, 45.98014332354069, 44.977228939533234, 55.96436597406864, 57.36664652824402, 63.57382245361805, 27.762541472911835, 0.807776270667091, 0.41135618928819895, 2.481866511516273, 10.855887327343225, 49.078664258122444, 45.21256171166897, 60.687041357159615, 54.86925333738327, 59.32650536298752, 58.61891493201256, 59.726939275860786, 42.24996328353882, 41.225010082125664, 47.279692590236664, 46.786851435899734, 39.15389321744442, 0.8741028397344053, 0.23367432440863922, 0.13290903065353632, 0.07353832974331453, 0.15067411644849926, 0.010847587600437691, 0.0458799404441379, 0.06991237431066111, 0.037968375327182, 0.09682060073828325, 0.11845980872749351, 0.15228601667331532, 0.04005894224974327, 0.07132933460525237, 0.14546278514899313, 0.07337388466112316, 0.08927367875003256, 0.7834985421504825, 0.2507728576892987, 13.879642523825169, 67.92018502950668, 54.161263927817345, 37.92515315115452, 36.75405979156494, 56.40171490609646, 53.05980943143368, 63.75695362687111, 66.57091543078423, 62.568593993783, 64.18186202645302, 57.583588287234306, 59.836760982871056, 43.976324647665024, 0.7573064882308245, 3.4054592018947005, 13.03268127143383, 0.4757108719786629, 0.44873516948428005, 33.81288841366768, 52.96862952411175, 60.64248114824295, 58.936357498168945, 58.24374206364155, 60.35329386591911, 61.84755228459835, 58.959133476018906, 58.46789203584194, 55.92296339571476, 54.72246341407299, 50.994190871715546, 52.66217976808548, 51.708776727318764, 56.70950599014759, 56.14455610513687, 46.63338527083397, 43.7139905244112, 41.29680722951889, 42.83435292541981, 48.30877237021923, 51.092085018754005, 53.17760311067104, 54.32155832648277, 56.28193013370037, 57.3274402320385, 56.77883706986904, 56.47286608815193, 51.915337443351746, 45.451352298259735, 48.56369309127331, 45.092978328466415, 44.1680433601141, 51.51160150766373, 54.60518270730972, 51.927728578448296, 50.26574335992336, 49.08849433064461, 46.68385796248913, 42.607820481061935, 41.55053861439228, 39.966620206832886, 42.94567935168743, 50.38381442427635, 51.54008857905865, 54.079568311572075, 53.06361302733421, 55.92652380466461, 54.55618053674698, 55.68437039852142, 56.92628055810928, 54.72913585603237, 55.5052138119936, 44.79253984987736, 38.43232713639736, 38.91044408082962, 43.96182082593441, 40.182980597019196, 50.48961214721203, 43.71120147407055, 40.14115244150162, 42.19482444226742, 40.41044399142265, 41.32386177778244, 44.05521221458912, 43.73178876936436, 47.68302574753761, 57.9933924973011, 57.86937475204468, 55.78221134841442, 54.51885513961315, 55.852933153510094, 51.00220464169979, 55.32030813395977, 45.856152176856995, 41.655819565057755, 39.94267389178276, 40.00974029302597, 39.49158489704132, 40.985334143042564, 44.478866681456566, 52.24676325917244, 51.382457837462425, 51.12574361264706, 51.496292129158974, 49.76950518786907, 48.03915783762932, 40.84743574261665, 45.54001294076443, 45.591332986950874, 47.45397783815861, 54.98776897788048, 53.44115696847439, 53.32071863114834, 51.45953670144081, 50.33475145697594, 49.640323519706726, 50.73995791375637, 48.34980636835098, 54.53055091202259, 50.54689407348633, 50.75460612773895, 43.190264627337456, 42.40089498460293, 40.48392444849014, 43.107725456357, 50.326456502079964, 54.53818470239639, 55.29727756977081, 57.22636565566063, 57.398029044270515, 57.77211897075176, 52.67134107649326, 60.535638481378555, 60.24110868573189, 58.96795280277729, 49.50294569134712, 46.66912995278835, 59.38142001628876, 58.79565104842186, 64.99716147780418, 29.550877511501312, 0.5236947862431407, 0.9215317759662867, 0.8992560650222003, 13.733862396329641, 59.685760885477066, 50.22879794239998, 66.48509323596954, 62.03010208904743, 64.65522542595863, 64.47278201580048, 65.4179584980011, 51.7629162222147, 43.93997959792614, 44.09051612019539, 55.58431796729565, 44.35413837432861, 1.3073380175046623, 0.1636582869105041, 0.03778434496780392, 0.06862315989565104, 0.08455750838038512, 0.040940943945315666, 0.018174196557083633, 0.04854815430007875, 0.04719578311778605, 0.21536417567403987, 0.18601325922645628, 0.2626790734939277, 0.19465832971036434, 0.23665806977078319, 0.2180715452414006, 0.19625614397227764, 0.27390530391130596, 1.0047956393100321, 0.4356528277276084, 16.8541457131505, 77.96556159853935, 69.82103303074837, 47.36681431531906, 36.19574435055256, 60.84595263004303, 61.23782940208912, 72.94719368219376, 72.23280921578407, 67.7057321369648, 66.61993280053139, 64.74851801991463, 64.81390491127968, 53.73860500752926, 1.3425460970029235, 8.277518581598997, 21.852845884859562, 0.551783888367936, 2.3916215915232897, 42.07323096692562, 53.670771047472954, 64.84871864318848, 62.95722953975201, 60.430061146616936, 61.80312126874924, 63.09469096362591, 61.98037415742874, 60.87497167289257, 58.4648521989584, 55.383992716670036, 51.045830100774765, 54.8699638992548, 52.470939829945564, 58.3177050948143, 58.793580159544945, 50.024387910962105, 47.27407269179821, 42.936206459999084, 45.019361078739166, 50.82158513367176, 53.79676088690758, 56.38408005237579, 55.578527078032494, 58.444382697343826, 60.34634403884411, 58.977946266531944, 59.125507548451424, 53.75783197581768, 48.5250149667263, 51.72521844506264, 49.49647843837738, 47.24540702998638, 53.81203606724739, 58.13236244022846, 55.06551280617714, 53.965167850255966, 52.65377841889858, 48.4244229644537, 44.63850371539593, 44.82819713652134, 42.07708775997162, 45.77180430293083, 54.13700222969055, 54.76506292819977, 55.25242477655411, 56.52668260037899, 60.31688041985035, 59.2704089730978, 60.609521716833115, 62.276024892926216, 55.59642791748047, 59.764857441186905, 46.101995185017586, 39.67255778610706, 39.69825580716133, 43.87756794691086, 40.00224329531193, 53.05903047323227, 44.8236183822155, 41.47641599178314, 42.92305916547775, 41.63679018616676, 41.9842891395092, 43.657027781009674, 44.143610671162605, 49.31230992078781, 59.682268872857094, 58.851967826485634, 59.63535659015179, 56.929635778069496, 60.31662583351135, 55.10022774338722, 59.107998088002205, 49.580005556344986, 43.8330153375864, 43.404352739453316, 41.94440647959709, 43.38448740541935, 44.33220215141773, 46.65541648864746, 53.835716396570206, 54.15339834988117, 52.87895433604717, 53.53164531290531, 54.483604431152344, 50.391406416893005, 43.02226044237614, 50.1247139275074, 49.129353538155556, 51.24623894691467, 58.00446890294552, 54.91677738726139, 55.762938782572746, 53.36775630712509, 52.9808496683836, 52.873467430472374, 52.52712361514568, 51.38528108596802, 56.097362637519836, 53.10372367501259, 54.756357595324516, 44.9324369430542, 43.59841972589493, 43.45453284680843, 45.191077664494514, 52.981773018836975, 54.67343084514141, 59.42520126700401, 61.94245219230652, 59.32938560843468, 60.310333371162415, 55.29079131782055, 62.29843229055405, 62.886697724461555, 63.34493413567543, 51.21408887207508, 50.24174764752388, 62.11677543818951, 62.436490282416344, 65.61466634273529, 34.12614360451698, 0.7084526284597814, 2.1243850188329816, 5.710936803370714, 13.956659641116858, 64.62648376822472, 57.675349563360214, 72.06959277391434, 66.91462218761444, 71.22277021408081, 69.14009436964989, 73.1453986465931, 56.06926694512367, 56.531762927770615, 53.7891460955143, 65.9702056646347, 54.48554612696171, 1.553296206984669, 0.33281351323239505, 0.1641158654820174, 0.21886540576815605, 0.2555543667403981, 0.09367711551021785, 0.1787261408753693, 0.1777352995122783], [0.11485090042697266, 0.028246739857422654, 0.04367999950773083, 0.10777301577036269, 0.0901101459749043, 0.05956046807114035, 0.01998629297304433, 0.1668634742964059, 0.04615567057044245, 0.16804293991299346, 0.07053771536448039, 1.629764016252011, 46.54100462794304, 45.41599899530411, 37.96114481985569, 29.370807074010372, 44.924989342689514, 64.61255371570587, 61.033392772078514, 60.05960762500763, 56.54608055949211, 56.07744410634041, 56.189082115888596, 50.02195984125137, 51.38753816485405, 3.647393169812858, 3.433322631753981, 9.60677370429039, 0.6971876579336822, 0.8896339125931263, 31.929705664515495, 56.53297506272793, 52.42475710809231, 57.0654708892107, 56.88265509903431, 57.77989335358143, 56.54131941497326, 54.815945997834206, 53.624162748456, 53.428051471710205, 54.31765593588352, 55.820562690496445, 55.430452823638916, 54.589664340019226, 56.47690907120705, 52.83113390207291, 44.619523733854294, 40.12877270579338, 39.156169295310974, 41.63469269871712, 47.400852888822556, 50.775968581438065, 52.619435861706734, 54.130128398537636, 54.97070789337158, 54.231263771653175, 53.80841486155987, 51.92938528954983, 54.172275736927986, 47.85670302808285, 45.46443499624729, 43.16839300096035, 43.02299000322819, 45.92489428818226, 51.09200522303581, 48.578972071409225, 46.74246221780777, 46.23335413634777, 43.71465928852558, 41.91477566957474, 42.572345584630966, 40.19248768687248, 46.534252390265465, 47.75531306862831, 49.27749238908291, 50.817986726760864, 50.360852256417274, 48.56117382645607, 52.819529324769974, 54.19633984565735, 52.43627808988094, 54.76707682013512, 54.31599922478199, 47.40273758769035, 38.968185782432556, 40.134461000561714, 43.156837821006775, 41.26968428492546, 49.82609935104847, 43.29884760081768, 40.21175265312195, 42.21673026680946, 41.04413598775864, 42.99223445355892, 42.0612920075655, 42.44608215987682, 47.30548940598965, 59.73083406686783, 55.46600751578808, 56.02884851396084, 53.21871690452099, 52.25661613047123, 51.46240554749966, 54.13506053388119, 51.022487953305244, 45.86977444589138, 39.61340256035328, 39.23171304166317, 39.49702240526676, 38.25513884425163, 41.160079166293144, 44.31373134255409, 49.227057695388794, 49.62864674627781, 47.96010687947273, 48.16643200814724, 44.372696578502655, 38.5000205039978, 45.87222531437874, 45.153965055942535, 48.80452036857605, 52.66119942069054, 51.95312641561031, 52.355836406350136, 49.39528986811638, 48.71509596705437, 51.85315378010273, 50.812336429953575, 46.39926463365555, 48.95156107842922, 50.53558588027954, 47.70971931517124, 44.85271342098713, 41.41441471874714, 38.91689993441105, 40.732195526361465, 41.10984206199646, 48.45244266092777, 52.10098408162594, 56.14604562520981, 55.313897877931595, 57.72298380732536, 50.580077692866325, 48.17691184580326, 64.64565753936768, 56.57052084803581, 52.59903855621815, 45.37798583507538, 57.973903343081474, 54.975906014442444, 61.22712157666683, 11.912814863026142, 0.2197809042991139, 0.30834757606498897, 0.8423670614138246, 27.665116600692272, 42.21096597611904, 46.59931629896164, 56.09343744814396, 55.190423503518105, 61.339956521987915, 56.001687571406364, 54.77698288857937, 38.513528779149055, 31.112455017864704, 30.248181894421577, 52.32048690319061, 17.78446689248085, 0.8134960918687284, 0.05088378951768391, 0.041047976483241655, 0.036920091733918525, 0.11092363303760067, 0.029872178711229935, 0.05010968496208079, 0.033017107416526414, 0.06633872544625774, 0.03311138614662923, 0.06549957164679654, 0.0724141244427301, 0.035342415649211034, 0.185384200012777, 0.012272275507712038, 0.06300666049355641, 0.014093079171288991, 0.2789010264677927, 0.08764569618506357, 3.4554695058614016, 54.86127756536007, 51.88941143453121, 35.24729624390602, 32.563781440258026, 56.810850352048874, 67.18867868185043, 69.3391352891922, 64.99608233571053, 64.95606288313866, 61.088497415184975, 60.86329869925976, 56.55556105077267, 57.18633100390434, 3.971691280603409, 1.7302894033491611, 7.5280106998980045, 0.5506051203701645, 1.9817441166378558, 35.68671606481075, 55.5600942671299, 55.84512077271938, 59.7195752710104, 59.64712455868721, 58.17625008523464, 60.10293290019035, 57.71520182490349, 57.367174699902534, 54.10981088876724, 55.80010078847408, 56.47331826388836, 54.50169526040554, 57.044009640812874, 59.8831906914711, 52.77002178132534, 48.18752467632294, 42.74152010679245, 42.90594108402729, 44.42949213087559, 49.878430142998695, 54.05787527561188, 53.42274695634842, 56.823929250240326, 56.49810053408146, 54.412559643387794, 55.51077291369438, 55.357219353318214, 55.47921560704708, 49.68684062361717, 48.535263016819954, 44.73120354115963, 44.636451825499535, 48.05669389665127, 53.96552503108978, 51.94280996918678, 48.984680101275444, 47.41818755865097, 46.43775276839733, 42.955809608101845, 44.14783984422684, 42.92256899178028, 49.52493891119957, 51.4947684109211, 50.629486441612244, 54.56317216157913, 53.43317359685898, 51.605198085308075, 53.89207877218723, 57.175220400094986, 54.08327691257, 57.11886942386627, 54.69938725233078, 48.271731957793236, 38.721734806895256, 39.03383865952492, 42.01300039887428, 40.61711110174656, 50.4842734336853, 44.868334382772446, 38.64233046770096, 41.67861074209213, 40.18453851342201, 42.17394456267357, 42.269984409213066, 41.25073470175266, 48.13397414982319, 60.44798478484154, 56.49575226008892, 57.00892232358456, 54.73249867558479, 54.65457625687122, 54.709965884685516, 55.45591525733471, 52.948783189058304, 48.26616905629635, 43.00105378031731, 41.99326425790787, 40.999621376395226, 40.81851929426193, 42.44098663330078, 46.91958971321583, 51.462120562791824, 51.58938713371754, 49.66839641332626, 50.81646300852299, 47.1000724285841, 42.24006101489067, 48.03080968558788, 45.883472710847855, 51.71616353094578, 55.11241748929024, 53.94064016640186, 53.8036423176527, 50.6279057264328, 50.10703727602959, 51.88688836991787, 53.66380222141743, 51.38638682663441, 50.96433587372303, 53.33078049123287, 49.06966254115105, 47.50551447272301, 42.682680264115334, 41.55864357948303, 42.59930893778801, 44.335086196660995, 50.70029564201832, 53.927204087376595, 58.26536290347576, 56.14769093692303, 59.05796617269516, 54.078872948884964, 49.424631893634796, 66.05894610285759, 58.446233198046684, 56.04438588023186, 47.935780584812164, 61.176762878894806, 58.26114892959595, 63.9955048263073, 13.270566556602716, 0.23517546651419252, 0.9756563685368747, 0.23672173119848594, 31.781652309000492, 44.063552767038345, 51.967352852225304, 63.058665096759796, 62.938063368201256, 66.00888758897781, 63.21618564426899, 59.80506308376789, 49.048136696219444, 40.11754430830479, 33.73344607651234, 61.86585210263729, 23.484869711101055, 1.0739398165605962, 0.15174850879702717, 0.03206204499292653, 0.018829898872354534, 0.05916088091908023, 0.05991366728267167, 0.0716408362495713, 0.14990437572123483, 0.1854275562800467, 0.23911425203550607, 0.15536119462922215, 0.24670723913004622, 0.2352676709415391, 0.24419670196948573, 0.11551723029697314, 0.4063062305795029, 0.12476737378165126, 0.4858474514912814, 0.1760354547877796, 3.8819011487066746, 66.3881604373455, 64.89140555262566, 46.675468012690544, 42.913517877459526, 63.0853358656168, 72.12245553731918, 73.90308558940887, 71.21776968240738, 69.76116344332695, 68.4307712316513, 67.43370473384857, 65.82770571112633, 64.49061825871468, 5.5094977375119925, 5.373769970610738, 20.547646321356297, 1.7613742290996015, 3.938324796035886, 41.76820233464241, 55.04321180284023, 56.527013182640076, 60.43018653988838, 63.77184882760048, 62.25906640291214, 64.05632436275482, 59.63034845888615, 58.55288587510586, 56.97958789765835, 57.29603871703148, 60.50760358572006, 58.22797670960426, 58.02951715886593, 61.36269070208073, 56.0146676748991, 52.0055066049099, 44.12164404988289, 44.117388278245926, 46.685879454016685, 54.20808121562004, 55.87691366672516, 57.00043357908726, 59.313392266631126, 59.21790339052677, 56.046407371759415, 58.00673358142376, 54.86669607460499, 57.84266598522663, 52.185936123132706, 50.92831000685692, 46.2952034175396, 46.407202407717705, 49.82223115861416, 58.04550290107727, 54.76954288780689, 51.01489216089249, 52.055120542645454, 50.51322788000107, 46.271158307790756, 47.36217476427555, 46.815938875079155, 53.116908967494965, 52.919019386172295, 55.18158137798309, 56.74154207110405, 57.264565005898476, 53.33894245326519, 58.480191975831985, 57.77752608060837, 57.27557681500912, 58.98398794233799, 58.207921385765076, 49.649842008948326, 38.66124965250492, 39.38295252621174, 43.420558869838715, 40.75010396540165, 53.646478950977325, 47.07172594964504, 39.193103313446045, 41.10372819006443, 41.035601645708084, 41.23854495584965, 42.025847509503365, 40.925513952970505, 50.43102689087391, 63.47779020667076, 57.8380074352026, 60.81786073744297, 57.10239730775356, 57.71507643163204, 57.37255901098251, 58.77512454986572, 56.20621159672737, 50.532390251755714, 44.753135964274406, 44.12291318178177, 44.68981236219406, 41.81161880493164, 46.06200993061066, 48.19557644426823, 54.13182690739632, 53.97358439862728, 52.76806868612766, 52.39034615457058, 49.471992552280426, 43.915337920188904, 50.98415561020374, 48.9063511043787, 53.80610078573227, 55.23958146572113, 55.782652124762535, 55.11799938976765, 52.780342027544975, 50.82577630877495, 54.972064420580864, 56.63819141685963, 50.6488312035799, 54.07956451177597, 55.25606498122215, 51.328922510147095, 51.50969780981541, 45.02853378653526, 42.942954897880554, 45.25468245148659, 48.166120424866676, 54.73005160689354, 57.713757902383804, 59.039438366889954, 60.776788741350174, 60.057399943470955, 55.15235714614391, 48.7052620947361, 71.0210770368576, 62.32531204819679, 59.31469939649105, 51.35506130754948, 63.798720985651016, 59.90446574985981, 67.02635899186134, 15.334816239774227, 0.20722654124256223, 2.791973571293056, 0.9483509743586183, 35.4566004127264, 51.7721801251173, 59.43948470056057, 66.82853400707245, 67.2437073290348, 73.8557781279087, 68.69820088148117, 67.49816447496414, 53.46798352897167, 44.0651448816061, 41.55864357948303, 71.21033728122711, 31.387983933091164, 1.4582415763288736, 0.32819174404721707, 0.2856666228035465, 0.0966029436676763, 0.1939730899175629, 0.15955026203300804, 0.2034222477232106, 0.19306431524455547], [0.02333507851290051, 0.06440697441576049, 0.024826747103361413, 0.021788741469208617, 0.08381038831430487, 0.044961484454688616, 0.12053296857629903, 0.08258644578745589, 0.0772210001014173, 0.06606433860724792, 0.5543967825360596, 0.367775852791965, 29.96190905570984, 57.3144069314003, 36.105863973498344, 25.036311261355877, 37.702728286385536, 49.96964804828167, 51.518631130456924, 62.70822890102863, 57.15189345180988, 55.20623065531254, 47.89540775120258, 47.25823514163494, 54.91528406739235, 14.324152171611786, 1.6965759498998523, 9.121270906180143, 0.4673641745466739, 9.808669220656157, 37.26422421634197, 52.30104334652424, 54.909527376294136, 54.94599021971226, 52.29073829948902, 54.997393861413, 56.79108761250973, 58.66881385445595, 58.03900524973869, 58.77055339515209, 57.067480981349945, 57.60852634906769, 54.45352904498577, 57.67278470098972, 53.62168908119202, 48.79098169505596, 41.75014190375805, 41.26737780869007, 42.17756196856499, 42.33790196478367, 50.19235409796238, 51.99982590973377, 53.68576504290104, 54.713522493839264, 51.95252984762192, 48.25277477502823, 54.10114735364914, 56.498723700642586, 55.125834569334984, 51.51317462325096, 46.17425590753555, 46.47996470332146, 40.58834284543991, 41.8054935336113, 48.434993997216225, 50.987579226493835, 50.354669988155365, 43.15276063978672, 43.36949720978737, 41.55948333442211, 39.510120302438736, 42.629764303565025, 47.32215151190758, 49.12048101425171, 52.96523630619049, 53.373315408825874, 51.350661143660545, 51.15276396274567, 55.417959094047546, 54.00118611752987, 55.49797520041466, 55.2614226937294, 54.44594085216522, 47.12813772261143, 40.22264286875725, 41.51287883520126, 41.11043103039265, 39.65598687529564, 50.45778125524521, 45.01110792160034, 41.68076142668724, 41.38864450156689, 43.53926829993725, 42.6732187718153, 42.49732241034508, 42.00972877442837, 47.322193309664726, 53.56102533638477, 56.11141428351402, 55.449873581528664, 51.595713794231415, 51.75617158412933, 50.81345736980438, 53.809509202837944, 49.17305499315262, 51.010123416781425, 42.096310928463936, 41.61579631268978, 36.97010859847069, 36.64817847311497, 37.20471940934658, 39.83298517763615, 45.410747677087784, 50.305998399853706, 50.353777036070824, 46.37643165886402, 40.521151050925255, 41.53208680450916, 43.88087376952171, 48.09138983488083, 53.2213843613863, 52.071748450398445, 52.719689682126045, 51.95299342274666, 52.422275841236115, 52.822496965527534, 54.2996297031641, 51.67890653014183, 54.72134247422218, 56.36062391102314, 54.84267756342888, 48.29235725104809, 43.01578938961029, 39.9231581389904, 40.73434241116047, 38.93019162118435, 42.95547902584076, 41.94590739905834, 47.04370625317097, 51.9182138890028, 54.97416950762272, 54.752884581685066, 55.96933610737324, 52.52092234790325, 61.41581945121288, 63.54699969291687, 57.03621245920658, 49.914497807621956, 56.18441216647625, 54.75684776902199, 57.36996755003929, 6.118157152086496, 0.0358376025542384, 0.10023888840805739, 2.8043753933161497, 62.55616866052151, 58.24545197188854, 58.87515798211098, 53.91564130783081, 58.66696335375309, 53.189078494906425, 64.51143354177475, 45.46386882662773, 39.52562727034092, 28.80125943571329, 28.5752247646451, 54.37099747359753, 7.161307577043772, 0.5090525094419718, 0.09002879174659029, 0.10536030851653777, 0.06687251516268589, 0.04312655401008669, 0.021805380420119036, 0.03449967727647163, 0.019094049639534205, 0.03429368676734157, 0.056948041456053033, 0.088762687810231, 0.03878037023241632, 0.07985683405422606, 0.06493203647551127, 0.08349171752342954, 0.09447767020901665, 0.10320414687157609, 0.09164964969386347, 0.35599019145593047, 0.44875188264995813, 39.832099825143814, 65.31676232814789, 41.063678339123726, 33.41017082333565, 49.673894718289375, 53.430965915322304, 61.13733999431133, 66.43455594778061, 63.740390315651894, 61.0501004755497, 56.15960329771042, 54.33818623423576, 61.509351432323456, 13.787104189395905, 1.449478652793914, 6.609478862956166, 0.6949878134764731, 11.827586386352777, 41.65649212896824, 50.46122387051582, 55.57050570845604, 55.18801063299179, 56.370301991701126, 58.40487241744995, 59.97258089482784, 61.40590198338032, 60.40125869214535, 61.26596309244633, 59.2962171882391, 58.48256304860115, 55.959164053201675, 59.49142411351204, 55.5566668510437, 50.22028259932995, 44.82904449105263, 43.26360449194908, 44.27565738558769, 44.43132363259792, 52.62809559702873, 56.22709907591343, 56.39215461909771, 57.25565068423748, 54.89913873374462, 50.68311296403408, 54.85994763672352, 59.70926262438297, 58.801289945840836, 54.2870257794857, 49.12740804255009, 48.56810085475445, 42.631402015686035, 43.855578526854515, 50.99471904337406, 52.10522085428238, 49.87572468817234, 46.51070885360241, 46.95520140230656, 45.936346873641014, 42.443570494651794, 44.468044862151146, 50.801324620842934, 50.94926968216896, 52.86178685724735, 56.054090559482574, 55.16074329614639, 54.041688144207, 57.21895985305309, 56.12136974930763, 57.3722056299448, 55.30242249369621, 54.765085726976395, 47.21516065299511, 41.037094965577126, 39.83597181737423, 41.75248257815838, 41.20390601456165, 50.2320771664381, 44.56159204244614, 40.267575457692146, 41.75045348703861, 42.4138180911541, 40.824188590049744, 41.34770929813385, 42.39619843661785, 48.02252992987633, 57.53755755722523, 56.800948083400726, 55.884980633854866, 54.470973908901215, 53.8820169121027, 53.51960375905037, 53.349631279706955, 51.93673029541969, 52.100835889577866, 44.60657022893429, 43.36071968078613, 39.385240003466606, 37.735167145729065, 38.98059591650963, 42.6713340729475, 47.15177245438099, 51.28674857318401, 51.51567868888378, 46.88295967876911, 43.369520008563995, 42.69638232886791, 46.013429537415504, 49.6089182049036, 55.44046528637409, 55.70073612034321, 54.47450011968613, 51.92212387919426, 53.361216858029366, 54.7768384963274, 55.9284009039402, 52.998176738619804, 55.78580595552921, 57.81757593154907, 54.68683272600174, 50.579838305711746, 46.20641738176346, 42.87143513560295, 41.14210993051529, 41.391232162714005, 44.73719961941242, 44.39689368009567, 48.87108899652958, 54.25326459109783, 57.96787686645985, 57.046582102775574, 59.15096998214722, 53.46163786947727, 61.273669078946114, 63.793522864580154, 59.819772094488144, 53.251908123493195, 59.90839473903179, 57.23370686173439, 59.23424631357193, 7.075373288244009, 0.07222319953143597, 1.3382906815968454, 3.360220016911626, 66.53354063630104, 58.55656787753105, 64.32878494262695, 58.96921433508396, 64.70975250005722, 60.032644271850586, 74.80021744966507, 50.42976915836334, 53.083037585020065, 30.354973264038563, 28.5806717723608, 65.08568912744522, 10.144818183034658, 0.5317790899425745, 0.15933259011944756, 0.08734750124858692, 0.07738277345197275, 0.146789537393488, 0.07552388648036867, 0.021392241651483346, 0.03228912733902689, 0.12127760986913927, 0.22037849645130336, 0.19060455582803115, 0.2280723859439604, 0.17269764561206102, 0.1855276571586728, 0.2317727342597209, 0.13869499205611646, 0.17608661844860762, 0.2773864514892921, 0.5264530819840729, 0.7098004873842001, 47.433550134301186, 77.8073000907898, 49.295058846473694, 33.34099553525448, 55.10189585387707, 59.685871079564095, 63.26418846845627, 73.15768718719482, 70.46159505844116, 67.94836431741714, 63.254951164126396, 59.60658073425293, 65.68006083369255, 18.64429235458374, 2.2361543588340282, 20.081770420074463, 0.8474497636780143, 15.61485456302762, 49.84862074255943, 49.46374699473381, 57.59865067899227, 56.840804144740105, 57.53918007016182, 60.20627975463867, 63.50709803402424, 63.18486772477627, 64.15660858154297, 64.32142093777657, 63.65219324827194, 62.59778022766113, 58.92249584197998, 64.06200125813484, 58.87437142431736, 53.616559356451035, 48.275573551654816, 44.67433199286461, 46.866875141859055, 46.950869634747505, 55.83276003599167, 58.17950651049614, 59.12290468811989, 60.46368554234505, 55.24143196642399, 50.59648521244526, 57.472018674016, 62.34813742339611, 60.36906681954861, 56.52766674757004, 50.595846846699715, 51.37156002223492, 44.53252360224724, 45.04944026470184, 53.523749336600304, 55.22904083132744, 53.80556881427765, 49.1028955578804, 49.35321092605591, 46.345581114292145, 44.660538733005524, 48.3866073936224, 53.07206757366657, 53.58761250972748, 59.097605645656586, 59.87692102789879, 55.22239878773689, 54.408889040350914, 60.15301041305065, 59.35977257788181, 62.37358845770359, 58.59398826956749, 58.28993998467922, 50.28388738632202, 41.18887022137642, 40.66536471247673, 41.92311242222786, 39.62252587080002, 53.77564921975136, 47.7529875934124, 40.24818129837513, 41.12101726233959, 43.44305366277695, 41.04279465973377, 40.19931212067604, 42.47625254094601, 48.369755297899246, 59.36418794095516, 60.091024339199066, 58.141987323760986, 56.15183271467686, 55.74370801448822, 56.78189970552921, 56.97897233068943, 54.10456337034702, 54.41776916384697, 47.04684488475323, 46.35861821472645, 42.44404926896095, 41.0197488963604, 41.44666738808155, 44.055330008268356, 50.29709927737713, 54.48231250047684, 54.079465717077255, 49.624178186059, 45.54992660880089, 44.857109785079956, 48.225408643484116, 51.63440331816673, 58.02435703575611, 56.43418416380882, 56.23446308076382, 55.0074253231287, 55.040084570646286, 56.406821832060814, 59.95536021888256, 55.60877725481987, 56.89134523272514, 58.73192846775055, 57.05276817083359, 52.662544548511505, 47.84998118877411, 44.944155514240265, 44.55937676131725, 42.793858498334885, 48.83733920753002, 47.88826413452625, 51.271416395902634, 56.904697716236115, 61.73858933150768, 59.4074372202158, 63.010814264416695, 53.89370508491993, 62.54374332726002, 66.12089797854424, 62.47400566935539, 56.019713804125786, 63.460797518491745, 59.88322488963604, 64.25633043050766, 9.265178684145212, 0.15886392386164516, 3.353598159737885, 2.898356937803328, 74.32050079107285, 66.78276166319847, 71.9711172580719, 65.17217248678207, 70.17091825604439, 66.57529279589653, 77.92172715067863, 58.70826333761215, 55.61109133064747, 37.64086380600929, 39.74621683359146, 76.49319380521774, 13.214044589549303, 1.0332067147828639, 0.2047757914988324, 0.2606224932242185, 0.12338181375525892, 0.2138912203372456, 0.3106302145170048, 0.14260879688663408, 0.15829523093998432], [0.01557712683279533, 0.022569825923710596, 0.08341097185621038, 0.04819178982870653, 0.11231518219574355, 0.03472949443676043, 0.14453020237851888, 0.056076196051435545, 0.07130145953851752, 0.052593259897548705, 0.8511593146249652, 0.13589978188974783, 12.724534906446934, 50.95996990799904, 34.319652020931244, 30.93377150595188, 31.980375945568085, 55.577181950211525, 52.51515045762062, 60.79951152205467, 56.87805354595184, 58.0194590985775, 54.22774136066437, 52.70455129444599, 54.09481689333916, 27.29620959609747, 1.2062655785121024, 5.255270004272461, 0.43252577364910394, 12.13714437559247, 29.959013611078262, 37.56498947739601, 59.87662844359875, 60.89957155287266, 59.30700100958347, 61.07572630047798, 57.06685781478882, 57.32722744345665, 56.57207876443863, 54.782089814543724, 53.841837868094444, 55.36659725010395, 51.9634922593832, 49.87659864127636, 43.521318063139915, 41.50340974330902, 39.93197366595268, 41.323736384510994, 40.20664572715759, 42.4602098017931, 46.28255009651184, 54.12416651844978, 55.274543389678, 55.587642788887024, 53.08810271322727, 50.44699743390083, 46.55810371041298, 50.25251626968384, 55.72516120970249, 52.421607077121735, 46.590462774038315, 45.87600991129875, 42.95754611492157, 40.43515786528587, 42.05207750201225, 48.99778559803963, 47.984900549054146, 43.834972232580185, 41.2469083070755, 40.89546896517277, 39.3766600638628, 47.24052049219608, 48.57711397111416, 52.04907886683941, 52.225108221173286, 51.559733524918556, 53.25258828699589, 53.995676413178444, 53.83544281125069, 54.77460041642189, 52.45696038007736, 54.59514744579792, 53.34790237247944, 45.112391486763954, 41.30182296037674, 39.948491379618645, 40.935461819171906, 40.486610904335976, 48.515884056687355, 40.92017903923988, 39.89658996462822, 44.05393548309803, 41.645392924547195, 42.68341742455959, 42.450421527028084, 42.717171013355255, 49.2256061732769, 55.86623623967171, 54.24073286354542, 55.18469721078873, 54.81429688632488, 51.790069565176964, 51.81226037442684, 51.82915046811104, 50.5823689699173, 51.324206963181496, 46.776185408234596, 41.445075273513794, 36.598021164536476, 38.05077061057091, 37.6743134111166, 41.13872051239014, 43.288622349500656, 47.18286618590355, 47.89882376790047, 44.71020586788654, 39.6194252371788, 42.13507264852524, 45.18036983907223, 51.29863813519478, 53.47734622657299, 48.67482952773571, 52.76736952364445, 50.615020617842674, 52.63124942779541, 49.83582302927971, 52.131295055150986, 48.42143252491951, 49.241850301623344, 51.146262511610985, 50.98200872540474, 47.94663280248642, 44.414414539933205, 39.91827540099621, 38.08531455695629, 39.09027323126793, 40.600110813975334, 39.29549261927605, 41.32875211536884, 44.688588827848434, 51.04051798582077, 53.67538020014763, 56.873459592461586, 58.16637061536312, 51.93997912108898, 53.07342790067196, 62.64909267425537, 53.55732433497906, 58.129174411296844, 55.764625892043114, 49.7005008906126, 4.158405186608434, 0.6436951970681548, 0.966504915850237, 8.690887000411749, 62.451841458678246, 56.56624987721443, 56.20067149400711, 55.10931685566902, 57.28128410875797, 58.97209458053112, 52.68195390701294, 41.6172706335783, 33.47823277115822, 23.950071148574352, 38.65125618875027, 41.802662685513496, 1.792637170292437, 0.28391524334438145, 0.0309119888333953, 0.09675952198449522, 0.07116779874195345, 0.08066569338552654, 0.01499399264503154, 0.0394213149411371, 0.033889242258737795, 0.04707961103122216, 0.07693184452364221, 0.030627579290012363, 0.03907155929482542, 0.13452961400616914, 0.027371465730539057, 0.10136391007108614, 0.0444284183322452, 0.03798295852902811, 0.043949770188191906, 0.7406582753174007, 0.20057624496985227, 17.93941117823124, 61.33777163922787, 36.00735045969486, 26.77479587495327, 47.104039415717125, 54.755829423666, 56.32378488779068, 66.77241861820221, 62.458890080451965, 62.40804500877857, 60.28394378721714, 55.20004838705063, 62.272722870111465, 29.549754671752453, 0.7848886144347489, 4.823459750041366, 0.7820889365393668, 16.603547260165215, 36.0969952493906, 39.04422350227833, 61.36710226535797, 62.44928799569607, 61.50309316813946, 64.30411666631699, 60.15010356903076, 61.55464880168438, 58.674635142087936, 57.24780410528183, 57.07350365817547, 58.33072319626808, 53.22555273771286, 52.57891483604908, 47.05815687775612, 44.4837836176157, 41.74745924770832, 43.58603239059448, 42.69550837576389, 46.5133573114872, 48.75811345875263, 54.54152852296829, 56.08152508735657, 56.2087232619524, 55.980917885899544, 51.96102999150753, 47.05443687736988, 53.45827504992485, 58.51358838379383, 54.16198588907719, 49.256076738238335, 47.44268484413624, 43.72063256800175, 42.44476743042469, 44.533788934350014, 51.42649747431278, 50.07076822221279, 45.061352625489235, 45.36682963371277, 43.42935159802437, 41.73676662147045, 49.76285934448242, 50.752455443143845, 53.04972857236862, 53.75400938093662, 55.472812950611115, 54.77157197892666, 55.75444243848324, 56.26973658800125, 55.80000199377537, 56.05673901736736, 56.481666415929794, 56.11187405884266, 44.43955399096012, 40.47524571418762, 40.51505617797375, 41.01190231740475, 39.501141384243965, 50.192650482058525, 42.67665758728981, 39.55910347402096, 43.631432354450226, 42.02328644692898, 42.25866861641407, 41.29569008946419, 43.039899095892906, 49.702887162566185, 57.63491593301296, 55.33588729798794, 56.003120094537735, 56.469507068395615, 53.29660892486572, 53.78544129431248, 54.119785353541374, 52.61190086603165, 53.443976417183876, 48.021610379219055, 43.40812213718891, 39.01165924966335, 40.56197226047516, 39.933485984802246, 41.58072419464588, 45.54585702717304, 50.78139089047909, 49.807966724038124, 45.31489782035351, 41.20598830282688, 42.699327170848846, 48.14867176115513, 53.493145778775215, 54.95403818786144, 50.34109711647034, 55.8158091455698, 53.98064821958542, 53.616198375821114, 51.85930944979191, 54.23894315958023, 52.3899319767952, 51.691943630576134, 52.39024356007576, 52.123250886797905, 49.23170484602451, 44.81784649193287, 43.007973209023476, 40.403653755784035, 41.839311718940735, 42.536688297986984, 41.44726015627384, 42.08444036543369, 46.76961936056614, 53.05213004350662, 56.86693534255028, 58.92890229821205, 58.999247923493385, 54.23364244401455, 53.68573844432831, 65.46940013766289, 58.29794995486736, 61.35633364319801, 59.26425330340862, 52.20854490995407, 6.083627454936504, 0.46671467658597976, 0.8066249324474484, 10.401718597859144, 70.20038187503815, 59.70475606620312, 62.49559611082077, 59.527480378746986, 64.88563746213913, 67.49363511800766, 63.448508977890015, 45.41192941367626, 52.003910690546036, 22.658241167664528, 39.6553561091423, 51.5412475168705, 2.7074886672198772, 0.16654622100759298, 0.08044340531341732, 0.07691076010814868, 0.02254877304949332, 0.05414926527009811, 0.048719011538196355, 0.02387176446063677, 0.02870978249120526, 0.1579229993512854, 0.1844126990181394, 0.16151353949680924, 0.15153802087297663, 0.16490678710397333, 0.13700626470381394, 0.293552951188758, 0.1615830638911575, 0.26255094911903143, 0.22677200962789357, 1.0049770795740187, 0.4690457624383271, 20.736522786319256, 73.85934993624687, 49.096758887171745, 38.012453466653824, 48.85337434709072, 66.15331023931503, 62.55419656634331, 73.05054053664207, 66.95486202836037, 66.86718553304672, 67.10731744766235, 64.61329847574234, 65.75943097472191, 35.54804630577564, 1.268131008837372, 20.334407463669777, 0.5522268021013588, 17.707783207297325, 44.25912447273731, 42.069761753082275, 65.39817675948143, 63.88933092355728, 65.68560093641281, 68.06882545351982, 62.15214394032955, 64.35064136981964, 62.05812178552151, 60.74297055602074, 58.3946243673563, 61.668977066874504, 56.73247575759888, 55.89140608906746, 48.910086303949356, 48.394852951169014, 44.94858607649803, 45.667051523923874, 45.30338063836098, 49.383958876132965, 50.915041118860245, 56.6441684961319, 58.78264054656029, 58.5933119058609, 57.79018320143223, 53.40092092752457, 48.14320385456085, 56.956553533673286, 60.17913021147251, 54.77471821010113, 51.936388313770294, 50.540107637643814, 46.68589845299721, 44.326468259096146, 45.644328743219376, 52.68449977040291, 54.16701301932335, 48.77424359321594, 45.89875169098377, 46.73924759030342, 44.95443396270275, 51.841830387711525, 53.5323216766119, 55.86169168353081, 56.06227532029152, 58.3639258146286, 57.74832084774971, 59.02284845709801, 58.44465248286724, 60.14391750097275, 58.185445591807365, 58.99759121239185, 57.153173983097076, 45.57637698948383, 42.40039341151714, 40.73692627251148, 41.018692553043365, 41.37741230428219, 52.909474298357964, 43.21114830672741, 39.32210639119148, 45.12198597192764, 41.12070567905903, 42.0878753811121, 42.21657447516918, 42.48126447200775, 51.59716531634331, 60.82952991127968, 60.14176681637764, 57.98043139278889, 60.48569016158581, 54.758466482162476, 55.79828828573227, 57.96762228012085, 53.31589289009571, 57.34471410512924, 52.042797803878784, 46.7094761878252, 42.565749138593674, 42.314514219760895, 42.79047288000584, 43.178276270627975, 48.39654766023159, 52.4825444072485, 51.541475504636765, 48.111247569322586, 43.86014588177204, 44.825020506978035, 50.858101174235344, 55.424775928258896, 55.943307504057884, 52.71753899753094, 60.348509922623634, 55.464932173490524, 56.416606307029724, 54.5872438699007, 57.43598900735378, 52.495524510741234, 53.68489868938923, 55.12523800134659, 54.91717256605625, 52.108253091573715, 47.81185783445835, 45.76344855129719, 43.06677125394344, 44.29292365908623, 46.533044055104256, 43.82612630724907, 46.28507696092129, 48.85387971997261, 55.29361456632614, 57.52233177423477, 61.81993916630745, 62.49368481338024, 56.45917922258377, 55.559748485684395, 68.92639383673668, 59.913722053170204, 64.29726183414459, 59.20487768948078, 55.7525235414505, 7.218633200973272, 1.5929707093164325, 2.7185318246483803, 10.595493000000715, 77.42758646607399, 67.88355499505997, 68.09969499707222, 67.60560750961304, 68.50659236311913, 70.20742669701576, 65.98664358258247, 53.733524680137634, 48.38424772024155, 33.28211009502411, 53.01975958049297, 62.94424943625927, 3.1108659971505404, 0.5981380166485906, 0.1089714803674724, 0.19104234874248505, 0.12034154642606154, 0.18640889815287665, 0.11969932893407531, 0.11497299856273457, 0.0917710798967164], [0.04584398338920437, 0.060007548963767476, 0.1648878474952653, 0.02702835416130256, 0.06831518345279619, 0.012073971793142846, 0.11225190668483265, 0.024514690703654196, 0.0885147659573704, 0.08522012751200236, 0.2116985450265929, 0.2034096757415682, 4.663260346278548, 53.856991454958916, 47.96624734997749, 39.85167637467384, 25.54061260074377, 53.464126735925674, 64.4521415233612, 56.38839662075043, 58.534061685204506, 55.996979624032974, 59.75701846182346, 52.43813619017601, 54.27872322499752, 38.655352368950844, 0.7655877282377332, 4.034897089004517, 0.6765938317403197, 2.9993574181571603, 14.53287212178111, 59.133612513542175, 61.953638792037964, 60.12905269861221, 57.41398058831692, 57.085712403059006, 53.9284086227417, 53.54988433420658, 49.83783312141895, 49.25581455230713, 46.29559479653835, 45.295146480202675, 41.200288608670235, 40.26023045182228, 38.661253452301025, 40.379498451948166, 41.462603732943535, 41.06051690876484, 39.69955913722515, 42.53680609166622, 42.341963946819305, 48.3541951328516, 53.68912786245346, 54.291718527674675, 54.301176220178604, 58.45052316784859, 47.780973091721535, 42.92065389454365, 55.84900416433811, 53.51941756904125, 48.45807395875454, 45.49369342625141, 43.902639001607895, 43.752934634685516, 42.493332624435425, 42.83769674599171, 43.135460168123245, 41.92684382200241, 42.3501905053854, 40.67011445760727, 41.79980143904686, 49.281732961535454, 51.074480563402176, 51.91131725907326, 51.952047273516655, 53.847248777747154, 55.399993658065796, 51.62743829190731, 54.14960615336895, 53.30993101000786, 55.488642901182175, 54.591378048062325, 48.5007418692112, 38.23788397014141, 41.90575495362282, 40.99430926144123, 43.071369007229805, 39.62800517678261, 45.234228149056435, 43.23785327374935, 41.047719195485115, 43.61261956393719, 43.027576357126236, 43.969226628541946, 44.72856268286705, 43.22230450809002, 47.522070184350014, 53.9973521232605, 54.703722819685936, 55.02410642802715, 53.88459697365761, 53.31908091902733, 52.32521764934063, 54.346967563033104, 52.147235199809074, 51.45904652774334, 49.762878343462944, 45.74083596467972, 41.52103319764137, 38.49320746958256, 36.88594691455364, 39.85959894955158, 42.125911340117455, 46.88693426549435, 43.75656343996525, 39.065821543335915, 40.90474046766758, 42.180491611361504, 44.164748936891556, 50.59752255678177, 52.217835411429405, 48.52184973657131, 51.8936026096344, 51.455071941018105, 53.25915053486824, 49.0450094640255, 47.494236677885056, 45.80977186560631, 49.296552166342735, 46.56569190323353, 44.907419085502625, 41.91974200308323, 40.83100162446499, 39.28076080977917, 39.011378064751625, 36.691876128315926, 38.35963323712349, 39.12279188632965, 41.80183432996273, 40.45966275036335, 45.49746662378311, 49.439302906394005, 53.16108159720898, 55.149332508444786, 58.39087396860123, 56.97248987853527, 60.907767713069916, 58.458118960261345, 60.7800679653883, 54.238783568143845, 37.35889993607998, 2.640263387002051, 1.8289587087929249, 0.5127228156197816, 24.101654514670372, 63.229199945926666, 50.3436353802681, 56.1757942289114, 54.932945519685745, 58.09788689017296, 44.47957344353199, 46.13945737481117, 42.4524962157011, 29.650340974330902, 29.81582399457693, 47.74626575410366, 30.00651106238365, 0.5789762979838997, 0.0321729107236024, 0.04269983393896837, 0.026190736607532017, 0.061951975876581855, 0.09979816401028074, 0.03903413649823051, 0.08697708792169578, 0.08190475346054882, 0.06863919028546661, 0.03192344891431276, 0.07519130042055622, 0.05450867996842135, 0.12056203850079328, 0.003940168699045898, 0.06514182678074576, 0.025100080092670396, 0.14147895126370713, 0.05121054229675792, 0.38265947601757944, 0.12545822421088815, 6.838566195219755, 61.80002823472023, 54.43779408931732, 41.48377239704132, 36.71043433248997, 59.144065752625465, 64.7755041718483, 60.9456592798233, 64.58628192543983, 64.82341200113297, 64.82243925333023, 56.01893484592438, 58.13058413565159, 43.6465897411108, 0.8344127226155251, 2.7942439494654536, 1.9695125729776919, 4.068432189524174, 17.939010299742222, 61.06453210115433, 62.607378512620926, 64.20467600226402, 58.6457034945488, 58.022286146879196, 56.45773150026798, 55.871764943003654, 52.85974636673927, 54.208043217659, 50.058768466115, 48.45365859568119, 44.66982163488865, 43.453214317560196, 40.22812597453594, 43.73716548085213, 42.53332927823067, 43.58332693576813, 42.498074769973755, 44.052901938557625, 43.949030712246895, 51.02668672800064, 55.32375454902649, 57.311994060873985, 54.61515337228775, 57.429852336645126, 48.874987587332726, 47.863542661070824, 58.851755037903786, 55.10603003203869, 50.9011984616518, 48.7275592982769, 44.95913051068783, 46.43110312521458, 44.842788353562355, 45.81034563481808, 46.89704172313213, 45.31389467418194, 43.45607176423073, 43.30451689660549, 43.59679341316223, 50.81525847315788, 52.236648201942444, 55.7736200094223, 55.93742161989212, 56.16312190890312, 55.506068766117096, 54.59309175610542, 55.434697195887566, 57.14297153055668, 57.44130112230778, 55.99941149353981, 50.92286869883537, 39.802928790450096, 40.935803800821304, 39.822341948747635, 42.48094528913498, 41.36101618409157, 47.5732496380806, 44.23055000603199, 39.95294854044914, 43.82768802344799, 41.87933497130871, 42.49564290046692, 43.111339062452316, 42.670908495783806, 49.580415934324265, 56.09202392399311, 56.63313768804073, 57.51934513449669, 56.22155137360096, 54.46563519537449, 54.731016755104065, 55.1453997194767, 53.667092844843864, 53.593654185533524, 50.19688345491886, 47.022738978266716, 43.360601887106895, 41.620454862713814, 38.497459441423416, 41.59568019211292, 45.152901113033295, 47.81298637390137, 45.30461937189102, 41.11046142876148, 42.198320254683495, 44.74351488053799, 46.07284314930439, 52.55394637584686, 54.26893875002861, 51.23445197939873, 54.21391010284424, 52.83285900950432, 55.52669405937195, 51.576410830020905, 49.71803694963455, 47.55594916641712, 48.997173830866814, 48.73729057610035, 46.646270379424095, 45.077174976468086, 42.60526701807976, 41.70411117374897, 41.21686331927776, 39.869565814733505, 42.053228840231895, 42.13894844055176, 44.61477778851986, 41.9970678538084, 47.40547724068165, 50.84462709724903, 55.902429297566414, 58.17727603018284, 62.214137613773346, 58.79934445023537, 63.854030817747116, 60.76065480709076, 62.74600647389889, 55.6015158444643, 39.74417634308338, 3.9457455603405833, 2.4324981356039643, 0.48979909101035446, 26.848394125699997, 69.58913147449493, 54.91582743823528, 62.36679062247276, 61.03025034070015, 65.0784619152546, 51.08460322022438, 50.3761350363493, 49.86873306334019, 34.580397829413414, 24.367820732295513, 55.85438087582588, 36.88941612839699, 0.8772951434366405, 0.08796182883088477, 0.043279299134155735, 0.07918243703898042, 0.046585014133597724, 0.013592315026471624, 0.03445007583650295, 0.06933394441148266, 0.07805948596796952, 0.15080565470270813, 0.1700518446159549, 0.24608171253930777, 0.16667155490722507, 0.1494173042010516, 0.06667344146990217, 0.18474286567652598, 0.13218028616392985, 0.31839901639614254, 0.23699531651800498, 0.5573542113415897, 0.2838595228968188, 8.73026143759489, 74.87261116504669, 65.24445980787277, 48.356110230088234, 40.12161388993263, 65.17877653241158, 72.51052111387253, 68.24401125311852, 71.45765841007233, 68.51438194513321, 69.86747413873672, 63.43622423708439, 63.66298466920853, 48.914372473955154, 1.1252567754127085, 12.141518890857697, 2.0722672529518604, 4.320237077772617, 21.83000721037388, 62.434571385383606, 64.32578310370445, 68.15836384892464, 63.22393722832203, 61.9902840256691, 59.4346209615469, 60.39958298206329, 54.77593034505844, 56.12591430544853, 52.69421964883804, 50.518129616975784, 45.83672761917114, 44.90257054567337, 42.26724475622177, 46.67829506099224, 44.98407997190952, 46.806393787264824, 45.2666138112545, 47.102196514606476, 46.353530287742615, 54.146060943603516, 58.58288526535034, 57.47041895985603, 57.01551876962185, 60.344831719994545, 49.12986271083355, 47.87493824958801, 63.340666964650154, 57.98549272119999, 52.46534653007984, 50.82935951650143, 47.91088432073593, 49.86237220466137, 46.87738537788391, 46.77562303841114, 48.86986166238785, 48.655864745378494, 46.28887675702572, 44.76622626185417, 47.89667688310146, 55.11755481362343, 55.4042000323534, 57.6723363250494, 57.931106239557266, 58.96997429430485, 60.95411382615566, 57.60221488773823, 60.08975140750408, 59.19733889400959, 60.40471650660038, 59.20179605484009, 51.86628207564354, 38.36639687418938, 41.93010784685612, 39.35089744627476, 42.00605817139149, 40.67661210894585, 48.484687730669975, 46.46637663245201, 40.19077017903328, 43.096212074160576, 42.056375071406364, 42.44685731828213, 42.900507375597954, 43.89932557940483, 50.076749101281166, 58.34645815193653, 58.85376513004303, 60.07992133498192, 57.036987617611885, 57.47392237186432, 56.717261373996735, 57.232939302921295, 57.61680990457535, 56.41665570437908, 52.29076869785786, 49.587088376283646, 45.37976033985615, 43.429837971925735, 39.90650363266468, 44.465951174497604, 45.65874516963959, 50.502155274152756, 46.74759954214096, 42.05011300742626, 45.284864231944084, 46.5538327395916, 47.01191335916519, 54.257622957229614, 55.49909994006157, 54.52170118689537, 56.14837110042572, 54.811941012740135, 58.24772045016289, 53.81196387112141, 52.736549377441406, 50.82929491996765, 51.62338010966778, 50.60984909534454, 50.06010979413986, 46.20916463434696, 45.879330933094025, 42.171197310090065, 43.58453147113323, 41.02438844740391, 43.67577977478504, 45.60865245759487, 46.903045400977135, 45.05773141980171, 52.2929497808218, 54.27224077284336, 60.01814804971218, 58.60023133456707, 65.34133940935135, 62.098209634423256, 68.06206941604614, 62.88235455751419, 66.0635058581829, 56.38711228966713, 47.08595998585224, 6.438900316134095, 4.853603057563305, 1.256359121762216, 28.500022999942303, 75.39845734834671, 60.60022361576557, 67.51029342412949, 64.51934471726418, 71.3835471868515, 56.53830237686634, 59.81140114367008, 55.06295934319496, 40.0394356995821, 38.92848551273346, 63.99025350809097, 46.65060594677925, 1.2012176681309938, 0.1750994284520857, 0.15441375406226143, 0.2690633840393275, 0.23802323557902128, 0.19658170931506902, 0.08374839671887457, 0.22619265946559608, 0.2839354594470933], [0.011723437819455285, 0.071025855577318, 0.07542672450654209, 0.08814821179839782, 0.05989909892377909, 0.04567481082631275, 0.10981240047840402, 0.09020511861308478, 0.02272540790727362, 0.021182384552957956, 0.17770047794329002, 0.10860407273867168, 0.7861742516979575, 35.41341193020344, 49.103875905275345, 31.233427226543427, 30.63111014664173, 43.78448814153671, 64.65844765305519, 57.79370181262493, 55.59745766222477, 55.06251856684685, 54.6012195199728, 53.14327955245972, 50.74922561645508, 49.624991342425346, 4.423903590068221, 2.4495991179719567, 1.2990113580599427, 0.2985428849933669, 7.886530486866832, 47.42906637489796, 61.599091216921806, 59.218549355864525, 54.16160210967064, 50.090109184384346, 46.40415497124195, 44.40918602049351, 40.66080495715141, 40.514778792858124, 40.294535011053085, 40.26448242366314, 40.058468878269196, 42.02938511967659, 41.30051963031292, 42.16305434703827, 40.22535592317581, 42.215882912278175, 41.60152047872543, 39.81755040585995, 40.21506987512112, 41.76960825920105, 46.2134014070034, 52.06019327044487, 53.78727279603481, 52.92163744568825, 56.273042410612106, 57.62950502336025, 54.30155999958515, 58.75031188130379, 50.82846276462078, 48.21180157363415, 43.8981856405735, 43.46403993666172, 41.11378625035286, 42.37293988466263, 40.16264408826828, 39.77168686687946, 41.57931067049503, 39.01436470448971, 43.60486038029194, 50.21646000444889, 50.175585597753525, 53.87820951640606, 51.1341867595911, 53.98002125322819, 52.49216929078102, 52.51233100891113, 52.38971158862114, 54.29691664874554, 54.92438457906246, 51.551328375935555, 44.84484404325485, 41.64281286299229, 41.9398695230484, 39.58347536623478, 42.32391111552715, 40.97641982138157, 48.000137731432915, 43.67707170546055, 42.24369741976261, 43.24599243700504, 43.8553087413311, 44.006647020578384, 42.6918263733387, 44.033735767006874, 45.523822009563446, 55.704771503806114, 52.76366852223873, 54.63188387453556, 53.53251926600933, 56.02944888174534, 52.695549577474594, 52.81582832336426, 50.610871240496635, 50.68928003311157, 50.76684147119522, 48.40171158313751, 40.78122429549694, 37.42484539747238, 37.970271930098534, 39.07148703932762, 38.767138570547104, 43.311466723680496, 40.5565195530653, 41.568112671375275, 40.000354796648026, 43.32994893193245, 47.43601620197296, 51.85104489326477, 51.14965572953224, 50.74426308274269, 51.999065950512886, 51.06878846883774, 50.90450048446655, 45.89787393808365, 44.98979866504669, 41.596934124827385, 39.63152378797531, 40.28951548039913, 39.833190366625786, 39.33643542230129, 39.80927065014839, 38.79499867558479, 40.0294878333807, 39.566064700484276, 39.57393407821655, 39.55876149237156, 40.31386077404022, 42.81744763255119, 42.31346547603607, 45.21848179399967, 48.4880543500185, 53.230420276522636, 57.67472639679909, 56.418734192848206, 60.60612849891186, 56.630086451768875, 59.863310158252716, 43.20504583418369, 8.491592444479465, 0.8394388435408473, 1.5089872595854104, 0.1879737462149933, 38.73314939439297, 52.850649654865265, 53.25924552977085, 58.88648137450218, 52.15244472026825, 49.77135568857193, 54.04978550970554, 58.11166875064373, 36.798019632697105, 38.57137307524681, 29.052849635481834, 50.428116247057915, 13.549536187201738, 0.9590120741631836, 0.07855159667087719, 0.08873430808307603, 0.11161603455548175, 0.03132537807687186, 0.057706130464794114, 0.08806557365460321, 0.04169001957052387, 0.13178304419852793, 0.04432282556081191, 0.09479366184677929, 0.05733576908824034, 0.06925257534021512, 0.041971371465479024, 0.05784453729575034, 0.12014556006761268, 0.019229920180805493, 0.07538863006629981, 0.04016541446617339, 0.1378796686185524, 0.11034995288355276, 1.5467814565636218, 45.36403298377991, 56.12470597028732, 33.10307130217552, 38.83302703499794, 55.853423327207565, 69.01766493916512, 66.9745221734047, 61.05502501130104, 60.13481318950653, 60.33100426197052, 59.904727935791016, 56.300218552351, 54.27416726946831, 4.81046112254262, 1.3930075080133975, 3.5042344266548753, 0.06127825421572197, 11.209427006542683, 50.244377106428146, 63.17965820431709, 64.98675763607025, 56.965110674500465, 53.05977523326874, 47.975218668580055, 47.02815368771553, 43.51460002362728, 42.92128466069698, 44.19816814363003, 42.62016601860523, 42.24147453904152, 43.46072271466255, 44.53299857676029, 44.47698578238487, 42.90377140045166, 44.34724934399128, 43.03897574543953, 41.94052308797836, 42.1125740557909, 45.48971123993397, 48.51925827562809, 52.68295705318451, 56.564528569579124, 55.78025825321674, 56.585161462426186, 58.161537274718285, 58.33772622048855, 58.91580060124397, 54.2905405908823, 48.357766941189766, 45.91222956776619, 44.92988348007202, 43.18431414663792, 42.6693619787693, 44.869508519768715, 43.39984618127346, 43.47421959042549, 41.17669187486172, 46.06260649859905, 51.56188040971756, 51.48310303688049, 56.57390646636486, 52.59800501167774, 55.56679330766201, 54.85648602247238, 54.44941006600857, 55.36444276571274, 58.066720962524414, 57.25503511726856, 54.282158240675926, 47.38431617617607, 41.31993278861046, 40.610925033688545, 41.04010060429573, 42.42998622357845, 40.53973965346813, 49.45535324513912, 46.134247854352, 41.418389305472374, 43.316919431090355, 42.28804863989353, 43.35250832140446, 42.035195007920265, 43.73476020991802, 45.945926159620285, 57.50886909663677, 55.36147892475128, 56.8995375931263, 55.99478334188461, 56.99209302663803, 56.90164268016815, 55.007831901311874, 52.96037256717682, 53.29654432833195, 53.13349887728691, 49.883385077118874, 43.98485518991947, 40.36923140287399, 39.45291817188263, 41.08104720711708, 40.624011531472206, 44.97665897011757, 43.153699189424515, 43.43393795192242, 41.72777250409126, 43.59552048146725, 49.04654458165169, 52.781337574124336, 53.71282339096069, 52.33440935611725, 53.108230233192444, 53.63147355616093, 51.71449162065983, 47.52145081758499, 46.67919181287289, 44.73605968058109, 43.09409558773041, 43.06199871003628, 41.86994567513466, 41.2518822401762, 41.16035655140877, 40.80550879240036, 42.420931309461594, 41.036802381277084, 42.12839260697365, 42.25126661360264, 43.20520922541618, 45.84240071475506, 45.95849588513374, 48.383354768157005, 51.209692507982254, 55.18342047929764, 59.165375009179115, 59.498461335897446, 62.273520827293396, 59.059934467077255, 61.14453300833702, 45.54768092930317, 10.49816882237792, 1.9261785107664764, 4.666059846058488, 0.2894473308697343, 43.37505251169205, 57.98657186329365, 59.406988844275475, 66.3430568575859, 58.82673338055611, 54.7698924690485, 57.76956170797348, 58.909413143992424, 47.445219308137894, 36.48185759782791, 25.435932017862797, 61.872140765190125, 16.749953404068947, 0.7930444611702114, 0.08240911702159792, 0.17044662265107036, 0.09451184610952623, 0.020130249213252682, 0.13152747822459787, 0.04858674969000276, 0.044027599215041846, 0.033785456616897136, 0.1747601482202299, 0.22110728546977043, 0.19303195760585368, 0.15920307050691918, 0.09636489980039187, 0.1467658777255565, 0.23940272483741865, 0.21022397180786356, 0.15045556880068034, 0.15500993613386527, 0.22675479180179536, 0.14661729976069182, 1.9813758926466107, 55.557886585593224, 67.16255888342857, 40.44368460774422, 42.39442393183708, 60.558646246790886, 73.25538754463196, 70.67168578505516, 65.85799008607864, 66.2223069369793, 67.14622735977173, 64.70876455307007, 61.81507542729378, 59.193314909935, 7.463971311226487, 3.85356891900301, 4.614628655835986, 0.5925580754410475, 14.370768070220947, 54.853316992521286, 64.75464329123497, 67.33184739947319, 58.12805727124214, 56.803068369627, 50.61446204781532, 49.74310040473938, 45.58205008506775, 46.468926295638084, 46.040263697505, 45.82284316420555, 46.16451323032379, 47.11114503443241, 45.00075727701187, 47.38284185528755, 44.282914996147156, 47.290499210357666, 46.54279813170433, 44.33336868882179, 43.29627513885498, 48.34833204746246, 50.59685379266739, 56.23788669705391, 59.76471684873104, 57.78174385428429, 57.87887044250965, 57.500357553362846, 56.26361511647701, 63.45180720090866, 56.384577825665474, 52.153402268886566, 46.69334225356579, 49.07511904835701, 45.92185065150261, 45.18227353692055, 45.705813243985176, 44.86755162477493, 46.574667021632195, 44.413753375411034, 47.15573564171791, 54.77856360375881, 53.16979832947254, 61.60825252532959, 55.79707235097885, 58.901414573192596, 57.808908596634865, 57.12931886315346, 56.10773608088493, 59.969126880168915, 60.72600446641445, 57.18808650970459, 45.870036631822586, 41.1868829280138, 40.60526333749294, 41.839311718940735, 42.63462424278259, 40.735478550195694, 52.04473949968815, 46.13803245127201, 42.49109074473381, 43.04163180291653, 42.867361754179, 43.09874653816223, 42.79686413705349, 44.18694354593754, 45.22095166146755, 61.15084446966648, 56.80771552026272, 58.93870957195759, 59.19046886265278, 60.884828343987465, 58.36414620280266, 56.9870050996542, 54.17907357215881, 56.34866215288639, 54.317530542612076, 53.593707382678986, 46.58209942281246, 42.830055356025696, 42.77747757732868, 43.46088610589504, 42.55260184407234, 48.00562843680382, 43.65596383810043, 46.117566749453545, 43.329173773527145, 47.98199750483036, 51.67857974767685, 55.29304839670658, 55.700595527887344, 54.40626338124275, 54.78050149977207, 55.42093053460121, 52.553399205207825, 48.674096167087555, 48.72665114700794, 46.69067099690437, 45.55496893823147, 45.604282692074776, 43.836834132671356, 43.55691455304623, 43.12155291438103, 44.71152059733868, 44.91282619535923, 44.78677175939083, 44.25473190844059, 44.584204629063606, 45.479881167411804, 49.698882177472115, 47.266188114881516, 51.68053664267063, 52.52913370728493, 58.31600658595562, 61.11996352672577, 62.96103693544865, 64.17070582509041, 60.31765937805176, 60.60549393296242, 51.73683442175388, 14.881339073181152, 3.645586841739714, 6.841373769566417, 0.20527323824353516, 48.26081894338131, 63.51328410208225, 64.53974962234497, 71.09955802559853, 65.22575721144676, 62.20827452838421, 66.61892205476761, 66.91494137048721, 51.96074120700359, 52.551195323467255, 38.99604968726635, 72.92966902256012, 23.554519973695278, 0.9177118528168648, 0.16034450847655535, 0.33777141594327986, 0.14912330982042477, 0.15009313356131315, 0.1939542542095296, 0.17796864558476955, 0.09802305066841654, 0.1276988719473593], [0.04719829899840988, 0.08100012739305384, 0.03548338288965169, 0.044690036520478316, 0.042331064469181, 0.09132709747063927, 0.05929713923251256, 0.028049241373082623, 0.07120085399947129, 0.08569319470552728, 0.02293058390932856, 0.41345418139826506, 0.09257369034457952, 23.09246476739645, 69.50161457061768, 43.33898104727268, 26.754073686897755, 32.125364765524864, 56.87766216695309, 62.87676125764847, 41.48603327572346, 61.22515708208084, 47.996972501277924, 55.07382296025753, 51.2422301620245, 54.79589827358723, 15.226594246923923, 0.9295831283088773, 2.297300440259278, 0.07317868497921154, 5.329143265262246, 49.560968577861786, 64.68449905514717, 59.24385979771614, 59.58535887300968, 56.9106861948967, 52.415200620889664, 51.83089837431908, 47.58222095668316, 45.25104224681854, 45.31122721731663, 41.999925300478935, 43.5773878544569, 42.51871906220913, 44.898158982396126, 47.97447390854359, 49.547889679670334, 51.219142600893974, 47.87266977131367, 47.227479591965675, 44.050834849476814, 44.84699472784996, 41.85688957571983, 46.562173292040825, 51.93223133683205, 54.0053278952837, 53.68327237665653, 51.31374232470989, 53.82823459804058, 55.05010463297367, 53.57663109898567, 49.36857730150223, 45.32511547207832, 42.45573364198208, 39.626245871186256, 41.322193667292595, 40.94219125807285, 39.853872656822205, 42.153456062078476, 41.759983375668526, 48.359438851475716, 51.566147580742836, 51.90309450030327, 52.50352308154106, 51.1780022084713, 54.5023450255394, 52.29508526623249, 53.84322479367256, 51.538131684064865, 53.384429812431335, 51.92545250058174, 47.24946901202202, 43.92535798251629, 43.270862102508545, 42.913799062371254, 42.728832587599754, 44.82682541012764, 41.22098229825497, 45.277944803237915, 46.04871824383736, 41.39343984425068, 44.74820762872696, 43.253918811678886, 44.61722105741501, 41.00093610584736, 43.62303860485554, 43.64202618598938, 51.647345423698425, 53.57658930122852, 56.942137107253075, 54.82555568218231, 55.082049518823624, 53.17543722689152, 53.28079417347908, 52.06893280148506, 51.2580107152462, 49.87367659807205, 50.24918384850025, 46.092545092105865, 39.89610739052296, 37.00538210570812, 37.2356953471899, 40.28984226286411, 40.23860961198807, 39.2594363540411, 38.79243761301041, 40.48346847295761, 42.34432741999626, 44.81483705341816, 51.84843823313713, 52.07308977842331, 48.99213150143623, 53.03839758038521, 50.586997121572495, 49.51037049293518, 47.004602551460266, 44.08567517995834, 40.833133310079575, 39.505085572600365, 40.84043271839619, 41.35536588728428, 40.04384346306324, 39.76505622267723, 38.679595068097115, 40.0105344504118, 41.09938122332096, 41.12818367779255, 41.07355020940304, 41.638507694005966, 44.206200912594795, 45.42936287820339, 45.23927427828312, 46.4854896068573, 49.875652492046356, 56.99378773570061, 58.5494926571846, 58.19485768675804, 54.138309359550476, 53.535832688212395, 21.214495338499546, 6.2947659753263, 0.9510345209855586, 3.846708149649203, 1.3769562193192542, 47.25735738873482, 60.194029211997986, 51.27374567091465, 51.655902564525604, 55.92233642935753, 60.33299535512924, 57.00444616377354, 45.80285623669624, 33.914122581481934, 24.671373143792152, 37.98650465905666, 42.047449350357056, 3.1921547977253795, 0.2502948552137241, 0.120614419283811, 0.1551648075110279, 0.08170237721060403, 0.05114906278322451, 0.023960746111697517, 0.025239371934731025, 0.03956718406698201, 0.06024698064720724, 0.0298075395039632, 0.0643579926691018, 0.036204164134687744, 0.11024965162505396, 0.08251483595813625, 0.0463168687565485, 0.04923970976960845, 0.01204139058245346, 0.06665822744253092, 0.06831841921666637, 0.05192583907046355, 0.4245516937226057, 0.1992467764648609, 29.76335071027279, 76.28549695014954, 38.685940727591515, 35.60051389038563, 44.58016164600849, 60.8183129131794, 69.39682379364967, 49.8653132468462, 65.65973952412605, 51.45314164459705, 64.78874266147614, 54.68006148934364, 61.780763268470764, 16.180371567606926, 0.551324172411114, 6.770167965441942, 0.6139642267953604, 7.416212623938918, 50.537022203207016, 65.76837569475174, 62.02168934047222, 62.33920410275459, 59.54917721450329, 54.415595680475235, 54.07938972115517, 50.078755393624306, 48.59266273677349, 45.7488801330328, 45.4964292794466, 46.505218148231506, 45.31262554228306, 47.13948391377926, 48.392014503479004, 51.14449180662632, 53.88908073306084, 49.73509043455124, 48.79543885588646, 45.684143006801605, 46.44177295267582, 45.35266399383545, 49.04958061873913, 52.744737938046455, 55.01518830657005, 56.66811481118202, 53.98836560547352, 55.80338381230831, 57.934396862983704, 54.50093150138855, 48.31079386174679, 46.794534623622894, 43.7806199491024, 41.57872550189495, 43.189732655882835, 42.28767246007919, 42.390532940626144, 42.887466475367546, 43.87968063354492, 51.38435013592243, 52.783678248524666, 53.420512676239014, 55.34481681883335, 54.04926113784313, 55.25196500122547, 56.012072414159775, 55.70414453744888, 54.71128821372986, 54.453730434179306, 53.99929761886597, 48.815345987677574, 44.31211642920971, 42.11849793791771, 40.80281853675842, 42.91148878633976, 43.77943441271782, 42.299182042479515, 49.93814013898373, 45.92689298093319, 40.96053667366505, 44.29570131003857, 41.996281296014786, 44.23968471586704, 42.70723834633827, 42.353230342268944, 45.29045753180981, 54.08128201961517, 56.579526364803314, 58.040532767772675, 55.94190537929535, 55.85443027317524, 54.122889786958694, 54.91822510957718, 53.901692256331444, 52.542406395077705, 51.262988448143005, 52.74976886808872, 48.34770888090134, 41.790089160203934, 39.16272774338722, 40.48496939241886, 42.66882620751858, 42.26878747344017, 40.76554253697395, 39.285423159599304, 42.397049590945244, 43.07815544307232, 46.79970994591713, 51.69174984097481, 53.475070148706436, 51.167400777339935, 53.59678141772747, 51.267601400613785, 52.4330710619688, 49.98418226838112, 45.60727693140507, 43.651738464832306, 42.33336120843887, 41.88797950744629, 40.170521065592766, 41.37410648167133, 40.526820346713066, 41.00374035537243, 41.69238120317459, 43.910614773631096, 43.40787515044212, 44.93837222456932, 45.42168729007244, 45.937935188412666, 45.66465765237808, 49.712413251399994, 47.92047880589962, 53.373007625341415, 57.860240042209625, 60.30426889657974, 60.261961966753006, 54.50130768120289, 54.35246206820011, 24.92765039205551, 8.328051120042801, 2.2444177279248834, 4.260967383161187, 1.2012483039870858, 52.3955936729908, 61.67165972292423, 57.66320921480656, 54.32819277048111, 63.68274360895157, 62.429726645350456, 64.11432445049286, 50.204509645700455, 48.898166343569756, 29.041623137891293, 36.367282345891, 55.03166422247887, 4.306059088557959, 0.20936125481966883, 0.14896582608344033, 0.017324979235127103, 0.11539311351953074, 0.0243066054827068, 0.0405703599244589, 0.07012283254880458, 0.03993562328105327, 0.0576609188283328, 0.14544918900355697, 0.150649655261077, 0.10467470507137477, 0.26004320243373513, 0.17305123445112258, 0.2745698229409754, 0.1865720222122036, 0.1167099506710656, 0.1574746976257302, 0.27071481104940176, 0.12370834389002994, 0.5654449865687639, 0.388622751343064, 35.210761204361916, 91.81895703077316, 56.0415094345808, 34.135346710681915, 42.83428452908993, 67.45949015021324, 74.42191734910011, 55.80758638679981, 71.40032708644867, 60.58548040688038, 67.733174264431, 62.378224208950996, 64.34061750769615, 21.504089199006557, 1.7083291942253709, 9.376771096140146, 0.40264471143018454, 9.171940237283707, 56.650187373161316, 64.8241339623928, 65.23312121629715, 63.57822261750698, 64.26414281129837, 56.014371290802956, 59.3145702034235, 52.780402824282646, 51.26912511885166, 47.99641013145447, 48.404139652848244, 48.84507179260254, 46.985915154218674, 50.35270169377327, 53.0780104547739, 53.543671667575836, 56.332330629229546, 52.645179480314255, 51.612683683633804, 49.408414363861084, 50.4196123033762, 46.733684688806534, 50.03022059798241, 56.35228715837002, 58.82459029555321, 58.486708626151085, 54.80039723217487, 57.00395978987217, 58.3827044069767, 55.83755537867546, 51.409288197755814, 46.97226248681545, 46.59992426633835, 43.30206602811813, 46.82776004076004, 45.28159640729427, 46.334166526794434, 45.8408048003912, 48.65618392825127, 52.560911402106285, 56.38061083853245, 56.41338028013706, 59.317712634801865, 56.706637144088745, 57.931850999593735, 58.225457444787025, 58.98623742163181, 56.61407791078091, 58.38145047426224, 57.709376737475395, 51.210851445794106, 44.29783299565315, 43.593571186065674, 41.33326627314091, 44.29138474166393, 45.85191920399666, 43.43326158821583, 50.54274469614029, 46.658756509423256, 40.67807503044605, 42.26613141596317, 42.27534592151642, 44.08301532268524, 40.91366998851299, 42.89249740540981, 44.329648688435555, 54.40907523036003, 57.356789857149124, 59.34520795941353, 58.73421974480152, 59.508758783340454, 56.02742359042168, 56.295886784791946, 57.2384338080883, 56.033947840332985, 54.105209335684776, 55.524178594350815, 50.111794620752335, 43.22938732802868, 41.62063725292683, 40.846117213368416, 45.115317329764366, 44.742963910102844, 43.070194870233536, 41.13546408712864, 44.81728412210941, 46.05739317834377, 47.669722661376, 55.67098751664162, 56.20947942137718, 54.393085688352585, 57.29131177067757, 54.39420662820339, 52.62174613773823, 51.68957255780697, 46.83943681418896, 46.477639228105545, 43.23241576552391, 46.013463735580444, 43.2573614269495, 45.380649492144585, 43.05922485888004, 42.75727026164532, 42.58801594376564, 47.50501669943333, 44.96053643524647, 46.991318464279175, 45.77747739851475, 49.76045787334442, 48.83035898208618, 53.189925849437714, 50.22654466331005, 56.00327588617802, 61.112405732274055, 65.88759049773216, 59.32444587349892, 57.89158076047897, 54.62813727557659, 33.30686576664448, 10.742409266531467, 4.572988590225577, 7.66020655632019, 0.7641437463462353, 59.765587002038956, 67.54382282495499, 63.344595953822136, 61.2023963034153, 69.0388298034668, 71.13457694649696, 69.73349332809448, 59.24531131982803, 48.533454313874245, 33.9700023829937, 49.427082762122154, 65.40367886424065, 5.764230843633413, 0.5184359278064221, 0.2565550192957744, 0.375546554569155, 0.13540199375711381, 0.12045540672261268, 0.24373231048230082, 0.19574005447793752, 0.17659757228102535, 0.17639747442444786], [0.07477713748812675, 0.01451853016988025, 0.02413084079307737, 0.03511077651637606, 0.08301558526000008, 0.06617671460844576, 0.05504443637619261, 0.10730973008321598, 0.054442795808427036, 0.1411202416056767, 0.037394279570435174, 0.3373815509257838, 0.1359687719377689, 7.9512961115688086, 54.817454516887665, 38.714701384305954, 34.9372822791338, 30.84855157881975, 45.53105302155018, 74.1658490896225, 41.506062000989914, 43.32403264939785, 56.884718388319016, 60.200538262724876, 54.220373556017876, 55.20778477191925, 23.362444080412388, 0.3152331034652889, 3.384123109281063, 0.7018856902141124, 4.935206528753042, 35.782991498708725, 63.56818735599518, 57.113040536642075, 59.95342992246151, 56.83178722858429, 56.81316062808037, 54.73566770553589, 55.393416211009026, 52.76367612183094, 54.26325425505638, 48.047019615769386, 47.199532091617584, 46.62938788533211, 50.38096457719803, 49.527309983968735, 53.81412975490093, 55.00004991889, 56.00492499768734, 53.09194430708885, 51.32151670753956, 44.84835505485535, 47.669650465250015, 44.04917053878307, 50.8541189879179, 50.242017433047295, 57.14327171444893, 53.32652851939201, 53.97338680922985, 57.02545143663883, 54.955352917313576, 51.29553750157356, 46.30555406212807, 44.00512710213661, 42.472281754016876, 41.62182278931141, 39.95558179914951, 40.41473016142845, 39.57747928798199, 43.591891676187515, 49.447347074747086, 52.28929057717323, 52.185343354940414, 52.195059433579445, 52.56196394562721, 51.91188342869282, 54.043063670396805, 54.04753603041172, 53.593619987368584, 52.64338217675686, 50.895711556077, 45.71289226412773, 43.1166435778141, 42.10912004113197, 43.08710016310215, 44.33366887271404, 42.82486483454704, 42.550538554787636, 49.94656428694725, 45.62971472740173, 42.20721557736397, 43.3176451921463, 42.8857147693634, 41.22187905013561, 42.42301359772682, 42.83870369195938, 44.30054225027561, 50.19181452691555, 53.378160148859024, 54.675775319337845, 56.88280329108238, 54.86511155962944, 53.90022173523903, 51.922462061047554, 52.90497533977032, 52.08861194550991, 50.27539104223251, 51.12988539040089, 49.385022819042206, 45.54948203265667, 39.19755667448044, 37.41475693881512, 37.80480980873108, 38.983156979084015, 39.83555383980274, 42.5529970228672, 39.52614784240723, 43.39100785553455, 43.32163877785206, 48.084603399038315, 50.44823996722698, 50.48851020634174, 52.25304812192917, 50.705584958195686, 54.05901521444321, 48.890688344836235, 43.2799968123436, 42.36032456159592, 39.659680277109146, 40.368349850177765, 39.726609885692596, 40.12876510620117, 40.3745511174202, 44.761434718966484, 44.94930803775787, 45.595166981220245, 46.223068088293076, 47.062431648373604, 44.52606774866581, 47.4382808804512, 44.628107473254204, 48.4372852742672, 47.22875252366066, 51.327858567237854, 52.581456899642944, 60.33952720463276, 54.38233986496925, 54.82392556965351, 43.01942579448223, 14.139442183077335, 11.2086271494627, 4.218435315415263, 1.8844093708321452, 5.446739355102181, 62.27144613862038, 52.20443733036518, 53.26622195541859, 51.772423312067986, 57.2477775067091, 53.66760961711407, 50.6465133279562, 46.12606689333916, 28.980381824076176, 28.838394843041897, 44.66340757906437, 26.444004625082016, 0.5900017032399774, 0.1418991107493639, 0.09332150802947581, 0.05566204054048285, 0.019153048524458427, 0.03195573233824689, 0.1162771598319523, 0.03444761190621648, 0.051091486966470256, 0.027608054988377262, 0.11583902552956715, 0.06981500453548506, 0.03688354467158206, 0.09135791886365041, 0.01948435809026705, 0.04590467251546215, 0.02015479203691939, 0.0719293461588677, 0.01506786880781874, 0.04433635120221879, 0.097553753585089, 0.3771134954877198, 0.14060790737858042, 12.359378300607204, 63.56806196272373, 39.10351172089577, 27.305122017860413, 45.617916360497475, 52.706037014722824, 78.32141250371933, 45.974242240190506, 54.39002685248852, 62.3939211666584, 64.66382816433907, 60.28143972158432, 59.63898919522762, 27.984732650220394, 0.3437501279404387, 6.467259619385004, 1.0050413198769093, 6.001246925443411, 38.45914989709854, 61.823374181985855, 60.6396920979023, 62.080153003335, 61.703065037727356, 60.68781651556492, 57.337855473160744, 57.56560765206814, 54.468325451016426, 54.53744374215603, 50.96625477075577, 50.09505271911621, 48.94430726766586, 52.544173300266266, 54.824092760682106, 57.93767608702183, 58.01225088536739, 56.429787799715996, 55.52773900330067, 52.25218556821346, 46.57292291522026, 49.67876225709915, 47.10411161184311, 52.02080078423023, 53.060998767614365, 59.28116999566555, 53.66611249744892, 55.04063554108143, 59.09819461405277, 55.86335979402065, 53.86274054646492, 47.539469450712204, 44.91782672703266, 44.98866632580757, 43.73522758483887, 42.62709304690361, 41.24766826629639, 42.424157336354256, 45.28347730636597, 51.844007670879364, 53.6158411949873, 54.33125160634518, 54.49341930449009, 55.14793038368225, 53.38818021118641, 55.90954251587391, 55.98690256476402, 54.550458043813705, 54.46590878069401, 52.9692754894495, 46.86137683689594, 43.278271704912186, 41.61164313554764, 42.02238209545612, 43.5459141433239, 43.33807289600372, 42.23860949277878, 49.86849747598171, 47.75903306901455, 41.70661523938179, 43.023715764284134, 40.93217119574547, 40.70118919014931, 43.851478546857834, 42.91797883808613, 43.41976471245289, 52.10423290729523, 54.16758678853512, 57.89253830909729, 57.37804591655731, 56.70279935002327, 55.36836415529251, 55.175228118896484, 53.84599104523659, 53.76492999494076, 52.18168795108795, 52.34085761010647, 50.14343172311783, 45.58079235255718, 40.40434151887894, 39.77453291416168, 39.78691644966602, 41.790020763874054, 40.85826516151428, 42.16099865734577, 42.61923886835575, 45.28352290391922, 45.11482335627079, 49.22916278243065, 52.231127098202705, 54.32387240231037, 53.49898226559162, 53.04719790816307, 54.63973805308342, 50.10002285242081, 44.60085913538933, 42.802704423666, 41.01183772087097, 41.97205379605293, 40.27511425316334, 42.68027499318123, 42.985869795084, 47.27491244673729, 46.54188998043537, 49.17041413486004, 47.89572313427925, 49.34434600174427, 47.90513522922993, 48.987081572413445, 46.451451033353806, 51.786357164382935, 50.977296978235245, 53.70645493268967, 55.39831414818764, 63.03825259208679, 56.418578401207924, 56.07547961175442, 42.82661274075508, 17.832517214119434, 12.236662935465574, 5.865579480305314, 1.316569265909493, 5.479120742529631, 68.56125622987747, 58.47949281334877, 58.633722737431526, 56.24359019100666, 63.998651057481766, 60.23683771491051, 57.57471576333046, 53.795370161533356, 37.007707580924034, 22.244526967406273, 50.385961309075356, 32.020912170410156, 0.6509018666110933, 0.08496183785609901, 0.07716815176536329, 0.03612518106820062, 0.03927358673536219, 0.02773929081740789, 0.10982091291225515, 0.03804302425123751, 0.00299880029160704, 0.011140743354189908, 0.25850330537650734, 0.10777553165098652, 0.11985403703874908, 0.18615947716170922, 0.2111885856720619, 0.15138528688112274, 0.12490614055423066, 0.16886259749298915, 0.1233104859420564, 0.2063298932625912, 0.20858030766248703, 0.7266803097445518, 0.4434129613218829, 12.901586405932903, 75.78281432390213, 53.22199992835522, 41.12116165459156, 45.74368201196194, 59.05252106487751, 84.13380861282349, 55.17048217356205, 55.31504921615124, 69.53467279672623, 69.46864753961563, 64.57409977912903, 64.56874206662178, 32.46106535196304, 0.27391723764594644, 12.909006457775831, 1.4461880293674767, 8.25650380924344, 43.53660084307194, 61.129710003733635, 61.56702473759651, 62.87043459713459, 64.36505779623985, 61.93248152732849, 61.47855408489704, 60.80120623111725, 57.017958238720894, 58.94410528242588, 55.60630738735199, 52.848787754774094, 51.81058466434479, 56.9073461741209, 56.96991741657257, 59.77238103747368, 60.357720628380775, 58.32237884402275, 57.94350877404213, 55.79495206475258, 47.24600739777088, 53.53397838771343, 50.175312012434006, 55.96730321645737, 55.27252569794655, 62.3987203091383, 54.647622630000114, 57.73388162255287, 61.301111206412315, 59.62249048054218, 56.85893677175045, 50.59980243444443, 47.706565484404564, 47.536596804857254, 44.71801444888115, 45.516256615519524, 45.92932105064392, 45.000742077827454, 48.30118417739868, 53.900244534015656, 57.45964273810387, 56.86660096049309, 58.32862190902233, 59.10446047782898, 55.69314032793045, 60.218340307474136, 60.402911603450775, 56.725373938679695, 56.56033359467983, 55.32445751130581, 47.01167777180672, 44.303760677576065, 41.40312932431698, 42.0199616253376, 44.64385002851486, 43.50068137049675, 44.76351320743561, 53.977695778012276, 49.50487218797207, 43.10853861272335, 43.48239295184612, 42.37052321434021, 41.47103168070316, 43.67127321660519, 42.19485104084015, 43.634605184197426, 52.60685853660107, 57.33763508498669, 58.79486829042435, 59.44070063531399, 58.99747721850872, 58.08613792061806, 57.42241233587265, 57.80031345784664, 57.49338112771511, 53.22268769145012, 54.716550931334496, 53.61964859068394, 50.319761261343956, 45.277051851153374, 42.852177768945694, 42.65520393848419, 43.85759621858597, 42.62928932905197, 46.2508711963892, 44.411078318953514, 47.71117843687534, 46.51844523847103, 50.82644887268543, 54.83576953411102, 54.603837579488754, 55.66156022250652, 54.33090202510357, 57.941806465387344, 54.231571555137634, 47.61701188981533, 44.90716449916363, 42.75383524596691, 44.93348568677902, 44.29642707109451, 45.619588270783424, 44.83518876135349, 50.66129833459854, 48.6394078284502, 50.92654690146446, 50.23921698331833, 52.46498554944992, 51.07886552810669, 54.8050481826067, 49.46228787302971, 54.474944695830345, 52.83175706863403, 58.33942852914333, 56.65998324751854, 67.5223995745182, 56.28090038895607, 56.80310256779194, 43.79497177898884, 26.496039032936096, 14.591694865375757, 7.634588805958629, 6.608906518667936, 6.3161184545606375, 74.90621656179428, 62.5017935782671, 64.5757032930851, 61.08764626085758, 68.39180812239647, 66.99411392211914, 63.408721312880516, 60.72487212717533, 39.59383361041546, 38.426661640405655, 60.183439180254936, 43.247185572981834, 0.8283077564556152, 0.2790290320990607, 0.2158641308778897, 0.14165607222821563, 0.24755757709499449, 0.17778497887775302, 0.2175323007395491, 0.2536598715232685, 0.12254658591700718, 0.07477824328816496], [0.08528061996912584, 0.05410669939010404, 0.0737815463799052, 0.045617862124345265, 0.0644200287933927, 0.10625372815411538, 0.04526391705439892, 0.10165011190110818, 0.10157744080061093, 0.08891082790796645, 0.05296982933941763, 0.2434787928359583, 0.13046291191130877, 0.9088836796581745, 49.50050622224808, 54.651730209589005, 41.90425403416157, 27.041019089519978, 42.76650756597519, 65.79347714781761, 65.62833040952682, 54.59650777280331, 56.273479387164116, 56.64861425757408, 51.69699735939503, 53.561139330267906, 32.90286764502525, 1.1006104666739702, 6.531642889603972, 2.5024827802553773, 2.4007344525307417, 25.438648872077465, 51.22751735150814, 53.466896787285805, 60.6956022977829, 58.659147173166275, 57.13131755590439, 59.688477739691734, 59.04853507876396, 59.81199771165848, 55.976468324661255, 52.72685989737511, 51.70918710529804, 52.4761151522398, 52.253063321113586, 53.909668028354645, 53.62435273826122, 55.86972825229168, 55.39971247315407, 54.65991497039795, 57.22502052783966, 50.82992948591709, 50.1093665510416, 49.58373315632343, 48.99890273809433, 53.95208515226841, 52.219978496432304, 54.911731258034706, 49.21019800007343, 50.049401968717575, 56.01429529488087, 52.81636409461498, 46.52338497340679, 44.75052930414677, 41.630676314234734, 39.848188161849976, 40.711228251457214, 38.35210584104061, 38.281399235129356, 43.302206620574, 52.252538949251175, 52.337278202176094, 52.22830004990101, 51.91862426698208, 53.465251475572586, 52.7096164226532, 53.83774168789387, 54.398530796170235, 55.523517429828644, 53.18368658423424, 44.34301257133484, 40.890073254704475, 41.72342173755169, 43.406701013445854, 39.67073768377304, 45.17886132001877, 42.72117219865322, 48.850117921829224, 51.73402637243271, 50.271971225738525, 44.49408486485481, 42.24827237427235, 43.64883542060852, 42.83377915620804, 42.00849764049053, 42.37455479800701, 43.03882755339146, 44.58736225962639, 51.087574660778046, 55.53628854453564, 55.65070800483227, 54.3046910315752, 54.17715087532997, 54.235542342066765, 53.06109756231308, 52.30365380644798, 50.54535895586014, 51.629911959171295, 51.59118823707104, 46.25231511890888, 41.18425726890564, 38.30623470246792, 35.286145359277725, 38.68990771472454, 38.87124918401241, 39.48977239429951, 38.858679458498955, 41.272389739751816, 44.07823517918587, 48.60959082841873, 52.51960761845112, 49.106756150722504, 50.095432698726654, 49.44182597100735, 51.474177315831184, 49.81610208749771, 45.239897444844246, 42.60913521051407, 41.1021588742733, 40.48967353999615, 39.50736545026302, 40.12779615819454, 42.698476016521454, 48.63497346639633, 51.691977828741074, 51.0842764377594, 49.8321296274662, 51.15592159330845, 49.44870740175247, 50.345288291573524, 48.94005909562111, 51.02534539997578, 50.16032561659813, 53.466098830103874, 53.96001912653446, 62.3114275932312, 51.08751766383648, 57.628786861896515, 35.90622268617153, 4.773737518116832, 0.6907992507331073, 2.0004577562212944, 0.6867448682896793, 10.863751955330372, 59.96014416217804, 49.254370629787445, 56.32438525557518, 53.52568343281746, 57.67877697944641, 54.149302169680595, 53.480549454689026, 36.41182355582714, 35.82291975617409, 42.31890298426151, 45.83243004977703, 8.61104378476739, 0.5690722481813282, 0.16491575224790722, 0.1956411261926405, 0.1230824388039764, 0.028687666490441188, 0.09185001472360454, 0.09475713333813474, 0.03897685382980853, 0.022578848584089428, 0.018410772827337496, 0.05178178078494966, 0.11974367967923172, 0.03860932003590278, 0.06339213941828348, 0.039790681839804165, 0.09157067775959149, 0.09663924953201786, 0.09054423557245173, 0.04705621482571587, 0.08988154222606681, 0.044562093971762806, 0.40954312251415104, 0.10367898779804818, 2.194057130254805, 55.72505101561546, 59.92230959236622, 34.242158979177475, 37.42313928902149, 51.32730379700661, 69.97459799051285, 69.07682776451111, 55.753530487418175, 64.52757507562637, 61.618128195405006, 59.210892766714096, 57.85629965364933, 39.236109405756, 0.7035860989708453, 2.7888776874169707, 1.2217790773138404, 2.9582676105201244, 31.294157467782497, 50.097002014517784, 54.73052658140659, 60.483474880456924, 60.991237834095955, 61.33871778845787, 59.90375138819218, 62.412977144122124, 63.75801756978035, 58.73087212443352, 54.747378677129745, 54.69649560749531, 55.41120685636997, 55.48431113362312, 57.41581588983536, 56.37819416821003, 58.6776065826416, 57.449892461299896, 56.03303208947182, 57.849357426166534, 54.242685958743095, 51.824157536029816, 51.23579330742359, 50.13981431722641, 56.40199229121208, 55.35519406199455, 55.149264112114906, 51.327216401696205, 52.39118970930576, 56.694246008992195, 54.24885682761669, 49.30856332182884, 46.293307319283485, 42.832601219415665, 40.891771763563156, 41.934128031134605, 40.66768258810043, 41.69768191874027, 45.610791742801666, 54.84496884047985, 53.93885426223278, 55.01131631433964, 53.80677714943886, 55.62352806329727, 56.14368595182896, 57.027442529797554, 56.0872133821249, 57.37234242260456, 55.41206181049347, 47.75636941194534, 41.43581137061119, 42.02075198292732, 43.2944056391716, 40.282007083296776, 43.756141662597656, 42.889541164040565, 48.91352891921997, 53.43212865293026, 52.4533049762249, 44.18336793780327, 42.55955167114735, 43.364846259355545, 43.61196979880333, 41.520915403962135, 41.96787402033806, 43.44534873962402, 46.37017719447613, 52.61109910905361, 59.692475125193596, 57.894103825092316, 56.272681429982185, 54.85869750380516, 53.282264694571495, 54.65370990335941, 53.70349109172821, 52.87290886044502, 52.63944558799267, 50.733992233872414, 49.480652287602425, 43.11029031872749, 41.599738374352455, 38.14350463449955, 40.879224836826324, 41.77471898496151, 40.824241787195206, 41.03361055254936, 41.48649305105209, 47.21110627055168, 51.20189532637596, 55.308752954006195, 50.973121002316475, 52.72006966173649, 50.72925388813019, 54.31689977645874, 51.92792236804962, 48.4612999856472, 45.859632790088654, 42.954574674367905, 42.16028429567814, 41.03618681430817, 42.349286153912544, 44.193973168730736, 50.116297379136086, 54.02939960360527, 54.24906961619854, 52.02508695423603, 53.670809045434, 51.68972074985504, 51.83128975331783, 51.09107807278633, 54.66134749352932, 52.519923001527786, 56.08402915298939, 56.33881688117981, 62.99976445734501, 53.04037727415562, 56.12911753356457, 36.17123946547508, 6.5462996531277895, 0.8685816172510386, 2.1487773349508643, 0.36524658382404596, 13.023729901760817, 65.38964241743088, 53.93812470138073, 60.910571962594986, 58.85867066681385, 62.55224347114563, 62.786128520965576, 57.68688574433327, 46.96407772600651, 39.451303258538246, 36.42903283238411, 57.125697657465935, 10.469940137118101, 0.3680168429855257, 0.12484813429182395, 0.19660997029859573, 0.06248048521229066, 0.06397735254722647, 0.0435185304377228, 0.01623109808861045, 0.08953547876444645, 0.025168103493342642, 0.04256237705703825, 0.20942034461768344, 0.17785385018214583, 0.11151548096677288, 0.13352323207072914, 0.16737257275963202, 0.22554166236659512, 0.2314885807572864, 0.17114602262154222, 0.14665743510704488, 0.18254342197906226, 0.20074671629117802, 0.4771132639143616, 0.22578977717785165, 2.7836608048528433, 63.552441000938416, 73.35304230451584, 51.85511827468872, 37.10762321949005, 53.657874539494514, 76.52801513671875, 77.90440768003464, 64.27228197455406, 69.93215426802635, 66.58403992652893, 65.2615436911583, 64.4222067296505, 46.354867815971375, 1.9204274006187916, 13.843779098242521, 5.28473979793489, 5.269205281510949, 37.56726175546646, 52.44849443435669, 55.298094525933266, 63.73564437031746, 64.44657862186432, 62.807874754071236, 62.736066207289696, 65.66006630659103, 65.55572390556335, 60.25361381471157, 57.8571318089962, 56.989687755703926, 58.358096927404404, 58.90662029385567, 60.582527965307236, 58.89039136469364, 61.55430682003498, 60.29411964118481, 58.99215370416641, 61.296068876981735, 57.04508878290653, 54.966277331113815, 53.91059137880802, 52.998442724347115, 58.81811924278736, 58.614290580153465, 57.248066291213036, 52.039925158023834, 53.6004102230072, 58.3807323127985, 56.99693776667118, 51.132663041353226, 50.433853939175606, 45.58651864528656, 43.90900366008282, 44.9367269128561, 43.027488961815834, 45.210114642977715, 47.324275597929955, 57.10835158824921, 57.64636091887951, 57.45453581213951, 56.01983919739723, 59.22406665980816, 57.77441404759884, 59.91944834589958, 58.906095921993256, 61.27578556537628, 57.11706452071667, 46.91368483006954, 40.9598945081234, 43.186354637145996, 45.68657107651234, 40.16001082956791, 44.7289502620697, 44.05517801642418, 51.0311096906662, 57.741070836782455, 54.4538976252079, 44.17771764099598, 42.6816201210022, 42.90273405611515, 44.373509734869, 41.621423810720444, 42.09349147975445, 43.80395069718361, 45.9237315505743, 53.67995135486126, 61.593756303191185, 59.67875026166439, 58.73003616929054, 57.53395535051823, 58.3643551915884, 57.3913300037384, 55.21315008401871, 55.096944719552994, 54.761270731687546, 52.953559532761574, 51.1265529692173, 46.60109840333462, 43.53429056704044, 38.70194926857948, 42.784400805830956, 43.000195026397705, 44.287535548210144, 43.02807033061981, 42.9501137137413, 48.91284115612507, 53.014238476753235, 56.67028449475765, 53.75948868691921, 52.911678180098534, 52.08445876836777, 56.5337198227644, 54.50394093990326, 50.569787845015526, 47.31991343200207, 46.37580469250679, 44.12222921848297, 42.85429805517197, 43.50644186139107, 47.148690819740295, 51.27990134060383, 57.26378224790096, 55.65963372588158, 54.95547451078892, 55.43808661401272, 54.95814576745033, 55.01749478280544, 53.46373915672302, 56.323617696762085, 55.00423349440098, 57.228941917419434, 59.45294737815857, 65.82945361733437, 54.984079375863075, 54.196723625063896, 39.95980717241764, 11.266091465950012, 1.7214913317002356, 7.700545666739345, 1.5217853290960193, 12.751503009349108, 72.05296486616135, 59.25564296543598, 67.40914285182953, 63.8036835193634, 70.87190464138985, 66.67950600385666, 66.79038405418396, 49.831711649894714, 51.10582508146763, 52.90437497198582, 65.7517021894455, 16.18687491863966, 0.7174910965841264, 0.3054638870526105, 0.4535470175324008, 0.2129171069827862, 0.19780631235335022, 0.13189760211389512, 0.18282754579558969, 0.1609155020560138, 0.15607552661094815, 0.13155713444575667], [0.021609785544569604, 0.06941589235793799, 0.04447142579010688, 0.010269703179801581, 0.045473518111975864, 0.013464541316352552, 0.064714008331066, 0.05990637197101023, 0.045239173850859515, 0.11867171415360644, 0.010032873651653063, 0.06174235255457461, 0.4412531037814915, 0.1283846312435344, 22.464018389582634, 62.24175453186035, 33.021162897348404, 29.917753525078297, 35.06114423274994, 59.85243134200573, 67.83015266060829, 56.911643743515015, 55.12772686779499, 59.682458862662315, 52.75570794939995, 53.954817205667496, 50.00271387398243, 3.564614849165082, 2.18790668528527, 1.5569049445912242, 0.03349373691889923, 11.525713484734297, 56.99959762394428, 56.840477362275124, 62.84821718931198, 58.566774129867554, 58.68875898420811, 58.4276407957077, 56.69462598860264, 56.405913680791855, 52.57623217999935, 57.21328675746918, 55.27460798621178, 54.44754436612129, 56.57748967409134, 56.484299674630165, 57.25513391196728, 50.17890281975269, 52.17759557068348, 57.0135048776865, 56.600725427269936, 57.427287474274635, 54.41538289189339, 51.73895850777626, 50.459251776337624, 52.88979135453701, 53.43678340315819, 57.37554185092449, 51.2055279314518, 50.35455219447613, 54.625515416264534, 52.43222750723362, 46.57204516232014, 42.777891755104065, 44.113751873373985, 38.87041322886944, 39.64266858994961, 39.5430151373148, 38.47122944891453, 42.77833633124828, 52.2702232003212, 51.02825604379177, 53.27534906566143, 51.70407637953758, 51.378418654203415, 52.5205347687006, 52.236633002758026, 52.94758625328541, 50.15863470733166, 43.63198712468147, 43.27381454408169, 43.58759790658951, 41.97334572672844, 41.61391541361809, 41.677926778793335, 41.532405987381935, 44.76253665983677, 52.17593885958195, 52.740105986595154, 54.4586131721735, 49.32022489607334, 42.377602234482765, 42.53821201622486, 43.283686414361, 43.450786247849464, 40.883427411317825, 43.65787893533707, 42.18816339969635, 45.378411412239075, 51.81802846491337, 55.784514024853706, 52.99386017024517, 53.856938257813454, 52.77013577520847, 51.10232546925545, 51.01914793252945, 50.596078634262085, 52.396285235881805, 51.14014483988285, 50.663308426737785, 42.407400235533714, 38.11377502977848, 34.284458309412, 38.517009392380714, 39.26686495542526, 39.25791643559933, 38.31353411078453, 41.169897839426994, 43.653718158602715, 48.204699754714966, 51.446024626493454, 51.660971492528915, 50.57244770228863, 51.23428858816624, 52.701279670000076, 50.27425490319729, 45.983175560832024, 41.84842362999916, 39.97746862471104, 38.8543476909399, 39.11808393895626, 38.93215611577034, 41.09894424676895, 50.39829924702644, 52.58193947374821, 52.22106143832207, 49.71984185278416, 50.89929856359959, 52.14220426976681, 54.19348619878292, 50.86861900985241, 50.74633777141571, 52.21876636147499, 56.49781174957752, 54.685894176363945, 58.44477787613869, 49.99058112502098, 56.3606771081686, 23.968680649995804, 0.5294531397521496, 0.27360265608876944, 0.4938047885661945, 0.6435536546632648, 13.440679628401995, 61.24041706323624, 49.995969235897064, 57.882339656353, 49.06411103904247, 58.41491147875786, 50.7763409614563, 45.80833934247494, 28.02724476903677, 27.65319474041462, 40.195044949650764, 39.485106244683266, 1.8202323582954705, 0.4492635786300525, 0.10460156641784124, 0.029723958832619246, 0.22010507440427318, 0.10668499016901478, 0.023727913976472337, 0.08583747563534416, 0.0418079319933895, 0.17688879102934152, 0.007489352665288607, 0.016177696852537338, 0.03480224717350211, 0.059246899545541964, 0.02345529901504051, 0.03075819171499461, 0.04731563625682611, 0.0202821148923249, 0.05011432709579822, 0.06410305009922013, 0.07642010401468724, 0.07895891700172797, 0.03204189197276719, 0.25188192317727953, 0.10334813094232231, 28.649018704891205, 69.48723614215851, 29.556704498827457, 34.07968729734421, 49.8111205548048, 62.28942297399044, 74.2130197584629, 59.781485348939896, 61.94215960800648, 63.30868028104305, 57.5004867464304, 57.78314597904682, 55.374352633953094, 3.318623648956418, 2.3323288606479764, 0.611693492392078, 0.11807058937847614, 14.950152430683374, 58.32999363541603, 58.122365176677704, 65.43098419904709, 60.00082477927208, 60.70199355483055, 61.372756361961365, 59.64234061539173, 57.948315516114235, 55.215471759438515, 59.69068922102451, 58.30258950591087, 57.92390562593937, 58.2037416100502, 59.21445317566395, 59.25678290426731, 53.387275859713554, 54.947772324085236, 57.23683789372444, 58.17970409989357, 59.30983945727348, 54.97951962053776, 54.231639951467514, 52.29100428521633, 54.61935594677925, 57.00608387589455, 60.240299329161644, 50.71875885128975, 51.17724224925041, 56.33835330605507, 54.27392788231373, 49.757186248898506, 46.674552261829376, 45.86748316884041, 40.62412552535534, 42.47504040598869, 42.42867909371853, 42.49329462647438, 44.080883637070656, 54.49623875319958, 53.78145910799503, 54.57213208079338, 54.522141963243484, 52.796000987291336, 55.281690806150436, 55.30595250427723, 56.628258749842644, 55.29430992901325, 45.589463487267494, 43.44803139567375, 43.71074169874191, 40.98599150776863, 42.83992722630501, 42.81223811209202, 41.50410130620003, 44.320456981658936, 53.705106005072594, 53.43485310673714, 56.847089007496834, 48.322744220495224, 39.79454644024372, 43.07002007961273, 43.50496754050255, 42.72399924695492, 40.558195263147354, 43.220970779657364, 43.16777363419533, 45.84464639425278, 52.72475101053715, 55.573933124542236, 54.677568823099136, 55.2898945659399, 54.89102616906166, 54.42400082945824, 53.909633830189705, 53.166697695851326, 52.59823679924011, 52.33414717018604, 52.04635441303253, 43.94648104906082, 40.34154608845711, 36.84278883039951, 40.887413397431374, 41.82783253490925, 43.486082553863525, 39.68961887061596, 42.45907366275787, 45.421219915151596, 49.85706768929958, 53.981708362698555, 54.48243409395218, 52.80392736196518, 51.711873561143875, 53.85854937136173, 53.60369324684143, 46.82975493371487, 44.03120890259743, 41.68577715754509, 41.86253987252712, 41.21326871216297, 41.66058450937271, 43.05043213069439, 51.14137977361679, 55.123562291264534, 54.80260871350765, 53.646452352404594, 54.766028076410294, 53.455106019973755, 56.063445657491684, 52.73875705897808, 54.56931643188, 54.6097956597805, 59.62586469948292, 57.480359226465225, 58.91870364546776, 48.1484741717577, 57.10355244576931, 26.56511552631855, 0.8272149588447064, 1.8842034693807364, 0.44750682602170855, 0.6044450250919908, 15.799373611807823, 65.60446009039879, 56.49589665234089, 61.60487450659275, 56.74162566661835, 64.08872902393341, 59.143738970160484, 51.20736703276634, 40.62646619975567, 29.555182680487633, 42.89176024496555, 50.70348747074604, 2.7620081417262554, 0.47305401298217475, 0.1293072840780951, 0.009638906412874348, 0.16306427191011608, 0.12344795395620167, 0.022569965076399967, 0.023879495784058236, 0.11258711252594367, 0.07511487405281514, 0.06796456320444122, 0.1829546905355528, 0.15199366986053064, 0.1489883428439498, 0.16978784784441814, 0.13440269191050902, 0.1972857551299967, 0.12536514404928312, 0.12344092581770383, 0.10472774636582471, 0.14718845661263913, 0.17470704013248906, 0.14406732487259433, 0.5081231030635536, 0.4839775658911094, 31.66305497288704, 81.60154089331627, 42.42888428270817, 39.69590373337269, 48.045860677957535, 68.35764795541763, 80.22007942199707, 66.69722065329552, 65.88997676968575, 70.19301027059555, 61.288788467645645, 64.91447791457176, 64.05348211526871, 5.888843731954694, 6.4369818940758705, 7.438509352505207, 0.27995425276458263, 19.764278456568718, 62.386188581585884, 59.2948492616415, 66.77937984466553, 62.596359103918076, 63.502207696437836, 62.704003527760506, 60.19562132656574, 59.313897639513016, 57.906468361616135, 62.55491092801094, 60.81125669181347, 60.545001178979874, 60.856504663825035, 63.142272010445595, 60.429536774754524, 56.1991211771965, 56.039229556918144, 60.31741239130497, 62.719369903206825, 63.22278968989849, 59.562867879867554, 57.93069206178188, 54.137777388095856, 57.520542070269585, 61.52686469256878, 61.40988036990166, 54.186072796583176, 53.47839877009392, 58.703695982694626, 56.00668050348759, 52.80290521681309, 48.30224432051182, 47.86708787083626, 41.71453021466732, 44.67302866280079, 44.24756929278374, 45.80799736082554, 46.06808580458164, 57.21343494951725, 54.87174980342388, 57.29935213923454, 55.436813682317734, 53.90446990728378, 58.99516314268112, 57.36918859183788, 59.35077466070652, 55.29086351394653, 43.73047024011612, 43.56380358338356, 44.95626166462898, 41.26293204724789, 42.34897457063198, 44.78649437427521, 41.19035214185715, 45.219332948327065, 55.4632792621851, 56.29046827554703, 58.67019698023796, 50.801780596375465, 42.458131313323975, 42.71732300519943, 44.12054590880871, 43.54163937270641, 39.98424366116524, 42.77786895632744, 40.73984831571579, 45.74508413672447, 53.20463865995407, 58.89552488923073, 55.145498514175415, 60.51636591553688, 57.56760634481907, 55.337737798690796, 55.93180552124977, 54.42451000213623, 54.45710465312004, 55.29547646641731, 53.765347972512245, 46.06605291366577, 43.051336482167244, 38.880228102207184, 44.22808013856411, 43.630668595433235, 43.225405141711235, 42.55210407078266, 45.53600035607815, 47.37593002617359, 51.78945019841194, 56.48625276982784, 55.20350620150566, 55.32250061631203, 53.7467023730278, 57.302243784070015, 55.11083297431469, 49.72047261893749, 46.42566181719303, 42.79253236949444, 43.26315611600876, 43.48299331963062, 43.3501448482275, 45.129585564136505, 55.29774874448776, 57.74386368691921, 56.997215151786804, 54.13879573345184, 54.7383351624012, 55.50814725458622, 58.981521874666214, 57.52994276583195, 57.09452413022518, 57.66903430223465, 62.53877319395542, 59.7019100189209, 60.37927687168121, 51.07107974588871, 56.2606892734766, 34.53707255423069, 2.0659284805878997, 3.258697777055204, 1.8014065059833229, 1.1207739659585059, 17.042076028883457, 74.08223077654839, 60.30245639383793, 69.18459758162498, 61.869841888546944, 69.03013586997986, 63.553641736507416, 60.10406143963337, 39.24889571964741, 37.673454657197, 53.12993086874485, 62.35279597342014, 4.247063929215074, 0.8279558003414422, 0.15819060296053067, 0.15248592157149687, 0.2746994612971321, 0.27188244683202356, 0.1323689697892405, 0.13910275767557323, 0.25586022064089775, 0.3007809945847839, 0.10037271989858709], [0.014153797983453842, 0.08574000195949338, 0.05437860745587386, 0.05306657199980691, 0.06856359512312338, 0.06524413925944827, 0.05597553856205195, 0.0604001413739752, 0.04886596419964917, 0.09269491274608299, 0.03155093902023509, 0.05994054787151981, 0.274028351996094, 0.0956115011649672, 3.536407300271094, 58.1292238086462, 49.772989600896835, 39.319818913936615, 28.340688049793243, 51.57736077904701, 66.54591277241707, 62.44318172335625, 56.2758694589138, 56.052658036351204, 54.863006472587585, 51.955417692661285, 54.8832593858242, 7.1550744865089655, 2.1939614228904247, 0.6342518131714314, 0.04313375655328855, 3.286626753397286, 45.5887833237648, 67.67216473817825, 58.150286078453064, 61.236678063869476, 60.38493476808071, 59.25081342458725, 59.39498148858547, 58.745945915579796, 56.73414006829262, 58.861383721232414, 56.825677156448364, 56.786961033940315, 54.67049740254879, 56.164178252220154, 52.89363294839859, 58.19307938218117, 57.37335316836834, 56.296099573373795, 54.54595908522606, 54.28923726081848, 51.82124689221382, 51.31532683968544, 49.44694049656391, 51.86579570174217, 52.59218752384186, 54.37292777001858, 56.28414921462536, 56.32476143538952, 55.75614474713802, 56.56784199178219, 49.88862879574299, 45.189610943198204, 42.71447315812111, 40.55958218872547, 38.48044775426388, 40.16623489558697, 37.97134347259998, 41.5616150200367, 52.51562923192978, 54.16899651288986, 53.62470231950283, 52.88554698228836, 52.69755207002163, 53.00791181623936, 52.84259408712387, 47.187672927975655, 42.77569927275181, 42.13611759245396, 41.35406635701656, 43.505222126841545, 43.05848769843578, 41.96514956653118, 43.40839572250843, 41.912955567240715, 49.33239184319973, 46.942019909620285, 54.08739969134331, 51.76584206521511, 49.64712895452976, 49.52590025961399, 44.2592878639698, 43.46091650426388, 43.091906905174255, 42.58577786386013, 42.49884992837906, 44.10085916519165, 43.90028692781925, 45.817846432328224, 49.56231750547886, 52.27643586695194, 53.29613395035267, 55.22860765457153, 51.671888306736946, 52.16468006372452, 52.58422315120697, 53.63362044095993, 48.8769368827343, 50.480656027793884, 42.27004140615463, 36.08604043722153, 38.01849514245987, 35.979083776474, 36.600798815488815, 39.38633054494858, 38.40442143380642, 44.621222242712975, 43.26703950762749, 49.21420678496361, 52.043090388178825, 52.98165142536163, 49.18064318597317, 52.22659394145012, 51.835948303341866, 48.72328832745552, 44.58013504743576, 44.03209425508976, 40.917017608881, 40.34512169659138, 38.57669658958912, 39.925673604011536, 37.98143193125725, 47.354373782873154, 54.10336643457413, 52.81172834336758, 53.03778201341629, 55.20331621170044, 52.707967311143875, 54.8146540671587, 53.71919944882393, 55.94756707549095, 54.564657881855965, 59.01249021291733, 55.204752534627914, 61.04065418243408, 51.224040538072586, 53.66934612393379, 18.003677129745483, 0.23811303544789553, 1.055402155034244, 0.4604124475736171, 0.17454712215112522, 25.666133165359497, 58.44423450529575, 50.678108632564545, 55.02390503883362, 53.91272686421871, 55.82161143422127, 49.63409565389156, 41.86511613428593, 25.60449857264757, 26.050148159265518, 42.92677156627178, 14.681945722550154, 0.4565900011220947, 0.07274274743394926, 0.17605151486350223, 0.043509513343451545, 0.06419696888769977, 0.011698474754666677, 0.03216829456505366, 0.10716936027165502, 0.0684327470662538, 0.03151516750222072, 0.028871628201159183, 0.037955847874400206, 0.10016774613177404, 0.02543027829233324, 0.03982752205047291, 0.013941628167231102, 0.04844812392548192, 0.04695518255175557, 0.07737024599919096, 0.1026878050470259, 0.06525708973640576, 0.0814776548941154, 0.07045381556963548, 0.37363139796070755, 0.17751123028574511, 5.770998755469918, 66.7363129556179, 48.713944628834724, 35.9880892932415, 46.07757389545441, 55.90851277112961, 70.54918795824051, 63.593900576233864, 63.1794074177742, 62.0266442745924, 60.03126114606857, 56.14554785192013, 60.557057932019234, 7.664557322859764, 1.8581278435885906, 0.8324671676382422, 0.1087913908122573, 4.350232193246484, 49.9057886749506, 69.52094793319702, 61.89977668225765, 62.60605998337269, 63.194272220134735, 59.85598795115948, 62.74280324578285, 60.949029698967934, 56.69239550828934, 58.32079812884331, 59.341081380844116, 59.61535066366196, 59.150008633732796, 58.167780339717865, 55.54842509329319, 58.75602297484875, 58.75076025724411, 58.02588455379009, 56.36414252221584, 56.40959568321705, 54.94372934103012, 54.73042018711567, 51.980910524725914, 53.269797563552856, 55.78632652759552, 55.31507581472397, 58.220844492316246, 55.815007388591766, 57.14204058051109, 57.61220455169678, 50.433587953448296, 46.997622326016426, 45.32579943537712, 42.04113408923149, 40.89548796415329, 40.994005277752876, 39.15140435099602, 43.9349714666605, 54.48041260242462, 56.53279647231102, 55.4112334549427, 54.20853719115257, 54.66233544051647, 54.33028265833855, 55.42427435517311, 51.171447560191154, 44.425091966986656, 42.45624281466007, 42.04229302704334, 43.74707914888859, 43.74438129365444, 43.29452723264694, 43.543991446495056, 42.32215940952301, 51.26006260514259, 52.01353557407856, 54.86958011984825, 52.275751903653145, 53.225161358714104, 50.00202991068363, 42.962618842720985, 42.45071031153202, 43.5004647821188, 42.82235696911812, 41.8030920624733, 41.64421498775482, 44.54633206129074, 47.715099826455116, 50.496675968170166, 53.53618606925011, 55.09221397340298, 56.20513625442982, 53.66872675716877, 54.167430996894836, 53.664322793483734, 56.099076345562935, 50.244855880737305, 53.61860744655132, 43.68273340165615, 38.09566520154476, 38.665034249424934, 38.83429616689682, 39.057264402508736, 39.72684547305107, 40.19818738102913, 43.716266602277756, 45.65260089933872, 51.073409020900726, 54.05113823711872, 52.59043961763382, 51.8962586671114, 53.770656287670135, 53.18347379565239, 51.56733311712742, 48.06445688009262, 46.298091262578964, 44.539253041148186, 41.84556618332863, 41.62760987877846, 41.66013613343239, 40.449015721678734, 48.304771184921265, 54.842331781983376, 53.63905414938927, 55.86869090795517, 56.931786462664604, 54.98706601560116, 56.63408763706684, 56.58649139106274, 60.393400713801384, 54.52646233141422, 62.19318173825741, 58.57095010578632, 61.83460257947445, 53.727042227983475, 57.07497037947178, 21.025924757122993, 0.1785691172699444, 2.7287941239774227, 0.16200766141992062, 0.0648230075603351, 27.875684201717377, 63.55642318725586, 55.30111916363239, 60.873945727944374, 59.15725864470005, 63.95968034863472, 55.66447086632252, 49.22823943197727, 33.15279923379421, 21.054157242178917, 51.10352240502834, 20.100558511912823, 0.40044563880655915, 0.08363847722648643, 0.23211343941511586, 0.040764594814390875, 0.06466167207690887, 0.04443398443982005, 0.05560509925999213, 0.04741088720038533, 0.022465017973445356, 0.03651722799986601, 0.008666008325235453, 0.16735721030272543, 0.20283255202230066, 0.14440814877161756, 0.1650790247367695, 0.12366321388981305, 0.12664257315918803, 0.1295606087660417, 0.15311618306441233, 0.21300969732692465, 0.1998663361882791, 0.3066352632595226, 0.1310810912400484, 0.4799813381396234, 0.2899052656721324, 6.897664899006486, 78.0905368924141, 65.61459794640541, 47.87362352013588, 41.93882077932358, 59.83082950115204, 74.705321341753, 73.83351132273674, 66.42339214682579, 68.6961641907692, 64.34542044997215, 62.413208931684494, 66.61169484257698, 9.430700652301311, 3.530385810881853, 3.069754340685904, 0.17666895204456523, 6.029574405401945, 51.48934230208397, 73.22872817516327, 63.106101751327515, 66.5307591855526, 65.8710765838623, 63.692429289221764, 64.66413214802742, 63.892385959625244, 58.479933589696884, 61.8654341250658, 61.60270482301712, 62.216649278998375, 60.64103342592716, 59.83381614089012, 57.52794787287712, 60.807745680212975, 60.76019883155823, 60.80592177808285, 58.18978875875473, 59.856139943003654, 55.982240214943886, 55.422040075063705, 54.82658542692661, 55.584523156285286, 58.17700244486332, 57.47928388416767, 61.00393295288086, 57.463852912187576, 59.11292642354965, 60.75796075165272, 54.92110155522823, 49.06150437891483, 48.0287653952837, 43.8189484924078, 41.452796459198, 44.3614149838686, 42.726628705859184, 46.43939808011055, 57.23931536078453, 60.164307206869125, 58.969062343239784, 57.70420141518116, 54.956466257572174, 55.1105859875679, 58.01149092614651, 48.84321749210358, 43.32049123942852, 43.202526569366455, 43.30981761217117, 43.385821133852005, 43.5749825835228, 41.277310475707054, 43.26830863952637, 43.23467284440994, 52.95573301613331, 53.40614564716816, 56.32498562335968, 55.30713804066181, 54.37936082482338, 53.66600230336189, 44.90185618400574, 40.928318202495575, 43.62136289477348, 43.613276928663254, 41.894853338599205, 42.01158307492733, 44.92022819817066, 46.612304002046585, 51.04411259293556, 55.338851138949394, 56.20978340506554, 58.62887039780617, 56.43096573650837, 56.52543626725674, 56.1621605604887, 58.03261399269104, 51.801708340644836, 56.02433815598488, 47.01867699623108, 39.182684272527695, 41.05339229106903, 40.605077147483826, 39.54535961151123, 44.90751788020134, 42.62683466076851, 46.901141703128815, 47.72257402539253, 54.191278517246246, 57.25213587284088, 55.463963225483894, 53.25324945151806, 55.62212213873863, 56.224161833524704, 54.62218679487705, 50.01447044312954, 47.845793813467026, 45.19466087222099, 45.51679998636246, 43.24387215077877, 43.759021908044815, 44.213249534368515, 50.37320539355278, 59.109130427241325, 55.78066483139992, 56.34813778102398, 58.408759608864784, 58.57574924826622, 57.37903006374836, 58.68041843175888, 63.57283070683479, 57.44002819061279, 65.81030264496803, 61.7337179929018, 65.45271143317223, 54.10440377891064, 58.50291095674038, 24.742516726255417, 0.8157846971880645, 5.962162222713232, 0.844247069908306, 0.33196298230905086, 31.055942550301552, 71.25799432396889, 61.18015989661217, 66.80685237050056, 64.5828165113926, 68.1404136121273, 62.56081581115723, 55.730952098965645, 38.325423672795296, 37.54601709544659, 59.58032414317131, 30.805746875703335, 0.39798476616851985, 0.12083017645636573, 0.32234088925179094, 0.10608369469991885, 0.24699023488210514, 0.15251240140059963, 0.19608729053288698, 0.1983223870047368, 0.24647306185215712, 0.2048083272529766, 0.09914628375554457], [0.06011805104208179, 0.08257488312665373, 0.008341480133822188, 0.03877383562212344, 0.013008742971578613, 0.08922799213905819, 0.06597660933039151, 0.14146525121759623, 0.019627032270363998, 0.0382950427592732, 0.07712832069955766, 0.0345523363648681, 0.025507847567496356, 0.24308897234732285, 0.09912585243000649, 29.311547353863716, 51.050838232040405, 41.01553872227669, 26.497845835983753, 37.47913308441639, 64.97734934091568, 60.981924533843994, 56.42530404031277, 56.97554871439934, 55.436908677220345, 48.7432486563921, 53.29663932323456, 10.255762729793787, 0.770288254134357, 0.2678079076576978, 0.17477427871199325, 1.2648155679926276, 42.62584671378136, 71.20527595281601, 57.47196167707443, 56.18883512914181, 54.83980871737003, 59.98714931309223, 59.04313936829567, 59.13401909172535, 56.250266432762146, 57.15759314596653, 58.0631073564291, 57.510028034448624, 55.574282705783844, 58.37364949285984, 57.43962541222572, 59.3234047293663, 53.524866476655006, 55.34826323390007, 54.027165323495865, 55.19063629209995, 52.14658163487911, 52.26395733654499, 48.1214614212513, 48.58280226588249, 51.28161124885082, 54.789507016539574, 55.82569621503353, 54.33282092213631, 55.873573645949364, 57.844949662685394, 50.0892998278141, 43.70140179991722, 40.81565424799919, 39.737431704998016, 39.78223130106926, 37.86448560655117, 37.222525253891945, 39.70073327422142, 47.956652864813805, 51.780809462070465, 51.25794231891632, 51.76783315837383, 50.27044750750065, 52.64630042016506, 46.490467339754105, 44.56221520900726, 41.65176898241043, 42.009614780545235, 42.20120429992676, 43.820745795965195, 42.55182668566704, 42.84382961690426, 45.18209494650364, 45.5402447283268, 41.630771309137344, 42.8400944173336, 44.82637323439121, 44.714370444417, 39.98788766562939, 41.77072159945965, 46.98866240680218, 45.33364601433277, 42.91129119694233, 42.12877258658409, 43.42681713402271, 43.41452099382877, 44.75690536201, 43.674282655119896, 45.15483520925045, 48.11688646674156, 51.49182356894016, 53.81390556693077, 53.607778027653694, 52.80898109078407, 52.643807753920555, 49.609127193689346, 50.8966539055109, 51.42619729042053, 41.55996970832348, 37.160630375146866, 37.215537428855896, 36.83336153626442, 38.366617262363434, 38.09948019683361, 37.335983365774155, 42.874490171670914, 45.490300208330154, 49.309414476156235, 51.380383148789406, 53.09865474700928, 50.06710521876812, 51.291509717702866, 52.235413268208504, 46.869337409734726, 42.9005491733551, 46.443296670913696, 41.91892884671688, 43.73086541891098, 39.5367568731308, 39.0652097761631, 36.76499180495739, 40.19914112985134, 47.55579337477684, 53.11741814017296, 54.62130904197693, 53.39036889374256, 54.18313555419445, 55.54519906640053, 52.902391478419304, 56.82084381580353, 55.91767407953739, 58.06778870522976, 52.87938371300697, 57.32846237719059, 52.55836173892021, 58.6752051115036, 25.71606818586588, 0.6798007409088314, 1.2794426456093788, 0.21638833946781233, 1.1123635922558606, 39.75325025618076, 57.00614467263222, 51.93241372704506, 53.87067452073097, 54.89728823304176, 47.998192235827446, 52.60056607425213, 33.06739501655102, 28.254476375877857, 36.399804800748825, 34.767233803868294, 1.7860825220122933, 0.563024872681126, 0.05230630478763487, 0.18923036550404504, 0.01946227734151762, 0.0574866959505016, 0.012599673027580138, 0.05506351328222081, 0.07427449570968747, 0.05248272071185056, 0.0510918543295702, 0.012705474528047489, 0.012579781614476815, 0.057593542951508425, 0.03069780872465344, 0.0370740465587005, 0.04221736373438034, 0.04897127866570372, 0.08737575481063686, 0.1394198031630367, 0.060330004707793705, 0.059597931685857475, 0.011653908786684042, 0.04246518168656621, 0.02396341227722587, 0.19422316399868578, 0.11337707677739672, 38.122704550623894, 57.082110196352005, 29.92485724389553, 33.390807062387466, 50.474002584815025, 68.50053548812866, 67.72770255804062, 59.289027974009514, 62.68937811255455, 62.5955231487751, 55.822432190179825, 59.42162945866585, 13.593895956873894, 1.0915048490278423, 0.263354784110561, 0.22064866789150983, 1.582532194443047, 45.24452559649944, 74.30149421095848, 59.57854583859444, 58.33258129656315, 58.568765223026276, 61.14204794168472, 59.62556831538677, 62.034247666597366, 58.166252821683884, 59.14106771349907, 58.85088488459587, 58.80890853703022, 58.508454859256744, 60.432272627949715, 60.17464645206928, 60.56292101740837, 55.66535621881485, 58.06603699922562, 56.731077432632446, 58.05284410715103, 56.4710383862257, 53.41246470808983, 49.77129869163036, 50.98770461976528, 53.85365143418312, 57.26331867277622, 57.042200937867165, 56.745379865169525, 56.93408913910389, 58.7920830398798, 51.62686452269554, 45.73736675083637, 43.405887857079506, 41.39666207134724, 40.230554044246674, 42.42648281157017, 41.9318937510252, 42.23480969667435, 50.443946197628975, 52.67250381410122, 54.33342128992081, 54.938193038105965, 54.119975343346596, 53.560519963502884, 47.28864870965481, 44.64709885418415, 43.54387745261192, 42.52164490520954, 43.77039469778538, 43.65646921098232, 42.976921275258064, 44.06557805836201, 44.69112329185009, 47.09109731018543, 45.52525073289871, 44.513672813773155, 46.5525484085083, 46.34048938751221, 43.87893967330456, 45.942042768001556, 48.14240589737892, 46.06565773487091, 42.63022027909756, 42.67046771943569, 42.18405582010746, 42.625500932335854, 43.95459361374378, 42.92835608124733, 45.08632868528366, 49.21150512993336, 52.70547844469547, 54.7491417825222, 55.1069837808609, 54.11631993949413, 53.88732522726059, 51.857496947050095, 51.48677743971348, 52.693269699811935, 42.423735558986664, 38.41473788022995, 38.29856291413307, 39.27090033888817, 39.41594235599041, 40.75038135051727, 38.95897887647152, 43.7686125934124, 45.232351049780846, 52.51672737300396, 51.68916217982769, 55.851348638534546, 52.34266251325607, 53.21490950882435, 52.603434920310974, 47.54568211734295, 44.28117848932743, 47.8994545340538, 43.64985756576061, 45.18390364944935, 42.7178967744112, 41.72239199280739, 39.59312304854393, 42.484338507056236, 50.03016360104084, 55.76841428875923, 55.497063249349594, 54.580411836504936, 54.09996561706066, 57.749130204319954, 53.718401491642, 57.61938996613026, 58.04091274738312, 58.44440929591656, 55.317329093813896, 59.522240459918976, 56.39661177992821, 62.02679246664047, 28.577440045773983, 0.7639721618033946, 3.046165918931365, 0.20808317261980847, 0.8303848200011998, 43.955634757876396, 61.64894074201584, 58.77701684832573, 60.64517140388489, 58.13716538250446, 55.85637576878071, 53.87347877025604, 45.192810371518135, 34.380323365330696, 35.36771938204765, 46.541491001844406, 2.8439300833269954, 0.5443027429282665, 0.06608995754504576, 0.11912259855307639, 0.014740409133082721, 0.005825920025017695, 0.1159637731325347, 0.06354165991069749, 0.05947613783064298, 0.0590373689919943, 0.032670413129380904, 0.08241765914135613, 0.1762535868328996, 0.19649406167445704, 0.14779396005906165, 0.13882488274248317, 0.08442490143352188, 0.18121583852916956, 0.1266150691662915, 0.32373265363276005, 0.12644767033634707, 0.1162364381889347, 0.1629243473871611, 0.12243501143530011, 0.18263527017552406, 0.311454621842131, 0.32232390891294926, 43.16711626946926, 71.8611815571785, 49.881207793951035, 38.69443707168102, 49.39579524099827, 74.23578053712845, 72.44195759296417, 66.16196617484093, 67.22891092300415, 66.36763393878937, 57.83017985522747, 66.17147326469421, 14.39468303695321, 2.9728607274591923, 0.7399835146497935, 1.0533437342382967, 2.0169293973594904, 49.12113457918167, 78.26956808567047, 62.70284838974476, 62.343098893761635, 63.459855169057846, 65.56083843111992, 63.21011357009411, 63.32698009908199, 59.30778756737709, 60.32664969563484, 60.87746813893318, 60.83824284374714, 60.00132255256176, 64.96529638767242, 60.90933322906494, 61.277761459350586, 58.584834560751915, 61.54560148715973, 58.54681760072708, 61.68837882578373, 59.52568307518959, 58.100919127464294, 51.074993535876274, 53.251136764883995, 55.73341816663742, 59.81425479054451, 59.004556238651276, 57.17489741742611, 59.008071050047874, 61.63105130195618, 55.61170309782028, 48.88429328799248, 44.31349955499172, 43.0692221224308, 42.65463396906853, 42.353891506791115, 42.336484640836716, 44.0828063338995, 51.47752493619919, 55.69559499621391, 55.02249911427498, 56.775136068463326, 53.973819985985756, 55.3921090811491, 47.18384273350239, 44.02225278317928, 41.735345497727394, 42.50372886657715, 43.366457372903824, 45.01941427588463, 41.9528192281723, 44.089672565460205, 47.36844822764397, 52.56861738860607, 46.8956433981657, 46.781543120741844, 47.57688984274864, 48.02458941936493, 46.569548696279526, 47.27261357009411, 51.97301834821701, 48.68980452418327, 42.90167011320591, 41.30700968205929, 41.866339668631554, 43.5609233379364, 43.51230874657631, 43.64837184548378, 45.08049599826336, 49.54505503177643, 51.61977030336857, 57.481096386909485, 58.290585950016975, 56.95387847721577, 58.110593408346176, 54.80361945927143, 53.98970313370228, 55.238984897732735, 44.97596740722656, 40.39004668593407, 41.19752615690231, 42.12532997131348, 42.171668484807014, 42.97698587179184, 40.722118467092514, 45.84541015326977, 49.52442593872547, 53.97822014987469, 53.778255879879, 57.547562420368195, 55.327189564704895, 55.133012384176254, 56.61254659295082, 49.9865647405386, 46.52731396257877, 51.921132132411, 45.7192987203598, 47.946465611457825, 43.34576368331909, 43.12574028968811, 40.78344337642193, 45.7635435461998, 51.668920665979385, 58.857713118195534, 57.49504163861275, 57.694755122065544, 56.948148384690285, 61.42806999385357, 55.09998455643654, 59.94159355759621, 60.37708438932896, 62.599163353443146, 58.602344021201134, 64.19798836112022, 57.2891990840435, 63.144749477505684, 30.422394946217537, 1.7438133526593447, 4.5671027060598135, 0.2996252034790814, 1.1180108017288148, 48.94437946379185, 65.63359692692757, 63.953767865896225, 64.40470486879349, 66.14464670419693, 61.263698413968086, 66.40800297260284, 43.6681117862463, 42.15608552098274, 48.992963656783104, 58.69455747306347, 6.989949122071266, 0.976004881085828, 0.11865018444950692, 0.2527829201426357, 0.12754701368976384, 0.23883219138951972, 0.3056080418173224, 0.18417305953335017, 0.07559689154732041, 0.13623981911223382, 0.0816116199712269, 0.12687189679127187], [0.03687097268993966, 0.03726557260961272, 0.03838325443211943, 0.051349286804907024, 0.08158912547514774, 0.04032732511404902, 0.10659890846000053, 0.10148623827262782, 0.04508706697379239, 0.10655897349352017, 0.015385372571472544, 0.08059313360718079, 0.028799456194974482, 0.43286600382998586, 0.06601296714507043, 6.714932229369879, 55.59446342289448, 45.89912407100201, 34.707003235816956, 26.303208880126476, 56.302513629198074, 64.24911841750145, 60.65760053694248, 54.799979254603386, 55.48023395240307, 51.00470870733261, 56.177401542663574, 16.035280153155327, 0.9553376119583845, 0.16065628471551463, 0.32417883281596005, 0.8669630822259933, 35.7524411380291, 67.30869144201279, 57.60628826916218, 54.36858840286732, 49.67909663915634, 53.52756053209305, 53.53107154369354, 58.21165658533573, 57.84368813037872, 57.82348081469536, 57.949789837002754, 57.77373008430004, 56.33012294769287, 56.45923241972923, 58.900023847818375, 54.24822986125946, 54.006353840231895, 49.003766477108, 48.24666850268841, 47.213845923542976, 45.726719722151756, 45.24429000914097, 47.41129092872143, 50.1843137294054, 50.6858716160059, 53.89992535114288, 54.77701708674431, 57.63697162270546, 56.88738204538822, 57.50588245689869, 52.31230594217777, 43.621811270713806, 42.46789298951626, 38.84513698518276, 38.71331445872784, 39.41050484776497, 39.05563049018383, 38.24588254094124, 42.99756556749344, 52.30299264192581, 52.664987817406654, 49.23902705311775, 49.06378425657749, 45.591598972678185, 43.48446764051914, 43.15010458230972, 45.61871811747551, 42.879783287644386, 43.32472041249275, 44.152597188949585, 44.90873001515865, 43.0668168514967, 39.96312819421291, 37.28890769183636, 39.74731497466564, 40.043383687734604, 37.10649847984314, 38.651563972234726, 37.58958175778389, 35.94123400747776, 37.919499054551125, 39.095038175582886, 42.85019047558308, 45.38456328213215, 43.982328325510025, 42.292201817035675, 42.60236017405987, 42.96540409326553, 44.65918220579624, 44.01654548943043, 48.70197907090187, 51.80353604257107, 52.015564665198326, 52.68264926970005, 53.80517743527889, 51.12213380634785, 49.798767417669296, 48.950337544083595, 41.15222118794918, 38.026740700006485, 36.81100353598595, 36.5652859210968, 38.08873437345028, 37.2650183737278, 39.762460961937904, 41.65607035160065, 47.36222416162491, 53.110726699233055, 50.95018923282623, 51.39293387532234, 51.385657265782356, 48.9632910490036, 49.925885796546936, 46.1014936119318, 47.43273317813873, 47.37035192549229, 45.444121286273, 43.68159346282482, 42.73159883916378, 41.78543820977211, 40.30675895512104, 37.946477606892586, 40.11036269366741, 47.25956127047539, 53.72784398496151, 56.643575727939606, 54.3013434112072, 55.11711783707142, 52.67281539738178, 56.60509519279003, 54.473417177796364, 54.59609739482403, 52.15867638587952, 53.414554595947266, 51.546191051602364, 58.62372547388077, 40.738902166485786, 1.5706957108341157, 0.48221653851214796, 0.4786427115323022, 1.9732626155018806, 38.76274220645428, 57.052312195301056, 52.4211473017931, 52.37606652081013, 55.7032135874033, 62.77942568063736, 47.16371141374111, 28.094926737248898, 26.249500662088394, 37.105955109000206, 10.986534766852856, 0.1196676614927128, 0.11283293410087936, 0.07003499194979668, 0.12248918821569532, 0.029093524790368974, 0.14671095879748464, 0.11344677186571062, 0.07306064639124088, 0.05740161614085082, 0.08206835991586559, 0.10018586937803775, 0.00648691524474998, 0.02744679557508789, 0.019507533506839536, 0.021262703485263046, 0.034277248196303844, 0.021289593350957148, 0.051265479778521694, 0.03751176154764835, 0.015243742964230478, 0.05156723331310786, 0.05296515751979314, 0.02344238750083605, 0.0011488261657177645, 0.03084143656451488, 0.4153481125831604, 0.1427981781307608, 9.792459290474653, 66.0830520093441, 40.824549570679665, 33.50224368274212, 48.121039643883705, 60.1058055460453, 72.2776848077774, 64.94388073682785, 62.28118881583214, 62.481913045048714, 56.49464271962643, 61.308186426758766, 19.649919793009758, 1.123238846193999, 0.3850750776473433, 0.45755372440908104, 0.8840460749343038, 39.129612520337105, 70.55396050214767, 59.62179131805897, 57.47844412922859, 53.4068638086319, 55.67461632192135, 57.78024673461914, 60.96325233578682, 59.76704232394695, 59.715224504470825, 59.38146561384201, 58.04851233959198, 58.66461507976055, 58.187391087412834, 59.45946782827377, 56.135280802845955, 56.87546968460083, 51.207344233989716, 50.22404819726944, 49.97793920338154, 48.36462177336216, 47.799873277544975, 48.93303707242012, 51.963701248168945, 53.54800343513489, 56.10232137143612, 57.58173778653145, 58.54831472039223, 57.954129204154015, 60.74106305837631, 54.608382135629654, 45.22365711629391, 42.712162882089615, 41.0532782971859, 41.895385310053825, 41.52441881597042, 41.31745532155037, 41.342157796025276, 46.29777207970619, 53.5240913182497, 54.332338348031044, 53.524315506219864, 52.66841143369675, 47.46479205787182, 44.23024222254753, 42.47951656579971, 43.1578865647316, 43.340174183249474, 42.08828575909138, 45.626085922122, 44.40014250576496, 44.65040847659111, 46.01345993578434, 39.9114965647459, 41.795785054564476, 41.63585923612118, 40.598431304097176, 39.73413348197937, 40.53648702800274, 40.32975152134895, 40.7475771009922, 43.3391672372818, 45.42986445128918, 45.587388798594475, 43.388135209679604, 42.06774786114693, 42.33613505959511, 44.23627249896526, 44.003835171461105, 44.74312350153923, 50.72832673788071, 53.768228217959404, 54.7009489685297, 54.66134749352932, 53.97541210055351, 53.95547457039356, 52.65736162662506, 50.27964301407337, 42.86241441965103, 39.07458007335663, 38.10283161699772, 38.81305530667305, 38.70113231241703, 40.64918518066406, 39.92891103029251, 43.42761889100075, 48.65788243710995, 54.11087863147259, 53.46193805336952, 53.10747787356377, 52.90927290916443, 50.31197167932987, 51.84415586292744, 48.82896065711975, 48.947430700063705, 48.21179397404194, 48.832711055874825, 47.28756196796894, 44.51472535729408, 42.63712450861931, 42.11326561868191, 39.1591065376997, 43.827289044857025, 49.78414960205555, 55.656039118766785, 58.39197590947151, 56.85387164354324, 58.076763823628426, 55.182979702949524, 59.14827972650528, 56.367710530757904, 56.25990651547909, 54.08106543123722, 55.82783930003643, 55.02876877784729, 60.64134120941162, 42.661363407969475, 2.073144055902958, 1.1034439271315932, 0.10219562012935057, 1.7604238050989807, 43.52514445781708, 63.84817913174629, 57.92274288833141, 59.22601975500584, 60.88009759783745, 68.2949361205101, 53.43475431203842, 39.64210622012615, 23.293650671839714, 42.82917760312557, 18.78730908036232, 0.18075270869303495, 0.06884213798912242, 0.04123138714930974, 0.047540774176013656, 0.07176699393312447, 0.024614192298031412, 0.07923584198579192, 0.08062831882853061, 0.0548048377095256, 0.08492300126818009, 0.13628103799419478, 0.032464838222949766, 0.1569538880721666, 0.10070251548313536, 0.09497205188381486, 0.17470663937274367, 0.1946661519468762, 0.07929221552331, 0.14911260805092752, 0.2521319378865883, 0.11954161513131112, 0.12987084133783355, 0.10996183191309683, 0.1181120754336007, 0.14859827002510428, 0.8575577556621283, 0.54088452947326, 12.30842873454094, 76.87502011656761, 57.75061212480068, 44.14226554334164, 42.19635955989361, 65.86707159876823, 76.24443635344505, 71.31135866045952, 67.81792491674423, 69.19245555996895, 60.40399454534054, 69.10395830869675, 23.292641825973988, 2.1474678302183747, 0.9303268790245056, 1.148736784234643, 1.1082835611887276, 43.16585473716259, 72.31673151254654, 64.14596155285835, 60.75549088418484, 55.87380163371563, 59.041505455970764, 60.70719547569752, 63.7050674110651, 62.8907673060894, 62.55922369658947, 62.64140188694, 62.21218451857567, 61.04511894285679, 60.764089822769165, 62.248214185237885, 59.23641599714756, 60.29592454433441, 54.17911916971207, 53.86893041431904, 50.75478471815586, 49.54842925071716, 49.97174933552742, 52.52655364573002, 55.26817113161087, 56.12607389688492, 57.563399970531464, 58.68234112858772, 61.846218556165695, 61.761023327708244, 63.063080459833145, 57.212872579693794, 46.9891107827425, 45.46610310673714, 42.25153639912605, 43.32929156720638, 44.42946173250675, 43.93905624747276, 42.17764936387539, 47.31446072459221, 59.24836255609989, 56.944644972682, 53.854350596666336, 53.97163890302181, 45.872384905815125, 43.681897446513176, 44.75651778280735, 44.3223112821579, 43.723957389593124, 42.30892851948738, 44.744430631399155, 46.63216933608055, 46.27382196485996, 48.841184601187706, 44.32976268231869, 43.26539419591427, 45.07352337241173, 43.10450702905655, 44.60976965725422, 42.161952406167984, 41.96202613413334, 42.727726846933365, 45.09564198553562, 48.7731758505106, 46.96191564202309, 44.275436997413635, 41.84954077005386, 41.67047917842865, 43.4104248136282, 43.01584258675575, 44.028944224119186, 49.99641381204128, 53.006882071495056, 56.063833236694336, 56.94315925240517, 56.983410492539406, 56.18465915322304, 51.08094021677971, 52.68313564360142, 44.19523850083351, 42.14252784848213, 41.01908013224602, 40.71206420660019, 40.74301354587078, 42.60771028697491, 42.78271749615669, 44.57721680402756, 53.054755702614784, 57.783921137452126, 53.18170689046383, 56.1982586234808, 54.18962560594082, 52.05981329083443, 54.45173554122448, 50.937311723828316, 51.04635447263718, 50.336233377456665, 50.25500513613224, 50.81465810537338, 48.34481343626976, 46.53134174644947, 44.360442236065865, 40.98385602235794, 44.54601287841797, 52.39240564405918, 57.78223782777786, 60.09128652513027, 59.610289335250854, 59.71548289060593, 55.52943371236324, 59.667666256427765, 58.880173712968826, 59.835628643631935, 57.73665927350521, 58.392226696014404, 57.11304433643818, 63.87258902192116, 45.53540378808975, 2.39226708188653, 1.8273593508638442, 0.7187551818788052, 2.673830548301339, 47.837422862648964, 67.38452017307281, 62.57976919412613, 63.48294273018837, 64.96774345636368, 74.14563417434692, 59.93306681513786, 43.08194763958454, 35.76289817690849, 55.70394694805145, 32.80388295650482, 0.18376625870587304, 0.22075495828175917, 0.1656656776322052, 0.15562850137939677, 0.1662702311296016, 0.14403326029423624, 0.19675256655318663, 0.215111177531071, 0.10987006535287946, 0.19296172074973583, 0.17856735095847398, 0.12203564692754298], [0.04369127273093909, 0.07511160118156113, 0.06938230275409296, 0.045711020211456344, 0.01341874431091128, 0.07468944531865418, 0.08130761401844211, 0.03316393762361258, 0.01567323681229027, 0.10131710281712003, 0.013351415746001294, 0.048293890795321204, 0.09544491127599031, 0.09965609468054026, 0.17969710752367973, 0.29541897762101144, 34.791339710354805, 51.631257086992264, 28.15854862332344, 22.637553177773952, 41.9785400480032, 55.278654769062996, 57.78288759291172, 59.134057089686394, 56.9750851392746, 50.225845500826836, 54.739505499601364, 24.245113916695118, 0.11720266251359135, 0.02041824332991382, 0.4560230893548578, 0.824636856559664, 34.2912333458662, 66.44889637827873, 55.92718876898289, 52.152277529239655, 44.69869248569012, 46.19983613491058, 46.837882697582245, 51.42402000725269, 51.77764043211937, 54.9559722840786, 55.61451114714146, 56.77840009331703, 56.98555737733841, 55.1947932690382, 52.05176152288914, 48.18244054913521, 44.55280691385269, 43.6641675978899, 42.30313003063202, 42.355985194444656, 42.20310419797897, 43.54033224284649, 43.408794701099396, 45.691818594932556, 50.676736906170845, 53.56686182320118, 57.866912484169006, 49.93910528719425, 53.718321695923805, 56.432470455765724, 50.95482878386974, 43.95058862864971, 41.70572608709335, 40.33601738512516, 39.26215700805187, 38.630801886320114, 41.21060885488987, 39.26199361681938, 42.1953260153532, 47.52478703856468, 49.89936701953411, 52.51026771962643, 45.02729505300522, 41.44000254571438, 43.897288888692856, 43.885163739323616, 42.34666049480438, 43.50123234093189, 44.01588812470436, 44.82365258038044, 41.10554829239845, 38.52479137480259, 37.86780282855034, 38.74950371682644, 37.082612961530685, 39.07594420015812, 39.43269565701485, 38.49511496722698, 39.1982938349247, 37.97015033662319, 38.85885424911976, 35.95411531627178, 36.869201213121414, 40.2717400342226, 44.25899147987366, 44.43020649254322, 43.49906265735626, 43.629965633153915, 43.94461914896965, 42.754602804780006, 45.87309166789055, 47.636755630373955, 52.1053234487772, 51.983148604631424, 51.499328166246414, 49.507665038108826, 49.2642766982317, 45.55109314620495, 38.22471767663956, 36.97165131568909, 37.383917793631554, 36.72876074910164, 37.18900725245476, 38.14296506345272, 40.65130166709423, 41.959776654839516, 47.47203826904297, 51.616061702370644, 49.37398061156273, 50.07674530148506, 51.79905988276005, 49.443478882312775, 46.965137869119644, 48.10661941766739, 45.51600202918053, 44.01868477463722, 44.56525884568691, 45.757296681404114, 45.27962811291218, 40.753865763545036, 40.13412281870842, 40.664262771606445, 40.161800533533096, 42.07232281565666, 47.04522617161274, 51.72710694372654, 52.33705401420593, 54.080126881599426, 55.07171027362347, 55.63247658312321, 56.31442978978157, 48.7308157235384, 48.830567970871925, 47.218827456235886, 54.46168340742588, 54.07782040536404, 51.188409850001335, 1.7362709948793054, 0.046291223843581975, 0.21558996668318287, 1.864411875139922, 46.63593113422394, 55.949987545609474, 51.261590123176575, 58.5939958691597, 52.38037168979645, 52.04182505607605, 33.42027448117733, 24.03155017644167, 34.636593014001846, 37.060505747795105, 4.8078592121601105, 0.6170252000447363, 0.07160461202147417, 0.07053349254420027, 0.07056431393721141, 0.011807330192823429, 0.023648071874049492, 0.0694972243218217, 0.02625258348416537, 0.028563768646563403, 0.03871499444358051, 0.054925429285503924, 0.01538654423711705, 0.10506062186323106, 0.054569992498727515, 0.05811841576360166, 0.061883178786956705, 0.04093955612916034, 0.025065672271011863, 0.04944283558870666, 0.06550913793034852, 0.04760260992043186, 0.07051917651551776, 0.0395149108953774, 0.01645485190238105, 0.04298275918699801, 0.06803706361097284, 0.12001330935163423, 0.5547744466457516, 44.89517994225025, 56.12939111888409, 23.49234201014042, 37.17267192900181, 53.94398778676987, 60.8726841956377, 62.79387630522251, 62.22174480557442, 62.98233479261398, 55.109499245882034, 61.28044791519642, 27.92727593332529, 0.12045483526890166, 0.05932769716309849, 0.6223366025369614, 0.8429528831038624, 37.116081565618515, 69.35699433088303, 59.837661534547806, 53.483163714408875, 48.16909186542034, 48.40714529156685, 48.84954035282135, 53.37513171136379, 55.564190447330475, 58.46909657120705, 59.65452276170254, 59.82344649732113, 59.178811088204384, 57.66495332121849, 54.94041591882706, 52.54353113472462, 47.67370864748955, 46.49649761617184, 44.78710614144802, 45.361536517739296, 44.58370305597782, 44.87991236150265, 45.74808217585087, 48.378688618540764, 51.015009954571724, 57.06138990819454, 59.14896748960018, 52.16813787817955, 57.90465205907822, 56.71984523534775, 53.88310365378857, 46.056469827890396, 43.76889377832413, 42.74066515266895, 41.88714735209942, 41.5338347107172, 41.952701434493065, 41.1647605150938, 43.01231637597084, 50.12796275317669, 51.01349003612995, 53.680855706334114, 46.995787024497986, 43.24177086353302, 44.259375259280205, 42.303597405552864, 43.00657108426094, 43.69942970573902, 45.05107797682285, 46.34986728429794, 45.11340603232384, 41.187931671738625, 40.30143924057484, 40.394564643502235, 39.93379756808281, 42.005731388926506, 39.61545445024967, 40.42708709836006, 41.24265633523464, 38.62811543047428, 41.38731077313423, 38.91224518418312, 40.45460142195225, 42.49869793653488, 45.59175096452236, 43.63405041396618, 43.19222532212734, 43.263623490929604, 44.65027168393135, 42.221601605415344, 44.03232604265213, 46.09979510307312, 54.14591275155544, 53.42778168618679, 53.75968627631664, 51.80738903582096, 49.66730207204819, 45.71719363331795, 41.222859397530556, 38.96347023546696, 39.18919712305069, 38.34641374647617, 40.29351286590099, 41.006404012441635, 42.57894583046436, 41.241364404559135, 49.930399954319, 53.2215591520071, 52.14574187994003, 52.1500888466835, 52.182900086045265, 49.264728873968124, 48.302894085645676, 49.9272271245718, 47.61255852878094, 45.28842844069004, 47.298224195837975, 47.21674516797066, 48.32119010388851, 43.0982905626297, 43.246087431907654, 43.36869925260544, 42.031060829758644, 45.010914131999016, 49.889696538448334, 53.21621663868427, 54.66216444969177, 55.47340951859951, 56.71161487698555, 57.82107174396515, 57.984143793582916, 49.86826568841934, 52.75625132024288, 49.833375960588455, 58.17268207669258, 57.41323962807655, 53.065801709890366, 1.7333939555101097, 0.049103666679002345, 0.40842372633051127, 3.0384449707344174, 53.4235031157732, 60.152524039149284, 57.74236276745796, 62.320547103881836, 59.793808087706566, 57.59931564331055, 41.966198310256004, 33.7424173951149, 32.090497836470604, 49.5452868193388, 7.743603531271219, 0.6447457813192159, 0.11320221194182523, 0.08343849811353721, 0.06764120204024948, 0.04159755539149046, 0.020168877999822143, 0.05168452233192511, 0.07081384625053033, 0.07156657695304602, 0.04826452772249468, 0.023320383988902904, 0.012071632172592217, 0.16920621186727658, 0.23531699407612905, 0.2124056633329019, 0.118955897341948, 0.22417456697439775, 0.13497579318936914, 0.15919003839371726, 0.15537105035036802, 0.1720878525520675, 0.12866111093899235, 0.2179342627641745, 0.16594108863500878, 0.13210672448622063, 0.1983746638870798, 0.27235682762693614, 0.9082934644538909, 53.2223305106163, 68.55104997754097, 36.301454678177834, 31.996988654136658, 57.556111961603165, 64.90477323532104, 68.91725912690163, 69.41396847367287, 68.87446582317352, 60.360464081168175, 66.95735469460487, 32.94395864009857, 0.3353540925309062, 0.319547118851915, 1.2011461844667792, 0.8677952375728637, 39.783538430929184, 70.56867331266403, 63.34567129611969, 57.840910479426384, 50.88493533432484, 51.75552561879158, 51.46161898970604, 55.746010690927505, 56.7139745503664, 60.62927685678005, 63.7845553457737, 62.8108461946249, 62.815702334046364, 60.072234347462654, 58.05035904049873, 54.4177957624197, 50.18580324947834, 48.03372412919998, 47.13532693684101, 47.61465601623058, 45.56445702910423, 46.6788574308157, 50.21776333451271, 50.32024383544922, 54.05142702162266, 59.45547804236412, 61.24672472476959, 53.12614247202873, 60.81142768263817, 58.21605294942856, 56.26496024429798, 47.78656259179115, 46.3835334777832, 43.856547474861145, 44.84738990664482, 42.75758944451809, 46.92954137921333, 43.008976355195045, 45.66429287195206, 52.42118909955025, 52.95176602900028, 55.516529604792595, 46.39600060880184, 43.583684116601944, 44.99583654105663, 42.654307186603546, 43.21367137134075, 42.058031782507896, 45.64599685370922, 50.49500025808811, 47.085302621126175, 44.0409629791975, 43.356631100177765, 43.85601170361042, 41.76763616502285, 44.173564463853836, 42.07540065050125, 45.096629932522774, 44.68370608985424, 42.628039196133614, 44.555964544415474, 40.57951211929321, 41.8890168517828, 44.62108924984932, 47.28132650256157, 47.9128298163414, 43.775813207030296, 43.88495475053787, 44.27460104227066, 40.91576747596264, 44.72467549145222, 46.86621777713299, 55.69263115525246, 55.16064070165157, 55.30024901032448, 53.091663122177124, 51.62378668785095, 47.95182332396507, 41.71015664935112, 41.580196022987366, 41.14068880677223, 41.32929928600788, 41.94472186267376, 41.83494575321674, 44.286388009786606, 44.197411984205246, 51.09974540770054, 54.830970391631126, 52.526405453681946, 52.207321375608444, 55.99317602813244, 51.06551684439182, 50.286627039313316, 50.526337176561356, 49.612547010183334, 48.50833386182785, 49.784575179219246, 51.1599987745285, 52.53229893743992, 45.59044383466244, 44.665109887719154, 45.38138285279274, 45.346789509058, 46.36642299592495, 52.10880026221275, 55.867417976260185, 57.536767199635506, 58.54223884642124, 59.084287360310555, 60.70525377988815, 63.01057867705822, 52.86659739911556, 56.12513914704323, 51.90367966890335, 60.62951624393463, 59.83860768377781, 55.245322957634926, 2.5968207931146026, 0.17926792352227494, 1.37750149006024, 3.9138780953362584, 57.578827142715454, 66.98390766978264, 62.17675141990185, 68.58372822403908, 62.82675974071026, 66.11618623137474, 46.06030762195587, 37.632264867424965, 45.26101291179657, 62.10092268884182, 15.998182743787766, 0.9176011243835092, 0.19084216182818636, 0.14344760187668726, 0.15236162667861208, 0.09061440563527867, 0.10838734335266054, 0.1216174170258455, 0.10035396582679823, 0.14858875569188967, 0.1695861024199985, 0.08356348320376128, 0.08839579968480393], [0.02177448110160185, 0.07183401728980243, 0.05753299854404759, 0.019106899926555343, 0.0731208419892937, 0.06682904015178792, 0.034740752817015164, 0.10214251204160973, 0.023400806821882725, 0.036784159965463914, 0.02375900625338545, 0.07501783824409358, 0.04191240783256944, 0.0477169340592809, 0.45613105699885637, 0.07954204469569959, 10.205259639769793, 53.003785237669945, 43.94136652350426, 28.687128759920597, 30.499122329056263, 54.343186765909195, 64.1081915795803, 57.02965401113033, 56.54687851667404, 49.02977608144283, 56.77353635430336, 28.54735516011715, 0.3211171174189076, 0.10169781715376303, 0.5569679383188486, 0.5513219756539911, 32.03380107879639, 67.5040465593338, 57.95876495540142, 55.8806336671114, 49.118375927209854, 48.46610672771931, 44.68064725399017, 44.772454127669334, 43.41716185212135, 44.68632414937019, 45.46810179948807, 49.502561911940575, 46.64915442466736, 45.77877692878246, 42.90021859109402, 42.69359327852726, 42.17967465519905, 43.642124980688095, 44.88837070763111, 44.55141618847847, 45.74641026556492, 44.453955218195915, 47.0756321400404, 45.37413664162159, 49.7791338711977, 51.97569340467453, 55.5765625834465, 51.84295892715454, 50.37455052137375, 55.90378202497959, 51.899412497878075, 44.86060939729214, 41.32621765136719, 40.90642377734184, 39.199072793126106, 39.72705826163292, 41.45048998296261, 41.73859432339668, 42.30756439268589, 46.35679051280022, 50.18418073654175, 52.96451434493065, 45.462535098195076, 45.78159257769585, 44.31421011686325, 41.88211642205715, 44.86301086843014, 46.12599849700928, 41.62654973566532, 38.62917937338352, 36.17678716778755, 37.9504369944334, 40.58812625706196, 37.55191057920456, 38.138287514448166, 37.363132908940315, 37.1532017737627, 36.476982459425926, 38.55112016201019, 38.83955508470535, 38.153927475214005, 37.960384860634804, 38.64720940589905, 37.16871254146099, 37.758904471993446, 39.87051576375961, 43.94820235669613, 42.67333276569843, 43.37161369621754, 44.18860025703907, 44.464252665638924, 42.5309544056654, 47.09714278578758, 50.988487377762794, 48.84531877934933, 48.12893562018871, 47.60984547436237, 42.34712027013302, 39.425088465213776, 37.23086580634117, 38.98805491626263, 36.68952025473118, 37.65770070254803, 38.796947970986366, 39.558826088905334, 42.89012253284454, 47.68743731081486, 48.8790799677372, 48.52753043174744, 49.20517086982727, 50.700345039367676, 47.756285816431046, 46.65035516023636, 46.89468964934349, 47.567185163497925, 44.982503056526184, 44.498401433229446, 44.905481189489365, 43.64833764731884, 43.08167025446892, 40.462831780314445, 38.76597203314304, 40.61769627034664, 37.955274134874344, 42.08651885390282, 43.987739235162735, 45.93725122511387, 48.649579882621765, 51.76927708089352, 49.071349650621414, 47.217223942279816, 44.976294189691544, 46.54301092028618, 49.97594811022282, 55.31248055398464, 55.84853298962116, 55.91633655130863, 3.860712298192084, 0.0754347322799731, 0.6673422188032418, 1.4735716162249446, 42.32988819479942, 52.80198186635971, 53.33959221839905, 50.22415079176426, 44.908524826169014, 43.26580837368965, 31.83099076151848, 24.007176384329796, 29.41123690456152, 25.388618856668472, 0.4815603909082711, 0.1864139299141243, 0.023667855675739702, 0.09941600990714505, 0.05096265384054277, 0.03934817257686518, 0.05479419902258087, 0.010592284161248244, 0.06570986661245115, 0.004049109484185465, 0.002800736847348162, 0.07823367544915527, 0.08880565073923208, 0.012889951103716157, 0.10415856362669729, 0.10199784519500099, 0.006082338541091303, 0.013855667057214305, 0.04642935236915946, 0.07719414177699946, 0.02169216393667739, 0.04530584468739107, 0.08453539980109781, 0.057971451969933696, 0.029568796162493527, 0.08112883806461468, 0.042051612472278066, 0.3917199413990602, 0.08334066820680164, 13.971760980784893, 67.28900089859962, 33.923435881733894, 28.5147700086236, 51.504636481404305, 54.25402075052261, 69.81856316328049, 61.909082382917404, 64.73718702793121, 55.83020657300949, 62.67412953078747, 32.75412082672119, 0.29450414702296257, 0.09286849366617389, 0.7267862290609628, 0.4980200686259195, 36.41491658985615, 69.33646023273468, 62.4461417645216, 58.665321841835976, 49.95980277657509, 49.995566457509995, 47.89681367576122, 47.45484039187431, 47.134300991892815, 48.04690942168236, 48.62284451723099, 52.15013064444065, 50.05365014076233, 49.19005908071995, 47.75128148496151, 44.55420903861523, 44.374258294701576, 45.28043366968632, 46.10117822885513, 46.2551611661911, 46.56384140253067, 46.20017051696777, 50.20913019776344, 49.86557923257351, 52.87676565349102, 54.280167147517204, 59.08821254968643, 52.906062081456184, 52.150940001010895, 57.78512567281723, 55.411062464118004, 47.38558530807495, 43.26577417552471, 41.96459099650383, 41.321885883808136, 41.61094017326832, 42.67302878201008, 42.86340616643429, 42.943855449557304, 50.39335571229458, 51.461083218455315, 54.926273077726364, 46.41266271471977, 45.17970487475395, 43.92586335539818, 43.535346910357475, 43.653873950242996, 46.909527853131294, 45.806545838713646, 42.92466647922993, 38.33680026233196, 40.54587632417679, 42.303297221660614, 40.19403800368309, 40.717463716864586, 40.870675295591354, 39.88084360957146, 39.507528841495514, 41.250461116433144, 40.003561824560165, 40.22227808833122, 40.28401717543602, 40.18548846244812, 37.31575325131416, 40.63289165496826, 42.58241884410381, 44.099362045526505, 43.24776314198971, 42.11084894835949, 43.782664239406586, 45.23912228643894, 42.91110880672932, 47.510572001338005, 53.44076558947563, 49.394856691360474, 50.27276538312435, 48.505525812506676, 42.52657324075699, 40.322216525673866, 39.77532707154751, 40.10576494038105, 39.61192063987255, 39.12915274500847, 40.82199990749359, 40.69193668663502, 43.66393581032753, 47.92493596673012, 52.06858702003956, 50.6788419932127, 51.40613056719303, 52.52990886569023, 50.61032027006149, 49.53543774783611, 48.80766659975052, 49.00405526161194, 47.41470694541931, 46.51602476835251, 46.63389444351196, 47.9805725812912, 43.37349459528923, 42.54808768630028, 41.45928271114826, 42.248777747154236, 41.10902890563011, 43.56605306267738, 46.66525796055794, 49.07130405306816, 51.447156965732574, 53.58423829078674, 50.77500343322754, 49.425239861011505, 47.11044207215309, 49.00298371911049, 53.774771466851234, 58.878843784332275, 59.14124250411987, 55.80610826611519, 4.468887951225042, 0.06458566873334348, 0.9579933725763112, 1.979432178195566, 47.805686965584755, 58.44820909202099, 59.56767462193966, 54.212036803364754, 52.109666615724564, 48.730865120887756, 44.5361752063036, 26.416845582425594, 33.38934414088726, 35.08112356066704, 0.6056881521362811, 0.04949662645231001, 0.06438402720959857, 0.01533471357106464, 0.0460535436286591, 0.018947460630442947, 0.02345006872928934, 0.03691435122163966, 0.0726122481864877, 0.036548828647937626, 0.03027642840606859, 0.01640236165258102, 0.021789153361169156, 0.15373710833955556, 0.18742569984169677, 0.2834046754287556, 0.10498452946194448, 0.14069257158553228, 0.1422798028215766, 0.15807350690010935, 0.1753277872921899, 0.12341025285422802, 0.16781190934125334, 0.17294815013883635, 0.17121588840382174, 0.3229280171217397, 0.1328954048221931, 0.7424479199107736, 0.3502319863764569, 19.44453701376915, 76.76664993166924, 55.02472959458828, 36.4889670163393, 47.16572530567646, 64.69470530748367, 76.68762937188148, 66.26277476549149, 67.40590542554855, 60.07627733051777, 70.82344964146614, 37.36258573830128, 0.42779912415426224, 0.3861498855985701, 1.1090105096809566, 0.4544397915014997, 39.49331380426884, 71.20649188756943, 65.54764553904533, 61.81194819509983, 53.03004562854767, 53.950990810990334, 50.77973037958145, 50.520728677511215, 49.348191395401955, 49.68212127685547, 49.634996205568314, 54.95292104780674, 52.97076880931854, 50.434522703289986, 49.16476383805275, 47.23208114504814, 46.863873302936554, 47.41390138864517, 49.33192066848278, 49.36383135616779, 51.239612102508545, 48.890920132398605, 51.847275495529175, 50.01140020787716, 54.44374457001686, 58.03292937576771, 60.0215108692646, 55.07833331823349, 53.631222769618034, 60.40745995938778, 55.960930958390236, 48.20028439164162, 45.19907623529434, 45.29766194522381, 44.032930210232735, 44.351463317871094, 46.05711579322815, 45.392645448446274, 45.47842964529991, 50.47639645636082, 53.141288459300995, 55.49627289175987, 46.277025192976, 45.01915588974953, 46.04202680289745, 43.51788304746151, 46.318192183971405, 49.37265448272228, 48.070247769355774, 45.7968183606863, 39.9837800860405, 43.02897468209267, 45.842947885394096, 43.0524992197752, 42.75412783026695, 41.99101857841015, 42.09625393152237, 42.21680246293545, 44.22110751271248, 43.88726122677326, 44.04178373515606, 42.28380806744099, 43.31220008432865, 39.247341603040695, 42.81026601791382, 44.269870296120644, 48.03856506943703, 44.65709611773491, 43.58545482158661, 43.87971483170986, 44.72244121134281, 40.92213213443756, 46.61292336881161, 53.87243762612343, 51.6067636013031, 51.66165925562382, 51.930601224303246, 44.41640563309193, 42.600840255618095, 40.01773126423359, 43.88921432197094, 42.27381460368633, 42.18101978302002, 43.327878043055534, 43.58912542462349, 45.549888610839844, 52.22813665866852, 52.708575278520584, 52.365218102931976, 51.88626140356064, 54.63699460029602, 51.910131722688675, 50.9295829385519, 52.01567105948925, 52.399518862366676, 49.039742946624756, 49.01151806116104, 50.35421021282673, 49.66753765940666, 46.25053681433201, 44.96118240058422, 43.141539841890335, 45.197389125823975, 43.05816471576691, 47.29580372571945, 48.69618818163872, 51.98995403945446, 53.93254280090332, 57.23238833248615, 53.576000332832336, 53.04614916443825, 49.22941356897354, 52.186646685004234, 56.509800106287, 60.81366956233978, 61.65343590080738, 60.920535027980804, 5.259012803435326, 0.19772090599872172, 1.0151386843062937, 3.390369024127722, 53.16464580595493, 64.89360183477402, 64.91203084588051, 60.33203400671482, 59.951058849692345, 56.0585705190897, 45.97347468137741, 35.28619095683098, 43.46519887447357, 48.50438207387924, 1.2126659788191319, 0.3405753686092794, 0.11166293828864582, 0.20138757565291598, 0.22295740025583655, 0.2339506705175154, 0.14301715622423217, 0.07769215255393647, 0.13308931316714734, 0.11814133831649087, 0.14865467324852943, 0.12090313699445687, 0.1419885692303069], [0.01615548066183692, 0.04402489408676047, 0.06618386891204864, 0.06139696073660161, 0.03532128299411852, 0.09044101025210693, 0.04369920257886406, 0.10892098463955335, 0.004462949118533288, 0.03142034700431395, 0.07952248910441995, 0.010564813564997166, 0.06357010643114336, 0.052052052415092476, 0.0910286873113364, 0.12711548450170085, 0.3646685101557523, 37.19488173723221, 47.844300493597984, 34.144291430711746, 25.248890854418278, 42.436795458197594, 62.59184114634991, 57.48064801096916, 56.05974845588207, 48.744867369532585, 57.537367567420006, 32.24566251039505, 0.8386825653724372, 0.012350446850177832, 0.48195355106145144, 0.35394830571021885, 25.032074488699436, 71.0238128900528, 58.616467863321304, 56.91406041383743, 51.93689748644829, 54.695739448070526, 47.23992772400379, 50.18197685480118, 41.70946128666401, 42.10109867155552, 41.92571148276329, 42.99557827413082, 40.89717887341976, 43.216931596398354, 41.77023142576218, 42.90012739598751, 41.497805044054985, 43.41365844011307, 43.535080924630165, 44.17689308524132, 45.569244772195816, 46.75006560981274, 48.1854347884655, 49.2930943518877, 52.74285323917866, 51.372715160250664, 56.12472116947174, 55.255749598145485, 51.072576865553856, 58.148177191615105, 50.65528705716133, 44.77580174803734, 41.73496171832085, 41.66866287589073, 39.82357308268547, 40.1630012691021, 41.38840511441231, 41.651464998722076, 42.360803335905075, 45.901274755597115, 49.86067749559879, 55.644875317811966, 48.048125356435776, 43.81674461066723, 45.457131788134575, 45.56732967495918, 43.610936254262924, 38.91734831035137, 36.881257966160774, 38.84446062147617, 37.594551891088486, 40.03457576036453, 37.59596161544323, 38.473258540034294, 39.732526168227196, 37.09170587360859, 38.102964609861374, 38.12547840178013, 38.21363367140293, 39.01250660419464, 38.86526830494404, 37.74236775934696, 39.317786023020744, 37.751160487532616, 38.625383377075195, 37.69966185092926, 38.67041476070881, 40.41260227560997, 44.9418680369854, 45.17028138041496, 44.02152322232723, 45.39555989205837, 44.83218692243099, 52.033640295267105, 50.515222772955894, 47.44356259703636, 44.92096535861492, 41.66889846324921, 39.38345409929752, 39.875037521123886, 38.652532920241356, 37.14388847351074, 38.593259900808334, 38.25447387993336, 39.43019159138203, 40.05901224911213, 47.773958668112755, 49.17671039700508, 49.36049893498421, 48.24042163789272, 45.38814269006252, 47.64268331229687, 47.424202635884285, 46.62711560726166, 47.05776929855347, 46.83722913265228, 43.10200296342373, 42.24526673555374, 43.99222679436207, 40.733730643987656, 39.98353689908981, 38.915456011891365, 38.660284504294395, 38.50588358938694, 39.176141023635864, 39.12038281559944, 39.85492520034313, 40.98016642034054, 42.614397928118706, 41.12314134836197, 41.442305222153664, 42.89663918316364, 50.80921299755573, 49.36059772968292, 57.52037487924099, 52.47152119874954, 55.16936503350735, 3.0352122941985726, 0.17306676018051803, 0.4583124368218705, 1.436687232926488, 40.938171073794365, 54.10523973405361, 53.008398190140724, 47.01353967189789, 58.23771558701992, 39.06142137944698, 20.6617845967412, 23.572510108351707, 42.058613151311874, 10.793370231986046, 0.5095886962953955, 0.07228741014841944, 0.11012376111466438, 0.04078137477335986, 0.13799314299831167, 0.050370531316730194, 0.006191437960296753, 0.07926235892227851, 0.025846997923508752, 0.08527362893801183, 0.07451563433278352, 0.07703201219555922, 0.05936698646110017, 0.051938752440037206, 0.02887132763135014, 0.07743104273686185, 0.031103179062483832, 0.010227731945633423, 0.01150798678281717, 0.04547984863165766, 0.026060241070808843, 0.05836508709762711, 0.05401012000220362, 0.042576581763569266, 0.11659848751151003, 0.10554290653089993, 0.03312387278128881, 0.023278363587451167, 0.12172582995845005, 0.8990035566966981, 46.81618966162205, 49.146965593099594, 21.806801855564117, 41.44767053425312, 53.431361094117165, 67.51299887895584, 62.95526124536991, 62.42560386657715, 55.51931485533714, 62.461899518966675, 37.069218680262566, 0.7528229069430381, 0.015818057654541917, 0.7674192893318832, 0.31463926658034325, 28.283989392220974, 73.03738564252853, 61.7670764029026, 60.7792966067791, 55.64863331615925, 56.94374442100525, 48.825970217585564, 50.725305899977684, 45.91030687093735, 44.671508744359016, 43.842294439673424, 45.101106092333794, 41.18545800447464, 44.31777812540531, 44.84758749604225, 43.892349153757095, 43.95715467631817, 45.03864124417305, 45.843597650527954, 47.1242543309927, 48.17021280527115, 48.62696349620819, 49.88498859107494, 50.751418098807335, 54.34347175061703, 53.22262689471245, 56.81353680789471, 56.692213118076324, 53.755939677357674, 58.597852662205696, 52.791068851947784, 45.71246288716793, 43.91659565269947, 44.02099885046482, 42.24978469312191, 40.95723085105419, 42.669844552874565, 43.27297478914261, 44.125569239258766, 46.390696093440056, 52.04211764037609, 56.232145205140114, 48.8329466432333, 44.72833089530468, 44.87179979681969, 46.826160326600075, 47.22799636423588, 43.450915440917015, 41.130041778087616, 40.37751875817776, 39.2253103852272, 42.53125458955765, 40.95219612121582, 41.1770224571228, 39.770432934165, 40.83297371864319, 39.67548742890358, 41.76498770713806, 39.772245436906815, 40.71805268526077, 40.628119111061096, 39.9934733659029, 40.17375849187374, 39.43528711795807, 39.799600169062614, 39.45928283035755, 41.491083204746246, 42.75249771773815, 45.35760372877121, 44.24459025263786, 42.888306230306625, 46.1200138181448, 44.54688303172588, 52.411651611328125, 51.94730132818222, 47.402395606040955, 46.33622221648693, 43.367145135998726, 41.181654408574104, 41.35741397738457, 39.92035388946533, 38.460704013705254, 40.13383403420448, 40.51652669906616, 41.22988902032375, 42.26467989385128, 50.278256088495255, 50.072580724954605, 51.90167337656021, 48.40063624083996, 50.138970762491226, 48.08814860880375, 50.113192945718765, 47.21011832356453, 48.311040848493576, 48.40931497514248, 46.671584621071815, 46.304634511470795, 45.676665008068085, 43.81668761372566, 42.58459232747555, 40.42017146945, 40.490418300032616, 41.90276451408863, 41.61322385072708, 41.472961977124214, 42.312713116407394, 42.74724259972572, 45.72060585021973, 44.353161826729774, 44.01828959584236, 45.312819331884384, 54.11755107343197, 53.55471007525921, 59.008629620075226, 56.04084827005863, 58.33803400397301, 3.216388472355902, 0.14399944804608822, 0.5614608409814537, 1.482591857202351, 44.40359652042389, 60.76908275485039, 59.38442185521126, 52.090777829289436, 65.8299171924591, 43.81278522312641, 33.671703189611435, 21.28665916621685, 49.88165616989136, 15.171145722270012, 0.45418633322697133, 0.053428832834470086, 0.15408195467898622, 0.030356808565557003, 0.11933631481952034, 0.034930334441014566, 0.09503168344963342, 0.07446804782375693, 0.014405692181753693, 0.053822679474251345, 0.040899969972088, 0.0399840187310474, 0.019945174281019717, 0.10292007500538602, 0.1836337853455916, 0.11172412836458534, 0.1374405695241876, 0.11458456589025445, 0.12011450118734501, 0.11089894178439863, 0.19774305168539286, 0.15517556865233928, 0.10355372811318375, 0.17424974357709289, 0.16530998109374195, 0.15707843529526144, 0.09956077323295176, 0.19749792030779645, 0.2976363367633894, 1.4067992242053151, 56.8630101531744, 62.954999059438705, 42.79818266630173, 40.54368384182453, 54.41275343298912, 72.35723733901978, 68.20933431386948, 68.79812031984329, 62.34615013003349, 68.83918851613998, 42.44312971830368, 1.1650121421553195, 0.14631496364017949, 1.3410759321413934, 0.2514424530090764, 29.625828489661217, 77.1479594707489, 64.58329528570175, 63.00752364099026, 60.0437168776989, 60.907201543450356, 51.41166687011719, 56.21201388537884, 48.04067775607109, 47.77686931192875, 47.808286026120186, 47.57989928126335, 44.02399308979511, 47.70741283893585, 47.36298032104969, 47.82548010349274, 45.761658847332, 49.14055533707142, 47.72214084863663, 49.02517832815647, 50.88890612125397, 52.32953421771526, 51.730876341462135, 54.204482808709145, 56.39890305697918, 57.946309223771095, 59.61541526019573, 57.96398587524891, 52.78090059757233, 62.20687620341778, 54.248568043112755, 48.22954282164574, 44.9952095746994, 46.303391978144646, 44.60044115781784, 43.79801921546459, 46.45283415913582, 45.2153355628252, 44.83220212161541, 47.383985593914986, 53.229303136467934, 59.23611581325531, 50.5611927062273, 45.833778977394104, 47.04280190169811, 48.26037056744099, 49.056507647037506, 44.78281617164612, 43.5398268699646, 43.75250145792961, 43.0044773966074, 44.81356792151928, 43.12550090253353, 44.60930608212948, 43.03888075053692, 43.65840710699558, 42.740220576524734, 44.41851831972599, 44.02864784002304, 43.48012067377567, 44.32356521487236, 42.8195945173502, 43.57818581163883, 40.987530425190926, 43.5976255685091, 41.826525405049324, 46.10720470547676, 43.99801768362522, 47.35212430357933, 44.320096001029015, 43.281281143426895, 45.758884996175766, 44.95294064283371, 53.477350026369095, 54.145905151963234, 51.28860667347908, 48.82733054459095, 45.55026859045029, 44.212573170661926, 43.77593860030174, 42.488951459527016, 40.07430262863636, 42.710183188319206, 42.203670367598534, 43.48979115486145, 44.480143412947655, 51.95299722254276, 51.59831665456295, 53.914239183068275, 50.62160186469555, 50.653953328728676, 50.55133603513241, 51.30029484629631, 50.50102673470974, 52.08166591823101, 51.25764213502407, 49.43757779896259, 48.365218341350555, 49.44880239665508, 44.82451893389225, 45.18597453832626, 44.20154236257076, 42.8731070458889, 42.66869701445103, 42.329683005809784, 43.08162085711956, 43.35058182477951, 45.59539496898651, 46.877286583185196, 45.692931935191154, 46.59666024148464, 47.664684131741524, 57.73911014199257, 53.62461492419243, 63.155734688043594, 58.15509282052517, 61.05840303003788, 4.605778455734253, 0.3587773418985307, 1.0063365753740072, 2.0512140076607466, 51.69964961707592, 65.46998530626297, 63.254582583904266, 58.40975895524025, 69.45114567875862, 51.36067360639572, 34.32682603597641, 31.99783220887184, 62.32924863696098, 24.464231058955193, 0.5480863305274397, 0.14197862445143983, 0.13569233677117154, 0.15493891260121018, 0.2435070983483456, 0.14009886828716844, 0.26889859756920487, 0.15657260228181258, 0.16103310277685523, 0.1583269503316842, 0.1203057674865704, 0.2464017563033849, 0.19064311782130972], [0.010698670103010954, 0.07564282306702808, 0.04464164849196095, 0.07983470321050845, 0.04153744514042046, 0.06496775604318827, 0.0650028967356775, 0.02426274641038617, 0.08991781098302454, 0.050831445842050016, 0.025988749985117465, 0.09297907366999425, 0.023042360626277514, 0.039465632289648056, 0.04663827065087389, 0.15489343379158527, 0.09047271480085328, 12.515503372997046, 53.41331206262112, 41.78427167236805, 28.1970177590847, 27.648217007517815, 56.82634212076664, 57.49493524432182, 56.569434106349945, 48.440944477915764, 54.97618719935417, 34.62657295167446, 1.0212474502623081, 0.37343553034588695, 0.8855759084690362, 0.4558338416973129, 21.63795981556177, 70.1762455701828, 57.93089345097542, 58.634057119488716, 53.38789522647858, 56.51417747139931, 55.47624796628952, 55.24260610342026, 46.63747385144234, 43.18033196032047, 41.20897114276886, 44.55938436090946, 41.988468915224075, 44.38697621226311, 41.863664612174034, 42.15161316096783, 41.23050458729267, 41.17669187486172, 45.5150330811739, 44.62327033281326, 49.08137731254101, 47.43187062442303, 50.309273824095726, 51.20736703276634, 53.393374532461166, 54.91963103413582, 55.374808609485626, 48.90455760061741, 56.43345080316067, 56.818328350782394, 50.13083539903164, 43.96753951907158, 42.70810469985008, 40.87976820766926, 39.54222097992897, 40.75048394501209, 41.42821557819843, 41.424358785152435, 44.12317156791687, 44.54384699463844, 50.26159778237343, 52.52363160252571, 56.02167829871178, 48.42090055346489, 47.094615921378136, 41.57795034348965, 38.572946190834045, 37.09588564932346, 38.01469534635544, 38.89917388558388, 37.56350375711918, 39.601376205682755, 38.70785415172577, 38.63215461373329, 38.72817926108837, 37.634134367108345, 36.521546468138695, 37.62128345668316, 38.2644597440958, 38.557142838835716, 37.93572798371315, 37.689204812049866, 38.94642435014248, 37.70384922623634, 38.96990329027176, 37.781558856368065, 38.43573175370693, 36.76020406186581, 37.527056112885475, 40.514778792858124, 45.29890447854996, 43.82931813597679, 47.22379378974438, 52.17494711279869, 52.57297955453396, 47.37328916788101, 47.59586222469807, 42.34856799244881, 40.313940569758415, 38.417013958096504, 40.708518996834755, 36.35540038347244, 37.83203534781933, 39.29475545883179, 40.237389877438545, 38.40156018733978, 44.92236748337746, 46.3163036853075, 49.09186474978924, 46.766579523682594, 48.18068124353886, 46.99487887322903, 47.1063344925642, 44.51560690999031, 45.695796981453896, 43.40435653924942, 43.83260115981102, 41.727198734879494, 39.57390747964382, 39.12307307124138, 39.33117650449276, 38.69100585579872, 39.09876957535744, 38.41391332447529, 41.33967272937298, 39.22467961907387, 40.846588388085365, 39.56791140139103, 42.1169476211071, 40.26651531457901, 45.85905522108078, 49.2826297134161, 53.69483895599842, 52.40279048681259, 58.81180018186569, 48.12914080917835, 50.276926159858704, 2.5049661844968796, 0.012314594623603625, 0.2655868971487507, 3.4228857792913914, 50.53740218281746, 53.95292870700359, 52.80088372528553, 58.75222697854042, 51.3123781979084, 33.90192523598671, 35.77038757503033, 30.340532138943672, 30.745850689709187, 0.9307938977144659, 0.11623317273915745, 0.11910291679669172, 0.05141932699189056, 0.04804845142643899, 0.05787348476587795, 0.024777231010375544, 0.019232942577218637, 0.031163415478658862, 0.09626192681025714, 0.02312781707587419, 0.10711300899856724, 0.09091542073292658, 0.07845694315619767, 0.009250062776118284, 0.0731791376892943, 0.022378639405360445, 0.032352076304960065, 0.023501677678723354, 0.019263921676611062, 0.01989257270906819, 0.02773629625153262, 0.053476204120670445, 0.03220806254830677, 0.05915531481150538, 0.030367274703166913, 0.08204618454328738, 0.02552220812503947, 0.113268700952176, 0.20376253727590665, 0.02939623755082721, 18.7139730155468, 62.91488841176033, 31.628989800810814, 32.73487485945225, 46.942061707377434, 59.27663303911686, 64.4338721036911, 60.55646516382694, 56.215099319815636, 62.5510199368, 39.12857137620449, 0.9236365067772567, 0.3175352158723399, 0.819651820929721, 0.4794301599031314, 23.484189547598362, 72.65439659357071, 61.061142683029175, 60.026040226221085, 54.34849128127098, 58.74293267726898, 57.970122545957565, 56.8614636361599, 49.20525446534157, 45.626758486032486, 42.659733295440674, 47.31269381940365, 45.28157360851765, 44.16026517748833, 44.0909530967474, 43.85661967098713, 43.63273188471794, 44.08601336181164, 48.188904002308846, 47.58943296968937, 50.37698619067669, 49.81390580534935, 51.796141639351845, 53.53707902133465, 52.42025054991245, 57.46226079761982, 57.86310128867626, 50.9895209223032, 59.255380779504776, 58.39006841182709, 53.12553450465202, 45.92009134590626, 44.353762194514275, 42.066193744540215, 40.93818247318268, 43.42544920742512, 43.025372475385666, 44.71342049539089, 46.08429953455925, 47.003675401210785, 51.20508335530758, 55.93590930104256, 57.44321621954441, 49.790054485201836, 49.34847258031368, 45.73977202177048, 41.849688962101936, 38.057310059666634, 40.388279780745506, 40.38537293672562, 39.150689989328384, 41.362908482551575, 40.765656530857086, 39.70052428543568, 40.67680589854717, 40.37671700119972, 38.65342207252979, 39.345338344573975, 41.52933955192566, 41.62949077785015, 40.147574096918106, 40.49921862781048, 39.88975413143635, 40.01432664692402, 41.470142528414726, 39.14717137813568, 40.96257336437702, 38.28164242208004, 40.72173468768597, 42.5166329741478, 44.76764738559723, 45.15678450465202, 46.70196779072285, 52.19904541969299, 53.95596094429493, 48.29938307404518, 47.12172366678715, 43.941647708415985, 41.838350370526314, 39.818025380373, 42.40573972463608, 39.10180181264877, 39.180936366319656, 40.27849607169628, 41.648531556129456, 41.21578797698021, 47.44777277112007, 49.110719338059425, 50.63530392944813, 49.572983533144, 50.428853407502174, 46.48119203746319, 49.2051936686039, 46.79478161036968, 47.936270758509636, 45.60630798339844, 46.791798770427704, 43.330074325203896, 42.839539647102356, 42.112346068024635, 42.757490649819374, 40.123046413064, 42.56008744239807, 41.365173161029816, 44.033728167414665, 41.784070283174515, 42.659649699926376, 40.80429665744305, 44.688486233353615, 42.44480922818184, 47.56726115942001, 51.69605880975723, 57.95832417905331, 54.83382023870945, 61.044165194034576, 50.78061953186989, 51.32208667695522, 2.9473398718982935, 0.10543761061853729, 0.22810236871009693, 3.7846517795696855, 55.12294292449951, 59.732289388775826, 55.96822276711464, 65.58934450149536, 55.54014153778553, 44.53468568623066, 41.73796735703945, 28.350172340869904, 42.60145962238312, 1.1963570164516568, 0.08932996322982945, 0.14590739097911865, 0.05284417260554619, 0.060817206103820354, 0.038356982404366136, 0.04382093335152604, 0.11591960792429745, 0.040848906501196325, 0.013052760677965125, 0.01723806075460743, 0.029415409080684185, 0.05907566381210927, 0.017897069337777793, 0.06452974048443139, 0.20336200017482042, 0.11627039886661805, 0.12872587074525654, 0.2309666431392543, 0.17234113271115348, 0.1323982994654216, 0.06209579296410084, 0.12839674309361726, 0.16264354839222506, 0.1387831146712415, 0.21267632459057495, 0.15290640760213137, 0.22299572476185858, 0.16144380730111152, 0.4568430734798312, 0.26975625311024487, 24.678176678717136, 75.26888430118561, 50.0209528952837, 39.8857681453228, 43.14689375460148, 66.61898285150528, 70.17540961503983, 67.80215576291084, 62.43644468486309, 66.05242565274239, 46.68319679796696, 1.2475654436275363, 0.6784232554491609, 1.7377818888053298, 0.5483460228424519, 26.146932765841484, 74.68152701854706, 64.61996331810951, 62.46302805840969, 57.380071207880974, 62.715604305267334, 61.48301124572754, 61.29798777401447, 51.68207176029682, 46.566505059599876, 44.81416068971157, 51.51196248829365, 47.02543683350086, 47.10030421614647, 46.63197934627533, 46.219405084848404, 47.714978232979774, 45.39446175098419, 50.472399070858955, 49.05467614531517, 54.38863232731819, 50.77735550701618, 55.359662622213364, 55.39183929562569, 56.781952902674675, 58.53338532149792, 58.599893152713776, 52.036505341529846, 60.74736692011356, 60.43032333254814, 55.00501625239849, 49.22796204686165, 46.72914393246174, 45.407764837145805, 43.08916725218296, 46.306462213397026, 45.930198803544044, 46.83574341237545, 48.43522198498249, 48.771792724728584, 53.52355934679508, 58.11837159097195, 60.56463472545147, 51.49482920765877, 52.4557900428772, 47.93927259743214, 43.897699266672134, 41.21948517858982, 42.917701452970505, 45.9250158816576, 42.11609646677971, 44.0383867174387, 43.40123690664768, 44.25297260284424, 42.42233343422413, 43.42606097459793, 41.10487572848797, 41.21673792600632, 42.20678240060806, 43.86232316493988, 42.50867240130901, 41.73382557928562, 42.70848087966442, 42.61314019560814, 43.81213925778866, 42.898972257971764, 43.34707461297512, 39.997292160987854, 42.4579793214798, 43.96554462611675, 46.19549296796322, 46.08256682753563, 49.88685429096222, 54.313020184636116, 54.70902353525162, 49.82138380408287, 50.07496699690819, 45.765204057097435, 43.76007825136185, 42.990573942661285, 45.25994896888733, 41.06697276234627, 42.42510728538036, 42.79390789568424, 44.6149829775095, 42.10260719060898, 49.80116508901119, 50.12644663453102, 53.65701958537102, 51.663707345724106, 52.337004616856575, 49.86575022339821, 52.2502476722002, 49.56433139741421, 50.47889292240143, 47.85034216940403, 48.80992367863655, 46.52955204248428, 44.66953285038471, 45.27770921587944, 44.14921537041664, 42.195686995983124, 43.89493301510811, 44.06914986670017, 46.76639713346958, 43.79776082932949, 45.27771681547165, 43.53017158806324, 45.848195403814316, 46.76611974835396, 50.10943494737148, 55.52265867590904, 58.980450332164764, 59.05979387462139, 63.95762085914612, 52.465426325798035, 53.96311976015568, 4.117571152746677, 0.15454596024937928, 1.2646635761484504, 3.7877141777426004, 62.41099365055561, 66.1690565943718, 65.04326820373535, 67.95668587088585, 63.387351259589195, 45.72898440063, 49.40301485359669, 43.99873584508896, 52.54556402564049, 2.9700837889686227, 0.22064984048483893, 0.2859479561448097, 0.19636374054243788, 0.19068533118115738, 0.124628443736583, 0.1197035591758322, 0.17382329067913815, 0.13929286622442305, 0.3094023757148534, 0.1159401134646032, 0.3321048215730116, 0.3498962981393561, 0.14831536333076656], [0.03987772091932129, 0.03922378491552081, 0.09492633558693342, 0.09100668263272382, 0.05936146488238592, 0.11416447319788858, 0.030822656517557334, 0.022178155631991103, 0.05719447901356034, 0.025594112958060578, 0.03686374046083074, 0.04664577005314641, 0.08024062830372714, 0.022930930863367394, 0.024221939420385752, 0.09775236714631319, 0.12956145481439307, 0.4510033212136477, 40.89166536927223, 44.09617021679878, 38.985634446144104, 24.15543492883444, 39.39056731760502, 63.89990955591202, 61.30730487406254, 47.146813720464706, 51.91569082438946, 41.48035258054733, 1.3799606706015766, 0.36500871065072715, 0.5796077765990049, 0.3687081387033686, 19.115391075611115, 69.83921125531197, 55.971581786870956, 61.46984875202179, 56.13149620592594, 58.87068182229996, 57.64666110277176, 58.712150529026985, 55.80717220902443, 53.670961037278175, 43.93684096634388, 43.05797852575779, 42.12523117661476, 43.55372652411461, 41.94309554994106, 42.82356910407543, 42.23257541656494, 43.08709256350994, 44.157107546925545, 44.74750466644764, 48.18959556519985, 49.32887323200703, 51.71686269342899, 53.91337662935257, 54.856729209423065, 53.77004452049732, 47.63476453721523, 56.565755903720856, 57.9992251843214, 51.2410294264555, 44.80071321129799, 42.64015294611454, 42.78441600501537, 40.54395742714405, 40.75670801103115, 42.44037866592407, 40.306291580200195, 46.89660854637623, 43.13921436667442, 44.40256677567959, 46.708499640226364, 49.7299987077713, 49.6519660949707, 44.28668059408665, 41.17317706346512, 38.72344471514225, 38.19073989987373, 39.26566421985626, 37.35757000744343, 38.06854985654354, 38.30905795097351, 38.08278389275074, 38.268175944685936, 40.07679909467697, 41.40686072409153, 38.413670137524605, 37.88471192121506, 39.44444082677364, 38.98029573261738, 38.043668791651726, 39.10978518426418, 37.01087661087513, 39.269361421465874, 39.39752474427223, 39.87969607114792, 37.7324540913105, 38.88578720390797, 37.79079616069794, 36.74162685871124, 37.45903976261616, 41.460992619395256, 42.52268984913826, 48.918404057621956, 49.339676052331924, 50.73229752480984, 45.463982820510864, 43.07516120374203, 42.45485968887806, 43.893112912774086, 40.673154294490814, 38.72630976140499, 37.65194021165371, 37.05287955701351, 37.32635848224163, 38.19650039076805, 39.03229974210262, 40.78868709504604, 42.839744836091995, 48.34765188395977, 46.96403592824936, 47.89059340953827, 47.589961141347885, 46.382822915911674, 44.819077625870705, 44.73887152969837, 41.30551256239414, 41.15986257791519, 38.75741109251976, 39.226271733641624, 37.42176756262779, 37.971723452210426, 36.68760895729065, 38.2334990054369, 38.224732875823975, 39.336925595998764, 38.678147345781326, 40.06528191268444, 39.34088118374348, 42.73301236331463, 41.78408548235893, 52.30579309165478, 52.6377584785223, 57.490554079413414, 52.24537633359432, 60.42721129953861, 45.212147533893585, 43.08103188872337, 1.4558880776166916, 0.05950914113782346, 0.13890099740820006, 4.839473515748978, 54.155408442020416, 55.23788295686245, 52.77197107672691, 59.5905189961195, 45.162822380661964, 30.751390792429447, 26.308547593653202, 40.42691990733147, 12.578232306987047, 0.4580316971987486, 0.06417450407752767, 0.13546506146667525, 0.012479827310016844, 0.12386207235977054, 0.03630658051406499, 0.04287379706511274, 0.01663891009229701, 0.015182511142484145, 0.06433671529521234, 0.025915913756762166, 0.06403137347660959, 0.06349872666760348, 0.03348532467498444, 0.06311079865554348, 0.05526289496629033, 0.04145258055359591, 0.04242112780048046, 0.06315925347735174, 0.041902507582562976, 0.04125565537833609, 0.06467739076470025, 0.03561675795936026, 0.030734628526261076, 0.05013342626625672, 0.014166445107548498, 0.01112729563828907, 0.05895395159313921, 0.05344406912627164, 0.037976928579155356, 0.10369528536102735, 1.667555719614029, 52.709981203079224, 46.58573962748051, 31.630017645657063, 39.526695013046265, 51.43003508448601, 66.85830920934677, 65.89676320552826, 51.59709312021732, 59.9584798514843, 45.335621908307076, 1.8285057018510997, 0.6726754107512534, 0.662179245846346, 0.4085811210097745, 21.452558264136314, 71.11971974372864, 59.91145357489586, 64.17319849133492, 58.58803778886795, 63.44873696565628, 59.63188737630844, 60.855835899710655, 57.50085532665253, 56.31007142364979, 45.963530614972115, 44.76186029613018, 43.545260578393936, 45.25570459663868, 43.4009101241827, 44.15047690272331, 44.5465524494648, 45.18958814442158, 44.54053737223148, 47.889020293951035, 49.79529820382595, 49.98665973544121, 52.963009625673294, 54.99764084815979, 55.474887639284134, 55.31017407774925, 49.92438107728958, 57.65434429049492, 60.98219431936741, 54.44641202688217, 46.99234440922737, 43.30343395471573, 45.16086548566818, 41.681760773062706, 42.62560352683067, 43.23084644973278, 43.74041050672531, 48.925855457782745, 47.06855311989784, 44.82413895428181, 48.77373822033405, 52.68950790166855, 54.47231903672218, 48.031907826662064, 44.04851697385311, 40.49157343804836, 40.25050677359104, 42.16306954622269, 39.502273723483086, 39.40456956624985, 40.56356817483902, 40.85540771484375, 41.810980439186096, 40.649462565779686, 43.736812099814415, 40.26716507971287, 40.35731144249439, 39.778891280293465, 40.44765159487724, 40.823006853461266, 40.42006127536297, 38.14936012029648, 41.43825463950634, 40.126812011003494, 41.11019164323807, 39.7143479436636, 41.2582240998745, 38.99979628622532, 39.72005903720856, 38.59902799129486, 43.1457994133234, 44.973372146487236, 49.76290874183178, 50.9097708016634, 53.046825528144836, 45.72153300046921, 45.0987084209919, 43.977810367941856, 45.125048607587814, 41.47433750331402, 40.78646041452885, 38.907867819070816, 39.57534000277519, 40.418438762426376, 40.38379602134228, 39.368216916918755, 41.504211500287056, 44.0473086386919, 47.95543313026428, 46.68075732886791, 50.47884352505207, 49.393519163131714, 49.42191883921623, 47.075955122709274, 48.161420077085495, 43.382906690239906, 43.91708582639694, 39.31900195777416, 41.502854973077774, 38.4290137141943, 41.03313937783241, 39.71343979239464, 43.12445975840092, 40.29993072152138, 41.65386646986008, 39.81530472636223, 43.44797059893608, 41.85927204787731, 45.8866873383522, 43.19274589419365, 57.161894515156746, 54.88680459558964, 61.072743460536, 54.95141252875328, 64.48478937149048, 47.992496341466904, 47.10715524852276, 1.506904971320182, 0.06652617710642517, 0.11149873069371097, 5.531811090186238, 59.66995753347874, 61.946187391877174, 57.84449748694897, 66.0538087785244, 49.709103628993034, 45.63265956938267, 28.809332102537155, 44.62735891342163, 19.66403603553772, 0.6601221906021237, 0.04383666688227095, 0.11928032719879411, 0.031111858479562216, 0.14421609579585493, 0.014623358529206598, 0.0584770549176028, 0.012984662134840619, 0.07563353137811646, 0.023075298995536286, 0.06114360265200958, 0.07684289070311934, 0.09349331521661952, 0.05019939206249546, 0.16192799928830937, 0.1593674859032035, 0.13223223650129512, 0.1422809308860451, 0.16942695627221838, 0.19394563045352697, 0.1262755662901327, 0.10086315334774554, 0.1785295459558256, 0.14829462772468105, 0.11657040464342572, 0.15661983255995438, 0.08852217259118333, 0.11506574475788511, 0.08600203203968704, 0.1390285577508621, 0.2451722402474843, 2.2596468357369304, 64.22771036624908, 58.29822354018688, 47.50718638300896, 36.339752823114395, 51.72674596309662, 73.4929583966732, 73.15095394849777, 57.400035336613655, 66.68615564703941, 51.69198922812939, 1.891230836044997, 0.9303269977681339, 2.3607021756470203, 0.4499216261319816, 23.485318087041378, 75.76417252421379, 61.58282049000263, 65.8252814412117, 62.543150559067726, 65.60283377766609, 63.5356231033802, 63.415279760956764, 61.271191611886024, 61.27350568771362, 48.632917776703835, 47.19185270369053, 45.97208775579929, 47.20452502369881, 46.711604073643684, 47.13854156434536, 46.0245743393898, 47.96485282480717, 49.44702789187431, 49.12774242460728, 54.46769468486309, 53.30551564693451, 57.58662052452564, 57.48344086110592, 57.349064871668816, 57.570072412490845, 52.177249789237976, 60.091366320848465, 62.5285479426384, 55.213799849152565, 50.632815062999725, 44.82397936284542, 47.909163013100624, 44.8297094553709, 44.495870769023895, 46.575525775551796, 45.2763868868351, 52.10887625813484, 48.823485150933266, 47.25685581564903, 48.95032614469528, 55.53894840180874, 57.87337213754654, 50.85296384990215, 46.20680496096611, 42.72453501820564, 41.067390739917755, 45.56064963340759, 42.120834812521935, 41.75714112818241, 44.3204265832901, 44.0998712182045, 43.47296565771103, 43.9239102602005, 46.59467674791813, 42.970070242881775, 41.38272821903229, 42.794398069381714, 43.39337132871151, 43.523119166493416, 43.585219234228134, 40.120432153344154, 45.07909767329693, 43.2508409768343, 45.25530181825161, 42.45520167052746, 42.87272326648235, 41.80415220558643, 41.08802743256092, 39.923716709017754, 44.70503054559231, 46.6501347720623, 53.756695836782455, 51.14289589226246, 54.56894405186176, 48.589588701725006, 45.824594870209694, 46.19044303894043, 47.670319229364395, 45.771310329437256, 42.38865964114666, 41.40755608677864, 41.04977108538151, 43.45458224415779, 41.79535947740078, 43.02733317017555, 44.01543974876404, 45.28153941035271, 51.03712096810341, 50.88734820485115, 52.23991982638836, 51.99207812547684, 51.53988718986511, 49.36737276613712, 51.897508800029755, 45.21678328514099, 46.02181948721409, 42.541027665138245, 44.26613129675388, 41.53793089091778, 41.95782735943794, 40.022059231996536, 45.28308592736721, 42.52012878656387, 43.30681957304478, 42.37455479800701, 44.83539775013924, 43.42972777783871, 46.070498675107956, 46.02341540157795, 58.54478470981121, 57.58686751127243, 63.415598943829536, 56.79756626486778, 66.3698910176754, 49.3100718408823, 48.016077876091, 2.279622363857925, 0.3858142567332834, 1.14259168272838, 6.685767844319344, 65.42260944843292, 66.06369584798813, 65.51618322730064, 70.98529055714607, 56.94068178534508, 45.267122983932495, 40.72917848825455, 57.78436191380024, 30.272320099174976, 0.5531218915712088, 0.23231174127431586, 0.23357030499028042, 0.12674246623646468, 0.17110051412601024, 0.13998008013004437, 0.11010024987626821, 0.12386406873702072, 0.086559852497885, 0.15741808660095558, 0.27897280699107796, 0.1670829125214368, 0.1594244086300023, 0.15722208539955318], [0.03235194271837827, 0.0752810038102325, 0.06299799220869318, 0.06362222004099749, 0.027904568960366305, 0.018158431485062465, 0.077396970737027, 0.03202137158950791, 0.08759903736063279, 0.04039661944261752, 0.042716413518064655, 0.08036961356992833, 0.060096127999713644, 0.014810511474934174, 0.05660712478857022, 0.02596963782707462, 0.34507489122916013, 0.1241333941288758, 14.165532533079386, 55.68627409636974, 41.37826345860958, 38.03837947547436, 30.062635950744152, 50.75877830386162, 58.19363795220852, 50.71362152695656, 54.001740887761116, 44.23221431672573, 3.3636645320802927, 0.5027196148876101, 0.8290069783106446, 0.3415726369712502, 17.94818300753832, 66.25153496861458, 56.432060077786446, 62.74154171347618, 59.851329401135445, 61.44049532711506, 56.839740201830864, 59.9201513081789, 58.415397852659225, 60.24816110730171, 56.18466675281525, 47.273073345422745, 41.98004476726055, 43.061542734503746, 41.712022349238396, 42.349183559417725, 42.48515926301479, 42.700303718447685, 42.39124730229378, 45.45039854943752, 43.12278404831886, 47.05303095281124, 48.78256134688854, 52.05389320850372, 54.1950137168169, 54.120412319898605, 56.47048741579056, 55.93693524599075, 49.60300572216511, 45.869246274232864, 41.908684596419334, 44.37034830451012, 41.87910698354244, 41.286315992474556, 40.667538195848465, 42.965867668390274, 44.236565083265305, 48.59102122485638, 43.43840651214123, 42.2839030623436, 46.92553259432316, 46.977092027664185, 46.387933641672134, 40.79092897474766, 38.80823336541653, 38.689603731036186, 38.69945280253887, 37.80657671391964, 38.24762664735317, 37.79013119637966, 39.07640017569065, 38.15688371658325, 39.69176955521107, 36.9736348092556, 37.88288041949272, 38.47923181951046, 37.59153105318546, 36.910542994737625, 36.27896748483181, 39.26064848899841, 38.99752400815487, 38.47770430147648, 39.72015403211117, 36.46665461361408, 38.12944918870926, 36.59003399312496, 37.2257474809885, 36.97482034564018, 37.954692766070366, 39.0424869954586, 36.09929412603378, 37.713918685913086, 42.16495804488659, 45.35342015326023, 49.83969882130623, 45.591530576348305, 41.75611898303032, 41.062511801719666, 45.94162479043007, 43.273358568549156, 38.040169179439545, 37.97860488295555, 37.0471266657114, 37.71733470261097, 38.556713461875916, 38.24365206062794, 41.226476803421974, 40.10806381702423, 43.65832731127739, 44.7519314289093, 45.85584819316864, 43.5687243193388, 44.036764204502106, 43.59167888760567, 44.013319462537766, 40.154064148664474, 40.27889505028725, 37.42386505007744, 37.08481304347515, 36.47551193833351, 38.01344521343708, 37.70326405763626, 36.78671903908253, 38.99636507034302, 40.56926406919956, 38.00187483429909, 42.187703624367714, 39.21311303973198, 44.61463339626789, 42.92383812367916, 55.04092812538147, 52.47548818588257, 59.08977806568146, 52.80945226550102, 62.038758024573326, 48.35551366209984, 42.79223218560219, 1.521389912813902, 0.2135779449599795, 0.062384621996898204, 4.914432093501091, 50.0278115272522, 53.06871235370636, 52.32674136757851, 58.511715084314346, 35.87217651307583, 32.29846067726612, 29.74613193422556, 31.714416816830635, 2.6712388498708606, 0.4754091741051525, 0.0240140657115262, 0.11492411329527386, 0.028969140839762986, 0.014097141502134036, 0.029327549927984364, 0.023738322597637307, 0.024762757275311742, 0.03581510063668247, 0.12010927646770142, 0.018092983336828183, 0.08374006240046583, 0.07604999496834353, 0.028106626086810138, 0.11341957957483828, 0.06361024177749641, 0.05677833083609585, 0.08103856322122738, 0.03754028970433865, 0.04812833991309162, 0.08691599432495423, 0.10672503645764664, 0.15902577142696828, 0.06095539400121197, 0.07718571097939275, 0.0580735455150716, 0.013291695122461533, 0.022528788867930416, 0.014619093035435071, 0.04418229618750047, 0.27633764839265496, 0.23389202600810677, 19.55370705574751, 63.24092611670494, 33.69773559272289, 35.15847221016884, 44.456862062215805, 57.31947585940361, 68.45367640256882, 54.607732370495796, 61.40973597764969, 49.12129417061806, 3.8733587320894003, 1.0550545924343169, 0.8640012005344033, 0.5808063154108822, 20.312334448099136, 67.91534408926964, 59.29900623857975, 65.08457198739052, 61.727315336465836, 64.654001891613, 58.52878376841545, 64.22485291957855, 60.637108236551285, 62.60781168937683, 56.990964487195015, 48.058688789606094, 44.75961461663246, 43.59387516975403, 44.70489755272865, 43.82438600063324, 45.51934204995632, 46.371605917811394, 44.76865813136101, 46.56596928834915, 46.027648374438286, 48.93977791070938, 51.04391120374203, 53.970593959093094, 54.64856497943401, 54.24581699073315, 57.08530202507973, 57.23771184682846, 52.902049496769905, 50.16086518764496, 43.982560113072395, 44.39559794962406, 42.95047469437122, 42.59581692516804, 42.26227082312107, 44.94157925248146, 44.306701719760895, 50.412715673446655, 45.90253248810768, 43.5736108571291, 47.07226172089577, 51.05999954044819, 48.51143829524517, 43.66526573896408, 41.285647228360176, 40.637618601322174, 41.61070838570595, 40.19880674779415, 39.62873853743076, 40.8562208712101, 39.841078743338585, 40.83630234003067, 42.005343809723854, 40.974272936582565, 39.8298579454422, 39.90552708506584, 42.362775430083275, 39.045507833361626, 38.91086965799332, 41.8792437762022, 39.8083321005106, 40.7719299942255, 41.62162899971008, 38.12037147581577, 40.69023437798023, 39.4630978256464, 39.18162792921066, 38.44173543155193, 40.35130016505718, 41.21248975396156, 39.14902187883854, 39.93725158274174, 45.01066714525223, 46.71069972217083, 50.422199964523315, 47.06771716475487, 44.4416780769825, 40.559301003813744, 47.84270837903023, 45.08845277130604, 40.05288317799568, 39.691218584775925, 39.56455238163471, 40.03559410572052, 40.0161961466074, 40.300941467285156, 41.604719907045364, 42.94748805463314, 46.79301470518112, 44.91017013788223, 49.26232360303402, 46.941351145505905, 46.40503652393818, 46.241185516119, 46.015557423233986, 42.850027084350586, 42.027451023459435, 39.52197566628456, 38.69861304759979, 38.24790023267269, 41.52082420885563, 39.56334784626961, 39.80515547096729, 42.088627740740776, 42.33362719416618, 42.23351016640663, 44.65179540216923, 42.374573796987534, 46.346618458628654, 45.47383949160576, 57.03115113079548, 55.31396247446537, 61.32929049432278, 56.201902627944946, 63.18238265812397, 51.91285237669945, 47.301552817225456, 1.8429670133627951, 0.2558045298792422, 0.23873286234447733, 5.792343160137534, 56.93871729075909, 57.32607990503311, 60.940404161810875, 62.72030085325241, 45.88621996343136, 41.85101889073849, 25.744251273572445, 41.340930461883545, 4.679707288742065, 0.49697913229465485, 0.0891802497790195, 0.1850279839709401, 0.09380397823406383, 0.07552879207651131, 0.04494073771638796, 0.018879372291848995, 0.023192645530798472, 0.06592306337552145, 0.0761651985521894, 0.060603942547459155, 0.028113648659200408, 0.10817130416398868, 0.031042682894621976, 0.2120935605489649, 0.1223153252794873, 0.14060777379199862, 0.1872419292340055, 0.19598416169174016, 0.08182569989003241, 0.25400407961569726, 0.20130613236688077, 0.3109803597908467, 0.17306959518464282, 0.16907415410969406, 0.23121165577322245, 0.12062680572853424, 0.21085447078803554, 0.18739372811978683, 0.20623433432774618, 0.4432263260241598, 0.5845286906696856, 24.135769084095955, 77.86459341645241, 52.43519514799118, 50.05119927227497, 45.19349813461304, 60.35453639924526, 71.43004149198532, 60.65134987235069, 69.58315059542656, 57.47215546667576, 4.93997479788959, 1.4043611800298095, 1.9892577384598553, 0.5073233647271991, 22.442999817430973, 71.29378080368042, 63.324092254042625, 68.85547444224358, 65.06206199526787, 67.34980523586273, 60.22581450641155, 65.40085941553116, 62.58071914315224, 65.98414331674576, 61.692475005984306, 52.661404609680176, 47.66514390707016, 47.899165749549866, 46.176505386829376, 46.46768756210804, 46.92568078637123, 49.276519641280174, 47.673868238925934, 49.29933741688728, 47.439569011330605, 51.79476611316204, 53.68809811770916, 58.0119127035141, 59.42643240094185, 56.94343663752079, 59.07273218035698, 59.73942160606384, 56.19417004287243, 50.946906208992004, 45.89106850326061, 48.33674266934395, 45.049664452672005, 46.11457251012325, 44.516621455550194, 48.24292570352554, 48.97282853722572, 53.07264894247055, 48.09482865035534, 46.03962913155556, 48.95416773855686, 54.1977571696043, 52.45348356664181, 45.6556711345911, 43.568747118115425, 42.72884398698807, 43.72473634779453, 43.68962623178959, 44.673317447304726, 43.176912143826485, 43.368155881762505, 45.243199467659, 44.23247270286083, 44.35177490115166, 41.142448112368584, 42.56498157978058, 43.52351054549217, 40.426095351576805, 38.81882719695568, 44.550116658210754, 42.29786351323128, 42.76616558432579, 44.13713961839676, 39.02272425591946, 42.30647765100002, 40.29777243733406, 43.29787105321884, 39.61082249879837, 43.51170837879181, 43.352850303053856, 41.10885791480541, 42.11002819240093, 47.78538465499878, 47.184123918414116, 53.26575078070164, 50.33674255013466, 45.77295944094658, 42.25361868739128, 51.242458149790764, 48.3176638931036, 43.15255165100098, 41.90038204193115, 43.366742357611656, 41.27598434686661, 42.148018553853035, 41.74886517226696, 44.71689730882645, 43.934975266456604, 48.90954293310642, 47.33016908168793, 50.251304134726524, 47.1841125190258, 49.18845556676388, 47.759090065956116, 49.17673319578171, 44.8201035708189, 44.9770313501358, 41.331138387322426, 41.045386120676994, 39.84763339161873, 43.888644352555275, 41.56922221183777, 42.54367612302303, 44.67563912272453, 46.20438449084759, 43.24357196688652, 47.64002725481987, 42.28149779140949, 49.1449972987175, 46.85032702982426, 60.48075042665005, 58.129098415374756, 65.70311039686203, 56.77971862256527, 65.63350573182106, 52.00768008828163, 47.93902561068535, 2.8221228159964085, 0.3325443807989359, 0.8936977351550013, 7.5999341905117035, 63.18083994090557, 64.56602141261101, 63.153462409973145, 68.6566311120987, 49.745110496878624, 45.22462226450443, 39.435944482684135, 52.1511147916317, 7.7419748436659575, 0.8081025187857449, 0.20918918045936152, 0.40082998224534094, 0.13236604572739452, 0.2145999565254897, 0.17684908612864092, 0.09268015142879449, 0.2006593655096367, 0.10065444657811895, 0.19686111307237297, 0.10707628753152676, 0.16330762213328853, 0.24191376665839925, 0.12083600973710418], [0.019901356026821304, 0.03201356790668797, 0.03998651234724093, 0.052731737232534215, 0.06450245913583785, 0.06808138467022218, 0.020412541780387983, 0.053129454172449186, 0.030789822048973292, 0.03267205698648468, 0.007588515190946055, 0.01576849703269545, 0.009085578731173882, 0.041203048240276985, 0.11128390862722881, 0.07062452437821776, 0.10984676191583276, 0.2873567008646205, 0.8138688874896616, 39.56653207540512, 45.571680441498756, 34.233499243855476, 28.1089935824275, 41.25361114740372, 48.36836077272892, 49.92152743041515, 50.694614946842194, 49.78938952088356, 4.957659998908639, 0.8538729627616704, 0.86626035743393, 0.2942883304785937, 11.294544339179993, 63.84049594402313, 52.77130611240864, 61.66002854704857, 57.283043414354324, 64.25586685538292, 58.48535969853401, 58.851926028728485, 57.216638177633286, 57.73807279765606, 57.366308346390724, 53.50888453423977, 46.377446204423904, 43.62748436629772, 44.03902128338814, 43.55232059955597, 42.54266917705536, 41.54788635671139, 42.353754714131355, 40.801902785897255, 44.2001174390316, 45.834850519895554, 46.28730744123459, 48.19532185792923, 49.285840541124344, 51.221183091402054, 49.21696163713932, 46.12115755677223, 44.713610485196114, 43.07817444205284, 44.19100932776928, 40.98517835140228, 41.10039956867695, 41.79380156099796, 42.61459171772003, 42.6241710036993, 41.104529947042465, 48.11365284025669, 43.8631097227335, 43.14926102757454, 45.37073202431202, 42.54087187349796, 41.4204677939415, 39.955376610159874, 38.45867112278938, 38.32635082304478, 39.34864416718483, 38.92599284648895, 36.80468067526817, 38.25017251074314, 38.64332601428032, 39.14772614836693, 37.47192107141018, 38.39095115661621, 39.411040619015694, 39.091143384575844, 40.46231120824814, 38.63077148795128, 38.413130566477776, 40.46269118785858, 38.340094685554504, 38.70019756257534, 38.98039072751999, 38.359219059348106, 38.87313388288021, 38.24506938457489, 38.581966906785965, 36.74790412187576, 38.37281472980976, 38.03898364305496, 36.72290526330471, 37.72090271115303, 37.571380734443665, 40.175339207053185, 44.88603003323078, 46.557123363018036, 41.682437136769295, 40.80689571797848, 44.319788217544556, 44.09270100295544, 38.93758602440357, 38.89589086174965, 39.8013024777174, 38.235676288604736, 37.94633701443672, 38.04513171315193, 37.90398828685284, 37.96099662780762, 38.50362651050091, 41.44938804209232, 43.008273392915726, 42.538147419691086, 42.13954120874405, 42.00085625052452, 41.94609358906746, 38.610932752490044, 36.66033402085304, 36.122602075338364, 37.06284262239933, 36.909513249993324, 38.880117908120155, 37.84860245883465, 38.27233672142029, 38.93534414470196, 39.471711963415146, 37.97372594475746, 40.4405801743269, 41.76162488758564, 40.31088553369045, 41.74217753112316, 50.912795439362526, 52.09075503051281, 57.303820699453354, 54.64087039232254, 61.04125835001469, 52.66138181090355, 46.69365003705025, 0.9808345406781882, 0.22196422854904085, 0.08662507243570872, 6.040402399376035, 57.98211470246315, 48.74311566352844, 59.15039621293545, 46.95203997194767, 31.763550080358982, 33.03347423672676, 45.20951047539711, 24.784943349659443, 0.3469288651831448, 0.12239204108482227, 0.03789255380979739, 0.08123671665089205, 0.06157610405352898, 0.033536236005602404, 0.07829018257325515, 0.07630586522282101, 0.041834066723822616, 0.0902425376989413, 0.017675822127785068, 0.030784281916567124, 0.051785595424007624, 0.07996561806066893, 0.10525757301365957, 0.009681634637672687, 0.05412082617112901, 0.05456752856844105, 0.03577931798645295, 0.01244098237293656, 0.017954956856556237, 0.049459003275842406, 0.05599041120149195, 0.08622328110504895, 0.027946813861490227, 0.03005688628036296, 0.028459168497647624, 0.07350019819568843, 0.024896854083635844, 0.02738433271588292, 0.04709784559963737, 0.10125080676516518, 0.3812650399049744, 2.6228857319802046, 52.01855890452862, 46.08167387545109, 32.550960928201675, 43.77777010202408, 47.60253846645355, 56.40519931912422, 57.58978955447674, 56.28934733569622, 57.30459585785866, 5.650997394695878, 0.8640222775284201, 1.0213561006821692, 0.6154128396883607, 14.44615412503481, 66.81749939918518, 55.92993602156639, 64.21612098813057, 60.403082594275475, 68.25046330690384, 59.236883372068405, 62.104692086577415, 61.38577826321125, 61.043735817074776, 59.89052429795265, 55.7950546592474, 48.03400531411171, 45.906925052404404, 45.12077383697033, 46.662571504712105, 43.022997602820396, 42.97539755702019, 44.102903455495834, 45.1332675665617, 45.442802757024765, 47.4786689132452, 49.42265219986439, 50.788086131215096, 52.32522904872894, 52.941289991140366, 51.85577563941479, 47.404033318161964, 47.480842396616936, 44.894222393631935, 45.06150461733341, 43.84198285639286, 42.776219844818115, 43.06961730122566, 43.58623757958412, 44.65760909020901, 43.04887041449547, 49.81867454946041, 46.26865044236183, 46.61355033516884, 45.605464428663254, 46.89430586993694, 45.227874889969826, 42.69744627177715, 41.911401450634, 38.620367646217346, 42.943787053227425, 42.192445769906044, 40.12195587158203, 41.11417002975941, 41.069868206977844, 41.220784708857536, 39.87673982977867, 41.08165517449379, 41.9589900970459, 41.079618483781815, 41.31943121552467, 40.80713890492916, 39.860210716724396, 41.42380401492119, 40.55863603949547, 40.8542487770319, 41.07526391744614, 41.101486310362816, 40.8742319047451, 38.753178119659424, 39.58969183266163, 38.738336116075516, 39.84107494354248, 40.06474994122982, 39.190496653318405, 39.89312835037708, 39.69917915761471, 42.929089441895485, 46.59505672752857, 48.58751781284809, 43.78698840737343, 43.47043119370937, 46.30795173346996, 45.53463622927666, 39.04081888496876, 41.6578334569931, 42.279483899474144, 39.61140766739845, 39.49607625603676, 41.64741821587086, 41.237754598259926, 39.59894433617592, 40.658886060118675, 43.38622771203518, 45.202636644244194, 45.30308425426483, 44.64999809861183, 44.626298770308495, 43.21787014603615, 41.396882459521294, 38.40523079037666, 39.03303310275078, 39.622275084257126, 40.53549528121948, 40.76289027929306, 40.4987208545208, 41.20841257274151, 40.13866737484932, 41.8518890440464, 41.05385206639767, 41.46573096513748, 43.468485698103905, 42.55999244749546, 44.91958603262901, 51.807427033782005, 54.59419749677181, 58.26820135116577, 58.11099238693714, 60.82428619265556, 55.645722672343254, 50.41570231318474, 0.7550133112818003, 0.535753439180553, 0.06352141412207857, 7.04785848967731, 65.38430750370026, 53.12440976500511, 65.47637656331062, 50.616460740566254, 42.89159685373306, 38.574891686439514, 45.48650421202183, 33.88021320104599, 0.4267532005906105, 0.07806866633472964, 0.05178261570108589, 0.032112900662468746, 0.04922194275422953, 0.04811491446162108, 0.05222473162575625, 0.05573426264163572, 0.04581590794259682, 0.03549967674189247, 0.04829361991141923, 0.02632544197695097, 0.07328424806473777, 0.08106204477371648, 0.061226686084410176, 0.1699173080851324, 0.22942912095459178, 0.1024548226268962, 0.1485121957375668, 0.20570757274981588, 0.18355872452957556, 0.1318875831202604, 0.15707313636085019, 0.2304998619365506, 0.17801954207243398, 0.18200980295659974, 0.21699491160688922, 0.14646593132056296, 0.16296443820465356, 0.15576726815197617, 0.24671506136655807, 0.22069897066103294, 0.5100184888578951, 3.3557676058262587, 60.618405640125275, 58.55612710118294, 46.44185274839401, 41.02082423865795, 53.228026404976845, 63.58292296528816, 63.571648970246315, 61.811408624053, 63.27034413814545, 6.478763977065682, 1.2190155568532646, 1.886944428551942, 0.5684525251854211, 17.165050730109215, 67.83892259001732, 56.82659670710564, 66.35320231318474, 63.30540865659714, 70.10647371411324, 60.55053748190403, 63.07161100208759, 62.856702134013176, 63.3343631029129, 63.26899141073227, 59.152881279587746, 49.916013926267624, 48.49305488169193, 48.86236846446991, 48.48611645400524, 45.66521242260933, 46.283994019031525, 48.070908933877945, 47.961292415857315, 48.24018985033035, 50.37975624203682, 53.324522227048874, 53.52566063404083, 54.83795441687107, 53.577987626194954, 52.817857414484024, 49.790662452578545, 47.934047877788544, 48.04383918642998, 46.317128241062164, 45.278811156749725, 45.641319304704666, 45.19270397722721, 46.12165912985802, 48.03718574345112, 44.40682254731655, 52.29909785091877, 48.781998977065086, 49.538321793079376, 49.99707877635956, 47.71160401403904, 47.24708653986454, 43.79956193268299, 43.45841243863106, 42.53212854266167, 44.888716489076614, 44.069959223270416, 42.47365728020668, 43.522116020321846, 43.70273932814598, 43.46681758761406, 42.71496333181858, 43.02989423274994, 43.81262943148613, 43.957580253481865, 46.497918739914894, 43.14146384596825, 44.14226934313774, 45.06262555718422, 43.00485357642174, 42.128388807177544, 44.23481337726116, 42.95655056834221, 43.59148129820824, 42.10756592452526, 41.9476743042469, 40.92152796685696, 41.763764172792435, 42.152433916926384, 41.35707199573517, 41.31017491221428, 42.535077184438705, 44.34568002820015, 47.88677081465721, 51.04789339005947, 46.06493577361107, 46.61856226623058, 48.89141410589218, 48.35503488779068, 43.35680589079857, 42.748640924692154, 45.03766089677811, 40.96577279269695, 42.83185265958309, 42.66304291784763, 42.26833149790764, 42.254230454564095, 43.11687156558037, 46.26624517142773, 48.133191391825676, 46.943425834178925, 48.05275730788708, 46.83428429067135, 48.1097162514925, 44.27800565958023, 40.605624318122864, 40.62982141971588, 42.83217564225197, 42.27424018085003, 44.0407919883728, 43.46909746527672, 43.5614363104105, 43.519524559378624, 45.087404027581215, 43.032702282071114, 43.545138984918594, 45.91441065073013, 44.61174175143242, 47.0650839060545, 56.561587527394295, 55.87025262415409, 63.71254161000252, 58.63208122551441, 66.72132655978203, 55.807502791285515, 49.57918860018253, 1.2435116549022496, 0.798048673896119, 0.25178624549880624, 8.52334164083004, 72.03519701957703, 57.65808708965778, 69.91120979189873, 55.615590289235115, 44.74450662732124, 46.918936148285866, 56.880850195884705, 45.029023960232735, 0.4930335487006232, 0.25542814226355404, 0.11290639187791385, 0.14846477250102907, 0.15938823635224253, 0.0998582853935659, 0.1676225132541731, 0.15747581084724516, 0.17643401777604595, 0.12471211346564814, 0.1396779963397421, 0.13610360532766208, 0.13684757868759334, 0.20589207066223025, 0.18097090010996908], [0.01121276693083928, 0.056784249463817105, 0.04347979775047861, 0.025634250159782823, 0.07543525920482352, 0.056641066912561655, 0.03651742466900032, 0.02054926022537984, 0.031054247410793323, 0.041626124366302975, 0.04779352369951084, 0.04588071969919838, 0.05534208583412692, 0.06098322082834784, 0.0703254017571453, 0.1712967231287621, 0.06404629064491019, 0.23562805785331875, 0.16135464567923918, 17.06412434577942, 54.77178856730461, 32.47542858123779, 30.733493752777576, 34.48219209909439, 53.40913608670235, 64.3214513361454, 49.1963667422533, 57.765381932258606, 12.346562538295984, 0.9192903712391853, 0.5127016198821366, 0.04896239886875264, 2.567049628123641, 56.49773955345154, 58.53691913187504, 59.569745510816574, 58.607815727591515, 61.581372767686844, 61.77960433065891, 57.12336838245392, 60.42118862271309, 59.338292330503464, 60.795620530843735, 53.513425290584564, 51.03720836341381, 45.871742740273476, 44.156343787908554, 43.59615124762058, 43.57246711850166, 42.73471087217331, 42.5833535939455, 42.25747928023338, 41.07498653233051, 42.20690779387951, 44.297707602381706, 42.12004065513611, 42.86231182515621, 44.61425341665745, 42.79280975461006, 44.04059059917927, 43.459423184394836, 41.270991414785385, 42.34295569360256, 42.29950502514839, 41.299185901880264, 38.95366296172142, 42.1453320980072, 42.021861523389816, 40.9852809458971, 42.40761302411556, 43.37384417653084, 41.935541555285454, 41.08949415385723, 42.04018034040928, 40.546165108680725, 39.73432347178459, 39.05345320701599, 38.19819509983063, 36.55883006751537, 37.62867026031017, 38.91099505126476, 39.13511462509632, 37.91336618363857, 38.42076435685158, 40.278731659054756, 38.9088823646307, 38.56546439230442, 39.717596769332886, 38.36071237921715, 40.33051148056984, 38.8206434994936, 39.509090557694435, 38.62800903618336, 38.68725925683975, 37.64043062925339, 38.01534131169319, 38.03995259106159, 37.81316176056862, 37.502676621079445, 36.19976073503494, 35.81297568976879, 37.08951339125633, 36.79380565881729, 37.4071991443634, 37.303947284817696, 39.25562895834446, 40.175871178507805, 43.38767543435097, 42.34556995332241, 40.25980867445469, 41.06280818581581, 41.9765717536211, 39.32844065129757, 38.53865683078766, 38.805805295705795, 37.72610083222389, 38.13732996582985, 39.911386370658875, 38.38642939925194, 38.31691212952137, 37.54884414374828, 38.72443646192551, 39.17405493557453, 39.7358737885952, 41.98425114154816, 38.137455359101295, 40.169628113508224, 39.13853444159031, 38.14365662634373, 37.346778586506844, 37.292285710573196, 36.61401070654392, 39.08843033015728, 39.453712329268456, 38.512689024209976, 42.855779975652695, 43.65916706621647, 43.33483166992664, 42.33760558068752, 41.040978357195854, 42.65199691057205, 42.67079070210457, 44.359363093972206, 50.95613971352577, 54.68728490173817, 57.851261124014854, 53.139350563287735, 61.623007133603096, 41.45353361964226, 0.48686021589674056, 0.1247371535282582, 0.12821243813959882, 8.234788924455643, 61.589846312999725, 49.64044511318207, 51.79589465260506, 43.630094826221466, 33.133952245116234, 29.75353393703699, 38.67427155375481, 7.1810294687747955, 0.600585441570729, 0.06242247894988395, 0.02218930825620191, 0.042968432026100345, 0.11919731798116118, 0.03062309857341461, 0.026676121597120073, 0.044235801324248314, 0.08059497413341887, 0.0689210431301035, 0.05263563652988523, 0.010338978026993573, 0.04373163443233352, 0.057992209840449505, 0.08286352662253194, 0.008732843361940468, 0.020742337364936247, 0.06406599466572516, 0.00845535063490388, 0.013426998848444782, 0.03641923853137996, 0.04363811640359927, 0.08216877249651588, 0.05598141266091261, 0.04507439109147526, 0.009944135981641011, 0.08556837288779207, 0.028746387069986667, 0.04517849585681688, 0.02892322972911643, 0.14061684283660725, 0.0830617913743481, 0.19410266890190542, 0.48826792160980403, 23.288015574216843, 62.259438782930374, 29.57897510379553, 31.656270436942577, 46.60813182592392, 55.89054733514786, 69.34795841574669, 55.01186728477478, 66.67385950684547, 13.44636507332325, 1.0344548290595412, 0.980384205467999, 0.2232892590109259, 3.9036281453445554, 61.55765064060688, 59.49620045721531, 63.92368108034134, 62.15435542166233, 62.413740903139114, 61.78760290145874, 58.7478344142437, 60.71060009300709, 62.01087512075901, 62.859316393733025, 56.332938596606255, 53.18278983235359, 47.65290476381779, 45.52310384809971, 47.15310998260975, 45.380007326602936, 45.93685604631901, 46.12433798611164, 45.59626892209053, 43.305755630135536, 44.96804863214493, 46.832334995269775, 45.93038119375706, 44.47007395327091, 47.257440984249115, 44.60747078061104, 45.06959818303585, 45.05855977535248, 43.838152661919594, 45.054577589035034, 42.777781561017036, 43.6549074947834, 41.49881199002266, 44.09425511956215, 45.10060451924801, 44.691788256168365, 46.25279389321804, 46.916964054107666, 44.98520091176033, 43.20027329027653, 44.92516413331032, 42.946781292557716, 42.975275963544846, 41.53965599834919, 41.78021349012852, 40.44797457754612, 39.73477944731712, 40.88687002658844, 41.304118037223816, 40.58220237493515, 41.50714494287968, 42.21757762134075, 41.82670399546623, 42.17704139649868, 41.99412681162357, 41.18469424545765, 40.938171073794365, 41.950763538479805, 42.11650304496288, 42.13700294494629, 41.70922949910164, 40.67783564329147, 41.22432991862297, 40.82627087831497, 40.45482560992241, 40.19475616514683, 38.74310106039047, 38.470017313957214, 40.17050586640835, 39.01609741151333, 40.33306874334812, 39.12640169262886, 40.68304516375065, 41.968238800764084, 44.36168856918812, 43.37283343076706, 41.97380930185318, 44.27780047059059, 46.52832090854645, 40.57617589831352, 40.88672563433647, 40.00347062945366, 39.30147349834442, 39.40745361149311, 40.93478925526142, 42.29022592306137, 39.38768707215786, 39.25971753895283, 42.21055939793587, 41.360472813248634, 42.02085077762604, 44.11964535713196, 41.19258262217045, 41.61781780421734, 42.157537043094635, 39.740843921899796, 39.65289384126663, 38.79065930843353, 39.60617534816265, 39.59100276231766, 41.03925704956055, 40.82761600613594, 42.48749993741512, 44.282778203487396, 44.703681617975235, 43.82029362022877, 43.56464333832264, 43.434124141931534, 44.35070715844631, 47.44120292365551, 53.72852794826031, 56.416195929050446, 60.20772747695446, 56.49237424135208, 64.91755574941635, 44.39864918589592, 0.46844094176776707, 0.46852394356392324, 0.07635492118424736, 9.941559489816427, 67.74974137544632, 55.15760846436024, 58.0618192255497, 48.15697431564331, 41.47309496998787, 29.473920240998268, 46.418985575437546, 10.518163349479437, 0.7923654851038009, 0.1171634548518341, 0.05172529592528008, 0.03329380604554899, 0.053372967668110505, 0.030037198957870714, 0.02344684038689593, 0.12145887943916023, 0.04579264161293395, 0.09363952573039569, 0.079081742442213, 0.03835246643575374, 0.09124707910814323, 0.05036754417233169, 0.0067775472325593, 0.06425530911656097, 0.11538446749909781, 0.13943289464805275, 0.12774255475960672, 0.18056859669741243, 0.23077092395396903, 0.1745059181121178, 0.1892562219290994, 0.13543766137445346, 0.25592772639356554, 0.06167473547975533, 0.241816530469805, 0.16708769195247442, 0.18949704885017127, 0.30699401744641364, 0.27807175065390766, 0.17269108502659947, 0.3463038877816871, 0.561329866759479, 29.663170985877514, 74.41564008593559, 42.23447151482105, 41.72629818320274, 48.829659819602966, 64.66921627521515, 77.20491081476212, 60.87132386863232, 72.63224378228188, 16.295171007514, 1.3876758003607392, 2.4387853732332587, 0.355669999262318, 6.134803583845496, 65.44954240322113, 60.83894580602646, 67.06544369459152, 63.45813766121864, 64.33839082717896, 65.36665365099907, 59.99848410487175, 63.02371457219124, 63.29899460077286, 67.26761564612389, 59.04680997133255, 57.15742215514183, 50.599019676446915, 47.67918415367603, 48.93069639801979, 48.47575441002846, 48.27591933310032, 47.251832485198975, 47.98088796436787, 45.4831375926733, 47.846128195524216, 50.26287451386452, 48.57066951692104, 46.47347465157509, 48.09918321669102, 46.49470031261444, 47.28517949581146, 47.21132665872574, 45.05265489220619, 46.5249352902174, 45.48760235309601, 45.726073756814, 41.85989901423454, 45.377313271164894, 47.084394469857216, 46.24404676258564, 48.497413247823715, 49.22454982995987, 46.31780080497265, 45.870507806539536, 47.26952813565731, 45.35217382013798, 46.66889436542988, 44.265215545892715, 45.28671853244305, 41.93080700933933, 43.0958054959774, 43.83538261055946, 44.46552939713001, 44.15658317506313, 45.8233143389225, 45.654379203915596, 44.579394087195396, 43.499150052666664, 44.03859570622444, 44.93338689208031, 45.0993087887764, 44.807153865695, 42.976374104619026, 45.32839089632034, 43.716334998607635, 43.30350995063782, 42.7813533693552, 42.42889568209648, 42.80342638492584, 40.60690864920616, 40.670049861073494, 39.955061227083206, 42.406055107712746, 41.1942583322525, 42.241968512535095, 39.35748249292374, 43.17652076482773, 44.33113820850849, 46.210239976644516, 46.02290242910385, 44.68676872551441, 45.67038394510746, 47.51645788550377, 43.77620458602905, 41.638351902365685, 41.32170349359512, 43.034598380327225, 41.74501597881317, 43.59834372997284, 42.98725672066212, 42.21304066479206, 42.286517322063446, 44.38948027789593, 42.86780633032322, 44.77990172803402, 47.963025122880936, 44.52959395945072, 45.0170736014843, 44.550751224160194, 43.52544084191322, 43.149230629205704, 42.65430338680744, 41.87503360211849, 42.30460435152054, 42.90625646710396, 43.98468419909477, 47.527439296245575, 48.06976139545441, 47.446712628006935, 47.1366036683321, 46.38287611305714, 46.914991959929466, 47.035840675234795, 50.60083597898483, 55.52043579518795, 61.3059863448143, 61.36012203991413, 60.38816839456558, 64.44709539413452, 44.67016361653805, 0.5974041810259223, 0.3832772100577131, 0.24330495216418058, 11.454775091260672, 74.97271299362183, 60.2750788629055, 66.1131539940834, 52.37232752144337, 48.735709860920906, 40.372324436903, 57.53911167383194, 16.019828282296658, 0.9568544430658221, 0.1954205153742805, 0.09351706394227222, 0.12423076390405186, 0.18699461594223976, 0.12685344700003043, 0.1344321106444113, 0.23536337830591947, 0.09844545886153355, 0.21565049624769017, 0.12999411206692457, 0.17146435944596305, 0.1859148356015794, 0.1818249636562541, 0.1434236453496851], [0.06870715616969392, 0.010365583093516761, 0.018958208784169983, 0.03795669392275158, 0.007597313815494999, 0.032459294379805215, 0.06534087820909917, 0.042552551021799445, 0.07843433733796701, 0.015490447694901377, 0.0337259512161836, 0.003964736106354394, 0.023919581035443116, 0.015402024509967305, 0.03177743135893252, 0.13280173094244674, 0.06967387773329392, 0.05804304324556142, 0.11348253596224822, 2.150123887695372, 40.749328806996346, 43.98710086941719, 37.45816580951214, 30.980567894876003, 38.716631680727005, 57.47706100344658, 47.99040265381336, 58.85981820523739, 25.782310031354427, 0.13204319664509967, 0.21893445518799126, 0.060345589809003286, 2.6880033127963543, 47.133434638381004, 64.97447669506073, 60.23508980870247, 63.13801623880863, 60.24472989141941, 63.49835850298405, 58.63183043897152, 63.0433215200901, 58.84950935840607, 58.28859485685825, 57.025892212986946, 53.28851155936718, 48.13274681568146, 44.85630422830582, 41.66991300880909, 44.50218603014946, 42.5862680375576, 44.27679732441902, 42.18459539115429, 42.74531990289688, 41.84170559048653, 42.148577123880386, 40.546807274222374, 42.59026542305946, 42.52002999186516, 40.724656730890274, 41.39466717839241, 44.53652858734131, 43.57227712869644, 40.86881339550018, 43.75698521733284, 42.32685595750809, 41.06063470244408, 43.40861991047859, 42.46618688106537, 42.517970502376556, 42.30216108262539, 40.7348819822073, 40.38891814649105, 40.32957673072815, 39.01410631835461, 39.753140062093735, 38.22628319263458, 39.312238320708275, 39.12618890404701, 38.100992515683174, 38.128674030303955, 39.750799387693405, 39.64671157300472, 38.76151867210865, 38.11761662364006, 39.01723735034466, 41.02438844740391, 42.19710052013397, 43.08094069361687, 42.153437063097954, 42.82830365002155, 42.214587181806564, 43.07590216398239, 43.28747101128101, 40.73483258485794, 40.373699963092804, 39.71500150859356, 40.79356603324413, 37.56672978401184, 38.45215447247028, 37.10043020546436, 37.06459812819958, 37.84177802503109, 38.63093487918377, 36.8232236802578, 39.440025463700294, 39.45686995983124, 39.80705916881561, 37.4223717302084, 39.749522656202316, 43.064825758337975, 42.04775333404541, 40.65382473170757, 36.42800308763981, 39.140392541885376, 40.84236301481724, 38.850901275873184, 38.52683566510677, 38.69207359850407, 39.48006771504879, 39.224128648638725, 39.11373697221279, 37.00257025659084, 38.356156423687935, 37.2389517724514, 38.71178314089775, 38.158156648278236, 37.635300904512405, 35.93383580446243, 35.592108741402626, 37.69339218735695, 40.15299640595913, 41.20671786367893, 39.84610967338085, 42.56035342812538, 45.08321665227413, 45.82059368491173, 45.38320295512676, 48.224986866116524, 47.41651564836502, 47.28800654411316, 47.44046576321125, 47.68203020095825, 47.72686779499054, 49.50501658022404, 51.67610988020897, 55.04551447927952, 54.38746578991413, 63.8657645881176, 37.54940651357174, 0.16530776949366555, 0.31754248891957104, 0.2418389730155468, 19.02670383453369, 57.02538684010506, 49.56097237765789, 57.528270855546, 32.87621967494488, 38.66965480148792, 37.348511293530464, 34.92002360522747, 1.8842544103972614, 0.07228895381558686, 0.018692670200834982, 0.03646935576398391, 0.029601521164295264, 0.035759124148171395, 0.06841250127763487, 0.041375207947567105, 0.05099875932501163, 0.04891650445642881, 0.05815319651446771, 0.07544233187218197, 0.05234669617493637, 0.03450333977525588, 0.09186732160742395, 0.00623176301814965, 0.08158845754223876, 0.06723313956172206, 0.024610537220723927, 0.031538949624518864, 0.0459785384737188, 0.06928459159098566, 0.01279952597542433, 0.09729162702569738, 0.071430912357755, 0.020511811453616247, 0.022955399472266436, 0.07376599096460268, 0.10818792827194557, 0.01924242536915699, 0.04451385437278077, 0.01794719028112013, 0.030313901297631674, 0.09228955910657533, 0.16493207949679345, 3.918883614242077, 50.39446905255318, 43.84542167186737, 29.875182509422302, 40.014186054468155, 47.29015722870827, 65.51801472902298, 53.20871204137802, 64.85030695796013, 29.180395491421223, 0.12034402519930154, 0.6189388723578304, 0.16252538363914937, 2.9101132694631815, 52.152399122714996, 65.97767606377602, 63.46566125750542, 65.4879279434681, 62.79121644794941, 64.06526148319244, 61.49982154369354, 64.72709476947784, 61.71558916568756, 61.526655703783035, 60.26363007724285, 54.364769607782364, 49.9671021848917, 47.48624570667744, 44.556428119540215, 45.305189341306686, 45.334060192108154, 45.73235481977463, 45.66014349460602, 43.21446932852268, 45.03475405275822, 45.04480451345444, 42.78189294040203, 44.72712256014347, 44.183485731482506, 42.43265748023987, 44.969443157315254, 46.080195754766464, 44.88811992108822, 44.71693530678749, 44.87511321902275, 46.082357838749886, 43.49939323961735, 45.50927259027958, 44.11340229213238, 45.22972159087658, 46.320327669382095, 43.34314942359924, 43.51047724485397, 43.05960863828659, 42.56485618650913, 41.88334755599499, 42.112714648246765, 42.56969332695007, 40.74417628347874, 40.795918107032776, 40.712531581521034, 40.487511456012726, 40.79080358147621, 41.15678854286671, 40.539758652448654, 42.839410454034805, 43.82222391664982, 45.388830453157425, 45.12225195765495, 43.22950132191181, 45.00920422375202, 44.175209775567055, 43.01935739815235, 44.31295618414879, 41.95044055581093, 41.9725401699543, 41.79574325680733, 41.57093971967697, 39.705813601613045, 40.35901755094528, 37.94087290763855, 39.518411457538605, 39.391954243183136, 39.95906621217728, 39.89590220153332, 40.90737372636795, 40.66670224070549, 42.270865961909294, 39.85946595668793, 42.55223326385021, 43.61113004386425, 42.68809117376804, 42.72178016602993, 39.62698683142662, 40.65181463956833, 41.30500718951225, 39.578368440270424, 40.439995005726814, 40.86876019835472, 40.97808413207531, 40.09805515408516, 39.33047354221344, 38.91191080212593, 38.92525188624859, 39.55601043999195, 40.593183785676956, 40.473585203289986, 39.5600800216198, 37.51556172966957, 38.2006611675024, 39.922173991799355, 41.516883820295334, 42.813324853777885, 42.19201259315014, 44.174936190247536, 48.085469752550125, 47.8278473764658, 49.100463688373566, 50.541464164853096, 50.19660986959934, 49.3525193631649, 50.54195053875446, 50.13060361146927, 52.012270241975784, 50.48051543533802, 55.06561920046806, 57.00889192521572, 56.86244398355484, 64.22581046819687, 40.2205415815115, 0.2879836969077587, 1.0753838578239083, 0.1834862315445207, 21.744743585586548, 65.30490696430206, 57.81790271401405, 61.557141467928886, 42.23146967589855, 44.74553257226944, 35.35343214869499, 44.3090195953846, 2.612892030738294, 0.2124967545387335, 0.033826938961283304, 0.03846344719931949, 0.052463892425294034, 0.011658050898404326, 0.00857120916407439, 0.04005785500339698, 0.057851609963108785, 0.0735878681007307, 0.05187215581827331, 0.026043446268886328, 0.04653052565117832, 0.03133868107397575, 0.07796324425726198, 0.03006556013133377, 0.23384810570860282, 0.23589451855514199, 0.1208339910954237, 0.11807510163635015, 0.05476209371408913, 0.1655273709911853, 0.13124371063895524, 0.24507843278115615, 0.15272958349669352, 0.06918029015650973, 0.1158593974832911, 0.16080633213277906, 0.1839050106354989, 0.07901234421296977, 0.1754073306801729, 0.295519731589593, 0.13611896778456867, 0.20111321849981323, 0.29107310925610363, 3.8082086155191064, 63.050191551446915, 58.63083489239216, 48.20466175675392, 46.924217864871025, 50.76422341167927, 70.12544229626656, 60.850022211670876, 72.23727777600288, 35.42019836604595, 0.21315183344995603, 1.162260971032083, 0.10552943655056879, 4.2490108497440815, 57.40328036248684, 66.38398826122284, 67.44965627789497, 69.40955311059952, 66.40867933630943, 65.28640195727348, 61.574582532048225, 66.02412477135658, 62.92518585920334, 61.55532516539097, 62.310428246855736, 58.99372301995754, 54.05649974942207, 50.0327854603529, 45.30087657272816, 48.79071190953255, 49.094049632549286, 47.55057245492935, 47.815444841980934, 46.432809233665466, 47.747831270098686, 47.84033730626106, 45.264242738485336, 47.295514941215515, 47.4537992477417, 45.297342762351036, 46.45660735666752, 49.63063783943653, 48.18992994725704, 45.07172226905823, 48.61143372952938, 47.45579794049263, 45.65355084836483, 47.83408284187317, 47.99234054982662, 47.38353721797466, 46.97268806397915, 45.05897015333176, 45.3666016459465, 45.8663622289896, 43.66549372673035, 44.27210457623005, 43.52479487657547, 43.47049959003925, 43.35958734154701, 42.417177110910416, 43.79567474126816, 43.60493637621403, 43.256232887506485, 43.926828503608704, 42.48626120388508, 44.49285753071308, 46.54152899980545, 48.87085720896721, 47.69880250096321, 47.00801096856594, 48.310037702322006, 46.082726418972015, 45.76161324977875, 48.34556199610233, 44.370329305529594, 44.86301466822624, 43.476959243416786, 44.47106570005417, 41.61578871309757, 42.61656381189823, 40.8045968413353, 41.04534052312374, 41.32379338145256, 42.42852710187435, 41.66948743164539, 43.71095068752766, 42.87564530968666, 45.096021965146065, 42.82512702047825, 43.88552471995354, 46.88031122088432, 46.169703751802444, 44.33887839317322, 40.76915614306927, 42.804748713970184, 45.230052173137665, 42.68954649567604, 43.01001749932766, 41.7573045194149, 43.487385883927345, 43.51778045296669, 41.20889134705067, 40.82218609750271, 40.619577169418335, 40.560991913080215, 42.52253405749798, 42.67312377691269, 41.81793786585331, 39.58378314971924, 39.91234391927719, 43.0020797252655, 45.2729556709528, 46.08538247644901, 43.88138294219971, 46.09269328415394, 50.084713473916054, 51.47123247385025, 50.82059718668461, 53.57814721763134, 53.09233568608761, 52.80947506427765, 52.5827070325613, 53.34499932825565, 52.928667068481445, 55.0907776504755, 58.34380589425564, 59.756847470998764, 58.017388209700584, 64.56713855266571, 41.541065722703934, 0.3138928738189861, 1.6004845686256886, 0.4848211206262931, 25.12794714421034, 72.0435793697834, 61.93953774869442, 66.65620565414429, 44.542904645204544, 50.552586168050766, 45.126652121543884, 57.76864975690842, 3.165546962991357, 0.35686179937329143, 0.10472568319528364, 0.09018847224069759, 0.14767250017030165, 0.17089436034439132, 0.17908790818182752, 0.1013889723981265, 0.09228412658558227, 0.14541908749379218, 0.11306132262689061, 0.1053145773767028, 0.13055281568085775, 0.1344942580908537, 0.2586010907543823, 0.09405271644936875], [0.04977394848538097, 0.03345967234054115, 0.08193725210730918, 0.021836665655428078, 0.07886951047112234, 0.04683906241552904, 0.024543345025449526, 0.007158846938182251, 0.05212957716139499, 0.031343542141257785, 0.08250491344369948, 0.04567329684505239, 0.07353303080890328, 0.014241492935980204, 0.04026033144327812, 0.055610075360164046, 0.037464846682269126, 0.04468011771677993, 0.1264295619330369, 0.1121011764917057, 10.34598033875227, 50.775470808148384, 29.0493481233716, 31.104616038501263, 26.613467931747437, 59.4001530110836, 55.745478719472885, 54.16695982217789, 40.966323763132095, 0.6892399094067514, 0.6272214185446501, 0.09834513533860445, 0.4680447239661589, 32.9022216796875, 67.80258893966675, 61.08420364558697, 63.040065094828606, 56.49346858263016, 62.91405625641346, 62.286793515086174, 60.79212471842766, 61.19594804942608, 56.80087588727474, 56.191559582948685, 53.23580078780651, 48.73037874698639, 47.32347384095192, 43.3032363653183, 43.91134813427925, 43.07293452322483, 45.57191602885723, 43.06518293917179, 41.626234352588654, 42.249659299850464, 42.29656018316746, 42.951394245028496, 41.813887283205986, 43.19492697715759, 42.748401537537575, 42.0755298435688, 43.70997413992882, 44.254222735762596, 42.03367128968239, 44.14051003754139, 42.47921638190746, 41.33390083909035, 43.27792592346668, 43.00632029771805, 42.77429714798927, 42.29555703699589, 40.52332453429699, 40.70687748491764, 40.590892508625984, 41.240695640444756, 41.80824838578701, 41.190675124526024, 39.25176076591015, 41.67169511318207, 39.00652952492237, 40.892045348882675, 39.79824744164944, 38.601003885269165, 40.95447979867458, 43.36636617779732, 49.520922526717186, 51.59888282418251, 51.82771414518356, 51.72114506363869, 49.5480340719223, 49.4942669570446, 48.38876947760582, 48.23678523302078, 47.35581010580063, 49.36731576919556, 47.529111206531525, 45.50685212016106, 41.84547118842602, 39.64785911142826, 39.603640884160995, 37.900393679738045, 37.30728730559349, 39.07066248357296, 38.80391679704189, 36.9786961376667, 38.857634514570236, 38.45862552523613, 38.790636509656906, 39.8726474493742, 38.65832380950451, 39.3983568996191, 39.98341150581837, 38.89753237366676, 39.517279118299484, 38.68019163608551, 39.29113805294037, 37.75800012052059, 38.76000255346298, 39.33872289955616, 37.32304506003857, 40.450904220342636, 40.175468400120735, 39.486204385757446, 38.05979132652283, 39.14204925298691, 38.662324994802475, 38.4815838932991, 38.364645168185234, 37.72646561264992, 38.60062010586262, 40.526254177093506, 42.02252648770809, 45.09573698043823, 44.80075120925903, 45.372255742549896, 49.200561717152596, 48.262426257133484, 50.0700918585062, 49.04836468398571, 50.955926924943924, 50.801309421658516, 51.787557899951935, 51.09501466155052, 51.71234853565693, 49.80347156524658, 53.30328896641731, 56.46192267537117, 55.1059540361166, 62.82582879066467, 32.804563120007515, 0.2313010994112119, 1.0735702863894403, 0.2843241667142138, 37.20552496612072, 51.165641471743584, 43.942392468452454, 46.61736533045769, 27.48869776725769, 32.65650786459446, 42.792718559503555, 19.67806678265333, 0.9193061641417444, 0.025336914259241894, 0.13061059929896146, 0.052559555260813795, 0.046854142856318504, 0.05804586340673268, 0.042152173482463695, 0.05286948355205823, 0.03758743834623601, 0.03404559422051534, 0.019618857513705734, 0.05313982939696871, 0.030774183142057154, 0.009756880062923301, 0.02471235246048309, 0.026182509900536388, 0.07648534621694125, 0.04996264695364516, 0.05944763935985975, 0.06945627261302434, 0.04274532759154681, 0.058072436004295014, 0.0733216003573034, 0.033670709453872405, 0.05455572470964398, 0.04917636004392989, 0.08745806640945375, 0.04003931244369596, 0.06063671207812149, 0.04590453150740359, 0.028496422455646098, 0.008553436582587892, 0.035699989821296185, 0.047517351995338686, 0.11233584358706139, 0.3668048564577475, 16.488400138914585, 59.14896748960018, 32.77362518012524, 39.90468353033066, 35.68467177450657, 62.23954305052757, 60.69750219583511, 62.49970369040966, 43.8140619546175, 0.8441958320327103, 0.8718568040058017, 0.40658762329258025, 0.37418308085761964, 36.877450570464134, 69.15034621953964, 63.178183883428574, 65.25576040148735, 59.17705938220024, 64.44925367832184, 64.23885136842728, 61.75108306109905, 62.18815840780735, 60.20983636379242, 58.84827062487602, 56.626647636294365, 51.61852017045021, 48.770728781819344, 47.975055277347565, 46.572789922356606, 45.95714695751667, 48.60833689570427, 45.39278224110603, 44.545530304312706, 44.70983348786831, 44.435260221362114, 44.05117303133011, 44.08645033836365, 44.786243587732315, 44.85709838569164, 43.15465673804283, 45.18756665289402, 46.51005528867245, 45.326547995209694, 45.66162921488285, 43.895548582077026, 43.941518515348434, 44.559266567230225, 44.85852710902691, 45.32115988433361, 45.29035113751888, 42.41297833621502, 42.66202837228775, 42.12128698825836, 42.91424363851547, 45.2863385528326, 43.28706443309784, 41.793786361813545, 42.67267920076847, 40.60234509408474, 42.9285042732954, 42.57050268352032, 41.19655340909958, 43.60403582453728, 43.62309940159321, 49.33260843157768, 52.22994916141033, 52.43348143994808, 54.31388273835182, 51.42135255038738, 49.95368890464306, 50.31769797205925, 48.584888353943825, 49.67619739472866, 48.56479503214359, 48.913198336958885, 45.374794006347656, 43.72588388621807, 41.47305317223072, 41.148922964930534, 40.69594167172909, 38.34828324615955, 41.42712503671646, 39.59767520427704, 40.627765730023384, 41.509485617280006, 40.03734581172466, 40.16959011554718, 39.74310480058193, 40.06623186171055, 41.04697443544865, 42.404527589678764, 42.709214240312576, 41.65446303784847, 42.47731268405914, 41.42028160393238, 40.830484852194786, 40.98984070122242, 41.27492040395737, 40.569910034537315, 42.78037682175636, 42.142049074172974, 40.64619094133377, 40.04198536276817, 39.82823923230171, 40.83769306540489, 40.839984342455864, 40.350711196660995, 40.5798465013504, 41.47686816751957, 43.33478607237339, 44.28138367831707, 48.04389238357544, 48.11885856091976, 47.62697875499725, 50.79245589673519, 52.12068222463131, 52.490208595991135, 51.32867552340031, 54.84979458153248, 53.106421530246735, 54.69901867210865, 53.608146607875824, 53.453031331300735, 52.301100343465805, 55.5047882348299, 59.844341576099396, 59.2756412923336, 65.233334004879, 34.672641679644585, 0.29294323234353215, 1.5835506585426629, 0.2543093101121485, 41.69698655605316, 57.12580405175686, 51.936525106430054, 51.33209154009819, 39.13425587117672, 32.92789690196514, 46.40027157962322, 25.955305248498917, 0.9706152859143913, 0.08118073645164259, 0.16890013532247394, 0.013631197998620337, 0.07772263255901635, 0.06632012722548097, 0.09082945776754059, 0.06662599596893415, 0.08133891780744307, 0.06960533297387883, 0.030796724022366107, 0.03263111640990246, 0.02540651101298863, 0.0492131631472148, 0.024909431631385814, 0.04869646509177983, 0.17940605204785243, 0.19108373089693487, 0.14645908871898428, 0.10364642235799693, 0.19930222973925993, 0.2332226384896785, 0.16327193967299536, 0.10904661539825611, 0.13513631973182783, 0.1256595243467018, 0.1438076325575821, 0.13591363036539406, 0.1297092461027205, 0.09774801816092804, 0.13486840442055836, 0.21067613270133734, 0.13163593568606302, 0.17733120010234416, 0.28302591294050217, 0.4718978359596804, 22.799623981118202, 75.84748685359955, 39.512126594781876, 48.78036506474018, 38.64951588213444, 70.4728576540947, 69.47406604886055, 69.80865329504013, 52.859499379992485, 0.9219738584943116, 1.5107409842312336, 0.3257339884294197, 1.0074399411678314, 42.57124364376068, 70.60904234647751, 68.44926863908768, 67.59075030684471, 63.14102187752724, 66.33711397647858, 66.40428677201271, 63.740451112389565, 65.43276250362396, 61.72699995338917, 61.543264612555504, 59.24484774470329, 53.8685542345047, 51.198631301522255, 49.87952448427677, 49.02591548860073, 47.39427924156189, 50.8902208507061, 48.22639659047127, 47.124083340168, 46.6839187592268, 47.22873732447624, 46.70071005821228, 45.515975430607796, 47.480508014559746, 46.890620067715645, 46.18503972887993, 46.79192416369915, 48.80789838731289, 47.11494483053684, 48.58669325709343, 46.56218469142914, 46.62930428981781, 46.78549490869045, 46.01812608540058, 48.837411403656006, 49.41231295466423, 45.16537584364414, 46.838319674134254, 45.40909856557846, 45.97007766366005, 47.560873702168465, 45.47968737781048, 44.488966539502144, 46.49359077215195, 43.24823051691055, 46.69007822871208, 44.43234957754612, 42.395943850278854, 46.38754226267338, 48.619918674230576, 53.897242695093155, 56.780546978116035, 54.11129280924797, 57.07472339272499, 54.79045696556568, 53.65104250609875, 51.12040489912033, 50.10649010539055, 50.51133558154106, 52.79011130332947, 51.57595865428448, 49.95189540088177, 45.34966595470905, 42.29949742555618, 44.56182762980461, 42.4403178691864, 40.653619542717934, 45.6738493591547, 43.34529250860214, 42.414148673415184, 43.83599057793617, 41.901506781578064, 43.43562886118889, 43.20220358669758, 44.48183812201023, 43.13257612287998, 44.34302397072315, 44.64646428823471, 43.99855725467205, 44.3366327136755, 42.6237378269434, 42.942107543349266, 43.74320335686207, 43.276265412569046, 40.53623624145985, 46.591690108180046, 43.936263397336006, 43.62727537751198, 42.41507962346077, 43.92096921801567, 42.73512125015259, 42.73658037185669, 42.777633368968964, 42.23036013543606, 43.335682824254036, 46.00473940372467, 46.85980372130871, 51.66388973593712, 49.98071305453777, 48.90168875455856, 53.66551972925663, 54.94398012757301, 55.677819550037384, 54.1053157299757, 57.06381417810917, 55.401167795062065, 56.93122789263725, 57.229861468076706, 58.81004847586155, 55.44621057808399, 58.05611193180084, 63.044978231191635, 62.444671243429184, 66.32927879691124, 37.832787707448006, 0.2972036646679044, 3.3498753095045686, 0.7446038292255253, 45.773324221372604, 61.11537717282772, 55.682896077632904, 57.55675032734871, 39.85042244195938, 40.3026931732893, 57.80620314180851, 36.03223152458668, 0.9290918265469372, 0.2663931960705668, 0.2836393128382042, 0.06821242568548769, 0.15387712192023173, 0.16608276462648064, 0.16160267143277451, 0.12177317898022011, 0.12454308191081509, 0.23745207872707397, 0.10578526969766244, 0.14400382671738043, 0.10065578986541368, 0.2039303071796894, 0.11548970403964631, 0.11256324505666271], [0.04432312613062095, 0.022302072029560804, 0.031874318738118745, 0.03922667929145973, 0.03658795838418882, 0.04567282558127772, 0.010584006431599846, 0.11170920377480797, 0.04527729797700886, 0.04427658233908005, 0.07701495022047311, 0.04681696867919527, 0.07786660178680904, 0.036522100199363194, 0.05021898847189732, 0.06596558843739331, 0.038910375951672904, 0.08054034464294091, 0.07862106911488809, 0.08857920664013363, 0.3529171657282859, 43.60957212746143, 35.670297145843506, 31.2310903519392, 27.057816088199615, 38.649325892329216, 60.14808967709541, 51.82698078453541, 50.88019698858261, 3.7801350094377995, 0.6425984809175134, 0.4284879262559116, 0.2713688212679699, 18.033663220703602, 67.83889979124069, 64.86328706145287, 62.983227744698524, 58.05098220705986, 57.77025707066059, 57.649993523955345, 59.54069226980209, 58.53742450475693, 56.873269602656364, 54.767418801784515, 54.290878772735596, 50.170201286673546, 49.10267136991024, 46.56689263880253, 45.41428528726101, 44.169559478759766, 44.375371634960175, 43.9434640109539, 44.25759315490723, 43.23394328355789, 42.887344881892204, 43.48320230841637, 42.50643812119961, 43.618870228528976, 42.933539003133774, 42.83262021839619, 42.55408376455307, 43.670543655753136, 44.77883018553257, 43.61595958471298, 43.210304751992226, 41.82163126766682, 44.76448975503445, 44.860453605651855, 41.77887976169586, 41.7944323271513, 43.300188928842545, 42.66691491007805, 42.65940651297569, 41.49127699434757, 41.7197435349226, 40.19140474498272, 40.32685987651348, 40.643690675497055, 41.54204227030277, 41.94108545780182, 42.60764569044113, 40.696393847465515, 41.9348081946373, 42.31653571128845, 51.274916008114815, 58.659276366233826, 58.17280746996403, 58.31224478781223, 55.895072892308235, 55.842609107494354, 53.22967551648617, 54.14852701127529, 56.2416522949934, 56.48985497653484, 57.98969529569149, 52.262786999344826, 44.46939758956432, 41.77275449037552, 43.05239662528038, 40.02509146928787, 38.3842559158802, 40.29612712562084, 39.46168810129166, 40.46036571264267, 40.36130502820015, 40.155333280563354, 38.859777599573135, 39.67691995203495, 38.43131639063358, 37.57383540272713, 39.24891471862793, 40.43762393295765, 39.360206946730614, 40.633313432335854, 41.038827672600746, 39.29252117872238, 37.49310873448849, 38.48956726491451, 38.65044683218002, 39.0679532289505, 39.601000025868416, 38.76675859093666, 40.16993969678879, 39.35056306421757, 39.54624116420746, 39.63898278772831, 37.276189774274826, 38.23132172226906, 40.59560425579548, 42.85361789166927, 43.07829223573208, 46.815106719732285, 44.698973670601845, 49.23300817608833, 49.015329256653786, 49.98765908181667, 48.594809621572495, 52.3359102755785, 50.320661813020706, 53.85087378323078, 49.90842953324318, 53.934750482439995, 48.67324881255627, 52.271602526307106, 50.243810936808586, 59.35054287314415, 53.52192163467407, 67.3250837624073, 19.317637123167515, 0.4182069544913247, 1.0557195567525923, 1.1114343046210706, 50.71181282401085, 46.47424980998039, 54.282302632927895, 28.954191729426384, 29.252901300787926, 39.52327899634838, 36.580895483493805, 2.610458736307919, 0.1936444520833902, 0.012800295025954256, 0.02230954731203383, 0.16708365466911346, 0.013609474408440292, 0.08775464346399531, 0.030686047539347783, 0.1208772583049722, 0.02582946097390959, 0.14271542866481468, 0.0465511573565891, 0.11921562676434405, 0.03580196833354421, 0.0319827316707233, 0.015987733022484463, 0.07692684244830161, 0.055446821424993686, 0.0757683276606258, 0.06190667147166096, 0.08400493490626104, 0.04427742838743143, 0.010192127410846297, 0.01963487120519858, 0.021344389824662358, 0.0862536572094541, 0.041188702525687404, 0.04561979541904293, 0.04183658631518483, 0.057126309038721956, 0.023140138582675718, 0.021070837901788764, 0.01151932958237012, 0.06447975683840923, 0.11306149332085624, 0.14219203643733636, 0.07190563454059884, 1.884414714295417, 57.68364451825619, 36.806003004312515, 33.583266735076904, 37.55070984363556, 52.30542071163654, 66.25519797205925, 57.958441972732544, 56.36583723127842, 4.473862359300256, 0.5700990837067366, 0.7600978540722281, 0.18834467162378132, 21.52769923210144, 69.21491235494614, 65.69225817918777, 64.63494211435318, 61.07766039669514, 60.699896067380905, 61.25677518546581, 62.184381410479546, 61.20824418962002, 58.43910098075867, 54.952883049845695, 56.674240082502365, 51.290985345840454, 52.316288128495216, 47.309517189860344, 48.60394053161144, 46.3430580496788, 46.7015840113163, 47.09928587079048, 47.09279961884022, 45.18237613141537, 46.21119752526283, 44.245878383517265, 46.84022717177868, 45.667670890688896, 45.39905570447445, 45.633514523506165, 45.02351425588131, 44.859914034605026, 46.56913451850414, 45.13536885380745, 45.326171815395355, 45.19421249628067, 45.638522654771805, 46.92106403410435, 43.29673491418362, 43.9306814968586, 45.816045328974724, 44.378149285912514, 43.95003765821457, 45.49224950373173, 43.0217132717371, 46.08307600021362, 42.1297263354063, 42.8082787245512, 44.289386048913, 45.25233797729015, 43.30334275960922, 42.492492869496346, 44.29333783686161, 45.27973830699921, 53.355102986097336, 60.961018055677414, 58.42947989702225, 59.10884544253349, 56.6247933357954, 57.09300421178341, 54.180369302630424, 53.86118642985821, 57.13708944618702, 56.27347178757191, 59.15926493704319, 53.58818627893925, 44.378175884485245, 44.40413609147072, 43.117426335811615, 41.391121968626976, 40.81363655626774, 41.4281851798296, 41.78434006869793, 42.58611224591732, 42.378973960876465, 42.48568743467331, 40.8244963735342, 41.75435587763786, 38.518107533454895, 40.1281875371933, 40.664262771606445, 41.48409157991409, 39.73323293030262, 41.53351932764053, 41.91379152238369, 42.542965561151505, 40.08058749139309, 41.10368639230728, 40.09623505175114, 40.33059127628803, 41.030749306082726, 40.72409816086292, 40.98300866782665, 39.94540594518185, 40.58011248707771, 41.91669076681137, 39.71651762723923, 40.61599016189575, 43.14496345818043, 45.744339376688, 45.0983664393425, 50.00673405826092, 47.357804998755455, 52.12323188781738, 51.132191866636276, 54.052179381251335, 50.8742731064558, 55.42977645993233, 51.94010451436043, 55.320912301540375, 53.676938116550446, 56.0391079634428, 51.53295636177063, 54.995064586400986, 53.831418827176094, 62.32610620558262, 55.11430598795414, 68.50843906402588, 19.561278149485588, 0.40919947845395654, 1.3709063502028584, 1.0684537421911955, 57.456211522221565, 50.8245337754488, 58.42154212296009, 37.75360755622387, 32.97087639570236, 35.55348001420498, 45.089349523186684, 4.62024855427444, 0.17195552762132138, 0.04453138761164155, 0.07005989100434817, 0.02916886020102538, 0.04671102338761557, 0.09709655350889079, 0.03436343380599283, 0.024765443849901203, 0.011870595499203773, 0.07095322158420458, 0.041837165190372616, 0.0610522368515376, 0.03278166477684863, 0.04574980113829952, 0.03405794355785474, 0.034616001503309235, 0.1413948807748966, 0.14291291416157037, 0.16851304593728855, 0.2312304321094416, 0.16262469784123823, 0.08323488247697242, 0.17464314121752977, 0.20302383316447958, 0.12426968954969198, 0.1030448151868768, 0.11947341175982729, 0.10528793427511118, 0.1953399329795502, 0.12898726999992505, 0.13950117223430425, 0.13798195141134784, 0.12508256389992312, 0.2675045176874846, 0.28009549831040204, 0.1123527719755657, 2.7048226352781057, 72.29781612753868, 48.18235695362091, 41.81643694639206, 44.13741320371628, 52.23865829408169, 71.9885203242302, 64.99189496040344, 63.92966955900192, 6.803125971928239, 1.2924399669282138, 0.8497218042612076, 0.24601545359473675, 26.729815788567066, 72.05516114830971, 68.40170279145241, 70.94362959265709, 62.7613690495491, 63.62245984375477, 62.45675839483738, 67.11840525269508, 64.62557181715965, 63.565561696887016, 58.37081104516983, 59.994338527321815, 54.787158742547035, 54.10979948937893, 50.313054621219635, 50.368432849645615, 50.58820925652981, 50.076361522078514, 49.09466899931431, 50.44372200965881, 48.44076208770275, 48.625903353095055, 47.02448308467865, 49.302236661314964, 48.26351299881935, 46.9382581114769, 45.4173631221056, 47.25472792983055, 46.7613510042429, 48.65142658352852, 47.87178821861744, 48.80213789641857, 47.662377655506134, 50.00469356775284, 50.92840500175953, 46.108641028404236, 45.847089663147926, 47.99794904887676, 47.54211790859699, 48.074305951595306, 47.924761176109314, 46.918977946043015, 48.897368386387825, 45.139841213822365, 47.04608112573624, 46.54276393353939, 47.89964072406292, 46.94146513938904, 45.275938510894775, 44.63367037475109, 47.757228165864944, 55.62424622476101, 63.82954493165016, 61.69864967465401, 61.0885164141655, 59.4302473962307, 57.93917700648308, 56.43597386777401, 55.36069616675377, 60.07395565509796, 59.283875450491905, 62.655974105000496, 55.67245043814182, 47.836651504039764, 45.64149409532547, 45.77594228088856, 44.867262840270996, 44.12429250776768, 44.27608676254749, 44.11790505051613, 45.78539237380028, 45.17810516059399, 44.61336046457291, 42.45628081262112, 44.80915255844593, 41.453890800476074, 41.946682557463646, 43.03840957581997, 45.37026844918728, 42.268551886081696, 44.57103453576565, 42.65076957643032, 45.13770952820778, 43.003436252474785, 43.315239921212196, 43.02681639790535, 42.697594463825226, 43.92656251788139, 41.88292197883129, 43.30358974635601, 43.15555348992348, 44.44220244884491, 43.77482146024704, 42.82614916563034, 43.28336723148823, 45.70430852472782, 48.468059822916985, 47.88739778101444, 52.40929953753948, 49.779342859983444, 55.652968883514404, 55.454239547252655, 55.57430550456047, 52.56891757249832, 58.3390561491251, 53.05255562067032, 57.717755287885666, 55.506916120648384, 58.44661317765713, 53.657137379050255, 57.92069859802723, 56.66600972414017, 64.39764484763145, 58.58415439724922, 68.97912740707397, 22.349701523780823, 0.6527602043934166, 2.7540967287495732, 1.865334513131529, 61.59304194152355, 56.37689083814621, 65.84075421094894, 40.762662291526794, 41.45107515156269, 47.96821564435959, 58.55233870446682, 6.054108738899231, 0.28705372649710625, 0.21582748362561688, 0.1521602226421237, 0.2223645875346847, 0.13948273728601635, 0.18314531858777627, 0.13143945951014757, 0.21822603070177138, 0.13866128370864317, 0.24346593883819878, 0.14755347452592105, 0.24951699539087713, 0.12686959613347426, 0.10103347623953596, 0.17798623448470607, 0.14503152313409373], [0.030074785026954487, 0.059357802383601665, 0.06075227189285215, 0.04489967839617748, 0.04823539100470953, 0.04042174114147201, 0.02275633320095949, 0.040819138957886025, 0.059152168105356395, 0.0459065649920376, 0.019565866314223967, 0.09008819324662909, 0.04530867598077748, 0.06021419627359137, 0.025768090927158482, 0.01948111119418172, 0.10781072429381311, 0.07944253011373803, 0.04787461075466126, 0.19996538321720436, 0.2738992776721716, 13.766920622438192, 53.06153453886509, 51.94339893758297, 41.595330610871315, 27.738693952560425, 58.904370814561844, 53.24927866458893, 63.69926132261753, 10.76075753197074, 0.3766602510586381, 0.6645400472916663, 0.24960919981822371, 3.5514604300260544, 53.67088124155998, 66.15622088313103, 64.46664154529572, 60.68665757775307, 58.618664145469666, 55.6455934792757, 54.51236888766289, 54.95750740170479, 54.239315539598465, 53.2297021150589, 52.46279686689377, 50.951804146170616, 51.547760367393494, 49.79134641587734, 50.823629423975945, 47.59299337863922, 46.92367069423199, 45.843555852770805, 44.2128923535347, 40.99356830120087, 45.37227474153042, 46.826855689287186, 45.1084017008543, 41.18180640041828, 43.87529946863651, 44.00293081998825, 44.932037964463234, 44.77310389280319, 44.18621778488159, 43.677136301994324, 43.54125939309597, 42.05974169075489, 44.094346314668655, 42.17326059937477, 44.14233773946762, 42.42307439446449, 43.22766602039337, 41.78986117243767, 43.17892223596573, 43.06209750473499, 42.9548292607069, 40.99943898618221, 41.072398871183395, 41.90455041825771, 42.116024270653725, 44.722881987690926, 43.319518491625786, 41.39951951801777, 43.66044379770756, 42.82908260822296, 46.095820516347885, 49.949972704052925, 52.36649103462696, 54.71683211624622, 56.62571668624878, 60.6240863353014, 53.73146899044514, 57.89006844162941, 60.47524452209473, 59.77265082299709, 55.0179697573185, 47.54716783761978, 41.64245568215847, 42.17124290764332, 42.4266842007637, 42.59134076535702, 41.58820979297161, 40.7456886023283, 40.16767881810665, 39.62179630994797, 38.93706925213337, 39.208006113767624, 39.0321971476078, 39.7676020860672, 38.635912612080574, 39.50240671634674, 39.05781537294388, 39.45853427052498, 39.58692938089371, 41.4614599943161, 40.01863181591034, 39.4653245061636, 41.37351371347904, 40.14843665063381, 40.16522794961929, 39.740722328424454, 39.7588549554348, 39.42427910864353, 39.32845585048199, 39.401685521006584, 39.04017671942711, 41.3988621532917, 38.63068409264088, 41.478331089019775, 42.187825217843056, 44.14415404200554, 43.20906601846218, 46.252600103616714, 47.06014037132263, 48.55295866727829, 46.570130065083504, 50.50631605088711, 47.4122978746891, 50.30990459024906, 48.41320216655731, 50.80945238471031, 48.64996366202831, 53.431300297379494, 47.70140156149864, 52.784176021814346, 53.301822245121, 58.31363931298256, 53.96487906575203, 61.13564908504486, 3.0637532752007246, 0.07085811535944231, 1.0260582296177745, 5.862300731241703, 54.28491689264774, 51.578633710742, 54.403565526008606, 25.957436934113503, 33.69035258889198, 43.2222893089056, 15.062768887728453, 1.0559673747047782, 0.08937340113334358, 0.05919943178014364, 0.04552137921564281, 0.04375389515189454, 0.06868170050438493, 0.014922146256139968, 0.016509377492184285, 0.007989096357050585, 0.05386533070122823, 0.046211558001232333, 0.09838622063398361, 0.03520661004586145, 0.02813322837027954, 0.028037172196491156, 0.02505654756532749, 0.03070355665840907, 0.09483387882937677, 0.02524573399568908, 0.07026218561804853, 0.09704385360237211, 0.02234375660918886, 0.04774527667905204, 0.011589665700739715, 0.03060361534153344, 0.030663523357361555, 0.07118342837202363, 0.03583816287573427, 0.04987968597561121, 0.024151537436409853, 0.050536657363409176, 0.048482463098480366, 0.08439307814114727, 0.032506966235814616, 0.022129281496745534, 0.09073668930795975, 0.22487695037852973, 0.4719086119439453, 23.60244110226631, 59.14732977747917, 50.989258736371994, 49.168362244963646, 35.9847454726696, 67.81512826681137, 59.15148675441742, 68.75041007995605, 12.293930612504482, 0.3989181207725778, 2.329605594277382, 0.30466325813904405, 3.78348286729306, 56.05811834335327, 68.48254725337029, 67.27261617779732, 62.0447389036417, 62.34475560486317, 56.254244819283485, 56.9112029671669, 58.0572784692049, 56.498225927352905, 56.61444649100304, 55.52223689854145, 52.714605554938316, 53.71590122580528, 52.298562079668045, 52.85997815430164, 50.5622224509716, 47.81595781445503, 46.3377383351326, 46.483126133680344, 44.36753645539284, 47.37813390791416, 48.29369857907295, 45.9733796864748, 44.890825375914574, 44.30858261883259, 44.9666503071785, 46.89365990459919, 47.13899374008179, 45.85270956158638, 47.26618431508541, 44.96781304478645, 44.20940414071083, 47.06536889076233, 44.18096646666527, 47.44460754096508, 46.263243332505226, 43.035928308963776, 43.70863661170006, 45.41444107890129, 47.84549742937088, 44.95941549539566, 43.07465583086014, 41.02024666965008, 43.761594370007515, 44.24735650420189, 46.40034757554531, 44.3239413946867, 43.47258187830448, 43.95737886428833, 45.41535682976246, 48.39685544371605, 52.088254764676094, 55.62854379415512, 57.64380745589733, 58.0549605935812, 61.3468911498785, 56.1994593590498, 59.729587733745575, 63.40153589844704, 62.86511868238449, 57.87354312837124, 50.0621996819973, 44.784716069698334, 43.87186825275421, 43.76932695508003, 44.9645072221756, 43.03211711347103, 42.55406476557255, 41.75766550004482, 42.49507673084736, 41.193213388323784, 40.32401762902737, 40.69848373532295, 42.15254791080952, 41.034898683428764, 40.824249386787415, 42.58437193930149, 41.963549852371216, 42.50546537339687, 43.78167249262333, 42.545701414346695, 41.1500059068203, 40.7013525813818, 43.00706125795841, 41.70082814991474, 42.790719866752625, 41.316987946629524, 41.85296058654785, 40.15429213643074, 41.65509380400181, 41.875687167048454, 43.194748386740685, 40.90862765908241, 43.334523886442184, 43.73966954648495, 47.110993042588234, 46.969906613230705, 48.63118126988411, 49.786657467484474, 51.34817987680435, 48.41569863259792, 51.40216737985611, 48.925228491425514, 51.93430222570896, 50.531387105584145, 53.27379874885082, 50.63984848558903, 56.38198256492615, 50.0160663574934, 58.00908945500851, 54.77494619786739, 62.614468932151794, 55.67863650619984, 64.47943925857544, 2.597985193133354, 0.03149646167003084, 1.6848788713105023, 6.365167172625661, 59.75497417151928, 56.18988387286663, 59.16969157755375, 32.71066635847092, 34.34918403625488, 46.76526479423046, 22.798012867569923, 1.4027367671951652, 0.1467305960250087, 0.08037843770580366, 0.05723934184061363, 0.061870120698586106, 0.015827004244783893, 0.017777138273231685, 0.07128048644517548, 0.024413966420979705, 0.09587591353920288, 0.08572291771997698, 0.02630217008118052, 0.05616434835246764, 0.0225190982746426, 0.05703050148440525, 0.06302735899225809, 0.027047798430430703, 0.2677023148862645, 0.10620149580063298, 0.1840938872192055, 0.29500174219720066, 0.1417062117252499, 0.12321002141106874, 0.050309033249504864, 0.18273842870257795, 0.1283406515722163, 0.14502580859698355, 0.18515216012019664, 0.14294904191046953, 0.09386113844811916, 0.19693612935952842, 0.1294663708540611, 0.20178753387881443, 0.37631726008839905, 0.2101155143463984, 0.1900908857351169, 0.33964756526984274, 0.37149380485061556, 29.442138746380806, 73.94473135471344, 57.5683207064867, 53.83757449686527, 43.842210844159126, 71.27600535750389, 65.29471591114998, 75.91945499181747, 16.36024821549654, 0.5309547716751695, 4.2789755668491125, 0.32860767329111695, 4.705931581556797, 58.04840214550495, 70.46723395586014, 70.4565641283989, 65.46148896217346, 64.46608677506447, 60.65500147640705, 59.4894178211689, 61.686908304691315, 60.46197563409805, 60.762547105550766, 57.8166563808918, 57.79096595942974, 56.87769256532192, 55.7926569879055, 56.110422536730766, 52.42388315498829, 50.84642820060253, 49.686715230345726, 48.91219899058342, 45.57975880801678, 51.28226101398468, 52.40139216184616, 49.96194586157799, 45.22481605410576, 48.14834877848625, 47.909516394138336, 48.67520950734615, 49.851922765374184, 47.810866087675095, 49.65082235634327, 49.44242253899574, 46.081252098083496, 49.35295253992081, 44.65491123497486, 50.797304436564445, 49.54904481768608, 46.391311660408974, 46.50695085525513, 48.37054185569286, 49.29688274860382, 47.74797946214676, 46.14170305430889, 45.23176588118076, 46.25106878578663, 48.20635266602039, 48.241709768772125, 45.64185127615929, 44.97472487390041, 47.516625076532364, 47.904755249619484, 50.49842767417431, 54.48143854737282, 57.52496123313904, 58.383779749274254, 59.22858081758022, 64.08535480499268, 58.005555644631386, 61.68335169553757, 64.2760817706585, 64.07986789941788, 58.952392637729645, 52.69136980175972, 46.29282854497433, 45.664900839328766, 45.40046542882919, 48.642804846167564, 45.7059196382761, 46.1312460154295, 43.47287066280842, 45.25921180844307, 42.70831748843193, 43.4891489893198, 43.855141550302505, 44.535324051976204, 43.47421959042549, 44.42850798368454, 44.973379746079445, 44.3612439930439, 43.7945082038641, 44.8452278226614, 43.86437505483627, 42.417355701327324, 43.2808593660593, 44.17401283979416, 44.13935489952564, 44.336286932229996, 44.099183455109596, 44.54876773059368, 41.17661587893963, 44.3168243765831, 43.129019513726234, 46.66022703051567, 42.58676201105118, 45.91209277510643, 45.50444304943085, 49.45812709629536, 48.07453013956547, 52.652820870280266, 52.371537163853645, 53.94386239349842, 51.04254327714443, 55.03257617354393, 51.57876670360565, 54.468633234500885, 53.89924518764019, 56.561895310878754, 52.63517461717129, 59.98265415430069, 51.47956922650337, 60.28360940515995, 57.66063295304775, 66.15763440728188, 57.55999535322189, 66.02632105350494, 3.8654727302491665, 0.1776818055077456, 3.2712884014472365, 7.404700666666031, 67.8109484910965, 62.168988436460495, 63.38360846042633, 37.15357795357704, 43.98697927594185, 58.23617286980152, 33.563279807567596, 1.4751782175153494, 0.2524018718395382, 0.1593947078799829, 0.21633754688082263, 0.16407577466452494, 0.1721246333909221, 0.14395358331967145, 0.13147668563760817, 0.12073638383299112, 0.1626541611040011, 0.24178485560696572, 0.2672406693454832, 0.2235703993937932, 0.15023731801193208, 0.1430777451605536, 0.15520005952566862, 0.13639648648677394], [0.03304562815173995, 0.0991896771301981, 0.04734372654638719, 0.018422634202579502, 0.020451161290111486, 0.06249159516301006, 0.06541825452586636, 0.030353663714777213, 0.07090248836902902, 0.04207298261462711, 0.14693513192469254, 0.05196856080146972, 0.04989572749764193, 0.03371899729245342, 0.035372435522731394, 0.02266440336825326, 0.049818692568806, 0.0804117378720548, 0.09652394204749726, 0.059522147275856696, 0.19447945727733895, 0.7002579525578767, 33.45220036804676, 42.5914091616869, 45.54880566895008, 35.67793473601341, 40.33839985728264, 54.43916581571102, 56.00445382297039, 26.837773695588112, 0.08345461013959721, 0.8532993122935295, 0.07995000327355228, 0.19917438738048077, 20.773804485797882, 73.33411931991577, 59.53911155462265, 65.2398544549942, 55.89144788682461, 60.19533634185791, 53.68014134466648, 55.836461037397385, 53.53845834732056, 54.119279980659485, 52.026033103466034, 55.24994730949402, 53.47551092505455, 54.81158763170242, 55.679913237690926, 55.213765650987625, 48.37926238775253, 46.74870528280735, 46.22449681162834, 50.71848526597023, 56.223561465740204, 56.04552581906319, 54.83758583664894, 50.53068034350872, 45.25942079722881, 44.990649819374084, 45.90034760534763, 43.44374142587185, 43.55162903666496, 43.73481720685959, 41.807651817798615, 42.47674651443958, 43.60347345471382, 43.440454602241516, 42.2930795699358, 43.13872419297695, 43.863930478692055, 42.48504526913166, 43.10985714197159, 43.600870594382286, 41.56690813601017, 40.2894052863121, 43.23383688926697, 40.814955085515976, 42.023514434695244, 43.82734604179859, 40.70155017077923, 39.391688257455826, 41.88257619738579, 44.17050942778587, 46.96557104587555, 48.9725511521101, 51.691301465034485, 54.95936930179596, 56.203623935580254, 67.09872990846634, 57.39564657211304, 56.69400282204151, 59.28081661462784, 54.82256144285202, 49.43047598004341, 47.20997393131256, 45.555394515395164, 44.83128637075424, 45.158433616161346, 45.88172860443592, 43.003728836774826, 42.48855248093605, 40.85294924676418, 40.78335598111153, 41.566638350486755, 40.2301474660635, 40.20597316324711, 40.10213613510132, 37.60017178952694, 40.08941441774368, 40.47791317105293, 41.02229095995426, 40.48165217041969, 42.9187235981226, 42.17130370438099, 40.61434485018253, 39.2706685513258, 40.58864302933216, 41.18321992456913, 40.42953796684742, 41.61902993917465, 41.89631626009941, 40.253630205988884, 39.06634211540222, 38.208766132593155, 40.138294994831085, 39.655150920152664, 41.293011233210564, 43.48055765032768, 45.046347230672836, 45.98421290516853, 46.45694553852081, 47.665774673223495, 48.053467869758606, 47.37051531672478, 48.504773452878, 47.02007532119751, 44.958047568798065, 46.247789561748505, 48.16033333539963, 48.04401017725468, 48.4771641343832, 49.336537420749664, 51.48226708173752, 55.655594542622566, 54.636021852493286, 63.262649551033974, 29.456876255571842, 0.4781571094645187, 0.4092959873378277, 0.7587768312077969, 16.231381930410862, 61.80533654987812, 52.923829928040504, 34.66053172945976, 21.89714390784502, 39.03557896614075, 32.62416400015354, 5.894247991964221, 0.21829672768944874, 0.09498023777268827, 0.06634592427872121, 0.03684163559228182, 0.039200759783852845, 0.06869245422421955, 0.07828717687516473, 0.05790750481537543, 0.05008814412576612, 0.13056235969997942, 0.03209810965927318, 0.07256276920088567, 0.09868349530734122, 0.025270788901252672, 0.049085981299867854, 0.02902054569858592, 0.052805733066634275, 0.044399021862773225, 0.04326728747400921, 0.027231685926381033, 0.015402551434817724, 0.05585892118688207, 0.015747368088341318, 0.003488018242023827, 0.08054317222558893, 0.03670933292596601, 0.07603567893966101, 0.09901680867187679, 0.028795214821002446, 0.021924682514509186, 0.09169443088467233, 0.0018096875669471046, 0.03398719090910163, 0.06614225669181906, 0.06466246617492288, 0.06100791579228826, 0.015508787091675913, 0.20236640906659886, 1.8035266734659672, 45.20319901406765, 47.634046375751495, 46.93772993981838, 52.63928599655628, 53.61136503517628, 60.50593547523022, 63.08342456817627, 31.08077611774206, 0.1734805668820627, 3.935352168045938, 0.8914062206167728, 0.2709669928299263, 25.118565447628498, 72.55761578679085, 62.93695002794266, 69.43167552351952, 58.77183772623539, 61.52008205652237, 55.86106091737747, 58.563559502363205, 54.730724170804024, 56.30960024893284, 53.77490445971489, 56.03221893310547, 56.10210858285427, 56.81427776813507, 58.75730350613594, 56.863374933600426, 51.09067149460316, 46.406670436263084, 47.30659134685993, 51.929210498929024, 58.356861993670464, 57.72729657590389, 55.38508705794811, 51.72574281692505, 48.06671395897865, 46.77720755338669, 47.10080198943615, 44.93344388902187, 46.01919762790203, 45.6802786141634, 44.799140095710754, 44.37861666083336, 46.51345610618591, 44.04827758669853, 45.720108076930046, 45.067287907004356, 45.04814073443413, 43.99603419005871, 45.87343744933605, 46.52662239968777, 42.74129591882229, 42.761051058769226, 44.265720918774605, 44.50932964682579, 44.048459976911545, 46.76905319094658, 43.34169790148735, 43.34555849432945, 45.05615450441837, 45.838984698057175, 48.69679994881153, 49.827562272548676, 54.520074874162674, 57.149503380060196, 57.99506440758705, 61.889806017279625, 58.13953645527363, 57.11101524531841, 61.52564875781536, 56.46515250205994, 50.50464794039726, 49.15609270334244, 46.54784806072712, 45.32245561480522, 44.816136583685875, 46.43363758921623, 43.86366069316864, 44.22616504132748, 43.09345342218876, 42.85293012857437, 43.0271165817976, 42.95675575733185, 41.753371730446815, 43.00736524164677, 40.41284926235676, 41.90037444233894, 43.026991188526154, 43.75327281653881, 41.629904955625534, 43.09572570025921, 43.57176035642624, 41.71367906033993, 43.10519099235535, 41.67009919881821, 41.96045681834221, 42.42568485438824, 42.15344846248627, 42.91745446622372, 42.68008500337601, 41.146855875849724, 41.737070605158806, 41.06996700167656, 40.860256254673004, 43.78718979656696, 45.6771057844162, 46.11113369464874, 49.75985370576382, 50.13188034296036, 49.456899762153625, 49.295058846473694, 49.91263970732689, 50.40652960538864, 50.733289271593094, 48.992887660861015, 48.45862112939358, 51.95434235036373, 51.02971136569977, 52.24526233971119, 52.254313454031944, 54.73746880888939, 58.89978066086769, 57.04408563673496, 66.26979678869247, 30.29133427888155, 0.5420224496629089, 1.0449661337770522, 1.6746999300085008, 20.764664076268673, 66.77147626876831, 59.862956777215004, 42.72152937948704, 27.936342246830463, 41.28519505262375, 40.5221313983202, 8.179749827831984, 0.2354265350732021, 0.04083247906237375, 0.10002135008107871, 0.07312467889278196, 0.028800055479223374, 0.07905694728833623, 0.03739310326636769, 0.0286713744935696, 0.04373769035737496, 0.09812829463044181, 0.10072971519548446, 0.05058276328782085, 0.01304462395637529, 0.021179274954192806, 0.0579546311928425, 0.057926982481149025, 0.02758668670139741, 0.12156021228292957, 0.18194946635048836, 0.15403095429064706, 0.1619523565750569, 0.09723307899548672, 0.11507274321047589, 0.12043587339576334, 0.20321725169196725, 0.21070935123134404, 0.11991458886768669, 0.20203460968332365, 0.17443131742766127, 0.20229410903993994, 0.15832957753445953, 0.2587993926135823, 0.12466043030144647, 0.15758490655571222, 0.14577375986846164, 0.2232294567511417, 0.20777196041308343, 0.36124156904406846, 2.0267597073689103, 57.158231511712074, 57.164379581809044, 56.95548199117184, 48.53908181190491, 55.81252232193947, 67.69014537334442, 70.37873670458794, 34.71426844596863, 0.15312271396396682, 5.925981989130378, 0.663986464496702, 0.562086976133287, 26.557504534721375, 75.2055948972702, 65.53392827510834, 70.53985565900803, 61.34388171136379, 65.22412329912186, 58.54916587471962, 61.34027190506458, 59.290023520588875, 59.65776778757572, 58.20661425590515, 60.585966780781746, 59.59126375615597, 60.277628526091576, 61.75006851553917, 60.16952432692051, 54.98256705701351, 49.747717157006264, 50.91338060796261, 56.25609911978245, 62.21127636730671, 60.21337777376175, 59.751892536878586, 55.060166493058205, 50.2662905305624, 49.6010298281908, 49.995266273617744, 47.06859491765499, 47.100824788212776, 49.29443567991257, 45.544812083244324, 47.675490751862526, 48.89240965247154, 46.66791021823883, 48.72023329138756, 48.54839891195297, 46.19954355061054, 46.359739154577255, 48.39879333972931, 50.43738394975662, 45.11482335627079, 45.03221198916435, 47.23297409713268, 45.82174502313137, 44.517977982759476, 48.612011298537254, 45.62906876206398, 45.50372488796711, 45.12669391930103, 50.04234954714775, 51.41904607415199, 52.82989136874676, 56.89098805189133, 59.4425131380558, 59.138430655002594, 64.63013917207718, 59.24685023725033, 58.506714552640915, 63.324065655469894, 59.6203625947237, 51.802392303943634, 50.47565929591656, 49.528476521372795, 48.558114990592, 47.99217715859413, 48.70721518993378, 46.62858232855797, 47.18795791268349, 45.72712630033493, 44.59472246468067, 44.0342753380537, 45.561937764286995, 43.64370949566364, 45.773951187729836, 41.43692471086979, 44.27417926490307, 44.86070439219475, 46.686016246676445, 44.9982114136219, 46.419566944241524, 46.07449226081371, 44.684234261512756, 46.255104169249535, 44.65721011161804, 44.32019479572773, 44.64665047824383, 43.972038477659225, 45.069328397512436, 45.15995353460312, 42.996319234371185, 43.240771517157555, 43.94768178462982, 43.89930658042431, 46.225853338837624, 47.24493585526943, 50.2401365339756, 51.634680703282356, 52.21554033458233, 51.03125788271427, 52.63911120593548, 53.1795410066843, 53.28255347907543, 53.679320588707924, 50.67307390272617, 51.63757234811783, 55.872992277145386, 52.54667356610298, 54.07426759600639, 54.76936049759388, 57.91143089532852, 59.33791995048523, 62.11002320051193, 67.59936824440956, 34.93910238146782, 0.6455185054801404, 1.0165240662172437, 3.1805297965183854, 21.30600392818451, 74.87391829490662, 63.23630936443806, 46.72654867172241, 32.98474945127964, 51.511753499507904, 54.32152792811394, 12.334335744380951, 0.4831465979805216, 0.3039928019279614, 0.18775111675495282, 0.2743867796380073, 0.15160965296672657, 0.20736818754812703, 0.1647540827980265, 0.19530530436895788, 0.1798220703494735, 0.26004284620285034, 0.19135452574118972, 0.10921295295702294, 0.283720355364494, 0.1338514097733423, 0.09878159980871715, 0.15830695687327534, 0.16656639258144423], [0.026876993142650463, 0.03195198820321821, 0.018590699110063724, 0.05288997053867206, 0.026275655000063125, 0.0872020551469177, 0.03007856441399781, 0.055371044436469674, 0.05646440236887429, 0.0885534095868934, 0.01964899984159274, 0.05395883017627057, 0.022887676641403232, 0.04367993271443993, 0.033491514186607674, 0.021068655987619422, 0.04622391104931012, 0.0399640772229759, 0.1522235872107558, 0.034793025988619775, 0.0791943707736209, 0.13819300336763263, 8.12640069052577, 56.645186841487885, 39.20020513236523, 21.88666597008705, 19.21276845037937, 44.766579642891884, 52.75798782706261, 52.29964882135391, 2.7872055396437645, 1.7490133736282587, 1.0551606304943562, 0.25389816029928625, 4.304553894326091, 54.651688411831856, 69.58081752061844, 60.83808705210686, 62.44476243853569, 59.35273535549641, 58.464764803647995, 59.10326734185219, 56.72408580780029, 54.64106798171997, 55.04793494939804, 54.239022955298424, 57.80011206865311, 57.708476185798645, 57.2036998718977, 57.68003471195698, 56.33560985326767, 52.88616634905338, 55.227520912885666, 58.733098804950714, 61.88911445438862, 62.174741327762604, 60.52666336297989, 55.64200647175312, 47.75633901357651, 45.723451897501945, 45.90663246810436, 46.006836891174316, 43.607660830020905, 43.81602644920349, 42.232047244906425, 44.27977256476879, 42.975712940096855, 41.30146957933903, 41.94347932934761, 45.6642434746027, 42.34542176127434, 43.718109503388405, 41.65790565311909, 41.73677422106266, 41.50087907910347, 44.64893035590649, 41.366518288850784, 42.764873653650284, 44.65487703680992, 45.21877057850361, 42.58954346179962, 42.195345014333725, 44.326365664601326, 50.10786943137646, 52.65006981790066, 54.79666203260422, 56.35059244930744, 57.33082205057144, 55.602006018161774, 80.27902945876122, 64.8581725358963, 57.02286757528782, 58.3701004832983, 56.975537315011024, 52.12243773043156, 50.895874947309494, 51.687057092785835, 53.517396077513695, 53.9539660513401, 50.40354676544666, 47.607770785689354, 41.65108501911163, 42.49736040830612, 42.7290415763855, 41.5864846855402, 40.88562369346619, 39.152327701449394, 40.573595836758614, 40.30691094696522, 41.25210262835026, 39.88583654165268, 41.074173375964165, 40.62407612800598, 41.50109946727753, 39.68213327229023, 39.34055060148239, 39.642056822776794, 37.78905965387821, 39.68261204659939, 39.537551030516624, 40.283454805612564, 42.12261691689491, 41.74610272049904, 42.02499255537987, 41.15778028964996, 40.66115453839302, 39.02051277458668, 40.764436796307564, 42.864861488342285, 45.510667115449905, 48.243047297000885, 46.93161226809025, 49.76238816976547, 47.71901361644268, 48.84948715567589, 48.0374251306057, 47.67926774919033, 45.692228972911835, 45.62858618795872, 43.92916917800903, 47.07504317164421, 47.63172470033169, 49.290616884827614, 54.67327505350113, 52.92976900935173, 56.980100870132446, 51.97804547846317, 2.3212398681789637, 0.3416179970372468, 0.31402506516315043, 0.3105363476788625, 32.60642275214195, 51.122354194521904, 42.9136660695076, 31.90422423183918, 37.03262284398079, 41.32801875472069, 11.29046905785799, 0.5326151638291776, 0.11611890426138416, 0.02971992525999667, 0.04974889357981738, 0.01607281097676605, 0.0203958063502796, 0.05726932460675016, 0.0681819902092684, 0.06360343628330156, 0.019197419678675942, 0.026946810685331002, 0.13745471485890448, 0.03530910064000636, 0.10042268870165572, 0.038119101809570566, 0.04874746919085737, 0.017383057856932282, 0.05326808364770841, 0.043424318500910886, 0.034567999391583726, 0.01832653349993052, 0.04097540928341914, 0.01927856053953292, 0.03486588262603618, 0.037850039880140685, 0.06311925171758048, 0.11067475381423719, 0.04863521935476456, 0.015360378893092275, 0.04029363160952926, 0.046881847229087725, 0.06984743638895452, 0.08871786209056154, 0.06130284527898766, 0.02061340033833403, 0.012498030337155797, 0.16610020509688184, 0.09595727518899366, 0.08099194150418043, 0.4059458139818162, 14.719618801027536, 62.92064130306244, 39.7065469622612, 32.43875674903393, 32.42646060883999, 55.26376336812973, 59.1123678535223, 54.4405185431242, 3.6335600120946765, 3.436051835305989, 2.872010814025998, 0.38207344652619213, 4.9653678853064775, 57.32829138636589, 71.005300283432, 65.20603626966476, 65.33190071582794, 62.16392710804939, 60.15945486724377, 60.650795102119446, 59.354654252529144, 57.37052991986275, 58.827580735087395, 56.752789467573166, 59.47291150689125, 61.20949812233448, 58.940670266747475, 58.82188104093075, 57.07444220781326, 54.83322747051716, 56.503773629665375, 61.621738001704216, 65.3654757142067, 62.857978865504265, 61.236058697104454, 56.397554129362106, 52.0095381885767, 47.69883289933205, 45.93078017234802, 47.06480652093887, 46.898132264614105, 47.97711096704006, 44.5053930580616, 45.55664464831352, 44.98372659087181, 45.94791725277901, 45.166956558823586, 48.96898694336414, 45.42352259159088, 45.024281814694405, 45.67771755158901, 44.99243572354317, 44.18557181954384, 46.20850346982479, 43.986006528139114, 44.663095995783806, 46.14195004105568, 45.71734182536602, 45.92737935483456, 44.961015209555626, 47.788348495960236, 48.27359385788441, 53.903348967432976, 56.15227349102497, 58.782021179795265, 55.24473398923874, 62.90009580552578, 70.13857439160347, 58.206918239593506, 61.902292147278786, 63.57658490538597, 58.754229471087456, 51.31030350923538, 52.333429008722305, 53.17349933087826, 54.866943061351776, 54.53845448791981, 51.530174911022186, 48.59959356486797, 44.01030622422695, 44.141399189829826, 43.99713613092899, 43.07749427855015, 41.853804141283035, 41.78810566663742, 43.1221304833889, 43.25000122189522, 43.16871598362923, 42.58059874176979, 43.37576687335968, 44.46365229785442, 44.47082631289959, 42.45173625648022, 43.10238294303417, 41.19011655449867, 42.02851876616478, 42.55638264119625, 43.28177511692047, 42.64223523437977, 43.07000868022442, 43.620447143912315, 43.31630006432533, 44.957842379808426, 41.53446167707443, 41.04190170764923, 43.65000195801258, 45.842089131474495, 47.40900345146656, 49.79514241218567, 51.341640427708626, 51.95665642619133, 50.339140221476555, 52.41050407290459, 50.710653886199, 48.967847004532814, 46.841389909386635, 48.6956562101841, 46.52791053056717, 48.4171387553215, 51.48969568312168, 53.37279863655567, 56.83040410280228, 56.431638300418854, 59.54576879739761, 54.39191535115242, 2.1177823981270194, 0.4310702736256644, 1.033832374960184, 0.5176712782122195, 36.17110647261143, 59.95558060705662, 48.55178453028202, 37.07852058112621, 39.13574919104576, 48.15958857536316, 20.052494890987873, 0.831513834418729, 0.09086531092179939, 0.047556585632264614, 0.06477587376139127, 0.027995534001092892, 0.04033856494061183, 0.03803779211011715, 0.059963628664263524, 0.060025839193258435, 0.07290371184353717, 0.061706966953352094, 0.08134345232974738, 0.05172557051992044, 0.11474950078991242, 0.02513749546778854, 0.04037523074657656, 0.0932661586557515, 0.051004867200390436, 0.19439652969595045, 0.16618187102722004, 0.1599349468597211, 0.14704360422911122, 0.14954835263779387, 0.21269750548526645, 0.2651563921244815, 0.204971659113653, 0.22761829546652734, 0.10909960474236868, 0.11164108203956857, 0.14870438229991123, 0.378273205133155, 0.1406708563445136, 0.12214299116749316, 0.20444699039217085, 0.1807510611251928, 0.11976453402894549, 0.2628672821447253, 0.13666803832165897, 0.1732169114984572, 0.37035434099379927, 20.29161036014557, 75.34981235861778, 49.27072875201702, 35.6333327293396, 30.80406166613102, 60.36041468381882, 62.68865995109081, 66.92485123872757, 3.6025038035586476, 5.615204265341163, 4.341956712305546, 0.47837966470979154, 5.913075031712651, 58.11570793390274, 69.46214228868484, 66.07438087463379, 68.00945743918419, 66.49965405464172, 63.44067379832268, 66.46470353007317, 63.19786302745342, 58.5386898368597, 60.59855170547962, 60.57553634047508, 61.85751914978027, 66.61323755979538, 62.57316514849663, 61.59491904079914, 61.233949810266495, 58.26343260705471, 60.42939618229866, 62.69805684685707, 66.78776979446411, 65.04646003246307, 63.82255330681801, 59.391424879431725, 52.85137541592121, 49.852534532547, 49.3942791223526, 48.640163987874985, 48.00276719033718, 49.66873459517956, 46.87835052609444, 48.6607550829649, 46.953510493040085, 47.50648722052574, 48.228813260793686, 50.56708239018917, 47.19556890428066, 47.3203694075346, 47.16430798172951, 45.80015078186989, 45.669111013412476, 47.2619741410017, 45.11171892285347, 46.21881991624832, 49.99658480286598, 49.098704382777214, 47.888324931263924, 47.01581194996834, 49.8310162872076, 52.53592774271965, 56.13188378512859, 58.8366774469614, 61.03617802262306, 58.50109085440636, 63.256201297044754, 70.57007923722267, 57.344064339995384, 62.557376995682716, 62.87572771310806, 61.00432813167572, 54.836518093943596, 55.11796899139881, 54.60836313664913, 57.03867852687836, 58.13109330832958, 54.08409766852856, 51.48099035024643, 45.768506079912186, 46.699000149965286, 47.45767503976822, 44.70225669443607, 43.830993846058846, 42.50644192099571, 45.94145379960537, 45.385547429323196, 45.27618169784546, 44.910086542367935, 43.930970281362534, 46.727399826049805, 44.13302443921566, 44.862623289227486, 44.04083378612995, 42.377970814704895, 42.914460226893425, 43.84499229490757, 46.40730120241642, 45.74517533183098, 46.00518397986889, 46.67562760412693, 46.30968824028969, 47.30113863945007, 42.86244861781597, 42.80901588499546, 45.882568359375, 47.98559971153736, 51.11042283475399, 51.823351979255676, 53.08161646127701, 54.547087624669075, 52.693638280034065, 56.308122128248215, 52.17346139252186, 51.245330795645714, 50.231093019247055, 53.22545014321804, 48.80790218710899, 50.402562618255615, 52.247933596372604, 55.46991750597954, 58.41652639210224, 60.035216733813286, 62.430471405386925, 58.25575701892376, 3.7312601320445538, 0.4619275568984449, 1.8362042075023055, 1.1757654463872313, 41.403015330433846, 65.88262796401978, 53.54588694870472, 44.25635442137718, 47.360936030745506, 57.53343477845192, 34.00838792324066, 1.0677556484006345, 0.22363509982824326, 0.24567649990785867, 0.0998879416147247, 0.17168505932204425, 0.09102777446969412, 0.11231247335672379, 0.3276261384598911, 0.13252087257569656, 0.1290648541180417, 0.20620890834834427, 0.3266071400139481, 0.161897407961078, 0.16068289813119918, 0.22316696791676804, 0.12445496671716683, 0.11943721721763723, 0.16772717091953382], [0.06775397880119272, 0.038095531199360266, 0.024209449074987788, 0.009194403555738972, 0.01776103366864845, 0.02962761136586778, 0.028426770040823612, 0.06073136559280101, 0.09217004364472814, 0.13566469919169322, 0.05152175450348295, 0.022682393027935177, 0.08219658076995984, 0.0813304795883596, 0.04502457442868035, 0.05530639595235698, 0.008706908083695453, 0.010190552202402614, 0.05484722918481566, 0.05410501471487805, 0.03157674720569048, 0.10701056293328293, 1.1025788797996938, 25.925866328179836, 47.298053205013275, 39.67080608010292, 18.723463006317616, 36.09835557639599, 50.96275135874748, 70.33788129687309, 16.980059556663036, 1.4314401894807816, 3.7893984373658895, 0.3423420066246763, 0.1345424828468822, 20.647037588059902, 70.39366990327835, 62.87976689636707, 68.00785392522812, 57.585944160819054, 67.081798017025, 57.565527856349945, 62.01561726629734, 54.84116904437542, 60.14381870627403, 57.74716190993786, 61.29007659852505, 58.61510753631592, 60.2931734919548, 59.985933378338814, 59.32779349386692, 56.398751065135, 60.766464695334435, 58.771731331944466, 62.475783973932266, 61.250817105174065, 62.78321407735348, 57.91744217276573, 49.86843287944794, 47.24733352661133, 46.22982792556286, 46.67641416192055, 44.257961735129356, 43.396874740719795, 43.756175860762596, 42.84101776778698, 42.06895999610424, 43.33764731884003, 42.48954802751541, 43.54217514395714, 43.91069456934929, 44.362703114748, 41.547061800956726, 43.12116153538227, 42.794116884469986, 43.47618408501148, 43.25779840350151, 44.35149371623993, 44.81559321284294, 46.60341627895832, 42.66568377614021, 45.79137705266476, 46.70034147799015, 51.17563113570213, 56.15855075418949, 57.39003047347069, 58.72793488204479, 60.27134366333485, 54.651532620191574, 80.22386401891708, 81.77242532372475, 59.535505548119545, 59.13844205439091, 55.259933173656464, 56.613055765628815, 58.4060275554657, 59.56091098487377, 60.090062990784645, 59.12357725203037, 57.504316940903664, 55.84877997636795, 45.46728104352951, 43.51535238325596, 43.806777745485306, 41.29275284707546, 43.36641937494278, 39.82746407389641, 40.977479964494705, 40.456159338355064, 41.9210035353899, 42.8599863499403, 42.501950562000275, 42.126667499542236, 41.39163114130497, 41.3909737765789, 39.07250918447971, 40.033515617251396, 40.02702936530113, 40.86716428399086, 39.6536386013031, 39.1519021242857, 41.022344157099724, 41.88359834253788, 39.78675685822964, 40.69804675877094, 41.77687346935272, 40.28456814587116, 43.618250861763954, 51.10775537788868, 51.761635690927505, 54.60785776376724, 54.43750150501728, 53.094030395150185, 55.198011696338654, 56.40069276094437, 53.387473449110985, 50.64742907881737, 50.94183728098869, 48.113964423537254, 46.11994922161102, 47.323580235242844, 50.193790420889854, 52.08078436553478, 54.97203402221203, 54.37941022217274, 65.04935547709465, 15.608319863677025, 0.33766662469133735, 0.3287346102297306, 0.6810283125378191, 1.30035042995587, 44.5536732673645, 55.321102291345596, 37.95702964067459, 48.755920976400375, 57.56243482232094, 34.922102093696594, 1.9643129082396626, 0.04470509840757586, 0.17411847249604762, 0.061039423671900295, 0.044002800350426696, 0.06447300329455175, 0.052091675679548644, 0.04482597942114808, 0.044062001470592804, 0.03506313805701211, 0.07064004268613644, 0.03847162195597775, 0.005985072666589986, 0.035757955265580676, 0.04482573451241478, 0.14509521424770355, 0.09496132784988731, 0.06269383040489629, 0.06481591262854636, 0.036108456770307384, 0.023337013662967365, 0.015133170381886885, 0.053766907076351345, 0.01750284049194306, 0.031070442928466946, 0.06332474498776719, 0.008638110066385707, 0.04533149331109598, 0.03377034649020061, 0.047023872029967606, 0.059631818148773164, 0.021145729879208375, 0.006878545646031853, 0.021759387673228048, 0.04959145808243193, 0.048109975468833, 0.025749607739271596, 0.011867300363519462, 0.08785343816271052, 0.027952867931162473, 0.07345445221289992, 1.9811077695339918, 38.98715436458588, 50.87010093033314, 34.009729251265526, 26.110893599689007, 43.697871789336205, 57.62807250022888, 75.7507972419262, 16.788228750228882, 2.1537479432299733, 6.425827592611313, 0.9322842489928007, 0.14628312550485134, 22.499400191009045, 73.45802307128906, 64.67250689864159, 70.19635409116745, 60.444990545511246, 69.11023557186127, 61.02179579436779, 63.23328472673893, 58.6156091094017, 61.51960328221321, 60.72876691818237, 63.448980152606964, 61.88234701752663, 63.407262191176414, 60.60792200267315, 62.31969594955444, 57.60970048606396, 62.24452078342438, 60.600998774170876, 65.08536994457245, 61.98844112455845, 64.9760802090168, 57.84662537276745, 53.57370525598526, 49.24048237502575, 46.9467506557703, 47.49749310314655, 48.07022497057915, 46.06634549796581, 45.46108357608318, 46.050929725170135, 45.8094222843647, 45.917594879865646, 45.8858247846365, 45.99724620580673, 46.87944486737251, 44.16763678193092, 44.63041014969349, 45.62893956899643, 45.71635387837887, 44.265078753232956, 46.71055153012276, 45.227171927690506, 47.43486866354942, 47.66360878944397, 46.13115482032299, 47.53068432211876, 51.31737492978573, 51.10272824764252, 58.03256459534168, 57.4860817193985, 63.59917849302292, 57.39567317068577, 60.740876868367195, 78.48250105977058, 61.51335261762142, 59.271689504384995, 61.51864193379879, 57.21876986324787, 57.162392288446426, 59.19261574745178, 59.70112346112728, 62.41342552006245, 58.59535999596119, 59.017623737454414, 57.507489770650864, 45.610894337296486, 43.46714437007904, 43.6998400837183, 42.28540778160095, 44.54545050859451, 42.41208918392658, 41.03708736598492, 42.61634722352028, 44.01220612227917, 43.61965298652649, 45.69676972925663, 43.2033397257328, 40.986800864338875, 42.83530667424202, 40.608128383755684, 41.61928452551365, 42.47040085494518, 42.624585181474686, 43.22070099413395, 43.27452130615711, 42.65834636986256, 45.08415140211582, 41.65296591818333, 42.76738531887531, 43.34433875977993, 39.70662675797939, 46.529502645134926, 54.21216979622841, 54.28826451301575, 56.33578084409237, 56.78186550736427, 56.07382670044899, 55.50625875592232, 57.422150149941444, 56.32610276341438, 52.17022776603699, 53.352906703948975, 48.72556820511818, 50.227293223142624, 49.60827983915806, 52.9575265198946, 55.671629682183266, 56.68943166732788, 55.543215572834015, 67.16788619756699, 15.662582851946354, 0.5233165284153074, 1.9703362975269556, 0.5587369215209037, 2.215741379186511, 48.097233921289444, 61.47272899746895, 44.01475578546524, 56.982243955135345, 58.117015063762665, 42.33760558068752, 7.264928491786122, 0.35422019893303514, 0.12876651075202972, 0.024916367001424078, 0.06496469097328372, 0.011463460705272155, 0.05985025447444059, 0.019887654125341214, 0.03190649826137815, 0.03431856355746277, 0.02112143010890577, 0.042664084685384296, 0.05929429680691101, 0.04287328127247747, 0.038771119361626916, 0.051897244120482355, 0.05776539466751274, 0.020596291979018133, 0.06134558185294736, 0.13047039275988936, 0.14344501920277253, 0.12798829469829798, 0.18532991933170706, 0.1001791752059944, 0.08694527205079794, 0.17658007243881002, 0.13956900453194976, 0.1453317515552044, 0.2193729902501218, 0.14287450059782714, 0.21439384727273136, 0.17449152044719085, 0.23232380859553814, 0.1349905619281344, 0.10922588859102689, 0.07644810524652712, 0.05489680093887728, 0.09054433947312646, 0.15465242875507101, 0.09225719404639676, 0.29799482377711684, 1.9925719918683171, 53.44103917479515, 62.471281215548515, 53.961668238043785, 33.21228504180908, 51.41485869884491, 61.93596214056015, 84.93718430399895, 21.22154016047716, 7.767291935160756, 10.023713931441307, 0.7289348356425762, 0.20982039190130308, 23.733079992234707, 75.33740222454071, 65.5965793132782, 74.11443784832954, 61.213446110486984, 73.34321603178978, 62.345971539616585, 68.31138163805008, 61.07424058020115, 66.24304622411728, 62.93552130460739, 67.58873641490936, 64.50739055871964, 66.58182084560394, 64.96882259845734, 65.22149384021759, 60.977235585451126, 65.90535834431648, 63.301848247647285, 68.97918820381165, 64.45191353559494, 68.13409075140953, 62.3721369355917, 55.7790195196867, 50.18792353570461, 50.73134757578373, 50.992629155516624, 49.779806435108185, 48.888955637812614, 48.58477436006069, 47.36909419298172, 46.675958186388016, 48.042722046375275, 47.490205094218254, 48.000145331025124, 48.41837368905544, 46.930004954338074, 46.75204150378704, 48.27514797449112, 48.73765915632248, 47.39751286804676, 48.78388747572899, 48.01130913197994, 51.07573829591274, 50.28698042035103, 46.34565711021423, 50.395521596074104, 52.26204603910446, 56.17033392190933, 60.03106355667114, 59.56254869699478, 64.75327536463737, 62.22304053604603, 60.28196029365063, 83.60488459467888, 61.353024020791054, 57.021465450525284, 64.5448337495327, 60.158356726169586, 59.150350615382195, 61.24370388686657, 61.20808079838753, 64.46460485458374, 63.881351351737976, 61.08027845621109, 59.065645560622215, 48.3168089389801, 46.03472739458084, 47.06395536661148, 46.240243166685104, 47.413209825754166, 44.20008324086666, 45.13914205133915, 45.74838235974312, 47.500494942069054, 46.8853535503149, 48.1183759868145, 45.66849544644356, 46.11698538064957, 43.9986864477396, 42.908885926008224, 43.67413446307182, 44.48887154459953, 44.57156650722027, 43.028108328580856, 45.36152511835098, 44.220366552472115, 47.83878318965435, 44.17452581226826, 44.21347372233868, 44.92543771862984, 42.86236122250557, 49.506893679499626, 56.10888361930847, 56.72507755458355, 59.37177233397961, 58.70394676923752, 59.56738583743572, 57.8157976269722, 61.04604609310627, 58.186593130230904, 54.77326288819313, 56.53997428715229, 51.91910684108734, 52.46557831764221, 52.17148169875145, 55.80810695886612, 57.56065271794796, 59.554800912737846, 57.11396008729935, 70.39985597133636, 19.30074892938137, 0.49425271921791136, 1.5238644112832844, 2.4154133023694158, 3.9683674089610577, 55.086149498820305, 68.04974287748337, 50.01936838030815, 61.99060320854187, 63.37203808128834, 56.21699921786785, 14.953690990805626, 0.5705246014986187, 0.401735432096757, 0.19021332525881007, 0.2404057522653602, 0.12145502027124166, 0.2317314560059458, 0.12859905255027115, 0.155572498915717, 0.11157050379551947, 0.19177339388988912, 0.23778950358973816, 0.13498603482730687, 0.15605158492689952, 0.17590942326933146, 0.20882563199847937, 0.19405428087338805, 0.1106111888657324, 0.12385291425744072], [0.04109751484065782, 0.03355228865984827, 0.12078009633114561, 0.09766718343598768, 0.07053812354570255, 0.03378611341759097, 0.022530241622007452, 0.0530868697387632, 0.020096915650356095, 0.06892018223879859, 0.03794123127590865, 0.002917745705417474, 0.010872220409510192, 0.030226893759390805, 0.02136828697985038, 0.016988110983220395, 0.03362884861417115, 0.0539469817886129, 0.012033476505166618, 0.06035295191395562, 0.09673839304014109, 0.08800735959084705, 0.18799525365466252, 5.697565795853734, 49.38503801822662, 35.1643580943346, 27.171188704669476, 25.729314275085926, 39.821604788303375, 59.534897580742836, 39.979224130511284, 0.24434286053292453, 3.1010829471051693, 0.29267309058923274, 0.0839457189431414, 1.3218831620179117, 53.82857657968998, 68.42059537768364, 67.48822420835495, 64.76333722472191, 63.5871597379446, 64.56726774573326, 60.09152591228485, 58.345587998628616, 61.55271850526333, 59.70083847641945, 59.81092996895313, 61.32110193371773, 63.833929896354675, 59.77792114019394, 57.29132317006588, 61.25113248825073, 62.2122947126627, 60.03721542656422, 60.07986053824425, 62.98606239259243, 61.57946527004242, 55.61125472187996, 52.333634197711945, 47.191841304302216, 47.059919983148575, 44.05602917075157, 46.94123715162277, 44.05249536037445, 44.94149185717106, 44.13819216191769, 43.19503717124462, 44.94801230728626, 43.850467801094055, 41.403418108820915, 45.04507049918175, 41.81714750826359, 44.24186199903488, 43.13892558217049, 41.889066249132156, 44.18299935758114, 48.76756735146046, 47.523707896471024, 48.15467543900013, 45.32248981297016, 47.79434457421303, 44.986063465476036, 44.59842726588249, 52.3276799172163, 58.05843360722065, 59.415777772665024, 57.79319643974304, 57.844117507338524, 56.237240731716156, 55.149948075413704, 74.71146181225777, 81.57656863331795, 60.20266614854336, 57.56107069551945, 55.60247719287872, 57.057362124323845, 58.755943179130554, 60.67151539027691, 59.67874266207218, 56.136686727404594, 55.772757455706596, 45.670927315950394, 42.67194963991642, 42.97860458493233, 42.374087423086166, 43.07528659701347, 41.92107193171978, 40.093848779797554, 40.92571534216404, 41.477464735507965, 41.873981058597565, 41.02828323841095, 41.63743995130062, 38.852162808179855, 41.0332115739584, 40.894085839390755, 39.628533348441124, 40.00387340784073, 39.637873247265816, 39.023640006780624, 41.1539538949728, 40.84807030856609, 41.730827540159225, 39.561622738838196, 39.79414366185665, 40.49881964921951, 41.92483372986317, 47.41623446345329, 56.86377391219139, 55.77966928482056, 55.58757819235325, 54.97674956917763, 58.86470854282379, 54.75534304976463, 58.99286046624184, 55.96032299101353, 57.68829546868801, 51.44239582121372, 54.16985906660557, 48.097602501511574, 50.01912519335747, 50.45304290950298, 59.503503665328026, 52.75340527296066, 63.45079265534878, 39.713196605443954, 0.11090312007581815, 0.3208263439591974, 0.2016580439521931, 1.2689894065260887, 5.56766739115119, 60.8682232350111, 42.70401991903782, 24.810035303235054, 35.89807592332363, 41.508953645825386, 36.038455590605736, 2.428953875787556, 0.1843235967680812, 0.09470940582104959, 0.05376566397899296, 0.08955533863627352, 0.06818966401624493, 0.04517542336543556, 0.11635525603196584, 0.09430260499357246, 0.006542259980051313, 0.015058745957503561, 0.011217300525458995, 0.015570530995319132, 0.039565276747453026, 0.03703799673530739, 0.07393846608465537, 0.08485229685902596, 0.045551785005955026, 0.0527516156580532, 0.011190062778041465, 0.012545305144158192, 0.03748210903722793, 0.046815940804663114, 0.08022033056477085, 0.012676258957071695, 0.023295253013202455, 0.062163773691281676, 0.044322157627902925, 0.08161251054843888, 0.07810306487954222, 0.0414212433679495, 0.039577737406943925, 0.035422426590230316, 0.056500396531191655, 0.032215792016359046, 0.07968375779455528, 0.03777166537474841, 0.061953270924277604, 0.05657182453433052, 0.1374452153686434, 0.030965017140260898, 0.3076946939108893, 9.399190843105316, 61.16266943514347, 33.55044409632683, 29.68591846525669, 36.010105311870575, 45.26758275926113, 69.70119506120682, 42.02408440411091, 0.9261529811192304, 5.2723899856209755, 2.2707372531294823, 0.3763144992990419, 1.4735192502848804, 56.966512799263, 68.4271614253521, 68.00908505916595, 66.7027835547924, 67.86912336945534, 68.56126382946968, 63.28396640717983, 61.09103187918663, 64.16451215744019, 62.9823499917984, 63.78300502896309, 64.09537866711617, 66.82599574327469, 62.8952244669199, 60.703061297535896, 64.46672514081001, 61.701108142733574, 62.802429646253586, 62.827709689736366, 63.1457906216383, 62.619081884622574, 58.713229671120644, 53.02813433110714, 50.00978149473667, 47.90469445288181, 45.736409202218056, 47.6812132447958, 45.68407841026783, 47.613405883312225, 47.57965989410877, 46.532177701592445, 47.17632293701172, 45.29369495809078, 44.605323895812035, 46.77713915705681, 45.41306175291538, 46.85062721371651, 45.93706503510475, 44.34621959924698, 45.13182744383812, 49.814680963754654, 47.85661183297634, 50.089018642902374, 46.40117593109608, 48.57061631977558, 47.057974487543106, 47.285601273179054, 53.90043072402477, 58.9054499566555, 59.17103670537472, 60.19228510558605, 57.64854960143566, 59.10491265356541, 61.66601322591305, 70.97841292619705, 71.79427474737167, 61.285779029130936, 60.39711311459541, 57.43359133601189, 60.090731754899025, 62.00212799012661, 63.482843935489655, 61.278745606541634, 57.727478966116905, 56.61802589893341, 48.353271782398224, 44.682372361421585, 41.60986103117466, 43.6894666403532, 43.02541047334671, 43.691313341259956, 42.10465908050537, 44.020941853523254, 41.639757826924324, 44.00105372071266, 43.75189729034901, 44.29713383316994, 41.36410541832447, 42.56831020116806, 42.78494417667389, 40.10016784071922, 42.0017796009779, 42.592693492770195, 41.30544796586037, 43.80890943109989, 41.05608634650707, 43.945823684334755, 42.24239408969879, 43.10264132916927, 43.36158983409405, 44.01521176099777, 48.981533870100975, 60.38282588124275, 58.60592722892761, 58.178294375538826, 57.61005386710167, 63.024782314896584, 56.70207738876343, 61.15363731980324, 58.25722374022007, 60.93023970723152, 52.490664571523666, 55.30081897974014, 49.32743690907955, 52.120773419737816, 53.898314237594604, 61.39614410698414, 56.027472987771034, 64.69321578741074, 40.815570652484894, 0.407140048337169, 1.5820328774861991, 2.310542492195964, 1.7954009282402694, 7.157503506168723, 67.99292832612991, 48.45026537775993, 32.8536868840456, 47.20164097845554, 44.72659818828106, 45.46544574201107, 3.2786657055839896, 0.28570577851496637, 0.03206483175745234, 0.12314140985836275, 0.019944194646086544, 0.025541873183101416, 0.0659931889094878, 0.11822123051388189, 0.03228423658583779, 0.0075634278164216084, 0.08018430671654642, 0.05193024371692445, 0.03635897614003625, 0.03268599080911372, 0.009089428622246487, 0.06885787151986733, 0.03866669547278434, 0.059581819659797475, 0.10081416417961009, 0.09772466277354397, 0.0753483537118882, 0.1654694537864998, 0.1241247629513964, 0.12273859436390921, 0.11291390241240151, 0.11645419916021638, 0.20484470733208582, 0.14880670962156728, 0.11428919853642583, 0.12436224278644659, 0.13309464178746566, 0.12676804064540192, 0.21897672791965306, 0.17934129224158823, 0.12137441561208107, 0.16266238410025835, 0.28530276264064014, 0.1720477914204821, 0.15169667720329016, 0.2993971266550943, 0.17526074167108163, 0.4317512089619413, 13.122647143900394, 76.2957563996315, 45.992918238043785, 42.96961046755314, 40.9393186122179, 50.88382959365845, 73.99843007326126, 48.766887187957764, 2.2512376494705677, 10.231594126671553, 1.4867586898617446, 0.4512066696770489, 2.256205645389855, 59.45212282240391, 70.54448381066322, 69.28798243403435, 70.43811991810799, 70.13574734330177, 70.57485178112984, 67.14486703276634, 63.235055431723595, 66.60139739513397, 65.1384074985981, 65.66451966762543, 68.0999381840229, 70.08905544877052, 68.07294443249702, 62.75072202086449, 68.2860217988491, 65.40959894657135, 64.49102103710175, 63.821299374103546, 65.95749154686928, 64.94373634457588, 60.63725262880325, 57.05521523952484, 52.448927611112595, 51.80884435772896, 48.66759851574898, 51.14457160234451, 48.64485673606396, 49.380820244550705, 49.34384062886238, 47.19386659562588, 48.806625455617905, 48.02290990948677, 45.52023120224476, 50.70935815572739, 46.961125284433365, 50.57101517915726, 47.657532915472984, 46.48900821805, 50.53224965929985, 56.13001048564911, 52.724458426237106, 54.12514306604862, 50.190788581967354, 52.058715149760246, 48.56927879154682, 47.15314418077469, 58.1956784427166, 60.88944509625435, 63.142104819417, 63.39651636779308, 61.31721094250679, 57.45137818157673, 68.63907605409622, 77.87175983190536, 71.5475007891655, 63.98452341556549, 63.2284589856863, 59.384915828704834, 61.607758551836014, 62.69382007420063, 66.15253508090973, 62.959946393966675, 59.12946313619614, 60.87065130472183, 49.54321593046188, 46.374839544296265, 44.501008093357086, 46.10395967960358, 47.48684987425804, 46.89737990498543, 43.90378274023533, 46.52043633162975, 44.996653497219086, 46.795374378561974, 45.438394993543625, 45.11590629816055, 42.708157896995544, 46.06104098260403, 46.12800098955631, 42.39345118403435, 43.39675694704056, 45.066995322704315, 42.60464005172253, 46.23184561729431, 44.628426656126976, 46.075472608208656, 44.71280112862587, 43.96237559616566, 44.19402256608009, 45.85345432162285, 51.04922331869602, 63.429908975958824, 61.39151215553284, 58.730887323617935, 60.263196900486946, 64.15606901049614, 59.28701788187027, 63.16132798790932, 58.892211467027664, 62.536212131381035, 54.96140219271183, 58.86475034058094, 53.72561350464821, 56.1503279954195, 57.01248653233051, 64.33267593383789, 58.888540863990784, 64.35678943991661, 44.61358845233917, 0.8121657476294786, 1.4299478195607662, 2.4174264818429947, 3.5075015388429165, 8.488640002906322, 78.32359358668327, 54.01588752865791, 36.098112389445305, 48.212451338768005, 50.87179183959961, 58.1438834220171, 5.5914422404021025, 0.5586561758536845, 0.15856051904847845, 0.378117265063338, 0.19245893054176122, 0.16825727216200903, 0.18159670871682465, 0.29199215525295585, 0.2101485844468698, 0.11137541543575935, 0.12811506836442277, 0.19693134992849082, 0.20393689745105803, 0.1596711133606732, 0.13628985470859334, 0.15120564261451364, 0.1859805898857303, 0.1320715615293011, 0.16784027422545478], [0.02985203311254736, 0.024926026053435635, 0.0735099425946828, 0.027640065673040226, 0.014412434593396029, 0.039810742091503926, 0.09348380088340491, 0.07352577260462567, 0.09178642008919269, 0.02998157127876766, 0.08753774338401854, 0.040116948512149975, 0.065383499750169, 0.013070457189314766, 0.027755556839110795, 0.02881872049329104, 0.05243193925707601, 0.04176795620878693, 0.12844900513300672, 0.023380254897347186, 0.043559593468671665, 0.19814217870589346, 0.037040438401163556, 0.2811750560067594, 19.593783505260944, 41.500445902347565, 27.658438459038734, 30.84300197660923, 26.452405974268913, 60.315014719963074, 53.3598717302084, 2.8775549540296197, 7.552074333652854, 2.271215314976871, 0.1729834169964306, 0.36226276424713433, 4.517321577295661, 68.50777789950371, 63.84804993867874, 62.704140320420265, 67.27240338921547, 64.45319026708603, 64.53585863113403, 61.63101710379124, 60.741013661026955, 64.27791327238083, 61.45925872027874, 61.94600500166416, 59.609510377049446, 62.955143451690674, 63.7868732213974, 63.05745676159859, 64.91132408380508, 64.37553003430367, 63.34255166351795, 60.240386724472046, 57.82944269478321, 52.57582560181618, 49.27175089716911, 47.123376578092575, 45.80934628844261, 45.006540566682816, 44.12111587822437, 43.850426003336906, 46.87310300767422, 45.66241197288036, 46.64106085896492, 43.92271712422371, 46.502524092793465, 43.25471296906471, 42.28192336857319, 44.25083331763744, 44.30527299642563, 44.04024101793766, 44.23849157989025, 42.37869277596474, 47.947624549269676, 52.1768432110548, 51.72812528908253, 49.57071505486965, 48.308468386530876, 48.83542411029339, 45.847731828689575, 45.56289531290531, 54.759306237101555, 61.66303038597107, 57.96019747853279, 55.649685859680176, 57.380097806453705, 48.618212565779686, 12.483984064310789, 51.81686952710152, 76.65774777531624, 53.19776862859726, 61.14109419286251, 56.474154219031334, 61.56252957880497, 56.814581751823425, 60.26969455182552, 57.82733380794525, 53.44849057495594, 45.27483657002449, 41.658015847206116, 42.015128284692764, 42.445037215948105, 40.8390723913908, 40.59191845357418, 40.46620599925518, 43.123574405908585, 42.21109516918659, 40.45883819460869, 42.15599052608013, 42.4077308177948, 40.75122490525246, 41.40834644436836, 42.05664485692978, 42.57370971143246, 40.647824853658676, 41.9781980663538, 40.752741023898125, 38.97986635565758, 39.42858427762985, 39.73799787461758, 41.930955201387405, 40.181624069809914, 40.62800891697407, 41.180309280753136, 47.696070447564125, 54.00433234870434, 53.68620961904526, 56.42949901521206, 56.397972106933594, 55.58733120560646, 55.493521839380264, 57.53831371665001, 54.77327808737755, 59.74634103477001, 54.331190809607506, 53.410610407590866, 50.6453961879015, 50.13332426548004, 52.64222703874111, 60.30756711959839, 51.751714423298836, 62.73247539997101, 7.150366539135575, 0.05508522110176273, 0.8322742686141282, 1.3314802595414221, 0.9525702323298901, 12.17563346028328, 60.5222138017416, 35.676118433475494, 26.507210433483124, 32.897536531090736, 38.19763273000717, 21.686847992241383, 0.09592948917998001, 0.08460957746137865, 0.02660826146893669, 0.05657398418406956, 0.06570755853317678, 0.06666171553661115, 0.0741569692036137, 0.05178427440114319, 0.05796587844088208, 0.06091544419177808, 0.06688922832836397, 0.017978332653001416, 0.04419546930876095, 0.05118879736983217, 0.01976650964934379, 0.05378216192184482, 0.028322425932856277, 0.08918244653614238, 0.05003034937544726, 0.0719680343172513, 0.028858109981229063, 0.025266681113862433, 0.00897994792467216, 0.06832439350546338, 0.10064399713883176, 0.03189755909261294, 0.0326307750219712, 0.03549532404576894, 0.06783240896766074, 0.08948465649154969, 0.0782287995389197, 0.12290815284359269, 0.035971871911897324, 0.0518324546283111, 0.020437951061467174, 0.05303102312609553, 0.0788707350147888, 0.044446715983212925, 0.021777574002044275, 0.016330380749423057, 0.15144059172598645, 0.06158855358080473, 0.8078948955517262, 34.91916485130787, 43.35330627858639, 30.506034158170223, 40.883134827017784, 34.66079771518707, 69.24300044775009, 59.593456238508224, 2.9389874450862408, 1.8437501275911927, 5.9412443451583385, 0.7324521406553686, 0.5626806942746043, 5.736884661018848, 72.90449917316437, 63.34147252142429, 63.30093629658222, 64.53687697649002, 66.88209593296051, 65.99169731140137, 64.2796003818512, 60.45278772711754, 66.72921493649483, 64.6834123134613, 63.486514538526535, 61.32492072880268, 65.28102904558182, 65.57311177253723, 66.15712523460388, 64.74683851003647, 65.23841053247452, 62.30314023792744, 62.498008981347084, 60.52386291325092, 56.087517365813255, 52.208993285894394, 50.708028227090836, 48.855160251259804, 45.45371197164059, 45.77971927821636, 45.39585627615452, 48.747010454535484, 47.993628680706024, 47.953772619366646, 46.55155286192894, 48.14272128045559, 45.93174532055855, 44.13338541984558, 46.8423018604517, 46.097929403185844, 46.3989682495594, 45.551587119698524, 44.89611469209194, 49.741227105259895, 52.49646686017513, 53.48820984363556, 51.41423173248768, 50.75989544391632, 49.00717489421368, 48.16238522529602, 49.45187643170357, 57.97257341444492, 60.140938460826874, 59.46988686919212, 55.511445477604866, 61.33241392672062, 52.85838983952999, 23.23623575270176, 55.72785906493664, 68.93038362264633, 56.46043695509434, 61.591826006770134, 58.893317207694054, 63.10613974928856, 58.63388612866402, 61.900844424963, 59.73403349518776, 55.041395500302315, 47.630873546004295, 44.79701600968838, 45.644267946481705, 45.211015194654465, 42.18487277626991, 43.015929982066154, 40.97363457083702, 44.06982623040676, 44.34946462512016, 42.89147146046162, 42.42036134004593, 42.83352077007294, 41.94644697010517, 42.80784174799919, 43.832775950431824, 43.00678767263889, 41.76588825881481, 41.893576607108116, 43.044268861413, 41.19074732065201, 42.64207564294338, 42.38220378756523, 43.93979720771313, 42.40291267633438, 42.20992863178253, 44.099096059799194, 50.92459760606289, 56.84606686234474, 56.51234596967697, 56.91500276327133, 56.20397351682186, 57.531603276729584, 56.10512562096119, 58.215843960642815, 57.05355852842331, 60.74231319129467, 56.14403173327446, 56.34158693253994, 53.35815042257309, 54.47057493031025, 53.45110483467579, 62.304587960243225, 55.09826324880123, 67.80837222933769, 7.6236064452677965, 0.049972369088209234, 4.30251625366509, 2.5401762826368213, 1.0649432055652142, 14.43874642252922, 68.33767622709274, 39.71961446106434, 32.93834634125233, 35.010033175349236, 43.49353015422821, 27.304952926933765, 0.2656315150670707, 0.037305689402273856, 0.03347335754369851, 0.05691226622730028, 0.05308390114805661, 0.09083932091016322, 0.021481575822690502, 0.02647315719514154, 0.10309593431884423, 0.07779139254125766, 0.038618066246272065, 0.04013003999716602, 0.018419676744088065, 0.08942796383053064, 0.05102538758364972, 0.03421680026804097, 0.033909681005752645, 0.027914357888221275, 0.03480210987618193, 0.251431439537555, 0.23358252074103802, 0.19910916744265705, 0.07960558737977408, 0.10629165190039203, 0.1754518595407717, 0.13921307050623, 0.16927088261581957, 0.1589577313279733, 0.21847411582712084, 0.21116626186994836, 0.14526926272083074, 0.22960072034038603, 0.17326093569863588, 0.14508336957078427, 0.1007604475307744, 0.11923297817702405, 0.14972627512179315, 0.298352301470004, 0.13108542538248003, 0.2281822238001041, 0.30962237797211856, 0.1718021702254191, 0.9316762816160917, 47.90569379925728, 60.0010983645916, 43.16237032413483, 47.97248661518097, 38.21951575577259, 74.10120695829391, 69.23534765839577, 3.249425799585879, 14.28521091118455, 6.237821755930781, 0.521291890181601, 0.3589304321212694, 6.9134801253676414, 74.27462965250015, 62.66053386032581, 64.2179524898529, 66.86563521623611, 67.80945897102356, 69.96218025684357, 67.01403245329857, 63.58609959483147, 68.81857082247734, 66.4854048192501, 65.38085728883743, 64.36628133058548, 68.34076926112175, 67.12469771504402, 67.78450950980186, 66.75593510270119, 68.78630295395851, 65.08996769785881, 64.99513998627663, 63.06384041905403, 58.70365418493748, 55.82939341664314, 53.530319184064865, 51.747948825359344, 48.48149210214615, 49.45070989429951, 46.585925817489624, 51.52475260198116, 50.09339600801468, 51.04870654642582, 48.154071271419525, 51.41312979161739, 46.53661206364632, 46.747078970074654, 49.54774148762226, 48.33358883857727, 48.432052955031395, 47.6999082416296, 47.78862968087196, 53.82551394402981, 57.313700169324875, 55.671071112155914, 55.4595972597599, 53.40561367571354, 52.611315697431564, 49.732677564024925, 49.67753492295742, 59.646391198039055, 62.79087446630001, 60.70855960249901, 57.17813104391098, 58.07358719408512, 61.7211976647377, 30.550848953425884, 57.8146006911993, 68.97247776389122, 57.143655493855476, 64.04227271676064, 59.76177200675011, 67.30237618088722, 60.52460387349129, 63.499145060777664, 60.77701672911644, 56.18044897913933, 49.18223150074482, 46.47307567298412, 46.966091617941856, 47.00373239815235, 44.28361415863037, 44.45767141878605, 44.67867136001587, 46.42912343144417, 45.55532991886139, 44.955551102757454, 45.5901550501585, 44.7694256901741, 44.204924181103706, 45.78082121908665, 45.911727994680405, 47.24894843995571, 44.57443915307522, 45.790913477540016, 45.119869485497475, 42.920976877212524, 45.344049856066704, 45.52452117204666, 44.58733946084976, 45.12499161064625, 43.78339760005474, 47.530414536595345, 51.712181344628334, 59.506376311182976, 58.90128917992115, 60.794419795274734, 59.66945216059685, 60.65219342708588, 59.38492342829704, 62.07968182861805, 59.32462066411972, 63.699299320578575, 56.920356675982475, 58.135854452848434, 56.01282097399235, 56.855425760149956, 55.79393371939659, 65.98785951733589, 56.32299453020096, 70.12913569808006, 8.935552071779966, 0.14269355015130714, 3.2473359117284417, 8.020958248525858, 3.249029195867479, 14.335577208548784, 77.07634851336479, 46.65289342403412, 41.47351294755936, 43.3817895501852, 51.708142161369324, 38.14196191728115, 0.2793559926794842, 0.25661299587227404, 0.12800215801689774, 0.15972422144841403, 0.21062177780549973, 0.2126318254158832, 0.21558630047366023, 0.10960255080135539, 0.40034458797890693, 0.27496648603118956, 0.099088114220649, 0.08469316555419937, 0.0924688768282067, 0.18675185943720862, 0.25465702114161104, 0.15310573362512514, 0.10535149180213921, 0.22617547132540494, 0.11301761755021289], [0.0451239146059379, 0.04417303418449592, 0.03734892321517691, 0.08810263650957495, 0.04601659580657724, 0.06038644874934107, 0.011075043803430162, 0.037875024281674996, 0.03647259152785409, 0.07263018589583226, 0.05055918896687217, 0.0970192217209842, 0.11667052036500536, 0.06402666083886288, 0.05864576363819651, 0.05892444751225412, 0.09483775284024887, 0.035549463718780316, 0.06374418459017761, 0.10784064026665874, 0.021186288249737117, 0.06801184543292038, 0.12254006243892945, 0.16143539134645835, 1.0006602737121284, 28.23551159352064, 26.88789300620556, 25.79145424067974, 29.97064668685198, 36.18194729089737, 73.63168135285378, 11.881063766777515, 0.796780016971752, 5.577025813981891, 0.6461831729393452, 0.05416724379756488, 0.20754518976900727, 5.936112245544791, 67.71058067679405, 69.81873795390129, 63.10927838087082, 61.832387298345566, 61.30622573196888, 58.25433969497681, 58.257322534918785, 59.3414955586195, 61.77855558693409, 62.28084683418274, 61.1486329883337, 62.57258377969265, 62.268090918660164, 63.097149431705475, 62.83677600324154, 65.55847495794296, 61.54715180397034, 59.32123124599457, 53.31583209335804, 51.09571002423763, 49.74712818861008, 46.53897173702717, 45.26653781533241, 44.82715979218483, 45.29418893158436, 46.24223046004772, 47.53636881709099, 44.33222874999046, 44.71096582710743, 45.135133266448975, 45.771678909659386, 46.4241798967123, 43.58459606766701, 43.87475989758968, 43.62897768616676, 44.01387043297291, 43.781102523207664, 47.2487660497427, 56.399165242910385, 55.28408467769623, 56.17807790637016, 57.135558128356934, 55.45414835214615, 53.04652914404869, 50.58593697845936, 47.49212399125099, 50.55512823164463, 59.169292598962784, 59.52651523053646, 59.051194936037064, 60.36723531782627, 54.23099398612976, 16.21004607528448, 30.547573529183865, 73.40440794825554, 68.03706675767899, 59.24620807170868, 56.81289464235306, 55.796544179320335, 57.23793603479862, 57.69092112779617, 54.952024295926094, 48.366453275084496, 42.635680586099625, 42.75949314236641, 43.43138828873634, 43.34177769720554, 42.089931070804596, 39.95378449559212, 39.37006741762161, 41.20869755744934, 41.57740317285061, 40.90425789356232, 40.441735312342644, 39.410322457551956, 41.62505641579628, 44.851972460746765, 43.42263735830784, 41.49890698492527, 40.08477486670017, 40.27167923748493, 41.47823989391327, 40.81942744553089, 39.2482003569603, 39.06924515962601, 41.52378425002098, 41.064020320773125, 41.76297381520271, 40.3658951818943, 43.08321297168732, 52.697118893265724, 52.952411994338036, 55.01799255609512, 53.08937944471836, 57.972524017095566, 52.40943633019924, 56.175668835639954, 52.13899724185467, 55.87024882435799, 56.16493061184883, 55.992286875844, 51.51969127357006, 52.39175207912922, 56.169710755348206, 53.077824264764786, 57.1333010494709, 46.62266984581947, 0.37955682375468314, 0.10920821805484593, 1.6242982470430434, 2.1560622565448284, 0.9971223073080182, 22.59831078350544, 60.732969492673874, 25.062765441834927, 41.80699445307255, 33.856456875801086, 41.18494503200054, 3.834343138150871, 0.18826365878339857, 0.07172317753429525, 0.06889667100040242, 0.09060564829269424, 0.07295112765859812, 0.06967451598029584, 0.010727913504524622, 0.030327321182994638, 0.04282434776541777, 0.018737405007414054, 0.05476060199725907, 0.032037090277299285, 0.05286841114866547, 0.04444183265150059, 0.04005510905699339, 0.04801513270649593, 0.05459448708279524, 0.026926544487650972, 0.014720873023179593, 0.10316387051716447, 0.023692554350418504, 0.07211477175587788, 0.03702920970681589, 0.03139220105367713, 0.021077793680888135, 0.021054785247542895, 0.0808580283774063, 0.010794888621603604, 0.025877873122226447, 0.02235655494587263, 0.07017348412773572, 0.0671148338005878, 0.05542662758671213, 0.018202828614448663, 0.02611938281916082, 0.11908137967111543, 0.06068814662285149, 0.030739472895220388, 0.0168298220160068, 0.018372973390796687, 0.0209747112239711, 0.11245649453485385, 0.05353018794266973, 3.8547900784760714, 50.049933940172195, 27.958624251186848, 36.00831940770149, 37.510496601462364, 43.37875731289387, 79.80356857180595, 12.122118081897497, 0.4148219001945108, 8.380902484059334, 1.6579463914968073, 0.9940485691186041, 0.8253010490443558, 6.93468346260488, 72.81323567032814, 67.59840309619904, 64.99089181423187, 61.59957759082317, 62.885607182979584, 61.72983460128307, 60.81156447529793, 62.367436587810516, 65.22336333990097, 66.49298161268234, 60.471444725990295, 64.76565510034561, 65.10495409369469, 65.54688557982445, 66.89860984683037, 68.5217535495758, 62.664189264178276, 60.971497893333435, 55.22776409983635, 53.07016767561436, 52.705292254686356, 48.82213622331619, 49.23146925866604, 48.985641449689865, 46.93932585418224, 47.20438063144684, 49.486526772379875, 46.96978121995926, 47.318351715803146, 47.13779680430889, 47.452131137251854, 48.7549102306366, 46.50081418454647, 44.72395732998848, 46.60409264266491, 47.145157009363174, 45.71376621723175, 48.893602788448334, 58.81237015128136, 56.46614044904709, 57.54544973373413, 57.32577972114086, 56.838155686855316, 55.655963122844696, 52.4506489187479, 48.382256627082825, 53.89183558523655, 61.48925431072712, 60.558387860655785, 60.86520619690418, 65.19274458289146, 53.06644767522812, 15.118821579962969, 33.47151093184948, 70.08745193481445, 68.41698557138443, 61.65136121213436, 60.98421201109886, 58.760480135679245, 58.945636600255966, 59.45476748049259, 56.48455426096916, 50.128259137272835, 44.43809486925602, 42.93317802250385, 44.25054833292961, 45.816166922450066, 44.15563702583313, 41.24025106430054, 40.332985147833824, 43.19108158349991, 42.31058523058891, 43.809281811118126, 43.6684575676918, 41.450083404779434, 43.16176235675812, 47.58694030344486, 43.89800325036049, 42.75270290672779, 40.91138631105423, 42.51910664141178, 42.51523844897747, 42.93436735868454, 40.389085337519646, 42.7418202906847, 43.54320868849754, 43.727825582027435, 43.07489521801472, 41.80512875318527, 45.81489019095898, 54.77144278585911, 55.49824498593807, 56.773410961031914, 56.2847875803709, 58.364195600152016, 55.77157571911812, 60.80933399498463, 54.7442552447319, 56.92267455160618, 56.798744201660156, 59.12469819188118, 54.669798240065575, 52.47385807335377, 57.074597999453545, 56.45401909947395, 60.36131523549557, 52.0060233771801, 0.9879008552525192, 0.41329061205033213, 3.9333152398467064, 4.6057656314224005, 0.8284008514601737, 24.678298272192478, 69.56146135926247, 31.998455375432968, 48.81414145231247, 35.96261166036129, 48.16281080245972, 6.952321641147137, 0.30910881177987903, 0.16337275301339105, 0.10081306580104865, 0.0035221106509197853, 0.0957067558192648, 0.027963048341916874, 0.03425737719226163, 0.06261459129746072, 0.014236995521059725, 0.1107351052633021, 0.02408882039162563, 0.012952247907378478, 0.01083473824110115, 0.024337365648534615, 0.048633723927196115, 0.05094867548905313, 0.09423736279131845, 0.012291320872463984, 0.015526655224675778, 0.15631890652002767, 0.12781834288034588, 0.13535126054193825, 0.18183219217462465, 0.18846408318495378, 0.15817388979485258, 0.07786113957990892, 0.22121621790574864, 0.23745000071357936, 0.20465510344365612, 0.12883438757853583, 0.29829479986801744, 0.23508118407335132, 0.16660005640005693, 0.1311509421793744, 0.14676924707600847, 0.4493356856983155, 0.08962008359958418, 0.19054050848353654, 0.2915312221739441, 0.1579716248670593, 0.1753325667232275, 0.35069936129730195, 0.24694444437045604, 6.749498499557376, 66.94269508123398, 40.633701011538506, 42.94149197638035, 43.73137079179287, 48.671147525310516, 90.41311606764793, 16.262219175696373, 2.061159973964095, 23.10568615794182, 1.39195496449247, 0.5046083510387689, 0.43714222905691713, 8.414185848087072, 75.19839808344841, 71.29124253988266, 64.40389931201935, 63.97363319993019, 65.66095545887947, 61.477596536278725, 62.046338617801666, 65.15812084078789, 67.79966309666634, 65.35384833812714, 62.19754010438919, 64.86815840005875, 65.93356803059578, 69.02980908751488, 70.44726222753525, 69.99650001525879, 64.44127410650253, 64.89294067025185, 57.88795955479145, 56.39716275036335, 55.48536367714405, 53.563685193657875, 52.96531230211258, 50.46156205236912, 50.03199130296707, 51.23236209154129, 51.398314386606216, 49.53220792114735, 48.63553203642368, 50.918943509459496, 50.05101688206196, 50.47788217663765, 48.99096116423607, 48.42454455792904, 48.96696165204048, 49.49542209506035, 47.10092358291149, 51.429628506302834, 61.13283723592758, 59.83973242342472, 61.24130241572857, 62.706910371780396, 62.00807847082615, 58.81737068295479, 54.72683697938919, 52.70946063101292, 54.14498560130596, 64.58172217011452, 61.624481454491615, 63.476361483335495, 64.93892580270767, 61.78407669067383, 21.06693785637617, 39.61846008896828, 72.5177863240242, 64.63137030601501, 62.59304568171501, 61.65282793343067, 60.74230559170246, 59.828648418188095, 63.55633959174156, 58.11645649373531, 52.96769097447395, 46.876788809895515, 47.67267510294914, 45.803654193878174, 49.56944592297077, 45.83512030541897, 43.540130853652954, 41.600338742136955, 46.202606186270714, 45.46834498643875, 46.27631463110447, 45.48745036125183, 44.16239306330681, 46.68725498020649, 49.782869070768356, 47.70383723080158, 44.37665596604347, 43.61030928790569, 44.26332704722881, 45.53334429860115, 46.56747780740261, 42.74274744093418, 44.006217643618584, 45.685522332787514, 45.407635644078255, 44.767138212919235, 44.18078787624836, 47.963025122880936, 56.80808790028095, 57.180904895067215, 59.979150742292404, 56.895874589681625, 61.22174106538296, 57.76307925581932, 63.19562494754791, 57.087916284799576, 58.814220651984215, 59.20051172375679, 63.08573864400387, 56.003986448049545, 58.10759536921978, 60.801297426223755, 60.41942931711674, 60.56063733994961, 55.609913393855095, 0.9841024840716273, 0.6725924683269113, 3.2378440210595727, 7.637276686728001, 2.493961500003934, 27.99351017922163, 76.77769973874092, 36.79523058235645, 58.426649048924446, 42.31046363711357, 60.71023911237717, 11.310703922063112, 0.5318870872724801, 0.28788110241293907, 0.25719320692587644, 0.19154139852616936, 0.180922185536474, 0.16975562379229814, 0.16293015098199248, 0.18051528080832213, 0.10127013971214183, 0.1272440838511102, 0.10531528983847238, 0.1577768407878466, 0.09772075165528804, 0.10805807469296269, 0.16153308766661212, 0.15856255253311247, 0.18419262254610658, 0.07644369688932784, 0.1523760095005855], [0.02311806340003386, 0.028460686189646367, 0.03465611829597037, 0.04364689229987562, 0.039130274308263324, 0.032458581918035634, 0.053665622472180985, 0.04484270371904131, 0.0383497538859956, 0.021556870415224694, 0.08354587946087122, 0.09130564198130742, 0.000726545645193255, 0.051488740064087324, 0.012206301362311933, 0.05954760665190406, 0.025035518810909707, 0.14422022213693708, 0.11655542068183422, 0.0696188400615938, 0.08320794993778691, 0.06707849825033918, 0.15638791141100228, 0.13528960291296244, 0.2910811244510114, 7.61813236400485, 36.84202887117863, 21.68296840041876, 35.2503664791584, 29.58145447075367, 66.21584728360176, 39.38289552927017, 0.18324221338843927, 5.056769605726004, 2.8197657549753785, 1.1550936056300998, 0.2032380466698669, 0.16250363871222362, 5.356580168008804, 63.05561006069183, 75.47091946005821, 61.0718809068203, 59.84576649963856, 61.96494698524475, 60.91237686574459, 64.62186321616173, 67.29220792651176, 66.04718953371048, 67.84306436777115, 65.21437302231789, 62.02093318104744, 62.464969754219055, 64.05872583389282, 62.439587116241455, 56.36982701718807, 48.60817730426788, 49.55530688166618, 49.917036071419716, 47.52001069486141, 47.317321971058846, 46.611335054039955, 44.7749999910593, 45.33176131546497, 44.5226289331913, 45.707485154271126, 47.38630726933479, 47.243651524186134, 49.3618668615818, 45.1476725935936, 44.90184098482132, 44.358796924352646, 44.94361974298954, 44.26244169473648, 46.69336125254631, 46.69598311185837, 51.21784687042236, 58.843300491571426, 55.53414545953274, 58.87293130159378, 57.21546024084091, 55.11652126908302, 54.176288321614265, 52.79128164052963, 49.54542741179466, 47.04453460872173, 51.34023830294609, 55.32284639775753, 60.25244727730751, 60.9786681085825, 56.484675854444504, 45.701310485601425, 44.60189267992973, 18.325025886297226, 45.18979333341122, 64.16009679436684, 56.716585010290146, 59.02929671108723, 57.36352689564228, 53.16862799227238, 46.55635580420494, 42.55370378494263, 42.628099992871284, 44.52668711543083, 41.90947115421295, 42.89053291082382, 42.24883854389191, 43.30621160566807, 41.40898481011391, 41.363535448908806, 40.55048167705536, 43.21043774485588, 40.11816367506981, 40.39741449058056, 41.54781796038151, 42.63219237327576, 43.905401453375816, 42.064727023243904, 41.006943583488464, 40.57066239416599, 40.535514280200005, 40.94084233045578, 38.83718401193619, 41.145674139261246, 40.438254699110985, 41.94215700030327, 44.69786413013935, 41.41277700662613, 45.38186922669411, 51.662909388542175, 55.971650183200836, 56.10827945172787, 55.369971469044685, 56.02194048464298, 57.559011206030846, 52.47841402888298, 54.58591394126415, 54.01591032743454, 59.39647480845451, 52.16635577380657, 56.3639335334301, 55.00374712049961, 57.89180114865303, 54.47546526789665, 61.688101440668106, 33.798392191529274, 0.05499992235854734, 0.1045709676691331, 4.301287969574332, 2.8140119137242436, 0.21236898639472201, 42.834299728274345, 40.00864215195179, 21.488428339362144, 30.545447543263435, 29.136414751410484, 30.35996049642563, 0.14597047353163362, 0.06351020027068444, 0.07655698573216796, 0.026599090379022527, 0.16582605574512854, 0.013056268253421877, 0.037584996680379845, 0.024532474417355843, 0.06088714981160592, 0.014975317426433321, 0.019703948455571663, 0.03874331108818296, 0.0437026461440837, 0.043489271265571006, 0.010991334183927393, 0.04980352307029534, 0.01567359304317506, 0.03397154272533953, 0.036324455140857026, 0.036937728873454034, 0.050936459738295525, 0.058779172104550526, 0.07858327153371647, 0.039657206580159254, 0.06152111462142784, 0.008950932733569061, 0.02411120913166087, 0.08857859065756202, 0.022356677400239278, 0.03647538942459505, 0.05151551675226074, 0.034225435156258754, 0.03776247758651152, 0.043284657440381125, 0.013403682423813734, 0.09047381317941472, 0.028525384768727235, 0.031198545038932934, 0.0776935848989524, 0.008656024583615363, 0.04797166140633635, 0.028276260636630468, 0.15658652497222647, 0.07950670362333767, 0.6509048352017999, 20.47975916415453, 43.966388180851936, 22.436821348965168, 43.53714421391487, 35.449509993195534, 79.27737280726433, 37.84065708518028, 0.1512797237955965, 2.8663080325350165, 5.408897185698152, 2.8237173054367304, 2.352417907677591, 0.43392421735916287, 7.211585054174066, 68.3621697127819, 72.3309351503849, 64.23300728201866, 61.35780416429043, 61.73822835087776, 61.4504773914814, 63.4049367159605, 68.360535800457, 67.37331077456474, 67.90507704019547, 66.24103233218193, 64.22500491142273, 64.84844505786896, 65.07223024964333, 65.00408470630646, 59.68568108975887, 53.593802377581596, 52.287542670965195, 50.35548694431782, 50.62736615538597, 48.541430085897446, 48.73737797141075, 47.257672771811485, 46.54453843832016, 46.60470440983772, 48.19731295108795, 50.6198425590992, 49.02464635670185, 52.02594950795174, 47.07788161933422, 45.69744609296322, 44.81802508234978, 46.29609636962414, 46.62028357386589, 48.78211297094822, 49.302407652139664, 54.85922567546368, 61.03263661265373, 58.010708168148994, 61.54863752424717, 60.03746621310711, 58.27015824615955, 55.66837705671787, 55.01268804073334, 52.22750969231129, 50.40672719478607, 53.85445699095726, 57.277503311634064, 61.12776830792427, 61.89529292285442, 58.30392703413963, 44.64295707643032, 47.88668341934681, 21.34360671043396, 51.21853843331337, 65.01607686281204, 58.277138471603394, 61.83160834014416, 58.12730871140957, 57.1192342042923, 50.112968757748604, 44.62627217173576, 44.05067905783653, 46.75666585564613, 43.3791296929121, 44.93472062051296, 42.73201301693916, 44.65300753712654, 44.0389870852232, 43.40989664196968, 42.621856927871704, 45.18397964537144, 42.55390517413616, 41.75114884972572, 43.14456827938557, 43.883328437805176, 44.48330104351044, 42.95933581888676, 42.819514721632004, 42.40426540374756, 42.901632115244865, 43.91330882906914, 41.5286897867918, 43.295275792479515, 43.975750878453255, 43.050162345170975, 45.30784159898758, 43.48981395363808, 46.40116073191166, 55.57288058102131, 58.95711958408356, 59.10829447209835, 58.1216736137867, 58.586069494485855, 57.924433797597885, 56.71669140458107, 57.354054003953934, 57.49840825796127, 60.05994200706482, 56.03934735059738, 58.560344874858856, 56.12220950424671, 60.302239805459976, 57.20479041337967, 63.36515665054321, 36.90034054219723, 0.040492998450645246, 0.37089141842443496, 3.172710291109979, 2.7690425142645836, 0.3747279359959066, 48.12650375068188, 49.443315491080284, 29.27218146622181, 37.48719245195389, 34.792684838175774, 39.543623104691505, 0.33981184707954526, 0.031707313246442936, 0.021401824633358046, 0.006471495271398453, 0.06945987202925608, 0.03434063874010462, 0.1312410389073193, 0.003814950528067129, 0.08168079555616714, 0.023710506902716588, 0.04521322094660718, 0.06463289901148528, 0.04473164131923113, 0.03239642705011647, 0.07219881998025812, 0.020394253406266216, 0.04425040679052472, 0.08001217298442498, 0.07057097100187093, 0.039551376321469434, 0.12660757347475737, 0.14452022791374475, 0.16964939277386293, 0.16130036499816924, 0.1689163438277319, 0.10259217189741321, 0.10430084075778723, 0.18381719972239807, 0.19888098671799526, 0.11296701792161912, 0.11278627527644858, 0.17755333974491805, 0.11629420696408488, 0.1426039877696894, 0.1030141867522616, 0.16219756216742098, 0.08579210072639398, 0.25680800259578973, 0.1859629267710261, 0.163438759627752, 0.1584050539531745, 0.10241496929666027, 0.3332205960759893, 0.3121392976026982, 0.6174963153898716, 35.46365283429623, 61.37310214340687, 33.16265590488911, 52.91536398231983, 39.28330287337303, 84.31179106235504, 46.05943366885185, 0.19070499809458852, 17.960313856601715, 8.603148758411407, 3.6351540265604854, 1.0205941228196025, 0.2632577408803627, 7.7309673093259335, 69.394870698452, 76.85586154460907, 64.96116980910301, 61.76873691380024, 63.619951978325844, 64.00080174207687, 67.13912934064865, 70.99236577749252, 70.62997922301292, 71.9059431552887, 69.95376750826836, 67.35354423522949, 67.04994812607765, 67.78184965252876, 69.63111162185669, 62.50459022819996, 54.10124234855175, 56.02645844221115, 55.238874703645706, 54.30279113352299, 51.74897477030754, 51.8490120023489, 50.67040264606476, 48.93023282289505, 48.725059032440186, 49.88671749830246, 52.89288818836212, 52.42452532052994, 54.910640716552734, 49.32378530502319, 49.087145403027534, 47.10245870053768, 48.66063728928566, 49.490444362163544, 52.030038088560104, 52.111870497465134, 55.63137464225292, 62.60382570326328, 61.228238716721535, 64.0406160056591, 62.4595208466053, 59.624344781041145, 57.818058505654335, 57.456348314881325, 55.37823982536793, 52.57268317043781, 56.70113503932953, 59.90349680185318, 63.889581710100174, 63.1405621021986, 61.18045628070831, 48.066725358366966, 52.374219819903374, 27.70771611481905, 50.827626809477806, 66.9911576807499, 59.69461441040039, 63.48042346537113, 61.22478470206261, 59.568100199103355, 52.36985005438328, 45.92721216380596, 46.400081589818, 50.19648067653179, 45.44009730219841, 46.78160011768341, 44.38815414905548, 47.661108523607254, 46.872913017868996, 45.935199335217476, 44.40455786883831, 48.80089916288853, 43.73912617564201, 43.65933805704117, 46.15729741752148, 45.33606268465519, 47.40999519824982, 45.06052806973457, 44.95304323732853, 44.25793893635273, 45.65106198191643, 46.149998009204865, 44.054307863116264, 45.94133980572224, 45.34968115389347, 45.048395320773125, 47.02474147081375, 45.616339445114136, 50.69962687790394, 56.495319083333015, 62.13810749351978, 62.24441438913345, 59.38652694225311, 61.38473331928253, 62.109981402754784, 58.375230208039284, 58.92104811966419, 61.25071071088314, 63.570543229579926, 56.73298493027687, 62.60524682700634, 60.06147712469101, 63.65405514836311, 62.01013036072254, 67.22916930913925, 40.62410272657871, 0.2345811398117803, 0.5452422425150871, 13.041588943451643, 10.448457039892673, 0.39107139338739216, 55.12091003358364, 54.64701846241951, 35.3479528427124, 46.63952574133873, 44.5339485257864, 53.29377807676792, 1.005485539790243, 0.1205825291981455, 0.1404760722653009, 0.16660498426062986, 0.25087186018936336, 0.13856055942596868, 0.18355391541263089, 0.12671564501943067, 0.18301624426385388, 0.1142988093488384, 0.07387089353869669, 0.1522805099375546, 0.07585514409583993, 0.12350194519967772, 0.229331424634438, 0.1386795553844422, 0.09573140254360624, 0.21142503392184153, 0.13727128563914448, 0.1563701147097163], [0.0384555655909935, 0.030178349879861344, 0.09699159156298265, 0.01951592534169322, 0.00966402347330586, 0.03139848333375994, 0.041283630635007285, 0.05331556996679865, 0.11177490610862151, 0.06401935810572468, 0.06482599099399522, 0.05784087479696609, 0.01327008192674839, 0.015322420822485583, 0.03964560310123488, 0.02281913002661895, 0.08547601260943338, 0.013310666272445815, 0.0068016749173693825, 0.10292899562045932, 0.0416804087581113, 0.02742881333688274, 0.042110598369617946, 0.08611171404481865, 0.08075060992268845, 4.59339777007699, 37.502015456557274, 37.6964396238327, 39.260443300008774, 28.174469769001007, 40.90699374675751, 56.09477497637272, 4.48870531283319, 1.8432272993959486, 3.1407312070950866, 3.4647687943652272, 4.774847058579326, 0.6094251328613609, 0.24732442398089916, 4.97695536352694, 64.36742126941681, 62.42122270166874, 64.1345165669918, 63.6037914454937, 68.93071800470352, 65.73768854141235, 64.0058858692646, 67.67960473895073, 63.71082790195942, 62.80894249677658, 60.69725900888443, 61.65730029344559, 54.9792992323637, 54.73456956446171, 47.95893654227257, 48.568211048841476, 45.34517079591751, 47.24759951233864, 47.25571967661381, 47.51963831484318, 44.71142940223217, 46.07047587633133, 46.158581748604774, 47.12672799825668, 44.46027047932148, 46.44856318831444, 46.141235679388046, 47.91224084794521, 47.82569669187069, 48.00934463739395, 44.37568321824074, 43.90672758221626, 43.90214882791042, 47.46019430458546, 49.01140786707401, 57.37174205482006, 61.345093846321106, 59.56855237483978, 54.726943373680115, 57.73036301136017, 68.95532548427582, 60.3562843054533, 58.00375834107399, 54.964202642440796, 51.5100321918726, 46.91308066248894, 50.0636588037014, 55.229390412569046, 59.138286262750626, 60.226494669914246, 63.9019538462162, 48.81809324026108, 20.360455065965652, 46.75829976797104, 62.1153125166893, 58.529969304800034, 56.00316569209099, 52.289282977581024, 46.37053817510605, 41.550569012761116, 43.980090245604515, 48.845124989748, 46.815680488944054, 45.04868030548096, 42.82741069793701, 43.43286640942097, 42.89901405572891, 41.75329573452473, 41.733863577246666, 42.1646274626255, 40.93357712030411, 41.900366842746735, 41.48879952728748, 41.09096087515354, 42.08390459418297, 42.358504459261894, 42.96175628900528, 41.05934277176857, 39.890232905745506, 39.92145583033562, 39.9011155217886, 40.50228886306286, 40.817527547478676, 39.79217916727066, 40.09024277329445, 42.16224879026413, 39.72805380821228, 44.58156377077103, 53.994160294532776, 57.77071684598923, 56.2952484190464, 57.58421525359154, 55.45528069138527, 56.80003233253956, 54.55548897385597, 54.49503421783447, 55.11717863380909, 58.219848945736885, 57.92705945670605, 57.21481427550316, 56.206515580415726, 58.209627494215965, 54.66507509350777, 64.06476750969887, 17.510431297123432, 0.11309205496218055, 0.2138454743544571, 5.182095905765891, 3.5568402288481593, 1.1992511549033225, 53.379797860980034, 24.6267806366086, 36.90561845898628, 26.57052643597126, 40.68056769669056, 15.268370155245066, 0.20498904021224007, 0.04366186883999035, 0.04724597827589605, 0.039020083931973204, 0.11544273351319134, 0.03266475425334647, 0.033831106120487675, 0.051129893108736724, 0.07332490291446447, 0.04063891581608914, 0.07367890735622495, 0.04589280557411257, 0.013558278278651414, 0.037008763538324274, 0.09418498200830072, 0.011095784975623246, 0.05105543343233876, 0.05518813100934494, 0.04330942661908921, 0.03782273626711685, 0.036622156549128704, 0.03155324338877108, 0.085599327867385, 0.03870393644319847, 0.040710852190386504, 0.03412205398490187, 0.05981368143693544, 0.019357144701643847, 0.09825486791669391, 0.02167844162613619, 0.07550516951596364, 0.07325770886382088, 0.052260748052503914, 0.02032073254667921, 0.04797453722858336, 0.07287697968422435, 0.0636181233858224, 0.042267985627404414, 0.04120473291550297, 0.07760883905575611, 0.06525269622216001, 0.042249498728779145, 0.06979432087973692, 0.11351942812325433, 0.2681185706751421, 7.434489168226719, 51.31224140524864, 37.62391671538353, 40.16527734696865, 36.73552058637142, 51.49716608226299, 65.70746496319771, 4.015296315774322, 1.042717604432255, 5.174299199134111, 3.1387261021882296, 7.132033472880721, 2.982441675849259, 0.24283244158141315, 6.978680826723576, 66.68842032551765, 60.62850929796696, 64.36710208654404, 60.882153287529945, 67.56494969129562, 66.064782589674, 66.30761235952377, 67.72286161780357, 68.08623611927032, 64.96942296624184, 63.247336372733116, 62.36531250178814, 59.11707200109959, 57.59092949330807, 51.003021597862244, 50.26674650609493, 49.5123615860939, 49.42177824676037, 49.525801464915276, 48.45334701240063, 47.37631380558014, 48.93710285425186, 47.850174978375435, 49.503052085638046, 46.41117699444294, 48.04160490632057, 47.21306696534157, 50.74368931353092, 50.25789298117161, 49.000244066119194, 48.38398173451424, 46.43912449479103, 47.1315461397171, 49.479588344693184, 49.12069760262966, 59.31073620915413, 63.1678332388401, 60.40777914226055, 57.15917006134987, 58.15747529268265, 64.32831376791, 64.53996241092682, 58.10837812721729, 56.006703302264214, 51.52086541056633, 50.32312788069248, 51.32361799478531, 57.787067368626595, 60.27260139584541, 61.34454667568207, 67.96069085597992, 51.666348204016685, 18.622050248086452, 42.527675181627274, 64.79837894439697, 60.37270322442055, 58.84682670235634, 53.58577340841293, 49.189587906003, 46.36756673455238, 46.4188601821661, 50.872620195150375, 50.35378083586693, 46.47485017776489, 44.526603519916534, 45.90088717639446, 45.530099272727966, 44.93522219359875, 42.19299674034119, 43.21566626429558, 43.43646101653576, 43.44732463359833, 43.468656688928604, 43.24858769774437, 44.52775105834007, 44.89006541669369, 44.98765558004379, 43.12309943139553, 43.1489684432745, 42.068895399570465, 40.703332275152206, 43.79955813288689, 43.37950587272644, 42.66762547194958, 41.46972455084324, 43.645590394735336, 41.79611183702946, 46.85249671339989, 55.85217319428921, 59.85604874789715, 59.26108427345753, 59.43562030792236, 58.276591300964355, 60.230112075805664, 57.3137191683054, 57.05144964158535, 58.68193455040455, 58.89910809695721, 61.80730864405632, 59.65806417167187, 58.576019033789635, 61.46388687193394, 57.69326560199261, 66.27065554261208, 20.910460352897644, 0.17416325368685648, 0.6120907492004335, 4.294832590967417, 1.8382990825921297, 1.3060410995967686, 58.98658700287342, 31.95733018219471, 43.03681366145611, 29.88529186695814, 46.46964445710182, 22.039583064615726, 0.2593316015554592, 0.047184932918753475, 0.07885043727583252, 0.046445264015346766, 0.065440288890386, 0.007142518297769129, 0.0436581172834849, 0.07635313260834664, 0.15426795172970742, 0.022701729685650207, 0.07830478803953156, 0.06566017240402289, 0.05847313266713172, 0.024652294159750454, 0.05257156692096032, 0.003121128029306419, 0.016591373678238597, 0.09355096524814144, 0.09306313673732802, 0.03037226379092317, 0.11146442120661959, 0.20194657612591982, 0.248487577191554, 0.1217572005407419, 0.09942373566445895, 0.1460715095163323, 0.12574972497532144, 0.12714064330793917, 0.14798677002545446, 0.24100533337332308, 0.20202159241307527, 0.15313988726120442, 0.10346363880671561, 0.10010520534706302, 0.12063254253007472, 0.2732598432339728, 0.20194822369376197, 0.11849483809783123, 0.09266672597732395, 0.15988511906471103, 0.16335586173227057, 0.10286967575666495, 0.15191795595455915, 0.35577277187258005, 0.4003094101790339, 10.80199671909213, 71.45538613200188, 45.481606274843216, 54.44090612232685, 42.75733105838299, 53.01479324698448, 70.63376381993294, 6.221072254702449, 4.063127199187875, 14.024708289653063, 8.287058919668198, 10.190674122422934, 1.8921084702014923, 0.36074269737582654, 8.175053279846907, 67.5470906496048, 64.93986815214157, 66.29078686237335, 64.41318601369858, 73.35702449083328, 71.95306062698364, 69.03126820921898, 72.14773178100586, 69.62528273463249, 67.80926898121834, 66.23606219887733, 66.1138379573822, 60.2813371270895, 59.23309877514839, 52.532226741313934, 54.15984280407429, 51.050674840807915, 51.61567412316799, 52.563320472836494, 52.816512286663055, 50.0068024545908, 50.59940725564957, 50.52320994436741, 52.34561875462532, 46.4602817595005, 51.039879620075226, 49.84934650361538, 53.52805830538273, 51.38658061623573, 52.04191245138645, 49.819210320711136, 48.55260148644447, 49.499389082193375, 52.51797370612621, 52.39407375454903, 62.235462069511414, 66.11215844750404, 61.53773210942745, 58.30108478665352, 61.56912602484226, 67.09431454539299, 66.75203651189804, 61.49946056306362, 59.431873708963394, 55.143165439367294, 51.377012729644775, 53.627715557813644, 60.3046640753746, 63.63436460494995, 64.3044738471508, 71.49422004818916, 54.839561730623245, 23.576545491814613, 50.60511074960232, 66.18422538042068, 62.183743044734, 60.388343185186386, 56.228535398840904, 50.94825513660908, 47.61515758931637, 47.62020751833916, 54.50955703854561, 51.40936799347401, 49.79965277016163, 45.82946240901947, 48.526979461312294, 47.50196546316147, 46.39473147690296, 45.732446014881134, 46.86920441687107, 44.7737954556942, 47.08688333630562, 45.70587784051895, 45.994153171777725, 45.577475130558014, 46.985231190919876, 46.851801350712776, 47.41165950894356, 45.213751047849655, 44.22641582787037, 42.4860218167305, 46.759960278868675, 44.703039452433586, 44.12257879972458, 43.77293676137924, 45.756114944815636, 43.790913596749306, 48.88402730226517, 58.169976621866226, 63.323921263217926, 60.853468626737595, 61.28369674086571, 62.0392481982708, 62.456822991371155, 60.53836293518543, 60.338022485375404, 59.00755047798157, 62.28679731488228, 64.13955509662628, 63.20706993341446, 60.092711448669434, 65.07496610283852, 59.92270477116108, 71.12991079688072, 22.358997724950314, 0.16742694249842316, 0.9181317896582186, 18.75374548137188, 8.96686714142561, 1.580659607425332, 67.70517736673355, 36.032907888293266, 53.75975087285042, 38.859621807932854, 57.34340697526932, 31.270169354975224, 0.4912394215352833, 0.23249534860951826, 0.1240926279569976, 0.18533866183133796, 0.267344688763842, 0.08220151605200954, 0.1573389588156715, 0.16911316139157861, 0.26599077391438186, 0.1532644047983922, 0.31470552552491426, 0.1715664641233161, 0.144439215073362, 0.163867364753969, 0.23804769676644355, 0.1377094050985761, 0.08257879424490966, 0.14481353951850906, 0.2164257733966224, 0.22092716622864828], [0.045268343965290114, 0.04266867857950274, 0.020531274276436307, 0.061210525818751194, 0.06548950812430121, 0.04053772398037836, 0.039523352825199254, 0.09730670004501007, 0.035433647863101214, 0.04835730360355228, 0.06934304314199835, 0.07337211092817597, 0.030362196557689458, 0.037176102996454574, 0.028811302727262955, 0.012088509538443759, 0.0600296093034558, 0.059643124768626876, 0.02151075521396706, 0.02481276689650258, 0.07654753077076748, 0.03912583997589536, 0.04715155482699629, 0.01291111530008493, 0.041144374044961296, 0.5317822960205376, 20.642213746905327, 46.8426438421011, 46.74504227936268, 43.54538597166538, 26.574789807200432, 69.03579756617546, 25.160555094480515, 0.9897020773496479, 3.6119527090340853, 2.6592151075601578, 5.039240196347237, 2.8687900118529797, 0.7457215629983693, 0.231324580963701, 30.920996591448784, 66.47658169269562, 59.52530689537525, 68.85707035660744, 63.26170340180397, 65.74540972709656, 61.474594697356224, 63.76582235097885, 59.21571470797062, 54.930680841207504, 51.376917734742165, 49.97314006090164, 48.61133113503456, 50.02081610262394, 48.74006822705269, 49.5646695792675, 47.916641011834145, 46.164156049489975, 49.40169632434845, 46.93092830479145, 47.312313839793205, 46.299523785710335, 47.68856965005398, 45.41116565465927, 45.56737907230854, 48.470119312405586, 45.7583986222744, 45.976119339466095, 46.74873188138008, 47.63410337269306, 46.473558247089386, 44.9825144559145, 42.64189325273037, 47.50562086701393, 50.05218341946602, 60.496732369065285, 58.624622225761414, 61.590024903416634, 55.430065244436264, 60.853039249777794, 66.60206615924835, 57.603343427181244, 59.00402046740055, 56.96705996990204, 56.976867243647575, 53.45998875796795, 51.44420072436333, 54.473622366786, 60.16015022993088, 61.98079593479633, 70.26446923613548, 42.29532524943352, 54.47801873087883, 65.75010627508163, 55.21954894065857, 54.832057133316994, 48.43887738883495, 44.959677681326866, 44.82884310185909, 50.63653126358986, 52.06371568143368, 54.522700533270836, 56.725981906056404, 53.8612662255764, 44.879163801670074, 43.908315896987915, 41.76050014793873, 41.360575407743454, 41.36462219059467, 42.02650487422943, 42.87479795515537, 42.7698627859354, 41.73081234097481, 42.038839012384415, 41.33650749921799, 43.05210404098034, 41.76346018910408, 41.30184195935726, 41.48103654384613, 44.84436146914959, 45.60840167105198, 42.66397766768932, 41.35697320103645, 42.16289475560188, 41.544196754693985, 42.588962092995644, 39.49799135327339, 41.2378191947937, 51.805584132671356, 56.73176899552345, 55.58363400399685, 58.03721934556961, 56.751698926091194, 56.81913010776043, 54.2894272506237, 54.51603189110756, 56.0965570807457, 62.33211748301983, 55.714761167764664, 59.76784028112888, 60.30477046966553, 59.23836909234524, 57.8948599845171, 55.094638243317604, 3.9952870644629, 0.1330489551764913, 0.7100294250994921, 4.645259287208319, 0.2414966796641238, 7.663197945803404, 50.19858196377754, 20.680764578282833, 39.18406739830971, 27.721176892518997, 39.439687281847, 5.5636106338351965, 0.10642890469171107, 0.11867471985169686, 0.06187217644765042, 0.04641538514988497, 0.03019602783751907, 0.0632450457487721, 0.04225635988404974, 0.05646920406434219, 0.05487031739903614, 0.011642050194495823, 0.026453703649167437, 0.025454194001213182, 0.03445202768489253, 0.03594996000174433, 0.07842625534976833, 0.06865814473712817, 0.05540084166568704, 0.029476851486833766, 0.0524806093017105, 0.048888621968217194, 0.08152890019118786, 0.02972756567032775, 0.055636744436924346, 0.002848023482329154, 0.012780198594555259, 0.036598771475837566, 0.1313071939512156, 0.06539624984725378, 0.03170312753354665, 0.03181501742801629, 0.006033639738234342, 0.04643690001103096, 0.021879533960600384, 0.03302505210740492, 0.13008290261495858, 0.03590639964386355, 0.020119502914894838, 0.055131111803348176, 0.05502568972588051, 0.09126964781899005, 0.017375771822116803, 0.06346875132294372, 0.06885387876536697, 0.07447818556101993, 0.020896806126984302, 1.170584661886096, 32.67770312726498, 51.02016247808933, 51.86165012419224, 48.44024911522865, 32.64810651540756, 77.27310955524445, 23.34982305765152, 0.5683153762947768, 3.914440465159714, 3.8818249152973294, 13.137383703142405, 6.768445232883096, 0.9701593103818595, 0.2223866293206811, 35.89234583079815, 67.83905938267708, 60.299743339419365, 71.06064811348915, 67.85340741276741, 67.99905359745026, 65.61864092946053, 65.69628596305847, 61.89848095178604, 58.34307633340359, 54.00679461658001, 52.59637489914894, 51.11053682863712, 50.217691138386726, 51.13800175487995, 51.955915465950966, 52.59776182472706, 50.12550428509712, 50.73476359248161, 50.95740884542465, 48.218941390514374, 48.97119842469692, 49.50308248400688, 47.954885959625244, 48.324803709983826, 50.98672427237034, 46.9551520049572, 48.532614558935165, 49.94429960846901, 49.3604951351881, 48.56779307126999, 47.284358739852905, 46.95573717355728, 46.657384783029556, 50.940416157245636, 61.6020018607378, 61.83282807469368, 63.01394909620285, 58.915021643042564, 62.785098776221275, 66.66130498051643, 62.39524349570274, 62.40503177046776, 60.74605979025364, 58.144559785723686, 54.22962225973606, 53.64949218928814, 55.732563212513924, 58.17327864468098, 63.22180174291134, 70.80915480852127, 45.33034399151802, 56.82182416319847, 67.67814561724663, 57.320672795176506, 59.01471309363842, 49.74529288709164, 47.44289003312588, 45.83646543323994, 51.076623648405075, 52.479052394628525, 55.25410808622837, 56.948775351047516, 52.90674224495888, 44.79130111634731, 45.59381805360317, 42.91094921529293, 42.61258542537689, 42.834839299321175, 45.884981229901314, 45.3759491443634, 44.21913541853428, 43.17674495279789, 42.37920954823494, 42.81297147274017, 44.92586709558964, 42.57893443107605, 41.98054254055023, 45.097530484199524, 46.771287471055984, 46.85530476272106, 45.286931321024895, 43.3699531853199, 43.41431960463524, 43.26352849602699, 45.17831414937973, 41.07030898332596, 44.48009021580219, 54.32656645774841, 58.97916600108147, 58.46772864460945, 62.15962953865528, 59.666499719023705, 60.222128704190254, 57.1353567391634, 57.3123512417078, 59.14411135017872, 62.89055451750755, 58.72711032629013, 62.539821937680244, 61.45460017025471, 61.004939898848534, 58.18821184337139, 58.4361257404089, 3.8831075839698315, 0.33583111537154764, 2.408304358832538, 1.7473219893872738, 0.6271528440993279, 8.265162594616413, 60.02662159502506, 26.071865893900394, 45.930970162153244, 29.413970857858658, 50.30953601002693, 9.04464801773429, 0.30412080755922943, 0.04862015375692863, 0.03881185955833644, 0.10094091558130458, 0.06281864480115473, 0.014939597858756315, 0.030636188203061465, 0.013436972385534318, 0.10484635640750639, 0.0628423786838539, 0.007158875696404721, 0.023306192269956227, 0.06052291857486125, 0.021908752314629965, 0.051568932831287384, 0.07935814050142653, 0.06232899802853353, 0.028871917638753075, 0.08713907649507746, 0.010143299659830518, 0.12753926566801965, 0.13582645769929513, 0.12633714970434085, 0.1612463514902629, 0.1319761510239914, 0.20302552526118234, 0.18669054319616407, 0.2328182422206737, 0.15766247583087534, 0.11747714583179913, 0.14433399337576702, 0.17338405799819157, 0.17683655867585912, 0.10772513982374221, 0.2674404258141294, 0.12944250338478014, 0.18447906186338514, 0.22867272404255345, 0.16053826839197427, 0.16273696994176134, 0.1357021034345962, 0.2044066324015148, 0.29727986839134246, 0.07940714451251552, 0.10237562062684447, 1.0906298272311687, 45.938413962721825, 62.83992223441601, 55.2323542535305, 61.1789857596159, 36.607171073555946, 84.46025669574738, 31.810348369181156, 0.9778954577632248, 11.659827288240194, 7.4582725670188665, 9.88444285467267, 5.929589895531535, 2.0995436143130064, 0.30135396227706224, 37.3464860022068, 69.50055062770844, 62.961808294057846, 72.5050038099289, 70.20735830068588, 70.27958482503891, 70.22270947694778, 68.97098064422607, 65.47756969928741, 61.39013282954693, 56.66258990764618, 54.51588749885559, 54.46244716644287, 54.24162581562996, 54.144130647182465, 55.5866814404726, 54.60555888712406, 51.25909745693207, 55.341157615184784, 52.76663616299629, 52.21207112073898, 50.72683721780777, 52.39195726811886, 50.537329986691475, 49.09313008189201, 53.24540667235851, 50.33461846411228, 49.043497145175934, 50.98113477230072, 51.86578810214996, 50.61816684901714, 49.069643542170525, 48.11013042926788, 51.11705347895622, 54.947677329182625, 65.42014718055725, 64.32740181684494, 65.98763912916183, 61.01973630487919, 62.43646748363972, 67.4881862103939, 62.705375254154205, 63.85518595576286, 63.750896751880646, 62.57968559861183, 56.50391422212124, 56.06525436043739, 58.660853281617165, 64.49431926012039, 65.75407326221466, 71.62921160459518, 48.03638778626919, 57.101257368922234, 72.24664807319641, 59.353856295347214, 59.37353923916817, 50.78036114573479, 48.50764989852905, 49.70844626426697, 55.78904338181019, 56.82840161025524, 58.24039064347744, 61.13442935049534, 58.41886706650257, 46.744799092411995, 48.730348348617554, 44.228049740195274, 45.5475365370512, 43.43844451010227, 47.68041908740997, 47.45021604001522, 46.94170072674751, 45.207336992025375, 45.071163699030876, 44.754583686590195, 48.251091465353966, 45.64494051039219, 45.234220549464226, 48.3787190169096, 48.4656735509634, 49.26030211150646, 48.78014087677002, 47.05662555992603, 45.968177765607834, 44.73843835294247, 47.96431325376034, 42.422534823417664, 47.081487625837326, 57.12787874042988, 61.08879379928112, 60.30659057199955, 64.55750226974487, 60.519835129380226, 61.50951102375984, 56.76520340144634, 60.653580352663994, 61.35279223322868, 66.26583740115166, 59.074829667806625, 65.04062354564667, 64.39086601138115, 64.58932176232338, 59.557688757777214, 60.91567508876324, 5.986373573541641, 0.6341194140259176, 3.341257134452462, 11.184802427887917, 1.3114358601160347, 10.508361775428057, 65.17201289534569, 31.54134750366211, 58.437185883522034, 37.03732319176197, 64.47120890021324, 12.921313047409058, 0.5604205280542374, 0.17797627486288548, 0.19196473440388218, 0.24402891722274944, 0.0834711229254026, 0.27791328728199005, 0.07208324532257393, 0.17972424044273794, 0.24209128838265315, 0.16590849350905046, 0.12960963504156098, 0.10587084674625657, 0.08554703614208847, 0.211640672350768, 0.1058302290039137, 0.20565563725540414, 0.11438964822445996, 0.12040832487400621, 0.1784587005386129, 0.17432668944820762], [0.10716410586610436, 0.013548952265409753, 0.010322666548745474, 0.08930999203585088, 0.02938571575214155, 0.051129848579876125, 0.04344067543570418, 0.02216030698036775, 0.08863913506502286, 0.024519013713870663, 0.04870843593380414, 0.06248267454793677, 0.05538114135561045, 0.06313909674645402, 0.027113250289403368, 0.07505648187361658, 0.07435557534336112, 0.023670052432862576, 0.037142123765079305, 0.026231402589473873, 0.08124830899760127, 0.041171718476107344, 0.09139268106082454, 0.07544095889898017, 0.07890139313531108, 0.17183694726554677, 8.795167654752731, 57.80249074101448, 38.47312934696674, 48.13992463052273, 30.025076866149902, 45.7420215010643, 54.91536006331444, 1.1502162110991776, 2.8598673781380057, 0.4882242833264172, 12.648552283644676, 6.05299492366612, 0.9714379417710006, 0.37131280987523496, 5.8537564147263765, 61.73748359084129, 60.87961882352829, 68.5647976398468, 66.99040532112122, 65.84233492612839, 61.2422751635313, 56.55643120408058, 52.242214903235435, 51.47586442530155, 51.393511444330215, 54.83188234269619, 54.01844099164009, 53.75251606106758, 50.524843856692314, 52.50232994556427, 48.70179668068886, 47.751106694340706, 47.77669072151184, 46.37079656124115, 45.79137325286865, 47.3035629093647, 46.20501525700092, 49.108542054891586, 46.34589649736881, 45.87431140244007, 45.54271839559078, 46.54000528156757, 49.404831156134605, 48.26244905591011, 47.06558167934418, 43.37433435022831, 43.814662322402, 45.547813922166824, 52.89551004767418, 60.518668591976166, 59.58280920982361, 61.68805204331875, 56.95977196097374, 58.14449518918991, 64.21023890376091, 61.448680087924004, 63.155898079276085, 61.77115738391876, 57.46071808040142, 55.64049035310745, 54.472448229789734, 57.69941367208958, 59.5488466322422, 61.207324638962746, 58.27667489647865, 53.584720864892006, 61.66831590235233, 55.6117182970047, 54.872627556324005, 48.467064276337624, 48.36787819862366, 49.54323872923851, 49.650491774082184, 52.203240394592285, 56.11161187291145, 55.34429244697094, 55.830107778310776, 54.50804091989994, 47.499765381217, 43.91596108675003, 41.89681023359299, 42.0541749894619, 42.2244818508625, 41.328478530049324, 41.50744132697582, 44.13213908672333, 41.660485714673996, 41.83618828654289, 42.91100241243839, 43.22755582630634, 43.00551474094391, 43.938243091106415, 48.729037418961525, 55.29646821320057, 52.911009415984154, 51.67800597846508, 43.458401039242744, 40.03941290080547, 41.2485384196043, 42.1819469332695, 40.226404666900635, 42.33442895114422, 51.76986984908581, 55.196563974022865, 56.20316416025162, 57.450861409306526, 58.01395699381828, 56.03508397936821, 54.81701374053955, 56.51147201657295, 55.77740840613842, 57.776845917105675, 60.657140761613846, 60.55589139461517, 60.161666348576546, 57.37292759120464, 60.81611283123493, 24.81094155460596, 0.025343953529954888, 0.44758709671441466, 0.8936942915897816, 1.9602043787017465, 0.5196186143439263, 22.8545880317688, 35.58304622769356, 27.224026769399643, 58.61433997750282, 37.118422240018845, 29.3155637383461, 2.1200990863144398, 0.28692934254650027, 0.10705880995374173, 0.030758117500226945, 0.0618486095481785, 0.04330844327341765, 0.06842727001640014, 0.04634281423932407, 0.019053927280765492, 0.08205468955566175, 0.017801751600927673, 0.023718939555692486, 0.057052127667702734, 0.042966869805241004, 0.059358904472901486, 0.09602588674169965, 0.03443657617026474, 0.10508212188142352, 0.020401081164891366, 0.05674519023159519, 0.052120997934252955, 0.02545560408179881, 0.06066444984753616, 0.027858778448717203, 0.0469241904647788, 0.023905845737317577, 0.04960354395734612, 0.07014766481006518, 0.006102726729295682, 0.018068390418193303, 0.020863671088591218, 0.016920957750699017, 0.0435490957897855, 0.03026621459866874, 0.08825160039123148, 0.06724146645865403, 0.08677449644892476, 0.03650999948149547, 0.04475065514270682, 0.030162492039380595, 0.04822034024982713, 0.02309135721588973, 0.07832856645109132, 0.04364693311799783, 0.09348995328764431, 0.07331289496505633, 0.36252785939723253, 12.933975867927074, 66.14241242408752, 41.908042430877686, 58.634304106235504, 34.002988412976265, 58.28312695026398, 57.24385231733322, 1.1246343213133514, 3.0232163378968835, 3.51719006896019, 12.247011680155993, 7.53147991374135, 2.490964410826564, 0.5748785147443414, 8.065472859889269, 69.12687107920647, 61.19085252285004, 72.325699031353, 66.88084200024605, 69.44515720009804, 62.92616240680218, 58.693071752786636, 52.332908436656, 54.2956855148077, 51.8853722512722, 56.489778980612755, 54.08270314335823, 55.4893496632576, 53.60484838485718, 54.607766568660736, 51.021287217736244, 50.557506904006004, 49.5856786519289, 50.55643156170845, 48.327281177043915, 49.61009994149208, 47.71930620074272, 52.523635402321815, 49.27289463579655, 47.98321343958378, 48.14300246536732, 49.43176411092281, 50.47237627208233, 50.536102652549744, 48.8778792321682, 44.935142397880554, 46.41037903726101, 49.68022897839546, 55.0563894957304, 62.32588581740856, 61.466706320643425, 63.315379321575165, 58.048516139388084, 63.3842696249485, 62.64134109020233, 63.53993207216263, 64.10376861691475, 61.3737291097641, 59.12532515823841, 58.479736000299454, 57.76386961340904, 59.56167474389076, 61.642659679055214, 62.697057500481606, 56.43002338707447, 57.15357296168804, 67.62994900345802, 56.791213005781174, 59.701856821775436, 51.62315972149372, 50.11398710310459, 51.03655479848385, 52.69940637052059, 54.805321767926216, 58.58758941292763, 58.78290273249149, 59.96295601129532, 56.62074275314808, 50.3258903324604, 44.29043859243393, 43.861350417137146, 43.62210765480995, 44.17244732379913, 43.7952833622694, 43.98870438337326, 45.18000885844231, 43.882925659418106, 44.26964230835438, 44.76540170609951, 43.568807914853096, 44.044994562864304, 45.73029913008213, 50.95840819180012, 57.1192342042923, 55.17540670931339, 54.29608069360256, 44.84483264386654, 43.85598510503769, 41.954373344779015, 44.40732792019844, 42.40442879498005, 44.27030727267265, 53.172211199998856, 57.39883080124855, 61.01699285209179, 60.546665489673615, 59.4044353812933, 58.61420698463917, 54.974287301301956, 57.978037521243095, 59.280786216259, 59.27482433617115, 60.78767515718937, 61.41004376113415, 61.51681423187256, 59.03206676244736, 61.294526159763336, 27.04410072416067, 0.0418341149634216, 1.1524345795623958, 1.8714456539601088, 3.1606528256088495, 0.7647395425010473, 24.787567108869553, 43.90539765357971, 31.03790681809187, 70.60515895485878, 39.595330730080605, 40.65005533397198, 3.5334992688149214, 0.4107936710352078, 0.19261942739831284, 0.04422145560965873, 0.01394682505633682, 0.03088524183112895, 0.16049669327912852, 0.0416356795176398, 0.056788850779412314, 0.011750977992051048, 0.028357067531032953, 0.06959020800422877, 0.042946787289110944, 0.06283042268478312, 0.0674816699756775, 0.08853118226397783, 0.04950997026753612, 0.08931371019571088, 0.019005628309969325, 0.05098385699966457, 0.0316033457784215, 0.16300981311360374, 0.16000695002730936, 0.14232237241230905, 0.14203146536601707, 0.20937657274771482, 0.09759895780007355, 0.14650762517703697, 0.17273047822527587, 0.1924683409743011, 0.11365540442056954, 0.12186096020741388, 0.17196014377987012, 0.14386434748303145, 0.20780991384526715, 0.17618297890294343, 0.15818239480722696, 0.15308306843508035, 0.1642628849367611, 0.12412531956215389, 0.13136395340552554, 0.147741608961951, 0.15506626514252275, 0.15967862389516085, 0.23476214963011444, 0.18549007480032742, 0.5287679296452552, 13.266455177217722, 82.34936356544495, 45.62641270458698, 66.84437915682793, 41.14616811275482, 58.86730000376701, 66.35157600045204, 1.2328209285624325, 5.779174016788602, 5.945242680609226, 20.814519301056862, 11.526360400021076, 5.0054937321692705, 0.4929913056548685, 9.818326402455568, 70.53839653730392, 65.03806248307228, 74.46616977453232, 71.93618953227997, 73.1240513920784, 67.92890936136246, 61.80167734622955, 55.70781134068966, 57.573887407779694, 56.092464700341225, 61.97889603674412, 58.48892390727997, 59.673335552215576, 55.59792883694172, 58.94613437354565, 54.56192962825298, 51.019983887672424, 52.69054904580116, 52.50191196799278, 49.61258500814438, 52.917252480983734, 50.594604313373566, 56.010837480425835, 53.02331618964672, 51.436996310949326, 50.06992846727371, 51.591374427080154, 53.033180460333824, 53.204771652817726, 52.89882346987724, 47.793972194194794, 49.64258819818497, 51.68367147445679, 59.61850069463253, 64.06759455800056, 63.901596665382385, 66.5222704410553, 58.83584909141064, 65.4378542304039, 68.13482031226158, 64.41143050789833, 67.7454324066639, 63.65686319768429, 61.29631966352463, 60.17384089529514, 59.95138943195343, 64.37696635723114, 65.08856937289238, 64.86180514097214, 59.455223456025124, 58.2046839594841, 66.36222302913666, 57.10691146552563, 60.215509459376335, 53.53597708046436, 53.77237379550934, 53.60189974308014, 54.739737287163734, 57.082778960466385, 61.57369337975979, 59.32867884635925, 62.11191929876804, 59.1168250143528, 51.295693293213844, 47.912723422050476, 45.643496587872505, 45.45894809067249, 46.95234015583992, 44.47064012289047, 46.092982068657875, 48.27651210129261, 46.10998995602131, 45.556355863809586, 47.1247711032629, 47.702887281775475, 48.05851399898529, 48.42052437365055, 55.73607422411442, 61.84916339814663, 58.54055933654308, 56.577444076538086, 47.30297774076462, 45.21723926067352, 46.36393412947655, 46.518954411149025, 44.73051957786083, 47.772955521941185, 56.59963108599186, 60.67223735153675, 63.92342269420624, 60.79701125621796, 62.68748581409454, 60.27132846415043, 59.53896716237068, 61.32106773555279, 62.25159980356693, 60.64151979982853, 64.06897008419037, 59.38268534839153, 65.23696660995483, 58.55645388364792, 64.51863795518875, 28.264395743608475, 0.15757255721837282, 1.5484831715002656, 3.4903701581060886, 9.919533021748066, 0.6800410186406225, 30.374713204801083, 49.47675749659538, 40.07662050426006, 73.41909795999527, 44.98812675476074, 55.846545696258545, 4.585276180878282, 0.6235473125707358, 0.25127710250671953, 0.17238082276890054, 0.17133571556769311, 0.1740343277924694, 0.2045291312970221, 0.13965536083560437, 0.1149709576566238, 0.1144627646135632, 0.10308759257895872, 0.1396868724259548, 0.1681877626106143, 0.10187137580942363, 0.1332775960327126, 0.1727384637342766, 0.10462146339705214, 0.21635843091644347, 0.109944443393033, 0.15633665869245306, 0.147300164680928], [0.03426626069995109, 0.04421629026182927, 0.04824039679078851, 0.06845664422144182, 0.03679047935293056, 0.036533781603793614, 0.11590714726480655, 0.020620678951672744, 0.044659923878498375, 0.030219147593015805, 0.02944200579804601, 0.02780649228952825, 0.1028056358336471, 0.020493033262027893, 0.030468156692222692, 0.07968734978931025, 0.06876906612887979, 0.1474795417743735, 0.10567599587375298, 0.060247251531109214, 0.04989048422430642, 0.12306353630265221, 0.10047350355307572, 0.07108067060471512, 0.041404147996217944, 0.029865701617382, 0.4205117386300117, 37.204947397112846, 47.48901575803757, 33.91733340919018, 57.450603023171425, 24.990400224924088, 61.455713510513306, 6.848930614069104, 1.709245063830167, 3.325132937170565, 19.570230469107628, 11.247560810297728, 1.7280325619503856, 0.23310546821448952, 0.1307281109620817, 42.22755208611488, 65.57352975010872, 66.57794505357742, 70.60056120157242, 62.86771774291992, 58.64284224808216, 56.51570878922939, 57.99928978085518, 60.83972096443176, 65.36759600043297, 63.78811955451965, 65.5673360824585, 57.343197986483574, 56.858708783984184, 52.7705043554306, 53.179335817694664, 50.18187806010246, 48.15357729792595, 45.58222107589245, 47.41764418780804, 45.183934047818184, 49.69184875488281, 45.723596289753914, 49.36180226504803, 51.53501585125923, 50.2999073266983, 48.22948582470417, 49.719161689281464, 47.14054025709629, 46.31821498274803, 43.912799656391144, 44.05255235731602, 45.32676078379154, 49.44513559341431, 56.09640508890152, 59.8097900301218, 59.857872650027275, 60.05413971841335, 52.34373025596142, 56.38387866318226, 63.869207203388214, 56.23020350933075, 61.431212425231934, 57.1588546782732, 59.00280073285103, 59.736070185899734, 60.59731677174568, 57.58562117815018, 65.05035102367401, 56.35736748576164, 59.38778467476368, 64.84461486339569, 57.30880983173847, 54.407543912529945, 47.609640285372734, 52.833216190338135, 53.24649341404438, 54.29741442203522, 56.31395861506462, 56.95068284869194, 59.631720185279846, 58.45960848033428, 57.33594797551632, 51.613842621445656, 44.34198662638664, 44.473136588931084, 42.398318722844124, 40.78274421393871, 41.814727038145065, 41.72616899013519, 41.98588125407696, 42.71731540560722, 42.342727705836296, 42.281550988554955, 42.75570094585419, 44.50850509107113, 49.42345395684242, 53.877932131290436, 57.062944024801254, 56.43999025225639, 55.626016929745674, 51.415584459900856, 43.855810314416885, 40.20269013941288, 42.90921650826931, 40.95445699989796, 41.99135676026344, 49.62076976895332, 59.33323100209236, 58.57854209840298, 61.00299060344696, 58.4115144610405, 57.31053873896599, 54.51207250356674, 59.40696224570274, 54.87743429839611, 58.63211542367935, 55.49322925508022, 64.26198452711105, 55.47920800745487, 66.93556666374207, 35.374262630939484, 0.328400821890682, 0.15465985023183748, 0.1025368002592586, 1.1874252394773066, 1.5196173079311848, 0.10513370856642723, 24.311355762183666, 26.323074214160442, 43.3068385720253, 36.12480975687504, 38.86795476078987, 27.62469246983528, 0.9245995176024735, 0.03934270665922668, 0.03667008815682493, 0.006650787481703446, 0.052770135953323916, 0.05110747282742523, 0.0401787137525389, 0.04330351541284472, 0.06290167628321797, 0.010535157343838364, 0.0823618051072117, 0.04188648461422417, 0.025173515605274588, 0.005130593053763732, 0.007539988009739318, 0.13518776540877298, 0.06890358781674877, 0.0326358884194633, 0.08640292537165806, 0.05392948936787434, 0.08199677977245301, 0.04180803218332585, 0.013874215183022898, 0.0183123955866904, 0.03521723017911427, 0.02024288311076816, 0.007531051624027896, 0.060194269608473405, 0.007624201361977612, 0.030465473828371614, 0.016529241074749734, 0.06578057844308205, 0.03989280878158752, 0.03853433714539278, 0.027104995751869865, 0.026918811308860313, 0.046453342292807065, 0.019000130851054564, 0.04682415266870521, 0.050178485762444325, 0.021504083306354005, 0.07819506150553934, 0.14428280002903193, 0.04378307639854029, 0.05484403052832931, 0.05009058579162229, 0.038369777030311525, 1.0160475480370224, 48.939557522535324, 47.09824852645397, 36.24384216964245, 61.16779915988445, 30.823092944920063, 72.5997707247734, 5.837992010638118, 0.5744616652373224, 2.9492611438035965, 8.247323501855135, 6.182884303852916, 3.410858712159097, 0.5119165463838726, 0.8452607842627913, 47.50498250126839, 68.64897832274437, 68.30601632595062, 72.32610940933228, 66.76275953650475, 60.709912329912186, 57.01308690011501, 59.95477505028248, 63.14646318554878, 68.11376944184303, 64.78131785988808, 65.42542889714241, 59.86916944384575, 60.1025415211916, 55.8694014698267, 55.18644891679287, 53.07442344725132, 50.27522765100002, 48.70606005191803, 49.28553655743599, 48.46920356154442, 50.51887057721615, 49.01679217815399, 52.250996232032776, 53.19424621760845, 50.95734424889088, 48.128464445471764, 51.15861564874649, 48.658061027526855, 46.50507375597954, 46.84491232037544, 44.84738230705261, 47.23051182925701, 52.135949805378914, 58.668870851397514, 63.50465476512909, 63.15789297223091, 61.77977152168751, 59.54997517168522, 61.5878514200449, 61.451184153556824, 59.05387759208679, 63.9724400639534, 58.74009042978287, 60.5257286131382, 62.544032111763954, 64.20812621712685, 59.448467418551445, 64.88067492842674, 55.94171918928623, 63.67695651948452, 64.84806507825851, 59.39026214182377, 56.42110526561737, 49.23285998404026, 52.711246535182, 55.80510511994362, 56.40405558049679, 58.18576857447624, 61.17434620857239, 62.808509320020676, 58.60604502260685, 59.023357629776, 51.47450029850006, 46.553452759981155, 45.88287614285946, 43.973546996712685, 43.18259283900261, 44.21805627644062, 44.32527892291546, 45.07043033838272, 44.14977394044399, 44.24790747463703, 43.52911904454231, 46.4463897049427, 48.66561122238636, 52.79334872961044, 55.59880658984184, 58.598365634679794, 56.56244248151779, 58.52117657661438, 53.59993904829025, 44.98520851135254, 40.79810678958893, 44.51856695115566, 42.5535061955452, 45.392132475972176, 51.93461000919342, 62.34884798526764, 60.047710463404655, 62.24860556423664, 60.086031407117844, 58.99978369474411, 57.41692543029785, 61.301677376031876, 57.439617812633514, 61.849965155124664, 57.790342792868614, 66.25577554106712, 54.95002940297127, 66.22562795877457, 37.110541462898254, 0.41794625285547227, 0.6039107381366193, 0.784661517245695, 3.0446566874161363, 0.17947719432413578, 0.011150473837915342, 30.5875226855278, 30.27042780071497, 51.95420555770397, 41.958070546388626, 45.69670893251896, 37.83770464360714, 1.4980509714223444, 0.032688039136701263, 0.015926502128422726, 0.029115583274688106, 0.05007172410842031, 0.03584592202969361, 0.01904676370031666, 0.0733351445524022, 0.07566317275632173, 0.03286812127043959, 0.08952168223913759, 0.03168417308188509, 0.005495665700436803, 0.044875703315483406, 0.021714860667998437, 0.06036908620444592, 0.029582837596535683, 0.016577948226768058, 0.04980978679668624, 0.0029228744097054005, 0.04777342634042725, 0.12935423234011978, 0.15084197541000322, 0.19779663474764675, 0.14501106954412535, 0.22137481486424804, 0.1510020566638559, 0.2071108849486336, 0.07658466784050688, 0.09840684491791762, 0.1297808633535169, 0.3019361919723451, 0.0837624901032541, 0.1494205102790147, 0.12607432552613318, 0.08572975290007889, 0.18920102098491043, 0.2204369628452696, 0.2085769531549886, 0.23047143768053502, 0.12994398741284385, 0.16801531717646867, 0.32935139432083815, 0.2026526108966209, 0.17437550792237744, 0.14602687675505877, 0.12122625324991532, 0.47439620189834386, 60.155689269304276, 61.2102884799242, 45.77553190290928, 72.8151735663414, 38.25222060084343, 73.81730139255524, 8.467822819948196, 3.2073342707008123, 10.580433458089828, 37.19402678310871, 28.26231725513935, 4.186389734968543, 2.394342008046806, 1.1670770938508213, 48.42230647802353, 74.14339989423752, 70.59324279427528, 75.06215259432793, 66.89621597528458, 64.93340849876404, 60.77121824026108, 64.26644548773766, 66.93049013614655, 70.42725250124931, 69.68373119831085, 69.29348453879356, 62.48105049133301, 63.35858300328255, 58.36678706109524, 58.979017809033394, 54.976498782634735, 53.588091284036636, 50.933880507946014, 50.37680760025978, 50.7085146009922, 53.48951697349548, 51.13037936389446, 54.979432225227356, 58.82687397301197, 54.3482480943203, 52.51457288861275, 54.91987802088261, 51.73922449350357, 48.925486877560616, 47.67043322324753, 47.26588033139706, 51.411450281739235, 55.801928490400314, 60.802239775657654, 66.45514324307442, 66.59727841615677, 63.752568662166595, 57.18849688768387, 63.38802382349968, 60.19114516675472, 62.70669378340244, 65.35573303699493, 62.19902582466602, 62.79006130993366, 65.33934831619263, 66.16705790162086, 59.39083971083164, 67.37947404384613, 57.46317654848099, 61.68091222643852, 69.51116725802422, 62.27031759917736, 60.50831034779549, 50.460874289274216, 57.15596683323383, 60.169752314686775, 59.389289394021034, 60.94929188489914, 63.732106760144234, 64.52506721019745, 60.97759656608105, 60.86691610515118, 56.05123691260815, 48.99905472993851, 48.64363320171833, 46.75187051296234, 45.10961003601551, 45.64350798726082, 45.678458511829376, 46.04931861162186, 46.32618695497513, 46.113690957427025, 46.022203266620636, 48.75605396926403, 51.32398657500744, 54.2239947617054, 59.87689822912216, 60.75532369315624, 58.73708099126816, 60.169949904084206, 58.31069827079773, 47.487685829401016, 44.135771691799164, 47.03943528234959, 46.232586577534676, 47.45014004409313, 54.037823751568794, 65.29411554336548, 63.39105226099491, 64.7532145678997, 61.94820128381252, 62.02005922794342, 58.611683920025826, 63.27277220785618, 61.53615899384022, 63.044970631599426, 60.85492014884949, 66.77235782146454, 56.660272032022476, 67.5471818447113, 41.044580563902855, 0.6936958234291524, 1.023063634056598, 0.936431607697159, 5.869200685992837, 4.401375548914075, 0.1347253331914544, 32.98142082989216, 37.45914235711098, 58.90091300010681, 43.24683219194412, 53.06712783873081, 46.45311154425144, 1.3223658548668027, 0.2742346393642947, 0.1842893986031413, 0.12814184505259618, 0.1100782526191324, 0.14690592099213973, 0.162543699843809, 0.1324305680464022, 0.24618414376163855, 0.10405253298813477, 0.2198404839145951, 0.1648201487842016, 0.16324321855790913, 0.11406213845475577, 0.24805489025311545, 0.2696192526491359, 0.1794556126696989, 0.10268414625898004, 0.14606270764488727, 0.1093197480076924, 0.11916064846445806], [0.07099077425664291, 0.04776603454956785, 0.04150750319240615, 0.04607852803019341, 0.06599256550543942, 0.024425970659649465, 0.005569755230681039, 0.027608862073975615, 0.009389923288836144, 0.04782836011145264, 0.0706935441121459, 0.0791823331383057, 0.01743446828186279, 0.1093257000320591, 0.05033958004787564, 0.04053380915138405, 0.052056011772947386, 0.058527231522020884, 0.10165261293877847, 0.02801259783154819, 0.011797957795351977, 0.16173220588825643, 0.06558785011293367, 0.06720532386680134, 0.08116691766190343, 0.10239745461149141, 0.4412045079516247, 12.111467253416777, 65.69557920098305, 29.037979133427143, 53.72524872422218, 35.8624604344368, 44.02951039373875, 25.21627340465784, 0.7411076605785638, 3.7048123637214303, 0.907936996081844, 4.844690635800362, 3.052345337346196, 0.2503935608547181, 0.15936220181174576, 20.16091827303171, 68.64803597331047, 64.97467428445816, 70.04395186901093, 66.08926087617874, 66.28051981329918, 65.87454199790955, 68.57271641492844, 65.0709231197834, 64.88711938261986, 66.67972639203072, 62.762220203876495, 60.62452711164951, 58.762041851878166, 58.08120958507061, 56.440077647566795, 54.11528259515762, 46.977084428071976, 46.612106412649155, 48.946803733706474, 46.17859907448292, 49.16528061032295, 53.756524845957756, 64.22179028391838, 63.00072580575943, 59.91173096001148, 49.7600968927145, 48.34626875817776, 50.10782763361931, 46.47040821611881, 44.825423285365105, 43.44234690070152, 42.005077823996544, 47.94761314988136, 54.06215764582157, 60.34618064761162, 60.786273032426834, 62.428997084498405, 57.475392892956734, 46.199855133891106, 64.40294176340103, 66.56355142593384, 61.2907225638628, 61.37382410466671, 57.005156725645065, 61.86193831264973, 58.52395422756672, 58.54078732430935, 57.82090075314045, 51.04098916053772, 59.58405174314976, 65.35843849182129, 55.23847572505474, 56.31593830883503, 53.75487573444843, 53.92541818320751, 55.8533701300621, 57.98321284353733, 54.80798162519932, 58.58707644045353, 57.918046340346336, 59.70870025455952, 57.904625460505486, 55.44147603213787, 46.021815687417984, 43.120675161480904, 41.25740334391594, 42.243271842598915, 41.04278706014156, 41.228980869054794, 41.4642034471035, 43.238594233989716, 42.038702219724655, 45.06056606769562, 45.62041662633419, 49.43720921874046, 51.25698857009411, 54.83456499874592, 56.54511161148548, 60.41268467903137, 56.52668260037899, 54.85303580760956, 48.88556621968746, 41.384749710559845, 40.18637001514435, 43.536923825740814, 39.15187552571297, 48.02580535411835, 57.44437895715237, 60.64588576555252, 59.86547224223614, 59.66059863567352, 57.186274006962776, 59.542246386408806, 54.32653225958347, 57.88645103573799, 54.015469551086426, 60.61392568051815, 54.80843000113964, 65.56405305862427, 45.01121811568737, 0.3519632387906313, 0.03566826300811954, 0.32466894714161754, 0.8059695863630623, 1.9069163943640888, 0.7312918966636062, 1.4980633207596838, 17.84352522343397, 37.87221819162369, 35.694786831736565, 24.429151341319084, 46.55544765293598, 9.690947737544775, 0.42633620265405625, 0.049402277218177915, 0.0057735359951038845, 0.017777069624571595, 0.04045607289299369, 0.015519566786679206, 0.10975665034493431, 0.07502611319068819, 0.03339903516462073, 0.061055925325490534, 0.053759563525090925, 0.03034537392522907, 0.08869076627888717, 0.05300377517414745, 0.06856645981315523, 0.07991171587491408, 0.011221552103961585, 0.054027463993406855, 0.07595972754643299, 0.015551180422335165, 0.036995223053963855, 0.04789223676198162, 0.06225300210644491, 0.03504539330606349, 0.05111392951221205, 0.052103921116213314, 0.08775127411354333, 0.04447531835467089, 0.03580176053219475, 0.023121879894461017, 0.01806627529731486, 0.03247894645028282, 0.026276044627593365, 0.019403825790504925, 0.08378345577511936, 0.06103719351813197, 0.09093637898331508, 0.05480436644575093, 0.07433288046740927, 0.012815552654501516, 0.08749685846851207, 0.07519009071984328, 0.08271535683888942, 0.0995158584555611, 0.03219730511773378, 0.06235921828192659, 0.09890996167086996, 0.377335338271223, 16.432995311915874, 72.1876448392868, 29.404389671981335, 67.24300816655159, 40.943676978349686, 55.236412435770035, 23.67456693202257, 0.664840528042987, 3.8438497530296445, 2.302213814109564, 4.2858408484607935, 2.876937724649906, 1.6140390350483358, 0.2331748144933954, 25.72497870773077, 74.89138975739479, 67.99156799912453, 72.4425807595253, 66.84817895293236, 67.03563049435616, 65.52728623151779, 70.85811138153076, 65.8727864921093, 68.83449196815491, 69.65601548552513, 66.01416930556297, 64.06598344445229, 62.624185010790825, 60.083493143320084, 57.90929161012173, 57.21831388771534, 50.81898607313633, 47.535696253180504, 49.70023490488529, 46.89354211091995, 52.31195256114006, 56.027001813054085, 64.5232205092907, 62.90845915675163, 60.56810773909092, 50.884471759200096, 51.36998310685158, 50.426273345947266, 48.09590399265289, 48.171280547976494, 48.586716055870056, 45.24155415594578, 51.213834285736084, 56.490455344319344, 64.3004460632801, 62.03895561397076, 62.69399106502533, 55.330765172839165, 50.68818189203739, 65.9985901415348, 61.119230166077614, 59.34734724462032, 62.29685917496681, 60.90983100235462, 62.96744719147682, 60.74664115905762, 62.53645531833172, 59.139194414019585, 51.06749273836613, 61.694447100162506, 65.20317882299423, 58.77449378371239, 58.23974847793579, 56.0455372184515, 57.027674317359924, 58.89907009899616, 59.08073075115681, 57.97267600893974, 61.41021855175495, 60.41127495467663, 60.186877995729446, 57.59847208857536, 55.55702023208141, 47.510769590735435, 45.79439029097557, 43.51151458919048, 45.33548131585121, 43.85909713804722, 43.05305778980255, 43.60454119741917, 46.49943105876446, 43.280707374215126, 48.120336681604385, 48.74500796198845, 51.423970609903336, 54.16993506252766, 56.93904407322407, 59.50876258313656, 63.17028030753136, 58.327827751636505, 56.915717124938965, 49.27593447268009, 43.420490473508835, 42.15898096561432, 45.70577144622803, 41.57899908721447, 51.70718461275101, 59.566135704517365, 63.91626387834549, 61.668874472379684, 61.97254277765751, 57.91001357138157, 60.284513756632805, 56.47722825407982, 60.75201027095318, 57.51775681972504, 63.7039502710104, 56.43845893442631, 66.6350407898426, 46.7035561054945, 0.6970570399425924, 0.5624730116687715, 2.2098813811317086, 2.222652970813215, 0.8627726789563894, 0.5509471020195633, 1.6163057321682572, 23.644605539739132, 40.33345252275467, 44.47995342314243, 22.015376463532448, 55.13457030057907, 13.756374288350344, 0.5422989442013204, 0.06643306725891307, 0.05091181301395409, 0.06695395102724433, 0.08584624782088213, 0.03111012927547563, 0.07608733241795562, 0.0462667403917294, 0.022360989278240595, 0.0190818116243463, 0.025370490875502583, 0.04126035317312926, 0.047134611595538445, 0.04828827644814737, 0.03478142993117217, 0.05226641435001511, 0.028025106730638072, 0.026820730927283876, 0.05447643736260943, 0.006219865927050705, 0.045953160733915865, 0.11869354813825339, 0.10816019421326928, 0.15576162782963365, 0.07750471573672257, 0.1712429174222052, 0.16708586626918986, 0.09814022094360553, 0.12177320866612718, 0.08310717370477505, 0.1630247599678114, 0.27953387063462287, 0.12687997135799378, 0.09177936226478778, 0.1331698807189241, 0.13279524457175285, 0.18227353255497292, 0.16972768935374916, 0.13968893559649587, 0.13832776254275814, 0.3150636563077569, 0.15698143659392372, 0.2784483163850382, 0.2066643346915953, 0.10551201092312112, 0.30560370767489076, 0.11927151790587232, 0.5882279702927917, 17.10315015166998, 88.11675488948822, 39.061105996370316, 71.88992321491241, 46.35699190199375, 58.59903819859028, 28.626806996762753, 0.6527956493664533, 10.000793561339378, 6.876439712941647, 13.757793512195349, 5.369302835315466, 2.0437478832900524, 0.30588385357987136, 25.605710707604885, 79.83532726764679, 70.68034172058105, 75.93143954873085, 70.51091641187668, 71.43887981772423, 70.9313790500164, 75.70121750235558, 68.67882192134857, 69.43803638219833, 72.85232797265053, 69.3893913924694, 66.22962534427643, 66.38514339923859, 62.36996725201607, 61.845276206731796, 59.528456926345825, 51.08695909380913, 50.74796408414841, 53.4385921061039, 48.90535555779934, 55.02314507961273, 60.32640650868416, 69.67632159590721, 68.4228752553463, 63.7980218231678, 54.47385415434837, 55.40524497628212, 55.002455189824104, 50.51493778824806, 50.815570056438446, 49.31623511016369, 48.19870367646217, 53.1495264172554, 57.1272137761116, 66.22055143117905, 65.08590191602707, 66.42702475190163, 57.664246559143066, 56.40025198459625, 66.83662757277489, 60.32705247402191, 61.715026795864105, 63.369359225034714, 62.54541903734207, 64.45515096187592, 62.24124535918236, 61.5055326372385, 59.49303902685642, 49.604050666093826, 62.25810885429382, 70.41637748479843, 60.8728551864624, 60.89065343141556, 60.63974529504776, 59.707685708999634, 62.91708469390869, 64.11708310246468, 59.85907718539238, 66.67764410376549, 64.04804840683937, 65.46652749180794, 60.915158316493034, 58.188850209116936, 51.831437945365906, 48.78950357437134, 45.950729101896286, 47.41771258413792, 45.71946211159229, 45.16697935760021, 45.75261153280735, 48.08048062026501, 45.85101865231991, 50.8784718811512, 51.00837551057339, 55.43855018913746, 56.88854858279228, 58.81893239915371, 63.64145502448082, 64.39927116036415, 60.713385343551636, 58.381971046328545, 53.41504476964474, 45.65771922469139, 44.63285721838474, 48.014732748270035, 44.28420692682266, 53.05149927735329, 63.04452605545521, 66.13210737705231, 65.00567302107811, 63.42373810708523, 59.85365487635136, 63.82174775004387, 58.297463580965996, 63.760122656822205, 59.533199071884155, 64.3196502327919, 57.83882059156895, 68.48177209496498, 49.416063353419304, 0.8222035027574748, 0.44384450535289943, 1.9534279173240066, 4.092168565839529, 7.632442871108651, 1.3366616377606988, 2.1700899163261056, 30.71933951228857, 49.49286103248596, 51.07779398560524, 32.89015732705593, 67.52088725566864, 15.104984622448683, 0.7866866898257285, 0.11993413703748956, 0.1587622199440375, 0.1098673119849991, 0.20847670384682715, 0.15016218298114836, 0.2925496269017458, 0.10915796723566018, 0.06536162865813822, 0.14774631417822093, 0.12721099890768528, 0.1130345459387172, 0.11871102571603842, 0.15845510439248756, 0.12025181335047819, 0.15960633871145546, 0.2209464175393805, 0.08208104321965948, 0.09283657389460132, 0.09742442693095654, 0.12135804383433424], [0.014314916388684651, 0.04081828548805788, 0.07365390440099873, 0.015465196120203473, 0.052722475229529664, 0.03377879213076085, 0.06759760086424649, 0.037786727261845954, 0.03878850788169075, 0.060804444874520414, 0.06564084687852301, 0.037583861194434576, 0.04669720459787641, 0.021911405492573977, 0.03028023747901898, 0.033732723313733004, 0.02698601092561148, 0.03282021192717366, 0.046145287924446166, 0.07694525513215922, 0.03229993300919887, 0.019326532965351362, 0.08547913705115207, 0.05012136636651121, 0.04570304954540916, 0.04804740128747653, 0.03344224671309348, 0.4869140958180651, 32.134282886981964, 50.494111105799675, 30.83916988223791, 52.59621910750866, 31.00004754960537, 41.881193071603775, 1.3290967186912894, 3.2514651026576757, 1.7334215040318668, 2.5109378015622497, 1.905316086485982, 1.6584954620338976, 0.1962107393774204, 3.19406870752573, 53.25788900256157, 66.45119145512581, 69.54371631145477, 68.77015382051468, 68.13718378543854, 67.34200045466423, 71.22829511761665, 70.5127403140068, 69.5298470556736, 67.05261558294296, 65.28447166085243, 65.60771271586418, 62.285946160554886, 60.82449518144131, 62.38995797932148, 57.115100026130676, 49.06033784151077, 47.76963450014591, 49.64423730969429, 48.87763984501362, 50.88920250535011, 61.66406773030758, 63.91639307141304, 67.19452276825905, 65.06883323192596, 58.7932837754488, 47.654762864112854, 49.3304805457592, 45.91504521667957, 46.94445937871933, 43.35123158991337, 45.35655118525028, 43.16799022257328, 50.342871621251106, 60.70249892771244, 62.336890026926994, 59.69621032476425, 60.32720826566219, 52.434188202023506, 46.75339803099632, 54.08434845507145, 60.24040572345257, 59.01293858885765, 57.8091973811388, 56.27076253294945, 57.51894995570183, 57.171249613165855, 56.733950078487396, 43.64124342799187, 60.72761557996273, 64.97500866651535, 59.01893466711044, 58.20720702409744, 54.925133138895035, 57.18273639678955, 57.31291741132736, 59.56517055630684, 58.82984921336174, 61.71971194446087, 61.79347738623619, 60.636139288544655, 60.42427405714989, 58.24528858065605, 49.128848165273666, 41.02506101131439, 42.50884719192982, 40.553453117609024, 45.66856004297733, 40.55492743849754, 43.028157725930214, 42.50882439315319, 45.031930804252625, 45.29203064739704, 46.232920959591866, 51.51657544076443, 51.69686056673527, 56.99569523334503, 56.98692910373211, 57.87379011511803, 59.64170604944229, 57.42289870977402, 51.03082090616226, 47.224743738770485, 38.474254086613655, 41.616940051317215, 42.398447915911674, 43.821775540709496, 54.872996136546135, 58.813981264829636, 60.698231756687164, 59.11882370710373, 59.087091609835625, 59.30011957883835, 56.44206114113331, 59.3854895979166, 59.73907582461834, 57.843004167079926, 56.91106617450714, 57.25565068423748, 2.573098666034639, 0.1492843113373965, 0.4367880168138072, 0.042816035711439326, 1.0403410694561899, 0.4065484378952533, 0.08820019182167016, 1.2177972472272813, 25.24428930133581, 47.743035927414894, 22.797729782760143, 39.87081974744797, 39.200091138482094, 0.9684276720508933, 0.0723077153088525, 0.05385809847211931, 0.01342532159469556, 0.011797331608249806, 0.04022477885882836, 0.015897051853244193, 0.0734366406686604, 0.0401041501754662, 0.030920018871256616, 0.04173444824118633, 0.02912764874054119, 0.037911849649390206, 0.050158035883214325, 0.0655791447206866, 0.017757538153091446, 0.061225457830005325, 0.09230442432453856, 0.05471611766552087, 0.0038534881696250523, 0.01772174993675435, 0.06645903500611894, 0.05985451069136616, 0.027480919525260106, 0.020581237513397355, 0.003532313789946784, 0.03896858630469069, 0.021593901728920173, 0.03536728130711708, 0.01395257948388462, 0.03174407553160563, 0.07390350350760855, 0.030471325662801974, 0.024780489038676023, 0.01741033363941824, 0.014450709932134487, 0.031117584148887545, 0.016710406744095962, 0.057613625467638485, 0.00881389423739165, 0.016548004423384555, 0.030053038244659547, 0.03299175565189216, 0.025172940440825187, 0.05809110101836268, 0.08205756908864714, 0.00837578405480599, 0.1132194371894002, 0.08634054043795913, 0.9813790989574045, 45.83516210317612, 52.73752972483635, 37.355989292263985, 59.553736969828606, 39.02729541063309, 50.06472274661064, 1.2918673851527274, 3.026342145167291, 2.6557867415249348, 3.611724483780563, 4.125198293477297, 3.1202412815764546, 0.10945563524728641, 3.975832345895469, 60.77008970081806, 68.81100162863731, 72.0922015607357, 69.99276861548424, 72.7378249168396, 67.99613535404205, 73.62802594900131, 71.42258629202843, 70.39683893322945, 68.5977190732956, 66.646189391613, 68.12250137329102, 63.77892404794693, 64.89445298910141, 63.19607712328434, 59.01850908994675, 53.04472804069519, 50.22737681865692, 52.333926782011986, 49.81273166835308, 52.486435398459435, 64.51496735215187, 67.82079756259918, 68.34076926112175, 66.14517107605934, 59.68503512442112, 51.14064261317253, 50.72500951588154, 48.64702261984348, 47.72055633366108, 45.93351602554321, 47.83372566103935, 45.804254561662674, 54.46096904575825, 63.33577662706375, 64.8959045112133, 62.21743583679199, 61.24799765646458, 52.76815228164196, 51.441514268517494, 61.32185809314251, 61.077041029930115, 60.1128313690424, 56.491287499666214, 58.64689663052559, 57.39103741943836, 58.70947167277336, 57.30369530618191, 47.09793694317341, 62.090336456894875, 65.37828102707863, 60.383908823132515, 60.204763635993004, 58.121096044778824, 56.461250111460686, 57.425452172756195, 59.07792270183563, 60.69442056119442, 62.13533364236355, 62.29482628405094, 63.15017178654671, 60.959767922759056, 61.03963203728199, 51.42595410346985, 44.177147671580315, 43.880619183182716, 44.40273396670818, 47.08459585905075, 44.023179933428764, 44.607983753085136, 44.45816159248352, 46.56286485493183, 46.800735890865326, 48.148189187049866, 54.117744863033295, 53.45080465078354, 59.743445590138435, 58.54764215648174, 59.02249127626419, 60.806681737303734, 60.29926836490631, 51.858458295464516, 48.75008448958397, 42.02437698841095, 43.503386825323105, 45.44245697557926, 46.821042001247406, 56.36952683329582, 59.50698807835579, 61.830396205186844, 60.399104207754135, 61.6565403342247, 63.06676626205444, 58.464567214250565, 62.028988748788834, 62.10661478340626, 60.71080528199673, 57.42341548204422, 59.99803572893143, 2.2804623562842607, 0.08780945106991567, 2.5501535972580314, 2.6907517528161407, 3.433814705349505, 0.9345715481322259, 0.22614315821556374, 2.7436005044728518, 29.840078093111515, 56.12779900431633, 28.47858265042305, 41.42356462776661, 48.321794271469116, 1.4830164844170213, 0.16604780947091058, 0.040976151431095786, 0.039512829171144404, 0.021250868085189722, 0.05785473811556585, 0.1010134605166968, 0.05072466563433409, 0.09479469343204983, 0.04668571244110353, 0.05823861029057298, 0.02823316968715517, 0.011588368797674775, 0.05519893667951692, 0.01312028405664023, 0.03938306093914434, 0.020104177565372083, 0.08927199407480657, 0.08980952421552502, 0.006088048439778504, 0.048209913074970245, 0.013468483048200142, 0.053486404940485954, 0.07789614668581635, 0.12908305157907307, 0.13488615659298375, 0.20437917293747887, 0.13223602145444602, 0.15871570212766528, 0.08919625048292801, 0.07211813368485309, 0.22488674672786146, 0.1124384455033578, 0.06732885434757918, 0.1204137722379528, 0.10433110554004088, 0.1977846267982386, 0.21133968693902716, 0.10663378197932616, 0.07421415168209933, 0.10322497153538279, 0.10104883127496578, 0.1451414797338657, 0.09657580332714133, 0.11850930997752585, 0.21739314805017784, 0.08579031957197003, 0.23039466992486268, 0.1949421121389605, 0.7613839663099498, 52.16093346476555, 67.9471255838871, 43.229581117630005, 67.1416600048542, 43.250445798039436, 52.50151298940182, 1.3898343220353127, 8.473976589739323, 6.791456323117018, 5.835488419979811, 8.989620320498943, 4.169408921152353, 0.4619177308632061, 4.849366759881377, 61.32523611187935, 73.07204738259315, 73.68354856967926, 72.38364592194557, 74.69836011528969, 71.6149851679802, 77.38238409161568, 76.86564221978188, 74.51729223132133, 71.12884685397148, 71.32594987750053, 72.42255583405495, 67.73770362138748, 65.36186590790749, 66.54753908514977, 62.85656154155731, 54.75997120141983, 53.30086849629879, 55.103085190057755, 52.603393122553825, 56.78641006350517, 66.518584638834, 70.39495423436165, 70.41657507419586, 69.33739498257637, 64.26253169775009, 52.61309780180454, 53.02669420838356, 49.61459890007973, 50.52559621632099, 47.3028789460659, 51.00466310977936, 49.92935121059418, 56.29546120762825, 67.28302001953125, 67.8168685734272, 63.71680498123169, 63.52606661617756, 55.34920558333397, 57.682888358831406, 60.2929113060236, 59.2132980376482, 60.67928597331047, 58.37680332362652, 59.41692151129246, 60.6034192442894, 59.85808543860912, 60.27716115117073, 43.46069611608982, 60.990569069981575, 72.30596289038658, 62.8454015403986, 63.18158470094204, 60.465612038969994, 61.10687702894211, 60.434400513768196, 64.37263458967209, 63.325197994709015, 65.21478340029716, 65.67716538906097, 65.62485739588737, 63.88118416070938, 63.29321891069412, 53.91176551580429, 46.88426300883293, 46.82770684361458, 47.032033279538155, 52.69619934260845, 44.501657858490944, 47.8264756500721, 46.95049725472927, 49.548680037260056, 48.701116517186165, 49.53969731926918, 58.57849270105362, 57.60215029120445, 64.12311717867851, 61.16335719823837, 61.739869862794876, 63.4631609916687, 63.238262459635735, 54.24454025924206, 53.30638960003853, 42.50039264559746, 46.73647753894329, 49.45860967040062, 47.703316658735275, 59.55135449767113, 61.996857672929764, 66.3936397433281, 63.19605812430382, 63.26016828417778, 63.11461329460144, 60.98916694521904, 64.13453936576843, 66.30955785512924, 62.47348889708519, 59.87722501158714, 59.07702594995499, 3.396114553324878, 0.2100846855319105, 1.1746813170611858, 4.909092430025339, 7.076878007501364, 3.8973532570526004, 0.4661211365601048, 3.5381780052557588, 39.83121447265148, 61.19432173669338, 34.32958088815212, 51.715544164180756, 55.2510454505682, 1.4414628641679883, 0.2785950538236648, 0.11999071095488034, 0.2119820157531649, 0.09666498721344396, 0.22398257337044924, 0.2681625651894137, 0.2136352684465237, 0.15803016547579318, 0.128207792295143, 0.1288796734297648, 0.06183159210195299, 0.16636224259855226, 0.19360635022167116, 0.18398321815766394, 0.09624784826883115, 0.1320629971451126, 0.16393636964494362, 0.1399365605902858, 0.12450366644770838, 0.1508734276285395, 0.17442388110794127], [0.05715594670618884, 0.034234719423693605, 0.036285596288507804, 0.028017076692776754, 0.01951649865077343, 0.02662643852090696, 0.08491834800224751, 0.01664641691604629, 0.05821008213388268, 0.00896459938303451, 0.011164577426825417, 0.028192405370646156, 0.026835360513359774, 0.04694290371844545, 0.04533138941042125, 0.03385951553354971, 0.060323432990117, 0.04540538153378293, 0.02987829029734712, 0.019606339337769896, 0.07905369668151252, 0.023458232353732456, 0.07265011998242699, 0.04647416695661377, 0.019221891998313367, 0.055953370610950515, 0.08331429227837361, 0.0405320057325298, 2.256332701072097, 60.429358184337616, 33.02802532911301, 48.52309226989746, 44.68802645802498, 32.981116846203804, 11.457087267190218, 1.379015352576971, 0.8937507541850209, 1.6726391343399882, 1.8069542082957923, 2.5191510608419776, 0.05482320957526099, 0.046594747400376946, 17.029829286038876, 68.9630238711834, 67.0303563773632, 74.93973836302757, 68.04212808609009, 74.47715878486633, 69.8708863556385, 65.59103161096573, 66.00134879350662, 64.78847667574883, 65.78101381659508, 65.27108877897263, 63.9885587990284, 62.63084605336189, 63.754650950431824, 59.77798193693161, 49.92458626627922, 48.87300789356232, 50.996839329600334, 49.14975464344025, 62.59908355772495, 65.1061700284481, 68.3791472017765, 67.10284128785133, 63.87310579419136, 59.98341031372547, 56.68041855096817, 53.5843750834465, 51.14477299153805, 42.98745051026344, 44.548076167702675, 44.74669151008129, 46.322075575590134, 46.13878861069679, 56.84675082564354, 61.41269601881504, 64.53936964273453, 63.60923655331135, 66.41793563961983, 61.353616788983345, 54.64234471321106, 50.95760263502598, 57.76759721338749, 57.51567453145981, 58.99881474673748, 55.54189324378967, 62.961857691407204, 47.900476679205894, 30.302752666175365, 67.76135355234146, 61.21900901198387, 60.048284232616425, 59.34033282101154, 58.545464873313904, 58.173757418990135, 58.63724894821644, 58.90728525817394, 60.99592678248882, 61.79006516933441, 62.21627689898014, 59.54063527286053, 60.89136779308319, 59.22074943780899, 49.823352098464966, 42.243366837501526, 43.9037599414587, 41.69291317462921, 42.79680714011192, 40.88141351938248, 43.70279632508755, 44.92679804563522, 46.263190135359764, 46.4673113822937, 47.737085446715355, 49.7884775698185, 52.829648181796074, 53.03712844848633, 56.972854658961296, 58.417411744594574, 59.92145463824272, 58.2603357732296, 56.12387001514435, 48.625929951667786, 42.79657915234566, 41.801176965236664, 43.22762422263622, 43.23504142463207, 53.27496908605099, 56.47833399474621, 59.81476776301861, 58.69596339762211, 58.10841612517834, 58.083975836634636, 62.17577867209911, 58.415834829211235, 60.444637164473534, 54.15113367140293, 64.48231190443039, 15.5457647703588, 0.17691700748400763, 0.3391368192387745, 2.3483813367784023, 2.4687928380444646, 1.9889605231583118, 0.3065999667160213, 0.03348237834870815, 7.277246480807662, 49.305641278624535, 34.89879034459591, 25.44196419417858, 50.04584155976772, 9.53405985608697, 0.2506208955310285, 0.07282518519787118, 0.05410191624832805, 0.038305755660985596, 0.018355879874434322, 0.05952772080490831, 0.0502029469498666, 0.0211705565743614, 0.025330698772449978, 0.052763835119549185, 0.05291085828503128, 0.05372672720113769, 0.013028260527789826, 0.056159279483836144, 0.06242270901566371, 0.03598153096390888, 0.014772002359677572, 0.03128542455669958, 0.08375312419957481, 0.030021188977116253, 0.018246693252876867, 0.01918462319736136, 0.016040293776313774, 0.02746335474512307, 0.03556596908310894, 0.0879667566914577, 0.0221461096953135, 0.058585378792486154, 0.04569826640363317, 0.0341957455384545, 0.0813660433050245, 0.031687950613559224, 0.0558801614533877, 0.024257950281025842, 0.026051223976537585, 0.04516948989476077, 0.04313087702030316, 0.01963473576324759, 0.030884766856615897, 0.05249980866210535, 0.0067269517785462085, 0.08017913394724019, 0.03978264438046608, 0.05840630969032645, 0.014486935087916208, 0.10157934812013991, 0.05369116348447278, 0.012034038682031678, 0.06841906186309643, 0.056302384109585546, 7.304384624585509, 70.47408878803253, 32.56072640419006, 56.72476977109909, 45.86097791790962, 43.93892325460911, 12.85097787156701, 1.5251238062046468, 1.6919530229642987, 1.3878419226966798, 4.267644574865699, 2.231379677541554, 0.7280648604501039, 0.09987121360609308, 22.987157218158245, 72.79428228735924, 68.58986109495163, 75.6673689186573, 70.1869609951973, 75.30375882983208, 70.93616679310799, 69.9932549893856, 68.88037070631981, 68.20128634572029, 67.00879633426666, 67.57031500339508, 65.05687907338142, 65.6309674680233, 65.23939847946167, 60.31248405575752, 53.14659297466278, 51.97305254638195, 54.8276873677969, 52.89361394941807, 63.228941559791565, 67.57840856909752, 69.53107818961143, 67.6437346637249, 67.02566742897034, 62.33187049627304, 58.537044525146484, 56.51541240513325, 52.23067492246628, 46.61124765872955, 47.12795153260231, 46.88371963799, 47.41842694580555, 50.08478946983814, 58.65592874586582, 62.681064158678055, 65.4081018269062, 63.17765191197395, 66.00822642445564, 57.81033352017403, 53.76217134296894, 56.32666513323784, 61.51030518114567, 61.5264543145895, 60.87562143802643, 58.78421366214752, 63.77133205533028, 49.84138213098049, 32.94387124478817, 67.63268485665321, 62.933302223682404, 62.68535412847996, 61.05341009795666, 60.08263438940048, 60.13206593692303, 62.29306697845459, 60.536307245492935, 65.85987478494644, 63.75366300344467, 64.28618162870407, 60.49286797642708, 63.45395788550377, 61.6783207654953, 51.514713540673256, 41.677121222019196, 44.98034477233887, 45.190382301807404, 45.045412480831146, 43.527808114886284, 45.30323624610901, 46.55839629471302, 48.99351082742214, 49.1206444054842, 48.96367482841015, 51.51516191661358, 54.221350103616714, 56.607500463724136, 60.96562720835209, 59.38952498137951, 60.601621940732, 59.387522488832474, 57.40844048559666, 50.65678037703037, 45.152574330568314, 44.87920939922333, 44.77390944957733, 46.16352528333664, 56.17110148072243, 60.48642352223396, 63.17463107407093, 60.11464387178421, 61.43663853406906, 60.2582685649395, 65.27916714549065, 63.34584228694439, 62.220722660422325, 56.62229306995869, 65.33526733517647, 17.330991625785828, 0.37764796055853367, 1.3596330676227808, 5.983030227944255, 3.962297234684229, 1.0912031214684248, 0.3173780586803332, 0.10115573022630997, 10.703273266553879, 55.42790696024895, 44.36057522892952, 25.138620771467686, 53.29887740314007, 14.135707933455706, 0.4706304258434102, 0.08269342637504451, 0.05943019888945855, 0.02613795320939971, 0.047901732541504316, 0.043071920808870345, 0.026548045461822767, 0.05653319945849944, 0.10431621805764735, 0.10311007965356112, 0.026721260874182917, 0.004224978538331925, 0.08487986764521338, 0.05444007212645374, 0.044618163228733465, 0.07214799028588459, 0.04987533699022606, 0.01778090838342905, 0.06249105339520611, 0.011423127762100194, 0.05646599798637908, 0.03639132635726128, 0.14465427462710068, 0.2670692332321778, 0.1099842373514548, 0.18272824643645436, 0.17509512399556115, 0.136517976061441, 0.17391328350640833, 0.14261981035815552, 0.2529829734703526, 0.09846324071986601, 0.13014576252317056, 0.2048824678058736, 0.10228698592982255, 0.1380328627419658, 0.394043130800128, 0.1769724756013602, 0.1718297039042227, 0.1299995297449641, 0.13995423854794353, 0.12136166551499628, 0.10831299499841407, 0.1430765280383639, 0.148180129181128, 0.3080210310872644, 0.13025837601162493, 0.07434189756168053, 0.12084234025678597, 0.1306496511097066, 9.061592258512974, 85.9965218603611, 43.85321505367756, 64.56032931804657, 55.97697749733925, 51.18622116744518, 14.900170862674713, 2.196057247929275, 4.665742088109255, 5.75474132783711, 10.555509645491838, 7.262793481349945, 0.5758323229383677, 0.12450390393496491, 23.542856499552727, 75.2707690000534, 71.80034682154655, 80.02784013748169, 74.42925095558167, 77.23623633384705, 73.05886209011078, 71.55245572328568, 70.47953009605408, 71.40416488051414, 71.3579973578453, 69.56615030765533, 66.61902084946632, 68.50340813398361, 69.53803941607475, 64.3337094783783, 55.370279252529144, 52.79658615589142, 58.88808108866215, 55.76277159154415, 67.98403680324554, 68.80526393651962, 73.22929814457893, 72.1843010187149, 68.92792135477066, 65.27860477566719, 62.830829322338104, 60.457947850227356, 57.71022789180279, 49.74005676805973, 48.64527851343155, 50.40310978889465, 50.402460023760796, 50.745201632380486, 59.26754392683506, 66.31352484226227, 68.31149563193321, 66.66931495070457, 70.54513737559319, 64.29142534732819, 62.46643267571926, 58.686836287379265, 63.98003205657005, 64.70782220363617, 63.702711537480354, 60.42286433279514, 66.87226206064224, 50.663471817970276, 28.15619844943285, 70.25824517011642, 65.8347125351429, 64.9160586297512, 64.81044709682465, 63.125172927975655, 64.05129343271255, 64.46927860379219, 63.11430171132088, 67.12777554988861, 66.41570895910263, 65.96244648098946, 62.94640772044659, 65.7805198431015, 63.73597115278244, 55.26993803679943, 45.426140651106834, 47.22282104194164, 48.588000386953354, 47.933610901236534, 44.70539912581444, 47.55226716399193, 48.76048073172569, 51.649040132761, 52.35968939960003, 52.80636303126812, 55.00620178878307, 56.69045761227608, 57.15495988726616, 62.162950560450554, 63.35417903959751, 62.1457526832819, 60.22854655981064, 61.55065521597862, 54.404910653829575, 47.795492112636566, 44.82721298933029, 49.60372008383274, 48.815870359539986, 57.964780032634735, 61.48698963224888, 64.89237070083618, 61.611584946513176, 59.78029601275921, 62.32224181294441, 67.6665410399437, 63.73138479888439, 64.23564434051514, 59.13291335105896, 68.98097410798073, 18.15400466322899, 0.38221110007725656, 0.6054228788707405, 6.527146305888891, 10.41842820122838, 6.23683855868876, 1.7238743975758553, 0.2187374743516557, 15.249981991946697, 65.06371110677719, 49.25017945468426, 36.16447202861309, 65.06187200546265, 17.626805752515793, 0.570315137738362, 0.18183706066338345, 0.1617611199617386, 0.09405473509104922, 0.15801572328200564, 0.27690500544849783, 0.13753911189269274, 0.12174915565992706, 0.2051923144608736, 0.12129863491281867, 0.10792713015689515, 0.15043279970996082, 0.24571132147684693, 0.13397447270108387, 0.10787082341266796, 0.2968813944607973, 0.15297032136004418, 0.14797311450820416, 0.15349922032328323, 0.08923755842261016, 0.12215594164445065, 0.1709259016206488], [0.08330928278155625, 0.05587754538282752, 0.06711723835906014, 0.06396719254553318, 0.0640407764876727, 0.018148117487726267, 0.041971738828578964, 0.16508463537320495, 0.03824462495686021, 0.019473693428153638, 0.1085958571638912, 0.05912437838560436, 0.07509560047765262, 0.053137773647904396, 0.01179569053419982, 0.04070055489137303, 0.08067177157499827, 0.020860118056589272, 0.021794179556309246, 0.056261402714881115, 0.06537771841976792, 0.05519452832231764, 0.08006752977962606, 0.03300600859802216, 0.0989941880106926, 0.04087385750608519, 0.051974152884213254, 0.09952601103577763, 0.04209125057968777, 27.251246608793736, 57.517437636852264, 26.05092141777277, 62.14110553264618, 39.153855219483376, 11.204932797700167, 0.1697608781978488, 1.6735937143675983, 2.052645105868578, 3.093207632191479, 1.7376953247003257, 0.7725212280638516, 0.08042264002142474, 0.05884517129743472, 33.10043424367905, 75.74276447296143, 65.36233708262444, 75.1851823925972, 65.68379983305931, 70.51318109035492, 61.54397517442703, 68.01087856292725, 64.0200363099575, 67.1259668469429, 67.38407179713249, 67.49777689576149, 67.6888382434845, 65.55234968662262, 58.98544326424599, 51.10311962664127, 51.351474300026894, 49.879501685500145, 55.79052150249481, 65.24795562028885, 65.65888836979866, 69.78194832801819, 67.00575649738312, 68.87321189045906, 60.143871903419495, 59.19609636068344, 55.83942487835884, 54.23289768397808, 46.22981272637844, 47.35491335391998, 44.8514898866415, 45.30844196677208, 43.39746370911598, 47.995068803429604, 54.67418700456619, 61.41303800046444, 60.74147343635559, 62.84426540136337, 62.78449460864067, 67.33396008610725, 56.14424452185631, 60.63496135175228, 54.7086663544178, 64.18135285377502, 50.021173283457756, 72.41812527179718, 53.38231332600117, 40.26069022715092, 77.603220641613, 59.02561850845814, 65.96044778823853, 55.40996812283993, 62.467534616589546, 59.849152117967606, 62.36539229750633, 58.87437902390957, 60.87624080479145, 59.50452201068401, 60.01065105199814, 61.6041449457407, 59.04739134013653, 59.65221628546715, 47.48034842312336, 40.57406321167946, 42.63556659221649, 41.89957268536091, 42.515071257948875, 41.77459739148617, 43.654250130057335, 44.15110766887665, 46.5062440931797, 48.69055688381195, 48.12775008380413, 47.83666290342808, 51.62909120321274, 56.864172890782356, 58.800165206193924, 58.952624425292015, 57.44634345173836, 59.60808925330639, 60.8224318921566, 54.57770638167858, 45.40375605225563, 44.8086129873991, 43.89427565038204, 44.91089969873428, 53.980397433042526, 57.08080306649208, 60.15118271112442, 59.27038237452507, 58.03595021367073, 57.651802226901054, 58.94710712134838, 61.71409584581852, 56.88091479241848, 54.83676888048649, 46.02536089718342, 0.6935066054575145, 0.1990966548328288, 2.2370176250115037, 10.817168354988098, 2.5934722227975726, 1.2355079781264067, 0.18746522662695497, 0.30174718180205673, 25.23253843188286, 47.90646135807037, 23.02742935717106, 42.611859664320946, 40.24750113487244, 0.47481916670221835, 0.06666211629635654, 0.06584799513802864, 0.03071442541113356, 0.03852105641271919, 0.06094040261814371, 0.06313784993835725, 0.06536761778988875, 0.03617506823502481, 0.05229871632764116, 0.027167894622834865, 0.024294389731949195, 0.04228684359986801, 0.01803915722121019, 0.05360472554457374, 0.08105322805931792, 0.029729430316365324, 0.03220374324882869, 0.02809024132147897, 0.02416650841041701, 0.053067666667629965, 0.0376021811098326, 0.014489614241028903, 0.03456484526395798, 0.08780956981354393, 0.06633592012804002, 0.052953494669054635, 0.04371619776065927, 0.012639962369576097, 0.026401013019494712, 0.05570732639171183, 0.004068582975378376, 0.07812809752067551, 0.059704771265387535, 0.05771654650743585, 0.07550452384748496, 0.03597560862544924, 0.06152661022497341, 0.06221941250259988, 0.030138871334202122, 0.04005345035693608, 0.037603554083034396, 0.023064099987095688, 0.08274265303043649, 0.0872593563690316, 0.07658708724193275, 0.025486264057690278, 0.12641848908970132, 0.09713243634905666, 0.05885093407414388, 0.13323530845809728, 0.2798756444826722, 40.35548374056816, 57.42607533931732, 32.791966795921326, 69.40157353878021, 44.27537240087986, 16.667448431253433, 0.5203235358931124, 1.2419409141875803, 0.9894221392460167, 3.4477763436734676, 4.452971080318093, 3.807672606781125, 0.18733229313511401, 0.15707283950177953, 41.8818124383688, 76.4156323671341, 67.1874475479126, 77.18575984239578, 65.14130294322968, 70.67939177155495, 62.052631080150604, 71.47601142525673, 66.81415557861328, 72.5695775449276, 69.43763360381126, 71.8558618426323, 68.9027439057827, 68.7218128144741, 62.00381889939308, 55.13515926897526, 52.165440022945404, 53.53847734630108, 56.940765380859375, 67.09623724222183, 66.78657665848732, 71.72102987766266, 71.60543248057365, 70.13744965195656, 62.770245373249054, 62.736408188939095, 56.569631695747375, 56.47949293255806, 48.94003629684448, 49.73781108856201, 46.65246784687042, 47.691069915890694, 45.739582031965256, 51.533184349536896, 58.50673355162144, 67.01600074768066, 63.88224810361862, 66.38328149914742, 64.78016272187233, 68.3938068151474, 56.97582609951496, 62.500315457582474, 57.57300965487957, 65.61177089810371, 54.64392922818661, 72.83332139253616, 52.93298743665218, 40.86928837001324, 76.99052631855011, 59.24060717225075, 64.95271146297455, 59.524888917803764, 63.571588173508644, 59.76541221141815, 64.5860767364502, 61.121529042720795, 63.750638365745544, 61.567077934741974, 59.479226768016815, 62.428001537919044, 62.47851602733135, 60.39184279739857, 51.10989846289158, 42.72294670343399, 45.560482442379, 44.26197811961174, 45.39040356874466, 43.86624835431576, 44.30086523294449, 46.642170399427414, 48.11150975525379, 49.37491536140442, 50.99634535610676, 51.775603741407394, 54.26538214087486, 59.907798171043396, 61.077367812395096, 58.155765384435654, 59.66713808476925, 61.042877063155174, 63.3816097676754, 55.19928462803364, 47.436156794428825, 46.18345521390438, 46.94937251508236, 46.647497713565826, 56.736803725361824, 60.01421146094799, 62.182853892445564, 62.941502183675766, 60.648367032408714, 58.41380953788757, 61.06420151889324, 62.741271927952766, 58.376389145851135, 56.021849289536476, 48.071501702070236, 1.1017847224138677, 0.5138563422951847, 5.1204256899654865, 8.652611654251814, 1.4428624953143299, 1.16081289248541, 0.45006414817180485, 1.0102228168398142, 28.65487229079008, 58.830316588282585, 28.643395006656647, 40.27444928884506, 49.54467885196209, 1.0534490598365664, 0.05884422505914699, 0.025858992885332555, 0.05034024427004624, 0.020743676941492595, 0.02563741541962372, 0.046057005747570656, 0.019414785456319805, 0.01854414789704606, 0.017516727930342313, 0.013695985635422403, 0.11588776978896931, 0.02795174172206316, 0.0269713330999366, 0.07271244554431178, 0.049031162561732344, 0.045447632001014426, 0.0638274684024509, 0.03852104156976566, 0.041463764719082974, 0.04757156588311773, 0.06154416943900287, 0.0030675607376906555, 0.22947335295611992, 0.1550890045473352, 0.12540897529106587, 0.1567696573329158, 0.1376696111401543, 0.12923366302857175, 0.10246328311040998, 0.2779830788495019, 0.11117882051621564, 0.1784572162432596, 0.22342999989632517, 0.15921049198368564, 0.16378899395931512, 0.14219270437024534, 0.20824490144150332, 0.12374769998132251, 0.13888302259147167, 0.12994659977266565, 0.21869122370844707, 0.11925059676286764, 0.0999004022742156, 0.1815733459079638, 0.08870262579875998, 0.10761602185084485, 0.2016923311748542, 0.1620929193450138, 0.16149115632288158, 0.2341274797799997, 0.20514226402156055, 47.59506046772003, 75.06116464734077, 35.34582495689392, 78.91730412840843, 52.994566932320595, 20.624195113778114, 0.4566290677757934, 4.529495174065232, 6.181566249579191, 7.344112917780876, 6.564645068719983, 6.723563466221094, 0.1500819271313958, 0.8220117911696434, 41.852166429162025, 81.80476918816566, 69.58188146352768, 76.97018221020699, 65.13067111372948, 74.9469655752182, 66.17495387792587, 76.28396943211555, 69.62077617645264, 72.64642462134361, 73.92656072974205, 74.59653317928314, 72.59301468729973, 71.64748102426529, 66.97785079479218, 59.552543833851814, 55.136006623506546, 55.797383934259415, 60.7865846157074, 70.48618733882904, 71.81828185915947, 73.41840639710426, 72.42187187075615, 72.9480068385601, 65.09968757629395, 65.9427635371685, 59.52927008271217, 59.099330753088, 52.4924086779356, 52.84061439335346, 49.94524955749512, 50.284027978777885, 47.936380952596664, 51.57582946121693, 59.21406179666519, 66.99232801795006, 65.2640363574028, 67.53848031163216, 64.06245723366737, 71.41043454408646, 57.77947537600994, 68.1421311199665, 61.3294842839241, 69.86937403678894, 57.40192003548145, 76.94289967417717, 53.1806505471468, 33.42309013009071, 79.34295728802681, 63.784175366163254, 70.60778081417084, 61.020367071032524, 65.65217033028603, 62.797797694802284, 68.20279866456985, 63.41775722801685, 65.42535290122032, 61.93846620619297, 61.452111303806305, 64.60888311266899, 63.043435513973236, 63.63498017191887, 53.07734549045563, 45.421029925346375, 47.770911231637, 46.896836534142494, 48.16179245710373, 47.12491549551487, 48.78687411546707, 48.973645493388176, 49.8355608433485, 49.94577392935753, 52.15090960264206, 53.91917131841183, 55.47822766005993, 63.18786956369877, 63.18440794944763, 60.670037269592285, 60.229572504758835, 63.76001626253128, 67.23571255803108, 58.8638573884964, 50.38997009396553, 49.96336318552494, 52.89341256022453, 49.440537840127945, 59.461261332035065, 63.12472075223923, 64.5486107468605, 65.49764782190323, 62.01548807322979, 59.139426201581955, 61.62725530564785, 65.94079524278641, 61.64104476571083, 58.72356131672859, 50.082475394010544, 1.2880635517649353, 0.4446340020513162, 4.120942521840334, 23.08068159967661, 8.140659425407648, 2.858270276337862, 0.7921312039252371, 0.9506181464530528, 36.50681845843792, 59.62182551622391, 34.36140038073063, 50.973979756236076, 58.97985756397247, 1.4715857477858663, 0.27677548583596945, 0.13158254558220506, 0.1888359585427679, 0.12225530779687688, 0.20324965385952964, 0.24202568252803758, 0.14369555341545492, 0.09487381379585713, 0.20143203029874712, 0.1652329758508131, 0.3029308479744941, 0.16658601496601477, 0.12230639724293724, 0.14860340568702668, 0.1357213399023749, 0.07973920364747755, 0.19256115396274254, 0.1689961989177391, 0.1388550881529227, 0.11998612448223867, 0.30594928131904453, 0.09032928734086454], [0.07710115809459239, 0.04035289952298626, 0.07004322978900746, 0.029869460595364217, 0.016713427285139915, 0.06190583655552473, 0.026383320218883455, 0.015983790362952277, 0.03748163035197649, 0.0655727028788533, 0.02370079033426009, 0.04799245267349761, 0.010617075604386628, 0.026760381333588157, 0.11777874722611159, 0.03447935727308504, 0.070444360608235, 0.030006019478605594, 0.11165559102664702, 0.10649463671143167, 0.04639092396246269, 0.01858390103734564, 0.07064193516271189, 0.055438075214624405, 0.03395288142201025, 0.1243320967478212, 0.025461608056502882, 0.041293798058177345, 0.10920075204921886, 3.1632423866540194, 58.82371634244919, 36.177140548825264, 44.91410292685032, 68.17172393202782, 20.30233908444643, 0.4405470541678369, 0.8257915789727122, 0.20710304786916822, 2.175897667184472, 1.9143725442700088, 1.2787375459447503, 0.7865303638391197, 0.2776657365029678, 2.3508768528699875, 46.117600947618484, 77.60852515697479, 62.53698728978634, 72.65976950526237, 67.43191882967949, 66.00735247135162, 68.03971901535988, 71.55889257788658, 68.49966153502464, 68.53968098759651, 70.07004886865616, 68.67173910140991, 66.6753414273262, 62.09968015551567, 54.549565091729164, 50.33473625779152, 56.23345233500004, 61.85395874083042, 66.26852005720139, 70.91855853796005, 67.84511625766754, 67.14811965823174, 64.95417818427086, 61.29555210471153, 62.6092404127121, 62.25391007959843, 59.1062767803669, 53.2393915951252, 47.330013290047646, 45.95309257507324, 47.245315834879875, 45.84785722196102, 45.73068670928478, 45.00158943235874, 51.453897804021835, 55.40418483316898, 62.692710533738136, 60.979781448841095, 61.84577398002148, 60.238661617040634, 58.24737846851349, 56.87859691679478, 61.108427345752716, 61.10434256494045, 61.068818271160126, 65.03626137971878, 55.31703270971775, 59.954102486371994, 62.168483063578606, 63.67686152458191, 64.22692000865936, 64.02635917067528, 61.101146936416626, 61.45847216248512, 58.80254007875919, 58.28547142446041, 59.59346763789654, 62.918289229273796, 60.40389575064182, 59.67542923986912, 54.5254971832037, 42.47240334749222, 42.59558513760567, 41.29403717815876, 43.457055911421776, 42.314274832606316, 43.204662054777145, 41.82443931698799, 45.74614427983761, 48.08434881269932, 49.36768434941769, 49.3235307186842, 48.76979783177376, 50.193079859018326, 54.81843866407871, 58.824434503912926, 60.617961063981056, 57.365829572081566, 60.442684069275856, 58.39297905564308, 56.737233102321625, 51.500768288969994, 46.586362794041634, 42.54151023924351, 49.901403710246086, 59.82096903026104, 58.346674740314484, 58.61710622906685, 62.79296055436134, 57.3036877065897, 60.10538376867771, 58.2955826818943, 63.78168269991875, 48.96777480840683, 65.75063824653625, 15.460198111832142, 0.1646610620082356, 0.7253685488831252, 8.051588404923677, 6.495978478342295, 0.9340813744347543, 0.876056884881109, 0.1675635125138797, 5.144862653687596, 46.538462564349174, 42.03363709151745, 24.190917424857616, 55.682462900877, 11.102180611342192, 0.12151458504376933, 0.06151125518954359, 0.03267044281528797, 0.07196591919637285, 0.023999452823773026, 0.04121277408557944, 0.06316227401839569, 0.08401592611335218, 0.03319209841720294, 0.046655614642077126, 0.03141392742691096, 0.0208156930966652, 0.03627289814176038, 0.015525160724791931, 0.04343269734818023, 0.02364372103329515, 0.0059381837763794465, 0.05575515409873333, 0.025280893241870217, 0.027853524043166544, 0.026197723927907646, 0.010177069234487135, 0.05117664470162708, 0.06560719048138708, 0.023460447664547246, 0.038114841881906614, 0.005106999251438538, 0.02698615749977762, 0.03396129366592504, 0.03265444211137947, 0.019054953299928457, 0.04007357740192674, 0.026119412505067885, 0.035528542575775646, 0.04414570088556502, 0.0059244392014079494, 0.04956691525876522, 0.05801918690849561, 0.04062361273099668, 0.061265956828719936, 0.03967400138208177, 0.058380297414259985, 0.037414569887914695, 0.030252097094489727, 0.11671802523778751, 0.0593808126723161, 0.04668263623898383, 0.04884212641627528, 0.07952993284561671, 0.024502237465640064, 0.07739916749414988, 0.11149795143865049, 6.317539103329182, 70.1821580529213, 37.13410019874573, 56.35683171451092, 63.302414417266846, 26.259843707084656, 0.7328368106391281, 0.4974300612229854, 0.9679372608661652, 0.9946146793663502, 4.184280373156071, 3.3787221740931273, 3.321691509336233, 0.6312234944198281, 3.2715755235403776, 57.96152360737324, 75.1288466155529, 64.83912035822868, 72.19157382845879, 70.75386017560959, 70.78347578644753, 70.82045540213585, 72.74809196591377, 68.99182632565498, 69.31099399924278, 70.57230591773987, 70.14690354466438, 69.10462707281113, 65.1149171590805, 57.66349419951439, 52.309410497546196, 55.56928217411041, 65.41413590312004, 67.93824926018715, 72.11448356509209, 66.58809810876846, 67.76616409420967, 67.4495954811573, 64.26413521170616, 65.30407100915909, 62.920227125287056, 62.06632934510708, 55.07201425731182, 50.09070575237274, 48.73203165829182, 48.58631327748299, 49.19795125722885, 48.76856669783592, 47.58146099746227, 54.47345897555351, 58.215646371245384, 64.55447763204575, 63.10194097459316, 64.93384167551994, 61.574392542243004, 61.89584009349346, 61.92921370267868, 63.09321664273739, 62.75497779250145, 63.60004864633083, 67.51327246427536, 54.66696739196777, 63.91511633992195, 62.80002057552338, 65.56212276220322, 63.59294682741165, 67.18285739421844, 64.79465514421463, 65.23111492395401, 61.89673684537411, 61.1899633705616, 59.48479346930981, 63.32560457289219, 63.156122267246246, 60.66963069140911, 58.2773132622242, 45.63162982463837, 45.435222163796425, 43.49726915359497, 44.17622812092304, 43.208933025598526, 44.55745026469231, 43.35420303046703, 45.75439743697643, 50.44689483940601, 52.60758429765701, 51.8181424587965, 51.692631393671036, 54.00651343166828, 56.624641343951225, 62.180805802345276, 61.86322644352913, 59.067325070500374, 60.889973267912865, 62.219651117920876, 59.653903394937515, 53.10065723955631, 47.85663463175297, 46.164148449897766, 51.07507333159447, 63.64004909992218, 60.38239650428295, 61.59254416823387, 64.68536540865898, 58.230731561779976, 60.29139518737793, 60.05343295633793, 63.92149239778519, 51.41974903643131, 66.63041263818741, 19.38921958208084, 0.31204174971207976, 1.7940585315227509, 4.74800624884665, 4.728196961805224, 0.35163461579941213, 0.7014596974477172, 0.19511504739057273, 7.238287171348929, 54.80129398405552, 51.96704886853695, 26.061500050127506, 60.236355140805244, 15.73693061247468, 0.19549953925888985, 0.09136107299127616, 0.01861942764662672, 0.0833086964848917, 0.051708890750887804, 0.036946311811334454, 0.004916123043585685, 0.08816211222438142, 0.05175130449060816, 0.013477802567649633, 0.04568496711726766, 0.044394546712283045, 0.028878802913823165, 0.03500459744827822, 0.06439538206905127, 0.033597058718441986, 0.04739769923617132, 0.012564789303723956, 0.06391785456798971, 0.008210500345740002, 0.05281429745082278, 0.007793688873789506, 0.010359721982240444, 0.15326145105063915, 0.21012246084865183, 0.22205362765816972, 0.0851195739232935, 0.11581676852074452, 0.12831445375923067, 0.1868075501988642, 0.12881277623819187, 0.17797201493522152, 0.10378299979493022, 0.14867779857013375, 0.17353646544506773, 0.06842330694780685, 0.1105543551966548, 0.16544442856684327, 0.08720561003428884, 0.13933599984738976, 0.1087654972798191, 0.1756300640408881, 0.19554688828065991, 0.122918661654694, 0.14720380422659218, 0.25067792215850204, 0.19044226297410205, 0.2027394124888815, 0.13666478771483526, 0.07926077814772725, 0.11603204329730943, 0.18867526872782037, 6.895528938621283, 86.5525384247303, 46.37069396674633, 61.08185917139053, 80.54299369454384, 34.41571086645126, 1.237263127695769, 2.510747811757028, 2.6082916650921106, 7.115964135155082, 9.616395737975836, 5.461830720305443, 3.764425227418542, 0.37136075261514634, 4.469272680580616, 55.76952762901783, 83.4130708873272, 70.179672986269, 75.86381077766418, 72.27091357111931, 74.6343943476677, 72.3347045481205, 76.80624380707741, 74.55896079540253, 73.20893883705139, 73.98861899971962, 73.58161523938179, 71.12712174654007, 67.69956886768341, 59.8965659737587, 55.58939069509506, 60.80419287085533, 66.8203416466713, 71.93970054388046, 75.71728304028511, 69.39268201589584, 70.82964330911636, 67.96490862965584, 67.80836462974548, 67.75861009955406, 66.94853156805038, 65.29558226466179, 57.86664269864559, 53.027822747826576, 51.06646679341793, 52.4448998272419, 51.76439054310322, 49.8709749430418, 49.571927189826965, 55.642774030566216, 59.89009112119675, 67.49965399503708, 64.59556102752686, 68.75517502427101, 64.60662603378296, 65.02410963177681, 60.12237265706062, 65.72540760040283, 66.40608787536621, 66.8031969666481, 67.8551173210144, 57.7056947350502, 62.4075548350811, 63.056031838059425, 67.44155511260033, 68.95850971341133, 69.14640203118324, 66.71805113554001, 66.38268113136292, 64.11656633019447, 62.919307574629784, 62.17442974448204, 67.32221871614456, 64.23743024468422, 64.20012384653091, 60.25417998433113, 45.20859852433205, 47.700375616550446, 46.42931342124939, 47.26110018789768, 45.472866743803024, 48.41508686542511, 46.023035421967506, 50.52396610379219, 53.195253163576126, 57.285752668976784, 54.54055197536945, 53.76991532742977, 54.89599630236626, 60.453479290008545, 65.95423892140388, 66.58183604478836, 59.76166561245918, 62.371559366583824, 63.683503568172455, 62.099186182022095, 57.096963599324226, 51.24854542315006, 48.91488924622536, 53.913828805089, 67.36948817968369, 63.028316125273705, 64.08792346715927, 68.0488233268261, 59.899864196777344, 62.28073664009571, 61.06286779046059, 64.76826176047325, 53.86336371302605, 72.01577246189117, 19.687475077807903, 0.25375195720698684, 1.2996255001053214, 16.483145020902157, 20.76092317700386, 3.216651133261621, 3.7540223356336355, 0.27350742369890213, 9.387426674365997, 62.49411419034004, 53.73811103403568, 36.682931408286095, 72.59400263428688, 20.498146377503872, 0.35366991127375513, 0.2226607341435738, 0.09138215740676969, 0.20518787641776726, 0.12907135533168912, 0.1378383458359167, 0.10367652386776172, 0.2451661546365358, 0.10207493207417428, 0.1613728579832241, 0.14696976053528488, 0.1581747061572969, 0.08217519207391888, 0.17637592245591804, 0.14609188889153302, 0.08674022406921722, 0.13560004328610376, 0.07870895424275659, 0.1294082755339332, 0.14620940055465326, 0.12815458030672744, 0.09683841228252277, 0.21267586445901543], [0.01082384907931555, 0.07569151537609287, 0.07165788338170387, 0.049063063779613, 0.028357299452181906, 0.06865289775305428, 0.07319245181861334, 0.021754762237833347, 0.04074279422638938, 0.02883182867662981, 0.04533222432655748, 0.03765873647353146, 0.02509587211534381, 0.05378145317081362, 0.01808475106372498, 0.07512638476327993, 0.02633970791066531, 0.08566629185224883, 0.051684574282262474, 0.10066834700410254, 0.1179992689867504, 0.07486901537049562, 0.0237860185734462, 0.0797660842363257, 0.12118461134377867, 0.033017612076946534, 0.037011001113569364, 0.05055769725004211, 0.09619128177291714, 0.2713109040632844, 21.135425381362438, 55.648355931043625, 35.69672092795372, 65.85483625531197, 54.6612448990345, 7.412671213969588, 0.08142311446135864, 0.24943384516518563, 0.636423456016928, 4.145053178071976, 2.463076994754374, 3.689010674133897, 1.7570017324760556, 0.1264667880604975, 1.0428068996407092, 53.74091528356075, 73.54019746184349, 63.64207439124584, 69.61639881134033, 69.31305348873138, 73.22934374213219, 68.4238176047802, 71.10695242881775, 71.03003695607185, 69.59671586751938, 69.20128628611565, 68.00923705101013, 65.0506018102169, 55.28976157307625, 52.248328775167465, 59.968287125229836, 67.71407648921013, 69.77143049240112, 65.79460188746452, 68.54547187685966, 69.09401804208755, 64.92355182766914, 63.3242404460907, 58.58815938234329, 61.80055260658264, 60.135485753417015, 55.973390489816666, 49.55044314265251, 45.81221893429756, 48.27164836227894, 47.76329264044762, 45.954905077815056, 46.30108170211315, 45.09309992194176, 46.83586500585079, 48.47696654498577, 48.806446865200996, 49.35796067118645, 50.08584201335907, 49.8547688126564, 51.61867596209049, 56.19084142148495, 59.18338604271412, 64.058877825737, 53.40645723044872, 53.46791513264179, 58.6427928507328, 57.67133317887783, 61.639942824840546, 59.95744250714779, 60.010107681155205, 57.0183914154768, 58.341898396611214, 58.58100816607475, 61.43626995384693, 63.3166940510273, 60.502743646502495, 63.53662244975567, 57.74260975420475, 45.304569974541664, 43.567451387643814, 43.82797680795193, 44.04139995574951, 43.43191646039486, 43.44665206968784, 43.02315339446068, 43.03437419235706, 43.021264895796776, 48.34910720586777, 51.10163010656834, 53.91165152192116, 51.37859724462032, 51.97392649948597, 55.566455125808716, 56.54016427695751, 59.337513372302055, 59.96143989264965, 61.50714375078678, 60.113617926836014, 60.81427372992039, 56.699364334344864, 48.68926875293255, 46.27545207738876, 47.53224603831768, 57.44733139872551, 60.16064800322056, 61.03498488664627, 58.41741554439068, 61.347073540091515, 56.4979637414217, 64.3078100681305, 54.299162328243256, 61.894821748137474, 48.55904594063759, 1.9580795802175999, 0.07418278852128424, 0.8512530627194792, 3.6077817203477025, 1.631331907119602, 0.20963423157809302, 0.8228950062766671, 0.02590609699836932, 21.791425980627537, 53.24364736676216, 19.603446386754513, 38.599974140524864, 40.79178772866726, 0.6494883424602449, 0.15618196543073282, 0.06525226577650756, 0.014335395953821717, 0.03652365870948415, 0.032614470037515275, 0.009715248361317208, 0.02695100753044244, 0.05471192082040943, 0.08138394390698522, 0.021996579926053528, 0.03640890783572104, 0.0241349727002671, 0.045192088291514665, 0.05464180270791985, 0.021979846351314336, 0.10597655826131813, 0.03534362534992397, 0.02897766069509089, 0.020386262331157923, 0.02729259584157262, 0.06158689117000904, 0.04052989803312812, 0.028645558886637446, 0.06734872906235978, 0.03158553794492036, 0.004914588653264218, 0.039993744576349854, 0.038732501707272604, 0.04522472052485682, 0.019420358985371422, 0.03912460801075213, 0.061688287096330896, 0.062058540861471556, 0.04566491799778305, 0.05847969325259328, 0.04014066384115722, 0.08097985191852786, 0.034017426005448215, 0.06971030234126374, 0.007757437742839102, 0.028901720434078015, 0.046714392738067545, 0.03912925014446955, 0.033941170331672765, 0.026278801706212107, 0.04084204163518734, 0.10426331777125597, 0.04498938549659215, 0.09373293243697844, 0.0749042080133222, 0.03941040165955201, 0.1847802402335219, 0.3999335569096729, 32.63097703456879, 58.697392120957375, 44.23890195786953, 76.80476948618889, 54.38077814877033, 10.86948774755001, 0.17636620032135397, 0.4185394663363695, 0.17771552869817242, 1.1633436754345894, 3.2262427685782313, 9.470849297940731, 5.41658797301352, 0.13930227665696293, 2.281732438132167, 63.68205204606056, 72.87535473704338, 65.74322864413261, 72.77754038572311, 70.0405852496624, 73.19137617945671, 72.24805399775505, 73.06370303034782, 71.05833023786545, 72.13253259658813, 71.86707124114037, 69.54921841621399, 68.50397050380707, 56.06615491211414, 54.11850482225418, 61.45753361284733, 67.10500717163086, 72.143225222826, 68.11340466141701, 70.4786105453968, 72.52098575234413, 66.43610626459122, 64.55885499715805, 61.88478268682957, 63.95856320858002, 62.457054778933525, 58.26251305639744, 51.73923209309578, 49.30144630372524, 50.36245197057724, 48.56626935303211, 49.466889426112175, 49.39363315701485, 47.36824683845043, 50.92768684029579, 52.26097449660301, 52.41941839456558, 53.05024914443493, 52.74807795882225, 51.38113170862198, 54.95062217116356, 59.58720937371254, 63.30131247639656, 64.4584871828556, 57.75895647704601, 55.72681412100792, 59.85184617340565, 61.0543904453516, 62.97362565994263, 62.48671218752861, 62.386515364050865, 56.8672963231802, 58.94033208489418, 58.626852706074715, 61.05632074177265, 65.88036328554153, 62.84507855772972, 63.01453046500683, 59.79931019246578, 48.57149787247181, 46.020402163267136, 45.725921764969826, 45.36149471998215, 44.56303596496582, 45.45564986765385, 45.26355877518654, 45.79720214009285, 45.13454809784889, 50.43266460299492, 52.53769464790821, 54.05292794108391, 51.51451215147972, 55.35032272338867, 57.730461806058884, 58.87394204735756, 61.00084751844406, 60.77122963964939, 59.58874449133873, 60.96940040588379, 62.39215046167374, 60.45096382498741, 50.797338634729385, 46.60182036459446, 50.84741994738579, 60.41600190103054, 61.603479981422424, 62.62700065970421, 61.026541739702225, 62.988133281469345, 59.80445131659508, 63.43268662691116, 54.216178581118584, 62.932230681180954, 52.979903519153595, 1.7989455442875624, 0.43415481748525053, 1.5815943572670221, 3.532256498001516, 1.2758804555051029, 0.2827933238586411, 0.3546225617174059, 0.17096851574024186, 25.34995973110199, 65.21887198090553, 28.110557198524475, 36.1132849752903, 50.98303087055683, 1.4893334079533815, 0.10813167347805575, 0.015586665285809431, 0.04713474518212024, 0.017489268466306385, 0.044708452915074304, 0.011047860789403785, 0.023250737140187994, 0.060794759847340174, 0.05108747565827798, 0.012480292079999344, 0.030887349530530628, 0.04249831115885172, 0.012480914556363132, 0.054213509283727035, 0.017570951094967313, 0.030296644508780446, 0.036523064991342835, 0.03725778005900793, 0.005272311718726996, 0.02440647815092234, 0.05597753493930213, 0.027373985321901273, 0.0674643630918581, 0.08805060453596525, 0.16116143495310098, 0.10819615868967958, 0.13563262356910855, 0.16939526656642556, 0.11783034133259207, 0.12174900723039173, 0.16098398744361475, 0.12460686208214611, 0.17695604445179924, 0.15571539202937856, 0.11947013146709651, 0.1728135987650603, 0.13483828806784004, 0.09508655042736791, 0.1502441309276037, 0.12275196044356562, 0.13167577417334542, 0.14425354456761852, 0.17925820138771087, 0.16902272327570245, 0.16888517362531275, 0.1281277442467399, 0.16349728539353237, 0.20729775773361325, 0.09694840598967858, 0.15399831463582814, 0.11727543009328656, 0.2930098178330809, 0.38406914100050926, 36.95395186543465, 74.88971784710884, 47.16905012726784, 77.45944395661354, 71.72065749764442, 15.152283534407616, 0.2273967198561877, 1.7137757269665599, 2.40942292381078, 8.893668819218874, 10.074919983744621, 9.886407349258661, 2.677769511938095, 0.2644727850565687, 2.1001088339835405, 61.09545484185219, 79.81635108590126, 69.73176822066307, 74.28711578249931, 73.23198080062866, 77.80066564679146, 74.37552943825722, 75.95061331987381, 74.80317369103432, 75.24523437023163, 73.29175159335136, 73.80435928702354, 72.03794807195663, 59.20141227543354, 56.79135739803314, 65.00582501292229, 71.52078822255135, 75.70451572537422, 69.87755879759789, 71.41178727149963, 72.96690702438354, 69.80093970894814, 68.21124941110611, 63.64678613841534, 66.86541482806206, 64.37055990099907, 62.885496988892555, 54.14387606084347, 50.53347699344158, 52.973884642124176, 53.155978471040726, 52.79190480709076, 52.948414608836174, 49.999066069722176, 52.70604841411114, 53.43084052205086, 53.38368885219097, 51.14462099969387, 54.76927310228348, 54.61042262613773, 58.649902269244194, 61.40815146267414, 65.32718896865845, 67.18532726168633, 58.550594598054886, 53.09226728975773, 62.560052052140236, 61.75868645310402, 66.91823959350586, 67.30562880635262, 64.29011061787605, 61.2733992934227, 62.80912108719349, 59.850299656391144, 64.58998292684555, 68.1329508125782, 63.14631499350071, 66.8664787709713, 60.9147023409605, 50.49239739775658, 49.193125516176224, 48.74288007616997, 48.139879032969475, 46.54333770275116, 48.02019685506821, 48.82486827671528, 49.15882855653763, 45.89465171098709, 52.475176602602005, 54.68647174537182, 58.449877202510834, 56.23485825955868, 58.154617846012115, 61.29759259521961, 60.46849988400936, 62.15409703552723, 62.39596925675869, 63.23286674916744, 64.15932923555374, 66.79688170552254, 63.742594197392464, 54.314494505524635, 49.42705616354942, 52.122357934713364, 62.73588001728058, 63.308657482266426, 63.99513244628906, 62.3491557687521, 65.84190934896469, 60.93531243503094, 65.47478064894676, 58.24434623122215, 65.03090366721153, 53.81449073553085, 2.8567092726007104, 0.3367855172837153, 2.4042466515675187, 13.719985540956259, 9.629690274596214, 1.2192377261817455, 2.168057025410235, 0.11085372272646055, 35.04809193313122, 64.6274185180664, 32.01157607138157, 48.91852185130119, 61.64449878036976, 2.244262173771858, 0.48265752266161144, 0.20027625403599814, 0.14432633441174403, 0.10343242407543585, 0.1581137313041836, 0.1046688124188222, 0.1251722895540297, 0.14646953815827146, 0.12146086839493364, 0.09533036078209989, 0.07526174507802352, 0.1268093634280376, 0.15102216886589304, 0.13413712178589776, 0.1489080721512437, 0.25901010318193585, 0.08473494846839458, 0.14044147334061563, 0.07499687999370508, 0.0886289008485619, 0.15167801961069927, 0.1697739993687719, 0.1132948616577778], [0.05164236092241481, 0.015776894433656707, 0.015383411446237005, 0.054253885828075, 0.016989571158774197, 0.01642090606765123, 0.031335497260442935, 0.09329582971986383, 0.026399111266073305, 0.05504297063453123, 0.02875108300941065, 0.019481456292851362, 0.05296204792102799, 0.04535569103609305, 0.030092778397374786, 0.057641430030344054, 0.11997914829407819, 0.04015459395304788, 0.024556829848734196, 0.05788482478237711, 0.08458031457848847, 0.031111825082916766, 0.05359829854569398, 0.025668394519016147, 0.02462256557919318, 0.03919976901670452, 0.084786290244665, 0.026464260699867737, 0.07891910077887587, 0.08496844297042117, 3.2474133325740695, 50.70942275226116, 40.09704440832138, 26.13521609455347, 67.81400352716446, 33.69588889181614, 0.3263257473008707, 0.08878208755049855, 0.1459850641549565, 0.25042176246643066, 2.1385459089651704, 4.183047814294696, 8.662138693034649, 0.32374194532167166, 0.13313719653524458, 5.636125942692161, 70.02400293946266, 70.08201062679291, 67.1564108133316, 67.33350411057472, 72.18413382768631, 70.49435690045357, 69.68553990125656, 70.88749140501022, 72.88204237818718, 67.6987025141716, 69.64127987623215, 67.20209196209908, 55.54665818810463, 53.94492633640766, 59.35218058526516, 68.59281733632088, 68.08292269706726, 71.98608085513115, 68.7826019525528, 68.60066771507263, 63.155890479683876, 62.10769772529602, 63.12196210026741, 61.91554203629494, 62.393324598670006, 56.09314106404781, 52.270606979727745, 47.9156606644392, 46.32118262350559, 47.47119091451168, 47.40905664861202, 46.89357250928879, 50.220039412379265, 49.34379883110523, 47.14713290333748, 47.643108889460564, 49.23072449862957, 53.20085406303406, 57.36511141061783, 58.96212011575699, 60.923639461398125, 60.83136521279812, 65.19013792276382, 50.95577493309975, 53.06739762425423, 59.38729830086231, 55.37219814956188, 61.24709330499172, 58.90128158032894, 62.148184552788734, 61.2392733246088, 61.9883119314909, 63.16869579255581, 62.68707163631916, 59.996542409062386, 61.026876121759415, 57.81191423535347, 48.80504094064236, 43.45117002725601, 44.20813500881195, 44.58998031914234, 44.35851573944092, 43.79355825483799, 42.334117367863655, 43.225963711738586, 43.95394764840603, 44.69494968652725, 45.607523918151855, 50.862011164426804, 54.39416863024235, 53.72202269732952, 52.46266767382622, 53.154287561774254, 58.369169533252716, 61.19822412729263, 61.050020679831505, 60.395296812057495, 57.3757204413414, 58.49981412291527, 58.87254372239113, 51.53042569756508, 45.05039021372795, 49.19409826397896, 56.815087124705315, 61.817970871925354, 63.729902878403664, 61.910917684435844, 62.92775832116604, 64.79198008775711, 61.46919898688793, 56.752318292856216, 57.78775133192539, 3.9480166509747505, 0.19665699277538806, 0.4175085638416931, 1.9173373351804912, 1.9042490562424064, 0.2037685486720875, 0.42908268340397626, 0.16907476267078891, 2.8114230651408434, 47.812435403466225, 38.51975664496422, 24.237651117146015, 51.88428930938244, 13.703600820153952, 0.31695070036221296, 0.03501618979498744, 0.028311854039202444, 0.02310358966497006, 0.03595945949200541, 0.07651119522051886, 0.031494161012233235, 0.08583380942582153, 0.13752708910033107, 0.05643531389068812, 0.04872028061072342, 0.04425490049470682, 0.05257786404399667, 0.03298392970464192, 0.03472833297564648, 0.05068986261903774, 0.019909701477445196, 0.052032567327842116, 0.04833048238651827, 0.05661655006406363, 0.04324305264162831, 0.04661592829506844, 0.12484356266213581, 0.032523824120289646, 0.08987962748506106, 0.04256252548657358, 0.0022338206736094435, 0.04041606742248405, 0.028170691984996665, 0.03072405292186886, 0.02665599084139103, 0.060753103098249994, 0.02472573523846222, 0.03421562767471187, 0.01796239874238381, 0.050809619278879836, 0.03776136436499655, 0.01652400522289099, 0.042617355356924236, 0.050623332790564746, 0.08461052741040476, 0.024233845324488357, 0.05984722280118149, 0.07211589982034639, 0.10723592349677347, 0.015126709986361675, 0.07299331133253872, 0.03341626412293408, 0.02679189849004615, 0.047825120636844076, 0.06646836380241439, 0.03262932412326336, 0.08370196053874679, 0.1657590249669738, 6.1023039277642965, 67.15425252914429, 39.67122785747051, 45.8757933229208, 76.64001792669296, 34.10451136529446, 0.593600703869015, 0.22014056390617043, 0.17188515717862174, 1.2935376330278814, 1.5613128268159926, 10.487293805927038, 8.449216168373823, 2.8754180436953902, 0.02967117357911775, 7.184292068704963, 75.39326682686806, 69.39387515187263, 69.31261271238327, 69.94319647550583, 73.26947718858719, 72.48806431889534, 69.4525896012783, 73.77331495285034, 75.6683948636055, 71.13973706960678, 71.77993431687355, 69.20644640922546, 59.08757798373699, 56.91416680812836, 62.1430092304945, 70.45011207461357, 72.38868445158005, 73.61165642738342, 71.26782819628716, 70.06697103381157, 66.46662622690201, 65.64741298556328, 65.30306026339531, 65.08783981204033, 62.66962677240372, 57.78925605118275, 55.26070453226566, 50.80931179225445, 49.311986938118935, 51.163327395915985, 47.92216971516609, 48.81674811244011, 50.23946017026901, 50.567127987742424, 48.597572073340416, 49.3597237765789, 51.87310270965099, 55.14148972928524, 60.403306782245636, 59.62220549583435, 62.08155892789364, 63.027803152799606, 70.50925210118294, 53.61073426902294, 54.942342415452, 60.50828754901886, 58.58111836016178, 63.77530664205551, 60.89638352394104, 62.82011769711971, 64.25872430205345, 64.23108458518982, 63.97497832775116, 63.60065661370754, 62.205151095986366, 63.05945165455341, 61.337384060025215, 51.515750885009766, 45.05174674093723, 46.22361145913601, 45.60133785009384, 46.11906386911869, 46.16300091147423, 44.1547516733408, 44.43438246846199, 44.98746179044247, 47.07548774778843, 47.59714275598526, 52.708035707473755, 55.18831081688404, 55.352872386574745, 56.033279076218605, 54.277594685554504, 59.91666689515114, 63.06520834565163, 63.201655223965645, 61.56484745442867, 59.79239836335182, 62.21957512199879, 61.23108856379986, 55.05598671734333, 47.08702392876148, 51.283138766884804, 59.84970308840275, 64.25104111433029, 64.83677208423615, 63.17184202373028, 63.384820595383644, 65.3448124229908, 61.65464423596859, 58.187793865799904, 59.97567392885685, 5.290806647390127, 0.46410142618697137, 1.1681722663342953, 2.459375993348658, 2.6616695383563638, 0.360636095283553, 0.48965621273964643, 0.05722787194827106, 5.265160873532295, 55.11205270886421, 46.872681230306625, 19.679835587739944, 57.63076655566692, 18.690788559615612, 0.2965835260692984, 0.06245122232940048, 0.06117729615652934, 0.07743870912236162, 0.012154549549450167, 0.03044226501515368, 0.013673119137820322, 0.03603892124374397, 0.050388101662974805, 0.03737486127647571, 0.04611395444953814, 0.025471653025306296, 0.012712635325442534, 0.0616169333079597, 0.07603169360663742, 0.017684607300907373, 0.08329757911269553, 0.028670049759966787, 0.0185013575173798, 0.02326606620044913, 0.04632104704796802, 0.034643601975403726, 0.12288605168578215, 0.03300817566923797, 0.19584966968977824, 0.15732469473732635, 0.10200329998042434, 0.0897815971984528, 0.12740965699777007, 0.16623474162770435, 0.08735851472010836, 0.11245880261412822, 0.13673109118826687, 0.14987881615525112, 0.09372649801662192, 0.19243884802563116, 0.17005168134346604, 0.10930180287687108, 0.09831757939537056, 0.17938821081770584, 0.23283939342945814, 0.14262672717450187, 0.11974491906585172, 0.14906151860486716, 0.26020418910775334, 0.12147800458478741, 0.22128115582745522, 0.15885684377280995, 0.20576114096911624, 0.1393655373249203, 0.14191447320627049, 0.18771400937112048, 0.25514087174087763, 0.29537130205426365, 7.622356787323952, 80.13051822781563, 51.68598175048828, 42.406955659389496, 77.42577776312828, 52.94796243309975, 0.9233475441578776, 0.5814675393048674, 0.8897967101074755, 4.399479450657964, 6.776616219431162, 12.369534205645323, 17.635571882128716, 1.6288143047131598, 0.16224688530201092, 6.929169008508325, 77.80325710773468, 75.6692536175251, 72.15330228209496, 72.76481106877327, 74.01425242424011, 74.07912254333496, 72.28120341897011, 77.42007046937943, 78.58184292912483, 73.23533222079277, 73.2919491827488, 71.47025853395462, 62.63639755547047, 59.00316171348095, 63.20018470287323, 72.47102603316307, 73.90489429235458, 75.98385393619537, 73.59458774328232, 75.16002014279366, 68.00203263759613, 67.29209393262863, 69.01651740074158, 66.15807518362999, 67.66950488090515, 62.04681359231472, 58.14116656780243, 53.92573356628418, 51.63935445249081, 53.37738499045372, 50.64776346087456, 51.22364155948162, 53.19073520600796, 54.58062842488289, 51.25401712954044, 52.305834889411926, 57.181436866521835, 59.09789443016052, 64.10640567541122, 65.32493948936462, 65.26958405971527, 66.63645431399345, 72.06590697169304, 55.894506722688675, 58.78371588885784, 63.62324260175228, 63.48903760313988, 66.26780569553375, 66.58809050917625, 64.81819108128548, 67.55603536963463, 64.54970508813858, 67.17693731188774, 66.9965685904026, 67.54772901535034, 66.33323058485985, 63.1921861320734, 54.85690400004387, 47.573101446032524, 48.25579561293125, 50.47010399401188, 48.64095814526081, 48.792957589030266, 45.85232198238373, 47.533021196722984, 48.03475767374039, 49.929495602846146, 48.84762145578861, 56.6464027762413, 59.90435175597668, 59.6243941783905, 57.50739097595215, 57.749027609825134, 63.37018758058548, 67.5611574947834, 66.19159698486328, 62.065117210149765, 60.075836554169655, 64.12831529974937, 64.04246270656586, 57.83961474895477, 49.729478135704994, 54.19249065220356, 61.42251469194889, 65.31922459602356, 67.79258787631989, 65.35260200500488, 66.20288237929344, 67.88051515817642, 64.28074032068253, 60.30477046966553, 60.46505346894264, 5.604699729010463, 0.5333799321670085, 1.370866452343762, 8.164638988673687, 7.986368704587221, 1.7593051213771105, 1.150683704763651, 0.40594400314148515, 7.3005530051887035, 62.952168211340904, 50.1298588514328, 34.60663542151451, 71.5041983127594, 23.649699166417122, 0.4780036036390811, 0.2671461791032925, 0.13700375624466687, 0.08412925206357613, 0.0990633710171096, 0.18122146400855854, 0.13980920804897323, 0.20739054103614762, 0.2603151847142726, 0.16950397635810077, 0.17249594471650198, 0.19999837910290807, 0.14273701031925157, 0.18441997206537053, 0.08896374303731136, 0.12966026435606182, 0.1474383971071802, 0.13165956566808745, 0.1532935563591309, 0.0996584992390126, 0.0918205885682255, 0.16245528036961332, 0.18301277101272717, 0.12238919123774394], [0.07414860519929789, 0.029476962808985263, 0.031410661977133714, 0.02479232629411854, 0.06169109241454862, 0.05439031112473458, 0.05256848700810224, 0.028453381601138972, 0.029256285197334364, 0.03129568474832922, 0.050852916174335405, 0.10442096478072926, 0.006625500191148603, 0.07563244042103179, 0.07441798996296711, 0.035633051811601035, 0.04051232026540674, 0.07930037172627635, 0.04659358965000138, 0.0430543356196722, 0.08445423853117973, 0.033658705215202644, 0.021367071713029873, 0.02517894441552926, 0.006908151772222482, 0.030892798749846406, 0.008295574589283206, 0.007896824208728503, 0.05949572681856807, 0.24124338466208428, 0.10286582401022315, 12.898180838674307, 53.66734363138676, 32.04129807651043, 37.697051391005516, 66.02998405694962, 8.325150925666094, 0.1282841741340235, 0.29524406825657934, 0.6045476789586246, 2.1332223946228623, 15.625378098338842, 12.898989245295525, 2.483136118389666, 0.8350483572576195, 0.5082399467937648, 21.36171843856573, 68.35811913013458, 66.45132824778557, 65.89939266443253, 69.1761240363121, 70.54521337151527, 72.34819382429123, 75.25357112288475, 70.57710126042366, 70.16298428177834, 69.91858139634132, 67.98380121588707, 58.19494508206844, 56.65798455476761, 65.91963797807693, 72.23217844963074, 70.56833133101463, 67.12513849139214, 70.05307897925377, 67.30228498578072, 67.22759619355202, 61.50302477180958, 59.871806502342224, 60.970692336559296, 59.38159480690956, 55.69953918457031, 53.171808421611786, 48.116460889577866, 48.74124996364117, 47.18550704419613, 48.667587116360664, 48.00991840660572, 48.97839903831482, 47.37221002578735, 52.381363436579704, 56.7162050306797, 61.83223530650139, 60.159272477030754, 59.99324418604374, 60.194910764694214, 64.6208980679512, 64.17564556002617, 66.744794100523, 53.731415793299675, 58.373748287558556, 60.08293837308884, 64.17837381362915, 63.451108038425446, 63.77419710159302, 63.05030174553394, 64.21132564544678, 62.28737108409405, 63.66718344390392, 60.05163185298443, 57.61673390865326, 52.64229543507099, 47.83078461885452, 44.756023809313774, 45.52419438958168, 44.62387450039387, 45.02386003732681, 43.4785133600235, 46.35560877621174, 44.51767399907112, 45.522131100296974, 44.77942295372486, 44.41886030137539, 45.907878801226616, 51.96898676455021, 54.99215394258499, 56.64994798600674, 55.20703241229057, 58.16447451710701, 56.13298572599888, 61.81873843073845, 59.57311972975731, 61.66105829179287, 59.99205105006695, 63.06992009282112, 58.093760311603546, 59.51263077557087, 49.718287736177444, 51.76447793841362, 51.66752614080906, 59.85910378396511, 59.229302778840065, 64.21807408332825, 63.527024164795876, 69.14393976330757, 52.40321986377239, 67.97994062304497, 7.71482577547431, 0.551612185081467, 0.34193768457043916, 0.25600945169571787, 1.4816096099093556, 0.7409620215184987, 0.14703244232805446, 0.1591950107831508, 0.18400870350888, 24.36783593147993, 53.8936822861433, 24.408647641539574, 45.182398930191994, 40.11898063123226, 1.0468913242220879, 0.07013240625383332, 0.08427549226325937, 0.03581028780899942, 0.06081082363380119, 0.0366235072579002, 0.027939386818616185, 0.027040992936235853, 0.04103415398276411, 0.02021975778916385, 0.010431234404677525, 0.07683099407586269, 0.0568413725704886, 0.06742200130247511, 0.06648435708484612, 0.05742561348597519, 0.028718131652567536, 0.023414633033098653, 0.01025598179694498, 0.05900526368350256, 0.037650914237019606, 0.025578282948117703, 0.08346486662048846, 0.008896492490748642, 0.026326480983698275, 0.07004199782386422, 0.07271499111084267, 0.017783507755666506, 0.014349948542076163, 0.018694944883463904, 0.04744688507344108, 0.007301249306692625, 0.020063212868990377, 0.06202869539265521, 0.058109606470679864, 0.05405753952800296, 0.06858356631710194, 0.04820374582777731, 0.04475520079722628, 0.11001874721841887, 0.05293276277370751, 0.02697442971111741, 0.008598988679295871, 0.051914892392233014, 0.04264011331542861, 0.07921621217974462, 0.05571242123551201, 0.06664379267022014, 0.023856715561123565, 0.028124044292781036, 0.018449826493451837, 0.02387408367212629, 0.021935046606813557, 0.058684347895905375, 0.10847877594642341, 0.2545548422494903, 26.94088116288185, 58.951328694820404, 28.94238766282797, 58.544359132647514, 71.963662058115, 8.833989221602678, 0.1398363261250779, 0.3890460426919162, 0.7424310583155602, 0.9878790064249188, 1.5204090904444456, 11.683123838156462, 8.646051306277514, 2.1394531102851033, 0.3720971115399152, 26.874297335743904, 73.8269604742527, 68.96001443266869, 66.7420506477356, 69.81990069150925, 73.80909383296967, 76.04541823267937, 76.61566123366356, 74.7737480700016, 73.2647730410099, 72.60374531149864, 69.22926038503647, 60.02911426126957, 59.23604741692543, 67.58579537272453, 73.41386944055557, 72.0175051689148, 67.74361610412598, 73.23865324258804, 69.13364231586456, 69.53371524810791, 63.91921252012253, 62.05063998699188, 62.92509846389294, 62.8146155923605, 59.17570285499096, 56.11459091305733, 50.169547721743584, 51.188083067536354, 49.685959070920944, 50.33262737095356, 49.77237403392792, 50.70378765463829, 50.704657807946205, 55.35860247910023, 58.465425968170166, 63.84178787469864, 62.09362328052521, 63.01755130290985, 63.300655111670494, 67.7685883641243, 66.98442444205284, 65.8215120434761, 54.85764116048813, 59.38673213124275, 63.453106731176376, 64.08173739910126, 65.70288240909576, 65.69832265377045, 63.91611948609352, 65.00329434871674, 65.4752366244793, 65.29304400086403, 61.79941646754742, 61.15056708455086, 54.77625332772732, 50.9491328895092, 47.351200953125954, 46.61408990621567, 46.38489380478859, 46.88186153769493, 45.72014607489109, 48.448593467473984, 47.70860217511654, 48.10562387108803, 46.06491677463055, 45.8547842502594, 48.050310239195824, 52.44329251348972, 57.945313677191734, 57.68691994249821, 55.80298103392124, 58.11595872044563, 57.779057398438454, 63.1165511906147, 62.943516075611115, 63.01803007721901, 60.52092187106609, 64.67031061649323, 60.67798264324665, 60.229006335139275, 52.84786060452461, 52.867182567715645, 55.81783823668957, 61.881195679306984, 61.43020547926426, 66.096001714468, 65.18709808588028, 69.63822484016418, 54.05468724668026, 68.29100713133812, 11.082249730825424, 1.4602642552927136, 1.1960374773479998, 1.5825672238133848, 2.185463416390121, 0.427281164447777, 0.29998933081515133, 0.22606689512031153, 0.2634414966451004, 28.34895260632038, 64.38119173049927, 28.68505597114563, 41.90044283866882, 50.94687581062317, 1.3503393600694835, 0.06200974836247042, 0.057301474444102496, 0.027347286559233908, 0.018091925776388962, 0.030829608585918322, 0.06438303273171186, 0.04877157785813324, 0.07742027417407371, 0.03430185781326145, 0.04978666147508193, 0.06845409865491092, 0.057920199251384474, 0.043727611991926096, 0.02278758503962308, 0.07135746200219728, 0.06641245039645582, 0.0483367609558627, 0.03064580087084323, 0.058319682502769865, 0.014021029619470937, 0.03554718532541301, 0.12194759852718562, 0.03942436145734973, 0.013077264538878808, 0.164549250039272, 0.10437305914820172, 0.11073107540141791, 0.11325095620122738, 0.09790709751541726, 0.1412221384816803, 0.09912721798173152, 0.09964595694327727, 0.15237672196235508, 0.1520347551559098, 0.18862153723603114, 0.12713426083792, 0.10182474667089991, 0.16265827260212973, 0.18480712082237005, 0.13224688649643213, 0.18736727797659114, 0.11497944782604463, 0.12514671514509246, 0.135010659287218, 0.17288598784944043, 0.1897315081441775, 0.10196782532148063, 0.09992544233682565, 0.11439253517892212, 0.09756133833434433, 0.12954293080838397, 0.11200533554074354, 0.1297194283688441, 0.31895286636427045, 0.2297559182625264, 35.45104891061783, 73.81697461009026, 42.207872942090034, 53.95731367170811, 80.22601470351219, 15.931519120931625, 0.2669504302321002, 0.9454978618305176, 2.70434504840523, 6.818408751860261, 34.59589719772339, 28.965528421103954, 8.210442680865526, 1.8587879394181073, 0.4607629787642509, 24.715967550873756, 75.92501789331436, 75.4667928814888, 71.69570043683052, 71.19381576776505, 73.2450520992279, 77.9059199988842, 80.09710282087326, 78.48222747445107, 76.44997492432594, 75.66785529255867, 74.86517876386642, 62.64638341963291, 62.99119211733341, 73.4373065829277, 78.5048058629036, 75.61459735035896, 69.0240029990673, 76.43942669034004, 71.17408722639084, 71.35814175009727, 66.50716245174408, 64.4704033434391, 64.8374180495739, 63.337752521038055, 61.66627541184425, 59.333603382110596, 53.083740547299385, 53.796266913414, 51.731073930859566, 54.08185958862305, 54.94722135365009, 52.42155008018017, 52.35733352601528, 58.122999742627144, 62.74699442088604, 68.20037439465523, 65.89586645364761, 65.5523344874382, 65.67760616540909, 71.14484399557114, 68.43656972050667, 67.37346276640892, 57.14385688304901, 61.12866885960102, 64.8944453895092, 67.37714096903801, 67.0386703312397, 69.1179795563221, 66.66869178414345, 67.50879630446434, 67.84003213047981, 68.38912546634674, 64.56413671374321, 63.004236817359924, 54.90303732454777, 51.94004751741886, 48.963507637381554, 48.96983049809933, 49.189618304371834, 49.154538586735725, 47.00582228600979, 51.42717383801937, 49.127430841326714, 49.410242065787315, 49.35691572725773, 48.70187267661095, 50.160485208034515, 56.679255813360214, 58.9219980686903, 61.82339318096638, 58.24390925467014, 63.09007041156292, 59.78865936398506, 65.00747412443161, 66.31716504693031, 66.74544006586075, 62.05237649381161, 69.0132723748684, 62.59133197367191, 65.00762611627579, 56.05954326689243, 55.99755339324474, 57.57790379226208, 65.58272525668144, 61.969863921403885, 68.81237715482712, 67.92863577604294, 70.12915849685669, 57.56096050143242, 70.78519329428673, 10.049747284501791, 1.238092789426446, 0.8434647868853062, 1.4304324123077095, 8.45236524939537, 5.06785218603909, 0.44768903811927885, 0.6988373631611466, 0.417206569109112, 39.788668155670166, 67.05505505204201, 38.44678536057472, 58.142070919275284, 61.067085564136505, 2.3030825424939394, 0.21169915358768776, 0.17790018988307565, 0.12375723657896742, 0.25049110874533653, 0.1539300667354837, 0.18992657423950732, 0.1629544934257865, 0.2566372789442539, 0.1016776826872956, 0.15173178078839555, 0.21218675945419818, 0.11836424237117171, 0.13246411312138662, 0.10214261594228446, 0.16997667989926413, 0.10524619588977657, 0.12264954406418838, 0.06861783127533272, 0.17098632728448138, 0.13194842438679188, 0.12211447043227963, 0.34130668092984706, 0.08878521199221723, 0.10406988440081477], [0.02700240867852699, 0.057574046732042916, 0.030123302931315266, 0.04795226537680719, 0.015485601470572874, 0.007135727646527812, 0.010640572927513858, 0.07031613233266398, 0.02056875830021454, 0.05034326852182858, 0.02108236531057628, 0.04674321033235174, 0.05875730101251975, 0.020729398020193912, 0.04735244678158779, 0.030910725326975808, 0.04845842864597216, 0.05817354249302298, 0.08124490996124223, 0.015677832561777905, 0.10455606534378603, 0.03659749127109535, 0.10007868098909967, 0.07560787533293478, 0.020943758099747356, 0.07171156292315573, 0.18374815030256286, 0.11117222282337025, 0.07297515097889118, 0.04263662893208675, 0.1552352076396346, 1.9732367293909192, 46.51972956955433, 53.16722586750984, 25.49602009356022, 45.0530918687582, 45.25170341134071, 1.2727887276560068, 0.4211403970839456, 0.527448212960735, 0.055724740886944346, 2.9331388464197516, 5.42983453720808, 9.329508282244205, 0.7287292904220521, 0.09929187828674912, 0.3803644288564101, 45.906317085027695, 78.0440653860569, 65.46746984124184, 72.32291758060455, 75.26873230934143, 72.85605937242508, 69.56958532333374, 74.33090463280678, 70.79132616519928, 70.66795438528061, 68.85083869099617, 59.898321479558945, 60.32945774495602, 66.0209633409977, 70.07407665252686, 69.08781677484512, 71.65284633636475, 71.28401532769203, 68.22013333439827, 63.152949437499046, 61.32207848131657, 60.18205225467682, 62.319517359137535, 64.29352283477783, 57.53512568771839, 55.151904970407486, 49.80446711182594, 49.47563275694847, 49.48648117482662, 49.95622716844082, 48.94401468336582, 52.27633707225323, 55.216037929058075, 59.60598796606064, 59.28540676832199, 60.671374797821045, 63.76529037952423, 65.88721811771393, 63.50187711417675, 64.73603948950768, 64.64351445436478, 67.91988104581833, 48.23651164770126, 58.551878929138184, 68.74319806694984, 64.42016243934631, 62.990766540169716, 60.04204496741295, 63.038659170269966, 60.515229776501656, 60.149875581264496, 55.993438214063644, 53.702525943517685, 49.811929911375046, 46.771819442510605, 46.51939898729324, 48.21694649755955, 46.003645062446594, 44.84345331788063, 46.20041370391846, 45.789420157670975, 45.85047908127308, 45.754777416586876, 45.26537507772446, 47.19494193792343, 45.47592557966709, 47.48004823923111, 50.44874154031277, 53.55257458984852, 55.19576981663704, 58.12008909881115, 56.71769455075264, 61.578526720404625, 61.85212343931198, 65.81504479050636, 60.524961054325104, 59.060398042201996, 58.52868877351284, 63.885842710733414, 58.3050973713398, 52.2535040974617, 51.40542760491371, 56.61859966814518, 53.41311067342758, 60.46661138534546, 57.870461493730545, 68.58058959245682, 55.86630843579769, 71.41224324703217, 25.121536888182163, 0.3672279993770644, 0.8113283081911504, 0.7451036805287004, 1.7868816666305065, 1.6527740377932787, 0.3106728137936443, 0.13977739959955215, 0.09043954822118394, 9.00168752297759, 55.611885488033295, 27.04575553536415, 23.41339934617281, 52.8565089404583, 9.804285205900669, 0.21385947125963867, 0.039358870635624044, 0.019694875700224657, 0.015042555078252917, 0.0314125247678021, 0.03188987044268288, 0.006992721355345566, 0.04172364257101435, 0.05528399793547578, 0.025304244918515906, 0.058174262376269326, 0.017055839380191173, 0.027503671917656902, 0.012802585479221307, 0.06102672552515287, 0.07379894232144579, 0.049312366027152166, 0.03462499262241181, 0.047071462249732576, 0.06171323810121976, 0.05140934510563966, 0.053375079078250565, 0.022834293959022034, 0.023091629955160897, 0.01782878618541872, 0.03976664367655758, 0.0467707291682018, 0.020082686824025586, 0.01432909883078537, 0.05196666461415589, 0.026138608154724352, 0.0611891000153264, 0.018087454336637165, 0.061002060247119516, 0.06655185541603714, 0.03801144957833458, 0.014199855668266537, 0.08111908624414355, 0.029868840902054217, 0.05485940411745105, 0.029447429042193107, 0.046918386869947426, 0.07085890945745632, 0.10317547028535046, 0.06494210741948336, 0.07733969177934341, 0.020193320633552503, 0.07377670015557669, 0.05068709440820385, 0.05408244971476961, 0.03863782963890117, 0.0316355030372506, 0.08473163106827997, 0.09457068357733078, 0.0642116337257903, 0.07088144848239608, 4.625685112550855, 67.07053542137146, 46.004579812288284, 29.453832618892193, 68.32267463207245, 45.09040206670761, 1.524896768387407, 0.4614472092362121, 0.3849569574231282, 0.1755372213665396, 1.6955096321180463, 1.4852069481275976, 13.536392692476511, 6.947700614109635, 0.278200350003317, 0.46971835603471845, 51.86527132987976, 78.31764310598373, 67.56668999791145, 71.70109614729881, 75.53863182663918, 73.8670863211155, 74.54814657568932, 75.78078523278236, 76.45416989922523, 73.40484112501144, 72.4683889746666, 62.1353754401207, 61.80861197412014, 68.0860461294651, 73.81405636668205, 71.68529659509659, 71.62288874387741, 70.45781806111336, 69.50208574533463, 66.90889209508896, 65.43301329016685, 65.15305191278458, 63.953372687101364, 64.52809184789658, 60.941038727760315, 58.17798659205437, 50.981575548648834, 50.47767698764801, 51.41774274408817, 50.32973952591419, 50.04768066108227, 53.92741687595844, 56.88430421054363, 60.22396020591259, 61.459357514977455, 63.286379277706146, 65.73427632451057, 68.0854457616806, 65.98565563559532, 65.23364558815956, 66.33325338363647, 68.43970075249672, 51.87126740813255, 61.6214644163847, 69.87872913479805, 64.68940079212189, 64.92458537220955, 62.00642555952072, 66.41890838742256, 63.27561445534229, 65.00521704554558, 60.49400791525841, 56.79586015641689, 51.626404747366905, 48.27599912881851, 48.598069846630096, 49.73496504127979, 47.9294653236866, 49.60354529321194, 46.61376692354679, 48.58681105077267, 46.05503350496292, 46.86898782849312, 47.18575403094292, 49.043462947010994, 46.83619938790798, 50.724690333008766, 53.44222091138363, 56.81858293712139, 57.111273631453514, 60.497777312994, 57.42196395993233, 62.44273714721203, 62.827040925621986, 66.83213621377945, 62.261642664670944, 62.2633221745491, 60.58059386909008, 66.05515390634537, 61.43381528556347, 54.61761184036732, 54.44663621485233, 57.70607851445675, 55.990326181054115, 62.18640670180321, 61.56275376677513, 69.98036608099937, 57.29972451925278, 73.2646894454956, 29.596902541816235, 0.4259707988239825, 1.5024511353112757, 1.3528680056333542, 1.2842328823171556, 0.7953863230068237, 0.3511969861574471, 0.24110911530442536, 0.26600540906656533, 12.953594215214252, 62.4789834022522, 39.38688911497593, 21.632262021303177, 61.175235360860825, 14.289969205856323, 0.2876690559787676, 0.09556346194585785, 0.01068063591446844, 0.01585859376064036, 0.10809009836521, 0.0993660485255532, 0.04702892605564557, 0.03505943845084403, 0.0043626422939269105, 0.020283075973566156, 0.02439336069073761, 0.01290183103265008, 0.029047550597169902, 0.010151424321520608, 0.04715832321380731, 0.04164208054135088, 0.031082927707757335, 0.05783382439403795, 0.06707454260322265, 0.08585938383475877, 0.03881383367115632, 0.009351088556286413, 0.013467146254697582, 0.03683630326122511, 0.06507397964014672, 0.096513685566606, 0.12156328477431089, 0.17072154383640736, 0.13050157780526206, 0.1284969033440575, 0.11869293215568177, 0.18144703237339854, 0.15360677236458287, 0.20342545380117372, 0.1519863522844389, 0.17579021950950846, 0.18248928972752765, 0.15642828424461186, 0.06945461020222865, 0.10168825087021105, 0.15785644354764372, 0.11410742430598475, 0.15867268724832684, 0.18266123050125316, 0.14788224594667554, 0.18302863813005388, 0.1705221287556924, 0.1553530161618255, 0.14694546262035146, 0.17255117534659803, 0.17465209151851013, 0.24189763236790895, 0.2876664139330387, 0.21339196275221184, 0.2740687842015177, 0.3721760166808963, 5.149069977924228, 82.45969444513321, 64.81613919138908, 37.261875942349434, 56.76424205303192, 64.43063467741013, 3.173946887254715, 0.8368438796605915, 1.32785762893036, 0.9850847313646227, 7.366344574838877, 12.947882171720266, 21.540255658328533, 6.616914588958025, 0.2304744508001022, 0.6180141563527286, 53.59369598329067, 82.38272577524185, 75.04143610596657, 74.08614456653595, 77.31470212340355, 78.68459701538086, 76.17906466126442, 79.81306806206703, 78.42550411820412, 77.60723322629929, 73.83336693048477, 65.795529037714, 66.56538292765617, 70.77223598957062, 76.53638228774071, 72.2784523665905, 74.6093612909317, 73.19215133786201, 74.09602403640747, 69.18348804116249, 67.19141453504562, 67.18406572937965, 67.4029491841793, 70.25490894913673, 63.82869377732277, 62.72866040468216, 54.86769162118435, 53.94969508051872, 54.30248714983463, 54.241880401968956, 51.5009430795908, 57.596150413155556, 61.78275056183338, 62.904860749840736, 66.91239550709724, 67.10370004177094, 70.51261112093925, 71.21228277683258, 69.73713353276253, 68.17785680294037, 69.0062503516674, 69.30195808410645, 54.42623130977154, 61.921800300478935, 73.58295276761055, 68.74971851706505, 67.80950456857681, 64.89183112978935, 68.55129316449165, 65.652497112751, 67.42862060666084, 61.33755125105381, 58.54701139032841, 53.92331689596176, 52.5982291996479, 51.95353679358959, 53.02599124610424, 49.65888172388077, 51.85534246265888, 49.873893186450005, 52.84389741718769, 47.89969012141228, 49.64590921998024, 50.03195710480213, 52.145221307873726, 50.45123040676117, 52.81519375741482, 57.15193144977093, 59.82155799865723, 59.00604195892811, 63.52883666753769, 59.303007423877716, 68.1458093225956, 67.0591588318348, 70.09559869766235, 64.7206199169159, 62.99968086183071, 62.738182693719864, 69.37226191163063, 63.226483091712, 57.331768199801445, 57.49201700091362, 61.069126054644585, 57.96038746833801, 67.43254959583282, 63.72903272509575, 71.56120285391808, 62.093114107847214, 76.84652164578438, 27.469793781638145, 0.2550602745031938, 1.6240095812827349, 1.5561953326687217, 7.557276729494333, 4.7947275917977095, 1.0114723560400307, 1.205090016592294, 0.37091377191245556, 17.713803984224796, 69.4934830069542, 41.60272881388664, 34.46061685681343, 71.01049840450287, 20.075631849467754, 0.6147780956234783, 0.18891222163802013, 0.10990372917149216, 0.09870494337519631, 0.1660387997981161, 0.18450165283866227, 0.0934781160322018, 0.283256127149798, 0.1833206880837679, 0.1541696023195982, 0.09701413058792241, 0.2171628299402073, 0.12334320723311976, 0.09623549151001498, 0.10207597850239836, 0.12174661009339616, 0.07021698882454075, 0.12051106037688442, 0.16173979063751176, 0.1837183753377758, 0.21722643199609593, 0.23982809419976547, 0.10492984059965238, 0.15572305099340156, 0.14726255263667554], [0.06878710773889907, 0.008476305174554, 0.06975172902457416, 0.07327633677050471, 0.06074582262954209, 0.049828555711428635, 0.024256978067569435, 0.032618292098050006, 0.021740969423262868, 0.02458297571138246, 0.03767871508898679, 0.07106455857865512, 0.011713949461409356, 0.02271147408464458, 0.05668320976838004, 0.055160248521133326, 0.013723715983360307, 0.041029764179256745, 0.08383815205888823, 0.06131517235189676, 0.06892513236380182, 0.02454511875839671, 0.031761786885908805, 0.02415191222098656, 0.04349957227532286, 0.09031365028931759, 0.04453852707229089, 0.0960837742604781, 0.040244961564894766, 0.0336231266555842, 0.24592949805082753, 0.09410804355866276, 21.142392307519913, 59.36745196580887, 32.46132753789425, 30.56228443980217, 63.96401211619377, 21.105245500802994, 0.13017096585826948, 0.17424457822926342, 0.20344200369436294, 0.4595833201892674, 2.6431205961853266, 17.640340626239777, 4.965647645294666, 0.5439065548125654, 0.4827450664015487, 3.5291114542633295, 69.13257077336311, 70.43773993849754, 70.7364571094513, 72.0323395729065, 80.02306759357452, 75.8310717344284, 73.10911819338799, 74.93004888296127, 70.8512033522129, 69.99672040343285, 60.78460492193699, 64.68620896339417, 70.66129714250565, 75.18712788820267, 71.57581686973572, 69.14364337921143, 70.95311388373375, 67.58236795663834, 64.93257254362106, 63.195712342858315, 60.062681660056114, 61.15807548165321, 59.36136469244957, 58.662244006991386, 52.52996206283569, 49.32826906442642, 50.197050645947456, 47.0960446447134, 49.10003051161766, 49.796073362231255, 50.18107250332832, 54.57275904715061, 57.977600544691086, 54.739927276968956, 60.60064919292927, 62.037735879421234, 62.70195923745632, 64.3043902516365, 65.89415654540062, 62.112709656357765, 68.27143058180809, 42.17638023197651, 57.66666702926159, 68.34537461400032, 60.72872132062912, 62.300883159041405, 58.40012267231941, 57.53865569829941, 54.04833398759365, 51.836461275815964, 49.49707880616188, 50.256251469254494, 48.73563386499882, 47.75891147553921, 47.57790058851242, 48.13297100365162, 46.62788316607475, 48.85641798377037, 46.2613320350647, 46.79545797407627, 45.82690894603729, 46.658737510442734, 47.75845170021057, 48.34531120955944, 44.83603611588478, 46.27519749104977, 47.03075274825096, 53.211083114147186, 57.08484224975109, 59.60292533040047, 59.829180389642715, 59.32184301316738, 60.60022361576557, 64.79866772890091, 61.30037784576416, 61.08976274728775, 60.72462894022465, 62.51576542854309, 62.744828537106514, 58.73167388141155, 52.072356417775154, 52.61036194860935, 57.214039117097855, 57.94421173632145, 63.0639012157917, 64.45070520043373, 62.46223010122776, 57.28785015642643, 0.7321596157271415, 0.4189657559618354, 0.5862295744009316, 1.9919741177000105, 2.0994764054194093, 0.08956943202065304, 0.01981858800718328, 0.12518866133177653, 3.448390723206103, 37.58525758981705, 42.697301879525185, 17.480405308306217, 48.38041752576828, 37.49246656894684, 0.3770195395918563, 0.08030941055039875, 0.08644291970995255, 0.011829757895611692, 0.12001532799331471, 0.04585752758430317, 0.03071321942115901, 0.017518195527372882, 0.025113715200859588, 0.025330567041237373, 0.046857564157107845, 0.019556789848138578, 0.011024307805200806, 0.042371463277959265, 0.054759581544203684, 0.02625827575684525, 0.026838104604394175, 0.05821214901516214, 0.05716786930861417, 0.024695670836081263, 0.02330071150936419, 0.03863547332002781, 0.03601381067710463, 0.017439965740777552, 0.0034875460505645606, 0.06336574122542515, 0.03545566367392894, 0.03850711516861338, 0.1334230272914283, 0.05518994927115273, 0.08762397352256812, 0.03749199444428086, 0.02944409123301739, 0.042262571660103276, 0.04520081965893041, 0.02377483069722075, 0.03389106052054558, 0.03983878414146602, 0.0465790658199694, 0.023040896739985328, 0.011459112647571601, 0.05453621364722494, 0.01236430181961623, 0.022612592183577362, 0.06792414584197104, 0.0650174799375236, 0.03577025265258271, 0.017942071317520458, 0.06281750931520946, 0.03141469926049467, 0.04558892207569443, 0.04151716595515609, 0.07471887889550999, 0.10252862179186195, 0.06887790208566003, 0.07022175341262482, 0.20069953054189682, 0.146860753884539, 32.03193157911301, 70.78316420316696, 25.936995930969715, 44.73781518638134, 78.13402935862541, 21.224374808371067, 0.06340670035569929, 0.19751185784116387, 0.07656761328689754, 0.7432511018123478, 0.7948311371728778, 7.474669162184, 7.070129094645381, 2.00762702152133, 0.6860846537165344, 5.920164976269007, 79.91524457931519, 72.51793831586838, 73.07384848594666, 73.42839226126671, 83.18412557244301, 76.13868042826653, 75.73755875229836, 80.10450482368469, 74.32176992297173, 71.18868604302406, 65.10209664702415, 64.90752428770065, 73.00985991954803, 75.53623035550117, 73.05077612400055, 68.54329079389572, 73.77771511673927, 72.04940065741539, 68.82010594010353, 63.98567855358124, 63.21745477616787, 64.2654499411583, 63.39150823652744, 59.67162564396858, 54.7755541652441, 51.49577155709267, 51.20935432612896, 48.77925932407379, 52.102883979678154, 52.77610905468464, 54.15744513273239, 57.65347793698311, 61.4219219237566, 59.691145196557045, 63.13814923167229, 64.03412595391273, 65.57380333542824, 66.362344622612, 69.69462141394615, 65.00359073281288, 69.21956330537796, 46.824925392866135, 57.713089138269424, 69.85746547579765, 64.68927159905434, 63.512223958969116, 60.8851171284914, 59.09591093659401, 55.46801000833511, 53.646615743637085, 50.31607165932655, 52.277211025357246, 49.5569483935833, 50.95853738486767, 48.79364155232906, 48.70433874428272, 47.21423730254173, 49.13059987127781, 49.293242543935776, 48.11011902987957, 49.08918209373951, 49.32903282344341, 49.56978790462017, 50.29562495648861, 49.40420038998127, 48.14360283315182, 51.02961257100105, 55.59920556843281, 58.816116750240326, 59.80193205177784, 61.10482133924961, 61.61461718380451, 63.739352971315384, 64.94716376066208, 65.58590948581696, 62.24859796464443, 63.58603119850159, 65.10732516646385, 64.803037494421, 59.30206127464771, 54.94479328393936, 54.05859723687172, 59.10918742418289, 60.19548073410988, 64.86607611179352, 64.87743750214577, 65.43732225894928, 60.24668678641319, 1.0971654765307903, 0.8032831305172294, 0.9559988952241838, 2.681338945403695, 0.41182994667906314, 0.4263670166255906, 0.21538229892030358, 0.43287933280225843, 8.325085379183292, 43.67226876318455, 60.83073064684868, 20.821229740977287, 45.781470984220505, 48.06243158876896, 0.7271860388573259, 0.08598763437476009, 0.029574288055300713, 0.03720338805578649, 0.017077999909815844, 0.016298644659400452, 0.037225530031719245, 0.03951211299863644, 0.01281699056562502, 0.056333402171730995, 0.03179373263265006, 0.09287929933634587, 0.03584987767681014, 0.016805321865831502, 0.03314810761366971, 0.014827692193648545, 0.05577691386861261, 0.05007862979255151, 0.04281788365915418, 0.02256472365843365, 0.13360900949919596, 0.038241901274886914, 0.04507736710365862, 0.028511486198112834, 0.024870715642464347, 0.01868225972430082, 0.13752432831097394, 0.16031670762458816, 0.18262642377521843, 0.12734676740365103, 0.1583851347095333, 0.12118092286982574, 0.17523469228763133, 0.15152982756262645, 0.1686170356697403, 0.11234482357394882, 0.12474524293793365, 0.14962203305913135, 0.10150329282623716, 0.10761096040369011, 0.09245896915672347, 0.14763821294764057, 0.13339307421119884, 0.12624831462744623, 0.23310094111366197, 0.14789722248679027, 0.1553996081929654, 0.1043129080790095, 0.11192923571798019, 0.17117766779847443, 0.18053913343464956, 0.10269215403241105, 0.08353940793313086, 0.24078029935481027, 0.1481117625371553, 0.13987674348754808, 0.2653903764439747, 0.2327731196419336, 35.9907491505146, 90.69905832409859, 40.970560535788536, 47.03603446483612, 79.1184501349926, 34.68176878988743, 0.3308342647505924, 0.3866720903897658, 0.6343906244728714, 1.2692709476687014, 9.217085614800453, 34.11800064146519, 14.02211207896471, 1.811120684724301, 0.7264497689902782, 4.907713104039431, 78.28624159097672, 74.64187994599342, 80.34419596195221, 77.22869753837585, 84.8640838265419, 81.33758425712585, 77.607841193676, 84.04921755194664, 77.54638329148293, 73.35254073143005, 66.22764185070992, 69.70339894294739, 75.75996235013008, 79.92550402879715, 72.25756108760834, 69.9075011909008, 76.9709649682045, 73.30821990966797, 70.28365820646286, 68.41836869716644, 66.3462182879448, 66.83208301663399, 65.04617884755135, 62.668939009308815, 56.11870229244232, 54.448532313108444, 55.897637754678726, 52.031702399253845, 55.432972088456154, 55.98364233970642, 57.72672660648823, 59.96395155787468, 64.52612355351448, 59.893947914242744, 63.3804926276207, 66.0318611562252, 68.27665910124779, 70.64484402537346, 71.7733758687973, 67.87164643406868, 70.79231411218643, 49.16992016136646, 59.03135620057583, 71.59097045660019, 67.34316319227219, 66.5087203681469, 64.3704155087471, 62.80357338488102, 58.450511768460274, 55.878935158252716, 53.02163287997246, 53.85911174118519, 52.741530910134315, 52.872783467173576, 51.19466431438923, 51.73997305333614, 51.053410694003105, 53.106543123722076, 51.282299011945724, 52.13286057114601, 51.922515258193016, 51.6440661996603, 52.5654711574316, 52.95921742916107, 51.088414415717125, 50.36483444273472, 52.139586210250854, 57.312970608472824, 62.936440855264664, 64.00618225336075, 64.79983046650887, 62.974001839756966, 65.62593653798103, 70.47368600964546, 67.33866423368454, 64.24678534269333, 65.33738002181053, 67.54781261086464, 69.06423524022102, 64.29828777909279, 56.045670211315155, 57.22526751458645, 61.31035231053829, 62.41589158773422, 69.31382864713669, 69.15163055062294, 64.56122606992722, 59.21899393200874, 1.2168336426839232, 0.8580205589532852, 0.8511298662051558, 6.353126093745232, 6.504839602857828, 1.2771364068612456, 0.40915373247116804, 0.732393303187564, 7.903734063729644, 55.052680894732475, 56.18703402578831, 28.54652300477028, 60.87792031466961, 56.34616568684578, 1.0981480800546706, 0.2282698269118555, 0.28869773203041404, 0.08777682625805028, 0.17975359980482608, 0.05993887432850897, 0.10342814930481836, 0.0897284594248049, 0.0675325516203884, 0.14853339147521183, 0.1655843827757053, 0.13387625687755644, 0.13257034413982183, 0.14916899643139914, 0.11895678049768321, 0.11349777967552654, 0.2577482146443799, 0.16751585179008543, 0.19439004332525656, 0.05410605743236374, 0.2205143985338509, 0.1757777068996802, 0.27677260630298406, 0.17894304095534608, 0.1756004078197293, 0.16290125175146386], [0.05028054591093678, 0.01708288324152818, 0.008066973623499507, 0.04610045478329994, 0.06218932212505024, 0.043804773085867055, 0.06645382512942888, 0.021022277323936578, 0.020697982909041457, 0.07450900695403107, 0.12213015943416394, 0.05905913989408873, 0.014257647635531612, 0.08454633163637482, 0.02827789336151909, 0.027197630624868907, 0.01423183573933784, 0.014558767561538843, 0.06871061457786709, 0.04764354678627569, 0.10146104978048243, 0.008269515928986948, 0.007348969402301009, 0.030391121763386764, 0.03751064090465661, 0.05883883706701454, 0.03883677716657985, 0.07994710889761336, 0.08488814259180799, 0.08521865063812584, 0.08250466111348942, 0.3201444586738944, 1.1457307892851532, 42.798395454883575, 59.33425314724445, 31.845606677234173, 34.6061984449625, 58.263702392578125, 8.140728771686554, 0.08071426695096307, 0.17216562962858006, 0.23630970565136522, 0.1705168149783276, 5.858207400888205, 7.770539810881019, 1.1040122341364622, 0.4272139852400869, 0.20248055137926713, 12.6466865837574, 77.17186778783798, 63.36569242179394, 74.13323163986206, 72.78494998812675, 76.01118966937065, 74.80284690856934, 72.97891438007355, 69.54041808843613, 72.38653376698494, 64.61610272526741, 69.18454438447952, 72.23963364958763, 76.47988691926003, 66.83271378278732, 73.4191283583641, 72.14803576469421, 67.9082840681076, 62.18954153358936, 60.65078370273113, 64.36665371060371, 63.39377671480179, 62.246131896972656, 59.69938315451145, 53.96953001618385, 51.08437903225422, 50.28116673231125, 48.749077543616295, 51.136272847652435, 49.68269124627113, 54.15204182267189, 57.714985236525536, 64.38680022954941, 58.96397061645985, 61.483873799443245, 62.06324391067028, 62.98818647861481, 63.50064978003502, 69.72815841436386, 63.49391274154186, 71.65424466133118, 32.43793599307537, 58.246842697262764, 71.30300670862198, 64.73089456558228, 63.504343181848526, 60.71754612028599, 60.217052176594734, 61.596199572086334, 60.884623154997826, 62.17464253306389, 60.43358735740185, 57.96161100268364, 51.622924134135246, 49.71711739897728, 46.8264377117157, 47.23724126815796, 46.56751200556755, 46.58188283443451, 45.37559196352959, 48.34192179143429, 48.19494567811489, 49.93316240608692, 49.83111508190632, 50.29041163623333, 46.429719999432564, 48.53522501885891, 50.108348205685616, 56.914577186107635, 57.62391172349453, 61.91323935985565, 60.19754022359848, 65.33749401569366, 63.69887754321098, 63.80221679806709, 59.810914769768715, 65.11624708771706, 62.02975630760193, 64.16441336274147, 58.25907804071903, 59.240519776940346, 56.3123133033514, 59.70386691391468, 59.91154856979847, 65.27414381504059, 58.53102944791317, 73.98976653814316, 7.053169654682279, 0.10314782528439537, 0.10084480745717883, 4.24990332685411, 1.0157815623097122, 0.26472538243979216, 0.11926295352168381, 0.1957737628254108, 4.984171651303768, 30.849564224481583, 55.68487957119942, 18.70304860174656, 36.01629137992859, 51.94131664931774, 6.472985912114382, 0.2955199987627566, 0.10553352578426711, 0.05185901980439667, 0.026061139069497585, 0.05794211487227585, 0.03435243517742492, 0.05021996439609211, 0.05908310013182927, 0.023671011658734642, 0.05050858191680163, 0.02918726360803703, 0.038960125821176916, 0.024850755580700934, 0.014418988685065415, 0.0546251266496256, 0.027908988449780736, 0.033205746512976475, 0.08969273985712789, 0.07757080398732796, 0.008103059626591858, 0.08680493934662081, 0.06509476719656959, 0.057734142828849144, 0.025487215862085577, 0.025932849566743243, 0.006666173594567226, 0.018221230166091118, 0.02408918775472557, 0.04977291318937205, 0.008234210108639672, 0.025122110746451654, 0.030989090555522125, 0.033670249322312884, 0.03772961899812799, 0.033372306716046296, 0.02940577600384131, 0.06438308468204923, 0.020775064222107176, 0.050149738672189415, 0.0797708636673633, 0.04357288533356041, 0.020625565994123463, 0.08373793243663386, 0.05401521113526542, 0.04633155956980772, 0.0145362025614304, 0.08451376619632356, 0.010831749241333455, 0.03387826960533857, 0.005282232377794571, 0.02294800211529946, 0.04303537374653388, 0.023749428837618325, 0.04545503492408898, 0.07638760536792688, 0.11444788455264643, 0.09698655980173498, 0.1543137719272636, 3.1740832049399614, 56.88240431249142, 56.11617922782898, 25.236885398626328, 62.12713748216629, 59.67775471508503, 10.066830217838287, 0.04983929087757133, 0.08723729974008165, 0.5345645186025649, 0.19982660160167143, 1.158423414453864, 1.8997828708961606, 2.920080372132361, 1.28304687095806, 0.5241811601445079, 19.122517593204975, 86.7211277782917, 69.30138811469078, 75.90231031179428, 73.10113862156868, 81.01149335503578, 75.9632134437561, 75.10816052556038, 71.19585245847702, 74.79925990104675, 66.37784779071808, 69.90462094545364, 73.3553297817707, 80.73791563510895, 68.30717146396637, 72.34018385410309, 74.78070929646492, 70.15905529260635, 64.74682331085205, 62.85501502454281, 67.5816459953785, 67.41232708096504, 64.14690390229225, 61.14990212023258, 55.83192028105259, 52.28481061756611, 52.55258224904537, 52.34453961253166, 52.64148227870464, 51.346184983849525, 56.5669946372509, 58.328059539198875, 64.0424171090126, 62.678499296307564, 63.917555809020996, 64.69288900494576, 65.17346441745758, 66.13185659050941, 69.23282459378242, 63.899521976709366, 72.67885208129883, 34.98192608356476, 61.38844572007656, 73.17451268434525, 66.50963231921196, 64.85865890979767, 60.00938192009926, 60.01983895897865, 61.67944170534611, 61.648294776678085, 62.82435066998005, 59.57933619618416, 57.68478445708752, 54.337365478277206, 52.34310328960419, 48.90697427093983, 49.704087898135185, 49.2988396435976, 48.242310136556625, 46.770310923457146, 49.81121554970741, 49.160276278853416, 48.85247379541397, 50.576570481061935, 50.06773218512535, 49.692107141017914, 50.038013979792595, 53.39692734181881, 58.09049628674984, 61.00350357592106, 63.99479806423187, 62.751405984163284, 66.29353031516075, 66.1568820476532, 66.67999997735023, 61.213275119662285, 65.27786001563072, 62.74899311363697, 68.40093523263931, 62.390193566679955, 61.984485536813736, 60.19520714879036, 61.7358610779047, 60.834587439894676, 67.04932495951653, 60.61481103301048, 75.7295335829258, 10.142177324742079, 0.21508538047783077, 0.4992919019423425, 1.3560358481481671, 1.171295817475766, 0.48902250768151134, 0.2601448172936216, 0.505324968835339, 9.584305509924889, 33.25453117489815, 66.69052541255951, 26.91090077161789, 28.91612157225609, 64.10214230418205, 8.097740728408098, 0.28574416239280254, 0.1550420859712176, 0.0473972168401815, 0.012780186534655513, 0.06512037871289067, 0.029393653021543287, 0.037607524573104456, 0.02231914142612368, 0.021487650301423855, 0.024127373108058237, 0.032350009423680604, 0.05950450271484442, 0.04110850233701058, 0.05117198030347936, 0.039442161869374104, 0.054769210910308175, 0.05723445108742453, 0.04081956940353848, 0.0859713219688274, 0.023832085535104852, 0.030970603656896856, 0.12597943452419713, 0.0661009487521369, 0.06554753665113822, 0.034813958263839595, 0.025681717925181147, 0.12178912031231448, 0.17500204383395612, 0.09247652837075293, 0.16916028776904568, 0.1852058173972182, 0.14107532682828605, 0.1517560490174219, 0.11619415061431937, 0.1856411315384321, 0.13769632845651358, 0.23076166195096448, 0.21463601005962119, 0.21820734342327341, 0.2191676973598078, 0.1661682897247374, 0.1684855716302991, 0.1438836136367172, 0.13643598358612508, 0.11804691486759111, 0.08574364590458572, 0.19194457767298445, 0.06807872778153978, 0.12555204652016982, 0.1336315559456125, 0.1331792466226034, 0.16064899682532996, 0.09679032111307606, 0.13724885793635622, 0.18192910181824118, 0.25732913869433105, 0.2158846883685328, 0.38894487312063575, 2.8304861672222614, 68.3812902867794, 79.9072878062725, 41.343058347702026, 53.3301155269146, 71.88509747385979, 18.48103031516075, 0.2580752345966175, 0.18255967501318082, 1.2238747836090624, 0.4489949211711064, 13.98373793810606, 17.041089981794357, 4.329178472980857, 1.3603981328196824, 0.3648027795134112, 17.415060214698315, 90.75509771704674, 72.22327172756195, 80.53210347890854, 76.3454881310463, 80.62983423471451, 80.99233478307724, 78.23115214705467, 75.19082888960838, 77.84051030874252, 69.93782356381416, 74.21226739883423, 76.01424470543861, 82.51201003789902, 67.34646141529083, 75.24414762854576, 78.22032272815704, 75.49979031085968, 67.2714002430439, 65.5701707303524, 69.97754663228989, 69.73192021250725, 69.78792920708656, 64.76018339395523, 59.48395371437073, 54.99471880495548, 54.87844504415989, 55.54079130291939, 57.08454206585884, 55.26033215224743, 59.88968074321747, 64.14555877447128, 69.45265799760818, 65.5958953499794, 69.11826074123383, 66.55998721718788, 67.8665243089199, 69.18455958366394, 72.91131600737572, 68.67588847875595, 75.76964423060417, 36.547024101018906, 63.035854920744896, 75.46271950006485, 70.56526869535446, 67.78807371854782, 65.09686812758446, 64.98935669660568, 66.44644170999527, 66.11809372901917, 68.53721112012863, 64.45407181978226, 63.85051220655441, 58.20867374539375, 56.18422217667103, 51.49375006556511, 53.566386848688126, 52.823036536574364, 51.18358410894871, 49.61478888988495, 53.3257457613945, 52.57393330335617, 53.83171521127224, 56.34512074291706, 55.44517323374748, 52.287500873208046, 54.972622990608215, 55.407205671072006, 60.81183046102524, 63.51826183497906, 67.16495275497437, 67.02192083001137, 69.75805521011353, 67.8016921877861, 70.19427940249443, 62.52170450985432, 67.55297273397446, 64.59756731987, 70.43919146060944, 62.769671604037285, 65.23332640528679, 61.52886338531971, 66.21518611907959, 64.89600330591202, 70.45865401625633, 61.75466626882553, 75.18211215734482, 9.066379051655531, 0.3924448712496087, 0.40794346772599965, 11.178400721400976, 7.388436589390039, 0.9120715304743499, 0.37479285907465965, 0.607064925134182, 8.73830085620284, 50.6677807867527, 69.3207822740078, 31.371536515653133, 47.46760010719299, 72.16359212994576, 11.557374335825443, 0.8512364979833364, 0.28712696162983775, 0.17024002358084545, 0.1449261381640099, 0.17674123722827062, 0.132288743625395, 0.31561053008772433, 0.1130608179664705, 0.09406518453033641, 0.16487349435919896, 0.12302768314839341, 0.13786728959530592, 0.2505593269597739, 0.14112120639765635, 0.18189827300375327, 0.11886951135238633, 0.17265979608055204, 0.30189163342583925, 0.18206353444838896, 0.09164276998490095, 0.1252885692520067, 0.15784540039021522, 0.18731492687948048, 0.19084616942564026, 0.12935019505675882, 0.1486165268579498], [0.03623893375333864, 0.025104429078055546, 0.045413938496494666, 0.02538515571359312, 0.016010962244763505, 0.06434633352910168, 0.02359368729230482, 0.021761551033705473, 0.056866312443162315, 0.0462492999213282, 0.02584761390608037, 0.055150582047645, 0.10717963901697658, 0.048042848211480305, 0.03676660075143445, 0.017399335010850336, 0.0299776230531279, 0.07900931625044905, 0.09349247658974491, 0.024629825638839975, 0.06480859505245462, 0.04535755011602305, 0.050789982051355764, 0.006424203302231035, 0.09091611093026586, 0.06862753114546649, 0.003856418261420913, 0.05777279016911052, 0.18250258901389316, 0.05910247389692813, 0.16561202035518363, 0.1909525934024714, 0.5615384399425238, 15.207020547240973, 58.83724741637707, 48.38796392083168, 39.33634802699089, 51.406529545784, 52.70976461470127, 3.831984889693558, 0.2983075944939628, 0.2687216695630923, 0.21317740785889328, 0.4815003660041839, 2.1805227315053344, 5.120131680741906, 1.6863883403129876, 0.2675616630585864, 0.3194365091621876, 24.491340704262257, 86.02112174034119, 57.64587074518204, 74.19970527291298, 74.20902237296104, 78.73439714312553, 74.5811516046524, 77.31496050953865, 68.92252564430237, 69.86180484294891, 72.87935212254524, 77.6304043829441, 76.58125787973404, 73.24617683887482, 71.15241318941116, 68.86121213436127, 71.89794078469276, 69.05120953917503, 61.40797287225723, 62.63424687087536, 59.82805944979191, 58.78253415226936, 59.023369029164314, 51.88594602048397, 50.28610646724701, 53.00409682095051, 50.885284915566444, 50.787998735904694, 50.83396486938, 55.22310175001621, 61.23217150568962, 68.96389782428741, 64.16093274950981, 67.22084775567055, 66.09293907880783, 63.59822854399681, 64.43709433078766, 68.46900478005409, 64.33421865105629, 64.18351873755455, 38.152950927615166, 54.70417879521847, 72.79169842600822, 64.40104946494102, 65.37580356001854, 64.35409158468246, 65.42212307453156, 66.58530905842781, 66.02300003170967, 64.88309919834137, 65.35358235239983, 61.45430378615856, 55.2206052839756, 47.593673542141914, 49.83867667615414, 47.41791397333145, 51.15847885608673, 46.0940346121788, 48.58688324689865, 49.27189148962498, 58.73344078660011, 64.0831509232521, 66.23763531446457, 60.416408479213715, 54.74507600069046, 53.97878251969814, 52.56868578493595, 53.55843007564545, 58.60181584954262, 62.839002683758736, 61.06336176395416, 63.44225071370602, 64.98984307050705, 65.81385165452957, 65.0445905327797, 65.12238755822182, 64.98151391744614, 65.27864277362823, 68.91592159867287, 60.40414273738861, 59.53080900013447, 60.8702789247036, 67.25361719727516, 58.18521000444889, 76.81176871061325, 16.57358966767788, 0.1268532095127739, 0.23898296611150727, 0.6273332750424743, 0.8774295018520206, 0.22174642304889858, 0.13018653611652553, 0.19145484926411882, 6.1177790723741055, 27.04897776246071, 62.798166275024414, 19.110350646078587, 26.403331607580185, 52.959973588585854, 27.698366716504097, 0.37429612479172647, 0.1866076304577291, 0.03573731242795475, 0.0823097508691717, 0.03940424554457422, 0.05973258324956987, 0.00868974962941138, 0.08288361656013876, 0.05241343751549721, 0.02936517310445197, 0.04667606823204551, 0.041875860770232975, 0.014179464233166073, 0.006532607421831926, 0.031779516793903895, 0.058373020656290464, 0.016473438990942668, 0.05831801638123579, 0.09655712347012013, 0.04793434251041617, 0.10786858212668449, 0.046696788995177485, 0.08369296570890583, 0.05846443098562304, 0.02006583265028894, 0.04300619249988813, 0.003340330390528834, 0.007992427672434133, 0.02391269019426545, 0.009134386073128553, 0.014428039175982121, 0.09026434199768119, 0.03882004544720985, 0.04233494961226825, 0.03357104644237552, 0.014233241181500489, 0.048713352662161924, 0.020561180972435977, 0.03135124563414138, 0.04261757429048885, 0.06180441465403419, 0.04683943720010575, 0.03499933562125079, 0.07878765900386497, 0.065229370520683, 0.03433252335526049, 0.0679849945299793, 0.061269084981177, 0.04693446549936198, 0.038028385388315655, 0.029643567540915683, 0.047351470857393, 0.04764379540574737, 0.06946675915969536, 0.04654710523027461, 0.0645824329694733, 0.04026843198516872, 0.10413779091322795, 0.33033622428774834, 0.3014306409750134, 24.064595103263855, 71.69401332736015, 39.489890187978745, 33.34025837481022, 80.91563209891319, 48.774999752640724, 8.075300082564354, 0.1626420789398253, 0.15458323090570047, 0.22473563061794266, 0.3398889710661024, 0.2937508968170732, 1.867357192095369, 2.539390199817717, 0.6011805846355855, 0.4202016693307087, 34.470944702625275, 90.63617169857025, 64.39278110861778, 77.63088315725327, 75.84660530090332, 81.74081861972809, 77.93159902095795, 78.95143389701843, 69.71238166093826, 72.67383635044098, 76.4431580901146, 81.16853892803192, 76.02905631065369, 70.77975958585739, 70.2231502532959, 72.60423928499222, 75.2840606868267, 70.15116691589355, 62.813962027430534, 64.60411816835403, 63.54674510657787, 63.36717814207077, 61.80721364915371, 53.78885731101036, 51.44947864115238, 53.98890137672424, 52.601333633065224, 53.57342027127743, 55.27566812932491, 58.08707267045975, 64.22229945659637, 71.56409829854965, 66.73627495765686, 67.14056566357613, 66.2732470035553, 65.34689471125603, 64.09553065896034, 70.52802309393883, 65.7011952996254, 64.63875710964203, 38.90950933098793, 55.76248660683632, 73.95902618765831, 66.8206000328064, 67.13930413126945, 64.35065656900406, 65.48538208007812, 66.65779396891594, 65.51130428910255, 66.62358060479164, 66.06827840209007, 63.44377823174, 55.45743137598038, 50.136474296450615, 50.69888971745968, 49.56307366490364, 50.13156495988369, 50.11196941137314, 48.71904395520687, 50.53840532898903, 59.054496958851814, 65.87726265192032, 65.37415444850922, 60.86701110005379, 55.62350146472454, 54.00642603635788, 52.734087109565735, 57.37574703991413, 60.804265066981316, 64.53166365623474, 63.332102224230766, 64.33934837579727, 66.3352444767952, 68.27750265598297, 67.40541145205498, 65.9699472784996, 67.27109625935555, 65.14937371015549, 71.7731174826622, 63.193337470293045, 61.58186674118042, 62.36792676150799, 68.97573798894882, 59.92322534322739, 77.66058996319771, 20.532756820321083, 0.09072534929146059, 0.6314274366013706, 0.5688442010432482, 0.8223420765716583, 0.3161059581907466, 0.432885448099114, 0.5129536532331258, 11.928024496883154, 33.534861132502556, 72.43345364928246, 37.80378386378288, 17.985225319862366, 59.19856242835522, 33.12520131468773, 0.3700711077544838, 0.07868007727665827, 0.03355224784172606, 0.040978674733196385, 0.0668857476557605, 0.061208863407955505, 0.0248838720654021, 0.06768622071831487, 0.04556403786409646, 0.02129780150426086, 0.045671107509406283, 0.023254395928233862, 0.0355891278013587, 0.036650688416557387, 0.026186729010078125, 0.08177961994078942, 0.049265028137597255, 0.05992519283608999, 0.036042654246557504, 0.008962890588009031, 0.01546608855278464, 0.02414062044408638, 0.1047850475879386, 0.08998902005259879, 0.022943536241655238, 0.05481752843479626, 0.06455308845033869, 0.11506762239150703, 0.09518524122540839, 0.24180406238883734, 0.09123045500018634, 0.15344897692557424, 0.10607331205392256, 0.12548841477837414, 0.16072343423729762, 0.14784221450099722, 0.14527105871820822, 0.13228611642261967, 0.14494041708530858, 0.14087879128055647, 0.0930292576958891, 0.12810136831831187, 0.13118098431732506, 0.1742593914968893, 0.16863501048646867, 0.17586237110663205, 0.19440797361312434, 0.10023786424426362, 0.1361790075316094, 0.11074771435232833, 0.20839227712713182, 0.15709681087173522, 0.20179183833533898, 0.1721010627807118, 0.138483643240761, 0.20145663991570473, 0.39523306069895625, 0.24457113031530753, 0.47408292652107775, 0.6493187765590847, 25.901621729135513, 89.26319137215614, 61.703631207346916, 50.846413001418114, 71.28965422511101, 69.89078968763351, 11.016579754650593, 0.3903231304138899, 0.3637171065201983, 0.46581275935750455, 1.25406333245337, 5.599810341373086, 13.207706529647112, 5.327173545956612, 0.30670413456391543, 0.27322796056978405, 30.931662619113922, 94.29071679711342, 71.50834769010544, 79.17887449264526, 79.24869954586029, 86.82627573609352, 80.69512993097305, 84.07154515385628, 75.16467869281769, 76.69950753450394, 79.39973384141922, 83.32575917243958, 78.59000489115715, 72.25352570414543, 73.11211243271828, 74.01786983013153, 77.25221067667007, 73.15630406141281, 67.02192083001137, 67.59950503706932, 65.55093616247177, 63.79240572452545, 64.72710236907005, 55.836255848407745, 54.48963850736618, 58.2806570827961, 57.56508328020573, 58.181003630161285, 59.957130923867226, 63.38425062596798, 68.79197224974632, 76.4216360449791, 69.27500233054161, 72.50199437141418, 70.49194023013115, 68.22368234395981, 67.22275525331497, 70.91947808861732, 69.60198238492012, 66.22047543525696, 42.60786607861519, 56.34577810764313, 77.00709342956543, 68.36818858981133, 71.0465356707573, 69.0397797524929, 69.06626433134079, 69.64650839567184, 70.17686873674393, 68.28925162553787, 70.3830836713314, 65.35498827695847, 59.16804626584053, 53.15213307738304, 53.41961972415447, 51.54396437108517, 54.07089337706566, 50.72676882147789, 54.13229428231716, 53.572276532649994, 64.9138243496418, 71.50836288928986, 72.16069668531418, 64.06064853072166, 60.51735766232014, 56.980974823236465, 56.75389900803566, 60.66414758563042, 64.00851532816887, 66.32726490497589, 65.51800712943077, 67.62947782874107, 70.54072201251984, 71.02119863033295, 69.91003185510635, 66.43075615167618, 70.36894842982292, 67.20851361751556, 75.0091378390789, 65.9958390891552, 65.03514423966408, 65.54061591625214, 71.62108764052391, 61.81347571313381, 80.55984199047089, 18.285392113029957, 0.19686998915858567, 0.5294523085467517, 3.2081654760986567, 3.879647394642234, 1.1102322628721595, 0.4994839697610587, 0.322065107175149, 10.153453219681978, 45.67387975752354, 74.7507593035698, 33.28024059534073, 36.8914832174778, 70.18621623516083, 42.08056837320328, 0.605397408362478, 0.35814562579616904, 0.11074450827436522, 0.12975545221706852, 0.17509304598206654, 0.15789395169122145, 0.10551209998084232, 0.22871097433380783, 0.17798716959077865, 0.08552517989301123, 0.15257423714501783, 0.09482023815508, 0.10635708706104197, 0.06962920786463656, 0.12545863981358707, 0.23874549369793385, 0.13145603908924386, 0.18281350436154753, 0.15218572283629328, 0.17167400132166222, 0.18207732355222106, 0.11246674359426834, 0.5314105690922588, 0.15275316894985735, 0.0914439931511879, 0.14117873768555, 0.11459954985184595], [0.04718505537312012, 0.039517319164588116, 0.03204767701390665, 0.052371673154993914, 0.0386123702628538, 0.04438378557097167, 0.03647045043180697, 0.006238282785488991, 0.006965911734369001, 0.05583104240940884, 0.021477623886312358, 0.031455532225663774, 0.0329743077600142, 0.0885558438312728, 0.10789410458528437, 0.07711735175689682, 0.04308417366701178, 0.06126693646365311, 0.10105297245900147, 0.15337793854996562, 0.011531599138834281, 0.03479893348412588, 0.08454922601231374, 0.025173348622047342, 0.04445372185728047, 0.061759184463880956, 0.04268977412721142, 0.0624417228391394, 0.12229346903041005, 0.04878370455116965, 0.024572938164055813, 0.06003169473842718, 0.09399207556270994, 0.5244315310847014, 33.91753859817982, 54.05020348727703, 41.69941462576389, 28.796308301389217, 65.89629963040352, 58.26803416013718, 6.979741919785738, 0.47607657266780734, 0.09697419562144205, 0.07968049234477803, 0.4964608163572848, 1.1930889543145895, 1.155751207843423, 0.2160036249551922, 0.09711886988952756, 0.35021352174226195, 36.016545966267586, 85.09875163435936, 57.86603473126888, 73.20713773369789, 78.17265048623085, 75.90864837169647, 76.98146760463715, 78.13274502754211, 73.9687992632389, 75.5575168132782, 78.97408828139305, 75.4452708363533, 73.83456766605377, 73.43585506081581, 73.43668341636658, 65.85485145449638, 63.0677580088377, 60.499244034290314, 63.92882600426674, 65.38316756486893, 64.5623280107975, 56.96930184960365, 54.277784675359726, 51.210053488612175, 52.24637188017368, 51.67404659092426, 53.19598272442818, 49.68249745666981, 56.44974432885647, 67.19120934605598, 71.63660600781441, 70.93348413705826, 71.32787257432938, 67.23106920719147, 71.71573296189308, 68.86134892702103, 68.54688540101051, 61.22942425310612, 65.78536838293076, 24.81095675379038, 52.48838469386101, 74.66869130730629, 66.75107896327972, 73.13156738877296, 64.41420435905457, 67.28685781359673, 68.95297721028328, 66.76078364253044, 69.95695933699608, 67.02691376209259, 66.47988751530647, 55.24734824895859, 49.32542681694031, 48.101170510053635, 49.43975128233433, 48.920623138546944, 47.73236230015755, 47.34049312770367, 52.65486516058445, 62.42854490876198, 67.9863166809082, 66.0959105193615, 67.59419292211533, 63.98140758275986, 60.98603591322899, 55.543207973241806, 56.47801861166954, 58.02010886371136, 60.18452972173691, 63.70758667588234, 64.44865331053734, 64.64934334158897, 68.65699589252472, 65.5531932413578, 64.37010392546654, 68.1819149851799, 67.44258105754852, 62.081923708319664, 64.73933011293411, 67.22270205616951, 60.012638345360756, 59.39660020172596, 72.6419560611248, 23.425589092075825, 0.13794264727039263, 0.2534060867037624, 0.018681142792047467, 1.2284701620228589, 0.23170555505203083, 0.10704093903768808, 0.10097506921738386, 8.397391699254513, 20.748579539358616, 64.22555968165398, 34.290625378489494, 20.62655858695507, 44.382017478346825, 49.65215988457203, 2.8365577664226294, 0.14337824075482786, 0.04399306337290909, 0.0082521088552312, 0.07604434722452424, 0.0646542506001424, 0.04305700735130813, 0.054904233547858894, 0.06718774980981834, 0.06889232201501727, 0.05511136325367261, 0.05185802903724834, 0.014819060088484548, 0.028254005483177025, 0.0566859408718301, 0.03865160389977973, 0.05601061988272704, 0.07510317780543119, 0.0275592457910534, 0.0637758149241563, 0.07879320284700952, 0.06776513328077272, 0.05439361368189566, 0.015246876682795119, 0.026776144550240133, 0.03951428378059063, 0.0217366241486161, 0.024853440299921203, 0.03993986836576369, 0.06701318925479427, 0.040339462939300574, 0.048410589806735516, 0.07821785286068916, 0.03201541585440282, 0.04872445519140456, 0.024661524621478748, 0.02590994132333435, 0.08098000776953995, 0.005850474444741849, 0.028981857540202327, 0.03252048816648312, 0.018436877871863544, 0.06925120236701332, 0.03587187864468433, 0.02518391680496279, 0.06963133040699176, 0.04311785975005478, 0.09084017437999137, 0.04181085234449711, 0.05974989013338927, 0.09076308007934131, 0.031545903548249044, 0.040538499524700455, 0.04290287441108376, 0.08300034896819852, 0.052120745604042895, 0.026798273538588546, 0.031211740424623713, 0.02836545194440987, 0.0761490642616991, 0.1088608409918379, 1.3468199176713824, 52.87858195602894, 63.10241974890232, 39.012783989310265, 36.54920898377895, 89.26280379295349, 46.05729818344116, 12.237687930464745, 0.45986907673068345, 0.08335556311067194, 0.06851870261016302, 0.4367710661608726, 1.2528539285995066, 1.6069907695055008, 1.4924087491817772, 1.379396163392812, 0.32394078152719885, 47.399059385061264, 87.28893890976906, 60.639654099941254, 77.11987897753716, 79.62319225072861, 79.04571443796158, 79.31738466024399, 79.34702306985855, 75.62307089567184, 77.765281945467, 81.22257202863693, 73.86071026325226, 73.68672519922256, 77.0365722477436, 72.92199343442917, 67.96021208167076, 65.88518142700195, 64.94044572114944, 67.28209286928177, 67.13529914617538, 66.54503121972084, 57.74620056152344, 54.94991920888424, 54.36576135456562, 54.173210486769676, 55.66050007939339, 54.723360165953636, 51.480720564723015, 58.502511978149414, 68.87501299381256, 72.75031104683876, 74.3028013408184, 71.8119589984417, 70.7045616209507, 71.57576367259026, 69.89622339606285, 68.88201981782913, 62.97228813171387, 67.25500792264938, 29.940238818526268, 53.64702992141247, 75.464908182621, 68.15201058983803, 74.00628805160522, 66.83285057544708, 69.27211448550224, 70.54804041981697, 68.40111762285233, 71.76653623580933, 68.466527312994, 67.21768632531166, 57.59554244577885, 49.881868958473206, 50.709209963679314, 50.2238430082798, 51.31544843316078, 50.64486041665077, 49.344376400113106, 54.11842122673988, 62.970897406339645, 69.38405647873878, 69.75097998976707, 68.27319368720055, 64.79766458272934, 62.32312336564064, 57.790601179003716, 55.84570974111557, 59.844341576099396, 62.87011921405792, 64.54263746738434, 66.56861275434494, 67.42520079016685, 69.74882930517197, 67.7083919942379, 64.43374291062355, 69.55915108323097, 67.8780148923397, 65.01320421695709, 66.29676774144173, 68.13522309064865, 64.59732413291931, 62.015845254063606, 74.19845134019852, 27.459931410849094, 0.18657769222045317, 0.40847739845048636, 0.07799076309311204, 1.2631457950919867, 0.022506628338305745, 0.045548560374299996, 0.20319765899330378, 15.572495386004448, 26.492539420723915, 55.85929021239281, 44.23697926104069, 12.120411023497581, 44.449710845947266, 56.93552166223526, 4.453204767778516, 0.2823554864153266, 0.20531929592834786, 0.032700492374715395, 0.08091890675132163, 0.1003252224472817, 0.07877236334024929, 0.03475738063571043, 0.04045737165142782, 0.03635196655523032, 0.027575615713431034, 0.05955472013738472, 0.0666970046586357, 0.08389647744479589, 0.09942891585524194, 0.0201215697961743, 0.043603877420537174, 0.0300858040645835, 0.04194072818791028, 0.04283012909581885, 0.030203723908925895, 0.015619401419826318, 0.022676190528727602, 0.051759512643911876, 0.06072801479604095, 0.006195831938384799, 0.039475269077229314, 0.05949322207015939, 0.14969724230468273, 0.11904036859050393, 0.12334418686805293, 0.20955477724783123, 0.18345249351114035, 0.26265835273079574, 0.11559580147149973, 0.10629729964421131, 0.21441154007334262, 0.22777091071475297, 0.10618507207254879, 0.11627544547081925, 0.1303367764921859, 0.1894392800750211, 0.16808779531857, 0.1727179656154476, 0.10345650676754303, 0.1860747832688503, 0.2858505863696337, 0.1727132307132706, 0.13761010573944077, 0.2475306816631928, 0.11551861811312847, 0.14772896276554093, 0.17867517017293721, 0.16444466658867896, 0.1382450872915797, 0.1860516134183854, 0.21399179619038478, 0.13239335676189512, 0.0798152812058106, 0.10259323316859081, 0.1673228043364361, 1.2410854850895703, 61.10190309584141, 83.47509875893593, 50.981731340289116, 44.840082898736, 80.1871807873249, 75.87138757109642, 16.061417050659657, 0.7235433999449015, 0.1415569955133833, 0.1432364311767742, 1.2859123921953142, 7.318375948816538, 5.041682040318847, 1.0887421597726643, 0.9473424847237766, 0.4984071431681514, 40.70785403251648, 91.99561715126038, 67.32393622398376, 78.80777880549431, 80.34162729978561, 84.33690011501312, 81.56199261546135, 84.0316016972065, 80.33082067966461, 81.20328426361084, 83.06103497743607, 73.41788202524185, 75.27338325977325, 80.17926961183548, 78.3856974542141, 72.19889983534813, 69.85609754920006, 67.82777398824692, 70.09912490844727, 73.34395319223404, 71.48237988352776, 61.35008677840233, 60.85240088403225, 56.55363455414772, 57.15667739510536, 57.097047194838524, 58.54121670126915, 53.580518290400505, 63.75802516937256, 74.24888983368874, 76.44730746746063, 79.53131318092346, 76.81493774056435, 72.11709022521973, 75.59483081102371, 74.00072515010834, 71.70392319560051, 65.11354923248291, 71.30913197994232, 31.05425164103508, 56.452510580420494, 77.60680004954338, 70.10282590985298, 78.03156405687332, 69.3028624355793, 72.22248136997223, 73.32266673445702, 68.97042587399483, 75.23679882287979, 73.53873074054718, 71.66080310940742, 63.47062759101391, 54.25761915743351, 53.35610993206501, 53.34902711212635, 54.00791935622692, 52.7596977353096, 52.16908022761345, 55.56920997798443, 65.40533557534218, 73.77063989639282, 72.42236584424973, 71.99560314416885, 69.71873492002487, 68.35543647408485, 61.48061357438564, 60.091803297400475, 62.879861891269684, 65.44580340385437, 70.07413744926453, 69.59317445755005, 68.99799719452858, 72.6904034614563, 69.98507782816887, 67.67224073410034, 71.22794553637505, 67.6957006752491, 65.18148198723793, 71.0281066596508, 71.63544327020645, 66.40438556671143, 63.68243582546711, 75.62382325530052, 25.59266220778227, 0.38660871097818017, 0.8545059850439429, 0.3755541244754568, 4.924540976062417, 0.5493931041564792, 0.19415522780036554, 0.22438990854425356, 13.79328265786171, 36.31049819290638, 78.22375014424324, 48.246296122670174, 30.683097057044506, 56.20856747031212, 68.59644994139671, 5.800858978182077, 0.5597670224960893, 0.2198280455195345, 0.29124104243237525, 0.29608987912070006, 0.2060926434933208, 0.17697726987535134, 0.20303811208577827, 0.09508422008366324, 0.1129590324126184, 0.12302242132136598, 0.16438425576779991, 0.2623211801983416, 0.11747037002351135, 0.16382213827455416, 0.10614696278935298, 0.1505880124750547, 0.13447337405523285, 0.10645637899870053, 0.15541222470346838, 0.1087209906836506, 0.11083361794590019, 0.20815145020605996, 0.13047830405412242, 0.11004193191183731, 0.12870991457020864, 0.16004908917238936, 0.09742629714310169], [0.03981214846135117, 0.051328380504855886, 0.02827739983331412, 0.03903807359165512, 0.05485121080710087, 0.03909982769982889, 0.02472595046128845, 0.06326824528514408, 0.041626387828728184, 0.01796951222786447, 0.035504971965565346, 0.10606308525893837, 0.07590604058350436, 0.03217323355784174, 0.04401339821924921, 0.05196839010750409, 0.03719404812727589, 0.025443568301852793, 0.034707875674939714, 0.03210979477444198, 0.04009273965493776, 0.04985714695067145, 0.0637571350671351, 0.050173917843494564, 0.01284677573494264, 0.008946832367655588, 0.07275474054040387, 0.13392835564445704, 0.06687997374683619, 0.024361750765820034, 0.06462920311605558, 0.019875419820891693, 0.05906001562834717, 0.19474798114970326, 1.6436149855144322, 46.16993933916092, 44.11962255835533, 25.937639996409416, 24.13305602967739, 61.88450910151005, 67.81434550881386, 18.61146781593561, 1.7793365777470171, 0.060408612989704125, 0.10648815776221454, 0.24270134861581028, 1.519746738485992, 2.5946394726634026, 0.6772900850046426, 0.16709870542399585, 0.6951164721976966, 43.325529769062996, 86.35698571801186, 62.70903825759888, 68.44581082463264, 80.36871984601021, 78.62352669239044, 76.5041296184063, 79.41560178995132, 79.98999416828156, 77.80230715870857, 74.49260875582695, 77.58713230490685, 72.3173850774765, 74.45515036582947, 68.09746071696281, 64.30534020066261, 63.042398169636726, 60.465596839785576, 60.175729393959045, 57.70997330546379, 55.046696215867996, 54.29722063243389, 51.29457235336304, 57.113006338477135, 55.20783416926861, 55.173617005348206, 50.88066816329956, 56.75488315522671, 67.28586986660957, 71.52739986777306, 69.27944049239159, 68.23395699262619, 69.5276203751564, 71.52142658829689, 67.9500362277031, 67.00672924518585, 47.527944669127464, 52.75781683623791, 27.991163805127144, 52.06888720393181, 72.46571391820908, 68.49754124879837, 59.89388711750507, 62.16809928417206, 71.35351359844208, 67.28334680199623, 70.62570065259933, 64.42347586154938, 66.58216282725334, 56.43511511385441, 47.372605204582214, 50.01053765416145, 50.31545989215374, 50.96859164535999, 50.9831752628088, 50.31143210828304, 52.873801812529564, 55.791099071502686, 63.9156711101532, 71.10363900661469, 71.79983004927635, 68.82258340716362, 70.05328416824341, 66.42986699938774, 59.05316703021526, 58.15157040953636, 59.378957748413086, 60.16084559261799, 61.44076131284237, 65.44758930802345, 68.83801817893982, 70.508271753788, 68.35772395133972, 68.45211088657379, 64.5580418407917, 67.47167229652405, 71.16473212838173, 64.09389674663544, 59.810819774866104, 73.30467849969864, 70.03825217485428, 24.40692823380232, 0.6072346691507846, 0.07854703988414258, 0.10014891042374074, 0.21825586503837258, 0.4056679835775867, 0.19461295480141416, 0.07160056731663644, 10.092885419726372, 23.38528085500002, 57.894077226519585, 50.51573574542999, 92.64552667737007, 47.93959178030491, 56.43251985311508, 12.408009991049767, 0.26578709890600294, 0.10851474784431048, 0.0849041432957165, 0.033238798059755936, 0.01285414989979472, 0.10325983763323165, 0.02533655431761872, 0.06719999524648301, 0.02524789364542812, 0.04286108407541178, 0.04813159423065372, 0.023538159803138115, 0.0673292031569872, 0.03644104283011984, 0.05592753273958806, 0.061942131287651137, 0.022599354124395177, 0.09552949384669773, 0.012590506576088956, 0.061646307513001375, 0.018126187023881357, 0.024383417767239735, 0.017493170307716355, 0.10078817416797392, 0.03235747914004605, 0.02657553275639657, 0.0367661925702123, 0.02385196024988545, 0.029783391873934306, 0.07222798638395034, 0.04458797637198586, 0.014690248299302766, 0.09235907607944682, 0.03772600473894272, 0.09457515872782096, 0.07426011288771406, 0.012885512132925214, 0.060615004258579575, 0.006514659971799119, 0.02714903479500208, 0.031091705459402874, 0.05302197634591721, 0.02481220286426833, 0.06308884592726827, 0.044155760697321966, 0.05146869094460271, 0.014121741842245683, 0.012060192893841304, 0.06453846071963198, 0.014393774217751343, 0.058814446383621544, 0.05088329970021732, 0.020669959412771277, 0.020453751385502983, 0.08284588577225804, 0.07009805965935811, 0.05301107419654727, 0.05841554200742394, 0.0358482931915205, 0.07645809455425479, 0.013025305852352176, 0.2090266501181759, 5.567089347168803, 64.56003293395042, 47.403664737939835, 24.25250642001629, 43.554832264781, 95.54391995072365, 60.37288561463356, 19.21488493680954, 2.832240960560739, 0.1450513384770602, 0.11591046466492116, 0.5095882213208824, 0.9258346888236701, 0.46637619787361473, 1.2090361048467457, 0.8876720897387713, 1.3835802138783038, 57.916055247187614, 89.03906419873238, 63.91925811767578, 73.78538310527802, 82.37081721425056, 80.34320801496506, 78.97042527794838, 80.63723623752594, 80.73356866836548, 79.74284023046494, 74.53035593032837, 77.42240354418755, 72.8300079703331, 75.99764719605446, 72.11378440260887, 67.27042749524117, 63.39812748134136, 62.63203538954258, 63.00726905465126, 61.95559948682785, 59.120997190475464, 56.63922116160393, 54.41684581339359, 58.85390192270279, 54.84585039317608, 57.648655995726585, 52.93011099100113, 61.07244707643986, 69.88857060670853, 73.63948613405228, 72.50250354409218, 68.59531000256538, 71.14731386303902, 72.86178186535835, 67.5693042576313, 68.38838830590248, 52.25790046155453, 55.87247170507908, 27.393389381468296, 52.86652900278568, 73.4784583747387, 72.55107253789902, 63.82386803627014, 62.87662446498871, 70.63512414693832, 67.97985702753067, 69.43005681037903, 67.13030621409416, 68.0757562816143, 63.23621056973934, 50.159653052687645, 52.13666036725044, 50.72474353015423, 50.85218109190464, 50.65863087773323, 51.806294694542885, 53.357854038476944, 57.227760180830956, 65.5896408855915, 72.42094472050667, 71.64852976799011, 70.21067932248116, 70.32291010022163, 66.04742512106895, 59.20391634106636, 58.22711795568466, 61.38241544365883, 62.19837985932827, 64.77750286459923, 67.10448279976845, 70.51755085587502, 71.74810722470284, 68.50869745016098, 67.46474906802177, 67.26933315396309, 64.71953317523003, 69.418885409832, 66.39845788478851, 62.417153120040894, 71.6323958337307, 73.87380436062813, 31.6220323741436, 0.5742795125115663, 0.3126680926652625, 0.28270005073864013, 0.5867445655167103, 0.2618854207685217, 0.06885007154778577, 0.07851834103348665, 19.68340739607811, 23.975480385124683, 53.63495796918869, 71.08980774879456, 80.26522859930992, 40.65809190273285, 60.37589505314827, 19.495342187583447, 0.47860563383437693, 0.22055843757698312, 0.08051008728216402, 0.06815243046730757, 0.010145290470973123, 0.1127469414495863, 0.027226479760429356, 0.06127245433162898, 0.02342313247936545, 0.013651417812070576, 0.014181896622176282, 0.02365360087424051, 0.005519827245734632, 0.10283462412189692, 0.03902484480931889, 0.018343786578043364, 0.017448120088374708, 0.07684671276365407, 0.0350312257069163, 0.06864284907351248, 0.007981752805790165, 0.02120988669048529, 0.05107217999466229, 0.06505480254418217, 0.07057365015498362, 0.01894142696983181, 0.01364784715406131, 0.017859726322058123, 0.1282866974361241, 0.18657320964848623, 0.08656749661895446, 0.09603710059309378, 0.110789927712176, 0.14404489716980606, 0.22883681289386004, 0.1192176973563619, 0.14900697075063363, 0.08860468456987292, 0.09158953573205508, 0.19038629019632936, 0.1135440896905493, 0.14888185949530452, 0.14073997997911647, 0.11819315506727435, 0.17674097005510703, 0.17037221492500976, 0.10106288755196147, 0.15112552035134286, 0.10627988885971718, 0.13800215267110616, 0.11548919195774943, 0.13815420388709754, 0.23811828985344619, 0.10096546582644805, 0.29625252820551395, 0.18968659336678684, 0.14310214697616175, 0.10609703109366819, 0.21231023798463866, 0.1475573336938396, 0.1399501715786755, 0.21720039745559916, 4.640113413333893, 77.70521476864815, 67.17834323644638, 36.86772309243679, 44.94566023349762, 74.59208741784096, 86.48066908121109, 30.858953520655632, 3.5599375376477838, 0.2862782118609175, 0.12933925580000505, 0.8249199413694441, 6.055951165035367, 8.018604274839163, 1.6900066961534321, 0.46176496718544513, 1.677291034720838, 52.47458003461361, 91.07038959860802, 70.44330283999443, 73.57172816991806, 82.54587382078171, 85.01198709011078, 85.54394334554672, 83.70639994740486, 83.91398280858994, 78.84937137365341, 73.72574150562286, 78.68889838457108, 77.2584879398346, 79.6265360713005, 73.32301631569862, 71.72777831554413, 68.04141372442245, 67.23498299717903, 67.5332061946392, 62.855508998036385, 60.67835122346878, 59.06623832881451, 56.797387674450874, 61.97391450405121, 60.48351667821407, 63.72157372534275, 59.103350937366486, 64.17237013578415, 74.85466092824936, 80.11031091213226, 73.7719090282917, 69.74378317594528, 73.06568652391434, 73.67863923311234, 68.68231773376465, 68.23495253920555, 56.36006534099579, 58.135751858353615, 34.77831020951271, 55.068887025117874, 72.11925610899925, 72.45420813560486, 63.78017798066139, 68.37960317730904, 71.93254172801971, 71.49177297949791, 73.60070541501045, 66.6311725974083, 70.88762819766998, 64.43182781338692, 50.396973118186, 55.49350284039974, 52.96309322118759, 53.405378088355064, 54.241477623581886, 55.095041021704674, 57.58531339466572, 60.359985306859016, 70.35151496529579, 78.34234178066254, 75.59546157717705, 71.45722523331642, 72.27634727954865, 68.37421506643295, 61.98537848889828, 63.2284589856863, 64.74685370922089, 64.5972329378128, 65.30680686235428, 69.24014300107956, 73.38930755853653, 74.63238045573235, 71.1828875541687, 69.22520220279694, 67.85420536994934, 68.32689240574837, 71.33237153291702, 67.03960508108139, 63.45704711973667, 75.59714868664742, 72.40019783377647, 28.9874779433012, 1.0895968764089048, 0.32034323550760746, 0.35248372179921716, 3.2403015391901135, 1.0376368020661175, 0.24391946528339759, 0.10574088926659897, 18.322084844112396, 37.45050922036171, 71.70079976320267, 68.27791303396225, 96.55629962682724, 55.48191346228123, 75.53776547312737, 22.5679637119174, 0.5859391868580133, 0.29216516471933573, 0.21908365655690432, 0.19652281247545034, 0.09030303757754155, 0.21994998038280755, 0.10419026075396687, 0.17266542155994102, 0.0983557925792411, 0.08554104701033793, 0.14693982229800895, 0.15300943254260346, 0.16211833048146218, 0.20954627223545685, 0.21630993898725137, 0.1723349283565767, 0.10612063138978556, 0.15449268888914958, 0.1235014850681182, 0.17666852159891278, 0.07723890812485479, 0.12661260523600504, 0.17958709155209363, 0.21099985751789063, 0.179449348943308, 0.09839823600486852, 0.11545673783984967, 0.1164842264552135], [0.0561676991492277, 0.042915435260511, 0.011877950182679342, 0.05897555922274478, 0.0025903238338287338, 0.048559590795775875, 0.03160846288665198, 0.02847372757969424, 0.01938398818310816, 0.04121881887840573, 0.038558887390536256, 0.04756698683195282, 0.053375780407804996, 0.043501078835106455, 0.006206560610735323, 0.046111056362860836, 0.04757135808176827, 0.05931011197390035, 0.11100632313173264, 0.0929859904863406, 0.05200044717639685, 0.04561879351967946, 0.022254147843341343, 0.06253752668271773, 0.0037138827701710397, 0.06319608626654372, 0.053597604637616314, 0.05107183489599265, 0.016837111761560664, 0.017922641891345847, 0.0792554569488857, 0.022449321550084278, 0.13147488964023069, 0.043706609212676995, 0.09443095943424851, 2.7269999077543616, 57.487373650074005, 49.989220798015594, 30.401205383241177, 21.226329803466797, 56.90293841063976, 88.80451798439026, 34.70636107027531, 4.4531135726720095, 0.4404414020245895, 0.16698779887519777, 0.34861371852457523, 1.5087791020050645, 1.0101358965039253, 0.9864030231256038, 0.15004900546045974, 0.6415105517953634, 30.940008871257305, 82.08073318004608, 74.18464288115501, 61.8071224540472, 77.96167060732841, 83.45284715294838, 80.09529411792755, 73.29775527119637, 76.13698571920395, 77.17736229300499, 78.87692749500275, 75.57727575302124, 74.18950662016869, 65.56863561272621, 60.680722296237946, 62.28066444396973, 64.97386872768402, 60.97849331796169, 59.493848383426666, 53.58829267323017, 54.044857174158096, 56.10613636672497, 60.252090096473694, 60.46774372458458, 60.10009445250034, 52.110654562711716, 54.52331230044365, 67.68208980560303, 72.55601987242699, 71.65258795022964, 71.9338184595108, 73.96990120410919, 67.02968001365662, 67.68151983618736, 60.046817511320114, 52.72472821176052, 81.61952912807465, 25.4808247089386, 51.35144770145416, 76.24467194080353, 59.92471866309643, 66.60179257392883, 72.73956522345543, 70.77372550964355, 69.97968971729279, 67.30352371931076, 67.97317698597908, 59.32216599583626, 51.279316172003746, 51.85440011322498, 51.249130591750145, 53.25950011610985, 52.89216622710228, 53.3255747705698, 52.5491738319397, 53.25509615242481, 55.838991701602936, 65.45156389474869, 68.47025111317635, 70.10234713554382, 71.52908697724342, 72.2393448650837, 70.6741252541542, 66.05867251753807, 63.59045796096325, 60.81571005284786, 62.88306511938572, 68.6545792222023, 68.06626439094543, 71.39773562550545, 70.345009714365, 68.33280488848686, 66.66152536869049, 71.10911071300507, 69.4271157681942, 62.762630581855774, 73.55721294879913, 75.71998849511147, 61.13348700106144, 15.897559393197298, 0.1855686682392843, 0.07148680349928327, 0.10225079880910926, 0.40514750056900084, 0.44066609465517104, 0.06088200672820676, 0.4607144423061982, 13.798638470470905, 25.67189935594797, 71.50811970233917, 32.04133987426758, 17.276888228952885, 37.320275008678436, 51.192749217152596, 29.6861407533288, 0.14483901002677158, 0.2010890541714616, 0.03477937789284624, 0.04913686294457875, 0.06036719001713209, 0.04156890106969513, 0.12335042090853676, 0.06303413480054587, 0.028719499059661757, 0.08634861500468105, 0.05385826916608494, 0.045319284981815144, 0.016896567067306023, 0.04082598527020309, 0.032564723878749646, 0.02562169116572477, 0.06927302150870673, 0.08082927015493624, 0.053878622566116974, 0.02603585038741585, 0.09593553768354468, 0.1604791934369132, 0.030018699071661104, 0.045493544967030175, 0.06349902352667414, 0.022423476257245056, 0.003633160526987922, 0.04832556936889887, 0.04984095328836702, 0.06912915618158877, 0.03625200297392439, 0.07947439051349647, 0.018595151996123604, 0.04435663409822155, 0.02567663977970369, 0.011733390019799117, 0.004543105706034112, 0.044269450299907476, 0.06165449340187479, 0.045803343382431194, 0.028259907412575558, 0.070146685175132, 0.02663752620719606, 0.0018345695752941538, 0.015427122089022305, 0.01012455579257221, 0.023198638373287395, 0.061380863553495146, 0.09452781712752767, 0.03681950103782583, 0.042737713156384416, 0.05193739430978894, 0.045930484411655925, 0.041519926744513214, 0.02144340531231137, 0.036050216731382534, 0.04865837065153755, 0.05019131378503516, 0.051685687503777444, 0.02840982866473496, 0.06455236114561558, 0.01910136536025675, 0.04005805909400806, 0.1919821897172369, 9.33507688343525, 72.31861621141434, 44.90600936114788, 22.709183134138584, 31.81717660278082, 91.79361999034882, 85.4056079685688, 34.91525486111641, 9.378464855253696, 0.4949940653750673, 0.17332781804725528, 0.4208642290905118, 1.1359609197825193, 0.46635705046355724, 1.210966045036912, 0.4997073265258223, 0.981579894432798, 42.31121599674225, 89.8882882297039, 72.66701191663742, 64.04924914240837, 80.66970929503441, 82.618328332901, 80.87553665041924, 72.88623735308647, 75.4054793715477, 77.63868793845177, 80.57656869292259, 79.24052238464355, 74.81479346752167, 66.46805495023727, 63.39164882898331, 67.45312169194221, 68.38553085923195, 63.38580094277859, 61.54083274304867, 55.55618807673454, 57.435073256492615, 56.703669503331184, 61.04738362133503, 62.7423282712698, 60.737875029444695, 54.98507872223854, 57.780945897102356, 69.32806268334389, 74.52192038297653, 72.55668103694916, 76.21619626879692, 71.3337242603302, 67.81683057546616, 67.81986281275749, 62.0382222533226, 53.181307911872864, 76.29667595028877, 30.45132089406252, 52.73999959230423, 75.61598807573318, 60.72593227028847, 65.48873350024223, 72.82514423131943, 71.67550072073936, 72.67430752515793, 72.13389292359352, 67.47847393155098, 62.61604584753513, 52.42095351219177, 52.86241762340069, 53.41402642428875, 56.4026952534914, 53.78296382725239, 56.01683735847473, 54.1365272551775, 54.237609431147575, 58.67933169007301, 67.54962891340256, 69.03680831193924, 72.48323857784271, 72.00286075472832, 73.30142587423325, 71.9128891825676, 67.08724692463875, 63.231179639697075, 62.93625466525555, 64.40211340785027, 68.52718725800514, 70.29810503125191, 72.7488823235035, 70.78381776809692, 69.59728583693504, 68.066066801548, 68.86919930577278, 71.53103247284889, 65.32995522022247, 72.05475836992264, 74.27888542413712, 68.7703438103199, 20.000794865190983, 0.2675431687384844, 0.18801495025400072, 0.12259114446351305, 0.42664600478019565, 0.08642944230814464, 0.09822320789680816, 0.45590544410515577, 21.6727127507329, 24.07129604369402, 68.80470916628838, 47.63871632516384, 21.71122558414936, 49.37707744538784, 54.12678837776184, 41.68906018137932, 0.2318595358519815, 0.1957608197699301, 0.02848809184797574, 0.052502257749438286, 0.1061440164630767, 0.08565833602915518, 0.055868198032840155, 0.04136107374506537, 0.011691108938975958, 0.04044707806315273, 0.04669891895900946, 0.011339107368257828, 0.018268165440531448, 0.04430956338183023, 0.051397671122686006, 0.076080742146587, 0.0516946823336184, 0.08723591934540309, 0.05336766131222248, 0.03537671029334888, 0.06421390469768085, 0.050231571585754864, 0.06659981299890205, 0.019056370801990852, 0.06708016066113487, 0.023648077440157067, 0.03939657915907446, 0.020586807331710588, 0.020279543350625318, 0.27379083505366, 0.11916053714230657, 0.13629035936901346, 0.20413493213709444, 0.10361721142544411, 0.14594253909308463, 0.13083912141155452, 0.06043148969183676, 0.14420466672163457, 0.14920402580173686, 0.10019762499723583, 0.13409701612545177, 0.14201712707290426, 0.16880663955817, 0.14065561263123527, 0.11029943489120342, 0.08038399639190175, 0.16168058209586889, 0.1831391142331995, 0.21990598586853594, 0.0785600274684839, 0.2774602803401649, 0.13506841321941465, 0.12209443986648694, 0.12122782660298981, 0.17644776235101745, 0.16022162366425619, 0.1184429471322801, 0.08422507075010799, 0.12860730523243546, 0.23070205264957622, 0.12223797122715041, 0.2139794171671383, 0.19382054888410494, 0.2232682562316768, 8.220296502113342, 90.72915270924568, 65.37223935127258, 42.00061306357384, 39.185317531228065, 74.17017325758934, 104.36522260308266, 49.4776276499033, 9.91644473746419, 0.48679766769055277, 0.3577367024263367, 0.8023480838164687, 4.794343812391162, 7.9894921369850636, 2.7514021983370185, 0.41158111940603703, 1.138951478060335, 37.110302075743675, 90.58947220444679, 79.42291259765625, 67.08713293075562, 78.18911880254745, 84.41700741648674, 83.26662674546242, 71.24094843864441, 72.78573274612427, 78.78330051898956, 82.01567307114601, 82.94004946947098, 79.71951708197594, 71.9897210597992, 65.39548650383949, 70.51710247993469, 72.1788065135479, 66.8402373790741, 65.16774192452431, 60.171921998262405, 61.199820041656494, 61.309873536229134, 66.86378091573715, 66.03327468037605, 63.51943597197533, 57.20614314079285, 61.62514641880989, 75.14069437980652, 79.96342599391937, 78.17350924015045, 79.19192299246788, 75.44396370649338, 68.34781408309937, 69.43008720874786, 64.28264781832695, 59.30451974272728, 81.76108673214912, 31.954104155302048, 53.66543233394623, 79.57997336983681, 64.62807208299637, 71.08609154820442, 74.42105859518051, 75.62009945511818, 76.92956998944283, 72.99032896757126, 73.41455340385437, 65.11685505509377, 54.36426803469658, 58.8172110915184, 57.50053994357586, 59.842137694358826, 57.89574533700943, 61.07417218387127, 57.99349509179592, 58.49580153822899, 62.09516599774361, 71.6196209192276, 71.45414739847183, 74.78207722306252, 75.055350959301, 77.62060090899467, 79.40096497535706, 72.24671646952629, 67.14058846235275, 67.45810702443123, 67.87992238998413, 73.79739046096802, 75.66304475069046, 76.01029291749, 72.32461988925934, 71.52081102132797, 69.19234916567802, 69.20437172055244, 68.79790753126144, 66.36921465396881, 74.2012631893158, 74.12768393754959, 66.56913712620735, 18.18391665816307, 0.23470798769267276, 0.30597083328757435, 0.3351825673598796, 1.765771305654198, 0.92943832045421, 0.2120461521553807, 0.5888792197220027, 25.664459355175495, 39.38783146440983, 81.57760217785835, 45.39179049432278, 26.39065358787775, 51.52364306151867, 62.217781618237495, 49.752520099282265, 0.4114685207605362, 0.4116594011429697, 0.1934662030544132, 0.11704612872563303, 0.24445866525638849, 0.12710147275356576, 0.18606192927109078, 0.14098181622102857, 0.12978841841686517, 0.17242371890461072, 0.15314723452320322, 0.15449159051058814, 0.15059878845931962, 0.11458747510914691, 0.22675655811326578, 0.17208964854944497, 0.18771237664623186, 0.1733699275064282, 0.187047234212514, 0.09647142025642097, 0.16995475685689598, 0.20602669625077397, 0.18839890777599066, 0.12454122654162347, 0.21479701157659292, 0.07334045090829022, 0.13210434961365536, 0.20313564513344318, 0.11726829805411398], [0.08795437766821124, 0.04743714067444671, 0.019031482879654504, 0.009177117080980679, 0.04702870712208096, 0.06009192373312544, 0.04145656217588112, 0.05191492207814008, 0.04950541719153989, 0.13695462606847286, 0.04836586056626402, 0.03513583884341642, 0.01414248023138498, 0.14742125349584967, 0.014844947127130581, 0.020799957710551098, 0.053870603660470806, 0.029636155340995174, 0.1047766613191925, 0.043479578816914, 0.09166596952127293, 0.04720816956250928, 0.02024346569669433, 0.08545918070012704, 0.05179377389140427, 0.09575347401550971, 0.08213850771426223, 0.04349666676716879, 0.03888038576405961, 0.05667579942382872, 0.06907196628162637, 0.03930046361347195, 0.026111575425602496, 0.13046010659309104, 0.07209043673356064, 0.12823449476854876, 4.32138841599226, 53.0569139868021, 60.86769886314869, 43.47784839570522, 23.61627995967865, 44.97499465942383, 85.09131163358688, 49.554398730397224, 10.63556469976902, 0.7807587704155594, 0.09266541237593628, 0.02056040357274469, 0.25316183106042445, 1.4482498937286437, 0.13799465697957203, 0.10046927331131883, 0.12551961466670036, 15.954562984406948, 68.92865851521492, 86.97677046060562, 71.9274728000164, 66.7269578576088, 76.88801541924477, 80.0103610754013, 77.09848612546921, 77.20660552382469, 81.67518094182014, 75.0520071387291, 72.06042766571045, 72.46306926012039, 70.67620754241943, 65.22049069404602, 62.20991984009743, 58.14892195165157, 56.41696348786354, 54.404044300317764, 55.876396894454956, 59.161704406142235, 67.80911698937416, 67.5845718383789, 64.4569444656372, 60.96427448093891, 53.75129632651806, 58.335381746292114, 67.2027987241745, 69.28995832800865, 71.23127415776253, 72.71105155348778, 72.76918083429337, 71.31633639335632, 63.50193791091442, 68.51557508111, 75.27097418904305, 25.3268588706851, 48.38505707681179, 72.60241538286209, 68.06529924273491, 75.60694456100464, 69.46914911270142, 70.52406370639801, 67.0674879848957, 66.34928852319717, 60.202688947319984, 52.35813528299332, 49.64837148785591, 49.04055990278721, 50.991823598742485, 57.103286460042, 58.27998831868172, 61.4413882791996, 66.349828094244, 67.66944408416748, 63.185156509280205, 66.84155970811844, 70.8331087231636, 74.44486811757088, 72.61696860194206, 72.77370259165764, 67.64966234564781, 66.73179119825363, 69.50799822807312, 69.53734025359154, 69.66489180922508, 67.42424324154854, 69.4274653494358, 71.94234520196915, 72.66281694173813, 71.68732568621635, 78.32420915365219, 60.3538828343153, 58.08964893221855, 70.08413091301918, 65.9882926940918, 25.54035611450672, 1.294143225532025, 0.14034134277608246, 0.043500793108250946, 0.06213484848558437, 0.10715122960391454, 0.29413904005195946, 0.2789458225015551, 0.294452968519181, 13.202766794711351, 47.250555753707886, 66.35296672582626, 32.838856279850006, 19.81827735900879, 34.61881756782532, 54.10517893731594, 32.998003140091896, 0.5512499576434493, 0.09615209637559019, 0.13135653192875907, 0.07753808269626461, 0.02790725924569415, 0.09306868058047257, 0.022948866717342753, 0.06602218461921439, 0.03025062949745916, 0.05253274517599493, 0.026331607368774712, 0.02215246990090236, 0.025878275737341028, 0.07302371712285094, 0.04465134465135634, 0.05500608589500189, 0.04414866947627161, 0.046702952531632036, 0.028284671025176067, 0.012207542604301125, 0.02170617754018167, 0.018653757542779204, 0.0420213291363325, 0.042581342640914954, 0.015527648774877889, 0.06199919131177012, 0.05507652684173081, 0.033273649314651266, 0.042135545663768426, 0.030134030675981194, 0.0021030347716077813, 0.03907931473804638, 0.03353889660502318, 0.017445177472836804, 0.03820791462203488, 0.04622441942046862, 0.056058673944789916, 0.04290523072995711, 0.029348278112593107, 0.024197155398724135, 0.01619500559172593, 0.09212445351295173, 0.0389515651477268, 0.0189306287211366, 0.04960133977874648, 0.014402971282834187, 0.038931089293328114, 0.008119355334201828, 0.06237005363800563, 0.06285947034484707, 0.04137465875828639, 0.059273041697451845, 0.02345721561141545, 0.020567136707541067, 0.07204172216006555, 0.07022898193099536, 0.0655804731650278, 0.03928396567062009, 0.03640998766059056, 0.025574761457392015, 0.057309393159812316, 0.023645927067263983, 0.019173166292603128, 0.23136569594498724, 0.09500199754256755, 0.29903222748544067, 11.607601940631866, 69.94452640414238, 56.750190407037735, 29.257124774158, 27.36661981791258, 76.2529706954956, 85.87118178606033, 41.125162839889526, 15.114426165819168, 1.682235519401729, 0.014109172643657075, 0.042892116980510764, 0.8490862289909273, 1.1162079172208905, 0.7913667324464768, 0.41203127650078386, 0.09964656550437212, 23.45812674611807, 81.5039013326168, 86.66980013251305, 69.89547863602638, 69.4368888437748, 77.38837257027626, 78.44559744000435, 76.01580262184143, 76.98377028107643, 82.99018397927284, 75.291857868433, 75.08209392428398, 75.37667691707611, 72.48054072260857, 65.79837888479233, 63.07361729443073, 60.20906500518322, 60.314836129546165, 57.31498830020428, 56.61253899335861, 61.769238486886024, 69.2984926700592, 67.44125112891197, 66.2255747616291, 63.59684161841869, 56.155982092022896, 62.2479671984911, 70.42418986558914, 70.6944465637207, 72.122812718153, 74.62668836116791, 73.2077457010746, 70.17839625477791, 63.92539858818054, 68.65066543221474, 76.51038408279419, 24.614849276840687, 49.00809444487095, 73.48368689417839, 66.16877540946007, 76.27881690859795, 72.5521744787693, 71.2478868663311, 70.83057045936584, 68.05355027318001, 63.02331179380417, 56.63241572678089, 53.58641177415848, 51.438831612467766, 51.407342702150345, 56.75462856888771, 56.88022322952747, 61.59493803977966, 66.12641528248787, 66.53442218899727, 63.287853598594666, 66.96190685033798, 73.26355710625648, 73.61471146345139, 71.7123207449913, 71.725262850523, 69.54938560724258, 68.46173956990242, 71.92457735538483, 70.82557752728462, 69.95779529213905, 71.15952640771866, 71.69410452246666, 74.98184010386467, 73.86258736252785, 70.00583231449127, 77.67724826931953, 63.59445534646511, 57.053227946162224, 67.54873976111412, 74.03745397925377, 31.37315332889557, 2.120167720131576, 0.3276590898167342, 0.19020268286112696, 0.11615546987741254, 0.24273600691230968, 0.11594460345804691, 0.3893908148165792, 0.7766196643933654, 21.448633074760437, 43.85144054889679, 73.98085981607437, 55.08927293121815, 18.10664590448141, 28.77143483608961, 52.518893256783485, 45.383617132902145, 1.6179278888739645, 0.17690827982733026, 0.014016055374668213, 0.0468145715421997, 0.02531583912059432, 0.03910644765710458, 0.06033290279447101, 0.07489569557947107, 0.04206323079415597, 0.13441803952446207, 0.05310826214554254, 0.021405334991868585, 0.055243562019313686, 0.06355844729114324, 0.0147791446033807, 0.06523846182972193, 0.035467538036755286, 0.03157515158818569, 0.015826592352823354, 0.01916667435580166, 0.015616905948263593, 0.06300163615378551, 0.023021511842671316, 0.009367120801471174, 0.028444251329347026, 0.02307362730789464, 0.00791057342212298, 0.04324997316871304, 0.050111662785639055, 0.027135188174725045, 0.12016519729513675, 0.152535333763808, 0.22880313423229381, 0.09768627147423103, 0.0897753780009225, 0.13966134254587814, 0.1498122900375165, 0.17449054081225768, 0.11302664206596091, 0.2209840147406794, 0.12817194656236097, 0.15029229631181806, 0.17826974974013865, 0.1769909105496481, 0.13502890127710998, 0.10104334680363536, 0.13254094024887308, 0.0575326200487325, 0.23640407714992762, 0.15558800980215892, 0.2132100475137122, 0.11156485605170019, 0.1028367095568683, 0.22242582956096157, 0.13408196537056938, 0.2534828841453418, 0.17334447184111923, 0.24967596342321485, 0.1689279213314876, 0.1557996851624921, 0.22359063033945858, 0.20740988140460104, 0.13855517143383622, 0.4332323279231787, 0.2586288470774889, 0.312809813185595, 9.545814525336027, 84.12408873438835, 81.13901451230049, 55.77981747686863, 40.27552083134651, 67.70836919546127, 94.93456944823265, 63.84412854909897, 21.46049603819847, 1.281434807460755, 0.20551998750306666, 0.1501553552225232, 3.0382314696907997, 8.316916767507792, 1.1152601055800915, 0.25026914721820503, 0.21921132080024108, 18.854677565395832, 78.03201243281364, 89.432343095541, 77.35715344548225, 68.5643720626831, 77.61670991778374, 77.73231491446495, 78.57197105884552, 76.29425168037415, 85.5421194434166, 79.61741656064987, 77.38499075174332, 79.50891718268394, 78.06153684854507, 70.88559910655022, 67.22245126962662, 64.56814169883728, 63.65435913205147, 60.83708390593529, 62.07048252224922, 66.51741430163383, 73.34613427519798, 72.88155600428581, 71.28401532769203, 71.83076038956642, 61.48730121552944, 65.89640602469444, 73.17735493183136, 74.23195034265518, 76.80954962968826, 79.76318433880806, 76.49249464273453, 72.58290722966194, 65.17141252756119, 66.76066964864731, 72.2041891515255, 30.535159595310688, 51.73730939626694, 72.07270860671997, 71.10666364431381, 79.11215767264366, 75.69762289524078, 74.45353165268898, 69.87033158540726, 71.26984968781471, 63.38344506919384, 55.7732780277729, 56.89329832792282, 55.493651032447815, 58.24664890766144, 61.39170214533806, 65.31734749674797, 66.79450303316116, 72.12339788675308, 73.12530532479286, 68.80989968776703, 70.61972737312317, 78.58931332826614, 77.75984063744545, 74.17666330933571, 75.16514226794243, 70.73556035757065, 70.90902104973793, 77.53082692623138, 74.88379776477814, 74.71454724669456, 71.13158270716667, 73.0667732656002, 78.4832002222538, 77.52311334013939, 71.02353170514107, 77.13394582271576, 65.51741436123848, 61.16717979311943, 70.19590571522713, 70.22193431854248, 28.957083374261856, 1.8206018884666264, 0.42569712444674224, 0.5247652600519359, 0.5418771668337286, 0.5108324170578271, 0.35665566043462604, 0.8735269925091416, 0.3962184546981007, 23.55599619448185, 59.82045225799084, 72.53119960427284, 50.36750189960003, 29.978377372026443, 46.110981702804565, 70.01982316374779, 52.12314069271088, 1.6649864637292922, 0.28086658974643797, 0.2366212147171609, 0.26091884763445705, 0.21923959662672132, 0.16115447360789403, 0.19892340787919238, 0.16234446287853643, 0.09524352950393222, 0.24560635210946202, 0.12956470542121679, 0.13549945259001106, 0.10874972664169036, 0.1460842150845565, 0.09487953575444408, 0.1152771306806244, 0.19542663067113608, 0.19973583694081753, 0.09277317221858539, 0.12775298935594037, 0.11592096605454572, 0.12674907135078683, 0.1998361010919325, 0.12160624770331196, 0.11184986302396283, 0.19673819857416674, 0.08984293570392765, 0.21461110358359292, 0.09283658873755485, 0.15232019999530166], [0.05092020670417696, 0.02385124593274668, 0.0718251263606362, 0.07093695370713249, 0.040071091207209975, 0.04011839198938105, 0.04935834207572043, 0.038664220410282724, 0.015372769976238487, 0.045614730261149816, 0.04322964574384969, 0.045451060723280534, 0.023236016641021706, 0.03927534562535584, 0.011824440407508519, 0.05224730404734146, 0.016126807786349673, 0.12290150320040993, 0.039573525718878955, 0.043572881622822024, 0.031537862378172576, 0.018023577686108183, 0.02338159076316515, 0.03702183275891002, 0.06261865826672874, 0.051555666941567324, 0.04767325495777186, 0.05001320576411672, 0.03818497483734973, 0.02175318331865128, 0.02119331453286577, 0.024955331609817222, 0.04176925867795944, 0.10744340572273359, 0.18191363546065986, 0.027608246091404, 0.14266435406170785, 2.115744282491505, 34.84202139079571, 63.011775612831116, 48.17476116120815, 24.514973536133766, 39.79447044432163, 75.64290583133698, 72.67058372497559, 31.553134471178055, 3.6872556433081627, 0.07531679017120041, 0.055198944100993685, 0.302444503759034, 0.6511791329830885, 0.26167726318817586, 0.03748548580915667, 0.5268949270248413, 2.641775468364358, 33.3819155395031, 80.43898567557335, 84.81924623250961, 70.4230423271656, 74.02052208781242, 79.2040367424488, 78.5459652543068, 78.78063306212425, 78.0249448120594, 80.41703805327415, 78.11460480093956, 73.97631525993347, 73.41116398572922, 71.32812336087227, 69.96690720319748, 65.07498890161514, 56.65865711867809, 56.7135451734066, 64.00332480669022, 71.70067816972733, 72.06263154745102, 68.41506287455559, 62.464927956461906, 59.52804274857044, 56.57482601702213, 59.2256473749876, 63.0427211523056, 72.32301637530327, 72.63052627444267, 73.08462470769882, 72.49488115310669, 74.06136229634285, 68.46040964126587, 82.61984065175056, 25.96801556646824, 50.564221143722534, 80.43419793248177, 74.84768450260162, 74.26028162240982, 67.41498693823814, 71.86583250761032, 63.63360084593296, 61.74916036427021, 56.616486981511116, 53.005122765898705, 52.87985108792782, 56.24747358262539, 60.29142938554287, 63.64713191986084, 65.04471212625504, 68.57365876436234, 71.21501863002777, 71.58151656389236, 71.94557502865791, 69.46696043014526, 72.60660275816917, 74.57004860043526, 75.44302895665169, 77.4959447979927, 78.62414985895157, 73.10096383094788, 67.97194585204124, 70.67308411002159, 74.19396758079529, 73.30167666077614, 74.22118932008743, 73.66109937429428, 73.60816061496735, 70.57900875806808, 62.01707258820534, 70.62829971313477, 70.74310675263405, 42.101402655243874, 5.078080762177706, 0.17652567301411182, 0.006436960820792592, 0.2739425894105807, 0.061104042470105924, 0.09643360783229582, 0.10244728982797824, 0.22362039046129212, 0.46403466258198023, 17.885195687413216, 53.92334349453449, 55.52329324185848, 23.593002408742905, 24.820824824273586, 41.11278310418129, 57.85701401531696, 24.011266864836216, 0.7319307967554778, 0.07093741383869201, 0.02804850479151355, 0.041825101579888724, 0.024532524512324017, 0.03389214776689187, 0.04504435266426299, 0.004907597158307908, 0.04370364062197041, 0.11290005393675528, 0.08035038452362642, 0.04057873506098986, 0.03823498816927895, 0.0392372660280671, 0.05644401928293519, 0.034872621326940134, 0.03115170809905976, 0.03865901795506943, 0.01300488380366005, 0.07809557660948485, 0.01518703824331169, 0.026359092807979323, 0.030244701592891943, 0.10695022632717155, 0.035408529874985106, 0.03697524072777014, 0.045905043589300476, 0.03512301824230235, 0.03108194807282416, 0.06519969945657067, 0.056731130243861116, 0.0861412737867795, 0.052487934299279004, 0.0897344114491716, 0.05400383772212081, 0.02002466942940373, 0.02728528568695765, 0.017271620672545396, 0.0009035116863742587, 0.05219275248236954, 0.038644954256596975, 0.01071150090865558, 0.020382419861562084, 0.03396513428015169, 0.06312390498351306, 0.028308638684393372, 0.02029152532486478, 0.10828787329955958, 0.019847824914904777, 0.05117022512422409, 0.04665994878450874, 0.028188160285935737, 0.06174561429361347, 0.01747122314554872, 0.038341720137395896, 0.07669275422813371, 0.11563906125957146, 0.05886489016120322, 0.03963846364058554, 0.04166884238657076, 0.03503106243442744, 0.061144541468820535, 0.02388932367466623, 0.04789166159753222, 0.031949795156833716, 0.06163282640045509, 0.05974407169560436, 0.17700820259051397, 7.050909250974655, 53.13950635492802, 68.02063643932343, 39.04082268476486, 24.457252733409405, 62.7338395267725, 89.17468652129173, 67.24088028073311, 29.061401076614857, 6.105847712606192, 0.11523017499712296, 0.07561661783256568, 0.17920163489179686, 0.9047975926660001, 1.1929101264104247, 0.31951455341186374, 0.6194937613327056, 5.650692461058497, 46.04672335088253, 87.19469636678696, 81.5307354927063, 70.727459192276, 73.85158315300941, 79.54615518450737, 77.06885531544685, 81.5908482670784, 82.07829371094704, 79.02118295431137, 74.92369562387466, 77.46210381388664, 77.50266283750534, 75.67855551838875, 71.81814506649971, 63.06223310530186, 56.664258018136024, 58.78117002546787, 64.13850635290146, 74.27824705839157, 75.57271599769592, 70.53198248147964, 63.0976852029562, 62.31398105621338, 58.05962674319744, 62.654773369431496, 68.25173243880272, 74.62212860584259, 75.59106901288033, 76.08788475394249, 71.39639049768448, 73.50141674280167, 68.59890460968018, 78.40359449386597, 29.616272002458572, 50.37516228854656, 77.73917734622955, 75.19961401820183, 77.23308250308037, 68.390554189682, 72.36675202846527, 67.09360778331757, 66.9378237426281, 60.13499177992344, 55.46329066157341, 52.94138118624687, 55.83611145615578, 60.374929904937744, 64.78632599115372, 67.1512658894062, 71.52749866247177, 73.76356467604637, 75.1723162829876, 72.02964931726456, 70.72299063205719, 74.04595032334328, 76.27095893025398, 74.4554315507412, 76.45923882722855, 77.84308657050133, 76.58257260918617, 69.59063619375229, 71.41517668962479, 75.67548528313637, 74.35421258211136, 77.00639426708221, 74.52308312058449, 72.14109733700752, 70.99863544106483, 67.18714356422424, 68.43289911746979, 76.01205602288246, 49.2157419025898, 8.395611494779587, 0.24076686648186296, 0.3030723606934771, 0.34996885049622506, 0.11362305420334451, 0.009466065785090905, 0.04676263233704958, 0.24032776738749817, 1.6695768549107015, 17.491130232810974, 49.05306123197079, 78.10569807887077, 38.98899346590042, 20.852458365261555, 39.280939400196075, 60.015526190400124, 37.97523446381092, 1.3143531535752118, 0.08187990635633469, 0.04981795413186774, 0.02792563111142954, 0.01563006608193973, 0.07230142189655453, 0.01587017311976524, 0.025063746397790965, 0.12900061381515115, 0.11906318963156082, 0.070502611779375, 0.08498593539115973, 0.038788196179666556, 0.024432488571619615, 0.04070943468832411, 0.027668354487104807, 0.032092298642965034, 0.024768521907390095, 0.009803378397919005, 0.05287449304887559, 0.01687359017523704, 0.025923992034222465, 0.026429088466102257, 0.06464345977292396, 0.03245843719923869, 0.025899603206198663, 0.02508857309294399, 0.022762053304177243, 0.02360364691412542, 0.07387957666651346, 0.03386247299204115, 0.16723275213735178, 0.16814289236208424, 0.24048856110312045, 0.1674914945033379, 0.12197646807180718, 0.08183516969438642, 0.14101032953476533, 0.06919370076502673, 0.10613761172862723, 0.13246840273495764, 0.15580908075207844, 0.1058341475436464, 0.11439122899901122, 0.1412604036158882, 0.09839946797001176, 0.33197245211340487, 0.277927684946917, 0.21086526161525398, 0.10788438987219706, 0.12636567786103114, 0.13671304215677083, 0.12419124454027042, 0.06770758714992553, 0.1142023375723511, 0.2422958836541511, 0.2799570729257539, 0.12775238079484552, 0.14901924587320536, 0.10437463250127621, 0.09314924813224934, 0.12899524066597223, 0.15925021172733977, 0.1830748442444019, 0.18793010793160647, 0.37701707566156983, 0.19014160410733894, 0.15498477732762694, 5.845467634499073, 63.167122676968575, 88.67424577474594, 63.84881749749184, 39.24185089766979, 64.07321065664291, 86.85739606618881, 88.37768688797951, 47.84793309867382, 8.72422831133008, 0.18906560871982947, 0.25890902266837656, 1.1676160711795092, 3.330261711962521, 1.3901979150250554, 0.22056628949940205, 0.6338647089432925, 3.855334399268031, 38.179473504424095, 86.86404570937157, 87.43832409381866, 72.31303811073303, 73.54522079229355, 76.5818202495575, 77.77030527591705, 83.20605039596558, 84.22346100211143, 85.24898037314415, 83.38552236557007, 82.48444631695747, 81.62459045648575, 78.55671867728233, 75.8374933898449, 67.01631233096123, 62.74225227534771, 63.07250775396824, 70.31895831227303, 78.30586373806, 80.89349448680878, 73.72953370213509, 68.64459335803986, 65.48259302973747, 62.37719066441059, 66.3446831703186, 71.26554071903229, 78.48015278577805, 79.85928878188133, 79.98001590371132, 77.7715440094471, 76.06080740690231, 69.55775275826454, 83.55892986059189, 31.78771298378706, 53.56989026069641, 83.15035298466682, 81.39870017766953, 79.62760761380196, 71.533183157444, 78.05120140314102, 71.32433116436005, 70.95638930797577, 66.09421581029892, 60.10917976498604, 59.20101709663868, 60.85135214030743, 64.44164648652077, 70.06833896040916, 72.75963574647903, 76.06248691678047, 78.39863955974579, 77.66233026981354, 75.88996097445488, 74.9216665327549, 76.47833660244942, 81.2116514146328, 77.80253514647484, 82.337576597929, 86.65105193853378, 81.16698861122131, 72.11875453591347, 76.71721458435059, 81.15713953971863, 80.89451283216476, 83.1440681219101, 75.96290186047554, 73.63539755344391, 68.37808325886726, 71.6829863190651, 73.14070209860802, 73.03129076957703, 46.00563235580921, 6.988472426310182, 0.33241735480260104, 0.24703598086489365, 0.8985408127773553, 0.19835573912132531, 0.4101640626322478, 0.366568912868388, 0.577893415465951, 1.3229368929751217, 29.79881800711155, 66.09026402235031, 64.711272418499, 37.822847440838814, 37.12374955415726, 52.841438949108124, 72.10793271660805, 40.33190220594406, 1.383347357623279, 0.21048747876193374, 0.12107753427699208, 0.12340647532255389, 0.07674497916013934, 0.2138852683128789, 0.09709704332635738, 0.14538058487232774, 0.2583929034881294, 0.26114496518857777, 0.12514693778939545, 0.1703744858969003, 0.10744716841145419, 0.16517108073458076, 0.12603227543877438, 0.13069855864159763, 0.21814038685988635, 0.09929433479555883, 0.07924553443444893, 0.15512263868004084, 0.15778331231558695, 0.07746073606540449, 0.09577199060004205, 0.18268836342031136, 0.12535779678728431, 0.1679772004717961, 0.16166832181625068, 0.10349682765081525, 0.11143217489006929, 0.12186559120891616, 0.14935388026060537], [0.040500527538824826, 0.006710206607749569, 0.08202098120818846, 0.09552751231240109, 0.02911969477281673, 0.024512512500223238, 0.03672085476864595, 0.02336253983230563, 0.05337488983059302, 0.012046544798067771, 0.04764969176903833, 0.08964100474258885, 0.03088762598054018, 0.026210622454527766, 0.05712210477213375, 0.05789881797682028, 0.01828652802942088, 0.10366948088631034, 0.040940988474176265, 0.005629087618217454, 0.009072947377717355, 0.03814817173406482, 0.05332195614755619, 0.0402667102025589, 0.1101949553412851, 0.11505538437631913, 0.07616487942868844, 0.024937132293416653, 0.06168754494865425, 0.019886067784682382, 0.02698061551200226, 0.03132736703264527, 0.03491634866804816, 0.023519710011896677, 0.07238975973450579, 0.07923352648504078, 0.13595873810118064, 0.5060794658493251, 0.8042611624114215, 27.939775362610817, 68.88091027736664, 54.367334470152855, 35.64169228076935, 37.396137937903404, 48.293839171528816, 79.9856624007225, 67.54485636949539, 15.577311627566814, 0.2970402140635997, 0.08248646365245804, 0.14089526695897803, 0.7492825062945485, 0.21364911692216992, 0.8342781267128885, 0.0956423522438854, 0.1028481089451816, 6.361145563423634, 43.15003998577595, 80.58502703905106, 95.95946565270424, 77.24980920553207, 77.8233352303505, 82.3674201965332, 80.49953922629356, 78.97811606526375, 80.98620191216469, 83.29304292798042, 78.09014931321144, 76.8529660999775, 72.27235749363899, 70.80813646316528, 62.306962832808495, 61.97626277804375, 73.02926167845726, 79.19336691498756, 78.00756454467773, 72.47303992509842, 68.8623596727848, 62.22582198679447, 60.24688437581062, 60.90782850980759, 63.696118891239166, 64.95688363909721, 70.2581387758255, 71.83634608983994, 75.00049710273743, 71.97693854570389, 72.96391278505325, 59.851002618670464, 33.0759521573782, 41.6966787725687, 76.07088446617126, 74.34017613530159, 71.39480978250504, 69.20592963695526, 64.68794927001, 61.76545388996601, 58.808270171284676, 58.275519758462906, 56.78658865392208, 57.49572180211544, 60.14382250607014, 62.89044052362442, 64.23502117395401, 67.91304901242256, 72.45822072029114, 78.41222763061523, 74.47190746665001, 74.8648975789547, 76.44322648644447, 76.11648961901665, 77.64593794941902, 75.94745188951492, 73.65686640143394, 71.54705241322517, 76.12420320510864, 75.63754811882973, 76.12817779183388, 72.58937448263168, 73.7899124622345, 79.73696574568748, 81.48899853229523, 75.52428379654884, 69.8093980550766, 78.90018224716187, 55.60655437409878, 12.182055115699768, 0.08040240907575935, 0.3449313895544037, 0.15401373646454886, 0.403945607249625, 0.14644705108366907, 0.07228356582345441, 0.258957885671407, 0.0814912436180748, 2.576548643410206, 38.49832199513912, 70.00541433691978, 41.11736945807934, 19.747133776545525, 37.33512081205845, 54.05231237411499, 56.76230035722256, 16.615518517792225, 0.061702573439106345, 0.16132029908476397, 0.04015391488792375, 0.11718358189682476, 0.04230492231727112, 0.0271421699289931, 0.11453119062935002, 0.04179538598691579, 0.03385972333489917, 0.01879894574813079, 0.021077207384223584, 0.05201965024753008, 0.04074187025253195, 0.07924248420749791, 0.021393182323663495, 0.02971256872115191, 0.04440674762008712, 0.0410947317868704, 0.007040300442895386, 0.061412007780745625, 0.01787861212505959, 0.01910728769871639, 0.04465045036340598, 0.022012274494045414, 0.012477686213969719, 0.01581251752213575, 0.04604525754984934, 0.020449981275305618, 0.005758000525020179, 0.04279450229660142, 0.04971338181348983, 0.01896750232845079, 0.010056307892227778, 0.029827147045580205, 0.01089136689188308, 0.03570140732335858, 0.03954011423047632, 0.07628590145031922, 0.002278451115671487, 0.051932418209617026, 0.035324066047905944, 0.05450946664495859, 0.02859579231881071, 0.026432570994074922, 0.08901141118258238, 0.020131549827056006, 0.011559178274183068, 0.042364761684439145, 0.05531923881790135, 0.08652874908875674, 0.05261593250907026, 0.023938220074342098, 0.03955243017117027, 0.02401765770628117, 0.0739484182849992, 0.035740911844186485, 0.05589412496192381, 0.034126662721973844, 0.073621576448204, 0.01882489123090636, 0.0402579231740674, 0.028890601206512656, 0.010234907585982, 0.044180938057252206, 0.043669204969774, 0.029612436301249545, 0.06861406858661212, 0.03801067403401248, 0.0847033626632765, 0.6782793381717056, 2.4706478510051966, 45.41078567504883, 78.87907058000565, 50.76696686446667, 32.15414822101593, 48.53438526391983, 78.33497777581215, 93.8059464097023, 59.47341687977314, 16.70924998819828, 0.7707143656443805, 0.03454713762039319, 0.38101728132460266, 0.48401232808828354, 0.45815260789822787, 0.9944007627200335, 0.33591085171792656, 0.24529680231353268, 12.352563366293907, 55.39174810051918, 86.03205755352974, 91.89037799835205, 76.29430487751961, 78.30979272723198, 83.35820183157921, 79.46752980351448, 81.88676118850708, 86.57899260520935, 86.13009229302406, 78.41874808073044, 76.83535024523735, 73.15584808588028, 75.2235147356987, 64.6921518445015, 61.893955394625664, 75.07168248295784, 79.36837792396545, 76.45736932754517, 75.73575004935265, 70.0222398340702, 64.49142381548882, 60.88373400270939, 63.66764321923256, 65.48011556267738, 67.33823865652084, 72.17505991458893, 73.37387278676033, 74.27886262536049, 74.40668776631355, 71.20292007923126, 65.45945227146149, 28.99605218321085, 47.0473350584507, 79.23269480466843, 76.12428680062294, 75.90239390730858, 73.20681095123291, 67.42188736796379, 63.895858973264694, 59.95653435587883, 60.319878458976746, 58.94760489463806, 60.09659864008427, 64.06523868441582, 64.35287564992905, 65.66554561257362, 67.04677909612656, 72.27835357189178, 77.86708608269691, 75.32131388783455, 77.5718343257904, 74.17395785450935, 78.13801914453506, 77.39800125360489, 75.88163942098618, 72.83323019742966, 74.82453614473343, 75.60008972883224, 73.96711215376854, 76.07741251587868, 76.8677169084549, 76.00686550140381, 77.39128321409225, 80.32100200653076, 73.93084689974785, 68.076873421669, 74.68055427074432, 65.13544365763664, 17.116010561585426, 0.5642959044780582, 0.6105189397931099, 0.46434915508143604, 0.7532338192686439, 0.21413136448245496, 0.2288536002743058, 0.14430402545258403, 0.1297539530787617, 2.9842221178114414, 34.74835641682148, 73.26186999678612, 67.79418379068375, 23.379482366144657, 22.831544168293476, 54.227232187986374, 61.51939809322357, 28.172092996537685, 0.5204039253294468, 0.025497991846350487, 0.0663749422528781, 0.028990945138502866, 0.023837974476919044, 0.038178855829755776, 0.055179859773488715, 0.05268662949674763, 0.06880236629513092, 0.036452605490922, 0.00805883504654048, 0.11677358241286129, 0.04484459990635514, 0.03938093468605075, 0.016217318261624314, 0.045881046244176105, 0.02740689586062217, 0.034259666717844084, 0.05246672000794206, 0.013513955364032881, 0.08373333854251541, 0.05641125717374962, 0.01708691310341237, 0.07813864343916066, 0.018203819381596986, 0.0588310111197643, 0.03205816356057767, 0.03241522194002755, 0.027038972439186182, 0.049051534515456297, 0.09718129193061031, 0.03083669795159949, 0.12937639286974445, 0.10425271248095669, 0.17301123269135132, 0.0970938520913478, 0.10334652790334076, 0.17327142966678366, 0.09223032087902538, 0.15567095222650096, 0.13146758690709248, 0.1291666174074635, 0.06458963922341354, 0.13000680279219523, 0.18592960434034467, 0.24326472776010633, 0.1722670960589312, 0.16337055625626817, 0.10265902456012554, 0.2361717403982766, 0.19663024577312171, 0.06164969912788365, 0.10460340694407932, 0.1214735591202043, 0.13549443567171693, 0.11859757360070944, 0.2275053405901417, 0.1262618662440218, 0.1711494365008548, 0.06064742869057227, 0.10843337135156617, 0.1139221248740796, 0.1304099225671962, 0.11069128144299611, 0.20104243245441467, 0.14770335867069662, 0.25454192887991667, 0.27857080043759197, 0.27118770754896104, 0.7324530312325805, 1.9652248593047261, 46.3003521412611, 96.96901068091393, 68.33599671721458, 52.117763981223106, 57.29685187339783, 63.594698533415794, 89.91481080651283, 83.53949770331383, 27.67481178045273, 0.7871658203657717, 0.11530957737704739, 1.4090211549773812, 4.511348297819495, 0.8662323339376599, 1.43675752915442, 0.20925540971802548, 0.3292473155306652, 8.495654426515102, 45.10240562260151, 84.19569969177246, 96.04305356740952, 79.8327586054802, 77.46939182281494, 81.63472831249237, 83.99131625890732, 84.21735092997551, 85.47261357307434, 87.86452442407608, 83.03847938776016, 81.03153347969055, 78.94378870725632, 77.5038255751133, 70.70677310228348, 66.85598373413086, 80.41706845164299, 82.50953257083893, 80.9430818259716, 81.43036767840385, 78.44534665346146, 71.1183974146843, 67.46747732162476, 66.61088928580284, 70.45090243220329, 70.8625115454197, 75.00650078058243, 77.66139551997185, 78.97330552339554, 75.33281967043877, 75.27046501636505, 58.11386123299599, 39.586705192923546, 51.18201099336147, 80.3418780863285, 81.85741916298866, 78.06240320205688, 77.5712339580059, 69.7662627696991, 66.25142097473145, 62.34829321503639, 63.531105145812035, 61.92167870700359, 64.90908980369568, 68.68170216679573, 68.98379355669022, 70.32436922192574, 71.62318512797356, 77.40421772003174, 84.3781279027462, 79.93357479572296, 82.98006892204285, 80.19997090101242, 84.92862716317177, 80.75621545314789, 77.68171682953835, 73.45447406172752, 71.80568173527718, 77.0041523873806, 78.92539009451866, 81.36599913239479, 76.43266305327415, 75.58120474219322, 80.04477202892303, 80.56254744529724, 75.83591267466545, 77.43922144174576, 80.28648465871811, 57.46233679354191, 14.707066174596548, 0.27488229679875076, 0.5638930073473603, 0.5173811875283718, 1.4947295933961868, 1.0764952981844544, 0.6902207317762077, 0.82309550489299, 0.3364742308622226, 5.840079048648477, 54.004089161753654, 78.2726763188839, 49.63716968894005, 29.291824512183666, 49.8032283782959, 67.20128640532494, 72.60680794715881, 27.815271243453026, 0.4207078437320888, 0.32767799973953515, 0.1156961546803359, 0.19059562037000433, 0.20966753916582093, 0.14419601327972487, 0.24344613833818585, 0.13292400719365105, 0.1381096156546846, 0.0877981110534165, 0.10736688287579454, 0.11790926873800345, 0.11888243956491351, 0.14951676683267578, 0.08481279975967482, 0.20777602738235146, 0.1339668285800144, 0.2429752011084929, 0.11665572194033302, 0.15772448969073594, 0.14129779301583767, 0.11078030947828665, 0.12239164774655364, 0.18908845202531666, 0.10793320092489012, 0.17766907025361434, 0.14543182274792343, 0.07949761973577552, 0.1631758315488696, 0.19357532844878733, 0.13440347858704627, 0.22071100829634815], [0.02775667562673334, 0.033689827178022824, 0.0367543070751708, 0.060615212059929036, 0.027131136048410553, 0.0565824298246298, 0.021465849713422358, 0.05837562188389711, 0.09587189109879546, 0.04400147561682388, 0.12845430406741798, 0.004620480631274404, 0.03997739506303333, 0.08772207060246728, 0.05203723172598984, 0.016404831148975063, 0.037866886632400565, 0.0340075146232266, 0.029170735979278106, 0.06530092839966528, 0.051697357775992714, 0.04634142642316874, 0.005866867095392081, 0.005348189824871952, 0.06173824476718437, 0.047228574912878685, 0.06782080919947475, 0.08137049619108438, 0.0894668597902637, 0.0648029992589727, 0.05453881858556997, 0.019186795834684744, 0.02730253505433211, 0.07599367338116281, 0.07928695369628258, 0.027860928821610287, 0.020238619472365826, 0.03591503082134295, 0.10742615821072832, 0.04422236102982424, 11.369000393897295, 49.97357703745365, 60.50345040857792, 39.26667116582394, 32.26591922342777, 33.69593448936939, 70.21169766783714, 76.14499568939209, 36.36346735060215, 2.368448772467673, 0.09290718182455748, 0.5415890947915614, 1.022218179423362, 0.9060273610521108, 0.11677416128804907, 0.2554224128834903, 0.4938093898817897, 0.17319010512437671, 3.086764602921903, 34.0679345279932, 83.51439625024796, 91.42430260777473, 76.22035324573517, 83.76207455992699, 84.28990423679352, 80.59519529342651, 79.42035153508186, 74.43364351987839, 79.2890989780426, 83.30478429794312, 82.69509941339493, 68.69703814387321, 63.80718693137169, 73.3279712498188, 79.37213972210884, 77.89393544197083, 75.77484995126724, 73.28182652592659, 68.23221668601036, 66.54270574450493, 65.79122766852379, 68.16445112228394, 66.79269433021545, 68.28960120677948, 70.15861451625824, 77.7954675257206, 71.02516561746597, 82.90821477770805, 55.25028169155121, 53.92504580318928, 48.50202240049839, 71.86396300792694, 81.95438235998154, 69.06851381063461, 69.56365764141083, 66.91674247384071, 65.65587133169174, 60.30204601585865, 64.81898903846741, 64.12167325615883, 67.64260992407799, 67.42396205663681, 68.88638958334923, 70.2384178340435, 74.4645282626152, 73.40306282043457, 79.31866139173508, 77.54319906234741, 78.45675364136696, 72.41338312625885, 78.01446497440338, 74.37818929553032, 78.30204114317894, 80.86301252245903, 80.96803888678551, 79.30668443441391, 74.38901871442795, 74.8956835269928, 75.77469035983086, 77.17869222164154, 77.76237890124321, 66.41887038946152, 79.60841864347458, 72.61807054281235, 27.184850871562958, 0.690964957466349, 0.08214332425268367, 0.035483546162140556, 0.7051631924696267, 0.3809198224917054, 0.7092733844183385, 0.10754239337984473, 0.13426217366941273, 0.08943778244429268, 11.009501684457064, 59.457925111055374, 56.69265769422054, 26.862504668533802, 21.201416440308094, 45.607953295111656, 54.29713323712349, 52.15339086949825, 9.320905543863773, 0.055769117607269436, 0.062487298127962276, 0.06774197827326134, 0.10194452930591069, 0.030263188491517212, 0.05584870923485141, 0.014979646002757363, 0.04097106029803399, 0.07511538613471203, 0.0536092044058023, 0.055896611156640574, 0.009995123382395832, 0.06986276915995404, 0.05317274735716637, 0.06909830510267057, 0.011603830516833114, 0.022437749612436164, 0.053484694290091284, 0.048235238864435814, 0.03815960451902356, 0.04868818272370845, 0.0576402240403695, 0.05388847457652446, 0.07728669501375407, 0.02796124121232424, 0.04278679138224106, 0.02641831433720654, 0.030396070033020806, 0.0643135306017939, 0.08801653995760716, 0.020757393685926218, 0.06454061294789426, 0.1583047304302454, 0.031489570828853175, 0.011965746252826648, 0.018883929078583606, 0.061571461919811554, 0.07691042614169419, 0.02519041059713345, 0.017531852899992373, 0.01846532253694022, 0.04900149149762001, 0.06815658649429679, 0.11635331902652979, 0.05532471215701662, 0.04565144801745191, 0.024452615616610274, 0.02756676189164864, 0.03213354721083306, 0.014694960937049473, 0.03232585993828252, 0.04617797210812569, 0.06713507216772996, 0.022416312676796224, 0.04343351742136292, 0.01995831771637313, 0.046377453982131556, 0.07322932171518914, 0.13252621603896841, 0.050910098652821034, 0.08745543178520165, 0.003946707020077156, 0.04525956806901377, 0.011940007643715944, 0.030023289255041163, 0.08659861487103626, 0.06477195522165857, 0.0975153103354387, 0.01812927806895459, 0.020544790640997235, 0.024807369627524167, 0.14370716060511768, 0.718206645688042, 23.552963957190514, 68.19627821445465, 68.33462879061699, 35.87789140641689, 29.188451059162617, 53.828777968883514, 97.6204477250576, 78.8005743920803, 32.41291433572769, 3.112416551448405, 0.05916935253480915, 0.5791773309465498, 0.4563134768977761, 0.8901201677508652, 0.24581686971941963, 0.14424242719542235, 0.8834600157570094, 0.07430354336975142, 8.30209281295538, 46.82400204241276, 88.41449931263924, 87.568269520998, 79.12905156612396, 87.52242118120193, 82.24605470895767, 78.23960289359093, 80.51482200622559, 82.0906050503254, 86.15029960870743, 85.37339329719543, 80.54022744297981, 70.32303169369698, 65.69984257221222, 76.39170125126839, 81.25618502497673, 82.35728994011879, 78.73806774616241, 76.94350004196167, 70.18290281295776, 69.99049633741379, 70.37937507033348, 71.09048411250114, 70.09566709399223, 70.9703877568245, 72.54052430391312, 78.49687948822975, 73.63440960645676, 78.39597970247269, 54.27050046622753, 50.43785132467747, 50.31978406012058, 72.4844317138195, 81.2184226512909, 71.92974507808685, 70.77527582645416, 67.53953665494919, 67.60582029819489, 62.91981674730778, 64.61337447166443, 62.62768842279911, 66.09515815973282, 66.82929396629333, 70.14433488249779, 73.81279483437538, 76.36989802122116, 76.28892436623573, 79.08191129565239, 78.24310630559921, 80.22948771715164, 76.70437127351761, 79.2382425069809, 75.78830122947693, 76.30039975047112, 78.1203044950962, 77.46064469218254, 83.58781591057777, 77.59205684065819, 77.2459714114666, 75.52126675844193, 76.67021870613098, 79.32255238294601, 69.61583644151688, 75.87147876620293, 79.85976755619049, 38.383435159921646, 2.1178256208077073, 0.18540717690484598, 0.3351757099153474, 1.513268204871565, 0.9518527239561081, 0.37102877511642873, 0.30376784212421626, 0.07764124864479527, 0.15547664312180132, 9.195268135517836, 62.54097327589989, 82.21213012933731, 47.116172164678574, 12.435180433094501, 29.7525991871953, 58.415071070194244, 60.54254271090031, 19.578698314726353, 0.23260857065906748, 0.10634289719746448, 0.07059854178805836, 0.020115896077186335, 0.049313649942632765, 0.030302715276775416, 0.02603691722470103, 0.056781095336191356, 0.11348368629114702, 0.03543636041285936, 0.08745208469917998, 0.015276960566552589, 0.0500251394987572, 0.09996913999202661, 0.030906782667443622, 0.017511104306322522, 0.03596410162572283, 0.018965845483762678, 0.030413439999392722, 0.04230241756886244, 0.06917379636433907, 0.03628035672591068, 0.0891677891195286, 0.05911871950956993, 0.0405573241005186, 0.05349006372853182, 0.03322381409816444, 0.026831172945094295, 0.08556305168895051, 0.11138703746837564, 0.043671609528246336, 0.02045006476691924, 0.07679235786781646, 0.11059298398322426, 0.1558090659091249, 0.07829300273442641, 0.20355129236122593, 0.1829189041745849, 0.11719884787453339, 0.17732597538270056, 0.12630459910724312, 0.21066559420432895, 0.13671319058630615, 0.2792818075977266, 0.06237419482204132, 0.177683571819216, 0.1878314616624266, 0.1700286302366294, 0.08772106128162704, 0.09104596450924873, 0.20007204468129203, 0.18341259565204382, 0.13108213024679571, 0.18632954772328958, 0.13050594163360074, 0.08779094932833686, 0.19393795664655045, 0.19388545711990446, 0.31100885826162994, 0.4088140663225204, 0.17801200185203925, 0.21062885789433494, 0.10613742619170807, 0.155232684337534, 0.11925549493753351, 0.15256536105880514, 0.21036612277384847, 0.24977146298624575, 0.13453544728690758, 0.09583859093254432, 0.12334455052041449, 0.2569412626326084, 0.5358930816873908, 22.382518462836742, 80.33257618546486, 83.83578300476074, 54.91793252527714, 46.979850679636, 52.99613244831562, 83.07114243507385, 89.99167308211327, 55.72176419198513, 5.500760581344366, 0.24228556780144572, 1.3989949179813266, 3.3203644305467606, 2.22011161968112, 0.38397954893298447, 0.7989052310585976, 0.5920747295022011, 0.2307686975109391, 5.574484225362539, 39.49304781854153, 86.36552006006241, 91.94457828998566, 79.6080082654953, 83.49481210112572, 86.5309327840805, 83.59423756599426, 85.42263105511665, 81.7084139585495, 84.28232744336128, 90.24062052369118, 85.74418500065804, 76.43320262432098, 72.1321602165699, 82.11652725934982, 88.64885553717613, 86.61237761378288, 82.56166577339172, 78.14664468169212, 75.50064146518707, 74.26310107111931, 75.40014445781708, 78.80469337105751, 77.03957408666611, 75.43661490082741, 76.63635492324829, 83.89565259218216, 78.17948251962662, 81.20655968785286, 61.78406909108162, 60.71113586425781, 62.12004706263542, 74.52606976032257, 86.23384952545166, 78.87847781181335, 76.86953321099281, 74.81315195560455, 75.07681980729103, 68.21357488632202, 72.7614976465702, 68.50993618369102, 73.85963872075081, 73.21729838848114, 74.35149192810059, 77.79803618788719, 80.408154129982, 80.2987352013588, 82.7417305111885, 81.61748483777046, 83.75570610165596, 76.28974512219429, 79.91155117750168, 79.31410923600197, 81.25526547431946, 84.45600852370262, 85.9288702905178, 87.31875211000443, 76.29994377493858, 75.6325475871563, 78.93139377236366, 78.77431780099869, 85.34658193588257, 70.9908002614975, 79.66410085558891, 74.59377452731133, 31.050867922604084, 1.2333745113573968, 0.17041610553860664, 0.2196111305966042, 1.5302010462619364, 2.4056183779612184, 4.18306871317327, 1.813260919880122, 0.4269501072121784, 0.3349688585149124, 18.158934898674488, 74.61773604154587, 66.10120743513107, 38.142702877521515, 29.415857456624508, 60.12196987867355, 70.7443454861641, 70.71233600378036, 17.17182006686926, 0.2165468770544976, 0.2011650352505967, 0.16423538094386458, 0.1539095983025618, 0.13818985666148365, 0.1653345610247925, 0.19379316363483667, 0.15136058820644394, 0.17248163610929623, 0.12708171678241342, 0.3341586113674566, 0.12816022062906995, 0.15839715750189498, 0.17137665243353695, 0.13205789116909727, 0.08670609269756824, 0.11706254503224045, 0.08736666350159794, 0.19185722689144313, 0.10307430071406998, 0.15451355808181688, 0.08934885830967687, 0.19281584420241416, 0.11322356353048235, 0.13971589040011168, 0.13431878469418734, 0.11630265260464512, 0.1456504742964171, 0.12230961816385388, 0.2465559745905921, 0.15182117989752442, 0.16332485480234027, 0.2830165025079623], [0.03845211089355871, 0.03690749748784583, 0.08289037752547301, 0.09248979797121137, 0.030808563133177813, 0.02054633245279547, 0.08004174756933935, 0.03003300582349766, 0.04339451756095514, 0.052757512021344155, 0.0674573052674532, 0.04359074882813729, 0.01782860250386875, 0.035193841395084746, 0.03489366121357307, 0.039899655093904585, 0.069072359619895, 0.04816866079636384, 0.06526719036628492, 0.06729694199748337, 0.00889643775735749, 0.02097345142828999, 0.034063973507727496, 0.06083312888222281, 0.08122181432554498, 0.03316374837595504, 0.014962804816605058, 0.09083417782676406, 0.02054771284747403, 0.024569874949520454, 0.06308051903033629, 0.028763176305801608, 0.07504969122237526, 0.05497294900123961, 0.005643925005642814, 0.0390041722857859, 0.02627348978421651, 0.1281518195173703, 0.04870001626841258, 0.08997186901979148, 0.023806004610378295, 1.742336181923747, 40.96869483590126, 68.37857723236084, 72.9310293495655, 46.509872898459435, 22.07423910498619, 49.83232341706753, 80.52765771746635, 67.79378101229668, 14.272007569670677, 0.7743054698221385, 0.10060069282189943, 0.22732777433702722, 0.5048835393972695, 0.136218044499401, 0.13371148525038734, 0.5455429013818502, 0.06815185159211978, 0.12185240324470215, 4.581872513517737, 48.36264967918396, 92.21692487597466, 78.2745686173439, 79.47434663772583, 86.10155582427979, 87.99795806407928, 80.10952815413475, 81.82084232568741, 79.2703203856945, 73.89349490404129, 77.67620712518692, 76.66942074894905, 76.92799687385559, 80.77924981713295, 86.14449352025986, 81.21872663497925, 76.1230556666851, 70.46093389391899, 70.58179020881653, 74.37583342194557, 73.28399240970612, 69.46759879589081, 72.72571876645088, 73.77496406435966, 74.44613724946976, 73.85591492056847, 78.22783872485161, 43.60983431339264, 53.245152086019516, 29.561995714902878, 66.91354304552078, 82.88300693035126, 68.65131139755249, 77.22311183810234, 71.46968856453896, 65.55000901222229, 64.76930290460587, 67.35523134469986, 67.9652202129364, 67.04721227288246, 67.44768798351288, 72.54883825778961, 70.02802312374115, 70.2929525077343, 74.24070507287979, 75.6349490582943, 75.87132677435875, 78.61066818237305, 82.70304098725319, 81.63722097873688, 80.4819005727768, 75.70737317204475, 77.38825857639313, 75.51990643143654, 80.22011741995811, 84.1868157684803, 78.1722629070282, 72.31175377964973, 61.10406517982483, 74.69003096222878, 84.39391225576401, 43.33109647035599, 4.96873545460403, 0.04046308247779962, 0.09822591673582792, 0.44931570708286017, 0.6585730612277985, 1.2459971965290606, 0.4047331149922684, 0.19806444615824148, 0.07585215324070305, 1.9665951607748866, 30.430695600807667, 68.6996828019619, 33.727784380316734, 15.730008333921432, 27.632430754601955, 65.17189890146255, 50.67385286092758, 34.473087787628174, 5.631149634718895, 0.24164999253116548, 0.11488210031529889, 0.027715974392776843, 0.16702263528713956, 0.04027246184705291, 0.04178773444436956, 0.056611952459206805, 0.022657445733784698, 0.10364139801822603, 0.02316847378097009, 0.024159799395420123, 0.02927695029939059, 0.013356536564970156, 0.055465089390054345, 0.12844351324019954, 0.02866969723982038, 0.04987522566807456, 0.04054498589539435, 0.04012240700831171, 0.05827115717693232, 0.04512392944889143, 0.01279218056879472, 0.030426755984080955, 0.011297357850708067, 0.06022170309734065, 0.052946930372854695, 0.011725110434781527, 0.07190764576080255, 0.054131193974171765, 0.06485386606073007, 0.050964401598321274, 0.048139553764485754, 0.09933757231920026, 0.009934685658663511, 0.005206243877182715, 0.03953485982492566, 0.05736517297918908, 0.03688812743348535, 0.011432621686253697, 0.08649628754938021, 0.04522472052485682, 0.06659742328338325, 0.02804244515573373, 0.07841058861231431, 0.045291766145965084, 0.026457904205017257, 0.021182178606977686, 0.04827899960218929, 0.039646419463679194, 0.06602265959372744, 0.027708493544196244, 0.04298471103538759, 0.07154529957915656, 0.0599143908766564, 0.03660847505670972, 0.023538506757176947, 0.013455055741360411, 0.04036993552290369, 0.08857612672727555, 0.043389270576881245, 0.047716088010929525, 0.041171432749251835, 0.012281073668418685, 0.06693890027236193, 0.022009992389939725, 0.03642292329459451, 0.07530563569162041, 0.04791425628354773, 0.05094774409371894, 0.014349250923260115, 0.0681886546954047, 0.03385398653335869, 0.024499745704815723, 0.07404921678244136, 0.07213223449070938, 8.677915446460247, 59.02585029602051, 75.44331774115562, 60.78441493213177, 31.54085922986269, 31.377825178205967, 79.72055062651634, 102.8323544561863, 67.75690779089928, 11.34464655071497, 0.6391249329317361, 0.2036091501940973, 0.3000533930025995, 0.4346579045522958, 0.2723504154710099, 0.4750933457398787, 0.38639286474790424, 0.25521758012473583, 0.04533071776677389, 10.049854628741741, 63.21449853479862, 93.4379817545414, 77.1407550573349, 80.57016983628273, 91.63439333438873, 88.79805073142052, 80.70472061634064, 79.18870836496353, 78.84783625602722, 82.61148869991302, 80.22468477487564, 78.68740126490593, 78.25316056609154, 81.22862130403519, 83.6139965057373, 83.6734177172184, 79.66055944561958, 69.91614952683449, 70.95037043094635, 74.82524290680885, 74.8612953722477, 70.08151665329933, 74.13684144616127, 73.67321312427521, 76.6554906964302, 73.89189139008522, 78.89244586229324, 50.47828495502472, 54.542106091976166, 41.69274218380451, 68.88883665204048, 85.51276981830597, 72.3702022433281, 78.36735963821411, 73.4277006983757, 69.32876944541931, 64.25024315714836, 69.17058393359184, 71.17828220129013, 70.07650852203369, 70.49976021051407, 73.39787989854813, 72.05359563231468, 72.21792921423912, 74.54361721873283, 77.13661327958107, 80.23295313119888, 80.74528723955154, 79.26574543118477, 80.81743016839027, 79.49523791670799, 78.90133738517761, 79.57856744527817, 74.75300118327141, 77.24884405732155, 79.33864831924438, 79.4906933605671, 76.07107445597649, 64.45481657981873, 70.65003454685211, 82.55453735589981, 53.66697505116463, 10.085980240255594, 0.05926802106841933, 0.10076596168801188, 1.1266118776984513, 1.5553888259455562, 0.4773156327428296, 0.12286947952816263, 0.18149648909457028, 0.09735233470564708, 2.089402195997536, 30.183112286031246, 80.77639237046242, 57.0084473490715, 21.071374118328094, 13.49598566070199, 51.62471003830433, 61.562293991446495, 43.49270559847355, 10.986808352172375, 0.2762721315957606, 0.25246551842428744, 0.0849585872492753, 0.15700178628321737, 0.051290211849845946, 0.04208336154988501, 0.09348236853838898, 0.03629908853326924, 0.06440845128963701, 0.06113908668339718, 0.06071131276257802, 0.05344265533494763, 0.1210126854130067, 0.02007884806516813, 0.0836234338930808, 0.04344193708675448, 0.09551034643664025, 0.03543842729413882, 0.04250894613505807, 0.03898827919329051, 0.037167163827689365, 0.07296672760276124, 0.020090956204512622, 0.02112834878062131, 0.06237671812414192, 0.027339503285475075, 0.0471473245852394, 0.04023759945994243, 0.006879553111502901, 0.06799663140554912, 0.05720885441405699, 0.01582711556693539, 0.06967430817894638, 0.035316677967784926, 0.20176452730083838, 0.15587948088068515, 0.19356759526999667, 0.15630749228876084, 0.0948079778754618, 0.14581664116121829, 0.18147128575947136, 0.07830275455489755, 0.175551826832816, 0.139129014860373, 0.17381235142238438, 0.11152421604492702, 0.1462895525037311, 0.09467676616623066, 0.12797616800526157, 0.13342819263925776, 0.15168336307397112, 0.16290101426420733, 0.2449566760333255, 0.1049303675245028, 0.17663926613749936, 0.10910178665653802, 0.0901375460671261, 0.1513456561951898, 0.21797332941787317, 0.1497261563781649, 0.13582439452875406, 0.1718916287063621, 0.11153153362101875, 0.10245167592074722, 0.10775655493489467, 0.08716370837646537, 0.28618998534511775, 0.14975276979384944, 0.1516082280431874, 0.1302506576757878, 0.1381691952701658, 0.20185359986498952, 0.11959122770349495, 0.18057512759696692, 0.14233795751351863, 6.875529661774635, 71.16140350699425, 97.33868524432182, 85.38203403353691, 58.92612084746361, 40.348317325115204, 64.17136698961258, 88.93450900912285, 87.88054436445236, 23.88440117239952, 1.1390830460004508, 0.4377795854816213, 2.5991417560726404, 2.1404439071193337, 0.3437109722290188, 0.49397747148759663, 0.7123166648671031, 0.13678627728950232, 0.24549523775931448, 6.495846435427666, 55.82763031125069, 93.38623613119125, 84.44065734744072, 81.56076908111572, 86.20777532458305, 89.6237464249134, 81.57475233078003, 84.54009801149368, 84.53553825616837, 85.63132345676422, 83.58259499073029, 87.03663244843483, 80.57096019387245, 83.1479363143444, 86.9824929535389, 88.56493324041367, 89.78503257036209, 78.38882088661194, 78.54243144392967, 82.17318221926689, 80.42638555169106, 74.6461509168148, 80.44338583946228, 76.75512135028839, 78.47065329551697, 75.97867861390114, 77.87353813648224, 53.013577312231064, 59.26328055560589, 44.982434660196304, 70.09432196617126, 89.39852491021156, 74.6289910376072, 85.20613387227058, 77.82238528132439, 71.08542278409004, 68.85997340083122, 73.86345371603966, 75.53931578993797, 75.08590131998062, 75.68243131041527, 80.73232993483543, 76.16595536470413, 75.64602926373482, 78.79518628120422, 80.89837342500687, 83.06936413049698, 83.87001156806946, 86.89865425229073, 88.00282940268517, 85.02196535468102, 77.03361600637436, 77.75154948234558, 70.42177319526672, 72.12246313691139, 81.67692884802818, 81.5813259780407, 76.50386363267899, 68.72964039444923, 73.49983602762222, 87.57499516010284, 46.98364667594433, 5.971962371841073, 0.12301093287533149, 0.13723490556003526, 1.0954370442777872, 3.292674128897488, 7.222102414816618, 3.8831234956160188, 1.6298882220871747, 0.33841963740997016, 3.8459436781704426, 43.96031990647316, 79.45994541049004, 42.884061858057976, 24.196516424417496, 40.41644386947155, 78.88071209192276, 71.27925038337708, 47.72594824433327, 8.967673648148775, 0.3359531541354954, 0.27300338668283075, 0.17985390848480165, 0.3251422889297828, 0.11650356682366692, 0.11121928240754642, 0.1863064372446388, 0.12419482169207186, 0.2801498235203326, 0.1749533589463681, 0.16274011664791033, 0.11474751925561577, 0.21091013186378404, 0.24245577194960788, 0.20622066396754235, 0.13063169113593176, 0.18030188366537914, 0.056091539954650216, 0.1559715368784964, 0.11999288544757292, 0.11500135602545924, 0.15369265369372442, 0.11211107674171217, 0.1187180019041989, 0.20451163145480677, 0.1780566939851269, 0.15398033981909975, 0.12006339689833112, 0.16097065847134218, 0.24758987536188215, 0.1991693110903725, 0.11634986061835662, 0.2792324696201831, 0.08509402177878655], [0.02840240347723011, 0.0034010934996331343, 0.027691876857716125, 0.07151621481170878, 0.04314008336223196, 0.036364390107337385, 0.0418401337810792, 0.012979641505808104, 0.08432483024080284, 0.03455579106230289, 0.03686965166707523, 0.0562421068752883, 0.049332700873492286, 0.06254251391510479, 0.027439453879196662, 0.04174188456090633, 0.016847796832735185, 0.028027255248161964, 0.024645193661854137, 0.08183226789697073, 0.0250221749956836, 0.07139422799809836, 0.06313173464150168, 0.030307750748761464, 0.08536496505257674, 0.04301649722037837, 0.04541341528238263, 0.08303370108478703, 0.05800697115773801, 0.017642481143411715, 0.03437025785387959, 0.10743776540039107, 0.03272739522799384, 0.011185459607077064, 0.03062862942897482, 0.08520571500412188, 0.03353925283590797, 0.04870124452281743, 0.05584744016232435, 0.053620499893440865, 0.10049426884506829, 0.07451642843079753, 0.5938610492739826, 29.58745624870062, 62.47139900922775, 69.48862686753273, 50.77594578266144, 22.936243750154972, 24.176181815564632, 55.41542463004589, 81.89838856458664, 45.67400895059109, 5.930989645421505, 0.0584634439292131, 0.20859564043348655, 0.9076624014414847, 0.2802744449581951, 0.5571552563924342, 0.32920343976002187, 0.4439343942794949, 0.29448458401020616, 0.10866175987757742, 15.652933269739151, 84.66941267251968, 92.99366399645805, 86.86839267611504, 74.30510401725769, 77.90905103087425, 81.84866443276405, 87.95974731445312, 80.99823966622353, 83.94110575318336, 75.91794267296791, 78.16233024001122, 79.56969872117043, 77.97419473528862, 78.13339099287987, 74.73183631896973, 76.90237104892731, 75.93274667859077, 77.59252041578293, 76.7757086455822, 75.1887010037899, 71.99998050928116, 74.88964945077896, 78.3646921813488, 85.33405780792236, 80.07760226726532, 48.55251029133797, 77.17721790075302, 34.916922971606255, 60.05854748189449, 79.05563950538635, 81.09111428260803, 71.03949844837189, 79.51195701956749, 79.64335396885872, 77.72656202316284, 77.76668027043343, 81.70879393815994, 82.49181032180786, 83.47059220075607, 80.78956246376038, 79.73315834999084, 77.68718093633652, 78.36496576666832, 82.15118899941444, 78.76033455133438, 78.57725277543068, 75.7743027806282, 77.537362575531, 79.2230661213398, 83.54012846946716, 83.20687115192413, 81.89135134220123, 64.61630031466484, 50.97503989934921, 59.56951752305031, 66.98241055011749, 80.75015857815742, 54.980032593011856, 13.595896549522877, 0.06182454169902485, 0.041409840268897824, 0.32005082932300866, 0.7688465877436101, 0.38690272020176053, 1.4196444349363446, 0.5714775191154331, 0.48369540134444833, 0.12787642335752025, 11.401516199111938, 52.887864857912064, 59.7538760304451, 22.031077221035957, 22.595320343971252, 47.37581603229046, 63.26757788658142, 41.482799649238586, 15.362690594047308, 0.49702757969498634, 0.21411808003904298, 0.08895634382497519, 0.045612503818119876, 0.01429295716661727, 0.028976946377952117, 0.03957903987611644, 0.027221084346820135, 0.05297116149449721, 0.03668277517135721, 0.052867565100314096, 0.05264332517981529, 0.02574275029473938, 0.038140742835821584, 0.05329039631760679, 0.0488220476108836, 0.05748790194047615, 0.037827192863915116, 0.07070179679431021, 0.03918240276107099, 0.047324271145043895, 0.034056949079968035, 0.09043987476616167, 0.09738872962770984, 0.06794707078370266, 0.024354399793082848, 0.027586723808781244, 0.03889205603627488, 0.05040612471930217, 0.06990901980316266, 0.025769584499357734, 0.03526640859490726, 0.05924667690123897, 0.026045841550512705, 0.033256676397286355, 0.04773353590280749, 0.07043849764158949, 0.035869611383532174, 0.008126005905069178, 0.041839161567622796, 0.04145361213886645, 0.03550005152646918, 0.053778198853251524, 0.05624865632853471, 0.03489782837277744, 0.04577654442982748, 0.06219223505468108, 0.03802906816417817, 0.026994154140993487, 0.07192881923401728, 0.0535497138480423, 0.03352523366629612, 0.06203121127327904, 0.028561334402184002, 0.022261083213379607, 0.037992235374986194, 0.026622763034538366, 0.03454094439803157, 0.01768976708262926, 0.047112510437727906, 0.09216047736117616, 0.06504549601231702, 0.04860288026975468, 0.0295037784599117, 0.04009190473880153, 0.06906636306666769, 0.03649441809102427, 0.0751472168485634, 0.045758473133901134, 0.010114314154634485, 0.04410424080560915, 0.07014156435616314, 0.08827988363918848, 0.10073853933135979, 0.09649042665841989, 0.0656574264576193, 0.09787997943931259, 0.09641756259952672, 4.073266480118036, 45.22898443043232, 77.65885725617409, 73.07269334793091, 35.25667034089565, 17.165546603500843, 39.59073297679424, 90.24060532450676, 106.28230333328247, 45.487283170223236, 4.164980258792639, 0.08554026033380069, 0.49115475732833147, 0.48751425580121577, 0.3761766676325351, 0.47685959783848375, 1.1622053990140557, 1.3827227661386132, 0.7674635807052255, 0.18299228773685172, 28.607882112264633, 100.18312901258469, 88.28736573457718, 77.08645597100258, 71.50906205177307, 79.84849736094475, 89.213847219944, 90.89404106140137, 78.27151358127594, 82.88274094462395, 80.45959576964378, 83.93605962395668, 88.6708715558052, 86.29198640584946, 81.63343638181686, 76.68110892176628, 82.06474363803864, 78.17067459225655, 83.14111948013306, 78.69436249136925, 80.20915880799294, 78.43096822500229, 78.54449853301048, 81.02748289704323, 86.26576021313667, 74.22083213925362, 48.33706945180893, 71.52610793709755, 37.05271616578102, 60.82298286259174, 79.44061204791069, 77.33580619096756, 75.66166162490845, 80.08697256445885, 81.28865048289299, 81.22894808650017, 78.46873059868813, 79.51389491558075, 78.31388890743256, 81.38442814350128, 82.50241935253143, 81.34313955903053, 83.68463471531868, 81.99690967798233, 83.8149981200695, 81.93592295050621, 81.99333786964417, 80.17743051052094, 78.5127854347229, 79.71301943063736, 81.03021115064621, 81.22552067041397, 83.75825196504593, 79.57922860980034, 63.84534448385239, 64.73762780427933, 67.36112862825394, 79.73920002579689, 70.26496320962906, 24.767426289618015, 0.4563709784997627, 0.12452869908884168, 0.9543303691316396, 1.568298158235848, 1.027889612596482, 0.2647507342044264, 0.724833965068683, 0.135431828093715, 0.24684995412826538, 12.436476163566113, 55.725799575448036, 76.02925390005112, 36.96241021156311, 14.971844516694546, 27.110887840390205, 63.55523765087128, 54.28108669817448, 22.276333160698414, 1.4871573122218251, 0.28496713377535343, 0.06104116029746365, 0.04969142908521462, 0.08453249058220536, 0.023709553242952097, 0.02306707599927904, 0.04660517457523383, 0.01343908101262059, 0.03501544393657241, 0.023560034605907276, 0.05455964324937668, 0.0590310162078822, 0.05638019829348195, 0.15792576014064252, 0.024567492655478418, 0.11081844844738953, 0.050801262696040794, 0.05072850995929912, 0.03172477969201282, 0.013465511674439767, 0.01677915373875294, 0.019960306672146544, 0.021805920332553796, 0.07504451845306903, 0.010215550519205863, 0.017513872517156415, 0.04921400177408941, 0.023883841058705002, 0.06927099544554949, 0.0218351999137667, 0.04424076629220508, 0.009798896753636654, 0.03223172221623827, 0.04161304030276369, 0.025416902935830876, 0.19625293789431453, 0.07327862258534878, 0.11155036932905205, 0.18801351048750803, 0.20219126221491024, 0.10104361397679895, 0.10538804257521406, 0.10571961931418628, 0.17358308716211468, 0.12426479879650287, 0.10940110965748318, 0.19401803438086063, 0.1536490154103376, 0.17931424838025123, 0.14950003882404417, 0.1384675980079919, 0.0968050082155969, 0.14981573360273615, 0.2036625106120482, 0.2225006083608605, 0.1832377159735188, 0.2425751241389662, 0.16241731209447607, 0.18373801256529987, 0.13485740579199046, 0.14342331880470738, 0.1261190028162673, 0.19313817378133535, 0.3087628522189334, 0.21654914802638814, 0.1385968504473567, 0.2131761610507965, 0.13633840600959957, 0.08238899739808403, 0.11850828581373207, 0.17924766289070249, 0.12418860249454156, 0.2796026231953874, 0.17941840138519183, 0.16506859014043584, 0.2828359231352806, 0.1961602139635943, 3.0753592774271965, 46.21149390935898, 91.03936046361923, 92.27328345179558, 60.627145171165466, 38.50317433476448, 39.69894737005234, 71.67549312114716, 97.60214030742645, 65.96999287605286, 10.408434737473726, 0.4286283702822402, 0.891928217606619, 4.103526631370187, 0.981853895355016, 0.7316572708077729, 1.3546920265071094, 0.7485158974304795, 0.5549707298632711, 0.12987222173251212, 22.363812066614628, 99.85793486237526, 92.91797205805779, 84.06896129250526, 73.31811457872391, 79.80900228023529, 84.62168723344803, 92.93613508343697, 85.83397418260574, 86.0742124915123, 79.5196782052517, 86.9266739487648, 96.83392032980919, 91.22379496693611, 85.53201958537102, 74.13081496953964, 86.04433849453926, 82.58789956569672, 91.08239695429802, 87.61908039450645, 87.30315014719963, 83.35780665278435, 84.25425454974174, 88.07958528399467, 92.40660309791565, 75.12794986367226, 62.925448045134544, 84.17613834142685, 51.33052982389927, 68.72271716594696, 82.24147215485573, 91.52150139212608, 80.13094380497932, 87.89346367120743, 92.97309949994087, 88.749238550663, 86.46303802728653, 86.93539068102837, 87.64396145939827, 90.24881288409233, 85.557561814785, 86.50514736771584, 86.7292745411396, 89.12899017333984, 90.56978926062584, 89.38605397939682, 85.96598669886589, 83.07852163910866, 76.82652711868286, 85.0424462556839, 92.01895549893379, 90.21033614873886, 96.49677202105522, 91.60599365830421, 63.74077409505844, 71.41653701663017, 74.80501279234886, 85.1849614083767, 60.966789945960045, 16.66742943227291, 0.2197758131660521, 0.07901060758740641, 1.0998894553631544, 2.289310419000685, 5.247142715379596, 9.258250705897808, 3.4441009908914566, 0.8949783258140087, 0.6943256396334618, 18.296592012047768, 69.86062690615654, 68.1595341861248, 35.01712739467621, 35.508577823638916, 60.30501365661621, 79.19304773211479, 60.677488669753075, 25.69673102349043, 1.2550527043640614, 0.4583085479680449, 0.23821052396669984, 0.12650711636524647, 0.16293500462779775, 0.1648754091002047, 0.09588619970600121, 0.16081841429695487, 0.12742501945467666, 0.14511225395835936, 0.1553720299853012, 0.1577207789523527, 0.16501770849572495, 0.16544655110919848, 0.31866889097727835, 0.10885504481848329, 0.16915086249355227, 0.17409650492481887, 0.19722267257748172, 0.19302035041619092, 0.12157495133578777, 0.12723663268843666, 0.18084794108290225, 0.16261448588920757, 0.1446286853752099, 0.08953313357778825, 0.17729096085531637, 0.13008085428737104, 0.12221521697938442, 0.19517061940860003, 0.18632358085596934, 0.12554622808238491, 0.09621272241929546, 0.18319689785130322, 0.23754676192766055, 0.12426789355231449], [0.13253077282570302, 0.03814748524746392, 0.05712456870242022, 0.05376966415497009, 0.09210763644659892, 0.07789063995005563, 0.0891062650771346, 0.05327633261913434, 0.17461167415603995, 0.06588622316485271, 0.02871400716685457, 0.11664392179227434, 0.033803104888647795, 0.02975255934870802, 0.012819379353459226, 0.13644025835674256, 0.04470257139473688, 0.16738735634135082, 0.07249619855429046, 0.09654064037022181, 0.1219445483002346, 0.09089153842069209, 0.04798653404577635, 0.08402531428146176, 0.005601174980256474, 0.02160540872864658, 0.0434213944390649, 0.03943220595829189, 0.11508740804856643, 0.05400431269663386, 0.036295236786827445, 0.2539341989904642, 0.07214031647890806, 0.07399760041153058, 0.16438293474493548, 0.10112083444255404, 0.07314493210287765, 0.0719073043728713, 0.09255423865397461, 0.083141401555622, 0.002576844344730489, 0.036262689900468104, 0.2480193562223576, 0.08247559118899517, 8.966512810438871, 39.229668751358986, 74.39015865325928, 75.92792093753815, 48.56638714671135, 24.101031348109245, 30.130245722830296, 69.11911949515343, 80.21687999367714, 30.249078646302223, 2.673963066190481, 0.12158940095105208, 1.246472408529371, 1.4543445291928947, 0.6011622387450188, 0.3567267581820488, 0.11953875044127926, 0.15814046346349642, 0.3386925993254408, 0.9676931833382696, 27.212443090975285, 85.77983468770981, 114.72671940922737, 96.12085819244385, 82.55848914384842, 77.94620543718338, 79.29545223712921, 82.0294663310051, 80.86884140968323, 85.25222539901733, 90.04436865448952, 101.92294165492058, 94.57495674490929, 85.4574903845787, 87.4272058904171, 77.53691419959068, 75.16287758946419, 77.95476257801056, 76.8220129609108, 80.70360347628593, 80.43297439813614, 75.77256247401237, 74.31938365101814, 79.81546193361282, 43.027979135513306, 47.718922421336174, 24.389164187014103, 40.73920235037804, 79.50936555862427, 79.31732386350632, 84.16141033172607, 74.46233958005905, 76.5818202495575, 77.0514066517353, 75.36156132817268, 72.54448369145393, 75.30810579657555, 66.98646113276482, 73.43257963657379, 74.35080036520958, 80.575200766325, 77.22400099039078, 77.88135051727295, 78.76972764730453, 78.70447754859924, 78.96611630916595, 68.40399026870728, 62.50375807285309, 69.83628541231155, 71.36827200651169, 70.2080574631691, 82.99697041511536, 83.71626421809196, 92.25114583969116, 56.725837513804436, 15.450492482632399, 0.1611077628331259, 0.06739020769600756, 0.45796024322044104, 0.2715001517208293, 0.7641958747990429, 0.4711181949824095, 0.20908006990794092, 0.40658979036379606, 0.4373238474363461, 5.212468151003122, 34.82611924409866, 65.83060875535011, 48.603583350777626, 23.695965483784676, 35.24385362863541, 55.315508991479874, 55.62425762414932, 28.629991225898266, 5.851916838437319, 0.1936472425586544, 0.07694883228396066, 0.028292383794905618, 0.024587786683696322, 0.0619566142995609, 0.037354771338868886, 0.13654450041940436, 0.06255866304854862, 0.06620714266318828, 0.12711210030829534, 0.03633983615145553, 0.0712896000186447, 0.0505978474393487, 0.004748144410768873, 0.08400595907005481, 0.04352394069428556, 0.07915563066489995, 0.06347651418764144, 0.07449741460732184, 0.1768129286938347, 0.11103332246420905, 0.01511060352640925, 0.07496147212805226, 0.0273268162709428, 0.06213019893039018, 0.018569262174423784, 0.07132161626941524, 0.13926677231211215, 0.04010079566796776, 0.12014690335490741, 0.012637491945497459, 0.10876264001126401, 0.06825448319432326, 0.017881237472465727, 0.04780467446835246, 0.08689856869750656, 0.04642566018446814, 0.10238088245387189, 0.034235936545883305, 0.06519037808175199, 0.059465202284627594, 0.1284882944310084, 0.059113999450346455, 0.0274244402316981, 0.10100988336489536, 0.12357676110696048, 0.09844233441981487, 0.09565183689119294, 0.0355018401023699, 0.017488795347162522, 0.02792361432511825, 0.05369425081880763, 0.03659641515696421, 0.03383803406904917, 0.04164055171713699, 0.0332580827671336, 0.11715062311850488, 0.09613196933059953, 0.057218090441892855, 0.03841061741695739, 0.02589175128377974, 0.007715098681728705, 0.07854268347728066, 0.03431900513533037, 0.025458739655732643, 0.019236402840761002, 0.040028918665484525, 0.04303256100683939, 0.16010397841455415, 0.034263132547494024, 0.04139779521210585, 0.09849948721239343, 0.0013485561953530123, 0.05568220098211896, 0.0430990648601437, 0.07581219600979239, 0.07325725615373813, 0.07617233059136197, 0.12480393197620288, 0.4550611472222954, 0.12365312068141066, 14.988344181329012, 52.823165729641914, 84.29222211241722, 62.60914921760559, 25.940478444099426, 20.23738157004118, 50.08369892835617, 100.7630766928196, 93.22675108909607, 28.59801784157753, 2.1004106802865863, 0.21706326340790838, 1.3296258402988315, 0.7898802403360605, 0.6497584842145443, 0.8320759073831141, 1.8098374223336577, 0.5656953575089574, 0.8192067104391754, 3.8685401156544685, 43.15251745283604, 106.76312953233719, 111.56145125627518, 85.71755602955818, 75.79901665449142, 76.16641134023666, 85.86573287844658, 87.20643773674965, 80.30900985002518, 87.35733523964882, 89.33771297335625, 92.17483073472977, 97.83772006630898, 88.20379301905632, 85.22156104445457, 80.55289596319199, 79.59030121564865, 79.90544110536575, 76.37034639716148, 77.47521311044693, 79.11060735583305, 73.91949310898781, 73.82340386509895, 81.10636666417122, 62.24979110062122, 71.15302875638008, 39.73171301186085, 54.189348220825195, 78.70482712984085, 80.41760042309761, 81.26454457640648, 80.05553305149078, 79.73432868719101, 78.57441052794456, 80.84312438964844, 80.93062609434128, 81.5464286506176, 76.4010639488697, 78.55836778879166, 78.21361228823662, 79.58989083766937, 77.65905484557152, 82.50442564487457, 85.72004869580269, 82.03201979398727, 81.72094568610191, 79.43488955497742, 73.1478001177311, 73.24468731880188, 82.78719127178192, 83.01063448190689, 81.51590868830681, 76.1395999789238, 92.21225872635841, 73.56254026293755, 28.263419196009636, 1.414187690243125, 0.35885690012946725, 1.119292639195919, 1.3470785412937403, 0.9888384549412876, 0.30057631025556475, 0.7369793602265418, 0.3825947310542688, 0.22925293509615585, 4.347457867115736, 37.89522975683212, 76.17683038115501, 64.98223587870598, 31.75724431872368, 25.597951523959637, 53.50524052977562, 68.54305520653725, 37.74129241704941, 8.707743845880032, 0.14429868198931217, 0.20437209284864366, 0.09387167694512755, 0.10425871645566076, 0.01930312191689154, 0.06032891746144742, 0.07652019747183658, 0.017623007188376505, 0.05111377366119996, 0.09348859515739605, 0.11219605265068822, 0.024119521185639314, 0.0013294736072566593, 0.04685629879531916, 0.027775624512287322, 0.04938566424243618, 0.06069197981560137, 0.063589884666726, 0.1237084403692279, 0.05278382115648128, 0.09591567781171761, 0.0021298847468642634, 0.05965652424492873, 0.058065355915459804, 0.03366298369655851, 0.014773546026844997, 0.06988564215134829, 0.050613395433174446, 0.019565751281334087, 0.06245567521546036, 0.05642169919156004, 0.08874468330759555, 0.05241254693828523, 0.06372697418555617, 0.02273619316838449, 0.09545408422127366, 0.061692346644122154, 0.17029661976266652, 0.15421736694406718, 0.23622790613444522, 0.13861040206393227, 0.21068696805741638, 0.2216174526256509, 0.14692787372041494, 0.14585925528081134, 0.45653603214304894, 0.2404651982942596, 0.2572469681035727, 0.1434706084546633, 0.16476493299705908, 0.131751072476618, 0.1502740097930655, 0.26577394804917276, 0.13326837855856866, 0.21767811791505665, 0.2666527102701366, 0.25348015304189175, 0.1618883092305623, 0.16508142929524183, 0.1322375502786599, 0.19774977554334328, 0.04378473138785921, 0.16287929902318865, 0.19219871872337535, 0.17197765846503899, 0.21698398719308898, 0.13518378749722615, 0.1287309470353648, 0.28412607265636325, 0.22454323625424877, 0.1705166813917458, 0.20985310577088967, 0.16876012174179778, 0.14978441497078165, 0.17073331429855898, 0.1870401541236788, 0.3988301020581275, 0.24779689003480598, 0.16848407249199226, 0.34585693676490337, 0.17284322530031204, 14.709912221878767, 65.88182240724564, 101.22164368629456, 89.33391317725182, 62.715406715869904, 36.9455087184906, 46.43975906074047, 81.17190554738045, 92.94647812843323, 44.00738798081875, 6.485842997208238, 0.32893193245399743, 2.6249485462903976, 5.9812557231634855, 4.9868182092905045, 1.4428096543997526, 0.7020138739608228, 0.30424056050833315, 0.7040904031600803, 1.94394885096699, 32.05871254205704, 99.71448495984077, 113.13568398356438, 88.14265429973602, 80.21814152598381, 79.23133447766304, 86.1110857129097, 88.6143533885479, 87.1058115363121, 97.68185243010521, 92.21578493714333, 99.99570026993752, 113.28116297721863, 109.20921787619591, 95.621397793293, 88.35923507809639, 79.94154676795006, 85.10543927550316, 74.39689189195633, 81.75467267632484, 80.21858230233192, 68.67295503616333, 68.36526274681091, 79.53471779823303, 62.674015536904335, 64.32718142867088, 40.25125913321972, 56.5366380661726, 83.68056133389473, 80.23516461253166, 91.81072667241096, 86.7301332950592, 80.20016849040985, 82.65891015529633, 81.50815710425377, 84.42352026700974, 84.04199793934822, 77.85880252718925, 87.4536980688572, 83.02360698580742, 83.92654493451118, 80.2581837773323, 83.75778079032898, 88.76115471124649, 87.13712945580482, 87.65783071517944, 84.49437126517296, 66.28735944628716, 58.665629625320435, 86.39219462871552, 96.37468457221985, 118.70649665594101, 107.16512516140938, 100.7392367720604, 69.2498704791069, 19.02100034058094, 0.5269862408749759, 0.3467527683824301, 1.3790368451736867, 3.1169575452804565, 2.997740604914725, 3.964253179728985, 5.744001679122448, 1.2894591456279159, 0.49662141711451113, 10.54248109459877, 50.00429078936577, 86.29756450653076, 64.83254671096802, 40.39774887263775, 52.11670383810997, 73.9084205031395, 78.46316769719124, 44.463036730885506, 9.391702394932508, 0.28191672870889306, 0.4997773258946836, 0.2555106393992901, 0.22227443143492565, 0.19490834441967309, 0.09112660627579316, 0.5275077628903091, 0.23748160136165097, 0.17393872432876378, 0.2720140147721395, 0.2898107754299417, 0.14892144565237686, 0.129026678041555, 0.19621053157607093, 0.1823128218529746, 0.17938686010893434, 0.17510074947495013, 0.11325121595291421, 0.24599495547590777, 0.15561956592136994, 0.2498290833318606, 0.18669588665943593, 0.15774427534779534, 0.17791933729313314, 0.17946285603102297, 0.12247992621269077, 0.245029911166057, 0.1810409885365516, 0.07128631972591393, 0.2376610823557712, 0.17873825272545218, 0.17429660278139636, 0.15707819780800492, 0.25985523127019405, 0.14628299191826954, 0.22415292594814673, 0.20286441984353587], [0.23116001713788137, 0.4337736504385248, 0.08865095005603507, 0.08453361864667386, 0.21659507212461904, 0.10753928378107958, 0.03236414362618234, 0.09263501400710084, 0.02167498507333221, 0.02862604411348002, 0.12509708030847833, 0.06967550303670578, 0.025827700228546746, 0.0668780886917375, 0.07026665334706195, 0.028384552970237564, 0.05959910798992496, 0.03566360603144858, 0.07525277993408963, 0.08030809694901109, 0.061919028230477124, 0.04543227325484622, 0.06352818993036635, 0.03122570393315982, 0.035629585981951095, 0.0743107867310755, 0.07344516794546507, 0.13854890770744532, 0.21849182347068563, 0.04800027119927108, 0.08593523132731207, 0.05463336448883638, 0.044757386422134005, 0.060405952390283346, 0.08447793530649506, 0.16077468695584685, 0.08658309656311758, 0.07583077196613885, 0.06548250225023367, 0.04866315008257516, 0.10307296484825201, 0.030877753561071586, 0.054092208956717514, 0.06939445171155967, 0.7886345009319484, 0.40561490517575294, 14.441163092851639, 49.50426422059536, 79.5718266069889, 77.73626670241356, 49.498009756207466, 26.39289166778326, 42.71357640624046, 65.77953949570656, 71.78191781044006, 23.95981002599001, 1.7584971897304058, 0.6306649837642908, 0.3870094410376623, 6.2340509332716465, 1.804699741769582, 0.3238425211748108, 0.4649966344004497, 0.15914939838694409, 0.48734753974713385, 0.4192931321449578, 15.004555061459541, 56.18347741663456, 98.09068769216537, 111.8224136531353, 99.502874314785, 90.3309416770935, 89.40152674913406, 87.03601688146591, 77.53978684544563, 90.82116097211838, 91.44722297787666, 91.1099074780941, 75.83574548363686, 80.2827076613903, 76.66600853204727, 74.65921461582184, 72.61041015386581, 72.77404457330704, 60.811458081007004, 63.697532415390015, 66.5419913828373, 22.977672927081585, 2.21354509703815, 4.477987512946129, 1.0206992109306157, 1.1793611221946776, 60.69682963192463, 84.56811770796776, 75.95663979649544, 74.96472582221031, 87.6688577234745, 85.73665380477905, 87.2871682047844, 88.88745233416557, 88.11727166175842, 86.2283930182457, 79.20038893818855, 75.69937080144882, 76.94754302501678, 70.36862164735794, 71.68814644217491, 64.32012140750885, 62.22895681858063, 46.36385813355446, 39.57515761256218, 27.01568014919758, 36.20069168508053, 56.53755761682987, 77.99017667770386, 85.02585634589195, 50.07460601627827, 11.941039748489857, 0.5221885826904327, 0.3740844939602539, 0.2811127156019211, 0.9946499462239444, 0.22414284758269787, 1.3220403785817325, 0.39281377801671624, 0.5956145364325494, 0.5153439030982554, 1.923462487757206, 27.971594855189323, 63.107636868953705, 57.89883837103844, 27.48694036155939, 21.142943277955055, 43.38417202234268, 58.409926146268845, 37.70492076873779, 6.997608561068773, 0.11563727268367074, 0.2408629300771281, 0.19067786517553031, 0.0422412312036613, 0.055639761267229915, 0.06434788461774588, 0.04218916583340615, 0.1532744089490734, 0.10139393736608326, 0.05835445212142076, 0.022243911771511193, 0.10964420755044557, 0.07102843825123273, 0.09886992280371487, 0.19016713398741558, 0.24683641735464334, 0.07870948858908378, 0.12483962927944958, 0.05190982352360152, 0.041936338384402916, 0.14145079418085515, 0.084258311544545, 0.16978348401607946, 0.13028136774664745, 0.1729913876624778, 0.1413297647377476, 0.03449792209721636, 0.18412384029943496, 0.04338195300078951, 0.1265870308270678, 0.09711184917250648, 0.06897004714119248, 0.21528568613575771, 0.12715933058643714, 0.1433700177585706, 0.11184109825990163, 0.1902692683506757, 0.16829353349749, 0.08035077786189504, 0.08704274572664872, 0.06187301878526341, 0.021368988309404813, 0.05203079359489493, 0.018187141467933543, 0.06548910736455582, 0.004846330084546935, 0.01944701507454738, 0.09440796027774923, 0.09166418836684898, 0.14050823694560677, 0.060241366300033405, 0.11657251976430416, 0.06542425107909366, 0.03267484746174887, 0.06114721320045646, 0.04082780724274926, 0.0607981625944376, 0.08211501874029636, 0.06748224885086529, 0.13403495773673058, 0.10872153245145455, 0.06996259544393979, 0.013226100400061114, 0.04242537288519088, 0.0413499118440086, 0.02291057004185859, 0.022760312967875507, 0.09221170039381832, 0.02287546274601482, 0.05013887363020331, 0.0400750023254659, 0.06423610975616612, 0.06379332218784839, 0.04903443172224797, 0.16942208778345957, 0.0852424067852553, 0.15930803987430409, 0.039469142648158595, 0.0498460926610278, 0.05475708421727177, 0.12718831887468696, 0.07514731332776137, 0.191289751091972, 0.5958860437385738, 1.718686013482511, 24.47472609579563, 69.37582612037659, 88.03112268447876, 59.759849309921265, 25.727788656949997, 28.631421849131584, 69.924645870924, 99.05734822154045, 80.54430082440376, 18.114847764372826, 0.5792212067171931, 0.02612826632685028, 1.3479754119180143, 2.098439773544669, 1.1528640752658248, 1.1578782624565065, 0.6954753748141229, 0.547418991336599, 0.5300068412907422, 1.3788396120071411, 30.19798468798399, 78.11468839645386, 110.03262609243393, 108.3425223827362, 88.85675758123398, 87.11612418293953, 85.22378772497177, 97.47958928346634, 77.55110263824463, 87.60928452014923, 101.34067609906197, 104.30561140179634, 110.38590833544731, 104.55797865986824, 94.17487621307373, 84.84788909554482, 87.87749692797661, 86.30115151405334, 76.84694722294807, 76.51908561587334, 84.52993735671043, 47.43603140115738, 11.917206477373838, 13.605073057115078, 3.8910581823438406, 8.252364881336689, 71.47911965847015, 83.27146768569946, 80.94201028347015, 80.14123365283012, 88.71203854680061, 90.09522512555122, 88.33173215389252, 82.11965069174767, 87.77842864394188, 85.28519243001938, 85.97195997834206, 81.46138921380043, 89.61820632219315, 83.65975365042686, 84.54200550913811, 77.58353769779205, 81.60244524478912, 76.91913574934006, 68.52049961686134, 44.81305494904518, 46.926254555583, 76.42278358340263, 98.56838285923004, 114.0912339091301, 72.58766457438469, 26.107348389923573, 2.0051813777536154, 0.9545359737239778, 1.8899525608867407, 1.3582455483265221, 0.6658711633644998, 0.5136246734764427, 0.5784582789056003, 0.44813067535869777, 0.15871200623223558, 1.4312252635136247, 28.217371366918087, 75.96194431185722, 71.50432750582695, 40.391418412327766, 26.84601165354252, 42.16369651257992, 67.0996342599392, 50.76948992908001, 13.580838907510042, 1.1144154821522534, 0.3363127098418772, 0.1659538535750471, 0.011337200048728846, 0.05870645647519268, 0.09394220323883928, 0.03547149368387181, 0.11972515567322262, 0.054579469724558294, 0.040947059242171235, 0.13490027224179357, 0.07871202673413791, 0.1496832157135941, 0.05074622131360229, 0.06537565524922684, 0.13968402257887647, 0.05812444200273603, 0.06377727695507929, 0.1311937195714563, 0.017348406981909648, 0.11547636764589697, 0.10845899028936401, 0.08668547583511099, 0.03317969341878779, 0.09546840767143294, 0.11027178246877156, 0.03625117919000331, 0.044291699887253344, 0.033878867034218274, 0.029173353905207478, 0.06102509651100263, 0.04002793531981297, 0.07165762363001704, 0.1657299476210028, 0.02734281326411292, 0.15372697060229257, 0.09205538925016299, 0.0959511153632775, 0.06472541514085606, 0.43303761805873364, 0.6013686745427549, 0.10687572954338975, 0.16558341798372567, 0.41366483259480447, 0.10621362249366939, 0.1915411907248199, 0.23742868623230606, 0.11887787535670213, 0.14037586748600006, 0.3027947380905971, 0.20320387819083408, 0.23878174019046128, 0.2163600636413321, 0.13801706983940676, 0.17663059785263613, 0.09479559885221533, 0.17598699254449457, 0.22276902833255008, 0.21298741805367172, 0.21097693999763578, 0.1310202945023775, 0.2976101537933573, 0.2040019689593464, 0.18090508645400405, 0.13244875066448003, 0.1504571273108013, 0.4558982007438317, 0.3576007706578821, 0.19785409182077274, 0.21154946240130812, 0.2074196480680257, 0.1575635327026248, 0.14139486593194306, 0.1697848050389439, 0.26607095554936677, 0.22027392784366384, 0.3636403090786189, 0.18034230102784932, 0.13993510598083958, 0.18907800258602947, 0.31506656552664936, 0.20767052366863936, 0.21272956626489758, 1.2101011164486408, 1.3491649855859578, 28.75248335301876, 78.97974237799644, 104.93906021118164, 93.59644085168839, 69.740971326828, 42.14320421218872, 58.67612466216087, 77.71450147032738, 88.84877040982246, 32.222677543759346, 3.992667105048895, 1.0871904180385172, 2.9219802701845765, 18.14274586737156, 7.162819895893335, 2.6415301440283656, 0.6889676302671432, 0.36678089993074536, 0.6545921217184514, 0.6418917188420892, 20.99492982029915, 67.07776263356209, 105.69763630628586, 106.78219690918922, 95.20245507359505, 98.32071214914322, 84.36314910650253, 107.75191247463226, 70.45967996120453, 69.48042690753937, 100.79615771770477, 106.71050235629082, 134.03014719486237, 133.53051960468292, 129.4285637140274, 108.70861753821373, 108.62426966428757, 92.24189713597298, 82.45517268776894, 91.22392416000366, 97.15180367231369, 42.61095151305199, 8.219788279384375, 8.690157439559698, 1.956088487058878, 4.118642695248127, 70.6031146645546, 96.08362779021263, 84.0407820045948, 87.4339771270752, 103.93394574522972, 100.53847074508667, 97.86230474710464, 92.30459377169609, 95.36301925778389, 93.43270763754845, 89.24234569072723, 88.82483169436455, 94.21580001711845, 90.10263472795486, 93.2559335231781, 80.52030131220818, 88.14286708831787, 79.07469168305397, 74.29436579346657, 59.39548306167126, 61.45316004753113, 91.33604854345322, 99.18366864323616, 91.30121201276779, 49.82565477490425, 12.860783245414495, 0.754241596441716, 0.805835168575868, 1.20251304237172, 2.2087293304502964, 2.179171903990209, 5.162038682028651, 5.239328434690833, 1.6025058226659894, 0.49971290747635067, 7.052491391077638, 43.87257881462574, 84.50722217559814, 71.26719743013382, 40.889214500784874, 35.434299409389496, 57.60382600128651, 73.37311282753944, 59.18015621602535, 18.022191636264324, 1.2802951061166823, 0.41760299471206963, 0.31678380619268864, 0.07371245985268615, 0.21732564229751006, 0.25897338171489537, 0.18748048518318683, 0.2780754317063838, 0.21948487643385306, 0.20403434144100174, 0.21274305850965902, 0.1675463985884562, 0.16936212225118652, 0.23969296395080164, 0.23620236141141504, 0.37225996842607856, 0.161284928326495, 0.1733044403954409, 0.4002192837651819, 0.1164026273181662, 0.3495999437291175, 0.37371009530033916, 0.24733380472753197, 0.4428796243155375, 0.2636745903873816, 0.35618635592982173, 0.19846109440550208, 0.2820249041542411, 0.1523389169597067, 0.2205151109956205, 0.1688573876162991, 0.13872157578589395, 0.37341961869969964, 0.2784001955296844, 0.28577631223015487, 0.24902033532271162, 0.3428798558888957, 0.2441682034987025, 0.24890194792533293], [0.034773333100019954, 0.026100795730599202, 0.14429703442147002, 0.2860152837820351, 0.06905541638843715, 0.05791136027255561, 0.09085026758839376, 0.0201283418937237, 0.07718939203186892, 0.02133527068508556, 0.09235220379196107, 0.14616041880799457, 0.0913077051518485, 0.030561025341739878, 0.08016181222046725, 0.058667259945650585, 0.12017419212497771, 0.1976509956875816, 0.07917324182926677, 0.12336007624980994, 0.06749175576260313, 0.15099120646482334, 0.032722767937229946, 0.0638958573108539, 0.03319806528452318, 0.057657360230223276, 0.04296317019907292, 0.06998894910793751, 0.03846466432150919, 0.04599792337103281, 0.04083548847120255, 0.024749482108745724, 0.09233908262103796, 0.08151793124852702, 0.04963400540873408, 0.01895061846880708, 0.08473522306303494, 0.02452388591336785, 0.03518146608257666, 0.10673404613044113, 0.0578659482562216, 0.08457022137008607, 0.03610681291320361, 0.05699272245692555, 0.08681051287567243, 0.19782197166932747, 0.07767705727019347, 0.832122751744464, 27.878547348082066, 66.35724529623985, 80.5264949798584, 70.97861051559448, 42.441454008221626, 21.349234208464622, 42.76585400104523, 77.32199773192406, 64.76381599903107, 21.231792010366917, 1.7601028410717845, 0.7559578574728221, 2.450196398422122, 5.01092316582799, 0.2788923878688365, 0.26982212613802403, 1.6482431371696293, 0.5951529799494892, 0.12774389062542468, 0.15024867287138477, 5.78235587105155, 31.282568089663982, 74.21162903308868, 99.80378776788712, 98.40502202510834, 88.27225014567375, 84.3365429341793, 79.4108672440052, 70.58565080165863, 64.24552381038666, 68.98792013525963, 69.4776302576065, 95.11430740356445, 93.74858468770981, 84.93986696004868, 77.80346989631653, 55.036052986979485, 30.567022785544395, 7.709261924028397, 0.10905373259447515, 0.1355937053449452, 0.12911868951050565, 0.24739035638049245, 0.679096591193229, 2.7297770837321877, 36.944311782717705, 49.42425191402435, 57.723378986120224, 55.48466831445694, 90.76838940382004, 77.27852806448936, 64.81500685214996, 61.588379591703415, 54.794431552290916, 59.555804058909416, 67.12129309773445, 74.2679800093174, 70.37790074944496, 57.36186258494854, 44.824857115745544, 31.647606901824474, 28.87902606278658, 26.908579096198082, 38.61188270151615, 46.886143907904625, 47.56023533642292, 26.45267765969038, 5.1918913051486015, 0.21817931992700323, 0.3514711948810145, 1.4944176538847387, 14.743713308125734, 1.7429384496062994, 1.563355098478496, 0.9440709196496755, 0.6285331200342625, 1.016699569299817, 0.5631805455777794, 22.18396581709385, 60.34757897257805, 57.98068217933178, 30.884640142321587, 21.9370873644948, 34.503512755036354, 52.51051850616932, 46.79915517568588, 17.72646300494671, 1.0407048999331892, 0.056696319807088, 0.06947166475583799, 0.2775510598439723, 0.1669981295708567, 0.05180224921787158, 0.030778200016357005, 0.04816414482775144, 0.0189789870637469, 0.05043192548328079, 0.047071161679923534, 0.010715164335124427, 0.07321779616177082, 0.08445647239568643, 0.007238902408062131, 0.04948929403326474, 0.04648322115826886, 0.06508788006613031, 0.03954033316404093, 0.10618634856655262, 0.10371633266913705, 0.04234394815284759, 0.11623954778769985, 0.046597708569606766, 0.12695777812041342, 0.2362076158169657, 0.06619421445066109, 0.05971929138468113, 0.023343245848082006, 0.04532421655312646, 0.018356712935201358, 0.021719922115153167, 0.10547911151661538, 0.043785551461041905, 0.0608199409180088, 0.01473808342780103, 0.11907110092579387, 0.2613904676400125, 0.1881419020355679, 0.19996113813249394, 0.1742484819260426, 0.0991033430909738, 0.222159665718209, 0.13175551051972434, 0.10638752995873801, 0.16983383131446317, 0.08724798666662537, 0.1622157744714059, 0.03175473648298066, 0.03565478931705002, 0.002439738591419882, 0.1665569969918579, 0.08918442807043903, 0.1446951224352233, 0.034740066330414265, 0.014061298552405788, 0.11497254585265182, 0.09686631703516468, 0.14007936464622617, 0.03842136371531524, 0.13576698198448867, 0.08457448129775003, 0.13573821634054184, 0.013327224514796399, 0.06662713887635618, 0.04339926359534729, 0.06536899076309055, 0.05637793474306818, 0.04842381116759498, 0.01794746858649887, 0.009969702041416895, 0.04090430411451962, 0.07463186950189993, 0.053872863500146195, 0.07609194857650436, 0.03169184688886162, 0.026433084931341, 0.08775550435530022, 0.019132491033815313, 0.04909327661152929, 0.08598999440437183, 0.097696060402086, 0.06236865097889677, 0.052379777407622896, 0.07896159615484066, 0.06696762880892493, 0.11622562509728596, 0.07963433818076737, 3.3118880353868008, 35.07458031177521, 81.5015758574009, 79.79549020528793, 49.680567160248756, 23.30741923302412, 25.303416028618813, 67.43957921862602, 104.12305399775505, 72.4007374048233, 16.429632492363453, 0.8506087004207075, 0.4157313279574737, 2.0394132658839226, 1.213639557827264, 0.7182337192352861, 0.03190049799741246, 2.3810101859271526, 2.159858252853155, 0.38407766085583717, 0.8510833187028766, 13.000353556126356, 53.59001778066158, 100.84123849868774, 107.72539749741554, 104.80529978871346, 90.28288185596466, 74.39259052276611, 91.94631099700928, 91.38284683227539, 74.37897965312004, 91.20839819312096, 110.13791084289551, 138.1033158302307, 123.71185407042503, 116.1683164536953, 95.71682587265968, 63.633399456739426, 44.75782111287117, 20.24040050804615, 1.2293426902033389, 0.05323542543919757, 0.2623867563670501, 0.45826247544027865, 0.2913221443304792, 12.025519665330648, 63.76624032855034, 70.81045433878899, 75.20126312971115, 78.08842420578003, 93.60027864575386, 89.2559489607811, 87.82037079334259, 79.61980283260345, 78.47640618681908, 71.33341267704964, 73.48599717020988, 79.57574039697647, 80.1296366751194, 75.9309683740139, 72.50129520893097, 64.63183388113976, 43.1533420085907, 26.34167041629553, 51.57670721411705, 69.01998281478882, 71.06593742966652, 44.41813454031944, 14.009131025522947, 0.9024930757004768, 0.4645395901752636, 1.4664298994466662, 21.424228884279728, 1.2939234310761094, 1.76949035609141, 0.5654908809810877, 0.6394033273681998, 0.33742943429388106, 0.4924830829259008, 19.01356603950262, 69.7588075697422, 76.56995728611946, 44.82480771839619, 26.020619943737984, 30.970785319805145, 54.61868338286877, 58.83841395378113, 25.732179321348667, 2.6167730474844575, 0.04921095896861516, 0.19818250701064244, 0.2264517283765599, 0.049789307231549174, 0.042204168348689564, 0.03476011916063726, 0.08095527198747732, 0.05816174605570268, 0.07261753227794543, 0.0961924172588624, 0.04395193354866933, 0.09119801572524011, 0.0744805381691549, 0.022995492145128082, 0.06491520456620492, 0.04134359987801872, 0.08954320452176034, 0.04062520463776309, 0.18413500220049173, 0.038118778975331225, 0.0946343524265103, 0.17058340046787634, 0.056798661971697584, 0.07697238805121742, 0.08421691454714164, 0.10051190227386542, 0.07925524172605947, 0.05720337365346495, 0.06811649567680433, 0.08562750721466728, 0.15815310965990648, 0.11535861107404344, 0.04005402923212387, 0.07897933348431252, 0.09000991893117316, 0.2621070557506755, 0.351257337606512, 0.2521587739465758, 0.20306482940213755, 0.0657042114471551, 0.137444814608898, 0.20808525063330308, 0.33020985138136894, 0.25884101225528866, 0.2293270904920064, 0.12601725436979905, 0.1979003573069349, 0.16184519045054913, 0.11998622096143663, 0.15659378317650408, 0.15864303102716804, 0.2797933551482856, 0.167091105831787, 0.1484822723432444, 0.2942817402072251, 0.1286057021934539, 0.3615256631746888, 0.34688558313064277, 0.23884418449597433, 0.2797924942569807, 0.17334830132313073, 0.23763006058288738, 0.1556571334367618, 0.1916596820228733, 0.1900263485731557, 0.2105599717469886, 0.10190505447098985, 0.14379503089003265, 0.0859910408325959, 0.0738432708021719, 0.11683284290484153, 0.23623850400326774, 0.13033780065597966, 0.1923904154682532, 0.1270520011894405, 0.15895740478299558, 0.16709866089513525, 0.07568491026177071, 0.2448496434953995, 0.1650320616317913, 0.33075509243644774, 0.12058533451636322, 0.1659616461256519, 0.24630137340864167, 0.1875539726461284, 0.2704471332253888, 0.25413264927919954, 5.5339366011321545, 45.547335147857666, 98.54187548160553, 105.00217482447624, 88.78152161836624, 63.67990896105766, 36.2237374484539, 63.64830605685711, 88.98904368281364, 79.67253640294075, 28.528384678065777, 2.9874020721763372, 0.8038745925296098, 6.200600853189826, 13.589321952313185, 1.6892948281019926, 0.21917264006333426, 3.891032296232879, 2.326930775307119, 0.2524938090937212, 0.7810424489434808, 7.8852414060384035, 44.46937099099159, 86.91736444830894, 101.55917197465897, 106.34188413619995, 88.46797004342079, 88.69223400950432, 82.88765028119087, 83.96350175142288, 64.27927359938622, 98.46256613731384, 119.87247169017792, 162.77273207902908, 158.7022688984871, 151.60172671079636, 116.71122372150421, 72.40324527025223, 39.414711222052574, 11.256828512996435, 0.7100632670335472, 0.2863286482170224, 0.6942032149527222, 1.2747991760261357, 0.6935175892431289, 5.520007023587823, 54.07668046653271, 75.17179191112518, 91.2154658138752, 73.95537078380585, 100.04669353365898, 100.47128275036812, 89.74547669291496, 84.00878012180328, 83.96450489759445, 88.660748898983, 89.64276060461998, 98.97479385137558, 95.30108258128166, 88.4578549861908, 86.623625010252, 79.19240936636925, 57.05153323709965, 36.41205534338951, 73.56154471635818, 79.4541697204113, 58.8847790658474, 27.465222626924515, 7.345012994483113, 0.48215915565378964, 0.6399011006578803, 2.432670551352203, 24.95779037475586, 2.94516425114125, 3.577238484285772, 6.26659476198256, 2.4726379942148924, 1.1498973844572902, 2.311639920808375, 32.494784742593765, 79.81901854276657, 73.02297681570053, 46.942928060889244, 35.5242557823658, 47.55260914564133, 68.70622605085373, 68.32620844244957, 34.47083830833435, 3.686765469610691, 0.24017559742787853, 0.3289954306092113, 0.7848866551648825, 0.257715797633864, 0.15903567167697474, 0.14707199879921973, 0.1484008735860698, 0.1501624649972655, 0.14421474508708343, 0.18267222912982106, 0.16584756318479776, 0.25763947516679764, 0.2857886318815872, 0.16811172215966508, 0.24678685673279688, 0.1825097730034031, 0.21583061548881233, 0.2548905601724982, 0.4026276123477146, 0.21418653574073687, 0.24035338632529601, 0.26117821340449154, 0.1479001613915898, 0.19655481388326734, 0.30703088734298944, 0.1298279600450769, 0.13130645180353895, 0.16551058361073956, 0.29381819476839155, 0.22340448485920206, 0.2927724493201822, 0.29298054752871394, 0.1639494314440526, 0.18206050648586825, 0.18435268895700574, 0.2788106328807771, 0.6237286340910941, 0.23913602664833888, 0.2581942453980446, 0.27181565354112536], [0.24087870813673362, 0.06782679090974852, 0.06543407711433247, 0.6391857890412211, 0.05330965133907739, 0.5566942936275154, 0.36928576708305627, 0.7454342627897859, 1.6121185943484306, 0.6907778175082058, 2.206171592697501, 0.042654169592424296, 0.07946870566229336, 0.551749155856669, 0.06279166031163186, 0.44138529512565583, 0.30031296657398343, 1.0970354522578418, 0.48994262237101793, 0.31223476747982204, 0.1814336737152189, 0.1256705229752697, 0.016157447353180032, 0.26054997055325657, 0.056550213193986565, 0.19622112944489345, 0.1230613247025758, 0.04510976927122101, 0.04629714989278, 0.08895036211470142, 0.11194326973054558, 0.04115706105949357, 0.06906277107191272, 0.14351718564284965, 0.1274010183988139, 0.020111951562284958, 0.11862958243000321, 0.055634184027439915, 0.09091208848985843, 0.14796092844335362, 0.058561292389640585, 0.08125047606881708, 0.003598218359002203, 0.06839040011982433, 0.022919616822036915, 0.08938837025198154, 0.03546872176229954, 0.20516515185590833, 0.4597115336218849, 8.906988054513931, 44.99363265931606, 68.26174110174179, 80.32747685909271, 67.55184799432755, 33.83910320699215, 23.380105532705784, 42.818811759352684, 68.84067043662071, 63.045422807335854, 20.86228083819151, 0.6213900970760733, 1.5372649859637022, 1.6169425542466342, 0.8038893761113286, 1.7992704268544912, 1.1263029067777097, 0.23202644486445934, 0.13932715344708413, 0.07432171114487574, 0.13983117562020198, 1.5351703483611345, 15.18000589683652, 49.285327568650246, 62.39170588552952, 71.23847097158432, 51.857591941952705, 28.309704512357712, 40.74825346469879, 33.961646631360054, 32.76089206337929, 20.671728663146496, 14.169878549873829, 7.735452493652701, 2.710446333512664, 0.9269967733416706, 0.11631749555817805, 0.2043827500892803, 0.14729021990206093, 0.24233722127974033, 0.3926063922699541, 0.018527904139773455, 0.07082808064296842, 1.680149668827653, 1.1527360696345568, 5.529044363647699, 43.8296715170145, 38.65042023360729, 63.27852889895439, 147.36045509576797, 61.16303041577339, 81.84966757893562, 103.65503311157227, 109.26377534866333, 77.10069000720978, 62.41695933043957, 55.064635053277016, 48.65661710500717, 32.47930057346821, 32.91640631854534, 40.19683465361595, 58.040969744324684, 26.201790422201157, 7.43241305463016, 0.9415643010288477, 0.2507833665004, 0.13534136029193178, 0.6464510585647076, 3.9319304516538978, 4.0346320532262325, 11.18616845458746, 3.6750920210033655, 0.5592601059470326, 0.6935913884080946, 0.5348425568081439, 19.645620323717594, 58.959046080708504, 63.19323107600212, 34.39005844295025, 21.45359180867672, 32.0063703507185, 52.6626281440258, 66.08057454228401, 36.88691586256027, 3.2952532405033708, 0.25507378159090877, 0.09030746819917113, 0.046688825750607066, 0.05153819307452068, 0.059559362271102145, 0.13298943493282422, 0.10283296171110123, 0.10333023776183836, 0.06165742488519754, 0.21638594975229353, 0.12896055268356577, 0.0853834074223414, 0.15552785131148994, 0.12206770770717412, 0.07694063897361048, 0.01813791666791076, 0.04910454612399917, 0.060763133224099874, 0.12637727020774037, 0.1355314688407816, 0.11230521515244618, 0.048632083780830726, 0.05525507644051686, 0.039237689052242786, 0.033318975984002464, 0.06742038342054002, 0.05880764460016508, 0.0688403271487914, 0.1565781090175733, 0.1781200140248984, 0.1142161044117529, 0.028037741794832982, 0.03211105642549228, 0.05331922133336775, 0.2179341291775927, 0.23841906746383756, 0.23095864278730005, 0.0745893592829816, 0.07576699179480784, 0.1287220709491521, 0.13521615997888148, 0.26697462424635887, 0.11770985365728848, 0.1280171048711054, 0.09254272052203305, 0.3343076049350202, 0.12383088731439784, 0.22687889373628423, 0.1547496352577582, 0.24713891674764454, 0.39300973468925804, 0.320913145551458, 0.5313908576499671, 0.0124119143038115, 0.09144074996584095, 0.1117675143177621, 0.12753885006532073, 0.3227407584199682, 0.05552730362978764, 0.29306663665920496, 0.19271114200819284, 0.11943548059207387, 0.018571453365439083, 0.0763892158283852, 0.034918938763439655, 0.11942880126298405, 0.05752355842560064, 0.042100085847778246, 0.011067129726143321, 0.01640454171138117, 0.006810018048781785, 0.16766791784903035, 0.09240657353075221, 0.021649047012033407, 0.1350966890458949, 0.13859046797733754, 0.2267895985278301, 0.061026365583529696, 0.03903615885064937, 0.01401129078658414, 0.06884883958264254, 0.024547120701754466, 0.055489865990239196, 0.025468910789641086, 0.03003068846737733, 0.049514545607962646, 0.04813253675820306, 0.08231018131482415, 0.07694219006225467, 0.2150702109793201, 0.790522227762267, 11.546608563512564, 50.798771157860756, 82.36574068665504, 77.73305207490921, 45.58412857353687, 24.22470521181822, 32.88282372057438, 70.16790121793747, 104.46949660778046, 71.11827582120895, 12.174190487712622, 1.0986988130025566, 0.8081852237228304, 1.2760028801858425, 1.0985199850983918, 1.7717593093402684, 1.796060549095273, 0.602445857366547, 0.3868090908508748, 0.07647500809980556, 0.754041513428092, 5.069340756163001, 33.17490264773369, 66.09388142824173, 74.8220206797123, 83.43186467885971, 69.37049120664597, 49.05645065009594, 67.93470025062561, 61.370810866355896, 68.27025264501572, 63.535436913371086, 54.62353192269802, 33.08365814387798, 14.966983627527952, 6.34755939245224, 1.3547734846360981, 0.45383336779195815, 0.6234159227460623, 0.45869716617744416, 1.3237787852995098, 0.16524942184332758, 1.1875211843289435, 0.4268396756378934, 3.1776505010202527, 25.01619514077902, 72.64420554041862, 68.5832342505455, 64.43359851837158, 122.7196741104126, 72.66212537884712, 111.05481684207916, 114.4602245092392, 116.18442758917809, 85.86426615715027, 79.72390964627266, 80.23666933178902, 67.61452183127403, 48.25793109834194, 38.776375874876976, 43.67046765983105, 58.05898457765579, 37.906097173690796, 15.98441418260336, 4.818916143849492, 0.7060364331118762, 0.10089753704960458, 0.44051745731849223, 1.6735741216689348, 4.6455214731395245, 12.51747451722622, 2.226395532488823, 1.2640281789936125, 0.23179292067652568, 0.431888981256634, 14.513974785804749, 70.0893746316433, 89.13981959223747, 51.38197906315327, 25.204847417771816, 24.630086459219456, 49.560976177453995, 71.77357345819473, 43.06985668838024, 6.1877551674842834, 0.2701999683631584, 0.07757022511214018, 0.017214998515555635, 0.05373710984713398, 0.11308211018331349, 0.11424009804613888, 0.021820529509568587, 0.03874034991895314, 0.04498780101130251, 0.1770701422356069, 0.2199753321474418, 0.18925384705653414, 0.12751698639476672, 0.024085183868010063, 0.06161063247418497, 0.06946902271010913, 0.09762208312167786, 0.006938250498933485, 0.02403036141913617, 0.04823288996703923, 0.034492649137973785, 0.03857539646560326, 0.0648070959141478, 0.04658327750803437, 0.06185789010487497, 0.006380364638971514, 0.12303614363190718, 0.12095719503122382, 0.03788519912632182, 0.05973889150482137, 0.03594293557398487, 0.023492649452236947, 0.03530742338625714, 0.04166904647718184, 0.04847777643590234, 0.2022083761403337, 0.05006155297451187, 0.10721293918322772, 0.09890303743304685, 0.22866047860588878, 0.09641146214562468, 0.24325577745912597, 0.3050364396767691, 0.265567630995065, 0.15073498740093783, 0.425921015557833, 0.13959790376247838, 0.6636420486029238, 0.406025965930894, 1.058459091000259, 1.784463096410036, 0.9106331295333803, 2.4387293262407184, 0.09750582568813115, 0.29795166046824306, 0.7336460484657437, 0.2614241314586252, 0.6458557967562228, 0.4282847559079528, 1.275077392347157, 0.4936349258059636, 0.41234422533307225, 0.3052894229767844, 0.15885954519035295, 0.194609496393241, 0.4200726543786004, 0.267369476496242, 0.3523710637819022, 0.5154941137880087, 0.1750015837023966, 0.11022853752365336, 0.25947655783966184, 0.2335932818823494, 0.23699067067354918, 0.2399509641691111, 0.3231684729689732, 0.4007782693952322, 0.12282240510103293, 0.13721075607463717, 0.09131036946200766, 0.2871974359732121, 0.17305352026596665, 0.193079870659858, 0.23197774513391778, 0.09263462066883221, 0.25368958711624146, 0.23484945588279516, 0.24067639868007973, 0.1797243591863662, 0.41763707413338125, 0.5532557750120759, 16.559986397624016, 64.48226630687714, 93.3540290594101, 101.86846017837524, 81.77161976695061, 46.6217502951622, 40.52043668925762, 58.07706020772457, 89.55838993191719, 82.50391647219658, 29.346266090869904, 2.2008563904091716, 2.5346613535657525, 6.171152433380485, 4.62576063349843, 6.099919080734253, 2.9091438464820385, 0.7511293853167444, 0.19325362227391452, 0.29605229676235467, 0.38842041220050305, 2.039191690273583, 23.53794526308775, 56.608803793787956, 69.16444346308708, 72.50236675143242, 68.42479795217514, 50.67908518016338, 85.2163477241993, 59.31639790534973, 62.109004855155945, 40.51459260284901, 32.507168278098106, 16.608973369002342, 5.0281167682260275, 1.8533642054535449, 0.5932060594204813, 0.31540456926450133, 0.20651838392950594, 0.37370881880633533, 0.6312891002744436, 0.17857710277894512, 1.068481884431094, 1.5011958964169025, 1.452897994313389, 19.48606688529253, 87.91836753487587, 92.427828758955, 50.80741189420223, 170.61428010463715, 92.2705551981926, 179.29751336574554, 187.0585361123085, 156.7610290646553, 87.0380611717701, 69.59336444735527, 81.33686989545822, 72.70175725221634, 53.88113155961037, 45.75603514909744, 50.25652505457401, 62.96769417822361, 32.04429231584072, 9.590339586138725, 2.154577011242509, 0.5465239018667489, 0.22810986440163106, 0.8915435476228595, 5.404018722474575, 6.196680888533592, 19.178254902362823, 11.556863263249397, 1.985630001872778, 0.7403833838179708, 1.1112234159372747, 28.30301497131586, 77.06605106592178, 82.43768602609634, 50.24780452251434, 33.51973034441471, 46.15986227989197, 67.69775256514549, 85.0722898542881, 53.23190599679947, 10.175890065729618, 0.257521117455326, 0.11972408698056825, 0.24754904239671305, 0.12981751060578972, 0.27806156838778406, 0.23593927006004378, 0.18364174116868526, 0.2952055062633008, 0.09676201560068876, 0.3969163110014051, 0.41172705532517284, 0.2350226286216639, 0.22241064521949738, 0.14731172734173015, 0.16922840208280832, 0.17364950937917456, 0.22179602819960564, 0.15532987599726766, 0.2614066464593634, 0.25710676156450063, 0.2284283348126337, 0.20721812528790906, 0.1506986518506892, 0.1472147583262995, 0.24145510455127805, 0.18433000892400742, 0.22338677721563727, 0.3623075899668038, 0.1704720634734258, 0.29991128656547517, 0.1610256516141817, 0.13512587029254064, 0.1740957479341887, 0.17185486271046102, 0.19547007599612698, 0.6221194204408675, 0.3546247584745288, 0.18996970786247402, 0.23091473733074963, 0.34265148220583797, 0.20690863486379385, 0.32053773757070303], [0.03612380438426044, 0.03500690923829097, 0.12241384538356215, 0.03831072805041913, 0.053454284789040685, 0.04120902252907399, 0.133679335413035, 0.09060919575858861, 0.15123078657779843, 0.06090905058954377, 0.06550104852067307, 0.07381081668427214, 0.029235677611723077, 0.04204524855595082, 0.09278682773583569, 0.02846515391865978, 0.08217674316256307, 0.0667184081976302, 0.10669825234799646, 0.05382859439123422, 0.06266064898227341, 0.10229618856101297, 0.07524675369495526, 0.015279809485946316, 0.045025012295809574, 0.06582433547009714, 0.07009171429672278, 0.03872364788549021, 0.020861995690211188, 0.036570825905073434, 0.05918563525483478, 0.09962770753190853, 0.03824109604465775, 0.03366603021277115, 0.03568564781744499, 0.09293660797993653, 0.062276602402562276, 0.057960664853453636, 0.017520540714031085, 0.06103918989538215, 0.0773435880546458, 0.04588545831211377, 0.028728217439493164, 0.026028456741187256, 0.06961725928704254, 0.03351913321239408, 0.06492658169008791, 0.05707704527594615, 0.040977194148581475, 0.40011532371863723, 0.1963308485574089, 11.882762275636196, 49.06248092651367, 71.0888122022152, 75.28651535511017, 53.31911511719227, 29.398359395563602, 20.552166178822517, 41.00511208176613, 71.51738360524178, 74.02798488736153, 25.310422852635384, 1.7026455304585397, 1.6956774168647826, 0.8069662016350776, 3.5728710936382413, 2.141737025231123, 1.406233529560268, 0.521007024217397, 0.263057776610367, 0.2535733667900786, 1.319253584370017, 1.0312545695342124, 0.053363375409389846, 2.3476724373176694, 5.240688286721706, 13.4006373770535, 11.288008689880371, 0.9139483922626823, 1.03062974056229, 0.9907439933158457, 0.31362077279482037, 0.6936835928354412, 0.09374119996209629, 0.07093399253790267, 0.09631933935452253, 0.029031588856014423, 1.531901692505926, 0.7524050481151789, 0.6682356458622962, 0.5166510923299938, 0.22649496590020135, 0.20673981111031026, 0.29500399832613766, 0.023457762945326976, 2.3787395702674985, 8.874030523002148, 16.97130862623453, 26.08977623283863, 28.10610193759203, 26.106398440897465, 28.769318349659443, 17.1263213083148, 12.488541919738054, 7.062716642394662, 10.090155266225338, 17.125323861837387, 27.268794067204, 27.27912001311779, 7.604590840637684, 3.958503375761211, 0.25838945992290974, 0.0757708064338658, 0.30565435183234513, 0.27854740794282407, 0.623158902162686, 0.7702041242737323, 1.3501138659194112, 1.4584854757413268, 0.4325835424242541, 0.4616215545684099, 0.376447492162697, 22.97639239579439, 53.875891640782356, 62.60570280253887, 25.543340854346752, 18.390712961554527, 28.332037813961506, 57.9445119202137, 63.262983933091164, 45.919969752430916, 12.06770595163107, 0.5145655979868025, 0.19716396869625896, 0.027893598162336275, 0.04514577456575353, 0.09157319364021532, 0.07479338310076855, 0.08713905423064716, 0.011430953709350433, 0.043601146317087114, 0.06728249980369583, 0.020483405751292594, 0.10139211168279871, 0.0643372125341557, 0.060515864461194724, 0.05550180714635644, 0.026603812293615192, 0.08844349009450525, 0.011334377104503801, 0.05065065866801888, 0.02689776214538142, 0.07314698043046519, 0.04990727531549055, 0.03682357171783224, 0.058414632876520045, 0.037190344810369425, 0.05079857241071295, 0.12909831013530493, 0.08529682105290703, 0.057486922305542976, 0.047861415368970484, 0.04873594734817743, 0.05268232875096146, 0.05970139078272041, 0.06501302705146372, 0.0438389341434231, 0.017776607637642883, 0.03534883522661403, 0.08692774252267554, 0.03444925576332025, 0.0739562553644646, 0.1273294902057387, 0.032998208625940606, 0.01558495463541476, 0.1188718194316607, 0.03653830870462116, 0.046905373310437426, 0.07781313746818341, 0.1152731453476008, 0.07031864821328782, 0.07452002784702927, 0.18608642014442012, 0.20173187280306593, 0.46238664945121855, 0.1982955212588422, 0.4840921831782907, 0.038489811995532364, 0.016105085123854224, 0.13642041332786903, 0.06600193883059546, 0.15460715774679556, 0.1806696772109717, 0.24084691453026608, 0.11324214690830559, 0.07885290862759575, 0.16673532023560256, 0.021480902323673945, 0.03629481005191337, 0.02357918016059557, 0.05393181600084063, 0.0573656553751789, 0.0818956844159402, 0.0542897835111944, 0.10694209981011227, 0.07355033027124591, 0.023439339129254222, 0.06822854513302445, 0.04834644227230456, 0.04195623165287543, 0.04716220835689455, 0.08368405993678607, 0.016699224433978088, 0.08855435211444274, 0.09605475628632121, 0.05170334319700487, 0.06047386632417329, 0.027883994771400467, 0.05269952060189098, 0.029296646898728795, 0.079261676146416, 0.08047926588915288, 0.07312080488190986, 0.04052396827319171, 0.058009216154459864, 0.31905264069791883, 0.41592758148908615, 16.025222092866898, 58.38204704225063, 90.06464436650276, 71.82621583342552, 40.238469019532204, 20.243938118219376, 26.030894592404366, 69.05767679214478, 100.57507798075676, 75.17065957188606, 14.799767900258303, 1.766631247010082, 0.8477066655177623, 0.38651053968351334, 1.5423791552893817, 1.43315662862733, 0.937167105730623, 0.8025500667281449, 2.3324442794546485, 0.7525268790777773, 0.8653747080825269, 2.0644926326349378, 0.2926420094445348, 8.299329411238432, 12.943120077252388, 26.443058475852013, 26.647593900561333, 8.305616173893213, 3.9887932129204273, 1.7631363845430315, 1.223892120178789, 1.256665955297649, 0.9688050986733288, 0.20784629392437637, 0.32941845478489995, 1.247207906562835, 4.590302836149931, 2.3785814037546515, 3.142123119905591, 3.629212095402181, 0.9319131157826632, 0.5569763097446412, 0.7052870420739055, 0.009088557526411023, 11.972293071448803, 22.562522403895855, 43.586746752262115, 84.65020850300789, 38.37573677301407, 62.490831166505814, 72.9110500216484, 53.14060069620609, 36.92174859344959, 22.776183038949966, 31.965157762169838, 39.69423562288284, 36.01937301456928, 37.0626450330019, 18.234336152672768, 11.583580579608679, 0.6175631680525839, 0.043155486637260765, 0.4939790745265782, 1.422201341483742, 0.2789887780090794, 0.2878871880238876, 0.4927938350010663, 1.4297469053417444, 0.4266261449083686, 0.39342486241366714, 0.8143864315934479, 15.34559341147542, 58.776009902358055, 86.89067468047142, 45.808012560009956, 19.923191629350185, 23.695125728845596, 52.18209832906723, 71.1032210290432, 54.54671524465084, 14.023834336549044, 0.47442458162549883, 0.19781386741669849, 0.06628396979067475, 0.053621520346496254, 0.05681259208358824, 0.02607988571980968, 0.04395716568978969, 0.03195457087713294, 0.02876119477150496, 0.05528377900191117, 0.15967264218488708, 0.1552123940200545, 0.06675268057733774, 0.10379896339145489, 0.044232016371097416, 0.038037773556425236, 0.04151386339799501, 0.00859436788232415, 0.06051299977116287, 0.059261601491016336, 0.07398397458018735, 0.017661361380305607, 0.04356766803539358, 0.021655377531715203, 0.00995653912468697, 0.032448173296870664, 0.060271950205788016, 0.05889931839192286, 0.04420565157488454, 0.008816307145025348, 0.025305048293375876, 0.059243997748126276, 0.07604844387969933, 0.014001383115100907, 0.04011737524706405, 0.07613603956997395, 0.12883416493423283, 0.06183092416904401, 0.1168947083351668, 0.015584075190417934, 0.11629432570771314, 0.03618785172875505, 0.07328383246203884, 0.0302400631699129, 0.16050855279900134, 0.11588627807213925, 0.14881188981235027, 0.22823506471468136, 0.1938108415924944, 0.1673434063559398, 0.274746750947088, 0.17886753485072404, 0.23797573812771589, 0.16652008256642148, 0.21065756416646764, 0.1406810831394978, 0.141721811669413, 0.1486566918902099, 0.19352275470737368, 0.16142163192853332, 0.31144250999204814, 0.24818109988700598, 0.22940068185562268, 0.11322887730784714, 0.2883251738967374, 0.15946929372148588, 0.17743180564139038, 0.07115257729310542, 0.29816824884619564, 0.14871595980366692, 0.12983460968825966, 0.12630099226953462, 0.28501121734734625, 0.17746319848811254, 0.1900855274288915, 0.14393069548532367, 0.20745577581692487, 0.12168989516794682, 0.14862222655210644, 0.12614713021321222, 0.26899044576566666, 0.21082071791170165, 0.1447873713914305, 0.0726472849783022, 0.22555816773092374, 0.27616137347649783, 0.08974144700914621, 0.13883119099773467, 0.1744410692481324, 0.24092402367386967, 0.16355465340893716, 0.15930680790916085, 0.17740762647008523, 0.4689212597440928, 0.7032876962330192, 20.49533072859049, 69.97688546776772, 99.90949809551239, 90.31619846820831, 65.32606422901154, 46.75306744873524, 33.277557939291, 62.40644909441471, 88.51156130433083, 92.60869905352592, 32.065149396657944, 3.8060569809749722, 1.9963105162605643, 2.3357235034927726, 12.826565131545067, 11.992184054106474, 10.318810846656561, 3.6245692195370793, 3.6424790835008025, 0.3845056128920987, 1.338643825147301, 1.2937011430040002, 0.15316130564315245, 2.92220089584589, 9.712012857198715, 31.73188827931881, 32.0711986720562, 7.168257404118776, 2.204923122189939, 2.3739929124712944, 0.9649189165793359, 2.400784562341869, 0.7433975127059966, 0.17951511807041243, 0.1972389849834144, 0.88137541199103, 3.2464237231761217, 1.3587265787646174, 2.4450241634622216, 2.1162437181919813, 1.2986837443895638, 0.4001368163153529, 0.8016954094637185, 0.12297239314648323, 4.761365382000804, 16.05214174836874, 35.432961881160736, 45.48027254641056, 31.186062768101692, 42.34630711376667, 44.65608537197113, 29.376480169594288, 24.24284353852272, 15.594051629304886, 29.573700986802578, 38.7173118442297, 43.253060057759285, 46.13532319664955, 14.648923594504595, 6.464119087904692, 0.3946833370719105, 0.17694709415081888, 0.829762959619984, 1.789309261366725, 2.213489287532866, 1.4836413133889437, 2.0439580595120788, 5.155894886702299, 2.745499452576041, 0.45534924895036966, 1.6954616596922278, 35.64263842999935, 69.50261771678925, 80.47905072569847, 36.46173767745495, 27.97642059624195, 43.02440732717514, 71.80147916078568, 82.69871681928635, 62.88032166659832, 18.08350134640932, 1.1030646599829197, 0.49748673161957413, 0.15759780508233234, 0.2180676267016679, 0.34985093807335943, 0.13708657992538065, 0.3302658983739093, 0.0924332908471115, 0.10848784499103203, 0.13907840038882568, 0.1832198302145116, 0.1318895275471732, 0.17101224308134988, 0.15215381048619747, 0.1605647779069841, 0.129033891716972, 0.23332916636718437, 0.0982428302813787, 0.15873789234319702, 0.13008952257223427, 0.11479500186396763, 0.10455415802425705, 0.10408017798908986, 0.224123299412895, 0.1009971703751944, 0.2081103649106808, 0.30699775787070394, 0.16397181461798027, 0.12769897584803402, 0.12588065466843545, 0.14533583336742595, 0.1356557637336664, 0.20416347513673827, 0.18035088025499135, 0.1161841167777311, 0.2139742815052159, 0.15625238040229306, 0.16966802068054676, 0.16716352460207418, 0.14063649490708485, 0.18713197263423353, 0.09306483625550754, 0.13910593406762928, 0.265678953146562], [0.016869270875758957, 0.008781352917139884, 0.06264466312131844, 0.03669646037451457, 0.029962884000269696, 0.08771855282247998, 0.025650310235505458, 0.03598768336814828, 0.05285142709908541, 0.015698306560807396, 0.07171796023612842, 0.03390771431440953, 0.09002994207548909, 0.030973987850302365, 0.08504584897309542, 0.07365110650425777, 0.09007928005303256, 0.08457707881461829, 0.07704058400122449, 0.04565637216728646, 0.03970861143898219, 0.0787183349893894, 0.008649248775327578, 0.03669922487461008, 0.039772951931809075, 0.03186462628946174, 0.040783816439216025, 0.16561451397137716, 0.04176189657300711, 0.004566198094835272, 0.05072992375062313, 0.05157910767593421, 0.04034564131870866, 0.07031625107629225, 0.03925722237909213, 0.07188682109699585, 0.03382451213838067, 0.029954920755699277, 0.014088536299823318, 0.05036757014750037, 0.12067064439179376, 0.09120664690271951, 0.047146638098638505, 0.028372088600008283, 0.10071644559502602, 0.021457316870510112, 0.06280011337366886, 0.017180592549266294, 0.048698539394536056, 0.053549131262116134, 0.0454777817503782, 0.30252803990151733, 0.7523036410566419, 16.145451441407204, 50.31256444752216, 71.5373857319355, 68.7544758617878, 58.48022237420082, 26.002595610916615, 19.276375137269497, 34.506016820669174, 56.451663225889206, 69.44520279765129, 34.92220088839531, 5.641505979001522, 0.8849600446410477, 0.9669798903632909, 1.6471168538555503, 0.237639797560405, 4.1831238102167845, 0.4879832931328565, 1.2565275002270937, 2.33777919318527, 1.3191040861420333, 0.339551234501414, 0.5426302982959896, 2.344691972248256, 6.534337420016527, 4.409544160589576, 0.027452183567220345, 0.6564254639670253, 0.010950475243589608, 0.18064227711874992, 0.22660214686766267, 0.6537754030432552, 0.7240586879197508, 1.6252588829956949, 9.086728859692812, 3.9070142386481166, 4.152171621099114, 4.596404833719134, 1.6146794194355607, 0.18155122990719974, 0.09174336810247041, 0.11244595603784546, 0.22659349342575297, 0.3125104308128357, 0.6193195644300431, 0.5237087979912758, 0.11354244954418391, 0.11125011122203432, 0.13670673390151933, 0.11324093720759265, 0.05885642967768945, 0.19284003821667284, 0.34205711097456515, 0.04958373603585642, 0.31925423769280314, 0.24864713894203305, 0.5932209023740143, 0.045445691284839995, 0.2388779225293547, 0.6574297975748777, 0.919382160063833, 2.271781722083688, 0.3337186068529263, 0.45144914416596293, 0.8893621677998453, 0.46050399891100824, 3.9376066345721483, 28.771868012845516, 62.487814128398895, 56.13830544054508, 31.284642778337002, 20.625680834054947, 32.886061146855354, 62.03357130289078, 69.99054953455925, 49.64903645217419, 14.156299028545618, 0.9335801575798541, 0.3115193371195346, 0.07465374801540747, 0.05403049195592757, 0.05629415740258992, 0.03303787641925737, 0.02287634775711922, 0.08182843841495924, 0.017577597027411684, 0.028519998631963972, 0.05861923928023316, 0.028722903662128374, 0.07005308551015332, 0.036024660876137204, 0.019865280228259508, 0.02655391399457585, 0.03429943841183558, 0.0255477862447151, 0.05525249747734051, 0.027628486313915346, 0.08539436894352548, 0.021620698826154694, 0.022892159213370178, 0.052706767673953436, 0.03905008896254003, 0.04912037242320366, 0.03699030261486769, 0.010203754081885563, 0.017386254658049438, 0.07407029377645813, 0.08213928696932271, 0.03569168889953289, 0.014180122889229096, 0.030402942320506554, 0.08209940395317972, 0.04337534417572897, 0.02591376152849989, 0.027246502904745284, 0.0729011588555295, 0.04196162706648465, 0.0326431911526015, 0.018301636300748214, 0.02906200948928017, 0.03863863486913033, 0.030104860561550595, 0.03793417716224212, 0.01667731994530186, 0.02255938761663856, 0.021825980584253557, 0.0459127396607073, 0.026845561333175283, 0.016191463691939134, 0.016820155542518478, 0.013109900482959347, 0.056849476823117584, 0.039669774851063266, 0.02812235034070909, 0.01133231671701651, 0.06443896840210073, 0.040678364675841294, 0.06925259760464542, 0.04341991385444999, 0.05883045450900681, 0.05490008494234644, 0.06528010373585857, 0.04926051587972324, 0.011287981742498232, 0.053642270795535296, 0.02422581528662704, 0.025455412978772074, 0.03070721544645494, 0.022715325831086375, 0.06386459062923677, 0.0409180746646598, 0.028739613117068075, 0.015861868487263564, 0.03762394830118865, 0.04825819720281288, 0.03903092670952901, 0.04907729075057432, 0.022963661431276705, 0.08563385999877937, 0.030292672163341194, 0.028543606349558104, 0.023423664970323443, 0.037371629223343916, 0.02192779767938191, 0.06027508577972185, 0.08609926080680452, 0.06240816292120144, 0.06444394821301103, 0.0780280634353403, 0.05177634455321822, 0.09320745477452874, 0.04991947251255624, 0.1576782835763879, 0.07458529231371358, 0.6057326216250658, 1.0342494025826454, 18.42555709183216, 61.78732171654701, 85.79763293266296, 67.06250265240669, 44.20985631644726, 20.193207040429115, 28.538286946713924, 69.59840297698975, 104.81796070933342, 77.6960876584053, 23.72309982776642, 0.33869892242364585, 1.1243035015650094, 0.8379279496148229, 0.1869462279137224, 0.35129260446410626, 2.9094323934987187, 0.9731361537706107, 1.8095393758267164, 1.5432820818386972, 3.3761763107031584, 0.7778682536445558, 1.0174886207096279, 5.18766213208437, 9.756285231560469, 5.732652638107538, 0.4049004544503987, 0.696850901003927, 0.42424438521265984, 0.15711071871919557, 0.9317862382158637, 1.208087580744177, 3.3637721138074994, 3.8385155517607927, 7.7756476867944, 6.948566967621446, 4.688391722738743, 5.33405402675271, 3.208052907139063, 0.9847046330105513, 0.2512567676603794, 0.2786390483379364, 0.6769579590763897, 0.4308351018698886, 1.3567461725324392, 0.8925799420103431, 1.9934943923726678, 0.45848871173802763, 0.8807372837327421, 0.5873451707884669, 0.6110018701292574, 0.01064873933501076, 1.0303137637674809, 0.8265783148817718, 2.880453485995531, 1.873292236123234, 0.20815153926378116, 0.3081919328542426, 0.9874466608744115, 1.4634356601163745, 1.2790807150304317, 1.95485545322299, 0.5009242112282664, 1.6794351884163916, 0.2972036349819973, 0.5195943906437606, 1.114032177720219, 17.628770247101784, 66.93435072898865, 80.45281693339348, 49.63837422430515, 26.229090057313442, 19.01466228067875, 50.60191132128239, 76.6654385626316, 61.394236609339714, 18.873306065797806, 1.6660613310523331, 0.23175361653557047, 0.01967136446182849, 0.038221258437260985, 0.01675768340646755, 0.10159837678656913, 0.06126882151875179, 0.04390071793750394, 0.060398401037673466, 0.055380514240823686, 0.021589792086160742, 0.03368600140674971, 0.16477714874781668, 0.0950522928906139, 0.024782546643109526, 0.012231558503117412, 0.021710953260480892, 0.06123350642155856, 0.07431852733134292, 0.026870109722949564, 0.06882738409331068, 0.05806961955386214, 0.03384629417269025, 0.04748728759295773, 0.07124667419702746, 0.023008206990198232, 0.025451410947425757, 0.015475530526600778, 0.01944728039234178, 0.04054840719618369, 0.05309486637997907, 0.03254078961617779, 0.040501718685845844, 0.0780579868296627, 0.05384563781262841, 0.029624086164403707, 0.036843216366833076, 0.016411352771683596, 0.025988688757934142, 0.05352780564862769, 0.03853077483654488, 0.01814070528780576, 0.017789751072996296, 0.004606908141795429, 0.025345484209537972, 0.05037309543695301, 0.14355775143485516, 0.12955878308275715, 0.1700226336834021, 0.17157240130472928, 0.11887750428286381, 0.14367073599714786, 0.11064827398513444, 0.08883737755240873, 0.20443274115677923, 0.20282150886487216, 0.2787093148799613, 0.20877718459814787, 0.22600909665925428, 0.09169507655315101, 0.2051305677741766, 0.1762891950784251, 0.1493524108082056, 0.16062308102846146, 0.15870517847361043, 0.13936285075033084, 0.1437410619109869, 0.2788377064280212, 0.19497914530802518, 0.12303857787628658, 0.14153471624013036, 0.15911769383819774, 0.15278488834155723, 0.21705658407881856, 0.15605124353896827, 0.11211073535378091, 0.14800182078033686, 0.12034165032673627, 0.14785980340093374, 0.2388956895447336, 0.12338617016212083, 0.19531741621904075, 0.1704670613980852, 0.1390047644963488, 0.07929603758384474, 0.11587800312554464, 0.3049412666587159, 0.15230914199491963, 0.14595966786146164, 0.11154981271829456, 0.2614049840485677, 0.09274713767808862, 0.24629567371448502, 0.15271275158738717, 0.16275751258945093, 0.2709921367932111, 0.1471359422430396, 0.9345208446029574, 1.9714682805351913, 26.570566333830357, 76.00459322333336, 100.65804272890091, 87.19462797045708, 76.62252366542816, 44.04168114066124, 34.288455694913864, 48.97858902812004, 76.49061754345894, 84.17743787169456, 45.667043924331665, 9.771265927702188, 1.2937265541404486, 1.243690364062786, 5.371006093919277, 4.743351973593235, 16.771091669797897, 4.475933248177171, 4.918549647554755, 5.917472345754504, 3.6820572847500443, 0.9045891975983977, 0.7785733533091843, 6.502929255366325, 13.16936468705535, 6.433713119477034, 0.9736599319148809, 0.5467210162896663, 0.4823830467648804, 0.595281341811642, 0.3052783204475418, 1.7220596387051046, 3.450874127447605, 4.866645382717252, 22.372777685523033, 13.36189940571785, 13.704639114439487, 13.237373437732458, 4.67714480124414, 0.7888314372394234, 0.22929543047212064, 0.39148619456682354, 0.5730381666216999, 0.689220791682601, 0.8613768476061523, 0.5763221404049546, 1.1957149696536362, 0.2804746764013544, 0.5186291830614209, 0.7398872135672718, 0.9184079873375595, 0.3923271072562784, 1.5675836778245866, 0.5573206662666053, 1.9745587022043765, 1.1632257630117238, 1.3618071447126567, 0.2688209095504135, 1.6969952336512506, 2.170555628836155, 5.412001619115472, 8.117540515959263, 6.174596473574638, 7.55047176964581, 4.270436950027943, 0.5103745416272432, 8.727137055248022, 40.019330978393555, 79.08315762877464, 70.25335103273392, 45.32168425619602, 32.06158898770809, 45.34974955022335, 78.9671802520752, 86.91594332456589, 69.9872437119484, 23.929896131157875, 2.2079380229115486, 0.47158598550595343, 0.22323462209897116, 0.16998533334117383, 0.12201673700474203, 0.21770553285023198, 0.1836985451518558, 0.18732834490947425, 0.1944686219212599, 0.13566909270593897, 0.0959894918196369, 0.13159580033970997, 0.25583498761989176, 0.14052809681743383, 0.09955477667972445, 0.13478455657605082, 0.1520929840626195, 0.1685650259605609, 0.2504573261830956, 0.05264027866360266, 0.2037214519805275, 0.1343183542485349, 0.13641049823490903, 0.15709934901678935, 0.16854562622029334, 0.09812311443965882, 0.09853821247816086, 0.08365441113710403, 0.09769223834155127, 0.1456551201408729, 0.26617378753144294, 0.11786192713771015, 0.09538673431961797, 0.21882501809159294, 0.21100963902426884, 0.07447311669238843, 0.1679852305096574, 0.12763350358000025, 0.10456983218318783, 0.1143335121741984, 0.18152437900425866, 0.0926685071317479, 0.14106395712587982, 0.10175554140005261, 0.13539773382944986, 0.09240483690518886], [0.019065523338213097, 0.03572359753889032, 0.03061209437873913, 0.07433132195728831, 0.014414718552870909, 0.04175309470156208, 0.07277704949956387, 0.02463503180479165, 0.04137518197239842, 0.09541320672724396, 0.07017680152785033, 0.06542243281728588, 0.038949338704696856, 0.003485669808469538, 0.045594221010105684, 0.07261424456373788, 0.014910665231582243, 0.013865821492800023, 0.015505703468079446, 0.007708799239480868, 0.028554575292218942, 0.05471656666486524, 0.017799191191443242, 0.013739323349000188, 0.04007470917713363, 0.0362293823127402, 0.021425738486868795, 0.02129668828274589, 0.018263642050442286, 0.01071576361937332, 0.040138214753824286, 0.014559096889570355, 0.04454295398318209, 0.033667610987322405, 0.04561077461403329, 0.030332803798955865, 0.011195521274203202, 0.03725802125700284, 0.07160720211686566, 0.11014575837180018, 0.041680059948703274, 0.08064388166530989, 0.0496258566272445, 0.056728788767941296, 0.05044849021942355, 0.03733627701876685, 0.049359644544892944, 0.05685915813955944, 0.03231750706618186, 0.03756082493055146, 0.05700528701709118, 0.03259047640312929, 0.17241398192709312, 0.18787931534461677, 0.9951951575931162, 28.026273921132088, 67.01923817396164, 68.31764370203018, 68.67598727345467, 43.74630779027939, 25.61827853322029, 13.648501876741648, 23.7182379886508, 46.47735804319382, 69.23913985490799, 56.98492281138897, 29.331108704209328, 9.52509043738246, 1.3193933456204832, 0.27521237439941615, 3.6529308976605535, 2.2907650284469128, 3.7760238675400615, 1.6433816542848945, 1.6713238111697137, 1.9213498011231422, 2.311726128682494, 1.5624041995033622, 0.34430872765369713, 1.1461632535792887, 0.738523977342993, 1.0138235986232758, 1.6248926776461303, 6.013979567214847, 1.3021104480139911, 5.2172112464904785, 2.51109026838094, 2.3244846565648913, 4.606921719387174, 0.7352467719465494, 3.4340799786150455, 2.144606108777225, 1.5067786280997097, 0.39879991149064153, 0.26827605441212654, 0.0947112834546715, 0.40622658329084516, 0.5306595156434923, 0.5914043029770255, 0.1409327008877881, 0.11904669168870896, 0.2190472764777951, 0.26857793040107936, 0.23867798794526607, 0.5220013239886612, 0.5446468619629741, 0.19695303548360243, 0.05734566191677004, 0.39083779498469085, 0.8329401235096157, 0.26827988389413804, 0.47924489015713334, 1.8246612581424415, 2.919664056971669, 0.652812214102596, 0.1917353959288448, 1.295351916924119, 11.643999237567186, 42.928926050662994, 55.302365496754646, 52.29340195655823, 24.85882468521595, 22.194116972386837, 39.87151511013508, 56.03000745177269, 77.53632143139839, 54.031006917357445, 24.709502197802067, 3.1705814553424716, 0.08293732578749768, 0.018318163929507136, 0.04558533750241622, 0.029013667844992597, 0.051736732420977205, 0.05970837810309604, 0.05945033706666436, 0.0266897270194022, 0.08775905182119459, 0.1366337510989979, 0.028905588878842536, 0.0037393845877886633, 0.03225821317755617, 0.08810621366137639, 0.044047737392247654, 0.046754349968978204, 0.029869044992665295, 0.015023334381112363, 0.005811815972265322, 0.10568396653980017, 0.041766163922147825, 0.05239275757048745, 0.03553706243110355, 0.022765036737837363, 0.05956176682957448, 0.10199520314927213, 0.08259520313004032, 0.06100428297941107, 0.018132048135157675, 0.07289066488738172, 0.007272666880453471, 0.04518240697507281, 0.05635767040075734, 0.04124421888263896, 0.04259674962668214, 0.010695473301893799, 0.0304174067787244, 0.10166500680497847, 0.07128007826395333, 0.02987293013575254, 0.020634993124986067, 0.06598299922188744, 0.03331338019052055, 0.06104523468820844, 0.012474812247091904, 0.02623328022309579, 0.051734977241721936, 0.06261702554184012, 0.06908911731443368, 0.046349727344932035, 0.03973896527895704, 0.037937219967716374, 0.010201381992374081, 0.0412854637397686, 0.0910607777768746, 0.03608385828556493, 0.015083685830177274, 0.0444872446678346, 0.06309720993158408, 0.013203133712522686, 0.0730746507178992, 0.04579212582029868, 0.014584310429199832, 0.013101089334668359, 0.03370836973772384, 0.037488472953555174, 0.023076835241226945, 0.037004748519393615, 0.014397390332305804, 0.05555102266953327, 0.038221555296331644, 0.030385715217562392, 0.050798531592590734, 0.02151569235138595, 0.03724714508280158, 0.05894252622965723, 0.04580544737109449, 0.01026244868626236, 0.023838408633309882, 0.05422311267466284, 0.04587008101225365, 0.00799619499957771, 0.06692964569083415, 0.0400814219028689, 0.05437004307168536, 0.021603874338325113, 0.0568872076109983, 0.06912471071700566, 0.061936806378071196, 0.10260463997838087, 0.03724558286194224, 0.0021627148089464754, 0.03417693209485151, 0.021644295411533676, 0.12136490127886645, 0.03245069659897126, 0.13420590403256938, 0.029514372617995832, 0.07004046157817356, 0.16358172695618123, 0.23485067300498486, 1.550181086640805, 32.58467271924019, 77.30457946658134, 80.70885479450226, 58.70773136615753, 29.049479216337204, 15.453761257231236, 14.975545518100262, 59.89703334867954, 100.73665291070938, 101.21260017156601, 59.78096857666969, 17.83626951277256, 0.728200584417209, 1.5070577943697572, 0.4700735182268545, 2.819801615551114, 1.3606333639472723, 1.2087035039439797, 3.304957919754088, 2.42199526168406, 2.9112192476168275, 0.7091269735246897, 3.4531471179798245, 3.1771971378475428, 0.6680209573823959, 1.694522041361779, 2.041192282922566, 0.9019543952308595, 6.307664858177304, 3.098654164932668, 4.952531224116683, 4.042418310418725, 1.928964473772794, 4.978559352457523, 3.9319743867963552, 2.458031103014946, 3.5244605038315058, 3.272110582329333, 2.3253932828083634, 0.7278041588142514, 1.198894924018532, 0.9513259772211313, 1.0644384264014661, 0.5999237427022308, 1.0406621522270143, 0.8239143015816808, 0.9668423258699477, 0.7999332540202886, 0.7171555864624679, 0.9472978371195495, 1.9277646881528199, 0.7942095142789185, 1.781859879847616, 0.8103198185563087, 0.6981306604575366, 1.0012817778624594, 0.4043491277843714, 0.5987318535335362, 1.5350897214375436, 0.4962957330280915, 0.23468061728635803, 1.856765616685152, 2.2083291644230485, 31.59899041056633, 73.30351576209068, 82.0965251326561, 44.840455278754234, 26.431072019040585, 30.48726126551628, 47.99723468720913, 77.49443247914314, 67.85790637135506, 31.7376696690917, 3.6436278093606234, 0.04907360598735977, 0.02698272692214232, 0.03158259904012084, 0.017562390421517193, 0.027658127692120615, 0.07383628719253466, 0.028973578882869333, 0.0486461882974254, 0.025072791322600096, 0.16423048276919872, 0.08462387122563086, 0.046966377849457785, 0.07255710661411285, 0.07136023763450794, 0.0753047748003155, 0.04633767115592491, 0.09844265354331583, 0.015994814966688864, 0.04192428219539579, 0.04518452209595125, 0.0078975997530506, 0.017689626074570697, 0.04994099108444061, 0.025585299954400398, 0.016898624671739526, 0.04583532994729467, 0.03332606720505282, 0.09713965744595043, 0.003764285265788203, 0.042504489538259804, 0.056346909259445965, 0.042762018492794596, 0.0835355487652123, 0.027029484081140254, 0.047907205880619586, 0.052886374833178706, 0.05153662714292295, 0.04681087564677, 0.03592945446143858, 0.04434406953805592, 0.06801316645578481, 0.08887005431461148, 0.03275466173363384, 0.055456101981690153, 0.01684676895820303, 0.06647729183896445, 0.019706518141902052, 0.1217301344149746, 0.1081754156621173, 0.09153023813269101, 0.142993867630139, 0.12530936422990635, 0.10904847818892449, 0.20932959479978308, 0.11451309706899337, 0.16164771979674697, 0.1636352061177604, 0.1381609871168621, 0.16514066752279177, 0.08850227561197244, 0.17749742633895949, 0.11334316805005074, 0.20470932475291193, 0.12207530729938298, 0.06266617056098767, 0.09955241665011272, 0.13354519964195788, 0.14278850052505732, 0.13850146962795407, 0.181251862377394, 0.11476754982140847, 0.12211487119202502, 0.13862374587915838, 0.0997636021929793, 0.19502242736052722, 0.16245024860836565, 0.13353869842831045, 0.1804925117176026, 0.10864197422051802, 0.10820959898410365, 0.0900173700938467, 0.1658462718478404, 0.10724217238021083, 0.13612953596748412, 0.10119798811501823, 0.15207402961095795, 0.1908920193091035, 0.12047822776366957, 0.16687560098944232, 0.18102405272657052, 0.2067950862692669, 0.2561281656380743, 0.12272522828425281, 0.1618453091941774, 0.2649050415493548, 0.1829642939264886, 0.2269778962363489, 0.1966831015306525, 0.17549529002280906, 0.33069325669202954, 0.5667015316430479, 2.9614881752058864, 42.06759586930275, 91.96823582053185, 92.68134355545044, 80.49540504813194, 60.66965349018574, 41.226271614432335, 19.36725676059723, 42.195645198225975, 64.4030025601387, 89.45106849074364, 70.49469128251076, 37.76864714920521, 13.875613790005445, 2.0133407274261117, 0.30896391486749053, 5.837508961558342, 5.9059822373092175, 5.93479941599071, 3.6028160993009806, 4.48067681863904, 5.949603896588087, 5.985347628593445, 7.266029957681894, 5.2508422918617725, 2.7703534439206123, 7.567452108487487, 5.991252036765218, 4.260673373937607, 19.818340055644512, 9.859186559915543, 19.65845413506031, 18.608236089348793, 12.314423862844706, 13.65842029452324, 7.716612154617906, 12.331921923905611, 11.951000913977623, 5.3013230580836535, 3.1513722985982895, 0.47399333445355296, 0.9016720822546631, 1.1422593193128705, 1.3460605521686375, 0.9226078307256103, 0.9901008184533566, 0.5504411947913468, 1.0821734997443855, 0.6456547637935728, 0.9232976718340069, 0.7754899968858808, 1.6221512435004115, 1.0162800480611622, 2.544143982231617, 1.9174704467877746, 3.720414089038968, 2.581728477962315, 5.124764107167721, 8.367070276290178, 8.00518149510026, 1.5657362644560635, 0.4669378255493939, 4.674929995089769, 22.62306645512581, 61.97883144021034, 71.17458879947662, 68.15611436963081, 37.99447663128376, 33.94431576132774, 54.182599782943726, 70.7496652007103, 92.75079622864723, 74.56386253237724, 36.84690780937672, 4.882933683693409, 0.17514193867100403, 0.2162355906330049, 0.2639196178643033, 0.07895588161773048, 0.18912900297436863, 0.20724120608065277, 0.23635788587853312, 0.25786672078538686, 0.19682198704686016, 0.3602682868950069, 0.19310749339638278, 0.12204253405798227, 0.17227284028194845, 0.18399651744402945, 0.15479986381251365, 0.10054532860522158, 0.15346281055826694, 0.11629028100287542, 0.1266950578428805, 0.18191952811321244, 0.12023394243442453, 0.141818929114379, 0.1817981424392201, 0.12054315826389939, 0.16233239555731416, 0.1648301529348828, 0.15330853289924562, 0.13093751535052434, 0.08249467180576175, 0.18831265537301078, 0.07725406278041191, 0.115501504187705, 0.1917564432369545, 0.24592742003733292, 0.13547974114771932, 0.1029606482188683, 0.10203972458839417, 0.22817459452198818, 0.24200439773267135, 0.12936484505189583, 0.14526863931678236, 0.1903862159815617, 0.09433462866581976, 0.16749121248722076, 0.12051758385496214, 0.09293202892877162, 0.10368611241574399], [0.08295463267131709, 0.02203003594331676, 0.023280859059013892, 0.05268500048259739, 0.05640001363644842, 0.07605414357385598, 0.08000175323104486, 0.07105669181328267, 0.0371901073231129, 0.05808869645989034, 0.01794266874640016, 0.011709694172168383, 0.0634394513326697, 0.02663620518433163, 0.048725379165261984, 0.020069133352080826, 0.03596691807615571, 0.026116119224752765, 0.01969579781871289, 0.010689127011573873, 0.028236770958756097, 0.01190519720694283, 0.04540535926935263, 0.0410934256069595, 0.03018178787897341, 0.052204415333108045, 0.0458860928483773, 0.05768906106823124, 0.038355216092895716, 0.004216568149786326, 0.07225919369375333, 0.02521063041058369, 0.03553715148882475, 0.08195803966373205, 0.01326227824392845, 0.02833706108503975, 0.03988691241829656, 0.008747867213969585, 0.0536835898674326, 0.04801415678230114, 0.018727042770478874, 0.06681713610305451, 0.052178310288582, 0.060170365031808615, 0.06848871984402649, 0.03804692794801667, 0.06327568160486408, 0.03012472043337766, 0.05851555753906723, 0.05896048620343208, 0.061076260171830654, 0.07838334437110461, 0.048732485229265876, 0.034524813818279654, 0.14113575249211863, 0.4615383449709043, 5.938131362199783, 41.49839401245117, 71.08498960733414, 72.66183659434319, 68.36787700653076, 67.92703986167908, 44.25684839487076, 19.690478816628456, 14.301580432802439, 18.65749854594469, 46.24249644577503, 79.19481843709946, 67.64503419399261, 55.521347746253014, 42.95144744217396, 22.589445859193802, 11.942253783345222, 2.6837760396301746, 0.20158420025836676, 0.11695338253048249, 0.5081780219916254, 1.6276578605175018, 1.6151876421645284, 2.6178122917190194, 2.1071434440091252, 1.8370943097397685, 1.1489572911523283, 4.423356419429183, 1.5753047447651625, 2.545740846544504, 2.4977330351248384, 1.0828121029771864, 2.655897648073733, 4.430470587685704, 1.8388371099717915, 2.7322669001296163, 3.716403404250741, 1.8401747569441795, 2.2522241715341806, 2.137485765852034, 1.9733496545813978, 1.027120747603476, 0.5843650025781244, 0.19916945951990783, 1.04458746034652, 0.8224026951938868, 0.4897188500035554, 0.6813987926580012, 2.1441831439733505, 0.5807163671124727, 0.16533745540073141, 1.4764460432343185, 2.0529657136648893, 1.9152083806693554, 1.4366023312322795, 1.1335371248424053, 0.11479483859147877, 5.356383053585887, 21.730292961001396, 40.259128510951996, 73.02628263831139, 81.59288495779037, 34.770057052373886, 17.570606768131256, 21.309860721230507, 43.524034917354584, 64.44079533219337, 71.54468894004822, 59.71240885555744, 27.22966756671667, 2.336864392273128, 0.006079751692595892, 0.10043235146440566, 0.05794607051939238, 0.01916581160912756, 0.007812264830135973, 0.060975951491855085, 0.05566058222029824, 0.029473291033355054, 0.18120501801604405, 0.13538275728933513, 0.03262534250097815, 0.04872245139267761, 0.10497708572074771, 0.10223355871858075, 0.022301901335595176, 0.0716938404366374, 0.01649858480959665, 0.009286952154070605, 0.031168833156698383, 0.0020099462608413887, 0.014611537972086808, 0.014490890735032735, 0.06413035371224396, 0.051771528014796786, 0.046468719592667185, 0.0378260239813244, 0.004975082038072287, 0.0366267615754623, 0.09087067664950155, 0.012102973068977008, 0.12644444941543043, 0.09895710289129056, 0.06321920416667126, 0.03410740027902648, 0.01646229749894701, 0.04306592054490466, 0.06064767359930556, 0.030436212800850626, 0.03965945899835788, 0.05487669615831692, 0.08474031419609673, 0.04327522103267256, 0.013894039802835323, 0.04302881316107232, 0.013328348868526518, 0.06913217672263272, 0.020547202620946337, 0.02740036496106768, 0.024058863600657787, 0.13361266086576506, 0.018423808651277795, 0.05682893046468962, 0.023104845749912784, 0.0545568490633741, 0.052427916816668585, 0.09162043876131065, 0.04646338726161048, 0.04564771872537676, 0.038954789779381827, 0.05066924946731888, 0.043619599819066934, 0.025487778038950637, 0.049841547006508335, 0.054273296700557694, 0.0434472657070728, 0.02392026195593644, 0.038403975195251405, 0.03584508711355738, 0.07292235459317453, 0.0442331481463043, 0.028191269884700887, 0.047360673488583416, 0.0038700835193594685, 0.07316329283639789, 0.027097574275103398, 0.08657113314257003, 0.021092623646836728, 0.05072072854090948, 0.043456152925500646, 0.11797914194175974, 0.02683350699953735, 0.039819911326048896, 0.007637188946318929, 0.017296499318035785, 0.012857218680437654, 0.11386397760361433, 0.04549893666990101, 0.04656742894439958, 0.11594536787015386, 0.04488080187002197, 0.05579835451499093, 0.09939764175214805, 0.05569372653553728, 0.032459706271765754, 0.03573337904526852, 0.02443867993861204, 0.03480115621641744, 0.04737215451314114, 0.050389686148264445, 0.004852277470490662, 0.03052818345167907, 0.07685141055844724, 0.06423461803933606, 0.0324002268462209, 0.5182593560311943, 7.686377177014947, 51.08980134129524, 82.35845267772675, 77.04186916351318, 54.23556134104729, 36.3015990704298, 19.05560128390789, 14.310931731015444, 34.19628024101257, 60.04605755209923, 89.44956377148628, 104.99009907245636, 77.0937591791153, 45.47541260719299, 22.082509361207485, 6.21896811760962, 3.2448850432410836, 3.5279769776389003, 1.0162572492845356, 0.5124704260379076, 0.2945733448723331, 0.5163116042967886, 0.43352666369173676, 0.8369191631209105, 1.4390456001274288, 1.3680214737541974, 0.947367895860225, 1.7032367549836636, 1.3392217503860593, 0.9188121906481683, 1.1321198008954525, 0.9778302675113082, 0.4076995386276394, 2.0688151381909847, 1.8181374832056463, 2.25008939858526, 2.9780334373936057, 0.6846809259150177, 2.265439862385392, 3.7552057346329093, 1.1809709295630455, 1.0085297701880336, 0.6364581291563809, 3.0014280695468187, 1.7718811403028667, 1.2603436829522252, 1.644745187368244, 0.9728050965350121, 1.5033433749340475, 1.8294642004184425, 1.3428105390630662, 1.6861912258900702, 2.2721484024077654, 1.2552748736925423, 1.2116743507795036, 0.8335301012266427, 0.7322241528891027, 2.11271062027663, 4.110017158091068, 28.470553681254387, 61.79995983839035, 84.45637330412865, 63.71449090540409, 29.272453151643276, 22.105908505618572, 29.499105289578438, 50.905515030026436, 77.27333754301071, 70.79058900475502, 33.32276031374931, 3.3196004340425134, 0.03225767140975222, 0.0415905086993007, 0.016797291827970184, 0.04755935013236012, 0.01621619019715581, 0.10347722010919824, 0.04600756386935245, 0.01830684246669989, 0.01646031410928117, 0.064674347959226, 0.05430035540484823, 0.03583272293326445, 0.01929963011207292, 0.050583156626089476, 0.019777408087975346, 0.022638689806626644, 0.033394155543646775, 0.07085225981427357, 0.03523241452057846, 0.041030821739695966, 0.041742823377717286, 0.06877810548758134, 0.05436202045530081, 0.01812731323298067, 0.04544818490103353, 0.02260323555674404, 0.024425169140158687, 0.02125061389961047, 0.047708607162348926, 0.06970201997319236, 0.019101241050520912, 0.054031137624406256, 0.11140121991047636, 0.07474771875422448, 0.034800944704329595, 0.06974533913307823, 0.09721097783767618, 0.0443577732949052, 0.08018885608180426, 0.03734661513590254, 0.0580935315520037, 0.04558320753858425, 0.03012855362612754, 0.0246905277526821, 0.007268995568665559, 0.028477059822762385, 0.05032917884818744, 0.0927912064071279, 0.03354296728502959, 0.4034125671023503, 0.1363839887198992, 0.08619437445304357, 0.1921382188447751, 0.18626530742039904, 0.17827920470153913, 0.2631932037184015, 0.12522360164439306, 0.15722995216492563, 0.2192717613070272, 0.10942276552668773, 0.10216773764113896, 0.15383688267320395, 0.1657292796880938, 0.1360631879651919, 0.16868184000486508, 0.2022135118022561, 0.12603916256921366, 0.14108015078818426, 0.1236677187262103, 0.0979774456936866, 0.12446552747860551, 0.1434210329898633, 0.0777406593260821, 0.0771465255820658, 0.11451061087427661, 0.1720684379688464, 0.15013571799499914, 0.11260257888352498, 0.1751714019337669, 0.3447573707671836, 0.13806091592414305, 0.11797631435911171, 0.1538665685802698, 0.04836260624870192, 0.12382820816128515, 0.17935116280568764, 0.1773166688508354, 0.11969814891926944, 0.3306050004903227, 0.14539664494805038, 0.22558120399480686, 0.20310777006670833, 0.13882185477996245, 0.1383947191061452, 0.0892921062768437, 0.14520077733322978, 0.13809394149575382, 0.1715962094021961, 0.12897126929601654, 0.20486640773015097, 0.36845910362899303, 0.1631652782089077, 0.15828488540137187, 0.2564043930033222, 0.764142737025395, 10.935916732996702, 62.66939878463745, 100.95948055386543, 90.96585720777512, 83.13668891787529, 93.18659484386444, 64.54730361700058, 27.85245794802904, 22.976857870817184, 33.61720651388168, 65.43623551726341, 97.48563095927238, 86.41860321164131, 72.35203921794891, 57.04284690320492, 31.405512392520905, 16.849958337843418, 3.6578511586412787, 0.5662232323084027, 0.369828722323291, 0.81269457237795, 2.2054736176505685, 3.7349497340619564, 5.613470608368516, 3.6643666215240955, 4.815963702276349, 2.0691188843920827, 12.681439518928528, 9.49445553123951, 9.035956934094429, 10.86817491799593, 12.349010556936264, 16.80915802717209, 17.87309143692255, 12.156821619719267, 15.716018434613943, 16.10101092606783, 13.359383940696716, 11.538922525942326, 12.989888917654753, 8.295958042144775, 6.862110206857324, 7.795883975923061, 9.970425590872765, 8.104994539171457, 9.731877241283655, 5.70683017373085, 9.087573364377022, 12.297861501574516, 9.330836310982704, 3.085813228972256, 5.869447197765112, 6.928230933845043, 6.159913586452603, 4.414242133498192, 1.5339043037965894, 0.8049654902424663, 9.838816802948713, 37.4311188608408, 62.28240855038166, 90.31420737504959, 96.59393280744553, 53.56230206787586, 27.84960050135851, 35.274251997470856, 62.44587957859039, 80.86596116423607, 94.62164863944054, 78.80355343222618, 37.670031040906906, 4.762291107326746, 0.09940134506905451, 0.40403125109151006, 0.08256819637608714, 0.17024952307110652, 0.07931614978588186, 0.18140498228603974, 0.22122347611002624, 0.1540292621939443, 0.31137708225287497, 0.2004302793648094, 0.14193256676662713, 0.15736331610241905, 0.2004284833674319, 0.1419291677302681, 0.07072978318319656, 0.13986574485898018, 0.22798329853685573, 0.15647894324501976, 0.14473295712377876, 0.12237198825459927, 0.18999216525116935, 0.1301851260359399, 0.20449514093343168, 0.12244033263414167, 0.10629926633555442, 0.1739798838389106, 0.1328238469432108, 0.14521193923428655, 0.14803517289692536, 0.12508459738455713, 0.3269058692967519, 0.20331143023213372, 0.19346970599144697, 0.10383736211224459, 0.16516855743248016, 0.19734567613340914, 0.2340083650778979, 0.11858193654916249, 0.2417376104858704, 0.14667852694401518, 0.39841331192292273, 0.1372360039385967, 0.1282959891250357, 0.13652385387104005, 0.07924575707875192, 0.15872181742452085, 0.22179616178618744, 0.18666505784494802, 0.11997393099591136], [0.06576346451765858, 0.09435891915927641, 0.04770589461259078, 0.008445881758234464, 0.030481609974231105, 0.040226185228675604, 0.024317865718330722, 0.004957998262398178, 0.036885767403873615, 0.06124850522610359, 0.0539171919808723, 0.07367511498159729, 0.06085754925152287, 0.04580284243274946, 0.039457539169234224, 0.021043092710897326, 0.047421459094039164, 0.011734181334759342, 0.06692990544252098, 0.052779052857658826, 0.014034212017577374, 0.05060622999735642, 0.13954231690149754, 0.08254672604380175, 0.06946922308998182, 0.03344275879499037, 0.00868175113282632, 0.04130340887058992, 0.05228645975876134, 0.046196147304726765, 0.07755672544590198, 0.03954248910304159, 0.019453746353974566, 0.033230085246032104, 0.01709750355075812, 0.046233915199991316, 0.029092435688653495, 0.011245148689340567, 0.006036006261638249, 0.03378597983100917, 0.043887537394766696, 0.041917517519323155, 0.05936850415309891, 0.023518774905824102, 0.053872818971285596, 0.08729366585612297, 0.0022384526027963147, 0.0572572981036501, 0.04360728387837298, 0.03926240256987512, 0.07131205740734003, 0.06869464355986565, 0.040833644234226085, 0.057803811941994354, 0.031617743443348445, 0.1201521948678419, 0.3172640351112932, 0.24034421338001266, 19.762013778090477, 60.71170963346958, 74.44113671779633, 67.3792764544487, 76.9354672729969, 78.33105638623238, 60.054417103528976, 37.88521729409695, 17.178891487419605, 12.686467599123716, 18.51564835757017, 27.897521629929543, 34.60983484983444, 40.30366592109203, 44.43481184542179, 58.938956558704376, 67.78203964233398, 49.9634125828743, 41.934565007686615, 36.91728763282299, 24.91590142250061, 15.353194903582335, 12.934162057936192, 4.7995400335639715, 1.9831683277152479, 0.5798108875751495, 0.5501017661299556, 0.10742401340394281, 0.27195464295800775, 1.0924070631153882, 1.3022990128956735, 1.179830515757203, 2.1825919579714537, 1.8186807353049517, 1.2749825161881745, 0.4825766879366711, 1.5389091102406383, 2.0309722563251853, 0.36436084541492164, 1.66994484141469, 1.4825271419249475, 1.943823576439172, 1.1621858063153923, 1.9063673238269985, 3.335970430634916, 1.0595029662363231, 0.4372628132114187, 0.38825138064567, 0.07492392687709071, 0.5754338193219155, 4.218065310269594, 11.037534680217505, 19.300655834376812, 39.83228601515293, 50.74832126498222, 50.61633914709091, 53.87547746300697, 25.347896441817284, 26.48859903216362, 31.108488030731678, 20.800216868519783, 56.75193831324577, 60.56794434785843, 66.22175216674805, 62.28306211531162, 36.18644244968891, 6.520347520709038, 0.11494634803966619, 0.21145154343685135, 0.014411147894861642, 0.11399230977986008, 0.034658289077924564, 0.11745492593036033, 0.03190381910826545, 0.06809124039136805, 0.026317321025999263, 0.11841102736070752, 0.06194210902322084, 0.010995533812092617, 0.0708781681896653, 0.06888703792355955, 0.06012090088916011, 0.051370230212341994, 0.0770513822499197, 0.04088907895493321, 0.012168245884822682, 0.03069236878218362, 0.01866423110186588, 0.03725330490851775, 0.018691248988034204, 0.0709044179529883, 0.023113697716325987, 0.06418612611014396, 0.05072727057267912, 0.03453979406913277, 0.02180837869673269, 0.03643021118477918, 0.05373669424443506, 0.10151181268156506, 0.054960120978648774, 0.018271948538313154, 0.07300107419723645, 0.024211911149905063, 0.014859141629131045, 0.022772081574657932, 0.04973903043719474, 0.019115265786240343, 0.038443602170445956, 0.01763680556905456, 0.0410269848362077, 0.02386497195402626, 0.036404143247636966, 0.03840740020677913, 0.05877211056940723, 0.10946041467832401, 0.04256628446455579, 0.09143734350800514, 0.04218932910589501, 0.040022343237069435, 0.05695276893675327, 0.09707955832709558, 0.06752702262019739, 0.04310088312195148, 0.05220289393037092, 0.03965153286117129, 0.08300577406771481, 0.04190938729152549, 0.0185408193647163, 0.038614177392446436, 0.07247142566484399, 0.014216296094673453, 0.02220475420472212, 0.01842780882725492, 0.027936553669860587, 0.02343565251067048, 0.013271555089886533, 0.07981668386491947, 0.06510611463454552, 0.035000600983039476, 0.04354187098215334, 0.13820947904605418, 0.08218997565563768, 0.05483946260937955, 0.06855733139673248, 0.00822501489892602, 0.0398705035331659, 0.02852849807823077, 0.01425481077603763, 0.02452330147207249, 0.031230153108481318, 0.06438994954805821, 0.0719937052053865, 0.0526814121985808, 0.06302960027824156, 0.034412905370118096, 0.030526407863362692, 0.0377293072961038, 0.037996424798620865, 0.0905412744032219, 0.025890309661917854, 0.017400524302502163, 0.03832696995232254, 0.06166741419292521, 0.11866516098962165, 0.12066018010955304, 0.034388666826998815, 0.04339276609243825, 0.05546312269871123, 0.033733676973497495, 0.028834138611273374, 0.025327954681415576, 0.015153435651882319, 0.057777005567913875, 0.21687063155695796, 0.376421784167178, 0.3638311894610524, 22.94312708079815, 69.1134350001812, 85.49731224775314, 77.66115993261337, 65.43119698762894, 45.11926531791687, 18.691005147993565, 4.910841761156917, 18.381819538772106, 39.50346685945988, 45.818902775645256, 70.8576250076294, 80.52248999476433, 79.51860666275024, 86.1329573392868, 75.7927317917347, 55.97394905984402, 34.5100674033165, 17.99596544355154, 7.384505700320005, 2.8625117987394333, 2.466714824549854, 6.013946793973446, 2.7816017903387547, 1.92906184354797, 0.7354235812090337, 0.5169637443032116, 0.12311632526689209, 0.27501903008669615, 0.4780963424127549, 0.2791176742175594, 0.32212943653576076, 0.8499883837066591, 1.61898945691064, 1.5073243738152087, 0.8171542268246412, 1.3003218127414584, 1.891906843520701, 0.7392972952220589, 0.43645313009619713, 0.8794229105114937, 1.9168192567303777, 1.993125812150538, 0.4396851535420865, 0.7950435695238411, 0.864005119074136, 0.3115055925445631, 0.7647423329763114, 0.12816728587495163, 1.2020206125453115, 2.876762696541846, 2.913450915366411, 8.906912058591843, 17.540772669017315, 39.24003839492798, 56.34122595191002, 78.47873166203499, 55.16958922147751, 53.23642015457153, 57.27768190205097, 13.544609751552343, 27.038222439587116, 50.161917731165886, 72.79495105147362, 72.99718379974365, 45.87876096367836, 7.994543965905905, 0.12023001647321507, 0.04520832277194131, 0.01671129917667713, 0.015851934840611648, 0.01498909261499648, 0.04635242876247503, 0.05180929591006134, 0.03834474067843985, 0.11877950368216261, 0.08521940762875602, 0.03100643454672536, 0.0682081063860096, 0.03544066858012229, 0.004872627159784315, 0.03461589018115774, 0.06557868458912708, 0.09685913304565474, 0.04896670703601558, 0.08796599227935076, 0.041776962170843035, 0.019177307476638816, 0.03864372229145374, 0.08724108469323255, 0.04881546847173013, 0.043407263947301544, 0.028987188015889842, 0.0425865339639131, 0.032866017281776294, 0.05713279912015423, 0.029258719441713765, 0.028036884614266455, 0.10157683223951608, 0.030754660947422963, 0.027835981527459808, 0.06727697080350481, 0.01358169025479583, 0.05084332762635313, 0.03883172685164027, 0.009076976311916951, 0.007397820345431683, 0.0317898734647315, 0.004301424851291813, 0.04541441347100772, 0.041367771627847105, 0.040538440152886324, 0.044445060993894, 0.05513892290764488, 0.0397069267637562, 0.024653179170854855, 0.046016725682420656, 0.015351998190453742, 0.10586459044134244, 0.20799847872694954, 0.21363555046264082, 0.12831304367864504, 0.09795220525120385, 0.14526635350193828, 0.1380092030740343, 0.16184758016606793, 0.08699466197867878, 0.17823433445300907, 0.1308838283875957, 0.23468719271477312, 0.13995362998684868, 0.12684522400377318, 0.17755008913809434, 0.06899397398228757, 0.22091989318141714, 0.11285556960501708, 0.18144765577744693, 0.10549765778705478, 0.08976308061392047, 0.11630939872702584, 0.2556835301220417, 0.1569287441088818, 0.16201250022277236, 0.1835185446543619, 0.10000082227634266, 0.17804274160880595, 0.1399948785547167, 0.12146305030910298, 0.17450933199143037, 0.14348289842018858, 0.17671244189841673, 0.20616120309568942, 0.07932735621579923, 0.14421774336369708, 0.14171254966640845, 0.16559567826334387, 0.16628033918095753, 0.19301968248328194, 0.17943833547178656, 0.20239100384060293, 0.18744803848676383, 0.09216412872774526, 0.2085331961279735, 0.23244080075528473, 0.1703465959872119, 0.15646484243916348, 0.23319969128351659, 0.2124931922298856, 0.11150975900818594, 0.24345741898287088, 0.14122795691946521, 0.16960842622211203, 0.14678601961350068, 0.4089021444087848, 0.4571114043937996, 0.6006743805482984, 28.7601912394166, 87.70742565393448, 96.6758868098259, 89.20712158083916, 101.65252536535263, 102.65950933098793, 92.21083000302315, 51.94294296205044, 29.059210494160652, 23.326380215585232, 29.63379666209221, 41.73562668263912, 45.199953988194466, 50.219556838274, 63.91497194766998, 77.86796763539314, 94.77901339530945, 70.05956903100014, 57.345557659864426, 51.64957210421562, 38.25924262404442, 22.49855663627386, 18.660450987517834, 7.907147705554962, 3.399347704835236, 1.9803650281392038, 0.9681850194465369, 0.13718682923354208, 0.5605205101892352, 1.335780678782612, 2.0273313391953707, 1.8882401590235531, 4.791296850889921, 3.854783191345632, 3.8002482801675797, 2.86783745046705, 4.1409897711128, 5.389048000797629, 3.8672332232818007, 3.709664703346789, 3.64416619297117, 5.425119465216994, 6.20067304931581, 5.266668917611241, 5.806813733652234, 2.1525897178798914, 0.5806448240764439, 0.8730830694548786, 0.10004006704548374, 1.157977650873363, 8.43006994575262, 20.052644982933998, 38.48363198339939, 60.16955852508545, 80.71485847234726, 73.48308652639389, 72.45056793093681, 40.863394886255264, 36.13765686750412, 52.80763976275921, 37.5233931094408, 76.95918560028076, 78.06358873844147, 88.74765023589134, 79.15625810623169, 51.09066389501095, 9.426823910325766, 0.30522666696924716, 0.6660081935115159, 0.1062838890356943, 0.145512078597676, 0.1568843043060042, 0.17689866159344092, 0.14279856404755265, 0.1798994911951013, 0.2554283500649035, 0.35076146421488374, 0.1477448150399141, 0.14717563230078667, 0.15183781884843484, 0.284224659553729, 0.11178955610375851, 0.11381202726624906, 0.3007010801229626, 0.1655487300013192, 0.12815532245440409, 0.13799719512462616, 0.152597971027717, 0.1526573279988952, 0.1916789630195126, 0.11542471416760236, 0.1599175954470411, 0.16853792272740975, 0.11125121702207252, 0.1962536503560841, 0.09576959346304648, 0.12050821052980609, 0.09353773275506683, 0.22581824596272781, 0.22083392279455438, 0.08907426366931759, 0.25961320206988603, 0.11202724374015816, 0.11454003702965565, 0.09853834606474265, 0.19012371834833175, 0.1045918368618004, 0.13127900718245655, 0.06471322165452875, 0.14035262342076749, 0.14546432881616056, 0.14510052802506834, 0.1404731482034549, 0.22071886021876708, 0.14077147672651336, 0.06788698650780134, 0.15871402487391606, 0.0816835043951869], [0.04893374083621893, 0.07609981534187682, 0.0740328524261713, 0.021909318202233408, 0.03471498173894361, 0.04737949064292479, 0.10976125908200629, 0.06915814446983859, 0.031157118355622515, 0.04664312429667916, 0.03153058933094144, 0.028505829177447595, 0.014827034465270117, 0.0431559653225122, 0.043514541393960826, 0.06287941185291857, 0.032574271608609706, 0.014464591804426163, 0.03474101627944037, 0.06114109048212413, 0.03919736816897057, 0.02109651621140074, 0.03149704796669539, 0.04139239237701986, 0.06851880651083775, 0.0579818976984825, 0.020943995587003883, 0.04640191145881545, 0.06324638903606683, 0.10687954418244772, 0.03769239287066739, 0.0741048259078525, 0.010126284996658796, 0.025443870727031026, 0.04430802713613957, 0.017537339226691984, 0.058501412204350345, 0.034661343015613966, 0.04069550828717183, 0.05569610511884093, 0.03192243217199575, 0.01987563504371792, 0.030786897987127304, 0.05221380721195601, 0.059592376710497774, 0.05967727840470616, 0.012112234144296963, 0.1198683753318619, 0.04358144971774891, 0.08715938165551051, 0.0639877500361763, 0.08025901872315444, 0.020568227664625738, 0.11023653045413084, 0.04045242152642459, 0.15250903205014765, 0.07882345278630964, 0.0901049212552607, 0.7682179589755833, 1.3718921598047018, 27.23502717912197, 69.88790944218636, 78.43479081988335, 64.17789503931999, 62.36676022410393, 68.16740736365318, 70.37800714373589, 59.92516703903675, 41.93372905254364, 25.612048767507076, 25.715899094939232, 27.878735437989235, 20.258077159523964, 16.995133347809315, 23.418207988142967, 32.053548619151115, 40.380801782011986, 35.217612236738205, 51.503154560923576, 63.35220314562321, 53.9388694614172, 56.710102558135986, 59.44780245423317, 56.843703389167786, 51.5700613707304, 35.78040763735771, 31.507723107933998, 26.774292401969433, 19.125827215611935, 12.100324351340532, 8.122533448040485, 7.019822169095278, 6.931339167058468, 3.693478759378195, 6.02115785703063, 5.8981741312891245, 7.2827941831201315, 8.652006536722183, 11.872155144810677, 12.889917232096195, 11.50888703763485, 20.057890601456165, 27.91080191731453, 34.80069860816002, 41.37951359152794, 51.41634821891785, 54.33320850133896, 64.6223571896553, 61.254324316978455, 54.2495521903038, 61.72742173075676, 49.03348848223686, 25.182232931256294, 20.372806303203106, 17.2791738063097, 31.57794713973999, 42.37108178436756, 49.116403833031654, 63.69952350854874, 63.19660909473896, 56.883456856012344, 38.30497317016125, 9.141874350607395, 0.06028388765116688, 0.21197618247242644, 0.03433448633586522, 0.07270479400176555, 0.0380731257610023, 0.028316010066191666, 0.08871947997249663, 0.05935871522524394, 0.0949246138043236, 0.017712196640786715, 0.06501779906102456, 0.005330518361006398, 0.045969617858645506, 0.040013470861595124, 0.03844442966510542, 0.07302417725441046, 0.006601455534109846, 0.0407023768639192, 0.07635254631168209, 0.017746179582900368, 0.04835451683902647, 0.048379478976130486, 0.07019199329079129, 0.1345754342037253, 0.03864169251755811, 0.047464997187489644, 0.025609978220018093, 0.04390089605294634, 0.050675706152105704, 0.03179401464876719, 0.03838784461549949, 0.03522595412505325, 0.039100966896512546, 0.059610600146697834, 0.01897898891911609, 0.04274198421626352, 0.058030448999488726, 0.052913778636138886, 0.06988708191784099, 0.06820074428105727, 0.02713645539188292, 0.02990209097333718, 0.03690141558763571, 0.016210740977840032, 0.030793850055488292, 0.02797455348627409, 0.013043060807831353, 0.10528019367484376, 0.06477778850239702, 0.03465294932539109, 0.01948387383890804, 0.0584398733190028, 0.018837242423614953, 0.07349409774178639, 0.040592769073555246, 0.04396280230139382, 0.09304125080234371, 0.039698291875538416, 0.029953735174785834, 0.06445141421863809, 0.03139773376460653, 0.024614850954094436, 0.07921512864413671, 0.01641306713281665, 0.05367275451135356, 0.011019289959222078, 0.05985138996038586, 0.039684747680439614, 0.016500647980137728, 0.08015400482690893, 0.013640068518725457, 0.021437614705064334, 0.07039966105367057, 0.10277178647811525, 0.010132832594536012, 0.07469138232409023, 0.04455130314454436, 0.017707281767798122, 0.041530877133482136, 0.03653616760857403, 0.08463788297376595, 0.08776731192483567, 0.14621763839386404, 0.019318226477480493, 0.05039670315454714, 0.015135545254452154, 0.027112626885354985, 0.07123385730665177, 0.0454219870880479, 0.025192332759615965, 0.030759861547267064, 0.02839267206582008, 0.09598874967196025, 0.0838354135339614, 0.03558415912266355, 0.020750157746078912, 0.0702855187410023, 0.10919151973212138, 0.03542525417287834, 0.04764407000038773, 0.0720920175081119, 0.05443170070066117, 0.023192651096906047, 0.05046785285230726, 0.051405530466581695, 0.01333302718194318, 0.13134630513377488, 0.006902562936375034, 0.09336057468317449, 0.0145089360557904, 0.048914155559032224, 0.9497681201901287, 1.8993960041552782, 34.037118181586266, 77.8811377286911, 89.06421884894371, 68.01593989133835, 62.21494697034359, 58.67976486682892, 44.23423960804939, 18.251262344419956, 9.682913068681955, 13.99589253589511, 21.767500564455986, 34.58113878965378, 27.34993301331997, 42.03060865402222, 55.46634949743748, 65.25556281208992, 79.91625532507896, 79.99149888753891, 77.90348052978516, 79.0636494755745, 72.70976722240448, 59.27448995411396, 50.4417385160923, 34.15255978703499, 28.133202083408833, 20.72448693215847, 12.016463801264763, 9.71614608541131, 2.9547238256782293, 2.054204447194934, 3.105155141092837, 3.63261956255883, 2.701884680427611, 1.137297973036766, 2.0673488918691874, 3.2367651164531708, 3.175678881816566, 2.9032731615006924, 3.0801099725067616, 3.8981193909421563, 5.718052871525288, 0.7274099299684167, 5.025410363450646, 8.024990782141685, 19.039431251585484, 27.30539370328188, 39.06202174723148, 47.82147131860256, 60.4055904597044, 62.22532041370869, 71.07622727751732, 68.50858345627785, 49.33235004544258, 36.7907278239727, 26.553714238107204, 19.917438738048077, 21.91439688205719, 36.87685780227184, 58.99686925113201, 70.50238206982613, 71.35973006486893, 49.33975584805012, 12.816704660654068, 0.1975754598970525, 0.15235111786751077, 0.03336230627610348, 0.05570063593040686, 0.04301293862226885, 0.09978324684198014, 0.02832024958479451, 0.023650717630516738, 0.033337281056446955, 0.04783762211445719, 0.06135921510576736, 0.028096412279410288, 0.030908233566151466, 0.0791129052231554, 0.04630438954336569, 0.0451344493922079, 0.029583216091850773, 0.07193874916993082, 0.04167451610555872, 0.04424486294738017, 0.03092665738222422, 0.04175186273641884, 0.04516434681136161, 0.09462684189202264, 0.046429471112787724, 0.05630505955195986, 0.044119369485997595, 0.024281123842229135, 0.06436775933252648, 0.061101519168005325, 0.05629336701531429, 0.08853352745063603, 0.03721591921930667, 0.07786291331285611, 0.024232145806308836, 0.05466273127240129, 0.0663774432905484, 0.025762986806512345, 0.06704968807753175, 0.014693656612507766, 0.019744291603274178, 0.02852024725143565, 0.045599523655255325, 0.031607609416823834, 0.02891258362069493, 0.04891036689514294, 0.06138645934697706, 0.08505211269948632, 0.0658803379337769, 0.03541150959790684, 0.019125282924505882, 0.08089186288998462, 0.03609161743952427, 0.20053765329066664, 0.2195260359439999, 0.2931626111967489, 0.16193124989513308, 0.15865876455791295, 0.06607667310163379, 0.2830301283393055, 0.1388249421142973, 0.126428033108823, 0.15572573756799102, 0.13533034682041034, 0.20092791906790808, 0.11904960832907818, 0.20643799449317157, 0.15530329226749018, 0.10465716070029885, 0.18306060985196382, 0.11528543531312607, 0.08813874941552058, 0.1547122755437158, 0.14366367075126618, 0.08586565498262644, 0.1403793110512197, 0.14643525093561038, 0.17475668981205672, 0.11945000442210585, 0.16372901358408853, 0.18094398983521387, 0.23720271710772067, 0.1801012217765674, 0.13016562239499763, 0.15238982829032466, 0.11153722589369863, 0.15450048143975437, 0.21599443716695532, 0.08873508733813651, 0.18300644791452214, 0.1478812366258353, 0.1562745260889642, 0.12668828945606947, 0.16444592823972926, 0.14099363121204078, 0.12399424143950455, 0.1635669285315089, 0.19985343766165897, 0.07852893890230916, 0.08658632490551099, 0.2159274063888006, 0.19156326219672337, 0.15241749555571005, 0.1294212185894139, 0.15565342269837856, 0.236662715615239, 0.3500288457144052, 0.08319382686750032, 0.2099597969208844, 0.24404243915341794, 0.24090492079267278, 1.1750105931423604, 2.7304498851299286, 42.422398030757904, 94.41528931260109, 106.17352277040482, 79.87771019339561, 81.56928062438965, 89.00034427642822, 94.50778394937515, 79.11871612071991, 62.89299018681049, 41.707424595952034, 34.90656092762947, 41.1577232927084, 23.474777452647686, 27.648312002420425, 32.623548433184624, 41.69968821108341, 56.993202567100525, 59.19963397085667, 68.70706960558891, 89.0386538207531, 81.2674780189991, 85.31672313809395, 90.65185725688934, 83.1328359246254, 77.87881225347519, 57.617501467466354, 49.496140256524086, 41.859515234827995, 28.30306436866522, 20.162584483623505, 13.888835180550814, 11.033027172088623, 10.011333245784044, 7.345643285661936, 10.08306484669447, 12.18966705724597, 13.867000602185726, 13.47700472921133, 17.639593966305256, 21.713906340301037, 20.202381648123264, 28.569905050098896, 39.43546190857887, 46.094558984041214, 55.88632956147194, 67.5154459476471, 78.95279422402382, 89.39260482788086, 88.5826326906681, 79.2179287970066, 84.16326463222504, 66.18131473660469, 40.65235421061516, 35.14372140169144, 33.4465728700161, 52.227380499243736, 60.504544749855995, 67.8131827712059, 82.39937648177147, 81.73330262303352, 81.94872826337814, 57.76557572185993, 15.795558616518974, 0.2987374464282766, 0.4568541463231668, 0.11591026428504847, 0.1923654496204108, 0.11272754170931876, 0.20925828925101086, 0.15689567400841042, 0.13058627169812098, 0.17162809206638485, 0.1784360798774287, 0.2729973307577893, 0.16843512043124065, 0.2716089802561328, 0.22142574103781953, 0.208859488775488, 0.1583355592447333, 0.08614327758550644, 0.15108189691090956, 0.20505844586296007, 0.12753470888128504, 0.10799478433909826, 0.15918025688733906, 0.14595249871490523, 0.2756477182265371, 0.13917973323259503, 0.1877929738839157, 0.16388504271162674, 0.144739146635402, 0.12873131810920313, 0.11266920148045756, 0.16170364804565907, 0.2258212145534344, 0.09615684612072073, 0.16921691363677382, 0.044359224193613045, 0.2231525702518411, 0.14202181744622067, 0.18617316236486658, 0.18181111518060789, 0.2691667206818238, 0.17103150923503563, 0.11958100832998753, 0.1477610383881256, 0.1546763110673055, 0.1332194561837241, 0.21343766420613974, 0.13349036977160722, 0.1971299189608544, 0.3106808883603662, 0.1181614282540977, 0.14099484833423048, 0.17083552287658677, 0.1152523206837941], [0.03431069679209031, 0.030796020837442484, 0.06975352502195165, 0.00735678839191678, 0.050540475713205524, 0.027566724784264807, 0.0031432871674041962, 0.02435650007100776, 0.02765192519291304, 0.04539181507425383, 0.06953246891498566, 0.032291646930389106, 0.010486896408110624, 0.0281796478520846, 0.028541849314933643, 0.04421233090397436, 0.05540386962820776, 0.03315792993817013, 0.02867823379347101, 0.021941952290944755, 0.07320663426071405, 0.036897908939863555, 0.057300635817227885, 0.02983002101245802, 0.05409996439993847, 0.05043878663855139, 0.03678493922052439, 0.06162300778669305, 0.0757558447367046, 0.038783420459367335, 0.029895912593929097, 0.031823066019569524, 0.05335715621185955, 0.03174483994371258, 0.03661216724140104, 0.027954903271165676, 0.0571593642962398, 0.03228120862331707, 0.0027179987455383525, 0.04365914886875544, 0.07851791800931096, 0.014960531989345327, 0.07732383208349347, 0.015826135932002217, 0.034616220436873846, 0.04650812392355874, 0.0079838697820378, 0.05156315892236307, 0.015984085366653744, 0.07634607478394173, 0.019396190946281422, 0.014886370099702617, 0.09653900022385642, 0.07952087864396162, 0.0944285697187297, 0.10262481155223213, 0.046037116189836524, 0.012568044548970647, 0.17499867448350415, 0.008893023878044914, 0.22761200205422938, 2.1553267585113645, 24.76285133510828, 62.10448309779167, 80.80593958497047, 68.88717994093895, 66.9240152835846, 73.13364207744598, 68.60445991158485, 77.061438113451, 84.58210095763206, 76.17871508002281, 87.54224091768265, 78.66425290703773, 49.4821722060442, 52.986222580075264, 36.58475987613201, 21.121318638324738, 14.696733579039574, 15.474870074540377, 20.342064052820206, 18.39214738458395, 14.985134303569794, 34.826936200261116, 50.841492265462875, 74.62116345763206, 63.57873558998108, 34.50838789343834, 36.70159600675106, 44.16428156197071, 47.776436135172844, 42.34356366097927, 41.613930612802505, 61.11617513000965, 60.834724232554436, 57.83266872167587, 52.468230575323105, 45.89807912707329, 54.34829369187355, 41.47924683988094, 68.12019109725952, 66.69671148061752, 50.09752258658409, 41.59441865980625, 28.552564680576324, 21.386829391121864, 22.00278203934431, 32.656238079071045, 23.865016512572765, 22.99327488988638, 35.60464806854725, 35.89692458510399, 42.36174188554287, 56.465365290641785, 65.5393011868, 73.26390668749809, 71.21760249137878, 72.04359456896782, 59.531063586473465, 34.02012549340725, 9.81406208127737, 0.15219179360428825, 0.37537217955105007, 0.05669028243573848, 0.1008012137026526, 0.07674302731174976, 0.0579855490650516, 0.08218345217755996, 0.045240687832119875, 0.051852648466592655, 0.02005260201258352, 0.09479764717980288, 0.04678134930145461, 0.019067564244323876, 0.03393653190869372, 0.03590618071029894, 0.0680038079735823, 0.019191246865375433, 0.10106187823112123, 0.0468357079080306, 0.01910990191390738, 0.05229713184235152, 0.04657429381040856, 0.048258857714245096, 0.05170327640371397, 0.06096223289205227, 0.03250062087317929, 0.048623716065776534, 0.05648294492857531, 0.02557565203460399, 0.03928903824998997, 0.04528968442173209, 0.031097948776732665, 0.018332038380322047, 0.015368080530606676, 0.06352015989250503, 0.016393279620388057, 0.055103774793678895, 0.05212719115661457, 0.07235218479763716, 0.0165410449335468, 0.02980084904265823, 0.03408397809835151, 0.01296762242418481, 0.015834548175917007, 0.07048170547932386, 0.08034070691792294, 0.06592742720386013, 0.043707425575121306, 0.04035909645608626, 0.06861281435703859, 0.06069838455005083, 0.02936006712843664, 0.03079596888710512, 0.0947226605785545, 0.06927316993824206, 0.07255773001816124, 0.050154696218669415, 0.06056233403796796, 0.018026817160716746, 0.08179483396816067, 0.036866660811938345, 0.0541651583625935, 0.04378276098577771, 0.030972416352597065, 0.04142936988500878, 0.026285054300387856, 0.01604872271855129, 0.08999309444334358, 0.02056978988548508, 0.012085202342859702, 0.04125468687561806, 0.01888291419163579, 0.04519583613728173, 0.011773423320846632, 0.049087669685832225, 0.017574392804817762, 0.055545935247209854, 0.04099162149941549, 0.046026729833101854, 0.04610558673448395, 0.044630753764067777, 0.10889456418226473, 0.016416859507444315, 0.05795916942588519, 0.0433885061647743, 0.049848155831568874, 0.030598904559155926, 0.06389888527337462, 0.0921873802144546, 0.04039929117425345, 0.01743440891004866, 0.0342051967891166, 0.02827036427333951, 0.049537073500687256, 0.025240646573365666, 0.007972340517881094, 0.11334643349982798, 0.07344028461375274, 0.07947175588924438, 0.021904440436628647, 0.0400591129437089, 0.051851765310857445, 0.06692204609862529, 0.034226778443553485, 0.02652137824043166, 0.02221331302280305, 0.0562823869404383, 0.021657000979757868, 0.03476424179098103, 0.07194530975539237, 0.03381869741133414, 0.037248540320433676, 0.08031061282963492, 0.1971664177835919, 0.012710886639979435, 0.28806358168367296, 4.771414892747998, 34.84005689620972, 79.21327024698257, 87.88986906409264, 74.6977749466896, 73.97956788539886, 66.08658581972122, 60.04389546811581, 49.24152731895447, 37.96173758804798, 34.09356415271759, 35.522975251078606, 21.08290269970894, 24.378507658839226, 31.951600089669228, 24.854954592883587, 20.88094923645258, 28.591438494622707, 36.505218744277954, 38.96164633333683, 42.50650271773338, 45.622248128056526, 68.11832159757614, 76.91177174448967, 75.56442484259605, 78.77491816878319, 57.99028046429157, 65.77387019991875, 67.04147458076477, 64.42616611719131, 61.34533703327179, 64.05443206429482, 59.3238341063261, 59.94207613170147, 65.09977877140045, 68.64808917045593, 70.52284777164459, 81.05813965201378, 58.63516665995121, 59.261160269379616, 84.47092652320862, 82.7596427500248, 79.50234353542328, 70.2365255355835, 61.102929040789604, 54.912836998701096, 61.64790339767933, 46.88413381576538, 40.67947715520859, 52.39837512373924, 40.297278463840485, 29.979562908411026, 37.60479614138603, 45.55084615945816, 62.40983471274376, 74.7321555018425, 87.91558608412743, 74.39607873558998, 50.46812430024147, 16.722513176500797, 0.7344899594318122, 0.42625521949958056, 0.0495360456261551, 0.10731090267654508, 0.08486857215757482, 0.02431326254736632, 0.03806492131843697, 0.017115216760430485, 0.028161730551801156, 0.03668152465252206, 0.118782383215148, 0.011469867295090808, 0.031131707219174132, 0.017652359128987882, 0.08463800913887098, 0.031172469680313952, 0.020735875114041846, 0.007096981507856981, 0.020745430265378673, 0.0209941647699452, 0.03358484296768438, 0.06969106587348506, 0.06595506478333846, 0.10662326574674807, 0.025002738148032222, 0.0267202905160957, 0.049266827845713124, 0.04829565339605324, 0.02020105381234316, 0.0365416409476893, 0.01703432822978357, 0.023461490382032935, 0.01882833294075681, 0.059132003952981904, 0.030907701075193472, 0.014437258505495265, 0.033090242359321564, 0.056981334200827405, 0.047056689800228924, 0.0679675317951478, 0.13638820411870256, 0.047463186347158626, 0.06433972099330276, 0.021733598041464575, 0.023730658067506738, 0.09482750378083438, 0.1270441641099751, 0.040175704343710095, 0.010238449485768797, 0.02868869065423496, 0.004161741062489455, 0.06199581825057976, 0.02155435453460086, 0.03769799608562607, 0.07881344863562845, 0.24516009871149436, 0.26340712036471814, 0.16344437026418746, 0.19451565924100578, 0.2689391782041639, 0.147451592492871, 0.1645417691906914, 0.17660720535786822, 0.13429622340481728, 0.16557731752982363, 0.09100235591176897, 0.13851616415195167, 0.11862823172123171, 0.14943882648367435, 0.18841581390006468, 0.10927376453764737, 0.10729442699812353, 0.1808289866312407, 0.18697530525969341, 0.10873889870708808, 0.09027544452692382, 0.15970332256983966, 0.16235434828558937, 0.12635148799745366, 0.09956314810551703, 0.17936563468538225, 0.12027541364659555, 0.14213673159247264, 0.24390803620917723, 0.0993399768776726, 0.1506785544916056, 0.12823124416172504, 0.11674587804009207, 0.17936377931619063, 0.07912201137514785, 0.08810232480755076, 0.1262570422841236, 0.21063089137896895, 0.13628178014187142, 0.13715444190893322, 0.16251279681455344, 0.1509573942166753, 0.13903416838729754, 0.1797851113951765, 0.14463790284935385, 0.09755563864018768, 0.11575683267437853, 0.17317998223006725, 0.17229866702109575, 0.14901298214681447, 0.09176268620649353, 0.1765123737277463, 0.18137106613721699, 0.19893437682185322, 0.16557902446947992, 0.2658833999885246, 0.21624121611239389, 0.19732899265363812, 0.471601570607163, 0.07438906104653142, 0.5245831666979939, 5.743805039674044, 39.46720540523529, 95.50073906779289, 104.02175903320312, 92.15086922049522, 90.00064060091972, 90.54192915558815, 80.02649500966072, 96.53385803103447, 101.39843299984932, 102.95553624629974, 116.68760418891907, 101.39990732073784, 70.45796245336533, 69.80294600129128, 51.41580864787102, 31.29486992955208, 27.265457846224308, 27.940330132842064, 29.46902610361576, 26.071109734475613, 24.523395784199238, 50.23955136537552, 68.1048247218132, 92.04677000641823, 84.98342782258987, 57.16514714062214, 62.81810760498047, 68.29368218779564, 68.93058881163597, 64.27928879857063, 65.45776516199112, 85.57435691356659, 85.37849262356758, 80.29485940933228, 75.3204171359539, 68.32873150706291, 76.10191360116005, 58.84998433291912, 85.56988835334778, 86.0027003288269, 67.05700054764748, 60.736776888370514, 45.107983723282814, 35.46017222106457, 38.87627251446247, 54.05436046421528, 43.19643169641495, 40.47106593847275, 57.182637602090836, 56.507805213332176, 65.75336650013924, 79.39527288079262, 84.18130606412888, 94.2953373491764, 96.58658400177956, 106.05402678251266, 85.89603245258331, 64.0027168393135, 20.954004116356373, 0.8512174990028143, 0.9987410204485059, 0.09836486162384972, 0.2781862788833678, 0.19845820002956316, 0.31166461994871497, 0.10185281469603069, 0.15955327515257522, 0.17889325768919662, 0.15146775433095172, 0.2875937131466344, 0.12269151251530275, 0.11353583700838499, 0.20835962262935936, 0.24018974276259542, 0.12350118078757077, 0.09438884997507557, 0.20360673079267144, 0.20709224219899625, 0.16016107925679535, 0.12299821246415377, 0.14077346568228677, 0.12915601953864098, 0.171171611873433, 0.11427662655478343, 0.1611223682994023, 0.11525183828780428, 0.149089616315905, 0.12262934280443005, 0.21902945009060204, 0.1387359734508209, 0.06465215774369426, 0.16300326737109572, 0.08849509904393926, 0.1523921883199364, 0.07044363330351189, 0.14673457393655553, 0.1907424023374915, 0.14632884180173278, 0.12517343246145174, 0.18770115537336096, 0.0904780211567413, 0.08569477548007853, 0.19424618541961536, 0.21522747207200155, 0.28538478480186313, 0.2653162507340312, 0.16395070793805644, 0.08826619843603112, 0.18960562505526468, 0.13738565059611574, 0.16884227748960257, 0.0890538546082098, 0.15124052355531603, 0.11760346678784117], [0.028610865338123403, 0.037084766881889664, 0.05800042912596837, 0.034209542063763365, 0.054636392451357096, 0.03320440693642013, 0.0054088103024696466, 0.05362812917155679, 0.027794091001851484, 0.03472104508546181, 0.061699178113485686, 0.08531882573151961, 0.09421053415280767, 0.02419619617285207, 0.06284283881541342, 0.05044968878792133, 0.046709078960702755, 0.03808002773439512, 0.009519409504719079, 0.04362469095212873, 0.08508427737979218, 0.05159955755516421, 0.021740932315879036, 0.09000381105579436, 0.0691525412548799, 0.06277021224377677, 0.03175124838890042, 0.015891808579908684, 0.049562514323042706, 0.020010891457786784, 0.041465683170827106, 0.13602133083622903, 0.032219977729255334, 0.061192866414785385, 0.0705810271028895, 0.02717864092119271, 0.049477683132863604, 0.005755556539952522, 0.10508454870432615, 0.02531056245061336, 0.033590149323572405, 0.015435565874213353, 0.022463832392531913, 0.058235140750184655, 0.06332802528049797, 0.03907019745383877, 0.12465517589589581, 0.05966379729215987, 0.01236087124198093, 0.07619867683388293, 0.040678134610061534, 0.03347974372445606, 0.025050168806046713, 0.08288731987704523, 0.04314971272833645, 0.1444894733140245, 0.07336704948102124, 0.032276796555379406, 0.28734562802128494, 0.07521848528995179, 0.11432561572291888, 0.014785465846216539, 0.6980978278443217, 0.962364919250831, 9.010978024452925, 29.55198135226965, 49.21546071767807, 65.26501670479774, 76.89402669668198, 80.77169582247734, 82.70009994506836, 81.73217788338661, 67.7387447655201, 70.5535577237606, 69.98605817556381, 65.74893593788147, 67.19009220600128, 80.68525046110153, 63.20189081132412, 68.17965030670166, 66.19076862931252, 49.59187611937523, 46.85648649930954, 22.935622483491898, 29.069213457405567, 22.981297932565212, 41.57620623707771, 77.113396525383, 45.49919173121452, 20.560491532087326, 22.33984675258398, 21.334437802433968, 16.345989480614662, 23.90308666974306, 26.65353298187256, 21.246214136481285, 15.829691234976053, 20.303382128477097, 13.26828857883811, 41.8292498588562, 100.06628528237343, 17.6607683300972, 24.865157045423985, 27.75252141058445, 47.522594556212425, 42.010439336299896, 57.16738902032375, 47.12964624166489, 54.13123793900013, 48.935449942946434, 52.09955535829067, 56.42331674695015, 62.4474260956049, 62.72850841283798, 68.59081864356995, 62.99144670367241, 42.40220211446285, 15.966910421848297, 3.4809682751074433, 0.026157054235227406, 0.37274399714078754, 0.01511225666035898, 0.01532357671749196, 0.10113212250871584, 0.07152618185500614, 0.04619532352080569, 0.04150663116888609, 0.10958659462630749, 0.0627033447381109, 0.012237825012562098, 0.03495315548207145, 0.04553072285489179, 0.03921205898222979, 0.010518834733375115, 0.030868183566781227, 0.039968956843949854, 0.017958571115741506, 0.021608727984130383, 0.06404004918294959, 0.03592040768126026, 0.021545009039982688, 0.01135218679337413, 0.017980329030251596, 0.05463234774651937, 0.0051328918561921455, 0.05002549944038037, 0.03837697957351338, 0.02662920487637166, 0.028498160936578643, 0.0677114017889835, 0.010229694926238153, 0.05177967679628637, 0.031806323167984374, 0.06399936464731582, 0.03921732823073398, 0.080938566243276, 0.03126353491097689, 0.09898778327624314, 0.04293260113627184, 0.037020422678324394, 0.0045676916670345236, 0.045708003381150775, 0.03419203480007127, 0.03468518079898786, 0.06528833415359259, 0.01918774392834166, 0.02157118644390721, 0.043550045738811605, 0.04853390135394875, 0.02218261593952775, 0.07743824156932533, 0.025202899087162223, 0.020169640556559898, 0.0752948374429252, 0.06258360663196072, 0.04341408799518831, 0.02481026585883228, 0.02609317201859085, 0.0773204627330415, 0.07390493585262448, 0.0217158644227311, 0.058798371464945376, 0.04928253540128935, 0.047517029161099344, 0.04966031454387121, 0.03564907477993984, 0.037422477471409366, 0.03359439069754444, 0.017679775919532403, 0.006385029037119239, 0.043814068485517055, 0.053281653817975894, 0.02074710380838951, 0.05503943430085201, 0.0557022872089874, 0.008036566905502696, 0.08883118804078549, 0.045342224766500294, 0.01979863351152744, 0.018352360239077825, 0.03392165926925372, 0.12376984566799365, 0.062222607448347844, 0.019587355200201273, 0.13912034657550976, 0.09833365431404673, 0.07691236314713024, 0.0963461011997424, 0.04770134895807132, 0.06849009281722829, 0.0858632058952935, 0.018415823142277077, 0.048365559996454976, 0.004030070613225689, 0.03345889308548067, 0.024165274589904584, 0.05851969130162615, 0.10329677432309836, 0.08114741402096115, 0.02193944568716688, 0.03136667117360048, 0.022271694069786463, 0.02042578169493936, 0.009601398269296624, 0.04806873432244174, 0.08270535268820822, 0.04158267533057369, 0.03021963369974401, 0.033589095473871566, 0.09091557658393867, 0.024695481588423718, 0.07043863864964806, 0.0582391594798537, 0.10464300052262843, 0.26056745555251837, 0.018937705099233426, 0.02461977695929818, 0.03637285430158954, 0.7442425517365336, 1.6866546822711825, 18.042839728295803, 45.62842279672623, 64.1303139925003, 79.77706119418144, 86.61296278238297, 86.55910447239876, 83.30360636115074, 73.67606297135353, 65.86732998490334, 65.19478127360344, 55.66221758723259, 51.72376312315464, 44.64827299118042, 39.38406586647034, 28.471505530178547, 30.486957281827927, 33.27203303575516, 26.511508002877235, 18.397810980677605, 27.612046748399734, 41.09739013016224, 39.391258880496025, 58.313498720526695, 59.01310957968235, 41.286726370453835, 38.93430680036545, 41.64046838879585, 39.65382479131222, 34.69938084483147, 54.68029327690601, 58.50503884255886, 47.724196538329124, 37.43002451956272, 35.685439333319664, 35.10066591203213, 43.97938348352909, 99.3574333190918, 31.31541732698679, 30.745495408773422, 25.47694131731987, 22.5661189109087, 18.33922192454338, 26.58972680568695, 39.116146042943, 34.41979184746742, 36.51429645717144, 48.677500784397125, 53.242260441184044, 64.9100549519062, 73.73342469334602, 85.62709048390388, 83.69064599275589, 62.39618584513664, 26.484702341258526, 7.69062202423811, 0.39428806921932846, 0.3361139923799783, 0.043740302717196755, 0.0728939229156822, 0.06976668330025859, 0.1245994702912867, 0.04082502789970022, 0.02549953365814872, 0.07680752736632712, 0.11230730058741756, 0.04946776432916522, 0.04652395022276323, 0.05067983620392624, 0.011015880718332483, 0.04858558822888881, 0.010667383940017316, 0.07723937567789108, 0.028164485775050707, 0.014054617367946776, 0.07883687823778018, 0.04744085141282994, 0.01302978007515776, 0.03984230192145333, 0.07838315141270868, 0.06487791906693019, 0.05129017103172373, 0.05380686801800039, 0.03934749351174105, 0.018752190444502048, 0.05125487448822241, 0.06395465024979785, 0.03571728557290044, 0.0098502106993692, 0.005779963457825943, 0.05335090732842218, 0.06668696340057068, 0.034534535952843726, 0.033737050034687854, 0.04479818970139604, 0.033594053020351566, 0.03566500497981906, 0.017805876086640637, 0.07029723725281656, 0.040138270414900035, 0.043461006571305916, 0.05460675849462859, 0.046621230940218084, 0.009216783018928254, 0.04855755731114186, 0.05874123722605873, 0.08692866278579459, 0.06858082779217511, 0.02643251162226079, 0.060723714050254785, 0.04665565174946096, 0.02707040239329217, 0.08371759016881697, 0.17552678677020594, 0.15139070455916226, 0.1432759134331718, 0.19283239409560338, 0.18571448541479185, 0.11454496489022858, 0.13150390761438757, 0.1348201054497622, 0.14878435613354668, 0.1317455805838108, 0.20985515409847721, 0.11422903262428008, 0.2134638768620789, 0.11340915982145816, 0.2075936965411529, 0.13858629710739478, 0.14103164401603863, 0.11457469532615505, 0.21033049968536943, 0.15013383293990046, 0.1618590092402883, 0.1587418999406509, 0.062447474483633414, 0.21341721061617136, 0.11081763950642198, 0.19102143502095714, 0.1646226632874459, 0.11896337076905183, 0.1701925855013542, 0.20050749240908772, 0.18794843897921965, 0.2979360456811264, 0.09267716799513437, 0.19249593402491882, 0.15039359946968034, 0.0865622867422644, 0.1348872549715452, 0.08593925376771949, 0.2135408078902401, 0.13541928579797968, 0.13684858800843358, 0.19379730481887236, 0.13540240935981274, 0.1454876916250214, 0.11480612665764056, 0.07855292511521839, 0.4227662645280361, 0.1433025862206705, 0.1703967948560603, 0.2089571108808741, 0.15747100173030049, 0.1279500444070436, 0.13798226311337203, 0.17675000941380858, 0.19684208440594375, 0.1686560281086713, 0.2945950749563053, 0.3009059722535312, 0.30556502693798393, 0.2676051529124379, 0.3612691769376397, 0.09744715891429223, 0.8933534973766655, 1.7449198057875037, 18.861344307661057, 45.915269404649734, 74.68503803014755, 93.7224192917347, 105.76398834586143, 102.50365689396858, 97.43718355894089, 90.58117344975471, 80.43921366333961, 86.04195222258568, 83.53496074676514, 86.63049504160881, 90.31734600663185, 104.03470873832703, 89.14048075675964, 91.9378374516964, 96.42596662044525, 78.94550621509552, 67.5287376344204, 39.170790910720825, 43.07305991649628, 34.19153429567814, 62.011084109544754, 91.18178442120552, 60.7193548232317, 33.47079277038574, 30.81712346524, 33.27099189162254, 25.184231624007225, 36.91113956272602, 40.50263084471226, 33.49169164896011, 24.37358122318983, 26.111258380115032, 26.953524984419346, 55.0250069797039, 121.73605129122734, 28.421331122517586, 39.637675657868385, 43.655724450945854, 65.90101897716522, 63.438614308834076, 79.12049442529678, 69.93415296077728, 69.08147111535072, 71.441091299057, 72.26924926042557, 79.10466447472572, 82.11937710642815, 82.55099594593048, 91.66646361351013, 88.79554286599159, 66.31522715091705, 27.694371230900288, 7.967805750668049, 0.38211361155845225, 0.5727534787729383, 0.14014154177857563, 0.43143057147972286, 0.25657784775830805, 0.20658539986470714, 0.1185345949488692, 0.0954922528762836, 0.19774070649873465, 0.18518399825552478, 0.16345704614650458, 0.12288405530853197, 0.09720635425765067, 0.11070093678426929, 0.09380094285006635, 0.13187649543397129, 0.21517043060157448, 0.09684375574579462, 0.10761480472865514, 0.16282191616483033, 0.1452535143471323, 0.0704096132540144, 0.12109104136470705, 0.252853364800103, 0.21000113454647362, 0.10488898537005298, 0.1685146935051307, 0.12064334077876993, 0.14041307877050713, 0.10773966365377419, 0.1346180186374113, 0.08653078257339075, 0.12039444671245292, 0.13182444119593129, 0.27142869774252176, 0.1123552062199451, 0.11998920439509675, 0.11732165847206488, 0.24874502822058275, 0.11878302888362668, 0.21616787707898766, 0.06676070319372229, 0.13626733794808388, 0.19320943480124697, 0.09350084801553749, 0.11750683916034177, 0.08258413028670475, 0.09431883576326072, 0.1742099941475317, 0.13671314605744556, 0.20296162634622306, 0.2699506958015263, 0.11180256595253013, 0.1570912596071139, 0.16754286596551538, 0.20670847763540223, 0.11106077450676821], [0.00948450722717098, 0.01792688140994869, 0.019006442817044444, 0.033799364464357495, 0.0665623568056617, 0.06907486807904206, 0.030125403209240176, 0.07572209928184748, 0.05099144545965828, 0.03192091819073539, 0.05945203658484388, 0.0751448271330446, 0.03917889240256045, 0.06396038705133833, 0.027867396638612263, 0.012145126129325945, 0.08021995206945576, 0.06836720058345236, 0.05918507493333891, 0.033901832794072106, 0.033205965446541086, 0.030402485899685416, 0.01921185445098672, 0.04247307813784573, 0.08627068949863315, 0.01900309758639196, 0.00531355147359136, 0.021891558608331252, 0.02228741090220865, 0.07096146684489213, 0.06179938660352491, 0.02983227343065664, 0.07848698529414833, 0.001403665878569882, 0.04411010006151628, 0.0275152475660434, 0.053690239510615356, 0.023594240192323923, 0.06811711165937595, 0.06545722470036708, 0.0668185313406866, 0.07107267025276087, 0.03563155267329421, 0.03113992279395461, 0.014497227748506702, 0.01542454683658434, 0.050601183393155225, 0.06381933446391486, 0.029037249587418046, 0.05082072922959924, 0.020637707530113403, 0.05757115606684238, 0.04735854723548982, 0.02996557243022835, 0.019729647174244747, 0.04409282286360394, 0.048770353314466774, 0.010750497986009577, 0.04906783578917384, 0.07714638457400724, 0.0680620146158617, 0.06181445220136084, 0.14917215798050165, 0.20532328868284822, 0.36780580587219447, 0.1775071633164771, 0.046107820598990656, 2.7820627531036735, 11.953260842710733, 22.808241918683052, 35.08055739104748, 57.95931592583656, 77.23844021558762, 79.76094245910645, 77.01902478933334, 82.53246814012527, 68.11109438538551, 66.72083258628845, 65.88769689202309, 63.4183119982481, 59.54076446592808, 71.21802806854248, 75.828328281641, 70.55142223834991, 59.660214856266975, 55.201374515891075, 45.99385678768158, 66.50084719061852, 75.74030220508575, 63.390755876898766, 69.52104672789574, 72.58549869060516, 65.27994230389595, 57.7059531211853, 57.644514217972755, 67.98241809010506, 72.64679700136185, 81.0437460243702, 82.18533396720886, 73.6854712665081, 58.376894518733025, 74.71973776817322, 84.29582431912422, 85.99349722266197, 91.04810759425163, 96.56394481658936, 82.85460725426674, 82.82238498330116, 81.92257806658745, 81.06412813067436, 67.85270065069199, 62.51504726707935, 55.76465629041195, 37.250943928956985, 17.440338358283043, 5.108207445591688, 0.1962094777263701, 0.20130999153479934, 0.23330764408456162, 0.011915797858819133, 0.06888531614094973, 0.021102961763972417, 0.15970823558745906, 0.026888514985330403, 0.0667630038515199, 0.059470493797562085, 0.01882866505184211, 0.04531089500233065, 0.02918664762546541, 0.04686742729973048, 0.04808988553122617, 0.026321306359022856, 0.02343634085264057, 0.06712104557664134, 0.0055745286317687714, 0.04309248201025184, 0.03260101490013767, 0.035613106592791155, 0.008197499773814343, 0.028631469212996308, 0.010069443906104425, 0.03557553165592253, 0.01057913887052564, 0.06131575493782293, 0.015599227990605868, 0.061703961255261675, 0.04128904089157004, 0.01123257485232898, 0.038672139125992544, 0.07013765323790722, 0.02374538227741141, 0.040706399304326624, 0.017574587618582882, 0.03734091173100751, 0.06737652991432697, 0.035022943338844925, 0.09922265817294829, 0.038253482489380985, 0.04668705201765988, 0.08574757186579518, 0.012329276160016889, 0.03230442300264258, 0.03998142492491752, 0.029666199334315024, 0.08917441649828106, 0.06658721133135259, 0.015492402326344745, 0.009277046337956563, 0.03420282562728971, 0.021451487300510053, 0.09400015755090863, 0.031742635765112936, 0.11907660766155459, 0.1334745471831411, 0.01951596244907705, 0.08563961906475015, 0.06269495104788803, 0.07699016248807311, 0.021540814050240442, 0.020039924274897203, 0.10376220481703058, 0.03660879789094906, 0.039617468282813206, 0.04443627025466412, 0.05142000605701469, 0.05074736793176271, 0.0719866251165513, 0.01106299132516142, 0.056081060829455964, 0.03954355779569596, 0.018593628738017287, 0.02582605266070459, 0.056352579267695546, 0.056090608559316024, 0.016766763583291322, 0.024816525874484796, 0.014531713495671283, 0.03359044618264306, 0.013223685637058225, 0.07277857832377777, 0.07590499415528029, 0.02458917264448246, 0.022166622657096013, 0.011476275740278652, 0.030732953127881046, 0.062213037454057485, 0.0183641177136451, 0.05145932133018505, 0.0256050410825992, 0.017474822561780456, 0.027906201685254928, 0.032603441723040305, 0.048868368758121505, 0.008594834507675841, 0.014956509548937902, 0.04905035450065043, 0.0164241882157512, 0.041821476188488305, 0.03961469636124093, 0.01866251117462525, 0.026277655088051688, 0.04023637120553758, 0.0440870786405867, 0.04236638327711262, 0.025478913084953092, 0.025592931087885518, 0.032409615014330484, 0.04153510366450064, 0.07464625974535011, 0.025556929504091386, 0.0700947199948132, 0.037834892646060325, 0.07568850225652568, 0.10383993736468256, 0.10190161090577021, 0.04417733864102047, 0.19164244935382158, 0.06878333020722494, 0.1009523298125714, 0.06945193847059272, 0.6311372271738946, 0.15736125293187797, 0.7994104851968586, 6.203893851488829, 22.671538554131985, 37.85819314420223, 55.52205450832844, 78.24828922748566, 89.86055731773376, 93.44634890556335, 89.57852885127068, 90.17638877034187, 77.52289295196533, 74.36533838510513, 67.8959347307682, 66.2120170891285, 58.273597061634064, 56.75320364534855, 51.76782175898552, 39.255556762218475, 42.82753989100456, 37.02409230172634, 39.8205142468214, 83.81720960140228, 58.35396274924278, 27.826201356947422, 29.435785487294197, 33.45185458660126, 17.943499758839607, 26.386998184025288, 27.734552174806595, 27.38863203674555, 23.01131822168827, 26.11544955521822, 22.49753639101982, 51.56503044068813, 79.85049605369568, 35.83895489573479, 46.56625047326088, 53.8089582324028, 68.850177526474, 70.50775498151779, 75.41196942329407, 80.37824213504791, 85.86544409394264, 88.99829238653183, 84.79666024446487, 81.30798384547234, 75.10179206728935, 58.755396008491516, 33.18936467170715, 10.471530351787806, 0.8950908947736025, 0.20173752796836197, 0.1560075458837673, 0.0439494176680455, 0.04133533235290088, 0.022268254215305205, 0.10110829956829548, 0.06556825741427019, 0.10150886635528877, 0.049124669458251446, 0.003969451990997186, 0.03652649000287056, 0.08217860595323145, 0.05576959258178249, 0.03458419676462654, 0.0702545563399326, 0.0769198736816179, 0.08318111387779936, 0.030130097293294966, 0.03288067469839007, 0.030394029126910027, 0.02762814492598409, 0.021291474695317447, 0.03473955795925576, 0.087862670479808, 0.04233108302287292, 0.05872791196452454, 0.05591353212366812, 0.059977848213748075, 0.08677825913764536, 0.06722154721501283, 0.0221990712088882, 0.013082147870591143, 0.051118901901645586, 0.01841260036599124, 0.026875115509028547, 0.018212513641628902, 0.019445137440925464, 0.040245993150165305, 0.04637415142497048, 0.019871775875799358, 0.03442290209932253, 0.0213917202927405, 0.036305174144217744, 0.018103712936863303, 0.041525207125232555, 0.059243949508527294, 0.041636889218352735, 0.03724208363564685, 0.04984670864359941, 0.03016990052856272, 0.05087005607492756, 0.07654685541638173, 0.03264648257754743, 0.13502691232133657, 0.0060956471043027705, 0.06137303760624491, 0.030358936674019787, 0.10335118116927333, 0.026903914549620822, 0.17224607843672857, 0.09841595106991008, 0.05266797561489511, 0.10305309755494818, 0.20833995571592823, 0.11133429303299636, 0.07360571675235406, 0.18078723340295255, 0.1674932162859477, 0.16145692847203463, 0.15447508514625952, 0.0977235272875987, 0.15454527747351676, 0.1317543676123023, 0.0891149407834746, 0.16753574134781957, 0.225189617194701, 0.17571417905855924, 0.09266795052099042, 0.13403268676484004, 0.08105994449579157, 0.12657864455832168, 0.08640521118650213, 0.15633842500392348, 0.16444543842226267, 0.06195309280883521, 0.06760517077054828, 0.07943412158056162, 0.1213519211160019, 0.16144508379511535, 0.14087549614487216, 0.17322161671472713, 0.13536739483242854, 0.1952184730907902, 0.22769834351493046, 0.18563149846158922, 0.14441580773564056, 0.1188618152809795, 0.10468551816302352, 0.1562611822737381, 0.1513729672296904, 0.1895954427891411, 0.056481301071471535, 0.08211804670281708, 0.183750020514708, 0.1362143486039713, 0.16539694595849141, 0.11794495119829662, 0.15574059536447749, 0.1019652649119962, 0.1667018939042464, 0.13398425420746207, 0.2748555794823915, 0.14186406653607264, 0.17619751015445217, 0.1018824041238986, 0.19521155627444386, 0.18672364298254251, 0.25393078511115164, 0.1822175004053861, 0.3088609641417861, 0.253213900141418, 0.20931203558575362, 0.16524490958545357, 0.5504084215499461, 0.36954471725039184, 0.6444455380551517, 5.905662579461932, 22.74584736675024, 37.853701785206795, 58.309467136859894, 81.89788699150085, 101.91665679216385, 110.60517936944962, 110.70304691791534, 113.92697632312775, 95.26431575417519, 91.2853592634201, 84.97982561588287, 79.9977457523346, 75.08824959397316, 91.33082762360573, 98.73311161994934, 89.03398007154465, 81.6947802901268, 66.06664448976517, 61.81186839938164, 94.01234373450279, 93.55378434062004, 88.35947066545486, 89.98571500182152, 97.71516904234886, 81.13339841365814, 79.8815555870533, 77.50254884362221, 85.54379135370255, 99.57057908177376, 103.43909829854965, 102.34984874725342, 87.00407579541206, 79.5897464454174, 85.06016090512276, 106.96334078907967, 109.25141081213951, 122.94599756598473, 125.22353455424309, 106.68129712343216, 105.69103226065636, 99.78421121835709, 103.03228452801704, 92.08940371870995, 88.48522111773491, 81.83708265423775, 62.482805997133255, 35.208694115281105, 10.078075714409351, 0.8184757840353996, 0.32867022149730474, 0.3638723638141528, 0.13611286733066663, 0.43236294644884765, 0.08996684468002059, 0.33331386919599026, 0.07612239147420041, 0.33335361862555146, 0.15561330219497904, 0.05729145173972938, 0.1680139813106507, 0.2649291168199852, 0.21354952070396394, 0.09825547647778876, 0.20463570370338857, 0.20556378905894235, 0.21768938371678814, 0.11277287208940834, 0.16378454107325524, 0.17060818820027635, 0.12190651323180646, 0.16705189074855298, 0.0946111157827545, 0.14038694032933563, 0.0758851194404997, 0.12588476616656408, 0.1727601938182488, 0.1195908640511334, 0.19737605965929106, 0.08660113817313686, 0.09179855420370586, 0.10348241514293477, 0.12110983254387975, 0.10723630941356532, 0.17792874772567302, 0.10717795434175059, 0.10121487197466195, 0.2249766801833175, 0.1113277324475348, 0.21762236778158695, 0.13567264017183334, 0.12739809433696792, 0.1882516805198975, 0.11709952625096776, 0.12974776356713846, 0.19658853707369417, 0.21283140376908705, 0.09761670997249894, 0.10943706671241671, 0.1372670553973876, 0.17676988412858918, 0.12166539687314071, 0.10529409410082735, 0.2698012866312638, 0.12361499655526131, 0.18200076359789819, 0.2548278635367751, 0.178935797594022, 0.17156701331259683], [0.015164766391535522, 0.0391442452382762, 0.08608079617260955, 0.0189498169493163, 0.02795779950247379, 0.005160565151527408, 0.09838667334406637, 0.04030012169096153, 0.019742727527045645, 0.014758575052837841, 0.06385237487847917, 0.06204242512467317, 0.07588434018543921, 0.018734595978457946, 0.009544793738314183, 0.06274438550462946, 0.061811754494556226, 0.043060706957476214, 0.04860100263613276, 0.04845593502977863, 0.025147451378870755, 0.04912498487101402, 0.025546164652041625, 0.06880506029119715, 0.01784017815225525, 0.02321750933333533, 0.03829108340141829, 0.05654186774336267, 0.04403704675496556, 0.04444623729796149, 0.04320594896853436, 0.027920256106881425, 0.08195780959795229, 0.04675783806305844, 0.07937002228572965, 0.03328799131850246, 0.07214744851808064, 0.033228834727196954, 0.07408198260236531, 0.05913439737923909, 0.07071890329825692, 0.09417116321856156, 0.029951534706924576, 0.01765873603289947, 0.005366963378037326, 0.08847175107803196, 0.06560907553648576, 0.04608044648193754, 0.06822977709816769, 0.043628550120047294, 0.038317377693601884, 0.030775275954511017, 0.025566913245711476, 0.03140261709631886, 0.10415193624794483, 0.02469795108481776, 0.04042311782541219, 0.041430382916587405, 0.09656657843152061, 0.06920786836417392, 0.06110590526077431, 0.08726696338271722, 0.1738174573983997, 0.1224676362471655, 0.07770123644149862, 0.27933794364798814, 0.1304133958183229, 0.2155915548792109, 0.4517650615889579, 0.44970762042794377, 0.5921872390899807, 0.15076376788783818, 1.1132941860705614, 4.398071151226759, 13.593397233635187, 18.105519264936447, 33.62561546266079, 55.01016117632389, 63.10450203716755, 82.91872501373291, 82.1324560046196, 82.2178602218628, 79.88483101129532, 83.9205564558506, 86.01085469126701, 88.32608565688133, 88.1749677658081, 78.82819890975952, 75.64341500401497, 91.25691398978233, 89.83436152338982, 82.27860376238823, 86.8383514881134, 90.1275309920311, 92.06982716917992, 81.95827335119247, 80.74442088603973, 79.56703126430511, 84.31752875447273, 78.4147734940052, 67.35785320401192, 72.35927402973175, 71.32560029625893, 67.91224345564842, 53.57634611427784, 59.71230246126652, 56.237472519278526, 44.18679155409336, 26.023980863392353, 18.93235109746456, 11.097804196178913, 4.816872803494334, 0.8818008110392839, 0.08329148608027026, 0.4216257913503796, 0.19590466283261776, 0.022404482842830475, 0.1394109716056846, 0.1581474396516569, 0.074363746389281, 0.013453487954393495, 0.013165017935534706, 0.17681791592622176, 0.056459140541846864, 0.08536763678421266, 0.04376453383883927, 0.06724975624820217, 0.029907441858085804, 0.05970915735815652, 0.10053389953100123, 0.05356169582228176, 0.046800782438367605, 0.12289748076000251, 0.08007679920410737, 0.029897137137595564, 0.0343295992934145, 0.030943073688831646, 0.0890503590926528, 0.030746174488740508, 0.11695423600031063, 0.09523392611299641, 0.023708996632194612, 0.03370445119799115, 0.014822018474660581, 0.03438905274379067, 0.06021057088219095, 0.017374625203956384, 0.06261912581976503, 0.01242098613147391, 0.0976368147530593, 0.03060851351619931, 0.026661872361728456, 0.029377490900515113, 0.01753227592416806, 0.0570416670962004, 0.06141242709418293, 0.05725113456719555, 0.037867424689466134, 0.07283524129888974, 0.03493525488011073, 0.05237692384980619, 0.056823460836312734, 0.06328166331513785, 0.11518520826939493, 0.027659151855914388, 0.052470434457063675, 0.02598077004222432, 0.07009533597738482, 0.05420520836196374, 0.025581680129107554, 0.06333873447147198, 0.026652940614440013, 0.07086693949531764, 0.07894249327364378, 0.05230639755609445, 0.06010737895849161, 0.0446411512530176, 0.045014603674644604, 0.02112107387802098, 0.05554681469220668, 0.06087352769100107, 0.02836821644450538, 0.03719384032592643, 0.023671889248362277, 0.017612220071896445, 0.05715029896236956, 0.04151570021349471, 0.009244361226592446, 0.07369758721324615, 0.046847856865497306, 0.03262981022999156, 0.02953954997792607, 0.05209351620578673, 0.06779068542527966, 0.0483089415502036, 0.013079471500532236, 0.10056371902464889, 0.010906168099609204, 0.0626799967722036, 0.025549676865921356, 0.028473167258198373, 0.14976733073126525, 0.021384081737778615, 0.05128959957801271, 0.037722750421380624, 0.09666684258263558, 0.0423651921300916, 0.023894381411082577, 0.06864536495413631, 0.023370727576548234, 0.00972894747974351, 0.028699698559648823, 0.056555790433776565, 0.026959471724694595, 0.06539118097862229, 0.03047758753382368, 0.04822993250854779, 0.01407010227922001, 0.02606927115266444, 0.050787996806320734, 0.06424459250411019, 0.060025137863704, 0.050662889261730015, 0.030412334199354518, 0.026316975927329622, 0.06390501541318372, 0.048742110884631984, 0.05498712773260195, 0.05599332413112279, 0.06717437630868517, 0.06612213706830516, 0.07931324056698941, 0.03401854664843995, 0.054645146083203144, 0.11937358547584154, 0.051530318887671456, 0.030591149115934968, 0.0848604753264226, 0.1263820199528709, 0.05241217586444691, 0.14132170501397923, 0.2453205658821389, 0.06373380194418132, 0.1271164047648199, 0.655121065210551, 0.2025028900243342, 0.1955247574369423, 0.2721570117864758, 4.925149893388152, 15.962439961731434, 33.139955922961235, 46.31120815873146, 58.82168345153332, 75.26798754930496, 83.31620648503304, 91.25786393880844, 97.47726380825043, 98.84051665663719, 94.15613561868668, 93.19492399692535, 91.235361546278, 91.33613213896751, 85.30591651797295, 76.89980998635292, 87.30659276247025, 90.43216824531555, 87.91946187615395, 87.43017733097076, 83.30307438969612, 87.54981011152267, 85.0826708972454, 85.73401674628258, 84.8230992257595, 80.51567316055298, 89.58707839250565, 90.3064937889576, 80.13027504086494, 94.15047392249107, 88.92826974391937, 87.79691085219383, 77.87303656339645, 83.05727317929268, 78.49753305315971, 68.99666726589203, 47.54424959421158, 37.87576340138912, 22.867423743009567, 11.392690222710371, 3.585875420831144, 0.26551502756774426, 0.5141284433193505, 0.24298766918946058, 0.05947067933448125, 0.13734173029661179, 0.041742511675693095, 0.059701453865272924, 0.10083924877108075, 0.050231998320668936, 0.06688810026389547, 0.04714543581940234, 0.08598036132752895, 0.058182489083264954, 0.010527743288548663, 0.0693089488777332, 0.05745293565269094, 0.03159167921694461, 0.08944059518398717, 0.06524911907035857, 0.051521721106837504, 0.017953047681658063, 0.04806310513231438, 0.024955459630291443, 0.023748180174152367, 0.07556725759059191, 0.058505037595750764, 0.04669688918511383, 0.024637781461933628, 0.03480582432530355, 0.05005055805668235, 0.030036473508516792, 0.014739034304511733, 0.02626675664942013, 0.0363029922300484, 0.08023367437999696, 0.06494392568129115, 0.03210789116565138, 0.011216808852623217, 0.030982596763351467, 0.040598850973765366, 0.026273820039932616, 0.036921089922543615, 0.08589165241573937, 0.041288061256636865, 0.029059818298264872, 0.06766984151909128, 0.04501421033637598, 0.0463534751906991, 0.03222070503397845, 0.0797522060747724, 0.0812957544985693, 0.06369926981278695, 0.030123909637040924, 0.08941879830672406, 0.028654511042986996, 0.06499009468825534, 0.04114570620004088, 0.009335044251201907, 0.01304624833210255, 0.045105539029464126, 0.07056015048874542, 0.043646613994496875, 0.06988184977672063, 0.15536975901341066, 0.0723581516649574, 0.1701886224327609, 0.16314516600687057, 0.10126072185812518, 0.19638282858068123, 0.12472134578274563, 0.12528570456197485, 0.18448731454554945, 0.20486496796365827, 0.17876019061077386, 0.07818072321242653, 0.1813907627365552, 0.11267559879343025, 0.09336352843092754, 0.13046959124039859, 0.14364131726324558, 0.0887636822881177, 0.1294716401025653, 0.15385082020657137, 0.29981857747770846, 0.14000621857121587, 0.12718034820863977, 0.1324138548807241, 0.10010785481426865, 0.23956838704179972, 0.13174847495974973, 0.21084691572468728, 0.23029614239931107, 0.18008447892498225, 0.1581549650290981, 0.14103287598118186, 0.15026692970423028, 0.09896049450617284, 0.12683185050264, 0.20443401765078306, 0.1718229503603652, 0.20027747115818784, 0.21117265918292105, 0.1382000240846537, 0.14307870995253325, 0.21839742228621617, 0.1324652263429016, 0.18600423471070826, 0.18368607707088813, 0.0975090688734781, 0.13805673021124676, 0.11212943747523241, 0.14227172825485468, 0.13258699793368578, 0.1545352436369285, 0.16613269632216543, 0.13125554047292098, 0.15489261742914096, 0.2471600382705219, 0.2242953737732023, 0.2748477424029261, 0.14404273009859025, 0.2264041270245798, 0.1331404916709289, 0.2070296643069014, 0.2767781575676054, 0.31055083440151066, 0.26291970745660365, 0.2297898640972562, 0.3839682089164853, 0.20611965766875073, 0.32690773950889707, 0.7360538723878562, 0.6598984776064754, 0.502592915436253, 0.15341270074713975, 2.395402626134455, 9.842770490795374, 24.49534758925438, 39.714629128575325, 55.207780972123146, 77.02285498380661, 92.70273640751839, 108.4749148786068, 115.23257866501808, 113.06243151426315, 110.35823062062263, 116.21955290436745, 119.59494218230247, 124.34189826250076, 112.24590852856636, 101.22148409485817, 101.41312301158905, 115.32198786735535, 111.74899399280548, 107.8931812942028, 113.12524974346161, 120.14256119728088, 120.13157218694687, 115.31548261642456, 109.26189824938774, 105.35202205181122, 114.13352563977242, 111.5844552218914, 105.26945248246193, 111.83228552341461, 99.40531834959984, 93.45806747674942, 75.94732269644737, 78.35564106702805, 76.95103123784065, 64.47703778743744, 41.69524244964123, 30.409772023558617, 18.051203079521656, 7.339849071577191, 1.8106211302801967, 0.22100098023656756, 0.9177054406609386, 0.34486667427700013, 0.1507460157154128, 0.32480808498803526, 0.31584926415234804, 0.12391682059387676, 0.21775702305603772, 0.24931450781878084, 0.29975196230225265, 0.13130676350556314, 0.2689191995887086, 0.20517947530606762, 0.17087257088860497, 0.19221679744077846, 0.17545300244819373, 0.3969331132248044, 0.3069646580843255, 0.20632508414564654, 0.21439766191178933, 0.20768450573086739, 0.12771180015988648, 0.08082637577899732, 0.12555857741972432, 0.286794924759306, 0.17123620840720832, 0.16182714141905308, 0.15889402537140995, 0.1451016857754439, 0.11439269102993421, 0.11904816856258549, 0.14767114946153015, 0.14216278097592294, 0.09252037445548922, 0.1925461774226278, 0.1750586845446378, 0.17872839700430632, 0.13007221568841487, 0.14049434394109994, 0.16266183491097763, 0.09159951761830598, 0.15817794192116708, 0.16702777094906196, 0.19589275878388435, 0.11835318437078968, 0.21359099191613495, 0.16778076882474124, 0.16101202578283846, 0.1157058916578535, 0.2803437615511939, 0.25178413779940456, 0.2123861003201455, 0.08299742490635253, 0.16972832760075107, 0.15285088011296466, 0.10675827725208364, 0.10079566243803129, 0.1348010025685653, 0.10435670221340843, 0.1337450896971859, 0.159799252578523, 0.18454929871950299, 0.1846814900636673], [0.046586862081312574, 0.06350050040055066, 0.06481102187535726, 0.04765664940350689, 0.037874415720580146, 0.022785353030485567, 0.017997953182202764, 0.0550143608415965, 0.028647213875956368, 0.01123318341342383, 0.0712338944140356, 0.014781775516894413, 0.04637161699065473, 0.02018575629335828, 0.025842240756901447, 0.07593114001792856, 0.08857544395141304, 0.02174597335397266, 0.015409452480525943, 0.07340287294937298, 0.017384688726451714, 0.02295465732458979, 0.030757028398511466, 0.04728673702629749, 0.05902283402974717, 0.12399487968650647, 0.049003105668816715, 0.03911530518962536, 0.052283828845247626, 0.03308907718746923, 0.03794222204305697, 0.04151237539190333, 0.04995493232854642, 0.03736487196874805, 0.02996700663061347, 0.029380077285168227, 0.023177279363153502, 0.015596626762999222, 0.023140125595091376, 0.056550361623521894, 0.010642804008966777, 0.035388503019930795, 0.055594824225408956, 0.02325510653463425, 0.05135135739692487, 0.0307083527877694, 0.028542988511617295, 0.013408610284386668, 0.0181574945236207, 0.04885875423497055, 0.07401138209388591, 0.055047557107172906, 0.09624124315450899, 0.033533664463902824, 0.012302782415645197, 0.039714448430459015, 0.035666021722136065, 0.013859877817594679, 0.07077313945046626, 0.025572408849257044, 0.06183881690958515, 0.008744989536353387, 0.047792288023629226, 0.1593797016539611, 0.11566896981094033, 0.14967307797633111, 0.09738798748003319, 0.019818801374640316, 0.050148328591603786, 0.11573135474463925, 0.04863617672526743, 0.042036290833493695, 0.05572936075623147, 0.2988547057611868, 0.6183322111610323, 0.49003844847902656, 0.2209630564902909, 0.3997475153300911, 1.5079873194918036, 3.907652129419148, 5.177274914458394, 8.27765442430973, 12.448944244533777, 17.94212993234396, 20.092957019805908, 29.746177531778812, 33.11332695186138, 49.7493776679039, 43.48026506602764, 37.53664679825306, 39.715187698602676, 39.562926068902016, 40.49710214138031, 40.4087682813406, 30.008367262780666, 28.04175429046154, 26.469719745218754, 32.92179822921753, 32.27628506720066, 18.79441659897566, 16.640483178198338, 17.676438689231873, 13.750308863818645, 6.430431045591831, 1.342209696304053, 0.8288299909327179, 0.17742224677931517, 0.10842505929758772, 0.2784568362403661, 0.5828029301483184, 0.11850848619360477, 0.07377305621048436, 0.13059027929557487, 0.17529954115161672, 0.19720935844816267, 0.055794421132304706, 0.037167854025028646, 0.08696888718986884, 0.03411064717511181, 0.11701686584274285, 0.11916406234377064, 0.028584391075128224, 0.032646464023855515, 0.039379988447763026, 0.043286587024340406, 0.012666454258578597, 0.04974061492248438, 0.027205996484553907, 0.06569548379047774, 0.06698740704450756, 0.08095675628283061, 0.04255282190570142, 0.02366467371757608, 0.04660235070332419, 0.07600349199492484, 0.10698268786654808, 0.010490981003385969, 0.038156246300786734, 0.004368642094050301, 0.03782842482905835, 0.019486569690343458, 0.018250411412736867, 0.041986670839833096, 0.03454499281360768, 0.028780626053048763, 0.019208028679713607, 0.05487203176016919, 0.009699838592496235, 0.03826229178230278, 0.01508188055595383, 0.03507078217808157, 0.05582344652793836, 0.01204051392051042, 0.03255792580603156, 0.05026522427215241, 0.022411369973269757, 0.08177234689355828, 0.07197855797130615, 0.036583197506843135, 0.047681006690254435, 0.04967177701473702, 0.03422492307436187, 0.04050974501296878, 0.05486205358465668, 0.02800509100779891, 0.08460522105451673, 0.01825611852837028, 0.017513193452032283, 0.050144918423029594, 0.036799459339817986, 0.05711675017664675, 0.017534782527945936, 0.0333541574946139, 0.03959742287406698, 0.08508436643751338, 0.1384999556466937, 0.05962958799500484, 0.034740537594188936, 0.11222014276427217, 0.05457765146275051, 0.02956178843305679, 0.02180603907618206, 0.02696908439247636, 0.03083426556258928, 0.03621351148467511, 0.024968786747194827, 0.034883293410530314, 0.026808979018824175, 0.05619338859105483, 0.04862834335654043, 0.037577423063339666, 0.08943220891524106, 0.011232252018089639, 0.04302240842662286, 0.008892831847333582, 0.08934036814025603, 0.03280979588453192, 0.04029961703054141, 0.059497600741451606, 0.018409804324619472, 0.045101316209184006, 0.08265569558716379, 0.02866613864171086, 0.049157876856043003, 0.007029748030618066, 0.056966198098962195, 0.06056980746507179, 0.037780760394525714, 0.04455587477423251, 0.027690455644915346, 0.03161442233249545, 0.04688036293373443, 0.07555013624369167, 0.012216010509291664, 0.06168732972582802, 0.03706565286847763, 0.00985925376880914, 0.06173378074890934, 0.07642196680535562, 0.03862039287923835, 0.0445908670371864, 0.02022347409365466, 0.013535220678022597, 0.02249461853352841, 0.06181114222272299, 0.05449984470033087, 0.04517644010775257, 0.06727525644237176, 0.05398269393481314, 0.04086695182195399, 0.020465020897972863, 0.04128124091948848, 0.06466216189437546, 0.07469207994290628, 0.056945863252622075, 0.024525006556359585, 0.10932906938251108, 0.0263624621584313, 0.11441829512477852, 0.06673623458482325, 0.19868131930707023, 0.20255466224625707, 0.07490857184166089, 0.09352470806334168, 0.21213227097177878, 0.07853218208765611, 0.08898973304894753, 0.12249677296495065, 0.22248811059398577, 0.357610181090422, 0.2924733341205865, 0.5654178536497056, 0.745058439206332, 1.514300205744803, 5.46963170170784, 11.16515463218093, 13.259431254118681, 20.42252853512764, 26.63070570677519, 33.754299357533455, 38.18284012377262, 50.5853746086359, 58.34522321820259, 75.28867363929749, 65.44352352619171, 64.7610953450203, 68.052167147398, 63.235834389925, 63.818107545375824, 64.46775108575821, 56.2871016561985, 52.09885619580746, 52.664558440446854, 56.06613211333752, 56.94236509501934, 41.306029334664345, 33.60833019018173, 33.641851991415024, 27.74395477026701, 15.438515525311232, 6.385994805023074, 4.163994211703539, 2.192413480952382, 0.24706192634766921, 0.3997621207963675, 0.6039273622445762, 0.30713508487679064, 0.1906676235375926, 0.02114822720614029, 0.14828264946117997, 0.13489963399479166, 0.12466659012716264, 0.08707606815733016, 0.01253448741408647, 0.028455476312956307, 0.08336377868545242, 0.06267454940825701, 0.014800229018874234, 0.05512292220373638, 0.055309294039034285, 0.06608392388443463, 0.04987657266610768, 0.07493810189771466, 0.021285815819283016, 0.0396003617788665, 0.07002526239375584, 0.025741987738001626, 0.015352159607573412, 0.03534211136866361, 0.1373597644851543, 0.007912541041150689, 0.04600359337928239, 0.01265528586372966, 0.08605851689935662, 0.055741402102285065, 0.01906193319882732, 0.04015313934360165, 0.034161424919147976, 0.00798676694103051, 0.017348874534945935, 0.047696855253889225, 0.04369772199424915, 0.038186577876331285, 0.028672775297309272, 0.03831945941783488, 0.02299416926689446, 0.007363035883827251, 0.0407699902280001, 0.04444495338248089, 0.015081763667694759, 0.003909937313437695, 0.04248831442964729, 0.08102198364213109, 0.04715705414128024, 0.028538492952066008, 0.014697944370709592, 0.01880213512777118, 0.04725816805148497, 0.06030792952515185, 0.011196232808288187, 0.053837370287510566, 0.018139849962608423, 0.04120949008211028, 0.0431144236063119, 0.022867497646075208, 0.032942721954896115, 0.026129485304409172, 0.008534958033123985, 0.02306933583895443, 0.10894244012888521, 0.03884783887770027, 0.04450997665117029, 0.08654895034851506, 0.17857239756267518, 0.35751462215557694, 0.18679180182516575, 0.11848645925056189, 0.17799696594011039, 0.09819209706620313, 0.1628596766386181, 0.16735287616029382, 0.12072489538695663, 0.09728206816362217, 0.11047191743273288, 0.12086002563592046, 0.13718533009523526, 0.07429811084875837, 0.18752410862362012, 0.1788575603859499, 0.17827672592829913, 0.11845090295537375, 0.1119091606233269, 0.1103234285255894, 0.11549915900104679, 0.1212974326335825, 0.09486437367741019, 0.16519447322934866, 0.1752741597010754, 0.09649817468016408, 0.31124082393944263, 0.1566136282053776, 0.18425194983137771, 0.1575688910088502, 0.20082484959857538, 0.11499285101308487, 0.08524184275302105, 0.11273439915385097, 0.09966761281248182, 0.11127686564577743, 0.10231296851998195, 0.20982307847589254, 0.13077180861728266, 0.08004552510101348, 0.15495961852138862, 0.201875003403984, 0.12084535337635316, 0.19216401589801535, 0.19499110872857273, 0.14051013684365898, 0.1245934292091988, 0.08935299207223579, 0.14766280772164464, 0.1034502504626289, 0.14897683955496177, 0.16607703524641693, 0.20621998119167984, 0.14075673767365515, 0.22035179397789761, 0.16069595993030816, 0.11046692277886905, 0.30394319677725434, 0.12395307450788096, 0.25079108483623713, 0.08711769522051327, 0.15732341824332252, 0.18013053660979494, 0.29004140524193645, 0.22511051909532398, 0.19911458512069657, 0.12032520433422178, 0.28477375977672637, 0.3257347899489105, 0.22153651400003582, 0.18214653624454513, 0.24149748118361458, 0.42819050315301865, 0.6587512360420078, 0.45151002996135503, 0.2871557272737846, 0.399794330005534, 2.0300002209842205, 5.127651477232575, 7.290734332054853, 13.060984052717686, 20.593433864414692, 25.804542638361454, 30.3420140594244, 43.501319736242294, 50.46319976449013, 67.37883567810059, 63.17267417907715, 59.510955065488815, 65.30503615736961, 60.29305949807167, 58.472337797284126, 55.91751828789711, 47.525167018175125, 48.61261546611786, 48.725769594311714, 52.203377187252045, 56.61794230341911, 45.73109328746796, 36.71277120709419, 31.412929594516754, 23.087656125426292, 10.968188401311636, 4.288272717967629, 2.6971938321366906, 0.9293452848214656, 0.1519238337641582, 0.44365243753418326, 0.7190683088265359, 0.506531047867611, 0.27627130039036274, 0.23810451559256762, 0.39000127580948174, 0.6491217215079814, 0.2726279490161687, 0.2952251583337784, 0.2296262650634162, 0.21061918028863147, 0.17013793374644592, 0.29660276253707707, 0.1120504284335766, 0.1949447690276429, 0.15904775384115055, 0.1578832944505848, 0.05991403464577161, 0.20078667352208868, 0.13434820342808962, 0.14034076390089467, 0.15412045730045065, 0.18701981927733868, 0.10803522396599874, 0.13690361083718017, 0.19229827041272074, 0.1750893352436833, 0.16457955935038626, 0.1863105338998139, 0.2629213104955852, 0.16866301913978532, 0.11710591614246368, 0.07259833291755058, 0.16861923242686316, 0.09486790630035102, 0.2536475221859291, 0.1724781034863554, 0.1308252729359083, 0.19264178088633344, 0.06092055387853179, 0.11992382118478417, 0.061762190161971375, 0.105965121765621, 0.12952005781698972, 0.1359319020411931, 0.1348572425195016, 0.0938398388097994, 0.17093611357267946, 0.20589895779266953, 0.17031821626005694, 0.11539158469531685, 0.10096340265590698, 0.19469365593977273, 0.18977161380462348, 0.12205477949464694, 0.1396106687025167, 0.15890659735305235, 0.1179381605470553, 0.07957613153848797, 0.1186409372894559, 0.1554774446412921, 0.10179536504438147, 0.12518146249931306, 0.14740826591150835, 0.14188524743076414, 0.1965766923967749, 0.15865457884501666, 0.19787194789387286], [0.023679418336541858, 0.05561637990467716, 0.027813856249849778, 0.028715066582662985, 0.0478916653082706, 0.0365516228339402, 0.014771169298910536, 0.03256637886806857, 0.049646343613858335, 0.026537553349044174, 0.0030109304634606815, 0.004546219015537645, 0.028865340354968794, 0.03196431898686569, 0.07167436648160219, 0.030937815572542604, 0.0217850715489476, 0.01784230440534884, 0.06955877805012278, 0.03267499960202258, 0.04681359561800491, 0.049142525531351566, 0.10712615985539742, 0.0632696553657297, 0.0587299565813737, 0.026061126081913244, 0.013997514670336386, 0.03040245435840916, 0.07061986369080842, 0.101012087543495, 0.041819902835413814, 0.0012285829211577948, 0.02231541398941772, 0.008445110852335347, 0.03780303224630188, 0.024430787198070902, 0.019433971829130314, 0.023780918163538445, 0.23223038704600185, 0.101319455425255, 0.03859271077089943, 0.05229623755440116, 0.06504059783765115, 0.01312370999585255, 0.004882112734776456, 0.03414410319237504, 0.011871771803271258, 0.045716964814346284, 0.04088138659426477, 0.06654087163042277, 0.05978520151984412, 0.01622558949748054, 0.06268627534154803, 0.015140438790695043, 0.04534591324045323, 0.012416704867064254, 0.0352376058435766, 0.1156660086417105, 0.02070433198241517, 0.03487004978524055, 0.1155284812557511, 0.019194874112145044, 0.0753867301682476, 0.04235705448081717, 0.04543537914287299, 0.18106363888364285, 0.06950324313947931, 0.07289807152119465, 0.11167901320732199, 0.06188074083183892, 0.12325691030127928, 0.06834219762822613, 0.09758694242918864, 0.030790224664087873, 0.16155653953319415, 0.1825125189498067, 0.18799053359543905, 0.24548523360863328, 0.0439711514627561, 0.1046352153935004, 0.20036716712638736, 0.4514676978578791, 0.4213905008509755, 0.414190570008941, 0.2645731531083584, 0.20933664520271122, 0.031710411712992936, 0.16889382706722245, 0.1764641935005784, 0.15175480220932513, 0.07254736221511848, 0.17902758641866967, 0.11774946207879111, 0.03929949140001554, 0.041337132061016746, 0.24980310816317797, 0.15460975526366383, 0.08950788571382873, 0.1842701918212697, 0.09574850162607618, 0.06671504626865499, 0.1840482748229988, 0.26924138073809445, 0.3161130828084424, 0.16478507488500327, 0.04003013949841261, 0.054487376619363204, 0.10976240198942833, 0.058097049331991, 0.10151435824809596, 0.07025027414783835, 0.0757139059714973, 0.03873834983096458, 0.08516115645761602, 0.041463493835181, 0.08042390167247504, 0.031335300591308624, 0.03405758361623157, 0.07877708339947276, 0.029471535854099784, 0.06084054664825089, 0.010748611075541703, 0.023549442303192336, 0.018240242134197615, 0.0032317439809048665, 0.00818855040051858, 0.06644746492384002, 0.04457486262253951, 0.03737987077329308, 0.060429660297813825, 0.03230201102269348, 0.02647409972269088, 0.03942833936889656, 0.024213436263380572, 0.014279816514317645, 0.004145226421314874, 0.10889424505876377, 0.027751758898375556, 0.025143297207250725, 0.013378604326135246, 0.004816265682165977, 0.022694131948810536, 0.016657474916428328, 0.007864295876061078, 0.03209515220078174, 0.024780251551419497, 0.00818534988866304, 0.05372295338020194, 0.05655165667121764, 0.037838863136130385, 0.0728530899505131, 0.07825311971828341, 0.08172324640327133, 0.0447489556245273, 0.020079812857147772, 0.12840486218919978, 0.022747432994947303, 0.03912495682016015, 0.010578142537269741, 0.013251792624942027, 0.053189675745670684, 0.0255448863026686, 0.025597079693397973, 0.025641547326813452, 0.04690140653110575, 0.003282940342614893, 0.02111782512656646, 0.045544085223809816, 0.017162486001325306, 0.04636355355614796, 0.03852120484225452, 0.013044529332546517, 0.0303597307720338, 0.030327900058182422, 0.030934377573430538, 0.02160920852475101, 0.038437976691056974, 0.035009803614229895, 0.0245798902324168, 0.04736391667393036, 0.05976077001832891, 0.04146807288634591, 0.029421294311759993, 0.14367401628987864, 0.01021493360894965, 0.040406608750345185, 0.04354424214398023, 0.027921790497202892, 0.08147080487105995, 0.06130654117441736, 0.017288784692937043, 0.02400320809101686, 0.029445970722008497, 0.031110917807382066, 0.011848648337036138, 0.04262622773239855, 0.07326107079279609, 0.05073389424069319, 0.06327044946374372, 0.044488680723588914, 0.11754150487831794, 0.03934312968340237, 0.009775921716936864, 0.05930705803621095, 0.04802466930414084, 0.031635840714443475, 0.03995909370132722, 0.0159711478772806, 0.024568385088059586, 0.01653528401220683, 0.01635507942410186, 0.02016173668380361, 0.03323739911138546, 0.027182860030734446, 0.11462130220024846, 0.048442375991726294, 0.038489711805596016, 0.06260066118557006, 0.02454250083246734, 0.024476290127495304, 0.006494849267255631, 0.03742893044545781, 0.05567711727053393, 0.03722461719007697, 0.04407116699439939, 0.017078267082979437, 0.013039870500506368, 0.04767276514030527, 0.04759711060614791, 0.024363958655158058, 0.04758034920087084, 0.017023309192154557, 0.03914976681699045, 0.03159239538945258, 0.08668747963383794, 0.031119155646592844, 0.052055585038033314, 0.018257699302921537, 0.019035351324419025, 0.015483491915802006, 0.06448038024245761, 0.1662475214106962, 0.0353679640829796, 0.05704820912797004, 0.21485862467670813, 0.17179912741994485, 0.15815015591215342, 0.007451460460288217, 0.06418362507247366, 0.05368656216887757, 0.0663031023577787, 0.028280344304221217, 0.24812656687572598, 0.2443489313009195, 0.12986178713617846, 0.09429490892216563, 0.2506270701996982, 0.2910089283250272, 0.42416254116687924, 0.09761818684637547, 0.03164235677104443, 0.2058286764076911, 0.09865367581369355, 0.303606825764291, 0.623564055422321, 0.34435331588611007, 0.3383697650860995, 0.7193062710575759, 0.7890096714254469, 0.6138990959152579, 0.4258633655263111, 1.0498504154384136, 0.673095288220793, 0.678163681877777, 0.9504002518951893, 0.24026588711421937, 0.2004172175657004, 0.21264472394250333, 0.25934843346476555, 0.29949372459668666, 0.38136187533382326, 0.2651115960907191, 0.2048710238886997, 0.05558984441449866, 0.07272015645867214, 0.12335460662143305, 0.01273269650482689, 0.15310421964386478, 0.029494635200535413, 0.08224125806009397, 0.055316055004368536, 0.034913888448500074, 0.04372644310933538, 0.015950623783282936, 0.03204288273991551, 0.07809780305251479, 0.03232504728657659, 0.030915866555005778, 0.03967078788264189, 0.013497933323378675, 0.040016250204644166, 0.05080333699879702, 0.04834480212593917, 0.043560224294196814, 0.022909736981091555, 0.01009595898722182, 0.02396823252638569, 0.0148873256148363, 0.012444907406461425, 0.018347011209698394, 0.020053229127370287, 0.08447450658422895, 0.09755085920915008, 0.033865901714307256, 0.011780284476117231, 0.013967648792458931, 0.06373916767188348, 0.05281472418573685, 0.04310382573748939, 0.02332794090762036, 0.03488538997771684, 0.031056754014571197, 0.018710160766204353, 0.06879857392050326, 0.07232835443574004, 0.011668318511510734, 0.0281285008895793, 0.061347526279860176, 0.05683124967617914, 0.03590318614442367, 0.033524001701152883, 0.041455834871158004, 0.01926268043462187, 0.01909044094645651, 0.02466730966261821, 0.03353515989147127, 0.08611667901277542, 0.019581443993956782, 0.039928988480824046, 0.04906555368506815, 0.034949188702739775, 0.03533727256581187, 0.030065955324971583, 0.056940768408821896, 0.035810202462016605, 0.06897642961121164, 0.0143352224768023, 0.004539890815067338, 0.06002067384542897, 0.044223938093637116, 0.018362353257543873, 0.023421946898452006, 0.11936614915612154, 0.11651438733679242, 0.08432787304627709, 0.05778815262601711, 0.2238095787470229, 0.08437096956185997, 0.12402915948769078, 0.16411362419603392, 0.07757040322758257, 0.11143720665131696, 0.07345256715780124, 0.11051384877646342, 0.3128736378857866, 0.10799747833516449, 0.19971133122453466, 0.12251195730641484, 0.09345305370516144, 0.09665856763604097, 0.14803588535869494, 0.0859550540917553, 0.14399459440028295, 0.14270883839344606, 0.17507708980701864, 0.20182058913633227, 0.13315382064320147, 0.11700939983711578, 0.13245326292235404, 0.11252242693444714, 0.0932275150262285, 0.3609818470431492, 0.13918538839789107, 0.07721700734691694, 0.12059193220920861, 0.1362739282194525, 0.08927131872042082, 0.0971868283522781, 0.10561355156823993, 0.09754124097526073, 0.33661814813967794, 0.13388154096901417, 0.17425734316930175, 0.12059970991685987, 0.14083248126553372, 0.15257137245498598, 0.1391315381624736, 0.06485865291324444, 0.21681194251868874, 0.10988489346345887, 0.07952188796480186, 0.21741829201346263, 0.11708340680343099, 0.12887999997474253, 0.12533815955976024, 0.08623923728009686, 0.16064218390965834, 0.18868662358727306, 0.19160155701683834, 0.20725981914438307, 0.14616467873565853, 0.13154196494724602, 0.20490728522418067, 0.09694468782981858, 0.15255719743436202, 0.15516166080487892, 0.18032224819762632, 0.2975073811830953, 0.188600059482269, 0.16348376346286386, 0.31823019264265895, 0.355397779494524, 0.3215983259724453, 0.22488732560304925, 0.16759825986810029, 0.15412943728733808, 0.20680740592069924, 0.18092132464516908, 0.409379968768917, 0.28956450114492327, 0.15090631961356848, 0.16147249873029068, 0.1613981503760442, 0.5333511962089688, 0.6942608649842441, 0.5528221826534718, 0.4204336943803355, 0.20916086010402068, 0.1540384945110418, 0.13017163379117846, 0.16334906365955248, 0.19045597786316648, 0.15247823292156681, 0.29079824744258076, 0.27162207174114883, 0.19067405053647235, 0.1660850059124641, 0.4709435231052339, 0.2590616379166022, 0.35355229570996016, 0.5098669126164168, 0.19596911093685776, 0.23771212727297097, 0.3608193463878706, 0.6028416892513633, 0.7688074023462832, 0.5213010928127915, 0.3187515662284568, 0.2708218287443742, 0.20025504345539957, 0.39983010152354836, 0.3634320030687377, 0.22025139624020085, 0.2583360846620053, 0.25136613054201007, 0.2649809780996293, 0.437421603128314, 0.1301943138241768, 0.11431794191594236, 0.20270370034268126, 0.2762371319113299, 0.17033556767273694, 0.12554566405015066, 0.1105231256224215, 0.19546186784282327, 0.2442010212689638, 0.11238881808822043, 0.14646379393525422, 0.12653206737013534, 0.14296658628154546, 0.1901597570395097, 0.20242205529939383, 0.20088244025828317, 0.09263344065402634, 0.12868379097199067, 0.119894113013288, 0.1446999909239821, 0.17237457388546318, 0.14586001227144152, 0.13130109349731356, 0.14861070842016488, 0.06383844476658851, 0.23043088673148304, 0.15228950476739556, 0.10412107774754986, 0.0938400169252418, 0.09745656192535535, 0.16857937909662724, 0.09903095400659367, 0.24479355197399855, 0.25667118025012314, 0.10951957869110629, 0.12770201865350828, 0.16453321964945644, 0.1981063626590185, 0.12385903697577305, 0.1259534148266539, 0.14797928917687386, 0.07382543699350208, 0.15870431758230552, 0.10460105433594435, 0.08194977956009097, 0.21960330836009234, 0.09635225360398181, 0.1351569959660992, 0.1772238261764869, 0.11343785125063732, 0.08038977030082606, 0.10264985161484219, 0.13864446664229035, 0.12859342707088217, 0.1307195911067538, 0.06363457679981366, 0.09074936519027688, 0.15076330775627866, 0.11049690554500557, 0.08205620353692211, 0.11696463348926045], [0.048554737149970606, 0.0531283223972423, 0.01809544541174546, 0.03713160753250122, 0.09029657347127795, 0.01615472552657593, 0.033466429595137015, 0.03892182357958518, 0.1305208439589478, 0.03044667337235296, 0.027512913511600345, 0.016664634786138777, 0.03392224185517989, 0.016733346528781112, 0.017064839776139706, 0.015538470215687994, 0.05931826446612831, 0.0813586292497348, 0.04785542252648156, 0.034711181942839175, 0.023340308798651677, 0.03859676289721392, 0.03443062785663642, 0.030592306866310537, 0.08985026070149615, 0.044201640266692266, 0.02261229161376832, 0.006094810332797351, 0.020267607760615647, 0.030542165513907094, 0.06771569140255451, 0.04910355535685085, 0.03763639040698763, 0.05157116298505571, 0.007215752038973733, 0.05277478921925649, 0.030206211959011853, 0.07547350207460113, 0.028045731014572084, 0.05336708614777308, 0.010090384530485608, 0.061248649944900535, 0.037966738891554996, 0.13977036403957754, 0.036567441711667925, 0.022761598738725297, 0.01547705935081467, 0.0599718887679046, 0.029427789959299844, 0.05607370985671878, 0.012746591364702908, 0.017067429871531203, 0.049348927932442166, 0.0567490605317289, 0.05476399361214135, 0.039169901283457875, 0.0895982347719837, 0.02827641277690418, 0.07395298991468735, 0.0723507153452374, 0.07583951446576975, 0.05930368868575897, 0.05056209447502624, 0.08906063783797435, 0.04828238750633318, 0.021125157545611728, 0.06992217065999284, 0.03519318088365253, 0.06913453675224446, 0.1305755996145308, 0.10510887630516663, 0.0409471111925086, 0.005277228910927079, 0.07456066043232568, 0.18589700921438634, 0.18632571824127808, 0.17470767837949097, 0.20263361191609874, 0.0530941947363317, 0.009216845173796173, 0.05630308543913998, 0.0855847001366783, 0.18801992264343426, 0.11686272177030332, 0.07739129330730066, 0.027426236229075585, 0.03719739521329757, 0.11169417528435588, 0.1997845812002197, 0.08826025383314118, 0.05653842046740465, 0.1698484961525537, 0.037598180933855474, 0.0630244349304121, 0.037836592164239846, 0.1343772214022465, 0.1426170050399378, 0.11322123318677768, 0.11009840192855336, 0.05160628512385301, 0.08246356097515672, 0.02533098635467468, 0.12230800770339556, 0.04921261395793408, 0.05762762979429681, 0.031232809997163713, 0.040413436508970335, 0.09538590311422013, 0.10099603488924913, 0.08917126237065531, 0.02123451115039643, 0.02126696526829619, 0.015415751458931481, 0.07283391285454854, 0.13055340939899907, 0.07219976250780746, 0.039996442283154465, 0.0344983339891769, 0.047085815385798924, 0.062119649301166646, 0.03411439131014049, 0.03119526845694054, 0.030745345138711855, 0.005337468110155896, 0.04247095188475214, 0.14096210477873683, 0.08208047176594846, 0.017228668875759467, 0.042525028475211, 0.019100179779343307, 0.0506789604696678, 0.03517452329106163, 0.08398452584515326, 0.048462929771631025, 0.02600915904622525, 0.0658569231745787, 0.0359176097845193, 0.049853514137794264, 0.05782529340649489, 0.0876138654712122, 0.03512088085699361, 0.05489397335622925, 0.07760770356981084, 0.01649274225201225, 0.014926281874068081, 0.05835434451000765, 0.06417755430447869, 0.019040666957153007, 0.016810355482448358, 0.019417948860791512, 0.045859423771617, 0.03554954535502475, 0.043720932662836276, 0.053974801194272004, 0.023475884336221498, 0.04615832745912485, 0.06592031000764109, 0.06989493384025991, 0.006760094702258357, 0.030769396289542783, 0.030732470731891226, 0.07172630197601393, 0.039751377698848955, 0.07973526284331456, 0.0354799949855078, 0.08959733677329496, 0.03655025728221517, 0.018869379273382947, 0.04982045888027642, 0.08465373524813913, 0.02579123480245471, 0.04504784075834323, 0.06662320549366996, 0.019132329616695642, 0.0680696067865938, 0.11786834671511315, 0.04583894791721832, 0.023873758982517757, 0.015173132251220522, 0.040519392932765186, 0.05203164335398469, 0.02115692517691059, 0.08090331422863528, 0.023367870307993144, 0.08334987825946882, 0.03591792148654349, 0.04135613846301567, 0.04619962055585347, 0.08606309595052153, 0.033846242222352885, 0.029716507669945713, 0.04789549107954372, 0.10832591578946449, 0.016771068039815873, 0.031127662514336407, 0.05761028209235519, 0.07168115713284351, 0.04693895920354407, 0.02553188202000456, 0.025482263881713152, 0.10343315138015896, 0.04538176639471203, 0.050570955718285404, 0.05239796002570074, 0.04431614994246047, 0.03378809124114923, 0.04536778804322239, 0.07004557497566566, 0.011920409378944896, 0.021449745108839124, 0.024948038153524976, 0.011665443616948323, 0.08782026416156441, 0.03973679449700285, 0.03596956012188457, 0.03621039446443319, 0.025457240517425817, 0.03578224575903732, 0.05634962551994249, 0.03412323771044612, 0.04050237919727806, 0.017149067971331533, 0.026120581387658603, 0.008621222496003611, 0.03226986118534114, 0.04154084046604112, 0.06032549244991969, 0.0435619089694228, 0.09123562776949257, 0.07342380151385441, 0.04402910948556382, 0.0754609152500052, 0.03736078644578811, 0.017010432929964736, 0.06928343384061009, 0.04033447570691351, 0.046898957443772815, 0.03615026937040966, 0.030843842978356406, 0.04368687921669334, 0.0704111420782283, 0.08138114601024427, 0.04598254607117269, 0.024210170813603327, 0.10065567854326218, 0.13404843513853848, 0.06437073534470983, 0.05010464577935636, 0.11073042973293923, 0.15254743077093735, 0.08945465146098286, 0.1425215500057675, 0.061328749943641014, 0.13208177348133177, 0.11925079714274034, 0.048811494270921685, 0.10924813075689599, 0.11174212544574402, 0.24070344254141673, 0.05999951150442939, 0.045437256776494905, 0.06965248903725296, 0.029657122868229635, 0.1159981865203008, 0.375538450316526, 0.12549212551675737, 0.10778276016935706, 0.30325531493872404, 0.15215376595733687, 0.08225484678405337, 0.0810365000506863, 0.17772222287021577, 0.22109560406534, 0.24016333714826033, 0.17055009288014844, 0.0746528129093349, 0.01773216041328851, 0.2339288662187755, 0.14936631865566596, 0.0635634567879606, 0.054079655528767034, 0.05804624561278615, 0.08260627597337589, 0.04994445691409055, 0.08579733286751434, 0.15290713490685448, 0.01329523238382535, 0.14742088242201135, 0.09031529785715975, 0.04158012234256603, 0.07605207298183814, 0.08827226178254932, 0.03404135655728169, 0.05269101558951661, 0.053116666967980564, 0.036878446117043495, 0.030571131537726615, 0.022165613336255774, 0.08649171591969207, 0.04346623500168789, 0.028920930926688015, 0.07008892382145859, 0.05025645950809121, 0.010869903981074458, 0.04026175636681728, 0.031181746526272036, 0.062367099890252575, 0.016462329040223267, 0.012129505776101723, 0.02335033150302479, 0.04695914562034886, 0.08390033661271445, 0.026055114685732406, 0.04371328112029005, 0.03375077976670582, 0.04897994323982857, 0.023638182756258175, 0.02103193080984056, 0.06589251657715067, 0.019446632868493907, 0.01268693011297728, 0.05773729324573651, 0.05542288345168345, 0.03246935419156216, 0.01222212858920102, 0.01399846554704709, 0.030301850674732123, 0.016328681231243536, 0.04105706037080381, 0.03373367326275911, 0.035435759273241274, 0.018702520355873276, 0.02581714874395402, 0.0636960488918703, 0.05378433270379901, 0.020691821227956098, 0.053068839260959066, 0.031216582938213833, 0.007541935683548218, 0.05368364181776997, 0.05786841218650807, 0.012242174925631844, 0.02075664040603442, 0.030716911605850328, 0.029007522862229962, 0.02228685058071278, 0.08801805393886752, 0.03796895791310817, 0.031626934942323714, 0.04198690832708962, 0.034709174433373846, 0.1146235509077087, 0.10321666690288112, 0.1379385803011246, 0.1454909422318451, 0.14169340225635096, 0.12236387658049352, 0.10158895151107572, 0.15359847515355796, 0.12929343560244888, 0.3075941774295643, 0.10659979161573574, 0.17107614199630916, 0.17652522772550583, 0.3263784694718197, 0.13667911116499454, 0.09691071230918169, 0.24576166877523065, 0.25216468144208193, 0.1688904280308634, 0.10370632851845585, 0.1573091244790703, 0.14504280377877876, 0.14486127445707098, 0.10068040690384805, 0.10701809573220089, 0.19016567937796935, 0.11172098907991312, 0.11554697557585314, 0.08080313171376474, 0.140313868469093, 0.07736190425930545, 0.14544391975505278, 0.12650950608076528, 0.12234116686158814, 0.12275925575522706, 0.15889830014202744, 0.13278991595143452, 0.1777728967135772, 0.16868932085344568, 0.12198587108287029, 0.1548248148174025, 0.08470232365652919, 0.203579033841379, 0.16241959790932015, 0.17126791295595467, 0.15399531635921448, 0.1571978468564339, 0.12109427712857723, 0.12915992323542014, 0.17044559848727658, 0.23121949285268784, 0.08765075021074153, 0.1690901251276955, 0.2466129863751121, 0.1655946540995501, 0.12576167355291545, 0.1401350850937888, 0.12994602089747787, 0.09131284081377089, 0.17307924310443923, 0.18812796450220048, 0.18085439776768908, 0.09653877015807666, 0.1693060455727391, 0.14639428438385949, 0.18135611928300932, 0.11932933863135986, 0.14038737077498809, 0.13041090220212936, 0.1315658027306199, 0.3778806980699301, 0.18877891707234085, 0.2421724348096177, 0.13352585927350447, 0.2174445491982624, 0.28314560651779175, 0.23161231161793694, 0.23260062967892736, 0.36137117771431804, 0.20010140404338017, 0.1344505901215598, 0.12347553958534263, 0.19731747452169657, 0.603687025140971, 0.20579198462655768, 0.17012723197694868, 0.2311277188709937, 0.17903177213156596, 0.2618188055930659, 0.4564814694458619, 0.16229616390774027, 0.40453172579873353, 0.3578161122277379, 0.20342808100394905, 0.18839444004697725, 0.10258542577503249, 0.35495059099048376, 0.3188762767240405, 0.4459950712043792, 0.2465763539657928, 0.1894532621372491, 0.12670106923906133, 0.4072304716100916, 0.42666286637540907, 0.21351983479689807, 0.12896923581138253, 0.1869381236610934, 0.13336436793906614, 0.28893254755530506, 0.27981769759207964, 0.38865056703798473, 0.18797480006469414, 0.23603908892255276, 0.10990266790031455, 0.14482504280749708, 0.27208163926843554, 0.20860153308603913, 0.22462628257926553, 0.13784751878120005, 0.19021146988961846, 0.17427441256586462, 0.13154441403457895, 0.14703443128382787, 0.21864651673240587, 0.13309015921549872, 0.2463856665417552, 0.23292377562029287, 0.18309103790670633, 0.08950231218477711, 0.14965817565098405, 0.14168908295687288, 0.17650774272624403, 0.14060004061320797, 0.1752913775271736, 0.14763629820663482, 0.08994074334623292, 0.2610082912724465, 0.14302773925010115, 0.13690165156731382, 0.15813422942301258, 0.22258491633692756, 0.18236110598081723, 0.14998583385022357, 0.1484070482547395, 0.07382282463368028, 0.047770012461114675, 0.15140079776756465, 0.12412389463861473, 0.08195658505428582, 0.1683757486171089, 0.08123883177177049, 0.11217362494789995, 0.15728322352515534, 0.11176432308275253, 0.0990970571001526, 0.11948610990657471, 0.1413410750683397, 0.15197695669485256, 0.15079465607414022, 0.18773851508740336, 0.1389187347376719, 0.13413373759249225, 0.21349187067244202, 0.20551663299556822, 0.20598102448275313, 0.11620701945503242, 0.17455555294873193, 0.10424405903904699, 0.1276502464315854, 0.11762656242353842, 0.24514259886927903, 0.12962777313077822, 0.11584321124246344, 0.1761405577417463, 0.10068668547319248, 0.09088130420423113, 0.2052919997368008], [0.023400151876558084, 0.031000141134427395, 0.026666243611543905, 0.026143819886783604, 0.014746917768206913, 0.10587448326987214, 0.02787310746498406, 0.009599795230315067, 0.016010982653824612, 0.06911137432325631, 0.025512931279081386, 0.0901611166773364, 0.06661566527327523, 0.0505122407048475, 0.043960535040241666, 0.011901038396899821, 0.06137528260296676, 0.05994916791678406, 0.009747513231559424, 0.07095558903529309, 0.05580002805800177, 0.10369066178100184, 0.07425410891300999, 0.044941435335204005, 0.010857062970899278, 0.03725730137375649, 0.0333740322093945, 0.09069630163139664, 0.009768237705429783, 0.05068768441560678, 0.007716781501585501, 0.057745538506424055, 0.07447625597706065, 0.04238718196575064, 0.06078385027649347, 0.01701903442153707, 0.07126063399482518, 0.03077887166000437, 0.025033722813532222, 0.014182279755914351, 0.073899199051084, 0.037355884560383856, 0.025708192188176326, 0.03144999580399599, 0.05534935888135806, 0.11578579127672128, 0.008258979287347756, 0.037520949335885234, 0.04116842334042303, 0.035876246183761396, 0.014720293220307212, 0.03791450282733422, 0.04986299136362504, 0.02694924307434121, 0.04153018322540447, 0.01390480558256968, 0.041747699287952855, 0.1338916935492307, 0.011930201089853654, 0.05851441092090681, 0.07800178398611024, 0.037888000733801164, 0.02856366289051948, 0.11583623505430296, 0.04977765551302582, 0.02959970290248748, 0.1290099203470163, 0.0336076120584039, 0.055812574064475484, 0.05084372838609852, 0.05256819385976996, 0.1054075313732028, 0.029487545834854245, 0.03908247257641051, 0.06087754270993173, 0.0698431022465229, 0.08174848684575409, 0.08845453325193375, 0.08084786095423624, 0.038601393898716196, 0.05288891668897122, 0.0993819824361708, 0.09163110342342407, 0.01869724554126151, 0.09552414296194911, 0.03430337550526019, 0.016870608596946113, 0.1560125479591079, 0.13961565593490377, 0.06898540959809907, 0.01731369487970369, 0.1081819020328112, 0.11115457455161959, 0.006623694453082862, 0.027554744665394537, 0.14223050937289372, 0.08158621625625528, 0.049034342664526775, 0.09502088520093821, 0.024841953709255904, 0.05467040136863943, 0.060308578904368915, 0.1369978635921143, 0.11027920394553803, 0.03600592535804026, 0.10692273717722856, 0.05815233933390118, 0.11831154246465303, 0.028609468245122116, 0.03197719524905551, 0.03751617361558601, 0.025932747521437705, 0.04635931589291431, 0.06989620291278698, 0.08299244509544224, 0.0139839890289295, 0.05620098818326369, 0.057495631408528425, 0.05648983576975297, 0.04760521856951527, 0.03529699992213864, 0.039675455991528, 0.047463164082728326, 0.010122316361957928, 0.07431119491229765, 0.1070090637949761, 0.04109488021640573, 0.04983549479220528, 0.03215596378140617, 0.04140719451243058, 0.06760316697182134, 0.02186587287724251, 0.023584707305417396, 0.09611946414224803, 0.07198074730695225, 0.03863805970468093, 0.024317546594829764, 0.01733447687001899, 0.12077084174961783, 0.06414711140678264, 0.029144990876375232, 0.03451565200521145, 0.05451155579066835, 0.048936650055111386, 0.0911488187557552, 0.04690023764851503, 0.052333793937577866, 0.055858776468085125, 0.01829418328270549, 0.06701449543470517, 0.028512384196801577, 0.04480589319427963, 0.06775570058380254, 0.023186713915492874, 0.01111447225412121, 0.10674364209990017, 0.03494165590382181, 0.02754169956460828, 0.04698921744420659, 0.017790773381420877, 0.04679416248109192, 0.04857157277001534, 0.008782255554251606, 0.012986613055545604, 0.017571092103025876, 0.04998581309337169, 0.05250549722404685, 0.009008887045638403, 0.026956627443723846, 0.08102668885840103, 0.033854528301162645, 0.03751069285499398, 0.025859256347757764, 0.07157865911722183, 0.022492492280434817, 0.056683057628106326, 0.015135634312173352, 0.06517211382742971, 0.02008066076086834, 0.08352289514732547, 0.03380918307811953, 0.08341717621078715, 0.05704892901121639, 0.02636818782775663, 0.0248126295991824, 0.019209666970709804, 0.018016004069068003, 0.0583562815154437, 0.09038805059390143, 0.03838897267996799, 0.026232079799228813, 0.03985519302659668, 0.028508059331215918, 0.02044933004071936, 0.05960055146715604, 0.03141819477605168, 0.04540517373243347, 0.07409969766740687, 0.024534092299290933, 0.057216654386138543, 0.07765246991766617, 0.04321841704950202, 0.037654951520380564, 0.03153003643092234, 0.05263399638351984, 0.024755853446549736, 0.07728826836682856, 0.05980031535727903, 0.071205343992915, 0.015120083535293816, 0.015152079377003247, 0.032640864519635215, 0.021418081378214993, 0.0028816494977945695, 0.026324666432628874, 0.030361305980477482, 0.08231306084780954, 0.03061127987166401, 0.004384173389553325, 0.007667762183700688, 0.01460370274799061, 0.011629376167547889, 0.014721086390636628, 0.008636776055936934, 0.02974623625050299, 0.04110360787308309, 0.011872706909343833, 0.009323150406999048, 0.04133584814553615, 0.06681548111373559, 0.08200918106012978, 0.023368328584183473, 0.0017778447931959818, 0.008794512123131426, 0.04961939252098091, 0.04824489420570899, 0.060363468146533705, 0.006165337090351386, 0.0333442646660842, 0.01436747992556775, 0.02216827208030736, 0.07759950283798389, 0.03170596624840982, 0.013722715939366026, 0.07824280386557803, 0.04571050812955946, 0.046059150554356165, 0.017795339445001446, 0.08436951495241374, 0.03957887660362758, 0.04669926034694072, 0.04722693105577491, 0.05662807932822034, 0.07999411653145216, 0.05170000724319834, 0.06284413015237078, 0.08848458281136118, 0.07940876981592737, 0.0735060685838107, 0.09231525225914083, 0.11325600280542858, 0.04240904934704304, 0.0627369194990024, 0.07551745206001215, 0.16799192468170077, 0.09087343743885867, 0.07820522150723264, 0.13486687559634447, 0.121131243504351, 0.0651242230378557, 0.10289499783539213, 0.06746186947566457, 0.11941911623580381, 0.13574075448559597, 0.09132638500886969, 0.07917649243609048, 0.06699428675347008, 0.009159928013104945, 0.23396358388708904, 0.10722090242779814, 0.1352670564665459, 0.07494963487260975, 0.03793141266214661, 0.03516184369800612, 0.026438389431859832, 0.0452751197735779, 0.02061435214272933, 0.062419280293397605, 0.041812744821072556, 0.024548887013224885, 0.009770280466909753, 0.020350689337647054, 0.021766360150650144, 0.05378637360990979, 0.032992572014336474, 0.018527024694776628, 0.031137440309976228, 0.013515919272322208, 0.010789372608996928, 0.06648327354923822, 0.056084663956426084, 0.07312826346606016, 0.013564107848651474, 0.13202750764321536, 0.039848291053203866, 0.01787253208021866, 0.02403446920652641, 0.02434277776046656, 0.0347426044754684, 0.07103673546225764, 0.06769204657757655, 0.012354442387731979, 0.010862337785511045, 0.0469571900612209, 0.0661889452021569, 0.012700961342488881, 0.05178609637368936, 0.04470329869945999, 0.04957333112542983, 0.02931424507551128, 0.03709246295329649, 0.058983797061955556, 0.025826549899647944, 0.043899111187784, 0.026749802018457558, 0.04592569013766479, 0.0058216164961777395, 0.044761427416233346, 0.0588414568483131, 0.0364438407268608, 0.0476029104902409, 0.05757910075772088, 0.018904369680967648, 0.06285693219979294, 0.023994183575268835, 0.033511392612126656, 0.023297707666642964, 0.010715726511989487, 0.010078125178552, 0.020227719178365078, 0.037309062463464215, 0.0063955744917620905, 0.06886877366923727, 0.014808141240791883, 0.031398498176713474, 0.05244441104878206, 0.029623440495925024, 0.025877351763483603, 0.011641101173154311, 0.025460270335315727, 0.05074594671896193, 0.04132844893319998, 0.05714370126952417, 0.12566734658321366, 0.08671152521856129, 0.16284179087961093, 0.17360753350658342, 0.27293599967379123, 0.12712441995972767, 0.12580124486703426, 0.12219597309012897, 0.11158291992614977, 0.09329982989584096, 0.16228366614086553, 0.17274747340707108, 0.10036622610641643, 0.1173988492519129, 0.11457756743766367, 0.13671182503458112, 0.19695885392138734, 0.2089822993730195, 0.20261314348317683, 0.09559049096424133, 0.19273305020760745, 0.1554337766719982, 0.173400251660496, 0.15643187623936683, 0.1361733375233598, 0.15028057037852705, 0.17041061364579946, 0.1435072408639826, 0.1145703463407699, 0.10616926432703622, 0.19046316185267642, 0.27168494649231434, 0.18460432154824957, 0.1459311693906784, 0.09882474827463739, 0.09217484534019604, 0.21955589996650815, 0.0761388152022846, 0.046503812045557424, 0.29774014838039875, 0.16711329604731873, 0.16036649089073762, 0.18741965875960886, 0.12742653343593702, 0.17588724789675325, 0.11334270049701445, 0.1433200712199323, 0.11177604901604354, 0.12160206199041568, 0.08991579976282082, 0.08779327225056477, 0.22584125254070386, 0.17579064995516092, 0.19347568770172074, 0.12549077480798587, 0.14039160101674497, 0.15723257936770096, 0.20586985076079145, 0.18298197188414633, 0.20544670784147456, 0.17294341523665935, 0.11506774855661206, 0.15741103619802743, 0.1594943189411424, 0.149509196926374, 0.3331492905272171, 0.16599676455371082, 0.16226462263148278, 0.10371395037509501, 0.32709250459447503, 0.22188999893842265, 0.14028792298631743, 0.11360945063643157, 0.09227204442140646, 0.12422084138961509, 0.17479777510743588, 0.16958433610852808, 0.1357958366861567, 0.17003477521939203, 0.14380813721800223, 0.15327385975979269, 0.23220202216180041, 0.23025296424748376, 0.16979353269562125, 0.2877650602022186, 0.11653342342469841, 0.29278996400535107, 0.3031224705046043, 0.2403686597244814, 0.17256123886909336, 0.2946895355125889, 0.28618701675441116, 0.1522233200375922, 0.1624208892462775, 0.31257093069143593, 0.23846202297136188, 0.3326139645650983, 0.3653319604927674, 0.24005093146115541, 0.2841836039442569, 0.2493520308053121, 0.5536469165235758, 0.3170275274896994, 0.3176600154256448, 0.14781003497773781, 0.2586408401839435, 0.14595873275538906, 0.1556339635862969, 0.18487998488126323, 0.12908300705021247, 0.09428774719708599, 0.208938809519168, 0.2861223608488217, 0.32749204721767455, 0.1415546503267251, 0.15084112936165184, 0.19336233206558973, 0.13716886925976723, 0.13669606181792915, 0.12349012278718874, 0.11076499897171743, 0.20218125806422904, 0.09448374097701162, 0.2596240967977792, 0.1340497116325423, 0.12446977256331593, 0.14977647399064153, 0.12713365227682516, 0.10987894886056893, 0.11968648235779256, 0.15604178857756779, 0.13486208132235333, 0.26606210914906114, 0.12861901632277295, 0.13998632901348174, 0.1825481271953322, 0.17230255587492138, 0.20117753301747143, 0.16006989899324253, 0.15422437281813473, 0.07260904210852459, 0.13869623886421323, 0.09856717850198038, 0.15544311288977042, 0.11010262474883348, 0.11214362733880989, 0.19957982265623286, 0.09106515644816682, 0.1483815925894305, 0.08627569899545051, 0.107569333340507, 0.08602558038546704, 0.09514094985206611, 0.12188847162178718, 0.2554452116601169, 0.1708343651262112, 0.1483733844361268, 0.1954553072573617, 0.13966297527076676, 0.14808473351877183, 0.13047190674114972, 0.19452863198239356, 0.11846825436805375, 0.13191838224884123, 0.1079634360212367, 0.1143843492900487, 0.04713896800240036, 0.14869829668896273, 0.15191921760560945, 0.11040211844374426, 0.08062278982833959, 0.09186302457237616, 0.1257931554573588, 0.1561166564351879, 0.1465384688344784], [0.03595325513742864, 0.07200468156952411, 0.06582334099221043, 0.03295456292107701, 0.04667708126362413, 0.029929685879324097, 0.033103519381256774, 0.04587134266330395, 0.02883871209633071, 0.07339275005506352, 0.004368609625089448, 0.04976505384547636, 0.033998794388026, 0.025382235362485517, 0.0026724301824287977, 0.023496391731896438, 0.017219935652974527, 0.029044010552752297, 0.04125451989239082, 0.024302859492308926, 0.0714982177305501, 0.03236220662074629, 0.014989518422225956, 0.011534400746313622, 0.06340329389786348, 0.02117665331752505, 0.03835781360976398, 0.04201713229122106, 0.03673974613775499, 0.07440160334226675, 0.010801371281559113, 0.04370033064333256, 0.05074489657999948, 0.026098057205672376, 0.047602294507669285, 0.129871717072092, 0.02622217212774558, 0.08270317819551565, 0.035777150915237144, 0.029264398726809304, 0.08082763000857085, 0.03425403010623995, 0.06501057796413079, 0.0449607794143958, 0.038647614856017753, 0.09763245834619738, 0.01885760695586214, 0.04050078729051165, 0.055137297604233027, 0.05749010240833741, 0.023148112959461287, 0.054774491291027516, 0.03522345679812133, 0.036412002591532655, 0.021200194241828285, 0.03283891033788677, 0.05127571399498265, 0.045024299834039994, 0.023010515069472603, 0.043855840267497115, 0.09364765224745497, 0.028465961004258133, 0.027020238776458427, 0.05168013994989451, 0.08583700066083111, 0.08329133022925816, 0.024228141919593327, 0.03318319264508318, 0.007360979670920642, 0.06680253805825487, 0.09022145328344777, 0.08431159032625146, 0.01710736298264237, 0.0150662843225291, 0.02484796139469836, 0.03529172325215768, 0.06219308852450922, 0.07653035005205311, 0.023815485546947457, 0.08688535846886225, 0.029129236936569214, 0.052837934854323976, 0.0976166951295454, 0.09296479474869557, 0.0604747272154782, 0.03969349018007051, 0.05575486837187782, 0.11516528902575374, 0.08021099434699863, 0.1506289790268056, 0.018693406782404054, 0.02250773413834395, 0.032794455692055635, 0.02550477878685342, 0.03284901467850432, 0.024942219715740066, 0.14464015897829086, 0.04405751147714909, 0.10586892458377406, 0.05653270964103285, 0.016225938306888565, 0.07279458644916303, 0.017526338742754888, 0.11204735594219528, 0.0481991445121821, 0.009533432385069318, 0.008834752297843806, 0.020650207152357325, 0.04846989853831474, 0.062247269015642814, 0.0707457319367677, 0.016021029477997217, 0.03671211969049182, 0.05431810757727362, 0.025322214169136714, 0.02035405868809903, 0.04124025581404567, 0.044840469854534604, 0.025257970155507792, 0.025320963650301564, 0.06665838329354301, 0.009820846698858077, 0.07291952701052651, 0.07168558775447309, 0.04680575853853952, 0.05271787020319607, 0.0264553716260707, 0.046577121393056586, 0.00546598072105553, 0.023085431166691706, 0.020821068101213314, 0.060728846001438797, 0.03315099085739348, 0.08284599709440954, 0.03981803369242698, 0.024187793205783237, 0.08439569050096907, 0.06707121778163128, 0.019439057396084536, 0.06289978380664252, 0.09653510394855402, 0.025027670599229168, 0.04096146432857495, 0.018290238767804112, 0.007305957769858651, 0.060780736966989934, 0.02826634739903966, 0.015006022858869983, 0.05283502192469314, 0.06727883359417319, 0.021587420924333856, 0.030568036781914998, 0.05567993001022842, 0.07509706250857562, 0.024461339562549256, 0.02405387451290153, 0.021949067631794605, 0.019162330936524086, 0.012811713895644061, 0.030200143046386074, 0.03353482963575516, 0.019708980216819327, 0.04364391257695388, 0.04379326979687903, 0.06990460402448662, 0.009822363463172223, 0.0501540802360978, 0.05168869691260625, 0.014929589069652138, 0.04780229588504881, 0.039827507207519375, 0.004240505659254268, 0.10092239157529548, 0.025274531180912163, 0.05006501138268504, 0.037691353863920085, 0.012037387623422546, 0.06861879606731236, 0.038468274869956076, 0.04288170464860741, 0.06675451368209906, 0.002114075145982497, 0.023105684376787394, 0.04133585185627453, 0.007534392216257402, 0.05110245219839271, 0.03228272631531581, 0.037893741246080026, 0.03977746790042147, 0.03973911741923075, 0.05087109137093648, 0.09952300533768721, 0.02183010506996652, 0.05509324742888566, 0.03803107938438188, 0.04031473086797632, 0.029439886966429185, 0.0373337203200208, 0.015169523558142828, 0.03563350081094541, 0.012237915925652487, 0.013368638210522477, 0.031210649467539042, 0.08098105419776402, 0.04115804811590351, 0.13460822228807956, 0.04964402069163043, 0.002070181981252972, 0.013537740269384813, 0.02428021100058686, 0.09484835813054815, 0.07953871245263144, 0.031942381101544015, 0.03548598040651996, 0.03703817485074978, 0.04743851735838689, 0.032230479118879884, 0.05704282484657597, 0.025486113772785757, 0.05168222538486589, 0.05963053052255418, 0.04215597698930651, 0.016709365881979465, 0.0603864858567249, 0.05085763994429726, 0.018738625840342138, 0.045802931490470655, 0.06820213951868936, 0.09164091461570933, 0.057873354890034534, 0.041849444023682736, 0.02923508389358176, 0.033030625636456534, 0.015228475131152663, 0.029410143542918377, 0.01373220058667357, 0.01935257121658651, 0.044049722637282684, 0.048801556913531385, 0.0997181011189241, 0.055157769747893326, 0.058793792413780466, 0.01739146639010869, 0.015727100035292096, 0.05528000147023704, 0.04817896922759246, 0.037475370336323977, 0.017597519981791265, 0.062215675789047964, 0.03531009882863145, 0.032424602686660364, 0.057229875746998005, 0.039995614788495004, 0.03558809250534978, 0.025147128544631414, 0.07952397339977324, 0.04020576503535267, 0.07588621039758436, 0.17157017486169934, 0.02354967607971048, 0.04351591436716262, 0.04496198540437035, 0.009576223692420172, 0.05831673617649358, 0.05154272017534822, 0.12971255608135834, 0.0010900062079599593, 0.01337692150627845, 0.10694497192162089, 0.045413697298499756, 0.045529361013905145, 0.11816032987553626, 0.11126715093269013, 0.0692120540770702, 0.1691184751689434, 0.031730939517728984, 0.009661258973210352, 0.11692713276715949, 0.10815309186000377, 0.1478394091827795, 0.09726954071084037, 0.06609692631172948, 0.12014178995741531, 0.06775731104426086, 0.031538181501673535, 0.07003339633229189, 0.0843450018146541, 0.01764286520483438, 0.05510003808012698, 0.05478656974446494, 0.09429513898794539, 0.0506703960854793, 0.006135897483545705, 0.038708025676896796, 0.0778233642631676, 0.05714749364415184, 0.0705846116761677, 0.028697752277366817, 0.027119039041281212, 0.02550835779402405, 0.024698830529814586, 0.009838866044447059, 0.060695827851304784, 0.02295772239449434, 0.047274261523853056, 0.006761038157492294, 0.05076452638604678, 0.08367211135919206, 0.044270826983847655, 0.0748711230698973, 0.026141114758502226, 0.006693569048366044, 0.012237773062224733, 0.0518906612705905, 0.029540268005803227, 0.06147690488433, 0.10602288311929442, 0.03624721612141002, 0.052367209136718884, 0.02472462016157806, 0.038331619507516734, 0.05360397226468194, 0.037791343420394696, 0.01763723044859944, 0.02966608986753272, 0.05460229447635356, 0.0493060948792845, 0.015662982186768204, 0.03652412255178206, 0.01990938420931343, 0.048691826668800786, 0.03749356037587859, 0.06433753907913342, 0.07414821928250603, 0.048926067029242404, 0.027049421878473368, 0.025621848872106057, 0.043945866491412744, 0.056906340178102255, 0.05145740287844092, 0.018478350939403754, 0.0702289745095186, 0.02446086273266701, 0.037259464734233916, 0.025800704606808722, 0.06847904223832302, 0.09464721384574659, 0.09546926114126109, 0.06014614504238125, 0.038821336784167215, 0.0451653895288473, 0.0406310008111177, 0.07825731285265647, 0.200570946035441, 0.1484076419728808, 0.12652365141548216, 0.16768198896897957, 0.12465786247048527, 0.08886844385415316, 0.1300734476535581, 0.07753901780233718, 0.2001340882270597, 0.12861374707426876, 0.11538182545336895, 0.12314796302234754, 0.13845882582245395, 0.1346865633968264, 0.13538731407606974, 0.08085644760285504, 0.1713896548608318, 0.10968751186737791, 0.1131820106820669, 0.07967046592966653, 0.10900550783844665, 0.06383785104844719, 0.13071156106889248, 0.1358548819553107, 0.09823090396821499, 0.08662663836730644, 0.2342362341005355, 0.12918172753416002, 0.24121021066093817, 0.13533310760976747, 0.06603045214433223, 0.1298280491027981, 0.12411745279678144, 0.23285028815735132, 0.20039140566950664, 0.16474688396556303, 0.28111152816563845, 0.1158704629051499, 0.17049652466084808, 0.13034966017585248, 0.13001086976146325, 0.1387378733488731, 0.11998915244475938, 0.20224116422468796, 0.12100587991881184, 0.13135791232343763, 0.1184926116548013, 0.19063280196860433, 0.1638404099503532, 0.2170280262362212, 0.16355698375264183, 0.15684053243603557, 0.11210964439669624, 0.12978966522496194, 0.10836962086614221, 0.16475515149068087, 0.10699828038923442, 0.2101741885417141, 0.1398691290523857, 0.20441567176021636, 0.077237089863047, 0.15889473783317953, 0.17747556266840547, 0.14324410498375073, 0.15164889773586765, 0.13402600743575022, 0.06656051627942361, 0.266661912901327, 0.21638627629727125, 0.16336637054337189, 0.19367908069398254, 0.14762307313503698, 0.09184979207930155, 0.08118001656839624, 0.14478866272838786, 0.12488960550399497, 0.1826748118037358, 0.21952177601633593, 0.2471243409672752, 0.11598191864322871, 0.30558334314264357, 0.3547703381627798, 0.1661234491621144, 0.20297292183386162, 0.21785213670227677, 0.17688438267214224, 0.1750113206799142, 0.20019197574583814, 0.1991150007233955, 0.15067770844325423, 0.21460322197526693, 0.09860202233539894, 0.23225458106026053, 0.10575113832601346, 0.1721334204194136, 0.3428894147509709, 0.3451859165215865, 0.25575934792868793, 0.12472820322727785, 0.09885777384624816, 0.30177743174135685, 0.3956125653348863, 0.32402333803474903, 0.25342084059957415, 0.1325077810906805, 0.23348544782493263, 0.08653692755615339, 0.19376706972252578, 0.25341650645714253, 0.2516058145556599, 0.13949242973467335, 0.11420030408771709, 0.2221841417485848, 0.39604888879694045, 0.2634914283407852, 0.1879374255076982, 0.10768559077405371, 0.17672863556072116, 0.15273402153979987, 0.2860764367505908, 0.1283634058199823, 0.146162185119465, 0.15508829208556563, 0.1064735374529846, 0.08100000864942558, 0.1561717237927951, 0.2385259367292747, 0.19260882952949032, 0.09162121059489436, 0.16411625139880925, 0.19914246018743142, 0.20434387639397755, 0.1304057813831605, 0.10444029772770591, 0.09516063160845079, 0.22915007342817262, 0.17838531697634608, 0.12840386771131307, 0.19823978596832603, 0.2037740554078482, 0.12789874715963379, 0.14157393132336438, 0.12852923129685223, 0.16154499171534553, 0.15690334781538695, 0.07413391067530029, 0.06964512693230063, 0.12795194430509582, 0.21286444418365136, 0.10202642530202866, 0.1548536992049776, 0.15030403708806261, 0.1191255819867365, 0.12843625503592193, 0.14318706351332366, 0.17914358410052955, 0.1579145685536787, 0.09749299395480193, 0.10184163795202039, 0.1394216882181354, 0.12319247703999281, 0.12393446886562742, 0.11795163794886321, 0.09778045743587427, 0.09396642693900503, 0.09845670982031152, 0.06095233635278419, 0.09601542245945893, 0.16668225667672232, 0.23725325736450031, 0.0967246262007393, 0.16508021217305213, 0.08622120309155434, 0.1875940486206673, 0.07895649017882533], [0.03748413881112356, 0.03840963036054745, 0.07803843865985982, 0.07045529244351201, 0.014158115427562734, 0.027386429283069447, 0.019404052145546302, 0.08314347956911661, 0.03268086256866809, 0.06472269145888276, 0.06865018149255775, 0.06610314550925978, 0.095787182362983, 0.053123680263524875, 0.062198350351536646, 0.03247388500312809, 0.03930608167138416, 0.03368186764419079, 0.018303391480003484, 0.012276151373953326, 0.05760468258813489, 0.04261495821992867, 0.047555368510074914, 0.03639501112047583, 0.11220773405511864, 0.009824502703850158, 0.01574654244905105, 0.023646580157219432, 0.04580325432471, 0.04147888226725627, 0.012677637496381067, 0.06081143961637281, 0.08329941963893361, 0.025661097351985518, 0.024282526501337998, 0.0304430572577985, 0.01932304116053274, 0.07306979707209393, 0.04548452787275892, 0.021099358637002297, 0.06812134190113284, 0.012859848666266771, 0.03475150282611139, 0.018438978149788454, 0.013743471026828047, 0.024490179421263747, 0.02319684237590991, 0.05772073593107052, 0.03579466931114439, 0.06271814316278324, 0.059192782136960886, 0.03789230147958733, 0.00709428612026386, 0.02006259688641876, 0.054582846496487036, 0.04812429891899228, 0.030932477675378323, 0.01602674772584578, 0.08304193150252104, 0.03102776758169057, 0.05335268106136937, 0.0772595324087888, 0.014725917772011599, 0.03968870332755614, 0.053549914227914996, 0.056964546820381656, 0.04117689866689034, 0.03960676651331596, 0.06625901878578588, 0.05218000980676152, 0.04435624447069131, 0.059432050547911786, 0.030485662100545596, 0.05302890800521709, 0.12105243484256789, 0.09914730791933835, 0.01447001504857326, 0.07457375191734172, 0.09134056002949364, 0.04302791516238358, 0.03094143725320464, 0.043203006352996454, 0.046415611504926346, 0.007522832802351331, 0.016942563524935395, 0.08857718799845316, 0.050438341349945404, 0.08012437087018043, 0.11214082202059217, 0.04902313623460941, 0.07335327522014268, 0.06317745835985988, 0.026277354518242646, 0.07297773365280591, 0.019612065007095225, 0.0308319370742538, 0.07928364371764474, 0.06672453091596253, 0.022051454325264785, 0.10049918186268769, 0.01361841172183631, 0.06036100792698562, 0.006720600849803304, 0.03508482361212373, 0.03337239206302911, 0.021900642495893408, 0.0543233137432253, 0.050862478747149, 0.089109938708134, 0.06173342822876293, 0.026239597755193245, 0.021604694411507808, 0.028491624470916577, 0.035424478628556244, 0.08071253032539971, 0.08664621622301638, 0.013176123247831129, 0.02817408359987894, 0.03614356777688954, 0.03723658803210128, 0.02812496455590008, 0.02342670406505931, 0.01857102663052501, 0.02213065261457814, 0.011131263345305342, 0.02464678185788216, 0.09045351544045843, 0.03935761269531213, 0.00842352919789846, 0.056041652787826024, 0.09184901282424107, 0.03608071157941595, 0.04934264194162097, 0.05493165961524937, 0.047444113151868805, 0.04174685323960148, 0.0224435847485438, 0.02317296006367542, 0.04025939262646716, 0.038486394405481406, 0.018821696285158396, 0.04281995054043364, 0.026026965024357196, 0.02685074337932747, 0.04395739204483107, 0.006524383961732383, 0.0341927138651954, 0.01765966557286447, 0.09876451556920074, 0.017640670303080697, 0.04123394384805579, 0.05073385713330936, 0.012350945944490377, 0.010675438097678125, 0.03423706461035181, 0.01346360992101836, 0.03612708467699122, 0.02416980169073213, 0.0284591963281855, 0.06670763963484205, 0.08111175382509828, 0.04546565134660341, 0.024495420839230064, 0.002905215933424188, 0.03721734414284583, 0.0660378513566684, 0.006274615088841529, 0.029474643597495742, 0.047264769455068745, 0.07888606778578833, 0.020703216905531008, 0.02708877425902756, 0.04581960012728814, 0.013149079386494122, 0.05975610562018119, 0.08976368917501532, 0.05484896209964063, 0.016559824980504345, 0.0262471324094804, 0.06071416260965634, 0.019220342765038367, 0.05769610404968262, 0.020723919114971068, 0.06374809570843354, 0.0564311801281292, 0.03843663711450063, 0.02542107380577363, 0.033777563876356, 0.04535788037173916, 0.0036750176559507963, 0.06552960636327043, 0.014572885065717855, 0.02793924395518843, 0.10449376204633154, 0.054334694577846676, 0.03053097207157407, 0.024214644108724315, 0.03722030160133727, 0.0423044621857116, 0.020488276095420588, 0.023796089517418295, 0.004161767501500435, 0.01114697090088157, 0.020300004362070467, 0.032273594188154675, 0.04490577513934113, 0.021148585292394273, 0.06066434223612305, 0.045143362585804425, 0.03099646379268961, 0.03643425960035529, 0.026059931224153843, 0.009751194284035591, 0.0019869014158757636, 0.05600211115961429, 0.04931321949698031, 0.021001660461479332, 0.026136854830838274, 0.035121760301990435, 0.0940372797776945, 0.04013567289803177, 0.04067904003022704, 0.032555265206610784, 0.03058600974327419, 0.02682995211216621, 0.059986123160342686, 0.012618155287782429, 0.017741210904205218, 0.013158838628442027, 0.01710861350147752, 0.019908705144189298, 0.031358897176687606, 0.012121451618440915, 0.047377301307278685, 0.0038530616666321293, 0.02062169383862056, 0.0446218294382561, 0.0194329124133219, 0.05169637443032116, 0.08201299569918774, 0.03924000084225554, 0.0727550893498119, 0.015740156268293504, 0.08962845502537675, 0.020182765438221395, 0.02815747619024478, 0.05374946660595015, 0.04715637507615611, 0.06641029074671678, 0.07378823313047178, 0.06018091837177053, 0.07231963420053944, 0.06426928375731222, 0.0701483475859277, 0.06114182891906239, 0.03471644005912822, 0.020509258465608582, 0.08600012472015806, 0.035391382552916184, 0.015425931869685883, 0.0367338571959408, 0.07392944899038412, 0.03485014909529127, 0.029798926880175713, 0.03176529353368096, 0.06446860235882923, 0.05082154930278193, 0.005976980937703047, 0.05207557478570379, 0.04841315392695833, 0.0339788306155242, 0.07600378143251874, 0.08715244999621063, 0.15814558428246528, 0.073954748804681, 0.03021857799467398, 0.011065679755120073, 0.016097329680633266, 0.054035186039982364, 0.0825845162034966, 0.04629055219993461, 0.07595199436764233, 0.043337687602615915, 0.07517281352193095, 0.0036902145211570314, 0.09973082153010182, 0.07200477804872207, 0.03863625257508829, 0.04869554853939917, 0.033404152272851206, 0.07148644726839848, 0.03158416868245695, 0.008594920782343252, 0.021759051851404365, 0.08765825332375243, 0.021657060351572, 0.018640161397343036, 0.07345606267335825, 0.026080707648361567, 0.030185704563336913, 0.059961116494378075, 0.021716892297263257, 0.01820110497646965, 0.03706680690811481, 0.022466574628197122, 0.022940892340557184, 0.017891369643621147, 0.02921044644608628, 0.02637553508975543, 0.056366301578236744, 0.04580835658998694, 0.03868902669637464, 0.03909082544851117, 0.09915821006870829, 0.04888141942501534, 0.04996232040866744, 0.06859376342617907, 0.05920675306697376, 0.019034247379750013, 0.04477763592149131, 0.05676979984855279, 0.0646892651275266, 0.08693737559951842, 0.031625892224838026, 0.08023057220270857, 0.026381629977549892, 0.06137510448752437, 0.04465949343284592, 0.036697061514132656, 0.02418567437416641, 0.07044977086479776, 0.05019212643674109, 0.03754306162591092, 0.04870499607932288, 0.02167068432754604, 0.05886588834982831, 0.010418005622341298, 0.026153944636462256, 0.04739017014799174, 0.02917949517723173, 0.07045265039778315, 0.015774953717482276, 0.005827260993100936, 0.02166593087167712, 0.06830758386058733, 0.027235237103013787, 0.03731314056494739, 0.041596197261242196, 0.05181491025723517, 0.05936834459134843, 0.07429807374137454, 0.03605649158998858, 0.1702491074684076, 0.19210063648642972, 0.21183826174819842, 0.1916227675974369, 0.06866391122457571, 0.1263986885896884, 0.1371949928579852, 0.22358215501299128, 0.15752937906654552, 0.13154107437003404, 0.26515740144532174, 0.13940295641077682, 0.2546122547937557, 0.07537859622971155, 0.15338927856646478, 0.08620342865469866, 0.07286792548256926, 0.2676597749814391, 0.1356968193431385, 0.08969577524112538, 0.1101367041701451, 0.18706939474213868, 0.17104468977777287, 0.1434600105858408, 0.13268472393974662, 0.12379599895211868, 0.07589442597236484, 0.16256882896414027, 0.19818764267256483, 0.1665965683059767, 0.09251126830349676, 0.1763408337137662, 0.19513674778863788, 0.1114205305930227, 0.16699251893442124, 0.12270064835320227, 0.12366937371552922, 0.18237367796245962, 0.18681964720599353, 0.13577971723861992, 0.1447251794161275, 0.11099143564933911, 0.07955475026392378, 0.3431243490194902, 0.08365746136405505, 0.16062284354120493, 0.21927090041572228, 0.1749894124804996, 0.12045264593325555, 0.13666495098732412, 0.103449166927021, 0.10559445610851981, 0.12048870688886382, 0.2286589497816749, 0.21947068657027557, 0.18020994641119614, 0.10209232801571488, 0.11188092932570726, 0.18537376541644335, 0.11433898180257529, 0.16437597339972854, 0.12624188762856647, 0.1615711153135635, 0.22662493080133572, 0.08980021768365987, 0.20410631492268294, 0.07485195339540951, 0.20873792498605326, 0.15792108461027965, 0.08861605427227914, 0.15318852761993185, 0.14586192701244727, 0.1397487972280942, 0.22625578654697165, 0.20713222911581397, 0.1859053212683648, 0.16365145915187895, 0.1692363282199949, 0.1156708993948996, 0.18166998837841675, 0.16667397430865094, 0.17559092317242175, 0.15489775309106335, 0.13040827499935403, 0.18514478317229077, 0.2337772454484366, 0.15133272798266262, 0.17810052522690967, 0.1750250207260251, 0.22995821287622675, 0.17993704386753961, 0.18259731674334034, 0.18352927610976622, 0.11019243946066126, 0.1020868138584774, 0.15576897509163246, 0.30353451089467853, 0.2801771939266473, 0.2722637919941917, 0.17553386685904115, 0.08485851605655625, 0.19421933451667428, 0.16631415142910555, 0.17271058866754174, 0.12347609619610012, 0.1662477885838598, 0.13828776078298688, 0.21801239607157186, 0.23262562521267682, 0.23211443389300257, 0.22386026743333787, 0.12437402067007497, 0.08992946270154789, 0.23694541450822726, 0.2699593344004825, 0.16778306948253885, 0.08513835025951266, 0.13934738439274952, 0.15827393130166456, 0.14862201875075698, 0.26802823645994067, 0.19512646162183955, 0.15277672471711412, 0.10477459814865142, 0.14417569327633828, 0.16135008889250457, 0.12809017673134804, 0.1469445275142789, 0.10001259273849428, 0.12713834265014157, 0.09310052613727748, 0.13781542831566185, 0.17438267706893384, 0.16826130944537, 0.10301892907591537, 0.1125946750107687, 0.15880869323154911, 0.23427991691278294, 0.13428506150376052, 0.1791010590386577, 0.16319160960847512, 0.2038896968588233, 0.12794948037480935, 0.17013316915836185, 0.1319233694812283, 0.09429254147107713, 0.1437562462524511, 0.11480859058792703, 0.14765443629585207, 0.08307547657750547, 0.1270382120856084, 0.14391049422556534, 0.11655812952085398, 0.09154643921647221, 0.18444792134687304, 0.17407044069841504, 0.12423441527062096, 0.19097619369858876, 0.07943298609461635, 0.14380788488779217, 0.1468867587391287, 0.19400169228902087, 0.18522027443395928, 0.0866291913553141, 0.08892334051779471, 0.12380091939121485, 0.1431470617535524, 0.1255504137952812, 0.24709958292078227, 0.1419088477268815, 0.1081603871716652, 0.10053073798189871, 0.19136599934427068, 0.1278592797461897, 0.19313155382405967, 0.18821268808096647], [0.0045128965848562075, 0.030028630862943828, 0.022181187305250205, 0.04547892836853862, 0.015276775029633427, 0.06028206196788233, 0.04378795230877586, 0.0487197982147336, 0.02760605675575789, 0.057742584758671, 0.018345202224736568, 0.03509670539642684, 0.07362540593021549, 0.039654545980738476, 0.010594995783321792, 0.030572727155231405, 0.05042198441515211, 0.021015633246861398, 0.04456856178876478, 0.018586374244478066, 0.023213420099637005, 0.025527423567837104, 0.060176035040058196, 0.06998676719376817, 0.05145412258571014, 0.021522534952964634, 0.05955678701866418, 0.042081046049133874, 0.0337347605091054, 0.04962226092175115, 0.019366597807675134, 0.03263617785705719, 0.03665908210678026, 0.027681466381181963, 0.09075450827367604, 0.04969925132172648, 0.01667920314503135, 0.0320983916753903, 0.037848581559956074, 0.06123928033048287, 0.010456515665282495, 0.017579778941581026, 0.07209399162093177, 0.024116424574458506, 0.0873608079564292, 0.03600117561290972, 0.034983397999894805, 0.05699596935301088, 0.020221474005666096, 0.03890904750733171, 0.03466376612777822, 0.08036206592805684, 0.012372978453640826, 0.05071937041066121, 0.05727492040023208, 0.03444865833444055, 0.05353120097424835, 0.021523280811379664, 0.05533139890758321, 0.06293496160651557, 0.028136117180110887, 0.03997185864136554, 0.028279976941121276, 0.03139771521091461, 0.01342737548839068, 0.055911543167894706, 0.008440370384050766, 0.04988114429579582, 0.05135218860232271, 0.09907396146445535, 0.04951934730343055, 0.00960403289354872, 0.07924315214040689, 0.018810113215295132, 0.050969797011930496, 0.008003362290764926, 0.049859918872243725, 0.06586832998436876, 0.07864726692787372, 0.023034879777696915, 0.006468383353421814, 0.05909603576583322, 0.053370488894870505, 0.030207844683900476, 0.03663443167170044, 0.0741010409547016, 0.0435397781257052, 0.02651706265169196, 0.0436945233377628, 0.02667320310138166, 0.01942605867952807, 0.08373082266189158, 0.06025856186170131, 0.008328568619617727, 0.033570100204087794, 0.06490223182481714, 0.05412287078797817, 0.0838480523088947, 0.0314798932231497, 0.049425836696173064, 0.04079075180925429, 0.026702107898017857, 0.04935833465424366, 0.01729040071950294, 0.05411634730990045, 0.030223338872019667, 0.0760471673856955, 0.03669685000204481, 0.11193652360816486, 0.046317573796841316, 0.010247098289255518, 0.015263139921444235, 0.025347452756250277, 0.02818803783156909, 0.05551942202146165, 0.06443938400479965, 0.07071079162415117, 0.019590665178839117, 0.088993436365854, 0.018599903596623335, 0.0202092118706787, 0.03690403907967266, 0.019158050599799026, 0.025006033283716533, 0.027195302136533428, 0.073904156597564, 0.043320621916791424, 0.041120009336736985, 0.058500035520410165, 0.04217569585307501, 0.06586098272236995, 0.04113039940421004, 0.02135642931534676, 0.04548792690911796, 0.061075124685885385, 0.008130227797664702, 0.06998636643402278, 0.07708955090492964, 0.04234244530380238, 0.036985111291869543, 0.054492360141011886, 0.015001018928160192, 0.020294310234021395, 0.033641836198512465, 0.029236456866783556, 0.027602813570410945, 0.054980708155198954, 0.04553905346256215, 0.0312833836505888, 0.06387770437868312, 0.03755069090402685, 0.033623991257627495, 0.018176727280660998, 0.03372527215105947, 0.08125382315483876, 0.015818528918316588, 0.023804741103958804, 0.020038757247675676, 0.01407539843057748, 0.06661263731075451, 0.03734530524525326, 0.009262102266802685, 0.05323702847817913, 0.031071580269781407, 0.03640311166236643, 0.048110339121194556, 0.045284478255780414, 0.0512597689521499, 0.117982978845248, 0.05719219690945465, 0.031341245194198564, 0.008742448608245468, 0.04658772668335587, 0.045092098735040054, 0.041579176104278304, 0.11206055874936283, 0.03162446359056048, 0.05205265726544894, 0.033962481102207676, 0.022819718178652693, 0.010858843197638635, 0.055947611544979736, 0.026069709019793663, 0.0499202109494945, 0.11690289422404021, 0.014433986561925849, 0.018692525482038036, 0.024881584395188838, 0.06293663886026479, 0.06633232813328505, 0.005950245067651849, 0.022249169887800235, 0.0527546918601729, 0.055482748794020154, 0.07213401564513333, 0.02636304659972666, 0.05163339577848092, 0.09938504750607535, 0.06416055912268348, 0.04070142320415471, 0.03353197607793845, 0.02391307982179569, 0.029806561724399216, 0.045791684242431074, 0.05762556291301735, 0.023662382336624432, 0.0138801903995045, 0.07184257425251417, 0.06250793725484982, 0.038957083015702665, 0.039019579271553084, 0.013871666833438212, 0.010418278361612465, 0.021807144876220264, 0.05854108741914388, 0.05586609404417686, 0.007907309827714926, 0.06502721691504121, 0.030080909600656014, 0.038703160898876376, 0.011856105993501842, 0.050389411553624086, 0.08077077407506295, 0.02996411782078212, 0.014874021690047812, 0.04751088417833671, 0.04035923004266806, 0.06904205773025751, 0.08563783048884943, 0.08837512345053256, 0.07460550841642544, 0.025923461398633663, 0.047706128389108926, 0.035586196318035945, 0.06238882997422479, 0.03829141736787278, 0.07130856189178303, 0.015585119763272814, 0.06355766061460599, 0.04743614248582162, 0.06703123086481355, 0.05363075637433212, 0.042788939899764955, 0.04902242748357821, 0.08887862612027675, 0.03372828527062666, 0.047732786333654076, 0.012291638140595751, 0.041098182773566805, 0.027171371584699955, 0.0056040368872345425, 0.038737793220207095, 0.07896293202065863, 0.025827882054727525, 0.10937156475847587, 0.06017246159899514, 0.04014092359284405, 0.06335352547466755, 0.009055329719558358, 0.08250623446656391, 0.04929757873469498, 0.037109981349203736, 0.10225195655948482, 0.024631591950310394, 0.08915664206142537, 0.030632753914687783, 0.039486460664193146, 0.03786432993365452, 0.0877423831843771, 0.008761573753872653, 0.060723988644895144, 0.010356660623074276, 0.06094720811233856, 0.05772973447164986, 0.040304760113940574, 0.008070360599958804, 0.07872454676544294, 0.0541713775601238, 0.05047316291893367, 0.06173232613946311, 0.03631248058809433, 0.016516791547473986, 0.024327036808244884, 0.029912321479059756, 0.019289099036541302, 0.05125429932377301, 0.07595928967930377, 0.038634282173006795, 0.005753387613367522, 0.06626786518609151, 0.032360202822019346, 0.03238194032746833, 0.07414139152388088, 0.008413442483288236, 0.00864809102495201, 0.07490164760383777, 0.012207513846078655, 0.07831517068552785, 0.04604871224728413, 0.017961196463147644, 0.01799113098968519, 0.0072438339793734485, 0.04601957924023736, 0.04984282721125055, 0.06833152554463595, 0.011685999252222246, 0.023365246815956198, 0.05020288757805247, 0.008576151867600856, 0.06285761497565545, 0.020846867009822745, 0.011608885470195673, 0.02421694662189111, 0.015746779936307576, 0.060847734348499216, 0.05360547140298877, 0.03404931238037534, 0.012018851557513699, 0.012463327511795796, 0.025132164992101025, 0.02152209523046622, 0.07968103411258198, 0.0720288310549222, 0.041831862545222975, 0.008081420455710031, 0.07552894050604664, 0.07028246109257452, 0.017457677095080726, 0.022775100260332692, 0.022390916383301374, 0.0706429296405986, 0.017403112542524468, 0.008239780854637502, 0.046618488704552874, 0.017593777702131774, 0.05471586533531081, 0.04180663323495537, 0.027118695797980763, 0.058060420633410104, 0.032974218702293, 0.014176690456224605, 0.009408788682776503, 0.06715083538438194, 0.0579247968562413, 0.03919485599908512, 0.10661043401341885, 0.03209580900147557, 0.037339460832299665, 0.051221848916611634, 0.04103228005988058, 0.07080693685566075, 0.027149500492669176, 0.16514773276867345, 0.09664704208262265, 0.11357991315890104, 0.09729920435347594, 0.07378529422567226, 0.14324593066703528, 0.18644339317688718, 0.1296953234123066, 0.20704612514236942, 0.1885129461879842, 0.035964287162641995, 0.16949340817518532, 0.09430083868210204, 0.18677869549719617, 0.12926904862979427, 0.09915774993714876, 0.11995930326520465, 0.12519332201918587, 0.2723988034995273, 0.1369491490186192, 0.12354955397313461, 0.23572232545120642, 0.13450537546304986, 0.13257215498015285, 0.0844538006640505, 0.13311438291566446, 0.07823668114724569, 0.13841261970810592, 0.14127613714663312, 0.10108221307746135, 0.07299101067474112, 0.16052648308686912, 0.20923492644215003, 0.16405934351496398, 0.15678846335504204, 0.0729930515808519, 0.07912557368399575, 0.13234403362730518, 0.22648589685559273, 0.14777871634578332, 0.12685585155850276, 0.16914351523155347, 0.14683454122859985, 0.12205918043036945, 0.13858068647095934, 0.11041494275559671, 0.12743613682687283, 0.1249665959039703, 0.1444161491235718, 0.12500070501118898, 0.1450634651700966, 0.14219257078366354, 0.16764583153417334, 0.2391157957026735, 0.18981866596732289, 0.12506653351010755, 0.09386372854351066, 0.11420483118854463, 0.11262170402915217, 0.11006093089235947, 0.2180480636889115, 0.09664805140346289, 0.1125063668587245, 0.1372379038366489, 0.11638209951343015, 0.2034416771493852, 0.14079429034609348, 0.1068554021185264, 0.16544341924600303, 0.20900500909192488, 0.19694424845511094, 0.14752864226466045, 0.2781592943938449, 0.1282664664904587, 0.15082395606441423, 0.09695526343421079, 0.1792139100143686, 0.20319621922681108, 0.14757070719497278, 0.14143935026368126, 0.05089425751066301, 0.13317642646143213, 0.18974222475662827, 0.19932992669055238, 0.22376571781933308, 0.16531755100004375, 0.18830106302630156, 0.14482884260360152, 0.19835481885820627, 0.11211116579943337, 0.13814149831887335, 0.14587369747459888, 0.2289636607747525, 0.0775606810930185, 0.11371326967491768, 0.1771383307641372, 0.16054270643508062, 0.22261298436205834, 0.1801505300682038, 0.1695634372299537, 0.2729108853964135, 0.18563819263363257, 0.2247470003203489, 0.19466540979919955, 0.1423395605525002, 0.22697963286191225, 0.20327675709268078, 0.08234376349719241, 0.122627628443297, 0.22078617301303893, 0.19220661517465487, 0.13993590750033036, 0.07167350559029728, 0.17904042557347566, 0.31723782245535403, 0.1241188109270297, 0.1894837198778987, 0.1182706723921001, 0.18543931189924479, 0.19641542370663956, 0.11966248872340657, 0.1562385170836933, 0.19508455996401608, 0.15285248315194622, 0.1375700594508089, 0.15551182092167437, 0.16597844834905118, 0.12925435410579666, 0.19502119539538398, 0.2285296082845889, 0.12852271524025127, 0.18147510039852932, 0.1344063729629852, 0.15982175449607894, 0.09382829841342755, 0.11363433484802954, 0.16590231884038076, 0.10475841190782376, 0.15713770320871845, 0.13030422589508817, 0.11911790817975998, 0.062374513945542276, 0.11542506297701038, 0.18418401363305748, 0.21009424439398572, 0.11897280346602201, 0.11275181735982187, 0.2016250035376288, 0.08734516348340549, 0.13604343199403957, 0.15382681915070862, 0.11844354085042141, 0.12686156609561294, 0.07257458419189788, 0.18826833431376144, 0.16210574365686625, 0.10322252244804986, 0.21365919528761879, 0.05834840361785609, 0.1941706199431792, 0.13945036480436102, 0.09842212573857978, 0.1431832934031263, 0.10098036073031835, 0.2247044604155235, 0.11343039266648702, 0.13859327329555526, 0.11878653924213722, 0.18806376872817054, 0.26066895166877657, 0.09807448892388493, 0.1146945076470729, 0.241677941812668, 0.0919646691181697, 0.12906627904158086, 0.1780066583887674], [0.029151544040360022, 0.013861087518307613, 0.017486516953795217, 0.04129825836571399, 0.009466081555729033, 0.03469884744845331, 0.08812569503788836, 0.06632159667788073, 0.04273710088455118, 0.029317098633327987, 0.005976326920063002, 0.031238420633599162, 0.02792764047626406, 0.04285510236513801, 0.07103018229827285, 0.016149139009939972, 0.024005141385714523, 0.09409687423612922, 0.03223244952096138, 0.0379342476662714, 0.02056427016214002, 0.04779649600095581, 0.04365456239611376, 0.03267723346652929, 0.050748455178109, 0.02859697604435496, 0.01709968546492746, 0.045870696994825266, 0.039278737240238115, 0.02602279229904525, 0.06175892842293251, 0.050952709061675705, 0.056795875207171775, 0.07126551732653752, 0.08007452081074007, 0.07850419569876976, 0.033903413568623364, 0.06313844365649857, 0.012892242484667804, 0.048492010828340426, 0.05000300123356283, 0.025915340447681956, 0.03890203050104901, 0.02675805655599106, 0.029045591327303555, 0.016256199378403835, 0.07054593093926087, 0.07130022757337429, 0.020153285477135796, 0.018320718772883993, 0.03615044006437529, 0.01440102963897516, 0.05693673483619932, 0.044329879674478434, 0.05157957893970888, 0.02340044688025955, 0.02106176885718014, 0.012698070677288342, 0.058230561699019745, 0.026506869253353216, 0.03574197311536409, 0.035534349881345406, 0.015833536999707576, 0.07037658768240362, 0.013424905064312043, 0.022769298520870507, 0.06887657364131883, 0.024879192824300844, 0.017284793793805875, 0.02043363176198909, 0.024275468676933087, 0.10061222579679452, 0.01841330169554567, 0.053751611412735656, 0.06042663604603149, 0.060793739394284785, 0.031518926480202936, 0.05010212247725576, 0.07259893405716866, 0.034427076680003665, 0.023482376273022965, 0.04403755512612406, 0.050918132401420735, 0.031713439675513655, 0.01948273835296277, 0.05358043134037871, 0.011341710451233666, 0.033446139277657494, 0.07702418995904736, 0.059696314492612146, 0.035028208876610734, 0.0866271801351104, 0.058169946787529625, 0.04517064764513634, 0.035929710502387024, 0.03802986968366895, 0.12131033858167939, 0.13264390581753105, 0.09243214793968946, 0.04673776296840515, 0.01556635270389961, 0.028647358594753314, 0.005469774951052386, 0.02454539335303707, 0.01329667771642562, 0.01318845032074023, 0.01298508886975469, 0.11015063428203575, 0.013461535618262133, 0.015162161453190492, 0.015581525913148653, 0.04238266599713825, 0.03864507671096362, 0.05460005319037009, 0.0487496770801954, 0.054528907203348354, 0.015257512586686062, 0.04410503119288478, 0.02831121950293891, 0.03786923552979715, 0.10468015985679813, 0.029785902188450564, 0.053577982253045775, 0.0292344994522864, 0.0904437636199873, 0.04714554343081545, 0.03732655859494116, 0.03557635172910523, 0.12031845821184106, 0.05132877755386289, 0.017005707304633688, 0.055330055620288476, 0.05665910852258094, 0.051031558541581035, 0.053150508902035654, 0.022578535026696045, 0.0728118784900289, 0.04093613853910938, 0.025708765497256536, 0.01889271425170591, 0.025164949365716893, 0.05854275354067795, 0.027360743551980704, 0.05293342699587811, 0.010431081336719217, 0.024234826814790722, 0.039555899711558595, 0.05727688338083681, 0.01851026143413037, 0.03064595857722452, 0.04561233312415425, 0.047135242421063595, 0.04871927871135995, 0.1362848377902992, 0.046026158379390836, 0.05844039282237645, 0.08957509460742585, 0.013839548537362134, 0.02956190346594667, 0.06213383545400575, 0.02044979944912484, 0.03394552673853468, 0.03351861741975881, 0.04801363356818911, 0.035059482979704626, 0.029331223558983766, 0.029624121416418348, 0.04467911952815484, 0.04666271328460425, 0.04409519773616921, 0.06198716851940844, 0.028147188168077264, 0.025532414510962553, 0.030954617795941886, 0.041950153463403694, 0.0569907854514895, 0.041201808853656985, 0.022645252247457393, 0.036646614025812596, 0.07708378441748209, 0.010065019778267015, 0.010066364920930937, 0.04066680201503914, 0.05517603029147722, 0.017329265137959737, 0.042641315594664775, 0.03020643831405323, 0.015316356548282783, 0.030126460769679397, 0.05849433582625352, 0.049876524426508695, 0.03592219996789936, 0.0411812884703977, 0.06636849298956804, 0.026770611839310732, 0.04844718881940935, 0.022910185980435926, 0.08020031484193169, 0.028568854213517625, 0.03283875819761306, 0.0730152269534301, 0.08590967918280512, 0.022049871695344336, 0.05783326778328046, 0.05501601212017704, 0.013079483560431981, 0.020660469199356157, 0.026662918789952528, 0.02636825833178591, 0.0545326364954235, 0.059276793253957294, 0.00428408735388075, 0.10180956975091249, 0.021790450264234096, 0.058135392391704954, 0.017332892384729348, 0.05274357077723835, 0.005542885774048045, 0.03480224717350211, 0.010531565349083394, 0.057378205092391, 0.03801410646701697, 0.08810050654574297, 0.04471388543606736, 0.03158596096909605, 0.025571585065335967, 0.019931001115764957, 0.02099217766954098, 0.06880416971398517, 0.010262808627885533, 0.024626908998470753, 0.05349630147975404, 0.032852168806130067, 0.056328570790356025, 0.0601969710260164, 0.020242602950020228, 0.05328417712007649, 0.03572916364646517, 0.033326965203741565, 0.01986412433325313, 0.034854260593419895, 0.014705192370456643, 0.054655510175507516, 0.011326776584610343, 0.079666732926853, 0.07901785094873048, 0.07638192793820053, 0.060041917822672985, 0.03899999399436638, 0.06235830544028431, 0.043493701887200586, 0.004573610758598079, 0.004897550334135303, 0.007933016895549372, 0.06384624473867007, 0.03384620140423067, 0.010194061633228557, 0.02396659052465111, 0.07558287979918532, 0.03768626644159667, 0.03806675813393667, 0.01433081411960302, 0.01537365684271208, 0.06188657040183898, 0.06623400098760612, 0.020335519839136396, 0.052395889433682896, 0.053657533062505536, 0.024240237071353476, 0.07390998245682567, 0.04220107730361633, 0.012500839366111904, 0.11470051904325373, 0.1587048073997721, 0.039005830985843204, 0.061516079149441794, 0.016797462521935813, 0.05516827484825626, 0.040340015839319676, 0.06329191237455234, 0.016859999595908448, 0.04649151465855539, 0.03467980393907055, 0.059998401993652806, 0.05140828754520044, 0.03651452287158463, 0.08629001502413303, 0.030550774426956195, 0.026606179744703695, 0.026109957543667406, 0.10037185900728218, 0.020884299083263613, 0.05402050264819991, 0.022021642253093887, 0.0791025671060197, 0.014295766195573378, 0.04527087468886748, 0.046237781789386645, 0.009079106275748927, 0.02632946998346597, 0.11131567996926606, 0.06467180981417187, 0.026569627116259653, 0.012926725448778598, 0.07652602333109826, 0.041365062788827345, 0.05999362998409197, 0.032011452785809524, 0.020103329661651514, 0.02775175333226798, 0.05155891383765265, 0.024707587872399017, 0.009871854508674005, 0.028515111589513253, 0.04907778056804091, 0.020854162321484182, 0.017426011509087402, 0.03536979347700253, 0.028475430808612145, 0.0392371769703459, 0.06405355627066456, 0.051335378957446665, 0.09098757233005017, 0.01579587671585614, 0.073690982098924, 0.006953214051463874, 0.04547320269921329, 0.02302644898009021, 0.01708847161353333, 0.03261633653892204, 0.07196012302301824, 0.011676962676574476, 0.022355870314640924, 0.1036587568523828, 0.06004617032886017, 0.06394429728970863, 0.0019227573602620396, 0.040282005866174586, 0.03412754958844744, 0.01849237010901561, 0.0359913532884093, 0.06528734709718265, 0.009975073335226625, 0.011935600214201258, 0.0335710724175442, 0.04345774483226705, 0.034833513855119236, 0.05311332359269727, 0.05936444089456927, 0.024001256242627278, 0.023348079084826168, 0.0579627094703028, 0.13142627896741033, 0.11451497470261529, 0.0938968728587497, 0.15398394665680826, 0.07218713115435094, 0.09444389506825246, 0.14400961546925828, 0.22630323946941644, 0.12365185903036036, 0.13078053627396002, 0.14625145064201206, 0.11767623436753638, 0.09210877935402095, 0.11885020066983998, 0.13748067518463358, 0.08227939702919684, 0.17845944268628955, 0.17979377968003973, 0.09645688158343546, 0.13319082412635908, 0.09634232366806827, 0.1496825774665922, 0.13154482963727787, 0.13735238753724843, 0.20659797184634954, 0.19533859711373225, 0.08918561550672166, 0.2025147050153464, 0.18599764443933964, 0.136156297812704, 0.16009851620765403, 0.12022832437651232, 0.13676048023626208, 0.1547593277064152, 0.17623225750867277, 0.19128115702187642, 0.1653942742268555, 0.17568156908964738, 0.2676848595729098, 0.15456022432772443, 0.13076266535790637, 0.07227011810755357, 0.12102347624022514, 0.10802570221130736, 0.149682265764568, 0.17380084813339636, 0.1858303346671164, 0.20691016368800774, 0.09574992654961534, 0.22698079061228782, 0.1295146846678108, 0.21429263317259029, 0.2414061376475729, 0.10415706448839046, 0.12737011536955833, 0.1214574916230049, 0.10754838251159526, 0.19379040284547955, 0.09517491052974947, 0.1537492498755455, 0.25087663962040097, 0.10700026934500784, 0.08264481570222415, 0.10831418985617347, 0.09088428021641448, 0.17145296005764976, 0.14539156865794212, 0.25119341793470085, 0.1517449168022722, 0.17802021000534296, 0.18219053075881675, 0.16555627022171393, 0.1944241375895217, 0.20971537800505757, 0.1484538777731359, 0.13797452993458137, 0.09014898998429999, 0.1475759467575699, 0.24773118027951568, 0.11315332667436451, 0.09036039817146957, 0.19939560675993562, 0.2768935763742775, 0.10506088903639466, 0.12378704122966155, 0.26759318949189037, 0.07612810601131059, 0.3128767845919356, 0.13284958462463692, 0.23286704585189, 0.15896757220616564, 0.11913066569832154, 0.15285380417481065, 0.21091378323035315, 0.14799122291151434, 0.20222934923367575, 0.31883795221801847, 0.3969312133267522, 0.15061993966810405, 0.15648799744667485, 0.2127285421011038, 0.15032682102173567, 0.18846105522243306, 0.15386839426355436, 0.07460512992111035, 0.1318590104347095, 0.13461254158755764, 0.26793502271175385, 0.09079925977857783, 0.210631811642088, 0.13512484612874687, 0.15140493895160034, 0.11354626418324187, 0.07997013031854294, 0.26932705426588655, 0.11669973129755817, 0.11581904691411182, 0.18210013717180118, 0.18484177911886945, 0.06448192390962504, 0.13284649729030207, 0.10146129468921572, 0.19007381633855402, 0.11068987878388725, 0.19493528438033536, 0.1828284512157552, 0.16393040277762339, 0.11239916362683289, 0.1578186682309024, 0.14346490876050666, 0.13262843945994973, 0.17905307176988572, 0.14598381734685972, 0.2218185894889757, 0.1504745232523419, 0.21155222319066525, 0.20432029094081372, 0.13121181313181296, 0.12714264710666612, 0.14148079178994521, 0.07338359937421046, 0.18427773204166442, 0.15089552878635004, 0.16227219253778458, 0.12598823639564216, 0.18008433049544692, 0.17754811502527446, 0.09375694833579473, 0.15376893163193017, 0.049953744892263785, 0.14605099655454978, 0.1307855680352077, 0.16863462456967682, 0.18352685670834035, 0.16117540217237547, 0.1874597347341478, 0.16782983962912112, 0.3835641243495047, 0.1123837121122051, 0.15474564250325784, 0.08512627551681362, 0.11454371808213182, 0.08043392066610977, 0.21170681255171075, 0.08980306753073819, 0.14617080887546763, 0.18060061294818297, 0.1128327262995299, 0.07385421748040244, 0.08468239699141122, 0.11290762384305708, 0.20826983760343865, 0.1886086683953181, 0.09419530528248288, 0.149833025643602, 0.13487070507835597], [0.025196559290634468, 0.023966881817614194, 0.046908686999813654, 0.01899902505101636, 0.008714359246368986, 0.06536155444337055, 0.0411566565890098, 0.011639846943580778, 0.060841318481834605, 0.03396764645003714, 0.07291948248166591, 0.026631657674442977, 0.063083992281463, 0.04145023907767609, 0.037279053722159006, 0.052049321311642416, 0.051353350063436665, 0.04443396217538975, 0.04443057427124586, 0.04717040166724473, 0.0025418620543860015, 0.06989200235693716, 0.03548300068359822, 0.023105591608327813, 0.02650868565979181, 0.03493767057079822, 0.028320251440163702, 0.035443485030555166, 0.01908463178551756, 0.04825377771339845, 0.03303949430119246, 0.07233631025883369, 0.09998935609473847, 0.01936858861881774, 0.0293463763591717, 0.039536974945804104, 0.06097671590396203, 0.03245320876885671, 0.012262194359209388, 0.018497450109862257, 0.09155366031336598, 0.05998622335027903, 0.09831422488787211, 0.04154756803472992, 0.08113229647278786, 0.058304832127760164, 0.0142777904511604, 0.027196708506380673, 0.024316127237398177, 0.056647686869837344, 0.013479156987159513, 0.01883904213173082, 0.01626638349989662, 0.061647903130506165, 0.007922129589132965, 0.0707206992956344, 0.01943462120834738, 0.0504602755245287, 0.04623958149750251, 0.053052886796649545, 0.0789998983964324, 0.013457038203341654, 0.02853097685147077, 0.06881592533318326, 0.03326402365928516, 0.031343805603682995, 0.021603657260129694, 0.06312573808827437, 0.05514365780982189, 0.05774441044195555, 0.08184326652553864, 0.04337152211519424, 0.02451876880513737, 0.037641674498445354, 0.024861444362613838, 0.03556085568561684, 0.02975827574118739, 0.05393335966800805, 0.056487728070351295, 0.06633374563534744, 0.01438821738702245, 0.05357529196771793, 0.0788002458284609, 0.043638097849907354, 0.04356390534667298, 0.010038293185061775, 0.027727512933779508, 0.027630484546534717, 0.07849186862586066, 0.037924195275991224, 0.005910682566536707, 0.03602060132834595, 0.014625472722400445, 0.0420906457293313, 0.028057609088136815, 0.018415708109387197, 0.017981453383981716, 0.04037434759084135, 0.0697240098088514, 0.06808500635088421, 0.052788244356634095, 0.034913532217615284, 0.03457509432337247, 0.050982602770091034, 0.034396804476273246, 0.08016932275495492, 0.07607907973579131, 0.07928657520096749, 0.07238436432089657, 0.04093459858268034, 0.030102726886980236, 0.07700823378399946, 0.04791146580828354, 0.012700952065642923, 0.08989536101580597, 0.03350021215737797, 0.08729835622943938, 0.0572225507494295, 0.019552299854694866, 0.034055561263812706, 0.03540832949511241, 0.046634990358143114, 0.037161619984544814, 0.02610707058920525, 0.018337025612709112, 0.011736807609850075, 0.016795731462480035, 0.01857975614257157, 0.005353702126740245, 0.031316620734287426, 0.03082643775996985, 0.04015150661871303, 0.0535064689029241, 0.027439079094619956, 0.035832682115142234, 0.03646830933575984, 0.038637436300632544, 0.0022264073140831897, 0.09691132087027654, 0.0393182232073741, 0.06951359609956853, 0.03366635304701049, 0.027871441343449987, 0.054644240663037635, 0.04398256940476131, 0.030751132035220508, 0.03736661972652655, 0.04912776050332468, 0.026755557373689953, 0.022981278161751106, 0.04553037404548377, 0.016026994489948265, 0.02444132012897171, 0.034294380675419234, 0.06259858317207545, 0.02535422670916887, 0.012724072748824256, 0.051232799305580556, 0.026314478600397706, 0.08388223563088104, 0.0252747668127995, 0.03950141493987758, 0.06365736073348671, 0.0041026470898941625, 0.07538955775089562, 0.0263413925858913, 0.019235508552810643, 0.04787445861438755, 0.023686860222369432, 0.06029400312399957, 0.0479550076124724, 0.04686364976805635, 0.08096521676634438, 0.02938421290309634, 0.09733889441122301, 0.055760946561349556, 0.017030367016559467, 0.059748424391727895, 0.05870493878319394, 0.04993637863663025, 0.05000116070732474, 0.0543114059837535, 0.05121119538671337, 0.055755265420884825, 0.019831250901916064, 0.07515273100580089, 0.07546836641267873, 0.009798290975595592, 0.027924020650971215, 0.06064195906219538, 0.044929590658284724, 0.03608155020629056, 0.051448267040541396, 0.037434526238939725, 0.029093344819557387, 0.062235346413217485, 0.024747064562689047, 0.10575313470326364, 0.04991256682842504, 0.030903782535460778, 0.027740203659050167, 0.01876164726127172, 0.023904454210423864, 0.048573131280136295, 0.06304729307885282, 0.09373073567985557, 0.06816775581683032, 0.06435385890654288, 0.13424078497337177, 0.0572175709385192, 0.06532051367685199, 0.028898883574584033, 0.04990769833966624, 0.053194106367300265, 0.027807679725810885, 0.04006931005278602, 0.05971351005428005, 0.04486665653530508, 0.0164930409664521, 0.09406810117070563, 0.02546907406212995, 0.02727525556110777, 0.02335798490094021, 0.05480204723426141, 0.04880296328337863, 0.051475945438141935, 0.04047778442327399, 0.06596543258638121, 0.0197335527263931, 0.023822721486794762, 0.05636224574118387, 0.05783834036265034, 0.02958993994980119, 0.06074908436858095, 0.041789942333707586, 0.007279900501089287, 0.003624033502092061, 0.016901185081223957, 0.02088685578200966, 0.015051907066663262, 0.06707113614538684, 0.06775742978788912, 0.016644734096189495, 0.06926330679561943, 0.04181513453659136, 0.05877211056940723, 0.006699193136228132, 0.017584359848115128, 0.0502822454291163, 0.030939650532673113, 0.08489171974360943, 0.07243566156830639, 0.012158236168033909, 0.06601944609428756, 0.03537738564773463, 0.09897288837237284, 0.02762727290246403, 0.01804705367248971, 0.05779634964710567, 0.07987097938894294, 0.03282900637714192, 0.04519989568507299, 0.04813947954971809, 0.006843607652626815, 0.11344699451001361, 0.01244595105163171, 0.04048040049383417, 0.0548463571612956, 0.04891790711553767, 0.0803966871171724, 0.0674990881816484, 0.02540090037655318, 0.03680210138554685, 0.023343806169577874, 0.06835498483269475, 0.055240437577595, 0.06197818853252102, 0.004520136235441896, 0.05285726780130062, 0.0035822299469145946, 0.08547571575036272, 0.03653535866760649, 0.03666330492706038, 0.0536365822335938, 0.05598696392553393, 0.036754518587258644, 0.022912143394933082, 0.03737036015081685, 0.03552508416760247, 0.01520118265034398, 0.03329388397105504, 0.042650380928535014, 0.020396832369442564, 0.08286122596473433, 0.009660967680247268, 0.011660249510896392, 0.05132960133778397, 0.022451761360571254, 0.05102339120639954, 0.08739509517909028, 0.015933589638734702, 0.037729121759184636, 0.04335464567702729, 0.03611692838603631, 0.01814411360101076, 0.0285310362232849, 0.03492531381198205, 0.013931027515354799, 0.07782669650623575, 0.012853147072746651, 0.0519531167083187, 0.011634074890025659, 0.04827955250220839, 0.032718485745135695, 0.02755249781330349, 0.019627696492534596, 0.01831388915888965, 0.048568322163191624, 0.05118460423545912, 0.07103764830389991, 0.04148366169829387, 0.04553131657303311, 0.04285922499548178, 0.015310690250771586, 0.05426893287221901, 0.0294157820098917, 0.02028193306614412, 0.03814485062321182, 0.0163120014622109, 0.05352895597752649, 0.050020211638184264, 0.04344035631220322, 0.06938547914614901, 0.024948759892140515, 0.0107305741039454, 0.04467709717573598, 0.044803073033108376, 0.02134567745088134, 0.04357641424576286, 0.018130181633750908, 0.1076362824824173, 0.07188016403233632, 0.020921619834552985, 0.03979440742114093, 0.05809570233395789, 0.030443300311162602, 0.03516039279929828, 0.001123123156503425, 0.054667800141032785, 0.05388848570873961, 0.1105976669350639, 0.06891516532050446, 0.09784900961676612, 0.17159684764919803, 0.12447798813809641, 0.17583411012310535, 0.2319078941945918, 0.24322809535078704, 0.1375630238908343, 0.08622150737210177, 0.1141864036617335, 0.11503913876367733, 0.2557439112570137, 0.06437996766180731, 0.12145728382165544, 0.17660851153777912, 0.138873255928047, 0.1752072328235954, 0.08401777406106703, 0.07922595657873899, 0.1311231413274072, 0.1293662254465744, 0.1095053665630985, 0.19628394482424483, 0.06748113562935032, 0.1572348948684521, 0.1274784837733023, 0.1308176139718853, 0.13855390978278592, 0.14610757789341733, 0.10834891494596377, 0.32986513862852007, 0.15018474427051842, 0.24985942232888192, 0.17981818149564788, 0.23243085597641766, 0.21728057909058407, 0.12859160138759762, 0.14848702208837494, 0.1379828865174204, 0.10398563579656184, 0.09275584307033569, 0.22490340052172542, 0.21075163880595937, 0.1667424596962519, 0.12728315050480887, 0.18357045046286657, 0.20715646765893325, 0.09800908344914205, 0.10480143420863897, 0.1085524563677609, 0.14911404781742021, 0.19012210046639666, 0.11391335268854164, 0.095658286154503, 0.10661781838280149, 0.1529642951209098, 0.1950760549516417, 0.10579231267911382, 0.19215316569898278, 0.13465230586007237, 0.12881543312687427, 0.15999028139049187, 0.09841820719884709, 0.11321260200929828, 0.1403643493540585, 0.15547420887742192, 0.14948619034839794, 0.13181595102651045, 0.13341786194359884, 0.17476878681918606, 0.21123684011399746, 0.2199267511605285, 0.16743532876716927, 0.0772084726486355, 0.1541964680654928, 0.1438425580272451, 0.1236404967494309, 0.0906070509518031, 0.1564265476190485, 0.16780083649791777, 0.09874983588815667, 0.16423686523921788, 0.15796745399711654, 0.2723651396809146, 0.14603630203055218, 0.18881543073803186, 0.11215787657420151, 0.17910315189510584, 0.14642321330029517, 0.19176618021447212, 0.15450043691089377, 0.12889027129858732, 0.12564941629534587, 0.14068491262150928, 0.15784409421030432, 0.17559859697939828, 0.164991139608901, 0.21291447978001088, 0.12500254553742707, 0.240373661799822, 0.1437708071898669, 0.28852472256403416, 0.11972661770414561, 0.12435470998752862, 0.2524243440711871, 0.18052273197099566, 0.1644764601951465, 0.19264034111984074, 0.1515426964033395, 0.16391613869927824, 0.23241384595166892, 0.08026575742405839, 0.19023066182853654, 0.09494316749623977, 0.16932779049966484, 0.19999333249870688, 0.12579735601320863, 0.18797459226334468, 0.14549324288964272, 0.0868190846813377, 0.2905748609919101, 0.1830552367027849, 0.16796664713183418, 0.14197147014783695, 0.1074480070383288, 0.13328524015378207, 0.08353574172360823, 0.17571129952557385, 0.1750802216702141, 0.09580417754477821, 0.11848306021420285, 0.17250394506845623, 0.14281319919973612, 0.14608283468987793, 0.07242082603625022, 0.13921403529820964, 0.14363836351549253, 0.12396872640238144, 0.1307729960535653, 0.14717775484314188, 0.12754833471262828, 0.1399271353147924, 0.11742898044758476, 0.21394852898083627, 0.17117802402935922, 0.15777902270201594, 0.13176783017115667, 0.18027537415036932, 0.08264701245934702, 0.2785787562606856, 0.12565415119752288, 0.13671642635017633, 0.08394988981308416, 0.11211199700483121, 0.2037769349408336, 0.1944070978788659, 0.11423513307818212, 0.18095930776325986, 0.10602415961329825, 0.10502116187126376, 0.2626777079422027, 0.11508861774927936, 0.09793656077818014, 0.20253906230209395, 0.11164970579557121, 0.11496787774376571, 0.22161237633554265, 0.10182571146287955, 0.18346968165133148, 0.09049712403793819, 0.20148129406152293, 0.10117979065398686, 0.14842107484582812, 0.18202268664026633, 0.11725813805242069, 0.2543857810087502, 0.11811594944447279], [0.02510585771233309, 0.03440998130827211, 0.054760672501288354, 0.008600152923463611, 0.05997831205604598, 0.039599255978828296, 0.09185753267956898, 0.07754032398224808, 0.03700852605106775, 0.009232866286765784, 0.060234939301153645, 0.029883129100198857, 0.014009157112013781, 0.03631815801782068, 0.04877795661741402, 0.07792261167196557, 0.01632832871109713, 0.0216812729195226, 0.0636553717777133, 0.045192500183475204, 0.03766231733607128, 0.00845051461510593, 0.046516781076206826, 0.04029658164654393, 0.029466927117027808, 0.011512861765368143, 0.08331616249051876, 0.04138011354370974, 0.03259481796703767, 0.06128169778094161, 0.019974242350144777, 0.03224533691536635, 0.1568002931890078, 0.07003111051744781, 0.06090812290494796, 0.005563525828620186, 0.06137581694929395, 0.028699310787487775, 0.020255521885701455, 0.06531491788337007, 0.009106375564442715, 0.07108478952432051, 0.02876190352253616, 0.0848804613633547, 0.027489331769174896, 0.031625651026843116, 0.047213346042553894, 0.062159743829397485, 0.02842476067598909, 0.012056776231474942, 0.021421367237053346, 0.017978000541916117, 0.027995090567856096, 0.052482631654129364, 0.037824988685315475, 0.05730584940465633, 0.006477919951066724, 0.06808323261793703, 0.04012042176327668, 0.023936416655487847, 0.019674845134431962, 0.0273240499154781, 0.07849597270251252, 0.06263086659600958, 0.026504089910304174, 0.06294969323789701, 0.11104659948614426, 0.01934552266902756, 0.01745566401950782, 0.07820626793545671, 0.057093932846328244, 0.02293094014021335, 0.04395889489387628, 0.06959325823117979, 0.036660280675278045, 0.022897011003806256, 0.08686134999152273, 0.06174785929033533, 0.02233709026768338, 0.05170997799723409, 0.060133265069453046, 0.0522377563174814, 0.031751333735883236, 0.038801276532467455, 0.043850481961271726, 0.09157495995168574, 0.047578148733009584, 0.00813385133369593, 0.10800605756230652, 0.014440792983805295, 0.0019212504525967233, 0.01076881604603841, 0.020569910484482534, 0.0344276666874066, 0.02668970661034109, 0.04970111411239486, 0.04935606739309151, 0.0448182722175261, 0.06520342503790744, 0.05814968244521879, 0.02989340227941284, 0.014840949734207243, 0.026510758107178845, 0.009239906485163374, 0.06749876163667068, 0.09878237906377763, 0.04608630944858305, 0.04362697305623442, 0.04273926795576699, 0.017719584720907733, 0.02288682502694428, 0.028293484028836247, 0.07482523607905023, 0.045814683398930356, 0.015368396871053847, 0.010713000046962406, 0.022017348928784486, 0.06133653878350742, 0.027430332884250674, 0.02827705287927529, 0.01731548716634279, 0.12014078063657507, 0.05798839149065316, 0.006187737426444073, 0.0675352085090708, 0.04004008056654129, 0.027726774496841244, 0.06162901918287389, 0.0285828028791002, 0.007925063855509507, 0.033402085391571745, 0.029957393962831702, 0.007087788617354818, 0.016361337584385183, 0.039777015190338716, 0.06846491174655966, 0.02022224954998819, 0.08368892842554487, 0.027688412883435376, 0.017085747931560036, 0.06783055359846912, 0.029852333682356402, 0.02403090133157093, 0.05144998140167445, 0.008783373414189555, 0.027488849373185076, 0.05087317680590786, 0.009114503936871188, 0.06417124604922719, 0.0627556438848842, 0.024755966624070425, 0.03951373459130991, 0.039477714453823864, 0.08247097503044643, 0.039789809816284105, 0.02665540640009567, 0.05628412727674004, 0.0217983949551126, 0.016784849722171202, 0.0385342666413635, 0.019731608299480285, 0.020501163489825558, 0.013098989984428044, 0.017467384386691265, 0.01629054226214066, 0.03324823817820288, 0.03986303381680045, 0.04208366954117082, 0.08013493905309588, 0.042624194247764535, 0.08036559112952091, 0.0008762282504903851, 0.05981744412565604, 0.03151560536934994, 0.047261578220059164, 0.06689204848953523, 0.010263156509608962, 0.03320668532978743, 0.02592222943349043, 0.03627768499427475, 0.06075944103940856, 0.05322289056493901, 0.015865315763221588, 0.08805271965684369, 0.018038524540315848, 0.04542399830825161, 0.04413972288602963, 0.019406421452003997, 0.007899193515186198, 0.030460516281891614, 0.03284409052866977, 0.006790697625547182, 0.048453645504196174, 0.02327439680811949, 0.05233765681623481, 0.02038079641351942, 0.010555249136814382, 0.009054088477569167, 0.008627117931609973, 0.0339812871243339, 0.018781518265313935, 0.0423731590854004, 0.05406194046372548, 0.020297696282796096, 0.04660752347263042, 0.03115442807029467, 0.007649063772987574, 0.07653589389519766, 0.05695142193872016, 0.010250996419927105, 0.06376976642059162, 0.04099321711692028, 0.09392130436026491, 0.05470538992085494, 0.006976727609071531, 0.034572036674944684, 0.06177929666591808, 0.019354575015313458, 0.021504543437913526, 0.10774840615340509, 0.011481493038445478, 0.011283626263320912, 0.06657545571215451, 0.023774880792188924, 0.03867287014145404, 0.043870427180081606, 0.05322319484548643, 0.02167305920011131, 0.030305168074846733, 0.03807145963946823, 0.02691076271730708, 0.09556906516081654, 0.02138610594556667, 0.03871112043270841, 0.033808786029112525, 0.0215500964623061, 0.016051767379394732, 0.03148781936033629, 0.009996638291340787, 0.05551761118113063, 0.042038472747663036, 0.05750075222749729, 0.04466083300940227, 0.049359199256286956, 0.05842851474881172, 0.05198131832003128, 0.07223949709441513, 0.02847763869795017, 0.02971023837744724, 0.06092537412769161, 0.04724401529529132, 0.08064071269473061, 0.04423738209879957, 0.03495666212984361, 0.013546178488468286, 0.022845303719805088, 0.012342632962827338, 0.10535197419812903, 0.07889046130003408, 0.02150918557163095, 0.03839970042463392, 0.04174002919171471, 0.026520339233684354, 0.04041694315674249, 0.022223567648325115, 0.041922771924873814, 0.05732350880862214, 0.0660598708782345, 0.06181570643093437, 0.04105541651370004, 0.03359374502906576, 0.051199309891671874, 0.08210743399104103, 0.0857270292181056, 0.10216919225058518, 0.017708515588310547, 0.047955827685655095, 0.023551852427772246, 0.015456640085176332, 0.026387889993202407, 0.09247343361494131, 0.06355623569106683, 0.044320999877527356, 0.038144668797031045, 0.016098029154818505, 0.029492284447769634, 0.026125943404622376, 0.05570283639826812, 0.041961582537624054, 0.024116424574458506, 0.02732313336309744, 0.054965297458693385, 0.01690760465862695, 0.04174688663624693, 0.06034209429344628, 0.06070678195101209, 0.08007116630324163, 0.058859628334175795, 0.038510985468747094, 0.10073842800920829, 0.010083813740493497, 0.0381493480381323, 0.02525172498280881, 0.022612571774516255, 0.03899157061823644, 0.010264401462336536, 0.05005758619518019, 0.03424592214287259, 0.02607125639769947, 0.044283061288297176, 0.053596825382555835, 0.04760438736411743, 0.038050004150136374, 0.05761326552601531, 0.026130210753763095, 0.012671371914620977, 0.06491484833532013, 0.03684546136355493, 0.047283991079893894, 0.06256208434933797, 0.04456024231330957, 0.0805382221005857, 0.03260108169342857, 0.1417443878017366, 0.04157462673902046, 0.042383341351523995, 0.030251267744461074, 0.02932031584350625, 0.04958097153576091, 0.05629542647511698, 0.10110713439644314, 0.050134294579038396, 0.04352484240371268, 0.050685428286669776, 0.048387108254246414, 0.03152350182062946, 0.0061700840524281375, 0.027585235802689567, 0.053521979789366014, 0.057452126711723395, 0.014545461781381164, 0.0464898967766203, 0.04710562701802701, 0.05918698225286789, 0.05043534307333175, 0.03028471448487835, 0.03483593696728349, 0.02542730413551908, 0.017731106563587673, 0.05735283477406483, 0.041211757343262434, 0.0909158363356255, 0.13550105562899262, 0.14499696873826906, 0.1429982908302918, 0.1381182245677337, 0.16662141541019082, 0.11716277207597159, 0.14898044639267027, 0.15031506540253758, 0.13668812083778903, 0.12712059047771618, 0.1208314677933231, 0.10111175797646865, 0.10104388857143931, 0.15698538481956348, 0.16421599604655057, 0.10369817973696627, 0.17186835495522246, 0.09078173025045544, 0.07591256406158209, 0.13444705749861896, 0.11077506249421276, 0.11097706767031923, 0.1419524266384542, 0.10060577653348446, 0.08706141074071638, 0.097466996521689, 0.15428107290063053, 0.18065743177430704, 0.12483192578656599, 0.08062906839768402, 0.09262818624847569, 0.15026528213638812, 0.24333713168743998, 0.11523611217853613, 0.14225081453332677, 0.25752046436537057, 0.24189596995711327, 0.14101528708124533, 0.07454369493643753, 0.14861780335195363, 0.15558901912299916, 0.170162083231844, 0.11842856431030668, 0.20936970046022907, 0.13206123083364218, 0.09174069637083448, 0.14245882368413731, 0.15590603492455557, 0.1914182465407066, 0.12193079630378634, 0.06933884258614853, 0.14883050287608057, 0.064979237067746, 0.12774377188179642, 0.1547404919983819, 0.17059971287380904, 0.09927368824719451, 0.1404911675490439, 0.10583595838397741, 0.09101331001147628, 0.12059007684001699, 0.12639506690902635, 0.1407495982130058, 0.10256586276227608, 0.06788922037230805, 0.1812899048672989, 0.24404010880971327, 0.14688453229609877, 0.11050115805119276, 0.11848131616716273, 0.25530568789690733, 0.0937665591482073, 0.1302099137683399, 0.1258078054524958, 0.1092428392439615, 0.16432117321528494, 0.18208327557658777, 0.1191532937809825, 0.1443551148986444, 0.11249341638176702, 0.1718861368135549, 0.13115744339302182, 0.10364593254053034, 0.16733643016777933, 0.10536222325754352, 0.3044344688532874, 0.08481906348606572, 0.09123751282459125, 0.15854696743190289, 0.17430589447030798, 0.15116157388547435, 0.12714108859654516, 0.13928908127127215, 0.086550160049228, 0.06912388693308458, 0.18493600218789652, 0.23036829399643466, 0.2203378564445302, 0.23260779882548377, 0.21072725183330476, 0.13299100828589872, 0.12243486300576478, 0.11922777572181076, 0.15071376197738573, 0.11229183422983624, 0.2514839539071545, 0.1974250710918568, 0.23197832400910556, 0.10500444870558567, 0.14305806340416893, 0.10685424436815083, 0.1298024895368144, 0.17263846675632522, 0.13587465276941657, 0.10661860505933873, 0.09008436376461759, 0.24844767933245748, 0.1155159760673996, 0.17463730793679133, 0.18603568692924455, 0.09900189150357619, 0.16684996720869094, 0.16828746272949502, 0.16708338749594986, 0.1497847118298523, 0.1794205981423147, 0.12110276729799807, 0.13304214226081967, 0.153661364747677, 0.11409241807996295, 0.2238356281304732, 0.05962245224509388, 0.09573228569934145, 0.16561951604671776, 0.12148790483479388, 0.2727384102763608, 0.13289963506394997, 0.11997540044831112, 0.0832564196025487, 0.13719548267545179, 0.15599688864313066, 0.10706208282499574, 0.1133000195841305, 0.0991799846815411, 0.14515924674924463, 0.11445658252341673, 0.11466140043921769, 0.24632371205370873, 0.16611579019809142, 0.08886750874808058, 0.1821192548959516, 0.1302995058358647, 0.1528170530218631, 0.2373729509417899, 0.25007013289723545, 0.1613482038374059, 0.1265087045612745, 0.17617996578337625, 0.10352239463827573, 0.08980426980997436, 0.22444309084676206, 0.08958118021837436, 0.13538516184780747, 0.1520411079400219, 0.09074238158063963, 0.19446229882305488, 0.11186010466190055, 0.1714079562225379, 0.18839479627786204, 0.15778267406858504, 0.2275732471025549, 0.06366179877659306, 0.19542440422810614, 0.19245392846642062, 0.15181362483417615, 0.17128979146946222], [0.03202460735337809, 0.051317430115886964, 0.08469609703752212, 0.06285001538344659, 0.04996845054847654, 0.03338380629429594, 0.027143390761921182, 0.019685545048560016, 0.03178272658260539, 0.030323358114401344, 0.04230812097375747, 0.03806015301961452, 0.027375682984711602, 0.03995534956629854, 0.027045887400163338, 0.05789341143099591, 0.04793376734596677, 0.020876545495411847, 0.06650710391113535, 0.02954452793346718, 0.03891231295710895, 0.02567942468886031, 0.052898341964464635, 0.03281596313172486, 0.026021280173154082, 0.07956073197419755, 0.0049997811765933875, 0.03772098782064859, 0.038243085000431165, 0.016596329369349405, 0.027860815644089598, 0.04055569879710674, 0.054234063063631766, 0.05770714349637274, 0.03919734219380189, 0.050721129300654866, 0.0528667004982708, 0.031346800169558264, 0.04646509791200515, 0.09758504995261319, 0.013544849116442492, 0.022735131897206884, 0.015406164766318398, 0.024710088910069317, 0.07352508982876316, 0.010668152062862646, 0.031724490254418924, 0.024465037313348148, 0.028724549374601338, 0.0426416198752122, 0.01319769933616044, 0.02133600541128544, 0.08201887350878678, 0.011822397646028548, 0.06280464789597318, 0.03298385920061264, 0.02492706320481375, 0.04207229241728783, 0.07473291290807538, 0.06614950005314313, 0.044719518336933106, 0.010334618837077869, 0.03921437819371931, 0.06338764942483976, 0.01988988613447873, 0.07526423869421706, 0.021150652173673734, 0.026908176332653966, 0.06376632285537198, 0.05137285370437894, 0.046001311275176704, 0.031009390149847604, 0.014705949361086823, 0.016687192364770453, 0.031381195003632456, 0.054209412628551945, 0.052353394057718106, 0.06434234819607809, 0.05735036713303998, 0.06660094106337056, 0.0654416841280181, 0.0918278913013637, 0.010011198301072, 0.0191094325055019, 0.06957051140489057, 0.016402801375079434, 0.03980624467658345, 0.05868329775694292, 0.07889944870839827, 0.0968535224092193, 0.02741963111475343, 0.027532534040801693, 0.06678785095573403, 0.015564948189421557, 0.05832643975736573, 0.08705784101039171, 0.04580661254294682, 0.03160600637784228, 0.008667883175803581, 0.056702991714701056, 0.017715144822432194, 0.048713604992371984, 0.01708752166450722, 0.050454753945814446, 0.021877524595765863, 0.014832654378551524, 0.011851028775708983, 0.02455602090776665, 0.07071145955706015, 0.03655535212601535, 0.0379066063760547, 0.04212072497466579, 0.058665115138865076, 0.06827193108620122, 0.06372548989020288, 0.018156468504457735, 0.025952236319426447, 0.028441898721212056, 0.05589444037468638, 0.09083440789254382, 0.05407273871242069, 0.019637429759313818, 0.047857411482254975, 0.047966099009499885, 0.024016076931729913, 0.05809715323266573, 0.030882987557561137, 0.010626801449689083, 0.021993652153469156, 0.04076219025591854, 0.0231745575365494, 0.06862561640446074, 0.038998487434582785, 0.01728557861497393, 0.06118176388554275, 0.0069391039687616285, 0.03552602669515181, 0.026571881389827468, 0.022961423856031615, 0.039231514383573085, 0.060227365684113465, 0.04921176419884432, 0.0857990026997868, 0.06800586372264661, 0.008503471490257652, 0.028883485865662806, 0.003265147815909586, 0.0032336853928427445, 0.030257486941991374, 0.028309742629062384, 0.0508338837971678, 0.03332381107611582, 0.02286670725879958, 0.05681834001734387, 0.028388306382112205, 0.031809525535209104, 0.028909203138027806, 0.03451218617556151, 0.02454927107464755, 0.010637605264491867, 0.02448088958772132, 0.07932780150440522, 0.030197801570466254, 0.0445474885054864, 0.021508120589714963, 0.05856749303347897, 0.030377406874322332, 0.03322872340504546, 0.04469340587093029, 0.05852009948284831, 0.0670259541948326, 0.07084624099661596, 0.13851959287421778, 0.07405116863083094, 0.042376925484859385, 0.06712071903166361, 0.014335848663904471, 0.0604423473123461, 0.09474361140746623, 0.02883536315493984, 0.06212301865161862, 0.03648661440820433, 0.006305941142272786, 0.04380082114948891, 0.03830195215414278, 0.035937410284532234, 0.013674242563865846, 0.034652530011953786, 0.047193905484164134, 0.04635948658687994, 0.027205521510040853, 0.017486409342382103, 0.050656406601774506, 0.0179872996523045, 0.028893569797219243, 0.01949777240952244, 0.06810810198658146, 0.05209313028899487, 0.07711559286690317, 0.0078106024193402845, 0.04477022186620161, 0.05401599410106428, 0.021780806055176072, 0.031633224643883295, 0.02350809911149554, 0.007268248318723636, 0.10256715409923345, 0.08328885887749493, 0.03214027106878348, 0.034892373587354086, 0.020477965808822773, 0.1078832098573912, 0.034018988226307556, 0.02709990647417726, 0.014494546740024816, 0.036343045940157026, 0.023579059561598115, 0.07407479119137861, 0.020316654445196036, 0.024666502577019855, 0.0369490466255229, 0.029892650854890235, 0.03837260461295955, 0.05067976569989696, 0.11836252058856189, 0.03792275550949853, 0.0375234577950323, 0.036774935069843195, 0.08995214273454621, 0.007032455478110933, 0.14542478718794882, 0.060306823725113645, 0.02636406890815124, 0.05453547521028668, 0.05316219772794284, 0.06609597636270337, 0.023816168322809972, 0.04714866416179575, 0.022311285792966373, 0.07106055098120123, 0.06958139128983021, 0.03928470781829674, 0.03500371429254301, 0.05092435530968942, 0.07466555558494292, 0.06359647493809462, 0.044819860413554125, 0.04422553742188029, 0.07213591554318555, 0.013253514407551847, 0.055572916025994346, 0.026429233184899203, 0.040898986626416445, 0.05410765304986853, 0.09918791824020445, 0.07921325843199156, 0.020952181475877296, 0.09731351296068169, 0.0823242895421572, 0.06322553468635306, 0.02470418141456321, 0.010172638612857554, 0.022029865249351133, 0.035634877494885586, 0.018676780819077976, 0.02333759253815515, 0.03254500501498114, 0.030037599717616104, 0.029932734250905924, 0.05078452355519403, 0.024198635983339045, 0.0717845605686307, 0.045373784596449696, 0.00425898096182209, 0.03278064803453162, 0.034916515651275404, 0.06963505598832853, 0.0301350919471588, 0.10708355315728113, 0.0581702844647225, 0.01782007337169489, 0.049819456980912946, 0.047534347177133895, 0.04221911891363561, 0.048282450588885695, 0.01636345641600201, 0.06009079566865694, 0.02826780571922427, 0.06921407271875069, 0.022840650453872513, 0.05708661527023651, 0.016976639235508628, 0.04092641640454531, 0.033771248199627735, 0.05964236035651993, 0.053182102128630504, 0.05671735227224417, 0.055462851814809255, 0.026743553135020193, 0.025745856182766147, 0.04410444860695861, 0.029581509152194485, 0.02002933011681307, 0.022327019323711284, 0.01323943122770288, 0.012381486249068985, 0.01667460925091291, 0.11101675030658953, 0.040761507480056025, 0.0364102214371087, 0.012322835245868191, 0.022783330678066704, 0.04784276519785635, 0.023796994937583804, 0.0382319008349441, 0.03313726854685228, 0.04399307450512424, 0.017651180969551206, 0.07078891751007177, 0.021059536848042626, 0.01499814217822859, 0.02484354376065312, 0.04871758661465719, 0.0233115988157806, 0.03337692658533342, 0.04111843969440088, 0.01550838725961512, 0.056504196327296086, 0.04025620510219596, 0.0067257123919262085, 0.02037021524301963, 0.0502146098006051, 0.020543356440612115, 0.006002496438668459, 0.04875583319517318, 0.014672215966129443, 0.030485660245176405, 0.031667983130319044, 0.051418692455627024, 0.03120873101579491, 0.07376481837127358, 0.028956387031939812, 0.02778135945845861, 0.0305022379689035, 0.04249817015079316, 0.08391902389121242, 0.02348411475395551, 0.07004486993537284, 0.0035256432738606236, 0.05936611443758011, 0.035065286574536, 0.025942376887542196, 0.09939337440300733, 0.11672337612253614, 0.2514714264543727, 0.12499791453592479, 0.10184301092522219, 0.11179168606759049, 0.05061227850092109, 0.08637780367280357, 0.17912780604092404, 0.09625383740058169, 0.07972692110342905, 0.17243350041098893, 0.10643300876836292, 0.12240416035638191, 0.13736279244767502, 0.10178404729231261, 0.09532334006507881, 0.18351244420045987, 0.1203454946517013, 0.12120899831643328, 0.24073152540950105, 0.12498942436650395, 0.08418700599577278, 0.08985423861304298, 0.11119325528852642, 0.18964562681503594, 0.0784170972474385, 0.2028413093648851, 0.11064898644690402, 0.060681827235384844, 0.12277792076929472, 0.13009857677388936, 0.08430569767369889, 0.1338410790776834, 0.1081829855684191, 0.18748787697404623, 0.2125903542037122, 0.06907252289238386, 0.1264644428738393, 0.12300279151531868, 0.1658624951960519, 0.11477647785795853, 0.09911561079206876, 0.10772063498734497, 0.0961195160925854, 0.16403817746322602, 0.16713456599973142, 0.13145013159373775, 0.3293796256184578, 0.1399620607844554, 0.09810928080696613, 0.14930096513126045, 0.15962042467435822, 0.06658197919023223, 0.25089881499297917, 0.16332273225998506, 0.13553019234677777, 0.09284203610150144, 0.17343366314889863, 0.12879763642558828, 0.12498100841185078, 0.10728302760981023, 0.097061717096949, 0.21236471162410453, 0.19575394748244435, 0.17000373860355467, 0.10693552438169718, 0.1637170056346804, 0.2362374501535669, 0.15772256010677665, 0.2893957664491609, 0.1842143081012182, 0.1579399945330806, 0.13931654073530808, 0.20904671779135242, 0.14301267365226522, 0.17587918817298487, 0.13983329816255718, 0.25232085899915546, 0.16284185025142506, 0.19510030833771452, 0.31385457899887115, 0.12496831768658012, 0.12205385181005113, 0.1684142809244804, 0.18318468210054561, 0.14843379525700584, 0.19027916860068217, 0.12151359056588262, 0.19588067661970854, 0.09748800672241487, 0.08975697273854166, 0.1606608711881563, 0.16798416181700304, 0.1318903884384781, 0.1736617845017463, 0.14663965324871242, 0.10145095657208003, 0.12998274236451834, 0.1703696619370021, 0.1849414050229825, 0.0964827454299666, 0.2532450406579301, 0.2708795975195244, 0.09170706965960562, 0.09664274504757486, 0.10006557466113009, 0.12146165507147089, 0.1449412779766135, 0.1246331341098994, 0.1479998169816099, 0.13519202533643693, 0.17081116558983922, 0.14788487314945087, 0.2897747664246708, 0.07097654728568159, 0.08691613533301279, 0.15986745595000684, 0.12507919454947114, 0.15775202336953953, 0.12991082825465128, 0.11925073777092621, 0.07358769740676507, 0.14432682422921062, 0.10405142718809657, 0.1443610669230111, 0.09563414409058169, 0.11788644769694656, 0.11668954903143458, 0.1440030400408432, 0.07406099466606975, 0.22522718471009284, 0.13623915117932484, 0.1172468722506892, 0.16126907605212182, 0.12503056903369725, 0.1152833498781547, 0.13422824267763644, 0.1110848349344451, 0.14326665143016726, 0.1447950303554535, 0.130699404689949, 0.22539434605278075, 0.13251974451122805, 0.06858407097752206, 0.08979263293440454, 0.14927524229278788, 0.2185997465858236, 0.13439708127407357, 0.11447515105828643, 0.1770051004132256, 0.10981838218867779, 0.16011922212783247, 0.13318703917320818, 0.11423918520449661, 0.13546929170843214, 0.12756534473737702, 0.0735051186347846, 0.11103996468591504, 0.11374605033779517, 0.1543564602616243, 0.1607928695739247, 0.12534687237348408, 0.1163604881730862, 0.18600282463012263, 0.1532258724910207, 0.28980133531149477, 0.09670550105511211, 0.15335551084717736, 0.13986923295306042, 0.15607570472639054, 0.2098002500133589, 0.1826443095342256, 0.10563155607087538, 0.08851777907693759, 0.13488872442394495], [0.043811085051856935, 0.04876243830949534, 0.047959364019334316, 0.04829638812225312, 0.030584226733481046, 0.01739744624501327, 0.06260486174141988, 0.05829192617966328, 0.04275179540854879, 0.05925000172283035, 0.05972408194793388, 0.042570429359329864, 0.017981740966206416, 0.02924168529716553, 0.07310440341825597, 0.014762480604986195, 0.06968589310417883, 0.0706860632635653, 0.025128033084911294, 0.03793435527768452, 0.07089203892974183, 0.03213885356672108, 0.020479290542425588, 0.05385387565183919, 0.044089453513151966, 0.01782671930413926, 0.011041203724744264, 0.05487297057698015, 0.08091274692560546, 0.03396667423658073, 0.08242292838986032, 0.07292148628039286, 0.05641818141157273, 0.04394504641823005, 0.026420149297337048, 0.014612302384193754, 0.04302813409594819, 0.010916473747784039, 0.032584312866674736, 0.033889746919157915, 0.015265356159943622, 0.017497621338407043, 0.08523648444679566, 0.03494546312140301, 0.0960091884189751, 0.04657662415411323, 0.012234329497005092, 0.047467234762734734, 0.05776305319159292, 0.1015215867664665, 0.010078179911943153, 0.012929592921864241, 0.019614382363215555, 0.03629386381362565, 0.015744028423796408, 0.03935821383493021, 0.01716670140012866, 0.10734242910984904, 0.06184064630360808, 0.011148622179462109, 0.07220614497782663, 0.04947832137986552, 0.0535242618934717, 0.026422175360494293, 0.01297516078921035, 0.023975089970917907, 0.03866922990710009, 0.016982372326310724, 0.04793961546965875, 0.04417050346091855, 0.09006365042296238, 0.011175785712111974, 0.03170094561937731, 0.061386704255710356, 0.07547287124907598, 0.03538800578098744, 0.05714253609767184, 0.023581638524774462, 0.07649131308426149, 0.06622516200877726, 0.034439986338838935, 0.08111856674076989, 0.021839242763235234, 0.02760711060545873, 0.05160872678970918, 0.03262941689172294, 0.058358044116175734, 0.06400288242730312, 0.023262271970452275, 0.03984688468335662, 0.02167550272133667, 0.026515335302974563, 0.0022381573671736987, 0.01966977069969289, 0.11173392471391708, 0.018672741680347826, 0.09678916336270049, 0.03486622772470582, 0.04913964599836618, 0.023408165216096677, 0.029581885792140383, 0.1375479286070913, 0.02388486151176039, 0.018208916080766357, 0.10362579065258615, 0.023779919974913355, 0.05666412544087507, 0.035759205784415826, 0.04254331870470196, 0.05165986447536852, 0.05588852545770351, 0.016698081526556052, 0.0623587729933206, 0.025074026998481713, 0.06263155679334886, 0.013933305908722105, 0.05287180647428613, 0.026113640451512765, 0.04863023954385426, 0.0720186265243683, 0.07365787489106879, 0.03007898929354269, 0.033135502235381864, 0.03451290605880786, 0.020752662494487595, 0.016631889375275932, 0.039962047449080274, 0.027112721509183757, 0.03358779300469905, 0.0662185123655945, 0.03716124519996811, 0.043540464612306096, 0.013159322879801039, 0.042859744498855434, 0.03513552714139223, 0.012563564760057488, 0.026622627592587378, 0.03331652689666953, 0.01928911016875645, 0.07655996174435131, 0.01037981655827025, 0.032011029761633836, 0.03238650082494132, 0.05268104112474248, 0.032468634308315814, 0.028341818251647055, 0.02033421736996388, 0.02145481212210143, 0.021619596736854874, 0.016651389305479825, 0.09229470961145125, 0.023551460944872815, 0.0601640827517258, 0.030093086388660595, 0.1097607024712488, 0.08523082928149961, 0.02016481288592331, 0.026514593155297916, 0.011928963558602845, 0.05534677620744333, 0.05540312376979273, 0.04960437887348235, 0.013483023576554842, 0.060495162251754664, 0.042089755152119324, 0.09257464771508239, 0.01765818498824956, 0.055630031711189076, 0.10787162493215874, 0.030401853218791075, 0.008899641979951411, 0.03956319131248165, 0.023340843144978862, 0.0242579818223021, 0.05603594567219261, 0.033374002523487434, 0.02203942040068796, 0.06370526636601426, 0.03308077997644432, 0.010788715808303095, 0.04358936843345873, 0.06357004705932923, 0.018717819730227347, 0.026701454808062408, 0.03169114555930719, 0.011351730372552993, 0.04671162452723365, 0.04581899156619329, 0.07107099299901165, 0.07758490479318425, 0.05221497609454673, 0.06598806809051894, 0.029324816969165113, 0.024122703143802937, 0.037687338844989426, 0.04816484244656749, 0.07115000204066746, 0.027194198191864416, 0.039784737236914225, 0.03389579913346097, 0.037002028548158705, 0.0646690564462915, 0.00470293184662296, 0.029093639823258854, 0.05588378684478812, 0.03918867761967704, 0.036004166468046606, 0.09124924617935903, 0.07035763323074207, 0.027819669121527113, 0.050176051518064924, 0.04101570419152267, 0.06173372508783359, 0.06123771810962353, 0.04298356070648879, 0.03795692769926973, 0.01436574701074278, 0.03515011034323834, 0.02943083833088167, 0.020646548364311457, 0.044052995508536696, 0.04165949874732178, 0.012599600668181665, 0.06651592804701068, 0.08377742953598499, 0.08620682026958093, 0.02216886950918706, 0.004516387925832532, 0.02016637325141346, 0.04882591048954055, 0.011390020554244984, 0.058065734410774894, 0.013347954554774333, 0.08309477983857505, 0.06895968675962649, 0.013603954685095232, 0.045973220985615626, 0.003095019969805435, 0.10812917986186221, 0.01997468207264319, 0.07639977658982389, 0.0551377020747168, 0.049522464323672466, 0.018895361863542348, 0.02356152075662976, 0.0630514119984582, 0.02045826920948457, 0.05806084365758579, 0.01444656596504501, 0.02281249522638973, 0.031215028138831258, 0.043388261256041005, 0.04332120450271759, 0.07095814944477752, 0.025001274261740036, 0.03833609094726853, 0.02666542168299202, 0.029054621409159154, 0.028780293941963464, 0.04464862839085981, 0.06587820796994492, 0.013644200425915187, 0.01479619080782868, 0.020624052012863103, 0.02395821353275096, 0.030868391368130688, 0.028928929423273075, 0.05666384342475794, 0.023936119796417188, 0.03337633657793049, 0.029911898454884067, 0.024430596095044166, 0.08192761160898954, 0.03900300340319518, 0.05427403513749596, 0.015567799891869072, 0.08025652510696091, 0.05140445435245056, 0.020151181488472503, 0.04818274304852821, 0.02355252221605042, 0.02113502996508032, 0.0379647462250432, 0.04017836123239249, 0.02168486676964676, 0.027840796210512053, 0.030610559988417663, 0.05601966295216698, 0.012651630786422174, 0.05719282402424142, 0.13287506997585297, 0.027889996890735347, 0.02990918219438754, 0.020533910756057594, 0.012117804890294792, 0.09107297868467867, 0.014895168260409264, 0.050878590773209, 0.021462274416990113, 0.052946058349334635, 0.028505482223408762, 0.009258846093871398, 0.017324938417004887, 0.008442433554591844, 0.023311088589252904, 0.007696550555920112, 0.018928784484160133, 0.045232702323119156, 0.006310554981610039, 0.05375227934564464, 0.03564772407116834, 0.036102408266742714, 0.033045832242351025, 0.0245011669176165, 0.05076127577922307, 0.04745524907775689, 0.08783052806393243, 0.019627408910309896, 0.0544095401710365, 0.012665152717090677, 0.01166733887657756, 0.08566433258238249, 0.02994706326717278, 0.011776985629694536, 0.011484948663564865, 0.010184567709075054, 0.03068681195145473, 0.03392552214791067, 0.04157562492764555, 0.07245769593282603, 0.03757275866519194, 0.05910076324653346, 0.028431809223548044, 0.020125766641285736, 0.04786494799191132, 0.023086290202627424, 0.022596663839067332, 0.014387767459993483, 0.029757062329736073, 0.06552232589456253, 0.03388327910215594, 0.09951638538041152, 0.04239252913976088, 0.03573743859305978, 0.021665557942469604, 0.014631694702984532, 0.041588657040847465, 0.029686834750464186, 0.0124112946105015, 0.018485683358449023, 0.057874813210219145, 0.03753803357540164, 0.09587315274984576, 0.16503844410181046, 0.1274197205202654, 0.08805855293758214, 0.14030879217898473, 0.10127210640348494, 0.17183273186674342, 0.16297668364131823, 0.2174955199006945, 0.10659163541276939, 0.13569846691098064, 0.15064935840200633, 0.22096414002589881, 0.23523212206782773, 0.18704940128372982, 0.13611116039101034, 0.12217521521961316, 0.15662897581933066, 0.13324565399670973, 0.09598111297236755, 0.17471245781052858, 0.10766920415335335, 0.1670189097058028, 0.1001665809599217, 0.11580392936593853, 0.16236683120951056, 0.11210694297915325, 0.14239511772757396, 0.14249128522351384, 0.13184479088522494, 0.19599484861828387, 0.21409232751466334, 0.16445725341327488, 0.15555213438346982, 0.14294723107013851, 0.10321949448552914, 0.15751085506053641, 0.18783168430672958, 0.07143399227061309, 0.11610675530391745, 0.16696832492016256, 0.09608378910343163, 0.12776771356584504, 0.12270680075744167, 0.1445097487885505, 0.14396808488527313, 0.13741521775955334, 0.1027745843748562, 0.1620492959045805, 0.19075936783337966, 0.11429831210989505, 0.06669721245998517, 0.11284954336588271, 0.17222718335688114, 0.1384666925878264, 0.15396004950162023, 0.08641079955850728, 0.26726566487923265, 0.14704744855407625, 0.05111546575790271, 0.3474515746347606, 0.10741898906417191, 0.22521425649756566, 0.1760722801554948, 0.11789088574005291, 0.1394087600056082, 0.17779881251044571, 0.0589053965813946, 0.12149824295192957, 0.15193245752016082, 0.15985939622623846, 0.1307218917645514, 0.19724973128177226, 0.13834760757163167, 0.1095057895872742, 0.130721936293412, 0.0845952911186032, 0.22264161641942337, 0.15918755962047726, 0.11866524262586609, 0.11468706390587613, 0.20532115129753947, 0.14096220867941156, 0.16619701083982363, 0.16635470237815753, 0.08012875696294941, 0.13659587188158184, 0.19002861954504624, 0.1520847313804552, 0.1395238225813955, 0.1396867833682336, 0.1877476880326867, 0.07360589486779645, 0.1052403255016543, 0.20527700835373253, 0.11929862113902345, 0.2686715597519651, 0.08243757096352056, 0.20633983804145828, 0.12576735840411857, 0.1828099272097461, 0.27983271866105497, 0.11132213665405288, 0.1194420040701516, 0.18287188169779256, 0.11984137599938549, 0.12075142716639675, 0.16330423793988302, 0.10096092388266698, 0.11790888282121159, 0.13598480232758448, 0.15279051382094622, 0.13785838382318616, 0.10476138792000711, 0.14977596933022141, 0.12569137732498348, 0.13856434437911958, 0.1159511343576014, 0.1724862225819379, 0.19928312685806304, 0.18118261999916285, 0.19270836637588218, 0.0786476676876191, 0.15462683950318024, 0.13067936670267954, 0.0941983777738642, 0.27676842059008777, 0.0895524665247649, 0.10402810148661956, 0.14405041874852031, 0.13814654492307454, 0.13556097663240507, 0.04474120389204472, 0.11874884556164034, 0.2554895920911804, 0.14742624072823673, 0.12157821678556502, 0.13781988120172173, 0.07766168739181012, 0.1625909746508114, 0.12391850526910275, 0.08102288164081983, 0.08992679839138873, 0.16130618343595415, 0.12557607726193964, 0.13530817144783214, 0.11837014986667782, 0.1750124042155221, 0.2618880331283435, 0.13109185238135979, 0.10949787087156437, 0.1145801278471481, 0.09038993564900011, 0.13937546726083383, 0.20262302889022976, 0.14675271202577278, 0.10173479095101357, 0.11131741659482941, 0.09781691172975115, 0.21246025571599603, 0.2372589273727499, 0.10108077331096865, 0.15668724925490096, 0.1173233134613838, 0.1284870327799581, 0.26723019022028893, 0.10455035822815262, 0.13571596675319597, 0.3153169364668429, 0.10036359148216434, 0.08671429342939518, 0.06643643660936505, 0.10705284308642149, 0.08231734303990379, 0.18722269276622683, 0.139810009568464], [0.009103925549425185, 0.02706173967453651, 0.022935020097065717, 0.0065676395752234384, 0.12073032790794969, 0.02246152060251916, 0.03725230671989266, 0.018399379005131777, 0.019474472683214117, 0.008210157102439553, 0.032848621340235695, 0.05113040147989523, 0.02059938673482975, 0.0604046796070179, 0.027153276168974116, 0.05469314448419027, 0.04510680810199119, 0.055910062583279796, 0.03179221122991294, 0.1084382546832785, 0.05398890200012829, 0.03132726684270892, 0.03437540835875552, 0.04752204979013186, 0.04953930365445558, 0.017676588395261206, 0.017302076557825785, 0.03133630620141048, 0.020939685564371757, 0.09530672337859869, 0.03654244988865685, 0.025163411264657043, 0.010013565752160503, 0.022017452829459216, 0.02307336199010024, 0.014304743399407016, 0.02239039502455853, 0.058501538369455375, 0.01406471521477215, 0.049843899614643306, 0.036110260189161636, 0.06673171490547247, 0.037582161676255055, 0.0270841618112172, 0.04500835850194562, 0.08350146192242391, 0.03639324480900541, 0.05320555770595092, 0.03561731457011774, 0.022048055288905744, 0.08324341717525385, 0.08040355198318139, 0.05466015230922494, 0.07113442436093464, 0.04354102122306358, 0.030400315117731225, 0.050445469678379595, 0.035075398336630315, 0.0961367561831139, 0.06308912052190863, 0.012592872171808267, 0.06160187142086215, 0.008539774571545422, 0.057650428570923395, 0.019800045447482262, 0.09214643592713401, 0.021871997450944036, 0.0325434873229824, 0.032643124359310605, 0.012379785803204868, 0.09185246381093748, 0.047898838165565394, 0.04121910831599962, 0.0037172769361859537, 0.05924555996898562, 0.04105094507394824, 0.0339273960707942, 0.035764415661105886, 0.07488276736694388, 0.05315978945873212, 0.044642090069828555, 0.07432712140143849, 0.02633327905641636, 0.049946193539653905, 0.03868659245199524, 0.03648677396995481, 0.10557102650636807, 0.030329512374009937, 0.03972558806708548, 0.028635118724196218, 0.07822438376024365, 0.018378481981926598, 0.02288397889060434, 0.06099454600189347, 0.023241443595907185, 0.017959598990273662, 0.05609045270830393, 0.07200111183919944, 0.031190578083624132, 0.051152146406820975, 0.05718340617022477, 0.09183410307741724, 0.00573659002839122, 0.09830448048887774, 0.034083020727848634, 0.0723235378973186, 0.028224315865372773, 0.012270856150280451, 0.03938260822906159, 0.04122195074160118, 0.03149999800371006, 0.05889794170798268, 0.03991301746282261, 0.07295492745470256, 0.10427880639326759, 0.02561294681072468, 0.008672848143760348, 0.0693201701506041, 0.014094003145146417, 0.07356711765169166, 0.04708331805886701, 0.03794702373852488, 0.03661381109850481, 0.05691827762348112, 0.02736261933023343, 0.04532376384304371, 0.0659066322259605, 0.026338759817008395, 0.013077451931167161, 0.04927837937430013, 0.03913720967830159, 0.07260893820784986, 0.02206615998147754, 0.014465267158811912, 0.03318104783829767, 0.02869624200684484, 0.009614971222617896, 0.02759507297014352, 0.059510532664717175, 0.05157091065484565, 0.08719697143533267, 0.0269669952467666, 0.05427689611678943, 0.06176449081976898, 0.059033164725406095, 0.04230053622450214, 0.025664097483968362, 0.047376128713949583, 0.09281318882131018, 0.05830128466186579, 0.06660629194811918, 0.02417853676888626, 0.03900366762536578, 0.023568101751152426, 0.033192502887686715, 0.031949438925948925, 0.1047232341079507, 0.03823433136858512, 0.028953416585864034, 0.06528961806907319, 0.033413640630897135, 0.04974950214091223, 0.04582456880598329, 0.07843509432859719, 0.014567411726602586, 0.010000122674682643, 0.02285062120790826, 0.04265625131665729, 0.051949172193417326, 0.054517274038516916, 0.05715605802834034, 0.02673930433957139, 0.054557884359383024, 0.023669180409342516, 0.05815563446958549, 0.044342663168208674, 0.05550998932449147, 0.0660190601774957, 0.009744860053615412, 0.03678417480841745, 0.04788283746165689, 0.03933807194698602, 0.04471711006772239, 0.019717379473149776, 0.018681762485357467, 0.039629873281228356, 0.052620192436734214, 0.014946246574254474, 0.04188898565189447, 0.002877890983654652, 0.02840119934262475, 0.04165525737334974, 0.041867908657877706, 0.011479390905151377, 0.0645938546222169, 0.08815814915578812, 0.04704176892118994, 0.05001343954063486, 0.06206699392350856, 0.05128781471285038, 0.04326906862843316, 0.008952344669523882, 0.0689182971836999, 0.0603222603967879, 0.10415613680379465, 0.05767463742813561, 0.04591468408762012, 0.045638953961315565, 0.028568269772222266, 0.05252787297649775, 0.06158221192890778, 0.02361070288316114, 0.05556560958211776, 0.014457829911407316, 0.017256297178391833, 0.08195468515623361, 0.005770743200628203, 0.04520263049926143, 0.037342125142458826, 0.04701867699623108, 0.07480708314687945, 0.060992442013230175, 0.023456909475498833, 0.04206254430755507, 0.06063851178623736, 0.05393005340010859, 0.07746503310045227, 0.025474443500570487, 0.06163157588161994, 0.10071555501781404, 0.02100298705045134, 0.0012851742326347448, 0.05971343955025077, 0.03962547234550584, 0.06105745786044281, 0.05837292046635412, 0.05793228141556028, 0.04170335225353483, 0.06369022303260863, 0.05178583291126415, 0.06137252552434802, 0.02705302686081268, 0.031182870880002156, 0.03554334100044798, 0.0565463762904983, 0.026053999608848244, 0.0788563521928154, 0.048496990639250726, 0.05369496328057721, 0.04504075324803125, 0.040823499075486325, 0.02581743261544034, 0.06673249416053295, 0.03713219011842739, 0.07600673518027179, 0.03560508026566822, 0.07612849192810245, 0.013979909072077135, 0.03366439006640576, 0.05594174857833423, 0.013922345315222628, 0.050536701892269775, 0.059118693534401245, 0.0660724428598769, 0.031013202933536377, 0.017594011478649918, 0.042347948328824714, 0.11789265205152333, 0.016471945418743417, 0.036132647073827684, 0.05565002516959794, 0.014834063531452557, 0.038680825964547694, 0.060199271683814004, 0.012993260843359167, 0.021526503587665502, 0.050758882352965884, 0.042569523939164355, 0.04131199551920872, 0.05687309196218848, 0.06787193575291894, 0.0573439661093289, 0.03646205303084571, 0.06663325417321175, 0.07539706828538328, 0.07395586944767274, 0.030024085208424367, 0.01110402374251862, 0.06101275088440161, 0.05714032820833381, 0.043376991743571125, 0.051393700632615946, 0.03184740475262515, 0.03303989506093785, 0.0442016105807852, 0.041366361547261477, 0.028393102511472534, 0.03776624769670889, 0.03499474543787073, 0.025593135178496595, 0.04991500478354283, 0.012132799984101439, 0.0794697149831336, 0.02589466606877977, 0.05008115680539049, 0.061350049581960775, 0.043355636444175616, 0.052448125497903675, 0.018406924791634083, 0.032596832897979766, 0.04050159994221758, 0.05872789341083262, 0.012745706353598507, 0.0423639527434716, 0.024447301839245483, 0.011413770207582274, 0.08096219622530043, 0.03784203952818643, 0.031088024406926706, 0.1254434257862158, 0.050333179024164565, 0.026845537213375792, 0.0256664129847195, 0.0457375223049894, 0.05311339038598817, 0.06039220781531185, 0.03418470609176438, 0.01987936433579307, 0.016329067148035392, 0.051036723889410496, 0.005652603031194303, 0.06085805391194299, 0.061040481232339516, 0.06296291830949485, 0.06122689388575964, 0.03806540000368841, 0.057647029534564354, 0.0018687059332478384, 0.02876825259590987, 0.012000653168797726, 0.012495007940742653, 0.02734794521529693, 0.011431217171775643, 0.02146051552699646, 0.05271205176541116, 0.0754806341137737, 0.03900130388501566, 0.050728702917695045, 0.03503899228235241, 0.03903994751453865, 0.03123354101262521, 0.06103644394897856, 0.06919715917319991, 0.1803678457508795, 0.17703950637951493, 0.1532148293335922, 0.22783231601351872, 0.10784754966152832, 0.11094127388787456, 0.20707953663077205, 0.14520432479912415, 0.0965928727237042, 0.14669621974462643, 0.1400282306713052, 0.21648993948474526, 0.23338352126302198, 0.18294875335413963, 0.12520353397121653, 0.08784445817582309, 0.15873173251748085, 0.1330463428166695, 0.32941922661848366, 0.09195396734867245, 0.09611359375412576, 0.10371418044087477, 0.10065269510960206, 0.10602030786685646, 0.08503007091348991, 0.08514251370797865, 0.21684385486878455, 0.16150390641996637, 0.1917583282920532, 0.17751635110471398, 0.1599193617585115, 0.15126559330383316, 0.1247173678711988, 0.17262346053030342, 0.07629393148818053, 0.16312843799823895, 0.13854334159987047, 0.15326937718782574, 0.1745193509850651, 0.18470007344149053, 0.16740357968956232, 0.11866598477354273, 0.15642454382032156, 0.16618175228359178, 0.1542033997247927, 0.159415042726323, 0.11919461656361818, 0.16996357357129455, 0.11231208743993193, 0.13825682806782424, 0.19089886191068217, 0.1746810055919923, 0.1933597939205356, 0.11731604783562943, 0.1296718418598175, 0.23698038450675085, 0.13572447176557034, 0.08944685891037807, 0.1610800510388799, 0.1405013498151675, 0.15284277586033568, 0.08531385334208608, 0.13964666286483407, 0.13904945662943646, 0.21233566396404058, 0.14434797543799505, 0.08167416075593792, 0.11107054859166965, 0.0758092051546555, 0.18395221122773364, 0.18003048026002944, 0.09753669903147966, 0.1255482467240654, 0.13609048415673897, 0.14832432847470045, 0.15024096937850118, 0.1608546607894823, 0.14320499380119145, 0.12490193999838084, 0.1443511518300511, 0.15087669307831675, 0.20186164474580437, 0.0807550479657948, 0.10741771999164484, 0.11550157840247266, 0.21677633427316323, 0.1976166490931064, 0.20498479512752965, 0.0957104962435551, 0.17770071543054655, 0.1604814940947108, 0.12602464616065845, 0.18249717133585364, 0.1973384476150386, 0.07804620894603431, 0.18085914751281962, 0.19589222443755716, 0.14321318711154163, 0.17204320494784042, 0.14756929711438715, 0.18509569752495736, 0.1832274001208134, 0.3189617721363902, 0.10962462969473563, 0.1217992951569613, 0.12163219318608753, 0.15023722895421088, 0.3229170630220324, 0.17883775988593698, 0.19227548647904769, 0.11523241628310643, 0.17337595374556258, 0.13387287268415093, 0.16418089246144518, 0.16617029352346435, 0.09158396962448023, 0.2698777278419584, 0.12098201987100765, 0.17506217263871804, 0.18618316651554778, 0.1297778353909962, 0.15197624423308298, 0.09978325426345691, 0.1622171251801774, 0.1458225041278638, 0.22118295484688133, 0.18054134503472596, 0.1658936802414246, 0.16119713225634769, 0.09765604379936121, 0.10195808834396303, 0.13416364614386111, 0.06810205348301679, 0.07780458050547168, 0.06792549655074254, 0.07336152048083022, 0.0907808322517667, 0.07265334090334363, 0.155012073519174, 0.34436646674294025, 0.12659804429858923, 0.16118461964651942, 0.24391011422267184, 0.11817231556051411, 0.09254526608856395, 0.16489091998664662, 0.13935906579717994, 0.13049972243607044, 0.16597871552221477, 0.16665396600728855, 0.13194599014241248, 0.22685939009534195, 0.14668185176560655, 0.09408005716977641, 0.1276809861883521, 0.21585449780104682, 0.20769973460119218, 0.1998300600098446, 0.09324782760813832, 0.10384110995801166, 0.08330706376000308, 0.2327898476505652, 0.2700684597948566, 0.1370297314133495, 0.09420401067472994, 0.10549392478424124, 0.2052803777041845, 0.11020002420991659, 0.18941524933325127, 0.17981221462832764, 0.11912851347005926, 0.14390286494744942, 0.10550116814556532, 0.3386008401867002, 0.23638414306333289], [0.06961294740904123, 0.018156950900447555, 0.019447356462478638, 0.012809783384000184, 0.0429423269815743, 0.06956927201827057, 0.03326812031446025, 0.03146195551380515, 0.07713914863415994, 0.03272163987276144, 0.057151404762407765, 0.054665377028868534, 0.02769176739093382, 0.02947923007013742, 0.011005230899172602, 0.051413000182947144, 0.03106391759502003, 0.1417762110941112, 0.03955215557652991, 0.05718870881537441, 0.014724995653523365, 0.031506714440183714, 0.010368649091105908, 0.06666364512057044, 0.08245256234658882, 0.040835514446371235, 0.044832528874394484, 0.08246626239269972, 0.01919587786687771, 0.06274035564274527, 0.023963900239323266, 0.056350215527345426, 0.0455056456848979, 0.07371150248218328, 0.039486390160163864, 0.027595930150710046, 0.031768685148563236, 0.011095895370090147, 0.03196112775185611, 0.010841626299225027, 0.024910852844186593, 0.007495302834286122, 0.019134854774165433, 0.10790386382723227, 0.05265704749035649, 0.015644189152226318, 0.04496190376812592, 0.09704421725473367, 0.0656597048509866, 0.058611773274606094, 0.03055323464650428, 0.03472291529760696, 0.036513001468847506, 0.011325293216941645, 0.025632023716752883, 0.018837119969248306, 0.02622974574478576, 0.02785678949294379, 0.01604778204637114, 0.12197689109598286, 0.028055673938069958, 0.03974859835579991, 0.02669451572728576, 0.023635245706827845, 0.06256783599383198, 0.05739468819228932, 0.05021481389121618, 0.00835894843476126, 0.03177275211783126, 0.03937670815503225, 0.05090340448077768, 0.0733873101125937, 0.030484465387417004, 0.057694827555678785, 0.028953385044587776, 0.011206313956790837, 0.0445109933934873, 0.038277628264040686, 0.04196702619083226, 0.03114851686405018, 0.042997475975425914, 0.03570448352547828, 0.07639289688086137, 0.019596698839450255, 0.029864671887480654, 0.02785969129035948, 0.02681843026948627, 0.02377254488237668, 0.039026911690598354, 0.03964407427702099, 0.037596151159959845, 0.05109098601678852, 0.04737141978694126, 0.044672295480268076, 0.029868434576201253, 0.01377370705085923, 0.017136332717200276, 0.023442511810571887, 0.03133879610686563, 0.020101815680391155, 0.14704140747198835, 0.00962403562880354, 0.03276734132668935, 0.03693326856591739, 0.03526966291246936, 0.016479233308928087, 0.0440292913117446, 0.05290846114803571, 0.05702815258700866, 0.048946769238682464, 0.03199226826836821, 0.03718377309269272, 0.027783476434706245, 0.019675706025736872, 0.060438209839048795, 0.09819444225286134, 0.021499181420949753, 0.01829012002417585, 0.07288749591680244, 0.04616817946953233, 0.01624984844966093, 0.06209932187630329, 0.03357267916726414, 0.03228815883630887, 0.04762460717756767, 0.09754010548931547, 0.019438573144725524, 0.03338451133458875, 0.018179222752223723, 0.0630638949223794, 0.04473024237086065, 0.022586719060200267, 0.07330367006943561, 0.021898057966609485, 0.015125748905120417, 0.04521068651229143, 0.028808951974497177, 0.03476110992778558, 0.026862307895498816, 0.054105682647787035, 0.08490485575748608, 0.017927489971043542, 0.023904238987597637, 0.009105225235543912, 0.03411165649595205, 0.024986752287077252, 0.015224265298456885, 0.04599596781190485, 0.025815074441197794, 0.04415111485286616, 0.025795656147238333, 0.014861540621495806, 0.03692316051456146, 0.05397479748353362, 0.0913473877881188, 0.020921066934533883, 0.03318722992844414, 0.03618274204200134, 0.025912011915352196, 0.042903111898340285, 0.056114891631295905, 0.01842271027271636, 0.036919149206369184, 0.07156845458666794, 0.06252280989428982, 0.043983085197396576, 0.04269423814548645, 0.026925032361759804, 0.06462766687036492, 0.039940039059729315, 0.05570323715801351, 0.02574411399109522, 0.03615484471083619, 0.01094146278774133, 0.07886853825766593, 0.021616032572637778, 0.06093576048442628, 0.02002727436774876, 0.038648134359391406, 0.02502287446986884, 0.05314643451129086, 0.06902245761011727, 0.013015643089602236, 0.02775256598397391, 0.07508230119128712, 0.05434202328615356, 0.09078039438463748, 0.02609808689157944, 0.02793908253806876, 0.026107129961019382, 0.018362434893788304, 0.07042804078082554, 0.029895023872086313, 0.10184284765273333, 0.051108986808685586, 0.027914688143937383, 0.07253150994074531, 0.01817383847082965, 0.021556597675953526, 0.05149783508386463, 0.08617718631285243, 0.03094587900704937, 0.03470294781436678, 0.0677560419717338, 0.03552588197635487, 0.06237714856979437, 0.026834707423404325, 0.05817286713863723, 0.050872378997155465, 0.06473751956946217, 0.04033010445709806, 0.026167991636611987, 0.03768485265027266, 0.015812443307368085, 0.021120296478329692, 0.028383300596033223, 0.01692037702014204, 0.016153606738953386, 0.012910028053738642, 0.06711080393870361, 0.032736275024944916, 0.04519353919022251, 0.022717773063050117, 0.07000762154348195, 0.016746332257753238, 0.051215102794230916, 0.0802443316206336, 0.028308814944466576, 0.015744221382192336, 0.005072130834378186, 0.058219923012075014, 0.050194909490528516, 0.040494671993656084, 0.05131824276759289, 0.039285898965317756, 0.04342945416283328, 0.058997671512770467, 0.04337140708230436, 0.03638043905084487, 0.0068047780223423615, 0.026071098691318184, 0.010474989576323424, 0.06732197463861667, 0.04668994268286042, 0.06260195994400419, 0.033171077084261924, 0.040951007467810996, 0.07022663674433716, 0.057036909929593094, 0.03680607558635529, 0.007848024288250599, 0.03681788315589074, 0.037555344169959426, 0.013357517127587926, 0.07054124798742123, 0.012367809395072982, 0.02944023577583721, 0.01825404237024486, 0.044013928854838014, 0.08783489931374788, 0.028635701310122386, 0.0443292228737846, 0.011984160792053444, 0.06211701467691455, 0.049105607395176776, 0.0471604049380403, 0.08661916494020261, 0.07778313243761659, 0.008866178541211411, 0.027774242262239568, 0.04808186291484162, 0.011794587517215405, 0.03670670572319068, 0.0726051013043616, 0.034434902627253905, 0.030744033392693382, 0.09383708544191904, 0.055069921727408655, 0.004986365929653402, 0.007052705441310536, 0.05301887787936721, 0.04545033341855742, 0.05104738113004714, 0.007851798109186348, 0.08186824721633457, 0.1048706097935792, 0.06751171211362816, 0.04480450166738592, 0.02527601918700384, 0.035573193890741095, 0.022313471417874098, 0.07254313939483836, 0.012428239697328536, 0.015825653536012396, 0.04706886473286431, 0.04056539124576375, 0.08712330585694872, 0.0799607792578172, 0.01173960179585265, 0.05187645656405948, 0.06216030415089335, 0.018125298302038573, 0.07182405766798183, 0.007213404996946338, 0.039591370659763925, 0.03253576156566851, 0.04322853252233472, 0.033704748057061806, 0.054225168423727155, 0.07959275564644486, 0.10357583669247106, 0.03365240067068953, 0.027902368492505047, 0.034369296772638336, 0.031546616010018624, 0.03824210165475961, 0.04412498754390981, 0.03879692012560554, 0.008041720193432411, 0.066093668283429, 0.057264522911282256, 0.017041371211234946, 0.030059643358981702, 0.011463188893685583, 0.05740332679124549, 0.016465264234284405, 0.07080509632942267, 0.03146797804220114, 0.03549721652234439, 0.059463873840286396, 0.054795067335362546, 0.05531610324396752, 0.0583499732601922, 0.009798635146580637, 0.034160515788244084, 0.016227417036134284, 0.019383160688448697, 0.03243477382056881, 0.07286756925168447, 0.03845183629891835, 0.0929413503035903, 0.10266298020724207, 0.08562864270061255, 0.028366238620947115, 0.05217026540776715, 0.02118252741638571, 0.04380271733680274, 0.029562024064944126, 0.009353687000839273, 0.02028156755841337, 0.039513634401373565, 0.03596818343794439, 0.12791571265552193, 0.10473179107066244, 0.10590524529106915, 0.13424900796962902, 0.17621324368519709, 0.15998355753254145, 0.14201590995071456, 0.09632443048758432, 0.1678181136958301, 0.2027922830893658, 0.21865016809897497, 0.2158377252635546, 0.09332797955721617, 0.21566985145909712, 0.06183491692354437, 0.19437980168731883, 0.10401137347798795, 0.24915010726545006, 0.10747154796263203, 0.09361293457914144, 0.16325148608302698, 0.295888400869444, 0.275477321119979, 0.16403946880018339, 0.20513490191660821, 0.11334002876537852, 0.061238263588165864, 0.16867988073499873, 0.11587056680582464, 0.14765704865567386, 0.15278064325684682, 0.11393205480999313, 0.20632631611078978, 0.2162610017694533, 0.22617458074819297, 0.07484582325560041, 0.21998980402713642, 0.17804422590415925, 0.1853122265310958, 0.09423366689588875, 0.11734883591998369, 0.10380868552601896, 0.11597143951803446, 0.13270082854432985, 0.10370681833592243, 0.19021282059838995, 0.17134732275735587, 0.2842986071482301, 0.17267076502321288, 0.15009681461378932, 0.13954233174445108, 0.15338782395701855, 0.07605474471347407, 0.14253067842219025, 0.15615705895470455, 0.10366922113462351, 0.18035650573438033, 0.09178427528240718, 0.23864364135079086, 0.16839654359500855, 0.14209604705683887, 0.11528389164595865, 0.18043845368083566, 0.09823103755479679, 0.1518959883833304, 0.12584526906721294, 0.12473581766244024, 0.15092745597939938, 0.162507186178118, 0.09953764791134745, 0.15485273441299796, 0.20919504342600703, 0.1403467752970755, 0.19725307094631717, 0.21427440602565184, 0.11068369669374079, 0.14081464003538713, 0.12799522635759786, 0.19187143159797415, 0.08181277909898199, 0.14963365509174764, 0.1522125440533273, 0.30660611169878393, 0.13194600498536602, 0.14385695569217205, 0.13765193318249658, 0.11021481521311216, 0.14553526329109445, 0.11618865130003542, 0.1787300148862414, 0.14785581064643338, 0.19947010354371741, 0.14325311465654522, 0.06087884888984263, 0.10184527447563596, 0.12390783318551257, 0.09105761622777209, 0.14258552313549444, 0.11545024404767901, 0.1419313348014839, 0.3385967732174322, 0.1841318406513892, 0.09502294095000252, 0.16506459738593549, 0.180400975223165, 0.08948147267801687, 0.1424434463842772, 0.08681906983838417, 0.17069129389710724, 0.17548843257827684, 0.1425158799975179, 0.12431090101017617, 0.10017865570262074, 0.14009671605890617, 0.19319086626637727, 0.21570358949247748, 0.12840900337323546, 0.12559789640363306, 0.14390491327503696, 0.12102770648198202, 0.2517833065940067, 0.22783984139095992, 0.1340635897940956, 0.11996846136753447, 0.173182119615376, 0.13027096283622086, 0.11959244482568465, 0.09451445846934803, 0.10818310431204736, 0.15558734186924994, 0.13292719842866063, 0.1146559085464105, 0.14170748821925372, 0.1454716463922523, 0.15659804310416803, 0.09593206443241797, 0.07250476293847896, 0.1335553522221744, 0.14593551837606356, 0.1185592268302571, 0.11792771110776812, 0.15234571503242478, 0.0604999119968852, 0.13725595286814496, 0.13998526032082736, 0.09859774014330469, 0.12049921569996513, 0.15107535116840154, 0.19796986685832962, 0.10756879157270305, 0.14370693796081468, 0.07311576569918543, 0.13968231563922018, 0.14214292110409588, 0.1386281690793112, 0.12879894260549918, 0.10282262359396555, 0.1601400616345927, 0.07138722212403081, 0.16742125764722005, 0.08596499887062237, 0.11920217904844321, 0.24538565223338082, 0.18768182984786108, 0.18856543087167665, 0.15802520792931318, 0.16718249389668927, 0.10075682585011236, 0.09988987862016074, 0.14886596269207075, 0.1471105162636377, 0.1003883643716108, 0.08622475055744871, 0.07688857731409371, 0.13510688615497202, 0.10017883381806314], [0.03443709196290001, 0.09368601386086084, 0.06482112250523642, 0.007669636570426519, 0.03295006179541815, 0.03877230308717117, 0.038440514836111106, 0.02042308398813475, 0.04682672421040479, 0.0031047676156958914, 0.000736354750188184, 0.023738920026517007, 0.06707805296173319, 0.018170144430769142, 0.06708179338602349, 0.038844380469527096, 0.0513068656437099, 0.052439861683524214, 0.015796815532667097, 0.025123914165305905, 0.058647177429520525, 0.030239790430641733, 0.02468988393957261, 0.014818881045357557, 0.08044120113481767, 0.038022681983420625, 0.02726303609961178, 0.03322326490888372, 0.07697486682445742, 0.034678672163863666, 0.0419989311194513, 0.07226095258374698, 0.012405736852088012, 0.053454744920600206, 0.07648385450011119, 0.046099935279926285, 0.022716164457960986, 0.023820294663892128, 0.021711279805458616, 0.04326274181948975, 0.03655147440440487, 0.04730130167445168, 0.02592863416793989, 0.05850463312526699, 0.03336466630571522, 0.028929411819262896, 0.009553883191983914, 0.010774105703603709, 0.08124700281769037, 0.03010541531693889, 0.05900541211303789, 0.018444796587573364, 0.04253830178640783, 0.04328315088059753, 0.029398725600913167, 0.07032492678263225, 0.062367812352022156, 0.034389538850518875, 0.021913518758083228, 0.01349216683593113, 0.026658599490474444, 0.007264301020768471, 0.04684678446210455, 0.012582359649968566, 0.027574339219427202, 0.03594236412027385, 0.028136048531450797, 0.027952261225436814, 0.042578336942824535, 0.05416075742687099, 0.043984046278637834, 0.02681022397155175, 0.0665681752434466, 0.01998098105104873, 0.015218041462503606, 0.06782212280086242, 0.09757708670804277, 0.05113557053846307, 0.030543891007255297, 0.04140297540288884, 0.03204748034477234, 0.03833162321825512, 0.05795488352305256, 0.019572428755054716, 0.04096994707651902, 0.11617722222581506, 0.0634878764685709, 0.01315133087700815, 0.031494814102188684, 0.03310901127406396, 0.05455035898194183, 0.03480968720396049, 0.0354801508365199, 0.012051699013682082, 0.03666959462861996, 0.01865274265583139, 0.021688280648959335, 0.05092719402455259, 0.0845541464514099, 0.038222382790991105, 0.02826676114636939, 0.03541140198649373, 0.0406744461361086, 0.04148179890762549, 0.04851595622312743, 0.08004243034520186, 0.025428816261410248, 0.06302108042291366, 0.05324364472471643, 0.042417457880219445, 0.018425471062073484, 0.05778371087217238, 0.04910384850518312, 0.07137572625651956, 0.08553069405024871, 0.04892502060101833, 0.01313668180955574, 0.0409366209350992, 0.018034307286143303, 0.06818273977842182, 0.026317886913602706, 0.04542784263321664, 0.028442043440009, 0.056612275293446146, 0.023558698740089312, 0.06255784668610431, 0.0037519992429224658, 0.010422785981063498, 0.030643058635178022, 0.016760674261604436, 0.015346811505878577, 0.05023212077503558, 0.08589659511926584, 0.03517774421197828, 0.04033934048493393, 0.07706077783950604, 0.03155142141622491, 0.053850840267841704, 0.0681029811676126, 0.06161579040053766, 0.013988025384605862, 0.04364291438832879, 0.04269054967153352, 0.019691376473929267, 0.1028343643702101, 0.06867511023301631, 0.0161100259720115, 0.037853850808460265, 0.06703955034026876, 0.05408286160673015, 0.08345531517989002, 0.02748692535533337, 0.06734380862326361, 0.05527132947463542, 0.07202662687632255, 0.07369410654064268, 0.09979579655919224, 0.07744496542727575, 0.06871724195661955, 0.048720974518801086, 0.01723204564768821, 0.021130708810233045, 0.031019017660582904, 0.015498930442845449, 0.06970060247112997, 0.04890729069302324, 0.058198408150929026, 0.024628309802210424, 0.08819430659059435, 0.11129342296044342, 0.04734113274025731, 0.07809968810761347, 0.011351976208970882, 0.06981527913012542, 0.0186442636186257, 0.006546230006279075, 0.03125445102341473, 0.04323066248616669, 0.056018048780970275, 0.006070337549317628, 0.036885054942104034, 0.055457975904573686, 0.024020420351007488, 0.0566765341500286, 0.06167182626086287, 0.02429835280054249, 0.02898645143432077, 0.008918708681449061, 0.042225100623909384, 0.02895318466471508, 0.04032351789646782, 0.00810467472547316, 0.04423902966664173, 0.05966768985672388, 0.007493157563658315, 0.014367735966516193, 0.042146217747358605, 0.046845366960042156, 0.061441912621376105, 0.027394884200475644, 0.022569228494830895, 0.05564034385315608, 0.04733864283480216, 0.040268142547574826, 0.035562488410505466, 0.004386568207337405, 0.024100229056784883, 0.033109627256635576, 0.02310316664079437, 0.006165923850858235, 0.02893827491789125, 0.026644522804417647, 0.012868386147601996, 0.03026147413038416, 0.054571484215557575, 0.0268272544053616, 0.09107543519348837, 0.00846442246256629, 0.020807494220207445, 0.020312255364842713, 0.014837096132396255, 0.08899200402083807, 0.02117146570526529, 0.03427426847338211, 0.009544080348860007, 0.05852506816154346, 0.07148241740651429, 0.008510192565154284, 0.042132985254283994, 0.06644311593845487, 0.05835324242070783, 0.04510317899985239, 0.032828561088535935, 0.038873851153766736, 0.06261788643314503, 0.05691953556379303, 0.018221721838926896, 0.012564923817990348, 0.0336794519535033, 0.034769158519338816, 0.025668643138487823, 0.027318018110236153, 0.03640770555648487, 0.02342000989301596, 0.04329648727434687, 0.0453254039894091, 0.03893051412887871, 0.054444057459477335, 0.018769679154502228, 0.03110988993284991, 0.01555406737679732, 0.11714002524968237, 0.04898689345282037, 0.04539518071396742, 0.04241931324941106, 0.011277725261606975, 0.07482689106836915, 0.07983130417414941, 0.050579438466229476, 0.04078320416738279, 0.0104196207212226, 0.04212357111100573, 0.04583837275276892, 0.07610465414472856, 0.011669688701658743, 0.03835540162981488, 0.04719548625871539, 0.09385249242768623, 0.047208722462528385, 0.06358657468808815, 0.024916472757468, 0.03340865710924845, 0.03748601273400709, 0.07376659952569753, 0.08894535261788405, 0.011154272706335178, 0.024354249508178327, 0.044655619421973825, 0.04289488890208304, 0.05777211110398639, 0.007553872665084782, 0.04257602515281178, 0.029891075646446552, 0.028963353943254333, 0.035247628547949716, 0.03995678562205285, 0.050449221234885044, 0.035915709886467084, 0.05955652355623897, 0.04934781842166558, 0.03053504831768805, 0.027605809991655406, 0.05399142530222889, 0.017959706601686776, 0.0606400072138058, 0.06110186055593658, 0.036422114353626966, 0.020959836729161907, 0.05407747361459769, 0.021482477532117628, 0.0277187722895178, 0.020925978096784092, 0.02484727490809746, 0.039229644171427935, 0.0195771024300484, 0.03180699852237012, 0.027869431978615467, 0.003774283618440677, 0.044882471702294424, 0.024238272235379554, 0.0243964832770871, 0.0473283640894806, 0.017496380096417852, 0.06701894832076505, 0.038428955886047333, 0.06510923165478744, 0.03511110677209217, 0.04184204481134657, 0.0499369649332948, 0.0059935020726697985, 0.030041457030165475, 0.049168931145686656, 0.06353702148771845, 0.030935954637243412, 0.04365092587249819, 0.04731593682663515, 0.04043328153784387, 0.013794763635814888, 0.00759361096243083, 0.03074184034630889, 0.11655528709525242, 0.03194167235051282, 0.0577178638195619, 0.04682210063037928, 0.02913114796683658, 0.052315774591988884, 0.087783349736128, 0.019839190026686992, 0.03775891527766362, 0.02103277871356113, 0.04608558585459832, 0.044519286893773824, 0.010866387128771748, 0.007416938997266698, 0.05473108678415883, 0.031965228117769584, 0.025441241668886505, 0.030353771326190326, 0.01973438022105256, 0.046474296832457185, 0.024584515667811502, 0.015046009775687708, 0.17030974093358964, 0.16434009798103943, 0.14692493481561542, 0.14613897074013948, 0.12647128547541797, 0.19245231058448553, 0.1369035811512731, 0.09914230584399775, 0.15517225867370144, 0.11779696695157327, 0.08671933261211962, 0.160332411469426, 0.20594979490851983, 0.07419939778628759, 0.09766387345734984, 0.07373873930191621, 0.12665949412621558, 0.133397423196584, 0.07864864732255228, 0.13602152379462495, 0.14837985596386716, 0.1650775849702768, 0.1747446076478809, 0.14455516822636127, 0.15298969141440466, 0.1357777282828465, 0.2128769864793867, 0.0646965010673739, 0.1550023365416564, 0.12837268266594037, 0.1513168608653359, 0.12167572756879963, 0.14091892662690952, 0.15214281185762957, 0.18014952074736357, 0.1559541409369558, 0.0864610577991698, 0.13011018396355212, 0.15100034972419962, 0.15775310690514743, 0.1941147807519883, 0.17617781355511397, 0.09811550000449643, 0.230761899438221, 0.058467822600505315, 0.12360964567051269, 0.1203197569702752, 0.17251378594664857, 0.1214847358642146, 0.06365587643813342, 0.12251954205567017, 0.13478961802320555, 0.1972293815924786, 0.1410105818649754, 0.11986667581368238, 0.13380906282691285, 0.14539234049152583, 0.08389333816012368, 0.20221276965457946, 0.12315634186961688, 0.11633613088633865, 0.07368555699940771, 0.09831282965024002, 0.1282548444578424, 0.18561825854703784, 0.1384246425004676, 0.1459370768861845, 0.2060748467920348, 0.11553252596058883, 0.1235560626082588, 0.10880392568651587, 0.11461669346317649, 0.10777689720271155, 0.06380623555742204, 0.13222773908637464, 0.2036506065633148, 0.1899336840142496, 0.17868726718006656, 0.09369876395794563, 0.11874465984874405, 0.21275646169669926, 0.1389394555008039, 0.15111285931197926, 0.08654127654153854, 0.12014938212814741, 0.13451934268232435, 0.10527629739954136, 0.1938345457892865, 0.12017701228614897, 0.14251838845666498, 0.1791034042253159, 0.15012828167527914, 0.18861162214307114, 0.1390944456215948, 0.18758064543362707, 0.151030941051431, 0.17427166661946103, 0.19035460049053654, 0.17942932579899207, 0.1742629538057372, 0.09823047352256253, 0.20246550062438473, 0.15334604104282334, 0.10690683295251802, 0.20716155879199505, 0.21063973777927458, 0.19183834665454924, 0.20357661443995312, 0.15261946362443268, 0.15421554126078263, 0.10537086927797645, 0.12004257965600118, 0.1983492379076779, 0.2579368982696906, 0.14438382117077708, 0.11175349514815025, 0.16792128706583753, 0.16746854729717597, 0.11516675105667673, 0.18673412210773677, 0.12781872879713774, 0.11735521096852608, 0.12954733916558325, 0.08516289308317937, 0.11838174963486381, 0.10808242455823347, 0.10201922646956518, 0.12579827627632767, 0.1556156325386837, 0.18590793362818658, 0.0674072399851866, 0.11058569609303959, 0.18082080816384405, 0.0831438358000014, 0.10261536401230842, 0.12620573019376025, 0.10054903934360482, 0.10148756671696901, 0.1610717092989944, 0.23487670754548162, 0.15494726918404922, 0.07499423052649945, 0.10418139208923094, 0.0708460331952665, 0.13083493569865823, 0.1536344099440612, 0.22783621971029788, 0.10397857055068016, 0.13293896889081225, 0.21024522691732273, 0.15885430562775582, 0.06619882318773307, 0.25581385125406086, 0.11425607648561709, 0.12681772001087666, 0.17206817079568282, 0.15983869030606002, 0.14622730115661398, 0.10390036302851513, 0.17640724108787253, 0.20159215608146042, 0.08802630662103184, 0.0975274592929054, 0.10793088542413898, 0.17957073461730033, 0.16843273071572185, 0.1649325990001671, 0.128054553642869, 0.16659688000800088, 0.20934860862325877, 0.21094050054671243, 0.27045787952374667, 0.19461911462713033, 0.17948669381439686, 0.13940326811280102, 0.13168785633752123], [0.04644095213734545, 0.05204068642342463, 0.025710585614433512, 0.06108265748480335, 0.048793352470966056, 0.012254498287802562, 0.06857674597995356, 0.03948307647078764, 0.05267553438898176, 0.05298439398757182, 0.024309997097589076, 0.02455942736560246, 0.0499774676427478, 0.02825037452566903, 0.030132531537674367, 0.03270805114880204, 0.0459829431201797, 0.03869255931931548, 0.03563543410564307, 0.07328691237489693, 0.04037509344925638, 0.05575443421548698, 0.06567814722075127, 0.0437713875726331, 0.014627163891418604, 0.007259484946189332, 0.0671795268135611, 0.025519118935335428, 0.03151494856865611, 0.02459498922689818, 0.027966380584985018, 0.0355756058706902, 0.05838467237481382, 0.029109313982189633, 0.08861850335961208, 0.04568331583868712, 0.016393090372730512, 0.012230278298375197, 0.056469159535481595, 0.020158311672275886, 0.014496180392598035, 0.054678691158187576, 0.07697581677348353, 0.02750801904767286, 0.013833510238328017, 0.04516420580330305, 0.02974995441036299, 0.0392161741910968, 0.023126447813410778, 0.0172401257805177, 0.046131595299812034, 0.03919972448784392, 0.023538185778306797, 0.05243863713985775, 0.04784953358466737, 0.04497929599892814, 0.04699532160884701, 0.011704377611749806, 0.03733375000592787, 0.029809111001668498, 0.0664096228138078, 0.02483231135556707, 0.09309843328082934, 0.07016097893938422, 0.061964803899172693, 0.08745880113565363, 0.023292236182896886, 0.022126619041955564, 0.0681363332842011, 0.030279085294750985, 0.04993802620447241, 0.03605980899010319, 0.0768566426995676, 0.02426511942758225, 0.009692563689895906, 0.02547879434132483, 0.04856441475567408, 0.012893952207377879, 0.03250598289014306, 0.00416568372202164, 0.05373202984628733, 0.004398118344397517, 0.0569821320095798, 0.015382526435132604, 0.053337403951445594, 0.03476103571301792, 0.03927309320715722, 0.04348441019828897, 0.02838687774783466, 0.03745152513147332, 0.02356997752940515, 0.05019161806558259, 0.015808393036422785, 0.06775608650059439, 0.04805200260307174, 0.015672724730393384, 0.014841250304016285, 0.07348766332142986, 0.05906778220378328, 0.047869426853139885, 0.01528868371678982, 0.06350528725306503, 0.028501376291387714, 0.04480731440708041, 0.013046354088146472, 0.050798624361050315, 0.021916327787039336, 0.0110975216011866, 0.04017516999738291, 0.026328674030082766, 0.020144915906712413, 0.04597306142386515, 0.018439555169607047, 0.026242302883474622, 0.033565042467671447, 0.03171592215949204, 0.046578498076996766, 0.05248543697234709, 0.08634088924736716, 0.046826739053358324, 0.04639451966795605, 0.03305063764855731, 0.029752338559774216, 0.014359897031681612, 0.0748822107561864, 0.02412978694337653, 0.01261640660231933, 0.014438005291594891, 0.03637993067968637, 0.039830902533140033, 0.04170917811279651, 0.05437939784314949, 0.03676450789498631, 0.03616349073126912, 0.008705736418050947, 0.031057854248501826, 0.041882744189933874, 0.049380840282537974, 0.04177804570645094, 0.014724575412401464, 0.06051947872037999, 0.04912793490802869, 0.0952793232863769, 0.02064039039396448, 0.017299991122854408, 0.025227883488696534, 0.03656665874586906, 0.02497633067832794, 0.023602273940923624, 0.057784853779594414, 0.017316568846581504, 0.05410178637248464, 0.012713394171441905, 0.03660610018414445, 0.03781450584938284, 0.11433720064815134, 0.02597111655632034, 0.017545154041727073, 0.035634818123071454, 0.04600451735313982, 0.0758712412789464, 0.043765665614046156, 0.025734069022291806, 0.04984140228771139, 0.02883500692405505, 0.02692359259526711, 0.010049135962617584, 0.046505236969096586, 0.05560861332924105, 0.029400298953987658, 0.03808243971434422, 0.05258658798993565, 0.023841933834773954, 0.03728088682692032, 0.03620858733484056, 0.01670699472015258, 0.03990475364844315, 0.027833615931740496, 0.02344670494494494, 0.04144208287470974, 0.017019431470544077, 0.03199795311957132, 0.016082709371403325, 0.020357767571113072, 0.020629514219763223, 0.007522847181462566, 0.08989185065729544, 0.03745939189684577, 0.012271845989744179, 0.04478688679228071, 0.005965263353573391, 0.017782758186513092, 0.029899252258474007, 0.05103554758534301, 0.1253384118899703, 0.0039448303141398355, 0.01887476355477702, 0.05858811731741298, 0.051607951245387085, 0.012414400498528266, 0.026925678030238487, 0.022844656195957214, 0.0440398260980146, 0.047562804829794914, 0.03636969646322541, 0.0012331248649388726, 0.03887464525178075, 0.05626225618470926, 0.031695386933279224, 0.03663299561594613, 0.02975252595206257, 0.026591700443532318, 0.018724057481449563, 0.02922390714957146, 0.04492315994866658, 0.06020969514793251, 0.015228079937514849, 0.02196034085500287, 0.021962572864140384, 0.03590894892113283, 0.0840240452089347, 0.028490971380961128, 0.05413654856965877, 0.08588957440224476, 0.011173856128152693, 0.048403142354800366, 0.022917219685041346, 0.045414569322019815, 0.003965370642617927, 0.08706899548997171, 0.06086736415454652, 0.01314025803367258, 0.04474223547731526, 0.02694540988159133, 0.002835387258528499, 0.061217780312290415, 0.016217913835134823, 0.030724646640010178, 0.04976795564289205, 0.030710584796906915, 0.08079358769464307, 0.036083427839912474, 0.028067143830412533, 0.015018458470876794, 0.059042322827735916, 0.04658166704757605, 0.016534660608158447, 0.012251795942574972, 0.08267166660516523, 0.028082812423235737, 0.07933688539196737, 0.03222865714633372, 0.07624028905411251, 0.01468279342589085, 0.04128682929149363, 0.03029420655366266, 0.022137430278235115, 0.019431565415288787, 0.007246312288771151, 0.046260354210971855, 0.02829937668138882, 0.049674344845698215, 0.08580162990256213, 0.03750836622202769, 0.08202535987948067, 0.043651515879901126, 0.011381426484149415, 0.04106165055418387, 0.03782566403970122, 0.03796852004597895, 0.031953513316693716, 0.05261478218017146, 0.012854569213232026, 0.06236223882297054, 0.07569060995592736, 0.025088304064411204, 0.05476418657053728, 0.07359923780313693, 0.06360204104566947, 0.06461263837991282, 0.017221978414454497, 0.010459886871103663, 0.05108713055960834, 0.008576882883062353, 0.07869111301261, 0.039383476541843265, 0.07610990112880245, 0.04705820378148928, 0.07427997275954112, 0.020799623744096607, 0.045780726431985386, 0.03046793590328889, 0.04543970957456622, 0.07390379294520244, 0.055040246952557936, 0.01592943361174548, 0.04547241602267604, 0.03061346178583335, 0.04972424685547594, 0.02233949111541733, 0.019271135352028068, 0.030616001786256675, 0.03085676748014521, 0.010525607758609112, 0.03202256644726731, 0.03327006474137306, 0.03718099746038206, 0.06233146195882, 0.005475221387314377, 0.04450600245036185, 0.057936233351938426, 0.06642917840508744, 0.02162577882700134, 0.02299557934748009, 0.06442625541239977, 0.023134501971071586, 0.043761097695096396, 0.05578671763942111, 0.02800693895551376, 0.005551121757889632, 0.043912243490922265, 0.014738504596607527, 0.04272370511898771, 0.06076007557567209, 0.03738952240382787, 0.028755172243108973, 0.020823379891226068, 0.045306167521630414, 0.028815006044169422, 0.0452850348665379, 0.06311668388661928, 0.0752660866419319, 0.05393475861637853, 0.010910702621913515, 0.05947718796960544, 0.029692571552004665, 0.025740815144672524, 0.024682970833964646, 0.04867981871939264, 0.008986122593341861, 0.01127246343457955, 0.016275216912617907, 0.10985091794282198, 0.03511843548039906, 0.022097953587945085, 0.02485290780896321, 0.03437352701439522, 0.028178059656056575, 0.058599253243301064, 0.09471880141063593, 0.01776322300429456, 0.0536959614692023, 0.16735287616029382, 0.2736246236599982, 0.10670765535905957, 0.24834714800817892, 0.1032174238935113, 0.0880289041379001, 0.10497944575035945, 0.09058820040081628, 0.15984464233042672, 0.1979989738902077, 0.1771765958983451, 0.10921266351942904, 0.10895115294260904, 0.12462139333365485, 0.0911688715859782, 0.08480705553665757, 0.12886986223747954, 0.1803369278786704, 0.1345539267640561, 0.14852429274469614, 0.11138999121612869, 0.14643067930592224, 0.15383765450678766, 0.16699486412107944, 0.08321641784277745, 0.10709993977798149, 0.18662901915377006, 0.12593569234013557, 0.0716901222767774, 0.0889286988240201, 0.11071710818214342, 0.10494591551832855, 0.14410968666197732, 0.11938486612052657, 0.18193615222116932, 0.13827851362293586, 0.10745006278739311, 0.19872262724675238, 0.17364964296575636, 0.14427649177378044, 0.08408377325395122, 0.16970119468169287, 0.13239481137134135, 0.1398745912592858, 0.1710897678276524, 0.11503769899718463, 0.10034308594185859, 0.15035730844829232, 0.08456107068923302, 0.13420715084066615, 0.11270028262515552, 0.17020027415128425, 0.1468304148875177, 0.19690102577442303, 0.15083694364875555, 0.13925461593316868, 0.136882801016327, 0.1439862823463045, 0.14024484873516485, 0.13441894494462758, 0.10830268656718545, 0.09031412526383065, 0.23579551605507731, 0.18390008277492598, 0.14090077369473875, 0.1272150213480927, 0.1277680549537763, 0.07050768806948327, 0.17339311219984666, 0.13713339460082352, 0.15209470584522933, 0.1344034934299998, 0.1956272331881337, 0.11406834280933253, 0.15685871505411342, 0.14776287891436368, 0.13688286038814113, 0.09141876013018191, 0.1726624381262809, 0.10846340606804006, 0.11841358034871519, 0.11476770567242056, 0.11641896198852919, 0.08488075080094859, 0.18380649795290083, 0.11837500351248309, 0.15541832515737042, 0.16618109919363633, 0.11759771514334716, 0.1514767194748856, 0.13178215362131596, 0.10654552577761933, 0.10102296000695787, 0.27429564390331507, 0.16472996299853548, 0.1560229973983951, 0.1578629299183376, 0.2082345707458444, 0.20408666285220534, 0.18625196360517293, 0.17326188564766198, 0.12348426724202, 0.171583310875576, 0.17834249505540356, 0.15802808746229857, 0.23633032251382247, 0.15378001931821927, 0.046945363937993534, 0.11668472507153638, 0.17580325162271038, 0.1499633616185747, 0.13890749862184748, 0.15124793018912897, 0.13706121331779286, 0.10071343247545883, 0.08889171018381603, 0.18621889350470155, 0.13454448664560914, 0.21290929958922789, 0.14297911373432726, 0.17994863621424884, 0.1302335289074108, 0.10915170350926928, 0.09566035674652085, 0.2365153844584711, 0.0675487304397393, 0.16173064737813547, 0.0643927177588921, 0.13243184454040602, 0.13100070180371404, 0.12415262317517772, 0.15661579527659342, 0.14848274731775746, 0.12959954183315858, 0.113180704502156, 0.17292490607360378, 0.14239510288462043, 0.16622127906884998, 0.15383976220618933, 0.12418751153745688, 0.21948416397208348, 0.13343166589038447, 0.18881154188420624, 0.1014283433323726, 0.11525901485583745, 0.08574443258112296, 0.14531346503645182, 0.15245540445903316, 0.07441165202180855, 0.1493071991717443, 0.11856818455271423, 0.10410797884105705, 0.10760229954030365, 0.19612689153291285, 0.09818353268201463, 0.2672891761176288, 0.1125583988323342, 0.07294147973880172, 0.17584421817446128, 0.20064793643541634, 0.13753599487245083, 0.1643943489762023, 0.15071871952386573, 0.09692728446680121, 0.17308798560407013, 0.12847135862102732, 0.2183397870976478, 0.16350593883544207, 0.15355623210780323, 0.18032364343525842, 0.1382011966779828, 0.24104935757350177, 0.2533895516535267, 0.1614469985361211, 0.09756489322171547, 0.13168289879104123], [0.022140346918604337, 0.044709187641274184, 0.019857023835356813, 0.05594897338596638, 0.0681994084152393, 0.027920315478695557, 0.06831546546891332, 0.04489780076255556, 0.00713222239028255, 0.018647261895239353, 0.12081075445166789, 0.032599174373899586, 0.03109991732344497, 0.09391838029841892, 0.011162079172208905, 0.0053424298312165774, 0.03699841799971182, 0.02648670139024034, 0.0059734923797805095, 0.03939012247428764, 0.02725053647736786, 0.03980881992902141, 0.04196107416646555, 0.08899289459805004, 0.012613173621502938, 0.0322596232581418, 0.06824387790402398, 0.038017242040950805, 0.03574570611817762, 0.05128334327309858, 0.04221046176098753, 0.07000885350862518, 0.05570176770561375, 0.054603823300567456, 0.010383361241110833, 0.042003480484709144, 0.010552587609709008, 0.04953106210450642, 0.04641532577807084, 0.03548086700902786, 0.03263374361267779, 0.047017537799547426, 0.02879414241760969, 0.042310941134928726, 0.053119364674785174, 0.014104962810961297, 0.014451778624788858, 0.012212572510179598, 0.04616476559021976, 0.07691590319154784, 0.019329442184243817, 0.08482615841785446, 0.02930312399257673, 0.048179640871239826, 0.04450768341484945, 0.04778803551744204, 0.04801062044862192, 0.06040556647349149, 0.09305733314249665, 0.05024356098147109, 0.015644704944861587, 0.09054770140210167, 0.03834761278994847, 0.054130552016431466, 0.03596586422645487, 0.030025732776266523, 0.03343396805576049, 0.05876967632502783, 0.037607283375109546, 0.040391906804870814, 0.014474845502263634, 0.0474399088852806, 0.07884674880187958, 0.07470413242117502, 0.058649782367865555, 0.07357769325608388, 0.05057098169345409, 0.045567229099106044, 0.03776755758735817, 0.08998484918265603, 0.027764644437411334, 0.035854727611877024, 0.03438239196839277, 0.025626975257182494, 0.07695554872043431, 0.07138575267163105, 0.06290274497587234, 0.0032862210991879692, 0.07368427308392711, 0.06290061501204036, 0.015868304762989283, 0.035217527038184926, 0.13232642988441512, 0.015636925381841138, 0.01809156954550417, 0.01966632898984244, 0.01761197145242477, 0.08316597406519577, 0.05248548521194607, 0.03654660591564607, 0.05049811392382253, 0.030759256696910597, 0.03346265948493965, 0.04206958728900645, 0.05363593285437673, 0.0017324795089734835, 0.06949434478883632, 0.09313463524449617, 0.026438574968778994, 0.018903709169535432, 0.02828710712492466, 0.06575505598448217, 0.047702603187644854, 0.0206721673021093, 0.05443283989734482, 0.03557716809154954, 0.06678822945104912, 0.016735010794945993, 0.018976729079440702, 0.05622867771307938, 0.0710023740248289, 0.012509569805843057, 0.04620485269697383, 0.038884808964212425, 0.02514763877115911, 0.04255427651514765, 0.05493957090948243, 0.052879647264489904, 0.04727082538011018, 0.02344213702599518, 0.05365726217860356, 0.022983491617196705, 0.024811139737721533, 0.03123283968307078, 0.07568093977170065, 0.013257551690912805, 0.049353826107108034, 0.056660013942746446, 0.08365878980839625, 0.039618971131858416, 0.05336369824362919, 0.04930376453557983, 0.011892846941918833, 0.07249417991260998, 0.09040818506036885, 0.056187959780800156, 0.059972693998133764, 0.028059878204658162, 0.04166943239397369, 0.03722675457538571, 0.01838293672335567, 0.05515395139809698, 0.052976872320869006, 0.012063908270647516, 0.04218806374410633, 0.04448695151950233, 0.04018636158434674, 0.013652458674187073, 0.038217102410271764, 0.04124578852497507, 0.045004391722613946, 0.027190489308850374, 0.07223383450764231, 0.010135107277164934, 0.003197198630005005, 0.03821492791757919, 0.04582095083605964, 0.01894250493933214, 0.059664068176061846, 0.025032887897395995, 0.054924568394199014, 0.06430067660403438, 0.05609337305941153, 0.016109048192447517, 0.08223408891353756, 0.023448812644346617, 0.049903308536158875, 0.08232384425355121, 0.066187861666549, 0.03210557566490024, 0.04141481265833136, 0.008815640139800962, 0.05229981841694098, 0.051762035946012475, 0.006496848427559598, 0.0236524524007109, 0.0016207423345804273, 0.10506303384318016, 0.04520020738709718, 0.0796010899648536, 0.036806160933338106, 0.024081178125925362, 0.06574702594662085, 0.03927211728296243, 0.02446992992190644, 0.010932698023680132, 0.04769543775182683, 0.039994939434109256, 0.02797099488816457, 0.028760879358742386, 0.024142566726368386, 0.04685452135163359, 0.04731352484668605, 0.03147809722577222, 0.057246815267717466, 0.030256583377195057, 0.03964224859373644, 0.019646927394205704, 0.02473365209880285, 0.024021550270845182, 0.042822585164685734, 0.03841551559162326, 0.035090835008304566, 0.031186815394903533, 0.02684178194613196, 0.02241557423985796, 0.02757811304036295, 0.0459283433156088, 0.019971908295701724, 0.024284322498715483, 0.0181478670128854, 0.01748703645716887, 0.041020628341357224, 0.0401278989011189, 0.0031922668267725385, 0.02951448394014733, 0.010978594291373156, 0.04960921767633408, 0.024436562962364405, 0.03267627238528803, 0.06682284321868792, 0.0682155427057296, 0.024972293394966982, 0.06686994733172469, 0.02667236632987624, 0.0343488320504548, 0.03459891726379283, 0.05860041099367663, 0.04028669995022938, 0.06137410629889928, 0.07053692868794315, 0.042556269181659445, 0.00787470171417226, 0.05128853088535834, 0.08695989236002788, 0.04165514234045986, 0.0110437186776835, 0.019602997817855794, 0.06707689521135762, 0.057003906622412615, 0.032798563479445875, 0.03485398228804115, 0.0919211124710273, 0.016297772635880392, 0.02045195724349469, 0.037319630646379665, 0.10339401793316938, 0.10100879240781069, 0.017891286152007524, 0.015422306478285464, 0.0767240951245185, 0.04262377122358885, 0.05059700139099732, 0.05722861038520932, 0.0835144123993814, 0.044261038055992685, 0.042265221127308905, 0.025067043388844468, 0.04008316223917063, 0.021730006046709605, 0.0464073439798085, 0.04457081791770179, 0.043889418739126995, 0.04150006687268615, 0.05242465507762972, 0.01555818629640271, 0.03115867315500509, 0.04923340522509534, 0.06914127545314841, 0.020085080250282772, 0.014735574968653964, 0.013993837328598602, 0.08317506537423469, 0.054397420899476856, 0.07188823117758147, 0.0773117202334106, 0.02849733158654999, 0.02037609305261867, 0.05587122970609926, 0.06532287370646372, 0.013597595407190965, 0.03935045468097087, 0.04400313802761957, 0.04943653846567031, 0.04184173682006076, 0.03209805770893581, 0.036936422693543136, 0.03096508949965937, 0.07963514712173492, 0.029228731109469663, 0.0010792181637953036, 0.012998568126931787, 0.053004480214440264, 0.037625978075084276, 0.06621618202188984, 0.022324223282339517, 0.02525154130125884, 0.021331650859792717, 0.028223276858625468, 0.024074890279734973, 0.04114794006454758, 0.058718601721921004, 0.06245487369596958, 0.03088912882958539, 0.007285190158654586, 0.06224856406333856, 0.028146889453637414, 0.012161696431576274, 0.005230080269029713, 0.04523943360254634, 0.0516229314962402, 0.01749007740727393, 0.048508293548366055, 0.09643282115575857, 0.023810861966921948, 0.03966206764744129, 0.03507780660584103, 0.08216381495003588, 0.03838832701148931, 0.02998728767124703, 0.08215274952817708, 0.02565727900218917, 0.011688594913721317, 0.04989913766621612, 0.010526473288337002, 0.03591751701605972, 0.03653478721389547, 0.05592514302406926, 0.01177476289740298, 0.029192838992457837, 0.04559087763482239, 0.025246450168197043, 0.023060001476551406, 0.039384304036502726, 0.052958852975280024, 0.04973985422111582, 0.07004564176895656, 0.02434015983453719, 0.09907956467941403, 0.045876548829255626, 0.03814110648818314, 0.011756797357520554, 0.11548087990377098, 0.1113650921615772, 0.19835225102724507, 0.08028141674003564, 0.16902725037653, 0.137442781124264, 0.14392360055353492, 0.12355530561762862, 0.08905999959097244, 0.07851086760638282, 0.15890529117314145, 0.15727737540146336, 0.07367600555880927, 0.17649221699684858, 0.1312672218773514, 0.1369281017105095, 0.18700145854381844, 0.22978987894020975, 0.0624900143884588, 0.12345823270152323, 0.06711072230245918, 0.22253790870308876, 0.15352902497397736, 0.14786202984396368, 0.15023130661575124, 0.11970011561061256, 0.1216062625462655, 0.09625175938708708, 0.15348152752267197, 0.0968171571730636, 0.10280478978529572, 0.1381982577731833, 0.11321280238917097, 0.19405328639550135, 0.1159424363868311, 0.15173636726103723, 0.17171011422760785, 0.149050178588368, 0.16737583820940927, 0.12126517889555544, 0.10605388262774795, 0.14471933129243553, 0.08311613142723218, 0.15983303514076397, 0.15118547104066238, 0.08600929766544141, 0.10915695791481994, 0.12473921669879928, 0.13338446529814973, 0.15488102508243173, 0.10008697820012458, 0.24380553077207878, 0.13963610952487215, 0.080079448671313, 0.13203966402215883, 0.09582284255884588, 0.14827656385023147, 0.18674917286261916, 0.20007692801300436, 0.15064079401781783, 0.13856404752004892, 0.13431584578938782, 0.06386523629771546, 0.15776514454046264, 0.14751029637409374, 0.16784116480266675, 0.14576046058209613, 0.12985475157620385, 0.1325148463365622, 0.09475996092078276, 0.13413393055088818, 0.15148642676649615, 0.15125453530345112, 0.16905702534131706, 0.2103630651254207, 0.13184191135223955, 0.18451308191288263, 0.11831188385258429, 0.10820595503901131, 0.15176427201367915, 0.16178899502847344, 0.17206561780767515, 0.14384925219928846, 0.15812406199984252, 0.23765419522533193, 0.12593086838023737, 0.2761473320424557, 0.13033805298618972, 0.17174150707433, 0.16444849607069045, 0.1361393026309088, 0.11252291675191373, 0.21752376604126766, 0.13676223170477897, 0.1455311369500123, 0.15286109206499532, 0.1552317343885079, 0.18879064300563186, 0.25660723680630326, 0.10317103966372088, 0.18295638263225555, 0.09210638221702538, 0.10926166753051803, 0.13210020842961967, 0.16037060238886625, 0.10846341348951682, 0.15569367678835988, 0.13614037132356316, 0.10026694159023464, 0.2978304825956002, 0.09197518535074778, 0.14008227386511862, 0.16463621490402147, 0.2893114584730938, 0.223314774048049, 0.13493653357727453, 0.12941350025357679, 0.1633127429522574, 0.22404904011636972, 0.1530410480336286, 0.1442447872250341, 0.1649350777734071, 0.18503945757402107, 0.13294452015543357, 0.1182037232501898, 0.15874776290729642, 0.11383211720385589, 0.13612005132017657, 0.14080077671678737, 0.15722261974588037, 0.08291851976537146, 0.12531742395367473, 0.12662468740018085, 0.2269615393015556, 0.21481580275576562, 0.08567924975068308, 0.14881959330523387, 0.14582278614398092, 0.2780680399155244, 0.17583344219019637, 0.1486898510484025, 0.09620718599762768, 0.07045368198305368, 0.13725850585615262, 0.2870067930780351, 0.09916005801642314, 0.1894677637028508, 0.15112376888282597, 0.0981906201923266, 0.0932513305451721, 0.17062738013919443, 0.1638774579623714, 0.12265295794350095, 0.1464235843741335, 0.12618074950296432, 0.17917356686666608, 0.0998778484063223, 0.09307944914326072, 0.1464103296166286, 0.1441950336447917, 0.1296282184193842, 0.17100442084483802, 0.12790711858542636, 0.10144897503778338, 0.10641927903634496, 0.1992495817830786, 0.1425547240069136, 0.19061975501244888, 0.21267218340653926, 0.1229981159849558, 0.11382214273908176, 0.1925452274736017, 0.13013759889872745, 0.1039115471940022, 0.20344431919511408, 0.08675334524014033], [0.07299243559828028, 0.03393223858438432, 0.014870126342430012, 0.039653109924984165, 0.09315097733633593, 0.049724825730663724, 0.03070945487706922, 0.025180354496114887, 0.06014264581608586, 0.04479954041016754, 0.01098102575269877, 0.021712207490054425, 0.05538997662370093, 0.07661275070859119, 0.046845916149322875, 0.047464492527069524, 0.05007312305679079, 0.06993197443080135, 0.028285951229918282, 0.04552254067675676, 0.01480903181800386, 0.08599553082603961, 0.034238942243973725, 0.05407201882917434, 0.05495747522218153, 0.0050476292926759925, 0.019200223141524475, 0.04698297969298437, 0.036547403724398464, 0.04596646744175814, 0.030891900751157664, 0.021155576323508285, 0.006580235676665325, 0.012029378922306933, 0.047041405268828385, 0.02781988248898415, 0.03496331919450313, 0.052547584418789484, 0.06945777917280793, 0.08007507742149755, 0.012339145796431694, 0.07420680442010053, 0.06927522568730637, 0.016504167615494225, 0.042595907289069146, 0.009647581191529753, 0.017165679091704078, 0.04081494211277459, 0.025179009353450965, 0.043138216860825196, 0.08299061941215768, 0.011945102487516124, 0.023051310927257873, 0.0152319196240569, 0.01820851717639016, 0.016623710907879286, 0.07064638804877177, 0.017988064064411446, 0.025883082998916507, 0.03128676413325593, 0.028143870767962653, 0.031867134748608805, 0.025134619645541534, 0.06708807195536792, 0.03911458530637901, 0.02491685125278309, 0.023175459245976526, 0.01451572856240091, 0.06419731027563103, 0.0676986294274684, 0.07591476081870496, 0.036895177836413495, 0.029964171626488678, 0.05435752675111871, 0.03393177474208642, 0.015351543625001796, 0.07754396050586365, 0.047170976831694134, 0.023932743024488445, 0.036480465714703314, 0.015746817043691408, 0.039610399326193146, 0.010491656357771717, 0.018815590265148785, 0.029565614204329904, 0.04062445506860968, 0.003205689263268141, 0.031100930355023593, 0.042194679990643635, 0.02778245969238924, 0.018387243035249412, 0.009623474379623076, 0.051757605324382894, 0.016152215212059673, 0.03171374395606108, 0.013098065082886023, 0.048028057208284736, 0.03494812743156217, 0.06334514662739821, 0.03411353041883558, 0.0819522954407148, 0.04858948821492959, 0.05922501361055765, 0.056040495037450455, 0.009197135586873628, 0.06468455991125666, 0.018859172887459863, 0.11262529602390714, 0.05768658229499124, 0.02584227786428528, 0.027652778662741184, 0.023709033739578445, 0.002394180928604328, 0.02492028368578758, 0.0693040581245441, 0.00544080568033678, 0.03739603103895206, 0.015342069182224805, 0.0387110128212953, 0.04483095552131999, 0.07740623274003156, 0.05184483736229595, 0.014757077769900206, 0.05914679124543909, 0.022817026037955657, 0.013321702008397551, 0.055504349002148956, 0.03567761406884529, 0.028667877122643404, 0.014366565228556283, 0.0523574461840326, 0.11853578238515183, 0.0270148006893578, 0.0613155842438573, 0.07258107056259178, 0.027165666324435733, 0.06035987986251712, 0.0630183270550333, 0.07394802494673058, 0.042319891435909085, 0.03583717581932433, 0.07630707492353395, 0.034115233647753485, 0.04862128182139713, 0.000867388343976927, 0.02880491469113622, 0.03272948808444198, 0.012139419013692532, 0.05806935609143693, 0.13628565415274352, 0.016449990835099015, 0.03062516545469407, 0.021329112714738585, 0.05326157501258422, 0.017922339466167614, 0.03231159957067575, 0.05051749882113654, 0.06075446122849826, 0.05955774067842867, 0.012598888206412084, 0.09289065419579856, 0.04402234480949119, 0.025102519903157372, 0.05517613419215195, 0.05134645551152062, 0.035818258475046605, 0.03272630798164755, 0.09216322330757976, 0.020011102969874628, 0.029838711561751552, 0.04839902714593336, 0.0409854653844377, 0.1065713376738131, 0.043668511061696336, 0.04171336753643118, 0.0236050013336353, 0.05684118332283106, 0.05018777745135594, 0.03536671727488283, 0.04241000300680753, 0.03326328151160851, 0.032306712528225034, 0.05784030334325507, 0.032373557769460604, 0.032768977762316354, 0.022554880924872123, 0.030505685244861525, 0.02394717223069165, 0.017229090044565964, 0.06960574857657775, 0.024161226174328476, 0.03380051850399468, 0.050050554345943965, 0.03156610480800737, 0.013827001603203826, 0.01850027769251028, 0.08192073190002702, 0.033328627614537254, 0.04268746233719867, 0.051910487745772116, 0.030420469993259758, 0.04168422339716926, 0.01497076063969871, 0.02734679488639813, 0.05097332592413295, 0.023639722712687217, 0.0377836844563717, 0.029012313425482716, 0.03309463216282893, 0.08768051033257507, 0.03573245136067271, 0.0431850909080822, 0.06971839917241596, 0.021371064467530232, 0.05984923031064682, 0.10989944697939791, 0.01842045043304097, 0.0750915112439543, 0.11588158027734607, 0.011471735651866766, 0.1202476944308728, 0.034821223889593966, 0.008963988966570469, 0.032208812117460184, 0.013413583601504797, 0.03511948190862313, 0.05235355733020697, 0.019132427951262798, 0.06373920477926731, 0.05970582882582676, 0.05928474165557418, 0.006526215211124509, 0.06436023395508528, 0.009868272718449589, 0.03270114175393246, 0.01725683338008821, 0.00590496292716125, 0.040857110943761654, 0.020888063627353404, 0.04580510227242485, 0.04002898916951381, 0.02551349716668483, 0.04427134648722131, 0.04342892723798286, 0.06249311656574719, 0.042422359765623696, 0.04298205785744358, 0.01949278146639699, 0.046768191023147665, 0.04150487598963082, 0.052770996844628826, 0.022628223669016734, 0.07431368852849118, 0.03735946171218529, 0.044206527309142984, 0.049374198060831986, 0.019549223652575165, 0.009547711306368, 0.07210913885501213, 0.10879246692638844, 0.037073271014378406, 0.026051301902043633, 0.011309942819934804, 0.037715325233875774, 0.03628982653026469, 0.05168924239114858, 0.02263925754959928, 0.025091447059821803, 0.05122385271533858, 0.045511697899200954, 0.01248173370186123, 0.03730572650965769, 0.05057036942162085, 0.05366007120755967, 0.08277367480332032, 0.031963921937858686, 0.05699545727111399, 0.02355016775254626, 0.01215618227433879, 0.01915740122058196, 0.052269275329308584, 0.019406582869123667, 0.014296152112365235, 0.0479841331980424, 0.040157069015549496, 0.01153292943854467, 0.015302355932362843, 0.020105042167415377, 0.0071531634785060305, 0.021257157786749303, 0.041198387552867644, 0.017334690237476025, 0.03093538874963997, 0.010772692839964293, 0.029073501646053046, 0.026169501907133963, 0.02686420408281265, 0.002496679176147154, 0.028722753377223853, 0.012955793517903658, 0.03189038994605653, 0.0071036696499504615, 0.0528834099532105, 0.041736555940588005, 0.029895669540564995, 0.02286561630171491, 0.07347306527663022, 0.04069214264745824, 0.0522804706270108, 0.020507887347775977, 0.011785724418587051, 0.03847466847219039, 0.114369721559342, 0.0444334649364464, 0.025567970806150697, 0.05607860803138465, 0.006666112367383903, 0.0781183605431579, 0.019733578701561783, 0.05496198376931716, 0.023402439546771348, 0.0567180313373683, 0.01861222139268648, 0.0980295889894478, 0.049919238736038096, 0.11992896426818334, 0.046009059296920896, 0.039925029122969136, 0.04034852456243243, 0.041318826988572255, 0.04128512606257573, 0.06275364008615725, 0.012013828145427397, 0.02494262789696222, 0.046222449018387124, 0.032532336554140784, 0.02658145323948702, 0.05059028495452367, 0.015355964969785418, 0.06847815908258781, 0.03271609231887851, 0.04699787088611629, 0.08800214229268022, 0.027926820403081365, 0.036494295636657625, 0.027945446454396006, 0.0040262731363327475, 0.021606392074318137, 0.05404860778071452, 0.051205506824771874, 0.01052197865647031, 0.046826097095618024, 0.12614528968697414, 0.17071657144697383, 0.10104132074047811, 0.12839254253776744, 0.17771523183910176, 0.14204976672772318, 0.15475668566068634, 0.10271654842654243, 0.19630571943707764, 0.10425165863125585, 0.09127557757892646, 0.12898476154077798, 0.18226734304334968, 0.23060937324771658, 0.17542569141369313, 0.14858149748761207, 0.12809318985091522, 0.11675528847263195, 0.07553870716947131, 0.14217520452803, 0.13007208210183308, 0.12387634385959245, 0.11374023190001026, 0.1277682330692187, 0.2000276790931821, 0.0973427238932345, 0.05800344224553555, 0.09817568075959571, 0.12785727594746277, 0.09557693934766576, 0.09681730560259894, 0.11406531484681182, 0.06710318950354122, 0.1716785432654433, 0.08890183307812549, 0.23235791770275682, 0.14473818184342235, 0.07358256916631944, 0.17627487162826583, 0.25328351359348744, 0.06762983233784325, 0.25178318785037845, 0.1315292890649289, 0.22207262663869187, 0.20826951105846092, 0.0742078508483246, 0.112509179598419, 0.10377552636782639, 0.10551242652582005, 0.11601749720284715, 0.16849732724949718, 0.13991089712362736, 0.09999317073379643, 0.08365224406588823, 0.11251688309130259, 0.18383697053650394, 0.16755116317654029, 0.14691656338982284, 0.13779421773506328, 0.11872823612065986, 0.14119981467956677, 0.11781427383539267, 0.2060179685940966, 0.1566955167800188, 0.09737921529449522, 0.052047002100152895, 0.08669423317769542, 0.14423386281123385, 0.1972651679534465, 0.17123289842857048, 0.19995350885437801, 0.12077856008545496, 0.09664287121267989, 0.15377526957308874, 0.11326271182042547, 0.09825077126151882, 0.14892126753693447, 0.10011403690441512, 0.17014762619510293, 0.1709484332241118, 0.09780923792277463, 0.0936712822294794, 0.14687506249174476, 0.22580766293685883, 0.16587172751314938, 0.12155197444371879, 0.14368654374266043, 0.1118014230451081, 0.1513606624212116, 0.12822187825804576, 0.12390369942295365, 0.1579670829232782, 0.16502756421687081, 0.08820846676826477, 0.08713696137419902, 0.07885791812441312, 0.17584831482963637, 0.1439887165906839, 0.25248959369491786, 0.09110906190471724, 0.14513736823573709, 0.14389683870831504, 0.149726883682888, 0.3431195399025455, 0.11200558044947684, 0.15350616682553664, 0.0605323141644476, 0.22621784795774147, 0.12052107194904238, 0.09677124791778624, 0.07060398173052818, 0.10355683029047213, 0.1090369674784597, 0.09767858282430097, 0.17829440388595685, 0.12217291456181556, 0.09037423922563903, 0.15903041727142408, 0.11771812860388309, 0.10739941120846197, 0.18111567827872932, 0.18789206544170156, 0.08628562150988728, 0.1461456500692293, 0.12191640606033616, 0.11138786125229672, 0.1317260175710544, 0.1302728775772266, 0.10864819341804832, 0.07475573394913226, 0.09839468853897415, 0.33619527239352465, 0.13168560020858422, 0.12546190526336432, 0.14069726195884869, 0.12480998790124431, 0.16575313231442124, 0.10337418774724938, 0.19063945161178708, 0.15109261352336034, 0.11132517945952713, 0.1940483585349284, 0.1229079747281503, 0.16014527151128277, 0.07322035657125525, 0.120014556159731, 0.14918156841304153, 0.15801266563357785, 0.15731859428342432, 0.24737643369007856, 0.143531316134613, 0.08575277432100847, 0.08289751698612235, 0.1260478308540769, 0.15835135214729235, 0.13976887974422425, 0.13053424714598805, 0.1464586879592389, 0.17600790626602247, 0.10895852246903814, 0.19627729518106207, 0.18013157561654225, 0.10720707621658221, 0.10508955077966675, 0.1352968908031471, 0.11935348811675794, 0.18750635645119473, 0.19907680980395526, 0.12677624879870564, 0.09921706980094314, 0.11273876298218966, 0.11410973238525912, 0.14623883413150907, 0.1453253542422317, 0.10118835503817536, 0.15288766095181927], [0.008019627384783234, 0.048636169303790666, 0.020709927775897086, 0.013849248407495907, 0.031132430813158862, 0.01867306822532555, 0.07944771030452102, 0.039346213306998834, 0.04830320103792474, 0.0527855874679517, 0.011109149199910462, 0.020328820100985467, 0.03802197323238943, 0.047920494034769945, 0.025911562916007824, 0.018547107210906688, 0.013639839380630292, 0.01695773116807686, 0.03923093179764692, 0.10669860115740448, 0.02968117216369137, 0.04099378485989291, 0.018604413999128155, 0.07928569946670905, 0.019102105652564205, 0.05827461187436711, 0.06902276931214146, 0.07540386635810137, 0.05672189792676363, 0.02156719554477604, 0.027592072838160675, 0.03908704420609865, 0.04174079731456004, 0.042566458869259804, 0.03516500524710864, 0.030457289794867393, 0.029588999277621042, 0.0850253805401735, 0.036770125952898525, 0.040494972563465126, 0.05791461459011771, 0.009367735856358195, 0.012634418526431546, 0.017619929130887613, 0.034680071112234145, 0.03321260024677031, 0.03080572627368383, 0.05704807183064986, 0.036070944915991277, 0.03578577838197816, 0.02872032840969041, 0.021338933183869813, 0.01384368601065944, 0.06284005576162599, 0.023373137701128144, 0.039104844618123025, 0.02093458329909481, 0.04239875575876795, 0.02257128795463359, 0.014959458658267977, 0.026928704137390014, 0.02518993933335878, 0.02118671684002038, 0.02501908951671794, 0.023641728366783354, 0.07734594066278078, 0.03595393420255277, 0.023658011086808983, 0.05118008084536996, 0.04267411852197256, 0.01541794728836976, 0.046887068237992935, 0.017191852784890216, 0.02307588900293922, 0.07540283477283083, 0.013673395587829873, 0.01640278467675671, 0.05405129435530398, 0.07796984937158413, 0.05509893970156554, 0.034210287922178395, 0.028882545193482656, 0.055929009613464586, 0.07455214057699777, 0.06527181394631043, 0.03606530088291038, 0.020593043227563612, 0.019677648597280495, 0.06589341457583942, 0.061369226677925326, 0.07511852541938424, 0.07845500615076162, 0.06628606264712289, 0.10738440498244017, 0.017787398464861326, 0.014339275530801388, 0.0174053185764933, 0.032852899821591564, 0.05320728691003751, 0.03936133085517213, 0.0316697197558824, 0.056364112242590636, 0.010665560112101957, 0.07170383716584183, 0.06784578989027068, 0.03685245610540733, 0.04749730658659246, 0.036076128817512654, 0.03116737112577539, 0.02503540563338902, 0.0681809066736605, 0.04930993549351115, 0.023102669401851017, 0.026150536323257256, 0.010061566936201416, 0.005577139600063674, 0.056874220026656985, 0.04332302647526376, 0.023930742936499882, 0.03701573230500799, 0.030388136474357452, 0.02462713349814294, 0.0787781817780342, 0.04086804648977704, 0.04388263922010083, 0.036223215065547265, 0.017824324022512883, 0.03528641689626966, 0.05811582937894855, 0.05998690612614155, 0.03383854986168444, 0.12413177624694072, 0.05995086001348682, 0.0009895801758830203, 0.054941737980698235, 0.04996774179744534, 0.12343695532763377, 0.018470029608579352, 0.025510600935376715, 0.034922575287055224, 0.017691607608867344, 0.0284117452611099, 0.05564729406614788, 0.006443394313464523, 0.08051655880990438, 0.10428889960166998, 0.028591382106242236, 0.048607915741740726, 0.03780621234909631, 0.01084795960196061, 0.0038802444487373577, 0.018519415825721808, 0.021163357741897926, 0.03640366456238553, 0.03196484220097773, 0.006031244920450263, 0.042462569326744415, 0.04117645337828435, 0.03424892413022462, 0.06433753907913342, 0.034463890915503725, 0.010880617810471449, 0.016419100793427788, 0.0535268965177238, 0.023566641575598624, 0.050422622662154026, 0.05496934587426949, 0.039654349311604165, 0.08974149153800681, 0.053179463793640025, 0.03771371106267907, 0.020870931148238014, 0.015654189592169132, 0.06697274220641702, 0.031219102529576048, 0.029052728932583705, 0.059052857614005916, 0.06736887095030397, 0.021843367248948198, 0.04295324026315939, 0.013669546624441864, 0.05810317576106172, 0.07637029848410748, 0.03089329598878976, 0.06336990467389114, 0.07339260162552819, 0.0761404330842197, 0.059862344060093164, 0.04711345296527725, 0.027973091455351096, 0.07169111675466411, 0.03771481315197889, 0.06693352712318301, 0.031633269172743894, 0.053454192020581104, 0.03765973095141817, 0.025433623522985727, 0.05244294530712068, 0.048472971029696055, 0.04878634659689851, 0.049989594335784204, 0.016456441953778267, 0.06682215302134864, 0.006446955230785534, 0.032721046154620126, 0.027381301042623818, 0.058877566043520346, 0.029102278422215022, 0.012601846592588117, 0.012316767260927008, 0.08340513857547194, 0.048265191944665276, 0.03377483648364432, 0.06437260555685498, 0.05192719720071182, 0.013403185184870381, 0.02243365852336865, 0.01790113816241501, 0.03378363464435097, 0.027332111494615674, 0.012268572190805571, 0.016612717845418956, 0.03118983964668587, 0.04127301792323124, 0.0634592815185897, 0.02565141232480528, 0.05342112934158649, 0.04202777839964256, 0.01700923436146695, 0.04725090984720737, 0.010022094884334365, 0.0353574292967096, 0.0038296383263514144, 0.03380399175512139, 0.01823503967898432, 0.0420082710479619, 0.03485263900074642, 0.1548412162810564, 0.028043998099747114, 0.03168145311065018, 0.0052610111288231565, 0.07108957637683488, 0.03969441415392794, 0.0437802191299852, 0.055847288022050634, 0.013042031077930005, 0.048609715449856594, 0.02600890671601519, 0.013950521879451117, 0.024996155298140366, 0.07419738656608388, 0.03918183130735997, 0.02761989595455816, 0.01608869293704629, 0.017336013115709648, 0.0715773603587877, 0.034560102940304205, 0.040569265256635845, 0.0337094421411166, 0.041415406376472674, 0.11536819220054895, 0.011736660107999342, 0.026255988086631987, 0.018274980211572256, 0.07643178541911766, 0.036330284710857086, 0.019530630997905973, 0.129199746879749, 0.020563964026223402, 0.11256856625550427, 0.02035315141256433, 0.08336006794706918, 0.04020872991532087, 0.02251821140816901, 0.0708289044268895, 0.021739646545029245, 0.07680146401980892, 0.060970155318500474, 0.0409967089217389, 0.0888852757634595, 0.01691105564532336, 0.02207109526352724, 0.05256637930870056, 0.031074122125573922, 0.044080373336328194, 0.10081345913931727, 0.03214265336282551, 0.04902343680441845, 0.03531530499458313, 0.02367884873820003, 0.05273253504128661, 0.03040283285372425, 0.04391425471112598, 0.019148102110193577, 0.029052728932583705, 0.025618737417971715, 0.02558716274506878, 0.053139573356020264, 0.0699003366753459, 0.020935403372277506, 0.12094981066184118, 0.023683915751462337, 0.03389029610843863, 0.08774440924753435, 0.05084782875201199, 0.04770005019963719, 0.025862987495202105, 0.1038421860721428, 0.07591623769258149, 0.046410149298026226, 0.04482184936932754, 0.08351480573765002, 0.027975787306786515, 0.0118988741087378, 0.05524424108443782, 0.03571675864805002, 0.036212565246387385, 0.043223834727541544, 0.032823536748765036, 0.014382150329765864, 0.04100167388969567, 0.05615151661913842, 0.04882303095655516, 0.029088305636832956, 0.03167831011523958, 0.038330758616211824, 0.011151631588290911, 0.09479447078774683, 0.02171120187995257, 0.017952222042367794, 0.04473710352613125, 0.051178633657400496, 0.046081711843726225, 0.06429770801332779, 0.02414220307400683, 0.07166158669861034, 0.025105623935814947, 0.014431021681957645, 0.0204006971034687, 0.02721287248277804, 0.02648472727742046, 0.013179530633351533, 0.053308990827645175, 0.024045822210609913, 0.14967229129979387, 0.054097155370982364, 0.030990983032097574, 0.0180957237171242, 0.029386498717940412, 0.06652638490777463, 0.07261574370204471, 0.06272318976698443, 0.1408034929772839, 0.15017730795079842, 0.11112888882053085, 0.11451228070654906, 0.23934494121931493, 0.09584801620803773, 0.21670554822776467, 0.1460917849908583, 0.16601393785094842, 0.14350609795656055, 0.22014074202161282, 0.18599184084450826, 0.14569868420949206, 0.17045413318555802, 0.1391830135253258, 0.0864556104352232, 0.1751910540042445, 0.1255016546929255, 0.2650421013822779, 0.10516393624129705, 0.0944521848578006, 0.12460096942959353, 0.11620991383097135, 0.24359404837014154, 0.12459141056751832, 0.16925207659369335, 0.13399253657553345, 0.09324695929535665, 0.15694369096308947, 0.07535365264629945, 0.1177302552969195, 0.13898600300308317, 0.08219698152970523, 0.14396507176570594, 0.12548412516480312, 0.1402100716950372, 0.10066617993288673, 0.12908515927847475, 0.10881492431508377, 0.1212578390550334, 0.14540338364895433, 0.17743894510203972, 0.1086740275786724, 0.13000338891288266, 0.24544174375478178, 0.07739101129118353, 0.11550014605745673, 0.0897034267836716, 0.11531682073837146, 0.12651493860175833, 0.13249252253444865, 0.1772193139186129, 0.15733487700344995, 0.1449777471134439, 0.054384463001042604, 0.1608416880480945, 0.1988591082044877, 0.12408958515152335, 0.07547303452156484, 0.09445410702028312, 0.10679513972718269, 0.194254363887012, 0.23291246528970078, 0.237081850937102, 0.11958268558373675, 0.19993241701740772, 0.1266709974152036, 0.11180379791767336, 0.14930947014363483, 0.14053036778932437, 0.14121106563834473, 0.10626592906191945, 0.0947015464771539, 0.15623866551322863, 0.14713831711560488, 0.06610394702875055, 0.1536312632379122, 0.1042202435201034, 0.21599372470518574, 0.23888164811069146, 0.13078509306069463, 0.0753568513027858, 0.17858937790151685, 0.18477648496627808, 0.23878579231677577, 0.1474663760745898, 0.08435329902567901, 0.2387713352800347, 0.13272079231683165, 0.13245544483652338, 0.16025841934606433, 0.20091637125005946, 0.10562934447079897, 0.2616033749654889, 0.10664030545740388, 0.14322752540465444, 0.17521334812045097, 0.23188816790934652, 0.16659836430335417, 0.18420731707010418, 0.15628819644916803, 0.19879504601703957, 0.20681359543232247, 0.1320409998879768, 0.15399932395666838, 0.13278595288284123, 0.21765091078123078, 0.14521835139021277, 0.09807379872654565, 0.18212214927189052, 0.13412009691819549, 0.16992940509226173, 0.08009238430531695, 0.09568389024934731, 0.18362259375862777, 0.08501251169946045, 0.15958158066496253, 0.0972810217353981, 0.10846827455679886, 0.13419950671959668, 0.11785497321397997, 0.14988806331530213, 0.10987517875037156, 0.10857869870960712, 0.17926189728314057, 0.07481359178200364, 0.09075164358364418, 0.1821286356425844, 0.19515727559337392, 0.19556078128516674, 0.07286600332008675, 0.20943615236319602, 0.15999810362700373, 0.10403579755802639, 0.1486331212799996, 0.16646537143969908, 0.21969938679831102, 0.07514320925110951, 0.09623628560802899, 0.0928136712173, 0.08959723287262022, 0.18361978844041005, 0.14272604137659073, 0.12554646556964144, 0.21942011662758887, 0.2230283644166775, 0.14309511141618714, 0.11394410728826188, 0.09383649914525449, 0.1543129704077728, 0.0910942189511843, 0.20001486962428316, 0.21159878553589806, 0.1707647813600488, 0.10655589358066209, 0.16087483236333355, 0.185435808962211, 0.16641266411170363, 0.10419859507237561, 0.177135985577479, 0.060349593695718795, 0.06783115473808721, 0.13077008683467284, 0.1458382821874693, 0.17997495277086273, 0.17667431035079062, 0.18064252944895998, 0.13615794538054615, 0.26365027762949467, 0.16547041857847944, 0.114204660494579, 0.1097301630943548, 0.14713297365233302, 0.17064581508748233, 0.14412694901693612, 0.19244040653575212], [0.11803530767792836, 0.02013624947721837, 0.09498263490968384, 0.08423508232226595, 0.08553917679819278, 0.013556432186305756, 0.042733753798529506, 0.03492168842058163, 0.06216256027983036, 0.0638997535861563, 0.009763570524228271, 0.06406485175830312, 0.04906503789243288, 0.022388803117792122, 0.0383868686913047, 0.0157657640738762, 0.006655159659203491, 0.024205669687944464, 0.08031626799493097, 0.03214115422451869, 0.046704845008207485, 0.010502209697733633, 0.08798559982096776, 0.04131569883611519, 0.024672823819855694, 0.02599723458843073, 0.06258948444155976, 0.03537939686793834, 0.04126626066863537, 0.0009521412027879705, 0.010528981747484067, 0.02636201501445612, 0.020828153756156098, 0.01841647066612495, 0.0389352304773638, 0.022313308145385236, 0.029978910679346882, 0.0472117949539097, 0.03475423392956145, 0.041037541886908, 0.017736652262101416, 0.027485793580126483, 0.036117128765909, 0.021567139883700293, 0.0075249038582114736, 0.013651331537403166, 0.03342300282383803, 0.04918573336908594, 0.012377488856145646, 0.01960067675099708, 0.05204318375035655, 0.013340069235709962, 0.005965952159385779, 0.0201589944481384, 0.030785326489422005, 0.01613868029380683, 0.0332338479347527, 0.015348729029938113, 0.04260046778654214, 0.04112051770789549, 0.03900728559528943, 0.05534898409678135, 0.033791939276852645, 0.03821002603217494, 0.01398459759002435, 0.07261939506861381, 0.07718341774307191, 0.06946704859728925, 0.005849357048646198, 0.029679339058930054, 0.018867722428694833, 0.021154361056687776, 0.03827445558272302, 0.03709528311446775, 0.04190997358819004, 0.02961913418403128, 0.0829216738929972, 0.04694985764217563, 0.03416720996028744, 0.06833627528976649, 0.046407462723436765, 0.0418756121507613, 0.021233781990304124, 0.04390269205032382, 0.02376666150667006, 0.03455633283010684, 0.08001048088772222, 0.028681833209702745, 0.10534862711210735, 0.04740441567264497, 0.030793966943747364, 0.11521501292008907, 0.04761500378663186, 0.003666124871415377, 0.049489423909108154, 0.026940042298519984, 0.016142096028488595, 0.053223495415295474, 0.025621665190556087, 0.021578756350209005, 0.030545020927092992, 0.008621465549367713, 0.01699970889603719, 0.02806989348755451, 0.020188665512250736, 0.04996779745852109, 0.04164713456702884, 0.025272974526160397, 0.07801814092090353, 0.058282604804844595, 0.04730968794319779, 0.08911988348700106, 0.03661789662146475, 0.011573878364288248, 0.037501293554669246, 0.04985945502994582, 0.03564965365512762, 0.07095781547832303, 0.024108839825203177, 0.09545071487082168, 0.032553153796470724, 0.01857627918070648, 0.10141531864064746, 0.018336474568059202, 0.03304152407508809, 0.008095205848803744, 0.03948102814320009, 0.04930007235088851, 0.08134483272442594, 0.06468179912189953, 0.11748128701583482, 0.05248959299933631, 0.014815552513027797, 0.021105511041241698, 0.04071732000738848, 0.031629424847778864, 0.013483354759955546, 0.027249846280028578, 0.072334647848038, 0.04595849306497257, 0.03823071710939985, 0.08026520823477767, 0.011832587333628908, 0.02003635268920334, 0.08307555079227313, 0.05039517433033325, 0.00918355521207559, 0.03045184799702838, 0.04333552424213849, 0.026083221673616208, 0.0644622569961939, 0.01666959789872635, 0.009186807674268493, 0.07920947347884066, 0.09819601560593583, 0.03992465433839243, 0.05029366337112151, 0.05489601055160165, 0.08186144914361648, 0.015191223028523382, 0.04843721064389683, 0.04734137393825222, 0.01343866726529086, 0.01853163899795618, 0.04069811322551686, 0.015658920783607755, 0.05017706826038193, 0.04034007892187219, 0.05141723042470403, 0.005927127167524304, 0.051894123389502056, 0.016641886104480363, 0.05175970189156942, 0.06461896147811785, 0.05006219864299055, 0.040480133320670575, 0.02570397493400378, 0.06200531031936407, 0.02723817971855169, 0.027522980744834058, 0.06100222723034676, 0.048408868024125695, 0.04477402908378281, 0.020245180057827383, 0.028950698469998315, 0.04031596654385794, 0.034481535476516, 0.041177997045451775, 0.017264123125642072, 0.021367112531152088, 0.031676554935984313, 0.03525431900925469, 0.0648429490684066, 0.036215329746482894, 0.032748757948866114, 0.0563177985168295, 0.05432938822195865, 0.015592051422572695, 0.03353861829964444, 0.07641985910595395, 0.03265933286456857, 0.02738488561590202, 0.006669946951660677, 0.00822256024548551, 0.05910958367167041, 0.021206576711847447, 0.017590083662071265, 0.04700085431977641, 0.013756882563029649, 0.03186695663316641, 0.015941671626933385, 0.0864545491640456, 0.026396838438813575, 0.058555106588755734, 0.02434540681861108, 0.08609961703768931, 0.04015442325908225, 0.025884081187541597, 0.0769978437165264, 0.03980450434028171, 0.01898451791930711, 0.023235200278577395, 0.01975143106392352, 0.054474982753163204, 0.03291471330157947, 0.018850576961995102, 0.07408168574329466, 0.0377491152175935, 0.03843176491500344, 0.04810286940482911, 0.025596007290005218, 0.014394142508535879, 0.012847438101744046, 0.040442068566335365, 0.007761336801195284, 0.023032276694721077, 0.013996660272823647, 0.026493410405237228, 0.03873699912219308, 0.055411246576113626, 0.02182195628847694, 0.0270218158402713, 0.022867553307150956, 0.07235547993332148, 0.027522244163264986, 0.04335403340519406, 0.0631211516156327, 0.062077807015157305, 0.06497485839645378, 0.00642752209387254, 0.03711398894665763, 0.08467830033623613, 0.07655671855900437, 0.04014146907138638, 0.010378323913755594, 0.057184764300473034, 0.06591807614313439, 0.03604999779781792, 0.09146898868493736, 0.04681129124946892, 0.01596316051291069, 0.026134891850233544, 0.033614042768022045, 0.022066853889555205, 0.041013859954546206, 0.06753247740562074, 0.029191594039730262, 0.03255616691603791, 0.047467995464103296, 0.01779387741407845, 0.031111207244975958, 0.07708759905654006, 0.0026241467503496096, 0.05336113041266799, 0.0659310414630454, 0.03155963328026701, 0.031546961108688265, 0.008668706959724659, 0.021556067040364724, 0.02754836776148295, 0.03269160144554917, 0.06277106571360491, 0.010861419377761194, 0.041348780068801716, 0.09360693802591413, 0.11566093977307901, 0.008965112392615993, 0.04133650494622998, 0.058770117902895436, 0.043150299025001004, 0.030764776420255657, 0.049050373054342344, 0.012219224008731544, 0.09281803504563868, 0.01949591332959244, 0.010593890910968184, 0.04421915866259951, 0.030585451277147513, 0.03080977468925994, 0.0038488592554131174, 0.022183519504324067, 0.014263851990108378, 0.05045087993494235, 0.05546537140617147, 0.033021181807271205, 0.0887293802225031, 0.013455233856802806, 0.01405623432219727, 0.0272806936482084, 0.05656154949974734, 0.028658986193477176, 0.028326530009508133, 0.01748646314808866, 0.08207833438063972, 0.023510423889092635, 0.03610299085266888, 0.03612995678849984, 0.07429543911712244, 0.03147806753986515, 0.025295179584645666, 0.02055519184068544, 0.033603129486436956, 0.03256798932852689, 0.005268028135105851, 0.0730264259618707, 0.033613571504247375, 0.01856200582551537, 0.06514221269753762, 0.03217885532649234, 0.0191097423521569, 0.018668244265427347, 0.018339470989303663, 0.03258893273596186, 0.03950426107621752, 0.06900765918544494, 0.049532115954207256, 0.026195256286882795, 0.044977147481404245, 0.02713610287173651, 0.08705623797141016, 0.018127862422261387, 0.032290244271280244, 0.03516139098792337, 0.036625255015678704, 0.06264703057240695, 0.06071455223718658, 0.009597768239473226, 0.016402389483118895, 0.0011581997227949614, 0.0461129896575585, 0.02299644209415419, 0.011071275548601989, 0.2653439773712307, 0.19221256719902158, 0.16350647318176925, 0.2527436753734946, 0.23064573848387226, 0.1829636111506261, 0.09057579911313951, 0.09580100115272216, 0.12862646748544648, 0.11115124973002821, 0.08837135334033519, 0.21911527204792947, 0.12247957740328275, 0.13376940245507285, 0.13188728626118973, 0.1537094113882631, 0.09004761261167005, 0.13620052981423214, 0.13471375568769872, 0.13469282712321728, 0.19312402844661847, 0.11393258915632032, 0.15312249131966382, 0.15265069319866598, 0.11032883878215216, 0.08289613659144379, 0.11540187086211517, 0.1533459816710092, 0.12543425284093246, 0.16657915752148256, 0.08763663456193171, 0.21271012199576944, 0.15144022065214813, 0.09091893109143712, 0.10965344728901982, 0.12877115659648553, 0.17106643470469862, 0.15395950031233951, 0.09447643082239665, 0.14781347854295745, 0.07539784754044376, 0.1925229630433023, 0.18983491900144145, 0.060277401280472986, 0.1469662575982511, 0.08797229311312549, 0.15925537707516924, 0.14990311407018453, 0.07043034143862315, 0.15756139531731606, 0.19695745868375525, 0.17927467706613243, 0.16040674498071894, 0.11395438603358343, 0.1466973329661414, 0.08849199686665088, 0.10853193598450162, 0.22077104804338887, 0.1626758763450198, 0.11635843242402188, 0.22237073251744732, 0.12353376849205233, 0.09904227175866254, 0.2055894525256008, 0.13073281617835164, 0.15617951634339988, 0.20059727743500844, 0.20298626564908773, 0.1603957315091975, 0.22706490562995896, 0.09642410834203474, 0.11438501722295769, 0.11194947408512235, 0.09277958437451161, 0.11206953131477349, 0.1619466271949932, 0.1498736211215146, 0.13995748915476725, 0.06840110188932158, 0.16880701063200831, 0.13076707371510565, 0.14663389418274164, 0.18104674760252237, 0.10874274303205311, 0.10747534775873646, 0.09630816261051223, 0.12682422122452408, 0.12720020808046684, 0.21584585920209065, 0.12789525906555355, 0.15043588704429567, 0.22207966219866648, 0.16159520542714745, 0.08746140607399866, 0.12221899451105855, 0.1703268548590131, 0.10260661409120075, 0.1632589817745611, 0.3073798748664558, 0.13416802481515333, 0.09790983604034409, 0.079627295199316, 0.0946876683156006, 0.13640263146953657, 0.10866786775295623, 0.08336418686667457, 0.08538334805052727, 0.2603366179391742, 0.12727290886687115, 0.16468948626425117, 0.08643848908832297, 0.19058797624893486, 0.1264297845773399, 0.09420901275007054, 0.2101939741987735, 0.1994968208600767, 0.2152241175645031, 0.21831566729815677, 0.14473827090114355, 0.18921881768619642, 0.07930566323921084, 0.10784933823742904, 0.16177231154870242, 0.1333481297479011, 0.1219455873069819, 0.12577568530105054, 0.06783991208067164, 0.12960123392986134, 0.17052247014362365, 0.18456267222063616, 0.15431840292876586, 0.09890208006254397, 0.1380219976999797, 0.1515082607511431, 0.08862201371812262, 0.13711267383769155, 0.13223789166659117, 0.20959819288691506, 0.219666019838769, 0.18835184077033773, 0.2017486750264652, 0.17192940402310342, 0.13456427230266854, 0.08718271477846429, 0.22098760673543438, 0.1043587431195192, 0.12391549214953557, 0.08329256961587816, 0.1290510650142096, 0.10662924745702185, 0.20051800122018903, 0.16005259210942313, 0.10756223098724149, 0.1687839298392646, 0.33713554381392896, 0.26800810941495, 0.12089574520359747, 0.12838598195230588, 0.2032718589180149, 0.12291805309359916, 0.15031657938379794, 0.13242992979940027, 0.15716979367425665, 0.17918539670063183, 0.20319097966421396, 0.14123634318821132, 0.14195754745742306, 0.07864379367674701, 0.13183092756662518, 0.08198824507417157, 0.19473837775876746, 0.09555757671478204, 0.13572196330642328, 0.1403990076505579, 0.1018559985095635, 0.1255339232739061], [0.006132165408416768, 0.04601659209583886, 0.06587475698324852, 0.057313211509608664, 0.056305434336536564, 0.08528628255589865, 0.027910292774322443, 0.042378016441944055, 0.03592792563722469, 0.04275682345905807, 0.031088605137483682, 0.04851113226322923, 0.09035172988660634, 0.0784022914012894, 0.04571338766254485, 0.011998575155303115, 0.004384636304166634, 0.02300376338098431, 0.027900286768272053, 0.0702040086616762, 0.04685084772063419, 0.06419359953724779, 0.010517598129808903, 0.03887976607074961, 0.0662013835972175, 0.06343807093799114, 0.024643653705425095, 0.05409435376350302, 0.04626032823580317, 0.0604957745235879, 0.05048518942203373, 0.015173129468166735, 0.05166266608284786, 0.0326456921902718, 0.10936239923466928, 0.028681135590886697, 0.031673653138568625, 0.03137589977995958, 0.016205590472964104, 0.04757119109854102, 0.03547582782630343, 0.032637157491990365, 0.020288423147576395, 0.024703211056475993, 0.030043503502383828, 0.051475166183081456, 0.053087400374352, 0.03380278947588522, 0.006312451168923872, 0.0050790309524018085, 0.05494072123838123, 0.013004968222958269, 0.02234702948044287, 0.030657326424261555, 0.04011005396023393, 0.09276115684770048, 0.06241632654564455, 0.018194570366176777, 0.052119988613412715, 0.05725156130210962, 0.04689522444095928, 0.023594928534294013, 0.02801179260131903, 0.10080467953230254, 0.05577858741162345, 0.02670797643077094, 0.06763709796359763, 0.07939924063975923, 0.0633157130505424, 0.03980828929343261, 0.09232983546098694, 0.03690277742862236, 0.0500933725561481, 0.006377457275448251, 0.08495936650433578, 0.023848820965213235, 0.037732298151240684, 0.010485356451681582, 0.03296071161457803, 0.031312798673752695, 0.03132013480353635, 0.02752076728938846, 0.03968332275690045, 0.045950106796226464, 0.04908868271741085, 0.017591154210094828, 0.021198452050157357, 0.00897905827514478, 0.014332107311929576, 0.038180314149940386, 0.08112445939332247, 0.03763140688533895, 0.07281977494130842, 0.03962778784625698, 0.014914365765434923, 0.05491349184012506, 0.03424149523198139, 0.033888715333887376, 0.015560343163087964, 0.03141999819490593, 0.06443755090003833, 0.015665062055632006, 0.026255724624206778, 0.0322285495349206, 0.04604026660672389, 0.013002839186810888, 0.008694071711943252, 0.01843172180088004, 0.04072691597684752, 0.040670423695701174, 0.025068139912036713, 0.029262458010634873, 0.057528107790858485, 0.025616202983655967, 0.037849271757295355, 0.03554901100869756, 0.043109217440360226, 0.023085967368388083, 0.031214241462294012, 0.01531982330561732, 0.0276497210143134, 0.015528095918853069, 0.008342875371454284, 0.057985623279819265, 0.062155717678251676, 0.031050540383148473, 0.01263774613107671, 0.009453935381316114, 0.04432236913999077, 0.04482605363591574, 0.013664872021763586, 0.06433270027628168, 0.04138904529099818, 0.018157808081014082, 0.046825421741232276, 0.025709403744258452, 0.025047370909305755, 0.0654230487998575, 0.01697184496151749, 0.03408843469514977, 0.025796659901970997, 0.052828442785539664, 0.007470569371434976, 0.025646798021625727, 0.0249081514266436, 0.031837433998589404, 0.0556242281163577, 0.021445026904984843, 0.027944014109380078, 0.05054462802945636, 0.041499157741782255, 0.08220714895287529, 0.04454010784684215, 0.04339871069532819, 0.08597392690717243, 0.04232342034811154, 0.04335391095082741, 0.04621045591193251, 0.033245084050577134, 0.0506919962936081, 0.06258401481318288, 0.042338482235209085, 0.012957791750523029, 0.06778391703846864, 0.01386780302709667, 0.021529147488763556, 0.04582494730129838, 0.06033192315953784, 0.07630765379872173, 0.00914491714866017, 0.032098977972054854, 0.03609176215832122, 0.03216664328647312, 0.07757596933515742, 0.027413280186010525, 0.05818340563564561, 0.02075888911349466, 0.06524801327032037, 0.016076085703389253, 0.05301745666656643, 0.02210960901720682, 0.022776102159696165, 0.009516722002445022, 0.013545740621339064, 0.06415689291316085, 0.03726344264578074, 0.02074481984891463, 0.073684562521521, 0.04588114643411245, 0.05349472812667955, 0.056836763833416626, 0.029812550856149755, 0.03591813670936972, 0.023685776686761528, 0.03001553752255859, 0.022382721217582002, 0.03950294747482985, 0.0518460878811311, 0.021626736197504215, 0.03743590663361829, 0.03481628489680588, 0.047306092237704434, 0.04391667782329023, 0.007263817233251757, 0.0588345511641819, 0.05996849344228394, 0.0519377579621505, 0.02214263273344841, 0.05929128368734382, 0.05095690219604876, 0.0379926101595629, 0.01871765089163091, 0.04458434726984706, 0.07097132998751476, 0.025044142566912342, 0.04194280249066651, 0.039757032864145, 0.023195256035251077, 0.0245337230808218, 0.07652492495253682, 0.06343985951389186, 0.03612974898715038, 0.0254537913860986, 0.03426806040806696, 0.03200802406354342, 0.01667276501393644, 0.05495051387697458, 0.0630380681832321, 0.02235743624623865, 0.03728683885128703, 0.058165000373264775, 0.08289574325317517, 0.01628883161174599, 0.04109413806872908, 0.06195119291078299, 0.03136268955131527, 0.04013636309537105, 0.03456042948528193, 0.07112342573236674, 0.059396794822532684, 0.05606934231764171, 0.05891135602723807, 0.09099523871554993, 0.04072512369020842, 0.013919526081735967, 0.08505911857355386, 0.08214955087169074, 0.028463343078328762, 0.0510185524035478, 0.05619779694825411, 0.06913490782608278, 0.005955422939223354, 0.05859797674929723, 0.016578413924435154, 0.06250234888284467, 0.05801596969831735, 0.016582890930294525, 0.03237077842641156, 0.033949523203773424, 0.03441823399043642, 0.023779808652761858, 0.023509366328653414, 0.06061857027816586, 0.03614690744143445, 0.04688820743467659, 0.017623211278987583, 0.07227248555864207, 0.07805866960552521, 0.06762551303836517, 0.05589970220171381, 0.018050745857181028, 0.03742921617231332, 0.04841723573917989, 0.03625690114859026, 0.036385455969139, 0.06018475898599718, 0.04191067120700609, 0.023469043590012006, 0.013077480689389631, 0.01702148721960839, 0.07131622827728279, 0.04759727758937515, 0.022207848960533738, 0.026045557679026388, 0.03269464425102342, 0.0511556382116396, 0.0031078758229341474, 0.044024315211572684, 0.057016081555048004, 0.007584521044918802, 0.013884102445445023, 0.006804368449593312, 0.01954322895471705, 0.05888635678275023, 0.0435211427975446, 0.013114035173202865, 0.05162528781511355, 0.042192683613393456, 0.045979610877111554, 0.03898753333487548, 0.05009084183257073, 0.04651316310628317, 0.007914434445410734, 0.034348301414866, 0.041813913703663275, 0.03555454000888858, 0.052768518071388826, 0.023720292119833175, 0.02939537851489149, 0.016604669253865723, 0.021267603515298106, 0.03467413022008259, 0.02224265568656847, 0.014850641255179653, 0.04051869902468752, 0.0038478988699353067, 0.02502587274648249, 0.03102657457930036, 0.007676836330574588, 0.028390751758706756, 0.027967619971605018, 0.06107485380198341, 0.0474659805331612, 0.0263844167420757, 0.02712466080993181, 0.013546780555770965, 0.037861480086576194, 0.02366135817283066, 0.08389371665543877, 0.0677595820161514, 0.060332357315928675, 0.039918843322084285, 0.005482140059029916, 0.0044361014624882955, 0.01142813262049458, 0.028844343141827267, 0.02793584491882939, 0.038365116342902184, 0.05403236216807272, 0.00718052089723642, 0.015668924934288952, 0.013062775033176877, 0.025220979659934528, 0.04635680001229048, 0.07273727780557238, 0.02393731650954578, 0.03335495159262791, 0.061569947938551195, 0.07621447715791874, 0.026172364741796628, 0.021535420492000412, 0.015614356670994312, 0.09323967140517198, 0.10286409480613656, 0.14721955260029063, 0.1408445931156166, 0.14926364994607866, 0.22734203841537237, 0.0839595971046947, 0.12471074791392311, 0.08226951904362068, 0.08332001423696056, 0.12006028729956597, 0.2002504124538973, 0.21108970191562548, 0.2040170197142288, 0.10975642770063132, 0.11048106069210917, 0.20112878875806928, 0.1048582604562398, 0.09715903492178768, 0.11509192030644044, 0.1678230712423101, 0.16067311662482098, 0.06690238660667092, 0.13411071617156267, 0.14258866984164342, 0.1927146449452266, 0.09407997553353198, 0.12866755278082564, 0.1627794504747726, 0.2440860032220371, 0.18436782876960933, 0.17104509053751826, 0.2631548198405653, 0.17159374547190964, 0.23790443257894367, 0.15071003639604896, 0.12396765770972706, 0.15512534009758383, 0.16907825076486915, 0.15627728687832132, 0.16057441098382697, 0.11235424884944223, 0.07733764345175587, 0.12423987747752108, 0.1263774631661363, 0.2072981436504051, 0.16072962374892086, 0.1058352310792543, 0.1506875196355395, 0.10103971028001979, 0.21013320714700967, 0.1419948329566978, 0.10289161364198662, 0.1085622378741391, 0.12001506824162789, 0.1311221913783811, 0.09358228388009593, 0.1138303434709087, 0.17458770278608426, 0.16025221499148756, 0.14093010337091982, 0.13621158781461418, 0.14192946458933875, 0.23178552888566628, 0.19713557412615046, 0.26414395426400006, 0.09897728930809535, 0.12078529136488214, 0.1245452935108915, 0.19295839592814445, 0.2068902741302736, 0.18352774728555232, 0.1800313263083808, 0.15848087175982073, 0.239337311941199, 0.08234333305153996, 0.15121719043236226, 0.06061323052563239, 0.1897277231910266, 0.24282834492623806, 0.1298244867939502, 0.09315546732977964, 0.14178462704876438, 0.15487102093175054, 0.12944805464940146, 0.08405167536693625, 0.14219283795682713, 0.10288268560543656, 0.17396449169609696, 0.10340506109059788, 0.2902153052855283, 0.25339875428471714, 0.19260069559095427, 0.2248184839845635, 0.07129532197723165, 0.10662414890248328, 0.13951666827779263, 0.16825967672048137, 0.1082670857431367, 0.0951216540124733, 0.1846838352503255, 0.08448635126114823, 0.1329186637303792, 0.11830746065243147, 0.10712366623920389, 0.17296134552452713, 0.05856840958585963, 0.07476886254153214, 0.1354756296495907, 0.11697802925482392, 0.13072843750705943, 0.08472682937281206, 0.15792550781043246, 0.15604410407831892, 0.09510903008049354, 0.16443264379631728, 0.1014593279978726, 0.12733177602058277, 0.11935419315705076, 0.05544804225792177, 0.18846249498892576, 0.1410572332679294, 0.1719164609676227, 0.18871537438826635, 0.1850038641714491, 0.14133810647763312, 0.15224626724375412, 0.13297395373228937, 0.13590904389275238, 0.1691251396550797, 0.19042329367948696, 0.12412048075930215, 0.12134352742577903, 0.11970771520282142, 0.18355722539126873, 0.12119630759116262, 0.10189564403844997, 0.16307151527144015, 0.22640348877757788, 0.08391285664401948, 0.07516917699831538, 0.150096220895648, 0.09562056278809905, 0.18340092909056693, 0.15364215796580538, 0.19680991972563788, 0.16868615930434316, 0.1328316394938156, 0.106820521177724, 0.09425971627933905, 0.12024668511003256, 0.19149381201714277, 0.12859589100116864, 0.1937275577802211, 0.21142074430827051, 0.13781140587525442, 0.12193677059258334, 0.12366043083602563, 0.11147815836011432, 0.11905722276424058, 0.19178949849447235, 0.12720936618279666, 0.11962610122282058, 0.13637328695040196, 0.15882420411799103, 0.08374023309443146, 0.18289888103026897, 0.1102887479646597, 0.17747550329659134, 0.10215217480435967, 0.09913699948810972, 0.07951966894324869, 0.14429264090722427, 0.18611631385283545, 0.04386033026094083, 0.10122341409442015], [0.03888363266014494, 0.03147696545056533, 0.043585082530626096, 0.07161674613598734, 0.005694473147741519, 0.08830914652207866, 0.08692431380040944, 0.027695928984030616, 0.005866604560651467, 0.01631446910323575, 0.03530993184540421, 0.07414545849314891, 0.008535919114365242, 0.09291636961279437, 0.04000655404524878, 0.031048215605551377, 0.08338881874806248, 0.050513955065980554, 0.02731807006057352, 0.05978393615805544, 0.013444125761452597, 0.037648710058419965, 0.045679130125790834, 0.026373833716206718, 0.02831586720276391, 0.06275375140830874, 0.010499909967620624, 0.06847637050668709, 0.0441403500008164, 0.03490461902401876, 0.08739352182601579, 0.018208628498541657, 0.05680024274624884, 0.028895697905682027, 0.039914253138704225, 0.031052046942932066, 0.05399968911660835, 0.03873724032018799, 0.024225561101047788, 0.05752715042035561, 0.00931386335651041, 0.05713355240004603, 0.011999398011539597, 0.04366053668491077, 0.039799242513254285, 0.058863212907454, 0.03812807066424284, 0.03397569504159037, 0.05056001646153163, 0.09307333384640515, 0.035030802682740614, 0.052465647604549304, 0.01831434743507998, 0.03830717316304799, 0.033875197113957256, 0.05628265411360189, 0.034686761573539115, 0.017743155331118032, 0.058460248983465135, 0.052791584021179006, 0.040466110440320335, 0.01347368457572884, 0.04918616010400001, 0.060632667373283766, 0.060143592054373585, 0.024888154257496353, 0.07804242399288341, 0.03468884700851049, 0.038000922213541344, 0.07528154557803646, 0.012303119165153475, 0.018723315333772916, 0.037252785405144095, 0.015149138616834534, 0.08072321725194342, 0.15266234491718933, 0.04535065185336862, 0.014275987032306148, 0.03430800650676247, 0.009192435009026667, 0.06281152018345892, 0.028622995741898194, 0.042363407264929265, 0.019370740847080015, 0.03871551394695416, 0.04106430373212788, 0.01856656075688079, 0.028150232828920707, 0.05124041003000457, 0.014745991938980296, 0.0679913250496611, 0.021092677452543285, 0.06062890468456317, 0.038403251601266675, 0.007671030880374019, 0.022315315654850565, 0.05897760755033232, 0.056506226101191714, 0.023137027128541376, 0.043284542407491244, 0.03481376901618205, 0.01623368818400195, 0.09642485048971139, 0.03819943929556757, 0.07146017524064519, 0.02501265138562303, 0.07793476062943228, 0.011226861242903396, 0.009082265041797655, 0.028167764212412294, 0.04807879784493707, 0.08095711993519217, 0.06804523465689272, 0.044297978456597775, 0.07117752087651752, 0.07030172724626027, 0.023917811013234314, 0.04761947893712204, 0.04410917608765885, 0.07585694009321742, 0.08237943853600882, 0.0979591443319805, 0.038722931712982245, 0.008707132583367638, 0.01932723058416741, 0.020296503280405886, 0.01666485557507258, 0.047271619478124194, 0.032176165041164495, 0.00433897010225337, 0.026562719576759264, 0.050664726077229716, 0.07353893088293262, 0.05785150235169567, 0.03278504897025414, 0.05051319436461199, 0.02370104266447015, 0.03602711367420852, 0.03134925296762958, 0.06384140593581833, 0.0211993055199855, 0.013133483153069392, 0.037259898890624754, 0.04434750939253718, 0.043569174595177174, 0.08179729047697037, 0.05562223173910752, 0.013194927414588165, 0.06780644864193164, 0.03916818321158644, 0.06777649556170218, 0.0442475792078767, 0.03194952427293174, 0.05784579894680064, 0.07470428827218711, 0.05670681377523579, 0.051683071433217265, 0.07950330458697863, 0.03851788744213991, 0.06433733127778396, 0.013960604883322958, 0.08372193173272535, 0.06409690511645749, 0.07400358212180436, 0.0238879803873715, 0.0400162427831674, 0.03647557125077583, 0.05479281120642554, 0.053170157261774875, 0.030956697664805688, 0.029686487796425354, 0.00825163295303355, 0.04746605103719048, 0.03293963833129965, 0.011986115423496813, 0.05282411235384643, 0.019327328918734565, 0.03024790210474748, 0.03541123871400487, 0.03842630270810332, 0.05774665543867741, 0.07371237079496495, 0.005990970421407837, 0.05526053122594021, 0.07080528186634183, 0.031743218351039104, 0.11701721465215087, 0.058640075076255016, 0.01875481950264657, 0.10868092955206521, 0.05677565168298315, 0.03236416960135102, 0.020868934770987835, 0.014807392599323066, 0.04106394750124309, 0.04611485986970365, 0.015050087877170881, 0.028220415879331995, 0.038392991409637034, 0.019181359602953307, 0.050071427249349654, 0.050631904596230015, 0.0667258445173502, 0.04532168211881071, 0.01922176768857753, 0.05587073617789429, 0.02251841920951847, 0.029483723774319515, 0.07386657423921861, 0.002358625329179631, 0.014458058121817885, 0.018981287721544504, 0.015176154647633666, 0.0883001294278074, 0.03709564305609092, 0.042926211244775914, 0.038389688852475956, 0.028611414527404122, 0.013444056185107911, 0.06283571419771761, 0.06136061034339946, 0.0528035363095114, 0.01784161606337875, 0.07708406643359922, 0.02619333412440028, 0.052064134579268284, 0.017240313172806054, 0.06857258253148757, 0.039202733896672726, 0.05261080797936302, 0.015965104939823505, 0.059436065566842444, 0.052646323456428945, 0.01246237292434671, 0.03946477510908153, 0.021600007748929784, 0.008312986301461933, 0.020953376333636697, 0.048553783490206115, 0.03577751085686032, 0.013405235367827117, 0.0328596199688036, 0.025607044881326146, 0.04106052620045375, 0.008213626642827876, 0.01292569571887725, 0.023304711685341317, 0.060618113857344724, 0.03840360412141308, 0.036852200064458884, 0.05960037335171364, 0.10789721418404952, 0.07629872576217167, 0.007271340755323763, 0.0473464019887615, 0.02008134910283843, 0.040097875316860154, 0.039023315985105, 0.034395976981613785, 0.05131544858159032, 0.008763186997384764, 0.005453097501231241, 0.03837759926682338, 0.028454017992771696, 0.04583383823046461, 0.04128088468860369, 0.05618050119664986, 0.018652993130672257, 0.017462909236201085, 0.06974599964451045, 0.05322965524101164, 0.025458567106397822, 0.050621577611309476, 0.0781319715315476, 0.024131529135047458, 0.04412903595948592, 0.03685110539663583, 0.0032571119800195447, 0.08266236749477684, 0.025780855867196806, 0.08705255691893399, 0.03386570133443456, 0.017186171644425485, 0.05841472193424124, 0.057419605800532736, 0.005472443899634527, 0.051683876663446426, 0.09600826815585606, 0.036649630856118165, 0.009596443505870411, 0.007425933827107656, 0.0605904094845755, 0.06520718030515127, 0.020772806237800978, 0.016511303365405183, 0.06941406667465344, 0.06258471243199892, 0.05503592394234147, 0.032299829108524136, 0.03486052060907241, 0.06065119137929287, 0.028377068410918582, 0.041683377348817885, 0.030712184125150088, 0.02703294620005181, 0.04932587682560552, 0.013993061784276506, 0.019948842345911544, 0.04990090768842492, 0.012583365260070423, 0.016170648304978386, 0.05489999217388686, 0.035264371399534866, 0.007131145348466816, 0.055744225974194705, 0.03966354452131782, 0.008227972357417457, 0.03933222011255566, 0.025581130939826835, 0.06130461901193485, 0.07462257781298831, 0.0630194328550715, 0.010409049755253363, 0.05524788131879177, 0.04743910365505144, 0.05800111932330765, 0.06076621684769634, 0.0555503732903162, 0.06243534779059701, 0.07754798294627108, 0.035438067352515645, 0.016067168799054343, 0.028950551895832177, 0.014261772121244576, 0.1364184689009562, 0.021492800806299783, 0.029137263263692148, 0.014083135320106521, 0.05664058822731022, 0.02338757989491569, 0.046101712723611854, 0.02031164494837867, 0.049808276526164263, 0.023582456742587965, 0.019396307834540494, 0.0014582441144739278, 0.017455285524192732, 0.024162981353583746, 0.09189452131977305, 0.0464624744199682, 0.0018711196526055573, 0.08591684832936153, 0.10997841891366988, 0.15931158734019846, 0.10301875096047297, 0.19052207353524864, 0.15716554858954623, 0.16312794818077236, 0.2130950294667855, 0.17038166988641024, 0.13498180458554998, 0.18282620992977172, 0.11926677558221854, 0.19012060132808983, 0.0474268953257706, 0.24076082539977506, 0.12524294201284647, 0.13482912996551022, 0.15846506401430815, 0.11000458704074845, 0.14999160775914788, 0.11173058504937217, 0.11696466317516752, 0.10298355831764638, 0.16443213913589716, 0.07999062843737192, 0.1696131017524749, 0.21461941563757136, 0.1279342218185775, 0.17759025417035446, 0.12210222499561496, 0.1611565367784351, 0.1291083439718932, 0.10542797754169442, 0.18368374672718346, 0.16135449724970385, 0.15987309627234936, 0.09087596816243604, 0.14688799070427194, 0.18096947518642992, 0.15213384671369568, 0.17874928103992715, 0.15253534860676154, 0.19727601815247908, 0.138930713001173, 0.09333842899650335, 0.20348040241515264, 0.11263452091952786, 0.15608838060870767, 0.21179003699216992, 0.1138897672353778, 0.19921842642361298, 0.08799944087513722, 0.13640496181324124, 0.07816981364157982, 0.09225040339515544, 0.12427783090970479, 0.12913589249365032, 0.1815722178434953, 0.10410731832962483, 0.22705503506585956, 0.12621564528672025, 0.11304721439955756, 0.14790393150178716, 0.14264093188103288, 0.11417999892728403, 0.14821385237155482, 0.06682110659312457, 0.18496205157134682, 0.10196587347309105, 0.06766606398741715, 0.181241279351525, 0.08742833597352728, 0.16705767950043082, 0.08205857840948738, 0.15908169967588037, 0.2110433325287886, 0.23933312622830272, 0.28166294388938695, 0.09944595556589775, 0.16455849719932303, 0.14003496937220916, 0.08798686147201806, 0.11274753516772762, 0.08748304710024968, 0.1663582943729125, 0.13812621007673442, 0.1358488854020834, 0.08090957053354941, 0.09434151579625905, 0.1759309900808148, 0.073362322000321, 0.25512902706395835, 0.1694259766372852, 0.22211764531675726, 0.1690061140106991, 0.1231108333740849, 0.10211289292783476, 0.15508894517552108, 0.13871657371055335, 0.14140481071081012, 0.08108369322144426, 0.1477594205061905, 0.1275707030436024, 0.15334185532992706, 0.07337099028518423, 0.1906581685761921, 0.11305591237032786, 0.18991526390891522, 0.09392696694703773, 0.12360494045424275, 0.18769930000416934, 0.11865223277709447, 0.15171514183748513, 0.1708724076161161, 0.07932145614176989, 0.1600934992893599, 0.23460790165700018, 0.12124983128160238, 0.07136207816074602, 0.13674712157808244, 0.22297669609542936, 0.15176801243796945, 0.16792620008345693, 0.1242427050601691, 0.136444058152847, 0.1345880507142283, 0.11126150318887085, 0.15469903562916443, 0.1136517382110469, 0.11760903289541602, 0.13126364472554997, 0.1393916312372312, 0.11125769597128965, 0.17881074571050704, 0.14527935592923313, 0.10490467437193729, 0.13791468314593658, 0.061266906777746044, 0.1301099464762956, 0.12901156791485846, 0.14009949169121683, 0.060213995893718675, 0.14151740935631096, 0.10405656285001896, 0.16848989092977718, 0.14703134394949302, 0.1475866633700207, 0.16158340527908877, 0.10658537910785526, 0.09232315613189712, 0.13088780629914254, 0.1745729785761796, 0.11552454787306488, 0.08685236258315854, 0.18212232738733292, 0.19194477063138038, 0.11529857132700272, 0.18720878491876647, 0.24657317757373676, 0.24676637345692143, 0.16676803410518914, 0.10477110263309442, 0.1316722563933581, 0.17120477103162557, 0.0780724809737876, 0.13264565728604794, 0.10079085332108662, 0.2373806099058129, 0.10876109634409659, 0.12125537512474693, 0.1803741094772704, 0.1775642641587183, 0.086026916251285, 0.15324037405662239, 0.13415759021881968, 0.12141552317189053, 0.15790937351994216], [0.023560409390483983, 0.08414250682108104, 0.028835300072387327, 0.03602245298679918, 0.038612155040027574, 0.013199756012909347, 0.022081453789724037, 0.05934981687460095, 0.072960760735441, 0.055411691864719614, 0.042209059101878665, 0.0527755610528402, 0.05410224650404416, 0.03975371175329201, 0.03859009098960087, 0.041528179426677525, 0.029599689914903138, 0.033823499106802046, 0.0283444640081143, 0.018309979896002915, 0.037928740930510685, 0.07483135879738256, 0.012809482814191142, 0.05574405528022908, 0.045573003008030355, 0.05477325932588428, 0.04601802444085479, 0.039321128715528175, 0.012043569713569013, 0.015675975337217096, 0.01900602535897633, 0.02423555783025222, 0.04063799926370848, 0.04842744398047216, 0.03514393567456864, 0.0708247409784235, 0.08180017000995576, 0.007363880540651735, 0.04027614289952908, 0.005220269540586742, 0.05104432348161936, 0.01894827699288726, 0.060997158361715265, 0.05300977543811314, 0.030545863264705986, 0.047744122639414854, 0.0641659322718624, 0.043161969297216274, 0.0779547392448876, 0.06769874817109667, 0.03683114533487242, 0.022727356044924818, 0.016547794766665902, 0.010115030327142449, 0.0358451501961099, 0.050174849238828756, 0.00766887494137336, 0.05412341626652051, 0.054935277585173026, 0.0361309178697411, 0.04399988742079586, 0.054157254489837214, 0.045855512653361075, 0.02748249844444217, 0.02643268417159561, 0.0223710806312738, 0.03000530145072844, 0.01886799331259681, 0.044200812772032805, 0.00445465144366608, 0.03632999898400158, 0.016770990114309825, 0.05091190578241367, 0.03251914858992677, 0.019289345800643787, 0.02909956958319526, 0.014625217609136598, 0.0474207651859615, 0.027498775598360226, 0.013593843850685516, 0.03879100149788428, 0.012465738564060302, 0.04918283528240863, 0.0245635351529927, 0.11790819262387231, 0.05767956899944693, 0.042113407398574054, 0.02113039339747047, 0.040850331424735487, 0.03644370342954062, 0.04120705954846926, 0.049344141079927795, 0.02984538903547218, 0.10095968449604698, 0.06461247510742396, 0.04580200751661323, 0.027699637867044657, 0.015390641819976736, 0.02379639194259653, 0.09080815812922083, 0.0308868912543403, 0.04447026803973131, 0.02637244775542058, 0.018411264500173274, 0.009672547967056744, 0.02138046191248577, 0.04800378155778162, 0.1023894023091998, 0.04886045746388845, 0.05399218229285907, 0.02609404404211091, 0.04333727942139376, 0.0010448089506098768, 0.030740480360691436, 0.05399069057602901, 0.040370414208155125, 0.041790090763242915, 0.047161833572317846, 0.03385738928045612, 0.026167509240622167, 0.05060073810454924, 0.021845612245670054, 0.08047617855481803, 0.0660636780958157, 0.04457989809452556, 0.04589837168168742, 0.009681816463853465, 0.05260159421595745, 0.014370550561579876, 0.029882405506214127, 0.026862810700549744, 0.05364063435990829, 0.04773104599735234, 0.019511632017383818, 0.04603606976161245, 0.041153220445266925, 0.01842923189542489, 0.05965420503343921, 0.010526675523578888, 0.04538867578958161, 0.030665775775560178, 0.06137597651104443, 0.06446222731028683, 0.0439975756307831, 0.05348410799342673, 0.03623949407483451, 0.03831690642982721, 0.044627113529713824, 0.040637913916725665, 0.0591004886518931, 0.021803602976433467, 0.04043863242259249, 0.05700549481844064, 0.07685002274229191, 0.06345699570374563, 0.06433165384805761, 0.026704916926973965, 0.016861615622474346, 0.03552238275005948, 0.054361259753932245, 0.03199109938577749, 0.047505692855338566, 0.03561686557077337, 0.018565417849458754, 0.054234534327406436, 0.05511260264029261, 0.011555568653420778, 0.023514531676482875, 0.04265689327439759, 0.04731473825813737, 0.023323187451751437, 0.08012293110368773, 0.013340174064069288, 0.07720213470747694, 0.05496899706486147, 0.0472578749031527, 0.030168835546646733, 0.03373189210833516, 0.06441123434342444, 0.015113183417270193, 0.07134731684345752, 0.01668031265580794, 0.0033708955106703797, 0.005135512101333006, 0.04529528763669077, 0.05845490552019328, 0.021389542089309543, 0.027173607304575853, 0.08022973357583396, 0.013769815413979813, 0.005035300828239997, 0.0763520119653549, 0.009079724113689736, 0.021090014997753315, 0.04512100167630706, 0.02049133188847918, 0.10932192250038497, 0.030714787208125927, 0.025006827381730545, 0.02920571711001685, 0.12302280723815784, 0.014866677211102797, 0.06521008210256696, 0.053631068076356314, 0.006759422130926396, 0.030558672733604908, 0.041287682761321776, 0.056179948296630755, 0.014304784217529232, 0.052689197327708825, 0.0855572109867353, 0.06661260020337068, 0.05196672027523164, 0.06493375083664432, 0.033346394629916176, 0.045651292166439816, 0.04146853301790543, 0.02408867010672111, 0.017690585300442763, 0.022048654573154636, 0.03135258149995934, 0.02559537831984926, 0.008811044390313327, 0.031136772377067246, 0.08536803754395805, 0.05659812995872926, 0.030437632158282213, 0.012830646082875319, 0.020261475765437353, 0.011822304877568968, 0.0027949731429544045, 0.05043284945713822, 0.025065616609936114, 0.040506045406800695, 0.03462010557996109, 0.0579892449604813, 0.0626176266814582, 0.010117881101905368, 0.08304772767587565, 0.04140972894674633, 0.027669397204590496, 0.03570367829524912, 0.020009605686936993, 0.011946990325668594, 0.04113270748348441, 0.019957417862315197, 0.10894128237850964, 0.046432673480012454, 0.021698839555028826, 0.020082304617972113, 0.03084978201513877, 0.017360255369567312, 0.024748344767431263, 0.010155512627534335, 0.05217163838096894, 0.01536524459879729, 0.05094087551697157, 0.05408373734098859, 0.06261080634430982, 0.03212353192793671, 0.04276878316886723, 0.05143163551110774, 0.04221740826324094, 0.03936680790502578, 0.09815078912652098, 0.03389789941138588, 0.047242542132153176, 0.0408312953368295, 0.020001033881271724, 0.0036798061319132103, 0.012389520925353281, 0.050029495905619115, 0.03606707090511918, 0.047548496222589165, 0.06567264048499055, 0.10932755540125072, 0.02104401297401637, 0.007430285131704295, 0.052009557039127685, 0.040968574103317223, 0.043942070406046696, 0.011096237685706, 0.020180709689157084, 0.014133496533759171, 0.06738799609593116, 0.023536701482953504, 0.04175264199147932, 0.02232901384559227, 0.007913695080787875, 0.040755581430858, 0.04324288194766268, 0.026024543767562136, 0.017976310300582554, 0.11953533656196669, 0.03230493137380108, 0.005770169427705696, 0.07303662307094783, 0.0722886346920859, 0.08492306806147099, 0.13629065622808412, 0.0725851597962901, 0.0913793224026449, 0.041529934605932795, 0.06278071363340132, 0.023429724606103264, 0.012817601909773657, 0.03983557064202614, 0.012927436055178987, 0.02753974957158789, 0.03762138047022745, 0.021286903065629303, 0.013843846500094514, 0.023476891801692545, 0.048140689250431024, 0.07011974521446973, 0.08591831778176129, 0.01988391926715849, 0.0345541063870769, 0.031065965922607575, 0.0692013671505265, 0.04603963578119874, 0.07954741784487851, 0.03501103929011151, 0.040359315389650874, 0.05863087615580298, 0.024033858790062368, 0.05668171063007321, 0.04809797494090162, 0.023702708786004223, 0.0774813380849082, 0.032898289573495276, 0.028674623245024122, 0.03657471475889906, 0.03147168506984599, 0.08294986808323301, 0.05996229650918394, 0.0344710229546763, 0.014607434823119547, 0.08069675968727097, 0.03083791507378919, 0.01768923830240965, 0.03403175316634588, 0.016039158290368505, 0.02392677986790659, 0.01346510163784842, 0.05382631228712853, 0.024074190805549733, 0.002574055724835489, 0.06436468684114516, 0.058348440725239925, 0.03866452469083015, 0.016263531797449104, 0.09228866110788658, 0.2076230410602875, 0.20581004850100726, 0.09046059552929364, 0.18025036377366632, 0.10109786497196183, 0.10821224102983251, 0.15251826436724514, 0.2733750839252025, 0.15951821609633043, 0.1204134828003589, 0.10214483496383764, 0.16680957953212783, 0.10195638140430674, 0.1177920465124771, 0.16998426464851946, 0.0759120074508246, 0.08297097476315685, 0.10314568789908662, 0.12919933127705008, 0.15520083135925233, 0.19798055378487334, 0.11093429769971408, 0.1846712187398225, 0.1698056742316112, 0.09625656108255498, 0.18015838199062273, 0.17856882041087374, 0.08747006693738513, 0.1365580371930264, 0.07668920676223934, 0.1747820564196445, 0.10716648073866963, 0.24293046444654465, 0.18491868046112359, 0.1570549834286794, 0.13924922794103622, 0.1542741560842842, 0.07289673565537669, 0.12038396758725867, 0.1420786214293912, 0.1469333507702686, 0.12165569700300694, 0.12460294354241341, 0.16544607613468543, 0.09544438435113989, 0.16945048235356808, 0.11305788648314774, 0.22373505227733403, 0.13882094935979694, 0.11655162830720656, 0.25919569947291166, 0.08446210529655218, 0.0987028208328411, 0.11760420893551782, 0.12390927295200527, 0.09862951148534194, 0.11206192430108786, 0.14409137045731768, 0.12143007668782957, 0.13456486602080986, 0.16553370893234387, 0.1923742811777629, 0.10097034915816039, 0.21761125040939078, 0.10104769578902051, 0.07463456349796616, 0.0921826898411382, 0.15493638929910958, 0.12191778645501472, 0.17025991313857958, 0.15058540011523291, 0.16497399599757046, 0.11488739924971014, 0.18899532733485103, 0.11901739911991172, 0.12750064430292696, 0.07394215455860831, 0.2688057697378099, 0.06764995196135715, 0.2310810674680397, 0.13407969439867884, 0.16695596073986962, 0.10791561202495359, 0.2120926254428923, 0.10168350854655728, 0.16442149673821405, 0.10084687062771991, 0.21504901524167508, 0.11247247297433205, 0.2707506122533232, 0.15249741001753137, 0.1286555448314175, 0.22407054755603895, 0.09703149684355594, 0.16490211157361045, 0.1107862763456069, 0.11201958477613516, 0.09149048128165305, 0.15646456042304635, 0.11003186096786521, 0.08340001775650308, 0.15691695880377665, 0.2467439160682261, 0.12440897582564503, 0.14648705284344032, 0.12470347486669198, 0.1418594503775239, 0.12846997822634876, 0.1889987857430242, 0.10664621295290999, 0.12364479378447868, 0.06781471616704948, 0.16465323977172375, 0.12365220783976838, 0.12159435849753208, 0.1964982770732604, 0.15981982491211966, 0.11617025345913135, 0.12145896107540466, 0.11335524279274978, 0.16142673790454865, 0.1236454765603412, 0.22264848870690912, 0.17465569835621864, 0.18654874846106395, 0.15021869010524824, 0.2396184523240663, 0.1283516947296448, 0.08130379195790738, 0.11431673221522942, 0.07320799239096232, 0.11824463043012656, 0.13530126947443932, 0.13421665033092722, 0.09848989124293439, 0.11032155089196749, 0.10631353783537634, 0.25115826982073486, 0.18392246594885364, 0.21509203012101352, 0.1917233582935296, 0.17412280663847923, 0.12748485140036792, 0.07372526190010831, 0.23461665899958462, 0.22890684194862843, 0.12694278673734516, 0.12996675650356337, 0.12422318657627329, 0.08801681455224752, 0.18900366907473654, 0.11953879497013986, 0.15506242081755772, 0.10869316756725311, 0.13677510054549202, 0.11548033071449026, 0.12408934766426682, 0.198903176933527, 0.11423517018556595, 0.1581014264957048, 0.12849549326347187, 0.1082945303642191, 0.12033283361233771, 0.11369185871444643, 0.14206092862877995, 0.16866794700035825, 0.09382908508996479, 0.13473216095007956, 0.15262750850524753, 0.07543278043158352, 0.15843160799704492, 0.10471510016941465, 0.1321065760566853, 0.09564276042510755, 0.12925187533255666], [0.017993619039771147, 0.02547859952755971, 0.025820724040386267, 0.030611893998866435, 0.026828260015463457, 0.04478871989704203, 0.024278923374367878, 0.009769070766196819, 0.0187707255827263, 0.04328391900344286, 0.07205885092844255, 0.06500452946056612, 0.02834582955983933, 0.042582296300679445, 0.050551986423670314, 0.03965015617723111, 0.037560301716439426, 0.03663937808596529, 0.032866729743545875, 0.036646543521783315, 0.024348097103938926, 0.0519254086248111, 0.04120547506317962, 0.029230647705844603, 0.028314060073171277, 0.054081321650301106, 0.08305788767756894, 0.01910048034915235, 0.062214414137997665, 0.060429578661569394, 0.05630440646200441, 0.03414492697629612, 0.0104484364601376, 0.05251066628261469, 0.03793125681113452, 0.029671488991880324, 0.06567700431332923, 0.05980024114251137, 0.03902411008311901, 0.022336914007610176, 0.033097919877036475, 0.07229169234051369, 0.03067557769099949, 0.10346926428610459, 0.012538844748632982, 0.021686659056285862, 0.07626603415701538, 0.056104586910805665, 0.06105739106715191, 0.015345008087024326, 0.05741926441260148, 0.0382306391838938, 0.0577946612611413, 0.048984077002387494, 0.09117889800108969, 0.015467196208192036, 0.08220636969781481, 0.07352854081545956, 0.03480758692603558, 0.008179900669347262, 0.028162316848465707, 0.036817359941778705, 0.055676586634945124, 0.02412138768704608, 0.05317930794262793, 0.06802304444136098, 0.11948019498959184, 0.06468517589382827, 0.02486685090843821, 0.06350257841404527, 0.016967373521765694, 0.0526088412880199, 0.07951074090669863, 0.02118763524777023, 0.025141130136034917, 0.012754807867167983, 0.07498584425775334, 0.04323344553995412, 0.03607480779464822, 0.02233191378763877, 0.02810930152918445, 0.06109608664701227, 0.028823731845477596, 0.024561334685131442, 0.020823687882511877, 0.05692424449080136, 0.03104293893557042, 0.03156342565489467, 0.07670076942304149, 0.016873697786650155, 0.037410495497169904, 0.027399923383200075, 0.027710512185876723, 0.02869531246687984, 0.023303973248403054, 0.09585310734109953, 0.0913164253870491, 0.01820428322389489, 0.05360843628295697, 0.025567052398400847, 0.014564820703526493, 0.08705988191650249, 0.0579440073488513, 0.0045928240342618665, 0.012218546798976604, 0.035146125010214746, 0.03269085558713414, 0.04192121712549124, 0.10627926545566879, 0.02434050307783764, 0.03720623048138805, 0.015468272322323173, 0.03934438762371428, 0.0689048643107526, 0.051830410011461936, 0.043968784011667594, 0.01590199455677066, 0.04419327626237646, 0.026291776302969083, 0.04739748401334509, 0.04567643612972461, 0.05101593633298762, 0.054936791566433385, 0.03944541989767458, 0.037329052211134695, 0.037091976846568286, 0.045601475503644906, 0.0823912386840675, 0.03142076631775126, 0.03994937527750153, 0.06298631822573952, 0.0151773643483466, 0.01269325321118231, 0.012218856645631604, 0.025732425165188033, 0.0020847053474426502, 0.0926795725536067, 0.04119355246075429, 0.010423502153571462, 0.1018588335136883, 0.05980768117296975, 0.008016394403966842, 0.07411660379148088, 0.03980208493885584, 0.09624581478419714, 0.048136971090571024, 0.05534321389859542, 0.06291831523412839, 0.022237109988054726, 0.059045948219136335, 0.0629959290381521, 0.0666337959410157, 0.04170433559920639, 0.07196027145255357, 0.0628595742455218, 0.016425212379544973, 0.04266800322511699, 0.02251349691505311, 0.052579029215849005, 0.017470944840169977, 0.05620806085062213, 0.05148420183104463, 0.01844824386353139, 0.04348328584455885, 0.07844972948078066, 0.09206391652696766, 0.026976446497428697, 0.021654958218277898, 0.04270417550287675, 0.028832533716922626, 0.005831237976963166, 0.01278939844269189, 0.024136677784554195, 0.030362697507371195, 0.037225897394819185, 0.057920462713809684, 0.02564292215538444, 0.08687297944561578, 0.009211696524289437, 0.02802337010507472, 0.06679876052658074, 0.013887645272916416, 0.0413109379587695, 0.021207675090408884, 0.03350009341374971, 0.01810116180422483, 0.05267725617159158, 0.034862787870224565, 0.029034169674559962, 0.030864279870002065, 0.003759135224754573, 0.021700652250729036, 0.06000791261612903, 0.02747082446148852, 0.014862786501907976, 0.054547431209357455, 0.06806335048167966, 0.06603863803320564, 0.05973977466055658, 0.02411376583040692, 0.044586317671928555, 0.04501004317717161, 0.08544755124603398, 0.03840456520265434, 0.03792854055063799, 0.07403580617392436, 0.06478980387328193, 0.06656586716417223, 0.030599787714891136, 0.09001636819448322, 0.034193738028989173, 0.023982055026863236, 0.041118287554127164, 0.04999031050829217, 0.030141207244014367, 0.012762473324983148, 0.026274714327882975, 0.06172107889142353, 0.033911024293047376, 0.03405475974432193, 0.0005279071524455503, 0.016985988440865185, 0.0871340447338298, 0.024427863136224914, 0.04941077480907552, 0.03602505421440583, 0.009362155833514407, 0.02223681498435326, 0.032088101797853597, 0.0229650789333391, 0.04590283198922407, 0.07753883226541802, 0.03503703301248606, 0.014188613058649935, 0.04367646688478999, 0.04619006169377826, 0.06867470947327092, 0.07361565410974436, 0.0299451114187832, 0.018137020524591208, 0.03303928278910462, 0.06015216757077724, 0.07390866143396124, 0.058910535954055376, 0.04773887565534096, 0.03782966421567835, 0.014156514243950369, 0.08755695758736692, 0.047071540175238624, 0.04945353364746552, 0.04674953714129515, 0.03274492846685462, 0.0621529457566794, 0.023477936374547426, 0.032141473348019645, 0.09529600676614791, 0.041242549050366506, 0.032043610044638626, 0.05071372266684193, 0.02065398653940065, 0.022877550036355387, 0.03456558370089624, 0.011337322503095493, 0.024670276397955604, 0.025266452903451864, 0.026280735000909772, 0.028462910777307115, 0.08257059351308271, 0.059224991346127354, 0.02644778687681537, 0.03937061512260698, 0.028870518690382596, 0.03592355438740924, 0.02073085262964014, 0.022499045444419608, 0.02851359389751451, 0.03656769775261637, 0.019970772809756454, 0.01609207898582099, 0.029178454315115232, 0.04224452633934561, 0.04261018992110621, 0.013281636238389183, 0.06266248208703473, 0.055822077265474945, 0.03213236719602719, 0.04498957103351131, 0.03590300431824289, 0.032917911958065815, 0.03420969791477546, 0.03261802492488641, 0.04682888386014383, 0.02905124463723041, 0.09152832339168526, 0.04158678311796393, 0.03272932481195312, 0.04218286128889304, 0.08945004272391088, 0.06571501711732708, 0.019512279541231692, 0.041687822813401, 0.0581689560203813, 0.03663731120468583, 0.049117403832497075, 0.017372803231410217, 0.028249669485376216, 0.034632870519999415, 0.030958354509493802, 0.015862373147683684, 0.0162751297102659, 0.05060418538050726, 0.013906726817367598, 0.0838691218814347, 0.018504112740629353, 0.021124144514033105, 0.04679222918639425, 0.016366196796298027, 0.012531666325230617, 0.01375291856675176, 0.03993861042545177, 0.025567885459167883, 0.047224697191268206, 0.09319483826402575, 0.04501562041696161, 0.028018086013616994, 0.04475048444874119, 0.026016450647148304, 0.021084011023049243, 0.0878405396360904, 0.01371781962006935, 0.03155664984660689, 0.03845089748210739, 0.01422845154593233, 0.026489721931284294, 0.015669596577936318, 0.026302040205337107, 0.008459255259367637, 0.009064003570529167, 0.059476416136021726, 0.02218850488134194, 0.023704360064584762, 0.05194943936658092, 0.056491479626856744, 0.02250008074042853, 0.051511921046767384, 0.06599985339562409, 0.026277194956492167, 0.04175710600975435, 0.026763750684040133, 0.020534888535621576, 0.03818023622443434, 0.015504446455452126, 0.17794693034375086, 0.15651101886760443, 0.13919373013777658, 0.2291682263603434, 0.20577381685143337, 0.2525587915442884, 0.12996191770071164, 0.08721142105059698, 0.12790345237590373, 0.18581846030429006, 0.2745199209311977, 0.12378588347928599, 0.08354462523129769, 0.1473991374950856, 0.12862568080890924, 0.15559807332465425, 0.14980112813645974, 0.19461620540823787, 0.16728577116737142, 0.0791918029426597, 0.18058352870866656, 0.17411424225429073, 0.20285201113438234, 0.07219144303235225, 0.1624350345809944, 0.12554303684737533, 0.17680938122794032, 0.15266825241269544, 0.16754448384745046, 0.16638382425298914, 0.17968824628042057, 0.08751013549044728, 0.05447478608402889, 0.1539552106987685, 0.16948153381235898, 0.08151309986715205, 0.1611771684838459, 0.216455563204363, 0.12153436327935196, 0.12734002870274708, 0.10817748625413515, 0.1838971141842194, 0.07979820438777097, 0.1340341116883792, 0.10246701611322351, 0.12373618184938096, 0.14910690835677087, 0.22889504180056974, 0.1247025397606194, 0.1057137934549246, 0.10304450348485261, 0.1389066080446355, 0.1690603798488155, 0.12620581925148144, 0.12203828897327185, 0.13581722538219765, 0.2055423113051802, 0.13312501047039405, 0.18550999404396862, 0.12603297305759043, 0.19462525960989296, 0.16246990067884326, 0.2771668054629117, 0.11521134671056643, 0.11531715470482595, 0.19624087057309225, 0.17816518113249913, 0.22657661698758602, 0.20670221390901133, 0.11795649159466848, 0.16805888124508783, 0.10517740622162819, 0.13977731054183096, 0.2606223744805902, 0.1115287802531384, 0.14013363048434258, 0.1648585920338519, 0.14089753793086857, 0.12219008785905316, 0.20541199017316103, 0.11661726384772919, 0.20218767022015527, 0.1313054870115593, 0.08960729639511555, 0.07067790706059895, 0.10535766647080891, 0.19196900917449966, 0.16120945190778002, 0.24392648600041866, 0.12257044596481137, 0.14447906840359792, 0.2631311601726338, 0.16588158323429525, 0.11077034985646605, 0.10439775040140375, 0.18688792479224503, 0.2622512402012944, 0.13224693102529272, 0.1064551915624179, 0.14892811013851315, 0.14381140266777948, 0.13932172092609107, 0.14937612984795123, 0.19933112896978855, 0.2162922461866401, 0.0625051319366321, 0.1416026969673112, 0.16696593520464376, 0.22676795750157908, 0.18505401851143688, 0.11649207837763242, 0.11350005064741708, 0.06693921939586289, 0.14554517838405445, 0.10116247634869069, 0.2662958559812978, 0.11345346603775397, 0.21620195650029927, 0.08767213148530573, 0.16957394604105502, 0.17468683887273073, 0.1949150237487629, 0.181719905231148, 0.13675712572876364, 0.16104726295452565, 0.07857310411054641, 0.14261878619436175, 0.11119715898530558, 0.10191259469138458, 0.11827024194644764, 0.13901984493713826, 0.131943971500732, 0.14392937446245924, 0.05427169366157614, 0.11926817081985064, 0.07590251538204029, 0.13749214878771454, 0.06638538427068852, 0.07216855519800447, 0.2633178548421711, 0.17214956955285743, 0.10855927670490928, 0.15634017647244036, 0.10544278338784352, 0.10786614046082832, 0.13875519507564604, 0.18373168946709484, 0.1414932301850058, 0.060861067031510174, 0.2127117695636116, 0.14362211048137397, 0.16897246503503993, 0.17388068838045, 0.18231691850814968, 0.15048307279357687, 0.13096145703457296, 0.19325972272781655, 0.08275952204712667, 0.12135456316173077, 0.1086812189896591, 0.1493778664735146, 0.07223979395348579, 0.14559377421392128, 0.1398347527720034, 0.18715094192884862, 0.12476378178689629, 0.12088382631191052, 0.07434609811753035, 0.1828109216876328, 0.13204585353378206, 0.05488932380103506, 0.1276490738382563, 0.06888843316119164, 0.11419787726481445, 0.14373834565049037, 0.1751430073636584], [0.09292073344113305, 0.027107201785838697, 0.036355781194288284, 0.024838274512148928, 0.04522278351942077, 0.004595793088810751, 0.01832428664783947, 0.06342139487969689, 0.019147057537338696, 0.0830543995834887, 0.0070828510160936275, 0.037570031272480264, 0.051402098033577204, 0.037174945246079005, 0.04529217803792562, 0.027196426490263548, 0.08772998189670034, 0.016694287296559196, 0.03667070785013493, 0.05825340129376855, 0.012762501155521022, 0.0791783255408518, 0.013468758570525097, 0.02099504607031122, 0.015347202988778008, 0.02229154280939838, 0.07546683758846484, 0.06103512663685251, 0.03151895616611, 0.0292816629371373, 0.05232201605394948, 0.03424952898058109, 0.055573420686414465, 0.021207586032687686, 0.044175486982567236, 0.043110193364555016, 0.058101676622754894, 0.04498265792790335, 0.008561007416574284, 0.04340443636465352, 0.002743485720202443, 0.007367782845904003, 0.043659813090926036, 0.06530705853947438, 0.005871799594387994, 0.032607779576210305, 0.023750458567519672, 0.046366744791157544, 0.03142663299513515, 0.07315308088436723, 0.043785814923467115, 0.13079352385830134, 0.019628609334176872, 0.04761698903166689, 0.053732137457700446, 0.060096588131273165, 0.05038314040575642, 0.0799345962877851, 0.031700748950242996, 0.029021575428487267, 0.04863759793806821, 0.06962346364161931, 0.03602947370382026, 0.04221702605718747, 0.015405974590976257, 0.02874415320547996, 0.031116853133426048, 0.04944221589539666, 0.031435898708878085, 0.047681303549325094, 0.061039286374580115, 0.0506639987725066, 0.024467016992275603, 0.017109420587075874, 0.06807746613048948, 0.03886330523528159, 0.06027233612257987, 0.02284306985529838, 0.04405483603477478, 0.025133233684755396, 0.016730572751839645, 0.01061295854015043, 0.07062651333399117, 0.011976525947829941, 0.02514132866053842, 0.013873130719730398, 0.047237688486347906, 0.03576003698981367, 0.015093460842763307, 0.040408133863820694, 0.011231457920075627, 0.027362469045328908, 0.028132875850133132, 0.04946864006342366, 0.006053891092960839, 0.05204194436373655, 0.056851911067496985, 0.01528737104308675, 0.030534328434441704, 0.044946615525987, 0.04117062380828429, 0.03999535503680818, 0.01995152520976262, 0.0414876396098407, 0.049025481421267614, 0.021225336349743884, 0.09880750818410888, 0.08719093777472153, 0.04234306499711238, 0.0216313653436373, 0.01648504246986704, 0.03517298333463259, 0.01098197291867109, 0.0345019630913157, 0.009226243546436308, 0.039231777845998295, 0.05529039895918686, 0.018577607625047676, 0.023981650556379464, 0.030023506333236583, 0.016691290875314735, 0.02769542988971807, 0.04677202050515916, 0.030729199716006406, 0.02941521797765745, 0.03983302507549524, 0.04708076507085934, 0.035411706267041154, 0.02919881142588565, 0.11812768279924057, 0.05051639673183672, 0.020866504237346817, 0.040272009136970155, 0.020062611729372293, 0.0928433719673194, 0.023157662544690538, 0.04324170193285681, 0.04464054640266113, 0.03678713597764727, 0.04419949545990676, 0.023063994231051765, 0.01675570929364767, 0.059358685539336875, 0.023271372556337155, 0.03394046529137995, 0.05895303133002017, 0.050075869003194384, 0.020611660002032295, 0.008823890038911486, 0.016621022477920633, 0.06512374806334265, 0.02273844558658311, 0.030041559075471014, 0.02406016421446111, 0.05862558835360687, 0.015955258495523594, 0.04860374487179797, 0.005917429152759723, 0.0061635239308088785, 0.0585773784405319, 0.020066530269104987, 0.028249519200471696, 0.03770915798668284, 0.05835260046296753, 0.02669917270395672, 0.027832281921291724, 0.016196491742448416, 0.01425575144821778, 0.0248435920002521, 0.03699917870108038, 0.016548384774068836, 0.08352253891644068, 0.050283054370083846, 0.06265849675401114, 0.01168876931842533, 0.046313154307426885, 0.061803813514416106, 0.09406109529663809, 0.02666189833689714, 0.02003237106691813, 0.0619092949636979, 0.018940764603030402, 0.05686158125172369, 0.01276278038858436, 0.03249875066103414, 0.019082833932770882, 0.03167773495079018, 0.012156422544649104, 0.02600171344965929, 0.03867253246426117, 0.022636923495156225, 0.005250082076599938, 0.049719296730472706, 0.01603938279004069, 0.054986916220514104, 0.051451135441311635, 0.024465699680149555, 0.07569404609967023, 0.020337217501946725, 0.08144282590365037, 0.06265039250138216, 0.05227249253948685, 0.03185223613400012, 0.04839208064367995, 0.060635146146523766, 0.05716647036024369, 0.02537311436753953, 0.05520738603081554, 0.09215339727234095, 0.013707052912650397, 0.055556930165039375, 0.06649221642874181, 0.007474835792891099, 0.099467366526369, 0.06352356635034084, 0.0817144445318263, 0.04155837741564028, 0.01483995432863594, 0.03336395384394564, 0.0462221892667003, 0.019072200811933726, 0.05913281289394945, 0.06465770158683881, 0.025503533834125847, 0.01580061718414072, 0.018346287615713663, 0.02283262412674958, 0.026914295340247918, 0.01849162239523139, 0.03842705598799512, 0.05662469884555321, 0.024247675246442668, 0.07453908619936556, 0.04071451839990914, 0.06310421580565162, 0.03141933397273533, 0.010621947803883813, 0.02518928624340333, 0.11012633636710234, 0.006491820377050317, 0.01563139638165012, 0.02640655500727007, 0.009692469993751729, 0.02902320815337589, 0.0050888685836980585, 0.009310425357398344, 0.06965942069655284, 0.048700168408686295, 0.029233222958282568, 0.06593016572878696, 0.0517958259297302, 0.09657641188823618, 0.022633628359471913, 0.0460337579715997, 0.019666072948893998, 0.046835552057018504, 0.041526238710503094, 0.012721220118692145, 0.0559780729963677, 0.03845730592729524, 0.01435803609638242, 0.0825576949864626, 0.009270849404856563, 0.03278180207416881, 0.05133212835062295, 0.04038022911117878, 0.0060746735471184365, 0.012339668082859134, 0.016924007977650035, 0.032273308461299166, 0.028355809590721037, 0.048365719558205456, 0.0634840469865594, 0.01869505435024621, 0.026701028073148336, 0.03805050509981811, 0.0375223297305638, 0.0006805748148508428, 0.029279054288053885, 0.06533279622090049, 0.014334158422570908, 0.007589488332087058, 0.052367198004503734, 0.026388262922409922, 0.02274169248266844, 0.033103749447036535, 0.033071766592911445, 0.04633739656128455, 0.049110702238976955, 0.017236069943464827, 0.02202528248744784, 0.04771157204231713, 0.059959969876217656, 0.07281015670741908, 0.023259435110958293, 0.028674064778897446, 0.014588468311558245, 0.021992388647049665, 0.029983504573465325, 0.10551922459853813, 0.032242976885754615, 0.05513505260751117, 0.011770513174269581, 0.037228294531814754, 0.05133370170369744, 0.03600412564992439, 0.02082559520204086, 0.04647148038202431, 0.027499764510139357, 0.022021775839675684, 0.05248315857897978, 0.08113717980450019, 0.030919248893042095, 0.049476618150947616, 0.016912556638999376, 0.03939816735510249, 0.08158217155141756, 0.07668442733120173, 0.06704785497277044, 0.04086930814082734, 0.0359083366492996, 0.031221978351823054, 0.04375701588287484, 0.04040475338115357, 0.02117943822668167, 0.03873667257721536, 0.0561256045330083, 0.03614057321101427, 0.035406129027251154, 0.05410075107647572, 0.02034723092947388, 0.05393623920099344, 0.09042788908118382, 0.03616838148445822, 0.031347742697107606, 0.11113765358459204, 0.018339797534281388, 0.02006168961088406, 0.043330652042641304, 0.05368268073652871, 0.013728009307669709, 0.044730361114488915, 0.027150728747074027, 0.07128634199034423, 0.03401496207516175, 0.02800242669763975, 0.0069031854127388215, 0.013279641716508195, 0.03648384990810882, 0.0259490376629401, 0.04109676527150441, 0.05291725930874236, 0.23320873064221814, 0.11053487382014282, 0.15422711876453832, 0.09148662211373448, 0.13869769347365946, 0.14254694629926234, 0.10180464931181632, 0.14468072477029637, 0.1027661981061101, 0.13119842478772625, 0.08991476817755029, 0.1322059941594489, 0.16874790599104017, 0.1054981179186143, 0.08156265306752175, 0.13105545745929703, 0.15889878995949402, 0.13181458547478542, 0.2505793352611363, 0.09393271859153174, 0.08966323948698118, 0.11408123391447589, 0.09545605833409354, 0.1651325632701628, 0.12785194732714444, 0.1908279868075624, 0.19229691970394924, 0.10113431926583871, 0.12784747959813103, 0.1466664596227929, 0.10243750832160003, 0.1152449734217953, 0.21731992776039988, 0.15994971559848636, 0.22831324255093932, 0.1069084285700228, 0.0986657728208229, 0.1951371188624762, 0.13396509195445105, 0.14912289421772584, 0.10693262258428149, 0.12197729927720502, 0.1523433846887201, 0.12362461478915066, 0.09508598639513366, 0.16192550567211583, 0.13810044270940125, 0.15883186308201402, 0.0815745274303481, 0.13448103301925585, 0.0769150051928591, 0.16307228710502386, 0.15335920674260706, 0.12765878112986684, 0.1627289695898071, 0.12276972003746778, 0.18901785893831402, 0.1659760289476253, 0.16520087054232135, 0.08920433247112669, 0.08509871215210296, 0.13759413472143933, 0.16984564630547538, 0.11238941922783852, 0.09862294347840361, 0.11800158448750153, 0.07488799950806424, 0.24454266153043136, 0.062196201834012754, 0.11671703075990081, 0.09783902030903846, 0.10906505776802078, 0.33409359923098236, 0.08112125331535935, 0.16592268337262794, 0.16782556485850364, 0.13195504434406757, 0.12337950567598455, 0.11699616734404117, 0.1099368734867312, 0.10510539563256316, 0.13102369353873655, 0.13504126545740291, 0.11441372349509038, 0.1526672876207158, 0.18202954408479854, 0.12014510735752992, 0.22167084272950888, 0.2047637093346566, 0.12883965682704002, 0.11136115877889097, 0.12243226548889652, 0.08073182616499253, 0.14133487071376294, 0.08408866400714032, 0.1105788312270306, 0.21481563948327675, 0.09756293395184912, 0.1392895117169246, 0.17795233317883685, 0.18955483246827498, 0.18234924646094441, 0.15227507741656154, 0.10113736207131296, 0.15485619282117113, 0.14086040086112916, 0.13514092104742303, 0.23469492589356378, 0.12479924160288647, 0.14447231485974044, 0.10959763778373599, 0.17064447922166437, 0.12630011653527617, 0.24250831600511447, 0.16580978786805645, 0.19742608041269705, 0.159819528053049, 0.2254643602645956, 0.12334630198893137, 0.16441155195934698, 0.10761727608041838, 0.09231115560396574, 0.13395792280789465, 0.24672423431184143, 0.07883777623646893, 0.15335482807131484, 0.14063928538234904, 0.16584042372414842, 0.12326879950705916, 0.22402849746868014, 0.19347263005329296, 0.13132246735040098, 0.08262107439804822, 0.0940990487288218, 0.0929240434197709, 0.12806160404579714, 0.10874262428842485, 0.20577579096425325, 0.15723185206297785, 0.11548967435373925, 0.24893044639611617, 0.12155134361819364, 0.13719996524741873, 0.08041762310313061, 0.18322944844840094, 0.13966800703201443, 0.13236735190730542, 0.15773633436765522, 0.08444969658739865, 0.18998149316757917, 0.17324159533018246, 0.13134832377545536, 0.11087904480518773, 0.1760193650261499, 0.1641516963718459, 0.11165954667376354, 0.12211038119858131, 0.0653784086171072, 0.13008247216930613, 0.37332931417040527, 0.08671223768033087, 0.08952235759352334, 0.13808758871164173, 0.1586541929282248, 0.10556054738117382, 0.10817777569172904, 0.10651998105458915, 0.10828411803231575, 0.11358055882737972, 0.09131114129559137, 0.1039226794091519, 0.15284703578799963, 0.1373473706189543, 0.20507284352788702, 0.08547353383619338, 0.1060779950057622], [0.03929492719180416, 0.015741464303573593, 0.01820623507228447, 0.03462635817413684, 0.0218981433135923, 0.08930802534450777, 0.055424041202059016, 0.020889495972369332, 0.02285571419633925, 0.017458098263887223, 0.039823317783884704, 0.028835082994191907, 0.08360146632185206, 0.057437829236732796, 0.0292902718501864, 0.037200456572463736, 0.005572144018515246, 0.017515080362500157, 0.0537202408304438, 0.01780902464815881, 0.02297584193001967, 0.02388320837781066, 0.026712935832620133, 0.04534032486844808, 0.02973586473672185, 0.0660104735288769, 0.031153678501141258, 0.012849417780671502, 0.06366968038491905, 0.04834355160710402, 0.021626806701533496, 0.06890397373354062, 0.00877597791259177, 0.02504761767340824, 0.052562494165613316, 0.026224736247968394, 0.09119774855207652, 0.0174164730560733, 0.034006468195002526, 0.0737552743521519, 0.05619310286419932, 0.02885006138967583, 0.043000863879569806, 0.054350873397197574, 0.014697633596369997, 0.08273904619272798, 0.09314902548794635, 0.016532087211089674, 0.011944525467697531, 0.03424805210670456, 0.06057044200133532, 0.03185459987435024, 0.07790162373567, 0.03641220668214373, 0.04480385599890724, 0.011647967894532485, 0.05577089134021662, 0.048093733566929586, 0.026238256323267706, 0.044253178712097, 0.022657588597212452, 0.08470545551972464, 0.025449754102737643, 0.008435183699475601, 0.03319731942610815, 0.04451958375284448, 0.05064475117251277, 0.008257410572696244, 0.022146130104374606, 0.022971188664087094, 0.051159593858756125, 0.01887250557047082, 0.019679311008076183, 0.03060825190914329, 0.08546105091227219, 0.03590706386603415, 0.049363455473212525, 0.04860906978137791, 0.03567206280422397, 0.04102981241885573, 0.04869566357228905, 0.03935213935619686, 0.02668300316145178, 0.019130207074340433, 0.01750883890053956, 0.017624541578697972, 0.030800635140622035, 0.020731511285703164, 0.045903514765086584, 0.023701265308773145, 0.015404747264256002, 0.035180423365090974, 0.03884561614540871, 0.0573720304237213, 0.04036757178255357, 0.006486210204457166, 0.08893992751836777, 0.03843986174615566, 0.006717680034853402, 0.022314842535706703, 0.02402138885372551, 0.014027317465661326, 0.025550270584062673, 0.03476075369690079, 0.12663153000175953, 0.022251307273108978, 0.03946723161789123, 0.03929478247300722, 0.02975324769067811, 0.08421290694968775, 0.07127905410015956, 0.05747815012000501, 0.06887117080623284, 0.03912664149538614, 0.07685951481107622, 0.0477472767670406, 0.020694478116638493, 0.06865087168989703, 0.056886291058617644, 0.06269467645324767, 0.051581935258582234, 0.017086983607441653, 0.01386773437843658, 0.022645389544777572, 0.023027974093565717, 0.01221919617819367, 0.009122828978433972, 0.020775385200977325, 0.012266740941413445, 0.07697059205383994, 0.015425978253915673, 0.056175495410570875, 0.08263222887762822, 0.03654068728792481, 0.025270846417697612, 0.03590151260141283, 0.021166007209103554, 0.01806124910217477, 0.04687906046456192, 0.027509629508131184, 0.07779101404594257, 0.04078445097547956, 0.01080338157407823, 0.02570805674622534, 0.023192693770397455, 0.04008654272183776, 0.07676829001866281, 0.03757074002351146, 0.015912074777588714, 0.0797434190462809, 0.01994523550820304, 0.03708427706442308, 0.053283538873074576, 0.04296409788366873, 0.004758467221108731, 0.015098820076673292, 0.032613575749564916, 0.07396425571641885, 0.03705072827870026, 0.020856025112152565, 0.017584953566256445, 0.0347603752015857, 0.010525000125198858, 0.10387516711489297, 0.040309020041604526, 0.07449898796039633, 0.07172217563493177, 0.035343666168046184, 0.009602836180420127, 0.03437166422372684, 0.07474987840396352, 0.029978994170960505, 0.03257308417232707, 0.06025188253261149, 0.06374475604388863, 0.09271288014133461, 0.03915580418833997, 0.08049467287492007, 0.016069031589722726, 0.027448387481854297, 0.02793202471366385, 0.02922399991803104, 0.026439252178533934, 0.041208900074707344, 0.082162063481519, 0.05498317950696219, 0.05054973400547169, 0.019411917055549566, 0.023953627060109284, 0.08543624833691865, 0.084246934420662, 0.1074233306280803, 0.03679796391224954, 0.09705927543109283, 0.06377686877385713, 0.04705279723566491, 0.048831346721271984, 0.026639442803571, 0.025750455642992165, 0.02804895008011954, 0.023079000457073562, 0.00880980222063954, 0.023495300774811767, 0.03043058175535407, 0.03638596805103589, 0.00855060621688608, 0.04435551345522981, 0.031948451869538985, 0.020742378183058463, 0.02684919414605247, 0.034981813514605165, 0.012238431718287757, 0.03855607836158015, 0.019995879665657412, 0.10798148505273275, 0.016406426766479854, 0.03874641697620973, 0.06872849291539751, 0.08034890022827312, 0.038056753983255476, 0.08170807690476067, 0.047411247142008506, 0.0042132544604100985, 0.018657612999959383, 0.027747899730456993, 0.018755442906694952, 0.08824866890790872, 0.006207309252204141, 0.019763246054935735, 0.029771085210086312, 0.030678644616273232, 0.05098766792798415, 0.035990659380331635, 0.05481193264131434, 0.005679966943716863, 0.038926569613977335, 0.004159971040280652, 0.11069473985116929, 0.0192876388609875, 0.05880726981558837, 0.020392143851495348, 0.03581249569833744, 0.06080848215788137, 0.039815102209104225, 0.03807536333624739, 0.04770530831592623, 0.0640533484693151, 0.013476792319124797, 0.015445935532625299, 0.03484267937892582, 0.06088651898608077, 0.021932126255705953, 0.013058789700153284, 0.019479762340779416, 0.04677524142607581, 0.03341964089486282, 0.027702435763785616, 0.01021037682221504, 0.1194703095825389, 0.05342842465324793, 0.05689995770808309, 0.04873098609095905, 0.02524308267311426, 0.0008332356935625285, 0.023749224747007247, 0.025071512973227073, 0.03229926878702827, 0.04602765380695928, 0.018746952737274114, 0.05231594157521613, 0.01446361866328516, 0.03116981650236994, 0.09625129183405079, 0.06004731694702059, 0.020215887489030138, 0.025160179211525247, 0.02957352735393215, 0.05455552804050967, 0.06852482532849535, 0.022709520380885806, 0.034199511937913485, 0.0181657713255845, 0.035547337465686724, 0.08360732928849757, 0.04764859339047689, 0.061406189342960715, 0.037960541958454996, 0.07829893249436282, 0.029414086202450562, 0.021591966578853317, 0.08955691198934801, 0.03951356760808267, 0.030633143542218022, 0.07668876889511012, 0.04781013667525258, 0.029725804924964905, 0.04467438462597784, 0.02977814117912203, 0.04190250016108621, 0.038974022536422126, 0.036842722838628106, 0.09371892068884335, 0.05964619354926981, 0.043440727386041544, 0.0687613181071356, 0.02968664364743745, 0.029904933398938738, 0.04328209332015831, 0.01779940641426947, 0.027075506513938308, 0.020271808316465467, 0.04251961079717148, 0.01683795595454285, 0.038387221211451106, 0.015621286474925, 0.05715728628274519, 0.04869109565333929, 0.013612073780677747, 0.018000238997046836, 0.038283261164906435, 0.026812019968929235, 0.038335107601596974, 0.045113788000890054, 0.022403269431379158, 0.045722909417236224, 0.030081898512435146, 0.019737337679543998, 0.04079279271536507, 0.06170560511236545, 0.03131389334157575, 0.020674935512943193, 0.03424568465561606, 0.0005816726206830936, 0.08500886033289135, 0.04191178442852106, 0.048218622177955694, 0.00944818188145291, 0.04159864263783675, 0.03084967625909485, 0.05175400590815116, 0.03831012320006266, 0.025378891987202223, 0.04465576043003239, 0.06460125383455306, 0.05948266130872071, 0.01767313926393399, 0.04883724308456294, 0.03409501012356486, 0.03189247909176629, 0.03205773311492521, 0.024340605123143177, 0.06177438364829868, 0.1137075996666681, 0.13923226244514808, 0.13757814886048436, 0.19764312892220914, 0.14797459880355746, 0.19120477518299595, 0.11571455994271673, 0.13570517592597753, 0.20080213987967, 0.14019631227711216, 0.092841954465257, 0.11985209261183627, 0.16157763137016445, 0.18767184054013342, 0.2417661386425607, 0.20055757253430784, 0.08157390402629972, 0.2130489272531122, 0.1370226067956537, 0.12239316914929077, 0.11453865663497709, 0.19675393210491166, 0.1641512956121005, 0.15546358132269233, 0.13994650536915287, 0.16624293493805453, 0.08654346587718464, 0.12775857030646876, 0.11976124631473795, 0.14946218929253519, 0.10073758196085691, 0.1463322259951383, 0.11987874313490465, 0.18455856072250754, 0.14483001519693062, 0.06931791402166709, 0.19460685434751213, 0.17410244210623205, 0.23487491154810414, 0.13151420862413943, 0.124443775130203, 0.13349926070077345, 0.1842574862530455, 0.13252664648462087, 0.21160212520044297, 0.19673310744110495, 0.15689776686485857, 0.060593489397433586, 0.0913099167519249, 0.111528602137696, 0.12902071117423475, 0.09687743440736085, 0.15392586617963389, 0.11055267052142881, 0.14473614835878834, 0.12706776440609246, 0.10608491182210855, 0.22234428237425163, 0.12534497247543186, 0.1389155286597088, 0.07793611133820377, 0.28293712239246815, 0.08253635081928223, 0.11147444020025432, 0.1664229205925949, 0.116891079233028, 0.09816260411753319, 0.1320430779014714, 0.1142061002610717, 0.1073339834692888, 0.18768546637147665, 0.08639171894174069, 0.15531737823039293, 0.06188738305354491, 0.14073068829020485, 0.1449592676362954, 0.10468954802490771, 0.11175167688634247, 0.1428402282181196, 0.09779109241208062, 0.1490018647746183, 0.08825962300761603, 0.3097124450141564, 0.11687545702443458, 0.10094575438415632, 0.12037988577503711, 0.21873710327781737, 0.11839374274131842, 0.09399186776136048, 0.0977929329383187, 0.17601615894818678, 0.10219683725154027, 0.07132471102522686, 0.10779685355373658, 0.1325526216533035, 0.0754707190208137, 0.17378156713675708, 0.16023523465264589, 0.05065959041530732, 0.1017360451805871, 0.20400284469360486, 0.1617342245299369, 0.16946007090155035, 0.10921304201474413, 0.27341878158040345, 0.10180720229982398, 0.12463010614737868, 0.14755335578229278, 0.1073869876563549, 0.16663141956087202, 0.1692759440629743, 0.2943136525573209, 0.09252338015357964, 0.17857891361927614, 0.2150620028260164, 0.19890927738742903, 0.18498321762308478, 0.24085703742457554, 0.22099574067397043, 0.21925494424067438, 0.10264180673402734, 0.10554746331763454, 0.09118963687797077, 0.13495182181941345, 0.09866042193607427, 0.14670663949800655, 0.1461830988409929, 0.11687566482578404, 0.16663760907249525, 0.16009486484108493, 0.12889991921838373, 0.22116030449979007, 0.13729556871112436, 0.12314748062635772, 0.11802352237282321, 0.1249887712765485, 0.13890558388084173, 0.1315115368925035, 0.12661818618653342, 0.14290991588495672, 0.14814331865636632, 0.23016953200567514, 0.10923734735115431, 0.11868496891111135, 0.08695083073689602, 0.10224044584902003, 0.196921746537555, 0.09554012882290408, 0.10706044267863035, 0.1574617248843424, 0.15850499155931175, 0.1140434734406881, 0.09672864121966995, 0.1372148675727658, 0.12427567868144251, 0.10428016452351585, 0.09429416677448899, 0.18252638226840645, 0.08346048794919625, 0.1661122724181041, 0.10363416207837872, 0.06972480390686542, 0.08252538929809816, 0.18415230908431113, 0.20229195681167766, 0.17007286223815754, 0.10601041503832676, 0.16021317802369595, 0.1348277198849246, 0.15247472998453304, 0.11587522007175721, 0.13569868955528364, 0.1052984876150731, 0.10909173055551946, 0.11814149416750297, 0.1146486280777026], [0.0047092558725125855, 0.07581212921650149, 0.007810105180396931, 0.042291270510759205, 0.04223706775519531, 0.02703852343984181, 0.021827333148394246, 0.05562662525335327, 0.028389900144247804, 0.016112129960674793, 0.025227573642041534, 0.021658659679815173, 0.06824922136729583, 0.04417132353410125, 0.015752678154967725, 0.04682353297539521, 0.0184555002124398, 0.023831282160244882, 0.04879148596955929, 0.05427360098110512, 0.01648985158681171, 0.10221677875961177, 0.020609160819731187, 0.055061795210349374, 0.018238154843857046, 0.03285741579020396, 0.02456739246554207, 0.04260775196598843, 0.051560179199441336, 0.041768757728277706, 0.0038418378426285926, 0.0009755550922818657, 0.022083012299844995, 0.04912463977234438, 0.014900730657245731, 0.021589780953945592, 0.02423057801934192, 0.0571028831473086, 0.010927499279205222, 0.07750861201202497, 0.022575750117539428, 0.06753917899914086, 0.03138618223601952, 0.02924791377154179, 0.0717309997708071, 0.0385367231501732, 0.018160620820708573, 0.035810992849292234, 0.026623816884239204, 0.03629228303907439, 0.08634572062874213, 0.01950547219166765, 0.07636332971742377, 0.02058283684164053, 0.019188243022654206, 0.02249839606520254, 0.044665111490758136, 0.057990317363874055, 0.08877132640918717, 0.015332221810240299, 0.0469702036207309, 0.032977216978906654, 0.03886821825290099, 0.015246770926751196, 0.060469124000519514, 0.049399397685192525, 0.02534022609324893, 0.01794814394088462, 0.031208675354719162, 0.0634186489332933, 0.09778594932868145, 0.034531827113823965, 0.030511433178617153, 0.06883502821438015, 0.044370126342982985, 0.05185210298805032, 0.018875437053793576, 0.03974366307375021, 0.08839892412652262, 0.12269511193153448, 0.04943738822476007, 0.12308842793572694, 0.03876803944876883, 0.0583098045171937, 0.05744549191149417, 0.041062333330046386, 0.05294472990499344, 0.07336149821639992, 0.036472272404353134, 0.03499537626339588, 0.03406646712392103, 0.03866681050567422, 0.04200746952847112, 0.04095718955795746, 0.05256023803667631, 0.050784497580025345, 0.06410264933947474, 0.04698831573477946, 0.033076289983000606, 0.026521721483732108, 0.010674460318114143, 0.02973228387418203, 0.021804090938530862, 0.152617355925031, 0.05940096569247544, 0.013572941261372762, 0.09033959577209316, 0.02117692791216541, 0.02450945114105707, 0.014426787729462376, 0.01751018218783429, 0.07774125304422341, 0.012286305809539044, 0.031108893599594012, 0.07383613134152256, 0.010178989541600458, 0.027598371816566214, 0.016823343066789676, 0.042014486534753814, 0.05621825795969926, 0.021426905514090322, 0.018996848702954594, 0.04008933319710195, 0.02362521929171635, 0.02512301431124797, 0.005882980976821273, 0.04918197068036534, 0.01431186894478742, 0.0494667735620169, 0.05851803631230723, 0.022056562156649306, 0.05119791465403978, 0.0405176414642483, 0.03676845983136445, 0.037145830792724155, 0.02443072782625677, 0.0358693627640605, 0.009622004927223315, 0.007574140254291706, 0.04716974115581252, 0.03898574104823638, 0.03448466362897307, 0.020445535810722504, 0.061285382544156164, 0.07758378415019251, 0.08197720933821984, 0.04002577938081231, 0.04983103077393025, 0.06707944819936529, 0.041344201017636806, 0.030317311466205865, 0.021227241813903674, 0.040184242752729915, 0.03149357842630707, 0.09216297839884646, 0.0185132430124213, 0.029080602143949363, 0.013166142289264826, 0.022528067129314877, 0.028841096245741937, 0.05451444274513051, 0.034222062095068395, 0.04722043355286587, 0.03874235371768009, 0.051307700559846126, 0.03436476967181079, 0.05422939866548404, 0.00992417313682381, 0.0350901411002269, 0.04603766537911724, 0.009406154058524407, 0.02026084122917382, 0.06040921784006059, 0.017074458010029048, 0.01483107731473865, 0.0585810743359616, 0.02836377840139903, 0.007722500213276362, 0.015722198149887845, 0.02108748427417595, 0.03865231265081093, 0.03641957991931122, 0.028679079841822386, 0.08900348504539579, 0.027141181017213967, 0.023756451410008594, 0.019553296187950764, 0.016197020522668026, 0.04594636266119778, 0.03263689031882677, 0.022716372259310447, 0.02629162230732618, 0.04987996428098995, 0.05133281483722385, 0.068551371950889, 0.06999264500336722, 0.01916395252919756, 0.09007581422338262, 0.031500829209107906, 0.04701070261944551, 0.042824340343941, 0.07261219623615034, 0.05267112974252086, 0.02488689817255363, 0.025298205691797193, 0.02452417349559255, 0.02717831994232256, 0.021399874640337657, 0.00806018297225819, 0.027109287220810074, 0.060026700084563345, 0.03292060595413204, 0.03828553584753536, 0.07757857427350245, 0.05419205379439518, 0.01561810822749976, 0.09625057195080444, 0.006907013967065723, 0.037945116418995894, 0.03061321873246925, 0.05538704885111656, 0.07105486612999812, 0.023943908636283595, 0.049636176190688275, 0.030872476891090628, 0.0533421388536226, 0.07683725038077682, 0.020650919614126906, 0.043880446173716336, 0.0030407397525777924, 0.06210192681464832, 0.08699820944457315, 0.07155382685596123, 0.08577827451517805, 0.09307578293373808, 0.06960530328797176, 0.0648289595847018, 0.04766211161040701, 0.05525939573999494, 0.040864075999706984, 0.022674819410894997, 0.014979979041527258, 0.026121998889721, 0.04134668721235357, 0.04978756689524744, 0.0270940323753166, 0.015018937156128231, 0.026947148362523876, 0.03709505675942637, 0.053461791612789966, 0.08134176765452139, 0.01647138509724755, 0.02176712641812628, 0.03382345828867983, 0.06266850090469234, 0.09236258643795736, 0.02882955399400089, 0.03165391943184659, 0.017689360756776296, 0.046978541649878025, 0.022507021676574368, 0.027441639504104387, 0.028534737684822176, 0.1130432661739178, 0.05987488264509011, 0.016638936067465693, 0.046178647462511435, 0.01736515168886399, 0.10534597764490172, 0.007363825343418284, 0.020247935281076934, 0.029375665217230562, 0.021866427632630803, 0.037559874981525354, 0.022666143704554997, 0.024306841114594135, 0.057923219792428426, 0.03413412130612414, 0.009891331246763002, 0.016680299668223597, 0.031773594455444254, 0.01853762070822995, 0.06669325681286864, 0.026944485907733906, 0.054156074475031346, 0.03949213067244273, 0.013571440267696744, 0.040538154426030815, 0.00715053210115002, 0.036683313228422776, 0.016322001902153715, 0.04695140873081982, 0.03423204027058091, 0.022957128676353022, 0.017028242618835066, 0.012497039570007473, 0.014812701738264877, 0.057157431001542136, 0.06197719034389593, 0.027028582371713128, 0.1014061011665035, 0.03197009289579, 0.03967439472035039, 0.035725616180570796, 0.02926479392044712, 0.07054602741845883, 0.022704227012582123, 0.025133678973361384, 0.040679077137610875, 0.049806888710008934, 0.0254216563916998, 0.039260799530893564, 0.01882075004687067, 0.07378130889264867, 0.05632435539155267, 0.05627340324281249, 0.0609649491525488, 0.03872862027492374, 0.02650688409630675, 0.05576696166826878, 0.07620405740453862, 0.08967915855464526, 0.039897981550893746, 0.042476844537304714, 0.09053639849298634, 0.05562933780311141, 0.04919676168356091, 0.01833601258113049, 0.019396046227484476, 0.04098967336176429, 0.03270593973866198, 0.05141055109561421, 0.06735832503181882, 0.07179348118370399, 0.050847383463406004, 0.018896347064583097, 0.036015287550981157, 0.04306408001866657, 0.010326027550036088, 0.13084280246403068, 0.029925635608378798, 0.02229713118140353, 0.1011482196918223, 0.026667377242119983, 0.06936136676813476, 0.017609062233532313, 0.04644929387723096, 0.021272941412462387, 0.030524437461281195, 0.034872587930294685, 0.03701004745380487, 0.0600017231045058, 0.07493709999835119, 0.2325224518426694, 0.0819461207720451, 0.15778917528223246, 0.1392564713023603, 0.07671371247852221, 0.12673718214500695, 0.24684416537638754, 0.2210238977568224, 0.11333077418385074, 0.16302617004839703, 0.07854642390157096, 0.190805945021566, 0.10045612245448865, 0.12904638948384672, 0.15853536024224013, 0.21596163423964754, 0.15381191682536155, 0.22691134043270722, 0.15712381020421162, 0.10307180709787644, 0.2019160590134561, 0.15583149361191317, 0.13528437819331884, 0.1248897539335303, 0.16376610612496734, 0.14521238452289253, 0.1292082222062163, 0.11539341780007817, 0.1149211372830905, 0.18903783755376935, 0.087286578345811, 0.08099211961962283, 0.22439241700340062, 0.12586704368004575, 0.11137576424516737, 0.09453332386328839, 0.25744108424987644, 0.16955925151705742, 0.16702812717994675, 0.12736205564578995, 0.12084427726222202, 0.08534074135241099, 0.12250032785232179, 0.14235492300940678, 0.14312313491245732, 0.06718408360029571, 0.10409827154944651, 0.13843504741089419, 0.11686810976243578, 0.17767989076673985, 0.1501149230170995, 0.3365960024530068, 0.12579823174746707, 0.17145002115285024, 0.1819831895409152, 0.11134803018649109, 0.18635638378327712, 0.18490554444724694, 0.1481770715327002, 0.0841004418907687, 0.15870269970037043, 0.16855625377502292, 0.09061354474397376, 0.15217424923321232, 0.10637205617967993, 0.08499156829202548, 0.13903774553909898, 0.16973350779153407, 0.1491014609928243, 0.12929787364555523, 0.13606629014248028, 0.13248280039988458, 0.06850011923233978, 0.12529940460808575, 0.1554849254898727, 0.114183813566342, 0.13683858385775238, 0.11138886315166019, 0.1755088713252917, 0.10937934246612713, 0.2054976488579996, 0.1164335897192359, 0.13383150537265465, 0.1512173833907582, 0.2207522717071697, 0.1224118415848352, 0.18568717438029125, 0.32520783541258425, 0.11917495707166381, 0.17895705270348117, 0.23058850405504927, 0.22974736872129142, 0.13714178086956963, 0.19486926292302087, 0.15185444295639172, 0.13642547477502376, 0.19645480206236243, 0.11977182934060693, 0.0878377268963959, 0.1124294803594239, 0.07694588595768437, 0.10469262793776579, 0.2938627533148974, 0.24059740448137745, 0.1959289310616441, 0.1739817243651487, 0.09170355187961832, 0.14826360595179722, 0.12474752875277773, 0.1467008507461287, 0.1272168173454702, 0.08693413241417147, 0.12573295243782923, 0.11790075630415231, 0.21136299037607387, 0.10201817261986434, 0.08130247835651971, 0.07373521410045214, 0.14339027839014307, 0.09158148342976347, 0.20347637997474521, 0.12410355979227461, 0.10077995859319344, 0.1515167360776104, 0.08914398102206178, 0.1478796187439002, 0.09931597582180984, 0.14788062806474045, 0.1278327257023193, 0.2239469948108308, 0.13030250411247835, 0.22037284128600731, 0.08816666901111603, 0.13122827396728098, 0.1252375985495746, 0.15040357393445447, 0.17034738266374916, 0.20658026420278475, 0.14352683356264606, 0.10965842709993012, 0.102932120062178, 0.09907611369271763, 0.17065434978576377, 0.17482125665992498, 0.22889355750521645, 0.13020828104345128, 0.2392588966176845, 0.21443849487695843, 0.18180250626755878, 0.10488873303984292, 0.1718047380563803, 0.19757608330110088, 0.09827554415096529, 0.19439716794295236, 0.08254714906797744, 0.18039833317743614, 0.14035599277121946, 0.15457235102076083, 0.10702198458602652, 0.15291558054741472, 0.12429936803528108, 0.1625902473460883, 0.26294832467101514, 0.1383963815169409, 0.12420252518495545, 0.19107534462818876, 0.13210890640038997, 0.14731150469742715, 0.13095360511215404, 0.14648625132394955, 0.07611728549818508, 0.19208677316782996, 0.10680240535293706, 0.12958345207152888, 0.125421205884777], [0.016134431498358026, 0.05393098479544278, 0.01576068036229117, 0.04256066640664358, 0.08424933155765757, 0.034897331133834086, 0.014240512373362435, 0.04695468531281222, 0.025406639033462852, 0.02722842418734217, 0.05204860142839607, 0.008519014845660422, 0.037210954251349904, 0.04308451134420466, 0.0051773604172922205, 0.039040077390382066, 0.00835688804727397, 0.044548297446453944, 0.0835106497106608, 0.017482277435192373, 0.05827965847856831, 0.058217548139509745, 0.062117330089677125, 0.027136436838191003, 0.07633505389094353, 0.049877489218488336, 0.023347041933448054, 0.023821888426027726, 0.016722548280085903, 0.042804146505659446, 0.024341221105714794, 0.014254134493967285, 0.010162786602450069, 0.025267393575632013, 0.015971971661201678, 0.045464638315024786, 0.04374777985503897, 0.029111275107425172, 0.06521371862618253, 0.03048131868126802, 0.01913655985845253, 0.059852970734937117, 0.06415872601792216, 0.015960976743372157, 0.04906643684080336, 0.0485617764206836, 0.04790249695361126, 0.06764851219486445, 0.03421792833250947, 0.0200115742336493, 0.008521424970240332, 0.023903008877823595, 0.03193057724274695, 0.03982619731687009, 0.02842766432877397, 0.046513452543877065, 0.042619066007318906, 0.044645578163908795, 0.027880133748112712, 0.049333342831232585, 0.01826160485506989, 0.03452358927461319, 0.025386441484442912, 0.01834569946367992, 0.05581634788541123, 0.12240633484907448, 0.016321964794769883, 0.013811715216434095, 0.022727016512362752, 0.02961543643323239, 0.019596993843151722, 0.04253981947840657, 0.08004763280041516, 0.015586283079755958, 0.01657692962908186, 0.07131544902222231, 0.03763167034776416, 0.004812945498997578, 0.05676809661963489, 0.03244428073230665, 0.04357043253548909, 0.038270466538961045, 0.07596556082717143, 0.024932842679845635, 0.009185933795379242, 0.06682210107101128, 0.08934684708947316, 0.06859878776594996, 0.030993895961728413, 0.033264721278101206, 0.02548242344346363, 0.017529201577417552, 0.042900369662675075, 0.04495137640333269, 0.080722912971396, 0.07212977798189968, 0.03226512257242575, 0.05412465565314051, 0.034660493256524205, 0.05454770209325943, 0.029605749550682958, 0.016999495528580155, 0.06063162836653646, 0.04167819344729651, 0.014209806940925773, 0.04331289615947753, 0.030999525151855778, 0.10024390532635152, 0.046292659899336286, 0.02270569089887431, 0.039459858380723745, 0.015473857911274536, 0.07620384960318916, 0.06473328190622851, 0.03574819231289439, 0.04772580272401683, 0.03628535880125128, 0.02047338490228867, 0.04211754858260974, 0.0027509109077072935, 0.043940578689216636, 0.02375851086981129, 0.06691286573186517, 0.007860348578105913, 0.06266527256229892, 0.0334149542322848, 0.024014459049794823, 0.04373341187601909, 0.010802730339491973, 0.03743961737200152, 0.0030081555269134697, 0.057946170709328726, 0.019567445233406033, 0.06378755570040084, 0.019314461933390703, 0.03812197763181757, 0.05904711339098867, 0.034868387374444865, 0.01752919972204836, 0.0308818669145694, 0.039479024344473146, 0.023817821456759702, 0.017477655710536055, 0.02863314646674553, 0.0823752602445893, 0.08208486528019421, 0.01904964323330205, 0.03653589672467206, 0.047391795451403596, 0.0908392170094885, 0.07966584977111779, 0.06323593217530288, 0.019030369658139534, 0.062311854417202994, 0.008649166211398551, 0.07666640798561275, 0.02119549459166592, 0.03476658326690085, 0.03100267371337395, 0.07412024773657322, 0.025746219835127704, 0.06106581073254347, 0.029685526715184096, 0.021256562213238794, 0.01821581619878998, 0.05226140114245936, 0.03819486024440266, 0.030274895871116314, 0.04798986257810611, 0.012791263088729465, 0.0500373552495148, 0.02071692066238029, 0.032700700176064856, 0.031210389715852216, 0.011894775598193519, 0.05171007076569367, 0.026496069149288815, 0.09751508026965894, 0.04468168735911604, 0.0327857651427621, 0.09822316336794756, 0.028088938852306455, 0.05737554449297022, 0.018111681747541297, 0.05455462262034416, 0.023213410822791047, 0.011391527114028577, 0.08446073232335038, 0.022533117444254458, 0.046957242011558264, 0.02452301388984779, 0.07738451749901287, 0.022575367911485955, 0.027104379769298248, 0.05605636215477716, 0.029497342184185982, 0.04811217964743264, 0.06997262185905129, 0.057947662426158786, 0.08879386543412693, 0.043023458565585315, 0.024774086159595754, 0.043224283726885915, 0.05202839274716098, 0.04815892381884623, 0.09527563481242396, 0.02756612178927753, 0.01506049000454368, 0.08184649486793205, 0.029004888237977866, 0.0227711371917394, 0.006317726911220234, 0.01698151700111339, 0.03710360258992296, 0.06125777093984652, 0.01608504528121557, 0.024541187231079675, 0.030804288362560328, 0.023619742241862696, 0.055327012814814225, 0.016784231884230394, 0.03134742357360665, 0.06145994680991862, 0.11170741519890726, 0.010420282160339411, 0.08525212891981937, 0.049512812693137676, 0.0415606075694086, 0.03471665899269283, 0.07698339410126209, 0.02124377315340098, 0.0039412573369190795, 0.019889557734131813, 0.038082654937170446, 0.07485371970687993, 0.015295255434466526, 0.03255410003475845, 0.07650803367141634, 0.023779291004757397, 0.027447181491879746, 0.04333377648435999, 0.07316139293834567, 0.03319327472127043, 0.059989084329572506, 0.006405498861568049, 0.017183683594339527, 0.01763390377163887, 0.022891814114700537, 0.055424935490009375, 0.06532623563543893, 0.017587296897545457, 0.06256667824345641, 0.05201399137149565, 0.02921399391198065, 0.04710537468781695, 0.058763219640241005, 0.05186281217902433, 0.03795496842940338, 0.03551848647475708, 0.03820422614808194, 0.008430968300672248, 0.038927786736167036, 0.05991474710754119, 0.020401415131345857, 0.01745137069519842, 0.07806196474120952, 0.02359010457439581, 0.06739650110830553, 0.06024288399203215, 0.020405706600286067, 0.06592716003069654, 0.03660938047687523, 0.005803776193715748, 0.01605386580195045, 0.046353033612831496, 0.021099004261486698, 0.03424778864427935, 0.038349512688000686, 0.02612425130791962, 0.05693534702004399, 0.04219378199195489, 0.016587572026764974, 0.10236113390419632, 0.007582024645671481, 0.06653190648648888, 0.1102371167507954, 0.03245722007704899, 0.06950130613404326, 0.03171553624270018, 0.02297900904522976, 0.08519076072843745, 0.01843406142143067, 0.060261196485953405, 0.022896215050423052, 0.021649137925123796, 0.013698079419555143, 0.021841892230440862, 0.02241241640149383, 0.0780453703191597, 0.010555479202594142, 0.02919802846008679, 0.06011761688569095, 0.01788238780136453, 0.04531527738436125, 0.06253928557271138, 0.03532283408276271, 0.04404033817991149, 0.06852922626421787, 0.015090208380570402, 0.05639203925966285, 0.0164505919747171, 0.02277851785038365, 0.018723326465988066, 0.030726281220267992, 0.04211567837046459, 0.012206083356431918, 0.046941037217038684, 0.014808140313107288, 0.009198249736073194, 0.05245000313152559, 0.07375436893198639, 0.05909037317906041, 0.06788786966353655, 0.0369860501086805, 0.06173878653498832, 0.08049293624935672, 0.0410098338034004, 0.06264051451580599, 0.04583807960443664, 0.07894023714470677, 0.053621635379386134, 0.02489593010977842, 0.013595548934972612, 0.026604133272485342, 0.10435229385620914, 0.07514215540140867, 0.014557282338500954, 0.053529071010416374, 0.11426464829128236, 0.03724427297129296, 0.012155002259532921, 0.10595991931040771, 0.03793470037635416, 0.022892487613717094, 0.0266314758482622, 0.04758494680572767, 0.05050795109127648, 0.03768399175896775, 0.04770542334881611, 0.03405516792554408, 0.025303658621851355, 0.0832476771029178, 0.11268949921941385, 0.17626149812713265, 0.09323124060756527, 0.1312516664620489, 0.26756118808407336, 0.11562001775018871, 0.12572377949254587, 0.11846040244563483, 0.1324943482177332, 0.09452223617699929, 0.10917165243881755, 0.1843744338839315, 0.09238108817953616, 0.218713280337397, 0.07770352967781946, 0.16161031555384398, 0.11495206999825314, 0.12785482686012983, 0.26060756121296436, 0.18718800478382036, 0.12399643077515066, 0.17292012664256617, 0.11713994361343794, 0.13886268774513155, 0.2399064798373729, 0.1193293534743134, 0.09935637091984972, 0.1634764310438186, 0.0950212859606836, 0.26328196458052844, 0.1650793364387937, 0.07513235905207694, 0.11762784633901902, 0.11347850610036403, 0.0823454704368487, 0.21560185588896275, 0.11144028656417504, 0.08536040084436536, 0.17902632476761937, 0.16003953031031415, 0.13814081554301083, 0.235056247911416, 0.16900955757591873, 0.1215205667540431, 0.1467145507922396, 0.1463593143853359, 0.1744877058081329, 0.21084430336486548, 0.211854069493711, 0.11341387245920487, 0.08450417764834128, 0.150834895321168, 0.11370384439942427, 0.18634029402164742, 0.11941590273636393, 0.14945702394470572, 0.1902508334023878, 0.2345054704346694, 0.19366348074981943, 0.08322842579218559, 0.07545072556240484, 0.11715815591742285, 0.12902296730317175, 0.1332123315660283, 0.14589342375984415, 0.27274874097201973, 0.21835004357853904, 0.10265931399771944, 0.09548392597935162, 0.13453503168420866, 0.08745089726289734, 0.1856880055856891, 0.12829509854782373, 0.11998152316664346, 0.09237325852154754, 0.1714520249515772, 0.15273479337338358, 0.16370774363167584, 0.13242451212136075, 0.09720719288452528, 0.202640944335144, 0.09808752103708684, 0.14211681234883144, 0.12468829052522779, 0.09506611910182983, 0.16874982073204592, 0.14774438459426165, 0.22542661463376135, 0.15585942805046216, 0.2292849068180658, 0.11425382777815685, 0.14358553744386882, 0.17367584077874199, 0.09485719710937701, 0.18477661855285987, 0.14956844999687746, 0.10182824960793369, 0.1757946575526148, 0.09418928646482527, 0.19054393720580265, 0.15692660672357306, 0.07453087804606184, 0.10279975802404806, 0.1731274975463748, 0.09244860877515748, 0.05990766701870598, 0.19001848180778325, 0.13831191026838496, 0.17628578119911253, 0.21369275520555675, 0.13211086567025632, 0.18011634674621746, 0.1564029324799776, 0.15630207461072132, 0.14804838312556967, 0.14540802949341014, 0.167036127531901, 0.09573518749675713, 0.11298722660285421, 0.13230662938440219, 0.1496343527105637, 0.0915181782329455, 0.14921785943442956, 0.10327809446607716, 0.1320199971087277, 0.1391406072070822, 0.10687020054319873, 0.13569111964898184, 0.18671154597541317, 0.09177799671306275, 0.18224015075247735, 0.17728874925523996, 0.18912639061454684, 0.15680452343076468, 0.11505062720971182, 0.19356824835995212, 0.1336535086738877, 0.1256628194823861, 0.2023549799923785, 0.08369050920009613, 0.13460271555231884, 0.1493387998198159, 0.07897433140897192, 0.13447251316392794, 0.24134341132594272, 0.1817783567821607, 0.17532235477119684, 0.12253914959728718, 0.1423574611544609, 0.25414508767426014, 0.12933187885209918, 0.10290121703292243, 0.13178353401599452, 0.1752565856440924, 0.15872992167714983, 0.18370525416685268, 0.17101206496590748, 0.11238043181947432, 0.17275808611884713, 0.21057634352473542, 0.07164803508203477, 0.18124246678780764, 0.14633028156822547, 0.22088185069151223, 0.10474863040144555, 0.17658850323641673, 0.22477370279375464, 0.06229463659110479, 0.16707789560314268, 0.15900147351203486, 0.1597721196594648, 0.09300412115408108, 0.13202431640820578, 0.14456229284405708, 0.14648120471974835, 0.26743873371742666]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.020163165318081155, 0.059591389654087834, 0.029045031005807687, 0.06780349489417858, 0.04154598354944028, 0.032188455006689765, 0.030594980453315657, 0.028141234288341366, 0.06207549522514455, 0.02329157381609548, 0.050626902520889416, 0.006541347602251335, 0.03524674539221451, 0.029164847037463915, 0.016823821752041113, 0.05734822232625447, 0.06053540149878245, 0.0347983546089381, 0.06042227592843119, 0.03697176005516667, 0.06959262740565464, 0.06609394287806936, 0.02586603215604555, 0.0644970266148448, 0.09291528607718647, 0.05297373303619679, 0.04821289279789198, 0.02121544908732176, 0.012084190238965675, 0.02094949861202622, 0.1290536773740314, 0.05645618308335543, 0.056169595336541533, 0.04355717035650741, 0.04777998692588881, 0.11033983741072007, 0.006613556715819868, 0.0798626450705342, 0.042652447809814475, 0.008588881555624539, 0.04097700861166231, 0.026583169455989264, 0.04525148979155347, 0.07146512536564842, 0.03274211943789851, 0.058599279218469746, 0.022886121842020657, 0.06697244534734637, 0.02463934368279297, 0.03325026424136013, 0.030106055419309996, 0.017383339873049408, 0.04799775160790887, 0.11820544503279962, 0.010369512765464606, 0.03677448978123721, 0.04070426934049465, 0.01631777351576602, 0.05433118421933614, 0.02224074094556272, 0.006579740756933461, 0.021651807801390532, 0.038994713613647036, 0.01596086542122066, 0.09342929013655521, 0.043064265555585735, 0.03134839207632467, 0.005246741020528134, 0.023864105496613774, 0.05323908422724344, 0.004973853783667437, 0.07275053998455405, 0.0048968619921652135, 0.05467354436405003, 0.033610001773922704, 0.08812385451165028, 0.04003289657703135, 0.06383897169143893, 0.03909274018951692, 0.014932954709365731, 0.09254745542421006, 0.05291494380799122, 0.017142691067419946, 0.011331705372867873, 0.02969985202071257, 0.025006356117955875, 0.043643641693051904, 0.05896704678889364, 0.1026073117100168, 0.028482282687036786, 0.022834089868410956, 0.031611431477358565, 0.05981329923088197, 0.04236172258970328, 0.06949041140615009, 0.028504558249551337, 0.01698213854979258, 0.02416736002487596, 0.012014634303341154, 0.030443912582995836, 0.046030644662096165, 0.023641084553673863, 0.034976752067450434, 0.015910616457404103, 0.056514144816901535, 0.07704482166445814, 0.036644283682107925, 0.07433499558828771, 0.05395238462369889, 0.03149076197587419, 0.06591331155505031, 0.04910272044071462, 0.024598902200523298, 0.016607745455985423, 0.016921102469495963, 0.06782649405067787, 0.09783992572920397, 0.07713321887422353, 0.03158567524224054, 0.0282855486148037, 0.04802975672646426, 0.09953671280527487, 0.012266935755178565, 0.036722353906952776, 0.02446331738610752, 0.08019875633181073, 0.07875185779994354, 0.050927312768180855, 0.05311491549946368, 0.013202360023569781, 0.027033569604100194, 0.05013528163544834, 0.07056763875880279, 0.08611964760348201, 0.08619233354693279, 0.0728640217857901, 0.0779922770743724, 0.008901799774321262, 0.06208808204974048, 0.04946259155985899, 0.0059509213497221936, 0.04577629952109419, 0.0476233158406103, 0.008352785825991305, 0.07127052682335488, 0.03688266522658523, 0.002054234619208728, 0.02319274757610401, 0.07015355746261775, 0.0875679859018419, 0.02305642432474997, 0.023518563393736258, 0.029906976160418708, 0.015396781236631796, 0.06643746077315882, 0.012917094227304915, 0.04162154902587645, 0.023422906124324072, 0.025437660806346685, 0.03373448591446504, 0.024661118295625784, 0.025532867221045308, 0.011323093676764984, 0.031358886044472456, 0.023007318268355448, 0.0572913812357001, 0.044780945900129154, 0.01587137910973979, 0.048640722379786894, 0.035448624403215945, 0.0532895539799938, 0.03404489289096091, 0.009230194555129856, 0.01683319322182797, 0.01984696587896906, 0.0244451514663524, 0.027311938065395225, 0.1006064964167308, 0.03127060757833533, 0.048159027719520964, 0.01615232653421117, 0.028247212976566516, 0.06192804161401, 0.0793767832510639, 0.021278444437484723, 0.09146992379100993, 0.06284537696046755, 0.03436079918174073, 0.013243494486232521, 0.08598459156928584, 0.06833136969362386, 0.015551256492472021, 0.061207278922665864, 0.005601506627499475, 0.037725125293945894, 0.04668976827815641, 0.13670621439814568, 0.031179286306723952, 0.020400826979312114, 0.022268102075031493, 0.04115514260774944, 0.014793443933740491, 0.039347211495623924, 0.04423337821208406, 0.01172654185211286, 0.02550989403971471, 0.021078975551063195, 0.05606463710137177, 0.0789852261368651, 0.07463875663233921, 0.05893420304346364, 0.10726206935942173, 0.12454725278075784, 0.027493584275362082, 0.020590128442563582, 0.053107902203919366, 0.006314074616966536, 0.08673998658196069, 0.06585016963072121, 0.009668691582191968, 0.046126214729156345, 0.10222489785519429, 0.01358677860480384, 0.028028242304571904, 0.02585003701824462, 0.10970803225063719, 0.04200007773761172, 0.03324827157484833, 0.03579622782126535, 0.030229725052777212, 0.022937209432711825, 0.07896077237091959, 0.013010710590606323, 0.02402967122179689, 0.06343636399833485, 0.0748945823579561, 0.017321654413535725, 0.012389099756546784, 0.045225655630929396, 0.006344079647533363, 0.017655748888500966, 0.054806830376037396, 0.05778942540928256, 0.13335734722204506, 0.0945242028683424, 0.05022555647883564, 0.051331594004295766, 0.024297742384078447, 0.05166782771993894, 0.0070146838243090315, 0.07418262524879538, 0.0354986303136684, 0.027961680934822652, 0.05327884849975817, 0.06432553855120204, 0.031122662294365, 0.020610608007700648, 0.02453854147461243, 0.038113546834210865, 0.030249067276599817, 0.01685896801063791, 0.06122345774201676, 0.028122756666562054, 0.05420429923105985, 0.01165073332231259, 0.03481614388874732, 0.027764252954511903, 0.0061137541160860565, 0.03390138008398935, 0.029302649018063676, 0.023883742724137846, 0.019883227214450017, 0.013078249739919556, 0.019075846612395253, 0.049859195278258994, 0.022780770268582273, 0.06864434079034254, 0.02459789287968306, 0.02468873732141219, 0.03845955463475548, 0.017371382018609438, 0.0332530361629324, 0.12418316255207174, 0.021926597255514935, 0.062453315185848624, 0.019210342325095553, 0.1120516455557663, 0.021319733823474962, 0.007946354216983309, 0.058341004405519925, 0.09158819244476035, 0.030802158398728352, 0.08207939565181732, 0.011246466929151211, 0.062121356240822934, 0.02661054728378076, 0.029036353444098495, 0.05280466808471829, 0.06704758037813008, 0.01949451438122196, 0.029364043184614275, 0.07810539522324689, 0.07230601579067297, 0.030465954368992243, 0.018180807237513363, 0.026231241172354203, 0.0831104614189826, 0.007435446768795373, 0.07022705976851285, 0.01648162487981608, 0.029632299883814994, 0.028682278498308733, 0.021421621422632597, 0.016668729585944675, 0.06993504692218266, 0.03041515992663335, 0.003465054801381484, 0.033881635245052166, 0.019496848435665015, 0.01465020850446308, 0.011190007116965717, 0.09914450260112062, 0.03976825042627752, 0.037046256838948466, 0.04040995212562848, 0.08775336696999148, 0.05397649700171314, 0.03140626475214958, 0.048871775215957314, 0.01964176019100705, 0.030937195879232604, 0.0486294343136251, 0.02052562096650945, 0.042377155550639145, 0.04697171018051449, 0.025403638901480008, 0.038380931509891525, 0.04832211467146408, 0.06528661979245953, 0.030251995049184188, 0.021861503482796252, 0.005947526024101535, 0.010842901865544263, 0.028673298511421308, 0.006720782212141785, 0.02508745059458306, 0.06711925700074062, 0.063031938043423, 0.005042198163209832, 0.03905440084054135, 0.01348198178675375, 0.03474958808510564, 0.13544591405661777, 0.1945240009808913, 0.13295455399202183, 0.17577850841917098, 0.11683642005664296, 0.11220398620935157, 0.1489001460140571, 0.15366538718808442, 0.10044742448371835, 0.21399709512479603, 0.17558488209033385, 0.10724032443249598, 0.0956048366788309, 0.17085907864384353, 0.11124533179099672, 0.08889715754776262, 0.1232956133026164, 0.17213966930285096, 0.1660685005481355, 0.19612913281889632, 0.19029273506021127, 0.12563967931782827, 0.11693787164404057, 0.1591551277670078, 0.13162486284272745, 0.10625755021465011, 0.17598044680198655, 0.17470846505602822, 0.10011944716097787, 0.12595592328580096, 0.20145260263234377, 0.20940893038641661, 0.15710277773905545, 0.163005419599358, 0.14140657702228054, 0.2238143581780605, 0.13554933975683525, 0.21255504281725734, 0.1649238565005362, 0.0762456918891985, 0.12106692156521603, 0.13414086221018806, 0.19260851782746613, 0.12675652251346037, 0.16294871951686218, 0.2260572768864222, 0.0825609678577166, 0.09855449519818649, 0.12147739602369256, 0.2604216680629179, 0.16142620355822146, 0.08658589445985854, 0.14053161459742114, 0.22091210063081235, 0.13240166881587356, 0.13893872819608077, 0.1305537804728374, 0.11149087134981528, 0.15447351179318503, 0.10445555628393777, 0.10690441355109215, 0.08571056838263758, 0.09506577771389857, 0.0985749413666781, 0.08410637907218188, 0.1235313861980103, 0.15277170779882, 0.16323670250130817, 0.13483762013493106, 0.1277018553810194, 0.10409695052658208, 0.15145479643251747, 0.10182919955695979, 0.12499162112362683, 0.13660476281074807, 0.18608671700349078, 0.12766997271683067, 0.22406306670745835, 0.194371088873595, 0.1654362797853537, 0.1359440287342295, 0.1575253120972775, 0.10935263999272138, 0.13584576838184148, 0.09217402897775173, 0.2296040006331168, 0.11766015202738345, 0.14140368264634162, 0.13317900913534686, 0.14375603845110163, 0.09030651825014502, 0.12955832295119762, 0.15585896791890264, 0.13379938522120938, 0.1006341191532556, 0.09664146113209426, 0.119495030521648, 0.0796293509483803, 0.062362350145122036, 0.10544972989009693, 0.13954579015262425, 0.091469953476917, 0.07433472099364735, 0.11945747042773291, 0.07853263479773887, 0.20377231878228486, 0.2310641761869192, 0.14569779363228008, 0.14336823660414666, 0.08891599325579591, 0.24998214386869222, 0.17879894556244835, 0.11978607115452178, 0.18164046574383974, 0.169549826241564, 0.19665320782223716, 0.21111009613377973, 0.11150093487231061, 0.12240509546245448, 0.16923603136092424, 0.14502509613521397, 0.25137242395430803, 0.0965125129732769, 0.11009795663994737, 0.12669685384025797, 0.2619325916748494, 0.16763922641985118, 0.11078016847022809, 0.0883794279070571, 0.13347448781132698, 0.13866480148863047, 0.1269181029056199, 0.24654743989231065, 0.16748741269111633, 0.14350730023579672, 0.12466970714740455, 0.20894869492622092, 0.12605502968654037, 0.10080318781547248, 0.13705727993510664, 0.1544123885105364, 0.14034828927833587, 0.14079106942517683, 0.08243093616329134, 0.1592493656789884, 0.15721969568403438, 0.16082463349448517, 0.19664937834022567, 0.19649970199679956, 0.10964044486172497, 0.16091260768007487, 0.10713332900195383, 0.1383067003916949, 0.2574021660257131, 0.15329943416872993, 0.1527295241248794, 0.10596711072139442, 0.13556980818975717, 0.10360631669755094, 0.15052101138280705, 0.07579668512335047, 0.15909372246824205, 0.114015256986022, 0.1300881421775557, 0.19983595266239718, 0.1174584733962547, 0.11745574971428141, 0.14249839499825612, 0.13435215165372938, 0.11157851899042726, 0.11706494216923602, 0.2033753736759536, 0.08392470132093877, 0.20785353728570044, 0.15623354469425976, 0.1048656967759598], [0.041058270071516745, 0.04245828713465016, 0.035532212496036664, 0.00373421529729967, 0.06196255890245084, 0.021955643060209695, 0.07425678064464591, 0.01940813581313705, 0.09102861309656873, 0.06299046683125198, 0.02111896246788092, 0.03740786458365619, 0.06695844102068804, 0.0589821049652528, 0.007321756702367566, 0.023048693001328502, 0.038821726411697455, 0.03327753445773851, 0.008218951552407816, 0.029456264310283586, 0.01354510422970634, 0.015481912068935344, 0.060237577636144124, 0.017514514474896714, 0.020544723847706337, 0.015004576598585118, 0.07236661956994794, 0.049556970479898155, 0.06532475876156241, 0.053274013407644816, 0.039215895885718055, 0.04705821491370443, 0.012740742313326336, 0.038243188901105896, 0.04142673897149507, 0.05565272658714093, 0.12161526479758322, 0.018648330587893724, 0.034421614473103546, 0.03538109267537948, 0.08287939373985864, 0.020925441895087715, 0.03130246426735539, 0.05091913430078421, 0.029797899005643558, 0.014757933095097542, 0.007596372215630254, 0.0648354236909654, 0.0236365611635847, 0.04354978598712478, 0.06951990435482003, 0.05193120479816571, 0.005546469883483951, 0.019490226623020135, 0.047712117520859465, 0.03647237259428948, 0.06498300717794336, 0.05632754662656225, 0.04945796055835672, 0.07669335536775179, 0.05644861317705363, 0.023318068488151766, 0.03748885515960865, 0.033203267739736475, 0.0436067050031852, 0.04664460488129407, 0.027178360760444775, 0.031609527868567966, 0.010184552866121521, 0.027531133237062022, 0.061313751139095984, 0.058066858764505014, 0.02264289592858404, 0.03566709412552882, 0.00890593446456478, 0.05975925232633017, 0.030945342805352993, 0.002983622443935019, 0.01167585965959006, 0.06279951965552755, 0.033593500120332465, 0.03177242186211515, 0.05167997667740565, 0.008868784407241037, 0.03462278844381217, 0.026137797358387616, 0.00868460190758924, 0.01723588811728405, 0.04464421632292215, 0.03779445672989823, 0.0229880075858091, 0.03862392179144081, 0.017758009416866116, 0.0446409954020055, 0.03142344547086395, 0.0690526184916962, 0.06535322754643857, 0.0249787296706927, 0.012038065760862082, 0.04767657235788647, 0.058597108436515555, 0.022197128637344576, 0.01389384127833182, 0.04345560744695831, 0.11475206119939685, 0.024806692417769227, 0.10528395636356436, 0.0429725361027522, 0.03517736942740157, 0.03772519208723679, 0.013001747302041622, 0.009276399741793284, 0.018496912052796688, 0.033996746060438454, 0.027934162098972593, 0.017826954936026596, 0.028960016134078614, 0.017257859399251174, 0.03691501544381026, 0.01909750990307657, 0.0249871845880989, 0.04455156289623119, 0.013299229776748689, 0.10950808282359503, 0.06757348848623224, 0.03963368792028632, 0.018150202922697645, 0.0394248995144153, 0.015021235958556645, 0.05529923422727734, 0.043806105240946636, 0.043571070782491006, 0.06373305237502791, 0.02401313431619201, 0.03776599907723721, 0.04167193343164399, 0.04807418539712671, 0.09635802751290612, 0.06845816562417895, 0.03187431502738036, 0.05104789321194403, 0.029563345087808557, 0.010784197984321509, 0.03347393270814791, 0.032130845793290064, 0.06124418963736389, 0.03666642565804068, 0.011176547341165133, 0.025810012994043063, 0.0401705464173574, 0.037398606291390024, 0.04946823188220151, 0.03475529891147744, 0.011890809746546438, 0.057741293421713635, 0.022937953435757663, 0.07179631618782878, 0.07331976725254208, 0.03304041827504989, 0.041221627907361835, 0.024028083025768865, 0.07453295605955645, 0.031851182284299284, 0.08055923230131157, 0.03685788862640038, 0.09333753841929138, 0.04171241387666669, 0.019551520599634387, 0.051403177858446725, 0.04511567676672712, 0.04892413744528312, 0.027996051649097353, 0.0407748364523286, 0.052943041519029066, 0.03742701570445206, 0.035070967715000734, 0.03809662215644494, 0.020922905605402775, 0.036610464012483135, 0.05477039834659081, 0.01446732569093001, 0.026501488682697527, 0.03726456328877248, 0.09534222772344947, 0.039709156917524524, 0.016323621639457997, 0.027911290962947533, 0.03721643501194194, 0.027665853449434508, 0.01351923852780601, 0.04455866896023508, 0.04813055151316803, 0.018820011609932408, 0.010562739262240939, 0.06575568681000732, 0.018636074019013904, 0.05626931771985255, 0.042071509451488964, 0.02995220449520275, 0.05366597128158901, 0.03810886759310961, 0.04929129274387378, 0.02010401243751403, 0.025868256743706297, 0.028936363887623884, 0.05736706545576453, 0.013608114422822837, 0.061814886357751675, 0.06327502109343186, 0.041049171341001056, 0.054993139128782786, 0.04888783900241833, 0.03705734452523757, 0.017873200013127644, 0.039400620153173804, 0.028388777645886876, 0.07002530692261644, 0.055002308363327757, 0.0502233300358057, 0.03493176307529211, 0.04036334896227345, 0.030864211221341975, 0.020829046188737266, 0.07664093747735023, 0.021749782426923048, 0.05553294024139177, 0.07986669719684869, 0.03844351311272476, 0.047141966279014014, 0.026148159595322795, 0.06786761645344086, 0.01100978397516883, 0.017566950918990187, 0.018544817685324233, 0.01655605672567617, 0.08177302224794403, 0.0075094843487022445, 0.07306067607714795, 0.04714733200671617, 0.03692172816954553, 0.03362049945280887, 0.032266399066429585, 0.0258569686775445, 0.024560073034081142, 0.038557291773031466, 0.051679364405572414, 0.04822720140509773, 0.03906537720467895, 0.00368482792055147, 0.05536114418646321, 0.05809055553982034, 0.10957942547975108, 0.04403475351864472, 0.03850919318210799, 0.03412088881304953, 0.0380569692060817, 0.022998264066700358, 0.026164512819377705, 0.031241990363923833, 0.06607425370020792, 0.02623024112835992, 0.033225587831111625, 0.05337919428711757, 0.02287625498865964, 0.0443274528515758, 0.018126318755093962, 0.028722309943987057, 0.023285083734663203, 0.02474472679750761, 0.03645006363512948, 0.00488222034618957, 0.035456806581350975, 0.0592456304730149, 0.020278550728107803, 0.03325440171465743, 0.049138555041281506, 0.058129941317019984, 0.024975408559839707, 0.0561881935573183, 0.03851399116683751, 0.01753893113345839, 0.029188382395659573, 0.08714585972484201, 0.05090086633572355, 0.016780339319666382, 0.04330746363848448, 0.07303398844669573, 0.027510082218213938, 0.04404582636198029, 0.04307042167056352, 0.03598802475607954, 0.03599832205509301, 0.005639745786538697, 0.029753531562164426, 0.056177525184466504, 0.03341633091622498, 0.014120534924586536, 0.03742972083273344, 0.011042423629987752, 0.044772051260224544, 0.04256518237525597, 0.03768397691601422, 0.026135595035157166, 0.06426728738006204, 0.019183033145964146, 0.05565832609136123, 0.03812687209574506, 0.03701842259033583, 0.03415871236938983, 0.0373628236411605, 0.04848010306886863, 0.07696126325754449, 0.01974334350961726, 0.07336770257097669, 0.03702579211676493, 0.036284000671003014, 0.033147105714306235, 0.0630120633286424, 0.0674569490365684, 0.006499184801214142, 0.08344441303052008, 0.0485480763745727, 0.057254733983427286, 0.006607985505979741, 0.053642107523046434, 0.053107638741494156, 0.04639223756385036, 0.01869595977041172, 0.037519747056649067, 0.028482358757173643, 0.054186780835152604, 0.050165921202278696, 0.04266316071152687, 0.026310311441193335, 0.11706300516379997, 0.1127904535678681, 0.0319175080221612, 0.04678853329096455, 0.045006744330748916, 0.029424782405840233, 0.01805042858904926, 0.037872282046009786, 0.032251088559860364, 0.035384807124501094, 0.07991110731381923, 0.04264455878001172, 0.02718566534895217, 0.021405424049589783, 0.031259193347068503, 0.04404821236676071, 0.010746200950961793, 0.024297144955198746, 0.11855844015371986, 0.07279685742105357, 0.30678081326186657, 0.11571566574275494, 0.17811351281125098, 0.20042542571900412, 0.09174817721941508, 0.2869049704167992, 0.20401801419211552, 0.1822535984683782, 0.09341052864328958, 0.13024733285419643, 0.18043118063360453, 0.14005401288159192, 0.18513504619477317, 0.17081621219404042, 0.13128847698681056, 0.12249455394339748, 0.17029544716933742, 0.1269664612482302, 0.1132749646785669, 0.1809259259607643, 0.11005719788954593, 0.15171821432886645, 0.1141365832882002, 0.11264472545008175, 0.16554892295971513, 0.14806672901613638, 0.14590054837753996, 0.24401036353083327, 0.10707895926316269, 0.15186640637693927, 0.1226077091996558, 0.1848063341458328, 0.11007100183633156, 0.18942080059787259, 0.16352548700524494, 0.08677765799802728, 0.30679951538331807, 0.13481174886692315, 0.1720306626521051, 0.17215209285495803, 0.12261176132597029, 0.10701973587856628, 0.1314388806349598, 0.09893411857774481, 0.16794494673376903, 0.17940391466254368, 0.18946148513350636, 0.15802145266206935, 0.13869206799427047, 0.1307487129815854, 0.18903651653090492, 0.11871008318848908, 0.12342988266027533, 0.0864618741616141, 0.1705118574318476, 0.15459093439858407, 0.1223724038572982, 0.20035198278492317, 0.14406594447791576, 0.18184608517913148, 0.12609129102202132, 0.09425311116501689, 0.15685872989706695, 0.08785452169831842, 0.10838731366675347, 0.11606854954152368, 0.10621753361192532, 0.18925343145383522, 0.11241575804888271, 0.10071124313981272, 0.09699849353637546, 0.15407873375806957, 0.09468772026593797, 0.23037923325318843, 0.1324004665366374, 0.162871565844398, 0.07753287281957455, 0.15859281731536612, 0.1548847951926291, 0.1002214034087956, 0.13113418448483571, 0.13283822976518422, 0.14844736171653494, 0.13852858770405874, 0.09105320044909604, 0.09595635492587462, 0.15311170049244538, 0.10055864273454063, 0.22054922010283917, 0.2083326381398365, 0.08921973945689388, 0.12066009105183184, 0.14744759973837063, 0.117882588529028, 0.1071369432611391, 0.17737176589434966, 0.09088201666600071, 0.11212060591788031, 0.18636242486536503, 0.1512374510639347, 0.1190785075596068, 0.1929999265121296, 0.2311486325925216, 0.14673405443318188, 0.24069636245258152, 0.10134362717508338, 0.08489594998536631, 0.10683008003979921, 0.17712170665618032, 0.1309687300818041, 0.09694215710624121, 0.13101014192216098, 0.1877981540746987, 0.12277317844564095, 0.1678200432797894, 0.21734830748755485, 0.1346452851430513, 0.11406535195419565, 0.11172596889082342, 0.12165874722995795, 0.12152918308856897, 0.19498297479003668, 0.11946389742661268, 0.11762285910663195, 0.1906287349993363, 0.16500702156918123, 0.19946179148973897, 0.1175282130134292, 0.14400796790141612, 0.1218504439748358, 0.2306470595067367, 0.14633132057497278, 0.11263239095569588, 0.17017737147398293, 0.14214396011084318, 0.17406214348739013, 0.10040961948106997, 0.13527499744668603, 0.158636930573266, 0.15744471485959366, 0.13430996797978878, 0.06846080766990781, 0.16673634439939633, 0.11291872637229972, 0.11163152317749336, 0.09994899068260565, 0.17541426233947277, 0.11634163762209937, 0.14467590081039816, 0.1993310547550209, 0.08402480962104164, 0.11055336814024486, 0.11601390520809218, 0.16528934938833117, 0.16012708889320493, 0.13438995665637776, 0.22106786258518696, 0.2015898554236628, 0.15764090901939198, 0.12263300901395269, 0.13488704717019573, 0.2135751544847153, 0.17627248191274703, 0.1377605984453112, 0.14997578517068177, 0.07001855337875895, 0.14913123595761135, 0.1850951780215837, 0.17609754286240786, 0.09593539667548612, 0.18942658934975043, 0.16837895469507203, 0.11116303503513336, 0.11842917287140153], [0.011247627462580567, 0.03253955022955779, 0.01866712176706642, 0.01283838297240436, 0.047232200304279104, 0.07419792833388783, 0.016826031496748328, 0.037100971676409245, 0.0822176577639766, 0.11880133766680956, 0.05265624226012733, 0.007046069249554421, 0.01905192904814612, 0.056125689879991114, 0.13299835554789752, 0.06348655544570647, 0.03860925695335027, 0.018968344666063786, 0.09197036881232634, 0.03507427027216181, 0.09196886225254275, 0.03178245198796503, 0.05026964747230522, 0.04360646751592867, 0.04302492430724669, 0.029946530776214786, 0.01667577998887282, 0.03809564252151176, 0.03586736638681032, 0.026700050293584354, 0.03621289179136511, 0.06751908906153403, 0.03846292769594584, 0.043940645482507534, 0.06678615143755451, 0.029372798671829514, 0.023533502826467156, 0.026177813961112406, 0.03997076768428087, 0.10153923503821716, 0.030378100782399997, 0.020474856210057624, 0.0527012201200705, 0.04655927274143323, 0.019533872327883728, 0.06822879004175775, 0.02275358168844832, 0.048936223320197314, 0.05036047521571163, 0.055576059021404944, 0.04329575996962376, 0.0921490260225255, 0.05713106620532926, 0.024237069956143387, 0.06219253562449012, 0.07981747796293348, 0.03108033946773503, 0.02845708677341463, 0.03834018760244362, 0.07377901565632783, 0.012713723499473417, 0.028773147059837356, 0.023418263990606647, 0.03913263433787506, 0.049644681203062646, 0.06488502884167247, 0.02003746591071831, 0.0388540729181841, 0.06915809994097799, 0.07618247575010173, 0.021372316841734573, 0.038447561528300866, 0.0431716135062743, 0.01540737725008512, 0.01957618587766774, 0.03505997279717121, 0.010051817898784066, 0.012397407172102248, 0.006247554529181798, 0.024444891714665573, 0.029964045461383648, 0.000994873544186703, 0.027979813457932323, 0.041996975560323335, 0.045854892960051075, 0.021747977152699605, 0.019011090516869444, 0.06303059475612827, 0.03196070472768042, 0.03870821121381596, 0.03385527044883929, 0.048790736400405876, 0.018567440201877616, 0.07384887401713058, 0.042855039282585494, 0.029529352868848946, 0.009607431002223166, 0.026702768409450073, 0.038347375302691944, 0.04208195889077615, 0.019553032725525554, 0.011666009504551766, 0.017430043226340786, 0.0838465902779717, 0.04499132621276658, 0.0058203191292705014, 0.011265742359682918, 0.05069752529379912, 0.031330977581092156, 0.05322633784089703, 0.03973388527811039, 0.03018885683559347, 0.04146589097217657, 0.013969891006127, 0.06026131522958167, 0.019928253313992172, 0.01908265952806687, 0.01403888290951727, 0.05956575587333646, 0.04762327873322647, 0.05694272767868824, 0.009742486108734738, 0.0850463165261317, 0.012697130932792788, 0.029334676401049364, 0.06503412630991079, 0.08615530779934488, 0.08464055470540188, 0.05047801656473894, 0.04725440165202599, 0.007330685666602221, 0.007010519448158448, 0.03499945807561744, 0.030308418681670446, 0.044280556539888494, 0.009709996738820337, 0.0657376971503254, 0.04667203837016132, 0.04442504156031646, 0.05027460872952361, 0.009339330154034542, 0.017814995226217434, 0.03126162388070952, 0.024321875171153806, 0.04964576102793217, 0.048852497930056415, 0.024701780566829257, 0.012269934959476814, 0.037767553876619786, 0.05548491215449758, 0.04291136086976621, 0.057509253529133275, 0.03120805195067078, 0.04426523119036574, 0.03224279505957384, 0.007166789309849264, 0.05243865569354966, 0.0252285328679136, 0.05295861919876188, 0.007746041137579596, 0.06074116194213275, 0.06057533646526281, 0.027895609382539988, 0.028532796968647745, 0.02125964398146607, 0.048675139478291385, 0.11204091410036199, 0.0434125183528522, 0.036350133450469, 0.0078044249676167965, 0.06810188278905116, 0.024103466676024254, 0.0619062632904388, 0.02198957219661679, 0.03210678536561318, 0.040690817913855426, 0.032692091263015755, 0.009152406346402131, 0.02327119444089476, 0.032738074733060785, 0.029261367053550202, 0.11098860064521432, 0.04212533371173777, 0.036547418567352, 0.030625297185906675, 0.04980602410796564, 0.0264703110588016, 0.030691969877807423, 0.018635756750882138, 0.028477694359025918, 0.039118444474297576, 0.0621299948397791, 0.016421058207924943, 0.058388305187691, 0.08465069986414164, 0.00896822013601195, 0.053407499799504876, 0.09910903536365367, 0.056307846316485666, 0.05115645828482229, 0.03699533066537697, 0.03695813051308505, 0.010972891814162722, 0.05023841418733355, 0.01855646383774001, 0.010494470025150804, 0.03287320498202462, 0.058978308879886754, 0.037403163078124635, 0.03207028654287569, 0.013564009514084319, 0.04316883787396364, 0.033253863657591864, 0.051193825420341454, 0.07605884879012592, 0.05858845128386747, 0.032684287580195814, 0.07614511603605933, 0.04730268206913024, 0.01487207448008121, 0.027565045675146393, 0.03414709775825031, 0.06925365887582302, 0.04027393129945267, 0.024459101987304166, 0.033992994503933005, 0.04132539870624896, 0.0669115743949078, 0.019482884927128907, 0.082065391325159, 0.055219186178874224, 0.044555151180247776, 0.04058468337461818, 0.03460993444605265, 0.020179583480057772, 0.052824713493464515, 0.013082641398796113, 0.02239810593891889, 0.025262115050281864, 0.04174344678176567, 0.03718696803844068, 0.053890385606791824, 0.04025904381705914, 0.04686482236138545, 0.03289886844868306, 0.03491246352496091, 0.0974770006723702, 0.07683565476327203, 0.03782802778005134, 0.032694881738279946, 0.007745219672870007, 0.03376208267582115, 0.01782046485459432, 0.03543725470080972, 0.0354416185291484, 0.050472506118239835, 0.053371694884845056, 0.03790194939938374, 0.021050106006441638, 0.025884307542582974, 0.029257717542350292, 0.004842323414777638, 0.04513794861850329, 0.08134259143844247, 0.019237391752540134, 0.044624968722928315, 0.012593871288117953, 0.039146156268543564, 0.07066073376336135, 0.07839716316084377, 0.0200769518778543, 0.03126379095192533, 0.08509296050760895, 0.02285061749716988, 0.04083949235791806, 0.03783768312132452, 0.03413094120332971, 0.044858752662548795, 0.03298628231277689, 0.050402228443999775, 0.06876278755953535, 0.03233031653508078, 0.07634026376763359, 0.037074647698318586, 0.06189648549479898, 0.040754483052296564, 0.03657983186712954, 0.010624028600432212, 0.030773979051446076, 0.04647294612368569, 0.028100241761421785, 0.018770172682707198, 0.042887641830020584, 0.004353998592705466, 0.03832747090200428, 0.030341123274411075, 0.04703052909462713, 0.01356962849968113, 0.019931604110752232, 0.06004424074490089, 0.06054146484530065, 0.011407809834054206, 0.06628087503486313, 0.01671366106165806, 0.04417357595229987, 0.047206117524183355, 0.0247884392956621, 0.015733697728137486, 0.03162681619869545, 0.0032599502310404205, 0.04902206754195504, 0.03834568691672757, 0.041146014191326685, 0.0364703316881787, 0.02211108774645254, 0.05071562627563253, 0.005563672866628622, 0.017299670143984258, 0.018185950320912525, 0.027659070219669957, 0.027897284780920018, 0.02056988079857547, 0.05425990835647099, 0.04243561081239022, 0.04840466004679911, 0.015744705633551348, 0.050712234660750255, 0.015227457461151062, 0.07434022772940807, 0.04707592997874599, 0.049635133473202586, 0.050217860407428816, 0.008191311189875705, 0.036114160175202414, 0.03239384066546336, 0.03307891347503755, 0.02586296894151019, 0.013988836180942599, 0.07794490578817204, 0.04274275604984723, 0.02949877452920191, 0.016949829150689766, 0.009262270177714527, 0.013923600472480757, 0.06004851922625676, 0.008954780769272475, 0.025486006161372643, 0.05683464871253818, 0.034341603532084264, 0.041387520177522674, 0.018610069164424203, 0.04188025799521711, 0.1197680295445025, 0.1665120228426531, 0.14186555083142594, 0.1456649016472511, 0.15044357569422573, 0.2750763238873333, 0.12815511465305462, 0.09479111628024839, 0.13309067871887237, 0.22324934630887583, 0.17794296727515757, 0.1571279068593867, 0.07872283240430988, 0.10215705071459524, 0.3235206665704027, 0.1581298655946739, 0.11025813437299803, 0.10279882291797549, 0.20104522292967886, 0.07178159197792411, 0.18303408549400046, 0.18850421853130683, 0.18181869992986321, 0.24542578757973388, 0.11602228405536152, 0.11929924454307184, 0.1080265779455658, 0.21098065073601902, 0.13650032778969035, 0.15098277566721663, 0.13149561040336266, 0.22974837804213166, 0.16574967390624806, 0.11273531199549325, 0.1352999039227143, 0.11036051364499144, 0.11450917852926068, 0.10729137677117251, 0.2288019616389647, 0.15184958931058645, 0.11128335943794809, 0.15401490905787796, 0.17816105479141697, 0.12212283443659544, 0.09281449500122108, 0.12296097149373963, 0.11177162581589073, 0.09061604578164406, 0.12368123323540203, 0.1704712471109815, 0.15924316132441163, 0.21280529501382262, 0.11411852683522739, 0.18677243177080527, 0.1507505725021474, 0.19052749121328816, 0.1347430408350192, 0.11686867379467003, 0.10407513138488866, 0.27754930837545544, 0.10139933277969249, 0.22362760413670912, 0.1203999608696904, 0.13824354362441227, 0.1087085968174506, 0.2099782763980329, 0.13464403833495453, 0.13003945728996769, 0.10204655976849608, 0.1617668493418023, 0.19827353884465992, 0.16683206660673022, 0.11690865329001099, 0.1451828915742226, 0.08760150129091926, 0.15004473068984225, 0.10224814934190363, 0.12686511356150731, 0.1277804488199763, 0.15987150807632133, 0.13092383014736697, 0.08649187919218093, 0.1511206667055376, 0.14848527061985806, 0.19393656140891835, 0.08609500087914057, 0.11414692140533589, 0.13418853777693585, 0.13992338004754856, 0.21594459452899173, 0.13272310781758279, 0.1358641142724082, 0.13050720328465104, 0.15340823301812634, 0.12046885443851352, 0.1506989190238528, 0.20162350439932197, 0.122565436467994, 0.07067649698001333, 0.2211998015991412, 0.15856497193453833, 0.18474614596925676, 0.1584278082009405, 0.1913684484316036, 0.13305664382642135, 0.14493635011604056, 0.19465699384454638, 0.21942437655525282, 0.15112850378500298, 0.0743527700251434, 0.14086553652305156, 0.08195532340323552, 0.11745695941499434, 0.11952636399655603, 0.12451517715817317, 0.09381106574437581, 0.10653870544047095, 0.17394258349668235, 0.1359228923683986, 0.15349788445746526, 0.15003827400505543, 0.10697347039240412, 0.1370478843455203, 0.13427657133433968, 0.15509713848587126, 0.11547541769687086, 0.15575487428577617, 0.16527523373952135, 0.12774537492077798, 0.17317582620307803, 0.1832703556283377, 0.1686710788635537, 0.11190649631316774, 0.12371236633043736, 0.12211910143378191, 0.12116779427742586, 0.1667761235148646, 0.1533518743235618, 0.1148097928671632, 0.10828971382579766, 0.1941739150788635, 0.15527727256994694, 0.14387715695193037, 0.17543148016557097, 0.10956461963360198, 0.13768657663604245, 0.10644941023201682, 0.14167116751195863, 0.17695597023703158, 0.11784312111558393, 0.11906017651199363, 0.18280824995599687, 0.18076502834446728, 0.14515235961880535, 0.16141913831233978, 0.10784632511786185, 0.17480546375736594, 0.07784824847476557, 0.12075872247805819, 0.1311230967985466, 0.13234569603810087, 0.12048924865666777, 0.17533589154481888, 0.1334995575598441, 0.1072197817848064, 0.19681652483996004, 0.12224727775901556, 0.10636750681442209, 0.09459144144784659, 0.08836242530378513, 0.14833256631391123, 0.11524765257490799, 0.18505758082028478, 0.11345181846991181, 0.10538049493334256, 0.14750763948541135], [0.037575805181404576, 0.0042367888909211615, 0.038733800465706736, 0.060888541338499635, 0.06908220049808733, 0.09464610804570839, 0.013699849441763945, 0.06321570865111426, 0.03632341242337134, 0.12686710251728073, 0.057970910202129744, 0.02888544142479077, 0.009933334022207418, 0.08112762094242498, 0.04131337962462567, 0.04682898405008018, 0.007460757715307409, 0.051957376635982655, 0.025969457856263034, 0.014720625331392512, 0.00457160324913275, 0.04547496158920694, 0.0198014536726987, 0.0493502266908763, 0.017743385396897793, 0.04333136821514927, 0.027454367336758878, 0.0656982371583581, 0.010819408253155416, 0.054315023953677155, 0.06766863923985511, 0.014511226509057451, 0.07273725554114208, 0.05609014471701812, 0.04891586992016528, 0.047669577616034076, 0.026275289492332377, 0.03680384914332535, 0.04410844136145897, 0.04956127864716109, 0.05510816459718626, 0.013100159794703359, 0.053593051561620086, 0.05840486992383376, 0.05744147318182513, 0.03425590773986187, 0.04068378977535758, 0.019169333099853247, 0.09241022489732131, 0.10047272429801524, 0.009664889930718346, 0.05340697287465446, 0.014818399577052332, 0.03484841246972792, 0.03490611816232558, 0.013161390688765096, 0.013751316455454798, 0.034602954547153786, 0.036637511584558524, 0.05916328176681418, 0.061468147541745566, 0.027546649689611513, 0.04919373372104019, 0.034739802867989056, 0.04252264247043058, 0.08635394362499937, 0.01605394558282569, 0.030580588354496285, 0.03485574488877319, 0.024213734977820423, 0.04461677170183975, 0.02479176411725348, 0.042176018687314354, 0.032588925314485095, 0.017231761776201893, 0.04724245678517036, 0.016646522672090214, 0.04220527785946615, 0.046281631584861316, 0.08580462817917578, 0.02540542005590396, 0.03696901039802469, 0.09367047328851186, 0.014923996986908605, 0.10178593976888806, 0.04061311134137213, 0.06571114310645498, 0.08048776348005049, 0.06420780424377881, 0.007744253489363473, 0.015375827624666272, 0.04807307217561174, 0.0786191840597894, 0.04239173875248525, 0.0222427595872432, 0.04326236332417466, 0.01144061276136199, 0.01949035835423274, 0.012394421883072937, 0.009705816592031624, 0.018579305287858006, 0.02271487312100362, 0.06798279035137966, 0.05282320693368092, 0.01508333702076925, 0.06206400677911006, 0.015103686710062902, 0.03013519770320272, 0.05759176179708447, 0.019353673305886332, 0.03731744502147194, 0.028826965753978584, 0.028695015607809182, 0.005720953440686571, 0.08996067001135089, 0.021262929840304423, 0.006930793306310079, 0.07188653908087872, 0.06626668517128564, 0.024938319729699288, 0.030033926086616702, 0.04153784961090423, 0.017599926395632792, 0.03753778124519158, 0.048651902834535576, 0.04686750893597491, 0.10549475598963909, 0.014199975339579396, 0.010092867942148587, 0.04549519253487233, 0.05411905614892021, 0.06434015886043198, 0.010247188274661312, 0.06851151119917631, 0.040520068287150934, 0.010567334084043978, 0.018951748388644774, 0.02721821037994232, 0.012269219714653445, 0.05174848061869852, 0.031045885261846706, 0.03876582042721566, 0.03240636440750677, 0.055162267162813805, 0.04552377635263838, 0.003628948838922952, 0.021082651037431788, 0.02115942621458089, 0.04497745176195167, 0.03451164811849594, 0.057392131493543275, 0.016340191941708326, 0.023225179429573473, 0.014933009442756884, 0.03254510520491749, 0.08543270829250105, 0.011136188422824489, 0.0764511406305246, 0.033785467749112286, 0.029167041939217597, 0.01701821805909276, 0.02409802302281605, 0.03939688715036027, 0.0269171099353116, 0.04439045747858472, 0.022390966478269547, 0.05170920616365038, 0.0471493617806118, 0.03247657899919432, 0.02122106343449559, 0.02454533398122294, 0.04577042542223353, 0.04250368430803064, 0.0016378338796130265, 0.0635288652847521, 0.13340052537387237, 0.02647065801284043, 0.03503910360450391, 0.05286662628350314, 0.04184687990345992, 0.04580323577101808, 0.04295473197998945, 0.012870620939793298, 0.08590598328737542, 0.021022516666562296, 0.03751392119738739, 0.053429085164680146, 0.008153960752679268, 0.028079721378162503, 0.02782051516987849, 0.06954764583497308, 0.071738502883818, 0.04441561257408466, 0.045607464635395445, 0.07102710238541476, 0.04197388363536447, 0.051643696788232774, 0.03465929468802642, 0.01735533121973276, 0.06773282759240828, 0.006876137840663432, 0.009847509281826206, 0.05226135290286038, 0.002798881710077694, 0.05580972421739716, 0.002155561896870495, 0.06276507658185437, 0.07781118561979383, 0.04363132204161957, 0.05819313519168645, 0.030340906196215656, 0.022925895391381346, 0.022290757988230325, 0.020215037729940377, 0.011096680191258201, 0.04295497317798436, 0.04093522940820549, 0.03389862671610899, 0.02286909697431838, 0.01366496386253857, 0.06656227516941726, 0.0617048852291191, 0.01001919679765706, 0.044648342664004304, 0.07765563146676868, 0.03989621895016171, 0.06582805362995714, 0.07113785308320075, 0.04207667108858004, 0.06217963709787, 0.04301265289541334, 0.008315654322359478, 0.05327460341504775, 0.0390437881287653, 0.06487576683866791, 0.018223467741336208, 0.03916167086572386, 0.11564340282347985, 0.04541365276963916, 0.048015559441410005, 0.013450006354105426, 0.0256955385702895, 0.08983770356280729, 0.04192369960946962, 0.01647775643505156, 0.03828310902463272, 0.08888400669093244, 0.01525140007288428, 0.02704610818909714, 0.028297545431996696, 0.036676645031548105, 0.028086428537790198, 0.04811084007087629, 0.09142425944446586, 0.016819667580421083, 0.04791564409970306, 0.08226153353461996, 0.0449644530453952, 0.06106350636400748, 0.07445670780725777, 0.11448472476331517, 0.03671736667456571, 0.06918441649759188, 0.007034008885966614, 0.03260598357883282, 0.03447734234214295, 0.0315927441988606, 0.0479796840227209, 0.052443501917878166, 0.0034824347403628053, 0.03532113827532157, 0.02732797402131837, 0.024939668583101593, 0.02379806734097656, 0.03470860669040121, 0.06989146801060997, 0.03245609572331887, 0.04659091049688868, 0.028316329189692624, 0.03138934749586042, 0.04017804210889153, 0.08868680321029387, 0.06486770711489953, 0.015165472359512933, 0.012656473300012294, 0.040003303438425064, 0.0073292709475936135, 0.015069330838741735, 0.02009443131100852, 0.011345528801030014, 0.0409539055544883, 0.03845646730042063, 0.008884483613655902, 0.02668508117494639, 0.04681496116972994, 0.06984238236327656, 0.03401840935111977, 0.03049701695999829, 0.0023821588320060982, 0.008891052548278822, 0.0215934527295758, 0.016375388295273297, 0.04880957210843917, 0.043875562842004, 0.019626212197181303, 0.02247923010145314, 0.060275104333413765, 0.06692479204502888, 0.007281978978426196, 0.08969004586106166, 0.04693328919529449, 0.044449621491367, 0.015382146084448323, 0.06492073356639594, 0.018114665181201417, 0.04222030263917986, 0.03881344404362608, 0.03456291939073708, 0.06365966139128432, 0.04725819773739204, 0.06626712303841487, 0.03455622892943211, 0.015497465628868667, 0.011350209897500463, 0.08246377619798295, 0.03024763678695308, 0.022060371229599696, 0.04782142845215276, 0.007617047058374737, 0.06181057819048874, 0.02845816659828415, 0.0844405904354062, 0.022771261501475237, 0.04249203630024567, 0.0178159989809501, 0.022664798561891075, 0.032399737028754316, 0.01617737958440557, 0.02768711969110882, 0.038644690794171765, 0.07165853647165932, 0.07284129722393118, 0.03432867531955708, 0.09472426361753605, 0.04990970584913157, 0.04019507810880896, 0.032652419758960605, 0.04948049216181971, 0.09088909675483592, 0.035774456919170916, 0.03739099185622763, 0.055038087302818894, 0.08196611423045397, 0.09428955061594024, 0.1409567316295579, 0.14274631685111672, 0.19857727020280436, 0.19684677477926016, 0.0916113548737485, 0.19967266533058137, 0.15889574715401977, 0.265865083783865, 0.21689675515517592, 0.10164250488742255, 0.2120225370163098, 0.18127026763977483, 0.14747700362931937, 0.15402411168906838, 0.18306878831936046, 0.18953620456159115, 0.15251583012286574, 0.08949513561674394, 0.13716322893742472, 0.19986105209682137, 0.1056800183141604, 0.14811290544457734, 0.13585440698079765, 0.09840996193815954, 0.29438172234222293, 0.09668928512837738, 0.09686104778666049, 0.09275997683289461, 0.18549405271187425, 0.12982502114027739, 0.1375605005887337, 0.1390662440098822, 0.12019250832963735, 0.14717183250468224, 0.16844435274833813, 0.13613297953270376, 0.1467716516344808, 0.17995720059843734, 0.17027509748004377, 0.08145896019414067, 0.08402334016864188, 0.1746942158206366, 0.20946609060047194, 0.2019005035981536, 0.10138344339793548, 0.15724384516943246, 0.16236030030995607, 0.22236141114262864, 0.1814946040394716, 0.12855802662670612, 0.08636987011414021, 0.20917217043461278, 0.09409927879460156, 0.08730044166441076, 0.18537299358285964, 0.0820702152850572, 0.1481872092699632, 0.1259494962869212, 0.15761699702125043, 0.27469512715470046, 0.18691989651415497, 0.26128137193154544, 0.11459451809059829, 0.1587643424863927, 0.15979134128428996, 0.17271523451199755, 0.13990763167385012, 0.12462274404242635, 0.14788303262321278, 0.09178051259368658, 0.16418228769907728, 0.16984347923425958, 0.04917023361485917, 0.10649003539583646, 0.1341234365827404, 0.16419209889136255, 0.11546369918505661, 0.12919045519083738, 0.15098633797606453, 0.14170376263791695, 0.16058260429417714, 0.12568423786433414, 0.19902321189874783, 0.1536646153545007, 0.1597923951339908, 0.1513301007798873, 0.09043217869475484, 0.09297571174101904, 0.11910416360478848, 0.1287693012272939, 0.1473857936798595, 0.08194352325517684, 0.13777348212897778, 0.10883310693316162, 0.09027049440192059, 0.1063904094917234, 0.11561270759557374, 0.18704036192502826, 0.08969440968940035, 0.10377409402281046, 0.13984426710521802, 0.1363260269863531, 0.15466921613551676, 0.17740629060426727, 0.19677039294037968, 0.06806313525885344, 0.11343436315655708, 0.12637694366276264, 0.12346546121989377, 0.0786860218795482, 0.08611428187577985, 0.05624223675113171, 0.1929998374544084, 0.09003492188639939, 0.09043985250173137, 0.12079248277586885, 0.21677728422218934, 0.24780319829005748, 0.16057328291935846, 0.14560921088559553, 0.11286965556791984, 0.11803911489550956, 0.10739897334133275, 0.13247995055280626, 0.19103727245237678, 0.33932446385733783, 0.16014761669794098, 0.13408027327386662, 0.14041385060409084, 0.2432938347919844, 0.10462829115567729, 0.14795610448345542, 0.10596376363537274, 0.13501337554771453, 0.1192893368715886, 0.18166056310292333, 0.19292136275907978, 0.09534814264043234, 0.1940584517433308, 0.10086095659062266, 0.09222571956343018, 0.15053178736707196, 0.1142793576582335, 0.08023357790079899, 0.06550802470883355, 0.07174507831223309, 0.19833942671539262, 0.14842855569440871, 0.1849836777546443, 0.14303251868113875, 0.1258380405488424, 0.20063490432221442, 0.14335101877804846, 0.29743064311333, 0.16346592223271728, 0.28946407372131944, 0.11993856023764238, 0.1566793824895285, 0.11209472722839564, 0.17540266999276355, 0.10867910386878066, 0.1006093314208556, 0.1835820873384364, 0.1610256516141817, 0.12596255808603019, 0.24625034333439544, 0.23246146214660257, 0.08091009745839983, 0.09004114108392969, 0.13387008220888674, 0.17949603003216907, 0.08273838568129577, 0.1016852303291671, 0.2709827263606712], [0.08220810632337816, 0.016787139247753657, 0.026073876178998034, 0.059305673930794, 0.033952506637433544, 0.021311677810444962, 0.022089945814514067, 0.06040593754732981, 0.06431074012652971, 0.03803935062023811, 0.04156860049988609, 0.036780259979423136, 0.023613647354068235, 0.012856914399890229, 0.09107919788220897, 0.020375514177430887, 0.03554219067154918, 0.05640510476951022, 0.035527978543541394, 0.037855650516576134, 0.03365030039276462, 0.019814064617094118, 0.042468569590710104, 0.03359150745382067, 0.01902475160022732, 0.02919857022789074, 0.022868937412567902, 0.04123374346818309, 0.06297815460129641, 0.04486567690037191, 0.02000428819883382, 0.04744212419609539, 0.04405915904499125, 0.010102553897013422, 0.02526508364098845, 0.034306407178519294, 0.08472862537018955, 0.05362837779102847, 0.03899525538145099, 0.011008570563717512, 0.038153667337610386, 0.047398749375133775, 0.06043764951755293, 0.02877415081457002, 0.06330359377898276, 0.023588037693116348, 0.030545896661351435, 0.036680545017588884, 0.0406050404853886, 0.004173460038146004, 0.14137050864519551, 0.13775317696854472, 0.023586807583342306, 0.024045948375714943, 0.09304024148150347, 0.04272754202247597, 0.014414293673326029, 0.0576553415885428, 0.0518101011402905, 0.01683298913121689, 0.018637085195223335, 0.029334359132917598, 0.06282388436375186, 0.021138519914529752, 0.046449772562482394, 0.03249478017096408, 0.09158161701634526, 0.0809015404956881, 0.04991027730284259, 0.07120364447473548, 0.0669399912294466, 0.013822420696669724, 0.047374625864904374, 0.014691697342641419, 0.04245937438099645, 0.06044966488843784, 0.020266594729037024, 0.00847902050736593, 0.05858420248841867, 0.04436443035956472, 0.02271023469802458, 0.06950601877178997, 0.021207105492067058, 0.07342712633544579, 0.05294695634802338, 0.02671647773240693, 0.03093977298703976, 0.017336810924462043, 0.07895094633568078, 0.03944695243262686, 0.04590254626236856, 0.01645356427616207, 0.006066446840122808, 0.02496005909051746, 0.05552979724598117, 0.05374240878154524, 0.043008415232179686, 0.06107751440140419, 0.03005538343131775, 0.04502023286477197, 0.06171387263748329, 0.028015757525281515, 0.04187873659247998, 0.047966603669920005, 0.019519615671015345, 0.036043470609001815, 0.08342390006873757, 0.06589092095964588, 0.057260734247392975, 0.04155104499659501, 0.015881175459071528, 0.03405976924113929, 0.05694245679478627, 0.0675238759140484, 0.012298622677917592, 0.037075816580909304, 0.029148553185223136, 0.016594329281360842, 0.03600562107749283, 0.0247218667936977, 0.03571414628822822, 0.03957108405302279, 0.0552795450494159, 0.0634866593463812, 0.08811992112896405, 0.05913494656851981, 0.050982213142560795, 0.05644899167236872, 0.018018714763456956, 0.0746910335146822, 0.012387095030135242, 0.019001494547410402, 0.015480578986171167, 0.015643884871678893, 0.04227542936860118, 0.033120815132861026, 0.03698346743476577, 0.04369868678622879, 0.019063217114307918, 0.014591884973924607, 0.05329477498889901, 0.023547280798084103, 0.05437954627268482, 0.0818420568248257, 0.06474736786913127, 0.048980073115671985, 0.002871764554583933, 0.04351471950940322, 0.01245384750291123, 0.026205618523817975, 0.08941029329434969, 0.028424933225323912, 0.01626015317015117, 0.027843197058246005, 0.007008431230133283, 0.02863986104784999, 0.008266708755400032, 0.06105837441282347, 0.009291849401051877, 0.035090972305624746, 0.05992365287966095, 0.016939079141593538, 0.055373456416418776, 0.04012668920040596, 0.03981259746069554, 0.05143774709722493, 0.018590209292597137, 0.02463516724674264, 0.09041117591550574, 0.04147918654780369, 0.06568986573256552, 0.02301386030012509, 0.02146155824448215, 0.02836665793438442, 0.037435260965139605, 0.04690079054853413, 0.060397963170544244, 0.04585419534123503, 0.052439026767387986, 0.016189986818062607, 0.026183621266682167, 0.04967539498466067, 0.052282852921052836, 0.03490301969577558, 0.06100738886743784, 0.08886671465006657, 0.053301543375710025, 0.021827954697073437, 0.016659491702739615, 0.01066714645276079, 0.04648948859539814, 0.08197355797165073, 0.012072134977643145, 0.017610513132240158, 0.01090848823878332, 0.04181461874395609, 0.026514210949244443, 0.052297792353783734, 0.06935213445103727, 0.0377552453574026, 0.01722177432384342, 0.05751613694883417, 0.03944965013943147, 0.030043659353395924, 0.04335591846029274, 0.04070101131219417, 0.026885544539254624, 0.07237374418764375, 0.07169666801928543, 0.07256482494994998, 0.029758305427094456, 0.02729883730353322, 0.03213479030819144, 0.04837819877138827, 0.05024254794989247, 0.03096171643846901, 0.061831573548261076, 0.031228349689627066, 0.042878817694145255, 0.012037972992402501, 0.03675856329209637, 0.020972811325918883, 0.04406947118695825, 0.07704593488597311, 0.035797890232061036, 0.026963672280544415, 0.051512748541426845, 0.17626085988013074, 0.05072925952845253, 0.054121438442962244, 0.055440049327444285, 0.09345021870103665, 0.004426295372468303, 0.011460845562396571, 0.06384018881362863, 0.01789232701412402, 0.032170598933589645, 0.0243435217635124, 0.03726157985511236, 0.09809374023461714, 0.029871557162550744, 0.04639237486117054, 0.04791991144884378, 0.041961834867834114, 0.049897523495019414, 0.021862548055651132, 0.027983329382550437, 0.030928635205782484, 0.06272092621657066, 0.007280106910911854, 0.021615533478325233, 0.011056119037675671, 0.027163360100530554, 0.08219114082749002, 0.023694827177678235, 0.02155271067749709, 0.02122399862855673, 0.018945688752864953, 0.030198935201042332, 0.030472852631646674, 0.020186713663861156, 0.03783352338359691, 0.06487205610028468, 0.04919649079965893, 0.03276681811257731, 0.029194501403253525, 0.030700361712661106, 0.009584228682797402, 0.0488159619999351, 0.01570510463352548, 0.03363117153639905, 0.04837118547584396, 0.07960229224408977, 0.06043071043677628, 0.04202383759547956, 0.011805341237050015, 0.08388673304580152, 0.040333737269975245, 0.04687610300607048, 0.04124349528865423, 0.02849041291483445, 0.004412844409671379, 0.03457972903561313, 0.08350446019903757, 0.03942407944123261, 0.04943772219121456, 0.06317775521893054, 0.014955234910303261, 0.07277327196788974, 0.03826402469712775, 0.036722732402267866, 0.08276643144199625, 0.05763430912338663, 0.019599932747951243, 0.025431406356801745, 0.02972660087834811, 0.030748796125408262, 0.039509155540145, 0.045969547354616225, 0.04020389111246914, 0.04097710880159866, 0.045380601222859696, 0.02931340644863667, 0.055357778546749614, 0.035976005674456246, 0.038866218164912425, 0.046585682066506706, 0.02741579792200355, 0.01184811677376274, 0.014539616440742975, 0.027369085291866213, 0.0490620693017263, 0.07916068469057791, 0.02142667359294137, 0.024635987319925334, 0.016904096155485604, 0.06551251470227726, 0.06643903412623331, 0.04511165803705808, 0.04567006850265898, 0.03698970889672637, 0.023239168913278263, 0.04152339628490154, 0.014900936603226, 0.04803302959771827, 0.03289231157395989, 0.027260034112259746, 0.021263712806103285, 0.013867052530258661, 0.04907925002044067, 0.010546650428295834, 0.04698846045357641, 0.01195335424199584, 0.018155203142669052, 0.08565650292439386, 0.03148573021462653, 0.03762972221011296, 0.027017049396818038, 0.028336343057162594, 0.043978873509331606, 0.03487455833237618, 0.10553334024734795, 0.04107484593987465, 0.08875732950400561, 0.05263813385681715, 0.05524312044144608, 0.028093733126297593, 0.07185102731455117, 0.05204418564972002, 0.050920588910230435, 0.01999828793486813, 0.070353885384975, 0.1593097616569139, 0.16411813645390794, 0.1701192613109015, 0.14467585628153756, 0.07498004066292197, 0.14605470729293302, 0.15640883997548372, 0.11946279162657447, 0.11222812085179612, 0.20077450230019167, 0.24112410668749362, 0.11522149929078296, 0.15569881245028228, 0.0899067307182122, 0.1079621298413258, 0.12218409872730263, 0.1359866576967761, 0.10871185484575108, 0.09550231639877893, 0.09179098429740407, 0.12846816738601774, 0.17456353845773265, 0.26330215099733323, 0.15705253434134647, 0.07001477584708482, 0.10853897154447623, 0.15733046864625067, 0.2472444946761243, 0.18981661763973534, 0.16329867183230817, 0.12430050352122635, 0.18153816810809076, 0.19837433734210208, 0.21558627078775316, 0.09453780643525533, 0.115087326412322, 0.1227587585162837, 0.186306971590966, 0.15453016734682024, 0.07671967192436568, 0.12177525699371472, 0.1769291638629511, 0.2149317559087649, 0.1675805522245355, 0.21538831031648442, 0.08269956393633038, 0.2255866810446605, 0.11212437602807768, 0.1871285735978745, 0.10132807175978087, 0.20626229845220223, 0.31983471591956913, 0.10574978761724196, 0.16237566276686266, 0.14326822478324175, 0.23355047480436042, 0.09503541645244695, 0.08894418744603172, 0.1260644698049873, 0.12637486564926803, 0.1511905770166777, 0.1041467412142083, 0.11584918553126045, 0.25123358296696097, 0.2151119345217012, 0.14938782609533519, 0.24847556924214587, 0.22156369144795462, 0.10643189554684795, 0.16951270401477814, 0.16019345173845068, 0.1586590614169836, 0.15996754198567942, 0.13800909917335957, 0.15094016154762357, 0.14009964012075216, 0.10589267330942675, 0.13312631665030494, 0.19763322867220268, 0.11839261467684992, 0.073057432891801, 0.13511000317521393, 0.09557028228300624, 0.19219327135942876, 0.10295099287759513, 0.13321522594196722, 0.12193230286356993, 0.07130186029826291, 0.23323170753428712, 0.08810998377157375, 0.07079573784722015, 0.2748962788609788, 0.10989207003149204, 0.1761543468455784, 0.12127628142479807, 0.218964081723243, 0.16751404094975442, 0.24094996915664524, 0.08946524932980537, 0.08111295610433444, 0.15351762558566406, 0.1012426802481059, 0.10841809795238078, 0.21611001924611628, 0.07445520124747418, 0.13800966320559382, 0.15709164552390575, 0.1770627949736081, 0.12142138613853604, 0.20748308685142547, 0.16027397476136684, 0.10477078350959346, 0.13453826744807884, 0.2171943712164648, 0.14844742108834907, 0.13586050743469968, 0.2092282471130602, 0.1635490873013623, 0.14743296458618715, 0.07168451906181872, 0.16502634709468111, 0.1278175858897157, 0.12116294063162059, 0.12252822518348694, 0.13382304488914087, 0.16551748558413237, 0.11662901204545051, 0.15120487078092992, 0.1221615300164558, 0.14267878141254187, 0.130737031577155, 0.08878389839082956, 0.11926477920496836, 0.06986407533986494, 0.10800680713145994, 0.08126620217808522, 0.13490534853190184, 0.14026504999492317, 0.11713712345226668, 0.08481454380671494, 0.11443746479926631, 0.1554352609673515, 0.1844674101448618, 0.13195133360568434, 0.13251578144263476, 0.11414485823479481, 0.16260274511296302, 0.16028547805035487, 0.12680672138230875, 0.1739235399872996, 0.16624483483610675, 0.10036126113845967, 0.08803057397017255, 0.12370358672342263, 0.08224013741710223, 0.1264553886721842, 0.042321624350734055, 0.14543728495482355, 0.17872403317596763, 0.08602422967669554, 0.18373801256529987, 0.10822563679539599, 0.11144995674840175, 0.11595555013627745, 0.17523887800052762, 0.2415783901233226, 0.17616685945540667, 0.21088935172883794, 0.14402825821889564, 0.21373979252530262, 0.15917629381874576, 0.1757190327043645, 0.12112550670281053, 0.16522089368663728, 0.1414338732138276, 0.12875567539595068], [0.057933880743803456, 0.05514977310667746, 0.0815820082789287, 0.03722496971022338, 0.01620832714252174, 0.06247348675969988, 0.021054529206594452, 0.023510136306867935, 0.016208416200242937, 0.056549537839600816, 0.04232907922414597, 0.04246038370183669, 0.053509229692281224, 0.02908551145083038, 0.07351301508606412, 0.05067188409157097, 0.0754126459651161, 0.04735321119369473, 0.07491394499083981, 0.038999266689643264, 0.060140070563647896, 0.023643221938982606, 0.057829816796584055, 0.013726592733291909, 0.009530420193186728, 0.023672714887652546, 0.09511323063634336, 0.050148361988249235, 0.001718921166684595, 0.04954200878273696, 0.05487506714416668, 0.0367573164839996, 0.0538155622780323, 0.07872759699239396, 0.04851719560974743, 0.0531350499659311, 0.023729162639938295, 0.04501987663388718, 0.06597091705771163, 0.0031128324417295516, 0.025240119648515247, 0.07562363112810999, 0.03517178105539642, 0.040250138044939376, 0.11092122847912833, 0.02234840801975224, 0.03024038229341386, 0.011800717657024506, 0.05638199800159782, 0.013952455174148781, 0.06638205202762038, 0.0148800442184438, 0.022779002101742662, 0.11205656599486247, 0.030172947044775356, 0.013490218698279932, 0.02963045750220772, 0.04749041945615318, 0.010494753896637121, 0.04642234278435353, 0.09392005013069138, 0.03241708473069593, 0.019836288229271304, 0.03139571883366443, 0.05644585609843489, 0.015171252762229415, 0.0692148000234738, 0.06686156848445535, 0.042493965884204954, 0.031195502233458683, 0.08162579499185085, 0.016576202324358746, 0.025821282506512944, 0.05843637038196903, 0.061356153746601194, 0.025058707215066534, 0.020451424752536695, 0.010373445220466238, 0.01630980841582641, 0.024118370856740512, 0.06507500380394049, 0.00896420790013508, 0.012299604168219958, 0.01681390294834273, 0.025163791615341324, 0.049983902063104324, 0.09813088472583331, 0.026918041330645792, 0.03433265694184229, 0.035296755013405345, 0.07328027015319094, 0.018776770375552587, 0.01632499090192141, 0.014802495352341793, 0.08669357266626321, 0.03531659262080211, 0.06595135404495522, 0.017369636116200127, 0.03283620149886701, 0.03532967297360301, 0.019436528527876362, 0.03445654365350492, 0.08649911513202824, 0.027050087956013158, 0.029103326705808286, 0.01751910094753839, 0.056395749998046085, 0.020661382040998433, 0.04580651977448724, 0.012004054988210555, 0.010450199060869636, 0.03794039264903404, 0.03843005426460877, 0.040101422782754526, 0.05549715759116225, 0.04629486036719754, 0.05513860749488231, 0.02877840888686478, 0.02517147469916381, 0.01438406321540242, 0.02369061177887488, 0.05045801939559169, 0.04630519848433323, 0.032568531096330844, 0.06459464872023091, 0.05070234554295894, 0.02828264310664963, 0.046513775378116407, 0.06557458051247522, 0.016998029786918778, 0.022699596011079848, 0.046413314557867125, 0.062253970609162934, 0.03436643579334486, 0.04020189473521896, 0.03764479151868727, 0.03538622833730187, 0.06503787415567786, 0.02543003523896914, 0.00995430154944188, 0.07446234070812352, 0.010207016748609021, 0.03544137733115349, 0.07238379286718555, 0.03184790941304527, 0.032129676910699345, 0.027707126137102023, 0.022755362842872273, 0.013952577628515428, 0.026316291296097916, 0.060465843707788736, 0.023845193718443625, 0.04900584048300516, 0.04905477399006486, 0.01771727478626417, 0.07192698612925597, 0.02321842959645437, 0.014642514288425446, 0.05070962601166684, 0.030160196947690565, 0.020136110324529, 0.020812347866012715, 0.046994078511488624, 0.03949222344090231, 0.019120509059575852, 0.005231002387517947, 0.07071645421092398, 0.07662309624720365, 0.09395881250384264, 0.01201863447931828, 0.04230766084219795, 0.06008904048940167, 0.08123638268443756, 0.060625045516644605, 0.04231589497067034, 0.041114465493592434, 0.029437684643198736, 0.04997440628358163, 0.11374642141163349, 0.041966759017668664, 0.015352490790974116, 0.056613340275362134, 0.07971587052452378, 0.05044337311119307, 0.058064127661054954, 0.06256567634409294, 0.029865428878110833, 0.06611222939682193, 0.012883356193924556, 0.01761805706337327, 0.011340520231897244, 0.03299457581306342, 0.02953667786641745, 0.03797714380198158, 0.06048623792594299, 0.01755557008436881, 0.048770260546007194, 0.06973383584409021, 0.02076433833281044, 0.025380572951689828, 0.0119764906958153, 0.04012587283796165, 0.022355070650519338, 0.04338716658821795, 0.01127387537053437, 0.028386816520651337, 0.021469749699463136, 0.017090597866626922, 0.07453053665813059, 0.026038841242552735, 0.005979995912639424, 0.06398900426574983, 0.09345570317236707, 0.028086623351555318, 0.04959619669534732, 0.04979183053364977, 0.01098778022424085, 0.037232714021229185, 0.007035194930722355, 0.04605558824550826, 0.07411415470414795, 0.024574613562435843, 0.1079261653649155, 0.03671650207252242, 0.03086885149969021, 0.026367551436123904, 0.06290748729952611, 0.020427670460776426, 0.038422796060331166, 0.03002117413416272, 0.03002833400387317, 0.05924454322666861, 0.0785375181294512, 0.005726363233407028, 0.0718363476335071, 0.10795177688123658, 0.1079772251250688, 0.09523534361505881, 0.03569705462723505, 0.010662175918696448, 0.06480714044300839, 0.020040393683302682, 0.01749015718814917, 0.0471518850827124, 0.06050325166143011, 0.04140989221923519, 0.040578642292530276, 0.05366241268347949, 0.1026220952917356, 0.06163274105347227, 0.01619860686332686, 0.02576225950178923, 0.03366627141076606, 0.031782362930243835, 0.05741765024140477, 0.008428238124906784, 0.02632377956615528, 0.08447714120848104, 0.044121573664597236, 0.044497976123238914, 0.06273363920627162, 0.08324018141138367, 0.12900493311462924, 0.011949470954277785, 0.0529567118792329, 0.036513840095722117, 0.04098632256500423, 0.05458566294691991, 0.0158477621152997, 0.029357182029343676, 0.04001968263764866, 0.038383959472412243, 0.013135370063537266, 0.010745345625764458, 0.0485382948681945, 0.030927878215152305, 0.02785542579658795, 0.08073306555161253, 0.08500154275679961, 0.0439443042705534, 0.024196073718485422, 0.03146306502458174, 0.022150206350488588, 0.04719274402305018, 0.03331938416522462, 0.038461365475086495, 0.04216407010972034, 0.02808864570397418, 0.06872171710710973, 0.026475892009329982, 0.10718038116465323, 0.026084193887072615, 0.009303158803959377, 0.06470289095886983, 0.05119420762639493, 0.027587150543695316, 0.007677102112211287, 0.04463965211471077, 0.027185375911358278, 0.04824704643397126, 0.08175452050636522, 0.029069597949273884, 0.041430509081692435, 0.08423168328590691, 0.06983651939663105, 0.04672789611504413, 0.034989502164535224, 0.03197221543814521, 0.006083352036512224, 0.03165448346408084, 0.09786212336621247, 0.027272056904621422, 0.027822530100820586, 0.03682683716760948, 0.03258794567955192, 0.026010734254668932, 0.06488361876108684, 0.06429582295822911, 0.0352536956052063, 0.042892610508715734, 0.03571137065591756, 0.014931184687156929, 0.009209403287968598, 0.029365475529630203, 0.018263456513523124, 0.009443526760151144, 0.021987599939166103, 0.01508000385001651, 0.07838837613235228, 0.056151212338590994, 0.04008910313132219, 0.007213722265078104, 0.051934618677478284, 0.03693533544719685, 0.023333286226261407, 0.03191358577169012, 0.05597095951088704, 0.013220948039815994, 0.019514292616804596, 0.03569485415937379, 0.012347491247055586, 0.01259126263903454, 0.08398029560339637, 0.0035578397273638984, 0.022949764716031495, 0.028839610095019452, 0.07321478304220363, 0.08043070716666989, 0.06091502116760239, 0.06908666080562398, 0.05319648495060392, 0.03628955193562433, 0.1661523780785501, 0.1300758818979375, 0.17891903989948332, 0.09933844063198194, 0.08681905499543063, 0.14606300450395793, 0.13786237657768652, 0.13757175154751167, 0.1671063495450653, 0.12192238034913316, 0.16931340767769143, 0.19360017555300146, 0.1227911606838461, 0.13053844770183787, 0.12269278158782981, 0.15280038438504562, 0.17442692391341552, 0.11890050343936309, 0.11261179635766894, 0.15875570388743654, 0.1455604369402863, 0.1986388981458731, 0.12855430104536936, 0.14211094938218594, 0.11582116945646703, 0.13330306654097512, 0.13475875952281058, 0.09000438250950538, 0.1455719253863208, 0.13509000971680507, 0.2099838573485613, 0.13416835136013106, 0.1650024054106325, 0.14519685879349709, 0.10072843870148063, 0.18621154624270275, 0.2644976321607828, 0.09849925714661367, 0.27261025621555746, 0.11727884397259913, 0.184042961045634, 0.1953715187846683, 0.08368506183614954, 0.17899223050335422, 0.25894696125760674, 0.11847036948893219, 0.20678445871453732, 0.11696935354848392, 0.12418996804626659, 0.16676231956807896, 0.11450555684859864, 0.09101626375922933, 0.08209509949665517, 0.15531173790805042, 0.09075390713405795, 0.1958423521136865, 0.1227204043243546, 0.1794763037469238, 0.15069056244101375, 0.15225088340230286, 0.1809047005372122, 0.21896743623074144, 0.14471830712864175, 0.13528501644032076, 0.13891334674553946, 0.07523957712692209, 0.0802099404972978, 0.1858841849025339, 0.15689730673329905, 0.13465846568578854, 0.14463533501839265, 0.11956364949583076, 0.1888458291068673, 0.11330620909575373, 0.12417836085660383, 0.08974296841188334, 0.1960196511936374, 0.12967148562893271, 0.23402829916449264, 0.1262198606855236, 0.15137255162699148, 0.1623416130314581, 0.11496348422951996, 0.10241516967653297, 0.27839808783028275, 0.1785955228842795, 0.1755628699902445, 0.13279393839184195, 0.16128929215483367, 0.10783472534967586, 0.1457941986154765, 0.13736524153500795, 0.0895773210504558, 0.11162117021740414, 0.14286210673162714, 0.11976555819273926, 0.1787511512520723, 0.19229835947044194, 0.10574541636742651, 0.1383684916072525, 0.1687761818175204, 0.19181663141353056, 0.09989732236135751, 0.15306694898754358, 0.14937348780222237, 0.15647829015506431, 0.1874154878896661, 0.14792926842346787, 0.19598056969698519, 0.11464090974186547, 0.1107404190406669, 0.11569662223337218, 0.10509819680009969, 0.1374629230122082, 0.15004229644546285, 0.17516372812679037, 0.1473105399054475, 0.2094250646769069, 0.13069242850178853, 0.13089221465634182, 0.14734510914422572, 0.20132366189500317, 0.20336100569693372, 0.14328698627650738, 0.13206753908889368, 0.11376891590771265, 0.12294402826228179, 0.18555330578237772, 0.22156394377816468, 0.09416542641702108, 0.06138645934697706, 0.154407030204311, 0.13118350761942565, 0.16753513278672472, 0.19920407328754663, 0.10778768802993, 0.07020671750069596, 0.12962568027433008, 0.09759971479070373, 0.11047197680454701, 0.1610234400141053, 0.11834074597572908, 0.09555212192935869, 0.13622420432511717, 0.1022381526126992, 0.1020555397553835, 0.13346789753995836, 0.10699975726311095, 0.1639494759729132, 0.13449667749227956, 0.16517872485565022, 0.1532378062256612, 0.22320578224025667, 0.13663522055139765, 0.19886618829332292, 0.08793845860054716, 0.18387281626928598, 0.1404027480748482, 0.08952235759352334, 0.1456454276922159, 0.16516389674507082, 0.06280320070800371, 0.1453508692793548, 0.13947129336884245, 0.12308301025768742, 0.07699289359152317, 0.14505718660075217, 0.11737357912352309, 0.18155437661334872, 0.19715368252946064, 0.12012093560770154, 0.10517797025386244, 0.15442760253790766, 0.1625262593734078, 0.13650755630806088, 0.08777773909969255], [0.07587767569930293, 0.07468137817340903, 0.031164907195488922, 0.03347299760207534, 0.06790862753405236, 0.07454502338077873, 0.05437386513222009, 0.015461866660189116, 0.1055429139523767, 0.02659398625837639, 0.036840563188889064, 0.04199070070171729, 0.02273741029057419, 0.030589731613872573, 0.01256834697414888, 0.06238977250177413, 0.01122948751799413, 0.015074871898832498, 0.03075970755162416, 0.015271464035322424, 0.03436256178247277, 0.03588005340134259, 0.03707681848027278, 0.04711720823252108, 0.041036443508346565, 0.028731983838952146, 0.017798601184040308, 0.034955188966705464, 0.014067322936170967, 0.06092229792557191, 0.014508600233966717, 0.028042367230227683, 0.06632370437728241, 0.071976687759161, 0.03243013910832815, 0.05976632128295023, 0.07811389281414449, 0.007715735073361429, 0.06112390605267137, 0.04763667820952833, 0.01260781717064674, 0.06798733971663751, 0.015093484962562798, 0.08901112916646525, 0.028740887755702715, 0.053691994689870626, 0.07656402871361934, 0.05931916617555544, 0.050053849481628276, 0.03133326339593623, 0.03103361013927497, 0.04447488419828005, 0.04808670542843174, 0.025828216021182016, 0.028955748784937896, 0.028596304400707595, 0.010000901002058527, 0.03263899801822845, 0.05940191935223993, 0.0816514139296487, 0.0632388042868115, 0.022167734023241792, 0.014381620621861657, 0.03325796773424372, 0.011688902905007126, 0.09723552808281966, 0.02379565721639665, 0.005935712424616213, 0.018707913914113306, 0.02846268627763493, 0.032200333080254495, 0.023368399088212755, 0.02281010922160931, 0.014849064191366779, 0.04326561764173675, 0.08154227369232103, 0.06088553192967083, 0.03098315337410895, 0.0452532746567158, 0.020152077631792054, 0.03649833663075697, 0.03452111421211157, 0.008852111132000573, 0.03894190609571524, 0.024872882713680156, 0.014791119156143395, 0.04079426587850321, 0.03232585251680575, 0.00409224125178298, 0.107141522312304, 0.037683676346205175, 0.05274675459077116, 0.04699785233242437, 0.047351044122478925, 0.07191422118921764, 0.04551014681055676, 0.03940380396670662, 0.014268537725001806, 0.021202984717092477, 0.011804469213529956, 0.035402470239205286, 0.05187400747672655, 0.017581743777554948, 0.011152349616168067, 0.03781205305131152, 0.04368272318970412, 0.05263829341856763, 0.029516782742575742, 0.04269175937224645, 0.03587679166230373, 0.09373751890962012, 0.02444041285343701, 0.05390936232288368, 0.043451904130051844, 0.01668786400841782, 0.04018328167148866, 0.026582046957628336, 0.01076081754945335, 0.053077192133059725, 0.02766796671494376, 0.032910761365201324, 0.007889421285653953, 0.035899037538911216, 0.07610988628584892, 0.07115888554835692, 0.037621625378960744, 0.010328134321753168, 0.01545427448945702, 0.06009226883179508, 0.05434909224277362, 0.0960576803481672, 0.04183494245808106, 0.053608966918545775, 0.033496954129077494, 0.07114718930097297, 0.07851342801586725, 0.044570413447218016, 0.026315979594073724, 0.034947247986565344, 0.015045659110910492, 0.04385645253933035, 0.02469930550432764, 0.02075361986499047, 0.03328089267597534, 0.008589809240220347, 0.028787045630451757, 0.023987847489479464, 0.06477368442574516, 0.05382290211855434, 0.042225894721923396, 0.024801350809866562, 0.03903262251697015, 0.011606552343437215, 0.044229927225387655, 0.03917201640433632, 0.03361045448400546, 0.06111841415986419, 0.09498889863607474, 0.039512543444288895, 0.02643587169586681, 0.03275627961556893, 0.0540159458614653, 0.057305890222778544, 0.03641969866293948, 0.04249827776220627, 0.05705073243007064, 0.009502966295258375, 0.014117771352175623, 0.050275421381229535, 0.03156863553158473, 0.03199066522938665, 0.05466105030791368, 0.04684806466684677, 0.05327438819222152, 0.05353453321731649, 0.10323134658392519, 0.04167544379015453, 0.1292506285244599, 0.03744496083527338, 0.019334067619638517, 0.03431101962632965, 0.12191429093945771, 0.06090505783504341, 0.02969490560644772, 0.024901357064663898, 0.032201056674239226, 0.026284673949703574, 0.05761888358392753, 0.02590639571280917, 0.05569993831159081, 0.06596526931389235, 0.07003201593761332, 0.012014803141937591, 0.05352864056476392, 0.028538168262457475, 0.06744363490724936, 0.09792836004635319, 0.020272433575883042, 0.02325961508176988, 0.04183482000371441, 0.022632266518485267, 0.02030660762102343, 0.053560137312160805, 0.03168156443280168, 0.008247073383245151, 0.008748357031436171, 0.04011949036794249, 0.03943625066312961, 0.06858697277493775, 0.07184795482316986, 0.004771174180859816, 0.07492125514545478, 0.08084720044280402, 0.022659382739220746, 0.08289224773761816, 0.02225842446932802, 0.020690403725893702, 0.02620983392262133, 0.04384518673759885, 0.05943274074525107, 0.027849165780935436, 0.10492060086107813, 0.032947404906735756, 0.05605795406154357, 0.040024636473390274, 0.03351534825924318, 0.013604592004412552, 0.06611768418224528, 0.0034847193956011324, 0.034050763279083185, 0.08941638632677495, 0.05842752769240178, 0.043944868302787654, 0.018458277700119652, 0.039621769028599374, 0.028089270963391755, 0.02887914244638523, 0.0108800973794132, 0.07600964439916424, 0.06182124656334054, 0.025545786156726535, 0.05446191724331584, 0.024862141981429886, 0.023641808147658594, 0.013184945528337266, 0.05642231888487004, 0.031928955650073476, 0.02361497394304024, 0.05512384246685542, 0.04320370026107412, 0.06670424059848301, 0.030598819212173112, 0.04470864587347023, 0.015275627483788412, 0.007971102986630285, 0.013455285807140172, 0.05568063133978285, 0.008436287644144613, 0.10030387828010134, 0.05203624095884152, 0.08497181232087314, 0.06062401022063568, 0.02103015336615499, 0.03918375718058087, 0.06656453129835427, 0.022230862959986553, 0.06170190550619736, 0.06711923473631032, 0.028593638235179242, 0.018355250904278364, 0.048829613806447014, 0.04810837985132821, 0.04121666293940507, 0.025009799683175515, 0.013134700275259092, 0.01748145921737887, 0.04485931669478305, 0.055983780112001114, 0.015894782736722846, 0.10770869383122772, 0.06591600555111654, 0.06603001427720301, 0.015292727493942948, 0.02574971535068471, 0.010467865886312211, 0.01684656486759195, 0.043387274199631065, 0.013346915548027027, 0.08109685892122798, 0.02262995101773413, 0.0440207046631258, 0.0394849429721944, 0.012080657616024837, 0.009730562578624813, 0.022227237568586133, 0.018844775222532917, 0.03659270812931936, 0.02684390448848717, 0.020073209598194808, 0.02311082003870979, 0.07122953058569692, 0.0033644998211457278, 0.059859234461328015, 0.02176469031837769, 0.019289713163743727, 0.016680080734658986, 0.01881572199636139, 0.056229831752716564, 0.09004098523291759, 0.03020087406184757, 0.08514502216712572, 0.06535340566188097, 0.05340723633707967, 0.03695155508466996, 0.020874933179584332, 0.02970033441670239, 0.009578752560628345, 0.0536663943057647, 0.021010028176533524, 0.08479060954414308, 0.04617393482476473, 0.019090363020950463, 0.007788959537720075, 0.04575517799821682, 0.07196752965683118, 0.04886506620096043, 0.05016579132643528, 0.04196977213723585, 0.029023959577898495, 0.04642100691853557, 0.02256760504678823, 0.026078796618094202, 0.048508764812140726, 0.0380974719155347, 0.030673876317450777, 0.015029158385004848, 0.023059005143295508, 0.013090935826767236, 0.058731856479425915, 0.053558426661766134, 0.03558764721674379, 0.05383850948419422, 0.015043284238345223, 0.05567798187257722, 0.013580062168330187, 0.037300742988009006, 0.016638581691950094, 0.0823492553899996, 0.05842903054144699, 0.027627760864561424, 0.02105591702274978, 0.056965956900967285, 0.2803312340984121, 0.22996331885224208, 0.18183188047260046, 0.1087469064805191, 0.16217240336118266, 0.12036909494781867, 0.13834026030963287, 0.09761664317920804, 0.19861391745507717, 0.09245519162504934, 0.17656476935371757, 0.16799737204564735, 0.08980420301668346, 0.2833458676468581, 0.11611903784796596, 0.18147395749110729, 0.11283284504315816, 0.09150160607532598, 0.0785138584615197, 0.25982391263823956, 0.1462623750558123, 0.14300277340225875, 0.19924800843000412, 0.08590282915974967, 0.11794245016062632, 0.12227053666720167, 0.11246378242503852, 0.0897975533735007, 0.1445100159617141, 0.17910140042658895, 0.16840623604366556, 0.14088812749832869, 0.12061519111739472, 0.26431826991029084, 0.134319304197561, 0.16025638586143032, 0.2323438465828076, 0.07421705347951502, 0.18484746397007257, 0.14173570467391983, 0.0729619110643398, 0.1296126184752211, 0.11625211234786548, 0.14762003032956272, 0.13461472350172698, 0.19366753287613392, 0.1915060871397145, 0.2180161068099551, 0.13236845028586686, 0.10286701144650578, 0.11431347418692894, 0.11351678607752547, 0.1392633732757531, 0.12184999868622981, 0.15188239223789424, 0.16378647065721452, 0.11860708793392405, 0.15111651067854837, 0.1833200201508589, 0.16853648296091706, 0.2304885961348191, 0.13051186397206038, 0.17349310917779803, 0.17350143607473, 0.08144311534124427, 0.18367153097642586, 0.13258138729725033, 0.16228593711275607, 0.1465675313374959, 0.1301781795336865, 0.09282195358537138, 0.16529902699403465, 0.1519420015392825, 0.07420546855428256, 0.18618974194396287, 0.27081004343926907, 0.08455604634946212, 0.12145066386437975, 0.16023165750084445, 0.06339688174193725, 0.12455299700377509, 0.11618483666097745, 0.1696611038642004, 0.1036264214781113, 0.10376300633652136, 0.10709733483963646, 0.12191762318252586, 0.20912520732963458, 0.138702220574487, 0.16912561462959275, 0.120437186997151, 0.13053691887762398, 0.12751429982017726, 0.12499576230766252, 0.2484121749876067, 0.12199246135423891, 0.23180206393590197, 0.07865965337259695, 0.09287976688938215, 0.09761269495356828, 0.09607920263078995, 0.09740371358930133, 0.1334667397895828, 0.1267388742417097, 0.18075116502586752, 0.19618028163677081, 0.10799732248415239, 0.129345549212303, 0.09163128153886646, 0.09323022386524826, 0.20405742223374546, 0.18177761463448405, 0.12149358226452023, 0.12889709905721247, 0.10745887950179167, 0.08989013629616238, 0.2515802549896762, 0.14310159778688103, 0.13173830753657967, 0.07606886778376065, 0.11129208709462546, 0.0966226847958751, 0.13813881174428388, 0.1854706899030134, 0.2731537161162123, 0.11644116704701446, 0.12737818993628025, 0.12040138579322957, 0.18908609199570492, 0.08694515330716968, 0.25540961825754493, 0.11283306026598439, 0.25118133577052504, 0.0774307013489306, 0.1308570071705617, 0.17706421989714727, 0.15659565338864923, 0.10677030004444532, 0.11907444801181555, 0.08286387543193996, 0.18381697707809508, 0.10405603592516854, 0.10302333743311465, 0.1789668045239523, 0.19498178735375404, 0.1905589285888709, 0.1294103090185672, 0.13107395177939907, 0.08956086763646454, 0.16224974999204278, 0.1093367431894876, 0.1690789038548246, 0.09793749588425271, 0.13700639829039574, 0.15125468373298645, 0.12800702650565654, 0.1824293241952546, 0.1341402981779538, 0.09597132404451258, 0.20018354494823143, 0.07275001305970363, 0.07126012933440506, 0.1784201237023808, 0.11968087172135711, 0.07663556432817131, 0.14921552909072489, 0.11476929386844859, 0.09672950953245163, 0.10692490424844436, 0.12083954978152178, 0.17363110411679372, 0.23542490234831348, 0.14105329988524318, 0.14227140170987695, 0.15144600940402597, 0.2283896243898198], [0.021163853125472087, 0.02931673312559724, 0.03668067860417068, 0.042785440673469566, 0.03538604280038271, 0.019715286616701633, 0.06572686921572313, 0.06761731972801499, 0.02704720842302777, 0.010143098352273228, 0.013069408905721502, 0.0459871473867679, 0.04396159260068089, 0.005979827537885285, 0.07997059045010246, 0.059233325664536096, 0.02867069728381466, 0.030730027210665867, 0.03102172278886428, 0.07257543024024926, 0.013612970851681894, 0.04347626141679939, 0.059266328971716575, 0.04714281232736539, 0.04423466954904143, 0.03399529516173061, 0.03863425248709973, 0.04524611293163616, 0.041059086433961056, 0.04415645089466125, 0.04788494516105857, 0.04710379391326569, 0.03764214947295841, 0.01937801203894196, 0.049178293338627554, 0.01681971025391249, 0.04502248528297059, 0.04895455807854887, 0.05718985543353483, 0.03142824716633186, 0.04424687416758388, 0.02025056804995984, 0.02984701804962242, 0.015770075951877516, 0.05845684994710609, 0.06340804364299402, 0.019026323097932618, 0.04173783614533022, 0.04243624905939214, 0.05638935268507339, 0.026903459984168876, 0.014501788245979697, 0.04516855849942658, 0.17571128468262032, 0.015869417984504253, 0.07314761125599034, 0.07232196454424411, 0.012712964653474046, 0.05693916536984034, 0.05933047279540915, 0.06024463917128742, 0.05496074438269716, 0.04200100542220753, 0.02549962457123911, 0.012561681560327997, 0.06834901796537451, 0.05906182646867819, 0.02152217501134146, 0.04708122149168048, 0.021416439376480412, 0.05249509231362026, 0.018981590146722738, 0.0657169170153793, 0.06646839348832145, 0.01789217487385031, 0.027492196459206752, 0.058330640313215554, 0.06574243947397918, 0.02747958180407295, 0.03479287384834606, 0.04292923920729663, 0.07706321208388545, 0.027182043668290135, 0.04324855195591226, 0.028261382431082893, 0.035907045312342234, 0.01947369528352283, 0.04536024040135089, 0.03836237039649859, 0.01107006028178148, 0.08091277661151253, 0.03374695028469432, 0.03028134142368799, 0.009080188883672236, 0.0232021116244141, 0.08192541485186666, 0.05068603313702624, 0.042500463387113996, 0.04520091984886676, 0.020637781744881067, 0.022793581592850387, 0.04832516860915348, 0.021797016415803228, 0.09411203631316312, 0.0554158330487553, 0.060446529314504005, 0.05030357846408151, 0.062092991356621496, 0.03306262704427354, 0.0712575318175368, 0.01873087039712118, 0.024051646214502398, 0.0366408141417196, 0.03596820941311307, 0.04496792629652191, 0.02326669702597428, 0.02266022693220293, 0.022877922965562902, 0.09015348739922047, 0.025733586626301985, 0.058197992548230104, 0.13228950061602518, 0.028961659991182387, 0.04942769948684145, 0.061238849884830415, 0.05382787450798787, 0.01861167220340576, 0.035607896716101095, 0.09471246346947737, 0.028335103670542594, 0.12994314136449248, 0.04737963536172174, 0.03123309201328084, 0.04064619257405866, 0.011166524636792019, 0.06645461922744289, 0.0388137928530341, 0.05682963921572082, 0.028844101943832356, 0.025697197270346805, 0.018722957247518934, 0.06814162479713559, 0.012934385340486187, 0.029529640451073647, 0.06397957156877965, 0.05943880038103089, 0.05455907550640404, 0.037730108815594576, 0.005796254527012934, 0.022418142070819158, 0.023849913777667098, 0.09540207451209426, 0.05623064440442249, 0.01857189865404507, 0.023777979258738924, 0.009443800427106908, 0.05771131065557711, 0.0036391232197274803, 0.04169237217865884, 0.019582124914450105, 0.04756549882586114, 0.014954061389289564, 0.04147713822021615, 0.032085585917229764, 0.04309246716729831, 0.030451614220510237, 0.04325001769757364, 0.03393887709535193, 0.03325102494272869, 0.02615439734654501, 0.07950933824758977, 0.02310397001565434, 0.03228352783480659, 0.04535212501650676, 0.029030314217379782, 0.016180116253963206, 0.0805791886523366, 0.02132608846295625, 0.06557570857694373, 0.0514846285659587, 0.027449966401036363, 0.08655943689518608, 0.03283148515038192, 0.06345821282593533, 0.022011563887645025, 0.06134588984423317, 0.016807112297101412, 0.028840298436989542, 0.03652604471426457, 0.04031914664665237, 0.01627055993594695, 0.0216077279401361, 0.03507310881104786, 0.031205109335132875, 0.01834274942666525, 0.05300097727740649, 0.04741724369523581, 0.10280484915710986, 0.021360787577577867, 0.04177456132310908, 0.07409271405776963, 0.06492519387393259, 0.041837955577648245, 0.03380314570677001, 0.05583814847341273, 0.023073888914950658, 0.031287966412492096, 0.027283799536235165, 0.027468544212752022, 0.053802147958776914, 0.005576680396188749, 0.0038476242752949474, 0.07566547341411933, 0.03662699535198044, 0.07159636676078662, 0.07335503411013633, 0.04935859440593049, 0.04419221499119885, 0.039072323706932366, 0.04987355954654049, 0.05005968276236672, 0.04958994410117157, 0.05514294905879069, 0.04564602662867401, 0.04998719348805025, 0.020840495672018733, 0.005368149886635365, 0.040177596820285544, 0.07488246308639646, 0.016233647365879733, 0.03214094271243084, 0.08148828987032175, 0.055133920832304284, 0.07810546943801455, 0.012841788502555573, 0.09463980721193366, 0.02501229701010743, 0.08223840079153888, 0.05108244018629193, 0.032856617981451564, 0.03823114384431392, 0.012133261043345556, 0.04296620929380879, 0.041373946296516806, 0.10204935766523704, 0.055174590524984524, 0.05070324725238606, 0.041784754721447825, 0.07592567038955167, 0.03825074767519254, 0.11481488400022499, 0.03872591143590398, 0.08843548232107423, 0.013659352298418526, 0.013437500238069333, 0.08703488638275303, 0.09837887337198481, 0.03459305429714732, 0.023820738097128924, 0.008577691824029898, 0.023736875409667846, 0.03129128381260671, 0.026114881693501957, 0.10646423092111945, 0.05168567266082391, 0.052826561441179365, 0.023620541905984282, 0.04431975306943059, 0.048045486546470784, 0.059495786190382205, 0.06550648104166612, 0.03939969989005476, 0.022899166942806914, 0.038856967294123024, 0.03104846051428467, 0.048993420641636476, 0.029276378845679574, 0.028517015198303852, 0.05189954106754158, 0.04859046413912438, 0.09345107959234156, 0.04221596107527148, 0.03540999932738487, 0.05073524866020307, 0.12967590882908553, 0.043904681006097235, 0.0031261263939086348, 0.05064745630079415, 0.0020794490865228, 0.017641577578615397, 0.05774043995188549, 0.04237438362906687, 0.062376888818107545, 0.028719406291202176, 0.06881435940158553, 0.025530546154186595, 0.05026616308896337, 0.020351630009827204, 0.0493775154609466, 0.010495568403712241, 0.024414289255219046, 0.026265110936947167, 0.012963736353412969, 0.059952385126962326, 0.08401594095630571, 0.04447354833246209, 0.10943727451376617, 0.0599063348636264, 0.041421877904213034, 0.048159005455090664, 0.03940322880225722, 0.04113188369956333, 0.029475439550878946, 0.024535003285564017, 0.040307847448275425, 0.06886107759783044, 0.0690859038149938, 0.027052885852754116, 0.04024816764285788, 0.028172387792437803, 0.0394032993062865, 0.06363387175952084, 0.022016467628418468, 0.04535456668236293, 0.013270175622892566, 0.05392885112087242, 0.07661530369659886, 0.028790993856091518, 0.01230283251061337, 0.10335547078284435, 0.006982898103160551, 0.0464408296829788, 0.08522281408659182, 0.03336058449349366, 0.038732145476387814, 0.011938309053221019, 0.027803167467936873, 0.04772674525156617, 0.09861174446996301, 0.08887343108654022, 0.029245295845612418, 0.025635608290031087, 0.0299323409126373, 0.0383129916008329, 0.03816727832600009, 0.04822346098080743, 0.03739229061466176, 0.03663936695375014, 0.02595639234641567, 0.043261788159725256, 0.026766620940179564, 0.04466843631234951, 0.16150795854628086, 0.1982487362693064, 0.1716302294516936, 0.13386715814704075, 0.090161955304211, 0.1480958063621074, 0.1788802255759947, 0.23399996396619827, 0.10308900265954435, 0.2040139026939869, 0.1313875982305035, 0.14391752978553995, 0.1284972150460817, 0.14468522218521684, 0.1800232517416589, 0.13747145771048963, 0.16116188024170697, 0.11682305397698656, 0.18134880170691758, 0.17133127752458677, 0.10920506392722018, 0.21176608046516776, 0.17929556110175326, 0.19344782747793943, 0.08179302312782966, 0.10786418119096197, 0.08519406328559853, 0.16609474288998172, 0.09461170207941905, 0.11281809856882319, 0.10598959037452005, 0.2300770307192579, 0.10512334818486124, 0.11892686452483758, 0.14205355168087408, 0.11582585982978344, 0.14430395123781636, 0.12818947609048337, 0.2168311196146533, 0.15049279492814094, 0.1466531603364274, 0.0977542670443654, 0.15008213493274525, 0.1387630173121579, 0.24326175916939974, 0.2443449237034656, 0.11901573670911603, 0.11756781401345506, 0.19486078759655356, 0.12191265821456909, 0.12303822906687856, 0.24720471556065604, 0.1522269714041613, 0.19946055952459574, 0.11509936404763721, 0.18259219592437148, 0.120932941645151, 0.17357869364786893, 0.21012151089962572, 0.2344329477637075, 0.19031330739380792, 0.15768281067721546, 0.11979111775872298, 0.1924301203689538, 0.13745357195148245, 0.13005973276449367, 0.10227251405012794, 0.1528000133112073, 0.27774238551501185, 0.1490251236828044, 0.17161749419756234, 0.1380021229851991, 0.12772318470524624, 0.20117880951147527, 0.24901389348087832, 0.21481949865119532, 0.22622568503720686, 0.14104621979640797, 0.1264835160691291, 0.19251607591286302, 0.1967496276483871, 0.17156152141978964, 0.1682737478404306, 0.09786816444830038, 0.09271840914152563, 0.10492615212569945, 0.11775844206567854, 0.2970581443514675, 0.08711852642591111, 0.1079623302211985, 0.13483618036843836, 0.16146950045367703, 0.1262435203534551, 0.12717730540316552, 0.11576588687603362, 0.15756323584355414, 0.16768783709267154, 0.18488694622647017, 0.11994556611170992, 0.14333525556139648, 0.1223968576232437, 0.16837053874041885, 0.14056339336093515, 0.16046138189267367, 0.2498388203093782, 0.16903651237953454, 0.13823236688040197, 0.15749053505714983, 0.22281358687905595, 0.1320272107841447, 0.13859756290912628, 0.09667585225543007, 0.13062563521089032, 0.07971810438903049, 0.13165871961973608, 0.11122286698082462, 0.13505637558409944, 0.1613628538325429, 0.12078359184670262, 0.19485755183268338, 0.10442056402098387, 0.30287494941148907, 0.16024341312004253, 0.09350780936074443, 0.10381314583355561, 0.14016404369613156, 0.09372063504997641, 0.12152655588579364, 0.2405495211132802, 0.10882434959057719, 0.2970164950238541, 0.1885141633101739, 0.16484144842252135, 0.14200712292222306, 0.1497662323527038, 0.16395410697441548, 0.16637009452097118, 0.16987313545541838, 0.13691550004296005, 0.10752274873084389, 0.1834149259957485, 0.24731441983021796, 0.12958916660863906, 0.17788013705285266, 0.14972685399698094, 0.13359085656702518, 0.11380308438674547, 0.1080837455810979, 0.12402271764585748, 0.09484614653047174, 0.26469032338354737, 0.1834732439601794, 0.1348927171784453, 0.19911001349100843, 0.08389497830648907, 0.10393264645244926, 0.17732858774252236, 0.09710629790788516, 0.17078973236493766, 0.1341147386119701, 0.20981448440579697, 0.12508447864092886, 0.17559730564244092, 0.19414068170590326, 0.09125291238888167, 0.10450243033119477, 0.1126315894362051, 0.09749837452545762, 0.18835190014215186, 0.13379304728005081, 0.19774389773374423, 0.10712498726206832, 0.11341516379616223, 0.1177820646262262, 0.08793339715339243, 0.17592601769138128], [0.10347838528105058, 0.029961182626720984, 0.01867973271146184, 0.030506032198900357, 0.047177426095004193, 0.03097385611908976, 0.09721298163640313, 0.0320737152651418, 0.019445916695985943, 0.09514339893939905, 0.026337164199503604, 0.0701272780133877, 0.01884358593088109, 0.026165605631831568, 0.035038962596445344, 0.045849156158510596, 0.0812437002605293, 0.04761058429721743, 0.0677384456503205, 0.029788657411700115, 0.008355737718375167, 0.05820487225719262, 0.026644587742339354, 0.023156940806075, 0.041889675849233754, 0.013190972695156233, 0.04629796996596269, 0.002572389139459119, 0.02035270426858915, 0.05832315204315819, 0.051862300097127445, 0.021397568416432478, 0.05812039729789831, 0.06475420304923318, 0.06367635971400887, 0.03127120500721503, 0.01726578368106857, 0.030071727378526703, 0.003122697439721378, 0.032664435129845515, 0.06142807527794503, 0.0282598313424387, 0.034999740091734566, 0.058788363603525795, 0.02461731302901171, 0.015621798556821886, 0.008698927213117713, 0.010061742268590024, 0.0237252663646359, 0.028692067426163703, 0.031026773103803862, 0.05942578682152089, 0.042005410068668425, 0.0316063997161109, 0.021503760472114664, 0.0352877787372563, 0.0368343810987426, 0.04118683602428064, 0.008061598618951393, 0.050462750587030314, 0.06281621055677533, 0.01001892684143968, 0.007245413362397812, 0.07543068015365861, 0.04733282810775563, 0.020175178833596874, 0.018076058659062255, 0.0696015554422047, 0.01618851922103204, 0.029079008381813765, 0.03134205413516611, 0.018228005974378902, 0.0474958148697624, 0.1105629195808433, 0.05950333012151532, 0.040058845770545304, 0.01653630446526222, 0.03188095353834797, 0.06276008192799054, 0.06595642291358672, 0.04590733311488293, 0.03492579620797187, 0.030739779031137004, 0.005886986718905973, 0.061321588218561374, 0.07145455718273297, 0.06167132160044275, 0.012519624979177024, 0.060087270467192866, 0.02071570354019059, 0.036393708651303314, 0.057985864477814175, 0.02211118051491212, 0.05193959106691182, 0.03365729142387863, 0.023735209288133774, 0.07263466104632244, 0.043707425575121306, 0.042166344792349264, 0.029868827914469875, 0.03549033681338187, 0.044238383998163044, 0.03985058057878632, 0.01796972930605989, 0.07476524828234687, 0.05710259370971471, 0.018466634282958694, 0.04167674997006543, 0.00918250600079773, 0.06349405855871737, 0.07962702060467564, 0.06445034552598372, 0.014817067421972752, 0.04469903506105766, 0.0878913322230801, 0.015268518636730732, 0.08425938765867613, 0.04443789555807598, 0.013328196728252806, 0.016471999224449974, 0.034284421053598635, 0.07013058799202554, 0.07772261029458605, 0.0327095873944927, 0.051358559940126725, 0.03565241815522313, 0.01721036936942255, 0.05842831807967741, 0.024364311175304465, 0.01842417044827016, 0.0418004956736695, 0.03717056657478679, 0.037648353827535175, 0.10745118343038484, 0.023327798044192605, 0.04058911399624776, 0.009236336754838703, 0.0161982877398259, 0.01651056678383611, 0.06303465430391952, 0.03637157780758571, 0.07101843410055153, 0.06506007921416312, 0.053297639678930864, 0.052801899873884395, 0.043634609755827114, 0.03151231394440401, 0.030062914374866523, 0.041644774537417106, 0.029936606406408828, 0.06785916339140385, 0.021821948867000174, 0.02699685370316729, 0.029394779230642598, 0.07715873391134664, 0.014261931682995055, 0.045703698924626224, 0.0303842531866394, 0.05371287501475308, 0.015433443331858143, 0.07365337747614831, 0.023993395043362398, 0.026215854595648125, 0.04321080632507801, 0.05440956614620518, 0.06801527415518649, 0.09447109478060156, 0.00990084186923923, 0.06616033540922217, 0.06926038273377344, 0.07123182382201776, 0.023876037375885062, 0.023286838913918473, 0.05069157326943241, 0.04514472071605269, 0.07562796527054161, 0.05347706872271374, 0.05806586799735669, 0.025110407077590935, 0.02497616926120827, 0.07973539642989635, 0.015247706960508367, 0.059577941938186996, 0.015458884154213592, 0.02054885761026526, 0.03611536245443858, 0.021706860316044185, 0.027725865365937352, 0.06534527172334492, 0.05930735860601999, 0.009180811121041188, 0.04618594277417287, 0.020088585042685736, 0.06070720497518778, 0.0513533426419599, 0.027715319447452202, 0.010119711423612898, 0.004630181429092772, 0.03551318382960744, 0.030422290110436734, 0.08383473817957565, 0.01427970704753534, 0.0751487011439167, 0.023041085987642873, 0.016488849687448237, 0.05007970961742103, 0.023387073379126377, 0.009525136101729004, 0.052552211709553376, 0.025497565111436415, 0.010160578713112045, 0.03463238070253283, 0.06428009684896097, 0.057807715638773516, 0.03191530755429994, 0.025957401667255908, 0.005122670163473231, 0.036796487038373016, 0.022363740790751763, 0.06028956137015484, 0.03805096152063925, 0.04642914827854838, 0.042041374545078725, 0.003021496095243492, 0.00710892637471261, 0.01885636942461133, 0.0659793107479345, 0.06947007655980997, 0.05094767358968966, 0.007830169142835075, 0.05763988636317663, 0.037272808549460024, 0.029279065420269035, 0.09481958506512456, 0.021086679043946788, 0.03906206722604111, 0.05286399165925104, 0.07561747872387059, 0.05000560988264624, 0.02967548916785745, 0.03869615131407045, 0.028364446334308013, 0.01562044784805039, 0.03000592114403844, 0.046273894695332274, 0.02357048218982527, 0.03038129387277877, 0.05012309928133618, 0.05307428291416727, 0.021795162901980802, 0.06109194546297658, 0.024453526602883358, 0.016563014360144734, 0.03595498434151523, 0.037888794831815176, 0.009349499432573793, 0.030359463598870207, 0.027823747223010287, 0.014017112935107434, 0.0397094500658568, 0.031452366965822875, 0.15490695572225377, 0.07042677170829847, 0.033637004817137495, 0.054339537091436796, 0.041727134375832975, 0.039207312947837636, 0.06167904364701826, 0.033141320673166774, 0.06882681263959967, 0.03230136906495318, 0.04949263369780965, 0.03406376941711642, 0.018627030949573964, 0.04131909787247423, 0.01459720246202778, 0.030807316325081047, 0.031990520510589704, 0.047660890777478926, 0.10760311590274796, 0.029505817510653287, 0.04064136119268369, 0.011348638399795163, 0.04967673456121702, 0.00563988679459726, 0.030392993830901105, 0.05861735793587286, 0.08871544268913567, 0.03955376974772662, 0.017479696616646834, 0.08792416483629495, 0.011699108363245614, 0.021661552200384904, 0.03760863037314266, 0.025902035595208872, 0.06522492505609989, 0.08316695370012894, 0.03768814778595697, 0.0825711723882705, 0.00011931261781228386, 0.03748823546629865, 0.02467894839355722, 0.040102087004925124, 0.018011612410191447, 0.028793446654162835, 0.041402062561246566, 0.016766043700044975, 0.03515103060635738, 0.041903194069163874, 0.035540190583560616, 0.03419159693294205, 0.036367889333632775, 0.015094850514287828, 0.010933567264146404, 0.06299141678027809, 0.016993896024359856, 0.021178169154154602, 0.05430452998552937, 0.03594031208194792, 0.07051683132885955, 0.05523470819753129, 0.04303842768422328, 0.03158330036967527, 0.0027389869137550704, 0.0418233797972789, 0.062229516843217425, 0.025532438630762044, 0.08716105890925974, 0.04121865189517848, 0.04430529232195113, 0.017285721478401683, 0.037927249213680625, 0.029425719367282, 0.03152261124341749, 0.07433934457367286, 0.00865082398377126, 0.040429203436360694, 0.07200644045951776, 0.034184594769612886, 0.05872622728929855, 0.031238557930919342, 0.016165020970220212, 0.03512965304253157, 0.025727552965690847, 0.04314304453146178, 0.04792791180079803, 0.033859300310723484, 0.03470577168627642, 0.008075844143604627, 0.021260349021758884, 0.040638062346260995, 0.057161594450008124, 0.23741083015920594, 0.15476012922590598, 0.10600268928101286, 0.14762445352971554, 0.1444726562476717, 0.12573443673318252, 0.22239796933718026, 0.1847212840220891, 0.08911648445064202, 0.19307283509988338, 0.17808004195103422, 0.09715761741972528, 0.1820436745765619, 0.14640414010500535, 0.14172454277286306, 0.2252922859042883, 0.14532240049447864, 0.09645653277402744, 0.11678164213662967, 0.1309353779652156, 0.10835006527486257, 0.11229915922740474, 0.12541945441626012, 0.13441446237266064, 0.13792124373139814, 0.12219365016790107, 0.0985516601940617, 0.12335685532889329, 0.10838689806405455, 0.20257161289919168, 0.16957856219960377, 0.07822373809176497, 0.24258532124804333, 0.13283386593684554, 0.1191231477423571, 0.17993358545936644, 0.16682850429788232, 0.19397046271478757, 0.11103050230303779, 0.061269938451005146, 0.13564510649302974, 0.1294537098146975, 0.11723320189048536, 0.1382571249268949, 0.0660437365877442, 0.20349848113255575, 0.11946912214625627, 0.18757136858766899, 0.07387996258330531, 0.14394132304005325, 0.15351096109952778, 0.15691917040385306, 0.10379764979006723, 0.13147594348993152, 0.17698041658150032, 0.1132960787799675, 0.1526543594081886, 0.24087069294182584, 0.13420867966488004, 0.111260671983473, 0.13801196386339143, 0.11047973224776797, 0.1647538601537235, 0.12984767148736864, 0.20926156954374164, 0.164795093878638, 0.19771461258642375, 0.17629934765864164, 0.09435529005713761, 0.17902469204273075, 0.13060861034318805, 0.13020498590776697, 0.09189803167828359, 0.2576799667440355, 0.22195855854079127, 0.12350434975815006, 0.07477669219952077, 0.1451694587012753, 0.11785314753069542, 0.16888645011931658, 0.13436818204354495, 0.13015328790061176, 0.2366573573090136, 0.12823124416172504, 0.13172860024496913, 0.2321988606126979, 0.16984382062219083, 0.13101072079734877, 0.14932434278307483, 0.1481713421526365, 0.08216285015805624, 0.1423689050716348, 0.23274147446500137, 0.14329789584735408, 0.19517620035912842, 0.16580903087742627, 0.19867431343300268, 0.10194931615842506, 0.1736554317176342, 0.10884035029448569, 0.12827074126107618, 0.1612663597916253, 0.15974727255525067, 0.2614230627659708, 0.11138727495563217, 0.08945839930674993, 0.11043443897506222, 0.14066880801692605, 0.06701122256345116, 0.13579969585407525, 0.17527122079627588, 0.15291740623069927, 0.11535395780811086, 0.13346776395337656, 0.142212608770933, 0.1159377460135147, 0.1972467330051586, 0.12293097388464957, 0.10245257391943596, 0.09970728060579859, 0.12822030490497127, 0.1060545579821337, 0.1761164379422553, 0.16158117883605883, 0.12494240188971162, 0.09716147658764385, 0.08802318217931315, 0.14251313405111432, 0.15500586916459724, 0.18112011632183567, 0.10540976523770951, 0.1406041521113366, 0.13537334685679525, 0.2146427339175716, 0.1534905965672806, 0.1757801411440596, 0.1257113559404388, 0.09871017551631667, 0.16980177053483203, 0.1409168486134149, 0.09730623991345055, 0.2068399268318899, 0.18425672926241532, 0.173132544150576, 0.16801255638711154, 0.16317795409122482, 0.16476726334076375, 0.13342733174795285, 0.1046972069889307, 0.10826632133102976, 0.143905833538156, 0.1243915873055812, 0.07705982789047994, 0.10507745377253741, 0.15216233034152538, 0.12060457840561867, 0.16391312557971105, 0.11716194087057374, 0.16621805814793333, 0.09411521270521916, 0.20067993784323335, 0.11157256696606055, 0.09593165625119582, 0.13385495723923668, 0.14592226361855865, 0.1466721890028566, 0.18067325436277315, 0.12032322279992513, 0.1819147783680819, 0.1892573499935679, 0.17813815211411566, 0.0943059149722103, 0.14188719185767695, 0.10997925011906773, 0.1060260520898737, 0.11575062831980176], [0.007996569784154417, 0.08058188264840282, 0.04127855063416064, 0.08653987388242967, 0.014460558231803589, 0.0684894248843193, 0.021905139910813887, 0.045165627016103826, 0.04438929601747077, 0.06916034864843823, 0.016408777519245632, 0.03834245115285739, 0.08331179124070331, 0.032145180375664495, 0.019550442630134057, 0.026167281030211598, 0.04605553258443251, 0.021955069751129486, 0.01949780580616789, 0.030441951457760297, 0.04361930667073466, 0.013984921351948287, 0.028812723940063734, 0.030088277271715924, 0.014213333997759037, 0.051843045075656846, 0.06642197957262397, 0.03392630140297115, 0.018200492704636417, 0.012984569366381038, 0.03511398259433918, 0.03601889438868966, 0.06605862407013774, 0.06046072288881987, 0.014227356878109276, 0.017168168997159228, 0.005412539130702498, 0.07371886458713561, 0.07059981086058542, 0.021369266614783555, 0.04219095812004525, 0.03423245216254145, 0.031196274067042395, 0.03793532006966416, 0.045485373921110295, 0.10081309548695572, 0.005475425941767753, 0.038271935991360806, 0.029464797153195832, 0.04203112177492585, 0.026732283622550312, 0.013710267339774873, 0.014853510583634488, 0.09767610405106097, 0.009483963603997836, 0.02142600751540158, 0.01744357628922444, 0.018648564364411868, 0.011276984041614924, 0.010938541508949129, 0.10203591737081297, 0.014968500800023321, 0.10746463114628568, 0.03228334229788743, 0.04869782322202809, 0.037156217149458826, 0.004452739021871821, 0.029288451733009424, 0.11524542613187805, 0.09672378015238792, 0.05473094577610027, 0.0585934682021616, 0.018265387952851597, 0.015719331604486797, 0.04349976894445717, 0.06536922825034708, 0.03992292513430584, 0.020396192267071456, 0.023258620603883173, 0.03677620414237026, 0.005966754606561153, 0.02171386619011173, 0.03926498153305147, 0.04371302136860322, 0.06050482872524299, 0.06016696228471119, 0.00916937740839785, 0.022519127960549667, 0.030333915165101644, 0.05076675282907672, 0.051655140705406666, 0.04636774669052102, 0.029938244697405025, 0.05115219464641996, 0.03767428075661883, 0.02637699155457085, 0.05573218091740273, 0.05017294563003816, 0.013851804178557359, 0.08224801160395145, 0.060877134528709576, 0.0128632950145402, 0.07978727997397073, 0.027757692369050346, 0.038162305936566554, 0.004794592650796403, 0.0239641358712106, 0.04665253472921904, 0.038575685903197154, 0.03581514145480469, 0.02074938776786439, 0.05416886539023835, 0.06975092750508338, 0.014525462756864727, 0.017176477340399288, 0.11419189555454068, 0.03749595380213577, 0.03322644130093977, 0.07782294123899192, 0.032389361804234795, 0.06994646857492626, 0.035985186041216366, 0.06273072998737916, 0.03684617011458613, 0.024930846302595455, 0.049630439389147796, 0.031952492863638327, 0.04205319695756771, 0.0121102563207387, 0.042037875318783335, 0.03868809530104045, 0.015152229661907768, 0.01867553401098121, 0.06133589682576712, 0.024079404392978176, 0.10973401484079659, 0.016069727353169583, 0.06801484370953403, 0.0213855456240708, 0.022237191624299157, 0.062243918218882754, 0.018643593830347527, 0.013016218254051637, 0.036530156212393194, 0.02940840135124745, 0.03364886433701031, 0.018730471492744982, 0.014859044222248485, 0.08902971996576525, 0.08755976290558465, 0.039885895675979555, 0.04312584896979388, 0.0208831951385946, 0.016746912988310214, 0.06626764254178852, 0.027912393052247353, 0.012976540256204316, 0.01978412637981819, 0.04313187149818987, 0.06739051197655499, 0.011173087077622768, 0.04988175285689067, 0.03361524133651983, 0.01992826073546894, 0.058482223976170644, 0.09167496435111389, 0.04388842426124029, 0.04703211357991677, 0.022024902136763558, 0.039969394711079076, 0.06485932084615342, 0.04318475323088933, 0.028818449609389063, 0.07357971931924112, 0.061948921938892454, 0.04505650904320646, 0.051288913091411814, 0.0436574085324537, 0.053896159515716136, 0.0628139173204545, 0.029479526929208077, 0.025180742268275935, 0.01423389148840215, 0.043712520418921486, 0.04398471050080843, 0.0625037589634303, 0.06403118793969043, 0.05264525105303619, 0.020565529957821127, 0.02048684560577385, 0.04175164380285423, 0.019862478620780166, 0.048013678097049706, 0.03025335317943245, 0.026999441943189595, 0.04535575040790718, 0.02924058135249652, 0.04675050193327479, 0.08169126725988463, 0.06099751088186167, 0.01652283448493108, 0.07566263098851778, 0.046483224869007245, 0.006999691049713874, 0.025408420187886804, 0.07744729577098042, 0.028100033960072324, 0.04430811990459915, 0.03895476009347476, 0.024295068797073327, 0.058306728315074, 0.0639216395211406, 0.0347456138842972, 0.05671537444868591, 0.058734943813760765, 0.019184938610123936, 0.037285766447894275, 0.05783166845503729, 0.048398448270745575, 0.0334935884893639, 0.04937829100526869, 0.03254092691349797, 0.03040846946532838, 0.0351359984051669, 0.01124903012168943, 0.04315214326197747, 0.08040675063966773, 0.028091063250030857, 0.027582924012676813, 0.023944650783960242, 0.015497494387091137, 0.03926616525859572, 0.039435245053027757, 0.03841821329842787, 0.04941908686305396, 0.03523794723150786, 0.12277472211280838, 0.02051718645816436, 0.10474123118910939, 0.0504149933840381, 0.04811069535207935, 0.022330065839923918, 0.03932403422368225, 0.018005608435487375, 0.002435416276966862, 0.06874457525555044, 0.052591378553188406, 0.01613271342648659, 0.006337723616525182, 0.053351059468695894, 0.11057457872084342, 0.04788693411683198, 0.043903753321501426, 0.03158463994623162, 0.03579101052309852, 0.06207987018569838, 0.016620339702058118, 0.055418809060938656, 0.021232486942608375, 0.007255228265421465, 0.03610563660913613, 0.035543207413866185, 0.01960426689038286, 0.05023609126510564, 0.046434257965302095, 0.010593419647193514, 0.03194196549884509, 0.00998329633148387, 0.054565918107982725, 0.005684290417775628, 0.049099685056717135, 0.08123500971123576, 0.019239237844885793, 0.06992177732172422, 0.051908420864492655, 0.055215434622368775, 0.05725657450966537, 0.03214403004676569, 0.022742692526662722, 0.011425759603298502, 0.013690844407392433, 0.0020660296650021337, 0.059186755897826515, 0.04087990972038824, 0.036317189515102655, 0.039568018983118236, 0.0330249890248524, 0.010327185300411656, 0.030472542784991674, 0.035808135580737144, 0.05459622370835859, 0.04146965737163555, 0.026805364759638906, 0.031969729243428446, 0.01887851696665166, 0.048846920690266415, 0.02507863573555369, 0.02407028525340138, 0.05088037192763295, 0.02000689499254804, 0.026986532284354325, 0.03314064160804264, 0.027733130991691723, 0.03094625750236446, 0.015750414604553953, 0.040827321136021055, 0.04640195598767605, 0.08294516286696307, 0.039638879243284464, 0.05173595687665511, 0.01737602044158848, 0.037278905292623676, 0.03325804937048815, 0.05836235228343867, 0.04753879635245539, 0.024013540642044973, 0.039635242719668895, 0.004826911326745176, 0.049593083385843784, 0.005617066217382671, 0.036557444982463494, 0.016148359754879493, 0.02948354565887712, 0.023676227101532277, 0.08583342350902967, 0.024366502366319764, 0.01654438459809171, 0.008334972426382592, 0.06421930011129007, 0.059573292382992804, 0.05251581678749062, 0.054266435545287095, 0.08130025933496654, 0.03458817467617337, 0.005676258060702821, 0.04497541827731766, 0.048207916697720066, 0.052379591870703734, 0.05877890122064855, 0.03567580693925265, 0.031707276139059104, 0.0704702541406732, 0.07309885957511142, 0.03700011751789134, 0.028819625913456548, 0.049208717682631686, 0.027661181629810017, 0.045864533458370715, 0.07764574605971575, 0.025559269124642015, 0.045672866399399936, 0.023377315992547665, 0.15686667087720707, 0.08864896852173842, 0.1505508308764547, 0.17427087994292378, 0.06525786156998947, 0.17118111136369407, 0.13362357043661177, 0.16190868860576302, 0.2115323336329311, 0.16222505131736398, 0.18647319782758132, 0.14046004187548533, 0.15697616734541953, 0.10485431223060004, 0.14158767589833587, 0.10738657947513275, 0.15124401164939627, 0.08431863330770284, 0.116459327400662, 0.12094699792214669, 0.12407458634697832, 0.10341257162508555, 0.10584395873593166, 0.14027057157363743, 0.06982892722589895, 0.11538985549123026, 0.16998704028083012, 0.12293124105781317, 0.15113003260921687, 0.13033701397944242, 0.18434648460242897, 0.09694989770650864, 0.10835796914761886, 0.21533499442739412, 0.13288072514114901, 0.12566008837893605, 0.07933839195175096, 0.14052331738639623, 0.1746209361590445, 0.10813813016284257, 0.17848742165369913, 0.17454259505029768, 0.15397327457321808, 0.1289085132884793, 0.1291083885007538, 0.22743718174751848, 0.07329480882617645, 0.1455138745950535, 0.13094852882204577, 0.105367960059084, 0.14063803857425228, 0.11787210198235698, 0.17924459039932117, 0.1544411393115297, 0.06846575037343428, 0.12152778785093687, 0.07933384258649312, 0.09777246450539678, 0.17645861255005002, 0.13410240411758423, 0.39062755939085037, 0.09675593741121702, 0.3420543798711151, 0.10674087388906628, 0.11536511970916763, 0.14496749063255265, 0.1612930474220775, 0.09668117345427163, 0.22037514194380492, 0.17128134582890198, 0.18855066213291138, 0.15391822205856442, 0.10101588733959943, 0.15441826632013544, 0.24913404718972743, 0.23655403550947085, 0.1581142211216502, 0.1112048550567124, 0.16081684094388038, 0.1647675156709738, 0.08950822710175999, 0.11974068882409483, 0.09763207985088229, 0.08805499062873423, 0.10604623850667849, 0.1368974064826034, 0.1254182224511169, 0.1812822013744153, 0.11038793600164354, 0.18467043206328526, 0.11399714858271182, 0.17405354941729456, 0.11851081653730944, 0.1374300310271792, 0.15857359569054097, 0.2618334110593423, 0.12277308196644299, 0.13206053321482614, 0.14368667732924223, 0.18865312304114923, 0.13977673166664317, 0.1453839839086868, 0.20119201974011958, 0.1585590941249393, 0.13522594148525968, 0.08352263539563864, 0.13552630349295214, 0.10381822954514064, 0.13998778362292796, 0.10811050000484101, 0.10068481526104733, 0.11768945943913423, 0.12056776788085699, 0.131217913585715, 0.1314404688309878, 0.14738396799657494, 0.15805504226591438, 0.15779702720465139, 0.10791808337671682, 0.09853551106061786, 0.16146084701176733, 0.13501089677447453, 0.20313812390668318, 0.08615558239398524, 0.17758672154741362, 0.2273741437238641, 0.14809525717282668, 0.1335225344519131, 0.23522171715740114, 0.10313734615920112, 0.13653804373461753, 0.18927021883428097, 0.09968819256755523, 0.16770266520325094, 0.09601860627299175, 0.11390262865461409, 0.09565415239194408, 0.207862576644402, 0.1853025786112994, 0.1252766652032733, 0.13217378495028242, 0.15849173680180684, 0.15417049289681017, 0.13674814574187621, 0.16719807899789885, 0.0928349189052824, 0.14727421919815242, 0.13899312762077898, 0.21850675548193976, 0.11265333436313085, 0.15737052977783605, 0.074510439299047, 0.13683175609912723, 0.08542145733372308, 0.1925672692595981, 0.16845118050696328, 0.11989009057288058, 0.10999640115187503, 0.08409369576838799, 0.1893753811600618, 0.07926287842565216, 0.11033968898118474, 0.21736055292421952, 0.15250780008500442, 0.13920095865614712, 0.2150852617342025, 0.16707923146896064, 0.16121506254421547, 0.0885109364753589, 0.12326901472988538, 0.156234999303706, 0.16621152724837884, 0.21455234033055604, 0.15303371561458334, 0.10776419163448736, 0.22020551667083055], [0.010873507108044578, 0.025979779275075998, 0.014305195181805175, 0.05018381438276265, 0.021713331843784545, 0.026569419314910192, 0.03271563589805737, 0.08544464944861829, 0.029740577374468558, 0.03609845261962619, 0.05475050136737991, 0.03724071437318344, 0.03383652750926558, 0.06052566081052646, 0.010984383043251, 0.03890690641128458, 0.03706820214574691, 0.04523095085460227, 0.0303525820345385, 0.0450810667098267, 0.010878706780204084, 0.02263268212118419, 0.016315185275743715, 0.04009350777778309, 0.04925571789499372, 0.015249489042616915, 0.03626250436354894, 0.009478830725129228, 0.01180667710286798, 0.027225077101320494, 0.008206177335523535, 0.061720785743091255, 0.030495746032102033, 0.028315466443018522, 0.018036251713056117, 0.07118120192899369, 0.029098222585162148, 0.06655946985119954, 0.023135789597290568, 0.039651952174608596, 0.062389134254772216, 0.037029903614893556, 0.03155737344059162, 0.012938941199536202, 0.0402373619726859, 0.10215309506747872, 0.04855017294175923, 0.01337617100944044, 0.03556779476639349, 0.06505239056423306, 0.032835388847161084, 0.030969959843787365, 0.008273016082966933, 0.025411440728930756, 0.046506246289936826, 0.031042920381878503, 0.021812640479765832, 0.02701392866583774, 0.01554065120217274, 0.029677248057851102, 0.03911825522664003, 0.00938987319386797, 0.016680494481988717, 0.030094186622591224, 0.0071111416855274, 0.04558048014587257, 0.04937698853609618, 0.06981039579841308, 0.006220119648787659, 0.05121856491314247, 0.02447224542265758, 0.08270530815934762, 0.035949106531916186, 0.02784055315714795, 0.07522733911173418, 0.00865211439304403, 0.008754691261856351, 0.07814142649294809, 0.03688616074214224, 0.024578103511885274, 0.06657759309746325, 0.07748602845822461, 0.015461706170754042, 0.046703134357812814, 0.07325736005441286, 0.016069664270617068, 0.016488996261614375, 0.010056091741716955, 0.017715642061375547, 0.022824905790912453, 0.06541774986544624, 0.07990553378476761, 0.02937809760624077, 0.0332896871259436, 0.05140025379660074, 0.008942669846874196, 0.031131469731917605, 0.040980407648021355, 0.06539850597619079, 0.03676682710647583, 0.05372576983063482, 0.04938378289807588, 0.05388631492678542, 0.0256106405868195, 0.018684868373384234, 0.021504656615434214, 0.08276473192381673, 0.06303379341261461, 0.09007219996419735, 0.05488033268193249, 0.03402580114197917, 0.06088482688937802, 0.08686845234478824, 0.043564643783611245, 0.02494419939466752, 0.00039685552678747626, 0.010207826617261162, 0.06611707562115043, 0.0432478803122649, 0.024895720453059766, 0.023634486860828474, 0.014369769451150205, 0.0529077561077429, 0.013956546263216296, 0.04253453167621046, 0.026149283949052915, 0.06981570957577787, 0.026867217202379834, 0.01856688173575094, 0.03383018214663025, 0.04081722421688028, 0.0838232423120644, 0.07034182548522949, 0.08621931803645566, 0.05425325871328823, 0.061103400512365624, 0.05046701793617103, 0.023871463890827727, 0.10042104113381356, 0.05837000753672328, 0.04870399417995941, 0.03844951708742883, 0.06815825632656924, 0.07181137436418794, 0.03190608636941761, 0.1360685908002779, 0.03846897991024889, 0.03554413509846199, 0.022795487057010178, 0.04578449283144437, 0.03906140300387051, 0.028204019981785677, 0.015846472633711528, 0.024405648800893687, 0.04309367315727286, 0.04360857892606873, 0.07863073187763803, 0.06417920929379761, 0.03787797060795128, 0.055063632025849074, 0.02421712844807189, 0.04692490663728677, 0.052290986859588884, 0.026830659007828217, 0.030264984488894697, 0.04477527589187957, 0.04290878932806663, 0.031945627997629344, 0.02929471360403113, 0.05756284772360232, 0.026284926279913634, 0.007819797629053937, 0.03316109148727264, 0.024339337905985303, 0.08148195935063995, 0.05622457363642752, 0.016071311838459224, 0.03690183119033463, 0.02982398549647769, 0.05476888065459207, 0.0257714955296251, 0.024761391723586712, 0.03619623799750116, 0.08389817696297541, 0.01059171641827561, 0.02631154526170576, 0.05788668386230711, 0.04855340128415264, 0.04333586563006975, 0.034990466956514865, 0.0215368621138623, 0.06881652647280134, 0.047969483202905394, 0.06797815192840062, 0.0147381344504538, 0.04305297748942394, 0.04463531055080239, 0.03383613046025857, 0.04061666251800489, 0.06305449933279306, 0.019854316851706244, 0.06470477601396851, 0.030567504290957004, 0.0553069006127771, 0.021712198213208467, 0.05659802976879291, 0.025269746183766983, 0.029419151360343676, 0.02172804863221245, 0.07002582642599009, 0.08713346585864201, 0.050921527727041394, 0.025626576352806296, 0.01840556666138582, 0.013615624957310501, 0.02010951175179798, 0.03218166435544845, 0.040908419323386624, 0.02083050821966026, 0.08113976989989169, 0.07532001109211706, 0.04401409583806526, 0.049481011665193364, 0.008373605851375032, 0.07035010785330087, 0.09373953012982383, 0.03644875003374182, 0.004622713568096515, 0.015841095773794223, 0.0059683942890842445, 0.03565884515410289, 0.012115794597775675, 0.011201549368706765, 0.04595965823682491, 0.03408531396416947, 0.04219987131364178, 0.004092289027539664, 0.06449854801758192, 0.029172650720283855, 0.056449960175086744, 0.02303588353242958, 0.04776286557898857, 0.036788750148843974, 0.06226714001968503, 0.03223366664315108, 0.03468424569291528, 0.03347855628817342, 0.06249825964914635, 0.11780353495851159, 0.03433637881244067, 0.05019899872422684, 0.01459214565329603, 0.006062083475626423, 0.07449003765941598, 0.05866698164027184, 0.04157939132710453, 0.035418077604845166, 0.05207665089983493, 0.024424399161944166, 0.0630022372934036, 0.012205583334434777, 0.018860735108319204, 0.02005737587751355, 0.02779128568363376, 0.008871775262377923, 0.011853065043396782, 0.018443247354298364, 0.012254321100044763, 0.051055897274636663, 0.06633876997511834, 0.04486098281631712, 0.07181050605140626, 0.030576630852010567, 0.08125518128508702, 0.011373769375495613, 0.07132280370569788, 0.04211092491459567, 0.013137728237779811, 0.050307552664889954, 0.06651303367107175, 0.06249770303838886, 0.013848605522071011, 0.018783134291879833, 0.05540389189263806, 0.08375211487873457, 0.06849781857454218, 0.052826539176749066, 0.03744402201846242, 0.040560014385846443, 0.0097739438933786, 0.0180000256295898, 0.04253775259712711, 0.018623075302457437, 0.01714407146209851, 0.01604653338290518, 0.05651839361235034, 0.037610712097375654, 0.013473537073878106, 0.026629807871358935, 0.05669290963851381, 0.02131758345058188, 0.016043746618379373, 0.05277396172459703, 0.05261452613922302, 0.011594827337830793, 0.029330303295864724, 0.050740877850330435, 0.02252631566079799, 0.030084355021244846, 0.034196476553916, 0.04365551605587825, 0.02377508117206162, 0.039004914433462545, 0.05736480561608914, 0.01920843315019738, 0.09948012404493056, 0.03238261197111569, 0.055232440936379135, 0.08262813222245313, 0.06658908896497451, 0.0275753132882528, 0.01885655125079211, 0.0015219578403957712, 0.025255548898712732, 0.04340987259638496, 0.043108460449730046, 0.03226499640732072, 0.031135529279708862, 0.01783881445589941, 0.03155083511956036, 0.035644985546241514, 0.11712949417415075, 0.0434918390965322, 0.052806386156589724, 0.04833243423490785, 0.046278737208922394, 0.04885029004071839, 0.028390349143592175, 0.07694095067563467, 0.03534942523401696, 0.07362234828178771, 0.04139258533541579, 0.012475495950639015, 0.06903159344801679, 0.05055220164649654, 0.06799764072638936, 0.047406805388163775, 0.04694203169492539, 0.018777488403429743, 0.03837530603050254, 0.017412806846550666, 0.04484960940317251, 0.10839447539183311, 0.18310322397155687, 0.10500542834051885, 0.1298600950394757, 0.07894324284279719, 0.07467533709132113, 0.12233302550157532, 0.14408972288947552, 0.09117339868680574, 0.10272646351950243, 0.14867019897792488, 0.1668637414695695, 0.10145710155484267, 0.14430089358938858, 0.07622625504154712, 0.13619288569316268, 0.17323027015663683, 0.12391366646625102, 0.14206457999534905, 0.09940251766238362, 0.10974173317663372, 0.1076213207852561, 0.09395104963914491, 0.20128276955801994, 0.18071672937367111, 0.16522686055395752, 0.08913275232771412, 0.17496964166639373, 0.1108133202069439, 0.1870671534561552, 0.09818710983381607, 0.11264461412793025, 0.1447998097864911, 0.176119243260473, 0.18304719182197005, 0.15373118600109592, 0.11669892235659063, 0.12689350813161582, 0.0574815825530095, 0.12916966021293774, 0.1623343102983199, 0.11673199987853877, 0.11320138815790415, 0.116129650559742, 0.20969891716958955, 0.15179306734353304, 0.12061651956173591, 0.07631950589711778, 0.2126816680538468, 0.12426582296029665, 0.1357310323510319, 0.08340315704117529, 0.12544452416477725, 0.16622708266368136, 0.09964198645320721, 0.1592181806336157, 0.23867902695201337, 0.3035093075595796, 0.12659078609431162, 0.13640779681736603, 0.09117506109760143, 0.1302328016026877, 0.1473939573043026, 0.17908176319906488, 0.10027627780800685, 0.2197634638287127, 0.17396339331753552, 0.20604237040970474, 0.0848222769855056, 0.12434486168785952, 0.17754585889633745, 0.14654596452601254, 0.13754884887021035, 0.056461081258021295, 0.1592267895466648, 0.12368054303806275, 0.15733560430817306, 0.15509520890191197, 0.1647371766739525, 0.10246508652926423, 0.14372259727679193, 0.1097732076596003, 0.08469686887110583, 0.12287865247344598, 0.10021580761531368, 0.09690211081760935, 0.2040644726366736, 0.16679335618391633, 0.09572953233146109, 0.1353384807589464, 0.13634989445563406, 0.10166128122364171, 0.17095009563490748, 0.19724732672329992, 0.13948946114396676, 0.1071391103323549, 0.14827546547167003, 0.12678711384069175, 0.15572094329399988, 0.14674385078251362, 0.1664049903047271, 0.1268285998958163, 0.181913694832474, 0.1740815135417506, 0.1167336993967183, 0.09783543573576026, 0.25005828822031617, 0.22161714092362672, 0.21266884374199435, 0.11115884190076031, 0.1650652356329374, 0.1119315586402081, 0.15374178386991844, 0.12319661080255173, 0.15131132444366813, 0.12087440103641711, 0.12486220541177318, 0.13116905058268458, 0.1163924673164729, 0.17039514728821814, 0.09048270410858095, 0.058344032368040644, 0.11077921852120198, 0.11820007930509746, 0.14987900911364704, 0.17643324594246224, 0.16977279708953574, 0.11357943818438798, 0.09781885615666397, 0.20853588270256296, 0.2548435080097988, 0.14915679552359506, 0.0946533217211254, 0.15436986344866455, 0.12226229882799089, 0.166292718204204, 0.1644542402937077, 0.11285686094197445, 0.1536500544170849, 0.22582501434953883, 0.18111146287992597, 0.18995750695466995, 0.13206770236138254, 0.19053409632761031, 0.12688179704127833, 0.20000206015538424, 0.2042799032642506, 0.14251629560021684, 0.20623265707399696, 0.1341601728927344, 0.2576356159988791, 0.11983180971583351, 0.10348937648814172, 0.12943102978169918, 0.1251381656038575, 0.23289742937777191, 0.13209664612077177, 0.15854806581046432, 0.1871694510919042, 0.10743905673734844, 0.11055222523282282, 0.10804830060806125, 0.17830482363933697, 0.0888607997330837, 0.16624700190732256, 0.11501467015477829, 0.06798285714467056, 0.21296331309713423, 0.1283464700100012, 0.14682588778669015, 0.1271767562138848, 0.08344088782905601, 0.06257158383959904, 0.1260351252858527, 0.10637840896379203, 0.1425496774027124], [0.10076386883156374, 0.04203497352136765, 0.03877557966916356, 0.03942678828025237, 0.012827196023863507, 0.09555011813063174, 0.024204537912737578, 0.07553371993708424, 0.003938339305022964, 0.0972018791071605, 0.04167405226326082, 0.06655800782027654, 0.005404207131505245, 0.05342275464499835, 0.04208664926409256, 0.01735489520797273, 0.025284733856096864, 0.02513341180019779, 0.029356029845075682, 0.019378422075533308, 0.0033343329096169327, 0.02264573278807802, 0.008378471557080047, 0.03605931546189822, 0.055696361159789376, 0.02522215225326363, 0.03425120252359193, 0.014508835865854053, 0.0317414483288303, 0.03803949904977344, 0.032567302841925994, 0.050895077583845705, 0.04081838567799423, 0.018395395527477376, 0.04944938133121468, 0.03691332705784589, 0.011360387525201077, 0.03618816343077924, 0.03243342311179731, 0.06789004415622912, 0.014755757674720371, 0.027032755097025074, 0.007690528027524124, 0.00932061133426032, 0.04859647553530522, 0.02432799417874776, 0.04766890226164833, 0.013715672957914649, 0.039738857667543925, 0.03546774954884313, 0.04143615311477333, 0.02645463504450163, 0.09064225843758322, 0.0651353552530054, 0.027935754005739, 0.03040974410396302, 0.015479512148885988, 0.042266093150828965, 0.03682772774482146, 0.03041534360818332, 0.0210143715958111, 0.04574580838379916, 0.05142262583831325, 0.036103625388932414, 0.07344255558564328, 0.027759135846281424, 0.05955217457085382, 0.03382473478268366, 0.033328835415886715, 0.012594831441674614, 0.07935791785712354, 0.029712449977523647, 0.02372156119236024, 0.07508978946134448, 0.03687991185870487, 0.014045513999008108, 0.058237378325429745, 0.011525915215315763, 0.024805694229144137, 0.05053301341831684, 0.01032228898111498, 0.04830870035220869, 0.028436438369681127, 0.029655462312803138, 0.042469189284020104, 0.06140288678579964, 0.039277794712688774, 0.06204333796631545, 0.004731460467155557, 0.01830158435041085, 0.02186825888202293, 0.037287625527824275, 0.06756786300684325, 0.0336410754971439, 0.03466446745733265, 0.04871594275755342, 0.03369380508956965, 0.04742466888274066, 0.02411614255834138, 0.04535151645541191, 0.036432281776797026, 0.021780347778985742, 0.07572192858788185, 0.06510929844807833, 0.019872323209710885, 0.03745978894585278, 0.037855628252145834, 0.06994076888076961, 0.07383618329185992, 0.02483001440850785, 0.0030230989023039, 0.03045940862648422, 0.011703015770763159, 0.04499065085838083, 0.05281837555230595, 0.06472325549111702, 0.008274043957499089, 0.04333217715611681, 0.0062713329407415586, 0.06736751282005571, 0.02871478642191505, 0.020940314534527715, 0.04575123719405383, 0.05445053640869446, 0.0767698856361676, 0.02866723145416472, 0.026671475752664264, 0.049836348262033425, 0.05113770050229505, 0.04697521682828665, 0.02114503597113071, 0.0322397040145006, 0.07989350357092917, 0.0345962455321569, 0.03266309555328917, 0.08458600685116835, 0.03751452604774386, 0.04514570035098586, 0.0277931800155784, 0.032252661912934855, 0.136198659602087, 0.05765266985690687, 0.038617732279817574, 0.059488168044481426, 0.035205786261940375, 0.07225522320368327, 0.033888897160068154, 0.030807026887487154, 0.04251163642038591, 0.04020153850433417, 0.027344509071554057, 0.05274873983580619, 0.034711742264335044, 0.03976554529799614, 0.06729719432769343, 0.002723225088629988, 0.008725577736186096, 0.01144592004493461, 0.03437347877479624, 0.04562271948088892, 0.014033327006472973, 0.0341425855003763, 0.037911883046035655, 0.05420717876404524, 0.03349545499077067, 0.016689513431629166, 0.05511842107807752, 0.05832207221828867, 0.04048992967000231, 0.019568777388485614, 0.01600446103111608, 0.03579912590794265, 0.05058708258729894, 0.020121942725381814, 0.01781621791451471, 0.1404126186389476, 0.04676792013924569, 0.027487474544614088, 0.014562491287506418, 0.040439129661535844, 0.033661414054222405, 0.056536327610956505, 0.044780177777283825, 0.0626560699311085, 0.031138802150962874, 0.04392360948259011, 0.04758543291245587, 0.06680161779513583, 0.01713931058475282, 0.04346563386206981, 0.05426069132226985, 0.02260366229165811, 0.02629236816574121, 0.0318475717358524, 0.052477974677458405, 0.015928281427477486, 0.033507856278447434, 0.033694268931867555, 0.033090921424445696, 0.04080172075191513, 0.019787286073551513, 0.03419036125706043, 0.08749536675168201, 0.07262940664077178, 0.011647797200566856, 0.03942918912798632, 0.04607966351613868, 0.03807425011473242, 0.022367599958670326, 0.04307070739741903, 0.05042857468652073, 0.007927812584966887, 0.05564320112171117, 0.03238469369534869, 0.07724150564172305, 0.05671016457199585, 0.0376982558373129, 0.09292967632063664, 0.01561798206239473, 0.022522558538184967, 0.017866054986370727, 0.03949613084841985, 0.020903602344333194, 0.01118127296649618, 0.045112344523658976, 0.04374806929263286, 0.0070189149937505135, 0.042595617851475254, 0.09918170646415092, 0.03790117014432326, 0.022183092769409996, 0.05382683921197895, 0.04465507765416987, 0.029490150773199275, 0.006210308456502389, 0.043013280010200106, 0.0736675005464349, 0.012886412914667744, 0.06841598937171511, 0.014248330899135908, 0.03268680346081965, 0.02092371454637032, 0.018483403109712526, 0.027969312068307772, 0.040313265126314946, 0.03639256574388128, 0.09436389897018671, 0.05840155252371915, 0.019985649159934837, 0.06453911380958743, 0.059345671979826875, 0.0405393975233892, 0.04359690865385346, 0.027353850855433848, 0.058890048967441544, 0.0912507378961891, 0.061126833825255744, 0.050543600154924206, 0.0731627584900707, 0.015564395289402455, 0.009714543321024394, 0.03323618941067252, 0.07813284726580605, 0.06098339152231347, 0.05710092758818064, 0.07498286824556999, 0.024602288249298, 0.023338089777098503, 0.04841965142986737, 0.015989139392331708, 0.07009020773693919, 0.014030697948328452, 0.05904867190110963, 0.04364555643405765, 0.01734333625790896, 0.029720216552959755, 0.06290446675848216, 0.06979240613873117, 0.03207109919458162, 0.04479381845158059, 0.03088444958848413, 0.02654874864674639, 0.0344314293761272, 0.016929553676163778, 0.06078908983909059, 0.056603462289785966, 0.01616572972125141, 0.013753038238064619, 0.12631916004465893, 0.007364064686044003, 0.015881748768151738, 0.08506069192662835, 0.018618531503307167, 0.02769028680631891, 0.04885571885097306, 0.026788885370478965, 0.01449343722924823, 0.013269133833091473, 0.043008196298615076, 0.017236147868970875, 0.04898204351775348, 0.030850581679260358, 0.05989350313029718, 0.04031403695989866, 0.08647343682241626, 0.012993911150260828, 0.040992400754475966, 0.01712189052341273, 0.06643901186180301, 0.009476859395363135, 0.09289464695029892, 0.022630344356002752, 0.007181856299212086, 0.060004068291164, 0.010176388313993812, 0.02019285864662379, 0.037125095186638646, 0.06634119679802097, 0.03292478053481318, 0.09731320868013427, 0.024829012509144377, 0.030444610201811884, 0.027393746859161183, 0.0474982491141418, 0.008203059387597023, 0.02946705699287122, 0.02158716117264703, 0.02120932265825104, 0.023246286109497305, 0.047890874920994975, 0.025211508000211325, 0.020838285927311517, 0.0010041174573416356, 0.021947553650534246, 0.026632446206349414, 0.0642194040119648, 0.018947284370369744, 0.038254399041761644, 0.03069920581765473, 0.030659692019980866, 0.012104179058951559, 0.005650279181281803, 0.10502876146347262, 0.01715013295324752, 0.07989141071448103, 0.027124996631755494, 0.06471546294051223, 0.03749317074834835, 0.1315661589615047, 0.021531648526433855, 0.03902928285242524, 0.029283108269737568, 0.18374828388914466, 0.22906609199708328, 0.11597954377066344, 0.098767335730372, 0.10094053708598949, 0.300764370476827, 0.22601490025408566, 0.2406468612025492, 0.11120199778815731, 0.19633208052255213, 0.10381279702414759, 0.10024698523920961, 0.20344693155493587, 0.12654024583753198, 0.13587791821919382, 0.1365865208208561, 0.20400373527081683, 0.1812300135497935, 0.1212824041431304, 0.14321495342301205, 0.1910076310741715, 0.12930625991430134, 0.16438202932476997, 0.15201562258880585, 0.1525701256468892, 0.10866791970329359, 0.10908491763984784, 0.12308307705097832, 0.13458411733154207, 0.10915115431998856, 0.07256029784912243, 0.1776025292929262, 0.1062366587575525, 0.1427372478065081, 0.13140402938006446, 0.132526260567829, 0.25159106065984815, 0.13801882130792364, 0.1524193212389946, 0.1927095538121648, 0.0977421626157593, 0.1985411869827658, 0.1737079312442802, 0.09262690233299509, 0.20690200006356463, 0.09792325407033786, 0.20893756271107122, 0.09797093705856241, 0.10927296301815659, 0.24906820384785533, 0.10617319770972244, 0.2239875606028363, 0.2166891170782037, 0.22529470530571416, 0.17468081263359636, 0.12773796828696504, 0.13639283512020484, 0.09148742363322526, 0.12278042180696502, 0.11382318916730583, 0.12871212617028505, 0.13422424992313609, 0.23111813032301143, 0.10794385816552676, 0.1391673690523021, 0.17871331656351686, 0.13410100887995213, 0.1894107964471914, 0.05650717233947944, 0.14732763898791745, 0.15679085307056084, 0.32568568945862353, 0.10929554657195695, 0.16317310044541955, 0.3297517681494355, 0.197412766283378, 0.16136886522872373, 0.2521934767719358, 0.15874172182520851, 0.25192713481374085, 0.1794403837993741, 0.12872989318566397, 0.10497360504814424, 0.17475302360253409, 0.1050619428860955, 0.1547253373428248, 0.16530264867469668, 0.21031004609540105, 0.15105664904695004, 0.18293226283276454, 0.15832038974622265, 0.18304661294678226, 0.28936343849636614, 0.17646582622546703, 0.1328926588757895, 0.18783039296977222, 0.15267893933923915, 0.11668384933727793, 0.13978122908156365, 0.1748750326805748, 0.2117604698287323, 0.1527150225592777, 0.09807038484723307, 0.11771440302254632, 0.16769635694799945, 0.06777072907425463, 0.08316322811879218, 0.14691494550788775, 0.1477691574837081, 0.1577856723451987, 0.13013687159400433, 0.10337198356864974, 0.19489201717078686, 0.13831495307385921, 0.1725488598458469, 0.20034383400343359, 0.09779069907381199, 0.17603502434212714, 0.15865647874306887, 0.15457117842743173, 0.13586176908574998, 0.09073192471987568, 0.19231020414736122, 0.118228154751705, 0.16125893831485882, 0.14160885679302737, 0.18433606484904885, 0.165193953725975, 0.17136448121163994, 0.13096271868562326, 0.1071059363312088, 0.13366624392801896, 0.09101777031901293, 0.17524956492707133, 0.2977794228354469, 0.14052570710191503, 0.10585974421701394, 0.13166700198780745, 0.12618864595424384, 0.09745903327711858, 0.17665830964688212, 0.12395921206916682, 0.11112004242022522, 0.2055298729101196, 0.11696225861669518, 0.18905585689935833, 0.14229804481146857, 0.22384255978977308, 0.10071515425806865, 0.09009465735289268, 0.11207839255803265, 0.12309077312238514, 0.1036450790707022, 0.13042387494351715, 0.11376078939065337, 0.11645302656688727, 0.1067497648182325, 0.11531612311955541, 0.10247933576465584, 0.17992846464039758, 0.08774682864896022, 0.09154890314675868, 0.15519465669058263, 0.07243363550514914, 0.0638202992558945, 0.055545144859934226, 0.18431374104693532, 0.1510945727932267, 0.10871705730096437, 0.12879897229140624, 0.1245441209175624, 0.21888643823331222, 0.27515131048858166, 0.11877326964167878, 0.18074469349812716, 0.23553711507702246], [0.025103866901190486, 0.04334918347012717, 0.02966719195683254, 0.03719174746947829, 0.036138728974037804, 0.07532491668825969, 0.07953775508212857, 0.026312903391954023, 0.033837106384453364, 0.09540841987472959, 0.017259236083191354, 0.02206296874646796, 0.08766038328758441, 0.057697514130268246, 0.041490905059617944, 0.05696184540283866, 0.05381765513448045, 0.06883700232720003, 0.041281059093307704, 0.030905600797268562, 0.04867273863055743, 0.02780449591227807, 0.030628061686002184, 0.023577983447466977, 0.037499100508284755, 0.07081724528688937, 0.011938741354242666, 0.0341029251285363, 0.037866266939090565, 0.02705378385144286, 0.015361637761088787, 0.0443961720156949, 0.03494001575745642, 0.07565641921246424, 0.03069238919124473, 0.03221638944523875, 0.07177317602327093, 0.009251528517779661, 0.03263664541009348, 0.008638200979476096, 0.04462949211301748, 0.020349247715785168, 0.06688933965051547, 0.029030295663687866, 0.07354509813012555, 0.03414358739973977, 0.07174931597546674, 0.07666111647267826, 0.08051177937886678, 0.1195658536744304, 0.02177325099182781, 0.04650447255698964, 0.04692346316005569, 0.046382237123907544, 0.03835323826933745, 0.022839229241071735, 0.052475184202194214, 0.022094211308285594, 0.012017048138659447, 0.09338362579001114, 0.1031665199843701, 0.05952195431746077, 0.12454753479687497, 0.03313815912406426, 0.007636444479430793, 0.041604193902458064, 0.07152912075980566, 0.05864863946044352, 0.042265451193088666, 0.04383119725389406, 0.05493099168234039, 0.00513026372573222, 0.03729476498847362, 0.008635824251541635, 0.0615232482959982, 0.059731291912612505, 0.009018147193273762, 0.08616245468147099, 0.05089757491077762, 0.04892259748885408, 0.01973548231035238, 0.06476339083747007, 0.08258746252977289, 0.038867194089107215, 0.013142842562956503, 0.021431304594443645, 0.031067363015608862, 0.0537103034730535, 0.020501298931776546, 0.04701963065599557, 0.024977670254884288, 0.022480909210571554, 0.05676646760548465, 0.06402695769793354, 0.0342707506933948, 0.0715440305066295, 0.09466719988267869, 0.01811746678868076, 0.04565720708342269, 0.0419052906363504, 0.02559316486440366, 0.021187765123613644, 0.051432017717161216, 0.048717634854256175, 0.01271824874493177, 0.020119799773965497, 0.0464333933632588, 0.0192516075912863, 0.009474629241594812, 0.08175632392521948, 0.02372238683165051, 0.0464266212657094, 0.07849395406083204, 0.016276571332127787, 0.04541354515822604, 0.041402864080737345, 0.008482359244226245, 0.008645453617646126, 0.05371898660087027, 0.047594939824193716, 0.07800671926815994, 0.032053766335593536, 0.026679784095904324, 0.015274055058398517, 0.03316478738270234, 0.05056272158981301, 0.06105504588049371, 0.04276373656466603, 0.03845263410767075, 0.029317061525944155, 0.0802183490304742, 0.0187229424045654, 0.04335822282882873, 0.0657525920541957, 0.01154382509412244, 0.03412353456951678, 0.03994088510808069, 0.039536551921628416, 0.09650784486439079, 0.022046333506295923, 0.010585626168904128, 0.04735916692879982, 0.09741035581100732, 0.04246307027642615, 0.029576859597000293, 0.021240821261017118, 0.03153634839691222, 0.0250503487768583, 0.06226803801837377, 0.05087071287562139, 0.038560445900657214, 0.06352398195303977, 0.01608013411896536, 0.05184532346902415, 0.04529730256763287, 0.018710826843744144, 0.04221381626848597, 0.03363422176335007, 0.04626521527825389, 0.00929705185626517, 0.01802668542950414, 0.057610411968198605, 0.04290889322874136, 0.07212152529973537, 0.023262915783561766, 0.011525071022333577, 0.043949024329776876, 0.057755512971198186, 0.039487952381023206, 0.06981360929785296, 0.0683432440564502, 0.034145691388403066, 0.046688721849932335, 0.05990141442453023, 0.02991654986544745, 0.08687950292369351, 0.03316180023830384, 0.01381484800731414, 0.048192606191150844, 0.0034420076372043695, 0.028306963286013342, 0.014929163262422662, 0.0532665140053723, 0.021289899486873765, 0.029311449034139514, 0.046143083745846525, 0.06248798090382479, 0.003884726324940857, 0.0865872971189674, 0.08497301460010931, 0.03372997365659103, 0.03371473736478947, 0.010567145764071029, 0.06442770260036923, 0.05080463204649277, 0.03393681392481085, 0.01713117479084758, 0.05456226303067524, 0.09810051604290493, 0.07015143492026255, 0.04103780534933321, 0.029614581108035054, 0.042245242511853576, 0.03844594364636578, 0.03775576115003787, 0.011323954568069894, 0.02967258737044176, 0.043103387870360166, 0.05350871018890757, 0.036541255030897446, 0.06755099399015307, 0.008824500455375528, 0.019840997156279627, 0.03337379472213797, 0.04983045560948085, 0.049245899281231686, 0.023786241217749193, 0.12318736364250071, 0.012302403920330107, 0.029342366906348616, 0.04843519942369312, 0.042098260164493695, 0.04094038733455818, 0.035440534993540496, 0.053584591078106314, 0.09907931977068074, 0.019177097819920164, 0.05386858501879033, 0.04675500305893365, 0.039218797683133744, 0.04995080969820265, 0.04082428204128519, 0.04648100213671569, 0.07639914576429874, 0.006280296229306259, 0.016550125110370573, 0.08956178789958358, 0.037294523790478706, 0.09272637238609605, 0.037995634411345236, 0.0412836714531295, 0.04539202287560329, 0.030554678123735357, 0.008169044904207112, 0.01857652223407058, 0.043198453277000226, 0.051787628908641636, 0.037137912077014334, 0.0705248984741047, 0.029520755088014994, 0.0225287257853779, 0.05630524508887902, 0.05276363102893811, 0.09852549206698313, 0.041782116386457346, 0.05053181484981906, 0.01583088938787114, 0.08881625602953136, 0.04684189370891545, 0.06595212587853894, 0.0607968564145267, 0.04187970138445962, 0.045390527448034845, 0.03981652713264339, 0.04357340112619568, 0.01940086091053672, 0.04425847022503149, 0.08386960427742451, 0.01035878687616787, 0.01340498489298625, 0.035113967751385644, 0.03879723182762973, 0.014560009731212631, 0.052099034073762596, 0.019600288978836033, 0.02523409897548845, 0.0642913107003551, 0.02969864788610721, 0.011024638060916914, 0.03331038562464528, 0.06248098245123401, 0.02639965488924645, 0.03661244554677978, 0.07312757326872088, 0.03466772548563313, 0.04015341022750363, 0.04124195904296357, 0.017362851031066384, 0.003925864730263129, 0.02368948556977557, 0.036585000925697386, 0.032723855183576234, 0.04355632801889442, 0.041902737648342736, 0.01140214075348922, 0.03812168077274691, 0.05446257404400967, 0.038846755342092365, 0.04015840859210584, 0.023025632617645897, 0.048175518240896054, 0.027566058706725016, 0.07013645838014781, 0.05212006653891876, 0.0449403072707355, 0.02731177293753717, 0.048720777849666774, 0.012314257874095347, 0.05755299571319483, 0.0493413506046636, 0.06027572773746215, 0.046198592681321315, 0.03331070103740785, 0.01840585424361052, 0.0337898241559742, 0.026804260814969894, 0.012547584465210093, 0.07246968903928064, 0.04525304459093604, 0.01513170835096389, 0.055476151101174764, 0.017832441262726206, 0.06775883986847475, 0.04026773436635267, 0.05986655945889652, 0.02684450377273606, 0.0462890716153197, 0.051023387495661154, 0.038157222224981524, 0.02272734862344805, 0.014126585283520399, 0.09404793701833114, 0.013904649731557583, 0.022082667201175354, 0.09673857115558349, 0.026106539953616448, 0.0493569542595651, 0.03253901959396899, 0.04156846691330429, 0.05119143570482265, 0.04911311792966444, 0.026012828966486268, 0.015359197022917215, 0.09005711952340789, 0.013351674570003524, 0.07404498654068448, 0.013297879067977192, 0.022726997958670836, 0.024392807790718507, 0.014618646819144487, 0.01631979401281569, 0.035597833193605766, 0.1734647442935966, 0.13303393410751596, 0.12982766318600625, 0.24314467795193195, 0.09694465814391151, 0.19589439150877297, 0.13375525712035596, 0.1591622969135642, 0.10000012465752661, 0.156869787897449, 0.13465775322401896, 0.17977593844989315, 0.28537869919091463, 0.22223275242140517, 0.12892733415355906, 0.13107277918606997, 0.12389995157718658, 0.2332000178284943, 0.14924497751053423, 0.06461291297455318, 0.18697054067160934, 0.1657022358267568, 0.17501216672826558, 0.1919813733547926, 0.12534930661786348, 0.14273525885073468, 0.10014732964918949, 0.12258624628884718, 0.1561936765210703, 0.11512048557051457, 0.05464189176564105, 0.20348062505945563, 0.16448584094177932, 0.14874640270136297, 0.1314456935506314, 0.1780791810597293, 0.12440096063073725, 0.21906664653215557, 0.1953266336931847, 0.1338775482145138, 0.1723611113266088, 0.16558833100134507, 0.15054529445478693, 0.14512555324472487, 0.14765669242478907, 0.21115827636094764, 0.23980979283805937, 0.2229617492412217, 0.22332204709528014, 0.1282735465792939, 0.1126588114129845, 0.21352966083213687, 0.1372758424258791, 0.09916045135469176, 0.2148550475249067, 0.07155583065468818, 0.147815972159151, 0.15070746856508777, 0.10338874868466519, 0.16080701490864158, 0.15027755725895986, 0.15537544386461377, 0.2972916536964476, 0.14201438112650067, 0.08331219942192547, 0.146995052928105, 0.14984492969233543, 0.1617059635464102, 0.11964098870521411, 0.15448353078681976, 0.18537980649853125, 0.10640786480507813, 0.1796178164659068, 0.0660574811627157, 0.11811888834927231, 0.15037025150377303, 0.16247227555140853, 0.2154760470148176, 0.0991847195837181, 0.24544683488784358, 0.11671581363771111, 0.17338825855404139, 0.16400988679379225, 0.11114487468148582, 0.1421422531711869, 0.09809559560380876, 0.11252414871705696, 0.20079667767276987, 0.0671172457805369, 0.11004547195625491, 0.08013599290279672, 0.16158886748598889, 0.09575714764650911, 0.1324611296877265, 0.16981447610305622, 0.1907344168284908, 0.14902504946803674, 0.0992269032576587, 0.18568380502983928, 0.15221833280520514, 0.2469977008877322, 0.15190861973678693, 0.15196965396171436, 0.16242986923316494, 0.14683940971735865, 0.12996751349419355, 0.13001472892938182, 0.14863680233247578, 0.13963005359983072, 0.19080217491136864, 0.15289868926629424, 0.19438440300291404, 0.2637118462007493, 0.13170066580642015, 0.07708120174356736, 0.15564521454507485, 0.10284064293955453, 0.1581135086598806, 0.1748817862244323, 0.185066694393754, 0.12365174770820886, 0.10454827279318124, 0.12788485415512696, 0.1209678225859534, 0.14124275534413755, 0.11906580941285938, 0.22999926848569885, 0.1274523008032702, 0.16802757745608687, 0.17507844051579013, 0.2391845334204845, 0.07664303033379838, 0.17512915888801217, 0.1005967817036435, 0.11385531674022786, 0.08706230873940513, 0.16743699117796496, 0.11188835080247372, 0.18927225231891498, 0.11500760490889661, 0.1507423198199831, 0.12081140754162334, 0.2357219098485075, 0.12820329488022253, 0.13286343310028315, 0.09669528910308145, 0.21484162949491292, 0.11815046673291363, 0.09587254418875091, 0.12044258241076022, 0.14682898996397853, 0.16264445381239057, 0.11884280145750381, 0.15863124572206289, 0.17244580521946773, 0.18900313472840935, 0.1326844864524901, 0.0943530784570612, 0.19093228824203834, 0.12086153219570406, 0.11557114732568152, 0.1917570666410029, 0.16875574307050556, 0.17756689136149362, 0.09707901655929163, 0.08929817704483867, 0.10001426257076673, 0.1143350632628426, 0.1490449538687244, 0.26012451213318855, 0.18129958247300237, 0.0773177390510682, 0.120292401406914, 0.14360980567289516, 0.09013054019305855, 0.24033627239987254], [0.015042909453768516, 0.02814169998600846, 0.019081158534390852, 0.06720099714584649, 0.019503420153341722, 0.030035056006454397, 0.020851501722063404, 0.027844941105286125, 0.06772365464712493, 0.03186029956850689, 0.02135906022886047, 0.058718085929285735, 0.00482894434753689, 0.03431361343245953, 0.032172955252463, 0.03135165752610192, 0.0424004033266101, 0.04245349657139741, 0.010254722928948468, 0.012446344389900332, 0.0039003130495984806, 0.006034451462255674, 0.044855861997348256, 0.04402347287395969, 0.0719567239866592, 0.01814693932828959, 0.0452807638066588, 0.014437098943744786, 0.026403859155834652, 0.03647640245617367, 0.041475883990642615, 0.022381624694389757, 0.05685320982593112, 0.01853952246165136, 0.015794898936292157, 0.02060379323665984, 0.06338061386486515, 0.05823134837555699, 0.021162572920729872, 0.018991982069564983, 0.04449328946066089, 0.015218355947581585, 0.027699385536834598, 0.0364474475645693, 0.08113683099509217, 0.02130644195858622, 0.029760416837234516, 0.023009999276837334, 0.01822401136450935, 0.002338892318221042, 0.09368327533593401, 0.01044844759235275, 0.04673450122936629, 0.022247548295126762, 0.040653554679010995, 0.07129278383217752, 0.06868239070172422, 0.01672558737482177, 0.016781443264335394, 0.015167542951530777, 0.03385204210644588, 0.03859749391267542, 0.041428765034652315, 0.026096877190866508, 0.0470556099753594, 0.04491531173698604, 0.005767386837760569, 0.060333967776387, 0.034264924834133126, 0.04843641283514444, 0.011481026413093787, 0.04471122483664658, 0.026877651798713487, 0.01782203820766881, 0.017712578846840188, 0.05809927577502094, 0.0440230053209234, 0.010856591707124608, 0.02102325695886975, 0.06277511041844264, 0.0725358069757931, 0.030180901012499817, 0.008682958050485468, 0.01719500134640839, 0.048404359476990066, 0.05671639119100291, 0.0564651074091671, 0.07746935982140712, 0.018023243719653692, 0.038550979807041585, 0.057020341482711956, 0.045787324124830775, 0.023145370723796077, 0.01328819218542776, 0.0404445176536683, 0.05161905377462972, 0.014686875238112407, 0.05144763992575463, 0.04305537833715789, 0.05310389831720386, 0.0739896965387743, 0.025158223652397282, 0.046904660848667845, 0.029403362168523017, 0.06883961468702182, 0.05465733214805368, 0.05391358143242542, 0.04234432664816268, 0.033157722136820666, 0.008079386971076019, 0.09345144324470311, 0.03153264136926737, 0.011390037252567708, 0.04792787840415258, 0.05433501741208602, 0.026745825962279923, 0.017670332090347074, 0.10040270266472362, 0.033129353541880846, 0.027540020455489866, 0.041458488049102016, 0.03679615678265691, 0.015213683200272499, 0.03563200909411535, 0.02655683991179103, 0.04720503027783707, 0.053210125624900684, 0.033817472867667675, 0.00543829582966282, 0.0717571827408392, 0.012019635450997157, 0.036928927002009004, 0.012187714273750316, 0.031369201897177845, 0.06952620518859476, 0.016877460475370754, 0.0314216420520097, 0.0331285446009133, 0.03339773269544821, 0.013257830923976144, 0.008347796738235047, 0.03702779591549188, 0.028951125204912387, 0.07840313744964078, 0.025712296264828183, 0.12263914657523856, 0.03414783990592696, 0.046634430036647245, 0.014063961934880354, 0.03950459504267201, 0.016168225192814134, 0.07063929311698303, 0.025333240628242493, 0.024463886984449346, 0.012017168737656903, 0.03970427358581219, 0.03477339618257247, 0.0184961569175357, 0.021590530523099005, 0.05555011724936776, 0.01670091467531165, 0.06722366233589128, 0.07622424382134341, 0.06336316597298719, 0.03796796714595985, 0.016481619313708507, 0.0733648675668519, 0.03244905645260587, 0.04144218677538447, 0.05644401928293519, 0.020972917081962805, 0.04565449453366455, 0.05324630161339883, 0.04862807247263845, 0.03795484226429835, 0.07564019586425275, 0.07176517567131668, 0.04368943591543939, 0.05815439508296549, 0.02989910753967706, 0.01674705585173797, 0.06811128580011427, 0.016033569918363355, 0.007103779116732767, 0.05656935689330567, 0.05051987369370181, 0.04168475032201968, 0.030714636923221406, 0.05117603614053223, 0.02942183979030233, 0.022100291353126522, 0.01643865638470743, 0.02436796439724276, 0.01010893729471718, 0.02757437261607265, 0.019922954379580915, 0.01921300292451633, 0.01185134789920994, 0.031377005579997785, 0.05738073210522998, 0.023947788213263266, 0.03300729251350276, 0.036062128201592714, 0.02674349376320606, 0.019797653876594268, 0.019773675085161813, 0.03994713770225644, 0.024452068282698747, 0.13610569818411022, 0.013621238376799738, 0.03706642841279972, 0.02876290356653044, 0.04000009736046195, 0.012096944974473445, 0.03513144161843229, 0.04005833368864842, 0.08062273045652546, 0.03617374721216038, 0.033820938697317615, 0.07035051603452303, 0.024205498993978836, 0.01911876315716654, 0.09304469436756335, 0.030759245564695448, 0.10034437727881595, 0.026312617665098514, 0.08958259772043675, 0.0187304900464369, 0.06009493314195424, 0.015769400597491767, 0.010483874939382076, 0.06416821808670647, 0.025235368048015516, 0.05331917309376877, 0.015650621717213653, 0.022668461060675327, 0.035930100129917264, 0.05137608204677235, 0.09858601421001367, 0.044120159873273224, 0.010623067519190954, 0.03640834751422517, 0.05373448264435865, 0.023411310066876467, 0.07182600209489465, 0.005858852828168892, 0.017383373269694857, 0.032909833680605516, 0.0033376612100255443, 0.03576170311134774, 0.03559125034371391, 0.06534686734084971, 0.04689757333835587, 0.033791816822486, 0.07477065853890963, 0.06492248503491282, 0.027999966478091665, 0.007852158978494117, 0.0874572574684862, 0.05388134624809027, 0.02337073314265581, 0.048668345116311684, 0.022327327314997092, 0.026011519075836986, 0.021042055559519213, 0.045129866630304605, 0.051771275684586726, 0.031086300768947694, 0.025889632452162914, 0.023154079826781526, 0.020325291188783012, 0.012104770921723684, 0.06259059024159797, 0.06271421720157377, 0.027384765016904566, 0.02929176171164727, 0.023108142740966287, 0.008489084957545856, 0.042261480703018606, 0.09856817297986709, 0.023776274174451828, 0.045338450945564546, 0.062065194215392694, 0.0778581116173882, 0.013735911325056804, 0.017560774394951295, 0.053739514405606315, 0.02004241232498316, 0.010620765933708753, 0.03788536982028745, 0.03353068845171947, 0.0268148382747313, 0.035188894980819896, 0.05473374367284123, 0.05792479314550292, 0.059546370976022445, 0.021162802986509632, 0.0588159603648819, 0.01716021874017315, 0.026365749872638844, 0.013885479129385203, 0.026380988019809593, 0.021343482549127657, 0.033981442975346, 0.018705012116697617, 0.09026990068377927, 0.046470074012177065, 0.02783209267363418, 0.04781705720233731, 0.031235763744916767, 0.029298608023964334, 0.02303840683453018, 0.06495683162938803, 0.01984365218959283, 0.05991173027723562, 0.0266202768398216, 0.061961237879586406, 0.05263778875814751, 0.027359804735169746, 0.03594351073843427, 0.05775386169261765, 0.08794282985036261, 0.058393574436195195, 0.012968525988981128, 0.08101477738819085, 0.020637139787140768, 0.03529517794959247, 0.035321242175996304, 0.025227022597391624, 0.022438061314460356, 0.02426032515359111, 0.11558230180526152, 0.04032256423670333, 0.02632010779052507, 0.018180903716711327, 0.072506922588218, 0.02655910160683561, 0.027679334561980795, 0.0444389085896546, 0.014210965618985938, 0.021280596665746998, 0.04225345066515729, 0.02636052329762606, 0.047070623622857966, 0.07278230390511453, 0.06777112983400002, 0.0945888068235945, 0.009447322845517192, 0.11754629915230907, 0.05726376592065208, 0.03818768367636949, 0.06803751632105559, 0.13230728247435763, 0.13101039425237104, 0.09061168195330538, 0.07424763738526963, 0.09857152006588876, 0.25003884395118803, 0.09005720115965232, 0.08779030365985818, 0.1672697110916488, 0.1328095977078192, 0.1389167457818985, 0.1192693730990868, 0.13064316473901272, 0.09966488170903176, 0.14061051973840222, 0.15610478207236156, 0.1595329403062351, 0.08084695553407073, 0.1439291815040633, 0.08221275958931074, 0.10667862254194915, 0.09897974581690505, 0.1361432805424556, 0.15838106774026528, 0.21915031626122072, 0.1172368903644383, 0.18537394353188574, 0.10757409792859107, 0.15772066020872444, 0.18378726148512214, 0.14854571112664416, 0.19911771698389202, 0.17731971165630966, 0.10910793163930066, 0.20456807920709252, 0.21774148248368874, 0.17673889204161242, 0.10902714886469766, 0.12310910416999832, 0.11445520212873816, 0.15580394509015605, 0.14501182653475553, 0.10762846024590544, 0.16031439212383702, 0.16783271916210651, 0.1612490974366665, 0.1643545104889199, 0.09664152792538516, 0.1369345435523428, 0.11314203118672594, 0.22486682748422027, 0.1014271930034738, 0.17565036920132115, 0.10783807243569754, 0.11245921079535037, 0.18132074852474034, 0.11324536040774547, 0.09085426034289412, 0.0625424248573836, 0.10063021545647644, 0.12530219508334994, 0.16704999085050076, 0.14947128802305087, 0.12704981927527115, 0.21483358461409807, 0.12421159422956407, 0.10305533141945489, 0.09074506073375233, 0.1793773309327662, 0.17465326411183923, 0.10953660355880857, 0.0978761276928708, 0.07061777083436027, 0.16815142706036568, 0.09280578218749724, 0.20447596383746713, 0.20348127814941108, 0.16200635524000973, 0.202693221217487, 0.18064388015773147, 0.13935284659964964, 0.17848942545242608, 0.2213182780542411, 0.16633291292237118, 0.12681535998126492, 0.1665068426518701, 0.13087572413496673, 0.20990462566260248, 0.17013572214636952, 0.15153013926465064, 0.12725975801004097, 0.06713850088999607, 0.12694513192400336, 0.060459657906903885, 0.13777226500678807, 0.22859807882923633, 0.124513974878937, 0.1643817769945599, 0.1605940778972581, 0.13835103629389778, 0.1467590796528384, 0.2366460469784215, 0.12313873070525005, 0.16971189645119011, 0.17833900696132332, 0.1401822263142094, 0.17508605495095253, 0.1890852756332606, 0.049945848440984264, 0.15484255214687437, 0.22831006615888327, 0.161336982564535, 0.10056181912659667, 0.08668087451951578, 0.10855943997739814, 0.13522110268240795, 0.10509756597457454, 0.09142229275312275, 0.13971897773444653, 0.09106459241593257, 0.1330163303646259, 0.16705315239960328, 0.1462156345951371, 0.14974790130509064, 0.16346825257642195, 0.10822448646649718, 0.21792874118546024, 0.08518973656464368, 0.20632052735891193, 0.17612515075597912, 0.1440612244186923, 0.10132442781468853, 0.10276414235704578, 0.1269836790743284, 0.10596496591460891, 0.2146445744438097, 0.1456507563125342, 0.13119045412167907, 0.1837222493486479, 0.12400621228152886, 0.10999261619872414, 0.0952281076752115, 0.1860478284652345, 0.18173523800214753, 0.20445024099899456, 0.1896056844270788, 0.16833868576213717, 0.13240607717307284, 0.13615275034680963, 0.08077718623098917, 0.09619052478228696, 0.11572404459002428, 0.09747163494466804, 0.15657503652619198, 0.08273723535239697, 0.18050861632218584, 0.14394994679605588, 0.16515436756890267, 0.08759434698731638, 0.20637002860894427, 0.06307599192950875, 0.1321544891106896, 0.13095369416987523, 0.0817342079244554, 0.16465806373162195, 0.1339341443963349, 0.19150862528476864, 0.1135575225634966, 0.15817846142454073, 0.10939048952423036, 0.18751144758425653, 0.07488744289730676, 0.20871791668469086, 0.2057523390976712, 0.1407622147235088, 0.1588725030887872], [0.0598565590189537, 0.025810256047407165, 0.05909638086450286, 0.03772741853026673, 0.08852079219650477, 0.02227257351478329, 0.04267296077159699, 0.029002099618082866, 0.01744689554470824, 0.026922631514025852, 0.033295694811386056, 0.004897119888482848, 0.03340051574923564, 0.057042201442527585, 0.057654465854284354, 0.056739861611276865, 0.02183779186452739, 0.09075122798094526, 0.02468633647367824, 0.011300022160867229, 0.0763544462097343, 0.06824374431744218, 0.0527298150700517, 0.01751402836816851, 0.023723769081698265, 0.04156896786298603, 0.029834570377715863, 0.03381200695002917, 0.04369181449874304, 0.02363044401135994, 0.04779329363373108, 0.049961685872403905, 0.037262618861859664, 0.05393461760831997, 0.052655700492323376, 0.06929810610017739, 0.02024999474087963, 0.03134049562504515, 0.016930971178226173, 0.033661484558251686, 0.053366830106824636, 0.021525071242649574, 0.05471974305692129, 0.04087762390554417, 0.03559366974513978, 0.013210134020482656, 0.03434625679801684, 0.03645854267233517, 0.04899355422821827, 0.04970729991327971, 0.03706242081534583, 0.04082020393980201, 0.09849709749687463, 0.03513851799652912, 0.04848389173275791, 0.022422830588766374, 0.013609944744530367, 0.03887483449943829, 0.031236969734891318, 0.04410502006066963, 0.0339763295778539, 0.0190790897977422, 0.04530995989625808, 0.06939422906725667, 0.019563522982934956, 0.05852665635757148, 0.045864474086556584, 0.05872534784430172, 0.009273131508962251, 0.04014512785943225, 0.09156219501164742, 0.07092155414284207, 0.010745402214524802, 0.015031865368655417, 0.055215067259268835, 0.009925769682013197, 0.02620588755235076, 0.029243063836474903, 0.030609302048105747, 0.012477323489292758, 0.0428051966446219, 0.11805118221673183, 0.034039701567962766, 0.044188660103827715, 0.02452988803270273, 0.07312591827940196, 0.015692846209276468, 0.05018760304665193, 0.07184727204730734, 0.030905957028153352, 0.005514640561159467, 0.020984797010896727, 0.04684848026954569, 0.029637396582984366, 0.04927452762785833, 0.01931966809934238, 0.021872926990909036, 0.056272683359566145, 0.030949038700782694, 0.058892082452075556, 0.056200008548330516, 0.0451362639432773, 0.004398503333504777, 0.054079748297226615, 0.027736151532735676, 0.03602494289225433, 0.029187853615439963, 0.0321399333915906, 0.03873911053233314, 0.059789669248857535, 0.03145981070701964, 0.0453512975218473, 0.03815830947132781, 0.05753240853664465, 0.03533607399731409, 0.036562024033628404, 0.02882163713366026, 0.0194266932157916, 0.04433071087987628, 0.062385965284192935, 0.03813289833487943, 0.012525773672678042, 0.004833101302210707, 0.09507516588200815, 0.028640302625717595, 0.02940600421425188, 0.01717861287033884, 0.03451856864558067, 0.029166568820073735, 0.036830477401963435, 0.043223882967140526, 0.028130144746683072, 0.0030730278149349033, 0.027823869677376933, 0.047812359407544136, 0.05810437061882112, 0.0205705821281299, 0.007603702779306332, 0.06023987829394173, 0.02527462023863336, 0.010424063402751926, 0.008915432099456666, 0.07017785537755117, 0.028022186379530467, 0.04759846873639617, 0.07244060427183285, 0.013651457702508196, 0.014051154321350623, 0.08720115714822896, 0.021725601400248706, 0.0595171452005161, 0.038988743035588413, 0.022711871133651584, 0.03077416644373443, 0.019675535331771243, 0.026073592307511717, 0.02538746008212911, 0.04833355858863797, 0.0031479919198318385, 0.03411884048546199, 0.018219068660982884, 0.042784256947925314, 0.0719852744077798, 0.08050363801885396, 0.018799535755533725, 0.004586835830195923, 0.05732959813030902, 0.08024775292142294, 0.04173886773060076, 0.09500233893049881, 0.080336001701653, 0.03495258031762205, 0.06302856869297102, 0.015290014016500209, 0.016804358929221053, 0.05152222576725762, 0.021880532149225473, 0.04291466342692729, 0.052898193534929305, 0.013918067761551356, 0.015956197312334552, 0.0351026017597178, 0.03148452422465198, 0.07579156430438161, 0.013036724722041981, 0.03112549729848979, 0.06177649505843874, 0.02913664542575134, 0.03129499084025156, 0.07325300364755094, 0.015973919798852876, 0.06607573057408445, 0.005143979078638949, 0.07449732554960065, 0.02458924314851174, 0.05673419902450405, 0.10357381062931381, 0.03925062839698512, 0.015506788859056542, 0.03216212731786072, 0.043104786818730645, 0.052229663197067566, 0.022316794384096283, 0.024244686246674974, 0.02437428935081698, 0.05103487223095726, 0.03490389171929564, 0.045395863489829935, 0.057933409480028786, 0.013846342899341835, 0.01737475879053818, 0.01918661957461154, 0.025646929752838332, 0.08276232736534439, 0.09713390580145642, 0.03852975809422787, 0.047241280481102876, 0.03883615376253147, 0.050737423152895644, 0.02530230976844905, 0.11954910340136848, 0.017080131729017012, 0.04877275416220073, 0.07333369736443274, 0.06909414165420458, 0.018338496920478065, 0.08757269111811183, 0.03510530688799918, 0.06072804448194802, 0.05305389982822817, 0.027385553548811004, 0.035614987937151454, 0.040985250161611475, 0.016063292932813056, 0.039045216763042845, 0.06362121814163402, 0.022295155213214457, 0.046413106756517664, 0.05182671040529385, 0.04810508842638228, 0.05437187246570829, 0.009005712508951547, 0.050108850045944564, 0.033823703197413124, 0.02368338140513515, 0.025108330919465516, 0.07463419242412783, 0.06748424522811547, 0.073260914941784, 0.031768455082783476, 0.0022079821064835414, 0.00931177421080065, 0.0651092613406945, 0.08363864792045206, 0.037038568189018406, 0.0731616304256022, 0.02489965012500761, 0.04496322479099035, 0.016808060390758328, 0.052539988537319005, 0.013778039337921655, 0.04051694013469387, 0.0720693300536368, 0.04242849361617118, 0.09220094667398371, 0.020870211264991667, 0.018201041893917136, 0.013641918321809499, 0.03184638429956976, 0.017460449016653, 0.054883646371308714, 0.03352142644871492, 0.05552028291276656, 0.013833022276230622, 0.05584123580774758, 0.04397299198899418, 0.10112467876751907, 0.021084916443214752, 0.02874286743463017, 0.0410172033298295, 0.06105382875830401, 0.07425664705806412, 0.02207429763075197, 0.06424875595257618, 0.035578255337895826, 0.045716129898210056, 0.016838453193486203, 0.011793768371717306, 0.051223362897871993, 0.03131283949187491, 0.005193803626752924, 0.06273130144109018, 0.031541153803118505, 0.03881600816384889, 0.02954856892756652, 0.061268825229490176, 0.03258677308622282, 0.029723522820859216, 0.025303179936599918, 0.03121572946838569, 0.04888891511654947, 0.017593924276297912, 0.051177301502320915, 0.01521327780210413, 0.05389057485444937, 0.02139991360309068, 0.02351136827201117, 0.04658249454223551, 0.027099054859718308, 0.03411656951357145, 0.055546669973409735, 0.030186901276465505, 0.03691953141242266, 0.045607190040755086, 0.039652260165894404, 0.018756489334919024, 0.03414395476283971, 0.022551535694219638, 0.06742813144228421, 0.03945209180528764, 0.025057848179130815, 0.13449508929625154, 0.03635374770965427, 0.03257673182815779, 0.061865311581641436, 0.038536530191777274, 0.00575997231862857, 0.03659646710730158, 0.06378814941854216, 0.07846748165320605, 0.019177624744770583, 0.03446482231083792, 0.08346556423930451, 0.06948883063159883, 0.03729317679244559, 0.04029934985737782, 0.044976861754548736, 0.049803055517259054, 0.029320191533770412, 0.08680709157488309, 0.039352618041448295, 0.039238538811332546, 0.03379494868568145, 0.018997765255335253, 0.06247445897315629, 0.053475328386412, 0.03957807879487518, 0.06578044485650025, 0.044100192390033044, 0.0007372318759735208, 0.07655333436559886, 0.010640338223311119, 0.1463040243834257, 0.13480742956744507, 0.19999210053356364, 0.15052976872539148, 0.14397728751646355, 0.1287390067591332, 0.1676530748954974, 0.18178496189648286, 0.14290970808360726, 0.11591774513362907, 0.11926384409889579, 0.08023107686312869, 0.1439767234842293, 0.14815157133853063, 0.17579174833372235, 0.12461423903005198, 0.08707808679901063, 0.14065818046219647, 0.14137669815681875, 0.1453753304667771, 0.26433940627612174, 0.15541709319222718, 0.13099319126922637, 0.10950855037663132, 0.10677916128770448, 0.09794890269404277, 0.1472289185039699, 0.11950366912060417, 0.12868174264440313, 0.12544600846013054, 0.11809145114966668, 0.10493276466149837, 0.1399645395576954, 0.16158431069925427, 0.1530527591239661, 0.1787686807801947, 0.1138106023427099, 0.21614216908346862, 0.22302175930235535, 0.1440482516773045, 0.1812341102049686, 0.20328958140453324, 0.12213537673233077, 0.1124668623378966, 0.1979811623459682, 0.11015121315722354, 0.1833973964676261, 0.16460547514725477, 0.1368182193255052, 0.1678076048847288, 0.21962763596093282, 0.10882294693146832, 0.2200941351475194, 0.20152530341874808, 0.16926028474699706, 0.09323856560513377, 0.09511130847386084, 0.1436170787201263, 0.146380539808888, 0.16416597529314458, 0.16251374676357955, 0.1447885439847596, 0.127816591411829, 0.15704475663369521, 0.15019957238109782, 0.11931681117857806, 0.11630558408796787, 0.18429098679916933, 0.14556695299688727, 0.06657340738456696, 0.3258445981191471, 0.15231497527565807, 0.1756676909280941, 0.11720371636329219, 0.22856621100800112, 0.11297438744804822, 0.22037885268218815, 0.12337629959802143, 0.11141012568259612, 0.12348202595603652, 0.10152613613172434, 0.26893644710071385, 0.16419641819084063, 0.11266595087363385, 0.06893793441122398, 0.1973551162518561, 0.2133963562664576, 0.16190319671295583, 0.13876021199394017, 0.14259797637350857, 0.20989233569707721, 0.08987949389847927, 0.1604305233922787, 0.11672934298985638, 0.18847999483114108, 0.1388316066004336, 0.117524405795848, 0.18370938050793484, 0.2190467421314679, 0.1375497691333294, 0.17598285136045888, 0.09411487873876467, 0.18055097811156884, 0.17467527621192858, 0.12286703786230646, 0.19496418361086398, 0.1545838691527024, 0.11544366119778715, 0.17263724963413551, 0.1631492329761386, 0.11589615605771542, 0.11241553540457971, 0.10917712206719443, 0.23342669941484928, 0.15769940509926528, 0.12287273755646311, 0.1520782450097613, 0.20871713000815362, 0.12241466174600646, 0.13913400209276006, 0.12878263019956648, 0.10060574684757739, 0.11388843136955984, 0.12204459722852334, 0.12844113836763427, 0.0965818963595666, 0.1829575255396776, 0.05562684418691788, 0.10823230128153227, 0.10485515085747465, 0.1387992044328712, 0.12927725678309798, 0.07543402723968029, 0.14186979591613635, 0.24963110801763833, 0.1485319813946262, 0.1011808890325483, 0.12623308575712144, 0.1459385166526772, 0.09611248053261079, 0.10499699012143537, 0.14737071323907003, 0.24391625920543447, 0.1234343578107655, 0.23580093373311684, 0.29802272852975875, 0.11405908822780475, 0.14082243258599192, 0.1850412238854915, 0.110776294459356, 0.16203679813770577, 0.14945757313398644, 0.14987111266236752, 0.21331133582862094, 0.11449329656898044, 0.0804352639534045, 0.14271560678025708, 0.1894962918595411, 0.11605143561610021, 0.12942691828357056, 0.20520182879408821, 0.18808302003890276, 0.15202044654870406, 0.23783343873219565, 0.12014757128781639, 0.13001824670936912, 0.11447666503954679, 0.1323738828068599, 0.1476502208970487, 0.2061362669337541, 0.12472079659346491, 0.13216346909757704, 0.14589513069950044, 0.11081961361924186, 0.13551140116760507, 0.15025060245534405], [0.023852743215684313, 0.06817453904659487, 0.029988632813910954, 0.056449043622706085, 0.024404602372669615, 0.03177064441842958, 0.08418558107223362, 0.02356152075662976, 0.07659117647563107, 0.06270904443226755, 0.007841226215532515, 0.02821579786541406, 0.027471108332974836, 0.06489771956694312, 0.06736865572747774, 0.04429627151694149, 0.02218175504822284, 0.0717879892908968, 0.06250638616620563, 0.02778016460069921, 0.041394500076421537, 0.05088773774332367, 0.02887004000513116, 0.044027873809682205, 0.031305076627177186, 0.05105771924718283, 0.013774731214653002, 0.02440441126964288, 0.04637293801351916, 0.021295307888067327, 0.022129168319224846, 0.026380828458059113, 0.03413082245970145, 0.009278234701923793, 0.053601348772645, 0.026986946031684056, 0.08278712994069792, 0.021072583804198075, 0.060525619992404245, 0.08484736157697625, 0.053339997757575475, 0.058084982010768726, 0.042640833198674954, 0.03313370623800438, 0.01934527219418669, 0.02877489667298505, 0.027629438118310645, 0.03688892895297613, 0.0338792603724869, 0.06711831447319128, 0.05619773015496321, 0.020084317693545017, 0.023771563392074313, 0.045170250596129335, 0.03469547809800133, 0.022150041222630534, 0.05547079650568776, 0.05920783289184328, 0.018625262782734353, 0.0643768283771351, 0.05274072835163679, 0.05691340542398393, 0.047424787626368925, 0.06292007412412204, 0.045144164105295204, 0.03048345235583838, 0.03871662716846913, 0.028153249659226276, 0.02900577695982065, 0.04683500657847617, 0.04488614162255544, 0.023649788090551738, 0.024677061483089346, 0.066146739263786, 0.016102788176795002, 0.044113632684457116, 0.12206254978082143, 0.009428553930774797, 0.016891119703359436, 0.024256440010503866, 0.04595213285938371, 0.0032080506844067713, 0.016516643117938656, 0.02470062467182288, 0.012156927205069223, 0.030349559638125356, 0.091070870985277, 0.09609804576030001, 0.006032823839632329, 0.04620370607881341, 0.04132321679207962, 0.05243380204774439, 0.0775485321355518, 0.03491256000415888, 0.047616476949770004, 0.082939381536562, 0.009259397138521308, 0.0419821326067904, 0.005159085958439391, 0.029185270941525232, 0.049086408034781925, 0.037957120657665655, 0.04168440151261166, 0.058000692588393576, 0.057693703201948665, 0.07109107551514171, 0.05584745871601626, 0.026597940050123725, 0.04952732168021612, 0.05157909654371906, 0.03759229199204128, 0.026894763868767768, 0.11347104751621373, 0.06908684634254314, 0.008090367045952007, 0.039376407585223205, 0.03388136807188857, 0.028847534376836848, 0.0432930956594646, 0.04032114302390255, 0.03910724546585698, 0.009330798238806892, 0.056432953861076385, 0.10134243231732398, 0.0272044045777875, 0.03051173745916458, 0.015081939000083366, 0.06531496983370744, 0.02797844234009972, 0.1330984415835701, 0.13437092798994854, 0.03996091938461177, 0.02747466878645355, 0.06355890000122599, 0.0201301787092234, 0.0221299086115323, 0.026198295381618664, 0.0528555014898302, 0.03430417331401259, 0.02679761117178714, 0.048320196219719946, 0.02571304954471998, 0.02294013163918862, 0.05542835308006033, 0.06469131345511414, 0.0207570875500096, 0.07245690183481202, 0.05444015747343656, 0.059373042386141606, 0.013046134226897266, 0.05345688230590895, 0.028107357102271635, 0.06936455800314434, 0.032362358761020005, 0.05488162030815147, 0.024823040075716563, 0.05049759442044888, 0.03262776190240402, 0.05184447370993439, 0.000980482489012502, 0.03796308010350913, 0.03490280818368774, 0.08463721504085697, 0.0673815468326211, 0.06855924613773823, 0.05552532209549099, 0.04802404590009246, 0.014942614689061884, 0.02737836399319349, 0.048257328890031204, 0.05042442608100828, 0.039503719308413565, 0.031819577925489284, 0.017248404437850695, 0.0299109837578726, 0.04442044395545963, 0.0788153633766342, 0.06150324741611257, 0.02939985181001248, 0.020854770882579032, 0.04593629913870245, 0.034568492919788696, 0.050520452568889596, 0.03854406670143362, 0.07372304287855513, 0.09750135795911774, 0.09943471945007332, 0.05280070872686338, 0.06110356749559287, 0.0223077605915023, 0.06588922886294313, 0.03283853926404845, 0.03162130575219635, 0.02115490653523011, 0.0882084370823577, 0.026634453715814743, 0.060719676766893826, 0.059865936054848135, 0.040949582544271834, 0.04456156704691239, 0.010952510583592812, 0.0273053700584569, 0.03814781921391841, 0.01907024339743657, 0.03536095449817367, 0.04596684222633485, 0.02442549568513641, 0.014633664177381434, 0.07021092547802255, 0.07263078703545034, 0.05900786491110921, 0.07087119200150482, 0.05175599115318619, 0.03317035720101558, 0.013574805907410337, 0.07274761592270806, 0.008901681958377594, 0.06633404991589487, 0.11095402398495935, 0.04967554712493438, 0.03485623099550139, 0.036215229556546547, 0.02822104299411876, 0.01890625288069714, 0.0868946204718668, 0.06253921135794371, 0.02080561658658553, 0.013485868785210187, 0.058767431328305975, 0.01280731667065993, 0.07971311715664342, 0.029934264930489007, 0.03018222574610263, 0.03869746120471973, 0.016305123608617578, 0.015942322861519642, 0.06406059925211594, 0.05710515411919914, 0.02987059979204787, 0.012100856092729373, 0.00940962174354354, 0.020045666642545257, 0.05069646402262151, 0.04591894772602245, 0.07204671681392938, 0.01670802816079231, 0.044105862398282625, 0.03932136249204632, 0.037818402124685235, 0.020781854873348493, 0.045891903864685446, 0.020166974391031545, 0.09648307939642109, 0.03108546770818066, 0.03251050256949384, 0.025809246726566926, 0.019933773037337232, 0.03898680231941398, 0.025658572194515727, 0.07986450043972582, 0.02806160926411394, 0.061145873623900115, 0.05467339222377632, 0.08084423185209744, 0.02734247929765843, 0.04031696844322141, 0.03854100163152907, 0.034467757504899055, 0.10977380137774162, 0.0114283274342597, 0.033179593228851445, 0.0122845450641762, 0.0180205200376804, 0.08707608300028369, 0.05359673632483464, 0.03576715047529433, 0.061507266145781614, 0.040088661553454585, 0.07191730852355249, 0.05514554286492057, 0.03827005093626212, 0.06775516623747535, 0.015991111649782397, 0.041708910939632915, 0.02333242719032569, 0.03551924346538726, 0.042713281654869206, 0.027212030145165045, 0.05554743438551668, 0.04300287509977352, 0.01137055865910952, 0.012991844268981367, 0.022937712237762753, 0.02042131767666433, 0.021206105448072776, 0.010134365129488287, 0.06111746792157646, 0.03565167971828487, 0.016049707919592038, 0.09523299100692384, 0.033128767245216295, 0.05688144483428914, 0.022751715187041555, 0.036310810755821876, 0.04964354200637899, 0.13632207876071334, 0.06596809689654037, 0.01706615337752737, 0.08196518654585816, 0.051895911965402775, 0.04784380420460366, 0.04595236663590185, 0.08570535108447075, 0.01927891677041771, 0.022342261181620415, 0.04072606250701938, 0.0075154679143452086, 0.05029000458307564, 0.037950753030600026, 0.055661431979388, 0.034025070126517676, 0.07232689982629381, 0.04839489338337444, 0.021980375131533947, 0.05792147203464992, 0.0266187498709769, 0.04344311710156035, 0.012470557885535527, 0.06686230321065523, 0.06976671298616566, 0.037504046922549605, 0.08779273790423758, 0.08373048869543709, 0.0477809405856533, 0.042171016611973755, 0.0097813802130986, 0.08721851598238572, 0.010112777908943826, 0.0354559605329996, 0.08377141813980415, 0.011819291758001782, 0.03127749099803623, 0.03203519408998545, 0.0479401127086021, 0.03675831096188631, 0.053612707342836075, 0.06224122422281653, 0.06903049506945536, 0.0739125873951707, 0.05294975795550272, 0.038733017499907874, 0.05035899092035834, 0.1343045651447028, 0.17496085463790223, 0.08764434547629207, 0.12170082700322382, 0.18382189009571448, 0.10419972313684411, 0.1738421560730785, 0.1456449378747493, 0.1910408347612247, 0.24602937628515065, 0.16312144696712494, 0.20791406685020775, 0.15707318088971078, 0.10723682891693898, 0.137375408958178, 0.12341912894044071, 0.1288377124001272, 0.11494248145027086, 0.16234790644375607, 0.14552180073224008, 0.11417541987611912, 0.12864255724707618, 0.12547173129860312, 0.1093925155873876, 0.14052152138901874, 0.17273899808060378, 0.05534821226319764, 0.18835237511666492, 0.11854619471705519, 0.1957124614273198, 0.10910517084994353, 0.11484871851280332, 0.18264913349412382, 0.155099498515483, 0.18491551891202107, 0.2332700468832627, 0.2072826327639632, 0.12485215673223138, 0.13808377407258376, 0.1749487131019123, 0.10475028539076447, 0.15113408473553136, 0.18766352848615497, 0.12524037418188527, 0.10676166144548915, 0.15383657097117975, 0.11539718791027553, 0.10150350804906338, 0.148680618731305, 0.23147396044805646, 0.1704110886203125, 0.09643358556786552, 0.1328319957247004, 0.16857347160112113, 0.18442436557961628, 0.08606616844190285, 0.15345397900091484, 0.14333375642308965, 0.11593866627663374, 0.15354777162428945, 0.16710036783479154, 0.22303842793917283, 0.21968426182866096, 0.2873640332836658, 0.15910071349935606, 0.11829543043859303, 0.15933557355310768, 0.13236714410595596, 0.12742484133923426, 0.11345023027388379, 0.10955586229101755, 0.1350457628723234, 0.15476268221391365, 0.16013612825190648, 0.09791783639229834, 0.14600311318645254, 0.2350472382386215, 0.11162113311002031, 0.11696190238581039, 0.1263549760915339, 0.08932758835726418, 0.16424492496298626, 0.14825320104137063, 0.10759939032141119, 0.13398397219134495, 0.23502255440689623, 0.20897887065075338, 0.252752403030172, 0.1317487718188204, 0.19164446799550205, 0.09814703385927714, 0.11613862312515266, 0.17988619190873578, 0.19166171550750732, 0.1948827106389217, 0.1445279610925354, 0.17648135195486248, 0.16380981862312183, 0.11389223116566427, 0.14370689343195409, 0.16537230665562674, 0.23223187134135514, 0.18050929909804836, 0.20164394314633682, 0.1237194835266564, 0.19797961867880076, 0.15474182786419988, 0.17633580195251852, 0.12277686691959389, 0.10484566621016711, 0.12639248423511162, 0.07735241219052114, 0.17624499276280403, 0.15244553389493376, 0.1163816245389171, 0.09392578693223186, 0.07401470691547729, 0.09453612918150611, 0.12496153445681557, 0.08983224135590717, 0.12790550070349127, 0.1118535218120087, 0.14880405273288488, 0.21453460300108418, 0.11622482357779518, 0.14361222507432103, 0.12164506202680059, 0.1999127649469301, 0.16782028076704592, 0.2572969888569787, 0.2510506584076211, 0.09601114768884145, 0.11151987448101863, 0.15752047329442576, 0.20907024387270212, 0.09814082208322361, 0.2330600784625858, 0.1855777669698, 0.11463916569482535, 0.258482881472446, 0.150019601569511, 0.11119718867121264, 0.08632295895949937, 0.09136381893767975, 0.20458722661715, 0.20840477489400655, 0.1066780585097149, 0.18835451250197366, 0.13274856348289177, 0.08155281961080618, 0.14166178676532581, 0.12259804643690586, 0.14633035578299314, 0.12795362155884504, 0.15165148040978238, 0.18266798404511064, 0.1810346802813001, 0.09360667085275054, 0.12774072907632217, 0.14467563363723457, 0.17632097384193912, 0.07462438865331933, 0.15268511400790885, 0.17511603771708906, 0.16847820952534676, 0.25385161279700696, 0.13184002629714087, 0.10314505707356147, 0.12028454948449507, 0.12822593038436025, 0.12701308296527714, 0.15829074836801738, 0.19750644016312435, 0.0874374050181359, 0.10694080105167814, 0.0961404520785436], [0.03800789840170182, 0.04036912658193614, 0.07083533142576925, 0.07326881881454028, 0.07295618168427609, 0.07526829824200831, 0.04388478773762472, 0.040248609220725484, 0.031066021583683323, 0.011452917569840793, 0.053005044246674515, 0.026955224784614984, 0.036706241880892776, 0.040987684405990876, 0.028683529017143883, 0.03678684282931499, 0.035609711267170496, 0.14363085298100486, 0.05342571952496655, 0.023126572123146616, 0.027392294105084147, 0.03087399458308937, 0.021771581159555353, 0.017482728289905936, 0.06659419494098984, 0.02132599569449667, 0.04323739747633226, 0.026744013266579714, 0.04642538558982778, 0.03685803705593571, 0.04752543398353737, 0.03647622805146966, 0.04756303860631306, 0.03918373862688895, 0.055491116509074345, 0.07626548496773466, 0.07812650190317072, 0.037611814186675474, 0.009401105598954018, 0.08901761553715914, 0.13457161956466734, 0.0343240665824851, 0.017080575162253808, 0.10587676908471622, 0.07576861709821969, 0.01866632024757564, 0.0455867364507867, 0.010554204563959502, 0.0047677357179054525, 0.021731084016209934, 0.011445250256656436, 0.044135214338894, 0.0320905137778027, 0.029897445128881373, 0.02345235083339503, 0.05189448333112523, 0.06843870651209727, 0.007804629058227874, 0.036234094950486906, 0.05313069726980757, 0.02702826324821217, 0.07303298654733226, 0.11701510695274919, 0.043761580091086216, 0.036695532689918764, 0.0198562742662034, 0.05633841166854836, 0.04632544056221377, 0.019176058813172858, 0.03639241731434595, 0.049382090801373124, 0.009897660838760203, 0.02809241952490993, 0.032602350765955634, 0.02965034520457266, 0.022287807951215655, 0.060508721289807, 0.02081448896205984, 0.048351329314755276, 0.0433233047806425, 0.015172131279541645, 0.060711342448485084, 0.06282342423219234, 0.04922694854030851, 0.04094045783858746, 0.03448035175097175, 0.02546010335208848, 0.08646352172945626, 0.04181958000117447, 0.06147161708213389, 0.058391566926729865, 0.029773532442050055, 0.04804934200365096, 0.008566400974814314, 0.09193067875457928, 0.07615685681230389, 0.035937799912062474, 0.021656962017004844, 0.10302068796590902, 0.022484219189209398, 0.033884240183397196, 0.059451030974742025, 0.026234309952997137, 0.047425362790818326, 0.029856022156309336, 0.014601150687667541, 0.026000856269092765, 0.025216003559762612, 0.06256168358959258, 0.03341087984154001, 0.050749130532494746, 0.0797496827726718, 0.03324490964587312, 0.011639703152468428, 0.01409687525665504, 0.04311936630983837, 0.02247672720841365, 0.021027014081482776, 0.02606664209451992, 0.07615193637320772, 0.06659385355305858, 0.010375425827078288, 0.03402703681786079, 0.06011388388287742, 0.034763878138619475, 0.05339496121450793, 0.02928850553871598, 0.00713696749699011, 0.06407116743503138, 0.02247491636808263, 0.056116750711225905, 0.003400567270546162, 0.049068744920077734, 0.03657189830846619, 0.040870974262361415, 0.045383584656519815, 0.004114537223358639, 0.05138149601407349, 0.015460913928109221, 0.027128249093948398, 0.058688132849056274, 0.02157909402740188, 0.0660575924848672, 0.019220077447243966, 0.0549046305968659, 0.029225163234514184, 0.024536502423870843, 0.03939842710678931, 0.026625436621543486, 0.027343197325535584, 0.045980278810020536, 0.03421800254727714, 0.011212306799279759, 0.061558941888506524, 0.030095012261881493, 0.035726721980609, 0.009973920223274035, 0.03528943743731361, 0.01754902805259917, 0.05366583769500721, 0.027050253083871212, 0.02404781487712171, 0.017067389053408988, 0.039806333734304644, 0.10700564249418676, 0.021498216628970113, 0.047418672329513356, 0.01738178136292845, 0.030276311517809518, 0.049721979594323784, 0.03433646787016187, 0.010064576345030218, 0.017147919497801922, 0.05462429173348937, 0.018544277772889473, 0.024512414165656082, 0.028940883566974662, 0.009842655636020936, 0.08806385929347016, 0.08627560993772931, 0.036590908421203494, 0.024858269825926982, 0.05875581300642807, 0.04207549478451256, 0.06273939085076563, 0.08599757915362716, 0.007187351902757655, 0.07138376371585764, 0.04273563885362819, 0.016828667976369616, 0.0778917754360009, 0.024118830988300033, 0.033046633761841804, 0.08655943689518608, 0.0389402993459953, 0.03455408041190822, 0.011545159104571212, 0.012768079322995618, 0.03804956257226877, 0.08307725773192942, 0.07479827385395765, 0.011334664686728502, 0.022513754811370745, 0.018533184520492796, 0.024407611781498417, 0.02743660403211834, 0.08214478628360666, 0.05493836120876949, 0.08904453323339112, 0.05897047922189813, 0.03242095132009126, 0.07262813014676794, 0.07348790080868639, 0.01607978716492653, 0.01723915913316887, 0.012165434072812786, 0.03574749469407834, 0.015959306911099702, 0.0429849967622431, 0.010299534733348992, 0.04014099780761171, 0.039306920298258774, 0.06752578323357739, 0.024746489398239646, 0.025608751820982434, 0.05096352215332445, 0.0073756036908889655, 0.07801296073012054, 0.034873597251134925, 0.046472623289446346, 0.04725178187072743, 0.04716216011729557, 0.017068888191715814, 0.01812088994483929, 0.03657882996776607, 0.015209122702799505, 0.004409450011735316, 0.09029195731272921, 0.02922029289038619, 0.04539194123935886, 0.042069754272233695, 0.07098545305780135, 0.035822047138935886, 0.05421584333817009, 0.03659926871478092, 0.023371632996713743, 0.022254268442338798, 0.007630400614289101, 0.028173868377052713, 0.021796441251353826, 0.05874213522474747, 0.06684120395220816, 0.01638839257793734, 0.008481029872200452, 0.03633395092037972, 0.043681591414497234, 0.028440592541301157, 0.03297798510175198, 0.04947569417709019, 0.06779740186175331, 0.02389277837210102, 0.024506334120815154, 0.08421139296842739, 0.015825696209503803, 0.0024224878325185273, 0.033109360083471984, 0.030794623744441196, 0.10339913133066148, 0.052295944406068884, 0.024775043530098628, 0.00820982777440804, 0.0549220265384065, 0.034909424430225044, 0.02452187840390252, 0.10447694497997873, 0.10452609742060304, 0.04669857014960144, 0.03038025115529308, 0.01809124856663402, 0.020420293512870558, 0.03492232666758355, 0.040008331488934346, 0.04759307332278695, 0.04826869488169905, 0.021004220870963763, 0.01909385853650747, 0.04221731178404298, 0.03784006170462817, 0.009814511540753301, 0.07083061136654578, 0.06575725274160504, 0.02219114136096323, 0.013880323986086296, 0.05321341704984661, 0.010460198573127855, 0.03290343636763282, 0.03647648780315649, 0.07492690288927406, 0.02908873608248541, 0.03386806507478468, 0.028808297029172536, 0.03449918745900504, 0.0412867699196795, 0.036748963611898944, 0.016237962954619434, 0.014536031867464771, 0.03236179101804737, 0.03293998342996929, 0.0232405326096341, 0.016579697839915752, 0.00987120512945694, 0.06061219894036185, 0.05606604347121902, 0.03693852668220643, 0.07616038201376796, 0.01970679088117322, 0.02370482761762105, 0.06888936826726422, 0.05602372621069662, 0.0195290539340931, 0.0628940544265788, 0.05627047175948974, 0.0438633025623858, 0.04180484094831627, 0.07013948634266853, 0.04107859007490333, 0.07832417293684557, 0.05932698470132891, 0.04430672837770544, 0.05560368546866812, 0.035697729981620796, 0.04640613798983395, 0.0384791139367735, 0.037246621868689544, 0.01907204310555244, 0.0443974336667452, 0.048495072187506594, 0.03127407340798527, 0.012907274685858283, 0.01885146753920708, 0.05299824617395643, 0.07984708223375492, 0.02551292571297381, 0.05502213112777099, 0.012792758516297908, 0.028996770997764543, 0.0036880365496472223, 0.013847891204932239, 0.03466221874987241, 0.05299436474160757, 0.056412952981190756, 0.050120063897338696, 0.11773599209845997, 0.08628190335002728, 0.12501970399171114, 0.18054743064567447, 0.10619008899084292, 0.1800254633417353, 0.15648014552425593, 0.15117689181352034, 0.2758815244305879, 0.13576523051597178, 0.14917313761543483, 0.17198067158460617, 0.16338428598828614, 0.11440282134572044, 0.12480462959501892, 0.08294628350995481, 0.129348473274149, 0.2592910506064072, 0.13837463659001514, 0.14642447495134547, 0.09725925454404205, 0.10429634334286675, 0.10233753360807896, 0.10991213770466857, 0.15128236584132537, 0.14047397940885276, 0.16104059846838936, 0.07340389711316675, 0.08793621731456369, 0.12170654896181077, 0.178809602803085, 0.08526682344381697, 0.20020226191263646, 0.2445891051320359, 0.14639098924817517, 0.20029612875077873, 0.13246485526906326, 0.1439526630565524, 0.11074073816416785, 0.2495004009688273, 0.22236141114262864, 0.20918313937727362, 0.17395830218447372, 0.2266911303740926, 0.18674313178053126, 0.13986095058498904, 0.0943409517640248, 0.07559329955256544, 0.11466974960057996, 0.16642731410684064, 0.2026646040030755, 0.2942664222791791, 0.09235324279870838, 0.11124955461127684, 0.12363762463792227, 0.09830692215473391, 0.2055430831387639, 0.10367382245021872, 0.08402209336054511, 0.11937568575376645, 0.13127850252203643, 0.20442255889065564, 0.22170397220179439, 0.1492708339355886, 0.2203580131754279, 0.11639116855803877, 0.12661987828323618, 0.15747613739222288, 0.09858950230409391, 0.19112382171442732, 0.17395898496033624, 0.11349016524036415, 0.18479959544492885, 0.1455046868068166, 0.1834345335373655, 0.15443916519870982, 0.07922211967525072, 0.13364610204007477, 0.18744927045190707, 0.1232053607236594, 0.09691775529063307, 0.17223003320395947, 0.14179552177665755, 0.1423344694194384, 0.11078685522079468, 0.23169525404227898, 0.2173813182162121, 0.1028877693170216, 0.12375035687000491, 0.11743384893634357, 0.17996782815316692, 0.1755671892897226, 0.2589021058520302, 0.07752052348223515, 0.200383004557807, 0.16100436681881547, 0.09469691547565162, 0.06022663837939035, 0.23405899439239874, 0.15253763442160562, 0.11397103240597062, 0.19445925601758063, 0.14895077532855794, 0.06434423325117677, 0.19171008869307116, 0.11943264558794908, 0.21325965266441926, 0.09274851807276718, 0.09801513937418349, 0.0739781858283095, 0.17608166090212762, 0.2064488743781112, 0.12422510873875581, 0.14564036624506116, 0.11931355315027758, 0.15047053049784154, 0.1183460968604777, 0.11084607118391432, 0.15441176510648802, 0.14222768921172246, 0.10425050088088028, 0.13095744943711907, 0.08420817204751074, 0.12956497259438038, 0.13630149158416316, 0.146876294456888, 0.1807163137709722, 0.09031298235640861, 0.11350060725817457, 0.06798253059969284, 0.12313081198954023, 0.10465847430168651, 0.06002962043567095, 0.12100933090550825, 0.14574849716154858, 0.18476057332009077, 0.13773163984296843, 0.12567775149364024, 0.13755561725702137, 0.10940061984001659, 0.19915679848054424, 0.1269714187947102, 0.20417500811163336, 0.08306352799991146, 0.09472952544456348, 0.13683942990610376, 0.0816515252518002, 0.13550065486924723, 0.19760063354624435, 0.13133218948496506, 0.10395347111625597, 0.12295029941014946, 0.09858024772256613, 0.18145767477108166, 0.18360942805884406, 0.17256656748941168, 0.10001864124205895, 0.10250610503135249, 0.11203879155800678, 0.16525103972526267, 0.1455096888821572, 0.14306104683782905, 0.1335868044407107, 0.10395013887318783, 0.2345362992491573, 0.20603655197191983, 0.12195997755043209, 0.06854140490759164, 0.12043946539051831, 0.12173437949968502, 0.06387623492628336, 0.19273150654044002, 0.17601491214009002, 0.17412720015272498, 0.14657315681688488, 0.13994199311127886], [0.008493818932038266, 0.03244976520363707, 0.02469819228281267, 0.011416842698963592, 0.043658963331836276, 0.08253411695477553, 0.022627628095506225, 0.016766173575888388, 0.04003930873295758, 0.017535964398120996, 0.0064881235539360205, 0.031765905805514194, 0.023748950152366888, 0.1218836402404122, 0.06393505012965761, 0.07770326992613263, 0.019425205209699925, 0.05188735871342942, 0.005105504287712392, 0.026742434347397648, 0.019696215276781004, 0.04653733856684994, 0.025621906388550997, 0.031228991647367366, 0.060298422613414004, 0.05289731780067086, 0.006037562916390016, 0.08412938565015793, 0.08678471582243219, 0.03891575281159021, 0.013344021172088105, 0.03324447920022067, 0.049922507896553725, 0.025250081125705037, 0.016822226134536322, 0.020770739356521517, 0.06170469227072317, 0.07451953802956268, 0.03317169306683354, 0.027182288577023428, 0.02933106956334086, 0.05975789790682029, 0.031239559830282815, 0.0009437712265025766, 0.06577782507520169, 0.049949269741773605, 0.054738363542128354, 0.008065933689067606, 0.08976708821137436, 0.03364700896781869, 0.07753401572699659, 0.1017085560306441, 0.02739895302511286, 0.03907349630026147, 0.026829517955775373, 0.05054644258052576, 0.032606057793600485, 0.06513672080473043, 0.1292343606473878, 0.02527068128983956, 0.031806783299543895, 0.011884377181559103, 0.04072838542924728, 0.04454155503481161, 0.023451315537386108, 0.0458855399483582, 0.048987301634042524, 0.03978451459261123, 0.009061270611709915, 0.01627886827918701, 0.020136941529926844, 0.007443310751114041, 0.04933332427754067, 0.050878690963145345, 0.05247941073321272, 0.029589451987703796, 0.02290199823619332, 0.062415480497293174, 0.02443107292492641, 0.02851424698746996, 0.024570438981754705, 0.05035563270212151, 0.04517871479038149, 0.06957307923585176, 0.0880621894611977, 0.022187990944075864, 0.0370871491759317, 0.012313981424085796, 0.01612184652913129, 0.034867838185164146, 0.12233186775119975, 0.06042523338692263, 0.06877002349938266, 0.03881455726514105, 0.058761546097230166, 0.050169661626568995, 0.03340651972393971, 0.0321878724207636, 0.04092947034223471, 0.0378618994000135, 0.0374460406601429, 0.03264377002778929, 0.015507553271163488, 0.01500859532825416, 0.03346881931065582, 0.06875153660075739, 0.028095501293137204, 0.022001615398039576, 0.037580840653390624, 0.02787094039376825, 0.015568232192890719, 0.05372053768951446, 0.03599163159378804, 0.05965387848846149, 0.036276887185522355, 0.06187773142301012, 0.04868462412559893, 0.018545496750448365, 0.018670454010134563, 0.04573620499286335, 0.060180450818734244, 0.056049938866635785, 0.026280397323716898, 0.04496513582125772, 0.016643641283735633, 0.02539153632824309, 0.05675913889717776, 0.03033117849554401, 0.0499979175219778, 0.04132572896196507, 0.03861688252072781, 0.03913720225682482, 0.05199642102525104, 0.10468699503690004, 0.021503187163034454, 0.007516982823290164, 0.027252495747234207, 0.05762136606790591, 0.00993779989585164, 0.04449058062164113, 0.056631871702848, 0.03802934275881853, 0.020179561215627473, 0.05863762598892208, 0.05698081098671537, 0.03441712447965983, 0.023143611833802424, 0.0045607349602505565, 0.057417813513893634, 0.010987732912326464, 0.10037042666226625, 0.015470042344531976, 0.004337691752880346, 0.01859531897935085, 0.04095125237654429, 0.08056977821979672, 0.03867213541525416, 0.05335680740245152, 0.07681756862439215, 0.02109669803758152, 0.009062661210919032, 0.019992202323919628, 0.039601779280928895, 0.010850223152374383, 0.02305951351445401, 0.05072828731499612, 0.0471461074630497, 0.006943096723261988, 0.028788808231183793, 0.004044716897624312, 0.021321642998373136, 0.014130935196590144, 0.008241279992944328, 0.029710344133491162, 0.03966019743529614, 0.044167408705106936, 0.03641802140919026, 0.01986071602004813, 0.027180199431313667, 0.0370549919171026, 0.1276357745518908, 0.055143101199064404, 0.023977474120329134, 0.06951095405383967, 0.015667859952372964, 0.011078939151047962, 0.10148614179342985, 0.031955828817444853, 0.01850599037425127, 0.08568689387175255, 0.07736179293715395, 0.002574074742369703, 0.03179501654813066, 0.02028362145210849, 0.03968555662140716, 0.02621913303300971, 0.02534269373427378, 0.02002032229938777, 0.01698803862382192, 0.009233466498699272, 0.030270103452494368, 0.0630391739832703, 0.03900894800608512, 0.05564138657064177, 0.06257986620767042, 0.03854379210679326, 0.03758622122404631, 0.057403078171773814, 0.08190088687115349, 0.04828095516131725, 0.02379880206717644, 0.11990040642558597, 0.0035804573735731537, 0.02498569472663803, 0.024490209107170813, 0.025598140964575578, 0.024986768985399976, 0.03134593185677659, 0.057831594240269624, 0.01279929590964457, 0.016291822466882877, 0.04369045636849478, 0.024680800052010454, 0.09444451105082408, 0.08052796561969444, 0.04637374324374832, 0.04262168578861747, 0.07843923551263288, 0.03178985491103958, 0.04215616994770244, 0.016458492136735003, 0.029122572450432926, 0.04026262467959896, 0.02579932606749935, 0.05802132058306597, 0.040332694552489556, 0.05090276994451415, 0.0707345774571877, 0.0247930869954871, 0.02638556521560531, 0.028402548196027055, 0.03531972077325918, 0.07921019336208701, 0.02092472386721056, 0.012205013736092951, 0.00787896906331298, 0.05963230796623975, 0.012111332434869837, 0.016482237151649315, 0.03438656283833552, 0.06361655745422468, 0.08519764785887673, 0.009037622075993568, 0.0732159185281489, 0.008592766698711785, 0.03639592025137972, 0.055783370553399436, 0.025332073601020966, 0.026653261593310162, 0.04130505272769369, 0.06216990383109078, 0.02361792398005491, 0.0231193825675291, 0.024883565929485485, 0.012498714968387503, 0.030611001566285267, 0.06885085080284625, 0.03795259726757649, 0.036704701924463734, 0.021886658578296192, 0.05496115256391931, 0.027421987433626782, 0.09412682731635869, 0.04574099926685449, 0.00922881044971291, 0.01872938981250627, 0.018464867971488275, 0.067338235094212, 0.029785532969981432, 0.04190189159999136, 0.022474541583505925, 0.024867257234291174, 0.04228430916555226, 0.043075765133835375, 0.07278738761669956, 0.04256401720340364, 0.04669259215006605, 0.04314689627790358, 0.0343929638620466, 0.023717561016383115, 0.03427200863370672, 0.06452211862779222, 0.07529652953962795, 0.03974280960392207, 0.012457893135433551, 0.04499036142078694, 0.027857693057740107, 0.02553504913521465, 0.06358179525705054, 0.03331484222144354, 0.020600024981831666, 0.006076655081415083, 0.04198779148282483, 0.02129753804183565, 0.02979623659484787, 0.024417614076810423, 0.02512662857043324, 0.008948789782152744, 0.028961832540517207, 0.04390396483358927, 0.03809131208981853, 0.02648572361067636, 0.03735128324478865, 0.07400834670988843, 0.025698347599245608, 0.0070206047712417785, 0.04994683178665582, 0.035059056244790554, 0.028043471174896695, 0.03135886749078054, 0.06282025526161306, 0.010353765319450758, 0.014333412564155878, 0.0265232057790854, 0.05227439985901583, 0.061177121751825325, 0.04947677400195971, 0.03060968610952841, 0.019748980121221393, 0.021625437439070083, 0.03185839224897791, 0.016813440961414017, 0.018598825627123006, 0.0659705905127339, 0.018896599394793157, 0.04223938696668483, 0.021001940622227266, 0.020437884268176276, 0.03357831206812989, 0.029380283231148496, 0.03514953517878894, 0.0405138787755277, 0.025305402668891475, 0.03676485670439433, 0.06071139439882245, 0.04613391080056317, 0.029128403875802178, 0.009891840545606101, 0.017709363492031116, 0.0393965049443068, 0.045599545919685625, 0.04499016846239101, 0.11878336285008118, 0.09109353617532179, 0.09942754288204014, 0.135534348373767, 0.25184686412103474, 0.18105137860402465, 0.1878802356077358, 0.16173860320122913, 0.15554155135760084, 0.08276583772385493, 0.1260684774024412, 0.16414770361734554, 0.19895201025065035, 0.18829340406227857, 0.1651819160906598, 0.2124981943052262, 0.10756385629065335, 0.1175389667332638, 0.09075723195564933, 0.11098615897935815, 0.15608741581672803, 0.1387699638144113, 0.0684822112089023, 0.09924519719788805, 0.16675982595188543, 0.13114245200995356, 0.09686542645795271, 0.22083254239987582, 0.17139897623565048, 0.15199705405393615, 0.09086428675800562, 0.14308990153949708, 0.11499305881443433, 0.12478494783863425, 0.16230184875894338, 0.21404803614132106, 0.10093479286297224, 0.18669753422727808, 0.1934462392819114, 0.08778347590123303, 0.12093984361854382, 0.1178021619853098, 0.17964714614208788, 0.09227072339854203, 0.12046692485455424, 0.13055435934802517, 0.11089586187154055, 0.1712693675654009, 0.27200890879612416, 0.14799064403632656, 0.1659358193865046, 0.1693060010438785, 0.13448630226776004, 0.09081893411348574, 0.07560757105238736, 0.06284654955379665, 0.15962524863425642, 0.11144135525682941, 0.22645198070676997, 0.14661050168797374, 0.1532966288505122, 0.13023544364841655, 0.19204623706173152, 0.10931299446383491, 0.1122737184050493, 0.16578179405769333, 0.26397714915219694, 0.1256529043894261, 0.08742282923776656, 0.09940127827576362, 0.18360405490966514, 0.08265448588645086, 0.13516971637727693, 0.13613965886179358, 0.15859442035434768, 0.1814275881042704, 0.06323953159153461, 0.17782889917725697, 0.09077555558178574, 0.10821934338309802, 0.1023163230274804, 0.0835067311709281, 0.20417261839611456, 0.11258913858910091, 0.15220706700347364, 0.12278707145014778, 0.13895098847569898, 0.15821822569705546, 0.12977259582839906, 0.09764752394403331, 0.13476223277393728, 0.16232274763751775, 0.06790896150050685, 0.1122958269843366, 0.18922352290246636, 0.10588851728243753, 0.1723670633509755, 0.09520870051346719, 0.13786553812678903, 0.15254049911163747, 0.07031231769360602, 0.1819402043474838, 0.1256753024063073, 0.08185114071238786, 0.16227937652729452, 0.3028089873259887, 0.17498898203484714, 0.12020196329103783, 0.16909193596802652, 0.11045938997995108, 0.12270465595065616, 0.19191564875654876, 0.12313844126765616, 0.15844685171032324, 0.10658447368768975, 0.16048434394178912, 0.25590676814317703, 0.17328529298538342, 0.1057124427461531, 0.1260595567873679, 0.12178794771898538, 0.14259819901781157, 0.11232939432375133, 0.1804255848401226, 0.20208250789437443, 0.11962957447394729, 0.14089477714151144, 0.08943498454755172, 0.09624531012377702, 0.10112031493918039, 0.14706730842590332, 0.14408527000341564, 0.11856082986923866, 0.22610130108660087, 0.12031528924126178, 0.11080804353696294, 0.11506837938213721, 0.20242242637323216, 0.09859650075668469, 0.1260883966460824, 0.2277984147076495, 0.1278559846105054, 0.1537069771438837, 0.14800045522861183, 0.16238347016042098, 0.06829277801443823, 0.06958962912904099, 0.063863566465443, 0.2569319709436968, 0.1452114642597735, 0.09100709081394598, 0.07676097986404784, 0.08573937113396823, 0.09616710260161199, 0.10048151132650673, 0.1564036894706078, 0.11168207827722654, 0.19816039100987837, 0.14485950814560056, 0.10721308761276305, 0.18524694722145796, 0.08124973392114043, 0.08456455136183649, 0.11227828261326067, 0.15801609435584396, 0.12797362986020744, 0.15694238478317857, 0.14698132319608703, 0.2315316698513925, 0.186368272989057, 0.14949799049645662, 0.061364083594526164, 0.05183065492019523, 0.12136346151237376, 0.17097988544264808, 0.08207988546928391], [0.04511115708737634, 0.038000499189365655, 0.02032394604611909, 0.04931618437694851, 0.020390600184327923, 0.0458997483656276, 0.06283214446739294, 0.018486891203792766, 0.013894647436245577, 0.03227699322451372, 0.020428843054105528, 0.1434277420048602, 0.048451923721586354, 0.015449919937964296, 0.04458102244825568, 0.02415640035906108, 0.020902110627503134, 0.018879878807638306, 0.038156799200805835, 0.02079551781207556, 0.018997149272763636, 0.04073272328241728, 0.04690565161581617, 0.044325898052193224, 0.057621291853138246, 0.009199870401062071, 0.033280614370596595, 0.01722035125567345, 0.03130234181298874, 0.03394196442968678, 0.04113858529308345, 0.04040427469590213, 0.062252835123217665, 0.05961831106105819, 0.0548464462190168, 0.07394649612251669, 0.10291164420777932, 0.05614094843622297, 0.04038593622681219, 0.02280379911098862, 0.02758761438599322, 0.14646413532318547, 0.0620896479813382, 0.06087622910854407, 0.0857480097329244, 0.01620485018065665, 0.07492223478038795, 0.05374770400521811, 0.0068414957786444575, 0.052369446711963974, 0.03939298716431949, 0.034375104078208096, 0.014338530600070953, 0.00628345870609337, 0.014682011387776583, 0.040702362020965666, 0.012762512287736172, 0.02038379097939469, 0.06493550230516121, 0.06049592666386161, 0.05604509264230728, 0.08347675582626835, 0.04985223393305205, 0.055116662188083865, 0.044392643103492446, 0.03217298864910845, 0.03160924214171246, 0.011671259271679446, 0.021983128499414306, 0.027709447203960735, 0.061525111086666584, 0.03302810604509432, 0.09350967215141281, 0.03325404548377264, 0.04381087353976909, 0.034620005390024744, 0.03359272457601037, 0.03902725307852961, 0.06653468211879954, 0.05558519114856608, 0.08923080487875268, 0.02201683870225679, 0.019800989830400795, 0.058088629666599445, 0.037148814226384275, 0.04216351720970124, 0.03983700298704207, 0.045263616484589875, 0.03860893411911093, 0.050983775363420136, 0.06769372383132577, 0.005265850859359489, 0.05820732134452555, 0.047079481155378744, 0.048439667152706534, 0.028533622607938014, 0.03803738021815661, 0.046008495264686644, 0.029052521131234244, 0.013543998429668136, 0.06007221971231047, 0.044546382705448195, 0.07654629880562425, 0.02662101342139067, 0.05301360863086302, 0.046971198098617606, 0.011822726046375465, 0.005635297538901796, 0.054336861649062485, 0.028294322655710857, 0.05789871407614555, 0.04495673470955808, 0.034948992033605464, 0.024213955766754225, 0.02557842766691465, 0.03417447929678019, 0.07421502741635777, 0.04161951183050405, 0.060999269771855325, 0.025392857351107523, 0.055204209638759494, 0.05112975952215493, 0.04158549549174495, 0.0690290256170556, 0.039576475755893625, 0.05440469765744638, 0.05101450398797169, 0.041507740679662675, 0.07127175136702135, 0.05577117706707213, 0.10620734392432496, 0.05576178147748578, 0.024538938523619436, 0.03256445670558605, 0.06781723946915008, 0.09785931804799475, 0.01590785937878536, 0.06420865771360695, 0.05040098534664139, 0.031037623302836437, 0.012816935832233867, 0.04249177283782046, 0.024476173239236232, 0.03779553284402937, 0.03814347022853326, 0.08337290710187517, 0.0731379039643798, 0.053282963708625175, 0.09440482099307701, 0.019973800772277173, 0.061836230524932034, 0.04175717280304525, 0.02449899613566231, 0.03372957660758402, 0.01990851218579337, 0.07080183087964542, 0.02073941515845945, 0.020378323206386995, 0.055986466686590575, 0.05397661945607979, 0.03854102018522099, 0.018845129598048516, 0.061622336143045686, 0.022879989846842363, 0.05453084049804602, 0.022856168761791196, 0.039651250845054165, 0.012516763999883551, 0.059230490660411306, 0.01978641033929307, 0.02664458217623178, 0.025603402791603003, 0.006829662697782624, 0.026784545661939774, 0.04371066876046825, 0.03374895779415965, 0.06123536921222694, 0.06406799104297534, 0.014154336968204007, 0.029211324035713915, 0.030334538569150027, 0.053370039895526133, 0.02754882789304247, 0.018977341351273935, 0.07395932043436915, 0.018496405537007377, 0.010226793128822464, 0.04841519483306911, 0.034780001296894625, 0.05214005628658924, 0.02051289498922415, 0.02682750859094085, 0.062139420115272515, 0.04915306773909833, 0.021241485483187716, 0.027849265970871784, 0.035056807537330315, 0.06491471474873833, 0.037258659504004754, 0.022941194765735418, 0.043172355653950945, 0.023156239476520568, 0.05442199340905063, 0.022221203907974996, 0.009416976427019108, 0.023039709303702693, 0.023375584933091886, 0.04606405986123718, 0.064516723214183, 0.021071639421279542, 0.1111800673243124, 0.04161049844697118, 0.032755381616880186, 0.014661887125839712, 0.025775074536795728, 0.0823218998266384, 0.04153015725023579, 0.06702957587549463, 0.015998935741663445, 0.055072400500648655, 0.024076350455288775, 0.01710194530460285, 0.021485173383553047, 0.026166397874476388, 0.03218262914742809, 0.014797457097301958, 0.007855216626921901, 0.0984645468997769, 0.021597770173684694, 0.0564590440626489, 0.013590407706942642, 0.0239074561977759, 0.022809205656812992, 0.10660321291652508, 0.011411658797442215, 0.03131030505755916, 0.05597886338364333, 0.03783337495406158, 0.06115701326052658, 0.07382448704447597, 0.06490686282631941, 0.05105649099277798, 0.014652896934421733, 0.00941479172979598, 0.02255278992379317, 0.06424587641959079, 0.13464669522363693, 0.10896446707192808, 0.024819934187689796, 0.03161570995871443, 0.03708635878865607, 0.004637564870790811, 0.0417572507285513, 0.06552759514306672, 0.03151104858261533, 0.04291605124308262, 0.09733720973599702, 0.03485551853373181, 0.06960997881833464, 0.03860659635392949, 0.02820042056555394, 0.0609152623655973, 0.0337830520584248, 0.015020727587398142, 0.07210523515823297, 0.06407466295058839, 0.013971352109365398, 0.026043715297419112, 0.0646594975842163, 0.059703520746552385, 0.06345496964058839, 0.02839883560227463, 0.020192324300296605, 0.029447323286149185, 0.035726670030271634, 0.02376305466896156, 0.12428051748429425, 0.028192130776005797, 0.052710782692884095, 0.030066671497479547, 0.04621567321009934, 0.055063654290279374, 0.037002154713263735, 0.06723528436850756, 0.025736970819707494, 0.016443424683529884, 0.026612573346938007, 0.021956318414595444, 0.03108872944721952, 0.07623435187269934, 0.04249625912052579, 0.03659828536910936, 0.06877723717479967, 0.06343297980492935, 0.01897618916700594, 0.017103416612371802, 0.04152557819907088, 0.030905027488188352, 0.02922911702626152, 0.016158376893145032, 0.02428855274047237, 0.09323963429778814, 0.07388955855276436, 0.11593603165238164, 0.03617791437136475, 0.10665428751963191, 0.057975856616394594, 0.03234044685086701, 0.06516035820823163, 0.044179628166602924, 0.04832853053812869, 0.07927201426355168, 0.04021560962428339, 0.08332723533385433, 0.036217407759977505, 0.06716980467899702, 0.04200766248686705, 0.04668866618885659, 0.05814919633849058, 0.045652976841665804, 0.02582969103968935, 0.026634800669853576, 0.046321243717102334, 0.041589863030822016, 0.06233406689716503, 0.04383291903650388, 0.08061018816079013, 0.025417658071091864, 0.03150267344608437, 0.04712561676569749, 0.10790338143124245, 0.06037437400664203, 0.054721806227462366, 0.05493723314430099, 0.07581301979371347, 0.04106790314835962, 0.05254400355624966, 0.027781270400737412, 0.14013946376508102, 0.02623003332701046, 0.028907056475873105, 0.06830059282947332, 0.021354959862947, 0.024125603085849434, 0.06090547343774233, 0.05654843203956261, 0.03329065191792324, 0.03469224233413115, 0.021597120794467628, 0.06149197419290431, 0.04235354783304501, 0.0553930157184368, 0.18778673984343186, 0.11529978102771565, 0.06415313764591701, 0.1049787258671131, 0.12277277768589556, 0.12936408806126565, 0.11320516568957828, 0.1059383228130173, 0.28899978613480926, 0.08270348247606307, 0.08715415693586692, 0.2748640102799982, 0.0881936757650692, 0.15879580954788253, 0.13385866797761992, 0.20212160423398018, 0.23979162506293505, 0.10429456960991956, 0.22770919371396303, 0.12174683273769915, 0.12673356046434492, 0.14780332596274093, 0.1110672831418924, 0.13702189433388412, 0.24215888319304213, 0.05830094698467292, 0.16596022120211273, 0.06444126905989833, 0.158379138156306, 0.11344458253006451, 0.17842505156295374, 0.15298890473786741, 0.18980656896019354, 0.14943688205676153, 0.21038964885519817, 0.14904162904713303, 0.23929190734634176, 0.13963916717329994, 0.24256840028101578, 0.1257356390124187, 0.12651789234951138, 0.28167101845610887, 0.17517776956083253, 0.22281803976511583, 0.178306634479668, 0.09372120650368743, 0.1368655831902288, 0.13076653936877847, 0.12740057311020792, 0.1444995665224269, 0.1453601461253129, 0.1323346231947653, 0.07862045313231647, 0.1437163632363081, 0.05581007673754357, 0.14229087566491216, 0.1548436505254358, 0.22133246791781858, 0.211442593135871, 0.11860455721034668, 0.16412258933996782, 0.1354683269164525, 0.15905725333141163, 0.11704611388267949, 0.1948726619593799, 0.11433945677708834, 0.1260784370242618, 0.08702291554072872, 0.09042526929988526, 0.1791285036597401, 0.17457686743000522, 0.21993930829921737, 0.2004198299255222, 0.08024503666092642, 0.2058217447483912, 0.11050581131712534, 0.13135130720911548, 0.1880427511059679, 0.20700889901490882, 0.08686299755936489, 0.19481475959764794, 0.10314736515283585, 0.1668205187888816, 0.18280162999872118, 0.11603722348809242, 0.10831951105501503, 0.09031552050146274, 0.07620057673193514, 0.12334337050560862, 0.17809812066843733, 0.13883491657907143, 0.06291091602179222, 0.24538091733120382, 0.17695870134048164, 0.18726498034084216, 0.15033899224363267, 0.09082461896468885, 0.1168341119773686, 0.16080181987490505, 0.10543262338615023, 0.17752252577338368, 0.19776129367528483, 0.14060453802812845, 0.1277533604297787, 0.10647306247847155, 0.142034359741956, 0.07259192818310112, 0.13966950617032126, 0.10882710295845754, 0.07233800977701321, 0.11927738829399459, 0.11237574886763468, 0.0815707424771972, 0.13026492175413296, 0.10604249808238819, 0.13144922617357224, 0.2236887571052648, 0.16547484177863225, 0.08607882948126644, 0.08119345686282031, 0.1398245556629263, 0.2007601788500324, 0.08425915759289637, 0.14355053775943816, 0.08515126362908632, 0.20987732947105542, 0.2895686571719125, 0.2863743348279968, 0.16908078890992329, 0.2317533196764998, 0.13213269965490326, 0.11023237442714162, 0.19676510884892195, 0.1374825305538252, 0.10049094402347691, 0.2663568902062252, 0.12734099349472672, 0.17583875596756116, 0.12407946225721389, 0.15330427297158167, 0.18525989027693868, 0.16082173911854625, 0.10260774215566926, 0.11775706167099997, 0.16169923968845978, 0.1962046537664719, 0.14071391575271264, 0.10287806944688782, 0.2388294306001626, 0.11499820931931026, 0.1995837560389191, 0.09487788076512516, 0.06617928243940696, 0.1278413346153684, 0.19350828282767907, 0.13405383797362447, 0.19457356160273775, 0.1455568746314384, 0.17000648454995826, 0.10250738894683309, 0.13651037646923214, 0.1462996457121335, 0.19003620429430157, 0.10033636950538494, 0.17261220957152545, 0.1388617229531519, 0.11937747432966717, 0.07525665394496173, 0.19903213251382113, 0.07477134873624891, 0.15439493319718167, 0.1675237185554579, 0.09923007222823799, 0.05848634660651442, 0.13962861383333802, 0.13773690909147263], [0.038222739021875896, 0.049478647924843244, 0.02474792730936315, 0.06781600008253008, 0.03388660021300893, 0.041214766752091236, 0.010476653842488304, 0.039878080860944465, 0.06773575907573104, 0.017310819057456683, 0.0022593194762521307, 0.026748224954644684, 0.04825359217647929, 0.10820959898410365, 0.06385463100741617, 0.03269140106567647, 0.04678057004639413, 0.05024158686865121, 0.06909454983542673, 0.04207110498100519, 0.03239364770706743, 0.013477668981067836, 0.015585279325023293, 0.037416050472529605, 0.04679390272940509, 0.03896593683748506, 0.00986550172456191, 0.015427586859004805, 0.012418120513757458, 0.04675434254750144, 0.09348603474791162, 0.03780899540288374, 0.031138824415393174, 0.04798655631020665, 0.07634055320522748, 0.034777121763909236, 0.016632891274639405, 0.02473788790666731, 0.04886347429419402, 0.019391639725654386, 0.0585618415789213, 0.0525457438925514, 0.04227805286063813, 0.014797280837228755, 0.02321663730981527, 0.08482367222313769, 0.09352714972919784, 0.052885959230479784, 0.022393259714590386, 0.006658934871666133, 0.10329845157684758, 0.022097562105045654, 0.03724103720742278, 0.04949132009642199, 0.013187881650083, 0.07133147941203788, 0.026361404597992077, 0.016919766603678, 0.039151781747932546, 0.013170558067940874, 0.049911331152543426, 0.03294055117294192, 0.02661943821294699, 0.024832834569679108, 0.017585792193131056, 0.030727132834726945, 0.04811088459973689, 0.08605391558376141, 0.01934779735165648, 0.013373849942581728, 0.06483753881184384, 0.01716410944936797, 0.029679936487809755, 0.01360713757094345, 0.06175876143970527, 0.101600796187995, 0.012296413860894972, 0.05508698370249476, 0.018063444003928453, 0.03274032715125941, 0.02942775285191601, 0.016526706640433986, 0.038509965015691705, 0.06796558736823499, 0.05563051039644051, 0.08905936134397052, 0.04229524471156765, 0.09037648793309927, 0.03636234920122661, 0.016749900132708717, 0.029146003907953855, 0.05131486599566415, 0.1028478195075877, 0.04761055090057198, 0.03880503179971129, 0.03301941920653917, 0.05317228351486847, 0.08298432599985972, 0.02359272250032518, 0.07569426132249646, 0.0719564345490653, 0.011166830772708636, 0.012929135573358508, 0.037125451417523436, 0.028950653941137716, 0.041831769776763394, 0.005551805925279041, 0.07861148798838258, 0.010364653553551761, 0.029479775548679754, 0.023064064735081047, 0.08043908601393923, 0.022320122916426044, 0.12185707135358825, 0.07307450970984064, 0.07234002841869369, 0.0400447264109971, 0.03474969940725714, 0.04295748163713142, 0.057597075574449264, 0.06687897926894948, 0.03455765014223289, 0.059449917753227055, 0.04667108842113521, 0.03375482076080516, 0.01884796831291169, 0.08676981349708512, 0.018237961885461118, 0.02519104327802779, 0.05413770260929596, 0.0168642817880027, 0.0726609182311222, 0.02417744766717078, 0.017074417191906832, 0.028539580198412295, 0.05884569080080837, 0.011332305584801361, 0.01896862482681172, 0.06591358614969067, 0.046067251096246764, 0.03090297173912404, 0.01958988963451702, 0.04764839672134258, 0.07512669646530412, 0.013155652031855425, 0.09992460370995104, 0.04340703759226017, 0.014863918277114863, 0.026527825648372527, 0.020479220038396306, 0.05914868743275292, 0.01062844437910826, 0.0291105162614258, 0.02071087215881562, 0.02830681114573963, 0.03218960904632695, 0.05364177355659194, 0.06981795828323811, 0.061536566136055626, 0.02210702634329209, 0.08111485600238666, 0.05415991137851961, 0.07702059796429239, 0.02533205690269824, 0.06436966665205546, 0.011035468778572977, 0.06688556211884134, 0.042161068122368306, 0.024701231377548538, 0.023778819740982726, 0.0659967512183357, 0.018101571840816177, 0.015637418910046108, 0.03061676619836362, 0.057556591418688186, 0.07199097410193644, 0.018673936538107228, 0.008465488372166874, 0.021017778053646907, 0.029674465004063677, 0.03434149220993277, 0.0561379316059174, 0.052794968214584514, 0.04074523960298393, 0.018700063847063575, 0.03580478849471547, 0.05370749444409739, 0.004087395955139073, 0.0853339878085535, 0.027040857494284865, 0.10273502790369093, 0.03243997256504372, 0.012574087486427743, 0.055744237106409855, 0.022314079978968948, 0.03456965809164103, 0.012436125016392907, 0.049061334575526416, 0.03704760754771996, 0.02560641962190857, 0.010980717761412961, 0.05018422998546157, 0.05893926449061837, 0.017163953598355874, 0.08707402725121938, 0.03849214604997542, 0.026086464858963154, 0.08176475472282618, 0.02957105043606134, 0.01748316801240435, 0.0952778612554539, 0.059168102015974, 0.00935466570808785, 0.01551846376969479, 0.029916739113104995, 0.05733904195949435, 0.04565933333651628, 0.018347068726143334, 0.049445941476733424, 0.039693838989478536, 0.02709112686716253, 0.045659979004994966, 0.03467314316367265, 0.03465065237833187, 0.04632955948181916, 0.045908598476671614, 0.04849205906793941, 0.028901809491799213, 0.032002420848584734, 0.06253871411900036, 0.08050959746469744, 0.06319486914435402, 0.0322707777377218, 0.06374629228957929, 0.013409211424004752, 0.01640195903746644, 0.01139759046054678, 0.027246309946349356, 0.0695381018158514, 0.01278769428608939, 0.04093824252777267, 0.023323423083638772, 0.03343498108733911, 0.05980062334856484, 0.04767892125528306, 0.01249268687388394, 0.05098059897136409, 0.036706368045997806, 0.033100354121415876, 0.04459281888557598, 0.029199529453762807, 0.013047324446233688, 0.025477137496636715, 0.027245423079875764, 0.024424488219665363, 0.030032881513761822, 0.04521995964751113, 0.018466233523213305, 0.0374900611495832, 0.03772388961806428, 0.05690478537871968, 0.058954359774361365, 0.050520233635324985, 0.03634015898569487, 0.08404518899624236, 0.025523937329126056, 0.03326230558741372, 0.003099773889516655, 0.09213371551595628, 0.04874136131547857, 0.06423588711186312, 0.06473610206739977, 0.07939203438581899, 0.018438772203808185, 0.00520963549206499, 0.03793889351072721, 0.08095995493931696, 0.018538978838478215, 0.017526576230011415, 0.07874078495660797, 0.03608569139032625, 0.013937924850324634, 0.07220768122351728, 0.03341436051414348, 0.02374285711994162, 0.012980529299966292, 0.016554106732655782, 0.0927889948070515, 0.05853879418282304, 0.017603132473595906, 0.10468922147992998, 0.027312179263390135, 0.032855126264621504, 0.02255579562188359, 0.07932429114589468, 0.03497485216939822, 0.06175391150463838, 0.011763426591642201, 0.054201197053771466, 0.0455460370721994, 0.013898698634875473, 0.010445404786878498, 0.04460025891603436, 0.023617996339453384, 0.03611450898461044, 0.026273667899658903, 0.05607675637293141, 0.039501711798948236, 0.034141798823839054, 0.01107030797356856, 0.06186868093209341, 0.014745777643838665, 0.03667814045911655, 0.01103626937037916, 0.035489743095240556, 0.019941396749345586, 0.055681395751889795, 0.017523167916806415, 0.06500304516521282, 0.02250340927275829, 0.058469143623369746, 0.07713902246905491, 0.019365258231118787, 0.07998081724508666, 0.05708797340048477, 0.029262610150908586, 0.03605911879276391, 0.046765163060626946, 0.021622819513140712, 0.043711533362511545, 0.019414221424085554, 0.060843533792649396, 0.06045740548870526, 0.039245307198143564, 0.013266353562357835, 0.06255248095840216, 0.04292533551051747, 0.03183470660587773, 0.04408216933370568, 0.03088542365730973, 0.0739050620177295, 0.018248324122396298, 0.03828328714007512, 0.10880450456170365, 0.021362266306823585, 0.0291496014688164, 0.04180961666861549, 0.05279031494865194, 0.006922548045622534, 0.15477013337658718, 0.0624901925039012, 0.08613429759861901, 0.1067500097269658, 0.19374246010556817, 0.09563510888256133, 0.09191192468279041, 0.122615011932794, 0.13592930452432483, 0.08681862454977818, 0.3295962733682245, 0.1982484690961428, 0.10275162232574075, 0.17655415664194152, 0.10318443542928435, 0.18479852675227448, 0.11902211175765842, 0.17739270930178463, 0.09180297740385868, 0.169217670627404, 0.1896789640886709, 0.15862392814597115, 0.1173321895475965, 0.12291978971916251, 0.14561094751115888, 0.14359456195961684, 0.07547969158622436, 0.11107263402664103, 0.12246997401234694, 0.11555783319636248, 0.08866946664056741, 0.10572531158686616, 0.1030374901893083, 0.11311379246762954, 0.20791293878573924, 0.13147159450454637, 0.1379812092636712, 0.20342934265499935, 0.13225497590610757, 0.09412104598595761, 0.08930044059525244, 0.12497085583163425, 0.12125215420383029, 0.19608021044405177, 0.17454390123020858, 0.0826280060573481, 0.07280422694748268, 0.11560803206521086, 0.14228508691303432, 0.24154083745088428, 0.1594714607927017, 0.14788693631999195, 0.11186162606463768, 0.19056133314734325, 0.08550373182515614, 0.08254541986389086, 0.1327982428483665, 0.145090909791179, 0.17572306998772547, 0.06286499934503809, 0.18307426536921412, 0.16606798104476184, 0.07831619484932162, 0.17767381999874488, 0.10579956346191466, 0.1687949729966931, 0.26107193785719573, 0.08481040262267925, 0.08898775151465088, 0.1404492955771275, 0.28185453673359007, 0.14998708065832034, 0.18050717655569315, 0.1343062869273126, 0.13936568575445563, 0.14130721829133108, 0.12544327735668048, 0.11881977261509746, 0.19195317174308002, 0.10910806522588246, 0.15451143553946167, 0.09856578326434828, 0.09564020743709989, 0.16106759780086577, 0.061973835836397484, 0.11266703440924175, 0.16946657211519778, 0.14016603265190497, 0.26103548356331885, 0.1729650265770033, 0.11925397353479639, 0.17001476691802964, 0.09636000904720277, 0.17313295975327492, 0.18952688318677247, 0.2212351278285496, 0.2139190657180734, 0.3234940383117646, 0.24300019664224237, 0.12424876098521054, 0.14370160934049636, 0.09325113758677617, 0.16115416190586984, 0.13240793254226446, 0.1505175678175874, 0.10838225221959874, 0.11359025869751349, 0.11946974555030465, 0.1453451398992911, 0.19241978967329487, 0.1299793878570199, 0.08118734156596474, 0.15810856595635414, 0.1545020696357824, 0.25866108597256243, 0.1894191381870769, 0.2194745308952406, 0.28255218523554504, 0.15240397362504154, 0.1317958239815198, 0.15605931810569018, 0.19005265028681606, 0.1365408638957888, 0.20296325907111168, 0.11512404045788571, 0.13973926805192605, 0.20142883906373754, 0.09045048005646095, 0.14294828491983935, 0.13594067422673106, 0.1378667849348858, 0.12943338981131092, 0.19120679382467642, 0.11390504805603996, 0.21432669775094837, 0.13941443001385778, 0.08053923142142594, 0.1707786595216021, 0.07988920653588139, 0.1428166130790487, 0.14665074093500152, 0.24689258309081197, 0.08563575247535482, 0.1444254704983905, 0.10198933276114985, 0.20110898825805634, 0.11456256863311864, 0.14362653368152678, 0.139024906384293, 0.1402959381812252, 0.14844129094853997, 0.11134057160234079, 0.0660081728710793, 0.16366330382879823, 0.12798814626876265, 0.12708993977867067, 0.12182089907582849, 0.1287084599607624, 0.18372339225606993, 0.1253236728371121, 0.11316386517137289, 0.2108798670815304, 0.11035177856683731, 0.14156619814457372, 0.167172905348707, 0.2252019220031798, 0.15777636581333354, 0.18252598150866106, 0.08407852626987733, 0.13543408422265202, 0.25736069481354207, 0.1167002359579783, 0.10558035530266352, 0.179461074876599, 0.14195597410434857, 0.12980973289813846, 0.24693037325050682, 0.17469645710662007, 0.10949280942440964], [0.014701874042657437, 0.08115235672448762, 0.019776422886934597, 0.05081053954199888, 0.054266023653326556, 0.03576981478545349, 0.04534718602371868, 0.024730041550355963, 0.09917835195665248, 0.03818436998699326, 0.06165982202219311, 0.01519818159067654, 0.05129852761456277, 0.04002707813924644, 0.03452446129813325, 0.02904062635934679, 0.0162535295021371, 0.020165067071502563, 0.030980049341451377, 0.0365851975948317, 0.002655910670910089, 0.04466194994165562, 0.02895726833230583, 0.014893268362357048, 0.06464606471126899, 0.0771948393958155, 0.06090856077207718, 0.04935136588755995, 0.024559390258218627, 0.10121466417331249, 0.008430536927335197, 0.05377960151236039, 0.03205040440661833, 0.0369357881572796, 0.0372099597734632, 0.020154652884230018, 0.06528161771711893, 0.0277147888118634, 0.03032397224160377, 0.021904058230575174, 0.0708581821527332, 0.08146556530846283, 0.02458186248986749, 0.030808941628492903, 0.0222068173752632, 0.024958413378044497, 0.11633840185822919, 0.054030298997531645, 0.038509690421051346, 0.02845989765773993, 0.020817728436668403, 0.056899122791946866, 0.04243397437676322, 0.0056689655320951715, 0.016071797945187427, 0.09846154120168649, 0.027879796070919838, 0.010778826690511778, 0.07880987890530378, 0.05722703703213483, 0.03135028455290012, 0.0394181274168659, 0.07364254954154603, 0.09274226918932982, 0.040321907436009496, 0.03243861072405707, 0.007287094695129781, 0.07957390509545803, 0.07555687494459562, 0.04267381795216352, 0.03084644235059386, 0.09631955457734875, 0.03180735475325491, 0.06809037950006314, 0.021680065074178856, 0.011716407825588249, 0.012357810810499359, 0.008652467840875033, 0.034937540694954805, 0.0540159681258956, 0.018607325073389802, 0.04865523136686534, 0.02618068607262103, 0.033360647576046176, 0.019972912050434388, 0.029792316199745983, 0.05072322586784139, 0.036008240858791396, 0.040605597096146084, 0.06277601583860815, 0.05595528535195626, 0.018497975179343484, 0.015345017363870284, 0.026516669313423336, 0.1053664089704398, 0.062407769582932815, 0.02260052671772428, 0.0873928761575371, 0.04931693023536354, 0.03759290055313613, 0.07622693781740963, 0.03462069187662564, 0.03102736682194518, 0.02340659557376057, 0.03103145420027431, 0.03374526932020672, 0.028726382479362655, 0.0776871875859797, 0.037367758923210204, 0.012932716435898328, 0.06139101242297329, 0.013613204628200037, 0.08121969920466654, 0.03137894629617222, 0.09969540624297224, 0.10527443460887298, 0.06155880830192473, 0.04601463282597251, 0.03802913495746907, 0.03161339074722491, 0.02730186897679232, 0.028767272960976698, 0.04519909787632059, 0.019798509201791603, 0.015682951525377575, 0.03067120644118404, 0.03601627831812948, 0.0259249141527107, 0.019353461793798488, 0.03728149909875356, 0.021562514448305592, 0.07106468474376015, 0.08194820620701648, 0.06608241732465103, 0.05454712692881003, 0.050112557073589414, 0.06571247155079618, 0.04242394796165172, 0.013296116467245156, 0.03628023056080565, 0.05612242443021387, 0.012414316079230048, 0.05878985160961747, 0.0553242297610268, 0.028171309822937474, 0.035739327358896844, 0.06751103675924242, 0.07686099910642952, 0.018635810556588694, 0.03238646742829587, 0.044668506816378795, 0.039384957126458175, 0.04024096509965602, 0.014154534565022914, 0.018836760027625132, 0.0014469050256593619, 0.10961000938550569, 0.02856703409634065, 0.0663825344236102, 0.07134989951737225, 0.04411819689266849, 0.0530719748348929, 0.045247081434354186, 0.04632342192053329, 0.014683151512144832, 0.025999752324423753, 0.046189824206521735, 0.07742940259049647, 0.042035418809973635, 0.022592435452679638, 0.01811209920560941, 0.01129628173657693, 0.0423510059772525, 0.04606743292242754, 0.014945611110306345, 0.07186308721429668, 0.0628696674539242, 0.04020847016363405, 0.02864080172003014, 0.05963007781247143, 0.07879430122557096, 0.05031602799135726, 0.07765824382659048, 0.03970367615693249, 0.0857851022738032, 0.04509734200837556, 0.04329494731791783, 0.03733255885890685, 0.0356685598671902, 0.0786328173126094, 0.02273524321935838, 0.08171555775334127, 0.03864511010760907, 0.028372344640956726, 0.01740786599839339, 0.044907248302479275, 0.039047695536282845, 0.016853372217155993, 0.053110002481844276, 0.025760706557775848, 0.09814885212108493, 0.017114227848651353, 0.041752953693503514, 0.0565296000422677, 0.05324070581991691, 0.01183882601253572, 0.061597066014655866, 0.056911149295046926, 0.009474876005697297, 0.04979681034456007, 0.051534552840166725, 0.07621898199431598, 0.057284776121377945, 0.033864821889437735, 0.057071738920058124, 0.041837658718577586, 0.01576956572534982, 0.04929035021632444, 0.058146595110883936, 0.01042543915900751, 0.03613344859331846, 0.028414532025635708, 0.012611542751983507, 0.08954514894867316, 0.04599340369168203, 0.0488430503901327, 0.07047442501061596, 0.00036855592838946905, 0.03131711797323078, 0.031885818316368386, 0.03568059008102864, 0.08007423879462294, 0.01445381860321504, 0.010133165633305907, 0.030918367592676077, 0.049163042203872465, 0.022363377138390206, 0.018391254343441688, 0.04552602506009862, 0.050336485292064026, 0.018937890636152588, 0.02719123145652702, 0.0308895685520838, 0.031087840725376736, 0.022466392802016344, 0.02246116622700356, 0.033092183075495996, 0.024195752739615273, 0.014332188948174007, 0.05658757661876734, 0.07095332548487931, 0.01964015158591792, 0.05431592566310428, 0.04636247373127844, 0.027733336937671993, 0.04910864277917426, 0.034816366533050314, 0.029676760095753707, 0.04613736178725958, 0.032820534761413, 0.06899158426676877, 0.05772552278358489, 0.06449117106967606, 0.0270875923888525, 0.07908888190286234, 0.02361760114581557, 0.036568462164723314, 0.02104947889165487, 0.03225506276066881, 0.021201951276452746, 0.04358434038294945, 0.10128503461601213, 0.10116037607076578, 0.072654632240301, 0.03374054555024486, 0.046184154198272154, 0.07340451309573837, 0.04090032620297279, 0.07037588264211081, 0.04702974241808988, 0.018245153296447825, 0.028197496503707953, 0.06337172293569893, 0.0629474593733903, 0.029791460874548648, 0.045315440656850114, 0.08983448264189065, 0.009460904147999827, 0.05560455007071141, 0.009276994387619197, 0.07521692677983083, 0.041226733883377165, 0.039101597722037695, 0.01860967582615558, 0.07784009969327599, 0.016132019518408924, 0.017748585996741895, 0.015293844426196301, 0.028823280990764033, 0.02041730080236448, 0.000753119344381048, 0.0330220018804539, 0.03473397700872738, 0.054376280822907574, 0.030506594375765417, 0.03642388808657415, 0.0029418290932881064, 0.04027616887469776, 0.046173404189175926, 0.03229750247555785, 0.07238829028210603, 0.024038538031163625, 0.03948151053918991, 0.07100312359398231, 0.015115061978576705, 0.08398451842367649, 0.036316146797616966, 0.02866600134439068, 0.01647523313295096, 0.02341771480132593, 0.05953340194537304, 0.0625582474458497, 0.02809808953315951, 0.024540899648854975, 0.01859978485299507, 0.037445565685629845, 0.03770732117118314, 0.04768593455082737, 0.015130989395402139, 0.0009864486605692946, 0.008343501558556454, 0.028432109793357085, 0.03916052795830183, 0.028383875760482624, 0.025082737956836354, 0.006455576203734381, 0.021569620512309484, 0.03963430390285794, 0.05679772686562501, 0.043983793948427774, 0.014619093035435071, 0.01003523553663399, 0.06751324835931882, 0.054289687031996436, 0.045404468692140654, 0.019899547041859478, 0.0272509038404678, 0.08571149606723338, 0.06545284602907486, 0.044818494861829095, 0.026569218935037497, 0.11499924832605757, 0.11198018415598199, 0.22864109370857477, 0.1278105948586017, 0.2206225146073848, 0.26056294329464436, 0.21600660838885233, 0.15827574214199558, 0.13233937293989584, 0.18526584230130538, 0.16667685384163633, 0.14134330151136965, 0.14583448239136487, 0.14062781177926809, 0.11973397238762118, 0.08302556714625098, 0.14829200052190572, 0.07130666199373081, 0.10290121703292243, 0.08671782605233602, 0.13799804117297754, 0.14360967208631337, 0.16747967951232567, 0.20125367736909539, 0.1169357416802086, 0.2483724255580455, 0.17033896670909598, 0.16197787161218002, 0.16510799818206578, 0.1722487501683645, 0.1922884295345284, 0.1677838561590761, 0.09109781836741604, 0.1583349209977314, 0.12209900407469831, 0.08288276309031062, 0.13490702578565106, 0.19314319069962949, 0.11475133389467373, 0.11465835021226667, 0.12640956847462803, 0.14454829593887553, 0.18427883042022586, 0.17828814015956596, 0.14404826652025804, 0.1282735465792939, 0.139921777008567, 0.14931524405255914, 0.24987233569845557, 0.08196790280635469, 0.13661245146067813, 0.17465531243942678, 0.12398268620017916, 0.095709101005923, 0.1866705497377552, 0.21011299104429781, 0.15882838983088732, 0.11368014020263217, 0.23772328917402774, 0.10510639011044987, 0.22830527188489214, 0.07366222387645394, 0.06194842098921072, 0.19706658407812938, 0.2425201903679408, 0.08168887754436582, 0.14487550884950906, 0.08780724689131603, 0.1768247436848469, 0.16802031925180927, 0.18645010219188407, 0.1230813775327988, 0.22490322240628302, 0.09265540080377832, 0.21033468539826572, 0.20777034253114834, 0.2455788926454261, 0.16655756102409214, 0.12503168225521222, 0.11197233965503983, 0.0901708091259934, 0.11620134202530608, 0.1703231144347228, 0.10865761127206497, 0.14961731299990788, 0.166287315369118, 0.09492210534517653, 0.11146312244818546, 0.13058823096798733, 0.1968056449550204, 0.08113832271192223, 0.10062145069241524, 0.07750795150059275, 0.10683104483177885, 0.1402070140466094, 0.31014449370559305, 0.16649532451992854, 0.20806769141927361, 0.19475420034723356, 0.1517960656201467, 0.22423107409849763, 0.1445852845790796, 0.07816898985765874, 0.13525516726076603, 0.10822661643032916, 0.09815530880587175, 0.11295025280560367, 0.19603116932557896, 0.13528402196243405, 0.16786093561677262, 0.1404583646217361, 0.2484232626738958, 0.17224202631041408, 0.212647276930511, 0.2675744576845318, 0.20662590628489852, 0.26511688018217683, 0.11868033790960908, 0.13259685365483165, 0.10814284280058928, 0.13958225928945467, 0.09524681721813977, 0.12720225640805438, 0.14060634886845946, 0.08592951679020189, 0.1390095439273864, 0.17766917415428907, 0.14420934225199744, 0.10615858482196927, 0.10257292800815776, 0.11827132548205554, 0.10408444533823058, 0.23579216154757887, 0.20522060513030738, 0.13890843372792006, 0.1396419873344712, 0.13886331114917994, 0.15727580204838887, 0.18765791784971952, 0.1422428438672796, 0.12858116679126397, 0.1279160095145926, 0.13696795504074544, 0.11182681191712618, 0.17096732830395922, 0.1623625712818466, 0.16817091585835442, 0.13000343344174325, 0.1741764193866402, 0.11200900175026618, 0.1308667886769399, 0.13803491106955335, 0.11777196399634704, 0.10923487599939108, 0.17117349692853168, 0.096452955622226, 0.1678311754949391, 0.28645855374634266, 0.09468584263231605, 0.1005312500637956, 0.14020260568941012, 0.10712522474932484, 0.16334867774276063, 0.17659104138147086, 0.11309455599985085, 0.13752502592979, 0.06792658008635044, 0.16208560176892206, 0.17273559904424474, 0.10645945149008185, 0.06649761184235103, 0.1402464517741464, 0.1404447536333464, 0.08320085500599816, 0.16047616547439247, 0.1099159820296336, 0.2004659321391955], [0.04686899694206659, 0.07859899764298461, 0.009258582631446188, 0.021071296177979093, 0.06338784980471246, 0.05149613927642349, 0.057922255000448786, 0.07537345314631239, 0.05092707528092433, 0.010979212129313964, 0.04200976276479196, 0.02479334860254312, 0.0036412193230717094, 0.035699989821296185, 0.05115528569149319, 0.03007528041052865, 0.09756224375450984, 0.045905477745691314, 0.07785897993016988, 0.03502741477859672, 0.001602022123279312, 0.03619744769821409, 0.022884053105372004, 0.08978107769507915, 0.06668423229712062, 0.04937769357638899, 0.026825289569387678, 0.027519303403096274, 0.03884166420903057, 0.0529268552782014, 0.06137662960099988, 0.030635726216132753, 0.03367073913977947, 0.03010276770510245, 0.039500643106293865, 0.03194031793100294, 0.01688283733528806, 0.052089875971432775, 0.07111411920050159, 0.05355706853151787, 0.05366036064515356, 0.041896503607858904, 0.03361901886819396, 0.020548256470647175, 0.03731695149326697, 0.02624866865517106, 0.024685495991434436, 0.0351757478347281, 0.014724522534379503, 0.11577448094612919, 0.04419433382281568, 0.021329697156033944, 0.011412888907216256, 0.03337635142088402, 0.04679780642618425, 0.03786234839935787, 0.08660411418532021, 0.08294257277157158, 0.04846603194891941, 0.05573060756432824, 0.02475676443282282, 0.03360128896019887, 0.043908031802857295, 0.03727386239916086, 0.018812729285855312, 0.041234526433981955, 0.02629995477036573, 0.010984687323798425, 0.020305403486418072, 0.06279465116676874, 0.07724924624199048, 0.07179816413554363, 0.07159704953664914, 0.043997312168357894, 0.049284787819487974, 0.07892946116044186, 0.021446830323839094, 0.02697209936741274, 0.04878100684436504, 0.02048360613116529, 0.0368776928371517, 0.02769398270174861, 0.06140397774288431, 0.03541071178915445, 0.044461655415943824, 0.017202458075189497, 0.06878220214275643, 0.02877961116610095, 0.0649579225864727, 0.0700810199487023, 0.09089986531762406, 0.07134092695196159, 0.029102627231623046, 0.023042703869577963, 0.06945085493498482, 0.07435668114339933, 0.027505306497914717, 0.05608378822216764, 0.018204073567176238, 0.1493182423291728, 0.018696173137868755, 0.021764755256299395, 0.04982107857358642, 0.040531671766075306, 0.03557277457730379, 0.010138770703633782, 0.007319160577026196, 0.043296869480400346, 0.07234887481899932, 0.06952190073207021, 0.026248022986692376, 0.033120355001301505, 0.019284262089058757, 0.026547180859779473, 0.03817940872977488, 0.06567498567164876, 0.0296732423157664, 0.02570707340055378, 0.04308910152758472, 0.005709304969059303, 0.08097516154521145, 0.040752568311290815, 0.10289625948644243, 0.06624816858675331, 0.026285807580279652, 0.016737185287638567, 0.03143124173220713, 0.03593204455683008, 0.023624078239663504, 0.06992375885602087, 0.030686967802466825, 0.021063423846499063, 0.015373808055301197, 0.021762335854873527, 0.04945937434968073, 0.02487025922164321, 0.052922636168659665, 0.01405963799697929, 0.02728145249420777, 0.03188443792168982, 0.024881445242499467, 0.028158229470136575, 0.048966417598421685, 0.013641601053677732, 0.06739168456988409, 0.028296144628257025, 0.03652678686194122, 0.022326323560264427, 0.07904122117906809, 0.025912928467732854, 0.029075392267259303, 0.06550507096108049, 0.07309895605430938, 0.05009173240978271, 0.04686167565523647, 0.07727513977442868, 0.03479344530205708, 0.03335091802000534, 0.055129582979134284, 0.031874663836788386, 0.0774330242711585, 0.014757562948943814, 0.05876460374565795, 0.07136980391805992, 0.039924097727634944, 0.032175753149203956, 0.013507312214642297, 0.07091016217600554, 0.03591405489714816, 0.021269241806294303, 0.02907810852775583, 0.03190603441908024, 0.023630564610357396, 0.09407447621924803, 0.04196939364192076, 0.0620042416267097, 0.03703030066390056, 0.0339629189693369, 0.01101001867937157, 0.008514707606082084, 0.03435758568230085, 0.04362581530585885, 0.030784224400122184, 0.10188878659391776, 0.023085798529791646, 0.04822544251510408, 0.04253548904671334, 0.05225563465501182, 0.035854831512551755, 0.04657421217416413, 0.04310313925088849, 0.024137572072504554, 0.02861731089069508, 0.043326050727046095, 0.05108634017233271, 0.05159941654710565, 0.03383051240234636, 0.0735072189127095, 0.043341509663150646, 0.04471248648769688, 0.11134232307085767, 0.04615768550138455, 0.017220174995600246, 0.04703573154984042, 0.04324158318922855, 0.03941777118598111, 0.029950571770314127, 0.04472872838960029, 0.10767404295620508, 0.08448224718449637, 0.03343447642691899, 0.06602718669455498, 0.025344050009152852, 0.08539618720533326, 0.022766281690564938, 0.06758444258593954, 0.057621302985353395, 0.009176371222565649, 0.039964641255210154, 0.03043998291104799, 0.012021913844364462, 0.054892036350793205, 0.010561778180999681, 0.03803994804911781, 0.028880879071948584, 0.0701124499028083, 0.04398389413836412, 0.0317148683097912, 0.02836989184288541, 0.028920858567289542, 0.04474181987461634, 0.0724711584916804, 0.028894952047266997, 0.024653652289998718, 0.02264540809846949, 0.06307222924078815, 0.03591079686884768, 0.04506643155764323, 0.046068056326475926, 0.04297977946407627, 0.018971491372212768, 0.020560212469717953, 0.06155349823529832, 0.015484962295886362, 0.02768971535260789, 0.04297369385312777, 0.02714432957873214, 0.02781200088065816, 0.049050729285227135, 0.0855918247543741, 0.063507862505503, 0.04240472262608819, 0.04959009624144528, 0.027021121932193637, 0.07379218135611154, 0.059939141501672566, 0.03039818700926844, 0.05094588872452732, 0.09477117477217689, 0.07553515970357694, 0.05557904987654183, 0.0022708322740072617, 0.011020953297702363, 0.04065954010002315, 0.10999440477462485, 0.06011218065395951, 0.09058397758053616, 0.10797168128192425, 0.07114783496945165, 0.07960906063090079, 0.1128994305327069, 0.060788496120949276, 0.06551176513312384, 0.03686604482936673, 0.025983708947023842, 0.05492616030096542, 0.06882957342895679, 0.03692101199703757, 0.07613982452312484, 0.026433986640768126, 0.0636729013058357, 0.026577263815852348, 0.06013387734128628, 0.03291039771283977, 0.052879406066494994, 0.011106821639259579, 0.02761203475529328, 0.04128022788790986, 0.030568101719836704, 0.03766369030927308, 0.026132574494113214, 0.06040812688297592, 0.04983511629689019, 0.04911417177936528, 0.06670253365882672, 0.02621151303173974, 0.04244898802426178, 0.058952029430656694, 0.06661262988927774, 0.07824773172615096, 0.03658111578261014, 0.022535028474521823, 0.03589712279790547, 0.027186429761059117, 0.03309564148366917, 0.07544168620370328, 0.017039718077285215, 0.0361587150109699, 0.03254437790019438, 0.03264897248300258, 0.04867009658482857, 0.026220160907541867, 0.006765418220311403, 0.02520838170312345, 0.06956767640076578, 0.018678669584915042, 0.013420866853266489, 0.042373229589429684, 0.10240722869639285, 0.02464252193021821, 0.060984408264630474, 0.09621649995096959, 0.03950816848373506, 0.05064516306447331, 0.04420250857947394, 0.011063906949857483, 0.0479636833188124, 0.04036805417854339, 0.04400359815917909, 0.04973392446117941, 0.03886608828906901, 0.01642446095502237, 0.026437684391567018, 0.02625250184792094, 0.03632022489910014, 0.042236451772623695, 0.03500378479657229, 0.008714760006114375, 0.028293289215071127, 0.07993808438186534, 0.01561095763463527, 0.05792361313069705, 0.018549856868048664, 0.04177080234512687, 0.035217801632825285, 0.044937153143109754, 0.039863987476564944, 0.03536385629558936, 0.014376888502738439, 0.04179241368547082, 0.03927838472009171, 0.014750233312952332, 0.10274451255099848, 0.14061795605812222, 0.06179977623105515, 0.09959705683286302, 0.14522780635161325, 0.14777700940612704, 0.17470459104515612, 0.19718362076673657, 0.06460513526690193, 0.09996772991144098, 0.18077455752063543, 0.13498170068487525, 0.13493064092472196, 0.25023043679539114, 0.14218354626791552, 0.16754725947976112, 0.13473740051267669, 0.1095154152426403, 0.15641358972061425, 0.1736471345066093, 0.08274495368823409, 0.10958348502754234, 0.19712413020897657, 0.23155299917561933, 0.170933204353787, 0.16125697904499248, 0.14758701960090548, 0.13435571396257728, 0.1672641301411204, 0.21549875673372298, 0.11932616966078058, 0.102573937328998, 0.22334422246785834, 0.17540988366818056, 0.09720049129100516, 0.17635462281759828, 0.10951989039313048, 0.1374131694319658, 0.14050227007828653, 0.16549265332287177, 0.24450798839097843, 0.1683138683438301, 0.10830257524503395, 0.12589330086484551, 0.0506009013770381, 0.05948927013378125, 0.1608473580563441, 0.0706950284074992, 0.1153886086831335, 0.15868981601670384, 0.17160254734335467, 0.1364723636652343, 0.08045221460633911, 0.08808499565930106, 0.1945454638916999, 0.12285176446312107, 0.2193760478985496, 0.11477054809802212, 0.11439516980317421, 0.152625014889054, 0.09588707544025965, 0.1514055029838346, 0.14667729497887194, 0.10920039581833407, 0.09556603719829582, 0.12148362264269963, 0.11902233440196142, 0.20562069694278762, 0.12313576953602023, 0.15837199869565666, 0.18896984198363498, 0.17376360716298223, 0.14180864294758067, 0.2959813177585602, 0.184769464249257, 0.09617933319532312, 0.13827302173012868, 0.14642395544797182, 0.26014564849901944, 0.11548603040864691, 0.12042712347465567, 0.1109916360292118, 0.24803636624710634, 0.24629686115076765, 0.1761101296870038, 0.1264246043865569, 0.17506975738797337, 0.15269896248355508, 0.15959814540110528, 0.1473135084961541, 0.1528582867467776, 0.22398739733034745, 0.2289836245472543, 0.1877495730877854, 0.26713884668424726, 0.16938610846409574, 0.23149034706875682, 0.09336174727650359, 0.09379985189298168, 0.23316565639106557, 0.15025588654680178, 0.17417542490875348, 0.1255611452506855, 0.1426243968307972, 0.14098172716330737, 0.11032561786123551, 0.20354197098640725, 0.14070034929318354, 0.2774255775148049, 0.12460371537599713, 0.07933722677989863, 0.09600022327504121, 0.1267428818391636, 0.180966580810491, 0.11472133628558367, 0.11923033613129519, 0.16707163187675178, 0.08745828905375674, 0.23937520600156859, 0.20569412503391504, 0.22705941373715177, 0.09972797910450026, 0.20033691718708724, 0.14864728145767003, 0.1364449635730125, 0.07669405298656784, 0.2026774876867421, 0.09284264466259629, 0.21861994784558192, 0.15084040205692872, 0.09556176242767833, 0.05199895545956679, 0.08355462938197888, 0.11884193314472213, 0.11491364159155637, 0.11445073439972475, 0.11170078039867803, 0.1023187127429992, 0.11542329666553997, 0.06200554038514383, 0.1113599342352245, 0.0847006167168729, 0.20796600234461948, 0.08981712380773388, 0.12516091985162348, 0.2138380825635977, 0.10422857041703537, 0.15358496806584299, 0.18513612973038107, 0.07732611789833754, 0.1163878437364474, 0.17439458111766726, 0.16561449912842363, 0.11782460453105159, 0.12013084327918477, 0.14590333885280415, 0.069376009341795, 0.11128911850391887, 0.1381813219632022, 0.10879542809561826, 0.23999590863240883, 0.14807642146479338, 0.2082344371592626, 0.27295087231323123, 0.1431521528866142, 0.21434020483866334, 0.15932270471239462, 0.3075420786626637, 0.10918279949692078, 0.11520142419612966, 0.10160048448597081, 0.11850423368741758, 0.12818824412534013, 0.19230159523431212, 0.22483084816485643, 0.16034293512348086], [0.07711455386015587, 0.02992196754348697, 0.0063092223626881605, 0.02332235253561521, 0.04938950856740121, 0.07071958607411943, 0.06578157292096876, 0.04167400773440022, 0.020408255877555348, 0.03987232550571207, 0.028175840634503402, 0.03660486821900122, 0.013209768512751907, 0.019956415962951723, 0.03461976790276822, 0.019203633310098667, 0.03443818663072307, 0.052447450143517926, 0.009146099946519826, 0.03841189762169961, 0.10231497974018566, 0.0296739733312279, 0.027644101101031993, 0.04276415958884172, 0.03211914583516773, 0.007249869959196076, 0.014113588422333123, 0.0386280184466159, 0.0035166055386071093, 0.021584556234302, 0.0205017071129987, 0.06825344418757595, 0.06712434071232565, 0.0035114728916596505, 0.09456450148718432, 0.01648607776587596, 0.048818759896676056, 0.01683109479927225, 0.04284637099772226, 0.06810131875681691, 0.031420372979482636, 0.08596059793489985, 0.06896986160427332, 0.049717871806933545, 0.041454847814748064, 0.03987352778494824, 0.05318543437169865, 0.015502758069487754, 0.03072829800657928, 0.0439344559708843, 0.05352707092242781, 0.0927204055187758, 0.04373030969873071, 0.01814761468267534, 0.05672637307725381, 0.0435439601278631, 0.002891847998398589, 0.023918649640108924, 0.04463887285965029, 0.04649691378290299, 0.0980246759718284, 0.07674418506212533, 0.05632111962768249, 0.021742351673310623, 0.00839902255393099, 0.07513562450185418, 0.020111727062612772, 0.04469844505365472, 0.0337539487372851, 0.025409177178516984, 0.039550367000629194, 0.040320894404430874, 0.03973434169893153, 0.048417313664685935, 0.022165845257404726, 0.06020881570293568, 0.009367849033878883, 0.007034338213998126, 0.0342639118025545, 0.046492794863297604, 0.0355756058706902, 0.025460507822572254, 0.02123421429132577, 0.03855845323414542, 0.025111739232670516, 0.03061979416088434, 0.020358749061415438, 0.058473180906730704, 0.11583915169467218, 0.05700222936866339, 0.02338786747714039, 0.024279056960949674, 0.03996240739070345, 0.04765297577250749, 0.05443981979624368, 0.09318393611465581, 0.07487031412892975, 0.0577183276618598, 0.09341630255221389, 0.030034237788640894, 0.05003832746297121, 0.03463006891252007, 0.036287399707362056, 0.011333187812851975, 0.018902883530245163, 0.027370864590920974, 0.0297405680976226, 0.007881189012550749, 0.06800523289712146, 0.05999813482048921, 0.05173804973310325, 0.025221046453225426, 0.05521118582691997, 0.04835335166717414, 0.06295753773883916, 0.04558917811664287, 0.018267740560986567, 0.11980001610936597, 0.04143771162489429, 0.028420973867469, 0.02588092891528504, 0.0136615713199717, 0.03208895897842012, 0.029319069035409484, 0.05282627200358547, 0.05761502812674735, 0.05420519351901021, 0.036526196854538284, 0.040243673938675784, 0.026885051011049654, 0.0070789176334074, 0.05797516641905531, 0.028792032862838823, 0.05965657990600448, 0.012670513806369854, 0.02940401896921685, 0.07397636756650172, 0.11629523854935542, 0.04561484158330131, 0.02850238190148957, 0.04860947796260007, 0.04406759726407472, 0.03451784505159594, 0.021364064159570262, 0.08682179352035746, 0.07985655203810893, 0.04332697099016514, 0.04703966864326503, 0.053685716120526195, 0.03545019033481367, 0.047115538400248624, 0.04364270658697933, 0.05636234593112022, 0.026721101312432438, 0.018543060650699772, 0.0782125761907082, 0.014351902245834935, 0.011617922045843443, 0.10687618225347251, 0.04524440228124149, 0.08234270964749157, 0.03692434052936733, 0.09118691319599748, 0.02573102250607917, 0.06319328094832599, 0.008474823662254494, 0.03467027847364079, 0.009517963244434213, 0.02081879341858439, 0.06007685442455113, 0.02099619454384083, 0.017224240109499078, 0.04544637034996413, 0.018761971950880252, 0.010426469816593453, 0.06589714015717618, 0.09244122440577485, 0.022425123825087212, 0.05559658682614099, 0.035284027180750854, 0.03589012434531469, 0.01391363621223718, 0.036354189287521876, 0.09239697756129317, 0.0888257406768389, 0.01410691837008926, 0.059055737146991305, 0.11921473618713208, 0.004605877020367188, 0.01384529276037938, 0.020447934803087264, 0.026342136588937137, 0.05773007214884274, 0.05855912160768639, 0.03628193007898517, 0.06325983675196767, 0.012771026576956501, 0.007770187839923892, 0.05251009111816529, 0.045896802039351314, 0.04140189186728094, 0.020069255806447472, 0.0447141192125855, 0.007557690087196534, 0.06899493877426721, 0.01968349486560328, 0.038357728262781166, 0.02906377580075059, 0.08079161358182319, 0.05092821447760798, 0.07792834105202928, 0.029000559661653824, 0.04988605731341522, 0.006116902213761932, 0.022083594885771163, 0.01716780348942848, 0.06912289245519787, 0.04654851902159862, 0.02899105274991598, 0.05739453605201561, 0.03675814768939745, 0.017878055514302105, 0.05639174982206896, 0.03044092172785895, 0.024530637601856142, 0.0482052746519912, 0.03141849534586072, 0.025661073232186027, 0.0817705063673202, 0.03089682119025383, 0.05607146114925854, 0.026868536369875073, 0.02331010709895054, 0.04956194286933169, 0.013852159481757553, 0.032421493087895215, 0.12154878320870921, 0.023142029203881975, 0.00562601002457086, 0.07285082640009932, 0.05370218808820937, 0.0673168760840781, 0.0465197088487912, 0.0435124670912046, 0.028093827750126366, 0.046556842207792215, 0.012630006458493881, 0.040070093018584885, 0.0737654566182755, 0.028467810807342175, 0.025972595285566058, 0.038130553148221225, 0.02442504668579204, 0.046579266199842095, 0.022869664717291016, 0.016848579798534047, 0.05768408867879771, 0.05786748821265064, 0.01264752856513951, 0.02857960051187547, 0.024369598977500573, 0.06496252390206791, 0.03194950942997821, 0.06686574677587487, 0.0502171998959966, 0.08616478502517566, 0.033245451413677074, 0.04935712495353073, 0.045016600051894784, 0.050718591155600734, 0.00673708116664784, 0.040931188414106146, 0.03312738685053773, 0.025644534471211955, 0.03929015147150494, 0.08189543208573014, 0.06839986992417835, 0.04638485690520611, 0.027727798660635017, 0.009964993114408571, 0.03188334325386677, 0.008393850712309359, 0.0934990297537297, 0.030237350620154757, 0.07129047575290315, 0.033263411387451924, 0.0555752278160071, 0.017486047545389738, 0.04438422714883927, 0.033026551245711744, 0.039260617704712786, 0.040091359260259196, 0.03634424450865481, 0.041707615891937166, 0.02972022026369814, 0.08611548415501602, 0.0416027689789189, 0.016501618338224944, 0.03853821115626488, 0.0369099836825626, 0.02823070390149951, 0.044897040061187, 0.06355064731906168, 0.05099074784084223, 0.05827232977026142, 0.029332436970435083, 0.004801373561349465, 0.01712502424197737, 0.03493234937195666, 0.07966922654304653, 0.09611472181859426, 0.0766201202350203, 0.02570971173554426, 0.0276723398201284, 0.031924833019729704, 0.05111637859954499, 0.05440913198981434, 0.05274219780403655, 0.020035898123751394, 0.019898075734090526, 0.07405489421216771, 0.02797788016323466, 0.028281867562327534, 0.03680581212393008, 0.0443708981765667, 0.006198402552399784, 0.034823242531274445, 0.0048418725600640755, 0.008453700284007937, 0.021668058980139904, 0.01696486691798782, 0.035381422931095585, 0.07423317292705178, 0.03310534877527971, 0.09744898459757678, 0.030120351038931403, 0.03720240842085332, 0.03515805132337846, 0.04163436220551375, 0.05298093557939865, 0.06114507581514772, 0.03921503870515153, 0.04296612765756436, 0.035346901931916364, 0.023882340065028984, 0.042234570428263396, 0.030482788133667782, 0.03505347158352379, 0.08723924416699447, 0.043659089496941306, 0.057306684320792556, 0.021447474136948586, 0.22289170534349978, 0.08482631426886655, 0.1653665179037489, 0.13311974122188985, 0.2186591480858624, 0.1362206568592228, 0.09826992609305307, 0.23660341801587492, 0.21632809191942215, 0.08119064412312582, 0.14845218567643315, 0.17099376360420138, 0.0624417896324303, 0.10354587619076483, 0.1385792763903737, 0.06781773670809343, 0.16427223599748686, 0.16188519221032038, 0.09720731162815355, 0.11409436250687577, 0.1644231443060562, 0.12292977160541341, 0.10804483477841131, 0.14721532235853374, 0.10738497643615119, 0.13243464985862374, 0.11210539931198582, 0.1273878972278908, 0.1430956309195608, 0.15007704379968345, 0.07323862082557753, 0.16808295651571825, 0.1916949191945605, 0.2088339440524578, 0.2070091661880724, 0.0641560171789024, 0.21405389910796657, 0.09051224158611149, 0.16893011808861047, 0.18027601239737123, 0.11705207332852297, 0.2378540110657923, 0.1998846820788458, 0.19290165131678805, 0.09705016927910037, 0.11107532802270725, 0.18953921768115833, 0.09787961578695104, 0.069566874881275, 0.16801714285975322, 0.12096577425836585, 0.16314804553985596, 0.15648740372853354, 0.1850653436849825, 0.17987519328016788, 0.11325447398121469, 0.09543708903947845, 0.11681433374178596, 0.07999599416507408, 0.16438351362012327, 0.19837766216369346, 0.20146150840446353, 0.09692417486803606, 0.09738196866237558, 0.1686381720355712, 0.22827043547295034, 0.1566001953324303, 0.16889499966055155, 0.12358165186014958, 0.1758449009503238, 0.16909776924876496, 0.1800319497124292, 0.1434277865337208, 0.1522941654548049, 0.1129860094806645, 0.14962081593694165, 0.10064942965982482, 0.11535668149008416, 0.12293050633161329, 0.10508884573937394, 0.13053279253654182, 0.12729070556815714, 0.04685227635491174, 0.12686630099778995, 0.15037408098578453, 0.2020000701304525, 0.14913537714164704, 0.19275734812254086, 0.18557505070930347, 0.15869320021010935, 0.09493997626123019, 0.1516127699869685, 0.195089710468892, 0.18557828647317365, 0.10271545746945776, 0.136823310458567, 0.19135838490910828, 0.11292519790004008, 0.21900668099988252, 0.14560769690433517, 0.2606907411245629, 0.17997474496951327, 0.10555254702921957, 0.045500257692765445, 0.06193362256453838, 0.08653735058032908, 0.15941807068884373, 0.09508278773864731, 0.29080311593133956, 0.09084794466616586, 0.23385619511827826, 0.07528278496465646, 0.21482993324752897, 0.1627485326025635, 0.10526765137910843, 0.11192780337296426, 0.13304423511726782, 0.2462344613741152, 0.09278785189962946, 0.28395454748533666, 0.2313695105840452, 0.1377262221649289, 0.18102068337611854, 0.11704380580340512, 0.10996205455739982, 0.09296910662669688, 0.12447403249097988, 0.13730206992477179, 0.09745941177243367, 0.07201616259408183, 0.14284781296737492, 0.1713758212281391, 0.15010569070000201, 0.2727036183932796, 0.15309614507714286, 0.14099597639869899, 0.13808174058794975, 0.17812583246268332, 0.12247580729308538, 0.08135840660543181, 0.21055586024885997, 0.11137811685330234, 0.1556384758441709, 0.14301170886028558, 0.10788364030304365, 0.18720206106081605, 0.13982020667754114, 0.11119483606307767, 0.15591927483910695, 0.16125859692692757, 0.13509487820556387, 0.15463296964298934, 0.13716239773202688, 0.10142017228645273, 0.12243734920048155, 0.17509412951767445, 0.1485726807732135, 0.13166462711524218, 0.16676683182595298, 0.14530504908179864, 0.16892474493943155, 0.11091475695138797, 0.14089835429331288, 0.15565599052933976, 0.21378099656431004, 0.1684333392768167, 0.1057991330162622, 0.07984852942172438, 0.1384606515057385, 0.1373164527467452, 0.06394723619450815, 0.11456484702648595, 0.13393911678576842, 0.09935755835613236, 0.12572075153002515, 0.1827243872685358], [0.03627951809903607, 0.05956643864919897, 0.02337085930776084, 0.04939231017488055, 0.02170776017010212, 0.01638951878703665, 0.002795562222672743, 0.015932012574921828, 0.024931465995905455, 0.03271496796514839, 0.04109247194719501, 0.04406520012707915, 0.05863244579813909, 0.04627712674846407, 0.030412126398005057, 0.029027939344814513, 0.0590725801885128, 0.01339265503702336, 0.05851432928466238, 0.08073440141743049, 0.012732513750961516, 0.035041259543504566, 0.05961778784694616, 0.04960978541930672, 0.024273822964460123, 0.030695422719873022, 0.05403419156209566, 0.06655144723481499, 0.021328756483853795, 0.014099055315455189, 0.06877115898532793, 0.07007103806245141, 0.08595839375630021, 0.02365684962569503, 0.04441958306415472, 0.034961801502504386, 0.023051691277942155, 0.025515768138575368, 0.04043320361233782, 0.047899242636049166, 0.0447539354354376, 0.06963598367292434, 0.07753525511361659, 0.028535945530165918, 0.02737492413871223, 0.05523878258827608, 0.03738208608410787, 0.05682862247340381, 0.07896320661529899, 0.0705446173378732, 0.03409777091292199, 0.04906374655547552, 0.024748923642619047, 0.03445212045335211, 0.09065107515198179, 0.01419753089066944, 0.04341281150118448, 0.007469386109733023, 0.08935780861065723, 0.03162526511005126, 0.06403870589565486, 0.0463695872167591, 0.04206413992505986, 0.057195002227672376, 0.06467332379543222, 0.026896570998360403, 0.025605872287997045, 0.02067783545498969, 0.023763661374687217, 0.04329363000579178, 0.03019188850885257, 0.007610652992298128, 0.06630375544773415, 0.0780143411247991, 0.09264072854421102, 0.03279729811765719, 0.03384408257261384, 0.021284472531988285, 0.04197891539661214, 0.025996666845458094, 0.04676416487200186, 0.03733685218321625, 0.027130481103085913, 0.034609964131959714, 0.042627556176739745, 0.022465556030510925, 0.02323326883924892, 0.041096472123172134, 0.04034720725030638, 0.033038510955520906, 0.03770795570744667, 0.04471528809517622, 0.026731951511465013, 0.07657448557438329, 0.09330626431619748, 0.11539041952346452, 0.04115877913136501, 0.05651486470014788, 0.09815347570111044, 0.04618125611159485, 0.04976511321729049, 0.03356231136422139, 0.02535590025217971, 0.08805176970781758, 0.0843053637072444, 0.010808807601279113, 0.059905425732722506, 0.032821677668835036, 0.058808538888115436, 0.04362787847639993, 0.051942986392532475, 0.0607131755532464, 0.015624765292159282, 0.026247559144394472, 0.04138571304793004, 0.03959316665714141, 0.03565961327694822, 0.04842427500989288, 0.03611647567595355, 0.03547510794305708, 0.024444182963634375, 0.005061955989731359, 0.01083423358068103, 0.0065335068120475626, 0.06505272453068756, 0.014889668946125312, 0.018517499229346868, 0.028688210113614332, 0.021274442406138405, 0.0618493182992097, 0.04353232325229328, 0.03610259751440026, 0.021142479272384662, 0.09766299030161463, 0.017016308884194586, 0.020424534886842594, 0.02250354657007847, 0.014912225597072393, 0.03998710606538225, 0.03795099793933332, 0.048599811489111744, 0.011928917174373055, 0.0416852772468701, 0.041414545485167764, 0.020602950899046846, 0.00892722297066939, 0.021776481189590413, 0.019869259995175526, 0.01782670817192411, 0.011938551178900525, 0.017846052251115907, 0.04593714518705383, 0.07167254079831764, 0.05266983098408673, 0.06869843593449332, 0.025785434918361716, 0.05034332789364271, 0.05615871174086351, 0.022589333275391255, 0.03504757893097121, 0.03452204560744576, 0.010018966731877299, 0.04661665188905317, 0.020138999134360347, 0.03404453666007612, 0.028031949332216755, 0.045251441551954485, 0.007828841626178473, 0.030703218981216196, 0.06053315650206059, 0.03653491708973888, 0.0477908111497527, 0.021378437704697717, 0.014322521547001088, 0.01646369644731749, 0.037629269500030205, 0.02641138453327585, 0.041029593485291116, 0.01296728845773032, 0.007011509287622175, 0.03643485331849661, 0.024311715169460513, 0.05403173876402434, 0.03248280561820138, 0.032088936713989824, 0.02395954568783054, 0.040329432813450694, 0.06817401954322122, 0.030922390033083502, 0.03527789704094175, 0.02946799766505137, 0.013521995606424753, 0.039658089735894464, 0.05512225798156578, 0.0402438038145192, 0.06912209835718386, 0.02669529312697705, 0.03164629757520743, 0.06452522822655737, 0.007881572146288818, 0.04640613798983395, 0.012421706942404853, 0.01650298945605755, 0.05159620304766577, 0.08431225825916044, 0.02532888793211896, 0.021231935897958465, 0.04437431947735604, 0.02451934396958677, 0.050356463907519355, 0.045605939521919936, 0.06305610237177461, 0.062275132950162515, 0.04232733146636747, 0.020005959886475466, 0.06776609807275236, 0.12474908726289868, 0.027048638912674505, 0.031468594024772756, 0.01838167321693618, 0.04379378930025268, 0.027408975729485974, 0.014652581521659158, 0.06336619393550791, 0.06071651521779131, 0.08992423056042753, 0.06452067886129953, 0.043879663207917474, 0.0113452662662894, 0.05711061632609926, 0.04421850186190568, 0.03604946345149074, 0.03433512458286714, 0.04234702435496729, 0.03459429368376732, 0.021474959576153196, 0.05118733904964756, 0.046337437379406765, 0.0730895456217695, 0.1048004100448452, 0.0689444133604411, 0.03894930901878979, 0.035264553225715645, 0.022190564341144636, 0.010689986975194188, 0.07040962067549117, 0.03640016904682852, 0.05272336951748002, 0.09384633260197006, 0.026780482403410133, 0.08949294628109783, 0.0549181747919647, 0.05292482550430577, 0.027541784911591094, 0.05149700758920517, 0.04233543571899645, 0.10552623047260568, 0.019224897696403787, 0.07252376191900112, 0.03777349105803296, 0.026983671305060852, 0.01273189312996692, 0.03641836279712152, 0.017727310478221625, 0.028731996826536488, 0.04544073744909838, 0.06092815718147904, 0.022650580867775716, 0.028511593809525948, 0.04618886683601886, 0.04496845322137233, 0.04716887284303084, 0.03909645092790015, 0.020147637733316515, 0.01997821469558403, 0.018659943343664054, 0.08414194278884679, 0.08193794972612523, 0.054192187380976975, 0.01091256726795109, 0.044170770634082146, 0.04675711075833533, 0.03207751506124623, 0.02412581830867566, 0.09684080199804157, 0.05559057171922177, 0.019428706291364506, 0.03275118848250713, 0.0207791311913752, 0.059674692020053044, 0.06538875415571965, 0.033569458246347494, 0.051209065422881395, 0.03878091200022027, 0.032996256777551025, 0.02165927566238679, 0.037670191522920504, 0.025649111667007674, 0.09625525490264408, 0.037725333095295355, 0.07696144879446365, 0.034291122647118755, 0.01769167069141986, 0.03572484805772547, 0.01471569468776579, 0.023894320183899254, 0.042335981197538786, 0.0250661064274027, 0.009111156850849511, 0.09222889595548622, 0.046092669654171914, 0.025225590252375696, 0.04766470912727527, 0.08815578170469962, 0.10183325168327428, 0.022401226669899188, 0.05770814168499783, 0.029421606013784185, 0.022402833419619128, 0.06604119844269007, 0.08061353524681181, 0.04623471300874371, 0.03849806838843506, 0.02306678656168515, 0.047918668351485394, 0.04406461011967622, 0.015572063530271407, 0.024446314782835543, 0.06370130329742096, 0.03447872644755989, 0.06994801966357045, 0.02756764504738385, 0.022158017454785295, 0.06287806856562383, 0.022146068877191283, 0.07335195419727825, 0.04023240071546752, 0.013930390196037479, 0.01844830323534552, 0.06596280538360588, 0.04124725055589806, 0.0358389977918705, 0.03823894010565709, 0.01830700388381956, 0.03697933367220685, 0.06229409482330084, 0.03761667896469589, 0.04550185702100862, 0.0362962869257899, 0.032954703929135576, 0.07787073554936796, 0.057402792444918305, 0.14418565289815888, 0.1950518015655689, 0.10277931927703321, 0.15917767421342432, 0.10080386316985823, 0.11790984761319123, 0.11641067219898105, 0.1567791122943163, 0.19775434717303142, 0.12090593489119783, 0.09982907446101308, 0.18030259612714872, 0.14392416458576918, 0.09514523204416037, 0.0638264516601339, 0.13774214865406975, 0.09289840221754275, 0.09759760709130205, 0.0839766145509202, 0.22315966518362984, 0.1519567851210013, 0.1683300026343204, 0.09436896783881821, 0.1162737311096862, 0.09521763597149402, 0.15491929021663964, 0.16042148403357714, 0.15044033993035555, 0.19772069819737226, 0.09978879810660146, 0.1997367720468901, 0.07967453289893456, 0.15112556488020346, 0.11272460280451924, 0.08020976980333216, 0.13460369518725201, 0.21891818731091917, 0.07265922613441944, 0.07510084746172652, 0.17130965134128928, 0.24959322880022228, 0.15227620548103005, 0.14365697657922283, 0.12750132707878947, 0.18802786362357438, 0.08616537874331698, 0.16871023457497358, 0.13486896845279261, 0.19531133060809225, 0.19132052053464577, 0.14753698400454596, 0.18164764973334968, 0.1568650678382255, 0.17353416478727013, 0.1299089877284132, 0.07068079401506111, 0.1104177777597215, 0.11101792289991863, 0.22611783613683656, 0.11483746013254859, 0.10203031415585428, 0.146773774176836, 0.08035049584577791, 0.13229432457592338, 0.1809755904832855, 0.13159507303498685, 0.12340834553469904, 0.131792988977395, 0.13944309175712988, 0.17502225993666798, 0.15714784094598144, 0.1751073545892723, 0.1356265676440671, 0.16147414629813284, 0.18198816193034872, 0.11306964952382259, 0.1302175282035023, 0.1247148890979588, 0.15382382087409496, 0.08830872349790297, 0.1630297175142914, 0.12424138403730467, 0.17298090853728354, 0.09210448974044994, 0.20736787584610283, 0.0967502970888745, 0.1018675314844586, 0.10836798071977682, 0.19002697197720408, 0.0768542307196185, 0.14991849137004465, 0.22566328552784398, 0.18275488953804597, 0.20397795306053013, 0.21798720757942647, 0.23610249802004546, 0.12157527045928873, 0.12403115586494096, 0.197735674737487, 0.17788073077099398, 0.16474667616421357, 0.19173266482539475, 0.15494885738007724, 0.10398027749033645, 0.2392944454913959, 0.1925476171891205, 0.21097818680573255, 0.1709070213837549, 0.24118073255522177, 0.1284378135460429, 0.11777991239796393, 0.1291603536810726, 0.09570326772518456, 0.1705799569026567, 0.12194401395390742, 0.2119805759866722, 0.1784813657286577, 0.1456462440546602, 0.1931526159751229, 0.12425734763382934, 0.14091671502683312, 0.19107898115180433, 0.15341121645178646, 0.10694589218473993, 0.2642231562640518, 0.14748383138794452, 0.12347893862170167, 0.10790821281261742, 0.08194852533051744, 0.10171036687097512, 0.10707167137297802, 0.10872179220314138, 0.09679105583927594, 0.26460171095095575, 0.09016879048431292, 0.17203685216372833, 0.14358727406943217, 0.11857591031002812, 0.16437736863736063, 0.08691909650224261, 0.1696865595295094, 0.1281897135777399, 0.10440646321512759, 0.260301826056093, 0.18191589158959687, 0.13855270750354975, 0.1064275465614628, 0.12142644758569077, 0.16496759868459776, 0.1134199506486766, 0.16727487643947825, 0.09985911659896374, 0.18961882044095546, 0.15535073034698144, 0.1826966754742898, 0.14319553883979097, 0.1488298349431716, 0.26317565934732556, 0.08013462735107169, 0.13862563093425706, 0.14118713879724964, 0.09211692071403377, 0.08718088167370297, 0.12788387452019379, 0.09953931032214314, 0.08684724918566644, 0.21997246745740995, 0.0550724784261547, 0.13821170548908412, 0.12969560542842373, 0.09552026895107701, 0.18230545974802226, 0.16927379183471203, 0.09710470229038037, 0.23127377353375778, 0.12286628087167628], [0.020273064401408192, 0.017079573262890335, 0.039252973583643325, 0.005771776177425636, 0.07785621914081275, 0.037550705746980384, 0.012677294253080618, 0.00960745233896887, 0.01607779264304554, 0.07853713963413611, 0.043411727965576574, 0.042608137882780284, 0.02633444979437627, 0.008512054428138072, 0.0301554972975282, 0.024865798914106563, 0.055077391443774104, 0.05786093504866585, 0.025290392732131295, 0.020594392080965918, 0.03304950958408881, 0.046698084042873234, 0.07998059460078366, 0.027989557856926695, 0.033983161047217436, 0.03441383676545229, 0.0351836925256066, 0.027533983084140345, 0.015075165047164774, 0.060373772867023945, 0.02205950477218721, 0.06598441672394983, 0.05692166923836339, 0.09319448945461772, 0.05215031647821888, 0.040029352821875364, 0.030120740666461643, 0.05533289062441327, 0.046963346176198684, 0.08021612258744426, 0.10173059039516374, 0.03973028215114027, 0.028763504706148524, 0.0370325271069305, 0.033873820430017076, 0.014359012948261807, 0.04690731773735024, 0.011673202770907665, 0.013279555441840785, 0.04249072269885801, 0.009488885898463195, 0.030859081125527155, 0.08027607327676378, 0.041509840957587585, 0.020552846654027235, 0.0708388195198495, 0.040667106295586564, 0.04735898881335743, 0.012206951669213595, 0.04411870155308861, 0.0530298356898129, 0.058246914923074655, 0.04796681518200785, 0.052545083381119184, 0.035255910916021094, 0.0783541334385518, 0.04090834881935734, 0.012701554132945603, 0.02308822349732509, 0.06345306974253617, 0.05298741452861577, 0.08560477523133159, 0.07199592422693968, 0.06393619303707965, 0.06312581230304204, 0.06980238802498206, 0.05230545502854511, 0.040325840818695724, 0.019790777878370136, 0.041848375331028365, 0.011549445935088443, 0.08659137893118896, 0.032788225362310186, 0.06642110383836553, 0.03534838993800804, 0.06233204825548455, 0.05475469821249135, 0.06449632157455198, 0.07153316546464339, 0.07701237496803515, 0.044099483639001846, 0.05199744518904481, 0.03531636997649912, 0.0417709507746622, 0.05101427021145355, 0.10416099044959992, 0.06661680818069726, 0.025076507627090905, 0.02369062291109003, 0.023141027304518502, 0.004929789229208836, 0.05716703810321633, 0.04178840608801693, 0.059063722655992024, 0.06320488071651198, 0.014093849149503512, 0.027666894311551005, 0.05457199258671608, 0.048496690069441684, 0.008498186471115332, 0.07775111618684605, 0.06067658025131095, 0.04423530408530496, 0.05866643616172951, 0.038900750296306796, 0.05559560719120782, 0.016235040748142637, 0.09012440263177268, 0.04470472733373754, 0.03920675262634177, 0.05446116396342404, 0.06728418447892182, 0.03399215216632001, 0.010977064539474668, 0.024425143164990004, 0.052297840593382716, 0.08801032818155363, 0.03913690168701578, 0.015084430760907708, 0.06391254821210168, 0.04635331562894862, 0.030590000642405357, 0.08747268671868369, 0.04924103450321127, 0.0588364993018331, 0.033038566616596654, 0.018059269423247315, 0.04668373832828365, 0.026558374302112497, 0.02587900118669495, 0.12012163322651759, 0.032762231639935635, 0.0298821902833879, 0.047365686696139164, 0.06525782446260564, 0.012867014102084795, 0.012403243235894479, 0.06699568941257894, 0.04247204284183681, 0.01620673338038614, 0.04919234219414648, 0.039681615817244165, 0.09015133517095819, 0.029604422961710952, 0.01776965185854351, 0.029197876319813076, 0.029591873244498856, 0.04805476710316725, 0.03837598880636506, 0.04068691792781465, 0.028761769935954362, 0.057823942697723396, 0.0035155929708707845, 0.04078593156009447, 0.037017476352048106, 0.019712043431354687, 0.057131530047627166, 0.049396161921322346, 0.02978210053697694, 0.05538518606044818, 0.01726726426568348, 0.049869581634993665, 0.008130202750180615, 0.05796878023829777, 0.06447655076044612, 0.03984643568401225, 0.012516749156930018, 0.019243163806095254, 0.05052854568930343, 0.07718699489487335, 0.02771123206912307, 0.03386538963241037, 0.04985276085790247, 0.03260387587943114, 0.017466790668549947, 0.08010353878489695, 0.018771703362290282, 0.04202860589430202, 0.011207875249965582, 0.05444921909656841, 0.04108609689865261, 0.05560560392041225, 0.0576824967720313, 0.036232428828952834, 0.023056235077092424, 0.033191608599736355, 0.03265516941610258, 0.021302571658452507, 0.037912458210485056, 0.02230178073659772, 0.010877519343921449, 0.016166711211553775, 0.0635612006590236, 0.03348960315634031, 0.03405243682209402, 0.014968759624025552, 0.024319513286172878, 0.03192447307810653, 0.0886844951310195, 0.0430507955752546, 0.05848983098985627, 0.023243829600687604, 0.020390043573570438, 0.0197455922170775, 0.018598254173411988, 0.07494210949516855, 0.043990220947307535, 0.06740835320670158, 0.06079659295210149, 0.018725469417404383, 0.06129096720542293, 0.017771364364307374, 0.022848693479318172, 0.0883129908470437, 0.0646694794704672, 0.003358718722665799, 0.055959968303795904, 0.029597858665511012, 0.05497236270457506, 0.040863515678211115, 0.07791727563017048, 0.07311019959161058, 0.05017284544010181, 0.053864967048866674, 0.031536092355963774, 0.023198504786705598, 0.05273131791909691, 0.024203938628488686, 0.04605558453476988, 0.06874302416690625, 0.023277359832718503, 0.10574170562904328, 0.060176227998454124, 0.04276084961020388, 0.11277594458078966, 0.024083560419967398, 0.06214129774889443, 0.07497261176467873, 0.08440902689471841, 0.05512068091775291, 0.12669566640397534, 0.029777296986139845, 0.11754796898458153, 0.017444004879507702, 0.01599128605448641, 0.018980052045662887, 0.016691168420948088, 0.06223703850992024, 0.07475856153178029, 0.038579979227506556, 0.05558620046940632, 0.09352553184726276, 0.060414179097278975, 0.04132299043703824, 0.06933002587174997, 0.0499859652336454, 0.054899220340303145, 0.004671335836974322, 0.056269870619871654, 0.07957633933983743, 0.031339950146502815, 0.013656663868459873, 0.07930708074127324, 0.04686383901571389, 0.04623298009391874, 0.0696820042503532, 0.02151096115994733, 0.060096599263488315, 0.027619903376034927, 0.02580753051006468, 0.13814609963446856, 0.030183266608219128, 0.007064818219078006, 0.05009552478441037, 0.07027777071925811, 0.013526005986932432, 0.05004938175261486, 0.08031521414523013, 0.036750180734088644, 0.023328311981458683, 0.04358101185061969, 0.03504026506561786, 0.027014719053113367, 0.06453762209275737, 0.007618977570018615, 0.026097784466401208, 0.06541795024531893, 0.06298643696936779, 0.01991377957892837, 0.07167453717556782, 0.05754477271693759, 0.10351164091844112, 0.03492452342470642, 0.04529354358965065, 0.03094150775723392, 0.044543317635543644, 0.03467604496108834, 0.031036563887028024, 0.029639966269314755, 0.03905055651557632, 0.0430599796527531, 0.0647388628567569, 0.028016572032356635, 0.027828240927192383, 0.05657522357068956, 0.03658895286207553, 0.06395764110493474, 0.027311333215038758, 0.04258135006239172, 0.03425562572374474, 0.034438643051544204, 0.029925585513410624, 0.02421707278699614, 0.022526790635311045, 0.01934753017849289, 0.036382947509991936, 0.038489767466671765, 0.03555300005245954, 0.028542392938106786, 0.029060729284537956, 0.01272443269044743, 0.022224578824534547, 0.03038756130990805, 0.02153965444449568, 0.06735021335771307, 0.08755319489864632, 0.03171438591380138, 0.046756509618717246, 0.026991521372110583, 0.03458631188550498, 0.02151418764697155, 0.027618216845439747, 0.07925692640128545, 0.06134306597232353, 0.03657726774690673, 0.01856652550486615, 0.037025806959718466, 0.0871039877529256, 0.050313738465774804, 0.021304245201463345, 0.032985469661070965, 0.012845195888075978, 0.07944641154608689, 0.16921882837777957, 0.13908727647503838, 0.15153402811847627, 0.11415360815590248, 0.1370358615531586, 0.09133180268690921, 0.07830055779777467, 0.09179315136861987, 0.2688953618053347, 0.11345831226208247, 0.17924727697391063, 0.07084429656970315, 0.11908704967936501, 0.18658655346371233, 0.17456141591537744, 0.13640231976751238, 0.06865421877591871, 0.12906195974210277, 0.11611792462645099, 0.15282983280485496, 0.09814085919060744, 0.14348467957461253, 0.13130429957527667, 0.13573692500358447, 0.11451887839939445, 0.10597933389362879, 0.10200536315096542, 0.16858984337886795, 0.09576514799846336, 0.14144264539936557, 0.12755599367665127, 0.15407105995109305, 0.23891057702712715, 0.19305695313960314, 0.10911613979260437, 0.10205625963862985, 0.15868778253206983, 0.07986232594703324, 0.11861666163895279, 0.19921617029467598, 0.10549795464612544, 0.23848571232520044, 0.16228063817834482, 0.14133136777672917, 0.09691578859928995, 0.12413274103892036, 0.15374506416264921, 0.13455683598294854, 0.11169683959451504, 0.128778132784646, 0.09357389761134982, 0.18547063053119928, 0.1045275668730028, 0.12076301209162921, 0.23159059637691826, 0.14554041379597038, 0.10735139425378293, 0.1141119736712426, 0.08785231009824201, 0.13592079951195046, 0.14070688019273803, 0.17381092649884522, 0.12893466657260433, 0.20879679213976488, 0.2658247703220695, 0.17929567984538153, 0.0914825477229897, 0.2063754017581232, 0.15709301107563078, 0.21730864711571485, 0.1631229609483853, 0.194505387917161, 0.13891104608774185, 0.23688426153967157, 0.2226657362189144, 0.1941625156905502, 0.1255989502533339, 0.12384293237118982, 0.1610684735351242, 0.16033318330300972, 0.20839273725869134, 0.255508353584446, 0.15413939690915868, 0.10905768824159168, 0.22805579152191058, 0.17794491170207039, 0.1595316786551848, 0.29874976607970893, 0.22781256004236639, 0.2358124073361978, 0.1462599408114329, 0.13326512795174494, 0.16470268164994195, 0.2076005094568245, 0.14104620495345443, 0.15627476357622072, 0.1267394976457581, 0.11295503965811804, 0.166591981833335, 0.2335416284040548, 0.1641293428838253, 0.07966648059664294, 0.15138377289986238, 0.32853331009391695, 0.1519306912086904, 0.1352967572165653, 0.1388337736716494, 0.08600243279943243, 0.17116126633482054, 0.1844500587321818, 0.1593423864687793, 0.16751007788116112, 0.12508807063568383, 0.10746930667664856, 0.11732605198631063, 0.12201272940728813, 0.37748403497971594, 0.13203022390371189, 0.16111269069369882, 0.19439293770119548, 0.1795376348309219, 0.07811735864379443, 0.15031686139991507, 0.11332718961057253, 0.1270465538254939, 0.17808103642892092, 0.22280304838204756, 0.08570165518904105, 0.15913179464405403, 0.13070157176116481, 0.13847772090230137, 0.15476556174689904, 0.18959088600240648, 0.1874676311854273, 0.19632762763649225, 0.09820974533795379, 0.21722600155044347, 0.23936773999594152, 0.08650933450553566, 0.23381910257739946, 0.12794277135981247, 0.0865524384425953, 0.11183753595105372, 0.13238088868092746, 0.14821655378909782, 0.14493522205157205, 0.1334514663903974, 0.22960956674069166, 0.1371093638590537, 0.14579084410797805, 0.10024642120697536, 0.15913221024675295, 0.08053656711126678, 0.14891819504555315, 0.12021652422845364, 0.16691582539351657, 0.11300863756332546, 0.19516594387823716, 0.298469471745193, 0.09689508267911151, 0.1295972114894539, 0.11093756314949133, 0.11631838613539003, 0.13374710833886638, 0.08127136010443792, 0.2403355302521959, 0.17391830042470247, 0.08110088878311217, 0.10809773506480269, 0.16747237677918747, 0.13536527229007334, 0.1905691108549945, 0.15120699332328513, 0.15083783422596753, 0.18796602787915617], [0.09518950857454911, 0.015938539763737936, 0.03941692513762973, 0.06167840168927796, 0.05026736907893792, 0.054071599515737034, 0.023768982573528774, 0.07362576958257705, 0.012843857239204226, 0.04740021140605677, 0.058306850769440643, 0.02847492985893041, 0.055110706452978775, 0.019675988041853998, 0.04008992691524327, 0.04690776673669461, 0.03683036979055032, 0.05596592032816261, 0.0481428637431236, 0.03771984491322655, 0.015235205482895253, 0.01380049765430158, 0.05384574171330314, 0.031659481828683056, 0.056413687707390636, 0.01849092292104615, 0.023617410042788833, 0.08658448437927291, 0.010723532050178619, 0.024652052961755544, 0.050690545394900255, 0.03350711784150917, 0.012864847958553582, 0.0679356417094823, 0.04687701213697437, 0.014770248108106898, 0.08098124715615995, 0.05237069352006074, 0.07874928996898234, 0.014343849943543319, 0.024893907757359557, 0.017996589485846926, 0.005446878303700942, 0.015596851262671407, 0.020121430643484928, 0.010765404949779622, 0.007381548293778906, 0.046833707820042036, 0.03594927351514343, 0.04868990079557989, 0.0754658282676246, 0.02388890065049054, 0.03942699608160183, 0.0073171822896256344, 0.014385131908056792, 0.10376535152317956, 0.04927807138301432, 0.01491925095251645, 0.05147617921466008, 0.01647762841457734, 0.03923034921172075, 0.02901628948166035, 0.026391402207082137, 0.055070838279789314, 0.02278808784467401, 0.035772000410361215, 0.06357114543789066, 0.06402115410310216, 0.02262170019093901, 0.06490213534561917, 0.088481347047491, 0.028879170276923105, 0.16374045750126243, 0.04582892892358359, 0.14127334667136893, 0.09817832280532457, 0.033455560842412524, 0.04393831884954125, 0.051059812103630975, 0.06936106248758733, 0.025962769250327256, 0.06584140486666001, 0.023828165140002966, 0.03485398228804115, 0.028511968594102655, 0.03633259650086984, 0.041736429775482975, 0.05782284431916196, 0.08771738765062764, 0.027248451042396482, 0.05733844081987627, 0.06780494208214805, 0.10824404947925359, 0.06843914437922649, 0.11990345665253699, 0.13154346408555284, 0.09622666737413965, 0.05934047694609035, 0.049898065262823366, 0.025622422181186266, 0.14886441902490333, 0.08990106813143939, 0.00929632826228044, 0.03466155823844019, 0.024033910740399733, 0.07179845357313752, 0.028442807852115948, 0.04351280476839747, 0.03046030476980377, 0.04816914319235366, 0.049185191601281986, 0.032326783912139945, 0.021227885627013166, 0.012686625832429854, 0.010477204887138214, 0.026305253704776987, 0.04409199536894448, 0.04035499609017279, 0.0595722311118152, 0.032100722019094974, 0.06872311234474182, 0.05202854117669631, 0.02761914824077394, 0.06640804946073331, 0.037534478688030504, 0.04702677011664491, 0.03690363831992727, 0.007595714023409528, 0.04163012083154172, 0.005246215023362311, 0.03743572480743751, 0.015023701744212303, 0.07378075228189118, 0.03255493124015629, 0.032068189975689165, 0.04251730642863549, 0.04101081343833357, 0.0792761257616803, 0.07219720209832303, 0.018855449161492288, 0.061975249627721496, 0.0267085831364966, 0.02490255377779249, 0.008705382042535348, 0.03545395302353427, 0.014839960822428111, 0.028464697497838642, 0.031806853803573176, 0.061721372039755806, 0.0421116262441501, 0.057410388326388784, 0.01959740387974307, 0.02624302462209016, 0.061448673586710356, 0.01702073022897821, 0.02612077249068534, 0.029273382424435113, 0.027155938623764087, 0.02618588667246513, 0.01873306344350567, 0.010803281384141883, 0.032096844297484495, 0.08078995859250426, 0.055890718504088, 0.038912865857128054, 0.0201745758386096, 0.056658774556126446, 0.0529467967862729, 0.037764845037600026, 0.08235013854573481, 0.03704346265294589, 0.03149830961774569, 0.022655683133052662, 0.02383294271567138, 0.009113428750424646, 0.04057402242324315, 0.0525990152527811, 0.00517354948897264, 0.03478927072137594, 0.09739159431774169, 0.05620320720481686, 0.0606079390126979, 0.05879105388885364, 0.045244224165799096, 0.0050762905721057905, 0.08172202928108163, 0.02100581277773017, 0.03465495312411804, 0.02506660923245363, 0.01728589959384408, 0.023234565742313862, 0.07621084063430317, 0.0494405237986939, 0.028803317218262237, 0.029461060439643916, 0.023581469686178025, 0.027281482180114836, 0.04532849132374395, 0.0607899729948258, 0.05152900528628379, 0.07473242309060879, 0.018449011986376718, 0.08601632580393925, 0.046116025041555986, 0.05788441660115495, 0.04200482006126549, 0.008923798886826262, 0.02149565436411649, 0.03283007135905791, 0.07646269586985, 0.03874862857628614, 0.05029724052292295, 0.03633647422248032, 0.024465336027788, 0.02693973801797256, 0.02919666290836176, 0.05913283515837975, 0.03835377261566464, 0.022551815854967572, 0.010912696216109907, 0.033852279593702406, 0.03940259797673207, 0.05060031508037355, 0.013812216166115832, 0.02702640602365136, 0.038761170872021466, 0.05300585689838044, 0.044823018251918256, 0.03526510983647313, 0.03123700684227515, 0.019451631233096123, 0.08951672469265759, 0.014204991330188932, 0.0385976534744259, 0.03308434228529222, 0.019617586585809477, 0.015903332277957816, 0.04926925837935414, 0.025349284005642403, 0.048716729434090666, 0.04821143076696899, 0.05285308579914272, 0.07136183325201273, 0.017813598133216146, 0.01831378340284573, 0.045104058444849215, 0.022636840003542602, 0.09719421272166073, 0.10261456249281764, 0.08767854364123195, 0.2291992332902737, 0.13696731679374352, 0.027789630694314837, 0.03582353143428918, 0.018276952469022945, 0.052309084130683914, 0.005566579302467289, 0.05187139511690475, 0.030921657162252814, 0.05717290478060022, 0.02473835731507279, 0.004855907036471763, 0.07218575075967237, 0.05367530378862284, 0.07633161774720065, 0.08293288774439134, 0.051438593145576306, 0.10746840125648305, 0.1192706124857068, 0.1140510656114202, 0.11971261337748729, 0.03514687457936816, 0.0671556222368963, 0.01686500352661824, 0.0395978830056265, 0.03762229702260811, 0.06007083931763191, 0.0749451300362125, 0.03407032258110121, 0.028022871010762174, 0.04156549090112094, 0.12384273199131712, 0.040737636300036684, 0.018660060231923126, 0.030276285542640835, 0.023109933172236197, 0.07358780872891657, 0.008773288554948522, 0.033253232832066715, 0.04007472030934878, 0.026214455647277646, 0.06877256906591356, 0.03153816665872, 0.029112024676578585, 0.025663231026555877, 0.025326071481686085, 0.03970337187638506, 0.010841608673217706, 0.11254068376729265, 0.02621975272631971, 0.05669556281645782, 0.08610865639639087, 0.0442307361663552, 0.10127852598088793, 0.02119979719282128, 0.012572163468576036, 0.04109765955945477, 0.08188349835108966, 0.04535745734756347, 0.015632214599463623, 0.057594633908593096, 0.07179023057688028, 0.05926205049036071, 0.04560801011393778, 0.04404838306072634, 0.049719916423782706, 0.06019517131790053, 0.06524825817905366, 0.08927180111641064, 0.04080249629623722, 0.03547547530615702, 0.025381303967151325, 0.05135776213137433, 0.02283040881593479, 0.04205351237033028, 0.020976659361622296, 0.020054216183780227, 0.05109067431476433, 0.0469050245010294, 0.03334275068482384, 0.020296616457926575, 0.026483398833079264, 0.06605109127121978, 0.060581448051379994, 0.07267631779541261, 0.046685716151841916, 0.042375088669359684, 0.017582532309461385, 0.10944772395305336, 0.01244456323547638, 0.02346316206967458, 0.06718075135722756, 0.05095019318105187, 0.027053676240029745, 0.012793605492333882, 0.1102703130163718, 0.009764926799107343, 0.02802567818434909, 0.018548253829067107, 0.018386281954008155, 0.031170510410447605, 0.05419981294835452, 0.3153439803281799, 0.11812744531198405, 0.11441434689913876, 0.19915265729650855, 0.10857499539270066, 0.2089317442732863, 0.17466377292294055, 0.1266862262855284, 0.08005582611076534, 0.27198032126761973, 0.11738059984054416, 0.14277018432039768, 0.11310835252515972, 0.10811030704644509, 0.14387970993993804, 0.1800555203226395, 0.1297063665697351, 0.12070795215549879, 0.16377171676140279, 0.11659680283628404, 0.09687123747426085, 0.12120210376451723, 0.19918795384000987, 0.08448641805443913, 0.14212352136382833, 0.10706201603170484, 0.16345685318810865, 0.12433660900569521, 0.1590635467437096, 0.11264459186349995, 0.14425256493268535, 0.1467487044283189, 0.1258530467748642, 0.15695210691774264, 0.1291952791507356, 0.28326633910182863, 0.1891960931243375, 0.18770652852253988, 0.15146713092690334, 0.0739919526677113, 0.12247093880432658, 0.10847707642824389, 0.24168855452444404, 0.18608958169352263, 0.16854526998940855, 0.07328920561121777, 0.1453157063224353, 0.09355922535178252, 0.12490680848713964, 0.1340950865414925, 0.11131581355584785, 0.11127348887384869, 0.12601848633494228, 0.08149764835252427, 0.11409700455260463, 0.14391904376680031, 0.07794376288075, 0.13437012647045776, 0.10360859509091824, 0.12142108185798861, 0.1231767880381085, 0.11151225262437947, 0.1250638024066575, 0.11767895804950967, 0.12246261932887137, 0.28591399546712637, 0.2653881796868518, 0.2586558315670118, 0.1436792706954293, 0.27258573565632105, 0.22500940889585763, 0.1696904335403815, 0.3183506283676252, 0.16398162581026554, 0.369313582777977, 0.28869687113910913, 0.1455434417584911, 0.18902729905676097, 0.1103536413575057, 0.13036013930104673, 0.09600082441465929, 0.2181520831072703, 0.08329474410857074, 0.2704313996946439, 0.13331440655747429, 0.1067091099685058, 0.3594569710548967, 0.1928101445082575, 0.15247392846504226, 0.2065787502215244, 0.22581370401894674, 0.2851146727334708, 0.33661004388704896, 0.2626926399534568, 0.3518568741856143, 0.2992451941827312, 0.17211500031407923, 0.23332031996687874, 0.13971930427942425, 0.19309849856654182, 0.26691011677030474, 0.16972249432001263, 0.19798626832198352, 0.10151921189390123, 0.12198643511510454, 0.24146406969521195, 0.16498198150657117, 0.14190795714966953, 0.19593103876104578, 0.15553876088233665, 0.13756024825852364, 0.12599873036378995, 0.24019796575885266, 0.17742760508554056, 0.13564541819505394, 0.24781909509329125, 0.13614948489703238, 0.0780531183409039, 0.11249096729443409, 0.12054606006131507, 0.10922381799900904, 0.19166083977324888, 0.126812465605326, 0.11793713638326153, 0.1492303572013043, 0.19834267732221633, 0.18631348764756694, 0.19702584017068148, 0.14301709685241804, 0.15246067370753735, 0.17328132991679013, 0.1851433582487516, 0.25719249446410686, 0.18176994082750753, 0.10084048815770075, 0.08616275896201842, 0.14352986152516678, 0.14803548459894955, 0.1772800661274232, 0.09622584359021857, 0.08908082425477915, 0.12985739362193272, 0.15295736346160993, 0.10015979773015715, 0.17998126102611423, 0.11800357344327495, 0.15323081519454718, 0.07391784922219813, 0.20341343100881204, 0.1320472190855071, 0.24915803340263665, 0.18621081893797964, 0.15189232217380777, 0.22818946716142818, 0.15075046860147268, 0.11233707555220462, 0.10285101074259728, 0.1238696496875491, 0.19753058964852244, 0.09949639934347942, 0.108881049673073, 0.0718586788570974, 0.31158096506260335, 0.12436026125214994, 0.12454174604499713, 0.11829999464680441, 0.24966637487523258, 0.22604387369938195, 0.12340791508904658, 0.2599184325663373, 0.10490465210750699, 0.08288434386486188, 0.11602135637076572, 0.1426382749923505, 0.07567731066956185, 0.15521383378654718], [0.02040067298366921, 0.030963727658672724, 0.036361911334097385, 0.011577500044950284, 0.014787283180339728, 0.053219547189655714, 0.012098537808924448, 0.03928096739400644, 0.042605822382029146, 0.04375618838821538, 0.04334550612838939, 0.02512299204681767, 0.07783160210237838, 0.0499340445821872, 0.042643003980629146, 0.07047132283332758, 0.02497083507478237, 0.055108068117988296, 0.0385584569448838, 0.01685083221673267, 0.04099578123714309, 0.04824519477551803, 0.02163150449632667, 0.03463038432528265, 0.028297315366216935, 0.03168610266584437, 0.00717253353286651, 0.021440011842059903, 0.024877951582311653, 0.034252208133693784, 0.06075641307688784, 0.030433732172241434, 0.0131753105961252, 0.03250396424846258, 0.02989932461787248, 0.0511370251479093, 0.022043658063921612, 0.0030569399086743942, 0.06742763420334086, 0.07311914247111417, 0.009296014704887057, 0.05288233754981775, 0.06254246938624419, 0.0030653442672701203, 0.02085403430100996, 0.06285033450694755, 0.07980339200003073, 0.01916736084240256, 0.0940506903862115, 0.023682754290348385, 0.03828695334959775, 0.04476479305594694, 0.02128671567334095, 0.025180751545121893, 0.06291448575211689, 0.03926750854589045, 0.01665339310420677, 0.025878709893731866, 0.080879298329819, 0.04711317094916012, 0.027424735235399567, 0.014820371834503021, 0.05189701034396421, 0.0417752886278322, 0.037081508853589185, 0.08074165220023133, 0.034071294794557616, 0.08463245787424967, 0.04930463655909989, 0.09430178120965138, 0.0357093928323593, 0.07768323193886317, 0.0859825432416983, 0.05136591462360229, 0.12847557401983067, 0.08746823383262381, 0.11081321630626917, 0.039799313017283566, 0.0940902617003303, 0.042429358218214475, 0.10313320497516543, 0.03914825283573009, 0.10081923304824159, 0.07904804151621647, 0.09387706493726, 0.3131811541970819, 0.19235412444686517, 0.0854864323628135, 0.12337315289187245, 0.133654770324938, 0.08486618986353278, 0.04604210342222359, 0.042355674086138606, 0.04447190076461993, 0.11638066716841422, 0.20565375220030546, 0.016964013448159676, 0.06539250200148672, 0.027096401681774296, 0.06963300023926422, 0.04000139611889608, 0.1387125364271924, 0.04742509561765473, 0.026461321795068216, 0.037714627615059726, 0.04881942782958504, 0.14572676707757637, 0.027494723472045735, 0.010693028852983844, 0.014004711647430668, 0.0569053123035701, 0.05645665805786848, 0.012611289494088851, 0.04019624328066129, 0.029777987183479127, 0.04585984679579269, 0.012969536237505963, 0.024926345176936593, 0.06329454699880444, 0.04640644598111976, 0.04266851901775226, 0.044789094681618735, 0.021179746217967477, 0.04483220604015514, 0.06315705672022887, 0.04079844045918435, 0.04359116072009783, 0.03816671800450422, 0.049636922049103305, 0.04889574287517462, 0.028034843708155677, 0.0201881868269993, 0.030212882011255715, 0.043150666388100944, 0.04081352089997381, 0.07343358302023262, 0.04525201671640389, 0.047394444918609224, 0.02049509643256897, 0.03414733895624522, 0.011381751173757948, 0.016904684307519346, 0.04329757080995478, 0.0477777530613821, 0.04515608299698215, 0.06994452414801344, 0.15546668349998072, 0.02076129923807457, 0.07879642376792617, 0.033759874786483124, 0.04271599049388897, 0.06356926780426875, 0.040264528288389556, 0.05769532850536052, 0.09700364404125139, 0.06998899363679811, 0.04239896356011741, 0.07522729458287358, 0.03606788726756349, 0.04307067771151196, 0.011855817483592546, 0.005843166609338368, 0.04431606088473927, 0.026574148650979623, 0.0258200969255995, 0.047401666015503, 0.03219491169147659, 0.04277826039469801, 0.03515542412060313, 0.01961129131814232, 0.04791414125065785, 0.031448144145542756, 0.0412352463172283, 0.03742393950233236, 0.057975285162683576, 0.008917421982914675, 0.047129368322202936, 0.10141194929019548, 0.050717756239464507, 0.002659680317265156, 0.03752240023459308, 0.03238368808524683, 0.04896548991382588, 0.01771046929206932, 0.03211367620679084, 0.03681569010950625, 0.048431154718855396, 0.029651386066689156, 0.014724688589922152, 0.06867744799819775, 0.04604612215189263, 0.06528437850647606, 0.033276424946961924, 0.015161288501985837, 0.011644411151792156, 0.04559836961561814, 0.02953245690150652, 0.03204099397407845, 0.012512816701928386, 0.010906325805990491, 0.017459525042795576, 0.029287670622579753, 0.06755163223715499, 0.04497597117733676, 0.04195846922812052, 0.0386539342434844, 0.015969042033248115, 0.04323064764321316, 0.06848846009233966, 0.031638479049433954, 0.04770419138367288, 0.024071828920568805, 0.009363887820654782, 0.08845670032314956, 0.09815223631449044, 0.1034552302735392, 0.028577884295373224, 0.053914449745207094, 0.08784007208305411, 0.02534345258027315, 0.059022822897532023, 0.06005126146192197, 0.04745858132082503, 0.01938277477165684, 0.07535240583820269, 0.036052777140866965, 0.0319056670559803, 0.021298343272064812, 0.05309140426106751, 0.003009529427799862, 0.017028055226546712, 0.03805250147706829, 0.056788899019011296, 0.015036185595818097, 0.02315959212864982, 0.023864131471782457, 0.0470971516915597, 0.011173497114214115, 0.03984314054832794, 0.030366246828634758, 0.0487235831678845, 0.06521407485706732, 0.08600344212027267, 0.07279053432284854, 0.07683881631237455, 0.06587721349205822, 0.05957013454462867, 0.13817125844070688, 0.07486573507776484, 0.07012013113126159, 0.08672612326336093, 0.1312169191078283, 0.08376412282814272, 0.12351983838016167, 0.007598386218887754, 0.09164513001451269, 0.10315356950741261, 0.06895943442941643, 0.05428264405054506, 0.018972177858813666, 0.2032165540731512, 0.1551769787329249, 0.08071888310951181, 0.0818746371078305, 0.13368087908020243, 0.08174577800673433, 0.01385879520967137, 0.026935921523545403, 0.021359375641623046, 0.0726114095596131, 0.12666458525927737, 0.06705582563881762, 0.06949706847080961, 0.035436712933005765, 0.10197392577538267, 0.10408676083898172, 0.08308597054565325, 0.14800124190514907, 0.07627084327396005, 0.012357942541711964, 0.07437339430907741, 0.05115291081892792, 0.04329376730311196, 0.021627858695865143, 0.014100848529778887, 0.06076794605178293, 0.07843559898901731, 0.028563048763317056, 0.033933778540813364, 0.0077025461814628216, 0.019923520267184358, 0.017133293622464407, 0.03381022579560522, 0.009719347799546085, 0.037603175587719306, 0.04888362360361498, 0.01940084792295238, 0.004968163366356748, 0.011120540239062393, 0.06920429121237248, 0.0282193304883549, 0.13993059372296557, 0.02177494123316137, 0.05281436053337529, 0.09195932565489784, 0.04294298749300651, 0.05939750357356388, 0.03455537917034235, 0.04194089888187591, 0.033599158996366896, 0.007583700971736107, 0.013418524449662073, 0.0848680452327244, 0.04732562927529216, 0.04541176029306371, 0.035851491848006845, 0.02873899898986565, 0.07899197968072258, 0.02709333104576217, 0.005106306271045469, 0.04307074450480286, 0.023505650024162605, 0.02295837548444979, 0.009942822380253347, 0.038541843969142064, 0.02789803249470424, 0.035731341849896125, 0.005209865094002453, 0.05210460760281421, 0.043184886817471124, 0.03428771247854456, 0.03800630278419703, 0.01984715141588822, 0.06422279562684707, 0.0323855768510839, 0.021948861685814336, 0.0024291488398375805, 0.013423974596662447, 0.042546216791379265, 0.015153735294006765, 0.017600675964786205, 0.01676913845585659, 0.020786283639608882, 0.0967765913810581, 0.03241407161112875, 0.02450955318636261, 0.08161776495398954, 0.07242491526994854, 0.06747687570168637, 0.07603574573295191, 0.04303700276068412, 0.03771878735278733, 0.10397146819741465, 0.09117808906012215, 0.12067983218003064, 0.08861934940796345, 0.1421547806239687, 0.23709460103418678, 0.12337078544078395, 0.15955241426127031, 0.11657300216029398, 0.11053694441216066, 0.16040006565162912, 0.08992770381155424, 0.16330487618688494, 0.2699786005541682, 0.0926609594898764, 0.2000095261610113, 0.08801408344879746, 0.07930214545922354, 0.1288157151429914, 0.1148654984717723, 0.14921015594154596, 0.16718170722015202, 0.11939268093556166, 0.12442957784514874, 0.06320725558907725, 0.10775235437904485, 0.1524993692873977, 0.10417464596685022, 0.1685169941629283, 0.10527571852435358, 0.2010100006009452, 0.10883920738706365, 0.23064415028784424, 0.08051268479903229, 0.16604564239969477, 0.18081699352478608, 0.07712091406574473, 0.2094691779348068, 0.17851897777291015, 0.1681533269584179, 0.180304748355411, 0.11245146277360618, 0.1575844464241527, 0.12134222124586813, 0.2185302073485218, 0.16807010251795873, 0.19909941562218592, 0.08518916511093266, 0.18646203592652455, 0.1049403939396143, 0.14678480249131098, 0.20525018713669851, 0.09692208943306468, 0.07232629868667573, 0.09810564428335056, 0.16740687482524663, 0.14929645287338644, 0.1251735957339406, 0.15680253447499126, 0.102816857106518, 0.18286196660483256, 0.09486921990173869, 0.11865721258800477, 0.13127281767083332, 0.31449968344531953, 0.37456018093507737, 0.18020791292656213, 0.14814000867772847, 0.2047847121139057, 0.24004643404623494, 0.213549105101265, 0.2079352329019457, 0.1797790703130886, 0.19825310009764507, 0.1581170264398679, 0.26175355596933514, 0.16287601873045787, 0.27288894751109183, 0.3424675780115649, 0.2224616752937436, 0.27820438728667796, 0.20976159896235913, 0.3286789491539821, 0.24788931710645556, 0.3594841039739549, 0.5562143912538886, 0.280981088289991, 0.2516601694514975, 0.3194314328720793, 0.2276178650208749, 0.13325966574484482, 0.1466752466512844, 0.08240925060817972, 0.15103674464626238, 0.2859941771021113, 0.3125443321187049, 0.15812628844287246, 0.21389138360973448, 0.1415745250415057, 0.3298713726690039, 0.2018407903960906, 0.28667261882219464, 0.1826246129348874, 0.10250024948618375, 0.10797698763781227, 0.14007657417096198, 0.2191275471705012, 0.14038659894140437, 0.10757374169770628, 0.1904905025730841, 0.17595755896763876, 0.08714979310752824, 0.16508567437995225, 0.13697453046916053, 0.12079253472620621, 0.1618682564003393, 0.11952846427448094, 0.05345406956621446, 0.23486217629397288, 0.09900189150357619, 0.13625262858113274, 0.1448149941279553, 0.14592419320251793, 0.24236997967818752, 0.13520897598937154, 0.18830149347195402, 0.12209337859530933, 0.13763768394710496, 0.35386073228437454, 0.13631921407068148, 0.2299674748792313, 0.146345614339225, 0.07486661081202328, 0.1057027057686355, 0.08894360114936717, 0.1751483656698838, 0.10279671521857381, 0.17357118311338127, 0.18914464744739234, 0.08810901897959411, 0.15167778212344274, 0.20762482221471146, 0.17286121495999396, 0.09921954857418314, 0.16492961556650698, 0.21806330740218982, 0.26676887122448534, 0.20169369672657922, 0.1553038414567709, 0.09203114328556694, 0.13439197529805824, 0.08431790600297973, 0.13214552396675572, 0.08579952220316045, 0.15238485590089113, 0.183467663009651, 0.13497521431418136, 0.2282883509178646, 0.19134474423481151, 0.13393537636147812, 0.07570070316432975, 0.08268308825790882, 0.14654186787083745, 0.14382856112206355, 0.10368160757934675, 0.153438275156077, 0.27493831410538405, 0.1292187161743641, 0.20706911687739193, 0.11801388929598033, 0.14450269838562235, 0.12639631371712312, 0.09686026853160001, 0.14547906786901876, 0.18893611879320815, 0.13421568553894758], [0.05000877514248714, 0.013603807183244498, 0.12175693336757831, 0.020129371623625048, 0.024549595764256082, 0.05005881073884666, 0.04149735803366639, 0.03516134274832439, 0.03280095319496468, 0.006057097634766251, 0.05439721680886578, 0.030792599536653142, 0.007216734920802992, 0.04639332852093503, 0.022517446996062063, 0.02529323144699447, 0.04844717026571743, 0.025976228098443244, 0.042395664713694714, 0.03133835823973641, 0.05065651050244924, 0.025721769779920578, 0.013275524652271997, 0.03240311380068306, 0.06275110194110312, 0.01736109214107273, 0.020939668866049033, 0.04415760122356005, 0.030264785964391194, 0.042469330292078666, 0.004193631148154964, 0.015545970545645105, 0.06400828526238911, 0.025975022108468693, 0.03965165902627632, 0.061920657244627364, 0.042785359037225135, 0.0056901394691522, 0.007356703044933965, 0.06531250590342097, 0.05687036085873842, 0.026223773311357945, 0.05229458256508224, 0.007149323328121682, 0.013512085151887732, 0.03719843050930649, 0.061520372473751195, 0.021177308262849692, 0.01712869601760758, 0.04777206078870222, 0.03448192510404624, 0.011544078352017095, 0.006658607862846111, 0.015420835170516511, 0.04732509121822659, 0.05566053026996087, 0.04093717012437992, 0.028118639602325857, 0.05147389711055439, 0.027201506491110194, 0.005820975002279738, 0.03675635169201996, 0.08289014003821649, 0.03624386903538834, 0.012255742312845541, 0.146224154450465, 0.09321795616415329, 0.0624615307606291, 0.18034286506008357, 0.3468452696688473, 0.4331339488271624, 0.19603419728809968, 0.27290494821500033, 0.27625669492408633, 0.3589014883618802, 0.09834653799771331, 0.32559740357100964, 1.3364577549509704, 1.7787441657856107, 1.6089721256867051, 1.1243829410523176, 0.7959977933205664, 2.8732115495949984, 8.817511405795813, 12.219128776341677, 10.048869531601667, 9.586185459047556, 12.400219459086657, 14.306738656014204, 8.10352211818099, 1.9643313135020435, 0.31548412749543786, 0.1020803720166441, 0.11224814399611205, 0.17586913949344307, 0.6637358560692519, 0.25566269061528146, 0.22106884222012013, 0.12631111516384408, 0.042118045821553096, 0.023775008812663145, 0.0828683357394766, 0.013266861005831743, 0.008717974433238851, 0.08995571988634765, 0.06901072425534949, 0.11177200431120582, 0.017682670295471326, 0.06412524031475186, 0.08723361126612872, 0.020975980296498165, 0.04675366719311569, 0.049900725862244144, 0.020786560089618433, 0.0674064681516029, 0.029241733536764514, 0.031929779433994554, 0.0633480261603836, 0.025114950876741204, 0.029701451348955743, 0.034293612552573904, 0.002324488623344223, 0.016908190955291502, 0.03143381327390671, 0.026956900182995014, 0.07285999192390591, 0.060239243757678196, 0.035263840763946064, 0.010254911248921417, 0.018840882657968905, 0.03277741969213821, 0.03493022682960145, 0.09043235681019723, 0.05785725770692807, 0.02558326090365881, 0.09625779304769821, 0.022195241726876702, 0.04166896113019902, 0.027648071591102052, 0.021967725224385504, 0.04161084354564082, 0.014469077159446897, 0.017512323283881415, 0.01215442245666054, 0.035667973570525646, 0.02025770751060918, 0.023816977263777517, 0.040476771391695365, 0.027165931642230134, 0.01738184815621935, 0.11587250381126069, 0.01978784639504738, 0.050464587402530015, 0.042036543163703755, 0.03585056787414942, 0.021631541603710502, 0.02089200628688559, 0.058106266806134954, 0.041146058720187284, 0.05616063019260764, 0.05533506140636746, 0.030716815126652364, 0.03855626018776093, 0.019972051159129478, 0.005216670588197303, 0.05698927889170591, 0.025479595860815607, 0.024245790191343985, 0.055142526034615, 0.08353739671292715, 0.04543719369394239, 0.055585113223060034, 0.04061624320456758, 0.033748527348507196, 0.01877653288829606, 0.061888273630756885, 0.04004642592917662, 0.015709279214206617, 0.06839826688519679, 0.0114820635644719, 0.02077203811495565, 0.038147054801811464, 0.024331671520485543, 0.03120707973721437, 0.1262062496971339, 0.04085639848199207, 0.03400322500965558, 0.1264785585226491, 0.057625926565378904, 0.03341825678944588, 0.02601628737465944, 0.09676369285443798, 0.053435842419276014, 0.05578062831773423, 0.02721512119023828, 0.0035927218277720385, 0.06358323502354324, 0.04147291911067441, 0.06096549463109113, 0.03919502669305075, 0.00605259836447658, 0.044391656047082506, 0.06138692318927497, 0.034553735313238576, 0.05827535402204376, 0.03363810319569893, 0.021864742957404815, 0.04765239318658132, 0.05913871296797879, 0.0696872734988574, 0.035299693918204866, 0.009837699944910128, 0.07131931561161764, 0.007655464796698652, 0.029920854321972, 0.010668488812370924, 0.027979058322671335, 0.06088355410611257, 0.03260796882386785, 0.01034974566209712, 0.056718035048106685, 0.05438227737613488, 0.059864032446057536, 0.0041856924872263335, 0.0364122586324811, 0.02522489448892884, 0.02425921007670695, 0.05578488824539818, 0.013141877770976862, 0.041471557269687764, 0.023356535857601557, 0.08062170629273169, 0.043298646924085915, 0.04551692632958293, 0.031674777492298745, 0.048754794188425876, 0.018984248890774325, 0.03770727664232254, 0.03959760841098614, 0.029805513440805953, 0.016732821459299885, 0.18482562998542562, 0.05842204322107136, 0.10772347741294652, 0.01907490222947672, 0.33313133055344224, 0.2284258115105331, 0.2343820661189966, 0.23963014857145026, 0.2795753418467939, 0.34712921536993235, 0.10409918439108878, 0.22974157996941358, 0.9926300577353686, 1.3375528086908162, 0.5080096435267478, 0.33010817714966834, 0.3655568906106055, 1.4500647713430226, 6.720449058339, 10.079221352934837, 8.127286043018103, 8.297004885971546, 11.277210619300604, 11.882978864014149, 5.137868179008365, 1.0235592699609697, 0.2667471411405131, 0.13939457014203072, 0.06964578002225608, 0.20609774946933612, 0.38587520190048963, 0.12456700875191018, 0.0904882034228649, 0.10408893533167429, 0.0267968671687413, 0.023740318974887487, 0.09758003303431906, 0.013278209371492267, 0.06135345603979658, 0.05591313136392273, 0.1187813442084007, 0.22345300647430122, 0.09187447591102682, 0.03884202415065374, 0.04303547022573184, 0.009885317995212972, 0.03232379676774144, 0.015068684242578456, 0.025955824603443034, 0.04883287183474749, 0.03463714900135528, 0.04206928671919741, 0.02733041012106696, 0.03959296256653033, 0.025150984001811594, 0.04920841340208426, 0.04335827848990448, 0.020724039713968523, 0.02626799603604013, 0.022811413546151016, 0.012715880366158672, 0.06853961633169092, 0.012809938307327684, 0.009427569657418644, 0.005981846179565764, 0.02996097297000233, 0.07612312620040029, 0.056538839780841954, 0.09949119688826613, 0.02957189833978191, 0.0689224161033053, 0.03309951920527965, 0.01607598922419129, 0.022731289427611046, 0.03919261471310165, 0.010358132858527824, 0.011204851925867843, 0.029919002663518768, 0.03871410015563015, 0.07308311120141298, 0.07801030384143814, 0.03238794059143402, 0.013287817400851054, 0.009585383650119184, 0.09730209872941487, 0.03897644564858638, 0.03337244772410486, 0.04886319598881528, 0.007110804472176824, 0.0455949928436894, 0.04282441455870867, 0.014123988694336731, 0.03949288395233452, 0.0433383332710946, 0.021303118992364034, 0.009299894281866727, 0.048390277224825695, 0.04428550666489173, 0.06985011554206721, 0.0325576512113912, 0.05580988377914764, 0.07660089118871838, 0.040476311260135844, 0.04551156431261916, 0.05074605061963666, 0.015933237118588295, 0.009841894006967777, 0.02482348536432255, 0.004395770374685526, 0.02530560304876417, 0.09355875779874623, 0.1970730852917768, 0.13411142863333225, 0.23045481357257813, 0.181573434965685, 0.09872507784166373, 0.1951106241904199, 0.14574564731447026, 0.10035117535153404, 0.24611509434180334, 0.24257856770418584, 0.124414823949337, 0.17626094893785194, 0.1205659718834795, 0.17744345735991374, 0.11706520192092285, 0.3031927964184433, 0.15400238160509616, 0.10283363706548698, 0.1206764776725322, 0.09084601508220658, 0.11767735501052812, 0.1357146754162386, 0.12302990959142335, 0.2486749694799073, 0.2272732710116543, 0.12865073571447283, 0.11037298172595911, 0.14501095080049708, 0.13125306169968098, 0.13038589182542637, 0.11837040961836465, 0.13654435198986903, 0.1689480186905712, 0.10026681542512961, 0.07641858261195011, 0.08984713625977747, 0.1592652327963151, 0.1817939567263238, 0.0776315710390918, 0.1472808836842887, 0.15410237858304754, 0.14961315697291866, 0.0947595750039909, 0.07257525212480687, 0.10357789244153537, 0.1347252886625938, 0.177463406289462, 0.07339640142163262, 0.09400975352036767, 0.11448128119809553, 0.10756335163023323, 0.08603391470387578, 0.1340753899421543, 0.10817354544997215, 0.09377064096042886, 0.12844094540923834, 0.14704065048135817, 0.11027374916011468, 0.15370878798421472, 0.21949890302494168, 0.10680634615710005, 0.13618503377074376, 0.2141454059164971, 0.10725604312028736, 0.15499810629989952, 0.38231137907132506, 0.22143580456031486, 0.20452749857213348, 0.5417987960390747, 0.7019341376144439, 0.6051245355047286, 0.4662719409679994, 0.3735472384141758, 0.3598469845019281, 0.5639297585003078, 0.18123283371096477, 0.8712541207205504, 2.8504217974841595, 3.2376362197101116, 2.5343279214575887, 2.319435914978385, 1.6753299837000668, 5.210485132411122, 14.124795868992805, 18.94845273345709, 13.546725288033485, 15.132609140127897, 18.65585893392563, 22.189920097589493, 11.585093848407269, 2.7235214319080114, 0.5188835319131613, 0.12268288133782335, 0.23667739529628307, 0.33044223266188055, 0.7426249072887003, 0.1815104266279377, 0.31829526415094733, 0.29356883314903826, 0.11032790367607959, 0.2246712418855168, 0.1795947356731631, 0.07403994735796005, 0.1931934934691526, 0.22612070082686841, 0.31834169290959835, 0.34283606917597353, 0.13083030469715595, 0.1751173587399535, 0.17675302253337577, 0.14435843972023576, 0.1659216740517877, 0.15559473366010934, 0.16048269637394696, 0.12154570329585113, 0.1672458287794143, 0.08728412925847806, 0.172743376751896, 0.08002689719432965, 0.13461984432069585, 0.14287738013081253, 0.153420923743397, 0.1431201514787972, 0.19718304189154878, 0.16214760078582913, 0.10841066163266078, 0.13647234882228076, 0.1267466667923145, 0.04982370577636175, 0.1241128366382327, 0.09664107521530241, 0.11412352891056798, 0.1587671774905175, 0.17886474437545985, 0.09344025907921605, 0.10735661155194975, 0.18312388536287472, 0.08018902677576989, 0.14867482997942716, 0.10194766116910614, 0.11168313954840414, 0.09710168174933642, 0.1317988074151799, 0.20193626027321443, 0.12477930751629174, 0.17799321067286655, 0.10987367961206473, 0.12533290515420958, 0.11448770077549852, 0.2038607679423876, 0.21761052310466766, 0.17566113034263253, 0.15268316958099604, 0.16847486986080185, 0.1871576509438455, 0.12619465735042468, 0.07671990941162221, 0.12754002265864983, 0.17492160986876115, 0.10779343225294724, 0.14342002366902307, 0.15138830000068992, 0.11282105231657624, 0.11321335899992846, 0.08568229255615734, 0.1739044371061027, 0.16183561674552038, 0.1419800939038396, 0.1290631026495248, 0.22514007141580805, 0.1317460704012774, 0.1290832890663296, 0.19873703975463286, 0.10035615516244434, 0.10636580729624256, 0.1853040183777921], [0.013631015244754963, 0.1105742967047263, 0.08166970044840127, 0.0466373837844003, 0.05683857838448603, 0.027140212514495943, 0.08473007997963578, 0.018330830534978304, 0.08407975823502056, 0.032541149557800964, 0.07277144628460519, 0.03044309250981314, 0.0412768770911498, 0.07103389303665608, 0.05718705382605549, 0.0320854449091712, 0.055745866120560095, 0.04732896893983707, 0.06400271173333749, 0.05310177948558703, 0.03604828343668487, 0.11281014274572954, 0.01782721097697504, 0.031090375159692485, 0.01817430973460432, 0.047611660411348566, 0.05093478619528469, 0.07632051521795802, 0.047560326056554914, 0.05522553896298632, 0.010204577865806641, 0.007569587178295478, 0.02983089303597808, 0.01091928648747853, 0.021909500028414186, 0.038541432077181526, 0.05837557735503651, 0.01706488801573869, 0.06419823053875007, 0.08537563713616692, 0.04809480597032234, 0.040124028600985184, 0.03645489130576607, 0.057215244305552915, 0.028304833322181366, 0.08893237987649627, 0.02068428471829975, 0.03713861711730715, 0.022479834951809607, 0.04266327574441675, 0.018447605616529472, 0.03365146185387857, 0.04954450239893049, 0.021540173947869334, 0.016661645786371082, 0.00807580147011322, 0.034170605285908096, 0.05684610747266561, 0.06438587515731342, 0.04327230810304172, 0.036334919423097745, 0.04912179363600444, 0.015887632143858355, 0.06524599462863989, 0.19972642650827765, 0.4450708004878834, 0.18348164507187903, 0.06738286043400876, 2.368887886404991, 9.334462266415358, 15.475201606750488, 32.972225323319435, 30.367803275585175, 31.19712397456169, 35.762609392404556, 58.42537231743336, 76.12392961978912, 88.41113269329071, 85.57724475860596, 84.64558035135269, 78.91771450638771, 82.61550888419151, 92.26844251155853, 117.5531293451786, 111.8899056315422, 111.61456480622292, 112.98765152692795, 122.5122432410717, 115.50741031765938, 99.28937137126923, 82.95899525284767, 69.20679599046707, 66.87537029385567, 65.50230637192726, 66.64409190416336, 36.687741950154305, 24.128104895353317, 14.640260059386492, 5.7489665877074, 1.5832524932920933, 0.2798746945336461, 0.7031531003303826, 0.40083547413814813, 0.3953461046330631, 0.11425380551372655, 0.10841531489859335, 0.07767809627694078, 0.049570729897823185, 0.030428937898250297, 0.024953307402029168, 0.0799380472744815, 0.039831674366723746, 0.04625640227459371, 0.08677482299390249, 0.06184337740705814, 0.04850126540986821, 0.08517819616827182, 0.059253397048451006, 0.055085963249439374, 0.06745884893462062, 0.03945826647395734, 0.038550222816411406, 0.014961019951442722, 0.0795650586951524, 0.05620358198939357, 0.060894359776284546, 0.005685486667061923, 0.09454772152821533, 0.06849963683634996, 0.04428940294019412, 0.0545396312372759, 0.04472889908356592, 0.08937190199503675, 0.009001163143693702, 0.010783617253764533, 0.03493197829811834, 0.08743192796828225, 0.07126418888219632, 0.02846039304131409, 0.04094182339031249, 0.0030950886184655246, 0.02166933918488212, 0.06240656730369665, 0.03310641746793408, 0.040453404872096144, 0.007092210425980738, 0.08347858893102966, 0.09949442523065954, 0.03686862750328146, 0.03981742884207051, 0.04184971119684633, 0.051095479720970616, 0.014496631247311598, 0.059536730477702804, 0.04369079033494927, 0.037329831466195174, 0.05511084746103734, 0.04920982348266989, 0.0350913804868469, 0.03166718532156665, 0.047753911567269824, 0.062498185434378684, 0.05622179800411686, 0.023611971955688205, 0.09494982456089929, 0.03453820216236636, 0.043510786126716994, 0.05299218282743823, 0.03244612496928312, 0.04959783313097432, 0.009532213407510426, 0.05599872696620878, 0.07882856618380174, 0.08481809869408607, 0.08474711969029158, 0.03965945157688111, 0.0232191754548694, 0.06207808532053605, 0.014379281001311028, 0.04049236391438171, 0.04052912619954441, 0.023920061576063745, 0.08460289071081206, 0.03376308457518462, 0.05013756745029241, 0.024976451277325395, 0.02967616823298158, 0.06471098036854528, 0.041714328617672436, 0.08953037278843112, 0.03463286680926103, 0.028552560361276846, 0.05677254950569477, 0.035477980054565705, 0.03336580550239887, 0.036854942300124094, 0.01003977284199209, 0.05067335725470912, 0.032891346781980246, 0.03593615234422032, 0.04439064672624227, 0.03078642115724506, 0.011967434638791019, 0.008856722652126336, 0.03285458449681755, 0.04049817121995147, 0.01988727191928774, 0.013461867729347432, 0.009153085411526263, 0.04530590776994359, 0.036174455963191576, 0.029844799028069247, 0.009831621755438391, 0.07858929035137407, 0.06529628255520947, 0.05060943978605792, 0.08202046912629157, 0.11121597242890857, 0.057695688446983695, 0.014657344254374038, 0.05869058564712759, 0.010241492291243048, 0.024286114785354584, 0.05362779149436392, 0.018283594690728933, 0.054078512621345, 0.016228346576099284, 0.0466839498403715, 0.04234483501932118, 0.02042937554506352, 0.08789300205535255, 0.05557860458793584, 0.027166744293936063, 0.05080613860627636, 0.022154527505335864, 0.06218744449142832, 0.03166695525578689, 0.032435838802484795, 0.05732079254812561, 0.135375706886407, 0.14252569118980318, 0.3998876624973491, 0.23745020851492882, 0.15359320590505376, 1.0352779598906636, 7.005469864234328, 12.546662651002407, 30.627460442483425, 28.11225190758705, 30.17837394028902, 33.337913900613785, 59.40055578947067, 80.96711933612823, 93.91910433769226, 89.53872978687286, 91.97227880358696, 85.62234073877335, 82.56417363882065, 102.12019667029381, 126.27961188554764, 123.24522390961647, 123.08733478188515, 125.22524446249008, 136.1756792664528, 130.73630154132843, 110.73800504207611, 89.09555196762085, 66.67827486991882, 66.24537169933319, 62.913220301270485, 66.47093519568443, 35.05761422216892, 23.49315896630287, 13.372205402702093, 4.679922927170992, 1.328672922682017, 0.203705451276619, 0.6218890578020364, 0.22644616226898506, 0.40786797646433115, 0.0883662844717037, 0.001232248782798706, 0.06552176186232828, 0.02562550394941354, 0.05517643476196099, 0.06143584556411952, 0.13598723657196388, 0.030587006076530088, 0.05028350336942822, 0.04449013533303514, 0.06819641013862565, 0.0351100826082984, 0.12061510948115028, 0.04977748110832181, 0.005196768970563426, 0.008765252023295034, 0.06190392181451898, 0.012407072717905976, 0.02009435153013328, 0.020687982469098642, 0.03511685841658618, 0.02125435246853158, 0.016727739603084046, 0.08972347219241783, 0.0377465696510626, 0.011590296526264865, 0.035988674135296606, 0.0562930330488598, 0.031385243419208564, 0.04276586652849801, 0.015237947718560463, 0.05481864536704961, 0.065448741952423, 0.027428668618085794, 0.022542694860021584, 0.10565014687017538, 0.04239944966684561, 0.06832984086940996, 0.01900052975543076, 0.008505051337124314, 0.022120592802821193, 0.035086805146420375, 0.03680736692331266, 0.07568315137177706, 0.08007382319192402, 0.025762183431652375, 0.022433254052884877, 0.03975046856794506, 0.025362071210111026, 0.07247054250910878, 0.044616511950152926, 0.02897181813750649, 0.03824268795142416, 0.08260289177997038, 0.05112284270580858, 0.05093539846711792, 0.0033640591709627188, 0.07651934400200844, 0.04263160088157747, 0.03659153182525188, 0.0383818888803944, 0.044294698163867, 0.06257263026782311, 0.015530540367763024, 0.021203374344622716, 0.05141171255672816, 0.011942035562242381, 0.031423608743352816, 0.06655765158939175, 0.031229166052071378, 0.10101664433022961, 0.02621494175400585, 0.12876800989033654, 0.17380142700858414, 0.1872023133910261, 0.12438358695362695, 0.23216604284243658, 0.10538919290411286, 0.15720457071438432, 0.13579356571426615, 0.15302366693504155, 0.14492236805381253, 0.1494022979750298, 0.12577676883665845, 0.11212416080525145, 0.16574143606703728, 0.13460351707180962, 0.18108360265614465, 0.14131364529021084, 0.08008937860722654, 0.15944299200782552, 0.10375591140473261, 0.11966316407779232, 0.19481446273857728, 0.1669739800854586, 0.25386660418007523, 0.14039023546501994, 0.12330870478763245, 0.23649265989661217, 0.1450793768162839, 0.10814636058057658, 0.135697502119001, 0.1452869109925814, 0.17222605529241264, 0.1254362566396594, 0.08945230627432466, 0.15855432953685522, 0.09175394370686263, 0.16482093546073884, 0.2249825283070095, 0.12695562589215115, 0.18198275909526274, 0.17444457218516618, 0.1658151313313283, 0.08086300076683983, 0.08373287841095589, 0.13595735770650208, 0.2253921196097508, 0.06951696545002051, 0.19778625952312723, 0.096705790492706, 0.1285118650412187, 0.13858261605491862, 0.12530934938695282, 0.13148602185538039, 0.14331459417007864, 0.19554492901079357, 0.1637652303907089, 0.18571080436231568, 0.16422968124970794, 0.1346368543454446, 0.1469437705236487, 0.10601112750009634, 0.12068536118022166, 0.1521940200473182, 0.30273121024947613, 0.4385008045937866, 0.7119628682266921, 0.30829939583782107, 0.22734089550795034, 3.5321071185171604, 14.806446991860867, 24.86113116145134, 47.387158423662186, 45.34395486116409, 43.67147460579872, 51.82281240820885, 86.09424501657486, 107.1038344502449, 124.06036376953125, 116.35101824998856, 116.07161924242973, 111.8600544333458, 110.81107512116432, 125.37466764450073, 158.01312267780304, 148.4566354751587, 147.82343745231628, 152.34198778867722, 164.51074361801147, 156.7241406440735, 137.07597255706787, 116.60658493638039, 95.39629027247429, 93.22320207953453, 91.73069536685944, 95.87201714515686, 57.48178035020828, 37.41481773555279, 22.238931767642498, 7.9540979862213135, 1.7680471460334957, 0.2863288560183719, 0.7942072581499815, 0.48588874458801, 0.7053685595747083, 0.28492495010141283, 0.19527612312231213, 0.19197821180569008, 0.08309378536068834, 0.08940943240304478, 0.13134116947185248, 0.23033038509311154, 0.07584387829410844, 0.1529586993274279, 0.17608229914912954, 0.1538281698594801, 0.1371591619681567, 0.23399316589348018, 0.1767003448912874, 0.08373167613171972, 0.1285563493729569, 0.16472922085085884, 0.10087369184475392, 0.14801083045313135, 0.19229930941946805, 0.16193764720810577, 0.15007104724645615, 0.1641197394928895, 0.20259467884898186, 0.15977810136973858, 0.15061003941809759, 0.19458184397080913, 0.11724330252036452, 0.1313182371086441, 0.18326645193155855, 0.1695128227584064, 0.14444843254750594, 0.22223247040528804, 0.17789655335946009, 0.12941921479068696, 0.18034727341728285, 0.08431115988059901, 0.15404600504552945, 0.11112099979072809, 0.1394247607095167, 0.13546771835535765, 0.17134303314378485, 0.27785694343037903, 0.13263799832202494, 0.1259037057752721, 0.12796751456335187, 0.07545943837612867, 0.14575302426237613, 0.13885183754609898, 0.14537405397277325, 0.1826076177530922, 0.10765258746687323, 0.19479593873256817, 0.14336580235976726, 0.145261945144739, 0.12148494366556406, 0.15844379406189546, 0.1895332953426987, 0.12089141848264262, 0.09577292570611462, 0.26703536161221564, 0.17729179206071422, 0.16221871337620541, 0.14539275609422475, 0.16922973794862628, 0.14040237700100988, 0.11060445016482845, 0.15128753118915483, 0.15260809392202646, 0.1036511646816507, 0.23638107057195157, 0.1531912587233819], [0.023491261636081617, 0.04338590122642927, 0.046372874930966645, 0.03395455496502109, 0.04310866082960274, 0.056328982682316564, 0.053082654339959845, 0.05770368508819956, 0.08680706188897602, 0.020882415883534122, 0.040677459255675785, 0.033557305578142405, 0.08295988707686774, 0.06425985106034204, 0.045523015651269816, 0.06878336731460877, 0.05477170452650171, 0.10916905492194928, 0.05346992184058763, 0.08497976072249003, 0.02971183213958284, 0.03194308614183683, 0.028559191450767685, 0.015558074046566617, 0.015381530101876706, 0.028655049100052565, 0.024213323085859884, 0.08414740499574691, 0.04533136343525257, 0.02713049037993187, 0.027317420681356452, 0.02878459283238044, 0.060520202314364724, 0.06520291295601055, 0.018599499126139563, 0.04266362826456316, 0.037641629969584756, 0.053567896466120146, 0.045211963006295264, 0.030583081970689818, 0.04559948654787149, 0.04086755667231046, 0.0559664101456292, 0.037437027276610024, 0.04375619952043053, 0.04551863326923922, 0.04353031203208957, 0.00767149101193354, 0.043402042938396335, 0.031021257091197185, 0.06899264553794637, 0.04335310572059825, 0.02396405609033536, 0.03179034101776779, 0.013565293429564917, 0.03042858723347308, 0.047257848927984014, 0.09652279171859846, 0.09312270150985569, 0.045966196557856165, 0.04612960263330024, 0.10727969536674209, 1.0837979125790298, 5.267758509144187, 7.559709073975682, 16.414171122014523, 23.714453391730785, 44.34258319437504, 79.9812850356102, 95.52797600626945, 105.50865724682808, 115.89113652706146, 100.77201381325722, 108.55452820658684, 110.46742156147957, 108.06439250707626, 99.48747754096985, 89.87160712480545, 109.7184969484806, 105.04151031374931, 109.99712839722633, 106.17289200425148, 114.38162192702293, 101.95813536643982, 109.15695548057556, 107.6842837035656, 100.76433822512627, 105.73952525854111, 96.4787457883358, 103.20120826363564, 123.14014434814453, 122.10034534335136, 118.99273529648781, 108.81932839751244, 114.45820301771164, 116.02624207735062, 109.37631011009216, 108.90097081661224, 78.99993449449539, 64.12481188774109, 50.88607147336006, 30.07614992558956, 13.881610818207264, 4.179032379761338, 0.5532909231260419, 0.17168195714475587, 0.3523322643013671, 0.11084451267379336, 0.027237231624894775, 0.044905389222549275, 0.032328873057849705, 0.02510878177417908, 0.11870559319504537, 0.015016868419479579, 0.028312210270087235, 0.01830972199968528, 0.09112072104471736, 0.04888396870228462, 0.010102143860422075, 0.06073384436604101, 0.072713900153758, 0.06471888424130157, 0.03735776961548254, 0.018253623056807555, 0.053209862162475474, 0.07050246334983967, 0.031484190258197486, 0.033229536056751385, 0.03227020628401078, 0.024334988920600154, 0.0185256368786213, 0.0529058524989523, 0.048478099270141684, 0.09246111396350898, 0.008555794756830437, 0.014121790081844665, 0.05408229386375751, 0.027974017284577712, 0.015663783706258982, 0.03061762523429934, 0.04299645181163214, 0.06077181264117826, 0.06617848091991618, 0.04939637343341019, 0.051949138796771877, 0.033055276071536355, 0.03480602470517624, 0.009264427972084377, 0.028277045457798522, 0.03677525790408254, 0.045913303692941554, 0.07634557754499838, 0.01041752044329769, 0.05851903079019394, 0.025642862783570308, 0.007558806555607589, 0.028377378257573582, 0.02753460834355792, 0.030340093544509728, 0.08324244496179745, 0.018231082176498603, 0.05113822371640708, 0.05712203055736609, 0.02222483486548299, 0.017531329685880337, 0.07450208271620795, 0.03688322183734272, 0.08145990272169001, 0.036003097775392234, 0.06935514757060446, 0.024278092168970034, 0.021517903951462358, 0.01355501932266634, 0.07955108405440114, 0.02728382922214223, 0.05194788827793673, 0.022656837172689848, 0.058438203486730345, 0.026679244183469564, 0.022533937517437153, 0.062331536173587665, 0.04846310788707342, 0.023592555517097935, 0.06390040667611174, 0.04947218381857965, 0.05396786211349536, 0.06380363804055378, 0.06884715490741655, 0.040717383089940995, 0.09051955174072646, 0.002759753133432241, 0.07108128658728674, 0.02508956200472312, 0.03227486326068174, 0.046379598788917065, 0.029415765311568975, 0.01043542939441977, 0.03514069248922169, 0.0929588575672824, 0.029978801212564576, 0.030047000873310026, 0.033718507474986836, 0.021494917782547418, 0.06451348745031282, 0.02649829002621118, 0.015587453817715868, 0.08604454225860536, 0.07340635362197645, 0.020799184021598194, 0.04067682100867387, 0.03970927566115279, 0.03979781758971512, 0.02603554054076085, 0.029011908954998944, 0.04606166643498, 0.010406491201138124, 0.03523998813761864, 0.08393811192945577, 0.06573603473952971, 0.009423725332453614, 0.036434771682252176, 0.029913089601905085, 0.045595976189360954, 0.05541896120121237, 0.02332346761249937, 0.023246388154802844, 0.06800305840442888, 0.049347963140462525, 0.0034354676927250694, 0.046040274028200656, 0.05981888389214873, 0.04875590369920246, 0.04953233859851025, 0.018161886182497256, 0.0640965488855727, 0.08533239219104871, 0.062381824100157246, 0.08647256108815782, 0.31323895265813917, 3.646503542549908, 5.30035980977118, 14.109783824533224, 21.079572178423405, 46.88535735011101, 87.94100672006607, 106.95709392428398, 117.58337572216988, 132.52962291240692, 120.0942961871624, 128.830187022686, 127.20136642456055, 131.85599505901337, 119.74618166685104, 114.26093280315399, 129.8790067434311, 120.42862504720688, 125.67846894264221, 129.17291343212128, 135.2912539243698, 124.47531670331955, 131.30741089582443, 124.3433877825737, 120.72460636496544, 119.571892619133, 117.52136304974556, 127.04302132129669, 142.51487910747528, 146.53618812561035, 138.98033916950226, 130.727698802948, 134.17645454406738, 136.52390778064728, 128.48139613866806, 126.98505163192749, 92.21871078014374, 76.97772860527039, 56.462184861302376, 34.92430977523327, 16.939207948744297, 4.660020070150495, 0.4370282351737842, 0.07220539540867321, 0.24770565039943904, 0.15457818430149928, 0.0077932074054842815, 0.0248830315831583, 0.09623015546821989, 0.052220571888028644, 0.11651095119304955, 0.06875623439555056, 0.008428197306784568, 0.0671780202537775, 0.11562862666323781, 0.08825972690829076, 0.04068284353706986, 0.059318876737961546, 0.053366403371910565, 0.031201721430988982, 0.01820375444367528, 0.016997632737911772, 0.024412437596765812, 0.07028666906990111, 0.021626199995807838, 0.08167529624188319, 0.06642933425609954, 0.016633590748824645, 0.034925443687825464, 0.013091382970742416, 0.01755957397108432, 0.018641367387317587, 0.018249493004987016, 0.03740334490430541, 0.021894992896704935, 0.058435461251065135, 0.02172287586290622, 0.013780848366877763, 0.03162229651934467, 0.11068153704400174, 0.06268206736422144, 0.009569079593347851, 0.03354234388098121, 0.06105371743615251, 0.021573281155724544, 0.016736057223170064, 0.036256793537177145, 0.04250671227055136, 0.06991826696321368, 0.013193274280638434, 0.09623385878512636, 0.07399405294563621, 0.0493439852289157, 0.03663568219053559, 0.04007573705166578, 0.050882075156550854, 0.01810194105928531, 0.09523271641228348, 0.03682233604195062, 0.06559743866091594, 0.03767359427001793, 0.027185244180145673, 0.020823712002311368, 0.14743815961992368, 0.044404966465663165, 0.07299380115000531, 0.024831348418956622, 0.020238363431417383, 0.020365858836157713, 0.04263162685674615, 0.04715784823929425, 0.040988151959027164, 0.058387206809129566, 0.0425560576695716, 0.12239029703778215, 0.1712105597835034, 0.1284716703230515, 0.11918323943973519, 0.16109081218019128, 0.15279398707207292, 0.1780288782902062, 0.19606072164606303, 0.13874027790734544, 0.13190916477469727, 0.12578393798321486, 0.3200558165553957, 0.1846251610550098, 0.20036449539475143, 0.10608377633616328, 0.1655148880672641, 0.27663275599479675, 0.23451437620678917, 0.19101392448646948, 0.09836112119955942, 0.1210620827623643, 0.08377041624044068, 0.15267922135535628, 0.05747039096604567, 0.15912726754322648, 0.1394723026896827, 0.1675184047780931, 0.1819676934974268, 0.13671998865902424, 0.13321004575118423, 0.10281757698976435, 0.16997647209791467, 0.1892152553773485, 0.17776917113224044, 0.13383962446823716, 0.13775489875115454, 0.14265841688029468, 0.08943322565755807, 0.11654260379145853, 0.16176748758880422, 0.1018114473845344, 0.16581771400524303, 0.13426135730696842, 0.16884987708181143, 0.15437752241268754, 0.10725695596192963, 0.2706702228169888, 0.18637375003891066, 0.1142395636998117, 0.1700047479243949, 0.2086497875279747, 0.24721503141336143, 0.1504460396245122, 0.26867978274822235, 0.19452717737294734, 0.14729661721503362, 0.13546455680625513, 0.15994330344256014, 0.16089176817331463, 0.17129647079855204, 0.11852754454594105, 0.4593236278742552, 2.2452695947140455, 9.062199275940657, 12.987139765173197, 26.694192700088024, 35.302412286400795, 66.69865697622299, 109.61182907223701, 127.8518459200859, 139.1917446255684, 148.88742595911026, 137.0738598704338, 144.94376957416534, 145.26760339736938, 140.90025454759598, 130.25883436203003, 119.0212033689022, 140.46914488077164, 135.8783832192421, 142.4744188785553, 140.72385281324387, 148.16535830497742, 133.1914258003235, 141.4327123761177, 138.83052080869675, 131.76294565200806, 136.16101205348969, 126.09434142708778, 136.39497309923172, 157.89798885583878, 155.880266726017, 153.73187720775604, 144.06533271074295, 147.8429228067398, 152.21078842878342, 150.52302539348602, 152.45649844408035, 114.75477710366249, 97.9962931573391, 73.06528374552727, 46.55047371983528, 22.711447812616825, 7.8512398805469275, 1.3610129873268306, 0.23339864623267204, 0.5894177814479917, 0.42046112415846437, 0.2461189535097219, 0.1336171879665926, 0.22833593742689118, 0.176409482373856, 0.23277709755348042, 0.14186298300046474, 0.11008347733877599, 0.20486915367655456, 0.2495386661030352, 0.1318465275107883, 0.1115101894538384, 0.14886029268382117, 0.16533968184376135, 0.17734426190145314, 0.07775317193591036, 0.14902362454449758, 0.1397203581291251, 0.1201809011399746, 0.10573532315902412, 0.161884568806272, 0.16917795088374987, 0.08460444922093302, 0.10380174644524232, 0.15909422712866217, 0.11683194490615278, 0.1611561657045968, 0.11962103235418908, 0.09909869724651799, 0.22550008725374937, 0.15399864118080586, 0.08574009101721458, 0.08538495108950883, 0.14815725618973374, 0.2561035560211167, 0.1935553053044714, 0.20690587407443672, 0.2034603792708367, 0.14807812840444967, 0.09290695175877772, 0.2357886586105451, 0.12455262592993677, 0.15286412002751604, 0.1894160805386491, 0.19085571344476193, 0.1252550390199758, 0.200256587122567, 0.1461688644485548, 0.08442340971669182, 0.14008010679390281, 0.12223644982441328, 0.10397873382316902, 0.17592575051821768, 0.09513807774055749, 0.17202983144670725, 0.13968332496006042, 0.09818887614528649, 0.14274808316258714, 0.1913862451328896, 0.1105193406692706, 0.20418217725818977, 0.1427383758709766, 0.11312525122775696, 0.10426973734865896, 0.14076179912080988, 0.08494012261508033, 0.16202447848627344, 0.13500328233931214, 0.11350500819389708], [0.06663289794232696, 0.033502635269542225, 0.0157090398715809, 0.020006637096230406, 0.04491898536798544, 0.024971673701656982, 0.008319253738591215, 0.06255214699194767, 0.058284256083425134, 0.02230556754511781, 0.043443172762636095, 0.05997276079142466, 0.003228056202715379, 0.014516634910251014, 0.026181890207226388, 0.028874099552922416, 0.02527995442505926, 0.030065576829656493, 0.05103053066704888, 0.11687208025250584, 0.04954878088028636, 0.04756457114126533, 0.031193888062261976, 0.023680401682213414, 0.028175191255286336, 0.05418215354438871, 0.04482060256123077, 0.02386556938290596, 0.08141199708916247, 0.019726042191905435, 0.033658441752777435, 0.03267411273554899, 0.03187241512932815, 0.01697301384410821, 0.04634374192391988, 0.04037982092995662, 0.02763919921562774, 0.037270652610459365, 0.050190823967568576, 0.06847853015642613, 0.07038797222776338, 0.008521232939529, 0.05256053860648535, 0.07358774193562567, 0.014457157340075355, 0.042851343387155794, 0.020598175178747624, 0.022445991162385326, 0.00254941827734001, 0.06520770723000169, 0.028916285082232207, 0.048871181497815996, 0.036543674432323314, 0.01821518537326483, 0.03512484021484852, 0.06843873619800434, 0.047909625282045454, 0.04935463504807558, 0.3571586584439501, 2.367497873492539, 11.928724609315395, 41.80162914097309, 66.27157509326935, 85.60955822467804, 98.58951732516289, 92.69216537475586, 103.72628688812256, 100.51476761698723, 98.91228720545769, 98.4381714463234, 100.58301955461502, 78.90857979655266, 84.80762645602226, 78.52279409766197, 86.41332149505615, 65.37845581769943, 69.41410526633263, 66.05934128165245, 89.58593085408211, 79.16632756590843, 87.70979672670364, 60.341400504112244, 82.42486551404, 81.61969631910324, 75.92811092734337, 87.8446514904499, 85.53136602044106, 96.54112324118614, 74.0259937942028, 66.74456611275673, 86.16756588220596, 92.5217293202877, 87.64744967222214, 82.14172750711441, 80.75128331780434, 104.68273356556892, 95.39009660482407, 105.18123641610146, 103.59806656837463, 107.8832258284092, 119.07319217920303, 122.5384770333767, 122.91581958532333, 86.66551396250725, 71.55699267983437, 36.017488315701485, 19.452345594763756, 2.9099833639338613, 0.1670491002732888, 0.17112332774559036, 0.3501652227714658, 0.06168796055135317, 0.062372458196477965, 0.05049811392382253, 0.017301367806794588, 0.04362884697911795, 0.02918321333709173, 0.014515819475491298, 0.04124521707126405, 0.008146829641191289, 0.012710583287116606, 0.006404838350135833, 0.06532321509439498, 0.02355165019253036, 0.06380937484209426, 0.054590661311522126, 0.0550553273933474, 0.0504910820745863, 0.0022953846064410754, 0.06577824067790061, 0.029733094670518767, 0.01150301810412202, 0.029983871936565265, 0.03557802898285445, 0.034021719329757616, 0.04907288610411342, 0.012328639768384164, 0.04060875122377183, 0.030611433867306914, 0.08070585099630989, 0.05308181200234685, 0.02685247814952163, 0.03224053521989845, 0.030654628717456944, 0.06314180558547378, 0.05414300896518398, 0.0392452775122365, 0.061639572522835806, 0.060975825326750055, 0.052138030223432, 0.011258070408075582, 0.03514124909997918, 0.03642780662630685, 0.06930122312041931, 0.042911112250294536, 0.00845318820211105, 0.06830118654761463, 0.017167066907859407, 0.047235335878212936, 0.10063446796266362, 0.0518001415184699, 0.06719880038872361, 0.0517133621906396, 0.04915307887131348, 0.02698129457712639, 0.03313969536975492, 0.028126795805292204, 0.08081758132902905, 0.04607852803019341, 0.0489509883482242, 0.07019799726549536, 0.06054107521777041, 0.04563553637126461, 0.05236742064880673, 0.04893851655651815, 0.06911347460118122, 0.03029480212717317, 0.021793457817693707, 0.0887479264929425, 0.10469901782926172, 0.02940159956779098, 0.022170906704559457, 0.02540949444664875, 0.05048364204412792, 0.04979147430276498, 0.04871891505899839, 0.02968809083540691, 0.03910598381480668, 0.06867515476187691, 0.051165241602575406, 0.019081876562268008, 0.01300167030422017, 0.013220518521848135, 0.011323398884997005, 0.012176373329566559, 0.019431496766628698, 0.12843318254454061, 0.012593584633577848, 0.011026399733964354, 0.012945762464369182, 0.046361534914467484, 0.021386571643233765, 0.01728111645206809, 0.054399231739807874, 0.11630423337919638, 0.0884838035563007, 0.008149566310748924, 0.019521821704984177, 0.049819397609098814, 0.02494976364687318, 0.01891646668809699, 0.05801180624985136, 0.03384352596185636, 0.05334873654646799, 0.08284929223009385, 0.026789278708747588, 0.05438561704067979, 0.02463372005877318, 0.07506356938392855, 0.09655233661760576, 0.005941473345956183, 0.05385104435845278, 0.031098178842512425, 0.0265756366570713, 0.04449473293789197, 0.06087029192713089, 0.02873718814953463, 0.01800928577722516, 0.04008220486866776, 0.014492189493466867, 0.05428817305073608, 0.10195612165261991, 0.06195576454047114, 0.058945134878740646, 0.19046460161916912, 1.1229703668504953, 10.570190157741308, 40.31596966087818, 67.3217323422432, 88.64044278860092, 103.9886400103569, 103.03321927785873, 117.63332024216652, 114.25285443663597, 113.33878308534622, 108.86145293712616, 111.86339065432549, 99.21221271157265, 100.55411070585251, 108.06403532624245, 114.51212972402573, 90.66234469413757, 99.01853710412979, 91.90498441457748, 119.06332790851593, 119.09419745206833, 119.09299671649933, 92.68638968467712, 108.57117891311646, 108.67102235555649, 101.2837627530098, 122.70874589681625, 112.194664478302, 123.3936895430088, 98.31771790981293, 97.37194865942001, 119.24245789647102, 119.35642138123512, 119.5168487727642, 104.71566259860992, 113.58561784029007, 119.81647789478302, 118.6919966340065, 127.19091698527336, 123.21858733892441, 129.7665023803711, 144.07750725746155, 141.94711357355118, 144.0302073955536, 104.89051401615143, 86.28098979592323, 43.63769441843033, 25.637689791619778, 4.537919797003269, 0.15105943952221423, 0.17911864793859422, 0.2283249536412768, 0.1092788482492324, 0.057074770593317226, 0.1203366185654886, 0.030236009188229218, 0.0010487863983144052, 0.06538876157719642, 0.007339467592828441, 0.07196008591563441, 0.04663364707084838, 0.033615512220421806, 0.012191134646855062, 0.057759412957238965, 0.009068229173863074, 0.03523841478454415, 0.05774309684056789, 0.06353478762321174, 0.06411190392100252, 0.028509975927590858, 0.04700363366282545, 0.07935078581795096, 0.005192389371586614, 0.07853004470234737, 0.01819441451516468, 0.01901016654301202, 0.04295421989809256, 0.06370478397002444, 0.023922059808683116, 0.04533696293947287, 0.04089825561095495, 0.09348664330900647, 0.04113765760848764, 0.04995278752176091, 0.027582269067352172, 0.0875444152916316, 0.06226174460607581, 0.027402611813158728, 0.03577371848223265, 0.056252315116580576, 0.04449514854059089, 0.008491222342854599, 0.030708439990121406, 0.06317969964584336, 0.05284974984533619, 0.02439722913550213, 0.028027498301526066, 0.05296066010487266, 0.03320902309496887, 0.0600500146538252, 0.05613479603198357, 0.06747743231244385, 0.00858232375321677, 0.05138817534316331, 0.021258124434098136, 0.021935391705483198, 0.034186706179752946, 0.016830662498250604, 0.06812884501414374, 0.05835005489643663, 0.026414521962578874, 0.01981024626729777, 0.0560474786470877, 0.09195422710035928, 0.03946796263335273, 0.04863028778345324, 0.056726562324911356, 0.129207628488075, 0.13006630819290876, 0.1580940347048454, 0.14121161482762545, 0.1655268218019046, 0.10917439838522114, 0.10171801841352135, 0.16748813999583945, 0.1168525691900868, 0.15420371142681688, 0.13280925631988794, 0.17055353644536808, 0.18340851383982226, 0.1823326965677552, 0.1061229023616761, 0.09615067145205103, 0.10759558310383, 0.10211618064204231, 0.25480687560047954, 0.14883415424264967, 0.2240992835140787, 0.07845917702070437, 0.14566763275070116, 0.12176756834378466, 0.10099511462613009, 0.12750987662002444, 0.10503193785552867, 0.06689210786134936, 0.208789415191859, 0.25286491261795163, 0.09836984885623679, 0.11497505431179889, 0.13815847865771502, 0.12547088525025174, 0.19604515138780698, 0.1506153680384159, 0.21026474540121853, 0.18535497423727065, 0.21396121970610693, 0.1372072531376034, 0.14410351199330762, 0.0798180716810748, 0.2016819707932882, 0.19997863797470927, 0.12068245938280597, 0.11241774700465612, 0.10081575237563811, 0.12036798914778046, 0.1864693089737557, 0.14166517095873132, 0.17920349026098847, 0.08899029708118178, 0.12118720143917017, 0.09576984579325654, 0.24330345302587375, 0.24641082534799352, 0.18700681685004383, 0.15597109158989042, 0.5462735309265554, 4.375776322558522, 22.11892280727625, 61.926576644182205, 92.54008993506432, 116.2189069390297, 127.99699813127518, 123.73937219381332, 135.486761033535, 130.20645797252655, 124.11994457244873, 123.28481778502464, 122.8650239109993, 102.17358380556107, 106.61932244896889, 102.61228546500206, 110.43659001588821, 90.40905028581619, 93.49899128079414, 90.45730009675026, 119.19679954648018, 110.24611383676529, 115.07000058889389, 87.69313082098961, 110.45085445046425, 112.0241904258728, 103.82344767451286, 119.14415717124939, 114.28573787212372, 131.4162066578865, 103.47164735198021, 93.48044827580452, 117.51741126179695, 122.37488061189651, 120.21490931510925, 110.55477887392044, 113.68135750293732, 137.35328167676926, 128.39272409677505, 136.51451468467712, 135.032958984375, 142.9659453034401, 160.13717830181122, 161.27888023853302, 163.86465668678284, 123.91484677791595, 106.45902425050735, 56.111003905534744, 33.277432546019554, 7.245164327323437, 0.45089030696544796, 0.39765243243891746, 0.4552677314495668, 0.3254405432380736, 0.13627677806653082, 0.15954986127326265, 0.11280343373073265, 0.11938232797547244, 0.17425415193429217, 0.08700459933606908, 0.10577298715361394, 0.16349136305507272, 0.11935691683902405, 0.14887574419844896, 0.18675024155527353, 0.09941333817550912, 0.20141371409408748, 0.13402783311903477, 0.1484720455482602, 0.1397892739623785, 0.1627830127836205, 0.17252242454560474, 0.21959376434097067, 0.06939770231838338, 0.19053099415032193, 0.17221339425304905, 0.21050650742836297, 0.1517249085009098, 0.0879545632051304, 0.1413712656358257, 0.24352939246455207, 0.16077784850494936, 0.15968813822837546, 0.06860870285890996, 0.14549383660778403, 0.06609795047552325, 0.20421365916263312, 0.14775048504816368, 0.10035142026026733, 0.10942186010652222, 0.12653508048970252, 0.17544899485073984, 0.07301273333723657, 0.09663909368100576, 0.14793510170420632, 0.19322822598041967, 0.13370283180847764, 0.07220262719783932, 0.1368401720537804, 0.12674372788751498, 0.19013073906535283, 0.14276374247856438, 0.1558316420414485, 0.0882063145400025, 0.1266400350141339, 0.08214270827011205, 0.0725754228187725, 0.1730082047288306, 0.08844364594551735, 0.11608641303610057, 0.22046523867174983, 0.17651727190241218, 0.1280213796417229, 0.18340394221013412, 0.1879745625774376, 0.1283199159661308, 0.1668878018972464, 0.08834278065478429], [0.03361804294399917, 0.06982067454373464, 0.046675982885062695, 0.03893081098794937, 0.039351753439405, 0.03895392517733853, 0.07268892688443884, 0.038716081689926796, 0.02041669224126963, 0.023784881232131738, 0.08429856563452631, 0.034104227597708814, 0.08144733074004762, 0.02905450266553089, 0.04391237707750406, 0.018782505321723875, 0.06339774263324216, 0.11181784677319229, 0.0053946491971146315, 0.03624391356424894, 0.03398498673050199, 0.055379226614604704, 0.02445858062856132, 0.0059607061029964825, 0.0588707160204649, 0.08009167184354737, 0.00869721470735385, 0.010473221409483813, 0.025578537133696955, 0.03861545759718865, 0.03203412539733108, 0.032980111354845576, 0.07032676730887033, 0.025125856736849528, 0.007582587286378839, 0.1036274382204283, 0.07472670855349861, 0.0109894955130585, 0.04072467840160243, 0.019252989841334056, 0.04475727881072089, 0.054918119130888954, 0.06038269348209724, 0.03062976677028928, 0.03137758445518557, 0.09857494878815487, 0.05504942360857967, 0.026103677118953783, 0.03300030519312713, 0.12678548111580312, 0.018135181853722315, 0.04193601183942519, 0.04620756895747036, 0.01014276345813414, 0.03947465680539608, 0.02174514957005158, 1.2595609249547124, 7.075908584520221, 12.657641395926476, 43.62233564257622, 79.04063031077385, 96.84582129120827, 85.22813469171524, 84.04604092240334, 78.74882116913795, 86.47869318723679, 82.16651737689972, 76.64970740675926, 68.82928624749184, 66.25700667500496, 58.52045841515064, 34.33864340186119, 31.61541312932968, 30.61489261686802, 26.169839836657047, 27.801035307347775, 19.19949386268854, 16.539773382246494, 22.617294564843178, 24.471975043416023, 23.588140569627285, 28.61341081559658, 38.392250686883926, 30.101811848580837, 32.53396824002266, 22.813079059123993, 26.520314030349255, 18.29186126589775, 26.766662411391735, 37.2070524841547, 21.669919900596142, 23.774146288633347, 31.958287730813026, 25.34691609442234, 16.814447343349457, 46.32030487060547, 54.609282687306404, 52.38477945327759, 82.06206858158112, 70.62410473823547, 75.83481833338737, 103.12905013561249, 94.162078499794, 124.74801287055016, 120.25157734751701, 119.93447676301003, 112.43378564715385, 86.51390209794044, 54.99909996986389, 29.796644523739815, 7.745276391506195, 1.4656486851163208, 0.27273784624412656, 0.01480416703998344, 0.05703991191694513, 0.039687089156359434, 0.07987359174876474, 0.1136990798113402, 0.055658953206148, 0.05671967148373369, 0.058152205747319385, 0.01425870148523245, 0.06981367609114386, 0.05374014894186985, 0.07444786140695214, 0.02143759800674161, 0.04186923339148052, 0.0442760851001367, 0.025360304898640607, 0.022162375717016403, 0.013256092443043599, 0.026807648719113786, 0.03755719953915104, 0.06900368869537488, 0.06287299969699234, 0.05091509701742325, 0.022964555719227064, 0.01754936016368447, 0.019603346627263818, 0.043077212321804836, 0.06731649758876301, 0.06189511994307395, 0.003917773465218488, 0.015839711668377277, 0.023072933399816975, 0.030698170521645807, 0.04689484594564419, 0.04502719049924053, 0.03107004402409075, 0.05171046039322391, 0.05353166852728464, 0.07664062577532604, 0.06033944482624065, 0.024895570168155245, 0.04909948467684444, 0.029342674897634424, 0.09169914352241904, 0.07906949700554833, 0.0066662236895354, 0.029103065098752268, 0.08390190996578895, 0.05112457562063355, 0.04946403132635169, 0.03960967202147003, 0.013865567307220772, 0.018120745226042345, 0.05568333275732584, 0.03931309125619009, 0.010245330122415908, 0.044870055571664125, 0.02012671102420427, 0.013266003825265216, 0.040185274338000454, 0.04258826687873807, 0.009181385357805993, 0.06276747371884994, 0.04890502714260947, 0.05179955893254373, 0.04261254252924118, 0.05289056425681338, 0.014032746275915997, 0.01569246956933057, 0.01981570847419789, 0.017310522198386025, 0.01488094036176335, 0.019654217139759567, 0.04534573141427245, 0.08476146540488116, 0.013993416159792105, 0.05659774033119902, 0.011043463564419653, 0.09504004745394923, 0.05953959516773466, 0.022118566739663947, 0.07147034266381525, 0.03137237828923389, 0.036823638511123136, 0.038662031074636616, 0.025004278104461264, 0.04124544342630543, 0.0533917365828529, 0.08596675033913925, 0.022736682985851076, 0.010752006401162362, 0.037070606704219244, 0.03549197695974726, 0.0168720279543777, 0.030967835446062963, 0.06403862425941043, 0.049891719900188036, 0.016402135297539644, 0.03294370158982929, 0.015268408242263831, 0.03544341823726427, 0.015958405201672576, 0.027049522068409715, 0.032563068889430724, 0.03876097049214877, 0.08094618809991516, 0.03771371106267907, 0.0888989980740007, 0.05855544797668699, 0.05165200142073445, 0.013161090118956054, 0.07363502416410483, 0.021593480560113676, 0.04826630145544186, 0.07270241912920028, 0.09052602326846682, 0.034822678499040194, 0.04522469826042652, 0.04708322529040743, 0.5250354018062353, 4.7634144220501184, 10.736752320080996, 45.26003636419773, 88.0934089422226, 111.57071515917778, 102.04262763261795, 104.29050341248512, 97.23846182227135, 105.2292050421238, 95.67185908555984, 99.79615777730942, 96.88910856842995, 99.40499916672707, 106.86478927731514, 62.35185742378235, 61.24088063836098, 56.958609223365784, 52.28913478553295, 56.80607780814171, 44.679875895380974, 42.58996903896332, 52.311716973781586, 39.21031638979912, 47.31291800737381, 54.161803498864174, 64.76845175027847, 58.031287863850594, 63.99502605199814, 48.921953067183495, 56.96352235972881, 49.90411676466465, 48.88686574995518, 53.81579026579857, 55.52713863551617, 60.99891722202301, 63.6527556180954, 50.596181228756905, 44.951967895030975, 85.7918344438076, 88.78641575574875, 92.21685647964478, 117.28298664093018, 110.21991044282913, 108.36860418319702, 123.24090734124184, 117.74087727069855, 138.37601959705353, 135.61498135328293, 133.97892594337463, 131.88995003700256, 102.46024802327156, 68.28409910202026, 36.51721090078354, 11.889911592006683, 1.5334433410316706, 0.3013075632043183, 0.059982115562888794, 0.05570004592300393, 0.06948074122192338, 0.19081087288213894, 0.06594700505957007, 0.03843370192043949, 0.014446950954152271, 0.05704191200493369, 0.049793622820288874, 0.013238885749160545, 0.049928381995414384, 0.014433157211897196, 0.04356474397354759, 0.05419800952950027, 0.025547780678607523, 0.07059943236527033, 0.015010428433015477, 0.026504496236157138, 0.02807928165566409, 0.058463336317799985, 0.031410940282512456, 0.03535723633831367, 0.05041272241214756, 0.018429335796099622, 0.03464817360509187, 0.03556813615432475, 0.028768256306648254, 0.03628594509791583, 0.12653315090574324, 0.05415303538029548, 0.018439223058521748, 0.056780865270411596, 0.06839535024482757, 0.03747244998521637, 0.01873151235486148, 0.028497294479166158, 0.06277132546529174, 0.0705125936656259, 0.03258926670241635, 0.027608459458861034, 0.011436857494118158, 0.03496928606182337, 0.019810242556559388, 0.01439556093828287, 0.03041996904357802, 0.01349435988231562, 0.01346183711575577, 0.03077008092077449, 0.07004703700658865, 0.036113046953687444, 0.006042044560672366, 0.12506604369264096, 0.048034699429990724, 0.025028676209331024, 0.01921486014907714, 0.04190058542008046, 0.04473168584809173, 0.01910977760417154, 0.018328687583561987, 0.013520778484235052, 0.02378207034780644, 0.020212920753692742, 0.03975045743572991, 0.08379282167879865, 0.2034872301737778, 0.12379678562865593, 0.15548076946288347, 0.17124125501140952, 0.12287377656321041, 0.1899250751012005, 0.13699464267119765, 0.08585848583607003, 0.128649459220469, 0.2253993778140284, 0.18430517666274682, 0.1339135572197847, 0.13550688890973106, 0.1229162942036055, 0.15840110572753474, 0.2047249989118427, 0.16523443046025932, 0.15487928845686838, 0.12360569002339616, 0.12260776857146993, 0.16569229104788974, 0.09353159519378096, 0.07639783958438784, 0.17537534411530942, 0.146504255826585, 0.20779009850230068, 0.13290827366290614, 0.10570277998340316, 0.11534477001987398, 0.24769478535745293, 0.09525202709482983, 0.22558144148206338, 0.19513487757649273, 0.060022154430043884, 0.10609735021716915, 0.11563627078430727, 0.11199400294572115, 0.16345530952094123, 0.1204979837348219, 0.20769989787368104, 0.12198026044643484, 0.20634112937841564, 0.12444739681086503, 0.1469078951049596, 0.2687038283329457, 0.1717652112711221, 0.08965083819930442, 0.1784911472350359, 0.3059078101068735, 0.18584553385153413, 0.28251644340343773, 0.16935664520133287, 0.18776245677145198, 0.1521755405701697, 0.2122741102357395, 1.9995339307934046, 10.149346590042114, 22.434393279254436, 64.09208044409752, 113.68659362196922, 124.36995595693588, 110.60837879776955, 107.36484244465828, 99.89369854331017, 110.97958847880363, 102.6364141702652, 98.22390094399452, 90.85103496909142, 88.24863821268082, 84.052614569664, 52.162833362817764, 50.988255590200424, 47.5891137868166, 39.360560327768326, 47.364055663347244, 32.253676280379295, 25.40478888899088, 37.90625296533108, 40.457215681672096, 38.2583686709404, 41.9290667027235, 59.30169649422169, 43.61564040184021, 50.63684664666653, 39.07455727458, 40.42363688349724, 29.589449241757393, 44.78568881750107, 51.905416175723076, 33.68858948349953, 38.72462645173073, 50.105851739645004, 42.0110435038805, 28.572538308799267, 67.59876027703285, 78.82118448615074, 77.93656155467033, 110.78445374965668, 97.41972729563713, 103.48848804831505, 130.45782208442688, 122.99130633473396, 150.61926662921906, 147.30660438537598, 151.55805945396423, 148.98302882909775, 123.724514991045, 81.88625201582909, 47.62908764183521, 16.435714066028595, 3.041782141663134, 0.44876708183437586, 0.17874453129479662, 0.199346432054881, 0.1597562525421381, 0.29091636766679585, 0.18269413732923567, 0.11785794180468656, 0.10904934650170617, 0.1855197161785327, 0.10607103366055526, 0.16886354744201526, 0.21634150994941592, 0.11405569661292247, 0.13951779634226114, 0.18974982434883714, 0.2036196441622451, 0.14953503850847483, 0.12235010974109173, 0.15046319807879627, 0.12651976256165653, 0.12114409750211053, 0.1512739498866722, 0.16877386631676927, 0.18598859023768455, 0.17186612851219252, 0.1143264766142238, 0.14343430259032175, 0.14985775400418788, 0.15794214676134288, 0.17461749259382486, 0.09319509059423581, 0.09377836671774276, 0.11437387016485445, 0.14267913764342666, 0.14270607760408893, 0.10512590117286891, 0.13084697333397344, 0.26090204541105777, 0.1393603126052767, 0.14941147092031315, 0.15193112165434286, 0.07646987243788317, 0.08861229158355854, 0.10381155021605082, 0.18872858461691067, 0.226170320820529, 0.13917045638663694, 0.12385296620777808, 0.156075467239134, 0.12384426823700778, 0.1294771913671866, 0.09923725621774793, 0.20878785668173805, 0.12954705714946613, 0.13151989347534254, 0.14961453736759722, 0.13381360477069393, 0.12163385559688322, 0.10063965557492338, 0.09877305768895894, 0.1451909216120839, 0.18906816170783713, 0.19848560012178496, 0.13289844762766734], [0.023560607914987486, 0.03495897391985636, 0.017027895664796233, 0.07139910390833393, 0.03291243119747378, 0.0799009324691724, 0.04689050809247419, 0.01202543997351313, 0.08523713011527434, 0.01945857216924196, 0.04468291190278251, 0.010012361617555143, 0.031143425730988383, 0.07773699311655946, 0.014593303403671598, 0.05024546459026169, 0.062879493489163, 0.0479506697593024, 0.0683667478733696, 0.011566550583665958, 0.08163724633050151, 0.050457945180824026, 0.018769374873954803, 0.02868789655622095, 0.016970768847386353, 0.06655475721345283, 0.030030935231479816, 0.026248275316902436, 0.04641860236006323, 0.02185957204346778, 0.05319562777003739, 0.08499950185068883, 0.03540584701113403, 0.004824977104362915, 0.042939191407640465, 0.027123679319629446, 0.07037464325549081, 0.009928214130923152, 0.04261483205482364, 0.0466404822509503, 0.040775919987936504, 0.05656208384607453, 0.03704209339048248, 0.022846387255412992, 0.032493125181645155, 0.05306517305143643, 0.0164074564963812, 0.023857940104790032, 0.026783582725329325, 0.05682692295522429, 0.026609406231727917, 0.057461997275822796, 0.04748857892991509, 0.04576550498313736, 0.0416593614500016, 1.0099161020480096, 9.868354517966509, 34.507304951548576, 58.732825219631195, 79.18670207262039, 76.90134510397911, 76.35382488369942, 71.34742632508278, 62.758617997169495, 67.33095824718475, 30.559056513011456, 44.653543308377266, 48.78673352301121, 38.723216727375984, 18.55940490961075, 18.731700964272022, 27.542185597121716, 26.821472570300102, 49.1746661067009, 62.43995189666748, 47.34713897109032, 65.93998968601227, 82.4671496450901, 67.29328706860542, 114.13415640592575, 68.21146979928017, 60.57596951723099, 52.45000295341015, 67.3014186322689, 53.16192515194416, 83.24810653924942, 82.90965870022774, 58.69644217193127, 51.2871665507555, 83.1035926938057, 82.34750166535378, 96.16541460156441, 79.8192997276783, 67.80559077858925, 80.71563363075256, 55.00688195228577, 58.878687992691994, 30.35682186484337, 32.454301714897156, 25.25512631982565, 40.64110681414604, 52.63404607772827, 40.660280585289, 63.861387223005295, 65.82949921488762, 88.39797779917717, 85.18912598490715, 93.23930561542511, 106.96592465043068, 107.45254933834076, 98.69025751948357, 53.91384020447731, 15.030362326651812, 1.0686616622842848, 0.16551343345781788, 0.006923826858837856, 0.09779610933037475, 0.10271090810419992, 0.0924072414636612, 0.0551141314645065, 0.07485880341846496, 0.027765045197156724, 0.06495763314887881, 0.0269912523435778, 0.040169770873035304, 0.04165342055785004, 0.011003347699443111, 0.004072832698511775, 0.08693428826518357, 0.058134049104410224, 0.07083500488079153, 0.045993507592356764, 0.024986702192109078, 0.054689890166628174, 0.08834711479721591, 0.07270998903550208, 0.0475347219617106, 0.03668939141789451, 0.04840243731450755, 0.021413723115983885, 0.05654156717355363, 0.04200612995191477, 0.005654714441334363, 0.043448278738651425, 0.021181410484132357, 0.05692627797543537, 0.008583275557612069, 0.037155092795728706, 0.03133543417789042, 0.03941473209124524, 0.04211659121210687, 0.04162857716437429, 0.013992214808240533, 0.05475249774463009, 0.013692946540686535, 0.09345513171865605, 0.042595985214575194, 0.03216951539798174, 0.023598440748173743, 0.0619646480481606, 0.014535245190927526, 0.021250137069728225, 0.05821778562676627, 0.020318801107350737, 0.07986795142642222, 0.04926176268782001, 0.027591393773036543, 0.04392678958538454, 0.03139201922749635, 0.058396053209435195, 0.020542942693282384, 0.026084722667292226, 0.030938066047383472, 0.050255854657734744, 0.010996754645020701, 0.012489804557844764, 0.018590044164739083, 0.01348175821476616, 0.039702377398498356, 0.05940694369201083, 0.07828523244825192, 0.02035357629210921, 0.012432395724317757, 0.05113333296321798, 0.0647520953498315, 0.016993712342809886, 0.021057147132523824, 0.03562659512681421, 0.03174495497660246, 0.0838119319814723, 0.013667424082086654, 0.03173892131599132, 0.03577159222913906, 0.03480634753941558, 0.06049928117136005, 0.007518523707403801, 0.04401946898724418, 0.051090462802676484, 0.03684104929561727, 0.045808898357790895, 0.06770485604647547, 0.09084317265660502, 0.009907574076351011, 0.020352835999801755, 0.07404586969641969, 0.027512067463248968, 0.04969921792508103, 0.06988849941990338, 0.0019435800527389802, 0.07632831519003958, 0.02899319755670149, 0.032279872757499106, 0.0664889880863484, 0.027163272898178548, 0.011199286745977588, 0.010354020432714606, 0.05934151224209927, 0.01608075381227536, 0.06985312124015763, 0.025036466904566623, 0.06988754204940051, 0.03571700355678331, 0.047563747357344255, 0.0395482184831053, 0.05671546721714549, 0.039027316161082126, 0.024065149591478985, 0.07117501241737045, 0.02869812335120514, 0.05578223877819255, 0.10245970595860854, 0.695007584290579, 9.260029010474682, 41.245240196585655, 73.41341346502304, 95.06574600934982, 88.80688145756721, 89.15184214711189, 84.25636723637581, 71.38775736093521, 79.51874345541, 57.15777173638344, 71.40931740403175, 65.71784600615501, 54.17182356119156, 30.47398667782545, 31.388510204851627, 36.06161154806614, 23.329857029020786, 29.63210005313158, 36.08426213264465, 23.694808445870876, 30.19710123538971, 37.04066701233387, 41.5713918954134, 69.63911399245262, 40.52578680217266, 34.92779038846493, 44.74223054945469, 39.282242730259895, 44.18704994022846, 53.716847375035286, 49.696207121014595, 28.78328450024128, 38.10266062617302, 53.44032861292362, 42.675247862935066, 56.27325899899006, 52.367961555719376, 45.10375075042248, 42.574051693081856, 41.26162111759186, 52.6862058788538, 35.02536155283451, 43.680164739489555, 42.83521927893162, 58.87726306915283, 85.8599191904068, 77.36339271068573, 106.88140198588371, 105.89445814490318, 112.3946325480938, 104.5948138833046, 110.71265280246735, 122.82783150672913, 124.41536352038383, 115.90309828519821, 69.38462644815445, 19.92755949497223, 0.7502092409413308, 0.1130420267872978, 0.03607128259318415, 0.056746667105471715, 0.03561977850040421, 0.11942120167077519, 0.05530771697522141, 0.016945456045505125, 0.05127686061314307, 0.017475729837315157, 0.012268135251360945, 0.03137167324894108, 0.03525399246427696, 0.05497746868059039, 0.013331830468814587, 0.05247180371952709, 0.05764846930105705, 0.052121079570497386, 0.01155822832515696, 0.08812070038402453, 0.03873059438774362, 0.06467688610428013, 0.049854549433803186, 0.047634715228923596, 0.05477848775626626, 0.06445620849262923, 0.039868418098194525, 0.010081779328174889, 0.01381865893563372, 0.037440893866005354, 0.028312655558693223, 0.011893109476659447, 0.059441791236167774, 0.00998504501694697, 0.04116115400393028, 0.015470157377421856, 0.01569670537719503, 0.025975480384659022, 0.04524804993707221, 0.01641953866055701, 0.08058652107138187, 0.05654118867823854, 0.07978364345035516, 0.0857468816684559, 0.0035392338531892165, 0.03199874350684695, 0.02683921225980157, 0.013809570409648586, 0.03992708487203345, 0.04323797264078166, 0.0496948207000969, 0.0812286272412166, 0.06423311147955246, 0.05814444288262166, 0.030436248052865267, 0.05687481003405992, 0.04389960471598897, 0.03409580051084049, 0.05994144215947017, 0.029842227486369666, 0.04804714524652809, 0.02121287940099137, 0.07664121949346736, 0.11881813246873207, 0.09085789686650969, 0.10371941258199513, 0.17568070819834247, 0.16027136240154505, 0.18454477161867544, 0.12447064829757437, 0.19752932799747214, 0.19688685075379908, 0.163905214285478, 0.1558253783150576, 0.1266016808222048, 0.13345041254069656, 0.19368390465388075, 0.06402764047379605, 0.18537743162596598, 0.10831095409230329, 0.09060856493306346, 0.20940593210980296, 0.17126267339335755, 0.17896799196023494, 0.09735483574331738, 0.10249651648337021, 0.17391902772942558, 0.11830101881059818, 0.18288734805537388, 0.13931860390584916, 0.14170500944601372, 0.14585817174520344, 0.171284967509564, 0.1658867931109853, 0.14362760237418115, 0.15340275596827269, 0.13472251303028315, 0.1360703571117483, 0.14919701992766932, 0.23432115063769743, 0.13028353481786326, 0.1251741300802678, 0.10485139559023082, 0.1357172432471998, 0.13209968892624602, 0.16368596901884302, 0.09650040854467079, 0.13037744618486613, 0.19314454140840098, 0.10933326251688413, 0.1553396723465994, 0.16999073617625982, 0.23578831722261384, 0.1224839486530982, 0.18218307959614322, 0.13002903753658757, 0.14569687336916104, 0.21871200384339318, 2.328094462864101, 13.68575032800436, 55.285532400012016, 94.1992025077343, 116.25121280550957, 99.99790415167809, 101.27065345644951, 99.01916027069092, 86.1401541531086, 90.37174388766289, 49.77262482047081, 65.87112978100777, 63.151345923542976, 54.877738282084465, 33.0821268260479, 28.622159846127033, 44.9984659999609, 44.694926887750626, 79.14985924959183, 89.83024254441261, 70.41306406259537, 100.1155686378479, 120.22685587406158, 94.72205445170403, 149.31563258171082, 102.65606671571732, 92.90987089276314, 76.95300713181496, 93.47321346402168, 71.17377564311028, 114.21516045928001, 107.82924592494965, 80.32764405012131, 77.73970171809196, 118.13968867063522, 110.50815537571907, 129.36823815107346, 117.21642181277275, 97.74612978100777, 112.28608757257462, 75.14181151986122, 79.23666939139366, 43.76411743462086, 45.16083508729935, 37.075993716716766, 56.18881992995739, 77.30761170387268, 62.22316212952137, 91.49645313620567, 91.57048836350441, 117.230693846941, 108.87857481837273, 118.2784952223301, 136.39055013656616, 140.42502164840698, 133.88754844665527, 86.26484826207161, 26.638443991541862, 1.7014284082688391, 0.2851179975550622, 0.17821900168200955, 0.26475201069843024, 0.19130757747916505, 0.2553411922417581, 0.2257769528659992, 0.12285471078939736, 0.1718008640455082, 0.12004568925476633, 0.12578763387864456, 0.13221466244431213, 0.21123728540260345, 0.13262122578453273, 0.07781661071931012, 0.12663240573601797, 0.13735811691731215, 0.16207772016059607, 0.22873199195601046, 0.1265806780429557, 0.22122730559203774, 0.17800802394049242, 0.13582029787357897, 0.15686074853874743, 0.21148119965801015, 0.1730894995853305, 0.1007071316416841, 0.16897538909688592, 0.11477829611976631, 0.09749370641657151, 0.11450342688476667, 0.09512703458312899, 0.11595986201427877, 0.11019954181392677, 0.10026130126789212, 0.09501393127720803, 0.1864269026555121, 0.09367620266857557, 0.1318676638766192, 0.14243697485653684, 0.18201881262939423, 0.14378814375959337, 0.14124870736850426, 0.15618196543073282, 0.0765156555280555, 0.12742922001052648, 0.09650339197833091, 0.09487167641054839, 0.18872145999921486, 0.12953191733686253, 0.1318296807585284, 0.16325867007253692, 0.13893555180402473, 0.15237485175020993, 0.12652877223445103, 0.10289767698850483, 0.11381654694559984, 0.1428039520396851, 0.16803442005766556, 0.16141732747200876, 0.1255617686547339, 0.0819651791243814, 0.14924745628377423], [0.04268554017471615, 0.03130747005343437, 0.0792923491098918, 0.025966613575292286, 0.10533453372772783, 0.054392496749642305, 0.043441220914246514, 0.06884612332214601, 0.05998950364300981, 0.020971416088286787, 0.03790699971432332, 0.019783445459324867, 0.029028965363977477, 0.049707281359587796, 0.017226945237780455, 0.027854358959302772, 0.08548613550374284, 0.036038535326952115, 0.009270356804336188, 0.03064541866478976, 0.05146083531144541, 0.09405207078089006, 0.07725283081526868, 0.02985337639984209, 0.015525253493251512, 0.047554670891258866, 0.07841299317078665, 0.019834646227536723, 0.013870946022507269, 0.006557871984114172, 0.05424803028290626, 0.05755591977504082, 0.018249903041578364, 0.010049299235106446, 0.01791792925359914, 0.06259620829951018, 0.030426110315602273, 0.005322270781107363, 0.08091659125057049, 0.046274217529571615, 0.029089741692587268, 0.026123579664272256, 0.02730108601099346, 0.021031376054452267, 0.05485232402861584, 0.06674958582152613, 0.03695784849696793, 0.02381341124419123, 0.03990661643911153, 0.054101645364426076, 0.09296719188569114, 0.06769868137780577, 0.009093485386983957, 0.8581854938529432, 12.412196416407824, 28.730773217976093, 43.26949417591095, 47.96946197748184, 48.03747832775116, 66.48073107004166, 73.55373993515968, 59.29388411343098, 29.39577553421259, 34.25369895994663, 26.650014370679855, 20.295655243098736, 12.764024287462234, 65.25807827711105, 73.61645177006721, 79.99819412827492, 116.77644342184067, 114.39654752612114, 115.72034329175949, 95.29353618621826, 87.16236770153046, 108.12203541398048, 92.32678458094597, 109.8146241903305, 116.73724472522736, 77.88796976208687, 83.9579464495182, 102.92826890945435, 103.22584614157677, 112.83295422792435, 124.9581415951252, 90.10622933506966, 109.38862144947052, 112.57927224040031, 104.95767161250114, 77.66772598028183, 129.90753561258316, 123.02822515368462, 99.52647104859352, 77.64992013573647, 90.00754863023758, 96.82117581367493, 86.41940116882324, 120.09666725993156, 90.81156268715858, 109.77971166372299, 86.05833694338799, 52.72358827292919, 34.214496463537216, 31.271012909710407, 28.985321559011936, 50.64913138747215, 52.28967435657978, 53.673164919018745, 70.65676018595695, 79.17821332812309, 90.11170864105225, 103.37718442082405, 93.58755692839622, 46.6919781267643, 9.861230850219727, 0.4319235950242728, 0.3822208964265883, 0.17101236182497814, 0.10195107504841872, 0.053340687954914756, 0.05592498717305716, 0.011961657019128324, 0.026030646076833364, 0.06210265783010982, 0.040504290227545425, 0.039505129388999194, 0.03020692071004305, 0.06209627536009066, 0.015040868547657738, 0.04283125344954897, 0.03024476838618284, 0.05172027900698595, 0.0545196452003438, 0.03610250474594068, 0.05112236030981876, 0.04101773025467992, 0.057828621938824654, 0.044576814470929094, 0.02346391720493557, 0.046826271500322036, 0.04952603776473552, 0.01970192424778361, 0.053185271099209785, 0.04486216654186137, 0.04567176059936173, 0.01492158129622112, 0.058227830595569685, 0.043397912886575796, 0.006147051035441109, 0.02867160084861098, 0.037671479149139486, 0.0011142364019178785, 0.036948297056369483, 0.055886191403260455, 0.07815857010427862, 0.03342405296280049, 0.07834741700207815, 0.03070797429245431, 0.03672453582112212, 0.04332162752689328, 0.06540990536450408, 0.030052258989599068, 0.09686639867140912, 0.10009579491452314, 0.04035920406749938, 0.012071967066731304, 0.05706456977350172, 0.030202369489416014, 0.01892264135676669, 0.02334688793780515, 0.06047859009413514, 0.06829699341324158, 0.00613656031418941, 0.03228034402127378, 0.0636924643185921, 0.03190285060554743, 0.05057503753050696, 0.03588613159081433, 0.0897838978562504, 0.021513460342248436, 0.03931025254132692, 0.04054694145452231, 0.03120058223430533, 0.04604393652698491, 0.0307659397367388, 0.04302663495764136, 0.03361359747941606, 0.025232499647245277, 0.056852575289667584, 0.023288653464987874, 0.018914709653472528, 0.07452126723364927, 0.018420836349832825, 0.01046297049470013, 0.05296581060974859, 0.03196228921297006, 0.03729282798303757, 0.019202620278520044, 0.040659499281900935, 0.024911214641178958, 0.004666023914978723, 0.022776386031182483, 0.08153530492563732, 0.019854867896356154, 0.04778297778102569, 0.04556955202133395, 0.007900731616246048, 0.009016902240546187, 0.06716831296216697, 0.02033111890341388, 0.02859941028873436, 0.04031229662359692, 0.043094493230455555, 0.04679877121816389, 0.07165256960433908, 0.07758517938782461, 0.054370955913327634, 0.09706090815598145, 0.032293264812324196, 0.06726779043674469, 0.016393921578128356, 0.07768925075652078, 0.10363436987972818, 0.01812310525565408, 0.07151118305046111, 0.09983878917410038, 0.06619598076213151, 0.02946060587419197, 0.01740089908707887, 0.24668368336278945, 11.066051200032234, 27.662264853715897, 47.56675198674202, 58.44263479113579, 62.89117768406868, 81.83880016207695, 94.31780934333801, 86.74028635025024, 55.4619949311018, 64.22133430838585, 48.940450474619865, 24.9910955876112, 24.81729481369257, 55.27136296033859, 49.149769842624664, 43.171364441514015, 48.071767687797546, 65.67199006676674, 74.81226280331612, 78.54369297623634, 77.37098470330238, 73.74540165066719, 67.34262362122536, 84.66320380568504, 81.42026782035828, 83.70413526892662, 75.5859924852848, 71.50024652481079, 63.798454999923706, 74.39725667238235, 60.688439682126045, 66.42422050237656, 70.37682920694351, 68.52570533752441, 65.78578636050224, 62.95535624027252, 88.8861072063446, 85.22205501794815, 75.77108815312386, 64.23533275723457, 62.5032564997673, 70.125313103199, 61.31889805197716, 64.65063527226448, 61.87361128628254, 64.7735358774662, 61.12386591732502, 43.458024859428406, 31.548451222479343, 32.601692005991936, 38.85388031601906, 79.1804552078247, 81.69509187340736, 80.05104169249535, 90.81489130854607, 90.92496380209923, 102.40452021360397, 113.02703261375427, 112.37076982855797, 61.17878437042236, 13.200041390955448, 0.320370516856201, 0.3630680835340172, 0.13950865308288485, 0.058770437026396394, 0.05210173920204397, 0.09592855407390743, 0.04234376632666681, 0.011901579237019178, 0.050061823858413845, 0.02400249933998566, 0.01824795861466555, 0.030093639288679697, 0.04355530385510065, 0.022531436479766853, 0.010096868118125712, 0.026995261796400882, 0.0609227209497476, 0.018245477986056358, 0.03881433833157644, 0.043412659360910766, 0.053303595414035954, 0.07183375011663884, 0.05986298230709508, 0.045099308699718677, 0.024707368938834406, 0.09725230804178864, 0.03361235809279606, 0.04614778525137808, 0.06554421182954684, 0.026930711646855343, 0.05764619090768974, 0.04060168226715177, 0.015207597589323996, 0.05273843140457757, 0.0544317823369056, 0.05587121115240734, 0.020352331339381635, 0.03640680755779613, 0.040140174023690633, 0.10227871098322794, 0.05325286962033715, 0.09959986957255751, 0.02965989478980191, 0.026017391319328453, 0.027108999638585374, 0.02840948542143451, 0.04458313385839574, 0.014306642369774636, 0.10641027678502724, 0.03379155707079917, 0.029114284516253974, 0.04325231464463286, 0.0733485551609192, 0.025846688076853752, 0.019931951064791065, 0.03789102869632188, 0.04023971458082087, 0.021291699194989633, 0.11719150061253458, 0.06008384174492676, 0.025375808363605756, 0.1516953413374722, 0.13959156582131982, 0.23437583207851276, 0.10731619418947957, 0.227231458411552, 0.12627172196516767, 0.07618269839440472, 0.25208369828760624, 0.1168192393379286, 0.1688021866721101, 0.1660839669057168, 0.09561993938405067, 0.13431017578113824, 0.1526968547841534, 0.18884796649217606, 0.22862202051328495, 0.14733606978552416, 0.08889998513041064, 0.13514109916286543, 0.18820970464730635, 0.23105843196390197, 0.18512959883082658, 0.18738215061603114, 0.118689651862951, 0.07123436196707189, 0.089548681571614, 0.1412024864112027, 0.08246216573752463, 0.15865245630266145, 0.1387874488136731, 0.1283531790249981, 0.18510847730794922, 0.19150924868881702, 0.08481760145514272, 0.1657599155441858, 0.1425902877235785, 0.10859404632356018, 0.1430596664431505, 0.14061561087146401, 0.11259540973696858, 0.12586141820065677, 0.14453113748459145, 0.09544284068397246, 0.16237621195614338, 0.13272488897200674, 0.12072821278707124, 0.2062028821092099, 0.1542129585868679, 0.1274072821252048, 0.1659617351833731, 0.14220907614799216, 0.15246390947140753, 0.14852464897558093, 1.6598304966464639, 17.060290351510048, 41.98200926184654, 70.90466648340225, 78.49662870168686, 79.58711698651314, 95.04532590508461, 106.19304612278938, 86.55620902776718, 46.60695768892765, 53.50662745535374, 46.753417029976845, 38.70227985084057, 27.77349628508091, 89.015072286129, 104.03530150651932, 115.28523623943329, 166.90276086330414, 162.06215500831604, 164.4637629389763, 143.78401100635529, 136.25179678201675, 150.01187682151794, 138.34739953279495, 170.03338247537613, 168.09775114059448, 112.61292323470116, 129.52311784029007, 160.8117637038231, 150.04309594631195, 162.73503810167313, 178.7362378835678, 131.3619303703308, 161.71906381845474, 166.3808360695839, 146.36641323566437, 114.01346728205681, 191.02569043636322, 177.53332883119583, 136.60405308008194, 112.93356522917747, 133.60181897878647, 137.08083629608154, 127.84895807504654, 164.6254214644432, 129.99663323163986, 159.18545097112656, 124.75775554776192, 74.07586991786957, 49.16898921132088, 47.70983710885048, 46.83179162442684, 73.31026419997215, 75.93409940600395, 77.80617535114288, 93.2751452922821, 99.90292444825172, 115.07047936320305, 126.68289184570312, 129.28824484348297, 77.88327321410179, 16.474329493939877, 0.5578006280120462, 0.42469958891160786, 0.2851997525431216, 0.16593611624557525, 0.23690321599133313, 0.12300168571528047, 0.0868337346764747, 0.1429869359708391, 0.15287326328689232, 0.14356391126057133, 0.10481128992978483, 0.1518432513694279, 0.12640579836443067, 0.09426234348211437, 0.16552683664485812, 0.08985820910311304, 0.13728403573622927, 0.17234270606422797, 0.13598799356259406, 0.1565181731712073, 0.16381643858039752, 0.20697189553175122, 0.1957362546818331, 0.1865009096218273, 0.18562385434051976, 0.22757161437766626, 0.1698286659666337, 0.11221833192394115, 0.16766693821409717, 0.12960386113263667, 0.1533404749352485, 0.1807499775895849, 0.14176337193930522, 0.10780191500089131, 0.1780053076799959, 0.10984455031575635, 0.21080447972053662, 0.10826410973095335, 0.10197711701039225, 0.21563786489423364, 0.20921493298374116, 0.2270629908889532, 0.1682585189701058, 0.15962039498845115, 0.12224466539919376, 0.18807890854077414, 0.19886826630681753, 0.2520180033752695, 0.15424939803779125, 0.15116516588022932, 0.08614246122306213, 0.12831515137804672, 0.1375098415883258, 0.15883174433838576, 0.09047375380760059, 0.1373516008607112, 0.13284213346196339, 0.13138123060343787, 0.13208324293373153, 0.11945090242079459, 0.11017282449756749], [0.0922171254933346, 0.051159560462110676, 0.051635184354381636, 0.0086126154383237, 0.009046500017575454, 0.047056266776053235, 0.006971404554860783, 0.03304807723907288, 0.024340959498658776, 0.04019557163701393, 0.06990462628891692, 0.0075010554064647295, 0.027479824857437052, 0.01735201196424896, 0.006790573779653641, 0.049134376749861985, 0.0793087505735457, 0.021684759158233646, 0.03602023396524601, 0.012345045870461036, 0.0850142705894541, 0.039014759022393264, 0.02421478882752126, 0.06004335758916568, 0.016798718606878538, 0.09061233504326083, 0.04883593319391366, 0.04178370087174699, 0.05769837131083477, 0.05683291208697483, 0.029811760468874127, 0.1301930521731265, 0.03181133266480174, 0.02601280855742516, 0.059685182277462445, 0.07556010328698903, 0.021608638926409185, 0.008663403386890423, 0.02488442125468282, 0.030263446387834847, 0.07429653007420711, 0.051695328002097085, 0.060134767918498255, 0.03541996265994385, 0.07035478338366374, 0.04328186696511693, 0.02509916725102812, 0.0648825871758163, 0.08287570526590571, 0.028451249781937804, 0.062096052715787664, 0.36121627665124834, 4.749239757657051, 27.521733194589615, 50.51324687898159, 72.82815366983414, 74.18449088931084, 50.211926847696304, 42.36030176281929, 42.58953206241131, 30.37268601357937, 9.316265042871237, 17.248699441552162, 17.411486506462097, 28.980997391045094, 55.97176797688007, 79.51185822486877, 57.06736698746681, 49.57194618880749, 61.807639226317406, 59.4708102196455, 48.24688509106636, 21.51808574795723, 5.653701899573207, 2.070656376890838, 0.342946708551608, 0.6900217174552381, 0.4293394961860031, 0.9834929730277508, 0.8024636213667691, 1.9928899873048067, 2.2419932205229998, 3.8819146854802966, 1.7914578085765243, 2.6303083961829543, 0.9567838499788195, 0.6494199461303651, 0.8602768066339195, 1.589415525086224, 2.0339702954515815, 0.8034087612759322, 0.8788212959188968, 0.5628763244021684, 0.7564083114266396, 0.9895445045549423, 0.9327524551190436, 0.22935547021916136, 3.390087839215994, 7.10784824565053, 24.244304560124874, 43.51006306707859, 81.61437660455704, 129.0861412882805, 104.50248643755913, 97.89453461766243, 48.73176947236061, 35.56277051568031, 25.64923357218504, 37.15609721839428, 68.20969149470329, 64.02493804693222, 82.20171868801117, 93.83360892534256, 91.20222732424736, 75.23187428712845, 38.82206842303276, 12.358754184097052, 5.6463925167918205, 1.558004985563457, 0.07471891600289382, 0.02594726021925453, 0.051677828159881756, 0.024716408297535963, 0.036258515319786966, 0.043322540368535556, 0.04916160614811815, 0.06730654538841918, 0.03654951884527691, 0.09705472606583498, 0.017746888333931565, 0.036314655080786906, 0.025048209536180366, 0.0249220945261186, 0.02796942339045927, 0.060826512635685503, 0.10892978651099838, 0.01336260640528053, 0.030114604960544966, 0.10180956975091249, 0.018430428608553484, 0.04799202964932192, 0.04173842244199477, 0.03465808498731349, 0.02715587183047319, 0.019755351459025405, 0.10383210028521717, 0.05367594574636314, 0.06831443388364278, 0.042981215519830585, 0.02666378153662663, 0.019406154278840404, 0.04115044110221788, 0.07719489134615287, 0.017417773669876624, 0.023961822225828655, 0.043215047699050047, 0.048698654427425936, 0.03299040123238228, 0.02885878162487643, 0.04507177873165347, 0.028486598275776487, 0.03443254259764217, 0.023727208936179522, 0.040371434661210515, 0.03717700099514332, 0.007401398424917716, 0.038993266425677575, 0.04180446245300118, 0.0584082689601928, 0.039332958549493924, 0.04048496841278393, 0.008417563258262817, 0.04157504976319615, 0.040274981438415125, 0.04885818649199791, 0.024111031016218476, 0.06178576448292006, 0.03274296919698827, 0.012706615580100333, 0.04982767626643181, 0.05313188099535182, 0.08391162467887625, 0.03316091708256863, 0.004874433361692354, 0.09012057314976119, 0.06287236887146719, 0.01777441088052001, 0.05112086117151193, 0.037252499678288586, 0.02182091171562206, 0.07904926605988294, 0.026477457940927707, 0.02945810298115248, 0.011845506269310135, 0.03143277055642102, 0.04246065829647705, 0.061847362740081735, 0.05991227204503957, 0.009971143663278781, 0.03447344235610217, 0.025186948478221893, 0.04799863847438246, 0.05946385528659448, 0.0619485582865309, 0.06386027875123546, 0.05896269780350849, 0.019542880145309027, 0.0331076086149551, 0.022477183629234787, 0.038712166860932484, 0.034731642954284325, 0.082355407794239, 0.008293443697766634, 0.016809101252874825, 0.027840870425279718, 0.005151188115632976, 0.03946565826481674, 0.05500318780832458, 0.0627728617109824, 0.010269861813867465, 0.0056846758707251865, 0.04220311078825034, 0.056814258205122314, 0.04368556561530568, 0.06805630007875152, 0.014310408769233618, 0.02510116177290911, 0.16930319572566077, 4.29156856611371, 26.712562814354897, 55.357185155153275, 86.39173105359077, 92.99709901213646, 70.59971764683723, 60.00044099986553, 59.940100237727165, 48.93243670463562, 28.011610507965088, 23.563548289239407, 20.30283685773611, 31.340347789227962, 36.50862716138363, 37.93288193643093, 56.24504931271076, 57.120191752910614, 64.47121649980545, 64.55086022615433, 51.38404235243797, 24.6730849519372, 9.687767308205366, 3.2411187328398228, 1.484253911767155, 1.097565998788923, 0.6436321442015469, 1.7128760064952075, 1.1524165305308998, 2.3895136546343565, 3.204599842429161, 4.483374198898673, 2.0260170847177505, 3.380963341332972, 1.172414857428521, 0.7621914823539555, 1.3740678993053734, 2.231714059598744, 2.200802955776453, 1.4029121515341103, 0.8059550402686, 0.39244858198799193, 0.12795866816304624, 0.40153309295419604, 0.13347356754820794, 1.1380457016639411, 4.515230739489198, 9.035363215953112, 22.826644331216812, 39.338126331567764, 64.16265785694122, 78.18352550268173, 72.86308899521828, 59.139228612184525, 38.799733221530914, 39.61045391857624, 43.26477102935314, 60.33131584525108, 97.06817016005516, 86.57899260520935, 101.87197118997574, 104.97479349374771, 105.7243412733078, 91.10880553722382, 51.40264615416527, 16.171702332794666, 6.230173716321588, 1.5458975289948285, 0.08351736614713445, 0.045626686260220595, 0.04439885487954598, 0.020849527609243523, 0.03587824627174996, 0.07291094778338447, 0.025719346667756326, 0.03976099222199991, 0.0387759247678332, 0.03531785427185241, 0.031048213750182185, 0.06839362104074098, 0.034440824965713546, 0.03167259186739102, 0.03822851664153859, 0.01952156195329735, 0.05787135109130759, 0.01186561197755509, 0.06823097195592709, 0.02993905178300338, 0.052675575207103975, 0.03470468072919175, 0.03656210195913445, 0.01930669906869298, 0.03676758780784439, 0.07206806098110974, 0.06999868608545512, 0.02512781971745426, 0.06251602666452527, 0.056309141364181414, 0.025235817047359888, 0.03791051378357224, 0.02582600813184399, 0.028001393257000018, 0.012474498689698521, 0.05304336504195817, 0.03385427968169097, 0.04633057251339778, 0.060887279687449336, 0.06077617646951694, 0.0478571183339227, 0.05798459911602549, 0.035140740728820674, 0.04641229039407335, 0.040013277903199196, 0.006504526872959104, 0.005111816253702273, 0.05251765360299032, 0.0430710005457513, 0.06657821650151163, 0.029148989196983166, 0.041226414759876207, 0.06327986731776036, 0.06693601331789978, 0.04202378935588058, 0.04933832635288127, 0.022333628148771822, 0.1454141447902657, 0.14702956279506907, 0.13042617560131475, 0.09548333226121031, 0.13914823648519814, 0.27821353054605424, 0.13810445030685514, 0.13190104567911476, 0.11748777338652872, 0.20863430632743984, 0.14380142820300534, 0.10436835393193178, 0.15868315153056756, 0.06333640412776731, 0.15649553766706958, 0.12586002296302468, 0.15370687324320897, 0.13294263510033488, 0.11500529682962224, 0.10728445995482616, 0.2077951154205948, 0.14734585129190236, 0.1832029686192982, 0.13007089466555044, 0.19560351414838806, 0.17007088812533766, 0.15490364574361593, 0.11640367374639027, 0.13846911198925227, 0.2129864681046456, 0.16132262942846864, 0.21175380534259602, 0.07600349199492484, 0.1692983866087161, 0.1817382065928541, 0.1525259530171752, 0.18481157370842993, 0.15108121413504705, 0.08634483747300692, 0.15569275652524084, 0.17581288469955325, 0.10517448958125897, 0.15205786563456059, 0.16153035656316206, 0.16627575270831585, 0.21266835392452776, 0.1245921230292879, 0.14073349360842258, 0.19763857213547453, 0.10706070985179394, 0.21299865416949615, 0.5318526516202837, 8.603752925992012, 40.15144228935242, 71.46098703145981, 109.51032131910324, 105.59175878763199, 82.35630199313164, 71.99522316455841, 71.78969219326973, 50.60463197529316, 17.59755302220583, 28.314644247293472, 30.99181529134512, 45.681106969714165, 83.74397233128548, 118.65098163485527, 90.65448671579361, 82.98391431570053, 93.07430326938629, 92.62686967849731, 78.51790755987167, 33.337974697351456, 12.444146052002907, 4.267467884346843, 1.3505943026393652, 2.030743081122637, 0.8158307103440166, 2.1737232338637114, 2.583869188092649, 4.524004943668842, 4.211408542469144, 8.245693389326334, 3.0750750051811337, 4.714160040020943, 1.9494245946407318, 1.455929756630212, 1.776806863490492, 3.860521358437836, 3.6741280602291226, 2.000732528977096, 1.5472018090076745, 1.2899022968485951, 1.410694015212357, 1.5055980789475143, 1.28306943224743, 2.4902512365952134, 7.465688344091177, 12.269856054335833, 39.26717273890972, 64.87466365098953, 113.84091094136238, 173.2181739807129, 145.05394846200943, 133.77546966075897, 69.82501521706581, 50.69853253662586, 40.570818185806274, 57.99065664410591, 92.68461138010025, 87.8201200067997, 109.43144515156746, 113.80308017134666, 117.12898850440979, 108.86821657419205, 64.36170637607574, 21.25332735478878, 9.004586767405272, 2.696178574115038, 0.2293637377442792, 0.12803847872419283, 0.09486727547482587, 0.14997437509009615, 0.07899958669440821, 0.1435676368419081, 0.17203849973157048, 0.14032258128281683, 0.10285497381119058, 0.18700007814913988, 0.11867118722875603, 0.171133762341924, 0.12115194942452945, 0.18975734972627833, 0.13443078962154686, 0.15881782164797187, 0.21966239815810695, 0.05887408537091687, 0.19243654736783355, 0.17861560540040955, 0.24527441913960502, 0.11969316168688238, 0.10981783299939707, 0.08633875186205842, 0.14824077748926356, 0.14036486885743216, 0.18296275025932118, 0.18543836195021868, 0.14496596180833876, 0.09612072579329833, 0.16115891165100038, 0.10509857529541478, 0.11809507283032872, 0.1346708001801744, 0.08994932257337496, 0.13403755525359884, 0.14404019195353612, 0.18435852223774418, 0.1583693566499278, 0.1493857629247941, 0.08391660448978655, 0.29423795349430293, 0.1564128921017982, 0.11940228432649747, 0.08133576367981732, 0.22081967355916277, 0.15199724701233208, 0.179272910754662, 0.23709200351731852, 0.11104435820016079, 0.10111026625963859, 0.08080631552729756, 0.10982995969243348, 0.11599988603848033, 0.09337596682598814, 0.14019395224750042, 0.09908304535201751], [0.04179545649094507, 0.025570907855581027, 0.038657381519442424, 0.04247459954058286, 0.010724954190663993, 0.026125503682123963, 0.03173296187014785, 0.030950072141422424, 0.03522321560012642, 0.054193667965591885, 0.03948526951717213, 0.0623140882817097, 0.05518606412806548, 0.08030532131670043, 0.112406310508959, 0.040887661452870816, 0.04376714619866107, 0.039203112391987815, 0.05013729285565205, 0.04287003066565376, 0.01182782831165241, 0.033031267594196834, 0.030185021787474398, 0.0057639302849565865, 0.023517915869888384, 0.017466556892031804, 0.038281713787000626, 0.041699604407767765, 0.057446664504823275, 0.08716318887309171, 0.0134207314113155, 0.01115059165385901, 0.027599403401836753, 0.05187847520573996, 0.031827819475438446, 0.05636665409838315, 0.057774103770498186, 0.02798513465677388, 0.05770706928160507, 0.02613520911836531, 0.025706798805913422, 0.04827551150810905, 0.040063829292193986, 0.03685575124109164, 0.11437766253948212, 0.01490975424530916, 0.06003171329211909, 0.053780644229846075, 0.019734524939849507, 0.11412214109441265, 1.5467841876670718, 18.519896529614925, 47.86370985209942, 65.92159107327461, 70.23981615900993, 53.87093670666218, 51.94517344236374, 35.61444014310837, 42.66568757593632, 39.058370143175125, 37.05288715660572, 42.01272301375866, 58.80246788263321, 109.92288038134575, 108.37180361151695, 64.96208176016808, 59.593790620565414, 38.51249523460865, 19.630546532571316, 5.585975283756852, 0.6288563401903957, 0.1976323826238513, 0.09037481810082681, 0.08125424617901444, 0.08477440846036188, 0.12535677262349054, 0.04214490414597094, 0.22903103294083849, 0.020827417174587026, 0.07067662314511836, 0.08899519525584765, 0.09854495860054158, 0.09319329459685832, 0.25880004570353776, 0.02083007220790023, 0.06157306124805473, 0.3181596292415634, 0.18312403379241005, 0.05369893005990889, 0.03673010192869697, 0.20140345761319622, 0.22644908633083105, 0.28093373926822096, 0.2255338104441762, 0.34364848339464515, 0.5732234660536051, 0.06336795282550156, 0.03507239634927828, 0.29794299218337983, 0.5450641270726919, 0.31538559996988624, 0.3493096155580133, 7.276505995541811, 18.786191940307617, 46.98681190609932, 90.81155508756638, 77.70442441105843, 63.222626298666, 43.350825011730194, 13.684140164405107, 21.338368691504, 41.48137852549553, 73.72201010584831, 71.64279967546463, 81.45245209336281, 87.62707516551018, 74.71219897270203, 59.02976408600807, 31.1558847874403, 7.884397376328707, 0.5034886579960585, 0.09311772912042215, 0.06195385351020377, 0.11594008377869613, 0.08345570851815864, 0.018661882204469293, 0.08115700256894343, 0.05781779771496076, 0.024823758103593718, 0.029748021115665324, 0.03803513522143476, 0.021300274711393286, 0.08242309166234918, 0.02779082740744343, 0.027971497693215497, 0.04891371398116462, 0.0431095773819834, 0.015182025035755942, 0.02104050447087502, 0.034632135793799534, 0.034498259774409235, 0.11458092936663888, 0.028412992069206666, 0.08064490582910366, 0.033452002244303, 0.050089238793589175, 0.04632163334463257, 0.06285234572715126, 0.07215408331830986, 0.05164089518075343, 0.05658886795572471, 0.016348945573554374, 0.04474770881643053, 0.05050184692663606, 0.050949621727340855, 0.006162014587971498, 0.09976956906029955, 0.06389510032022372, 0.04919117331155576, 0.06779731280403212, 0.07058237039018422, 0.01623812066100072, 0.00396808551158756, 0.008932894834288163, 0.04795353816007264, 0.025734735099831596, 0.022014491660229396, 0.11138567191665061, 0.041571765759726986, 0.06371106253936887, 0.02871277705708053, 0.09955982328392565, 0.05669780781317968, 0.029473593458533287, 0.030097036469669547, 0.025799606228247285, 0.041227858237107284, 0.06942756634089164, 0.024093182364595123, 0.016544473655812908, 0.060283939601504244, 0.0784232719161082, 0.04847901582252234, 0.02128624626493547, 0.013624556704598945, 0.023440849399776198, 0.03424627837375738, 0.04037432903714944, 0.01873008928669151, 0.048690576149965636, 0.10880710950004868, 0.04859260152443312, 0.00728299386537401, 0.034558254992589355, 0.004669415066018701, 0.03337301175633911, 0.026135524531127885, 0.029391309690254275, 0.0356890320108505, 0.034676672075875103, 0.008648085458844434, 0.018090623307216447, 0.07535472133895382, 0.0368292009079596, 0.047111868479987606, 0.03815098818449769, 0.055834044396760873, 0.05435237995698117, 0.04107902423129417, 0.05212967735133134, 0.02590121923276456, 0.03625704957812559, 0.02413784110103734, 0.015234237907861825, 0.04405233499710448, 0.01999001298827352, 0.0529071141500026, 0.03554049115336966, 0.034895472053904086, 0.019703733232745435, 0.0328291214100318, 0.03592999251850415, 0.03574920534447301, 0.034046195360133424, 0.014833541245025117, 0.045622222241945565, 1.516482001170516, 18.657031171023846, 51.687125489115715, 81.13211408257484, 85.79144686460495, 79.57400768995285, 66.392363011837, 48.250920474529266, 51.61486476659775, 53.14604580402374, 43.97485412657261, 23.030490092933178, 33.445318937301636, 52.94892758131027, 72.02122896909714, 60.7892444729805, 67.47142150998116, 40.48703648149967, 24.964971989393234, 8.69039112702012, 1.1743468162603676, 0.04781280098541174, 0.06298492298810743, 0.06727686690283008, 0.08343424560735002, 0.1751532786875032, 0.10364711997681297, 0.1610868045827374, 0.09495026984950528, 0.16968339798040688, 0.05531234055524692, 0.18919683527201414, 0.2204241236904636, 0.44969390553887933, 0.018054790562018752, 0.43322870624251664, 0.7504321227315813, 0.5923407746013254, 0.13307625136803836, 0.022538722514582332, 0.14645561546785757, 0.095424264727626, 0.09833473784965463, 0.0596619530551834, 0.043148933473275974, 0.09748108990606852, 0.05492665011843201, 0.312373549095355, 0.4656393936602399, 0.6596466223709285, 0.2736370323691517, 0.642324301879853, 8.548855371773243, 23.50700732320547, 52.93200708925724, 77.69225746393204, 55.59620372951031, 39.668245017528534, 37.20155417919159, 34.212136790156364, 46.95807784795761, 63.38900417089462, 91.02279335260391, 87.04382926225662, 93.47294747829437, 103.45245838165283, 92.01511010527611, 73.14513266086578, 37.582897916436195, 9.227700345218182, 0.5131992744281888, 0.032769218960311264, 0.06656640151049942, 0.045140676011214964, 0.07077453468809836, 0.007766896414977964, 0.05882835052034352, 0.019561090593924746, 0.006637993319600355, 0.046624422175227664, 0.011868533256347291, 0.03160913453029934, 0.06796310859499499, 0.04410476401972119, 0.0036592398282664362, 0.025116279321082402, 0.03982850910688285, 0.029556482077168766, 0.031816023038118146, 0.014088959323999006, 0.05419334884209093, 0.07721187168499455, 0.04542149355984293, 0.03208211637684144, 0.06937704092706554, 0.05821245700644795, 0.05182686996704433, 0.05421206951723434, 0.03432968464039732, 0.04415241732203867, 0.004743708686874015, 0.048587922283331864, 0.02949585788883269, 0.057070904003921896, 0.02173882647184655, 0.06983666040468961, 0.037742213244200684, 0.008075960104179103, 0.05626297977869399, 0.012195265626360197, 0.03330678249767516, 0.028804851608583704, 0.09246558911399916, 0.04156553914071992, 0.026102471128979232, 0.02448792143695755, 0.09934069676091895, 0.060035913847968914, 0.025828262405411806, 0.047730307560414076, 0.04325503090512939, 0.02553378748416435, 0.02964511491882149, 0.029687738315260503, 0.005057647358626127, 0.00503699106957356, 0.10943252476863563, 0.16906296252273023, 0.164452800527215, 0.19492422637995332, 0.10389938339358196, 0.1611059668357484, 0.1336935252766125, 0.13782632304355502, 0.12460165220545605, 0.07915366397355683, 0.13062410638667643, 0.15600098529830575, 0.11808151379227638, 0.14588849589927122, 0.2955770253902301, 0.1925101684173569, 0.15701827680459246, 0.11446250486187637, 0.11284148364211433, 0.174883003346622, 0.07376819514320232, 0.0810365445795469, 0.1959716045530513, 0.12533234112197533, 0.09279937745304778, 0.10962703425320797, 0.10407850073534064, 0.1004284255031962, 0.1490660457056947, 0.12072830926626921, 0.14330098318168893, 0.11843447180581279, 0.0736315805988852, 0.13665671314811334, 0.16649490891722962, 0.12434638309059665, 0.09853638679487631, 0.13316576922079548, 0.15834450954571366, 0.05559524353884626, 0.1487528593861498, 0.1081074720423203, 0.20255117415217683, 0.0810997532971669, 0.22454774851212278, 0.13282368367072195, 0.11657395210932009, 0.16655923827784136, 0.0853787838423159, 0.1953305077040568, 2.360001113265753, 29.38490431755781, 70.47699943184853, 100.76914116740227, 103.14382374286652, 86.59654766321182, 81.02349311113358, 61.23598650097847, 67.33973577618599, 60.82048639655113, 59.103084951639175, 65.51659360527992, 88.36978331208229, 148.08162599802017, 148.10658305883408, 98.28029751777649, 90.33804729580879, 60.54602712392807, 31.96252830326557, 12.027302719652653, 1.3869983679614961, 0.49970352672971785, 0.19820530578726903, 0.25160376622807235, 0.21708978776587173, 0.2852596587035805, 0.20621959527488798, 0.4375890316441655, 0.1455185649683699, 0.2590308239450678, 0.1747091775177978, 0.1899517627316527, 0.24480797932483256, 0.32203316513914615, 0.16485152678797022, 0.25266901531722397, 0.5399235966615379, 0.41936247842386365, 0.22495578130474314, 0.18597177317133173, 0.3244537836872041, 0.32840025785844773, 0.42425907973665744, 0.44217960094101727, 0.560864747967571, 0.6662936531938612, 0.2019065892091021, 0.3483211639104411, 0.5001798667944968, 0.9274314937647432, 0.636351378634572, 1.2360762851312757, 12.097688242793083, 30.6582235917449, 71.58775582909584, 130.02760916948318, 113.1784088909626, 93.66193413734436, 63.92716929316521, 26.371850296854973, 35.30174732208252, 61.488547548651695, 97.3211757838726, 93.58751133084297, 104.32853177189827, 116.23655319213867, 109.79394569993019, 90.31210228800774, 47.92416840791702, 12.283588517457247, 0.7222406635992229, 0.1560645131394267, 0.19638900324935094, 0.2741312136640772, 0.12589759047841653, 0.11846276989672333, 0.18638195819221437, 0.07802801148500293, 0.09893546186503954, 0.1266440426115878, 0.14462262945016846, 0.09614186215912923, 0.18061547074466944, 0.1114477970986627, 0.14183256978867576, 0.16165914887096733, 0.08030541779589839, 0.10441036691190675, 0.1651483413297683, 0.11368685663910583, 0.09872229478787631, 0.15411104686791077, 0.1324732563807629, 0.12766226922394708, 0.0918977422406897, 0.16910714999539778, 0.11180798363056965, 0.19758013542741537, 0.19563465466490015, 0.16151480114785954, 0.10392045296612196, 0.12507454870501533, 0.11949744992307387, 0.10654941463144496, 0.1479457292589359, 0.1265856355894357, 0.2259962129755877, 0.1248825402581133, 0.13893760013161227, 0.13340174249606207, 0.20074772561201826, 0.1103632670128718, 0.17687342857243493, 0.16632504615699872, 0.18591165920952335, 0.1450797330471687, 0.16610007151030004, 0.15320224250899628, 0.11212315148441121, 0.12722662853775546, 0.12125918234232813, 0.19777644833084196, 0.08134311094181612, 0.15535634098341689, 0.15316783654270694, 0.11194801205419935], [0.050477085169404745, 0.060123876901343465, 0.032442826122860424, 0.029881073351134546, 0.04406139662023634, 0.07701093520154245, 0.03518379642628133, 0.04988520755432546, 0.029782900201098528, 0.03198237915057689, 0.05130622739670798, 0.05743234476540238, 0.02028560669714352, 0.04656537319533527, 0.006732145420755842, 0.054049004829721525, 0.07723539034486748, 0.04256635125784669, 0.0541787470865529, 0.08934351484640501, 0.051412703323876485, 0.06658479192992672, 0.05246466796961613, 0.045401785828289576, 0.026117022789549083, 0.06077555677620694, 0.018280863587278873, 0.057965344094554894, 0.03144382484606467, 0.06315002858173102, 0.03289764761575498, 0.025780521900742315, 0.042733913360279985, 0.07555012140073813, 0.047289223221014254, 0.05579195720201824, 0.05563167927903123, 0.010880762529268395, 0.08061441098107025, 0.053844691574340686, 0.0066768864962796215, 0.0441341753321467, 0.08719253339222632, 0.005582291032624198, 0.08001118592801504, 0.007202507022157079, 0.02928585421614116, 0.0697339916951023, 1.2020391365513206, 5.022902498021722, 25.356884859502316, 59.38469164073467, 63.44402901828289, 60.524121299386024, 53.894833624362946, 31.98888748884201, 30.32346535474062, 31.484574750065804, 33.53347800672054, 44.76533330976963, 40.62490828335285, 90.6612503528595, 81.01129576563835, 48.332787081599236, 36.13888420164585, 13.262527137994766, 1.46651717601344, 0.1781268120976165, 0.08424406973063014, 0.09724768446176313, 0.1027585168776568, 0.1447026032838039, 0.048080315536935814, 0.013040224876021966, 0.16190986119909212, 0.2152889664284885, 0.11388301369152032, 0.22742518864106387, 0.3426879661856219, 0.046698440273758024, 0.23888059426099062, 0.19510802667355165, 0.08685198408784345, 0.23964610474649817, 0.2530920098070055, 0.11194470949703828, 0.42436734423972666, 0.09165957220830023, 0.1828113224473782, 0.05709373617719393, 0.06312328157946467, 0.27058279782067984, 0.25681025872472674, 0.2284761142800562, 0.3286850347649306, 0.47058669850230217, 0.14605826960178092, 0.0610585673712194, 0.11470779951196164, 0.27309176162816584, 0.19855407066643238, 0.15200621215626597, 0.10044599213870242, 0.09294442279497162, 0.29730762471444905, 8.341400753706694, 44.67965930700302, 89.21609669923782, 84.42882478237152, 74.08468544483185, 35.45628122985363, 23.840695917606354, 23.807700388133526, 35.67326858639717, 61.47247061133385, 62.80164308845997, 78.10120671987534, 78.00001814961433, 67.96046286821365, 44.69702057540417, 18.26568067073822, 3.9343409473076463, 0.15763611474540085, 0.13260973733849823, 0.042808369325939566, 0.08598848784458824, 0.044793399138143286, 0.0142791402322473, 0.02400928071438102, 0.034837116982089356, 0.014959586678742198, 0.030265374116424937, 0.1114717016753275, 0.05629525949188974, 0.03424620044825133, 0.027451645510154776, 0.022983024064160418, 0.02537653566832887, 0.03483935084659606, 0.013823068220517598, 0.009432627393834991, 0.010554600685281912, 0.0026017661275545834, 0.039695215673418716, 0.032893306051846594, 0.048601455346215516, 0.051379228752921335, 0.03727209237695206, 0.03978294495027512, 0.052032474559382536, 0.0367604817438405, 0.020363816074677743, 0.019364786967344116, 0.10081057960633188, 0.027349798729119357, 0.07735599676379934, 0.030655652881250717, 0.07117024782928638, 0.027593152663030196, 0.02385062809480587, 0.026080208554049022, 0.0031963732226358843, 0.04841254907660186, 0.02355164833716117, 0.05131580481247511, 0.06432804701034911, 0.008423017116001574, 0.04661049948481377, 0.016213004528253805, 0.01484632381107076, 0.020378803747007623, 0.06339615443721414, 0.026927004619210493, 0.04545434101601131, 0.021781922987429425, 0.027969427101197653, 0.06682049803202972, 0.05647098892950453, 0.0294920488158823, 0.02301700700627407, 0.13766306539764628, 0.0325509904359933, 0.019067887078563217, 0.032009823771659285, 0.03779107253649272, 0.012070566262991633, 0.039081214636098593, 0.019440890500845853, 0.02918962920375634, 0.06163384314277209, 0.014767504017072497, 0.05280875731841661, 0.031183720639091916, 0.021369268470152747, 0.05991416452161502, 0.04599777494149748, 0.005939293750998331, 0.07687233170145191, 0.08601285997428931, 0.04348772759840358, 0.029503509431378916, 0.017670066772552673, 0.044917853592778556, 0.04450458123756107, 0.03906875026586931, 0.04623824563168455, 0.05743680136220064, 0.028655852474912535, 0.0186898110769107, 0.012679268365900498, 0.02694502025406109, 0.04999731267162133, 0.0324301502405433, 0.027363519184291363, 0.049873207026394084, 0.0621064687584294, 0.07303035192308016, 0.013163448293198599, 0.0818494931445457, 0.03822790808044374, 0.03494996053632349, 0.03993418351456057, 0.008425279738730751, 0.1111120346467942, 1.0505754640325904, 4.548143148422241, 29.34969160705805, 66.65448054671288, 81.73432096838951, 79.8018130660057, 73.84276002645493, 50.33832706511021, 58.901422172784805, 45.98385192453861, 41.984205543994904, 36.2148193269968, 31.258222796022892, 51.96059301495552, 63.04643355309963, 60.343965366482735, 41.4401089400053, 17.637232393026352, 2.498357151634991, 0.637162160128355, 0.04845380877668504, 0.24240729486336932, 0.06042812405212317, 0.12230932130478323, 0.04974391747964546, 0.08254072206909768, 0.11845612025354058, 0.18934401799924672, 0.3361222450621426, 0.898028671508655, 0.327540910220705, 0.5980466434266418, 1.040995940566063, 0.9317119640763849, 1.0840410995297134, 0.5842423404101282, 1.4420114597305655, 1.598512118216604, 1.8323153536766768, 0.9095056587830186, 0.8805106615182012, 0.7282322889659554, 0.33788926899433136, 0.8253654674626887, 0.7302562741097063, 0.39309199433773756, 0.4968847014242783, 0.571835768641904, 0.1267173222731799, 0.14532277156831697, 0.33193071372807026, 0.21690615074476227, 0.22101138514699414, 0.1585552646429278, 0.28081781580112875, 0.16930552606936544, 0.3920824360102415, 10.636094771325588, 44.156104400753975, 76.93877309560776, 65.07688879966736, 36.15232028067112, 29.26791049540043, 38.478764444589615, 43.456299751996994, 61.647018045187, 82.96199709177017, 85.1616382598877, 95.93955472111702, 95.48337399959564, 84.09647181630135, 65.75019747018814, 27.846672758460045, 4.631513999775052, 0.16967165720416233, 0.15628510911483318, 0.008927465096348897, 0.07930633859359659, 0.06318476851447485, 0.0689075879927259, 0.009509646552032791, 0.11222025408642367, 0.01577369577717036, 0.03200963081326336, 0.009372697113576578, 0.007571383639515261, 0.0178575184327201, 0.0562955340865301, 0.0348664540797472, 0.09715902007883415, 0.009255442419089377, 0.04022287896077614, 0.039540095676784404, 0.03664800555270631, 0.042836815846385434, 0.04790373262949288, 0.025053508470591623, 0.013593523799499962, 0.041275311159552075, 0.045980987561051734, 0.0431553011003416, 0.03253531627706252, 0.03172506912960671, 0.03237224416807294, 0.01583420864335494, 0.08608953867224045, 0.020426785449672025, 0.011713228650478413, 0.011069040756410686, 0.054535542003577575, 0.07492787510273047, 0.04215264103549998, 0.018541798999649473, 0.011779805790865794, 0.011892045422428055, 0.06246499659027904, 0.019101818070339505, 0.01138487561547663, 0.068561732332455, 0.044179605902172625, 0.03259026118030306, 0.026226793852401897, 0.040493514243280515, 0.03775996912736446, 0.03986010604421608, 0.08308743999805301, 0.013376630213315366, 0.030747079908906016, 0.19940841622883454, 0.22602891200222075, 0.09880308498395607, 0.12464033294236287, 0.21589044743450359, 0.15811232122359797, 0.1217821218597237, 0.17186194279929623, 0.11219036037800834, 0.16156226891325787, 0.17041568993590772, 0.1141366500814911, 0.13386430829996243, 0.12080748158041388, 0.16316069173626602, 0.15509111224673688, 0.2633359335595742, 0.14955516555346549, 0.3110513387946412, 0.20421548484591767, 0.113996666186722, 0.17899742553709075, 0.2623606921406463, 0.1472773659043014, 0.12613525585038587, 0.12355000668321736, 0.19801409885985777, 0.1665677729761228, 0.19504754163790494, 0.19134242873406038, 0.20907450380036607, 0.11122185765998438, 0.14062099886359647, 0.16897987166885287, 0.1329296623589471, 0.1517747066100128, 0.20968074939446524, 0.16047588345827535, 0.2491502556949854, 0.1436310459394008, 0.18696613231441006, 0.13597558485344052, 0.1315559321665205, 0.17415042937500402, 0.17641289625316858, 0.130426962277852, 0.19628725480288267, 0.3094077785499394, 1.8646155204623938, 7.553070830181241, 46.70760668814182, 81.63523748517036, 101.31584823131561, 89.98309314250946, 83.3883798122406, 52.61302560567856, 52.24397040903568, 52.84906893968582, 57.36413486301899, 67.1311117708683, 60.70834681391716, 127.11692735552788, 113.9689564704895, 74.03532609343529, 57.778039053082466, 26.48097664117813, 2.7424555784091353, 1.024132207967341, 0.3798032464692369, 0.6263851665426046, 0.29956802842207253, 0.5604004010092467, 0.28247146925423294, 0.24088151345495135, 0.37646877695806324, 0.36569338641129434, 0.4678739112569019, 0.676263605710119, 0.5673373444005847, 0.4221139760920778, 0.8466491941362619, 0.6026337691582739, 0.7533755991607904, 0.5046253313776106, 0.839852427598089, 0.8609886153135449, 0.7652084017172456, 0.23785102763213217, 0.45756283798255026, 0.3909923991886899, 0.20905427285470068, 0.5215552635490894, 0.5361813318450004, 0.44073541124816984, 0.5007324402686208, 0.9083310468122363, 0.46436488861218095, 0.3584170440444723, 0.635564939584583, 0.7082682789769024, 0.5268804403021932, 0.2850451780250296, 0.3321629762649536, 0.24751885182922706, 1.1735242791473866, 14.471618458628654, 64.37921583652496, 125.5296841263771, 118.73081535100937, 103.56264486908913, 52.21684366464615, 39.84401598572731, 39.55770514905453, 54.41922448575497, 89.88321930170059, 88.17777201533318, 107.30742752552032, 106.79621055722237, 103.30023095011711, 80.9726594388485, 34.465868175029755, 5.13895302079618, 0.3469206125009805, 0.21380449295975268, 0.11678125621983781, 0.20285318372771144, 0.14747590525075793, 0.14779179298784584, 0.13854316348442808, 0.3134409652557224, 0.10411842085886747, 0.09161798225250095, 0.2126931119710207, 0.10898811189690605, 0.15386118058813736, 0.11098745773779228, 0.143695360457059, 0.1301158985006623, 0.10202888181083836, 0.0917262393340934, 0.09355587084428407, 0.07521939813159406, 0.16182853665668517, 0.11472437909105793, 0.07693499865126796, 0.09569006491801701, 0.2504191204207018, 0.12269073326024227, 0.07835219643311575, 0.10627707612002268, 0.07747621726593934, 0.08757427189266309, 0.07699399939156137, 0.25732836686074734, 0.10699134872993454, 0.15347616921644658, 0.18884234101278707, 0.15615296229952946, 0.15324246691307053, 0.12767218431690708, 0.15085957915289328, 0.0713048288889695, 0.12480627716286108, 0.20074097206816077, 0.07797212776495144, 0.09902129124384373, 0.1446481593302451, 0.14144028536975384, 0.12850854021962732, 0.0820008096343372, 0.1290204588440247, 0.14461253624176607, 0.08092530406429432, 0.1566499934415333, 0.1289058118709363, 0.1444105533300899], [0.035926304044551216, 0.03799001264269464, 0.044025565730407834, 0.060426539566833526, 0.020925061544403434, 0.02975463921757182, 0.027442188693385106, 0.048483082791790366, 0.022808430112490896, 0.06953094751224853, 0.03380644084245432, 0.03590436986996792, 0.051228929005446844, 0.052591456478694454, 0.02269770538987359, 0.06430552282836288, 0.011320661287754774, 0.041335970599902794, 0.03136310515401419, 0.001857254942478903, 0.07972355175297707, 0.062330697546713054, 0.0795912639296148, 0.059885606679017656, 0.004885088283117511, 0.038356166041921824, 0.02087628388835583, 0.0643654512532521, 0.012373852332530078, 0.0760126204113476, 0.06407233260688372, 0.023134026996558532, 0.046913956248317845, 0.012385448389977682, 0.05722160451114178, 0.054651550817652605, 0.028602698002941906, 0.02519195797503926, 0.11839849248644896, 0.041520505619701, 0.05119080116855912, 0.039342587915598415, 0.08627281204098836, 0.06372637304593809, 0.2496199164306745, 0.43534608324989676, 2.280544526875019, 5.253724437206984, 9.6903046220541, 27.277402505278587, 44.35560129582882, 52.3197877407074, 51.57092772424221, 48.367027044296265, 26.57950345426798, 23.770395889878273, 21.532215289771557, 34.88330997526646, 27.404777370393276, 33.29391226172447, 51.507311537861824, 37.518875151872635, 18.279508128762245, 3.5391576401889324, 0.07456059363903478, 0.476496450137347, 0.1630833451054059, 0.10861293398193084, 0.07436037703882903, 0.12761356949340552, 0.015435804289154476, 0.06848476419690996, 0.037422718669404276, 0.10047742209280841, 0.23527656187070534, 0.10439684498123825, 0.19392042711842805, 0.28579902194906026, 0.08892273937817663, 0.08370461742742918, 0.18427915696520358, 0.43587161286268383, 0.7930117473006248, 0.8919840271119028, 1.3167162705212831, 1.2229472771286964, 2.4150413973256946, 1.093663964420557, 0.17692977242404595, 0.2297766093397513, 0.08160430239513516, 0.29647517250850797, 0.2784298814367503, 0.1145937610999681, 0.37024233606643975, 0.28239093138836324, 0.15943950391374528, 0.1526440732413903, 0.07425928910379298, 0.09878877637675032, 0.134326295228675, 0.1638755135354586, 0.16958846244961023, 0.10146161381271668, 0.11059306561946869, 0.11457536325906403, 0.15678773605031893, 2.6737170293927193, 25.11753760278225, 83.78878712654114, 100.70697650313377, 57.27164402604103, 32.93594487011433, 19.71247013658285, 20.859060510993004, 30.316635221242905, 38.50624077022076, 51.92092314362526, 61.00625082850456, 68.7741968035698, 61.45323984324932, 44.74489040672779, 10.726321879774332, 0.4820731852669269, 0.05136958454386331, 0.048058663378469646, 0.07235411438159645, 0.09466611634707078, 0.034955088776769117, 0.007973495485202875, 0.071491642302135, 0.06425392130040564, 0.030030528905626852, 0.03765610556001775, 0.029049732511339244, 0.07616270493599586, 0.007889937078289222, 0.0358804504503496, 0.06799748487537727, 0.07274959745700471, 0.019534486455086153, 0.024051824329944793, 0.02823429775162367, 0.034605889741214924, 0.03859454387566075, 0.02064861710096011, 0.05987704229482915, 0.018733677570708096, 0.02668922421435127, 0.005250126141618239, 0.04096038450370543, 0.04228426463669166, 0.039307714396272786, 0.02684605115064187, 0.02553253882069839, 0.04610143441823311, 0.09626365601434372, 0.087372890120605, 0.05956540706392843, 0.027997647266602144, 0.049394989327993244, 0.07071940053720027, 0.04862271416641306, 0.0925831898348406, 0.029683621251024306, 0.025418439181521535, 0.048882929695537314, 0.00839156860820367, 0.12478279561037198, 0.02859130789147457, 0.02672272104973672, 0.037290746258804575, 0.055973660928430036, 0.021591851545963436, 0.05142528643773403, 0.041368929378222674, 0.053649614346795715, 0.015413653036375763, 0.02125201470335014, 0.014426061352423858, 0.013600994443550007, 0.01910017050249735, 0.008581559341109823, 0.05211343916016631, 0.02202173687692266, 0.019804305375146214, 0.03792866671574302, 0.05784496031992603, 0.08130132802762091, 0.03334895503940061, 0.06478866838733666, 0.06049232724762987, 0.036641608239733614, 0.03511412731313612, 0.035879975475836545, 0.031238914161804132, 0.015577945050608832, 0.03648638434242457, 0.03627179976319894, 0.0666437778272666, 0.03703342139488086, 0.09118934001890011, 0.011799650819739327, 0.02380626250669593, 0.042919799088849686, 0.056893167056841776, 0.011967072841798654, 0.08471828725305386, 0.03504148589854594, 0.07628685882082209, 0.016306516990880482, 0.055752122425474226, 0.08067966060480103, 0.079234186996473, 0.032693056054995395, 0.015666221661376767, 0.12093336466932669, 0.07611779758008197, 0.04525225049292203, 0.03359121430548839, 0.10109007242135704, 0.18946509197121486, 1.2549249362200499, 4.664547527208924, 11.097930539399385, 41.344696059823036, 72.56749525666237, 72.3134408891201, 73.40262964367867, 66.04138344526291, 50.15623323619366, 37.2188850492239, 28.26593466103077, 38.26376438140869, 25.301607325673103, 35.04707358777523, 46.7380278557539, 45.568849593400955, 24.840792752802372, 5.357989417389035, 0.2842641418101266, 0.3792021959088743, 0.10301347429049201, 0.20329369290266186, 0.16379472333937883, 0.30798828753177077, 0.15925654966849834, 0.2878126467112452, 0.6072909536305815, 0.7721337676048279, 1.1019235337153077, 0.8187172492034733, 1.1578929866664112, 1.3729987316764891, 0.9803622972685844, 1.0464475792832673, 0.8718606631737202, 2.224821229465306, 3.2921537943184376, 2.059719138778746, 5.289621111005545, 6.391536807641387, 7.05217600800097, 5.403288686648011, 2.876868615858257, 2.0646493742242455, 1.8215931602753699, 0.9296204138081521, 0.9869426535442472, 0.6056696875020862, 0.9602697473019361, 0.9243881539441645, 0.4964079160708934, 0.7098948885686696, 0.3477525897324085, 0.37904480122961104, 0.3097777836956084, 0.09626765619032085, 0.06312463970971294, 0.1686164122656919, 0.0974209388368763, 0.17729817453073338, 0.04429318418260664, 3.5604312736541033, 28.246111124753952, 72.65681326389313, 60.3726614266634, 34.654068276286125, 30.238285325467587, 33.970891535282135, 46.93121708929539, 48.21747466921806, 59.2036047577858, 65.20190969109535, 79.06660571694374, 84.62604939937592, 80.66187411546707, 62.71299384534359, 16.586774960160255, 0.3941186220617965, 0.02655032199982088, 0.06859149245428853, 0.04515049833571538, 0.04335008889029268, 0.01862661349150585, 0.06705111300107092, 0.006545762917085085, 0.032721584211685695, 0.0414106195239583, 0.02771161984128412, 0.0858635175973177, 0.07971371087478474, 0.014161396647978108, 0.022142868365335744, 0.09353621877380647, 0.06510607752716169, 0.03723563808307517, 0.055584723595529795, 0.01290462614633725, 0.055544317365274765, 0.08403852451010607, 0.03026251870323904, 0.02593373086710926, 0.009365899040858494, 0.01976767111045774, 0.010095369907503482, 0.044120883467257954, 0.017907030814967584, 0.0322640279046027, 0.01592292497662129, 0.053544678376056254, 0.014025552081875503, 0.02973469214339275, 0.022755077116016764, 0.0292307590279961, 0.02614316123072058, 0.020918204099871218, 0.050153215634054504, 0.07227112742839381, 0.053686725441366434, 0.050121165986638516, 0.06243407871806994, 0.03921094576071482, 0.02588748022390064, 0.04099948826478794, 0.0245325504874927, 0.06395630523911677, 0.01941949438332813, 0.005571017345573637, 0.012265680597920436, 0.05816148259327747, 0.012000196747976588, 0.11636681127129123, 0.10352902943850495, 0.10880198868107982, 0.14775539806578308, 0.14786407817155123, 0.16948229080298916, 0.1169021223904565, 0.204612682282459, 0.1347224388155155, 0.1437798168626614, 0.1437955949222669, 0.17039154045050964, 0.18022486357949674, 0.09328226326033473, 0.14705329667776823, 0.14285747573012486, 0.10168814696953632, 0.08756110619287938, 0.12686174421105534, 0.07205757443443872, 0.11215513804927468, 0.22836431715404615, 0.12897475739009678, 0.16585418314207345, 0.09877670905552804, 0.25558660563547164, 0.18869934399845079, 0.20800263475393876, 0.3717000922188163, 0.2212220660294406, 0.1786071597598493, 0.20573785237502307, 0.14800961333094165, 0.10302107388270088, 0.1857324899174273, 0.1534483683644794, 0.12410346331307665, 0.20677699270891026, 0.21255297964671627, 0.16416872123954818, 0.17857570754131302, 0.20711468474473804, 0.17481196497101337, 0.14520500757498667, 0.2273729266016744, 0.6433939444832504, 2.4786081863567233, 7.506511453539133, 22.9465164989233, 69.39619302749634, 97.68898084759712, 89.61145028471947, 85.53813725709915, 75.90446099638939, 41.374896839261055, 34.075697511434555, 33.23235556483269, 54.143461883068085, 46.86086006462574, 55.43847419321537, 78.61032620072365, 59.25466641783714, 31.519204191863537, 7.137133749201894, 0.6104006711393595, 0.7024249050300568, 0.4551054385956377, 0.2793498180108145, 0.20863593905232847, 0.42754854541271925, 0.1688947918592021, 0.18256130773806944, 0.545615809969604, 0.4353735130280256, 0.49214412923902273, 0.3569222101941705, 0.6963678519241512, 0.7288952346425503, 0.2571938303299248, 0.3364391124341637, 0.3195877588586882, 1.1608062428422272, 2.9732217080891132, 2.2023093374446034, 3.6537592532113194, 5.201739901676774, 8.456929754465818, 4.681634735316038, 1.4377839490771294, 0.8248009602539241, 1.2016929988749325, 0.5624854797497392, 0.4939404234755784, 0.3944630379555747, 0.7176424947101623, 0.5698623682837933, 0.29836913337931037, 0.3201547299977392, 0.1863619202049449, 0.32987549901008606, 0.25405211141332984, 0.298908437252976, 0.5901724565774202, 0.3087549557676539, 0.2779131388524547, 0.32451769744511694, 0.41485580150038004, 5.017088335007429, 39.634141847491264, 131.25643283128738, 140.57111620903015, 80.68498447537422, 51.36034682393074, 31.44741654396057, 33.088829666376114, 45.992910638451576, 60.857105031609535, 75.32480970025063, 91.74699649214745, 101.0270257294178, 100.91175511479378, 70.93502685427666, 19.639411456882954, 0.4242162132868543, 0.11864763146149926, 0.21805400087032467, 0.16021537478081882, 0.1611541915917769, 0.10215202637482435, 0.20057336543686688, 0.13873776944819838, 0.20942877541529015, 0.09669327046140097, 0.07740720495348796, 0.25679511891212314, 0.2777687169145793, 0.05393764928157907, 0.1762181121739559, 0.12745007436024025, 0.1363719065557234, 0.2091504106647335, 0.09048303807503544, 0.09449885852518491, 0.16750902403146029, 0.1614911711658351, 0.15418870520079508, 0.17898513557156548, 0.1225878567493055, 0.16036419023294002, 0.044704860920319334, 0.13500089262379333, 0.18550050939666107, 0.12004646108835004, 0.10644425230566412, 0.12392940741847269, 0.13228571566287428, 0.24959830509033054, 0.1394300744868815, 0.10570803438895382, 0.08202615397749469, 0.12494229798903689, 0.17979535303311422, 0.13117912894813344, 0.1785110664786771, 0.16742983687436208, 0.16606150951702148, 0.21144492347957566, 0.09707948411232792, 0.26707911863923073, 0.09573077913955785, 0.16060158843174577, 0.13095335278194398, 0.1466443733079359, 0.10290589998476207, 0.18774059310089797, 0.1502934392192401], [0.029304586023499724, 0.01800901303795399, 0.040823866438586265, 0.020856147566519212, 0.04309432624722831, 0.07008702392340638, 0.046544667275156826, 0.036312072406872176, 0.03982867980084848, 0.051936054733232595, 0.034261102773598395, 0.03197601894498803, 0.05060116483946331, 0.042039893960463814, 0.04298133797419723, 0.06147087122371886, 0.06456239498220384, 0.06259402638534084, 0.09823204687563702, 0.05413435552327428, 0.038665726970066316, 0.030282976003945805, 0.04592144505295437, 0.041310529777547345, 0.12413051459589042, 0.03363240721228067, 0.1016155129764229, 0.046933522971812636, 0.01680989906162722, 0.014847670809103874, 0.03558218500984367, 0.03142422101518605, 0.05048149352660403, 0.03992711084720213, 0.07098885951563716, 0.009882787271635607, 0.035302250616950914, 0.01521546899311943, 0.06917588179931045, 0.04453486457350664, 0.09940500385710038, 0.09331716646556742, 0.07594587164930999, 1.6783013055101037, 3.344237837009132, 7.25554347038269, 13.824611026793718, 22.586153335869312, 36.33465729653835, 47.7772530913353, 51.39273248612881, 39.50953133404255, 51.41010135412216, 25.922589004039764, 25.582180470228195, 44.821916073560715, 74.91997182369232, 74.75749254226685, 39.051082134246826, 22.43952490389347, 10.867382660508156, 1.9073458900675178, 0.24435480911051854, 0.1697535754647106, 0.04063182459503878, 0.12611892860149965, 0.08176209783414379, 0.05444527829240542, 0.008536521181667922, 0.18642242008354515, 0.1867054306785576, 0.23381122096907347, 0.1133034928352572, 0.4417741805082187, 1.5206989436410367, 0.7295999187044799, 0.829611086519435, 2.2402493515983224, 1.10353440977633, 2.184488056227565, 3.6864393996074796, 3.888819389976561, 3.3817000268027186, 0.9761292056646198, 4.644221942871809, 5.344113511964679, 7.6358394138515, 7.926729954779148, 5.59419946745038, 2.632866846397519, 2.322362707927823, 4.199230195954442, 3.644515061751008, 1.5923598920926452, 0.549592652823776, 0.5847852362785488, 0.3182561381254345, 0.4003277263836935, 0.16551074688322842, 0.18885418568970636, 0.09477527142735198, 0.0884935405338183, 0.030107203892839607, 0.04718998694443144, 0.05085069344204385, 0.08429003093624488, 0.17199264984810725, 0.09173831407679245, 0.21069962909677997, 2.0599986612796783, 27.809748239815235, 83.46051514148712, 87.741829007864, 77.18415632843971, 32.08653084933758, 47.78788112103939, 44.50921185314655, 38.7168824672699, 51.3339876383543, 45.78153558075428, 62.330278381705284, 67.74254456162453, 60.454809218645096, 22.171297296881676, 2.6111697731539607, 0.19408160675084218, 0.06467448896728456, 0.02514626394258812, 0.06959440113860182, 0.0773501857474912, 0.06805841519962996, 0.029315516003407538, 0.02295334001246374, 0.024279333410959225, 0.038243589660851285, 0.015363694437837694, 0.025541724753566086, 0.05412383186921943, 0.02094991421472514, 0.1097111270064488, 0.03892717075359542, 0.07057078546495177, 0.036345316912047565, 0.020060947463207413, 0.02690020381123759, 0.027924250716750976, 0.02592714059574064, 0.013081781435175799, 0.03539393925166223, 0.0106013457843801, 0.08730664601898752, 0.05034689762396738, 0.03993768274085596, 0.05699287459719926, 0.02808250628731912, 0.04106237043743022, 0.028314540613791905, 0.04486620382522233, 0.024620934709673747, 0.025495822919765487, 0.07796979742124677, 0.034780357527779415, 0.10653649384039454, 0.020253169277566485, 0.07975717104272917, 0.05747362301917747, 0.03337238835229073, 0.026657727466954384, 0.0646273403253872, 0.027969197035417892, 0.05328602135705296, 0.04336867968959268, 0.038925719854887575, 0.008946965026552789, 0.0853104839916341, 0.039186436333693564, 0.028284023501328193, 0.05145925824763253, 0.043015539849875495, 0.04342780288425274, 0.05829915469803382, 0.009443526760151144, 0.023460518168576527, 0.027460605087981094, 0.019686092382471543, 0.02396238996880129, 0.02284717578731943, 0.020108828975935467, 0.05806469911476597, 0.0288006250775652, 0.02674630279216217, 0.053424676807480864, 0.05134941668075044, 0.00449067993031349, 0.01418296160409227, 0.003229848025512183, 0.02942668415926164, 0.01787692373909522, 0.01794417345081456, 0.02032059524935903, 0.0469410557707306, 0.02496204433555249, 0.024664882839715574, 0.040072456758935004, 0.040052878903225064, 0.022589882464671973, 0.04418475640704855, 0.030442875431617722, 0.056290840002475306, 0.0934307076386176, 0.07972138468176126, 0.03707387215399649, 0.06924114626599476, 0.046071132528595626, 0.1043449985445477, 0.021268317832436878, 0.13173505692975596, 0.044599628090509214, 0.10068553514429368, 0.6427095655817538, 3.012641267850995, 6.910487785935402, 15.79269452020526, 31.854931376874447, 62.22767248749733, 73.61756131052971, 74.33515280485153, 69.17210385203362, 71.5986156463623, 44.749731346964836, 24.83413551002741, 28.023148588836193, 41.587123051285744, 54.64224211871624, 44.89004261791706, 32.325545623898506, 17.673978321254253, 3.453355631791055, 0.20882468204945326, 0.1703375714714639, 0.2792636991944164, 0.07880768956965767, 0.1093729971034918, 0.37954263389110565, 0.3215368464589119, 0.9127483691554517, 2.3590312153100967, 1.143565617967397, 1.5019831666722894, 2.4525767331942916, 3.4230372961610556, 2.40383627358824, 4.707027822732925, 5.40252635255456, 5.45566032640636, 7.564552389085293, 6.392208421602845, 10.94525283202529, 8.670467846095562, 7.4238834623247385, 11.124853994697332, 10.896401703357697, 13.39215338230133, 14.17529420927167, 11.785062868148088, 12.40080937743187, 4.416827419772744, 4.704383164644241, 2.77329258620739, 2.897509108297527, 2.865725001320243, 1.6498962859623134, 2.05635251943022, 2.7981401653960347, 1.545476820319891, 1.695529343560338, 1.3325730571523309, 0.4786792548839003, 0.046207932609831914, 0.10294889259967022, 0.15682174125686288, 0.22146949806483462, 0.03993314821855165, 0.11134008920635097, 0.32377308583818376, 2.3567109648138285, 26.881353557109833, 68.09558361768723, 60.46252280473709, 48.319092616438866, 29.54590167850256, 49.7768197953701, 64.89353343844414, 58.38013954460621, 71.52033984661102, 62.93907791376114, 79.4733814895153, 83.70082184672356, 79.009198397398, 36.91694185137749, 3.9248625934123993, 0.28021958540193737, 0.046900849920348264, 0.02523618626582902, 0.02002783654461382, 0.03525280873873271, 0.02590522497484926, 0.07315472845220938, 0.05954285690677352, 0.09734020801261067, 0.012367335348244524, 0.03713344063726254, 0.05660567760060076, 0.021292771598382387, 0.07489756579161622, 0.1161929483350832, 0.05810746537463274, 0.03399529145099223, 0.05262078615487553, 0.02666541240614606, 0.024761842578300275, 0.021710764012823347, 0.057105272862827405, 0.04189081875665579, 0.055540050016134046, 0.045065006634104066, 0.10053363235783763, 0.028510692100098822, 0.053421233242261223, 0.041895449758158065, 0.04762115619087126, 0.02504730782675324, 0.050301493029110134, 0.05372374005673919, 0.012017029584967531, 0.05259530451439787, 0.06256993627175689, 0.02463776290824171, 0.03605833953770343, 0.05015946451749187, 0.05152631500095595, 0.05683114577550441, 0.07418281078571454, 0.05938887610682286, 0.01424885504093254, 0.05561209029110614, 0.014715994329890236, 0.06033017911249772, 0.022071572093409486, 0.012985956254851772, 0.03831580062978901, 0.03431046672631055, 0.18137651350116357, 0.16675396298523992, 0.09079543029656634, 0.18697393970796838, 0.14531932800309733, 0.2466827630996704, 0.0940988038200885, 0.21560326596954837, 0.11870145943248644, 0.12436981269274838, 0.13230995420599356, 0.08148456428898498, 0.08182932157069445, 0.10847184428712353, 0.23039308172883466, 0.13622380356537178, 0.1299749646568671, 0.18496948789106682, 0.13522954832296818, 0.10206040082266554, 0.10068671515909955, 0.1285934419138357, 0.07809484930476174, 0.11884364750585519, 0.2218731670291163, 0.10094991041114554, 0.17485365882748738, 0.09742409296450205, 0.11417706002248451, 0.1330507660168223, 0.12228758379933424, 0.11973131549893878, 0.17220033245394006, 0.1623168252990581, 0.1802735187811777, 0.15084835788002238, 0.22083249787101522, 0.09646252190577798, 0.277724425541237, 0.17714619752950966, 0.14212853828212246, 0.23293999896850437, 0.28342809760943055, 2.2567725274711847, 5.607565250247717, 12.719882056117058, 27.760219797492027, 51.432254165410995, 92.04404175281525, 94.99462142586708, 86.74746036529541, 66.5008395910263, 71.76301002502441, 40.24277038872242, 38.03527124226093, 63.76816302537918, 100.89698910713196, 100.76502218842506, 61.61324165761471, 39.81657385826111, 19.266051091253757, 4.2415812984108925, 0.694170679198578, 0.38832301273941994, 0.45799043378792703, 0.4123468970647082, 0.1718347950372845, 0.31715535500552505, 0.20812602422665805, 0.8403527538757771, 1.928340238519013, 0.5707848281599581, 0.8389326394535601, 1.6840126365423203, 4.125660443678498, 3.2600956270471215, 3.9149394258856773, 8.20571668446064, 5.972762228921056, 7.251520911231637, 9.522116146981716, 12.265118658542633, 9.723188057541847, 8.108961526304483, 19.84516091644764, 16.535819694399834, 22.828198447823524, 20.892314426600933, 18.36949110031128, 13.306722566485405, 8.239210937172174, 12.437093630433083, 9.104616399854422, 7.628464009612799, 4.395208954811096, 3.0662179179489613, 2.0648035034537315, 2.6704869652166963, 1.6675157030113041, 0.8409106114413589, 0.8635360223706812, 0.2664370718412101, 0.16615185857517645, 0.18784329149639234, 0.2897486725123599, 0.3448645962635055, 0.3461733885342255, 0.35170375427696854, 0.38243030081503093, 2.9069214407354593, 46.85921475291252, 117.03385680913925, 118.36787402629852, 104.74700331687927, 45.00461407005787, 61.2554794549942, 56.97171092033386, 58.716102316975594, 75.35672038793564, 72.83048674464226, 89.4985431432724, 102.01381757855415, 94.45108339190483, 40.34709379076958, 4.008382586762309, 0.50190384616144, 0.09971137726097368, 0.11603835897403769, 0.14786247513256967, 0.17593348369700834, 0.1511997648049146, 0.1595530821941793, 0.14255294285248965, 0.13870515947928652, 0.12028703567921184, 0.07416006395942532, 0.16699771396815777, 0.1229215189232491, 0.1573316560825333, 0.2188563664094545, 0.12165648367954418, 0.18662613962078467, 0.16715904203010723, 0.1260908308904618, 0.09076918795472011, 0.16430468269390985, 0.17593931697774678, 0.1600114325992763, 0.17827852192567661, 0.0926337820419576, 0.16550035681575537, 0.14920310553861782, 0.20541455800412223, 0.11015774405677803, 0.20410754688782617, 0.11846724504721351, 0.10314843384549022, 0.15683244302636012, 0.11307746433885768, 0.15325211483286694, 0.1194272204884328, 0.1448966600582935, 0.19626298657385632, 0.14521704521030188, 0.24178703752113506, 0.2001658669905737, 0.11614033748628572, 0.1295558738638647, 0.11239035433391109, 0.12159815087215975, 0.17216665379237384, 0.19402192323468626, 0.1258069890900515, 0.0728480656107422, 0.12492126552388072, 0.13553630764363334], [0.024319544827449135, 0.007883802300057141, 0.03270804001658689, 0.03178706072503701, 0.04120025034353603, 0.0335350634122733, 0.045595427000080235, 0.04484628458158113, 0.0674668863939587, 0.028027591069985647, 0.04753559027449228, 0.02914513745054137, 0.08266535834991373, 0.025215810601366684, 0.045875743599026464, 0.0031238326937454985, 0.042313282610848546, 0.026013723254436627, 0.10311464386177249, 0.03905089419276919, 0.01684348681010306, 0.02400931411102647, 0.06319701395113952, 0.011761920031858608, 0.08189002182916738, 0.040855021798051894, 0.027427900495240465, 0.020869636100542266, 0.08443326543783769, 0.06619820720516145, 0.0021854407623322913, 0.057623907923698425, 0.025717437492858153, 0.03954838546633255, 0.03130156626866665, 0.06433799178921618, 0.031592243249178864, 0.059675003722077236, 0.03421533452637959, 0.05109852623718325, 0.048534149973420426, 0.6350757158361375, 5.774656059220433, 15.222690906375647, 15.21586837247014, 21.496430709958076, 42.39177547395229, 53.96331734955311, 50.681745037436485, 53.71204063296318, 30.334332771599293, 22.620661184191704, 29.062092639505863, 26.987432464957237, 72.15764924883842, 72.57205501198769, 56.232711374759674, 27.341647557914257, 5.595310907810926, 0.8297479385510087, 0.25479633710347116, 0.16137667262228206, 0.021384415704233106, 0.08523491851519793, 0.04055265599163249, 0.13217342871939763, 0.19743360579013824, 0.17665838386164978, 0.3121118975104764, 1.1582114570774138, 2.715207953006029, 2.437722380273044, 1.4476727996952832, 2.6462207548320293, 3.452522289007902, 2.960122860968113, 2.559850439429283, 3.210987774655223, 7.300456585362554, 9.437087159603834, 3.506818525493145, 8.342589139938354, 4.7892639599740505, 2.904620189219713, 9.177438542246819, 11.214789468795061, 7.569309733808041, 9.24203222617507, 8.032980803400278, 10.200690384954214, 2.8574682818725705, 1.541512564290315, 2.5911424728110433, 3.921217401511967, 3.363743615336716, 4.060666831210256, 2.178795486688614, 3.7213576259091496, 1.5379155823029578, 0.3351960447616875, 0.585110712563619, 0.6184596824459732, 0.14607695688027889, 0.17067714856239036, 0.10972824835334904, 0.034834983307518996, 0.12191204223199748, 0.12800922326277941, 0.1525730051798746, 0.10435099509777501, 0.40336762263905257, 1.512508720625192, 26.51261944323778, 86.54663354158401, 97.06584468483925, 65.08829578757286, 39.95913080871105, 20.249143838882446, 27.042354717850685, 33.0104398727417, 51.88483268022537, 61.95868492126465, 68.5527902841568, 78.2831409573555, 44.56019751727581, 4.601441463455558, 0.40307061513885856, 0.183946511533577, 0.014855730532872258, 0.07497099388274364, 0.11977547328569926, 0.04959918383974582, 0.06772781809559092, 0.03887697559548542, 0.035939005902037024, 0.07495465921238065, 0.024706049771339167, 0.033404805362806655, 0.054882752083358355, 0.05223253530857619, 0.07318102274439298, 0.028659457457251847, 0.08869282202795148, 0.05111083846713882, 0.02437094968627207, 0.007803391526977066, 0.03606442885939032, 0.04003389476565644, 0.04726483253762126, 0.03389633719052654, 0.03343773816595785, 0.011116478835901944, 0.04270633144187741, 0.030343192011059728, 0.05593075737124309, 0.047287664710893296, 0.06669828115263954, 0.020185659814160317, 0.023861376248532906, 0.02386065636528656, 0.18784474610583857, 0.08267552577308379, 0.03465616282483097, 0.025783032215258572, 0.03058665355638368, 0.03663979368866421, 0.04406558975460939, 0.06739207790815271, 0.04641343701223377, 0.06287627998972312, 0.06235309556359425, 0.10041713001555763, 0.010793939600262092, 0.027140917554788757, 0.032884125685086474, 0.012071738856320735, 0.03198983773472719, 0.04359120524895843, 0.040027861105045304, 0.05172384131583385, 0.02284181748109404, 0.07336508278967813, 0.03622286254540086, 0.026805168090504594, 0.031303306604968384, 0.012609376608452294, 0.05212777745327912, 0.0760806308244355, 0.15680143609642982, 0.04151664274104405, 0.011622751571849221, 0.04197411370114423, 0.044591149053303525, 0.010052884736069245, 0.038891532822162844, 0.031151325893006288, 0.03221634491637815, 0.06661882682237774, 0.023839148925617337, 0.1327982873772271, 0.036715399983222596, 0.041675985557958484, 0.05367347439459991, 0.03890089501510374, 0.07115093714674003, 0.029758075361314695, 0.04229779769957531, 0.03352311112394091, 0.012889221943623852, 0.05147331081388984, 0.039108150886022486, 0.03618281254603062, 0.04842779650061857, 0.06522141469758935, 0.09113174193771556, 0.05069713566626888, 0.08151854723109864, 0.24312714842380956, 3.7778135715052485, 15.285347644239664, 16.771346256136894, 32.055015340447426, 63.8450101017952, 77.73650988936424, 74.37262639403343, 73.92507120966911, 59.551711678504944, 41.826080828905106, 43.66764061152935, 26.376189664006233, 35.27417980134487, 54.17635291814804, 52.94664770364761, 33.86902280151844, 9.186371862888336, 1.1308709741570055, 0.42278179025743157, 0.22068216843763366, 0.0093144190395833, 0.08342498360434547, 0.05570187160628848, 0.45789395458996296, 1.3347221980802715, 1.6291301627643406, 2.4235256295651197, 4.788715364411473, 4.45201400667429, 5.551727246493101, 4.203474568203092, 3.1568164564669132, 2.3158346582204103, 2.4361730134114623, 1.5471230819821358, 5.244098603725433, 7.5596843753010035, 10.646111033856869, 9.469443373382092, 12.29851696640253, 8.697639238089323, 10.238658897578716, 20.677823536098003, 19.941970221698284, 13.69060741737485, 10.891111437231302, 9.403767697513103, 5.2876722905784845, 2.45749746914953, 2.050599390640855, 0.8344633074011654, 2.297209482640028, 1.6854672459885478, 1.906643877737224, 1.4752108720131218, 1.6994102415628731, 3.1457379134371877, 2.823748178780079, 2.1425354573875666, 2.1698659658432007, 2.279800954274833, 1.6453305934555829, 0.35789347370155156, 0.7476766174659133, 0.3502899332670495, 0.05564588398556225, 0.11304690269753337, 0.13987848011311144, 0.3921113203978166, 2.0313954586163163, 27.937081307172775, 69.797732681036, 54.00690481066704, 56.53018981218338, 38.16740155220032, 33.86931538581848, 50.74112065136433, 50.88479854166508, 70.84567844867706, 76.36181965470314, 81.2863402068615, 97.67017185688019, 70.37172228097916, 9.15250713005662, 0.7281140796840191, 0.12938166211824864, 0.06632994583924301, 0.11038707511033863, 0.03050885792617919, 0.12683771346928552, 0.034139115959987976, 0.04244375588314142, 0.0707184209022671, 0.03423205140279606, 0.05018733587348834, 0.07635414935066365, 0.020744398680108134, 0.03748626135347877, 0.06794012428144924, 0.06483692282927223, 0.013697231515834574, 0.043060354437329806, 0.035269592408440076, 0.05186377326026559, 0.0443980978889158, 0.04828606113733258, 0.07399665788398124, 0.025755333408596925, 0.08449809945886955, 0.056878064351622015, 0.07199750500149094, 0.04472117332625203, 0.028427920369722415, 0.06968932182644494, 0.047636800663894974, 0.07326464052312076, 0.0362293377838796, 0.020929963429807685, 0.11945276521146297, 0.03676405147416517, 0.02644418374984525, 0.01039324850353296, 0.028588936729647685, 0.01324746961472556, 0.031283157295547426, 0.011182889920746675, 0.04049731775012333, 0.0232386957941344, 0.05802665662486106, 0.0361649564729305, 0.048799259966472164, 0.02288738720380934, 0.0349427431501681, 0.013972180531709455, 0.14794296846957877, 0.12596796092111617, 0.1584464657935314, 0.16848684812430292, 0.169369543727953, 0.20431702549103647, 0.2220517722889781, 0.14863019721815363, 0.15165257878834382, 0.08103682659566402, 0.11331340050674044, 0.20213289972161874, 0.2319628428085707, 0.11384742771042511, 0.19763164047617465, 0.11067899147747084, 0.10983601561747491, 0.13227298040874302, 0.19176665518898517, 0.15201765607343987, 0.10696156634367071, 0.17025146749801934, 0.1698088803095743, 0.1516010143677704, 0.22325463040033355, 0.16553148248931393, 0.17796919477405027, 0.11976751746260561, 0.11287309913313948, 0.20496469776844606, 0.11154045423609205, 0.09669258026406169, 0.14336851862026379, 0.14629980898462236, 0.07956285451655276, 0.12833003886044025, 0.18066528369672596, 0.15961705532390624, 0.14362602902110666, 0.11503226647619158, 0.1138514575723093, 1.2490375083871186, 8.680881187319756, 24.08078033477068, 34.56309735774994, 55.45459672808647, 91.00957006216049, 103.81467014551163, 86.0706102848053, 79.63651433587074, 48.39630447328091, 34.49918478727341, 39.7454758733511, 41.208100989460945, 99.95044469833374, 103.40023398399353, 79.60302293300629, 43.353716656565666, 10.280184969305992, 2.3974041687324643, 0.6065048114396632, 0.3526420664275065, 0.12361572385998443, 0.3029527561739087, 0.12534397799754515, 0.3633468638872728, 0.9017009963281453, 1.1802375689148903, 2.147325575351715, 6.4531894493848085, 9.052795730531216, 6.792211532592773, 6.370789920911193, 8.818947728723288, 11.387895829975605, 13.817307818681002, 12.788256537169218, 14.915630333125591, 20.464653074741364, 19.618075601756573, 14.916647728532553, 20.040322244167328, 16.100387759506702, 15.224700048565865, 25.179875157773495, 30.370848812162876, 27.737863697111607, 24.96442671865225, 23.487502969801426, 24.867191836237907, 15.548052247613668, 17.097296565771103, 17.426602095365524, 18.264046758413315, 15.336106270551682, 12.007972206920385, 14.7477144934237, 13.094218019396067, 9.611445553600788, 5.097716683521867, 2.83250552136451, 3.049150421284139, 0.9958847018424422, 0.7446934806648642, 0.18732123513473198, 0.3836264053825289, 0.32936427800450474, 0.18174319382524118, 0.34402846300508827, 0.4445295670302585, 0.5315318063367158, 3.5640683909878135, 41.72759771347046, 119.72865700721741, 135.53415209054947, 85.81911697983742, 52.449330389499664, 33.13827261328697, 40.740992054343224, 49.1431088000536, 78.22545245289803, 87.60464116930962, 94.4139289855957, 116.73001751303673, 79.81373682618141, 10.595797933638096, 0.6393681198824197, 0.2815617743181065, 0.25042143592145294, 0.19236227322835475, 0.15442674164660275, 0.1792387868044898, 0.12164742947788909, 0.23902843007817864, 0.1116474051377736, 0.14304145413916558, 0.07309555701795034, 0.12357979649095796, 0.0999894822598435, 0.18572825967567042, 0.17736136098392308, 0.13383713085204363, 0.18497821554774418, 0.18773986579617485, 0.09555961762089282, 0.1377999025862664, 0.16908433637581766, 0.22838291537482291, 0.19333905831445009, 0.1454222490428947, 0.23103734012693167, 0.12025493779219687, 0.14663730806205422, 0.10809302984853275, 0.1000714376277756, 0.15070188761455938, 0.21975289564579725, 0.16631910897558555, 0.1429752545664087, 0.10620194851071574, 0.35790546680800617, 0.24181050423067063, 0.1671200941200368, 0.11182021422428079, 0.08596684681833722, 0.13200749934185296, 0.15106277918675914, 0.1983378385193646, 0.2330009886645712, 0.11348746382282116, 0.21429526037536561, 0.24915838963352144, 0.14742497907718644, 0.16755004995502532, 0.11154512234497815, 0.13466306700138375], [0.017855620390037075, 0.028708190584438853, 0.044905838221893646, 0.05953606996627059, 0.03686853473482188, 0.00847182353027165, 0.06256837776163593, 0.05603244273515884, 0.038697502022841945, 0.07597324205562472, 0.014144231699901866, 0.05025516074965708, 0.0136009295056283, 0.044685950997518376, 0.010656833383109188, 0.03094124243943952, 0.03545866195054259, 0.05230932161794044, 0.046852239247527905, 0.03631509665865451, 0.05502089174115099, 0.08708915222086944, 0.039948692501639016, 0.03454017627518624, 0.048872751140152104, 0.04222772782668471, 0.03473801429208834, 0.025528386504447553, 0.04157803690759465, 0.03064072829147335, 0.12417584497598, 0.023266504067578353, 0.07562715632957406, 0.04238133013132028, 0.00968816739259637, 0.044500859366962686, 0.04166120939771645, 0.01554857641167473, 0.05660793372953776, 0.3595433273585513, 4.702156009152532, 15.579115580767393, 24.33022554963827, 23.714360296726227, 32.034279853105545, 38.247106075286865, 49.848879128694534, 36.25366844236851, 33.71209882199764, 23.029838427901268, 15.193605367094278, 31.96014203131199, 47.29765422642231, 73.2832932472229, 39.76970337331295, 20.004117786884308, 4.91913671605289, 0.24073318782029673, 0.25573871622327715, 0.05005332626751624, 0.06969341848162003, 0.17938041826710105, 0.028993548221478704, 0.10312015801900998, 0.30312294547911733, 0.5721800064202398, 1.5605298313312232, 1.5059796022251248, 1.7914510401897132, 1.869405994657427, 3.547260230407119, 5.67239404655993, 6.457457570359111, 5.491018854081631, 1.5457246382720768, 5.092089660465717, 8.296993486583233, 7.680861772969365, 6.812141463160515, 8.934795912355185, 5.639693476259708, 12.091979999095201, 10.105174910277128, 10.550954639911652, 12.92396055534482, 12.10016855970025, 23.077932447195053, 16.49386614561081, 9.550455026328564, 11.728576049208641, 4.376453636214137, 16.361726336181164, 37.692609429359436, 50.33648416399956, 43.92115160822868, 31.985384076833725, 26.848489120602608, 24.350411966443062, 7.4583428632467985, 9.692912232130766, 5.750119825825095, 1.0834990348666906, 1.4805849711410701, 1.0987901268526912, 0.5265629198402166, 0.09684627904789522, 0.2505642845062539, 0.027058969608333427, 0.05982812734146137, 0.045962571166455746, 0.051216891370131634, 0.043641623051371425, 0.08464269951218739, 6.968856928870082, 40.31680941581726, 62.94657491147518, 79.59835678339005, 58.48428055644035, 33.16060781478882, 24.022377468645573, 26.00139107555151, 46.65323160588741, 63.13620373606682, 56.934043541550636, 65.82874685525894, 56.227197870612144, 20.117991976439953, 2.2951428685337305, 0.12403541579260491, 0.04226217090035789, 0.04810276179341599, 0.03598661467549391, 0.03068279507715488, 0.054471105031552725, 0.038305547859636135, 0.013292258227011189, 0.016346711709047668, 0.05786639354482759, 0.06663190346444026, 0.05066160163551103, 0.02756350571871735, 0.0976576616812963, 0.07167124203988351, 0.02615503744891612, 0.07611451728735119, 0.006051838590792613, 0.042300725472159684, 0.07734510945738293, 0.02392145681369584, 0.028799541541957296, 0.044832220883108675, 0.022716817547916435, 0.05167635128600523, 0.05182252840313595, 0.031082936984603293, 0.025390977862116415, 0.053669292392442, 0.039647569792578, 0.06061520834919065, 0.02277785177284386, 0.020837146730627865, 0.012907142954645678, 0.005659743883370538, 0.033481187201687135, 0.02753987388132373, 0.0339944342704257, 0.035305041092215106, 0.04679961726651527, 0.02559982935053995, 0.019742703407246154, 0.07376781664788723, 0.03435276543314103, 0.03569682827219367, 0.12484835693612695, 0.023427279229508713, 0.020000343683932442, 0.02649377962370636, 0.009178870404866757, 0.0332401339255739, 0.034842337990994565, 0.009663388937042328, 0.03451889890129678, 0.056014664587564766, 0.030870948066876736, 0.03664545627543703, 0.04233387720887549, 0.03410844670725055, 0.02653155865118606, 0.04199589202471543, 0.036988796055084094, 0.050446434470359236, 0.02107199379679514, 0.04334622230089735, 0.0752896349877119, 0.06257370638195425, 0.04888451047008857, 0.03721515851793811, 0.07246334367664531, 0.07036878771032207, 0.06142473561340012, 0.04700903649791144, 0.054440109233837575, 0.03096292984992033, 0.02220469668827718, 0.020141600361966994, 0.026143062896153424, 0.04616713304130826, 0.08250090584624559, 0.06580260538612492, 0.03716122293553781, 0.03353121908730827, 0.017105344340961892, 0.03093291183176916, 0.07352531989454292, 0.03825608000624925, 0.1435029660933651, 2.2726167272776365, 13.869405873119831, 24.687729366123676, 33.560353964567184, 53.615617007017136, 62.94262692332268, 72.22045227885246, 61.48572050035, 57.952586486935616, 49.27579768002033, 22.252973914146423, 24.737894274294376, 27.643054984509945, 52.039993554353714, 43.31200249493122, 29.500193931162357, 7.556405151262879, 0.5379396281205118, 0.3368690237402916, 0.05263699837087188, 0.06060262523533311, 0.05437317864561919, 0.3423799155279994, 0.6157589773647487, 1.618735226802528, 3.0081192729994655, 3.4871883038431406, 4.675553636625409, 5.772459777072072, 4.430079208686948, 4.767589922994375, 5.760943545028567, 4.408282153308392, 1.0293115675449371, 1.6527740377932787, 5.6773964781314135, 6.450737630948424, 3.508022823370993, 2.8988646855577826, 5.739454748108983, 8.088509123772383, 15.377356857061386, 14.745140131562948, 11.20898338034749, 16.093690618872643, 12.492111828178167, 20.088940635323524, 16.496864184737206, 3.5955777252092957, 2.2996556013822556, 3.230645307339728, 18.265802264213562, 45.5738615244627, 56.412156745791435, 48.21041464805603, 36.68675400316715, 32.32125945389271, 26.01200580596924, 11.810912881046534, 11.45105604082346, 6.889589857310057, 4.803559742867947, 3.644408192485571, 3.4749463107436895, 1.6224072547629476, 0.8510424708947539, 0.9641362773254514, 0.23833668907172978, 0.13139092305209488, 0.042598348954925314, 0.1288232405204326, 0.0051003185308218235, 0.22190369898453355, 7.242224235087633, 36.1496452242136, 51.937691643834114, 47.146813720464706, 42.11982026696205, 34.36361566185951, 37.12125688791275, 50.01502141356468, 65.77757120132446, 86.0477203130722, 66.25708267092705, 82.03154861927032, 84.5257879793644, 33.89582276344299, 3.6495260428637266, 0.08040942979278043, 0.09973571228329092, 0.04117056814720854, 0.01500857306382386, 0.022825516207376495, 0.050286427431274205, 0.04218559610308148, 0.03397854859940708, 0.05982234230032191, 0.042060996929649264, 0.06011267418216448, 0.008927504986786516, 0.00699399970471859, 0.012122053685743595, 0.03693573991768062, 0.01753632619511336, 0.033515040267957374, 0.008614103444415377, 0.091023774293717, 0.037988895710441284, 0.021305549526005052, 0.05293931964843068, 0.015063817609188845, 0.01494747575634392, 0.010584465635474771, 0.021590528667729814, 0.026837624063773546, 0.08542631840100512, 0.036578332728822716, 0.02092365702992538, 0.05768064882431645, 0.04904249515675474, 0.021634217046084814, 0.05445286675239913, 0.05229112786764745, 0.03145540234982036, 0.016946348478086293, 0.04881002110778354, 0.047229747506207787, 0.0448227213928476, 0.06611038144910708, 0.045277902827365324, 0.03368302910530474, 0.05390355501731392, 0.026700117086875252, 0.03392143662495073, 0.03542595179169439, 0.05270803303574212, 0.1526214080513455, 0.12714888114714995, 0.11639152478892356, 0.14367349678650498, 0.14477919292403385, 0.12709197326330468, 0.11722212904714979, 0.14538564631948248, 0.1262583039351739, 0.18189966824138537, 0.08330564625794068, 0.13951427856227383, 0.11494518286781386, 0.14172967843478546, 0.107582966593327, 0.15309374051867053, 0.18114362756023183, 0.15609143825713545, 0.13717063557123765, 0.20149217394646257, 0.15660648874472827, 0.20109889504965395, 0.15515544160734862, 0.10956175494357012, 0.18637094472069293, 0.1050247167586349, 0.2469296904746443, 0.11677771617542021, 0.1168066450918559, 0.17219590925378725, 0.2654211310436949, 0.15573933371342719, 0.34209736506454647, 0.1166725464281626, 0.15703865617979318, 0.14940544468117878, 0.20199575083097443, 0.2190619264729321, 0.11706156539730728, 1.14237355068326, 7.041679071262479, 23.42571448534727, 38.712052926421165, 66.38416305184364, 85.80715522170067, 90.64705431461334, 93.52984562516212, 67.70734325051308, 56.698619574308395, 36.3246638327837, 22.65914361923933, 41.57530568540096, 67.84261599183083, 100.64866483211517, 61.516236662864685, 33.28761599957943, 10.350049920380116, 1.2092911661602557, 0.8482395275495946, 0.2504674787633121, 0.1425686021684669, 0.39232078415807337, 0.29609988327138126, 0.3894575487356633, 1.1512413248419762, 2.6799610443413258, 4.061897015199065, 5.03595432266593, 6.104379091411829, 6.640481874346733, 11.265160515904427, 15.303564816713333, 15.465038102120161, 14.724331498146057, 13.154816217720509, 14.542938731610775, 19.20441459864378, 19.47718296200037, 21.367355436086655, 25.24857547134161, 18.072649128735065, 30.34231424331665, 28.374122455716133, 27.09117829799652, 32.91674830019474, 30.061366818845272, 50.130626410245895, 39.99116688966751, 27.314828597009182, 26.58260028809309, 15.459843780845404, 23.2577084004879, 48.22352394461632, 57.87021830677986, 49.90509331226349, 39.09863278269768, 37.356582060456276, 38.26559208333492, 16.378741823136806, 22.75668628513813, 17.676518484950066, 9.023871682584286, 6.7585367895662785, 3.503641183488071, 1.367875300347805, 0.47449867764953524, 0.4369274515192956, 0.20587509032338858, 0.12598614353919402, 0.1211700429848861, 0.25776748079806566, 0.1249655123683624, 0.3852301271399483, 11.415555495768785, 61.3335120677948, 91.2497627735138, 113.05538669228554, 77.4241590499878, 47.30615437030792, 33.97752217948437, 39.71044935286045, 67.8195284307003, 90.27981922030449, 78.63145306706429, 98.17159295082092, 103.23843866586685, 38.77444177865982, 3.2730515068396926, 0.25947768590413034, 0.13746293785516173, 0.19541420711902902, 0.11245476533076726, 0.0874092553567607, 0.09923664765665308, 0.1910848292754963, 0.09201303488225676, 0.2445644955150783, 0.22325709433062002, 0.19175484019797295, 0.14027873519808054, 0.14761922881007195, 0.17435451998608187, 0.18743488762993366, 0.12938145431689918, 0.14074708975385875, 0.162507186178118, 0.09447107993764803, 0.1646311386139132, 0.25600336608476937, 0.1751161416177638, 0.12549828534247354, 0.1628878782503307, 0.15386352577479556, 0.158165963657666, 0.13500699307769537, 0.09813488490181044, 0.18557178525952622, 0.11865756881888956, 0.24832868337398395, 0.11514345504110679, 0.08998808494652621, 0.14589262224035338, 0.1498008906492032, 0.1518960774410516, 0.11892053400515579, 0.1216074128751643, 0.10227704857243225, 0.16076636005891487, 0.167574243969284, 0.08365920541109517, 0.11614761053351685, 0.1713142081280239, 0.13611018075607717, 0.18688152747927234, 0.07967794677824713, 0.18578460352728143], [0.011911046258319402, 0.009452429749217117, 0.021885022142669186, 0.07298875454580411, 0.03973112448875327, 0.030350823144544847, 0.07102169212885201, 0.0472576967877103, 0.022873382877151016, 0.04826906224479899, 0.02527630676922854, 0.03259472890931647, 0.021645098786393646, 0.09660456897108816, 0.07130450976546854, 0.04969424182490911, 0.021603588611469604, 0.0589343663159525, 0.027103266547783278, 0.024743183130340185, 0.0936798688780982, 0.01568998151924461, 0.04470469764783047, 0.09878321769065224, 0.05088050922495313, 0.020750311741721816, 0.027187034611415584, 0.03398271575861145, 0.024758465806371532, 0.02848784137313487, 0.07994428131496534, 0.05446936840598937, 0.03762239350180607, 0.08153756847605109, 0.01664149091084255, 0.035712439348571934, 0.006350710737024201, 0.06400858954293653, 2.535040145739913, 12.455367799848318, 25.675777047872543, 33.771261647343636, 42.00347810983658, 41.37761369347572, 42.34745465219021, 41.38829492032528, 41.82129308581352, 22.91256722062826, 32.215207144618034, 42.06096522510052, 71.26574590802193, 69.40861836075783, 57.12967984378338, 25.747173316776752, 6.386961853131652, 0.6688855297397822, 0.1950321049662307, 0.07403590265312232, 0.06809512924519368, 0.16924933064728975, 0.18508086941437796, 0.13621797028463334, 0.23679306643316522, 0.24700898153241724, 0.8072343247476965, 2.1982573298737407, 2.5828418182209134, 4.6149407140910625, 3.6492510326206684, 3.722674730233848, 2.4269259721040726, 5.105296801775694, 5.225138096138835, 21.279080472886562, 50.45533038675785, 74.30832624435425, 65.9412208199501, 44.02450606226921, 21.11300278455019, 8.771844506263733, 8.348462674766779, 9.016068801283836, 8.456828109920025, 7.592324148863554, 21.605813540518284, 16.55161164700985, 4.598815804347396, 5.368380434811115, 3.501060171984136, 4.23453220166266, 45.81166796386242, 107.65215262770653, 118.68853121995926, 120.33812910318375, 117.60249629616737, 106.57177180051804, 91.64502516388893, 87.95614510774612, 71.38348639011383, 56.09221391379833, 44.51172731816769, 28.34591466933489, 21.35181427001953, 11.807334423065186, 5.017645955085754, 3.5183585062623024, 1.6752175334841013, 0.028607744607143104, 0.13491636200342327, 0.06134185998234898, 0.03734855585207697, 0.02816048559907358, 0.16491226415382698, 0.1476783779799007, 0.31863246636930853, 13.57428615912795, 43.12374159693718, 85.46268090605736, 90.34262984991074, 38.04205007851124, 21.99468657374382, 22.562425509095192, 27.96756897121668, 53.65619122982025, 70.59195086359978, 63.311408534646034, 59.88596074283123, 33.427885472774506, 3.300643963739276, 0.25588177260942757, 0.028665919708146248, 0.04280317800294142, 0.023261077112692874, 0.05701669382688124, 0.12384512912831269, 0.03826653315627482, 0.011133313528262079, 0.07341653588810004, 0.059719528871937655, 0.04105013984371908, 0.05426226467534434, 0.0429818315024022, 0.04891520569799468, 0.07639535338967107, 0.033451475319452584, 0.033497128533781506, 0.03690257333801128, 0.06298481166595593, 0.06471461689216085, 0.040906467474997044, 0.028270097100175917, 0.06195925634528976, 0.046635840117232874, 0.020836569710809272, 0.05998388929583598, 0.033644808499957435, 0.051857298021786846, 0.005287879193929257, 0.030076885304879397, 0.03465598842012696, 0.015563525121251587, 0.07993089297087863, 0.036689510161522776, 0.013582397150457837, 0.025313300975540187, 0.03701065230416134, 0.06622926608542912, 0.028816284393542446, 0.0597692267911043, 0.0208113107146346, 0.04803593139513396, 0.022255127478274517, 0.024620079384476412, 0.03989831551734824, 0.05874640999536496, 0.02153328496206086, 0.029310764402907807, 0.017678389958746266, 0.013930411532783182, 0.014039034122106386, 0.057319215484312735, 0.02278897100040922, 0.0438583227514755, 0.036950972498743795, 0.07386240336927585, 0.03953716790420003, 0.03940023423638195, 0.048582152085145935, 0.026609419219312258, 0.06718979813740589, 0.04429050502949394, 0.05519883277884219, 0.043691818209481426, 0.042433881608303636, 0.020414979735505767, 0.06085268818424083, 0.0499291093001375, 0.08893238729797304, 0.008652678425278282, 0.07801194398780353, 0.05901838114368729, 0.0494519009225769, 0.009920708234858466, 0.042881033004960045, 0.06846234391559847, 0.04430593427969143, 0.042184820558759384, 0.050322677634540014, 0.01229929803230334, 0.022601857017434668, 0.012798075076716486, 0.03160437736369204, 0.00859062745803385, 0.2020970539888367, 1.7302867909893394, 11.332713291049004, 26.029524765908718, 44.20796021819115, 61.6838950663805, 70.59859290719032, 69.79711711406708, 66.26231878995895, 67.88794755935669, 43.171896412968636, 39.49736438691616, 38.02281551063061, 35.7888849824667, 38.0002561211586, 50.32003104686737, 32.324892058968544, 9.72472982481122, 0.9532848908565938, 0.3106499556452036, 0.11024598541553132, 0.026612948131514713, 0.242445916228462, 0.49199365137610584, 0.7055863947607577, 0.7494023779872805, 2.678317870013416, 3.1746876100078225, 7.365619288757443, 7.461725156754255, 9.066549092531204, 5.160043789073825, 3.7050410639494658, 2.50524855684489, 1.9640630716457963, 6.184578537940979, 25.18962163478136, 57.15117149055004, 75.99784478545189, 71.92390099167824, 48.648052364587784, 21.01962849497795, 5.533446427434683, 3.4335247334092855, 11.164733804762363, 9.954224210232496, 6.9011773355305195, 9.22029359266162, 3.396834139712155, 1.213684561662376, 2.1435941755771637, 2.0637832581996918, 5.502281924709678, 53.8055270165205, 116.10373511910439, 125.5456280708313, 124.13651168346405, 122.14411899447441, 111.80862039327621, 98.14174935221672, 93.47958192229271, 78.19846630096436, 62.01216325163841, 47.97130107879639, 32.063667476177216, 25.718866735696793, 11.352456081658602, 6.876081107184291, 4.6186246164143085, 3.690912709571421, 1.23540312750265, 0.5546238203532994, 0.27087713358923793, 0.18884121294831857, 0.28775238431990147, 0.14298082067398354, 0.13337058713659644, 0.21923085412709042, 13.59003346413374, 45.78041084110737, 66.92389369010925, 53.44749502837658, 38.940511867403984, 27.574504762887955, 42.6198810338974, 52.396319434046745, 81.5308266878128, 91.19232505559921, 76.57285273075104, 82.79735952615738, 51.160960122942924, 5.737703992053866, 0.3449888911563903, 0.027757887182815466, 0.03562734469596762, 0.03887553211825434, 0.05774526762252208, 0.06262720038648695, 0.04964097046467941, 0.005560326244449243, 0.0587037736113416, 0.0351124277949566, 0.0436376451398246, 0.012588169738592114, 0.04453955865756143, 0.021141837314644363, 0.015707919228589162, 0.02509985559299821, 0.037294315989129245, 0.057331676143803634, 0.06898122388520278, 0.06790524334064685, 0.02630763228808064, 0.05076496054243762, 0.06983520579524338, 0.013373586480156519, 0.019098192678939085, 0.055452131491620094, 0.028981913201278076, 0.0491190810862463, 0.049816403043223545, 0.04128804641368333, 0.009463058231631294, 0.06757667229976505, 0.01603606724529527, 0.03642226649390068, 0.01822259942855453, 0.02513694627850782, 0.11565817156224512, 0.06488759667263366, 0.044905674949404784, 0.010441159702168079, 0.09268283058190718, 0.041724792899913155, 0.03331612984766252, 0.037852830355404876, 0.03509480178763624, 0.0647869762906339, 0.005188820568946539, 0.08227541169617325, 0.12263310549315065, 0.06513203785289079, 0.18382281035883352, 0.12824326695408672, 0.0966798524314072, 0.19112828944344074, 0.09664896424510516, 0.2082354316371493, 0.20625420904252678, 0.09329038977739401, 0.12386759393848479, 0.14575131732271984, 0.12137883881223388, 0.1281147715053521, 0.16226285632001236, 0.18787604989483953, 0.12709375441772863, 0.1202487334376201, 0.1310590939829126, 0.14241511118598282, 0.17398202122421935, 0.17848805990070105, 0.1316389488056302, 0.1497041739639826, 0.12481625162763521, 0.16069604898802936, 0.08913770245271735, 0.23938234546221793, 0.15917062381049618, 0.11604693077970296, 0.21554125210968778, 0.09573070492479019, 0.1874632525141351, 0.1568688527913764, 0.1550334770581685, 0.16704299981938675, 0.366612640209496, 3.5651161847636104, 18.941573202610016, 44.00051794946194, 71.27457663416862, 96.89477026462555, 96.04522705078125, 85.36244988441467, 75.22176682949066, 65.33330664038658, 37.28787034749985, 45.87575152516365, 53.087787330150604, 98.09692695736885, 97.82914772629738, 86.72774702310562, 42.067865654826164, 12.848424408584833, 2.52868237439543, 0.7169907703064382, 0.3338408237323165, 0.1675655014696531, 0.6791745463851839, 0.47094052482862025, 0.4775428486755118, 0.3297800588188693, 1.4728564233519137, 2.209894680418074, 6.992671675980091, 8.862559888511896, 10.936319511383772, 10.365156009793282, 12.163781896233559, 10.526541899889708, 14.927647188305855, 14.305336531251669, 28.24910346418619, 63.4834823012352, 84.41907450556755, 75.50270855426788, 54.63145449757576, 31.181119233369827, 28.622518926858902, 26.33054081350565, 25.994448848068714, 23.193032070994377, 24.396693482995033, 44.64188173413277, 32.257354483008385, 17.31761634349823, 18.911750502884388, 15.332491714507341, 10.169956684112549, 57.122053653001785, 121.26872956752777, 132.45507091283798, 131.88434153795242, 131.50360196828842, 120.785973072052, 102.69373789429665, 94.47736278176308, 79.63942497968674, 63.01241397857666, 52.79846705496311, 37.05167502164841, 35.89344397187233, 23.393404819071293, 13.993673454970121, 11.255756970494986, 5.414575980976224, 0.39026506477966905, 0.45936878013890237, 0.1601117115933448, 0.15139665658352897, 0.4065340699162334, 0.28042851481586695, 0.23890824668342248, 0.5415555497165769, 22.53185234963894, 65.04945427179337, 113.63198295235634, 119.10241261124611, 52.96759977936745, 31.535136736929417, 32.43201591074467, 42.70506486296654, 81.98469713330269, 99.74245145916939, 87.79506415128708, 102.66849964857101, 59.12346325814724, 5.649782884865999, 0.3769826400093734, 0.15991576976375654, 0.14152514253510162, 0.12784293765434995, 0.17053752089850605, 0.2516668784664944, 0.21734906447818503, 0.05818800695124082, 0.1622701738961041, 0.22021560987923294, 0.14414562145248055, 0.12905713578220457, 0.08881390342139639, 0.12469332228647545, 0.16401851054979488, 0.111062370124273, 0.16777374810772017, 0.1265872534713708, 0.16640540590742603, 0.2697739755967632, 0.16101845278171822, 0.17216120642842725, 0.2251870048348792, 0.12542466429295018, 0.18885670899180695, 0.20362344395834953, 0.13611653354018927, 0.21689458808396012, 0.15151002706261352, 0.09721810987684876, 0.15202387527097017, 0.16550852044019848, 0.18291477783350274, 0.14143072650767863, 0.11974737557466142, 0.13584769796580076, 0.1794413782772608, 0.22233766241697595, 0.0940925623581279, 0.09349590531201102, 0.1709727756679058, 0.07474584854207933, 0.11371984510333277, 0.17794727173168212, 0.12742675608024, 0.20917689049383625, 0.09486852228292264], [0.06822086390457116, 0.0383892361423932, 0.033757225319277495, 0.05129304314323235, 0.03654027168522589, 0.026473810285096988, 0.06928761955350637, 0.06210681014636066, 0.03536203432304319, 0.058655578541220166, 0.05933336346060969, 0.06323866327875294, 0.028296428499743342, 0.014917261996743036, 0.07273355222423561, 0.013764722425548825, 0.04949420334014576, 0.03140161148621701, 0.018659414563444443, 0.0363346188532887, 0.04203802003758028, 0.030931082437746227, 0.02067203928163508, 0.10571897364570759, 0.046253274122136645, 0.03737286118848715, 0.004163899320701603, 0.06230596176465042, 0.0670255534350872, 0.04032407821796369, 0.054640589296468534, 0.01643874915316701, 0.038026626498322, 0.057852641548379324, 0.02410865985439159, 0.07014089642325416, 0.029699859442189336, 3.7488011782988906, 13.362682163715363, 37.888093739748, 47.373273968696594, 57.547133043408394, 42.466141283512115, 26.32215466350317, 20.66761538386345, 24.010461308062077, 25.35818248987198, 29.461988881230354, 54.80559915304184, 95.532216578722, 54.97896485030651, 32.82228536903858, 5.877320850268006, 0.3545260231476277, 0.1605124564957805, 0.0996235069760587, 0.07329872736590914, 0.11756713865906931, 0.045835281707695685, 0.05408203782280907, 0.1579592310008593, 0.08757109550060704, 0.860810203012079, 3.275857181288302, 2.9324921686202288, 5.637792628258467, 3.660268778912723, 7.046847743913531, 7.276722583919764, 4.979554899036884, 10.417027026414871, 28.355395160615444, 76.8136078119278, 106.49643704295158, 110.45002609491348, 111.5941371023655, 112.3209697008133, 107.70896717905998, 84.02078747749329, 28.31477914005518, 14.925557300448418, 12.88492999970913, 7.9085427056998014, 6.959459558129311, 3.7555866641923785, 3.869080636650324, 7.276106541976333, 10.395782366394997, 10.524602103978395, 52.809437066316605, 123.04600819945335, 109.87242668867111, 108.6007109284401, 107.69031777977943, 111.56522065401077, 108.38294461369514, 114.94913667440414, 111.71024367213249, 108.57947006821632, 110.72216749191284, 94.44430455565453, 86.0712942481041, 59.85084302723408, 43.93250919878483, 38.65939535200596, 15.2594387345016, 9.520423337817192, 2.8921209974214435, 0.6087358854711056, 0.11499099564389326, 0.27063584653660655, 0.4291957273380831, 0.04094894429726992, 0.07672626219573431, 0.02782399398711277, 0.17780624883016571, 0.6424963613972068, 19.49911918491125, 53.577885031700134, 85.57254821062088, 72.37356886267662, 30.775639191269875, 23.58070056885481, 20.565250776708126, 44.33927737176418, 57.67777003347874, 62.210132628679276, 74.17235434055328, 30.09624134749174, 6.191611485555768, 0.3950282873120159, 0.12944232526933774, 0.047090234875213355, 0.06661665975116193, 0.02386112762906123, 0.024856022973835934, 0.0620062120287912, 0.011922564390260959, 0.03937640387448482, 0.06751726337824948, 0.09015891249873675, 0.04144434642512351, 0.07350330779445358, 0.07348385610384867, 0.050064877796103247, 0.03177760576363653, 0.053733465902041644, 0.03826505628239829, 0.0175636947460589, 0.03400569636141881, 0.009214310739480425, 0.038875190730323084, 0.06205327532370575, 0.03762998567253817, 0.02409758701105602, 0.07273322567925788, 0.01946233671333175, 0.04983267834177241, 0.02549270589952357, 0.005954691459919559, 0.09035654642502777, 0.03923634947568644, 0.07708222590736113, 0.10287836630595848, 0.0402914979349589, 0.01421654471414513, 0.019569996366044506, 0.02406358180451207, 0.04914902303426061, 0.03386797972780187, 0.01663768369326135, 0.04772855980263557, 0.06918953731656075, 0.026230818148178514, 0.07650038212887011, 0.08170197645085864, 0.06185768230352551, 0.013918343283876311, 0.04319519524869975, 0.03708315271069296, 0.05810274902614765, 0.02164846442610724, 0.03194527918822132, 0.0017593813186067564, 0.07947650563437492, 0.029789223299303558, 0.010837456356966868, 0.010111476367455907, 0.024739066066103987, 0.039423608177457936, 0.05236061515461188, 0.018253370726597495, 0.020869840191153344, 0.05239734033239074, 0.038361216356861405, 0.04010695920442231, 0.07487844064598903, 0.03370195016032085, 0.039334854736807756, 0.0522699135763105, 0.02078934314340586, 0.05263493148959242, 0.04613882010744419, 0.06123663828475401, 0.02831008030625526, 0.029213526358944364, 0.02302269742358476, 0.06352013762807474, 0.026691354178183246, 0.05176296363060828, 0.012793024761776906, 0.10170842986553907, 0.022881876757310238, 2.9966564755886793, 17.99828141927719, 51.3468461483717, 66.2434034049511, 78.76186966896057, 64.81804668903351, 51.53261438012123, 48.327839747071266, 44.33781825006008, 32.64272600412369, 29.151327051222324, 35.47967277467251, 59.065979942679405, 49.551818668842316, 37.92639188468456, 9.435659386217594, 0.6257971480954438, 0.19130370346829295, 0.12230683511006646, 0.18997085076989606, 0.1761406467994675, 0.28169904195237905, 0.5529111216310412, 0.8548907737713307, 2.005328619852662, 3.679650113917887, 8.335379976779222, 5.3078539576381445, 8.825000803917646, 5.416050776839256, 4.239689949899912, 2.736354055814445, 5.783860115334392, 10.150780063122511, 29.802089631557465, 80.10724827647209, 110.20871624350548, 113.19059863686562, 116.84801638126373, 117.23588436841965, 114.02408391237259, 88.90675529837608, 35.401712357997894, 14.710293151438236, 6.028538485988975, 4.993679216131568, 1.9983552815392613, 0.9089054691139609, 3.2019352354109287, 4.440345782786608, 9.54759567975998, 14.39751673489809, 59.07482586801052, 127.98476278781891, 111.94553464651108, 112.23789855837822, 111.2284143269062, 115.81714689731598, 110.86332231760025, 117.67989814281464, 112.22768470644951, 113.3058388531208, 110.05847990512848, 99.91958275437355, 90.39483144879341, 63.76471281051636, 48.78633454442024, 39.701945409178734, 20.08151963353157, 13.289497140794992, 6.29326980561018, 3.041484570130706, 0.8873415668494999, 1.040301052853465, 1.1803793488070369, 0.25289376731961966, 0.09444252951652743, 0.014073502243263647, 0.2797853696392849, 0.4223541053943336, 19.172346219420433, 51.37255936861038, 52.610715329647064, 41.73779636621475, 25.427870750427246, 23.94422896206379, 28.032439090311527, 56.63005605340004, 79.43292886018753, 76.71621143817902, 94.44115072488785, 49.87449735403061, 12.161185685545206, 0.654802891658619, 0.258810970117338, 0.012981141571799526, 0.07120632362784818, 0.08868876990163699, 0.004404410365168587, 0.038425341626862064, 0.011442647173680598, 0.0399380501039559, 0.07927329817903228, 0.02948025423393119, 0.11874660427565686, 0.0496631718124263, 0.037572810615529306, 0.04936150733556133, 0.06791807507397607, 0.05433867991087027, 0.01229376068295096, 0.013191674024710665, 0.01660829278989695, 0.024435965533484705, 0.049227709241677076, 0.022714353617629968, 0.04919909573800396, 0.033523600941407494, 0.008784288111201022, 0.030131909988995176, 0.034980162236024626, 0.019794906074821483, 0.004485663012019359, 0.033718103004503064, 0.054084475777926855, 0.045475907827494666, 0.04920035367831588, 0.11084157376899384, 0.030874664371367544, 0.00766278654737107, 0.012994144926778972, 0.044969700029469095, 0.04483276636165101, 0.020615539579011966, 0.05553170085477177, 0.058139915781794116, 0.027921354485442862, 0.10803241122630425, 0.058894650283036754, 0.21498225163668394, 0.15353799011791125, 0.08839662346872501, 0.20458057697396725, 0.11849953589262441, 0.10653609308064915, 0.2068556603626348, 0.14049803983652964, 0.13986852049129084, 0.10367641254561022, 0.19139059411827475, 0.11759059794712812, 0.1227863812528085, 0.12667053728364408, 0.0972585346607957, 0.06338871069601737, 0.09798060724278912, 0.14969963202020153, 0.11518117840751074, 0.1270235175616108, 0.1858983450802043, 0.14556794747477397, 0.10623581270920113, 0.14920925052138045, 0.1381998014403507, 0.15177386056166142, 0.1062628639920149, 0.18924275937024504, 0.10443128805491142, 0.13888328976463526, 0.13940527191152796, 0.20382716349558905, 0.13536230369936675, 0.12609241908648983, 0.14077842322876677, 0.21052394789876416, 0.23462457029381767, 5.978957796469331, 37.25958086550236, 82.13094368577003, 94.45469319820404, 102.93227389454842, 85.35330757498741, 54.234334006905556, 38.814457431435585, 43.06066498160362, 39.38789986073971, 43.73464621603489, 77.22335502505302, 134.89922136068344, 81.55542656779289, 52.92427830398083, 11.187421437352896, 1.4817067421972752, 0.7266915310174227, 0.4123200016329065, 0.360517114168033, 0.3508871840313077, 0.25969008856918663, 0.336239593452774, 0.477402345277369, 2.1748854964971542, 5.010815346613526, 9.353973269462585, 10.735746324062347, 13.471077997237444, 10.739671513438225, 15.32688606530428, 16.981292590498924, 16.743820533156395, 18.31874292343855, 37.364170253276825, 87.25918650627136, 115.58225870132446, 116.79434046149254, 118.51855114102364, 122.71724224090576, 116.40243709087372, 90.4081155359745, 41.01380601525307, 29.553624764084816, 28.867127001285553, 25.589141696691513, 19.99635860323906, 16.885395236313343, 14.858433902263641, 16.955453976988792, 20.56601643562317, 15.443704146891832, 63.025306686758995, 130.09936451911926, 117.1830216050148, 117.0454765856266, 115.04973247647285, 118.55088740587234, 113.836639970541, 117.69660204648972, 117.97188967466354, 115.14690846204758, 115.09197860956192, 101.84688493609428, 93.9759112894535, 66.36819630861282, 52.91866220533848, 50.25621347129345, 22.918960377573967, 20.252168476581573, 11.988693941384554, 2.366610858589411, 0.3626905975397676, 1.7191985109820962, 0.7563333841972053, 0.22388297715224326, 0.25255552609451115, 0.14824140089331195, 0.4559073143173009, 2.0319160306826234, 33.08803170919418, 79.38348591327667, 115.25521025061607, 96.15868896245956, 44.09821070730686, 35.87458938360214, 33.02736036479473, 67.37321957945824, 82.19500824809074, 87.79222950339317, 112.67285361886024, 61.64335884153843, 12.163561508059502, 0.6369936629198492, 0.3496047528460622, 0.11121717470814474, 0.19138486473821104, 0.16841717530041933, 0.14229050459107384, 0.1506292016711086, 0.12526959995739162, 0.09671215069829486, 0.15432273707119748, 0.26495046098716557, 0.19965843093814328, 0.13551957963500172, 0.11050130648072809, 0.2744243619963527, 0.31314348278101534, 0.21350981580326334, 0.10063369612907991, 0.17455758643336594, 0.09149931283900514, 0.11063024721806869, 0.24754157639108598, 0.17293004173552617, 0.21308351133484393, 0.1321576358168386, 0.1232956133026164, 0.10343146670493297, 0.11945239413762465, 0.07440092056640424, 0.11833510565338656, 0.16428569855634123, 0.08664335153298452, 0.1309830238460563, 0.18340364535106346, 0.14849217259325087, 0.15945823572110385, 0.0781507181818597, 0.12404447741573676, 0.171342201938387, 0.1400199779891409, 0.13046219944953918, 0.14193641109159216, 0.15650444343918934, 0.25551363767590374, 0.19974984868895262, 0.19653859053505585], [0.032348209715564735, 0.03927599871531129, 0.15446537785464898, 0.046316505104186945, 0.04509024707658682, 0.012743632978526875, 0.042349061550339684, 0.021842033238499425, 0.08072560696746223, 0.11408880382077768, 0.11505978531204164, 0.04923827000311576, 0.026530265458859503, 0.040104268919094466, 0.036559478467097506, 0.026266669447068125, 0.04835683976125438, 0.07415083164232783, 0.08976377823273651, 0.09336087896372192, 0.06488045721198432, 0.049012022573151626, 0.027106359448225703, 0.007618154713782133, 0.04613585893821437, 0.007827816534700105, 0.08100722974631935, 0.11089898631325923, 0.02452860411722213, 0.04596570674038958, 0.05783216198324226, 0.06483855555416085, 0.08700085891177878, 0.060696759246638976, 0.1132267621869687, 0.08358400358702056, 4.409355595707893, 28.585942089557648, 38.72507102787495, 48.49829100072384, 69.09554556012154, 36.910835579037666, 35.68429559469223, 11.647249963134527, 39.233476147055626, 30.520864762365818, 48.17402020096779, 72.71627247333527, 47.54348963499069, 25.228453651070595, 8.292514476925135, 0.8892946026753634, 0.03436662504100241, 0.04866580697125755, 0.10946505310130306, 0.12972656782949343, 0.06162331948871724, 0.051093906367896125, 0.06304753056610934, 0.26298198848962784, 0.08958985592471436, 1.143279920797795, 3.2718156231567264, 4.10361117683351, 4.495433326810598, 9.19661421328783, 6.289466209709644, 8.896543364971876, 14.379936028271914, 34.169210493564606, 56.902630627155304, 98.01719203591347, 109.59317967295647, 101.75751373171806, 99.88776326179504, 101.61364585161209, 96.9343489408493, 105.33790960907936, 113.03927555680275, 94.64225113391876, 68.82918745279312, 29.935861453413963, 8.548259753733873, 4.607251351699233, 15.273886509239674, 53.97648364305496, 83.31766560673714, 119.99267444014549, 67.8573440015316, 77.59654060006142, 116.48795530200005, 95.58678165078163, 103.91659587621689, 106.07839867472649, 118.03472310304642, 117.19704285264015, 113.49348038434982, 109.37755644321442, 111.6696010529995, 109.33834254741669, 109.59982171654701, 104.24911603331566, 110.52642479538918, 88.37055087089539, 73.86511042714119, 59.861319065093994, 39.56184312701225, 26.39024131000042, 6.800136007368565, 3.3848498202860355, 1.0624785628169775, 3.7107519200071692, 0.6605894467793405, 0.029722314975515474, 0.009797109105420532, 0.22330318170133978, 0.10939696105197072, 0.17100262484746054, 3.006822830066085, 43.65305319428444, 66.80030912160873, 88.22010174393654, 69.5632092654705, 100.95374286174774, 118.18594738841057, 21.138045340776443, 57.78481788933277, 59.39935505390167, 60.93971639871597, 53.67949917912483, 24.403548315167427, 2.8167848149314523, 0.5748874798882753, 0.16920129884965718, 0.037668206277885474, 0.02833969014318427, 0.07462540539563634, 0.10986302979290485, 0.11976500900345854, 0.048727883913670667, 0.0517857995146187, 0.04600317406584509, 0.028570197500812355, 0.07223860651720315, 0.008842206243571127, 0.01882135860796552, 0.09854368210653774, 0.012163800420239568, 0.08376390760531649, 0.009473052177781938, 0.1485478039830923, 0.11300333862891421, 0.091542854643194, 0.034960090852109715, 0.04459408424736466, 0.03441409280640073, 0.10690669936593622, 0.21628765971399844, 0.024246764260169584, 0.03249322166084312, 0.014748671092092991, 0.05624664881906938, 0.05713543374440633, 0.04266787706001196, 0.01596915150003042, 0.03198728103598114, 0.0391926035808865, 0.04858145446632989, 0.032961427787085995, 0.05270858593576122, 0.0781397640821524, 0.0160558028073865, 0.098049730877392, 0.037114790466148406, 0.10248488702927716, 0.08168254702468403, 0.038206352401175536, 0.03404853312531486, 0.027326051858835854, 0.04698546588770114, 0.1258479111129418, 0.05937376226938795, 0.04755050744279288, 0.015564386012556497, 0.04438883959664963, 0.05005166385672055, 0.06039565138053149, 0.08521065770764835, 0.003632346019912802, 0.03218292600649875, 0.13203359325416386, 0.018198368306912016, 0.06842977105407044, 0.10805210040416569, 0.0588699404761428, 0.12545111443614587, 0.029934823396615684, 0.11280799051746726, 0.024935733345046174, 0.029259602597448975, 0.14524876460200176, 0.024432698228338268, 0.053369446177384816, 0.030097147791821044, 0.013535680809582118, 0.003767075277210097, 0.019121397781418636, 0.042079739869222976, 0.07449923286912963, 0.062425981886917725, 0.16265018319245428, 0.09047216561157256, 3.4404391748830676, 28.940178081393242, 51.567317917943, 69.33095052838326, 88.90354827046394, 61.449831426143646, 62.60870464146137, 25.234748013317585, 40.37968844175339, 32.136684358119965, 37.55985975265503, 49.070673286914825, 45.7102058082819, 31.274328231811523, 13.020845856517553, 1.1952859489247203, 0.08921029933844693, 0.0573210819857195, 0.056566807616036385, 0.3176427085418254, 0.2304100917535834, 0.5109291931148618, 1.0165813006460667, 2.521706661209464, 3.3271774649620056, 4.583303136751056, 3.999161906540394, 4.646251983940601, 7.379084816202521, 6.114178290590644, 4.173458078876138, 7.205816963687539, 15.925800427794456, 36.44849918782711, 60.16494557261467, 102.24508836865425, 115.5642856657505, 107.81225323677063, 105.85526704788208, 106.171455681324, 102.88388729095459, 109.99867111444473, 118.28623160719872, 103.53953450918198, 73.71406853199005, 28.805351816117764, 5.132077764719725, 5.2044933289289474, 15.453607365489006, 58.60631100833416, 87.89581194519997, 130.33800691366196, 77.09421515464783, 80.81639662384987, 121.51001662015915, 104.37034472823143, 107.86399886012077, 114.20604094862938, 123.4247262775898, 121.95723742246628, 118.0183307826519, 116.10310435295105, 115.88848426938057, 113.78074496984482, 111.14630833268166, 109.257323294878, 114.91852551698685, 96.26645117998123, 79.00841563940048, 61.274429038167, 40.50877891480923, 20.562366731464863, 5.8451892994344234, 4.101880369707942, 1.0060363914817572, 3.8686536345630884, 5.340174548327923, 0.1735387957887724, 0.20845881808781996, 0.1753746613394469, 0.08060775391641073, 0.16140695224748924, 3.834757790900767, 38.64450015127659, 56.83157064020634, 55.147444009780884, 48.488229140639305, 87.33384490013123, 134.6158629655838, 47.33774967491627, 77.06698581576347, 70.79842418432236, 82.44772508740425, 75.0634217262268, 39.97360423207283, 5.109345484524965, 0.5430156213697046, 0.05452851015434135, 0.011188135977135971, 0.020378300941956695, 0.12543438642751426, 0.05633493099594489, 0.07829338865121827, 0.013592898540082388, 0.03481090803688858, 0.024111342718242668, 0.01951923160959268, 0.0965831580106169, 0.03411430225241929, 0.07146073927287944, 0.07019384123850614, 0.014515911316266283, 0.04635968325601425, 0.029690252340515144, 0.06350234092678875, 0.10400762563222088, 0.08740038669202477, 0.035447385016595945, 0.02329404331248952, 0.06400041107553989, 0.057057133453781717, 0.07734922837698832, 0.05283358215820044, 0.042723311780719087, 0.04294729566026945, 0.03389886420336552, 0.08655228259158321, 0.07666588106076233, 0.039365319898934104, 0.04607687675161287, 0.06337574537610635, 0.07252622584928758, 0.02694622253329726, 0.052248988722567447, 0.039557966592838056, 0.03134320446406491, 0.022974904968577903, 0.06260050533455797, 0.031880883034318686, 0.0029617265363413026, 0.2198523879633285, 0.08402417879551649, 0.16655054030707106, 0.10472307083546184, 0.16291723761241883, 0.11438118774094619, 0.17151651758467779, 0.07803010434145108, 0.19359220488695428, 0.18972279533045366, 0.2087823796318844, 0.16946979303611442, 0.16028482496039942, 0.0753740468644537, 0.2957005484495312, 0.11738696004613303, 0.19249964476330206, 0.21603285073069856, 0.14216192008461803, 0.2595619345083833, 0.10963930195430294, 0.18920413800515234, 0.1327038268209435, 0.12546972749987617, 0.2529768878594041, 0.09511901196674444, 0.1452883952879347, 0.19194116379367188, 0.134043937723618, 0.08075044665019959, 0.14127748785540462, 0.17356578027829528, 0.17086344247218221, 0.09223564207786694, 0.26842086226679385, 0.3520740562817082, 8.11714343726635, 50.48237733542919, 72.39664882421494, 88.08498859405518, 113.44031363725662, 71.88336476683617, 62.19924621284008, 23.181057013571262, 54.04358044266701, 44.93884339928627, 74.00232866406441, 100.36136984825134, 72.19000071287155, 42.50223934650421, 15.829642787575722, 2.167158373631537, 0.44868235825560987, 0.24541190941818058, 0.2091024976107292, 0.6966102670412511, 0.2092775999335572, 0.49863697146065533, 0.6729917437769473, 1.6763794398866594, 2.8601848985999823, 6.748122023418546, 10.763444937765598, 13.889154363423586, 20.25808285921812, 24.06061101704836, 18.0859712138772, 19.224922098219395, 22.20399834215641, 41.9601034373045, 63.39069128036499, 104.44321721792221, 118.39947313070297, 111.27165600657463, 109.54723253846169, 110.09951010346413, 108.81975397467613, 117.7029401063919, 123.96737515926361, 110.0927160680294, 80.59642642736435, 45.89411973953247, 16.74584772437811, 12.51514334231615, 20.82581989467144, 62.026442885398865, 86.57769307494164, 131.36805564165115, 93.12573730945587, 92.21522256731987, 127.37422674894333, 109.2334757745266, 114.25878971815109, 119.88039046525955, 128.41844111680984, 129.3401500582695, 124.91943687200546, 120.54884299635887, 119.20461192727089, 118.31689596176147, 113.69023382663727, 109.80276122689247, 115.99135994911194, 91.84242457151413, 75.93694925308228, 67.05505505204201, 49.6374736726284, 39.42961402237415, 17.493526004254818, 11.615735404193401, 4.469467420130968, 7.704120799899101, 3.7883663177490234, 0.14934896724298596, 0.25565007410477847, 0.40074098389595747, 0.20241056685335934, 0.2768477116478607, 6.179404640570283, 66.59442856907845, 93.66461679339409, 114.54604670405388, 96.03663951158524, 114.39537718892097, 126.75548315048218, 31.99644148349762, 81.71732068061829, 81.15815788507462, 98.91481786966324, 89.10431429743767, 43.23535680770874, 6.0279566422104836, 0.722315531456843, 0.24982032598927617, 0.18112332239979878, 0.15494326158659533, 0.24641021678689867, 0.20835390809224918, 0.3234096709638834, 0.2811749966349453, 0.13831177668180317, 0.14604274387238547, 0.06998514189035632, 0.17473173880716786, 0.12180656820419244, 0.21487904858076945, 0.21757820999482647, 0.08908275383873843, 0.1598248418304138, 0.08476217044517398, 0.20775460900040343, 0.23238827154273167, 0.17170727922348306, 0.23453675938071683, 0.1315465514198877, 0.11938827999983914, 0.23757910472340882, 0.23841847374569625, 0.13445250486256555, 0.10139272024389356, 0.1520378128043376, 0.1266301644500345, 0.18057000677799806, 0.1547524257330224, 0.20081873430171981, 0.1618605529074557, 0.1491467171581462, 0.2597214962588623, 0.13936228671809658, 0.10932723627774976, 0.1626342418603599, 0.11477861524326727, 0.19479253969620913, 0.1367030676919967, 0.2631672582356259, 0.17032860632753], [0.06576283369213343, 0.06308548399829306, 0.09857939425273798, 0.0029382459115367965, 0.022716327730449848, 0.06532058789161965, 0.055796625310904346, 0.18325537908822298, 0.14021510345628485, 0.059503051816136576, 0.04698228949564509, 0.09565754400682636, 0.017070886424335185, 0.0378464515961241, 0.2467836654977873, 0.15081890946021304, 0.09108029626077041, 0.0061615924914804054, 0.2727745083393529, 0.19856321392580867, 0.06926137721166015, 0.19219926791265607, 0.0542803767893929, 0.1340691262157634, 0.07459269894752651, 0.19467131729470566, 0.2588324627140537, 0.28949842031579465, 0.04944026033626869, 0.09360005831695162, 0.14849095547106117, 0.03967973076214548, 0.03622957898187451, 0.10660981060937047, 0.12522192439064384, 6.3727339915931225, 38.88940840959549, 82.01030775904655, 75.81497579813004, 34.286046624183655, 40.865727961063385, 18.70413914322853, 15.861769113689661, 40.997284501791, 87.23676770925522, 62.012851014733315, 33.90749953687191, 29.77008394896984, 12.11135420948267, 3.5114302905276418, 0.24086453311610967, 0.08971162751549855, 0.038431460634456016, 0.08228424325352535, 0.33253318921197206, 0.21980543970130384, 0.5087643186561763, 1.1047362140379846, 0.7907348976004869, 3.2032190915197134, 2.861091624945402, 2.9741723695769906, 4.333915868774056, 8.986818920820951, 5.844655428081751, 11.048163659870625, 20.879537612199783, 38.15139681100845, 70.70373326539993, 90.06781339645386, 92.1918386220932, 104.52086985111237, 99.73363593220711, 95.2975183725357, 83.35420444607735, 87.82617688179016, 92.72346809506416, 102.79661357402802, 110.80003291368484, 109.00137662887573, 103.1551243364811, 83.90954464673996, 32.5230248272419, 51.136272847652435, 112.04145669937134, 138.66615682840347, 131.13883674144745, 139.01462852954865, 120.62073513865471, 71.29426717758179, 115.58232709765434, 87.68547803163528, 88.00655320286751, 99.97027203440666, 112.45716959238052, 106.1326065659523, 110.68639621138573, 101.7983691394329, 106.55603304505348, 102.8289270401001, 108.61518815159798, 109.83730897307396, 115.86130052804947, 111.12082690000534, 117.78535008430481, 92.04765155911446, 70.13042762875557, 41.63420632481575, 26.252979375422, 12.434614263474941, 2.3934540431946516, 3.7797764036804438, 5.0657846219837666, 2.1783378487452865, 0.1017471106024459, 0.015390860753541347, 0.10866686585359275, 0.09918615192873403, 0.19368904031580314, 0.6604074127972126, 16.299365982413292, 44.971449449658394, 42.82756268978119, 49.65353921055794, 57.01052583754063, 22.271927297115326, 26.44901655614376, 46.501547545194626, 47.78613701462746, 65.07098391652107, 64.70135495066643, 37.99023985862732, 8.940833788365126, 2.441968652419746, 0.5644424934871495, 0.07356811212957837, 0.2802190213697031, 0.33285507350228727, 0.12729935901006684, 0.0307690604677191, 0.07479154257453047, 0.023691452261118684, 0.04222568320983555, 0.08602506088209338, 0.08756650902796537, 0.13537728023948148, 0.6354699446819723, 0.37416942534036934, 0.32582423358689994, 0.355758789810352, 0.11295873555354774, 0.1302326680161059, 0.12746236432576552, 0.06199070114234928, 0.08506592406774871, 0.09737753061926924, 0.15634427312761545, 0.35120111249852926, 0.33514035400003195, 0.02808576617098879, 0.03537645796313882, 0.08798940703854896, 0.08414468873525038, 0.15976235299604014, 0.11489990443806164, 0.1572978586773388, 0.196292583423201, 0.12056824285537004, 0.06160880679090042, 0.06196435489982832, 0.15009111491963267, 0.023480956915591378, 0.0959172734292224, 0.08955432189395651, 0.1616885676048696, 0.028426851677068044, 0.031166473127086647, 0.023018444917397574, 0.041523474210407585, 0.08395651719183661, 0.02669878122105729, 0.07929594852612354, 0.15112019173102453, 0.1507988863158971, 0.09499730716925114, 0.06510559513117187, 0.11144222356961109, 0.034500129986554384, 0.035358642708160914, 0.041182012064382434, 0.2600190381053835, 0.0877943483646959, 0.11483225025585853, 0.010175741717830533, 0.18131390592316166, 0.14583556592697278, 0.08017811720492318, 0.16963774105533957, 0.06661841864115559, 0.07755962724331766, 0.10812281223479658, 0.11235875368583947, 0.1884603130747564, 0.0868302836897783, 0.08068700786679983, 0.08727802880457602, 0.06970510730752721, 0.0322663953556912, 0.07966561970533803, 0.04644660359190311, 0.14006484823767096, 5.163280740380287, 44.26911413669586, 99.80122670531273, 86.03401064872742, 42.13802509009838, 71.50573343038559, 35.53800344467163, 25.313265100121498, 33.04558798670769, 60.99001809954643, 49.781641736626625, 35.843902230262756, 36.8606972694397, 18.45395676791668, 4.743484016507864, 0.19627168454462662, 0.07417250977596268, 0.07008561384282075, 0.1533748660585843, 0.5231834761798382, 0.4291462409310043, 1.8837768235243857, 3.26509568374604, 4.110683547332883, 4.854389615356922, 3.9015748305246234, 5.018751220777631, 1.6827011131681502, 3.644389668479562, 0.6013964605517685, 6.235197521746159, 19.459918588399887, 42.47663252055645, 71.4544589817524, 92.29718416929245, 93.25266569852829, 107.81966283917427, 103.36648419499397, 102.34898999333382, 88.68684589862823, 95.8176040649414, 96.6075436770916, 107.30085387825966, 115.23802757263184, 114.44669723510742, 107.06426337361336, 92.29378715157509, 38.222031220793724, 57.98393480479717, 123.04957240819931, 152.53313273191452, 143.77410113811493, 147.38138437271118, 121.45833179354668, 73.02358478307724, 118.58833819627762, 92.16823428869247, 90.25699764490128, 104.84482526779175, 115.34113124012947, 108.98509830236435, 112.85107165575027, 108.39913934469223, 113.82736086845398, 110.30681177973747, 114.0120005607605, 116.75475418567657, 121.01898416876793, 117.78446853160858, 118.39662328362465, 100.43423473834991, 75.68637549877167, 45.22895783185959, 26.666815169155598, 9.643388539552689, 2.932527791708708, 3.3213663892820477, 10.082401782274246, 4.566668579354882, 0.13517629180569202, 0.23189015686511993, 0.21078846417367458, 0.11790812583058141, 0.08125108462991193, 0.7652058487292379, 16.963439248502254, 46.5136156976223, 41.88348814845085, 57.59692557156086, 62.602602168917656, 24.70281645655632, 49.01784472167492, 71.97885364294052, 63.44257369637489, 84.77624773979187, 86.24856233596802, 61.81194819509983, 17.07684986293316, 3.359852861613035, 0.5258954025339335, 0.04682912505813874, 0.24856906500644982, 0.26026759820524603, 0.089749462204054, 0.1376638817600906, 0.03119592154689599, 0.031446192297153175, 0.033086902694776654, 0.10250557810650207, 0.059656527955667116, 0.14164042775519192, 0.5169428454246372, 0.20667945966124535, 0.12116418743971735, 0.24389917496591806, 0.061449200511560775, 0.03212709052604623, 0.05936977322562598, 0.043871113666682504, 0.091934500815114, 0.11516954895341769, 0.12206796003738418, 0.11813591321697459, 0.1934611119213514, 0.09421604088856839, 0.04288970500056166, 0.09082141288672574, 0.0518708756135311, 0.091157628048677, 0.08497797214658931, 0.13075226044747978, 0.11297409801045433, 0.12091268843505532, 0.07521583582274616, 0.12206557774334215, 0.010938051691482542, 0.08615629485575482, 0.026769728683575522, 0.043039696756750345, 0.03457801096374169, 0.048553816886851564, 0.2355432600597851, 0.1909085246734321, 0.2310759318061173, 0.12701170257059857, 0.14364314294653013, 0.13455840933602303, 0.2537379157729447, 0.26824874337762594, 0.2838219405384734, 0.13873613672330976, 0.23482334712753072, 0.2652499917894602, 0.0837944692466408, 0.25235113862436265, 0.36683795624412596, 0.21446138271130621, 0.20623900985810906, 0.11333182803355157, 0.3038258187007159, 0.2867889282060787, 0.18856321927160025, 0.3516668250085786, 0.13407579070189968, 0.20699698012322187, 0.2301723521668464, 0.2556771773379296, 0.3414513700408861, 0.3268715227022767, 0.2069350256351754, 0.17853480036137626, 0.17904088570503518, 0.17858097678981721, 0.1437262783292681, 0.19804279028903693, 0.4262971953721717, 10.230992808938026, 59.4015247374773, 119.13407251238823, 106.45694956183434, 59.56585451960564, 69.86245080828667, 35.16909644007683, 25.649476759135723, 58.73243764042854, 108.93302589654922, 87.025977820158, 54.34287518262863, 49.08845633268356, 24.64501015841961, 7.1016142051666975, 0.500799233559519, 0.32139702583663166, 0.22199695726158097, 0.2564392739441246, 0.3863387176534161, 0.3918592573609203, 1.760289624799043, 3.4813914773985744, 3.1552062928676605, 7.89087412878871, 7.107973638921976, 13.213390074670315, 13.498072698712349, 20.393042117357254, 17.604656741023064, 22.40579031407833, 30.099564269185066, 45.026048719882965, 77.81505927443504, 93.85100439190865, 92.35196202993393, 108.60261842608452, 107.59702518582344, 105.3452280163765, 90.96562162041664, 97.02616721391678, 100.88804438710213, 109.67706397175789, 117.44296565651894, 118.82572665810585, 110.26210337877274, 97.85547271370888, 45.38336254656315, 68.37548419833183, 128.78249198198318, 149.4275289773941, 143.93138229846954, 145.09091287851334, 118.06237801909447, 87.00980588793755, 123.68299081921577, 96.29023030400276, 94.00065556168556, 108.86586830019951, 122.49708965420723, 113.27255263924599, 117.71821528673172, 113.10307413339615, 117.59589985013008, 113.72304126620293, 119.27827477455139, 121.96620494127274, 126.69550716876984, 122.23944827914238, 124.82888013124466, 100.36688715219498, 82.82638236880302, 49.86225441098213, 34.886551201343536, 22.501811161637306, 9.871184416115284, 13.260828629136086, 17.040369920432568, 5.653604529798031, 0.12571969768032432, 0.1793013053247705, 0.21047941903816536, 0.3675524960272014, 0.3693325520725921, 0.9796537540387362, 26.782777346670628, 66.90522909164429, 63.73065523803234, 59.24626126885414, 64.70742702484131, 32.36381717026234, 38.310194090008736, 70.33638417720795, 71.1246670782566, 101.73707842826843, 106.48517444729805, 77.68135204911232, 21.01403519511223, 4.541520578786731, 0.9613964462187141, 0.08686192886671051, 0.34986788872629404, 0.5733829387463629, 0.33039336965885013, 0.19307029695482925, 0.16703753761248663, 0.12121521009248681, 0.17856548074632883, 0.16205385269131511, 0.206875356961973, 0.233065792999696, 0.6604013568721712, 0.3871403855737299, 0.36003400571644306, 0.4730524990009144, 0.30232068384066224, 0.24890505010262132, 0.3684259741567075, 0.2147357547073625, 0.2450149494688958, 0.20765217777807266, 0.24112872284604236, 0.35909233905840665, 0.34039538295473903, 0.21888959978241473, 0.10322765068849549, 0.23169881635112688, 0.1451975415693596, 0.25571226608008146, 0.15008163027232513, 0.2951594040496275, 0.3029769501881674, 0.20451252203201875, 0.2638994314474985, 0.24632868444314227, 0.36836559302173555, 0.15896473720204085, 0.17441513860831037, 0.1999637801782228, 0.20458296668948606, 0.09377550944918767], [0.023527522971562576, 0.03330345767608378, 0.08540285911294632, 0.03503843196085654, 0.054543690785067156, 0.09952871245332062, 0.04542195369140245, 0.21356084587750956, 0.09405485383467749, 0.09557492812746204, 0.0494151386374142, 0.022757364786230028, 0.030557615173165686, 0.0572691613342613, 0.13842492451658472, 0.12837124289944768, 0.07643952601938508, 0.058060364972334355, 0.1076449581887573, 0.08029062679270282, 0.03977301501436159, 0.08067911883699708, 0.11421821211115457, 0.3502236446365714, 0.23634451237739995, 0.15378463547676802, 0.20105684496229514, 0.32535611651837826, 0.06734579015756026, 0.04208127240417525, 0.05508889844350051, 0.039749585412209854, 0.0790977654105518, 0.7351381215266883, 16.174204498529434, 53.42558540403843, 94.85313981771469, 87.52394109964371, 66.86172902584076, 49.781607538461685, 26.079505383968353, 29.250990003347397, 59.58408214151859, 64.32546392083168, 37.191260531544685, 35.54540544748306, 26.176468580961227, 9.700290486216545, 1.302653937600553, 0.2094759017927572, 0.06799005597713403, 0.1650455390335992, 0.10868797253351659, 0.3527880914043635, 0.3075701912166551, 0.20392456295667216, 1.6182678518816829, 1.696413983590901, 4.894331647083163, 6.276836637407541, 7.714491868391633, 4.058167515322566, 1.9399761641398072, 5.366070633754134, 20.36426056176424, 53.91195170581341, 77.228302359581, 97.25401818752289, 96.65811896324158, 98.07755559682846, 94.49871003627777, 101.37919083237648, 97.74321913719177, 81.13853573799133, 74.59388852119446, 88.0074043571949, 102.37225994467735, 98.72042790055275, 96.037977039814, 99.34570714831352, 102.10513427853584, 104.43698555231094, 74.57650065422058, 62.38459266722202, 119.60245817899704, 76.75647407770157, 88.97696033120155, 76.48242518305779, 104.85470473766327, 59.27458494901657, 110.93233421444893, 95.8470144867897, 90.9821355342865, 82.89147287607193, 96.604283452034, 102.01020017266273, 103.48213478922844, 95.77015221118927, 95.41812390089035, 89.66814324259758, 100.19071340560913, 97.09175929427147, 101.40813767910004, 98.0495510995388, 104.78219702839851, 99.51717674732208, 99.87746581435204, 80.89680030941963, 49.65003199875355, 27.514296993613243, 8.38407151401043, 1.8336636875756085, 4.743516789749265, 8.853405229747295, 0.4886227275710553, 0.12093936864403076, 0.0847700223675929, 0.07966471428517252, 0.011718833720806288, 0.008128042172756977, 0.1342309737810865, 4.936792943626642, 30.58594387024641, 42.092419937253, 52.61326119303703, 75.11709004640579, 23.9588600769639, 10.56067356839776, 40.155975446105, 43.91830176115036, 50.4024638235569, 62.74640545248985, 49.36891168355942, 26.613397635519505, 9.54918684437871, 1.5994805912487209, 0.41307096602395177, 0.3708786831703037, 0.1444272813387215, 0.0648294271377381, 0.061400704871630296, 0.009291782607760979, 0.09701339586172253, 0.16820517339510843, 0.15454305103048682, 0.15287188289221376, 0.44837858236860484, 0.3654397203354165, 0.5338113871403039, 0.5816376989241689, 0.10989189933752641, 0.03702251924551092, 0.06430903318687342, 0.037416258273879066, 0.06335011901683174, 0.05071732579381205, 0.0680271336750593, 0.12506582104833797, 0.17606396810151637, 0.08699062469531782, 0.03148585637973156, 0.06383441490470432, 0.06868032753118314, 0.16606826306087896, 0.05222361840424128, 0.2420751837780699, 0.10011617428972386, 0.0942624251183588, 0.055869563584565185, 0.035314173219376244, 0.17532149387989193, 0.10247199592413381, 0.12219304160680622, 0.028393054271873552, 0.05873789014003705, 0.061035738908685744, 0.02854725029465044, 0.023768459359416738, 0.0988579222757835, 0.05112734383146744, 0.0255430494871689, 0.06823260468081571, 0.05523654501303099, 0.08709586865734309, 0.07096493267454207, 0.11226083472138271, 0.05711475379939657, 0.09205271751852706, 0.015089200915099354, 0.0640906191256363, 0.1373038362362422, 0.04593751626089215, 0.04457176044525113, 0.07278004777617753, 0.11436599597800523, 0.0562780936161289, 0.058223091982654296, 0.06054356512322556, 0.1008312706835568, 0.1954983369796537, 0.17411537031875923, 0.1273267887881957, 0.24054603301919997, 0.18700101325521246, 0.11734627551049925, 0.06948128298972733, 0.11812320022727363, 0.04358088939625304, 0.2211948885815218, 0.7573612884152681, 16.360054425895214, 59.58256222307682, 108.51503312587738, 98.70936289429665, 89.49073076248169, 74.35791358351707, 30.138282291591167, 22.87501383572817, 33.93893904983997, 50.334200486540794, 39.29929621517658, 39.08503331243992, 32.43961550295353, 13.310785498470068, 1.3060807599686086, 0.10193221707595512, 0.11960908377659507, 0.17696158087346703, 0.24369465390918776, 0.6039900588802993, 1.0729806055314839, 2.436724933795631, 3.4392158780246973, 4.1709269396960735, 4.993477826938033, 4.861468635499477, 4.438031231984496, 2.2893776278942823, 0.7572952075861394, 5.424775583669543, 23.195878118276596, 56.521731466054916, 82.05551773309708, 99.98672515153885, 100.38640290498734, 102.44001030921936, 97.18284800648689, 104.79815617203712, 101.00538209080696, 83.24177607893944, 78.05725827813148, 92.9213310778141, 105.98813071846962, 103.21115612983704, 99.77692320942879, 102.6890717446804, 104.83971834182739, 109.62037101387978, 78.76332119107246, 73.6239905655384, 128.10856014490128, 86.9816417992115, 98.19221824407578, 89.53238412737846, 113.75949651002884, 69.31884437799454, 111.30289793014526, 101.76498413085938, 94.1554744541645, 89.09058183431625, 101.61649569869041, 105.86627125740051, 106.9366206228733, 100.28836816549301, 98.69547843933105, 93.91130715608597, 103.47276449203491, 101.69618502259254, 108.10860693454742, 103.67294535040855, 109.73894745111465, 104.78976622223854, 107.05539464950562, 89.00465324521065, 53.437972739338875, 33.60440120100975, 11.188068352639675, 1.1900919838808477, 0.5370128934737295, 7.274824110791087, 1.1192672280594707, 0.5176101252436638, 0.16760257916757837, 0.14448138390434906, 0.0030843017339066137, 0.02287804541992955, 0.046917833969928324, 5.330796176567674, 31.376196965575218, 36.67054787278175, 44.15500245988369, 50.349053889513016, 24.989454075694084, 20.227439403533936, 60.004054605960846, 65.57884186506271, 66.24034836888313, 84.65413749217987, 76.24812975525856, 41.156100779771805, 13.034669514745474, 1.625231453217566, 0.3373359830584377, 0.465498830890283, 0.20231304864864796, 0.21367003064369783, 0.015613156247127336, 0.08105319095193408, 0.015592804702464491, 0.12882831681054085, 0.15304967178963125, 0.06813697153120302, 0.27912468009162694, 0.3242100327042863, 0.29405799752566963, 0.4770028917118907, 0.07530942806624807, 0.08033187536057085, 0.01604812714504078, 0.03300709584436845, 0.025690606998978183, 0.04587738374539185, 0.09453108999878168, 0.06128087028628215, 0.2941930090310052, 0.15549972391454503, 0.054204740808927454, 0.013882535586162703, 0.027610227625700645, 0.1179096101259347, 0.12169161695055664, 0.20400573906954378, 0.030877519784553442, 0.12266164107131772, 0.02134208731149556, 0.06353078744723462, 0.06688972556730732, 0.05882370467588771, 0.06053144585166592, 0.04028685580124147, 0.014789979031775147, 0.15862897475017235, 0.13700892159249634, 0.08095491575659253, 0.21910004317760468, 0.1506842690287158, 0.10849108075490221, 0.16063985356595367, 0.2525533293373883, 0.42989067442249507, 0.2393068393575959, 0.24997169442940503, 0.18315740075195208, 0.19707982399268076, 0.14662917412351817, 0.0751413093530573, 0.3154484153492376, 0.28370022831950337, 0.22812564246123657, 0.11997240959317423, 0.27342077053617686, 0.1887817817623727, 0.15446533332578838, 0.29569814389105886, 0.32156985718756914, 0.40157316892873496, 0.35417418577708304, 0.29408658505417407, 0.38607712544035167, 0.3900187014369294, 0.3502299083629623, 0.17193632083944976, 0.28666460362728685, 0.13603022176539525, 0.4578586877323687, 2.118809767998755, 28.261289410293102, 78.75271216034889, 124.42366987466812, 113.92300933599472, 97.55023509263992, 79.65304344892502, 46.30965404212475, 47.0825781673193, 88.55286508798599, 88.68111580610275, 58.16612742841244, 55.999012514948845, 44.89568151533604, 18.55098456144333, 2.9930523689836264, 0.4576498473761603, 0.19220146466977894, 0.32873084011953324, 0.31504691345617175, 0.5683784291613847, 0.9519737237133086, 2.2652674466371536, 4.507886683568358, 5.6695351749658585, 12.375178802758455, 19.144744500517845, 24.688673615455627, 14.783793557435274, 10.253924578428268, 14.83151139691472, 27.612605318427086, 71.23676106333733, 84.62208241224289, 98.74815121293068, 103.33270400762558, 103.64507764577866, 97.89860039949417, 106.052256077528, 102.27562353014946, 86.61285638809204, 80.10221734642982, 93.94266307353973, 111.06424033641815, 108.55909556150436, 107.572812885046, 109.67881187796593, 110.99510684609413, 116.8438670039177, 83.93634080886841, 86.28397643566132, 131.38399958610535, 95.28513863682747, 104.68660935759544, 100.35366386175156, 119.26444351673126, 80.93182682991028, 114.80465322732925, 105.94671294093132, 100.47968789935112, 95.8128847181797, 107.01371848583221, 113.12024161219597, 114.3538910150528, 105.4198408126831, 103.91021981835365, 96.82634353637695, 107.41527333855629, 105.5585789680481, 111.62486225366592, 109.0174725651741, 114.2552787065506, 109.85890701413155, 108.32317382097244, 89.08849954605103, 56.305789053440094, 35.19545942544937, 14.314168207347393, 5.306785739958286, 13.95844079554081, 20.386303178966045, 0.9004746715072542, 0.8272491570096463, 0.16670670302119106, 0.1724106867914088, 0.26322229590732604, 0.21852275618584827, 0.3126393270213157, 9.579798001796007, 48.39647926390171, 63.40594366192818, 76.87641844153404, 98.49139899015427, 34.899242520332336, 16.87684379518032, 60.569768249988556, 66.55583024024963, 81.30712509155273, 103.21259245276451, 97.62299358844757, 53.78578707575798, 17.29222420603037, 2.354068919084966, 0.5524394125677645, 0.8343433763366193, 0.3081302158534527, 0.3222098556580022, 0.281574628315866, 0.15179943497059867, 0.12469072476960719, 0.2963547070976347, 0.2744811511365697, 0.26739073160570115, 0.6266248505562544, 0.6245769385714084, 0.6466646783519536, 0.6940093659795821, 0.18109320604708046, 0.2415233079227619, 0.20940530870575458, 0.16981835011392832, 0.19018696417333558, 0.09990560472942889, 0.24987678858451545, 0.17610083799809217, 0.44396574259735644, 0.3040621482068673, 0.15443833399331197, 0.13622776663396508, 0.1842658725217916, 0.38704883423633873, 0.28883793856948614, 0.42464740108698606, 0.31102999462746084, 0.143509007175453, 0.15603614825522527, 0.13700433511985466, 0.2879506564931944, 0.22977307671681046, 0.27627147850580513, 0.1777742474223487, 0.08801052856142633, 0.37826507119461894], [0.012701684008789016, 0.044529547085403465, 0.028084886725991964, 0.0645455408084672, 0.04310301308578346, 0.018657627842912916, 0.0498508943564957, 0.031777520416653715, 0.053385372666525654, 0.15549972391454503, 0.03280085300502833, 0.033020435948856175, 0.0289930843791808, 0.10629787109792233, 0.11320964084006846, 0.12604049843503162, 0.021700696779589634, 0.005208720331211225, 0.09309710483648814, 0.04481937059608754, 0.023279988890863024, 0.06757866867701523, 0.029901821944804396, 0.18077136628562585, 0.24175153317628428, 0.07988246783497743, 0.26423039962537587, 0.2874695073114708, 0.09642793040256947, 0.07799215833074413, 0.04665814536565449, 0.1196352593251504, 4.131745817139745, 26.47114846855402, 72.40019023418427, 97.00418919324875, 89.52740639448166, 84.99564796686172, 48.449494019150734, 13.791453056037426, 44.09710496664047, 50.83102002739906, 41.368292793631554, 46.69322445988655, 31.608427204191685, 16.518469825387, 2.6527746906504035, 0.3009679267415777, 0.21072036470286548, 0.19927640300011262, 0.15760877402499318, 0.09815323821385391, 0.384785165078938, 0.6360657408367842, 1.7086520581506193, 1.6561460006050766, 2.917197276838124, 5.046185748651624, 6.068032141774893, 3.0408602161332965, 2.3082191543653607, 3.4827795904129744, 29.961861558258533, 78.23547631502151, 96.18072018027306, 88.87394785881042, 90.60138076543808, 101.05107843875885, 97.32524916529655, 102.38873586058617, 99.5076696574688, 102.84707486629486, 96.43641605973244, 81.13015338778496, 76.85482800006866, 93.4770892560482, 104.33347150683403, 100.54112300276756, 84.95039999485016, 84.2661327123642, 93.31916213035583, 107.00089797377586, 84.50673580169678, 34.37102906405926, 81.65351450443268, 82.1492587029934, 83.99045750498772, 65.47861084342003, 93.70011448860168, 45.27935452759266, 113.5861574113369, 95.37413746118546, 95.49354985356331, 84.04947593808174, 81.21912181377411, 85.30065760016441, 90.08713155984879, 88.74680668115616, 86.01065710186958, 85.27627050876617, 90.15583947300911, 87.61632934212685, 89.604701846838, 96.97282567620277, 99.00464504957199, 99.85902160406113, 101.4857067167759, 95.97671672701836, 84.7834749519825, 59.990626126527786, 25.98441358655691, 9.313771426677704, 1.336869082879275, 4.509348180145025, 1.0993298166431487, 0.6955532706342638, 0.5064529145602137, 0.03673047300253529, 0.11244697278016247, 0.09266803957871161, 0.09550487680826336, 0.062462703353958204, 1.8658845336176455, 22.624907456338406, 47.253341004252434, 65.4467761516571, 72.71643206477165, 53.79888877272606, 20.442857444286346, 19.179660826921463, 58.96944612264633, 50.308304876089096, 47.45848819613457, 47.811740040779114, 36.64861164987087, 17.00940728187561, 3.59770679846406, 0.7848538225516677, 0.0632460179622285, 0.10551138751907274, 0.025091439638345037, 0.03836765077721793, 0.021674946110579185, 0.05110859347041696, 0.12429940514266491, 0.15847396978642792, 0.010083395354740787, 0.2173144358675927, 0.23657940211705863, 0.15523602400207892, 0.014325917800306343, 0.06692307026241906, 0.031953717407304794, 0.056431773846270517, 0.047841748455539346, 0.022052157510188408, 0.09189899647026323, 0.08169530454324558, 0.12750775407766923, 0.08333571066032164, 0.0685699404857587, 0.05609125422779471, 0.012316125303186709, 0.08210479194531217, 0.08260039074230008, 0.05767116788774729, 0.08890266428352334, 0.04981327489076648, 0.06020348708261736, 0.11577411729376763, 0.0965992255078163, 0.09265865141060203, 0.02076656477584038, 0.014097264884185279, 0.01094511229894124, 0.008935618516261457, 0.07673154628719203, 0.02924272615928203, 0.01762563068041345, 0.032897966739255935, 0.022070950544730294, 0.05277886361000128, 0.06697004078887403, 0.057337127218488604, 0.06291996280197054, 0.04482474003452808, 0.06062962085707113, 0.04030576572404243, 0.05566233739955351, 0.05806875866255723, 0.07833665586076677, 0.1282553788041696, 0.03998588894319255, 0.06711829963023774, 0.021180510630074423, 0.08807761128991842, 0.04443320518475957, 0.021472573571372777, 0.02921725194028113, 0.1989325214526616, 0.42053462646435946, 0.024462992696498986, 0.1831345574464649, 0.13761619135038927, 0.10690149691072293, 0.11893888731719926, 0.06921488165971823, 0.11734295068890788, 4.193229367956519, 30.13518165796995, 84.37313497066498, 110.37283703684807, 102.22333833575249, 110.94717621803284, 69.131620824337, 39.335656464099884, 60.623303577303886, 47.70440720021725, 46.203138157725334, 46.16928577423096, 37.97963462769985, 22.41517011076212, 4.027489861473441, 0.08739626035094261, 0.12429513779352419, 0.27037232473958284, 0.21466290549142286, 0.31545298697892576, 0.8228296972811222, 2.0464115403592587, 3.518398404121399, 3.6215623933821917, 4.220483405515552, 4.563164692372084, 4.632203187793493, 0.19585896137868986, 1.916307471692562, 5.415088953450322, 34.888496696949005, 84.01847720146179, 102.68828898668289, 102.1829617023468, 98.06080609560013, 106.02862894535065, 102.49465137720108, 105.3690755367279, 104.39564377069473, 105.43864980340004, 101.23695686459541, 83.29840824007988, 76.841049939394, 96.33208885788918, 108.4997883439064, 103.8480931520462, 89.03684511780739, 85.86931988596916, 99.78176414966583, 111.21475026011467, 89.04237002134323, 39.797130301594734, 90.5472032725811, 92.11679264903069, 92.04016596078873, 75.30121296644211, 99.74754318594933, 53.735815957188606, 110.48484742641449, 100.52742093801498, 101.26730963587761, 87.37270921468735, 82.80498951673508, 87.12372377514839, 95.22536784410477, 92.85995677113533, 91.122165620327, 90.42289674282074, 94.86563354730606, 93.27013716101646, 94.92114096879959, 101.25154808163643, 102.85356491804123, 105.70143610239029, 102.6478211581707, 103.40461894869804, 92.493686825037, 64.39515978097916, 31.71663209795952, 11.093309037387371, 3.927023489959538, 2.5779844913631678, 1.786030987277627, 1.3647356000728905, 0.6028074910864234, 0.4434226982994005, 0.13389427622314543, 0.16416815720731393, 0.04643931199098006, 0.057438964722678065, 2.4111261824145913, 24.229530952870846, 40.95774382352829, 47.96337090432644, 46.70450985431671, 44.746908098459244, 34.959628880023956, 37.126508206129074, 84.57667484879494, 70.00485956668854, 70.87247461080551, 68.15367490053177, 52.06140540540218, 26.471566446125507, 4.943389389663935, 0.6603239360265434, 0.02834089613315882, 0.07808084497810341, 0.0542923513421556, 0.034203912873636, 0.07565224834252149, 0.05223821644904092, 0.19851651799399406, 0.16001600422896445, 0.07402555711450987, 0.1715561334276572, 0.18991428427398205, 0.19199538510292768, 0.034853800461860374, 0.07870365530834533, 0.03241746322601102, 0.008974544161901576, 0.07513508273405023, 0.09322067242464982, 0.058113658596994355, 0.07115960543160327, 0.0949034106452018, 0.07630947206052952, 0.035167009045835584, 0.08684357555466704, 0.009467448962823255, 0.031490980909438804, 0.10131785980775021, 0.13050252775428817, 0.019790751903201453, 0.07009652341366746, 0.05411795405962039, 0.08386825356865302, 0.09003616127301939, 0.0625334597134497, 0.050313797837588936, 0.045106433317414485, 0.04941248545947019, 0.02913696640462149, 0.19397316413233057, 0.1265245271497406, 0.16744303226005286, 0.10008950150222518, 0.13048737309873104, 0.2873636473668739, 0.2165855874773115, 0.17074533709092066, 0.140936040552333, 0.28022543352562934, 0.2852478140266612, 0.1303361085592769, 0.11591651316848584, 0.16423342167399824, 0.2675876975990832, 0.24926024198066443, 0.1240828241861891, 0.20277499104849994, 0.12466059357393533, 0.16428440721938387, 0.15690214553615078, 0.2996255300240591, 0.18546561361290514, 0.41264731844421476, 0.5847867205739021, 0.30028458684682846, 0.45034073176793754, 0.42542261886410415, 0.20294282032409683, 0.16683418914908543, 0.21167378698009998, 0.2119118976406753, 9.185325969010592, 47.993792071938515, 109.3962362408638, 122.11311265826225, 114.83054503798485, 115.68288490176201, 73.84611904621124, 31.582305505871773, 70.54582893848419, 82.2892963886261, 61.991997733712196, 68.45461115241051, 52.17510290443897, 30.510607212781906, 5.355281587690115, 0.8963327156379819, 0.30269665585365146, 0.5634632147848606, 0.564003320178017, 0.38496880210004747, 0.8873247052542865, 1.6464977245777845, 5.9267286490648985, 6.154782436788082, 9.525438118726015, 11.752108186483383, 19.785583913326263, 13.154407739639282, 12.323325835168362, 10.464912056922913, 36.008228212594986, 87.90448307991028, 102.04741537570953, 101.76050797104836, 101.06144428253174, 107.26180717349052, 105.65767765045166, 108.92667263746262, 106.0271318256855, 108.41893628239632, 103.63598093390465, 87.18396574258804, 77.17571318149567, 98.8961760699749, 110.13479501008987, 107.95065701007843, 92.61986285448074, 91.85880929231644, 104.84876945614815, 116.79881662130356, 93.36095988750458, 48.30465719103813, 103.3046007156372, 101.73828676342964, 100.23653894662857, 80.86921378970146, 105.86704641580582, 64.38518911600113, 117.40852430462837, 106.14854291081429, 104.70059260725975, 92.56427943706512, 86.81692063808441, 93.41956034302711, 101.04376003146172, 99.00152921676636, 94.27335172891617, 93.5677295923233, 99.15453180670738, 99.01962384581566, 98.52491319179535, 105.40324330329895, 108.01545113325119, 109.07418072223663, 108.32601606845856, 110.35722747445107, 92.04360857605934, 67.4718014895916, 32.14042715728283, 14.872713536024094, 7.339431568980217, 12.417281493544579, 6.708578495308757, 2.7396330423653126, 0.7655289501417428, 0.28898535878397524, 0.3100451943464577, 0.34944041166454554, 0.172318838594947, 0.21103165112435818, 4.140774132683873, 36.96673057973385, 68.47929462790489, 87.60373681783676, 94.34906646609306, 75.30903294682503, 30.643788166344166, 30.84452949464321, 83.47145855426788, 79.60493803024292, 83.7974202632904, 91.80800601840019, 68.05563256144524, 33.54198195040226, 6.3084338419139385, 1.1631865776143968, 0.22597289469558746, 0.2374875682289712, 0.16750973649322987, 0.16052194114308804, 0.19048561924137175, 0.2796018513618037, 0.34197387169115245, 0.28708157187793404, 0.20320678740972653, 0.3370177501346916, 0.35418445710092783, 0.33838665636722, 0.08166419371264055, 0.2155920150107704, 0.2631406002910808, 0.195779032073915, 0.21992499969201162, 0.26673556363675743, 0.28537006059195846, 0.14684625231893733, 0.27756337949540466, 0.11997206820524298, 0.227536792808678, 0.1839672026108019, 0.15532138582784683, 0.17449539445806295, 0.2730235434137285, 0.21298937732353806, 0.18027659127255902, 0.27212477289140224, 0.13067432009847835, 0.17611406306969002, 0.20515587500995025, 0.2513126068515703, 0.1758453165530227, 0.20062297058757395, 0.10837219611858018, 0.16133809578604996], [0.013995091558172135, 0.07562369792140089, 0.05691520142136142, 0.11080210635554977, 0.01963727019756334, 0.08796266745775938, 0.04178322218649555, 0.031628393262508325, 0.024550057751184795, 0.03231028968002647, 0.06143886239442509, 0.02816109416016843, 0.04815272688574623, 0.05630850682791788, 0.07536111123044975, 0.05511059884156566, 0.02962217513413634, 0.0432050324161537, 0.031189264482236467, 0.052561002448783256, 0.009117293484450784, 0.050835449728765525, 0.04407051019370556, 0.10690640992834233, 0.2199269738048315, 0.19649722322355956, 0.033889001060742885, 0.16175329772522673, 0.09192919445922598, 0.061097478173905984, 0.36442520446144044, 8.33792869001627, 54.44467172026634, 95.53576558828354, 96.16281554102898, 85.43060302734375, 85.75231656432152, 37.19376839697361, 12.591391000896692, 30.16698595136404, 30.621105283498764, 29.332736916840076, 31.493038795888424, 25.355891212821007, 8.222883213311434, 0.6490466161631048, 0.039953765081008896, 0.014739353428012691, 0.34341191640123725, 0.06891941782669164, 0.04614014113030862, 0.5996134656015784, 0.8660565933678299, 1.446849787607789, 0.9311985166277736, 4.701471095904708, 2.822761656716466, 5.530083132907748, 3.1709505105391145, 2.0568229816854, 13.133144080638885, 79.891077876091, 106.00915119051933, 97.65375673770905, 90.77500864863396, 96.39863848686218, 101.54566749930382, 99.16470766067505, 93.9055010676384, 89.56953853368759, 93.18186789751053, 91.22716158628464, 82.25125283002853, 72.33104914426804, 80.89296251535416, 93.8640832901001, 102.71978929638863, 95.79688757658005, 91.38666182756424, 81.29818797111511, 91.3940942287445, 90.95616772770882, 96.65067136287689, 39.50323887169361, 64.30023327469826, 74.40156564116478, 72.07943424582481, 77.81213343143463, 82.89778053760529, 37.30972297489643, 84.86628770828247, 106.05818375945091, 95.35614162683487, 96.0282039642334, 88.42953130602837, 84.71285194158554, 82.31641933321953, 80.68606361746788, 81.01248890161514, 80.3703385591507, 80.78408315777779, 80.07339209318161, 84.9663895368576, 89.56067740917206, 94.22314122319221, 93.21842193603516, 88.68838101625443, 96.4084267616272, 95.57508587837219, 93.08036774396896, 57.224819138646126, 26.22971512377262, 5.022152988240123, 3.225099742412567, 1.355526081752032, 0.4825695336330682, 1.108717331662774, 0.9956875280477107, 0.27545161312446, 0.04571526158542838, 0.03303451449028216, 0.06794994289521128, 0.04021439250209369, 0.2499696461018175, 11.60219008103013, 47.47118331491947, 60.74652336537838, 50.56162588298321, 42.6264850795269, 39.82589855790138, 15.454259980469942, 26.05902448296547, 40.47838814556599, 49.485584422945976, 50.31492032110691, 51.2154757976532, 34.15954381227493, 10.393551886081696, 2.9281015042215586, 0.08787807004409842, 0.1897163238027133, 0.013379939264268614, 0.03983190443250351, 0.04225612981826998, 0.08364478548173793, 0.058468316128710285, 0.16780917823780328, 0.1322560297558084, 0.05834267794853076, 0.12972953642020002, 0.09516540361801162, 0.03007944756973302, 0.048881267284741625, 0.05152065241418313, 0.0939735812426079, 0.05318196112057194, 0.02768472069874406, 0.13834760757163167, 0.18730553128989413, 0.08678743208292872, 0.0686196050082799, 0.033231888664886355, 0.0094540272220911, 0.03279139804362785, 0.0425636498403037, 0.05802945452160202, 0.1046600921836216, 0.023753740715619642, 0.007552172683062963, 0.0289329518636805, 0.08790400810539722, 0.04774060857016593, 0.05305296843289398, 0.002241434644929541, 0.03140313288895413, 0.06841567024821416, 0.04949272646626923, 0.03845753970381338, 0.040518851164961234, 0.10846120931091718, 0.03134724545816425, 0.034728084356174804, 0.023737641677143984, 0.03217824676539749, 0.023999167096917517, 0.028161175796412863, 0.07392996849375777, 0.004315915748520638, 0.036171001265756786, 0.022008702908351552, 0.023992508176888805, 0.014687105303892167, 0.06442604761105031, 0.03303917888842989, 0.058495044577284716, 0.015454818112630164, 0.07548522800789215, 0.03542917642334942, 0.0027708088146027876, 0.05836869022459723, 0.177721198706422, 0.26146800722926855, 0.04928496964566875, 0.17812440753914416, 0.10060664484626614, 0.14867662597680464, 0.09709981153719127, 10.00041263177991, 63.40070754289627, 108.31431269645691, 112.59321749210358, 99.24337863922119, 105.00078409910202, 62.029376327991486, 38.47097486257553, 33.81288841366768, 32.323615327477455, 39.228844195604324, 38.67450334131718, 33.8932579010725, 12.916550002992153, 1.1099899071268737, 0.1269717898685485, 0.02292722012498416, 0.38053242140449584, 0.42107963003218174, 0.37530957197304815, 1.834873566403985, 2.272096867673099, 3.007523654960096, 2.700076214969158, 4.882686221972108, 2.1362078469246626, 2.5855638971552253, 1.0691221500746906, 2.915212595835328, 16.29255674779415, 84.87920701503754, 109.54739212989807, 103.07962998747826, 93.50635528564453, 99.96626704931259, 105.9270603954792, 102.95811250805855, 99.09128800034523, 96.45205602049828, 98.29131692647934, 94.04205054044724, 88.52790802717209, 75.09093225002289, 81.86213091015816, 96.82608515024185, 104.27063807845116, 100.29810324311256, 94.35385420918465, 83.47392842173576, 94.78800371289253, 95.86581587791443, 101.3711504638195, 48.204441368579865, 72.59837999939919, 85.95341697335243, 77.72565767168999, 86.5148976445198, 93.00034403800964, 43.73512879014015, 91.29491955041885, 112.14529752731323, 99.25961896777153, 101.8547049164772, 94.124855697155, 91.70074537396431, 85.68054601550102, 85.59029325842857, 84.56837609410286, 84.62000772356987, 85.93836978077888, 85.99882453680038, 88.23551371693611, 93.50837677717209, 97.81257301568985, 95.67801475524902, 93.13665792346, 98.71178716421127, 98.99382323026657, 97.88791537284851, 62.15872138738632, 30.409829020500183, 9.200517553836107, 1.6366078052669764, 2.0900918589904904, 2.464103177189827, 1.7770832986570895, 1.1527405818924308, 0.7576984609477222, 0.23131076217396185, 0.05316155205946416, 0.04905729729216546, 0.1314917512354441, 0.03763272048672661, 12.135422118008137, 38.08704726397991, 50.211797654628754, 42.564996778964996, 33.076370134949684, 34.060809910297394, 30.27489636093378, 54.30502541363239, 63.69089797139168, 68.83985728025436, 72.3571765422821, 70.34030556678772, 44.998135417699814, 12.535038124769926, 3.59248801600188, 0.0919084514316637, 0.10877267384785227, 0.061799831892130896, 0.017898139885801356, 0.02579084331955528, 0.08932366981753148, 0.11188377175130881, 0.10750469227787107, 0.08004260846064426, 0.11143322131829336, 0.06442932790378109, 0.0630307877145242, 0.07293091897736304, 0.06449560169130564, 0.019316554789838847, 0.1703747975989245, 0.044388108581188135, 0.06687431858154014, 0.04591091397742275, 0.15073203365318477, 0.07252590672578663, 0.06554508756380528, 0.03196601850504521, 0.01491237680966151, 0.023063485859893262, 0.06467158716986887, 0.0642005015106406, 0.0693052084534429, 0.011689560633385554, 0.0530038753640838, 0.040046270078164525, 0.04995784525817726, 0.03422641850193031, 0.0759789120638743, 0.009080106319743209, 0.027087588678114116, 0.09202415225445293, 0.24445667630061507, 0.1827716620755382, 0.15987459541065618, 0.26396949018817395, 0.07222352607641369, 0.17348737979773432, 0.1320275224861689, 0.19274666119599715, 0.19247380318120122, 0.17400576994987205, 0.22347739344695583, 0.13144815748091787, 0.18905699980678037, 0.2354813352576457, 0.1555482455296442, 0.1636196210165508, 0.16728091752156615, 0.11645186139503494, 0.18148305622162297, 0.13252890261355788, 0.19246002892032266, 0.12057377927703783, 0.1311756853829138, 0.20087463286472484, 0.3473936574300751, 0.4069943795911968, 0.2636278053978458, 0.3551728493766859, 0.3221422905335203, 0.26713492814451456, 0.45530317642260343, 18.361201845109463, 85.90578272938728, 129.16379392147064, 124.22541171312332, 108.33179175853729, 114.37187924981117, 57.39744387567043, 24.50752403587103, 46.03067301213741, 44.90725949406624, 47.34351396560669, 54.49669472873211, 44.727392345666885, 18.282842449843884, 1.826443956233561, 0.2750342292711139, 0.3282892028801143, 0.7242864381987602, 0.41931741521693766, 0.271471623564139, 1.6980592953041196, 2.777098319493234, 7.3286838456988335, 4.044631691649556, 11.6463684104383, 7.377289412543178, 14.775554649531841, 12.004791777580976, 6.501064030453563, 14.535532929003239, 86.51790708303452, 113.53906273841858, 107.32287749648094, 99.20024335384369, 102.7986578643322, 107.81429752707481, 106.71728119254112, 100.59384137392044, 98.14373284578323, 101.85730397701263, 98.4975166618824, 89.4781382381916, 78.28570201992989, 84.9090126156807, 100.04258215427399, 110.36887764930725, 107.05766692757607, 101.04626029729843, 91.50972202420235, 100.48459723591805, 103.11455011367798, 106.35120883584023, 55.18348507583141, 81.13371759653091, 97.79068619012833, 85.25456607341766, 93.4591618180275, 103.7101985514164, 51.949174627661705, 98.86501014232635, 114.83746826648712, 103.97957369685173, 109.20218825340271, 99.30432736873627, 96.99286580085754, 92.08501115441322, 90.69458976387978, 88.93485099077225, 87.89597153663635, 89.23590883612633, 88.6712971329689, 94.2975564301014, 97.80123442411423, 103.12455117702484, 102.87176594138145, 99.28174138069153, 106.77855670452118, 106.2319028377533, 102.04459592700005, 62.48475909233093, 30.247152149677277, 10.562344528734684, 8.34159929305315, 5.781605411320925, 4.239017860963941, 7.017742255702615, 2.2453408408910036, 1.0842538881115615, 0.23466892103897408, 0.17456251429393888, 0.201545994495973, 0.1441145403077826, 0.5021674570161849, 22.428697384893894, 67.83313170075417, 83.15789937973022, 67.95768901705742, 62.83513829112053, 53.95825982093811, 26.627435982227325, 45.64535468816757, 69.13632497191429, 84.20120179653168, 93.9641547203064, 89.22827124595642, 52.82411947846413, 16.83396689593792, 4.452411560341716, 0.2690985321532935, 0.39102264912799, 0.14504887454677373, 0.1315573719330132, 0.15656906965887174, 0.22964115254580975, 0.2369114093016833, 0.2702909259824082, 0.22448284027632326, 0.27331589022651315, 0.2956007147440687, 0.2574094687588513, 0.21844107541255653, 0.13371262815780938, 0.20773523894604295, 0.33078650012612343, 0.09264826134312898, 0.14996753248851746, 0.2538370370166376, 0.23689782799920067, 0.14718378108227625, 0.16565843427088112, 0.09459907814743929, 0.13010320777539164, 0.2084201225079596, 0.13625592371681705, 0.17535251565277576, 0.22474144905572757, 0.15402124699903652, 0.16210574365686625, 0.09834356198552996, 0.16601684706984088, 0.13471638289047405, 0.2606482309056446, 0.12544505851110443, 0.16288410814013332, 0.17558897874550894], [0.05927387290284969, 0.028896258227177896, 0.054303502110997215, 0.0812200851214584, 0.13114870089339092, 0.09448126962524839, 0.04531278376816772, 0.05050526080594864, 0.08860637666657567, 0.04050837203976698, 0.06207034100953024, 0.0516047822748078, 0.08137751690810546, 0.04605987043760251, 0.004227486533636693, 0.04321900705690496, 0.03169763564073946, 0.029312950027815532, 0.12191630215966143, 0.09808924281969666, 0.03607902690418996, 0.008279865178337786, 0.04539496178040281, 0.06541575348819606, 0.07519015751313418, 0.059666305751306936, 0.33746143570169806, 0.1255086754099466, 0.1091052450647112, 1.0574051225557923, 24.735498502850533, 79.54705953598022, 108.73852953314781, 93.07659074664116, 81.32341101765633, 64.0705431997776, 39.44593794643879, 27.024191692471504, 30.684159100055695, 67.32214272022247, 69.22058925032616, 34.57375958561897, 27.92991679161787, 8.17274110391736, 0.8017994882538915, 0.10060059634270146, 0.0855410321673844, 0.2721747342729941, 0.08136846270645037, 0.7430703740101308, 0.440461914986372, 0.9066496964078397, 0.6758586305659264, 3.884048033505678, 3.4655468026176095, 1.6924713389016688, 3.455511541105807, 2.2236055321991444, 10.494279731065035, 43.91757220029831, 103.03958013653755, 100.50298824906349, 89.22530740499496, 85.74593290686607, 84.16681364178658, 87.12892949581146, 89.989043623209, 86.3438156247139, 82.89254441857338, 75.90504616498947, 78.9698477089405, 79.24144193530083, 78.69239419698715, 79.86651599407196, 89.0077006816864, 98.65278393030167, 96.28420382738113, 99.09558936953545, 95.76215744018555, 93.69179293513298, 86.39990821480751, 81.1843004822731, 97.25784078240395, 67.72349238395691, 41.52040623128414, 83.58784630894661, 75.8838053047657, 91.02285414934158, 59.41399186849594, 40.257832780480385, 106.7049166560173, 93.59964028000832, 99.59840878844261, 96.39587983489037, 99.86883267760277, 95.61551570892334, 78.73592466115952, 72.49593749642372, 74.8092457652092, 75.97404286265373, 74.83050182461739, 77.07710847258568, 79.65912312269211, 88.33784222602844, 90.15909969806671, 83.22509497404099, 80.99690973758698, 86.45825788378716, 87.79637888073921, 95.28231918811798, 86.1004538834095, 58.97706091403961, 22.83407863229513, 3.428892306983471, 1.4749852591194212, 1.4194244029931724, 1.4147410355508327, 0.5900318641215563, 0.2732341055525467, 0.0988787246751599, 0.13187842501793057, 0.026634765417838935, 0.073817176889861, 0.169673542259261, 0.7105189457070082, 10.477583426982164, 28.939638510346413, 48.57003875076771, 67.05721333622932, 76.12140655517578, 46.42641417682171, 10.0444389693439, 22.284770607948303, 32.76061087846756, 45.323606953024864, 45.08422739803791, 46.900028362870216, 30.55395718663931, 20.01591995358467, 6.967564048245549, 0.8754284936003387, 0.02294112797244452, 0.030319317120302003, 0.06326661256025545, 0.0034280847148693283, 0.05943405063590035, 0.1340100067318417, 0.06486712081823498, 0.12382922490360215, 0.06772890905267559, 0.022882205157657154, 0.10307585922419094, 0.07308276981348172, 0.0512769199849572, 0.08722272395971231, 0.033834353016573004, 0.033227012754650787, 0.11677250629873015, 0.1063225771940779, 0.09714319006889127, 0.11718110312358476, 0.021494928914762568, 0.03098530745774042, 0.022107237855379935, 0.028592725393536966, 0.020278702868381515, 0.08222753574955277, 0.03328694489027839, 0.026331601802667137, 0.04577729770971928, 0.029375852609518915, 0.06503146199975163, 0.012701490122708492, 0.029265779121487867, 0.027326764320605434, 0.0810106510471087, 0.08269780504633673, 0.05891057677217759, 0.07452102974639274, 0.03094376759690931, 0.026282358448952436, 0.05974786778097041, 0.03785573586355895, 0.04689913184847683, 0.056451121636200696, 0.023929342132760212, 0.020216195480315946, 0.02061568429780891, 0.10511865039006807, 0.05240676189714577, 0.12815055786632001, 0.0192551049622125, 0.019175641355104744, 0.023185832615126856, 0.04785688826814294, 0.049768497410696, 0.06168770451040473, 0.08087037029326893, 0.06520100563648157, 0.0681078273919411, 0.0706204203015659, 0.08650986885186285, 0.2901761792600155, 0.07659483526367694, 0.06922183558344841, 0.9117502102162689, 30.3298357129097, 93.25056821107864, 122.21253052353859, 108.03881227970123, 95.54219484329224, 79.34180215001106, 63.2598415017128, 45.3885530680418, 21.78815245628357, 48.693167343735695, 56.55757114291191, 40.48553176224232, 36.18143431842327, 11.48532735183835, 0.9255999920424074, 0.13163598021492362, 0.1277751795714721, 0.3019958012737334, 0.22840004414319992, 1.8619909300468862, 1.9090363243594766, 2.6510757068172097, 4.039542339742184, 1.22378536965698, 2.6201627030968666, 3.4840627340599895, 1.916309252846986, 3.275109096430242, 12.43617882952094, 48.77520494163036, 108.24807465076447, 105.37973776459694, 91.66324898600578, 91.68214917182922, 89.3996724486351, 93.73509541153908, 95.49280509352684, 91.06858849525452, 87.44720041751862, 80.0234703719616, 81.03711917996407, 83.04084286093712, 82.8688108921051, 82.67461091279984, 92.95296058058739, 100.3717964887619, 97.60811358690262, 100.45717030763626, 98.23806658387184, 96.25315949320793, 88.41270580887794, 85.58218449354172, 101.48779660463333, 72.24349424242973, 48.51125210523605, 92.84430161118507, 84.96111541986465, 99.34117779135704, 65.91639295220375, 46.15871474146843, 108.39647188782692, 98.48718881607056, 101.90201237797737, 101.47647321224213, 104.06916528940201, 99.50611934065819, 84.30698052048683, 76.72096878290176, 78.21892440319061, 81.63178727030754, 79.15759563446045, 81.93726047873497, 84.6301531791687, 92.6459750533104, 92.50333070755005, 85.33208191394806, 84.0052843093872, 92.18692928552628, 90.80237478017807, 98.40594917535782, 88.76249223947525, 62.881096825003624, 25.28619345277548, 5.1392327807843685, 0.6828196195419878, 1.8273502076044679, 2.7335388818755746, 3.439266225323081, 2.236967752687633, 0.6227652076631784, 0.20802620536414906, 0.14259141578804702, 0.0435259890218731, 0.09884228522423655, 0.7572377356700599, 11.392899211496115, 27.918148823082447, 38.37339609861374, 51.41998842358589, 57.81423591077328, 33.45087043941021, 11.808939836919308, 37.65026070177555, 53.178461864590645, 63.292971923947334, 61.12602040171623, 68.26867952942848, 49.683086425065994, 24.99089229851961, 8.11526633799076, 0.6666386628057808, 0.039834668932599016, 0.04524260999460239, 0.009458290860493435, 0.01882381140603684, 0.08177559007890522, 0.06078962789615616, 0.045814991390216164, 0.08904856309527531, 0.05465847505547572, 0.03137992964184377, 0.09266828448744491, 0.05626771839160938, 0.09443252536584623, 0.1077133916260209, 0.055398826734744944, 0.03728517272975296, 0.14055132603971288, 0.02954991035949206, 0.050780204255715944, 0.07235424796817824, 0.13155551656382158, 0.04883012217760552, 0.020915012864861637, 0.031727900422993116, 0.024941748451965395, 0.095033635298023, 0.006352997479552869, 0.04800797840289306, 0.04477138332731556, 0.017712152111926116, 0.017987683713727165, 0.02576562143076444, 0.009063853285624646, 0.027948383503826335, 0.05366555567889009, 0.16324151161825284, 0.1671750724199228, 0.11821011314168572, 0.16022202442400157, 0.15709675149992108, 0.25335220678243786, 0.18336276785703376, 0.12711872026557103, 0.16384637681767344, 0.15376841212855652, 0.10375102065154351, 0.14572106738341972, 0.1743022579466924, 0.1796212451881729, 0.26513789780437946, 0.21104870567796752, 0.12007190191070549, 0.09881533042062074, 0.32051971822511405, 0.1734388730255887, 0.16745711822295561, 0.19103316095424816, 0.14065311901504174, 0.19711461587576196, 0.195189529331401, 0.15349200664786622, 0.4922076273942366, 0.2030206864583306, 0.3433868911815807, 1.9681346719153225, 44.586750492453575, 118.1593944132328, 135.23091316223145, 120.0846903026104, 108.51532950997353, 87.4536220729351, 56.58046491444111, 39.13937799632549, 43.22181053459644, 92.71915912628174, 94.7670516371727, 59.907232001423836, 48.007049560546875, 17.809963524341583, 1.5578195080161095, 0.2221678738715127, 0.34035073535051197, 0.4933008999796584, 0.2671399450628087, 1.8802839796990156, 3.2784457923844457, 5.470631048083305, 6.507776845246553, 11.652220096439123, 13.284651450812817, 10.582186114042997, 9.342325944453478, 7.853189175948501, 15.343570969998837, 48.23044337332249, 112.08861216902733, 105.42074516415596, 94.44326341152191, 93.38726967573166, 93.97537931799889, 98.9053563773632, 100.35548776388168, 92.66181260347366, 91.52856901288033, 84.04389023780823, 83.55551764369011, 85.76333597302437, 87.34827652573586, 84.89227071404457, 97.12950646877289, 103.35631594061852, 98.93545836210251, 102.79295817017555, 103.39925363659859, 100.32884359359741, 92.15928196907043, 87.17974796891212, 106.66027665138245, 74.34471309185028, 58.26052576303482, 106.2259903550148, 92.74363741278648, 107.06822276115417, 73.36533084511757, 52.67174385488033, 110.64151301980019, 103.82803022861481, 104.75360736250877, 103.83040130138397, 108.67936670780182, 105.27930915355682, 89.88805264234543, 81.71431124210358, 82.9476946592331, 85.97347989678383, 82.65904694795609, 84.1434296965599, 89.88271772861481, 98.91003012657166, 99.63473483920097, 92.66082465648651, 89.77306321263313, 97.27745532989502, 95.70101112127304, 104.42604973912239, 91.41750857234001, 64.98510852456093, 26.85637179762125, 7.085289331153035, 4.5805777329951525, 4.620370622724295, 4.743344374001026, 5.027794260531664, 4.2709556221961975, 0.4662615805864334, 0.20142612280324101, 0.23689996538450941, 0.3546007425757125, 0.388466811273247, 1.3862494518980384, 20.05021881312132, 44.93325389921665, 71.61969691514969, 86.92013069987297, 96.69787243008614, 65.13419732451439, 16.532323881983757, 35.82871824502945, 58.204189985990524, 74.45896536111832, 79.94580253958702, 89.62072178721428, 68.31204280257225, 33.68494167923927, 10.410084798932076, 1.1772923707030714, 0.2891597041161731, 0.1982559499447234, 0.1000824362563435, 0.11732974788174033, 0.23610280972206965, 0.3635585244046524, 0.24700850655790418, 0.2614534611348063, 0.2596815687138587, 0.15775846521137282, 0.2539553650422022, 0.1584400684805587, 0.14703842403832823, 0.19270844059064984, 0.10812297550728545, 0.10501673867111094, 0.2674341027159244, 0.19900284736650065, 0.14567628619261086, 0.18608251644764096, 0.33918425731826574, 0.17277378996368498, 0.12158176425145939, 0.10229906809399836, 0.10325837560230866, 0.20491019444307312, 0.15201330708805472, 0.10540010989643633, 0.09734061619383283, 0.14145664230454713, 0.11381585674826056, 0.1048509799875319, 0.10396761645097286, 0.23730747867375612, 0.18366160104051232], [0.06039113170118071, 0.011028460121451644, 0.017295567922701593, 0.018691217446757946, 0.056013848225120455, 0.05023738631280139, 0.017128002109529916, 0.03286920109530911, 0.05400840935180895, 0.01208697793117608, 0.08276726264739409, 0.008962617848737864, 0.019497252906148788, 0.03795449716562871, 0.027686017601809, 0.027986457535007503, 0.04506815334025305, 0.022625640995102003, 0.08757545190746896, 0.06408851142623462, 0.04950504611770157, 0.0776774728728924, 0.04242019640514627, 0.024974156185635366, 0.04685450650868006, 0.07737847641692497, 0.09642375953262672, 0.22405757481465116, 0.27712147508282214, 34.90387827157974, 102.71808698773384, 98.93360406160355, 94.99662771821022, 68.35432693362236, 53.40902589261532, 25.04144098609686, 19.40379559993744, 38.23638305068016, 97.15081572532654, 61.39785781502724, 31.21918749064207, 28.389954306185246, 9.810393378138542, 0.27573422295972705, 0.21445667749503627, 0.10714644275140017, 0.21151832188479602, 0.12921356566948816, 0.5786380567587912, 2.7400191966444254, 3.0195832578465343, 2.4223956651985645, 2.372095864266157, 2.022898639552295, 3.114323574118316, 2.0701576536521316, 10.909077823162079, 32.23615922033787, 73.72651666402817, 103.29292014241219, 85.84012985229492, 91.48300185799599, 92.18147277832031, 91.17497518658638, 81.3717520236969, 87.6155237853527, 82.43536055088043, 80.55403590202332, 70.17677754163742, 71.28096029162407, 73.01891103386879, 79.13466766476631, 81.13002419471741, 86.65052756667137, 90.68136647343636, 97.44492754340172, 93.29781487584114, 92.63652876019478, 95.7299579679966, 96.76623836159706, 89.13952320814133, 82.08052799105644, 81.06571644544601, 98.60115990042686, 50.88154211640358, 54.46816585958004, 74.77918937802315, 87.59198784828186, 38.63751232624054, 79.91144478321075, 94.07235771417618, 85.02579554915428, 95.28676494956017, 96.37951031327248, 101.1956986784935, 97.81447291374207, 82.78723686933517, 71.76317721605301, 74.49991956353188, 72.8182666003704, 72.97123119235039, 71.2369130551815, 78.14966931939125, 84.94927525520325, 82.73751273751259, 76.90552487969398, 70.87256580591202, 83.08922186493874, 87.81672298908234, 91.95204108953476, 84.3750348687172, 80.29317229986191, 65.35406112670898, 18.848265409469604, 1.7745632026344538, 1.7187938326969743, 0.980003394652158, 1.1183823505416512, 0.9021859453059733, 1.2362697185017169, 0.5273473996203393, 0.12228051855345257, 0.024099002657749224, 0.11445601106970571, 0.09225376532413065, 0.2758415968855843, 7.111800508573651, 28.907207250595093, 46.88979171216488, 46.40773057937622, 87.29766324162483, 105.31155422329903, 28.761733956635, 14.953705240041018, 30.102017037570477, 48.28375831246376, 53.05615782737732, 54.09598723053932, 49.96790774166584, 30.090317465364933, 17.334645129740238, 1.74609893001616, 0.07175992868724279, 0.15545179601758718, 0.04504497606831137, 0.06661368373897858, 0.07451797209796496, 0.0814924162114039, 0.05651946601574309, 0.016344995492545422, 0.03418443520786241, 0.13081341341603547, 0.07492613847716711, 0.04046314184961375, 0.02314596073119901, 0.12910917517729104, 0.011434087427915074, 0.14525962964398786, 0.059115491167176515, 0.0286679884447949, 0.045278477991814725, 0.03521063248626888, 0.04462034885364119, 0.03281050092482474, 0.11748401069780812, 0.010919283704424743, 0.039982430535019375, 0.05237898702034727, 0.04877534054685384, 0.03832010508631356, 0.09014045528601855, 0.0850687813363038, 0.08489111118251458, 0.01872727840236621, 0.07467653194908053, 0.05725889001041651, 0.11113136759377085, 0.016564851175644435, 0.045528522387030534, 0.08910343749448657, 0.050862419375334866, 0.01337078858341556, 0.01841808854806004, 0.04575936371111311, 0.026840384853130672, 0.06592280362383462, 0.037289781466824934, 0.06696184747852385, 0.04743183802929707, 0.013041039383097086, 0.013192178685130784, 0.048236571019515395, 0.06985990446992218, 0.07758451145491563, 0.06592010220629163, 0.09386952471686527, 0.04436848990735598, 0.05215198631049134, 0.07168102354626171, 0.04942237828799989, 0.04555301697109826, 0.05629488099657465, 0.10241342562949285, 0.2524647465907037, 0.49292237497866154, 42.99954906105995, 116.60622015595436, 113.11043813824654, 109.9706058204174, 82.07549706101418, 70.00392481684685, 51.34222939610481, 37.881862074136734, 33.24133828282356, 63.38969573378563, 53.893811479210854, 36.96573503315449, 34.77828361093998, 14.678270369768143, 0.6453547580167651, 0.12407283487846144, 0.14658471947768703, 0.20694183855084702, 0.3854062536265701, 1.9489597133360803, 3.261104947887361, 2.780648753978312, 2.5114073138684034, 1.3231255766004324, 0.5977890884969383, 1.0040385299362242, 4.159034052863717, 13.613843936473131, 38.37644353508949, 78.82309198379517, 106.46625146269798, 90.20674914121628, 96.49300262331963, 99.93269205093384, 93.63742545247078, 85.89006677269936, 90.19078239798546, 86.57787546515465, 84.18237760663033, 73.8379342854023, 74.09293100237846, 76.74985483288765, 82.77866452932358, 84.9120220541954, 90.25388181209564, 96.10866084694862, 100.13587474822998, 94.89574313163757, 96.05460494756699, 99.92687836289406, 98.42726603150368, 92.64339119195938, 83.74202683568001, 85.83167150616646, 103.71009215712547, 58.09484325349331, 61.81934639811516, 84.8623663187027, 95.61348661780357, 46.79241433739662, 83.61856386065483, 99.11057576537132, 91.44584745168686, 98.03962603211403, 99.13609519600868, 104.89283949136734, 103.44332367181778, 88.50208461284637, 77.32714265584946, 77.2153602540493, 76.42135486006737, 76.34719043970108, 72.92344495654106, 83.41775983572006, 89.10264238715172, 87.29230552911758, 81.45147174596786, 76.79660752415657, 86.47319868206978, 92.48993262648582, 96.1901892721653, 87.31112971901894, 83.08525487780571, 72.29134127497673, 23.05084180086851, 2.328134598210454, 0.5915339710190892, 0.5801159993279725, 0.8316695666871965, 2.4307792028412223, 1.5737728332169354, 1.281237811781466, 0.5204613972455263, 0.10893762359046377, 0.17321625840850174, 0.11337261646986008, 0.11905353429028764, 7.829192513599992, 33.95226493477821, 42.747261598706245, 46.42904743552208, 78.6088290810585, 79.38689813017845, 33.93850587308407, 32.97765903174877, 51.33450821042061, 72.22942739725113, 73.15793037414551, 73.49567905068398, 73.90485629439354, 45.68909414112568, 20.105688236653805, 1.8430569022893906, 0.1723215845413506, 0.09357596820336767, 0.06972016548388638, 0.06930806572199799, 0.16279028583085164, 0.11298365687252954, 0.0568123583070701, 0.02664711846591672, 0.038467091144411825, 0.02893173659685999, 0.04465272133529652, 0.04023904293717351, 0.08814402608550154, 0.05425246090453584, 0.04780023642524611, 0.11899891964276321, 0.07994253726792522, 0.04558445063594263, 0.013053377588221338, 0.03997452666226309, 0.02318269147508545, 0.01653319486649707, 0.06435145434807055, 0.036732050066348165, 0.08080456405878067, 0.08164151367964223, 0.030476340725726914, 0.020888056205876637, 0.018579338684503455, 0.037177342383074574, 0.04322026128647849, 0.017883428663481027, 0.08964311244199052, 0.05670602338796016, 0.21853679761989042, 0.11551922667422332, 0.14946664217859507, 0.14576320652849972, 0.2152561635011807, 0.15280977997463197, 0.1091372019436676, 0.14814081019721925, 0.3142704488709569, 0.1903106801910326, 0.26650932733900845, 0.1272302947472781, 0.13872460374841467, 0.07791988798999228, 0.15436149202287197, 0.22029271902283654, 0.15216151397908106, 0.16227967338636518, 0.2100123855052516, 0.2023133751936257, 0.16171847615623847, 0.15395032736705616, 0.19634791795397177, 0.16707170609151945, 0.13365583901759237, 0.16916310793021694, 0.20375585794681683, 0.3244824009016156, 1.4103468088433146, 62.77487352490425, 138.665412068367, 124.33031648397446, 120.78440755605698, 96.81783959269524, 76.03636711835861, 41.655621975660324, 32.63166479766369, 51.61581851541996, 125.16194745898247, 84.86818760633469, 52.13385611772537, 47.11254335939884, 20.655972808599472, 1.0822365526109934, 0.35452878393698484, 0.30356980743817985, 0.3166254615643993, 0.33509615168441087, 1.6014955518767238, 7.946427622810006, 9.989201333373785, 9.217710681259632, 9.395347349345684, 7.857234058901668, 11.654487624764442, 8.9305648393929, 16.80175792425871, 38.533276319503784, 79.97032642364502, 111.14551037549973, 92.23812773823738, 100.41150435805321, 100.48803225159645, 98.10286223888397, 90.64758628606796, 96.33786454796791, 91.6055528819561, 87.47585088014603, 76.38838782906532, 77.15796813368797, 80.80470845103264, 85.95348536968231, 87.73339346051216, 93.19907337427139, 99.23570305109024, 103.54895040392876, 99.35448467731476, 99.02056619524956, 105.75632035732269, 104.12305399775505, 98.07588368654251, 89.2363952100277, 92.31024026870728, 109.52674403786659, 64.79226887226105, 69.843869805336, 93.68059113621712, 107.36665114760399, 57.15964123606682, 88.50985899567604, 107.344019562006, 97.0105804502964, 103.78922671079636, 104.97019574046135, 111.06894448399544, 109.90055277943611, 93.4944923222065, 80.7352177798748, 80.59257343411446, 80.2378548681736, 80.33221900463104, 78.11617031693459, 88.8668954372406, 94.7958692908287, 92.74260386824608, 88.27499359846115, 80.0956816971302, 91.54023438692093, 96.81474655866623, 101.34325236082077, 92.08774700760841, 84.82991605997086, 73.5752771794796, 21.84098482131958, 5.419367998838425, 8.531776238232851, 5.419491492211819, 3.9040247490629554, 3.207562970928848, 3.02171494346112, 2.3644421249628067, 0.8562376827467233, 0.20633719599572942, 0.2412734119570814, 0.2598582295468077, 0.9444066078867763, 13.876609336584806, 48.424745947122574, 67.83829942345619, 63.359422758221626, 101.46985396742821, 123.4207820892334, 41.27162978053093, 26.27979263663292, 53.33649158477783, 76.13921239972115, 87.31517270207405, 91.3866314291954, 92.54747673869133, 60.9833000600338, 24.40293274819851, 2.402100716717541, 0.27063664805609733, 0.25882346788421273, 0.1920396913192235, 0.15456568653462455, 0.20395597064634785, 0.2170745440525934, 0.185141057590954, 0.08047367751714773, 0.21430168737424538, 0.21063230145955458, 0.26585353596601635, 0.21035251178545877, 0.19748542254092172, 0.22210185241419822, 0.2024273542338051, 0.2635308512253687, 0.19406427018111572, 0.09333357535069808, 0.12920059292810038, 0.18984097492648289, 0.16840696334838867, 0.1400377301615663, 0.18452832562616095, 0.12057539715897292, 0.15268523275153711, 0.1979077936266549, 0.10812771040946245, 0.14632922771852463, 0.2769785077543929, 0.15176410874119028, 0.17415896407328546, 0.09514572186162695, 0.1674594040377997, 0.13796550541883335], [0.04532718514383305, 0.023658415557292756, 0.02118501917721005, 0.05021707002015319, 0.07570551970275119, 0.034930779729620554, 0.03457218510448001, 0.06596283506951295, 0.05378394307626877, 0.05311047374561895, 0.06928845075890422, 0.06088345391617622, 0.06457388342823833, 0.03585507642128505, 0.009628133211663226, 0.00754823837269214, 0.051514551960281096, 0.03605589416110888, 0.05948832389549352, 0.016513487134943716, 0.08313179074320942, 0.02538491451559821, 0.010333539012208348, 0.016507791151525453, 0.03307663879240863, 0.032417259135399945, 0.4497304785763845, 0.9872348222415894, 45.42982265353203, 97.9497380554676, 98.29475194215775, 93.26178520917892, 86.9324192404747, 55.41483946144581, 24.791051521897316, 19.686506129801273, 31.99390321969986, 71.44809812307358, 50.590409338474274, 43.53604607284069, 32.77014836668968, 9.38522944226861, 0.2346361181116663, 0.13801012333715335, 0.18708140269154683, 0.21308121067704633, 0.2819349558558315, 0.5179809022229165, 1.728060229215771, 2.1499721333384514, 1.934779705479741, 3.0370893934741616, 1.5372127387672663, 0.964138830313459, 5.282245231792331, 30.025325752794743, 59.964240342378616, 92.64123290777206, 95.62348768115044, 84.01971593499184, 88.29481333494186, 89.68450516462326, 86.12510696053505, 87.66698822379112, 84.75009754300117, 75.90889915823936, 73.34972888231277, 70.15933647751808, 70.3270822763443, 77.08970099687576, 80.41777521371841, 82.88966417312622, 88.17990750074387, 93.7510621547699, 96.19872361421585, 94.56670358777046, 88.95040735602379, 88.41716676950455, 93.3963891863823, 94.38147872686386, 91.5050482749939, 86.64852127432823, 83.48987996578217, 85.13172626495361, 92.44235917925835, 38.70546407997608, 72.21464619040489, 61.464228853583336, 54.257581159472466, 97.68393471837044, 81.49701610207558, 83.39977160096169, 80.00412940979004, 97.01299712061882, 95.89825093746185, 96.35910540819168, 77.6202817261219, 71.42923593521118, 68.42153772711754, 72.34600514173508, 70.05412772297859, 71.85065612196922, 72.08102256059647, 81.1409904062748, 77.54011362791061, 74.50005635619164, 71.88346356153488, 79.2785507440567, 86.87147811055183, 91.87551319599152, 83.19799482822418, 91.2423987686634, 88.56040388345718, 88.56675714254379, 32.580211758613586, 3.0232852092012763, 1.8529220041818917, 1.3315154076553881, 0.7735898019745946, 2.5968970265239477, 1.4023728179745376, 0.44539734546560794, 0.45120479946490377, 0.11421378148952499, 0.08341107575688511, 0.09155011284747161, 0.15242174064042047, 3.675624942407012, 18.18663541227579, 30.330941453576088, 32.45573803782463, 54.531934037804604, 73.81328880786896, 27.445507384836674, 12.43782414123416, 12.060334347188473, 30.574776269495487, 45.651487559080124, 49.28947314620018, 57.651236057281494, 46.082331240177155, 23.454976715147495, 3.1004880415275693, 0.2514179621357471, 0.05213645315961912, 0.052987629751442, 0.05025018464948516, 0.0874030361592304, 0.03261191333876923, 0.018411424061923753, 0.03578721443773247, 0.08645795562188141, 0.033464444350101985, 0.03982722519140225, 0.06997786884312518, 0.03822666498308536, 0.031171304508461617, 0.09567856905050576, 0.035231182555435225, 0.10713524374295957, 0.0691206289047841, 0.04361195198725909, 0.03515781383612193, 0.007032407238511951, 0.04608360803104006, 0.020260789278836455, 0.038410298293456435, 0.06277430147747509, 0.11121885196189396, 0.08255044420366175, 0.020490105489443522, 0.02851727680535987, 0.029243388526083436, 0.05699980254576076, 0.012028879827994388, 0.039538077035103925, 0.04741300974274054, 0.054485450746142305, 0.05646422054269351, 0.02766961057204753, 0.08022890237043612, 0.06395452408469282, 0.024980260350275785, 0.03006255443324335, 0.0530322921986226, 0.08728665998205543, 0.04890182477538474, 0.01041838782839477, 0.015564580826321617, 0.033431084812036715, 0.019169642946508247, 0.02327463615074521, 0.04263510010787286, 0.05755929654696956, 0.09871776768704876, 0.016635780084470753, 0.055534517305204645, 0.029904872171755414, 0.050213533686473966, 0.036303957022028044, 0.010210115215159021, 0.05263152874249499, 0.4407002334482968, 1.5376367722637951, 53.88361282646656, 113.69370684027672, 112.89641082286835, 110.57702288031578, 103.72060999274254, 73.3317482471466, 45.52730642259121, 30.729889646172523, 28.469419442117214, 41.78204499185085, 44.98993165791035, 42.219355925917625, 37.29020342230797, 14.162604790180922, 0.4553114587906748, 0.26661910582333803, 0.09343629601062275, 0.3016760543687269, 0.522943198448047, 1.7909169313497841, 3.3856223663315177, 2.4126503756269813, 3.2899881480261683, 0.6165036780294031, 2.1078616054728627, 1.9004116184078157, 7.317807404324412, 36.645682007074356, 67.78259441256523, 93.50837677717209, 99.62825998663902, 86.63882419466972, 93.45737591385841, 95.14465257525444, 90.39719492197037, 90.50267726182938, 89.73814308643341, 82.75220274925232, 76.24571308493614, 74.96135920286179, 71.99944853782654, 79.86993581056595, 84.45784762501717, 88.12203660607338, 91.45614489912987, 97.41753101348877, 98.8926650583744, 96.37564212083817, 93.89783307909966, 92.51711636781693, 97.6961624622345, 99.04224783182144, 94.98942330479622, 91.65169760584831, 87.72110491991043, 89.14540529251099, 94.57988128066063, 47.650210708379745, 79.1019894182682, 69.42422032356262, 61.17951013147831, 99.37565714120865, 85.98679438233376, 83.98930996656418, 85.15989795327187, 98.96489158272743, 96.66555896401405, 99.4067394733429, 81.65866702795029, 74.67895075678825, 73.08947324752808, 74.15649399161339, 73.90030413866043, 76.45296916365623, 75.09775668382645, 85.27418822050095, 82.06390768289566, 79.1141639649868, 76.41732707619667, 82.08472296595573, 89.36838492751122, 96.06240212917328, 85.72463124990463, 93.43963846564293, 91.56367152929306, 95.04024937748909, 40.76793260872364, 4.098561247810721, 1.0010664956644177, 0.938575048930943, 0.39523576211649925, 0.8957845356781036, 2.170870774425566, 1.5227720886468887, 1.30580646218732, 0.1087831158656627, 0.11896495896507986, 0.1122585563280154, 0.1664967494434677, 4.13849662989378, 21.37234076857567, 30.032742954790592, 33.84072571992874, 50.67708648741245, 52.5535473972559, 28.22133455425501, 26.24666601419449, 27.65340942889452, 52.128224819898605, 63.88789460062981, 65.78171297907829, 77.98674926161766, 61.02460004389286, 27.856276743113995, 4.236477222293615, 0.32108199899084866, 0.09953110959031619, 0.07851509042666294, 0.08836747190798633, 0.13652134541189298, 0.043672273750416934, 0.04826482829230372, 0.02552374622609932, 0.059457079478306696, 0.08318681357195601, 0.03246890890295617, 0.06314564248896204, 0.06516314868349582, 0.05224439111771062, 0.03359193418873474, 0.021929664180788677, 0.042825809796340764, 0.07528397982241586, 0.07962063813465647, 0.06295192710240372, 0.06848383651231416, 0.015429727027367335, 0.02793719006149331, 0.030057852927711792, 0.08435165145783685, 0.05156465063919313, 0.10869181685848162, 0.06038974388502538, 0.07322047531488352, 0.07740741275483742, 0.062182524052332155, 0.05582680845691357, 0.048459523313795216, 0.18192674178862944, 0.11038154611014761, 0.11624683567788452, 0.12236029942869209, 0.17602763255126774, 0.2588750026188791, 0.1146335327939596, 0.11045026156352833, 0.15722316893516108, 0.3557983017526567, 0.14147969341138378, 0.1682427854393609, 0.23209902690723538, 0.1522957388078794, 0.08255566892330535, 0.1388898800360039, 0.08049260228290223, 0.12331589619861916, 0.26430485188029706, 0.09503703433438204, 0.26661587005946785, 0.12840860261349007, 0.15879871876677498, 0.1855936786159873, 0.1780810215859674, 0.12054896185873076, 0.6812374794390053, 2.113009379245341, 74.75712776184082, 136.895649433136, 121.44807994365692, 123.00169497728348, 116.25520259141922, 76.63157477974892, 44.031634479761124, 31.965161561965942, 47.99884580075741, 102.56071463227272, 71.80147156119347, 67.6812082529068, 54.08663593232632, 19.59552951157093, 0.8637401426676661, 0.30590831476729363, 0.35073109553195536, 0.5922643037047237, 0.4330145224230364, 1.2249847990460694, 5.937450723722577, 10.597691182047129, 7.427587313577533, 10.132860224694014, 7.465756265446544, 1.8904405971989036, 6.243416480720043, 36.12467676401138, 65.42767077684402, 96.85877099633217, 103.5651983320713, 92.06054046750069, 97.30218440294266, 99.22650754451752, 94.30449485778809, 95.1375013589859, 94.31815892457962, 88.69458988308907, 80.6564936041832, 78.69031950831413, 77.88189008831978, 84.98604208230972, 89.12785783410072, 92.5244727730751, 95.92096611857414, 102.82877504825592, 102.10280120372772, 101.26214951276779, 97.85638466477394, 98.3067212998867, 102.94736668467522, 104.46011871099472, 99.75179895758629, 96.75506696105003, 92.09616735577583, 96.95663094520569, 99.46438997983932, 55.64754657447338, 88.11778083443642, 78.03284838795662, 67.50457853078842, 103.94676625728607, 89.66212436556816, 88.89875292778015, 87.60375201702118, 103.39166924357414, 102.34224915504456, 102.34114721417427, 86.8103089928627, 78.68632212281227, 77.86866679787636, 80.5770094692707, 79.09094721078873, 82.1191643178463, 80.55824607610703, 91.28828510642052, 86.23853087425232, 83.7161274254322, 80.65541446208954, 86.77611842751503, 95.53132742643356, 102.36380159854889, 86.47008284926414, 99.29635539650917, 97.03318923711777, 100.32773405313492, 36.26371510326862, 5.515943616628647, 6.462788209319115, 8.262422941625118, 6.354276482015848, 7.771864989772439, 6.8318970780819654, 2.4970742454752326, 2.059384756721556, 0.2627803914947435, 0.4297228896757588, 0.3824470436666161, 0.7524954120162874, 7.802526019513607, 32.16108284890652, 47.65922762453556, 50.79521834850311, 67.75613263249397, 93.23710933327675, 38.62537577748299, 24.17316097766161, 26.122211292386055, 54.93369407951832, 74.78737413883209, 85.04145070910454, 95.623799264431, 74.08572658896446, 33.85000862181187, 6.36641445569694, 0.5243457388132811, 0.23009337281109765, 0.12599592504557222, 0.1371145885786973, 0.22914302302524447, 0.16405057132942602, 0.10370762727688998, 0.09883291932055727, 0.17826473282184452, 0.18838685529772192, 0.08919358617276885, 0.14245254511479288, 0.18188396439654753, 0.14827965118456632, 0.17651045898674056, 0.12345795810688287, 0.17385944811394438, 0.09350834370707162, 0.1789471079246141, 0.18687092961044982, 0.12283001953619532, 0.11032870519557036, 0.10057167484774254, 0.14170012611430138, 0.16615801840089262, 0.19291284290375188, 0.2454397251131013, 0.1295037750969641, 0.14153686846839264, 0.21348872396629304, 0.19053149881074205, 0.12685132445767522, 0.19756582682020962], [0.05143811446032487, 0.038704994003637694, 0.02953037703264272, 0.04031760669022333, 0.038484327524201944, 0.03583963603887241, 0.048908040262176655, 0.048131052462849766, 0.07394557585939765, 0.022699555192957632, 0.02415882161585614, 0.0743191729998216, 0.027875079722434748, 0.015840767373447306, 0.015560212359559955, 0.014162083134579007, 0.07401616152492352, 0.04177707349299453, 0.08226833160733804, 0.004591496053762967, 0.021365355496527627, 0.040077128578559496, 0.04728790961962659, 0.02105609884893056, 0.04490570834605023, 0.06736046241712756, 1.0873880074359477, 61.0771170258522, 109.27230969071388, 97.00282886624336, 90.11748433113098, 72.82870844006538, 45.56321069598198, 30.95657028257847, 21.679691076278687, 44.66381795704365, 88.568474650383, 49.85812023282051, 50.50520271062851, 27.256860807538033, 8.479003719985485, 0.07994297513505444, 0.10864472016692162, 0.019445083635218907, 0.16242318990407512, 0.11028067339793779, 0.383991957642138, 1.8900530179962516, 4.479807140305638, 2.123157922178507, 1.056979070417583, 1.9471796276047826, 5.928676994517446, 27.821204625070095, 61.294970735907555, 83.70544999837875, 89.31990712881088, 92.36266985535622, 88.27770665287971, 89.17676880955696, 75.50647035241127, 75.14882594347, 79.29821088910103, 82.45997563004494, 81.42905294895172, 78.43902379274368, 73.68294060230255, 71.30378186702728, 69.43591609597206, 78.42269226908684, 84.77191597223282, 90.05978062748909, 89.88540038466454, 91.13139152526855, 91.64304926991463, 84.89646568894386, 80.22216930985451, 79.14954766631126, 89.44447204470634, 90.76177015900612, 90.40325939655304, 90.33155724406242, 92.24579572677612, 89.28766965866089, 90.87867468595505, 73.89643594622612, 33.539869263768196, 40.40589563548565, 87.45556756854057, 88.0666583776474, 74.72601503133774, 69.05038878321648, 73.12150552868843, 81.90481022000313, 87.24408611655235, 83.00545915961266, 72.70298078656197, 70.67680031061172, 70.46176224946976, 71.06351315975189, 70.18512189388275, 67.64772444963455, 69.1463640332222, 72.005505412817, 75.0580108165741, 71.84867262840271, 69.16803047060966, 79.84026700258255, 83.85301128029823, 92.98153504729271, 87.14193239808083, 90.71671217679977, 80.62174826860428, 83.85656028985977, 94.07604351639748, 69.52380537986755, 19.896024987101555, 1.8248606286942959, 2.3793370882049203, 1.8122235755436122, 1.1913954326882958, 0.7794275355990976, 1.1857940582558513, 0.0867743109120056, 0.12439160214853473, 0.029597951433970593, 0.04514443869993556, 0.4315700358711183, 2.773262900300324, 15.520401131361723, 32.92561702430248, 38.363239243626595, 43.266952112317085, 52.930699959397316, 41.22463010251522, 27.800727523863316, 14.143507964909077, 32.07222081720829, 45.077824741601944, 54.649184346199036, 61.07491694390774, 58.94629396498203, 45.27396261692047, 13.455974757671356, 1.1038856534287333, 0.06246601333259605, 0.04851411940762773, 0.054858331714058295, 0.03538550103257876, 0.02548810272855917, 0.0039041174841258908, 0.04147423642280046, 0.018576691072667018, 0.015670383254473563, 0.03357626745128073, 0.07069523620884866, 0.03598663322918583, 0.04507688099693041, 0.1004429419117514, 0.006458458519773558, 0.04938276244502049, 0.0422765982511919, 0.07934764653327875, 0.04109429020900279, 0.028307573702477384, 0.025344411806145217, 0.035044714240939356, 0.04139058895816561, 0.04221465489536058, 0.04468752063985448, 0.01394298073137179, 0.04179423936875537, 0.018998824671143666, 0.08544629701646045, 0.055797497334424406, 0.06730297565809451, 0.03556710456905421, 0.042857336229644716, 0.03888919876771979, 0.07980069058248773, 0.05665569464326836, 0.04940757244185079, 0.12949023832334206, 0.03188207789207809, 0.015644293052901048, 0.02645199856488034, 0.012445288684830302, 0.05477266189700458, 0.007915638580016093, 0.01816947649786016, 0.021604573812510353, 0.028583856728801038, 0.0646345094719436, 0.06641552288783714, 0.0694180371647235, 0.03784268148592673, 0.02445881811581785, 0.06397451012162492, 0.02200956194428727, 0.02861072247469565, 0.05642072697810363, 0.0800210861780215, 1.2818130059167743, 69.88898858428001, 127.55625218153, 112.64938607811928, 103.35760027170181, 83.13397586345673, 65.34684911370277, 55.49460478127003, 30.616382136940956, 29.993194676935673, 64.56132486462593, 50.345656871795654, 51.47715635597706, 35.18563315272331, 13.709114324301481, 0.16282098105875775, 0.08989152411231771, 0.05166947899851948, 0.12968478491529822, 0.15258162893587723, 0.31165470485575497, 2.6696901954710484, 6.635265229269862, 3.8504388369619846, 0.8082945272326469, 2.83490770496428, 8.604345694184303, 31.212364956736565, 65.6961415708065, 86.02419957518578, 90.35286650061607, 94.26310747861862, 93.74714076519012, 93.42293456196785, 79.09802243113518, 78.71063321828842, 82.6754392683506, 88.76484051346779, 83.85944053530693, 82.91355729103088, 76.38560637831688, 73.06417420506477, 74.79076355695724, 81.68220296502113, 88.99782121181488, 90.8832648396492, 94.05279636383057, 95.10600864887238, 93.54590356349945, 87.83366248011589, 85.2681465446949, 83.4388867020607, 92.06412747502327, 92.90002182126045, 94.56226542592049, 94.86051142215729, 98.56541141867638, 94.15660679340363, 96.03663951158524, 76.74448952078819, 40.94427354633808, 49.76348631083965, 92.27942392230034, 93.74033153057098, 78.97681653499603, 74.08986076712608, 75.8868907392025, 84.95099276304245, 91.63540408015251, 85.92304900288582, 76.4418813586235, 73.30293819308281, 72.84302607178688, 75.53533360362053, 72.51603841781616, 70.57743564248085, 72.91129320859909, 77.19240948557854, 79.2118339240551, 74.60243806242943, 73.3813051879406, 83.6994843184948, 89.90486294031143, 97.6630662381649, 92.2546112537384, 93.01592320203781, 85.4654623568058, 88.75420108437538, 100.75380519032478, 76.33987963199615, 24.364649802446365, 3.1490658223629, 1.1182238277979195, 0.929035363951698, 0.6243087560869753, 1.4660940924659371, 1.619491979945451, 0.23977813281817362, 0.1668904142570682, 0.07595764953293838, 0.047540243540424854, 0.30502471374347806, 3.0265919817611575, 17.806783095002174, 34.086914509534836, 30.042780116200447, 32.133709117770195, 37.33139321208, 33.0354805290699, 33.38154695928097, 31.206748858094215, 47.07037702202797, 61.63519307971001, 69.6293181180954, 76.5575547516346, 77.7308177947998, 56.54459863901138, 17.19721980392933, 1.275555572938174, 0.09156339729088359, 0.06497222377220169, 0.03201729719876312, 0.02599083356471965, 0.019413560912653338, 0.04667789391533006, 0.05114044644869864, 0.08237447356805205, 0.005925912828388391, 0.027050804128521122, 0.049156374006997794, 0.07637451388291083, 0.013765677940682508, 0.06550167934619822, 0.030191363439371344, 0.041804032007348724, 0.03838621560134925, 0.019051999552175403, 0.022867061634315178, 0.014542206536134472, 0.037998513944330625, 0.09236064943252131, 0.08061377273406833, 0.02617212539917091, 0.08274263818748295, 0.021374591524363495, 0.016692528406565543, 0.012709481197816785, 0.048226036233245395, 0.029450820657075383, 0.011474050224933308, 0.17200507340021431, 0.14368213538546115, 0.10265483142575249, 0.14636240171967074, 0.14911523525370285, 0.1794780552154407, 0.1725785605958663, 0.16166754998266697, 0.16566204110858962, 0.1350093085784465, 0.11356668808730319, 0.24495991179719567, 0.19785202865023166, 0.11033174057956785, 0.0755465219845064, 0.1565930707147345, 0.17237635503988713, 0.15448477759491652, 0.14830394909949973, 0.09603350117686205, 0.1322189372149296, 0.07852725422708318, 0.08447743064607494, 0.1273442737874575, 0.11923090016352944, 0.20797100441996008, 2.581094386987388, 91.00026056170464, 146.81144535541534, 122.07037255167961, 117.76255130767822, 97.99456804990768, 70.33935561776161, 49.72337946295738, 35.13939343392849, 66.35852962732315, 126.08811736106873, 71.07279226183891, 80.763169080019, 45.377640053629875, 17.17038184404373, 0.807427876861766, 0.3124085784656927, 0.1823158943443559, 0.28465730196330696, 0.2295587444677949, 1.894112981390208, 6.638374887406826, 13.3764773234725, 8.958702329546213, 5.215704627335072, 4.592776503413916, 7.846716698259115, 31.745898127555847, 68.5888123512268, 87.22090736031532, 93.87682020664215, 94.45039942860603, 94.91338178515434, 96.22431144118309, 82.41290375590324, 81.2475822865963, 88.64850595593452, 93.69611710309982, 88.46800044178963, 85.3310863673687, 81.83058500289917, 77.13031321763992, 78.14511716365814, 86.99636220932007, 92.95324936509132, 95.72712332010269, 99.442328363657, 99.67181324958801, 99.4693373143673, 93.58423590660095, 90.5847680568695, 87.73315027356148, 98.85692417621613, 97.85923451185226, 99.58111971616745, 99.07918184995651, 103.02979946136475, 98.02090063691139, 98.74887317419052, 79.39115390181541, 47.587818056344986, 57.219108045101166, 94.42800343036652, 101.01840779185295, 83.40508371591568, 79.05982688069344, 80.91313943266869, 91.66324898600578, 94.98376920819283, 91.24918520450592, 80.03812998533249, 76.97188451886177, 76.91021382808685, 78.19631561636925, 77.63754799962044, 74.07435759902, 78.55285048484802, 81.71032905578613, 84.62313875555992, 81.68890580534935, 77.9581367969513, 89.4955413043499, 93.64586099982262, 103.9109493792057, 96.02592408657074, 101.16091534495354, 89.63183239102364, 95.36123335361481, 104.89730045199394, 76.09112218022346, 22.289702743291855, 3.28187748324126, 9.079766683280468, 6.6062998585402966, 4.027597680687904, 3.6362500302493572, 4.099795231595635, 0.4682033654535189, 0.40072326140943915, 0.20378898741910234, 0.23241111484821886, 0.6740668485872447, 6.150936568155885, 29.185168035328388, 51.470928490161896, 57.2508629411459, 60.6020475178957, 73.3809632062912, 60.0798225402832, 41.649378910660744, 22.867961414158344, 51.72391511499882, 71.45536333322525, 83.88850137591362, 94.55025807023048, 89.42560225725174, 68.02007406949997, 22.251476794481277, 2.231273758225143, 0.19354469259269536, 0.14870194805553183, 0.09704218377009965, 0.17154115688754246, 0.10633160913130268, 0.07802969616022892, 0.12135291559388861, 0.18400494824163616, 0.07590287161292508, 0.10563240954070352, 0.18957614694954827, 0.2740119950613007, 0.12276229856070131, 0.2001911890693009, 0.08193880319595337, 0.20767240872373804, 0.14577782683772966, 0.15420126233948395, 0.061386299785226583, 0.09470859688008204, 0.17692341963993385, 0.17015812016325071, 0.14240755612263456, 0.10309068733477034, 0.12563110009068623, 0.18508689565351233, 0.16230552981141955, 0.15620767342625186, 0.1941611204529181, 0.1690974278608337, 0.15358473057858646], [0.043750744735007174, 0.05281993406242691, 0.03098735021922039, 0.013073166956019122, 0.021816468106408138, 0.05848240580235142, 0.060634938345174305, 0.0915330286079552, 0.028465270806918852, 0.05943903415754903, 0.05666859316988848, 0.03352384956087917, 0.03691028796311002, 0.02551930447225459, 0.003685558936012967, 0.05602541830739938, 0.10419086931506172, 0.09519373139482923, 0.034331161514273845, 0.07157794665545225, 0.04439673233719077, 0.014215855444490444, 0.046779356634942815, 0.04076747063663788, 0.040547635362599976, 0.8229581185150892, 58.414702489972115, 117.47451916337013, 98.9894686639309, 102.89268761873245, 74.58990633487701, 56.8781029433012, 30.403384566307068, 20.117156021296978, 66.66855499148369, 68.32756876945496, 43.99947300553322, 42.0827342569828, 29.630036763846874, 10.442158877849579, 0.11414258726290427, 0.0843981618527323, 0.18948302225908265, 0.1987261450267397, 0.08987144159618765, 0.4317165951943025, 1.6303615341894329, 4.168244283646345, 3.0812154756858945, 1.5100862318649888, 4.784785425290465, 19.831563346087933, 55.33335663378239, 90.02038434147835, 83.8859935104847, 88.82133588194847, 85.47721892595291, 92.43422761559486, 89.97767463326454, 86.35193958878517, 81.12342774868011, 73.7307496368885, 66.73696652054787, 69.70482006669044, 69.28120359778404, 70.71976840496063, 68.18353369832039, 66.97362542152405, 67.89949133992195, 80.19604951143265, 87.12794914841652, 90.24547666311264, 87.1448202431202, 93.06236431002617, 83.78603607416153, 81.55914276838303, 68.3069434762001, 74.07400041818619, 76.78893193602562, 88.28972160816193, 85.00221401453018, 95.8711887896061, 85.89142709970474, 96.63223475217819, 84.01669129729271, 105.05056902766228, 39.979919493198395, 32.82155200839043, 101.10517993569374, 74.20869559049606, 83.72433498501778, 62.692649737000465, 70.5840852856636, 67.23385825753212, 74.46330472826958, 64.307209700346, 72.48655200004578, 67.98928052186966, 71.14281490445137, 72.54996299743652, 73.56059476733208, 71.81192100048065, 71.18772089481354, 69.31000605225563, 72.75826781988144, 69.59240689873695, 71.51093915104866, 75.14812678098679, 87.36419007182121, 88.23193430900574, 91.87663033604622, 75.30688986182213, 75.89069053530693, 78.09542343020439, 81.46073564887047, 89.19971197843552, 86.16950377821922, 57.98173472285271, 16.655361279845238, 0.29883864568546414, 0.6083639804273844, 1.3894926966167986, 0.2996065904153511, 0.12303799157962203, 0.09733257873449475, 0.045495107187889516, 0.054666835349053144, 0.056872212517191656, 0.014492105074168649, 0.6997353618498892, 7.303191963583231, 24.92786318063736, 36.21412016451359, 49.22973275184631, 70.13925835490227, 53.58103886246681, 24.023745395243168, 18.27525995671749, 26.581323556602, 44.64218571782112, 49.07163463532925, 68.2349145412445, 66.2436617910862, 54.59591120481491, 26.747804023325443, 2.80801797285676, 0.20595773588865995, 0.061158026292105205, 0.05621628384687938, 0.025424053528695367, 0.029147963177820202, 0.016745677312428597, 0.04640210812794976, 0.06644394714385271, 0.07988097611814737, 0.04291259283490945, 0.02573208748799516, 0.04099098325241357, 0.01883311793790199, 0.04464963400096167, 0.02577570721769007, 0.014867844238324324, 0.011071866483689519, 0.023534577085229103, 0.02812590893881861, 0.02643925774464151, 0.06459686774178408, 0.034707853410509415, 0.03365865326486528, 0.01898526563309133, 0.03874986054142937, 0.028220590284036007, 0.012776636285707355, 0.05975950836727861, 0.037054576314403675, 0.02497742163541261, 0.03073400141147431, 0.046368856201297604, 0.030028938854229636, 0.02731235737883253, 0.0957970306626521, 0.04574528516968712, 0.009293903294746997, 0.05064617238531355, 0.0574425196100492, 0.026223268650937825, 0.0532511107303435, 0.04635076635167934, 0.022181109379744157, 0.04035818361444399, 0.04024558496894315, 0.05106658791191876, 0.07508567054173909, 0.010708947920647915, 0.02177242720790673, 0.0545258643978741, 0.04644069238565862, 0.03135657054372132, 0.0720461379387416, 0.05824429143103771, 0.024935926303442102, 1.0090719535946846, 69.73537042737007, 135.2190425992012, 111.73800498247147, 115.55040881037712, 85.14002501964569, 76.63976714015007, 48.07491011917591, 33.458017855882645, 41.88229501247406, 44.5134562253952, 45.515846237540245, 40.59432752430439, 38.65208074450493, 14.032754357904196, 0.1297497228370048, 0.021062138075649273, 0.10299822315573692, 0.18993473786395043, 0.25701028236653656, 0.5465187958907336, 0.5522832053247839, 2.213717275299132, 2.6943793706595898, 1.1745486804284155, 6.378694446757436, 23.292347341775894, 57.8928042948246, 94.60290804505348, 90.16489818692207, 89.79627996683121, 89.29333135485649, 92.75517359375954, 92.36436456441879, 91.18129804730415, 86.45432129502296, 76.91237971186638, 70.22382661700249, 74.2947381734848, 72.84791260957718, 73.60059142112732, 71.93932816386223, 70.40155827999115, 71.08723908662796, 83.87415334582329, 91.05012148618698, 94.7954361140728, 89.79444846510887, 95.80212369561195, 87.1797251701355, 85.24858519434929, 72.78797462582588, 77.2363731265068, 80.95257371664047, 88.85045751929283, 87.18717277050018, 98.83878394961357, 87.49630138278008, 99.2060874402523, 88.00872668623924, 107.34392836689949, 44.81708653271198, 37.92156234383583, 102.45183527469635, 79.28818702697754, 86.91259950399399, 66.48910582065582, 74.78576302528381, 69.57476824522018, 75.97040265798569, 68.1833665072918, 72.96673223376274, 71.59974798560143, 73.28846096992493, 77.20693990588188, 77.35632508993149, 75.96774280071259, 74.98256206512451, 74.2583817243576, 75.98557144403458, 70.9155111014843, 73.99232760071754, 78.21063324809074, 90.20241737365723, 91.3775347173214, 93.94956350326538, 78.87181296944618, 80.44725403189659, 83.43758717179298, 86.14194005727768, 89.51866686344147, 89.36703220009804, 67.1016101539135, 21.139436066150665, 0.762616228312254, 0.6759539223276079, 0.9785066905897111, 1.0471785650588572, 0.08161172387190163, 0.23057345330016688, 0.13161377515643835, 0.11208809242816642, 0.04982010264939163, 0.11794702921179123, 0.20779873710125685, 9.998793918639421, 31.065548434853554, 37.6514158397913, 36.15016579627991, 54.950557574629784, 43.83675813674927, 17.29411080479622, 36.5020877122879, 41.88501946628094, 59.10637177526951, 65.83434015512466, 81.44356817007065, 80.53033277392387, 68.0659756064415, 33.1695107370615, 3.2050444185733795, 0.12480796925956383, 0.03956046391976997, 0.05889216779905837, 0.062468544056173414, 0.025798793576541357, 0.058908880964736454, 0.04204292192298453, 0.04283389549527783, 0.02115061135555152, 0.05263823033601511, 0.0507111399929272, 0.10286764227203093, 0.04227767436532304, 0.03846726554911584, 0.09358719689771533, 0.09660859883297235, 0.0595114343741443, 0.04255713749444112, 0.026690851373132318, 0.054830961307743564, 0.0741037869011052, 0.051625321211759, 0.060950221231905743, 0.09371179607114755, 0.017606794972380158, 0.03670548860100098, 0.04082873863808345, 0.02857253155525541, 0.011325989908073097, 0.055832059151725844, 0.1698239310644567, 0.13947718602139503, 0.09959320508642122, 0.08889923556125723, 0.182215659879148, 0.2706894889706746, 0.13689336919924244, 0.15449503407580778, 0.16318951675202698, 0.13042633887380362, 0.1642957769217901, 0.09795496604056098, 0.07645387173397467, 0.10789590058266185, 0.11326451523927972, 0.2573158097220585, 0.24293283931910992, 0.21286972827510908, 0.06840422633104026, 0.16088848788058385, 0.19459941802779213, 0.19029451621463522, 0.2560546336462721, 0.16954899503616616, 0.14028909557964653, 2.341861599124968, 87.56144508719444, 149.54599142074585, 124.34743076562881, 134.5525887608528, 100.0553722679615, 82.29314178228378, 47.79734641313553, 34.710913226008415, 92.92722076177597, 91.91411912441254, 63.28374981880188, 67.8398497402668, 49.03081722557545, 19.344323091208935, 1.1837952467612922, 0.2318274453864433, 0.41886235994752496, 0.3190466738305986, 0.5358965252526104, 1.4503470249474049, 5.480620712041855, 12.70961880683899, 10.121338292956352, 4.510022643953562, 8.86450918391347, 22.41642214357853, 60.584602653980255, 99.34982612729073, 94.85627084970474, 94.74451884627342, 92.22536042332649, 92.16164544224739, 95.55627688765526, 94.94984462857246, 90.96123665571213, 82.49711483716965, 72.60582759976387, 77.38121375441551, 77.2542853653431, 79.08970847725868, 77.0778152346611, 73.64581659436226, 73.01648676395416, 87.46711134910583, 95.6142769753933, 99.38990637660027, 94.63232606649399, 103.26445206999779, 92.75991573929787, 89.33697581291199, 76.84481173753738, 81.98336720466614, 86.75927773118019, 94.30170580744743, 91.22536808252335, 102.89983883500099, 91.76917970180511, 104.3963049352169, 93.28959211707115, 110.77544063329697, 48.525429144501686, 43.661667332053185, 104.84288737177849, 83.80260318517685, 89.43775400519371, 71.19688600301743, 77.29369685053825, 75.87666928768158, 80.76535776257515, 71.09291598200798, 78.10053795576096, 75.62944695353508, 77.19009920954704, 82.36086934804916, 83.23134943842888, 81.9346234202385, 81.57802775502205, 80.37220045924187, 81.64893954992294, 76.20583042502403, 79.8824979364872, 84.10105437040329, 94.97168585658073, 97.46123626828194, 100.20734891295433, 84.61258292198181, 85.49378603696823, 86.48405849933624, 89.51077848672867, 94.34553265571594, 90.78867271542549, 65.03005251288414, 17.75903295725584, 1.155208193231374, 2.3882756335660815, 4.237968642264605, 4.1046171728521585, 1.268636619206518, 0.7399424293544143, 0.39838041993789375, 0.3333405271405354, 0.1777904262416996, 0.25143241917248815, 2.1653021732345223, 16.430097967386246, 42.4723881483078, 55.745889097452164, 69.60632175207138, 85.0739997625351, 66.67717292904854, 37.130608186125755, 31.179076842963696, 44.11717928946018, 71.94536983966827, 80.41574612259865, 97.82328084111214, 94.53314378857613, 79.98638436198235, 40.97418174147606, 5.149968629702926, 0.24455113685689867, 0.13422954885754734, 0.18749319075141102, 0.18729053990682587, 0.13386945880483836, 0.13754487095866352, 0.15447104786289856, 0.11837135214591399, 0.13921461417339742, 0.1491075466037728, 0.10471892222994938, 0.1809833533479832, 0.10777643707115203, 0.15092454676050693, 0.16023385425796732, 0.1486969311372377, 0.1413028544629924, 0.16458371537737548, 0.14264673547586426, 0.1319083632552065, 0.14783963182708248, 0.13851681724190712, 0.18651273945579305, 0.17963074467843398, 0.19930552487494424, 0.1018389142700471, 0.10228486338746734, 0.1406090206000954, 0.11006147266016342, 0.0810189259937033], [0.030531899756169878, 0.02681076202861732, 0.0897532026283443, 0.09170692865154706, 0.05927533493377268, 0.03189875766111072, 0.051748621626757085, 0.04734419038868509, 0.035826670718961395, 0.013420083887467626, 0.05385270305851009, 0.04751598273287527, 0.09080312636797316, 0.049419068309362046, 0.05729662821977399, 0.03895866379025392, 0.0832381627697032, 0.05176424754608888, 0.04013247053080704, 0.025297407883044798, 0.0845694421150256, 0.04113491166208405, 0.163585007248912, 0.09784451962332241, 0.011624372236838099, 40.343396589159966, 123.51791247725487, 99.43785220384598, 107.10008025169373, 70.07390186190605, 62.38081946969032, 23.129412084817886, 20.73917504400015, 70.10664850473404, 76.34807199239731, 63.245216086506844, 53.5288904607296, 39.593666419386864, 16.317772194743156, 0.572038582758978, 0.03339913164381869, 0.15832191857043654, 0.14638542314060032, 0.013875184613425517, 0.23232734121847898, 0.3799049503868446, 0.3993054328020662, 1.238333957735449, 2.106312238611281, 8.264427334070206, 29.345025457441807, 72.7570290863514, 91.5846312046051, 83.70532840490341, 88.1199087202549, 89.48907405138016, 91.34425610303879, 88.18610116839409, 86.35716810822487, 92.09370508790016, 82.78196275234222, 77.63934150338173, 72.04209744930267, 69.06838461756706, 65.59581935405731, 67.01985374093056, 65.68897515535355, 66.20294317603111, 63.91107335686684, 69.78191033005714, 82.25230157375336, 87.58958637714386, 83.20723593235016, 80.30772551894188, 74.88238424062729, 66.34702384471893, 62.03824505209923, 66.60015866160393, 69.75835159420967, 75.09255856275558, 76.25873878598213, 84.02733832597733, 78.74403342604637, 85.47144323587418, 76.15061938762665, 89.98557820916176, 72.09996834397316, 38.13566945493221, 98.10697361826897, 78.79438072443008, 85.34307852387428, 70.16068160533905, 70.70733547210693, 74.12298738956451, 79.46721822023392, 70.15893369913101, 67.06891670823097, 70.1860186457634, 73.07333171367645, 72.87858456373215, 75.74787899851799, 72.2694544494152, 70.97549468278885, 66.70780688524246, 70.33943921327591, 65.57525485754013, 67.57872775197029, 71.63662120699883, 77.26076021790504, 77.18413352966309, 70.39212718605995, 62.44786687195301, 68.38259741663933, 78.67968767881393, 89.10744532942772, 79.86748114228249, 79.98633116483688, 90.94793736934662, 94.84198361635208, 44.06922586262226, 3.7057943735271692, 1.0053119366057217, 0.8573197340592742, 0.4950026742881164, 0.07988154757185839, 0.01897229845781112, 0.15805997012648731, 0.09336960662039928, 0.055739520757924765, 0.07326953869778663, 1.1617299495264888, 8.553739059716463, 25.442327074706554, 32.266865372657776, 43.92016366124153, 59.14488270878792, 88.00257861614227, 19.827482365071774, 17.970242723822594, 20.389622300863266, 32.84274347126484, 55.99955968558788, 66.50458618998528, 72.90792658925056, 65.22063508629799, 36.75176091492176, 3.7626970326527953, 0.09542524436255917, 0.05747138544393238, 0.08216162561438978, 0.06507441008579917, 0.06438461350626312, 0.028916398259752896, 0.038030311261536554, 0.07156046907766722, 0.018395278639218304, 0.053515118634095415, 0.06108481713454239, 0.04035697020299267, 0.022450295618909877, 0.09360957265016623, 0.03584505742765032, 0.04110296591534279, 0.05144374736119062, 0.03860344964778051, 0.06937313723028637, 0.022130945762910414, 0.047713126841699705, 0.0858671689638868, 0.03006277522217715, 0.02992801233631326, 0.010805003166751703, 0.05550496127398219, 0.04733394875074737, 0.04051911462738644, 0.052474575641099364, 0.07590969195007347, 0.04289588709070813, 0.056706902832956985, 0.06435076415073127, 0.06081292020098772, 0.024826361186569557, 0.03393785664229654, 0.037658510118490085, 0.0605748948873952, 0.03516571028740145, 0.028003499101032503, 0.06154521586722694, 0.05191036529140547, 0.016836182221595664, 0.042953273659804836, 0.04812156410480384, 0.058528678709990345, 0.08195659989723936, 0.03978095599450171, 0.009504299378022552, 0.03307132130430546, 0.02506831802747911, 0.0876521528698504, 0.036966179104638286, 0.036032234493177384, 50.52377991378307, 140.7413774728775, 111.18113726377487, 118.11439722776413, 87.90352553129196, 85.97744688391685, 43.37265104055405, 34.56698834896088, 40.02241261303425, 76.86143204569817, 56.47002764046192, 42.01791353523731, 45.540191531181335, 21.614739261567593, 0.7312915998045355, 0.0355892168590799, 0.14331221929751337, 0.20841783669311553, 0.32286074885632843, 0.5033253261353821, 0.39674294530414045, 0.33190933987498283, 0.9973150282166898, 0.6163069792091846, 10.564221628010273, 34.73761439323425, 74.79957148432732, 96.03450402617455, 87.11432307958603, 91.99301809072495, 92.9158441722393, 96.49149030447006, 90.99072307348251, 88.20023640990257, 95.99882394075394, 85.88330313563347, 80.68949103355408, 75.69605737924576, 71.76281243562698, 67.66700461506844, 70.051559060812, 68.34837645292282, 70.25528132915497, 66.95886701345444, 73.33554044365883, 85.95318898558617, 91.61741584539413, 87.36133262515068, 84.21029090881348, 79.58985283970833, 71.14998891949654, 65.26076093316078, 69.93344619870186, 72.29629620909691, 77.86387145519257, 78.56602817773819, 85.6806980073452, 83.23391050100327, 89.3448793888092, 80.90202122926712, 89.76425528526306, 76.33533507585526, 41.73088453710079, 100.66366642713547, 85.87529316544533, 91.87295213341713, 73.68097230792046, 72.48497888445854, 77.99671992659569, 82.07383275032043, 74.94435891509056, 69.96154949069023, 73.64231318235397, 75.58175191283226, 76.87112912535667, 79.83417972922325, 74.51813578605652, 73.93118128180504, 70.32854899764061, 74.21745792031288, 68.88925462961197, 72.83654361963272, 75.54356396198273, 80.54051622748375, 80.67083403468132, 72.8582252562046, 67.71875023841858, 71.84912860393524, 81.49510100483894, 92.88113683462143, 83.20580720901489, 79.94428262114525, 94.78595942258835, 99.8270121216774, 52.33297683298588, 5.337632009759545, 0.3914104064460844, 0.31177344848401845, 0.7355582364834845, 0.05022170844313223, 0.06337713319226168, 0.25874316750559956, 0.24548116663936526, 0.0837744609452784, 0.04412043446791358, 0.9867012477479875, 9.54856462776661, 29.98504601418972, 31.724731363356113, 30.473979078233242, 40.92372044920921, 65.88750690221786, 19.86800719052553, 32.57286675274372, 40.90599440038204, 46.029764860868454, 70.80776408314705, 75.63792809844017, 83.89695972204208, 79.27456855773926, 46.923119723796844, 5.343461371958256, 0.09762213507201523, 0.04293787409551442, 0.026977235029335134, 0.028441047106753103, 0.020619023962353822, 0.029454830109898467, 0.0072514108433097135, 0.048949741540127434, 0.005999538516334724, 0.07931079147965647, 0.040784643933875486, 0.02273741214594338, 0.06426724285120144, 0.05216541547270026, 0.05338511662557721, 0.028717532368318643, 0.04199754701403435, 0.0902961430256255, 0.05195905388973188, 0.05324536279658787, 0.029614018931169994, 0.02709684140427271, 0.04739146890642587, 0.05934869252087083, 0.05584613398241345, 0.011060072829423007, 0.05841332669660915, 0.03722640947671607, 0.021040018364146817, 0.29657696548383683, 0.12986190587980673, 0.15228689240757376, 0.25134852679912, 0.22927190439077094, 0.14589875238016248, 0.16415050893556327, 0.16053996048867702, 0.12594419735250995, 0.11764518290874548, 0.10150702582905069, 0.25454133516177535, 0.25239741895347834, 0.099602682312252, 0.23500195238739252, 0.11692517349729314, 0.16423843859229237, 0.20975603285478428, 0.1433418903616257, 0.11602829545154236, 0.2012332683079876, 0.18089304881868884, 0.3514458431163803, 0.22474284429335967, 0.170018314383924, 64.22338619828224, 159.51826751232147, 122.8971853852272, 137.67957776784897, 96.18501394987106, 90.10279431939125, 35.94520479440689, 30.124772116541862, 94.09941226243973, 98.56135323643684, 80.74680715799332, 82.03996896743774, 64.59715694189072, 30.428068041801453, 1.5717762778513134, 0.07691163584240712, 0.5078936903737485, 0.2890344295883551, 0.37665481853764504, 0.8302131167147309, 1.8851996096782386, 1.8605975923128426, 5.24684015661478, 6.7927582282572985, 12.64077790081501, 34.092640802264214, 76.03025704622269, 98.62561538815498, 95.88625118136406, 99.87329363822937, 98.19778114557266, 102.04965725541115, 94.46540862321854, 87.7352325618267, 99.34846580028534, 89.18528035283089, 85.71892395615578, 79.03245314955711, 75.56696310639381, 71.32315322756767, 73.52523386478424, 71.03423193097115, 71.183662712574, 69.40889954566956, 74.90255355834961, 92.21264630556107, 95.86208447813988, 91.09354555606842, 89.02814358472824, 84.57156792283058, 75.48363357782364, 69.72773283720016, 75.01422956585884, 78.32942247390747, 83.92135441303253, 83.33010613918304, 92.32607781887054, 88.75911802053452, 96.27323761582375, 85.48202946782112, 95.72832405567169, 81.51796817779541, 46.97461076080799, 103.71899887919426, 90.85587590932846, 93.43725219368935, 79.32499945163727, 78.38682219386101, 82.05240949988365, 86.15468457341194, 79.91807922720909, 73.66156294941902, 76.31197392940521, 79.77824673056602, 81.09452649950981, 83.13814043998718, 81.21089905500412, 77.2724711894989, 74.85816434025764, 78.57226744294167, 74.39635992050171, 76.6632042825222, 80.39091065526009, 86.99205324053764, 87.20168799161911, 78.42438697814941, 70.83568498492241, 75.39345681667328, 88.53635877370834, 98.74653249979019, 83.09753581881523, 81.54071375727654, 99.29275318980217, 106.92405089735985, 51.88009433448315, 4.338222937658429, 3.5815963754430413, 2.836497207172215, 1.8007370294071734, 0.17299471248406917, 0.3618361777625978, 0.6683649576734751, 1.2346386560238898, 0.183133251266554, 0.2292511539417319, 1.9848074647597969, 17.239654026925564, 42.497311010956764, 52.900309190154076, 60.78061133623123, 74.12153586745262, 109.66137081384659, 30.837940648198128, 29.729870706796646, 35.45156188309193, 54.88890968263149, 82.5661951303482, 90.89679971337318, 95.44988259673119, 88.22007894515991, 54.38028797507286, 6.534223901107907, 0.16418215411249548, 0.20121464040130377, 0.22555303206900135, 0.15157918038312346, 0.10461300291353837, 0.1398194645298645, 0.06790823419578373, 0.09021884834510274, 0.11246099194977432, 0.2060307186911814, 0.12898768560262397, 0.13058906217338517, 0.16863330354681239, 0.1804783070110716, 0.105578655784484, 0.18471030023647472, 0.09983560536056757, 0.27398201229516417, 0.19896511657861993, 0.13964102254249156, 0.11509862189996056, 0.12102599212084897, 0.11682496129651554, 0.11953598965192214, 0.1639740410610102, 0.12322300157393329, 0.16630674479529262, 0.09195323262247257, 0.19897529884474352], [0.027198675197723787, 0.044044939495506696, 0.00437283198152727, 0.03335876994242426, 0.025884517199301627, 0.05320130519976374, 0.08145028448780067, 0.05913188520935364, 0.06355665129376575, 0.018186744418926537, 0.03747182658116799, 0.012448432607925497, 0.050412844866514206, 0.022517883007822093, 0.03501188533846289, 0.0413319852668792, 0.05452358971524518, 0.09249016162357293, 0.046392935182666406, 0.09632986300857738, 0.03360475107911043, 0.21113758528372273, 0.09846662491327152, 0.12858652509748936, 14.239310324192047, 109.05541732907295, 102.75591015815735, 101.37951001524925, 86.19389086961746, 58.750368878245354, 19.00088422000408, 35.69260574877262, 73.67015048861504, 85.56753247976303, 43.98347966372967, 42.47743807733059, 37.063302397727966, 14.16711039841175, 0.28254069678951055, 0.06850524005130865, 0.015174922682490433, 0.038758369264542125, 0.22074602282373235, 0.1102344153332524, 0.06829668913269415, 0.18309271516045555, 0.02240635676571401, 0.3876850032247603, 6.843713968992233, 30.46228140592575, 71.94672256708145, 97.12487831711769, 83.25850278139114, 89.16737571358681, 84.13962990045547, 81.11213475465775, 84.59504306316376, 90.12362480163574, 86.57958537340164, 89.66815084218979, 87.84830689430237, 85.31673073768616, 81.42339885234833, 77.09768056869507, 72.93941169977188, 62.06843063235283, 63.20337273180485, 65.10743156075478, 64.41111892461777, 63.69287386536598, 65.60070589184761, 74.11821484565735, 74.17875319719315, 69.66586455702782, 62.58805654942989, 63.93106788396835, 63.5820984095335, 65.44894963502884, 64.75996300578117, 68.17991629242897, 65.86529329419136, 66.90497070550919, 67.08519503474236, 65.10886788368225, 70.91497153043747, 80.18341138958931, 85.05845859646797, 38.68053361773491, 79.74939107894897, 85.86380258202553, 84.72045913338661, 77.33303233981133, 67.83402845263481, 79.67363074421883, 83.02887350320816, 77.18624621629715, 66.20000213384628, 64.9211123585701, 71.39087319374084, 73.03422421216965, 76.42749533057213, 73.0740612745285, 70.93702554702759, 68.61921831965446, 67.30320453643799, 63.71048592031002, 66.99461549520493, 66.08835652470589, 64.69076871871948, 60.491184666752815, 61.93458281457424, 67.75387555360794, 77.23409324884415, 81.21318653225899, 84.67150256037712, 79.69158858060837, 87.6247800886631, 82.59248971939087, 80.67043885588646, 92.11670905351639, 51.765716671943665, 3.985627507790923, 0.23049619572702795, 0.4565876559354365, 0.14459638710832223, 0.04587284922308754, 0.1718125306069851, 0.13679680094355717, 0.0714113493449986, 0.0856859958730638, 0.059798241054522805, 0.8265624032355845, 7.259454885497689, 22.446609623730183, 39.325959384441376, 49.47818621993065, 60.45363888144493, 89.18839618563652, 25.749449394643307, 10.439830552786589, 20.2937800437212, 30.049361363053322, 56.81367740035057, 62.99806974828243, 72.535789757967, 79.05836015939713, 36.15372620522976, 1.6629643784835935, 0.07604304104461335, 0.014894594023644459, 0.051700571275432594, 0.0672724362812005, 0.05812949973915238, 0.0027361308048057253, 0.004900301846646471, 0.06687814064207487, 0.010438405406603124, 0.021998919546604156, 0.05362344250897877, 0.0911165279103443, 0.01545657421957003, 0.10027524622273631, 0.06303469883278012, 0.03999540698714554, 0.01780033595423447, 0.02859065294614993, 0.08099416794721037, 0.0376621800387511, 0.031118500701268204, 0.050797088115359657, 0.011878562454512576, 0.04920766383293085, 0.07601769670145586, 0.01634596956137102, 0.07342861063079908, 0.0101699947117595, 0.012399541774357203, 0.05206892514252104, 0.06576185405720025, 0.0360501350951381, 0.024148667180270422, 0.013170952333894093, 0.03317177470307797, 0.029914238075434696, 0.010057621493615443, 0.05370213242713362, 0.09761889930814505, 0.06425118277547881, 0.04298829189792741, 0.010966086319967872, 0.08410891721723601, 0.05830852431245148, 0.024269438727060333, 0.09286227446864359, 0.012673692053795094, 0.10528311031521298, 0.02646749089763034, 0.12764144456014037, 0.2247091953177005, 0.17901789397001266, 17.74782355874777, 127.71333575248718, 115.41716516017914, 115.23126393556595, 96.28900676965714, 76.61864027380943, 42.58015036582947, 46.951443403959274, 47.84223720431328, 82.14171230792999, 46.98552757501602, 43.16464640200138, 48.08298848569393, 19.41856350749731, 0.07583621190860868, 0.05962321665720083, 0.17174354055896401, 0.033162713079946116, 0.3678262000903487, 0.2118934181635268, 0.07025570666883141, 0.26727356133051217, 0.4633573192404583, 0.8559316804166883, 7.942760344594717, 34.39467519521713, 76.40353381633759, 102.68536314368248, 89.20824632048607, 93.21246385574341, 87.84442350268364, 83.87297540903091, 89.77441594004631, 92.78561756014824, 88.25939923524857, 91.22007116675377, 91.55137538909912, 88.9740800857544, 84.24943640828133, 80.52001252770424, 76.66623651981354, 66.60637512803078, 65.88973358273506, 67.426697909832, 66.26581460237503, 65.20434156060219, 69.36437353491783, 78.02200376987457, 76.10575899481773, 72.55108013749123, 65.82018211483955, 67.33098104596138, 67.69690901041031, 67.88268864154816, 68.98236483335495, 70.27095168828964, 69.60888281464577, 70.15759617090225, 70.27595981955528, 66.9624388217926, 75.05931034684181, 83.18434596061707, 87.5321714580059, 40.31405836343765, 81.57702460885048, 91.03639662265778, 86.5651385486126, 78.81366848945618, 71.68162599205971, 83.06247130036354, 87.67788603901863, 79.34053301811218, 69.14741277694702, 66.82790324091911, 74.11614775657654, 75.48413515090942, 79.58376556634903, 77.87391811609268, 75.36305844783783, 72.17448234558105, 70.08592441678047, 68.27844500541687, 69.73315894603729, 68.5389818251133, 67.73692086338997, 65.83986505866051, 65.23575827479362, 70.42718410491943, 80.10611593723297, 84.69906628131866, 87.07153737545013, 79.49496433138847, 90.00954732298851, 87.56009995937347, 84.63790476322174, 94.7675684094429, 60.61000809073448, 5.2234680857509375, 0.856138828676194, 0.02906938458181685, 0.34483318857382983, 0.06289974669925869, 0.30171966296620667, 0.1742968402686529, 0.061979758174857125, 0.07450730743585154, 0.054685600553057157, 0.7547649589832872, 7.603093245998025, 27.56118457764387, 45.613174214959145, 45.56629233062267, 57.437011152505875, 60.20206958055496, 19.37258407473564, 19.3532545119524, 34.69591163098812, 46.164182648062706, 65.58926090598106, 74.52775686979294, 83.37073355913162, 92.78185576200485, 47.81808190047741, 2.3386790324002504, 0.08815966313704848, 0.07425845789839514, 0.016152209645952098, 0.07527796100475825, 0.041796974182943814, 0.027855325606651604, 0.01762320942361839, 0.04375765041913837, 0.007775925569148967, 0.030094060457486194, 0.07200064428616315, 0.05137596701388247, 0.04450748674571514, 0.05655438406392932, 0.034551646167528816, 0.06672585936030373, 0.03760884559596889, 0.0256366231769789, 0.0763707140868064, 0.008367239151994, 0.028936241433257237, 0.012063523281540256, 0.022214509735931642, 0.03491770679829642, 0.12151022121543065, 0.019736408139578998, 0.030504052519972902, 0.07168612952227704, 0.10051969482447021, 0.19603758148150519, 0.11667660597595386, 0.15244958602124825, 0.13774542894680053, 0.12730157061014324, 0.17307510192040354, 0.09500337793724611, 0.11098336850409396, 0.06932422227691859, 0.16421130567323416, 0.13699906587135047, 0.0976381877262611, 0.1629440885153599, 0.2511852839961648, 0.1179343755939044, 0.165841136185918, 0.1570105881546624, 0.19027009955607355, 0.17502147326013073, 0.2289627998834476, 0.3909741423558444, 0.4345158574869856, 0.3289534547366202, 25.148568637669086, 145.5150157213211, 127.6421731710434, 131.97819650173187, 109.6245051920414, 86.5575161576271, 34.18446287512779, 53.38558115065098, 95.34856483340263, 106.52424395084381, 62.263299375772476, 65.55332243442535, 60.690803155303, 25.604502372443676, 0.6338436913210899, 0.294602140202187, 0.6047719856724143, 0.18393248494248837, 0.5452013353351504, 0.45444418501574546, 2.4988079024478793, 0.8733427023980767, 0.9410432539880276, 1.7858981131576002, 10.742422565817833, 34.29627187550068, 80.08007973432541, 108.93701568245888, 92.328350096941, 100.28796538710594, 94.43026810884476, 89.41414967179298, 94.39106181263924, 96.75768122076988, 88.69070649147034, 96.56931012868881, 96.228346824646, 94.28662821650505, 88.65782305598259, 83.8971497118473, 80.63347443938255, 68.52726325392723, 69.89864006638527, 70.25449857115746, 70.87927624583244, 67.53578245639801, 71.80809080600739, 83.43191787600517, 82.06238776445389, 76.11194506287575, 68.27061742544174, 71.79055854678154, 71.34105026721954, 71.49491161108017, 72.68330544233322, 74.93611335754395, 74.77943256497383, 74.03423935174942, 75.06843745708466, 71.30294591188431, 78.98178666830063, 88.78633975982666, 92.82886683940887, 45.378848388791084, 84.3783786892891, 93.19490879774094, 90.17963379621506, 84.06137689948082, 73.61685454845428, 87.47889831662178, 89.48012173175812, 85.51379576325417, 72.73090168833733, 70.71026891469955, 79.33854952454567, 80.25309205055237, 84.45370584726334, 82.46934592723846, 79.58678260445595, 78.26492473483086, 74.42365005612373, 71.94863006472588, 74.91731956601143, 72.56766244769096, 71.69570803642273, 69.58228424191475, 69.70618799328804, 74.62295696139336, 86.56503215432167, 88.6118683218956, 92.3690003156662, 81.17850199341774, 93.73144000768661, 91.17903336882591, 87.67993032932281, 100.90600982308388, 65.1807676255703, 5.605175653472543, 1.4123666379600763, 1.3419691217131913, 0.515555979218334, 0.2957275923108682, 0.6953144771978259, 0.42099802347365767, 0.2710780478082597, 0.4157618450699374, 0.15305608394555748, 1.6911525721661747, 14.800071883946657, 39.95652794837952, 62.89015933871269, 68.19649860262871, 71.98703080415726, 112.41551622748375, 36.68694779276848, 19.134091772139072, 33.47408339381218, 48.96402060985565, 83.06824699044228, 88.87008726596832, 94.58776965737343, 102.93144553899765, 55.1120413094759, 3.262762133963406, 0.20624886557925493, 0.167539541143924, 0.15921478159725666, 0.13376684946706519, 0.14301237679319456, 0.09125895347096957, 0.1469473328324966, 0.15270957519533113, 0.12298165514948778, 0.13390046573476866, 0.12627359217731282, 0.12415850840625353, 0.14632493810495362, 0.11744421673938632, 0.16080217610578984, 0.10695109463995323, 0.10795902766403742, 0.22976756998104975, 0.15395075781270862, 0.18155519297579303, 0.1669072758522816, 0.13024743675487116, 0.08532923806342296, 0.17330531612969935, 0.18210959213320166, 0.17239186592632905, 0.12479061784688383, 0.18361820024438202], [0.08274584426544607, 0.01910103139380226, 0.04943626387102995, 0.06178619121783413, 0.10292253893567249, 0.029809864281560294, 0.051411760796327144, 0.021803701311000623, 0.006800131714044255, 0.021630454357364215, 0.13830272248014808, 0.02092581296892604, 0.015446339075424476, 0.05293759786582086, 0.010955108100461075, 0.04699109136709012, 0.0562587940657977, 0.024640660994919017, 0.016071039099188056, 0.02002279736188939, 0.0614402984501794, 0.21011085365898907, 0.04966986227373127, 4.270412726327777, 80.68634480237961, 105.80964669585228, 100.41503816843033, 84.78187143802643, 64.67089578509331, 30.53029205650091, 28.347970359027386, 54.32266406714916, 107.65113428235054, 49.88319128751755, 61.78228318691254, 35.67937485873699, 15.131463501602411, 0.33760645135771483, 0.0723422177543398, 0.13056488300208002, 0.1597849588142708, 0.07502935637603514, 0.14487871492747217, 0.1924559471081011, 0.3490964707452804, 0.20408397627761588, 0.22892411914654076, 1.8656629580073059, 27.02384401112795, 73.2152085006237, 94.89831939339638, 84.30543020367622, 86.53952792286873, 79.58296000957489, 76.49413615465164, 77.57533773779869, 88.02467063069344, 86.68186828494072, 85.86246505379677, 84.13338303565979, 85.98790392279625, 84.8092071712017, 84.57719162106514, 81.67784839868546, 81.822719424963, 72.01521769165993, 65.06642416119576, 65.02396523952484, 64.70143854618073, 62.823412120342255, 63.74875746667385, 61.7798513174057, 63.68074111640453, 62.01088272035122, 64.74591135978699, 63.73514659702778, 63.46365496516228, 61.60487450659275, 64.84219059348106, 61.05317071080208, 61.57022036612034, 58.59256334602833, 61.57311201095581, 63.021970465779305, 69.40392941236496, 74.66030895709991, 88.49864199757576, 35.06946578621864, 74.30467084050179, 86.47743165493011, 81.18651196360588, 75.03961220383644, 72.24288627505302, 81.30086302757263, 81.49428024888039, 78.39169353246689, 67.87605419754982, 61.77234672009945, 65.0064405798912, 72.18767523765564, 70.41905254125595, 65.55648386478424, 63.16122159361839, 63.23584958910942, 65.08106097579002, 64.10499215126038, 62.050085216760635, 63.03324066102505, 61.01238749921322, 65.3149764239788, 71.88423871994019, 78.31594839692116, 78.17250609397888, 82.93513253331184, 83.04275035858154, 78.21454703807831, 85.35795852541924, 81.79539889097214, 83.73594716191292, 78.4074854850769, 89.63603496551514, 47.65651077032089, 0.6686464988160878, 0.3950450598495081, 0.13727006851695478, 0.1073659626126755, 0.04483758290007245, 0.11484888920676894, 0.07123685558326542, 0.059394731651991606, 0.13723512820433825, 0.02739301027759211, 0.07172598285251297, 1.405961369164288, 11.499777026474476, 25.39055485278368, 36.044474467635155, 58.47513444721699, 76.96566045284271, 50.17724610865116, 16.482354663312435, 19.46653213351965, 34.525543972849846, 43.290704637765884, 69.50067982077599, 75.10675460100174, 73.12744081020355, 27.34893176704645, 0.8490067895036191, 0.02748139449977316, 0.06455032766098157, 0.07323698067921214, 0.09583157763700001, 0.04994141781935468, 0.01882112854218576, 0.041550269452272914, 0.019845535389322322, 0.005926177682340494, 0.04285246403014753, 0.03980100511398632, 0.061170178960310295, 0.03835424387943931, 0.04935376302455552, 0.0526281631027814, 0.030927525695005897, 0.039125305629568174, 0.06061412481358275, 0.045506317328545265, 0.058342633419670165, 0.0342094233201351, 0.03599025490984786, 0.02618112208438106, 0.04518861504038796, 0.01756722922436893, 0.04054128999996465, 0.04590840922901407, 0.012597830645972863, 0.019209136335121002, 0.014525215992762242, 0.08493170666042715, 0.11364216450601816, 0.008338530096807517, 0.027173321577720344, 0.06223651158506982, 0.03923207099433057, 0.04420697259774897, 0.04470175874303095, 0.017921088947332464, 0.05221439350862056, 0.03727584393345751, 0.016017788148019463, 0.03385725569387432, 0.05861372141225729, 0.06060099993192125, 0.0037903446218479075, 0.014143034986773273, 0.043798954648082145, 0.15050236863316968, 0.045551955699920654, 5.439515467733145, 98.23385640978813, 120.36180183291435, 112.18973994255066, 95.5132631957531, 85.07895469665527, 52.19319373369217, 34.03216324746609, 45.88715851306915, 100.45952618122101, 51.71922616660595, 55.35604901611805, 45.84117718040943, 17.508854381740093, 0.24469189258525148, 0.11774540995247662, 0.160940156201832, 0.18893910222686827, 0.11004426225554198, 0.11668036866467446, 0.17209239449584857, 0.8151365944650024, 0.21693864197004586, 0.06496627174783498, 2.091457648202777, 30.116129480302334, 75.57224482297897, 99.24894154071808, 86.89156383275986, 89.60951238870621, 84.26048621535301, 77.5240632891655, 81.89007461071014, 91.18698254227638, 91.63795754313469, 86.68444454669952, 88.46118360757828, 86.8935777246952, 88.62957537174225, 89.12493959069252, 86.462582051754, 85.13390734791756, 76.8949082493782, 68.24050784111023, 68.95142689347267, 69.36273962259293, 64.70026820898056, 66.39075949788094, 63.159534484148026, 65.4917049407959, 66.23106926679611, 67.93642535805702, 67.64444142580032, 67.75294080376625, 66.67305395007133, 69.61335137486458, 64.57745879888535, 64.10926312208176, 61.69934883713722, 65.77121034264565, 66.53607130050659, 73.46189126372337, 78.69902104139328, 92.52825736999512, 37.79624506831169, 76.99111148715019, 91.5216837823391, 83.21599066257477, 79.52217847108841, 75.26213586330414, 85.69482564926147, 84.5429402589798, 83.50887134671211, 70.76186254620552, 65.84541276097298, 66.56781479716301, 75.4563282430172, 74.23296868801117, 69.74227085709572, 65.70294320583344, 65.94693571329117, 67.06271544098854, 69.36809733510017, 65.26468992233276, 65.98912864923477, 66.20725974440575, 70.26204496622086, 76.70777589082718, 84.77926477789879, 83.80706414580345, 87.61968076229095, 83.281529545784, 79.40196812152863, 88.95274803042412, 85.37025466561317, 87.01183497905731, 83.52647200226784, 94.85124751925468, 56.557343155145645, 0.46733917901292443, 0.9247211704496294, 0.05783106360468082, 0.10449442997924052, 0.14894817781168967, 0.06100512902776245, 0.06523800911963917, 0.023876898267189972, 0.10362409855588339, 0.06195996880705934, 0.25982619845308363, 0.7693252433091402, 12.285666055977345, 31.1630018055439, 28.718805760145187, 55.47917380928993, 52.8199815005064, 23.654845990240574, 17.880155257880688, 33.17901782691479, 54.901825189590454, 52.65412040054798, 79.89110067486763, 84.55722749233246, 88.26991707086563, 37.74706810712814, 0.8411658508703113, 0.09202877583447844, 0.017822845293267164, 0.03516660457535181, 0.025617002647777554, 0.037745564040960744, 0.02193513009842718, 0.022936359673622064, 0.0750073442759458, 0.02326876205188455, 0.03957112116040662, 0.018885181452787947, 0.05664397613145411, 0.03519937781675253, 0.01943089006090304, 0.04070632880029734, 0.019519869856594596, 0.028084061086701695, 0.02687232132302597, 0.020869658364972565, 0.04593296689563431, 0.030696263202116825, 0.04174332061666064, 0.04582548535836395, 0.030405020334001165, 0.013696925379917957, 0.04099795572983567, 0.03638558213424403, 0.12096820850274526, 0.07316015355172567, 0.18254867638461292, 0.14496391348075122, 0.27410500100813806, 0.13721682684263214, 0.14142942032776773, 0.16574772947933525, 0.08963252199464478, 0.1079708500765264, 0.16759441554313526, 0.1284149257116951, 0.10693688993342221, 0.22758737759431824, 0.2083622943609953, 0.16653983853757381, 0.21507537632714957, 0.15690325875766575, 0.079239144542953, 0.05956524379143957, 0.2880030224332586, 0.3336047910852358, 0.29822346463333815, 8.2584198564291, 114.96291473507881, 133.63329648971558, 128.38506370782852, 110.6808789074421, 89.62151974439621, 46.999267637729645, 39.71544608473778, 77.32957452535629, 135.6150421500206, 67.25943088531494, 89.55893710255623, 59.019158855080605, 27.84357212483883, 0.9792456321883947, 0.3585213009500876, 0.7296509784646332, 0.3254483506316319, 0.25837954482994974, 0.5732339748647064, 2.4086496653035283, 1.8805119674652815, 1.53572179377079, 0.7432963431347162, 2.990168798714876, 31.469734646379948, 77.936622351408, 105.08607432246208, 92.29312598705292, 95.40738567709923, 89.78325426578522, 83.16606134176254, 87.93749570846558, 96.32652595639229, 96.21466755867004, 87.71236538887024, 89.52027797698975, 89.63198438286781, 92.18829721212387, 92.28862702846527, 90.98934754729271, 88.94461646676064, 81.99548855423927, 71.84217497706413, 71.26530513167381, 72.53400385379791, 68.23179870843887, 71.42627209424973, 68.37058246135712, 70.51489099860191, 67.93904721736908, 71.28593802452087, 69.65353041887283, 70.35292088985443, 71.48907512426376, 72.16422289609909, 68.50824907422066, 69.14089992642403, 66.0154840350151, 67.4709503352642, 71.05652153491974, 75.94967857003212, 83.6897112429142, 97.3703983426094, 43.901096284389496, 79.66055184602737, 95.68851739168167, 89.69018206000328, 83.13195437192917, 80.25609388947487, 87.06342861056328, 88.3591590821743, 87.593994140625, 74.96919438242912, 68.18098023533821, 70.82943052053452, 79.19954538345337, 78.51872071623802, 74.22663822770119, 67.65318855643272, 68.54527428746223, 72.07004114985466, 74.05270636081696, 69.54309314489365, 68.74198973178864, 70.34092873334885, 74.12840589880943, 79.70629379153252, 87.25135132670403, 87.6017153263092, 91.09051331877708, 88.7564505636692, 80.42871102690697, 93.71108070015907, 90.64113423228264, 92.56415784358978, 86.3556481897831, 98.49334448575974, 61.78540661931038, 1.1299421614967287, 1.5161156770773232, 0.5467786663211882, 0.30771903635468334, 0.357509249006398, 0.5186701496131718, 0.40800381917506456, 0.3128075273707509, 0.4106783412862569, 0.11366700418875553, 0.5620416160672903, 2.9423184413462877, 21.41750894486904, 43.91836255788803, 53.35362106561661, 70.42719930410385, 104.51259389519691, 69.56821739673615, 26.38522367924452, 31.523625254631042, 55.031516030430794, 65.89659601449966, 92.68050760030746, 96.213937997818, 99.70476508140564, 43.19117657840252, 1.0140997963026166, 0.1779819597140886, 0.13444998156046495, 0.1657589804381132, 0.19587264658184722, 0.07655897468794137, 0.13981701544253156, 0.13283324253279716, 0.1451082166749984, 0.08488367486279458, 0.13141339528374374, 0.10735495656263083, 0.1506499818060547, 0.15958076430251822, 0.19562635745387524, 0.12247181453858502, 0.09027847248944454, 0.16409561969339848, 0.11004949439666234, 0.08925876900320873, 0.15489105891902, 0.15227513678837568, 0.06783936289139092, 0.11650602333247662, 0.12832859909394756, 0.08223497206927277, 0.11774551385315135, 0.2871025004424155], [0.02888295337470481, 0.00815466857602587, 0.010444792515045265, 0.040685789863346145, 0.07076311303535476, 0.016656781008350663, 0.019647298468044028, 0.0066759666970028775, 0.026906974053417798, 0.004266904779797187, 0.051990977372042835, 0.05528653236979153, 0.07109288635547273, 0.09582029699231498, 0.058123425260419026, 0.12205973704112694, 0.011467255862953607, 0.04335174016887322, 0.03244432526116725, 0.13502235553460196, 0.04054010256368201, 0.04402191065310035, 0.10684401757316664, 46.533807814121246, 118.64343523979187, 98.75861585140228, 92.84376204013824, 77.46316775679588, 40.56047514081001, 24.941244162619114, 51.424080803990364, 80.11078968644142, 53.27005214989185, 56.67542561888695, 29.86179582774639, 12.165724541991949, 0.14498907228698954, 0.04517619148828089, 0.13399848859990016, 0.10841046125278808, 0.013557818147091893, 0.005910880627197912, 0.3508216078625992, 0.2844872314017266, 0.1405972204520367, 0.10842426519957371, 0.3456631471635774, 12.648956011980772, 65.25557801127434, 90.75808435678482, 87.38523334264755, 84.04553174972534, 78.7666954100132, 74.26522135734558, 66.89528122544289, 73.36112067103386, 82.38750591874123, 87.46917843818665, 84.69408094882965, 85.28643876314163, 83.06103497743607, 81.1029164493084, 82.69133761525154, 84.07089158892632, 86.31189733743668, 75.1525953412056, 65.3986631333828, 60.030584782361984, 67.03127592802048, 60.91956987977028, 63.06283727288246, 62.64799453318119, 62.67455890774727, 61.88830889761448, 65.53126841783524, 69.21635627746582, 67.27684155106544, 61.883718743920326, 66.00189596414566, 63.058604300022125, 61.880929693579674, 60.34742318093777, 73.29609856009483, 69.72083240747452, 76.17294698953629, 70.83788886666298, 89.46395739912987, 35.664149075746536, 65.25250777602196, 85.85202321410179, 70.76073780655861, 72.38038569688797, 70.82857936620712, 84.36394706368446, 80.17404869198799, 82.73327216506004, 71.04209750890732, 62.206769809126854, 59.12157855927944, 64.34029072523117, 65.34834623336792, 62.23263122141361, 61.525720953941345, 65.53727969527245, 63.979089707136154, 63.11727315187454, 61.48687183856964, 62.70295478403568, 61.01152494549751, 73.15856873989105, 79.85122561454773, 82.34219714999199, 79.01558205485344, 80.70402905344963, 70.15442714095116, 79.08210888504982, 83.56345921754837, 78.00817251205444, 68.57166767120361, 77.64429643750191, 77.66320422291756, 92.16010272502899, 38.0741735547781, 0.12231487999088131, 0.25654115597717464, 0.1884351097396575, 0.07597958741826005, 0.08026863695704378, 0.039762532178428955, 0.1882927361293696, 0.047651595377828926, 0.08027697869692929, 0.06086116722144652, 0.056667416865820996, 0.2683233143761754, 4.093596814200282, 32.7640762925148, 37.63281583786011, 54.42639470100403, 99.07485768198967, 77.90447607636452, 28.66292215883732, 9.87384332343936, 40.57576172053814, 57.187543138861656, 74.61789563298225, 74.62667316198349, 67.16844856739044, 12.64202993363142, 0.17121008480899036, 0.018132450750272255, 0.08956788093200885, 0.06115292402682826, 0.0013032694164394343, 0.03934680702514015, 0.053751359082525596, 0.07303671212866902, 0.011620105815381976, 0.04333135708293412, 0.07756384264212102, 0.028394655455485918, 0.05866556413820945, 0.05179021900403313, 0.0626005647063721, 0.037256136201904155, 0.04579192915116437, 0.08280531998025253, 0.009508002694929019, 0.07420727939461358, 0.049285889908787794, 0.029049725089862477, 0.04119137054658495, 0.060805146204074845, 0.04546935837424826, 0.015466072782146512, 0.009060359625436831, 0.030947906925575808, 0.06657622012426145, 0.010763550508272601, 0.023306672810576856, 0.04048344329930842, 0.05091375373012852, 0.07466899915016256, 0.01991331017052289, 0.03818975426838733, 0.03527336994011421, 0.027605789582594298, 0.035718476719921455, 0.03128793301584665, 0.015527740615652874, 0.07182609857409261, 0.041783686028793454, 0.06279321140027605, 0.027187416817469057, 0.06073704673326574, 0.04312159646360669, 0.04317965096561238, 0.08866363335982896, 0.06680343605694361, 60.118515864014626, 135.96614331007004, 110.83709612488747, 104.45123478770256, 93.38591694831848, 56.66181094944477, 37.46552601456642, 39.595862701535225, 58.172514885663986, 56.163365095853806, 47.50622123479843, 41.48923650383949, 15.58500336483121, 0.3666811849689111, 0.08936926737078466, 0.030226240669435356, 0.1438864931697026, 0.13395329180639237, 0.04481731113628484, 0.22171419899677858, 0.33646122843492776, 0.6759247707668692, 0.35471996117848903, 0.22378531051799655, 14.984219502657652, 68.42345282435417, 92.97553136944771, 89.45612981915474, 88.36264729499817, 84.58983734250069, 78.7468908727169, 71.98902949690819, 78.41612622141838, 88.01020100712776, 90.59910088777542, 87.12453693151474, 87.00330063700676, 87.20546498894691, 82.74432197213173, 85.38934484124184, 86.78437918424606, 90.71409031748772, 80.27905985713005, 67.4497702717781, 64.0697680413723, 68.27874898910522, 66.06729805469513, 65.5607396364212, 65.11386841535568, 64.42234352231026, 63.95780324935913, 68.45141172409058, 71.38960406184196, 70.28138592839241, 63.64139422774315, 69.7891603410244, 65.16531765460968, 64.27013128995895, 63.42542141675949, 76.00070983171463, 73.57992053031921, 79.31371405720711, 75.12893781065941, 92.52802938222885, 38.86076174676418, 67.76734203100204, 87.8288671374321, 75.25654256343842, 74.3407841026783, 75.9335370361805, 87.92981252074242, 81.82233944535255, 84.24307554960251, 74.06660601496696, 66.4477488398552, 61.36878177523613, 66.79643332958221, 68.18244695663452, 65.55621787905693, 63.78348380327225, 67.32155755162239, 66.96588143706322, 66.88189834356308, 64.1942797601223, 66.10865503549576, 64.95380580425262, 76.74361556768417, 83.95707249641418, 85.1387482881546, 82.30487555265427, 83.07942599058151, 69.50620472431183, 78.8843446969986, 88.77667307853699, 84.10050719976425, 71.11449122428894, 82.53423884510994, 80.25422438979149, 97.82361522316933, 47.79724761843681, 0.22230917878914624, 0.5589780898299068, 0.3405037068296224, 0.09286523563787341, 0.27438844204880297, 0.14331843849504367, 0.19439175026491284, 0.0572727236431092, 0.017835059188655578, 0.05810677888803184, 0.061909068608656526, 0.097862583497772, 4.3922859616577625, 34.803970232605934, 30.978033430874348, 55.530714243650436, 87.5675019621849, 52.31878079473972, 26.944844350218773, 20.66715180873871, 54.10576410591602, 67.98064738512039, 82.79889464378357, 84.25072833895683, 82.84959152340889, 16.671711802482605, 0.16092129080789164, 0.06668135276413523, 0.0802070832287427, 0.039142234018072486, 0.004160295729889185, 0.07329175117774867, 0.10686236346373335, 0.10781609002151527, 0.0396448461106047, 0.037852277455385774, 0.10651002143276855, 0.016888052778085694, 0.041881081779138185, 0.03565316030289978, 0.06580990811926313, 0.04035270285385195, 0.05697384964150842, 0.05304199206875637, 0.022187749746080954, 0.026057240938826, 0.08792919659754261, 0.06888711955980398, 0.038767987498431467, 0.08213660039473325, 0.02749666789895855, 0.03659299385617487, 0.017922424813150428, 0.20638222951674834, 0.08029220756725408, 0.0771292854915373, 0.09595199109753594, 0.14360401692101732, 0.18498262390494347, 0.286088697030209, 0.12767362408339977, 0.10529496241360903, 0.10947398113785312, 0.08892070589354262, 0.14714800956426188, 0.2114249300211668, 0.17167903308290988, 0.19263631867943332, 0.23249076213687658, 0.16389803029596806, 0.13700026815058663, 0.16614605498034507, 0.23589077813085169, 0.17755336943082511, 0.20281986129703, 0.1499227958265692, 73.62177148461342, 153.40421319007874, 121.24544441699982, 117.22600489854813, 102.32910186052322, 61.43888421356678, 38.84368546307087, 77.60953590273857, 108.7385143339634, 71.01724684238434, 82.08913072943687, 52.85883441567421, 22.937191799283028, 1.0438818857073784, 0.23434641334461048, 0.45251178089529276, 0.24021930992603302, 0.3998432226944715, 0.21051416639238596, 0.9661130618769675, 1.198565410450101, 1.0003674519248307, 0.6725538172759116, 0.5848818342201412, 17.103731520473957, 74.18534204363823, 98.13133031129837, 95.63943162560463, 94.35100436210632, 87.95760422945023, 84.54943791031837, 74.6885034441948, 81.46249115467072, 92.64307960867882, 93.24893429875374, 90.97671702504158, 89.26943823695183, 88.24569717049599, 85.7926096022129, 85.39702042937279, 90.02091631293297, 94.78858888149261, 84.07049641013145, 70.72629645466805, 67.80051425099373, 72.2407203912735, 69.77545827627182, 68.95833492279053, 67.56662160158157, 68.0289351940155, 66.98622554540634, 71.24613136053085, 72.56643131375313, 73.40558588504791, 67.18754634261131, 72.9477408528328, 68.89789536595345, 68.7513068318367, 65.0640606880188, 79.86625760793686, 76.25566095113754, 84.74637374281883, 78.57416734099388, 97.29282930493355, 43.917876183986664, 72.13589921593666, 91.28108829259872, 79.6386270225048, 79.40285727381706, 79.28193256258965, 92.86778435111046, 85.64114212989807, 89.49953868985176, 78.94929081201553, 69.79698032140732, 67.40142926573753, 71.65334030985832, 72.70040452480316, 68.67436096072197, 67.01998293399811, 71.73799976706505, 68.80774900317192, 70.07039844989777, 68.41122508049011, 67.77925059199333, 67.61177837848663, 82.52140313386917, 88.36311846971512, 90.94771698117256, 85.44030770659447, 86.2067873775959, 70.32290250062943, 82.94792264699936, 92.3660060763359, 86.47791802883148, 76.01667657494545, 88.24721708893776, 85.26000738143921, 101.49847403168678, 49.26352433860302, 0.469005627091974, 1.0144973499700427, 1.0610720445401967, 0.6525041931308806, 0.28362369805108756, 0.47338940436020494, 0.3086440492188558, 0.2427677411469631, 0.16728185262763873, 0.24986841715872288, 0.21525402611587197, 0.6523476296570152, 8.724234960973263, 50.45766346156597, 53.25017921626568, 64.35226008296013, 121.19375959038734, 105.11011183261871, 40.58454304933548, 19.713562577962875, 59.1675028949976, 79.37463238835335, 95.88230699300766, 94.31090131402016, 95.19595742225647, 18.059127554297447, 0.21816271066199988, 0.15496332925977185, 0.20791581831872463, 0.17611339513678104, 0.11026024949387647, 0.142829823307693, 0.16607240424491465, 0.14769347326364368, 0.11099169540102594, 0.10004408948589116, 0.16083074879134074, 0.09058238938450813, 0.17586891684914008, 0.1483332342468202, 0.1604454850894399, 0.1035060228605289, 0.12915579689433798, 0.15162874100496992, 0.12278925336431712, 0.12403303349856287, 0.1376183732645586, 0.07918487128335983, 0.08472613917547278, 0.16152124298969284, 0.16979574429569766, 0.1913752910331823, 0.07570954214315861], [0.03690259931317996, 0.04930464769131504, 0.05734288628445938, 0.04849339122301899, 0.05944478209130466, 0.04886373404588085, 0.012588535246322863, 0.011838944756163983, 0.03675454827316571, 0.014306324173958274, 0.014782634552830132, 0.05231268354691565, 0.05689821366104297, 0.06420743316994049, 0.08049128868151456, 0.05597831419436261, 0.03885667785652913, 0.09354790017823689, 0.060681151880999096, 0.04657657591451425, 0.1138789467222523, 0.20632158120861277, 9.886691384017467, 109.59871977567673, 103.68354678153992, 97.39977076649666, 85.65163716673851, 49.142379239201546, 25.980815179646015, 45.88151581585407, 62.77247965335846, 49.17948804795742, 52.11802996695042, 37.92733423411846, 13.439613785594702, 0.3490186046110466, 0.0617935236368794, 0.026693840372900013, 0.014944814229238546, 0.01585557693033479, 0.1549718639580533, 0.0582254816981731, 0.13444530603010207, 0.0449855226179352, 1.0715789557434618, 0.18870560772484168, 1.4263570122420788, 28.849032372236252, 80.69228008389473, 92.09066525101662, 83.1645718216896, 79.22928258776665, 75.10461151599884, 69.02409419417381, 63.50209750235081, 76.35697111487389, 85.12978076934814, 85.39872273802757, 83.6889436841011, 90.71772292256355, 81.5267913043499, 83.00849139690399, 78.6664491891861, 80.02917766571045, 85.02492159605026, 81.51377320289612, 70.75219586491585, 59.86748233437538, 59.73257057368755, 61.70757919549942, 63.481677398085594, 62.27337643504143, 60.40048733353615, 59.19819004833698, 64.76649105548859, 68.48346680402756, 63.55548843741417, 61.807004660367966, 64.86182034015656, 60.85004881024361, 61.55675768852234, 66.98570877313614, 80.2397395670414, 76.42739653587341, 72.64485910534859, 67.45785623788834, 88.79668280482292, 49.285171777009964, 60.023194178938866, 84.8963288962841, 65.98439410328865, 69.57730650901794, 71.5165476500988, 84.35679584741592, 74.45358484983444, 82.34622493386269, 73.9846596121788, 68.58552932739258, 57.433564737439156, 60.10217294096947, 62.5824860483408, 63.42531882226467, 61.92553550004959, 62.76709534227848, 62.72776745259762, 62.074369713664055, 56.60371966660023, 61.162570640444756, 61.496823504567146, 76.3881978392601, 76.51511862874031, 83.95426824688911, 78.1187541782856, 80.75115412473679, 74.21881064772606, 73.60214173793793, 79.41552579402924, 80.41520655155182, 72.44380429387093, 67.10664868354797, 77.88558349013329, 76.39242321252823, 88.03211823105812, 49.84860174357891, 6.894950419664383, 0.08401460509048775, 0.12523654469987378, 0.2345544521813281, 0.06923790308064781, 0.024618591378384735, 0.0803089133114554, 0.0671747028536629, 0.05275125200569164, 0.131624432397075, 0.053513040620600805, 0.11717481713276356, 0.6218157929833978, 31.712264232337475, 25.629902109503746, 53.02319459617138, 134.85085755586624, 92.3331606388092, 30.729074589908123, 13.494007866829634, 39.54177640378475, 57.40735374391079, 71.47797971963882, 71.81808426976204, 50.554926842451096, 4.332321854308248, 0.0977458807756193, 0.033207271626451984, 0.11473353719338775, 0.03353756073920522, 0.05734730206313543, 0.08330327880685218, 0.0383427591441432, 0.0584691102267243, 0.05309995380230248, 0.03924906988686416, 0.03976913358201273, 0.023830378595448565, 0.05998785978590604, 0.11933430359931663, 0.006037334705979447, 0.041239198253606446, 0.054223836268647574, 0.044858040200779215, 0.05748912277340423, 0.05578670650720596, 0.060182172601344064, 0.04354384509497322, 0.0438558662426658, 0.028245951325516216, 0.06556620166520588, 0.04549687721009832, 0.0835774207371287, 0.050769717709044926, 0.028516684942587744, 0.017371237299812492, 0.044139923265902326, 0.050251702341483906, 0.008732407350180438, 0.06443798134569079, 0.04321086198615376, 0.04266047784767579, 0.03293254711024929, 0.010625825525494292, 0.06056741774955299, 0.033742927844286896, 0.03205132466973737, 0.02974528630147688, 0.08491449625580572, 0.045741674621240236, 0.05514852629858069, 0.05511925970495213, 0.12908952310681343, 0.33584459277335554, 13.975367937237024, 130.82158416509628, 112.85386830568314, 108.84783446788788, 98.79428073763847, 74.66974005103111, 43.654352724552155, 47.22005479037762, 59.48600560426712, 55.003245547413826, 45.356836169958115, 45.77951028943062, 18.2577732950449, 0.047051401998032816, 0.06183539931953419, 0.026682277712097857, 0.10401650913991034, 0.14069089433178306, 0.05879777774680406, 0.0538206756755244, 0.27007478289306164, 0.2648053562734276, 1.3805185281671584, 0.02926564367953688, 1.8596222321502864, 33.81988763809204, 85.00375673174858, 97.33699053525925, 88.1305405497551, 84.14168938994408, 78.56914401054382, 74.18380692601204, 67.59086430072784, 80.21557286381721, 88.73755797743797, 88.63938644528389, 86.66777864098549, 92.97820642590523, 84.23793062567711, 86.55152767896652, 79.661083817482, 80.94825714826584, 87.47264385223389, 83.82883697748184, 73.96965801715851, 63.100124672055244, 63.15924569964409, 65.57258740067482, 65.84168896079063, 62.843383848667145, 61.892636865377426, 62.30879433453083, 68.28777730464935, 70.37029355764389, 66.19181737303734, 64.79463994503021, 68.21279972791672, 65.63686475157738, 66.04715913534164, 70.63959270715714, 82.27100417017937, 79.18698325753212, 77.56697058677673, 70.02030953764915, 92.08183452486992, 53.52721095085144, 62.77721419930458, 89.24723222851753, 68.52339506149292, 72.05357283353806, 75.2423769235611, 86.7911884188652, 78.5824128985405, 86.27096593379974, 77.67119899392128, 71.66904866695404, 61.77586153149605, 62.34138138592243, 62.73803070187569, 65.10629162192345, 64.24595698714256, 65.88123723864555, 65.8472290635109, 64.06567946076393, 61.021772995591164, 63.241632878780365, 65.00287637114525, 79.92556482553482, 78.76000016927719, 85.67354679107666, 80.03352463245392, 83.13019886612892, 75.9484626352787, 77.70307168364525, 84.10277187824249, 84.19589728116989, 75.96773520112038, 71.23041540384293, 82.22834765911102, 82.84644529223442, 92.81964853405952, 59.20406833291054, 8.865967355668545, 0.1900863289483823, 0.3440199134638533, 0.07618113988428377, 0.21643206680892035, 0.0796630592958536, 0.1696620834991336, 0.10298486449755728, 0.03547474800143391, 0.1734983635833487, 0.07079801624058746, 0.2630664745811373, 0.6422949128318578, 33.9853535592556, 27.62472476810217, 55.51715277135372, 123.51171880960464, 62.56917916238308, 26.284928061068058, 31.628784611821175, 50.650145933032036, 64.05545800924301, 78.0950054526329, 84.30049806833267, 64.71810445189476, 5.070510618388653, 0.07156699255574495, 0.04092665760254022, 0.0816040723293554, 0.03517135432048235, 0.08854603263898753, 0.01933001920406241, 0.036021929772687145, 0.03911591003998183, 0.006232389669094118, 0.024239086742454674, 0.03462819498963654, 0.03141422428598162, 0.04011310789792333, 0.0892734486842528, 0.057871358512784354, 0.03893433618941344, 0.07275118565303273, 0.06264375770115294, 0.12044571427395567, 0.07425563773722388, 0.047775430139154196, 0.06363439868437126, 0.05783083353890106, 0.0361692052683793, 0.03882711069309153, 0.05043264165578876, 0.2294763660756871, 0.14729324786458164, 0.15400008094729856, 0.13009005691856146, 0.11943149525905028, 0.18518104450777173, 0.1914963946910575, 0.12169521636678837, 0.17959999007871374, 0.11878289529704489, 0.11089682666352019, 0.10280861184583046, 0.26113792962860316, 0.16210623347433284, 0.1917110980139114, 0.12185946849058382, 0.2278976546949707, 0.15354560455307364, 0.23156108858529478, 0.23595354898134246, 0.3909285448025912, 0.5980378563981503, 18.563759475946426, 148.85790914297104, 127.62183666229248, 124.90024030208588, 113.0232784152031, 72.36903190612793, 39.56023581326008, 63.17168243229389, 87.1422591805458, 68.87568175792694, 77.78760194778442, 64.232437312603, 24.249407686293125, 1.0146363987587392, 0.1798981404863298, 0.4139870434300974, 0.24493718723533675, 0.35922862705774605, 0.297171039856039, 0.5347537365742028, 0.6774330523330718, 0.609077689005062, 2.3798811715096235, 0.8856735157314688, 2.5474621541798115, 37.47368797659874, 91.68091803789139, 104.53304439783096, 94.34139087796211, 88.86472195386887, 82.73753553628922, 77.27233439683914, 71.13149151206017, 85.86871951818466, 93.2356958091259, 91.15527704358101, 90.01269355416298, 96.28879398107529, 86.41701489686966, 89.28560256958008, 81.29233628511429, 84.11193698644638, 90.76762944459915, 89.03181418776512, 78.42747241258621, 65.77850595116615, 67.25995525717735, 69.84963029623032, 69.6506729722023, 68.47761511802673, 65.6134732067585, 66.17035612463951, 70.69345101714134, 74.19616386294365, 69.28909957408905, 69.02898833155632, 72.56849840283394, 68.57796773314476, 70.04696890711784, 75.23801475763321, 86.28445520997047, 84.19326022267342, 80.94385698437691, 73.92959296703339, 96.45556703209877, 58.274455815553665, 65.69000110030174, 95.05218833684921, 73.16930696368217, 77.10476338863373, 80.21451652050018, 91.83666408061981, 81.8975830078125, 90.11160984635353, 83.37860673666, 75.7057848572731, 64.84357371926308, 66.55804172158241, 66.07102945446968, 67.76616409420967, 66.43921449780464, 70.19161194562912, 68.9829272031784, 67.97871708869934, 63.60039062798023, 67.18486368656158, 69.94580313563347, 86.2078969180584, 82.9294404387474, 90.44067218899727, 84.50138568878174, 87.6027412712574, 78.03090289235115, 79.53258231282234, 87.95375123620033, 88.08095321059227, 80.61123043298721, 74.87301394343376, 85.23910850286484, 86.21066316962242, 96.2322150170803, 60.005521327257156, 7.96227372251451, 0.8790067734662443, 1.2703196913935244, 0.6286681909114122, 0.22037272254237905, 0.21192736399825662, 0.2673018223140389, 0.37834836984984577, 0.10251201994833536, 0.3837106836726889, 0.1903260129620321, 0.32250742719043046, 2.1357891568914056, 53.31839695572853, 38.723509311676025, 58.50322633981705, 145.59923440217972, 112.23935768008232, 46.067641228437424, 24.511327631771564, 57.441179528832436, 78.34210619330406, 91.82655662298203, 94.84935522079468, 75.36300525069237, 4.958617547526956, 0.21843688969966024, 0.14369435113621876, 0.1654946868075058, 0.10265714692650363, 0.1663635636214167, 0.1390680400072597, 0.1494926618761383, 0.19694506481755525, 0.07571875961730257, 0.24115554406307638, 0.15217576321447268, 0.2664069109596312, 0.10430619906401262, 0.2419427697896026, 0.08956402176409028, 0.12873793806647882, 0.2033350899000652, 0.19901754189049825, 0.22198500868398696, 0.15795146813616157, 0.1412259679636918, 0.16166394314495847, 0.15602970641339198, 0.18482092476915568, 0.11233461904339492, 0.1654406584566459], [0.012086511305824388, 0.022787922716815956, 0.06144767910882365, 0.04199984025035519, 0.009762708705238765, 0.053719810384791344, 0.05875311529962346, 0.015820387998246588, 0.016051643069658894, 0.06927675451152027, 0.012242318716744194, 0.03814002666331362, 0.04367927962448448, 0.013084643342153868, 0.026757937812362798, 0.003301924016341218, 0.03372839288203977, 0.05469193849421572, 0.05711177036573645, 0.04976531730790157, 0.06149437132989988, 0.13337934447918087, 58.19032073020935, 108.78725811839104, 83.06829258799553, 97.29598313570023, 58.385102078318596, 24.30870920419693, 27.863640747964382, 64.22036156058311, 44.06477630138397, 40.633537620306015, 50.14133803546429, 14.674886651337147, 0.06216942143510096, 0.02022416614636313, 0.13313005707459524, 0.024363348238694016, 0.0841204056632705, 0.010360440937802196, 0.11521313528646715, 0.051026946093770675, 0.058795376899070106, 0.42093253636267036, 0.569685084046796, 0.9668942762073129, 7.809553267434239, 44.01970311999321, 87.34638422727585, 85.27228072285652, 81.4002200961113, 80.12987226247787, 78.10797035694122, 68.59422326087952, 65.34282132983208, 68.98105010390282, 82.45655581355095, 84.31693598628044, 87.7522860467434, 84.66339379549026, 83.21065574884415, 83.68895128369331, 82.80684381723404, 75.16770333051682, 82.78450101613998, 79.49794337153435, 71.59553781151772, 62.06083483994007, 61.353677585721016, 63.24510969221592, 67.10865497589111, 67.02724054455757, 67.9872514307499, 61.24060705304146, 65.24847999215126, 65.49002543091774, 64.13651525974274, 60.37708818912506, 63.80918562412262, 64.63308021426201, 63.041007444262505, 72.19383090734482, 80.24410173296928, 75.77960729598999, 80.38824319839478, 73.20811048150063, 87.39323571324348, 59.349972903728485, 58.91741931438446, 81.41558647155762, 63.526218608021736, 64.10084277391434, 68.05040404200554, 81.55943915247917, 77.33094245195389, 78.80815878510475, 75.30675306916237, 71.9580003619194, 61.39365904033184, 58.29457573592663, 59.345496743917465, 63.734466433525085, 65.26548027992249, 64.46626156568527, 62.14813515543938, 60.05046911537647, 58.69470566511154, 57.161997109651566, 60.15923447906971, 70.00629588961601, 72.87272527813911, 76.94385722279549, 78.32374557852745, 77.08949580788612, 79.883873462677, 73.41470539569855, 79.1079019010067, 79.60588797926903, 73.03029522299767, 65.60642838478088, 66.41334548592567, 80.77798828482628, 74.16794657707214, 86.47402703762054, 89.11323621869087, 30.069559179246426, 0.14058439614018425, 0.39177301980089396, 0.13528209237847477, 0.05945133154455107, 0.05995480081764981, 0.048334449165849946, 0.07410646605421789, 0.06059434286726173, 0.1015440961054992, 0.2452534163603559, 0.0774056909722276, 1.8259281339123845, 31.313749216496944, 55.98880626261234, 119.02732104063034, 97.59777814149857, 70.24829730391502, 23.632457591593266, 30.102081634104252, 54.08012308180332, 66.4582134783268, 74.27256256341934, 80.68881466984749, 29.98785026371479, 0.3783402655972168, 0.015740764829388354, 0.040862391324480996, 0.03687918455398176, 0.030333547802001704, 0.06401180304237641, 0.027272396437183488, 0.019453679560683668, 0.11095692578237504, 0.025885626710078213, 0.03906580022885464, 0.057042613334488124, 0.06916125406860374, 0.02931848088337574, 0.011830987077701138, 0.07639511590241455, 0.05888671301363502, 0.026354688161518425, 0.011458558819867903, 0.10691950883483514, 0.015616889249940868, 0.07106465505785309, 0.03759599530894775, 0.03201478873961605, 0.015972802866599523, 0.032361980265704915, 0.05738801999541465, 0.019015417237824295, 0.033764683903427795, 0.0019260577141722024, 0.0209987902053399, 0.07634649780811742, 0.01628401136258617, 0.002616824999677192, 0.0214161981784855, 0.04277697276847903, 0.0848111447703559, 0.056856775845517404, 0.06421576748834923, 0.0240299346842221, 0.003345418044773396, 0.023669488400628325, 0.04005770286312327, 0.03243643252062611, 0.08940100902691483, 0.02308174083736958, 0.08354772740858607, 0.11426978395320475, 73.24755996465683, 122.89017856121063, 95.56956857442856, 108.42185452580452, 82.24192813038826, 41.105491295456886, 37.046777084469795, 48.32155488431454, 36.03727385401726, 43.64004649221897, 44.77306209504604, 20.34084051847458, 0.1729150058235973, 0.03104616542259464, 0.13556902151321992, 0.043060009338660166, 0.09625730323023163, 0.2106154992361553, 0.23131079185986891, 0.035612698411569, 0.22918865026440471, 0.9454504831228405, 0.7631902943830937, 0.8569355984218419, 8.879527878016233, 49.68810215592384, 90.44264048337936, 90.50011619925499, 87.40856409072876, 86.60375207662582, 80.13051062822342, 73.3806212246418, 66.59974068403244, 73.38171556591988, 84.31195825338364, 87.84869447350502, 90.31555250287056, 85.29907688498497, 87.32562214136124, 84.77748647332191, 86.93375676870346, 75.77469795942307, 84.1228424012661, 82.11292505264282, 75.08226871490479, 64.42051962018013, 62.931786105036736, 64.90734949707985, 70.15907049179077, 71.04210510849953, 71.17450520396233, 63.54418784379959, 65.18473461270332, 68.3031664788723, 66.28089979290962, 63.927974849939346, 64.71741288900375, 67.59508207440376, 65.56491941213608, 75.22662296891212, 81.86561152338982, 80.15615165233612, 83.38553756475449, 78.51057395339012, 88.51280003786087, 62.54493646323681, 63.383483067154884, 84.15129527449608, 67.21047431230545, 65.2335923910141, 70.63866555690765, 85.07210746407509, 81.29942670464516, 80.36398530006409, 79.55600425601006, 75.13852089643478, 64.13183391094208, 62.16276817023754, 63.12956929206848, 65.69857344031334, 66.70279875397682, 67.7211745083332, 65.26346638798714, 64.3446072936058, 61.59770809113979, 60.19638508558273, 63.7027533352375, 72.5534588098526, 74.79748159646988, 81.83398202061653, 81.21942579746246, 80.74933022260666, 82.65302807092667, 75.58096915483475, 82.02401742339134, 84.96746867895126, 79.74065914750099, 70.59527948498726, 69.36903968453407, 87.24595561623573, 80.15881910920143, 94.72570225596428, 95.27075260877609, 36.11054912209511, 0.20551128953229636, 0.4888440656941384, 0.243867366516497, 0.25349173054564744, 0.27675384480971843, 0.21124279213836417, 0.2544765605125576, 0.15247284492943436, 0.09369019215228036, 0.2237459470052272, 0.17427414539270103, 1.8111080978997052, 29.447923935949802, 46.34409539401531, 122.0652124285698, 92.08374202251434, 61.286816373467445, 28.783993162214756, 40.19435338675976, 61.377205923199654, 72.85485863685608, 80.43219164013863, 94.93451625108719, 38.956763595342636, 0.44860514521133155, 0.07524653105065227, 0.015742486611998174, 0.09798303406569175, 0.017450825216656085, 0.07283515224116854, 0.0508486451144563, 0.04738520146929659, 0.013710680159420008, 0.044579144814633764, 0.015179295787675073, 0.02181070904043736, 0.03644456432084553, 0.043464954796945676, 0.03496125602396205, 0.037853817411814816, 0.017416363589290995, 0.03275393071817234, 0.05499621904164087, 0.035625088567030616, 0.042357852289569564, 0.04030366544611752, 0.037859027288504876, 0.028822310632676817, 0.02092562928737607, 0.022619431074417662, 0.16128522518556565, 0.09295670533902012, 0.15810789802344516, 0.22351923573296517, 0.11065310536650941, 0.10308296899893321, 0.13957480812678114, 0.1076995357288979, 0.10086117923492566, 0.1432158291572705, 0.2105537080205977, 0.12804875004803762, 0.1566173241008073, 0.1191071247740183, 0.06118905177572742, 0.1144776595174335, 0.11566128116101027, 0.1233044225955382, 0.20266384701244533, 0.23109408473828807, 0.15456448425538838, 0.22993093152763322, 87.36687272787094, 138.6703822016716, 107.35827639698982, 124.55814465880394, 81.82828232645988, 40.22602468729019, 42.229816764593124, 88.08118879795074, 62.222033590078354, 57.74262875318527, 78.65738287568092, 25.231204703450203, 0.5691406445112079, 0.1063049140793737, 0.5299743649084121, 0.1344751552096568, 0.31477582175284624, 0.418508592993021, 0.41030622844118625, 0.17219631001353264, 0.3921343566616997, 1.877313726581633, 2.246624934487045, 2.1067126421257854, 9.066127315163612, 57.638202756643295, 96.39837250113487, 93.95902499556541, 92.15770125389099, 91.23267889022827, 87.23596215248108, 76.78962349891663, 71.21346071362495, 77.74757489562035, 91.64415881037712, 91.1105078458786, 97.28912830352783, 89.56738784909248, 91.6766394674778, 91.00843012332916, 89.81603130698204, 75.65780103206635, 88.9722865819931, 86.26695334911346, 79.17129009962082, 67.91459172964096, 68.43127280473709, 69.7444823384285, 74.7546198964119, 75.28969958424568, 73.83734911680222, 66.401277333498, 70.10553896427155, 70.85850656032562, 69.61653560400009, 66.80290058255196, 69.80470150709152, 71.39053121209145, 70.97926408052444, 79.72365885972977, 86.9610621035099, 81.24141901731491, 88.09995979070663, 81.54837414622307, 94.13742542266846, 68.00207823514938, 69.0830746293068, 87.05063089728355, 71.57216146588326, 67.9844319820404, 75.06114944815636, 89.15013983845711, 84.44106012582779, 82.89379835128784, 83.58494326472282, 79.24051478505135, 68.13050374388695, 64.2174281179905, 66.55351236462593, 67.93026208877563, 70.29830262064934, 70.17417088150978, 68.95266562700272, 66.9651746749878, 65.89884549379349, 63.531466126441956, 67.5676779448986, 77.00355961918831, 78.64040538668633, 87.10788622498512, 87.0257194340229, 85.83047837018967, 87.01089262962341, 76.66752845048904, 85.30353784561157, 86.846232265234, 82.25514382123947, 74.92268487811089, 73.76588255167007, 89.68236967921257, 82.05752402544022, 94.58017006516457, 97.34479531645775, 34.40363131463528, 0.22633470653090626, 1.6577453585341573, 0.3264262044103816, 0.23954731004778296, 0.17182626033900306, 0.42953791678883135, 0.4028408759040758, 0.16847668070113286, 0.3369410417508334, 0.718569407472387, 0.3170525230234489, 3.8692193292081356, 53.781056329607964, 72.63550400733948, 122.09763988852501, 109.64686319231987, 90.52827268838882, 35.53955756127834, 48.89600805938244, 73.94579529762268, 88.3094197511673, 92.71618008613586, 108.60223844647408, 41.222327426075935, 0.5616257165092975, 0.15789905766723678, 0.15767524077091366, 0.2402389916824177, 0.144520791945979, 0.16665564326103777, 0.1510038526612334, 0.13853364915121347, 0.1843772392021492, 0.12089112904504873, 0.06834428306319751, 0.15052875940455124, 0.18225356878247112, 0.12166193104349077, 0.1233095582574606, 0.16330950718838722, 0.09736446882016025, 0.10123205269337632, 0.11596331300097518, 0.1895748556125909, 0.11366347898729146, 0.1272051953128539, 0.12167608379968442, 0.11106422549346462, 0.1331874993047677, 0.10914604834397323], [0.017149873201560695, 0.03364617776242085, 0.0699944855296053, 0.03398151347937528, 0.0817568508500699, 0.013296708330017282, 0.018049868267553393, 0.05456598119053524, 0.07803830507327802, 0.04911268006253522, 0.02686552510567708, 0.024570275709265843, 0.018617952628119383, 0.03320006166177336, 0.02989820954098832, 0.04433775757206604, 0.051513943399186246, 0.00848666741148918, 0.07770472453557886, 0.08463766775093973, 0.2411433431552723, 9.496254734694958, 100.88016360998154, 111.15950882434845, 90.46269580721855, 64.91464510560036, 41.057469472289085, 42.27466195821762, 46.500776186585426, 70.39252996444702, 57.53094591200352, 42.55248785018921, 23.445302434265614, 0.236560863268096, 0.10114945165696554, 0.08047545867157169, 0.13440425042062998, 0.17570562951732427, 0.14459074678597972, 0.11612711241468787, 0.18065222189761698, 0.07408685851260088, 0.4403902235208079, 0.9530817798804492, 0.5027943046297878, 6.678907312452793, 37.15587683022022, 70.04214316606522, 83.04935440421104, 83.68956685066223, 90.47094896435738, 81.515042334795, 81.24474763870239, 67.46104046702385, 64.2948679625988, 66.0840855538845, 78.03289398550987, 76.90540328621864, 76.73749789595604, 72.98234179615974, 77.53602504730225, 76.67816027998924, 82.04394355416298, 76.61662638187408, 82.378219217062, 79.40655827522278, 71.76390677690506, 61.053356900811195, 62.19812527298927, 67.032241076231, 74.10327404737473, 74.47563126683235, 72.54221901297569, 63.888920545578, 59.14653182029724, 61.77121438086033, 65.47911241650581, 58.5544665902853, 61.75594300031662, 60.34831613302231, 64.35321003198624, 67.35258668661118, 74.88571286201477, 74.7026614844799, 78.9284299314022, 75.19956842064857, 80.58599218726158, 48.56140561401844, 50.950869396328926, 80.16012623906136, 65.95040872693062, 63.98841440677643, 61.69824309647083, 75.04851892590523, 76.73515722155571, 76.18293285369873, 72.34931856393814, 74.10314485430717, 63.943554013967514, 59.886162132024765, 59.511262848973274, 63.519587963819504, 62.71717742085457, 62.492324486374855, 59.18989509344101, 57.9650954157114, 55.6835762411356, 59.2757248878479, 59.18556332588196, 65.51279380917549, 66.58926084637642, 67.57923692464828, 69.29039910435677, 73.10284852981567, 75.489941239357, 80.08299797773361, 75.09706512093544, 79.16473925113678, 77.32447519898415, 71.5971565246582, 59.469381496310234, 70.69783598184586, 80.49341395497322, 77.80511900782585, 76.36902406811714, 97.84531205892563, 41.04797378182411, 0.18867179547669366, 0.6512706249486655, 0.04913118922559079, 0.19119184697046876, 0.1283309591235593, 0.08085149747785181, 0.11012736053089611, 0.08007404583622701, 0.09043595622642897, 0.0272717080952134, 0.05289420820190571, 5.1230257004499435, 40.19395060837269, 34.92155872285366, 37.7041532099247, 50.8812153339386, 64.06476750969887, 23.425737284123898, 37.789131850004196, 52.8340445458889, 64.39255312085152, 76.74049973487854, 72.27301865816116, 5.630360227078199, 0.29239439929369837, 0.07858762051910162, 0.10512142602237873, 0.09351765023893677, 0.05646211655403022, 0.019545368195394985, 0.025128547022177372, 0.08234760782215744, 0.037957591921440326, 0.04878386782365851, 0.037748606846434996, 0.04865795133810025, 0.035616665190900676, 0.057925342334783636, 0.012331425605225377, 0.0696823382168077, 0.08296433254145086, 0.0329867238906445, 0.06017075094860047, 0.03413820682908408, 0.044440656347433105, 0.03274636452260893, 0.07353859691647813, 0.08626435897895135, 0.011273024683760013, 0.1089191366918385, 0.058028267085319385, 0.05356738438422326, 0.02060921091469936, 0.10519764458877034, 0.030130440536595415, 0.0567001715535298, 0.03683580973302014, 0.014307948549685534, 0.017984449805226177, 0.044723525934387, 0.013412997304840246, 0.006429555114664254, 0.0404266356053995, 0.02733446966885822, 0.0404086199705489, 0.01716428199870279, 0.06154269998660311, 0.08647659837151878, 0.1983058816404082, 0.426441557938233, 13.793486896902323, 120.9312316775322, 119.32486787438393, 101.4707051217556, 78.23321923613548, 58.17357502877712, 49.67550963163376, 51.2470369040966, 69.94414642453194, 47.930137887597084, 38.80118474364281, 29.5002319291234, 0.0941212018369697, 0.10131241986528039, 0.1450790502713062, 0.1655867279623635, 0.44377385289408267, 0.6856876937672496, 1.0677874716930091, 0.19311009091325104, 0.07193809607997537, 0.775794277433306, 1.9446791242808104, 0.8396448043640703, 8.039869833737612, 47.04042322933674, 77.12349638342857, 87.33234018087387, 85.81837981939316, 94.52440425753593, 87.01536118984222, 85.97075164318085, 70.81099390983582, 67.76038080453873, 69.6455280482769, 79.34030503034592, 80.4222209751606, 78.44276279211044, 78.24393466114998, 80.05267560482025, 79.16219338774681, 86.2796750664711, 77.73911654949188, 82.64152228832245, 83.12703743577003, 75.0287751853466, 65.56294351816177, 64.58228453993797, 72.03616216778755, 76.89551621675491, 76.5567871928215, 74.58330988883972, 65.21034523844719, 61.453654021024704, 61.96697607636452, 66.89914181828499, 61.081809774041176, 65.8227887749672, 61.653078719973564, 66.75231009721756, 69.25519779324532, 77.25964307785034, 78.23416158556938, 83.03814500570297, 77.33500823378563, 85.2998748421669, 53.42789188027382, 53.418806567788124, 86.05724260210991, 68.68774384260178, 67.29166835546494, 64.65688213706017, 77.24349394440651, 79.88169997930527, 79.66609194874763, 77.77794286608696, 77.81753674149513, 66.75563871860504, 62.876020297408104, 61.337957829236984, 65.35789892077446, 66.52851730585098, 63.92376467585564, 61.32436215877533, 60.83768047392368, 60.705633759498596, 61.69155165553093, 60.48014625906944, 68.49129438400269, 69.77180287241936, 69.66924637556076, 71.90550237894058, 76.39939203858376, 79.22543719410896, 82.16954201459885, 77.4658428132534, 81.78165882825851, 82.23500490188599, 75.66255077719688, 63.115852028131485, 72.92669758200645, 84.69855710864067, 81.3551165163517, 78.86689603328705, 103.30668300390244, 48.21917697787285, 0.22654081578366458, 0.40235785651020706, 0.8650676370598376, 1.046518706716597, 0.4729701206088066, 0.3443813690682873, 0.16552726709051058, 0.06070841096516233, 0.23979647870874032, 0.10428452093037777, 0.028521184212877415, 5.138522693887353, 40.756514221429825, 40.52924461662769, 49.976616874337196, 45.512510016560555, 58.59861642122269, 34.40157562494278, 48.649682477116585, 60.79090118408203, 74.17487740516663, 85.57868108153343, 88.1410051882267, 8.893941454589367, 0.33676084829494357, 0.11120917435619049, 0.10776580951642245, 0.06315319013083354, 0.06278362285229377, 0.042920841806335375, 0.028654329216806218, 0.04726363025838509, 0.029712791365454905, 0.03635684617620427, 0.022566681072930805, 0.04154359383392148, 0.04974808092811145, 0.011580341542867245, 0.042139686847804114, 0.060834524119854905, 0.043929765597567894, 0.022945573437027633, 0.01674776831350755, 0.052165318993502297, 0.07497828919440508, 0.027753512222261634, 0.020101676527701784, 0.04158119474595878, 0.016144482033269014, 0.21135868591954932, 0.11098100105300546, 0.14437513804296032, 0.13861243554856628, 0.25884181377477944, 0.10945916787022725, 0.1267573982477188, 0.12430845192284323, 0.14650370663730428, 0.19103379920125008, 0.09984180229366757, 0.10953860735753551, 0.0970890058670193, 0.18098051834385842, 0.15968248306307942, 0.24827855871990323, 0.21328380214981735, 0.2700032398570329, 0.20245321065885946, 0.29061953828204423, 0.618484856095165, 18.80794957280159, 139.10485088825226, 134.7758799791336, 117.83415466547012, 90.59388756752014, 60.386849865317345, 56.74740515649319, 62.42368496954441, 94.23979952931404, 79.86686557531357, 68.43092322349548, 40.598233714699745, 0.4723950452171266, 0.28505322290584445, 0.21946933586150408, 0.3073121316265315, 0.4788654448930174, 0.4602772876387462, 0.5211469635833055, 0.3498193225823343, 0.30744646035600454, 1.2565212068147957, 2.428975962102413, 1.7983805621042848, 10.391814429312944, 58.41189444065094, 83.50931212306023, 91.26129895448685, 90.35136178135872, 99.4689193367958, 91.65816485881805, 90.57934954762459, 76.32090345025063, 72.16635078191757, 74.31076571345329, 85.01918390393257, 83.31432178616524, 81.08675971627235, 79.61404994130135, 85.46390444040298, 83.60847160220146, 91.0747441649437, 79.85192477703094, 84.97894406318665, 87.26353347301483, 80.1962623000145, 68.54569226503372, 69.1081228852272, 75.1554299890995, 80.64721450209618, 81.22800573706627, 80.40123850107193, 69.61434692144394, 64.74857121706009, 65.79584062099457, 71.05004668235779, 64.0841692686081, 68.92680421471596, 67.20060244202614, 71.76606506109238, 72.73641899228096, 81.87292993068695, 80.54470360279083, 86.26591980457306, 80.73328748345375, 88.89885932207108, 57.77200497686863, 59.18951131403446, 89.15978372097015, 75.44143304228783, 68.9656001329422, 69.6965517103672, 80.9802894294262, 87.46040090918541, 84.36558857560158, 80.46241521835327, 80.96452787518501, 68.59917059540749, 66.14186525344849, 65.18357187509537, 67.53469571471214, 68.34135442972183, 67.6448518037796, 65.58959528803825, 65.77564850449562, 62.682367488741875, 65.04491731524467, 66.09657928347588, 72.95610040426254, 74.0831807255745, 73.02073493599892, 77.38391920924187, 80.68821430206299, 84.20089781284332, 86.71150669455528, 80.54405003786087, 85.24970233440399, 86.24492213129997, 79.93846133351326, 66.91325426101685, 77.40453690290451, 88.48611786961555, 85.12797206640244, 82.53482401371002, 106.44966155290604, 46.23010531067848, 0.24960602342616767, 2.1967898961156607, 1.064954367466271, 1.0713174822740257, 0.4881487326929346, 0.37766137858852744, 0.2678505069343373, 0.264740640996024, 0.3481055551674217, 0.19350301357917488, 0.19096816366072744, 11.181366462260485, 61.77728645503521, 46.227973625063896, 49.71549488604069, 67.49055728316307, 83.41920375823975, 37.900557070970535, 56.069593727588654, 75.14123395085335, 87.40392073988914, 98.39893475174904, 96.38062745332718, 8.556010387837887, 0.46807547856587917, 0.17373041831888258, 0.24666897399583831, 0.22104871517512947, 0.15935488423565403, 0.15372875175671652, 0.26448314543813467, 0.13978753733681515, 0.11866558401379734, 0.10770030014100485, 0.11161719972733408, 0.09944759571226314, 0.12822912161936983, 0.15107063110917807, 0.12500097218435258, 0.18012094806181267, 0.17771147657185793, 0.12258947463124059, 0.18193716154200956, 0.19557945372071117, 0.1521846541436389, 0.08778196934144944, 0.16465031570987776, 0.20202375948429108, 0.08716794603969902], [0.04175840847892687, 0.07341364893363789, 0.0692496141709853, 0.024529576330678537, 0.032629331544740126, 0.048505814775126055, 0.018397861313133035, 0.08554004511097446, 0.06596834180527367, 0.05426588264526799, 0.01918240788654657, 0.028480662949732505, 0.042359507278888486, 0.026621853903634474, 0.06090579627198167, 0.07530208080424927, 0.01744069861160824, 0.059643273198162206, 0.12163997089373879, 0.27993997384328395, 0.2590406499803066, 31.1647592112422, 124.09069374203682, 86.80504247546196, 92.9277603328228, 53.07430565357208, 32.76898942887783, 36.12137094140053, 48.89023996889591, 52.50652492046356, 38.57278659939766, 43.108139634132385, 1.5316389128565788, 0.11184759947354905, 0.09725053430884145, 0.10016180895036086, 0.3793521097395569, 0.23392370087094605, 0.4886983969481662, 1.0030612698756158, 0.09643919620430097, 0.1147478458005935, 0.3948364866664633, 1.1480791820213199, 24.203247763216496, 73.75531151890755, 81.98568508028984, 79.83978062868118, 82.73069590330124, 82.18208134174347, 84.71331551671028, 85.48167988657951, 83.69937792420387, 67.90925681591034, 63.079339787364006, 61.816694140434265, 66.74815312027931, 69.51503545045853, 69.02791678905487, 66.75163373351097, 72.05624788999557, 73.92064064741135, 80.4796738922596, 77.55712151527405, 81.22979164123535, 77.00540632009506, 70.4392522573471, 67.8164353966713, 69.07242000102997, 73.15754279494286, 79.53746885061264, 80.6274251639843, 76.62766858935356, 67.07692667841911, 60.446172282099724, 59.88892078399658, 63.140273317694664, 57.77136281132698, 61.491724178195, 58.213966861367226, 64.75648999214172, 61.51425316929817, 72.81298488378525, 71.93596914410591, 78.7223593890667, 74.99299630522728, 78.1425029039383, 41.67379640042782, 38.75653333961964, 86.46673902869225, 69.31251391768456, 71.0477440059185, 60.46197563409805, 65.99648505449295, 73.72068777680397, 78.45719441771507, 73.09768840670586, 73.72117415070534, 66.90256923437119, 59.66904178261757, 57.01847121119499, 61.7066216468811, 60.64153879880905, 59.75645989179611, 58.57674099504948, 57.648758590221405, 56.65471293032169, 57.51744523644447, 58.354642912745476, 59.05883252620697, 58.863716796040535, 59.28463540971279, 60.66529892385006, 64.51007321476936, 72.66987696290016, 74.45090219378471, 78.66501286625862, 76.75599530339241, 76.61807030439377, 69.7239026427269, 62.351074665784836, 58.551905527710915, 67.55090564489365, 76.7111425101757, 85.65279990434647, 71.99026063084602, 94.37041372060776, 24.432236775755882, 0.9150502143893391, 1.4142389874905348, 1.1103565874509513, 0.10186154977418482, 0.27985394408460706, 0.17180782539071515, 0.20648826757678762, 0.05725867478759028, 0.054303145880112424, 0.033563721444807015, 0.0769362528808415, 10.995652377605438, 31.985908448696136, 27.782384008169174, 33.68018053472042, 59.61914665997028, 45.48062972724438, 33.301048278808594, 40.43959602713585, 61.86756581068039, 65.01721680164337, 90.99686354398727, 42.08262026309967, 0.1616758620366454, 0.022140725413919427, 0.013920090113970218, 0.014202789934643079, 0.01802947404939914, 0.07599713178933598, 0.018849996231438126, 0.06010704499203712, 0.027768388572440017, 0.04553634462354239, 0.03372048900928348, 0.03392999729840085, 0.015290097508113831, 0.07058993287500925, 0.06444876475143246, 0.03435056125454139, 0.06197235896252096, 0.09278548444854096, 0.036248577962396666, 0.038980828030616976, 0.0535721341293538, 0.028499721302068792, 0.04617587554093916, 0.00990602948149899, 0.007610489719809266, 0.09780713764484972, 0.041211850111722015, 0.04796034736500587, 0.07868057451560162, 0.012478236330935033, 0.07037810908514075, 0.04437577037606388, 0.07995230393134989, 0.03533623726980295, 0.05060053401393816, 0.06119057688920293, 0.009469375763728749, 0.07152655292884447, 0.07442590867867693, 0.04529577745415736, 0.06483960940386169, 0.07977539076819085, 0.0813065082184039, 0.08320976077811792, 0.31846649246290326, 0.3362484695389867, 41.83418199419975, 138.05689752101898, 97.52524763345718, 103.25504377484322, 68.94239857792854, 45.45735977590084, 34.59029629826546, 25.108733475208282, 56.020553559064865, 44.99334767460823, 41.34032629430294, 1.7346719931811094, 0.2192597830435261, 0.07320417033042759, 0.48479752033017576, 0.4191356187220663, 0.6202062231022865, 2.5141025567427278, 4.076058380305767, 0.8576421823818237, 0.1425782055594027, 0.8773599180858582, 1.467600236646831, 24.95264545083046, 79.5096543431282, 90.273906737566, 88.38587924838066, 88.65280732512474, 86.0798741877079, 89.82728630304337, 90.53271844983101, 86.82254433631897, 70.84269180893898, 65.67333519458771, 64.7041667997837, 68.83125454187393, 72.49868094921112, 73.81011217832565, 68.68619352579117, 75.68615511059761, 78.02267253398895, 83.85513916611671, 79.84393760561943, 84.2498391866684, 79.64821010828018, 72.72118180990219, 68.89600306749344, 72.48725116252899, 76.21570229530334, 81.48441597819328, 83.41806381940842, 77.86756485700607, 70.13551935553551, 64.42328587174416, 61.388149335980415, 65.83610326051712, 60.05155585706234, 63.865658193826675, 61.456921845674515, 66.53094157576561, 64.18139845132828, 75.02429902553558, 73.84972885251045, 81.46043166518211, 77.90286496281624, 82.28855162858963, 46.07511542737484, 39.82710309326649, 89.1599129140377, 73.78419756889343, 73.83222699165344, 64.50517147779465, 70.67941457033157, 75.77280566096306, 80.97518250346184, 75.65423682332039, 78.22155386209488, 70.53227886557579, 64.09310638904572, 60.321181789040565, 62.93380379676819, 64.27055686712265, 62.52439096570015, 62.040274143218994, 59.38714250922203, 58.31966958940029, 61.04997508227825, 61.80001303553581, 63.63885976374149, 63.541858568787575, 63.08255821466446, 63.98668929934502, 68.04395198822021, 73.1375102698803, 78.77850517630577, 80.80088585615158, 80.93925163149834, 80.21291300654411, 73.38993832468987, 66.29240557551384, 63.73082622885704, 71.9656303524971, 79.4763833284378, 91.26423999667168, 75.15596956014633, 100.34275844693184, 30.836122445762157, 0.7077168929390609, 1.554495992604643, 2.1379362791776657, 1.3032429059967399, 0.5530786095187068, 0.5542767327278852, 0.2719599270494655, 0.11729989128070883, 0.2617100067436695, 0.15333027782617137, 0.11278223799308762, 12.961797025054693, 33.95162656903267, 31.736543029546738, 34.99381184577942, 53.80007430911064, 41.1187069863081, 41.63850389420986, 50.83643093705177, 68.28172042965889, 73.48253175616264, 102.44059547781944, 57.855266109108925, 0.24910833919420838, 0.02790976213873364, 0.028504324473033193, 0.04226226737955585, 0.04977557007805444, 0.04841052301344462, 0.028568039706442505, 0.010846323166333605, 0.014943799342290731, 0.02267287312861299, 0.03735344660526607, 0.025195021189574618, 0.020082479022676125, 0.010774577895062976, 0.022400946509151254, 0.03235928998037707, 0.04652069590520114, 0.05820524333103094, 0.08798219336313196, 0.014607959892600775, 0.026797041573445313, 0.020608628328773193, 0.04416621013660915, 0.0394452826003544, 0.022349085229507182, 0.16783827042672783, 0.1732149373856373, 0.15433513093739748, 0.23784516466548666, 0.07394545711576939, 0.179694302205462, 0.23321846761973575, 0.19455022847978398, 0.1538631398580037, 0.19575878628529608, 0.1743597150198184, 0.14042400318430737, 0.2318066800944507, 0.151918341871351, 0.11889885587152094, 0.1828094373922795, 0.17642076301854104, 0.15026007225969806, 0.30046341475099325, 0.36838533414993435, 0.4042239720001817, 49.247021824121475, 154.90274637937546, 108.65055665373802, 120.92493921518326, 76.86647057533264, 46.900704726576805, 52.67642520368099, 69.32471126317978, 71.58457159996033, 61.91431850194931, 69.93711680173874, 2.181348237209022, 0.23358081380138174, 0.2925753645831719, 0.5768934160005301, 1.1768827051855624, 1.1389784328639507, 1.4255590550601482, 4.326490592211485, 0.8801826322451234, 0.5237196036614478, 1.7635231325402856, 2.0131253264844418, 29.63475041091442, 89.7872744500637, 95.24521797895432, 91.78852066397667, 92.07062512636185, 88.54297041893005, 91.08011707663536, 94.26107078790665, 92.53350108861923, 75.89322879910469, 68.97818505764008, 68.01022499799728, 74.43969279527664, 76.44111379981041, 76.99285179376602, 72.65967071056366, 80.6519490480423, 79.64289799332619, 88.9597624540329, 81.99266910552979, 87.73251190781593, 83.9439631998539, 77.30707213282585, 73.46235483884811, 77.48854279518127, 80.22642508149147, 85.22412970662117, 86.37731462717056, 82.03352451324463, 74.37186643481255, 65.69611877202988, 64.65878203511238, 69.00666072964668, 62.931827902793884, 68.3334356546402, 64.55865740776062, 69.77000176906586, 68.89256045222282, 79.49050337076187, 76.96562245488167, 86.529131680727, 81.24442845582962, 87.08317995071411, 51.27266272902489, 45.188866183161736, 92.29966163635254, 75.73730796575546, 76.87571927905083, 67.9011632502079, 73.64581659436226, 80.97613245248795, 86.48390650749207, 79.40868616104126, 82.41916581988335, 73.82742404937744, 65.62404423952103, 62.918004244565964, 67.31750696897507, 66.16120621562004, 65.79033091664314, 64.46554720401764, 63.034232407808304, 61.8869561702013, 63.78511771559715, 65.83435535430908, 66.90570026636124, 67.53480210900307, 66.9088388979435, 66.03180795907974, 73.04983377456665, 77.8375692665577, 81.58797562122345, 81.5454027056694, 83.22867438197136, 83.90832111239433, 77.7043180167675, 70.21018534898758, 66.08650222420692, 75.3475932776928, 83.37479174137115, 94.20159637928009, 77.85133212804794, 102.513277977705, 29.137412197887897, 2.74409091565758, 8.075943198055029, 4.082808718085289, 1.13799381069839, 0.7132252317387611, 1.4857720490545034, 0.5699134874157608, 0.4556377069093287, 0.2910802041878924, 0.3587570070521906, 0.29262871015816927, 19.916462190449238, 52.89834849536419, 40.056709572672844, 49.7738141566515, 76.07350632548332, 56.87601685523987, 47.64775604009628, 58.633232563734055, 82.47170180082321, 84.49662074446678, 113.69895055890083, 61.50863327085972, 0.5026573338545859, 0.08553462743293494, 0.08284540337626822, 0.19369499234016985, 0.20001383061753586, 0.14775231073144823, 0.15146527555771172, 0.06558589084306732, 0.06925599664100446, 0.1343721302691847, 0.13028277782723308, 0.12325198986218311, 0.10644596666679718, 0.1643186350702308, 0.18770805734675378, 0.08874795617884956, 0.20445677189854905, 0.18293934292159975, 0.1815668001654558, 0.1612743898294866, 0.11111953033832833, 0.11008856847183779, 0.0978834526904393, 0.1251573278568685, 0.24001878162380308], [0.05127084550622385, 0.02655439639056567, 0.08404860287555493, 0.02404191851383075, 0.04267826341674663, 0.03027465096238302, 0.06461745491833426, 0.0637654545425903, 0.03420226159505546, 0.018718979335972108, 0.035474284159136005, 0.036301489381003194, 0.03844237762677949, 0.03693348007800523, 0.03456323109276127, 0.06557584958500229, 0.0250506140946527, 0.03508980342303403, 0.018039476344711147, 0.0912394498300273, 0.5041159212123603, 76.7193652689457, 105.58813378214836, 89.8402664065361, 84.79543671011925, 49.718793109059334, 36.80044010281563, 97.99352690577507, 166.86230063438416, 74.7122597694397, 45.759166181087494, 10.965342354029417, 0.04504808195633814, 0.04078921185282525, 0.16504956147400662, 0.2688175847288221, 0.017559878251631744, 0.21629276569001377, 2.849205150268972, 4.876012830063701, 0.47327535110525787, 0.04972273287421558, 1.8187843984924257, 41.945945397019386, 86.03516578674316, 80.51834061741829, 78.55347365140915, 79.05669584870338, 81.45435199141502, 85.33775120973587, 82.15291410684586, 84.4409841299057, 82.53078103065491, 69.04788091778755, 60.29478080570698, 63.29996354877949, 62.279532104730606, 61.880561113357544, 60.873208567500114, 64.66173067688942, 65.21628051996231, 73.01204860210419, 75.42839974164963, 79.7517241537571, 79.92690995335579, 77.09027856588364, 75.4373824596405, 70.69573849439621, 73.32013607025146, 77.13019162416458, 77.24900364875793, 80.7581077516079, 74.52113002538681, 66.83755472302437, 59.69220153987408, 57.40622900426388, 60.64387947320938, 60.77527642250061, 59.18629668653011, 56.93852350115776, 56.589671820402145, 55.56097961962223, 62.27562591433525, 64.68743249773979, 68.80908653140068, 69.32964339852333, 77.93419808149338, 51.792771220207214, 29.713527783751488, 69.61672559380531, 71.53474107384682, 79.1184501349926, 67.80502840876579, 58.342464566230774, 65.75360208749771, 77.82141253352165, 69.76076826453209, 73.14605221152306, 67.6782064139843, 63.74466508626938, 59.28881138563156, 58.06018151342869, 58.11268329620361, 57.361763790249825, 57.32891075313091, 56.31371542811394, 55.60796029865742, 58.48021477460861, 56.56395860016346, 57.5891587883234, 59.170056357979774, 58.24798263609409, 59.48505945503712, 63.27454291284084, 68.68835180997849, 76.14644721150398, 73.62434014678001, 80.79346105456352, 75.02603933215141, 73.94637286663055, 61.545058116316795, 61.42229810357094, 61.44531726837158, 66.12140715122223, 70.2244345843792, 83.77936363220215, 77.14456245303154, 86.68395817279816, 5.40172079578042, 1.8420879542827606, 1.9271187228150666, 0.582619293127209, 0.23838121793232858, 0.27276236680336297, 0.19757805741392076, 0.17192855797475204, 0.3975829674163833, 0.04333565040724352, 0.06047195529390592, 0.7807598391082138, 23.150265365839005, 35.7701101899147, 39.57888901233673, 74.86846938729286, 117.15769976377487, 36.06543034315109, 28.58104035258293, 49.556165635585785, 64.82291802763939, 71.73457235097885, 72.95011192560196, 4.680974995717406, 0.34277307568117976, 0.09997173008741811, 0.06366843357682228, 0.06100430524384137, 0.07890390901593491, 0.02435774316836614, 0.0360557345993584, 0.07091716062859632, 0.028596682896022685, 0.030789619813731406, 0.04279075074009597, 0.02008247345656855, 0.028624214719457086, 0.03987970616435632, 0.04743618701468222, 0.052521041507134214, 0.07672385763726197, 0.018107616633642465, 0.025658405211288482, 0.03325044235680252, 0.03418340362259187, 0.052543777201208286, 0.03683393581013661, 0.0374436064157635, 0.04702829151938204, 0.020507571935013402, 0.06080053746700287, 0.03092272028879961, 0.046760008845012635, 0.029201371835370082, 0.009413441021024482, 0.023380292004731018, 0.033261415010201745, 0.04443006218934897, 0.05409034616604913, 0.03571295143046882, 0.0569654225546401, 0.012385568988975137, 0.01273975896765478, 0.03827571723377332, 0.026467147654329892, 0.05395201354986057, 0.051548805786296725, 0.11310680143651552, 1.468662517145276, 95.80438077449799, 117.44090616703033, 100.97493812441826, 94.08711612224579, 64.25659641623497, 43.03718604147434, 52.67768673598766, 101.62996977567673, 50.8171621710062, 50.36522962152958, 15.130669344216585, 0.08584546856582165, 0.055961805119295605, 0.3258571255719289, 0.22849692410090938, 0.4529634222853929, 1.012519437354058, 4.362158328294754, 6.523739313706756, 0.9325244079809636, 0.03732246193976607, 2.7416044240817428, 45.308035388588905, 97.4279348552227, 86.9547088444233, 85.80070316791534, 85.73200285434723, 88.22534546256065, 88.93308028578758, 85.01207068562508, 87.39509761333466, 88.19718137383461, 72.50606775283813, 62.55833074450493, 65.00130325555801, 64.69788953661919, 65.24914115667343, 64.5821325480938, 68.8312241435051, 69.13893923163414, 74.70219790935516, 78.83928671479225, 83.12427118420601, 81.59511163830757, 80.27336776256561, 79.45323497056961, 73.46606343984604, 77.08280056715012, 80.18253743648529, 79.69862580299377, 81.10213369131088, 76.97265967726707, 71.22397854924202, 62.14538790285587, 61.05774186551571, 63.14533084630966, 62.54039570689201, 61.69556804001331, 59.745246693491936, 60.29458701610565, 59.819969683885574, 65.28894782066345, 66.49312600493431, 70.96218779683113, 71.37593239545822, 79.60868462920189, 57.5449975579977, 31.442397013306618, 74.62560161948204, 73.95496040582657, 82.69388347864151, 70.98424941301346, 61.296600848436356, 69.20469090342522, 81.82344138622284, 72.26768374443054, 76.4524295926094, 70.75115472078323, 65.71392461657524, 61.00149728357792, 61.820596531033516, 62.096811309456825, 60.28403118252754, 59.357390105724335, 58.33380863070488, 58.12831185758114, 60.53650103509426, 60.00849276781082, 60.12702740728855, 62.22378149628639, 60.099855065345764, 62.91684150695801, 66.85354426503181, 70.5643643438816, 79.65553611516953, 76.5591050684452, 81.66731536388397, 78.52334886789322, 78.46949815750122, 65.3719049692154, 64.39924836158752, 64.3307076394558, 69.11245465278625, 71.57004877924919, 88.09442728757858, 80.11113926768303, 96.47996932268143, 7.825061660259962, 1.4193861675448716, 1.41691570635885, 1.7356510343961418, 2.0046717301011086, 1.6328988480381668, 0.26720902416855097, 0.4341912717791274, 0.9849634347483516, 0.15552630764432251, 0.08475896436721087, 0.3526400774717331, 26.7903845384717, 29.683023020625114, 38.4383650124073, 58.087388053536415, 93.70241716504097, 38.936267495155334, 41.802438497543335, 57.90241777896881, 72.171351313591, 78.9189000427723, 92.4465237557888, 8.445909395813942, 0.4581000341568142, 0.037625573604600504, 0.06122231854533311, 0.08286728188977577, 0.06061005413357634, 0.03618696115154307, 0.03681869951833505, 0.016200083737203386, 0.05976012434985023, 0.02015726153331343, 0.07536896315286867, 0.08156057505402714, 0.012847989146393957, 0.02661505583091639, 0.009235922079824377, 0.004471078882488655, 0.0600958274299046, 0.05976278494927101, 0.016683808171364944, 0.050247123290318996, 0.06619558000238612, 0.0265598790065269, 0.020994960723328404, 0.024870290762919467, 0.2131596111576073, 0.07138187866075896, 0.20230798720149323, 0.21454018395161256, 0.10406969886389561, 0.18148422881495208, 0.14054246479645371, 0.24419444584054872, 0.1542925910325721, 0.1586477956152521, 0.16147203859873116, 0.12828723178245127, 0.15244404959958047, 0.08421753052971326, 0.1647072087507695, 0.11027472879504785, 0.1552638693829067, 0.1499790357775055, 0.16300635470543057, 0.366419741185382, 1.9867835962213576, 111.65652975440025, 132.55182892084122, 114.35037240386009, 109.07206803560257, 70.10357826948166, 55.477376505732536, 120.14598101377487, 184.40539687871933, 96.95572659373283, 76.14125669002533, 19.972341991961002, 0.1762112250435166, 0.2881530550075695, 0.5842212634161115, 0.6123099499382079, 1.398582283873111, 1.0155817167833447, 11.035917866975069, 16.22753843665123, 2.659074515104294, 0.9981113229878247, 3.5085790185257792, 53.12844514846802, 101.88679039478302, 89.28690969944, 89.1538256406784, 91.35230407118797, 93.19476440548897, 90.7516323029995, 86.78094416856766, 90.62527388334274, 89.89247560501099, 77.26307809352875, 65.34413605928421, 69.7616346180439, 69.05274465680122, 69.25667971372604, 66.49124890565872, 71.80140316486359, 72.29596942663193, 79.81642708182335, 82.3345747590065, 87.71689474582672, 83.35285931825638, 83.15296724438667, 83.16213235259056, 79.07036751508713, 80.60480877757072, 84.41861093044281, 80.09162351489067, 84.73654747009277, 81.24297693371773, 73.58554422855377, 65.41493386030197, 62.39875830709934, 65.3723381459713, 65.06769329309464, 63.43884989619255, 62.67580524086952, 63.8401235640049, 65.26743337512016, 69.7757014632225, 70.71289077401161, 75.60410231351852, 77.01600775122643, 84.20695468783379, 60.89133359491825, 36.50930732488632, 81.64391621947289, 77.67817541956902, 87.1416512131691, 76.73245176672935, 65.5741985142231, 74.83577594161034, 86.8340653181076, 75.19297197461128, 78.70374038815498, 73.86178180575371, 69.31197434663773, 63.73206876218319, 62.91793204843998, 65.6316514313221, 62.445556595921516, 63.92915278673172, 63.926249742507935, 62.3372396081686, 64.62297275662422, 62.20216825604439, 64.13738161325455, 67.32201352715492, 66.02588027715683, 67.69253924489021, 70.0621072947979, 76.04177042841911, 84.45706486701965, 79.3107882142067, 85.60939103364944, 80.93453228473663, 82.24787101149559, 68.81044685840607, 67.82728761434555, 68.6202746629715, 70.50447195768356, 75.19094288349152, 93.22048902511597, 83.33194524049759, 97.9639644920826, 6.392683871090412, 6.0286439303308725, 9.436197057366371, 3.4221683302894235, 2.052173218689859, 1.379146920517087, 0.5339296557940543, 0.739907103125006, 1.9629920041188598, 0.20598099479684606, 0.2445613784948364, 1.2878285581246018, 42.319222167134285, 53.49482148885727, 57.894882783293724, 87.83493921160698, 130.0651815533638, 45.619949251413345, 46.89701892435551, 67.3497824370861, 87.16939732432365, 89.0789620578289, 106.84822976589203, 9.299398697912693, 0.5834931274875998, 0.26599433622322977, 0.09565945132635534, 0.2108409340144135, 0.18995168851688504, 0.15316731703933328, 0.06843793467851356, 0.14941340050427243, 0.18233190989121795, 0.13577896024798974, 0.17699441348668188, 0.1906860139570199, 0.12840480281738564, 0.1013593161769677, 0.20627121906727552, 0.15957856754539534, 0.14695423480588943, 0.1329577006981708, 0.17210671794600785, 0.12156192664406262, 0.14750051486771554, 0.2227103541372344, 0.06984556617680937, 0.09796225393074565], [0.03974929226387758, 0.05230966671661008, 0.03417387073568534, 0.03717667073942721, 0.05443846166599542, 0.036244180737412535, 0.07881605357397348, 0.026730999707069714, 0.040806411125231534, 0.030409389728447422, 0.04055310128023848, 0.05167759067262523, 0.0187487709990819, 0.02729582232859684, 0.09306431675213389, 0.04310548072680831, 0.07534129588748328, 0.06060865518520586, 0.3274361486546695, 0.34677096584346145, 15.266495905816555, 109.92581382393837, 87.78913646936417, 89.60660174489021, 72.01907828450203, 57.498830035328865, 43.15877191722393, 145.33294469118118, 148.75998079776764, 69.92558062076569, 26.392638981342316, 1.212013007607311, 0.08296599495224655, 0.2744039084063843, 0.2934150898363441, 0.6094354635570198, 0.4335678677307442, 0.3297733794897795, 4.924265015870333, 6.850310415029526, 1.0997514752671123, 2.2255439031869173, 53.34488533437252, 88.22931244969368, 80.61088845133781, 80.4137322306633, 76.92636296153069, 77.47060775756836, 84.05920341610909, 83.77670377492905, 87.87449508905411, 82.49390780925751, 84.71509382128716, 67.72467792034149, 57.884292751550674, 59.3312057107687, 59.31749604642391, 59.492894634604454, 60.92502638697624, 64.85217645764351, 68.10063734650612, 68.98655220866203, 73.58090087771416, 75.3401380777359, 76.69618651270866, 74.00289103388786, 75.11620089411736, 76.24221727252007, 78.81727829575539, 76.84258505702019, 76.86029970645905, 70.66538572311401, 75.28802767395973, 65.67792534828186, 56.31026141345501, 59.553170800209045, 60.20194798707962, 61.43102243542671, 56.506311893463135, 56.7841187864542, 52.84297786653042, 54.006619825959206, 55.39040297269821, 54.935157001018524, 62.548527270555496, 67.34364196658134, 70.0576539337635, 65.43380364775658, 25.58245785534382, 52.175061106681824, 72.92105868458748, 73.87364476919174, 74.94528606534004, 61.647838801145554, 65.39142072200775, 75.4470643401146, 73.48176419734955, 72.21526935696602, 67.53794074058533, 66.15436658263206, 57.8085970133543, 56.033047288656235, 55.297794342041016, 56.62095934152603, 54.83224332332611, 54.06477190554142, 56.20000272989273, 55.12012727558613, 57.885998860001564, 58.01352001726627, 56.92664913833141, 60.97021736204624, 63.56485113501549, 69.17113110423088, 66.76883161067963, 72.34214454889297, 74.67278748750687, 74.65183541178703, 73.03116157650948, 72.5833024084568, 59.594193398952484, 59.91596773266792, 58.621407598257065, 64.26919654011726, 72.19094306230545, 77.06396877765656, 79.99026015400887, 86.76025807857513, 55.933644622564316, 0.21607662260066718, 1.9455526024103165, 2.0383445732295513, 0.4937212821096182, 0.4752055584685877, 0.1186302058340516, 0.16432975244242698, 0.3180399356642738, 0.010445520747452974, 0.15612415212672204, 0.04106560991203878, 3.47629951313138, 29.105963185429573, 27.65051018446684, 81.4269706606865, 130.66988110542297, 97.10952714085579, 23.53581167757511, 49.70481365919113, 62.90432497859001, 70.93799829483032, 80.68823710083961, 28.005040660500526, 0.595835221465677, 0.14618937741033733, 0.1679358331602998, 0.06706580752506852, 0.074945464002667, 0.023818545050744433, 0.008119231952150585, 0.02523403032682836, 0.03664435418613721, 0.020374443629407324, 0.08844744574162178, 0.04423262122145388, 0.08555164487916045, 0.008149972636601888, 0.009397950543643674, 0.04926729168801103, 0.060529568218044005, 0.042078956903424114, 0.012349277967587113, 0.01892185096949106, 0.01945954623806756, 0.05577952993917279, 0.043680938324541785, 0.05130782301421277, 0.037394164537545294, 0.02174946330342209, 0.029289600206539035, 0.009442493319511414, 0.032226200637524016, 0.06275376625126228, 0.018460687824699562, 0.11827889538835734, 0.03368428704561666, 0.06088412555982359, 0.07021046534646302, 0.06890615564770997, 0.02050569801212987, 0.04927153677272145, 0.08653611861518584, 0.018516443524276838, 0.11854122974909842, 0.23476134811062366, 0.2850924973608926, 0.6015609798487276, 20.059826597571373, 124.02863547205925, 96.9008195400238, 101.37060329318047, 81.42247170209885, 71.79039135575294, 46.685442477464676, 135.29737919569016, 157.3257091641426, 61.74009405076504, 35.23798294365406, 0.8311408606823534, 0.05881780460185837, 0.30523135734256357, 0.4148729599546641, 0.4117464699083939, 1.189795599784702, 2.8385020745918155, 4.4510607328265905, 1.6714885085821152, 0.35194239928387105, 2.8173535969108343, 58.37372928857803, 98.04888993501663, 84.92564052343369, 86.4630988240242, 82.40990191698074, 82.44729191064835, 86.87988325953484, 87.88819715380669, 89.03904899954796, 87.11135923862457, 88.76803234219551, 72.28129461407661, 61.07057757675648, 62.34320908784866, 62.36946947872639, 64.31022673845291, 64.16619926691055, 68.61066117882729, 70.87494447827339, 71.95006638765335, 76.45033970475197, 78.89598727226257, 80.18483251333237, 74.27558720111847, 77.10486218333244, 78.44596982002258, 81.05336710810661, 79.16512683033943, 77.61981055140495, 76.50667548179626, 78.5810449719429, 69.77411314845085, 59.48912523686886, 60.929745733737946, 62.95538283884525, 63.40943947434425, 58.877985030412674, 59.46667984127998, 57.14279294013977, 58.04711401462555, 59.360118359327316, 58.01797717809677, 64.98511612415314, 71.34600520133972, 72.02958092093468, 66.67771250009537, 30.42197696864605, 60.47940529882908, 73.31565991044044, 78.17889735102654, 77.83588215708733, 65.08828058838844, 68.26619446277618, 76.49196267127991, 75.77188611030579, 74.92868855595589, 71.13124832510948, 68.18804025650024, 60.92175096273422, 58.51792395114899, 58.68737205862999, 59.35183100402355, 56.417199075222015, 57.611516788601875, 58.105060905218124, 59.31562274694443, 59.94329586625099, 62.99059934914112, 60.678997188806534, 63.69463697075844, 66.25775903463364, 70.92830881476402, 70.96440687775612, 76.88172295689583, 76.29160702228546, 76.89451307058334, 78.4555073082447, 76.36088490486145, 63.29247795045376, 62.72965595126152, 61.376837342977524, 66.16327330470085, 77.61278852820396, 79.59587931632996, 82.72039845585823, 87.57491916418076, 65.124941021204, 0.43623116856906563, 0.8094700297806412, 0.9926803456619382, 1.7015228094533086, 1.479156247805804, 1.0758919618092477, 0.3006419457960874, 0.7898509106598794, 0.3836351033532992, 0.19834227656247094, 0.12986064422875643, 3.0455598514527082, 34.33124139904976, 26.583609133958817, 64.96196016669273, 117.26799264550209, 79.01911586523056, 30.60034889727831, 58.36810939013958, 71.75367012619972, 81.82347938418388, 93.8306374847889, 44.96735326945782, 0.37411159719340503, 0.049743383133318275, 0.07852434500819072, 0.07151919082389213, 0.08391296796617098, 0.041548985536792316, 0.059258042892906815, 0.04815749889530707, 0.036883655993733555, 0.042822403338504955, 0.02058163270703517, 0.011398301994631765, 0.02769589002127759, 0.06786289639421739, 0.0910172211297322, 0.0803682702826336, 0.02266787847474916, 0.04665143263991922, 0.01911796905915253, 0.039299268755712546, 0.02290909873408964, 0.07191005774075165, 0.032692803724785335, 0.06584012095117941, 0.10018579516327009, 0.13129224709700793, 0.08654074219521135, 0.09369525359943509, 0.1526564225787297, 0.2722969214664772, 0.19348379195434973, 0.1613663270836696, 0.13503020745702088, 0.1911138027207926, 0.14452842122409493, 0.13533227640436962, 0.22691013815347105, 0.151990671583917, 0.2700250589987263, 0.1386378169991076, 0.14502543752314523, 0.3621701442170888, 0.6730246951337904, 0.9178471018094569, 24.7873942181468, 142.1709367632866, 109.86214444041252, 113.41718807816505, 96.02767959237099, 75.04513710737228, 65.82830607891083, 160.35212516784668, 142.15192258358002, 98.16254943609238, 45.35604581236839, 2.5091124745085835, 0.2371796066290699, 0.6899596739094704, 0.7028049440123141, 1.7431756993755698, 1.6600557533092797, 1.997272577136755, 14.586850125342607, 18.005512431263924, 4.571442548185587, 3.0090882210060954, 65.6205104291439, 100.90746134519577, 88.07285204529762, 90.71565583348274, 85.42994946241379, 86.47616252303123, 92.75953575968742, 94.44459334015846, 91.57619565725327, 90.4401858150959, 93.916474878788, 75.00299736857414, 63.35323669016361, 63.88671666383743, 66.20040491223335, 66.95277214050293, 70.09823575615883, 72.04497769474983, 75.18882259726524, 75.66355392336845, 80.37232205271721, 82.10835009813309, 81.54847294092178, 80.14762490987778, 79.9809430539608, 82.5494684278965, 84.84000071883202, 81.77577674388885, 79.2660266160965, 80.03413259983063, 82.49993428587914, 73.43587026000023, 62.3224887996912, 63.21967385709286, 66.03791803121567, 66.17757573723793, 60.65552584826946, 62.00144402682781, 59.78539153933525, 60.073340088129044, 62.78628051280975, 60.06161771714687, 69.2690746486187, 73.74614641070366, 76.58264860510826, 71.52170777320862, 36.79572455585003, 61.77363485097885, 77.78362736105919, 81.78969159722328, 80.99473625421524, 68.54202926158905, 72.72758066654205, 81.03549286723137, 80.32450541853905, 80.5772602558136, 75.22893324494362, 72.6648460328579, 64.95259746909142, 59.75710965692997, 62.06426605582237, 62.909979075193405, 59.77558806538582, 60.91403737664223, 61.95303462445736, 61.7141642421484, 63.31126794219017, 65.74722602963448, 64.05668914318085, 66.13786026835442, 68.13309520483017, 74.16055217385292, 73.22612911462784, 78.83262187242508, 79.19212058186531, 77.08700314164162, 81.12601920962334, 80.44899433851242, 66.11857250332832, 66.5966248512268, 65.88962718844414, 71.08554437756538, 80.84744095802307, 83.96407932043076, 87.34937086701393, 90.32610073685646, 65.56897759437561, 0.3362582658883184, 6.654548719525337, 8.78665516152978, 3.03013457916677, 1.4602160453796387, 0.9709673014003783, 0.5761820229236037, 2.491409699432552, 0.3592992201447487, 0.34605351684149355, 0.1575124729424715, 5.9394370671361685, 49.63669091463089, 45.73937684297562, 92.61708900332451, 135.39520114660263, 103.40124472975731, 36.280608996748924, 66.95892781019211, 82.93596088886261, 91.65843084454536, 107.7860726416111, 50.96761889755726, 0.6296254426706582, 0.26805652712937444, 0.23374815325951204, 0.10821088289958425, 0.21060312021290883, 0.13860075414413586, 0.10814008943270892, 0.16421412583440542, 0.21527710690861568, 0.09487959512625821, 0.14593277242965996, 0.112658922735136, 0.09542534084175713, 0.18569603562355042, 0.22191294614458457, 0.18799599580233917, 0.07836038974346593, 0.14680322259664536, 0.08592301557655446, 0.09558183752233163, 0.11597987031564116, 0.2040185930673033, 0.0998764754331205, 0.24383034819038585], [0.03499790698697325, 0.01985461185540771, 0.08318535896250978, 0.07871371883084066, 0.060762469001929276, 0.05751436321588699, 0.04908404058369342, 0.060308946267468855, 0.0902363407658413, 0.020313463210186455, 0.0731814383470919, 0.03841820216621272, 0.058033788664033636, 0.06150688022898976, 0.01707533374428749, 0.038536749125341885, 0.013183299815864302, 0.048856705907383, 0.11145792741444893, 0.28771118028089404, 34.906891509890556, 99.95602279901505, 89.16975438594818, 102.03321933746338, 48.06822627782822, 31.083584167063236, 41.12800508737564, 40.4537008702755, 44.78078328073025, 46.69350944459438, 9.46733258664608, 0.10865928852581419, 0.06032583383785095, 0.12323542512604035, 0.14382593391928822, 0.32880645012483, 0.1602810696931556, 1.9499476603232324, 1.7096287244930863, 1.5346305398270488, 3.4063668781891465, 51.14216633141041, 93.0151404440403, 81.8576243519783, 82.13985040783882, 73.11155766248703, 69.73663195967674, 68.41060191392899, 79.17274162173271, 80.53774237632751, 87.79982909560204, 83.75455096364021, 82.64171987771988, 67.72676780819893, 58.202217891812325, 59.39725376665592, 60.96830986440182, 65.34516960382462, 63.28494295477867, 66.76329150795937, 68.10374557971954, 68.02759766578674, 71.81005910038948, 72.44216278195381, 79.00862842798233, 78.50143164396286, 72.84694746136665, 74.92111176252365, 74.81401830911636, 78.0097608268261, 70.63336104154587, 73.3931377530098, 72.34930336475372, 58.142971470952034, 55.967447608709335, 56.89753130078316, 59.83561344444752, 58.710357025265694, 59.180870577692986, 56.18945449590683, 55.63233599066734, 53.04649114608765, 54.396155923604965, 54.319666028022766, 64.54213589429855, 67.83081382513046, 72.1104633808136, 65.90821579098701, 36.170411109924316, 76.19514539837837, 69.3933279812336, 74.45463359355927, 71.25810071825981, 57.41496093571186, 60.06037898361683, 69.93318021297455, 70.74164763092995, 73.66451919078827, 72.25557759404182, 67.88420855998993, 61.67259067296982, 56.339516043663025, 54.486108496785164, 54.50300619006157, 52.54232659935951, 52.20621943473816, 54.83660168945789, 57.83438242971897, 57.41406798362732, 60.02514347434044, 60.41906453669071, 63.76563236117363, 65.61477273702621, 68.65395605564117, 71.58489838242531, 74.50510248541832, 71.34592920541763, 72.15529337525368, 74.04127657413483, 71.89020439982414, 58.0070261657238, 56.141634061932564, 57.24092647433281, 64.17852580547333, 71.18517503142357, 75.74043899774551, 76.71950966119766, 78.80121275782585, 86.75698265433311, 40.16390182077885, 0.07881186786107719, 0.810963052790612, 3.340238551609218, 1.1116177635267377, 0.1958193158498034, 0.01027896332743694, 0.24684217642061412, 0.2192602728609927, 0.08905285270884633, 0.05539954661799129, 0.011094817400589818, 12.205810490995646, 30.36640305072069, 55.18830321729183, 95.9330266714096, 92.9122343659401, 35.995673686265945, 43.267123103141785, 62.043268382549286, 60.659584030508995, 74.76484134793282, 69.04022052884102, 4.096842315047979, 0.3282419132301584, 0.06788906452129595, 0.09455973689910024, 0.013942920431873063, 0.061050155127304606, 0.0581026933650719, 0.06256494161789306, 0.0783030514139682, 0.034805430987034924, 0.059594510385068133, 0.026709208395914175, 0.026762869383674115, 0.015390272601507604, 0.042746444523800164, 0.05396295280661434, 0.051413070686976425, 0.01942973045515828, 0.01828119198762579, 0.04633342978195287, 0.07388970698229969, 0.025922348177118693, 0.06680511331069283, 0.02580171207227977, 0.033043294097296894, 0.03882564866216853, 0.00934732679525041, 0.0478619868226815, 0.06705307969241403, 0.073487500048941, 0.049587450484978035, 0.05540964353713207, 0.07124944982933812, 0.08410262380493805, 0.02365823558648117, 0.04936178193020169, 0.016817650794109795, 0.01868183298938675, 0.013374353675317252, 0.005028296345699346, 0.047435871601919644, 0.07001412275712937, 0.09267327914130874, 0.2575426991097629, 45.85410788655281, 113.7640030682087, 96.89891964197159, 113.14486429095268, 63.5684609413147, 46.688254326581955, 40.79864636063576, 53.645054027438164, 57.080077305436134, 54.522442147135735, 11.991581786423922, 0.14931960788089782, 0.009062859735422535, 0.6429382064379752, 0.7067438482772559, 0.7483864668756723, 1.100031710229814, 3.5375230154022574, 1.9212625245563686, 0.13247123773908243, 3.419500873424113, 57.60994367301464, 99.84817698597908, 87.02831089496613, 88.2865297794342, 76.87985345721245, 74.50729876756668, 71.31249099969864, 82.85489603877068, 83.45872163772583, 91.81038469076157, 86.44700288772583, 85.66669195890427, 73.00838559865952, 60.41744962334633, 63.09113435447216, 64.65814366936684, 69.32328253984451, 66.99341475963593, 70.50317242741585, 71.8760995566845, 72.39889070391655, 76.45231559872627, 76.8657486140728, 79.9955266714096, 80.73919236660004, 74.06875669956207, 78.71020004153252, 77.98363342881203, 77.9903894662857, 73.93375754356384, 77.68056929111481, 75.13041213154793, 60.78346498310566, 57.997811660170555, 59.148017540574074, 62.078982666134834, 61.56414069235325, 60.6336922198534, 58.7315408885479, 57.053649723529816, 55.167974308133125, 58.145768120884895, 57.310827523469925, 67.58505821228027, 70.29891058802605, 75.8933199942112, 66.81167811155319, 38.56372028589249, 80.1368410885334, 74.16154772043228, 75.88727831840515, 71.49410605430603, 60.13131357729435, 61.51594027876854, 73.00258710980415, 74.36284571886063, 76.87857672572136, 74.74451243877411, 71.6332545876503, 63.626229241490364, 57.92715825140476, 55.914888828992844, 57.18799151480198, 56.6033510863781, 55.925197675824165, 57.72820092737675, 60.92211954295635, 59.45724114775658, 62.67506808042526, 62.10758753120899, 66.02496832609177, 68.12852784991264, 73.65976184606552, 74.04444560408592, 78.36346864700317, 71.74201235175133, 76.05056315660477, 77.53892049193382, 76.05850473046303, 61.35737858712673, 59.0290155261755, 60.68679817020893, 66.27570167183876, 72.52467915415764, 79.98254656791687, 79.92478966712952, 82.55123153328896, 89.29998099803925, 47.90065906941891, 0.3025532135507092, 0.5826654843986034, 1.1693872511386871, 1.1938001099042594, 0.9332805674057454, 0.8023258193861693, 0.8482546673621982, 0.6436364189721644, 0.4815822100499645, 0.08949705035774969, 0.0755911621672567, 14.036576002836227, 33.856874853372574, 51.07998266816139, 92.05393642187119, 82.12832942605019, 33.951520174741745, 56.15748681128025, 67.6890966296196, 70.54996311664581, 79.84152093529701, 89.24692824482918, 7.490092534571886, 0.419021921698004, 0.08563753362977877, 0.0884749719989486, 0.06820671856985427, 0.03594968169636559, 0.06667227629804984, 0.022449742718890775, 0.06969803464016877, 0.03985484792792704, 0.037610266808769666, 0.04294265352655202, 0.007873994818510255, 0.07231637617223896, 0.010773098238132661, 0.01606499801710015, 0.021429616208479274, 0.029693543765461072, 0.10008657744037919, 0.10226584214251488, 0.051536812679842114, 0.03134297068754677, 0.06609676303924061, 0.0550149137416156, 0.09196877319482155, 0.1128807952045463, 0.1957471197238192, 0.15983370307367295, 0.18269841209985316, 0.15938338270643726, 0.15662361751310527, 0.1456994263571687, 0.16448049747850746, 0.1190563099225983, 0.1430262252688408, 0.16114834346808493, 0.11866038898006082, 0.17172096442664042, 0.15858297643717378, 0.14951615827158093, 0.14442170038819313, 0.2250540119712241, 0.2662842784775421, 0.43318919430021197, 57.70618490874767, 129.62025582790375, 111.44849091768265, 127.04542279243469, 69.11589726805687, 45.3364996612072, 60.28986766934395, 56.49449072778225, 61.019751504063606, 72.7409939467907, 16.547078490257263, 0.24609562038676813, 0.27410761336795986, 0.681055742315948, 2.559841889888048, 1.4522902644239366, 0.7679782155901194, 6.829952532425523, 5.404426725581288, 8.873265814036131, 5.082773035392165, 61.3889928907156, 105.22987380623817, 88.00906866788864, 92.25133582949638, 79.87840935587883, 78.51517170667648, 76.47441521286964, 87.62886866927147, 88.44708636403084, 94.2391611635685, 89.62308526039124, 90.72048157453537, 77.52891942858696, 63.39065708220005, 67.08184361457825, 67.83494800329208, 71.8016767501831, 69.56592991948128, 74.48542714118958, 74.40387591719627, 74.55487221479416, 80.48339769244194, 79.3161915242672, 84.93267014622688, 81.60588026046753, 77.21271559596062, 84.28833872079849, 80.37696540355682, 81.22780814766884, 77.51149356365204, 81.92808777093887, 78.4470945596695, 65.08891135454178, 60.6124247610569, 62.71513693034649, 66.34668946266174, 65.0743505358696, 64.47924926877022, 64.20941054821014, 61.666226014494896, 59.60520900785923, 61.52870759367943, 62.126267328858376, 70.72811275720596, 75.46703606843948, 78.13249424099922, 72.05313205718994, 43.74892204999924, 80.5782862007618, 78.56168121099472, 80.07522359490395, 76.83913484215736, 63.37306782603264, 65.71411460638046, 78.2844252884388, 80.19679427146912, 79.65970829129219, 79.10137385129929, 74.0517108142376, 67.634387165308, 60.43747074902058, 61.62436746060848, 60.963240936398506, 61.91034771502018, 60.03614008426666, 61.800624802708626, 65.45267343521118, 64.49339970946312, 67.61623933911324, 64.8548287153244, 68.83572310209274, 69.89347234368324, 76.54197558760643, 78.34003150463104, 81.02202638983727, 74.41361099481583, 79.31223973631859, 79.51352253556252, 80.71545124053955, 63.60685408115387, 61.91014252603054, 64.68319192528725, 70.54357945919037, 76.27086773514748, 82.60162442922592, 82.07722216844559, 85.75253695249557, 91.09298318624496, 47.590732499957085, 0.311862476519309, 5.09282729588449, 9.627846423536539, 5.097305830568075, 1.084944144822657, 0.7409868983086199, 1.023059596773237, 1.7422684980556369, 0.41147899988573045, 0.28898431977722794, 0.17570367024745792, 21.75657995045185, 51.92702181637287, 70.85276126861572, 101.61163195967674, 100.99382311105728, 46.23705893754959, 62.148313745856285, 79.25852581858635, 82.29381814599037, 90.53804576396942, 102.28533580899239, 8.070302400738, 0.6701859505847096, 0.16915264364797622, 0.3336451936047524, 0.12497814372181892, 0.20582842407748103, 0.2739158720942214, 0.12741375365294516, 0.11007138033164665, 0.19023089931579307, 0.13973650726256892, 0.14416324003832415, 0.10270671496982686, 0.12030756348394789, 0.2074535345309414, 0.12431399576598778, 0.17392460867995396, 0.13864103792002425, 0.23955032316735014, 0.2042602066649124, 0.1740884452010505, 0.10424530584714375, 0.16964051668765023, 0.1226992234296631], [0.0505296811752487, 0.03696899926580954, 0.008864705378073268, 0.1274395507061854, 0.07871426059864461, 0.013053312650299631, 0.09128796402364969, 0.03393140737898648, 0.02370029495068593, 0.05941222407273017, 0.0337620938080363, 0.05147642041265499, 0.052279338851803914, 0.030148328150971793, 0.01510082573076943, 0.03639564565673936, 0.06318781874142587, 0.08222654127166606, 0.027251182145846542, 0.6782828411087394, 72.22510322928429, 93.02835613489151, 85.4614269733429, 74.56433370709419, 46.81165650486946, 37.35927991569042, 55.559946075081825, 51.116863489151, 50.74261777102947, 27.253999561071396, 0.12266106219612993, 0.020548579304886516, 0.1612821823800914, 0.10577271255897358, 0.29156806238461286, 0.09819736631470732, 0.9430826758034527, 5.075794234871864, 1.3969887443818152, 0.6232295546215028, 38.238024562597275, 90.88400959968567, 83.64722952246666, 81.37548342347145, 72.81455039978027, 69.05390739440918, 64.79538470506668, 61.531063467264175, 68.3162073791027, 82.87979230284691, 82.19953760504723, 82.67053753137589, 81.02517262101173, 63.14231380820274, 55.78878879547119, 61.828982681035995, 66.22058182954788, 68.0377659201622, 65.8341121673584, 68.10737058520317, 72.177864164114, 73.11937004327774, 70.04952237010002, 72.56333827972412, 73.90575304627419, 77.80578017234802, 73.4884062409401, 74.99719128012657, 72.28869661688805, 71.64888694882393, 72.32715055346489, 72.82740131020546, 62.0332483202219, 55.43322667479515, 57.27825187146664, 56.66700527071953, 59.97363343834877, 58.12634736299515, 58.899860456585884, 55.375253185629845, 55.589915066957474, 58.74537214636803, 56.472147926688194, 59.49091114103794, 62.74783417582512, 64.5440585911274, 71.92707002162933, 67.5945197045803, 52.59361244738102, 73.9559331536293, 61.66861988604069, 62.58606165647507, 55.43855018913746, 55.41985899209976, 55.69777227938175, 67.6474280655384, 70.27663618326187, 70.07421344518661, 68.92183408141136, 66.47743284702301, 62.12695509195328, 58.57051692903042, 52.03725390136242, 55.43392963707447, 52.20053493976593, 54.596857354044914, 54.72215183079243, 57.49692253768444, 58.54823112487793, 61.52874559164047, 62.61768355965614, 69.74209606647491, 69.1968709230423, 74.03683841228485, 72.26712137460709, 74.18467327952385, 71.47788852453232, 69.99099031090736, 70.16529455780983, 73.50587770342827, 57.22061276435852, 57.06674762070179, 55.13599522411823, 69.29681316018105, 68.37873682379723, 70.99602118134499, 74.45257410407066, 77.25590407848358, 74.67722564935684, 87.26645171642303, 35.759007185697556, 0.22145924158394337, 0.93261833419092, 2.228983431123197, 1.3904985738918185, 0.14524273836286739, 0.1740121524198912, 0.5163770320359617, 0.31311738886870444, 0.17094910115702078, 0.2945073531009257, 2.2195143392309546, 21.511829383671284, 29.9325917288661, 62.91320890188217, 64.72070351243019, 37.835557758808136, 19.616063609719276, 41.48798257112503, 62.58762337267399, 71.4450278878212, 76.59569710493088, 25.85013449192047, 0.48227831488475204, 0.1537170258234255, 0.06327701004920527, 0.09928729923558421, 0.041274554168921895, 0.03616460024204571, 0.019484176264086273, 0.06719626966514625, 0.0532652746187523, 0.015150938324950403, 0.033593949119676836, 0.0372079225780908, 0.011349875003361376, 0.010013700266426895, 0.038570939868805, 0.004913812645099824, 0.007903292953415075, 0.0861780100967735, 0.036255620943848044, 0.02640352333401097, 0.008998930206871592, 0.07533816402428783, 0.024538521065551322, 0.015367666783276945, 0.043353525034035556, 0.08620615975814871, 0.0763374732923694, 0.05130649828060996, 0.04135537405090872, 0.05351838037313428, 0.10243638025713153, 0.08645366600831039, 0.009575759850122267, 0.04262416456185747, 0.08821403287583962, 0.042733787195174955, 0.07406837161397561, 0.023448853462468833, 0.060640033188974485, 0.07548580688307993, 0.08023674687137827, 0.05179541403776966, 1.4579991018399596, 91.32623746991158, 102.24629670381546, 93.26149642467499, 82.4920991063118, 56.366562992334366, 37.58887879550457, 48.40715289115906, 60.749263018369675, 57.63085015118122, 32.46952749788761, 0.2909332886338234, 0.12625345028936863, 0.19298539526062086, 0.7976334274280816, 0.7401010114699602, 1.138757688459009, 2.608071989379823, 5.891274651512504, 0.46082790184300393, 0.8965577348135412, 44.214689657092094, 97.55096465349197, 87.19452157616615, 88.45795378088951, 76.12681746482849, 73.62190067768097, 69.44625914096832, 66.85587733983994, 72.26129248738289, 85.78069344162941, 86.2391996383667, 85.9685705602169, 83.94828736782074, 67.75208204984665, 58.90163116157055, 65.59540897607803, 68.26592847704887, 72.45785593986511, 69.72963273525238, 72.33386859297752, 76.46493852138519, 77.8488090634346, 73.48100423812866, 75.50629556179047, 76.94334805011749, 79.67813730239868, 75.26910468935966, 76.71042814850807, 74.92228209972382, 75.84438621997833, 76.99961543083191, 74.82410296797752, 64.66494530439377, 57.523182928562164, 59.615966230630875, 60.270192325115204, 60.981643348932266, 61.383775770664215, 62.0872700214386, 57.04604633152485, 58.86263005435467, 60.25984548032284, 60.048447623848915, 62.74827875196934, 66.85262471437454, 68.75101804733276, 74.44446533918381, 69.08794596791267, 57.50123530626297, 77.4478317797184, 63.29487182199955, 64.39240872859955, 57.783415764570236, 57.53582485020161, 58.51929187774658, 70.73695108294487, 72.85811886191368, 72.8860853612423, 71.61103338003159, 70.3356546163559, 64.84148383140564, 60.78826032578945, 54.77870039641857, 58.7622394412756, 55.200344771146774, 56.9286934286356, 57.08710312843323, 61.94100446999073, 62.07368195056915, 64.60027277469635, 65.32854169607162, 71.95501372218132, 72.95113787055016, 77.19278946518898, 74.96264353394508, 76.23928382992744, 73.78824815154076, 71.2504555284977, 74.94920745491982, 77.20332249999046, 60.996485352516174, 59.174327328801155, 60.88354781270027, 72.76700735092163, 72.11907371878624, 74.04643669724464, 76.86805129051208, 81.04439198970795, 78.02894979715347, 88.78136962652206, 44.28601562976837, 1.1105742445215583, 0.5706550413742661, 1.4630951033905149, 1.8206198187544942, 1.3884566584601998, 0.5566885939333588, 0.9657598589546978, 0.7164546428248286, 1.0874934517778456, 0.3338564682053402, 1.9375813426449895, 26.704725734889507, 28.92538547515869, 61.11139498651028, 63.89486342668533, 38.93424980342388, 32.81840197741985, 49.99369315803051, 70.49865826964378, 78.30527856945992, 87.02250480651855, 37.36458443105221, 0.4688217822695151, 0.08688274610904045, 0.06334957724902779, 0.12253186170710251, 0.020334749860921875, 0.06531230552354828, 0.08278026507468894, 0.01634897340409225, 0.02247994070785353, 0.0539248509448953, 0.02523724197089905, 0.051119039198965766, 0.06398543453542516, 0.06720354271237738, 0.020685089948528912, 0.06476459311670624, 0.007024306232779054, 0.02149855801690137, 0.1124237064504996, 0.09461764668230899, 0.021797357803734485, 0.03907337013515644, 0.017915777025336865, 0.14995360979810357, 0.1625212572980672, 0.18983186135301366, 0.3799404844176024, 0.20681065652752295, 0.14598602894693613, 0.17459205177146941, 0.18334054795559496, 0.32313219679053873, 0.11359958007233217, 0.12692693446297199, 0.18793975585140288, 0.18186000786954537, 0.2296027835109271, 0.15584001346724108, 0.19428704807069153, 0.15903657709714025, 0.16574505774769932, 0.18520345736760646, 1.9336753897368908, 107.92333647608757, 113.0281725525856, 106.85238674283028, 97.17131182551384, 67.8822934627533, 54.38213847577572, 76.60912558436394, 72.13245660066605, 75.92314079403877, 45.98082348704338, 0.7156812062021345, 0.16406419716076925, 0.5038311146199703, 1.7954650497995317, 2.6007797056809068, 1.0689143487252295, 4.785447064787149, 14.474887233227491, 7.177474284544587, 1.5526627097278833, 47.15278699994087, 101.09900146722794, 89.3255764245987, 92.39628285169601, 80.46268120408058, 77.4766494333744, 73.67056846618652, 70.77425748109818, 75.28097525238991, 91.57162830233574, 88.69940042495728, 90.75194388628006, 88.69237840175629, 71.49559557437897, 61.13564148545265, 70.26309370994568, 71.35214567184448, 76.32686913013458, 74.41501691937447, 74.85422015190125, 80.41199952363968, 80.6185108423233, 78.03132086992264, 79.91692408919334, 79.63323131203651, 84.22678202390671, 78.45000520348549, 78.99941012263298, 76.97943091392517, 81.14612013101578, 79.65384900569916, 79.62072998285294, 68.91982778906822, 60.617676079273224, 62.478071451187134, 63.61696533858776, 65.44629737734795, 62.384269684553146, 63.98072361946106, 59.75665368139744, 61.86555951833725, 65.55383920669556, 63.0451188236475, 65.87160855531693, 69.59736183285713, 72.95993059873581, 78.46375286579132, 72.98712193965912, 61.674175187945366, 81.51458635926247, 67.60263606905937, 68.48321601748466, 62.42327459156513, 59.606318548321724, 59.268885254859924, 72.56946355104446, 76.62104174494743, 74.93189558386803, 74.46808487176895, 74.47462812066078, 69.38516601920128, 63.71230222284794, 57.94011935591698, 62.691278010606766, 57.51235730946064, 60.474754348397255, 60.12429915368557, 66.54446125030518, 65.99703222513199, 68.58415380120277, 70.07241994142532, 78.19847390055656, 77.23772585391998, 81.33025825023651, 78.1648837029934, 80.29387906193733, 77.98285067081451, 72.99180328845978, 77.84693196415901, 79.51618999242783, 63.91740381717682, 63.33310917019844, 62.054124400019646, 78.18233236670494, 76.09404042363167, 78.76854971051216, 80.36561921238899, 84.34628561139107, 82.23289981484413, 91.21697813272476, 44.32061657309532, 0.8469823887571692, 6.230069221928716, 8.423065971583128, 5.8649045415222645, 1.8500281032174826, 0.693633483024314, 3.738674009218812, 2.320352140814066, 1.5721188532188535, 0.5049639288336039, 4.256332581862807, 37.51795180141926, 48.428982719779015, 69.74546268582344, 72.53860160708427, 49.907422587275505, 32.00308732688427, 59.267008155584335, 82.78358146548271, 88.91009911894798, 101.05337351560593, 42.855635583400726, 0.608902839012444, 0.3059791453415528, 0.1555391022702679, 0.18432086566463113, 0.18229518842417747, 0.11983863747445866, 0.14186457119649276, 0.2708918577991426, 0.18530057481257245, 0.10245416953694075, 0.09965299992472865, 0.17136240319814533, 0.15132545493543148, 0.13539194507757202, 0.21838516200659797, 0.14000283437781036, 0.14817214367212728, 0.16969068587059155, 0.16720809799153358, 0.20190670795273036, 0.13612094189738855, 0.10406906803837046, 0.12010054138954729], [0.03860806209559087, 0.056367451907135546, 0.04188446968328208, 0.0517697320174193, 0.043150748024345376, 0.015316374174290104, 0.041311034437967464, 0.03618165479565505, 0.030050600289541762, 0.024372712287004106, 0.026974112442985643, 0.059933586526312865, 0.01488006833824329, 0.08523418378899805, 0.054872161636012606, 0.10275129578076303, 0.06534390617161989, 0.18597713147755712, 0.36857321625575423, 8.16656643524766, 99.1982750594616, 85.85264638066292, 85.60278698801994, 65.23265764117241, 53.25776360929012, 38.763152584433556, 62.424631118774414, 43.82192753255367, 40.50849013030529, 6.025116769596934, 0.010557039568084292, 0.05073197578894906, 0.11561591367353685, 0.45817982987500727, 0.6516396207734942, 0.4045189905446023, 2.7687941025942564, 2.1326901856809855, 0.43873036571312696, 13.26426649466157, 81.8680889904499, 86.72958612442017, 82.71148413419724, 77.57567211985588, 74.9174715578556, 66.56564131379128, 65.17620787024498, 62.76339814066887, 60.24841569364071, 71.66393414139748, 81.82420894503593, 80.66027820110321, 74.35427337884903, 57.843277752399445, 58.17657686769962, 62.22947359085083, 71.30999833345413, 69.60049286484718, 72.13135465979576, 72.70246401429176, 74.28254082798958, 72.75339648127556, 75.93805879354477, 72.03871563076973, 75.39273485541344, 71.08380407094955, 77.52898782491684, 72.23613783717155, 70.071462392807, 69.3479736149311, 68.83939370512962, 57.62222841382027, 53.610403686761856, 53.80287855863571, 57.01608493924141, 56.48833505809307, 58.55859696865082, 58.167043179273605, 59.0062091499567, 56.49683140218258, 58.56344170868397, 61.11823461949825, 63.50503474473953, 60.155218094587326, 61.99625350534916, 61.12872965633869, 70.81665560603142, 64.19913589954376, 54.98471774160862, 70.29470801353455, 60.38692966103554, 56.17008313536644, 54.320703372359276, 56.88680827617645, 59.562723487615585, 62.565006986260414, 67.92226731777191, 67.72486791014671, 66.925740391016, 67.13381722569466, 64.50889527797699, 55.982377007603645, 53.63733284175396, 52.627814412117004, 52.22904480993748, 54.29315485060215, 56.97726622223854, 57.6334910094738, 59.39263701438904, 63.28056558966637, 68.15145581960678, 68.73464092612267, 72.47418746352196, 70.16037002205849, 74.66788575053215, 71.46506801247597, 71.78535282611847, 66.72101497650146, 76.3066466152668, 68.74677747488022, 59.86386492848396, 53.31071376800537, 59.15072299540043, 64.19195428490639, 68.52863118052483, 68.7043945491314, 72.77988865971565, 74.62395250797272, 80.71625679731369, 69.16413947939873, 84.59965601563454, 33.825397342443466, 0.8154962095431983, 0.8989500033203512, 1.0871978988870978, 1.7854221886955202, 1.1493245651945472, 0.06875513601698913, 0.9945297183003277, 0.48375616839621216, 0.17573639895999804, 0.06449149761465378, 9.344530776143074, 29.820596538484097, 41.21823124587536, 43.12662564218044, 25.161470845341682, 23.19491107016802, 35.98547503352165, 63.46603363752365, 54.23507496714592, 73.68250742554665, 55.59051923453808, 2.2226541582494974, 0.10557264438830316, 0.04920157451124396, 0.09118806352489628, 0.06741480247001164, 0.03807919281825889, 0.003551354516275751, 0.018305604935449082, 0.03266439802246168, 0.06317845283774659, 0.020521600381471217, 0.04599871375830844, 0.014566945101250894, 0.08009262921405025, 0.01511398957518395, 0.029185710664023645, 0.05508323956746608, 0.03870002903568093, 0.025485241749265697, 0.05692703496606555, 0.053704136225860566, 0.031515241716988385, 0.05207748581597116, 0.043424351897556335, 0.008851806851453148, 0.045400257004075684, 0.025461841833021026, 0.07445960960467346, 0.09372314350912347, 0.04983816652384121, 0.0507935814675875, 0.015224686467263382, 0.07181483277236111, 0.006878808180772467, 0.10845231096027419, 0.033255585440201685, 0.07683506846660748, 0.018598237475089263, 0.09380001516547054, 0.09757606996572576, 0.18864386103814468, 0.48225403181277215, 13.204120472073555, 114.86931055784225, 93.40086534619331, 97.36242637038231, 78.85522305965424, 74.89231690764427, 45.72406366467476, 57.174601033329964, 47.423533871769905, 45.76911024749279, 8.713454939424992, 0.07213670221972279, 0.05402569026045967, 0.5135172104928643, 1.001268953550607, 2.17337389010936, 2.0841321162879467, 5.302746556699276, 2.3549844324588776, 0.13476858555804938, 14.905459228903055, 88.48405078053474, 89.2666719853878, 88.64520013332367, 80.9011472761631, 79.3047085404396, 71.27465263009071, 70.45278713107109, 65.46112418174744, 64.86546814441681, 74.88065153360367, 86.35300353169441, 84.12460550665855, 80.17605498433113, 62.64283441007137, 61.21121942996979, 64.71217676997185, 76.16214036941528, 73.09400260448456, 75.77313244342804, 75.64213067293167, 78.22083950042725, 77.0526833832264, 79.16747510433197, 75.58630406856537, 79.10993099212646, 73.58752012252808, 77.9477633535862, 77.06133171916008, 76.97932451963425, 72.47812405228615, 72.47375428676605, 60.110574290156364, 55.84389343857765, 57.10416421294212, 58.61673764884472, 60.062537267804146, 61.35634124279022, 59.82593156397343, 61.695381850004196, 58.486435040831566, 63.02926607429981, 64.64639469981194, 67.4169172346592, 64.71974596381187, 64.79779377579689, 64.46795627474785, 73.46203565597534, 67.41076916456223, 59.06142398715019, 72.77537450194359, 64.24688413739204, 59.534297212958336, 56.794009655714035, 58.482962027192116, 62.10657678544521, 66.16001307964325, 70.91014578938484, 69.38394248485565, 69.96816113591194, 70.22785440087318, 67.11592018604279, 58.992643877863884, 56.8384862691164, 55.127833262085915, 53.66252548992634, 56.48306854069233, 58.97050626575947, 60.20102843642235, 63.80884364247322, 66.27416655421257, 72.58351519703865, 74.37686696648598, 75.27532115578651, 72.5305612385273, 76.1207377910614, 72.94020965695381, 74.17632892727852, 69.76448446512222, 78.78454685211182, 72.20696300268173, 61.2434720993042, 56.30130909383297, 62.56090700626373, 66.88962712883949, 72.63752549886703, 72.34535917639732, 75.92293560504913, 75.30061259865761, 84.22118872404099, 75.23874431848526, 84.53468710184097, 41.78831845521927, 1.8744322936981916, 0.7693191873840988, 0.4241138859651983, 2.459401641972363, 3.121400694362819, 0.5806425679475069, 1.3737002690322697, 0.6433759548235685, 0.5163299501873553, 0.10707504814490676, 9.67733496800065, 33.78939047455788, 41.69858627021313, 53.293344900012016, 26.291752494871616, 25.450732223689556, 46.74910806119442, 66.91292747855186, 62.84610070288181, 80.05772933363914, 72.60665595531464, 4.868624126538634, 0.18606693134643137, 0.04761737865919713, 0.04579907974402886, 0.03862254881823901, 0.055800595800974406, 0.02011228552873945, 0.066823889646912, 0.04428871274285484, 0.05822379702294711, 0.04522222690866329, 0.04546476076939143, 0.09584276922396384, 0.01886800630018115, 0.029093701050442178, 0.05344595789210871, 0.06867712887469679, 0.03503164873109199, 0.0257941143354401, 0.017082853555621114, 0.05162510227819439, 0.05113344428536948, 0.04798621121153701, 0.17363138613291085, 0.10144512329134159, 0.1271747227292508, 0.09339282842120156, 0.14234471105737612, 0.14713574928464368, 0.1257587198051624, 0.12754570750985295, 0.11666349222650751, 0.25097023928537965, 0.07758069681585766, 0.20591544831404462, 0.19506836630171165, 0.2502170781372115, 0.13637248543091118, 0.18929947429569438, 0.15318184829084203, 0.3687746054492891, 0.7289993134327233, 17.040109634399414, 131.29187732934952, 104.97515827417374, 113.62195149064064, 87.30327174067497, 73.80734592676163, 54.059562385082245, 88.77900615334511, 59.758340790867805, 64.28190305829048, 11.856725122779608, 0.28908501437399536, 0.35694726509973407, 0.7688468846026808, 2.508326629176736, 2.535949721932411, 2.7096528885886073, 10.287152845412493, 8.596708104014397, 4.436446242034435, 18.05581983178854, 95.82089468836784, 93.76878440380096, 92.75442883372307, 84.9820826947689, 84.28034394979477, 75.04847332835197, 73.25264409184456, 68.31351712346077, 70.15770256519318, 77.62635380029678, 89.63056325912476, 86.64520785212517, 83.45580339431763, 63.959976732730865, 64.56502586603165, 69.31520417332649, 79.67268079519272, 75.86410716176033, 78.13614964485168, 81.031913459301, 79.77960705757141, 78.70080694556236, 83.41194614768028, 79.17159408330917, 83.61250698566437, 77.50006377696991, 84.97595742344856, 80.08918404579163, 79.42592203617096, 75.17615407705307, 77.15643301606178, 63.34982067346573, 58.080673813819885, 60.92503018677235, 61.621472015976906, 63.86468544602394, 64.37251299619675, 63.47984969615936, 65.0089256465435, 63.243209794163704, 65.57708635926247, 67.54780501127243, 70.46743914484978, 68.60281839966774, 70.3387400507927, 68.45446676015854, 77.41247847676277, 72.71405339241028, 63.21974605321884, 75.81603214144707, 67.12120190262794, 62.517209351062775, 59.49714660644531, 64.01502817869186, 66.98529079556465, 68.96144315600395, 74.63941007852554, 73.12375500798225, 73.63914415240288, 72.78130978345871, 71.3550791144371, 60.66964589059353, 60.69616846740246, 58.19838389754295, 57.99342289566994, 59.18536573648453, 63.46734456717968, 63.53280745446682, 66.9043019413948, 69.81764361262321, 74.42479759454727, 74.23866838216782, 77.77734249830246, 75.22104486823082, 82.16082528233528, 77.49895423650742, 79.78839978575706, 73.92189458012581, 82.57863566279411, 76.16613015532494, 66.21773198246956, 60.12028656899929, 65.67533388733864, 71.32192969322205, 75.76258420944214, 74.38740000128746, 78.52003544569016, 80.5617342889309, 87.64558777213097, 77.7099721133709, 87.29168996214867, 42.835036888718605, 1.6970877349376678, 4.98849724419415, 5.0240842346102, 5.746319554746151, 4.315547179430723, 0.4214960342505947, 4.339472595602274, 1.2732563400641084, 0.8615809085313231, 0.23785179946571589, 14.744845647364855, 50.667879581451416, 56.19972534477711, 57.875579819083214, 33.46616841852665, 33.1254331022501, 51.776375100016594, 80.07181137800217, 75.24106219410896, 90.62608703970909, 81.79730638861656, 5.342934625223279, 0.30385603895410895, 0.15846804744796827, 0.22627494879998267, 0.1706467056646943, 0.27454224473331124, 0.152337699837517, 0.1212937367381528, 0.17467638943344355, 0.10612107667839155, 0.22427309449994937, 0.1738001950434409, 0.3433509118622169, 0.22739087173249573, 0.09367066624690779, 0.12910107092466205, 0.13818396400893107, 0.16007230355171487, 0.16702998254913837, 0.08572693273890764, 0.12611423822818324, 0.14200422854628414, 0.12918946071295068], [0.021712816051149275, 0.03693359140015673, 0.05630937514069956, 0.07570217261672951, 0.034501922273193486, 0.08921319371438585, 0.08005061623407528, 0.025845118434517644, 0.011277310586592648, 0.02864551992388442, 0.029189740525907837, 0.04270173754775897, 0.13494965474819764, 0.005308440859153052, 0.04565337017993443, 0.030630024666606914, 0.10445432431879453, 0.14506114966934547, 0.2133130279253237, 37.42280870676041, 95.1169216632843, 73.38689848780632, 70.42960837483406, 43.82123216986656, 26.751125045120716, 34.719272777438164, 44.703879207372665, 50.95713146030903, 32.49802976846695, 0.26689168182201684, 0.13914603972807527, 0.08862056653015316, 0.33420284336898476, 0.2030053685302846, 0.5969628703314811, 1.550414061639458, 2.2877107048407197, 1.799680923577398, 0.8194591593928635, 49.754287004470825, 92.81993731856346, 87.22147732973099, 83.05555567145348, 81.0659596323967, 80.14357432723045, 72.26097330451012, 64.82728779315948, 61.900491043925285, 60.298063829541206, 61.1188729852438, 70.74628338217735, 73.46382156014442, 63.49881447851658, 59.27517011761665, 57.26061321794987, 64.91114169359207, 74.70508575439453, 73.59342500567436, 76.38655632734299, 74.50412973761559, 75.55489495396614, 71.92244186997414, 73.90569984912872, 70.70573195815086, 72.58069574832916, 71.32268205285072, 71.66227743029594, 69.46575209498405, 68.56487363576889, 63.32320690155029, 57.57373921573162, 53.292957320809364, 55.24166755378246, 54.95915271341801, 54.86300267279148, 56.49214245378971, 56.61912024021149, 55.11960670351982, 54.90220136940479, 53.18085193634033, 60.04052124917507, 64.16002079844475, 64.0784315764904, 59.09672409296036, 59.00136440992355, 58.87632071971893, 67.9914540052414, 65.68149715662003, 48.45247305929661, 72.86325618624687, 67.60959729552269, 65.16414731740952, 61.18391789495945, 57.40236081182957, 58.348795026540756, 63.624215349555016, 66.89734071493149, 67.3857057094574, 68.80314365029335, 64.84717592597008, 61.35515570640564, 56.508774161338806, 55.722926929593086, 54.571809098124504, 52.57701873779297, 53.354871198534966, 57.837471663951874, 57.88506031036377, 63.15641485154629, 66.26738011837006, 70.22321864962578, 71.59109964966774, 69.69435542821884, 68.98246362805367, 66.43702581524849, 67.15398654341698, 65.2816142141819, 68.75297874212265, 70.94546869397163, 63.21762956678867, 57.99534559249878, 54.368664398789406, 56.8903648853302, 63.026283234357834, 65.8945745229721, 66.2234316766262, 70.24851769208908, 71.70861214399338, 76.3306537270546, 79.17163968086243, 70.42201638221741, 71.88466429710388, 36.025574281811714, 2.0753460377454758, 0.48609770368784666, 1.2586439866572618, 1.2426333082839847, 0.9621076611801982, 0.06708318862365559, 0.3568103536963463, 0.724134030751884, 0.05371659317461308, 0.2606243040645495, 14.439571928232908, 32.78060160577297, 35.749222710728645, 29.386517331004143, 28.640393167734146, 23.91595847904682, 42.908954322338104, 58.381336480379105, 61.71606793999672, 75.26668801903725, 26.627171896398067, 0.37963038543239236, 0.0107979657514079, 0.02610904284665594, 0.029411279028863646, 0.07535590135375969, 0.07404848947771825, 0.13338112563360482, 0.0493512879620539, 0.03733787263627164, 0.05937171765253879, 0.05340938485460356, 0.035893564199795946, 0.035833394576911815, 0.06350613330141641, 0.03258256510889623, 0.029089110867062118, 0.011796559774666093, 0.05593866124399938, 0.04957602883223444, 0.024730620425543748, 0.04104026927961968, 0.041668081685202196, 0.03678961846162565, 0.048741183200036176, 0.014473594055743888, 0.03648507816251367, 0.032345363579224795, 0.07262688333867118, 0.02163800942071248, 0.06388201625668444, 0.031263074779417366, 0.07260729806148447, 0.10535518769756891, 0.06777112983400002, 0.04434948721609544, 0.010891264846577542, 0.040647072019055486, 0.059872938218177296, 0.11717650922946632, 0.09117028908804059, 0.20529856032226235, 50.19971050322056, 107.73963913321495, 83.67081865668297, 80.43801292777061, 52.512008026242256, 39.66775864362717, 38.246634900569916, 46.54994934797287, 55.12897700071335, 36.35380446910858, 0.19898806378478184, 0.03716298924700823, 0.36709672829601914, 1.7847598367370665, 0.9833819477353245, 2.6238411432132125, 4.654553113505244, 2.7533978037536144, 0.4847527836682275, 1.7357896082103252, 57.820923551917076, 95.65564155578613, 91.24497503042221, 87.25164011120796, 86.29716172814369, 83.87663841247559, 77.47006058692932, 70.37798434495926, 65.4500287771225, 64.09390434622765, 63.64267855882645, 73.39156463742256, 77.53699779510498, 66.98029786348343, 62.52109654247761, 61.304686814546585, 65.78418284654617, 77.94886529445648, 77.07754924893379, 80.1460973918438, 77.39893600344658, 78.36648568511009, 76.99147626757622, 77.15466991066933, 75.08383423089981, 75.87105318903923, 74.89874616265297, 74.9114678800106, 75.08469298481941, 72.66573518514633, 65.35444110631943, 60.55184081196785, 56.8760434538126, 57.68092766404152, 57.32037641108036, 57.018953785300255, 58.389878422021866, 58.60842749476433, 56.50606490671635, 56.777503341436386, 54.988616332411766, 63.61816607415676, 67.26550295948982, 67.85318702459335, 63.182112872600555, 61.3791324198246, 62.08532452583313, 70.92192515730858, 68.21796745061874, 51.82057432830334, 75.7054428756237, 69.13997277617455, 71.62146762013435, 65.89063793420792, 61.77519276738167, 60.25296404957771, 65.14499634504318, 69.25411865115166, 71.01826518774033, 70.81837311387062, 66.77380174398422, 63.90805631875992, 59.06728707253933, 57.73782201111317, 57.34121449291706, 56.51174180209637, 56.52138188481331, 60.125401094555855, 60.88738940656185, 65.9066578745842, 69.63795125484467, 72.38602459430695, 73.56364220380783, 70.68205922842026, 73.60631391406059, 70.7191376388073, 70.26212856173515, 69.92841526865959, 72.51583322882652, 75.57125687599182, 67.91550368070602, 58.65065462887287, 58.90224292874336, 59.901254922151566, 66.7399151623249, 68.94635036587715, 69.8815105855465, 71.22343897819519, 76.3206298649311, 78.03478628396988, 82.11835876107216, 72.63426527380943, 78.30457180738449, 43.27790692448616, 4.37479455024004, 0.5737559718545526, 0.34186732897069305, 2.0978144695982337, 3.004894433543086, 0.6724511040374637, 0.6597106845583767, 1.1407810798846185, 0.059969632638967596, 0.18841323122614995, 17.31380894780159, 39.619736820459366, 36.8625857681036, 21.033720038831234, 27.660353556275368, 37.76070177555084, 50.15265002846718, 67.90310114622116, 68.7351880967617, 86.62386059761047, 37.4719400703907, 0.4470086668152362, 0.07498405568185262, 0.017686579558358062, 0.033302029041806236, 0.11195852086530067, 0.022829340123280417, 0.04895584199402947, 0.036713826630148105, 0.022743900372006465, 0.02442822493321728, 0.08524792836396955, 0.018674838247534353, 0.0038756595995437237, 0.02040225746895885, 0.07718323220615275, 0.02335390123334946, 0.02385168194450671, 0.06395806412911043, 0.01321802305028541, 0.07622204706422053, 0.02402752827038057, 0.03554655449988786, 0.13887193490518257, 0.13088840001728386, 0.2021654206328094, 0.19388887099921703, 0.20376221073092893, 0.18843959231162444, 0.15440830669831485, 0.13402848620899022, 0.11215369828278199, 0.15588054957333952, 0.13270820549223572, 0.1400311547331512, 0.21986807696521282, 0.0988366745878011, 0.13225447124568745, 0.1417872987804003, 0.24928900762461126, 0.20344344346085563, 0.30314669420477003, 61.64681285619736, 121.61696568131447, 94.89145696163177, 92.18951314687729, 62.87245228886604, 38.18169258534908, 46.00331827998161, 64.28571805357933, 74.29717004299164, 52.486906573176384, 0.45819143706467, 0.269451646017842, 0.4723503679269925, 2.0246353838592768, 1.636970448307693, 2.7505120960995555, 8.082006722688675, 10.001486074179411, 9.181416928768158, 2.522974843159318, 65.31589597463608, 95.3749506175518, 94.91379216313362, 89.0859080851078, 91.20896056294441, 88.51194888353348, 83.12148213386536, 72.98506245017052, 68.86020138859749, 67.88579687476158, 67.59517326951027, 76.74866169691086, 80.49823969602585, 70.2397933602333, 66.24629884958267, 63.07491682469845, 69.84568610787392, 82.46322825551033, 79.68480974435806, 83.94147053360939, 82.44271695613861, 82.2308099269867, 79.51308935880661, 80.76741725206375, 77.64438763260841, 80.23231476545334, 77.97047093510628, 78.97856444120407, 79.58634182810783, 75.31596377491951, 70.57792201638222, 63.1248689442873, 59.269056245684624, 60.403477773070335, 60.1349575817585, 59.388381242752075, 61.273095309734344, 62.49254487454891, 59.7333837300539, 59.765020832419395, 57.879843190312386, 66.5227036178112, 70.40677160024643, 70.64288333058357, 66.47216632962227, 63.65690499544144, 64.29834097623825, 75.18823742866516, 72.12700009346008, 57.37647280097008, 80.95212534070015, 72.60106265544891, 74.44236785173416, 67.03240066766739, 63.458354249596596, 64.26136136054993, 68.49424302577972, 73.11807811260223, 72.87188932299614, 75.28096005320549, 72.1691170334816, 67.57911533117294, 61.47750534117222, 60.766662284731865, 60.53025797009468, 60.70750705897808, 59.40836437046528, 64.64264810085297, 63.8128562271595, 69.81346383690834, 72.66796946525574, 75.4023939371109, 76.58751234412193, 76.85431122779846, 77.77920439839363, 75.76285019516945, 75.59435963630676, 74.03594925999641, 73.84537428617477, 76.58327177166939, 71.59385070204735, 63.35880719125271, 62.522285878658295, 63.525952622294426, 69.4677659869194, 72.90151253342628, 73.09835717082024, 74.91418093442917, 78.54747757315636, 83.74968722462654, 85.4880939424038, 76.74494549632072, 78.13630163669586, 42.16247297823429, 3.3566724322736263, 4.294911911711097, 4.445620374754071, 4.934332575649023, 4.445185773074627, 1.37908244272694, 1.3363539730198681, 2.6948538701981306, 0.16118556959554553, 0.551118211587891, 24.774184226989746, 51.804090812802315, 48.87151077389717, 44.14375126361847, 41.201189160346985, 39.07454587519169, 60.74012450873852, 78.09882044792175, 76.79913818836212, 97.98831358551979, 39.268616661429405, 0.8262507012113929, 0.19753821892663836, 0.07329613727051765, 0.2361192854004912, 0.2147144402260892, 0.12693728000158444, 0.18657064181752503, 0.14811988163273782, 0.10848804537090473, 0.25094554061070085, 0.21279915003105998, 0.15061823272844777, 0.1797142659779638, 0.19240795983932912, 0.12953184312209487, 0.15664681704947725, 0.10137222954654135, 0.1843667749199085, 0.12541966221760958, 0.17655457224464044, 0.19676216994412243, 0.2255041096941568], [0.03635183296864852, 0.0528619433316635, 0.06334443416562863, 0.05055566747614648, 0.06929212438990362, 0.04694458097219467, 0.07707188036874868, 0.01259743730770424, 0.06417799217160791, 0.07045832040603273, 0.058115024148719385, 0.010520232754060999, 0.056671969941817224, 0.03179530227498617, 0.02319694442121545, 0.05791416559077334, 0.03447140516072977, 0.07369484868831933, 0.7148676936049014, 62.07199864089489, 86.44349947571754, 81.74605473876, 66.92365050315857, 58.83707642555237, 39.97868075966835, 62.558733522892, 58.76943625509739, 52.96459414064884, 9.700553622096777, 0.09643296216381714, 0.2597075141966343, 0.12023743794998154, 0.6995725049637258, 0.5075794353615493, 1.3433407293632627, 2.4814205104485154, 1.7584653664380312, 1.1915723606944084, 21.19695357978344, 92.17927649617195, 82.13316276669502, 88.52316588163376, 83.9510840177536, 83.18691462278366, 81.87941238284111, 82.14871913194656, 75.4207469522953, 62.35340394079685, 60.690677762031555, 58.474378287792206, 59.48373332619667, 61.79034635424614, 59.39661160111427, 57.223762795329094, 57.37352795898914, 63.68412673473358, 76.01019412279129, 76.06269970536232, 74.84735012054443, 74.62886184453964, 74.62825387716293, 71.53444468975067, 72.90671825408936, 72.98490285873413, 74.95705023407936, 72.53643572330475, 70.7364571094513, 68.16675379872322, 60.426698327064514, 54.58866499364376, 53.79185535013676, 52.62689106166363, 52.30171211063862, 54.02028389275074, 52.9336030036211, 55.05967631936073, 56.13305412232876, 57.0976285636425, 54.26465258002281, 52.31731787323952, 61.20937652885914, 67.67352506518364, 66.82993993163109, 65.96823737025261, 59.96061913669109, 61.08374387025833, 66.35935038328171, 65.34339129924774, 43.597165793180466, 69.34632450342178, 68.88484686613083, 69.62719023227692, 65.37578076124191, 64.0047687292099, 62.40190453827381, 65.24914115667343, 66.64385631680489, 68.25239360332489, 66.5021163225174, 62.451138496398926, 58.20741221308708, 52.409352734684944, 55.690879449248314, 57.01675370335579, 53.47386561334133, 52.26755574345589, 53.276587799191475, 59.48896564543247, 62.715296521782875, 70.23844823241234, 71.22914627194405, 63.408352732658386, 67.3018442094326, 64.96375367045403, 65.07985264062881, 64.65353071689606, 65.06083086133003, 68.92571747303009, 66.755600720644, 60.26785925030708, 53.210927322506905, 57.48604752123356, 57.315003499388695, 59.924863055348396, 61.13070175051689, 69.537393450737, 69.29777070879936, 77.40765273571014, 71.84079185128212, 75.6358078122139, 74.59553003311157, 71.32015898823738, 73.13387006521225, 43.90038572251797, 4.042028356343508, 0.5806766473688185, 0.7101592712569982, 1.544934161938727, 1.5932059404440224, 0.3476733580464497, 0.18107995128957555, 0.22227204171940684, 0.11501895234687254, 3.0574869364500046, 23.85329034179449, 32.613695561885834, 50.46167604625225, 31.061114072799683, 24.514867141842842, 44.24285754561424, 61.04868695139885, 66.54576078057289, 62.63597957789898, 54.81398530304432, 2.520039025694132, 0.1591526044649072, 0.03373775878571905, 0.050349554512649775, 0.04995245355530642, 0.07506900932639837, 0.014891425980749773, 0.016657435953675304, 0.07661767114768736, 0.029768825370410923, 0.010133992200280773, 0.04959277910529636, 0.020716683175123762, 0.02160858697607182, 0.02079780362691963, 0.024800757091725245, 0.023838019005779643, 0.055944694904610515, 0.03587391955079511, 0.016421965483459644, 0.011142227649543202, 0.02181901738367742, 0.12794717971701175, 0.0328590448043542, 0.09836074270424433, 0.02843784102878999, 0.0470612985373009, 0.055881167063489556, 0.04181065938610118, 0.037271595138008706, 0.05081846196844708, 0.0271176475143875, 0.029313925952010322, 0.01201569093609578, 0.08793294444330968, 0.03407031144888606, 0.05990448691591155, 0.027408176065364387, 0.05027673869335558, 0.04575951214064844, 1.4798550540581346, 80.82944512367249, 96.53176054358482, 92.71675005555153, 80.068239569664, 73.60406443476677, 43.98194074630737, 46.26212239265442, 44.49831023812294, 58.785391598939896, 10.543108060956001, 0.056198735765065067, 0.162707521521952, 0.6172775896266103, 1.6698329849168658, 1.8364669871516526, 3.0923253670334816, 6.018395880237222, 0.5452956177759916, 1.2186910305172205, 26.86247806996107, 96.60670012235641, 86.15741282701492, 91.38733059167862, 88.25407952070236, 88.07938769459724, 85.71026042103767, 84.15656939148903, 78.0765688419342, 67.47699961066246, 63.371521309018135, 63.33400212228298, 61.59804627299309, 63.42390529811382, 61.23347483575344, 61.498100236058235, 60.44207990169525, 68.81470263004303, 78.85892406105995, 77.99495682120323, 76.1708191037178, 77.88387358188629, 77.1741096675396, 75.09792387485504, 76.97807058691978, 76.66664689779282, 75.87733805179596, 77.81135067343712, 73.30731555819511, 73.09957310557365, 63.5838121175766, 57.54137635231018, 54.94993440806866, 55.610137581825256, 53.23585018515587, 55.6725150346756, 56.5544743090868, 58.42732161283493, 58.85556623339653, 60.68722754716873, 56.88787221908569, 55.180031061172485, 64.05366450548172, 70.47206729650497, 67.96397387981415, 70.0442710518837, 63.979614078998566, 63.50541852414608, 69.68028858304024, 68.05367186665535, 45.60894124209881, 70.66388100385666, 72.46699064970016, 72.76523664593697, 68.39030340313911, 67.83748626708984, 63.68016354739666, 68.03066030144691, 69.97419521212578, 71.08816623687744, 68.58268707990646, 64.16265785694122, 60.34597545862198, 54.848153069615364, 57.372277826070786, 59.09227833151817, 55.353111773729324, 56.468006148934364, 55.90861156582832, 63.45222517848015, 65.41120246052742, 73.62760797142982, 75.09272575378418, 69.00007948279381, 72.37461000680923, 70.44119775295258, 70.20016148686409, 70.27116447687149, 69.21425119042397, 71.17209613323212, 67.87103846669197, 63.304926082491875, 56.931820660829544, 58.42682383954525, 60.27650758624077, 63.017357513308525, 65.96130654215813, 71.93533077836037, 73.24237704277039, 78.55191573500633, 73.99891644716263, 77.21607461571693, 76.7882327735424, 73.69409680366516, 76.78116515278816, 51.49449102580547, 7.595826610922813, 1.1181608936749399, 0.6209124508313835, 1.0714355134405196, 2.6667572278529406, 1.0181383858434856, 0.5133354139979929, 0.8069795009214431, 0.13857795536750928, 2.7466434286907315, 29.23405811190605, 33.9608296751976, 35.992405861616135, 21.299549974501133, 28.610859252512455, 53.040951043367386, 67.83519119024277, 73.70195478200912, 67.28194087743759, 70.90514525771141, 4.9579207599163055, 0.27233132743276656, 0.09530987008474767, 0.07559217148809694, 0.049518137602717616, 0.07395998094580136, 0.016292046966555063, 0.04399907476908993, 0.03354369087901432, 0.023953029631229583, 0.05823845443956088, 0.06033192687027622, 0.0226239600306144, 0.030540892730641644, 0.04299873391573783, 0.03422867463086732, 0.01860744752775645, 0.045737336768070236, 0.01079034575013793, 0.045874322386225685, 0.02784872234769864, 0.03363605486811139, 0.17904937587445602, 0.1458989008096978, 0.20653196523198858, 0.14373098354553804, 0.16773526032920927, 0.33382155757863075, 0.17858522187452763, 0.11241408821661025, 0.13925853447290137, 0.17470356688136235, 0.10495896989596076, 0.11443805109593086, 0.1349413426942192, 0.1878969487734139, 0.14785223349463195, 0.10775674047181383, 0.13773935817880556, 0.17086500098230317, 1.8079976085573435, 95.20648285746574, 107.188980281353, 106.26729413866997, 88.65378007292747, 81.82570606470108, 53.887424021959305, 84.0346871316433, 78.936827480793, 80.48372447490692, 16.78178619593382, 0.35772206727415323, 0.6438332365360111, 0.9475867997389287, 3.581919358111918, 3.5861853417009115, 7.770019238814712, 11.132687274366617, 9.88673698157072, 3.911826442927122, 32.76413328945637, 98.25727835297585, 85.42904511094093, 96.41569957137108, 92.82995358109474, 91.56205281615257, 90.7000158727169, 89.16786208748817, 82.38989979028702, 69.85220655798912, 67.40686297416687, 66.28203213214874, 65.11852696537971, 66.94787800312042, 64.88603264093399, 63.69754381477833, 63.61611798405647, 71.14315688610077, 84.6846954524517, 81.97366252541542, 78.80989909172058, 79.97098758816719, 80.40328279137611, 78.60131308436394, 81.16204127669334, 81.13570109009743, 80.82480937242508, 80.5103762447834, 79.12297949194908, 73.84877890348434, 66.55295759439468, 60.483474880456924, 59.27844554185867, 57.31911487877369, 57.349707037210464, 60.41841097176075, 59.413197711110115, 61.05665512382984, 62.387526109814644, 64.96291011571884, 59.08540070056915, 59.78348024189472, 67.8729459643364, 72.85574778914452, 71.36985272169113, 73.50094556808472, 66.53854116797447, 67.2449840605259, 74.01867538690567, 73.30904066562653, 49.849034920334816, 73.09716403484344, 76.44793063402176, 74.63730499148369, 71.22090831398964, 73.33598881959915, 68.50533843040466, 71.77313268184662, 73.77829268574715, 74.04505357146263, 73.01615238189697, 67.80747547745705, 63.96924823522568, 56.65297642350197, 60.609761103987694, 64.04368624091148, 59.92799788713455, 57.81959742307663, 60.08123606443405, 66.52600184082985, 69.98856604099274, 78.26351121068001, 77.91988804936409, 70.2086578309536, 75.77127814292908, 74.27669674158096, 75.65728425979614, 74.12793472409248, 72.3022010922432, 76.50843098759651, 73.26891481876373, 67.43823409080505, 59.39143247902393, 63.06104376912117, 64.23386603593826, 63.70044685900211, 69.06694069504738, 74.47600364685059, 75.80119773745537, 79.76465106010437, 75.88142663240433, 82.3042219877243, 78.12111005187035, 75.66853925585747, 77.99884021282196, 50.1338866353035, 6.268768720328808, 3.8918414153158665, 2.995035625062883, 5.33499495126307, 3.846487761475146, 1.3548845099285245, 1.0530187329277396, 1.1848108610138297, 0.35165453504305333, 5.827508848160505, 40.19319824874401, 49.897980093955994, 67.91846752166748, 43.54112260043621, 35.729121789336205, 61.881549060344696, 78.50502625107765, 84.85445514321327, 78.14013183116913, 79.02499035000801, 4.968931619077921, 0.2287433616584167, 0.11245714020333253, 0.26743125286884606, 0.1162809225206729, 0.2537688484881073, 0.10902496695052832, 0.11654806599835865, 0.1453626248985529, 0.11632851645117626, 0.10039180793683045, 0.19386169355129823, 0.13066251995041966, 0.15496162232011557, 0.3050212998641655, 0.08007544107385911, 0.09761314024217427, 0.1272733838413842, 0.10147988548851572, 0.08231375104514882, 0.15533321566181257, 0.1277633645804599], [0.03433867575949989, 0.11007760695065372, 0.02418985266558593, 0.04600549327733461, 0.03159750878694467, 0.03276435789302923, 0.02314212753844913, 0.05602882847597357, 0.09064064055564813, 0.04544654846540652, 0.03599541283620056, 0.026731389334599953, 0.04839983237616252, 0.04302794855902903, 0.1657609100220725, 0.06353282093186863, 0.03798469144385308, 0.2691944770049304, 11.781219374388456, 96.13107964396477, 78.27443182468414, 82.59068861603737, 58.99749241769314, 24.981434606015682, 34.893710017204285, 99.19002950191498, 66.07103705406189, 35.46374022960663, 1.1035304912365973, 0.07470948330592364, 0.12721647595753893, 0.5335758591536433, 0.9391048830002546, 0.3396254195831716, 3.332845810800791, 4.5141800958663225, 1.6793334251269698, 4.921953314915299, 79.20875608921051, 88.03692877292633, 87.36123383045197, 83.8149145245552, 81.14480540156364, 86.49158209562302, 82.90167912840843, 78.6691166460514, 78.74727085232735, 75.1928199827671, 68.25302436947823, 60.1016029715538, 56.758842542767525, 57.92411461472511, 58.38616602122784, 56.16095222532749, 55.73437571525574, 63.06912213563919, 73.60619992017746, 72.57985219359398, 74.61672529578209, 74.11993235349655, 71.34801149368286, 71.95973306894302, 72.96680822968483, 71.28840029239655, 69.07652378082275, 68.34997236728668, 66.15869075059891, 58.27629491686821, 52.82497823238373, 51.97166942059994, 52.29344755411148, 51.17340825498104, 51.48695223033428, 51.719161570072174, 51.26642346382141, 53.01290474832058, 55.784650817513466, 54.84542481601238, 54.66387435793877, 51.308437809348106, 61.22353836894035, 67.76443898677826, 69.48794290423393, 69.43593889474869, 66.76788926124573, 65.92257902026176, 68.19709897041321, 63.26399467885494, 49.59668666124344, 68.59113022685051, 65.19024431705475, 65.03484785556793, 62.791778817772865, 60.54940514266491, 59.40299905836582, 63.27715717256069, 64.25968185067177, 65.09230837225914, 61.48523032665253, 57.84482806921005, 51.39637649059296, 52.1396242082119, 53.737419471144676, 54.70628388226032, 51.29054456949234, 53.73985514044762, 50.43099269270897, 54.99638311564922, 62.770135179162025, 64.1491761803627, 64.90733429789543, 71.03775814175606, 72.03499183058739, 68.76497089862823, 64.72672998905182, 63.81112352013588, 61.08542338013649, 61.178168803453445, 57.680726274847984, 53.427356109023094, 52.85737529397011, 54.445952251553535, 55.28280794620514, 60.53429335355759, 62.67305798828602, 66.19527518749237, 69.18326005339622, 73.28083097934723, 81.12507686018944, 73.50396260619164, 66.11319959163666, 71.36522457003593, 70.1233372092247, 72.1918474137783, 52.920915484428406, 8.4878059476614, 1.4309573778882623, 0.8459416008554399, 0.7274821260944009, 0.2437813367578201, 0.30459227913524956, 0.17806571850087494, 0.07866696352721192, 0.058538938901619986, 11.462088748812675, 28.853903710842133, 33.42101164162159, 58.691415041685104, 28.105284981429577, 28.229980990290642, 51.02075904607773, 46.71469710767269, 57.341286689043045, 67.5060148537159, 18.462793193757534, 0.6658497895114124, 0.17265921720536426, 0.10595764091704041, 0.028133233936387114, 0.04791049359482713, 0.07688428027904592, 0.019621030151029117, 0.13601423590444028, 0.02809208741382463, 0.03133708545647096, 0.023502369731431827, 0.016601661700406112, 0.051017776859225705, 0.02118296342814574, 0.038199524642550386, 0.04021994005597662, 0.016582228563493118, 0.03344542310514953, 0.026190081662207376, 0.04733174828288611, 0.017008043214445934, 0.004858203519688686, 0.053688873958890326, 0.08536770357750356, 0.044872523212688975, 0.021908650269324426, 0.027861515118274838, 0.055990218243096024, 0.02808650089718867, 0.02390591624134686, 0.055970929824979976, 0.04738160947454162, 0.073327619174961, 0.03857428324408829, 0.10497763491002843, 0.03452687327808235, 0.09172476988169365, 0.05440927670861129, 0.19340721715707332, 17.51964010298252, 113.58257800340652, 84.50121089816093, 91.58568754792213, 65.59617653489113, 40.80136701464653, 38.082787692546844, 59.807605147361755, 64.50283840298653, 41.04692883789539, 1.2288000318221748, 0.062470414268318564, 0.6526245991699398, 1.7337089823558927, 2.4018299812451005, 2.1270679123699665, 4.565547639504075, 1.7436281125992537, 0.3413453616667539, 8.578624874353409, 87.89167776703835, 88.5617870092392, 91.35364159941673, 85.50723731517792, 85.58378800749779, 87.77306333184242, 88.72647777199745, 81.44894108176231, 81.93387866020203, 77.27831527590752, 71.8435201048851, 62.950959876179695, 59.936935007572174, 61.71919137239456, 60.44326163828373, 60.90435929596424, 58.86887691915035, 63.70806165039539, 77.39910319447517, 75.76455250382423, 75.75279593467712, 78.34098145365715, 75.10359317064285, 74.3708024919033, 73.88565212488174, 72.68956750631332, 74.19004619121552, 71.47911965847015, 69.54674854874611, 61.24317191541195, 54.77772384881973, 54.36175636947155, 55.106482207775116, 54.024285078048706, 54.746170341968536, 55.56984834372997, 55.096663534641266, 55.601356253027916, 57.75633081793785, 56.59146912395954, 57.78956763446331, 53.550959676504135, 63.43046374619007, 72.35894724726677, 72.88270354270935, 71.97854965925217, 71.32324442267418, 68.06462287902832, 72.4175401031971, 67.3300538957119, 50.910093784332275, 71.57539889216423, 67.5720477104187, 68.65580275654793, 64.07188072800636, 63.246941193938255, 62.18973912298679, 66.77214503288269, 68.64504173398018, 69.26990300416946, 64.30840283632278, 60.14840126037598, 54.027055129408836, 56.159588098526, 56.98973335325718, 57.22521051764488, 54.34894725680351, 56.10937379300594, 53.017437905073166, 57.94071212410927, 65.97275912761688, 69.04107168316841, 69.54557061195374, 73.09154033660889, 74.28526148200035, 70.78048914670944, 68.87472420930862, 66.34273767471313, 64.41094413399696, 62.729222774505615, 60.09626805782318, 56.67827546596527, 55.397155210375786, 55.87144196033478, 57.1928970515728, 62.54085548222065, 66.28434240818024, 68.73260423541069, 71.19571566581726, 77.1605671942234, 82.54613220691681, 76.27732738852501, 68.98565545678139, 73.48405167460442, 72.34660550951958, 74.72794532775879, 60.29864899814129, 13.217643946409225, 0.8206930838059634, 0.3860529017401859, 0.6430991634260863, 1.7858408787287772, 0.32153776672203094, 0.7219838805031031, 0.2259692136431113, 0.10381660424172878, 17.176668606698513, 41.16129510104656, 33.83310712873936, 40.057746917009354, 28.40348158031702, 47.82731540501118, 61.24259814620018, 54.58418123424053, 63.79183575510979, 80.75852572917938, 31.26232087612152, 0.6820350210182369, 0.16026472760131583, 0.05969741287117358, 0.006925316256456426, 0.03744487177755218, 0.08500256692059338, 0.024198231512855273, 0.04958232966600917, 0.05059881223132834, 0.03611459433159325, 0.0465041497227503, 0.024632428721815813, 0.021286743503878824, 0.06725659884978086, 0.04841910224058665, 0.009196240371238673, 0.13497589709004387, 0.028467738447943702, 0.06319277628790587, 0.1250063453335315, 0.032349059474654496, 0.11294441952486522, 0.19126526021864265, 0.18632729159435257, 0.13999817369040102, 0.20644320436986163, 0.10375050114816986, 0.09408209807588719, 0.13521430460968986, 0.22756584046874195, 0.23401700367685407, 0.12613338563824072, 0.1255120596033521, 0.0890502700349316, 0.16369849647162482, 0.21281572961015627, 0.23917427693959326, 0.28044270467944443, 0.5420117033645511, 21.357844546437263, 128.1777012348175, 97.8712722659111, 103.4186401963234, 78.28613519668579, 39.0839047729969, 49.15698565542698, 130.26836425065994, 88.43775406479836, 57.535729855298996, 1.987533699721098, 0.24269665824249387, 0.37487286259420216, 3.7210674164816737, 6.322553884238005, 4.114960692822933, 11.898550428450108, 15.18197039142251, 5.9842347633093596, 12.523805927485228, 88.23413819074631, 89.92582261562347, 95.16862168908119, 89.22503381967545, 86.1966723203659, 92.47554659843445, 90.73052063584328, 86.35706171393394, 85.85504785180092, 82.22561180591583, 75.65933614969254, 66.62484973669052, 63.028240129351616, 66.17896646261215, 63.38219873607159, 63.46902787685394, 61.68761506676674, 68.19396033883095, 82.00189501047134, 77.51561254262924, 79.62043359875679, 84.28279861807823, 77.99336850643158, 79.03426185250282, 78.87090101838112, 76.09351605176926, 78.98603484034538, 74.91994142532349, 72.72697269916534, 65.67597225308418, 58.10173228383064, 56.79146759212017, 57.425520569086075, 57.71655075252056, 57.8290893137455, 58.4122060239315, 57.3240090161562, 58.75545680522919, 62.190502882003784, 60.29709108173847, 58.7676465511322, 56.34131334722042, 68.3329264819622, 74.5507076382637, 76.54911160469055, 75.8919520676136, 72.61712819337845, 72.4620509147644, 75.47645196318626, 70.6360436975956, 55.706162229180336, 73.6754322052002, 72.08809778094292, 72.74807676672935, 67.74194419384003, 68.14178913831711, 66.08968645334244, 69.03473362326622, 72.09586456418037, 71.46773546934128, 67.47076034545898, 63.94190490245819, 56.18538871407509, 58.6571104824543, 58.443326354026794, 61.348232477903366, 57.874561473727226, 60.61509221792221, 56.41998432576656, 60.73624111711979, 69.67552363872528, 70.7162193953991, 73.14910724759102, 76.03098660707474, 79.30866792798042, 73.77271458506584, 71.92235067486763, 69.78549733757973, 68.07390198111534, 67.22841694951057, 62.545293644070625, 60.15404015779495, 58.29943187534809, 62.128547206521034, 62.626765072345734, 66.18570730090141, 69.74752217531204, 71.39325186610222, 73.65729957818985, 79.30276304483414, 83.94933611154556, 78.19151267409325, 70.20248696208, 74.8033332824707, 74.96637493371964, 76.0271868109703, 61.927914172410965, 11.933354660868645, 3.6201377073302865, 3.866459964774549, 2.9243342438712716, 3.0025121988728642, 1.1106634209863842, 1.4323971443809569, 0.28539241407997906, 0.20080427726497874, 23.318826220929623, 50.64041465520859, 48.42993646860123, 82.6626643538475, 39.33065593242645, 44.8629766702652, 66.93457871675491, 68.68568435311317, 71.73823535442352, 94.55497741699219, 32.474676221609116, 1.0751945804804564, 0.3796766063896939, 0.2815837418893352, 0.11445285694207996, 0.1847288539283909, 0.19905709836166352, 0.18429726536851376, 0.23849663673900068, 0.14879438997013494, 0.11122938303742558, 0.1575335647794418, 0.0994598856777884, 0.19242312933783978, 0.16564762860070914, 0.10725343818194233, 0.11879151905304752, 0.2038281728164293, 0.15201480622636154, 0.20798041485249996, 0.21227826626272872, 0.17276286554988474], [0.06714354749419726, 0.018845350386982318, 0.02068584322842071, 0.016135878686327487, 0.09509019437246025, 0.04228868041536771, 0.045668710372410715, 0.00951451596847619, 0.04504637872742023, 0.06371581970597617, 0.05502472122316249, 0.024187858143704943, 0.10495344831724651, 0.07414298714138567, 0.06608643234358169, 0.09277696459321305, 0.191081756784115, 0.07610035710968077, 48.13118129968643, 90.15444874763489, 77.40139067173004, 74.90382269024849, 61.49071343243122, 33.83197858929634, 62.48016133904457, 122.28732571005821, 47.89908595383167, 14.028925113379955, 0.23162868339568377, 0.27924897498451173, 0.2914897509617731, 0.6111482216510922, 1.7207550024613738, 0.37221440055873245, 2.592799896374345, 1.7726462054997683, 0.3559311758726835, 59.3116557598114, 95.98368555307388, 85.56775286793709, 81.168432533741, 84.69242423772812, 78.43202456831932, 78.64404559135437, 82.9460683465004, 85.90281888842583, 82.48616382479668, 77.72706359624863, 73.64896282553673, 70.17447486519814, 58.301012590527534, 54.674977362155914, 56.421143263578415, 57.37719476222992, 55.49716964364052, 59.00203697383404, 69.36817333102226, 74.59470927715302, 74.34947803616524, 68.81735488772392, 66.0941170156002, 62.393924966454506, 63.768140226602554, 61.83821238577366, 61.33108399808407, 57.30269975960255, 54.92916092276573, 52.24796399474144, 49.44562576711178, 52.486161813139915, 48.6954016238451, 49.033138900995255, 51.58474378287792, 51.63727216422558, 51.62169300019741, 51.91888265311718, 55.22743731737137, 53.6106962710619, 56.0692935436964, 52.22930699586868, 57.62309096753597, 68.62744107842445, 68.69499385356903, 70.76465159654617, 69.08362939953804, 67.010118663311, 68.84883999824524, 61.61986090242863, 52.27733641862869, 69.20937985181808, 58.869522884488106, 59.04617540538311, 55.13989761471748, 57.25924909114838, 57.28159949183464, 62.289050593972206, 58.09227839112282, 56.63874998688698, 53.32520239055157, 53.257824406027794, 50.89755825698376, 48.41670177876949, 50.690355375409126, 51.61715604364872, 51.88826009631157, 50.74422128498554, 51.15837246179581, 52.019277065992355, 56.52847230434418, 66.33295699954033, 66.55361115932465, 66.48184061050415, 63.56006719172001, 65.022551715374, 60.86421065032482, 60.51814801990986, 59.36807133257389, 56.6610623896122, 54.040362015366554, 54.199440479278564, 53.64839404821396, 50.91532230377197, 50.93625918030739, 57.12177626788616, 60.17087325453758, 69.12912055850029, 72.84177973866463, 72.78710827231407, 72.04302459955215, 74.96599495410919, 74.5261837542057, 72.41868004202843, 72.03272715210915, 73.98184776306152, 71.29838615655899, 67.14808166027069, 15.136615075170994, 0.8283561444841325, 0.5250902019906789, 1.348069456871599, 0.598487063543871, 0.5819845490623266, 0.023636934092792217, 0.007765624095554813, 1.5148098533973098, 20.050178915262222, 27.49794267117977, 44.68126282095909, 29.89092316478491, 14.269450306892395, 21.956692412495613, 37.22324721515179, 60.67946836352348, 59.00627754628658, 62.20504470169544, 3.1414902163669467, 0.5695345171261579, 0.07082690062816255, 0.06274788102018647, 0.03577106159355026, 0.030423533207795117, 0.05584095008089207, 0.0780927787127439, 0.05754469850216992, 0.037726149457739666, 0.03552973001205828, 0.03264480903453659, 0.02913348016591044, 0.014797745607211255, 0.08506644357112236, 0.02715473634452792, 0.06446428305935115, 0.04875034501310438, 0.08790400068392046, 0.015397498336824356, 0.045204652851680294, 0.016048589131969493, 0.06520545110106468, 0.03141632456390653, 0.030008117901161313, 0.051645477942656726, 0.0691129476763308, 0.028483843052526936, 0.09178080945275724, 0.011519183935888577, 0.020127603456785437, 0.030004318105056882, 0.0843125773826614, 0.03685019997647032, 0.1007989798381459, 0.12702516512945294, 0.04667674729716964, 0.15524454385740682, 0.03452186378126498, 63.695423528552055, 98.3904080092907, 85.85709974169731, 84.17194336652756, 70.93296736478806, 36.194976791739464, 50.018635019659996, 107.76784881949425, 52.7386050671339, 15.68274836987257, 0.30317712225951254, 0.27918921725358814, 1.3464452815242112, 1.9001214089803398, 2.669770228676498, 2.7400391455739737, 3.2577646896243095, 1.6844383324496448, 1.0183978406712413, 67.25860252976418, 97.84103348851204, 90.43621882796288, 84.87230658531189, 89.04582783579826, 82.1775671839714, 80.64396947622299, 86.28475159406662, 89.61987063288689, 85.64465314149857, 82.04580545425415, 77.62398272752762, 74.00219947099686, 62.3027678579092, 60.06869673728943, 59.175999239087105, 60.40085211396217, 56.66840359568596, 62.22017928957939, 76.77653700113297, 77.64418244361877, 76.57438784837723, 74.12647560238838, 70.41321605443954, 65.78680470585823, 64.59423869848251, 65.75648993253708, 64.4458794593811, 59.603806883096695, 57.8604756295681, 54.35650125145912, 51.6974913328886, 55.38211941719055, 52.67469249665737, 52.13892504572868, 54.19521510601044, 55.00162683427334, 55.09690672159195, 54.09615062177181, 57.1363864839077, 56.93743675947189, 58.790243938565254, 55.511890053749084, 59.72350426018238, 71.60733237862587, 71.59910202026367, 71.89812317490578, 73.5510116815567, 68.17459657788277, 70.72027757763863, 62.483961135149, 56.883149072527885, 71.0486027598381, 62.68020160496235, 61.77422381937504, 56.92324072122574, 58.521849140524864, 60.111003667116165, 64.20947894454002, 61.454957351088524, 60.63453197479248, 55.411347448825836, 54.13168631494045, 53.25704924762249, 50.46232581138611, 53.82987231016159, 52.76905283331871, 53.81008677184582, 52.65882834792137, 55.288652032613754, 53.19374464452267, 58.49523916840553, 69.26858827471733, 69.171062707901, 69.87955749034882, 66.68101832270622, 69.15308207273483, 64.73604708909988, 64.59717214107513, 64.76157411932945, 57.77743108570576, 55.34426584839821, 56.020492762327194, 56.81123413145542, 54.962469935417175, 55.24771302938461, 59.90269884467125, 63.29394467175007, 71.00903928279877, 74.95426878333092, 76.76294893026352, 77.13896155357361, 76.53032541275024, 77.7362135052681, 74.13518473505974, 73.96781891584396, 76.81693643331528, 73.64127203822136, 73.16995292901993, 21.78142871707678, 0.17843366047600284, 1.124694524332881, 0.39796719211153686, 1.4778923406265676, 1.537796244956553, 0.35245816223323345, 0.12228931300342083, 1.5952241071499884, 33.9561977237463, 34.28114488720894, 43.25162373483181, 32.49400198459625, 24.7166059166193, 32.20518708229065, 45.47692872583866, 68.96606370806694, 65.28618156909943, 81.31802290678024, 7.013371540233493, 0.7029761129524559, 0.117860279569868, 0.013994820674270159, 0.013682203025382478, 0.05770278708951082, 0.05520137834537309, 0.05586985302215908, 0.021943410611129366, 0.02805820095090894, 0.017934423485712614, 0.021546936768572778, 0.05793350224848837, 0.03773638738493901, 0.08639576364657842, 0.0629155470232945, 0.04314462159527466, 0.03554329647158738, 0.06652422525803559, 0.07359799841651693, 0.07516223049606197, 0.07741534631350078, 0.2088043323601596, 0.10687470537959598, 0.09765144990524277, 0.13820630265399814, 0.2022435242542997, 0.09246801593690179, 0.26921582117211074, 0.11288222754956223, 0.16367831005482003, 0.16416594560723752, 0.16321595205226913, 0.1821351665421389, 0.2648594439961016, 0.30734113475773484, 0.1643502654042095, 0.37940693960990757, 0.1663599122548476, 76.31884396076202, 110.75453415513039, 99.57453086972237, 93.0645377933979, 85.0710891187191, 48.74759182333946, 87.7780182659626, 145.3292816877365, 67.70130917429924, 24.246620535850525, 0.37527878768742085, 0.6523525575175881, 1.8206622102297843, 3.048601350747049, 4.229093743488193, 5.358798298984766, 9.911058526486158, 9.931274391710758, 1.7726534488610923, 75.16675338149071, 98.69682356715202, 96.87074035406113, 85.55322244763374, 92.10278660058975, 82.81305268406868, 84.94401633739471, 87.48912736773491, 94.29552733898163, 88.94966259598732, 85.29497310519218, 80.42128622531891, 78.34671914577484, 64.76717501878738, 62.610087767243385, 62.73389272391796, 64.25416454672813, 59.16529901325703, 64.56496506929398, 78.62637653946877, 81.90917238593102, 78.17671626806259, 76.47289529442787, 72.61490151286125, 68.88072788715363, 68.52267310023308, 68.08819681406021, 67.58307471871376, 62.75744006037712, 60.674616023898125, 57.706374898552895, 53.66383261978626, 58.084952384233475, 54.899621307849884, 54.28089290857315, 56.92247696220875, 57.4087330698967, 58.393849208950996, 58.25321115553379, 61.13434575498104, 60.408991277217865, 63.101598992943764, 59.31615091860294, 63.29304791986942, 77.35439479351044, 73.45124423503876, 76.04539543390274, 75.15172898769379, 72.92248740792274, 73.57580155134201, 67.16204971075058, 60.43516427278519, 75.6089736521244, 67.88532570004463, 65.5730889737606, 60.69212548434734, 62.61985704302788, 63.01072306931019, 68.46522778272629, 64.15993720293045, 64.41016897559166, 58.948851227760315, 57.99403466284275, 55.97113341093063, 52.94803462922573, 57.467709705233574, 56.308388113975525, 58.56352910399437, 54.86513435840607, 57.5331611931324, 56.2734641879797, 63.032818883657455, 72.46678546071053, 72.87343204021454, 75.23326501250267, 70.58353051543236, 72.47309312224388, 69.22065004706383, 68.52113798260689, 67.8037516772747, 62.05665126442909, 59.61581043899059, 59.55514669418335, 59.34727884829044, 58.10751557350159, 57.16585390269756, 63.272836804389954, 66.34386241436005, 73.48937138915062, 78.15951839089394, 78.90145137906075, 80.26436224579811, 77.96482443809509, 80.00257149338722, 77.68560022115707, 78.69670316576958, 80.82992389798164, 76.54597297310829, 74.92203131318092, 19.215050227940083, 2.5912875775247812, 4.430443989112973, 6.386009054258466, 2.5900630932301283, 2.4029079359024763, 0.6611669564153999, 0.14011982653755695, 3.2022351818159223, 35.75245253741741, 41.32197707891464, 61.758716851472855, 42.09602214396, 20.927285850048065, 35.55902771651745, 54.35451775789261, 79.3728768825531, 76.36129528284073, 89.24179092049599, 6.370961386710405, 0.8049791457597166, 0.26024010905530304, 0.14674499368993565, 0.0985392440634314, 0.1831047231098637, 0.16050634119892493, 0.16033454885473475, 0.2015089464839548, 0.10991492075845599, 0.11040982935810462, 0.1743624164373614, 0.1338517214753665, 0.08310240911669098, 0.21776845213025808, 0.12555595021694899, 0.23814582353224978, 0.15219980879919603, 0.16990184172755107, 0.14136773301288486, 0.17242481728317216], [0.02658893594343681, 0.03188492773915641, 0.012135470788052771, 0.03582275960070547, 0.029847780606360175, 0.012593022456712788, 0.10024979055742733, 0.029711980569118168, 0.06604562164284289, 0.019801852577074897, 0.08858198227244429, 0.03263399223214947, 0.12542770709842443, 0.04736516719276551, 0.07002158876275644, 0.11483275491627865, 0.25694280629977584, 8.314882926642895, 84.75759834051132, 77.08684355020523, 82.45116010308266, 58.370883241295815, 36.01326294243336, 27.484894171357155, 41.73238165676594, 48.898405730724335, 39.501817747950554, 1.3859263504855335, 0.1467790434253402, 0.09281540042138658, 1.6481940960511565, 0.7585131016094238, 1.61576259881258, 1.5028537949547172, 1.4879600191488862, 1.3396584894508123, 23.156694620847702, 99.67228442430496, 80.06857395172119, 86.1543045938015, 80.70881679654121, 78.87296810746193, 81.22809693217278, 82.21408322453499, 76.57219916582108, 78.5890245437622, 76.54401987791061, 83.14669758081436, 78.7643775343895, 74.64098319411278, 65.50454065203667, 56.49728737771511, 55.8604833483696, 56.93754695355892, 53.862333968281746, 59.19680692255497, 69.80450391769409, 74.3025353550911, 73.41167315840721, 68.14574852585793, 59.78333964943886, 52.729234769940376, 55.02982132136822, 54.55103561282158, 52.04724356532097, 48.75584118068218, 51.088304221630096, 49.39414992928505, 53.46610262989998, 49.79785926640034, 49.5531789958477, 50.79411640763283, 52.55232386291027, 51.15122124552727, 50.783488377928734, 50.50497852265835, 54.602104872465134, 53.19507457315922, 54.232859686017036, 52.170774936676025, 54.81336213648319, 58.574939891695976, 65.45395776629448, 67.57613629102707, 68.5372719168663, 66.11759975552559, 70.69066196680069, 58.10020476579666, 50.42392127215862, 68.69072288274765, 55.605832412838936, 54.27123762667179, 54.08570498228073, 54.398462399840355, 55.52864335477352, 57.08852805197239, 54.46601137518883, 53.31629566848278, 54.06725317239761, 54.569837003946304, 55.43906696140766, 54.93149779736996, 52.29280538856983, 52.56343826651573, 49.44032125174999, 47.880368158221245, 48.41098688542843, 50.505335703492165, 51.23201251029968, 51.404074877500534, 60.52290536463261, 63.82733345031738, 63.102697134017944, 62.096948102116585, 63.159105107188225, 63.10618534684181, 62.01261542737484, 57.24004492163658, 53.592274859547615, 52.51186743378639, 53.12315583229065, 52.508550211787224, 53.57008405029774, 56.65950067341328, 63.679095804691315, 70.8210177719593, 70.48905238509178, 71.54306262731552, 69.47768345475197, 73.7256047129631, 74.98779058456421, 75.28890922665596, 70.26210576295853, 72.80322700738907, 71.57661482691765, 72.41528302431107, 83.86990517377853, 21.471971422433853, 1.0540664079599082, 1.5187806403264403, 0.6453513144515455, 0.4269612691132352, 0.15791725512826815, 0.020443507892196067, 0.9459206485189497, 12.294836863875389, 21.202280893921852, 35.09938918054104, 47.417530193924904, 22.264132015407085, 21.40710700303316, 39.43371780216694, 50.609902292490005, 56.04213260114193, 69.49812635779381, 30.980767384171486, 0.42790391540620476, 0.01776652741682483, 0.028010603309667204, 0.023889433141448535, 0.0112991213791247, 0.06653116433881223, 0.07514216282288544, 0.0524757853418123, 0.014950243967177812, 0.0456605467479676, 0.05492850177688524, 0.03343761200085282, 0.06755828930181451, 0.006455817865571589, 0.03781637606152799, 0.0032977814407786354, 0.0414894318964798, 0.1003550345194526, 0.015477844171982724, 0.029964088134875055, 0.03273608206654899, 0.0062641341082780855, 0.009130133566941367, 0.11603918275795877, 0.03274335882451851, 0.022149716533022, 0.08679748818394728, 0.02116703322826652, 0.042893334102700464, 0.011914634542335989, 0.007094610346030095, 0.08434149145614356, 0.07673395084566437, 0.046519144816556945, 0.11273160867858678, 0.11759726985474117, 0.21996783645590767, 12.489731255918741, 104.48670208454132, 83.86528462171555, 94.08379510045052, 66.46689221262932, 57.50657021999359, 40.05585461854935, 47.41227127611637, 56.97378560900688, 46.8408465385437, 1.7661768151447177, 0.1332914296654053, 0.43644674762617797, 1.7508231452666223, 2.335655107162893, 4.421559115871787, 8.20729834958911, 1.1472375271841884, 2.2914831899106503, 29.666526205837727, 102.73317977786064, 82.01475352048874, 87.78234243392944, 83.88377442955971, 84.22270104289055, 84.50172767043114, 86.77617162466049, 77.95044600963593, 80.50485134124756, 79.56863477826118, 83.80539983510971, 80.70615693926811, 78.46436083316803, 70.35950973629951, 60.20916000008583, 58.85933183133602, 60.512452125549316, 57.77032166719437, 62.05076538026333, 72.87465557456017, 76.63914397358894, 77.56903767585754, 71.41558706760406, 63.131115809082985, 55.13757973909378, 56.52469150722027, 56.08779475092888, 54.52705129981041, 52.657578215003014, 53.14076028764248, 53.286201283335686, 54.711018428206444, 52.97247111797333, 51.352709233760834, 55.026036724448204, 54.872068986296654, 53.79164636135101, 54.98498372733593, 53.50962929427624, 56.53929032385349, 56.972185894846916, 56.98182597756386, 55.57155065238476, 57.14622415602207, 60.00294886529446, 67.19524472951889, 70.02416253089905, 73.29278513789177, 68.82071390748024, 72.93906971812248, 61.49270072579384, 54.495182409882545, 72.24401101469994, 59.45816449820995, 55.208362340927124, 56.44217513501644, 57.25620925426483, 58.223956525325775, 59.03052404522896, 56.32791146636009, 56.44614592194557, 55.41995778679848, 58.37851703166962, 58.61665025353432, 55.451442897319794, 55.616498440504074, 54.02791008353233, 50.44301524758339, 50.954726189374924, 51.506479382514954, 53.25422219932079, 52.97564394772053, 53.738472014665604, 62.52969168126583, 67.40570023655891, 66.87561348080635, 65.4990765452385, 65.56231275200844, 65.68107917904854, 63.50728042423725, 60.80115683376789, 55.023354068398476, 54.47442792356014, 56.42015151679516, 56.01889304816723, 55.47393009066582, 61.17540255188942, 67.55285114049911, 74.18237820267677, 72.560496032238, 73.08020174503326, 71.2880127131939, 73.95238414406776, 77.86963954567909, 78.96325126290321, 72.93518632650375, 77.625343054533, 76.40941590070724, 76.26044869422913, 86.1083422601223, 29.451374150812626, 0.5327035090886056, 0.8365662570577115, 1.1810110649093986, 0.9660140296909958, 0.9783397964201868, 0.001197011263229797, 0.2848839241778478, 11.387648843228817, 31.724353283643723, 35.97803123295307, 36.272849813103676, 25.177475586533546, 34.19034495949745, 45.843958631157875, 60.34648083150387, 63.68672579526901, 75.17628327012062, 48.03661957383156, 1.00345074897632, 0.08989310488686897, 0.00999385987597634, 0.04012980993138626, 0.027831378356495406, 0.007700628657403286, 0.04934083110128995, 0.07142164293327369, 0.023805141863704193, 0.09161944428342395, 0.015023318610474234, 0.011063551646657288, 0.01489665626650094, 0.020687813630502205, 0.030223529975046404, 0.05169068957911804, 0.022557476586371195, 0.06396325916284695, 0.08161287420080043, 0.011243759017816046, 0.1353640848537907, 0.13256223988719285, 0.1143076854350511, 0.1396103570004925, 0.13807146926410496, 0.1652153572649695, 0.13822678592987359, 0.21755959693109617, 0.18372165563050658, 0.11609183071414009, 0.11810348136350513, 0.20198656304273754, 0.16932698898017406, 0.2250969229498878, 0.21845645271241665, 0.32119593350216746, 0.7687866222113371, 14.604925755411386, 116.37491136789322, 95.40510579943657, 106.4664414525032, 77.29543715715408, 56.80157504975796, 40.42066924273968, 64.05732750892639, 62.738817259669304, 63.538963124156, 3.311712294816971, 0.28404396143741906, 0.20877957431366667, 5.88334827683866, 4.7111178282648325, 6.402983218431473, 9.021914787590504, 8.642291408032179, 5.350361801683903, 34.354682341217995, 106.60596996545792, 86.81360721588135, 90.26572197675705, 90.74883565306664, 85.9289538860321, 89.29802030324936, 87.54103258252144, 80.12336701154709, 82.19117045402527, 81.84667333960533, 87.71103546023369, 86.23425230383873, 84.00522351264954, 73.85935753583908, 65.2142970263958, 62.89921425282955, 61.04024760425091, 60.33837586641312, 65.31263574957848, 76.87280103564262, 80.53686082363129, 80.98864898085594, 73.77337574958801, 66.72003462910652, 58.451309725642204, 60.12607365846634, 60.924498215317726, 57.55994215607643, 55.55713802576065, 56.68177507817745, 55.413053557276726, 58.78566138446331, 54.797304198145866, 55.329366847872734, 57.42097981274128, 57.52722591161728, 57.017342671751976, 58.39448757469654, 56.31746582686901, 59.919999316334724, 60.05407892167568, 61.25744014978409, 57.04483799636364, 60.61169520020485, 63.794655203819275, 71.72413811087608, 74.31521147489548, 73.22161495685577, 72.12673410773277, 77.65796810388565, 62.89778932929039, 57.390353456139565, 73.44403982162476, 60.118679255247116, 59.678412079811096, 60.75375057756901, 59.408421367406845, 62.46428199112415, 62.67265520989895, 59.51392650604248, 58.477718308568, 58.49155716598034, 61.6791757196188, 60.065409913659096, 59.57125402987003, 57.94067792594433, 57.386416867375374, 54.4816817343235, 52.81578652560711, 55.61864912509918, 55.47032408416271, 57.05875284969807, 55.25608777999878, 67.77113422751427, 71.36164516210556, 69.54274356365204, 70.17285615205765, 69.94321167469025, 70.63833877444267, 68.30241411924362, 63.31600248813629, 57.98496074974537, 59.24658045172691, 60.755110904574394, 59.39275100827217, 59.674277901649475, 63.06991249322891, 71.11671790480614, 76.29943460226059, 74.99459981918335, 73.84268403053284, 73.45436006784439, 79.3101954460144, 81.13437876105309, 81.97969660162926, 78.8239735364914, 79.69146698713303, 78.14989730715752, 80.23773327469826, 91.74527898430824, 25.0359008833766, 1.9130173232406378, 5.3468612395226955, 3.2482808735221624, 1.4287950564175844, 0.961248135427013, 0.10518102790229023, 1.5622023353353143, 21.49845600128174, 38.93139995634556, 50.466087609529495, 62.779421880841255, 33.073892667889595, 35.4887542873621, 55.40172256529331, 69.4436676800251, 72.07242742180824, 91.15828648209572, 49.05740439891815, 0.7444146112538874, 0.1256283838301897, 0.0933206471381709, 0.17043418425600976, 0.08745346509385854, 0.08856434884364717, 0.15367472340585664, 0.14262662327382714, 0.11563989246496931, 0.2791902265744284, 0.22596005554078147, 0.07189419062342495, 0.15177252469584346, 0.12539198010927066, 0.1557334855897352, 0.17081262019928545, 0.11674645691527985, 0.25578725268132985, 0.11003033214365132, 0.13837094069458544], [0.03617478992964607, 0.03383676870726049, 0.05013075082388241, 0.10435097283334471, 0.03068724981858395, 0.03787955880397931, 0.07251360933878459, 0.02862961384380469, 0.0022426768146033282, 0.036439970426727086, 0.019673358983709477, 0.04811446546227671, 0.05635286870528944, 0.05984929339319933, 0.07998432018212043, 0.0560728860727977, 0.015922437014523894, 44.03200685977936, 92.54705876111984, 69.72137957811356, 66.87777176499367, 63.6009605973959, 22.32092946767807, 28.673027716577053, 39.10977378487587, 36.02231405675411, 17.21304215490818, 0.09359154588310048, 0.06111940121627413, 0.3200206090696156, 0.6048480409663171, 2.0513947354629636, 2.1104628033936024, 3.1589189311489463, 2.66653707716614, 1.8636995321139693, 80.76770603656769, 84.81834188103676, 83.03828939795494, 77.53699779510498, 75.47110944986343, 78.29175129532814, 78.81187498569489, 80.43158367276192, 81.78698614239693, 79.67648819088936, 76.54138281941414, 73.02769616246223, 80.14554262161255, 76.23672276735306, 69.02822837233543, 57.244635075330734, 57.58150979876518, 55.1515743881464, 55.629223957657814, 57.899583131074905, 71.22107550501823, 73.0471359193325, 71.64267808198929, 67.7215088903904, 58.22883926331997, 53.10447223484516, 52.746033668518066, 50.6098984926939, 52.68988788127899, 52.71325662732124, 50.75735718011856, 50.864473432302475, 51.15437127649784, 49.67256858944893, 50.177215710282326, 51.709608882665634, 52.42857210338116, 48.54281701147556, 48.94034028053284, 48.754017278552055, 49.24290284514427, 53.28965149819851, 52.471661791205406, 53.49734075367451, 51.35805934667587, 53.961231261491776, 60.314038172364235, 57.880253568291664, 64.20818701386452, 61.48375600576401, 68.46636772155762, 60.3704309463501, 51.40470564365387, 71.49632513523102, 59.29711394011974, 50.71526683866978, 51.96199133992195, 54.440085366368294, 54.43874403834343, 59.457814916968346, 61.2815460562706, 63.11636880040169, 63.622988015413284, 64.71610575914383, 66.43003419041634, 62.95380212366581, 60.546220913529396, 59.00304391980171, 52.79495984315872, 51.01475156843662, 46.651107519865036, 47.844695672392845, 48.9670642465353, 50.51701247692108, 48.310242891311646, 55.76460309326649, 58.69265757501125, 62.164941653609276, 60.03970809280872, 60.542113333940506, 60.594763308763504, 58.449869602918625, 52.35587440431118, 50.64558997750282, 53.62369157373905, 50.85997827351093, 53.15216347575188, 57.38015100359917, 66.34250968694687, 70.78781515359879, 72.82124564051628, 72.15439662337303, 70.83728089928627, 69.79947298765182, 69.32329773902893, 71.13173469901085, 73.69347363710403, 73.80099266767502, 71.03291720151901, 71.5499098598957, 68.37963357567787, 89.28868800401688, 33.150485157966614, 0.20263162296032533, 1.5475203981623054, 0.8755037770606577, 0.7424569444265217, 0.10313572827726603, 0.12449548055883497, 9.537594616413116, 36.34777419269085, 31.922014877200127, 64.09447431564331, 44.6610327064991, 20.860821716487408, 17.83747784793377, 51.059893146157265, 66.0487550497055, 56.362994983792305, 72.37583354115486, 9.841470010578632, 0.4145796038210392, 0.12015526735922322, 0.05742826295318082, 0.0162242925944156, 0.08819208756904118, 0.02940969825431239, 0.02304218436620431, 0.08557606153772213, 0.03206950357707683, 0.052680888984468766, 0.05053139182564337, 0.058188114562653936, 0.027187537416466512, 0.03928264093701728, 0.12147443485446274, 0.06960781174711883, 0.04472023079870269, 0.028329329761618283, 0.04273568709322717, 0.03016143076820299, 0.04063185057020746, 0.019415312381170224, 0.02800326532451436, 0.04962600134604145, 0.08111910850857385, 0.019938539480790496, 0.018070915575663093, 0.01650755737500731, 0.01663310464209644, 0.011898292450496228, 0.03334875094878953, 0.05916855101531837, 0.02549769498727983, 0.057900472966139205, 0.021653049043379724, 0.07131891485187225, 55.38317956030369, 102.47855544090271, 78.84632393717766, 74.37469348311424, 78.79046693444252, 41.1223091930151, 30.875646024942398, 26.923405900597572, 41.90175376832485, 20.1502750441432, 0.07005664781900123, 0.061846583485021256, 1.3965071202255785, 2.186766746453941, 2.2745885839685798, 5.165869351476431, 4.9610242433846, 2.864206270314753, 4.400047995150089, 87.38537773489952, 90.27439311146736, 86.9582350552082, 82.18677029013634, 79.1350020468235, 80.44739082455635, 82.0154070854187, 83.09653267264366, 85.45960307121277, 81.66453391313553, 80.5050641298294, 77.03401118516922, 84.45370584726334, 78.37855383753777, 73.81438314914703, 58.94401028752327, 58.975126817822456, 57.17139780521393, 58.144669979810715, 59.59978669881821, 74.03425455093384, 75.01115173101425, 74.06666681170464, 70.1410062611103, 60.93170642852783, 55.022316724061966, 55.00186242163181, 53.34740839898586, 54.97442029416561, 55.245630741119385, 53.826068714261055, 54.03342358767986, 53.66817578673363, 51.86890013515949, 52.98328913748264, 54.719533771276474, 54.58108440041542, 52.01887048780918, 51.87330409884453, 53.66716504096985, 52.64183945953846, 56.29735730588436, 57.348335310816765, 57.722136452794075, 53.75669963657856, 56.29404008388519, 61.98572427034378, 61.23403340578079, 67.07131817936897, 64.95956629514694, 71.77390784025192, 60.92253752052784, 53.911913707852364, 73.40861812233925, 61.78181201219559, 52.43962951004505, 54.299660101532936, 56.51978597044945, 57.98709623515606, 62.67283380031586, 62.87750601768494, 65.93780100345612, 67.26866438984871, 68.91642317175865, 68.8007801771164, 65.73356956243515, 62.74145811796188, 62.01509669423103, 55.9785658121109, 54.554995000362396, 48.61902952194214, 50.31343840062618, 51.5174949914217, 52.2745967656374, 51.84505641460419, 56.81413717567921, 61.98209926486015, 65.28354451060295, 63.43593165278435, 62.84808039665222, 63.614275082945824, 61.10624626278877, 54.29253168404102, 53.565262109041214, 55.493875220417976, 53.90888147056103, 55.43742164969444, 60.357230454683304, 68.90787363052368, 74.62932541966438, 75.8967474102974, 74.01588633656502, 73.52936804294586, 72.06994995474815, 72.56027564406395, 75.40072962641716, 75.15330210328102, 75.69719731807709, 73.65501210093498, 74.81028690934181, 69.63121801614761, 90.12878492474556, 42.99974665045738, 0.7432682008948177, 0.3802668215939775, 1.0067976568825543, 1.3117400812916458, 0.663261356530711, 0.1055279522552155, 4.797871448099613, 41.628438234329224, 37.305387407541275, 46.196648105978966, 31.474716179072857, 27.240464687347412, 32.43534453213215, 58.25460568070412, 74.65267136693001, 60.90263418853283, 85.48728078603745, 15.799337513744831, 0.7945855159778148, 0.1324907413800247, 0.12060653767548501, 0.01550520901218988, 0.08617510829935782, 0.08253975727711804, 0.017158363370981533, 0.06203859935340006, 0.021710005166823976, 0.03392871338292025, 0.0715536338975653, 0.02392268506810069, 0.08586030409787782, 0.0382311698194826, 0.03783633241255302, 0.055236882690223865, 0.030074439928284846, 0.0940966812777333, 0.04469940613489598, 0.15880317165283486, 0.12056397550622933, 0.13173510145861655, 0.2641641109948978, 0.13340638834051788, 0.13912908907514066, 0.1805277043604292, 0.08693120835232548, 0.09956836540368386, 0.16428975068265572, 0.14131225005257875, 0.1332967879716307, 0.19221373979235068, 0.19377030548639596, 0.17109634325606748, 0.12158586090663448, 0.19038908067159355, 71.75049349665642, 113.98686110973358, 90.5548332631588, 85.15965476632118, 85.57023793458939, 34.38887670636177, 40.51699787378311, 53.25386121869087, 59.847624599933624, 29.10824876278639, 0.17238732398254797, 0.15308576985262334, 2.173415687866509, 6.197816552594304, 6.69838079251349, 8.432472366839647, 12.184879314154387, 10.230954810976982, 6.0678882244974375, 92.68804639577866, 91.60353899002075, 92.48011395335197, 85.47740891575813, 82.51453310251236, 85.07403776049614, 86.50077000260353, 87.61747688055038, 90.18607825040817, 85.15841603279114, 82.9292656481266, 78.4483028948307, 86.06397584080696, 82.42156729102135, 78.26723501086235, 61.53969660401344, 63.5444500297308, 59.72690127789974, 61.20159074664116, 63.35455521941185, 78.57979863882065, 79.24350142478943, 77.57271587848663, 73.88825878500938, 64.10263627767563, 56.84406436979771, 59.098787382245064, 56.02664463222027, 58.09077747166157, 59.08133111894131, 56.472603902220726, 56.330521926283836, 57.51093618571758, 53.48161339759827, 56.35230615735054, 57.16034419834614, 56.534969955682755, 54.53457489609718, 52.603222131729126, 55.89976564049721, 56.31283387541771, 60.86794205009937, 60.21038353443146, 60.47932930290699, 56.368766874074936, 59.97875176370144, 65.7818953692913, 64.90086704492569, 72.10379093885422, 68.71662989258766, 75.42781457304955, 65.00434309244156, 58.61694283783436, 76.41275212168694, 66.3710005581379, 54.94524545967579, 57.732221111655235, 59.25123520195484, 62.286158949136734, 66.4872895181179, 66.54803305864334, 70.38801580667496, 72.53103241324425, 71.95755958557129, 72.29677498340607, 68.69415789842606, 67.36277014017105, 64.70969170331955, 58.84917117655277, 58.60535725951195, 51.14823080599308, 53.16612772643566, 53.74254159629345, 57.33813665807247, 53.84655341506004, 59.38541740179062, 65.86845472455025, 69.99974504113197, 64.59441348910332, 66.79528579115868, 67.56975263357162, 64.07177433371544, 56.841928884387016, 57.40555264055729, 58.95314499735832, 56.35024666786194, 58.91463026404381, 62.923544347286224, 71.95741519331932, 78.04974228143692, 78.43628793954849, 77.15674459934235, 74.76437777280807, 75.33405840396881, 75.27357324957848, 78.62485662102699, 79.86481368541718, 78.42668205499649, 77.23305970430374, 77.18470349907875, 72.96123012900352, 94.0241838991642, 37.8747184574604, 0.9780331410001963, 7.347339894622564, 3.9563472289592028, 1.9640888390131295, 0.5463535047601908, 0.31653625541366637, 16.49905476719141, 52.38537222146988, 48.62308390438557, 84.8495914041996, 59.890303909778595, 30.478535033762455, 31.09148394316435, 64.76164251565933, 84.04251471161842, 69.96597245335579, 97.0260152220726, 15.315582621842623, 1.1352476268075407, 0.3070902294712141, 0.22953100298764184, 0.1110949058784172, 0.22643091855570674, 0.14225220977095887, 0.12702396285021678, 0.18173930497141555, 0.19704498758073896, 0.17978036165004596, 0.1383429765701294, 0.1516970928059891, 0.16353252256521955, 0.0718994227645453, 0.2021913364296779, 0.12817449955036864, 0.057243716801167466, 0.11629054075456224, 0.12112068274291232], [0.030626603365817573, 0.044163516140542924, 0.024387217563344166, 0.007293615853996016, 0.02625331821036525, 0.0492416245106142, 0.034220444213133305, 0.02631300358189037, 0.017166721809189767, 0.07742766596493311, 0.021229184385447297, 0.09663894525147043, 0.034328178080613725, 0.03809457382885739, 0.10305934643838555, 0.06077314850699622, 0.920999685768038, 59.8220481723547, 75.51341637969017, 74.50768634676933, 51.813848689198494, 26.128015480935574, 17.49193388968706, 55.71600750088692, 67.40464389324188, 37.163734808564186, 3.983890525996685, 0.07210076742921956, 0.2351463446393609, 1.8974828068166971, 1.0704912641085684, 0.8367002592422068, 6.360685788094997, 7.728950092568994, 1.231223470531404, 39.78388801217079, 97.99922659993172, 78.04168671369553, 84.76893693208694, 70.91244846582413, 75.53813025355339, 71.048853546381, 77.60851755738258, 73.25080499053001, 78.65365147590637, 76.33662700653076, 81.60031735897064, 76.1501482129097, 75.37977755069733, 74.84950840473175, 68.76313179731369, 57.52626456320286, 54.69776473939419, 53.97863432765007, 55.12234255671501, 52.656662464141846, 64.27528381347656, 69.29330974817276, 70.60986310243607, 66.8853485584259, 61.969556137919426, 53.53571109473705, 52.205907851457596, 49.75637309253216, 51.41086891293526, 51.478851065039635, 49.24440756440163, 48.72255876660347, 50.32650209963322, 50.338513255119324, 50.66800497472286, 50.04987694323063, 52.92958281934261, 50.58316312730312, 51.28904365003109, 48.240972608327866, 50.09104013442993, 50.490467101335526, 53.74589301645756, 53.64489823579788, 53.3468422293663, 49.53513756394386, 56.26945160329342, 50.99514462053776, 56.63758344948292, 57.21543364226818, 69.52537089586258, 58.25910843908787, 47.43415430188179, 71.69202223420143, 58.01190510392189, 53.41073580086231, 51.33273370563984, 57.63806216418743, 61.090872287750244, 63.864199072122574, 63.0763303488493, 61.47484928369522, 63.340332582592964, 64.2826934158802, 62.58837953209877, 64.55204576253891, 64.57978427410126, 62.87315525114536, 59.51250538229942, 54.16931189596653, 47.804778814315796, 47.13538013398647, 47.802343145012856, 48.32708738744259, 49.75206792354584, 49.226073548197746, 51.77848018705845, 53.00625130534172, 53.25806379318237, 55.608439072966576, 57.96777427196503, 54.028392657637596, 53.143663331866264, 52.90076516568661, 50.44689863920212, 50.741926208138466, 52.37195894122124, 55.183735862374306, 68.91728952527046, 69.17287901043892, 70.160461217165, 71.40955299139023, 71.5180067718029, 65.21743565797806, 65.50411507487297, 66.00926756858826, 68.52038562297821, 63.25951851904392, 65.3495317697525, 67.30268776416779, 76.31920114159584, 67.87896484136581, 87.58930519223213, 26.111474968492985, 0.4686379968188703, 2.0736316172406077, 1.817067840602249, 0.5266415874939412, 0.09700721377157606, 0.16685335140209645, 31.770437210798264, 43.94279524683952, 38.55462737381458, 60.504947528243065, 28.169813118875027, 16.23646415770054, 31.277195177972317, 52.21918813884258, 53.2086056470871, 64.20724466443062, 42.826221361756325, 1.1225728131830692, 0.09926965838531032, 0.03209882212104276, 0.04911478034046013, 0.026438745662744623, 0.04025716618343722, 0.03070300375838997, 0.02833816317433957, 0.011170768793817842, 0.04150049360760022, 0.047060960860108025, 0.05591386609012261, 0.0481718112132512, 0.021665847380063497, 0.05781863634183537, 0.02385348350799177, 0.025238486923626624, 0.04422901438374538, 0.03617667869548313, 0.044588521850528196, 0.08580061316024512, 0.01440082369299489, 0.034504263749113306, 0.060010313463862985, 0.06074362216168083, 0.03416458275751211, 0.031235359274432994, 0.06333111261483282, 0.04089714610017836, 0.05167233255633619, 0.03799340425757691, 0.025820215669227764, 0.021541105343203526, 0.04233572144585196, 0.12136378805735148, 3.054802855476737, 80.66852375864983, 83.7128672003746, 83.9886412024498, 63.4105072170496, 41.9514475017786, 25.23630402982235, 43.17592419683933, 51.54319301247597, 46.158676743507385, 4.53466004692018, 0.04699721779616084, 1.2524285889230669, 3.005271563306451, 2.741162935271859, 3.4861471597105265, 6.368754655122757, 1.4977340446785092, 1.4579114690423012, 45.23270823061466, 103.119026273489, 81.04591190814972, 86.73019409179688, 74.54389840364456, 79.14593786001205, 76.19963675737381, 81.372010409832, 77.91196167469025, 81.55908957123756, 78.95292341709137, 83.43474492430687, 79.04965862631798, 79.10615399479866, 76.22314989566803, 71.87294572591782, 60.89462801814079, 59.17336218059063, 57.30834245681763, 57.285881862044334, 55.14354541897774, 67.07741305232048, 71.04807838797569, 71.22210904955864, 69.33688580989838, 64.1963392496109, 55.82242079079151, 53.59789855778217, 52.56295569241047, 53.66546653211117, 52.28358328342438, 52.13796749711037, 51.3439355045557, 52.319004982709885, 52.571174651384354, 53.996166586875916, 51.58704645931721, 56.45796708762646, 54.39861439168453, 55.40587954223156, 51.72154404222965, 54.31110888719559, 53.51237274706364, 56.664421409368515, 57.271792218089104, 55.44100485742092, 54.22364518046379, 60.151254907250404, 54.37798909842968, 59.32564660906792, 58.27554635703564, 71.15353032946587, 60.13952873647213, 50.254279375076294, 73.04976537823677, 60.08336775004864, 54.74028825759888, 55.246968269348145, 61.06890186667442, 64.17043223977089, 68.34179520606995, 65.60593441128731, 65.47949999570847, 65.38478627800941, 64.92137834429741, 65.66582679748535, 67.51286968588829, 67.070482224226, 64.00589346885681, 62.27041259407997, 56.81501492857933, 50.474876537919044, 50.35719305276871, 49.710665345191956, 51.57284662127495, 53.23659114539623, 51.531246453523636, 51.79244063794613, 56.296262964606285, 55.2231739461422, 57.46062308549881, 60.12511990964413, 56.30126729607582, 54.87651854753494, 54.9226176738739, 53.3629609644413, 54.5387926697731, 54.140479043126106, 58.26302982866764, 72.5488306581974, 70.78333899378777, 73.05462911725044, 73.37188929319382, 75.2212044596672, 67.22339361906052, 67.45390444993973, 68.88005912303925, 68.69087487459183, 63.707643672823906, 67.23593294620514, 67.98422679305077, 81.28354355692863, 69.28569495677948, 91.38863012194633, 34.42914314568043, 0.5408181517850608, 0.777264857897535, 2.2650646325200796, 1.7091608745977283, 0.15580706211039796, 0.24061624018941075, 29.683518894016743, 57.52683073282242, 33.48105601966381, 40.135798528790474, 34.78486865758896, 30.113292932510376, 44.714374244213104, 58.86717841029167, 59.21718142926693, 70.97455993294716, 63.19761984050274, 2.604374550282955, 0.200370610691607, 0.051767531549558043, 0.03650382481282577, 0.016635561150906142, 0.01112393370931386, 0.05379597329010721, 0.02885115049139131, 0.035378966422285885, 0.02245924963062862, 0.11600618687225506, 0.07048621031572111, 0.08148705790517852, 0.06026374576322269, 0.01325351162449806, 0.020133342113695107, 0.023329291616391856, 0.017451144340157043, 0.06468001054599881, 0.12754046794725582, 0.20579468604410067, 0.10778123876661994, 0.11618727090535685, 0.1375365737476386, 0.13239691907074302, 0.140542138251476, 0.12352833597105928, 0.12779894314007834, 0.15484074130654335, 0.27179303287994117, 0.2821973792742938, 0.1902590860845521, 0.19814790808595717, 0.2644223190145567, 0.30534279823768884, 5.299740443006158, 97.83676251769066, 93.35105761885643, 96.06183975934982, 72.96207368373871, 41.69308416545391, 23.907420337200165, 82.10743814706802, 91.47727936506271, 57.9656919836998, 8.061587568372488, 0.16897135181352496, 1.2211987772025168, 5.168502135202289, 4.529817206785083, 5.552220270037651, 17.45726455003023, 20.499398410320282, 4.1544196754693985, 48.44271898269653, 107.9321976006031, 84.27095085382462, 90.64506322145462, 77.47940808534622, 82.07120329141617, 80.79191073775291, 85.45728519558907, 80.74692875146866, 85.60787111520767, 83.68805453181267, 88.37001129984856, 84.08193379640579, 82.22555100917816, 80.11311516165733, 77.693602591753, 65.67517429590225, 63.09298485517502, 61.094577088952065, 62.06374168395996, 57.332866340875626, 70.05153626203537, 75.84596693515778, 75.08816599845886, 72.79946520924568, 66.8762518465519, 58.961215764284134, 57.55602456629276, 54.695370867848396, 55.91117262840271, 55.97344368696213, 54.87658314406872, 55.20432695746422, 55.08464477956295, 55.81459321081638, 55.634368881583214, 56.18499353528023, 59.88741606473923, 57.29697726666927, 59.06678169965744, 53.77665996551514, 57.2521548718214, 56.68076053261757, 58.151775598526, 60.980655401945114, 58.79939004778862, 56.10095724463463, 61.52768164873123, 57.43230700492859, 61.54033496975899, 61.6980455070734, 75.43194875121117, 63.693880811333656, 53.35716627538204, 76.7997233569622, 64.32657346129417, 58.78931678831577, 56.38753026723862, 63.88765901327133, 68.86628866195679, 71.11739426851273, 69.77016896009445, 67.64838561415672, 68.13125610351562, 70.41573151946068, 69.08724680542946, 69.67868506908417, 70.06717622280121, 66.55643820762634, 64.76834535598755, 59.70401890575886, 52.89830669760704, 53.299903348088264, 51.59668654203415, 53.23621116578579, 55.01586467027664, 55.87057560682297, 55.63237018883228, 59.92685794830322, 56.620104387402534, 60.98470218479633, 64.54356461763382, 59.50600013136864, 58.05178016424179, 58.49379524588585, 55.1356266438961, 56.26928821206093, 57.85132572054863, 61.05783686041832, 76.8495462834835, 73.56016159057617, 75.46728685498238, 76.6926147043705, 78.98680239915848, 71.16579607129097, 72.21570253372192, 75.32664120197296, 74.1142326593399, 70.09325802326202, 71.39781922101974, 74.77169618010521, 83.4503772854805, 74.87839445471764, 94.74897980690002, 30.116501860320568, 1.7457462614402175, 7.443392090499401, 4.500522203743458, 2.2616068180650473, 0.3025173529749736, 0.34782057045958936, 41.770334020256996, 61.87921978533268, 56.224591210484505, 83.6576409637928, 43.90919364988804, 25.543418750166893, 46.30140848457813, 70.13727486133575, 71.3823464512825, 82.12554037570953, 65.91415107250214, 2.1514319675043225, 0.27924199879635125, 0.09015612202347256, 0.15493974380660802, 0.12243838820722885, 0.13383270765189081, 0.10609143530018628, 0.11484770919196308, 0.13615174102596939, 0.1347419572994113, 0.22211259871255606, 0.09937468712450936, 0.23025526490528136, 0.22726945637259632, 0.0828104407992214, 0.09181478497339413, 0.15722273848950863, 0.09977276771678589, 0.11176855332450941], [0.04082253799424507, 0.06783460572478361, 0.010036246712843422, 0.03471197975159157, 0.0720882548193913, 0.029006777003814932, 0.08669663031469099, 0.032110570318764076, 0.0968869858479593, 0.08498258088366129, 0.12351831697742455, 0.041397034510737285, 0.08137218828778714, 0.09744164475705475, 0.18128960800822824, 0.4472326172981411, 22.744333148002625, 87.1415676176548, 73.01209419965744, 69.81424659490585, 45.36552630364895, 33.50040078163147, 52.30394259095192, 59.02889393270016, 39.01051551103592, 19.280598610639572, 0.17572792363353074, 0.04342274885857478, 0.23517893976531923, 0.754731057677418, 0.577668099431321, 1.6461696359328926, 3.608652586117387, 1.0232371184974909, 10.4544398188591, 90.9009262919426, 79.67778012156487, 82.00535282492638, 70.99744990468025, 75.40216594934464, 71.71542137861252, 74.25687700510025, 69.43437337875366, 73.58048290014267, 69.63065564632416, 74.78403031826019, 70.4764598608017, 73.91001641750336, 71.28684237599373, 68.36674466729164, 64.12403672933578, 57.74580918252468, 51.95759117603302, 54.03404675424099, 54.19593706727028, 55.1010636985302, 58.76937925815582, 67.76022121310234, 66.10243856906891, 64.41006258130074, 59.541209042072296, 56.20252199470997, 50.907829105854034, 51.68990693986416, 51.529677137732506, 50.642831325531006, 48.637686520814896, 50.09841933846474, 49.65661324560642, 52.430122420191765, 52.96368598937988, 55.417571514844894, 54.7468277066946, 53.485625982284546, 52.093236297369, 50.616092160344124, 49.49136771261692, 51.45999267697334, 52.43569292128086, 55.68847417831421, 56.018007695674896, 56.314065009355545, 55.53686611354351, 49.980629459023476, 53.18343199789524, 56.37407898902893, 66.75275087356567, 57.3702335357666, 46.3602939248085, 67.7594992518425, 54.19280223548412, 56.014105305075645, 60.50092734396458, 64.0914648771286, 63.67319472134113, 63.5902451723814, 58.01426097750664, 60.554040893912315, 59.54741030931473, 60.54078720510006, 63.11755433678627, 65.05458399653435, 63.891504406929016, 63.513610884547234, 60.04929877817631, 55.18873639404774, 47.44950547814369, 46.9988876581192, 48.08198533952236, 48.72352011501789, 47.81745493412018, 48.2779598236084, 48.537732884287834, 49.97295767068863, 49.68084454536438, 49.99914966523647, 51.14015243947506, 51.191179901361465, 49.08986605703831, 51.02281853556633, 49.601846784353256, 51.53194181621075, 50.98468378186226, 52.78243571519852, 63.415652140975, 72.24164754152298, 70.40081351995468, 69.99064832925797, 64.24078166484833, 57.80274532735348, 53.190381824970245, 52.764983251690865, 52.86946624517441, 54.63974565267563, 50.953354462981224, 58.176972046494484, 57.93924540281296, 75.13453871011734, 69.13118004798889, 85.4989841580391, 10.489225052297115, 0.874739068094641, 1.1177540780045092, 1.1046023899689317, 0.198086992604658, 0.07748102638288401, 4.871166665107012, 62.644088342785835, 34.261754527688026, 41.114622205495834, 35.85945099592209, 16.385875940322876, 13.647815063595772, 30.032374374568462, 58.33917014300823, 56.88603311777115, 63.97417277097702, 19.23296056687832, 0.26655228284653276, 0.05376781620725524, 0.08949529146775603, 0.04697553966252599, 0.02119893630151637, 0.06068228365620598, 0.04054482633364387, 0.05195580699364655, 0.028338821830402594, 0.03868459978548344, 0.12178014032542706, 0.05978499371849466, 0.0897157315921504, 0.010455467381689232, 0.07800605875672773, 0.07623463388881646, 0.017920300415426027, 0.024775071360636503, 0.0673618279688526, 0.00735291298951779, 0.04898037368548103, 0.09786170034203678, 0.10066863644169644, 0.048225598366116174, 0.04026682523544878, 0.12067963922163472, 0.0592702623544028, 0.03348492020450067, 0.0976999121485278, 0.03024458470463287, 0.1281671819742769, 0.16770520334830508, 0.24423168681096286, 0.3797121701063588, 31.93786382675171, 102.1050962805748, 81.6082513332367, 80.76756924390793, 50.921276584267616, 42.28088982403278, 40.90686075389385, 40.16443379223347, 42.54985459148884, 23.952189534902573, 0.08684825108502991, 0.07039569056360051, 1.5462510287761688, 1.9312916113995016, 2.2683604806661606, 4.1204893961548805, 3.3565639005973935, 1.2136083282530308, 16.50022130459547, 95.35991862416267, 84.2125403881073, 87.00732842087746, 74.71207737922668, 79.24258187413216, 74.5665679872036, 77.12898328900337, 74.96710449457169, 78.09584900736809, 73.97234827280045, 77.0767816901207, 75.67724078893661, 77.87248939275742, 74.94205623865128, 71.79381117224693, 65.0267618894577, 60.536349043250084, 55.76719455420971, 56.44784063100815, 57.311591282486916, 58.00160005688667, 61.37460306286812, 70.52315935492516, 68.38594883680344, 67.14694172143936, 62.53114700317383, 59.46431256830692, 52.02018901705742, 55.118614956736565, 54.174563214182854, 53.594007566571236, 50.96588999032974, 51.829131469130516, 52.55237706005573, 54.30473282933235, 55.36304444074631, 57.42428943514824, 56.10192999243736, 56.95374548435211, 54.63465012609959, 52.210281416773796, 50.11354632675648, 52.74804376065731, 56.14317297935486, 59.02023419737816, 59.12611931562424, 59.11762677133083, 57.98654526472092, 53.79659369587898, 55.726244151592255, 58.065554425120354, 69.07370433211327, 61.39858737587929, 50.49994379281998, 72.11585149168968, 55.997572392225266, 60.0470606982708, 61.389247477054596, 68.98351237177849, 64.33158919215202, 66.9199950993061, 60.398701429367065, 61.54220446944237, 61.06222562491894, 63.203927502036095, 63.23656775057316, 68.35871949791908, 65.85437268018723, 65.74552372097969, 61.430475264787674, 56.82903237640858, 51.062997579574585, 51.5714330971241, 50.669361501932144, 50.48271931707859, 50.511981546878815, 50.40146827697754, 50.813571363687515, 53.949672281742096, 52.20246143639088, 52.7407481521368, 53.43033894896507, 53.180426359176636, 51.628000661730766, 54.06916067004204, 52.17178948223591, 53.27025353908539, 54.04303327202797, 55.46044461429119, 66.92824825644493, 73.84461432695389, 72.39123791456223, 72.45486170053482, 67.6015417277813, 60.23308351635933, 55.14582149684429, 54.923400431871414, 54.89495895802975, 59.20671299099922, 52.581114917993546, 59.22772966325283, 58.37515041232109, 79.37833338975906, 70.79251930117607, 91.11004427075386, 14.923971835523844, 0.6552865344565362, 1.0829086415469646, 0.7814069918822497, 0.5483884736895561, 0.030552334792446345, 3.8204280473291874, 66.96679338812828, 44.53663118183613, 34.99245151877403, 26.749802716076374, 19.00486070662737, 22.07915224134922, 37.04354725778103, 66.85226753354073, 61.23519614338875, 72.41275995969772, 35.07982783019543, 0.4431296687107533, 0.08646593370940536, 0.12228411054820754, 0.01800302019546507, 0.07301846271730028, 0.015362303838628577, 0.012500003522291081, 0.059522844894672744, 0.0820965095772408, 0.07315552997170016, 0.1321292412467301, 0.06557430591783486, 0.03644402626377996, 0.047027579057612456, 0.014683752651762916, 0.055392882131855004, 0.08450290857581422, 0.04540669142443221, 0.17377704003592953, 0.11294508003629744, 0.10795468610012904, 0.15705590369179845, 0.21047719259513542, 0.11072646666434593, 0.17581852502189577, 0.2536441676784307, 0.2607779880054295, 0.20164563524303958, 0.176999430404976, 0.17833698831964284, 0.18535065493779257, 0.3191376314498484, 0.3589312039548531, 0.694277489092201, 37.521979585289955, 112.94830083847046, 94.04284849762917, 92.58026137948036, 64.78221461176872, 48.566649332642555, 75.87836399674416, 84.82483193278313, 57.76793919503689, 33.313055634498596, 0.5887459893710911, 0.24769595795078203, 1.9271237100474536, 4.220801638439298, 5.687858741730452, 5.367816165089607, 14.322487860918045, 8.033843357115984, 15.805931109935045, 101.73781558871269, 83.10773447155952, 91.36753365397453, 76.26268297433853, 85.15666052699089, 78.52464839816093, 81.24785587191582, 78.423862606287, 81.73820436000824, 77.50178128480911, 81.95027098059654, 79.51566562056541, 80.11852607131004, 77.85716861486435, 75.35135507583618, 69.25894439220428, 64.86217752099037, 59.2147571593523, 61.178305596113205, 60.72348140180111, 61.45388200879097, 65.04316940903664, 74.86836299300194, 71.7221850156784, 71.91783651709557, 64.1695886850357, 63.711253479123116, 55.185202583670616, 57.95650787651539, 57.060527354478836, 57.46472306549549, 53.137739449739456, 55.87519235908985, 55.19787110388279, 57.26879417896271, 58.66007812321186, 60.77611617743969, 60.95538675785065, 61.521183997392654, 58.38751494884491, 57.33692452311516, 53.60808581113815, 56.29117123782635, 59.82910439372063, 64.05940219759941, 61.94353513419628, 63.525549843907356, 61.17098718881607, 55.95848768949509, 58.85510265827179, 61.97728872299194, 74.21917542815208, 63.35326708853245, 53.16625311970711, 71.91772252321243, 60.23675411939621, 62.106363996863365, 65.87756663560867, 70.11912703514099, 69.62034299969673, 70.73643431067467, 60.84595263004303, 63.528798669576645, 62.23713777959347, 65.34192457795143, 64.64727625250816, 70.73990732431412, 68.63524585962296, 70.42456984519958, 65.5168291926384, 60.008074790239334, 54.11811724305153, 54.18631598353386, 54.56727594137192, 55.47081045806408, 53.5270931571722, 53.42646695673466, 53.58350493013859, 55.443185940384865, 55.491002574563026, 54.4099909812212, 56.94341003894806, 56.9256915897131, 55.64251184463501, 57.17987135052681, 55.82085907459259, 57.15237222611904, 57.718671038746834, 57.55706571042538, 69.7860749065876, 77.66116753220558, 76.0915857553482, 77.24627539515495, 72.93964728713036, 64.5199602842331, 58.74306946992874, 58.06518204510212, 59.054196774959564, 61.91013492643833, 55.23670122027397, 62.3027640581131, 62.696259543299675, 83.47148135304451, 75.35038992762566, 95.733902156353, 13.06579364463687, 1.9401218625716865, 4.050374608486891, 2.320784842595458, 0.7302959938533604, 0.1221480748790782, 7.843052269890904, 78.27735006809235, 55.758333429694176, 58.622805923223495, 49.32619817554951, 23.549509942531586, 22.63941317796707, 42.5573705881834, 76.00483641028404, 72.90288805961609, 86.04426249861717, 35.20040675997734, 0.4750346270157024, 0.2169514514389448, 0.18145043140975758, 0.09446817071875557, 0.11147417302709073, 0.17179650021716952, 0.14940363384084776, 0.17921435530297458, 0.1396279310574755, 0.2226230627275072, 0.25885190698318183, 0.17762624833267182, 0.1619869703426957, 0.16937046399107203, 0.21714464732212946, 0.1716957165626809, 0.17229875607881695, 0.1595165388425812], [0.04069132628501393, 0.05178817067644559, 0.007895803755673114, 0.02796208169456804, 0.04728205036371946, 0.019179196242475882, 0.028365401849441696, 0.013260794876259752, 0.04165712758549489, 0.08323135727550834, 0.04466369027795736, 0.015578976635879371, 0.07029369720839895, 0.052952047481085174, 0.05710497229301836, 0.08603026333730668, 52.55768917500973, 72.22611397504807, 73.41623291373253, 59.41954717040062, 46.7268792539835, 27.992742620408535, 53.33486907184124, 46.912237107753754, 38.97920519113541, 7.288862457498908, 0.06338460661936551, 0.31756015203427523, 1.9194257981143892, 1.9956139661371708, 2.21491611097008, 5.391937745735049, 2.2817868227139115, 2.1843811869621277, 52.94735066592693, 93.76142799854279, 79.82757568359375, 80.59307500720024, 70.7645832002163, 69.80784013867378, 69.34553414583206, 72.65475377440453, 69.63979795575142, 67.7877089381218, 65.36330223083496, 65.78818023204803, 66.25780463218689, 68.56238856911659, 63.34467954933643, 62.07902446389198, 57.82936289906502, 55.742872059345245, 52.539370357990265, 53.19603592157364, 54.02417488396168, 55.585172921419144, 54.68093924224377, 59.021336138248444, 63.20426948368549, 63.860710859298706, 60.2762757986784, 53.47890794277191, 50.739824920892715, 50.94352439045906, 51.30292810499668, 49.26875285804272, 48.46806742250919, 49.40725162625313, 53.21351878345013, 55.47414667904377, 57.373691350221634, 56.990782096982, 55.60259498655796, 55.22985398769379, 51.24653913080692, 49.97928433120251, 49.19680371880531, 48.765918239951134, 53.57308588922024, 57.33238376677036, 59.41698610782623, 58.03794510662556, 55.00309735536575, 52.904587760567665, 52.476308941841125, 53.10807444155216, 66.61323755979538, 57.538739293813705, 48.03087428212166, 65.98586842417717, 49.111866876482964, 61.685836762189865, 63.501272946596146, 62.80738838016987, 56.772829592227936, 61.14375025033951, 58.68762664496899, 60.43365195393562, 61.71157658100128, 62.74871952831745, 62.03318752348423, 64.70980569720268, 61.733805388212204, 60.955128371715546, 55.61046056449413, 52.960269972682, 47.34672099351883, 47.834611013531685, 47.64077581465244, 47.32364483177662, 45.67425213754177, 48.25020611286163, 49.61978182196617, 50.39138741791248, 50.515344366431236, 49.69885177910328, 50.56734077632427, 49.665652960538864, 49.613576754927635, 50.72086773812771, 48.62804263830185, 51.88373453915119, 51.85978442430496, 52.07323417067528, 55.16827829182148, 62.25175939500332, 62.52827435731888, 60.50647884607315, 51.81536100804806, 51.81394748389721, 48.49892936646938, 59.803763553500175, 61.44047632813454, 64.82915729284286, 61.88964642584324, 63.65590184926987, 55.80816775560379, 62.85344950854778, 68.48149850964546, 78.66879746317863, 47.99998573958874, 0.1748339770711027, 0.9561530244536698, 1.587335136719048, 0.17842684756033123, 0.13048732856987044, 0.009700228220026474, 32.338141947984695, 56.62124812602997, 32.345969527959824, 74.6872267127037, 44.02856044471264, 27.291349656879902, 40.234756618738174, 49.05824035406113, 47.21002332866192, 56.71385295689106, 59.20183405280113, 8.412971813231707, 0.2683025342412293, 0.06033508099790197, 0.060103289724793285, 0.010251104959024815, 0.006093441998018534, 0.01220514453962096, 0.023433431633748114, 0.04292750258173328, 0.02798133671603864, 0.06942997089936398, 0.05690913436410483, 0.047130169841693714, 0.018832411042239983, 0.05378134184866212, 0.005656265529978555, 0.08550218073651195, 0.03102825183304958, 0.05718112406611908, 0.03171624870446976, 0.03205954024451785, 0.020860468721366487, 0.06067325171898119, 0.01236196034369641, 0.06806530975154601, 0.040276725485455245, 0.055834367231000215, 0.028714875479636248, 0.02421110406430671, 0.01629611950193066, 0.02999385011207778, 0.04998360891477205, 0.07153826401918195, 0.27425034320913255, 67.7667036652565, 83.36187243461609, 82.06545799970627, 69.26244780421257, 66.18788078427315, 41.86939850449562, 43.937000557780266, 43.32855440676212, 49.450618699193, 9.25740335136652, 0.15574363816995174, 1.4526606258004904, 2.876655589789152, 2.9466029489412904, 4.815912405028939, 3.691129060462117, 2.206658679060638, 3.7623495887964964, 58.81840042769909, 95.80672904849052, 84.63782876729965, 84.0373469889164, 73.80705714225769, 73.80077987909317, 75.50999656319618, 76.34253188967705, 73.6200387775898, 73.28963130712509, 68.18281173706055, 70.40739476680756, 69.14834752678871, 71.25872388482094, 66.30261942744255, 65.54177105426788, 61.38231664896011, 59.15014162659645, 56.38306550681591, 56.2036619335413, 57.25115552544594, 56.50668427348137, 58.74874256551266, 62.71607547998428, 64.43187341094017, 64.8613415658474, 62.86751635372639, 55.12186758220196, 54.38754938542843, 53.22272188961506, 52.20333158969879, 51.35587066411972, 51.398948952555656, 51.40443965792656, 54.88752655684948, 58.56871962547302, 58.870689421892166, 61.47549904882908, 58.166439011693, 57.07740604877472, 54.16407957673073, 50.402433425188065, 51.17492817342281, 51.61912053823471, 54.54019099473953, 60.32392144203186, 62.47106462717056, 60.769208148121834, 58.30882117152214, 56.34770840406418, 53.53865973651409, 56.79913178086281, 69.92399990558624, 60.948824509978294, 48.55634808540344, 69.54960599541664, 53.169646337628365, 65.06068646907806, 64.89845797419548, 65.982296615839, 58.21059264242649, 61.20629109442234, 59.12834219634533, 63.526184409856796, 64.21636417508125, 65.90379282832146, 65.26996403932571, 67.59227022528648, 64.36225354671478, 62.45032534003258, 56.13744668662548, 54.92975749075413, 49.12499517202377, 50.2156088501215, 50.12639343738556, 48.87116119265556, 47.685583010315895, 51.09835848212242, 50.58171920478344, 52.039856761693954, 52.114503756165504, 51.8229416012764, 51.775295957922935, 52.276086285710335, 51.64405480027199, 53.18597786128521, 51.71500079333782, 54.05807286500931, 54.01933014392853, 56.539541110396385, 56.83918543159962, 64.704759567976, 62.946388721466064, 62.166545167565346, 55.53965516388416, 54.75894145667553, 51.665721237659454, 63.32727648317814, 65.02587273716927, 67.42568716406822, 67.19291925430298, 67.64729887247086, 61.63048893213272, 64.19003918766975, 72.41813287138939, 81.50273099541664, 53.630451411008835, 0.34522281610406935, 0.7250773895066231, 3.247047127224505, 0.6233675347175449, 0.17480262875324115, 0.03217197190679144, 30.221286937594414, 67.1648159623146, 34.129745811223984, 41.10804095864296, 28.492185920476913, 32.84903213381767, 56.66025683283806, 54.588908180594444, 53.87736216187477, 63.61275136470795, 73.40457513928413, 18.17728791385889, 0.4394636076176539, 0.17589035007404163, 0.16715257050236687, 0.05109556506795343, 0.05222115076321643, 0.04192211512417998, 0.03347761376062408, 0.07367798709310591, 0.12441900966223329, 0.01818322663893923, 0.06394555151928216, 0.032100747994263656, 0.00928610981645761, 0.076370535971364, 0.05168704934476409, 0.07987566976225935, 0.034671258108573966, 0.11333988775731996, 0.17846958042355254, 0.16586932295467705, 0.21075839234981686, 0.2494878735160455, 0.2136649691965431, 0.16870845342054963, 0.166262527636718, 0.14512694848235697, 0.18898545677075163, 0.10215010421234183, 0.09553056996082887, 0.25387868634425104, 0.182161572156474, 0.2378434725687839, 0.4867657256545499, 82.85155221819878, 96.20520606637001, 95.58732122182846, 76.9260285794735, 67.6472532749176, 39.05585467815399, 74.32034879922867, 66.34480476379395, 62.65071518719196, 13.560729436576366, 0.2952673123218119, 1.0671881726011634, 5.908010853454471, 5.393196428194642, 7.071947772055864, 15.13307936489582, 9.644437283277512, 5.710735889151692, 61.96316868066788, 97.58643195033073, 87.41101875901222, 87.75008976459503, 77.88538590073586, 76.58714756369591, 79.1674143075943, 81.18983298540115, 76.71100571751595, 75.19002333283424, 72.56922796368599, 74.0401442348957, 72.68372341990471, 75.00322535634041, 71.11715868115425, 69.32009071111679, 64.90694671869278, 62.646087035536766, 59.938204139471054, 60.164709985256195, 60.59464551508427, 61.15218199789524, 61.46080143749714, 66.53653487563133, 69.67474088072777, 70.00720024108887, 66.33346617221832, 58.0202304571867, 56.96088910102844, 56.42126105725765, 54.852450639009476, 55.76325796544552, 54.04413141310215, 53.62671621143818, 58.50415728986263, 62.600698471069336, 62.659754902124405, 64.92318704724312, 62.739375829696655, 60.20655333995819, 55.97861520946026, 56.11189305782318, 54.05156001448631, 54.41981725394726, 58.52813400328159, 64.32319164276123, 65.52655667066574, 63.650874719023705, 61.73392318189144, 57.98691004514694, 57.656331583857536, 59.93854612112045, 73.03090319037437, 65.37883579730988, 53.725077733397484, 73.15143272280693, 56.29718251526356, 68.37942078709602, 68.81353989243507, 66.23451948165894, 61.9540111720562, 63.58918122947216, 61.218154057860374, 66.88267350196838, 67.92469158768654, 70.6207001209259, 68.34439426660538, 71.80934473872185, 68.78819525241852, 67.54170253872871, 60.76467879116535, 59.15954232215881, 52.68559791147709, 52.29333356022835, 55.581965893507004, 51.64279706776142, 51.4307152479887, 54.49519760906696, 54.175448566675186, 55.25475785136223, 55.9511274844408, 54.2221100628376, 56.47666968405247, 56.2401057779789, 55.327892526984215, 56.250532418489456, 53.59573267400265, 57.620339915156364, 56.590169593691826, 58.85293297469616, 61.343858912587166, 68.21429684758186, 69.53673988580704, 66.31293967366219, 57.19661325216293, 58.034760877490044, 52.584451138973236, 67.25681662559509, 67.88053795695305, 70.80391108989716, 71.03442952036858, 70.33313915133476, 64.03961285948753, 67.91004717350006, 76.64964661002159, 83.83674815297127, 56.49215765297413, 0.6550248828716576, 4.13184461183846, 5.422046380117536, 0.5794258613605052, 0.4205705167260021, 0.1917142595630139, 42.25181758403778, 72.22178220748901, 49.38046686351299, 101.47714957594872, 60.703695863485336, 37.469337210059166, 57.53224924206734, 64.3433153629303, 67.91039675474167, 69.0993757545948, 88.63237202167511, 17.20769204199314, 0.56203514453955, 0.4817279678536579, 0.32050048175733536, 0.11946694023208693, 0.1533228563494049, 0.21706158615415916, 0.0880066397076007, 0.16420477477367967, 0.15837627346627414, 0.2422217876301147, 0.214912653027568, 0.08664060558658093, 0.06823230782174505, 0.17666819505393505, 0.14466016727965325, 0.1894563643145375, 0.13519713131245226], [0.04702072161308024, 0.05016997332859319, 0.030553663236787543, 0.04285322473151609, 0.004413139413372846, 0.038336944417096674, 0.03316890259156935, 0.023456397393601947, 0.028836494930146728, 0.03641434777819086, 0.043937190785072744, 0.03903077085851692, 0.012604716848727548, 0.14255831600166857, 0.13381556404056028, 5.072179203853011, 71.80779442191124, 69.22533139586449, 65.14215409755707, 42.804106548428535, 14.876634925603867, 27.908860221505165, 51.70010559260845, 39.0659811347723, 26.525381058454514, 1.4282877836376429, 0.08910699980333447, 0.8777615090366453, 1.9115652074106038, 0.6219634506851435, 1.01524697849527, 2.2007887065410614, 0.7471729069948196, 12.928545959293842, 93.38028565049171, 79.10106226801872, 83.53268846869469, 69.84665125608444, 67.95140415430069, 66.81894332170486, 71.51138752698898, 67.06202387809753, 69.06456962227821, 67.4402403831482, 71.63023754954338, 63.549705147743225, 62.25494362413883, 59.03349928557873, 59.27412897348404, 57.93927580118179, 57.4331733584404, 53.27684238553047, 54.064167737960815, 52.82453365623951, 54.43593978881836, 50.95489718019962, 56.31989389657974, 53.21642182767391, 59.79363709688187, 56.985295191407204, 57.05791309475899, 53.21277402341366, 50.96359871327877, 50.4020344465971, 50.1404070854187, 46.79943636059761, 51.20584711432457, 53.532032892107964, 59.56568352878094, 58.119382336735725, 58.292352855205536, 54.40844066441059, 56.428929045796394, 50.52476406097412, 50.83743788301945, 46.97611168026924, 49.931372702121735, 48.8083353638649, 53.42117004096508, 54.59975279867649, 60.0866773724556, 58.3225080370903, 62.96383358538151, 57.03492812812328, 53.16434562206268, 52.849414721131325, 66.55788213014603, 55.495254546403885, 52.27264367043972, 64.13266226649284, 53.832121789455414, 60.44324643909931, 63.817575573921204, 56.751056760549545, 57.19852454960346, 62.490454986691475, 62.44508542120457, 61.854794695973396, 57.94842191040516, 57.59714975953102, 55.79372093081474, 53.47679525613785, 53.03169094026089, 50.498560667037964, 48.30103978514671, 48.99577550590038, 47.1317171305418, 43.90060991048813, 46.1891321092844, 45.58246046304703, 48.43745246529579, 46.67441546916962, 49.70508724451065, 47.56204403936863, 48.76838430762291, 49.76432226598263, 48.031121268868446, 49.572493359446526, 50.20013228058815, 50.035148933529854, 50.12298122048378, 49.54272575676441, 49.308582320809364, 50.53063474595547, 50.664672553539276, 50.41311465203762, 50.315566286444664, 49.80026073753834, 50.65223962068558, 52.78060421347618, 62.560694217681885, 66.12966790795326, 69.34433341026306, 67.49035969376564, 68.3464765548706, 68.7067124247551, 68.83767619729042, 68.14835518598557, 68.4646426141262, 73.87666180729866, 69.46151912212372, 3.397646346129477, 0.8044616610277444, 0.3225475922226906, 0.425535217509605, 0.13353458693018183, 0.16928741766605526, 3.1046573678031564, 65.24325907230377, 38.36695544421673, 40.583733692765236, 51.536957547068596, 19.63271241635084, 13.195463586598635, 29.548297449946404, 49.516617357730865, 53.57152797281742, 60.19190892577171, 41.27731427550316, 2.2270854329690337, 0.3185700665926561, 0.04929251728754025, 0.0864187182742171, 0.028056885494152084, 0.020938292182108853, 0.071716193924658, 0.029522916593123227, 0.04200381074042525, 0.04039945073600393, 0.039213209311128594, 0.017088664571929257, 0.015553834527963772, 0.016151426680153236, 0.06189172090671491, 0.06329977171844803, 0.05283676968247164, 0.06154712689749431, 0.05529660702450201, 0.07208587252534926, 0.028944499681529123, 0.07000690908171237, 0.07261325750732794, 0.013279141694511054, 0.04285403367248364, 0.05768380666268058, 0.08953074386226945, 0.051341575890546665, 0.040901005268096924, 0.04282399153453298, 0.12047553376760334, 0.21456786605995148, 8.669143617153168, 90.97845733165741, 75.17556890845299, 75.56426525115967, 52.18552954494953, 30.998639725148678, 24.77309748530388, 34.11743827164173, 43.60630050301552, 40.11226259171963, 1.9019502983428538, 0.11890685622347519, 0.7255197688937187, 2.5090597523376346, 3.6638662358745933, 5.573607422411442, 2.088764305226505, 1.0729144653305411, 16.8020087108016, 96.4519040286541, 82.6574282348156, 84.7195015847683, 74.79033797979355, 71.44806772470474, 70.22526293992996, 74.13167372345924, 69.99339178204536, 73.8838966190815, 71.85317918658257, 72.94365227222443, 67.89648190140724, 65.46261370182037, 63.42323273420334, 62.88642033934593, 59.73671995103359, 59.57546420395374, 55.3178458660841, 56.62054896354675, 55.91861642897129, 55.852154195308685, 55.41047729551792, 57.40825429558754, 55.937923192977905, 61.36201433837414, 61.96346126496792, 59.656749442219734, 56.37025639414787, 52.22079545259476, 52.42606423795223, 53.66440638899803, 49.33535948395729, 53.4488819539547, 56.412183344364166, 61.914348900318146, 61.951427310705185, 61.776374503970146, 57.68911622464657, 57.36619435250759, 54.45171654224396, 53.57884258031845, 50.593145191669464, 51.9401691108942, 50.36337912082672, 56.12809918820858, 56.932713612914085, 61.68300971388817, 61.32326401770115, 65.45588806271553, 58.61100755631924, 55.431068390607834, 55.59346787631512, 69.45950523018837, 60.7943020015955, 54.98320922255516, 65.9014293551445, 53.935548439621925, 62.72108741104603, 66.38393506407738, 56.16585776209831, 58.28633397817612, 64.18693855404854, 66.61593541502953, 64.591054469347, 60.5892688035965, 59.440818428993225, 57.15399093925953, 54.897736608982086, 56.16122581064701, 52.06902779638767, 50.179788172245026, 50.779570788145065, 49.81215409934521, 47.45962053537369, 49.12906475365162, 50.086404383182526, 50.48424683511257, 48.10798354446888, 51.84498801827431, 49.94662128388882, 51.913270354270935, 52.06591576337814, 51.448992267251015, 51.558882370591164, 54.41520810127258, 52.946735098958015, 54.12498727440834, 51.561352238059044, 53.42937760055065, 51.719693541526794, 53.280566185712814, 53.92897479236126, 53.6160159856081, 52.24086977541447, 52.582194060087204, 56.22994512319565, 65.27678087353706, 69.64751914143562, 73.13063263893127, 70.82934692502022, 73.2113479077816, 70.52478566765785, 71.28206223249435, 70.48148319125175, 73.47953751683235, 73.65027755498886, 77.11111664772034, 3.8193161319941282, 0.43790551309939474, 2.467988943681121, 2.0525740971788764, 0.28557759476825595, 0.12365582209895365, 2.2368148108944297, 67.8456862270832, 50.92164136469364, 42.14037336409092, 36.75127074122429, 22.740012779831886, 26.391641534864902, 38.36648806929588, 59.45632919669151, 58.60850349068642, 66.83222740888596, 59.73820947110653, 4.500874634832144, 0.43449314776808023, 0.05248311776085757, 0.07536997989518568, 0.032188811237574555, 0.11315299270791002, 0.021647494068020023, 0.024197546881623566, 0.019873403034580406, 0.00981457369562122, 0.013830240150127793, 0.08716511103557423, 0.04268427852366585, 0.08293970066006295, 0.028782763438357506, 0.030832655102130957, 0.10055772247142158, 0.16986612958135083, 0.15310231974581257, 0.22637175454292446, 0.1201648113783449, 0.16249774605967104, 0.20292364322813228, 0.08630796015495434, 0.09753623147844337, 0.1332322953385301, 0.27439455734565854, 0.15829244046472013, 0.16040558723034337, 0.30990320665296167, 0.42216123605612665, 0.528954416513443, 11.90554490312934, 106.37892454862595, 87.58952558040619, 84.94812771677971, 60.250520780682564, 26.47447519004345, 37.986926436424255, 73.02527949213982, 57.4433758109808, 46.64357252418995, 3.1143295112997293, 0.239535836444702, 2.479737913236022, 4.120299406349659, 4.276918452233076, 8.4761225245893, 13.476188722997904, 4.284179387614131, 17.20787063241005, 102.00925022363663, 86.79567977786064, 90.77788889408112, 77.79808938503265, 74.39222574234009, 72.94304430484772, 78.6290591955185, 72.40392163395882, 76.71016216278076, 75.55020600557327, 76.89716532826424, 71.7405304312706, 68.01218569278717, 66.50813519954681, 66.69009983539581, 64.78405371308327, 61.951016932725906, 59.01673458516598, 59.835301861166954, 57.67546355724335, 58.707947954535484, 59.64780852198601, 61.12603560090065, 57.58760467171669, 64.8561130464077, 65.5851723253727, 62.416176572442055, 59.564497992396355, 55.29113329946995, 56.17229461669922, 57.014914602041245, 52.085005939006805, 56.54387667775154, 58.80418919026852, 65.70127129554749, 63.01111824810505, 64.13915231823921, 60.20720690488815, 63.98801922798157, 57.37738095223904, 56.26103885471821, 52.08017259836197, 55.370245054364204, 53.74813489615917, 59.54534322023392, 59.497002214193344, 64.7478948533535, 63.59743818640709, 68.98764654994011, 62.21006043255329, 57.06110492348671, 59.38346430659294, 75.27917414903641, 62.677488550543785, 59.88460421562195, 69.62172612547874, 59.00699570775032, 65.84233492612839, 70.8479431271553, 57.28940047323704, 58.8958440721035, 67.18550205230713, 70.79667627811432, 67.17127561569214, 63.00481058657169, 62.92382933199406, 59.95383270084858, 57.38683484494686, 59.492218270897865, 54.62729752063751, 54.79916229844093, 53.57839800417423, 53.03713984787464, 49.14614863693714, 52.90065877139568, 51.07516832649708, 55.722033977508545, 51.264033392071724, 55.81113159656525, 52.28327929973602, 52.616057842969894, 54.200177639722824, 54.678279384970665, 54.770120456814766, 56.12551532685757, 55.98480887711048, 55.44090986251831, 55.39000779390335, 55.718963742256165, 56.83461047708988, 57.12572045624256, 57.381925508379936, 57.847256138920784, 55.97992993891239, 56.14704117178917, 58.869401291012764, 69.36140209436417, 72.50467702746391, 76.36741295456886, 72.50433504581451, 74.98242527246475, 73.5704818367958, 73.98212134838104, 74.74085703492165, 75.23638844490051, 79.00450184941292, 79.42477449774742, 4.404765916988254, 2.146662985906005, 3.881774330511689, 2.4362979317083955, 0.40540155256167054, 0.259847097331658, 4.190147258341312, 80.50607487559319, 55.797718316316605, 63.02873410284519, 73.0552750825882, 28.36358182132244, 23.08724954724312, 45.28867542743683, 67.56665959954262, 70.192189514637, 77.34239503741264, 70.62700018286705, 4.8608611430972815, 0.6488258123863488, 0.19853256322676316, 0.21458880946738645, 0.19949269451899454, 0.15329835063312203, 0.13026419444940984, 0.1743706691195257, 0.1417069835588336, 0.15445152937900275, 0.09909364322084002, 0.1554036306333728, 0.14525027858326212, 0.16625813412247226, 0.20646114950068295, 0.15336615324486047, 0.14602365583414212], [0.131770680018235, 0.022009255808370654, 0.04450772423297167, 0.0447477607667679, 0.10817670699907467, 0.04406455816933885, 0.07680631024413742, 0.01295654123168788, 0.025326188369945157, 0.04239746442181058, 0.029732473121839575, 0.07129417164833285, 0.05302480021782685, 0.12751254835166037, 0.053634982905350626, 19.09944713115692, 72.16197341680527, 63.495493456721306, 71.78987458348274, 36.14145666360855, 29.620877355337143, 58.98424632847309, 52.88594216108322, 34.557253271341324, 25.66606856882572, 0.6383919285144657, 0.07045579710393213, 2.161747463978827, 0.7961370202247053, 3.2782569900155067, 7.777617406100035, 0.7445427950005978, 0.5329086387064308, 55.594452023506165, 93.12338143587112, 78.2225114107132, 78.83597329258919, 67.55196198821068, 66.98630914092064, 65.93112856149673, 65.22646397352219, 67.15111389756203, 69.04864847660065, 65.88369950652122, 65.51213264465332, 63.0268570035696, 62.78187654912472, 60.622152239084244, 56.652372255921364, 54.60631884634495, 55.362561866641045, 50.97223185002804, 52.516457587480545, 51.23285986483097, 51.61103077232838, 53.133647069334984, 51.797737553715706, 51.984185948967934, 54.515822902321815, 54.637898951768875, 53.23839604854584, 50.81296719610691, 50.618717819452286, 49.93136890232563, 48.114333003759384, 48.58694784343243, 55.914736837148666, 59.29586000740528, 61.16131290793419, 60.67139379680157, 57.35921032726765, 54.61431361734867, 55.17877332866192, 49.94672007858753, 48.99986408650875, 46.225066781044006, 48.15627135336399, 47.69349418580532, 50.245995819568634, 53.7123142182827, 57.51295007765293, 58.94933760166168, 60.719901993870735, 58.587467819452286, 56.78173251450062, 50.7441832870245, 66.98605835437775, 56.955333799123764, 52.26699337363243, 64.00077134370804, 52.21927933394909, 65.41682615876198, 61.05994574725628, 59.45527285337448, 61.499669551849365, 60.646721720695496, 57.31381416320801, 53.408748507499695, 49.30848352611065, 51.24327890574932, 49.47702348232269, 48.63758772611618, 50.20509101450443, 47.42866359651089, 46.66555814445019, 45.234699323773384, 48.217201083898544, 46.04543522000313, 45.76214902102947, 45.82489125430584, 46.18154011666775, 45.860901921987534, 46.40517331659794, 47.72611923515797, 47.93622136116028, 47.95573711395264, 49.76863123476505, 48.8029358536005, 49.311720952391624, 49.352169781923294, 50.7386127859354, 49.820813834667206, 49.603894874453545, 49.01924304664135, 51.085644364356995, 49.607675671577454, 49.31954853236675, 49.37189072370529, 54.12836529314518, 57.30636656284332, 65.06593778729439, 65.8185102045536, 68.62547278404236, 67.87450388073921, 69.53858658671379, 68.40724289417267, 70.13726726174355, 67.46885284781456, 75.48279002308846, 71.27347469329834, 78.35607424378395, 7.0071018766611814, 0.6323165888898075, 2.040713271126151, 1.501836518291384, 0.14753517316421494, 0.10753771784948185, 0.08533959102351218, 25.48921275883913, 74.60268124938011, 27.086253762245178, 44.071528539061546, 36.61244139075279, 19.027420096099377, 23.245647847652435, 27.114180363714695, 50.16170494258404, 54.904800429940224, 56.81849554181099, 18.9470050111413, 0.2853749884525314, 0.05874968657735735, 0.024949015933088958, 0.04772267828229815, 0.05152916855877265, 0.024002339778235182, 0.0407990935491398, 0.0815398023405578, 0.045726801981800236, 0.03667602162749972, 0.04821065522264689, 0.02499663212802261, 0.05496410631167237, 0.08194896319764666, 0.03951233193220105, 0.044575701249414124, 0.048511392014916055, 0.02924902884842595, 0.04118401586310938, 0.08280128269689158, 0.020943507624906488, 0.060162424051668495, 0.10711758062825538, 0.06402217084541917, 0.07214054654468782, 0.050972435346920975, 0.022133057173050474, 0.0673739991907496, 0.05928519065491855, 0.1265374108334072, 0.2137692112592049, 35.04700519144535, 85.36441817879677, 73.13224375247955, 79.2268431186676, 52.34890557825565, 39.61344815790653, 40.283557400107384, 48.204365372657776, 40.87916783988476, 29.224731512367725, 0.174805938731879, 0.38664115767460316, 3.107632608152926, 2.6738875452429056, 9.516397453844547, 8.825322836637497, 2.1097814524546266, 1.1039348132908344, 60.72055175900459, 96.45432829856873, 79.05867174267769, 81.99029043316841, 69.17894348502159, 71.05693191289902, 68.6644434928894, 70.47485634684563, 69.74355518817902, 71.85542866587639, 69.15004223585129, 69.40383061766624, 67.79100716114044, 65.61626985669136, 64.5026484131813, 61.368622183799744, 59.64696116745472, 59.067222476005554, 54.846317768096924, 56.17109768092632, 53.191548362374306, 53.86760048568249, 54.198197945952415, 52.85729169845581, 54.95713122189045, 55.89607983827591, 58.388814479112625, 57.228907719254494, 53.79867598414421, 53.39583680033684, 52.04670399427414, 51.96835979819298, 49.95580159127712, 58.43265652656555, 61.48592568933964, 65.32565385103226, 62.3734250664711, 62.40870997309685, 57.907292917370796, 57.9261589050293, 52.938424944877625, 52.05833896994591, 50.832068771123886, 50.61867602169514, 50.622669607400894, 51.9929064810276, 55.003458335995674, 59.07735653221607, 62.88316011428833, 62.44239516556263, 62.90457956492901, 58.03327515721321, 53.6879613250494, 69.06108140945435, 58.89596946537495, 56.92859083414078, 65.88134363293648, 53.968184888362885, 66.59825876355171, 65.27452379465103, 59.59689125418663, 64.90391448140144, 62.598502188920975, 59.908003360033035, 55.38146585226059, 51.31434269249439, 52.098373621702194, 52.032276168465614, 50.215836837887764, 51.43775247037411, 49.00921918451786, 49.52699460089207, 47.18494087457657, 50.50798796117306, 48.450763151049614, 49.23822149634361, 47.265853732824326, 49.91618871688843, 48.30783002078533, 48.87297749519348, 49.56815019249916, 50.51553435623646, 50.280991941690445, 51.74361705780029, 52.34437242150307, 52.816915065050125, 52.42599964141846, 53.68553705513477, 53.33438649773598, 51.911461651325226, 51.6390048712492, 55.151080414652824, 52.493852600455284, 51.63318358361721, 53.112201020121574, 58.97761948406696, 61.30579635500908, 69.83098849654198, 67.46935442090034, 70.60407221317291, 71.29551351070404, 74.78934243321419, 70.02235382795334, 73.84057894349098, 68.18161860108376, 79.19386088848114, 73.05136129260063, 79.43661466240883, 8.24342206120491, 1.128606533166021, 2.3940696101635695, 2.5341467186808586, 0.9753230551723391, 0.36354944051709026, 0.10210705964709632, 24.075097739696503, 80.35972952842712, 37.954673767089844, 41.00159727036953, 24.303879663348198, 24.787202328443527, 41.960548013448715, 39.23456288874149, 61.258998066186905, 61.371787413954735, 66.10445246100426, 37.90663294494152, 0.5382307281251997, 0.020901997449982446, 0.029186718129494693, 0.02772270752757322, 0.042964083040715195, 0.05548276734771207, 0.011613714068516856, 0.05521017279534135, 0.006116965296314447, 0.01846476963692112, 0.023101966216927394, 0.007970113147166558, 0.046682031388627365, 0.0213843730307417, 0.04060134830069728, 0.0355594715801999, 0.24465744209010154, 0.19844188762363046, 0.1459081331267953, 0.1686591748148203, 0.1971917992341332, 0.0963910308200866, 0.18041425966657698, 0.22751225740648806, 0.12240175579790957, 0.14149149355944246, 0.15003117907326669, 0.163914461445529, 0.16099019179819152, 0.18799730198225006, 0.40931273018941283, 47.526812329888344, 100.15472173690796, 84.93205457925797, 89.96507450938225, 54.24784988164902, 44.259907230734825, 84.7766961157322, 76.5497575700283, 50.59836991131306, 39.49686661362648, 1.4470094977878034, 0.29479266435373574, 5.792585397139192, 5.293429456651211, 10.016090590506792, 15.976995080709457, 5.339805968105793, 1.930558132007718, 63.521879240870476, 101.88286140561104, 84.30260315537453, 85.97488582134247, 73.4390240907669, 74.95977088809013, 75.1486587524414, 73.9507882297039, 74.5319290459156, 75.228401273489, 72.8763122856617, 73.92070144414902, 70.79776301980019, 70.7225726544857, 67.58210957050323, 65.32315358519554, 64.23945933580399, 61.86253108084202, 57.38089956343174, 57.78083950281143, 57.40046091377735, 56.01530224084854, 59.357716888189316, 54.856463223695755, 56.15604668855667, 59.778107330203056, 62.658812552690506, 60.509492084383965, 55.73774613440037, 55.8570521324873, 56.36481888592243, 54.910530522465706, 54.16281044483185, 62.78638690710068, 64.25803273916245, 69.14710879325867, 66.52588024735451, 65.84901496767998, 61.7299447953701, 61.6217266023159, 56.41287490725517, 55.09680412709713, 54.14492480456829, 53.224082216620445, 54.2214222997427, 55.21793022751808, 57.22255066037178, 62.9617702960968, 65.41000932455063, 64.95486214756966, 64.9977694451809, 61.807878613471985, 55.606489777565, 72.29444950819016, 63.708354234695435, 60.01462183892727, 69.68954488635063, 58.81032966077328, 71.52397245168686, 66.24287143349648, 61.60199426114559, 68.48353520035744, 66.99332356452942, 61.815466806292534, 59.07160364091396, 55.53952217102051, 56.00207135081291, 57.13656507432461, 53.14847007393837, 55.42249605059624, 51.35793395340443, 52.14823454618454, 49.87893171608448, 53.06042119860649, 51.90481960773468, 50.98409861326218, 50.81473030149937, 52.92536124587059, 51.589375734329224, 52.082167491316795, 52.320646494627, 53.23428466916084, 52.467090636491776, 54.36945855617523, 53.940925151109695, 55.912335366010666, 55.44126324355602, 57.46978059411049, 55.79830348491669, 54.44663241505623, 54.9077794700861, 57.31862090528011, 55.075327679514885, 54.772229343652725, 56.88451699912548, 61.42510235309601, 64.28713917732239, 71.28343015909195, 72.01359897851944, 73.34844455122948, 73.97397458553314, 76.58206343650818, 71.71293631196022, 75.85737392306328, 73.39512124657631, 82.41915062069893, 77.99008548259735, 83.32711949944496, 8.817342314869165, 2.3465075623244047, 6.070227473974228, 3.5142457019537687, 1.0362397832795978, 0.276998812914826, 0.29048785159830004, 34.05717350542545, 89.93164390325546, 43.64994876086712, 63.268311247229576, 50.07245533168316, 29.093575850129128, 36.610678285360336, 40.08220240473747, 70.00325605273247, 70.99950939416885, 77.89623811841011, 42.03924939036369, 0.5642150994390249, 0.18442742322804406, 0.12327881850069389, 0.13501955021638423, 0.14648959098849446, 0.16004134115064517, 0.12728760339086875, 0.27035840204916894, 0.08067733026109636, 0.09631002540118061, 0.12331715042819269, 0.06099661288317293, 0.18664205126697198, 0.1892172294901684, 0.12644483533222228, 0.18072097445838153], [0.057291477714898065, 0.024452717661915813, 0.017778321998775937, 0.019420123353484087, 0.05160443717613816, 0.0839247829571832, 0.11372308086720295, 0.036340255464892834, 0.03555676274118014, 0.032599920232314616, 0.05684538387868088, 0.026671822706703097, 0.024788029259070754, 0.03806847249506973, 0.05356858666345943, 50.96557840704918, 75.89599505066872, 64.23162415623665, 51.783982291817665, 21.083301678299904, 24.27912399172783, 44.82383497059345, 36.14406332373619, 39.05793696641922, 18.850588984787464, 0.3847676207078621, 0.7307764305733144, 0.9245944709982723, 0.9974558581598103, 8.533310405910015, 9.352452401071787, 4.78672094643116, 16.603666953742504, 86.18231669068336, 79.51395571231842, 81.46929278969765, 71.88952803611755, 67.67749965190887, 60.31595706939697, 62.1984026581049, 61.49776965379715, 61.24040566384792, 62.87548452615738, 64.53482508659363, 62.37734265625477, 59.58373636007309, 57.87953160703182, 57.95007862150669, 55.45167088508606, 54.985743686556816, 52.40471698343754, 50.14603078365326, 51.642808467149734, 51.7267269641161, 51.61521054804325, 51.580647602677345, 52.75700367987156, 50.233338698744774, 51.003150790929794, 51.81084685027599, 51.54964126646519, 50.849209651350975, 48.2595270127058, 48.394640162587166, 47.785107269883156, 50.425311997532845, 58.64169850945473, 62.86115549504757, 62.54348114132881, 60.518881380558014, 56.03077881038189, 53.95527698099613, 52.45197504758835, 50.91278783977032, 44.96383845806122, 46.12347163259983, 47.64411583542824, 48.558871150016785, 52.82708711922169, 48.747850209474564, 50.646201744675636, 52.71011419594288, 58.10711279511452, 57.368041053414345, 55.27590371668339, 50.500285774469376, 64.38429996371269, 57.90730431675911, 51.343859508633614, 62.07812771201134, 51.351466700434685, 62.67833970487118, 59.49877671897411, 62.763865515589714, 61.646991446614265, 57.50679820775986, 53.898040652275085, 51.97546161711216, 47.898496985435486, 50.22074617445469, 48.11345525085926, 48.842890709638596, 48.65543536841869, 50.92129558324814, 48.268635123968124, 47.15125948190689, 48.108743503689766, 47.72427633404732, 43.90056811273098, 45.09373068809509, 46.312522888183594, 46.18934869766235, 46.87782235443592, 46.7227678745985, 45.886132568120956, 46.18504732847214, 48.666378781199455, 48.366916850209236, 48.925030902028084, 48.788918405771255, 50.98435699939728, 50.27633339166641, 47.700212225317955, 50.5569863319397, 49.855695962905884, 49.633445888757706, 49.46438916027546, 48.88400450348854, 55.14186970889568, 58.25739473104477, 65.16426131129265, 67.03720360994339, 66.80025592446327, 66.85689568519592, 69.3709471821785, 69.27884012460709, 67.78880327939987, 71.13042756915092, 70.0886070728302, 67.392568141222, 75.2628730237484, 10.3561039455235, 0.247280414623674, 2.3432133765891194, 1.9052874692715704, 0.6828279909677804, 0.028472345329646487, 0.028589764224307146, 2.759063537232578, 67.53522768616676, 56.6663821041584, 30.812863893806934, 48.15463364124298, 28.116087801754475, 10.201670732349157, 24.118538908660412, 40.641889572143555, 48.23753759264946, 54.65752109885216, 59.74286422133446, 8.769853413105011, 0.2122405800037086, 0.04043656183057465, 0.06414002389647067, 0.09352665991173126, 0.016356187079509255, 0.045262343701324426, 0.06295276572927833, 0.05002444930141792, 0.01403897567797685, 0.06864101596875116, 0.04686621388827916, 0.036856975784758106, 0.04541575304756407, 0.050086945557268336, 0.028523698238132056, 0.019584813344408758, 0.10642717548762448, 0.023537979832326528, 0.018197939716628753, 0.03835409544990398, 0.09144921787083149, 0.07183334935689345, 0.01629825132113183, 0.06796104542445391, 0.08181179946404882, 0.03363485258887522, 0.04090980342880357, 0.12255348789039999, 0.022647484256594907, 0.7225451816339046, 65.66581919789314, 85.37948057055473, 71.54453694820404, 67.53351017832756, 27.123337872326374, 30.63567940145731, 44.57575008273125, 39.93849791586399, 44.27856422960758, 17.554666623473167, 0.5016837548464537, 1.9364551780745387, 2.4852364556863904, 5.314840832725167, 7.669251970946789, 6.011145394295454, 9.13051676005125, 17.94768713414669, 90.23736789822578, 82.80343919992447, 85.73829531669617, 72.0987220108509, 71.96847259998322, 63.48197378218174, 66.20197042822838, 62.25902080535889, 65.64624264836311, 65.80104634165764, 68.92286002635956, 63.64888742566109, 63.92608255147934, 58.75938959419727, 61.92607507109642, 57.31633722782135, 60.09147271513939, 54.65247116982937, 53.3181993663311, 52.47760087251663, 56.82157337665558, 54.90377828478813, 55.195234045386314, 54.57093134522438, 54.27320212125778, 54.36192736029625, 55.66032528877258, 54.129459634423256, 53.63264009356499, 51.020208075642586, 51.402239575982094, 50.02840809524059, 53.244027346372604, 60.617942065000534, 66.05231925845146, 64.20330807566643, 63.579100370407104, 57.64075241982937, 56.964552104473114, 54.911799654364586, 54.124519899487495, 48.40675391256809, 49.56577152013779, 50.37800073623657, 50.90329974889755, 55.26849411427975, 51.75921142101288, 52.740037590265274, 57.11799927055836, 60.97143329679966, 59.48674276471138, 55.19673876464367, 54.25043374300003, 66.70557260513306, 59.9337013810873, 54.4485817104578, 65.20044296979904, 52.939428091049194, 65.29194965958595, 62.14853793382645, 64.33437824249268, 63.07050906121731, 59.54993337392807, 55.924262925982475, 55.050982385873795, 52.59750343859196, 53.24020855128765, 50.306005999445915, 50.689523220062256, 52.1221337467432, 53.570433631539345, 50.583455711603165, 50.16377583146095, 49.74341578781605, 49.40775319933891, 45.49885734915733, 48.82033132016659, 46.56726881861687, 48.81949916481972, 47.728038132190704, 49.73272696137428, 48.59199397265911, 49.6519622951746, 49.64694656431675, 52.97503598034382, 51.478140503168106, 51.61314345896244, 52.4639406055212, 53.20829026401043, 50.75675681233406, 51.57930627465248, 51.9050095975399, 52.91488520801067, 52.441046833992004, 52.576741352677345, 56.949512511491776, 60.76503597199917, 67.77289733290672, 70.0099740922451, 69.82272773981094, 71.4254741370678, 70.57491257786751, 70.68572223186493, 69.31847959756851, 73.92380967736244, 70.72356820106506, 68.82338896393776, 75.74956610798836, 13.66841945797205, 0.6341387098655105, 2.7514007734134793, 2.7952290466055274, 1.929063624702394, 0.15933777031023055, 0.06754712740075774, 1.7336754966527224, 69.3114423751831, 64.43260297179222, 39.13711331784725, 35.86690619587898, 29.649337828159332, 21.903590261936188, 39.07117925584316, 47.45857559144497, 55.93939371407032, 61.56530722975731, 76.25441461801529, 17.5980431959033, 0.492379508796148, 0.12598587636603042, 0.022898354291100986, 0.06462783014285378, 0.07995152467628941, 0.023091706025297754, 0.03622123353125062, 0.036346934793982655, 0.054876325084478594, 0.029148469693609513, 0.07830642076442018, 0.01583126973855542, 0.020266437022655737, 0.11076209717430174, 0.03718863044923637, 0.17124527745181695, 0.12147553323302418, 0.09675083143520169, 0.132057772425469, 0.19507460034219548, 0.23958394245710224, 0.17146743193734437, 0.11169327728566714, 0.19929687143303454, 0.15811294462764636, 0.13594171323347837, 0.1470354406046681, 0.2042404655367136, 0.18192548013757914, 1.6132287285290658, 82.0192676782608, 96.23451009392738, 84.03525710105896, 70.40232583880424, 34.48311164975166, 35.508593022823334, 63.78346860408783, 52.87090636789799, 57.779676765203476, 24.742720015347004, 0.4488666483666748, 1.9713021581992507, 3.005033126100898, 5.9567988105118275, 20.350186116993427, 21.59628175199032, 15.469314772635698, 19.958417639136314, 94.30701032280922, 86.86609759926796, 89.32007431983948, 76.45172283053398, 76.4778046309948, 67.55469784140587, 70.20885542035103, 65.9650607407093, 69.34279069304466, 70.27382433414459, 73.43100652098656, 68.18737149238586, 68.2755495607853, 63.46592344343662, 66.10062226653099, 61.34676955640316, 64.4813771545887, 58.56206998229027, 56.02223686873913, 55.85538402199745, 58.97470124065876, 58.31986717879772, 58.12480844557285, 57.517703622579575, 57.31575585901737, 56.62113793194294, 59.51107285916805, 57.728679701685905, 57.148405238986015, 53.74023512005806, 55.24542175233364, 52.67886087298393, 55.63168242573738, 64.33185517787933, 69.77757096290588, 67.58978515863419, 68.11437740921974, 60.34188687801361, 59.13882963359356, 58.06552782654762, 56.50454118847847, 51.008383110165596, 52.82711371779442, 51.96784682571888, 55.252276584506035, 57.007873579859734, 54.365396574139595, 56.02825574576855, 59.413190111517906, 63.514142856001854, 63.84567126631737, 59.884224236011505, 56.827968433499336, 70.3601785004139, 64.57581728696823, 58.69491085410118, 69.98903721570969, 57.441453114151955, 69.39503788948059, 65.75861021876335, 68.52318987250328, 66.31496116518974, 62.69711069762707, 60.4675917327404, 58.3020955324173, 55.62787123024464, 55.19785590469837, 53.072386756539345, 54.62794728577137, 54.859670251607895, 56.39666497707367, 54.25046034157276, 52.82173700630665, 54.94965702295303, 53.34236226975918, 48.84472221136093, 52.844167202711105, 50.74379190802574, 51.79768055677414, 50.83647273480892, 52.26014994084835, 50.927493050694466, 51.828873082995415, 52.260058745741844, 55.41091427206993, 53.952020555734634, 54.183739721775055, 57.039723470807076, 56.447453051805496, 52.85257615149021, 56.11967884004116, 55.356482192873955, 56.45975299179554, 55.76596722006798, 55.9600418061018, 60.29203735291958, 63.5580874979496, 72.04543367028236, 73.49686458706856, 73.51766467094421, 73.82174715399742, 74.09557566046715, 73.65186586976051, 72.47569978237152, 77.6519264280796, 74.75195243954659, 70.10690689086914, 79.88865360617638, 16.30698647350073, 1.0698361555114388, 11.48834154009819, 6.578232664614916, 2.658160189166665, 0.16592986736213788, 0.2612575935199857, 3.73124944511801, 80.72618946433067, 68.60170125961304, 50.52667535841465, 64.03659582138062, 37.196371257305145, 16.43462922424078, 35.414601266384125, 52.57903262972832, 66.42244219779968, 69.84773799777031, 91.24248996376991, 16.96544174104929, 0.5603542097378522, 0.3079951152903959, 0.21715585375204682, 0.21854945865925401, 0.20142023015068844, 0.15195314859738573, 0.12933426856761798, 0.1539211015915498, 0.23592105775605887, 0.15789423370733857, 0.19528820528648794, 0.182443484372925, 0.1412251961301081, 0.3975686291232705, 0.10456077056005597], [0.012410366925905691, 0.040399929421255365, 0.038526993594132364, 0.08232872016378678, 0.04009971955383662, 0.043587353502516635, 0.04665037879021838, 0.04574715538183227, 0.0035017790514757507, 0.04449856984138023, 0.04139502329053357, 0.08227573081967421, 0.1435770621174015, 0.08030731769395061, 7.474303906783462, 76.96072831749916, 66.04863345623016, 65.04760757088661, 23.948133252561092, 97.70443841814995, 68.39957490563393, 41.18725910782814, 44.48512114584446, 55.32810911536217, 7.448146585375071, 0.383516478468664, 3.0435020243749022, 1.7035521380603313, 2.414132533594966, 4.77550869807601, 5.326130976900458, 9.337382409721613, 49.65125933289528, 83.60556855797768, 80.8576700091362, 74.87719371914864, 72.68396660685539, 63.94472435116768, 60.283552408218384, 59.61836390197277, 58.01233068108559, 55.901410952210426, 58.10518629848957, 56.31029561161995, 55.78653171658516, 56.09649248421192, 55.89199885725975, 52.25726969540119, 52.6254091411829, 53.407608568668365, 52.38004490733147, 52.983034551143646, 51.08649551868439, 52.308620139956474, 52.59866997599602, 52.07988001406193, 52.363158613443375, 50.73490798473358, 50.14487564563751, 49.85885739326477, 52.37346366047859, 48.31471145153046, 47.897262051701546, 49.870549365878105, 48.211558386683464, 48.757585287094116, 59.867862313985825, 63.08872148394585, 64.14985254406929, 62.492358684539795, 60.98877556622028, 57.05369532108307, 50.42217716574669, 49.055246114730835, 49.16184939444065, 46.91294386982918, 47.98325903713703, 52.21519835293293, 56.6762425750494, 54.93492141366005, 52.38842725753784, 49.92565780878067, 53.34713101387024, 56.244897320866585, 56.47837959229946, 49.1457686573267, 62.379010766744614, 56.06886796653271, 53.05513188242912, 60.93767210841179, 54.20806981623173, 63.627559170126915, 62.29756973683834, 62.34896577894688, 57.04424522817135, 55.691969990730286, 52.93462514877319, 51.54447354376316, 50.52339993417263, 48.945002630352974, 47.12176166474819, 47.319430857896805, 47.468390464782715, 49.197054505348206, 48.48714619874954, 48.941829800605774, 47.098655104637146, 47.480318024754524, 44.49642173945904, 43.29942896962166, 44.556891694664955, 44.87512081861496, 45.352299213409424, 46.57052144408226, 45.23500710725784, 45.07161967456341, 48.56715850532055, 46.376838237047195, 48.96645247936249, 47.920482605695724, 51.96634590625763, 49.04908284544945, 49.29596319794655, 50.171907395124435, 50.931300446391106, 49.63373847305775, 50.487328469753265, 50.55399589240551, 51.66056111454964, 55.67840851843357, 60.638308972120285, 63.113081976771355, 65.31037107110023, 65.64609825611115, 66.97746321558952, 65.55650666356087, 70.02895027399063, 65.02638190984726, 71.21042087674141, 64.44565147161484, 70.25986388325691, 23.941204324364662, 0.6678908143658191, 1.7094602272845805, 2.5502875400707126, 1.448898590169847, 0.4876632196828723, 0.03896657137374859, 0.08349565832759254, 26.382983699440956, 76.05212867259979, 38.98546725511551, 37.86626771092415, 40.696101263165474, 23.94904900342226, 13.42861907556653, 31.173665933310986, 46.8746305257082, 51.27824082970619, 62.453144788742065, 35.133146569132805, 0.5712748237419873, 0.03737288345291745, 0.029024015238974243, 0.015338877947215224, 0.052761861006729305, 0.05704977134882938, 0.03403562346647959, 0.012306467178859748, 0.03504098123812582, 0.055575394799234346, 0.01967444251931738, 0.008561921185901156, 0.02489698581484845, 0.011979964874626603, 0.07064943827572279, 0.0576297783118207, 0.010154849333048332, 0.053769571386510506, 0.04739550618978683, 0.0575882588600507, 0.05255048250546679, 0.04042331078380812, 0.02307385551830521, 0.03233797549910378, 0.057079498074017465, 0.03816695178102236, 0.06384451553458348, 0.20131943165324628, 0.26441792550031096, 12.936448585242033, 93.63399043679237, 74.54886093735695, 72.03284874558449, 31.252823285758495, 81.90100282430649, 39.250624626874924, 39.91229072213173, 49.81895573437214, 62.95196682214737, 5.803610030561686, 0.4063721629790962, 2.6951725780963898, 3.400009819306433, 4.112264262512326, 2.5563104543834925, 1.7966670915484428, 13.385994862765074, 55.831840485334396, 87.81753614544868, 82.18231692910194, 78.52222412824631, 75.93213111162186, 67.72761136293411, 62.21081659197807, 63.262436762452126, 62.637415900826454, 59.20631401240826, 61.753872111439705, 60.585347414016724, 59.36631202697754, 58.93707945942879, 58.22039611637592, 55.4174043238163, 54.6747949719429, 57.52519682049751, 55.72366788983345, 55.40739946067333, 54.34390112757683, 55.14230288565159, 54.825411289930344, 55.94248674809933, 54.58040043711662, 54.79786656796932, 54.081813991069794, 55.16001373529434, 53.312381878495216, 50.961493626236916, 50.57775981724262, 51.57204486429691, 50.21498188376427, 51.7222698032856, 65.00988319516182, 65.9432727098465, 66.88599452376366, 66.30847111344337, 62.96235166490078, 59.85264793038368, 54.90025967359543, 51.06759533286095, 52.225750386714935, 50.079724341630936, 51.661777049303055, 55.14501973986626, 59.87628646194935, 57.319035083055496, 55.06244637072086, 52.47068524360657, 55.835792273283005, 58.12762789428234, 58.196643590927124, 52.84935012459755, 65.31379848718643, 58.87931115925312, 54.69238042831421, 63.14943842589855, 56.94877915084362, 65.4041500389576, 65.26560947299004, 65.3731133043766, 60.174262672662735, 58.32349218428135, 54.896938651800156, 54.43586379289627, 53.73026065528393, 51.96438901126385, 50.5069088190794, 48.70653122663498, 50.18745236098766, 51.75354592502117, 51.3098057359457, 51.89138352870941, 49.73444826900959, 49.9821075797081, 47.23828621208668, 46.19864299893379, 47.45502658188343, 46.672587767243385, 49.157137647271156, 50.462690591812134, 49.520078971982, 49.532515704631805, 50.108956173062325, 49.47803042829037, 51.08766205608845, 51.40611916780472, 53.97014178335667, 51.768425926566124, 50.435157269239426, 51.31471127271652, 53.38391304016113, 54.187710508704185, 53.66555392742157, 53.06542553007603, 55.42676702141762, 57.41966888308525, 62.85325951874256, 65.50717771053314, 67.47860312461853, 67.27297335863113, 68.67302343249321, 69.91352006793022, 71.5102931857109, 66.48035869002342, 74.81023371219635, 65.19652917981148, 71.14121899008751, 29.05463933944702, 0.27492180874105543, 0.9205148555338383, 2.5387040991336107, 1.7457463801838458, 1.4500097930431366, 0.266841275151819, 0.14827475300990045, 25.307386815547943, 81.41775995492935, 48.7868969142437, 37.261533960700035, 24.231520146131516, 20.413811802864075, 18.13685428351164, 44.6140406280756, 57.94451951980591, 57.76365302503109, 69.43427458405495, 50.52807368338108, 0.9775306179653853, 0.041205653178622015, 0.050435049924999475, 0.02545684161304962, 0.04658109559386503, 0.008951525524025783, 0.026212041811959352, 0.010418963920528768, 0.018403347639832646, 0.011723888674168848, 0.05516048229765147, 0.06761743105016649, 0.018053775675070938, 0.033573729306226596, 0.05830953363329172, 0.15314245509216562, 0.11833894997835159, 0.1388795641832985, 0.18009083170909435, 0.12441175887943245, 0.13755508291069418, 0.16391124052461237, 0.1304584144963883, 0.09896125149680302, 0.13389635423664004, 0.16034387022955343, 0.18235310562886298, 0.4078319377731532, 0.39055625384207815, 16.17114756256342, 109.10712495446205, 84.47052374482155, 85.94633415341377, 35.9508702903986, 111.35256126523018, 79.6692381799221, 60.57807460427284, 63.411635756492615, 71.20869576931, 10.314666219055653, 0.6960346573032439, 6.833912869915366, 6.078533828258514, 11.295565534383059, 13.888850379735231, 17.50749785453081, 14.679448306560516, 57.44208388030529, 93.94620448350906, 84.66071873903275, 83.640838265419, 79.14704740047455, 71.39496177434921, 64.45994630455971, 67.9418058693409, 65.26767656207085, 62.11489453911781, 63.97402077913284, 65.12255474925041, 62.49157972633839, 62.32667997479439, 61.517437398433685, 58.64924490451813, 58.239083513617516, 60.999479591846466, 60.05170784890652, 59.92193341255188, 57.85188049077988, 58.44740733504295, 59.00326430797577, 59.15177173912525, 58.549162074923515, 57.86667309701443, 56.983288899064064, 57.21766032278538, 56.96324497461319, 54.75431330502033, 52.62914054095745, 56.35204017162323, 52.32323035597801, 54.38372299075127, 66.0992619395256, 70.56277602910995, 69.11272063851357, 69.96385216712952, 67.04475000500679, 62.27414019405842, 55.71262188255787, 53.84881429374218, 54.58404444158077, 52.28500820696354, 55.146672651171684, 58.136918395757675, 62.68185071647167, 60.55850565433502, 57.50598885118961, 56.6563468426466, 60.47247067093849, 62.9978683590889, 60.7065799087286, 55.545411854982376, 68.77416640520096, 63.25781621038914, 58.63593801856041, 65.76383873820305, 61.1873073130846, 69.5282131433487, 67.8056363761425, 69.39968883991241, 64.23730865120888, 61.300655230879784, 58.3134151250124, 57.91195906698704, 57.30049967765808, 55.06205879151821, 54.106600061059, 53.58338713645935, 54.60906229913235, 54.66986283659935, 53.05431492626667, 55.83540089428425, 53.76949355006218, 53.78013677895069, 48.81504960358143, 49.588486701250076, 49.38233636319637, 47.94904187321663, 50.79534754157066, 52.25408546626568, 51.95501111447811, 50.977460369467735, 53.19984331727028, 50.53436994552612, 53.56239706277847, 53.09751860797405, 57.8374070674181, 53.67813505232334, 54.366897493600845, 55.67527748644352, 56.406377255916595, 57.69836872816086, 55.9990619122982, 56.23171202838421, 57.122422233223915, 61.21313452720642, 65.91564059257507, 68.78204718232155, 71.11940816044807, 72.35450148582458, 73.71203944087029, 72.67070531845093, 76.18786498904228, 69.96287181973457, 77.49725952744484, 68.08654770255089, 74.22212406992912, 34.444053545594215, 1.1636699829250574, 9.170153383165598, 7.884621089324355, 6.371381739154458, 1.7418171535246074, 0.21863795234821737, 0.2162879120442085, 33.50408658385277, 89.23525527119637, 53.257011249661446, 56.25456780195236, 52.317659854888916, 31.610895171761513, 20.34400574862957, 44.25792373716831, 64.9923737347126, 68.75764489173889, 80.02091690897942, 59.75365564227104, 1.447092262096703, 0.22185430163517594, 0.12176349395303987, 0.07768735827994533, 0.19834822858683765, 0.2366921046632342, 0.11277525438345037, 0.11101489493739791, 0.0936764178914018, 0.07464711321517825, 0.11499090658617206, 0.15914288233034313, 0.09748742042575032, 0.09203914363752119, 0.15443998156115413], [0.029694204276893288, 0.03700942776049487, 0.11194352206075564, 0.03962456692534033, 0.0761525152483955, 0.03252760165196378, 0.04920780113025103, 0.06151963403681293, 0.03334370063384995, 0.05788950773421675, 0.032948814987321384, 0.07849874091334641, 0.23283293674467131, 0.252148027648218, 36.94652706384659, 81.75690695643425, 61.297569796442986, 67.44093954563141, 53.027400970458984, 82.62318447232246, 90.83034887909889, 39.36046153306961, 49.031569585204124, 48.16194824874401, 0.24705147690838203, 0.04511403662036173, 2.417338374070823, 2.5996834645047784, 4.749465370550752, 2.0298677030950785, 1.1647978099063039, 36.883686035871506, 75.46921715140343, 82.9030242562294, 75.37882760167122, 74.03402656316757, 65.53169399499893, 64.871806204319, 60.475396513938904, 61.052566543221474, 57.47981585562229, 58.14733363687992, 58.15216697752476, 55.89077532291412, 55.72596296668053, 55.98133206367493, 52.057898193597794, 51.83195851743221, 52.96889930963516, 50.86017586290836, 52.104977667331696, 50.94365358352661, 50.733486860990524, 51.80925853550434, 52.060584649443626, 54.08451944589615, 50.084964260458946, 50.76833859086037, 48.371393010020256, 51.653717681765556, 50.07451482117176, 50.09745419025421, 48.50396789610386, 49.41154159605503, 48.16857509315014, 51.73828214406967, 63.77436429262161, 64.51855435967445, 62.383084148168564, 63.85580912232399, 63.493521362543106, 58.79625901579857, 53.9626257866621, 49.095497354865074, 46.27666421234608, 47.13779680430889, 47.07544595003128, 53.63433480262756, 60.63001021742821, 59.33515749871731, 57.616498321294785, 50.53455613553524, 49.90933768451214, 51.580244824290276, 52.3492057621479, 50.67568816244602, 62.698695212602615, 54.69762034714222, 52.53936655819416, 62.52723701298237, 55.111395344138145, 61.720532700419426, 60.24713896214962, 60.115890204906464, 51.89375080168247, 54.96495500206947, 54.492685943841934, 53.21899428963661, 49.19291652739048, 48.97634334862232, 49.94828179478645, 44.373289346694946, 45.438353195786476, 48.3348997682333, 46.33315198123455, 49.06932055950165, 45.828162878751755, 45.88636435568333, 45.023107677698135, 43.67009527981281, 42.89277099072933, 43.883670419454575, 44.62754510343075, 46.17286138236523, 44.56832528114319, 45.900966972112656, 47.703852429986, 47.352454885840416, 48.34622696042061, 49.18334484100342, 48.861532509326935, 49.014827683568, 47.66802795231342, 50.38444139063358, 51.13265164196491, 51.75972439348698, 47.87756770849228, 51.31737872958183, 49.861365258693695, 51.30325108766556, 52.225347608327866, 56.35814644396305, 56.737875267863274, 58.791539669036865, 62.25983016192913, 63.902007043361664, 62.07325637340546, 67.31803894042969, 66.7730949819088, 72.48937144875526, 71.09265759587288, 57.58467882871628, 1.0020723729394376, 1.793414584826678, 1.4043124951422215, 2.010229881852865, 0.9359030798077583, 0.16388946591177955, 0.09831820279941894, 3.008023565635085, 64.73531752824783, 64.20243412256241, 38.735300078988075, 59.61228422820568, 64.81312215328217, 43.60520616173744, 11.297949906438589, 21.635203063488007, 53.388647586107254, 59.00674492120743, 53.70174318552017, 6.042792471125722, 0.22270014218520373, 0.0759059663687367, 0.19685520557686687, 0.015374814593087649, 0.03154088291921653, 0.08921723841922358, 0.036586800633813255, 0.011721344963007141, 0.022722220383002423, 0.035366182928555645, 0.004517611077972106, 0.026258270190737676, 0.11854517797473818, 0.06997798016527668, 0.027430976697360165, 0.03927821773686446, 0.050532237873994745, 0.028253923846932594, 0.059763007593574, 0.11445967727922834, 0.0985737019800581, 0.049674630572553724, 0.031351286452263594, 0.03833921538898721, 0.04289089985832106, 0.0920091757143382, 0.08720523153897375, 0.23721010889858007, 46.16506040096283, 92.3634222149849, 69.90499332547188, 76.71554267406464, 51.616346687078476, 103.81459414958954, 72.6074007153511, 34.63970884680748, 58.56210798025131, 51.018543764948845, 0.1811607860145159, 0.2462822853703983, 3.159481300972402, 3.568009017035365, 3.886631182394922, 1.156883428338915, 2.7269975328817964, 38.52207452058792, 82.34865680336952, 83.49498689174652, 80.34334480762482, 78.69802549481392, 69.00671392679214, 69.15121257305145, 65.88784128427505, 62.57895603775978, 61.06469929218292, 61.533901914954185, 60.40847070515156, 61.21062286198139, 59.46997806429863, 58.56980636715889, 56.934324726462364, 54.37930762767792, 55.049200281500816, 53.82017903029919, 54.836757481098175, 54.50110249221325, 54.43741410970688, 54.381766095757484, 53.94548490643501, 55.343319699168205, 53.57584834098816, 53.74643258750439, 53.09821397066116, 52.69283652305603, 51.519755870103836, 54.305481389164925, 50.72678402066231, 51.51079215109348, 52.14329481124878, 53.53158451616764, 66.31952852010727, 67.85035997629166, 65.03968879580498, 66.38461902737617, 65.09899601340294, 60.79343184828758, 56.51339091360569, 50.90036630630493, 49.36905987560749, 49.560744389891624, 48.76407153904438, 56.12561032176018, 64.03474152088165, 62.64263682067394, 61.225339472293854, 52.994730323553085, 53.47065098583698, 54.63615484535694, 55.76407492160797, 54.098886474967, 66.28615111112595, 55.63093766570091, 56.70038267970085, 66.41526058316231, 57.128878086805344, 65.23637384176254, 62.16953560709953, 60.0497205555439, 54.537534937262535, 59.436368867754936, 55.78777804970741, 56.07998996973038, 52.579374611377716, 51.219476982951164, 52.98736251890659, 47.78046011924744, 48.010590970516205, 49.818412363529205, 49.482058212161064, 51.43397927284241, 47.94127129018307, 48.056287318468094, 47.33428806066513, 45.176832228899, 45.0252203643322, 45.603347942233086, 47.08361551165581, 47.77223356068134, 47.81339295208454, 49.72350485622883, 49.724504202604294, 50.065307915210724, 49.42073330283165, 52.64249302446842, 52.301503121852875, 52.29864947497845, 49.97632808983326, 51.03028893470764, 53.85726884007454, 54.00866411626339, 51.08679570257664, 52.53486379981041, 50.55478245019913, 54.99158397316933, 53.53989467024803, 58.822135627269745, 59.363709166646004, 61.21631495654583, 65.25607198476791, 65.45463413000107, 64.88812252879143, 71.42363503575325, 67.77839943766594, 76.7794780433178, 71.99805781245232, 61.59393489360809, 2.4745219806209207, 0.8236416662111878, 0.1998067120439373, 3.2300717756152153, 3.037783093750477, 0.6220273347571492, 0.08828905658447184, 2.301384983584285, 66.00049763917923, 71.79341599345207, 45.389670208096504, 41.03718236088753, 39.074903056025505, 32.86179564893246, 23.01798116415739, 34.03855450451374, 59.95484724640846, 65.0055742263794, 69.3589398264885, 11.694924104958773, 0.3007521398831159, 0.1686833836720325, 0.07492466902476735, 0.05717400686990004, 0.02116885891155107, 0.0482519520301139, 0.05941702205745969, 0.03541610720276367, 0.04626885551260784, 0.01539897799375467, 0.04724427133623976, 0.03037707105249865, 0.04499411668803077, 0.05556616990361363, 0.16564955818466842, 0.12984253582544625, 0.17934069852344692, 0.12710528739262372, 0.16833583591505885, 0.1676190400030464, 0.18326231074752286, 0.17448282247642055, 0.1133827467856463, 0.13183938805013895, 0.17479838366853073, 0.2110788962454535, 0.3631754871457815, 0.36997827992308885, 54.918882474303246, 101.14868000149727, 80.38796201348305, 86.6939364373684, 71.91155165433884, 90.19559293985367, 107.17773288488388, 63.974476754665375, 64.38577428460121, 63.656749203801155, 0.617054351605475, 0.36570496391505003, 7.239283192902803, 9.85142357647419, 16.106625124812126, 6.515987254679203, 3.513472443446517, 42.607254311442375, 83.90182346105576, 88.77558633685112, 82.85246416926384, 82.8564615547657, 72.10037112236023, 72.45929226279259, 68.4016951918602, 67.23391905426979, 63.946213871240616, 65.2209922671318, 64.50594663619995, 62.74281084537506, 62.131412252783775, 63.08989942073822, 59.24010179936886, 57.9300232976675, 58.936828672885895, 55.84059901535511, 57.49032609164715, 55.728885009884834, 55.95903865993023, 56.12967610359192, 57.99001827836037, 60.31249165534973, 55.670839324593544, 55.174027383327484, 55.53632654249668, 55.56447923183441, 54.29440878331661, 56.99639819562435, 52.96320341527462, 54.94622200727463, 54.5403353869915, 56.66245311498642, 70.30248239636421, 70.10377585887909, 67.01588675379753, 69.69093561172485, 68.95527988672256, 64.38959687948227, 59.55223225057125, 54.537534937262535, 50.821588933467865, 52.78460539877415, 50.78057013452053, 59.24630306661129, 67.82924070954323, 64.89569172263145, 64.83028203248978, 54.852887615561485, 55.04895329475403, 57.80972175300121, 59.68723140656948, 57.454847395420074, 67.88877591490746, 59.42378394305706, 59.813084453344345, 68.61844316124916, 60.845724642276764, 65.72038426995277, 65.79000413417816, 64.11257654428482, 57.18733035027981, 60.94836473464966, 57.39854961633682, 58.6588279902935, 56.20273858308792, 52.98202760517597, 57.30396509170532, 50.93320034444332, 50.293056294322014, 52.73707754909992, 52.39907048642635, 55.06800927221775, 50.312693640589714, 49.54849384725094, 51.35819233953953, 48.05372625589371, 49.515587612986565, 49.086605831980705, 50.05091808736324, 49.47557955980301, 50.53371258080006, 52.34270051121712, 52.8287286311388, 52.87359282374382, 52.83165067434311, 54.69238422811031, 54.17123079299927, 53.605695739388466, 52.12716847658157, 55.61971306800842, 57.95807719230652, 57.51143775880337, 53.09958949685097, 57.368109449744225, 53.913270235061646, 56.55034773051739, 57.04649470746517, 62.49003700911999, 63.11035372316837, 64.88091811537743, 68.7038017809391, 70.33757731318474, 67.60065257549286, 73.50408419966698, 71.4879047870636, 80.77902182936668, 73.57522398233414, 64.5643039047718, 2.1082729334011674, 6.876733247190714, 9.151173401623964, 8.881525620818138, 4.398785512894392, 0.5977303104009479, 0.23491188534535468, 4.115625657141209, 79.2754577100277, 75.54539546370506, 58.33317406475544, 83.07121083140373, 87.96566739678383, 53.97037357091904, 20.73061030358076, 32.81529374420643, 71.42211511731148, 73.78469154238701, 84.03819054365158, 13.316390197724104, 0.3514000080758706, 0.20969985227566212, 0.2993152232374996, 0.16515021154191345, 0.08992436414700933, 0.20763003209140152, 0.10562781564658508, 0.1686447623069398, 0.10119467071490362, 0.1149843460007105, 0.08732037575100549, 0.10422138642752543, 0.2006527010235004, 0.1657692962908186], [0.05294001726724673, 0.004086931185156573, 0.026715223502833396, 0.03804595944529865, 0.029652419507328887, 0.05365266086300835, 0.05983833187201526, 0.03712132507644128, 0.02295256817888003, 0.0755924015538767, 0.05617383671051357, 0.13918276119511575, 0.05977290784358047, 0.6781246152240783, 61.64275087416172, 69.30866092443466, 69.61655080318451, 41.29450835287571, 30.196576863527298, 3.3699978422373533, 27.127722837030888, 37.23444901406765, 70.74347153306007, 22.470877021551132, 0.163811243546661, 0.3716493886895478, 1.4686645357869565, 3.174899211153388, 1.82263252325356, 1.1251250887289643, 13.362065646797419, 61.81703992187977, 82.14896231889725, 79.10269618034363, 74.83549475669861, 70.41323885321617, 66.53040200471878, 65.39770558476448, 61.90415404736996, 59.47253532707691, 60.0153362005949, 59.788739159703255, 56.487601697444916, 58.89471933245659, 55.30345983803272, 57.10814639925957, 53.20316433906555, 53.352108746767044, 51.110787615180016, 49.81425158679485, 51.19878709316254, 53.497656136751175, 50.33038929104805, 52.43353843688965, 52.285631373524666, 51.729402020573616, 49.8972999304533, 50.183876752853394, 49.236595183610916, 51.87510900199413, 48.707169592380524, 49.22246374189854, 47.43403270840645, 49.751919731497765, 49.21301744878292, 48.43194656074047, 59.947859421372414, 65.4975414276123, 62.31460802257061, 62.88781486451626, 62.86160007119179, 58.94553020596504, 54.31084290146828, 50.126184448599815, 51.01201191544533, 50.65635100007057, 47.758763283491135, 51.94538243114948, 61.65188558399677, 62.75157317519188, 61.729921996593475, 58.87233853340149, 51.5325041860342, 52.20116190612316, 50.91331601142883, 50.83186738193035, 62.13080808520317, 51.837525218725204, 49.084607139229774, 62.63015069067478, 55.19664376974106, 61.06787972152233, 57.9979332536459, 58.35293300449848, 58.233680203557014, 60.49527704715729, 59.24535311758518, 55.41530303657055, 48.823827132582664, 48.98162506520748, 47.47818633913994, 48.67515631020069, 46.25407822430134, 43.76857079565525, 46.022982224822044, 47.057108134031296, 47.04584173858166, 46.27286061644554, 45.76082669198513, 43.03751662373543, 41.102489456534386, 42.3542220890522, 41.87354028224945, 45.165831819176674, 45.667317509651184, 45.011959075927734, 45.93560591340065, 45.82196921110153, 47.4343328922987, 49.66949835419655, 49.38140161335468, 50.69499872624874, 47.818085700273514, 51.27969615161419, 51.75757370889187, 49.93069253861904, 49.6674844622612, 48.71878556907177, 50.42216196656227, 54.00707960128784, 51.27744287252426, 56.000745221972466, 55.28506502509117, 59.39140968024731, 59.82954517006874, 64.14169818162918, 65.69423407316208, 66.59668564796448, 66.47533535957336, 68.02946716547012, 66.38941437005997, 71.20636269450188, 31.591455414891243, 0.12898073910037056, 0.9669661161024123, 0.5735507234930992, 2.048772401176393, 0.33817897376138717, 0.2411729993764311, 0.10044280832516961, 24.254845194518566, 74.87140282988548, 55.04749797284603, 33.055121675133705, 91.53676137328148, 145.606849193573, 53.656236827373505, 22.657914385199547, 46.88067600131035, 48.64679463207722, 68.56051906943321, 18.236673027276993, 0.5219810188282281, 0.08274408537545241, 0.144369364134036, 0.013250549527583644, 0.004948669466102729, 0.008827444926282624, 0.049096241491497494, 0.04975830772309564, 0.05679243535269052, 0.028137903900642414, 0.026653267159417737, 0.014063805156183662, 0.05162138040759601, 0.061948016518726945, 0.021098542274557985, 0.052861472067888826, 0.025497728383925278, 0.0060931149891985115, 0.04697552853031084, 0.016887791171029676, 0.028027787739119958, 0.00816651139757596, 0.011536411966517335, 0.033522201993037015, 0.03629870632721577, 0.06704842642648146, 0.058032534434460104, 1.7931309062987566, 77.34769955277443, 78.16404014825821, 78.66820469498634, 53.73297370970249, 45.416321977972984, 11.404869519174099, 27.602826543152332, 42.63646714389324, 80.23130401968956, 25.27319435030222, 0.20436072314623743, 0.3023240383481607, 2.6437743986025453, 3.1906643277034163, 3.230514689348638, 2.335136909969151, 16.955011300742626, 66.44527897238731, 84.971534460783, 84.36777725815773, 77.50824093818665, 74.70679566264153, 69.0781956911087, 68.1878274679184, 66.07862144708633, 63.65073412656784, 64.00705620646477, 63.61720472574234, 60.69272205233574, 60.69742240011692, 58.56982536613941, 60.22497475147247, 56.23040869832039, 56.724936962127686, 54.04959551990032, 53.83415088057518, 53.08573164045811, 54.82733018696308, 54.19013477861881, 55.05179934203625, 52.83575065433979, 54.391523972153664, 54.57174830138683, 54.61836040019989, 54.12837289273739, 54.2328292876482, 51.83718703687191, 52.18384623527527, 48.73552747070789, 51.57261103391647, 51.083311289548874, 51.31168283522129, 61.961656361818314, 67.37498268485069, 64.88806173205376, 66.15443497896194, 65.29917687177658, 61.54590167105198, 57.49629557132721, 53.009256944060326, 55.25073006749153, 52.686426267027855, 49.44628693163395, 56.73933818936348, 64.46987137198448, 66.87017977237701, 65.59355467557907, 60.68833328783512, 54.481753930449486, 55.36229208111763, 53.766856491565704, 53.7079406529665, 67.22944289445877, 56.061173379421234, 53.11040371656418, 66.23784050345421, 59.11446154117584, 63.425185829401016, 61.684206649661064, 62.654549181461334, 61.02296993136406, 62.82552860677242, 61.14172115921974, 58.54137249290943, 50.649750754237175, 52.14410796761513, 51.69716455042362, 51.91542483866215, 47.873524725437164, 45.298258513212204, 49.06466580927372, 48.78327190876007, 47.99570716917515, 48.052506521344185, 50.56917607784271, 44.8438560962677, 43.352386727929115, 46.41709707677364, 43.84901627898216, 46.927820071578026, 48.21987234055996, 47.5015626847744, 47.322071716189384, 48.8680187612772, 51.07350401580334, 52.475100606679916, 50.37842631340027, 53.55347514152527, 51.45536072552204, 54.35218088328838, 53.3296063542366, 54.0663868188858, 53.265807777643204, 52.559049502015114, 53.43295320868492, 56.74743555486202, 55.27681186795235, 59.7586789727211, 58.925604075193405, 60.86348868906498, 63.799268156290054, 66.23960360884666, 70.81999182701111, 67.31080412864685, 69.18522074818611, 70.40488690137863, 66.89573720097542, 72.35225960612297, 39.45239000022411, 0.2655120292911306, 0.5724230746272951, 1.0435445350594819, 2.3076724587008357, 1.2514658155851066, 0.409519225358963, 0.14814820198807865, 23.4995274245739, 79.63269174098969, 63.226061314344406, 33.74625898897648, 72.334795743227, 115.91253697872162, 45.90395741164684, 29.000230059027672, 55.728448033332825, 52.90831156075001, 80.83386048674583, 26.068168692290783, 0.7430998224299401, 0.10110711955348961, 0.07942447366076522, 0.07567883949377574, 0.12226574239321053, 0.04858169937506318, 0.02093047551170457, 0.02963744667795254, 0.01730551270156866, 0.03739256149856374, 0.011679550916596781, 0.051680329197552055, 0.019121731747873127, 0.11633096553850919, 0.26855801115743816, 0.12596845073858276, 0.08827473313431256, 0.11787340074079111, 0.1520766716566868, 0.1426507579162717, 0.11921793484361842, 0.10844481526874006, 0.12796025635907426, 0.17309093935182318, 0.17810729361372069, 0.2802224946208298, 0.10584677147562616, 2.8425324708223343, 92.20912009477615, 87.99818605184555, 91.19125351309776, 59.52081933617592, 44.691917449235916, 8.817994929850101, 45.69049246609211, 55.01836873590946, 90.68404152989388, 30.756678208708763, 0.19642011407995597, 1.2471163552254438, 4.220715668052435, 9.202725235372782, 7.648204900324345, 4.280915362760425, 17.691945657134056, 70.88673904538155, 88.28732773661613, 87.10648790001869, 81.97755351662636, 76.23125866055489, 73.66768822073936, 70.69894552230835, 69.3960790336132, 69.40101876854897, 68.60392034053802, 67.94308260083199, 64.34902265667915, 65.22984579205513, 64.03686180710793, 64.17978733778, 60.70178836584091, 59.86186623573303, 56.919885501265526, 56.18672624230385, 57.164295986294746, 58.37302252650261, 57.30852484703064, 57.223413214087486, 55.588911920785904, 56.34501054883003, 57.04773724079132, 57.51048021018505, 57.99629554152489, 57.16873034834862, 55.14995947480202, 56.00166477262974, 52.009465992450714, 54.2313701659441, 53.89297552406788, 54.43857304751873, 65.19336774945259, 71.31787911057472, 67.55422666668892, 68.71240451931953, 68.65385726094246, 64.27261635661125, 59.955793395638466, 56.550655514001846, 58.92089992761612, 56.72271408140659, 53.097989782691, 57.56691098213196, 66.56559571623802, 69.4038838148117, 68.92034456133842, 65.24511337280273, 56.625583693385124, 58.968017399311066, 56.29717871546745, 55.95957823097706, 68.01997527480125, 58.604034930467606, 56.092867478728294, 66.48470565676689, 61.283138170838356, 66.37545391917229, 63.694127798080444, 63.946350663900375, 65.02754464745522, 66.29302874207497, 65.56855961680412, 60.69132752716541, 55.74037179350853, 54.999582543969154, 55.396991819143295, 56.74363575875759, 52.583884969353676, 49.61950823664665, 50.86290791630745, 51.87822483479977, 52.29952722787857, 51.91078148782253, 52.40640789270401, 48.12469884753227, 46.167157888412476, 48.758862018585205, 46.416276320815086, 49.599821493029594, 50.67011006176472, 50.84041692316532, 50.509048104286194, 50.1247139275074, 53.55809189379215, 55.49975350499153, 54.47851650416851, 56.33955404162407, 52.761270850896835, 58.917647302150726, 56.346788853406906, 56.19476281106472, 57.17650853097439, 53.172716572880745, 57.19901092350483, 61.28202863037586, 57.889962047338486, 62.813430055975914, 62.706446796655655, 64.38856333494186, 67.81347155570984, 70.5687341094017, 73.42396929860115, 70.68652018904686, 72.31536358594894, 73.30963343381882, 72.21316426992416, 73.4112323820591, 39.820746034383774, 0.17681267636362463, 6.040200535207987, 6.105752717703581, 6.593180587515235, 2.3706312803551555, 0.8321277389768511, 0.12735843396512792, 30.502012073993683, 87.78606623411179, 68.7875796854496, 47.449414283037186, 101.31473869085312, 147.29292511940002, 62.96938128769398, 32.310091853141785, 64.95769679546356, 63.397340923547745, 92.8622442483902, 30.89628081768751, 0.9993919730186462, 0.3104565816465765, 0.29282469651661813, 0.2129867798066698, 0.17914925410877913, 0.15467908669961616, 0.10656199403456412, 0.17555142607307062, 0.13173470069887117, 0.11860209328006022, 0.13698572205612436, 0.0891368267184589, 0.12492733629187569, 0.24480915191816166], [0.05564870414673351, 0.03568037114746403, 0.08777112656389363, 0.016708725779608358, 0.0796580794849433, 0.04745373509649653, 0.031843207907513715, 0.0447043822350679, 0.06864273775136098, 0.01606987392733572, 0.020065634125785436, 0.13515175640350208, 0.32739248068537563, 14.18401949107647, 79.88488420844078, 64.84379410743713, 60.43116308748722, 30.361267626285553, 16.63282658904791, 41.051784977316856, 55.882408171892166, 37.56156586110592, 80.6968854367733, 4.695664057508111, 0.021370446629589424, 0.07913641646155156, 1.7540216236375272, 1.9107547821477056, 1.0387133317999542, 8.30276632681489, 35.23416794836521, 77.58991375565529, 78.13466772437096, 77.41658985614777, 75.66084086894989, 70.37170708179474, 66.21618166565895, 64.9622717499733, 64.01226192712784, 60.47866813838482, 55.78098401427269, 58.66233140230179, 54.24266315996647, 56.76635093986988, 56.05095572769642, 56.37433737516403, 56.57175578176975, 53.489980548620224, 53.734554424881935, 50.28193809092045, 52.03249655663967, 50.73579713702202, 54.534096121788025, 52.892694398760796, 52.91240394115448, 50.75419194996357, 51.16734378039837, 50.00553712248802, 50.31105972826481, 48.55557292699814, 49.2316098511219, 46.61364533007145, 48.096523359417915, 48.39069977402687, 50.27099847793579, 46.96305178105831, 55.21297909319401, 61.470213532447815, 62.8923936188221, 62.902698665857315, 64.16008919477463, 59.09642770886421, 58.68354186415672, 56.96121968328953, 58.03408831357956, 59.861284866929054, 55.987453535199165, 48.88974979519844, 58.88449028134346, 60.69413937628269, 63.17860186100006, 62.08369821310043, 61.43866002559662, 54.229154884815216, 53.034552186727524, 51.06602981686592, 66.56552731990814, 47.54300706088543, 47.47498691082001, 63.86467784643173, 55.63964679837227, 61.366281509399414, 55.33118315041065, 61.22009575366974, 58.60770933330059, 59.42062251269817, 58.04343581199646, 56.36147886514664, 46.963055580854416, 46.82827681303024, 50.95256790518761, 49.316265508532524, 45.28857663273811, 43.46992962062359, 43.43908287584782, 43.124672546982765, 46.318465769290924, 44.824214950203896, 46.69983610510826, 44.1551810503006, 40.984794571995735, 41.72551542520523, 43.8424426317215, 44.429841712117195, 43.632340505719185, 46.64718613028526, 44.25559066236019, 44.61428381502628, 45.868748500943184, 46.55471429228783, 49.8098324239254, 48.23899291455746, 49.54517662525177, 52.44390428066254, 51.203107461333275, 50.06187669932842, 51.68026685714722, 52.77238145470619, 53.970225378870964, 54.161571711301804, 60.43424092233181, 60.668467953801155, 60.15533588826656, 63.40172588825226, 65.24719566106796, 66.52635142207146, 69.35153022408485, 67.85815715789795, 66.72054380178452, 66.58473908901215, 66.6383770108223, 66.89544841647148, 70.0835533440113, 20.346105135977268, 0.34987560706213117, 1.5667633968405426, 2.7303629647940397, 1.2034849589690566, 0.2457047312054783, 0.11748793665901758, 3.2296409737318754, 59.804432317614555, 69.95173841714859, 49.25122819840908, 69.42429631948471, 109.9769438803196, 108.43506261706352, 30.785362869501114, 34.30399306118488, 54.96268652379513, 58.93519476056099, 42.541191056370735, 1.5933389333076775, 0.10673730415874161, 0.052678502979688346, 0.03950640217226464, 0.11966262230998836, 0.05925688885326963, 0.06157127638289239, 0.04240660768118687, 0.050584566706675105, 0.016401261418650392, 0.047755024788784795, 0.05303497506247368, 0.051620838639792055, 0.020263477708795108, 0.054332672225427814, 0.043816821853397414, 0.07061860946123488, 0.0638102283119224, 0.037683424015995115, 0.04231920494930819, 0.05085640055767726, 0.05723833994125016, 0.09165461466182023, 0.04662644452764653, 0.03256250114645809, 0.10262635521939956, 0.37659687164705247, 20.00058777630329, 93.10802266001701, 71.78817987442017, 68.58635008335114, 36.2196184694767, 25.90482495725155, 34.95868653059006, 50.254606157541275, 47.6145838201046, 85.8663484454155, 4.966781409457326, 0.11330655790516175, 0.42033973848447204, 2.267399369738996, 1.428302745334804, 1.6684402409009635, 11.702425852417946, 40.0332610309124, 79.34880137443542, 82.56843701004982, 82.07590743899345, 79.60932299494743, 73.77297297120094, 69.66239154338837, 67.97399774193764, 68.93441140651703, 63.68467390537262, 60.2022709697485, 62.34039343893528, 58.624588027596474, 58.96582491695881, 59.7148597240448, 59.21802498400211, 59.954600259661674, 56.919851303100586, 58.29547628760338, 54.17303569614887, 54.120248928666115, 54.139080718159676, 56.35777026414871, 56.77254840731621, 55.97527518868446, 54.23374883830547, 54.306081756949425, 53.759028911590576, 52.898576483130455, 53.68089750409126, 51.462884321808815, 50.32120518386364, 50.12202367186546, 51.5130340307951, 52.21127316355705, 49.03188116848469, 57.72900648415089, 65.26234924793243, 65.6673239171505, 66.98614954948425, 65.57371973991394, 61.459357514977455, 60.54475039243698, 58.88267397880554, 60.77259376645088, 63.32725748419762, 57.45007865130901, 52.678435295820236, 63.35529237985611, 63.25959071516991, 65.60574442148209, 65.18759965896606, 64.19921949505806, 56.3466976583004, 57.2611527889967, 54.35276985168457, 68.59915539622307, 49.88770544528961, 49.73397709429264, 66.83009192347527, 59.03883419930935, 63.73873360455036, 58.10888350009918, 64.6936185657978, 61.335943937301636, 59.29984599351883, 60.881427526474, 57.06138230860233, 50.44142313301563, 49.27412576973438, 53.03370103240013, 52.01855510473251, 47.40527965128422, 46.97913631796837, 46.32944718003273, 45.49311585724354, 47.99392506480217, 46.58391572535038, 49.28153537213802, 47.29596331715584, 43.34923669695854, 44.99650910496712, 43.774593472480774, 47.501190304756165, 47.39950016140938, 49.38545599579811, 47.04994171857834, 46.98955535888672, 49.15800780057907, 50.68728893995285, 51.56904302537441, 49.566292092204094, 52.77641303837299, 54.466129168868065, 52.97977812588215, 54.04599331319332, 55.75555957853794, 55.42206287384033, 57.37471729516983, 57.423609271645546, 62.14116632938385, 61.98701240122318, 64.49695631861687, 66.19156658649445, 68.6538116633892, 69.31532576680183, 70.60923993587494, 69.05806437134743, 70.1152816414833, 71.17634430527687, 69.87632006406784, 68.17332744598389, 73.30693557858467, 27.154648192226887, 0.3724243096075952, 1.736874331254512, 2.386297839693725, 1.5524397091940045, 0.6640349118970335, 0.12820452684536576, 2.584562413394451, 62.10157245397568, 75.91933339834213, 54.41674701869488, 67.3695869743824, 105.96100777387619, 103.9444787800312, 39.27672162652016, 41.38180486857891, 63.26136142015457, 66.64007931947708, 56.06361664831638, 2.003059429116547, 0.11341998775606044, 0.03212857853213791, 0.04912803509796504, 0.02216498993220739, 0.03202128624252509, 0.047958915019989945, 0.06765363301383331, 0.01614318141946569, 0.019773355961660855, 0.0807974765484687, 0.1640053151641041, 0.05208956798014697, 0.05012656140024774, 0.1503381461952813, 0.272357658832334, 0.1851383116445504, 0.11629949847701937, 0.1700990303652361, 0.20281154924305156, 0.13634719303809106, 0.18021410243818536, 0.15838341292692348, 0.12445666623534635, 0.17522504436783493, 0.3165788546903059, 0.6753191782627255, 24.425917714834213, 106.34712785482407, 79.69542637467384, 80.14434948563576, 46.08368776738644, 26.469525955617428, 57.174620032310486, 78.19395214319229, 54.64439660310745, 98.13848912715912, 6.537943901494145, 0.19195520522771403, 1.0323014133609831, 6.12672901712358, 5.949668018147349, 4.734725011512637, 14.093955773860216, 41.914266496896744, 84.36817243695259, 84.77453783154488, 89.3953786790371, 83.57911437749863, 77.7292750775814, 72.33169510960579, 72.80470132827759, 72.9104496538639, 67.51066580414772, 62.72952675819397, 65.08762702345848, 62.362238466739655, 63.04210938513279, 63.58830347657204, 62.19307154417038, 62.18067280948162, 60.51876358687878, 60.35844258964062, 55.85938520729542, 55.72479262948036, 56.0927876830101, 59.00226876139641, 58.2990974932909, 59.0788384526968, 58.371552005410194, 55.96439637243748, 56.10597677528858, 56.18429437279701, 56.3970335572958, 54.299675300717354, 52.7377425134182, 53.818317130208015, 53.49086210131645, 54.296631664037704, 52.54460267722607, 60.64611375331879, 67.78804332017899, 68.43210116028786, 69.35529962182045, 70.64422085881233, 65.87325766682625, 64.38976407051086, 63.48920859396458, 62.64849990606308, 66.30885109305382, 61.25828370451927, 56.64566181600094, 67.03620806336403, 65.3322958946228, 67.96466544270515, 69.29201781749725, 68.36857616901398, 60.44595569372177, 58.85750412940979, 55.65318167209625, 71.40184700489044, 52.98879124224186, 54.29140694439411, 69.0562404692173, 61.25423312187195, 67.14168280363083, 61.908345222473145, 67.0766530930996, 62.17460833489895, 63.15537370741367, 63.606413304805756, 61.65095843374729, 53.9670829474926, 51.34453967213631, 55.46080179512501, 54.54830355942249, 51.826627403497696, 49.149340465664864, 48.06274697184563, 47.62042410671711, 51.562655568122864, 49.323735907673836, 52.403136268258095, 49.87786777317524, 45.44026829302311, 48.34662213921547, 48.375010415911674, 52.05135494470596, 50.876230001449585, 51.74401603639126, 51.21108703315258, 49.81606788933277, 52.19842605292797, 51.26556470990181, 54.27341490983963, 52.13181562721729, 55.50953038036823, 59.046281799674034, 55.86994484066963, 56.61543443799019, 59.18664626777172, 57.0117873698473, 58.989326655864716, 60.73334567248821, 65.31356289982796, 63.52713815867901, 67.0055665075779, 70.58352291584015, 72.80061274766922, 71.07008680701256, 73.51487562060356, 73.91480416059494, 73.9286582171917, 74.81693655252457, 72.67653420567513, 71.7225193977356, 74.94829550385475, 27.55144950002432, 0.6932754116132855, 8.775734547525644, 9.384606275707483, 3.5308439237996936, 0.9553773317020386, 0.165310456068255, 4.270680136978626, 73.65883469581604, 83.1642298400402, 68.25290277600288, 75.4421778023243, 110.61994537711143, 116.08295023441315, 41.23009040951729, 51.04652926325798, 72.30998307466507, 77.67186775803566, 65.06856724619865, 2.6306532276794314, 0.32178519875742495, 0.11428311292547733, 0.2876648702658713, 0.26036639290396124, 0.1916001469362527, 0.1559275423642248, 0.20065290882484987, 0.16360491164959967, 0.1183372875675559, 0.23578301828820258, 0.31489652465097606, 0.0929795041156467, 0.07540022241300903], [0.04946777546138037, 0.026959082097164355, 0.04106122753000818, 0.06200860174431, 0.04122131991607603, 0.01447309774448513, 0.028920485638082027, 0.06798052680096589, 0.01268247258849442, 0.09875734642264433, 0.05280139892420266, 0.12787790765287355, 0.031259976312867366, 31.810080483555794, 77.14998096227646, 61.021070033311844, 56.3123095035553, 31.64202880114317, 30.019591860473156, 46.50806039571762, 29.227036088705063, 65.27188673615456, 61.26369461417198, 0.4532288736663759, 0.06740041964803822, 0.45932713081128895, 1.4485341659747064, 1.055189366452396, 3.911515809595585, 13.65817615762353, 51.49994753301144, 74.82336580753326, 79.31590273976326, 77.24817529320717, 77.6346905529499, 70.56309521198273, 70.32120019197464, 62.34848700463772, 62.325821220874786, 57.11416147649288, 56.80785991251469, 54.197726771235466, 58.53809326887131, 54.533051177859306, 55.3046415746212, 56.6121020168066, 60.14805927872658, 56.40365280210972, 55.682964473962784, 50.83579637110233, 51.31106346845627, 50.31037196516991, 52.09590755403042, 53.81165228784084, 53.84953245520592, 51.55235432088375, 50.22982768714428, 50.719363018870354, 51.63210444152355, 46.377507001161575, 49.06127259135246, 47.59428910911083, 48.37763227522373, 50.324511006474495, 49.885915741324425, 48.25039230287075, 54.93961416184902, 63.311598524451256, 64.75931704044342, 60.75512610375881, 64.38639745116234, 62.95360453426838, 61.33291929960251, 60.846385806798935, 63.03069859743118, 63.23939859867096, 63.22059340775013, 55.48073172569275, 55.23049235343933, 60.089933797717094, 65.26361837983131, 57.481970340013504, 64.36391025781631, 56.3073355704546, 61.041041761636734, 54.6611575037241, 66.21571809053421, 37.947815135121346, 33.49260360002518, 69.72001925110817, 54.42596912384033, 64.17201295495033, 54.43769909441471, 60.15024796128273, 51.6072765737772, 59.08617585897446, 59.06664490699768, 52.885524183511734, 45.16783431172371, 47.79454976320267, 49.23099808394909, 49.647440537810326, 44.42019023001194, 44.14384625852108, 44.89428699016571, 46.443767845630646, 44.1524375975132, 45.449524596333504, 43.40865030884743, 45.77156111598015, 42.34529256820679, 41.744563803076744, 40.61224356293678, 42.04898826777935, 44.124839678406715, 45.74774019420147, 44.598849043250084, 44.82486851513386, 45.91811925172806, 46.704042479395866, 49.46312002837658, 49.703255742788315, 48.36318165063858, 51.34478285908699, 53.001737147569656, 55.25749370455742, 53.993457332253456, 57.32466258108616, 57.25098453462124, 61.16859331727028, 66.99731335043907, 65.08635029196739, 64.09170046448708, 67.17606335878372, 63.84052634239197, 68.10797095298767, 65.75799465179443, 67.07306608557701, 64.89954471588135, 68.6530289053917, 65.27138516306877, 66.34685665369034, 63.13111960887909, 65.36606088280678, 13.825597073882818, 0.6011099321767688, 3.0966262612491846, 0.7740030891727656, 0.2469115672283806, 0.12708110822131857, 0.1448898619855754, 23.47431767731905, 73.3901359140873, 53.46978843212128, 39.44549337029457, 47.02080488204956, 32.10051789879799, 14.01719419285655, 34.44726437330246, 50.220742374658585, 57.2314877808094, 63.66748362779617, 7.696282770484686, 0.490671856678091, 0.09620031371014193, 0.11996706612990238, 0.09702738534542732, 0.09592384143616073, 0.03896579954016488, 0.051501297202776186, 0.07111322120181285, 0.06542451083078049, 0.04008731455542147, 0.05188676128454972, 0.07387863413896412, 0.040599630228825845, 0.10924032336333767, 0.08748013045988046, 0.038527613287442364, 0.049252163007622585, 0.02165016579965595, 0.06507744546979666, 0.0902005321404431, 0.10379262545029633, 0.03851053275866434, 0.03224181542464066, 0.05550023750402033, 0.08313988757436164, 0.0453030282369582, 44.150598496198654, 88.19911167025566, 68.25237840414047, 70.49555003643036, 47.391566187143326, 33.35753984749317, 29.81881443411112, 36.038497388362885, 73.72254967689514, 67.66154810786247, 0.1848934919689782, 0.22179954597959295, 1.2684354675002396, 4.232663651928306, 2.0334786968305707, 3.7448805011808872, 18.76891426742077, 55.00042989850044, 80.04587396979332, 78.85126367211342, 81.3822090625763, 80.09426817297935, 75.32277300953865, 73.06537494063377, 68.18686991930008, 65.52653387188911, 61.415572464466095, 60.04841722548008, 57.79218949377537, 60.130451023578644, 56.974765956401825, 57.50510349869728, 58.72552961111069, 61.86022460460663, 60.26769205927849, 58.25096547603607, 53.916503861546516, 53.72542731463909, 53.61647196114063, 54.36575375497341, 57.74503402411938, 56.57271333038807, 53.690020814538, 52.410614266991615, 51.58517315983772, 53.631849735975266, 49.13551300764084, 51.1133486777544, 50.13615511357784, 51.34099066257477, 52.58530229330063, 51.63834750652313, 50.285194516181946, 59.51915882527828, 66.39332056045532, 65.83010718226433, 60.6839407235384, 64.96532678604126, 66.67762890458107, 64.89377662539482, 64.29468557238579, 66.3873016834259, 65.82306236028671, 67.21238180994987, 58.715923726558685, 57.29894556105137, 62.2172686457634, 66.03484779596329, 61.03817671537399, 65.51192745566368, 59.50167216360569, 62.675489857792854, 58.46758805215359, 66.36831030249596, 47.98866614699364, 41.622411757707596, 68.11965152621269, 57.76832677423954, 65.31629875302315, 59.82308931648731, 61.94739192724228, 55.00101886689663, 60.16095958650112, 61.51877112686634, 54.80143077671528, 48.94213758409023, 50.59301599860191, 52.054683566093445, 52.0858608931303, 48.62898878753185, 46.74693837761879, 46.69835798442364, 49.13578279316425, 47.415645495057106, 49.15649928152561, 46.67854964733124, 46.947301626205444, 43.73780384659767, 44.58710387349129, 42.71193869411945, 45.326008424162865, 46.045929193496704, 50.10433182120323, 47.51603990793228, 46.67104125022888, 46.92768707871437, 49.85800623893738, 49.68773737549782, 51.764987111091614, 51.723432540893555, 53.96208241581917, 56.24993585050106, 57.259933054447174, 58.150175884366035, 61.148344203829765, 59.62386220693588, 63.08654420077801, 67.6284746825695, 69.3009777367115, 66.42620399594307, 71.42475217580795, 67.13323205709457, 71.04296386241913, 68.60145807266235, 71.9522550702095, 67.06972986459732, 70.52132785320282, 66.4368586242199, 69.82487842440605, 64.68390628695488, 70.78640922904015, 18.33926562219858, 0.25294770661275834, 0.8129654859658331, 1.3180555799044669, 0.5572874774225056, 0.4275392834097147, 0.20923036965541542, 22.617178671061993, 80.48112541437149, 63.591183722019196, 45.89421093463898, 54.947608932852745, 46.36110708117485, 17.630162872374058, 43.328204825520515, 57.20133639872074, 62.894536703825, 74.06905308365822, 11.625594925135374, 0.6017218774650246, 0.13178899622289464, 0.18907398014562204, 0.10833281034138054, 0.18405577051453292, 0.019545114009815734, 0.04411836387589574, 0.030806420181761496, 0.07516574827604927, 0.08011972502572462, 0.07459525935701095, 0.033085377581301145, 0.0689852908544708, 0.17786315671401098, 0.17062733561033383, 0.17443810065742582, 0.152540513954591, 0.22052768297726288, 0.11163774979650043, 0.12971173971891403, 0.18221476930193603, 0.08039160340558738, 0.1912949758116156, 0.14860301977023482, 0.23815370514057577, 0.1562450034543872, 56.47543855011463, 99.2801758646965, 80.26652812957764, 76.35224416851997, 46.70574098825455, 41.96673408150673, 62.66431085765362, 44.96209815144539, 81.65658473968506, 74.52209517359734, 0.8811794850043952, 0.4778270615497604, 2.480210275389254, 7.876148018985987, 5.018638176843524, 9.921461418271065, 20.44064786285162, 60.94128951430321, 81.91021353006363, 82.44449526071548, 81.52305230498314, 82.24123656749725, 76.45714893937111, 77.94571906328201, 71.46203577518463, 70.18907368183136, 63.89006048440933, 63.5128965228796, 61.083249896764755, 65.18081322312355, 60.78841611742973, 61.01162753999233, 62.402311116456985, 66.41323909163475, 64.46361690759659, 61.47494427859783, 57.79816277325153, 57.2112500667572, 56.342415288090706, 57.30036288499832, 59.03628073632717, 59.56999629735947, 57.06722639501095, 54.822291657328606, 54.51908692717552, 56.60036064684391, 52.57710613310337, 54.07167613506317, 54.114545434713364, 54.2627564817667, 56.593684405088425, 53.215437680482864, 52.99082413315773, 60.599874034523964, 69.652299284935, 70.051049888134, 64.74691450595856, 67.38067477941513, 68.63290518522263, 68.30264210700989, 69.30755898356438, 70.53791776299477, 69.1944694519043, 69.02234628796577, 62.11877033114433, 59.517437517642975, 66.06403782963753, 66.614278703928, 63.43223825097084, 69.32460486888885, 63.624823316931725, 64.10399660468102, 61.02289393544197, 68.86808216571808, 51.398131996393204, 45.14603108167648, 71.16028636693954, 60.675182193517685, 68.10081213712692, 62.975312769412994, 64.0740618109703, 58.9568991959095, 62.88989715278149, 66.14921405911446, 59.704094901680946, 52.179632261395454, 53.814604729413986, 57.04633891582489, 54.18453007936478, 51.427082642912865, 50.830909833312035, 51.02800525724888, 51.560246497392654, 49.91572514176369, 51.54606565833092, 47.94209964573383, 50.2946712076664, 46.709202602505684, 48.62918257713318, 45.699870362877846, 46.35902479290962, 49.339170679450035, 51.315323039889336, 51.32016018033028, 50.10102979838848, 50.77301613986492, 52.97486498951912, 53.04766148328781, 55.43926075100899, 54.45394702255726, 55.689602717757225, 59.1393768042326, 61.15267597138882, 60.53589306771755, 63.56164790689945, 63.925307393074036, 66.49904608726501, 69.41709950566292, 71.11389085650444, 69.34242591261864, 73.880385607481, 70.28957828879356, 74.40954521298409, 71.58021703362465, 74.42085340619087, 69.23423051834106, 74.21480566263199, 70.46637520194054, 72.05234169960022, 65.71687325835228, 70.64514800906181, 17.543565519154072, 2.825986258685589, 9.10997411236167, 5.696915555745363, 1.70995123218745, 0.5806901841424406, 0.2081089696730487, 29.38725259155035, 87.06335261464119, 70.13273790478706, 52.41050027310848, 58.601238280534744, 41.41986362636089, 22.03777626156807, 49.82446923851967, 67.61262953281403, 74.39456641674042, 85.43092980980873, 15.470047183334827, 0.6505323958117515, 0.3994739300105721, 0.4448296321788803, 0.385160573059693, 0.2302227885229513, 0.20373365288833156, 0.19344662519870326, 0.19847941061016172, 0.1444823486963287, 0.14552742621162906, 0.1704298352706246, 0.12562163028633222, 0.13294541073264554], [0.03157914805342443, 0.042240570692229085, 0.04863536036282312, 0.030941164513933472, 0.02160598203772679, 0.020355025335447863, 0.04438578194822185, 0.05238928060862236, 0.043478339430294, 0.05702716553059872, 0.050801964025595225, 0.032147280653589405, 0.410554432310164, 48.04661683738232, 74.63544309139252, 61.901836171746254, 36.1665391176939, 14.708138667047024, 33.57996091246605, 64.49311092495918, 39.95975777506828, 84.51092317700386, 30.19996628165245, 0.16625308751827106, 0.31417578051332384, 0.1997133795521222, 1.6771719348616898, 1.1742570460774004, 6.826352225616574, 22.685561701655388, 68.38794752955437, 84.21827808022499, 80.26111721992493, 77.60975629091263, 72.60534882545471, 67.00063437223434, 68.80483835935593, 62.447931468486786, 58.87988492846489, 58.87288570404053, 58.61444637179375, 54.149541556835175, 55.41756771504879, 55.74646666646004, 57.922218516469, 55.338440760970116, 56.57015226781368, 55.979280173778534, 58.39993268251419, 53.85585531592369, 51.78647495806217, 51.67779318988323, 53.35699528455734, 50.7658801227808, 54.47295740246773, 49.84222188591957, 52.385702803730965, 50.78109830617905, 52.07118608057499, 48.134973496198654, 51.312647983431816, 46.934412717819214, 49.64686676859856, 47.86141477525234, 47.963830679655075, 51.164262145757675, 61.268721744418144, 62.4576323479414, 65.0403119623661, 62.39239364862442, 63.975601494312286, 63.532959446311, 66.57211616635323, 57.57116675376892, 62.43473097681999, 61.85587003827095, 65.0030967593193, 58.08692827820778, 58.32770615816116, 57.2687029838562, 68.60753014683723, 54.82778616249561, 67.399772554636, 55.89560866355896, 65.25427848100662, 51.07516832649708, 77.30673775076866, 20.63303343951702, 18.005480132997036, 74.54579830169678, 52.81879596412182, 64.61490198969841, 51.603628769516945, 58.28737512230873, 50.55203899741173, 63.394365683197975, 52.50946216285229, 53.49063791334629, 44.038599506020546, 48.514451533555984, 49.14114810526371, 50.86524099111557, 42.62533754110336, 44.64601211249828, 43.79101239144802, 46.720214411616325, 43.980698212981224, 45.41960500180721, 43.337354734539986, 46.77086189389229, 42.38004170358181, 38.98136347532272, 39.277329593896866, 40.35106457769871, 41.00679159164429, 44.80825200676918, 42.67964422702789, 46.38210095465183, 43.07129681110382, 45.960828959941864, 47.850380167365074, 47.24256858229637, 48.59965056180954, 52.793230935931206, 53.87616142630577, 57.8154556453228, 54.31670218706131, 60.39129942655563, 57.46800608932972, 67.21568003296852, 67.40440830588341, 64.4655168056488, 63.43293361365795, 63.652907609939575, 63.830532878637314, 65.95347136259079, 64.38703581690788, 65.49791380763054, 66.39811590313911, 69.58941265940666, 63.175569623708725, 64.84738111495972, 66.56304225325584, 67.51049101352692, 62.08406299352646, 6.5541790053248405, 1.2578689469955862, 2.3732096794992685, 0.4160940006840974, 0.12136774370446801, 0.10523002449190244, 2.915623211301863, 57.817062959074974, 68.02330389618874, 47.96427145600319, 37.58105881512165, 39.795929566025734, 29.45103406906128, 23.564325347542763, 35.66319152712822, 46.898774430155754, 62.27370701730251, 24.69972152262926, 0.6919494015164673, 0.05282365222228691, 0.1337068690918386, 0.018729979819909204, 0.05957093606411945, 0.07929536222945899, 0.10497485927771777, 0.11301892373012379, 0.08532049556379206, 0.1310459282831289, 0.0139190316258464, 0.05378933477913961, 0.009532806197967147, 0.0368497843737714, 0.02928743684606161, 0.017340874182991683, 0.07227388821775094, 0.052878752976539545, 0.029004383577557746, 0.04633705146261491, 0.02448653176543303, 0.06932356918696314, 0.08675332297571003, 0.027115346856589895, 0.049697904323693365, 0.6252723606303334, 64.09757494926453, 80.11661097407341, 71.92502573132515, 41.92207507789135, 23.92326168715954, 32.65236608684063, 47.415653094649315, 47.28584825992584, 93.13044905662537, 33.38409282267094, 0.26825248380191624, 0.29588976642116904, 0.7608416641596705, 1.518976092338562, 1.1049719201400876, 10.461123660206795, 30.129155181348324, 72.65647888183594, 84.74501341581345, 84.1212996840477, 79.50129479169846, 76.86365872621536, 72.53675490617752, 72.81584993004799, 67.55807965993881, 62.1389776468277, 61.85906186699867, 59.398439303040504, 57.27149583399296, 58.36293786764145, 58.924266546964645, 60.50337441265583, 58.29254664480686, 61.09616540372372, 59.64861787855625, 59.8579790443182, 57.703726440668106, 55.75624734163284, 54.90018367767334, 55.65431021153927, 52.148306742310524, 58.630618304014206, 54.657631292939186, 55.1389666646719, 52.932181879878044, 53.0553674697876, 51.783674508333206, 52.13295556604862, 49.251893162727356, 52.356771156191826, 50.43497107923031, 51.94230079650879, 52.08720602095127, 62.67961643636227, 65.80388098955154, 68.71062621474266, 64.68564659357071, 67.25778177380562, 65.33665046095848, 65.57517886161804, 60.47977767884731, 63.87531727552414, 64.79352280497551, 68.39008301496506, 61.12855106592178, 59.26148325204849, 61.36707566678524, 67.16553792357445, 58.42487074434757, 67.67814561724663, 59.54894162714481, 65.93362882733345, 58.46272811293602, 72.18629211187363, 36.29123702645302, 31.25266559422016, 71.63699358701706, 56.88216112554073, 64.72071871161461, 56.84851013123989, 60.57185813784599, 53.87284800410271, 64.11851942539215, 55.73901906609535, 53.86946238577366, 48.06161843240261, 51.01103916764259, 52.347115874290466, 53.25810179114342, 46.981936767697334, 45.522286891937256, 46.94825917482376, 47.94820211827755, 47.13573731482029, 48.166967779397964, 46.301761865615845, 47.564605101943016, 44.97827768325806, 41.388180926442146, 42.2894773632288, 43.97176869213581, 45.006240382790565, 48.17499294877052, 47.27736331522465, 48.21069583296776, 46.53171792626381, 49.52697180211544, 51.156955137848854, 49.317295253276825, 52.06098362803459, 56.24281883239746, 57.29668848216534, 58.765530064702034, 58.78309652209282, 62.34532557427883, 60.45219875872135, 67.5091002881527, 72.47169479727745, 66.42467647790909, 67.16680705547333, 67.14609056711197, 66.19154378771782, 68.86514112353325, 67.97056272625923, 67.1718379855156, 69.42115768790245, 71.16175308823586, 65.24987831711769, 66.3115793466568, 69.38499122858047, 68.48716780543327, 65.66168501973152, 10.59426661580801, 0.47502233705017716, 1.009700344875455, 1.216955236159265, 0.4491424304433167, 0.20098090841202065, 2.8128883615136147, 60.889878273010254, 75.72213158011436, 55.57367093861103, 41.333452463150024, 37.797818183898926, 29.51389029622078, 35.95384173095226, 45.02713926136494, 51.8491829931736, 68.3038580417633, 35.15520818531513, 0.9286688023712486, 0.027897015752387233, 0.10547097757807933, 0.04242808172421064, 0.0898698608216364, 0.04042342952743638, 0.04891684955509845, 0.02341046401852509, 0.027449151893961243, 0.07621090742759407, 0.036773729079868644, 0.016024929464037996, 0.009089356262848014, 0.16011375992093235, 0.11414832406444475, 0.11025906205759384, 0.14910500845871866, 0.19100774981779978, 0.301340781734325, 0.122916182881454, 0.11698596281348728, 0.16572435182752088, 0.1889455143827945, 0.21204920980380848, 0.14813396759564057, 2.207081881351769, 78.58008742332458, 89.79626476764679, 80.36169022321701, 52.000642865896225, 22.689967565238476, 48.31170581281185, 85.17700463533401, 58.01334522664547, 101.97534844279289, 38.42400938272476, 0.3993307548807934, 0.8274120732676238, 2.2844008449465036, 6.673040427267551, 4.025508742779493, 13.022190984338522, 35.245191156864166, 72.71014720201492, 88.18507522344589, 85.30391782522202, 82.47712031006813, 79.70355793833733, 75.65534636378288, 73.79343867301941, 71.23548433184624, 64.65841725468636, 67.11842805147171, 63.445267751812935, 60.94868391752243, 63.436642214655876, 62.42689199745655, 63.64101804792881, 62.86543786525726, 64.81849506497383, 63.96905064582825, 62.875473126769066, 60.674574226140976, 56.11564725637436, 58.059501349925995, 59.578561037778854, 56.1681604385376, 58.615335524082184, 56.664748191833496, 56.86109505593777, 56.44518457353115, 58.09539422392845, 54.060804918408394, 56.488646641373634, 52.75258831679821, 54.48561072349548, 53.382765501737595, 54.074320793151855, 57.79836796224117, 66.52480870485306, 68.50549042224884, 71.4904810488224, 65.79454109072685, 70.59235364198685, 68.36649388074875, 71.15757331252098, 64.15484547615051, 67.72313520312309, 66.62076115608215, 71.25917226076126, 64.06729817390442, 63.015427216887474, 66.38290151953697, 71.74837321043015, 60.46943463385105, 71.96712747216225, 63.245679661631584, 69.44517999887466, 59.45987440645695, 75.2266001701355, 33.19233991205692, 29.07845266163349, 74.51954931020737, 59.201389476656914, 69.40366342663765, 60.304614678025246, 64.48517695069313, 55.822561383247375, 67.56491929292679, 58.898249343037605, 56.76986575126648, 51.319404020905495, 52.96305142343044, 54.146934896707535, 56.06515936553478, 49.76876422762871, 48.289746791124344, 50.31238205730915, 51.51976726949215, 50.14821566641331, 49.86999839544296, 49.4499347358942, 50.374683514237404, 48.48297022283077, 44.210779666900635, 43.996854946017265, 45.38774751126766, 46.84389777481556, 50.003937408328056, 49.73695993423462, 52.39148989319801, 48.060394898056984, 52.95635238289833, 52.080442383885384, 51.19036294519901, 54.321501329541206, 57.371609061956406, 58.65838721394539, 62.96707481145859, 60.89307390153408, 64.72191944718361, 62.600930258631706, 69.47981894016266, 72.77102753520012, 69.58079472184181, 69.27624866366386, 69.57870483398438, 66.67377591133118, 70.64917579293251, 69.86061930656433, 69.03504520654678, 72.62475818395615, 74.11161839962006, 67.16830417513847, 68.61000001430511, 71.45690605044365, 71.56982839107513, 68.07221487164497, 10.302494522184134, 4.092837804928422, 10.54034085944295, 2.9079480981454253, 0.8658566290978342, 0.24524599488358945, 4.393524695187807, 68.8761605322361, 80.6943091750145, 61.24807745218277, 53.711915239691734, 50.81097610294819, 43.82552593946457, 36.64806827902794, 53.908596485853195, 62.06973776221275, 80.18784955143929, 41.32541969418526, 1.4517872664146125, 0.13880468148272485, 0.16090944613097236, 0.12962294917088002, 0.1957182798651047, 0.1476143900072202, 0.1656815002206713, 0.22858618962345645, 0.1586453613708727, 0.40171147556975484, 0.14374941849382594, 0.157060208148323, 0.07190662159700878], [0.04889723459200468, 0.04375185424578376, 0.0570496563159395, 0.02826451058353996, 0.04801429036888294, 0.026990721707988996, 0.02104887033056002, 0.05347440812329296, 0.02590763138869079, 0.03526406340824906, 0.12176049567642622, 0.19625206216005608, 10.142820440232754, 68.11916515231133, 60.69099314510822, 59.788697361946106, 46.16236254572868, 22.089111506938934, 35.289325788617134, 30.73165275156498, 47.25137270987034, 89.65540632605553, 8.454534932971, 0.3839543752837926, 0.16168156173080206, 1.793109413702041, 2.34945026692003, 9.336988180875778, 8.447309620678425, 42.053232640028, 74.83901336789131, 75.42196288704872, 70.40848910808563, 72.81624510884285, 71.69522926211357, 68.51923048496246, 64.28905427455902, 60.94089813530445, 58.9178828895092, 56.07771009206772, 55.295085087418556, 54.50546085834503, 55.25937080383301, 53.97911310195923, 55.41123725473881, 55.471809804439545, 56.2798098474741, 56.26157462596893, 57.43886165320873, 55.32531626522541, 54.48127895593643, 52.85366669297218, 50.53914628922939, 50.60875095427036, 50.566159039735794, 55.23168928921223, 49.215156733989716, 51.13699860870838, 48.18000108003616, 46.910789385437965, 49.31747004389763, 46.88807040452957, 48.69852885603905, 47.92079418897629, 46.22499838471413, 51.58187113702297, 57.5199531018734, 63.179308623075485, 64.94340196251869, 62.89609082043171, 65.43329447507858, 61.67878434062004, 60.618078857660294, 53.64168360829353, 59.598730355501175, 66.31819099187851, 65.6662067770958, 58.622581735253334, 63.06524254381657, 58.09014670550823, 67.93312713503838, 57.35626928508282, 59.40725103020668, 52.311040610075, 66.05882450938225, 48.45616266131401, 78.52930694818497, 11.195802837610245, 9.602286145091057, 75.03680795431137, 49.897030144929886, 65.73606222867966, 51.57910868525505, 60.42767487466335, 55.58535911142826, 59.83321197330952, 50.71231059730053, 50.86110681295395, 41.56670294702053, 50.42825683951378, 47.93001629412174, 51.01806499063969, 43.89073424041271, 45.04197746515274, 44.72360394895077, 46.878958493471146, 44.48140874505043, 46.77577503025532, 45.209282487630844, 47.65380151569843, 42.890810295939445, 40.51045462489128, 40.020155534148216, 40.288360342383385, 43.15735459327698, 44.81536142528057, 44.78669576346874, 45.38217321038246, 43.27933184802532, 44.75636199116707, 48.52397762238979, 44.966836497187614, 51.18431746959686, 53.324875608086586, 56.507185846567154, 59.07525524497032, 57.01823942363262, 62.756474912166595, 64.39344227313995, 73.49437952041626, 60.078169628977776, 63.30590642988682, 64.49812665581703, 66.08119010925293, 65.42428895831108, 66.84154450893402, 63.33871386945248, 61.533130556344986, 67.06684961915016, 67.78580904006958, 60.84910646080971, 64.92301985621452, 72.03908041119576, 63.73281352221966, 69.5713560283184, 47.10985690355301, 1.414961542468518, 0.7437260169535875, 1.329676068853587, 0.5966832290869206, 0.13066703220829368, 0.1809920958476141, 26.664491593837738, 73.48045706748962, 59.17057313024998, 59.20327037572861, 45.06810486316681, 26.68823651969433, 16.0068728774786, 27.66457322984934, 47.96258054673672, 52.084447368979454, 55.05903035402298, 5.530275022611022, 0.24915916146710515, 0.03511532959237229, 0.1119114612811245, 0.02801160891976906, 0.05937370289757382, 0.028664147830568254, 0.03933046493330039, 0.0510222482989775, 0.10255909437546507, 0.02244998762762407, 0.027061296241299715, 0.024035383903537877, 0.03187140951922629, 0.014290899562183768, 0.04947150475345552, 0.014219137592590414, 0.04169136656855699, 0.08337003499036655, 0.06409121284377761, 0.03998628228146117, 0.01860591128206579, 0.12362489680526778, 0.050919520217576064, 0.30712359643075615, 15.865688603371382, 84.1928194463253, 67.3480649292469, 68.18246975541115, 60.13337306678295, 28.41042000800371, 22.75651529431343, 36.279210671782494, 54.3066593259573, 98.6352364718914, 8.679832443594933, 0.3378509444883093, 0.3367494192207232, 3.354324158281088, 4.099194863811135, 13.27598886564374, 13.81176296621561, 46.744491308927536, 76.22069522738457, 76.12744063138962, 73.09844836592674, 78.31180661916733, 72.4565564095974, 72.16818988323212, 66.39319896697998, 62.90138013660908, 61.27789065241814, 59.60692271590233, 57.31736317276955, 57.60180450975895, 58.832296282052994, 55.40501318871975, 58.326566219329834, 57.24064528942108, 59.79400187730789, 60.488422214984894, 60.12864992022514, 57.72834911942482, 56.5267737954855, 55.60060769319534, 53.05804252624512, 53.4044623374939, 51.36772222816944, 56.21101073920727, 52.967873364686966, 53.00112538039684, 52.10653938353062, 49.673457741737366, 51.77988991141319, 47.81145505607128, 50.95010943710804, 51.41928546130657, 48.646167665719986, 55.39718560874462, 60.61056666076183, 66.13295093178749, 66.66905656456947, 64.1415385901928, 66.77178785204887, 64.02562960982323, 62.487084567546844, 55.93927972018719, 62.264249324798584, 68.08234512805939, 68.75449866056442, 64.91781413555145, 64.62439388036728, 62.61333279311657, 71.10547810792923, 59.71386417746544, 59.26434449851513, 55.48541687428951, 64.8324403166771, 54.26212191581726, 71.20562553405762, 20.560559928417206, 20.499451607465744, 71.14954814314842, 54.555576369166374, 63.62318180501461, 54.927732199430466, 61.94421909749508, 60.899620950222015, 61.757721304893494, 54.4378624856472, 52.04192005097866, 44.85605724155903, 51.43013007938862, 51.02814964950085, 53.94115313887596, 47.790559977293015, 46.68035455048084, 47.8108736872673, 48.60076770186424, 47.39816263318062, 48.80809597671032, 47.28671841323376, 48.446340188384056, 46.38280771672726, 42.5526512414217, 42.49852694571018, 41.87146559357643, 46.3663773983717, 46.74661919474602, 48.59231695532799, 47.87220239639282, 46.72710724174976, 48.14441978931427, 48.9202431589365, 47.611802369356155, 52.26664379239082, 55.4864352196455, 58.638746067881584, 60.42722649872303, 60.3594571352005, 64.74225595593452, 66.8838818371296, 74.67901915311813, 65.51225423812866, 63.75366300344467, 68.66635859012604, 67.7028214931488, 67.34939485788345, 69.03401166200638, 66.02730140089989, 65.03918722271919, 69.86807450652122, 68.3196347951889, 62.37737685441971, 68.05565536022186, 72.38895043730736, 66.43414556980133, 70.73793902993202, 52.09104381501675, 2.458128472790122, 0.27206563856452703, 1.5850974130444229, 1.0412860312499106, 0.591975519200787, 0.14927068550605327, 25.025666132569313, 78.40138301253319, 66.82177037000656, 62.99593046307564, 33.27417992055416, 32.20897547900677, 24.799336977303028, 31.67861893773079, 57.7754969894886, 57.84643538296223, 66.75125375390053, 7.555952975526452, 0.2733927173539996, 0.06288725635386072, 0.05118921668326948, 0.015700794610893354, 0.07857336386223324, 0.12459642748581246, 0.0721986270218622, 0.0921193252725061, 0.0648761230695527, 0.03069460450205952, 0.026799783809110522, 0.07324315534788184, 0.10127206929610111, 0.1289377687498927, 0.2487670848495327, 0.06135837647889275, 0.1193702309683431, 0.16701936983736232, 0.0892994535388425, 0.2562804543413222, 0.12254482702701353, 0.2751135500147939, 0.33733135205693543, 0.4131372843403369, 21.618311069905758, 97.23275452852249, 77.6286792755127, 80.123982578516, 61.14268250763416, 33.61078105866909, 48.72170001268387, 49.997025579214096, 60.2976306527853, 106.93480432033539, 10.068042352795601, 0.39518185250926763, 0.5818371882196516, 5.164418304339051, 8.330484889447689, 17.117302492260933, 19.184972941875458, 45.852139592170715, 78.50523144006729, 80.71426570415497, 79.28490400314331, 82.99291223287582, 78.91227319836617, 76.2948976457119, 70.81633642315865, 67.34166607260704, 65.09540140628815, 60.30966840684414, 62.746587842702866, 60.615806579589844, 62.69385427236557, 59.66237314045429, 62.65239469707012, 60.360471680760384, 63.94290804862976, 63.95474821329117, 64.29821938276291, 59.96723838150501, 60.46618580818176, 59.29851986467838, 54.393420070409775, 55.30945971608162, 53.580928668379784, 58.99341523647308, 54.61799181997776, 54.81077827513218, 55.87162435054779, 52.95926682651043, 55.105657652020454, 51.299732476472855, 52.90652945637703, 51.211862191557884, 50.90995319187641, 58.51372517645359, 63.78479093313217, 69.51634258031845, 70.72441935539246, 67.43181243538857, 70.9504996240139, 66.29810526967049, 65.97349628806114, 60.0212524831295, 67.6746118068695, 71.67601749300957, 69.28016245365143, 65.94043046236038, 67.98481956124306, 63.74994300305843, 73.42279896140099, 59.66590695083141, 64.15493667125702, 56.265537813305855, 71.19919627904892, 53.68898347020149, 78.98665800690651, 13.409295212477446, 14.516362957656384, 78.43352168798447, 57.49559260904789, 70.65416112542152, 57.528525441884995, 65.64994364976883, 63.14870126545429, 65.48130109906197, 56.27481311559677, 55.517464354634285, 46.02434255182743, 53.778081089258194, 54.5049212872982, 57.14524760842323, 50.22738441824913, 50.890327244997025, 49.90359239280224, 50.50026297569275, 49.83448930084705, 50.20781546831131, 48.99193771183491, 51.7851260304451, 49.279992654919624, 45.660937651991844, 44.298110380768776, 44.034457728266716, 48.93023282289505, 49.26015391945839, 50.340667739510536, 52.38498464226723, 49.77423593401909, 51.46780885756016, 52.70936943590641, 48.12885582447052, 55.39863333106041, 60.450572445988655, 63.559892401099205, 65.15160039067268, 61.45607449114323, 67.57929012179375, 71.91700056195259, 74.42814901471138, 67.8464537858963, 67.17133641242981, 71.66881307959557, 70.46768993139267, 70.6242111325264, 73.19779023528099, 68.94891902804375, 66.03935435414314, 72.35778450965881, 73.35002526640892, 64.92601409554482, 70.85475236177444, 76.3294529914856, 70.86571857333183, 72.92985141277313, 55.5377172678709, 2.23909183871001, 3.524294262751937, 5.456211296841502, 1.3502845005132258, 0.5827908182982355, 0.14579228387447074, 31.67885832488537, 86.78666666150093, 72.2338579595089, 76.81600168347359, 60.01535139977932, 39.1154620796442, 26.778116896748543, 40.52881143987179, 65.58849334716797, 67.6924404501915, 77.81547725200653, 8.657841123640537, 0.4551446239929646, 0.21297030412824824, 0.21587680676020682, 0.13179110392229632, 0.12910819554235786, 0.20438095409190282, 0.22624173026997596, 0.1414294054848142, 0.2710201306035742, 0.22123316855868325, 0.11975317174801603, 0.1781128894072026], [0.02028812814387493, 0.05046375990787055, 0.04632099509763066, 0.016002321790438145, 0.011731143167708069, 0.08000167159480043, 0.08612361809355207, 0.08285273579531349, 0.041112895851256326, 0.06947521222173236, 0.09130423932219855, 0.23426163039403036, 31.04054007679224, 73.67164760828018, 58.11896435916424, 47.999522164464, 19.132507257163525, 29.370271302759647, 52.124846801161766, 41.533306539058685, 74.79611366987228, 63.340651765465736, 0.5827199877239764, 0.10659044797648676, 0.16394200996728614, 1.9466943223960698, 2.250470803119242, 9.428718108683825, 17.717884965240955, 50.00426419079304, 70.91778337955475, 75.33126935362816, 76.84374779462814, 72.0944282412529, 70.48789724707603, 62.70626820623875, 62.724849209189415, 57.5348787009716, 58.82228381931782, 56.79983474314213, 57.342882603406906, 56.64980739355087, 54.89209771156311, 58.28077107667923, 55.97973234951496, 54.73163232207298, 57.14267514646053, 54.52221795916557, 56.338752284646034, 54.11407805979252, 53.00268329679966, 52.484668493270874, 52.37910255789757, 51.5497362613678, 49.638351425528526, 52.79302954673767, 51.3639148324728, 48.81428584456444, 49.582524821162224, 45.976111739873886, 49.15483497083187, 45.09269714355469, 48.48175808787346, 47.540028020739555, 49.94539774954319, 50.759633257985115, 55.36590188741684, 54.19083014130592, 56.44680708646774, 57.78327897191048, 57.01845221221447, 53.56518231332302, 53.66021901369095, 54.85273942351341, 60.481631979346275, 52.640593126416206, 64.26221251487732, 55.096435546875, 64.95114594697952, 60.20757548511028, 68.50469246506691, 50.470673963427544, 61.71067602932453, 55.59349447488785, 68.88590320944786, 55.18168397247791, 65.57572603225708, 10.202244501560926, 8.594535570591688, 70.50736740231514, 49.52186867594719, 64.30195838212967, 53.20609778165817, 58.285004049539566, 53.96181263029575, 59.69319328665733, 48.563613295555115, 51.49031884968281, 42.49356061220169, 51.123984307050705, 49.51179921627045, 51.6233991086483, 46.6185736656189, 46.116153225302696, 43.75338301062584, 47.541433945298195, 47.15746834874153, 47.07241751253605, 44.884909093379974, 47.90911741554737, 44.21360291540623, 41.11032463610172, 38.234749138355255, 40.6681689620018, 41.77796021103859, 41.07609607279301, 42.17299081385136, 46.81790716946125, 42.720636427402496, 41.435507386922836, 44.27325211465359, 45.718854144215584, 49.88021984696388, 51.53503865003586, 57.0264507830143, 60.715091452002525, 62.60515943169594, 62.68113635480404, 66.85476019978523, 68.81268873810768, 59.133741706609726, 67.39975735545158, 65.51944345235825, 63.11837129294872, 61.44408233463764, 61.53147764503956, 58.89322221279144, 61.92280724644661, 65.27203872799873, 66.22826501727104, 63.40905949473381, 68.7356136739254, 67.4453093111515, 66.08263403177261, 65.99377200007439, 70.49801990389824, 24.288518987596035, 0.3349510469706729, 0.10792597982799634, 0.9277132723946124, 0.28196823375765234, 0.10575399559456855, 2.883848366327584, 59.895448833703995, 65.97370147705078, 51.441746056079865, 47.25940927863121, 38.843742460012436, 24.601641185581684, 22.63479072600603, 35.68269208073616, 52.55074314773083, 54.60141330957413, 29.385858066380024, 1.1270893458276987, 0.10725914529757574, 0.1135624801099766, 0.022202609397936612, 0.07940153387608007, 0.03364560630870983, 0.07384804281173274, 0.043895281705772504, 0.02900845982367173, 0.06410794085240923, 0.08291287944302894, 0.03895758025464602, 0.006477039578385302, 0.015217812324408442, 0.05721408284443896, 0.02763576863799244, 0.044463354934123345, 0.06299519431195222, 0.05306918807036709, 0.024721300906094257, 0.035058826179010794, 0.15395834256196395, 0.15483881172258407, 0.16309459606418386, 44.54994946718216, 83.19847360253334, 65.59475541114807, 58.71486738324165, 32.16533102095127, 30.861546881496906, 36.050493344664574, 48.48303861916065, 84.59421470761299, 69.46873113512993, 0.47212172707077116, 0.15017989062471315, 1.1370448116213083, 2.4641435500234365, 7.45728699490428, 9.20808769762516, 18.550389893352985, 55.08209511637688, 72.80053675174713, 78.33291068673134, 79.22716990113258, 75.27233451604843, 72.62250110507011, 67.46868565678596, 66.08109891414642, 62.26956143975258, 61.815322414040565, 59.55957345664501, 59.123725444078445, 61.67608268558979, 58.447973504662514, 59.96747776865959, 59.72794622182846, 58.860133588314056, 58.196901977062225, 57.86101520061493, 60.95640130341053, 57.652797773480415, 55.669365003705025, 55.08452318608761, 53.52528065443039, 55.48374876379967, 51.15417368710041, 55.21087400615215, 53.423772901296616, 50.41947551071644, 50.630440190434456, 49.58510868251324, 50.78456372022629, 48.97645354270935, 50.02624601125717, 48.85250799357891, 52.82616376876831, 54.27050806581974, 55.86985744535923, 56.64093866944313, 61.755209639668465, 59.85260233283043, 58.8681473582983, 55.77281445264816, 56.169581562280655, 57.02497646212578, 63.13072822988033, 60.015852972865105, 64.42728325724602, 56.474678590893745, 66.85973033308983, 62.65021361410618, 67.91679561138153, 54.543504416942596, 62.09081143140793, 60.70421643555164, 67.82760679721832, 59.44050684571266, 62.30617247521877, 14.993567951023579, 16.99002832174301, 67.13969931006432, 56.52555026113987, 65.58462515473366, 58.55821318924427, 60.344736725091934, 58.10146249830723, 60.13645850121975, 52.7898833155632, 52.4234651774168, 47.97650679945946, 51.24671392142773, 53.10000367462635, 54.00616765022278, 48.91040928661823, 47.22506292164326, 46.61610759794712, 51.22188985347748, 50.03645606338978, 49.71622824668884, 48.42248126864433, 51.089451760053635, 48.805261328816414, 43.38482938706875, 40.87246499955654, 41.82680279016495, 46.2144273519516, 45.33249467611313, 46.105449199676514, 48.350554928183556, 44.350444972515106, 44.629258811473846, 47.18580722808838, 48.46943914890289, 50.66225588321686, 54.301666393876076, 60.95724865794182, 61.41110010445118, 63.90164226293564, 66.55969843268394, 67.9090516269207, 70.15466272830963, 63.36431309580803, 68.79568845033646, 66.83259218931198, 65.85505664348602, 64.6280112862587, 62.89341576397419, 60.54666928946972, 65.74960470199585, 69.60275754332542, 68.0014018714428, 64.70675826072693, 69.59588751196861, 70.99841505289078, 69.50678989291191, 69.87965628504753, 73.71893227100372, 30.47426976263523, 0.3849383146734908, 0.8352512307465076, 2.005975297652185, 0.8562425512354821, 0.12490685301600024, 1.9834485626779497, 63.76347407698631, 72.46675506234169, 61.0310634970665, 42.00688652694225, 37.34952203929424, 33.727073818445206, 32.5748236477375, 46.62248745560646, 59.285554960370064, 62.48085670173168, 36.295333206653595, 1.2998367450200021, 0.05038622774009127, 0.0588223576778546, 0.03346055178553797, 0.07462682289769873, 0.05001918376365211, 0.0200353656327934, 0.05614813242573291, 0.04519983631325886, 0.05003305821446702, 0.1041183466440998, 0.03329776169266552, 0.062319038406712934, 0.10965158449835144, 0.17721362906740978, 0.11056547256885096, 0.11591545189730823, 0.19134472939185798, 0.21016795450123027, 0.18446442671120167, 0.161968624452129, 0.3830433147959411, 0.21882990142330527, 0.3579491941491142, 56.63445621728897, 97.06813976168633, 74.86520156264305, 69.52071234583855, 32.322414591908455, 41.75188221037388, 76.47041022777557, 60.749187022447586, 93.44206273555756, 76.0585655272007, 1.1688276124186814, 0.27970506926067173, 1.5328972390852869, 3.736301986500621, 14.569182023406029, 14.31045200675726, 21.936378702521324, 56.473306864500046, 78.13687920570374, 83.26383009552956, 82.68746182322502, 78.29514071345329, 76.18198290467262, 69.5710064470768, 71.56631737947464, 65.2571739256382, 65.75177818536758, 63.3797212690115, 62.29201063513756, 64.77168157696724, 62.19553001224995, 62.421158105134964, 62.05483876168728, 60.92132158577442, 62.092137560248375, 60.42580537497997, 65.97422584891319, 60.42121522128582, 60.14845445752144, 59.425881430506706, 59.00978095829487, 57.995075806975365, 53.33999879658222, 56.965745240449905, 55.47394149005413, 54.58086781203747, 55.80066315829754, 51.031242683529854, 55.64804054796696, 51.484964936971664, 53.64314652979374, 52.10680536925793, 54.30666692554951, 55.39094254374504, 60.47078736126423, 60.95478639006615, 62.418509647250175, 64.31229382753372, 63.69573511183262, 58.96233670413494, 59.81595329940319, 61.34915962815285, 66.22235253453255, 62.02330805361271, 66.45497605204582, 56.791900768876076, 71.6128496825695, 65.16548484563828, 71.71802043914795, 55.26120990514755, 66.35519340634346, 61.85071751475334, 73.74921664595604, 56.81440696120262, 70.878387093544, 8.417711108922958, 10.399788301438093, 75.4823948442936, 57.13504135608673, 72.31144219636917, 57.964814230799675, 64.95879113674164, 59.79283533990383, 62.56966173648834, 54.20776203274727, 54.499255791306496, 48.349354192614555, 54.11965616047382, 54.38491992652416, 56.81005619466305, 50.272271409630775, 50.45121140778065, 49.99110169708729, 54.66429993510246, 52.22513861954212, 51.77745044231415, 49.18992608785629, 54.02824826538563, 49.16838504374027, 46.152057498693466, 43.65406014025211, 44.23711225390434, 47.67819240689278, 46.39008432626724, 46.83250978589058, 52.94013865292072, 49.49833653867245, 46.44574373960495, 49.937349781394005, 50.7628782838583, 53.27169366180897, 57.31825612485409, 63.63464578986168, 65.43020904064178, 67.36397087574005, 70.5347715318203, 69.5528282225132, 73.55339795351028, 66.49682700634003, 71.8930846452713, 70.97230285406113, 68.4839303791523, 67.9716494679451, 66.70785248279572, 64.9390321969986, 67.18346536159515, 72.01316580176353, 72.06963837146759, 67.24977940320969, 74.01391804218292, 75.97369328141212, 70.52686035633087, 75.29684320092201, 74.17430743575096, 33.00928473472595, 0.6847093650139868, 5.530637428164482, 2.586137428879738, 1.306280130520463, 0.2894271444529295, 3.5319890873506665, 73.57412964105606, 78.02685990929604, 67.674011439085, 65.41700094938278, 49.74093072116375, 33.99265676736832, 34.00019556283951, 53.78539189696312, 69.21175092458725, 72.78735905885696, 42.170699536800385, 1.6225726646371186, 0.1726274681277573, 0.21812104649143293, 0.12580246198922396, 0.15105409605894238, 0.16634266474284232, 0.23897958191810176, 0.14530533109791577, 0.18911101331468672, 0.11104228018666618, 0.2015071059577167, 0.10918607236817479], [0.0334948946692748, 0.008260801259893924, 0.04193667606159579, 0.12998220801819116, 0.048481234844075516, 0.05509068330866285, 0.030662684730486944, 0.10264773649396375, 0.06690340334898792, 0.0490749938035151, 0.06980298916460015, 2.183244335465133, 59.49574068188667, 65.34495681524277, 65.38353994488716, 46.21841333806515, 21.205797605216503, 33.15393917262554, 43.5258512198925, 46.247721165418625, 82.33601868152618, 32.38184340298176, 0.20863218378508464, 0.15010928269475698, 1.217821470927447, 9.818932469934225, 5.958481170237064, 2.008380093611777, 23.34912769496441, 59.7421270608902, 81.12765312194824, 78.11835899949074, 72.0370665192604, 67.46981039643288, 67.46629938483238, 58.43718968331814, 60.99913001060486, 56.85737885534763, 57.58425325155258, 58.24331268668175, 62.20362737774849, 59.8723878711462, 64.32523593306541, 56.187714189291, 56.19842581450939, 51.07657425105572, 55.1581746339798, 54.302779734134674, 56.30156368017197, 52.87183351814747, 52.52544030547142, 52.519227638840675, 51.55077360570431, 49.8276686668396, 49.76724050939083, 49.14183586835861, 49.85300950706005, 47.78529345989227, 48.33007022738457, 47.07535855472088, 47.59859047830105, 45.2687568962574, 48.63706335425377, 47.04779863357544, 50.68164624273777, 53.723664209246635, 53.13169777393341, 52.36768037080765, 54.02390129864216, 50.8167289942503, 51.032462418079376, 52.245524525642395, 55.97674950957298, 54.160287380218506, 60.06127953529358, 57.6602453738451, 57.20710448920727, 56.24978005886078, 61.52464181184769, 62.30978988111019, 61.15947760641575, 56.48879483342171, 65.26828452944756, 59.8914210498333, 66.69568553566933, 53.24357517063618, 61.04536212980747, 11.284197494387627, 8.320484776049852, 68.58268707990646, 51.86512693762779, 59.21171732246876, 52.501493990421295, 59.887055084109306, 55.90078018605709, 59.12143796682358, 50.05855567753315, 51.436137557029724, 44.88788813352585, 48.41685377061367, 47.69936867058277, 51.81797906756401, 46.48401528596878, 46.64452247321606, 47.59279578924179, 52.532990500330925, 52.349961921572685, 49.093817844986916, 45.709423050284386, 45.53902879357338, 44.55342248082161, 40.637903586030006, 38.73721517622471, 41.27788424491882, 40.1736368983984, 43.32388445734978, 43.77159923315048, 48.29523369669914, 43.23994696140289, 41.340535283088684, 45.79209141433239, 48.168810680508614, 47.457561045885086, 52.87738122045994, 57.96670272946358, 61.39022782444954, 62.78258331120014, 63.56286384165287, 65.07479131221771, 61.86243608593941, 64.38551589846611, 65.44727772474289, 63.56505632400513, 64.04025882482529, 59.09938395023346, 60.12035496532917, 60.20353630185127, 62.06708550453186, 65.30183672904968, 66.270252764225, 65.04658922553062, 67.48796582221985, 66.75281167030334, 67.97483369708061, 66.1878351867199, 69.02536332607269, 55.833212211728096, 4.857811331748962, 1.4243511948734522, 1.262526665814221, 0.6982878770213574, 0.18066123157041147, 0.2960065210936591, 25.11302724480629, 71.08614474534988, 65.56681171059608, 43.27664539217949, 38.77578690648079, 26.857908815145493, 7.499760165810585, 24.964466616511345, 43.74213561415672, 52.36225426197052, 52.85451024770737, 6.593322604894638, 0.2686669584363699, 0.06817027911893092, 0.013534664994949708, 0.05689855133823585, 0.09650219712057151, 0.057630160517874174, 0.04349621776782442, 0.02509466983610764, 0.04259527275280561, 0.019484532494971063, 0.10782323690364137, 0.05337944661732763, 0.06210101768374443, 0.013688520557479933, 0.07933237313409336, 0.06927353359060362, 0.04527671910182107, 0.004817798217118252, 0.02667427179403603, 0.10300240144715644, 0.03540833691658918, 0.12717390636680648, 3.6207290505990386, 75.17535611987114, 73.05918887257576, 73.49538266658783, 58.560291677713394, 31.88606120646, 38.23416396975517, 46.12355902791023, 52.96148210763931, 90.30660018324852, 34.859470054507256, 0.2920564549276605, 0.10172968497499824, 2.2988398326560855, 13.221705928444862, 9.908381570130587, 3.0795858381316066, 27.624945156276226, 62.63154521584511, 84.14722949266434, 79.05030459165573, 74.4011552631855, 71.13125592470169, 71.45305305719376, 62.4404838681221, 65.01340180635452, 60.34713439643383, 61.052076369524, 61.524793803691864, 66.04114785790443, 63.44298027455807, 66.35292112827301, 59.772438034415245, 59.496667832136154, 57.04733446240425, 58.842544332146645, 54.38050456345081, 58.36189292371273, 54.723135977983475, 56.1931136995554, 53.94158251583576, 53.98868478834629, 52.85020127892494, 53.22784781455994, 50.87691016495228, 53.0192694067955, 48.28674115240574, 50.58453865349293, 49.875299111008644, 48.80439877510071, 47.5019920617342, 51.62953957915306, 48.65073882043362, 51.994168013334274, 54.90299932658672, 56.14392913877964, 55.303668826818466, 56.48958519101143, 53.74676316976547, 53.908459693193436, 56.90258502960205, 58.00633080303669, 57.8239481896162, 61.533746123313904, 59.14694979786873, 61.334948390722275, 59.21582870185375, 62.42039814591408, 63.62195447087288, 63.0191358178854, 58.83137673139572, 66.21243506669998, 64.12854328751564, 67.16684505343437, 59.45984020829201, 59.81737442314625, 15.53447462618351, 15.427313726395369, 61.822146847844124, 54.91826310753822, 59.361524283885956, 56.91390462219715, 60.25991007685661, 59.44730848073959, 60.23463763296604, 54.037876948714256, 52.92652018368244, 47.03637644648552, 49.31491658091545, 49.73606318235397, 53.49158026278019, 48.83957728743553, 48.17519053816795, 51.58542014658451, 55.08496016263962, 55.69993436336517, 51.16134010255337, 47.96721249818802, 47.05626077950001, 46.728258579969406, 43.37679661810398, 42.39651761949062, 42.874106392264366, 42.78122037649155, 44.94951702654362, 46.14130787551403, 48.259040638804436, 44.71718609333038, 45.377176478505135, 48.03979240357876, 49.244156777858734, 49.249286502599716, 54.12740394473076, 60.62413953244686, 64.69659760594368, 64.56504106521606, 63.7765833735466, 65.60230940580368, 63.42383310198784, 66.42679676413536, 67.9812553524971, 65.98149865865707, 66.05982005596161, 61.60075932741165, 60.9087822586298, 64.7745618224144, 65.1128576695919, 68.40766087174416, 68.01106095314026, 67.2561402618885, 71.47634580731392, 69.45904925465584, 71.85643941164017, 68.42567950487137, 72.58293002843857, 60.26063583791256, 7.000584276393056, 0.8546082233078778, 1.2204947462305427, 1.4210121240466833, 0.39472825184930116, 0.4014135181205347, 25.249865502119064, 76.95401787757874, 73.26623976230621, 50.04798844456673, 26.67101964354515, 26.962350010871887, 14.396835621446371, 30.157290771603584, 52.736496180295944, 58.60870108008385, 62.77711160480976, 9.404536206275225, 0.24271543457871303, 0.044159007593407296, 0.08126158601953648, 0.08065600093686953, 0.12479737139074132, 0.032783609203761443, 0.022556190815521404, 0.10612103957100771, 0.03615203568188008, 0.0193575974117266, 0.036151594104012474, 0.18703038746025413, 0.1849375310121104, 0.2397381013724953, 0.24002980993827805, 0.11910748100490309, 0.19921055965824053, 0.13124948454787955, 0.14713117765495554, 0.2688120928360149, 0.10535019304370508, 0.3447050938848406, 5.755169754847884, 90.32469481229782, 84.39474821090698, 86.70022130012512, 65.02820581197739, 31.789825670421124, 47.86727026104927, 65.44252038002014, 62.13449768722057, 100.24593204259872, 40.097416788339615, 0.3591738565592095, 0.45981635455973446, 4.6275427378714085, 14.14842490106821, 16.307301856577396, 4.985832637175918, 29.303007312119007, 67.00974628329277, 84.75823670625687, 84.44134131073952, 78.0865927040577, 75.1832064986229, 74.70165073871613, 64.15816649794579, 66.5739780664444, 62.021092772483826, 63.01640376448631, 64.70506355166435, 71.46680071949959, 67.29900196194649, 70.17654195427895, 63.30881327390671, 62.41281375288963, 58.89493592083454, 62.94005066156387, 59.15519915521145, 63.97549510002136, 58.12923140823841, 60.553679913282394, 57.56013594567776, 56.67146623134613, 55.59826701879501, 54.49943818151951, 53.400027975440025, 56.555371060967445, 52.61095091700554, 54.03741717338562, 50.59896267950535, 53.347400799393654, 50.519862323999405, 54.85186167061329, 50.08945941925049, 54.495455995202065, 58.07499311864376, 58.45828615128994, 55.47093965113163, 59.00810144841671, 55.768486484885216, 56.14387594163418, 57.85117752850056, 60.84845669567585, 60.61340890824795, 63.55445109307766, 59.80614222586155, 62.289958745241165, 57.45779603719711, 66.46684661507607, 65.33994868397713, 66.94870635867119, 61.48711122572422, 69.33219686150551, 63.178803250193596, 72.21539095044136, 57.64871299266815, 66.9227385520935, 12.343165520578623, 10.826409459114075, 72.54740953445435, 54.692300632596016, 65.28008669614792, 56.377126425504684, 65.57003393769264, 60.06450556218624, 65.27560293674469, 54.94032472372055, 57.12274521589279, 49.32122804224491, 53.09676244854927, 52.86253921687603, 56.964012533426285, 51.982977613806725, 50.99352590739727, 54.23567533493042, 58.42319503426552, 55.88205099105835, 52.971027195453644, 49.79664333164692, 50.50378538668156, 50.34523509442806, 45.60026630759239, 43.85562792420387, 46.78731881082058, 46.31213530898094, 49.259146973490715, 48.16308058798313, 53.82755823433399, 48.49402762949467, 48.10249663889408, 51.23325124382973, 52.0705933123827, 52.10826829075813, 58.288408666849136, 64.25178587436676, 68.80163133144379, 68.44252020120621, 68.53724911808968, 69.43906232714653, 66.5014323592186, 68.4937034547329, 69.43850755691528, 69.57811966538429, 70.2244421839714, 64.58768025040627, 67.58711010217667, 67.42042824625969, 67.01505079865456, 71.02121382951736, 69.19942438602448, 69.27953168749809, 75.72585538029671, 71.47396713495255, 74.07960891723633, 71.63416653871536, 76.09943613409996, 63.61831046640873, 7.876949775964022, 3.3566612703725696, 5.412436220794916, 2.086910242214799, 0.5109294306021184, 0.42002999573014677, 32.13799528777599, 85.15035286545753, 77.38872975111008, 60.113234147429466, 54.98760938644409, 35.808647722005844, 14.57511255517602, 36.30749635398388, 64.58610713481903, 68.71479079127312, 73.43342319130898, 11.477601416409016, 0.43195434962399304, 0.19070419657509774, 0.1741794028203003, 0.1822692429414019, 0.28958836861420423, 0.14427438407437876, 0.1171584973053541, 0.13292733201524243, 0.10959438717691228, 0.05886424820346292, 0.3033880703151226], [0.08185141530702822, 0.04994468697987031, 0.020899873052258044, 0.14945559902116656, 0.01971904745005304, 0.10037009269581176, 0.05465077527333051, 0.06606074661249295, 0.0429836683179019, 0.07068127641105093, 0.15420562616782263, 17.719323188066483, 72.88631334900856, 58.31387870013714, 63.125636503100395, 33.941496312618256, 29.65105153620243, 48.80505234003067, 41.91543683409691, 63.50797958672047, 85.25993898510933, 7.643260415643454, 0.1876478988560848, 0.2288299851352349, 0.7629147497937083, 3.789195385761559, 0.39612752676475793, 4.292561737820506, 31.741857044398785, 67.1514330804348, 75.14138594269753, 76.53650388121605, 72.89519727230072, 70.0960622727871, 64.08609956502914, 63.4758485108614, 59.088353142142296, 63.467150777578354, 60.49368113279343, 64.70292046666145, 63.90410453081131, 65.91554939746857, 64.0087129175663, 69.65397119522095, 66.62532091140747, 58.48167769610882, 55.12511260807514, 53.53688523173332, 53.361783027648926, 51.7741484194994, 50.33250957727432, 50.72272203862667, 53.630614802241325, 48.838224560022354, 48.8808810710907, 51.31066828966141, 47.16791018843651, 45.947453677654266, 48.863265216350555, 50.717854499816895, 46.23942621052265, 46.44242651760578, 47.39676050841808, 48.0475477874279, 54.233311861753464, 62.838341519236565, 64.03858691453934, 60.8222571015358, 57.71041788160801, 56.79997153580189, 54.04858097434044, 56.14631921052933, 55.94521500170231, 57.68968619406223, 58.87392684817314, 60.16027942299843, 56.52603663504124, 55.44694013893604, 56.93694658577442, 49.979934096336365, 53.988996371626854, 61.652512550354004, 63.20509023964405, 58.340595066547394, 61.306066140532494, 59.46605287492275, 47.5758258998394, 14.07721197232604, 8.061523921787739, 48.18535499274731, 54.102405086159706, 57.83113740384579, 52.0921191573143, 53.23172740638256, 52.92849987745285, 60.98863497376442, 54.58667390048504, 53.43875549733639, 51.12733192741871, 47.122099846601486, 49.123505651950836, 47.93228857219219, 45.781763568520546, 50.80310292541981, 53.02280701696873, 54.63410675525665, 53.53915750980377, 54.134672954678535, 46.976020485162735, 45.12423925101757, 45.14673784375191, 41.478528678417206, 39.40359681844711, 40.692046880722046, 39.5107776671648, 42.0139579474926, 43.861384615302086, 44.68185178935528, 41.65642373263836, 41.18937559425831, 42.57304474711418, 46.74427092075348, 46.77888326346874, 49.8092320561409, 57.23125979304314, 61.61981910467148, 62.19146803021431, 65.93083217740059, 63.14853027462959, 60.745714008808136, 63.375157713890076, 61.60029195249081, 61.9330020993948, 59.11175228655338, 56.4865605533123, 57.37877547740936, 60.556278973817825, 65.35624980926514, 64.57781597971916, 67.32664927840233, 67.42714628577232, 68.70949387550354, 66.9994792342186, 66.81490033864975, 69.09524917602539, 66.33391454815865, 68.52866917848587, 28.159907050430775, 0.5405274080112576, 1.64793333504349, 1.0449157864786685, 0.3559538855915889, 0.294879317516461, 4.101825747638941, 59.56536814570427, 65.84115698933601, 58.638833463191986, 56.33329197764397, 42.04036273062229, 20.621675848960876, 18.472165390849113, 40.614971816539764, 47.31109410524368, 57.90799967944622, 25.88025737553835, 0.5551600665785372, 0.04980293306289241, 0.07859847813961096, 0.06966982560697943, 0.0378811098926235, 0.037858210926060565, 0.04825943658943288, 0.036708913612528704, 0.017288923845626414, 0.03764913679333404, 0.06489563413197175, 0.045760150387650356, 0.020077855442650616, 0.02350690425373614, 0.09780577951460145, 0.043278048615320586, 0.047095455884118564, 0.020815260795643553, 0.09686958248494193, 0.0451554076425964, 0.15452391846338287, 0.07401664392091334, 24.783108048141003, 83.84150549769402, 64.38753738999367, 74.04122337698936, 40.74300594627857, 28.28641176223755, 31.435868963599205, 50.8379090577364, 66.0203629732132, 94.23261791467667, 8.203093875199556, 0.2616262627998367, 0.47159207111690193, 2.760691987350583, 6.354158213362098, 1.5225556190125644, 6.549615925177932, 35.590486228466034, 71.13834634423256, 78.56862723827362, 78.77393782138824, 75.70095911622047, 70.0308121740818, 67.06218346953392, 66.14635661244392, 63.81426975131035, 66.12614169716835, 62.882863730192184, 67.08750531077385, 66.29593178629875, 67.80281692743301, 68.67071315646172, 72.59004324674606, 67.70982071757317, 61.60307340323925, 55.9649321436882, 54.85098011791706, 56.12932652235031, 55.04437454044819, 52.57532022893429, 55.3343103826046, 55.70808872580528, 52.92945362627506, 51.694611087441444, 51.47698916494846, 49.01985101401806, 47.82336741685867, 51.5379872918129, 54.64943513274193, 49.76073145866394, 49.61888886988163, 48.94710771739483, 51.70350641012192, 57.84980580210686, 62.82431647181511, 66.13677352666855, 62.87255868315697, 60.803261920809746, 61.12695895135403, 58.11056300997734, 59.26803030073643, 57.33994536101818, 60.79703025519848, 61.493453085422516, 63.46949905157089, 56.86184361577034, 58.249133974313736, 56.43469713628292, 52.153033688664436, 54.48053039610386, 64.64007943868637, 63.74308057129383, 63.0362842977047, 62.23694398999214, 63.626692816615105, 47.66653083264828, 16.807231530547142, 13.7553939409554, 45.60131885111332, 56.66885197162628, 59.57824185490608, 55.92827171087265, 53.70083883404732, 57.07304008305073, 61.60592325031757, 57.58348189294338, 56.30664400756359, 55.949679762125015, 51.339048966765404, 52.46380001306534, 51.92805156111717, 48.548383712768555, 51.71557456254959, 53.44500236213207, 55.63368871808052, 56.6203323751688, 57.525139823555946, 49.843038842082024, 48.35533507168293, 46.549877151846886, 45.71047179400921, 40.56484490633011, 42.465214133262634, 42.13654696941376, 44.090804904699326, 45.80473713576794, 46.461611688137054, 44.439667984843254, 44.417860954999924, 45.94026446342468, 49.03973914682865, 48.8621860742569, 51.85934744775295, 61.29651725292206, 64.7525230050087, 63.68556685745716, 66.90874010324478, 65.33387660980225, 62.815728932619095, 66.53253749012947, 64.06269282102585, 63.86883482336998, 61.025709584355354, 59.01242181658745, 59.86996740102768, 63.76828461885452, 66.86324894428253, 67.93682053685188, 70.03298565745354, 69.65717062354088, 70.63183352351189, 69.20303419232368, 69.9258542060852, 72.02672347426414, 70.50420597195625, 71.89846515655518, 33.38892236351967, 0.3566496935673058, 0.41153632337227464, 3.5505902767181396, 0.48303628514986485, 0.30506265233270824, 3.2509979652240872, 64.82750818133354, 69.68543350696564, 68.00584763288498, 45.435814931988716, 38.438547402620316, 19.78036869317293, 22.774260342121124, 50.65184064209461, 52.88392446935177, 68.386769592762, 31.07110943645239, 0.5754654644988477, 0.04824941017432138, 0.052476471828413196, 0.020231780581525527, 0.05310110413120128, 0.04346925183199346, 0.04173704575805459, 0.0578212412801804, 0.011697654681483982, 0.0071417812523577595, 0.027280827234790195, 0.14254077163059264, 0.11579807382076979, 0.09911351793562062, 0.3028541395906359, 0.09808933929889463, 0.23230724385939538, 0.3190151770832017, 0.2553299115970731, 0.19584114983445033, 0.25674397009424865, 0.32399834250099957, 29.22098681330681, 94.72757175564766, 74.97641399502754, 84.14073184132576, 48.64902891218662, 40.75041554868221, 64.30176839232445, 62.227873876690865, 74.23596292734146, 104.53106090426445, 10.332809295505285, 0.30501862813252956, 0.6803600233979523, 4.673097068443894, 10.753688961267471, 2.0685698138549924, 6.7430440708994865, 38.2907809317112, 72.80049115419388, 82.30125054717064, 82.05672606825829, 81.000185161829, 75.50875023007393, 69.49076235294342, 70.0207731127739, 65.17292484641075, 70.45398026704788, 66.58068850636482, 70.87652519345284, 68.25484827160835, 69.92824047803879, 71.6609475016594, 75.9963096678257, 71.13729760050774, 64.52614635229111, 61.00943125784397, 58.00660818815231, 57.85614386200905, 56.3067390024662, 55.728584825992584, 57.39118181169033, 60.00964030623436, 53.93934063613415, 54.49216917157173, 58.052042350173, 50.92427842319012, 50.031907707452774, 54.978812858462334, 55.62271110713482, 51.291353926062584, 50.98478637635708, 50.770713463425636, 54.21983398497105, 60.80849044024944, 64.87553000450134, 69.1841872036457, 64.77230474352837, 63.495808839797974, 63.69119055569172, 60.97664661705494, 62.48544305562973, 58.748381584882736, 62.26273700594902, 66.86118185520172, 64.33728888630867, 59.7916916012764, 56.03360965847969, 58.87468680739403, 55.17494693398476, 60.22132694721222, 65.53674012422562, 67.06010118126869, 63.20842266082764, 67.0841158926487, 62.65171453356743, 54.23046201467514, 17.25954405963421, 11.05518663302064, 53.95150378346443, 56.37399539351463, 63.55950102210045, 54.62570160627365, 57.12674640119076, 57.2098745405674, 67.90589779615402, 60.15764236450195, 59.50478419661522, 56.569897681474686, 52.16024190187454, 53.42319153249264, 53.55988919734955, 50.335203632712364, 55.8341583609581, 56.05193607509136, 58.21472302079201, 58.706549629569054, 59.69185195863247, 52.54015691578388, 52.15565174818039, 50.52365832030773, 47.00441636145115, 43.026854395866394, 46.57782465219498, 44.1604133695364, 46.09414480626583, 49.077782705426216, 51.37641616165638, 47.44863532483578, 46.72412060201168, 48.32312040030956, 52.064065262675285, 52.00698472559452, 54.98146891593933, 64.32870894670486, 68.06721433997154, 67.1116492152214, 70.2785512804985, 68.41642320156097, 66.73192799091339, 67.53695279359818, 69.1260427236557, 67.81561464071274, 65.9826385974884, 61.89279645681381, 63.33863787353039, 66.36556684970856, 70.51403984427452, 68.70380938053131, 73.28281447291374, 72.99948647618294, 74.33035746216774, 70.62887728214264, 75.1042315363884, 74.85766276717186, 72.64396995306015, 72.40187734365463, 38.14408980309963, 0.7429621985647827, 6.490245535969734, 4.236784530803561, 0.8987154846545309, 0.3925425378838554, 5.0964100286364555, 72.88758248090744, 78.13768476247787, 75.57683497667313, 74.2972232401371, 56.96212783455849, 29.790032878518105, 32.90293604135513, 58.68570774793625, 64.48859676718712, 78.21032166481018, 38.60628180205822, 1.0518421023152769, 0.1376755186356604, 0.27539286471437663, 0.13080158358206972, 0.10020808927947655, 0.1673842838499695, 0.1749681425280869, 0.18779606121825054, 0.10455763869686052, 0.10430214693769813, 0.15162091876845807], [0.033382819237886, 0.035398692707531154, 0.08186585750081576, 0.06468205145210959, 0.03896987022017129, 0.056904173106886446, 0.03882640565279871, 0.04642816122213844, 0.03251694070058875, 0.02747015838394873, 0.15790711739100516, 42.94662170112133, 69.68357160687447, 59.18210931122303, 53.42037208378315, 65.72749748826027, 51.85881927609444, 66.8639025092125, 52.535536363720894, 68.86752739548683, 59.933959767222404, 0.7354722660966218, 0.00901113853615243, 0.3926154167857021, 0.4496484564151615, 1.8296242668293417, 1.784786672797054, 11.449348982423544, 44.02898982167244, 70.83304032683372, 77.52796187996864, 74.96781885623932, 69.31433022022247, 66.18550211191177, 63.64123463630676, 64.76155892014503, 61.96120038628578, 61.61381922662258, 63.72085936367512, 68.0045785009861, 68.58964830636978, 70.24396553635597, 73.31410199403763, 65.89846551418304, 64.92045119404793, 65.85581660270691, 62.95369952917099, 55.77058017253876, 52.36858852207661, 49.38578277826309, 50.64564697444439, 49.06204774975777, 50.00743322074413, 50.858161970973015, 49.210251197218895, 49.11898009479046, 47.143682688474655, 47.40920104086399, 48.616890236735344, 49.05713841319084, 46.39008052647114, 46.09590411186218, 46.14392213523388, 51.03084370493889, 59.59427699446678, 64.25788074731827, 61.89379580318928, 62.675626650452614, 61.51555649936199, 63.38922455906868, 59.36299480497837, 58.16542446613312, 59.07546043395996, 60.17460845410824, 59.83125127851963, 61.445332467556, 53.9136578142643, 53.678112253546715, 58.57663080096245, 56.39122746884823, 61.362911090254784, 60.08860386908054, 56.76125921308994, 57.98646166920662, 60.61415746808052, 62.7593095600605, 37.875831797719, 16.275317072868347, 9.154007099568844, 44.717607870697975, 62.483877539634705, 57.11161941289902, 55.962747260928154, 57.11072266101837, 53.737822249531746, 58.184149861335754, 55.49452878534794, 54.93558257818222, 52.64536187052727, 52.76058688759804, 46.77436150610447, 47.33821325004101, 47.81307376921177, 49.01728995144367, 54.591651633381844, 52.90063977241516, 56.178131103515625, 56.138480231165886, 50.57123936712742, 45.067037120461464, 44.62725251913071, 41.81373529136181, 39.94173914194107, 39.06545676290989, 41.85361795127392, 42.80954785645008, 43.69086496531963, 45.05308426916599, 44.8643483966589, 43.016222566366196, 41.96549154818058, 46.60003066062927, 45.2717587351799, 46.588866859674454, 59.089200496673584, 62.67889067530632, 59.95018869638443, 66.69563993811607, 60.142370983958244, 61.0174298286438, 61.20160974562168, 57.89783902466297, 57.33547680079937, 56.567564606666565, 56.52987442910671, 58.61009180545807, 61.23534433543682, 60.143168941140175, 65.6843014061451, 61.563639119267464, 66.5838423371315, 65.00168323516846, 63.945879489183426, 64.95986267924309, 68.34706172347069, 68.13966885209084, 69.32211980223656, 51.000810116529465, 1.6107002017088234, 0.35743503423873335, 0.8131437201518565, 1.0227404139004648, 0.09301896410761401, 0.2878405514638871, 30.59487909078598, 73.6573451757431, 59.90280143916607, 49.310915395617485, 43.69700163602829, 30.522627867758274, 13.897955641150475, 18.790390715003014, 49.19002488255501, 55.34064844250679, 51.34732112288475, 5.4304092563688755, 0.28893646609503776, 0.056459337210981175, 0.08722779282834381, 0.05825533087772783, 0.07387892357655801, 0.054375215840991586, 0.016070558558567427, 0.020805460735573433, 0.04965914195054211, 0.03226280336093623, 0.02507206216250779, 0.08625523798400536, 0.005738191675845883, 0.04910528827167582, 0.05138909560628235, 0.0642353601870127, 0.047127141879172996, 0.04764217010233551, 0.058001839206553996, 0.0472812896623509, 0.15692087734350935, 53.77010151743889, 76.33737176656723, 69.06004786491394, 60.820266008377075, 67.15277060866356, 40.06931349635124, 54.9919031560421, 60.12004718184471, 76.67372971773148, 65.44901803135872, 0.8929240610450506, 0.04131318295549136, 1.0901149548590183, 3.707186048850417, 4.0161507949233055, 3.628593203611672, 13.95032063126564, 49.25196535885334, 71.89373061060905, 81.06076911091805, 75.87536975741386, 72.63541281223297, 69.94135737419128, 66.74318298697472, 66.58569663763046, 64.0984109044075, 65.16993820667267, 65.75449883937836, 68.53459686040878, 73.46566066145897, 74.1610461473465, 75.00169023871422, 69.98114883899689, 70.49966901540756, 68.18196058273315, 65.16160145401955, 59.682835042476654, 55.69887802004814, 52.14764177799225, 53.082574009895325, 51.88337355852127, 54.62478205561638, 52.01469071209431, 50.06462775170803, 51.613774225115776, 49.10371631383896, 51.70104034245014, 51.19110390543938, 51.65150620043278, 48.35422933101654, 47.379311844706535, 48.29363018274307, 53.09434957802296, 62.63566039502621, 65.67790254950523, 64.79615986347198, 65.27928873896599, 65.96954450011253, 66.08578026294708, 61.44957683980465, 60.91847933828831, 61.065052673220634, 62.640710324048996, 63.237517699599266, 63.744019120931625, 58.51435974240303, 58.688166216015816, 59.8316540569067, 60.88267765939236, 64.19542729854584, 61.96818821132183, 57.987350821495056, 59.07470427453518, 62.7545902132988, 67.23702728748322, 39.00096282362938, 16.83911941945553, 14.873442146927118, 45.46182453632355, 64.27124083042145, 58.59441764652729, 59.66030605137348, 58.46631892025471, 58.586130291223526, 60.54878957569599, 59.32198740541935, 57.28397436439991, 55.84217593073845, 55.182014554739, 50.168529376387596, 51.43683671951294, 50.526447370648384, 53.63704025745392, 56.68136849999428, 54.54624027013779, 57.342814207077026, 57.80371427536011, 53.35459001362324, 45.79241439700127, 47.00375899672508, 44.83396142721176, 40.35130396485329, 41.96492537856102, 43.842879608273506, 44.348453879356384, 45.90094797313213, 47.625926211476326, 46.57241754233837, 44.0300689637661, 44.97988119721413, 48.35658140480518, 49.70927841961384, 47.68919661641121, 59.90076094865799, 65.37986174225807, 63.6139103025198, 64.91478189826012, 64.00184288620949, 61.766521632671356, 64.32506874203682, 61.13360859453678, 58.82803291082382, 58.56965057551861, 60.068529546260834, 61.56156063079834, 63.526233807206154, 62.91907578706741, 66.97477295994759, 65.67917928099632, 69.87884312868118, 67.9311816394329, 65.68723484873772, 66.84909090399742, 70.72862192988396, 70.46064510941505, 72.38080367445946, 54.71984915435314, 2.6169749116525054, 0.9175063669681549, 1.7037289473228157, 1.6913773538544774, 0.307039258768782, 0.34112212364561856, 31.80811408907175, 80.36118865013123, 66.0991783440113, 55.82759991288185, 37.95254208147526, 32.83716157078743, 23.477116227149963, 27.31434602290392, 58.3105842769146, 60.9109291434288, 62.18482978641987, 6.950972238555551, 0.24019890086492524, 0.060892741894349456, 0.057573185840738006, 0.09557667959597893, 0.022781595907872543, 0.029225092730484903, 0.06481830234406516, 0.05522212879441213, 0.051209492157795466, 0.02926223722170107, 0.15403588215122, 0.15796245192177594, 0.1212566664617043, 0.09015481584356166, 0.11291590621112846, 0.17835831764386967, 0.12959614279679954, 0.14002756273839623, 0.21018017025198787, 0.2641656843479723, 0.30494732258375734, 66.00178197026253, 87.57474437355995, 76.93432733416557, 71.08447283506393, 78.63015353679657, 65.24896636605263, 91.96135058999062, 69.60920959711075, 85.10855510830879, 74.97275099158287, 1.8705797754228115, 0.10015488471253775, 1.4439670485444367, 4.717201301828027, 9.260868765413761, 7.257981514558196, 15.940651930868626, 52.0697383582592, 73.52196604013443, 83.98064643144608, 81.03480890393257, 75.27956932783127, 74.76641446352005, 71.18557021021843, 72.11323723196983, 68.33325326442719, 67.22201809287071, 68.03472608327866, 72.25097984075546, 74.91095870733261, 74.89556193351746, 72.10066750645638, 72.06988155841827, 73.61290276050568, 73.4601965546608, 68.4520348906517, 61.04612968862057, 57.91170448064804, 53.9760010689497, 57.21509166061878, 54.71392147243023, 56.46253824234009, 56.05699360370636, 53.67851883172989, 53.68012994527817, 51.51593707501888, 54.17640991508961, 55.335765704512596, 54.18625518679619, 52.10470408201218, 49.584755301475525, 52.77036376297474, 56.23546242713928, 68.06763991713524, 69.76819306612015, 68.30705747008324, 68.49484339356422, 67.30746030807495, 69.37301427125931, 65.86938947439194, 62.008735835552216, 63.594706133008, 64.19028997421265, 66.31975650787354, 65.9456741809845, 58.93544174730778, 60.64317651093006, 61.94913603365421, 58.90324987471104, 67.33707591891289, 65.13991981744766, 61.36184334754944, 61.982391849160194, 67.71994337439537, 68.2008683681488, 45.51179185509682, 17.800680622458458, 12.018715180456638, 53.49633000791073, 66.05289682745934, 62.65896074473858, 58.94254356622696, 61.365346759557724, 59.99728336930275, 66.27048075199127, 60.25817357003689, 61.05187118053436, 55.718819350004196, 56.74322158098221, 50.943269804120064, 52.35147424042225, 51.48554250597954, 53.76447781920433, 59.10650856792927, 59.45733994245529, 59.382103979587555, 58.87806102633476, 54.08342130482197, 49.5436605066061, 50.07207155227661, 47.06290662288666, 44.149089977145195, 44.71119001507759, 48.24804022908211, 46.680913120508194, 47.603894993662834, 50.266191735863686, 50.23822903633118, 47.377107962965965, 47.45410703122616, 51.06819190084934, 50.47502852976322, 51.420702785253525, 63.92679691314697, 66.89810827374458, 66.62747919559479, 69.16506662964821, 66.25087380409241, 66.35375708341599, 66.66235372424126, 63.40252764523029, 62.734933868050575, 62.15040743350983, 62.49267786741257, 65.54240942001343, 67.49086886644363, 65.79027771949768, 71.12682536244392, 68.24430763721466, 74.65392529964447, 73.07047426700592, 69.43785399198532, 71.938446611166, 74.44733798503876, 74.9988479912281, 72.12068483233452, 57.214863672852516, 3.6716707795858383, 3.2525264332070947, 8.114426583051682, 1.8081661057658494, 0.6521322287153453, 0.5845120071899146, 38.50154422223568, 89.67122107744217, 73.3556717634201, 65.27906835079193, 58.4557630866766, 44.655944779515266, 25.05455408245325, 33.33842307329178, 67.31995403766632, 70.48788964748383, 73.23499783873558, 10.036825127899647, 0.45154010178521276, 0.224157779593952, 0.1557690344634466, 0.20821417652769014, 0.16818788135424256, 0.09669013859820552, 0.19432644126936793, 0.1328146443120204, 0.1313191425288096, 0.1514781592413783], [0.013811384960717987, 0.10334604550735094, 0.114705372689059, 0.04894552614132408, 0.0563226670055883, 0.023314099853450898, 0.03465122754278127, 0.011107140762760537, 0.0567478211451089, 0.04122929800359998, 2.330895150080323, 55.24193353950977, 66.37182891368866, 47.26284049451351, 38.804843947291374, 55.03079026937485, 37.79920510947704, 50.68109527230263, 50.392443761229515, 85.53126722574234, 32.95928701758385, 0.06542310817167163, 0.07749111216980964, 0.4449519084300846, 3.1370805529877543, 1.4384960546158254, 3.721809801645577, 24.294017292559147, 53.855232149362564, 75.00635638833046, 76.06557995080948, 72.57782310247421, 70.4665119946003, 69.18721944093704, 66.29501983523369, 64.15070369839668, 64.2351883649826, 69.09134298563004, 69.0790544450283, 70.20867303013802, 68.57558146119118, 64.91333797574043, 71.46875381469727, 80.39086505770683, 72.09435224533081, 67.16701984405518, 64.42262470722198, 65.88636696338654, 61.69344015419483, 53.72114114463329, 50.555732399225235, 49.54389609396458, 51.03692337870598, 48.77490855753422, 48.465745747089386, 49.02857534587383, 45.67860670387745, 46.257969215512276, 47.69779555499554, 48.47720593214035, 46.41132138669491, 44.90325830876827, 43.485843166708946, 46.82744085788727, 57.82816596329212, 65.04772156476974, 60.51016464829445, 58.39345023036003, 61.12553782761097, 63.55816729366779, 57.80150659382343, 60.010647252202034, 58.02438743412495, 60.257751792669296, 57.55618795752525, 62.229633182287216, 58.570281341671944, 50.407544150948524, 56.57233715057373, 60.48615373671055, 63.037439435720444, 59.924897253513336, 54.95935410261154, 53.33499066531658, 59.86590161919594, 62.89047472178936, 37.48732164502144, 18.628116622567177, 14.828118178993464, 50.17708271741867, 60.72460234165192, 59.513200744986534, 59.77996543049812, 58.090800270438194, 58.264131769537926, 55.52523113787174, 53.05162467062473, 59.62363801896572, 57.702559903264046, 56.2758694589138, 56.09727144241333, 52.92328655719757, 53.50356101989746, 54.86674167215824, 53.77591900527477, 55.72378568351269, 58.42887572944164, 57.55589917302132, 59.766666144132614, 50.52317574620247, 43.57996791601181, 44.07117135822773, 39.63576816022396, 38.34222637116909, 41.7403232306242, 42.03489102423191, 45.28282754123211, 43.687049970030785, 46.228418201208115, 42.44299292564392, 43.13852660357952, 45.92648260295391, 50.04073843359947, 45.03475405275822, 51.93400204181671, 61.963757649064064, 62.380230501294136, 63.01156662404537, 60.347396582365036, 60.295825749635696, 58.68154317140579, 56.82268671691418, 57.92947992682457, 56.55952423810959, 56.466531828045845, 56.77390493452549, 61.13577827811241, 58.24619673192501, 61.374196484684944, 60.79240970313549, 64.59692895412445, 60.75249284505844, 65.40211334824562, 66.91836878657341, 68.4800773859024, 67.07326367497444, 65.3272345662117, 66.0547511279583, 13.279911205172539, 0.5800323444418609, 3.70091472286731, 1.5557386446744204, 0.30542847176548094, 0.20188101480016485, 7.669101404026151, 61.64353363215923, 69.45490747690201, 54.12287838757038, 57.22809076309204, 31.149681620299816, 10.809644758701324, 13.534981068223715, 34.55592334270477, 46.9737596064806, 62.40320406854153, 22.699921131134033, 1.1787334433756769, 0.1025728760578204, 0.04799074202310294, 0.012506383209256455, 0.08369168179342523, 0.0689742476970423, 0.04682872800913174, 0.021678341436199844, 0.005336911035556113, 0.05664357166097034, 0.01910382001369726, 0.027042453111789655, 0.03952500039304141, 0.0217031607098761, 0.04344417466199957, 0.01493787700383109, 0.03586240141885355, 0.056276115792570636, 0.06137884491181467, 0.015343959803431062, 3.5858329106122255, 69.94479238986969, 71.66397973895073, 59.448965191841125, 47.09511749446392, 61.40071526169777, 36.53151333332062, 57.884121760725975, 57.67390564084053, 92.06690892577171, 37.49590538442135, 0.1860048432718031, 0.13103589444654062, 1.0948738432489336, 3.3654585108160973, 4.999614497646689, 3.7035190081223845, 27.864433005452156, 56.6885881125927, 76.84663563966751, 77.5954082608223, 75.34964516758919, 73.73339429497719, 71.51600047945976, 68.14400061964989, 68.31469506025314, 65.93621268868446, 71.14225253462791, 70.87271019816399, 73.33258420228958, 70.95265030860901, 69.42157566547394, 72.21653088927269, 76.93172067403793, 74.61751565337181, 70.73921576142311, 69.64354455471039, 68.29440414905548, 64.74812284111977, 57.94569365680218, 54.46998976171017, 51.83914393186569, 51.321976482868195, 53.20976838469505, 50.46375833451748, 50.77452465891838, 48.5413920879364, 49.07144844532013, 49.64114807546139, 49.52153429389, 49.05885972082615, 46.63364365696907, 46.0531260073185, 49.17380355298519, 58.96943472325802, 65.86565807461739, 62.781291380524635, 59.646759778261185, 62.05956190824509, 64.65619057416916, 61.960535421967506, 61.866593062877655, 62.33006179332733, 63.388457000255585, 61.0651932656765, 64.09058332443237, 60.61080224812031, 54.02002550661564, 58.96090418100357, 62.11425617337227, 64.89565372467041, 60.750102773308754, 55.618196949362755, 56.73370309174061, 63.87042313814163, 63.28007161617279, 38.755279406905174, 19.02372669428587, 21.02893989533186, 51.304079443216324, 63.55860807001591, 60.90855047106743, 61.57883830368519, 60.2383766323328, 60.64400106668472, 57.650628089904785, 54.19564068317413, 60.88361620903015, 62.46062658727169, 59.592677280306816, 58.465262576937675, 55.587361603975296, 56.34401120245457, 56.797311678528786, 57.498925030231476, 57.10228331387043, 60.98718345165253, 59.00522120296955, 59.03727248311043, 52.386569157242775, 46.15762799978256, 46.886573284864426, 42.03674912452698, 41.57125510275364, 43.24326038360596, 44.812287390232086, 45.33111535012722, 47.007080018520355, 47.787755727767944, 44.89354982972145, 45.89307859539986, 47.36386947333813, 50.2960467338562, 47.145293802022934, 53.21923367679119, 64.30511981248856, 63.66924673318863, 64.10273507237434, 62.60028429329395, 61.74212694168091, 60.63264727592468, 60.16310267150402, 59.65956509113312, 59.179506450891495, 60.11076048016548, 60.08078008890152, 60.277335941791534, 62.00605697929859, 64.6551114320755, 64.41405236721039, 66.95078864693642, 62.97739505767822, 67.01729267835617, 68.58826518058777, 71.4096973836422, 72.14164450764656, 69.55246344208717, 70.78125670552254, 17.15092308819294, 0.2697667322354391, 0.8369479584507644, 2.639390858821571, 0.4938652290729806, 0.3603216918418184, 6.935660010203719, 66.71211585402489, 75.41174903512001, 62.29037672281265, 55.15272192656994, 34.788269475102425, 21.67334731668234, 22.002432458102703, 39.797388687729836, 54.35118153691292, 70.23779466748238, 29.98330570757389, 1.0500351805239916, 0.2065290856990032, 0.12295265201828443, 0.03212829651602078, 0.0937122042523697, 0.07154030492529273, 0.08940924686612561, 0.009102765015995828, 0.02314529279829003, 0.03145254137052689, 0.07317142677493393, 0.1715889957267791, 0.2407914018840529, 0.16946511750575155, 0.14309128193417564, 0.2339845718233846, 0.18824629252776504, 0.11347622028551996, 0.1915695852949284, 0.28905241924803704, 5.735497260466218, 85.66611438989639, 80.81670060753822, 67.97358736395836, 54.34592641890049, 65.4057839512825, 52.205383479595184, 68.85251820087433, 63.57932075858116, 102.38383412361145, 42.79763549566269, 0.20302067161537707, 0.23290826473385096, 3.2746203476563096, 10.509389620274305, 11.162752211093903, 7.611355427652597, 31.339371241629124, 59.7850077599287, 80.96863925457001, 83.05081352591515, 79.73547622561455, 77.17537119984627, 76.41682550311089, 72.37370565533638, 72.83870190382004, 67.72942006587982, 74.47407335042953, 73.97753119468689, 78.83894473314285, 72.9162709414959, 71.61731824278831, 75.15159979462624, 75.19438549876213, 75.38578882813454, 73.23813647031784, 71.57458573579788, 71.39717325568199, 68.97183179855347, 59.73944440484047, 58.05773824453354, 53.09775039553642, 56.169144585728645, 56.79445423185825, 52.35273577272892, 53.71844708919525, 50.71208640933037, 51.42780840396881, 51.96660429239273, 53.00784341990948, 52.12209954857826, 50.23757167160511, 49.21528212726116, 52.261061891913414, 61.69490307569504, 68.98393794894218, 65.79394072294235, 60.069354102015495, 64.100721180439, 68.74947533011436, 63.17321754992008, 63.34238067269325, 64.18098047375679, 66.14568024873734, 63.99933502078056, 65.62801122665405, 62.061632797122, 54.79951947927475, 59.67637158930302, 64.49474483728409, 70.02778753638268, 64.10275787115097, 59.08898390829563, 58.59960436820984, 66.84966087341309, 67.6673997938633, 45.734041929244995, 19.50403992086649, 17.368362620472908, 55.59452801942825, 64.0236385166645, 65.32484829425812, 64.96496200561523, 61.66007414460182, 61.52564875781536, 60.5680051445961, 56.40052177011967, 63.70486222207546, 63.278532698750496, 60.16756363213062, 59.276253059506416, 58.02733227610588, 59.30767357349396, 59.557122588157654, 60.43153166770935, 60.8603348582983, 63.26117902994156, 62.50764146447182, 62.283107712864876, 55.80567508935928, 46.37899272143841, 49.32990297675133, 45.16627639532089, 44.20780062675476, 47.925927713513374, 47.10757702589035, 47.881527096033096, 48.54058653116226, 50.62695197761059, 47.546879053115845, 49.235941618680954, 50.66445216536522, 54.850615337491035, 49.18070398271084, 57.6926576346159, 66.63324728608131, 66.75470396876335, 67.86640271544456, 64.63628724217415, 64.78359013795853, 64.06897008419037, 63.111847043037415, 63.35183076560497, 62.930026799440384, 62.38360472023487, 64.10141274333, 65.49139335751534, 64.28805112838745, 68.03385972976685, 66.25836700201035, 71.14647790789604, 64.7443762421608, 70.45572817325592, 71.77434861660004, 75.69391429424286, 75.07978364825249, 71.51540771126747, 71.50944203138351, 19.90255493670702, 1.0453363764099777, 12.598851900547743, 3.2882865518331528, 1.9048715103417635, 0.3754153131740168, 9.344714116305113, 76.52012676000595, 82.28031367063522, 70.57150796055794, 74.08077165484428, 44.132427871227264, 20.474264658987522, 22.79551450163126, 51.111927554011345, 64.30432185530663, 80.3150287270546, 37.979646027088165, 1.4030501316301525, 0.2869588800240308, 0.1933975692372769, 0.18944435636512935, 0.1780136048910208, 0.21653703617630526, 0.2876278222538531, 0.15808955213287845, 0.2232199424179271, 0.15689341787947342], [0.030361962781171314, 0.0201723401187337, 0.16928514669416472, 0.054955508530838415, 0.07771190110361204, 0.0567596843757201, 0.09373115128255449, 0.05207581227296032, 0.2717144542839378, 0.40845237323082983, 21.75303664058447, 82.74923890829086, 61.04449197649956, 52.31883779168129, 24.19964175671339, 22.347446344792843, 42.19990096986294, 64.20602113008499, 56.352834329009056, 79.842030107975, 8.335264082998037, 0.09076190006453544, 0.013042068185313838, 1.0129904933273792, 3.3842399530112743, 1.2776866648346186, 6.321612009778619, 35.69992795586586, 66.61923363804817, 70.96772029995918, 73.37252765893936, 68.91362652182579, 67.74168580770493, 67.18376934528351, 66.36804431676865, 68.90816241502762, 70.62306359410286, 69.98277515172958, 70.39020448923111, 69.9860505759716, 69.65923011302948, 66.82392105460167, 55.29461391270161, 50.568131133913994, 58.46950314939022, 65.2815230190754, 68.26233386993408, 66.23032450675964, 64.19173389673233, 60.41654907166958, 57.04575754702091, 51.89782038331032, 50.21358735859394, 49.591142758727074, 48.57036933302879, 47.47401036322117, 45.72215996682644, 45.71562051773071, 46.52556225657463, 47.67287269234657, 47.139069736003876, 45.84563434123993, 44.43240277469158, 43.31326402723789, 52.5724171847105, 60.0630122423172, 60.7719250023365, 61.92583568394184, 58.675980269908905, 56.275614872574806, 60.084051713347435, 57.73988530039787, 60.78047074377537, 59.563126266002655, 55.7701849937439, 60.01973256468773, 51.3378482311964, 58.234185576438904, 60.978246331214905, 61.635329872369766, 63.19242171943188, 61.02260895073414, 50.05779191851616, 55.128673017024994, 58.38358975946903, 60.56659162044525, 35.09308911859989, 23.53697821497917, 22.337553575634956, 51.28286138176918, 59.294970855116844, 53.37872251868248, 55.7205406576395, 57.007934376597404, 57.4103669822216, 59.29272137582302, 55.70294000208378, 51.80887095630169, 60.07496640086174, 60.93849666416645, 56.11416153609753, 56.76754407584667, 54.39968213438988, 53.50193090736866, 57.037014216184616, 57.33462184667587, 57.44969867169857, 55.41448228061199, 55.63686914741993, 52.13136725127697, 46.11186325550079, 42.324101105332375, 40.4200878739357, 41.24212056398392, 40.074633210897446, 43.336298391222954, 43.04890461266041, 44.88864429295063, 45.67517548799515, 45.64039595425129, 43.4182295948267, 44.65472884476185, 46.20990179479122, 47.40247160196304, 47.0999850332737, 52.08872213959694, 58.202407881617546, 58.92111271619797, 59.62630167603493, 56.78350321948528, 58.40138040482998, 59.60379548370838, 58.27333867549896, 57.27001391351223, 57.357443422079086, 58.320041969418526, 58.199903815984726, 56.30338758230209, 57.15416193008423, 60.15678361058235, 60.101751163601875, 62.61197246611118, 62.47801445424557, 66.84736579656601, 66.22821182012558, 71.81533321738243, 63.789381086826324, 67.11295634508133, 32.28999853134155, 0.20588597020832822, 0.5047519714571536, 1.9210105505771935, 0.04499964568822179, 0.0768244631763082, 0.1480180589715019, 38.94576318562031, 70.36329433321953, 58.493715450167656, 58.66539403796196, 47.137291431427, 17.979607321321964, 17.491466514766216, 29.150016121566296, 45.72007767856121, 55.679825842380524, 48.19755233824253, 4.0704304073005915, 0.16536207986064255, 0.08005310985026881, 0.08921464832383208, 0.05250714108115062, 0.03762263469980098, 0.00909943370061228, 0.025332702571176924, 0.03337063317303546, 0.012665682424994884, 0.08437355965725146, 0.030584729538531974, 0.04629476759873796, 0.08217755952500738, 0.08115366290439852, 0.030385936006496195, 0.11840981765999459, 0.06645168774412014, 0.23741268552839756, 0.6114753009751439, 27.30645764619112, 93.23731452226639, 67.4080865085125, 59.95682694017887, 34.111407995224, 31.268607638776302, 41.58466078341007, 72.49132454395294, 60.578994154930115, 87.54885256290436, 9.211716502904892, 0.14650824858108535, 0.12138496895204298, 2.2420160192996264, 4.77304358035326, 1.2414430221542716, 7.957522552460432, 39.34538014233112, 69.36286881566048, 72.28853702545166, 76.32065266370773, 73.71433451771736, 70.41561752557755, 70.53997725248337, 69.70856666564941, 72.1706597507, 71.80940553545952, 70.93448728322983, 72.7379085123539, 71.91880166530609, 73.31322804093361, 65.79399392008781, 60.91799296438694, 53.227084055542946, 56.92256435751915, 68.82270500063896, 70.50186529755592, 68.09882864356041, 67.28626504540443, 64.17091101408005, 59.1179421544075, 54.81651596724987, 53.05344857275486, 52.56040222942829, 50.14324553310871, 49.79659013450146, 46.74693837761879, 49.12753343582153, 49.13922920823097, 49.01559144258499, 50.4812677949667, 50.51701247692108, 46.74449510872364, 47.17279672622681, 56.73372969031334, 63.3232980966568, 63.853643238544464, 62.437554225325584, 61.43047906458378, 58.38833570480347, 61.08519919216633, 62.315067797899246, 62.85014368593693, 62.0394191890955, 56.047649905085564, 59.69229653477669, 52.787751629948616, 61.767300590872765, 62.83506989479065, 64.40352693200111, 67.08872884511948, 63.19937154650688, 51.82368256151676, 54.84255596995354, 61.886522993445396, 62.8000395745039, 37.45087780058384, 24.23312745988369, 27.410040087997913, 54.72279779613018, 61.864115595817566, 55.22074207663536, 58.9985753595829, 60.32852299511433, 60.475388914346695, 60.34335359930992, 57.988832741975784, 53.37751418352127, 60.387682020664215, 64.95482414960861, 59.81517814099789, 59.095496758818626, 55.46303227543831, 56.92143201828003, 60.01777186989784, 59.320748671889305, 56.53725363314152, 57.50406235456467, 58.67116592824459, 58.03613260388374, 49.439500495791435, 44.14058983325958, 42.73930482566357, 42.52155750989914, 41.34742051362991, 43.8156046718359, 45.552445873618126, 47.599171847105026, 47.1625030785799, 46.90015755593777, 45.08655667304993, 46.51339150965214, 47.48059161007404, 48.61870653927326, 49.690461829304695, 54.7325024753809, 58.89967806637287, 60.56778095662594, 62.83088631927967, 58.96267868578434, 60.85698343813419, 60.049682557582855, 61.85983322560787, 60.583591908216476, 58.672438859939575, 60.71099907159805, 61.38409115374088, 58.76570485532284, 59.61536966264248, 62.41361930966377, 61.68150879442692, 66.23641937971115, 64.2706860601902, 69.90411177277565, 68.82546365261078, 71.7210602760315, 67.03512892127037, 68.07897090911865, 36.77077129483223, 0.19364884559763595, 0.5967899202369153, 1.7985785077326, 0.939958174712956, 0.22542646620422602, 0.14212353620678186, 42.573417127132416, 76.55062392354012, 66.87572747468948, 62.33338661491871, 46.715316474437714, 19.150763377547264, 19.714883007109165, 37.35092036426067, 53.978869915008545, 62.68515653908253, 57.53259502351284, 4.804224707186222, 0.1267450489103794, 0.1018696985556744, 0.05180717336770613, 0.0588240831712028, 0.027938616840401664, 0.061878599735791795, 0.0330004016723251, 0.08933638280723244, 0.026468320247658994, 0.1321296123205684, 0.07578392760478891, 0.2419780514901504, 0.21893248107517138, 0.19948755885707214, 0.13368651940254495, 0.21914804528933018, 0.20577959076035768, 0.45912482135463506, 0.7604565192013979, 34.26351763308048, 104.83712688088417, 76.64830148220062, 70.13067841529846, 35.66650874912739, 34.26425859332085, 55.55086836218834, 83.09031620621681, 70.39344191551208, 97.99514561891556, 12.407345026731491, 0.29789573221933097, 0.39987273048609495, 6.837433381006122, 11.826474945992231, 6.354705858975649, 12.772561479359865, 41.1939961463213, 71.89252987504005, 73.98001626133919, 79.78538274765015, 75.70696279406548, 73.60411763191223, 75.17094835639, 73.72850775718689, 73.17038610577583, 75.7759290933609, 74.16128933429718, 76.87855392694473, 74.06896188855171, 75.03347933292389, 65.40258452296257, 62.878319174051285, 58.81620414555073, 60.66122554242611, 68.11137557029724, 72.98766151070595, 71.56985878944397, 69.85361248254776, 67.5614158809185, 61.786595955491066, 58.01369860768318, 54.94545064866543, 55.53200997412205, 52.968542128801346, 51.69801950454712, 49.456804767251015, 51.77158735692501, 53.234501257538795, 51.3850113004446, 52.37653389573097, 51.555196568369865, 49.5769277215004, 49.37902674078941, 59.08750578761101, 64.27390828728676, 67.86629632115364, 64.99227494001389, 62.72640332579613, 59.60876561701298, 66.22690469026566, 63.77052649855614, 65.84110379219055, 63.96376892924309, 57.20461182296276, 60.32429002225399, 54.44426894187927, 64.30219396948814, 65.4156482219696, 65.29646381735802, 71.34760111570358, 66.35607495903969, 52.58260823786259, 57.45798222720623, 65.28258696198463, 66.3528223335743, 42.29569002985954, 24.203703738749027, 24.53938152641058, 58.275287970900536, 65.35105168819427, 59.449660554528236, 60.63378341495991, 65.04439294338226, 62.82054327428341, 64.69021394848824, 60.34720279276371, 55.01839153468609, 62.49772399663925, 68.69077607989311, 62.328693866729736, 61.877585873007774, 58.790981099009514, 59.423058182001114, 62.45107389986515, 61.20975650846958, 59.72148656845093, 60.151916071772575, 61.011836528778076, 59.29190441966057, 51.85797952115536, 46.12126775085926, 46.07779808342457, 47.16877654194832, 45.34216895699501, 48.60717795789242, 48.58654126524925, 49.487803503870964, 50.04716008901596, 50.51817521452904, 49.16888661682606, 50.04198856651783, 49.8089774698019, 51.101413518190384, 53.456101566553116, 56.67990177869797, 63.48210297524929, 64.75798711180687, 65.90121656656265, 62.151281386613846, 63.99881064891815, 63.74360114336014, 64.67477917671204, 63.43093492090702, 62.545867413282394, 63.820448219776154, 65.48814833164215, 60.86949236690998, 63.855246752500534, 65.9554472565651, 68.17193672060966, 69.29894104599953, 67.80618354678154, 71.67223289608955, 70.5779904127121, 76.19435504078865, 69.44514200091362, 68.64843115210533, 39.955745190382004, 0.7312788348644972, 6.339062098413706, 6.424945089966059, 1.3199129677377641, 0.17691003129584715, 0.25028636504430324, 49.60758827626705, 82.9660476744175, 73.16625952720642, 72.62328386306763, 63.556248396635056, 27.024313285946846, 27.95497264713049, 45.28645634651184, 62.7302411198616, 72.85816445946693, 69.68309283256531, 6.456669112667441, 0.37195268960203975, 0.21840873261680827, 0.22140588116599247, 0.1579499541549012, 0.23920130595797673, 0.15545299829682335, 0.08577243381296284, 0.1514590415172279, 0.2044912669225596], [0.035192015711800195, 0.08276768567156978, 0.03563903723261319, 0.022158147330628708, 0.09510972769930959, 0.016817522773635574, 0.016203697996388655, 0.05933749351243023, 0.03459974846919067, 0.4962424765108153, 56.02379098534584, 70.35189494490623, 47.87437967956066, 37.931289821863174, 14.590559676289558, 20.673535466194153, 59.15647588670254, 42.89995640516281, 64.57992866635323, 59.85247693955898, 1.9757019658572972, 0.05029966734582558, 0.43974571279250085, 0.5754189169965684, 1.407324189785868, 2.229692805558443, 10.528652686625719, 55.107048377394676, 64.8233588039875, 69.79333251714706, 73.90083611011505, 72.18245431780815, 69.44218575954437, 70.14767110347748, 72.65551373362541, 73.53369981050491, 74.99832361936569, 70.96283376216888, 68.78511741757393, 71.10768958926201, 71.14744305610657, 70.22241309285164, 71.49798944592476, 63.153067231178284, 59.152657091617584, 67.94568926095963, 66.63182616233826, 66.69108778238297, 65.67962765693665, 64.1018383204937, 65.73204964399338, 57.068073749542236, 48.92417594790459, 50.02969242632389, 48.49238991737366, 46.85805581510067, 45.911667197942734, 45.12395426630974, 47.31751196086407, 48.28933261334896, 48.13549026846886, 46.94934591650963, 44.40708853304386, 41.51974506676197, 44.96676430106163, 54.36842881143093, 61.452240496873856, 62.29245901107788, 62.96609826385975, 56.20730213820934, 48.899674862623215, 40.12615844607353, 53.227999806404114, 51.718390211462975, 55.68473897874355, 54.67692285776138, 59.87946689128876, 58.16565625369549, 62.601108849048615, 62.01109170913696, 62.84814119338989, 60.00391401350498, 51.62740409374237, 50.738855972886086, 59.08871412277222, 58.81449043750763, 37.41837814450264, 26.391221657395363, 24.26021620631218, 49.81733322143555, 61.92669443786144, 54.15954262018204, 49.012601003050804, 51.632055044174194, 55.99303923547268, 56.112075448036194, 57.08640396595001, 52.653318643569946, 45.08174613118172, 42.07385033369064, 66.59737721085548, 59.56396222114563, 56.043827310204506, 56.92016288638115, 55.870229825377464, 56.25035382807255, 56.51275634765625, 58.041801899671555, 59.29296836256981, 55.05670107901096, 53.44632089138031, 42.77477592229843, 40.78533947467804, 39.06570374965668, 42.90986627340317, 43.56676362454891, 41.617008447647095, 44.233426451683044, 46.730496659874916, 45.71414239704609, 42.81064219772816, 42.27310784161091, 46.96515306830406, 45.57486467063427, 45.324868485331535, 45.91372288763523, 47.66856752336025, 55.09821005165577, 56.397766917943954, 56.32266774773598, 57.00085535645485, 60.64067244529724, 58.784601241350174, 57.81654238700867, 57.428153827786446, 57.83701948821545, 57.83377446234226, 57.388715744018555, 57.598396092653275, 58.97240236401558, 60.612994730472565, 63.473515436053276, 63.71909625828266, 68.10876131057739, 66.83373972773552, 66.14770174026489, 65.0287301838398, 62.60303534567356, 61.72421470284462, 14.376560859382153, 1.552577333059162, 1.6195855499245226, 1.0119809349998832, 0.22979142260737717, 0.4653094644891098, 10.353872515261173, 67.6364466547966, 63.499479442834854, 54.78373892605305, 59.37913253903389, 44.781528040766716, 24.614476896822453, 14.84827609732747, 33.51356327533722, 53.71919184923172, 50.87450869381428, 18.646785020828247, 0.25838067289441824, 0.05842801750986837, 0.048979405182763, 0.05164345930097625, 0.11749207784305327, 0.057702308404259384, 0.07068934355629608, 0.030105174118943978, 0.033831829714472406, 0.047349058877443895, 0.07522715357481502, 0.02311346950591542, 0.028376660229696427, 0.1415120658930391, 0.047294744799728505, 0.01537895948786172, 0.060292767448117957, 0.0604193518665852, 0.8325062936637551, 65.12370228767395, 78.1977291405201, 57.076072320342064, 46.34998507797718, 26.952060163021088, 27.88236614316702, 60.154549330472946, 52.96794556081295, 69.44836422801018, 67.75734096765518, 1.5516303526237607, 0.16476252843858674, 1.095889457501471, 0.8710489911027253, 1.7737150168977678, 1.308890946675092, 13.151416350156069, 58.01040418446064, 65.75670272111893, 68.78555819392204, 77.35881015658379, 75.14995068311691, 73.98119419813156, 73.33120867609978, 75.63054129481316, 76.88449680805206, 76.12179413437843, 73.38900357484818, 69.71828654408455, 74.95390400290489, 72.46199771761894, 73.3191329240799, 71.82110130786896, 67.71909981966019, 62.52097874879837, 68.99713844060898, 69.29806709289551, 69.94193494319916, 67.9122206568718, 66.9647566974163, 67.60649666190147, 58.47065068781376, 51.96011424064636, 52.58106552064419, 49.874485954642296, 49.6148306876421, 47.73534893989563, 48.083189874887466, 49.77251082658768, 51.32463254034519, 51.29203028976917, 50.09209647774696, 45.33843755722046, 46.0358901321888, 47.61963754892349, 56.408383548259735, 63.350022062659264, 62.94234573841095, 65.88572099804878, 60.537052005529404, 52.37918995320797, 44.25033934414387, 52.05065578222275, 50.407844334840775, 57.84640118479729, 58.96467737853527, 62.10498847067356, 62.77963846921921, 63.196681290864944, 64.7846008837223, 64.62962999939919, 60.18952265381813, 51.21638014912605, 54.79541189968586, 62.190768867731094, 61.75008751451969, 39.77591224014759, 25.369578078389168, 27.390208952128887, 52.66298532485962, 63.769720941782, 56.74723036587238, 52.354248091578484, 54.39313508570194, 58.14626209437847, 57.225685492157936, 60.79129636287689, 55.30797019600868, 45.91522380709648, 42.279510498046875, 62.96121172606945, 60.78517869114876, 59.46925610303879, 58.42739000916481, 55.55108115077019, 56.47346645593643, 55.219168961048126, 58.20583149790764, 60.85027299821377, 58.50589379668236, 57.39511840045452, 45.309236124157906, 43.07121321558952, 41.42788879573345, 44.45767521858215, 45.26941806077957, 44.91013213992119, 46.462846621870995, 47.51215271651745, 46.982073560357094, 44.629498198628426, 43.09547871351242, 48.31619717180729, 46.86899922788143, 48.45799036324024, 47.37382493913174, 50.38690745830536, 55.84800861775875, 58.09017710387707, 58.465631157159805, 61.37846365571022, 62.05393821001053, 59.735857397317886, 60.10323688387871, 60.91540530323982, 60.76553754508495, 59.45560343563557, 59.05702002346516, 58.48719879984856, 61.71978794038296, 63.713620752096176, 64.88362357020378, 68.93457099795341, 71.4616709947586, 69.96695280075073, 68.47240939736366, 67.38594129681587, 64.33001607656479, 68.12862664461136, 19.505478143692017, 0.9510774468071759, 1.2331860652193427, 2.2286236379295588, 0.7868546526879072, 0.2949896006612107, 9.669552985578775, 73.26848924160004, 70.91031298041344, 60.832896530628204, 55.89811272919178, 38.48366618156433, 33.089335039258, 23.45542699098587, 40.31973525881767, 61.1531737446785, 61.452753469347954, 24.693277068436146, 0.5266537587158382, 0.017287066621065605, 0.0682045440771617, 0.030140196067804936, 0.075026024132967, 0.09727781565743499, 0.03392455735593103, 0.01669728742854204, 0.05628915532724932, 0.1275908894604072, 0.11396651272661984, 0.24472902965499088, 0.10195138675044291, 0.225144331343472, 0.12154578493209556, 0.06385429704096168, 0.13675721478648484, 0.1602096899296157, 1.279220951255411, 76.76620155572891, 88.22618141770363, 64.27709251642227, 53.66255968809128, 23.21407724171877, 31.374635249376297, 79.45443570613861, 59.36518348753452, 79.2590881884098, 75.11444538831711, 3.21213745046407, 0.2229116839589551, 3.455222281627357, 3.9002377772703767, 5.943149942904711, 7.851849747821689, 13.646769169718027, 63.82927894592285, 71.10404178500175, 73.75021979212761, 81.65665313601494, 80.3756582736969, 77.22260266542435, 75.7080115377903, 77.97598823904991, 79.29948762059212, 78.77607330679893, 75.52648767828941, 72.87097737193108, 74.96167078614235, 73.76545697450638, 76.21607467532158, 74.4051830470562, 68.47006872296333, 64.52960416674614, 72.28481322526932, 73.42687994241714, 72.23382756114006, 69.8179779946804, 70.76443880796432, 72.38393470644951, 61.4442191272974, 55.969693288207054, 54.46484103798866, 51.82880088686943, 51.986013650894165, 51.05613514780998, 51.094452291727066, 51.718185022473335, 54.87598657608032, 52.28705249726772, 52.809600457549095, 47.31974244117737, 47.88010977208614, 51.544769927859306, 58.9875141531229, 68.36299806833267, 65.34719109535217, 69.9170158803463, 62.088527753949165, 56.71178586781025, 43.58049228787422, 54.399970918893814, 53.74503806233406, 59.035049602389336, 60.90090148150921, 64.64579433202744, 63.090564385056496, 66.68615564703941, 66.38718008995056, 68.93827959895134, 64.48557212948799, 55.833048820495605, 54.84292834997177, 64.08243656158447, 63.7530854344368, 43.62236984074116, 28.66032499819994, 28.587456308305264, 55.683830827474594, 67.51951932907104, 59.08669263124466, 54.84424687922001, 55.468329191207886, 59.8973373323679, 60.20456604659557, 64.66619923710823, 56.51096284389496, 50.76854757964611, 43.99476505815983, 63.29663872718811, 62.464977353811264, 61.39411881566048, 61.08042664825916, 58.704630732536316, 59.143370389938354, 59.240854158997536, 62.62890815734863, 64.58831861615181, 60.240831300616264, 57.900981456041336, 46.46286942064762, 45.97369126975536, 45.788451209664345, 49.17899787425995, 49.3839056789875, 47.51092538237572, 48.20045918226242, 51.53261058032513, 52.76305675506592, 47.11925379931927, 45.8093386888504, 51.45672865211964, 50.23120701313019, 49.92641016840935, 50.12654162943363, 52.76742272078991, 59.99142788350582, 62.53826022148132, 62.57619358599186, 64.32086616754532, 65.74118435382843, 63.77485066652298, 64.11553278565407, 64.55622553825378, 64.45946753025055, 63.59200447797775, 64.35732901096344, 60.93634597957134, 63.767007887363434, 67.2021147608757, 69.20514687895775, 70.37355378270149, 73.89569878578186, 72.19189301133156, 70.50623506307602, 68.66978600621223, 66.42064869403839, 69.82259094715118, 21.611836217343807, 2.5254872208461165, 9.93867164477706, 3.272528797388077, 1.1034408397972584, 0.6728145782835782, 13.203651197254658, 82.35730513930321, 75.85144624114037, 69.65105295181274, 75.88026389479637, 62.61532008647919, 38.085565343499184, 27.132919058203697, 52.95887924730778, 69.12865698337555, 73.96302357316017, 33.07992294430733, 1.0579951596446335, 0.2737611491465941, 0.14564455195795745, 0.11632345500402153, 0.2052701509092003, 0.19012561824638397, 0.14271136169554666, 0.12407718386384659, 0.2001824020408094], [0.043511190597200766, 0.05589442924247123, 0.043334177244105376, 0.04780583592946641, 0.058146558003500104, 0.08252725951024331, 0.0359689775359584, 0.10464130842592567, 0.28236014710273594, 3.703826079145074, 70.09950488805771, 64.03106331825256, 54.58749085664749, 25.3734215721488, 13.209207449108362, 25.72236254811287, 57.40216702222824, 46.40349380671978, 76.46583527326584, 36.9191837310791, 0.07313784459256567, 0.04927600079099648, 0.1402140941354446, 0.6513419898692518, 2.1371376095339656, 1.2954191258177161, 27.37492997199297, 65.39990946650505, 66.67540982365608, 71.04630008339882, 70.48266872763634, 75.06883263587952, 73.1946212053299, 74.02511984109879, 74.02963399887085, 70.65930604934692, 72.31600195169449, 73.47576051950455, 71.03735536336899, 70.46569123864174, 69.85722228884697, 68.42871934175491, 67.58994475007057, 71.95908710360527, 71.21370390057564, 67.19646826386452, 67.57913053035736, 66.32331311702728, 65.76340556144714, 63.34959648549557, 65.55218249559402, 61.51795417070389, 50.769159346818924, 49.21690843999386, 49.086537435650826, 48.287029936909676, 45.05765542387962, 44.6382225304842, 48.39966729283333, 48.002976179122925, 49.25141058862209, 46.52698718011379, 44.03016395866871, 43.11683736741543, 44.23994690179825, 46.911287158727646, 51.96993671357632, 58.437075689435005, 61.230176612734795, 62.836069241166115, 59.60763327777386, 58.04643765091896, 48.112353309988976, 55.093198120594025, 58.98927725851536, 60.913889184594154, 60.950549617409706, 57.246892154216766, 59.00414206087589, 62.63414807617664, 61.808710768818855, 53.71930584311485, 49.95178900659084, 57.48317487537861, 58.83430257439613, 62.579404413700104, 36.506214290857315, 25.47314152121544, 23.269451670348644, 43.266146555542946, 61.03826031088829, 54.64682087302208, 48.547619953751564, 47.18898005783558, 53.87328118085861, 54.749829545617104, 53.48474062979221, 51.78069926798344, 45.79311355948448, 48.30451659858227, 53.11107628047466, 52.43278607726097, 57.71526642143726, 56.70414827764034, 56.801031678915024, 53.44603970646858, 53.90171505510807, 54.16493833065033, 58.218374624848366, 56.076798141002655, 51.40339091420174, 45.93960329890251, 39.37770500779152, 39.9511132389307, 42.54293516278267, 41.03248581290245, 42.0491136610508, 43.86852443218231, 43.59909608960152, 44.40037049353123, 42.42520608007908, 44.834478199481964, 47.61306010186672, 45.14408938586712, 47.23306529223919, 44.48866255581379, 44.39465939998627, 49.82736088335514, 55.512190237641335, 56.594189777970314, 54.39050182700157, 58.06984819471836, 60.53111672401428, 57.91105091571808, 57.71029248833656, 58.27623791992664, 58.970555663108826, 58.65075342357159, 61.267547607421875, 60.024197325110435, 64.52233135700226, 64.19972106814384, 64.60452854633331, 65.39598807692528, 64.38170850276947, 67.56697118282318, 68.85662198066711, 69.50433522462845, 67.86959454417229, 65.43482959270477, 6.382887521758676, 1.404843635391444, 0.7846960122697055, 0.3482576063834131, 0.03509686124743894, 0.4504234960768372, 42.607322707772255, 69.33180928230286, 57.6897431910038, 59.033951461315155, 46.245114505290985, 12.899714056402445, 17.308468334376812, 33.493477553129196, 41.751965805888176, 52.136413380503654, 42.79638156294823, 1.9529595924541354, 0.06763019599020481, 0.05164314017747529, 0.043779399056802504, 0.02297427043231437, 0.03720549575518817, 0.012455280775611755, 0.04340169041824993, 0.050306691773585044, 0.021561920730164275, 0.04720895994978491, 0.032336138683604077, 0.08758723721257411, 0.02446856437018141, 0.05806242814287543, 0.12930103519465774, 0.19075452903052792, 0.17488441342720762, 5.569917345419526, 83.63379344344139, 69.36459392309189, 61.67322523891926, 32.05714322626591, 16.274391822516918, 23.858319371938705, 62.610387951135635, 53.53841654956341, 86.90677061676979, 40.156724005937576, 0.11987472069449723, 0.19631370494607836, 0.5832141393329948, 2.0603931276127696, 1.9403378572314978, 1.9008221151307225, 31.59935899078846, 67.82829836010933, 68.24192136526108, 73.57120379805565, 72.21204712986946, 75.81853240728378, 74.19245526194572, 75.40031164884567, 74.30565878748894, 72.8289820253849, 73.1520102918148, 74.56564083695412, 72.66626715660095, 75.73548406362534, 72.60088786482811, 71.82428553700447, 71.74937635660172, 72.93017819523811, 73.31075817346573, 68.14723804593086, 68.25387552380562, 69.02705803513527, 68.00576403737068, 64.76383119821548, 69.75406542420387, 64.94751334190369, 53.44346724450588, 50.54817460477352, 51.18403248488903, 50.99988676607609, 46.22353546321392, 49.34875376522541, 51.20829038321972, 50.16087658703327, 51.62917099893093, 48.05358946323395, 47.081666216254234, 44.468584433197975, 45.89643381536007, 47.97095529735088, 54.825962260365486, 60.5274423211813, 62.28533439338207, 65.742879062891, 63.753305822610855, 61.878357231616974, 52.713488414883614, 60.55678054690361, 60.83037346601486, 61.393286660313606, 61.78535722196102, 60.208624228835106, 60.513573065400124, 64.39566135406494, 65.09100124239922, 57.31732897460461, 50.28338201344013, 58.6999873816967, 61.32523611187935, 66.65698081254959, 38.76169726252556, 24.092084728181362, 24.878697618842125, 44.56782750785351, 63.58541563153267, 57.79950030148029, 51.79906748235226, 48.94072785973549, 54.567720517516136, 58.205417320132256, 56.39928683638573, 52.02953651547432, 48.90857018530369, 46.88092298805714, 53.21650542318821, 55.74123054742813, 60.19123636186123, 58.45734380185604, 58.5560093075037, 54.37573581933975, 55.740178003907204, 55.183975249528885, 60.13090319931507, 56.89903981983662, 54.25534687936306, 45.703084990382195, 42.00473204255104, 42.278378158807755, 44.96443122625351, 43.23711231350899, 45.08931912481785, 46.97498694062233, 45.52584730088711, 46.945903301239014, 44.08148020505905, 46.842624843120575, 48.162750005722046, 48.09992037713528, 48.974211663007736, 45.36413557827473, 46.67926400899887, 50.181562677025795, 55.44537082314491, 58.33516135811806, 57.63602167367935, 60.40984623134136, 60.460220128297806, 60.38524255156517, 60.49400791525841, 60.32222293317318, 60.61794586479664, 60.89419864118099, 61.84512421488762, 62.43522495031357, 64.32313844561577, 66.56938791275024, 66.76719009876251, 68.10459673404694, 65.75823023915291, 70.75591206550598, 70.93378812074661, 71.5438985824585, 69.03958976268768, 73.27001675963402, 8.869253229349852, 0.8053214836400002, 1.1947478028014302, 1.3710109633393586, 0.2524789661401883, 0.3367427102057263, 45.97798503935337, 74.9346162378788, 66.22254252433777, 61.25596962869167, 44.77120399475098, 22.053207233548164, 23.63629538565874, 41.46614894270897, 49.41285252571106, 61.07268646359444, 50.47098934650421, 2.185069900006056, 0.15948450774885714, 0.0287114560342161, 0.04959312791470438, 0.03795940647250973, 0.027586332325881813, 0.0313604705297621, 0.04304842441342771, 0.06247551282285713, 0.12110914976801723, 0.2299526467686519, 0.09871351518086158, 0.1980698193074204, 0.15778003202285618, 0.25329378491733223, 0.18279716226970777, 0.34704683697782457, 0.42658416903577745, 7.860449161380529, 94.70532774925232, 78.13081473112106, 71.37954980134964, 37.611198797822, 19.56071387976408, 39.5474798977375, 77.6184730231762, 61.92572928965092, 93.15047398209572, 45.918100252747536, 0.29622103145811707, 0.25171508837956935, 0.7969479204621166, 4.202305655926466, 8.512201588600874, 3.6008033948019147, 35.77175930142403, 70.46313017606735, 74.14409145712852, 76.81888952851295, 75.80725461244583, 77.44298323988914, 76.89815327525139, 76.85944855213165, 80.32259792089462, 76.39041692018509, 79.24170792102814, 79.38913241028786, 76.47647470235825, 76.93547487258911, 75.29319539666176, 76.02309063076973, 75.23981586098671, 76.20104268193245, 76.81486934423447, 73.81333440542221, 72.7054962515831, 70.43643280863762, 69.49963867664337, 68.62151339650154, 73.14040571451187, 67.3379422724247, 56.13254874944687, 53.34243446588516, 54.69894267618656, 51.978159472346306, 50.90309835970402, 50.584485456347466, 56.04403629899025, 52.96625465154648, 52.209749445319176, 51.08115680515766, 48.9137265086174, 47.72515028715134, 48.79699297249317, 51.55607812106609, 56.28972351551056, 63.92523139715195, 64.73575830459595, 68.1675061583519, 65.38556903600693, 61.35788016021252, 54.87815625965595, 62.45273061096668, 66.65562808513641, 63.81052315235138, 65.26817053556442, 64.27955478429794, 63.2240854203701, 67.72175967693329, 66.9267663359642, 59.563187062740326, 53.65925006568432, 62.69997574388981, 66.01875185966492, 71.0603441298008, 40.875983610749245, 31.041814908385277, 28.59877970069647, 46.86915121972561, 66.89243137836456, 60.222352892160416, 54.2365986853838, 51.85563124716282, 58.28475706279278, 60.38692206144333, 58.11682887375355, 55.6529650837183, 49.85503099858761, 47.27945700287819, 57.673464864492416, 58.27170856297016, 59.13336172699928, 60.0295702368021, 61.84427686035633, 56.97889253497124, 59.95159462094307, 57.33358070254326, 62.66487702727318, 57.35653147101402, 57.87541262805462, 51.329883858561516, 43.62727917730808, 46.05586566030979, 49.45280738174915, 46.174685284495354, 48.3321563154459, 47.679161354899406, 47.16585069894791, 50.62278360128403, 47.38979168236256, 50.81859089434147, 51.660002544522285, 49.1168712079525, 51.580810993909836, 49.55179966986179, 50.17577938735485, 51.97046108543873, 60.21717756986618, 62.30821296572685, 61.834454387426376, 65.08191213011742, 63.49255621433258, 63.60286809504032, 64.75215822458267, 64.59011971950531, 65.65862238407135, 63.50150853395462, 65.9593914449215, 64.95159432291985, 68.68890658020973, 71.50873526930809, 69.40700724720955, 70.9706461429596, 66.97863355278969, 72.07579404115677, 72.10740074515343, 77.05352693796158, 70.73150977492332, 74.47949945926666, 9.026695881038904, 3.5222953325137496, 8.460066486150026, 1.4576667384244502, 0.33076776831876487, 0.5518147617112845, 53.7105967104435, 81.55622452497482, 72.70870327949524, 75.59912458062172, 60.067279413342476, 22.212485186755657, 28.525939509272575, 45.96359521150589, 58.1327386200428, 67.48765423893929, 61.2729699164629, 3.1923611741513014, 0.24631735926959664, 0.1985010813223198, 0.23201995849376544, 0.17354557901853696, 0.11232175762415864, 0.07711220867349766, 0.1425558966002427, 0.17841279128333554], [0.044573040649993345, 0.07544403881183825, 0.012153751740697771, 0.04670255919336341, 0.03401044610654935, 0.036602593536372297, 0.1732946588890627, 0.03501026003505103, 0.17127848113887012, 12.027719747275114, 76.36758774518967, 56.81487813591957, 47.12395794689655, 24.322099685668945, 30.93649785965681, 43.134498819708824, 53.30766633152962, 50.315558686852455, 81.18046268820763, 19.244506247341633, 0.2637949964264408, 0.479455660097301, 0.4279913997743279, 0.5750422028359026, 0.4584906413219869, 5.550175029784441, 51.89475014805794, 71.46943017840385, 69.91643831133842, 70.85773900151253, 69.53017383813858, 67.76744082570076, 68.7210376560688, 66.98521479964256, 67.61763766407967, 73.75950649380684, 77.89755284786224, 68.2126173377037, 71.2205359339714, 69.77575466036797, 63.634949773550034, 63.28382581472397, 62.9448764026165, 61.762319058179855, 62.51194663345814, 65.26101171970367, 63.159378692507744, 63.99715393781662, 64.22791555523872, 62.14783877134323, 64.46015909314156, 63.0392025411129, 54.6034500002861, 48.16015474498272, 48.479352816939354, 48.38780052959919, 44.97613839805126, 45.68980470299721, 47.93578438460827, 45.65705806016922, 48.967075645923615, 46.415683552622795, 44.06653940677643, 43.586556762456894, 44.071045964956284, 45.457773953676224, 46.956478133797646, 50.81545226275921, 57.00858414173126, 58.78608696162701, 60.92053882777691, 59.90426056087017, 57.70650789141655, 58.050207048654556, 58.720836862921715, 61.90998673439026, 54.943535551428795, 53.20910342037678, 54.93500120937824, 58.18982295691967, 53.459642976522446, 47.421253994107246, 51.258880868554115, 59.166077971458435, 55.002755373716354, 61.03181205689907, 28.036278784275055, 16.440249122679234, 25.44213518500328, 36.05338878929615, 61.93114399909973, 54.7048057615757, 54.59917522966862, 48.0683858692646, 48.35138328373432, 53.090530782938, 58.72398689389229, 53.70761387050152, 52.83676140010357, 48.04072715342045, 47.033363208174706, 58.79750534892082, 54.6995734423399, 57.134760171175, 57.976604998111725, 55.915078818798065, 57.227691784501076, 56.3476400077343, 57.91859731078148, 55.14314644038677, 48.381595462560654, 40.00949710607529, 37.96737268567085, 39.87452834844589, 41.2592576444149, 39.05974566936493, 43.13431262969971, 43.763395473361015, 44.169738069176674, 44.195242300629616, 45.038439854979515, 42.60082505643368, 47.27221839129925, 45.504294857382774, 45.0267668813467, 43.27913425862789, 44.33760926127434, 46.26962698996067, 52.436338886618614, 53.6199601739645, 55.46307407319546, 55.368006974458694, 57.29783222079277, 57.583861872553825, 57.61204116046429, 56.708814427256584, 55.73139287531376, 56.49703659117222, 61.21914200484753, 62.69728548824787, 65.24163275957108, 67.1222734451294, 67.11811646819115, 69.26009193062782, 69.70646157860756, 69.1953282058239, 70.24575904011726, 70.9709121286869, 65.08041501045227, 67.56206184625626, 52.830316945910454, 1.868879129178822, 0.9371981571894139, 2.1187793696299195, 0.25243280455470085, 0.2625036594690755, 16.651586182415485, 69.26091268658638, 62.761080265045166, 54.02965798974037, 63.510601446032524, 49.83135066926479, 17.372834980487823, 18.782014064490795, 43.30266259610653, 47.872316390275955, 62.553421407938, 8.426773622632027, 0.34958435862790793, 0.10187121995841153, 0.07618399715283886, 0.04065492394147441, 0.03215257958800066, 0.06928284012246877, 0.022739256382919848, 0.03894938694429584, 0.044668818518402986, 0.026627008119248785, 0.034659346638363786, 0.04912887001410127, 0.09108632992138155, 0.020511484908638522, 0.12975135556189343, 0.1375135820126161, 0.4004193964647129, 15.405934173613787, 86.97423979640007, 63.03755722939968, 55.72342090308666, 34.50993441045284, 35.455566868186, 42.9250730574131, 61.15198440849781, 58.50979618728161, 90.17806068062782, 19.362537413835526, 0.36796340835280716, 0.4229290026705712, 1.4512792811729014, 1.9697570661082864, 0.5279689631424844, 6.3450083043426275, 54.19988505542278, 78.63471329212189, 73.37527111172676, 73.1975470483303, 71.4262492954731, 69.14695680141449, 69.20843750238419, 70.04499301314354, 70.00178173184395, 74.11503821611404, 79.15046721696854, 71.69706836342812, 72.51818150281906, 73.65292981266975, 64.33366388082504, 67.4650226533413, 66.24103233218193, 66.70165121555328, 64.24318313598633, 67.0319826900959, 66.46654263138771, 66.37535512447357, 66.58511146903038, 66.27807274460793, 66.81669384241104, 66.2449537217617, 55.648192539811134, 51.70215368270874, 50.4318780452013, 50.14787748456001, 45.34322150051594, 47.62371852993965, 50.59450551867485, 49.27740499377251, 48.15453104674816, 48.45226027071476, 47.70019702613354, 47.11263455450535, 47.948559299111366, 48.03498946130276, 48.85346174240112, 51.66389353573322, 60.59637442231178, 63.40046435594559, 63.11943903565407, 62.038096860051155, 61.6538842767477, 61.96775123476982, 61.58098518848419, 64.73874494433403, 58.10693800449371, 54.28963243961334, 57.441582307219505, 60.550336092710495, 55.58643825352192, 49.88382205367088, 53.33607740700245, 60.72463274002075, 56.31466917693615, 64.36257272958755, 29.053434804081917, 17.137200124561787, 25.914392843842506, 37.74604596197605, 66.01955741643906, 57.75072991847992, 56.21568448841572, 49.04386952519417, 52.232096046209335, 55.02831660211086, 61.032819002866745, 57.05721013247967, 54.77354407310486, 51.93660110235214, 50.44300004839897, 60.48639692366123, 58.2895752042532, 58.56978356838226, 58.79685178399086, 58.33276368677616, 60.62870688736439, 58.93389903008938, 57.80599795281887, 57.41880252957344, 51.31121166050434, 42.01977923512459, 41.43733128905296, 42.00883202254772, 42.49334782361984, 42.030863240361214, 44.710867032408714, 45.90372182428837, 46.003097891807556, 46.39112547039986, 46.750544384121895, 45.12854442000389, 49.05548930168152, 47.291715145111084, 47.89614491164684, 46.260454282164574, 47.58256293833256, 47.59949862957001, 53.970954939723015, 56.00003086030483, 58.68522137403488, 56.423407942056656, 60.429897755384445, 59.28332448005676, 59.26044970750809, 58.42210829257965, 59.741971269249916, 61.85558125376701, 64.91527587175369, 66.4414943754673, 69.9580080807209, 68.61592009663582, 69.58505809307098, 70.23875221610069, 71.78950980305672, 69.92031410336494, 74.85422775149345, 71.38502150774002, 68.6912776529789, 68.76218944787979, 68.45345601439476, 3.8235464924946427, 0.05754337376856711, 1.5980675420723855, 1.4776377542875707, 0.19071492803050205, 15.912262704223394, 76.02283984422684, 65.91915920376778, 65.01502051949501, 58.22808310389519, 38.41871626675129, 25.66180519759655, 30.118033178150654, 49.376275688409805, 55.822390392422676, 71.59060567617416, 10.595209915190935, 0.44060823682229966, 0.06458131974795833, 0.07097457317286171, 0.08331165765412152, 0.04230307065881789, 0.04658016419853084, 0.03181365558702964, 0.0755340167961549, 0.17221036629052833, 0.13376098650041968, 0.12251942331204191, 0.1290519704343751, 0.17323792912065983, 0.1296486720093526, 0.31737574317958206, 0.3844026621663943, 0.5541516956873238, 21.264443658292294, 102.61467933654785, 71.58856898546219, 66.78434237837791, 36.21287003159523, 44.85677920281887, 60.70093721151352, 72.08343923091888, 66.807049959898, 96.50846019387245, 24.952153377234936, 0.5335264024324715, 1.5333832567557693, 2.607654961757362, 4.043598147109151, 4.325838927179575, 7.134011741727591, 61.65426425635815, 82.13437110185623, 79.88934516906738, 76.49089112877846, 74.29382622241974, 71.49331569671631, 72.25851863622665, 71.51854634284973, 72.5874137878418, 77.18334317207336, 80.59678360819817, 72.50087723135948, 77.74730890989304, 76.12345084547997, 67.98175692558289, 71.93345367908478, 68.97095784544945, 68.11301708221436, 69.44878220558167, 69.56607431173325, 69.42893967032433, 69.76701512932777, 68.55431780219078, 66.30936786532402, 68.53770509362221, 68.38374495506287, 60.92588514089584, 54.14491340517998, 53.01757849752903, 54.040198624134064, 49.27770517766476, 51.71894498169422, 52.57014110684395, 50.802878737449646, 51.26181811094284, 51.321668699383736, 49.44960035383701, 47.61335648596287, 51.70313782989979, 52.05873794853687, 51.605771854519844, 56.04526363313198, 63.88052299618721, 65.50200998783112, 65.52961930632591, 65.89848831295967, 63.22660468518734, 64.21037569642067, 64.91727456450462, 68.16140368580818, 61.81712731719017, 57.74471864104271, 60.96624277532101, 62.90000461041927, 59.58624802529812, 52.622525095939636, 57.1256672590971, 64.8656277358532, 61.227672547101974, 66.94771841168404, 34.966685101389885, 26.8070200458169, 30.866260528564453, 39.15403760969639, 67.91928827762604, 59.58752855658531, 60.64340449869633, 51.92593887448311, 54.44741137325764, 56.7577899992466, 63.708517625927925, 58.61939750611782, 58.41248340904713, 57.13462717831135, 55.30157893896103, 64.75074470043182, 62.90972828865051, 62.03184239566326, 62.35526584088802, 61.032442823052406, 63.62799994647503, 59.471345990896225, 61.439351588487625, 59.220282062888145, 53.376317247748375, 45.326342806220055, 43.349875062704086, 45.74659265577793, 46.722083911299706, 43.973410204052925, 46.98678530752659, 47.752645611763, 48.04363779723644, 48.72203819453716, 50.19110016524792, 47.81191483139992, 51.33197374641895, 48.611163944005966, 48.82264159619808, 48.748648166656494, 49.57214757800102, 50.0926398485899, 58.315470814704895, 58.56979496777058, 61.57428614795208, 60.400107353925705, 65.17728701233864, 60.96409969031811, 61.52912937104702, 59.538138806819916, 63.648404851555824, 62.72633492946625, 68.88784110546112, 68.7019170820713, 72.87081018090248, 70.37771075963974, 71.92211508750916, 70.98144516348839, 73.77715274691582, 74.2136201262474, 78.37250456213951, 75.32043993473053, 72.97491699457169, 72.06883281469345, 68.96598771214485, 3.738591126166284, 3.2145249098539352, 6.753370491787791, 1.0011601843871176, 0.4248391423607245, 21.472085416316986, 82.73070350289345, 73.26551020145416, 72.47495502233505, 79.45370614528656, 64.51184391975403, 28.041570000350475, 30.29947344213724, 60.4789113253355, 65.28743550181389, 83.69095757603645, 13.761603757739067, 0.6054141512140632, 0.17168378282804042, 0.20001630939077586, 0.2261864996398799, 0.11820426501799375, 0.2328307696734555, 0.09544877044390887, 0.2473998855566606], [0.03097573931881925, 0.05603800142125692, 0.03562900339602493, 0.0407344450650271, 0.05389726531575434, 0.019217262852180284, 0.025455284958297852, 0.11832041112938896, 0.21627879847073928, 27.491357624530792, 71.14419803023338, 57.22008839249611, 43.35382305085659, 18.049077093601227, 22.61645670980215, 41.37915261089802, 51.625572592020035, 67.80801504850388, 71.4305354654789, 3.6938523268327117, 0.3719110699603334, 0.42051844764500856, 1.1461541103199124, 0.28522857755888253, 0.9220080566592515, 23.024091236293316, 70.52770391106606, 74.93489742279053, 72.08162292838097, 72.54173263907433, 74.15846988558769, 75.4573541879654, 66.47128477692604, 58.583470433950424, 68.51691260933876, 70.5623808503151, 64.25079792737961, 67.42814183235168, 65.19944742321968, 64.30242195725441, 59.74432714283466, 55.02425841987133, 53.777412325143814, 53.28694224357605, 54.89902473986149, 56.82712487876415, 58.922723829746246, 64.24004450440407, 63.17311115562916, 64.78761032223701, 66.04066908359528, 62.70618461072445, 51.56083546578884, 48.98759834468365, 46.452856957912445, 46.65242984890938, 42.45200224220753, 46.15038938820362, 48.976183757185936, 46.122916862368584, 47.946123629808426, 45.80833934247494, 44.77318748831749, 43.18497151136398, 41.225678846240044, 41.93913996219635, 45.14399439096451, 44.65762808918953, 47.20459721982479, 58.30096699297428, 57.25386098027229, 62.745660692453384, 58.4282411634922, 59.53010983765125, 58.478356674313545, 54.390376433730125, 48.44352453947067, 48.648113161325455, 51.616320088505745, 49.41732868552208, 47.02737092971802, 52.271104753017426, 57.0462591201067, 61.0808902233839, 57.52886362373829, 60.24558484554291, 16.603041887283325, 10.47615185379982, 26.187136508524418, 31.430074274539948, 59.67124566435814, 56.18136093020439, 56.163277700543404, 46.99334755539894, 47.0884944498539, 53.13615493476391, 56.923590302467346, 57.312070056796074, 59.60452884435654, 53.644446060061455, 60.89011386036873, 54.92815777659416, 57.522951140999794, 54.17608693242073, 55.30418559908867, 55.61812475323677, 58.82799491286278, 55.05130156874657, 56.2893283367157, 52.920527905225754, 45.49535773694515, 40.517275258898735, 40.212436616420746, 39.58101309835911, 40.126675218343735, 40.167177245020866, 44.45419080555439, 41.71524077653885, 46.06238231062889, 44.35554429888725, 44.57323081791401, 41.3336044549942, 43.752117678523064, 46.34959749877453, 48.22184443473816, 44.83930394053459, 45.18276371061802, 45.69251395761967, 49.00610335171223, 49.989391788840294, 54.702822268009186, 54.17239353060722, 52.81275428831577, 54.16847214102745, 58.670603558421135, 57.33268015086651, 61.537682712078094, 62.62670047581196, 67.21333935856819, 64.49764028191566, 67.07467719912529, 64.59885165095329, 66.1729247868061, 65.8739872276783, 66.72501236200333, 63.05039294064045, 67.49631017446518, 63.41303788125515, 69.92073208093643, 66.97820037603378, 68.1041407585144, 31.734810322523117, 0.5078251753002405, 2.7645454555749893, 1.3745812280103564, 0.04345370383816771, 1.3723061000928283, 53.206553757190704, 69.11126911640167, 58.93396742641926, 59.43096175789833, 62.972003147006035, 19.374748058617115, 10.403225217014551, 24.94005862623453, 45.95325596630573, 60.22718243300915, 22.569717317819595, 0.550825746031478, 0.0955653989512939, 0.07839593119570054, 0.08174994887667708, 0.07045842430670746, 0.03358389301865827, 0.02031149280810496, 0.019713269830390345, 0.01969842502148822, 0.05766411377408076, 0.029536351321439724, 0.02809243251249427, 0.02441964013996767, 0.046996535020298325, 0.051727919417317025, 0.16327349818311632, 0.12312523103901185, 33.407491967082024, 83.4550966322422, 63.99982899427414, 50.64709089696407, 22.63753417879343, 28.14234059303999, 43.342138677835464, 60.203745290637016, 74.3430943787098, 77.16203391551971, 4.182385699823499, 0.5955561145674437, 0.30244592868257314, 2.651844690553844, 0.8183335291687399, 0.4512908589094877, 26.80288966745138, 76.02230787277222, 77.50359758734703, 73.89202058315277, 75.61841234564781, 76.9392442703247, 76.81720241904259, 68.8449414074421, 62.691046223044395, 70.62795773148537, 73.74499887228012, 69.76551041007042, 69.40008401870728, 66.46400436758995, 66.70383229851723, 61.33860759437084, 58.1586342304945, 55.11492155492306, 55.57376593351364, 57.335814982652664, 59.320421889424324, 62.50956416130066, 67.18546405434608, 66.46683901548386, 66.57470002770424, 68.95086452364922, 63.22546474635601, 53.723842799663544, 50.245798230171204, 49.28214713931084, 49.26032491028309, 46.51466064155102, 48.83420057594776, 50.69409817457199, 49.33617264032364, 49.77308079600334, 47.88634143769741, 47.163749411702156, 46.78664244711399, 43.7983687967062, 43.828687369823456, 47.01167017221451, 46.106007769703865, 49.17392894625664, 59.807346761226654, 58.93179774284363, 66.08166888356209, 59.89323355257511, 60.79052500426769, 60.75023576617241, 57.798060178756714, 51.1482498049736, 50.806617736816406, 50.08699335157871, 53.04184019565582, 48.186570927500725, 54.397159069776535, 60.21345376968384, 64.70602110028267, 59.56735163927078, 63.78192588686943, 17.17780664563179, 11.80782649666071, 27.175947949290276, 34.153680726885796, 62.92347975075245, 58.139661848545074, 59.35345731675625, 50.497378930449486, 51.18348531424999, 56.353081315755844, 60.321626365184784, 60.64326770603657, 61.10140912234783, 55.91987036168575, 61.95228986442089, 57.693710178136826, 57.59569823741913, 56.845348700881004, 57.460987865924835, 57.78875067830086, 61.78438447415829, 59.53053921461105, 58.35308499634266, 53.63267429172993, 45.40668949484825, 41.84810444712639, 42.01928526163101, 41.550637409090996, 43.29128220677376, 42.77209706604481, 46.74493208527565, 44.475291073322296, 49.16390888392925, 47.749271392822266, 46.203943714499474, 43.598803505301476, 45.998097360134125, 48.40314030647278, 49.23481687903404, 47.70128756761551, 47.21927963197231, 47.89321906864643, 51.24644033610821, 53.33308316767216, 56.07681334018707, 55.83760477602482, 56.37310244143009, 57.660925537347794, 61.14642530679703, 60.25141753256321, 64.62985038757324, 64.85577866435051, 69.20168146491051, 66.75367802381516, 69.92460787296295, 69.02411699295044, 67.47044876217842, 67.98633947968483, 68.24673190712929, 66.54607996344566, 69.91153657436371, 66.91299587488174, 72.79155403375626, 70.58778628706932, 69.5276127755642, 48.92775535583496, 3.189452192746103, 1.1503616720438004, 2.145533259026706, 0.06707734049996361, 1.6526748868636787, 58.02478641271591, 73.73883560299873, 65.74805438518524, 64.36824202537537, 52.98953220248222, 22.233148477971554, 15.01490855589509, 32.75139257311821, 51.458924934268, 67.74858623743057, 28.29480741173029, 0.5424062884412706, 0.2002194500528276, 0.14625762531068176, 0.08789588900981471, 0.050291867373744026, 0.021046476904302835, 0.044116879580542445, 0.02062372732325457, 0.17704992613289505, 0.17296625854214653, 0.15085987601196393, 0.14772312948480248, 0.30851720133796334, 0.1155472056416329, 0.15354440227383748, 0.26268349669408053, 0.26618447445798665, 41.07144132256508, 92.74547651410103, 71.95124432444572, 62.27741181850433, 28.342405557632446, 31.958078742027283, 55.31609795987606, 72.2702220082283, 80.71477487683296, 90.90112388134003, 5.615553371608257, 0.6860789540223777, 1.1742355534806848, 4.339155787602067, 5.405825050547719, 3.4342246083542705, 29.074022099375725, 77.92469099164009, 80.52138045430183, 79.41225036978722, 77.96977177262306, 82.71729782223701, 81.11808523535728, 68.56953978538513, 61.732733845710754, 73.25109377503395, 69.49813395738602, 70.51914677023888, 74.79773998260498, 70.20628675818443, 70.02519607543945, 64.14245054125786, 60.596993789076805, 59.32292215526104, 57.78513707220554, 60.09947508573532, 62.64981083571911, 64.86125037074089, 71.24511301517487, 68.1424655020237, 68.10232445597649, 70.69249346852303, 68.12709912657738, 55.22123605012894, 55.5645552277565, 52.246432676911354, 51.14598512649536, 48.67864452302456, 51.67323723435402, 53.87367635965347, 49.4659660756588, 52.54966780543327, 50.30725993216038, 49.28274750709534, 49.880865812301636, 45.084238797426224, 46.587590128183365, 49.76612716913223, 47.99718528985977, 51.995368748903275, 61.69181764125824, 61.5668423473835, 69.36097651720047, 63.84245663881302, 64.98673483729362, 65.81991612911224, 60.75462833046913, 55.66148042678833, 54.62249077856541, 53.3781373500824, 55.76800011098385, 51.631325483322144, 56.69395722448826, 63.40744078159332, 67.86413043737411, 63.73217135667801, 66.04372411966324, 20.69814294576645, 19.490676037967205, 35.88718190789223, 37.919423058629036, 63.73084522783756, 61.057969853281975, 60.94507411122322, 51.89100354909897, 52.411028444767, 58.17301265895367, 62.823636308312416, 61.23303785920143, 63.03830198943615, 57.391048818826675, 63.78525450825691, 61.27581976354122, 62.33615666627884, 58.98209944367409, 60.0354865193367, 61.05060204863548, 64.16377499699593, 60.58779448270798, 61.202282309532166, 56.63486659526825, 49.32986117899418, 45.37142738699913, 46.61236099898815, 45.98442569375038, 45.067740082740784, 44.371864423155785, 48.64358000457287, 46.02693401277065, 51.66703216731548, 47.97562524676323, 51.09129086136818, 46.29062846302986, 48.03936302661896, 50.86576156318188, 52.82748229801655, 50.1644141972065, 48.824617490172386, 50.17294853925705, 54.29397560656071, 56.998811066150665, 59.6073254942894, 59.40796159207821, 57.756171226501465, 60.98910614848137, 63.47226910293102, 64.04810920357704, 68.06888625025749, 68.10787215828896, 74.55358788371086, 69.94948893785477, 72.22033068537712, 70.12521430850029, 70.87871387600899, 71.33007645606995, 73.52818250656128, 70.29867500066757, 74.1690181195736, 69.99427333474159, 76.4612527191639, 72.14647024869919, 75.78061044216156, 48.072478249669075, 4.271917445585132, 6.328208930790424, 2.9705072287470102, 0.24170780583517626, 2.307454920373857, 65.5773751437664, 81.88243702054024, 73.83500844240189, 77.95653328299522, 80.44155433773994, 29.64740563184023, 18.846779689192772, 42.28178657591343, 60.58304473757744, 78.06165084242821, 37.55395106971264, 0.8090366155374795, 0.2576447295723483, 0.17386885854648426, 0.3488363034557551, 0.1884694118052721, 0.15278373059118167, 0.10420385689940304, 0.09477152358158492], [0.03129843811620958, 0.025699594407342374, 0.018109683514921926, 0.04069704082212411, 0.021537893699132837, 0.01922421306517208, 0.008604734757682309, 0.09553375377436168, 0.060065384532208554, 45.82073427736759, 68.28533783555031, 46.45322173833847, 36.24737598001957, 23.46708096563816, 45.20688861608505, 49.72688667476177, 51.354210153222084, 71.31532564759254, 49.52677421271801, 0.2598406851757318, 0.04841724316065665, 0.5660409608390182, 0.6873528950382024, 1.1040826491080225, 3.3979688538238406, 56.18334822356701, 73.05728137493134, 72.43878856301308, 68.07598426938057, 69.53857138752937, 66.9757229089737, 71.76143690943718, 73.85172754526138, 61.29120513796806, 63.6380960047245, 61.69704996049404, 60.348810106515884, 70.36622017621994, 63.71718876063824, 68.5737195611, 62.870275005698204, 61.17535315454006, 57.50175207853317, 53.84074352681637, 47.46523283421993, 52.200496941804886, 49.373942613601685, 54.51536312699318, 58.079902455210686, 63.64754609763622, 64.98694762587547, 53.310930356383324, 48.57548005878925, 49.41906899213791, 46.34772799909115, 45.3384717553854, 44.565509632229805, 45.80717280507088, 47.47621424496174, 49.73830506205559, 47.24732592701912, 46.94800078868866, 46.402220875024796, 43.5684697329998, 40.66264785826206, 40.0003357976675, 42.39167667925358, 43.61472465097904, 43.91386739909649, 45.65954692661762, 49.94985491037369, 59.17175866663456, 55.60694955289364, 56.80892005562782, 47.84704014658928, 45.314244255423546, 46.695637330412865, 46.78495533764362, 45.496946051716805, 50.4709779471159, 47.1349735558033, 57.51495636999607, 58.21338169276714, 60.36317713558674, 55.35939283668995, 56.04710653424263, 18.435489758849144, 11.928208786994219, 23.194058015942574, 25.112533271312714, 56.67211979627609, 57.38495014607906, 60.23749887943268, 50.43952323496342, 44.46555599570274, 50.81975743174553, 54.035809859633446, 54.90223936736584, 58.80702763795853, 56.903367787599564, 56.47770322859287, 55.38943402469158, 53.66342604160309, 55.8329614251852, 54.02016989886761, 55.66721431910992, 56.62253625690937, 52.70026132464409, 49.492503851652145, 43.748097494244576, 40.180271342396736, 39.07708793878555, 38.55179652571678, 37.868657782673836, 40.66440336406231, 40.94725638628006, 44.32175271213055, 45.12021906673908, 46.98239654302597, 48.1603979319334, 44.11947816610336, 43.646859526634216, 42.30621166527271, 47.34213083982468, 44.761529713869095, 46.24106392264366, 44.80159096419811, 45.927231162786484, 44.29065518081188, 48.47693234682083, 49.45030331611633, 50.780668929219246, 51.90249413251877, 54.020390287041664, 54.71626594662666, 59.303391203284264, 56.50120496749878, 64.15523305535316, 61.129770800471306, 63.39646317064762, 62.9848350584507, 65.16037032008171, 63.13676230609417, 68.49020004272461, 61.96720026433468, 65.59116080403328, 58.99062238633633, 67.59659439325333, 63.8312092423439, 74.05417308211327, 62.2595451772213, 70.44401720166206, 11.557056102901697, 1.0055821971036494, 3.845339035615325, 0.006281384403337142, 0.06590798293473199, 24.14593543857336, 69.89973440766335, 61.19008116424084, 54.62178401648998, 56.82742886245251, 34.54286344349384, 18.278163000941277, 16.18379518389702, 45.84001824259758, 58.53578679263592, 42.828991413116455, 1.1808267747983336, 0.07098965361365117, 0.06227322563063353, 0.13405965641140938, 0.05432275342172943, 0.08103675980237313, 0.05622017641144339, 0.02846789800969418, 0.09190241777105257, 0.07614709757035598, 0.021987444088154007, 0.01301984271776746, 0.03726579154317733, 0.017438531540392432, 0.022826614585937932, 0.08292840517242439, 0.05398300934757572, 54.43908601999283, 77.63165071606636, 55.693410113453865, 41.73321381211281, 29.512237384915352, 33.388052210211754, 46.67298674583435, 59.43224608898163, 79.7514733672142, 53.37794356048107, 0.22505041997646913, 0.05428533062513452, 0.7606204447802156, 2.2629270097240806, 0.9722148219589144, 4.36368347145617, 60.36739870905876, 76.96874588727951, 74.67036321759224, 70.77001690864563, 73.43305081129074, 70.99415928125381, 73.19506958127022, 75.6960041821003, 62.14614786207676, 64.85336199402809, 67.58255034685135, 63.9549458026886, 71.96291729807854, 66.78224489092827, 71.28302738070488, 65.23177608847618, 65.25450646877289, 59.22922298312187, 56.19300730526447, 50.72183668613434, 52.573534324765205, 50.49126125872135, 57.321641743183136, 60.91944828629494, 66.35121122002602, 67.24913343787193, 53.47738802433014, 50.928735584020615, 50.62634401023388, 50.746280774474144, 48.39315444231033, 47.25476212799549, 48.87228213250637, 48.79219003021717, 51.62211857736111, 50.99117763340473, 48.95319499075413, 49.17997062206268, 44.96576875448227, 42.63979196548462, 44.95497353374958, 44.78606879711151, 44.04769241809845, 47.794496566057205, 48.27518977224827, 53.186711221933365, 60.55497944355011, 57.12980903685093, 59.07572261989117, 50.3730496019125, 47.674134224653244, 48.143420442938805, 51.29929170012474, 47.53870189189911, 51.12607039511204, 49.33100491762161, 61.02136641740799, 58.98561045527458, 61.887636333703995, 58.057802841067314, 58.288526460528374, 20.865569561719894, 13.443522825837135, 23.176309168338776, 27.109692804515362, 58.70141990482807, 58.52947533130646, 60.126172453165054, 51.410884112119675, 48.33237290382385, 53.4743519872427, 56.6205869615078, 58.64355280995369, 59.09482419490814, 59.981749802827835, 59.756281301379204, 57.643123492598534, 55.76366454362869, 54.96520198881626, 57.272179797291756, 57.50938966870308, 57.01001286506653, 56.4252470433712, 50.287071615457535, 45.5791812390089, 41.622179970145226, 40.11310614645481, 40.94129450619221, 39.99800272285938, 43.84742796421051, 41.99664227664471, 45.453863963484764, 47.89517976343632, 49.082505851984024, 49.96644861996174, 47.061257511377335, 46.894891038537025, 45.171930491924286, 49.757022857666016, 46.93895347416401, 47.66206607222557, 47.57635027170181, 48.40738087892532, 46.51463024318218, 50.757661163806915, 50.90743012726307, 53.52941483259201, 54.39098060131073, 56.02113492786884, 58.500969260931015, 60.171663612127304, 60.24256020784378, 65.3912079334259, 63.32146279513836, 64.36344668269157, 65.99181890487671, 69.12642270326614, 64.91976723074913, 71.06380954384804, 65.3164355456829, 67.69734978675842, 63.34057576954365, 68.97128462791443, 67.82194510102272, 77.69997105002403, 64.5354862511158, 72.80417695641518, 22.076653875410557, 1.1329923290759325, 2.8877215459942818, 0.11288198264082894, 0.060211966119823046, 25.073399171233177, 79.26327556371689, 65.33905193209648, 64.68168720602989, 52.2860873490572, 34.02371630072594, 18.98704346269369, 20.641833767294884, 52.31649711728096, 67.35375702381134, 49.86928403377533, 1.3435701420530677, 0.09739668545080349, 0.05093784013297409, 0.017473831794632133, 0.13948346459073946, 0.04049240473250393, 0.04317963983339723, 0.01531847537989961, 0.19296822196338326, 0.18227385909995064, 0.13170146732591093, 0.15632831695256755, 0.11006461194483563, 0.15192589693469927, 0.06548447636305355, 0.2647021383745596, 0.19243484042817727, 65.3624738752842, 87.6597610116005, 64.34561803936958, 50.54999090731144, 35.97012385725975, 62.53594994544983, 69.32988658547401, 68.73999863862991, 85.90930134057999, 62.220620065927505, 0.6386029359418899, 0.1570733293192461, 1.5293644974008203, 6.72434052452445, 4.937321115285158, 4.337619720026851, 62.16472126543522, 78.39529573917389, 81.03983223438263, 74.75511386990547, 78.22216182947159, 72.78792142868042, 77.03319802880287, 78.48271384835243, 66.93256482481956, 65.40849700570107, 66.63146138191223, 67.46514424681664, 75.43957874178886, 69.89581301808357, 73.7018483877182, 69.54977318644524, 67.4332943558693, 63.329810947179794, 59.37206871807575, 51.66918285191059, 58.31709712743759, 53.05870749056339, 61.668334901332855, 62.64995902776718, 69.23876747488976, 70.39256796240807, 55.751155614852905, 52.002880945801735, 54.471600875258446, 53.412058129906654, 48.991344943642616, 50.29231533408165, 50.06233647465706, 52.27957829833031, 54.50804851949215, 53.99866305291653, 51.0834176838398, 53.502022102475166, 48.19835789501667, 45.3737186640501, 46.03408142924309, 48.893895372748375, 47.56486728787422, 49.567663818597794, 52.043466567993164, 55.20579367876053, 64.35235887765884, 60.55417388677597, 60.77356271445751, 52.96625845134258, 49.640467911958694, 50.77414087951183, 52.37414002418518, 50.42669132351875, 56.526207625865936, 51.998233795166016, 64.4448459148407, 62.910047471523285, 64.88388195633888, 61.01566672325134, 60.66230848431587, 23.629638142883778, 16.684954091906548, 32.854488641023636, 31.888417080044746, 60.65088249742985, 61.566032990813255, 63.21864031255245, 56.43984206020832, 49.358610436320305, 56.05422355234623, 57.976107224822044, 60.14472305774689, 61.673274636268616, 63.68916526436806, 62.674657702445984, 59.81533773243427, 58.51178728044033, 59.95797447860241, 59.799355790019035, 60.023992136120796, 61.622045785188675, 59.02077756822109, 52.1893635392189, 49.33181047439575, 44.47542406618595, 43.74139465391636, 44.014356806874275, 42.91716568171978, 46.16113141179085, 45.34993954002857, 48.08377504348755, 48.81530039012432, 51.44065551459789, 54.77882198989391, 49.47890818119049, 49.63630333542824, 48.54122869670391, 50.94877950847149, 47.48593412339687, 52.07006894052029, 50.64568877220154, 51.24932058155537, 49.138393253088, 54.319802820682526, 54.86238710582256, 57.04595133662224, 58.18721629679203, 57.680855467915535, 61.61826878786087, 62.350071519613266, 62.26980082690716, 68.35465371608734, 65.18037244677544, 66.6066563129425, 68.21245014667511, 72.54509925842285, 68.453319221735, 75.03381371498108, 68.13120290637016, 70.78998103737831, 64.95958909392357, 73.84146049618721, 71.60082712769508, 83.62945407629013, 66.71371936798096, 77.09071174263954, 21.057261675596237, 4.330246690660715, 9.230954870581627, 0.2699537534499541, 0.21698173106415197, 31.09463207423687, 85.22077828645706, 72.33310103416443, 73.25363203883171, 71.08541518449783, 51.72788590192795, 30.679760836064816, 30.687514320015907, 64.97660458087921, 74.0486253798008, 65.0269366800785, 1.7106913612224162, 0.1900685767759569, 0.18945676507428288, 0.2520171127980575, 0.17985689191846177, 0.18715793295996264, 0.15306328277802095, 0.13130890089087188], [0.02267662282974925, 0.03670366291771643, 0.049364683727617376, 0.02164268309570616, 0.08274249717942439, 0.02472414889780339, 0.04062171654368285, 0.03893527129548602, 0.16640830028336495, 50.90660557150841, 63.204562067985535, 52.00380429625511, 35.25231957435608, 18.97939257323742, 57.155427262187004, 56.52966924011707, 55.03696873784065, 83.10484662652016, 27.50170636922121, 0.14623896771809086, 0.03018133887962904, 0.4665351955918595, 1.0015316144563258, 0.7275824050884694, 32.24250487983227, 83.91693145036697, 71.31632879376411, 75.92064052820206, 68.22764933109283, 67.93922200798988, 68.31239998340607, 70.1744444668293, 69.32857185602188, 66.07331693172455, 61.624618247151375, 48.901878744363785, 66.23462587594986, 71.07555091381073, 66.8982906639576, 67.12488010525703, 64.70821738243103, 66.6114592552185, 65.45673921704292, 66.15786999464035, 58.05080361664295, 48.653980046510696, 48.23554649949074, 48.7639157474041, 49.20565724372864, 50.95366604626179, 49.384996220469475, 47.5069659948349, 46.51008568704128, 45.65513536334038, 47.11185559630394, 47.157384753227234, 43.55048909783363, 46.48582398891449, 47.19346381723881, 50.55078886449337, 45.05750723183155, 45.40937975049019, 44.58400323987007, 43.020945712924004, 40.99590137600899, 40.23037925362587, 40.646365731954575, 41.65224775671959, 43.65349397063255, 44.05217617750168, 43.64825025200844, 47.93442405760288, 46.1326215416193, 46.13229475915432, 42.79431827366352, 45.84584712982178, 46.75874054431915, 46.33762054145336, 46.52112029492855, 47.55604416131973, 47.5919484347105, 59.03583616018295, 60.06353281438351, 60.92646270990372, 53.79601612687111, 62.2391402721405, 33.52020151913166, 19.717292077839375, 24.327259808778763, 18.048070147633553, 53.93284298479557, 57.515321150422096, 56.76775686442852, 50.71535423398018, 45.647664964199066, 48.38929004967213, 55.48428073525429, 57.65809468924999, 59.42953683435917, 55.35944223403931, 56.913908421993256, 54.03589725494385, 54.370199516415596, 46.7764437943697, 49.779635444283485, 48.98227863013744, 48.33631709218025, 45.911093428730965, 42.107535526156425, 37.45869778096676, 38.13113629817963, 37.639974653720856, 38.829386830329895, 37.42079101502895, 37.90204279124737, 42.008885219693184, 44.00112211704254, 43.84421333670616, 47.583718076348305, 44.7361508756876, 45.45641742646694, 42.39859230816364, 43.195504546165466, 46.17706395685673, 45.81503078341484, 45.33370681107044, 46.599004715681076, 46.58948242664337, 45.44983617961407, 45.816611498594284, 46.72365702688694, 46.879224479198456, 46.90405614674091, 51.26450456678867, 52.97867238521576, 57.08480045199394, 57.39995554089546, 61.309033781290054, 63.37716020643711, 63.84170427918434, 63.760381042957306, 63.77650737762451, 61.7488107830286, 59.05348241329193, 55.77881433069706, 56.78878113627434, 56.522913202643394, 62.534506022930145, 65.5382752418518, 69.14155349135399, 69.37676846981049, 64.94711056351662, 44.86633189022541, 1.91732237348333, 1.3806780008599162, 0.13750210840953514, 0.1056332778534852, 5.217080153524876, 59.58920046687126, 64.74192917346954, 54.669266268610954, 59.43635366857052, 52.447848469018936, 17.973115369677544, 25.110506080091, 40.84636799991131, 49.11557547748089, 56.30568265914917, 5.848363554105163, 0.1485802061506547, 0.05369741978938691, 0.057543043512851, 0.004653936648537638, 0.07635408255737275, 0.03176072190399282, 0.03752388452994637, 0.03301573444332462, 0.08010005069081672, 0.06833029357949272, 0.03043019212782383, 0.05041857424657792, 0.03945955410017632, 0.04788028076291084, 0.010901190144068096, 0.33971643657423556, 61.189359202980995, 69.25105601549149, 59.11823473870754, 43.88261407613754, 23.53036466985941, 42.63254955410957, 54.649013355374336, 64.26140695810318, 89.3236993253231, 31.86922810971737, 0.1532756260712631, 0.06196773909323383, 1.3045532419346273, 0.9023369872011244, 0.3549035981995985, 35.45270562171936, 87.25829735398293, 74.99570935964584, 79.05924931168556, 70.73909416794777, 70.99529922008514, 72.2769932448864, 74.39211934804916, 72.49092176556587, 71.03298559784889, 65.15314310789108, 54.37815248966217, 69.15444999933243, 72.21041321754456, 70.18775135278702, 69.5789024233818, 68.38803112506866, 69.57904681563377, 69.3025204539299, 70.22595450282097, 59.898047894239426, 50.888347551226616, 49.99397054314613, 50.679514557123184, 51.46962136030197, 52.54058629274368, 53.53654325008392, 49.863930121064186, 50.00503554940224, 47.54896134138107, 48.39287705719471, 48.451492711901665, 46.3337105512619, 47.53756955265999, 49.01831589639187, 52.97075740993023, 48.92998203635216, 48.239376693964005, 48.43494459986687, 45.61942107975483, 42.33366139233112, 42.49118573963642, 43.6929814517498, 42.35877804458141, 45.300120413303375, 47.94471390545368, 45.827760100364685, 49.236807972192764, 48.75125862658024, 49.32592839002609, 45.71976609528065, 48.92205186188221, 47.62326255440712, 47.978186309337616, 47.886618822813034, 48.710342422127724, 50.83950497210026, 61.81374549865723, 63.27132448554039, 62.12433323264122, 56.08560226857662, 65.55982768535614, 36.193365678191185, 21.80181462317705, 26.852243319153786, 20.814979076385498, 56.4250722527504, 59.861619248986244, 60.11174462735653, 54.297627210617065, 47.05115005373955, 51.41464211046696, 58.60598802566528, 59.29815128445625, 61.0648512840271, 57.28054694831371, 59.38781887292862, 57.024604082107544, 56.12848296761513, 49.24072936177254, 51.43432505428791, 50.283564403653145, 50.68040370941162, 48.315687999129295, 44.51726742088795, 40.30560001730919, 39.98293273150921, 40.51545515656471, 42.751901149749756, 40.69383658468723, 41.201147362589836, 43.49027752876282, 46.50791220366955, 47.685453817248344, 48.67205187678337, 46.98767825961113, 46.57848201692104, 45.00526003539562, 46.23691074550152, 47.90002070367336, 48.238373547792435, 47.77685411274433, 48.664611876010895, 49.102169796824455, 47.61062063276768, 47.705725729465485, 51.06988660991192, 46.98539838194847, 50.04199996590614, 52.36214026808739, 55.21341606974602, 59.948718175292015, 60.14458246529102, 63.41301888227463, 65.66069707274437, 64.91134688258171, 65.84333807229996, 66.6271448135376, 63.28465037047863, 59.482194408774376, 58.68785843253136, 57.17473782598972, 60.4343169182539, 63.61190780997276, 69.85697150230408, 69.70416650176048, 72.19474285840988, 67.27207660675049, 55.18315069377422, 4.134539617225528, 1.8381277355365455, 1.045572201255709, 0.400280169560574, 5.779616218060255, 64.67417880892754, 73.43320280313492, 63.50433938205242, 64.41381677985191, 39.02023918926716, 19.43371519446373, 34.211331233382225, 49.508402198553085, 57.977805733680725, 67.91937947273254, 6.603901237249374, 0.29144100670237094, 0.05998677996103652, 0.15714162174845114, 0.027320201879774686, 0.13297028752276674, 0.011664310914056841, 0.043958790993201546, 0.13931603607488796, 0.1549489315948449, 0.2073633932741359, 0.2360692498041317, 0.13887515582609922, 0.16187915112823248, 0.10517539500142448, 0.24999018874950707, 0.7201444823294878, 72.5115242600441, 76.89067527651787, 68.33509236574173, 50.34349858760834, 30.231276601552963, 78.10993865132332, 78.33688527345657, 68.74730184674263, 101.49563178420067, 36.68569006025791, 0.3891763341380283, 0.2924816164886579, 2.8023755131289363, 7.972838580608368, 3.395071984268725, 34.55786503851414, 91.76537230610847, 78.1247578561306, 82.09077224135399, 73.71963143348694, 74.02179881930351, 76.02420777082443, 77.99512401223183, 73.21289822459221, 72.76562422513962, 64.57060396671295, 53.58810268342495, 72.59329587221146, 74.22550588846207, 71.55783623456955, 71.4945088326931, 71.25794872641563, 71.91459149122238, 74.53553885221481, 71.02462604641914, 62.86516807973385, 53.38289089500904, 53.21591265499592, 51.88542164862156, 54.86199572682381, 56.216512843966484, 55.63921362161636, 52.9703052341938, 51.76629804074764, 49.47247512638569, 50.321235582232475, 50.67642152309418, 49.68272544443607, 50.47270305454731, 52.30575509369373, 56.02390117943287, 50.09334661066532, 49.699756130576134, 50.938124880194664, 47.468527257442474, 45.48290580511093, 44.67070318758488, 45.82070767879486, 45.975689962506294, 49.03765305876732, 49.41774286329746, 48.42950329184532, 53.569491282105446, 51.96775563061237, 52.31553956866264, 48.451116532087326, 50.78275881707668, 51.228695288300514, 49.670053124427795, 49.236671179533005, 52.87421599030495, 51.748712584376335, 64.22401696443558, 67.39181578159332, 65.6175921857357, 57.28389456868172, 67.85693362355232, 39.65257465839386, 25.347930639982224, 33.50180670619011, 25.459399558603764, 58.31330493092537, 61.88607841730118, 62.254183664917946, 58.29741798341274, 51.098860055208206, 54.2241657525301, 62.73943282663822, 63.75854194164276, 65.82962080836296, 59.02754880487919, 60.75862571597099, 58.37543539702892, 59.308433532714844, 50.160150825977325, 55.42068734765053, 54.32037279009819, 53.687528148293495, 51.319533213973045, 47.09254503250122, 42.05986708402634, 42.803137600421906, 42.42597743868828, 45.30442178249359, 43.91308084130287, 43.50592128932476, 47.91492350399494, 48.49723845720291, 49.03873600065708, 52.21263349056244, 49.1471403837204, 51.53715893626213, 47.94974483549595, 48.40859681367874, 50.086385384202, 50.81499248743057, 49.17856849730015, 52.049177661538124, 50.65901465713978, 49.968238323926926, 51.25495947897434, 54.36017945408821, 50.20297072827816, 53.657103180885315, 56.79136119782925, 59.502971693873405, 62.772973626852036, 61.7222236096859, 67.18260660767555, 68.86610627174377, 68.71145457029343, 68.44460248947144, 70.57040601968765, 67.18979582190514, 64.63923588395119, 62.19264216721058, 61.97357252240181, 62.71156892180443, 68.50115865468979, 71.42241910099983, 76.34972870349884, 74.73639607429504, 71.52368366718292, 56.0604590177536, 5.199850928038359, 7.067726198583841, 1.0641393112018704, 0.3730744606582448, 7.656814763322473, 72.85149201750755, 80.12784317135811, 72.2830881178379, 76.24407917261124, 67.63994246721268, 31.00391384214163, 39.47884798049927, 59.99779254198074, 64.59261998534203, 81.67527973651886, 9.39064035192132, 0.500598200596869, 0.17232274229172617, 0.25390825350768864, 0.13026127038756385, 0.20782728010090068, 0.17879605118650943, 0.11631989269517362], [0.024405659933108836, 0.026084321907546837, 0.02568141178926453, 0.039202986226882786, 0.028553306219691876, 0.07998499553650618, 0.034436761707183905, 0.22218246449483559, 1.4077638974413276, 57.33573518693447, 59.342392310500145, 42.93122872710228, 15.24651562795043, 27.36579906195402, 55.85363611578941, 56.51587218046188, 57.577242627739906, 77.32659548521042, 13.140077758580446, 0.17838083440437913, 0.09359927906189114, 0.6164137891028076, 2.382694208063185, 5.1082102954387665, 83.22636410593987, 70.22269427776337, 73.68860989809036, 68.05810242891312, 66.7925575375557, 62.278802543878555, 66.5827251970768, 70.27067810297012, 71.86535373330116, 65.4108452796936, 66.41734287142754, 47.79024079442024, 64.99290570616722, 65.46454399824142, 68.7639981508255, 67.63402238488197, 66.8807128071785, 66.00396305322647, 66.7157332599163, 62.892674803733826, 63.89770567417145, 49.924658462405205, 47.35751621425152, 48.02119620144367, 48.839683681726456, 47.77311131358147, 48.85633058845997, 48.166933581233025, 47.300488874316216, 45.21414242684841, 49.014394506812096, 45.85725411772728, 44.72009293735027, 45.02340026199818, 47.39070363342762, 47.23853699862957, 47.834379225969315, 45.367023423314095, 45.92599242925644, 42.49786198139191, 40.93291215598583, 41.39050640165806, 40.86389645934105, 40.304380282759666, 39.69881437718868, 41.70389838516712, 43.374372348189354, 44.456972256302834, 42.73735173046589, 46.2200016528368, 44.81998957693577, 46.75550691783428, 47.474470138549805, 50.11250138282776, 46.950945630669594, 49.18214030563831, 47.163498625159264, 54.59729813039303, 57.00580649077892, 56.966121420264244, 56.041555032134056, 63.13092581927776, 48.920843526721, 28.940162882208824, 40.04342928528786, 29.042559787631035, 57.08686374127865, 57.74807386100292, 55.79300656914711, 50.94965346157551, 46.123749017715454, 46.45323693752289, 48.4535825997591, 49.967440366744995, 53.12143452465534, 52.08666265010834, 50.03640666604042, 49.08538989722729, 47.257148399949074, 46.08474411070347, 44.81207840144634, 43.36430288851261, 42.33332701027393, 42.03904040157795, 40.22548891603947, 37.9404017329216, 39.89106506109238, 39.192229360342026, 41.52948014438152, 39.261199459433556, 39.19591136276722, 39.33423154056072, 44.761434718966484, 43.25087137520313, 46.66318707168102, 45.11829636991024, 44.85656261444092, 41.26544751226902, 44.253656566143036, 44.66848410665989, 47.92477257549763, 45.52719242870808, 48.38590443134308, 44.649238139390945, 46.95110522210598, 43.76722186803818, 47.33367249369621, 43.66512134671211, 46.57788924872875, 47.0697158575058, 47.88070634007454, 48.59133280813694, 51.70353300869465, 49.962705820798874, 53.50648686289787, 53.2298769056797, 52.97187075018883, 52.408471181988716, 52.27640926837921, 48.72715651988983, 51.450056210160255, 49.15594071149826, 54.020511880517006, 54.99798282980919, 62.135295644402504, 65.50938159227371, 74.3852037191391, 64.25484851002693, 64.01375144720078, 16.59555248916149, 0.7532392221037298, 1.970875037368387, 0.03640413211542182, 0.633714854484424, 42.04402953386307, 68.86707901954651, 55.6789480894804, 50.11197321116924, 63.18521350622177, 24.548261649906635, 10.488172508776188, 31.803736723959446, 52.35791489481926, 70.15143290162086, 13.627321813255548, 0.6440209108404815, 0.1573528815060854, 0.12303071111091413, 0.15764482755912468, 0.03949951504182536, 0.06712636677548289, 0.025405987798876595, 0.05505639608600177, 0.04438787480466999, 0.05078192974906415, 0.07045967853628099, 0.023579796143167187, 0.07312498317332938, 0.03811375092482194, 0.30028948502149433, 2.410230142995715, 70.66087916493416, 67.0664544403553, 50.90086027979851, 26.468063034117222, 33.36539022624493, 45.12262433767319, 63.11082489788532, 64.0185695886612, 85.64032137393951, 13.72846383601427, 0.24644125340273604, 0.20265308587113395, 0.6469518598169088, 0.9313549019861966, 6.22925179079175, 89.93137791752815, 73.25446799397469, 77.3401303589344, 69.52421575784683, 69.43111315369606, 65.18535777926445, 71.40620157122612, 72.10132867097855, 74.8215951025486, 69.01380434632301, 69.58179026842117, 53.35922956466675, 64.67727944254875, 65.96858695149422, 69.85715389251709, 68.57368916273117, 70.52366092801094, 69.98387709259987, 68.58425259590149, 65.06621897220612, 66.42998099327087, 52.55306862294674, 51.357075199484825, 50.05412131547928, 52.271773517131805, 50.017331689596176, 52.14501991868019, 50.720590353012085, 49.42599602043629, 47.763410434126854, 51.32883131504059, 48.16737435758114, 46.45854525268078, 47.374964877963066, 49.84244227409363, 48.87191355228424, 50.69749139249325, 47.8788710385561, 49.02290605008602, 44.01341825723648, 43.14505845308304, 43.73420163989067, 44.8225012421608, 41.8074656277895, 43.814692720770836, 44.24921840429306, 43.72974447906017, 44.470146149396896, 44.46619056165218, 47.21405491232872, 47.85813935101032, 49.25809063017368, 50.392675548791885, 51.76974065601826, 47.40763172507286, 48.94126743078232, 47.52816505730152, 54.18967880308628, 59.67873126268387, 61.09721414744854, 58.865647092461586, 66.24377578496933, 52.41945259273052, 34.785252436995506, 46.28583312034607, 32.75581933557987, 58.69256258010864, 57.97502048313618, 57.750425934791565, 52.956861555576324, 49.16076645255089, 47.0830113440752, 50.14453366398811, 52.7538688480854, 54.16455075144768, 54.309649765491486, 54.33261573314667, 50.649211183190346, 49.7467178106308, 46.068826764822006, 46.425844207406044, 45.49081318080425, 44.509557634592056, 45.22155582904816, 42.01159827411175, 40.71557901799679, 41.493773460388184, 40.61898820102215, 41.98329359292984, 41.17408141493797, 42.35665775835514, 41.21462523937225, 48.18102702498436, 46.01284436881542, 47.95059598982334, 46.95804364979267, 46.92769467830658, 43.8676542788744, 47.63249605894089, 47.150936499238014, 48.94282154738903, 48.390376791357994, 48.97337570786476, 47.267552241683006, 48.2892794162035, 45.89769534766674, 49.15890835225582, 47.57418058812618, 48.8142516463995, 48.0971959233284, 48.72624456882477, 50.621058493852615, 53.9525905251503, 53.46799112856388, 56.04800708591938, 55.35435050725937, 54.049872905015945, 53.90089429914951, 54.81147363781929, 50.994867235422134, 54.79342460632324, 51.47165425121784, 55.62034383416176, 57.39751987159252, 64.52568277716637, 68.09638917446136, 76.25987872481346, 67.57210090756416, 69.7553725540638, 20.644886903464794, 0.0733648898312822, 1.5920030674897134, 0.0815856819099281, 0.7085373520385474, 45.275904312729836, 76.57615095376968, 59.76797707378864, 60.92077061533928, 58.8740636408329, 27.638082951307297, 18.34578987210989, 39.11044254899025, 58.157190307974815, 79.65264067053795, 16.323981061577797, 0.6994165352080017, 0.2015157593996264, 0.11707727666362189, 0.08405807267990895, 0.054998475170577876, 0.040079021055134945, 0.1149796110985335, 0.0992743784445338, 0.098545485525392, 0.13696840032935143, 0.1825555635150522, 0.1460690752719529, 0.16001573705580086, 0.23332952259806916, 0.49636596988420933, 4.10957733169198, 83.76775905489922, 74.33217376470566, 60.30065909028053, 27.318577095866203, 41.8398816883564, 73.06836158037186, 73.909020870924, 70.49079269170761, 94.70674887299538, 17.104331888258457, 0.3058983403025195, 0.40638237493112683, 2.7021976886317134, 5.700342496857047, 4.920348851010203, 92.28691712021828, 75.21604433655739, 78.26038017868996, 73.06413620710373, 72.62636929750443, 68.48814815282822, 74.44741398096085, 75.95156326889992, 76.98296472430229, 71.9655391573906, 67.79718562960625, 51.677348613739014, 68.1188915669918, 65.72457924485207, 71.31789430975914, 70.64606755971909, 72.79815047979355, 71.94292277097702, 71.52638152241707, 68.67037117481232, 69.70193222165108, 54.70115415751934, 53.74112047255039, 51.49505339562893, 55.19078828394413, 52.80751056969166, 55.58684103190899, 52.78544895350933, 51.649522706866264, 50.158459916710854, 55.65070420503616, 51.38619303703308, 49.94113437831402, 51.69241100549698, 54.85531188547611, 50.99992096424103, 53.38329367339611, 48.096652552485466, 50.93180201947689, 45.648265331983566, 44.84648175537586, 47.308077067136765, 46.062112525105476, 44.353617802262306, 46.25078000128269, 48.594064861536026, 47.713203728199005, 50.02773553133011, 46.80175043642521, 48.87146897614002, 52.54232279956341, 52.66667492687702, 52.65305645763874, 56.1884019523859, 51.39550633728504, 53.686635196208954, 50.950250029563904, 59.757938012480736, 62.74289444088936, 63.76534357666969, 60.519181564450264, 69.39053893089294, 55.37326209247112, 37.731032967567444, 48.78611035645008, 35.94840422272682, 61.614104211330414, 60.7535719871521, 61.779459938406944, 55.6515933573246, 51.16065613925457, 50.638165175914764, 51.51864252984524, 56.21566168963909, 57.53154627978802, 58.20180371403694, 56.32768727838993, 53.982513919472694, 53.138081431388855, 47.948361709713936, 47.89237551391125, 46.86731971800327, 48.03739473223686, 46.50074578821659, 45.83336099982262, 43.852732479572296, 44.77556236088276, 44.39165376126766, 45.5368173122406, 43.282155096530914, 45.066326558589935, 43.14215920865536, 51.14337846636772, 47.126807793974876, 50.92286869883537, 49.25262652337551, 49.09353666007519, 47.467250525951385, 49.44120280444622, 49.4995828717947, 52.530520632863045, 50.03910072147846, 52.39841312170029, 49.402593076229095, 50.10913096368313, 47.81979560852051, 51.85457110404968, 50.298132821917534, 53.283936604857445, 52.23812252283096, 53.052270635962486, 54.033244997262955, 58.03645558655262, 57.362466752529144, 58.77463437616825, 60.66481254994869, 57.60943070054054, 55.80721400678158, 57.92498096823692, 54.38505291938782, 57.4885667860508, 53.23099784553051, 59.56331625580788, 61.091601848602295, 66.91834598779678, 71.07948750257492, 79.51270177960396, 70.92083841562271, 71.84316292405128, 19.01335895061493, 3.2155287684872746, 4.81311765499413, 0.24739142507314682, 1.4735248312354088, 52.325840815901756, 81.71705469489098, 67.63783738017082, 68.81108522415161, 79.8564313352108, 37.90111564099789, 21.43699999898672, 48.79523366689682, 65.16595602035522, 93.37303563952446, 22.337492778897285, 0.9218824259005487, 0.36562840396072716, 0.30670671723783016, 0.23509877297328785, 0.19604945584433153, 0.1534309278940782, 0.2542089420603588], [0.03896948059264105, 0.046558289395761676, 0.05583149511949159, 0.059541483933571726, 0.036171331521472894, 0.03383004484931007, 0.0744137448782567, 0.18199029931565747, 7.143871737644076, 60.05528345704079, 50.65976321697235, 40.74941240251064, 16.323549784719944, 26.130097769200802, 50.061124339699745, 53.93569663167, 65.85355192422867, 70.1794146001339, 5.1540391612797976, 0.3433112514903769, 0.26216538855805993, 0.5561008129734546, 0.7315558637492359, 55.762353613972664, 87.76768282055855, 72.13865026831627, 76.58752754330635, 66.16109982132912, 62.33794257044792, 62.02837698161602, 65.23912489414215, 67.25011378526688, 67.2089695930481, 67.791827917099, 63.89687731862068, 56.21262565255165, 72.49187171459198, 64.61728826165199, 68.60933884978294, 64.36345428228378, 68.40595856308937, 65.61507672071457, 67.8100061416626, 65.63178822398186, 63.02460752427578, 53.76269951462746, 49.86963361501694, 46.99779711663723, 48.61549951136112, 47.11015708744526, 47.663741782307625, 46.29965677857399, 46.37619607150555, 46.13715849816799, 43.95335868000984, 43.90135087072849, 44.69659499824047, 44.4282153993845, 46.2850047647953, 47.892098128795624, 45.51519267261028, 46.06865957379341, 44.85398255288601, 43.01607817411423, 41.27044804394245, 40.98851457238197, 39.24218907952309, 41.80036000907421, 40.41236288845539, 40.204897820949554, 43.049786165356636, 40.57112976908684, 42.53432862460613, 44.485922902822495, 45.860457345843315, 47.764542773365974, 45.042992010712624, 45.40400303900242, 41.971499025821686, 43.95694188773632, 42.77626544237137, 45.79487666487694, 46.041985005140305, 53.619371205568314, 54.690138548612595, 60.565162897109985, 51.092727184295654, 33.24566625058651, 48.611369132995605, 37.16231368482113, 49.183789417147636, 55.7956550270319, 54.23515856266022, 49.83076170086861, 46.73783026635647, 45.28029307723045, 45.25158181786537, 43.07420365512371, 44.335257187485695, 44.52092282474041, 43.932205215096474, 41.99079819023609, 44.30504500865936, 42.38600358366966, 44.305595979094505, 43.4431866556406, 41.919643208384514, 39.85348507761955, 38.53871002793312, 38.95794913172722, 40.160702392458916, 40.46764612197876, 39.46895711123943, 40.34570686519146, 41.13082453608513, 42.83679999411106, 45.03198780119419, 43.3683230727911, 44.44164767861366, 43.96450728178024, 45.93252807855606, 42.5178375095129, 44.26150694489479, 45.164391696453094, 44.43005070090294, 45.00229239463806, 45.80572888255119, 46.14973962306976, 47.24970459938049, 45.46943932771683, 47.39382706582546, 46.79349347949028, 44.59502264857292, 46.126089692115784, 48.01515072584152, 47.067827358841896, 46.64589039981365, 47.97974422574043, 47.49147802591324, 46.59505672752857, 46.78511492908001, 48.19252520799637, 49.40792039036751, 48.90431061387062, 51.87206156551838, 51.785422414541245, 55.14485254883766, 50.934575870633125, 57.22626306116581, 63.040399476885796, 67.00747400522232, 70.09235367178917, 66.41209915280342, 37.688099071383476, 1.6835399181582034, 0.8868964563589543, 0.10129558795597404, 0.21274838712997735, 34.81611058115959, 69.74555388092995, 60.68065769970417, 54.84638996422291, 51.71063482761383, 24.447350464761257, 15.336401704698801, 34.392292723059654, 43.020793721079826, 64.88784894347191, 28.32018055021763, 0.5271939234808087, 0.11786295872298069, 0.08660957639222033, 0.023840084031689912, 0.05861516488948837, 0.07766578404698521, 0.030159465932229068, 0.01865323803940555, 0.02823644070303999, 0.060828052592114545, 0.047841013729339465, 0.04506636847509071, 0.06896299673826434, 0.131363938562572, 0.2649730519624427, 8.511873856186867, 73.63876417279243, 57.99458563327789, 48.44702795147896, 21.355961747467518, 28.542943596839905, 45.985964611172676, 62.98451587557793, 71.34090587496758, 79.77438613772392, 5.662885531783104, 0.26803494547493756, 0.7957306201569736, 0.9055229381192476, 1.097743520513177, 62.43432819843292, 89.34394463896751, 75.94663113355637, 78.63921225070953, 69.53661069273949, 65.65897956490517, 65.3653921186924, 69.0763109922409, 70.26942417025566, 69.98766928911209, 71.55009225010872, 65.96199810504913, 61.287595331668854, 72.07846909761429, 68.48457634449005, 69.18828338384628, 67.65312016010284, 69.58458691835403, 68.39109376072884, 70.61300173401833, 67.2664225101471, 65.50987556576729, 56.0232400149107, 50.318936705589294, 49.517286121845245, 50.57680606842041, 50.10746665298939, 49.89845506846905, 48.34688812494278, 47.881895676255226, 47.89218172430992, 48.313286527991295, 47.88295581936836, 48.344843834638596, 48.385953828692436, 48.838061168789864, 48.421155139803886, 48.607440143823624, 46.877655163407326, 46.73026867210865, 46.19150698184967, 44.28893007338047, 42.08599828183651, 42.20187306404114, 43.889921084046364, 42.803642973303795, 41.387390568852425, 43.72683763504028, 45.14262646436691, 45.789678543806076, 46.82139538228512, 47.836317121982574, 51.332121938467026, 48.795940428972244, 48.58356982469559, 46.55205063521862, 47.33147241175175, 46.961425468325615, 48.82603481411934, 51.497416868805885, 55.387583523988724, 56.48169681429863, 61.68114021420479, 53.9290963858366, 36.63077160716057, 53.58714133501053, 41.07210248708725, 51.590766459703445, 58.29859212040901, 57.5023752450943, 51.80451259016991, 48.53508062660694, 50.08228920400143, 45.82747511565685, 45.69186419248581, 46.87439873814583, 47.32346624135971, 46.01423129439354, 45.30053459107876, 45.66836625337601, 44.81330193579197, 45.94544738531113, 45.45324079692364, 41.234300583601, 43.331111669540405, 42.97569774091244, 39.54541280865669, 41.48205488920212, 42.624341994524, 41.249750554561615, 41.72273017466068, 42.57782109081745, 45.950333923101425, 48.112851083278656, 47.58926197886467, 47.18869507312775, 44.97439429163933, 48.12694452702999, 44.10270966589451, 44.222699627280235, 47.414478957653046, 47.85258784890175, 47.623395547270775, 48.50129283964634, 49.26604740321636, 48.942749351263046, 47.349848225712776, 48.55950951576233, 47.67872057855129, 48.6482347548008, 48.76570165157318, 49.05885212123394, 49.12332706153393, 49.572063982486725, 47.83236153423786, 49.06008705496788, 50.20219177007675, 49.452723786234856, 50.62977522611618, 50.58086425065994, 53.11949662864208, 56.51328831911087, 55.43500877916813, 57.8550761193037, 54.18089747428894, 59.06635992228985, 64.92121115326881, 69.60435345768929, 72.89648160338402, 70.93881905078888, 42.850908637046814, 1.6020714584738016, 3.1661570677533746, 0.26043728285003453, 0.250042881234549, 36.85323067009449, 75.18545597791672, 66.69912055134773, 63.5571451485157, 57.859176099300385, 30.549587421119213, 22.82552719116211, 40.329907312989235, 47.290206626057625, 75.51577985286713, 31.966563686728477, 0.4495372233213857, 0.09398665788467042, 0.08879783592419699, 0.10352343364502303, 0.05303232559526805, 0.021683829618268646, 0.0302660902889329, 0.18266054772539064, 0.13293907279148698, 0.11970527353696525, 0.2040485609904863, 0.1255413595936261, 0.10456692296429537, 0.21221012226305902, 0.5392735940404236, 12.764314021915197, 88.92360359430313, 64.86107558012009, 58.240189254283905, 27.631925381720066, 37.50826992094517, 66.03356346487999, 71.65794566273689, 78.25452089309692, 87.7720145881176, 7.417579125612974, 0.3865777188912034, 1.3698074966669083, 3.7642924720421433, 2.1159083861857653, 62.32872426509857, 92.20970526337624, 78.79290640354156, 83.11374574899673, 74.62816268205643, 67.85226747393608, 68.11132997274399, 71.85482069849968, 72.64080092310905, 71.38889729976654, 73.900106549263, 65.41490346193314, 64.88882169127464, 76.9572477042675, 70.01821964979172, 72.1692082285881, 70.85566431283951, 72.86205545067787, 71.25044032931328, 72.96876132488251, 71.20537474751472, 67.43872046470642, 59.634729623794556, 52.146300449967384, 52.481092885136604, 52.61455312371254, 52.92760692536831, 51.63031853735447, 52.0226588845253, 50.674799010157585, 52.1388528496027, 49.01401072740555, 49.07310135662556, 50.888545140624046, 49.978588968515396, 50.56922547519207, 50.70647031068802, 50.88279604911804, 49.58967983722687, 48.62487740814686, 47.2790352255106, 46.27832092344761, 45.9891602396965, 45.219196155667305, 47.92945012450218, 44.37455467879772, 44.37379091978073, 47.32684426009655, 46.14552944898605, 47.301834002137184, 48.86826194822788, 50.04924617707729, 55.250262692570686, 49.337608963251114, 52.23871149122715, 48.245543763041496, 50.27485527098179, 49.82005387544632, 51.5043742954731, 50.70327088236809, 58.135417476296425, 57.32433959841728, 65.28979897499084, 57.47692421078682, 42.36996464431286, 53.71813930571079, 44.651681408286095, 56.0645741969347, 60.74640937149525, 59.841905906796455, 55.34665212035179, 51.080507040023804, 51.44224002957344, 48.63862507045269, 47.93595537543297, 48.585857301950455, 50.44588789343834, 48.0120462924242, 45.81803262233734, 48.401593789458275, 46.57430224120617, 48.91572140157223, 48.19173105061054, 44.30908799171448, 45.95433510839939, 43.12110833823681, 43.406837806105614, 44.541635513305664, 47.251756489276886, 43.61287795007229, 45.02827540040016, 44.895723313093185, 47.66377218067646, 50.211052894592285, 48.54114890098572, 47.76148773729801, 48.425673097372055, 50.12741558253765, 46.50791980326176, 48.26604746282101, 48.66516664624214, 47.44443655014038, 49.982232972979546, 49.588699489831924, 50.33587999641895, 51.5204094350338, 50.01247555017471, 50.78522488474846, 51.765674874186516, 50.15980504453182, 52.77284882962704, 53.21074113249779, 52.85394407808781, 51.88530005514622, 53.27576324343681, 52.15435601770878, 51.58728584647179, 52.04557545483112, 53.145525231957436, 53.27778473496437, 55.170786157250404, 58.65274451673031, 58.34666334092617, 60.627889931201935, 57.83771865069866, 64.22828033566475, 68.0709457397461, 75.50238937139511, 77.4031613767147, 75.76187744736671, 42.36138470470905, 3.7306930124759674, 5.867221942171454, 0.46934357145801187, 0.4191762290429324, 42.360210567712784, 83.62477272748947, 72.32581302523613, 73.02803054451942, 68.32522809505463, 36.730292066931725, 25.5480981990695, 48.94341051578522, 57.747382298111916, 84.0344287455082, 40.1832427829504, 0.6574232073035091, 0.15994944842532277, 0.29888863675296307, 0.1300832736887969, 0.21608543931506574, 0.1678817454376258, 0.0978733372176066], [0.02736312770139193, 0.07556988479336724, 0.04818892884941306, 0.0572621665924089, 0.03717203602718655, 0.09550855786073953, 0.22064828197471797, 0.28206319897435606, 9.904637821018696, 61.25878147780895, 51.67254567146301, 42.68989607691765, 31.28600500524044, 41.968197003006935, 49.307974353432655, 50.13790301978588, 71.49526879191399, 48.989258855581284, 1.0284733562730253, 0.17532514524646103, 0.6066741398535669, 1.418056357651949, 18.138634487986565, 95.56971296668053, 70.39639815688133, 76.56830817461014, 63.22730764746666, 66.45731672644615, 59.82625834643841, 64.41772297024727, 60.950530618429184, 68.65350008010864, 66.08830332756042, 69.61186945438385, 58.78923699259758, 56.12332284450531, 69.77161288261414, 65.89978784322739, 64.92161393165588, 65.07270902395248, 64.72185865044594, 63.27257081866264, 63.54128859937191, 61.489379703998566, 55.82014851272106, 51.898504346609116, 48.43524098396301, 47.61489540338516, 46.032200530171394, 46.3672399520874, 46.69188693165779, 48.808392360806465, 46.79000526666641, 46.62908770143986, 46.76056444644928, 44.70540672540665, 44.95836675167084, 44.15098987519741, 46.74149326980114, 48.397072032094, 45.06555899977684, 46.51797026395798, 45.88135242462158, 44.11777585744858, 40.681601241230965, 42.19197079539299, 40.32271049916744, 40.12066774070263, 40.80123782157898, 40.76000243425369, 40.82626707851887, 42.203799560666084, 42.05962389707565, 41.791985258460045, 44.90567497909069, 45.27204371988773, 45.905055552721024, 44.268019795417786, 42.872244492173195, 45.12823663651943, 45.08233889937401, 45.39252385497093, 46.27949886023998, 47.68145263195038, 53.62146109342575, 57.55863502621651, 52.38852225244045, 35.13510346412659, 49.42747414112091, 38.73311139643192, 52.407285645604134, 55.26585325598717, 52.99567647278309, 49.72989611327648, 42.89524465799332, 43.68629761040211, 40.94279542565346, 43.24499689042568, 42.82480403780937, 43.74486766755581, 44.088798612356186, 44.64627429842949, 43.95723447203636, 44.79975946247578, 42.890810295939445, 39.239058047533035, 40.50114892423153, 40.43231941759586, 40.83403006196022, 40.96853144466877, 40.37672080099583, 39.62908811867237, 42.64678359031677, 41.565806195139885, 42.8815957903862, 44.923754408955574, 48.512582033872604, 46.20590440928936, 45.28672993183136, 45.43246731162071, 44.03488330543041, 41.91293276846409, 40.645328387618065, 46.19305729866028, 46.33207283914089, 43.792414516210556, 45.191199257969856, 44.6714973449707, 45.62677748501301, 43.88520173728466, 46.026155054569244, 46.544705629348755, 45.77924430370331, 46.74578323960304, 45.62176935374737, 45.52136734127998, 48.40771526098251, 47.42686249315739, 47.36018747091293, 47.44650363922119, 49.5989665389061, 50.156172439455986, 52.992123663425446, 53.06423619389534, 56.01703494787216, 58.55800420045853, 62.3433268815279, 63.18080194294453, 58.39875474572182, 58.30096319317818, 66.78985968232155, 67.60860934853554, 69.43011000752449, 51.01143054664135, 3.1664351653307676, 2.3978031473234296, 1.0884583625011146, 0.40168737061321735, 9.051662441343069, 63.67955558001995, 66.48581519722939, 51.65906399488449, 60.990132093429565, 38.08296628296375, 10.135784167796373, 22.951923608779907, 42.18871057033539, 64.46924820542336, 38.17525953054428, 0.4894100275123492, 0.16660974884871393, 0.06098633042711299, 0.03470437273790594, 0.0677098507003393, 0.0410990251111798, 0.016640062276565004, 0.06060439525754191, 0.04085336680873297, 0.05227215857303236, 0.0942217480042018, 0.043266274442430586, 0.12696025689365342, 0.06281563910306431, 0.24926736659836024, 15.27044864371419, 76.03828981518745, 57.676618695259094, 56.214301362633705, 28.260031677782536, 29.75113056600094, 51.410378739237785, 60.89527778327465, 78.99121016263962, 55.865943655371666, 0.8498521253932267, 0.3172208718024194, 0.7311475044116378, 1.7171204974874854, 19.246983714401722, 100.80811187624931, 72.55385398864746, 78.40604156255722, 65.4512371122837, 70.09549990296364, 62.52704702317715, 68.29770997166634, 63.82608711719513, 70.63731282949448, 68.2307955622673, 70.26803344488144, 62.660750448703766, 60.77894702553749, 69.25665691494942, 69.51717093586922, 68.2371412217617, 68.64590808749199, 67.03303903341293, 64.54040318727493, 64.63368058204651, 64.03981044888496, 58.1275898963213, 56.165139600634575, 50.1139073073864, 51.4716162532568, 49.04301077127457, 48.172618076205254, 46.79211035370827, 49.87026818096638, 49.25886198878288, 47.82366380095482, 48.5701185464859, 46.870142966508865, 46.89638055860996, 48.25899504125118, 48.9766663312912, 50.10885737836361, 47.210038527846336, 49.195956364274025, 48.957180976867676, 46.38414144515991, 42.69601374864578, 45.20223766565323, 42.97603212296963, 43.11290457844734, 43.77799428999424, 43.05608622729778, 43.816828206181526, 45.11955790221691, 45.014865919947624, 44.28008034825325, 46.60567715764046, 48.28227639198303, 48.16110469400883, 45.608793050050735, 45.09001828730106, 46.46119751036167, 47.363542690873146, 47.204027250409126, 48.856319189071655, 48.33849437534809, 55.34079663455486, 61.10276184976101, 53.352838307619095, 37.74807125329971, 51.3868959993124, 42.88500800728798, 54.79781337082386, 56.59196309745312, 55.023266673088074, 50.08853226900101, 45.47066666185856, 44.4748654961586, 43.88047859072685, 45.85417628288269, 45.51648460328579, 46.076122373342514, 46.39948882162571, 46.43333360552788, 46.70487843453884, 47.38741680979729, 45.4483200609684, 42.02599570155144, 41.56598478555679, 41.872643530368805, 43.466145023703575, 42.024407386779785, 42.889172583818436, 41.14395283162594, 44.51049618422985, 44.2242157459259, 45.33274166285992, 45.337620601058006, 52.04046092927456, 48.17555911839008, 46.294610649347305, 46.09800539910793, 46.77868187427521, 44.756692573428154, 43.97215247154236, 47.726271227002144, 47.31701418757439, 45.28853863477707, 47.42445722222328, 47.9941226541996, 46.02799415588379, 45.78048303723335, 47.69355118274689, 48.422165885567665, 46.618144288659096, 48.863041028380394, 49.90521490573883, 48.631014078855515, 50.319195091724396, 50.66677764058113, 48.20343442261219, 49.46660444140434, 51.011365950107574, 51.93875938653946, 55.34276492893696, 56.0614887624979, 59.534639194607735, 61.523292884230614, 64.50225323438644, 66.8235182762146, 61.0090246796608, 61.17210812866688, 68.91578480601311, 70.79233691096306, 72.68445298075676, 53.848054334521294, 3.9384615886956453, 2.493464914150536, 0.6613211450167, 0.28635723574552685, 9.86225489526987, 71.27034366130829, 71.87201857566833, 61.507823914289474, 63.38971093297005, 34.337522462010384, 17.205953635275364, 32.96728178858757, 47.7243485301733, 71.60843431949615, 46.47556073963642, 0.5693656636867672, 0.0927936629159376, 0.009587947770341998, 0.06214785833435599, 0.05347995938791428, 0.06213307846337557, 0.03300635740743019, 0.08793563101789914, 0.1346261822618544, 0.14411302632652223, 0.15249610383762047, 0.17952386057004333, 0.25328392919618636, 0.23912425618618727, 0.5989651253912598, 20.956244096159935, 90.64716070890427, 65.77023759484291, 62.03644394874573, 42.00903721153736, 58.57059292495251, 66.6955791413784, 66.78942650556564, 84.99309450387955, 64.60775077342987, 1.4640787756070495, 0.3244015958625823, 1.4291503373533487, 3.7636975664645433, 17.503696158528328, 101.46326512098312, 75.68533435463905, 83.12780499458313, 68.9946685731411, 74.31770414113998, 64.83513817191124, 71.40940859913826, 67.0391871035099, 73.94697323441505, 71.93084701895714, 69.50306609272957, 62.241355553269386, 64.90843623876572, 72.66363769769669, 72.14293643832207, 69.93229866027832, 71.9534558057785, 69.73511964082718, 67.7937962114811, 67.25420236587524, 67.10465759038925, 61.37371391057968, 58.636697977781296, 52.74999685585499, 53.98885577917099, 51.719830334186554, 51.40993416309357, 50.430483520030975, 52.683982998132706, 52.40405201911926, 50.72097413241863, 51.72390751540661, 49.26794730126858, 50.324518606066704, 49.400894567370415, 52.7626121789217, 52.905161529779434, 48.05427722632885, 52.34821021556854, 50.92647850513458, 47.978357300162315, 44.66275781393051, 48.22421170771122, 47.26046942174435, 45.07022514939308, 48.64800676703453, 46.21979646384716, 45.747299417853355, 47.3002152889967, 47.50735357403755, 46.3204150646925, 51.093361750245094, 50.0525937974453, 49.44200836122036, 48.267631977796555, 48.6018430441618, 50.030562579631805, 50.307506918907166, 48.16020794212818, 51.42229110002518, 52.36443914473057, 57.84300796687603, 62.68209770321846, 56.56668685376644, 43.29646892845631, 54.64029282331467, 46.693672835826874, 60.32479539513588, 60.30926562845707, 57.60714702308178, 54.56493906676769, 48.212724924087524, 48.93037721514702, 43.89430604875088, 49.38443385064602, 49.10444587469101, 49.56739783287048, 48.32233764231205, 49.12377543747425, 48.13752315938473, 48.39396759867668, 47.23116159439087, 44.84545961022377, 45.28400927782059, 45.57598941028118, 46.7923117429018, 47.42579475045204, 45.46179033815861, 43.44542093575001, 48.61339822411537, 46.85443460941315, 48.2147616147995, 49.56696465611458, 54.9298220872879, 50.07364846765995, 50.46488307416439, 49.14804093539715, 49.301894679665565, 45.678876489400864, 45.732499212026596, 50.60127675533295, 51.55374124646187, 47.565273866057396, 48.519854843616486, 50.98417840898037, 49.31464299559593, 48.65320488810539, 50.7614229619503, 52.55848713219166, 50.0804653018713, 51.856923177838326, 53.00894916057587, 50.02213843166828, 54.502926394343376, 53.986089527606964, 50.363219529390335, 51.58428020775318, 53.35876598954201, 56.66310288012028, 58.387305960059166, 59.00458663702011, 62.00886122882366, 65.20125612616539, 66.1242949962616, 70.68487107753754, 63.79208654165268, 64.03585866093636, 71.75158023834229, 76.24337241053581, 75.9954509139061, 58.63013572990894, 3.972861380316317, 4.558969242498279, 2.9064756771549582, 0.2846232522279024, 13.786460123956203, 81.8165485560894, 77.06478953361511, 69.60680052638054, 77.5250892341137, 52.840454801917076, 18.23531650006771, 38.24969373643398, 57.26244851946831, 79.3973095715046, 56.72030881047249, 0.713047650642693, 0.19666960928589106, 0.11047319392673671, 0.15011434414191172, 0.2097948471782729, 0.12976171594345942, 0.14145952183753252], [0.017427492093702313, 0.06575938270543702, 0.010174387298320653, 0.018574516579974443, 0.037799399433424696, 0.02721879667660687, 0.11648807078017853, 0.13005427055759355, 12.586473114788532, 57.95284487307072, 50.642694532871246, 41.53950780630112, 37.59324096143246, 38.6413349211216, 56.935647055506706, 54.31814230978489, 75.72486743330956, 35.27150474488735, 0.06226459445315413, 0.09487940958933905, 0.48925533425062895, 0.7415915408637375, 68.9463883638382, 84.75613921880722, 68.81329670548439, 74.19819295406342, 62.75392524898052, 61.80529475212097, 59.01968702673912, 61.9292289018631, 63.97532030940056, 67.94349297881126, 63.38088020682335, 71.4683510363102, 53.7158328294754, 56.87040835618973, 69.13653776049614, 66.10501483082771, 65.86048275232315, 63.112284019589424, 63.19353885948658, 63.18242445588112, 62.017148584127426, 57.492244988679886, 57.13110476732254, 54.29335243999958, 49.26363833248615, 48.64564709365368, 46.00138038396835, 46.5246807038784, 47.02057309448719, 44.47317458689213, 45.25402128696442, 46.3911634683609, 46.61663196980953, 45.943623483181, 43.21266442537308, 45.100737512111664, 44.42752003669739, 45.31195677816868, 45.13851508498192, 46.9091022759676, 47.08542041480541, 48.122711554169655, 45.812606513500214, 41.8096961081028, 38.741816729307175, 39.79728989303112, 40.60185492038727, 40.3823558986187, 38.55877675116062, 40.764334201812744, 40.30390910804272, 41.33650749921799, 41.64455696940422, 40.68356193602085, 41.558594182133675, 43.038542568683624, 52.024095207452774, 51.78558200597763, 55.008390471339226, 50.67718908190727, 51.85817711055279, 51.75420328974724, 55.677405372262, 57.032587453722954, 50.75595885515213, 37.13183552026749, 42.85644493997097, 39.43736180663109, 42.07760073244572, 52.0940038561821, 54.12116467952728, 49.972843676805496, 46.47902615368366, 47.37095609307289, 46.59279204905033, 41.11925795674324, 40.25086395442486, 44.16723020374775, 43.366278782486916, 43.22508215904236, 43.35750125348568, 42.23067931830883, 41.942308992147446, 41.54311761260033, 40.378176122903824, 39.57641154527664, 40.059806406497955, 39.94730204343796, 37.97885186970234, 43.160269036889076, 38.44627998769283, 42.45330177247524, 48.55433039367199, 47.45279610157013, 49.85342748463154, 43.179606199264526, 46.0577579587698, 45.62778823077679, 44.28153187036514, 43.6739444732666, 40.981595143675804, 44.014649391174316, 44.399211555719376, 44.712975919246674, 44.979630410671234, 44.066888988018036, 46.37282185256481, 46.25527895987034, 46.65987744927406, 46.087365970015526, 44.0304109454155, 45.9506569057703, 48.084998577833176, 47.25548788905144, 49.46706421673298, 48.630713894963264, 50.71319214999676, 53.337661921978, 57.27034069597721, 58.773103058338165, 60.24346075952053, 59.48451988399029, 61.7125341296196, 65.03791809082031, 66.30269542336464, 65.77013120055199, 62.55252465605736, 62.8888788074255, 65.03946840763092, 68.89282643795013, 70.29945015907288, 56.77831269800663, 7.81664083711803, 1.0273665469139814, 0.057256971558672376, 0.17849215655587614, 1.730942849535495, 54.94709976017475, 69.91536676883698, 61.42047040164471, 52.041118294000626, 47.64330267906189, 19.96868658810854, 16.743564046919346, 33.21717917919159, 59.337273985147476, 46.026782020926476, 0.5082398874219507, 0.03660021124233026, 0.03132092890155036, 0.024747305760683957, 0.02805428797728382, 0.0608550630568061, 0.04359447812021244, 0.02519904177461285, 0.017853855933935847, 0.03900813164364081, 0.062216755613917485, 0.09968879370717332, 0.058141407498624176, 0.1147127867443487, 0.2427696855738759, 17.863191068172455, 72.8884944319725, 57.590902894735336, 48.331012576818466, 42.85615235567093, 43.48644733428955, 60.63247248530388, 64.0843440592289, 81.52435943484306, 42.60635755956173, 0.03516920580295846, 0.17446412035496905, 1.178470307495445, 0.8457830781117082, 69.94910135865211, 89.05933991074562, 73.64270076155663, 78.28646957874298, 65.78881859779358, 66.2365409731865, 61.43185459077358, 64.85269322991371, 67.11046367883682, 70.77638536691666, 66.88732445240021, 68.38636681437492, 56.24356359243393, 61.40766128897667, 69.07530784606934, 68.50102186203003, 69.06379446387291, 67.33218178153038, 67.33264535665512, 65.00039130449295, 63.7813863158226, 60.17225258052349, 61.05383187532425, 57.49907322227955, 51.63324058055878, 51.54000498354435, 49.298824444413185, 48.94778788089752, 46.83344453573227, 47.76275306940079, 46.59254506230354, 48.405359387397766, 47.999031990766525, 48.368554562330246, 45.00291556119919, 46.577676460146904, 48.05262051522732, 48.16629521548748, 46.46870590746403, 48.31327132880688, 49.296483770012856, 52.13699854910374, 48.21113280951977, 43.41962032020092, 41.06944642961025, 43.459806963801384, 42.18082599341869, 42.91726067662239, 42.53221593797207, 43.71500127017498, 41.625462993979454, 44.25691679120064, 44.1989167034626, 43.63362483680248, 43.862285166978836, 46.26535601913929, 53.67134481668472, 52.93973967432976, 55.90271808207035, 53.141246661543846, 54.26182173192501, 56.02691061794758, 55.656802877783775, 59.57330971956253, 52.15755544602871, 37.673443257808685, 44.87407587468624, 41.76437593996525, 43.99918422102928, 54.728470891714096, 56.82474620640278, 53.466186225414276, 47.834440022706985, 50.27522385120392, 47.613215893507004, 42.14823134243488, 44.05565299093723, 44.76862773299217, 45.18177196383476, 45.12790225446224, 44.74057383835316, 44.915790036320686, 43.96545723080635, 43.50662425160408, 41.977080926299095, 41.838103383779526, 41.998116597533226, 41.6680359095335, 40.84697596728802, 44.31543745100498, 40.58763228356838, 45.78065402805805, 49.21318084001541, 49.90610025823116, 52.03561618924141, 46.3208444416523, 46.97415478527546, 47.375667840242386, 47.141607999801636, 45.35924904048443, 44.00462172925472, 45.503557696938515, 47.13570311665535, 46.87202766537666, 47.156100422143936, 46.598617136478424, 48.093445524573326, 47.934435456991196, 48.996223881840706, 48.52862857282162, 46.49639502167702, 49.066744297742844, 50.572428703308105, 50.07590174674988, 51.33421942591667, 52.34236612915993, 52.27085776627064, 55.85858345031738, 60.25566950440407, 62.339789271354675, 61.98174208402634, 62.36531250178814, 65.57287618517876, 67.5670775771141, 67.72955685853958, 67.6105472445488, 66.47728845477104, 66.33510768413544, 66.17982521653175, 71.88341796398163, 73.80410850048065, 58.45903851091862, 8.474352769553661, 1.9885562011040747, 0.3396649908972904, 0.1228682030341588, 1.6715750726871192, 59.55205745995045, 74.8659311234951, 66.7791898548603, 61.51937909424305, 46.94891273975372, 17.188649363815784, 21.668584272265434, 39.99223083257675, 67.28729858994484, 54.063574969768524, 0.945759869646281, 0.04193598586425651, 0.02939698526461143, 0.03705974166223314, 0.06558282577316277, 0.05963693525700364, 0.029708271686104126, 0.1297095578047447, 0.125211178092286, 0.12595685839187354, 0.13153662148397416, 0.1714326994260773, 0.23046195303322747, 0.3407753922510892, 0.5558705690782517, 25.94151008874178, 86.88595533370972, 64.57577168941498, 59.01328057050705, 47.284351140260696, 64.37140345573425, 73.98149818181992, 70.75597286224365, 89.83240842819214, 47.16810017824173, 0.18996679864358157, 0.24976113229058683, 3.1817796919494867, 0.5690510524436831, 71.63469091057777, 90.7614053785801, 76.59493714570999, 80.57124897837639, 68.42700183391571, 67.85824075341225, 65.09379789233208, 67.1912169456482, 69.07961681485176, 73.08435872197151, 68.75394389033318, 68.30588713288307, 58.22571203112602, 64.02553081512451, 73.69940891861916, 71.25712037086487, 73.17113846540451, 68.63611221313477, 69.22734528779984, 68.5782565176487, 67.40960642695427, 63.364411890506744, 63.55706915259361, 58.610190600156784, 52.65007361769676, 54.05254416167736, 49.52438034117222, 51.75872124731541, 49.68290023505688, 50.656157210469246, 47.143124118447304, 50.146619752049446, 50.17711691558361, 51.85353755950928, 47.483414858579636, 50.9196312725544, 49.806089624762535, 50.66751480102539, 47.644309625029564, 50.540210232138634, 51.365092769265175, 54.38398517668247, 50.151867270469666, 47.479067891836166, 44.63809713721275, 44.475230276584625, 45.4695875197649, 45.442570969462395, 45.06334751844406, 46.80052310228348, 45.61709940433502, 47.86754384636879, 48.42087395489216, 46.80730573832989, 46.158471554517746, 48.65879438817501, 57.25629284977913, 56.217010617256165, 59.71233665943146, 56.29116363823414, 57.578811943531036, 57.941874861717224, 60.76679527759552, 63.83602738380432, 55.52907653152943, 42.86928825080395, 46.01516604423523, 44.095452055335045, 47.698137536644936, 58.533776700496674, 59.47251632809639, 56.03587053716183, 51.23590350151062, 52.78108298778534, 49.633943662047386, 45.75713708996773, 46.039602532982826, 48.99517133831978, 46.804353296756744, 47.49971218407154, 46.728874146938324, 47.18186303973198, 47.31039494276047, 45.71590170264244, 44.56579081714153, 45.44983997941017, 44.47359636425972, 44.19111952185631, 43.26496101915836, 49.070544093847275, 43.96369792521, 49.73670534789562, 52.405970916152, 51.85666859149933, 53.53088915348053, 48.83863873779774, 49.920539483428, 49.76948618888855, 48.928925693035126, 50.02451330423355, 46.49606063961983, 49.65900331735611, 49.705254435539246, 48.56310412287712, 50.266689509153366, 49.3988236784935, 50.46725794672966, 51.747245863080025, 52.53530077636242, 50.93812108039856, 47.845201045274734, 50.89714027941227, 53.59589606523514, 51.62889361381531, 53.196537494659424, 53.508246168494225, 55.52065998315811, 57.50892989337444, 64.23756703734398, 64.5965413749218, 67.7356593310833, 65.60902744531631, 68.37591737508774, 72.52111494541168, 71.9543905556202, 70.10345667600632, 68.9454536139965, 68.3603686094284, 72.53267392516136, 75.02078801393509, 76.21148452162743, 64.14124980568886, 8.908695112913847, 3.5195031948387623, 1.4525051903910935, 0.28053054527845234, 2.509291539900005, 68.97704511880875, 79.86799791455269, 75.69059327244759, 71.96195214986801, 64.88379076123238, 30.176021866500378, 28.63274797797203, 49.124523997306824, 74.75056171417236, 67.39164099097252, 1.7982408008538187, 0.2294976360280998, 0.20100097608519718, 0.1962788833770901, 0.19957124342909083, 0.21672227623639628, 0.2042450668523088], [0.0464484218537109, 0.014688270475744503, 0.04204643970297184, 0.026517700898693874, 0.07425700328894891, 0.06326174407149665, 0.08960123304859735, 0.16816263349028304, 20.53534258157015, 60.06599888205528, 37.76009380817413, 43.85003462433815, 34.64747563004494, 30.708719082176685, 56.645050048828125, 58.738749101758, 75.54718136787415, 23.22064518928528, 0.3783059190027416, 0.48485692183021456, 2.4664880242198706, 19.023061729967594, 94.17021006345749, 68.17294746637344, 78.14472198486328, 63.365578427910805, 63.59163969755173, 56.3321178406477, 61.55742645263672, 58.67515571415424, 64.57831755280495, 67.609354108572, 67.62467488646507, 68.65987613797188, 48.735854253172874, 62.71843135356903, 63.543652072548866, 62.73762792348862, 67.91609644889832, 68.34056407213211, 65.0217005610466, 63.13798204064369, 61.955386698246, 63.01072306931019, 62.336711436510086, 58.10424394905567, 51.624200865626335, 47.39931017160416, 48.63573342561722, 45.48575185239315, 46.080032363533974, 46.586294397711754, 45.64583346247673, 45.49114756286144, 46.07657074928284, 42.82013028860092, 44.16029557585716, 44.466509744524956, 44.283215180039406, 43.880402594804764, 46.89022868871689, 48.43589834868908, 49.45179283618927, 48.16774293780327, 50.67245073616505, 46.50003142654896, 45.33364601433277, 39.118893295526505, 39.70075987279415, 41.216179355978966, 40.39559818804264, 38.47012750804424, 40.84371954202652, 40.573690831661224, 39.795055612921715, 39.38520200550556, 41.032189428806305, 38.80448676645756, 44.49517160654068, 47.83917456865311, 54.1060034930706, 58.73353958129883, 58.967785611748695, 57.69052594900131, 56.30602464079857, 59.15814399719238, 55.43985351920128, 35.291066095232964, 43.750867545604706, 35.525015741586685, 40.190439596772194, 56.4742112159729, 54.61574234068394, 53.24254162609577, 54.80799302458763, 53.179301619529724, 51.186772137880325, 46.185370311141014, 43.23502242565155, 44.050226882100105, 43.036863058805466, 41.23109735548496, 40.233248099684715, 39.593248441815376, 39.50720205903053, 42.08672784268856, 41.016883850097656, 39.3373853713274, 39.973334446549416, 41.04189030826092, 39.67795729637146, 40.62800131738186, 43.219127878546715, 46.09182693064213, 46.37485474348068, 45.60260698199272, 44.64475817978382, 44.7473830729723, 44.54959608614445, 46.34576350450516, 43.64611856639385, 41.453324630856514, 41.82550705969334, 43.94412137567997, 45.44331192970276, 45.37524238228798, 44.51685704290867, 47.25446954369545, 46.19558796286583, 44.205437153577805, 45.612437054514885, 48.46628151834011, 51.311618238687515, 50.47736920416355, 53.687288761138916, 56.55577763915062, 58.01677644252777, 60.60623489320278, 60.07034204900265, 61.99190653860569, 63.153394013643265, 63.4078511595726, 63.884026408195496, 64.5241628587246, 64.04709085822105, 64.84163582324982, 65.8480878174305, 82.43282988667488, 67.83825382590294, 65.27007043361664, 65.83906710147858, 67.33446925878525, 69.71291363239288, 57.971460074186325, 8.547255657613277, 1.2413973058573902, 0.36982518970035017, 0.0809730241599027, 0.27023716480471194, 38.80754180252552, 71.48786678910255, 62.2696640342474, 53.53801377117634, 37.87508323788643, 26.539645493030548, 23.19065909832716, 47.360377460718155, 52.97704227268696, 62.50199116766453, 2.736807418987155, 0.16001167008653283, 0.07105216471245512, 0.05400379690399859, 0.05523193256522063, 0.04534530467935838, 0.07440391884301789, 0.026154703482461628, 0.04501659263041802, 0.04930351220536977, 0.05492731805134099, 0.03236821430618875, 0.06145844396087341, 0.09840128623181954, 0.054340891510946676, 26.289729103446007, 74.0425457060337, 44.3039620667696, 51.25545345246792, 47.310717925429344, 31.275952644646168, 64.9240230023861, 65.01065075397491, 81.17774203419685, 25.75048103928566, 0.5395281210076064, 0.47613719129003584, 2.6639140304178, 22.095840945839882, 97.37704798579216, 72.26699978113174, 82.10207283496857, 67.44238346815109, 68.23451936244965, 60.2653019875288, 63.5230153799057, 61.91377513110638, 67.52414748072624, 70.88341802358627, 69.84479695558548, 66.51701912283897, 52.501896768808365, 64.9453854560852, 66.05436354875565, 64.96325969696045, 71.3183730840683, 68.23531731963158, 67.04764544963837, 65.96601068973541, 63.82780462503433, 65.37197336554527, 64.9679334461689, 61.54959887266159, 53.7053681910038, 49.66496139764786, 51.76624484360218, 46.885767728090286, 48.43614533543587, 49.55828212201595, 48.48035976290703, 47.82704181969166, 49.093095883727074, 45.60427509248257, 48.63544084131718, 47.26567134261131, 47.91611663997173, 46.63569934666157, 47.37966142594814, 50.065231919288635, 52.294925674796104, 47.52548240125179, 51.16287142038345, 49.550781324505806, 47.0847250521183, 41.12607479095459, 41.83564491569996, 43.85122396051884, 42.37620010972023, 42.13627338409424, 44.132230281829834, 41.72586880624294, 42.56372004747391, 42.62249909341335, 43.21842111647129, 41.699844002723694, 46.60497799515724, 49.516092985868454, 56.10173240303993, 59.95811127126217, 59.770910516381264, 60.16585752367973, 58.96476857364178, 60.2808241546154, 58.48559148609638, 39.21161592006683, 43.10199536383152, 39.23881486058235, 42.00445465743542, 58.48189428448677, 58.10064934194088, 55.58371379971504, 55.73901146650314, 57.10356384515762, 52.95533403754234, 49.480591490864754, 45.2498909085989, 46.795203387737274, 44.193878173828125, 43.959373757243156, 42.64744095504284, 42.4969994276762, 43.67369368672371, 44.51143093407154, 43.45958657562733, 42.67170265316963, 41.02044425904751, 43.079576566815376, 41.806451082229614, 42.39192746579647, 45.85793428122997, 47.28213205933571, 48.400659039616585, 47.50160068273544, 46.97439417243004, 47.55393527448177, 47.372358217835426, 49.845235124230385, 44.49976176023483, 44.334459230303764, 43.60044501721859, 47.61262692511082, 47.15867668390274, 47.64737606048584, 46.217691376805305, 49.25826162099838, 47.175916358828545, 47.32907474040985, 47.61813662946224, 50.19846796989441, 52.69233874976635, 55.264872908592224, 56.76957316696644, 59.32460926473141, 60.56456632912159, 62.57183521986008, 61.475924625992775, 65.28717711567879, 64.54044118523598, 65.64062654972076, 65.83387657999992, 68.61428618431091, 66.98341369628906, 66.99578583240509, 69.21121135354042, 80.90564623475075, 73.49963843822479, 67.44098514318466, 68.52041602134705, 69.5097005367279, 73.39670196175575, 61.53315715491772, 9.934592563658953, 0.7218821765854955, 0.8482573390938342, 0.10396020981715992, 0.16992045479128137, 43.35407383739948, 77.29929015040398, 66.76894560456276, 62.56445601582527, 42.672812193632126, 28.057097867131233, 27.484592087566853, 55.09912960231304, 58.11419181525707, 71.25240862369537, 3.9502894040197134, 0.3047757677268237, 0.07377091882517561, 0.021515419612114783, 0.020898520488117356, 0.025225015087926295, 0.014741334034624742, 0.1512245970661752, 0.14524300553603098, 0.12418040918419138, 0.0971993112761993, 0.2105458709411323, 0.15267147333361208, 0.1786080058082007, 0.17896266333991662, 37.89460279047489, 87.95782461762428, 54.33771885931492, 60.64057745039463, 41.09059989452362, 43.942882642149925, 73.19816261529922, 71.61421000957489, 89.6059101819992, 30.83157978951931, 0.5115024873521179, 1.0965292481705546, 5.884490590542555, 23.00957601517439, 99.53452661633492, 72.64713898301125, 84.85690981149673, 70.43780833482742, 70.09077295660973, 64.07548293471336, 66.03009045124054, 65.57830229401588, 70.3618960082531, 74.91180986166, 70.9164534509182, 71.84322372078896, 59.09005545079708, 66.43276244401932, 68.93051281571388, 64.85339239239693, 72.84095138311386, 72.889094799757, 70.39906561374664, 69.6513569355011, 66.29539981484413, 69.59043860435486, 67.70268470048904, 63.174832463264465, 56.544849425554276, 52.12998792529106, 53.80596399307251, 47.9494484513998, 50.66936530172825, 51.15546941757202, 50.6710372120142, 51.30046583712101, 49.87276844680309, 46.3278778642416, 51.33752524852753, 48.91858644783497, 49.286174923181534, 48.1446173787117, 50.66618487238884, 53.14009912312031, 54.371803030371666, 51.077558398246765, 55.054018422961235, 52.58571267127991, 52.047129571437836, 46.19229353964329, 43.509056121110916, 46.822979897260666, 46.10436625778675, 43.59151549637318, 46.06775142252445, 45.32462529838085, 44.42940853536129, 44.93308290839195, 47.079291343688965, 43.167017474770546, 50.27269318699837, 52.02731743454933, 59.795943573117256, 62.3096264898777, 63.692946061491966, 63.32294471561909, 64.66820552945137, 61.2080541998148, 63.32229495048523, 44.68321591615677, 43.702040165662766, 40.810110345482826, 46.2312338501215, 62.268520295619965, 59.31529976427555, 59.120431020855904, 59.74593825638294, 59.225400388240814, 54.31113548576832, 51.14878557622433, 47.88477972149849, 50.698578134179115, 48.29052194952965, 46.458131074905396, 45.13830989599228, 45.44964239001274, 44.71742548048496, 48.055550158023834, 45.7084047049284, 45.77581308782101, 44.10799138247967, 47.56535746157169, 44.30872701108456, 45.30938811600208, 48.587916791439056, 50.045431181788445, 48.50135363638401, 48.8503535091877, 47.11643435060978, 50.23342989385128, 49.979447722435, 51.84217996895313, 48.8227403908968, 46.05948306620121, 47.180331721901894, 50.04214435815811, 50.00984229147434, 49.00022506713867, 47.78784692287445, 51.82710237801075, 49.942118525505066, 48.387872725725174, 49.576213359832764, 52.34139338135719, 55.05378283560276, 55.64796835184097, 60.22095076739788, 62.28243514895439, 63.764264434576035, 66.64366632699966, 64.3254791200161, 68.78370389342308, 68.19318518042564, 67.7036726474762, 69.53908815979958, 69.33273643255234, 69.8088812828064, 70.19491016864777, 73.94934430718422, 81.15586280822754, 72.34248653054237, 72.7156189084053, 72.96144291758537, 74.52135801315308, 75.54612502455711, 66.67392790317535, 12.31659259647131, 4.159979252144694, 1.513910845387727, 0.35349618934560567, 0.47022254148032516, 49.83863107860088, 85.03649577498436, 73.06995749473572, 73.35277631878853, 52.78811261057854, 37.8848335146904, 35.3953742980957, 65.00229120254517, 67.09364578127861, 83.13761606812477, 5.62572400085628, 0.5890851211734116, 0.2495968504808843, 0.1463156909449026, 0.1761146419448778, 0.1474946815869771, 0.16567412327276543], [0.010809476461872691, 0.024848987413861323, 0.10525412202696316, 0.10421080340165645, 0.04144029429880902, 0.03763176682696212, 0.12977272941498086, 0.1656427452689968, 32.552769631147385, 56.435335502028465, 38.26349839568138, 30.867636054754257, 26.079687774181366, 45.61375938355923, 56.77410252392292, 61.81851044297218, 71.87766507267952, 15.283439196646214, 0.31713629665318877, 1.3118844735436141, 6.987646920606494, 58.899560272693634, 83.19043323397636, 73.89252975583076, 70.40152788162231, 63.44533234834671, 59.67091128230095, 57.482604905962944, 59.206397607922554, 59.7980372607708, 64.36925277113914, 65.97161918878555, 70.28963148593903, 46.30110450088978, 53.9846608042717, 69.72336307168007, 64.44470912218094, 66.60282611846924, 64.33995634317398, 65.51847830414772, 63.56991246342659, 63.4700196236372, 61.942174807190895, 63.6723967641592, 59.8537764698267, 64.69762355089188, 52.98592619597912, 48.805629909038544, 49.715973660349846, 46.841218918561935, 46.721559539437294, 44.610126838088036, 45.08399561047554, 45.19428849220276, 46.42019771039486, 45.03147102892399, 43.89264173805714, 45.80491192638874, 43.84764455258846, 44.27210457623005, 44.35647904872894, 49.555504471063614, 51.40252076089382, 47.57485695183277, 41.15427687764168, 45.655253157019615, 44.31319557130337, 47.19125613570213, 39.53191973268986, 42.27689243853092, 39.02002640068531, 40.95201753079891, 39.83338415622711, 41.38017475605011, 39.42244380712509, 40.47520771622658, 38.549208864569664, 41.432471349835396, 37.362103164196014, 39.718033745884895, 37.39310950040817, 44.89172972738743, 48.481575697660446, 54.74195256829262, 54.697008579969406, 57.4477531760931, 34.85792353749275, 40.34172847867012, 47.826335057616234, 48.874087035655975, 37.6642819494009, 44.06181626021862, 56.29305213689804, 56.27302721142769, 56.2865886837244, 49.140414744615555, 47.372365817427635, 43.0705900490284, 41.03997901082039, 40.335584208369255, 38.734631314873695, 39.85959514975548, 39.69605952501297, 42.25861541926861, 39.44578215479851, 41.48620046675205, 41.711061000823975, 41.02221876382828, 40.09121552109718, 41.23733662068844, 40.940701737999916, 44.99787323176861, 46.45096465945244, 45.292334631085396, 43.816501423716545, 43.80236238241196, 49.14666160941124, 45.584044978022575, 43.30401912331581, 45.93234948813915, 44.06640641391277, 44.16325181722641, 39.478373005986214, 42.86822810769081, 46.015960201621056, 45.29040053486824, 45.03535822033882, 46.63054682314396, 43.81819233298302, 45.667674690485, 44.37328554689884, 52.784578800201416, 53.46060812473297, 58.76871809363365, 59.08883951604366, 62.6926801353693, 62.18180514872074, 62.72195376455784, 60.81909567117691, 63.58094707131386, 62.7057970315218, 64.55766186118126, 62.815215960145, 65.52488476037979, 61.234652772545815, 66.86462447047234, 62.400004640221596, 74.55534338951111, 78.32523509860039, 67.0865249633789, 66.2053370475769, 67.79173672199249, 69.55225825309753, 59.205865636467934, 9.62736764922738, 0.7031957886647433, 0.6029647670220584, 0.07793312790454365, 0.20286761107854545, 26.80452547967434, 73.55690896511078, 64.06631782650948, 61.82441532611847, 47.82105714082718, 22.291072569787502, 10.997120048850775, 27.774081453680992, 44.609963446855545, 65.42032197117805, 5.7023734878748655, 0.40917270176578313, 0.05450999356980901, 0.047655740272603, 0.054299980620271526, 0.034769833873724565, 0.06114137249824125, 0.03299355164926965, 0.034341662903898396, 0.060753655998269096, 0.01849002863309579, 0.062156656495062634, 0.008535274373571156, 0.07806125227943994, 0.15257888298947364, 41.609188467264175, 67.70019203424454, 45.97573556005955, 37.446492835879326, 26.074115373194218, 44.40316714346409, 67.53844231367111, 68.1723926961422, 82.4224716424942, 15.713359527289867, 0.28450614132452756, 1.9395464309491217, 8.664678856730461, 71.16182148456573, 84.20168057084084, 77.3478439450264, 72.9847052693367, 65.16136586666107, 61.46288752555847, 61.8023195117712, 61.550168842077255, 60.70972993969917, 67.53588885068893, 70.41287407279015, 68.75169441103935, 51.25771053135395, 56.728444173932076, 71.45021080970764, 66.51658594608307, 68.2753823697567, 65.88452026247978, 66.32807046175003, 67.50500410795212, 66.25056222081184, 65.12257754802704, 66.59253627061844, 62.788537591695786, 65.70580065250397, 54.9768103659153, 50.21687038242817, 49.57073025405407, 49.30047735571861, 49.25712548196316, 47.4051808565855, 47.321224361658096, 49.69765104353428, 47.55992375314236, 46.94109655916691, 46.70550920069218, 47.55425065755844, 47.24016711115837, 48.21880839765072, 47.32393741607666, 51.67326383292675, 52.53343887627125, 48.25008071959019, 41.83346763253212, 46.70487083494663, 46.14910885691643, 49.01752933859825, 41.78544580936432, 43.946218863129616, 42.230272740125656, 44.31248880922794, 41.37564919888973, 42.79840685427189, 42.19466105103493, 43.11824329197407, 42.98879183828831, 43.00519935786724, 39.980417266488075, 42.12674729526043, 41.22902266681194, 46.48503743112087, 51.32899470627308, 58.767289370298386, 59.159200340509415, 59.18175972998142, 41.85325317084789, 43.11409771442413, 49.390236139297485, 51.44493788480759, 42.37751483917236, 49.193494096398354, 56.10673673450947, 60.466246604919434, 58.77199351787567, 49.82805244624615, 50.16740843653679, 44.51461896300316, 42.88631893694401, 43.72727461159229, 41.66892506182194, 42.74227626621723, 41.97638936340809, 42.955201640725136, 41.926384046673775, 43.371731489896774, 43.57003144919872, 43.18989984691143, 41.703206822276115, 44.95708242058754, 43.00428740680218, 47.42926016449928, 49.05042417347431, 44.85906668007374, 42.58513569831848, 45.53541898727417, 52.303801998496056, 48.72337572276592, 46.385782957077026, 46.732236966490746, 44.60158109664917, 45.90047299861908, 42.541533038020134, 46.241907477378845, 46.03796102106571, 47.32483796775341, 46.660607010126114, 48.81505720317364, 45.93819357454777, 48.89024376869202, 46.95361688733101, 55.885596200823784, 56.77815690636635, 60.54093919694424, 60.808235853910446, 64.66950505971909, 64.34102028608322, 65.3903491795063, 62.482205629348755, 66.4725387096405, 64.31881427764893, 65.58404758572578, 62.82913461327553, 65.56374907493591, 63.66947092115879, 68.29084753990173, 64.75158825516701, 73.43791455030441, 77.01276272535324, 70.71992039680481, 68.39985609054565, 71.26810178160667, 70.88340282440186, 63.18134531378746, 11.361197512596846, 0.96691636252217, 1.1371655738912523, 0.20603159442543983, 0.15975699468981475, 28.115094155073166, 79.91364106535912, 69.30102333426476, 71.56355872750282, 44.51449736952782, 23.85908503085375, 21.903922744095325, 34.766895622015, 50.272313207387924, 75.39843454957008, 8.569016139954329, 0.45082490891218185, 0.14054665050935, 0.10602315771393478, 0.025944141343643423, 0.010814098186529009, 0.01642548511881614, 0.23338166589383036, 0.20471732510486618, 0.152412063034717, 0.2325024880701676, 0.1758820380200632, 0.11440664340625517, 0.39392426842823625, 0.37599056668113917, 54.13835495710373, 79.42183345556259, 56.36108748614788, 45.913289710879326, 36.50638148188591, 66.49004057049751, 76.43039837479591, 75.43328627943993, 90.00143855810165, 19.62179560214281, 0.5428451648913324, 3.1003529112786055, 11.466069985181093, 73.00321027636528, 86.74523368477821, 80.74132785201073, 74.24981698393822, 69.17401134967804, 64.6587972342968, 65.64267084002495, 64.81944501399994, 64.67659547924995, 70.1273725926876, 74.5448787510395, 70.78037515282631, 58.198076114058495, 59.689465686678886, 72.9197895526886, 69.6534164249897, 73.21539089083672, 70.56891649961472, 70.85732102394104, 72.12678730487823, 70.60244590044022, 66.63348287343979, 70.0741146504879, 65.36939710378647, 69.87831875681877, 56.557069569826126, 53.25758881866932, 52.73074708878994, 50.9148283302784, 51.79708018898964, 48.70227165520191, 48.688280805945396, 50.73536396026611, 48.8574743270874, 49.5934796333313, 49.46717441082001, 51.08672730624676, 48.418829664587975, 50.107557848095894, 48.86901430785656, 55.34915618598461, 55.645817667245865, 49.23719175159931, 41.75114504992962, 45.698308646678925, 46.185089126229286, 52.582152262330055, 45.23016236722469, 47.93758548796177, 45.09644754230976, 48.909782320261, 46.716418415308, 47.84046649932861, 45.70419833064079, 46.68071933090687, 45.29008515179157, 46.91996969282627, 42.923651933670044, 45.7503392547369, 42.86537446081638, 52.164121493697166, 54.21036869287491, 60.72499372065067, 62.26859249174595, 60.97494810819626, 44.760321378707886, 47.01601713895798, 50.60104116797447, 52.55759797990322, 46.51398807764053, 53.90610381960869, 60.619237795472145, 62.85170540213585, 62.00065366923809, 53.44667427241802, 52.30560690164566, 46.444641798734665, 46.286361292004585, 47.81964361667633, 42.92256139218807, 45.40899217128754, 45.94526119530201, 47.123615965247154, 44.43135403096676, 46.99083589017391, 45.734068527817726, 46.80229380726814, 43.34024257957935, 46.658121943473816, 45.24506896734238, 50.15580005943775, 51.130937933921814, 46.823785454034805, 43.670809641480446, 47.447312995791435, 53.26682232320309, 50.64207896590233, 47.172580137848854, 50.672336742281914, 48.78373168408871, 50.21932125091553, 44.13660764694214, 48.08702766895294, 49.252193346619606, 48.926395028829575, 48.191586658358574, 53.15472453832626, 48.113930225372314, 51.00434772670269, 48.13836671411991, 56.855604350566864, 58.990800976753235, 62.78534576296806, 63.07610996067524, 67.32639849185944, 66.53720363974571, 68.02287831902504, 65.26894569396973, 68.7802916765213, 68.46689209342003, 69.23456490039825, 66.41254752874374, 70.88885173201561, 67.17260554432869, 70.91442435979843, 65.43615952134132, 80.14906883239746, 77.23475441336632, 74.08352270722389, 70.80508142709732, 74.8806819319725, 76.11082792282104, 67.97794193029404, 13.838267493993044, 5.262871021404862, 1.5690429182723165, 0.30046890664380044, 0.36200764356181026, 33.15487392246723, 88.13025936484337, 75.45782536268234, 81.36748105287552, 62.493859604001045, 33.50412838160992, 21.178750656545162, 43.124980330467224, 60.395562797784805, 86.12419500946999, 13.191541247069836, 0.8687173412181437, 0.3802085778443143, 0.16872138163307682, 0.25124317151494324, 0.11516571947140619, 0.17310489172814414], [0.00779746362240985, 0.05428616554127075, 0.06072287171264179, 0.018519514160288963, 0.006821453152952017, 0.019638485464383848, 0.09765450013219379, 0.4534410685300827, 27.543589621782303, 49.5472627133131, 41.639355048537254, 31.37164480984211, 32.1633855253458, 40.2901728451252, 58.275086581707, 61.41800433397293, 69.32658076286316, 4.221836132928729, 0.07948766011395492, 0.48439082340337336, 9.883926082402468, 71.71279191970825, 69.54163402318954, 74.44998264312744, 66.33580684661865, 67.95915573835373, 59.27582748234272, 59.99392434954643, 55.256779342889786, 58.72656315565109, 59.36880089342594, 65.63767790794373, 56.859799325466156, 56.88249550759792, 65.75663432478905, 65.77492654323578, 63.706750720739365, 66.6555292904377, 63.99194821715355, 64.8633174598217, 62.10376113653183, 64.03759896755219, 60.814330726861954, 61.87151379883289, 60.30823588371277, 58.673715591430664, 49.8001429438591, 45.324028730392456, 46.7235354334116, 46.67827986180782, 45.80523110926151, 47.45490498840809, 44.28808271884918, 46.072014793753624, 46.89179040491581, 44.21859584748745, 44.87488903105259, 44.42930594086647, 43.28029319643974, 44.70197170972824, 43.762453123927116, 49.67321835458279, 50.54506257176399, 47.211809232831, 41.57459132373333, 40.72997264564037, 38.80566090345383, 46.455987989902496, 45.4233667999506, 41.36789761483669, 39.23657298088074, 38.88377331197262, 40.02640999853611, 40.0157667696476, 39.21526372432709, 39.90812614560127, 40.21405532956123, 40.66892892122269, 39.131242632865906, 39.618748873472214, 41.32474333047867, 40.36175720393658, 40.914186760783195, 40.017332285642624, 42.09917597472668, 45.11194311082363, 37.569537833333015, 46.065634936094284, 43.71478468179703, 47.040343433618546, 37.05079346895218, 37.06870190799236, 42.799732983112335, 44.63657721877098, 42.35049448907375, 37.99315430223942, 40.4302941262722, 40.086157992482185, 39.03449222445488, 39.3167182803154, 40.153893157839775, 38.443555533885956, 40.192309096455574, 39.946458488702774, 39.986496940255165, 40.118999630212784, 40.05344554781914, 40.85715562105179, 41.358466520905495, 42.590250223875046, 45.89460991322994, 44.606824815273285, 40.612433552742004, 42.014193534851074, 41.21141441166401, 44.08331550657749, 48.493579253554344, 46.71298339962959, 44.14732687175274, 44.667811542749405, 42.72048823535442, 42.52897851169109, 39.278142750263214, 41.65040485560894, 44.34088088572025, 44.235725328326225, 44.47210304439068, 45.394807532429695, 45.724018067121506, 45.919566974043846, 51.16211526095867, 57.56621941924095, 61.35533049702644, 61.50333635509014, 58.717227056622505, 58.94256256520748, 57.11431726813316, 60.35767883062363, 58.94695892930031, 58.68571154773235, 57.424107044935226, 56.77995800971985, 54.42566134035587, 62.48277559876442, 62.21034921705723, 68.00537645816803, 65.14113575220108, 59.70960460603237, 68.47695395350456, 70.06787538528442, 65.11106416583061, 70.7804511487484, 64.75743994116783, 60.735861137509346, 15.47072734683752, 0.7379651698283851, 1.7763302265666425, 0.401872432557866, 0.24093172716675326, 13.376015648245811, 71.99622631072998, 66.31172373890877, 62.30103515088558, 58.80516953766346, 49.187904596328735, 10.100009087473154, 27.521250620484352, 44.74310450255871, 67.57799059152603, 11.76659680902958, 0.3562140528811142, 0.19907352951122448, 0.14134429598925635, 0.06896732345921919, 0.06293927348451689, 0.032078850927064195, 0.061103882908355445, 0.07596144190756604, 0.06525018776301295, 0.06713324648444541, 0.053857233870076016, 0.025124719395535067, 0.07711845013545826, 0.5584043206181377, 36.78156651556492, 62.15869478881359, 50.73756404221058, 39.00752507150173, 35.71238748729229, 46.8016554415226, 64.94052931666374, 67.33625516295433, 79.15153875946999, 6.3954543974250555, 0.18243484577396885, 1.1194903473369777, 11.413837987929583, 78.80112916231155, 73.18075194954872, 78.70883211493492, 69.40813198685646, 70.11187702417374, 61.01749822497368, 62.854779437184334, 58.057666048407555, 61.61897175014019, 60.47136873006821, 67.14545980095863, 59.10059228539467, 60.98125956952572, 68.73550727963448, 68.71051222085953, 65.43404683470726, 68.72533142566681, 64.48285147547722, 67.57129535079002, 64.94369834661484, 66.70099765062332, 62.62345924973488, 64.51628968119621, 62.23040074110031, 61.41375616192818, 53.78781236708164, 48.53811286389828, 49.306902810931206, 48.872285932302475, 48.61313223838806, 49.08168129622936, 46.53770260512829, 47.58690230548382, 47.94214904308319, 47.01051503419876, 47.38619327545166, 45.48542506992817, 45.94871520996094, 47.9636786878109, 44.87545520067215, 49.969876036047935, 52.332186475396156, 48.34833204746246, 43.37348699569702, 40.886908024549484, 38.96888494491577, 46.53375081717968, 46.317318230867386, 43.80129083991051, 42.51763232052326, 41.15295074880123, 42.65005521476269, 42.00498282909393, 41.12385950982571, 42.64544226229191, 41.63867108523846, 43.81371237337589, 42.39138409495354, 43.026417419314384, 42.474861815571785, 43.02755355834961, 41.27992853522301, 42.41011708974838, 45.109773427248, 47.9358945786953, 40.70889137685299, 48.670854941010475, 47.1938855946064, 50.08788250386715, 40.72726719081402, 41.492120549082756, 44.74183917045593, 45.90523034334183, 43.47487315535545, 42.20181606709957, 42.7754332870245, 42.81566932797432, 42.71260745823383, 42.424628511071205, 41.619136333465576, 41.93717546761036, 42.164319679141045, 43.365404829382896, 43.2244323939085, 44.32001620531082, 41.98612064123154, 42.58793234825134, 44.34517465531826, 45.31462803483009, 49.06763345003128, 46.07099264860153, 41.680396646261215, 42.9403368383646, 41.303981244564056, 44.09465029835701, 50.14981538057327, 49.370359405875206, 45.67193426191807, 45.95843888819218, 44.742861315608025, 45.7512816041708, 43.31600748002529, 45.12990854680538, 45.90739622712135, 46.499883234500885, 45.12919798493385, 47.87266977131367, 48.33677686750889, 50.03469295799732, 54.75832588970661, 62.4024973064661, 64.04965952038765, 63.66743043065071, 62.146117463707924, 62.06929698586464, 60.449261516332626, 61.31639018654823, 60.891603380441666, 62.82674454152584, 60.06846494972706, 57.38019660115242, 57.537245973944664, 62.967363595962524, 62.92025372385979, 69.9765282869339, 66.93229123950005, 62.532062754034996, 66.64777010679245, 73.55593621730804, 66.9436526298523, 74.44467052817345, 66.49373397231102, 64.55823183059692, 17.82979656010866, 1.5122821577824652, 1.6644971212372184, 0.2479755101376213, 0.3126857557799667, 14.269694443792105, 80.09089395403862, 68.28577101230621, 73.89652714133263, 55.61029717326164, 33.84656600654125, 15.124622918665409, 33.01144681870937, 48.698517456650734, 77.79767140746117, 15.572203751653433, 0.39940360409673303, 0.2329247849411331, 0.05268944223644212, 0.019948512090195436, 0.04511693841777742, 0.04888549381576013, 0.2660391025710851, 0.13545614085160196, 0.10166142223170027, 0.10879438166739419, 0.1796387747162953, 0.08787456710706465, 0.32591486466117203, 1.0077271820046008, 51.58178374171257, 75.66845566034317, 61.18493624031544, 43.3762988448143, 45.036201775074005, 57.34524607658386, 74.235400557518, 73.12224268913269, 87.37916886806488, 7.159416703507304, 0.2917033707490191, 2.7489703288301826, 16.434110552072525, 76.79625034332275, 76.06141537427902, 80.28160572052002, 72.05074578523636, 73.93450230360031, 64.49469164013863, 65.6069527566433, 62.24408380687237, 65.37503600120544, 66.69984251260757, 69.96243104338646, 63.03039841353893, 64.37354654073715, 71.11313089728355, 70.74301555752754, 66.86254978179932, 71.74092561006546, 68.39172452688217, 69.68855693936348, 65.90446159243584, 68.82737874984741, 65.81841140985489, 68.72631937265396, 66.11602663993835, 63.22757363319397, 54.046175703406334, 52.65776440501213, 50.62202364206314, 51.27246133983135, 50.328204408288, 51.90460301935673, 47.01473280787468, 51.06799051165581, 50.780049562454224, 50.5106820166111, 49.98265095055103, 49.81990948319435, 47.57888473570347, 49.99195285141468, 48.56995515525341, 52.910770028829575, 55.02501837909222, 50.70659950375557, 42.458321303129196, 40.84988661110401, 38.62572155892849, 47.16113515198231, 48.69397670030594, 46.079614385962486, 45.22509343922138, 43.390133902430534, 45.116723254323006, 46.48708172142506, 43.918229565024376, 45.01522310078144, 45.27124956250191, 45.63026189804077, 46.01506344974041, 45.9666046500206, 47.736690267920494, 45.893789157271385, 47.24189221858978, 44.641965329647064, 48.06905463337898, 51.97464846074581, 43.84367756545544, 51.52081221342087, 49.253804460167885, 52.56510257720947, 43.542121946811676, 42.81850777566433, 49.06759925186634, 49.79782126843929, 46.82831101119518, 44.780103117227554, 46.2541314214468, 45.99849633872509, 45.11195071041584, 43.15873011946678, 44.496178552508354, 44.50427211821079, 44.12562623620033, 46.47152915596962, 45.54685637354851, 46.732031777501106, 44.701280146837234, 46.061990931630135, 48.46753925085068, 49.91817221045494, 50.09594187140465, 46.79743766784668, 41.01473316550255, 42.07385413348675, 40.940614342689514, 45.388161689043045, 51.59339211881161, 51.80834658443928, 46.30733996629715, 48.51332679390907, 47.7986079454422, 48.00392992794514, 43.61531741917133, 45.47374829649925, 48.95596124231815, 48.464347422122955, 45.727833062410355, 50.03361761569977, 50.23291692137718, 50.541095584630966, 56.24039076268673, 64.43745151162148, 64.44252043962479, 68.74468758702278, 65.29587864875793, 64.80445861816406, 63.182112872600555, 64.65242877602577, 64.11689311265945, 64.56070929765701, 63.738710805773735, 59.02007080614567, 56.37711122632027, 65.05991891026497, 64.56222161650658, 73.99056449532509, 67.66458794474602, 69.24236208200455, 70.69932550191879, 73.54310810565948, 70.6126369535923, 77.2128675878048, 70.92403024435043, 70.0021693110466, 19.455073848366737, 2.456591217778623, 4.005923643708229, 1.2480734288692474, 0.41417284752242267, 17.52353299409151, 89.08591568470001, 75.0360555946827, 80.5720317363739, 77.69353419542313, 64.81464207172394, 18.049622364342213, 44.10523273050785, 58.40130440890789, 89.02563571929932, 22.976464591920376, 0.8058899687603116, 0.4497098468709737, 0.3181870887055993, 0.1230405000387691, 0.19492891675326973, 0.12514814006863162], [0.10371323791332543, 0.02402697722573066, 0.0665829365607351, 0.062072010841802694, 0.018981692192028277, 0.06972502655116841, 0.20583761186571792, 1.4640753320418298, 42.87664085626602, 42.896092012524605, 41.33959673345089, 24.021575711667538, 25.69993045181036, 47.49137923121452, 58.33029001951218, 64.02872264385223, 64.46772068738937, 3.4907202143222094, 0.07802565887686796, 0.2620183245744556, 7.534940578043461, 79.03131321072578, 68.77870336174965, 76.78577050566673, 66.96630701422691, 70.47263726592064, 61.97904422879219, 64.82857972383499, 59.54593598842621, 59.173134192824364, 56.891466826200485, 60.57973891496658, 59.72585253417492, 67.45664790272713, 61.38442553579807, 63.63258250057697, 61.42524674534798, 64.58831861615181, 61.59097485244274, 63.84617283940315, 61.318613067269325, 62.267190366983414, 59.27218347787857, 62.3856870085001, 59.023703411221504, 54.94235761463642, 43.22412081062794, 47.304262071847916, 45.314183458685875, 44.54223208129406, 44.318690076470375, 48.16763274371624, 45.563111901283264, 48.67365159094334, 44.813203141093254, 45.79106546938419, 43.23914900422096, 45.60678295791149, 43.49890686571598, 45.73160246014595, 44.907487481832504, 45.1772616058588, 47.88782715797424, 45.61430275440216, 42.14973606169224, 42.90403738617897, 42.537847235798836, 38.55375722050667, 41.260971352458, 46.23838126659393, 43.54364946484566, 40.991850793361664, 39.96409334242344, 41.054665222764015, 37.828953713178635, 41.63425572216511, 38.861525505781174, 40.148550644516945, 39.364470317959785, 39.88916136324406, 38.23929749429226, 39.34152714908123, 40.382184907794, 41.723687723279, 41.879194378852844, 42.05575570464134, 41.86090975999832, 44.05910700559616, 42.37145036458969, 40.32537415623665, 43.23790267109871, 43.5401726514101, 37.519467920064926, 41.569655388593674, 40.39951577782631, 40.10167255997658, 38.78414265811443, 40.157639756798744, 38.806515857577324, 41.55360504984856, 39.51560340821743, 39.45533484220505, 40.70563115179539, 41.50952361524105, 41.42334423959255, 40.44992387294769, 39.753972217440605, 41.592526361346245, 42.6684196293354, 47.61054463684559, 41.594825237989426, 40.812622010707855, 42.45059251785278, 40.05864366889, 39.469318091869354, 43.910983353853226, 47.5520733743906, 43.53165730834007, 43.52591201663017, 44.75602000951767, 41.29155591130257, 42.00321972370148, 40.066630840301514, 44.75108787417412, 43.615241423249245, 44.58170436322689, 46.86668515205383, 47.961592599749565, 46.48461565375328, 47.604863941669464, 55.240751802921295, 59.167879074811935, 64.46952939033508, 57.7990747243166, 55.543549954891205, 60.13914875686169, 56.34023800492287, 59.29699994623661, 57.260936200618744, 61.37209139764309, 60.07044084370136, 59.91607792675495, 60.08286237716675, 62.881628796458244, 65.15600815415382, 63.328541815280914, 68.00559684634209, 59.68489833176136, 53.85128416121006, 67.38237708806992, 62.293234169483185, 69.32419449090958, 60.449664294719696, 69.17249903082848, 34.525490775704384, 1.0780966747552156, 1.3365446752868593, 0.23207651014672592, 0.06213822154677473, 3.8790320651605725, 64.31549325585365, 65.02990052103996, 67.03176990151405, 50.08556842803955, 76.84125512838364, 33.2024359703064, 23.45770876854658, 39.27781976759434, 68.25325235724449, 21.614176891744137, 0.8117545978166163, 0.2095987569191493, 0.03766405767237302, 0.07631894186488353, 0.0067855624274670845, 0.03750022115127649, 0.038065863845986314, 0.04004582478955854, 0.10642946872394532, 0.021019139894633554, 0.05331968888640404, 0.00493685076435213, 0.06385805230820552, 2.1531812986359, 53.10755766928196, 55.99649325013161, 50.44015780091286, 31.25127486884594, 30.389724299311638, 49.91716906428337, 67.19590589404106, 70.08049070835114, 71.14930495619774, 3.6188685754314065, 0.027045610950153787, 0.6584408401977271, 8.315943069756031, 85.78098982572556, 71.96049302816391, 82.06779107451439, 69.31480139493942, 75.34830003976822, 65.54987981915474, 67.45059102773666, 62.703969329595566, 60.93713253736496, 59.31902356445789, 64.14302051067352, 64.85744297504425, 69.38049226999283, 63.41814860701561, 64.67078179121017, 64.69915106892586, 65.73363035917282, 65.150665640831, 66.5139488875866, 62.98400670289993, 65.57948023080826, 62.61345058679581, 64.13035199046135, 60.36284655332565, 56.89388729631901, 46.11046873033047, 51.22616462409496, 47.63083554804325, 47.620754688978195, 48.604252114892006, 48.96532393991947, 47.00608067214489, 50.935476422309875, 47.034400552511215, 49.24334742128849, 44.327866584062576, 46.974648758769035, 47.68871784210205, 47.34469950199127, 45.38020871579647, 48.5396783798933, 49.40281726419926, 46.553555354475975, 43.32200735807419, 43.19366544485092, 42.38410368561745, 39.424324706196785, 40.773081332445145, 44.68742609024048, 45.63395909965038, 43.614375069737434, 43.328581005334854, 42.852135971188545, 41.389149874448776, 42.83120669424534, 41.36160135269165, 42.05599129199982, 42.28684030473232, 40.99459044635296, 40.46076849102974, 43.932763785123825, 43.39349292218685, 44.590025916695595, 44.48999248445034, 45.30268147587776, 45.09235896170139, 47.29426100850105, 44.34900104999542, 43.2242614030838, 46.32642634212971, 45.240505412220955, 40.013619884848595, 42.67622821033001, 42.16036409139633, 42.83063292503357, 41.09517864882946, 43.027557358145714, 40.93989998102188, 42.022461891174316, 41.56675614416599, 39.7974456846714, 42.392326444387436, 43.34856413304806, 43.45757648348808, 43.20054307579994, 40.14506623148918, 43.29103522002697, 46.10386088490486, 50.51507078111172, 41.76050394773483, 41.49216614663601, 42.33711160719395, 40.41593849658966, 40.64631253480911, 44.37558062374592, 49.402703270316124, 44.88324858248234, 43.99917282164097, 46.204536482691765, 44.15474407374859, 44.17870178818703, 43.77071388065815, 45.99561609327793, 46.05091452598572, 47.30378329753876, 47.489323541522026, 48.02807003259659, 49.11097772419453, 49.34229791164398, 58.59989695250988, 60.084351897239685, 65.90668067336082, 59.894977658987045, 58.44390012323856, 61.71938896179199, 60.12224726378918, 61.46320290863514, 60.865928158164024, 62.017619758844376, 61.09750293195248, 60.85054278373718, 61.321922689676285, 63.93267899751663, 68.17089557647705, 67.51490637660027, 68.67282584309578, 62.642785012722015, 54.221315905451775, 68.48823934793472, 65.44875964522362, 70.83022087812424, 64.58183616399765, 72.03986316919327, 38.82706515491009, 1.7017858265899122, 1.5513052325695753, 0.04075701748661231, 0.10037706146249548, 4.174006674438715, 68.97251576185226, 69.08572688698769, 74.52682211995125, 54.91061411798, 60.25671064853668, 24.706249572336674, 31.354268342256546, 46.33996121585369, 77.6520100235939, 27.006777226924896, 0.864013668615371, 0.10998302765074186, 0.04228696234349627, 0.04607196373399347, 0.04941652645356953, 0.0180440238545998, 0.21069674956379458, 0.1363578948075883, 0.20376261149067432, 0.16870302089955658, 0.1672188294469379, 0.210017075878568, 0.5966010584961623, 2.6343475794419646, 66.67850285768509, 64.82622385025024, 62.71344602108002, 38.56566958129406, 40.53455293178558, 66.20062530040741, 77.26658910512924, 76.7266608774662, 78.91369432210922, 4.6015849057585, 0.21201959811151028, 0.9989412222057581, 9.312678035348654, 87.22830936312675, 76.75669446587563, 83.79058822989464, 71.96731746196747, 77.24309116601944, 67.87957280874252, 70.69643005728722, 66.6157454252243, 64.95106235146523, 62.9266943782568, 68.29603806138039, 65.9189160168171, 72.6546473801136, 66.73009648919106, 68.87932196259499, 66.66711866855621, 69.39523547887802, 68.40575337409973, 68.63770812749863, 66.46283403038979, 67.92507916688919, 65.55605828762054, 66.5935318171978, 63.125039935112, 58.842434138059616, 47.37369194626808, 53.56640964746475, 49.75059740245342, 47.90136583149433, 50.806317552924156, 52.13984079658985, 49.456728771328926, 54.04538914561272, 48.35444591939449, 51.15002050995827, 47.2088909894228, 49.89109866321087, 50.64319610595703, 49.01097849011421, 47.07582972943783, 50.565893054008484, 50.52364692091942, 48.952670618891716, 44.2868097871542, 44.48377221822739, 42.4777914583683, 40.15997663140297, 40.6191211938858, 48.72611157596111, 47.70580172538757, 46.629137098789215, 47.52818785607815, 46.01157143712044, 43.84545587003231, 48.1549946218729, 44.148687198758125, 46.4627630263567, 45.79481586813927, 43.464172929525375, 43.33065189421177, 47.45792202651501, 47.59202063083649, 46.65129750967026, 47.43481546640396, 47.05733232200146, 46.13851882517338, 50.905146449804306, 46.48884102702141, 46.13688111305237, 49.72186714410782, 47.77115061879158, 41.04306064546108, 46.94420479238033, 44.84490104019642, 46.124049201607704, 43.28067697584629, 44.31072950363159, 42.08687223494053, 44.83423501253128, 45.93157812952995, 42.18276388943195, 47.03137971460819, 47.08158262073994, 46.68155908584595, 45.21269850432873, 43.79184454679489, 47.532318234443665, 49.964377731084824, 51.32257305085659, 43.11716414988041, 41.96699246764183, 43.22334185242653, 40.55506803095341, 40.303111150860786, 46.78275525569916, 50.413924008607864, 48.141311556100845, 45.904003009200096, 49.47648011147976, 46.28008022904396, 45.845828130841255, 45.264292135834694, 48.783070519566536, 48.2303711771965, 49.52338099479675, 51.41126789152622, 50.78538067638874, 51.89088575541973, 51.98117271065712, 59.58773374557495, 62.99137070775032, 68.13664421439171, 62.45333477854729, 59.29884284734726, 64.99517038464546, 62.65745982527733, 63.89287233352661, 61.80907554924488, 63.22852358222008, 62.1256859600544, 62.96029977500439, 63.67827124893665, 66.98295772075653, 71.00738257169724, 69.13718372583389, 72.68449857831001, 66.19460642337799, 61.554652601480484, 70.83513021469116, 69.11753877997398, 74.5038865506649, 68.02274912595749, 77.2919337451458, 45.71218550205231, 1.817012862302363, 4.623808013275266, 1.1276026745326817, 0.12479320052079856, 5.139449369162321, 76.64739713072777, 77.46698275208473, 83.26457485556602, 65.54425612092018, 94.17774885892868, 44.44581985473633, 40.20294092595577, 54.8145666718483, 87.82585009932518, 38.49533535540104, 1.1189474514685571, 0.32751101651228964, 0.1862036794773303, 0.16503623250173405, 0.11359557989635505, 0.13379181531490758], [0.04712422894954216, 0.02351995306526078, 0.020627233971026726, 0.05661313247401267, 0.03264687962655444, 0.07891018758527935, 0.1265610705013387, 2.6109785959124565, 55.10924085974693, 42.702944576740265, 45.309578105807304, 28.103012703359127, 35.42953446507454, 47.63990566134453, 57.32013702392578, 64.42036762833595, 62.3641649633646, 4.052714807912707, 0.10845138327567838, 0.24288044369313866, 16.29606395959854, 80.71447089314461, 65.82971960306168, 74.79488253593445, 65.75713589787483, 73.26370909810066, 64.38990086317062, 67.15480729937553, 59.808137118816376, 57.97034293413162, 52.83743016421795, 57.69419655203819, 56.01579621434212, 60.71250759065151, 59.105193838477135, 61.89005300402641, 59.18784320354462, 61.16361938416958, 59.809535443782806, 62.2819297760725, 55.62621831893921, 58.40766526758671, 56.14115908741951, 55.64178988337517, 52.62331925332546, 46.31717383861542, 46.13128021359444, 47.07807540893555, 45.28894901275635, 46.33268840610981, 43.369265422225, 45.40367245674133, 45.13235941529274, 46.92459784448147, 44.996516704559326, 43.44482056796551, 43.67897540330887, 45.42504630982876, 45.05279928445816, 45.78509978950024, 44.5110509544611, 45.337122827768326, 47.82027058303356, 48.042026683688164, 43.6953791230917, 44.68181759119034, 41.15016929805279, 44.43383149802685, 40.984270200133324, 42.11894251406193, 39.45934362709522, 46.32014147937298, 39.0107548981905, 41.3052199780941, 39.23022352159023, 40.01356288790703, 37.36830823123455, 39.54707331955433, 39.799987748265266, 40.906902551651, 39.37058039009571, 41.36785201728344, 38.7304325401783, 42.65653006732464, 41.80161394178867, 46.3155285269022, 40.90426929295063, 42.977210059762, 40.47103933990002, 40.7070142775774, 37.80913017690182, 40.146639347076416, 39.456782564520836, 39.743477180600166, 40.286293253302574, 39.7364741563797, 39.399249851703644, 39.449543952941895, 39.93303380906582, 41.58833518624306, 38.20892192423344, 41.25821650028229, 38.84692668914795, 41.682402938604355, 40.18964543938637, 39.03882019221783, 42.816873863339424, 48.66343013942242, 43.91434237360954, 42.1983278542757, 39.5322997123003, 40.34794494509697, 40.55023469030857, 40.453655272722244, 38.55211190879345, 42.948400005698204, 46.797494664788246, 45.458305925130844, 41.04242227971554, 44.64539274573326, 40.5680101364851, 41.232624873518944, 38.620477840304375, 45.239304676651955, 44.016028717160225, 45.45795254409313, 45.10387994349003, 44.03283901512623, 45.27113176882267, 49.56607550382614, 58.4642518311739, 58.74309606850147, 56.32409267127514, 51.88570663332939, 61.57289162278175, 61.44786313176155, 63.13192896544933, 61.346336379647255, 61.33978933095932, 66.14382594823837, 61.78857184946537, 61.61508075892925, 62.0515101402998, 65.51787793636322, 62.24268928170204, 65.08353844285011, 63.54375846683979, 64.58868339657784, 54.15497146546841, 63.69076877832413, 65.44846326112747, 66.58027812838554, 64.57995906472206, 64.26516875624657, 62.01666221022606, 5.694782920181751, 1.1866963910870254, 0.04836113679630216, 0.006348603037622524, 0.9836951340548694, 53.695572316646576, 64.92312625050545, 69.72797602415085, 49.94822859764099, 82.20765396952629, 40.817303359508514, 19.5129257440567, 41.96884676814079, 65.00156924128532, 37.75101229548454, 0.7454140170011669, 0.09100448587560095, 0.022518725345435087, 0.039683486029389314, 0.0558702463604277, 0.05500624545675237, 0.045748569173156284, 0.07720082110608928, 0.024773974837444257, 0.017351470196445007, 0.09964201613911428, 0.10125581626198255, 0.1423326734220609, 3.4914882481098175, 66.03508338332176, 53.29970195889473, 52.846010103821754, 36.902669817209244, 41.35326839983463, 53.88697184622288, 64.66637402772903, 69.78102877736092, 69.45986241102219, 4.612176837399602, 0.14076120540266857, 0.5232135183177888, 20.12846991419792, 85.53151041269302, 67.0418393611908, 78.39813798666, 69.82091903686523, 74.46620777249336, 65.58984607458115, 70.37068113684654, 63.98611932992935, 62.6461136341095, 55.74636027216911, 60.56990884244442, 60.473511815071106, 62.74298943579197, 63.159105107188225, 63.295605182647705, 61.01875975728035, 63.37325781583786, 60.85799798369408, 62.11929850280285, 57.99480602145195, 60.738604590296745, 58.32143649458885, 58.258831053972244, 53.1737957149744, 49.753762632608414, 49.61753994226456, 49.10239778459072, 47.63308122754097, 47.99229495227337, 47.36722469329834, 48.237077817320824, 47.627168744802475, 48.256107196211815, 47.617977038025856, 45.475670993328094, 46.0410350561142, 47.18798831105232, 45.91783046722412, 48.748416379094124, 47.2412234544754, 48.681703358888626, 49.93214026093483, 48.30868497490883, 45.02400062978268, 45.505993366241455, 41.672618463635445, 45.92028133571148, 39.975374937057495, 41.91177003085613, 40.07007345557213, 48.127658888697624, 42.46107995510101, 43.56178969144821, 40.49224600195885, 42.514771074056625, 39.90684561431408, 43.087369948625565, 44.28825370967388, 43.32799583673477, 40.14160081744194, 43.90509366989136, 40.09622365236282, 44.23521615564823, 45.04547707736492, 47.433918714523315, 44.460908845067024, 43.70379187166691, 42.390190958976746, 43.16124938428402, 40.901305451989174, 42.5345604121685, 42.14487612247467, 43.145940005779266, 41.96643769741058, 42.7576844394207, 42.99439653754234, 44.105339124798775, 43.31183910369873, 43.75896491110325, 41.38802893459797, 42.64186665415764, 41.41968123614788, 44.82075713574886, 43.328846991062164, 41.1951968818903, 44.750346913933754, 48.95806632936001, 42.28317730128765, 42.65078857541084, 40.27278117835522, 41.174495592713356, 41.02674052119255, 40.86551897227764, 38.82496006786823, 45.67518688738346, 48.499712124466896, 47.392782121896744, 44.13556270301342, 46.54867261648178, 45.053806230425835, 45.715468525886536, 41.544538736343384, 46.98556937277317, 46.25020623207092, 47.01501399278641, 46.4885750412941, 47.96428665518761, 45.5461610108614, 52.566854283213615, 61.69986180961132, 61.66768133640289, 58.4611701965332, 57.039301693439484, 61.863412633538246, 62.293002381920815, 63.87578085064888, 62.31834702193737, 63.928180038928986, 65.58597028255463, 63.22543814778328, 63.40824633836746, 63.45084585249424, 66.83093547821045, 64.49075505137444, 65.91865003108978, 67.40524426102638, 67.02501386404037, 58.72061647474766, 65.01144111156464, 70.07082402706146, 67.41921991109848, 69.03202056884766, 68.3247797191143, 68.93802121281624, 6.8336340598762035, 1.232178050559014, 0.3277872141916305, 0.06564754847204313, 0.9898665966466069, 60.56147709488869, 69.84300345182419, 75.37383466959, 56.321448013186455, 76.2842658162117, 33.45902480185032, 28.0400462821126, 47.04075001180172, 72.81799301505089, 43.86895380914211, 0.6880294962320477, 0.11913010166608728, 0.03409241631743498, 0.08536457913578488, 0.040423407263006084, 0.06084685490350239, 0.16662533394992352, 0.134726045653224, 0.13711674080695957, 0.09165046605630778, 0.18382105889031664, 0.23398221179377288, 0.2846502960892394, 4.16743160225451, 77.85970687866211, 60.36962538957596, 67.1977449953556, 40.72925068438053, 51.32312022149563, 66.45420849323273, 72.58563548326492, 75.9711854159832, 80.3380934894085, 6.284352159127593, 0.20255356386769563, 0.9029219776857644, 21.15886442363262, 88.53920862078667, 69.72669169306755, 80.73956474661827, 73.3063580095768, 78.03722575306892, 67.5148455798626, 74.21697154641151, 67.97935545444489, 65.45065954327583, 59.8306243121624, 64.36298310756683, 64.12912845611572, 66.16011187434196, 65.47531262040138, 67.0562481880188, 64.25582885742188, 66.76593616604805, 65.23935288190842, 64.93393287062645, 60.967724695801735, 64.71701011061668, 61.89229868352413, 61.501812636852264, 56.729618310928345, 52.843042463064194, 52.84948691725731, 50.592476427555084, 49.236192405223846, 48.86625945568085, 48.13525088131428, 49.0819700807333, 50.38199432194233, 50.37423133850098, 49.952586963772774, 49.012756794691086, 49.385835975408554, 49.35617096722126, 49.6123456209898, 52.00350411236286, 50.146353766322136, 50.368801429867744, 52.26640060544014, 51.428412571549416, 45.542095229029655, 46.18266485631466, 42.593293860554695, 46.54743768274784, 41.58338785171509, 44.74126920104027, 39.42855767905712, 50.71577601134777, 45.814673602581024, 47.77229055762291, 44.3072222918272, 45.2103616297245, 42.98405349254608, 44.84246917068958, 46.23173162341118, 46.817139610648155, 43.93012672662735, 45.74856095016003, 44.658163860440254, 47.04670429229736, 47.74956397712231, 49.645468443632126, 47.25592106580734, 46.645594015717506, 46.14935204386711, 47.13448718190193, 41.88164904713631, 44.37002532184124, 45.36725141108036, 44.542391672730446, 46.26873403787613, 45.52203230559826, 46.53098836541176, 46.9156189262867, 47.29935273528099, 45.56319549679756, 43.403657376766205, 46.078128665685654, 44.759986996650696, 49.1433671861887, 45.712637677788734, 42.755005583167076, 47.475336492061615, 53.29021766781807, 42.822242975234985, 41.45567670464516, 40.46508885920048, 40.045047998428345, 40.41954070329666, 41.213348507881165, 39.32438246905804, 45.14854654669762, 49.885607957839966, 50.56255303323269, 47.06034176051617, 48.89007657766342, 49.030171260237694, 48.43292310833931, 43.53312022984028, 48.28309714794159, 49.41689170897007, 49.66957435011864, 48.422329276800156, 48.14567752182484, 48.888013288378716, 55.44934161007404, 65.04735678434372, 64.61924895644188, 63.64550940692425, 58.98054912686348, 65.50523981451988, 65.4060423374176, 66.18255347013474, 63.78908470273018, 65.80328062176704, 71.07992067933083, 66.63964614272118, 66.75718903541565, 67.37425312399864, 71.35066375136375, 66.80695876479149, 68.29919189214706, 70.25005280971527, 68.38603243231773, 62.03636795282364, 68.79422172904015, 73.10803905129433, 71.01582571864128, 72.99317121505737, 71.38941407203674, 72.77585327625275, 7.212633797898889, 2.641870938241482, 0.8594539726618677, 0.14273871725890785, 1.498890845105052, 65.42612805962563, 77.07166716456413, 84.24853205680847, 64.16758999228477, 97.79346004128456, 51.6777665913105, 34.67520274221897, 58.143393248319626, 82.425557076931, 56.376252472400665, 0.8046561037190259, 0.21241554873995483, 0.09770402364665642, 0.27037648076657206, 0.1566252057091333, 0.13011971313972026], [0.013501140329026384, 0.06437862437451258, 0.049768044700613245, 0.02472333439072827, 0.02661326539964648, 0.06086575740482658, 0.21807841752888635, 5.773827228695154, 60.038404762744904, 45.92706777155399, 36.07732750475407, 34.21510063111782, 39.33488130569458, 35.890077352523804, 59.65455695986748, 62.27722182869911, 51.34038269519806, 0.6889363413210958, 0.19486470613628626, 0.606071159709245, 23.930376805365086, 78.42925071716309, 69.51747491955757, 74.91331458091736, 65.69093585014343, 69.02463376522064, 61.02811485528946, 63.809421211481094, 58.04421477019787, 57.9149305075407, 56.791163608431816, 57.227262407541275, 55.57745173573494, 58.02918657660484, 57.92344205081463, 62.74797476828098, 57.1024315059185, 61.35642483830452, 54.57739099860191, 59.11205247044563, 52.90921211242676, 52.773430198431015, 51.2600702047348, 48.427345007658005, 46.26950539648533, 47.3047636449337, 44.06410373747349, 43.83793607354164, 45.96477314829826, 44.85875129699707, 44.937870651483536, 45.62122218310833, 45.08832737803459, 43.96819308400154, 44.003527387976646, 42.196443155407906, 41.658057644963264, 43.241227492690086, 43.35865639150143, 43.86777587234974, 43.869212195277214, 45.87660267949104, 45.77740520238876, 47.922781482338905, 43.26596036553383, 42.616533413529396, 45.02392463386059, 48.86289283633232, 48.364344388246536, 47.92758822441101, 41.58474437892437, 44.007342383265495, 44.72556084394455, 39.72826659679413, 39.12632569670677, 39.54985857009888, 38.6716078966856, 39.80204723775387, 38.227126747369766, 38.16332437098026, 37.30835884809494, 39.83421631157398, 38.40676590800285, 39.755533933639526, 40.58381348848343, 43.16359385848045, 40.96467845141888, 42.39070013165474, 39.61074650287628, 39.920863062143326, 42.99431674182415, 41.984026953577995, 39.002820923924446, 40.609690099954605, 40.6348979473114, 40.30452847480774, 38.91019329428673, 40.7655843347311, 38.957398161292076, 39.40941050648689, 38.235341906547546, 38.826780170202255, 40.891520977020264, 40.099981650710106, 41.59775868058205, 43.42606857419014, 45.74324503540993, 42.90983967483044, 37.942411825060844, 41.54367998242378, 44.72216762602329, 42.654744163155556, 39.999119862914085, 39.0303086489439, 40.46382732689381, 44.312447011470795, 45.505358800292015, 43.311379328370094, 43.32986153662205, 41.413080990314484, 41.63148947060108, 41.73969626426697, 40.422063767910004, 43.714628890156746, 45.50393767654896, 43.1006084382534, 42.868463695049286, 43.809023424983025, 45.099631771445274, 51.7065766453743, 56.692452505230904, 57.550940439105034, 51.03606462478638, 53.85180853307247, 60.056062415242195, 58.71288388967514, 59.0841543674469, 58.02979074418545, 61.778886169195175, 59.73167762160301, 61.39360584318638, 62.447194308042526, 62.58438594639301, 61.206997856497765, 64.49327811598778, 62.44773007929325, 63.7530854344368, 62.14842773973942, 67.47653603553772, 63.77044290304184, 67.80590236186981, 60.76964512467384, 66.32791846990585, 59.08413156867027, 75.68386003375053, 20.078221410512924, 0.82410684437491, 0.20930275873979554, 0.020338948561402503, 0.1964319439139217, 48.309752717614174, 67.1466301381588, 65.24413302540779, 61.062411814928055, 52.053946405649185, 30.7636983320117, 21.876243129372597, 43.06800998747349, 67.01334089040756, 43.954141438007355, 0.9784821700304747, 0.05871618603123352, 0.028739496228809003, 0.056771959498291835, 0.08289537960081361, 0.03958518856961746, 0.03418962653086055, 0.025215252135240007, 0.034897030564025044, 0.04568007636407856, 0.10786420345539227, 0.06720103425323032, 0.2189755256404169, 6.2632138933986425, 73.98389965295792, 55.03061927855015, 43.00434060394764, 31.887413933873177, 35.184082835912704, 44.70781959593296, 67.30009630322456, 70.35631790757179, 59.41930778324604, 0.6992141366936266, 0.10264727636240423, 0.47440115944482386, 24.656943418085575, 83.1062525510788, 72.63686433434486, 77.2399753332138, 68.9395335316658, 70.91141492128372, 65.96120774745941, 67.0206592977047, 59.73866164684296, 59.065406173467636, 58.8813516497612, 59.9762286990881, 58.120324686169624, 61.0798604786396, 59.90954987704754, 64.42776203155518, 59.982711151242256, 63.01427207887173, 56.9443865865469, 60.639980882406235, 55.34281812608242, 53.51146459579468, 54.43726971745491, 50.71840927004814, 49.911659359931946, 48.930931985378265, 46.99695736169815, 45.5483914911747, 47.98721842467785, 47.280061170458794, 46.94445177912712, 47.82935589551926, 47.90473625063896, 45.9935338050127, 45.746296271681786, 44.800580218434334, 44.81986038386822, 46.88693426549435, 45.9725247323513, 47.080294489860535, 46.99493207037449, 48.649013713002205, 47.99726888537407, 50.79510435461998, 43.113292157649994, 42.663232907652855, 44.81449507176876, 46.650104373693466, 46.37433037161827, 46.036300510168076, 41.11282490193844, 43.95766764879227, 46.53415359556675, 41.4809263497591, 42.25100822746754, 41.30140878260136, 42.23093010485172, 43.182243257761, 41.3190246373415, 40.62178485095501, 41.05401545763016, 41.8451102077961, 41.338399797677994, 42.38558940589428, 42.72374466061592, 45.45909248292446, 44.07556772232056, 45.791829228401184, 41.99650928378105, 41.172667890787125, 45.75052164494991, 44.734801948070526, 42.163111343979836, 43.76508638262749, 43.39541181921959, 43.41341905295849, 40.843081176280975, 41.5176247805357, 40.96547640860081, 42.28283531963825, 41.59280374646187, 41.53166122734547, 42.46837556362152, 42.33904950320721, 44.672382697463036, 45.44770449399948, 46.11936405301094, 44.217091128230095, 39.49188508093357, 42.88417585194111, 46.504298597574234, 43.383358865976334, 41.17414601147175, 40.66381439566612, 38.93325425684452, 44.25655961036682, 47.24856086075306, 45.46806760132313, 45.26038594543934, 44.94681537151337, 41.19198605418205, 43.45572218298912, 42.337924763560295, 47.96341270208359, 46.14413112401962, 45.92379614710808, 45.06888002157211, 45.94717629253864, 46.31200611591339, 53.14239040017128, 61.39660008251667, 60.71972340345383, 54.057214111089706, 56.16382487118244, 62.448573634028435, 60.54244011640549, 62.285440787673, 61.75861045718193, 64.2101401090622, 61.49450182914734, 63.58400970697403, 63.04615996778011, 64.29916933178902, 63.284243792295456, 67.52470225095749, 65.7840384542942, 66.78116574883461, 65.11935532093048, 69.9738684296608, 66.84488072991371, 70.48903718590736, 63.91453877091408, 70.67867740988731, 61.599038019776344, 79.59921553730965, 21.753435619175434, 0.3462418739218265, 0.43043383746407926, 0.08711246307939291, 0.16077666106866673, 50.96810907125473, 72.22505003213882, 73.72546792030334, 63.78205507993698, 57.83043444156647, 30.412834659218788, 26.866350062191486, 51.57302141189575, 72.0606404542923, 54.18503165245056, 1.0064024780876935, 0.20267714629881084, 0.06591301469597965, 0.018337227847951, 0.054454959608847275, 0.01271920054932707, 0.11730936850653961, 0.18940603185910732, 0.15023256826680154, 0.10531646243180148, 0.23525141790742055, 0.3042847034521401, 0.3436247049830854, 7.974269203841686, 88.99836078286171, 64.41763937473297, 55.00373192131519, 45.44499523937702, 53.55862006545067, 51.80349804461002, 77.04696848988533, 73.98425683379173, 69.47575315833092, 1.007729556877166, 0.2860931202303618, 1.2335159350186586, 26.640009507536888, 86.29392430186272, 74.78611260652542, 79.21554252505302, 72.83414974808693, 72.90816217660904, 69.12122458219528, 70.25303944945335, 62.53036044538021, 64.28647041320801, 61.50022052228451, 62.21451759338379, 62.098388224840164, 65.18688529729843, 63.869807571172714, 69.43820357322693, 64.33674171566963, 65.46837419271469, 61.13856352865696, 65.33849716186523, 59.671234264969826, 56.20847247540951, 58.57709817588329, 53.63403841853142, 52.904929742217064, 51.73936128616333, 49.0490410476923, 47.891113981604576, 50.85069917142391, 48.32087852060795, 48.01725581288338, 51.465954557061195, 51.67397439479828, 48.389563634991646, 49.00870241224766, 47.427804842591286, 46.66013963520527, 48.689618334174156, 48.35884988307953, 48.06799829006195, 49.342651292681694, 51.212933734059334, 49.22486141324043, 52.293158769607544, 44.96565096080303, 42.38082826137543, 46.49356037378311, 50.253363624215126, 49.10379610955715, 48.488795310258865, 42.208670899271965, 43.74316155910492, 49.05904971063137, 45.56430883705616, 43.037300035357475, 43.890719041228294, 45.919737964868546, 44.78148624300957, 44.07465197145939, 43.9958555996418, 42.85249315202236, 45.870086029171944, 43.76765124499798, 45.02285689115524, 45.29592543840408, 49.44872260093689, 46.090280413627625, 48.932045325636864, 45.06522461771965, 44.836879670619965, 48.26060615479946, 45.848837569355965, 42.97635890543461, 45.290902107954025, 45.583539605140686, 46.054212749004364, 43.4439542144537, 43.474728763103485, 45.42571507394314, 45.49646347761154, 44.2280687391758, 43.64174500107765, 46.69697865843773, 45.8911406993866, 46.8425602465868, 47.26199693977833, 47.485413551330566, 43.974884524941444, 40.34211985766888, 43.10184717178345, 46.03856898844242, 43.77985619008541, 41.33612371981144, 40.29692888259888, 41.269748881459236, 46.31350703537464, 48.453491404652596, 47.96697311103344, 48.029498755931854, 46.48227497935295, 46.48284114897251, 45.6427214294672, 45.62630631029606, 47.911686077713966, 50.93492165207863, 49.18103076517582, 47.293235063552856, 48.14266808331013, 48.96361403167248, 57.01592154800892, 63.4758523106575, 63.889239728450775, 59.326288774609566, 60.903264954686165, 65.79520985484123, 62.052862867712975, 66.23971000313759, 63.601500168442726, 68.11800241470337, 64.63818714022636, 68.32404255867004, 67.0730508863926, 67.31071293354034, 66.11756935715675, 69.75144356489182, 68.59791666269302, 69.28624212741852, 68.50936621427536, 73.95736947655678, 69.89724934101105, 72.83247783780098, 66.65109112858772, 73.8778929412365, 64.1116113960743, 85.3267090022564, 24.38902359455824, 2.198988553136587, 1.234288599807769, 0.18517331132898107, 0.4997341625858098, 57.97986522316933, 81.75898164510727, 78.72192621231079, 76.12428680062294, 67.85131752490997, 42.468250170350075, 34.25777614116669, 61.40783227980137, 81.71949416399002, 68.58270227909088, 1.4397454750724137, 0.2920817770063877, 0.18361585505772382, 0.10603212285786867, 0.19614801305579022, 0.07640601063030772], [0.026110965009138454, 0.029952334371046163, 0.06921629916178063, 0.011230481995880837, 0.019195217355445493, 0.17060685233445838, 0.27924565016292036, 6.259395098313689, 56.402414068579674, 41.21416166424751, 37.27697253227234, 45.67472331225872, 55.12998014688492, 33.78730818629265, 62.80598625540733, 61.487422809004784, 47.184731885790825, 0.10177509699133225, 0.17777124914573506, 0.5374441109597683, 30.714817754924297, 79.54672515392303, 70.04657372832298, 71.10295504331589, 65.81915616989136, 67.11829125881195, 61.56095266342163, 61.185491010546684, 58.23977507650852, 55.64701460301876, 55.41976019740105, 56.31257548928261, 54.917373955249786, 56.01694755256176, 60.04396766424179, 58.353886753320694, 58.10618184506893, 56.34471036493778, 54.906251952052116, 52.51833088696003, 47.894518598914146, 45.84327846765518, 45.875892117619514, 47.08268076181412, 45.80163270235062, 45.12642793357372, 45.29202684760094, 43.90857048332691, 43.957717046141624, 44.20606032013893, 46.39833748340607, 44.09846909344196, 44.74802523851395, 44.607732966542244, 44.93649512529373, 43.6314095556736, 42.96042636036873, 43.22985850274563, 42.36198887228966, 44.08173859119415, 45.00085227191448, 40.18931865692139, 46.03288069367409, 48.17671425640583, 45.9735506772995, 45.299159064888954, 44.94412511587143, 47.42399364709854, 48.04149851202965, 48.74079018831253, 47.02653497457504, 42.635407000780106, 45.57140685617924, 43.32806043326855, 40.34281902015209, 40.65548524260521, 37.297567427158356, 37.98743560910225, 40.26169337332249, 39.664422422647476, 38.01309183239937, 39.97839577496052, 39.574963822960854, 41.71616792678833, 40.985136553645134, 42.42760755121708, 41.71421103179455, 41.837381422519684, 39.257521256804466, 39.812523275613785, 40.15879109501839, 41.77763722836971, 40.379179269075394, 41.090440303087234, 39.01054210960865, 41.747010871768, 40.140362083911896, 39.43837635219097, 38.91444906592369, 41.82750955224037, 39.38785046339035, 39.55324798822403, 38.46519537270069, 43.20992857217789, 44.47871468961239, 43.62756036221981, 45.2642997354269, 49.45915304124355, 45.51950924098492, 47.064054161310196, 46.85522496700287, 41.61847896873951, 39.863759726285934, 38.98176625370979, 38.60381193459034, 41.677558198571205, 44.491960778832436, 42.07987301051617, 43.51882919669151, 43.23818005621433, 41.188771426677704, 40.24000033736229, 40.955064967274666, 42.88852281868458, 45.45394375920296, 44.09056171774864, 46.15505553781986, 43.975579887628555, 45.76465308666229, 51.66984401643276, 56.93183206021786, 54.15078029036522, 51.47516906261444, 54.42161835730076, 56.953327506780624, 57.55782566964626, 58.65291550755501, 58.74193333089352, 61.28268979489803, 59.317351654171944, 61.29648685455322, 61.2507601082325, 61.43301732838154, 61.31583921611309, 60.61104543507099, 61.47405132651329, 63.405924662947655, 64.00392517447472, 66.08945846557617, 62.21759922802448, 64.75737914443016, 58.104821518063545, 64.1415385901928, 60.16440600156784, 74.74636673927307, 35.021326169371605, 0.11890057023265399, 0.4980650427751243, 0.28075571288354695, 0.03802700499363709, 37.957265228033066, 71.40663474798203, 65.08735343813896, 63.75281944870949, 42.292243614792824, 26.24547477811575, 17.59538523852825, 34.86573211848736, 55.610186979174614, 64.0898385643959, 2.9912284668534994, 0.16983243607683107, 0.02959075445687631, 0.04007854236988351, 0.010598708377074217, 0.04537602588243317, 0.0323506736458512, 0.02750353276496753, 0.03692612168379128, 0.047696142792119645, 0.09870241265161894, 0.16411997698014602, 0.3413523081690073, 9.071169644594193, 71.44464030861855, 50.677029490470886, 45.66950239241123, 45.96622087061405, 49.817956387996674, 39.84145872294903, 71.09101608395576, 69.51413869857788, 54.88476410508156, 0.1410985560505651, 0.275771597516723, 0.5200968543067575, 34.95973527431488, 82.20155909657478, 70.32383725047112, 72.70444750785828, 66.88735485076904, 67.61378467082977, 63.755509704351425, 63.755448907613754, 60.28275825083256, 59.07027371227741, 57.592909187078476, 59.526055455207825, 57.363359704613686, 59.65068116784096, 63.230218291282654, 61.419406458735466, 59.7975242882967, 58.856299594044685, 57.75449551641941, 54.679385125637054, 50.873528346419334, 48.40159758925438, 48.90760883688927, 47.403235360980034, 47.78108328580856, 48.25140684843063, 47.30344131588936, 46.84516690671444, 47.42658510804176, 46.111042499542236, 48.544876500964165, 47.07643389701843, 47.68896482884884, 46.095090955495834, 47.1008437871933, 45.13804771006107, 45.41270837187767, 45.707656145095825, 45.33995747566223, 47.02369652688503, 47.39739127457142, 43.47427658736706, 48.22073109447956, 49.147824347019196, 44.97444748878479, 44.80045102536678, 44.67627748847008, 46.82253532111645, 50.401156693696976, 48.53098064661026, 48.52798640727997, 43.94126392900944, 46.66409522294998, 43.74396711587906, 43.405526876449585, 42.384153082966805, 40.27240879833698, 42.3909243196249, 41.83344103395939, 41.95348419249058, 39.095748737454414, 43.086925372481346, 41.02676711976528, 43.85112516582012, 42.79877923429012, 46.36152125895023, 44.10445377230644, 43.939573019742966, 40.102383121848106, 42.50023305416107, 44.33215655386448, 42.885106801986694, 43.65506708621979, 40.38035340607166, 41.849103793501854, 41.997155249118805, 43.624718114733696, 42.505431175231934, 42.3774578422308, 42.70225301384926, 42.75057502090931, 42.70304337143898, 41.905545964837074, 47.28278562426567, 44.927459210157394, 44.34628039598465, 45.55130213499069, 48.65396864712238, 46.600444838404655, 48.443304151296616, 47.80644312500954, 42.312876507639885, 39.55592684447765, 40.3821887075901, 37.87796348333359, 42.97580413520336, 47.143458500504494, 44.825252294540405, 45.48371136188507, 45.338270366191864, 44.47387754917145, 42.92983800172806, 43.87995041906834, 44.074211195111275, 47.951732128858566, 44.50945124030113, 46.639787927269936, 45.40268450975418, 47.58858181536198, 54.102078303694725, 59.46337401866913, 58.97911660373211, 54.83654089272022, 57.738737761974335, 59.05144192278385, 60.62154047191143, 60.57351864874363, 61.28520525991917, 63.85666027665138, 62.715003937482834, 63.896656930446625, 62.77768537402153, 63.43987204134464, 65.0084924697876, 63.17238159477711, 62.52702422440052, 67.08349272608757, 67.37799972295761, 69.6645650267601, 65.11414960026741, 66.40466675162315, 61.92448675632477, 67.16688305139542, 64.45759043097496, 79.41430985927582, 39.278237745165825, 0.28658718278165907, 0.9191434853710234, 0.05423975162557326, 0.06364139713696204, 40.258235558867455, 76.87619045376778, 70.68401992321014, 71.9775541126728, 47.967945858836174, 30.63019249588251, 20.951665341854095, 44.93996813893318, 62.30446636676788, 74.99679610133171, 3.6426562489941716, 0.20848219573963434, 0.09848645509919152, 0.027616650913842022, 0.04902447952190414, 0.08430209825746715, 0.09452162761590444, 0.10553347383392975, 0.2524737117346376, 0.11114415479823947, 0.23863906972110271, 0.36114814749453217, 0.46349532902240753, 11.30934739485383, 84.95876714587212, 60.59320159256458, 55.70978723466396, 60.06433077156544, 75.30433639883995, 51.74004144966602, 77.72410735487938, 76.9150547683239, 61.962986290454865, 0.257019039709121, 0.4843699838966131, 1.030326944310218, 38.42145971953869, 83.85655269026756, 74.34800371527672, 78.11448320746422, 71.7671138048172, 73.54747787117958, 68.00292178988457, 66.91548094153404, 64.04920354485512, 61.56674735248089, 61.77944853901863, 63.09337243437767, 60.18634982407093, 62.53226414322853, 66.90562427043915, 65.04456013441086, 64.2027685046196, 62.01917387545109, 61.877422481775284, 57.12707698345184, 53.11782091856003, 51.974032893776894, 52.760294303298, 50.38946092128754, 50.67943476140499, 50.85696883499622, 50.11731192469597, 49.34216871857643, 51.137617975473404, 47.70353324711323, 52.457203567028046, 46.965438053011894, 49.84495773911476, 48.1755743175745, 49.16705511510372, 47.15808391571045, 46.536361277103424, 47.32675686478615, 47.25728519260883, 49.84795957803726, 49.67948041856289, 45.5379344522953, 49.91462700068951, 51.11003525555134, 45.21775983273983, 45.54274119436741, 46.03021703660488, 47.03074514865875, 48.666705563664436, 51.767912954092026, 47.99260273575783, 44.98322121798992, 46.644742861390114, 45.26123709976673, 44.84116584062576, 44.998386204242706, 42.54773810505867, 45.23884490132332, 45.80343000590801, 46.738829612731934, 42.90502913296223, 45.83532929420471, 44.80987831950188, 48.56150060892105, 45.951876640319824, 48.543075397610664, 46.520557925105095, 47.25406676530838, 42.74388737976551, 44.3025067448616, 47.15739615261555, 45.25256596505642, 45.37214934825897, 43.28372821211815, 43.28373581171036, 46.51583097875118, 46.23995058238506, 46.47867277264595, 44.454263001680374, 45.41325934231281, 44.48827497661114, 43.353963643312454, 42.68592149019241, 49.75226171314716, 46.10182039439678, 44.73341882228851, 46.35000787675381, 48.69928881525993, 48.12695972621441, 49.48713853955269, 49.52235504984856, 42.71585248410702, 39.99114029109478, 38.9361497014761, 37.68830046057701, 42.4898824095726, 49.42063070833683, 45.645160898566246, 47.70870856940746, 47.02382571995258, 45.99875472486019, 46.438003554940224, 44.761085137724876, 46.81968167424202, 51.84364669024944, 47.29341745376587, 50.21568104624748, 48.0774749815464, 50.71358732879162, 55.55473655462265, 63.096609860658646, 62.33400218188763, 59.08369839191437, 60.69938689470291, 62.21083179116249, 62.04684779047966, 63.41825880110264, 64.47952285408974, 67.68525883555412, 65.29134169220924, 67.19567030668259, 66.3480269908905, 66.40490233898163, 67.37152487039566, 65.08564352989197, 66.32506862282753, 69.77695539593697, 70.06573230028152, 72.26700738072395, 70.2469065785408, 71.49256333708763, 64.65359911322594, 71.23264208436012, 68.07793736457825, 81.67045399546623, 42.18810260295868, 1.0827416880056262, 2.0972266886383295, 0.7057671225629747, 0.11789461874286644, 45.08488096296787, 84.58688870072365, 77.15229123830795, 79.8268461227417, 57.83556416630745, 38.94643574953079, 26.951309703290462, 53.61660115420818, 69.64374974370003, 88.84480342268944, 5.353679973632097, 0.33464771637227386, 0.20405909948749468, 0.30226903036236763, 0.14193305658409372, 0.15399123454699293], [0.02540446825150866, 0.019770248218264896, 0.07178348445449956, 0.1159215449297335, 0.08478275762172416, 0.06169534863147419, 0.14137386315269396, 3.606472215615213, 45.91557718813419, 38.84137138724327, 36.13602675497532, 32.16251157224178, 32.25606255233288, 40.231671184301376, 63.82041782140732, 65.7602821290493, 41.368817165493965, 0.06958928031963296, 0.2075951808365062, 0.8648217783775181, 29.039242565631866, 85.00878766179085, 70.76230332255363, 71.82848811149597, 60.85495054721832, 62.014291137456894, 60.61848923563957, 58.571850657463074, 58.064277693629265, 56.40733100473881, 53.34771618247032, 56.067743226885796, 55.29260382056236, 56.65722459554672, 56.203772127628326, 55.93412719666958, 54.27069045603275, 52.65159733593464, 49.98438745737076, 48.36996428668499, 44.95171710848808, 45.70069491863251, 45.601307451725006, 45.90767741203308, 44.653748497366905, 44.95055057108402, 44.89023260772228, 44.29695524275303, 47.16243848204613, 44.0388160943985, 43.506723046302795, 43.56775917112827, 44.038914889097214, 43.583976700901985, 44.829196482896805, 44.41180408000946, 43.52568402886391, 44.02639076113701, 42.79103145003319, 42.06021286547184, 45.34993954002857, 45.147345811128616, 48.00239481031895, 48.41860927641392, 42.223873883485794, 42.09127999842167, 43.249089270830154, 44.66628022491932, 44.83925074338913, 48.8909163326025, 42.641460075974464, 44.18698534369469, 46.23098686337471, 44.61456120014191, 44.20739404857159, 42.8310889005661, 39.71607685089111, 40.83570197224617, 39.3806878477335, 38.77301685512066, 37.70902454853058, 39.825754165649414, 39.92843605577946, 40.60115955770016, 40.37138968706131, 42.092784717679024, 41.4128378033638, 39.82983514666557, 40.455456376075745, 38.50225478410721, 42.529065907001495, 41.444167122244835, 42.02926732599735, 42.85028927028179, 40.21593622863293, 41.41838550567627, 40.37205845117569, 40.31078293919563, 39.52945366501808, 40.771375223994255, 40.470815151929855, 41.969842314720154, 42.70370073616505, 46.216198056936264, 44.63596545159817, 45.81871658563614, 45.958712473511696, 46.72040440142155, 44.81369711458683, 44.41537968814373, 45.46734943985939, 40.946378633379936, 39.917131662368774, 39.99182805418968, 40.154288336634636, 43.25725503265858, 45.86577706038952, 40.836108550429344, 43.744160905480385, 42.7522811293602, 42.89039991796017, 41.954194754362106, 41.33152596652508, 43.2913164049387, 44.80553515255451, 42.99356438219547, 44.7906057536602, 42.06524759531021, 48.883331939578056, 48.28592039644718, 52.392204254865646, 54.196997210383415, 54.83596332371235, 59.114412143826485, 53.72119814157486, 56.3003059476614, 54.712321758270264, 54.95553910732269, 59.72882017493248, 57.78574123978615, 59.74430814385414, 58.51281322538853, 59.03454802930355, 59.44473221898079, 59.870503172278404, 61.57369717955589, 67.07830980420113, 59.97612230479717, 63.63407202064991, 59.709752798080444, 58.3442010730505, 53.62782575190067, 64.27988916635513, 60.29229573905468, 73.15707921981812, 48.57328377664089, 1.5731181995943189, 0.4719731491059065, 0.21401058736955747, 0.13450429192744195, 25.862160846590996, 72.93672144412994, 60.721942484378815, 65.83521410822868, 45.617486983537674, 26.1571504175663, 28.967705704271793, 40.75390376150608, 52.04627841711044, 66.78078576922417, 5.7356079295277596, 0.5331166775431484, 0.12261196912731975, 0.04468923500098754, 0.08820131988613866, 0.061567298471345566, 0.018513294962758664, 0.04287052419385873, 0.05790352319309022, 0.05214165190409403, 0.13906116771977395, 0.11541723331902176, 0.25219597038812935, 6.324130799621344, 62.70094849169254, 49.7306864708662, 45.70933945477009, 38.12805086374283, 33.0802421271801, 47.343149185180664, 71.60236984491348, 72.48146027326584, 45.516078025102615, 0.0740761641645804, 0.22753937548259273, 0.9276486758608371, 31.434343345463276, 85.79958602786064, 72.50251114368439, 72.89721876382828, 63.58319275081158, 64.0816006064415, 64.78402331471443, 60.639980882406235, 59.97952692210674, 58.66497226059437, 56.71506129205227, 58.887537717819214, 58.902132734656334, 60.40992222726345, 58.833618611097336, 58.404910415410995, 58.55356603860855, 53.46413813531399, 52.80515469610691, 50.51263891160488, 47.86659389734268, 48.279422745108604, 48.111889734864235, 46.34077437222004, 47.87574380636215, 47.80189096927643, 46.71216644346714, 46.164532229304314, 46.91711604595184, 45.15663631260395, 46.73915259540081, 45.164460092782974, 46.56619727611542, 45.95910385251045, 44.772283136844635, 47.35234469175339, 45.62748804688454, 46.171599850058556, 44.55826722085476, 44.262513890862465, 46.95856802165508, 45.071805864572525, 48.62742707133293, 48.12181480228901, 42.04221323132515, 40.478464141488075, 43.75634305179119, 45.87467238306999, 46.08026795089245, 50.62400333583355, 42.67402432858944, 45.18920436501503, 47.47014977037907, 45.52294045686722, 44.611669555306435, 46.142922788858414, 42.47999154031277, 42.20829851925373, 41.6640043258667, 40.289450883865356, 41.94335773587227, 42.53359906375408, 40.909342020750046, 44.325199127197266, 42.944926992058754, 44.84984077513218, 43.6934944242239, 42.83215284347534, 43.28072637319565, 42.217630818486214, 44.825423285365105, 44.14244033396244, 43.10314670205116, 44.12752993404865, 43.742215409874916, 42.99297161400318, 42.696101143956184, 42.974417209625244, 41.95626564323902, 41.624847427010536, 41.87929317355156, 44.09812331199646, 47.05138184130192, 45.955281257629395, 45.31787306070328, 44.89945471286774, 46.2599641084671, 45.91711990535259, 45.473432913422585, 45.097359493374825, 46.54651813209057, 41.446576192975044, 39.53379683196545, 40.58702431619167, 40.02879247069359, 44.75533984601498, 47.9082852602005, 41.5424070507288, 44.084371849894524, 44.826624020934105, 44.85546447336674, 45.1126042753458, 43.066360875964165, 45.27976490557194, 46.90275281667709, 42.896582186222076, 47.26686827838421, 45.44224038720131, 50.492283403873444, 50.881572514772415, 54.46397088468075, 58.33595931529999, 58.49654249846935, 60.78414894640446, 56.94774180650711, 59.126058518886566, 59.174258932471275, 57.598335295915604, 60.55019170045853, 61.77766643464565, 60.49147345125675, 60.78930526971817, 61.576296240091324, 60.28008319437504, 63.382540717720985, 63.31450916826725, 70.0271263718605, 62.862979397177696, 65.26577666401863, 60.67791424691677, 60.68840928375721, 57.81926304101944, 68.64490494132042, 65.59850201010704, 76.66651770472527, 52.78351865708828, 1.9690409232862294, 1.0261564305983484, 0.33093736390583217, 0.11791203694883734, 26.85547884553671, 81.52720928192139, 65.59753686189651, 75.87502017617226, 49.44485820829868, 28.347368091344833, 31.274155341088772, 45.652912482619286, 58.46247732639313, 77.76214331388474, 8.151502143591642, 0.5793035554233938, 0.0912279836484231, 0.017006119196594227, 0.07556395503343083, 0.02898518792790128, 0.11722765804734081, 0.14297460147645324, 0.20406763418577611, 0.2498536929488182, 0.22186463233083487, 0.3447939734905958, 0.3612128924578428, 9.71232634037733, 80.06493374705315, 61.24898940324783, 53.11558663845062, 43.0434975028038, 43.60613711178303, 57.13189132511616, 78.2785964012146, 78.09342473745346, 52.858872413635254, 0.16566641977988183, 0.3846564469859004, 1.2768718460574746, 35.35691276192665, 89.30372759699821, 76.59834936261177, 77.6225996017456, 66.30135789513588, 67.49249517917633, 68.61617848277092, 65.084989964962, 64.77024525403976, 61.47252380847931, 60.646729320287704, 61.74281470477581, 61.291892901062965, 61.54770277440548, 61.94189362227917, 62.361672297120094, 61.193466782569885, 56.8101853877306, 56.04881264269352, 53.45859423279762, 50.050937086343765, 50.89128099381924, 51.195827051997185, 49.96213585138321, 50.05376793444157, 51.673089042305946, 50.02221442759037, 49.28454481065273, 50.04494860768318, 48.19901905953884, 50.73825180530548, 48.40969495475292, 48.661841824650764, 49.06360566616058, 48.364044204354286, 48.355878442525864, 48.193946331739426, 49.553585574030876, 45.33678084611893, 47.27045528590679, 49.90539349615574, 49.43503573536873, 52.30643905699253, 50.57408541440964, 42.068766206502914, 42.365477085113525, 44.71344709396362, 47.78116688132286, 47.55331210792065, 51.140714809298515, 43.59975725412369, 46.30023434758186, 48.17569211125374, 46.65792815387249, 47.608990520238876, 47.12092950940132, 47.04782523214817, 46.44754484295845, 43.399386405944824, 43.045849576592445, 43.822083324193954, 45.1789753139019, 44.91333156824112, 47.353465631604195, 46.13734468817711, 46.48108184337616, 48.43784384429455, 44.49823044240475, 46.98039025068283, 44.290810972452164, 48.91284495592117, 44.566486179828644, 46.55373774468899, 48.81882280111313, 45.28565838932991, 46.51539400219917, 45.087711811065674, 45.17315782606602, 44.859062880277634, 45.104708299040794, 46.471525356173515, 46.834614872932434, 49.43077616393566, 47.12715357542038, 45.70365495979786, 46.000137850642204, 46.589965000748634, 47.070715203881264, 46.300184950232506, 46.23545542359352, 48.51015776395798, 42.47854381799698, 41.23974189162254, 41.11606992781162, 41.69437609612942, 46.422956362366676, 51.92496992647648, 44.06767554581165, 46.404569149017334, 47.66780376434326, 47.681844010949135, 47.21003472805023, 46.36619120836258, 47.47087553143501, 48.951450884342194, 45.132063031196594, 48.81805144250393, 47.665542885661125, 52.44589917361736, 54.75060850381851, 57.23315209150314, 60.86328350007534, 60.56188367307186, 63.30376334488392, 59.90486092865467, 60.397561490535736, 59.82188478112221, 60.18618643283844, 65.22513404488564, 65.44824287295341, 64.41437914967537, 64.26380082964897, 62.837946340441704, 65.43401643633842, 64.28544446825981, 66.19662031531334, 72.88255155086517, 65.8070196211338, 68.61300185322762, 66.57752707600594, 66.55564785003662, 62.035000026226044, 72.07960143685341, 69.38060626387596, 80.21380215883255, 55.872091725468636, 2.337120403535664, 2.473229574970901, 0.9281409869436175, 0.22283221478573978, 29.884007535874844, 87.23910078406334, 72.62259989976883, 83.3474712073803, 60.69109953939915, 39.07443568110466, 40.53154729306698, 59.56596091389656, 65.99625706672668, 90.25848716497421, 11.146351341158152, 0.9952610009349883, 0.3385463071754202, 0.12236760958330706, 0.1988399459514767, 0.15713151369709522], [0.015571256444673054, 0.07115183514542878, 0.05111810409289319, 0.024733987920626532, 0.024684382769919466, 0.01430420255928766, 0.22813428106019273, 2.767718997783959, 34.919719621539116, 41.3846281170845, 31.64152342826128, 46.39736853539944, 40.567337572574615, 38.46843279898167, 64.33154359459877, 62.84738503396511, 32.81785100698471, 0.44887973985169083, 0.4016439995029941, 0.45399530441500247, 23.081808239221573, 81.42460718750954, 68.12732711434364, 70.44031620025635, 61.639179065823555, 61.17402322590351, 59.57816205918789, 57.218883857131004, 55.989657416939735, 53.35415683686733, 53.29674191772938, 54.20962393283844, 54.63178887963295, 56.10079765319824, 54.75267179310322, 51.26222088932991, 48.68182875216007, 47.06910029053688, 47.64664649963379, 46.41083121299744, 44.57160070538521, 44.91295538842678, 43.96204121410847, 44.808719381690025, 44.71769526600838, 45.52358642220497, 45.58056816458702, 46.20517484843731, 46.51529520750046, 47.51582711935043, 49.71491351723671, 48.900704607367516, 44.63823013007641, 44.991113394498825, 44.446169435977936, 43.595433086156845, 44.86588731408119, 42.52359040081501, 41.99462078511715, 42.563469260931015, 42.478711009025574, 42.28843241930008, 43.88519413769245, 49.67951841652393, 42.45007574558258, 42.692954912781715, 41.617814004421234, 43.48035626113415, 46.196621507406235, 45.0420306622982, 43.204232677817345, 44.910850301384926, 44.99472700059414, 46.25538915395737, 44.726894572377205, 47.49346151947975, 43.22961911559105, 38.804235979914665, 39.70332853496075, 38.9378672093153, 39.80526186525822, 39.902973622083664, 41.33058361709118, 39.12567213177681, 40.17354190349579, 42.18122497200966, 41.00869908928871, 38.01339201629162, 37.9594387114048, 40.94133250415325, 40.957979410886765, 39.38292592763901, 40.485546961426735, 39.935492277145386, 41.12922482192516, 39.77342337369919, 40.52099145948887, 39.90571327507496, 39.327391907572746, 40.541396364569664, 43.79301868379116, 45.511343479156494, 42.46450737118721, 42.79535561800003, 48.0372579395771, 44.32293824851513, 45.135923624038696, 44.906552731990814, 47.69727498292923, 44.526037350296974, 43.36552642285824, 39.228809997439384, 37.496665343642235, 37.429188564419746, 39.62050057947636, 43.1869588047266, 40.19693724811077, 41.31238639354706, 41.705349907279015, 42.41026148200035, 42.116856426000595, 39.381029829382896, 39.58265081048012, 41.63959443569183, 42.136501371860504, 43.998922035098076, 44.642960876226425, 44.85924147069454, 45.280475467443466, 48.42875473201275, 50.99277354776859, 54.074449986219406, 53.29798825085163, 55.03055848181248, 55.594744607806206, 52.374736592173576, 58.581395745277405, 56.85043282806873, 59.11540009081364, 58.698585256934166, 57.736602276563644, 59.50719706714153, 58.44885505735874, 59.49918329715729, 64.0323780477047, 62.391987070441246, 59.51214820146561, 59.017353951931, 57.76420019567013, 55.482692420482635, 52.8600237518549, 54.357523396611214, 64.27552700042725, 63.838611245155334, 71.75154983997345, 56.16279512643814, 4.7894928976893425, 1.0980213806033134, 0.4974116856465116, 0.476302660536021, 15.056334882974625, 72.39701360464096, 61.79800674319267, 66.79321870207787, 54.347963109612465, 33.27579863369465, 25.787538550794125, 37.826689034700394, 46.85873597860336, 76.35076224803925, 10.82282530143857, 0.45815139077603817, 0.11593387942411937, 0.14901369460858405, 0.01524633862572955, 0.06642558641033247, 0.015053840361360926, 0.02377026277827099, 0.03287134590209462, 0.0365094614244299, 0.008921154985728208, 0.057162570374202915, 0.07556098644272424, 3.6894908733665943, 51.62387788295746, 51.17229871451855, 41.54154449701309, 46.79225094616413, 36.96289278566837, 45.73429651558399, 70.43741315603256, 70.02400293946266, 38.48802074790001, 0.3940130886621773, 0.46530367573723197, 0.7211416913196445, 26.376626640558243, 86.48427128791809, 69.28269311785698, 73.55532065033913, 63.57510298490524, 62.88165919482708, 61.63138188421726, 60.92478699982166, 58.568670228123665, 54.4360575824976, 56.55698977410793, 55.163805931806564, 56.62646904587746, 57.44404077529907, 57.20614314079285, 53.612212389707565, 51.26733921468258, 50.228813141584396, 49.43489134311676, 48.248021230101585, 45.44285215437412, 48.12873423099518, 46.549979746341705, 47.76899233460426, 45.715346932411194, 48.37876081466675, 45.30929312109947, 49.595808908343315, 49.351964592933655, 49.2605908960104, 52.02776201069355, 50.90409770607948, 47.49561220407486, 45.46257309615612, 46.428967639803886, 46.327452287077904, 45.06866343319416, 44.71185117959976, 44.42140236496925, 44.37403030693531, 44.70327503979206, 44.594794660806656, 47.19455435872078, 49.604563638567924, 43.41393202543259, 42.9752379655838, 41.57510049641132, 43.57089780271053, 48.50233398377895, 45.819921121001244, 43.57639230787754, 45.744221583008766, 44.61951993405819, 45.00852406024933, 44.77985233068466, 48.54586064815521, 45.685583129525185, 41.1444354057312, 44.11595955491066, 40.54702766239643, 43.2941472530365, 43.27421732246876, 43.0896270275116, 43.40931907296181, 43.99060048162937, 44.720514714717865, 43.7996531277895, 40.37795953452587, 40.889746472239494, 43.096048682928085, 42.491660714149475, 42.80191786587238, 43.96468207240105, 43.107410073280334, 42.91908837854862, 42.345873937010765, 42.52859093248844, 42.04602062702179, 42.290590703487396, 43.20080526173115, 46.08749896287918, 48.178526759147644, 43.75761218369007, 43.869599774479866, 48.379418179392815, 46.248226538300514, 45.04697419703007, 45.69757528603077, 48.156567737460136, 44.54982027411461, 43.77585880458355, 38.74219670891762, 37.78556004166603, 37.186791971325874, 39.72964972257614, 44.666937589645386, 44.26968030631542, 41.50233060121536, 43.4682235121727, 44.029354602098465, 45.16864746809006, 42.55618505179882, 44.182851165533066, 43.973881378769875, 45.32413512468338, 45.888488441705704, 47.898101806640625, 45.501483008265495, 46.62758678197861, 50.61807565391064, 53.81245784461498, 56.3085401058197, 55.73672018945217, 56.501296162605286, 58.43331769108772, 56.433876380324364, 60.3721484541893, 59.21641007065773, 62.12174937129021, 59.765860587358475, 60.03910392522812, 60.81526167690754, 63.644684851169586, 64.10326704382896, 66.56091436743736, 65.90450718998909, 63.844090551137924, 62.71300904452801, 60.862310752272606, 58.48936088383198, 56.509853303432465, 57.984288185834885, 67.01229974627495, 66.01215541362762, 75.88147222995758, 59.525610879063606, 6.3527285400778055, 1.4639926864765584, 0.47892392612993717, 0.44152529386337847, 16.941544823348522, 79.11765217781067, 68.85340735316277, 72.38894283771515, 61.20961591601372, 38.942149579524994, 27.942562513053417, 49.935206696391106, 51.16276502609253, 83.322863727808, 13.811572976410389, 0.6768484180793166, 0.04081704610143788, 0.060836175398435444, 0.012977786136616487, 0.06600887791137211, 0.09622482684790157, 0.18097282969392836, 0.18159372528316453, 0.09902532852720469, 0.1687608935753815, 0.3469739877618849, 0.2894906426081434, 6.998413167893887, 72.57195621728897, 60.517030879855156, 49.2458438873291, 60.55021829903126, 56.47510036826134, 55.014340952038765, 78.67885932326317, 75.8536197245121, 45.69308012723923, 0.5372874287422746, 0.9431960759684443, 0.8038121333811432, 30.64968165010214, 89.67374414205551, 75.20580008625984, 77.19669565558434, 67.10666388273239, 67.12687879800797, 65.91591417789459, 63.41542415320873, 62.99900829792023, 56.27783015370369, 61.12641178071499, 60.59461511671543, 61.174327209591866, 61.83470897376537, 60.51581494510174, 56.137321293354034, 54.985846281051636, 53.19727465510368, 51.54212906956673, 51.24576397240162, 48.11589851975441, 51.635493859648705, 48.94828945398331, 49.733790904283524, 48.27700987458229, 50.98830498754978, 50.676600113511086, 52.228520438075066, 52.631158232688904, 53.53095754981041, 55.3813898563385, 52.59135156869888, 49.20868568122387, 48.270231038331985, 48.47103126347065, 48.77094157040119, 47.96816624701023, 47.62137785553932, 46.46069593727589, 49.06366266310215, 47.92159974575043, 46.7070709168911, 50.41096776723862, 52.666849717497826, 42.82071925699711, 43.866624534130096, 42.24984548985958, 42.01161727309227, 49.28474240005016, 47.01223634183407, 45.332122296094894, 45.504526644945145, 43.57935234904289, 45.44031389057636, 44.78796109557152, 49.77933906018734, 48.52422080934048, 44.223676174879074, 47.29539714753628, 43.88466216623783, 45.93532852828503, 47.03012578189373, 46.414585411548615, 45.028305798769, 46.02966986596584, 47.46801048517227, 46.71823471784592, 42.73353673517704, 42.841982915997505, 46.18857353925705, 46.37813776731491, 44.42510336637497, 46.50924973189831, 45.310205072164536, 46.31954111158848, 43.86241056025028, 45.454525128006935, 45.29388874769211, 45.30621908605099, 47.38506093621254, 49.34931993484497, 50.481187999248505, 43.50712962448597, 43.08584623038769, 49.8981586843729, 45.798809453845024, 45.6749626994133, 47.34219543635845, 48.7212972342968, 45.213648453354836, 45.93446597456932, 40.179849565029144, 38.1453513354063, 37.801728174090385, 42.24075637757778, 46.23741611838341, 45.73146566748619, 43.20296734571457, 46.066337898373604, 47.3213155567646, 48.19633640348911, 44.12857487797737, 47.34408773481846, 46.78967468440533, 47.504458129405975, 48.77450577914715, 50.1861984282732, 49.45296697318554, 49.17102590203285, 54.27712731063366, 56.41046203672886, 59.226806312799454, 58.35036054253578, 60.18542267382145, 61.57672181725502, 57.768786549568176, 64.48736563324928, 62.48750254511833, 66.33389174938202, 63.22837918996811, 64.51835677027702, 63.3587159961462, 64.25886869430542, 66.19190096855164, 68.2418529689312, 69.11466613411903, 66.49270042777061, 67.3247341811657, 63.49344536662102, 62.363036423921585, 60.226924046874046, 61.25043332576752, 71.28273099660873, 70.35047382116318, 80.7066585123539, 63.35514798760414, 6.326088644564152, 2.291014865040779, 1.1439016624353826, 0.5131770099978894, 18.652243427932262, 86.08431234955788, 75.51780134439468, 80.51458641886711, 71.68234795331955, 48.72939459979534, 34.68032106757164, 57.58095882833004, 58.81689190864563, 99.87778499722481, 18.58294654637575, 1.1084470711648464, 0.21871630829991773, 0.21233744511846453, 0.11107677521067671, 0.21537327440455556], [0.029231740518298466, 0.06676316712400876, 0.01648548033699626, 0.026920783566311002, 0.0629200147523079, 0.014595658794860356, 0.11619009848800488, 2.5615109503269196, 26.815018616616726, 36.1965499073267, 31.801842525601387, 27.54738561809063, 48.74609850347042, 49.29990738630295, 58.98276440799236, 67.67707407474518, 31.401038132607937, 0.2845808310667053, 0.25949419126845896, 1.1205547652207315, 14.02260510250926, 80.64278393983841, 68.49034443497658, 71.12315475940704, 59.65562090277672, 61.03098750114441, 58.387005776166916, 57.84517765045166, 58.90323847532272, 55.35966642200947, 52.043622359633446, 52.25715950131416, 51.88011333346367, 50.11147923767567, 49.17831391096115, 47.22292743623257, 45.782242342829704, 46.34330503642559, 44.88063432276249, 44.03748236596584, 45.91090343892574, 46.88672907650471, 44.80103239417076, 44.49041806161404, 45.96147112548351, 50.93603499233723, 51.747340857982635, 55.76469428837299, 55.527925193309784, 54.67134475708008, 53.66624929010868, 54.117934852838516, 53.729006722569466, 48.13151568174362, 43.91901612281799, 43.72293904423714, 43.23844984173775, 42.484988272190094, 41.96356885135174, 41.46268352866173, 43.82553733885288, 43.39259997010231, 44.052438363432884, 49.90317441523075, 49.82682891190052, 42.47558377683163, 40.35169154405594, 38.854264095425606, 41.74534656107426, 40.972300842404366, 42.8265443444252, 44.69841510057449, 44.69051532447338, 47.00504332780838, 46.02495811879635, 46.26739650964737, 42.85889960825443, 42.766211181879044, 40.77409967780113, 37.8768615424633, 38.81156578660011, 38.15892420709133, 41.394910365343094, 40.80709330737591, 41.85842089354992, 42.50503979623318, 40.940975323319435, 38.46395663917065, 38.88531982898712, 38.43371406197548, 39.930012971162796, 41.565274223685265, 40.355821922421455, 39.0207863599062, 41.64923071861267, 41.153923496603966, 39.929412603378296, 39.79714170098305, 40.56324899196625, 43.78779016435146, 46.37757919728756, 43.30262079834938, 41.73591926693916, 46.415854543447495, 45.288500636816025, 46.649135425686836, 46.26635156571865, 45.86177587509155, 42.78064280748367, 41.89179830253124, 37.2830294072628, 37.89236091077328, 38.15908759832382, 39.58824411034584, 43.022670820355415, 43.97191308438778, 40.37718437612057, 42.06467002630234, 41.588984951376915, 41.82522587478161, 39.73822206258774, 41.18068166077137, 39.96581085026264, 42.23309978842735, 42.62997709214687, 41.27225674688816, 42.95579060912132, 42.556223049759865, 43.68310958147049, 44.94536004960537, 47.131067365407944, 50.418795347213745, 50.95665268599987, 52.158828377723694, 52.178526520729065, 52.61939026415348, 54.517133831977844, 56.67293295264244, 53.06678205728531, 56.36924184858799, 54.37137745320797, 58.309470936656, 60.54722025990486, 60.52788309752941, 59.0775503218174, 57.52485103905201, 56.94312885403633, 55.29463291168213, 52.26635120809078, 48.83649185299873, 51.36393383145332, 55.88493503630161, 62.556689232587814, 66.70487344264984, 67.9617016017437, 62.51181364059448, 10.880029331892729, 0.6899301067460328, 0.3622319205896929, 0.32501057256013155, 8.357987813651562, 72.22137182950974, 61.56323254108429, 62.677556946873665, 50.45885279774666, 28.771455734968185, 18.90172854065895, 35.404140427708626, 40.24582922458649, 71.79513350129128, 15.974491015076637, 0.5421340686734766, 0.25526427605655044, 0.05532815201149788, 0.022291546520136762, 0.039540188445243984, 0.03218564968847204, 0.009872053960862104, 0.037401589725050144, 0.09361324628116563, 0.09934559493558481, 0.009418236222700216, 0.09663105622166768, 4.436173606663942, 44.760518968105316, 47.6890180259943, 41.503945514559746, 34.63255003094673, 54.309444576501846, 53.36995258927345, 67.54209771752357, 73.98858860135078, 35.82551121711731, 0.4127247689757496, 0.23968649242306128, 1.3503898261114955, 16.287330128252506, 86.69065341353416, 72.29498907923698, 74.801706969738, 60.82088157534599, 62.30291984975338, 61.777943819761276, 61.841544806957245, 60.39903201162815, 58.158938214182854, 56.31027281284332, 55.06100244820118, 52.77566447854042, 54.12594482302666, 50.6502865254879, 48.19119907915592, 49.50889617204666, 46.306967586278915, 46.185123324394226, 47.506369426846504, 47.93311692774296, 47.645476162433624, 45.91121502220631, 45.70721156895161, 47.96524040400982, 51.83847516775131, 54.027860686182976, 57.99481742084026, 56.38748846948147, 57.864552810788155, 57.293530851602554, 57.525652796030045, 56.251345574855804, 49.019881412386894, 46.272476837038994, 45.14875553548336, 46.350889429450035, 46.59735560417175, 43.70608314871788, 43.99615578353405, 46.86795808374882, 45.148785933852196, 44.68342110514641, 52.16065987944603, 50.23063324391842, 41.66655398905277, 41.58966511487961, 39.3885800242424, 41.923769786953926, 42.824925631284714, 44.72443990409374, 45.322467014193535, 46.64958380162716, 46.94332703948021, 45.54124407470226, 45.913323909044266, 45.68510055541992, 45.223801508545876, 42.04277940094471, 41.82582624256611, 41.942753568291664, 42.511469051241875, 44.278172850608826, 43.13701048493385, 44.98387098312378, 44.70625028014183, 45.00287376344204, 41.79318979382515, 42.88040645420551, 41.67758859694004, 44.583311676979065, 45.166561380028725, 43.96833747625351, 42.61056013405323, 44.19778436422348, 43.415672332048416, 42.405762523412704, 40.75088292360306, 42.5895244628191, 45.47278694808483, 45.527507811784744, 42.431110963225365, 42.490718364715576, 48.13380315899849, 43.74384932219982, 46.523928344249725, 46.78015619516373, 47.45383344590664, 43.77837806940079, 41.311911419034004, 36.752357482910156, 38.288626447319984, 38.29154089093208, 38.33669386804104, 42.49707542359829, 46.479637920856476, 42.27699503302574, 41.4775787293911, 43.148280680179596, 43.48182298243046, 42.615640461444855, 42.76092566549778, 42.80811533331871, 45.287858471274376, 45.55801637470722, 43.309099450707436, 45.09667173027992, 44.95980307459831, 47.46002331376076, 45.93732722103596, 50.30365392565727, 52.79111824929714, 51.91181503236294, 54.0105602145195, 54.67988669872284, 56.052726432681084, 56.40706121921539, 59.815227538347244, 55.047133192420006, 58.754898235201836, 55.92624641954899, 61.57239764928818, 65.59900358319283, 61.32134512066841, 60.166606083512306, 60.488638803362846, 59.222064167261124, 57.512995675206184, 55.39624325931072, 52.04410873353481, 55.19390031695366, 57.94789373874664, 67.28728339076042, 69.64761033654213, 72.3871037364006, 63.690286204218864, 12.281777914613485, 1.030788857024163, 0.14445398381212726, 0.3135996067430824, 9.367690533399582, 77.57538333535194, 66.34980529546738, 68.44300657510757, 58.7409757822752, 32.962174862623215, 24.44316688925028, 44.04861196875572, 46.17293357849121, 83.85018423199654, 18.43393564224243, 0.4809850483434275, 0.1479652922716923, 0.08984574102214538, 0.0374552024732111, 0.02045628396444954, 0.14836381073109806, 0.2210370486136526, 0.18268009589519352, 0.24302885838551447, 0.2594327414408326, 0.1117122094728984, 0.3277516504749656, 8.21764899417758, 67.8379574418068, 56.64835587143898, 51.32425256073475, 39.595904499292374, 67.91229665279388, 64.90202218294144, 73.9130562543869, 80.13094380497932, 41.591815799474716, 0.4055841505760327, 0.5990563798695803, 1.4395972830243409, 20.440229885280132, 92.98031911253929, 72.60380610823631, 78.51524770259857, 65.19692435860634, 67.27266937494278, 65.46647429466248, 64.99543637037277, 64.31228622794151, 61.542622447013855, 56.77945263683796, 58.16762074828148, 55.811868757009506, 57.20242314040661, 53.53939689695835, 50.77126443386078, 51.326049864292145, 49.914102628827095, 51.63569524884224, 49.684184566140175, 51.29575788974762, 50.4549466073513, 49.00518760085106, 49.41436864435673, 50.63630327582359, 55.38056530058384, 59.51432168483734, 61.23900353908539, 59.75313887000084, 59.229591563344, 59.7853497415781, 59.844212383031845, 58.89866352081299, 49.60071064531803, 49.14556346833706, 47.1623320877552, 50.201671198010445, 47.303300723433495, 46.57237574458122, 46.45123824477196, 49.47198495268822, 46.16112761199474, 48.633578941226006, 54.46957178413868, 52.8742615878582, 42.28710629045963, 41.54204227030277, 40.271998420357704, 42.973740845918655, 44.727323949337006, 44.73798617720604, 45.66497303545475, 46.588961854577065, 48.83535571396351, 46.694463193416595, 47.917868345975876, 44.87476743757725, 47.84643217921257, 44.911990240216255, 43.061291947960854, 46.284757778048515, 43.6323519051075, 46.23522363603115, 45.57436689734459, 49.103583320975304, 47.948927879333496, 46.198251619935036, 43.97489592432976, 44.54468674957752, 42.923686131834984, 46.64154343307018, 48.25341314077377, 46.19420483708382, 43.900537714362144, 47.402395606040955, 47.05646976828575, 43.60959492623806, 42.49935910105705, 46.14815890789032, 48.77466917037964, 46.68440133333206, 43.172230795025826, 43.26757147908211, 49.75324586033821, 44.995084181427956, 46.42051689326763, 47.437057346105576, 48.20245407521725, 45.712063908576965, 42.41311512887478, 37.11125962436199, 38.38910445570946, 39.10270996391773, 39.57590617239475, 43.567819967865944, 47.10254989564419, 45.36323882639408, 44.80548955500126, 47.53025874495506, 46.088802292943, 44.92732621729374, 45.223045349121094, 44.72442850470543, 46.86334893107414, 47.40748733282089, 44.63562346994877, 46.95551298558712, 46.14792712032795, 49.71732258796692, 50.14104925096035, 53.22537034749985, 56.56344182789326, 54.51909452676773, 58.036793768405914, 58.22516866028309, 58.11124697327614, 59.72255431115627, 62.56931595504284, 58.422077894210815, 62.87739962339401, 59.22117501497269, 63.743357956409454, 66.63128659129143, 64.90631595253944, 64.41061735153198, 65.08756622672081, 62.54037290811539, 61.66066311299801, 58.658288419246674, 54.25467811524868, 58.17643627524376, 61.80458799004555, 72.4075922369957, 74.06855911016464, 75.76952263712883, 69.31756004691124, 13.211094997823238, 2.050561155192554, 1.2799964658915997, 0.45464910683222115, 10.43382402509451, 83.90272781252861, 74.6561747789383, 78.18227916955948, 68.16586464643478, 42.9360506683588, 26.98850590735674, 53.08708816766739, 54.901175424456596, 95.2353385090828, 24.105629101395607, 0.7358907186426222, 0.3403353877365589, 0.15952808666042984, 0.1542153483023867, 0.10794301211717539], [0.013292017029016279, 0.04699578174040653, 0.07331058688578196, 0.08605419017840177, 0.03295090784376953, 0.042854260027525015, 0.0332184446597239, 5.545787215232849, 29.485431723296642, 35.00079967081547, 43.878620490431786, 11.853804029524326, 24.168481528759003, 51.11057482659817, 57.91054554283619, 67.7056485414505, 31.933600455522537, 0.20744203124195337, 0.3194672043900937, 0.6236770993564278, 8.741514533758163, 73.7945482134819, 65.53388267755508, 70.19392982125282, 59.61648300290108, 59.16393108665943, 58.251672238111496, 58.073693588376045, 56.280167028307915, 57.15188205242157, 52.39794574677944, 52.234410122036934, 47.22548469901085, 45.32232262194157, 45.279574915766716, 47.019178569316864, 44.70449097454548, 46.741960644721985, 47.154899686574936, 45.664881840348244, 44.240904450416565, 44.59311135113239, 43.498568683862686, 47.80514359474182, 49.460904747247696, 55.567302480340004, 54.44705419242382, 54.16475594043732, 56.213993579149246, 57.55766227841377, 56.201268061995506, 58.95721457898617, 54.73890893161297, 54.285646453499794, 48.54571245610714, 43.82129296660423, 44.447883144021034, 44.502680003643036, 41.1858531832695, 42.998891696333885, 42.34134078025818, 44.52766366302967, 42.50200375914574, 44.42077919840813, 53.67963217198849, 48.61438997089863, 42.33191728591919, 41.121560633182526, 40.374524518847466, 46.96822330355644, 47.345106080174446, 48.029593750834465, 46.39603480696678, 46.80265858769417, 41.040301993489265, 45.29762774705887, 42.70037591457367, 41.164118349552155, 44.07650247216225, 40.84365114569664, 39.33957405388355, 40.745350420475006, 41.10120892524719, 39.08329300582409, 41.422018110752106, 41.65129020810127, 39.15982849895954, 38.25355052947998, 37.620447501540184, 39.79616895318031, 43.50627467036247, 38.14953871071339, 40.35040721297264, 39.11906808614731, 41.046879440546036, 41.94342613220215, 39.61785972118378, 39.78877454996109, 43.53332921862602, 43.182957619428635, 40.82011140882969, 41.62319831550121, 42.91895158588886, 44.98958207666874, 49.011084884405136, 44.75327655673027, 42.222460359334946, 43.94481673836708, 39.00658272206783, 37.72562965750694, 38.04386258125305, 38.59312690794468, 37.269285544753075, 37.93548859655857, 39.831355065107346, 44.57275964319706, 40.626128017902374, 40.45000746846199, 40.13599991798401, 38.65903437137604, 37.98656165599823, 40.45847721397877, 41.287892907857895, 43.16514417529106, 43.111517652869225, 43.51425044238567, 43.81789594888687, 43.41876156628132, 42.40465298295021, 41.54401436448097, 43.17541882395744, 44.315490648150444, 47.17813923954964, 48.67984525859356, 49.395742043852806, 52.18134216964245, 50.227661803364754, 52.95048549771309, 52.26496048271656, 53.82872477173805, 55.557571202516556, 53.247861340641975, 55.60633398592472, 55.140524581074715, 56.40162751078606, 52.11859233677387, 48.51573586463928, 46.34163312613964, 50.01874141395092, 47.94459231197834, 54.630044773221016, 57.927314043045044, 65.81620752811432, 65.47016009688377, 70.12923449277878, 61.324650943279266, 13.477659244090319, 0.510670094517991, 0.250868090079166, 0.14583672367734835, 5.160813722759485, 68.83735701441765, 62.34822101891041, 60.68451069295406, 52.627772614359856, 42.8771386295557, 17.952795960009098, 45.667146518826485, 41.288493275642395, 69.4842267036438, 23.97090543061495, 0.5242183269001544, 0.16745469882152975, 0.004870636812484008, 0.10372730161179788, 0.032332338887499645, 0.048675759171601385, 0.03981402980571147, 0.038357898956746794, 0.04068347436259501, 0.04437191862962209, 0.011252379063080298, 0.06216677567863371, 6.75693042576313, 44.239730313420296, 46.77417911589146, 51.33043862879276, 21.058390215039253, 35.27444578707218, 56.0821520537138, 66.53524294495583, 74.40725013613701, 35.794755667448044, 0.32366731495130807, 0.3284308343427256, 1.1285806470550597, 11.267740577459335, 81.87272474169731, 69.14122670888901, 72.22512602806091, 61.349535807967186, 61.53319135308266, 61.43952637910843, 61.79278202354908, 59.325730204582214, 58.673115223646164, 53.98987032473087, 53.849274069070816, 50.70655770599842, 47.07269109785557, 46.76945596933365, 49.25662390887737, 46.89410448074341, 48.84893238544464, 48.07677961885929, 46.42457127571106, 45.85799887776375, 44.654014483094215, 45.15378646552563, 50.101067796349525, 53.78212787210941, 55.07308579981327, 59.06319469213486, 58.860038593411446, 57.854357957839966, 61.36718966066837, 59.21343483030796, 60.952802896499634, 58.645255118608475, 57.42987133562565, 52.699391171336174, 46.503329649567604, 46.19655691087246, 46.08530268073082, 44.62989717721939, 44.39714826643467, 44.981971085071564, 45.53858041763306, 43.57245571911335, 46.64349652826786, 55.084238201379776, 50.116460770368576, 43.33505965769291, 40.04745326936245, 40.355350747704506, 48.97590637207031, 48.260222375392914, 46.59938469529152, 47.024821266531944, 46.9504364579916, 43.47222089767456, 44.61643069982529, 43.54772664606571, 40.913552194833755, 46.331244483590126, 42.32255458831787, 42.97838419675827, 43.68361495435238, 42.52282664179802, 43.40274542570114, 42.930734753608704, 44.50897626578808, 43.80202040076256, 41.60681739449501, 39.70506504178047, 43.090816363692284, 45.48489689826965, 42.310870215296745, 43.441602140665054, 42.85219296813011, 43.136926889419556, 41.68157838284969, 42.967102602124214, 42.06347309052944, 45.429115891456604, 43.31703722476959, 40.73539115488529, 40.81424072384834, 43.58062908053398, 43.06709423661232, 47.32087478041649, 45.1324962079525, 44.077847599983215, 45.33346362411976, 39.960890114307404, 37.11519621312618, 38.52114737033844, 38.443133756518364, 37.87135563790798, 39.278279542922974, 40.372115448117256, 45.37322849035263, 42.49121613800526, 42.0149040967226, 43.91317203640938, 41.916230991482735, 41.13747797906399, 42.88618594408035, 43.192312717437744, 45.73553524911404, 46.1882733553648, 44.63484451174736, 45.578444078564644, 44.68459524214268, 44.99013304710388, 43.85325685143471, 46.99716255068779, 46.883905827999115, 49.91696387529373, 51.19643121957779, 52.18968652188778, 54.346230402588844, 53.335678428411484, 55.70469170808792, 55.50000049173832, 55.243153274059296, 56.87715299427509, 54.95701722800732, 57.84224420785904, 56.14525146782398, 57.840028926730156, 53.934708684682846, 50.97412794828415, 48.5485927015543, 55.1649534702301, 52.08160512149334, 55.91532960534096, 62.92630299925804, 69.7272464632988, 68.82490128278732, 73.75275805592537, 64.09659460186958, 14.928459394723177, 0.5988084431737661, 0.4872273711953312, 0.31391163531225175, 5.358086787164211, 75.58638766407967, 68.44614520668983, 67.48288169503212, 60.25679424405098, 45.2490359544754, 19.124274998903275, 49.280988201498985, 45.488723292946815, 79.9505826830864, 28.751311115920544, 0.4370576242217794, 0.12173872848507017, 0.14066870411625132, 0.04811645070731174, 0.03731320735823829, 0.13778152700979263, 0.15865042281802744, 0.19414431822951883, 0.22872026602271944, 0.1424541778396815, 0.18780168669763952, 0.13795152335660532, 10.083925500512123, 65.37796184420586, 57.495398819446564, 69.06264692544937, 19.891421534121037, 36.066357493400574, 67.42568716406822, 71.42552733421326, 83.94755780696869, 41.886296197772026, 0.40963642532005906, 0.3319119819207117, 2.201271755620837, 15.894963182508945, 89.67378973960876, 72.6658795773983, 74.85893189907074, 64.4255505502224, 66.34730502963066, 65.85116565227509, 63.46637561917305, 62.14660003781319, 63.68137948215008, 58.62866900861263, 59.01957683265209, 54.01412822306156, 50.398515835404396, 49.65627886354923, 53.1573273986578, 50.021747052669525, 52.57658936083317, 52.43885055184364, 48.189204186201096, 49.258915185928345, 48.29489551484585, 48.070916533470154, 51.284392699599266, 55.78921057283878, 58.74299347400665, 60.2102505415678, 61.697361543774605, 62.41494923830032, 61.80888935923576, 59.51133504509926, 64.19586807489395, 60.27431510388851, 60.51494479179382, 55.154055655002594, 48.96346963942051, 48.58742281794548, 49.454190507531166, 47.68501304090023, 47.401058077812195, 46.7070709168911, 50.06133332848549, 47.05438748002052, 49.404557570815086, 59.27171990275383, 48.536558747291565, 43.694193586707115, 40.68879045546055, 41.03750914335251, 47.411887496709824, 49.13866303861141, 48.71562413871288, 47.90136583149433, 47.60959088802338, 43.23813445866108, 45.31740188598633, 43.52981060743332, 40.45329809188843, 46.96274779736996, 45.005408227443695, 44.51848715543747, 45.628540590405464, 46.298125460743904, 45.03437027335167, 46.43417336046696, 47.62366533279419, 45.782705917954445, 43.91426257789135, 42.97624871134758, 46.105912774801254, 50.08619159460068, 43.5803896933794, 45.644001960754395, 45.4506379365921, 46.017571315169334, 44.77874659001827, 44.49977695941925, 44.99193035066128, 47.650579288601875, 42.96694681048393, 40.21736115217209, 41.59101024270058, 43.17192301154137, 45.350456312298775, 49.056420251727104, 47.89641469717026, 44.7594740241766, 45.860096365213394, 38.680434823036194, 38.01162511110306, 38.023362681269646, 38.940907046198845, 37.736512273550034, 39.806941375136375, 40.38119696080685, 48.19057211279869, 45.94133600592613, 45.06126523017883, 46.53561271727085, 44.58063282072544, 41.773548647761345, 45.77048197388649, 45.99734120070934, 48.3914977312088, 47.719686180353165, 47.572136297822, 48.95126089453697, 48.45507591962814, 47.413415014743805, 45.3657390922308, 49.21928711235523, 49.534829780459404, 53.416158109903336, 54.53577563166618, 54.33338709175587, 57.99606755375862, 55.96807457506657, 60.37236504256725, 57.62578882277012, 58.24312649667263, 60.26575796306133, 57.779273986816406, 61.404416263103485, 59.832414016127586, 61.73047676682472, 57.446153461933136, 53.36556762456894, 52.464962750673294, 59.94941733777523, 54.325126335024834, 60.179707780480385, 65.77171191573143, 73.77724394202232, 74.88167747855186, 80.32282590866089, 68.19496348500252, 17.22522810101509, 2.1186392521485686, 1.0805145325139165, 0.31349920900538564, 6.6576256044209, 82.95568183064461, 74.45857018232346, 76.22600734233856, 70.14327093958855, 59.38354790210724, 27.35062837600708, 59.49499972164631, 56.48137003183365, 94.15260180830956, 35.86119890213013, 0.626804509665817, 0.35671185585670173, 0.21552749269176275, 0.2442945764050819, 0.08113130199490115], [0.036647667875513434, 0.08420553742325865, 0.05179001120268367, 0.035353113707969896, 0.057413108297623694, 0.20626312965760008, 0.1960980219882913, 4.9676767364144325, 31.100808642804623, 41.77226811647415, 46.09222590923309, 29.69710886478424, 21.39294706285, 48.97981256246567, 62.93731480836868, 66.06789082288742, 35.581594705581665, 0.15487845725147054, 0.05253613679087721, 0.9791236824821681, 3.703693561255932, 62.703498154878616, 67.07227572798729, 68.33857297897339, 59.85241614282131, 58.56939218938351, 58.21278892457485, 57.735538333654404, 56.20364673435688, 53.92732188105583, 49.53115537762642, 47.82995246350765, 48.3010283857584, 47.490292489528656, 49.17040653526783, 47.325537130236626, 49.766849130392075, 48.18889640271664, 50.897470861673355, 50.62882527709007, 52.24198691546917, 51.01231969892979, 53.473884612321854, 51.86762720346451, 57.17952556908131, 58.15050646662712, 66.6719064116478, 63.54060843586922, 54.72274839878082, 53.31995867192745, 51.279916539788246, 55.88079705834389, 54.34774272143841, 55.30743442475796, 51.99647068977356, 48.425133526325226, 43.1181862950325, 44.85177107155323, 44.22975204885006, 40.95507636666298, 42.308263555169106, 43.560790345072746, 42.67354555428028, 42.700603902339935, 47.15656019747257, 53.22363384068012, 42.794021889567375, 39.99517187476158, 39.877309799194336, 47.34617382287979, 50.10750465095043, 44.44359317421913, 44.009280279278755, 47.565239667892456, 46.763433292508125, 46.981507390737534, 43.437486961483955, 38.248348608613014, 42.813769429922104, 43.30308437347412, 41.34591579437256, 39.53962191939354, 40.416747853159904, 41.96901015937328, 40.260542035102844, 41.744126826524734, 38.99295285344124, 39.800793305039406, 39.380068480968475, 40.74158862233162, 41.48465394973755, 41.82291939854622, 39.860750287771225, 42.074367105960846, 42.574815452098846, 40.0380639731884, 41.48727960884571, 46.766150146722794, 41.73288322985172, 40.738377794623375, 39.78194631636143, 40.54865777492523, 41.59878462553024, 47.824081778526306, 46.835336834192276, 39.48152683675289, 38.94008249044418, 36.49159647524357, 38.59531179070473, 37.349636033177376, 37.647855430841446, 38.17041479051113, 36.08952485024929, 37.05076307058334, 48.75253155827522, 40.876017808914185, 39.06777463853359, 39.51685734093189, 39.21614907681942, 40.51582373678684, 40.988069996237755, 40.60703404247761, 41.672139689326286, 43.47471736371517, 43.71475048363209, 42.24542252719402, 42.257703468203545, 45.00687874853611, 42.5265846401453, 41.20151214301586, 43.017354905605316, 41.55635990202427, 43.78993324935436, 43.88339303433895, 44.2095485329628, 46.137538477778435, 47.15418912470341, 46.62283703684807, 48.066896349191666, 49.51792448759079, 48.62121820449829, 50.57731904089451, 48.8229987770319, 48.322729021310806, 47.53213204443455, 45.593863651156425, 48.99727642536163, 48.993298038840294, 50.100775212049484, 50.31056575477123, 57.50515289604664, 64.22707200050354, 64.3092691898346, 62.145167514681816, 64.32978048920631, 65.47488704323769, 17.108027189970016, 0.23707064450718462, 0.1962077707867138, 0.08304878894705325, 1.7072982620447874, 67.25438475608826, 63.89196038246155, 61.2632804363966, 54.756691977381706, 48.59593816101551, 23.75395607203245, 34.857737347483635, 42.42198005318642, 69.39506828784943, 34.90202397108078, 0.4072571889264509, 0.054079967230791226, 0.05608865300018806, 0.11538693142938428, 0.03357427107403055, 0.039206875080708414, 0.02010786789469421, 0.04877460582065396, 0.019855075697705615, 0.0599173334921943, 0.09675985595094971, 0.24214432225562632, 8.441990856081247, 48.029859736561775, 53.11971701681614, 52.435240745544434, 31.537768095731735, 26.183505803346634, 56.36275939643383, 69.31168556213379, 73.96747693419456, 39.25345167517662, 0.2126704467809759, 0.158592312654946, 2.0551019115373492, 4.521800111979246, 73.43039095401764, 73.16977053880692, 71.17540955543518, 61.84609696269035, 60.96344992518425, 62.21142835915089, 59.93055894970894, 60.41429579257965, 55.52195191383362, 54.741230607032776, 50.23651912808418, 49.61235322058201, 48.27292129397392, 50.355665534734726, 51.648777946829796, 51.27354048192501, 51.68155498802662, 52.94604733586311, 52.289009392261505, 53.713989928364754, 53.71941603720188, 55.892010256648064, 54.89810138940811, 58.92382577061653, 61.23161293566227, 66.93574905395508, 61.93321868777275, 57.10929773747921, 55.24574093520641, 56.10394388437271, 59.02148813009262, 57.181832045316696, 57.79198430478573, 53.41987431049347, 50.595451667904854, 44.497679471969604, 45.16184963285923, 46.138499826192856, 43.0272875726223, 44.401518031954765, 44.42539595067501, 45.606562569737434, 44.53897945582867, 48.21951135993004, 54.85803633928299, 41.60443492233753, 39.5864962041378, 39.31768722832203, 47.3974596709013, 51.19159787893295, 45.439534932374954, 43.693901002407074, 48.010324984788895, 45.981530249118805, 49.536718279123306, 44.23977971076965, 38.91624636948109, 43.427702486515045, 46.806720569729805, 44.31983761489391, 44.578797519207, 43.50205309689045, 44.31884206831455, 42.831959053874016, 43.266644328832626, 42.185989916324615, 43.34680862724781, 42.5972456485033, 42.53928355872631, 44.23281468451023, 42.64745235443115, 44.63846191763878, 43.08903805911541, 46.32177159190178, 42.14526750147343, 43.6134897172451, 49.21995967626572, 42.39839851856232, 39.74426753818989, 39.715126901865005, 41.562838554382324, 41.54904529452324, 50.639160722494125, 48.82999040186405, 39.76170100271702, 40.605042949318886, 36.80313415825367, 37.74046026170254, 38.669244423508644, 37.628263682127, 38.04028317332268, 37.348743081092834, 38.9433541148901, 50.95433861017227, 44.223375990986824, 41.679572090506554, 41.20545633137226, 41.19244582951069, 42.358523458242416, 43.39729271829128, 42.815912514925, 42.751547768712044, 44.91075150668621, 43.450854644179344, 44.547475799918175, 44.96901378035545, 45.627564042806625, 44.283051788806915, 43.5914471000433, 45.364819541573524, 44.19652283191681, 46.260385885834694, 45.53617514669895, 47.05621898174286, 49.01339516043663, 50.53643323481083, 48.023350685834885, 49.17990602552891, 51.00986123085022, 51.23432278633118, 53.16331587731838, 50.9040255099535, 50.512889698147774, 50.18633522093296, 48.82206782698631, 50.44697463512421, 51.93125478923321, 51.76396496593952, 53.496618792414665, 60.14565020799637, 68.03446769714355, 68.86110574007034, 67.73126676678658, 70.18093451857567, 68.56800466775894, 18.413545936346054, 0.33601991774048656, 0.5789384187664837, 0.12459210818633437, 1.8428444699384272, 71.72616720199585, 70.46028792858124, 68.13924327492714, 62.128000035881996, 50.483760461211205, 20.734355002641678, 36.677778884768486, 48.14192332327366, 78.11176255345345, 41.6941899061203, 0.5307567666750401, 0.06767347062123008, 0.06692888870020397, 0.11436548389610834, 0.14217698568245396, 0.11234153585974127, 0.2411471726372838, 0.13306841428857297, 0.11830906369141303, 0.17688001884380355, 0.3418685757787898, 0.43479416286572814, 12.746172845363617, 65.7593321800232, 64.98435616493225, 68.17238509654999, 39.967870339751244, 33.219379261136055, 67.32417181134224, 75.40499299764633, 82.36425116658211, 42.13359072804451, 0.2541497483616695, 0.34847369010094553, 2.46388825122267, 7.966276332736015, 81.57674342393875, 72.5277341902256, 76.64847627282143, 64.81877624988556, 63.68093490600586, 64.03382197022438, 63.3244114369154, 62.65096977353096, 60.16457699239254, 57.05504424870014, 54.125754833221436, 51.728801652789116, 51.35409615933895, 54.30488482117653, 53.41276489198208, 54.415356293320656, 53.332661390304565, 55.089554116129875, 55.558676943182945, 56.999137848615646, 56.381499990820885, 58.876168727874756, 56.20165564119816, 62.80265003442764, 64.77545097470284, 68.328115940094, 61.31038270890713, 57.10917994379997, 56.89916901290417, 57.68182821571827, 63.72711002826691, 59.36324939131737, 60.71561582386494, 57.81463488936424, 53.294914215803146, 46.965137869119644, 47.40201182663441, 50.81840090453625, 44.83766242861748, 47.29152895510197, 48.059957921504974, 48.31306993961334, 47.69955486059189, 51.058563217520714, 56.468728110194206, 40.94336919486523, 40.318253338336945, 39.41902779042721, 48.030194118618965, 52.03751228749752, 45.29024854302406, 44.452290907502174, 48.64769898355007, 46.32551819086075, 48.41759853065014, 45.152969509363174, 38.02715487778187, 43.66174332797527, 48.8412643969059, 46.05649642646313, 47.5252316147089, 47.35534653067589, 48.83931130170822, 45.82582600414753, 46.24974645674229, 45.049132481217384, 47.64187015593052, 45.00326134264469, 45.48299700021744, 48.518585711717606, 47.07339785993099, 46.68050654232502, 46.958526223897934, 49.27355960011482, 44.61586073040962, 46.32120922207832, 52.08852834999561, 40.80668292939663, 40.31412295997143, 39.86348994076252, 41.50977820158005, 42.418092861771584, 50.13816520571709, 48.3817208558321, 40.584049075841904, 40.17178259789944, 36.40924349427223, 37.76676245033741, 38.89269143342972, 39.36021834611893, 38.92653241753578, 37.749256789684296, 37.806314527988434, 50.31481772661209, 45.44533722102642, 43.36907543241978, 44.14761185646057, 43.437247574329376, 46.17820009589195, 46.44727125763893, 45.381876826286316, 45.83204247057438, 49.57621715962887, 47.64321148395538, 46.11979342997074, 47.60507293045521, 47.78126187622547, 47.72792033851147, 46.79887779057026, 49.48530703783035, 47.12071292102337, 48.938957154750824, 48.06209720671177, 48.84360887110233, 52.40164674818516, 53.40227745473385, 50.61623275279999, 52.43888854980469, 55.2495863288641, 53.4537722915411, 55.653732642531395, 53.91642406582832, 54.05649974942207, 52.961827889084816, 52.6443625241518, 52.83420033752918, 55.438607186079025, 57.1192380040884, 58.601599261164665, 64.62418109178543, 71.48463696241379, 72.29569584131241, 72.73402512073517, 73.12734961509705, 72.00150042772293, 20.621324367821217, 0.950012969551608, 0.7526004407554865, 0.2417339591193013, 2.0320711098611355, 80.75387477874756, 75.22245839238167, 75.8004529774189, 72.70735055208206, 66.53161033987999, 36.35745607316494, 49.285240173339844, 56.487670093774796, 91.32470235228539, 48.72149482369423, 0.6380479282233864, 0.3268571547232568, 0.12400028252159245, 0.3266563592478633, 0.24221445521106943], [0.03577110241167247, 0.06501721276436001, 0.046923722911742516, 0.03029287254321389, 0.063752244313946, 0.07121758942957968, 0.13863205793313682, 6.188713191077113, 33.002289310097694, 39.20282319188118, 37.851334512233734, 25.131794437766075, 39.905804470181465, 51.86233028769493, 60.59070132672787, 68.42517793178558, 36.62950627505779, 0.08535714281606488, 0.13847080408595502, 0.3993137151701376, 0.8640370017383248, 51.71497039496899, 71.03652700781822, 66.95098623633385, 63.96020472049713, 55.903732627630234, 59.18957971036434, 55.990523770451546, 55.75491361320019, 51.79596684873104, 50.2672328799963, 48.51480111479759, 50.94516970217228, 51.38102911412716, 54.56872746348381, 55.45761376619339, 57.664356753230095, 61.55542775988579, 60.32641030848026, 62.28800565004349, 59.57934759557247, 58.64299803972244, 56.421128064394, 56.40241786837578, 56.873774975538254, 59.67402331531048, 45.46790041029453, 47.07309387624264, 55.06896302103996, 53.55457328259945, 55.29328778386116, 54.44637402892113, 56.79427184164524, 58.66163603961468, 53.92196796834469, 50.57946212589741, 48.7947890907526, 43.65640461444855, 41.01980209350586, 41.66461609303951, 41.67022839188576, 42.24955290555954, 42.12820641696453, 42.48839668929577, 43.042813539505005, 53.63074019551277, 48.64123933017254, 38.23583967983723, 42.04999141395092, 43.91634866595268, 51.74014784395695, 46.2338063120842, 45.087806805968285, 48.894256353378296, 45.52742801606655, 47.86050662398338, 47.83201955258846, 40.27604520320892, 40.18333777785301, 44.386930614709854, 44.432338178157806, 42.9556880146265, 41.55016243457794, 41.04096695780754, 42.166086584329605, 42.15710386633873, 41.74566954374313, 40.04982054233551, 40.52197940647602, 40.972069054841995, 40.887379199266434, 39.23232100903988, 39.93853211402893, 42.187171652913094, 41.96742944419384, 43.49424451589584, 45.756825506687164, 39.705745205283165, 40.32925754785538, 40.34945346415043, 40.63338942825794, 39.35518741607666, 48.732449635863304, 45.16621559858322, 41.31819248199463, 38.3241431415081, 40.20374648272991, 37.49456785619259, 38.07455733418465, 38.65328148007393, 37.7724165469408, 40.357262045145035, 37.12751895189285, 44.75949302315712, 47.60096535086632, 41.33478619158268, 39.763228520751, 39.803468361496925, 41.6194137185812, 39.67767991125584, 40.14550320804119, 40.76504096388817, 42.71308623254299, 43.57073061168194, 44.34703655540943, 41.60661220550537, 42.353446930646896, 42.06744387745857, 41.6718927025795, 42.46092036366463, 42.247808799147606, 42.64614902436733, 42.71557129919529, 43.25057879090309, 42.42546446621418, 42.365674674510956, 45.43664328753948, 46.16507939994335, 45.4629834741354, 46.39777131378651, 44.816265776753426, 41.95492051541805, 43.89450363814831, 45.628601387143135, 47.34482869505882, 46.629163697361946, 47.11060546338558, 48.43579575419426, 48.0008140951395, 51.608705297112465, 60.00540353357792, 64.68870162963867, 62.729952335357666, 64.22032356262207, 66.79322630167007, 62.620119228959084, 18.4855729714036, 0.02523792103602318, 0.7484103937167674, 0.08412566749029793, 0.5813896434847265, 55.71937412023544, 67.14133322238922, 67.39594236016273, 51.78827986121178, 57.29246310889721, 22.706922255456448, 33.843343779444695, 44.018164202570915, 69.51280876994133, 44.73206229507923, 0.43444921262562275, 0.05322431919921655, 0.027079311876150314, 0.03714251710334793, 0.021867247705813497, 0.039459572653868236, 0.03294544563686941, 0.042753491215989925, 0.04497289497521706, 0.03252390946727246, 0.0953049496456515, 0.16506060463143513, 8.201768696308136, 47.58319370448589, 49.33640442788601, 52.26018413901329, 33.91198329627514, 39.15375642478466, 58.232171684503555, 66.45677715539932, 75.44452607631683, 40.22771179676056, 0.17029501672368497, 0.07641498319571838, 1.3077644258737564, 1.5466185403056443, 63.363967314362526, 74.28892448544502, 68.9270929992199, 66.99344515800476, 60.01410886645317, 62.064190059900284, 60.045909360051155, 58.45822915434837, 54.491477608680725, 52.8534235060215, 48.78730349242687, 52.499548494815826, 53.76542776823044, 56.401840299367905, 59.55507069826126, 60.688466280698776, 64.31418612599373, 62.82606057822704, 63.23681853711605, 61.263664215803146, 61.08008086681366, 58.093425929546356, 58.6638855189085, 59.551130309700966, 61.62430286407471, 48.99944610893726, 47.77714669704437, 54.7006069868803, 54.297353625297546, 55.05772702395916, 57.10173234343529, 59.586707800626755, 60.973333194851875, 57.13250309228897, 54.2582955211401, 49.60348829627037, 47.376781180500984, 43.87361615896225, 42.63897880911827, 45.030258893966675, 44.62728291749954, 45.45916087925434, 46.03441961109638, 46.02447934448719, 52.33303003013134, 49.82167258858681, 38.160463124513626, 41.75169602036476, 44.97421570122242, 51.7194389551878, 47.915577068924904, 46.44565634429455, 49.56857576966286, 46.4198063313961, 49.903888776898384, 50.0399024784565, 40.255853086709976, 38.628187626600266, 45.24231791496277, 46.11644580960274, 44.49099563062191, 43.422496765851974, 43.998697847127914, 43.604943975806236, 43.57493698596954, 44.353359416127205, 41.55752643942833, 41.893515810370445, 43.36126685142517, 42.40837678313255, 42.88264453411102, 42.761890813708305, 43.37413676083088, 43.65047313272953, 46.12171232700348, 46.573424488306046, 41.872369945049286, 39.56336684525013, 40.4499314725399, 40.139271542429924, 38.44850666821003, 48.3813788741827, 44.92073357105255, 41.81015968322754, 38.116659075021744, 40.6583084911108, 37.81359873712063, 39.412131160497665, 39.520546942949295, 37.051914408802986, 40.01005567610264, 36.32950097322464, 47.896840274333954, 51.50375492870808, 43.68202663958073, 43.12831275165081, 40.84363594651222, 42.66408786177635, 41.85035392642021, 42.171223908662796, 41.520022451877594, 45.889708176255226, 44.942954778671265, 45.3896664083004, 42.52593107521534, 44.231986328959465, 43.949957862496376, 43.12293604016304, 44.08997654914856, 44.70807418227196, 44.069366455078125, 45.16562283039093, 46.27849191427231, 44.30609755218029, 43.8679126650095, 46.621727496385574, 47.66496531665325, 48.59328970313072, 48.73265482485294, 48.159740567207336, 45.4045008122921, 46.001665368676186, 47.44752958416939, 48.91641676425934, 50.700447633862495, 50.3030763566494, 52.061903178691864, 49.979865700006485, 52.72562496364117, 63.465710654854774, 67.71691873669624, 66.49532228708267, 69.35780748724937, 70.7354311645031, 67.78039813041687, 19.820676930248737, 0.21799526730319485, 0.5515331018250436, 0.1898854592582211, 0.6869203713722527, 60.334549471735954, 73.89995455741882, 71.62003129720688, 62.10772432386875, 52.49648205935955, 25.44115673750639, 46.293668299913406, 48.97027887403965, 79.03942957520485, 51.647353023290634, 0.4246502509340644, 0.10973362892400473, 0.08275269428850152, 0.09846750806900673, 0.07416537031531334, 0.16798338998341933, 0.17711904976749793, 0.09885338033200242, 0.09461418827413581, 0.1727643795311451, 0.34681003249716014, 0.3366832196479663, 13.292479030787945, 67.10706666111946, 60.50766058266163, 56.47039242088795, 36.12370401620865, 59.954824447631836, 69.39551666378975, 71.4175933599472, 83.7342220544815, 45.16203582286835, 0.20126541814533994, 0.16995186248095706, 1.2388953776098788, 2.883599242195487, 73.67695212364197, 78.52351605892181, 73.6383081972599, 67.99812644720078, 63.34988906979561, 66.43098413944244, 63.075813576579094, 62.78224132955074, 58.436201736330986, 56.74702897667885, 51.295719891786575, 56.57060444355011, 56.423339545726776, 60.58799967169762, 61.91866546869278, 63.28294426202774, 67.18922585248947, 65.71684285998344, 67.40684777498245, 62.74587348103523, 65.0538620352745, 62.3903189599514, 60.79698085784912, 62.50862941145897, 63.868926018476486, 52.92707495391369, 54.045826122164726, 55.64090073108673, 55.73711156845093, 54.226054251194, 59.382662549614906, 62.82059267163277, 64.01293829083443, 58.26945148408413, 57.74373449385166, 53.41528795659542, 50.32625891268253, 44.88641381263733, 45.04223585128784, 47.47886650264263, 48.35488669574261, 47.82345861196518, 48.123619705438614, 47.903710305690765, 58.22165384888649, 49.652593061327934, 38.50689433515072, 42.096010744571686, 45.48513248562813, 52.48819090425968, 48.35372015833855, 49.01843748986721, 51.12741932272911, 47.84605219960213, 50.06949909031391, 51.11908636987209, 40.61561398208141, 39.499203488230705, 46.71690098941326, 48.86834554374218, 47.503633573651314, 46.83225139975548, 47.51711145043373, 46.92577578127384, 47.940180748701096, 46.68991483747959, 45.08902654051781, 45.590991005301476, 46.42489805817604, 45.77110894024372, 44.727802723646164, 45.17352640628815, 46.91315285861492, 46.23090706765652, 48.604225516319275, 48.61075356602669, 41.89586028456688, 40.685537829995155, 40.77251896262169, 39.786342680454254, 39.155527129769325, 49.756319895386696, 47.283484786748886, 43.191370368003845, 38.654117435216904, 42.340531423687935, 38.68444740772247, 38.912849351763725, 38.5755680501461, 36.738161444664, 41.5488401055336, 37.844088301062584, 49.666690304875374, 54.396285116672516, 46.67649395763874, 45.22825486958027, 44.28965203464031, 47.474606931209564, 43.80215339362621, 45.11856235563755, 44.01139676570892, 48.45509111881256, 47.9266382753849, 48.31604138016701, 43.99678274989128, 45.692787542939186, 46.830001920461655, 44.995194375514984, 46.635558754205704, 47.34553545713425, 46.237233728170395, 46.63823381066322, 49.369424656033516, 47.138416171073914, 45.63246577978134, 49.506772086024284, 51.376773342490196, 51.45652346313, 51.201762333512306, 49.99408833682537, 46.61097787320614, 49.05707001686096, 50.55474825203419, 52.73647718131542, 51.99119657278061, 53.23473684489727, 56.6425421833992, 52.3004125803709, 56.392553597688675, 66.5692663192749, 74.00672122836113, 71.0606937110424, 73.1243933737278, 73.24320539832115, 71.38363838195801, 21.130459047853947, 0.5454982537776232, 2.6480140211060643, 0.40554045292083174, 0.9714694088324904, 67.57360562682152, 80.60822859406471, 82.64709278941154, 69.50445681810379, 74.18132185935974, 36.43750637769699, 48.55004422366619, 58.56669433414936, 88.28020691871643, 61.95899270474911, 0.6510042829904705, 0.16318703797878698, 0.11664591816952452, 0.1342196189216338, 0.14219389180652797], [0.04523948555288371, 0.08603670517913997, 0.05706101488613058, 0.05118853390740696, 0.07933386485092342, 0.05080746333987918, 0.13668203522684053, 9.141403175890446, 37.37897805869579, 39.454981461167336, 37.3474283516407, 25.99929928779602, 27.235751040279865, 52.17157669365406, 61.51294983923435, 66.67410269379616, 37.580504044890404, 0.10787471226649359, 0.15315535361878574, 0.7562104251701385, 0.04891940996458288, 38.107759952545166, 75.89808493852615, 65.29496669769287, 65.13491168618202, 56.17783471941948, 55.52590750157833, 54.64653208851814, 51.689766347408295, 46.06097258627415, 50.56680500507355, 49.028662741184235, 52.22584918141365, 53.62588785588741, 53.604134023189545, 56.67319513857365, 57.85959027707577, 57.464426681399345, 54.94426131248474, 55.520363599061966, 60.07658511400223, 58.45765918493271, 57.75409273803234, 56.87639683485031, 59.484364092350006, 56.52803532779217, 60.27194023132324, 50.119348615407944, 51.84133641421795, 53.86796146631241, 53.65350857377052, 51.5094318240881, 54.711740389466286, 55.72943218052387, 54.81821067631245, 54.89835977554321, 49.66416724026203, 43.987104669213295, 43.109306171536446, 43.26235055923462, 43.270630314946175, 40.17798766493797, 43.152095675468445, 41.814119070768356, 42.384745851159096, 46.64493665099144, 56.94089077413082, 49.2322102189064, 43.551116064190865, 40.937365517020226, 49.63354088366032, 46.90817892551422, 48.28152783215046, 51.420763581991196, 49.94709625840187, 49.2149743437767, 54.25689339637756, 43.55400770902634, 39.060771614313126, 40.38186192512512, 45.82966759800911, 46.95593476295471, 40.04778765141964, 41.271584182977676, 42.40771181881428, 39.167291298508644, 40.11672355234623, 38.36329244077206, 38.541312888264656, 40.16330145299435, 43.29310230910778, 42.713637202978134, 42.78952293097973, 42.99381896853447, 45.82650996744633, 47.49803267419338, 40.03038838505745, 40.00429518520832, 42.45046712458134, 43.75822775065899, 41.33276470005512, 45.83404876291752, 50.51791302859783, 40.8010858297348, 39.69365045428276, 41.09286457300186, 46.02728359401226, 40.91186888515949, 38.693255335092545, 41.77500776946545, 42.43333384394646, 39.23413351178169, 45.85169121623039, 46.4631962031126, 47.26544715464115, 40.502543449401855, 41.28002732992172, 38.00992280244827, 40.63563510775566, 37.99715168774128, 40.58846443891525, 39.482233598828316, 40.489061772823334, 42.25420005619526, 43.444767370820045, 42.853078320622444, 43.19269649684429, 46.55705876648426, 48.25546883046627, 44.63201366364956, 44.61171515285969, 42.61358857154846, 43.136600106954575, 42.38537281751633, 42.965996861457825, 43.19977551698685, 43.69120314717293, 43.56837473809719, 43.0296016484499, 43.833307921886444, 43.36792029440403, 45.385015457868576, 44.52762186527252, 44.77224513888359, 45.03639176487923, 46.825415566563606, 46.017168536782265, 47.23696768283844, 47.43285857141018, 53.755890280008316, 60.11907443404198, 62.45573244988918, 60.68106047809124, 67.99320951104164, 62.76048369705677, 67.37022534012794, 20.77940158545971, 0.13278975267894566, 0.39140642853453755, 0.12299805661314167, 0.07513738339184783, 49.09904636442661, 66.55819371342659, 61.93967454135418, 51.65189377963543, 58.54781314730644, 36.80110886693001, 17.781309261918068, 45.175118520855904, 66.31147295236588, 51.91869266331196, 0.8619903365615755, 0.10439436620799825, 0.016738964586693328, 0.017644052641117014, 0.027673184013110586, 0.0742240964609664, 0.09008116510813124, 0.01163809825811768, 0.046734749848837964, 0.049704720950103365, 0.153447744960431, 0.24197892722440884, 12.540271393954754, 55.19303396344185, 49.86767292022705, 46.54746048152447, 29.074622467160225, 31.333804540336132, 60.53286463022232, 68.04378479719162, 74.23930674791336, 41.983323991298676, 0.040808396370266564, 0.12247756618307903, 1.6689766058698297, 0.0134543943022436, 48.45328241586685, 80.09315863251686, 66.57219216227531, 67.9040738940239, 57.70660288631916, 59.77729417383671, 55.43882757425308, 54.5643424987793, 47.98192910850048, 51.64577230811119, 50.51702007651329, 54.675543531775475, 55.9998294711113, 57.59751074016094, 58.52843418717384, 60.8376120775938, 58.955668061971664, 60.39113223552704, 60.21662659943104, 61.410727724432945, 62.71363981068134, 61.9510093331337, 57.668198347091675, 61.20173893868923, 56.671128049492836, 60.79872876405716, 51.804732978343964, 52.58411295711994, 56.283073872327805, 56.17213502526283, 54.683621898293495, 59.15976271033287, 58.811689987778664, 57.46030010282993, 56.02568328380585, 51.875994354486465, 44.168153554201126, 43.98635990917683, 43.51522698998451, 44.16995085775852, 43.66705544292927, 43.80646236240864, 44.66472990810871, 45.03418408334255, 49.64643359184265, 59.64759573340416, 48.25389951467514, 43.0539545416832, 41.40163980424404, 50.00353842973709, 47.30251416563988, 48.33580031991005, 52.360456958413124, 50.550389885902405, 50.83502881228924, 54.7792399674654, 43.78578767180443, 39.69958573579788, 41.12192541360855, 50.17763368785381, 47.104073613882065, 44.09134067595005, 45.074002146720886, 46.385216787457466, 42.187627628445625, 43.11684876680374, 40.835945159196854, 43.23253735899925, 42.43051819503307, 44.36530977487564, 43.875044882297516, 45.26821732521057, 45.8668752014637, 49.01592582464218, 47.94519267976284, 39.24025498330593, 41.10546849668026, 43.64831104874611, 42.271728515625, 41.3793919980526, 47.19846434891224, 51.048736944794655, 39.76028747856617, 40.92183195054531, 41.79798513650894, 46.9767614454031, 40.29002085328102, 37.71766148507595, 39.55246523022652, 42.441803589463234, 39.04551923274994, 48.11244070529938, 52.60520942509174, 48.752679750323296, 42.67697297036648, 42.48750373721123, 41.82649500668049, 42.151533365249634, 40.72840712964535, 42.02779680490494, 42.27640986442566, 43.98214213550091, 44.54855874180794, 44.273062124848366, 44.450782388448715, 45.68616829812527, 47.7416680008173, 49.97335284948349, 48.54777194559574, 46.05709679424763, 46.44886337220669, 45.61709940433502, 44.8105812817812, 45.576164200901985, 46.54998354613781, 46.46149009466171, 46.04711093008518, 45.20704060792923, 46.60134918987751, 45.59539496898651, 47.95100636780262, 47.54196211695671, 48.43633532524109, 48.04258905351162, 49.58099730312824, 47.61285111308098, 51.55578173696995, 50.801617205142975, 56.35455183684826, 63.43859151005745, 68.23378220200539, 65.2147302031517, 70.96489325165749, 67.08885043859482, 71.5989500284195, 21.926818415522575, 0.38691607885994017, 0.8727662020828575, 0.1321824680780992, 0.013015725653531263, 53.818461522459984, 71.98627844452858, 70.48327669501305, 59.652394875884056, 62.92216122150421, 28.10605823993683, 23.162650801241398, 54.830582812428474, 73.44900995492935, 60.033715814352036, 0.9367501374799758, 0.0995557414717041, 0.0367245395318605, 0.04685554180468898, 0.05368827281927224, 0.29494937625713646, 0.16935568040935323, 0.1538427159539424, 0.11586290042032488, 0.20004115649499, 0.45343979203607887, 0.347345833433792, 18.65684688091278, 74.52186718583107, 60.169091150164604, 55.521408542990685, 36.033154875040054, 41.932661309838295, 69.76642996072769, 74.58467021584511, 81.21810346841812, 45.969978868961334, 0.15800270601175725, 0.7906996901147068, 3.071052208542824, 0.13165073411073536, 58.62723268568516, 85.71738123893738, 70.64112022519112, 70.78128710389137, 61.76062814891338, 60.98480097949505, 60.49030691385269, 58.138924688100815, 50.36935620009899, 54.77489300072193, 54.22467112541199, 57.959498316049576, 57.51434080302715, 60.36251217126846, 62.52131313085556, 65.57938143610954, 64.8732653260231, 63.58014911413193, 63.258568570017815, 64.81755271553993, 63.834940642118454, 62.52090275287628, 61.89520172774792, 63.40883910655975, 57.74758368730545, 62.9397314786911, 55.03996677696705, 57.63722240924835, 58.504434674978256, 57.11661234498024, 53.76825101673603, 56.04975499212742, 59.85501520335674, 61.44474349915981, 59.03924077749252, 54.77638252079487, 48.327805548906326, 48.08764323592186, 47.012551724910736, 47.47441314160824, 45.33404499292374, 45.958058908581734, 47.03615605831146, 47.29212552309036, 52.08068937063217, 61.14043302834034, 49.670953676104546, 42.62675106525421, 43.18077653646469, 51.77795581519604, 50.22929951548576, 49.53204073011875, 53.555409237742424, 51.07431337237358, 51.34932741522789, 56.464730724692345, 44.79724399745464, 39.051963686943054, 42.71964468061924, 51.09502226114273, 50.30458107590675, 47.57993347942829, 45.21829180419445, 48.371032029390335, 43.45925599336624, 45.304630771279335, 44.48660306632519, 43.90750274062157, 45.477764680981636, 47.88569547235966, 48.98012034595013, 47.28081353008747, 47.25281283259392, 53.24328638613224, 49.403166845440865, 39.394750893116, 40.863231495022774, 44.21580299735069, 43.19610871374607, 41.36169634759426, 46.89168021082878, 52.56303548812866, 41.01110436022282, 39.92058947682381, 41.557822823524475, 46.78736060857773, 42.0387402176857, 38.407951444387436, 42.24168732762337, 42.9453107714653, 39.456216394901276, 47.652912363409996, 54.45307306945324, 50.36586418747902, 44.492671340703964, 45.10275900363922, 42.68203429877758, 44.66836251318455, 42.9922990500927, 44.88539546728134, 43.845322877168655, 43.91132153570652, 46.784176379442215, 47.08685293793678, 47.76312164962292, 48.21507319808006, 50.74668735265732, 52.83167727291584, 51.12947501242161, 48.101128712296486, 48.109651654958725, 47.10123896598816, 46.58374473452568, 47.49039128422737, 49.893093556165695, 49.29190881550312, 48.10614064335823, 49.1163544356823, 50.139286145567894, 48.99325244128704, 51.365221962332726, 48.0233658850193, 50.1992317289114, 50.49115106463432, 53.60726125538349, 52.08823196589947, 53.55672396719456, 54.36149798333645, 58.529634922742844, 67.24616959691048, 70.27240321040154, 67.4751529097557, 76.30323439836502, 71.79445713758469, 77.46996939182281, 24.227366968989372, 0.8866246521938592, 1.7811303189955652, 0.35142812062986195, 0.2080087797367014, 59.779992029070854, 79.48294177651405, 78.28144624829292, 68.00453290343285, 79.76215839385986, 49.17537286877632, 27.3265490680933, 64.66378256678581, 83.01296755671501, 72.70411312580109, 1.3021970121189952, 0.3386181767564267, 0.29056735045742244, 0.10384022680227645, 0.13163149764295667], [0.022465565307356883, 0.15272379474481568, 0.014208505399437854, 0.07444962771842256, 0.07573695707833394, 0.23885641508968547, 0.18509636545786634, 4.577947799116373, 37.60348901152611, 43.14472407102585, 39.780623987317085, 35.24023622274399, 35.37938095629215, 53.388108015060425, 61.31866246461868, 68.24195936322212, 39.28367145359516, 0.04401018471980933, 0.0898732672794722, 0.07307505147764459, 0.28631270688492805, 19.14930235594511, 75.0181357562542, 61.94136545062065, 69.81759041547775, 52.9422627389431, 55.26774935424328, 47.521633207798004, 51.45976848900318, 48.42037618160248, 52.40083359181881, 47.98630267381668, 52.57087826728821, 50.5266297608614, 57.90943220257759, 57.9997343569994, 58.89440014958382, 56.55081130564213, 51.65817864239216, 46.359533965587616, 49.48042809963226, 51.47672697901726, 56.16718389093876, 54.3900952488184, 57.139247730374336, 58.81554298102856, 58.17754961550236, 60.67456662654877, 59.41068224608898, 53.9609082788229, 53.86341691017151, 49.681209325790405, 36.03244811296463, 37.667861357331276, 56.936384215950966, 52.9889090359211, 52.89441950619221, 41.31068408489227, 42.66065664589405, 40.20576037466526, 44.19407956302166, 43.64972837269306, 42.014512717723846, 41.198555901646614, 42.711425721645355, 40.72271503508091, 48.49049761891365, 57.7935004234314, 46.4982683211565, 39.46486093103886, 45.77615886926651, 47.643538266420364, 51.729136034846306, 54.0751301497221, 57.99418285489082, 53.21784295141697, 55.91172739863396, 47.748876214027405, 40.670806020498276, 41.545500084757805, 45.84311507642269, 43.39195780456066, 47.865909934043884, 44.97734673321247, 45.477430298924446, 41.769938841462135, 39.8656140267849, 37.97440990805626, 39.54247176647186, 39.24585588276386, 43.38226452469826, 40.9529484808445, 46.99213162064552, 43.73261332511902, 47.79410898685455, 41.0572262853384, 39.252923503518105, 39.57190498709679, 40.33920921385288, 39.345611929893494, 44.466809928417206, 45.95466569066048, 43.139670342206955, 40.23979514837265, 42.49158851802349, 49.851470589637756, 50.7213769108057, 48.31822246313095, 40.202857330441475, 37.12443731725216, 36.33599482476711, 41.272936910390854, 50.202898532152176, 52.57251977920532, 43.46236042678356, 41.202500090003014, 39.41102162003517, 38.68500977754593, 40.96277475357056, 38.85021351277828, 40.71410849690437, 41.999796107411385, 40.369653180241585, 42.821635007858276, 41.10595487058163, 42.16354452073574, 47.1835121512413, 49.40812177956104, 50.55360071361065, 52.46895253658295, 51.37004390358925, 50.31137891113758, 45.86708799004555, 46.20855666697025, 44.71883900463581, 44.14651371538639, 46.27220705151558, 46.340838968753815, 47.179286777973175, 46.82366006076336, 45.516678392887115, 44.62780348956585, 44.0179818123579, 47.249621003866196, 45.61141110956669, 47.82046057283878, 45.95490887761116, 47.17432804405689, 46.74669899046421, 52.530444636940956, 61.018360778689384, 66.93780094385147, 63.16550776362419, 65.64539149403572, 64.74554657936096, 71.24547019600868, 22.452337816357613, 0.24824119900586084, 0.2831257466459647, 0.2614728460321203, 0.09289504028856754, 40.63672944903374, 71.80331826210022, 61.732262670993805, 58.70200887322426, 46.78362920880318, 38.79536345601082, 40.925213769078255, 41.8953663110733, 64.64223772287369, 40.41156493127346, 1.2738624075427651, 0.03639689617557451, 0.055489750957349315, 0.057439135416643694, 0.08143526341882534, 0.0930254950071685, 0.04629994778952096, 0.004539487272268161, 0.11154248772072606, 0.07104188596713357, 0.2531905076466501, 0.24126217584125698, 7.675874540582299, 54.720495119690895, 51.23702824115753, 49.175958037376404, 28.84387794882059, 33.04881401360035, 61.980024576187134, 66.45293176174164, 74.85042035579681, 41.341530829668045, 0.037580981661449187, 0.09007248940179124, 1.247865033801645, 0.5113626073580235, 25.427741557359695, 81.68164059519768, 64.26292687654495, 72.27427259087563, 54.24128383398056, 57.820023000240326, 50.14055147767067, 53.32536198198795, 50.37900388240814, 54.55816403031349, 51.548379734158516, 55.957370549440384, 54.10596549510956, 57.923225462436676, 61.04379281401634, 62.708145305514336, 61.38493850827217, 54.67929773032665, 49.907114803791046, 53.30972962081432, 54.50111769139767, 57.51603551208973, 53.569757267832756, 58.98472510278225, 60.99407248198986, 60.635402128100395, 61.314798071980476, 60.69510832428932, 56.77056111395359, 56.01498685777187, 51.779198348522186, 39.54732030630112, 39.56207871437073, 59.99838910996914, 55.604863464832306, 53.772035613656044, 44.201097786426544, 44.428838565945625, 42.83932685852051, 45.65282888710499, 44.57564748823643, 44.66155707836151, 43.982157334685326, 44.75125886499882, 40.99509581923485, 51.73028737306595, 59.47990693151951, 46.79577715694904, 39.07723233103752, 46.20887205004692, 47.62990839779377, 52.9754501581192, 57.67900496721268, 59.7100567817688, 53.99034529924393, 54.934412240982056, 47.22179129719734, 41.88066489994526, 41.73754557967186, 46.13491661846638, 46.453730911016464, 51.91157564520836, 47.97039292752743, 46.59889832139015, 45.614743530750275, 44.529339373111725, 40.25530591607094, 40.29254011809826, 40.948460921645164, 46.465050503611565, 43.07331830263138, 48.792201429605484, 43.82238730788231, 48.83265405893326, 41.53598539531231, 38.95498529076576, 40.853842198848724, 39.47402983903885, 38.21954995393753, 46.68513089418411, 46.42422929406166, 44.46613736450672, 40.2507271617651, 44.0475632250309, 51.4813931286335, 52.54907123744488, 48.164060935378075, 39.65469114482403, 39.40970689058304, 36.59511812031269, 41.000651121139526, 52.96596586704254, 54.281033501029015, 45.18508158624172, 44.19138550758362, 43.51490020751953, 42.17188507318497, 42.69957035779953, 40.90714193880558, 43.03709104657173, 43.16168636083603, 44.003842771053314, 44.41985584795475, 44.04600910842419, 43.14663156867027, 48.73058393597603, 50.962770357728004, 54.21209380030632, 54.36206415295601, 53.15062455832958, 52.76252098381519, 48.81914958357811, 48.89935567975044, 46.627601981163025, 46.238829642534256, 48.326741605997086, 47.37851768732071, 47.72035874426365, 49.5181030780077, 48.650875613093376, 45.91334670782089, 47.208207026124, 49.18917752802372, 49.286440908908844, 51.28106787800789, 48.77593070268631, 50.95544055104256, 49.51216779649258, 57.16661386191845, 64.5428578555584, 71.59027889370918, 66.41795843839645, 68.7914326786995, 67.45201975107193, 74.02919322252274, 23.94126132130623, 0.5339002667460591, 0.7004123786464334, 0.09055467016878538, 0.0535021310497541, 42.90418937802315, 77.26877018809319, 68.18022787570953, 65.40316209197044, 54.64007243514061, 47.940549328923225, 40.14679133892059, 50.50943188369274, 71.5971565246582, 53.87779913842678, 1.7627365747466683, 0.11505211150506511, 0.090951667225454, 0.056311701773665845, 0.014256963931984501, 0.172807602211833, 0.21118720527738333, 0.2112810721155256, 0.17100779019529, 0.23276615829672664, 0.5189308512490243, 0.5540157936047763, 15.854578949511051, 70.5949679017067, 64.71197158098221, 60.69047637283802, 50.21820031106472, 53.33057150244713, 68.15389528870583, 73.40086653828621, 84.97420191764832, 46.52080111205578, 0.15434850443853065, 0.6613033334724605, 3.243245193734765, 0.4917355621000752, 32.26615481078625, 91.48226469755173, 64.53648939728737, 75.20688682794571, 56.53159573674202, 60.85007920861244, 51.56978398561478, 56.58421911299229, 52.821699008345604, 56.58201903104782, 53.698889538645744, 59.10692274570465, 56.16956636309624, 62.99165949225426, 62.87844076752663, 63.75325262546539, 62.968324944376945, 55.51318198442459, 51.396691873669624, 55.072352439165115, 55.92431992292404, 61.280675902962685, 56.27551607787609, 62.92922884225845, 66.82020485401154, 62.69049145281315, 64.68671053647995, 63.46014015376568, 59.13559980690479, 57.78203263878822, 55.24404622614384, 41.28986120223999, 40.113717913627625, 62.13680416345596, 57.28973105549812, 57.00845494866371, 46.55409872531891, 47.078417390584946, 45.73154926300049, 47.56585143506527, 46.07287734746933, 48.06022770702839, 46.31324864923954, 46.729577109217644, 44.24958698451519, 53.06177772581577, 63.42578239738941, 48.02174337208271, 39.488020688295364, 46.36600501835346, 49.393416568636894, 55.9241147339344, 57.65011511743069, 62.17428155243397, 57.01739586889744, 57.48324327170849, 49.546605348587036, 42.97418162226677, 41.65520019829273, 50.300621688365936, 48.223934322595596, 52.95652337372303, 49.90983925759792, 50.282090082764626, 48.151825591921806, 46.89224258065224, 44.34163324534893, 44.28294539451599, 42.9402494430542, 50.04617974162102, 45.669540390372276, 52.2133706510067, 46.52057312428951, 50.31236685812473, 41.480500772595406, 39.93173807859421, 40.64948916435242, 39.21316623687744, 40.858747735619545, 46.955387592315674, 48.28348472714424, 43.7633840739727, 41.30725286900997, 44.66116949915886, 51.77340745925903, 53.911605924367905, 50.012589544057846, 42.24390260875225, 39.10758510231972, 36.054935306310654, 43.08207303285599, 56.847579181194305, 57.56067931652069, 48.544336929917336, 46.209020242094994, 45.79869166016579, 43.854548782110214, 46.10782027244568, 44.54865373671055, 44.06808212399483, 45.58795116841793, 45.67413814365864, 47.42296390235424, 45.63014030456543, 47.11127042770386, 52.087217420339584, 54.184879660606384, 57.743574902415276, 57.29592092335224, 58.416932970285416, 55.13389393687248, 51.47608861327171, 51.49576395750046, 49.174905493855476, 48.407244086265564, 51.62548519670963, 51.28164544701576, 52.03084744513035, 52.535365372896194, 52.864009737968445, 48.7549140304327, 49.52824093401432, 52.672173231840134, 51.60902827978134, 54.53590862452984, 52.61609964072704, 54.51492615044117, 51.808464378118515, 59.9312961101532, 67.56139308214188, 75.92629462480545, 71.16014197468758, 74.77652192115784, 72.67537906765938, 79.81482356786728, 27.032349854707718, 0.9443766251206398, 1.8269774713553488, 0.6213782227132469, 0.16746020555729046, 48.16901586949825, 83.6749604344368, 76.79638713598251, 72.96923249959946, 63.51165018975735, 58.992738872766495, 52.0891173183918, 61.812217980623245, 82.17536330223083, 67.91949346661568, 2.087255548685789, 0.23550931422505528, 0.1911428800667636, 0.1882452832069248, 0.25429639674257487], [0.02680307523405645, 0.08770114945946261, 0.029160820886318106, 0.07389486490865238, 0.11396416753996164, 0.05355961409804877, 0.1487302387249656, 3.5138070629909635, 33.22985149919987, 39.03892658650875, 30.999623872339725, 31.566648446023464, 33.53827714920044, 51.120313704013824, 60.55455006659031, 61.60465411841869, 38.02940055727959, 0.027804052479041275, 0.0771700739278458, 1.3016211055219173, 0.33880127943120897, 3.776388172991574, 67.65158504247665, 61.953133419156075, 68.2337898015976, 56.05984725058079, 58.47314715385437, 48.67824174463749, 51.90544657409191, 49.54345531761646, 50.947232991456985, 49.389498978853226, 52.79204539954662, 52.81859077513218, 57.167974188923836, 57.80588015913963, 66.16304531693459, 61.86828777194023, 60.366543754935265, 57.43444249033928, 55.887731686234474, 47.79647246003151, 49.514120891690254, 50.591860860586166, 55.69705031812191, 56.10210478305817, 59.93236765265465, 52.362284660339355, 53.58589880168438, 56.452331990003586, 57.86209054291248, 55.337779596447945, 51.371712014079094, 49.74739037454128, 55.24242751300335, 50.91855213046074, 46.65586106479168, 41.64998687803745, 44.56131085753441, 39.62941110134125, 43.756175860762596, 42.95092687010765, 43.64768028259277, 39.95215058326721, 43.584413677453995, 43.73643212020397, 42.12883718311787, 47.01275311410427, 55.56623473763466, 48.17842796444893, 46.070901453495026, 44.504393711686134, 50.47863453626633, 54.39373545348644, 57.438743859529495, 56.65032796561718, 56.55783332884312, 50.922355726361275, 43.1628642976284, 38.78084443509579, 44.6574342995882, 41.3518662750721, 47.447620779275894, 44.15482006967068, 43.2845451682806, 43.5984805226326, 45.45699119567871, 43.41597631573677, 44.520592242479324, 42.172508239746094, 43.204396069049835, 45.906583070755005, 44.577463790774345, 43.93448509275913, 43.62200506031513, 37.74193078279495, 40.85220828652382, 40.20038366317749, 41.02797545492649, 44.18745271861553, 48.52090358734131, 43.77870865166187, 47.0440748333931, 40.44590748846531, 50.953973829746246, 52.448859214782715, 54.798580929636955, 42.08347901701927, 37.076499089598656, 37.54600569605827, 42.88942337036133, 50.18882788717747, 55.152307748794556, 43.94611246883869, 38.554353788495064, 40.96782088279724, 40.441625118255615, 40.939010828733444, 39.33399975299835, 38.96726243197918, 41.36984311044216, 40.440390184521675, 42.50133119523525, 42.537391260266304, 42.729098573327065, 43.292110562324524, 46.931764259934425, 50.237343683838844, 52.77528829872608, 52.355407029390335, 54.17842760682106, 52.10827589035034, 54.8707390576601, 50.673195496201515, 50.14394089579582, 47.38800197839737, 47.11380489170551, 49.15424220263958, 49.88554336130619, 51.58360004425049, 52.355441227555275, 52.03813165426254, 50.37001736462116, 48.51014256477356, 46.841579899191856, 49.342438504099846, 50.56631863117218, 48.94218698143959, 46.66819520294666, 51.90105780959129, 58.12392309308052, 65.51961064338684, 62.54692755639553, 66.76490262150764, 62.18493238091469, 70.83151280879974, 20.355897210538387, 0.17710787302348763, 0.7349438569508493, 0.32929225999396294, 0.21323053078958765, 32.06653252243996, 72.89797112345695, 63.981749564409256, 58.81152659654617, 53.09424698352814, 20.649784840643406, 20.952985771000385, 50.12030616402626, 58.61516833305359, 48.446116000413895, 0.9028509689960629, 0.08617898973170668, 0.10490107495570555, 0.05097998298879247, 0.09941839220118709, 0.06184570775076281, 0.09974422471714206, 0.02920883784099715, 0.09352867113193497, 0.05579606870014686, 0.10749035398475826, 0.1978475906071253, 6.197371501475573, 49.07123185694218, 49.388906210660934, 39.02677483856678, 27.515440732240677, 38.67269463837147, 58.71690787374973, 67.10885256528854, 68.32845032215118, 41.98067553341389, 0.036293091980041936, 0.1604532331111841, 3.875784664414823, 0.9826852788683027, 6.78119164891541, 78.12917321920395, 64.83766123652458, 70.33416509628296, 59.680228382349014, 60.598836690187454, 50.989045947790146, 55.51673099398613, 50.418058186769485, 53.63706685602665, 51.04427978396416, 54.276386350393295, 55.37940256297588, 59.23240341246128, 58.90628971159458, 67.46594980359077, 63.22134956717491, 58.309596329927444, 57.145198211073875, 57.805864959955215, 49.900974333286285, 52.973352670669556, 52.959065437316895, 58.829682022333145, 58.73980164527893, 61.92424736917019, 54.13748100399971, 56.14387974143028, 60.22169932723045, 59.29071508347988, 56.16235055029392, 51.07860714197159, 50.93036949634552, 57.744110673666, 53.253811821341515, 49.13654275238514, 43.07972475886345, 45.57687856256962, 41.688114032149315, 46.5650649368763, 44.364420622587204, 45.08613869547844, 43.36453087627888, 44.936875104904175, 43.67594316601753, 44.18143764138222, 48.63593101501465, 56.01546563208103, 49.82697330415249, 44.49951857328415, 46.60547196865082, 51.266830042004585, 56.47159695625305, 57.59315997362137, 58.45726400613785, 60.66397279500961, 51.133160814642906, 42.834075540304184, 39.414171651005745, 45.351622849702835, 44.74527418613434, 47.090139761567116, 45.610833540558815, 44.069108068943024, 43.72896932065487, 47.16212309896946, 44.29088316857815, 46.46082893013954, 45.70476070046425, 45.982928574085236, 47.210946679115295, 46.96502007544041, 45.33247947692871, 44.72828909754753, 39.2951924353838, 39.61103908717632, 39.6994299441576, 43.007304444909096, 44.38998945057392, 48.95405754446983, 45.377940237522125, 47.81132586300373, 42.20607943832874, 52.8603695333004, 52.70089969038963, 55.07575325667858, 43.380915597081184, 37.53313958644867, 39.07512724399567, 44.37217600643635, 50.46074129641056, 54.48848716914654, 45.83357758820057, 41.50271438062191, 43.20117004215717, 43.45807045698166, 42.570544481277466, 40.23063383996487, 41.40133962035179, 43.445812314748764, 43.2491310685873, 42.620143219828606, 44.53098848462105, 45.42452193796635, 44.890190809965134, 48.99053938686848, 52.406943663954735, 55.67442633211613, 56.11348897218704, 57.10994370281696, 54.9621469527483, 57.56821051239967, 55.32386094331741, 51.154907047748566, 48.84381406009197, 50.86949296295643, 51.760666742920876, 52.731814831495285, 54.77221794426441, 53.32186236977577, 55.783579275012016, 52.948380410671234, 51.550515219569206, 50.01684911549091, 51.64326064288616, 53.066839054226875, 52.659166529774666, 50.9849763661623, 53.78288023173809, 59.51005831360817, 69.27944049239159, 65.92499569058418, 71.32936969399452, 65.00567302107811, 74.82515171170235, 21.541596986353397, 0.36099205899517983, 0.776692038634792, 0.11071854052715935, 0.12140114777139388, 35.220089703798294, 77.9822351038456, 70.70084542036057, 65.59389665722847, 60.02035193145275, 35.14811396598816, 30.04201825708151, 56.82657390832901, 67.00370460748672, 59.64696116745472, 1.4056466985493898, 0.24312619847478345, 0.06133315087936353, 0.016382876565330662, 0.044720479418174364, 0.18714806239586323, 0.2343852276680991, 0.19916974153602496, 0.13893565570469946, 0.380582531215623, 0.2833279670448974, 0.4505920229712501, 12.524304650723934, 69.03158739209175, 58.36811698973179, 47.46688574552536, 44.3700785189867, 53.260362669825554, 66.72254249453545, 74.11434665322304, 78.07773917913437, 44.397281259298325, 0.1990482074324973, 0.7031303609255701, 4.0546902269124985, 0.5789533210918307, 9.327383246272802, 88.33458200097084, 67.29855358600616, 75.49756363034248, 60.64967416226864, 63.853574842214584, 53.20415608584881, 60.60143955051899, 54.96047504246235, 56.46228365600109, 53.78500051796436, 57.69800774753094, 58.01836095750332, 63.01456466317177, 61.865992695093155, 70.87676078081131, 63.992981761693954, 60.76153635978699, 57.41134732961655, 58.80916312336922, 49.592738673090935, 55.32640300691128, 54.91086110472679, 61.423289850354195, 61.34515464305878, 66.79603815078735, 55.16137406229973, 57.89292588829994, 62.29080989956856, 61.41116090118885, 58.19382794201374, 54.259192273020744, 54.71782386302948, 62.37126678228378, 55.899849236011505, 51.28254599869251, 46.111582070589066, 50.70131778717041, 42.83575884997845, 48.50408188998699, 45.11187471449375, 48.1070563942194, 44.31754633784294, 47.901969999074936, 48.07381957769394, 47.33180299401283, 50.27704015374184, 58.90803761780262, 51.00755475461483, 47.08525702357292, 49.32379670441151, 54.126252606511116, 59.44214455783367, 59.794442653656006, 60.67678190767765, 62.82949559390545, 53.75361420214176, 45.4989143460989, 40.392736941576004, 47.979531437158585, 46.950440257787704, 51.446009427309036, 48.55401121079922, 45.384551882743835, 47.350232005119324, 49.518794640898705, 47.19252146780491, 51.0747579485178, 47.60672204196453, 47.80912958085537, 49.48032550513744, 48.637599125504494, 46.151198744773865, 45.64597025513649, 38.742253705859184, 40.2141997218132, 41.080184653401375, 41.74294888973236, 46.24223046004772, 51.61102697253227, 46.07783988118172, 49.438265562057495, 41.09746992588043, 53.27817231416702, 55.29858089983463, 58.014644756913185, 45.872042924165726, 39.3936413526535, 38.48468452692032, 44.76717621088028, 53.81945326924324, 58.254845067858696, 48.19430351257324, 43.40972565114498, 44.50261540710926, 45.21057441830635, 45.11981248855591, 43.65620322525501, 43.25499415397644, 45.646069049835205, 44.46072645485401, 44.491592198610306, 48.046753630042076, 49.05486613512039, 47.968477830290794, 53.3175154030323, 55.788321420550346, 57.40012273192406, 58.140383809804916, 60.3637433052063, 56.86653636395931, 60.974036157131195, 58.10089632868767, 55.216946080327034, 51.10947668552399, 52.29056350886822, 54.18092407286167, 55.538139045238495, 58.27390864491463, 56.59065596759319, 58.64456735551357, 54.455504938960075, 54.01228532195091, 53.197506442666054, 56.403314620256424, 54.94618020951748, 55.9921994805336, 53.65301840007305, 58.31525042653084, 63.35687689483166, 73.46916407346725, 66.91871076822281, 77.29513317346573, 67.38509014248848, 79.37624350190163, 23.436855487525463, 0.7051661610603333, 2.2730570286512375, 0.5857008683960885, 0.3043139440706, 40.020421519875526, 85.51436573266983, 78.86499613523483, 73.83488684892654, 69.88695189356804, 33.72101314365864, 28.67220126092434, 72.14933529496193, 72.01204866170883, 75.90409621596336, 1.829164254013449, 0.3707044565817341, 0.22585698607144877, 0.1449472745298408, 0.15314684860641137], [0.05994516774080694, 0.07836896897060797, 0.016770689544500783, 0.04821310802071821, 0.054850424130563624, 0.07885222585173324, 0.07541533996118233, 7.140967268496752, 40.52761450409889, 32.64898046851158, 48.71582172811031, 31.785898581147194, 30.92569123953581, 55.19222840666771, 59.8690440505743, 65.64517870545387, 26.934609599411488, 0.028211955395818222, 0.07459872518666089, 0.49807424540631473, 0.7055423408746719, 0.37576715054456145, 49.38357129693031, 68.19850489497185, 66.86557441949844, 61.886162012815475, 59.253648072481155, 54.92416799068451, 51.848844811320305, 50.80254055559635, 51.02334290742874, 50.62886327505112, 52.60615177452564, 53.19714926183224, 56.863477528095245, 56.274414137005806, 57.22437836229801, 57.3161206394434, 59.02701683342457, 60.759750455617905, 60.51223933696747, 56.128874346613884, 55.18263392150402, 54.6641631424427, 54.505350664258, 54.879007413983345, 57.06749618053436, 55.26575826108456, 55.17710141837597, 56.63438022136688, 58.332896679639816, 55.910378471016884, 55.6184097379446, 53.888024389743805, 52.76180662214756, 46.81639105081558, 43.23520481586456, 41.26353621482849, 43.67347709834576, 42.011457681655884, 42.352185398340225, 41.47187143564224, 42.12058782577515, 42.687878385186195, 42.884403839707375, 44.02701772749424, 43.3547767996788, 40.51031023263931, 46.78111374378204, 50.684146508574486, 49.14221964776516, 43.565684482455254, 50.03829136490822, 48.045716285705566, 53.379790261387825, 57.04665429890156, 54.65115264058113, 53.39671075344086, 48.429719880223274, 40.101113989949226, 44.433725103735924, 43.41936573386192, 43.001471757888794, 41.249682158231735, 43.961326852440834, 41.50119826197624, 44.89832617342472, 45.755658969283104, 44.14714068174362, 44.37407210469246, 44.83248710632324, 46.050055772066116, 45.00041529536247, 47.80790224671364, 43.06925252079964, 41.52069881558418, 40.87299317121506, 40.20387187600136, 44.581708163022995, 46.711664870381355, 44.704555571079254, 46.38342708349228, 48.62352468073368, 48.70811194181442, 54.676136299967766, 48.75049866735935, 40.557062923908234, 39.73710112273693, 38.360332399606705, 40.24041451513767, 49.97818998992443, 51.194953098893166, 45.233084410429, 39.794010668992996, 41.68527938425541, 39.22862380743027, 41.16696059703827, 39.83025312423706, 40.20287252962589, 41.23192571103573, 40.09792976081371, 41.77602991461754, 40.22609308362007, 41.38911947607994, 41.272089555859566, 41.71317368745804, 45.92011034488678, 47.590937688946724, 50.645996555686, 53.61964099109173, 57.07911975681782, 57.26451940834522, 55.17321042716503, 55.34438744187355, 54.13445636630058, 52.17575266957283, 51.72512724995613, 54.66662161052227, 60.952453315258026, 61.25193424522877, 58.84463042020798, 56.413262486457825, 57.713845297694206, 57.515834122896194, 55.45841172337532, 56.95754148066044, 51.75480745732784, 54.70881834626198, 50.62475189566612, 49.26971420645714, 54.31164085865021, 67.4204358458519, 65.9067414700985, 67.55522981286049, 61.79581806063652, 70.38511276245117, 21.426856443285942, 0.10542046700720675, 0.19704616017406806, 0.19353342679096386, 0.05788277274405118, 24.578798711299896, 74.19138371944427, 64.74268153309822, 61.21383748948574, 54.62584599852562, 38.00938703119755, 29.17114868760109, 41.773145869374275, 54.52786065638065, 54.88297060132027, 1.3129474665038288, 0.06272042897762731, 0.08002566522918642, 0.010034628830908332, 0.05138136984896846, 0.09916843686369248, 0.0778481297311373, 0.03977766456955578, 0.041654997621662915, 0.06702361642965116, 0.11971880288911052, 0.24860770121449605, 10.354691371321678, 57.064908519387245, 44.088874608278275, 55.959798619151115, 38.854742869734764, 35.98133705556393, 62.65566252171993, 64.76405158638954, 72.5203549861908, 32.09057383239269, 0.12640940520213917, 0.08349962139618583, 1.2490240903571248, 1.2950222846120596, 0.40240214788354933, 59.98881362378597, 71.27415105700493, 68.0266173183918, 61.49953655898571, 62.81640909612179, 56.62910230457783, 55.772164687514305, 54.03957165777683, 53.58339473605156, 52.0814873278141, 55.43375484645367, 55.78658491373062, 58.521944135427475, 57.840731889009476, 59.58385035395622, 60.1358163356781, 61.28568783402443, 59.213697016239166, 60.82264848053455, 55.765211060643196, 56.92447945475578, 57.082151994109154, 57.26889297366142, 56.848943307995796, 61.11078701913357, 57.70344905555248, 57.370176538825035, 58.57028514146805, 59.338155537843704, 56.363956332206726, 57.612158954143524, 55.11073037981987, 54.73561070859432, 48.13829831779003, 45.94941057264805, 44.772583320736885, 46.81736379861832, 43.217721953988075, 45.479041412472725, 44.2134965211153, 43.684846088290215, 43.980762809515, 46.09750762581825, 46.177774518728256, 45.66495403647423, 44.13610987365246, 49.695443361997604, 52.08825096487999, 51.2444606423378, 44.91110868752003, 50.719157829880714, 51.446153819561005, 55.10360196232796, 59.531337171792984, 56.3569875061512, 55.80794356763363, 50.309118032455444, 40.4674257338047, 45.45701399445534, 45.16409911215305, 47.08792828023434, 44.132298678159714, 45.322125032544136, 42.53626272082329, 46.92122362554073, 45.402593314647675, 45.51489248871803, 45.13177804648876, 47.689287811517715, 46.29482723772526, 48.442840576171875, 49.68676842749119, 44.0666875988245, 41.8690375238657, 40.69279924035072, 40.889104306697845, 44.374239295721054, 47.896163910627365, 45.70539906620979, 47.43841007351875, 47.74051286280155, 49.781375750899315, 55.75028546154499, 48.24253052473068, 41.8544615060091, 41.559787318110466, 40.5416851490736, 41.152198389172554, 50.788564905524254, 53.9038011431694, 47.279023826122284, 40.45137919485569, 43.13281551003456, 41.109169498085976, 42.151020392775536, 40.95660388469696, 42.641984447836876, 42.97135837376118, 43.99376191198826, 43.763498067855835, 43.32791604101658, 44.07335244119167, 45.51289759576321, 45.08873015642166, 47.49023549258709, 50.133601650595665, 54.236366897821426, 56.2236450612545, 60.135253965854645, 58.89122731983662, 59.26107667386532, 59.07234840095043, 57.02584661543369, 55.21557055413723, 53.75588648021221, 58.74992050230503, 62.0309342443943, 62.58662022650242, 63.33772212266922, 60.40393374860287, 59.66975994408131, 59.19768467545509, 59.47379305958748, 61.16470992565155, 55.41210740804672, 58.30452360212803, 54.734865948557854, 52.36974745988846, 58.88339214026928, 69.74912568926811, 67.14446425437927, 72.31603994965553, 64.50305119156837, 76.51705652475357, 23.552739769220352, 0.21554717444814742, 0.809719153912738, 0.14489568042336032, 0.08572747450671159, 27.100333906710148, 78.95907148718834, 71.22324898838997, 67.60135933756828, 61.85585103929043, 36.12041339278221, 25.09189087897539, 51.9521726667881, 59.63835842907429, 64.68479543924332, 1.4591730013489723, 0.11566197135834955, 0.03687699521833565, 0.02620465002109995, 0.03623351607529912, 0.1696458601509221, 0.25723120488692075, 0.21038463193690404, 0.1849552386556752, 0.16953474580077454, 0.2745996572775766, 0.21370295231463388, 16.635875925421715, 74.26974311470985, 50.651612654328346, 64.08413127064705, 44.30138200521469, 47.457971423864365, 70.70213735103607, 70.68930923938751, 81.67875275015831, 38.41883406043053, 0.28587035718373954, 0.22895900008734316, 4.98573811724782, 2.304145535454154, 1.049344448838383, 66.89064547419548, 75.39765939116478, 71.98827713727951, 67.0083175599575, 64.282868206501, 60.02190604805946, 58.3048427850008, 56.30980163812637, 57.59651139378548, 55.00685915350914, 57.91410215198994, 58.342893943190575, 62.45954744517803, 61.15260757505894, 61.73872992396355, 63.687284365296364, 63.42202439904213, 64.29627388715744, 61.8447670340538, 57.84228600561619, 59.71120432019234, 58.36755082011223, 60.01457244157791, 58.52174274623394, 62.47136101126671, 59.8687856644392, 58.91524963080883, 60.99689193069935, 63.838345259428024, 58.02418604493141, 59.854665622115135, 57.01117180287838, 58.19305658340454, 52.07567743957043, 47.67760343849659, 46.68470151722431, 48.392299488186836, 45.38994379341602, 47.76963829994202, 45.66843464970589, 46.05986684560776, 46.336028426885605, 47.200425043702126, 47.99159198999405, 49.64859187602997, 46.25825800001621, 53.22857737541199, 55.94522640109062, 51.51100113987923, 45.8782821893692, 53.75242866575718, 54.52255614101887, 59.06541757285595, 63.667544424533844, 57.58893460035324, 58.41304957866669, 52.498518750071526, 41.8265026062727, 46.57717868685722, 45.989711210131645, 48.552688881754875, 44.9586783349514, 48.36674585938454, 42.10197642445564, 49.1775843501091, 48.380558118224144, 46.99238620698452, 45.98385192453861, 49.96596984565258, 49.27990905940533, 49.01274919509888, 51.07969768345356, 44.26042400300503, 42.652069106698036, 41.365344151854515, 41.9641350209713, 44.66565705835819, 47.54241429269314, 45.02431981265545, 47.6871333271265, 49.10687394440174, 52.07095809280872, 58.65799203515053, 50.41948691010475, 45.43388843536377, 42.65357382595539, 40.43073870241642, 41.345767602324486, 53.563324213027954, 54.37669716775417, 48.46305929124355, 42.78612591326237, 45.83997264504433, 44.27769407629967, 44.894556775689125, 43.688885271549225, 45.3649715334177, 45.66686533391476, 46.05603285133839, 44.90874141454697, 44.08909119665623, 47.2024617344141, 48.00514966249466, 46.9566985219717, 50.8405689150095, 53.10593895614147, 57.80371807515621, 59.68778997659683, 61.722470596432686, 61.36327967047691, 62.43778221309185, 60.28329782187939, 60.28726100921631, 57.932724952697754, 55.6149785220623, 60.22172212600708, 65.34302651882172, 64.4274352490902, 66.20808809995651, 63.45691032707691, 63.68348076939583, 63.205804601311684, 61.145342364907265, 63.654039949178696, 57.867330461740494, 62.31248013675213, 57.181205078959465, 55.14598488807678, 60.98951652646065, 72.21890196204185, 72.519161850214, 77.84973621368408, 67.46667176485062, 78.83597329258919, 25.406232811510563, 0.6197880080435425, 1.7002000054344535, 0.6833021936472505, 0.1239045528927818, 31.182137578725815, 84.74404826760292, 77.87951901555061, 75.24196654558182, 72.95395731925964, 54.67973470687866, 37.60479234158993, 64.2666582763195, 66.21720001101494, 79.45140346884727, 2.4045615596696734, 0.2837013266980648, 0.20357970177428797, 0.11684677301673219, 0.1343795220600441], [0.11107981801615097, 0.019252689271525014, 0.06199594441568479, 0.03882660974340979, 0.07442683636327274, 0.13338357472093776, 0.16166919755050912, 3.725129636004567, 44.26002122461796, 45.65947853028774, 36.40796296298504, 16.514664329588413, 37.98457436263561, 46.64472386240959, 63.12716782093048, 61.81548200547695, 36.205661818385124, 0.1560759570566006, 0.09370423358632252, 4.900408471003175, 1.7711001634597778, 0.3643683559494093, 19.07450906932354, 78.48892271518707, 63.90321537852287, 67.75327518582344, 58.9153066277504, 60.63398860394955, 54.38019298017025, 55.504104271531105, 49.601820185780525, 51.64827257394791, 52.138453871011734, 55.54319657385349, 56.98086082935333, 56.80790551006794, 56.14549845457077, 59.24458555877209, 59.359225407242775, 61.82890668511391, 58.333497047424316, 57.44603946805, 56.14642180502415, 56.66061021387577, 54.266370087862015, 58.09291295707226, 59.28793363273144, 56.35542958974838, 56.31800539791584, 58.23429577052593, 56.1094231903553, 55.699592381715775, 52.25208297371864, 49.40622188150883, 47.19316363334656, 45.20675182342529, 44.8147876560688, 44.26742322742939, 47.780646309256554, 45.30340723693371, 45.32988041639328, 41.83855935931206, 43.55501465499401, 43.75222407281399, 41.96818560361862, 42.54057168960571, 43.525657430291176, 43.300112932920456, 42.847291231155396, 45.098423436284065, 48.62643912434578, 47.83459201455116, 48.61475095152855, 49.918517991900444, 48.993590623140335, 53.13171677291393, 53.853157460689545, 56.77236221730709, 54.61941294372082, 44.1296274214983, 41.91694535315037, 40.774608850479126, 44.19787555932999, 42.88147799670696, 42.098378017544746, 42.600084096193314, 42.56882317364216, 42.82172240316868, 40.86527198553085, 42.68485754728317, 44.903045520186424, 43.19443680346012, 42.525554895401, 46.51242256164551, 42.124148234725, 39.69875358045101, 40.92763803899288, 40.701375380158424, 45.16455888748169, 48.68855819106102, 43.095140531659126, 45.2385713160038, 49.43230368196964, 55.57949222624302, 54.74294811487198, 41.300318241119385, 42.12078921496868, 42.39175267517567, 40.80639034509659, 45.81080161035061, 50.72450414299965, 42.679028660058975, 39.35088984668255, 39.65515851974487, 39.53036941587925, 41.279814541339874, 39.512434378266335, 39.48113925755024, 41.64931431412697, 39.422223418951035, 41.81521341204643, 43.92577216029167, 43.812101259827614, 43.296286538243294, 40.637679398059845, 41.261172741651535, 41.50400251150131, 44.78376992046833, 50.24379573762417, 49.82739508152008, 53.87651100754738, 54.103176444768906, 57.769892290234566, 56.373281031847, 55.82702234387398, 56.094341799616814, 54.53746274113655, 57.20139719545841, 53.940651565790176, 56.25441960990429, 61.405290216207504, 64.0136830508709, 59.75255370140076, 58.11931014060974, 59.12007763981819, 58.69079187512398, 65.83052515983582, 59.321615025401115, 54.42777402698994, 52.35167182981968, 50.15279062092304, 66.52031734585762, 65.23288562893867, 69.15209412574768, 60.8794554322958, 71.32442235946655, 21.258348785340786, 0.263203356298618, 0.4197328398004174, 0.22455671365605667, 0.24060267372988164, 21.676214262843132, 76.65812015533447, 60.976513624191284, 67.77792066335678, 52.54910163581371, 33.51394705474377, 25.433376654982567, 40.21122828125954, 57.056032195687294, 58.240394443273544, 1.1525809904560447, 0.16718420083634555, 0.10636615610565059, 0.0254262372982339, 0.08402438659686595, 0.05226988760114182, 0.08510743238730356, 0.13699085771804675, 0.05694381121429615, 0.07068667182466015, 0.1830600161338225, 0.30494488833937794, 8.232982121407986, 59.42048192024231, 53.55090267956257, 45.85306294262409, 18.331960514187813, 42.4079892039299, 55.14406219124794, 70.5198535323143, 67.57017821073532, 44.58149157464504, 0.2304090972756967, 0.016050047452154104, 2.8566650999709964, 4.259503511711955, 0.8230460481718183, 22.263687439262867, 80.47940790653229, 64.54684764146805, 68.64199429750443, 61.216618940234184, 62.789685130119324, 57.229036912322044, 57.26526416838169, 52.48824030160904, 53.91570970416069, 55.41013151407242, 57.87877544760704, 59.64600741863251, 58.152885138988495, 59.66463781893253, 59.77147288620472, 60.161605551838875, 63.37982006371021, 60.54574213922024, 59.32313114404678, 58.48593346774578, 57.50468172132969, 56.184339970350266, 61.081277802586555, 64.47403594851494, 57.78995141386986, 60.29191195964813, 59.66877579689026, 58.48653003573418, 57.49998897314072, 55.88603317737579, 51.82124309241772, 50.570737794041634, 48.13337758183479, 46.35409265756607, 46.39832228422165, 50.58092124760151, 48.39238688349724, 47.756095826625824, 43.05141627788544, 44.665615260601044, 44.00887370109558, 45.069677978754044, 43.24599623680115, 45.153091102838516, 45.62715746462345, 44.25947405397892, 45.04947446286678, 49.866973757743835, 49.024391770362854, 51.48530311882496, 52.30653025209904, 51.99792601168156, 55.32857649028301, 57.49163322150707, 59.696297720074654, 55.84529556334019, 44.82509270310402, 42.494081184268, 43.233825489878654, 45.25535501539707, 43.88843156397343, 43.25326904654503, 42.39285461604595, 42.95531943440437, 44.79895390570164, 41.87960475683212, 43.94641265273094, 47.92767941951752, 45.637185126543045, 45.03843605518341, 48.035810217261314, 41.12902723252773, 40.145507007837296, 41.82201884686947, 39.41343069076538, 43.930130526423454, 49.35336671769619, 43.57082560658455, 48.16858649253845, 50.7011353969574, 58.08115638792515, 55.995702892541885, 43.736048340797424, 44.95175890624523, 43.597029000520706, 42.15408682823181, 45.13664938509464, 51.8226870149374, 44.18714493513107, 42.58019216358662, 41.39193892478943, 41.54227405786514, 43.032189309597015, 42.93067395687103, 42.572311386466026, 43.87542486190796, 41.401351019740105, 44.84627276659012, 46.140635311603546, 46.1183875054121, 45.586727634072304, 43.72895412147045, 43.12599867582321, 44.172998294234276, 47.68545001745224, 50.750012174248695, 52.056226283311844, 56.38819143176079, 56.381260603666306, 59.774649515748024, 59.11638043820858, 59.483695328235626, 59.07036870718002, 56.69483117759228, 58.112402111291885, 56.25626631081104, 58.46617452800274, 61.936729699373245, 65.77867314219475, 64.40877825021744, 63.037739619612694, 61.076174676418304, 60.30906803905964, 65.15613734722137, 63.101481199264526, 57.32994429767132, 56.477482840418816, 53.172784969210625, 69.40886914730072, 67.06778436899185, 73.66116017103195, 65.45144230127335, 75.67824393510818, 23.870571814477444, 0.2757336589274928, 0.7006030809134245, 0.19490310485707596, 0.5444356170482934, 23.896742910146713, 84.88512709736824, 67.6598533987999, 74.67224791646004, 61.71472281217575, 43.12175810337067, 35.174085572361946, 53.6137019097805, 61.88364274799824, 71.61696866154671, 2.0217302022501826, 0.1898835742031224, 0.06079452236008365, 0.06292660502367653, 0.09710934071335942, 0.17730522493366152, 0.19634600321296602, 0.24972426239401102, 0.23884036985691637, 0.18643052433617413, 0.4149054957088083, 0.49906450789421797, 14.580969940871, 80.22222250699997, 60.3730072081089, 50.04306010901928, 23.88471655547619, 53.70530739426613, 64.64861378073692, 77.0184700191021, 73.78798976540565, 51.687452271580696, 0.5796009488403797, 0.16770263551734388, 10.962122026830912, 6.554010389372706, 0.5355518124997616, 24.18658945709467, 88.4614571928978, 69.26580682396889, 72.98553362488747, 64.49557319283485, 66.13659113645554, 62.22043387591839, 61.68685510754585, 56.27086512744427, 57.16268867254257, 56.96095749735832, 60.13688787817955, 62.618378922343254, 61.589014157652855, 62.100645303726196, 62.66827404499054, 62.7481609582901, 66.27298101782799, 62.865764647722244, 63.389672935009, 60.5639773607254, 58.84980194270611, 60.24605602025986, 62.06639014184475, 63.24769735336304, 61.0521599650383, 62.833538576960564, 62.414675652980804, 59.718739315867424, 60.892572328448296, 56.65038116276264, 56.00704528391361, 52.96819634735584, 50.30271537601948, 49.19767007231712, 49.1297373175621, 52.67705217003822, 51.14283509552479, 50.5669341981411, 44.87453565001488, 47.757448554039, 47.14316591620445, 48.339980095624924, 45.28267554938793, 48.080058842897415, 47.42543376982212, 46.09719604253769, 48.50106105208397, 52.773232609033585, 52.691434398293495, 54.52599115669727, 52.50010706484318, 54.75555583834648, 58.07183548808098, 60.108868181705475, 61.39311946928501, 57.38448277115822, 46.416926085948944, 43.94342981278896, 44.10000041127205, 48.89867551624775, 46.073112934827805, 43.75622905790806, 45.46853877604008, 44.07196931540966, 45.97800023853779, 43.045644387602806, 44.94649238884449, 48.3360131084919, 46.58790551126003, 47.5816585868597, 49.293071553111076, 43.13441902399063, 40.52656576037407, 41.597644686698914, 42.25765027105808, 45.694501250982285, 51.79307900369167, 45.70976883172989, 46.84652343392372, 50.78612923622131, 61.057008504867554, 59.074502885341644, 47.66940727829933, 44.61307168006897, 44.87199358642101, 43.58654536306858, 48.55127915740013, 56.36515326797962, 46.90804213285446, 44.98428136110306, 45.22308334708214, 44.08662132918835, 47.15304538607597, 44.65463005006313, 44.65838044881821, 46.98384426534176, 44.34923283755779, 46.96341656148434, 47.574902549386024, 47.78934024274349, 47.37292058765888, 45.44839225709438, 46.50540433824062, 47.010279446840286, 49.23905745148659, 55.327797532081604, 55.78855700790882, 58.7336041778326, 58.780615255236626, 61.70815296471119, 61.6433360427618, 61.33203774690628, 63.379333689808846, 59.66806523501873, 63.54634612798691, 60.49728333950043, 61.15310914814472, 64.4303534924984, 67.82104074954987, 66.32730290293694, 64.43324893712997, 64.25105631351471, 65.0694639980793, 68.35707038640976, 65.73298439383507, 60.282207280397415, 58.76122869551182, 56.93088971078396, 73.70867282152176, 71.5243524312973, 77.24851727485657, 70.3537568449974, 81.10828936100006, 26.153873093426228, 0.8464401459787041, 1.595922438427806, 0.6618148810230196, 0.4923996061552316, 26.886439584195614, 92.12707489728928, 74.57232847809792, 83.55398252606392, 70.5810834467411, 51.18560180068016, 37.22076214849949, 60.20143121480942, 70.3996279835701, 84.19061556458473, 3.0527077428996563, 0.47872791008558124, 0.15210003446554765, 0.1577038282994181, 0.15982175449607894], [0.06452045621699654, 0.11859577018185519, 0.04392314935103059, 0.054624904005322605, 0.06600087755941786, 0.04975571020622738, 0.4114988597575575, 12.056911680847406, 51.33401043713093, 45.42257644236088, 40.103986635804176, 23.82331945002079, 37.071620151400566, 47.36651413142681, 65.34750267863274, 61.998890563845634, 45.95533065497875, 0.5248849536292255, 0.07645955658517778, 0.7212385861203074, 0.49424767261371017, 0.30369451793376356, 0.04821246235223953, 40.111753419041634, 80.88962629437447, 60.193307250738144, 65.81108540296555, 55.95034472644329, 58.531386628746986, 55.20169369876385, 52.919946536421776, 53.48956257104874, 55.7832220941782, 54.87842604517937, 60.04907079041004, 58.53427827358246, 57.69182927906513, 58.51891949772835, 58.014268577098846, 58.7426932901144, 58.09302315115929, 58.27019244432449, 59.01274859905243, 54.531052485108376, 52.946966886520386, 52.47879400849342, 46.41576714813709, 59.70642037689686, 53.77344153821468, 56.32039166986942, 54.02758710086346, 49.763307720422745, 52.49408818781376, 49.58143807947636, 47.78031952679157, 44.36272591352463, 43.732841312885284, 46.976115480065346, 50.12218326330185, 52.056279480457306, 50.22106155753136, 44.59528483450413, 42.66720749437809, 43.68513107299805, 41.3390077650547, 41.708496138453484, 46.03573054075241, 41.56124264001846, 41.77091158926487, 43.13570715487003, 47.13976889848709, 45.336898639798164, 49.15641948580742, 51.05236195027828, 48.96958351135254, 50.438398495316505, 49.84723761677742, 55.1732712239027, 54.38491232693195, 45.30071318149567, 42.54290096461773, 42.824120074510574, 43.38912695646286, 40.24118207395077, 41.89199589192867, 40.599236860871315, 44.67004582285881, 44.95270885527134, 41.18450425565243, 41.700873747467995, 43.567538782954216, 42.98123024404049, 40.72737738490105, 46.987237483263016, 43.97350139915943, 41.235231533646584, 39.34978790581226, 40.63142113387585, 44.22299221158028, 50.3488676995039, 48.12285974621773, 52.48218722641468, 54.960832223296165, 49.73072066903114, 45.67423693835735, 45.248686373233795, 45.65827779471874, 40.62536045908928, 43.1549721211195, 43.076821714639664, 41.55243471264839, 38.645096719264984, 37.57290445268154, 41.70196048915386, 41.28679096698761, 40.53038075566292, 40.49809008836746, 41.9165463745594, 41.27432383596897, 40.43763533234596, 41.371484622359276, 45.16038291156292, 50.06171330809593, 51.25572703778744, 50.878065302968025, 43.492428213357925, 42.6053050160408, 40.48239313066006, 43.211368694901466, 46.51418946683407, 50.91377578675747, 52.97988072037697, 56.00207135081291, 57.44537450373173, 57.516537085175514, 59.14746277034283, 59.90173749625683, 47.48032182455063, 46.70198678970337, 49.04452309012413, 47.99083963036537, 52.27802038192749, 58.47052909433842, 65.10759115219116, 62.802798226475716, 68.22279319167137, 68.7816596031189, 62.24341504275799, 60.14838986098766, 57.077599838376045, 50.00801078975201, 57.32337825000286, 63.21657322347164, 71.44603103399277, 65.10732516646385, 68.26115593314171, 25.298159010708332, 0.21396668191300705, 0.5216606485191733, 0.1419522930518724, 0.5314546229783446, 24.107050225138664, 73.66876736283302, 62.69959956407547, 68.76073032617569, 51.334291622042656, 35.28790086507797, 18.621814660727978, 31.76393385976553, 55.6604278832674, 56.758466362953186, 1.116859819740057, 0.063794160814723, 0.03744075285794679, 0.019299084633530583, 0.043573111688601784, 0.02537449476221809, 0.11690468279994093, 0.10477326228283346, 0.13594892690889537, 0.05292454348818865, 0.12400503968819976, 0.3661170043051243, 15.52331367507577, 62.96788036823273, 51.84914879500866, 36.74207143485546, 35.19400790333748, 49.94656428694725, 53.23668614029884, 73.02841812372208, 66.47678688168526, 53.17667976021767, 0.7090379158034921, 0.08051109660300426, 1.7988702608272433, 1.8163196370005608, 1.4784884336404502, 0.21156908478587866, 46.260302290320396, 79.51983779668808, 62.31551997363567, 68.443713337183, 59.21405039727688, 61.21008709073067, 58.07053595781326, 56.10623516142368, 55.87258189916611, 57.83872939646244, 58.638943657279015, 62.07035332918167, 60.87889306247234, 61.19314379990101, 59.68612186610699, 60.54848559200764, 60.88730201125145, 61.67012080550194, 58.67435395717621, 60.84267720580101, 56.95084623992443, 55.3117585927248, 57.642713114619255, 52.15710707008839, 60.391196832060814, 59.20048512518406, 58.21103721857071, 55.109233260154724, 51.64342023432255, 54.482532888650894, 51.28734514117241, 50.50220847129822, 46.40347860753536, 46.843601390719414, 48.12182620167732, 53.458974212408066, 54.73091796040535, 51.58003583550453, 47.47651822865009, 44.02903541922569, 44.225880056619644, 44.24296393990517, 43.32795403897762, 48.79079170525074, 44.160504564642906, 44.05814565718174, 46.16384066641331, 48.21631193161011, 47.845071852207184, 50.99210858345032, 52.62239210307598, 51.76332280039787, 51.8951491266489, 52.92481027543545, 56.76942877471447, 54.43061247467995, 46.66168235242367, 45.65427280962467, 44.95781198143959, 45.55999606847763, 40.935401022434235, 44.620211496949196, 40.71260757744312, 44.770774617791176, 44.58095200359821, 39.839509427547455, 42.10186243057251, 44.33049224317074, 45.02287968993187, 42.22304932773113, 49.43935230374336, 45.39808675646782, 42.25006587803364, 42.902935445308685, 42.66270473599434, 46.54776066541672, 49.863086566329, 48.300219029188156, 52.90891572833061, 55.498385578393936, 49.596504271030426, 49.874991327524185, 49.138347655534744, 47.42907777428627, 42.90824756026268, 44.38255324959755, 45.41303135454655, 45.41001811623573, 41.28233760595322, 41.33406043052673, 42.704513892531395, 42.68259286880493, 42.76944100856781, 42.213413044810295, 44.0055450797081, 42.865469455718994, 42.846451476216316, 45.004800260066986, 48.227107152342796, 53.40348199009895, 53.15915510058403, 51.174810379743576, 46.764831617474556, 44.06803272664547, 42.4975161999464, 45.46378143131733, 48.2713557779789, 53.10472682118416, 55.844178423285484, 58.6161220818758, 58.70909549295902, 60.20086884498596, 59.62355822324753, 61.690689101815224, 51.22752495110035, 46.452959552407265, 51.6656718403101, 51.007060781121254, 51.68818183243275, 59.69013825058937, 67.0306983590126, 66.06334626674652, 68.32847312092781, 72.92175024747849, 65.59702008962631, 62.251508608460426, 61.24639414250851, 52.54702314734459, 62.95959301292896, 67.30683714151382, 72.95689076185226, 68.96936193108559, 74.96464982628822, 28.230429366230965, 0.12371891207294539, 0.7190433726646006, 0.13374084461247548, 0.7186891604214907, 27.984529361128807, 80.4631295800209, 68.68288770318031, 76.88402563333511, 59.25981894135475, 40.623350366950035, 18.98536965250969, 39.793459698557854, 63.28837417066097, 68.13544347882271, 1.7983322334475815, 0.058644654127419926, 0.0288059369995608, 0.02363193387282081, 0.08591179430368356, 0.1481411961140111, 0.24608625448308885, 0.1243705177330412, 0.22123334667412564, 0.20385006617289037, 0.4508676566183567, 0.4267841629916802, 25.413351729512215, 82.2110965847969, 62.53666430711746, 56.29487983882427, 37.4161134660244, 54.780383706092834, 62.82278895378113, 76.9491845369339, 73.64459306001663, 59.80608522891998, 1.0065348772332072, 0.22477978840470314, 2.2226496459916234, 2.476693564094603, 0.7653941761236638, 0.2811238181311637, 51.125477626919746, 85.02321168780327, 63.5339929908514, 71.08612194657326, 61.7139058560133, 64.66176867485046, 61.48388519883156, 58.387484550476074, 58.93256530165672, 62.35874645411968, 61.371760815382004, 64.32371601462364, 64.05266895890236, 62.80221305787563, 62.363636791706085, 62.73505926132202, 64.35719981789589, 62.34765484929085, 61.30642332136631, 64.07393261790276, 58.484272956848145, 57.51968331634998, 54.592647179961205, 51.74403503537178, 64.04779002070427, 59.57506522536278, 60.30048429965973, 59.0465933829546, 53.48494581878185, 56.54229216277599, 54.253104999661446, 53.0690011382103, 48.67021657526493, 48.972991928458214, 52.538674995303154, 55.98712295293808, 58.782750740647316, 54.02990497648716, 51.519094705581665, 48.242473527789116, 48.39940890669823, 45.183523669838905, 46.1068969219923, 51.262027099728584, 46.41932375729084, 46.115636453032494, 49.01914805173874, 50.451150611042976, 49.204901084303856, 54.11787025630474, 54.9549425393343, 54.04119797050953, 54.80810321867466, 54.88996222615242, 59.86533164978027, 57.57621668279171, 48.95332798361778, 46.68412774801254, 44.7813456505537, 47.15305298566818, 43.807693496346474, 47.292649894952774, 42.79654495418072, 46.53103016316891, 46.85804441571236, 41.655758768320084, 43.461874052882195, 45.69882161915302, 45.00510424375534, 44.6280162781477, 50.473033636808395, 45.790750086307526, 42.84424379467964, 42.733696326613426, 43.01946759223938, 46.31495475769043, 51.228721886873245, 48.80571350455284, 56.05287462472916, 57.884927317500114, 53.2567984610796, 55.19340254366398, 49.56653147935867, 48.84722247719765, 44.049892500042915, 45.82359552383423, 48.56895200908184, 46.56330183148384, 43.55658397078514, 42.30952888727188, 46.36911325156689, 46.492861211299896, 45.644636526703835, 43.403847366571426, 47.03596606850624, 44.6443136036396, 43.94204668700695, 45.67858770489693, 50.5060500651598, 56.58632040023804, 56.54113322496414, 54.727707132697105, 48.31231378018856, 48.025778755545616, 46.60661570727825, 48.5195242613554, 52.04560585319996, 56.19230814278126, 59.82409246265888, 62.02708885073662, 63.13339948654175, 62.96936608850956, 65.18027365207672, 65.40090501308441, 51.86533212661743, 49.70171682536602, 53.80610838532448, 54.60629224777222, 56.786394864320755, 62.584214955568314, 70.99713832139969, 67.890615016222, 70.6119529902935, 73.99944841861725, 68.84918197989464, 65.45556887984276, 65.10674759745598, 54.927998185157776, 65.37492960691452, 69.14098352193832, 77.44787737727165, 72.91795805096626, 78.59014928340912, 28.636055700480938, 0.6081317772623152, 1.3180441805161536, 0.29375686368439347, 0.938293389044702, 32.23280780017376, 86.79085403680801, 74.92279127240181, 82.85264655947685, 68.70013117790222, 52.349790930747986, 26.242965012788773, 51.79659001529217, 69.16676133871078, 84.93550479412079, 4.132046476006508, 0.2520982740679756, 0.1720643709995784, 0.09544449567329139, 0.1792852600920014], [0.055578619430889376, 0.016098617306852248, 0.08628397394204512, 0.12634264159714803, 0.08063629691605456, 0.3660809656139463, 0.2301667266874574, 21.796010434627533, 56.89315393567085, 50.60484856367111, 50.35981111228466, 15.664794333279133, 37.53970563411713, 49.38688091933727, 66.35387107729912, 58.17507214844227, 53.37092153728008, 1.1529545579105616, 0.11641215649433434, 0.5394032027106732, 3.281731428578496, 1.9543038890697062, 0.03564299287972972, 1.210219741333276, 64.40699994564056, 68.07483673095703, 67.49437227845192, 60.74746571481228, 59.03460882604122, 53.2937590777874, 55.013979971408844, 53.875230476260185, 56.958970203995705, 54.35137152671814, 58.57972003519535, 59.33338679373264, 62.78952173888683, 56.34347163140774, 61.555553153157234, 56.61118246614933, 56.20095647871494, 53.96749332547188, 56.30100131034851, 53.011270835995674, 53.51033605635166, 37.875448018312454, 48.71272869408131, 55.964806750416756, 53.976460844278336, 55.006665363907814, 50.940989926457405, 52.471866980195045, 49.38094183802605, 46.728266179561615, 46.370971351861954, 47.19567149877548, 50.535768270492554, 51.32362179458141, 56.9226935505867, 53.65274481475353, 53.55908364057541, 48.92569586634636, 39.62102495133877, 41.19849890470505, 40.96460625529289, 40.91455154120922, 43.00939813256264, 42.90598288178444, 42.637721076607704, 44.73707802593708, 46.440199837088585, 47.350490391254425, 46.953879073262215, 46.48553520441055, 47.25983865559101, 51.940891072154045, 53.2474509626627, 50.459920540452, 52.56018944084644, 50.16738183796406, 45.773882791399956, 45.21350026130676, 43.1439983099699, 40.54773062467575, 40.30370011925697, 39.4292264431715, 43.4256049990654, 48.41548204421997, 43.31295624375343, 43.06583650410175, 45.34615494310856, 41.14495977759361, 44.44807693362236, 44.995555356144905, 45.554193779826164, 39.00682970881462, 40.15374876558781, 39.887941628694534, 45.989369228482246, 45.076274424791336, 47.29768842458725, 54.288484901189804, 52.15489938855171, 42.51993499696255, 51.2311727553606, 47.34743535518646, 44.50994901359081, 45.174578949809074, 42.609784975647926, 41.805318742990494, 43.49582523107529, 41.65152579545975, 42.96945467591286, 41.05043984949589, 40.39044566452503, 38.430066257715225, 41.499777138233185, 43.21253143250942, 40.85319623351097, 43.140905275940895, 47.54188612103462, 48.543280586600304, 52.78399743139744, 54.040327817201614, 53.49222622811794, 53.53498913347721, 48.50500524044037, 47.39192336797714, 43.94120693206787, 44.31752733886242, 45.53350009024143, 48.96565832197666, 55.21356426179409, 58.18012207746506, 58.09114225208759, 57.49028429389, 56.226855888962746, 50.79038880765438, 53.184267953038216, 60.43280079960823, 56.391748040914536, 50.87057590484619, 44.36917416751385, 47.57159672677517, 51.7545110732317, 65.65519496798515, 61.52741566300392, 59.39460150897503, 63.73157858848572, 60.76822780072689, 53.80836546421051, 54.013368263840675, 64.0111143887043, 67.97763034701347, 63.91076937317848, 68.75889882445335, 23.997545801103115, 0.26443950715474784, 0.5610952293500304, 0.12053148428094573, 1.2636023643426597, 32.583536580204964, 73.42360451817513, 62.03313812613487, 65.98760113120079, 49.971623942255974, 38.25951620936394, 32.49028578400612, 45.509439781308174, 52.82422587275505, 62.1292881667614, 4.268110524863005, 0.3078675549477339, 0.11383941251551732, 0.0949877111997921, 0.04683264654886443, 0.12542420416139066, 0.0802480720449239, 0.06258122433791868, 0.11803409797721542, 0.08464173472020775, 0.1935736511950381, 0.31817286915611476, 27.58975524455309, 70.16956552863121, 52.567986622452736, 59.09319028258324, 25.036582946777344, 43.1195580214262, 56.235173642635345, 73.55149805545807, 65.85827127099037, 62.01834551990032, 1.3709634658880532, 0.13661844801390544, 2.4277574149891734, 7.446066671982408, 6.370510160923004, 0.43086193792987615, 1.7409829795360565, 65.88154122233391, 67.5176802277565, 69.93283063173294, 62.73311756551266, 62.20862030982971, 55.50402447581291, 58.19552645087242, 55.28299793601036, 58.78973476588726, 57.39931717514992, 62.15077981352806, 61.88539445400238, 65.46519756317139, 59.324058294296265, 63.052695617079735, 58.60259860754013, 57.191228941082954, 56.66018083691597, 59.84762839972973, 52.85160720348358, 54.87344071269035, 42.30835095047951, 50.386527478694916, 59.222698733210564, 56.96886107325554, 55.25102265179157, 54.32383060455322, 54.905495792627335, 50.636956840753555, 49.60622034966946, 47.66482852399349, 48.96909713745117, 53.23301173746586, 53.909968212246895, 59.20306898653507, 57.411784306168556, 56.798193231225014, 50.155211091041565, 41.643926203250885, 43.20862904191017, 42.02115096151829, 44.153626933693886, 44.59901623427868, 44.80254851281643, 45.10894887149334, 47.47907169163227, 50.12264683842659, 49.2965217679739, 50.07158897817135, 49.02918331325054, 50.43471649289131, 53.49892906844616, 53.01349751651287, 51.35487511754036, 54.08048406243324, 50.24627320468426, 48.09734791517258, 46.032363921403885, 45.39788916707039, 44.060155749320984, 41.547308787703514, 40.06791137158871, 44.79567468166351, 48.694995045661926, 44.06673699617386, 43.54255132377148, 45.99451795220375, 42.693965658545494, 45.422538444399834, 45.6088462471962, 47.24856086075306, 42.21042260527611, 40.79796239733696, 41.60304419696331, 47.76174992322922, 43.99423688650131, 49.240683764219284, 54.69356216490269, 52.95750752091408, 46.95796765387058, 54.012338519096375, 48.539697378873825, 45.438558384776115, 46.644606068730354, 43.76543216407299, 44.470282942056656, 43.00183653831482, 42.53393344581127, 45.557556599378586, 44.11146059632301, 42.25511200726032, 40.921440571546555, 43.35170276463032, 43.128821924328804, 42.25922718644142, 45.141478925943375, 49.30797055363655, 50.49187682569027, 54.92006801068783, 56.91335745155811, 56.35715089738369, 56.686372831463814, 50.45304670929909, 48.93401362001896, 46.24416835606098, 45.783142894506454, 48.630611300468445, 52.18006543815136, 57.060192972421646, 58.59860882163048, 60.6922622770071, 60.20572118461132, 58.21267493069172, 52.76951260864735, 52.13178522884846, 57.521545216441154, 55.4754576086998, 54.91728276014328, 47.54087537527084, 49.90584947168827, 51.61660887300968, 66.71355217695236, 68.99915993213654, 62.86826491355896, 67.20376387238503, 64.59339514374733, 56.95703610777855, 58.234417364001274, 66.66467919945717, 71.70845255255699, 68.58980789780617, 71.81874543428421, 26.488853618502617, 0.6650322990026325, 0.5169011070393026, 0.01131182045355672, 1.1985905840992928, 38.392319083213806, 79.39800873398781, 67.83816263079643, 74.16328802704811, 57.76256628334522, 41.83264687657356, 33.35915856063366, 55.729880556464195, 58.942771553993225, 75.45485392212868, 5.337075339630246, 0.18174632568843663, 0.09712566054076888, 0.11030572088202462, 0.10129687929293141, 0.15881577332038432, 0.18701708817388862, 0.21885286347242072, 0.30497861152980477, 0.19925161526771262, 0.41512297466397285, 0.4871440428541973, 36.81443475186825, 81.9872809946537, 65.4041576385498, 69.48985800147057, 21.387342363595963, 52.395179495215416, 63.69977429509163, 81.0457295179367, 72.07546725869179, 71.24381348490715, 1.4619620516896248, 0.4462326772045344, 4.2048833426088095, 10.317697506397963, 5.654186848551035, 0.24564472114434466, 2.538921874947846, 70.3348870575428, 70.7663007080555, 74.89126816391945, 65.58351561427116, 66.81488513946533, 58.485036715865135, 60.51144137978554, 59.47044163942337, 61.19969464838505, 59.30851332843304, 64.13443297147751, 64.98228147625923, 66.3020570576191, 61.322462260723114, 66.45193621516228, 60.97582586109638, 60.855767503380775, 58.913786709308624, 61.831384152173996, 53.86371709406376, 53.87880228459835, 40.15629842877388, 54.90019127726555, 62.45082691311836, 59.99880328774452, 60.227668806910515, 56.7268330603838, 58.480104580521584, 53.098430559039116, 54.16536010801792, 50.04568576812744, 51.16767816245556, 57.60818436741829, 56.43975466489792, 62.16585360467434, 58.69357332587242, 59.130500480532646, 52.53083221614361, 44.043486043810844, 45.07836051285267, 45.82329913973808, 44.910113140940666, 49.28840920329094, 46.98167838156223, 47.1599268168211, 49.72931854426861, 52.48247601091862, 52.19135083258152, 54.197597578167915, 50.77063746750355, 53.92029605805874, 56.464620530605316, 57.2381754219532, 54.88297060132027, 56.08676500618458, 55.89192286133766, 48.30993130803108, 47.78717815876007, 47.25521430373192, 44.930803030729294, 44.22439053654671, 42.6199646294117, 44.184162095189095, 48.46407003700733, 45.011351108551025, 46.786148473620415, 48.431289196014404, 43.82712945342064, 49.159151539206505, 47.505837455391884, 48.91135923564434, 44.40366871654987, 42.30666384100914, 39.654713943600655, 49.64028172194958, 46.329656168818474, 49.73663315176964, 56.66924335062504, 55.15156298875809, 52.25162319839001, 55.213902443647385, 50.130660608410835, 48.09660695493221, 49.02069456875324, 46.66092239320278, 47.467216327786446, 47.88925588130951, 46.218333542346954, 47.828402146697044, 46.468428522348404, 46.1806433647871, 42.249093130230904, 45.168799459934235, 46.616043001413345, 45.58220587670803, 47.68443167209625, 53.339280635118484, 54.01045002043247, 58.399465307593346, 57.05022610723972, 58.98970663547516, 59.07988339662552, 53.46137948334217, 52.401164174079895, 49.717318788170815, 48.681676760315895, 51.047331020236015, 55.35937003791332, 61.520454436540604, 60.976506024599075, 63.55638898909092, 63.997245132923126, 60.160138830542564, 53.90461049973965, 53.768140822649, 57.80811823904514, 55.21210893988609, 54.050712659955025, 48.22974421083927, 52.23980963230133, 55.69883622229099, 67.82704442739487, 71.64761781692505, 66.34753301739693, 69.851583391428, 66.77313297986984, 60.51876358687878, 62.7876902371645, 69.73783269524574, 75.88561400771141, 72.11959049105644, 76.48557141423225, 28.892277851700783, 1.3863665331155062, 1.5684909978881478, 0.19506542739691213, 2.893440001644194, 43.783564791083336, 86.8960551917553, 74.66901049017906, 81.02706491947174, 67.33954578638077, 60.5329330265522, 43.65008935332298, 63.86907801032066, 65.85089966654778, 91.24623656272888, 8.581586815416813, 0.8090920688118786, 0.19087477179709822, 0.23170165135525167, 0.19495064683724195], [0.07645009420230053, 0.02999527318024775, 0.010576765853329562, 0.034383627644274384, 0.07801173618645407, 0.16777333250502124, 0.26282132836058736, 22.68978137522936, 54.82520990073681, 40.41934311389923, 24.3361247330904, 29.233689531683922, 44.74753126502037, 50.015967562794685, 71.4717024564743, 57.538165524601936, 62.11149752140045, 3.0199456633999944, 0.15463806077605113, 1.1029275110922754, 2.327824914827943, 5.601355908438563, 0.46099990198854357, 0.4286217503249645, 21.513246707618237, 65.5204389989376, 59.894848465919495, 63.1681714206934, 55.51748335361481, 58.57052072882652, 56.380299255251884, 58.20150353014469, 58.930072635412216, 59.92001071572304, 60.113378539681435, 61.824445724487305, 56.656096056103706, 58.99715043604374, 57.901357635855675, 57.94281341135502, 55.494388192892075, 56.23122565448284, 50.582889541983604, 53.97562488913536, 48.81626553833485, 41.00893847644329, 53.99217300117016, 55.11996768414974, 56.06930874288082, 51.80440239608288, 49.59529593586922, 50.69698981940746, 47.43244059383869, 48.72321233153343, 49.22959975898266, 49.9797061085701, 52.334302961826324, 54.73152972757816, 55.36186270415783, 54.05303813517094, 56.51787847280502, 48.14947731792927, 40.51438741385937, 40.62457390129566, 41.54620684683323, 39.46921929717064, 41.63051672279835, 39.9925272166729, 44.632815420627594, 45.066995322704315, 47.3056185990572, 46.396612375974655, 47.66216106712818, 47.800473645329475, 48.17015200853348, 46.733608692884445, 50.03872074186802, 54.41367298364639, 51.526580303907394, 49.06379945576191, 42.30572149157524, 46.74250401556492, 44.32525232434273, 42.21125856041908, 39.28179435431957, 38.62471841275692, 43.42107184231281, 50.49719274044037, 44.17632311582565, 39.596592262387276, 48.38145487010479, 42.44548559188843, 42.35107205808163, 42.54605479538441, 43.390502482652664, 43.21874029934406, 41.04940630495548, 41.632580012083054, 47.32876695692539, 51.36409342288971, 49.99371595680714, 55.39503112435341, 46.012247800827026, 47.41614706814289, 50.306640565395355, 44.48836997151375, 45.921451672911644, 42.92457528412342, 45.068796426057816, 43.21768395602703, 43.52420970797539, 40.26914857327938, 42.493340224027634, 40.72647303342819, 39.74080212414265, 38.59664931893349, 40.9983104467392, 40.231686383485794, 41.032721400260925, 45.05976051092148, 46.28811299800873, 49.415679574012756, 53.45555439591408, 56.1168821901083, 53.927709460258484, 54.618554189801216, 52.26504787802696, 50.1347491890192, 48.701811879873276, 47.37725615501404, 44.47434492409229, 46.1837287992239, 49.59558092057705, 51.760871931910515, 56.89595818519592, 55.2884316444397, 58.68889577686787, 54.7343035787344, 50.53332880139351, 52.07550644874573, 57.35275827348232, 61.216653138399124, 61.18391029536724, 51.78539961576462, 48.27069081366062, 50.61925359070301, 43.59100632369518, 68.34485784173012, 66.02904930710793, 65.18509939312935, 55.35268999636173, 57.673445865511894, 59.49427776038647, 70.43147027492523, 66.3577164709568, 69.11296382546425, 20.678819082677364, 0.2700698550324887, 0.23290851706406102, 0.09711213861010037, 0.619901823811233, 47.50624403357506, 69.32873144745827, 65.58655545115471, 66.72068059444427, 46.49290680885315, 39.06406223773956, 19.25091080367565, 29.508794769644737, 54.2300820350647, 65.03208920359612, 8.912217523902655, 0.2689177746651694, 0.2133436786243692, 0.005238644653218216, 0.03831680252915248, 0.07683244868530892, 0.04250067118846346, 0.011530728970683413, 0.0964383278915193, 0.03927799509256147, 0.14114767138380557, 0.21139899938134477, 32.82185219228268, 65.53170919418335, 49.391144290566444, 36.41719646751881, 22.875883989036083, 50.175011828541756, 54.999970123171806, 76.91337525844574, 62.08200730383396, 71.66857749223709, 3.3509979117661715, 0.07198457678896375, 1.7975305952131748, 7.683763392269611, 8.89407254755497, 1.1607617139816284, 0.4677546629682183, 28.302633091807365, 69.22622054815292, 60.57899795472622, 66.01992979645729, 58.300575613975525, 61.35686941444874, 58.99387501180172, 63.02278362214565, 59.99314919114113, 61.693793535232544, 62.4867007881403, 64.18139085173607, 56.901680678129196, 60.40242902934551, 59.89058889448643, 60.792447701096535, 56.11918106675148, 56.6241055727005, 53.30589942634106, 54.642314314842224, 48.895996659994125, 44.042672887444496, 56.40008859336376, 57.64124259352684, 58.59024927020073, 53.16585414111614, 52.32880465686321, 52.84341104328632, 49.49747398495674, 49.63164858520031, 51.61557912826538, 50.434598699212074, 54.514964148402214, 57.100170627236366, 57.211459055542946, 55.60240879654884, 57.733988016843796, 50.51508218050003, 41.84386007487774, 44.002368450164795, 42.30267405509949, 41.831134557724, 43.549170568585396, 42.1722574532032, 45.92024713754654, 46.653345599770546, 47.21383072435856, 49.30002897977829, 49.5856748521328, 50.36640375852585, 50.808263048529625, 48.56378048658371, 51.93355746567249, 55.260362550616264, 54.619367346167564, 49.47982393205166, 44.51666325330734, 47.8480014950037, 47.06666462123394, 44.08805005252361, 40.37416733801365, 41.718109622597694, 43.186001256108284, 51.89392939209938, 43.34723800420761, 42.22497962415218, 48.64882752299309, 42.7130064368248, 44.21293415129185, 45.979721546173096, 43.929085582494736, 43.586685955524445, 41.82413153350353, 44.27218057215214, 49.46486413478851, 51.32954567670822, 50.534886717796326, 56.375522911548615, 48.58553811907768, 53.74913804233074, 51.6243452578783, 47.54325404763222, 46.478144600987434, 45.92161886394024, 46.4136278629303, 44.08734329044819, 44.6582056581974, 43.52435030043125, 44.849392399191856, 42.23325178027153, 41.143143475055695, 41.32767677307129, 43.100654035806656, 41.44625321030617, 43.2447575032711, 46.93471670150757, 49.40450057387352, 51.8654765188694, 54.828481525182724, 57.680049911141396, 54.89471577107906, 58.65656331181526, 56.69586852192879, 52.8718601167202, 51.67700283229351, 50.90340994298458, 46.94826677441597, 47.07571193575859, 53.26024487614632, 55.17630726099014, 57.481704354286194, 58.26115272939205, 59.69716027379036, 54.60848093032837, 52.08489954471588, 54.13675904273987, 56.862337589263916, 59.78831358253956, 61.84282913804054, 54.005419090390205, 52.16084226965904, 57.41049237549305, 45.18310949206352, 68.43280032277107, 68.89199808239937, 67.87384271621704, 59.60460104048252, 58.375720381736755, 62.75292210280895, 72.86339297890663, 70.07170557975769, 75.28344511985779, 22.846730053424835, 0.38370367779862136, 0.5086793575901538, 0.05846169988217298, 0.7759412820450962, 52.42776274681091, 76.17478609085083, 72.52195090055466, 72.53284111618996, 54.62016150355339, 43.145389035344124, 23.795788027346134, 38.732666820287704, 57.53328278660774, 81.09084069728851, 11.548578757792711, 0.5391645280178636, 0.1756043708883226, 0.07430240046232939, 0.09207834387780167, 0.14132722659269348, 0.126541611389257, 0.06025170812790748, 0.1945982751203701, 0.18304677621927112, 0.30065040627960116, 0.8220991271082312, 43.78126211464405, 76.65349960327148, 58.34974117577076, 37.998219430446625, 40.7683239877224, 65.09816765785217, 63.85478317737579, 84.08541440963745, 68.8085849583149, 80.3470230102539, 3.729794123210013, 0.3368100378429517, 4.411070728674531, 9.972729217261076, 13.642571344971657, 0.575941982679069, 0.36129078827798367, 30.486267618834972, 76.50154575705528, 62.15550675988197, 69.90931749343872, 60.316576436161995, 65.81702828407288, 62.374758794903755, 65.64884930849075, 63.6977794021368, 65.59677690267563, 64.51796919107437, 66.3138896226883, 60.434271320700645, 63.51625934243202, 62.25606456398964, 62.515339851379395, 60.195366740226746, 60.495060458779335, 54.50970523059368, 57.063449397683144, 49.66289430856705, 45.37316009402275, 59.76393789052963, 59.12678427994251, 61.83878615498543, 57.12337218225002, 53.61436687409878, 55.90655207633972, 53.46539966762066, 53.892971724271774, 56.20159104466438, 56.12062878906727, 56.36107228696346, 57.71209739148617, 59.02924731373787, 60.00400520861149, 60.492719784379005, 52.50718608498573, 43.64140301942825, 45.48968464136124, 44.885346069931984, 43.773445934057236, 46.397376134991646, 43.95676709711552, 49.545172825455666, 50.09662203490734, 52.0652811974287, 51.262353882193565, 51.511650905013084, 52.560972198843956, 53.389369547367096, 53.58858145773411, 55.64069554209709, 58.780391067266464, 56.69463358819485, 52.72686369717121, 44.82559807598591, 48.38245041668415, 49.69568274915218, 47.20979154109955, 41.510435566306114, 42.16199420392513, 45.54025612771511, 50.131029188632965, 45.25504723191261, 42.52570688724518, 50.560732930898666, 45.7741753757, 45.75043044984341, 46.84142790734768, 47.90806107223034, 44.81034189462662, 44.11998733878136, 45.548646077513695, 49.28364425897598, 52.20594584941864, 52.73003272712231, 59.46919530630112, 54.81874264776707, 53.4536886960268, 53.96153524518013, 51.85437351465225, 50.317633375525475, 48.76989662647247, 49.76185239851475, 47.038413137197495, 48.12570959329605, 46.10906660556793, 46.290066093206406, 45.50365649163723, 43.05465370416641, 42.212273105978966, 45.40160536766052, 44.757790714502335, 46.615784615278244, 49.482829570770264, 52.66908019781113, 54.58347447216511, 58.48163589835167, 59.83421131968498, 57.34364256262779, 59.20505627989769, 57.98633247613907, 58.914010897278786, 53.638537377119064, 53.95978733897209, 51.00377015769482, 50.344748720526695, 54.91668999195099, 56.74403853714466, 62.29896806180477, 60.58005049824715, 62.284840419888496, 56.58099688589573, 53.89596216380596, 56.79258853197098, 58.779809698462486, 59.79851223528385, 61.13152250647545, 51.152847558259964, 50.60544893145561, 54.14579875767231, 51.53601139783859, 69.80068892240524, 71.59751370549202, 70.09420037269592, 63.734542429447174, 63.104232251644135, 68.36777821183205, 75.85959300398827, 73.03781121969223, 78.19403573870659, 27.056246772408485, 0.7734866731334478, 0.932906346861273, 0.12356015184195712, 1.6633425769396126, 56.24351419508457, 84.75934624671936, 78.45329582691193, 82.79215380549431, 61.82487890124321, 55.78281931579113, 28.872889392077923, 48.57709117233753, 64.94668498635292, 96.5499995648861, 15.816882122308016, 0.8971654053311795, 0.3227723145391792, 0.2227257759659551, 0.1602000420098193], [0.08347844050149433, 0.0529517765971832, 0.003728009087353712, 0.07256213837536052, 0.07354998888331465, 0.09841029590461403, 0.39088161138352007, 32.59237490594387, 56.10797546803951, 42.682836055755615, 38.56465883553028, 31.222331821918488, 36.64808727800846, 52.419976964592934, 73.75932410359383, 56.83027870953083, 65.5079984664917, 5.974819818511605, 0.1317150189424865, 1.7705546552315354, 6.7174909170717, 10.095942355692387, 0.725156650878489, 0.5014952493365854, 9.41732631996274, 61.11187756061554, 62.09398426115513, 67.07471519708633, 55.40195815265179, 60.609460920095444, 55.342745929956436, 62.50410005450249, 58.382829800248146, 60.27251020073891, 60.04619814455509, 60.52541323006153, 56.83747172355652, 58.60830970108509, 54.55025665462017, 52.53815442323685, 49.647208750247955, 55.156586319208145, 54.108534157276154, 56.71557046473026, 50.097533985972404, 51.60545267164707, 53.423309326171875, 52.07610301673412, 53.22412021458149, 49.52209286391735, 49.72774162888527, 51.39794200658798, 47.51866936683655, 47.13645547628403, 48.45756098628044, 53.94960008561611, 54.45145435631275, 60.572709292173386, 52.57418029010296, 54.26048040390015, 53.346219062805176, 45.71438938379288, 38.69475245475769, 42.203062400221825, 40.208260640501976, 40.77298253774643, 39.68700461089611, 41.24268293380737, 43.27386774122715, 44.779495149850845, 45.51683038473129, 47.315520867705345, 44.8612629622221, 49.55069772899151, 49.25678350031376, 48.00227701663971, 49.96053993701935, 51.06770172715187, 51.78944259881973, 52.306819036602974, 44.255438670516014, 45.41500724852085, 42.79934160411358, 43.685944229364395, 40.77693432569504, 39.011583253741264, 38.29790934920311, 49.589839428663254, 46.76196277141571, 36.01029150187969, 47.76512414216995, 39.842013493180275, 43.95682789385319, 42.06685870885849, 42.57516883313656, 42.02694945037365, 43.96067328751087, 49.10355672240257, 51.34597219526768, 49.93806034326553, 48.60599622130394, 46.08973704278469, 48.60048271715641, 48.65705028176308, 44.96171437203884, 48.596078753471375, 44.64220471680164, 45.44464185833931, 45.759663954377174, 44.335652366280556, 41.311911419034004, 43.521120473742485, 40.53389556705952, 39.77734096348286, 40.46835668385029, 41.905264779925346, 40.667530596256256, 42.12854079902172, 42.54231579601765, 47.86787822842598, 51.372715160250664, 53.10403145849705, 54.55916337668896, 51.99149675667286, 53.208689242601395, 52.01643481850624, 53.69993828237057, 60.583702102303505, 58.38506028056145, 51.872126162052155, 47.33984336256981, 44.913027584552765, 47.02616639435291, 50.81443011760712, 54.2072718590498, 57.30967238545418, 56.357994452118874, 57.04483039677143, 59.61009934544563, 62.72314690053463, 57.7651197463274, 57.27968439459801, 57.55505941808224, 65.33104956150055, 63.386655896902084, 43.54607753455639, 55.23152209818363, 60.37380136549473, 62.30779878795147, 65.58122053742409, 60.93811668455601, 56.41691409051418, 61.38966545462608, 68.54564666748047, 65.28925940394402, 74.62560161948204, 18.904546089470387, 0.2129860970308073, 0.13277614169055596, 0.09786739261471666, 2.2301093582063913, 57.09773875772953, 66.17496907711029, 67.83510759472847, 68.87619093060493, 44.232187718153, 36.914092004299164, 33.7126611918211, 41.37795567512512, 56.83834947645664, 67.88879111409187, 11.031460706144571, 0.3933784633409232, 0.2025287612923421, 0.05736146224080585, 0.04914573160931468, 0.042788149512489326, 0.03530417277943343, 0.03258066521084402, 0.07582347665447742, 0.029916770654381253, 0.09928716564900242, 0.37135318270884454, 41.773438453674316, 66.52613863348961, 48.23263205587864, 44.74664591252804, 25.669040009379387, 42.31352247297764, 58.57803672552109, 80.06020680069923, 63.11683617532253, 74.75545585155487, 6.157114561647177, 0.30339178105350584, 2.2415037592872977, 8.004352189600468, 5.974016636610031, 2.4689590791240335, 1.4064910844899714, 11.542104855179787, 67.39578276872635, 62.99002178013325, 68.72162282466888, 58.32297161221504, 62.449174001812935, 57.34597183763981, 64.84766989946365, 59.93620544672012, 61.703467816114426, 60.034392178058624, 62.031948789954185, 59.016081020236015, 60.46865187585354, 57.659641206264496, 54.546779841184616, 52.60869383811951, 56.71522468328476, 54.92343083024025, 56.20115026831627, 51.067241951823235, 51.7841000854969, 54.76279444992542, 55.67110151052475, 55.1374277472496, 53.10770966112614, 52.76712253689766, 51.60654701292515, 48.96992929279804, 50.17878882586956, 49.476947486400604, 56.253617852926254, 55.62167376279831, 62.357435524463654, 55.49015901982784, 56.31050080060959, 55.824430882930756, 48.385026678442955, 40.49961760640144, 44.51581969857216, 44.242994338274, 41.25022552907467, 42.790959253907204, 43.157472386956215, 44.483521431684494, 48.409010991454124, 48.8747937977314, 50.297114476561546, 49.35271315276623, 50.34752257168293, 51.73589587211609, 51.429560109972954, 53.37964206933975, 53.63912634551525, 55.1003797352314, 51.405363008379936, 45.2049545198679, 48.29795055091381, 43.952967301011086, 44.53824229538441, 42.26860888302326, 40.53503930568695, 41.295937076210976, 49.299998581409454, 48.25174123048782, 37.18897685408592, 47.46050588786602, 39.94604051113129, 45.87520055472851, 43.88119675219059, 44.171892553567886, 42.98614718019962, 44.85533148050308, 49.63454023003578, 50.838653817772865, 49.553034603595734, 49.540343284606934, 48.615039736032486, 51.87011606991291, 51.50842487812042, 47.96892620623112, 52.35175542533398, 46.60959854722023, 47.06684701144695, 47.950915172696114, 47.25791595876217, 42.97526836395264, 44.78362552821636, 41.657020300626755, 41.17326445877552, 41.776311099529266, 44.2659755051136, 42.68502853810787, 43.5805606842041, 43.99325653910637, 50.6879311054945, 52.90995307266712, 53.63671727478504, 55.79126626253128, 55.61371698975563, 55.013242810964584, 52.83199645578861, 57.699516266584396, 59.50299829244614, 62.71689623594284, 54.79326881468296, 48.852656185626984, 47.948300912976265, 47.59061470627785, 53.05694438517094, 56.333497166633606, 59.280178248882294, 59.43275906145573, 59.65498633682728, 61.72579161822796, 62.4079804122448, 61.8247839063406, 59.43866394460201, 59.010172337293625, 62.53756865859032, 68.99125635623932, 46.656450033187866, 58.30777622759342, 63.24508309364319, 66.1503691971302, 68.94660115242004, 62.681356742978096, 59.22134220600128, 61.635200679302216, 72.07922145724297, 68.36809739470482, 78.19396734237671, 20.53462252020836, 0.2464195530046709, 0.4501102800713852, 0.11444930947618559, 3.573036859743297, 62.72377386689186, 74.08603817224503, 74.01396363973618, 75.62401324510574, 50.715240240097046, 38.3594736456871, 28.819922134280205, 44.35408517718315, 63.03300887346268, 78.9832153916359, 15.123847760260105, 0.5622691882308573, 0.1780779639375396, 0.06298478940152563, 0.09564542473526672, 0.22148459334857762, 0.21271996287396178, 0.13542139349738136, 0.16908991732634604, 0.29402964748442173, 0.2194310410413891, 1.2035195133648813, 56.173449754714966, 77.5173832476139, 57.803729474544525, 53.62882889807224, 40.221518129110336, 54.41306121647358, 64.66997623443604, 85.113365650177, 67.86074101924896, 82.70993381738663, 6.848086584359407, 0.5041991011239588, 6.350819617509842, 19.147366359829903, 20.10110378265381, 5.917149838060141, 1.1233701766468585, 12.932303007692099, 66.28807380795479, 62.91616894304752, 73.66105377674103, 61.443554162979126, 68.62946256995201, 59.074803069233894, 68.18693831562996, 61.48333802819252, 64.59033250808716, 65.24475619196892, 65.17968848347664, 61.19983524084091, 61.79026275873184, 60.231707990169525, 58.13476011157036, 56.4892166107893, 58.59945237636566, 57.96202898025513, 60.01707650721073, 52.416051775217056, 53.586898148059845, 55.092563554644585, 57.62132406234741, 58.85923683643341, 56.1077930778265, 54.1614805161953, 56.34717643260956, 51.524729803204536, 53.26304152607918, 52.817979007959366, 59.52101692557335, 57.65535123646259, 62.77684561908245, 57.015214785933495, 56.383840665221214, 58.606246411800385, 48.512779623270035, 42.57407449185848, 45.8878842741251, 47.24777050316334, 45.45969285070896, 46.346884444355965, 46.37400358915329, 45.28397887945175, 50.886082872748375, 53.57943914830685, 50.7958909124136, 51.83305285871029, 52.226814329624176, 53.08300718665123, 52.03465484082699, 57.16050758957863, 55.51133528351784, 56.8342000991106, 53.936619982123375, 46.4047097414732, 49.50131177902222, 45.99691942334175, 48.91059547662735, 45.5594526976347, 41.543159410357475, 42.113656997680664, 51.094501689076424, 49.310512617230415, 36.99528984725475, 49.696112126111984, 40.59593103826046, 47.638632729649544, 44.67142894864082, 47.67104119062424, 44.56137925386429, 46.37078516185284, 52.95207001268864, 52.941890358924866, 53.01639296114445, 52.10359074175358, 55.42663402855396, 55.1108405739069, 53.85411120951176, 51.06134466826916, 53.68999421596527, 51.35905869305134, 50.127160996198654, 49.74333979189396, 47.64660470187664, 46.27893649041653, 46.78672984242439, 43.67671072483063, 44.77694928646088, 44.26648087799549, 46.162259951233864, 42.41900481283665, 44.76125992834568, 46.069202944636345, 53.30232001841068, 55.8500225096941, 58.75581778585911, 58.735568672418594, 56.7955257743597, 59.05007779598236, 52.932406067848206, 57.58836843073368, 58.51611904799938, 61.860452592372894, 58.69453467428684, 51.816595941782, 50.68814389407635, 51.08268052339554, 55.02575173974037, 60.35947613418102, 63.50491315126419, 63.12368720769882, 61.423863619565964, 64.27159041166306, 65.02645790576935, 63.533582612872124, 62.72176757454872, 61.859544441103935, 65.02200454473495, 63.87396454811096, 44.57437455654144, 61.86893753707409, 66.11888408660889, 68.7281584739685, 71.69720515608788, 67.79510334134102, 61.36749744415283, 68.27251732349396, 73.96205842494965, 72.8659388422966, 81.16495192050934, 23.798024207353592, 0.4519644321408123, 1.149915314745158, 0.4090493271360174, 5.428614802658558, 69.60460424423218, 83.69868636131287, 81.6774532198906, 85.44792249798775, 58.21082063019276, 54.68883141875267, 45.114390179514885, 60.79319626092911, 69.51239839196205, 98.01703244447708, 21.45691853016615, 0.869371856097132, 0.22364773118169978, 0.19388014334253967, 0.253080046386458], [0.08585020346799865, 0.10665640264051035, 0.06622575572691858, 0.12349108015769161, 0.03147542920487467, 0.19463407632429153, 1.023194370791316, 41.16583965718746, 53.71590882539749, 45.85669934749603, 26.617267727851868, 21.137342378497124, 41.8113262206316, 49.19676952064037, 76.88892737030983, 53.28980728983879, 70.5954922735691, 10.329136792570353, 0.11802692883065902, 0.8565407164860517, 5.704794432967901, 6.2008145917207, 4.31227270513773, 0.787538675358519, 3.8453281112015247, 57.68420308828354, 57.18225762248039, 65.9989321231842, 59.28028844296932, 64.10084277391434, 56.56452476978302, 59.94318947196007, 56.15980848670006, 62.40851618349552, 61.32504992187023, 57.18322657048702, 54.913049787282944, 54.592852368950844, 52.18503177165985, 54.40543122589588, 52.53642551600933, 56.22282810509205, 53.4989632666111, 57.990291863679886, 53.27688418328762, 52.977433651685715, 52.42449872195721, 52.11823135614395, 47.88016676902771, 52.47229255735874, 48.483657985925674, 51.72384291887283, 52.437300235033035, 54.62946720421314, 52.068385630846024, 51.063639745116234, 60.187254175543785, 55.65267249941826, 54.91140827536583, 53.9216373860836, 49.58051472902298, 42.639712169766426, 39.6017599850893, 40.63323363661766, 38.08281809091568, 41.46320030093193, 40.92556335031986, 42.002094984054565, 39.09641370177269, 42.72581174969673, 46.93599723279476, 47.14979276061058, 48.506665751338005, 47.26174235343933, 48.48589986562729, 51.58993050456047, 49.47855480015278, 50.4050362855196, 52.71434336900711, 54.13147732615471, 51.902509331703186, 49.71337839961052, 42.59753443300724, 42.79668174684048, 40.16849957406521, 38.1768174469471, 34.176996275782585, 47.47808754444122, 48.0664973706007, 39.310342222452164, 45.11806458234787, 41.44435331225395, 40.9554373472929, 40.997390896081924, 42.360674142837524, 40.012890323996544, 39.28840599954128, 46.28574952483177, 50.821881517767906, 50.113158747553825, 47.91415214538574, 51.280307918787, 49.7244244068861, 45.81842020153999, 46.031866148114204, 49.44114960730076, 46.4858315885067, 45.895058289170265, 45.259679183363914, 43.28628167510033, 42.301427721977234, 42.126245722174644, 42.36025996506214, 40.50838753581047, 38.0233208835125, 41.46169938147068, 41.75622917711735, 41.75013430416584, 48.87007065117359, 53.05977903306484, 55.22373631596565, 54.409576803445816, 54.41888250410557, 50.7452168315649, 53.12433756887913, 49.89240579307079, 52.5359695404768, 70.80894201993942, 57.22592867910862, 54.71164919435978, 52.337699979543686, 49.876218661665916, 45.32729275524616, 48.573431968688965, 48.254598677158356, 51.95607125759125, 52.67277739942074, 55.79927243292332, 54.72745254635811, 59.20050032436848, 54.915417060256004, 58.91151823103428, 58.64766038954258, 61.38600245118141, 46.23360112309456, 50.36785528063774, 60.160404816269875, 63.03111657500267, 64.01609972119331, 67.42896258831024, 61.7918586730957, 62.97996751964092, 59.67001833021641, 67.9972904920578, 66.41190156340599, 72.33558610081673, 14.773334618657827, 0.26572680682875216, 0.4512198205338791, 0.04850680925301276, 2.994704805314541, 62.99414075911045, 62.637305706739426, 65.92439532279968, 66.0376900434494, 44.96735326945782, 48.209305107593536, 30.988021194934845, 32.54262417554855, 47.46183201670647, 73.39653477072716, 13.584388867020607, 0.4483698250260204, 0.22191071970155463, 0.09667890990385786, 0.07228226706502028, 0.07536373843322508, 0.09246645742678083, 0.049585420711082406, 0.07374410502961837, 0.16227449319558218, 0.20671156496973708, 1.4014660916291177, 50.266765505075455, 63.54859180748463, 51.79728537797928, 38.57509307563305, 22.32364632189274, 47.18813270330429, 55.2218022197485, 81.4009116590023, 58.1554614007473, 79.97881516814232, 11.795489508658648, 0.27063148270826787, 0.25583786715287715, 8.540283981710672, 5.816630506888032, 4.532810021191835, 2.640392342582345, 4.086888274177909, 60.07931336760521, 59.216543063521385, 69.0341180562973, 61.57827213406563, 63.437884747982025, 59.88764405250549, 61.29479594528675, 59.17508348822594, 63.25372762978077, 61.357124000787735, 58.82820390164852, 57.461348846554756, 57.67939254641533, 56.132674142718315, 56.85583993792534, 56.540783643722534, 58.606007024645805, 57.239482551813126, 59.96213145554066, 55.55428437888622, 55.42969286441803, 54.139859676361084, 55.54396413266659, 50.91477133333683, 51.728980243206024, 50.606626868247986, 53.5353235155344, 54.095725044608116, 57.11125463247299, 55.21320328116417, 51.86323083937168, 62.451636269688606, 59.86515685915947, 58.62231194972992, 57.42256052792072, 51.203099861741066, 43.876750990748405, 42.51094087958336, 42.98161782324314, 39.3141458183527, 43.46758894622326, 44.36943255364895, 44.03835631906986, 42.51025691628456, 43.71615260839462, 45.93142993748188, 49.01476688683033, 51.53933621942997, 50.13943433761597, 51.82113289833069, 53.64860683679581, 52.379896715283394, 52.08150252699852, 53.94211068749428, 54.109058529138565, 53.090678974986076, 51.63555085659027, 44.641965329647064, 44.46368269622326, 41.68663591146469, 40.28223507106304, 36.19162157177925, 49.74160708487034, 48.11802640557289, 39.35511901974678, 43.520554304122925, 42.758091017603874, 42.55965046584606, 43.963994309306145, 42.08145372569561, 42.248648554086685, 42.17849291861057, 49.879030510783195, 51.611843928694725, 52.053441032767296, 51.19587644934654, 52.854080870747566, 51.97510823607445, 50.85604548454285, 51.71714007854462, 51.05658732354641, 48.31587038934231, 49.33311380445957, 48.526603281497955, 45.815110579133034, 44.11994934082031, 43.11004713177681, 43.39850105345249, 42.94459640979767, 39.338244125247, 43.95205914974213, 43.16432721912861, 44.75746013224125, 51.81629575788975, 56.56223729252815, 55.91906480491161, 56.793633475899696, 56.6243601590395, 52.51867666840553, 55.81235893070698, 52.16145023703575, 54.28757295012474, 67.46386751532555, 60.02848729491234, 57.248632460832596, 55.12534819543362, 51.88409931957722, 46.2791682779789, 51.04309044778347, 51.12812228500843, 54.71201777458191, 54.9361639469862, 57.91895069181919, 58.41021113097668, 61.53466187417507, 56.29640735685825, 61.0897209495306, 60.670937821269035, 66.64135605096817, 51.05467602610588, 52.91791744530201, 60.53495831787586, 63.94004300236702, 67.15362936258316, 68.25250759720802, 65.47982677817345, 66.37758180499077, 63.5992506891489, 69.8735462129116, 72.35712334513664, 77.91387677192688, 15.776439942419529, 0.25415482465177774, 0.3027531481347978, 0.16416006779763848, 3.999781748279929, 68.54811653494835, 69.0925133228302, 73.34102734923363, 73.19620952010155, 53.99740532040596, 47.98601768910885, 23.916560746729374, 40.19522354006767, 54.417541176080704, 85.80353021621704, 18.364178985357285, 0.7895655697211623, 0.3859343065414578, 0.10058481828309596, 0.03737333987373859, 0.1183881469478365, 0.25987966277170926, 0.19137852679705247, 0.2551008848240599, 0.36817860149312764, 0.40608863288071007, 1.849771379493177, 61.9684199988842, 72.62245550751686, 62.599075958132744, 39.48843106627464, 30.256820730865, 61.10443376004696, 61.12240679562092, 90.45952677726746, 61.874952614307404, 88.39692905545235, 12.422739900648594, 0.4335554293356836, 4.033067487180233, 19.106320962309837, 15.394293498247862, 9.189168512821198, 3.225991507060826, 5.372649980708957, 64.08129662275314, 61.661081090569496, 71.0305081307888, 62.33970187604427, 68.46785724163055, 62.20901928842068, 65.18589735031128, 61.70771598815918, 65.95895826816559, 63.37944768369198, 60.540346428751945, 58.03333595395088, 60.80233097076416, 59.795411601662636, 59.07617099583149, 56.105156019330025, 60.70522718131542, 58.626499325037, 62.819638922810555, 57.38308444619179, 57.837688252329826, 54.9263870716095, 58.789362385869026, 52.48368054628372, 54.81112025678158, 54.1035146266222, 57.89979971945286, 57.38293245434761, 58.41268479824066, 57.5919858366251, 55.46321466565132, 57.6215710490942, 62.5603636354208, 61.51125892996788, 61.23874895274639, 52.87341423332691, 47.56080150604248, 43.27915705740452, 45.33772699534893, 41.508129090070724, 46.01879484951496, 45.47871083021164, 45.541304871439934, 44.96891498565674, 45.56109040975571, 49.19138140976429, 50.7134885340929, 54.78110946714878, 51.62395007908344, 52.267468348145485, 58.365723118186, 55.55506333708763, 55.930103212594986, 57.948357313871384, 58.700933530926704, 54.27212677896023, 55.21327927708626, 45.48403054475784, 46.64037689566612, 42.11510092020035, 41.0699138045311, 37.234350219368935, 50.60068018734455, 51.49858720600605, 41.386224031448364, 45.095645785331726, 42.29869946837425, 42.893587946891785, 45.34171298146248, 44.63807813823223, 42.70447589457035, 42.26970322430134, 53.690605983138084, 52.8854101896286, 55.90980090200901, 54.22443173825741, 54.94008533656597, 54.77286770939827, 52.9630134254694, 52.67330937087536, 54.98439095914364, 52.490208595991135, 52.360749542713165, 49.743457585573196, 48.276337310671806, 46.46798014640808, 46.86261557042599, 46.713997945189476, 45.576095804572105, 39.67729993164539, 45.222995951771736, 44.88556265830994, 46.0224274545908, 53.8368259370327, 57.662023678421974, 60.5902149528265, 59.70838487148285, 58.3868233859539, 56.73056825995445, 57.3874694108963, 57.048717588186264, 55.400335639715195, 65.98682597279549, 61.15641497075558, 60.09317122399807, 57.71396689116955, 53.98705467581749, 50.143351927399635, 55.42244665324688, 55.25521382689476, 55.91878741979599, 58.79575364291668, 60.06786838173866, 60.31437635421753, 64.43242818117142, 58.96576412022114, 62.97924555838108, 63.215957656502724, 66.22636511921883, 53.29823523759842, 56.6975936293602, 61.50556303560734, 66.62981227040291, 70.06396159529686, 73.34349721670151, 69.53150376677513, 70.25852635502815, 67.72577226161957, 72.84051060676575, 76.56359642744064, 80.84198445081711, 19.557246565818787, 0.650248242309317, 1.8498878669925034, 0.2830455353250727, 6.015232549980283, 75.32394334673882, 77.00238168239594, 79.32993918657303, 81.23298346996307, 62.9011445492506, 64.57606807351112, 39.9530815333128, 50.841697454452515, 62.78682008385658, 100.79064801335335, 23.847334161400795, 1.141017023473978, 0.47681637515779585, 0.18894989305408671, 0.16675650113029405], [0.046980949919088744, 0.04882168766926043, 0.013266378609841922, 0.027042158108088188, 0.09117906127357855, 0.10924546644673683, 0.3572533861733973, 40.67452222108841, 58.08494858443737, 39.59097236394882, 37.1558578312397, 24.55332487821579, 27.70654007792473, 50.92491298913956, 72.2318060696125, 54.54771839082241, 67.63526871800423, 18.905173055827618, 0.3943867451744154, 0.192543787707109, 5.955629898235202, 1.376162061933428, 1.9140398246236145, 0.7369344751350582, 1.4429333852604032, 47.80061423778534, 61.1432258784771, 59.07117426395416, 59.585111886262894, 60.7483434677124, 60.691354125738144, 61.35202847421169, 59.995546862483025, 56.88616991043091, 55.94682231545448, 58.16629461944103, 52.22785547375679, 55.34882180392742, 54.43582199513912, 57.62644998729229, 55.7088752835989, 59.46971967816353, 52.662320360541344, 54.817815497517586, 50.35368964076042, 52.8397898375988, 50.93225039541721, 51.621620804071426, 51.73017717897892, 50.10040283203125, 50.88139392435551, 53.453836888074875, 51.0444013774395, 53.31798657774925, 53.61940160393715, 65.29915407299995, 48.13110150396824, 49.977156445384026, 55.190913677215576, 53.83407488465309, 45.07231883704662, 41.40424646437168, 37.0173666626215, 37.76895113289356, 44.28531266748905, 40.31191147863865, 40.52217319607735, 37.719534784555435, 37.85177908837795, 38.26263964176178, 44.53358754515648, 46.83643497526646, 46.56462796032429, 49.229314774274826, 48.433956652879715, 50.14033108949661, 49.24044817686081, 48.62127140164375, 47.59618520736694, 51.506069004535675, 50.16735523939133, 52.489300444722176, 48.1180340051651, 47.39749386906624, 39.93326559662819, 41.523221880197525, 36.239157021045685, 45.240668803453445, 44.7879458963871, 39.268692657351494, 47.33969137072563, 40.33591479063034, 41.63428992033005, 38.62783804535866, 43.47642347216606, 45.91533400118351, 47.05300435423851, 47.12591104209423, 49.15846757590771, 48.03645998239517, 51.610677391290665, 49.714214354753494, 49.22220915555954, 48.44615779817104, 49.56914573907852, 49.11905989050865, 45.37024185061455, 48.13128389418125, 44.8767015337944, 43.38294468820095, 39.82766926288605, 38.49143676459789, 37.75882087647915, 39.320829659700394, 41.105935871601105, 37.9809607565403, 41.22690238058567, 42.209974229335785, 49.50818181037903, 54.4548399746418, 54.25592444837093, 52.96642944216728, 51.872023567557335, 50.47235727310181, 54.712682738900185, 54.406069591641426, 51.14564694464207, 46.77876926958561, 44.55843821167946, 53.89005348086357, 52.179537266492844, 52.13686555624008, 50.21327577531338, 48.37404526770115, 50.41610509157181, 51.35455213487148, 50.76349385082722, 52.18074940145016, 51.61395661532879, 53.639240339398384, 55.76842948794365, 55.49096457660198, 57.11147882044315, 50.2427925914526, 51.2173642963171, 66.1363023519516, 54.811040461063385, 59.44298431277275, 61.3922493159771, 67.41599008440971, 61.72237180173397, 64.95170831680298, 62.17469573020935, 66.0785074532032, 65.17002940177917, 76.94505795836449, 10.385673008859158, 0.459855361841619, 0.4242276126751676, 0.133550661848858, 3.5781288240104914, 63.78665283322334, 63.084416314959526, 62.77357019484043, 66.10487803816795, 42.71355360746384, 47.791684716939926, 50.87651498615742, 33.39766189455986, 55.91807685792446, 73.5263966023922, 7.420566715300083, 0.5523044604342431, 0.11456316235125996, 0.12917625048430637, 0.15020026999991387, 0.023712147049081977, 0.06799220078391954, 0.04308832598326262, 0.03672106256999541, 0.018138890736736357, 0.09901309051201679, 0.488399044261314, 51.246953308582306, 65.5667433142662, 47.71983437240124, 39.54005129635334, 26.023963764309883, 38.10453772544861, 56.577451676130295, 78.77704605460167, 59.37111496925354, 76.53154134750366, 20.215760730206966, 0.46722435392439365, 0.6410539231728762, 5.414497135207057, 3.7471591914072633, 4.725701445713639, 2.5544658908620477, 1.9501247070729733, 51.05679631233215, 61.39498136937618, 61.56796708703041, 62.54009172320366, 61.978516057133675, 61.5694186091423, 63.68606463074684, 59.96087372303009, 59.757474437355995, 57.84158684313297, 60.03948390483856, 55.218602791428566, 58.370146080851555, 57.414740547537804, 60.146109983325005, 57.02237740159035, 59.97753202915192, 55.85129924118519, 56.94568991661072, 52.97912076115608, 55.95821030437946, 53.1620429456234, 54.19050335884094, 54.98855173587799, 51.530577689409256, 52.07382693886757, 54.65906761586666, 53.6465435475111, 57.21282318234444, 55.4728889465332, 61.92184589803219, 53.22594031691551, 51.69392332434654, 58.73568266630173, 53.002774491906166, 46.69372983276844, 43.126036673784256, 41.678937524557114, 38.52398581802845, 46.11836090683937, 40.94220645725727, 41.951774284243584, 40.214883685112, 40.45422904193401, 42.145822271704674, 46.39619059860706, 48.94549660384655, 50.66903851926327, 51.51221327483654, 51.32028937339783, 52.54730433225632, 51.643108651041985, 51.22349716722965, 50.949334278702736, 53.88957850635052, 51.92287243902683, 53.86939398944378, 49.42498527467251, 46.19271531701088, 41.72756731510162, 43.634434193372726, 37.686734944581985, 47.383487820625305, 47.76586510241032, 40.48872359097004, 46.848259940743446, 39.60602715611458, 42.85965956747532, 42.701607048511505, 44.14724327623844, 48.38296718895435, 49.23782251775265, 48.27713146805763, 50.57744823396206, 51.38077452778816, 53.9030259847641, 51.6563281416893, 52.4875183403492, 52.33266144990921, 51.32907450199127, 51.43967516720295, 49.20499227941036, 50.23583136498928, 48.499522134661674, 45.3935270011425, 42.04198144376278, 40.72622984647751, 41.707648783922195, 40.71792729198933, 44.70884934067726, 38.89847092330456, 42.815897315740585, 44.224398136138916, 50.642101764678955, 56.102917939424515, 56.77334636449814, 53.861243426799774, 55.18373966217041, 52.745250910520554, 56.50191932916641, 55.37140019237995, 54.947806522250175, 47.394583225250244, 45.47385849058628, 55.93409299850464, 55.06476804614067, 55.10416813194752, 53.81643623113632, 50.76626390218735, 51.501885429024696, 55.216664895415306, 53.59735518693924, 52.74251885712147, 55.757208690047264, 56.39932483434677, 57.84011252224445, 57.17637553811073, 61.9058221578598, 53.52835088968277, 53.873087391257286, 68.84281352162361, 58.27496878802776, 61.40826925635338, 63.68566185235977, 69.33691620826721, 64.6084651350975, 67.80404046177864, 65.49228250980377, 69.80103850364685, 66.98239535093307, 79.02974769473076, 11.921399552375078, 0.6130053719971329, 0.6228134769480675, 0.19311369775095955, 3.7966629350557923, 70.65685138106346, 70.85101336240768, 70.57513296604156, 71.0897621512413, 53.281896114349365, 47.23609372973442, 42.74798735976219, 40.63720442354679, 61.36921875178814, 85.3833943605423, 10.627523381263018, 0.9567347494885325, 0.1478219241835177, 0.050399074316374026, 0.15424873010488227, 0.1492649709689431, 0.18740451894700527, 0.14917212829459459, 0.1449625479290262, 0.1976543798809871, 0.22519951744470745, 1.1109245382249355, 63.263173922896385, 73.59553769230843, 52.05957770347595, 48.930141627788544, 36.398338079452515, 41.9342078268528, 64.44549947977066, 86.48615598678589, 66.888517588377, 83.880764991045, 24.215570501983166, 0.5725758383050561, 3.502762005664408, 14.122889321297407, 10.736845415085554, 9.744739551097155, 3.8758352492004633, 2.413759441114962, 54.26744922995567, 64.67376083135605, 68.88204261660576, 67.28638663887978, 64.76837575435638, 64.40551042556763, 65.86279302835464, 61.65389567613602, 63.2320611923933, 59.14582125842571, 62.49148853123188, 59.77329678833485, 59.94565933942795, 58.21222275495529, 60.540817603468895, 58.72216299176216, 63.19186694920063, 58.784130066633224, 61.386678814888, 56.27968445420265, 59.108161479234695, 56.47847078740597, 57.206158339977264, 57.64414183795452, 53.80397669970989, 57.683720514178276, 57.05579660832882, 56.308722496032715, 59.00861822068691, 54.9216715246439, 57.78515987098217, 56.12140014767647, 57.079476937651634, 60.22513434290886, 59.031489193439484, 48.291437700390816, 47.184397503733635, 43.4576752781868, 42.33168549835682, 49.683918580412865, 43.19537915289402, 43.74588221311569, 42.6317135989666, 40.376299023628235, 42.00494863092899, 50.921352580189705, 51.00400194525719, 52.19729371368885, 56.5131439268589, 52.014945298433304, 55.78696869313717, 53.335712626576424, 53.06738242506981, 51.6949150711298, 57.566067427396774, 54.59026850759983, 57.75667279958725, 52.05135874450207, 49.26339894533157, 42.82031647861004, 45.94481661915779, 39.25953894853592, 50.63298985362053, 49.774102941155434, 43.93421530723572, 49.09455880522728, 42.45247341692448, 44.510233998298645, 42.584170550107956, 45.55083855986595, 50.26477821171284, 50.26531018316746, 51.642698273062706, 54.37827788293362, 53.57111379504204, 56.104677245020866, 53.771986216306686, 54.52853322029114, 54.7559168189764, 55.078561305999756, 52.58254364132881, 52.30721801519394, 51.744407415390015, 50.977057591080666, 46.1987341940403, 43.6628794670105, 42.14648723602295, 43.68261180818081, 43.41019682586193, 46.78268685936928, 41.82446971535683, 45.746775045990944, 46.72770380973816, 53.95364686846733, 58.73772695660591, 59.205428659915924, 56.92765988409519, 57.123193591833115, 55.3846500813961, 57.88324400782585, 57.37604342401028, 57.68432468175888, 53.07237155735493, 45.80730199813843, 58.58861915767193, 56.152387484908104, 58.48632864654064, 56.45589999854565, 53.80558781325817, 55.7745623588562, 58.59333850443363, 58.474522680044174, 55.502268970012665, 59.00721609592438, 59.264545887708664, 62.844877168536186, 60.61249315738678, 64.40924942493439, 54.71971616148949, 58.04559409618378, 69.74528029561043, 60.59954345226288, 61.40283554792404, 65.303995013237, 73.2306356728077, 68.75984877347946, 72.66613036394119, 68.93270149827003, 73.2469367980957, 74.62712153792381, 83.58143985271454, 14.154604319483042, 1.1133560515008867, 1.4233922213315964, 0.43431743688415736, 5.447468915954232, 77.33301714062691, 80.08786171674728, 73.90038773417473, 80.5268369615078, 57.8692227602005, 70.75058475136757, 65.4956567287445, 49.19276833534241, 71.19398295879364, 100.72901532053947, 14.064529202878475, 1.269929618574679, 0.26386852841824293, 0.2993934752885252, 0.2878718404099345], [0.06368023372488096, 0.06374799922923557, 0.06574767161509953, 0.10757230193121359, 0.04946769753587432, 0.10607052900013514, 0.7397255441173911, 54.433371126651764, 51.167427375912666, 42.87621907889843, 38.59287612140179, 24.959714971482754, 32.54378691315651, 49.7564946860075, 69.76959899067879, 54.989832267165184, 66.14015534520149, 28.346743024885654, 0.285583917866461, 0.20637933514080942, 3.9824197674170136, 2.175408680923283, 3.167562042362988, 1.4170137885957956, 0.5216653982643038, 34.51214589178562, 61.15564361214638, 57.559980154037476, 59.92170922458172, 59.27605167031288, 60.04481501877308, 60.132449716329575, 57.514694184064865, 51.28552883863449, 49.35484103858471, 57.68300615251064, 53.12660984694958, 56.714517921209335, 54.890695586800575, 57.664949521422386, 58.77738542854786, 55.095170214772224, 51.68396405875683, 50.30712313950062, 50.63556991517544, 51.14476539194584, 52.08605848252773, 50.20159140229225, 49.07264918088913, 48.09161402285099, 51.81672893464565, 49.17195685207844, 53.42720031738281, 52.693980261683464, 66.03585854172707, 46.7987409979105, 40.9712179005146, 57.40893825888634, 50.51038943231106, 47.50036954879761, 39.87691842019558, 41.633670553565025, 37.015356570482254, 44.89768020808697, 41.7651093006134, 39.59701023995876, 37.41922929883003, 38.00147965550423, 39.69995051622391, 41.03711016476154, 41.987043991684914, 46.30388595163822, 46.654561534523964, 51.41894347965717, 49.33510109782219, 49.57767628133297, 48.34247276186943, 51.77104778587818, 48.03460568189621, 49.64408531785011, 49.93475452065468, 52.051244750618935, 49.32972438633442, 50.212853997945786, 43.60270969569683, 42.56224572658539, 38.596193343400955, 42.94903077185154, 43.440564796328545, 40.1789528131485, 46.123844012618065, 37.207922637462616, 41.55444860458374, 41.75132744014263, 42.891486659646034, 45.31691171228886, 48.99785399436951, 49.861407056450844, 52.198524847626686, 49.81740161776543, 51.01538613438606, 47.15471729636192, 51.04436717927456, 48.23254846036434, 50.172249376773834, 47.480979189276695, 45.912123173475266, 45.981461852788925, 43.60366344451904, 41.41254901885986, 40.161310359835625, 43.41403841972351, 40.24235621094704, 39.064183831214905, 37.47483551502228, 40.8173755556345, 39.76117663085461, 40.87053470313549, 46.08364976942539, 53.95337328314781, 53.941354528069496, 53.661081567406654, 48.81343849003315, 52.316698506474495, 51.749518141150475, 54.368276819586754, 53.43263402581215, 43.94106633961201, 49.47440542280674, 52.32687056064606, 56.6015537828207, 53.48962336778641, 50.758322328329086, 53.525474444031715, 56.92463904619217, 56.2453418970108, 48.9374790340662, 51.299295499920845, 49.671656638383865, 50.49548663198948, 52.89311237633228, 55.46347685158253, 50.8833584189415, 52.885379791259766, 57.73724444210529, 56.879987642169, 63.26017968356609, 62.459946423769, 59.530463218688965, 63.38139317929745, 66.43026977777481, 65.02952054142952, 68.24855580925941, 68.53642836213112, 72.51233741641045, 68.48035097122192, 5.5079032480716705, 0.10506038437597454, 0.13107782579027116, 0.4208423802629113, 4.885085318237543, 66.73516541719437, 62.89223402738571, 66.52867689728737, 66.18922591209412, 45.742659866809845, 100.32556816935539, 47.733338847756386, 31.5219172462821, 61.50256119668484, 76.859060972929, 8.211940750479698, 0.37146171438507736, 0.28527812333777547, 0.08325176633661613, 0.16741526109399274, 0.07123507442884147, 0.04440417978912592, 0.01660678808548255, 0.12380636675516143, 0.037371317521319725, 0.1094682740222197, 1.2080234591849148, 62.0204696059227, 59.21069897711277, 48.47117565572262, 44.94879126548767, 18.215244077146053, 33.42989556491375, 56.639673337340355, 76.04977279901505, 60.51985792815685, 75.14772400259972, 30.924247317016125, 0.1996654219692573, 0.3948043962009251, 6.442629341036081, 1.6011674632318318, 6.529808063060045, 2.457031044177711, 0.49719272239599377, 38.76414053142071, 61.77346006035805, 59.724442809820175, 60.38262829184532, 61.50588981807232, 61.20281808078289, 63.24055753648281, 57.30565220117569, 52.33781397342682, 51.39585591852665, 58.71180094778538, 56.39400132000446, 57.76178352534771, 57.37214483320713, 58.73828552663326, 59.872973039746284, 58.187410086393356, 54.47812132537365, 53.65000896155834, 53.21268282830715, 53.44336844980717, 52.88269713521004, 52.447616681456566, 53.41563753783703, 51.34955160319805, 54.84925881028175, 51.31598420441151, 53.97240646183491, 53.00804860889912, 59.68538850545883, 53.57559755444527, 43.44977170228958, 59.505441561341286, 53.34858253598213, 48.47657896578312, 43.951732367277145, 43.759717270731926, 37.909175008535385, 47.44645044207573, 44.12164784967899, 40.71116365492344, 39.01531085371971, 40.992211773991585, 42.138070687651634, 42.85840943455696, 43.399173617362976, 47.55745388567448, 49.070148915052414, 54.008394330739975, 50.72637364268303, 51.68270252645016, 50.19769661128521, 53.7116264551878, 49.6209217607975, 52.936813831329346, 50.446818843483925, 53.80091406404972, 52.398511916399, 50.07779784500599, 44.66892868280411, 43.58541302382946, 40.41649706661701, 44.818348065018654, 45.673313587903976, 41.73229806125164, 46.59249186515808, 39.60771806538105, 43.68679918348789, 44.793421402573586, 45.750977620482445, 46.425304636359215, 48.464415818452835, 50.949934646487236, 54.52610895037651, 50.765481144189835, 53.6912177503109, 50.456842705607414, 52.70024232566357, 52.69292391836643, 51.8622162938118, 49.851383194327354, 47.67472319304943, 48.06129164993763, 47.222213074564934, 43.921915367245674, 40.91726079583168, 43.27815771102905, 42.28290371596813, 40.28240226209164, 40.5174994468689, 42.325799614191055, 42.06148199737072, 42.81118556857109, 48.61758179962635, 57.461424842476845, 56.24075174331665, 54.96356427669525, 50.11374771595001, 56.60882659256458, 54.932003170251846, 55.62637411057949, 56.484330072999, 48.56099143624306, 50.643473491072655, 53.25966730713844, 58.28591600060463, 56.23734712600708, 53.439796641469, 56.409447491168976, 58.57951104640961, 58.83242167532444, 50.32604992389679, 54.48530673980713, 51.99498116970062, 52.83386595547199, 55.835799872875214, 57.776940912008286, 54.7391103208065, 56.51513881981373, 61.649742498993874, 58.93136836588383, 65.06524622440338, 64.33492541313171, 60.707947835326195, 65.42186468839645, 70.6328746676445, 67.5720477104187, 71.35890930891037, 70.9823115170002, 74.71694871783257, 73.43022376298904, 7.426076894626021, 0.3448163566645235, 0.24197337595978752, 0.5074231687467545, 5.0645487383008, 73.4200631082058, 69.19722810387611, 72.62186273932457, 72.47914999723434, 52.6746316999197, 101.21582999825478, 54.131773710250854, 36.93661719560623, 66.66477799415588, 88.13099652528763, 10.881509352475405, 0.7952085044234991, 0.4201368649955839, 0.19201618008082733, 0.17607990943361074, 0.12673741963226348, 0.1176816075167153, 0.10921900888206437, 0.3326723864302039, 0.16325105563737452, 0.36524495109915733, 2.1427252097055316, 76.10403388738632, 67.94533967971802, 58.074860125780106, 53.80255177617073, 40.53446173667908, 48.00970561802387, 63.41208033263683, 82.71824017167091, 67.46629178524017, 81.53963461518288, 35.16173243522644, 0.3560817427933216, 0.9512024838477373, 12.39118829369545, 10.206437576562166, 11.11994655802846, 4.976903116330504, 0.6172559782862663, 41.33752964437008, 64.21370431780815, 62.95755252242088, 63.396672159433365, 64.60541009902954, 62.54316955804825, 64.09956604242325, 61.53432749211788, 56.218484938144684, 54.72546525299549, 58.956492617726326, 56.16008207201958, 60.17437286674976, 58.550602197647095, 60.78020855784416, 60.8329801261425, 58.5396283864975, 56.364571899175644, 55.43453000485897, 55.372844114899635, 55.46835578978062, 54.90440525114536, 55.4764873534441, 54.811238050460815, 53.06177772581577, 56.698121801018715, 52.7868776768446, 56.89835965633392, 55.52521973848343, 57.78691157698631, 55.27680046856403, 49.517483711242676, 59.665694162249565, 58.936384096741676, 50.16140095889568, 46.24294102191925, 44.86369863152504, 41.616544872522354, 47.828892320394516, 46.87390476465225, 43.397714495658875, 41.22835390269756, 41.963523253798485, 44.07870635390282, 45.293003395199776, 45.927728936076164, 49.21606868505478, 51.75079867243767, 56.217971965670586, 54.37351293861866, 54.050971046090126, 52.214157208800316, 58.51011537015438, 51.016005501151085, 55.29496729373932, 55.17671003937721, 56.49295561015606, 56.75628907978535, 52.34610132873058, 46.60718947649002, 45.66957078874111, 43.16623471677303, 48.620724231004715, 52.563913241028786, 43.32234933972359, 47.61121340095997, 41.91965840756893, 46.51240736246109, 46.60544157028198, 46.848077550530434, 48.41804310679436, 52.68965609371662, 52.86180205643177, 56.31775461137295, 54.633620381355286, 56.40101194381714, 50.75316220521927, 56.18226148188114, 55.46104118227959, 55.55548511445522, 54.1048863530159, 50.907384529709816, 51.27206236124039, 48.68793502449989, 47.87420868873596, 45.472456365823746, 46.45371951162815, 45.27789160609245, 43.44856336712837, 42.2398292273283, 46.77460849285126, 44.505225867033005, 45.34141659736633, 50.54291568696499, 58.91578160226345, 58.14536154270172, 57.60828696191311, 53.43588285148144, 56.50709085166454, 58.96432399749756, 60.05045011639595, 60.37057153880596, 47.6051527261734, 50.43025553226471, 55.23402236402035, 60.53821474313736, 58.72929900884628, 55.05324326455593, 60.210809111595154, 62.95794390141964, 61.13346040248871, 54.78310815989971, 58.17129895091057, 54.852150455117226, 56.32060445845127, 59.4134446978569, 58.77645067870617, 57.20864340662956, 60.073761865496635, 65.22384971380234, 60.811553075909615, 69.26755473017693, 65.74120715260506, 63.326774910092354, 67.12575405836105, 74.16584149003029, 70.83477303385735, 77.28588446974754, 73.51717829704285, 78.21853682398796, 66.97893753647804, 8.840066995471716, 0.6280016829259694, 0.6379332218784839, 0.9000469569582492, 6.853955369442701, 80.87898686528206, 74.63200807571411, 79.00077044963837, 81.5767814218998, 62.927283346652985, 112.1444995701313, 56.05622224509716, 49.83971022069454, 76.27773016691208, 101.76882952451706, 16.827341951429844, 1.199857578612864, 0.5769915576092899, 0.28121355862822384, 0.32905533676967025], [0.06143506630905904, 0.12312046645092778, 0.021224410520517267, 0.10375497629866004, 0.06626276663155295, 0.17505676980363205, 1.188640936743468, 55.06209298968315, 51.54662802815437, 46.482620760798454, 19.10191509872675, 52.15494118630886, 61.93486399948597, 44.46746349334717, 66.95790186524391, 57.766153290867805, 63.60203213989735, 44.90091383457184, 0.07294479713891633, 0.30463523464277387, 3.4999715304002166, 1.692598988302052, 3.2905232068151236, 0.8776689483784139, 0.3517730114981532, 25.192036405205727, 57.857059612870216, 53.877244368195534, 57.38061457872391, 55.86003117263317, 57.5413041561842, 53.654154539108276, 52.096823304891586, 54.31719996035099, 52.53163397312164, 53.57482239603996, 58.051825761795044, 56.523239985108376, 56.1276888102293, 55.114309787750244, 55.65074600279331, 53.90776053071022, 52.48444050550461, 50.79294227063656, 52.13127225637436, 50.582023188471794, 54.76677283644676, 52.54629358649254, 49.83362294733524, 49.33872610330582, 50.88260605931282, 52.52613566815853, 49.477813839912415, 31.16644822061062, 24.035311974585056, 38.121598809957504, 56.13956697285175, 54.874934032559395, 50.96167981624603, 42.98035629093647, 42.90374480187893, 37.85897210240364, 39.2154461145401, 38.603276163339615, 35.22159822285175, 38.15042786300182, 38.05977612733841, 37.5107815861702, 39.61141526699066, 37.81210541725159, 39.167659878730774, 45.35655118525028, 47.101140171289444, 50.09643204510212, 47.9305786639452, 49.839128851890564, 51.282394006848335, 52.2600207477808, 49.11992244422436, 49.413585886359215, 49.289872124791145, 49.73977938294411, 48.312841951847076, 51.31378412246704, 47.33046926558018, 43.93274858593941, 40.557028725743294, 42.71628566086292, 37.647562846541405, 39.61151026189327, 46.81036077439785, 35.10875567793846, 38.417272344231606, 41.05775065720081, 45.647311583161354, 48.548417910933495, 47.77594216167927, 49.95482124388218, 51.62516601383686, 51.05620354413986, 48.03921863436699, 48.58022220432758, 46.94176532328129, 47.57234908640385, 48.35975423455238, 47.13404640555382, 49.6939804404974, 45.35555563867092, 41.376466155052185, 38.60559783875942, 38.86779896914959, 38.18290092051029, 39.83710415661335, 38.10603864490986, 42.437525019049644, 41.429306119680405, 39.925472214818, 39.50750604271889, 43.2610472291708, 53.626944199204445, 55.56529998779297, 57.711436226964, 52.803486585617065, 49.69525717198849, 54.1385867446661, 54.8384065926075, 50.98580852150917, 43.67474623024464, 51.42054319381714, 52.06358268857002, 52.01697438955307, 55.674646720290184, 55.656373500823975, 55.84855958819389, 60.052589401602745, 59.828948602080345, 53.84049654006958, 54.64625470340252, 54.1301815956831, 54.22757036983967, 51.29008859395981, 53.35672929883003, 53.400791734457016, 54.03779715299606, 52.038758620619774, 57.70172394812107, 56.83654837310314, 62.33586028218269, 64.22675281763077, 62.98651076853275, 64.8937538266182, 66.21694162487984, 69.22942757606506, 69.208103120327, 69.9919630587101, 36.72712303698063, 2.995359320193529, 0.17581537831574678, 0.22197919024620205, 0.10828923142980784, 6.416076365858316, 72.23337158560753, 58.9737930893898, 69.55520689487457, 65.77465295791626, 53.38775463402271, 38.2515936344862, 36.79811842739582, 40.761959329247475, 56.4771294593811, 70.36502704024315, 5.550921689718962, 0.321034828084521, 0.33651427715085447, 0.05928954706178047, 0.1040402652870398, 0.03558911666914355, 0.05427864016382955, 0.09100070834392682, 0.08648960822029039, 0.038458953495137393, 0.08969503309344873, 1.8385359761305153, 65.51998302340508, 57.9797588288784, 53.735093995928764, 24.532783180475235, 39.61961142718792, 59.240090399980545, 49.12892036139965, 74.69650581479073, 61.85770533978939, 69.85651552677155, 49.80660259723663, 0.2361401545931585, 0.324551984667778, 3.5098108649253845, 4.382801195606589, 4.630734091624618, 3.197574494406581, 0.4075660411035642, 29.366745091974735, 59.684738740324974, 54.85824912786484, 60.1590520888567, 58.19195084273815, 59.35874663293362, 56.43477313220501, 56.074594259262085, 57.05720253288746, 55.181813165545464, 56.708867624402046, 60.09547770023346, 57.67297089099884, 57.58823923766613, 54.90171119570732, 58.0194590985775, 55.59446342289448, 53.952054753899574, 52.89987601339817, 53.38602192699909, 55.489437058568, 58.24823722243309, 52.58042335510254, 52.505198791623116, 52.837863340973854, 56.12512394785881, 53.65714877843857, 51.051601991057396, 32.05306604504585, 28.49172804504633, 41.34498104453087, 56.708350852131844, 58.72997537255287, 52.91459262371063, 45.33823996782303, 44.986036866903305, 39.55075152218342, 42.8911142796278, 40.04427284002304, 37.9719590395689, 40.48859819769859, 41.22642360627651, 39.47371065616608, 42.09850341081619, 40.58040887117386, 42.24596969783306, 47.85457134246826, 48.7825233489275, 51.868216171860695, 50.274148508906364, 53.237047120928764, 54.24485184252262, 54.139783680438995, 50.00506594777107, 53.7254349142313, 49.85127680003643, 52.93305583298206, 50.822386890649796, 54.13724921643734, 50.03147833049297, 46.837282329797745, 41.99776701629162, 44.74855341017246, 42.30710841715336, 42.91197136044502, 46.983840465545654, 37.64882057905197, 39.32513862848282, 45.18006965517998, 47.385254725813866, 49.61939424276352, 48.68503957986832, 53.95611293613911, 52.98242658376694, 54.02338072657585, 51.79896108806133, 52.231632471084595, 51.242408752441406, 50.04625953733921, 51.28845848143101, 47.39296071231365, 51.06034152209759, 47.261506766080856, 44.5465524494648, 42.4580667167902, 40.9075865149498, 41.33685328066349, 40.740923658013344, 40.107809230685234, 43.00008483231068, 43.96561682224274, 40.86284011602402, 40.9113597124815, 46.450782269239426, 56.204421892762184, 55.94260074198246, 60.63030660152435, 56.18286944925785, 50.68929523229599, 54.58937555551529, 55.62740005552769, 53.55383612215519, 47.749518379569054, 53.595918864011765, 53.50132293999195, 54.6807948499918, 58.50409649312496, 56.9888062030077, 58.624572828412056, 62.40144856274128, 62.0836716145277, 56.593144834041595, 56.78713962435722, 54.50394853949547, 57.839291766285896, 54.3562276661396, 57.08446606993675, 55.01450054347515, 58.69772270321846, 56.764211654663086, 60.9128138422966, 60.78147388994694, 65.27880236506462, 66.89634516835213, 62.69488401710987, 66.9203294813633, 69.87809836864471, 71.76115572452545, 72.48339056968689, 71.9947899878025, 42.76330813765526, 3.153812480159104, 0.2511197671992704, 0.4004079080186784, 0.36072895280085504, 8.422114122658968, 77.68473386764526, 65.63695594668388, 73.64853724837303, 73.51116701960564, 55.58927670121193, 63.66629809141159, 44.47617642581463, 45.41621558368206, 64.19870272278786, 84.13469016551971, 10.543027315288782, 0.6990175566170365, 0.2982007252285257, 0.15351952548371628, 0.07956300294608809, 0.2991057001054287, 0.2600920951226726, 0.4220215935492888, 0.23727856460027397, 0.18031527200946584, 0.2468041339307092, 2.6683115819469094, 78.1805768609047, 69.1944770514965, 63.01918521523476, 33.6091585457325, 61.83736503124237, 74.49117243289948, 59.85989794135094, 79.52364519238472, 68.81045445799828, 77.52007350325584, 55.96072196960449, 0.35603629366960377, 1.0684082633815706, 11.43529923632741, 7.800977127626538, 10.293364562094212, 6.306261783465743, 0.46693248208612204, 31.370892450213432, 61.822739616036415, 57.32706405222416, 63.25681306421757, 61.587239652872086, 65.37144899368286, 61.8639750033617, 59.37026001513004, 58.13990883529186, 55.525576919317245, 55.392515659332275, 62.47945837676525, 59.52082693576813, 57.748085260391235, 57.75184325873852, 61.99186094105244, 58.64753499627113, 58.527716025710106, 55.023783445358276, 56.889965906739235, 60.01117542386055, 60.35557374358177, 54.114906415343285, 53.69419679045677, 53.514379039406776, 57.46405050158501, 55.25280475616455, 51.81082405149937, 33.42710271477699, 37.171117812395096, 46.95656552910805, 57.008200362324715, 62.61999003589153, 56.029779464006424, 49.67099167406559, 48.36934491991997, 41.40239596366882, 43.87540206313133, 42.46910132467747, 39.22821342945099, 41.84285692870617, 43.4786881506443, 41.897349804639816, 44.68483842909336, 41.098457872867584, 44.66359756886959, 51.14733025431633, 52.119185104966164, 56.00813202559948, 53.895468190312386, 55.95463469624519, 56.89588598906994, 58.07953767478466, 51.461151614785194, 56.35332830250263, 55.22604279220104, 54.17653150856495, 52.93481133878231, 56.27415955066681, 51.39042980968952, 48.594897016882896, 45.66466145217419, 48.98495748639107, 45.953335762023926, 45.05766682326794, 47.68770329654217, 39.91687327623367, 42.03769147396088, 46.81082434952259, 48.178055584430695, 51.870059072971344, 50.61299532651901, 54.51067037880421, 54.92483675479889, 54.587357863783836, 52.23364636301994, 53.021511286497116, 51.54031276702881, 52.77869671583176, 54.82915788888931, 50.785760655999184, 54.01328086853027, 51.048995330929756, 45.65490357577801, 44.429172948002815, 44.600144773721695, 41.39479257166386, 44.57908630371094, 44.48855236172676, 47.05068647861481, 45.97974054515362, 43.974420949816704, 43.04738089442253, 49.03048664331436, 57.058870643377304, 59.98758628964424, 65.10209664702415, 56.884915977716446, 51.536938548088074, 56.40891931951046, 60.04505820572376, 54.411712288856506, 49.89130765199661, 51.42318785190582, 55.497997999191284, 57.27664835751057, 61.81349091231823, 59.757413640618324, 61.50572642683983, 65.3361488878727, 65.44675335288048, 59.52632524073124, 61.54161550104618, 58.02550457417965, 61.14839360117912, 56.52534507215023, 58.56828264892101, 59.22866441309452, 61.79561287164688, 58.696613162755966, 65.06023809313774, 62.97364845871925, 69.51395630836487, 69.94787782430649, 65.30927672982216, 67.69635424017906, 72.66015708446503, 74.58962514996529, 81.49177998304367, 71.8433529138565, 42.93547309935093, 5.200572889298201, 0.5662505433429033, 2.0620602881535888, 0.7743004825897515, 9.35725249350071, 86.16245895624161, 73.273436576128, 82.12847381830215, 80.53869992494583, 66.17667138576508, 55.51474750041962, 46.393876522779465, 56.155852898955345, 71.77149876952171, 95.71000903844833, 16.492724306881428, 1.1883008549921215, 0.5483178212307394, 0.25622523855417967, 0.25595491868443787], [0.06250192585866898, 0.015222718848235672, 0.07642452721484005, 0.028652063811023254, 0.0037683793698306545, 0.1935736066661775, 1.8217029981315136, 48.79211023449898, 57.92579412460327, 41.18344411253929, 47.105300948023796, 78.50799769163132, 79.31182935833931, 46.959897950291634, 58.66023011505604, 62.40212872624397, 60.84904566407204, 55.346199944615364, 1.1187359690666199, 0.6710641190875322, 4.045970169827342, 1.6667392384260893, 4.941392121836543, 1.2741203187033534, 0.29579233727417886, 15.112909097224474, 55.49847677350044, 48.627309277653694, 54.03503090143204, 50.330693274736404, 54.60869751870632, 55.88712751865387, 54.79900650680065, 55.179001316428185, 56.83226220309734, 54.26919333636761, 54.7372218221426, 53.04595537483692, 51.802692487835884, 54.15832668542862, 56.683219000697136, 53.61564360558987, 54.101751521229744, 53.26482743024826, 54.3532258272171, 50.93491405248642, 51.229219660162926, 55.44807627797127, 54.193224012851715, 49.53180894255638, 49.99605283141136, 49.1607740521431, 43.17318454384804, 34.13916930556297, 43.31654705107212, 59.42684277892113, 52.11644545197487, 56.07381530106068, 45.017267391085625, 43.0057655274868, 40.67067302763462, 39.53690506517887, 39.84476454555988, 37.42453761398792, 36.47418960928917, 38.36227409541607, 37.86157116293907, 38.19415591657162, 35.110799968242645, 39.42088209092617, 39.66372326016426, 42.299455627799034, 47.2509091347456, 46.88245050609112, 48.181467801332474, 49.51924301683903, 48.03457908332348, 47.180194929242134, 48.96447278559208, 50.61663933098316, 47.01156757771969, 49.60932098329067, 49.58016894757748, 51.918844655156136, 48.429643884301186, 44.97534044086933, 41.45770959556103, 40.06516791880131, 40.64334489405155, 42.25967936217785, 44.30297411978245, 34.70662705600262, 41.116062328219414, 40.66541031002998, 46.963853538036346, 44.29309464991093, 50.416325479745865, 52.42335878312588, 50.36192759871483, 49.01703156530857, 48.310679867863655, 50.23844562470913, 48.22609260678291, 47.77213096618652, 48.424677550792694, 47.29657128453255, 46.979732885956764, 46.60652071237564, 42.042209431529045, 37.05180041491985, 38.55586990714073, 37.49935559928417, 36.985129192471504, 36.6628684848547, 38.67022857069969, 44.50798451900482, 39.77181985974312, 38.00174944102764, 39.996608197689056, 45.0840450078249, 53.20034109055996, 54.5561957359314, 56.2024649977684, 50.47554150223732, 52.47511200606823, 50.65518066287041, 55.88962018489838, 43.15184488892555, 52.450059950351715, 54.74295571446419, 52.46115915477276, 51.89459815621376, 53.998670652508736, 56.35695330798626, 59.83816310763359, 53.20674754679203, 55.54377794265747, 56.4269645512104, 55.224826857447624, 57.677314057946205, 57.033590599894524, 57.099448665976524, 56.08234964311123, 56.97202630341053, 53.43845911324024, 54.51257407665253, 56.41377545893192, 56.24107852578163, 63.408736512064934, 65.28793707489967, 59.801586270332336, 66.50345385074615, 64.88986283540726, 60.686604380607605, 56.0287307202816, 32.12186515331268, 0.8274440746754408, 0.21788471698528156, 0.7412325195036829, 0.2523048286093399, 14.733065329492092, 73.36411491036415, 61.253845542669296, 73.13405245542526, 63.43332879245281, 56.25919595360756, 28.116283491253853, 29.465043917298317, 41.072201281785965, 53.19403722882271, 60.2043304592371, 4.912013523280621, 0.30132872925605625, 0.10850921142264269, 0.08266327291494235, 0.07914833535323851, 0.008084550463536289, 0.06636418853304349, 0.052275531634222716, 0.13639059383422136, 0.04364571228506975, 0.18622472678544, 2.393788187764585, 60.03371961414814, 63.685468062758446, 51.37752950191498, 44.76914070546627, 76.69486418366432, 83.02574247121811, 52.29549564421177, 66.576037555933, 70.1764203608036, 64.87622916698456, 61.95794016122818, 1.3180368184112012, 0.3750334039796144, 2.233802522532642, 3.732385584153235, 4.200302213430405, 2.001826395280659, 0.4693461541319266, 18.001011572778225, 57.624234706163406, 51.811774000525475, 57.48648829758167, 54.763372018933296, 57.95947551727295, 58.07452194392681, 56.390991881489754, 55.79567402601242, 59.35603357851505, 57.53358297049999, 56.45593799650669, 52.47298792004585, 54.48027960956097, 54.80266951024532, 57.54392981529236, 55.37782944738865, 56.67378030717373, 55.62922015786171, 56.78504213690758, 52.58832313120365, 56.705265417695045, 58.82950723171234, 53.44409801065922, 49.10395570099354, 50.1905681937933, 50.32089360058308, 42.371256574988365, 40.23673631250858, 48.59774686396122, 60.174570456147194, 56.39066889882088, 56.604437828063965, 50.84602162241936, 42.985204830765724, 43.20022389292717, 40.485375970602036, 42.566600292921066, 38.47672015428543, 40.712660774588585, 41.45850755274296, 41.10017538070679, 40.70565015077591, 39.57219757139683, 40.66433496773243, 42.46280886232853, 43.11549223959446, 49.30244944989681, 51.28402031958103, 51.76920868456364, 51.41179986298084, 52.36482672393322, 50.69922789931297, 51.851246282458305, 51.19911387562752, 50.273042768239975, 49.95108604431152, 50.97071573138237, 54.16375659406185, 50.594801902770996, 48.12616936862469, 43.59792195260525, 42.7663479745388, 44.11167338490486, 44.777420461177826, 46.28163814544678, 38.50730471313, 43.61363410949707, 42.77483291924, 47.47005857527256, 49.349616318941116, 52.51751013100147, 53.57715927064419, 51.94645017385483, 50.51075421273708, 49.28132638335228, 52.808270528912544, 51.98389336466789, 50.28704881668091, 51.27229414880276, 50.165896117687225, 49.43109914660454, 48.350433334708214, 43.243849352002144, 39.243370816111565, 40.271200463175774, 39.50882077217102, 37.41206668317318, 39.84181970357895, 41.591789200901985, 44.86080318689346, 42.12431542575359, 41.67115934193134, 42.75537796318531, 47.37388953566551, 54.35969687998295, 55.20809255540371, 58.72726991772652, 52.50076062977314, 54.05551940202713, 52.1566890925169, 58.39687764644623, 48.025178387761116, 55.016947612166405, 56.696020513772964, 51.84976056218147, 52.61887349188328, 55.0454992800951, 58.46977673470974, 61.644890159368515, 57.547630816698074, 56.794002056121826, 57.994133457541466, 57.837490662932396, 62.1545872092247, 60.899860337376595, 59.31749604642391, 57.36895300447941, 60.96402369439602, 58.26776057481766, 57.74705931544304, 58.755574598908424, 60.376491621136665, 65.09440585970879, 67.99882560968399, 61.906665712594986, 66.44967913627625, 64.43382650613785, 62.92409911751747, 62.07910805940628, 32.53191255033016, 1.2175292428582907, 0.48373357742093503, 0.4982732003554702, 0.102930880675558, 16.938280798494816, 81.16591706871986, 69.15908575057983, 79.04132187366486, 70.86284592747688, 61.31040930747986, 35.382907167077065, 29.939231872558594, 45.677155181765556, 61.47951543331146, 73.76791164278984, 6.82448985055089, 0.6751993659418076, 0.16170015995157883, 0.03546675136021804, 0.12734338321024552, 0.19550847471691668, 0.15210260229650885, 0.20718517393106595, 0.2381385801709257, 0.1739670743700117, 0.311627215705812, 3.835587571375072, 75.09592518210411, 74.14862841367722, 56.492514833807945, 60.84407553076744, 85.69792628288269, 84.31519567966461, 62.86494389176369, 72.71059557795525, 77.66917750239372, 71.70501753687859, 68.94122064113617, 1.7444550432264805, 1.648851817008108, 13.636420425027609, 4.776085317134857, 14.223262835294008, 5.368566624820232, 0.729690104490146, 22.39499319344759, 59.69095900654793, 53.30928884446621, 59.76512722671032, 57.06205107271671, 61.37906402349472, 60.47854274511337, 60.7243287563324, 58.457415997982025, 60.35660728812218, 59.14746277034283, 55.89642181992531, 56.92555099725723, 56.31249949336052, 56.238380670547485, 60.72505071759224, 57.026036605238914, 59.13506783545017, 57.02361613512039, 59.68241706490517, 54.6310593187809, 61.19732357561588, 59.29625518620014, 53.72345522046089, 50.44032499194145, 51.993320658802986, 51.67411118745804, 43.70114341378212, 41.08493059873581, 44.936540722846985, 63.359437957406044, 58.31749610602856, 60.28739780187607, 52.85448744893074, 47.92367823421955, 44.06661160290241, 42.531482577323914, 45.11820137500763, 41.31686635315418, 40.802605748176575, 43.43160107731819, 43.52210462093353, 42.694919407367706, 38.62663730978966, 43.123308420181274, 44.813229739665985, 44.60952267050743, 52.676504999399185, 52.79304474592209, 55.047277584671974, 56.06795221567154, 54.18529003858566, 51.94489225745201, 54.80458840727806, 55.01489572227001, 52.504074051976204, 55.92096850275993, 53.49760293960571, 58.57766434550285, 53.1493554264307, 47.84387491643429, 45.56314989924431, 46.53774820268154, 47.40454249083996, 50.05880646407604, 46.63503058254719, 42.594692185521126, 45.51199324429035, 44.59468446671963, 47.77368128299713, 49.08151790499687, 53.500152602791786, 56.96062311530113, 55.9970024228096, 54.04586412012577, 52.724602818489075, 56.6563468426466, 53.31076316535473, 53.35705608129501, 52.21746303141117, 52.29187823832035, 52.296331599354744, 51.297631189227104, 43.82673807442188, 40.831666588783264, 42.62052699923515, 42.76709273457527, 39.79200817644596, 41.39403261244297, 41.72814108431339, 48.29818993806839, 43.72946709394455, 42.90907211601734, 44.156206995248795, 49.67247359454632, 57.90016829967499, 59.745983853936195, 59.64840888977051, 53.90590623021126, 56.44261971116066, 55.696788132190704, 59.05790917575359, 50.94031736254692, 54.78737913072109, 55.00796489417553, 55.845139771699905, 54.17162977159023, 57.54553332924843, 61.74571394920349, 63.54348488152027, 58.154180869460106, 59.11429814994335, 61.61554053425789, 61.059067994356155, 65.51603123545647, 63.723181039094925, 60.17945319414139, 60.26712588965893, 65.4865600168705, 58.869351893663406, 61.9023871421814, 62.258872613310814, 63.41867297887802, 69.23118308186531, 71.4593455195427, 62.12504379451275, 67.81754493713379, 67.73715645074844, 64.47555586695671, 59.222751930356026, 37.28940926492214, 2.3432012647390366, 0.4182497615693137, 1.754016992636025, 0.5218041501939297, 20.02410851418972, 89.28670451045036, 73.85831639170647, 87.15438053011894, 76.9463574886322, 71.25059232115746, 46.40683002769947, 38.68439421057701, 58.154420256614685, 67.61594295501709, 88.12533482909203, 12.55588760599494, 0.9724448877386749, 0.3303715802030638, 0.23006482981145382, 0.26312721194699407], [0.036791047095903195, 0.04494020337006077, 0.014588618596462766, 0.09424934105481952, 0.13076066155917943, 0.13928885862696916, 1.7220438458025455, 55.24705566465855, 51.229288056492805, 37.16642126441002, 31.79183006286621, 74.22704100608826, 87.72707059979439, 48.026831299066544, 55.8575689047575, 65.68385303020477, 54.531565457582474, 69.73729312419891, 6.212192606180906, 0.2681291685439646, 0.7721380423754454, 3.28185492195189, 1.584335791412741, 2.3448358895257115, 0.02924630887719104, 7.820058753713965, 55.55251747369766, 48.762240037322044, 52.98733592033386, 51.76953166723251, 55.68965591490269, 54.53164905309677, 58.539119213819504, 57.88403056561947, 55.61481513082981, 43.81756916642189, 52.01495289802551, 55.13205863535404, 57.65690915286541, 56.320015490055084, 57.35139034688473, 53.57130378484726, 55.476544350385666, 56.69469438493252, 56.180498376488686, 56.66393123567104, 49.402669072151184, 47.580613642930984, 53.61092425882816, 51.64185091853142, 51.59193679690361, 45.45167148113251, 45.79351253807545, 65.03346472978592, 62.2086963057518, 51.038188710808754, 54.8838559538126, 51.00531667470932, 44.729527831077576, 45.406461507081985, 39.79634754359722, 37.378594279289246, 36.9291277974844, 35.54764352738857, 40.065722689032555, 36.61681115627289, 37.746391743421555, 37.94028393924236, 38.559954687952995, 38.20763759315014, 39.94994290173054, 40.98226010799408, 44.82203766703606, 46.02364718914032, 48.9003474265337, 48.04010018706322, 49.83480088412762, 49.68327261507511, 47.36850522458553, 49.436430260539055, 47.29042701423168, 47.14550659060478, 49.79003168642521, 53.47807578742504, 48.42627726495266, 50.29652550816536, 44.42965552210808, 41.41121909022331, 36.69063359498978, 41.70243926346302, 42.20260642468929, 35.13300217688084, 41.04008540511131, 42.88916118443012, 46.630269438028336, 50.43904446065426, 51.16448253393173, 46.89973197877407, 48.69526483118534, 47.64961414039135, 47.426372319459915, 47.67956033349037, 48.21771025657654, 47.179594561457634, 48.50498244166374, 46.81412637233734, 47.6644903421402, 42.47165098786354, 39.1573928296566, 41.46535478532314, 38.325286880135536, 37.62571021914482, 37.357079833745956, 38.27180095016956, 36.82841420173645, 37.695155292749405, 41.80231310427189, 36.668773368000984, 39.86240319907665, 42.47358128428459, 44.55370746552944, 51.67585909366608, 52.238852083683014, 57.466159388422966, 55.48692539334297, 51.588440984487534, 50.99728770554066, 44.767009019851685, 41.724611073732376, 59.415374994277954, 54.341959431767464, 52.53504239022732, 51.68960675597191, 51.6739895939827, 51.057047098875046, 45.11173032224178, 54.09957803785801, 57.77476742863655, 59.793842285871506, 58.214540630578995, 56.130728647112846, 57.17794485390186, 60.01836083829403, 59.8518043756485, 54.171922355890274, 54.95460815727711, 54.413323402404785, 57.64665350317955, 59.02236968278885, 57.808711007237434, 63.73612694442272, 60.67102901637554, 67.9613596200943, 63.32254573702812, 53.942194283008575, 21.580655090510845, 0.06597842017072253, 0.04251545477018226, 0.25788316677790135, 0.04099676458281465, 25.069441683590412, 72.35042810440063, 65.54514527320862, 73.46087291836739, 69.81467977166176, 55.72943218052387, 48.300819396972656, 41.3935424387455, 41.795382276177406, 54.59551602602005, 69.24512073397636, 5.454546036198735, 0.30653026420623064, 0.19954463001340628, 0.057642246392788365, 0.1569321728311479, 0.08404342268477194, 0.05833238064951729, 0.01941783011716325, 0.04729624393803533, 0.10832065396243706, 0.1508237185771577, 2.5979543197900057, 66.54364049434662, 58.709414675831795, 40.79918593168259, 38.990600779652596, 86.46350160241127, 89.74340960383415, 57.56723776459694, 62.55767337977886, 74.32566091418266, 60.07925637066364, 76.59630507230759, 6.308060036972165, 0.346307450090535, 1.7285520653240383, 2.921313880942762, 4.280097931623459, 5.173158785328269, 0.3270682512084022, 11.033943872898817, 59.10699874162674, 51.26885153353214, 55.20219147205353, 52.61139929294586, 59.00622434914112, 55.53560458123684, 60.1688327640295, 59.9731470644474, 57.14381888508797, 48.433261290192604, 54.37938742339611, 55.46196833252907, 59.53762963414192, 57.57493235170841, 57.840378507971764, 55.11100776493549, 56.62656784057617, 57.83318929374218, 57.85214267671108, 57.23153717815876, 51.53684355318546, 51.22626721858978, 59.03976134955883, 54.79815915226936, 51.57762296497822, 46.416891887784004, 48.339672312140465, 64.96781185269356, 62.910271659493446, 53.06296706199646, 55.94318591058254, 52.92851507663727, 46.231522634625435, 47.00702302157879, 42.21790060400963, 40.65920144319534, 40.724519938230515, 38.37914519011974, 43.32940176129341, 40.898751989006996, 37.717904672026634, 38.51294361054897, 40.7759615778923, 39.881527572870255, 42.52887971699238, 43.252657279372215, 48.91474865376949, 49.866012409329414, 50.78146688640118, 49.797942861914635, 52.64526307582855, 50.472733452916145, 50.281968489289284, 52.91291691362858, 48.87091040611267, 50.798478573560715, 51.13343060016632, 54.766313061118126, 51.76057554781437, 49.09537956118584, 45.03523662686348, 44.5077945291996, 40.76208472251892, 43.62773135304451, 43.30451689660549, 38.53418827056885, 42.75643050670624, 45.85686273872852, 47.55638614296913, 51.824233531951904, 54.54284705221653, 52.48118408024311, 52.72605434060097, 49.33588765561581, 49.21520613133907, 50.24297118186951, 51.00440472364426, 51.26518853008747, 49.13057707250118, 49.11748677492142, 49.582243636250496, 45.69015048444271, 40.06666503846645, 40.813796147704124, 39.83801230788231, 38.50362651050091, 38.243006095290184, 39.386816918849945, 40.068363547325134, 42.66669072210789, 43.57977792620659, 39.86594460904598, 42.73897044360638, 44.26583111286163, 49.42145146429539, 53.690864369273186, 56.43137611448765, 58.973428308963776, 56.84379078447819, 54.51162792742252, 52.50619053840637, 44.11614574491978, 45.798809453845024, 64.26277488470078, 56.37930750846863, 54.50795352458954, 52.92733334004879, 53.6312797665596, 53.365168645977974, 48.88485945761204, 57.0522665977478, 59.44898799061775, 60.55706173181534, 60.67338868975639, 59.76756289601326, 60.29596634209156, 61.90611854195595, 62.21853017807007, 58.4919523447752, 58.5265076905489, 57.02127166092396, 59.84659105539322, 62.818035408854485, 62.444929629564285, 65.43242052197456, 62.974248826503754, 67.54733383655548, 65.3336714208126, 58.97429846227169, 22.227910459041595, 0.06451094930525869, 0.5458084715064615, 0.35740519990213215, 0.11723965115379542, 27.52768747508526, 79.66676071286201, 70.24281799793243, 80.46867728233337, 74.86520916223526, 65.91598257422447, 52.49650105834007, 29.924629256129265, 45.64530149102211, 58.5396321862936, 82.25090324878693, 8.321670312434435, 0.5850986007135361, 0.17131468310253695, 0.10847328405361623, 0.1660367811564356, 0.1937659565010108, 0.2648121543461457, 0.12047462092596106, 0.19504727446474135, 0.21166396094486117, 0.3106355282943696, 3.03794221021235, 79.40826058387756, 66.77091389894485, 54.4045040756464, 42.53292270004749, 82.40410342812538, 91.5992984175682, 65.81452041864395, 69.0469841659069, 79.79266315698624, 67.00286105275154, 84.11883741617203, 8.003135304898024, 0.7885036454536021, 4.466398134827614, 9.41549576818943, 7.5511538330465555, 8.919711671769619, 0.8526179019827396, 14.952419009059668, 61.526131331920624, 53.11957262456417, 57.961565405130386, 55.143526419997215, 60.4916026443243, 58.67861732840538, 62.93203689157963, 60.64978055655956, 61.43815465271473, 53.84084612131119, 57.183340564370155, 55.880838856101036, 60.4752217233181, 59.45678137242794, 61.78451366722584, 58.20526532828808, 60.743217542767525, 62.030987441539764, 62.17761017382145, 61.07157312333584, 54.991857558488846, 56.042394787073135, 60.9928185492754, 54.49603356420994, 54.60060015320778, 47.560239136219025, 51.92088894546032, 63.47658947110176, 64.30094763636589, 56.786121279001236, 57.6048519462347, 57.59659118950367, 49.64456409215927, 52.02432319521904, 42.87236608564854, 41.307230070233345, 40.39605036377907, 41.68839141726494, 47.00529031455517, 40.67379266023636, 41.47026412189007, 41.477635726332664, 40.09246185421944, 41.10822714865208, 45.02679727971554, 44.48887534439564, 52.5502909719944, 51.160162165760994, 54.244821444153786, 53.80637437105179, 56.09347924590111, 53.844041749835014, 52.93268725275993, 55.194120705127716, 53.03888775408268, 53.934210911393166, 55.112808868288994, 57.63197869062424, 52.83442832529545, 51.14563934504986, 49.52107071876526, 48.52772042155266, 45.16725294291973, 46.67938940227032, 48.13748516142368, 41.34500004351139, 45.90737722814083, 47.18674577772617, 51.42262928187847, 54.744950607419014, 58.43520238995552, 54.4989138096571, 53.94930750131607, 53.36895324289799, 51.582026928663254, 53.81189547479153, 53.22257749736309, 52.58337199687958, 51.71744026243687, 51.71889938414097, 53.45818005502224, 47.302700355648994, 42.38828346133232, 44.34603340923786, 42.98245757818222, 39.79121021926403, 42.18545414507389, 42.035058215260506, 40.44681563973427, 44.41071733832359, 44.9698269367218, 40.37407234311104, 43.95094960927963, 46.02439574897289, 49.90060955286026, 55.4485322535038, 58.51734258234501, 62.10679717361927, 59.31896656751633, 56.00644111633301, 54.04047600924969, 44.607801362872124, 50.48153378069401, 60.011977180838585, 56.43261104822159, 59.24358241260052, 54.635600075125694, 54.03685860335827, 52.082228288054466, 50.27783051133156, 58.197870925068855, 62.97470860183239, 62.73318976163864, 63.16820561885834, 61.20635949075222, 61.208464577794075, 64.86565813422203, 65.72768747806549, 60.70662170648575, 61.981825679540634, 61.17577113211155, 63.05000156164169, 67.16630548238754, 63.84477451443672, 68.4290537238121, 67.63955488801003, 72.75973454117775, 62.910940423607826, 61.14121198654175, 28.326246924698353, 0.18153224576963112, 0.6573970837052912, 1.0447286465205252, 0.2174575367826037, 33.45587097108364, 86.41497060656548, 78.9553552865982, 86.62933990359306, 81.58323347568512, 74.31749895215034, 68.0034689605236, 51.670600175857544, 62.342369332909584, 66.62201508879662, 98.64871054887772, 11.827897019684315, 1.1114851268939674, 0.4680215095868334, 0.2620863349875435, 0.3186891961377114], [0.023642268279218115, 0.046759882679907605, 0.05615509377093986, 0.09450944897253066, 0.027013869294023607, 0.31469154346268624, 1.3414680236019194, 52.2568479180336, 53.38059961795807, 49.971186965703964, 28.542877100408077, 43.295404985547066, 71.44359156489372, 45.08246049284935, 59.85204756259918, 66.7623795568943, 56.19061343371868, 72.50947996973991, 12.566025462001562, 0.31977762992028147, 0.28339885699097067, 4.390279669314623, 1.2426126468926668, 1.8145744618959725, 0.5880120943766087, 5.3773365542292595, 56.23723693192005, 54.41448614001274, 55.44059067964554, 51.45846515893936, 57.40404412150383, 51.97494484484196, 51.85995161533356, 46.95642493665218, 54.052943140268326, 60.76953873038292, 59.23065170645714, 60.380340814590454, 57.09508270025253, 58.00636500120163, 55.95016993582249, 55.15575036406517, 56.00648671388626, 53.21382276713848, 54.632051065564156, 53.12149912118912, 55.57489827275276, 50.613067522645, 42.61870689690113, 45.56097261607647, 47.36860401928425, 48.127092719078064, 56.95934258401394, 53.686000630259514, 49.68982346355915, 52.85634934902191, 51.12763971090317, 44.60487172007561, 43.063112050294876, 42.030221074819565, 38.14779080450535, 38.5898020863533, 38.36038179695606, 42.54813328385353, 40.12547068297863, 37.050284296274185, 35.943707674741745, 38.40437963604927, 39.05124172568321, 37.640787810087204, 38.191332668066025, 42.53688968718052, 46.17725394666195, 45.7881548255682, 44.70629207789898, 47.59572543203831, 46.47138096392155, 47.2258684784174, 47.92074479162693, 48.07989165186882, 46.682835817337036, 49.90449674427509, 49.01377134025097, 50.551583021879196, 50.14422968029976, 50.153212398290634, 42.34795242547989, 44.178922176361084, 37.40759052336216, 38.741410151124, 40.282907634973526, 33.272990584373474, 40.34362077713013, 45.087103843688965, 47.17740587890148, 50.148436054587364, 49.07353833317757, 49.81169432401657, 47.82400578260422, 48.231032341718674, 46.28153555095196, 50.35638749599457, 48.58369521796703, 47.67403542995453, 48.5386448353529, 45.29476270079613, 44.60260324180126, 40.61650313436985, 37.886098846793175, 37.88764536380768, 35.88230676949024, 38.38186204433441, 36.70539580285549, 38.311341628432274, 38.81364807486534, 38.529822304844856, 37.21479266881943, 39.65634025633335, 37.4588193744421, 41.032960787415504, 41.32174529135227, 46.88275068998337, 51.229261457920074, 55.110973566770554, 55.63487805426121, 57.57412299513817, 51.58849038183689, 51.39937452971935, 40.59275820851326, 45.20244665443897, 58.149035945534706, 54.386029466986656, 52.06651613116264, 50.5285182595253, 46.45018570125103, 42.91064143180847, 51.319670006632805, 51.50169923901558, 54.1152635961771, 54.55629453063011, 57.71670654416084, 54.36710648238659, 58.307453244924545, 59.84366521239281, 60.65516106784344, 59.25821162760258, 62.11896792054176, 59.878889322280884, 62.64957144856453, 59.212830662727356, 63.75005319714546, 61.33829601109028, 71.014214605093, 54.1702276468277, 53.93697336316109, 9.43083269521594, 0.19467234145849943, 0.14042156893992797, 0.41163692891132087, 0.07116800654330291, 30.814007632434368, 74.10455837845802, 62.729686349630356, 76.57982155680656, 65.43678268790245, 57.11078725755215, 39.875508695840836, 38.424552753567696, 39.06772904098034, 51.96064241230488, 68.67350220680237, 3.8771174428984523, 0.13710060651646927, 0.11372345936251804, 0.09667795995483175, 0.05497057412867434, 0.08456358656985685, 0.015851836506044492, 0.0377745003788732, 0.049202324080397375, 0.02052024967269972, 0.2875450282590464, 1.7413792270235717, 64.59290876984596, 59.90624025464058, 50.81165246665478, 31.639064960181713, 68.21095302700996, 77.92564854025841, 53.080772906541824, 63.599870055913925, 72.22501203417778, 60.741906613111496, 78.1917254626751, 12.795150317251682, 0.30838230857625604, 1.0551302321255207, 5.306069478392601, 2.6342551968991756, 2.008730862289667, 0.2831350383348763, 6.6457165684551, 58.387476950883865, 50.46446889638901, 56.11118249595165, 52.4960108846426, 57.310082763433456, 54.16786037385464, 54.4289443641901, 49.36407074332237, 57.1736890822649, 58.87993052601814, 60.27350954711437, 61.41406014561653, 59.41612735390663, 57.91145749390125, 59.19202297925949, 57.22116753458977, 57.19017259776592, 53.77665616571903, 56.336704194545746, 56.57610274851322, 56.070452481508255, 50.54080680012703, 48.02834361791611, 47.93204918503761, 49.028601944446564, 47.92889915406704, 58.4561924636364, 54.16451655328274, 53.36130425333977, 55.16442909836769, 53.8961673527956, 46.266362965106964, 45.177907571196556, 43.539051711559296, 40.37448272109032, 39.71345879137516, 40.91995485126972, 44.72781412303448, 42.409870103001595, 38.296473026275635, 39.02330942451954, 40.21191984415054, 39.880482628941536, 39.568112790584564, 41.1013001203537, 45.7303561270237, 48.86665843427181, 47.95441098511219, 48.27548995614052, 50.16594931483269, 49.51672375202179, 48.61433297395706, 51.94873385131359, 51.87330409884453, 49.280517026782036, 51.205980107188225, 53.43924567103386, 54.43992957472801, 53.15594047307968, 51.51400297880173, 45.88049367070198, 45.13328656554222, 42.73652717471123, 40.056170001626015, 42.282056361436844, 36.746566593647, 44.070772379636765, 46.7072419077158, 49.26645778119564, 50.30700534582138, 49.90822434425354, 49.84882973134518, 49.99372735619545, 49.6755476295948, 48.71503137052059, 51.534951254725456, 51.05741947889328, 50.774057283997536, 49.87242266535759, 46.323610693216324, 46.38052023947239, 43.76923955976963, 39.25056003034115, 39.11068953573704, 38.3738748729229, 41.2040314078331, 38.553970009088516, 38.12701731920242, 40.039842277765274, 39.867772310972214, 40.38149334490299, 41.152069196105, 40.14513462781906, 44.13147412240505, 45.203871577978134, 48.919483199715614, 54.49944958090782, 57.09263563156128, 56.97836436331272, 59.68177489936352, 52.04530946910381, 51.67906232178211, 42.39578425884247, 50.83547718822956, 63.3702901750803, 55.5790476500988, 53.51100482046604, 52.86201484501362, 51.97670415043831, 45.5106633156538, 52.810432612895966, 55.189910531044006, 56.90909408032894, 57.130044624209404, 59.59115356206894, 57.0244786888361, 60.922833904623985, 61.690081134438515, 62.62326925992966, 62.294469103217125, 64.73944410681725, 61.92072495818138, 66.35057285428047, 61.14705987274647, 67.74898901581764, 63.83930280804634, 72.0095331966877, 61.372456178069115, 56.232969760894775, 10.347524955868721, 0.22699413442751393, 0.7345116301439703, 0.36243850481696427, 0.0202098315639887, 34.865682721138, 78.8130833208561, 67.55916640162468, 82.43624210357666, 70.11992499232292, 68.39547112584114, 41.3335170596838, 30.643544979393482, 44.13658104836941, 57.443383410573006, 82.48442351818085, 6.009640200063586, 0.32220685738138855, 0.11068221981986426, 0.026920375385088846, 0.0380285523715429, 0.19290306139737368, 0.10276528526446782, 0.2542091201758012, 0.20389265060657635, 0.15538096544332802, 0.37684127571992576, 2.526175221428275, 78.32209646701813, 69.00091543793678, 64.69519928097725, 38.70073713362217, 58.55521894991398, 78.41418072581291, 61.15139544010162, 71.18218079209328, 80.11400431394577, 66.03821441531181, 85.02918496727943, 16.502694971859455, 0.462116003036499, 2.39795561414212, 12.135939840227365, 6.679488206282258, 7.177850464358926, 1.524929660372436, 10.840345211327076, 61.77572473883629, 51.8378672003746, 58.21241274476051, 53.52187603712082, 61.01337544620037, 54.14357207715511, 55.23028336465359, 53.55651877820492, 59.16659474372864, 60.28973087668419, 61.37538202106953, 63.39580200612545, 61.15072287619114, 62.15704947710037, 60.68288818001747, 59.960569739341736, 60.84286719560623, 55.842369720339775, 58.4963259100914, 58.389775827527046, 58.6523113399744, 54.474610313773155, 52.51921243965626, 51.28464728593826, 51.455098539590836, 49.06142458319664, 58.978307247161865, 53.48756767809391, 56.65838733315468, 56.05470232665539, 58.4767759591341, 48.98007094860077, 47.99992494285107, 45.39891131222248, 41.29156731069088, 43.42245116829872, 43.65573205053806, 47.09771655499935, 44.973113760352135, 39.243868589401245, 42.40870736539364, 41.23286046087742, 42.230975702404976, 42.15693287551403, 42.09024265408516, 47.550754845142365, 50.97013436257839, 49.89692375063896, 49.773494973778725, 53.07656653225422, 52.089026123285294, 49.80461910367012, 55.2663092315197, 54.80965733528137, 52.60306254029274, 55.15383146703243, 57.72039234638214, 55.77073976397514, 55.82868665456772, 53.381454572081566, 47.92944632470608, 50.431589260697365, 45.53739108145237, 44.120276123285294, 48.21807503700256, 38.184918612241745, 45.46740263700485, 48.56479503214359, 50.64168378710747, 54.69437912106514, 51.90926156938076, 53.547786846756935, 51.88750013709068, 51.76249444484711, 51.75784729421139, 54.1254660487175, 54.38064895570278, 52.84640148282051, 53.20940360426903, 50.04341349005699, 50.45455902814865, 45.96766859292984, 41.26153752207756, 40.94056874513626, 40.18993802368641, 41.6535434871912, 40.712292194366455, 42.00121343135834, 43.54920096695423, 42.259667962789536, 42.99186207354069, 43.061823919415474, 41.57393395900726, 44.85727697610855, 46.466722413897514, 51.27729468047619, 57.11869463324547, 58.75660814344883, 59.64286878705025, 61.61225751042366, 54.39484879374504, 53.83412808179855, 44.601489901542664, 55.75911618769169, 56.68317340314388, 56.380067467689514, 58.62776845693588, 52.57888823747635, 49.60224576294422, 45.8291470259428, 53.93438570201397, 57.38271586596966, 59.3658484518528, 60.22521033883095, 62.18068040907383, 59.19963397085667, 62.42704018950462, 64.39506858587265, 65.35755693912506, 64.31345656514168, 68.78266274929047, 66.60010546445847, 69.92700934410095, 64.7386309504509, 70.02907946705818, 66.4754493534565, 75.68935453891754, 60.20268514752388, 61.4810885488987, 13.296108786016703, 0.3042913827812299, 1.2407541903667152, 1.7871516896411777, 0.24364432145375758, 40.090197175741196, 85.88123604655266, 74.56884786486626, 87.64428064227104, 76.76690071821213, 75.1585154235363, 59.886770099401474, 50.150837525725365, 58.84706608951092, 65.90668067336082, 93.83919462561607, 8.26449953019619, 0.6018992804456502, 0.2125128888292238, 0.24712589947739616, 0.15046733926283196], [0.05776651159976609, 0.003705855283442361, 0.0787249549466651, 0.05799205398943741, 0.06546647928189486, 0.21500312082935125, 0.9900950000155717, 55.85016690194607, 59.864320904016495, 40.584873631596565, 28.174899145960808, 14.592432975769043, 21.737907752394676, 51.06533445417881, 62.639672979712486, 73.21105912327766, 57.39134520292282, 73.2162344455719, 14.67923266813159, 0.18735154444584623, 0.8536534651648253, 0.7044927659444511, 3.837145962752402, 3.0850074347108603, 0.3700066002784297, 5.907345414161682, 63.93815830349922, 53.25598530471325, 55.99758379161358, 49.614245519042015, 57.95730963349342, 54.43987637758255, 57.059265822172165, 62.994254752993584, 70.37128150463104, 59.50755424797535, 60.1846095174551, 55.56159898638725, 57.88700960576534, 54.113063514232635, 58.38171645998955, 55.07356457412243, 53.074161261320114, 52.443550899624825, 53.4964781999588, 53.965912610292435, 51.19250603020191, 53.822895884513855, 71.94689735770226, 56.68171428143978, 48.18214036524296, 49.7815353423357, 50.19253648817539, 53.47892314195633, 57.384881749749184, 49.97373662889004, 48.59928958117962, 40.94798594713211, 46.74560844898224, 40.13757683336735, 39.96847450733185, 36.785328313708305, 46.0579327493906, 40.068287551403046, 35.40599852800369, 37.29475937783718, 35.646749809384346, 37.56924144923687, 38.48513290286064, 37.38202169537544, 37.551006227731705, 40.04275292158127, 43.21662001311779, 45.72610415518284, 45.42442314326763, 46.44502557814121, 48.323447182774544, 48.535889983177185, 48.069947585463524, 47.1988595277071, 45.982867777347565, 47.34936185181141, 50.197590216994286, 47.34857529401779, 50.72352759540081, 51.46655112504959, 46.522959396243095, 44.42709445953369, 38.34984876215458, 41.17215871810913, 38.39947409927845, 36.644093692302704, 42.28032745420933, 43.70547138154507, 48.0327969789505, 49.06496599316597, 49.98708911240101, 45.45626163482666, 49.649644419550896, 47.333151921629906, 47.853613793849945, 47.09674380719662, 47.13344603776932, 47.97396473586559, 46.303931549191475, 43.73634472489357, 46.14494048058987, 41.40078864991665, 36.1504165828228, 37.1845006942749, 36.14888146519661, 38.63100327551365, 35.95972381532192, 36.801732033491135, 38.874836191534996, 38.03793489933014, 37.8783168643713, 39.49674881994724, 39.9564291536808, 41.33407562971115, 44.42190773785114, 44.66628782451153, 48.80594529211521, 51.67558170855045, 54.3542517721653, 54.71565417945385, 54.45563793182373, 54.295423328876495, 53.37946727871895, 36.536707654595375, 42.319187968969345, 57.9728090018034, 51.04948930442333, 53.92754226922989, 45.12556917965412, 45.809984654188156, 54.99955594539642, 55.004925057291985, 58.95935006439686, 56.1319749802351, 55.50896041095257, 56.690970584750175, 53.23095224797726, 56.234839260578156, 55.93527473509312, 55.97606174647808, 59.08146411180496, 61.0091120749712, 65.040053576231, 63.10183838009834, 65.29923006892204, 60.75688920915127, 65.56612774729729, 50.16801260411739, 50.83784446120262, 2.5695394445210695, 0.0752512362669222, 0.6097124924417585, 0.046372874930966645, 0.41811124712694436, 39.02111314237118, 72.54844307899475, 62.68889933824539, 72.16991499066353, 65.89591965079308, 51.81853003799915, 46.52986742556095, 48.367182835936546, 39.86413210630417, 53.2596331089735, 65.87644189596176, 3.9631023164838552, 0.15407607686938718, 0.15429799386765808, 0.024910110696509946, 0.10004990050219931, 0.055239201901713386, 0.03144802169117611, 0.012301065271458356, 0.11048365078750066, 0.1661758151021786, 0.23424718820024282, 1.453732643276453, 67.64949515461922, 64.85675141215324, 49.538090005517006, 35.42972445487976, 30.883883982896805, 35.928101912140846, 56.045541018247604, 66.9860127568245, 77.98862636089325, 62.94056363403797, 75.24705067276955, 17.078502774238586, 0.3918240498751402, 0.23423335456755012, 2.6206286530941725, 4.387505818158388, 0.5401891667861491, 0.18531224137404934, 7.70852523855865, 62.60691873729229, 51.7260430008173, 56.60239353775978, 50.57614490389824, 58.38729076087475, 54.28334757685661, 61.28718115389347, 65.56899279356003, 69.85394686460495, 59.68758098781109, 59.609312787652016, 55.29159687459469, 59.66101661324501, 55.95654979348183, 60.05434110760689, 56.474180817604065, 55.57809390127659, 54.10881534218788, 55.67342318594456, 55.33275626599789, 52.93498992919922, 54.373345747590065, 65.67943766713142, 56.78663045167923, 50.46694256365299, 50.632651671767235, 51.66883707046509, 56.35563477873802, 57.57750101387501, 51.002774611115456, 50.27104027569294, 42.0466285943985, 47.266264110803604, 43.49268279969692, 42.45838589966297, 39.17926825582981, 48.931444957852364, 44.10035379230976, 37.38586708903313, 40.18540106713772, 37.990897223353386, 38.62202435731888, 39.466711431741714, 39.82347048819065, 41.051123812794685, 42.11066655814648, 46.55311077833176, 48.461311385035515, 49.32048328220844, 49.96506169438362, 50.902315601706505, 51.358583718538284, 52.54177562892437, 48.077623173594475, 48.925733864307404, 50.18438592553139, 55.055416747927666, 50.046365931630135, 52.96968586742878, 54.694409519433975, 48.13361696898937, 46.08057953417301, 44.62469905614853, 43.889586701989174, 40.50983525812626, 40.43199643492699, 43.767347261309624, 46.33197404444218, 49.93499390780926, 52.27994687855244, 50.9048006683588, 48.75203758478165, 51.84955537319183, 48.41455489397049, 49.29989218711853, 48.51083792746067, 50.08077308535576, 51.14172175526619, 49.215327724814415, 47.521359622478485, 47.36776426434517, 42.1009960770607, 39.828626811504364, 39.37944531440735, 38.04224766790867, 39.73715052008629, 39.12441439926624, 38.86105813086033, 38.782067969441414, 42.01769694685936, 39.47096340358257, 42.23123408854008, 42.10019811987877, 42.90065556764603, 47.31039874255657, 45.91282233595848, 51.92800976336002, 56.243996769189835, 56.22500538825989, 55.48130549490452, 55.98505586385727, 56.943277046084404, 54.06854510307312, 38.52280028164387, 47.998963594436646, 62.146983817219734, 54.14283111691475, 56.953962072730064, 49.57494802772999, 46.65706180036068, 57.304155081510544, 56.93997882306576, 61.50867126882076, 58.67390178143978, 59.909838661551476, 57.998746410012245, 54.08324271440506, 58.863940984010696, 60.28593868017197, 58.67740519344807, 63.12690183520317, 63.107507675886154, 65.73494508862495, 64.48675766587257, 68.38809192180634, 62.33175650238991, 69.10423189401627, 54.26690585911274, 53.66778060793877, 3.2494426611810923, 0.24558554228860885, 1.6907749674282968, 0.835413612658158, 0.4431812628172338, 43.59372317790985, 79.16807547211647, 68.5700261592865, 81.28485068678856, 70.53111612796783, 57.10906594991684, 56.07045628130436, 49.04136925935745, 49.93089012801647, 58.4236966073513, 80.60936853289604, 4.906263006851077, 0.1756139742792584, 0.04959768470143899, 0.07657651163754053, 0.1336321941926144, 0.0973122067807708, 0.12080161861376837, 0.17233844613656402, 0.23377510806312785, 0.268557031522505, 0.3342054854147136, 1.662010510917753, 79.62955310940742, 73.41035082936287, 59.22050625085831, 37.19716161489487, 24.16390847414732, 34.56901364028454, 67.49665215611458, 74.18164104223251, 86.44956395030022, 67.58381187915802, 87.2173735499382, 19.973911307752132, 0.3370170673588291, 4.252366069704294, 6.614809976890683, 9.950315169990063, 8.295772802084684, 0.8346644591074437, 11.634404752403498, 67.10728704929352, 52.492404878139496, 56.90321959555149, 50.23409865796566, 59.60313431918621, 57.61521399021149, 65.71298226714134, 65.60411810874939, 68.9651745557785, 62.85642854869366, 63.098581954836845, 58.51886250078678, 62.5379828363657, 58.15984636545181, 62.74365060031414, 58.39021660387516, 56.95036366581917, 56.80819429457188, 58.67202468216419, 58.58451917767525, 55.975867956876755, 56.15733101963997, 63.76883178949356, 56.779673025012016, 51.827159374952316, 51.021123826503754, 52.73990839719772, 57.331141233444214, 61.61361023783684, 55.04872910678387, 54.046939462423325, 45.54544284939766, 50.47124393284321, 43.573823645710945, 45.792832374572754, 41.01361222565174, 51.90719448029995, 46.88754603266716, 40.697423592209816, 42.714340165257454, 40.443468019366264, 39.77071791887283, 41.36342145502567, 42.10661977529526, 41.80730603635311, 45.27595371007919, 47.663810178637505, 50.257771387696266, 51.084736213088036, 51.505195051431656, 54.30253654718399, 54.94719855487347, 54.238920360803604, 51.991519555449486, 53.94965708255768, 54.450591802597046, 58.282233998179436, 53.398724645376205, 55.37250213325024, 57.73578532040119, 53.20890963077545, 51.13719239830971, 48.61331842839718, 48.67123872041702, 45.59400424361229, 43.38124617934227, 48.126545548439026, 48.14283907413483, 50.8865350484848, 54.15720194578171, 54.30132061243057, 50.51029063761234, 55.6078615039587, 51.48949049413204, 51.345782205462456, 50.67675590515137, 52.09321349859238, 54.085579589009285, 50.15719458460808, 50.291540175676346, 50.10116659104824, 45.42107172310352, 41.53859585523605, 41.78576119244099, 39.69930835068226, 43.44741202890873, 41.35943166911602, 41.7330352216959, 43.173309937119484, 44.95716601610184, 41.3024765253067, 43.175935596227646, 44.304798021912575, 44.656921327114105, 50.310979932546616, 48.40803824365139, 53.117972910404205, 60.33866085112095, 59.576444551348686, 58.51215586066246, 56.66499897837639, 60.659207850694656, 55.28405047953129, 39.83471028506756, 52.441844791173935, 53.62650342285633, 55.11214770376682, 57.07641810178757, 48.709270879626274, 50.7754822075367, 59.2518849670887, 60.69428376853466, 63.91785979270935, 60.9406853467226, 60.29254272580147, 61.43931359052658, 54.51235368847847, 61.642891466617584, 62.56367325782776, 64.40576121211052, 65.08774861693382, 67.16790899634361, 71.76709100604057, 68.78805845975876, 74.3705441057682, 65.0363601744175, 67.25372359156609, 59.13566440343857, 58.33021402359009, 4.9291107058525085, 0.32945933227892965, 2.2452541580423713, 1.4411794231273234, 0.8529233105946332, 50.03635726869106, 84.34326097369194, 75.08946552872658, 85.82096368074417, 79.39061433076859, 67.67901957035065, 65.59273391962051, 61.58666588366032, 62.694485038518906, 67.05361112952232, 90.08009433746338, 7.366637159138918, 0.5249969882424921, 0.25912326585967094, 0.14280220057116821, 0.3748077020281926], [0.09862410865025595, 0.07055740454234183, 0.04489741113502532, 0.018652406834007706, 0.07845169617212377, 0.2820673550013453, 0.19780880596954376, 47.213116362690926, 68.07996645569801, 42.62850657105446, 34.00911748409271, 20.2091433852911, 17.09727756679058, 48.337305039167404, 60.44293865561485, 71.59942880272865, 57.51149095594883, 71.38679221272469, 31.879559755325317, 0.11547157337190583, 0.25191339023876935, 2.3439512494951487, 1.4576718444004655, 0.4362444975413382, 0.08404755644733086, 13.234053365886211, 74.48341324925423, 57.198140770196915, 55.126837715506554, 56.0867004096508, 64.4877228140831, 61.358358934521675, 68.08746725320816, 58.69130104780197, 59.89563502371311, 56.60388685762882, 59.09560315310955, 58.58775660395622, 56.399207040667534, 53.48280273377895, 53.48247595131397, 54.43488724529743, 54.32484894990921, 56.39271318912506, 54.76687163114548, 54.027070328593254, 52.03111343085766, 59.43863354623318, 51.10435836017132, 40.22318623960018, 49.9351155012846, 53.59987445175648, 56.13790646195412, 52.897759526968, 51.402805745601654, 49.0981762111187, 43.011985793709755, 43.73632572591305, 45.48633322119713, 40.16177013516426, 39.50165435671806, 43.25095497071743, 40.57749442756176, 37.419711872935295, 38.143029659986496, 37.770900428295135, 39.68156710267067, 37.555877566337585, 39.09055441617966, 36.48033767938614, 39.3138874322176, 41.11095540225506, 43.00652168691158, 45.701618269085884, 47.77377247810364, 46.85365945100784, 45.933139845728874, 46.21495932340622, 47.64436662197113, 45.56836321949959, 48.22236120700836, 49.485523626208305, 50.09911850094795, 50.280866548419, 50.31902030110359, 54.15902964770794, 44.07581090927124, 42.968903705477715, 37.45271310210228, 39.38381128013134, 36.40122212469578, 36.87636762857437, 45.24134896695614, 46.27526968717575, 51.75798788666725, 48.731799870729446, 49.50397163629532, 48.339809104800224, 47.43130065500736, 49.74121190607548, 47.52963937819004, 47.4950460344553, 47.70224131643772, 47.074446603655815, 46.58876046538353, 45.62551975250244, 44.58680368959904, 38.98004874587059, 38.505374416708946, 38.048908710479736, 38.091698214411736, 37.119091004133224, 38.718341588974, 37.49907061457634, 37.95015200972557, 37.236143723130226, 38.85204881429672, 41.52279630303383, 39.44567956030369, 39.93205726146698, 42.741394713521004, 43.22135455906391, 42.59718105196953, 49.40823197364807, 50.63723802566528, 54.40447747707367, 54.2897692322731, 57.592016234993935, 56.440856605768204, 52.483365163207054, 35.36140412092209, 40.45898638665676, 52.092757523059845, 53.035110756754875, 43.86497162282467, 49.27313022315502, 58.22866067290306, 56.32604576647282, 54.36050623655319, 55.896718204021454, 59.4179892539978, 59.87181030213833, 59.79741409420967, 55.55341422557831, 51.47957302629948, 54.421983137726784, 54.88473750650883, 59.44733127951622, 59.210394993424416, 62.8374257683754, 52.65114136040211, 68.12472805380821, 54.62508983910084, 57.44815595448017, 43.98484759032726, 0.26816369325388223, 0.2079128348850645, 1.0912538249976933, 0.37783138977829367, 1.074340338818729, 55.31565718352795, 68.30915495753288, 67.64977633953094, 67.2176331281662, 67.06530690193176, 62.61269822716713, 28.0907279625535, 24.413631074130535, 33.35195414721966, 60.0746738165617, 59.339192882180214, 1.259183557704091, 0.0348980807029875, 0.08173601134330966, 0.05300510361848865, 0.01904528497107094, 0.10508452643989585, 0.039924639495438896, 0.034136648318963125, 0.08544870157493278, 0.030619974131695926, 0.2227609240799211, 0.3238045528996736, 58.393666818737984, 75.24875298142433, 45.97673110663891, 27.010628320276737, 18.238096050918102, 23.164807185530663, 55.314258858561516, 63.643259927630424, 76.63694769144058, 61.58881276845932, 78.11977252364159, 34.56030830740929, 0.13579429301898926, 0.23970644135260954, 1.8830876355059445, 3.6913456488400698, 0.35189220041502267, 0.09899584300001152, 17.566075511276722, 77.66377419233322, 56.505282148718834, 56.23850226402283, 54.80741165578365, 64.78464648127556, 63.94382759928703, 68.899916857481, 60.53468093276024, 60.62613062560558, 57.42697209119797, 62.071238681674004, 58.95341858267784, 58.54644142091274, 55.54538145661354, 55.66006310284138, 55.32984562218189, 55.94861201941967, 57.46242418885231, 56.409052312374115, 54.28880028426647, 56.791513189673424, 55.39720460772514, 52.81763702630997, 44.51644666492939, 51.20800159871578, 53.92495460808277, 56.95837363600731, 55.800214782357216, 54.201173186302185, 52.98572860658169, 44.91560384631157, 44.850163757801056, 47.4622917920351, 41.2512818723917, 40.40144607424736, 46.91057279706001, 44.47407893836498, 39.25194315612316, 40.126238241791725, 38.114413395524025, 40.1873579621315, 39.67898704111576, 41.057176887989044, 38.69426228106022, 40.22319383919239, 43.44684585928917, 44.65569779276848, 46.92420266568661, 48.48941087722778, 47.63443775475025, 48.45671363174915, 50.546111315488815, 50.27062229812145, 49.06240873038769, 51.540232971310616, 52.1646648645401, 53.63498076796532, 51.92566528916359, 54.58231933414936, 54.46610637009144, 46.44053801894188, 45.43011523783207, 42.25194297730923, 40.57270668447018, 38.899489268660545, 39.8364619910717, 47.24450267851353, 48.49586673080921, 53.955630362033844, 52.102276012301445, 52.251277416944504, 49.69435282051563, 51.00514568388462, 53.35651271045208, 49.69084180891514, 48.59113521873951, 50.029962211847305, 51.20901994407177, 49.899302423000336, 47.657301127910614, 46.55404932796955, 41.199517250061035, 40.646589919924736, 40.50084874033928, 39.177204966545105, 38.43309089541435, 40.81310078501701, 38.56317311525345, 40.32187834382057, 37.56239801645279, 40.82339823246002, 44.308502823114395, 41.805037558078766, 42.913464680314064, 46.10220417380333, 46.86743751168251, 44.297517612576485, 53.469161465764046, 52.12629832327366, 57.97840990126133, 53.70053865015507, 59.56004463136196, 55.46083979308605, 52.767016142606735, 35.35432510077953, 47.3993481695652, 58.43695789575577, 56.1695359647274, 47.59498067200184, 52.67603762447834, 59.595386534929276, 56.96291819214821, 55.68641468882561, 58.22441630065441, 59.975780323147774, 61.97397530078888, 59.97080259025097, 57.25821174681187, 56.757573410868645, 57.23949775099754, 58.147869408130646, 61.969297751784325, 60.348973497748375, 64.90392968058586, 57.96276994049549, 69.7630025446415, 58.235078528523445, 58.6364471912384, 48.50149802863598, 0.6137718027457595, 0.13088915700791404, 2.4787048436701298, 0.7374662684742361, 1.3069461635313928, 60.14974258840084, 73.79416063427925, 73.60028743743896, 74.08015608787537, 72.02804580330849, 67.44998306035995, 41.423690021038055, 34.85833391547203, 42.84928612411022, 65.62403663992882, 70.36992117762566, 2.459563370794058, 0.12626251933397725, 0.01840221771999495, 0.1039658798254095, 0.045363743338384666, 0.2416960205300711, 0.21797606052132323, 0.11356815011822619, 0.22340203577186912, 0.1864517794456333, 0.34750679042190313, 0.44358965184073895, 67.81734734773636, 87.31644943356514, 60.34527629613876, 46.290073692798615, 29.327198714017868, 30.776357352733612, 63.03158774971962, 72.87286207079887, 83.6088439822197, 66.94201111793518, 85.94715490937233, 39.43143032491207, 0.22504926222609356, 2.464186060242355, 8.034223336726427, 5.470251543447375, 4.989602509886026, 0.14141254388960078, 24.17740724980831, 79.37691986560822, 58.48285183310509, 58.137115985155106, 58.08788202702999, 70.13230472803116, 66.83936342597008, 69.13125604391098, 60.83070024847984, 67.04738706350327, 61.6462466865778, 63.13238114118576, 62.24067158997059, 61.24993935227394, 56.79234154522419, 56.79787024855614, 58.738828897476196, 59.644856080412865, 61.21237076818943, 57.01707288622856, 54.60445694625378, 55.97629353404045, 60.228842943906784, 59.22063164412975, 45.581301525235176, 52.10501566529274, 57.09031015634537, 60.50574168562889, 58.48209947347641, 55.375948548316956, 54.58988852798939, 48.24410744011402, 48.17104876041412, 51.384464129805565, 43.79969872534275, 43.338658064603806, 48.355099484324455, 46.7344256490469, 41.56568080186844, 42.544937655329704, 41.220389530062675, 43.02509889006615, 41.54279462993145, 43.84802833199501, 39.67911623418331, 41.80577091872692, 45.843787640333176, 48.42736020684242, 49.07086707651615, 52.75692008435726, 51.15480825304985, 51.478391289711, 51.91643178462982, 52.79634676873684, 51.628977209329605, 55.37371426820755, 53.44362683594227, 54.652459770441055, 54.35735620558262, 57.42820702493191, 57.0286812633276, 50.277176946401596, 48.99504974484444, 44.08701650798321, 45.63151203095913, 44.03426393866539, 41.52050502598286, 50.27159124612808, 49.980542063713074, 56.49217665195465, 54.956724643707275, 55.884216874837875, 52.70032212138176, 54.659774377942085, 55.7515773922205, 52.86901406943798, 53.62678840756416, 52.11405158042908, 50.92332847416401, 52.90028639137745, 50.329629331827164, 51.1542496830225, 44.19927768409252, 42.35046029090881, 43.71625520288944, 41.288193091750145, 39.76281054317951, 42.37430781126022, 41.078957319259644, 42.861456871032715, 40.32163515686989, 43.97974446415901, 45.97864240407944, 44.59129884839058, 44.04309466481209, 49.07970920205116, 49.492332860827446, 46.798000037670135, 54.72373254597187, 54.73638206720352, 59.663866460323334, 58.26990745961666, 61.084880009293556, 58.80499094724655, 53.45010548830032, 36.55519366264343, 49.16687272489071, 49.711805284023285, 55.5617281794548, 48.59854482114315, 53.594573736190796, 61.800168827176094, 60.72823494672775, 58.39701063930988, 61.395292952656746, 61.862983256578445, 64.63482812047005, 61.24053865671158, 59.15322706103325, 56.25175595283508, 59.43876273930073, 62.3323492705822, 65.96726462244987, 64.35074776411057, 70.02160146832466, 60.561165511608124, 69.20333057641983, 59.58723597228527, 65.17439156770706, 49.6430441737175, 1.138043801765889, 0.2830323844682425, 3.2136963168159127, 2.027062028646469, 2.2428890224546194, 65.61525151133537, 79.89949062466621, 81.3279327750206, 79.15853798389435, 80.62201425433159, 79.26168724894524, 46.30493089556694, 37.361639589071274, 52.565053179860115, 73.48007708787918, 82.24637389183044, 4.41536164842546, 0.4841135273454711, 0.2517391339642927, 0.15240054490277544, 0.15889599948422983], [0.04626058056601323, 0.09761970824911259, 0.07955858716741204, 0.03200714090780821, 0.009394410499226069, 0.2716650866204873, 0.2625402028206736, 26.868795230984688, 72.4009045958519, 48.132830411195755, 51.75783969461918, 33.27343516051769, 37.01254852116108, 46.13288752734661, 58.94931100308895, 67.61820003390312, 59.06709708273411, 65.70938766002655, 42.393405586481094, 0.11264494067290798, 0.05973298772005364, 0.7995707297232002, 3.1908253440633416, 0.35632982791867107, 0.07441617170115933, 22.26134866476059, 72.28609755635262, 52.49491274356842, 55.57365573942661, 61.44488029181957, 65.18115520477295, 57.01641172170639, 59.2042051255703, 54.47560966014862, 59.46394398808479, 52.371544763445854, 55.214666202664375, 49.53112117946148, 53.36520664393902, 51.643880009651184, 55.14799878001213, 51.40111103653908, 58.2679657638073, 53.129360899329185, 54.70475256443024, 50.846112817525864, 51.741166189312935, 32.65231288969517, 34.185485020279884, 51.29178710281849, 55.49671366810799, 58.29304061830044, 53.30119527876377, 54.917191565036774, 50.67269392311573, 45.1937261223793, 46.481188237667084, 44.30168978869915, 44.822980016469955, 40.740752667188644, 40.59618942439556, 40.3092972189188, 38.19275379180908, 39.61036652326584, 37.635798677802086, 36.62581667304039, 39.042703583836555, 36.73815004527569, 35.182300731539726, 37.91866309940815, 37.92726203799248, 39.32603158056736, 44.18249398469925, 45.00322714447975, 46.038101613521576, 48.34263235330582, 45.739863216876984, 47.00989946722984, 47.50888109207153, 50.22781379520893, 47.000133991241455, 47.96872101724148, 48.05012404918671, 48.383430764079094, 49.940230026841164, 49.946697279810905, 43.13228353857994, 42.40956611931324, 39.88201394677162, 39.6181371062994, 36.02707900106907, 39.32924620807171, 46.258311197161674, 50.403797551989555, 52.02384442090988, 48.87735866010189, 50.465719029307365, 46.08124829828739, 50.06989426910877, 46.14449970424175, 49.35024708509445, 46.58550404012203, 47.95186132192612, 44.337822049856186, 45.54374434053898, 45.988586470484734, 46.01893164217472, 39.198385030031204, 39.52093452215195, 38.177174627780914, 38.99676024913788, 37.200117856264114, 37.191621512174606, 36.50548852980137, 38.45227986574173, 37.21584141254425, 37.99218915402889, 39.09552834928036, 42.949456349015236, 39.74191926419735, 42.3593670129776, 45.04781395196915, 43.070023879408836, 44.76649224758148, 52.513353154063225, 50.736496299505234, 53.69577370584011, 54.67688485980034, 58.644388765096664, 56.220586225390434, 53.02070572972298, 33.41790720820427, 45.9027224779129, 58.66618059575558, 43.088209703564644, 55.585055127739906, 57.91112691164017, 56.74900107085705, 54.18220840394497, 52.45217643678188, 54.71145540475845, 61.111444383859634, 56.12026780843735, 56.18833735585213, 58.375796377658844, 58.699827790260315, 55.91723330318928, 57.295787930488586, 56.91339924931526, 57.03990966081619, 55.72538159787655, 58.8784372061491, 43.886664658784866, 68.82729515433311, 29.361888952553272, 0.06080821869545616, 0.12854095723014325, 2.553901383653283, 0.8216087752953172, 3.331248234026134, 61.003131195902824, 64.36248913407326, 65.21074801683426, 66.46927088499069, 66.99726015329361, 53.33184443414211, 40.86975194513798, 32.94323667883873, 34.75238420069218, 65.6956247985363, 53.69857795536518, 1.0977347334846854, 0.02425178674457129, 0.10263500866130926, 0.048217338262475096, 0.06342319087707438, 0.02605235389637528, 0.04273350888979621, 0.019452801971056033, 0.04540167821687646, 0.08724521845579147, 0.36050256807357073, 0.28345707105472684, 35.18849439918995, 78.43605995178223, 54.101443737745285, 48.51606264710426, 22.064904905855656, 37.42671109735966, 52.932113483548164, 63.07356409728527, 75.06156742572784, 62.45220623910427, 72.41509303450584, 45.35884626209736, 0.041050559157156385, 0.49967508763074875, 1.557215340435505, 3.248510998673737, 0.21317145583452657, 0.03878786592395045, 27.7839495241642, 77.02307537198067, 57.088326662778854, 56.29274055361748, 61.282169222831726, 67.95138895511627, 60.13976812362671, 60.268820598721504, 57.20960475504398, 61.75845846533775, 53.413866832852364, 57.04354986548424, 53.258048593997955, 55.01446254551411, 53.605832532048225, 57.05944441258907, 53.54846701025963, 59.66871879994869, 56.23806908726692, 55.637629106640816, 54.218899235129356, 52.29860007762909, 37.20132239162922, 37.57102355360985, 50.73521576821804, 56.27137430012226, 58.65872919559479, 55.897842943668365, 57.06951007246971, 53.11483807861805, 45.310083478689194, 46.99884966015816, 47.90372170507908, 46.34298965334892, 42.64772213995457, 41.945660412311554, 43.43728557229042, 40.99408507347107, 40.96159301698208, 39.73061487078667, 36.95259153842926, 40.53429074585438, 39.50005084276199, 36.932255029678345, 42.34248831868172, 39.21886973083019, 41.90972574055195, 47.276804745197296, 48.0592929571867, 49.4105688482523, 51.05602875351906, 48.67959827184677, 49.83925424516201, 50.35077899694443, 49.519797787070274, 51.56221479177475, 48.89920748770237, 51.03109069168568, 50.34490831196308, 53.909006863832474, 51.15132763981819, 47.38739401102066, 44.97250199317932, 43.514474630355835, 39.833087772130966, 37.3383354395628, 41.490422040224075, 46.595710292458534, 51.6749357432127, 53.080069944262505, 52.213632836937904, 51.93834900856018, 51.16447493433952, 50.28650924563408, 47.51834638416767, 51.934321224689484, 49.23411771655083, 49.607728868722916, 47.92880415916443, 47.832775712013245, 45.64781695604324, 46.81058496236801, 39.8325178027153, 42.269916012883186, 39.939041286706924, 39.62016999721527, 38.726089373230934, 37.97825150191784, 38.06592419743538, 40.24042211472988, 40.0141366571188, 39.066326916217804, 43.526291996240616, 44.935013204813, 40.999116003513336, 44.88135628402233, 47.82382719218731, 44.58583474159241, 47.03220807015896, 53.11650238931179, 54.274756237864494, 56.782028898596764, 56.37889713048935, 58.80379781126976, 59.43929471075535, 52.77379497885704, 35.58208867907524, 54.398428201675415, 58.223397955298424, 46.021868884563446, 57.32029281556606, 59.5668538659811, 58.873337879776955, 55.264831110835075, 54.916009828448296, 58.504784256219864, 63.221284970641136, 60.243327766656876, 56.72681786119938, 58.004525899887085, 59.25995193421841, 56.62629805505276, 60.72159290313721, 60.88567189872265, 60.15206426382065, 57.319206073880196, 63.054169937968254, 46.26409828662872, 72.54860267043114, 30.95222521573305, 0.10246503457892686, 0.31738025543745607, 3.9329160237684846, 0.048600145455566235, 3.5807022359222174, 69.68089655041695, 69.42618861794472, 69.7314490377903, 71.6518659889698, 71.38866171240807, 67.42808103561401, 51.216741129755974, 31.99708364903927, 40.94048134982586, 71.87366768717766, 64.53281119465828, 1.7933170963078737, 0.0404123158659786, 0.03505057349684648, 0.013460991995088989, 0.057083398060058244, 0.2678212069440633, 0.1688026764895767, 0.33251502143684775, 0.1879070419818163, 0.1361080730566755, 0.40954944561235607, 0.4295998119050637, 40.03665804862976, 90.60245990753174, 65.36289185285568, 69.8321284353733, 46.04150243103504, 53.780816942453384, 60.86166478693485, 68.87857720255852, 79.89927023649216, 68.8919448852539, 77.87261098623276, 51.0270819067955, 0.2816477447049692, 1.4149544178508222, 4.84053460881114, 12.611374128609896, 1.8050932581536472, 0.14491076086414978, 32.403665632009506, 76.69694647192955, 60.432975590229034, 60.66236548125744, 64.83644530177116, 69.84154433012009, 59.84098635613918, 66.19659751653671, 59.07320335507393, 63.679764568805695, 57.19144932925701, 60.74260197579861, 55.706906989216805, 59.04077589511871, 58.28944981098175, 60.66394999623299, 54.87771928310394, 63.51008087396622, 57.367433086037636, 59.44166198372841, 55.75862981379032, 53.325244188308716, 41.670672968029976, 40.69367319345474, 50.159482061862946, 57.19479314982891, 61.47631600499153, 58.57743635773659, 58.01853574812412, 57.00290344655514, 47.128445506095886, 51.3398203253746, 48.01878333091736, 48.000738099217415, 46.29060946404934, 43.40878710150719, 43.9213377982378, 42.84245789051056, 43.443163856863976, 43.03822338581085, 40.1451650261879, 44.65787887573242, 40.033831000328064, 36.99134185910225, 43.543972447514534, 41.84510260820389, 41.98800154030323, 51.33394584059715, 50.335974991321564, 52.26367995142937, 53.87638181447983, 52.080024406313896, 52.95431189239025, 52.43408940732479, 52.685293927788734, 52.41671673953533, 51.20438799262047, 55.25269456207752, 53.27648140490055, 55.96566930413246, 54.607397988438606, 48.33874136209488, 49.04760092496872, 47.695333287119865, 45.9511698782444, 42.95301295816898, 44.683504700660706, 48.91273856163025, 54.07430939376354, 55.06739370524883, 55.504841431975365, 56.109066009521484, 53.4793297201395, 54.7111514210701, 49.086913615465164, 53.920345455408096, 50.784913301467896, 55.037553906440735, 48.82805250585079, 50.5211466550827, 48.50491784512997, 50.666249468922615, 42.72619932889938, 44.195181503891945, 40.86324289441109, 42.13742472231388, 40.306831151247025, 41.49309329688549, 39.530133828520775, 44.2416188120842, 41.71815142035484, 40.449977070093155, 44.694489911198616, 48.481883481144905, 44.70986768603325, 46.109172999858856, 50.386269092559814, 47.25712560117245, 51.18704952299595, 55.2395548671484, 56.86042629182339, 57.71430127322674, 60.20077385008335, 61.42377242445946, 62.525732293725014, 53.15500572323799, 38.51154528558254, 54.450436010956764, 51.68741047382355, 50.06998926401138, 58.23121793568134, 62.831463888287544, 59.53163355588913, 59.77690279483795, 55.228368267416954, 60.65760813653469, 65.64286082983017, 63.82956013083458, 60.36506563425064, 61.72942042350769, 59.40656706690788, 57.34614282846451, 60.115103647112846, 63.188336938619614, 62.95630618929863, 58.3802193403244, 61.25075250864029, 50.69120652973652, 74.17170837521553, 38.13896007835865, 0.213711115939077, 0.27475782379042357, 7.28867769241333, 2.4333644891157746, 5.349489273503423, 75.13574704527855, 75.56182578206062, 78.08490559458733, 78.03767412900925, 80.5218668282032, 72.27355822920799, 58.99691864848137, 45.612361058592796, 54.52915258705616, 80.23863762617111, 78.97743970155716, 2.7463814802467823, 0.34868665679823607, 0.32902532431762666, 0.06197962829901371, 0.2030091089545749], [0.07676648659980856, 0.0601350684883073, 0.09012590919155627, 0.08358289778698236, 0.15584140870487317, 0.2629665518179536, 0.2550755627453327, 14.17064230889082, 72.49350562691689, 47.62328155338764, 33.264270052313805, 31.180784851312637, 32.79172740876675, 42.555930465459824, 59.53602991998196, 66.98934897780418, 63.80489185452461, 60.13042442500591, 50.62480889260769, 1.149869835935533, 0.14220011100405827, 0.6237729848362505, 3.311736756004393, 0.27026854280848056, 0.10716735647292808, 34.42875936627388, 63.54183577001095, 44.86581511795521, 61.81137442588806, 57.156593799591064, 58.871992751955986, 56.37890473008156, 57.52165541052818, 55.67647062242031, 52.600862458348274, 52.93853893876076, 54.083444103598595, 51.83719843626022, 53.365522027015686, 51.933686658740044, 52.14610666036606, 51.556439101696014, 51.796400025486946, 52.36913189291954, 52.14480713009834, 49.52688440680504, 47.03996725380421, 39.18375201523304, 46.086697205901146, 51.581323966383934, 54.80741545557976, 52.498450353741646, 50.43458729982376, 46.75550311803818, 47.989205718040466, 43.065882101655006, 42.94521577656269, 46.672416776418686, 43.937847912311554, 39.544755443930626, 40.89631251990795, 40.642147958278656, 39.03511539101601, 38.30623850226402, 42.83879868686199, 39.20697636902332, 37.107326835393906, 38.1088162958622, 37.67726965248585, 37.18866907060146, 37.38355301320553, 36.78693562746048, 40.944482535123825, 44.02920641005039, 46.828432604670525, 46.62016578018665, 46.98805443942547, 45.51212623715401, 46.692437902092934, 47.483912631869316, 49.56841617822647, 48.47100466489792, 48.768851682543755, 52.8267527371645, 49.99832130968571, 52.942593321204185, 44.71450723707676, 42.39191986620426, 40.295545756816864, 40.79857796430588, 34.968657195568085, 36.2611236423254, 46.21524430811405, 49.62952449917793, 51.55297748744488, 46.485896185040474, 48.90876017510891, 49.88482519984245, 50.016746520996094, 46.885866522789, 47.240531891584396, 44.78709854185581, 47.3249975591898, 45.85780888795853, 46.76105082035065, 45.81409603357315, 44.14399445056915, 40.45432023704052, 38.031422048807144, 37.13504634797573, 39.40738141536713, 36.56171031296253, 38.56174059212208, 34.23162594437599, 40.54420821368694, 37.160371989011765, 38.741372153162956, 40.627328753471375, 40.473095029592514, 40.06460174918175, 41.83462657034397, 45.699277594685555, 43.93800750374794, 43.45749668776989, 42.5648295879364, 45.94599835574627, 51.88719995319843, 53.06936591863632, 56.849224492907524, 55.8694052696228, 57.00471214950085, 50.47619506716728, 31.623084917664528, 54.18612599372864, 47.431749030947685, 53.43973584473133, 57.081441432237625, 54.291615933179855, 52.330161184072495, 52.97217473387718, 53.70163679122925, 59.15322706103325, 59.29027050733566, 59.663353487849236, 56.72577291727066, 58.484265357255936, 60.98099358379841, 64.18523624539375, 62.61541128158569, 66.66799262166023, 58.01418878138065, 48.248484805226326, 50.68301036953926, 62.09819443523884, 14.073029346764088, 0.27781291923020035, 0.04584816168062389, 1.536018771585077, 0.19057084748055786, 5.057836873456836, 65.87660148739815, 64.99646991491318, 67.51046821475029, 66.44719406962395, 65.09565219283104, 42.11239166557789, 51.54184028506279, 41.15504443645477, 41.278169229626656, 68.23475494980812, 48.1013149023056, 0.7078224560245872, 0.142468145058956, 0.09424060597666539, 0.05100019909150433, 0.06143386402982287, 0.06226913639693521, 0.030880280573910568, 0.02909789418481523, 0.06490551953902468, 0.21410084736999124, 0.44170907931402326, 0.3174265654524788, 18.922929503023624, 82.16856926679611, 54.294625371694565, 43.366886749863625, 30.586093962192535, 41.898489743471146, 49.56067979335785, 64.70621109008789, 71.9005398452282, 67.81157925724983, 66.36967062950134, 57.49102145433426, 1.0004145931452513, 0.17584619228728116, 0.8637650194577873, 3.5040280502289534, 0.270314259105362, 0.04529695004748646, 39.1778889298439, 66.6549365222454, 49.821687787771225, 63.80303755402565, 59.0449670702219, 61.95896990597248, 57.5786105543375, 57.83322349190712, 57.66772337257862, 56.77037492394447, 55.21023564040661, 55.18683269619942, 53.757132813334465, 54.92233268916607, 55.966915637254715, 54.075787514448166, 55.14116294682026, 57.71271675825119, 55.85528142750263, 54.04834918677807, 50.002516284585, 47.93776027858257, 39.44542497396469, 45.77832095324993, 55.71267507970333, 55.89145928621292, 52.92751953005791, 52.75761164724827, 49.023620411753654, 49.15293887257576, 46.16135559976101, 45.40046542882919, 48.35652820765972, 46.50286607444286, 40.31222686171532, 41.46944336593151, 42.091310396790504, 41.11687548458576, 39.534446597099304, 44.963355883955956, 39.87892471253872, 40.17045646905899, 40.19588090479374, 39.76743869483471, 40.57609610259533, 40.86814843118191, 38.427056819200516, 44.203655049204826, 47.70693026483059, 49.90253984928131, 50.47085255384445, 49.981830194592476, 48.61601248383522, 50.57905174791813, 49.59240049123764, 50.84725275635719, 51.537633910775185, 50.082399398088455, 53.09157192707062, 52.41589978337288, 54.244297072291374, 46.70152701437473, 46.63166396319866, 43.808981627225876, 42.36015737056732, 38.592522740364075, 41.50594040751457, 46.60960994660854, 51.69196642935276, 55.00394091010094, 49.99892167747021, 50.798341780900955, 52.31139779090881, 51.18559040129185, 47.907122522592545, 51.864838153123856, 49.39586363732815, 49.673628732562065, 46.87083452939987, 49.481400847435, 48.10463972389698, 46.186597645282745, 41.80387482047081, 39.90080013871193, 39.88810122013092, 40.27055449783802, 37.75992661714554, 40.38485236465931, 35.97552336752415, 41.45063817501068, 38.859504014253616, 41.82176426053047, 42.17151269316673, 42.801138907670975, 43.12599487602711, 44.59290996193886, 47.99127660691738, 47.855080515146255, 45.344874411821365, 46.32443904876709, 47.6621762663126, 55.508922412991524, 56.500403210520744, 58.91128644347191, 56.36644519865513, 59.689651876688, 48.44396531581879, 35.993492603302, 56.06677807867527, 48.21704909205437, 56.611657440662384, 60.443584620952606, 57.87378631532192, 54.29902173578739, 54.19317841529846, 57.22717501223087, 61.206028908491135, 59.71360959112644, 61.42325945198536, 59.61277060210705, 59.64122347533703, 61.90353088080883, 65.44435948133469, 63.910017013549805, 67.07188054919243, 59.19505141675472, 49.672728180885315, 52.13487446308136, 64.51339423656464, 16.4408627897501, 0.22011167951859534, 0.6742114189546555, 3.1375809386372566, 0.1741651981137693, 5.1792180351912975, 73.31161692738533, 69.4071364402771, 73.88489976525307, 72.16197341680527, 72.30064317584038, 49.51691374182701, 53.39600399136543, 45.365214720368385, 51.63922145962715, 75.47928661108017, 59.702533185482025, 0.9350947919301689, 0.04474098124774173, 0.09971211198717356, 0.03477456877590157, 0.04892482022114564, 0.16534296213649213, 0.14052107610041276, 0.2561354386853054, 0.1588931941660121, 0.33290301624219865, 0.6881765008438379, 0.3761516424128786, 23.32752775400877, 94.14899200201035, 63.201689422130585, 49.79972116649151, 39.445690959692, 48.92629623413086, 56.41499139368534, 71.33825361728668, 75.97699150443077, 75.82968100905418, 72.08455637097359, 63.645034432411194, 1.5772070176899433, 0.43560613179579377, 4.787099026143551, 10.301530323922634, 0.9938063914887607, 0.3183900215663016, 44.48071338236332, 68.01068857312202, 52.92143605649471, 67.80436724424362, 60.39124622941017, 63.24815712869167, 60.51734246313572, 60.82144774496555, 60.43990641832352, 57.107097655534744, 57.595455050468445, 59.593927413225174, 56.427591517567635, 56.66601352393627, 58.051913157105446, 57.6455819606781, 57.02431529760361, 58.81063364446163, 57.4369465559721, 57.52652294933796, 52.28526659309864, 47.96276293694973, 39.191268011927605, 47.81105987727642, 55.75961396098137, 57.834618017077446, 56.668821573257446, 55.390680357813835, 52.41553120315075, 51.66270799934864, 46.63985252380371, 48.130284547805786, 50.57329885661602, 50.141782611608505, 43.75573508441448, 45.37593014538288, 44.48123775422573, 42.33914449810982, 42.86906026303768, 48.24908897280693, 43.508497551083565, 42.533378675580025, 42.500510439276695, 41.4579413831234, 41.94479025900364, 43.46756994724274, 41.51184529066086, 45.70846930146217, 50.74972718954086, 52.09604434669018, 51.793569177389145, 53.39364431798458, 52.73138165473938, 51.53702214360237, 54.08989995718002, 53.46810892224312, 53.64667274057865, 53.16435322165489, 57.207720056176186, 54.639734253287315, 57.904291078448296, 48.97390007972717, 50.441844910383224, 47.44461514055729, 48.298417925834656, 44.00705359876156, 41.731306314468384, 48.389563634991646, 53.55841867625713, 57.81857527792454, 52.614359334111214, 54.606410041451454, 54.52602535486221, 54.56618160009384, 49.85938176512718, 53.70341129601002, 49.92846205830574, 52.80729778110981, 49.92899402976036, 51.919418424367905, 50.59619642794132, 48.6639317125082, 45.10227642953396, 41.727928295731544, 40.664030984044075, 43.38068000972271, 40.47530271112919, 43.30008253455162, 37.974474504590034, 43.85185852646828, 41.78400568664074, 43.986204117536545, 44.74362127482891, 45.03630816936493, 44.78889584541321, 47.63909250497818, 49.58077311515808, 48.58657166361809, 47.60011799633503, 48.24104480445385, 50.63792198896408, 56.82654730975628, 58.6496514827013, 63.076706528663635, 59.08318541944027, 63.515465185046196, 50.4157555103302, 35.96940189599991, 52.1649194508791, 47.76146113872528, 57.822268679738045, 62.74743899703026, 59.700697883963585, 55.864982306957245, 56.64053589105606, 58.95217604935169, 64.83649089932442, 64.25171747803688, 62.19671934843063, 61.48820176720619, 63.56037877500057, 65.62517657876015, 68.08096200227737, 66.14303559064865, 71.86552852392197, 59.6856164932251, 54.2570111900568, 55.82919962704182, 68.79416853189468, 18.988399989902973, 0.4407105938298628, 0.5337201326619834, 8.794058114290237, 0.6107458588667214, 8.267373126000166, 78.98961424827576, 77.56759375333786, 80.60467958450317, 79.3470686674118, 79.25639793276787, 57.0758481323719, 71.16425335407257, 54.72935624420643, 61.25957943499088, 86.430344581604, 73.63017663359642, 1.536545162089169, 0.3113613784080371, 0.15216840110952035, 0.201270405377727, 0.17342731036478654], [0.006975183941904106, 0.11320216741296463, 0.0018957558245347172, 0.10812990716658533, 0.10367389666498639, 0.22256937576457858, 0.11396544403396547, 7.773459954187274, 65.2259624004364, 48.86786296963692, 40.28617165982723, 20.387931391596794, 31.61232579499483, 42.02660746872425, 67.07985252141953, 63.094215989112854, 65.1703941822052, 56.58142626285553, 61.01834557950497, 2.9166035586968064, 0.2709001995390281, 0.22860673227114603, 0.32095381524413824, 0.33083396789152175, 0.06470534746767953, 38.532143980264664, 58.611889109015465, 48.60174424946308, 60.59789814054966, 59.10039849579334, 59.74210426211357, 56.44853599369526, 52.76239559054375, 53.41606691479683, 55.41823647916317, 54.557172283530235, 56.97014540433884, 55.26963025331497, 54.2082180082798, 55.53598456084728, 54.06241983175278, 55.08075378835201, 55.17243526875973, 54.37134325504303, 53.39516043663025, 51.306952089071274, 49.76435646414757, 47.17875860631466, 47.507741153240204, 54.15671557188034, 53.107553869485855, 52.77431175112724, 50.58804966509342, 47.47290842235088, 45.42047515511513, 45.97704268991947, 45.34450963139534, 44.50306378304958, 46.794637218117714, 42.554509341716766, 42.54259318113327, 41.31201781332493, 41.63912706077099, 48.00525605678558, 43.06307405233383, 36.401149928569794, 36.92328751087189, 35.817094668745995, 38.5303770750761, 36.457242518663406, 37.45765283703804, 38.76735515892506, 42.44175039231777, 46.391638442873955, 46.90678060054779, 46.41100600361824, 45.63382610678673, 44.7100842744112, 45.38170203566551, 49.1570882499218, 50.04357688128948, 46.21578007936478, 49.20014373958111, 51.542805433273315, 50.75935207307339, 52.955687418580055, 45.999529883265495, 40.84159925580025, 40.75157828629017, 36.78848214447498, 36.966624185442924, 38.15489262342453, 48.34314152598381, 52.12057203054428, 51.944569274783134, 47.7924332767725, 50.56300900876522, 48.95876929163933, 50.113637521862984, 48.13977263867855, 50.414387583732605, 47.886938005685806, 47.09378756582737, 48.162157237529755, 47.850414365530014, 44.86424580216408, 41.1710187792778, 40.12515150010586, 36.33328557014465, 37.916428819298744, 37.99055904150009, 36.34657345712185, 35.60450367629528, 34.66881148517132, 39.97682265937328, 44.93991494178772, 36.918568164110184, 39.644416496157646, 42.40947872400284, 40.90807668864727, 42.88996674120426, 47.873292937874794, 44.5546118170023, 43.592123463749886, 42.77170188724995, 42.13510304689407, 43.52254159748554, 49.599889889359474, 50.04974015057087, 54.70032200217247, 54.80331927537918, 58.42954449355602, 41.530099511146545, 40.11821687221527, 57.611224204301834, 52.18035042285919, 56.69419281184673, 54.75073769688606, 55.111273750662804, 54.14370507001877, 54.522434547543526, 56.977604404091835, 58.23937989771366, 60.388711765408516, 58.79764974117279, 64.2158854007721, 59.314273819327354, 63.054633513092995, 59.747689962387085, 66.19327649474144, 60.04854641854763, 63.9364255964756, 51.972019001841545, 60.65528646111488, 5.767281129956245, 0.1255340123316273, 1.6088027972728014, 2.6926651876419783, 0.06233866821276024, 6.667644241824746, 70.13084560632706, 63.69757421314716, 68.20045799016953, 65.37407085299492, 69.59954291582108, 44.68691311776638, 66.065474152565, 28.758549727499485, 39.610928893089294, 68.16910207271576, 35.5227130651474, 0.6116226618178189, 0.05667597382853273, 0.1240257010795176, 0.040519815956940874, 0.09206321890815161, 0.015630129164492246, 0.02652178085554624, 0.04314530437113717, 0.10581071794149466, 0.2519340516300872, 0.27447180007584393, 0.26260747108608484, 10.264514610171318, 78.76316919922829, 55.57349614799023, 45.344213247299194, 27.731069661676884, 38.64887371659279, 46.30750335752964, 72.1045432984829, 68.63703936338425, 70.70633992552757, 59.92411449551582, 67.76109516620636, 2.761437934823334, 0.11649892840068787, 1.0716796503402293, 3.3971143746748567, 0.09586329702869989, 0.06894027959788218, 42.582035064697266, 58.20621907711029, 52.37705446779728, 61.417046785354614, 60.655210465192795, 62.8555241972208, 58.8377033919096, 55.74575990438461, 57.59298138320446, 58.69177982211113, 55.9659618884325, 58.310599476099014, 54.276515543460846, 57.1621984988451, 56.20480187237263, 56.390220522880554, 56.00093141198158, 55.905423536896706, 53.20803187787533, 52.53430522978306, 50.183424577116966, 50.54829619824886, 47.690522745251656, 48.505157232284546, 54.1819766163826, 54.7072946280241, 54.30302292108536, 52.141558304429054, 50.52296295762062, 47.49944619834423, 45.76107747852802, 47.496235370635986, 46.49263322353363, 47.75631241500378, 45.19460007548332, 45.27709744870663, 44.16892871260643, 45.1428734511137, 50.41010521352291, 45.82886964082718, 37.89082959294319, 38.72419707477093, 36.67722791433334, 39.82760846614838, 37.5479131937027, 40.50109952688217, 40.77842004597187, 45.11360742151737, 48.516913801431656, 51.0465482622385, 49.03902858495712, 49.21235628426075, 47.341279685497284, 48.1007981300354, 49.47726666927338, 54.0561767667532, 48.24897117912769, 50.484858602285385, 55.48238843679428, 52.36353859305382, 55.002120807766914, 47.94942565262318, 45.856083780527115, 45.84838919341564, 40.61568237841129, 39.477962628006935, 42.277109026908875, 47.74331331253052, 55.36429837346077, 53.09734381735325, 49.90897290408611, 52.07264140248299, 50.116221383214, 50.87903805077076, 51.53148964047432, 52.94016145169735, 50.2239266037941, 48.37215296924114, 48.79382014274597, 48.04209508001804, 48.04138831794262, 44.90250214934349, 40.84055431187153, 39.15537893772125, 39.418347626924515, 39.0227622538805, 39.20594282448292, 38.75211797654629, 37.05589659512043, 41.27587415277958, 45.46411581337452, 39.070719480514526, 43.21066573262215, 43.853237852454185, 42.45357535779476, 46.140137538313866, 50.93673415482044, 46.72333404421806, 45.07940545678139, 45.734281316399574, 45.59900477528572, 46.67919561266899, 52.39367477595806, 50.976860001683235, 56.26529462635517, 56.384562626481056, 56.20196342468262, 44.24681693315506, 43.81124630570412, 53.573237881064415, 56.35700650513172, 57.71086245775223, 56.73141561448574, 57.39333249628544, 58.776481077075005, 58.79680998623371, 60.219822227954865, 58.26097033917904, 60.82012161612511, 61.04595489799976, 66.98541238904, 60.049279779195786, 65.27675047516823, 63.603772446513176, 69.82233256101608, 61.811222434043884, 66.4283698797226, 56.485268622636795, 64.71438825130463, 6.780700050294399, 0.2307081234175712, 4.740012902766466, 3.6034095799550414, 0.06181947283039335, 7.804219778627157, 77.00456276535988, 70.48016086220741, 73.23590219020844, 71.62567779421806, 72.5371652841568, 52.39850431680679, 64.29455637931824, 28.54729436337948, 45.01735858619213, 75.0898303091526, 44.66252602636814, 0.8383304311428219, 0.07774696758133359, 0.12646840594243258, 0.03812544346146751, 0.06842191171017475, 0.09078990129637532, 0.21490337618160993, 0.10796702801599167, 0.1888651101035066, 0.37603850942105055, 0.6015762977767736, 0.3369936451781541, 12.435242179781199, 90.41629269719124, 63.849433064460754, 54.93325710296631, 31.44918154925108, 49.38383728265762, 55.12624874711037, 77.08760350942612, 75.3271047770977, 76.0667958855629, 68.59933018684387, 74.27726671099663, 4.033061312511563, 0.2965042053256184, 2.7617464307695627, 4.974062293767929, 0.5075000552460551, 0.45894228271208704, 47.84778870642185, 65.55266886949539, 55.965749099850655, 65.51304459571838, 62.457799538969994, 64.38616186380386, 61.57496631145477, 59.63164418935776, 60.345055907964706, 60.905510634183884, 58.16996522247791, 62.44909420609474, 58.67046296596527, 59.81072098016739, 61.24433845281601, 58.63032191991806, 56.30463771522045, 56.248009353876114, 55.13593062758446, 53.44525694847107, 50.57952292263508, 51.07058197259903, 48.81489761173725, 50.14577239751816, 56.62295423448086, 58.422609865665436, 55.612881034612656, 53.46073731780052, 51.49306230247021, 50.85906632244587, 49.45552043616772, 49.094589203596115, 48.074758127331734, 49.529548063874245, 47.29374423623085, 48.21126200258732, 46.31877355277538, 45.293672159314156, 52.81050480902195, 49.70277316868305, 40.65774232149124, 41.61179892718792, 38.206098675727844, 41.29452735185623, 38.96481156349182, 41.461300402879715, 43.45916099846363, 48.14654007554054, 49.59907293319702, 53.7382098287344, 52.10826829075813, 50.742002204060555, 49.24398958683014, 50.731636360287666, 51.01834997534752, 56.175832226872444, 49.7841951996088, 53.46637241542339, 57.45355546474457, 54.412327855825424, 58.262828439474106, 51.257946118712425, 50.06341941654682, 49.77704398334026, 45.01830093562603, 45.821490436792374, 44.701470136642456, 49.37216430902481, 58.252914771437645, 54.13759499788284, 52.638499438762665, 56.10234797000885, 53.05325098335743, 54.81398530304432, 52.18785502016544, 54.789936393499374, 53.73686470091343, 51.16050414741039, 52.02458158135414, 51.38717718422413, 48.58220189809799, 45.10437771677971, 45.04673480987549, 40.18005095422268, 41.079781875014305, 42.256468534469604, 39.76898141205311, 40.60156233608723, 38.30120377242565, 43.810148164629936, 47.34469190239906, 41.10525190830231, 45.61372898519039, 47.083801701664925, 44.681308418512344, 46.54005467891693, 52.84449778497219, 51.003184989094734, 48.546985387802124, 47.799915075302124, 46.51285193860531, 49.39308978617191, 54.94952403008938, 54.504461511969566, 60.553132742643356, 60.941563099622726, 61.01754382252693, 43.36075387895107, 52.53547176718712, 51.511738300323486, 56.19614593684673, 61.20790980756283, 58.53057727217674, 60.345424488186836, 60.6613889336586, 60.03528133034706, 64.02285575866699, 62.62685626745224, 64.40264537930489, 63.33329916000366, 69.48138445615768, 64.46161821484566, 69.68184649944305, 67.44533210992813, 72.40235611796379, 66.74879148602486, 70.02638161182404, 59.262326806783676, 69.66464102268219, 7.878791727125645, 0.2232285958598368, 3.79765254445374, 6.168058924376965, 0.3527356660924852, 10.207269731909037, 84.01735246181488, 78.30982312560081, 78.0334335565567, 79.1291731595993, 79.82749208807945, 61.57086253166199, 85.26125371456146, 38.024270832538605, 58.98267701268196, 84.67674627900124, 58.48632864654064, 1.072142869234085, 0.22003379854140803, 0.33259294694289565, 0.1862263446673751, 0.1084877856192179], [0.02830069584888406, 0.11033013011910953, 0.010422670948173618, 0.04833128761674743, 0.03189877621480264, 0.19324772962136194, 0.17167501064250246, 3.786438633687794, 60.669376105070114, 55.288454443216324, 39.34384882450104, 28.481536991894245, 36.856494694948196, 37.05661095678806, 66.4495499432087, 61.376768946647644, 65.7131190598011, 53.44954311847687, 68.41374814510345, 9.856884833425283, 0.6361975462641567, 0.15947206935379654, 2.2650907561182976, 0.8889872347936034, 0.0584076715313131, 33.93570922315121, 56.889528930187225, 49.7739889472723, 59.50731486082077, 58.51616084575653, 55.56787624955177, 53.88731002807617, 53.92456702888012, 53.83878283202648, 57.140900641679764, 57.46918402612209, 59.22692030668259, 55.602591186761856, 54.35150071978569, 53.703665882349014, 48.55746142566204, 48.760963305830956, 51.66720695793629, 52.65985049307346, 54.27887141704559, 54.96397465467453, 54.47890788316727, 56.03345766663551, 54.88292880356312, 52.07701496779919, 55.37400685250759, 52.19971418380737, 52.117171213030815, 51.52946814894676, 54.92824897170067, 52.83122889697552, 48.86285863816738, 47.03179009258747, 46.02112412452698, 43.65698218345642, 40.922641307115555, 42.052472680807114, 49.43032778799534, 44.31186944246292, 37.01001025736332, 39.77132588624954, 39.07294236123562, 36.95718929171562, 36.4779020100832, 36.02365158498287, 38.47985878586769, 37.98827536404133, 40.31715139746666, 42.805888652801514, 45.269934833049774, 44.92328703403473, 48.74111697077751, 45.55093355476856, 46.7970234900713, 46.07225798070431, 49.02896672487259, 48.733069002628326, 48.51483531296253, 53.813951164484024, 49.96736437082291, 52.30923570692539, 42.663103714585304, 40.18420413136482, 40.326023921370506, 35.406823083758354, 34.39557194709778, 37.94256001710892, 53.3264335244894, 50.5629900097847, 52.68421098589897, 49.88172076642513, 49.38207797706127, 49.729949310421944, 52.485029473900795, 47.49857984483242, 48.79989981651306, 47.39793464541435, 46.27446033060551, 46.09362043440342, 45.79217500984669, 45.71039579808712, 41.455254927277565, 38.30512136220932, 37.459852918982506, 35.901586934924126, 37.61371806263924, 36.6111608594656, 36.53314344584942, 39.017415940761566, 34.374543875455856, 39.722080528736115, 49.07769151031971, 42.289458364248276, 43.70538778603077, 40.28149411082268, 42.40175373852253, 46.34540632367134, 44.928823336958885, 43.15871112048626, 47.55604796111584, 45.701454877853394, 50.645001009106636, 44.550416842103004, 47.940059155225754, 49.47354666888714, 51.4720456302166, 54.018539786338806, 51.58964931964874, 27.18901164829731, 58.427883982658386, 56.522312834858894, 53.3827693015337, 55.33051438629627, 55.13025753200054, 57.527651488780975, 59.87861193716526, 58.20893593132496, 57.80535198748112, 57.182352617383, 54.5756658911705, 58.10473792254925, 58.312031999230385, 60.79003483057022, 58.71852658689022, 64.28776994347572, 62.5526462495327, 58.67427036166191, 56.07671834528446, 56.94122135639191, 1.3648036401718855, 0.21961349062621593, 2.7428053971379995, 0.964293850120157, 0.13837977225193754, 8.403791505843401, 70.47102615237236, 62.82294474542141, 70.8899612724781, 65.40811702609062, 69.7627441585064, 46.54352769255638, 35.31505420804024, 39.628362357616425, 45.18266871571541, 71.51871353387833, 25.658050999045372, 0.5857366102281958, 0.037177698613959365, 0.04169450214249082, 0.10669871247955598, 0.01516140075182193, 0.07428159064147621, 0.06836669592303224, 0.14911346894223243, 0.10592877879389562, 0.08062267108471133, 0.25578873697668314, 0.035369659890420735, 5.696976827457547, 71.29318043589592, 60.92871218919754, 45.7110645622015, 27.656567059457302, 47.21931383013725, 41.540123373270035, 73.66401761770248, 66.68449133634567, 74.20380905270576, 59.266046807169914, 77.74751409888268, 9.647316578775644, 0.6824366119690239, 1.1970069003291428, 6.9891150668263435, 0.280375347356312, 0.025499431612843182, 37.98637546598911, 57.65725493431091, 52.94322408735752, 62.299047857522964, 60.21992862224579, 58.08906376361847, 54.27162140607834, 55.58515392243862, 55.47935999929905, 59.27466854453087, 59.31235112249851, 60.77958919107914, 58.025192990899086, 56.297969073057175, 53.42289514839649, 51.03902846574783, 49.783503636717796, 51.86326503753662, 53.6425119638443, 55.74790678918362, 55.570441111922264, 57.02778451144695, 56.73663653433323, 55.97258873283863, 52.48436450958252, 57.27194420993328, 53.633719235658646, 54.663855358958244, 52.34914496541023, 54.33567076921463, 55.65709546208382, 51.887716725468636, 48.20114314556122, 48.56028847396374, 46.4219456166029, 44.60364058613777, 45.0588371604681, 51.75620958209038, 45.37879139184952, 38.5476091504097, 42.02731043100357, 41.887238547205925, 40.134685188531876, 37.96945117413998, 38.53722430765629, 39.54421207308769, 39.259998723864555, 42.138473466038704, 46.621822491288185, 46.984862610697746, 47.74136781692505, 50.35033822059631, 46.94789059460163, 47.902672961354256, 49.985337406396866, 51.1189191788435, 49.546476155519485, 50.04097402095795, 53.6678110063076, 53.166663497686386, 53.28043319284916, 44.693270176649094, 42.81444199383259, 44.6813540160656, 38.02444942295551, 38.129772171378136, 42.61812172830105, 52.31782704591751, 53.76905657351017, 54.11329910159111, 52.28044465184212, 52.30871133506298, 51.97962999343872, 53.61561320722103, 48.411754444241524, 50.77935419976711, 48.69845665991306, 48.36982749402523, 47.89600811898708, 48.91571380198002, 47.00212508440018, 43.914121985435486, 39.8221405595541, 40.8663435280323, 38.400481045246124, 38.02087381482124, 38.19451689720154, 40.66691502928734, 40.16075178980827, 36.34437717497349, 41.33549675345421, 50.215453058481216, 45.63600338995457, 46.494840905070305, 41.9993781298399, 43.75354640185833, 48.34336191415787, 46.61518044769764, 46.089182272553444, 48.7621146440506, 48.711828142404556, 52.797646299004555, 49.04391132295132, 49.85680170357227, 53.309877812862396, 53.59129071235657, 58.140262216329575, 53.2431647926569, 32.16945379972458, 53.98002125322819, 55.53986415266991, 55.64842812716961, 57.18144826591015, 57.85477213561535, 60.281648710370064, 61.516939625144005, 60.43049052357674, 60.50118952989578, 59.57596957683563, 59.075205847620964, 59.97764602303505, 60.2139363437891, 63.571451380848885, 62.13063329458237, 66.41304910182953, 65.18924117088318, 62.36355319619179, 57.628657668828964, 60.11058188974857, 1.3811611686833203, 0.08282674578367732, 8.317510485649109, 0.7743941713124514, 0.11324730483465828, 10.101695246994495, 79.27753239870071, 70.30407831072807, 76.82892858982086, 70.21228283643723, 79.23543825745583, 54.3028025329113, 47.14241735637188, 36.54784865677357, 51.36366784572601, 82.52693563699722, 33.01522761583328, 0.6401322945021093, 0.1267680258024484, 0.05033903828007169, 0.045063158686389215, 0.10965248249704018, 0.13476275227731094, 0.24861446960130706, 0.22269181528827175, 0.24524278880562633, 0.24368982994928956, 0.4251837363699451, 0.3720648429589346, 6.540829371660948, 83.84373977780342, 67.68174022436142, 55.28875082731247, 38.28757010400295, 55.3533473610878, 50.113922506570816, 81.90472662448883, 72.8051421046257, 79.08872812986374, 65.15601575374603, 84.97227922081947, 11.780337821692228, 0.9299568738788366, 0.85462003829889, 4.55463794991374, 1.9253019453026354, 0.2557572996011004, 41.87836982309818, 63.247602358460426, 58.3625540882349, 65.70199325680733, 62.97963693737984, 60.145475417375565, 56.717869341373444, 59.01433691382408, 57.466862350702286, 63.118295297026634, 62.50516399741173, 64.25077512860298, 61.03145867586136, 59.21100676059723, 56.15810997784138, 51.3774611055851, 50.746375769376755, 53.86946998536587, 55.42952947318554, 58.10471512377262, 59.297098740935326, 59.43361781537533, 58.68252731859684, 57.23494179546833, 55.754020661115646, 60.5560851842165, 56.557916924357414, 56.76176078617573, 53.918209969997406, 58.66468347609043, 57.98681505024433, 54.79771077632904, 50.487697049975395, 51.13961286842823, 48.58507074415684, 45.75345888733864, 47.292136922478676, 54.83593292534351, 47.7842865139246, 41.07990726828575, 45.81807442009449, 43.69467996060848, 42.12878778576851, 40.02328276634216, 40.52260637283325, 41.23020060360432, 40.34794494509697, 44.7762805223465, 45.37229374051094, 49.051165133714676, 51.2911107391119, 53.449934497475624, 50.96000790596008, 51.78968958556652, 51.313890516757965, 52.436365485191345, 52.93191209435463, 54.04750183224678, 59.0665727108717, 56.31134435534477, 56.43709100782871, 46.524323523044586, 48.30096758902073, 50.29120199382305, 42.688881531357765, 44.05264355242252, 44.69073571264744, 54.115901961922646, 55.97439743578434, 58.29722419381142, 56.02841153740883, 53.73174637556076, 55.66403388977051, 56.888335794210434, 49.48650777339935, 52.54229240119457, 50.59905007481575, 49.87141951918602, 51.00445792078972, 50.55798567831516, 49.768384248018265, 47.410781756043434, 41.86521492898464, 42.53726206719875, 41.287490129470825, 41.101718097925186, 40.541286170482635, 42.86316677927971, 42.610571533441544, 40.577300637960434, 43.65732416510582, 51.7585426568985, 47.25820854306221, 47.5632181763649, 45.303361639380455, 46.20750792324543, 50.86836442351341, 49.479778334498405, 48.20612087845802, 51.854726895689964, 51.13421715795994, 54.90472823381424, 50.00542312860489, 49.44108501076698, 55.56531518697739, 55.84644690155983, 61.395505741238594, 52.005214020609856, 40.89480400085449, 57.930779457092285, 50.9463894367218, 58.79497468471527, 58.780820444226265, 60.646394938230515, 62.28479862213135, 63.92884120345116, 61.08130440115929, 63.11516806483269, 62.272833064198494, 60.530903935432434, 62.323693335056305, 63.716090619564056, 66.06637850403786, 63.87412413954735, 69.7736419737339, 67.71077066659927, 66.35339990258217, 60.69215968251228, 66.26841366291046, 2.9280276456847787, 0.3209200326818973, 7.209366448223591, 6.959947356954217, 0.26453622383996844, 13.563343696296215, 82.51414552330971, 74.82037916779518, 81.87729209661484, 78.51109072566032, 82.45825812220573, 62.035285010933876, 55.50745569169521, 51.55524596571922, 64.00021657347679, 90.0985461473465, 43.15627545118332, 0.9309733787085861, 0.3371162182884291, 0.2662773913471028, 0.18901371775427833, 0.32580544240772724], [0.02827242002240382, 0.06477686823927797, 0.058363806892884895, 0.12469589011743665, 0.09948311490006745, 0.011223949240957154, 0.08978305180789903, 3.2111756270751357, 60.24051211774349, 55.20493112504482, 43.45352590084076, 23.32087241113186, 24.930730126798153, 49.676569774746895, 62.326292395591736, 59.61905166506767, 67.61781245470047, 51.370298489928246, 67.5845642387867, 13.85561166331172, 0.18928525474620983, 1.459748789202422, 6.3683889247477055, 0.5661114945542067, 0.1160704271751456, 32.47520439326763, 60.99857144057751, 56.20597220957279, 59.2138110101223, 57.8111656755209, 54.77072462439537, 50.984850972890854, 52.97773763537407, 53.36929142475128, 57.3553991317749, 55.42267844080925, 57.15869128704071, 56.90741457045078, 55.919684171676636, 54.996675699949265, 54.89188112318516, 53.15693601965904, 54.463290721178055, 57.408626675605774, 55.51049552857876, 54.660203754901886, 53.91274966299534, 54.00713659822941, 54.10897493362427, 52.346371114254, 53.23829345405102, 53.7415536493063, 53.929981738328934, 53.394385278224945, 54.20464999973774, 53.150008991360664, 60.701157599687576, 54.58731226623058, 46.709031611680984, 44.91889826953411, 42.41556599736214, 47.006050273776054, 47.83388905227184, 44.46911260485649, 46.405557096004486, 45.33349022269249, 37.138488963246346, 37.8877517580986, 38.54478970170021, 37.076069712638855, 38.32433693110943, 36.615393832325935, 39.21203009784222, 40.21103449165821, 43.464849293231964, 45.90968370437622, 46.49538807570934, 45.54823949933052, 45.99456734955311, 47.24997438490391, 48.19016553461552, 47.163080647587776, 46.102105379104614, 50.80548919737339, 49.845098331570625, 50.02737835049629, 42.02067218720913, 38.653167486190796, 38.44735532999039, 33.118585869669914, 37.61070102453232, 39.30988244712353, 49.959183409810066, 49.9987430870533, 52.3139588534832, 50.20347610116005, 51.014401987195015, 48.839493691921234, 52.4172069132328, 47.97230042517185, 48.27814221382141, 44.74297910928726, 47.500582337379456, 45.249647721648216, 47.67207473516464, 43.555447831749916, 39.823018312454224, 36.59153871238232, 37.372651398181915, 37.41986386477947, 38.545659855008125, 37.33569838106632, 37.75585703551769, 38.082875087857246, 43.100061267614365, 39.99811291694641, 45.49348063766956, 47.20225654542446, 44.28772173821926, 41.428105384111404, 45.57318516075611, 46.48821406066418, 44.50384274125099, 49.665816351771355, 50.749643594026566, 51.678480952978134, 52.57612198591232, 57.866661697626114, 62.9317557066679, 50.26563696563244, 54.62292015552521, 51.33007004857063, 54.30075444281101, 33.843883350491524, 47.54102736711502, 59.35382589697838, 52.49736361205578, 55.17220728099346, 56.656609028577805, 59.0587717294693, 54.302908927202225, 56.69784061610699, 61.236917451024055, 56.75581410527229, 52.410956248641014, 53.937528133392334, 55.601063668727875, 56.22126258909702, 57.91027955710888, 62.41429567337036, 63.01462545990944, 64.13774639368057, 66.09966471791267, 49.94344845414162, 0.18226956948637962, 0.12118559097871184, 8.245991673320532, 1.542701544240117, 0.09054943802766502, 9.610894583165646, 70.51049843430519, 63.91631707549095, 64.2103984951973, 65.02923935651779, 63.25560472905636, 46.6935208439827, 27.03397996723652, 31.18326611816883, 47.05773890018463, 71.59049928188324, 20.800216868519783, 1.3384195184335113, 0.33443890570197254, 0.10577874621958472, 0.08443663478828967, 0.06482036551460624, 0.001645216741508193, 0.037714200880145654, 0.034354413000983186, 0.13422874733805656, 0.11978202644968405, 0.1921777901588939, 0.10313347956980579, 3.356331163085997, 71.0700336098671, 62.43553273379803, 50.5370108038187, 32.55674421787262, 35.61330020427704, 53.60001504421234, 72.15389505028725, 63.31610128283501, 74.88557606935501, 55.98104327917099, 75.50206258893013, 16.492061242461205, 0.1904283551266417, 0.8954857173375785, 8.763154372572899, 0.2094426832627505, 0.05637341135297902, 36.62048935890198, 61.31753772497177, 60.099057108163834, 60.92902757227421, 60.656152814626694, 58.712389916181564, 53.378049954771996, 55.535790771245956, 55.70340357720852, 58.74819539487362, 57.936482951045036, 58.9424941688776, 60.06928190588951, 57.03096114099026, 57.647428661584854, 58.05636651813984, 55.59346787631512, 55.942931324243546, 58.01369860768318, 58.210501447319984, 56.8305104970932, 55.04608444869518, 54.622429981827736, 55.91761328279972, 54.52406086027622, 55.354810282588005, 55.15044204890728, 56.62437915802002, 55.17657704651356, 55.256520956754684, 53.66764761507511, 61.37497164309025, 56.560960561037064, 47.32324205338955, 46.52936965227127, 44.97526444494724, 47.51475937664509, 50.29163137078285, 45.19754871726036, 48.407605066895485, 45.86401775479317, 39.22193996608257, 37.426049932837486, 39.595098942518234, 39.07574661076069, 39.86170783638954, 40.4453831166029, 41.537482514977455, 44.54225108027458, 46.42901323735714, 49.823086112737656, 48.71516056358814, 47.2816988825798, 48.86894591152668, 49.3526865541935, 50.92153117060661, 48.93139936029911, 48.64926069974899, 51.998568177223206, 53.26575078070164, 53.05925466120243, 45.74275866150856, 42.2295393794775, 41.37702852487564, 34.77228373289108, 39.703301936388016, 43.67781266570091, 52.3585494607687, 51.840819641947746, 53.87040853500366, 53.45395848155022, 53.114834278821945, 51.27286031842232, 53.49443010985851, 49.73588839173317, 50.08547343313694, 48.23213808238506, 50.65283238887787, 46.99624679982662, 50.73838099837303, 45.00863045454025, 42.79814086854458, 38.98123048245907, 39.67784330248833, 38.2181516289711, 40.75642302632332, 38.528328984975815, 38.56487162411213, 40.31348459422588, 45.83777256309986, 42.02901653945446, 47.599909007549286, 47.78996340930462, 46.33064791560173, 44.72874887287617, 47.861486971378326, 48.439606949687004, 45.425943061709404, 51.042683869600296, 54.00971285998821, 55.27029521763325, 54.97374013066292, 56.43258444964886, 62.68430918455124, 53.58442448079586, 56.24861352145672, 53.93755853176117, 55.04151329398155, 40.99514901638031, 46.05699419975281, 57.18883126974106, 55.92813491821289, 55.85030749440193, 60.64812384545803, 59.02097135782242, 57.69710339605808, 59.326596558094025, 61.475221663713455, 59.72230352461338, 55.73420092463493, 54.78466607630253, 58.67591567337513, 58.49417522549629, 59.516460970044136, 68.85391652584076, 63.264735639095306, 67.32658848166466, 68.02192077040672, 54.89781640470028, 0.12366060895146802, 0.07530241477070376, 9.184534661471844, 1.8286192207597196, 0.052449583818088286, 11.525030471384525, 76.97537273168564, 68.2277861237526, 72.09372907876968, 71.5679968893528, 71.8029610812664, 50.7988091558218, 41.48308463394642, 33.98742064833641, 51.626165360212326, 80.71023032069206, 27.75424651801586, 1.0825465922243893, 0.17189263802720234, 0.06264345342060551, 0.15228373085847124, 0.06192085020302329, 0.10724810214014724, 0.16344782867236063, 0.22021182492608204, 0.26654141780454665, 0.22947209130506963, 0.20898127520922571, 0.288243864197284, 3.822366655804217, 85.11187613010406, 67.62233421206474, 63.611900210380554, 29.411877170205116, 38.346398547291756, 63.99520084261894, 73.2961593568325, 69.24871534109116, 81.96073561906815, 61.06216862797737, 81.0125344991684, 19.931914061307907, 0.16638995439279824, 4.012275477871299, 17.07288097590208, 0.6565052596852183, 0.3638534835772589, 41.93953134119511, 63.49126808345318, 64.31187584996223, 64.48257029056549, 64.49899300932884, 59.730058908462524, 55.90157054364681, 57.13319465517998, 58.55125196278095, 62.16399930417538, 59.726715087890625, 61.49553157389164, 61.68623574078083, 59.834120124578476, 59.096112325787544, 61.75372771918774, 57.09653042256832, 58.580195009708405, 61.19149088859558, 60.91190189123154, 59.550339952111244, 57.28262163698673, 56.79409705102444, 57.37890087068081, 55.71520574390888, 56.754571571946144, 56.99227161705494, 58.70756797492504, 57.13946811854839, 58.326456025242805, 54.93570417165756, 61.71784244477749, 59.73848685622215, 49.31468479335308, 51.956196650862694, 46.99681296944618, 51.63200564682484, 52.42693059146404, 47.27259077131748, 53.27944524586201, 49.655252918601036, 41.16820313036442, 39.76814165711403, 41.73134431242943, 39.9590016156435, 43.0097097158432, 42.04418532550335, 44.45097237825394, 46.80266238749027, 49.46807116270065, 51.21953397989273, 52.99965865910053, 50.519520342350006, 51.291251331567764, 51.138674318790436, 55.23741938173771, 53.92764486372471, 50.526732355356216, 55.724040269851685, 56.55753314495087, 55.346234142780304, 49.549622386693954, 47.498747035861015, 49.1032375395298, 40.55510222911835, 46.37124493718147, 45.079394057393074, 55.2157149463892, 53.84156808257103, 57.174000665545464, 55.623915642499924, 56.99264779686928, 53.80707733333111, 54.328815937042236, 50.28605706989765, 51.724709272384644, 51.13972306251526, 53.12149152159691, 47.808988988399506, 53.054018542170525, 47.16338463127613, 46.06613650918007, 40.30176982283592, 42.10137225687504, 41.391859129071236, 43.66762161254883, 39.656154066324234, 42.42484129965305, 42.11881712079048, 48.11561733484268, 45.23135170340538, 49.35755029320717, 50.571338161826134, 48.19064810872078, 46.26474045217037, 50.989414528012276, 51.20395101606846, 46.61418490111828, 54.77316789329052, 55.115837305784225, 56.97603888809681, 57.331699803471565, 56.72060899436474, 64.2517402768135, 54.98213768005371, 58.954193741083145, 56.47733464837074, 58.96661527454853, 39.72243390977383, 58.1657512485981, 62.07246981561184, 55.30475176870823, 58.312168791890144, 61.02837324142456, 63.0381765961647, 59.098103418946266, 60.81655740737915, 63.14968541264534, 61.75715893507004, 58.47258858382702, 59.94853958487511, 61.75559341907501, 62.89577163755894, 62.768539264798164, 70.80957278609276, 66.96976482868195, 69.35632556676865, 71.3730825483799, 59.27484713494778, 0.6797027180436999, 0.4441602743463591, 14.018579218536615, 7.358963470906019, 0.31226311752106994, 13.838351089507341, 81.16272523999214, 75.209189504385, 74.44688200950623, 79.10906463861465, 74.65827226638794, 62.65361063182354, 45.228551253676414, 41.03738754987717, 64.85519349575043, 89.8939499258995, 39.54675033688545, 1.672612891998142, 0.3661164699587971, 0.19394313683733344, 0.461899652145803, 0.19899195263860747], [0.028505218760983553, 0.044997437798883766, 0.03836621101072524, 0.05960592832707334, 0.09501756037934683, 0.07423033050145023, 0.09705634394777007, 2.0200153067708015, 58.223758935928345, 58.16839970648289, 40.70266351103783, 22.369357869029045, 26.384112238883972, 48.91360491514206, 58.21721188724041, 61.79585225880146, 69.06706988811493, 53.590268567204475, 67.26510018110275, 29.516576752066612, 0.10783820602227934, 1.342552627902478, 10.152971595525742, 0.11380860596545972, 0.2126671961741522, 21.991245858371258, 67.35366582870483, 56.6216205060482, 59.52293582260609, 55.96603788435459, 55.125853568315506, 50.85099935531616, 50.049272775650024, 49.409710094332695, 50.74241638183594, 57.60018199682236, 55.511179491877556, 57.57228009402752, 58.5660445690155, 58.06449428200722, 58.49328227341175, 57.4398609995842, 56.16620734333992, 52.83021815121174, 52.44546219706535, 52.19668574631214, 51.192019656300545, 53.63778881728649, 53.83645735681057, 53.27931225299835, 51.578846499323845, 52.49526992440224, 51.667187958955765, 52.27308064699173, 58.37609276175499, 63.429540395736694, 56.60862140357494, 53.60085479915142, 49.86920803785324, 41.21930278837681, 43.056234419345856, 45.76532945036888, 47.99888379871845, 50.01437544822693, 49.72744144499302, 39.49809014797211, 36.63580633699894, 38.09219978749752, 38.72813366353512, 38.38640660047531, 37.39024065434933, 37.84989058971405, 41.03313557803631, 39.05535690486431, 41.480010598897934, 44.28972043097019, 46.56742841005325, 46.901973858475685, 44.41205106675625, 47.05827847123146, 46.43931448459625, 48.24466221034527, 45.69060266017914, 50.44985108077526, 49.532481506466866, 51.62955477833748, 39.57464084029198, 36.14848628640175, 36.951318606734276, 32.36200466752052, 34.74739506840706, 38.528731763362885, 50.76349765062332, 51.44334577023983, 52.06539899110794, 48.589166924357414, 50.15297681093216, 49.16784167289734, 51.148663982748985, 46.37027598917484, 47.75383114814758, 42.99520969390869, 45.685043558478355, 47.72913247346878, 46.17930203676224, 42.3579078912735, 37.57224328815937, 38.27777802944183, 37.672071531414986, 38.451212123036385, 37.38462075591087, 37.95451037585735, 39.28402483463287, 37.62874245643616, 37.64945134520531, 46.941814720630646, 47.101672142744064, 44.851045310497284, 42.528826519846916, 42.760819271206856, 45.31667612493038, 45.321859046816826, 50.06796017289162, 52.15002045035362, 54.79292303323746, 51.70868173241615, 56.73873022198677, 68.43517139554024, 52.333839386701584, 53.3586709946394, 53.698007985949516, 51.45443357527256, 55.78734487295151, 52.131295055150986, 35.151077806949615, 39.22063283622265, 49.397516548633575, 46.532056108117104, 49.220943823456764, 53.7166003882885, 54.058000668883324, 58.419212847948074, 60.172583162784576, 57.68561281263828, 56.303448379039764, 51.75266057252884, 54.1219512373209, 57.541003972291946, 57.02850267291069, 63.20998437702656, 65.16759753227234, 64.55355048179626, 69.45748373866081, 44.448654502630234, 0.19160363503033295, 0.5162873805966228, 12.735173385590315, 0.9008348803035915, 0.41400215355679393, 13.259764686226845, 69.3046635389328, 66.31721824407578, 63.65183226764202, 67.27899983525276, 64.2923752963543, 46.344011798501015, 20.25987446308136, 30.58778867125511, 46.42318435013294, 63.69938671588898, 19.510963149368763, 0.8732699719257653, 0.19330646318849176, 0.10723166356910951, 0.14873571577481925, 0.02697566909773741, 0.057823861061478965, 0.13214564271038398, 0.09362118726130575, 0.011485863360576332, 0.10262605093885213, 0.08806309488136321, 0.06034656202245969, 2.2541516181081533, 69.27812576293945, 62.424684315919876, 52.88606755435467, 26.074312962591648, 36.11432991921902, 56.80468328297138, 62.63021528720856, 66.52116850018501, 72.85361990332603, 59.31030683219433, 72.90677905082703, 30.72697140276432, 0.1352919332566671, 0.8914101391565055, 7.315149921923876, 0.04348737507825717, 0.08194727852242067, 26.370850950479507, 69.7029809653759, 58.28669875860214, 63.31402279436588, 57.4649890512228, 56.7439017444849, 52.20348738133907, 50.36530941724777, 52.4152310192585, 54.830453619360924, 59.00275133550167, 58.8962734490633, 60.06322123110294, 60.12513130903244, 57.74501122534275, 60.85729122161865, 58.53916481137276, 57.277632504701614, 54.85981844365597, 54.7072946280241, 54.46783147752285, 53.76288950443268, 55.46483337879181, 56.01666636765003, 54.043732434511185, 53.140885680913925, 53.2744675129652, 51.98610104620457, 53.09010900557041, 58.81193317472935, 62.12192416191101, 58.03689256310463, 56.27316400408745, 50.871085077524185, 43.67234855890274, 45.031957402825356, 46.52255281805992, 51.178556978702545, 51.8002188205719, 52.137511521577835, 40.454384833574295, 38.60359154641628, 39.551937058568, 39.52714718878269, 39.02072936296463, 37.45055101811886, 40.857041627168655, 42.666097953915596, 41.288329884409904, 43.75682182610035, 48.32724317908287, 48.4918237477541, 49.65466395020485, 46.710266545414925, 49.161062836647034, 49.73669394850731, 49.1912180185318, 49.059114307165146, 53.19738104939461, 54.24333952367306, 54.00664642453194, 42.7343612909317, 37.57332623004913, 38.66189941763878, 34.53545764088631, 38.283850103616714, 41.70234426856041, 53.20388250052929, 53.28227989375591, 54.16700541973114, 51.310778483748436, 53.50104555487633, 51.198091730475426, 53.69026020169258, 49.783621430397034, 50.00463277101517, 46.558168306946754, 48.115533739328384, 49.24085855484009, 50.324176624417305, 43.50405178964138, 40.97390055656433, 40.460969880223274, 38.66360932588577, 41.18624836206436, 40.176600739359856, 40.31801775097847, 41.29649564623833, 36.850411221385, 39.75375562906265, 49.34269309043884, 48.37826684117317, 48.43804143369198, 45.70280760526657, 45.882898941636086, 47.271538227796555, 47.875352427363396, 52.580624744296074, 54.41415175795555, 55.29633902013302, 54.98425416648388, 55.139418840408325, 69.03553158044815, 56.39158084988594, 54.139783680438995, 55.78427463769913, 53.017548099160194, 55.567560866475105, 53.67948018014431, 37.58526138961315, 40.08718393743038, 50.09614706039429, 48.074647933244705, 49.878943115472794, 52.72769205272198, 56.65393017232418, 58.48431475460529, 62.18166075646877, 58.804075196385384, 58.90062041580677, 53.29262673854828, 57.30279855430126, 60.103928446769714, 59.7623685747385, 64.36033084988594, 67.82233268022537, 67.36434325575829, 72.06059485673904, 46.81162230670452, 0.061175021473900415, 0.1710378471761942, 11.724215783178806, 0.15036845550639555, 0.40832041937392205, 15.64407404512167, 77.06276804208755, 73.04437726736069, 68.8079845905304, 73.25136736035347, 69.72403943538666, 52.22511202096939, 34.72091808915138, 29.325469806790352, 54.32847395539284, 75.1976229250431, 25.8282932639122, 1.170082613825798, 0.23785972560290247, 0.12718141690129414, 0.11418784342822619, 0.02591985456092516, 0.14620916306739673, 0.18078015331411734, 0.18188299960456789, 0.20809302834095433, 0.1586322401999496, 0.24749614211032167, 0.1919722746242769, 2.674020300619304, 81.72057330608368, 71.47343516349792, 61.85735955834389, 26.268398948013783, 39.868425875902176, 62.891249880194664, 68.97984176874161, 74.43335473537445, 78.95548447966576, 64.79055136442184, 79.06317830085754, 36.69181153178215, 0.20863918965915218, 3.1849339976906776, 20.41058197617531, 0.2627037721686065, 0.3956849395763129, 30.913691483438015, 69.40127715468407, 62.149856463074684, 66.46042495965958, 61.73056796193123, 58.62762786448002, 55.68771801888943, 53.42335492372513, 54.982871040701866, 55.954216718673706, 62.42162548005581, 61.17751903831959, 61.46744728088379, 63.76587554812431, 61.47750534117222, 62.698136642575264, 60.25222688913345, 62.091297805309296, 57.52659894526005, 57.195173129439354, 57.3525682836771, 55.601732432842255, 58.414128720760345, 57.427321672439575, 55.2172576636076, 54.5047464966774, 54.11060884594917, 54.798949509859085, 53.816918805241585, 57.163969203829765, 62.230309545993805, 61.04850076138973, 59.40672665834427, 55.48941045999527, 46.54368348419666, 46.795298382639885, 49.169201999902725, 54.18647937476635, 55.92378795146942, 56.11369036138058, 41.48897811770439, 40.51989711821079, 39.97789420187473, 42.11620666086674, 44.148223623633385, 40.90652257204056, 42.4944269657135, 45.28923399746418, 44.43124383687973, 45.45307360589504, 50.57938992977142, 52.73921303451061, 54.57109473645687, 48.74370463192463, 51.565281227231026, 52.28882320225239, 53.3408347517252, 51.15571640431881, 56.414565816521645, 59.2215321958065, 57.47674182057381, 45.57059369981289, 44.783500134944916, 46.88428960740566, 38.573983535170555, 42.11971387267113, 43.15858192741871, 55.75658552348614, 55.39920710027218, 56.59339562058449, 52.000513672828674, 56.290354281663895, 54.14825342595577, 56.327151507139206, 52.42848850786686, 51.72036990523338, 48.02601054310799, 50.65693996846676, 53.22617970407009, 52.258911207318306, 47.36256614327431, 43.781307712197304, 42.81721964478493, 40.88744379580021, 42.819309532642365, 45.52490875124931, 41.71513058245182, 44.09735195338726, 39.7117754817009, 41.00214064121246, 50.850607976317406, 50.888013169169426, 51.37376010417938, 46.50828078389168, 49.12892796099186, 49.96047534048557, 49.61408972740173, 55.233847573399544, 58.31210799515247, 57.45751865208149, 58.33874076604843, 57.51238010823727, 66.38439103960991, 58.69581140577793, 56.18924170732498, 59.69326168298721, 55.76532885432243, 58.396334275603294, 52.825703993439674, 44.47690598666668, 48.095227628946304, 50.425501987338066, 49.118197336792946, 50.2385064214468, 56.07714772224426, 55.42479492723942, 60.10133698582649, 64.48513135313988, 61.51435196399689, 61.675786301493645, 55.964411571621895, 59.456477388739586, 62.76713714003563, 61.58726625144482, 67.0324918627739, 69.04069930315018, 71.62180200219154, 74.00916069746017, 50.386166498064995, 0.2066902504884638, 0.741661658976227, 28.777438513934612, 3.5617308039218187, 0.6652055459562689, 19.409497193992138, 81.44648641347885, 78.3658929169178, 77.16872155666351, 81.21446326375008, 76.63408264517784, 64.21662256121635, 34.62232477962971, 39.685800075531006, 64.61706027388573, 84.94957163929939, 35.26821792125702, 1.3420282560400665, 0.4605416703270748, 0.20767218607943505, 0.32452256593387574, 0.2014349098317325], [0.02680503821466118, 0.03186911628290545, 0.009050631924765185, 0.11177200431120582, 0.019924828302464448, 0.03874300680763554, 0.0911178118258249, 1.5707591199316084, 57.31631062924862, 61.18599258363247, 46.072744354605675, 43.26539799571037, 27.90219157934189, 45.17722740769386, 66.70031368732452, 64.7865691781044, 64.88159447908401, 56.38172797858715, 63.61071467399597, 42.03438185155392, 0.16847671038703993, 0.5045202432665974, 5.522179082036018, 0.5683163262438029, 0.33247901243157685, 14.89439707249403, 70.03113135695457, 57.65595160424709, 62.52372980117798, 54.91926245391369, 53.099133521318436, 50.11102706193924, 51.332627311348915, 50.94925828278065, 51.18897221982479, 47.80074343085289, 49.89986099302769, 51.738928109407425, 52.55179189145565, 50.46405851840973, 53.12664784491062, 53.61254297196865, 52.50924937427044, 52.00997896492481, 50.930297300219536, 47.839121371507645, 49.831704050302505, 51.284768879413605, 52.147371992468834, 51.7272437363863, 54.125291258096695, 54.320703372359276, 48.60341235995293, 50.04424564540386, 46.688227728009224, 40.01749187707901, 44.77018564939499, 54.89953391253948, 47.19614267349243, 42.996114045381546, 41.90409064292908, 45.57353854179382, 48.21788504719734, 48.817413076758385, 49.26883265376091, 43.623927757143974, 42.03797645866871, 36.14480808377266, 36.78282804787159, 35.890069752931595, 36.888374984264374, 37.43749491870403, 39.203993529081345, 39.041236862540245, 43.78977745771408, 39.83950562775135, 44.242781549692154, 45.69988176226616, 45.78538857400417, 45.92243582010269, 45.665098428726196, 42.972403317689896, 47.71992176771164, 51.616019904613495, 48.887241929769516, 50.57026281952858, 39.66931656002998, 32.44938097894192, 35.22034049034119, 32.31845140457153, 37.19193309545517, 38.359363451600075, 49.33668941259384, 51.38404235243797, 52.567154467105865, 50.809592977166176, 49.54754389822483, 47.10205592215061, 50.868410021066666, 47.181532457470894, 49.53074499964714, 43.86485382914543, 45.655245557427406, 45.08604750037193, 45.81484079360962, 39.397665336728096, 39.9897837638855, 36.84360958635807, 38.55349503457546, 37.14999854564667, 37.68703132867813, 34.27057005465031, 36.65299281477928, 37.82125152647495, 40.57043440639973, 42.14579947292805, 51.853081583976746, 48.10118950903416, 44.41326320171356, 43.231321424245834, 45.2239952981472, 48.82364094257355, 54.10364381968975, 49.5165641605854, 56.63537956774235, 51.397892609238625, 56.85734465718269, 52.45978742837906, 47.0251252502203, 55.624276623129845, 50.6060378998518, 56.8348840624094, 54.57828775048256, 53.194128423929214, 43.405219092965126, 40.87286397814751, 55.757740661501884, 52.16353252530098, 44.064092338085175, 51.724135503172874, 51.78625077009201, 59.4461153447628, 54.94090989232063, 56.478520184755325, 57.86092020571232, 53.035711124539375, 50.19521914422512, 59.61554065346718, 55.330833569169044, 59.34885956346989, 64.40577641129494, 62.40273289382458, 67.91544288396835, 37.913111597299576, 0.12973841250641271, 0.710942029254511, 5.000896928831935, 0.6573974993079901, 0.1597061872598715, 19.23177693039179, 73.38971793651581, 62.98113405704498, 62.535801753401756, 62.96299763023853, 66.6709716618061, 44.09962423145771, 23.24530016630888, 30.987016148865223, 43.63779701292515, 69.2864853143692, 15.048914831131697, 0.8754192909691483, 0.20805905282031745, 0.06059506646124646, 0.048516590759390965, 0.06906365422764793, 0.06978047982556745, 0.023177683833637275, 0.02535617855755845, 0.05842558326548897, 0.038152368579176255, 0.0863441769615747, 0.10611716556013562, 1.445538739208132, 66.7686416208744, 65.8941413462162, 53.06153453886509, 30.290118344128132, 30.354295000433922, 53.44430699944496, 68.93856838345528, 71.37787029147148, 69.71388638019562, 63.42471085488796, 68.55532854795456, 45.76070509850979, 0.12687473179539666, 0.2623680839315057, 6.571597745642066, 0.7751592365093529, 0.15123106859391555, 17.908547334372997, 75.9339702129364, 58.26203428208828, 63.929243981838226, 56.63790263235569, 56.81099854409695, 52.058319970965385, 53.56602966785431, 54.089516177773476, 52.38229438662529, 49.6019721776247, 54.04294587671757, 53.46642941236496, 53.596621826291084, 55.09569078683853, 55.75264513492584, 55.469142347574234, 57.95297786593437, 53.535369113087654, 52.486898973584175, 50.732989087700844, 50.77487803995609, 53.92084702849388, 54.441236704587936, 54.674107208848, 55.43648689985275, 55.72278633713722, 49.44792844355106, 50.27533024549484, 48.36310185492039, 41.77042901515961, 48.88360172510147, 54.35920670628548, 49.797737672924995, 44.84645515680313, 44.30824063718319, 47.94642001390457, 53.383339270949364, 51.79864950478077, 50.41930831968784, 45.72364188730717, 44.51562210917473, 38.14289286732674, 39.02959428727627, 38.94997715950012, 38.99646006524563, 38.74738723039627, 39.73439946770668, 42.24842816591263, 44.56384152173996, 45.546681582927704, 47.43400231003761, 47.96935178339481, 48.7325332313776, 46.113683357834816, 48.136561810970306, 44.93016466498375, 48.899298682808876, 53.1944590061903, 53.13901998102665, 52.355236038565636, 43.59220705926418, 35.95989100635052, 37.95491695404053, 36.164502426981926, 40.960441678762436, 39.981051832437515, 50.49151584506035, 51.788150668144226, 53.68153586983681, 53.86365629732609, 51.353207007050514, 50.58321252465248, 52.68426798284054, 49.611707255244255, 52.00149402022362, 47.5567851215601, 47.45437301695347, 48.90510097146034, 47.62695975601673, 39.196549728512764, 41.793015003204346, 39.29454267024994, 41.13437734544277, 38.857049345970154, 39.94438000023365, 39.268221482634544, 38.536946922540665, 39.645590633153915, 40.2459242194891, 44.023138135671616, 51.55441761016846, 48.95262122154236, 45.59842340648174, 45.4840799421072, 46.96582183241844, 49.97326925396919, 54.573336616158485, 52.17099152505398, 56.74079731106758, 53.520071133971214, 58.85136365890503, 52.78108298778534, 48.82865287363529, 56.35734848678112, 54.07767981290817, 57.6377771794796, 55.39156951010227, 55.93378521502018, 48.82254660129547, 43.971213921904564, 55.14100715517998, 52.520736157894135, 44.05769728124142, 52.077923119068146, 55.376719906926155, 60.33101186156273, 58.00896406173706, 57.54187032580376, 59.348354190588, 54.216193780303, 54.354266971349716, 60.615764781832695, 57.437885105609894, 62.53954075276852, 65.63015431165695, 65.37584155797958, 71.62872523069382, 42.42328338325024, 0.046056671781116165, 0.6013459945097566, 11.666455082595348, 1.4185500936582685, 0.194142819091212, 22.476322129368782, 77.29507237672806, 72.091775983572, 65.77812597155571, 71.67073577642441, 71.07531532645226, 53.572842702269554, 26.120358891785145, 30.20302701741457, 55.74836656451225, 79.16584879159927, 20.17927508801222, 1.0454913368448615, 0.2061975238029845, 0.12304574702284299, 0.10208912935922854, 0.08236866255174391, 0.21108683722559363, 0.08583836621255614, 0.09631717228330672, 0.18124365422409028, 0.13048232649452984, 0.20419756940100342, 0.1639753027120605, 1.7874588794074953, 78.39344143867493, 75.07662981748581, 68.78875002264977, 53.203646913170815, 42.5714336335659, 60.74914142489433, 75.12168779969215, 77.13405981659889, 75.84171876311302, 68.35274621844292, 75.47943860292435, 53.03175933659077, 0.2853622235124931, 1.5208744467236102, 12.887608855962753, 1.3308982970193028, 0.5614887457340956, 21.723601520061493, 76.87830314040184, 61.06807731091976, 66.52363076806068, 58.77101317048073, 58.36411200463772, 54.57067295908928, 56.19704648852348, 56.697855815291405, 56.79943576455116, 52.73436829447746, 55.82565441727638, 55.95869667828083, 58.77108916640282, 57.00701862573624, 58.018744736909866, 57.06771656870842, 59.18878175318241, 56.734634041786194, 55.3695534914732, 52.456432208418846, 54.6933151781559, 57.54026681184769, 56.22970953583717, 55.71053199470043, 58.197631537914276, 58.834431767463684, 49.22278292477131, 47.7651659399271, 50.73837719857693, 46.27091512084007, 49.492545649409294, 57.76001662015915, 51.302244141697884, 46.79510839283466, 46.55882187187672, 51.779616326093674, 55.86775615811348, 54.317975118756294, 53.173985704779625, 47.18942083418369, 47.75512307882309, 40.9400899708271, 40.204134061932564, 41.436278745532036, 42.11529850959778, 42.87486255168915, 42.96367518603802, 43.277473747730255, 48.95440712571144, 46.87536008656025, 48.89752797782421, 51.450956761837006, 51.43162339925766, 50.11801488697529, 53.095136135816574, 47.562545612454414, 51.135706678032875, 57.613754868507385, 56.07072986662388, 54.44744177162647, 46.39019452035427, 41.20669886469841, 45.31058885157108, 40.560486540198326, 46.272598430514336, 42.661070823669434, 52.770181372761726, 55.60028851032257, 57.59107008576393, 56.533222049474716, 52.56345346570015, 51.845713779330254, 55.252869352698326, 52.042387425899506, 54.07339744269848, 49.554227739572525, 49.578177854418755, 50.921721160411835, 49.98985156416893, 41.98955945670605, 43.951534777879715, 41.78653635084629, 44.511278942227364, 40.00926911830902, 41.83017320930958, 39.942069724202156, 42.105460837483406, 41.837769001722336, 42.837138175964355, 46.55108168721199, 55.27888275682926, 52.41942219436169, 49.32711012661457, 47.38721162080765, 48.96634228527546, 53.640159890055656, 57.708115205168724, 52.890961691737175, 59.09909896552563, 54.5283280313015, 58.65198835730553, 57.651638835668564, 49.73524622619152, 59.089561477303505, 56.583687141537666, 60.97779415547848, 57.3985306173563, 56.67840465903282, 51.34641297161579, 46.000875011086464, 57.84719154238701, 54.44593325257301, 45.85469305515289, 50.58216758072376, 54.07878555357456, 66.22692748904228, 59.84002500772476, 60.92532657086849, 62.49713122844696, 58.19749094545841, 56.99133686721325, 65.154959410429, 57.99586236476898, 65.470350086689, 69.58517208695412, 69.04737174510956, 71.2231881916523, 47.820779755711555, 0.1160899233946111, 0.9387235378380865, 24.04561512172222, 4.103643475100398, 0.2525755047099665, 26.237297616899014, 84.77636933326721, 75.00835508108139, 73.41335266828537, 77.58002668619156, 78.44051331281662, 60.52870385348797, 34.246027171611786, 40.83390086889267, 65.0663709640503, 90.88992968201637, 28.486647717654705, 1.5034764865413308, 0.379400824313052, 0.3078754513990134, 0.2274708604090847, 0.12721257226075977], [0.054031735053285956, 0.014589744805562077, 0.047750330704730004, 0.02056436107523041, 0.044095821140217595, 0.01848445324867498, 0.016331150727637578, 0.7923207781277597, 49.35679413378239, 70.38982450962067, 45.86760476231575, 46.235219836235046, 35.14290824532509, 46.40040837228298, 65.06126403808594, 65.30508935451508, 63.566443249583244, 59.847487807273865, 57.12443232536316, 56.540483459830284, 0.9311901452019811, 0.3508696099743247, 2.4645973881706595, 0.4635627754032612, 0.051671883556991816, 7.011939967051148, 70.17319813370705, 56.923392713069916, 61.56302735209465, 51.78509943187237, 51.240786239504814, 51.52977213263512, 58.298835307359695, 54.87401828169823, 55.31074024736881, 47.56417192518711, 48.79163146018982, 43.2940636575222, 47.221924290061, 44.910755306482315, 48.45301263034344, 47.620583698153496, 48.7128920853138, 46.74174785614014, 45.329686626791954, 43.276846781373024, 47.42592394351959, 49.836575388908386, 53.90555664896965, 54.24013249576092, 55.603301748633385, 54.43814367055893, 52.10589341819286, 44.63137909770012, 39.63307410478592, 51.28535784780979, 56.487008929252625, 51.97728931903839, 45.80384038388729, 44.46808286011219, 41.97852484881878, 45.460107028484344, 48.39071497321129, 47.80918277800083, 48.06292936205864, 41.966593489050865, 37.65933081507683, 37.085664197802544, 39.58475589752197, 36.86888962984085, 37.28734217584133, 37.61652231216431, 37.523146122694016, 37.97627940773964, 40.89022144675255, 41.905416771769524, 43.06453697383404, 43.16624991595745, 44.44642782211304, 43.74490186572075, 43.97667422890663, 44.488597959280014, 47.39654392004013, 51.47138826549053, 51.70253366231918, 51.16544008255005, 39.953841492533684, 34.13877412676811, 36.582301408052444, 33.26710470020771, 38.4506269544363, 39.552936404943466, 50.30833527445793, 50.44848695397377, 51.34011670947075, 49.6013680100441, 49.83119107782841, 48.19713816046715, 50.085614025592804, 46.89639575779438, 46.11602783203125, 47.88701020181179, 44.984399154782295, 45.35039931535721, 42.59995870292187, 40.47724060714245, 37.77243174612522, 38.685264363884926, 36.819834262132645, 37.30187639594078, 37.414464354515076, 36.94908432662487, 39.965632259845734, 39.34225291013718, 50.867840051651, 53.12100134789944, 49.14946585893631, 45.40143057703972, 42.017092779278755, 44.31474208831787, 47.55620375275612, 52.698790803551674, 53.5454385727644, 53.83640795946121, 52.810527607798576, 49.62784878909588, 52.104016318917274, 49.17293719947338, 51.64314664900303, 53.28699544072151, 54.715479388833046, 51.93501278758049, 51.46222695708275, 53.850121423602104, 55.094965025782585, 55.82598499953747, 56.642025411129, 53.33611160516739, 47.23262831568718, 46.23477146029472, 53.38059961795807, 61.0831169039011, 55.52953630685806, 56.943774819374084, 53.589109629392624, 52.926170602440834, 52.95531503856182, 55.94111882150173, 55.361292734742165, 60.10915316641331, 61.5818477421999, 61.92133292555809, 68.58404740691185, 39.03828822076321, 0.031965161324478686, 0.33940019260626286, 6.101562492549419, 0.5170591548085213, 0.24372962390771136, 25.415768399834633, 72.12256953120232, 64.4142347574234, 61.93604953587055, 65.90525954961777, 61.856337413191795, 42.42267161607742, 36.42532803118229, 31.98984883725643, 43.29720988869667, 69.44476202130318, 6.819642260670662, 0.5900185648351908, 0.11153281753649935, 0.04838211360038258, 0.0064863131774473, 0.041893969173543155, 0.06983113140449859, 0.058369154066895135, 0.03384445735719055, 0.03938288282370195, 0.01083943881894811, 0.04486599602387287, 0.1613597961841151, 0.7244929333683103, 57.80398026108742, 74.22086253762245, 56.1362611502409, 38.68848279118538, 32.05229848623276, 58.97950038313866, 67.98326924443245, 74.25855651497841, 66.41605094075203, 68.30519556999207, 61.159010231494904, 60.44090956449509, 0.8595468895509839, 0.07836498363758437, 2.654562732204795, 2.5387955317273736, 0.14541043405188248, 8.265390582382679, 75.04614025354385, 59.72521796822548, 65.16470208764076, 53.78666862845421, 54.06007915735245, 53.60785782337189, 58.92923288047314, 56.44023343920708, 58.58212910592556, 49.65332642197609, 49.70440328121185, 45.320297330617905, 48.49340446293354, 48.74662667512894, 52.344695404171944, 50.494240298867226, 50.26490740478039, 48.38907726109028, 46.75465576350689, 45.60038410127163, 49.21870954334736, 51.32928729057312, 55.20517811179161, 55.04758536815643, 57.74115063250065, 55.95388613641262, 53.768057227134705, 45.3326428681612, 41.58532194793224, 50.65511606633663, 59.4530575722456, 54.367634654045105, 49.81841616332531, 45.95912665128708, 42.19449386000633, 47.78444990515709, 51.24464303255081, 50.32020203769207, 50.4004043340683, 43.19808840751648, 40.0440638512373, 42.31447622179985, 40.26913337409496, 39.7571412473917, 39.58065211772919, 38.563625290989876, 41.11489199101925, 41.388454511761665, 42.9067238420248, 43.94561089575291, 45.278845354914665, 45.932102501392365, 47.09545947611332, 44.872251972556114, 46.54681831598282, 45.51268860697746, 50.52289076149464, 54.80346366763115, 52.59816460311413, 52.97213673591614, 44.23943392932415, 37.61030204594135, 38.48530389368534, 36.894276067614555, 41.19253322482109, 40.50210267305374, 50.134373009204865, 55.38759112358093, 54.79515731334686, 51.56098745763302, 51.751121655106544, 50.01947097480297, 49.38254535198212, 49.65100854635239, 48.44229340553284, 48.17585550248623, 46.54264234006405, 48.28006491065025, 45.425430089235306, 41.409121602773666, 40.99753148853779, 39.63198736310005, 40.29620312154293, 38.264144361019135, 38.47585380077362, 38.55042479932308, 42.862733602523804, 42.21766881644726, 52.06765227019787, 56.030414029955864, 51.90130099654198, 47.081434428691864, 44.88316498696804, 46.67729951441288, 48.31857204437256, 52.88426645100117, 54.87571679055691, 55.48622243106365, 53.84722217917442, 52.604559659957886, 52.85406567156315, 49.24836315214634, 52.22644194960594, 54.564547687768936, 56.22073821723461, 55.38257159292698, 54.07519854605198, 56.138343438506126, 57.70353265106678, 56.69483117759228, 59.25258792936802, 55.85158422589302, 49.524669125676155, 50.903953313827515, 55.022119134664536, 63.03219951689243, 58.83490294218063, 60.10591574013233, 54.886322021484375, 56.18118613958359, 56.51207238435745, 59.38630275428295, 58.97826544940472, 63.589880391955376, 63.69106896221638, 67.30727791786194, 69.76308614015579, 46.415014788508415, 0.0236943262279965, 0.25246637931559235, 5.149254743009806, 0.5321137688588351, 0.13201483176089823, 28.541835956275463, 77.55993336439133, 71.39068320393562, 66.33264541625977, 72.48098909854889, 72.03254476189613, 54.1693726927042, 31.188525035977364, 29.741044007241726, 53.07598136365414, 78.19454491138458, 10.59568203985691, 0.7861748454160988, 0.17753486026776955, 0.11610755682340823, 0.08341320572071709, 0.06342148393741809, 0.13667167484527454, 0.2953457128023729, 0.11216171347768977, 0.13362760771997273, 0.16730377567000687, 0.1725035294657573, 0.3079705056734383, 1.013455493375659, 66.56663686037064, 85.02369806170464, 65.36862954497337, 58.795791640877724, 49.993286579847336, 65.92767834663391, 73.277547955513, 78.57463091611862, 73.02694380283356, 72.49019220471382, 67.77469083666801, 67.21233621239662, 2.1875948645174503, 0.577945247059688, 9.760832637548447, 2.4614475946873426, 0.2549085795180872, 10.29982041567564, 76.19899079203606, 60.29161557555199, 68.23543131351471, 56.018444672226906, 56.74823351204395, 56.468142941594124, 61.689773350954056, 57.6680463552475, 61.36122778058052, 51.156442165374756, 53.26710730791092, 46.4217746257782, 52.121776565909386, 50.816383212804794, 53.14396731555462, 51.26694783568382, 53.601588159799576, 49.94751803576946, 49.4222342222929, 47.22889691591263, 53.85883055627346, 54.06730256974697, 58.122049793601036, 61.02879501879215, 60.24145446717739, 58.422207087278366, 55.52184171974659, 47.51075439155102, 43.84130269289017, 51.03303998708725, 60.674855411052704, 55.973390489816666, 53.079640567302704, 49.39022473990917, 45.74487894773483, 49.607592076063156, 54.6330352127552, 54.51095536351204, 53.399154022336006, 45.82136884331703, 41.92703381180763, 44.663103595376015, 45.21700367331505, 43.30119967460632, 40.38732223212719, 41.42127335071564, 43.60148996114731, 42.9652900993824, 46.84765197336674, 46.57754346728325, 46.76301911473274, 49.06067602336407, 50.36252036690712, 47.67401643097401, 47.938816621899605, 49.44773085415363, 53.66928532719612, 57.976331412792206, 57.75123909115791, 55.25648295879364, 45.95415651798248, 45.0283931940794, 45.288534834980965, 40.69987826049328, 45.77928990125656, 43.853614032268524, 52.74963587522507, 57.238958179950714, 58.00106808543205, 53.65483470261097, 53.96672196686268, 53.74526984989643, 51.23503714799881, 52.499331906437874, 50.37235043942928, 51.0257063806057, 49.5152722299099, 51.191993057727814, 47.88052774965763, 44.378107488155365, 43.04983176290989, 42.66758367419243, 42.60878182947636, 40.57623289525509, 40.793987810611725, 41.003599762916565, 44.2227528244257, 43.08970682322979, 56.54132701456547, 58.35053913295269, 54.78313855826855, 49.20739375054836, 47.21985340118408, 51.01371422410011, 52.1700681746006, 56.407612189650536, 57.12687559425831, 57.53652021288872, 55.685795322060585, 53.28631907701492, 57.0569783449173, 51.76690600812435, 53.0067490786314, 55.056051313877106, 58.808912336826324, 57.16911032795906, 56.27259783446789, 57.064881920814514, 59.68525551259518, 60.53425915539265, 61.77285589277744, 58.515993654727936, 50.34044735133648, 54.4315168261528, 59.289320558309555, 67.10031822323799, 60.62856249511242, 62.46356762945652, 59.34352844953537, 58.34688752889633, 59.6044984459877, 62.152482122182846, 59.23459969460964, 65.03498464822769, 67.64686569571495, 71.56387031078339, 74.98545750975609, 49.78338964283466, 0.1814360634307377, 0.9073958813678473, 10.354560278356075, 1.9167209370061755, 0.4176393005764112, 32.23859868943691, 82.87150114774704, 76.5946863591671, 73.62383857369423, 78.89813795685768, 75.34095123410225, 61.52904577553272, 53.621962666511536, 44.1232817620039, 62.87585690617561, 93.59318822622299, 15.482601709663868, 1.176012670621276, 0.33830068598035723, 0.2550331415841356, 0.20124684961047024, 0.17589217575732619], [0.03737495033419691, 0.017871617383207195, 0.020523218263406307, 0.026624429156072438, 0.03846188868919853, 0.07470710843335837, 0.18728354887571186, 0.29356918937992305, 43.95659230649471, 65.73017254471779, 37.72075451910496, 27.55186937749386, 24.669617637991905, 46.91964291036129, 62.949253767728806, 62.086931839585304, 62.000615671277046, 62.967553585767746, 54.16656084358692, 60.709319561719894, 2.0991543726995587, 0.24817688448820263, 2.4337803293019533, 1.6821877844631672, 0.106302457570564, 2.116757878102362, 63.37872952222824, 60.20838864147663, 61.6078345477581, 52.09338068962097, 51.12553082406521, 53.61942060291767, 62.00471185147762, 59.090671017766, 58.37446644902229, 53.006418496370316, 52.783609852194786, 46.64482645690441, 45.09658433496952, 41.58126376569271, 44.57168810069561, 46.290339678525925, 47.62400731444359, 45.749081522226334, 44.68517281115055, 40.396312549710274, 42.597367241978645, 47.416629642248154, 50.48018865287304, 50.876925364136696, 52.87594489753246, 51.791904866695404, 52.25078344345093, 50.793094262480736, 54.76779118180275, 50.171770602464676, 53.87402594089508, 49.64959502220154, 46.00021004676819, 43.61585699021816, 43.2960357517004, 45.293181985616684, 47.46026270091534, 46.597777381539345, 44.379935190081596, 38.69482845067978, 37.656807750463486, 37.84416049718857, 36.60239093005657, 37.50308319926262, 36.98265552520752, 36.51764787733555, 37.74527460336685, 38.52257989346981, 40.2447234839201, 40.682235807180405, 40.69246105849743, 42.33138911426067, 43.968402072787285, 44.1400920599699, 43.473752215504646, 41.71663910150528, 48.057111874222755, 52.12871499359608, 48.88330154120922, 49.17436972260475, 41.44591502845287, 37.43122145533562, 36.3972133398056, 38.21530178189278, 42.265626043081284, 43.01593378186226, 49.43940930068493, 50.07853500545025, 47.939477786421776, 50.59244982898235, 46.06474578380585, 47.324233800172806, 48.171402141451836, 46.19904197752476, 45.756593719124794, 45.31666852533817, 45.37309169769287, 43.226115703582764, 41.76741577684879, 41.2871253490448, 38.256468772888184, 37.400538101792336, 36.9263881444931, 37.27646715939045, 37.197332605719566, 36.547134295105934, 35.94232454895973, 40.85431717336178, 40.995821580290794, 43.789549469947815, 46.68565906584263, 47.1269977837801, 44.185070246458054, 43.24673719704151, 48.48078913986683, 53.078500628471375, 53.785217106342316, 53.39131124317646, 53.41740444302559, 52.44864642620087, 48.83593328297138, 47.7210047096014, 51.905628964304924, 51.99327506124973, 54.623946100473404, 53.77217620611191, 53.50749380886555, 53.11375893652439, 51.797034591436386, 55.78495480120182, 51.918122693896294, 56.59338802099228, 51.50070749223232, 53.37425775825977, 56.04448467493057, 56.6156130284071, 55.57443089783192, 55.44068947434425, 55.00680595636368, 55.838125348091125, 58.42827156186104, 57.21115507185459, 57.05155223608017, 56.404344365000725, 59.122764095664024, 62.95676216483116, 65.87208732962608, 45.9959352761507, 0.23185817030025646, 0.3176188113866374, 6.388455647975206, 0.15132698375964537, 0.14311698992969468, 33.36589939892292, 67.44027078151703, 65.47025889158249, 58.59441764652729, 65.95981702208519, 47.520364075899124, 40.20574137568474, 39.68670442700386, 40.66821835935116, 47.5236015021801, 58.85754592716694, 2.4549972033128142, 0.23391622002236545, 0.02907371315814089, 0.038408027321565896, 0.10186201732722111, 0.07567926251795143, 0.016864044300746173, 0.044371068870532326, 0.011657094455586048, 0.02787328186968807, 0.054844331098138355, 0.07695750056882389, 0.2146264660404995, 0.43489871663041413, 51.71404704451561, 76.56667426228523, 45.0556643307209, 39.015622437000275, 31.244598627090454, 54.109590500593185, 65.87602391839027, 70.25252267718315, 66.65290743112564, 67.9088844358921, 59.38130982220173, 67.40136846899986, 2.630619267001748, 0.22504246415337548, 0.9144672425463796, 4.753454206511378, 0.11285434506135061, 3.1052332744002342, 67.49351352453232, 62.20830112695694, 64.72666919231415, 54.2588122934103, 54.38832454383373, 54.78751592338085, 63.30801911652088, 59.749259278178215, 59.77436453104019, 56.690396815538406, 53.97234566509724, 48.680483624339104, 48.332057520747185, 44.70917992293835, 46.922709345817566, 47.21050210297108, 48.954008147120476, 45.58077335357666, 46.60437762737274, 42.01617702841759, 46.428751051425934, 49.73065607249737, 52.308988720178604, 52.18441620469093, 55.65690167248249, 53.916640654206276, 55.04270642995834, 51.79766155779362, 56.162361949682236, 51.39584071934223, 55.25941260159016, 51.07392959296703, 47.45089240372181, 47.23115399479866, 45.18357686698437, 48.381226882338524, 50.846944972872734, 50.952275320887566, 46.215582489967346, 40.98492756485939, 38.37106682360172, 39.35810185968876, 39.586310014128685, 38.18799264729023, 40.2944628149271, 37.60006919503212, 39.5750018209219, 39.68885511159897, 41.77243530750275, 43.08707736432552, 44.73650425672531, 44.793865978717804, 45.49935892224312, 47.07599692046642, 46.28505416214466, 43.50293084979057, 49.417720064520836, 52.308088168501854, 53.80619578063488, 50.58026388287544, 43.364451080560684, 39.726043716073036, 39.794523641467094, 40.93712233006954, 44.52030345797539, 45.32592482864857, 50.83160899579525, 52.9758757352829, 51.753686517477036, 52.58996084332466, 48.34289833903313, 51.65381647646427, 49.97193552553654, 48.18434424698353, 49.38628055155277, 47.50933326780796, 46.19805783033371, 45.6340578943491, 44.6672073751688, 42.99651302397251, 40.239620357751846, 39.5594796538353, 39.43764679133892, 38.84418323636055, 39.2479457706213, 37.620398104190826, 39.089995846152306, 40.561565682291985, 43.224694579839706, 45.264618918299675, 48.737845346331596, 50.435894429683685, 46.0101655125618, 44.44477491080761, 50.29886998236179, 55.1319370418787, 54.71076384186745, 53.921656385064125, 55.193622931838036, 56.05490371584892, 51.57214745879173, 48.713302463293076, 53.6107836663723, 53.54830741882324, 56.061063185334206, 55.241830945014954, 56.57287672162056, 55.27520835399628, 54.73184131085873, 56.372840255498886, 55.60372352600098, 57.6382939517498, 55.60671016573906, 56.460759937763214, 57.73334585130215, 60.29652111232281, 57.50848151743412, 57.215479239821434, 56.10297493636608, 57.13202811777592, 59.90202248096466, 60.73143817484379, 59.47905957698822, 59.2258145660162, 60.86792305111885, 66.42013192176819, 69.7281964123249, 52.80914828181267, 0.11885143263498321, 0.24034537113038823, 10.411626566201448, 0.17493015940999612, 0.036494685264187865, 37.43695914745331, 75.91665834188461, 71.72691196203232, 63.128269761800766, 73.14580142498016, 54.92564611136913, 50.52017390727997, 40.75766175985336, 38.92976604402065, 56.29115603864193, 67.97204464673996, 5.408061230555177, 0.5049974739085883, 0.08005241965292953, 0.05509442744369153, 0.12691042909864336, 0.09829357091803104, 0.10039035332738422, 0.11442038798122667, 0.13247616559965536, 0.12616531283129007, 0.147703982074745, 0.20993198122596368, 0.3117073082830757, 0.42187117505818605, 60.119321420788765, 85.70847451686859, 54.09317918121815, 42.07833409309387, 34.61367644369602, 63.830852061510086, 70.12243285775185, 75.09464085102081, 74.38755199313164, 76.67338773608208, 62.50859521329403, 72.46883735060692, 3.350526262074709, 0.34029988339170814, 6.649424694478512, 8.180989511311054, 0.1701247680466622, 4.204973112791777, 71.09299197793007, 63.194401413202286, 67.58669212460518, 56.281926333904266, 56.36951543390751, 57.37772673368454, 66.95629075169563, 65.17047017812729, 63.36633078753948, 59.08745639026165, 58.1815280020237, 49.77538727223873, 51.376978531479836, 46.63565754890442, 48.643473610281944, 49.72257010638714, 50.92521697282791, 48.74552093446255, 48.26765097677708, 44.478710889816284, 49.662309139966965, 52.17224545776844, 56.458993032574654, 53.86128142476082, 58.10153089463711, 56.85667209327221, 58.68110999464989, 54.70581650733948, 57.712180987000465, 52.463678419589996, 56.54593996703625, 53.819327875971794, 51.73679642379284, 49.47431042790413, 48.04491072893143, 50.28839774429798, 54.60214287042618, 53.23043167591095, 48.58749881386757, 43.01137022674084, 40.945443883538246, 41.908942982554436, 40.68894624710083, 40.26656851172447, 42.92888045310974, 40.52060008049011, 41.73590786755085, 43.53569649159908, 44.34262119233608, 44.05626855790615, 46.68535128235817, 47.03672222793102, 49.20852608978748, 51.09515905380249, 48.94274555146694, 48.339767307043076, 52.54773750901222, 55.95852568745613, 55.19661337137222, 54.43624757230282, 47.360575050115585, 46.413213685154915, 44.2426485568285, 44.97233860194683, 48.70327100157738, 47.40875646471977, 54.472748413681984, 56.97953090071678, 53.23488123714924, 54.218177273869514, 51.083242893218994, 52.01322019100189, 52.260119542479515, 49.43049497902393, 50.70458561182022, 51.957416385412216, 49.24886092543602, 48.983874544501305, 47.664813324809074, 46.922006383538246, 44.47562925517559, 40.33430367708206, 41.225036680698395, 39.55886788666248, 41.095003858208656, 39.62719962000847, 40.92515677213669, 44.36359986662865, 45.56810863316059, 47.19608947634697, 52.722733318805695, 52.48517766594887, 48.47738452255726, 46.52128368616104, 52.642538622021675, 56.48412488400936, 55.61663903295994, 55.60465827584267, 57.738095596432686, 56.407577991485596, 53.51078823208809, 51.63271240890026, 55.22600099444389, 54.549667686223984, 57.9121870547533, 58.270975202322006, 59.20166686177254, 56.53130695223808, 57.2864556312561, 60.539814457297325, 58.569836765527725, 60.3451357036829, 57.11816646158695, 57.61036925017834, 59.10637557506561, 62.7796346694231, 59.93298701941967, 59.8446037620306, 56.709107011556625, 60.54692767560482, 63.46451371908188, 62.45406053960323, 61.67202830314636, 61.546498239040375, 63.01657475531101, 70.83382308483124, 72.05722823739052, 56.933750957250595, 0.47245135938283056, 1.3151867338456213, 17.07595881074667, 0.2980921044945717, 0.2277956242323853, 41.23610928654671, 80.84071531891823, 78.88904124498367, 69.8415519297123, 77.67123699188232, 57.92363204061985, 60.961181446909904, 57.489174753427505, 52.078462690114975, 67.32100278139114, 83.5796007514, 9.444187078624964, 0.6759346264880151, 0.28950762294698507, 0.22262042068177834, 0.1998003147309646, 0.18207153480034322], [0.07986143536982127, 0.02359192840231117, 0.0364252499275608, 0.008907668307074346, 0.03649562408099882, 0.04869006035733037, 0.38914952776394784, 0.18183660053182393, 36.491326689720154, 68.76488730311394, 45.21318107843399, 31.638645082712173, 21.256598979234695, 44.72304917871952, 58.566356152296066, 61.285942420363426, 58.64702582359314, 61.20160974562168, 50.69700501859188, 65.30169233679771, 4.31321220472455, 0.0995280742063187, 0.7964085275307298, 4.548221519216895, 0.12283853197004646, 0.0423683128610719, 49.49840493500233, 66.01197302341461, 60.24776212871075, 55.81053502857685, 50.491846427321434, 55.01936808228493, 61.37219399213791, 59.01116408407688, 58.034555688500404, 56.72582611441612, 56.30305700004101, 54.8249439150095, 48.791901245713234, 43.68589103221893, 46.29642695188522, 46.92854963243008, 47.857155203819275, 46.71338617801666, 45.96808277070522, 39.71496731042862, 41.630797907710075, 42.905507907271385, 44.851664677262306, 48.877560049295425, 51.68904058635235, 50.06624646484852, 53.343809992074966, 52.53795303404331, 51.38795614242554, 51.149974912405014, 54.567857310175896, 46.47531375288963, 43.396969735622406, 44.36974033713341, 42.72457681596279, 46.173913925886154, 47.55745388567448, 43.34230586886406, 40.59773214161396, 41.085819751024246, 38.51717658340931, 37.263874635100365, 37.98805497586727, 38.043778985738754, 38.30610550940037, 37.4419254809618, 38.10650981962681, 37.23936215043068, 38.86821694672108, 41.00629761815071, 41.38323359191418, 41.75604298710823, 43.56468893587589, 42.90959648787975, 42.125466763973236, 43.144154101610184, 48.14874395728111, 49.29012291133404, 52.13457427918911, 50.5294644087553, 41.69407591223717, 39.86480847001076, 36.01487785577774, 40.36231577396393, 41.85324177145958, 44.4274478405714, 49.508341401815414, 50.65374054014683, 50.1270318031311, 50.843240171670914, 46.38426683843136, 46.43828473985195, 46.84554688632488, 46.53501994907856, 44.85957205295563, 47.014668211340904, 43.14229980111122, 42.82286614179611, 41.192863807082176, 40.11883243918419, 39.51839245855808, 38.78663532435894, 36.210369765758514, 37.77281552553177, 37.14332990348339, 37.87099085748196, 38.32574285566807, 37.97625280916691, 44.192848429083824, 46.019140630960464, 47.025421634316444, 47.9093150049448, 43.27227562665939, 43.46954584121704, 46.88027702271938, 52.5868222117424, 50.77414847910404, 48.97242955863476, 49.26336854696274, 51.12249478697777, 52.05856315791607, 49.76595617830753, 53.35926376283169, 54.05053786933422, 55.65226972103119, 53.98472920060158, 54.05713431537151, 52.50591695308685, 49.80068251490593, 48.50782088935375, 48.74974250793457, 56.07133783400059, 56.98363088071346, 60.10562315583229, 54.389270693063736, 55.67101411521435, 55.13995461165905, 57.41004019975662, 57.36545719206333, 57.147462889552116, 56.99984461069107, 59.49861712753773, 57.1279851347208, 56.47491417825222, 55.85787668824196, 61.85963183641434, 63.80824327468872, 51.3040566444397, 0.20295919210184366, 0.2113994595129043, 3.2938898261636496, 0.3105429676361382, 0.04011407640064135, 36.57271072268486, 71.53977200388908, 61.633262783288956, 60.50182029604912, 68.0321878194809, 47.069628462195396, 45.187999829649925, 29.45864126086235, 32.44360148906708, 56.678286865353584, 49.82832223176956, 2.558223414234817, 0.15098739182576537, 0.025623925030231476, 0.07586020554299466, 0.03158720406645443, 0.04585112656059209, 0.10261632138281129, 0.047726600532769226, 0.008700394810148282, 0.028240385217941366, 0.05287884203426074, 0.03611321393691469, 0.42280153138563037, 0.16274887399049476, 41.87309950590134, 75.49912914633751, 50.66532611846924, 35.275452733039856, 34.27926018834114, 54.98458854854107, 59.46281924843788, 63.731867372989655, 66.98055624961853, 66.88053041696548, 57.06860572099686, 69.11751598119736, 4.484217753633857, 0.24872555426554754, 0.4583551548421383, 4.75367839448154, 0.4641440254636109, 0.28862319071777165, 52.307343408465385, 69.14103671908379, 61.34547382593155, 56.26508943736553, 52.783678248524666, 58.945602402091026, 63.47574591636658, 61.20481297373772, 59.03625413775444, 59.88777704536915, 58.48739638924599, 56.82666890323162, 49.932265654206276, 45.375040993094444, 48.36635448038578, 47.023776322603226, 50.04133120179176, 48.87982092797756, 47.168240770697594, 41.30895897746086, 44.29882474243641, 44.806291311979294, 47.81083568930626, 50.99838584661484, 53.01534801721573, 52.9961172491312, 55.75189657509327, 53.81863631308079, 53.89778986573219, 53.4946732968092, 55.775269120931625, 48.68423782289028, 43.720442578196526, 45.510306134819984, 44.957405403256416, 48.788188844919205, 50.297764241695404, 46.91191412508488, 43.667773604393005, 42.37855218350887, 40.86926557123661, 40.74533522129059, 37.738366574048996, 38.594282045960426, 39.6125628054142, 39.106494560837746, 39.47644650936127, 38.912541568279266, 40.98018541932106, 42.363212406635284, 44.5413239300251, 43.92698809504509, 45.11352762579918, 45.98388232290745, 46.600444838404655, 45.97836881875992, 49.92924101650715, 51.924050375819206, 54.16929669678211, 52.16795928776264, 43.438216522336006, 42.505313381552696, 39.663837254047394, 41.739377081394196, 43.62387835979462, 45.28568118810654, 51.89872473478317, 51.51604346930981, 51.768748909235, 52.09120720624924, 47.79505133628845, 50.45459322631359, 49.92197200655937, 48.88973839581013, 48.96381542086601, 48.3753751963377, 45.41261337697506, 43.896817713975906, 43.21132689714432, 41.88811630010605, 40.313647985458374, 41.78890362381935, 37.02597700059414, 38.43910597264767, 38.19408372044563, 40.63859894871712, 39.34573732316494, 39.840580970048904, 45.21042622625828, 47.94941805303097, 48.650009259581566, 50.71258418262005, 44.62898522615433, 45.244400203228, 49.00961436331272, 52.88442984223366, 53.70180398225784, 49.10886123776436, 50.438159108161926, 52.67872788012028, 53.039149940013885, 51.993628442287445, 54.12758633494377, 54.86526735126972, 58.655871748924255, 57.02958941459656, 55.84911435842514, 55.170539170503616, 52.086978033185005, 52.04575024545193, 51.174817979335785, 56.827641651034355, 59.15257729589939, 62.38154523074627, 56.50984950363636, 58.9432655274868, 57.18832589685917, 59.9176624417305, 59.36116710305214, 60.30822068452835, 60.51759324967861, 61.9869402050972, 57.900928258895874, 60.34962326288223, 59.61370535194874, 65.82823008298874, 68.61949190497398, 55.14816217124462, 0.4271411953959614, 0.21950311842374504, 9.81174135580659, 0.34922679187729955, 0.035699529689736664, 42.98471465706825, 77.42941036820412, 67.88185268640518, 66.54093503952026, 76.61316096782684, 49.23401892185211, 52.51416631042957, 42.18077279627323, 38.3841685205698, 63.293040320277214, 62.45878368616104, 3.7262624502182007, 0.33294466556981206, 0.035086771749774925, 0.10292012695572339, 0.04756656380777713, 0.039751963995513506, 0.16064178314991295, 0.10009552031988278, 0.08318179665366188, 0.12209055843413807, 0.0900210437248461, 0.20021523465402424, 0.6156393431592733, 0.25721686659380794, 46.44584633409977, 87.67891198396683, 59.0099785476923, 44.534286707639694, 30.55713001638651, 61.97251997888088, 65.58811336755753, 74.89556953310966, 69.43693444132805, 73.87222364544868, 59.87272225320339, 76.97411879897118, 6.026768255978823, 0.23571652185637504, 2.6260963222011924, 11.682199537754059, 0.19829670869512483, 0.24754157639108598, 55.95114268362522, 68.1696492433548, 66.30527168512344, 58.79846669733524, 54.72087889909744, 60.8009934425354, 66.76804885268211, 63.88929292559624, 62.57085107266903, 62.33314722776413, 61.878117844462395, 59.1021654009819, 52.29878626763821, 49.953916892409325, 51.328785717487335, 51.53835587203503, 52.84702084958553, 53.140585497021675, 49.87573988735676, 44.013448655605316, 45.83630584180355, 47.042589113116264, 48.75017188489437, 54.391900151968, 55.96559710800648, 54.29547652602196, 57.740709856152534, 55.99170930683613, 56.581088081002235, 54.449185878038406, 58.78463923931122, 50.40102370083332, 46.27482891082764, 48.838946521282196, 47.4086082726717, 50.646148547530174, 53.3881726115942, 48.93328405916691, 47.35669165849686, 46.411017403006554, 44.29021820425987, 41.38183146715164, 41.55051201581955, 41.79763935506344, 43.12181510031223, 40.82380101084709, 42.165623009204865, 40.76865456998348, 42.85983055830002, 44.198749512434006, 47.31712818145752, 48.0329679697752, 48.09757590293884, 49.21240948140621, 46.46229945123196, 48.20922911167145, 54.43924181163311, 52.84007482230663, 55.98590321838856, 55.736097022891045, 47.285335287451744, 46.67218878865242, 40.98032981157303, 44.475674852728844, 46.3710967451334, 47.46817767620087, 54.85419474542141, 55.786828100681305, 55.17704822123051, 54.03571866452694, 48.58339503407478, 52.187573835253716, 51.49672910571098, 51.02445624768734, 52.298391088843346, 52.01117590069771, 48.59071344137192, 46.762593537569046, 45.32846309244633, 43.481374606490135, 42.68325783312321, 43.93214821815491, 41.41656920313835, 42.082931846380234, 40.694094970822334, 40.974941700696945, 42.17699579894543, 41.96290388703346, 46.927383095026016, 51.68686330318451, 52.517099753022194, 53.56869712471962, 47.24046349525452, 48.2716179639101, 52.238612696528435, 55.471707209944725, 55.3068682551384, 49.695245772600174, 52.26253241300583, 53.104612827301025, 55.14354921877384, 54.9430263787508, 57.546551674604416, 57.46000751852989, 60.12546569108963, 59.04507726430893, 58.42101775109768, 57.22725100815296, 54.342525601387024, 54.216737151145935, 53.60767163336277, 60.654268115758896, 61.54410056769848, 63.95200476050377, 58.99075537919998, 60.16195133328438, 59.159173741936684, 63.179977387189865, 62.53155738115311, 63.95740807056427, 62.03177399933338, 64.51532453298569, 61.16402216255665, 63.264443054795265, 62.09358908236027, 68.80289286375046, 70.48562496900558, 59.80991542339325, 0.7768581609707326, 0.3355868300423026, 10.963817685842514, 1.0169999906793237, 0.17722824937663972, 45.79411670565605, 82.50386327505112, 71.64172813296318, 71.83093518018723, 81.6889514029026, 57.429362162947655, 65.24740844964981, 44.93104241788387, 49.257904440164566, 75.07556587457657, 77.78324738144875, 5.937646888196468, 0.7609851658344269, 0.19999842363176867, 0.2502430829918012, 0.20059065747773275, 0.1711774303112179], [0.057645103661343455, 0.07934616223792545, 0.04280321139958687, 0.06950972208869644, 0.12097948172595352, 0.02620034370920621, 0.4887784004677087, 0.16804950049845502, 26.36967111378908, 70.13016924262047, 49.04803790152073, 37.18757092952728, 17.448357827961445, 38.13273221254349, 65.48694759607315, 66.40697702765465, 55.966778844594955, 63.149852603673935, 49.80338416993618, 67.14194118976593, 15.874473731964827, 0.1789170509437099, 0.6671948579605669, 3.8816140266135335, 0.7264533312991261, 0.3625286906026304, 28.88115204870701, 72.06581577658653, 57.14077524840832, 56.8772441893816, 48.09109725058079, 51.821490079164505, 57.66869992017746, 55.91352090239525, 55.80147631466389, 50.21714776754379, 53.58002431690693, 58.12644615769386, 52.01220564544201, 43.92825722694397, 41.966369301080704, 45.191780626773834, 49.43162351846695, 48.6893979460001, 45.469249337911606, 41.317006945610046, 40.51232412457466, 42.20294080674648, 44.93086762726307, 49.26211841404438, 51.28894105553627, 52.041562870144844, 51.952389255166054, 54.141163006424904, 54.48392741382122, 56.43261484801769, 49.93181727826595, 43.92414964735508, 44.000757336616516, 43.706789910793304, 44.004332944750786, 45.889879167079926, 44.72898826003075, 45.13387933373451, 47.01379805803299, 47.97417372465134, 43.374740928411484, 40.116651356220245, 36.00895777344704, 39.66737486422062, 38.333999812603, 38.236516043543816, 37.26774662733078, 38.500544875860214, 37.31508068740368, 41.05626493692398, 39.154326394200325, 41.795750856399536, 42.81969711184502, 44.91875387728214, 45.0911620259285, 43.10065023601055, 44.392941892147064, 45.246011316776276, 50.09851053357124, 47.572664469480515, 43.834542855620384, 38.43001306056976, 38.82693596184254, 39.61412452161312, 41.577691957354546, 45.94678491353989, 51.76106572151184, 51.80787920951843, 49.11477752029896, 50.665082931518555, 45.05949832499027, 44.35505412518978, 46.26638576388359, 44.02764469385147, 43.80997337400913, 43.12966927886009, 41.93908676505089, 41.74086280167103, 41.19616962969303, 39.27545629441738, 37.27826066315174, 37.29277588427067, 36.991528049111366, 38.71292307972908, 37.85605005919933, 38.54398034512997, 37.99788124859333, 39.157423228025436, 39.88684728741646, 45.91241575777531, 50.05926623940468, 46.809764206409454, 42.14866451919079, 43.9615548402071, 45.58713421225548, 51.62209577858448, 53.018387854099274, 50.52653096616268, 49.83041971921921, 50.175175219774246, 50.89903637766838, 49.14450712502003, 52.23632901906967, 53.38203214108944, 53.70583176612854, 52.9879704862833, 52.00700372457504, 49.30676221847534, 47.44733579456806, 43.09286445379257, 48.1880946457386, 51.89879693090916, 53.36171083152294, 56.222413927316666, 56.80364213883877, 57.42440342903137, 57.296798676252365, 60.23750647902489, 57.511760741472244, 58.70143510401249, 61.07056237757206, 60.494657680392265, 58.16275700926781, 53.98105479776859, 55.775234922766685, 62.022772282361984, 65.32180085778236, 54.05526101589203, 1.42230951692909, 0.2095073094824329, 8.670107815414667, 0.4986840533092618, 0.3644217608962208, 41.34450986981392, 71.879792958498, 57.979546040296555, 56.04366771876812, 68.19587543606758, 52.22821645438671, 43.54043483734131, 25.165377035737038, 29.042377397418022, 53.112201020121574, 39.49074514210224, 0.21673768322216347, 0.08387786438106559, 0.028926988707098644, 0.056094797982950695, 0.12595492880791426, 0.04291569872293621, 0.03588999075873289, 0.023820407841412816, 0.047069807260413654, 0.01981832454475807, 0.04325154281104915, 0.07160002554883249, 0.5147242394741625, 0.10596476553473622, 33.75642344355583, 79.45165425539017, 56.09466478228569, 40.83605915307999, 23.462445214390755, 47.72109590470791, 69.6291433274746, 71.28137066960335, 63.09654526412487, 70.92465341091156, 56.28600351512432, 73.39448288083076, 18.240275233983994, 0.2770892658736557, 0.3613718308042735, 5.330482693389058, 2.318644607439637, 0.35454502212814987, 31.502908766269684, 73.45323532819748, 58.850064128637314, 60.396033972501755, 50.103579461574554, 54.56719994544983, 58.31786088645458, 59.18819658458233, 55.58698542416096, 52.00363710522652, 57.60241627693176, 57.772738337516785, 53.756293058395386, 44.32616427540779, 43.60253870487213, 47.890316024422646, 50.21330997347832, 49.76255156099796, 46.538728550076485, 43.7459772080183, 42.28694289922714, 43.961429446935654, 46.94324344396591, 51.52893237769604, 52.657468020915985, 54.80409063398838, 55.98970301449299, 55.32623201608658, 57.1063718944788, 57.57772900164127, 52.18596652150154, 46.468018144369125, 45.99243566393852, 45.582251474261284, 47.23073601722717, 48.53555180132389, 46.899545788764954, 46.99968941509724, 49.220712035894394, 48.47982779145241, 42.23155327141285, 41.0432468354702, 40.14483064413071, 42.62447498738766, 40.7782756537199, 40.33817186951637, 39.40234288573265, 40.19002161920071, 40.05441069602966, 42.73872725665569, 43.42512622475624, 43.23022708296776, 44.92575690150261, 46.22032083570957, 47.63691142201424, 45.626500099897385, 46.06918014585972, 48.36737662553787, 50.755233094096184, 49.74857211112976, 45.34332789480686, 41.35845132172108, 40.996353551745415, 42.002900540828705, 43.42318832874298, 46.19901917874813, 55.29009975492954, 55.07811293005943, 51.33958853781223, 53.28872434794903, 47.82639965415001, 45.73064871132374, 47.2781802713871, 47.36678011715412, 45.719120129942894, 44.956075474619865, 42.00317792594433, 43.88929791748524, 43.06086637079716, 40.25458015501499, 38.21968674659729, 39.54065926373005, 39.162438958883286, 40.64443923532963, 39.183550626039505, 40.88209368288517, 40.02457469701767, 40.46423390507698, 42.15709626674652, 48.820912688970566, 53.46866749227047, 49.112022668123245, 45.0505156069994, 44.823990762233734, 46.860768869519234, 53.945864886045456, 55.607967898249626, 53.32507699728012, 51.921983286738396, 51.75839066505432, 54.590545892715454, 52.060094475746155, 55.363401621580124, 55.32811291515827, 54.9227050691843, 55.224690064787865, 54.57074135541916, 50.54531715810299, 48.3933862298727, 47.07435540854931, 48.45093794167042, 53.40741477906704, 54.778445810079575, 57.94203445315361, 59.77892808616161, 59.63946416974068, 58.96376922726631, 60.64748927950859, 60.10683909058571, 64.01581093668938, 63.112550005316734, 63.65859590470791, 61.20003663003445, 58.128608241677284, 59.85232874751091, 66.16446644067764, 69.70808029174805, 60.58537781238556, 1.7577561107464135, 0.3265789680881426, 9.364557601511478, 0.44717015814967453, 0.24505009758286178, 47.321798130869865, 75.13378635048866, 64.93471562862396, 62.72405505180359, 75.08732244372368, 54.491040632128716, 55.37819802761078, 29.317195750772953, 33.32571655511856, 61.96306228637695, 49.00904819369316, 0.5585462192539126, 0.18241280398797244, 0.11126685407361947, 0.02094628882332472, 0.044477400078903884, 0.02776473163976334, 0.1632890387554653, 0.12055424595018849, 0.11653815090539865, 0.2183959083049558, 0.28644332487601787, 0.16035696171456948, 0.8546227100305259, 0.20222727122018114, 37.674944177269936, 91.1018519103527, 66.22365966439247, 51.157753095030785, 23.70214205235243, 57.396630719304085, 74.39475640654564, 78.49645391106606, 67.64317989349365, 76.7163634300232, 60.96133343875408, 81.30891099572182, 22.168348655104637, 0.24897812196286395, 0.9233074088115245, 11.693141050636768, 2.1366942208260298, 0.5009039060678333, 34.280859902501106, 75.91720551252365, 62.64436572790146, 62.82367430627346, 53.216262236237526, 57.20311850309372, 62.5595922768116, 60.32316528260708, 56.51105023920536, 53.97134251892567, 61.655643582344055, 61.55812941491604, 57.48094439506531, 47.556595131754875, 47.0860929787159, 49.53640289604664, 55.37746086716652, 52.14358739554882, 49.37972590327263, 44.79684881865978, 45.361509919166565, 44.76612366735935, 49.16094124317169, 54.02300074696541, 55.1658920198679, 56.36046811938286, 56.5799443423748, 57.410693764686584, 58.94212178885937, 61.855170875787735, 54.16763998568058, 48.534157276153564, 47.812796384096146, 49.794625639915466, 48.541977256536484, 48.06025430560112, 49.578941613435745, 51.453365832567215, 50.88732160627842, 53.35490919649601, 46.25709146261215, 44.542064890265465, 41.607147976756096, 45.70378415286541, 43.589987978339195, 41.60294160246849, 43.81702959537506, 42.56421402096748, 41.92291863262653, 45.141076147556305, 45.95800191164017, 47.25575767457485, 49.246885031461716, 48.8251418620348, 50.79348564147949, 48.37037466466427, 48.19760173559189, 48.30544374883175, 54.09203924238682, 50.709426552057266, 47.335690185427666, 43.67410786449909, 43.15835773944855, 43.91764059662819, 45.68856976926327, 48.62596794962883, 56.15035079419613, 57.39413045346737, 54.23277989029884, 57.058023288846016, 48.82741034030914, 48.522161319851875, 49.47564035654068, 47.18774512410164, 48.27098719775677, 47.74907000362873, 44.52133700251579, 46.34218789637089, 46.013361141085625, 41.92907050251961, 41.219599172472954, 41.499142572283745, 41.63542225956917, 41.50757811963558, 41.97678454220295, 43.56112092733383, 42.189907506108284, 44.18360732495785, 44.227046594023705, 51.739330887794495, 55.853818506002426, 50.27903124690056, 47.19632886350155, 48.21441203355789, 49.65668924152851, 56.45465366542339, 59.240861758589745, 55.27013182640076, 54.85302060842514, 53.30103188753128, 55.28048627078533, 56.16888999938965, 56.9501356780529, 58.75614456832409, 57.01579615473747, 56.70451685786247, 57.97228462994099, 52.27388620376587, 51.53175562620163, 48.0324549973011, 52.47930318117142, 57.76718683540821, 59.278335347771645, 61.117782443761826, 60.879026055336, 61.488676741719246, 60.36658935248852, 64.05109584331512, 61.620544865727425, 64.84982058405876, 64.63200867176056, 66.64124205708504, 63.11462089419365, 59.97645288705826, 61.245364397764206, 69.1534012556076, 70.83819285035133, 63.47723923623562, 2.72877037525177, 0.3005244192900136, 17.218656353652477, 1.3033465691842139, 0.8760629408061504, 51.93719007074833, 83.26402768492699, 70.08072629570961, 69.49604406952858, 80.54331287741661, 62.0179845392704, 62.545270845294, 33.25511634349823, 44.70203250646591, 70.5561263859272, 60.695898681879044, 0.8825632638763636, 0.4367920244112611, 0.20521352504147217, 0.1754835937754251, 0.18789723078953102, 0.14686320297187194], [0.020970176701666787, 0.01481576216974645, 0.07869723573094234, 0.1073066056414973, 0.06741072065779008, 0.15230909746605903, 0.6548304401803762, 0.2532724110642448, 19.90077283233404, 74.36550557613373, 50.235664173960686, 33.63152414560318, 44.86275628209114, 38.09318393468857, 53.625135496258736, 56.15551471710205, 47.069575265049934, 64.39184635877609, 52.94769264757633, 63.638654574751854, 31.630526818335056, 0.28351552260573953, 0.17910368624143302, 3.517336123622954, 3.379066293127835, 0.2864396438235417, 11.077707074582577, 72.29770213365555, 59.18900214135647, 61.58688627183437, 47.0609725266695, 49.87012758851051, 52.13596120476723, 57.79132694005966, 54.548683539032936, 45.780973210930824, 58.28795649111271, 56.15028239786625, 52.87228189408779, 47.35764540731907, 42.518654465675354, 46.21181309223175, 46.00145258009434, 46.85446120798588, 41.12580880522728, 39.07468266785145, 38.37374947965145, 45.18831521272659, 48.51633623242378, 52.3459417372942, 51.429947689175606, 54.850520342588425, 52.61473171412945, 54.24873523414135, 51.68407425284386, 51.982616633176804, 50.81574484705925, 43.4768870472908, 44.23181153833866, 41.99612930417061, 42.406621277332306, 49.58626762032509, 46.718686893582344, 47.43989199399948, 47.07380823791027, 45.74541471898556, 42.3158897459507, 40.13409622013569, 37.05632597208023, 39.35553319752216, 38.773503229022026, 40.47771938145161, 36.39002412557602, 35.85377410054207, 38.26382137835026, 38.28877463936806, 38.996209278702736, 43.6026830971241, 42.27926731109619, 43.27366255223751, 44.248321652412415, 44.55525778234005, 41.578292325139046, 38.61541651189327, 51.39399781823158, 54.822223260998726, 44.803642854094505, 45.351999029517174, 40.42357608675957, 43.30120727419853, 41.9252897053957, 48.17845456302166, 49.65780258178711, 52.49283045530319, 46.0707950592041, 48.86303722858429, 46.934078335762024, 44.963431879878044, 44.93478141725063, 44.94290918111801, 42.007547691464424, 42.733567133545876, 41.22415512800217, 41.9948373734951, 39.85856160521507, 39.56540733575821, 36.75065517425537, 38.11896175146103, 37.007092013955116, 39.47573974728584, 37.914525121450424, 40.90841107070446, 41.570445746183395, 41.53962939977646, 46.25448860228062, 44.521131813526154, 46.76337629556656, 47.00790837407112, 42.98287555575371, 43.62135909497738, 43.125409707427025, 47.76980549097061, 52.37619571387768, 50.81230603158474, 52.28661932051182, 52.543804720044136, 52.3818726092577, 52.777564376592636, 51.790396347641945, 52.0053394138813, 49.299835190176964, 48.76630201935768, 45.3312673419714, 47.34690338373184, 43.78683641552925, 45.30227869749069, 45.7731494307518, 49.65313263237476, 49.726567491889, 56.09503336250782, 58.423878997564316, 57.95796699821949, 56.27716898918152, 58.859172239899635, 57.477228194475174, 57.828234359622, 58.08400243520737, 58.41148026287556, 55.66520422697067, 54.15640018880367, 55.43100379407406, 62.52630606293678, 63.094079196453094, 54.836027920246124, 2.1026862831786275, 0.5896412569563836, 9.598181415349245, 0.13421656127320603, 0.5068893567658961, 48.87928515672684, 68.8745342195034, 59.39528167247772, 53.79119038581848, 61.25935144722462, 47.42878518998623, 45.857542902231216, 35.64085252583027, 34.88916166126728, 54.760533571243286, 27.059334106743336, 0.3587670112028718, 0.03966661330196075, 0.07477417631889693, 0.014874768476147437, 0.07333911504247226, 0.021024487068643793, 0.10215244197752327, 0.03100417656241916, 0.08044651491218247, 0.11989795733825304, 0.07444924922310747, 0.02639892016304657, 0.6422584585379809, 0.18007509817834944, 24.030575528740883, 78.97569179534912, 54.2510911077261, 36.46575026214123, 27.64041792601347, 45.66849924623966, 63.90022873878479, 63.11424471437931, 52.61459872126579, 72.02705785632133, 58.36441978812218, 69.51125845313072, 34.70356062054634, 0.1729547997820191, 0.16939588997047395, 3.5431913612410426, 5.367169724777341, 0.566097660921514, 12.521721739321947, 73.70546579360962, 59.849554896354675, 62.3520740121603, 48.256734162569046, 51.65422685444355, 53.43193866312504, 60.85752300918102, 54.521978572010994, 49.749484062194824, 59.515036046504974, 58.66357773542404, 54.7595190256834, 47.72223964333534, 43.7975100427866, 49.61562864482403, 49.16027247905731, 49.15831558406353, 43.94479013979435, 40.41158013045788, 41.408031061291695, 46.30699038505554, 50.165937915444374, 54.20610152184963, 53.92066463828087, 57.42302790284157, 54.46698032319546, 55.740128606557846, 52.38868184387684, 53.488745614886284, 52.28992134332657, 47.6432228833437, 47.42394044995308, 45.294048339128494, 45.509998351335526, 51.50845527648926, 48.31107884645462, 50.25435537099838, 50.64057804644108, 47.977859526872635, 44.05057266354561, 42.211543545126915, 39.38062325119972, 41.10109493136406, 41.32308281958103, 41.280449107289314, 39.68752898275852, 38.465001583099365, 39.21889252960682, 38.896677419543266, 41.556261107325554, 45.48312619328499, 46.31851516664028, 46.22588373720646, 47.4679496884346, 46.588198095560074, 44.66251842677593, 39.799987748265266, 52.171151116490364, 54.663084000349045, 46.633005291223526, 46.3800984621048, 43.228501975536346, 46.38437703251839, 43.877761736512184, 51.027093306183815, 52.68979288637638, 52.587673366069794, 49.18127775192261, 51.52822181582451, 46.76344469189644, 47.182151824235916, 47.509576454758644, 47.74027347564697, 43.640152886509895, 45.69471783936024, 43.91320623457432, 42.85593956708908, 41.590485870838165, 41.760849729180336, 39.078881442546844, 39.35272894799709, 37.81875506043434, 40.747322514653206, 39.15401481091976, 42.41730250418186, 43.954133838415146, 43.16235512495041, 47.20841221511364, 46.757627204060555, 48.41392792761326, 49.552058055996895, 45.30860535800457, 45.13240501284599, 44.99180495738983, 49.95174340903759, 54.51681844890118, 53.16591493785381, 54.062959402799606, 54.57727700471878, 52.59516656398773, 54.03593145310879, 52.55884051322937, 53.85511815547943, 51.83527193963528, 51.227289363741875, 48.22580762207508, 49.25772964954376, 45.72196617722511, 48.295423686504364, 47.417617589235306, 52.253207713365555, 53.056693598628044, 59.10338893532753, 58.53312313556671, 58.478664457798004, 58.115343153476715, 60.15878230333328, 59.6237064152956, 60.15317000448704, 60.17096824944019, 62.126977890729904, 57.10462398827076, 56.6069532930851, 57.69028656184673, 66.32420986890793, 66.98085263371468, 61.698938459157944, 3.1637472845613956, 0.7887433294672519, 4.329631123691797, 0.148988209257368, 1.153457318432629, 54.13141272962093, 75.17496094107628, 62.918167635798454, 56.98734328150749, 67.30168461799622, 54.28916126489639, 56.99294798076153, 31.59442115575075, 39.7078350931406, 64.45741564035416, 36.410094648599625, 0.2960590651491657, 0.07088500336976722, 0.04277652005839627, 0.052445613328018226, 0.07800642983056605, 0.00694733670570713, 0.2815480000572279, 0.14445425098529086, 0.15181503491476178, 0.296650052187033, 0.1519268617266789, 0.32347171450965106, 1.0810386668890715, 0.7848915830254555, 28.425053022801876, 91.64351284503937, 65.27907595038414, 49.00586396455765, 56.84750698506832, 59.01188604533672, 64.94776412844658, 69.79852303862572, 57.270549684762955, 78.11367005109787, 65.44355392456055, 74.42307248711586, 40.51008224487305, 0.3296248015249148, 0.29510445543564856, 12.521998174488544, 8.644638732075691, 0.543982966337353, 13.89751486480236, 76.232900172472, 62.65172593295574, 66.7189858853817, 51.420907974243164, 55.317868664860725, 54.772624522447586, 61.95651523768902, 58.95724877715111, 50.077630653977394, 61.97701893746853, 62.33907870948315, 56.78519792854786, 52.7649300545454, 46.482749953866005, 51.16270802915096, 51.32528230547905, 50.88199429214001, 45.21786242723465, 42.23393954336643, 42.03975476324558, 49.04133126139641, 52.68269866704941, 58.169691637158394, 56.25997871160507, 57.79396779835224, 54.29320424795151, 59.14296381175518, 56.354487240314484, 55.27568332850933, 54.35360960662365, 49.34957452118397, 49.72936414182186, 47.73050419986248, 48.70823733508587, 55.249042958021164, 52.39526689052582, 52.106957361102104, 52.932774648070335, 50.440807566046715, 46.422956362366676, 45.1043701171875, 41.64783999323845, 43.30962002277374, 42.94811502099037, 46.003037095069885, 42.54576601088047, 40.78217804431915, 41.1976021528244, 41.25288538634777, 44.541567116975784, 47.63419456779957, 48.569924756884575, 49.10598859190941, 49.54431787133217, 47.54641927778721, 46.20365492999554, 39.54572819173336, 53.892105370759964, 57.04664669930935, 48.726901933550835, 49.772020652890205, 45.5840639770031, 48.81624273955822, 45.58876432478428, 52.060987427830696, 52.913908660411835, 56.93108730018139, 51.91106267273426, 52.876796051859856, 50.53390257060528, 49.261179864406586, 50.294644609093666, 50.723660588264465, 46.74875468015671, 46.67410388588905, 46.55648499727249, 45.96882753074169, 42.38312713801861, 44.40510503947735, 43.01874563097954, 42.70507626235485, 40.23688070476055, 43.19775402545929, 41.04295425117016, 44.46061246097088, 45.97287431359291, 45.671048909425735, 50.50902530550957, 49.92711693048477, 52.39620164036751, 52.34186835587025, 48.44445548951626, 47.20634512603283, 47.69217945635319, 51.62475563585758, 54.98091794550419, 56.84803135693073, 56.223314478993416, 57.351515740156174, 53.62712278962135, 56.49382196366787, 55.77834315598011, 55.46580992639065, 53.79050262272358, 53.38824860751629, 50.25074556469917, 53.47394160926342, 48.335367143154144, 49.702655375003815, 50.7597054541111, 54.72990341484547, 53.56760658323765, 64.1864749789238, 63.0391151458025, 60.76418861746788, 60.997385904192924, 62.755676954984665, 61.64640627801418, 63.25289927423, 60.76116017997265, 62.92380653321743, 58.379303589463234, 60.19311346113682, 59.46110554039478, 69.03352528810501, 68.15861463546753, 63.604353815317154, 4.984478009864688, 1.1242703720927238, 16.860726960003376, 0.6703860335983336, 3.05127355735749, 60.29062382876873, 81.34442389011383, 70.28333902359009, 64.61748585104942, 74.2684055864811, 59.74215365946293, 65.6688742339611, 47.135938704013824, 53.73465321958065, 73.82348746061325, 50.49285717308521, 0.747241125209257, 0.25295717641711235, 0.17646569263888523, 0.14098252868279815, 0.19857051665894687, 0.18430134718073532], [0.04653725693060551, 0.09444583207368851, 0.14671803888631985, 0.0603784966369858, 0.1206899328099098, 0.03169241834257264, 0.6296175462193787, 0.2358911046758294, 16.543417386710644, 74.17700529098511, 50.119006633758545, 39.93444353342056, 52.07785852253437, 42.165246829390526, 44.19353999197483, 60.32916136085987, 45.000160709023476, 62.74256005883217, 56.76737688481808, 58.06110106408596, 46.987845450639725, 0.18338678375585005, 0.19974756287410855, 2.000304814428091, 3.496170546859503, 0.13057417469099164, 1.481367729138583, 60.86356848478317, 62.70926624536514, 60.99259816110134, 49.80532206594944, 49.47989992797375, 51.8709672242403, 57.61611454188824, 55.26822432875633, 53.49394753575325, 59.655548706650734, 55.08019141852856, 51.480978950858116, 43.377100601792336, 42.033530697226524, 44.85718958079815, 43.883499428629875, 46.87463812530041, 40.511203184723854, 40.69083094596863, 41.62607476115227, 49.3284210562706, 53.07854242622852, 53.32586735486984, 54.94533285498619, 55.791235864162445, 51.80146895349026, 54.434427469968796, 52.32462868094444, 51.190853118896484, 43.92291471362114, 42.99663081765175, 47.278776839375496, 43.46066191792488, 43.60732264816761, 47.824723944067955, 48.467698842287064, 46.47692486643791, 47.40074649453163, 46.019904389977455, 41.34672895073891, 37.97627940773964, 37.00429916381836, 40.047020092606544, 38.5680178552866, 38.89161989092827, 38.69847245514393, 37.027500718832016, 36.04765869677067, 38.050751611590385, 39.68780256807804, 46.77274279296398, 42.907643392682076, 45.521652325987816, 45.34362427890301, 42.96624764800072, 44.63906988501549, 40.33029109239578, 47.7971488237381, 54.91900786757469, 46.10745549201965, 43.26142340898514, 39.820430651307106, 45.02992071211338, 45.52495814859867, 54.90474723279476, 49.99030753970146, 45.46610690653324, 48.354240730404854, 46.94142334163189, 43.44822898507118, 46.081533282995224, 47.72497929632664, 42.05168232321739, 41.8778682500124, 41.518753319978714, 40.758410319685936, 40.502839833498, 40.14391489326954, 38.143405839800835, 36.540986225008965, 38.538740426301956, 38.630615696311, 39.39973622560501, 37.976078018546104, 41.31021291017532, 46.01571701467037, 45.302719473838806, 46.14619441330433, 49.60652433335781, 46.025178506970406, 46.62927769124508, 42.14683681726456, 42.00129322707653, 45.650203227996826, 43.470218405127525, 48.753219321370125, 52.60169841349125, 52.72412024438381, 53.72836455702782, 53.80959279835224, 53.14805589616299, 55.43238312005997, 53.95129479467869, 49.22407865524292, 47.2835835814476, 46.290005296468735, 43.962698578834534, 42.32904464006424, 42.203989550471306, 42.01076611876488, 45.64796134829521, 50.17545260488987, 51.75010710954666, 55.65558314323425, 55.333843007683754, 59.46160331368446, 59.29775230586529, 55.524942353367805, 55.40244832634926, 60.56037895381451, 59.2993938177824, 53.506566658616066, 48.87168176472187, 55.75654372572899, 61.181478425860405, 66.7589445412159, 58.00408512353897, 2.114964611828327, 1.105637715663761, 5.648148497566581, 0.035801077756332234, 0.948099831584841, 55.75013346970081, 64.58803743124008, 56.50401681661606, 56.37262746691704, 63.8405567407608, 43.177178129553795, 46.617509722709656, 33.37639443576336, 30.245822221040726, 56.344524174928665, 15.874555427581072, 0.5043091764673591, 0.0050211851794301765, 0.01362380528007634, 0.03633416614320595, 0.06249367317650467, 0.04836455438635312, 0.054759926642873324, 0.005778084896519431, 0.18139325635274872, 0.0515540119522484, 0.09932980203302577, 0.032200596542679705, 0.7323067984543741, 0.2942013507708907, 19.263545125722885, 85.82445949316025, 58.40923838317394, 42.028248980641365, 50.176828131079674, 53.935651034116745, 51.69203482568264, 66.98956936597824, 46.84792175889015, 70.79840138554573, 61.88644699752331, 66.83237180113792, 48.85169483721256, 0.1797441893722862, 0.25622342771384865, 0.9878762159496546, 6.72533892095089, 0.35545121412724257, 1.8155782017856836, 63.18688161671162, 64.08609956502914, 63.344930335879326, 50.60711704194546, 52.331586107611656, 51.73522710800171, 59.9812900274992, 57.693341597914696, 56.785733699798584, 59.234447702765465, 57.63197869062424, 53.40875990688801, 45.215354561805725, 44.43983897566795, 47.242348194122314, 46.05539828538895, 47.835845947265625, 41.445592045784, 44.523723274469376, 45.48573285341263, 51.25195384025574, 53.19811820983887, 54.96459782123566, 57.237742245197296, 59.26742993295193, 53.700629845261574, 57.034012377262115, 54.48149934411049, 54.440602138638496, 47.14131161570549, 46.47220931947231, 49.28732246160507, 45.401229187846184, 46.28411561250687, 49.73391629755497, 52.099027186632156, 49.69268471002579, 50.585727989673615, 47.65798509120941, 42.52885691821575, 40.55512882769108, 39.948586374521255, 41.919198632240295, 39.85293410718441, 40.298745185136795, 40.37213444709778, 39.11831192672253, 39.76977936923504, 39.40080016851425, 41.61069318652153, 48.99503834545612, 47.02156104147434, 49.24887992441654, 46.48783788084984, 45.35096548497677, 44.53027792274952, 38.62175837159157, 48.385900631546974, 57.23535597324371, 48.20214629173279, 46.59844994544983, 43.11594441533089, 46.33600562810898, 45.742884054780006, 55.32718576490879, 50.97507789731026, 47.4532026797533, 50.29305249452591, 48.74718904495239, 44.71950016915798, 48.21839042007923, 49.23930063843727, 45.13343095779419, 43.201694414019585, 43.238594233989716, 42.68468275666237, 41.499811336398125, 40.40530666708946, 39.909809455275536, 39.59639087319374, 39.35527101159096, 38.2730358839035, 40.589589178562164, 39.33923587203026, 42.28599674999714, 46.7805589735508, 47.42048643529415, 48.23349840939045, 52.89390653371811, 48.11845578253269, 49.47058282792568, 45.471658408641815, 44.789648205041885, 48.23399618268013, 45.8113943785429, 50.59036374092102, 54.659189209342, 55.145464316010475, 55.966383665800095, 55.275025963783264, 54.333094507455826, 55.82949221134186, 55.096063166856766, 51.1943831294775, 49.09342646598816, 48.50704953074455, 46.965206265449524, 44.5202274620533, 44.36968334019184, 44.42265249788761, 47.253135815262794, 50.33442087471485, 54.40463326871395, 57.66691781580448, 58.40037725865841, 60.696996822953224, 61.13787576556206, 56.66233532130718, 55.84311068058014, 61.49889439344406, 61.81421287357807, 57.491720616817474, 51.4274550229311, 56.86579920351505, 63.7442547082901, 68.3462181687355, 60.55589899420738, 3.68270514998585, 0.9544386633206159, 1.9698848342522979, 0.025207467006111983, 1.5596867515705526, 61.59310653805733, 71.38838052749634, 62.262999191880226, 59.80217143893242, 70.64498081803322, 47.259755060076714, 56.871768683195114, 35.95400892198086, 36.804665476083755, 66.21289864182472, 24.18002910912037, 0.5158305738586932, 0.04336639758548699, 0.057389366993447766, 0.050645745650399476, 0.004083751546204439, 0.08914798861951567, 0.1917961481376551, 0.21784109354484826, 0.27187870640773326, 0.15652829606551677, 0.1911880323314108, 0.1698770688381046, 0.8639849326573312, 0.3202591056469828, 22.663389891386032, 95.48144370317459, 67.47542649507523, 54.889624044299126, 61.01041540503502, 60.45732468366623, 55.79440489411354, 71.96302369236946, 55.2854298055172, 76.01597741246223, 68.61917272210121, 70.79542234539986, 55.78731827437878, 0.5778275127522647, 0.4355113743804395, 6.680314186960459, 9.966973476111889, 0.3871131339110434, 2.3712050495669246, 65.77178791165352, 66.65140271186829, 66.29325672984123, 54.119416773319244, 56.28729164600372, 54.52899679541588, 63.501219749450684, 59.19166199862957, 54.93744447827339, 62.865962237119675, 60.42256414890289, 55.06355971097946, 47.40343675017357, 46.1762659996748, 50.61014547944069, 48.830541372299194, 51.69906064867973, 46.28144055604935, 47.30745010077953, 47.86600112915039, 53.626146242022514, 56.08139209449291, 56.35069124400616, 59.82799865305424, 59.710516557097435, 54.16576288640499, 59.2195601016283, 55.546278208494186, 56.27718038856983, 49.88977253437042, 47.70900875329971, 50.5766274780035, 48.551480546593666, 49.71891090273857, 54.2453496158123, 56.04608818888664, 52.34054982662201, 53.09828996658325, 51.12058348953724, 45.56086242198944, 42.45835170149803, 41.484874337911606, 44.94113467633724, 40.92352285981178, 43.12399998307228, 45.41225239634514, 42.521629706025124, 41.83882534503937, 41.38547167181969, 44.58336107432842, 50.69903030991554, 50.73800481855869, 50.914037972688675, 50.55748030543327, 48.16600263118744, 44.76389318704605, 39.48006011545658, 49.0254595130682, 60.20214557647705, 48.12604017555714, 48.370401263237, 45.30498415231705, 48.12850244343281, 47.02551282942295, 58.91520783305168, 52.456500604748726, 47.64937475323677, 51.150199100375175, 48.961930721998215, 44.88498888909817, 49.669357761740685, 51.68037325143814, 48.85517165064812, 46.60592034459114, 44.67925652861595, 45.036441162228584, 45.674829706549644, 41.50807209312916, 42.135034650564194, 40.48870459198952, 42.200011163949966, 40.72978265583515, 41.69498026371002, 42.24130354821682, 44.696933180093765, 49.02089595794678, 49.73363131284714, 51.429860293865204, 54.70422059297562, 51.07892632484436, 51.07675664126873, 46.77387893199921, 46.760655641555786, 50.76611191034317, 48.06583620607853, 52.05494575202465, 56.3220027834177, 56.82933636009693, 57.939089611172676, 57.90016829967499, 58.01373280584812, 57.60898232460022, 59.36450332403183, 52.691176012158394, 51.18971697986126, 50.94919368624687, 49.74007956683636, 45.95986381173134, 47.29046881198883, 46.095246747136116, 51.63041353225708, 52.398762702941895, 57.87121385335922, 60.09179189801216, 62.08404779434204, 65.10968863964081, 63.381837755441666, 58.598871007561684, 57.82976187765598, 63.611771017313, 65.35812690854073, 59.57046367228031, 55.66219858825207, 60.629801228642464, 66.65399417281151, 71.05702310800552, 67.07709386944771, 6.307290578261018, 2.08059664350003, 12.081232275813818, 0.10565190576016903, 3.241081447340548, 68.06821748614311, 76.02472454309464, 69.1100911796093, 66.89430847764015, 75.20380899310112, 54.94491867721081, 68.96040961146355, 43.53804096579552, 45.7126946747303, 78.36612090468407, 35.061140432953835, 0.6191450112964958, 0.13155514548998326, 0.1691693568136543, 0.19914373668143526, 0.12817248090868816, 0.17556086619151756], [0.10564979806076735, 0.05607277103990782, 0.022144295144244097, 0.0272313612367725, 0.13358931289985776, 0.042343955574324355, 0.537567901192233, 0.19254619226558134, 8.85164212435484, 69.79005709290504, 52.01947085559368, 30.941561087965965, 60.7758653908968, 57.41924710571766, 38.761720061302185, 52.750354036688805, 51.4348304271698, 54.794344156980515, 60.644027665257454, 56.144757494330406, 60.3971017152071, 3.4107848536223173, 0.8107040135655552, 0.549068043474108, 4.645187566056848, 0.3896997857373208, 0.11711822095094249, 33.7353877723217, 67.04142138361931, 61.352818831801414, 54.01387743651867, 44.01247210800648, 53.85480277240276, 56.276059448719025, 56.8857329338789, 56.0770071297884, 56.573344096541405, 54.36828061938286, 49.74074073135853, 43.12829755246639, 42.002360969781876, 43.76152217388153, 42.22945958375931, 41.852174028754234, 39.76997695863247, 42.085333317518234, 49.47819761931896, 52.18048721551895, 54.98687222599983, 53.077318891882896, 49.91645850241184, 51.65737688541412, 54.49791066348553, 51.73751838505268, 48.350452333688736, 45.89557126164436, 42.32859626412392, 44.73933130502701, 47.94463790953159, 40.38807079195976, 41.094840466976166, 47.21237540245056, 47.71315433084965, 47.15576224029064, 45.576540380716324, 44.171941950917244, 41.785195022821426, 41.02338910102844, 39.78841356933117, 38.78154739737511, 37.97792091965675, 36.10727369785309, 38.18266913294792, 37.39375926554203, 36.76324009895325, 39.054289162158966, 41.00488789379597, 46.04263477027416, 49.7092442214489, 46.3172460347414, 56.50059700012207, 53.333140164613724, 46.62396177649498, 39.86159764230251, 39.86763171851635, 44.536756575107574, 46.79312489926815, 48.08826640248299, 41.489882469177246, 46.91801279783249, 44.77577514946461, 57.09816053509712, 50.35193033516407, 41.60653240978718, 42.734999656677246, 43.469728231430054, 39.40056838095188, 46.93555645644665, 41.78803347051144, 40.57297267019749, 45.16887545585632, 41.89533971250057, 42.11391158401966, 40.33979818224907, 39.43901091814041, 37.042730301618576, 36.28689765930176, 36.71182505786419, 38.976340144872665, 38.74429799616337, 39.36883248388767, 41.58235430717468, 48.00172224640846, 48.39786998927593, 47.098594307899475, 47.055443823337555, 47.89264149963856, 46.49917647242546, 44.18609619140625, 41.168423518538475, 47.526306957006454, 42.39170327782631, 43.04456904530525, 49.9308255314827, 52.41286374628544, 53.724994137883186, 55.03036469221115, 55.07093891501427, 53.29296872019768, 54.58119459450245, 54.075855910778046, 48.29197347164154, 48.827265948057175, 50.198927745223045, 45.68569332361221, 43.812591433525085, 42.10850827395916, 43.103329092264175, 46.4114011824131, 48.73917527496815, 53.060364201664925, 55.82268677651882, 56.795852556824684, 54.294119998812675, 57.45071701705456, 56.8233896791935, 60.36145582795143, 55.96528932452202, 54.15603540837765, 46.63299389183521, 57.786356806755066, 57.93857663869858, 66.3676643371582, 51.040282398462296, 2.631842801347375, 0.22129978373413906, 1.148953610099852, 0.08249458274804056, 3.392251110635698, 64.30725529789925, 61.79448053240776, 55.023901239037514, 58.342456966638565, 67.95547753572464, 47.94246442615986, 41.06446489691734, 21.299620270729065, 30.73594842106104, 54.26146075129509, 13.009240329265594, 0.7550691801588982, 0.11241828877246007, 0.04148713866015896, 0.05977764645649586, 0.09910869397572242, 0.02980902008857811, 0.15167941484833136, 0.014478528410108993, 0.10496039481949992, 0.08580666908528656, 0.15640334808267653, 0.04691270201874431, 0.6011712632607669, 0.19052100484259427, 11.22383488342166, 78.80334064364433, 58.780615255236626, 36.00870318710804, 53.58841046690941, 64.31951344013214, 42.27153092622757, 59.248297959566116, 54.013831838965416, 62.67474889755249, 65.19839107990265, 60.745113641023636, 63.60215753316879, 4.444219199940562, 0.9386766934767365, 0.33083093992900103, 10.328557323664427, 1.2241429067216814, 0.19049256574362516, 37.24705293774605, 67.80343249440193, 64.04779002070427, 54.98726740479469, 49.339512661099434, 54.86302547156811, 58.91876444220543, 57.568404302001, 56.42921023070812, 58.86363700032234, 57.56661459803581, 51.78867504000664, 44.87065605819225, 44.64314706623554, 46.088137328624725, 44.71424125134945, 43.05401153862476, 41.6703499853611, 44.92904372513294, 49.8619694262743, 54.609883055090904, 55.93250848352909, 55.508006662130356, 50.88809676468372, 53.59593026340008, 55.16669377684593, 52.852177172899246, 51.238274574279785, 47.421766966581345, 43.349745869636536, 48.300940990448, 48.77816118299961, 41.69167444109917, 42.19903081655502, 50.14399029314518, 51.126822754740715, 51.550146639347076, 47.16146193444729, 45.878525376319885, 43.24114389717579, 43.20365130901337, 40.84256440401077, 40.088806450366974, 38.243093490600586, 39.23961281776428, 38.585732504725456, 38.941104635596275, 39.22463022172451, 42.053924202919006, 42.393363788723946, 49.25863400101662, 51.16033315658569, 49.34973791241646, 57.153044790029526, 54.54311303794384, 47.02925182878971, 41.31546802818775, 40.74057027697563, 46.046616956591606, 47.78433211147785, 48.89416515827179, 42.84839317202568, 48.9339604228735, 45.0416012853384, 56.355877965688705, 52.055112943053246, 40.812663808465004, 45.12866981327534, 43.530475571751595, 41.891878098249435, 48.3154334127903, 44.87998455762863, 42.07600861787796, 46.92220017313957, 44.02316093444824, 43.76374125480652, 41.168716102838516, 42.62327805161476, 39.67236399650574, 38.06034229695797, 39.07339833676815, 41.057708859443665, 39.914996176958084, 42.32893064618111, 44.307841658592224, 49.0765705704689, 50.54988831281662, 50.23431144654751, 50.980599001049995, 48.5051154345274, 48.130516335368156, 44.9544757604599, 45.30692204833031, 48.08148756623268, 44.90197777748108, 46.248614117503166, 53.01684133708477, 55.268114134669304, 55.7381147146225, 55.054858177900314, 58.24011705815792, 56.95868141949177, 54.57460194826126, 55.66809207201004, 50.09273864328861, 50.11848226189613, 52.03793026506901, 47.20612093806267, 45.98639018833637, 44.7315189242363, 44.75721314549446, 49.18276347219944, 52.13894784450531, 56.63338467478752, 57.19355821609497, 58.280672281980515, 56.599756479263306, 60.25229908525944, 56.96400113403797, 62.287386283278465, 58.54732297360897, 56.034153029322624, 49.03804063796997, 61.47921524941921, 62.631001845002174, 68.73602405190468, 56.47632770240307, 3.230407820083201, 0.5730866733938456, 1.1480745510198176, 0.01958768545591738, 4.543829904869199, 68.00335496664047, 66.89369291067123, 61.454322785139084, 64.81214180588722, 73.76965194940567, 53.64253096282482, 49.028818532824516, 21.83589119464159, 38.15989315509796, 66.54583677649498, 19.74551696330309, 0.7532379752956331, 0.15190050064120442, 0.13218984502600506, 0.03750540505279787, 0.10946478592813946, 0.014733127736690221, 0.2102205133996904, 0.24679282360011712, 0.1486604323145002, 0.11753489976399578, 0.22736605431418866, 0.15508897486142814, 0.7400415209122002, 0.3063454100629315, 11.99495505541563, 91.09543025493622, 67.03461214900017, 49.028867930173874, 69.40306305885315, 74.26324546337128, 51.896547451615334, 63.85061100125313, 61.30679190158844, 68.7789237499237, 71.11122339963913, 65.72316572070122, 68.78456264734268, 7.266630325466394, 0.8715898683294654, 2.8566259145736694, 14.15404099971056, 1.1071893386542797, 0.32276513054966927, 41.071600914001465, 70.3687584400177, 68.14238950610161, 59.03645932674408, 50.23551978170872, 58.351048305630684, 62.509225979447365, 59.77614663541317, 57.234284430742264, 60.01935638487339, 61.160511150956154, 53.66569072008133, 47.27143943309784, 45.82083307206631, 50.73821000754833, 46.97766959667206, 45.17976947128773, 43.53423357009888, 48.380223736166954, 53.75032737851143, 57.79233008623123, 59.08085994422436, 58.2991810888052, 52.194656655192375, 55.387002155184746, 58.48855912685394, 55.35142846405506, 52.16287516057491, 49.458374083042145, 43.91429677605629, 49.407738000154495, 51.55511297285557, 43.9445735514164, 44.35079835355282, 52.93352320790291, 54.559915736317635, 55.88357850909233, 51.699843406677246, 48.89687821269035, 46.021378710865974, 45.85600398480892, 45.01860111951828, 42.768339067697525, 40.91503791511059, 39.433740600943565, 41.92395597696304, 41.39272928237915, 42.06436984241009, 45.35980761051178, 46.43582247197628, 53.108427822589874, 55.40974013507366, 53.376910015940666, 54.36690889298916, 57.684655264019966, 47.92717024683952, 42.447704672813416, 40.64780965447426, 44.97424229979515, 47.58185617625713, 52.96794556081295, 44.14595514535904, 50.81880368292332, 46.199760138988495, 59.660420045256615, 52.70947203040123, 42.156001925468445, 44.39287729561329, 44.30624954402447, 42.286395728588104, 48.62253673374653, 50.42765647172928, 47.71930240094662, 48.279054164886475, 46.85018643736839, 46.85289189219475, 44.11722108721733, 44.72958862781525, 42.10508465766907, 39.48677055537701, 40.656932964921, 43.90045411884785, 43.66685025393963, 43.119862005114555, 46.63970433175564, 50.88002599775791, 53.445013761520386, 52.603537514805794, 53.49893666803837, 50.64289212226868, 50.97805313766003, 47.484828382730484, 45.5844933539629, 50.77180780470371, 47.06541068851948, 47.474606931209564, 55.288017466664314, 56.57202936708927, 58.042607456445694, 55.194462686777115, 59.28426302969456, 59.497097209095955, 58.18381927907467, 56.97969429194927, 52.905461713671684, 52.42997042834759, 54.07809019088745, 50.15928827226162, 49.27925169467926, 47.22200408577919, 48.8812268525362, 51.00484549999237, 53.84768955409527, 57.62156344950199, 60.525983199477196, 60.480936616659164, 60.242298021912575, 62.80205726623535, 61.734268963336945, 63.30293878912926, 63.53202849626541, 58.68657790124416, 51.55118018388748, 62.96573728322983, 66.72057420015335, 69.5177561044693, 62.61234864592552, 6.27938250079751, 1.247567106038332, 6.328865820541978, 0.26654150686226785, 6.461327187716961, 73.7445504963398, 72.99712300300598, 67.9242280125618, 71.44628182053566, 80.03990828990936, 61.89142093062401, 59.90082934498787, 30.449107512831688, 48.341180831193924, 78.7924276292324, 29.25918236374855, 1.1480775196105242, 0.33974906138610095, 0.16779304394731298, 0.18789046240272, 0.1978552495711483, 0.08553260879125446], [0.06786876678233966, 0.04736418755783234, 0.036500663263723254, 0.006953420461286441, 0.06854279272374697, 0.03338123104185797, 0.15767861012136564, 0.10086837806738913, 3.9438698859885335, 65.3709626197815, 60.724754333496094, 46.08732797205448, 82.7738007903099, 84.09696578979492, 35.92892646789551, 56.64076007902622, 49.98376049101353, 49.411142617464066, 60.57257629930973, 52.044443115592, 62.99021936953068, 6.850481405854225, 0.8460431266576052, 0.6369605334475636, 7.431913381442428, 0.6207943602930754, 0.5421487928833812, 12.339601311832666, 63.015951588749886, 57.41882912814617, 53.828633576631546, 44.80993531644344, 51.17463558912277, 55.63064508140087, 57.1771164983511, 56.31360523402691, 56.529190465807915, 50.03515653312206, 50.55399589240551, 45.88203638792038, 42.21717484295368, 41.356365233659744, 40.591090098023415, 40.78795373439789, 38.53365249931812, 43.70107501745224, 51.10041417181492, 55.38170523941517, 54.57167990505695, 49.81532692909241, 48.73015835881233, 49.93336379528046, 53.68232622742653, 52.45066411793232, 53.91976408660412, 46.38363987207413, 44.477795138955116, 44.00198087096214, 46.288606971502304, 41.58274948596954, 44.31122727692127, 44.18372131884098, 45.17833694815636, 47.31591984629631, 47.584326043725014, 44.61018763482571, 45.13997420668602, 41.913951113820076, 40.72131671011448, 40.122001469135284, 40.53021356463432, 37.936795726418495, 38.539458587765694, 37.596660777926445, 36.7197210341692, 36.164244040846825, 42.68338322639465, 47.16174691915512, 55.59480540454388, 51.69910244643688, 47.260271832346916, 45.23406855762005, 37.666531428694725, 39.01005573570728, 39.29084926843643, 41.129973381757736, 43.98555815219879, 48.61626707017422, 45.82590959966183, 48.9749526232481, 42.11803816258907, 48.458404541015625, 47.42741346359253, 39.01099808514118, 41.06299437582493, 41.772116124629974, 42.64807552099228, 43.050188943743706, 45.33051498234272, 48.88506084680557, 46.76155999302864, 45.21381564438343, 41.4289565384388, 39.715624675154686, 37.606589645147324, 38.102520033717155, 38.71588312089443, 36.60791203379631, 38.8619776815176, 35.63699193298817, 38.763733953237534, 39.36560645699501, 43.35911996662617, 48.062230199575424, 49.8270682990551, 50.412442088127136, 48.77009801566601, 46.71738736331463, 43.1083220243454, 41.96579173207283, 46.87722198665142, 42.50510059297085, 42.87461556494236, 46.69173873960972, 50.656191408634186, 51.95347219705582, 54.133616611361504, 53.86315852403641, 55.389384627342224, 55.96353381872177, 53.80174621939659, 53.76933395862579, 51.834945157170296, 48.541642874479294, 47.834071442484856, 43.285799100995064, 44.68339830636978, 43.520349115133286, 42.46043398976326, 41.86418518424034, 47.51825138926506, 46.56957909464836, 54.79142211377621, 55.917145907878876, 57.12400294840336, 55.96136413514614, 62.24438399076462, 52.62997269630432, 52.51738853752613, 43.20644795894623, 58.921428099274635, 55.072154849767685, 67.48883977532387, 43.721240535378456, 2.5908346893265843, 0.5324987950734794, 0.41451387922279537, 0.07252181007061154, 7.208962244912982, 67.94148668646812, 54.20817621052265, 56.73380188643932, 58.562959134578705, 62.3418677598238, 50.588688030838966, 39.50709946453571, 42.92569242417812, 36.8138761818409, 55.75474642217159, 13.76464644446969, 0.8832453866489232, 0.12480458506615832, 0.06405443942639977, 0.03376073938852642, 0.10936749036773108, 0.019926431341446005, 0.054036024666856974, 0.01084069397620624, 0.02033306889643427, 0.03064673968765419, 0.0980162229097914, 0.11379129908164032, 0.2574852271936834, 0.07475053891539574, 5.0628497544676065, 76.37590929865837, 65.41382431983948, 50.75630083680153, 73.96094888448715, 75.54436951875687, 42.36548848450184, 61.521689370274544, 56.130306869745255, 53.88153053820133, 67.23910957574844, 55.96101075410843, 69.44201096892357, 8.158786352723837, 0.9285824163816869, 0.587492116028443, 8.143271785229445, 2.714545363560319, 0.6091300549451262, 13.406761698424816, 65.5606560409069, 59.150855988264084, 56.196294128894806, 46.39838308095932, 54.098297506570816, 57.161962911486626, 58.42612847685814, 59.16754849255085, 58.93994450569153, 53.050545528531075, 51.602994203567505, 47.73344524204731, 44.696230217814445, 42.506916895508766, 42.05166332423687, 43.36540102958679, 41.646000891923904, 46.06992110610008, 53.26084904372692, 57.78785392642021, 56.23648837208748, 50.35797581076622, 49.00889240205288, 52.15894617140293, 56.79392606019974, 53.69906432926655, 54.590203911066055, 47.42655090987682, 43.55650037527084, 46.688881292939186, 50.01461483538151, 43.145183846354485, 45.2829073369503, 46.979554295539856, 49.24468494951725, 50.91229006648064, 49.395947232842445, 46.528833881020546, 48.35217744112015, 44.158635064959526, 43.110875487327576, 41.39858856797218, 42.9357048869133, 39.581970646977425, 39.005100801587105, 40.7556326687336, 38.85088987648487, 40.571239963173866, 44.09416392445564, 50.59244602918625, 58.014454767107964, 55.6572550535202, 49.565425738692284, 49.17643681168556, 40.20227216184139, 39.61428411304951, 40.31296022236347, 41.595657393336296, 45.000023916363716, 51.19619943201542, 48.34976077079773, 51.024494245648384, 44.221935868263245, 50.40592923760414, 47.59161025285721, 40.21416552364826, 40.29135838150978, 42.93171130120754, 42.12629891932011, 46.40107713639736, 47.98505254089832, 52.71950349211693, 48.46006505191326, 46.80412910878658, 43.23848024010658, 42.44518540799618, 39.76953998208046, 39.60878200829029, 39.603811874985695, 37.96970576047897, 39.12708565592766, 39.35747109353542, 40.39172239601612, 41.57080292701721, 45.22274136543274, 49.914300218224525, 52.57780909538269, 50.103013291954994, 52.684321179986, 49.36106510460377, 45.104005336761475, 42.32233040034771, 48.58252868056297, 45.17535790801048, 45.63164882361889, 47.32433259487152, 52.425441071391106, 54.194854125380516, 54.670630395412445, 52.78071440756321, 58.79978522658348, 57.25226126611233, 56.95935398340225, 55.69834224879742, 53.130937814712524, 51.5015434473753, 49.03999373316765, 46.15678444504738, 47.90941759943962, 45.43911315500736, 46.729501113295555, 45.010047778487206, 49.55085352063179, 50.259477496147156, 57.86016024649143, 62.27758660912514, 59.55768495798111, 59.28610973060131, 64.73904892802238, 55.58608867228031, 54.69024874269962, 46.60059303045273, 61.41608163714409, 59.986294358968735, 68.76747116446495, 51.69241480529308, 3.049094849266112, 0.6969033856876194, 0.14638390915933996, 0.047757021166034974, 8.554604463279247, 74.84265357255936, 59.598772153258324, 64.18258398771286, 65.80499812960625, 68.10671702027321, 55.01201547682285, 51.70381419360638, 35.931609123945236, 41.73592306673527, 66.31470277905464, 20.029559321701527, 1.0390076972544193, 0.13777508516795933, 0.06866007432108745, 0.014501580444630235, 0.09942450007656589, 0.036931350114173256, 0.23093533935025334, 0.14831983105977997, 0.18871714069973677, 0.11493730125948787, 0.19189433427527547, 0.20219380035996437, 0.4483519244240597, 0.198044853459578, 5.383600993081927, 89.0859916806221, 76.48487225174904, 65.52271887660027, 89.680857360363, 90.42817085981369, 51.57232604920864, 68.58570411801338, 63.60189154744148, 60.0295702368021, 71.68201357126236, 60.246903374791145, 73.91579210758209, 11.606442052870989, 0.9487541683483869, 1.2380913645029068, 18.630896173417568, 3.967906921170652, 0.6311435205861926, 14.28509596735239, 65.83356499671936, 61.95575907826424, 58.29522170126438, 49.98472563922405, 56.29532441496849, 60.036349073052406, 59.05400678515434, 57.73437559604645, 60.7372822612524, 57.152778804302216, 55.48655301332474, 51.14794582128525, 46.844277754426, 45.91295152902603, 44.25444312393665, 44.78742532432079, 43.214283138513565, 49.37951311469078, 55.478660836815834, 61.28134086728096, 58.59563738107681, 52.94462241232395, 50.97513869404793, 53.170717880129814, 58.013041242957115, 55.80681502819061, 56.99402712285519, 52.00453005731106, 46.43593646585941, 50.08384712040424, 52.54149444401264, 46.36067010462284, 47.31074072420597, 48.13888728618622, 51.039552837610245, 52.69695930182934, 54.31918725371361, 51.7916426807642, 50.151764675974846, 44.49685111641884, 44.64437060058117, 46.73586957156658, 45.316584929823875, 44.05439905822277, 42.60826125741005, 41.70847333967686, 40.5229065567255, 41.78274415433407, 46.31525494158268, 53.260913640260696, 59.03003767132759, 57.556085363030434, 51.342445984482765, 49.32085946202278, 40.487477257847786, 39.54196259379387, 41.22651480138302, 42.17718958854675, 44.34971161186695, 52.20232464373112, 51.11959934234619, 53.76405984163284, 43.420285284519196, 49.75044161081314, 48.30594152212143, 40.85844375193119, 41.76539808511734, 43.17468546330929, 42.494525760412216, 49.72411662340164, 51.11308269202709, 52.31504939496517, 49.591959714889526, 49.7764740139246, 44.23082359135151, 43.87835070490837, 42.29643478989601, 42.26850628852844, 41.089463755488396, 39.55452851951122, 42.702310010790825, 39.57789346575737, 43.25656346976757, 45.02340026199818, 46.2302915006876, 53.82351525127888, 55.003142952919006, 54.63477171957493, 55.378726199269295, 51.39917694032192, 48.07244785130024, 44.11584556102753, 51.78522102534771, 47.54488795995712, 47.58739247918129, 49.5250529050827, 53.710817098617554, 56.491682678461075, 56.40950068831444, 55.771659314632416, 60.64022406935692, 60.044100657105446, 57.281097918748856, 57.88211166858673, 54.563783928751945, 53.94224368035793, 50.97003176808357, 48.04167330265045, 49.356132969260216, 47.42024324834347, 46.83720253407955, 45.96701502799988, 51.80772341787815, 53.094862550497055, 58.794419914484024, 64.23326566815376, 59.96792994439602, 61.0039671510458, 66.98976695537567, 60.95885597169399, 56.509408727288246, 49.529137685894966, 63.44417721033096, 64.50302079319954, 70.07632613182068, 58.67002598941326, 5.585207249969244, 0.9865994844585657, 2.7752974536269903, 0.20640173315769061, 10.980162508785725, 80.80738350749016, 64.1094683110714, 71.76041856408119, 71.3514693081379, 73.45081105828285, 61.94244459271431, 61.70528031885624, 52.14480713009834, 54.771252796053886, 77.38260447978973, 28.660568185150623, 1.1935834027826786, 0.5916891689412296, 0.18437039660057053, 0.11745217998395674, 0.17786165757570416, 0.12759541656123474], [0.11074865687987767, 0.05244303807558026, 0.06526755401864648, 0.07329508342081681, 0.04615656485839281, 0.11640322845778428, 0.06430446897866204, 0.23587353061884642, 0.7006121648009866, 46.4723689109087, 67.68096506595612, 35.34179337322712, 66.05845212936401, 90.89753687381744, 35.17755098640919, 52.00970157980919, 53.576642498373985, 47.18766152858734, 55.03608338534832, 54.50810171663761, 65.11743262410164, 17.428705282509327, 1.2135297199711204, 1.124072188977152, 7.9096099734306335, 1.9625348411500454, 0.23020073189400136, 2.2874200204387307, 49.72908295691013, 61.53395511209965, 54.98030997812748, 48.477449119091034, 53.11081029474735, 57.16001741588116, 56.26490704715252, 56.365233063697815, 52.740303575992584, 52.26163946092129, 48.40286672115326, 46.707196310162544, 40.468972250819206, 41.474402099847794, 40.09208187460899, 42.010317742824554, 40.42593955993652, 41.48302003741264, 50.75273282825947, 52.523935586214066, 54.43762689828873, 55.796851962804794, 54.03690040111542, 51.37734331190586, 52.72433303296566, 52.779414877295494, 50.706356316804886, 51.17614030838013, 47.196686044335365, 41.931760758161545, 46.189648881554604, 42.53246672451496, 40.7912253588438, 46.556333005428314, 44.161017537117004, 47.153064385056496, 44.8831307888031, 47.09357477724552, 43.337818309664726, 39.564407989382744, 38.522256910800934, 36.8899405002594, 38.16743575036526, 38.29398795962334, 37.259888648986816, 38.71192753314972, 37.46429108083248, 40.326692685484886, 45.544572696089745, 50.34182287752628, 55.16011252999306, 51.137876361608505, 48.584409579634666, 38.19271579384804, 38.35701897740364, 40.01684211194515, 35.8375945687294, 39.360560327768326, 41.998416781425476, 50.21452210843563, 50.62502548098564, 47.234391421079636, 41.92158490419388, 42.55561128258705, 41.59156881272793, 38.71327646076679, 39.878217950463295, 38.305280953645706, 44.17178615927696, 52.538899183273315, 57.2399765253067, 53.59967306256294, 50.99872402846813, 46.71438552439213, 41.19081571698189, 37.66550548374653, 38.97509001195431, 38.10585245490074, 38.180442452430725, 38.57644200325012, 36.051093712449074, 38.71653288602829, 37.08435706794262, 38.94740849733353, 41.08319029211998, 44.3466679751873, 47.73368842899799, 46.69686086475849, 47.671880945563316, 47.70860597491264, 43.44769321382046, 43.31800617277622, 47.477403581142426, 42.040024548769, 44.75943222641945, 45.92867508530617, 51.5273554623127, 51.538424268364906, 56.72052539885044, 51.987522169947624, 50.7157988101244, 61.55189774930477, 54.95232827961445, 54.02058407664299, 53.99815388023853, 51.949216425418854, 50.33768489956856, 44.99884977936745, 41.28833748400211, 41.053662076592445, 42.67666518688202, 41.45287245512009, 44.33453142642975, 43.10941256582737, 46.40361540019512, 52.80439093708992, 58.71281549334526, 55.13947583734989, 57.21198342740536, 51.877407878637314, 51.65025606751442, 44.109910279512405, 59.232072830200195, 57.67567254602909, 58.67564968764782, 27.08077635616064, 2.2895702300593257, 0.08669479720992967, 0.4957797029055655, 0.29367694922257215, 16.46548356860876, 68.04765298962593, 57.374189123511314, 61.22748635709286, 65.04927188158035, 58.558387979865074, 49.31819200515747, 31.981227099895477, 29.18264117091894, 43.65465670824051, 52.733042165637016, 5.633258046582341, 0.6768895033746958, 0.07567333275801502, 0.1756669339374639, 0.09389021579409018, 0.039122596790548414, 0.017594579221622553, 0.04713249647466, 0.056686649622861296, 0.05661971532390453, 0.0873471301747486, 0.019867985356540885, 0.12629438715521246, 0.1976519011077471, 0.2618546364828944, 1.1771192424930632, 55.85132583975792, 72.97352626919746, 44.87414047122002, 70.05141466856003, 88.55721205472946, 43.20520922541618, 59.38321352005005, 58.929643258452415, 52.10603021085262, 65.44157043099403, 58.88362392783165, 70.1790726184845, 18.176788240671158, 1.4306759554892778, 0.5450627615209669, 5.481688929721713, 6.139335315674543, 0.39828690933063626, 3.137593762949109, 54.40423808991909, 64.74512860178947, 57.4426082521677, 50.437524542212486, 54.217063933610916, 58.87228153645992, 57.49886803328991, 58.271754160523415, 55.31271614134312, 52.894427105784416, 48.240767419338226, 47.84634858369827, 42.45872788131237, 42.86136567592621, 42.60109484195709, 43.585641011595726, 40.80899700522423, 46.495680660009384, 52.34981372952461, 55.16758292913437, 55.31308092176914, 55.63798248767853, 55.02029903233051, 53.72497893869877, 55.18445402383804, 53.221809938549995, 52.547414526343346, 53.17941181361675, 48.10134910047054, 44.347382336854935, 49.017711728811264, 43.800534680485725, 43.27966243028641, 47.91030295193195, 46.84549368917942, 49.139350801706314, 46.168871596455574, 51.428344175219536, 45.61245985329151, 42.284997403621674, 40.615108609199524, 38.18994574248791, 38.907970413565636, 41.19384415447712, 39.36411313712597, 39.55851070582867, 40.50676882266998, 41.39955371618271, 47.24308915436268, 52.96839393675327, 57.18619421124458, 55.81537216901779, 49.2880330234766, 40.43717175722122, 39.51535262167454, 39.95405048131943, 37.72818312048912, 39.66574475169182, 40.818564891815186, 51.36502057313919, 53.73074322938919, 49.30664822459221, 40.591682866215706, 41.8475990742445, 40.01359708607197, 39.08297382295132, 40.04804223775864, 38.19998100399971, 45.76152205467224, 51.06708616018295, 57.87065528333187, 54.815045446157455, 52.52905771136284, 50.01672372221947, 42.82041147351265, 40.913415402173996, 40.68268798291683, 39.32861544191837, 40.90659096837044, 39.34419460594654, 39.607524275779724, 40.71889244019985, 39.49158489704132, 39.81457136571407, 42.79410168528557, 47.27313794195652, 50.945629477500916, 51.19727097451687, 50.994232669472694, 50.753998160362244, 45.34151919186115, 45.53881600499153, 48.88917222619057, 45.08792079985142, 45.99504992365837, 50.16489677131176, 52.548014894127846, 54.14039544761181, 57.66806535422802, 53.62818293273449, 50.38978390395641, 65.25462046265602, 56.50093138217926, 54.42980691790581, 56.101838797330856, 54.45635609328747, 52.13268958032131, 46.4583932608366, 44.4328473508358, 42.69406445324421, 45.200588554143906, 44.51038978993893, 45.44706992805004, 45.24529315531254, 50.1260020583868, 53.73945236206055, 61.206534281373024, 58.074856325984, 59.320611879229546, 53.69228169322014, 55.45792914927006, 47.612178549170494, 62.418851628899574, 60.429502576589584, 64.95597168803215, 37.36151039600372, 1.5708686015568674, 0.5450809292960912, 0.14106674760114402, 0.14031045458978042, 18.23299292474985, 74.46579739451408, 60.39922200143337, 70.7496728003025, 69.59426119923592, 67.1706372499466, 53.32569256424904, 46.94553852081299, 35.02547934651375, 51.370496079325676, 63.98394584655762, 7.857354702427983, 0.6502796499989927, 0.09937271301168948, 0.10300207490217872, 0.03595275789848529, 0.16502137470524758, 0.058330079991719685, 0.32194695726502687, 0.11786497736466117, 0.3833119722548872, 0.19407405168749392, 0.20567834697430953, 0.14728428272064775, 0.263676579343155, 0.45445950294379145, 1.13601079210639, 64.3722166121006, 81.23530894517899, 53.54763485491276, 77.101571559906, 96.18638947606087, 50.09246505796909, 62.665105015039444, 65.23800015449524, 58.475423231720924, 69.48051050305367, 63.58908623456955, 75.47711312770844, 21.267977468669415, 1.3988164463080466, 1.6053430829197168, 15.943452380597591, 7.425481751561165, 0.37202209525275975, 4.100720006972551, 52.83895768225193, 68.96926313638687, 59.18933652341366, 53.25571171939373, 56.72911673784256, 62.79237538576126, 59.73946340382099, 59.517600908875465, 55.85715092718601, 57.53578305244446, 51.475868225097656, 50.702548921108246, 43.97893890738487, 47.022651582956314, 45.22140383720398, 46.53338983654976, 45.35595841705799, 48.19902665913105, 54.933485090732574, 58.60507607460022, 57.77678892016411, 58.53292554616928, 56.264910846948624, 54.28297519683838, 56.2434495985508, 56.7035099118948, 55.43038822710514, 57.45764024555683, 51.65180258452892, 45.760754495859146, 50.5856291949749, 45.69832384586334, 43.259671702980995, 52.437961399555206, 48.41681197285652, 51.926030069589615, 48.292182460427284, 55.47801487147808, 45.903281047940254, 44.206371903419495, 43.87475609779358, 41.12298555672169, 40.67095421254635, 41.87971495091915, 40.078243017196655, 43.77948381006718, 41.73831693828106, 45.14122433960438, 50.008189380168915, 56.009165570139885, 60.04443883895874, 59.983680099248886, 53.47664326429367, 41.52451381087303, 39.325488209724426, 40.420057475566864, 37.83716507256031, 39.964211136102676, 42.161070853471756, 52.08195850253105, 55.92818431556225, 50.47584928572178, 44.379110634326935, 42.342469319701195, 40.05912244319916, 39.5576823502779, 39.058206751942635, 37.12154567241669, 46.9930549710989, 55.276397690176964, 58.115985319018364, 58.24197515845299, 53.91968809068203, 51.103283017873764, 44.24493223428726, 44.05197858810425, 42.84947991371155, 42.79427647590637, 43.01120303571224, 42.59922914206982, 40.03858454525471, 45.248754769563675, 41.63033053278923, 43.24695758521557, 44.74799104034901, 49.54319693148136, 51.38015516102314, 53.65308679640293, 54.47252422571182, 52.93235667049885, 46.92941978573799, 48.32497090101242, 52.876769453287125, 47.066630423069, 48.51005136966705, 52.233330979943275, 54.44468691945076, 55.50071485340595, 60.628129318356514, 54.46981117129326, 52.83946305513382, 59.69395324587822, 56.92383348941803, 57.54073038697243, 57.61497840285301, 55.717018246650696, 56.48099385201931, 50.042448341846466, 45.268753096461296, 44.667347967624664, 48.98325137794018, 47.668981701135635, 49.57603856921196, 46.65149889886379, 50.96672594547272, 58.38023453950882, 63.1571140140295, 61.98420435190201, 60.90159684419632, 56.82839021086693, 58.35909627377987, 51.63919486105442, 63.54824222624302, 65.2210758626461, 66.81241527199745, 49.09031443297863, 3.664750875905156, 0.674518074374646, 1.7571575241163373, 0.42738191841635853, 22.421287782490253, 79.10870745778084, 67.35845357179642, 75.31216397881508, 73.4542764723301, 72.57405370473862, 61.21732570230961, 48.84879179298878, 37.99669951200485, 63.45351330935955, 76.8646314740181, 12.989671379327774, 1.1365275643765926, 0.31780132034327835, 0.337661964003928, 0.1929359682253562, 0.23864101414801553, 0.16381505818571895], [0.03935549015295692, 0.022611805507040117, 0.034957831012434326, 0.0008145142066950939, 0.06759814263205044, 0.021643939180648886, 0.04336175916250795, 0.5596128932666034, 0.04793206782778725, 35.731884241104126, 64.52386647462845, 40.29952794313431, 42.87650786340237, 72.27265387773514, 42.24622808396816, 43.76034043729305, 60.87728574872017, 46.311614736914635, 51.25052131712437, 55.127035304903984, 61.55951254069805, 28.25337253510952, 1.4101138338446617, 0.3911121521377936, 2.3455222276970744, 4.38153063878417, 0.2777475508628413, 0.09613674876163714, 27.686285264790058, 63.049290999770164, 53.77672456204891, 50.63156872987747, 49.16007108986378, 60.00884994864464, 55.49233250319958, 59.155324548482895, 54.84489664435387, 53.72655585408211, 47.56963223218918, 45.90210311114788, 41.74083240330219, 40.17848923802376, 39.83613520860672, 39.93986964225769, 40.35358764231205, 41.1619258671999, 42.842986062169075, 48.567052111029625, 50.77626496553421, 51.66673578321934, 53.07306312024593, 55.54261140525341, 52.03650914132595, 55.024357214570045, 53.45645494759083, 53.30997280776501, 49.51660215854645, 44.60982285439968, 45.963196232914925, 45.404960587620735, 40.96277475357056, 44.804319217801094, 45.62172755599022, 49.0505837649107, 47.9981542378664, 41.39668487012386, 41.39612630009651, 40.04679590463638, 37.32825458049774, 38.88430528342724, 36.82212173938751, 37.48092658817768, 38.87890197336674, 40.18271081149578, 38.361396342515945, 43.00983510911465, 46.640669479966164, 47.9901784658432, 49.59248028695583, 48.78349229693413, 46.65215626358986, 40.49575321376324, 40.16556993126869, 39.56464357674122, 39.25989992916584, 40.386820659041405, 39.254948794841766, 45.69787546992302, 48.79762753844261, 44.51860874891281, 40.63019759953022, 39.242899641394615, 39.25477780401707, 39.557720348238945, 39.524354338645935, 41.314947456121445, 40.82332983613014, 47.75539666414261, 53.47549192607403, 54.949786216020584, 54.597845301032066, 48.465586155653, 42.576126381754875, 37.37146586179733, 37.322691679000854, 39.13688153028488, 37.49691233038902, 38.328577503561974, 40.740881860256195, 39.19939577579498, 40.744731053709984, 39.551382288336754, 39.07508924603462, 45.25648735463619, 47.72704638540745, 47.66597606241703, 47.42180876433849, 46.50681786239147, 40.38573771715164, 42.4404014647007, 46.07168421149254, 43.03154714405537, 47.683447524905205, 50.87591841816902, 54.09061051905155, 52.606710344552994, 56.50398641824722, 49.52815353870392, 56.237719506025314, 44.83238451182842, 44.864029213786125, 56.32563158869743, 51.65636233985424, 54.070076420903206, 48.24030004441738, 41.745920330286026, 42.030418664216995, 40.34688860177994, 42.27251127362251, 41.94048509001732, 42.76276856660843, 43.37937667965889, 43.074568435549736, 41.36546954512596, 47.533218786120415, 53.659880831837654, 54.30018447339535, 48.86659383773804, 49.888309612870216, 47.091553285717964, 57.146296352148056, 61.14576034247875, 58.56753408908844, 19.505795426666737, 0.9995841002091765, 0.8240926545113325, 0.5392706848215312, 0.3293152368860319, 40.54728604853153, 65.92825591564178, 54.02240797877312, 58.14852297306061, 58.23022238910198, 53.72773379087448, 52.45436131954193, 27.388725131750107, 21.771537847816944, 43.35371285676956, 46.73690691590309, 0.5442351778037846, 0.23481329844798893, 0.03904663426510524, 0.10986430628690869, 0.04592730059812311, 0.08470687302178703, 0.047702131923870184, 0.09462641886784695, 0.023360343075182755, 0.02732125201873714, 0.04143882484640926, 0.025818543981586117, 0.02298603347298922, 0.021535260930249933, 0.34784859395585954, 0.1505669206380844, 44.105700105428696, 73.90692338347435, 44.36526417732239, 51.79717518389225, 77.97850370407104, 48.48965406417847, 49.01254780590534, 67.36052826046944, 50.138336196541786, 58.43335948884487, 59.57674093544483, 67.31943726539612, 30.201446302235126, 1.1585254152305424, 0.6639387889299542, 3.3632957143709064, 7.846359042450786, 0.7788967515807599, 0.20554349874146283, 31.729139126837254, 68.48757818341255, 53.75807896256447, 51.849608570337296, 52.11114853620529, 62.92017012834549, 56.87540888786316, 61.69050671160221, 55.73157146573067, 55.10978423058987, 49.91867758333683, 47.14610315859318, 42.47928857803345, 42.821718603372574, 42.447917461395264, 43.139833733439445, 41.836534067988396, 43.15288603305817, 45.37695989012718, 49.96562406420708, 53.238677233457565, 52.07317337393761, 53.88594590127468, 55.882723554968834, 53.706572726368904, 54.701499938964844, 55.324214324355125, 54.70428138971329, 51.94174222648144, 45.32538905739784, 48.18324610590935, 46.110141947865486, 42.49895632266998, 48.58281746506691, 48.65823581814766, 50.4824685305357, 50.14596238732338, 44.56769831478596, 43.61264616250992, 41.5699327737093, 39.33361977338791, 40.96406288444996, 40.0974053889513, 39.3977565318346, 39.63916897773743, 41.46544598042965, 41.63314238190651, 44.597101137042046, 49.89260718226433, 52.48817950487137, 53.13229814171791, 53.16037863492966, 48.53827245533466, 40.75902968645096, 38.862350061535835, 38.841606974601746, 40.185594856739044, 39.494024366140366, 40.31403176486492, 46.92820385098457, 51.14882357418537, 47.80330069363117, 40.59050112962723, 38.85976240038872, 39.58518147468567, 39.470655620098114, 40.582076981663704, 41.517552584409714, 44.37293216586113, 50.659569427371025, 53.49079370498657, 54.17603753507137, 56.82832941412926, 52.41382509469986, 44.8785824328661, 40.248587876558304, 39.82353888452053, 41.20263308286667, 41.09854906797409, 39.36460331082344, 41.46725468337536, 42.0918233692646, 41.183892488479614, 41.38329058885574, 41.582244113087654, 48.801180347800255, 50.64752407371998, 51.10774777829647, 50.95000684261322, 47.095531672239304, 42.53542296588421, 46.01507104933262, 48.07015657424927, 44.20896336436272, 50.11988438665867, 53.85735623538494, 56.03470399975777, 55.0629061460495, 58.639810010790825, 48.74912694096565, 57.25109472870827, 51.454634964466095, 46.091978922486305, 58.39397080242634, 50.09660683572292, 57.310132160782814, 49.442517533898354, 43.573755249381065, 42.70046330988407, 43.05753394961357, 44.4878987967968, 45.77521651983261, 46.178982853889465, 46.95286452770233, 45.98046250641346, 45.75498640537262, 49.557829946279526, 54.70221430063248, 55.95316797494888, 51.5048910677433, 52.063765078783035, 49.63734447956085, 60.29794983565807, 63.18653583526611, 63.13951335847378, 30.01263253390789, 0.5526991642545909, 1.3578819553367794, 0.1581675370107405, 0.2733972592977807, 44.54531751573086, 72.39629164338112, 59.33224305510521, 64.19329181313515, 66.29696533083916, 59.28650110960007, 56.88584692776203, 39.14795033633709, 23.293833062052727, 50.06625786423683, 55.12114182114601, 1.9237414165399969, 0.39948265766724944, 0.03191360803612042, 0.13905753119615838, 0.11504299793159589, 0.02894487446610583, 0.09550537404720671, 0.20282066281652078, 0.08301196357933804, 0.14491377398371696, 0.1921431763912551, 0.16681636276189238, 0.20462320593651384, 0.1386403848300688, 0.7611379295121878, 0.23587179399328306, 49.49852652847767, 85.55254608392715, 54.31380674242973, 57.142720744013786, 78.93162176012993, 58.890737146139145, 54.26446259021759, 75.81553816795349, 55.49044780433178, 65.13323977589607, 64.99626472592354, 73.61604139208794, 33.642687946558, 1.7390543455258012, 1.014935513958335, 10.092918667942286, 11.54210390523076, 0.9520565473940223, 0.5732447211630642, 32.57418908178806, 70.2083158493042, 58.46381485462189, 52.10828348994255, 53.395483419299126, 64.69520688056946, 57.577618807554245, 62.74794057011604, 57.57783159613609, 57.944131940603256, 52.33649164438248, 50.219678431749344, 46.18594408035278, 45.15197776257992, 45.104107931256294, 44.38110172748566, 43.8897804915905, 46.44207313656807, 47.44818314909935, 52.343977242708206, 57.159398049116135, 56.466471031308174, 55.81581674516201, 59.30472493171692, 56.109529584646225, 57.754130735993385, 57.698528319597244, 56.39138326048851, 53.35604913532734, 48.83827015757561, 49.865370243787766, 48.30164395272732, 45.4569835960865, 51.446024626493454, 50.254579558968544, 54.857466369867325, 52.96476513147354, 44.26670886576176, 46.2763412296772, 45.97361147403717, 41.46423004567623, 44.44814532995224, 42.98685774207115, 42.2720742970705, 43.067253828048706, 44.88365136086941, 44.236770272254944, 48.829906806349754, 53.76813322305679, 55.18716707825661, 55.34979075193405, 55.450234562158585, 50.051769241690636, 41.30995452404022, 40.90860866010189, 40.64619094133377, 40.99480703473091, 40.62501087784767, 40.8405315130949, 47.42509938776493, 51.73035576939583, 47.22509332001209, 41.69170863926411, 39.37730222940445, 39.81162652373314, 37.52250015735626, 41.41688458621502, 42.85898320376873, 44.15893904864788, 48.42691943049431, 53.70077423751354, 60.46514466404915, 59.26639638841152, 53.20162162184715, 47.385459914803505, 41.83597169816494, 41.17060460150242, 43.31729181110859, 42.90371060371399, 41.53982698917389, 44.406294375658035, 42.641220688819885, 42.61845611035824, 43.987773433327675, 44.40213359892368, 51.437672674655914, 53.74145105481148, 52.87511274218559, 52.5083564221859, 48.779605105519295, 43.71214002370834, 47.883670181035995, 49.462911039590836, 47.643925845623016, 50.399724170565605, 57.28656582534313, 58.791471272706985, 56.88077799975872, 59.62999887764454, 51.4261668920517, 52.32249699532986, 46.77533805370331, 47.71141402423382, 61.4804919809103, 52.95106306672096, 59.47007305920124, 51.27530358731747, 44.937844052910805, 45.65140776336193, 45.14790818095207, 46.68028235435486, 46.760936826467514, 46.972650066018105, 49.20441851019859, 47.23284110426903, 47.37891286611557, 52.47035466134548, 58.235842287540436, 59.97952312231064, 56.258181408047676, 53.63037161529064, 52.73501805961132, 62.81637489795685, 67.95079618692398, 66.79340109229088, 40.90985119342804, 1.4517743233591318, 2.296433374285698, 1.6677420283667743, 0.5771132104564458, 51.727205738425255, 77.08761110901833, 65.15365988016129, 70.06483554840088, 71.71499580144882, 66.05975165963173, 68.81362348794937, 41.40542820096016, 29.860374704003334, 60.91793976724148, 69.88027185201645, 3.954186332412064, 0.6179544283077121, 0.18557888019131497, 0.3365747176576406, 0.21756890346296132, 0.16500172263476998, 0.19252235448220745], [0.05569593813561369, 0.053984545593266375, 0.02436625745758647, 0.05243091509328224, 0.02700361466850154, 0.07256836499436758, 0.07351141204708256, 0.47933486814145, 0.07638479262823239, 16.685769148170948, 65.9571647644043, 39.72608171403408, 33.35069641470909, 36.74855388700962, 36.57009646296501, 46.52768634259701, 60.17995096743107, 52.701397463679314, 48.64425256848335, 55.24040222167969, 56.88111998140812, 43.35745185613632, 0.452195952530019, 0.21645161497872323, 1.3497141748666763, 7.5606191251426935, 0.7271972007583827, 0.049351670168107376, 14.906829055398703, 64.80478540062904, 60.22041119635105, 53.80497604608536, 52.73548923432827, 58.67816895246506, 57.14936278760433, 56.584131717681885, 55.53921818733215, 53.79184775054455, 51.21343530714512, 46.21906690299511, 40.85428677499294, 39.59898233413696, 40.61833843588829, 40.26566416025162, 41.950926929712296, 41.04511633515358, 40.67726947367191, 44.316828176379204, 45.70691138505936, 50.13665288686752, 50.046932101249695, 53.95580515265465, 54.034350737929344, 52.218838557600975, 51.55785262584686, 54.92371201515198, 54.31444890797138, 48.62121820449829, 43.252664878964424, 44.43877883255482, 41.57255083322525, 43.478646352887154, 46.005712151527405, 49.448582008481026, 43.44475597143173, 41.63755014538765, 41.6103246062994, 40.42569637298584, 38.13707917928696, 37.05954059958458, 37.113372310996056, 38.582894057035446, 38.80958989262581, 38.807974979281425, 42.91167117655277, 43.69094096124172, 42.515010461211205, 48.433656468987465, 50.36578059196472, 52.548881247639656, 47.75199964642525, 38.64269904792309, 36.73215016722679, 40.447138622403145, 39.5328164845705, 39.9842094630003, 39.788212180137634, 44.33702789247036, 49.17473450303078, 42.46214009821415, 40.470788553357124, 39.443593472242355, 40.054137110710144, 41.455992087721825, 40.94799354672432, 39.49237525463104, 40.59441111981869, 45.90339884161949, 51.488137766718864, 58.06566081941128, 51.367562636733055, 53.19242611527443, 45.21036922931671, 40.21457590162754, 37.806135937571526, 39.804308116436005, 37.55815364420414, 37.487371042370796, 39.42847028374672, 39.64569702744484, 39.67585600912571, 42.599278539419174, 44.99172896146774, 44.523723274469376, 43.37993524968624, 50.275581032037735, 48.3285541087389, 47.572159096598625, 40.084725469350815, 44.99807462096214, 44.563366547226906, 47.72161267697811, 52.72148318588734, 52.22217097878456, 52.62127496302128, 54.22726258635521, 54.08028267323971, 58.37420426309109, 43.435522466897964, 37.1698372811079, 56.941304951906204, 53.83500203490257, 55.58733120560646, 49.65323902666569, 43.12073975801468, 39.40501034259796, 41.34447567164898, 40.97089871764183, 43.78191187977791, 41.914600878953934, 43.375797271728516, 42.229353189468384, 43.471897915005684, 42.838620096445084, 43.268821612000465, 43.22054520249367, 48.9933056384325, 45.16871586441994, 47.13545233011246, 47.1995434910059, 61.49478301405907, 55.132731199264526, 59.775318279862404, 17.25189507007599, 0.4334341624053195, 0.3348839865066111, 0.4636713961372152, 2.2510730708017945, 56.80454649031162, 62.23654881119728, 59.44958075881004, 64.16431456804276, 54.25417274236679, 58.080065846443176, 49.27489712834358, 30.775939375162125, 30.48894077539444, 45.24496637284756, 37.6367562264204, 0.7637023762799799, 0.031462808983633295, 0.1959268975770101, 0.1250913509284146, 0.051339601777726784, 0.013554746583395172, 0.03789439062529709, 0.05958489957265556, 0.049551463744137436, 0.0030039538114579045, 0.032529898599023, 0.014470810074271867, 0.055286517526838, 0.08990018497570418, 0.730493227019906, 0.014445133620029083, 23.336468674242496, 75.28827086091042, 46.29492983222008, 38.45159970223904, 53.935145661234856, 49.00266073644161, 47.331529408693314, 69.01146367192268, 55.480830520391464, 58.2398434728384, 61.5986542403698, 63.383673056960106, 47.60915771126747, 0.10061356908408925, 0.19705607526702806, 2.787316683679819, 7.4617004580795765, 1.4082309161312878, 0.19175877358065918, 18.380808793008327, 67.41007760167122, 60.02037853002548, 59.156217500567436, 53.33271078765392, 60.73254391551018, 58.82425211369991, 58.46812002360821, 55.07827632129192, 55.64232565462589, 51.206607073545456, 48.59371908009052, 44.965198785066605, 41.45246207714081, 41.708283349871635, 40.686540976166725, 42.945683151483536, 42.72822842001915, 44.519076123833656, 45.487856939435005, 47.11411267518997, 52.2113985568285, 51.439310386776924, 54.62566360831261, 56.06128357350826, 54.24914941191673, 52.49469995498657, 55.46520955860615, 55.35848468542099, 50.980306416749954, 44.897258430719376, 47.29222431778908, 43.0455531924963, 47.249396815896034, 49.732514172792435, 51.37346751987934, 47.02967740595341, 44.95626926422119, 43.93692456185818, 41.199448853731155, 40.33484324812889, 40.32672308385372, 38.51649262011051, 40.59919886291027, 41.40530660748482, 43.06688904762268, 43.55323635041714, 45.63713192939758, 44.34232100844383, 49.91538316011429, 55.07946565747261, 55.14387220144272, 50.252634063363075, 40.385046154260635, 37.9218815267086, 39.64026711881161, 37.87622317671776, 38.910748064517975, 39.61455389857292, 45.17358340322971, 50.13488978147507, 43.677189499139786, 39.19091463088989, 38.89557547867298, 40.15862390398979, 41.297103613615036, 42.707420736551285, 40.78707978129387, 41.090972274541855, 45.28222717344761, 52.83551886677742, 59.687371999025345, 56.46190747618675, 53.597719967365265, 46.40779137611389, 41.88017852604389, 40.47870732843876, 41.69328935444355, 39.48412209749222, 39.23831328749657, 40.0399486720562, 42.0983362197876, 41.79500989615917, 44.394898787140846, 47.017962634563446, 46.619592010974884, 46.77235521376133, 51.61989949643612, 50.194861963391304, 48.536851331591606, 43.2028229534626, 47.040085047483444, 46.2943484634161, 50.089945793151855, 55.66270776093006, 53.962071016430855, 55.19863486289978, 55.06233997642994, 52.0603908598423, 56.25323787331581, 48.84121119976044, 39.5144634693861, 57.17033386230469, 56.37132413685322, 57.20537558197975, 53.48718009889126, 45.3188382089138, 41.292342469096184, 43.193171471357346, 43.52389432489872, 45.013528391718864, 43.19230131804943, 45.409607738256454, 43.90612721443176, 46.92079424858093, 45.428979098796844, 45.93202270567417, 46.01902663707733, 50.07169917225838, 47.83806122839451, 49.92320694029331, 50.89861460030079, 63.58472786843777, 58.71594652533531, 65.84461480379105, 24.76540669798851, 0.5335936113260686, 1.7153062135912478, 0.26633156812749803, 2.9546625539660454, 61.26292705535889, 66.94818958640099, 65.18223434686661, 69.08225387334824, 62.96359799802303, 60.7427653670311, 59.97120916843414, 38.036635369062424, 29.48542032390833, 55.29549166560173, 44.96272511780262, 0.964050010079518, 0.052583274300559424, 0.13322401297045872, 0.06866140276542865, 0.04694468116213102, 0.0056577187478978885, 0.06698555167531595, 0.24354249879252166, 0.20003996905870736, 0.10370787960710004, 0.14570724859368056, 0.1048669138981495, 0.14004400873091072, 0.2840051322709769, 0.9945908118970692, 0.28160024725366384, 24.49936207383871, 88.730209171772, 55.044226348400116, 50.29194675385952, 48.48851792514324, 53.990052714943886, 55.5152490735054, 74.4384540617466, 61.33614532649517, 65.07571086287498, 66.99998080730438, 67.72740617394447, 54.455067962408066, 1.4990307250991464, 0.47536292346194386, 7.590388152748346, 15.160408448427916, 2.968155392445624, 0.29313693288713694, 19.287176057696342, 70.09957328438759, 66.00349947810173, 60.92715427279472, 56.38918697834015, 61.42029941082001, 61.70021139085293, 59.732684567570686, 58.370172679424286, 58.300233632326126, 55.543952733278275, 50.396748930215836, 45.67658521234989, 43.94815295934677, 46.326775923371315, 43.08507867157459, 45.07876709103584, 45.341701582074165, 48.08791682124138, 48.3050561696291, 50.49098387360573, 54.63227905333042, 52.68052898347378, 56.283545047044754, 58.38258661329746, 56.70806586742401, 54.25053633749485, 60.53330920636654, 56.74633361399174, 52.10067629814148, 47.455904334783554, 49.11854311823845, 44.96715188026428, 48.27262870967388, 50.960737466812134, 56.05058714747429, 48.8116829842329, 46.74504227936268, 46.68130449950695, 43.34218427538872, 41.760215163230896, 42.4685275554657, 41.92329861223698, 44.47173446416855, 43.16574074327946, 44.94226321578026, 47.26998411118984, 49.097420051693916, 47.97159746289253, 54.95912991464138, 56.863238140940666, 58.042428866028786, 52.49875433743, 41.90184876322746, 38.058032020926476, 41.65786765515804, 39.29352052509785, 39.50216732919216, 39.7416190803051, 46.12900033593178, 51.96602292358875, 43.66847276687622, 38.810676634311676, 40.944474935531616, 39.567314833402634, 42.36229665577412, 41.501183062791824, 41.156039983034134, 41.209396719932556, 45.999537482857704, 54.28148567676544, 61.91715694963932, 58.09487745165825, 58.611091151833534, 49.07336734235287, 46.04417748749256, 43.01962338387966, 45.715647116303444, 41.027812063694, 41.67810156941414, 43.95596534013748, 43.32950055599213, 44.02703292667866, 46.03201054036617, 49.05742719769478, 49.700117111206055, 47.403330355882645, 55.52974529564381, 52.71130733191967, 51.476012617349625, 45.842655301094055, 49.57990676164627, 47.40557223558426, 51.83774560689926, 56.99246920645237, 54.898241981863976, 57.75481849908829, 57.23049983382225, 54.577649384737015, 54.162354469299316, 45.61053715646267, 43.62346798181534, 59.22122061252594, 58.061929419636726, 59.237586334347725, 53.90790492296219, 45.374630615115166, 45.02735584974289, 45.151863768696785, 46.62154130637646, 48.101033717393875, 45.72588376700878, 47.813275158405304, 46.16397745907307, 48.38613621890545, 47.154512107372284, 47.39122420549393, 47.22714141011238, 53.22115257382393, 50.11501304805279, 52.8568509221077, 52.65429139137268, 66.83294177055359, 62.796881943941116, 68.65746706724167, 33.55169802904129, 0.39742649300023913, 2.22750554792583, 1.001476279925555, 3.4017320768907666, 65.33544972538948, 72.85586938261986, 71.62797287106514, 75.24456560611725, 66.99865087866783, 71.70267686247826, 66.18203669786453, 44.424362406134605, 40.82171492278576, 65.74217230081558, 57.669167295098305, 1.9726274558342993, 0.3076539054745808, 0.2553185122087598, 0.18976996623678133, 0.10899899920332246, 0.13459924230119213, 0.14247863902710378], [0.010381540196249261, 0.03845821505819913, 0.032184874144149944, 0.11102304371888749, 0.028127879340900108, 0.09764370188349858, 0.014087177241890458, 0.47051191970240325, 0.10653155113686807, 5.394361540675163, 61.14689268171787, 47.20877319574356, 40.16352944076061, 20.778594128787518, 25.28691541403532, 49.426638185977936, 61.51089034974575, 56.533769220113754, 43.27591963112354, 59.8081561177969, 52.78009504079819, 57.79603868722916, 7.020116178318858, 0.6809964892454445, 0.34379887219984084, 5.182614577934146, 2.146681984886527, 0.028213304249220528, 6.222975002601743, 59.445260390639305, 61.04729622602463, 53.75170670449734, 54.6777968108654, 60.34724839031696, 57.35177032649517, 57.889232486486435, 54.257881343364716, 52.093452885746956, 48.69194380939007, 43.33775371313095, 41.49725027382374, 39.93289701640606, 39.663271084427834, 40.53769916296005, 41.27212755382061, 39.288964569568634, 40.12620024383068, 39.54487703740597, 43.59009437263012, 44.959411695599556, 52.55285203456879, 50.06747379899025, 53.04692432284355, 51.744605004787445, 53.365487828850746, 52.680604979395866, 51.811534613370895, 49.539830312132835, 45.254492461681366, 44.709768891334534, 40.37143908441067, 43.8602826744318, 44.70811977982521, 46.20080888271332, 46.446435302495956, 42.48253360390663, 42.280772030353546, 40.585208013653755, 40.79453498125076, 38.01049277186394, 37.25643463432789, 38.856931552290916, 39.9063516408205, 42.61752896010876, 43.67636114358902, 43.412043526768684, 47.265990525484085, 50.3383232653141, 54.10433918237686, 53.49142827093601, 49.02951769530773, 40.38433559238911, 39.29425768554211, 38.82018752396107, 38.575252667069435, 39.246577844023705, 37.745278403162956, 45.81693448126316, 48.02783824503422, 44.546712040901184, 40.01479782164097, 40.06028898060322, 39.54284034669399, 41.26395419239998, 38.27864818274975, 38.54089871048927, 41.66214242577553, 41.221700459718704, 48.95895928144455, 55.33017620444298, 54.15238760411739, 53.45861703157425, 45.461737141013145, 41.59583978354931, 39.97371822595596, 39.687103405594826, 39.71861891448498, 36.44115038216114, 37.03419975936413, 37.4637933075428, 39.47080761194229, 46.54258154332638, 50.17259895801544, 46.173750534653664, 44.065019488334656, 49.0787136554718, 49.46275904774666, 44.22023355960846, 42.41151161491871, 44.00912068784237, 46.23367331922054, 51.556902676820755, 55.14396719634533, 51.97211779654026, 53.05421233177185, 61.698030307888985, 56.93984962999821, 41.202997863292694, 38.81951875984669, 55.51834210753441, 55.54175645112991, 55.041498094797134, 48.62213395535946, 43.01349051296711, 40.33195160329342, 41.92816235125065, 40.86880959570408, 42.15967632830143, 41.39288127422333, 40.99839024245739, 41.68148718774319, 43.00145275890827, 42.71013379096985, 41.571996062994, 43.428979218006134, 42.77452513575554, 42.54982419312, 42.88552477955818, 46.35248154401779, 52.54332974553108, 59.73657935857773, 55.714350789785385, 59.31513637304306, 8.48046949133277, 0.7680967811029404, 0.9919345169328153, 0.8818261628039181, 7.332511665299535, 62.265313267707825, 60.360866859555244, 50.451055616140366, 56.053611785173416, 40.82618348300457, 57.45025344192982, 38.43343287706375, 28.207738883793354, 28.781111016869545, 47.23895877599716, 29.80090219527483, 1.0966432420536876, 0.08114965530694462, 0.17851017590146512, 0.012914219332742505, 0.07978019246365875, 0.008660109178890707, 0.13787321193376556, 0.0118039061089803, 0.04600354513968341, 0.07595133385621011, 0.02887519236537628, 0.0410294413450174, 0.030151680803101044, 0.015565692192467395, 0.5474662513006479, 0.056384090858045965, 7.611055243760347, 74.0560045838356, 53.570296838879585, 43.76202754676342, 29.256098829209805, 39.47977893054485, 50.91941848397255, 68.48953127861023, 62.54353053867817, 50.92014044523239, 63.49653460085392, 58.63440290093422, 60.871966034173965, 8.015070464462042, 0.4028227675007656, 1.8034766823984683, 10.65366692841053, 3.4975135372951627, 0.016403111221734434, 8.464165516197681, 65.28919100761414, 61.84271514415741, 56.550697311758995, 55.77084235846996, 64.09819051623344, 57.6492715626955, 60.108499601483345, 54.68704551458359, 54.89834077656269, 51.55555374920368, 47.76148773729801, 42.44781106710434, 42.67354175448418, 41.90812602639198, 41.873209699988365, 43.0458115786314, 40.78190065920353, 42.18703106045723, 42.883605882525444, 44.61627870798111, 47.67754644155502, 52.83306419849396, 51.34156823158264, 53.049500584602356, 51.0853061825037, 55.62249831855297, 55.4230622202158, 53.223113268613815, 52.28003807365894, 48.121674209833145, 47.01150298118591, 43.58140803873539, 46.52669079601765, 48.94958898425102, 50.338566452264786, 48.55321325361729, 44.885433465242386, 44.13978807628155, 41.15979418158531, 43.26048485934734, 39.98139001429081, 39.04256299138069, 40.51593393087387, 41.56490944325924, 45.58770418167114, 46.28686286509037, 47.72555686533451, 47.23835080862045, 52.15336047112942, 52.44115322828293, 56.849209293723106, 51.682656928896904, 40.8297248929739, 39.12505276501179, 39.1722272336483, 38.12872342765331, 38.78725469112396, 38.25650297105312, 47.202370539307594, 49.82053644955158, 44.88752335309982, 38.87666389346123, 40.33914461731911, 39.11248303949833, 40.59565745294094, 39.200957491993904, 39.268848448991776, 41.624357253313065, 42.56678268313408, 50.175543799996376, 57.2677568346262, 57.730412408709526, 54.585993736982346, 49.44857820868492, 45.38629598915577, 41.2814636528492, 41.468812599778175, 41.35333679616451, 38.2596530020237, 39.37454357743263, 40.652213618159294, 41.487610191106796, 47.73667886853218, 52.3373693972826, 47.09023855626583, 48.820088133215904, 50.64090482890606, 51.162932217121124, 45.82615278661251, 43.18457253277302, 45.13535365462303, 48.322204649448395, 54.468694031238556, 55.24003744125366, 53.47425699234009, 51.799683049321175, 58.33187833428383, 55.325646847486496, 46.92597717046738, 39.205152466893196, 57.56224483251572, 58.77627968788147, 57.2772791236639, 52.70793691277504, 45.379243567585945, 42.25087523460388, 41.527424454689026, 41.917302533984184, 44.560440704226494, 42.512206211686134, 43.4676269441843, 44.17106419801712, 45.561766773462296, 44.734475165605545, 43.81622023880482, 45.88660754263401, 44.590899869799614, 45.25152862071991, 45.50753228366375, 49.60402026772499, 54.65085245668888, 61.45268127322197, 59.217306822538376, 63.7340484559536, 10.89263515546918, 0.8418417989742011, 2.480434225872159, 0.9360694396309555, 7.456348920240998, 71.01663127541542, 65.42795956134796, 63.12226228415966, 65.96244648098946, 49.278244748711586, 62.92308457195759, 46.68405935168266, 28.587980680167675, 27.978217899799347, 55.40832661092281, 36.293000131845474, 1.129978853277862, 0.028887658590974752, 0.13460737623972818, 0.03352607600390911, 0.029787323401251342, 0.02219040663476335, 0.09987303928937763, 0.11668076942441985, 0.1755323083489202, 0.13812641787808388, 0.13755152060184628, 0.13026253203861415, 0.3473934199428186, 0.15757267596200109, 0.6124050042126328, 0.17144208017271012, 8.09305178001523, 83.90595003962517, 66.11960604786873, 55.11197291314602, 32.06231854856014, 41.014360785484314, 59.985264614224434, 77.99511641263962, 67.54324525594711, 55.07020555436611, 70.495246052742, 63.67697171866894, 68.1102204322815, 12.217850144952536, 0.8643245988059789, 5.719336727634072, 16.42261426895857, 4.525260301306844, 0.09576981610734947, 9.48685023933649, 66.10977977514267, 66.72094658017159, 59.361471086740494, 58.0209182202816, 66.0754220187664, 58.829142451286316, 61.429867297410965, 58.594892621040344, 56.3685616850853, 54.11467842757702, 48.20038698613644, 46.6719152033329, 43.72681103646755, 44.308168441057205, 45.44495724141598, 45.68875215947628, 42.02941171824932, 44.18865725398064, 44.79947827756405, 46.83600939810276, 49.73861284554005, 55.535729974508286, 53.73412124812603, 57.896547093987465, 55.267498567700386, 57.53448352217674, 58.040722757577896, 57.4105341732502, 55.402129143476486, 50.7561070472002, 48.88733692467213, 45.38326755166054, 49.8617984354496, 51.83516554534435, 52.521199733018875, 50.46277038753033, 46.865161433815956, 46.31226450204849, 42.705011665821075, 46.42809748649597, 43.55796329677105, 41.27245433628559, 43.657696545124054, 44.357900172472, 48.218796998262405, 51.582627296447754, 50.98493076860905, 52.6906668394804, 54.752428606152534, 57.85788796842098, 59.274220168590546, 54.37096707522869, 41.890950947999954, 39.92569640278816, 39.143204391002655, 37.846360579133034, 40.216449201107025, 39.02634546160698, 48.273472264409065, 51.845706179738045, 47.61803783476353, 41.189132407307625, 39.943407252430916, 38.84159937500954, 40.385851711034775, 39.30736318230629, 38.58863174915314, 41.59135602414608, 42.96056695282459, 51.88604101538658, 60.623337775468826, 60.907946303486824, 57.47426055371761, 52.487396746873856, 47.14833363890648, 44.10974308848381, 43.93475107848644, 43.95441122353077, 39.971138164401054, 41.064559891819954, 41.461763978004456, 42.15039722621441, 49.880504831671715, 55.82535803318024, 50.41520453989506, 52.04747915267944, 52.29410871863365, 55.19456148147583, 47.80396185815334, 46.830894872546196, 47.12539806962013, 50.94364978373051, 55.608036294579506, 58.02997313439846, 55.48043914139271, 54.85617823898792, 60.27417451143265, 54.90459904074669, 45.38744732737541, 45.98966561257839, 58.87098580598831, 59.02502194046974, 60.632065907120705, 54.849817380309105, 48.20826016366482, 43.63667607307434, 46.78077936172485, 45.54081089794636, 46.71913526952267, 44.921516329050064, 45.27873896062374, 45.93176431953907, 49.21450696885586, 47.483285665512085, 48.51763196289539, 47.98585809767246, 47.28303641080856, 48.42471934854984, 46.860050708055496, 52.83268041908741, 57.57849656045437, 64.33273673057556, 63.196183517575264, 70.61803266406059, 15.947345271706581, 0.7120057346764952, 7.331053018569946, 1.653834655880928, 8.380050379782915, 75.32155707478523, 71.0057258605957, 63.31756040453911, 68.28162923455238, 55.4963792860508, 68.30261930823326, 55.190879479050636, 40.5419397354126, 40.31262204051018, 64.29052859544754, 49.186145290732384, 1.4929497451521456, 0.21012412325944752, 0.22477934311609715, 0.1162589029991068, 0.13614752562716603, 0.0832938683743123, 0.3301227529300377], [0.05107870347274002, 0.02095993135299068, 0.022854732706036884, 0.10318607557564974, 0.018301565796718933, 0.010398171725682914, 0.010112869749718811, 0.12058977255946957, 0.2918253204552457, 0.3372075024526566, 44.71926458179951, 54.56344194710255, 35.952652394771576, 32.55221106112003, 27.22195018082857, 49.17627342045307, 62.73665517568588, 57.93723911046982, 54.24314573407173, 62.0716642588377, 48.703954964876175, 60.54818540811539, 25.50009537488222, 0.19207610108423978, 2.105992818251252, 2.6400833716616035, 0.763756464002654, 0.11745656607672572, 5.323530491441488, 53.96754652261734, 67.10022702813148, 54.81641337275505, 58.73033635318279, 55.12339890003204, 56.598692536354065, 55.22400230169296, 55.75291872024536, 53.76188635826111, 49.00253914296627, 45.931357741355896, 41.82769574224949, 40.51398083567619, 41.01706624031067, 38.49791161715984, 39.909775257110596, 37.70659267902374, 39.37707044184208, 38.741638138890266, 44.377548918128014, 40.16934312880039, 45.22028669714928, 45.75291931629181, 51.392816081643105, 52.370036244392395, 50.179100409150124, 50.515359565615654, 52.841670736670494, 50.25002360343933, 45.59349127113819, 44.32142972946167, 42.2876800596714, 39.74583685398102, 46.704452857375145, 48.503485321998596, 41.57049514353275, 42.649546042084694, 43.399773985147476, 39.49935168027878, 39.49424095451832, 37.94495768845081, 37.96840623021126, 39.956045374274254, 39.55486670136452, 42.4990551173687, 43.446397483348846, 48.12083825469017, 48.039917796850204, 49.80600222945213, 53.436240032315254, 52.844946160912514, 55.284065678715706, 43.782269060611725, 39.32577319443226, 38.87997351586819, 37.31999382376671, 39.5855538547039, 35.864223539829254, 43.81429374217987, 51.84102103114128, 44.153307750821114, 40.95530815422535, 42.05118075013161, 40.082377195358276, 40.71570821106434, 39.185195937752724, 39.679093435406685, 40.839684158563614, 39.948346987366676, 50.01183718442917, 54.535794630646706, 53.36166523396969, 50.07513798773289, 47.03682862222195, 44.134453162550926, 42.80402295291424, 39.65682663023472, 38.71937893331051, 37.72477850317955, 38.953256383538246, 37.834235429763794, 38.10978524386883, 40.46551063656807, 48.59268933534622, 48.85951481759548, 46.77182324230671, 48.12702052295208, 48.150339871644974, 42.624284997582436, 41.1788197606802, 44.943357557058334, 47.10622809827328, 51.818925216794014, 56.28282688558102, 46.36555664241314, 40.01904219388962, 46.04925401508808, 43.08818690478802, 44.98377598822117, 55.68125456571579, 53.463587164878845, 51.3369020819664, 47.83440202474594, 41.42991788685322, 41.267526000738144, 39.81090076267719, 41.08093321323395, 40.59475690126419, 42.31910817325115, 42.687422409653664, 40.075453966856, 41.16767875850201, 42.65610449016094, 42.23372295498848, 44.24072206020355, 42.602949142456055, 44.32849735021591, 43.70969295501709, 45.153174698352814, 53.10406185686588, 56.11563205718994, 57.700956389307976, 53.26690971851349, 54.84018489718437, 1.814087019301951, 0.05542437516851351, 1.8721558596007526, 0.8442588255275041, 18.050103038549423, 65.32605662941933, 56.708145663142204, 43.86390008032322, 46.83671236038208, 49.95536461472511, 56.25304028391838, 41.14329546689987, 33.46832290291786, 31.110019348561764, 47.54445858299732, 30.12375947088003, 0.7351117604412138, 0.02155311329261167, 0.031375732796732336, 0.057774652959778905, 0.14240421645808965, 0.08190104272216558, 0.09235506848199293, 0.04350573581177741, 0.0503045098594157, 0.02322479907888919, 0.0425933505903231, 0.021937020719633438, 0.016915783126023598, 0.007329066856982536, 0.15281675616279244, 0.26668702717870474, 1.0560180782340467, 55.378616005182266, 61.335617154836655, 40.82025960087776, 34.12347234785557, 36.1961205303669, 56.631465777754784, 70.83257675170898, 62.948429211974144, 54.40410889685154, 69.68332082033157, 55.21558955311775, 66.87758937478065, 28.088862262666225, 0.2620912331622094, 2.445541648194194, 7.404875457286835, 5.4480707086622715, 0.17351403774227947, 6.049387017264962, 58.605304062366486, 67.82743960618973, 57.544613778591156, 60.034057796001434, 58.20585049688816, 57.995942160487175, 58.60218062996864, 57.60650485754013, 53.77513624727726, 52.576851546764374, 47.34298959374428, 43.123008236289024, 43.29426124691963, 41.96063920855522, 41.43002808094025, 41.54747977852821, 40.018054246902466, 40.11687934398651, 42.02250748872757, 43.86243715882301, 42.63464704155922, 48.048630729317665, 46.84681981801987, 53.97601626813412, 53.22736144065857, 52.942996099591255, 53.10276612639427, 54.46766048669815, 51.44677698612213, 49.0014486014843, 45.83500251173973, 42.2387120872736, 43.72410178184509, 49.65594068169594, 50.65643459558487, 46.54382407665253, 46.5419165790081, 43.78597766160965, 42.55854092538357, 40.87573662400246, 39.91960912942886, 39.85064662992954, 42.59000703692436, 41.92104913294315, 45.39024397730827, 46.566178277134895, 48.66114266216755, 51.62071265280247, 52.754625007510185, 54.83773022890091, 55.28879642486572, 56.75699584186077, 43.95025424659252, 39.168055057525635, 38.856638967990875, 38.0429620295763, 38.99147853255272, 36.25482738018036, 45.211820751428604, 54.0129616856575, 45.749047324061394, 40.183022394776344, 40.0633630156517, 39.952496364712715, 39.68722499907017, 39.67626638710499, 39.61695916950703, 41.03273659944534, 39.55513648688793, 51.22431792318821, 57.77104362845421, 57.79729261994362, 52.24611349403858, 48.63643258810043, 47.211588844656944, 43.556397780776024, 42.67099589109421, 41.16538368165493, 40.44561110436916, 40.79146094620228, 38.90072040259838, 41.09240099787712, 42.51362353563309, 50.99686972796917, 51.74792602658272, 49.33542028069496, 51.43112562596798, 51.06488607823849, 44.98575568199158, 42.82053306698799, 46.16146199405193, 49.90163929760456, 52.94939115643501, 58.65378946065903, 47.30046987533569, 38.79953183233738, 47.60400518774986, 47.50736877322197, 46.28524035215378, 57.00842835009098, 56.01539343595505, 52.72286631166935, 49.95702512562275, 41.93431422114372, 42.710525169968605, 42.8333193808794, 42.26892426609993, 42.158498391509056, 44.25431773066521, 44.098856672644615, 42.06308551132679, 45.0189621001482, 45.02910755574703, 43.722209483385086, 44.335899353027344, 44.99653570353985, 47.211041674017906, 47.569054663181305, 47.11075745522976, 56.47546894848347, 59.04391072690487, 62.07338936626911, 56.20900824666023, 58.20286385715008, 2.0919694332405925, 0.22825713618658483, 5.281285783275962, 1.1883861129172146, 20.072525516152382, 72.710040807724, 62.602111995220184, 47.89897955954075, 46.49729557335377, 55.03657355904579, 58.48558768630028, 53.554793670773506, 33.72839614748955, 30.480206944048405, 58.511114716529846, 35.95559723675251, 0.5709373543504626, 0.050814873684430495, 0.06806289035012014, 0.016507297623320483, 0.12635828607017174, 0.08330327880685218, 0.08269835423561744, 0.1475344310165383, 0.06540130387293175, 0.0653190293814987, 0.15464141528354958, 0.15999485302018002, 0.13973919383715838, 0.10818616938195191, 0.2737479389179498, 0.3409708145773038, 1.0744437645189464, 63.06554652750492, 74.99968394637108, 54.757068157196045, 41.0543954372406, 42.34242372214794, 59.9820651859045, 71.6426932811737, 70.27191683650017, 64.85393956303596, 76.29517123103142, 57.92156495153904, 72.75996252894402, 31.506843455135822, 0.2678608673159033, 5.7291254773736, 14.081393647938967, 4.366664411500096, 0.3006767079932615, 7.83006171695888, 60.32933995127678, 71.39905035495758, 61.845515593886375, 63.32873560488224, 60.40099270641804, 59.65060517191887, 60.8388964086771, 60.43948084115982, 57.64017105102539, 54.7921022772789, 50.15200026333332, 45.659155547618866, 45.65917454659939, 44.01251010596752, 42.89062790572643, 43.06785799562931, 41.927850767970085, 42.945922538638115, 42.21973590552807, 47.486466094851494, 44.03246283531189, 50.622673407197, 48.413057774305344, 57.21370093524456, 58.71570713818073, 53.94481614232063, 54.58891957998276, 57.42496579885483, 55.28499662876129, 52.86824271082878, 48.53734150528908, 47.53486789762974, 44.67758461833, 52.952024415135384, 55.85187301039696, 47.575768902897835, 48.66485886275768, 47.53779374063015, 44.889556244015694, 44.68093603849411, 42.627294436097145, 41.79775334894657, 46.12100176513195, 44.73051197826862, 50.50764977931976, 49.317519441246986, 51.68517619371414, 54.32314284145832, 56.90970204770565, 57.4359168112278, 58.90435941517353, 58.10964725911617, 45.504853427410126, 39.07463327050209, 38.21571595966816, 37.63531610369682, 39.68055635690689, 35.547594130039215, 44.847598895430565, 55.994099378585815, 46.82748645544052, 41.28093168139458, 41.22885927557945, 40.74349991977215, 40.61086043715477, 39.19458143413067, 40.66161431372166, 40.98184213042259, 40.062781646847725, 53.82682107388973, 60.174323469400406, 59.237681329250336, 55.26440933346748, 50.84936924278736, 49.672591388225555, 47.41687662899494, 44.045055359601974, 42.152924090623856, 41.135650277137756, 43.24519447982311, 42.020497396588326, 43.88315364718437, 44.80883717536926, 53.38567994534969, 57.00984187424183, 52.43441618978977, 54.137674793601036, 52.64050953090191, 46.81060016155243, 45.017438381910324, 48.69414009153843, 51.35161869227886, 55.342042967677116, 59.55275662243366, 49.27035637199879, 40.46245940029621, 49.821114018559456, 52.88341149687767, 51.90083362162113, 58.58491815626621, 57.33505502343178, 55.64997464418411, 53.42321053147316, 44.30021546781063, 45.17699182033539, 44.875580593943596, 45.3256968408823, 42.70052030682564, 46.21876671910286, 47.17880800366402, 43.85245509445667, 47.94577404856682, 48.73966924846172, 46.33609302341938, 48.408600613474846, 45.626458302140236, 47.990224063396454, 49.71348099410534, 48.01236927509308, 60.38816079497337, 61.570011377334595, 65.97852721810341, 59.068662598729134, 63.970661759376526, 3.700916147790849, 0.42205018107779324, 8.97278057411313, 1.6786812851205468, 23.79838328808546, 77.85453915596008, 66.20880246162415, 53.80951680243015, 59.505886137485504, 64.72983062267303, 64.66355457901955, 59.725909531116486, 47.13357523083687, 45.434526801109314, 70.98611891269684, 46.19438722729683, 0.9814504638779908, 0.12349377415375784, 0.1660387997981161, 0.17542929825140163, 0.28644106874708086, 0.13486402574926615, 0.13555281300796196], [0.03517261597153265, 0.03341104311402887, 0.03537748954840936, 0.012247269769432023, 0.09063924531801604, 0.06371825395035557, 0.05834193580085412, 0.05168039970158134, 0.6372424901928753, 0.18822741229087114, 21.131433695554733, 68.82309257984161, 43.978323340415955, 38.0782051384449, 26.672284975647926, 35.91965116560459, 42.199547588825226, 57.64421783387661, 59.192600548267365, 57.77763247489929, 53.29349689185619, 52.360825538635254, 50.777598693966866, 1.7364430543966591, 1.1769126285798848, 7.0499830506742, 6.773262424394488, 0.1720328742521815, 1.8094034143723547, 41.26172751188278, 61.552346125245094, 58.704398944973946, 53.68493288755417, 59.53689627349377, 55.940427258610725, 55.290316343307495, 56.669592931866646, 50.874052718281746, 45.58519631624222, 42.35609918832779, 40.90821348130703, 40.41917212307453, 39.582099840044975, 40.25233447551727, 40.352854281663895, 41.08497619628906, 38.96035440266132, 39.38091583549976, 39.6615269780159, 42.13056229054928, 41.54724799096584, 43.99352252483368, 44.79928828775883, 45.299881026148796, 47.52765968441963, 48.2199901342392, 48.29885110259056, 49.87932309508324, 46.41007125377655, 46.58216781914234, 41.3438069075346, 40.83031006157398, 46.49115890264511, 43.81381876766682, 45.45125350356102, 43.65972563624382, 41.9278659671545, 42.58977524936199, 39.105157032608986, 39.08614285290241, 39.488784447312355, 41.15049988031387, 41.25532865524292, 43.66887554526329, 47.58986234664917, 51.91662937402725, 48.18353869020939, 49.50975872576237, 54.56115446984768, 53.92301291227341, 52.790555879473686, 46.9302861392498, 39.27896350622177, 39.43869173526764, 36.48288734257221, 39.526797607541084, 38.40794764459133, 43.054030537605286, 50.45027665793896, 42.716160267591476, 41.49454481899738, 40.53836792707443, 40.55607497692108, 39.882367327809334, 41.01480156183243, 41.06273218989372, 39.41341169178486, 43.54282110929489, 54.6506092697382, 55.762121826410294, 52.66299672424793, 53.403766974806786, 45.86114510893822, 46.507000252604485, 47.67274729907513, 39.41792964935303, 38.91389049589634, 38.203792199492455, 38.72113063931465, 37.10311286151409, 36.31030820310116, 37.19673603773117, 41.632743403315544, 47.22117953002453, 47.701986730098724, 48.9898744225502, 48.30532595515251, 43.18444713950157, 40.89226573705673, 43.493636548519135, 47.845337837934494, 51.55242271721363, 50.07714428007603, 50.13803981244564, 51.648975536227226, 49.58236522972584, 54.022681564092636, 57.380405589938164, 50.0694040954113, 50.179829970002174, 42.55349479615688, 39.955410808324814, 41.72487325966358, 40.58080404996872, 39.80028413236141, 40.961847603321075, 42.27712042629719, 42.92269438505173, 43.613596111536026, 43.971335515379906, 41.30339987576008, 40.64229995012283, 40.18234983086586, 41.932292729616165, 42.609997764229774, 43.025353476405144, 44.115157797932625, 51.33437901735306, 57.869629338383675, 60.425087213516235, 57.553231716156006, 63.02148789167404, 36.87965825200081, 0.11133522813906893, 0.5939270707312971, 2.373649743385613, 0.1742202357854694, 35.351840034127235, 66.74575924873352, 53.53483334183693, 56.708198860287666, 65.51059752702713, 62.53854140639305, 58.37653733789921, 36.813386008143425, 18.673702776432037, 20.959568917751312, 55.03759190440178, 15.98433818668127, 0.8123964664991945, 0.01502644026913913, 0.11490836492157541, 0.05849721906997729, 0.14468958601355553, 0.023665265580348205, 0.02663712359208148, 0.017880285668070428, 0.08003308670595288, 0.034281586049473844, 0.04909171810140833, 0.08721732112462632, 0.03757514466997236, 0.07762706620269455, 0.05417152227892075, 0.482689316268079, 0.19324440479977056, 27.49593637883663, 78.09400990605354, 48.01810696721077, 42.85009928047657, 42.28584095835686, 46.044762656092644, 52.68044538795948, 63.67450185120106, 64.58912417292595, 63.50493215024471, 57.95577451586723, 57.64128819108009, 53.18601205945015, 1.8828943208791316, 1.3687369041144848, 4.2506765853613615, 7.7470812946558, 0.13834454992320389, 2.4360609194263816, 44.98899690806866, 64.04804080724716, 61.20861656963825, 57.81961262226105, 60.266111344099045, 59.41374108195305, 56.80689096450806, 57.90008470416069, 53.850455805659294, 47.42201775312424, 45.4995983093977, 42.983027547597885, 42.66171298921108, 41.518111154437065, 43.03949631750584, 39.78300265967846, 41.032326221466064, 40.925582349300385, 41.58692926168442, 41.97036288678646, 43.77449467778206, 43.78529749810696, 46.306899189949036, 47.23558075726032, 48.332091718912125, 49.47693228721619, 49.53176334500313, 49.5508649200201, 51.06915704905987, 49.983141124248505, 50.75643002986908, 43.05214203894138, 42.526390850543976, 47.740216478705406, 46.79606594145298, 47.53954544663429, 46.184701547026634, 43.86173419654369, 43.4159155189991, 43.65005515515804, 40.86497560143471, 41.395879313349724, 42.292365208268166, 44.6508264541626, 47.963256910443306, 50.4136960208416, 52.27662205696106, 50.28144791722298, 52.026599273085594, 56.12076558172703, 54.36537757515907, 55.638795644044876, 47.53651320934296, 38.405394181609154, 37.896723076701164, 36.06742903590202, 40.66503033041954, 38.30241210758686, 44.32907871901989, 53.942699655890465, 43.98463860154152, 39.575814977288246, 40.60228809714317, 40.921672359108925, 40.423933267593384, 39.34595011174679, 40.9608406573534, 39.365412667393684, 44.42402042448521, 57.42873139679432, 58.38352516293526, 55.738069117069244, 55.12169659137726, 48.201390132308006, 49.37285967171192, 48.41849908232689, 42.02778920531273, 41.40909880399704, 40.804148465394974, 41.28906324505806, 38.722050189971924, 38.913628309965134, 38.29813353717327, 43.365822806954384, 50.23094862699509, 48.92620123922825, 50.59831291437149, 50.122221261262894, 44.27397407591343, 43.366081193089485, 44.71536599099636, 50.20108222961426, 54.786919355392456, 51.879801750183105, 51.68964855372906, 54.656198769807816, 52.97460660338402, 56.1008470505476, 59.06826741993427, 53.49693417549133, 52.21052460372448, 45.310752242803574, 42.16153062880039, 42.30691842734814, 42.65466436743736, 42.17158488929272, 41.300242245197296, 43.39077986776829, 46.71087831258774, 46.55111588537693, 47.07663528621197, 43.9258823543787, 43.33984360098839, 42.34393984079361, 43.16580913960934, 45.1589921861887, 46.48576699197292, 46.77619680762291, 53.64832945168018, 60.85252247750759, 63.64424407482147, 59.99114669859409, 65.68642169237137, 38.49349245429039, 0.09268635578337125, 0.19044987740926445, 2.6308299181982875, 0.12994100397918373, 38.998952731490135, 69.38110783696175, 59.222588539123535, 58.52847598493099, 65.27824759483337, 69.75129917263985, 62.3592746257782, 46.18123233318329, 21.593000628054142, 22.27414447814226, 64.37276378273964, 20.266556404531002, 0.6535115547012538, 0.015504911225434626, 0.08083960085059516, 0.057976075549959205, 0.08213179127778858, 0.025768734740267973, 0.01021508853227715, 0.1510050252545625, 0.17606189008802176, 0.16572464868659154, 0.17286403512116522, 0.2399819265701808, 0.11262027168413624, 0.12504931568400934, 0.19826634001219645, 0.7758538867346942, 0.34948535612784326, 31.35752286761999, 88.09625878930092, 61.15075707435608, 48.17827597260475, 40.16634128987789, 56.349300518631935, 61.27226695418358, 67.74558439850807, 70.83519101142883, 68.61678645014763, 65.81281051039696, 60.53271643817425, 59.79869842529297, 2.697989889420569, 2.4963021744042635, 16.482430659234524, 13.269417118281126, 0.2243646903662011, 3.364027887582779, 51.12460367381573, 64.55783665180206, 65.9009201824665, 58.84270392358303, 63.84270742535591, 59.95728671550751, 60.73488838970661, 59.41049985587597, 57.23821721971035, 51.51236906647682, 48.991557732224464, 45.43154776096344, 45.12931577861309, 43.93515005707741, 46.26372970640659, 41.96758523583412, 45.55913731455803, 42.90187910199165, 44.336416125297546, 44.24512982368469, 47.01884038746357, 46.444478407502174, 48.687395453453064, 47.25829213857651, 49.835484847426414, 51.77020043134689, 54.067769944667816, 52.538804188370705, 55.118143782019615, 51.76212966442108, 54.155879616737366, 45.2640413492918, 45.01313701272011, 49.43157032132149, 49.750943183898926, 51.382887214422226, 49.065228179097176, 45.749803483486176, 45.76268099248409, 45.70471130311489, 43.938148096203804, 43.551811426877975, 45.111825317144394, 48.164053335785866, 50.78612923622131, 54.02309954166412, 57.725506871938705, 53.072523549199104, 53.96360993385315, 60.53626164793968, 58.13358597457409, 57.01940976083279, 48.31596538424492, 39.42333675920963, 37.97672398388386, 36.246676817536354, 39.73268195986748, 38.21527898311615, 45.64287722110748, 56.85895197093487, 46.57978154718876, 39.77650500833988, 41.52558535337448, 42.1921493858099, 40.327798426151276, 40.82171872258186, 43.519509360194206, 39.92601938545704, 44.842693358659744, 60.24564564228058, 61.86668045818806, 56.429985389113426, 58.888301476836205, 49.06111299991608, 50.7945191860199, 53.47433298826218, 43.1453662365675, 43.4072557836771, 43.500035405159, 44.108006581664085, 41.253816336393356, 40.786604806780815, 40.5923668295145, 46.77674397826195, 52.10926003754139, 51.2250816822052, 53.18521410226822, 54.3642870336771, 47.225986272096634, 46.05222165584564, 46.07118643820286, 51.29684463143349, 55.42208947241306, 53.94956588745117, 52.942722514271736, 57.062963023781776, 53.93821969628334, 58.55201572179794, 59.34763602912426, 53.2221557199955, 55.15974394977093, 46.5162755548954, 44.67727683484554, 45.0093600153923, 43.9605288952589, 45.176038071513176, 43.92400145530701, 45.92337816953659, 48.649340495467186, 48.19988161325455, 49.18317764997482, 46.71332158148289, 44.62010130286217, 45.748602747917175, 45.819442346692085, 48.111152574419975, 48.10751996934414, 49.30010497570038, 56.15766540169716, 64.67801660299301, 65.37176817655563, 64.00188088417053, 68.51435914635658, 46.40199288725853, 0.28337193187326193, 1.712761775124818, 10.30666384845972, 0.24533537914976478, 45.18665470182896, 74.88707318902016, 65.64645543694496, 69.95022609829903, 71.87453404068947, 74.5491649210453, 70.79650908708572, 51.149496138095856, 30.846892967820168, 32.18770042061806, 73.91780599951744, 27.923877015709877, 1.1905006994493306, 0.08132368893711828, 0.24966376251541078, 0.18563031102530658, 0.17644704988924786, 0.10205245242104866, 0.10466671214089729], [0.079979280999396, 0.0892959357588552, 0.10755101713584736, 0.01227343047503382, 0.04533339691988658, 0.03255546558648348, 0.07373111744527705, 0.08538708105334081, 0.5597579386085272, 0.1326226061792113, 6.378520606085658, 58.12815986573696, 43.82590591907501, 37.87716552615166, 24.48790568858385, 36.97240747511387, 40.08545882999897, 57.102511301636696, 58.35897468030453, 59.57565039396286, 57.7797831594944, 53.166268318891525, 57.605205327272415, 15.16428329050541, 0.8991742506623268, 3.901997795328498, 5.394315468147397, 1.481147815939039, 0.09521091953502037, 10.611984115093946, 59.91836540400982, 53.10917258262634, 58.42974208295345, 55.71710184216499, 56.0470799356699, 58.155525997281075, 52.763345539569855, 50.38585491478443, 44.039481058716774, 42.53606133162975, 42.11662843823433, 39.47406403720379, 39.49480712413788, 42.30108194053173, 42.53587894141674, 42.15242251753807, 40.62894746661186, 39.531771540641785, 39.65634025633335, 41.23577490448952, 40.51519677042961, 39.911291375756264, 40.801978781819344, 41.06716275215149, 42.64204904437065, 44.68730829656124, 45.72948977351189, 47.100361213088036, 46.57628193497658, 45.85814706981182, 41.98087312281132, 40.615830570459366, 44.44903068244457, 44.78581041097641, 43.42400148510933, 42.385543808341026, 40.06273604929447, 40.71050249040127, 37.72174246609211, 37.92078718543053, 37.789842411875725, 39.99791532754898, 45.89617542922497, 44.97039310634136, 48.79365675151348, 50.08361913263798, 50.19823618233204, 52.18826159834862, 53.23713831603527, 51.07058957219124, 54.36315469443798, 47.69340679049492, 41.41818791627884, 38.318580240011215, 36.09599590301514, 39.51585039496422, 37.455813735723495, 41.632735803723335, 46.786304265260696, 43.522355407476425, 40.745350420475006, 40.38024701178074, 38.09308513998985, 39.58470270037651, 39.42984201014042, 40.68696275353432, 38.6653458327055, 41.56625837087631, 54.329834282398224, 54.27477143704891, 52.02825218439102, 51.544887721538544, 48.226282596588135, 45.41615478694439, 49.111380502581596, 45.67048653960228, 42.774023562669754, 39.36686418950558, 37.80439183115959, 40.165281146764755, 37.75710716843605, 37.44350999593735, 38.74548353254795, 42.897592931985855, 47.688995227217674, 47.605593502521515, 45.05960091948509, 40.366617143154144, 41.27053163945675, 42.25524879992008, 45.8706483989954, 52.58681081235409, 50.86727388203144, 52.68898732960224, 52.63079345226288, 54.06525447964668, 53.63066799938679, 46.61655977368355, 47.46845506131649, 42.815733924508095, 41.81614816188812, 40.55733270943165, 40.31378857791424, 39.20993261039257, 40.92625491321087, 48.125310614705086, 51.61819338798523, 52.88968876004219, 51.705356910824776, 52.710178792476654, 50.69185249507427, 49.33597885072231, 43.54626752436161, 41.754580065608025, 39.75796580314636, 44.454821571707726, 43.4792847186327, 57.835362777113914, 56.12901493906975, 64.05566319823265, 57.1870643645525, 56.83764651417732, 12.654043938964605, 0.18541323282988742, 0.17386854684446007, 0.6783526623621583, 1.080441267695278, 50.435533449053764, 58.15771467983723, 54.86675687134266, 57.35379181802273, 56.375891491770744, 60.27933843433857, 53.34081195294857, 34.368608593940735, 41.48657664656639, 33.308484479784966, 46.98881059885025, 9.165101554244757, 0.5871180142275989, 0.030889672452758532, 0.17986214632401243, 0.04581747387419455, 0.061061777159920894, 0.0399392894905759, 0.03954692714614794, 0.0129500075490796, 0.03464177258138079, 0.13041752215940505, 0.029577516397694126, 0.06507037280243821, 0.03865719227178488, 0.11293246352579445, 0.06913480392540805, 0.619242915417999, 0.2413391217123717, 9.586825724691153, 69.10015851259232, 49.56151194870472, 38.945075422525406, 31.922193467617035, 48.32593984901905, 48.94875302910805, 64.06991243362427, 64.59389671683311, 61.988570317626, 65.0508525967598, 57.23212234675884, 64.88393515348434, 13.6046626791358, 0.8952215721365064, 3.2546329451724887, 9.172276519238949, 2.3745125345885754, 0.11667811995721422, 17.14915808290243, 60.4830265045166, 53.71691197156906, 59.16051506996155, 58.683929443359375, 57.558144852519035, 60.29514938592911, 54.92470756173134, 53.06336984038353, 45.6127068400383, 43.76008965075016, 43.265451192855835, 43.29282112419605, 42.20301680266857, 42.43361122906208, 44.679039940238, 44.67632308602333, 43.15656043589115, 41.79122909903526, 40.04062503576279, 43.17582920193672, 42.65359662473202, 41.98444873094559, 42.95582100749016, 43.410063832998276, 43.516336530447006, 45.43733485043049, 47.14600436389446, 49.514523670077324, 48.10998223721981, 46.97582669556141, 42.21792720258236, 42.472718730568886, 46.13614775240421, 48.11214052140713, 47.24620118737221, 44.75941702723503, 43.280441388487816, 43.23567599058151, 40.905732214450836, 40.24620920419693, 39.86625999212265, 42.2148759663105, 46.31554372608662, 47.009789273142815, 52.43894174695015, 52.643781155347824, 51.926569640636444, 54.190795943140984, 54.34339955449104, 53.6774130910635, 56.90688639879227, 49.50209453701973, 41.656944304704666, 37.94663339853287, 35.95466248691082, 37.51503735780716, 36.61098226904869, 41.79338738322258, 49.26100127398968, 45.2414857596159, 40.121222510933876, 42.583604380488396, 38.17223109304905, 39.19868141412735, 39.91645149886608, 40.12567587196827, 38.21330688893795, 41.840178072452545, 55.85183881223202, 56.052745431661606, 54.25997123122215, 55.45227125287056, 50.54880917072296, 49.361422285437584, 49.847875982522964, 47.30311833322048, 44.38914209604263, 41.198609098792076, 40.404793694615364, 41.84110142290592, 39.41238954663277, 39.96942065656185, 41.578163132071495, 46.658927500247955, 50.74160322546959, 49.82603095471859, 47.42154277861118, 43.15187148749828, 42.881326004862785, 43.698240369558334, 47.250521555542946, 52.166811749339104, 51.56007930636406, 54.01393063366413, 52.48928144574165, 55.23722939193249, 53.86050246655941, 49.312545508146286, 49.204908683896065, 44.13681663572788, 43.45337770879269, 43.43790493905544, 41.41822591423988, 41.56730331480503, 42.52618946135044, 50.48687629401684, 54.72300298511982, 55.381804034113884, 53.962842375040054, 55.49860596656799, 53.26247155666351, 50.153983756899834, 47.05329313874245, 44.50758934020996, 42.27585129439831, 45.806519240140915, 45.353157967329025, 58.94144542515278, 59.420212134718895, 65.22206380963326, 60.18376216292381, 60.045711770653725, 15.514465849846601, 0.3342468081973493, 1.2844524392858148, 1.4969242131337523, 1.1718040402047336, 53.74768652021885, 64.48821678757668, 60.28167150914669, 63.12588348984718, 62.106637582182884, 68.2109834253788, 58.34945619106293, 48.349859565496445, 37.752463817596436, 33.07367607951164, 58.39972749352455, 13.085657078772783, 0.6015491054859012, 0.023389355483232066, 0.1445891140610911, 0.04197982081677765, 0.09257872210582718, 0.04957150544214528, 0.06657406789599918, 0.23823915602406487, 0.15283366228686646, 0.23498951399233192, 0.12291101753362454, 0.21340405975934118, 0.09290557136409916, 0.21233257662970573, 0.14812700625043362, 0.7551927329041064, 0.3679438750259578, 11.603675801306963, 79.63250935077667, 58.63578982651234, 48.423039838671684, 36.15343362092972, 59.05847914516926, 50.10576814413071, 69.67100188136101, 70.40892988443375, 70.74500665068626, 69.54943880438805, 64.55338329076767, 70.3817917406559, 19.88507967442274, 1.3250229810364544, 14.084166549146175, 16.097422018647194, 3.6385807301849127, 0.20127908850554377, 22.850964926183224, 63.852640092372894, 55.89190386235714, 61.77173115313053, 60.47835275530815, 63.16375985741615, 62.15421102941036, 57.25243605673313, 55.78852280974388, 48.62910658121109, 46.18747919797897, 46.03622831404209, 44.0645407140255, 43.54611933231354, 45.4930854588747, 47.003914788365364, 46.19235433638096, 46.486530750989914, 42.41003729403019, 41.80777721107006, 45.21554835140705, 45.476400554180145, 43.249716237187386, 45.88495083153248, 46.67470805346966, 46.961588859558105, 47.69455052912235, 51.68692409992218, 52.513543143868446, 49.3392238765955, 48.93599711358547, 46.30087651312351, 46.06326766312122, 48.39856915175915, 50.091549307107925, 49.286741092801094, 48.44056449830532, 44.79911349713802, 45.309939086437225, 43.39899882674217, 41.78918480873108, 41.51122212409973, 44.65951278805733, 50.75990304350853, 49.55482430756092, 55.42838953435421, 56.44103139638901, 54.95650425553322, 56.00873239338398, 58.15096244215965, 55.20566068589687, 59.58388075232506, 50.7967534661293, 42.60082125663757, 38.53996776044369, 35.288041457533836, 37.48344585299492, 37.51360483467579, 44.08847562968731, 54.306321144104004, 45.68289667367935, 41.28553703427315, 43.06633807718754, 38.38916905224323, 39.74756956100464, 40.534811317920685, 41.472129821777344, 40.37871569395065, 41.604917496442795, 59.32552121579647, 59.608822613954544, 57.2159618139267, 57.02512085437775, 55.09314492344856, 52.03533120453358, 54.91874948143959, 49.3532907217741, 47.49918021261692, 44.29679565131664, 42.21744082868099, 46.43905229866505, 41.26700542867184, 40.977514162659645, 42.42351517081261, 46.55267380177975, 55.23562967777252, 53.02150748670101, 50.85014060139656, 46.12055718898773, 46.08497589826584, 46.07339791953564, 49.2377807199955, 54.454748779535294, 53.06001462042332, 56.6816458851099, 53.7077696621418, 56.98904179036617, 57.48296208679676, 50.70427022874355, 50.712204203009605, 46.42664976418018, 45.59330888092518, 44.72871847450733, 43.12318302690983, 42.542931362986565, 44.766948223114014, 52.6791762560606, 56.63194455206394, 58.72081786394119, 55.993567407131195, 58.71442660689354, 53.8591193407774, 51.89974308013916, 48.86370599269867, 47.352291494607925, 43.964697271585464, 48.55621129274368, 47.864804193377495, 59.960132762789726, 63.05673860013485, 70.96841186285019, 63.3708031475544, 61.30359247326851, 19.742323234677315, 0.2826222142903134, 2.025221739895642, 3.892657896503806, 1.1834722640924156, 64.19500932097435, 69.47827622294426, 67.24477127194405, 68.01586389541626, 67.42308050394058, 73.92944857478142, 66.18948429822922, 48.211482390761375, 48.048706725239754, 47.62013152241707, 67.73853957653046, 19.293945394456387, 0.7713254203554243, 0.11680667477776296, 0.25597878615371883, 0.09712522267363966, 0.2696278318762779, 0.09139406887697987, 0.18675659433938563], [0.06417933545890264, 0.08956517951446585, 0.029118232741893735, 0.018587268532428425, 0.04033043471281417, 0.025071104792004917, 0.013682333828910487, 0.03127726464299485, 0.031054113824211527, 0.17645556974457577, 0.6481248093768954, 46.95790305733681, 56.232061609625816, 40.64370207488537, 39.18177232146263, 39.9728062748909, 50.56413754820824, 53.57299089431763, 63.354293033480644, 54.02220278978348, 56.184366568923, 50.229850485920906, 56.66657209396362, 27.333447597920895, 0.22638824506429955, 2.0432669715955853, 6.423619911074638, 1.0981504549272358, 0.14319386158604175, 1.6304613975808024, 44.84645515680313, 53.264128267765045, 58.63999620079994, 56.34254068136215, 58.70588846504688, 53.306051418185234, 50.05853667855263, 45.45158788561821, 41.62385568022728, 41.387056186795235, 42.448141649365425, 43.27426292002201, 47.100239619612694, 50.10215073823929, 52.4910369515419, 50.06906971335411, 47.915569469332695, 42.69406445324421, 39.00975935161114, 40.705551356077194, 41.40149161219597, 39.684694334864616, 39.290499687194824, 40.46878986060619, 42.24285386502743, 44.097245559096336, 45.284385457634926, 46.125310733914375, 45.91561138629913, 43.62467631697655, 41.76725618541241, 40.781535878777504, 43.915835693478584, 46.005145981907845, 42.46802218258381, 42.92642578482628, 40.376394018530846, 38.91614757478237, 35.542449206113815, 38.51047374308109, 38.85269097983837, 40.19506014883518, 44.840113297104836, 45.62029883265495, 50.68543083965778, 47.519558519124985, 50.42729169130325, 51.124189496040344, 51.31877705454826, 51.329712867736816, 52.8343865275383, 50.697882771492004, 42.43536673486233, 38.7425234913826, 37.77888759970665, 36.93437911570072, 39.433850795030594, 39.997387155890465, 49.33741517364979, 42.01409474015236, 39.670046120882034, 39.25374045968056, 39.1618499904871, 36.94727182388306, 38.88244338333607, 40.07492579519749, 40.235280990600586, 43.585245832800865, 55.66182620823383, 53.75812076032162, 53.536227867007256, 50.75787395238876, 51.28337815403938, 48.49293328821659, 43.37073214352131, 48.5453362762928, 46.99275478720665, 42.79343672096729, 38.64360719919205, 38.709077686071396, 36.9235572963953, 35.76141245663166, 38.14254328608513, 41.36515416204929, 44.02581699192524, 46.38423264026642, 46.08401834964752, 42.995547875761986, 43.09307724237442, 43.23012828826904, 47.06454053521156, 52.51143045723438, 50.548820570111275, 52.46317304670811, 53.84252943098545, 49.407703801989555, 48.6782493442297, 44.852709621191025, 42.77797155082226, 42.958055287599564, 40.64694710075855, 38.711916133761406, 41.254021525382996, 39.35300253331661, 48.71134556829929, 56.13002188503742, 56.2449961155653, 54.0993120521307, 52.70596481859684, 55.1950478553772, 54.220217764377594, 55.46277768909931, 52.41903841495514, 49.00587536394596, 41.19993522763252, 41.70905090868473, 44.88469250500202, 55.98736993968487, 60.58962978422642, 60.66005140542984, 54.7200733423233, 54.43677194416523, 14.55493088811636, 0.26779662701301277, 0.8497780293691903, 0.731947124004364, 5.132370349019766, 60.56196726858616, 53.57940495014191, 57.65191622078419, 55.98890505731106, 61.95013538002968, 61.5536342561245, 54.92805898189545, 27.996206134557724, 60.96170201897621, 52.16621518135071, 47.48857498168945, 6.922649033367634, 0.9943508903961629, 0.06308309428277425, 0.37035104585811496, 0.03003673511557281, 0.1510519883595407, 0.03418774518650025, 0.054233799601206556, 0.025473211535427254, 0.06287243566475809, 0.05382228242524434, 0.04006905401183758, 0.07538518650108017, 0.040233944382634945, 0.03854417060210835, 0.05232898110989481, 0.06793504056986421, 0.1232065110525582, 1.4144555758684874, 56.208521872758865, 64.66296941041946, 37.829880863428116, 37.463838905096054, 54.345656633377075, 49.028560146689415, 60.16675807535648, 68.97304013371468, 60.58685973286629, 61.9060767441988, 54.41108912229538, 61.88817210495472, 31.903772056102753, 0.3588879812741652, 3.0093672685325146, 6.226952914148569, 4.422686705365777, 0.141650372534059, 3.260473944246769, 50.350820794701576, 54.21431668102741, 60.687702521681786, 56.34727142751217, 60.492924973368645, 55.39720840752125, 52.61445812880993, 47.9132591933012, 44.300124272704124, 44.10899072885513, 46.17769472301006, 45.970142260193825, 48.07177148759365, 51.088543608784676, 55.130766704678535, 53.50904032588005, 49.07860726118088, 44.772644117474556, 41.07833795249462, 43.029084876179695, 42.579606994986534, 41.95602245628834, 40.83398446440697, 42.14723199605942, 44.47095550596714, 46.72273367643356, 47.759021669626236, 48.44415910542011, 46.99883446097374, 46.550846099853516, 44.836537688970566, 42.93144911527634, 46.51942178606987, 48.26224386692047, 45.23944526910782, 46.005738750100136, 42.0191864669323, 41.86365321278572, 37.98133693635464, 41.173192262649536, 42.1788576990366, 44.36337947845459, 47.51690626144409, 47.90876403450966, 52.84648887813091, 51.91605940461159, 52.55925849080086, 55.3751315921545, 54.10734862089157, 52.4345263838768, 55.67279241979122, 51.750521287322044, 42.51372613012791, 36.70929819345474, 37.12266281247139, 37.87146583199501, 39.577863067388535, 41.83207310736179, 54.03372377157211, 42.536543905735016, 40.55683493614197, 39.649610817432404, 40.26261292397976, 38.46538916230202, 39.0451430529356, 40.144169479608536, 39.37420919537544, 44.95354861021042, 57.54071518778801, 56.31087318062782, 54.63528089225292, 52.57489085197449, 51.786425560712814, 50.81559665501118, 46.20576001703739, 50.77482484281063, 47.980773970484734, 44.38113212585449, 40.221191346645355, 41.33202753961086, 38.994073793292046, 37.05133683979511, 39.98603716492653, 44.40056808292866, 46.462136059999466, 47.9069971293211, 47.57724702358246, 44.20805901288986, 44.16808895766735, 45.33838056027889, 48.56666833162308, 52.326140999794006, 53.97209867835045, 53.5192009806633, 54.398067221045494, 52.39266403019428, 50.88171310722828, 47.068530321121216, 43.486314341425896, 43.735584765672684, 43.85125055909157, 40.527359917759895, 42.879730090498924, 42.85074144601822, 51.06872387230396, 57.110931649804115, 57.88043215870857, 55.92796012759209, 55.48432253301144, 57.13045500218868, 58.13765175640583, 57.83104620873928, 56.105053424835205, 50.46930603682995, 44.268232583999634, 44.489000737667084, 46.79087541997433, 57.064315751194954, 62.228242456912994, 63.33597421646118, 54.97281678020954, 55.56655012071133, 19.563476331532, 0.21970980655169114, 2.9964465368539095, 0.8851405943278223, 5.569404847919941, 66.81424677371979, 58.596891313791275, 64.65863764286041, 60.15962205827236, 68.97148221731186, 66.8224087357521, 62.63106644153595, 36.74309358000755, 66.19215935468674, 58.679092302918434, 55.7370849698782, 9.411353040486574, 1.0498729767277837, 0.04252613798598759, 0.2593248331686482, 0.17256199585972354, 0.13001222047023475, 0.02452774137054803, 0.12105922549380921, 0.2241793167195283, 0.22109457990154624, 0.15756555134430528, 0.2530300850048661, 0.18496426317142323, 0.0934047918417491, 0.12182107719127089, 0.14907912234775722, 0.19644605956273153, 0.21901294472627342, 1.7717657214961946, 68.74480918049812, 74.12865668535233, 53.484391048550606, 50.402159839868546, 59.49626885354519, 59.15038861334324, 67.25492432713509, 73.7053593993187, 68.24702829122543, 64.91445511579514, 59.93780896067619, 67.44861513376236, 36.13427884876728, 0.4766475217184052, 5.876881023868918, 16.459880769252777, 3.792595728300512, 0.22490990173537284, 4.355910988524556, 54.787192940711975, 55.09593777358532, 64.40656676888466, 59.990572929382324, 63.32683190703392, 57.11894541978836, 55.55456556379795, 49.6027397364378, 46.84945687651634, 46.02608285844326, 48.374847024679184, 47.45601452887058, 52.576175183057785, 54.195994064211845, 60.098449140787125, 55.09400747716427, 54.02748070657253, 48.910770267248154, 42.220461666584015, 45.23514769971371, 47.4378477036953, 45.512012243270874, 41.84611335396767, 45.17664223909378, 48.7185537815094, 50.05779191851616, 50.01977875828743, 51.654789224267006, 50.36793127655983, 48.0244792252779, 45.688679963350296, 45.49663066864014, 50.76095178723335, 49.0987803786993, 46.54845982789993, 49.97697785496712, 45.02475678920746, 43.011943995952606, 40.838871002197266, 43.47084917128086, 44.065490663051605, 45.0560937076807, 48.921052515506744, 51.435898169875145, 56.531968116760254, 54.60954487323761, 55.359544828534126, 57.294097021222115, 55.22910922765732, 57.62095548212528, 59.08637344837189, 54.0627808123827, 43.48222956061363, 37.9924551397562, 38.61627906560898, 37.50140368938446, 40.15634782612324, 44.39276710152626, 58.420687168836594, 42.90519252419472, 40.322668701410294, 37.95907773077488, 39.891201853752136, 37.96003147959709, 39.41384866833687, 40.64040005207062, 40.71844786405563, 45.91779626905918, 59.874036982655525, 58.96803639829159, 59.3131148815155, 55.493814423680305, 55.50533540546894, 54.74444903433323, 49.04914744198322, 52.65738442540169, 51.362315118312836, 48.65581154823303, 44.05385948717594, 43.84842351078987, 40.52112065255642, 39.76939179003239, 40.778150260448456, 45.81034943461418, 48.0372579395771, 49.503831043839455, 49.73812647163868, 46.80689536035061, 47.25500151515007, 47.1381501853466, 51.041346341371536, 54.510187804698944, 55.91932699084282, 54.38991665840149, 57.48193994164467, 53.20927061140537, 52.78430141508579, 49.62583489716053, 45.567382872104645, 45.91048166155815, 44.55621913075447, 43.06634947657585, 45.50942838191986, 43.86575438082218, 53.08991141617298, 59.81199011206627, 59.98570919036865, 57.59502947330475, 56.6213621199131, 60.84556125104427, 60.910476967692375, 60.505855679512024, 56.1836826056242, 53.0745754390955, 45.87949812412262, 45.81778183579445, 48.96512255072594, 60.38900814950466, 65.7136282324791, 67.69377037882805, 57.063168212771416, 58.09878744184971, 24.717063792049885, 0.6386925873812288, 5.072282273322344, 2.284352872520685, 6.6192543134093285, 74.45844858884811, 66.01249739527702, 69.38486203551292, 66.80968701839447, 75.47634556889534, 71.93789184093475, 67.38350182771683, 39.769836366176605, 67.77964577078819, 61.75596199929714, 71.63314819335938, 12.80600918456912, 1.1682277196086943, 0.1661301136482507, 0.46417510660830885, 0.18795688461977988, 0.25108346133492887, 0.12766860716510564, 0.14505632570944726], [0.12256476111360826, 0.01568036142998608, 0.07185169524746016, 0.018862147044274025, 0.0152922070628847, 0.013855137349310098, 0.020544328654068522, 0.015880073369771708, 0.03030165400559781, 0.22193685814272612, 0.1405388579587452, 16.609182357788086, 53.87985862791538, 42.02574871480465, 31.053579077124596, 30.820125304162502, 64.60713520646095, 54.86475057899952, 60.37040054798126, 57.43603840470314, 58.974138870835304, 54.00961026549339, 56.11424133181572, 34.12982560694218, 0.39092744642402977, 1.559248825069517, 6.120713464915752, 2.8454093914479017, 0.22610309708397835, 0.2989300189074129, 34.00005877017975, 58.251611441373825, 58.3442010730505, 56.417301669716835, 53.68918105959892, 49.29541602730751, 46.67775169014931, 44.143610671162605, 47.02190302312374, 49.01909485459328, 51.4882555603981, 50.82287326455116, 55.04866071045399, 54.366665706038475, 55.62890097498894, 53.40221285820007, 51.07460595667362, 44.99250032007694, 39.379072934389114, 40.265876948833466, 39.419453367590904, 40.62082730233669, 42.0491174608469, 42.669586166739464, 42.733403742313385, 46.712196841835976, 45.81538036465645, 46.29539340734482, 44.14152838289738, 44.0414759516716, 43.02275061607361, 41.17766082286835, 40.61224736273289, 42.379616126418114, 43.99952620267868, 45.27883015573025, 44.349115043878555, 38.66291396319866, 36.935154274106026, 38.9631662517786, 38.62016245722771, 42.05842696130276, 43.94222907721996, 48.641801699995995, 48.181828781962395, 47.321600541472435, 48.353993743658066, 51.48414418101311, 51.835477128624916, 50.832418352365494, 55.3489737957716, 51.54590606689453, 42.48539485037327, 38.435005992650986, 38.07050295174122, 39.49913889169693, 40.38603790104389, 38.64672303199768, 46.86164282262325, 40.12354418635368, 40.80939218401909, 39.57443945109844, 39.758311584591866, 37.778993993997574, 39.49490211904049, 37.641775757074356, 37.485535740852356, 47.288242131471634, 54.94572803378105, 55.10267101228237, 52.192521169781685, 50.34677401185036, 49.85383786261082, 49.30837333202362, 48.01692143082619, 45.219127759337425, 48.80647346377373, 46.61796569824219, 41.04036659002304, 35.872438699007034, 36.898049265146255, 35.91438464820385, 39.424282908439636, 38.91984097659588, 42.935305908322334, 44.4804397970438, 42.30082355439663, 39.272758439183235, 43.736014142632484, 43.69713082909584, 46.197024285793304, 50.21915785968304, 50.88495433330536, 53.34874972701073, 52.868949472904205, 50.83068944513798, 46.42397850751877, 44.188372269272804, 41.993047669529915, 39.57439765334129, 39.28142577409744, 38.992835059762, 39.45345774292946, 42.117395997047424, 55.96700683236122, 55.04999823868275, 56.1662757396698, 55.9911735355854, 54.99255672097206, 56.07928700745106, 58.69760490953922, 56.098149195313454, 55.91706611216068, 59.726456701755524, 48.53960998356342, 42.06650912761688, 42.018567100167274, 54.71523620188236, 58.6754634976387, 61.410530135035515, 52.81461238861084, 40.70920296013355, 20.00005390495062, 0.062338764691958204, 1.4734294801019132, 0.8913867466617376, 12.489239182323217, 63.701203018426895, 52.5895656645298, 58.44881325960159, 55.559611693024635, 57.976228818297386, 57.332436963915825, 46.62009738385677, 33.16371224820614, 32.98676714301109, 49.076923951506615, 43.75238746404648, 2.509693605825305, 0.3019970183959231, 0.028372639644658193, 0.09995883156079799, 0.019840229033434298, 0.10073980840388685, 0.007742368898107088, 0.07742634494206868, 0.03468834234809037, 0.05292429857945535, 0.014459470057772705, 0.013188338070904138, 0.014924465467629489, 0.04380690304969903, 0.09696122288005427, 0.03806055377935991, 0.11171780526638031, 0.31698243459686637, 0.173092661134433, 25.474023073911667, 65.05689427256584, 44.88294839859009, 32.385046631097794, 43.45734469592571, 66.06789842247963, 60.271324664354324, 65.08459478616714, 62.90226548910141, 64.58663150668144, 58.32041434943676, 62.448778823018074, 38.919795379042625, 0.4206848074682057, 1.4993531140498817, 4.840781120583415, 4.212415963411331, 0.43155537103302777, 0.8298961899708956, 38.83933089673519, 60.017122104763985, 59.44931857287884, 59.206363409757614, 54.37232360243797, 54.130838960409164, 47.10235230624676, 47.34976463019848, 48.912263587117195, 49.24597688019276, 51.75063908100128, 52.59177714586258, 57.45899297297001, 57.17938117682934, 57.868584394454956, 55.746181681752205, 53.76447781920433, 46.83328114449978, 40.75314000248909, 42.14880511164665, 40.85273265838623, 43.11946302652359, 43.18830393254757, 44.74628873169422, 45.414254888892174, 48.80023419857025, 48.500825464725494, 47.515853717923164, 44.840721264481544, 45.3949823230505, 44.73974548280239, 43.45918759703636, 42.95810088515282, 45.74084736406803, 46.98299691081047, 47.205896750092506, 45.851573422551155, 41.94064848124981, 40.55790267884731, 40.75828492641449, 41.28050610423088, 44.91621941328049, 45.80996185541153, 50.739319548010826, 52.14210167527199, 50.47530971467495, 51.56810447573662, 54.408691450953484, 52.319407761096954, 53.801210448145866, 58.979367390275, 53.06236669421196, 42.48116947710514, 37.453541457653046, 38.25391910970211, 38.964678570628166, 39.81668785214424, 40.25634706020355, 49.99643661081791, 40.85600808262825, 41.44034072756767, 38.96160453557968, 39.39221262931824, 37.48808540403843, 40.442122891545296, 37.3794150352478, 37.43355073034763, 48.78510721027851, 57.81516306102276, 55.56320630013943, 53.07712510228157, 52.63120003044605, 53.124489560723305, 54.2707322537899, 49.89153943955898, 48.50449986755848, 51.9044054299593, 48.94697092473507, 43.972912430763245, 37.91988283395767, 38.61001320183277, 39.01774652302265, 39.2952798306942, 40.608215779066086, 45.53035765886307, 45.73834329843521, 44.12906125187874, 42.52333201467991, 45.967003628611565, 46.22824341058731, 48.4037596732378, 50.68653658032417, 52.7313132584095, 55.288085862994194, 52.576870545744896, 53.03400121629238, 50.05276098847389, 46.380113661289215, 44.35276284813881, 42.32271417975426, 41.08038604259491, 41.611665934324265, 41.70182749629021, 44.03324939310551, 56.97361841797829, 55.77223688364029, 56.73245295882225, 57.60620467364788, 56.525117084383965, 59.46205548942089, 61.07921451330185, 59.33899149298668, 58.513694778084755, 60.55389650166035, 51.5090936422348, 43.64077225327492, 45.31259514391422, 56.54951937496662, 60.13030283153057, 64.96584355831146, 52.006429955363274, 42.15040102601051, 24.164358749985695, 0.0799570610979572, 2.5378322834149003, 1.0543147008866072, 14.8551831766963, 71.1290368437767, 58.23154091835022, 64.41787496209145, 60.93844726681709, 64.19181749224663, 61.7547232657671, 53.52914124727249, 43.23133282363415, 34.805908128619194, 54.35736380517483, 53.2285887748003, 3.9913352765142918, 0.4378640418872237, 0.058264162435079925, 0.14878823014441878, 0.11030252222553827, 0.0920388541999273, 0.059641540283337235, 0.07251078175613657, 0.2081740411813371, 0.20450818788958713, 0.21029432740760967, 0.127221463189926, 0.1569735401426442, 0.15742340037832037, 0.17539121123263612, 0.23736070550512522, 0.21384985302574933, 0.42773494322318584, 0.3494186815805733, 33.60935993492603, 74.42450881004333, 55.37694029510021, 38.40175777673721, 48.67517150938511, 74.7596888244152, 68.33783581852913, 70.9176541864872, 70.20865023136139, 69.5018881559372, 64.85529229044914, 65.64007177948952, 46.34278826415539, 0.7118609268218279, 5.461930464953184, 14.184311125427485, 6.595567334443331, 0.539345433935523, 0.9066074236761779, 44.31670278310776, 59.381830394268036, 64.49114263057709, 58.65396045148373, 59.361756071448326, 53.48420865833759, 50.144628658890724, 48.86082574725151, 51.64118975400925, 51.11395284533501, 55.61236426234245, 56.8354806303978, 61.84996895492077, 57.02882565557957, 60.742256194353104, 58.77441018819809, 57.00864113867283, 48.64154331386089, 43.30158345401287, 45.76381713151932, 44.13341201841831, 45.23421674966812, 46.44497998058796, 47.057640105485916, 49.39066931605339, 51.09521225094795, 51.196761801838875, 50.5506406724453, 46.96161545813084, 47.05739311873913, 45.59715427458286, 45.83827793598175, 44.78104166686535, 46.92182779312134, 49.053600803017616, 49.54448506236076, 50.45732907950878, 44.88422892987728, 41.87766306102276, 45.14324203133583, 42.92080208659172, 47.21383072435856, 49.07167263329029, 57.18339756131172, 54.60397057235241, 51.790438145399094, 55.58383919298649, 56.648865044116974, 56.06556214392185, 54.96645212173462, 62.36946947872639, 55.85656575858593, 43.00562873482704, 38.08457739651203, 37.760325595736504, 39.44520078599453, 40.07214054465294, 41.458632946014404, 53.282040506601334, 42.40420840680599, 42.94787183403969, 39.70026209950447, 40.49084387719631, 37.91803993284702, 40.689672008156776, 38.26718419790268, 36.87740117311478, 49.466023072600365, 60.46305477619171, 59.43124674260616, 57.08391509950161, 56.042873561382294, 55.09319432079792, 55.207488387823105, 53.0136913061142, 50.4759556800127, 55.75953796505928, 51.914315298199654, 48.1904923170805, 40.050432309508324, 41.13711319863796, 40.545940920710564, 43.02018575370312, 43.324792608618736, 45.74172131717205, 50.14056667685509, 45.50269894301891, 44.491257816553116, 48.59358608722687, 48.05163636803627, 49.32853884994984, 52.15296909213066, 53.834823444485664, 56.539351120591164, 56.50899834930897, 53.64286534488201, 51.93308629095554, 50.00205650925636, 46.248716711997986, 42.505396977066994, 44.01817560195923, 43.141950219869614, 43.097788989543915, 46.31135255098343, 60.99807746708393, 57.423453480005264, 60.989007353782654, 58.80284786224365, 57.74896681308746, 60.44078417122364, 63.24304640293121, 60.64937777817249, 60.081384256482124, 65.53272753953934, 54.06941905617714, 45.198384672403336, 47.54907913506031, 61.674243584275246, 63.36662717163563, 67.4359542131424, 53.53542611002922, 45.462386906147, 30.793456435203552, 0.29187284759245813, 8.398777674883604, 2.2824413375929, 16.99188072234392, 77.8923699259758, 62.821364030241966, 70.2957871556282, 66.72220811247826, 68.6451405286789, 65.89999303221703, 60.56404955685139, 45.08286327123642, 40.06105273962021, 62.98970639705658, 64.36169117689133, 5.970972049981356, 0.6575920013710856, 0.16212768154218793, 0.29478441167157143, 0.2232414498575963, 0.2546844509197399, 0.09033023728989065, 0.2126074829720892], [0.06479217132437043, 0.06459701617131941, 0.022049259423511103, 0.031405337067553774, 0.05717779182305094, 0.10043946123914793, 0.039564126418554224, 0.047045765386428684, 0.07508974493248388, 0.2669492131099105, 0.08656149264425039, 9.118802938610315, 59.314368814229965, 37.197275608778, 38.01626846194267, 34.82556067407131, 51.68536618351936, 56.083512380719185, 55.776872634887695, 60.66453896462917, 57.72916227579117, 56.57088562846184, 52.58237265050411, 52.27042838931084, 6.347791654989123, 1.9232027954421937, 3.121528699994087, 5.581366131082177, 0.9989287541247904, 0.4766301257768646, 26.75680574029684, 59.15083318948746, 58.66504065692425, 55.37936456501484, 53.168950974941254, 52.13352173566818, 51.299629881978035, 51.711409986019135, 52.58511230349541, 52.131466045975685, 52.25188158452511, 53.38738605380058, 56.31381042301655, 55.794940665364265, 55.79099267721176, 52.56466940045357, 54.89596590399742, 47.88860611617565, 40.90607799589634, 40.440390184521675, 41.08266592025757, 39.22129400074482, 39.120496809482574, 42.1346964687109, 44.06280800700188, 45.73453590273857, 43.745988607406616, 46.204726472496986, 44.197282791137695, 44.152221009135246, 44.72012333571911, 42.011742666363716, 40.34595385193825, 42.95429348945618, 44.155401438474655, 42.488092705607414, 43.01227457821369, 38.08058761060238, 40.94742737710476, 38.41470368206501, 40.042065158486366, 40.59618562459946, 46.60652071237564, 51.2309979647398, 51.0016992688179, 51.084873005747795, 49.69918996095657, 50.26773065328598, 49.56210471689701, 50.021507665514946, 52.1739249676466, 53.07251214981079, 41.954228952527046, 39.16870102286339, 37.251107320189476, 39.642459601163864, 38.82320076227188, 38.05061861872673, 47.77182698249817, 39.93501350283623, 41.81908540427685, 39.53329525887966, 39.396711587905884, 39.38532739877701, 39.594483375549316, 40.487614050507545, 38.32463711500168, 50.505670085549355, 55.491086170077324, 52.676634192466736, 51.65611915290356, 50.88442996144295, 51.28876246511936, 50.69107733666897, 48.86126272380352, 43.01506742835045, 43.824526593089104, 46.31705604493618, 43.10751646757126, 39.11834232509136, 38.83571729063988, 38.08876857161522, 37.56503127515316, 39.168089255690575, 43.22369143366814, 42.40746483206749, 42.32573501765728, 39.353424310684204, 43.26446704566479, 44.70790699124336, 44.94741193950176, 51.53307035565376, 51.434758231043816, 53.17922942340374, 52.58139990270138, 52.46032699942589, 48.34567978978157, 45.71987248957157, 41.94461926817894, 40.859074518084526, 37.887975946068764, 39.52139049768448, 38.25112245976925, 44.85998623073101, 52.24238209426403, 55.75844742357731, 56.06258690357208, 56.61000072956085, 56.41955494880676, 55.88299334049225, 52.70307317376137, 51.967440247535706, 54.54518012702465, 57.332908138632774, 55.738927870988846, 48.90632450580597, 40.991645604372025, 50.3220259398222, 57.2785634547472, 59.248966723680496, 60.30334934592247, 37.442753836512566, 2.2160503501072526, 0.17606178618734702, 1.3982553826645017, 0.22461142478277907, 25.737784020602703, 58.53786148130894, 52.086970433592796, 56.804394498467445, 53.926390931010246, 59.21657346189022, 57.730644196271896, 42.11230047047138, 30.63570410013199, 25.436866767704487, 48.41707795858383, 28.53605456650257, 0.8467790996655822, 0.04101568192709237, 0.12043524257023819, 0.03571314438886475, 0.13608096982352436, 0.00918582803933532, 0.10978687059832737, 0.0499475442484254, 0.11488869800814427, 0.02537378230044851, 0.039535757823614404, 0.04882787718088366, 0.036107688647462055, 0.04867998941335827, 0.05470386109664105, 0.057213708059862256, 0.07263618244905956, 0.39700501249171793, 0.13923288584919646, 12.35729506239295, 68.12570840120316, 42.12926656007767, 36.19642451405525, 44.87185679376125, 61.215520799160004, 61.61237150430679, 63.00187714397907, 63.884824365377426, 63.49786452949047, 60.317442789673805, 57.30632856488228, 57.47573107481003, 6.869478011503816, 1.3224134710617363, 3.715329486876726, 6.98131931014359, 1.272622486576438, 0.3235030628275126, 30.83781525492668, 58.962116315960884, 60.584557056427, 56.46624304354191, 56.98746867477894, 53.53433936834335, 52.97303728759289, 52.34212674200535, 55.452651232481, 54.59830887615681, 57.37140007317066, 56.93483009934425, 58.15569318830967, 56.47310547530651, 57.55270354449749, 56.23515084385872, 56.91452398896217, 51.53956040740013, 42.38299414515495, 42.801541686058044, 42.30246126651764, 41.242299154400826, 40.79229690134525, 43.44235070049763, 44.85898308455944, 46.762791126966476, 46.923712491989136, 47.75764234364033, 46.7362305521965, 44.96424123644829, 47.64119379222393, 43.739848136901855, 41.724025905132294, 44.76074695587158, 47.4989066272974, 44.929602295160294, 44.473934546113014, 40.87211921811104, 41.60403594374657, 39.730561673641205, 42.415706589818, 44.35528211295605, 48.60370114445686, 52.91341848671436, 53.43222364783287, 53.42158801853657, 53.05209204554558, 52.36716739833355, 54.04225051403046, 53.797452449798584, 54.5437666028738, 54.706466272473335, 42.381576821208, 38.66115465760231, 38.18790145218372, 40.00418119132519, 38.12297433614731, 38.09020109474659, 49.286133125424385, 40.94433434307575, 41.99673347175121, 38.56925278902054, 40.455524772405624, 39.24748219549656, 39.509554132819176, 41.155371218919754, 40.357459634542465, 50.27218401432037, 59.330206364393234, 55.259754583239555, 53.976761028170586, 52.52141632139683, 54.36646431684494, 53.6191850155592, 51.128323674201965, 44.92517553269863, 46.6292092949152, 48.87344107031822, 45.47942519187927, 40.732708498835564, 40.9668405354023, 39.687308594584465, 40.50476633012295, 39.081146121025085, 45.12690670788288, 43.90850208699703, 45.09470723569393, 41.35682500898838, 45.38965500891209, 46.648740246891975, 49.091948345303535, 53.62726718187332, 53.70979115366936, 53.01389269530773, 55.60568422079086, 53.77676635980606, 48.85462827980518, 48.04517671465874, 44.890076816082, 41.842742934823036, 40.44916771352291, 40.19376061856747, 40.61116822063923, 46.78017899394035, 54.76181410253048, 56.8395122140646, 57.63673223555088, 58.55368383228779, 57.81834729015827, 55.765511244535446, 54.50017914175987, 53.901452869176865, 57.41886332631111, 60.51804922521114, 57.72715598344803, 50.78944265842438, 42.49334782361984, 51.7966166138649, 60.453152507543564, 60.52511304616928, 64.84593719244003, 39.39224682748318, 2.754430160857737, 0.5438005761243403, 1.9864116911776364, 0.18711956392508, 31.952398046851158, 65.56009367108345, 56.65389597415924, 65.17131373286247, 58.258831053972244, 65.63658356666565, 62.5781124830246, 48.87941814959049, 32.51614339649677, 22.97201883047819, 55.78372746706009, 35.44618517160416, 1.1371284071356058, 0.03356052278832067, 0.13239191699540243, 0.03762737331271637, 0.056350890881731175, 0.053508220371440984, 0.06271386097068898, 0.07573820388643071, 0.23378655198030174, 0.11068631647503935, 0.10833941545570269, 0.12222928809933364, 0.16039724549045786, 0.2876949717756361, 0.0923077343031764, 0.26699516689404845, 0.2276294573675841, 0.6084006722085178, 0.3392591548617929, 18.427738174796104, 83.36940363049507, 50.001133158802986, 48.250586092472076, 51.04548431932926, 67.65864506363869, 66.70469865202904, 68.75800967216492, 69.6521244943142, 70.51666930317879, 64.58490639925003, 61.69654458761215, 64.84345972537994, 9.725780468434095, 3.92015868332237, 12.222147714346647, 16.59464243799448, 2.5993595318868756, 0.7818288286216557, 34.32610407471657, 59.57820005714893, 63.48915919661522, 57.29772202670574, 60.154230147600174, 56.33547306060791, 59.42314177751541, 55.03251537680626, 59.22929137945175, 57.31058433651924, 59.85421344637871, 57.11299113929272, 61.64602629840374, 58.741082176566124, 59.214947149157524, 55.69654494524002, 59.04732674360275, 51.927872970700264, 44.76044297218323, 44.08033646643162, 45.06725750863552, 43.22493776679039, 44.90618795156479, 44.81822647154331, 46.6304974257946, 48.84861320257187, 47.58235014975071, 49.04833808541298, 48.03779371082783, 48.60317297279835, 49.63042885065079, 48.34219917654991, 44.03486430644989, 46.86566300690174, 51.459882482886314, 47.45509497821331, 46.822877302765846, 41.41412973403931, 46.51972196996212, 42.16742031276226, 44.727331548929214, 46.97792038321495, 52.70604081451893, 56.22063182294369, 56.60950295627117, 56.743434369564056, 56.82719707489014, 55.20086534321308, 54.36622112989426, 55.77202409505844, 58.011179342865944, 56.368010714650154, 43.13872039318085, 38.83071295917034, 36.92336730659008, 39.57549959421158, 38.50931100547314, 40.226370468735695, 53.017274513840675, 41.866297870874405, 41.74816220998764, 37.2025041282177, 40.610298067331314, 39.454517886042595, 39.42513786256313, 42.20704458653927, 39.48057308793068, 54.4268012791872, 63.08443531394005, 56.668031215667725, 55.55809937417507, 54.26367983222008, 57.97059752047062, 56.888104006648064, 53.902558609843254, 47.522370368242264, 49.09604452550411, 51.47355034947395, 48.79805691540241, 42.95613259077072, 44.10271346569061, 41.584106013178825, 43.50180611014366, 42.39005796611309, 47.00301043689251, 46.739764362573624, 47.25359559059143, 44.032785817980766, 48.42010639607906, 47.7979239821434, 49.99850369989872, 55.251547023653984, 55.86685560643673, 55.06618916988373, 57.04384624958038, 56.60964734852314, 50.508432537317276, 49.16601777076721, 47.03983046114445, 44.16527330875397, 41.07372500002384, 41.79235763847828, 42.56533496081829, 48.150708451867104, 55.65804921090603, 60.43261460959911, 60.06302744150162, 60.38085758686066, 60.295225381851196, 57.65231899917126, 54.827831760048866, 55.83934128284454, 60.70047743618488, 63.384486213326454, 61.45998068153858, 54.872635155916214, 45.22474765777588, 55.417039543390274, 62.062141969799995, 66.02949768304825, 63.39996658265591, 44.25103850662708, 3.355502332560718, 0.4686312284320593, 9.63806027546525, 0.571383711649105, 34.85211364924908, 72.26287320256233, 61.97626277804375, 68.049256503582, 64.90794986486435, 72.47981876134872, 69.9913626909256, 57.18176744878292, 40.69794796407223, 35.368004366755486, 63.217792958021164, 46.9306281208992, 1.5447185235098004, 0.1890358337550424, 0.19976956013124436, 0.2962863107677549, 0.22015432332409546, 0.1620174280833453, 0.18065550219034776, 0.15599576057866216], [0.04308478222810663, 0.06360284998663701, 0.0252459510738845, 0.11687634760164656, 0.08293851322378032, 0.10485184087883681, 0.06340699721476994, 0.02366371078096563, 0.037766336754430085, 0.30556413636077195, 0.004618743078026455, 3.433257322758436, 49.81253407895565, 45.27545973658562, 34.346904158592224, 19.521042108535767, 50.89294530451298, 57.90298394858837, 55.24061881005764, 58.926307037472725, 57.35228709876537, 56.35142080485821, 51.84718810021877, 54.39418002963066, 24.90797694772482, 0.45160247187595814, 2.033750144764781, 1.672333963215351, 1.3110121828503907, 0.27836249442771077, 25.955810621380806, 62.69318550825119, 56.22717127203941, 58.24769765138626, 54.87077325582504, 54.991264790296555, 55.07968224585056, 56.86654396355152, 55.2242074906826, 57.58069284260273, 55.08427619934082, 54.45387102663517, 56.32770627737045, 51.53424449265003, 48.83142292499542, 54.12534825503826, 55.208685323596, 50.84996581077576, 42.69717648625374, 39.70082826912403, 40.45004926621914, 40.1519438624382, 40.71700394153595, 40.75893089175224, 42.91563056409359, 46.59017398953438, 47.97926925122738, 44.77510638535023, 44.731765910983086, 45.245144963264465, 44.409896582365036, 40.89385785162449, 39.69055362045765, 40.95932453870773, 42.42514528334141, 43.116123005747795, 41.451284140348434, 37.069161683321, 37.675088569521904, 38.01976427435875, 39.16533440351486, 43.27626161277294, 49.40436378121376, 48.657502457499504, 50.41355162858963, 50.43838709592819, 51.309653744101524, 52.74043656885624, 53.12163971364498, 51.386694610118866, 53.26040826737881, 52.203171998262405, 42.01119929552078, 39.793075919151306, 39.97673526406288, 42.50322729349136, 41.031015291810036, 39.69893217086792, 49.369671642780304, 41.83378301560879, 40.113976299762726, 40.77311173081398, 41.489555686712265, 40.71341693401337, 38.20652425289154, 38.27581353485584, 37.227833569049835, 49.485934004187584, 52.77799375355244, 51.26559130847454, 53.08465249836445, 53.34976427257061, 53.31650085747242, 51.41376055777073, 49.71057415008545, 47.877385318279266, 45.328143909573555, 46.32503941655159, 45.94072803854942, 40.04803843796253, 40.068200156092644, 38.631763234734535, 39.134613052010536, 38.289500400424004, 40.53349658846855, 42.89169564843178, 39.541932195425034, 38.9398393034935, 44.248743429780006, 42.79253616929054, 47.07169555127621, 52.62231230735779, 52.15065121650696, 52.27418638765812, 51.5152683109045, 50.891596376895905, 49.59181152284145, 49.91054221987724, 46.40525311231613, 42.43356183171272, 40.57648368179798, 41.7814864218235, 40.16780041158199, 42.03354209661484, 47.44336500763893, 52.033066526055336, 54.81586620211601, 55.856269374489784, 55.84727145731449, 56.13078944385052, 53.2055202126503, 48.96976210176945, 54.442718625068665, 54.77520078420639, 57.52480164170265, 53.04671913385391, 44.24102604389191, 43.725982680916786, 57.51702345907688, 56.153212040662766, 62.652371898293495, 36.36062130331993, 0.28428055811673403, 0.4288598906714469, 0.9836545237340033, 0.4309834720334038, 34.497562274336815, 55.0610214471817, 56.44695147871971, 58.209087923169136, 56.89406968653202, 60.18424093723297, 55.17220348119736, 41.087370067834854, 40.67813962697983, 35.18987372517586, 49.55696739256382, 16.31099335849285, 0.7005042268428952, 0.03672278064186685, 0.17344567109830678, 0.015443179381691152, 0.2094702169415541, 0.025655611025285907, 0.06036528640834149, 0.03880545853462536, 0.04625028326699976, 0.005819806119689019, 0.041734455662663095, 0.07849750894820318, 0.05866616527782753, 0.03644555508799385, 0.04601514861860778, 0.053294325989554636, 0.03227924935345072, 0.30776018102187663, 0.08953704469604418, 5.962861385196447, 61.25687777996063, 48.50800707936287, 39.65633265674114, 35.5941454321146, 58.875233978033066, 64.00206327438354, 60.82715503871441, 65.70602104067802, 64.71330910921097, 63.80158603191376, 56.42836667597294, 58.52630630135536, 25.010204762220383, 0.6499726383481175, 3.512354828417301, 7.755701132118702, 1.7008234094828367, 0.10940254942397587, 28.507295809686184, 63.13152998685837, 58.55122156441212, 61.277005299925804, 56.87898829579353, 57.55877181887627, 56.730492264032364, 57.47643023729324, 56.98261633515358, 58.729960173368454, 56.615518033504486, 57.003887593746185, 57.191350534558296, 53.645019829273224, 48.259580209851265, 55.71698784828186, 58.404454439878464, 52.11624026298523, 43.63442279398441, 40.88999345898628, 42.60233357548714, 41.14602372050285, 43.56603026390076, 42.67602302134037, 45.76752193272114, 49.07413110136986, 50.14335572719574, 46.62164010107517, 48.20649325847626, 47.7261496335268, 45.928131714463234, 41.796453818678856, 42.5456216186285, 43.480740040540695, 45.567553862929344, 45.876013711094856, 43.44520054757595, 40.97265042364597, 40.63313104212284, 40.06582148373127, 41.87830902636051, 45.859530195593834, 50.88021598756313, 50.25078736245632, 54.537261351943016, 54.70528453588486, 54.147276878356934, 54.901627600193024, 53.61637316644192, 55.77746160328388, 55.48095591366291, 53.52726794779301, 42.558993101119995, 39.91596892476082, 39.09482918679714, 41.88323736190796, 40.06926029920578, 40.47150291502476, 53.14622439444065, 40.54030582308769, 40.59378035366535, 41.7849138379097, 41.57214045524597, 39.26146924495697, 37.92749762535095, 38.173401430249214, 39.181114956736565, 49.690906405448914, 54.072546288371086, 55.32791152596474, 54.69650320708752, 55.24300128221512, 54.50258441269398, 53.357170075178146, 50.97603164613247, 49.35067266225815, 46.713534370064735, 49.24750439822674, 47.81852267682552, 43.158433735370636, 42.792726159095764, 40.90351693332195, 40.06382279098034, 40.48589274287224, 41.06413431465626, 44.07919652760029, 40.705638751387596, 40.38199871778488, 45.27487076818943, 46.93365275859833, 48.136732801795006, 53.73194396495819, 53.34637105464935, 53.40542748570442, 53.52143906056881, 54.38700221478939, 50.15168868005276, 51.067998111248016, 47.816577181220055, 44.89978529512882, 41.127245128154755, 42.92221561074257, 41.17141775786877, 42.871617525815964, 49.040145725011826, 55.59315249323845, 56.63193695247173, 58.02058383822441, 57.15065851807594, 57.36170679330826, 53.59468773007393, 53.37424635887146, 56.70803926885128, 58.75737190246582, 60.16382463276386, 56.514166072010994, 47.2130935639143, 47.59620040655136, 57.91539788246155, 57.98126354813576, 63.29040706157684, 39.865602627396584, 0.31344693212304264, 0.8374126616399735, 0.7524948182981461, 0.48143179155886173, 43.257699608802795, 62.055401131510735, 61.463123112916946, 63.30282099545002, 62.54297576844692, 67.85526171326637, 56.18201829493046, 54.37779910862446, 38.93747203052044, 32.36922048032284, 59.86439310014248, 22.439633198082447, 0.5616194230969995, 0.03717563915415667, 0.16583136952249333, 0.06470403386629187, 0.05414109051343985, 0.015015347016742453, 0.04454550326045137, 0.04169877320236992, 0.138551015406847, 0.15521968191023916, 0.22309592954115942, 0.20984182512620464, 0.14282164484029636, 0.13477357279043645, 0.14750691218068823, 0.11794884747359902, 0.2254212711704895, 0.4897533153416589, 0.23052567383274436, 7.010775804519653, 72.82336592674255, 59.71193008124828, 43.2304322719574, 29.634357132017612, 64.39892917871475, 69.00219216942787, 69.24868494272232, 69.69581454992294, 69.90546450018883, 68.00371214747429, 62.61191546916962, 65.13623401522636, 30.724378041923046, 0.7975359982810915, 10.044985190033913, 9.892793856561184, 4.0830338560044765, 0.2643412468023598, 32.144188955426216, 60.68027012050152, 60.20162120461464, 62.317271679639816, 60.38513995707035, 60.112280398607254, 60.32766804099083, 62.028072997927666, 60.591043308377266, 61.49830162525177, 58.788796216249466, 56.90343238413334, 60.10584734380245, 55.75625494122505, 49.248686134815216, 57.18355715274811, 61.70889772474766, 54.94669318199158, 45.697734877467155, 42.94807702302933, 44.40368011593819, 43.669228926301, 47.75747135281563, 45.07438972592354, 49.363652765750885, 51.850319132208824, 53.50588269531727, 47.650586888194084, 50.20195618271828, 51.224477514624596, 48.618793934583664, 44.50677998363972, 44.35881972312927, 44.56975780427456, 46.43507391214371, 48.171812519431114, 45.43293848633766, 42.69447483122349, 43.61919321119785, 42.156560495495796, 43.45770567655563, 49.45306196808815, 53.11467848718166, 52.69655652344227, 54.77071702480316, 57.32592411339283, 57.029604613780975, 58.74321386218071, 58.142561092972755, 58.64845834672451, 57.06755317747593, 57.13358983397484, 43.18653702735901, 40.90662896633148, 39.728597179055214, 43.44746142625809, 39.84180070459843, 41.15690253674984, 57.64115519821644, 42.97523036599159, 39.466198459267616, 42.74145171046257, 41.22722156345844, 39.611434265971184, 37.31759235262871, 38.584805354475975, 38.210574835538864, 51.43348149955273, 57.29469358921051, 56.32340870797634, 59.24312263727188, 58.76723237335682, 58.290585950016975, 55.196024402976036, 54.387442991137505, 52.46992528438568, 50.667894780635834, 50.80252915620804, 50.41389361023903, 45.13469249010086, 44.51469875872135, 43.7034422904253, 42.884840816259384, 41.71530157327652, 44.85530488193035, 45.65299607813358, 43.29580396413803, 42.350076511502266, 46.86977058649063, 47.383145838975906, 52.07627020776272, 56.33445091545582, 54.155081659555435, 54.42756503820419, 54.82893370091915, 54.92692284286022, 52.51265399158001, 53.67277733981609, 49.53941993415356, 45.54276779294014, 42.630543261766434, 45.58114193379879, 42.473421692848206, 45.8648195117712, 51.58196613192558, 56.98513939976692, 60.36921501159668, 60.526754558086395, 60.470707565546036, 59.063802659511566, 58.41890886425972, 53.3339799195528, 57.77846843004227, 62.971573770046234, 62.018862292170525, 58.85659597814083, 48.368254378437996, 48.86522211134434, 60.67854501307011, 60.42987495660782, 64.78197142481804, 45.610860139131546, 0.4213164938846603, 1.0143078351393342, 7.773730689659715, 0.30836244870442897, 47.19888232648373, 67.27968379855156, 68.3800895512104, 68.36425200104713, 68.47569242119789, 72.77688682079315, 65.15828803181648, 58.0492988973856, 53.28696124255657, 46.01099766790867, 70.41940972208977, 29.959600679576397, 0.9590977476909757, 0.08181320212315768, 0.2907865511951968, 0.25213475804775953, 0.2915599284460768, 0.11227370356209576, 0.14525461272569373, 0.21653086150763556], [0.00687892692440073, 0.11420511320466176, 0.07711818296229467, 0.0454720709240064, 0.018435647762089502, 0.04163801728282124, 0.05019300588173792, 0.08901866196538322, 0.04543963907053694, 0.11239189057960175, 0.18453184340614825, 0.5964268022216856, 41.11727446317673, 53.648021668195724, 40.39055585861206, 34.91395153105259, 35.627994015812874, 62.23387375473976, 56.82220794260502, 58.152421563863754, 56.5304633975029, 55.351610854268074, 52.97581873834133, 55.43266050517559, 39.069860726594925, 0.6441027845721692, 1.620432073250413, 4.825013391673565, 2.5366201484575868, 0.40367718727793545, 28.07392716407776, 64.57125753164291, 49.89388391375542, 59.34394642710686, 55.74028059840202, 60.15402115881443, 55.35282678902149, 55.66327013075352, 54.70316044986248, 58.088664785027504, 53.725351318717, 51.91969580948353, 53.49336616694927, 53.43524068593979, 47.65818648040295, 52.983205541968346, 55.007121339440346, 47.405724227428436, 38.81600394845009, 40.77506862580776, 40.631804913282394, 39.661925956606865, 41.75846345722675, 42.05685764551163, 45.85226498544216, 49.24218088388443, 46.98470301926136, 46.824024841189384, 45.206907615065575, 45.83159789443016, 43.25514234602451, 41.454947143793106, 39.52889509499073, 41.51108153164387, 40.29015004634857, 40.00896133482456, 38.915961384773254, 38.2934445887804, 36.61359652876854, 37.54487335681915, 39.983529299497604, 44.53769512474537, 49.445690363645554, 49.4858618080616, 51.90896898508072, 52.540947273373604, 51.05613894760609, 52.61372856795788, 53.23940299451351, 50.13791061937809, 51.989118084311485, 49.96033474802971, 39.65219847857952, 38.33120696246624, 40.21671138703823, 39.996676594018936, 41.86136953532696, 38.81267532706261, 49.402327090501785, 41.67655125260353, 38.884894251823425, 40.311269313097, 41.290089190006256, 41.70329801738262, 40.69176949560642, 40.262601524591446, 41.77954472601414, 49.53530855476856, 54.71731089055538, 50.325669944286346, 52.646277621388435, 53.35948795080185, 50.21297559142113, 52.29419231414795, 52.0550749450922, 48.39995227754116, 45.05828619003296, 42.087829783558846, 43.04322771728039, 43.680172339081764, 41.05858661234379, 39.24790017306805, 39.00059424340725, 42.1302355080843, 43.122210279107094, 39.79619935154915, 39.015253856778145, 39.7441079467535, 43.347336798906326, 44.9616763740778, 47.856752425432205, 51.38384096324444, 51.311625838279724, 50.21396353840828, 49.40453477203846, 51.794606521725655, 50.127495378255844, 49.46400158107281, 45.117734000086784, 42.381820008158684, 40.60383841395378, 39.78359542787075, 38.90652649104595, 40.779958963394165, 41.987534165382385, 47.98370361328125, 49.78142134845257, 54.035688266158104, 52.37616531550884, 54.33638513088226, 55.547144562006, 61.07886113226414, 49.652311876416206, 40.83652652800083, 57.66025297343731, 55.89930586516857, 49.74374257028103, 42.50801883637905, 54.709734097123146, 55.93428298830986, 60.60555852949619, 31.109641268849373, 0.4758829908678308, 0.9373283595778048, 0.34527743817307055, 3.7702880753204226, 48.94334591925144, 51.236097291111946, 56.45129084587097, 56.09416700899601, 53.55799309909344, 59.34989310801029, 52.98104725778103, 33.07720609009266, 23.196915462613106, 40.73449060320854, 41.89676083624363, 3.6630433425307274, 0.508366230642423, 0.04231589125993196, 0.14851517917122692, 0.0686904726899229, 0.07251824034028687, 0.060847229688079096, 0.07905265025328845, 0.04259024099155795, 0.040082557388814166, 0.05407237506005913, 0.027489756648719776, 0.07211816337076016, 0.02659268935531145, 0.1293167835683562, 0.0994190081837587, 0.06461856813984923, 0.030870502778270748, 0.1300440140767023, 0.12586771161295474, 0.8212375827133656, 47.8734677284956, 60.30950501561165, 37.83565275371075, 35.2037163823843, 48.443475142121315, 66.79081723093987, 61.68969355523586, 62.51555263996124, 63.44511955976486, 60.2603280544281, 56.92341931164265, 60.76203793287277, 40.43985441327095, 0.4105280415387824, 1.8820004188455641, 5.737261790782213, 3.991311052814126, 0.27451772417407483, 32.07261599600315, 61.7269429564476, 52.50728867948055, 61.10985226929188, 59.24526572227478, 60.334310084581375, 57.8898024559021, 59.105665013194084, 57.41257466375828, 59.81241188943386, 56.144130527973175, 53.4531719237566, 55.98206542432308, 54.09254841506481, 49.263520538806915, 56.07981137931347, 57.62515805661678, 49.95950259268284, 41.41055412590504, 42.647205367684364, 42.742853835225105, 41.54160909354687, 44.64027062058449, 45.72453483939171, 48.75650234520435, 50.29054082930088, 49.336100444197655, 49.96164567768574, 46.63287989795208, 46.41527697443962, 46.319788098335266, 43.283861204981804, 40.841956436634064, 44.83835779130459, 43.291065618395805, 42.19011269509792, 40.48824481666088, 40.310323163867, 39.92223098874092, 39.85771805047989, 42.495726495981216, 48.6724204570055, 53.280334398150444, 51.58013463020325, 54.75745193660259, 53.82780522108078, 53.481518402695656, 55.65630130469799, 55.09046986699104, 52.540681287646294, 55.05217932164669, 51.745076179504395, 41.0247266292572, 38.156260550022125, 41.716574504971504, 40.48161797225475, 40.84186524152756, 39.57370229065418, 51.15428768098354, 41.45023539662361, 38.638682663440704, 39.88922595977783, 42.045006081461906, 40.92596612870693, 38.69629517197609, 40.59655040502548, 41.04826636612415, 51.617684215307236, 57.476054057478905, 53.64042207598686, 54.57338221371174, 54.713625088334084, 54.70928952097893, 54.73278746008873, 53.45138981938362, 50.32972812652588, 46.64257697761059, 44.24189619719982, 44.327668994665146, 45.300086215138435, 43.762692511081696, 40.86279071867466, 41.14096999168396, 44.776683300733566, 43.65837290883064, 40.85995227098465, 41.141737550497055, 41.743853241205215, 45.50366409122944, 45.9593166410923, 50.04836842417717, 52.53438502550125, 54.58313629031181, 53.216699212789536, 51.573975160717964, 53.66058759391308, 52.80504070222378, 52.05968789756298, 47.688729241490364, 44.32759679853916, 41.569476798176765, 39.48349893093109, 41.142717897892, 42.03203357756138, 42.6703043282032, 50.38544833660126, 51.81125722825527, 55.42894810438156, 54.601470306515694, 55.9745342284441, 57.919262275099754, 63.020667135715485, 52.72117540240288, 43.83192479610443, 59.65630106627941, 57.443820387125015, 52.26606622338295, 45.44099785387516, 57.681619226932526, 59.314300417900085, 62.10187263786793, 33.296359330415726, 0.323895777692087, 1.1694506602361798, 1.2279404466971755, 4.962024064734578, 54.173491671681404, 58.693611323833466, 61.43730729818344, 62.29711756110191, 58.36121656000614, 65.6247130036354, 58.79493668675423, 46.87044695019722, 25.128237828612328, 41.638241708278656, 53.71950723230839, 6.4086121413856745, 0.4191966826329008, 0.017636020747886505, 0.019983270576631185, 0.05789344111690298, 0.026662826021492947, 0.025822167517617345, 0.047764951013959944, 0.04720317119790707, 0.11032195165171288, 0.14284431003034115, 0.2667478536022827, 0.13307457411428913, 0.14222483936464414, 0.17698880285024643, 0.13341848534764722, 0.24050337437074631, 0.10791052089189179, 0.2610009291674942, 0.3827050141990185, 1.1805432150140405, 56.743236780166626, 73.09896513819695, 51.608731895685196, 48.925965651869774, 51.8646215647459, 72.94694289565086, 69.21262487769127, 68.88222500681877, 66.50412261486053, 65.87114498019218, 61.840952038764954, 65.2158473432064, 48.92602264881134, 0.5495634418912232, 7.577722482383251, 17.564133815467358, 6.119832387194037, 0.4612163419369608, 34.088027849793434, 61.29779778420925, 51.7471394687891, 63.66383582353592, 61.61414980888367, 62.71083176136017, 61.29719741642475, 62.08026319742203, 62.399848848581314, 62.55095534026623, 58.34578178822994, 54.02275376021862, 57.49306194484234, 55.20727559924126, 51.59127563238144, 58.37743788957596, 60.748689249157906, 51.9220706820488, 42.30890192091465, 45.84381423890591, 44.395008981227875, 43.59221085906029, 46.63438081741333, 47.194998934865, 52.14463613927364, 54.34197463095188, 51.5598551183939, 53.273251578211784, 48.81515599787235, 48.71021702885628, 47.357873395085335, 46.14169165492058, 44.583600461483, 46.9988838583231, 46.09346084296703, 46.19654171168804, 43.76482419669628, 42.45311938226223, 41.34551301598549, 42.44727149605751, 45.94203516840935, 49.575331807136536, 55.750315859913826, 55.72574257850647, 58.84153738617897, 56.37266926467419, 56.277191787958145, 59.142640829086304, 57.04116739332676, 55.59927016496658, 58.49357485771179, 54.36276711523533, 41.46313190460205, 38.18132020533085, 40.52204020321369, 40.5978499352932, 41.50765411555767, 41.21817424893379, 55.0189995020628, 42.6006730645895, 38.76620002090931, 40.415041744709015, 42.019304260611534, 42.12596453726292, 40.72507470846176, 41.17335565388203, 41.60491369664669, 52.73918643593788, 59.52556148171425, 55.796578377485275, 58.178199380636215, 58.700393959879875, 55.59669390320778, 57.34307259321213, 56.31821058690548, 53.14665377140045, 48.191347271203995, 46.951933577656746, 46.54004327952862, 47.388606145977974, 46.28617890179157, 44.14748266339302, 43.52553963661194, 46.48998476564884, 46.730238273739815, 43.79865378141403, 42.68272966146469, 43.54841060936451, 47.22849793732166, 48.14423739910126, 51.21874742209911, 55.07342018187046, 54.658642038702965, 53.24631482362747, 52.83796973526478, 56.90013416111469, 54.29590970277786, 52.70737074315548, 49.595645517110825, 46.29723250865936, 44.273696690797806, 41.91021591424942, 43.44129055738449, 45.08912153542042, 46.42592780292034, 53.92185017466545, 53.036053106188774, 58.30229692161083, 57.068073749542236, 57.10222631692886, 58.99937331676483, 64.5857347548008, 55.53310811519623, 45.27805119752884, 62.515298053622246, 58.71967792510986, 55.01860052347183, 48.55564892292023, 60.23255914449692, 62.00989477336407, 66.08324199914932, 38.19738194346428, 0.37184772023465484, 2.475323975086212, 2.8361887112259865, 4.566419217735529, 60.856907442212105, 61.718841791152954, 68.68612512946129, 65.54498568177223, 66.28007143735886, 72.05016061663628, 67.2761119902134, 45.55237367749214, 31.75390999764204, 51.847112104296684, 65.18173277378082, 12.360986564308405, 0.7937660068273544, 0.1801247478579171, 0.2619727863930166, 0.133974309428595, 0.16032166517106816, 0.21672429487807676, 0.15850365569349378, 0.18898857379099354], [0.005899214529563324, 0.03108149907347979, 0.038295447229756974, 0.01846289014793001, 0.04400848891236819, 0.024946475932665635, 0.04203888835036196, 0.05232875846559182, 0.09481085740844719, 0.10023124428698793, 0.2625560847809538, 0.03952893377572764, 22.644774690270424, 56.75598129630089, 44.65261235833168, 42.225238010287285, 31.963140070438385, 53.1242311745882, 58.31965059041977, 60.87472088634968, 55.77638626098633, 59.3824877589941, 48.67911569774151, 47.389943674206734, 57.02571362257004, 4.584079720079899, 2.0908765168860555, 3.679338530637324, 2.9195985104888678, 1.1415247712284327, 23.718321584165096, 47.1442336589098, 55.729109197854996, 56.69729344546795, 58.34200479090214, 57.82826095819473, 57.178359031677246, 53.65935266017914, 51.72474727034569, 55.075164288282394, 55.077307373285294, 54.742678329348564, 56.52961224317551, 55.5432041734457, 57.2171663492918, 54.188987240195274, 49.11973625421524, 42.13011011481285, 39.7837246209383, 38.85806009173393, 40.37427753210068, 40.212976187467575, 40.33422768115997, 45.08525714278221, 46.62958167493343, 49.92090426385403, 47.93234556913376, 48.79011534154415, 48.5341040790081, 46.79184436798096, 44.37108166515827, 41.894613951444626, 39.20291058719158, 40.34335859119892, 40.1643767952919, 38.125242814421654, 38.57785552740097, 36.86471365392208, 37.202279940247536, 38.39313983917236, 43.21288861334324, 46.89386509358883, 48.94563339650631, 52.38388270139694, 49.236363396048546, 50.436073020100594, 53.787284195423126, 52.53654330968857, 49.835177063941956, 49.444345235824585, 52.33516551554203, 48.57961803674698, 40.93598619103432, 41.4573410153389, 38.48663002252579, 40.71234539151192, 38.934903368353844, 39.46835674345493, 47.68236458301544, 42.57921181619167, 40.20710550248623, 40.664733946323395, 41.42571531236172, 42.674886882305145, 41.234254986047745, 41.920194178819656, 42.613995149731636, 48.41396972537041, 55.35457469522953, 52.08489574491978, 54.62149143218994, 51.722368597984314, 53.179711997509, 49.90323141217232, 51.91900044679642, 51.3446194678545, 48.70921768248081, 41.66679337620735, 42.054771557450294, 42.56921835243702, 41.33230872452259, 38.64385038614273, 35.18986612558365, 38.86406756937504, 41.74339346587658, 40.28980426490307, 38.521348759531975, 40.36814846098423, 43.81268262863159, 44.56595420837402, 47.97022953629494, 49.3458317220211, 53.3861169219017, 51.47561363875866, 50.353469252586365, 49.6190370619297, 48.455790281295776, 47.904705852270126, 43.96355353295803, 40.542718693614006, 38.37246514856815, 37.97054931521416, 40.33636316657066, 39.90809954702854, 41.86421938240528, 40.46259619295597, 41.77035301923752, 42.79243357479572, 46.303536370396614, 52.58181408047676, 50.12335740029812, 53.521203473210335, 56.92772068083286, 47.38044798374176, 53.833922892808914, 57.16575510799885, 55.467668026685715, 45.64839072525501, 51.54888890683651, 54.26854357123375, 59.06024985015392, 25.095840767025948, 0.3065968200098723, 4.370971955358982, 0.6304563512094319, 19.43578228354454, 58.99339243769646, 53.14187362790108, 54.60685081779957, 53.350341841578484, 56.23964600265026, 60.39971977472305, 41.91998139023781, 33.559916988015175, 35.601600632071495, 37.549900487065315, 38.28830726444721, 1.2154745031148195, 0.14513033267576247, 0.21221033006440848, 0.06253765284782276, 0.07265867694513872, 0.06801083611208014, 0.12007819532300346, 0.023389331363432575, 0.047673099106759764, 0.07368303369730711, 0.03672296617878601, 0.03173965975292958, 0.03429979093198199, 0.022230428803595714, 0.05177981780434493, 0.02696381699934136, 0.0580153611372225, 0.028268278838368133, 0.031494621143792756, 0.1625651479116641, 0.11257376871071756, 29.966345317661762, 65.73137328028679, 42.083988189697266, 40.798661559820175, 45.992416664958, 58.6234100908041, 65.3956612944603, 65.91618776321411, 60.66400319337845, 64.09336477518082, 54.52186457812786, 52.75842860341072, 62.13121846318245, 4.570636041462421, 2.2431037109345198, 4.304591892287135, 7.994333077222109, 1.790151628665626, 28.64733349531889, 45.65686047077179, 57.009959667921066, 57.22751699388027, 60.67743927240372, 58.65928776562214, 59.361292496323586, 56.43152430653572, 55.498385578393936, 57.2850801050663, 58.8094937056303, 57.07851938903332, 57.918696105480194, 55.97649872303009, 59.01125147938728, 55.134384110569954, 54.266609475016594, 43.175943195819855, 41.875174194574356, 42.15934954583645, 42.104860469698906, 43.47390420734882, 42.41688072681427, 46.515515595674515, 48.6213131994009, 51.09510965645313, 51.273905262351036, 50.54704986512661, 49.77224484086037, 48.342176377773285, 45.68109177052975, 44.84191820025444, 41.02666832506657, 41.99517175555229, 42.24983409047127, 40.48973813652992, 40.46559043228626, 38.43823201954365, 39.22391206026077, 39.69566434621811, 45.32511167228222, 49.40375201404095, 51.91541723906994, 55.335514917969704, 52.9110512137413, 54.07139115035534, 55.2497573196888, 56.612694784998894, 52.81113937497139, 52.06520900130272, 55.87690606713295, 50.82825377583504, 41.04928471148014, 39.86926943063736, 40.12240044772625, 41.03125847876072, 39.76066745817661, 41.02577157318592, 51.53373911976814, 42.20090791583061, 39.99358355998993, 40.86584195494652, 40.12350618839264, 43.25531713664532, 40.82064338028431, 41.76632523536682, 41.34661115705967, 48.51496450603008, 56.832615584135056, 53.653288185596466, 56.20386332273483, 53.03812399506569, 56.78991727530956, 52.558380737900734, 55.27817979454994, 54.40400630235672, 50.31751558184624, 45.65230831503868, 42.92669177055359, 44.82751317322254, 43.91805857419968, 41.11923895776272, 39.2728154361248, 42.91363567113876, 43.23093004524708, 42.710156589746475, 39.47418563067913, 41.65178798139095, 46.41659930348396, 46.16616614162922, 50.16667127609253, 50.60641787946224, 54.56884525716305, 54.0029264241457, 51.72337934374809, 50.747610703110695, 50.76893135905266, 50.113432332873344, 46.55456230044365, 44.07484196126461, 40.0181720405817, 40.76588451862335, 40.76709285378456, 42.6489532738924, 43.21204125881195, 41.65027566254139, 43.949657678604126, 44.90706570446491, 48.78051705658436, 52.21074879169464, 53.753864988684654, 55.03510683774948, 59.670109525322914, 51.455843299627304, 54.27142761647701, 59.42439951002598, 56.79371327161789, 49.26401451230049, 54.38955567777157, 56.248096749186516, 63.89261394739151, 26.533535420894623, 0.4515120782889426, 4.072776306420565, 0.6093052611686289, 22.383113130927086, 58.98923546075821, 57.121179699897766, 60.36831445991993, 58.38110849261284, 65.79521745443344, 65.2646367251873, 50.115294232964516, 40.71851626038551, 29.201288670301437, 42.624531984329224, 46.13211236894131, 2.0400663558393717, 0.1426320557948202, 0.006948006493985304, 0.13315300428075716, 0.055555312283104286, 0.04357968340627849, 0.06798070491640829, 0.0071289513743977295, 0.030758327156945597, 0.2766350418096408, 0.2501460100756958, 0.15715722169261426, 0.16730373114114627, 0.1248005180968903, 0.1947086918517016, 0.13222198002040386, 0.15434719825861976, 0.298163914703764, 0.19294989091577008, 0.4224649822572246, 0.45188166783191264, 34.43329632282257, 77.56897687911987, 58.04863393306732, 51.7185840010643, 47.863174080848694, 63.02967645227909, 70.11890664696693, 71.37511923909187, 64.46414887905121, 71.09403312206268, 61.72570042312145, 58.50942000746727, 65.60870066285133, 5.985718108713627, 7.058432372286916, 14.997117910534143, 10.551469512283802, 5.1536416076123714, 34.911375269293785, 47.80798204243183, 56.86030849814415, 58.389775827527046, 63.05933006107807, 62.285190001130104, 59.42031852900982, 57.99180418252945, 55.1607508957386, 58.4255813062191, 62.086958438158035, 59.93887670338154, 59.807578548789024, 58.64614047110081, 63.017452508211136, 58.92719238996506, 54.39463600516319, 46.18718661367893, 43.62898908555508, 45.15615373849869, 44.884437918663025, 46.82324968278408, 44.631667882204056, 49.0432957559824, 50.27946822345257, 54.335511177778244, 53.28191131353378, 53.760864213109016, 53.63107457756996, 51.94404490292072, 48.28031949698925, 47.40506686270237, 43.42422567307949, 43.82243670523167, 44.31610241532326, 43.67440044879913, 42.97178775072098, 41.86898432672024, 43.13351847231388, 42.27257966995239, 49.53193433582783, 52.58375197649002, 56.3959202170372, 59.42362815141678, 55.091199427843094, 56.130409464240074, 60.154632925987244, 60.33542342483997, 55.48889748752117, 53.34330841898918, 58.25019411742687, 53.19192074239254, 41.80440679192543, 41.72426909208298, 39.6513245254755, 41.8851600587368, 39.12256769835949, 43.887599408626556, 54.40170742571354, 43.41679327189922, 41.05702489614487, 41.195744052529335, 42.14842893183231, 44.20856438577175, 40.82645706832409, 43.0254864692688, 42.19358190894127, 50.345185697078705, 61.285957619547844, 55.191966220736504, 60.63366562128067, 56.75895653665066, 58.982490822672844, 55.87247170507908, 58.01172651350498, 57.93232597410679, 53.68861109018326, 47.37146906554699, 45.90830057859421, 48.54759715497494, 47.91361257433891, 43.2445827126503, 41.47319756448269, 44.84638296067715, 44.7114522010088, 44.09000314772129, 41.24651312828064, 43.48517820239067, 48.49347285926342, 49.315357357263565, 50.68534344434738, 52.30416677892208, 55.9733334928751, 56.51270695030689, 53.47198471426964, 51.51731260120869, 51.87718369066715, 52.48941443860531, 48.041323721408844, 45.5965881049633, 41.636053025722504, 40.83527259528637, 43.105327785015106, 44.9386952072382, 45.72898440063, 44.28025133907795, 46.0684809833765, 46.21961407363415, 50.613975673913956, 56.809600219130516, 56.554109528660774, 57.518003806471825, 61.970403492450714, 49.06829081475735, 56.403702199459076, 61.45749181509018, 58.92753057181835, 50.6629778444767, 57.754594311118126, 60.7666052877903, 64.94321197271347, 31.90090700984001, 0.6910801981575787, 9.208660516887903, 0.9142992796842009, 25.359176136553288, 67.11066886782646, 64.40564721822739, 65.69008469581604, 65.80880552530289, 68.20784479379654, 71.00686579942703, 57.213070169091225, 45.80778457224369, 44.948126301169395, 51.827543154358864, 57.79622867703438, 3.012323509901762, 0.3195801889523864, 0.28612242022063583, 0.23851067817304283, 0.204086959711276, 0.16835716523928568, 0.20292123866965994, 0.1264587283367291, 0.134108831116464], [0.09527951624477282, 0.038185464654816315, 0.0769672375463415, 0.06416071497369558, 0.030601644939451944, 0.029077653962303884, 0.05186370646697469, 0.09229395262082107, 0.10707131514209323, 0.015398881514556706, 0.3472361736930907, 0.08416680473601446, 3.8760855607688427, 54.10456717014313, 47.52134062349796, 27.934698835015297, 25.78780833631754, 45.49946151673794, 55.05297347903252, 55.70414833724499, 57.264941185712814, 57.94445112347603, 55.85026569664478, 49.88509878516197, 55.364001989364624, 11.80613273754716, 1.317315569613129, 2.9936546366661787, 0.6663166894577444, 14.293402321636677, 36.862927749753, 55.85555121302605, 58.75815466046333, 60.397242307662964, 57.85060375928879, 57.754035741090775, 56.77059531211853, 57.876909747719765, 55.32377354800701, 57.667822167277336, 55.89428633451462, 55.76065130531788, 56.250274032354355, 53.8682996481657, 52.84234710037708, 49.52300861477852, 41.40845663845539, 39.60871361196041, 42.05658785998821, 39.068025425076485, 39.82191637158394, 41.21897980570793, 45.30127175152302, 47.379414439201355, 50.2552293241024, 50.24409972131252, 51.332019343972206, 54.81380291283131, 50.05982480943203, 51.07490994036198, 45.82555241882801, 41.83465696871281, 40.44259026646614, 39.85836021602154, 38.668712452054024, 38.7841122597456, 38.376435935497284, 37.98452876508236, 37.88720838725567, 41.20199091732502, 42.716107070446014, 49.842062294483185, 48.94770048558712, 49.36926506459713, 51.35313481092453, 50.44596388936043, 52.09422044456005, 50.69508992135525, 52.5293654948473, 52.55565628409386, 51.70970007777214, 46.00823901593685, 42.20565006136894, 40.51813021302223, 39.542395770549774, 40.27241259813309, 39.661333188414574, 40.583467707037926, 48.89532409608364, 41.858709678053856, 40.43559484183788, 40.62907665967941, 41.58107377588749, 40.58669373393059, 41.300884410738945, 41.86114154756069, 42.27219969034195, 48.24676349759102, 52.66081944108009, 53.04554119706154, 51.954456344246864, 52.085606306791306, 53.42713572084904, 50.72258524596691, 50.82448437809944, 50.179024413228035, 50.618425235152245, 47.03697681427002, 39.87904250621796, 42.05852575600147, 42.451846450567245, 37.7263630181551, 38.30998130142689, 40.6755405664444, 38.597796857357025, 38.47004011273384, 36.792874708771706, 38.76590743660927, 42.79933400452137, 45.15203095972538, 50.237548872828484, 48.30380603671074, 52.38428547978401, 50.99506862461567, 49.77789133787155, 48.15650314092636, 45.77910751104355, 45.309270322322845, 41.25227741897106, 40.422116965055466, 39.80372294783592, 38.73247303068638, 38.93678426742554, 38.38379234075546, 37.92169913649559, 39.89019490778446, 40.028446689248085, 39.76265475153923, 41.3510949164629, 45.16142025589943, 51.33905276656151, 50.88211588561535, 56.112531423568726, 60.470380783081055, 57.139916494488716, 59.24341142177582, 56.360327526926994, 52.53075622022152, 55.45335419476032, 57.09816813468933, 56.54779426753521, 26.001628562808037, 2.4302018713206053, 0.9544100461062044, 0.3369894891511649, 34.09977301955223, 63.56771618127823, 51.573462188243866, 52.71957188844681, 55.64278542995453, 43.088259100914, 46.2419530749321, 45.315650179982185, 29.66930005699396, 21.02452453225851, 42.556549832224846, 26.104177460074425, 0.49788235570304096, 0.03564080725482199, 0.19159361603669822, 0.034189299985882826, 0.11464007111499086, 0.051835482590831816, 0.06077482576074544, 0.014417385646083858, 0.05932190098974388, 0.007622135408382746, 0.03523483763274271, 0.017714582645567134, 0.050641370689845644, 0.10388275928562507, 0.022396057611331344, 0.027109587790619116, 0.045880196485086344, 0.003426474950174452, 0.053135317139094695, 0.30033523100428283, 0.18331161903915927, 7.126966444775462, 61.95938788354397, 47.29695126414299, 31.87420204281807, 38.46896477043629, 48.76078851521015, 62.84307226538658, 61.55920095741749, 62.21670247614384, 62.71580949425697, 59.96623143553734, 53.87925826013088, 62.52021498978138, 12.748824153095484, 1.1940913880243897, 3.3604344679042697, 1.869721852708608, 20.279249623417854, 40.643595680594444, 55.19039310514927, 59.3714265525341, 60.91026797890663, 61.025162413716316, 61.38827092945576, 58.85724574327469, 58.675775080919266, 57.72795774042606, 58.49414862692356, 57.612048760056496, 58.14681686460972, 58.133076801896095, 56.469799652695656, 54.743031710386276, 52.143530398607254, 43.78339760005474, 41.7058514803648, 43.63163374364376, 41.082859709858894, 42.17935547232628, 42.30005979537964, 48.30308027565479, 50.16470678150654, 51.87949776649475, 53.245991840958595, 52.96698801219463, 56.366999968886375, 52.31417544186115, 52.406480088829994, 48.36214430630207, 44.35066916048527, 41.20289906859398, 40.91228686273098, 40.882390066981316, 42.010952308773994, 41.96804121136665, 40.53930267691612, 41.308533400297165, 42.646529003977776, 47.494305074214935, 52.60012909770012, 51.740102246403694, 52.1101263910532, 54.387511387467384, 53.093027248978615, 53.734459429979324, 54.02486264705658, 54.93884660303593, 54.47131969034672, 53.82596991956234, 47.884202152490616, 41.5892281383276, 41.172325909137726, 40.02992860972881, 41.385916247963905, 40.8404441177845, 41.960282027721405, 52.45104029774666, 41.28435529768467, 39.90498751401901, 40.10331407189369, 41.43917039036751, 40.6892616301775, 41.75118304789066, 40.61863861978054, 41.52901276946068, 47.2717510163784, 55.32026633620262, 55.72829984128475, 54.49864022433758, 54.13178130984306, 55.59824422001839, 49.71449173986912, 52.8077195584774, 52.72180616855621, 53.63240450620651, 49.30695220828056, 42.41425506770611, 44.87767048180103, 44.0820349752903, 38.162416219711304, 39.15514335036278, 40.57991109788418, 41.1344039440155, 41.18407107889652, 40.05594961345196, 40.28182849287987, 44.51452776789665, 46.999826207756996, 52.16604419052601, 50.38601070642471, 54.567925706505775, 51.61478117108345, 51.301799565553665, 50.141421630978584, 47.156066223978996, 45.546502992510796, 44.595573619008064, 43.648710027337074, 41.243971064686775, 41.10788516700268, 40.55838905274868, 39.41348388791084, 39.82817463576794, 41.399679109454155, 41.83672785758972, 41.36425741016865, 43.41378003358841, 44.67049039900303, 53.82529355585575, 53.36531683802605, 57.476061657071114, 61.61807879805565, 58.1801600754261, 58.774801567196846, 58.585366532206535, 56.663881838321686, 58.00514906644821, 58.46834421157837, 58.394061997532845, 28.298835195600986, 3.037392902188003, 2.0449141832068563, 0.44540402479469776, 39.63666871190071, 64.79781657457352, 56.906658411026, 59.27719160914421, 63.18158470094204, 53.34652304649353, 51.854848489165306, 53.72262306511402, 38.24063882231712, 22.14091032743454, 48.56588177382946, 33.40379476547241, 0.6013134587556124, 0.059626563743222505, 0.2757668774574995, 0.05919373579672538, 0.14035991131095216, 0.07354393295827322, 0.058360522889415734, 0.021708016211050563, 0.0530186812102329, 0.1244894765841309, 0.110452814551536, 0.11372823879355565, 0.19573726400267333, 0.1638839888619259, 0.12873176339780912, 0.12142853302066214, 0.2080016996478662, 0.2315892605111003, 0.1634686830220744, 0.5764465837273747, 0.34788807621225715, 8.624716401100159, 73.5666972398758, 60.092928037047386, 37.425962537527084, 38.865959867835045, 57.64259912073612, 67.54544153809547, 67.13564872741699, 66.50121197104454, 69.05243307352066, 66.70435667037964, 61.14349566400051, 65.13448610901833, 16.13651432096958, 3.4481945587322116, 11.287419721484184, 5.3171515837311745, 27.542119100689888, 46.8705153465271, 55.39855733513832, 63.205633610486984, 63.33865687251091, 63.268413841724396, 64.89190712571144, 62.78193734586239, 62.936364859342575, 58.67497332394123, 62.06586576998234, 60.87041951715946, 59.953399524092674, 59.35875043272972, 58.29749397933483, 57.61737987399101, 55.303273648023605, 46.0969452559948, 43.71899105608463, 45.66590778529644, 44.017161056399345, 45.23817613720894, 43.89253914356232, 50.907829105854034, 52.2339503467083, 54.396900683641434, 55.64299061894417, 54.124048724770546, 60.81507928669453, 55.071459487080574, 57.750767916440964, 50.75889229774475, 45.137139558792114, 42.325309440493584, 43.022815212607384, 43.79049561917782, 45.92255361378193, 44.47003595530987, 42.7923309803009, 44.65991176664829, 47.12447091937065, 48.405006006360054, 56.830214112997055, 54.92841236293316, 53.189044296741486, 57.68016770482063, 55.37911377847195, 57.845876812934875, 56.98811084032059, 58.59138920903206, 58.09795528650284, 56.35149300098419, 48.60674478113651, 42.46620588004589, 40.66655404865742, 40.065012127161026, 40.030916556715965, 40.117947086691856, 42.69642032682896, 55.437072068452835, 42.002737149596214, 40.728927701711655, 41.35051354765892, 42.731431648135185, 40.281912088394165, 42.53402844071388, 41.926342248916626, 42.10626259446144, 48.39392200112343, 58.24304670095444, 57.00576089322567, 57.12154448032379, 56.50772161781788, 57.431490048766136, 52.87698604166508, 55.18322288990021, 55.150738433003426, 57.41973727941513, 51.542478650808334, 44.69198204576969, 47.53915026783943, 46.17835208773613, 40.58675833046436, 41.41195245087147, 42.63249255716801, 41.828463301062584, 42.60171800851822, 41.76094092428684, 42.00072705745697, 47.366054356098175, 48.724492862820625, 54.227790758013725, 51.32803715765476, 56.01128205657005, 52.44895040988922, 53.52459289133549, 54.030262157320976, 49.94708865880966, 49.26435649394989, 44.848001673817635, 45.92679798603058, 43.81585545837879, 42.29991540312767, 42.365621477365494, 40.98306946456432, 42.67327576875687, 45.41373051702976, 43.6800317466259, 43.600448817014694, 46.0524420440197, 47.06338919699192, 55.942547544837, 56.26187860965729, 57.46643677353859, 62.34090641140938, 58.3714684098959, 63.219518065452576, 60.926778092980385, 57.85334721207619, 60.44089816510677, 61.442676410079, 63.92078563570976, 31.83317754417658, 6.221406161785126, 4.451621202751994, 0.7254473946522921, 45.29188625514507, 73.09082597494125, 63.89173999428749, 64.70185652375221, 67.49317154288292, 55.05374103784561, 59.078944846987724, 57.59102828800678, 41.94585420191288, 28.029771633446217, 58.97054046392441, 42.38184280693531, 0.5171822325792164, 0.11281463273917325, 0.23262581817107275, 0.19534377730451524, 0.2922191336983815, 0.17755969252903014, 0.1754877794883214, 0.09719360416056588, 0.11568107423954643], [0.03858111100271344, 0.03026680089533329, 0.044692455921904184, 0.03794860822381452, 0.03627597434388008, 0.018324310767638963, 0.07382577838143334, 0.023258577930391766, 0.03465153553406708, 0.16098309686640278, 0.12346079311100766, 0.18987282790476456, 0.4629304655827582, 40.55366970598698, 54.84315253794193, 29.662580117583275, 30.139336735010147, 46.86972118914127, 58.078203946352005, 61.421754732728004, 58.202879056334496, 54.304204657673836, 60.24073250591755, 48.70242364704609, 57.54702664911747, 22.091085501015186, 0.24084439122816548, 4.216528767719865, 0.31284246768336743, 26.383274383842945, 25.59527076780796, 60.80738089978695, 60.527320727705956, 60.28976507484913, 55.86276322603226, 55.23245304822922, 54.5582590252161, 55.66087245941162, 56.15650646388531, 55.430126041173935, 54.00379277765751, 53.467668145895004, 51.545043513178825, 50.686221197247505, 44.57930289208889, 41.231272146105766, 40.419947281479836, 40.040864422917366, 40.002053305506706, 40.01960836350918, 40.22648826241493, 41.44286759197712, 45.420231968164444, 47.63906970620155, 49.206907376646996, 51.652858927845955, 53.67001488804817, 45.59828661382198, 47.53670699894428, 55.24322547018528, 45.881964191794395, 43.296183943748474, 40.230219662189484, 40.92370145022869, 38.934390395879745, 37.78736874461174, 37.32426859438419, 38.35858069360256, 38.7089066952467, 39.9698044359684, 45.413407534360886, 51.26077316701412, 50.026857778429985, 51.24688111245632, 51.32092013955116, 49.05319802463055, 51.39866776764393, 50.244084522128105, 51.37426547706127, 50.65015733242035, 49.303532391786575, 44.6425960958004, 41.156803742051125, 40.665942281484604, 41.009903624653816, 41.627727672457695, 41.501954421401024, 42.10285037755966, 46.18974007666111, 42.87848375737667, 41.554760187864304, 41.16006396710873, 42.01875329017639, 42.04128988087177, 39.47130538523197, 40.36239556968212, 42.58288621902466, 45.889483988285065, 51.6867683082819, 52.99095332622528, 51.336332112550735, 52.79772609472275, 54.301408007740974, 51.503298953175545, 50.1326896995306, 50.398952811956406, 50.31650483608246, 47.21688196063042, 43.73206615447998, 40.28908230364323, 40.63341222703457, 40.88291823863983, 38.18499080836773, 39.17009174823761, 38.81073363125324, 40.82216329872608, 39.39910165965557, 38.711950331926346, 42.36130490899086, 45.99798336625099, 45.42462073266506, 48.2037840038538, 47.56960563361645, 48.01086835563183, 46.1387088149786, 42.57523722946644, 42.29062110185623, 41.45818077027798, 40.63377320766449, 37.96688251197338, 39.423568546772, 39.682361260056496, 38.64303722977638, 39.71935987472534, 39.30732898414135, 41.44783012568951, 45.75830742716789, 48.622688725590706, 49.35297153890133, 50.45745067298412, 49.55814152956009, 50.72929948568344, 56.42737492918968, 55.84220252931118, 55.79307496547699, 57.27117285132408, 59.74450573325157, 56.46712079644203, 55.44220559298992, 60.11981159448624, 50.868315026164055, 16.788565032184124, 1.4988537970930338, 1.5306495409458876, 0.8462784171570092, 41.44333876669407, 54.76767338812351, 56.0928750783205, 54.96710188686848, 44.69416692852974, 44.601113721728325, 49.81378421187401, 36.71212524175644, 26.479223035275936, 27.46243167668581, 52.07290358841419, 9.598303958773613, 0.6382335838861763, 0.04699123979662545, 0.08163997743395157, 0.07444153830874711, 0.0840583472745493, 0.04085859523911495, 0.07462353518349119, 0.003948721951019252, 0.04176555907179136, 0.06637874204898253, 0.018522887221479323, 0.04559936780424323, 0.048417395300930366, 0.0332848854304757, 0.0300785885337973, 0.06522313648019917, 0.034259577660122886, 0.08114150652545504, 0.06341422573314048, 0.12846515426645055, 0.18942875642096624, 1.5779597335495055, 50.7220608741045, 60.61661213636398, 33.187609165906906, 42.700147926807404, 54.86899875104427, 60.41565611958504, 67.49239638447762, 62.51296117901802, 60.394286066293716, 65.58454155921936, 54.25797253847122, 62.94030524790287, 23.539022505283356, 0.1596941941534169, 5.363889075815678, 0.5240506608970463, 31.563568711280823, 30.533508583903313, 61.71846941113472, 62.15414263308048, 61.86003841459751, 58.3268778026104, 57.30830825865269, 58.02233934402466, 58.33307147026062, 57.12676540017128, 57.08666235208511, 57.36744448542595, 56.16063304245472, 53.0716647952795, 51.012806072831154, 47.24352613091469, 43.78705680370331, 43.11940222978592, 42.104457691311836, 40.94939187169075, 41.21800325810909, 41.745525151491165, 42.7953290194273, 46.459461003541946, 50.21834470331669, 50.821493938565254, 54.01826240122318, 55.51767334342003, 48.34730230271816, 51.09740473330021, 56.116175428032875, 47.93000489473343, 44.43483464419842, 42.50474341213703, 41.803734228014946, 40.154390931129456, 40.81695757806301, 39.86616499722004, 41.512510254979134, 39.7640834748745, 42.42748595774174, 47.446078062057495, 52.96278163790703, 52.05979809165001, 56.87689460813999, 53.589463010430336, 53.58363792300224, 52.98318274319172, 54.71417985856533, 54.22194667160511, 52.09722228348255, 52.06187278032303, 45.55280305445194, 40.569739043712616, 42.388921827077866, 41.62011668086052, 40.5771828442812, 41.41238182783127, 44.04897294938564, 49.152376502752304, 42.19715751707554, 40.49204461276531, 40.62687657773495, 42.007342502474785, 41.171220168471336, 40.1917315274477, 40.5119289457798, 42.01897747814655, 45.7224677503109, 53.33784431219101, 54.32524032890797, 53.835211023688316, 53.668791353702545, 57.358712553977966, 54.687121510505676, 54.34498026967049, 52.162867560982704, 52.29002773761749, 51.00869469344616, 46.243005618453026, 42.64487989246845, 42.73239679634571, 43.42734910547733, 39.801564663648605, 40.45120820403099, 41.77784621715546, 42.28077583014965, 40.31171768903732, 41.030578315258026, 43.12292084097862, 47.50865690410137, 47.798535749316216, 50.192889869213104, 49.9237997084856, 50.151130110025406, 47.583778873085976, 45.14109134674072, 43.55738192796707, 42.869440242648125, 41.840573251247406, 40.756643414497375, 40.059738010168076, 42.333748787641525, 40.97846791148186, 40.45437343418598, 40.83456963300705, 44.8783278465271, 48.39402839541435, 50.98907634615898, 52.22002409398556, 52.35707513988018, 52.689230516552925, 51.870393455028534, 59.481833428144455, 58.77953231334686, 54.83210653066635, 60.41177652776241, 62.81889796257019, 60.61050966382027, 57.2732475399971, 64.04939353466034, 52.15933755040169, 19.8695233091712, 2.6593849109485745, 1.432321979664266, 0.9416838164906949, 49.31748524308205, 60.685532838106155, 60.21845430135727, 59.802999794483185, 50.32126598060131, 48.88049729168415, 52.799227014184, 50.36442406475544, 24.098483584821224, 23.141748122870922, 60.626047030091286, 13.114045355468988, 0.7436627859715372, 0.058610066334949806, 0.10499460782739334, 0.05564756866078824, 0.0824817361717578, 0.038365520813385956, 0.029749407076451462, 0.05389742487750482, 0.04651371971704066, 0.22104991745436564, 0.16837926639709622, 0.10285118143656291, 0.21355219243559986, 0.14109244075370952, 0.07338194438489154, 0.1795945575577207, 0.11580640813917853, 0.20996306237066165, 0.33319744106847793, 0.31191876099910587, 0.3167781955562532, 2.091035870835185, 58.34181100130081, 73.44752043485641, 39.207561537623405, 40.70817321538925, 61.5961691737175, 66.40218928456306, 71.15769490599632, 66.66321247816086, 66.83750912547112, 70.96588119864464, 59.451374262571335, 65.81710427999496, 28.841700665652752, 0.3373998374445364, 12.813471034169197, 1.0460944357328117, 35.8838152885437, 35.4613995552063, 61.92433476448059, 64.42498818039894, 64.8176059126854, 61.71535737812519, 59.6922205388546, 61.86754301190376, 60.75394056737423, 60.56688420474529, 58.69507424533367, 61.42881855368614, 59.24054637551308, 57.918988689780235, 53.4505994617939, 49.96532768011093, 45.07543466985226, 45.320297330617905, 43.266796320676804, 42.37278789281845, 45.686491280794144, 44.02925580739975, 45.96808277070522, 49.92166802287102, 52.80387796461582, 53.21614444255829, 55.484406128525734, 57.702457308769226, 50.705353170633316, 52.92788431048393, 59.9202349036932, 50.2775227278471, 47.702157720923424, 45.376963689923286, 45.10782033205032, 42.49886132776737, 44.01258610188961, 41.938364803791046, 42.374239414930344, 42.99406975507736, 46.119736433029175, 50.414129197597504, 56.72184392809868, 56.35598435997963, 60.2562964707613, 56.75315424799919, 55.33727042376995, 56.3090530782938, 57.189283445477486, 56.46099932491779, 54.530262127518654, 54.80774603784084, 46.54285132884979, 40.777215510606766, 40.965396612882614, 42.56435461342335, 40.66267445683479, 42.36875630915165, 44.680666252970695, 53.06603729724884, 43.85786980390549, 40.484828799963, 41.981325298547745, 42.56081320345402, 42.4637246131897, 41.224470511078835, 41.49370886385441, 43.08968022465706, 47.27108985185623, 55.09295113384724, 57.94051453471184, 56.98457323014736, 57.90884703397751, 60.259621292352676, 59.03377287089825, 57.16874174773693, 55.25028169155121, 55.18356867134571, 53.80774229764938, 48.26833873987198, 43.29261593520641, 45.6193944811821, 46.72940991818905, 42.27527752518654, 42.90700502693653, 43.59723798930645, 44.200884997844696, 42.41069845855236, 42.375766932964325, 44.92804437875748, 48.982407823204994, 48.70316460728645, 51.705425307154655, 52.22305253148079, 51.20982930064201, 49.40320484340191, 47.304064482450485, 45.75489521026611, 44.999362751841545, 44.38321441411972, 42.870948761701584, 43.171508833765984, 44.83697846531868, 42.68456116318703, 42.579770386219025, 42.78768762946129, 45.193505734205246, 50.0383597612381, 53.8934239000082, 53.761616572737694, 55.77140472829342, 54.828671514987946, 55.25635376572609, 63.5379371792078, 59.38362009823322, 57.31405355036259, 60.61872482299805, 66.30827352404594, 61.47916965186596, 60.34054175019264, 66.84849053621292, 57.4065063893795, 25.07036503404379, 4.229847053065896, 2.3992408951744437, 0.6156385713256896, 53.49300138652325, 64.21714693307877, 67.91208386421204, 65.92211544513702, 59.221585392951965, 57.47609965503216, 62.637047320604324, 51.69496066868305, 34.933550879359245, 36.8669593334198, 70.72033077478409, 18.012268468737602, 0.7289340638089925, 0.15926064632367343, 0.20169960422208533, 0.16709860152332112, 0.2931849053129554, 0.12055297687766142, 0.1677509196451865, 0.13090497959638014, 0.13328982662642375], [0.052124085268587805, 0.026712551771197468, 0.01770395323546836, 0.015213979131658562, 0.032092781038954854, 0.03799137819441967, 0.07125543896108866, 0.02956267344416119, 0.01424362289981218, 0.04960716192726977, 0.05890378241019789, 0.48107274051290005, 0.12215936294523999, 18.934953957796097, 56.14318057894707, 29.652949534356594, 23.191417157649994, 37.80545577406883, 58.7190243601799, 51.3951263576746, 56.071353033185005, 49.11417715251446, 57.16012381017208, 48.449452221393585, 57.84095987677574, 33.60652908682823, 0.3725258057238534, 3.1178571470081806, 0.23651477589737624, 3.9161195000633597, 22.572475969791412, 63.51397566497326, 61.056529730558395, 59.58939805626869, 51.883111372590065, 46.632040143013, 45.27488976716995, 48.10946546494961, 46.49258382618427, 47.1469771116972, 46.262452974915504, 45.71044899523258, 45.26687979698181, 41.95652022957802, 39.80626121163368, 40.551978796720505, 39.134730845689774, 41.92238666117191, 40.76040521264076, 40.275927409529686, 41.28876306116581, 40.06242826581001, 40.66101394593716, 44.09696817398071, 47.2626581043005, 50.87695576250553, 56.6261650621891, 46.34346462786198, 43.506464660167694, 57.66043536365032, 48.79912085831165, 45.41122265160084, 39.33139689266682, 40.14305993914604, 38.86858552694321, 39.0155578404665, 37.703362852334976, 36.90806932747364, 37.71928779780865, 40.90603619813919, 47.83850580453873, 51.14719346165657, 49.90878291428089, 51.423909813165665, 49.9883658438921, 51.79870270192623, 53.119310438632965, 51.64438918232918, 51.71967454254627, 49.79882441461086, 45.93990348279476, 40.56091211736202, 40.39185918867588, 40.6501617282629, 40.252019092440605, 42.806876599788666, 41.48932009935379, 43.50744120776653, 50.30525743961334, 43.28621707856655, 42.58947126567364, 41.10725440084934, 40.019965544342995, 41.71247072517872, 40.590052753686905, 40.310570150613785, 39.704441875219345, 47.02750012278557, 51.117399260401726, 52.89942383766174, 51.45907312631607, 52.13033750653267, 52.57839046418667, 53.09750720858574, 52.812533900141716, 54.2686727643013, 48.79771873354912, 49.511214047670364, 45.6103889644146, 40.69192908704281, 39.865329042077065, 38.655337169766426, 37.38058157265186, 37.99603454768658, 38.8408812135458, 39.11569766700268, 38.908141404390335, 39.025167524814606, 41.72609679400921, 44.563742727041245, 46.36091709136963, 46.663669645786285, 46.292843744158745, 43.79180274903774, 41.0205240547657, 40.189565643668175, 39.74722757935524, 41.01026840507984, 38.98163326084614, 38.51094111800194, 38.26167829334736, 40.09876191616058, 39.74229544401169, 37.79217928647995, 42.99213945865631, 45.66985957324505, 48.99830996990204, 53.52816089987755, 53.43474291265011, 53.65616463124752, 54.1189493983984, 52.30352461338043, 53.41771602630615, 55.49580171704292, 55.69252096116543, 57.431395053863525, 57.821436524391174, 58.943713903427124, 57.287021800875664, 57.953726425766945, 26.12838976085186, 0.5640053388196975, 0.6793099141214043, 0.6002718990202993, 1.8851081770844758, 42.504093647003174, 54.43338252604008, 50.50518371164799, 51.506961956620216, 51.736948415637016, 57.88664862513542, 51.432493552565575, 33.976944610476494, 34.89187851548195, 33.66248868405819, 39.396267011761665, 2.7334080263972282, 0.34052027156576514, 0.02646856701176148, 0.07598332042107359, 0.0217149794116267, 0.03286648483481258, 0.058491968375165015, 0.0443869879381964, 0.03684201779833529, 0.020530500587483402, 0.02048218491836451, 0.07926026606583036, 0.06966880886466242, 0.036186066863592714, 0.11712734936736524, 0.07205640184110962, 0.015150701765378471, 0.018557838666311, 0.027109355869470164, 0.09275441814679652, 0.04880859618424438, 0.23134078946895897, 0.25416865828447044, 26.3020708411932, 66.71406894922256, 25.11667314916849, 28.787868954241276, 49.562572091817856, 59.78057339787483, 59.87492233514786, 63.336319997906685, 58.26572008430958, 63.193310871720314, 54.36708368360996, 63.874352127313614, 36.82736925780773, 0.5676666204817593, 6.091395188122988, 1.313578113913536, 5.000294661149383, 25.25317892432213, 63.57447221875191, 63.14386032521725, 61.03186525404453, 55.60544863343239, 50.6646953523159, 47.39042244851589, 50.52672475576401, 48.47418129444122, 49.74967785179615, 48.12620356678963, 49.21481475234032, 47.180985286831856, 45.29926925897598, 43.35137978196144, 43.35615612566471, 40.96164621412754, 43.20206679403782, 42.763965502381325, 42.55140110850334, 43.33414390683174, 41.87290571630001, 42.23309598863125, 47.7313781529665, 49.84414838254452, 53.21280062198639, 57.07728065550327, 49.11509670317173, 44.87531840801239, 57.48007424175739, 50.21798372268677, 47.68379710614681, 41.86082236468792, 41.27284571528435, 39.81098435819149, 40.88385298848152, 39.72723685204983, 39.66740906238556, 40.26667110621929, 42.310562431812286, 50.52949100732803, 53.732726722955704, 52.725837752223015, 52.03962117433548, 52.963663190603256, 53.92496980726719, 53.9880046248436, 53.79827320575714, 52.54837207496166, 51.50777891278267, 46.70427046716213, 40.715765208005905, 39.93019916117191, 40.740289092063904, 43.28961789608002, 42.667598873376846, 41.65827043354511, 45.09817644953728, 51.81441865861416, 44.637223184108734, 40.72383217513561, 41.11871838569641, 40.45346528291702, 40.71093946695328, 39.81102615594864, 41.110172644257545, 40.74758090078831, 45.40831200778484, 52.65697404742241, 54.130367785692215, 53.90339836478233, 54.6747911721468, 54.81298975646496, 54.646809473633766, 55.17400838434696, 53.95521618425846, 52.59422041475773, 50.722057074308395, 46.47586852312088, 42.42337837815285, 40.69695241749287, 39.82618734240532, 39.634605422616005, 38.29997643828392, 39.8426328599453, 41.06607601046562, 40.55100604891777, 39.87245365977287, 42.966160252690315, 47.01983593404293, 49.42658878862858, 47.110350877046585, 47.83279471099377, 46.84906929731369, 43.367411121726036, 40.95253810286522, 41.51743859052658, 41.153091341257095, 40.74653975665569, 40.41215389966965, 41.36074639856815, 42.23930485546589, 41.36770382523537, 40.110279098153114, 44.40117985010147, 47.31475330889225, 52.58505530655384, 54.473306983709335, 55.32444231212139, 54.629417806863785, 54.75066550076008, 55.385774821043015, 55.179472491145134, 58.80853235721588, 56.80060230195522, 59.22001227736473, 61.08063943684101, 60.184491723775864, 60.95772363245487, 58.945651799440384, 27.160085700452328, 0.4210633324692026, 0.8035985729657114, 0.7814442773815244, 2.704471154138446, 46.56705603003502, 59.62209150195122, 59.00039166212082, 56.56600669026375, 56.750053614377975, 61.521081402897835, 56.45880304276943, 45.92217743396759, 34.06264141201973, 35.554935336112976, 49.288329407572746, 4.232663651928306, 0.3723905567312613, 0.04254555627994705, 0.03655003092717379, 0.038441260694526136, 0.03914693552360404, 0.06544229268911295, 0.07028575622825883, 0.02235555490187835, 0.014484438688668888, 0.10970588002237491, 0.15903286635875702, 0.1502541350782849, 0.13446814933558926, 0.13412878004601225, 0.17381674493663013, 0.1989863716880791, 0.12767495994921774, 0.24275447154650465, 0.18623280135216191, 0.1551241081324406, 0.5692150967661291, 0.3898974641924724, 30.925738736987114, 79.5241467654705, 38.80621187388897, 33.019449189305305, 52.15102359652519, 66.19831502437592, 63.37173029780388, 68.03031831979752, 59.611653462052345, 69.79736790060997, 59.084021374583244, 67.79292225837708, 41.62663713097572, 0.6239994883071631, 12.005631532520056, 0.9795487846713513, 5.586215145885944, 29.49857521802187, 62.5242655724287, 65.20719900727272, 64.05250936746597, 57.31838531792164, 50.5859749764204, 49.40701223909855, 53.4515418112278, 51.613113060593605, 51.50957241654396, 49.75544974207878, 50.722836032509804, 49.99597303569317, 46.357869654893875, 46.38246953487396, 43.323033303022385, 43.18359978497028, 46.159140318632126, 45.618987902998924, 45.2973959594965, 46.0911163687706, 44.98922489583492, 44.05174300074577, 48.340246081352234, 51.83163933455944, 55.67808173596859, 60.15054054558277, 50.72532869875431, 48.140411004424095, 62.45529927313328, 52.01361916959286, 52.75276690721512, 43.700839430093765, 42.734304293990135, 41.85936324298382, 43.20269376039505, 41.81718550622463, 41.55418261885643, 42.04499468207359, 44.696142822504044, 54.693904146552086, 58.24514038860798, 55.554801151156425, 55.70241563022137, 54.76967968046665, 57.138578966259956, 58.95300820469856, 57.35099516808987, 55.67854531109333, 53.73103201389313, 47.78672978281975, 41.67607247829437, 39.12708945572376, 40.538284331560135, 43.109271973371506, 43.42268295586109, 42.135087847709656, 48.415254056453705, 56.74583964049816, 46.49607963860035, 41.84433504939079, 41.59128002822399, 41.90438322722912, 40.78235283493996, 40.87449409067631, 42.23368115723133, 40.68956941366196, 46.82427942752838, 54.577778577804565, 57.53695338964462, 53.99628818035126, 58.373619094491005, 56.65522590279579, 57.72676840424538, 57.44462974369526, 58.584595173597336, 52.97451160848141, 53.501892909407616, 49.05162110924721, 44.42459799349308, 44.6448265761137, 42.39693179726601, 42.688554748892784, 41.967923417687416, 41.437992453575134, 42.45350696146488, 41.19954004883766, 42.6976552605629, 46.06167554855347, 49.688797518610954, 49.60851922631264, 51.35015957057476, 50.174711644649506, 47.554501444101334, 44.45431239902973, 43.79941754043102, 43.514698818325996, 44.037964940071106, 42.55536809563637, 43.044056072831154, 42.90892772376537, 44.43883202970028, 42.90949389338493, 41.26896612346172, 46.077376306056976, 50.20713530480862, 54.43815127015114, 57.22156271338463, 57.83872939646244, 56.52580864727497, 57.19467155635357, 58.620978221297264, 58.494589403271675, 60.583059936761856, 59.45964641869068, 61.00180886685848, 63.74355934560299, 63.13947916030884, 62.43693485856056, 59.91736225783825, 32.57998377084732, 2.1744732186198235, 2.49444383662194, 1.8529551336541772, 2.4600972421467304, 58.57162646949291, 63.630139231681824, 62.02991209924221, 61.30206495523453, 65.48580005764961, 67.01195016503334, 61.83512695133686, 46.43674202263355, 47.480918392539024, 44.713105112314224, 59.09502558410168, 5.882163690403104, 0.5687778233550489, 0.11391711537726223, 0.23989843495655805, 0.12277354209800251, 0.08161749778082594, 0.1370626679272391, 0.18796273274347186, 0.1677485744585283, 0.08734996517887339], [0.03764591216167901, 0.02323785902262898, 0.0495454523479566, 0.04313498851843178, 0.04395278330775909, 0.05042806631536223, 0.0538187720667338, 0.08299348410218954, 0.0295726089461823, 0.07227883834275417, 0.04022440036351327, 0.18020310380961746, 0.10202315243077464, 7.644584644585848, 48.24078641831875, 44.680734649300575, 38.72558020055294, 28.128176853060722, 51.60575285553932, 52.73075848817825, 54.46536161005497, 45.10465510189533, 54.25391435623169, 53.008869364857674, 55.453597381711006, 46.684781312942505, 1.2501289998181164, 2.1730725187808275, 0.8191491791512817, 0.18947518517961726, 18.546863682568073, 69.29707154631615, 61.61493256688118, 59.44752886891365, 55.610118582844734, 51.33711487054825, 45.7054028660059, 43.27621601521969, 43.47376361489296, 40.57329945266247, 41.504887863993645, 39.752463698387146, 42.36882470548153, 41.09217680990696, 40.88240906596184, 38.33255589008331, 41.5292027592659, 42.03585237264633, 43.742515593767166, 41.557127460837364, 39.8647590726614, 38.95451791584492, 41.14095479249954, 40.842112228274345, 44.346052408218384, 50.161598548293114, 53.62606644630432, 53.64240936934948, 44.209879115223885, 56.62292763590813, 48.14732663333416, 46.73011288046837, 39.54722911119461, 40.12066014111042, 38.57301838696003, 39.02892932295799, 38.643227219581604, 36.82900317013264, 37.58045844733715, 41.252566203475, 48.165356665849686, 48.75149421393871, 48.807696998119354, 50.228786543011665, 50.13059601187706, 50.583790093660355, 50.10737545788288, 52.283024713397026, 51.224485114216805, 50.42614795267582, 43.34522031247616, 40.69665223360062, 40.689482018351555, 41.244012862443924, 40.19053839147091, 43.18119451403618, 40.87759852409363, 46.99486747384071, 49.96511489152908, 45.22800788283348, 41.188703030347824, 40.5354230850935, 42.10310876369476, 42.64684058725834, 40.913286209106445, 40.570878982543945, 41.56262956559658, 42.50919297337532, 47.76135854423046, 51.92191869020462, 52.731222063302994, 52.153751850128174, 51.03435471653938, 52.00311653316021, 50.690028592944145, 51.24885320663452, 50.44798918068409, 48.62906098365784, 50.34987464547157, 45.27549773454666, 39.47831600904465, 37.56277419626713, 38.326692804694176, 37.53201864659786, 38.72885562479496, 37.128601893782616, 40.173735693097115, 38.666166588664055, 41.94472946226597, 43.38049001991749, 46.35854221880436, 45.644963309168816, 45.40958873927593, 40.89032784104347, 41.69129826128483, 41.12614318728447, 40.596527606248856, 38.11783321201801, 40.20992115139961, 39.49125051498413, 40.23579016327858, 37.63117432594299, 40.52726872265339, 40.013312101364136, 43.92143279314041, 46.707599088549614, 51.21843583881855, 51.777712628245354, 55.68365603685379, 53.70668292045593, 56.037823632359505, 52.884179055690765, 56.09154134988785, 52.10628479719162, 58.21162238717079, 51.41420893371105, 56.9307567179203, 54.78319555521011, 59.44052204489708, 40.09592726826668, 9.150808621197939, 1.117487142328173, 0.5776458350010216, 1.3346030982211232, 8.041851427406073, 62.87796959280968, 47.64807142317295, 46.0880271345377, 53.39176341891289, 59.09596033394337, 53.843141198158264, 43.68940584361553, 28.472016602754593, 23.35398193448782, 42.61432573199272, 25.722442343831062, 0.5238147766795009, 0.07644930752576329, 0.038939720470807515, 0.03997801475634333, 0.04188157159660477, 0.028349046770017594, 0.0418142179842107, 0.08719058896531351, 0.03142582776490599, 0.01883365970570594, 0.036611933464882895, 0.0514202472550096, 0.09043030848260969, 0.04024771864351351, 0.07112053877790459, 0.023933679985930212, 0.07904559242888354, 0.0501458461076254, 0.0768468166643288, 0.02551652698457474, 0.09152307640761137, 0.20286216371459886, 0.13582206418504938, 10.067206397652626, 62.95314475893974, 36.92388027906418, 30.695666782557964, 44.93889659643173, 53.545275181531906, 53.721460327506065, 56.429856196045876, 53.49460110068321, 60.741674825549126, 59.14476491510868, 59.61695417761803, 47.71826885640621, 1.791230058297515, 3.671771236695349, 4.26363056525588, 0.475646928534843, 19.627159014344215, 69.3993392586708, 60.58159701526165, 63.08080270886421, 57.592153027653694, 52.454406917095184, 48.729869574308395, 44.412115663290024, 43.87603282928467, 43.169426545500755, 43.00352364778519, 42.67934404313564, 44.25141088664532, 41.6733518242836, 42.32896104454994, 41.358063742518425, 43.044812232255936, 42.954301089048386, 45.73092609643936, 42.53252372145653, 42.527857571840286, 41.48402698338032, 42.139571607112885, 42.61561766266823, 45.87617330253124, 52.47663952410221, 54.95722621679306, 55.407616049051285, 47.41570249199867, 57.66049616038799, 51.545419692993164, 50.40765054523945, 42.7514261752367, 42.496076077222824, 40.3727538138628, 40.392155572772026, 38.63852687180042, 40.97451612353325, 39.31866377592087, 43.52600701153278, 52.69353948533535, 51.99213892221451, 52.3114737868309, 54.3776661157608, 52.19157122075558, 53.13835121691227, 52.41856724023819, 52.913437485694885, 53.801381438970566, 50.62551945447922, 43.4966953843832, 39.93380516767502, 39.64681036770344, 41.66158005595207, 40.927923023700714, 42.160006910562515, 42.41059206426144, 47.29269169270992, 51.933413073420525, 47.06087753176689, 39.87874612212181, 40.6051379442215, 41.956242844462395, 42.08934970200062, 42.161317840218544, 40.49261458218098, 41.72347113490105, 43.05935025215149, 49.13038328289986, 53.02713878452778, 55.37128999829292, 54.25055913627148, 53.64240936934948, 55.71949951350689, 53.51082623004913, 54.59593400359154, 51.82386875152588, 51.68276712298393, 51.79603524506092, 47.15631701052189, 40.68873345851898, 39.02899011969566, 39.6751606464386, 38.28132323920727, 42.11868412792683, 39.8799392580986, 40.79115316271782, 41.587921008467674, 44.5893419533968, 47.443539798259735, 48.11893455684185, 46.59236267209053, 46.914657577872276, 43.909482434391975, 43.90253260731697, 39.59458217024803, 41.900161653757095, 41.19398854672909, 42.18664728105068, 41.36152155697346, 41.690412908792496, 40.79269967973232, 41.95051275193691, 41.59998156130314, 45.742257088422775, 47.94654160737991, 53.524102717638016, 54.45348344743252, 55.672032460570335, 56.013349145650864, 59.241796508431435, 56.44185595214367, 59.007007107138634, 54.78710934519768, 59.86874386668205, 52.41494603455067, 58.58127415180206, 56.677515506744385, 62.19476245343685, 41.06397472321987, 12.686365004628897, 1.2070895405486226, 1.4141645352356136, 1.1912016430869699, 8.690195437520742, 66.15228429436684, 54.55126740038395, 50.57577632367611, 58.13989743590355, 64.61538836359978, 57.98294685781002, 50.36851644515991, 39.35738369822502, 24.88533966243267, 45.96878953278065, 32.27142512798309, 0.706146745942533, 0.12330158016993664, 0.11210269789444283, 0.042559701614663936, 0.09319676042650826, 0.031337137406808324, 0.05412108592281584, 0.05694323233910836, 0.01894214870844735, 0.056587784420116805, 0.11202472785953432, 0.1435566382133402, 0.12748545996146277, 0.13067103980574757, 0.30184499686583877, 0.08396382734645158, 0.2323633650667034, 0.20684810529928654, 0.13482153037330136, 0.1267121420823969, 0.21032108925282955, 0.3358969883993268, 0.3075487876776606, 11.762921456247568, 74.19067695736885, 56.50908574461937, 46.904185339808464, 42.356790751218796, 60.27988560497761, 64.23266530036926, 65.60411810874939, 58.56318712234497, 68.05486500263214, 63.03944952785969, 65.58649465441704, 54.75661598145962, 2.4321428546682, 7.814214192330837, 3.206019541248679, 0.4881718580145389, 25.209030993282795, 70.20181059837341, 63.80037769675255, 64.93315011262894, 60.66647686064243, 54.62725952267647, 51.54557168483734, 47.93168820440769, 47.038610726594925, 44.663928151130676, 46.81355640292168, 44.46684792637825, 45.37863940000534, 44.332608729600906, 45.35043351352215, 41.81780107319355, 46.16213455796242, 45.903235450387, 48.5672003030777, 44.19450893998146, 45.02656169235706, 44.551712572574615, 45.26494190096855, 44.26285207271576, 47.70354464650154, 54.46167200803757, 57.46878124773502, 56.31838537752628, 47.6229015737772, 62.24669426679611, 53.335807621479034, 53.85117016732693, 45.306705459952354, 45.58711141347885, 44.14984233677387, 42.600505873560905, 42.19351351261139, 43.3025524020195, 43.472258895635605, 48.1078315526247, 54.257527962327, 53.978904113173485, 53.71126927435398, 57.196571454405785, 55.368934124708176, 55.29884688556194, 53.738954588770866, 57.7061203122139, 56.980442851781845, 52.0675078779459, 44.59134064614773, 40.133294463157654, 42.05908052623272, 43.06970089673996, 40.18834970891476, 44.34301637113094, 43.85717824101448, 51.2582653015852, 53.96522104740143, 50.76190173625946, 41.634244322776794, 42.73406870663166, 41.50061309337616, 44.742355942726135, 42.55301982164383, 41.644921749830246, 42.10307836532593, 42.94590353965759, 49.30522330105305, 55.45422814786434, 58.94724391400814, 56.603392884135246, 56.05104312300682, 60.7931886613369, 56.1202298104763, 57.84025691449642, 55.836301445961, 52.93429836630821, 54.961645379662514, 50.105004385113716, 43.109484761953354, 40.922880694270134, 41.61776080727577, 42.513612136244774, 43.772792369127274, 41.36559493839741, 43.53583708405495, 42.37441800534725, 46.93217843770981, 49.01187904179096, 50.68606540560722, 49.02450956404209, 48.47187481820583, 45.994761139154434, 45.80840393900871, 42.51272678375244, 44.183766916394234, 42.42079831659794, 44.008809104561806, 43.35289590060711, 44.817139729857445, 40.93223199248314, 43.9392576366663, 44.2810644954443, 48.4644690155983, 50.431855246424675, 55.11692024767399, 56.930578127503395, 58.61652486026287, 58.486305847764015, 61.91587641835213, 56.4600645750761, 61.23915933072567, 57.0268839597702, 61.861045360565186, 53.19587253034115, 59.48206141591072, 59.35389809310436, 62.42673620581627, 45.54224722087383, 17.30179399251938, 1.5842377091757953, 2.870573066174984, 2.6366618927568197, 10.062552597373724, 76.62940889596939, 57.477889358997345, 56.698053404688835, 61.44518807530403, 70.09566709399223, 61.97329893708229, 57.313536778092384, 41.02321811020374, 31.535121537745, 58.10793735086918, 46.06575272977352, 1.1116622923873365, 0.24798558850307018, 0.18502888939110562, 0.13690037507331, 0.1938161108409986, 0.2316550147952512, 0.19016753474716097, 0.22320288786431774, 0.14589798054657876, 0.09007923552417196], [0.014544151890731882, 0.0022283976613834966, 0.05421246285550296, 0.1084992518008221, 0.0461088076554006, 0.05383147392421961, 0.04719489625131246, 0.058089457161258906, 0.01265604470972903, 0.023386143839161377, 0.07070305102388375, 0.12389378432999365, 0.1980812186957337, 0.23247532546520233, 37.08787187933922, 52.418168261647224, 28.485298790037632, 18.922091647982597, 46.34864754974842, 63.77771571278572, 54.68390688300133, 49.13471505045891, 55.6840930134058, 54.65875223278999, 54.41100172698498, 57.58149079978466, 6.8758849427104, 3.137981817126274, 3.586861942894757, 0.1794803113443777, 14.124123305082321, 45.08923552930355, 59.28932435810566, 56.611357256770134, 57.182781994342804, 54.44923907518387, 54.10239368677139, 49.84601408243179, 48.54529827833176, 44.92498554289341, 42.61595584452152, 41.19602523744106, 41.676365062594414, 42.17073753476143, 41.595201417803764, 41.401875391602516, 42.36583426594734, 44.20671008527279, 45.739316046237946, 43.67012947797775, 39.82419244945049, 41.45740561187267, 39.43040817975998, 41.54491871595383, 41.80167093873024, 48.63835148513317, 53.30640099942684, 57.54161573946476, 45.12559577822685, 48.65726687014103, 53.434001952409744, 46.37568689882755, 42.59727984666824, 40.2544129639864, 38.744757771492004, 38.49811680614948, 38.94609376788139, 38.01139332354069, 36.05161428451538, 39.10564720630646, 50.180525332689285, 51.46243214607239, 50.438029915094376, 50.00424139201641, 49.372407495975494, 52.64425612986088, 51.198296919465065, 50.794241800904274, 47.93150581419468, 45.24304747581482, 43.640289679169655, 39.72809560596943, 40.97249083220959, 42.13986799120903, 43.652080446481705, 38.76872308552265, 40.949129685759544, 50.24161845445633, 51.05219475924969, 46.482483968138695, 42.29550004005432, 41.434853821992874, 43.11639279127121, 41.36358864605427, 41.030327528715134, 39.213333427906036, 41.58205792307854, 41.95217326283455, 44.73937310278416, 50.21027773618698, 50.99959038197994, 52.098039239645004, 49.798235446214676, 51.23017340898514, 53.20552781224251, 50.99433906376362, 50.52579380571842, 50.07387265563011, 49.26340654492378, 47.71019048988819, 40.928644984960556, 34.92198809981346, 39.21766899526119, 39.45250779390335, 38.96450378000736, 37.23039463162422, 39.79093663394451, 37.518198788166046, 39.23924043774605, 43.16093020141125, 46.3349074870348, 46.675775796175, 47.76966489851475, 43.53498212993145, 42.184215411543846, 39.600931629538536, 38.75069685280323, 38.74979630112648, 39.639947935938835, 39.74944666028023, 41.395461335778236, 38.21125119924545, 40.92633470892906, 39.53541934490204, 43.7880789488554, 44.5933773368597, 46.687893345952034, 48.6382906883955, 52.53265991806984, 50.94399556517601, 55.10804012417793, 54.055215418338776, 57.52206578850746, 53.80446307361126, 58.921994268894196, 52.050549387931824, 54.07645247876644, 48.929833844304085, 58.82688917219639, 21.03310827165842, 12.92368981987238, 0.2764357900014147, 0.5778631952125579, 0.7611287268809974, 14.707657992839813, 62.662817537784576, 49.17216584086418, 59.005061611533165, 53.46765294671059, 59.46913070976734, 51.371396631002426, 42.34254151582718, 24.078253470361233, 25.208060145378113, 45.11514633893967, 7.757422914728522, 0.441514725680463, 0.04304229427361861, 0.18633940344443545, 0.02295513972057961, 0.03789142574532889, 0.01941161091963295, 0.044927516355528496, 0.018658177032193635, 0.015671489054511767, 0.04652629912015982, 0.026312031368433964, 0.046454603943857364, 0.047231272619683295, 0.03633967287896667, 0.06329783471301198, 0.0981562513334211, 0.069326433876995, 0.023285202478291467, 0.015447005152964266, 0.03863889833155554, 0.047261095824069344, 0.15986007900210097, 0.18937428278150037, 1.511999072972685, 43.360069915652275, 57.9295901209116, 27.04424511641264, 30.701427273452282, 54.1707444190979, 66.65758118033409, 60.12726679444313, 50.37497229874134, 61.91917084157467, 59.46200989186764, 60.73775723576546, 60.45237734913826, 7.352927969768643, 3.5540951136499643, 4.819849468767643, 0.11046773914131336, 17.520666047930717, 45.61609245836735, 60.026708990335464, 60.84473669528961, 58.7793043255806, 57.89007604122162, 55.45010156929493, 51.98736257851124, 51.55107378959656, 47.329515516757965, 44.60476152598858, 43.340766951441765, 43.781258314847946, 43.55550102889538, 42.41726450622082, 43.00098918378353, 43.950402438640594, 46.18123613297939, 46.86880923807621, 47.69092172384262, 41.35895289480686, 43.80882203578949, 42.84316085278988, 43.78699600696564, 45.270896181464195, 50.81625781953335, 54.38208907842636, 58.22261139750481, 47.14312791824341, 52.0559298992157, 55.67693039774895, 47.80378706753254, 45.7641439139843, 41.60010315477848, 41.79211065173149, 42.43377082049847, 40.81321477890015, 40.156192034482956, 38.92846651375294, 41.75552241504192, 52.0001070946455, 54.32326443493366, 52.96930968761444, 53.29815924167633, 52.69078843295574, 55.51057532429695, 54.20503377914429, 54.219617396593094, 49.184336587786674, 46.15470975637436, 43.00549194216728, 39.85834501683712, 40.7120756059885, 41.387451365590096, 42.616541013121605, 40.701040998101234, 42.56977692246437, 50.355809926986694, 53.50600428879261, 47.79678024351597, 42.5446754693985, 41.36337585747242, 43.75068515539169, 41.62814185023308, 41.008771285414696, 40.66633366048336, 41.51273064315319, 41.5165988355875, 44.51272286474705, 49.819886684417725, 53.48551958799362, 55.618128553032875, 53.02577845752239, 51.90711088478565, 53.76021444797516, 52.86058992147446, 53.26948218047619, 52.689538300037384, 50.815148279070854, 50.481719970703125, 41.60472370684147, 38.02468501031399, 40.84668718278408, 39.558491706848145, 41.91738612949848, 40.20130321383476, 41.81777827441692, 40.05030691623688, 41.55794821679592, 44.41856771707535, 48.13125729560852, 48.75497482717037, 48.92501190304756, 45.83121031522751, 43.9593281596899, 42.116685435175896, 40.82632787525654, 40.886075869202614, 42.47005507349968, 42.0312812179327, 42.975370958447456, 40.23871600627899, 41.942179799079895, 40.886832028627396, 46.75377421081066, 46.00827321410179, 49.206770583987236, 49.535661935806274, 54.0325952321291, 53.03990609943867, 56.53041020035744, 56.38738587498665, 59.32970479130745, 55.33797338604927, 59.514238089323044, 51.83627888560295, 56.054124757647514, 49.26809549331665, 61.651072427630424, 23.69579829275608, 14.915533438324928, 0.4198710870696232, 0.6338985508773476, 0.4329046845668927, 17.206022031605244, 68.46896678209305, 52.270333394408226, 64.7025328874588, 56.62194348871708, 67.72750496864319, 53.84138949215412, 55.53029626607895, 29.156369380652905, 22.89356444031, 54.38300862908363, 11.72113224864006, 0.37685938412323594, 0.048193756520049646, 0.10232645334326662, 0.013123870485287625, 0.11884221516083926, 0.06513952612294815, 0.0689866860921029, 0.013826076701661805, 0.059579032895271666, 0.05088067991891876, 0.10169322325964458, 0.11516284735989757, 0.14230827160645276, 0.19422760204179212, 0.14937869767891243, 0.2908780431607738, 0.20914858498144895, 0.10326646501198411, 0.10470255787367932, 0.16670603508828208, 0.15993531793355942, 0.2814191929064691, 0.3318164823576808, 1.8512490252032876, 52.5760155916214, 68.67127552628517, 35.55506072938442, 28.125990070402622, 58.202024102211, 73.72494354844093, 66.27222865819931, 57.702525705099106, 68.98954644799232, 63.31616587936878, 67.37128928303719, 64.65996757149696, 9.150769673287868, 6.273703230544925, 10.686948392540216, 0.3562451043399051, 22.100317105650902, 50.20213097333908, 60.034289583563805, 61.89720422029495, 62.646858394145966, 59.47615273296833, 58.06137464940548, 56.165698170661926, 52.98766650259495, 50.60882315039635, 47.02569901943207, 45.67420653998852, 45.24262569844723, 46.03633850812912, 46.354438439011574, 45.50280913710594, 44.76905710995197, 49.49944607913494, 50.12733578681946, 48.79782892763615, 44.77615512907505, 46.22401423752308, 43.71187023818493, 46.44016183912754, 45.89240603148937, 52.06217676401138, 57.72624783217907, 61.31777711212635, 47.6901313662529, 55.626035928726196, 58.097909688949585, 50.36163881421089, 47.97272980213165, 44.92699943482876, 42.88672171533108, 44.01601731777191, 43.36236499249935, 42.465882897377014, 42.08180710673332, 45.391410514712334, 54.439579993486404, 55.89415334165096, 54.492678344249725, 54.16801616549492, 53.7894082814455, 58.96475337445736, 57.41159051656723, 56.6397987306118, 50.218701884150505, 46.21901750564575, 45.64753197133541, 39.956201165914536, 40.468311086297035, 41.7396354675293, 43.986074924468994, 43.01824405789375, 44.55291710793972, 50.40390394628048, 56.662741899490356, 48.85976940393448, 43.9964559674263, 40.74890322983265, 43.67680571973324, 42.0609500259161, 41.12661816179752, 39.40097115933895, 41.80509455502033, 42.1031391620636, 44.87459644675255, 50.896938890218735, 54.83500577509403, 57.743479907512665, 53.048463240265846, 54.98654544353485, 57.3100371658802, 55.07518708705902, 56.25129617750645, 55.33913232386112, 54.32848535478115, 52.964742332696915, 44.33319389820099, 39.66207414865494, 43.577091470360756, 43.733434081077576, 45.34145459532738, 40.49732252955437, 43.90014633536339, 41.621347814798355, 41.952769830822945, 46.18036977946758, 49.585614055395126, 51.84783786535263, 51.93095840513706, 46.56828336417675, 45.65910995006561, 45.538192838430405, 43.98679308593273, 42.07704596221447, 44.23068679869175, 43.96020211279392, 44.287030175328255, 42.155667543411255, 44.13935869932175, 44.270094484090805, 48.95048573613167, 49.64150905609131, 51.55210733413696, 52.46249668300152, 56.79855041205883, 55.49891754984856, 61.09232001006603, 58.06453227996826, 60.892545729875565, 57.603989392519, 61.24962776899338, 53.03792640566826, 54.14601534605026, 50.06581708788872, 61.081319600343704, 27.440423257648945, 19.335095286369324, 0.6810605514328927, 3.012450565584004, 1.624539652839303, 19.165687076747417, 72.71145433187485, 59.428434893488884, 69.22574177384377, 62.80489571392536, 70.62671899795532, 60.75257644057274, 56.341187953948975, 35.21211013197899, 34.11710388958454, 63.9593231678009, 16.90521877259016, 0.6043342966586351, 0.11413785978220403, 0.34341384598519653, 0.12706632463959977, 0.15340867830673233, 0.13551724929129705, 0.17538355226861313, 0.10836447036126629, 0.16958954598521814, 0.17329917114693671], [0.01471282628699555, 0.04426097126270179, 0.028915696930198465, 0.008690291397215333, 0.02774910200969316, 0.02540612138545839, 0.03096903772529913, 0.06803567579481751, 0.06244587144465186, 0.02490478022082243, 0.01487981415266404, 0.05822817198350094, 0.14548424805980176, 0.07445432551321574, 17.111063227057457, 50.404473915696144, 42.41659954190254, 36.70842044055462, 35.034310072660446, 59.35175500810146, 60.65532825887203, 52.07057811319828, 51.07839435338974, 55.9420345723629, 52.14979246258736, 57.39529699087143, 12.652507871389389, 2.0651072496548295, 7.469656756147742, 0.2803691430017352, 8.613113723695278, 49.26035910844803, 56.64242438971996, 63.36275517940521, 60.642724335193634, 60.72622485458851, 54.8655067384243, 56.4572337269783, 53.47914732992649, 51.9069816917181, 49.94418941438198, 44.55020785331726, 44.32611107826233, 44.19255204498768, 44.4779547303915, 43.759683072566986, 45.78900597989559, 46.74914225935936, 48.06345373392105, 44.11174178123474, 42.238799482584, 40.29836140573025, 38.93749862909317, 40.51168575882912, 40.12564927339554, 47.22459934651852, 51.158148273825645, 53.48660632967949, 58.026701509952545, 50.777838081121445, 51.30102440714836, 47.57999047636986, 41.027679070830345, 42.41212718188763, 41.251954436302185, 37.019388154149055, 37.095182687044144, 38.93267288804054, 39.11273382604122, 40.3092136234045, 47.47977465391159, 49.035874754190445, 49.829131588339806, 50.02347216010094, 50.39402447640896, 51.242047771811485, 50.94407916069031, 50.2287295460701, 44.788018092513084, 43.54050323367119, 41.56334012746811, 42.89212502539158, 42.94141598045826, 39.96269881725311, 39.27650883793831, 42.13527403771877, 46.78448796272278, 49.01274539530277, 49.21281225979328, 46.3926187902689, 44.33353967964649, 40.40141947567463, 40.90788669884205, 41.364941373467445, 41.58773481845856, 42.10687056183815, 41.41876928508282, 40.308305472135544, 41.611529141664505, 44.70582850277424, 49.12379443645477, 52.69578516483307, 49.91803541779518, 51.435187608003616, 50.56145869195461, 51.27371147274971, 48.93191233277321, 47.91588485240936, 50.105414763092995, 49.69586133956909, 40.966167971491814, 37.39598974585533, 36.814955323934555, 36.17134585976601, 35.86668200790882, 38.56935158371925, 41.01927012205124, 38.70171748101711, 43.1391915678978, 43.10491740703583, 44.41027656197548, 45.25205299258232, 45.855988785624504, 44.19409476220608, 44.30116921663284, 40.909839794039726, 37.653669118881226, 38.195740431547165, 39.576533138751984, 39.47110779583454, 41.077319607138634, 40.58878742158413, 39.43830795586109, 39.89095866680145, 41.56580239534378, 40.84414131939411, 44.052335768938065, 42.451572865247726, 43.21730777621269, 46.21351160109043, 48.75878602266312, 49.87725220620632, 49.583280980587006, 50.820217207074165, 56.563020050525665, 53.15283223986626, 54.042858481407166, 49.2180597782135, 48.09292875230312, 7.483686078339815, 3.140551191754639, 0.13264939771033823, 0.7546692516189069, 0.7739611133001745, 20.93225598335266, 60.24116948246956, 50.15228904783726, 53.90580363571644, 52.19006270170212, 58.73417414724827, 47.258607521653175, 34.14384685456753, 24.62443806231022, 32.856289744377136, 37.65280656516552, 1.33806198136881, 0.2269676694413647, 0.12342271351371892, 0.04271516670996789, 0.05828929897688795, 0.014866052879369818, 0.06863041067845188, 0.0845827636658214, 0.0469650902232388, 0.04030748750665225, 0.028437685177777894, 0.02328385362488916, 0.015714954788563773, 0.02205807057180209, 0.016687760107743088, 0.02974530856590718, 0.034584040913614444, 0.0529980754799908, 0.08967947767814621, 0.02751442378212232, 0.07332873981795274, 0.054938064349698834, 0.02721142715017777, 0.1630348531762138, 0.17067492211936042, 23.837042413651943, 60.953737646341324, 32.25705049932003, 29.923289828002453, 49.78022061288357, 62.72677190601826, 65.80385059118271, 56.608511209487915, 59.27583888173103, 59.62284006178379, 57.11951918900013, 60.37620663642883, 13.793641738593578, 3.112178589217365, 4.534251568838954, 0.5870273534674197, 11.033017672598362, 51.72317415475845, 57.62247160077095, 64.36831042170525, 62.26583383977413, 60.820961371064186, 58.34417447447777, 58.00407752394676, 54.97370973229408, 54.473641365766525, 50.511586368083954, 46.812842041254044, 44.73423197865486, 45.73251821100712, 45.371586978435516, 45.352549999952316, 49.950599670410156, 47.59532265365124, 50.33014230430126, 47.66345679759979, 44.13200989365578, 41.08027584850788, 42.74651683866978, 42.561994940042496, 42.35210940241814, 49.08461853861809, 52.910401448607445, 56.40632785856724, 59.170725122094154, 52.12611213326454, 53.47719803452492, 50.84770493209362, 42.91734807193279, 44.68258135020733, 43.5357116907835, 40.14833405613899, 39.0640964359045, 40.648432821035385, 39.755644127726555, 41.92498192191124, 49.6029981225729, 52.06651993095875, 51.71169877052307, 52.226685136556625, 52.95176222920418, 53.28767940402031, 54.88112770020962, 52.342586517333984, 46.91754162311554, 41.60833351314068, 41.72750271856785, 41.979850977659225, 42.95849606394768, 42.68709942698479, 40.12562647461891, 42.54474766552448, 47.46666915714741, 50.683580338954926, 51.645080745220184, 46.88165634870529, 44.52533058822155, 41.79600924253464, 41.55457399785519, 40.70652410387993, 41.83815278112888, 40.53356118500233, 41.06063090264797, 40.278062894940376, 41.30735546350479, 46.65217146277428, 50.56091532111168, 53.12075436115265, 52.28819243609905, 53.31484794616699, 52.43510015308857, 52.11902931332588, 51.529924124479294, 51.87513180077076, 52.81724564731121, 52.19689853489399, 41.645187735557556, 39.661249592900276, 38.360735177993774, 40.75255863368511, 38.21007326245308, 39.70475725829601, 42.85779766738415, 40.323630049824715, 44.3875727802515, 44.784681871533394, 46.8141795694828, 47.05966539680958, 47.731400951743126, 47.18758553266525, 45.782645121216774, 42.487811520695686, 39.97215270996094, 40.744415670633316, 41.83304205536842, 41.70429356396198, 42.03435905277729, 43.28089736402035, 41.444056928157806, 41.5140263736248, 43.88141714036465, 45.141000151634216, 46.056804209947586, 44.886976182460785, 45.54624080657959, 49.352169781923294, 50.35501956939697, 54.08352009952068, 52.0156292617321, 52.72210635244846, 59.648458287119865, 54.4184835255146, 53.63622710108757, 51.50364853441715, 49.334170147776604, 10.512645095586777, 5.455941986292601, 0.2894746419042349, 0.3342467488255352, 0.42557692620903254, 23.35577353835106, 66.59939870238304, 55.19902244210243, 61.68462082743645, 54.292763471603394, 65.90694665908813, 52.19926580786705, 48.290373757481575, 23.18791374564171, 32.80548267066479, 48.64476554095745, 2.6178856752812862, 0.12954229256138206, 0.13008383772103116, 0.05301533412421122, 0.05382734758313745, 0.05398349545430392, 0.07476000871974975, 0.03460274303506594, 0.0647498169564642, 0.054587147242273204, 0.03477504746115301, 0.07575662399176508, 0.06618379469728097, 0.20905915618641302, 0.1294653763761744, 0.11760279143345542, 0.14946637500543147, 0.08414113384787925, 0.17017184989526868, 0.10833999433089048, 0.16422806336777285, 0.08038883519475348, 0.11057174371671863, 0.30106013116892427, 0.3958587802480906, 28.683887533843517, 70.98481938242912, 51.2735328823328, 48.4913145750761, 50.4814387857914, 68.07762578129768, 73.78274604678154, 64.77134719491005, 64.16368380188942, 64.93587076663971, 62.358628660440445, 66.6934284567833, 15.68565521389246, 3.7803663220256567, 24.178017117083073, 1.1051462357863784, 12.87313163280487, 55.785619765520096, 57.16778799891472, 67.27345213294029, 64.67650428414345, 65.24502977728844, 58.67027297616005, 62.20626063644886, 57.358112186193466, 57.89671428501606, 53.43606524169445, 48.73382516205311, 48.6613592505455, 49.92410749197006, 49.672032818198204, 48.66673596203327, 52.41439886391163, 52.293990924954414, 53.66363883018494, 50.27796350419521, 46.189633682370186, 44.14218954741955, 45.45783855021, 43.67894120514393, 44.56843927502632, 50.85587449371815, 56.65598206222057, 58.25511485338211, 60.02384394407272, 54.73765879869461, 57.59977541863918, 52.81781941652298, 45.166519582271576, 48.45230966806412, 46.6049437969923, 41.94341093301773, 40.59249982237816, 44.377275332808495, 43.1867840141058, 45.57648718357086, 51.567724496126175, 56.38212315738201, 54.24036048352718, 54.71187338232994, 56.634657606482506, 55.77835075557232, 57.80417025089264, 54.76537451148033, 47.59495787322521, 43.42282734811306, 42.331613302230835, 41.824990287423134, 44.992219135165215, 44.07224290072918, 41.991485953330994, 45.24486377835274, 49.338030740618706, 53.30009713768959, 53.11752073466778, 48.70323680341244, 44.94706615805626, 43.58130544424057, 41.826149225234985, 42.91020065546036, 43.35012584924698, 41.37230917811394, 41.8213576823473, 41.02469243109226, 41.54962286353111, 48.23093734681606, 51.457002237439156, 54.6343195438385, 54.88390155136585, 55.89342378079891, 54.286839589476585, 54.33982014656067, 54.009731858968735, 53.84982883930206, 54.28536906838417, 53.2754934579134, 44.05953258275986, 41.82861149311066, 40.82115635275841, 41.98989383876324, 38.14587190747261, 41.83915592730045, 44.48568731546402, 41.559331342577934, 46.150161400437355, 47.365678176283836, 48.52297827601433, 48.627164885401726, 50.2807829529047, 49.87713821232319, 49.592643678188324, 45.80550469458103, 41.81538060307503, 43.177383318543434, 44.2413604259491, 43.214978501200676, 44.28077191114426, 45.28564319014549, 43.739057779312134, 44.76879112422466, 47.053498327732086, 45.666675344109535, 47.92104497551918, 47.17151619493961, 45.635581612586975, 51.53971999883652, 54.574666544795036, 56.78664565086365, 55.03085866570473, 54.41643163561821, 61.92496933043003, 56.831312254071236, 54.33565936982632, 50.78492850065231, 51.74599193036556, 15.936665944755077, 8.754452839493752, 0.8981899253558367, 1.1438577272929251, 1.5507162641733885, 26.15666214376688, 73.0449852347374, 60.17126463353634, 65.3738884627819, 62.00738310813904, 67.38034039735794, 59.873676002025604, 47.94298119843006, 34.14660930633545, 42.7831544727087, 62.594892382621765, 3.847135389223695, 0.38131612935103476, 0.18713825120357797, 0.19100871460977942, 0.09940469215507619, 0.13120458461344242, 0.1381021793349646, 0.21054311015177518, 0.13956182054243982, 0.15260318090440705, 0.11231792814214714], [0.01741580512316432, 0.010775750488392077, 0.06372191273840144, 0.061728348227916285, 0.05013916677853558, 0.031363680318463594, 0.02745100726315286, 0.02462508145981701, 0.044794052228098735, 0.024767204595264047, 0.08795431087492034, 0.04252433827787172, 0.13304822787176818, 0.2146489085862413, 2.6161263696849346, 49.380862042307854, 44.90458823740482, 29.803083278238773, 28.648769818246365, 47.98982888460159, 61.11482620239258, 53.258743956685066, 46.74096129834652, 57.79748260974884, 50.562644228339195, 59.2512010037899, 15.48135157674551, 1.4997400995343924, 0.42459280870389193, 0.9085355827119201, 0.7397890719585121, 36.25173434615135, 66.12902954220772, 55.23572087287903, 66.29626616835594, 56.89535401761532, 61.05247914791107, 55.22822007536888, 60.28473414480686, 58.242434933781624, 54.885398671031, 49.18258108198643, 51.806465685367584, 48.83522652089596, 47.33226656913757, 48.12547020614147, 51.18492163717747, 49.23893965780735, 47.85549469292164, 44.848233461380005, 44.306701719760895, 40.11763550341129, 42.364257350564, 41.885042265057564, 39.85390305519104, 39.17279340326786, 51.06049731373787, 50.13422481715679, 55.817382261157036, 55.48081152141094, 51.557613238692284, 49.233627542853355, 40.03204509615898, 41.25182144343853, 39.00850161910057, 38.553643226623535, 37.64900676906109, 38.7744265794754, 37.569340243935585, 38.17191570997238, 43.9820471405983, 49.23268519341946, 50.07669970393181, 51.27045884728432, 50.327991619706154, 51.074187979102135, 49.40493755042553, 44.31249640882015, 39.75166954100132, 41.43274873495102, 41.26743480563164, 40.20334370434284, 40.17382688820362, 35.43604351580143, 39.92976978421211, 42.50760845839977, 43.64046446979046, 44.138978719711304, 42.145138308405876, 42.79346711933613, 42.180955186486244, 42.62167073786259, 40.10309748351574, 38.65856699645519, 39.60232615470886, 40.676524713635445, 41.529696732759476, 42.20260642468929, 41.903307884931564, 43.91477935016155, 45.39817415177822, 50.26244133710861, 51.29568949341774, 49.83775332570076, 48.912426978349686, 51.4561852812767, 51.060425117611885, 49.09704007208347, 50.49273557960987, 48.40771146118641, 40.79900734126568, 35.65183773636818, 35.802963227033615, 36.388143226504326, 37.095038294792175, 38.51151488721371, 39.10231478512287, 42.026884853839874, 42.42096930742264, 42.03442744910717, 45.35541124641895, 46.545708775520325, 46.57322309911251, 44.13427837193012, 43.863801285624504, 41.42920732498169, 39.040267914533615, 39.99633461236954, 40.73202073574066, 38.571977242827415, 38.995384722948074, 39.35446925461292, 40.75029395520687, 36.94354422390461, 41.656883507966995, 40.78145228326321, 38.550177812576294, 40.50445854663849, 43.966061398386955, 44.50342856347561, 41.49047903716564, 42.541164457798004, 48.09329353272915, 49.70485545694828, 56.61915823817253, 55.60621999204159, 52.58685640990734, 50.44847175478935, 40.4890313744545, 1.0494849225506186, 1.5688258549198508, 0.7081027503591031, 0.4181938630063087, 0.4245476861251518, 31.818622425198555, 57.85526990890503, 51.395578533411026, 54.57807116210461, 55.457917749881744, 57.3555663228035, 36.35036565363407, 35.63260696828365, 30.797429122030735, 46.159645691514015, 19.75009761750698, 0.29835262801498175, 0.04244596006174106, 0.04034304009110201, 0.0690092399599962, 0.0668324317666702, 0.015175612879829714, 0.022167737733980175, 0.05397100139816757, 0.05672569401212968, 0.0750627827073913, 0.03865162616421003, 0.013481363021128345, 0.03842385362077039, 0.07729866585577838, 0.05476031998114195, 0.04901289830741007, 0.02180001469241688, 0.047737832937855273, 0.035502986720530316, 0.13451830367557704, 0.035023069503949955, 0.040886158603825606, 0.009974610420613317, 0.21356038574595004, 0.13536312006181106, 4.151785466820002, 58.67257185280323, 49.795275405049324, 32.743036821484566, 45.39989925920963, 56.11021734774113, 66.78061097860336, 58.82428251206875, 53.54650631546974, 62.04893387854099, 55.51766574382782, 61.85482509434223, 18.342474550008774, 1.507854089140892, 2.313088118098676, 0.3554246749263257, 1.1834008991718292, 38.773108050227165, 65.69864943623543, 57.815793827176094, 66.15210190415382, 59.97765742242336, 61.8656013160944, 58.35917986929417, 61.80035501718521, 61.27776525914669, 55.83170749247074, 50.925862938165665, 56.157285422086716, 50.198688358068466, 49.40724402666092, 50.03259167075157, 53.4528299421072, 53.02509069442749, 49.39603462815285, 48.25762331485748, 45.53487181663513, 43.193977028131485, 45.12271173298359, 43.21309380233288, 41.494332030415535, 43.831738606095314, 53.38382184505463, 52.99264043569565, 56.09388202428818, 55.77995806932449, 53.74230220913887, 52.54206821322441, 42.60446906089783, 44.105141535401344, 40.98765581846237, 40.35473518073559, 39.28556375205517, 42.28178657591343, 41.57388836145401, 41.463462486863136, 47.40250200033188, 52.80267342925072, 50.547011867165565, 52.519003450870514, 52.71646365523338, 52.82030448317528, 51.27073623239994, 46.71114429831505, 40.853051841259, 41.57386176288128, 41.556295305490494, 41.20403900742531, 40.590611323714256, 39.45633798837662, 42.4038702249527, 43.98855619132519, 44.71134960651398, 47.80205816030502, 44.597040340304375, 43.4957492351532, 43.029050678014755, 43.74591641128063, 40.47398418188095, 38.77784639596939, 40.84219582378864, 39.13103364408016, 40.00545032322407, 41.67932130396366, 41.51764377951622, 43.473417833447456, 45.33677324652672, 51.62662133574486, 52.853393107652664, 52.86174885928631, 51.58867657184601, 52.90820136666298, 52.81979151070118, 51.43818184733391, 53.606037721037865, 50.626701191067696, 42.0673792809248, 37.91971184313297, 39.13299433887005, 40.201588198542595, 38.98842729628086, 40.34493550658226, 39.919833317399025, 44.46696572005749, 42.52591207623482, 42.150024846196175, 48.243252485990524, 47.54196211695671, 49.675996005535126, 46.706915125250816, 44.744955003261566, 43.95202495157719, 41.13744378089905, 41.90187156200409, 41.98876529932022, 41.08540177345276, 40.53172968327999, 40.80713130533695, 42.632747143507004, 38.82391132414341, 44.09293659031391, 43.48355948925018, 39.66732166707516, 43.19218352437019, 46.81208208203316, 45.52656166255474, 42.683041244745255, 45.03103405237198, 49.58133928477764, 53.67511801421642, 58.318951427936554, 57.14492082595825, 51.5382494777441, 51.57077573239803, 43.273107782006264, 1.881881793960929, 4.330977201461792, 0.9194124396890402, 0.2761974121676758, 0.20841362129431218, 34.770106449723244, 64.24472585320473, 56.42238959670067, 60.24622321128845, 61.348969638347626, 61.044883355498314, 44.59684655070305, 45.77617786824703, 24.651414714753628, 50.56343078613281, 26.509904488921165, 0.3606312267947942, 0.10073882134747691, 0.08548843616154045, 0.08474226604448631, 0.008091158360912232, 0.04197562397166621, 0.032991507032420486, 0.018144124733225908, 0.01344290121778613, 0.053279542407835834, 0.08592354250140488, 0.10833704800461419, 0.1616709044901654, 0.2437688093050383, 0.11775509497965686, 0.17718671879265457, 0.13465782743878663, 0.15453957777936012, 0.12989126524189487, 0.2036739545292221, 0.07130271376809105, 0.14757812867173925, 0.16108060022816062, 0.3458634379785508, 0.29934256395790726, 6.302357967942953, 70.9794844686985, 58.207518607378006, 38.597428277134895, 42.09649331867695, 60.93320354819298, 71.01505815982819, 65.79528585076332, 58.42397779226303, 67.99829363822937, 60.492556393146515, 66.86841666698456, 21.104073263704777, 2.0969516783952713, 10.270605683326721, 3.2246079063043, 2.711077812127769, 44.02856044471264, 65.27683407068253, 59.13126423954964, 69.41147580742836, 61.17638669908047, 64.28230583667755, 61.07643686234951, 63.962180614471436, 65.7033383846283, 58.617429211735725, 53.995934799313545, 58.079514876008034, 51.853662952780724, 51.47168084979057, 52.74131052196026, 55.621172189712524, 55.38487046957016, 52.15103879570961, 49.076821357011795, 48.93236070871353, 47.43277497589588, 46.5589814633131, 44.992450922727585, 43.50634306669235, 46.364025324583054, 56.72475457191467, 55.27772381901741, 58.50125804543495, 55.853354930877686, 55.745273530483246, 54.81792949140072, 44.009690657258034, 45.54971382021904, 40.9582643955946, 42.93605826795101, 42.14560188353062, 44.92788478732109, 43.7349122017622, 44.53896805644035, 49.612942188978195, 53.833641707897186, 53.90501327812672, 55.50081364810467, 56.95887140929699, 55.21170996129513, 52.412552163004875, 47.72637762129307, 41.781729608774185, 41.10736459493637, 42.21494436264038, 41.010082215070724, 42.50868760049343, 38.390791565179825, 43.86494122445583, 44.991242587566376, 46.98117680847645, 51.09363153576851, 47.92648248374462, 46.79892338812351, 45.27305826544762, 46.231230050325394, 43.00776042044163, 39.93320479989052, 41.38456732034683, 39.996855184435844, 40.763863027095795, 43.620713129639626, 42.250784039497375, 45.26585765182972, 45.465141758322716, 53.182835429906845, 55.5594938993454, 54.973831325769424, 53.35390605032444, 56.175900623202324, 56.226228922605515, 53.60034942626953, 54.91951324045658, 51.30244933068752, 44.91565324366093, 38.37980255484581, 39.687247797846794, 40.90764731168747, 41.74013704061508, 41.55350625514984, 42.08999186754227, 45.82337513566017, 44.91838909685612, 43.682266026735306, 48.8197423517704, 52.14779756963253, 50.79792380332947, 49.90507051348686, 47.2059765458107, 45.49986809492111, 42.7921561896801, 43.28370541334152, 44.29623708128929, 42.632971331477165, 42.11200028657913, 43.217592760920525, 45.34205496311188, 39.83535625040531, 47.99657352268696, 46.65591426193714, 43.131652772426605, 42.64350436627865, 50.04457622766495, 47.822425067424774, 45.93417339026928, 47.07138776779175, 52.56488598883152, 55.2836325019598, 61.17328606545925, 57.660207375884056, 52.974697798490524, 49.97820898890495, 47.691731080412865, 3.7587891798466444, 6.9766792841255665, 1.7869993415661156, 0.8598470140714198, 0.37157731130719185, 38.36368381977081, 69.0935468673706, 60.93689315021038, 65.84513157606125, 64.54108715057373, 66.51281654834747, 48.0241334438324, 48.37618075311184, 38.944482654333115, 62.45919406414032, 36.40789836645126, 0.3850662609329447, 0.2168094934313558, 0.20461713516851887, 0.22488846851047128, 0.1603688657633029, 0.17556229111505672, 0.1218638768477831, 0.1365728207747452, 0.16569589788559824, 0.13886403845390305, 0.1821997927618213], [0.041260163925471716, 0.03190167059074156, 0.02298184590472374, 0.025571594342181925, 0.004145957436776371, 0.031513223075307906, 0.07012531132204458, 0.06962056184420362, 0.015918705867079552, 0.05774708217359148, 0.02800672187731834, 0.01594923967786599, 0.050994929843000136, 0.24126377888023853, 0.32354408875107765, 31.521596163511276, 48.30895096063614, 19.32118233293295, 20.827924981713295, 38.69403429329395, 61.17546334862709, 57.19731621444225, 46.93627081811428, 53.42316493391991, 50.89213974773884, 57.97014534473419, 24.931269697844982, 1.7082862090319395, 1.5130263241007924, 0.6023379194084555, 0.39727028575725853, 23.146931044757366, 65.46178534626961, 61.18966318666935, 62.41498723626137, 59.330042973160744, 60.30192442238331, 57.57002681493759, 60.321626365184784, 56.45386330783367, 57.91095972061157, 56.50317706167698, 55.39870172739029, 54.84162122011185, 52.58451193571091, 53.667556419968605, 47.54628248512745, 48.322729021310806, 47.88983345031738, 47.10254609584808, 42.80067153275013, 42.29885905981064, 41.564776450395584, 41.38489410281181, 39.893379136919975, 41.57787814736366, 46.50193512439728, 49.85872820019722, 50.78432813286781, 51.73536770045757, 51.444310918450356, 48.17516393959522, 41.68978974223137, 39.567573219537735, 38.570168539881706, 39.56532374024391, 37.61235013604164, 38.18718709051609, 38.358823880553246, 37.274396270513535, 41.21767647564411, 44.63552847504616, 46.081825867295265, 50.432182028889656, 49.92975398898125, 51.154850050807, 43.48582796752453, 41.24745927751064, 42.529065907001495, 41.02552078664303, 41.893257424235344, 39.530126228928566, 40.28044156730175, 41.49871699512005, 40.0721899420023, 39.91940774023533, 40.36084145307541, 38.25954660773277, 39.014053121209145, 38.42262625694275, 39.8960579931736, 39.459457620978355, 40.41319504380226, 40.30454747378826, 40.7743276655674, 42.171740680933, 40.26405684649944, 42.20648221671581, 40.883427411317825, 41.61294266581535, 41.37973017990589, 45.56068383157253, 49.26759772002697, 51.46948456764221, 49.072413593530655, 50.89395985007286, 51.41172006726265, 50.281721502542496, 48.95549766719341, 46.06758423149586, 37.64333747327328, 37.31157347559929, 37.365363389253616, 36.95188857614994, 37.69141249358654, 39.117555767297745, 39.440086260437965, 37.666968405246735, 41.05718448758125, 42.184196412563324, 42.88435064256191, 45.203727185726166, 43.976678028702736, 44.62828226387501, 40.35333685576916, 40.71622118353844, 38.9447258412838, 38.178033381700516, 37.59271278977394, 37.039926052093506, 38.93144555389881, 38.7795715034008, 38.42451475560665, 38.48548248410225, 41.51075854897499, 41.42397500574589, 43.038474172353745, 46.91977210342884, 45.6804534047842, 47.42832541465759, 49.28638771176338, 50.250893756747246, 51.04481175541878, 54.02755290269852, 54.641466960310936, 56.46006077528, 49.97952751815319, 53.8911098241806, 37.19788357615471, 0.512481409823522, 0.355324306874536, 0.2313705941196531, 0.2927278314018622, 0.32637398689985275, 36.05975724756718, 55.30733563005924, 52.684222385287285, 53.95680069923401, 54.212466180324554, 46.82769164443016, 35.26308439671993, 27.397580556571484, 25.798481963574886, 43.291392400860786, 8.37550487369299, 0.5294818757101893, 0.044906869807164185, 0.13988699996843934, 0.01916147375595756, 0.07547310131485574, 0.10452684698975645, 0.07092691987054422, 0.032384964579250664, 0.030629954162577633, 0.008536823606846156, 0.02793907140585361, 0.050000277551589534, 0.04262058369931765, 0.00883228836755734, 0.05293175716360565, 0.03054132503166329, 0.06955345685128123, 0.005555883562919917, 0.052401373905013315, 0.03208919275493827, 0.05750417723902501, 0.039917132671689615, 0.03645667988166679, 0.06925789653905667, 0.19559818552806973, 0.5978373577818274, 39.2488881200552, 52.447780072689056, 18.364807851612568, 34.583528861403465, 50.824632570147514, 63.643115535378456, 62.78749264776707, 53.51340629160404, 62.021666541695595, 54.89759601652622, 63.06783780455589, 27.024182192981243, 0.9385341417510062, 1.5652459720149636, 0.4150018561631441, 0.37967378622852266, 24.95494432747364, 66.41339108347893, 61.04402460157871, 62.37695887684822, 60.58565899729729, 61.29632726311684, 58.68133418262005, 62.79932901263237, 56.64596199989319, 59.094698801636696, 59.18183572590351, 59.01007354259491, 57.01298050582409, 52.95042470097542, 55.30883274972439, 50.65113008022308, 50.107086673378944, 52.17857971787453, 50.26890479028225, 45.2935391664505, 44.4726350158453, 43.28086696565151, 45.01436434686184, 43.366647362709045, 44.765405505895615, 48.31811606884003, 52.10851147770882, 55.27176193892956, 53.33434469997883, 53.9541332423687, 50.08676916360855, 45.296313017606735, 41.94251798093319, 42.46996767818928, 39.62840415537357, 41.777492836117744, 40.433770939707756, 39.888112619519234, 38.31326052546501, 44.66530367732048, 47.72766575217247, 46.857630237936974, 51.32551409304142, 52.49355621635914, 53.62703159451485, 46.38496980071068, 42.26753354072571, 42.56696127355099, 40.3985658288002, 43.54918956756592, 39.77954104542732, 40.83482421934605, 43.80615837872028, 41.91826768219471, 41.75288535654545, 42.310201451182365, 40.83188697695732, 41.739521473646164, 40.31500831246376, 41.361878737807274, 41.2009421736002, 42.07298018038273, 40.486789494752884, 42.05593429505825, 41.75723232328892, 42.26514346897602, 43.40970665216446, 41.53762690722942, 42.06769086420536, 41.554418206214905, 46.057617366313934, 50.31218446791172, 52.17144750058651, 51.14030063152313, 52.61360317468643, 53.156594038009644, 52.43698485195637, 51.403200924396515, 47.04574294388294, 40.60466676950455, 37.85432495176792, 39.80294778943062, 39.082954823970795, 38.82760472595692, 39.78341303765774, 40.835542380809784, 39.76089544594288, 42.17425994575024, 44.86111477017403, 47.170326858758926, 46.94947890937328, 45.67408874630928, 45.82385390996933, 42.22491502761841, 40.98585471510887, 41.28487206995487, 41.250624507665634, 39.30636763572693, 39.65592987835407, 40.74103005230427, 40.46375513076782, 39.6586999297142, 40.66659204661846, 44.271922186017036, 45.54231941699982, 45.08440978825092, 47.268297001719475, 48.8467551022768, 49.39433991909027, 52.153246477246284, 52.69331909716129, 54.291984513401985, 56.4161541312933, 57.803505286574364, 57.89286509156227, 51.40491463243961, 53.91724482178688, 41.515367701649666, 1.0459430376067758, 1.3412922830320895, 0.718308468349278, 0.20438776700757444, 0.22168089140905067, 39.495688676834106, 61.020838245749474, 59.63968075811863, 59.42818030714989, 62.80788995325565, 50.32143697142601, 49.60550978779793, 30.239005386829376, 23.921302892267704, 54.252709820866585, 10.766159892082214, 0.46518139948602766, 0.0624852794862818, 0.0436164865095634, 0.026432019949425012, 0.07116673747077584, 0.024864904626156203, 0.10139279445866123, 0.03974451283283997, 0.03677278284158092, 0.02709273547225166, 0.02523348855902441, 0.11949732375796884, 0.1458249383722432, 0.13102381228236482, 0.14198966760886833, 0.10545496203121729, 0.2020349956001155, 0.16110593714984134, 0.17437613132642582, 0.08554915126296692, 0.1643788380897604, 0.22239991376409307, 0.15912845497950912, 0.17731214175000787, 0.3157584252767265, 0.8680501207709312, 48.13224904239178, 63.85954812169075, 27.185833118855953, 31.269876770675182, 51.47527925670147, 69.97110217809677, 68.59030947089195, 62.37336806952953, 67.63102054595947, 59.440750032663345, 67.95764341950417, 32.8623466193676, 3.3279386116191745, 8.57195433229208, 1.3555469806306064, 0.5168656026944518, 28.261625692248344, 66.39654278755188, 63.61603058874607, 66.03534936904907, 62.76148684322834, 62.03064925968647, 59.61493268609047, 63.5362234711647, 58.80410939455032, 61.47911265492439, 62.01262682676315, 61.43843203783035, 60.229374915361404, 55.66779188811779, 57.913121804594994, 51.31183102726936, 52.989292815327644, 52.6159742474556, 52.84049279987812, 48.82233001291752, 47.82005399465561, 46.161591187119484, 46.528111919760704, 44.19683821499348, 48.12174640595913, 50.20493522286415, 54.854791313409805, 55.36932930350304, 55.51406353712082, 56.54484182596207, 53.41760963201523, 48.18407826125622, 44.54950109124184, 43.53556729853153, 42.065285593271255, 42.93367199599743, 43.44080038368702, 41.977381110191345, 41.632545813918114, 47.66904629766941, 50.921310782432556, 50.314665734767914, 55.758075043559074, 54.67204011976719, 54.16299283504486, 46.69385522603989, 41.53159283101559, 43.848966881632805, 40.37906527519226, 45.124972611665726, 43.694991543889046, 42.52396658062935, 43.18554908037186, 43.6339820176363, 44.350650161504745, 44.635475277900696, 41.96613371372223, 44.20339286327362, 42.330446764826775, 43.5934191942215, 43.79780262708664, 44.89811718463898, 41.729600206017494, 43.03678706288338, 43.932000026106834, 42.25501321256161, 42.13537283241749, 40.59731036424637, 43.32790844142437, 41.27527758479118, 45.16464628279209, 50.490957275033, 55.38100607693195, 53.56467314064503, 56.124766767024994, 55.86248964071274, 54.56800550222397, 54.52114641666412, 49.359716176986694, 42.09557756781578, 41.05916038155556, 43.00741843879223, 42.76334993541241, 41.605525463819504, 42.02640227973461, 42.559532672166824, 40.95930173993111, 45.0981118530035, 46.83899983763695, 48.03198382258415, 49.954980835318565, 48.04663583636284, 49.75432500243187, 42.86640800535679, 43.60005743801594, 44.370116516947746, 42.72150278091431, 41.010082215070724, 40.580595061182976, 42.56782002747059, 42.44893580675125, 41.52914576232433, 41.75689034163952, 47.09026515483856, 47.38499253988266, 47.2001438587904, 49.264831468462944, 52.11575008928776, 54.03509929776192, 54.44674260914326, 54.461455419659615, 56.16030625998974, 59.07606840133667, 59.92380291223526, 59.67341534793377, 52.82805606722832, 55.094056874513626, 46.324906423687935, 2.10279552731663, 2.3005212424322963, 2.0573036558926105, 0.7893542060628533, 0.3739086049608886, 43.73511739075184, 68.56607437133789, 63.31490434706211, 66.33803352713585, 64.49043586850166, 58.22017952799797, 47.88001857697964, 36.92601576447487, 35.937001034617424, 62.17821054160595, 14.65108947828412, 0.7624065864365548, 0.17916314711328596, 0.26598946773447096, 0.14175706368405372, 0.1579453973681666, 0.4063793766545132, 0.18705818831222132, 0.09558555568219163, 0.23889506614068523, 0.2540176163893193, 0.1495594996958971], [0.03424802613153588, 0.034344783634878695, 0.10393048680271022, 0.02061874565697508, 0.048294169100699946, 0.06728010266670026, 0.0380175314785447, 0.05293156791594811, 0.0587145533063449, 0.030911823705537245, 0.05027623032219708, 0.0952157806023024, 0.057222647228627466, 0.21096773736644536, 0.3344133758218959, 9.618041049689054, 57.2598684579134, 34.91823010146618, 28.268581219017506, 28.841805160045624, 49.46205988526344, 62.088827937841415, 51.22694358229637, 51.97152502834797, 50.90245619416237, 55.38683496415615, 29.332049153745174, 0.7383578550070524, 0.33752294490113854, 0.5810658296104521, 0.06758892515790649, 13.220470994710922, 64.30714890360832, 62.75629632174969, 62.66371808946133, 56.94742262363434, 59.114780724048615, 60.888472348451614, 59.8002715408802, 56.711755469441414, 59.74503390491009, 57.561796456575394, 59.14679780602455, 58.20469915866852, 57.60838195681572, 51.73945628106594, 50.95226772129536, 51.2166803330183, 49.82399806380272, 45.396813824772835, 43.63990589976311, 42.443726286292076, 40.141399428248405, 41.621108427643776, 42.531011402606964, 41.643618419766426, 45.610335767269135, 47.47378617525101, 51.67429357767105, 51.616912856698036, 50.09621925652027, 49.71178248524666, 45.024411007761955, 40.059711411595345, 38.843605667352676, 38.42477694153786, 39.08667482435703, 40.74559360742569, 39.73568759858608, 37.51555413007736, 40.96525602042675, 44.81975018978119, 45.533648282289505, 49.78503875434399, 51.80520035326481, 42.99544908106327, 42.359465807676315, 42.580336555838585, 39.7088610380888, 41.59834384918213, 38.74652847647667, 40.82210250198841, 39.20682817697525, 40.663738399744034, 37.09082432091236, 37.95458257198334, 36.52914226055145, 37.46389590203762, 37.08374910056591, 37.8023399412632, 38.07575806975365, 36.698050796985626, 37.03380078077316, 36.62680082023144, 40.2277459949255, 40.51551975309849, 41.8745282292366, 41.38432413339615, 41.11701987683773, 42.90973708033562, 41.83254808187485, 41.38613283634186, 42.43938311934471, 48.79171885550022, 50.998298451304436, 48.28667655587196, 50.35378463566303, 47.99199476838112, 45.03430187702179, 41.44238881766796, 37.713633701205254, 36.83779589831829, 38.63926023244858, 35.481941252946854, 36.68337218463421, 38.73289480805397, 38.83056856691837, 38.294158950448036, 39.40879113972187, 41.77666828036308, 43.258729353547096, 42.586579620838165, 43.98763284087181, 41.773917227983475, 41.00215204060078, 38.741448149085045, 38.54179546236992, 38.25018011033535, 37.44281843304634, 38.01930069923401, 37.72401474416256, 39.155622124671936, 38.08493457734585, 38.531441017985344, 40.5486273765564, 44.32365261018276, 46.83718353509903, 48.169927820563316, 50.548356994986534, 51.85209363698959, 53.272370025515556, 52.9392609000206, 53.445450738072395, 55.82882724702358, 54.01755943894386, 56.48748390376568, 53.33175703883171, 54.261251762509346, 45.33798158168793, 1.4730980666354299, 0.45613358030095696, 0.5562019825447351, 0.3138871444389224, 1.843298664316535, 42.69833542406559, 53.49921405315399, 51.83221310377121, 54.286212623119354, 53.143081963062286, 48.49346525967121, 33.08906525373459, 32.63023987412453, 37.08079285919666, 32.30067975819111, 0.5040740640833974, 0.026425032629049383, 0.08913093406590633, 0.07736564468359575, 0.07161475718021393, 0.05653188214637339, 0.08235553395934403, 0.032809317199280486, 0.04141359182540327, 0.05879730648302939, 0.06907167684403248, 0.04730266722617671, 0.045449053213815205, 0.053154445995460264, 0.07636668422492221, 0.028102329051762354, 0.0358594031422399, 0.10700559796532616, 0.04322084758314304, 0.030057721196499187, 0.07709183671977371, 0.019779515787377022, 0.056532379385316744, 0.0562867470580386, 0.07695551161305048, 0.1943824437330477, 0.32896429009269923, 14.437796473503113, 69.68560829758644, 28.15370388329029, 27.30083204805851, 46.62588827311993, 55.0946344435215, 68.54157328605652, 54.29331064224243, 60.05822069942951, 55.374318435788155, 61.080787628889084, 30.639807879924774, 0.7130365481134504, 0.7912184810265899, 0.41175098216626793, 0.11170492900419049, 15.108594428747892, 66.35383307933807, 65.69747149944305, 65.28640955686569, 60.57807080447674, 62.87846736609936, 61.25049412250519, 60.83531320095062, 59.33424174785614, 61.39594651758671, 58.4973556548357, 61.381332501769066, 58.818286433815956, 60.24062231183052, 54.27884481847286, 53.89661192893982, 53.58682595193386, 53.62882889807224, 49.24153491854668, 46.90049193799496, 44.972935169935226, 41.04122154414654, 41.72193981707096, 45.920741111040115, 43.786110654473305, 47.09530748426914, 51.16892449557781, 54.249932169914246, 50.89684769511223, 53.65969464182854, 50.5340925604105, 45.52823357284069, 42.052035704255104, 42.07615301012993, 42.36412055790424, 41.23029179871082, 41.820464730262756, 43.37334640324116, 40.04144959151745, 43.66974949836731, 46.55347175896168, 48.67388717830181, 51.75704173743725, 52.440283074975014, 46.90193586051464, 41.339832320809364, 42.74500072002411, 41.39195792376995, 41.03902146220207, 40.53362198174, 43.09165231883526, 41.63229502737522, 42.46345102787018, 40.963614508509636, 40.48374205827713, 39.37123015522957, 39.782603681087494, 40.14918141067028, 40.229816883802414, 40.650165528059006, 39.48546722531319, 41.53001211583614, 39.962459430098534, 42.32942841947079, 42.04018414020538, 42.65594869852066, 41.11902616918087, 42.62704744935036, 42.465917095541954, 40.79340264201164, 40.49298316240311, 43.498044312000275, 50.02199403941631, 54.27196718752384, 51.318803653120995, 52.26164326071739, 50.84020033478737, 45.46810179948807, 43.701739981770515, 39.12278048694134, 38.78230735659599, 40.03715582191944, 38.09624657034874, 37.6373565942049, 40.648372024297714, 40.1436223089695, 40.02023532986641, 40.06807096302509, 43.07793885469437, 45.03192700445652, 45.61207987368107, 44.892326295375824, 44.27438825368881, 41.56774029135704, 40.54026402533054, 39.285020381212234, 38.84822241961956, 39.880497828125954, 39.29385110735893, 39.30884510278702, 40.28139911592007, 40.81695757806301, 41.645898297429085, 43.671884983778, 47.713906690478325, 48.44001732766628, 49.860567301511765, 52.84157194197178, 53.91500674188137, 54.81056168675423, 54.23740044236183, 55.182877108454704, 57.57333643734455, 56.861076056957245, 58.41319017112255, 58.9509829133749, 57.702567502856255, 49.06744726002216, 2.0288514951243997, 1.057386954780668, 0.554179719183594, 0.1960533595411107, 1.7712180758826435, 47.98568710684776, 59.50783163309097, 56.723496839404106, 59.71067614853382, 57.58863441646099, 52.47828483581543, 46.583345755934715, 27.61039763689041, 40.50342880189419, 40.33092565834522, 1.1300753918476403, 0.059591679091681726, 0.12804995232727379, 0.020944815660186578, 0.07881386423832737, 0.01925119384395657, 0.08889611854101531, 0.004645648250516388, 0.05929343962634448, 0.03928846308554057, 0.08144157167407684, 0.04081115715962369, 0.14817203977145255, 0.13654444104759023, 0.27153298433404416, 0.10989279733621515, 0.15819968684809282, 0.20946221658959985, 0.12889039004221559, 0.14875165710691363, 0.2036904450505972, 0.24704985902644694, 0.08679120961460285, 0.13017066899919882, 0.26769931660965085, 0.44393626449164003, 0.6848141562659293, 16.113041080534458, 80.25550872087479, 45.645092502236366, 37.74945817887783, 41.931262984871864, 59.716793820261955, 74.17067483067513, 61.77108898758888, 65.05329206585884, 63.34246426820755, 64.92026880383492, 37.18421570956707, 1.318108777049929, 4.611067771911621, 0.976187865016982, 0.1455430409987457, 17.514641471207142, 67.12899148464203, 66.60366967320442, 67.3150523006916, 62.6854757219553, 66.03192955255508, 64.25446093082428, 63.35378386080265, 58.493362069129944, 63.38914476335049, 60.6226310133934, 63.806875348091125, 61.948227882385254, 61.12939082086086, 56.77383653819561, 55.48297740519047, 55.970156863331795, 56.24811574816704, 52.77267403900623, 50.3411541134119, 48.11740703880787, 42.112741246819496, 45.09191818535328, 50.304702669382095, 46.65774576365948, 52.333421409130096, 53.07254254817963, 56.56936950981617, 55.193296149373055, 56.509123742580414, 54.95849534869194, 48.2457185536623, 43.73245753347874, 44.58817921578884, 45.01787155866623, 43.378445729613304, 46.8597961217165, 46.07694312930107, 42.385517209768295, 46.432877629995346, 49.084546342492104, 50.75115591287613, 55.379421561956406, 54.199467077851295, 46.61795809864998, 43.923252895474434, 44.5220285654068, 42.156009525060654, 41.42044119536877, 42.98827886581421, 45.82560561597347, 42.53001965582371, 45.23341119289398, 43.67817364633083, 43.58097866177559, 40.979376062750816, 42.03783966600895, 42.15735845267773, 42.90452376008034, 42.895860224962234, 40.758710503578186, 42.74695381522179, 41.259535029530525, 45.11350102722645, 42.448517829179764, 44.707891792058945, 44.23772022128105, 42.85819664597511, 44.574359357357025, 40.26760585606098, 40.10815881192684, 42.53399804234505, 50.23938037455082, 56.521910056471825, 52.355209439992905, 52.617060989141464, 52.925270050764084, 49.15385842323303, 45.243051275610924, 42.54998378455639, 40.38766421377659, 42.52550929784775, 39.62136693298817, 40.67215874791145, 43.00829999148846, 42.17037655413151, 41.61893114447594, 42.276561856269836, 46.10247775912285, 49.097237661480904, 46.84466913342476, 48.826939165592194, 47.152600809931755, 45.07125109434128, 42.37809240818024, 42.57989197969437, 40.07192775607109, 42.79820166528225, 40.96714831888676, 41.06187343597412, 43.389465138316154, 42.96097353100777, 43.925741761922836, 45.099958553910255, 49.983277916908264, 51.62121422588825, 51.37352451682091, 54.13482114672661, 55.15572376549244, 57.73333065211773, 56.24881871044636, 57.44546189904213, 60.66449336707592, 58.077105805277824, 61.363443061709404, 60.40563605725765, 58.43213215470314, 50.92907756567001, 3.6937787057831883, 2.314760978333652, 2.1777906781062484, 0.4124115826562047, 2.1950538642704487, 52.15528316795826, 64.33306351304054, 61.3822178542614, 64.5288822054863, 62.70346395671368, 58.80987748503685, 45.76282158493996, 41.787835881114006, 49.69448581337929, 51.279650554060936, 1.6186804859898984, 0.14852812222670764, 0.24548732646508142, 0.20935990411089733, 0.25165126367937773, 0.13893326598918065, 0.14555616216966882, 0.09862479142611846, 0.14320340560516343, 0.2923046884825453, 0.1874504578881897, 0.11685194578603841], [0.029259350267238915, 0.06654944343608804, 0.05515096054296009, 0.03688727396365721, 0.09745404604473151, 0.05201183543249499, 0.009527768870611908, 0.022942799660086166, 0.07808632202795707, 0.0788526117685251, 0.10926298113190569, 0.019904569526261184, 0.07954827873618342, 0.10038857217296027, 0.10206820821622387, 0.41581563593354076, 34.43502523005009, 44.73943389952183, 31.402803137898445, 27.86062940955162, 42.765037044882774, 58.30763183534145, 47.00597807765007, 56.3533852994442, 52.240318804979324, 55.2752273529768, 39.70098406076431, 0.2758497605100274, 0.4053950810339302, 0.7331729144789279, 0.05167176110262517, 10.588565971702337, 66.12453058362007, 62.7641087025404, 60.78447952866554, 57.24506825208664, 58.63709315657616, 58.85428190231323, 58.55281747877598, 56.69282868504524, 56.54450364410877, 56.97629727423191, 57.226251661777496, 56.53807818889618, 52.695386186242104, 54.647444039583206, 52.59396582841873, 49.37382481992245, 46.92258395254612, 44.91371914744377, 41.36900335550308, 41.087902039289474, 40.00337943434715, 39.53239090740681, 41.245171800255775, 41.052297949790955, 43.38973492383957, 46.64358012378216, 48.204631358385086, 48.522393107414246, 47.80844561755657, 44.98935028910637, 42.27582849562168, 41.33657969534397, 40.270147919654846, 39.83502186834812, 38.51220265030861, 41.143599450588226, 40.263167694211006, 38.575457856059074, 41.525049582123756, 43.863159120082855, 46.18330702185631, 50.43134227395058, 50.68652518093586, 41.20347283780575, 40.764892771840096, 39.44029524922371, 42.07252040505409, 41.655374988913536, 39.49865631759167, 40.346501022577286, 37.95119695365429, 36.54857441782951, 37.44084253907204, 38.016853630542755, 38.70455212891102, 38.09443786740303, 37.37948723137379, 38.68591792881489, 37.37824849784374, 36.969428434967995, 36.59771338105202, 36.53203010559082, 35.97792863845825, 37.27656975388527, 38.51732857525349, 41.7103086411953, 40.574454590678215, 40.634179785847664, 41.77450239658356, 40.96910901367664, 42.63856463134289, 41.8959666788578, 49.13126863539219, 50.21515667438507, 46.70302793383598, 47.11909420788288, 42.484004124999046, 40.234148651361465, 37.66605265438557, 38.896213844418526, 37.26413682103157, 36.54670871794224, 37.42549516260624, 37.520136684179306, 37.11502522230148, 37.86112658679485, 38.243462070822716, 40.47314442694187, 42.198666036129, 42.86206103861332, 41.19269281625748, 40.18060952425003, 38.54405254125595, 36.242732629179955, 37.72248722612858, 37.124889492988586, 38.44203941524029, 37.06117831170559, 38.96219350397587, 38.69529962539673, 38.6860129237175, 37.9389426112175, 38.658722788095474, 42.66389027237892, 48.21465902030468, 53.193098679184914, 53.97020258009434, 53.40749077498913, 52.34265871345997, 55.73761314153671, 54.77865479886532, 54.4002179056406, 52.951880022883415, 54.649157747626305, 54.941023886203766, 55.483729764819145, 55.65192773938179, 5.306252343580127, 0.14586963050533086, 0.786477760411799, 0.4283047642093152, 5.526840956881642, 54.95130233466625, 50.99300153553486, 52.556100860238075, 55.251881405711174, 58.99339623749256, 42.12830901145935, 36.39551483094692, 31.74244411289692, 42.83446691930294, 12.343916930258274, 0.4003553045913577, 0.04144208287470974, 0.09559438723954372, 0.02606318554171594, 0.1327139200293459, 0.1048720940889325, 0.009244950306310784, 0.0543021551129641, 0.026288763183401898, 0.06331120079266839, 0.05186961767321918, 0.06440638811909594, 0.039177233702503145, 0.030066012841416523, 0.015133172237256076, 0.05269301196676679, 0.015292307252821047, 0.03223807128961198, 0.05239853519015014, 0.032113954512169585, 0.05024212492571678, 0.05648339392791968, 0.03505816937831696, 0.021280704277160112, 0.08455741932266392, 0.07708280478254892, 0.10235979803837836, 1.364301354624331, 44.76698622107506, 44.71706070005894, 22.682198882102966, 37.912914007902145, 50.802559554576874, 64.77775365114212, 57.49440707266331, 59.91151437163353, 56.0933880507946, 59.68562789261341, 42.94589973986149, 0.11352420755429193, 1.5597278368659317, 0.8929402695503086, 0.02759545146545861, 12.006521634757519, 67.24212661385536, 62.78624631464481, 62.54971660673618, 59.63355928659439, 61.7690484970808, 60.103217884898186, 61.61665387451649, 58.20479415357113, 56.731856390833855, 57.72972844541073, 56.13877281546593, 56.703129932284355, 55.24489738047123, 55.93014121055603, 54.487628415226936, 52.444348856806755, 49.388727620244026, 46.76337629556656, 44.17609892785549, 43.18765416741371, 42.67480708658695, 41.903969049453735, 44.53131906688213, 42.84921772778034, 45.852739959955215, 48.833550810813904, 50.55899642407894, 51.82850070297718, 50.72030156850815, 48.597142696380615, 44.8769561201334, 43.938338086009026, 43.73865880072117, 41.74278549849987, 39.86758232116699, 43.803920298814774, 41.88683956861496, 40.60062758624554, 42.970594614744186, 44.69989702105522, 48.319666385650635, 54.246398359537125, 51.59722611308098, 42.54575081169605, 41.36736184358597, 42.44495362043381, 43.03219310939312, 43.209814578294754, 42.167158126831055, 41.191533878445625, 39.52336639165878, 39.443019703030586, 38.2991860806942, 38.834193572402, 39.82693590223789, 38.35467830300331, 39.785126745700836, 39.75666627287865, 38.76825571060181, 38.50529082119465, 39.564366191625595, 37.90638975799084, 39.33059133589268, 39.55260582268238, 42.924871668219566, 43.000829592347145, 41.5313496440649, 40.991269424557686, 41.308423206210136, 42.619121074676514, 40.46562843024731, 42.92101867496967, 49.88043263554573, 52.22527161240578, 49.05484713613987, 49.918818175792694, 44.498276039958, 42.9959886521101, 38.894686326384544, 40.048513412475586, 40.09829454123974, 38.91223758459091, 37.72202745079994, 38.500605672597885, 39.31718185544014, 40.28491772711277, 40.31687021255493, 41.52604512870312, 44.21797648072243, 44.34625379741192, 42.695569172501564, 42.95739412307739, 39.560422003269196, 38.51570226252079, 39.25868779420853, 38.52971971035004, 39.09633010625839, 39.530141428112984, 40.157366171479225, 41.22399553656578, 40.43870687484741, 39.0202733874321, 41.89103074371815, 45.53228795528412, 49.83903005719185, 55.607340931892395, 55.264926105737686, 54.11959156394005, 54.624409675598145, 55.09879142045975, 56.45778089761734, 55.685753524303436, 55.14250047504902, 57.430931478738785, 56.08108051121235, 56.8154177069664, 57.658182084560394, 7.237783698365092, 0.04889694515441079, 1.021602968685329, 0.21678368153516203, 6.180912684649229, 60.11285416781902, 55.56390546262264, 56.07874743640423, 59.72929894924164, 63.848764300346375, 49.11625564098358, 41.04986608028412, 29.299232214689255, 50.63359022140503, 15.775056816637516, 0.4712714039487764, 0.052087156000197865, 0.12473871203837916, 0.012402650445437757, 0.04456202717847191, 0.06788752827560529, 0.06767206796212122, 0.04615716228727251, 0.010238463401037734, 0.02958119188406272, 0.02130268854671158, 0.0325744051951915, 0.15319097670726478, 0.16689436248270795, 0.13885020482121035, 0.15359783690655604, 0.22441281122155488, 0.11595917923841625, 0.10337017272831872, 0.13295786397065967, 0.3013297385768965, 0.17641834361711517, 0.1486211727024056, 0.12606746808160096, 0.12465167295886204, 0.21984846942359582, 0.1326995372073725, 1.6969560482539237, 53.15268024802208, 58.56320612132549, 39.48626138269901, 39.375565722584724, 54.55210715532303, 67.41336822509766, 63.42255637049675, 66.43555149435997, 61.14335507154465, 64.94337156414986, 50.03109075129032, 0.22911029431270435, 2.897156202234328, 1.7550635989755392, 0.14421633328311145, 13.239539321511984, 69.00766387581825, 66.24803155660629, 64.71094563603401, 62.22955718636513, 64.19709920883179, 63.266988918185234, 64.70475196838379, 60.20317152142525, 59.717333391308784, 60.51502838730812, 55.59330828487873, 58.936832472682, 56.04078367352486, 59.378999546170235, 56.33429512381554, 53.41200113296509, 51.31712794303894, 49.94876056909561, 46.52621582150459, 45.86291961371899, 45.250194892287254, 44.60523650050163, 46.657521575689316, 45.0468298047781, 46.39375112950802, 51.12452767789364, 55.05083419382572, 55.722626745700836, 52.117642387747765, 49.45652738213539, 46.91172033548355, 45.403828248381615, 46.44430361688137, 43.4828869253397, 42.74791516363621, 45.78683249652386, 44.49261054396629, 43.3004055172205, 45.40446661412716, 47.75556765496731, 51.56141683459282, 57.455808743834496, 53.552297204732895, 41.78794987499714, 42.99536168575287, 41.812967732548714, 45.16247279942036, 46.97806857526302, 43.44615809619427, 44.33584615588188, 42.698529213666916, 42.27041378617287, 40.80894760787487, 41.49451062083244, 44.00249384343624, 41.70436196029186, 42.83767394721508, 42.27336622774601, 41.93846359848976, 40.924940183758736, 41.624900624156, 39.81002300977707, 40.7459469884634, 40.47076195478439, 44.76840354502201, 44.23392042517662, 43.49081330001354, 41.42053619027138, 42.565699741244316, 43.25871415436268, 41.98441833257675, 43.16726066172123, 51.8080236017704, 55.02355545759201, 50.16606330871582, 50.24936243891716, 47.19121813774109, 44.48271967470646, 41.995183154940605, 43.31793397665024, 42.348909974098206, 41.296176463365555, 41.13019376993179, 41.08657591044903, 40.70406563580036, 42.19966918230057, 42.20804013311863, 42.737287133932114, 46.83412469923496, 48.513338193297386, 43.94714221358299, 44.03961785137653, 42.542186602950096, 39.988461434841156, 41.36255890130997, 42.22994215786457, 42.640114948153496, 39.69936914741993, 43.82222771644592, 42.48645879328251, 41.6205270588398, 40.430476516485214, 43.796229511499405, 47.880436554551125, 52.30067476630211, 57.556267753243446, 58.16657580435276, 55.45900069177151, 56.905495673418045, 56.917750015854836, 58.03621619939804, 56.04826547205448, 57.06373058259487, 59.97838318347931, 60.47559030354023, 58.820532113313675, 61.07318803668022, 8.916801027953625, 0.25602764915674925, 2.401527897454798, 0.6063237867783755, 6.856020083650947, 67.0679135620594, 60.4352630674839, 63.261270225048065, 64.36302110552788, 70.394566655159, 53.09765540063381, 50.37509769201279, 39.255222380161285, 61.07262186706066, 21.152366772294044, 0.5424680351279676, 0.2063233029912226, 0.16278004419291392, 0.09214302204782143, 0.1560935311135836, 0.18975697865244, 0.12469320354284719, 0.10431593604153022, 0.12296252258238383, 0.16987804847303778, 0.23519459908129647, 0.1334290238446556], [0.07010039742453955, 0.04252001897839364, 0.008975818800536217, 0.03671861719340086, 0.025445303072046954, 0.026142409806197975, 0.03649335681984667, 0.1047942131117452, 0.010302340979251312, 0.0594786574220052, 0.052869502105750144, 0.07438823726261035, 0.06426505351555534, 0.05816993936605286, 0.14513377624098212, 0.4108589206589386, 20.51501177251339, 54.693011194467545, 35.7837438583374, 24.947819709777832, 32.487565129995346, 46.617851704359055, 50.20935818552971, 60.758739709854126, 50.54917775094509, 53.012068793177605, 43.88226069509983, 1.14226003177464, 0.4765901091741398, 1.055120851378888, 0.2567286224802956, 10.414344370365143, 64.05197739601135, 66.02349400520325, 57.32680186629295, 50.414026603102684, 51.90874099731445, 53.91355901956558, 55.71484096348286, 56.596762239933014, 57.2524930536747, 56.86613358557224, 56.94989249110222, 55.81814602017403, 57.920463010668755, 58.75768728554249, 49.761977791786194, 47.373395562171936, 41.31849266588688, 41.989076882600784, 40.77243156731129, 41.06604941189289, 39.51082706451416, 41.98971524834633, 39.24636885523796, 42.57868744432926, 40.93935281038284, 42.537649646401405, 46.543797478079796, 47.952408492565155, 45.71991428732872, 43.75623665750027, 41.605388671159744, 40.200326666235924, 40.80027647316456, 38.35181325674057, 37.866024523973465, 42.28085182607174, 39.08897750079632, 39.94381383061409, 40.8000522851944, 45.22421568632126, 45.260435342788696, 47.81780071556568, 51.16365037858486, 42.53246292471886, 40.96354231238365, 40.75034335255623, 40.506195053458214, 38.78688611090183, 38.677820563316345, 36.719641238451004, 37.48512916266918, 36.9708913564682, 36.484141275286674, 38.41800570487976, 35.87650828063488, 37.29525715112686, 39.30090352892876, 37.66909249126911, 38.215491771698, 38.343704491853714, 37.94368475675583, 35.923667550086975, 36.40154890716076, 37.447598576545715, 37.98263646662235, 39.968687295913696, 40.536886006593704, 41.07872173190117, 40.709985718131065, 40.05496546626091, 41.14913195371628, 40.63933230936527, 46.74069531261921, 49.13447946310043, 45.27902014553547, 43.84557746350765, 41.496577709913254, 40.726784616708755, 37.46549181640148, 37.75755554437637, 37.57768839597702, 37.185515239834785, 36.823641657829285, 37.68000930547714, 37.98849955201149, 37.8822610527277, 38.60698476433754, 40.43079189956188, 40.961657613515854, 40.54089859127998, 39.509683325886726, 39.58201624453068, 38.57764273881912, 36.79610453546047, 36.35389566421509, 38.05236652493477, 37.023659124970436, 38.273799642920494, 37.07723245024681, 37.31572285294533, 39.07315894961357, 38.67063894867897, 38.50738450884819, 38.808206766843796, 46.54681831598282, 52.67098009586334, 53.478619158267975, 52.70878426730633, 51.69154465198517, 51.636284217238426, 55.437064468860626, 53.761703968048096, 52.20271982252598, 47.56993241608143, 52.159162759780884, 52.56338506937027, 57.8877429664135, 11.25612935051322, 0.31037574692163616, 0.48036066466011107, 0.23808490805095062, 6.5775249525904655, 57.96870142221451, 49.9455763399601, 55.25949239730835, 52.41499923169613, 47.92150855064392, 36.24067693948746, 29.01866476982832, 38.53899121284485, 44.88268241286278, 2.468786188401282, 0.20720990229165182, 0.02750339361227816, 0.011649449406831991, 0.09327740961452946, 0.0634929676016327, 0.026568827452138066, 0.04056283083627932, 0.058327875813120045, 0.06628890507272445, 0.08099643891910091, 0.03146027083857916, 0.032319451493094675, 0.07789864772348665, 0.043283210252411664, 0.018976391402247828, 0.047322378668468446, 0.03468858354608528, 0.012908969565614825, 0.02334298795176437, 0.06339783169096336, 0.015191023576335283, 0.05038877701736055, 0.036561278175213374, 0.06862603200715967, 0.04555292420263868, 0.0843684611027129, 0.14493274327833205, 0.4030039405915886, 28.36743101477623, 63.01289275288582, 28.85639637708664, 28.155180104076862, 52.607010528445244, 50.09454734623432, 55.11826917529106, 63.88439118862152, 56.39573782682419, 57.44668163359165, 50.53088553249836, 0.8141314296517521, 1.3514479505829513, 1.015543481335044, 0.18933983228635043, 11.230617519468069, 65.74173912405968, 66.27083793282509, 60.8702789247036, 54.04731944203377, 53.56517851352692, 56.803733333945274, 59.54571560025215, 58.52898895740509, 58.519964441657066, 59.57269035279751, 57.833827659487724, 58.1703832000494, 60.064938738942146, 59.45414051413536, 54.066208228468895, 49.08064775168896, 45.769672617316246, 42.31090821325779, 42.84113176167011, 43.23715791106224, 41.55932754278183, 44.38788056373596, 42.00712971389294, 44.089835956692696, 42.78745964169502, 45.67968584597111, 49.642337411642075, 50.320764407515526, 47.843589931726456, 47.19738520681858, 44.19919788837433, 42.42481470108032, 41.38854570686817, 40.10415382683277, 40.749070420861244, 43.87599103152752, 42.38472305238247, 41.721084862947464, 44.59668695926666, 46.713937148451805, 48.94834265112877, 50.46821929514408, 53.164056837558746, 43.034434989094734, 40.45642152428627, 42.95852266252041, 43.85782800614834, 40.67860320210457, 39.16425906121731, 40.28978906571865, 39.00870680809021, 40.35316586494446, 40.38636088371277, 40.16721524298191, 39.56192672252655, 39.76687252521515, 39.880585223436356, 39.34641748666763, 40.573949217796326, 40.27488246560097, 38.95686998963356, 37.25286662578583, 38.822767585515976, 39.0347658097744, 40.072205141186714, 41.26390099525452, 43.16014364361763, 42.65250988304615, 39.53713305294514, 40.80692231655121, 40.88848114013672, 41.01499155163765, 48.847906440496445, 52.62616530060768, 48.41607481241226, 46.339208856225014, 43.253428637981415, 42.851011231541634, 40.24111367762089, 39.16610196232796, 38.41851107776165, 39.2709269374609, 39.36295799911022, 39.56297926604748, 38.60613740980625, 39.556211829185486, 39.63358707726002, 40.800702050328255, 43.50954629480839, 41.90320149064064, 41.80924393236637, 41.6909334808588, 41.26869633793831, 38.87426622211933, 38.83605547249317, 39.12436880171299, 38.80911871790886, 40.237997844815254, 39.476891085505486, 40.485049188137054, 41.08965754508972, 39.41926717758179, 39.98878441751003, 41.84309631586075, 49.29765410721302, 53.842662423849106, 55.84860138595104, 54.669334664940834, 52.54691295325756, 54.35464695096016, 56.53688125312328, 57.73412860929966, 54.2598382383585, 52.073678746819496, 55.2037949860096, 56.62585347890854, 60.45450143516064, 13.258027229458094, 0.37735285295639187, 1.079201940447092, 0.07858422890421934, 8.416467625647783, 62.09076203405857, 57.06039056181908, 60.246466398239136, 59.28778164088726, 51.35969325900078, 48.48231665790081, 33.19247670471668, 36.98902778327465, 55.601690635085106, 3.9645621506497264, 0.2408184457453899, 0.0678501908259932, 0.04680468984588515, 0.0597538457805058, 0.03603099881729577, 0.0638203883136157, 0.046609894634457305, 0.04496998946706299, 0.07663248441531323, 0.04075604898389429, 0.03555607996531762, 0.036365685155033134, 0.25669771945104003, 0.2666908863466233, 0.08721614110982046, 0.17754769942257553, 0.14315930719021708, 0.06737139425240457, 0.1365005801199004, 0.23582094203447923, 0.08566498567233793, 0.14299983449745923, 0.1359926097211428, 0.15206926502287388, 0.17939949146239087, 0.18427933508064598, 0.2942275337409228, 0.737676682183519, 32.55492031574249, 70.8309580385685, 46.39873646199703, 34.139796271920204, 47.40504406392574, 57.49010570347309, 63.163607865571976, 70.12535870075226, 60.081118270754814, 62.61453352868557, 55.617030411958694, 1.1042044800706208, 2.75672547519207, 1.420565766748041, 0.29105517896823585, 14.146205820143223, 67.00441896915436, 68.98839890956879, 62.39767536520958, 55.324978083372116, 57.038017362356186, 58.51523369550705, 61.608583107590675, 60.65870627760887, 61.389787048101425, 63.02111931145191, 61.69065110385418, 59.89348813891411, 62.75379605591297, 63.28108236193657, 54.36701908707619, 52.21962511539459, 46.815372705459595, 45.50202637910843, 45.298885479569435, 46.20979160070419, 44.2609141767025, 47.398158833384514, 45.29066652059555, 47.238206416368484, 46.00934475660324, 48.14196512103081, 51.33344806730747, 53.14419150352478, 50.24744734168053, 49.2555295675993, 46.44223652780056, 45.734710693359375, 44.240592867136, 42.38232158124447, 42.32211001217365, 47.968702018260956, 45.20343840122223, 46.02806635200977, 45.399207696318626, 49.94303047657013, 51.59288674592972, 51.562055200338364, 54.753826931118965, 44.857649356126785, 42.16284915804863, 45.377700850367546, 46.78578369319439, 43.56994405388832, 43.040944039821625, 42.49585188925266, 40.43138086795807, 41.70663423836231, 41.291023939847946, 41.82321958243847, 41.13291822373867, 44.04057539999485, 43.87096010148525, 42.54615359008312, 44.158232286572456, 42.76316374540329, 41.941784620285034, 39.12582412362099, 40.678933784365654, 41.37844204902649, 42.86114528775215, 42.966965809464455, 44.888621494174004, 43.639123141765594, 42.33336120843887, 40.7299118489027, 41.954494938254356, 40.51811121404171, 47.9310954362154, 53.123984187841415, 49.1263896971941, 48.7318454682827, 45.41914142668247, 43.712159022688866, 41.18730470538139, 42.25325770676136, 41.06784671545029, 41.399078741669655, 40.78544966876507, 40.994818434119225, 40.89919276535511, 42.03147120773792, 42.58518509566784, 42.14491792023182, 46.54031686484814, 44.51461136341095, 44.28418792784214, 44.0655704587698, 43.980622217059135, 40.86233474314213, 40.46003133058548, 41.467543467879295, 41.6476272046566, 43.38998191058636, 41.598203256726265, 42.83190965652466, 44.00051034986973, 41.950995326042175, 43.01908761262894, 43.16689968109131, 51.219537779688835, 56.476384699344635, 59.03418704867363, 55.799561217427254, 54.21892963349819, 54.267768412828445, 59.51006971299648, 58.96237850189209, 56.769595965743065, 54.93142560124397, 57.46387951076031, 57.48596392571926, 62.95777291059494, 14.466287344694138, 0.36396510258782655, 2.3299577878788114, 0.6517396029084921, 9.244775678962469, 67.86318808794022, 60.13987451791763, 65.8653312921524, 63.078807815909386, 59.07245859503746, 50.78549467027187, 39.957546293735504, 47.678439393639565, 67.16299206018448, 5.747667057439685, 0.3918702411465347, 0.2774494152981788, 0.16180478793103248, 0.22681080910842866, 0.12537335220258683, 0.13042932230746374, 0.19517188105965033, 0.16082656307844445, 0.16024264128645882, 0.10107676571351476, 0.0771318755869288, 0.17209099925821647], [0.02765541514236247, 0.05221563660597894, 0.044129696470918134, 0.09353331697639078, 0.0400991926289862, 0.07112767823855393, 0.03527521788782906, 0.0008953489896157407, 0.028529425762826577, 0.005165733746252954, 0.03180148807587102, 0.035652607402880676, 0.041123820265056565, 0.05276339354168158, 0.19084140483755618, 0.2402126751258038, 1.4287296286784112, 37.564202919602394, 45.96691243350506, 21.88802819699049, 22.27868903428316, 46.947335824370384, 64.50811251997948, 58.64520572125912, 51.921759098768234, 51.12804248929024, 49.13508743047714, 2.7089067036285996, 0.9162403817754239, 0.9002975060138851, 0.07799115643138066, 7.5007951352745295, 63.02022635936737, 65.91594457626343, 59.2025788128376, 51.326699629426, 44.71312031149864, 47.4128944426775, 45.30956670641899, 48.849927932024, 51.05647712945938, 52.3328248411417, 54.6060224622488, 53.29951196908951, 50.62158666551113, 47.739665508270264, 44.75847467780113, 40.60154713690281, 40.905036851763725, 41.79697439074516, 41.26282565295696, 42.05768220126629, 40.244670286774635, 40.26375286281109, 40.1347041875124, 39.26923602819443, 42.428109124302864, 39.72340665757656, 44.28616762161255, 43.76583494246006, 47.13713563978672, 43.46934825181961, 42.3728296905756, 39.85735327005386, 39.840143993496895, 37.92188912630081, 40.53028576076031, 40.30737452208996, 39.273332208395004, 43.36996838450432, 43.51425044238567, 43.081522062420845, 45.23696020245552, 48.984535709023476, 49.54612277448177, 45.83530269563198, 43.44947151839733, 41.67811296880245, 40.83635553717613, 37.74405486881733, 39.81303244829178, 38.11368763446808, 37.45397463440895, 38.299816846847534, 37.27065347135067, 37.22441375255585, 35.79469107091427, 37.72543966770172, 37.9300282895565, 38.07752497494221, 36.862684562802315, 39.21215549111366, 36.3034001737833, 36.64260417222977, 34.76673223078251, 37.70572632551193, 36.72363482415676, 36.2070981413126, 38.25540862977505, 38.82415071129799, 40.96117123961449, 42.470951825380325, 44.6793819218874, 43.129524886608124, 48.01735460758209, 51.634464114904404, 47.43111826479435, 43.3222733438015, 40.480641424655914, 41.7313177138567, 37.79281385242939, 37.98676684498787, 38.80278825759888, 36.14162005484104, 36.931115090847015, 36.88741363584995, 37.106023505330086, 37.58478261530399, 37.408787459135056, 39.398007318377495, 39.80743534862995, 37.62750752270222, 37.01798602938652, 39.00393046438694, 36.02256864309311, 38.780920431017876, 35.94587355852127, 34.65777687728405, 36.79219454526901, 35.41818827390671, 37.63525530695915, 38.08915235102177, 36.60057842731476, 38.138990476727486, 38.94521601498127, 38.67538869380951, 40.085086449980736, 47.905743196606636, 50.85470415651798, 53.81596125662327, 53.34850654006004, 53.363720923662186, 52.610202357172966, 46.333550959825516, 44.76615786552429, 46.04654476046562, 54.17245052754879, 55.172108486294746, 60.22860735654831, 18.254520669579506, 0.6142987869679928, 0.9576944948639721, 0.05919147966778837, 7.615828737616539, 57.283499389886856, 52.046529203653336, 47.27464646100998, 50.14322653412819, 43.22455398738384, 34.53238360583782, 23.33710514008999, 40.597059577703476, 20.455514565110207, 0.13998468144563958, 0.050739133803290315, 0.05051245592767373, 0.01987352363357786, 0.03546923013345804, 0.02146195158275077, 0.0388187503995141, 0.04806397344509605, 0.05504644759639632, 0.016699723528290633, 0.023527192715846468, 0.06445712875574827, 0.03938417044992093, 0.045695872977375984, 0.08607928961282596, 0.04405240179039538, 0.029672143937204964, 0.0827632995788008, 0.014328873403428588, 0.05606210637779441, 0.050572825930430554, 0.047420115806744434, 0.0716901000123471, 0.1063684790278785, 0.03910894869477488, 0.03500307233480271, 0.06312447643722408, 0.14033127925358713, 0.28781502158381045, 3.9590346347540617, 49.03008006513119, 47.534256130456924, 19.387097395956516, 35.58747299015522, 52.98019230365753, 65.07001876831055, 64.8546539247036, 57.42671750485897, 57.8915199637413, 53.693478628993034, 2.4145222501829267, 1.5600149589590728, 1.1498593864962459, 0.2954419841989875, 9.23748767003417, 64.34428051114082, 68.34798887372017, 62.34723687171936, 54.9268202483654, 48.176007494330406, 48.766435012221336, 48.055618554353714, 51.71061962842941, 53.29974755644798, 54.947308748960495, 57.28325240314007, 58.14489796757698, 53.73279131948948, 50.06140552461147, 47.08173081278801, 42.5430453568697, 41.82613402605057, 42.60854244232178, 42.45182365179062, 44.93280552327633, 42.45487488806248, 42.07263819873333, 44.06867489218712, 41.427429020404816, 44.07269507646561, 43.07095102965832, 45.19189082086086, 47.32619069516659, 48.88871245086193, 45.998621731996536, 44.593559727072716, 41.53766870498657, 41.350954324007034, 40.88567689061165, 41.431312412023544, 42.056230679154396, 41.66512906551361, 44.411997869610786, 45.69150701165199, 45.197791904211044, 46.74392133951187, 50.80806165933609, 50.5734508484602, 48.022081553936005, 45.43591372668743, 44.45243149995804, 43.513197898864746, 41.088099628686905, 40.20644813776016, 41.36562153697014, 39.515668004751205, 39.58648480474949, 38.88537682592869, 39.61615741252899, 38.2469616830349, 38.83141212165356, 39.92315053939819, 41.35283902287483, 37.43191301822662, 40.50136171281338, 37.80749626457691, 38.893246203660965, 38.79230082035065, 37.93066665530205, 38.17919231951237, 39.05977226793766, 40.38813918828964, 41.82715617120266, 42.28543058037758, 42.44241155683994, 44.85686659812927, 42.490117996931076, 48.150704652071, 54.20501857995987, 49.82856161892414, 46.35537698864937, 43.51379446685314, 43.36014211177826, 40.721518099308014, 39.32747170329094, 40.26762865483761, 38.94062586128712, 38.91149282455444, 39.34554733335972, 39.541297629475594, 39.928580448031425, 40.819533839821815, 39.597732201218605, 41.1856821924448, 39.999283254146576, 39.67192701995373, 40.158471912145615, 37.674788385629654, 40.3592911362648, 37.881227508187294, 36.40105113387108, 39.328197464346886, 37.87379890680313, 41.09390951693058, 39.975469931960106, 37.493192330002785, 39.16967757046223, 39.42919984459877, 40.908783450722694, 42.36452713608742, 49.570794850587845, 53.78823794424534, 55.568932592868805, 56.52395814657211, 56.54369428753853, 55.76796591281891, 49.30841512978077, 47.12758295238018, 49.986306354403496, 55.67862510681152, 57.54867196083069, 62.011745274066925, 20.452972501516342, 0.7821815565694124, 1.164965950883925, 0.13995587127283216, 8.071842268109322, 63.541755974292755, 57.91035175323486, 54.29543472826481, 57.10981830954552, 49.38507601618767, 50.79372122883797, 20.285390093922615, 43.923321291804314, 27.05979198217392, 0.23483548866352066, 0.03950825011997949, 0.0554195957374759, 0.020326385856606066, 0.06431710775359534, 0.020778439138666727, 0.011523431803652784, 0.050161167746409774, 0.06991917980485596, 0.003739376238627301, 0.026018415483122226, 0.06533185369335115, 0.021047026093583554, 0.16209406225243583, 0.15189903118880466, 0.10192782356170937, 0.25884041853714734, 0.12319163099164143, 0.2344280792749487, 0.09147039876552299, 0.14393915596883744, 0.18599662027554587, 0.1283781003439799, 0.23097572702681646, 0.13802661385852844, 0.1490219621337019, 0.22652539395494387, 0.3676788689335808, 0.3896181791787967, 3.7721822736784816, 58.09592619538307, 59.028042778372765, 28.585845194756985, 31.63255400955677, 59.991131499409676, 72.97276630997658, 69.68382239341736, 62.12652191519737, 60.97981184720993, 60.81096790730953, 3.426258573308587, 2.6044020988047123, 1.8844235013239086, 0.4062728042481467, 10.266764089465141, 66.41015365719795, 71.37049108743668, 64.13995027542114, 58.09919022023678, 49.86856207251549, 52.72721327841282, 49.82001967728138, 53.91464576125145, 56.835119649767876, 56.736598536372185, 58.38756054639816, 58.531101644039154, 54.662286043167114, 52.58286662399769, 49.12860497832298, 43.55868525803089, 43.90969142317772, 46.62334240972996, 44.72290478646755, 46.69769302010536, 44.18602019548416, 45.36154791712761, 45.82003131508827, 43.64795386791229, 48.18923458456993, 44.61692087352276, 48.50685574114323, 49.16568338871002, 52.12249092757702, 47.737944200634956, 46.71009175479412, 44.55163277685642, 44.356532245874405, 42.435108348727226, 43.76616172492504, 44.917469546198845, 45.61606585979462, 46.35187737643719, 49.406571462750435, 49.35032308101654, 49.90952007472515, 52.61995643377304, 52.65731982886791, 48.88875424861908, 47.01081141829491, 47.489726319909096, 45.628377199172974, 41.997550427913666, 44.00142230093479, 44.30083103477955, 41.98585465550423, 42.1816049516201, 42.18344785273075, 41.99216231703758, 40.65486587584019, 42.931285724043846, 43.211908265948296, 42.97159396111965, 40.11149123311043, 44.58683788776398, 40.921843349933624, 41.35912388563156, 40.56220404803753, 39.971267357468605, 41.063343957066536, 39.938262328505516, 43.552548587322235, 43.08263160288334, 45.61920069158077, 45.188539400696754, 47.213990315794945, 44.415907859802246, 50.47932609915733, 56.478546783328056, 50.90028651058674, 48.746702671051025, 44.717049300670624, 45.85729971528053, 42.74004578590393, 41.46052144467831, 44.034138545393944, 39.2577188462019, 40.99159620702267, 41.06514126062393, 41.932395324110985, 42.313708662986755, 43.77322554588318, 42.16751150786877, 44.05629135668278, 41.017560213804245, 42.33560688793659, 44.14225794374943, 39.574450850486755, 42.48465768992901, 40.7887326925993, 38.47711153328419, 40.91602586209774, 38.33266228437424, 43.320065662264824, 41.772921681404114, 38.775422126054764, 39.373783618211746, 42.81500816345215, 43.03718224167824, 46.406792029738426, 51.56606398522854, 56.10761068761349, 57.86797642707825, 58.76632422208786, 56.87959626317024, 58.39975789189339, 51.244061663746834, 49.913126081228256, 51.768881902098656, 57.761574536561966, 60.21053932607174, 64.3368025124073, 23.372614234685898, 0.6035483325831592, 2.129134051501751, 0.3828431130386889, 9.359308183193207, 68.59243735671043, 62.4561770260334, 59.26625199615955, 65.04157349467278, 55.68976230919361, 49.23901565372944, 32.02362522482872, 55.89824952185154, 35.926581993699074, 0.24724391580093652, 0.1102628544322215, 0.12320821057073772, 0.07009810418821871, 0.10778749507153407, 0.11555051562027074, 0.1127703339443542, 0.15220783883705735, 0.15162154217250645, 0.11280141508905217, 0.13859357015462592, 0.19046264234930277, 0.12558291986351833], [0.047029757261043414, 0.03344008706335444, 0.0021212078809185186, 0.03611245323554613, 0.04235560729284771, 0.006554287874678266, 0.017570069794601295, 0.020844184145971667, 0.048443878840771504, 0.046329084507306106, 0.05378182795539033, 0.04516780893027317, 0.059986260457662866, 0.027875291234522592, 0.06899197018356062, 0.2735952049260959, 0.17159266193630174, 17.460292987525463, 55.145840495824814, 38.25959600508213, 28.153954669833183, 34.1119247674942, 57.18777112662792, 60.522312596440315, 55.01920469105244, 48.424704149365425, 48.236291259527206, 1.0072218091227114, 0.6625059095676988, 0.8639656961895525, 0.0951004508533515, 4.459869135171175, 58.06118845939636, 65.7872910797596, 60.87480828166008, 56.42276577651501, 47.92683586478233, 44.884909093379974, 44.58576254546642, 43.7731609493494, 43.7343992292881, 42.84940391778946, 43.32532458007336, 42.18864217400551, 42.47918978333473, 40.16272388398647, 43.36947441101074, 41.37508302927017, 40.97295060753822, 39.93297681212425, 40.75434073805809, 41.98907308280468, 41.00564785301685, 40.19973009824753, 39.01273839175701, 39.447476863861084, 40.42509600520134, 42.62608990073204, 42.67093509435654, 44.014485999941826, 45.46413101255894, 42.65635907649994, 40.03625527024269, 38.340949639678, 40.11183701455593, 38.81074123084545, 39.90886710584164, 39.54544700682163, 40.08792109787464, 44.79072354733944, 45.19414409995079, 42.639221996068954, 43.41213472187519, 46.18465214967728, 46.47610791027546, 44.26902674138546, 40.48120379447937, 39.71688240766525, 39.41594995558262, 37.28132709860802, 38.31025868654251, 37.85896070301533, 36.76066003739834, 36.66725344955921, 35.8298771828413, 37.36168518662453, 38.17371681332588, 36.449000760912895, 38.39906372129917, 38.77582110464573, 39.64930683374405, 37.19308063387871, 36.71657860279083, 36.088320314884186, 37.083255127072334, 36.977233216166496, 35.89003935456276, 35.831826478242874, 37.44779996573925, 36.68922767043114, 37.787330746650696, 38.92604984343052, 41.624478846788406, 43.777716904878616, 47.3388896137476, 51.21995575726032, 46.51513181626797, 42.71451875567436, 39.59946110844612, 42.756350710988045, 41.513642594218254, 38.43704268336296, 38.491045385599136, 40.203184112906456, 37.08962358534336, 37.36819423735142, 37.49264895915985, 37.764193788170815, 37.60121673345566, 37.959879487752914, 37.42462880909443, 37.87483625113964, 35.82853585481644, 36.665456146001816, 35.447469502687454, 38.2492795586586, 36.695314943790436, 36.38831041753292, 37.08673194050789, 35.71049898862839, 36.7502485960722, 36.92343570291996, 37.68408268690109, 37.22751058638096, 37.35595889389515, 38.66107486188412, 39.086918011307716, 38.355863839387894, 41.628791615366936, 44.67171773314476, 45.41206620633602, 45.63488245010376, 42.00942479074001, 41.26726381480694, 44.52653132379055, 46.016792356967926, 53.89253094792366, 52.099369168281555, 61.33724346756935, 18.424686938524246, 0.30791986151598394, 0.48582322779111564, 0.06193321809405461, 6.953326687216759, 58.37874501943588, 52.24251888692379, 54.83248271048069, 53.207024931907654, 35.56380406022072, 27.54369981586933, 33.94669063389301, 42.21391461789608, 3.3876944426447153, 0.324775519547984, 0.04444607773621101, 0.12928565789479762, 0.08877176427631639, 0.0685046314902138, 0.0785389133670833, 0.11617247990216129, 0.04592247663822491, 0.08829735379549675, 0.05318307434208691, 0.09012208713102154, 0.03596613139961846, 0.046020109875826165, 0.0222284621122526, 0.037558372132480145, 0.05383301388064865, 0.09013022106955759, 0.03681025016703643, 0.047151963008218445, 0.05119441913848277, 0.02535822131903842, 0.028032854752382264, 0.05218477068410721, 0.031358080814243294, 0.031260365940397605, 0.018212129580206238, 0.08534758395398967, 0.02188837850553682, 0.28080033080186695, 0.32174981315620244, 24.50803890824318, 62.01128929853439, 29.66990802437067, 31.58331625163555, 47.32315465807915, 59.13103245198727, 64.04648289084435, 58.56829024851322, 55.545943826437, 53.60725745558739, 1.6052916669286788, 1.0059974435716867, 1.1741367587819695, 0.2789658901747316, 5.384505819529295, 58.53059247136116, 68.03992420434952, 62.92391672730446, 57.819301038980484, 49.91431161761284, 49.23987440764904, 46.56072936952114, 45.90607009828091, 44.215453416109085, 45.256662145256996, 46.053167805075645, 44.75358434021473, 43.871784657239914, 43.88899013400078, 44.74134519696236, 43.02384875714779, 43.93535904586315, 42.64343596994877, 42.98431947827339, 44.50228862464428, 43.109184578061104, 41.56423307955265, 41.96712166070938, 41.776257902383804, 42.68619887530804, 44.402984753251076, 44.27996635437012, 45.41531503200531, 48.18348929286003, 46.416979283094406, 42.47548118233681, 41.10144451260567, 42.01832391321659, 41.38955645263195, 41.50644578039646, 41.58458858728409, 41.96320787072182, 48.94280254840851, 46.184393763542175, 42.58577026426792, 45.12716509401798, 47.722251042723656, 47.31406934559345, 45.93841016292572, 44.83748383820057, 43.30540604889393, 39.90156389772892, 39.812325686216354, 39.17288839817047, 40.32468639314175, 39.17761154472828, 38.28596659004688, 38.740152418613434, 39.1947828233242, 40.755442678928375, 38.60815890133381, 40.81169106066227, 40.97913287580013, 41.22013874351978, 38.80653105676174, 39.34162974357605, 37.985923290252686, 38.682733699679375, 38.20140592753887, 38.052149936556816, 38.182938918471336, 40.3846699744463, 38.395894691348076, 40.02428591251373, 40.35346984863281, 42.851106226444244, 45.00895343720913, 51.04572370648384, 52.0453854650259, 45.99984146654606, 45.674993097782135, 42.050116807222366, 44.46597017347813, 43.65283660590649, 40.43493367731571, 40.34972704946995, 41.46201856434345, 39.468941912055016, 39.88553635776043, 39.70282696187496, 40.521040856838226, 39.50577333569527, 39.700334295630455, 41.14456459879875, 38.991672322154045, 38.901119381189346, 38.954267129302025, 37.51984789967537, 40.30396990478039, 40.044010654091835, 38.14583010971546, 38.39712202548981, 39.61637780070305, 39.32811766862869, 38.65750305354595, 40.051367059350014, 39.01151105761528, 39.40136253833771, 41.067200750112534, 40.37645101547241, 41.141642555594444, 43.07248994708061, 48.34009788930416, 47.450820207595825, 49.25190456211567, 46.30241543054581, 42.83100910484791, 46.512772142887115, 50.113766714930534, 56.44713766872883, 54.74718488752842, 62.452354431152344, 20.98931562155485, 0.5123626068234444, 0.5477533140219748, 0.23602872854098678, 7.087734024971724, 64.27722170948982, 55.926337614655495, 59.33062054216862, 55.95308057963848, 46.03107579052448, 38.45903970301151, 29.170842804014683, 53.06979149580002, 5.18204603344202, 0.5345894547645003, 0.09850931324763224, 0.05177520535653457, 0.03240737372834701, 0.041547675646143034, 0.0768614221306052, 0.08460471639409661, 0.03782004969252739, 0.023935253339004703, 0.026861270744120702, 0.06841843103757128, 0.021966853200865444, 0.024824509528116323, 0.13902987877372652, 0.16148973139934242, 0.14035639353096485, 0.13103239150950685, 0.18051992665277794, 0.14977826998801902, 0.0886326858017128, 0.14397773280506954, 0.1854990399442613, 0.14771753369132057, 0.10989857124513946, 0.14060409273952246, 0.09111719584325328, 0.1921148263500072, 0.17388107429724187, 0.44246194360312074, 0.4902048676740378, 31.03849958628416, 71.89005240797997, 46.98442183434963, 41.84454023838043, 46.96872107684612, 66.35267034173012, 68.55184033513069, 65.96905052661896, 60.52889384329319, 63.573928847908974, 1.9527650903910398, 1.934834683779627, 2.0881283143535256, 0.528639864642173, 5.630051018670201, 62.712553068995476, 70.08987620472908, 64.96555477380753, 61.83529794216156, 52.959597408771515, 51.585423946380615, 49.26392711699009, 46.817679181694984, 47.03735679388046, 48.35100330412388, 48.253458738327026, 47.45513677597046, 48.07299882173538, 45.93689784407616, 46.7980570346117, 46.36353135108948, 45.70025034248829, 44.69874948263168, 45.47732770442963, 48.16819131374359, 46.18057496845722, 43.99334013462067, 43.62925127148628, 43.64568918943405, 44.98009778559208, 48.71016763150692, 48.25753211975098, 47.39566616714001, 49.1992811858654, 49.138682037591934, 45.17325662076473, 43.49984921514988, 43.96913543343544, 43.842492029070854, 44.74128060042858, 44.43136163055897, 45.55810756981373, 49.71579886972904, 48.91979478299618, 46.67025089263916, 45.94995394349098, 49.88948754966259, 49.43641886115074, 48.38240101933479, 47.76451237499714, 44.82742577791214, 44.39462900161743, 40.83448603749275, 42.43183672428131, 42.182292714715004, 42.55294382572174, 40.05561523139477, 41.07550710439682, 42.60782428085804, 43.41619290411472, 40.30551262199879, 43.753808587789536, 43.76313328742981, 43.49538825452328, 41.944657266139984, 42.21449978649616, 39.899888187646866, 41.90602093935013, 41.51258245110512, 40.108101814985275, 40.004865154623985, 43.15048076212406, 40.31747058033943, 43.54515798389912, 42.08602488040924, 44.05899681150913, 47.411879897117615, 51.65834583342075, 53.37469093501568, 48.72591398656368, 46.59873493015766, 43.129251301288605, 47.57545351982117, 44.789450615644455, 42.60837525129318, 41.749674528837204, 43.22066679596901, 41.85753934085369, 41.61502495408058, 40.76018862426281, 41.737883761525154, 41.87259793281555, 41.71385005116463, 42.640962302684784, 41.25623680651188, 39.21633526682854, 41.752676367759705, 40.24184323847294, 43.57119798660278, 43.069028332829475, 41.13694980740547, 40.549767315387726, 39.99023213982582, 40.94820253551006, 40.79136975109577, 41.713394075632095, 40.52349932491779, 40.781304091215134, 42.10722774267197, 42.23951384425163, 42.191032245755196, 45.25184400379658, 50.83343669772148, 49.746611416339874, 51.23462677001953, 48.070240169763565, 45.35053610801697, 49.00923818349838, 54.1540215164423, 57.636375054717064, 55.71330964565277, 64.43365171551704, 24.72124546766281, 0.5096207570750266, 1.2155911093577743, 0.41824590240139514, 8.1745764054358, 70.90373173356056, 61.090640500187874, 64.98616486787796, 61.41375616192818, 46.16096422076225, 41.347568705677986, 42.24740222096443, 64.53211203217506, 9.189553242176771, 0.6530381238553673, 0.18987134360941127, 0.3723334410460666, 0.14347785181598738, 0.2967698051361367, 0.22510766924824566, 0.21887312410399318, 0.14386316004674882, 0.1703720516525209, 0.1611150210374035, 0.21741560543887317, 0.06956999932299368, 0.12319804314756766], [0.02631821345858043, 0.03686538060719613, 0.017820049251895398, 0.04449082181963604, 0.013437907491606893, 0.05384005686210003, 0.03546709645888768, 0.07274597577634268, 0.016144151777552906, 0.0886337025440298, 0.044353966077324, 0.05480623665789608, 0.024072519117908087, 0.06593324564164504, 0.0550378646585159, 0.16986127593554556, 0.13675348920514807, 1.8355701165273786, 43.62671680748463, 51.302726715803146, 29.299302510917187, 22.428490296006203, 45.5512223392725, 62.82838225364685, 53.92836682498455, 48.27061101794243, 51.70108214020729, 1.9298043474555016, 0.80179343232885, 0.5761901568621397, 0.25191721972078085, 1.1872291937470436, 48.53117063641548, 69.58945825695992, 62.02275328338146, 55.35356394946575, 49.18739162385464, 45.81953354179859, 43.47848676145077, 44.9178571254015, 43.49284999072552, 41.66427791118622, 41.42945051193237, 42.969025298953056, 42.29438289999962, 42.32908643782139, 41.30262091755867, 41.7958078533411, 41.13549068570137, 40.292201936244965, 40.72266563773155, 40.64774505794048, 39.77462410926819, 39.643025770783424, 37.940234541893005, 38.98041732609272, 40.19699424505234, 40.94138950109482, 41.26385539770126, 41.94940321147442, 44.53750513494015, 40.81978842616081, 39.155766516923904, 40.310972929000854, 38.02361346781254, 37.839596942067146, 39.619539231061935, 40.32738424837589, 40.08540943264961, 45.521857514977455, 44.37379091978073, 40.766332894563675, 43.202328979969025, 45.27902774512768, 45.52194871008396, 41.790906116366386, 40.63834436237812, 39.67315815389156, 38.9367500692606, 37.57760860025883, 37.60772958397865, 38.43419663608074, 39.92034628987312, 36.868627443909645, 38.207025825977325, 38.485873863101006, 37.29615770280361, 39.01644319295883, 36.523940339684486, 35.904562175273895, 38.7237448990345, 36.875231489539146, 38.59945736825466, 36.704001277685165, 37.475614473223686, 36.90535247325897, 36.424689665436745, 38.1770796328783, 37.648866176605225, 36.84901289641857, 34.549364894628525, 35.22787548601627, 36.73978015780449, 38.018818125128746, 42.0173055678606, 45.33858574926853, 47.18581102788448, 43.6751452088356, 40.52463546395302, 40.47363840043545, 44.28467430174351, 39.86101247370243, 38.28974358737469, 39.55568365752697, 37.130137011408806, 37.42871358990669, 38.608489483594894, 38.62277291715145, 37.10262268781662, 37.942472621798515, 39.58708897233009, 37.576757445931435, 36.17758132517338, 38.28739531338215, 37.44459293782711, 37.618802189826965, 36.95248134434223, 37.47961565852165, 37.687008529901505, 37.78169944882393, 38.0695416033268, 37.680628672242165, 37.17743307352066, 38.07036615908146, 39.03738386929035, 37.318781688809395, 38.97409066557884, 39.058738723397255, 38.69549721479416, 37.13405840098858, 39.31102238595486, 38.44040930271149, 41.10499732196331, 40.893075093626976, 44.67787340283394, 47.52535700798035, 54.464757442474365, 54.00981925427914, 60.02892807126045, 13.448542356491089, 0.684546270640567, 0.3170148516073823, 0.11726063909009099, 13.350527565926313, 65.6151831150055, 45.642862021923065, 60.73124438524246, 41.33520416915417, 31.213411800563335, 24.540612660348415, 34.396134316921234, 26.158415749669075, 0.8560684730764478, 0.04624023087671958, 0.052831255525234155, 0.06587253054021858, 0.10052738347440027, 0.013278701044328045, 0.10283820127369836, 0.013471432157530217, 0.021321299755072687, 0.06644880821113475, 0.05602998622634914, 0.05395927175413817, 0.04688971399446018, 0.031189939836622216, 0.050834670473705046, 0.05300096614519134, 0.012766001309501007, 0.052334584324853495, 0.03997636347776279, 0.06692925235256553, 0.02796090910123894, 0.059095705510117114, 0.028095822272007354, 0.11680280076689087, 0.04677965349401347, 0.03581702279916499, 0.019712514695129357, 0.02809729914588388, 0.043450453231344, 0.27656272694002837, 0.16931502555962652, 3.6148004187271, 53.411225974559784, 48.51426914334297, 22.842373587191105, 38.304285407066345, 53.90580743551254, 66.01121306419373, 59.20927785336971, 52.88475662469864, 56.928784623742104, 2.717537465505302, 0.3617203136673197, 1.0359089635312557, 0.24490301875630394, 1.3818838424049318, 51.17193393409252, 71.71579375863075, 63.74835468828678, 57.69067794084549, 52.186981067061424, 47.99603395164013, 45.681939125061035, 47.4850145727396, 45.50153620541096, 44.51774999499321, 43.27690377831459, 44.051606208086014, 43.31571489572525, 43.47203090786934, 42.892755791544914, 43.3147307485342, 42.71477714180946, 42.77718499302864, 42.493127435445786, 43.904181718826294, 40.08610859513283, 40.94820253551006, 39.563423842191696, 41.71779803931713, 43.438558503985405, 44.29837256669998, 44.66198645532131, 44.60965946316719, 48.01390439271927, 44.00736518204212, 41.79905287921429, 41.56302094459534, 40.601064562797546, 41.14729285240173, 41.72143444418907, 43.380976393818855, 42.25969456136227, 48.59074003994465, 46.68493710458279, 44.35105673968792, 46.33333437144756, 48.81892539560795, 48.23778837919235, 45.20893290638924, 42.226377949118614, 40.64383506774902, 41.086967289447784, 39.32691693305969, 40.96230737864971, 39.28894177079201, 39.72176894545555, 39.37585070729256, 38.404280841350555, 39.23108607530594, 39.926984533667564, 39.60089363157749, 37.700866386294365, 38.58047358691692, 41.43063224852085, 38.85678716003895, 40.514900386333466, 38.86717200279236, 39.58987422287464, 39.1049974411726, 39.57871802151203, 38.84419843554497, 40.03150172531605, 39.254116639494896, 37.32078418135643, 38.3291170746088, 38.19412171840668, 40.15215665102005, 45.83328120410442, 50.48694469034672, 49.077448323369026, 43.93075369298458, 43.57191614806652, 42.55229406058788, 45.63892163336277, 42.16347232460976, 40.54898835718632, 41.39994889497757, 38.46431002020836, 38.05102899670601, 40.99262595176697, 40.88946148753166, 40.21114468574524, 39.76822905242443, 39.7673474997282, 39.272150471806526, 39.486006796360016, 42.008740827441216, 39.776524007320404, 40.579067543148994, 39.29328113794327, 38.84400464594364, 40.42220056056976, 39.587484151124954, 41.21161200106144, 38.812561333179474, 39.86881725490093, 40.40874168276787, 41.56370110809803, 38.889731392264366, 41.085800752043724, 40.235527977347374, 41.17839798331261, 38.63874725997448, 41.59207038581371, 40.635133534669876, 42.719785273075104, 43.27401213347912, 48.51126730442047, 50.192692279815674, 57.86771044135094, 54.721137285232544, 62.03199818730354, 14.294947888702154, 0.7594865025021136, 0.3501857060473412, 0.08409267902607098, 13.895675763487816, 70.86790725588799, 51.085936948657036, 66.54560878872871, 45.27385622262955, 43.21373216807842, 20.996480137109756, 35.539774149656296, 35.687293633818626, 1.2308003869839013, 0.06071922405681107, 0.06818178982939571, 0.05204099441471044, 0.05238880192337092, 0.04527360950305592, 0.09323976046289317, 0.032921618985710666, 0.016664143113302998, 0.04643619125999976, 0.04418298267410137, 0.034079681063303724, 0.04814061503566336, 0.012942497014591936, 0.10668728340533562, 0.2043966282508336, 0.1823679485823959, 0.22337611997500062, 0.10157559285289608, 0.17393925867509097, 0.1343912776792422, 0.22586612933082506, 0.11647988489130512, 0.199309473100584, 0.1119550401926972, 0.10165110637899488, 0.11538825245224871, 0.15174781117821112, 0.148973336617928, 0.3113034018315375, 0.291641594376415, 4.1254690289497375, 65.67220285534859, 63.638278394937515, 36.62754938006401, 35.71907892823219, 56.2503120303154, 73.33870947360992, 63.982555121183395, 57.61657811701298, 65.35966962575912, 2.8325157333165407, 1.4976614923216403, 2.2149163484573364, 0.7563330279663205, 1.597113199532032, 53.87779913842678, 74.51367482542992, 66.42985180020332, 59.530402421951294, 55.07015235722065, 51.25625520944595, 48.20496954023838, 50.71563541889191, 46.95108242332935, 45.08801579475403, 46.31210871040821, 46.545879766345024, 46.52821831405163, 47.26273410022259, 45.29856249690056, 45.89618682861328, 45.02996250987053, 44.27064165472984, 44.20786902308464, 46.23074367642403, 44.28871348500252, 44.521948769688606, 41.0783189535141, 44.51253667473793, 44.80696387588978, 46.20771311223507, 45.62723346054554, 47.57581830024719, 52.04168066382408, 45.11427238583565, 42.73291356861591, 45.94190217554569, 43.34435395896435, 43.18921208381653, 43.121036142110825, 45.70593103766441, 44.40164342522621, 49.51592579483986, 49.64902885258198, 46.06169834733009, 47.922146916389465, 50.889856070280075, 50.192076712846756, 48.19347135722637, 44.74126540124416, 43.640597462654114, 42.944281026721, 42.021200358867645, 42.42636501789093, 42.25763127207756, 43.920133262872696, 41.87981374561787, 41.731188520789146, 41.997497230768204, 41.30605973303318, 43.17584440112114, 40.49946941435337, 39.93465252220631, 44.65979017317295, 41.40530280768871, 42.95565761625767, 41.94119565188885, 42.252797931432724, 42.424301728606224, 41.922474056482315, 42.282056361436844, 43.27958643436432, 41.38188846409321, 39.21956889331341, 40.23099862039089, 41.02134861052036, 42.596215903759, 46.62199728190899, 50.07946975529194, 51.97522982954979, 46.364789083600044, 45.8526411652565, 43.94231267273426, 46.1883569508791, 45.79127065837383, 41.94060668349266, 42.23643220961094, 40.18755555152893, 40.734912380576134, 42.70077109336853, 42.96782076358795, 42.12408363819122, 41.56589739024639, 42.92842447757721, 43.17832186818123, 40.49337074160576, 43.1373942643404, 41.40609696507454, 42.78794601559639, 41.764030158519745, 42.56284989416599, 41.5120542794466, 42.24543772637844, 42.44850642979145, 40.376865193247795, 41.079842671751976, 42.651776522397995, 43.52210842072964, 40.97244903445244, 42.540685683488846, 42.49489054083824, 42.313887253403664, 41.64045698940754, 42.81538434326649, 42.200345546007156, 45.6365467607975, 46.172963976860046, 50.24226061999798, 53.30394633114338, 59.57012169063091, 58.60970042645931, 63.32359068095684, 17.27094154804945, 1.1217487324029207, 0.9861760446801782, 0.2401617489522323, 15.769024640321732, 77.04978033900261, 57.97193504869938, 70.0696536898613, 53.5635332018137, 45.559270307421684, 33.844449520111084, 45.95435030758381, 46.18299923837185, 1.0982094705104828, 0.1572560757631436, 0.11681832649628632, 0.2002235467080027, 0.18328506499528885, 0.1054523051425349, 0.2402034873375669, 0.11163107788888738, 0.07617463867063634, 0.13989587605465204, 0.21217319299466908, 0.12304836680414155, 0.13973900087876245, 0.12327109274338], [0.07367249520029873, 0.0737886932620313, 0.07224111497635022, 0.06030012955307029, 0.03259649522078689, 0.026256962155457586, 0.00812662745374837, 0.04290586897695903, 0.06096953191445209, 0.08615839513367973, 0.020093086168344598, 0.04482461386942305, 0.08813278254820034, 0.04711783905804623, 0.028134178319305647, 0.011208476389583666, 0.2990322868572548, 0.2646211552200839, 17.19577018171549, 55.65638490021229, 35.82942120730877, 17.89094477891922, 27.612795308232307, 54.05461125075817, 57.0732718706131, 46.016568168997765, 51.08250953257084, 5.229553459212184, 0.37420864042360336, 0.37010987754911184, 0.7626121316570789, 0.5229294241871685, 29.233453944325447, 72.63922780752182, 61.5033895522356, 58.509287014603615, 52.616111040115356, 50.35361744463444, 44.70343843102455, 46.596713438630104, 42.99900949001312, 43.4493575245142, 40.30306555330753, 41.3171361386776, 41.13773636519909, 41.407605484128, 40.726089254021645, 42.73113526403904, 40.91386377811432, 40.57120196521282, 39.49417635798454, 41.40540920197964, 41.35269843041897, 40.36556079983711, 38.22010852396488, 37.987055629491806, 39.368175119161606, 40.410934165120125, 41.821707263588905, 42.510773688554764, 41.20894834399223, 41.3827358186245, 38.92142169177532, 38.848860785365105, 38.81602294743061, 39.68652203679085, 40.914589539170265, 42.15295448899269, 40.777496695518494, 47.05211900174618, 42.830328941345215, 41.70741319656372, 43.79467159509659, 43.30554284155369, 41.17482237517834, 40.3874172270298, 39.00524899363518, 39.17503908276558, 37.713291719555855, 38.17481875419617, 37.962075769901276, 37.848222479224205, 37.23841980099678, 36.427486315369606, 37.66592726111412, 35.15740066766739, 37.047704234719276, 38.33167053759098, 37.42525577545166, 38.46855439245701, 38.532394766807556, 38.10123570263386, 39.65814895927906, 38.04542809724808, 35.9466715157032, 37.01381765305996, 37.3791528493166, 36.763513684272766, 36.00029043853283, 38.02517518401146, 35.57679556310177, 37.749366983771324, 36.767799854278564, 36.67887702584267, 38.30044001340866, 40.29522277414799, 44.17596973478794, 43.22301127016544, 41.695299446582794, 41.328831911087036, 45.157909244298935, 40.676764100790024, 38.068717047572136, 38.52614410221577, 37.39458002150059, 37.851627096533775, 38.15638214349747, 39.006377533078194, 36.25248670578003, 37.73615509271622, 36.608842983841896, 35.909441113471985, 36.11716836690903, 38.03590960800648, 37.60344721376896, 35.40892817080021, 36.213474199175835, 37.257133796811104, 36.098651960492134, 36.821061596274376, 36.90585024654865, 38.58003281056881, 38.96356143057346, 38.91590818762779, 39.44868139922619, 37.75866508483887, 38.283542320132256, 36.915893107652664, 39.3574482947588, 38.53142201900482, 39.19020026922226, 40.93104645609856, 42.375972121953964, 46.549645364284515, 48.99085097014904, 51.61314345896244, 53.9969265460968, 55.70066012442112, 60.32568074762821, 5.024578683078289, 0.43716413725633174, 0.6743473210372031, 0.11419028509408236, 13.528493866324425, 61.093642339110374, 48.17640267312527, 57.98668585717678, 35.52394039928913, 31.042567268013954, 29.182380884885788, 47.29486517608166, 11.800596434623003, 0.4635047691408545, 0.00965298402661574, 0.040392263035755605, 0.027382284388295375, 0.031152049486991018, 0.046717331642867066, 0.024475599930156022, 0.026527799673203845, 0.018059176654787734, 0.06371005321852863, 0.012130076302128145, 0.04235537722706795, 0.016536996517970692, 0.08482010249281302, 0.01912646108394256, 0.04037086691823788, 0.007030077358649578, 0.01168019751276006, 0.017303189779340755, 0.04402629303513095, 0.020530879082798492, 0.0517169690283481, 0.023260162415681407, 0.06589019365492277, 0.032790403565741144, 0.046504984638886526, 0.09146883283392526, 0.029759645003650803, 0.02485831249941839, 0.053692718283855356, 0.3015474253334105, 0.19430471118539572, 24.55246042460203, 61.554379016160965, 31.086891889572144, 20.22785358130932, 43.47674645483494, 58.947076722979546, 63.47244769334793, 50.04514999687672, 56.85601092875004, 6.792544014751911, 0.5374837713316083, 0.3450385556789115, 0.910994466394186, 0.5665162322111428, 31.501690931618214, 72.76728853583336, 65.21239712834358, 60.59438332915306, 56.05797775089741, 52.8918394446373, 46.5371972322464, 48.156780526041985, 46.11205704510212, 44.14369806647301, 43.084136322140694, 44.34759132564068, 43.219086080789566, 43.80105145275593, 42.82049886882305, 43.59914168715477, 42.53441981971264, 42.74056255817413, 43.32260012626648, 42.99868270754814, 44.59519363939762, 43.23612816631794, 41.543432995676994, 40.00477395951748, 42.997649163007736, 44.4654306024313, 43.532652854919434, 45.33730901777744, 45.187407061457634, 42.426368817687035, 43.21256943047047, 42.356653958559036, 40.87920963764191, 41.277644857764244, 42.75400623679161, 43.081214278936386, 42.95492805540562, 47.73495376110077, 46.96483388543129, 42.0311938226223, 44.84584718942642, 45.620959997177124, 43.388754576444626, 41.8275361508131, 40.236052349209785, 41.437411084771156, 39.82765406370163, 40.19117675721645, 39.37643587589264, 39.51904222369194, 39.2450275272131, 38.78779426217079, 39.635068997740746, 38.51435713469982, 40.84543325006962, 41.23376861214638, 40.148843228816986, 40.69973386824131, 41.57527528703213, 40.50991125404835, 41.41753815114498, 39.5949849486351, 38.27120438218117, 40.05853347480297, 39.9258141964674, 39.17621701955795, 39.70579080283642, 39.579090401530266, 39.03961434960365, 40.62914505600929, 38.43276031315327, 40.63934750854969, 40.49608759582043, 42.81202532351017, 46.632378324866295, 45.560170859098434, 44.11462962627411, 43.1362771242857, 47.23030284047127, 43.30677777528763, 40.649025589227676, 40.334083288908005, 38.819457963109016, 39.42568123340607, 40.33520422875881, 40.89436702430248, 40.14293074607849, 38.6032647639513, 38.11705805361271, 37.88836732506752, 38.0230662971735, 38.1455185264349, 38.82588341832161, 38.195466846227646, 38.8447380065918, 38.38769473135471, 38.5281427949667, 39.24991026520729, 40.66488593816757, 39.560334607958794, 40.25945529341698, 39.92547981441021, 39.73891742527485, 40.09010598063469, 41.18982017040253, 39.92129623889923, 42.346972078084946, 38.4603164345026, 42.39039994776249, 43.468048721551895, 45.261172503232956, 47.609864473342896, 52.49663405120373, 52.51395732164383, 58.22674177587032, 57.70208112895489, 61.37185201048851, 5.71398138999939, 0.5602487653959543, 0.81014912459068, 0.10919166074017994, 15.548905301839113, 65.97631573677063, 53.13458561897278, 62.60650835931301, 43.62764775753021, 42.13233299553394, 24.312410205602646, 54.238981157541275, 15.398888401687145, 0.517911734059453, 0.0129271011610399, 0.07916353453765623, 0.06862056237878278, 0.05713443926651962, 0.03443135887209792, 0.03160594329528976, 0.02532681177399354, 0.032943627375061624, 0.03203477848728653, 0.039934610249474645, 0.02174993271182757, 0.023357407881121617, 0.05098538582387846, 0.11897390926606022, 0.15993942943168804, 0.1511088220286183, 0.17325335094938055, 0.12998824910027906, 0.09004114108392969, 0.10741160469478928, 0.10324128394131549, 0.18537002499215305, 0.25562347553204745, 0.120173197647091, 0.15722247131634504, 0.22711100784363225, 0.09466256888117641, 0.11704537915647961, 0.12155664997408167, 0.3900358302053064, 0.3001299232710153, 33.38532395660877, 73.43622744083405, 44.02065686881542, 26.75858974456787, 43.42503122985363, 62.707655131816864, 68.58313545584679, 54.72343236207962, 65.07172867655754, 9.359542820602655, 0.6690752226859331, 1.5789603861048818, 1.8936008401215076, 0.6391628715209663, 34.02611777186394, 73.60629111528397, 67.39614754915237, 62.85843104124069, 59.10942681133747, 55.13381414115429, 49.156271293759346, 49.84728321433067, 48.68843659758568, 47.19409078359604, 44.405933395028114, 47.22352780401707, 46.02018937468529, 46.15701623260975, 44.4390220195055, 47.677709832787514, 43.855578526854515, 44.373631328344345, 46.40501752495766, 45.13143986463547, 47.373327165842056, 45.813191682100296, 44.339623153209686, 43.27816531062126, 45.18488019704819, 47.227950766682625, 46.483813896775246, 48.782983124256134, 47.05448627471924, 44.37597580254078, 46.082099452614784, 44.24630396068096, 42.93821655213833, 44.26103577017784, 44.7921484708786, 47.16614328324795, 45.40872998535633, 50.50706461071968, 48.80287125706673, 44.637052193284035, 47.711592614650726, 47.46815487742424, 45.77327862381935, 45.031691417098045, 45.00502824783325, 44.267282634973526, 41.46534338593483, 41.553073078393936, 42.74201788008213, 41.235482320189476, 41.40931159257889, 40.72089493274689, 44.27756488323212, 38.64048756659031, 42.49212048947811, 43.5267099738121, 42.758812978863716, 42.30027638375759, 44.07739542424679, 43.48969615995884, 45.80406837165356, 42.419517785310745, 41.01449757814407, 42.05950990319252, 42.090470641851425, 39.90642383694649, 40.354860574007034, 41.32049135863781, 39.04558002948761, 43.44166673719883, 40.186332017183304, 42.180176228284836, 43.34078595042229, 45.104845091700554, 49.34479437768459, 46.36460669338703, 46.18161231279373, 46.02172449231148, 50.27184583246708, 44.867194443941116, 43.77688854932785, 41.80303506553173, 39.76601757109165, 41.849935948848724, 42.09836281836033, 42.351680025458336, 40.62815710902214, 41.07138432562351, 39.641490653157234, 40.45016326010227, 41.955144703388214, 39.98714290559292, 42.808719500899315, 39.75639648735523, 41.41979902982712, 41.22358895838261, 41.495335176587105, 40.6235745549202, 42.0975686609745, 40.891038402915, 43.934599086642265, 42.94961594045162, 43.021743670105934, 43.30376073718071, 44.239069148898125, 41.043645814061165, 44.876754730939865, 41.098294481635094, 44.81914982199669, 46.12603269517422, 46.62161350250244, 50.17992116510868, 53.42115864157677, 55.09510941803455, 61.94067768752575, 60.32063081860542, 63.26456844806671, 8.303389493376017, 0.9032880642917007, 1.3583084824495018, 0.2227600631886162, 17.184068709611893, 74.34796571731567, 57.489877715706825, 69.90921869874, 46.31477236747742, 46.052430644631386, 39.19526159763336, 64.54028159379959, 21.86117883771658, 0.5693730851635337, 0.15987481805495918, 0.14560223469743505, 0.16426515590865165, 0.1116998156066984, 0.1292075394303538, 0.10578820860246196, 0.17146035184850916, 0.20238677359884605, 0.1248142181430012, 0.12295433669351041, 0.12492110225139186, 0.13190981786465272, 0.13294707314344123], [0.04976535070454702, 0.026525448920438066, 0.027754204274970107, 0.06465419122832827, 0.009625726797821699, 0.08838356166961603, 0.06355080317007378, 0.10034046616056003, 0.06469655301771127, 0.0605080348032061, 0.02926462508185068, 0.010833594405994518, 0.0640520200249739, 0.056643935313331895, 0.10035564308054745, 0.12329412158578634, 0.20497722522122785, 0.009781309709069319, 3.8926486345008016, 49.359518587589264, 35.362772047519684, 31.270026862621307, 24.268982335925102, 35.66808946430683, 58.61858814954758, 47.032291665673256, 59.778817892074585, 9.89591158926487, 0.4499044083058834, 0.4667082050582394, 0.9084228950086981, 0.36612920521292835, 12.663251794874668, 71.53546303510666, 57.16565631330013, 61.31731353700161, 52.45803952217102, 54.65077646076679, 49.84471075236797, 54.22914728522301, 51.65202297270298, 50.10895997285843, 47.276314571499825, 45.96187010407448, 41.791753470897675, 40.947928950190544, 40.883795991539955, 42.004264667630196, 40.3128994256258, 41.88311576843262, 38.892414048314095, 40.127309784293175, 39.1329525411129, 39.8428076505661, 38.54156747460365, 39.89035829901695, 39.78342063724995, 39.541624411940575, 40.75735777616501, 40.34173987805843, 42.14033916592598, 40.53672641515732, 39.936829805374146, 40.71362592279911, 39.974500983953476, 39.753147661685944, 41.202329099178314, 39.72126357257366, 40.136683881282806, 44.006441831588745, 42.237921729683876, 41.838338971138, 43.35745185613632, 41.42103776335716, 38.1970551609993, 38.59424784779549, 39.158392176032066, 38.28994877636433, 37.260857596993446, 39.92058947682381, 39.17052112519741, 39.58061791956425, 37.34705217182636, 37.35221989452839, 38.181806579232216, 39.17251221835613, 39.0102419257164, 39.3114023655653, 39.77641761302948, 40.05488567054272, 40.275684222579, 38.348705023527145, 37.43870325386524, 36.57035864889622, 37.882918417453766, 37.858409732580185, 37.33280673623085, 36.10208697617054, 38.09374250471592, 35.57648777961731, 37.32617989182472, 37.271747812628746, 35.735406652092934, 36.13449543714523, 37.91352577507496, 40.30248798429966, 39.9469942599535, 41.01982109248638, 40.892706513404846, 39.735030233860016, 43.006814271211624, 40.224744156003, 38.55038680136204, 38.84522818028927, 37.47979424893856, 37.34985262155533, 38.02321448922157, 38.06245118379593, 40.40724076330662, 38.24669189751148, 38.44611279666424, 37.328900545835495, 36.00441701710224, 35.45127309858799, 36.85511156916618, 38.61744940280914, 38.23245406150818, 37.674214616417885, 38.00422690808773, 37.084360867738724, 36.729615703225136, 38.56735289096832, 38.206554651260376, 40.76224811375141, 37.377838119864464, 38.9850302785635, 38.66597279906273, 39.1891211271286, 37.030209973454475, 38.78414645791054, 38.40787544846535, 43.294667825102806, 49.33919347822666, 52.622266709804535, 52.742841839790344, 54.38183829188347, 53.60164515674114, 61.03822611272335, 48.840952813625336, 1.4154626405797899, 0.20785741129657254, 0.40638374048285186, 0.21188774815527722, 21.319478005170822, 61.66102409362793, 47.35536552965641, 55.513056591153145, 31.809197030961514, 23.947312496602535, 29.348859451711178, 31.202067509293556, 1.0280345985665917, 0.028797855011362117, 0.02877850907680113, 0.010419210684631253, 0.07063032055157237, 0.03550255256413948, 0.029423531887005083, 0.019624401356850285, 0.016370408484362997, 0.02407566582405707, 0.044214390363777056, 0.03451663906162139, 0.08178229909390211, 0.05558468648814596, 0.022905799887666944, 0.08438006829237565, 0.0390680229611462, 0.050784553241101094, 0.017096841183956712, 0.031852800166234374, 0.03917878850188572, 0.06250255668419413, 0.03888951046974398, 0.05055386405729223, 0.0795143329014536, 0.03346106757817324, 0.02310336145455949, 0.028482672314567026, 0.08717010568943806, 0.11929838365176693, 0.030147237193887122, 0.19588981987908483, 0.14093241887167096, 6.570254992693663, 57.40996040403843, 38.884791657328606, 22.363508082926273, 31.459967270493507, 44.88565385341644, 65.37353128194809, 52.79413528740406, 65.6185345351696, 11.699458211660385, 0.7395955198444426, 0.36228482087608427, 0.8982484065927565, 0.36119294352829456, 14.634181335568428, 73.85515496134758, 58.979979157447815, 64.83425661921501, 54.422043934464455, 57.2951989620924, 50.59976823627949, 55.22010751068592, 52.778582721948624, 50.968671441078186, 49.65876393020153, 47.674932181835175, 43.86725150048733, 44.367517456412315, 43.09268966317177, 43.50601628422737, 42.95849986374378, 44.07268367707729, 41.028674617409706, 42.35579900443554, 41.319818794727325, 41.996547281742096, 41.174237206578255, 40.876857563853264, 40.77465444803238, 43.84488210082054, 43.65867309272289, 43.513498082756996, 43.582768365740776, 41.66211202740669, 41.506054401397705, 43.000856190919876, 41.94382891058922, 42.92003832757473, 42.57939040660858, 42.18644209206104, 42.2815053910017, 47.136660665273666, 45.14531672000885, 43.927611261606216, 46.81868992745876, 44.306705519557, 41.61005102097988, 40.830663442611694, 39.777929931879044, 41.163270995020866, 39.94544394314289, 39.726290702819824, 40.32516896724701, 39.60202217102051, 40.04374086856842, 39.858185425400734, 39.76559579372406, 40.23321010172367, 40.73898196220398, 40.73311507701874, 42.30018138885498, 42.662187963724136, 41.80981770157814, 41.7122807353735, 39.65719901025295, 37.77245454490185, 40.024665892124176, 40.287759974598885, 39.81365941464901, 40.30688814818859, 39.121765941381454, 37.911747470498085, 40.12042075395584, 38.75611916184425, 38.88081707060337, 37.899048551917076, 39.597834795713425, 42.088943123817444, 42.692198753356934, 42.790412083268166, 42.85327211022377, 41.88993640244007, 43.615336418151855, 42.82263435423374, 41.54105432331562, 41.227001175284386, 38.92933286726475, 39.015177860856056, 39.0896462649107, 40.17031587660313, 41.03220082819462, 40.26306509971619, 38.77352222800255, 37.874178886413574, 38.022959902882576, 39.09949913620949, 38.65659110248089, 41.22194364666939, 38.673139214515686, 39.48139004409313, 38.35772193968296, 39.94283728301525, 39.06235232949257, 41.648634150624275, 38.87151136994362, 42.67190784215927, 39.56790380179882, 42.26429991424084, 40.805873572826385, 42.46232248842716, 39.74995203316212, 41.454293578863144, 40.24748593568802, 45.45632243156433, 51.754655465483665, 54.68169920146465, 55.8980443328619, 58.260590359568596, 55.44622577726841, 61.38154909014702, 48.120944648981094, 1.8411058257333934, 0.7272704655770212, 0.23848290700698271, 0.161480751412455, 23.062586970627308, 67.25136771798134, 53.489311784505844, 60.45383267104626, 44.07269887626171, 29.131894893944263, 29.228692799806595, 40.82433678209782, 1.7828196845948696, 0.07342930824961513, 0.02096974440064514, 0.03893733075528871, 0.031132460499065928, 0.09795464691706002, 0.012811336328013567, 0.010351434048061492, 0.08639968960778788, 0.014695832960569533, 0.03105751471593976, 0.07335354239330627, 0.08472277724649757, 0.029367677852860652, 0.04635465520550497, 0.16187324363272637, 0.14633188460720703, 0.2985600137617439, 0.22085462871473283, 0.13946042832685634, 0.157256031234283, 0.22410706122172996, 0.3192860016133636, 0.19357694633072242, 0.13343358063139021, 0.17090811976231635, 0.12417021949659102, 0.17047357745468616, 0.18571690481621772, 0.2219662768766284, 0.16983927867840976, 0.42510732484515756, 0.19642516068415716, 7.971260715276003, 71.0420823097229, 47.06710919737816, 39.247478395700455, 38.933565840125084, 46.37351341545582, 71.91994160413742, 56.971026957035065, 74.06349778175354, 16.58588580787182, 0.8172282041050494, 1.9661989132873714, 2.1925303246825933, 0.5266859976109117, 15.436011459678411, 74.23568174242973, 62.20021516084671, 65.90212091803551, 57.65877865254879, 60.98831199109554, 54.725066274404526, 58.6369563639164, 56.47649489343166, 53.18276323378086, 53.42593118548393, 50.68874426186085, 46.63867078721523, 45.788185223937035, 44.434815645217896, 46.597416400909424, 45.45671381056309, 47.06169828772545, 43.352952897548676, 44.36486139893532, 43.68765413761139, 45.06294094026089, 42.75590993463993, 44.053878486156464, 45.499845296144485, 45.32353475689888, 46.22311748564243, 44.93740327656269, 46.57363347709179, 44.587548449635506, 44.82350438833237, 45.92293739318848, 44.96036924421787, 45.866578817367554, 45.119098126888275, 43.88278886675835, 44.940811693668365, 48.47979359328747, 47.224150970578194, 47.08108864724636, 49.13047067821026, 45.56709788739681, 43.243739157915115, 43.07088643312454, 43.104871809482574, 43.62178847193718, 40.934990644454956, 42.8388898819685, 42.27838575839996, 43.91245387494564, 42.89032392203808, 42.262540608644485, 43.06557051837444, 44.043239057064056, 44.25266481935978, 42.983396127820015, 45.27450978755951, 44.927159026265144, 44.83195133507252, 46.07762709259987, 42.152418717741966, 41.36139236390591, 43.60269449651241, 42.99055494368076, 42.613744363188744, 42.09983713924885, 41.54127091169357, 39.26215700805187, 44.10298325121403, 41.38926386833191, 40.784701108932495, 39.55809272825718, 42.423967346549034, 44.37553882598877, 45.58823995292187, 44.04127836227417, 45.034659057855606, 43.73992033302784, 45.131987035274506, 45.36041937768459, 44.29311364889145, 42.69049644470215, 40.93951240181923, 40.61211816966534, 41.33974112570286, 41.133959367871284, 43.99596959352493, 42.65699364244938, 41.87216475605965, 40.810691714286804, 40.58675833046436, 40.115443021059036, 42.146422639489174, 43.91189530491829, 42.590094432234764, 42.784913778305054, 41.88357174396515, 40.59381455183029, 41.95871651172638, 42.823690697550774, 41.16975724697113, 45.48135168850422, 41.34142063558102, 43.78141790628433, 42.481112480163574, 42.733909115195274, 40.98965831100941, 43.682942390441895, 42.90432617068291, 47.82019078731537, 55.204383954405785, 55.28780847787857, 60.202620550990105, 58.78617435693741, 59.44895379245281, 63.170356303453445, 52.19762049615383, 2.676870860159397, 0.4827090573962778, 0.9593393909744918, 0.39917398360557854, 27.581758573651314, 73.76036524772644, 57.6921446621418, 66.82799443602562, 45.02643249928951, 36.01607859134674, 39.54303793609142, 51.28748193383217, 2.2543373331427574, 0.13147793244570494, 0.09312023015809245, 0.14611903665354475, 0.17836757964687422, 0.16151376214111224, 0.19101002078969032, 0.1015735742112156, 0.14816469250945374, 0.15081374411238357, 0.1248982292599976, 0.14164434629492462, 0.1786064769839868, 0.1590628788108006, 0.14111452706856653], [0.049147676036227494, 0.05734932070481591, 0.026430517100379802, 0.03451750737440307, 0.05566669009567704, 0.024088655263767578, 0.030793944679317065, 0.10474060036358424, 0.04646005130780395, 0.016155347075255122, 0.012012737188342726, 0.04147004699916579, 0.04726184910396114, 0.060284492501523346, 0.056450097472406924, 0.013916250427428167, 0.06753967623808421, 0.05817347569973208, 0.04938696671160869, 24.149224162101746, 47.63360559940338, 28.98281369358301, 24.212576262652874, 26.427144929766655, 56.82248532772064, 44.717246890068054, 59.682759046554565, 26.73226285725832, 0.13966996630188078, 0.7538533047772944, 0.38206394703593105, 0.07995063409907743, 2.1321795880794525, 59.54555220901966, 64.9372386932373, 58.68304789066315, 55.877707824110985, 54.356949627399445, 53.92114341259003, 54.14332889020443, 55.25699973106384, 56.061002388596535, 52.80392736196518, 54.25175987184048, 50.37181846797466, 45.52213490009308, 40.158471912145615, 42.64657460153103, 41.34592719376087, 41.15179181098938, 41.80028781294823, 40.52272416651249, 40.74066527187824, 39.245977476239204, 39.16717350482941, 40.164004415273666, 39.4149050116539, 40.398003458976746, 39.57643434405327, 38.865032717585564, 41.42735302448273, 40.37240423262119, 40.91469593346119, 40.62351755797863, 40.48816882073879, 42.05377221107483, 39.998690485954285, 40.17348490655422, 41.976111978292465, 41.669001057744026, 43.64491783082485, 40.34254543483257, 40.470986142754555, 40.05428530275822, 38.37033346295357, 39.75545413792133, 38.620333448052406, 39.61472488939762, 38.81639152765274, 37.55602575838566, 38.535335808992386, 38.55124935507774, 39.04549263417721, 38.081989735364914, 41.52931675314903, 42.77828313410282, 42.88155399262905, 45.75126260519028, 43.67699570953846, 43.0240311473608, 44.94318276643753, 43.66291366517544, 39.98100243508816, 40.649299174547195, 38.825313448905945, 38.57149466872215, 37.062785625457764, 37.188756465911865, 37.62833587825298, 38.70478771626949, 38.22364613413811, 37.21726633608341, 36.93149507045746, 37.53833010792732, 39.819640293717384, 39.88649770617485, 39.17366735637188, 39.03968274593353, 39.07034330070019, 39.16120022535324, 40.632929652929306, 40.9111887216568, 37.50549226999283, 39.59893673658371, 39.924480468034744, 37.94787973165512, 39.135916382074356, 40.202652141451836, 39.02172110974789, 39.253326281905174, 38.39130073785782, 37.16195650398731, 36.13877400755882, 35.9543889015913, 36.61172702908516, 37.13359862565994, 34.97946761548519, 37.80017785727978, 36.74695797264576, 39.238963052630424, 37.26318687200546, 39.80683118104935, 36.850783601403236, 39.90409076213837, 38.79259340465069, 40.542787089943886, 38.376736119389534, 39.15441758930683, 38.06863725185394, 40.371461883187294, 37.827916368842125, 45.55841915309429, 50.747207924723625, 55.47202259302139, 53.81476052105427, 58.94998736679554, 50.76516196131706, 56.80063270032406, 32.78072699904442, 0.23798848822480068, 0.1784980937372893, 0.5603472038637847, 0.11670131207210943, 34.84496623277664, 55.691240429878235, 54.319441840052605, 43.020611330866814, 25.546029210090637, 25.19570130854845, 43.33180323243141, 16.16342257708311, 0.42659200611524284, 0.02303021537954919, 0.011604121809796197, 0.06712682690704241, 0.07398252739221789, 0.05888269057322759, 0.022432599107560236, 0.07880849108914845, 0.03042772448679898, 0.026368976359663066, 0.06782739204936661, 0.0754685964784585, 0.02689839111553738, 0.05795679084258154, 0.008858013989083702, 0.057395048133912496, 0.02281858083733823, 0.035412210927461274, 0.03245898267778102, 0.04865904229518492, 0.03916662841220386, 0.029244455363368616, 0.02163075863791164, 0.03491211842629127, 0.03590626234654337, 0.016681900851835962, 0.018470758768671658, 0.027206695958739147, 0.023750805521558505, 0.08761583216255531, 0.05511133356776554, 0.06815893910243176, 0.10272457104292698, 0.2369526430265978, 35.98664157092571, 50.37192106246948, 31.466875299811363, 28.262921422719955, 34.55038323998451, 63.04214358329773, 49.439371302723885, 65.85230559110641, 28.76061301678419, 0.19775219494476914, 1.2210400169715285, 0.45901323202997446, 0.10108371221576817, 2.462107571773231, 60.54139517247677, 67.23005846142769, 61.672518476843834, 58.74556593596935, 59.100007116794586, 57.004024386405945, 56.23610459268093, 56.5210285037756, 58.0618230253458, 52.818879559636116, 55.762938782572746, 51.183496713638306, 48.50664675235748, 42.526922821998596, 45.041346698999405, 41.90081521868706, 42.91638672351837, 44.834934175014496, 43.643530905246735, 41.224744096398354, 42.776193246245384, 41.75810627639294, 41.488879323005676, 42.238556295633316, 42.88402006030083, 42.293778732419014, 42.98990897834301, 42.85767987370491, 43.281710520386696, 41.662738993763924, 43.20308893918991, 43.11507426202297, 43.86480823159218, 42.58179567754269, 43.07596676051617, 44.7214874625206, 44.580233842134476, 46.87766656279564, 42.732092812657356, 42.399717047810555, 41.34396269917488, 42.294971868395805, 41.03039212524891, 40.90472526848316, 40.67598894238472, 39.90612365305424, 40.515173971652985, 40.524890050292015, 40.5317372828722, 41.95408836007118, 39.99556705355644, 45.09517461061478, 45.437152460217476, 45.73715776205063, 48.199931010603905, 45.25180980563164, 44.91979502141476, 45.451584085822105, 44.59159143269062, 41.875618770718575, 42.16329373419285, 40.45540697872639, 41.16412594914436, 39.01286758482456, 39.53743703663349, 39.00427244603634, 39.15177293121815, 40.31770996749401, 39.998663887381554, 40.007205829024315, 39.998492896556854, 40.725086107850075, 43.40646542608738, 42.06375427544117, 39.93934527039528, 40.930050909519196, 40.397308096289635, 42.29785971343517, 43.49940463900566, 38.4062909334898, 41.37885242700577, 40.65629839897156, 40.49438528716564, 40.9139359742403, 42.02318385243416, 41.21648333966732, 40.26904597878456, 40.553985089063644, 37.84571461379528, 38.82061690092087, 38.99762660264969, 39.43195469677448, 40.31020537018776, 37.304110676050186, 39.59703303873539, 39.712417647242546, 39.77379575371742, 39.18657526373863, 41.24156579375267, 39.83672417700291, 41.22918225824833, 41.440925896167755, 41.99302487075329, 39.21626687049866, 41.628054454922676, 37.96575777232647, 42.860058546066284, 40.20757667720318, 48.705360889434814, 53.591837882995605, 57.46932081878185, 56.41770824790001, 61.69893465936184, 54.3063173443079, 58.435616567730904, 33.71081069111824, 0.37636612309142947, 1.8093487923033535, 1.4132587588392198, 0.17314946511760354, 37.738073989748955, 61.07922971248627, 59.59186412394047, 48.58559891581535, 38.74581791460514, 22.02976629137993, 46.661800146102905, 20.799757093191147, 0.5061224510427564, 0.0053558886793325655, 0.04058919192175381, 0.0063477412186330184, 0.03456417362031061, 0.11926025210414082, 0.03394886269234121, 0.04648974834708497, 0.03429000200412702, 0.036093580420129, 0.01773676172888372, 0.0845097066485323, 0.04994594492018223, 0.09959179500583559, 0.010467243409948424, 0.21051410702057183, 0.11916999210370705, 0.1915310529875569, 0.10503455763682723, 0.14682407694635913, 0.14261924632592127, 0.1069411201751791, 0.15531509241554886, 0.13160409755073488, 0.16550596745219082, 0.20819200115511194, 0.09375913767144084, 0.12676964368438348, 0.13881609571399167, 0.13427115365630016, 0.13969123625429347, 0.1341964045423083, 0.2558792196214199, 0.30995046661701053, 43.75262685120106, 63.15397158265114, 37.73461237549782, 38.540488332509995, 40.002053305506706, 71.01752042770386, 55.171515718102455, 70.9787169098854, 36.01039029657841, 0.26683192409109324, 4.004421774297953, 1.2250496330671012, 0.3668942110380158, 2.870385688729584, 60.7973912358284, 69.2957492172718, 62.32800230383873, 63.70408706367016, 60.488707199692726, 60.81037133932114, 58.73520389199257, 59.58817832171917, 62.15462140738964, 55.54556384682655, 58.87467920780182, 55.17791457474232, 51.282557398080826, 45.006274580955505, 47.163920402526855, 44.83172334730625, 44.74246233701706, 47.517613023519516, 44.76578168570995, 44.911792650818825, 45.38173623383045, 44.99955654144287, 44.980454966425896, 43.42801406979561, 46.35122001171112, 44.141080006957054, 43.960160315036774, 46.28029301762581, 46.68370597064495, 45.51701657474041, 45.115085542201996, 45.65153695642948, 46.37858234345913, 44.56531964242458, 46.05147309601307, 48.21173317730427, 46.45666055381298, 47.33224757015705, 45.0237650424242, 44.40625257790089, 43.28207150101662, 45.00272177159786, 45.18233433365822, 42.50914357602596, 42.723383679986, 43.97152170538902, 43.84276561439037, 43.237024918198586, 42.37387463450432, 45.18782503902912, 42.5379878282547, 48.273498862981796, 48.8132257014513, 47.06823393702507, 52.08914391696453, 48.52874256670475, 47.43798069655895, 48.47572401165962, 47.061394304037094, 44.22456152737141, 44.70858335494995, 41.76157549023628, 42.519813403487206, 41.09757252037525, 42.14008077979088, 40.491087064146996, 41.317975893616676, 43.12632165849209, 42.48743534088135, 41.257760524749756, 41.832494884729385, 43.95300529897213, 45.38918003439903, 45.41305415332317, 42.72928476333618, 44.562473595142365, 42.20530427992344, 44.06283840537071, 46.45497344434261, 41.57388836145401, 43.456067964434624, 43.22276808321476, 43.122578859329224, 44.21690493822098, 43.64912800490856, 43.420988246798515, 42.361513897776604, 41.88226081430912, 41.627290695905685, 40.7679858058691, 40.79993449151516, 41.67704902589321, 41.028511226177216, 39.198111444711685, 41.5574998408556, 43.61701212823391, 43.79874497652054, 41.908745393157005, 43.501946702599525, 42.677535340189934, 44.23701725900173, 43.37317921221256, 44.199684262275696, 42.24786199629307, 42.1625679731369, 42.16647036373615, 44.97552663087845, 42.212778478860855, 48.895540684461594, 55.272616893053055, 59.131579622626305, 60.354684591293335, 63.44472438097, 56.41184516251087, 58.95145408809185, 36.734221056103706, 0.42706460575573146, 1.7947290767915547, 1.5545227099210024, 0.3337404556805268, 42.3132298886776, 67.14486703276634, 64.3128789961338, 53.079040199518204, 38.450740948319435, 32.5274857878685, 58.49222972989082, 26.96708645671606, 0.50023811054416, 0.11624401551671326, 0.14457869430771098, 0.13986154430313036, 0.15449041791725904, 0.15195126354228705, 0.1399898319505155, 0.13180234003812075, 0.27430671674665064, 0.03967253564042039, 0.1708860186045058, 0.2060290117515251, 0.16156387195223942, 0.19708142703166232, 0.11271366354776546], [0.037135366510483436, 0.030906363354006317, 0.02794710329908412, 0.023108946115826257, 0.02164259960409254, 0.10435027521452866, 0.016598290494584944, 0.034301909763598815, 0.044411437993403524, 0.02580113876319956, 0.08157715463312343, 0.03714045764354523, 0.07600030818139203, 0.022126082840259187, 0.05870960318134166, 0.05042496042733546, 0.048781277728267014, 0.04940877101034857, 0.04602639215590898, 1.8676393269561231, 42.57922321557999, 35.18362306058407, 38.0348114669323, 26.93978302180767, 46.45137123763561, 58.017224818468094, 52.27395460009575, 44.29296165704727, 0.879881854634732, 0.6059294985607266, 0.33947324962355196, 0.25708387373015285, 0.14556631474988535, 31.7241195961833, 67.71249577403069, 57.49662235379219, 58.17253388464451, 55.60388691723347, 56.48269236087799, 58.63067530095577, 57.34968803822994, 56.878175139427185, 58.88196341693401, 59.101025462150574, 58.58399860560894, 55.737160965800285, 48.63127626478672, 41.72249838709831, 41.573694571852684, 41.05351008474827, 40.61431065201759, 41.17382302880287, 41.94792129099369, 41.41191065311432, 39.16723810136318, 40.31629644334316, 41.09361693263054, 39.95075985789299, 41.52356006205082, 40.93749850988388, 41.54073514044285, 42.105837017297745, 42.446401342749596, 43.54528717696667, 41.3455244153738, 40.38897894322872, 42.06565797328949, 40.33996917307377, 41.64660505950451, 42.15818680822849, 39.666136130690575, 38.89965645968914, 39.29849825799465, 40.009117126464844, 39.37190651893616, 41.75643816590309, 38.879954516887665, 40.06768338382244, 41.85481868684292, 39.32064346969128, 39.19797085225582, 38.727160915732384, 41.50627858936787, 41.0970975458622, 48.25391851365566, 49.28047902882099, 51.92221127450466, 51.51880972087383, 51.87610074877739, 47.93338291347027, 47.5756511092186, 49.188007190823555, 45.415524020791054, 46.14411972463131, 45.374140441417694, 43.42888422310352, 38.35782453417778, 36.492459028959274, 37.363072112202644, 38.20066876709461, 37.87779629230499, 37.079284340143204, 36.76635593175888, 39.08134751021862, 38.34545619785786, 40.02482928335667, 38.37338089942932, 38.90354365110397, 37.692256048321724, 38.36419299244881, 39.28593993186951, 39.85564336180687, 39.17328737676144, 39.33881789445877, 39.410295858979225, 37.75273360311985, 37.97730915248394, 40.30480585992336, 39.92647536098957, 39.744453728199005, 38.57162766158581, 37.427771240472794, 36.5342415869236, 37.54458837211132, 36.59265585243702, 37.83651910722256, 36.84596166014671, 37.01456621289253, 37.033956572413445, 39.62303504347801, 41.0904973000288, 42.99104131758213, 44.671026170253754, 45.074602514505386, 44.951462522149086, 44.88275460898876, 45.733878538012505, 47.7264916151762, 43.07973615825176, 44.37226340174675, 42.70292937755585, 50.57464778423309, 52.231153696775436, 55.95236621797085, 53.075586184859276, 57.19377860426903, 51.84899680316448, 49.425042271614075, 18.584645055234432, 0.12409162605763413, 0.34068603767082095, 0.038068101421231404, 0.4868551396066323, 49.38739389181137, 58.899457678198814, 48.117893412709236, 33.12270484864712, 22.685945481061935, 31.66418731212616, 37.81207501888275, 1.4443148486316204, 0.25529434788040817, 0.004855626411881531, 0.04244879135512747, 0.03822295424470212, 0.030128676080494188, 0.02472001884598285, 0.0403422014642274, 0.04397015327413101, 0.028433230436348822, 0.08086588772130199, 0.06287437267019413, 0.007616512248205254, 0.028488340467447415, 0.03746434573258739, 0.0553725213103462, 0.037268826927174814, 0.042054915029439144, 0.018107444084307645, 0.05747521121520549, 0.04949014008161612, 0.0764094245096203, 0.028796565529773943, 0.02190119539591251, 0.014705895555380266, 0.0192532681467128, 0.022657534791505896, 0.04870957141974941, 0.028322496436885558, 0.05268839580821805, 0.05258658427919727, 0.07683463802095503, 0.1376441406318918, 0.11900600715307519, 0.06235663560801186, 5.575954271480441, 54.71489042043686, 34.56612579524517, 36.235186234116554, 31.579254269599915, 55.889954566955566, 60.158903896808624, 58.225252255797386, 47.83045783638954, 0.5810697481501848, 0.8176439255475998, 0.3882562491344288, 0.29597603366710246, 0.20200953993480653, 34.73250366747379, 70.1277069747448, 59.50164556503296, 61.31218381226063, 57.61360667645931, 58.394886553287506, 59.16212238371372, 61.431128829717636, 59.48399171233177, 60.629664435982704, 59.40102696418762, 61.09282158315182, 57.95841537415981, 51.41430772840977, 44.1267965734005, 44.26135875284672, 42.95555882155895, 44.02669474482536, 42.31452941894531, 43.10150898993015, 42.357725501060486, 42.23380275070667, 42.437585815787315, 42.636307552456856, 42.01203145086765, 44.46853883564472, 43.041305020451546, 44.050568863749504, 42.60184720158577, 44.941275268793106, 44.95997026562691, 42.79769629240036, 42.45966263115406, 44.36301089823246, 42.6564996689558, 43.13693068921566, 45.152456536889076, 43.82524475455284, 40.70306248962879, 42.634377256035805, 42.66440324485302, 41.914559081196785, 42.59952932596207, 41.679237708449364, 41.97097085416317, 41.78036168217659, 42.03435145318508, 42.57221259176731, 40.39357669651508, 42.05096796154976, 41.870466247200966, 48.92177827656269, 50.05923964083195, 51.57805234193802, 53.03468517959118, 52.28670671582222, 50.104916989803314, 48.71140256524086, 50.467698723077774, 46.42560862004757, 47.49851144850254, 45.86879409849644, 44.419285878539085, 39.976875856518745, 38.88896383345127, 39.9890998005867, 40.195071548223495, 40.59934325516224, 39.41007547080517, 38.006066009402275, 40.87342634797096, 39.924526065588, 41.892512664198875, 40.84762193262577, 40.56098811328411, 40.11250577867031, 41.32575407624245, 42.43614189326763, 41.10475793480873, 42.31302849948406, 42.07697756588459, 41.161819472908974, 40.245107263326645, 40.11840686202049, 42.101558446884155, 41.125504821538925, 42.178587913513184, 40.09609445929527, 39.15252909064293, 38.1588102132082, 39.320221692323685, 39.42471228539944, 38.902798891067505, 38.72315973043442, 39.49167609214783, 39.50544275343418, 40.62063731253147, 43.778598457574844, 45.31006447970867, 46.46474651992321, 46.429248824715614, 47.9840911924839, 46.10180139541626, 49.55160968005657, 48.74892175197601, 46.2377543002367, 45.993321016430855, 46.07235677540302, 52.940123453736305, 54.620336294174194, 58.2376129925251, 57.685958594083786, 58.7226265668869, 53.76426883041859, 50.74485585093498, 21.025993153452873, 0.31162558298092335, 1.8904459406621754, 0.5864360695704818, 0.5995960102882236, 52.706158608198166, 65.8901059627533, 53.3827731013298, 43.27975742518902, 28.864847123622894, 27.865930125117302, 46.65839932858944, 2.0024426747113466, 0.11241249259910546, 0.09475894417846575, 0.03619803028414026, 0.047038076736498624, 0.08641410211566836, 0.012731807782984106, 0.03258055388869252, 0.014303154275694396, 0.03182232758263126, 0.01693000453087734, 0.010127244222530862, 0.0882321412791498, 0.055467430865974165, 0.07508906215662137, 0.05245504973572679, 0.17846269329311326, 0.22062316769734025, 0.10699981663492508, 0.17258752573980018, 0.1679035200504586, 0.133086908608675, 0.14289008569903672, 0.1415384715073742, 0.13801614957628772, 0.09947275451850146, 0.18166396213928238, 0.08865770359989256, 0.1589832315221429, 0.18233484879601747, 0.14014505955856293, 0.17042542691342533, 0.22712050733389333, 0.23673454066738486, 0.21891106269322336, 7.184697221964598, 70.1480358839035, 43.473930805921555, 45.89162327349186, 44.27625015377998, 59.45646218955517, 67.5689622759819, 65.39357900619507, 54.798512533307076, 0.9786813030950725, 1.5403541014529765, 1.6569541697390378, 0.3598598681855947, 0.1961509816464968, 36.50806099176407, 70.27877166867256, 62.07193024456501, 63.392230197787285, 60.17993576824665, 61.08846701681614, 63.069099336862564, 61.07545271515846, 60.25430917739868, 61.49203576147556, 62.25926399230957, 62.80912108719349, 61.13746538758278, 54.92829076945782, 46.268095672130585, 46.74098789691925, 44.89871755242348, 46.13805904984474, 43.3251041918993, 47.35710583627224, 44.57088254392147, 44.520147666335106, 46.07236437499523, 46.91144295036793, 44.262814074754715, 46.389939934015274, 46.41125679016113, 48.00837188959122, 43.9582110196352, 48.08106578886509, 48.8320916891098, 45.417891293764114, 44.93421524763107, 46.20100647211075, 44.24765668809414, 46.77275039255619, 47.610430642962456, 45.38705974817276, 44.23504896461964, 45.33336102962494, 44.41224105656147, 43.58365371823311, 45.359933003783226, 44.109404906630516, 44.02418687939644, 45.43724745512009, 44.22725558280945, 45.14513432979584, 43.263881877064705, 44.828835502266884, 44.52139399945736, 51.80342584848404, 52.403744235634804, 54.89681325852871, 54.63201306760311, 57.100212424993515, 52.76580020785332, 52.30076976120472, 53.58097426593304, 49.16470684111118, 50.06420597434044, 49.72383163869381, 48.716216906905174, 42.15351305902004, 39.835892021656036, 42.98267036676407, 41.850855499506, 43.116894364356995, 42.66180418431759, 40.46907864511013, 44.2816648632288, 41.28744073212147, 44.71469722688198, 44.20565754175186, 42.00725890696049, 42.167389914393425, 44.28474649786949, 44.11420404911041, 43.05743135511875, 44.651878997683525, 44.676566272974014, 42.75857739150524, 41.1687047034502, 41.55317187309265, 45.97116440534592, 43.32762345671654, 45.10129988193512, 41.69491566717625, 41.438927203416824, 41.06878146529198, 42.05965809524059, 41.55172415077686, 40.46561323106289, 40.58583118021488, 42.146346643567085, 41.77868977189064, 44.01059500873089, 45.9895896166563, 47.62561842799187, 48.06533083319664, 49.30087253451347, 49.13856044411659, 49.93472032248974, 51.39587491750717, 51.53102606534958, 49.10362511873245, 47.81454049050808, 47.71723911166191, 55.057293847203255, 58.03204782307148, 62.02068239450455, 58.8641993701458, 62.15170316398144, 54.96047504246235, 51.28182403743267, 21.365151554346085, 0.18998441722942516, 0.8020242105703801, 0.3194945154245943, 1.0627846838906407, 58.30947853624821, 68.67122232913971, 60.786865800619125, 43.86948578059673, 34.22289781272411, 42.34482519328594, 56.58644959330559, 3.9703102922067046, 0.4472040297696367, 0.1835903400206007, 0.22350480838213116, 0.20162546366918832, 0.1496050230343826, 0.11903850579983555, 0.13798267871607095, 0.16620124108158052, 0.20005890866741538, 0.12117344202124514, 0.15118334849830717, 0.16752613795688376, 0.16871827945578843, 0.13589461654191837, 0.226155448181089], [0.06863766888272949, 0.06081695006287191, 0.005460736520035425, 0.016421471955254674, 0.03008143281476805, 0.0564578046760289, 0.025133923882094678, 0.055365778898703866, 0.03603220480727032, 0.025444499697186984, 0.04778146008902695, 0.025349204224767163, 0.03567004045180511, 0.045234446370159276, 0.024857390380930156, 0.03420783883484546, 0.0550491527246777, 0.08007287324289791, 0.06199173272761982, 0.18640104623045772, 23.968004286289215, 46.93909026682377, 59.15539674460888, 39.2762466520071, 30.754888504743576, 56.959999948740005, 46.085291281342506, 58.96105997264385, 4.254725268110633, 0.31667527451645583, 0.12183846571133472, 0.03147112103761174, 0.03880660515278578, 8.287797030061483, 64.57301303744316, 56.88832439482212, 63.41319367289543, 56.555808037519455, 60.0250256806612, 55.30766241252422, 59.77912187576294, 55.99023498594761, 60.55836886167526, 56.54618315398693, 58.83291944861412, 56.945336535573006, 56.92250356078148, 50.290381237864494, 43.191233575344086, 42.06033445894718, 42.8075909614563, 42.70183503627777, 41.79305300116539, 41.16522029042244, 42.652308493852615, 42.57635056972504, 41.1028428375721, 41.91607140004635, 42.59110137820244, 41.955976858735085, 41.177873611450195, 43.90165865421295, 43.054159730672836, 40.68545043468475, 40.680134519934654, 41.04231208562851, 42.9573143273592, 43.770204707980156, 42.0838437974453, 41.75682954490185, 39.43690583109856, 39.46539290249348, 40.511256381869316, 40.85885792970657, 41.372331976890564, 40.36418907344341, 40.00003561377525, 41.406830325722694, 41.33236572146416, 39.95649375021458, 41.52805522084236, 38.846588507294655, 40.731963738799095, 41.427223831415176, 49.08716820180416, 54.19205367565155, 54.57695782184601, 55.4175791144371, 56.39889545738697, 58.89429375529289, 49.68370579183102, 51.55858598649502, 55.92133708298206, 53.78345400094986, 54.1579657047987, 47.69625283777714, 40.96876323223114, 40.39525620639324, 38.60972061753273, 38.84139038622379, 38.15208837389946, 37.626895755529404, 37.38125033676624, 38.18096682429314, 37.18930743634701, 36.946154683828354, 38.75637374818325, 38.40857461094856, 37.927018851041794, 37.65033669769764, 37.942309230566025, 38.90141196548939, 38.93119856715202, 39.77031894028187, 39.44450922310352, 37.349951416254044, 39.270596355199814, 38.85706454515457, 39.10794988274574, 38.64433296024799, 38.84599193930626, 36.903228387236595, 37.88964405655861, 37.231416776776314, 37.774810418486595, 38.591261208057404, 37.38733761012554, 37.93228156864643, 43.80786448717117, 49.794640839099884, 50.91484732925892, 50.712230801582336, 52.25843243300915, 50.78676760196686, 55.61235286295414, 50.68243280053139, 53.477118238806725, 49.905458092689514, 51.135383695364, 51.18516482412815, 51.021674796938896, 50.75681380927563, 50.72447754442692, 53.63473378121853, 51.35322980582714, 58.00362154841423, 48.63798290491104, 49.579902961850166, 14.688713159412146, 1.0264910501427948, 5.158728584647179, 1.0419429210014641, 5.662214867770672, 50.38268968462944, 51.03350356221199, 47.13518634438515, 25.83820503205061, 29.810287691652775, 37.38843195140362, 16.852992475032806, 0.17049827612936497, 0.07790871866745874, 0.07771170072373934, 0.03215483942767605, 0.05347144695406314, 0.059952989977318794, 0.025491778214927763, 0.024355221721634734, 0.05182537825021427, 0.027976590681646485, 0.0658838334493339, 0.05413460785348434, 0.009143341012531891, 0.06661284511210397, 0.07221342544653453, 0.042845792122534476, 0.03582657423976343, 0.0010400955011391488, 0.04175773312454112, 0.016247143321379554, 0.0788684343569912, 0.05103305396914948, 0.021182959717407357, 0.11251568081206642, 0.13195195700973272, 0.08755594084504992, 0.011968951403105166, 0.03846210762276314, 0.03841624660708476, 0.0739621405955404, 0.05674890096997842, 0.03931829742214177, 0.05794773293018807, 0.028219417690706905, 0.0609021820127964, 0.2816731855273247, 35.12964315712452, 49.646068811416626, 59.972436502575874, 45.83963826298714, 39.065992534160614, 64.2123743891716, 52.22590617835522, 63.472896069288254, 4.531243080273271, 0.3940584190422669, 1.0989918722771108, 0.2234843696351163, 0.07007074862485752, 10.06551168859005, 66.33188545703888, 58.23983207345009, 65.44152483344078, 58.20377200841904, 62.910853028297424, 58.22028212249279, 62.45615042746067, 58.72937120497227, 60.783468782901764, 58.07952627539635, 62.69397206604481, 59.78036820888519, 60.21075591444969, 51.21690072119236, 43.92366707324982, 45.06232537329197, 46.19808442890644, 45.86418114602566, 44.99209374189377, 43.3531428873539, 44.54082615673542, 43.081651255488396, 43.54633592069149, 44.248184859752655, 45.78351907432079, 43.257665410637856, 44.591732025146484, 45.97409024834633, 46.111753061413765, 44.22581925988197, 42.9920444637537, 43.510496243834496, 46.08844131231308, 45.823359936475754, 45.10888807475567, 44.04322765767574, 42.42223463952541, 41.42297185957432, 41.48436896502972, 42.73763671517372, 41.805208548903465, 41.726624965667725, 43.521496653556824, 42.524099573493004, 43.61822046339512, 41.75662815570831, 41.61139614880085, 39.921197444200516, 42.66631454229355, 41.941537633538246, 50.834048464894295, 56.14505387842655, 56.584758684039116, 57.241059467196465, 58.37036646902561, 59.10418689250946, 52.263402566313744, 52.970882803201675, 55.55142693221569, 54.967717453837395, 54.66289021074772, 48.56762208044529, 43.43065872788429, 43.12362760305405, 40.696933418512344, 40.82369841635227, 40.77528901398182, 39.8140773922205, 38.957344964146614, 39.97499115765095, 39.10270996391773, 40.267917439341545, 41.869007125496864, 40.535977855324745, 40.88393658399582, 38.602235019207, 38.76892447471619, 41.46460622549057, 41.24643333256245, 41.271257400512695, 41.10291503369808, 39.97024521231651, 40.747922882437706, 40.63312344253063, 40.259839072823524, 41.50147944688797, 40.934990644454956, 39.54485043883324, 39.76133242249489, 38.70034195482731, 38.599932342767715, 41.14896856248379, 38.59002247452736, 38.9528726041317, 46.3831876963377, 51.058548018336296, 52.768699452281, 52.61729657649994, 53.677470088005066, 52.402406707406044, 54.76741500198841, 52.938827723264694, 55.21259531378746, 52.582125663757324, 53.6658389121294, 53.13898578286171, 53.56837414205074, 53.02636742591858, 53.24588544666767, 57.32883855700493, 54.82895649969578, 58.485542088747025, 51.18370570242405, 53.813574984669685, 15.546636823564768, 1.0125985206104815, 6.507232049480081, 0.2989835722837597, 6.1747741140425205, 56.27523869276047, 58.657551258802414, 49.767270907759666, 35.388910844922066, 26.737960651516914, 38.87145057320595, 23.73531237244606, 0.34847618371713907, 0.14643997099483386, 0.05754830905061681, 0.044298679786152206, 0.0338141035172157, 0.02622886444441974, 0.07331142551265657, 0.09873699673335068, 0.07547302710008807, 0.030097240560280625, 0.042349384384579025, 0.07174473692430183, 0.10439332720125094, 0.055310730094788596, 0.04652981318940874, 0.0708519852196332, 0.12055135899572633, 0.14708989940118045, 0.16703921486623585, 0.18616936256876215, 0.17619976628338918, 0.12539629940874875, 0.16192854847759008, 0.27796363458037376, 0.2574721653945744, 0.1523407278000377, 0.10131324364920147, 0.11687700811307877, 0.14374018617672846, 0.11991121209575795, 0.07432769285514951, 0.12778056756360456, 0.18377902364591137, 0.17884028318803757, 0.1403012074297294, 0.5386067891959101, 44.446701407432556, 60.45236214995384, 62.47098483145237, 54.07160393893719, 44.23742763698101, 68.46960514783859, 56.3479819893837, 71.07290625572205, 6.130040539428592, 0.4777558450587094, 2.2743005119264126, 0.9921530052088201, 0.17809041717555374, 11.912340838462114, 66.27270743250847, 59.94280569255352, 70.04059284925461, 63.07223416864872, 66.71985223889351, 59.83407072722912, 64.46899741888046, 60.005760714411736, 62.21310406923294, 60.357162058353424, 65.7974061369896, 62.102324813604355, 63.37152510881424, 54.72395293414593, 47.49349571764469, 48.156978115439415, 47.84762151539326, 47.8084722161293, 47.452560514211655, 45.968941524624825, 46.73290193080902, 47.034734934568405, 45.38213141262531, 45.88267855346203, 48.74527394771576, 45.23916408419609, 47.120443135499954, 49.15309466421604, 47.72931106388569, 45.96344321966171, 45.54352015256882, 45.01383617520332, 48.06800588965416, 49.25168417394161, 49.845064133405685, 46.84457793831825, 44.47960004210472, 43.9095014333725, 44.60971266031265, 43.94095614552498, 44.6300757676363, 45.87427340447903, 46.53779000043869, 44.745365381240845, 47.752486020326614, 44.75405551493168, 45.82940921187401, 41.197784543037415, 45.41296675801277, 44.22569766640663, 53.56917589902878, 59.076759964227676, 58.811906576156616, 59.437911584973335, 59.67990539968014, 62.81464219093323, 53.02586205303669, 54.8026505112648, 58.25392931699753, 57.36597016453743, 57.958426773548126, 50.78924126923084, 47.177656665444374, 44.897471219301224, 40.29872618615627, 43.57451520860195, 43.141368851065636, 41.90442122519016, 42.028644159436226, 43.14988039433956, 42.01076231896877, 41.812154576182365, 43.94330441951752, 43.477001041173935, 43.66504915058613, 40.78258842229843, 40.3151299059391, 42.15611971914768, 42.85839423537254, 42.78873257339001, 41.8695542961359, 41.37268155813217, 43.57780583202839, 41.73034876585007, 41.96814000606537, 43.80305774509907, 44.92787718772888, 41.89188189804554, 41.06169864535332, 40.146639347076416, 40.576616674661636, 43.550971671938896, 41.61107696592808, 41.1586694419384, 49.09428521990776, 52.94688709080219, 55.095607191324234, 52.75018684566021, 57.56362035870552, 55.132241025567055, 59.798060059547424, 54.90936778485775, 59.32941220700741, 54.562119618058205, 55.89766055345535, 57.01556816697121, 55.109902024269104, 53.768247216939926, 54.65016849339008, 58.81451703608036, 55.08815199136734, 58.45263585448265, 51.533313542604446, 51.58370263874531, 17.11568757891655, 1.1723697348497808, 9.175462648272514, 2.6969967177137733, 7.622692119330168, 61.28028832376003, 63.78245025873184, 57.0690692961216, 39.82242554426193, 40.793345645070076, 49.6622559428215, 33.701269403100014, 0.4168890486471355, 0.28467122465372086, 0.3312044183257967, 0.19868280360242352, 0.17116554110543802, 0.11495870479848236, 0.11526616173796356, 0.15695229987613857, 0.11581276092329063, 0.13244309549918398, 0.17363914899760857, 0.2161984535632655, 0.1406863672309555, 0.17131780012277886, 0.16205048334086314, 0.15169391641393304], [0.015455853408639086, 0.07020813500275835, 0.032346179941669106, 0.16432495816843584, 0.04593289639160503, 0.02716568487812765, 0.014631585236202227, 0.059452637724461965, 0.09333139343652874, 0.049042984974221326, 0.042004582574008964, 0.019367427157703787, 0.04804924923519138, 0.08380988365388475, 0.051633863331517205, 0.046617857879027724, 0.04710082903329749, 0.03684882329253014, 0.05783395798061974, 0.08235007175244391, 5.943391229957342, 47.64613352715969, 43.393743708729744, 39.47931915521622, 28.07616524398327, 46.284723579883575, 51.90253213047981, 56.50923393666744, 16.940268091857433, 0.3343441186007112, 0.37349816760979593, 0.07238593767397106, 0.07028912557871081, 0.7365444023162127, 44.21888083219528, 60.731160789728165, 58.798949271440506, 59.27157171070576, 61.152827963232994, 58.82359094917774, 58.06544803082943, 58.745858520269394, 57.01457642018795, 56.70401528477669, 56.55240722000599, 57.17860221862793, 58.628095239400864, 57.18738354742527, 47.719575986266136, 43.46088990569115, 42.8424920886755, 42.90316343307495, 43.20311173796654, 40.69754138588905, 41.87861680984497, 41.151761412620544, 43.063590824604034, 41.99479557573795, 41.67545311152935, 42.33455814421177, 42.564970180392265, 41.140700206160545, 44.47920486330986, 43.06860655546188, 41.109750866889954, 42.01925486326218, 44.596774354577065, 41.00649140775204, 40.81598103046417, 38.96491415798664, 40.840938091278076, 39.84796017408371, 41.851026490330696, 43.19669768214226, 41.51735119521618, 41.32278263568878, 41.979087218642235, 41.937566846609116, 43.17127324640751, 41.17832958698273, 40.4638235270977, 41.31052829325199, 40.87760992348194, 40.072866305708885, 46.00303329527378, 50.946214646101, 54.312966987490654, 54.27910700440407, 57.07977332174778, 56.16950176656246, 56.45399250090122, 52.954178899526596, 56.90853551030159, 53.419501930475235, 54.72392253577709, 47.75276340544224, 41.740509420633316, 40.819663032889366, 40.105460956692696, 38.69316793978214, 38.62556956708431, 37.56209023296833, 38.24312388896942, 37.64698527753353, 38.77595789730549, 38.331415951251984, 38.705217093229294, 39.54738490283489, 38.75758208334446, 38.90130177140236, 39.89977419376373, 39.362540021538734, 39.80769753456116, 40.44595308601856, 40.15791334211826, 38.38042192161083, 41.152851954102516, 38.260192573070526, 39.811520129442215, 40.70427842438221, 41.12476386129856, 37.63516031205654, 39.15334224700928, 37.984825149178505, 38.747364431619644, 37.954966351389885, 38.50649915635586, 39.56304386258125, 52.91382126510143, 51.801586747169495, 55.44674634933472, 51.49827942252159, 53.567397594451904, 51.71893738210201, 53.00222732126713, 51.638298109173775, 55.86176387965679, 52.434298396110535, 54.13643606007099, 53.818849101662636, 54.21813927590847, 53.845500871539116, 56.66119158267975, 51.062602400779724, 57.592042833566666, 53.118299692869186, 47.30110824108124, 56.06225252151489, 5.521104214712977, 0.5705540499184281, 4.952455228194594, 0.43471588112879544, 19.79826383292675, 54.53204423189163, 49.41781505942345, 41.49904377758503, 23.43192145228386, 36.76777325570583, 41.07901431620121, 4.816680438816547, 0.5217598588205874, 0.08506688143825158, 0.04457271410501562, 0.13319401536136866, 0.03739365245564841, 0.06358370257657953, 0.020987617172067985, 0.007015993251116015, 0.030116738635115325, 0.040058378217509016, 0.06743029109202325, 0.03350787112140097, 0.029394751400104724, 0.03227602472179569, 0.05318121155141853, 0.007458312338712858, 0.043795889578177594, 0.07032070396235213, 0.0762926104653161, 0.0862897998013068, 0.0352476767875487, 0.027678852165990975, 0.024379306269111112, 0.042904800284304656, 0.036241393972886726, 0.01349682566797128, 0.026953753476846032, 0.028840534068876877, 0.015786982075951528, 0.020370577040011995, 0.08283033035695553, 0.08788186241872609, 0.07298268377780914, 0.10023338909377344, 0.08772771834628657, 0.10283977462677285, 10.320587251335382, 55.18848940730095, 46.22915916144848, 45.29309839010239, 37.80639812350273, 55.31271614134312, 56.12217150628567, 65.59407904744148, 16.357527561485767, 0.2854795125313103, 0.9335135424043983, 0.33005302073433995, 0.06132928800070658, 1.0907920310273767, 49.25282411277294, 62.18778222799301, 61.12347833812237, 61.52483180165291, 63.864921033382416, 60.83534739911556, 60.70095621049404, 60.29768384993076, 58.93483377993107, 57.15081810951233, 60.144206285476685, 58.05100120604038, 59.17398154735565, 57.73674666881561, 49.72529835999012, 44.921903908252716, 46.18329182267189, 45.13425171375275, 45.62952093780041, 43.43171887099743, 44.10003840923309, 43.74874725937843, 46.06119677424431, 45.39650224149227, 45.24829499423504, 43.73187996447086, 42.965867668390274, 42.717034220695496, 45.086461678147316, 44.985729083418846, 43.292935118079185, 44.62908402085304, 43.50644186139107, 42.754937186837196, 43.89083683490753, 42.21900634467602, 44.50394153594971, 40.69034457206726, 43.60386103391647, 45.09903900325298, 42.453818544745445, 43.6076570302248, 44.04095537960529, 43.477035239338875, 44.430217891931534, 42.41866663098335, 42.57647596299648, 43.30113507807255, 42.883556485176086, 41.33793622255325, 47.09985964000225, 54.45536054670811, 55.37186376750469, 56.82931736111641, 57.679449543356895, 58.58400620520115, 56.18993707001209, 57.035479098558426, 57.8964027017355, 55.70557326078415, 56.43702261149883, 49.55273821949959, 42.779993042349815, 42.851338014006615, 41.87637113034725, 41.26012399792671, 38.77503454685211, 40.037767589092255, 41.598879620432854, 40.66056177020073, 41.006609201431274, 40.761590749025345, 40.3451406955719, 40.98624609410763, 41.34712412953377, 39.799353182315826, 41.18577718734741, 40.88006839156151, 41.781129240989685, 41.69428110122681, 42.0953343808651, 39.64839108288288, 40.48573695123196, 41.040009409189224, 42.13887244462967, 41.744951382279396, 41.96687467396259, 39.47680748999119, 40.08807688951492, 38.74872475862503, 40.76461918652058, 39.283272475004196, 39.13286134600639, 43.053069189190865, 54.02772009372711, 54.88254502415657, 55.35666458308697, 54.05298113822937, 56.177196353673935, 54.21565800905228, 54.13125313818455, 54.175851345062256, 58.06952141225338, 55.508922412991524, 54.83951613306999, 54.13870833814144, 57.26559475064278, 56.019755601882935, 60.47414258122444, 54.56558123230934, 59.75997470319271, 53.25529374182224, 49.826353937387466, 57.524486258625984, 5.145548041909933, 0.5817228381056339, 5.190613623708487, 0.8548675593920052, 21.284459084272385, 61.4110317081213, 52.453103587031364, 49.18763481080532, 31.117267459630966, 34.046815261244774, 51.161963269114494, 6.570850135758519, 0.4734742466825992, 0.1388419818249531, 0.09532050506095402, 0.09491185628576204, 0.03984934119216632, 0.10123188199941069, 0.023567148091387935, 0.048259922696161084, 0.06423391299904324, 0.13267838599858806, 0.059961034858133644, 0.03846985193376895, 0.04443684912985191, 0.007054137786326464, 0.025489175131951924, 0.01622096406208584, 0.10423678599181585, 0.18347241275478154, 0.1732845211517997, 0.2631346631096676, 0.21065244334749877, 0.21194131637457758, 0.09230635390849784, 0.1053912189672701, 0.2515465911710635, 0.11592203474720009, 0.12061427827575244, 0.06071493815397844, 0.35455006873235106, 0.15179060341324657, 0.14032645529368892, 0.15533112280536443, 0.12211621447931975, 0.24456920073134825, 0.18588075618026778, 0.32367767533287406, 11.653649769723415, 69.81322824954987, 50.01064404845238, 52.284635826945305, 43.527792915701866, 58.295069709420204, 63.912479281425476, 69.7296479344368, 22.397383265197277, 0.39087145880330354, 1.1367056798189878, 0.33793005743063986, 0.21718304604291916, 1.6986184590496123, 49.919338747859, 63.498373702168465, 62.53911517560482, 64.66887429356575, 68.03292497992516, 62.70965002477169, 64.47679460048676, 61.178339794278145, 61.77173875272274, 60.345029309391975, 63.23535941541195, 61.39802500605583, 63.085495457053185, 63.29573057591915, 54.14624713361263, 48.14931772649288, 49.203065782785416, 47.65638157725334, 50.64275152981281, 45.506722927093506, 45.84126457571983, 46.504188403487206, 49.04491826891899, 48.14477317035198, 46.41353666782379, 46.28278948366642, 45.84622710943222, 43.87771233916283, 48.12015049159527, 47.47131630778313, 44.864302799105644, 47.49362491071224, 48.43296490609646, 45.149025321006775, 46.05502590537071, 43.77215400338173, 46.29937559366226, 43.258907943964005, 47.142155170440674, 48.798239305615425, 45.34519739449024, 46.36356554925442, 46.520831510424614, 46.76284812390804, 47.692871019244194, 43.38140957057476, 45.05192533135414, 46.16245374083519, 45.8511858433485, 41.95870131254196, 49.29328814148903, 56.74438811838627, 58.86028178036213, 58.05811062455177, 60.43194204568863, 59.793154522776604, 60.50415717065334, 58.35192605853081, 61.30282871425152, 57.72330678999424, 57.168684750795364, 52.226479947566986, 43.78620944917202, 43.33126366138458, 43.99728052318096, 43.28047178685665, 41.82659760117531, 44.14497099816799, 42.5764911621809, 43.02081651985645, 44.655154421925545, 42.97831580042839, 42.51927003264427, 43.81616324186325, 42.57532462477684, 43.610438480973244, 43.87935385107994, 42.9219838231802, 45.87249889969826, 44.43617597222328, 44.324366971850395, 43.71396392583847, 42.64462910592556, 42.23122648894787, 43.62193666398525, 44.625732600688934, 44.91604082286358, 41.89757019281387, 41.923367008566856, 42.19684213399887, 43.57916995882988, 41.62212677299976, 41.5311748534441, 45.42584806680679, 56.14203684031963, 55.64501591026783, 57.95581251382828, 56.97893813252449, 57.89621651172638, 55.29467090964317, 57.44159370660782, 56.27765156328678, 62.22471624612808, 56.88365064561367, 57.93575718998909, 56.159101724624634, 58.883095756173134, 57.9888479411602, 64.51492175459862, 56.78127273917198, 58.982988595962524, 56.172556802630424, 50.70809282362461, 55.48562206327915, 7.095727846026421, 0.9633970982395113, 11.713636200875044, 2.265114742331207, 25.731149576604366, 67.21169784665108, 58.99534173309803, 51.60721957683563, 37.31383055448532, 46.63957893848419, 60.10183475911617, 10.829092115163803, 0.9597735176794231, 0.22293745132628828, 0.23367193469312042, 0.18080124515108764, 0.20562989957397804, 0.2957831049570814, 0.06582367495866492, 0.10281113514793105, 0.13104236597428098, 0.14990961528383195, 0.15511677571339533, 0.10428319990751334, 0.20614036358892918, 0.08482137898681685, 0.1263904507504776, 0.12066858122125268], [0.02636374978465028, 0.011938909265154507, 0.026618764713930432, 0.04140059681958519, 0.03329640727315564, 0.009472961264691548, 0.1800282092881389, 0.0501397159678163, 0.046281642717076465, 0.06696433367324062, 0.05630662548355758, 0.031373012825497426, 0.0800321961287409, 0.06879921216750517, 0.10373434459324926, 0.03366813420143444, 0.04947637324221432, 0.014578542086383095, 0.09254006363335066, 0.11604348721448332, 0.47137052519246936, 27.724165432155132, 45.08278347551823, 41.40924699604511, 34.917078763246536, 34.04313325881958, 50.713773518800735, 55.68032741546631, 36.625280901789665, 0.35480569407809526, 0.05958010529866442, 0.08197570277843624, 0.07431382211507298, 0.11981811709119938, 20.826653949916363, 61.05637773871422, 53.34082715213299, 58.33215571939945, 58.38141247630119, 60.03984868526459, 57.509910240769386, 59.629721492528915, 56.09889395534992, 55.79389952123165, 59.39956024289131, 58.35505709052086, 58.19692477583885, 57.35018201172352, 54.63219925761223, 48.40874880552292, 40.87954021990299, 43.49937804043293, 43.061474338173866, 43.17413069307804, 42.252129167318344, 41.39513835310936, 41.68579615652561, 42.47768506407738, 42.11273364722729, 42.285445779562, 42.95776270329952, 42.65654146671295, 42.09923297166824, 44.256563410162926, 40.634335577487946, 40.13617090880871, 41.68485380709171, 40.954027622938156, 42.38424427807331, 43.03799919784069, 40.087058544158936, 39.764699041843414, 39.381029829382896, 41.68478921055794, 40.52328273653984, 42.157700434327126, 39.53919254243374, 41.290020793676376, 45.53413465619087, 44.57106873393059, 39.65038597583771, 40.34446433186531, 41.25393033027649, 40.999484583735466, 46.064426600933075, 47.16902352869511, 51.95256404578686, 51.2931702286005, 65.94536259770393, 67.73853197693825, 57.38491594791412, 55.829104632139206, 56.230268105864525, 52.313062101602554, 49.15817879140377, 44.39665049314499, 44.326236471533775, 43.45758408308029, 42.34629571437836, 41.99950732290745, 40.3201038390398, 41.81849643588066, 40.711657628417015, 39.96401734650135, 38.09085085988045, 36.75950489938259, 38.80648545920849, 38.27532336115837, 39.930218160152435, 35.70031173527241, 38.0830954760313, 37.28780195116997, 39.917021468281746, 40.9981432557106, 41.33964993059635, 39.92466285824776, 39.11738097667694, 40.51232412457466, 37.45910435914993, 39.62145812809467, 38.60394112765789, 40.323588252067566, 41.01971849799156, 37.89686746895313, 37.83859759569168, 38.123536705970764, 39.06339347362518, 41.904672011733055, 52.3347133398056, 52.607002928853035, 51.7250170558691, 53.9189737290144, 53.670687451958656, 51.64112135767937, 52.78412662446499, 56.10216177999973, 52.906233072280884, 52.2324076294899, 55.349004194140434, 53.999347016215324, 56.58107668161392, 54.18951541185379, 53.37490372359753, 49.42915365099907, 55.43014883995056, 49.37779940664768, 63.13480161130428, 40.92175215482712, 0.9140939719509333, 0.20802519604330882, 2.568330396898091, 0.17987050290685147, 36.1360077559948, 55.127723067998886, 46.36619120836258, 31.47475227713585, 25.663942582905293, 36.52160346508026, 21.29276543855667, 0.08832534760585986, 0.04416790965478867, 0.074186514102621, 0.11197350482689217, 0.02035190274909837, 0.07147744501708075, 0.046421403967542574, 0.02436161903460743, 0.01606170288141584, 0.035651126818265766, 0.03299308409623336, 0.02727094182773726, 0.028179536529933102, 0.0071201495029526995, 0.033405217254767194, 0.06495844951132312, 0.055991446497500874, 0.05322353623341769, 0.019533889026206452, 0.03317824252007995, 0.02632077015732648, 0.025770057618501596, 0.006178921639730106, 0.03508342837449163, 0.031277728485292755, 0.015886958644841798, 0.041271121735917404, 0.029109555180184543, 0.05277569835016038, 0.0334582882351242, 0.05656422865286004, 0.02543913396948483, 0.025405102787772194, 0.020803638763027266, 0.0254154594585998, 0.006991641530476045, 0.27062872191891074, 0.9109533810988069, 40.788877084851265, 51.01162053644657, 43.76722186803818, 41.662260219454765, 47.1219402551651, 55.69102764129639, 63.01643796265125, 38.9134269207716, 0.163768881757278, 0.3183058323338628, 0.7110952085349709, 0.4596324503654614, 0.4050141217885539, 25.077609345316887, 63.24230544269085, 56.788674741983414, 61.083249896764755, 59.3445847928524, 61.199170276522636, 60.45492321252823, 60.03192991018295, 58.652064353227615, 57.65612259507179, 60.19835717976093, 60.40269881486893, 60.787644758820534, 57.010028064250946, 57.54600450396538, 49.20970782637596, 45.83705820143223, 45.41303135454655, 46.164954006671906, 46.42427869141102, 45.40862359106541, 44.80022303760052, 42.35157363116741, 44.188740849494934, 44.41208526492119, 43.769406750798225, 43.407859951257706, 45.41154183447361, 43.42270955443382, 45.13568423688412, 43.45583617687225, 43.94433416426182, 44.311383068561554, 46.580378115177155, 44.13120053708553, 43.24419513344765, 44.26444798707962, 41.75778329372406, 42.73385211825371, 43.79594072699547, 42.27040618658066, 43.424605652689934, 41.70916490256786, 42.689318507909775, 46.47097058594227, 47.415010929107666, 41.79372936487198, 42.94009745121002, 43.47374841570854, 43.46155487000942, 47.29709565639496, 51.11933335661888, 55.49821458756924, 57.709042355418205, 59.35842365026474, 59.889205768704414, 59.41465683281422, 56.66456580162048, 57.77948297560215, 54.58203434944153, 50.152406841516495, 46.118433102965355, 44.85718198120594, 44.25608083605766, 44.7833177447319, 44.04096677899361, 41.433979868888855, 41.80314525961876, 42.102690786123276, 41.339988112449646, 41.43283613026142, 39.472870901227, 41.422447487711906, 41.282474398612976, 40.118581652641296, 39.27758798003197, 39.323162734508514, 40.906545370817184, 41.203282848000526, 41.23420558869839, 42.14465193450451, 42.299379631876945, 41.131687089800835, 41.340493485331535, 40.35484917461872, 41.363816633820534, 39.70392510294914, 41.969473734498024, 41.556192710995674, 40.40753714740276, 38.89236465096474, 40.26457741856575, 40.43855108320713, 44.31858368217945, 56.03196434676647, 54.27610136568546, 53.94505932927132, 56.37939490377903, 53.51089842617512, 54.153675734996796, 54.71580997109413, 55.507516488432884, 56.05178788304329, 54.65176060795784, 55.56606374680996, 55.258546248078346, 57.46037229895592, 54.21848125755787, 55.5925977230072, 52.735485434532166, 55.280547067523, 50.56459352374077, 63.42898182570934, 38.968596160411835, 0.787510295631364, 1.1010557552799582, 3.134458218701184, 0.2859527652617544, 40.232005566358566, 60.792303308844566, 50.82437798380852, 35.95706395804882, 28.02987802773714, 37.75537446141243, 28.693079240620136, 0.1902815286302939, 0.056555734772700816, 0.0747047780896537, 0.032405496094725095, 0.02965078307170188, 0.0802521019068081, 0.053483443771256134, 0.04741781885968521, 0.021298027859302238, 0.03972243765019812, 0.029729855195910204, 0.013217795767559437, 0.029162863647798076, 0.022887539344083052, 0.015290541869035223, 0.025913696590578184, 0.0239371792122256, 0.17883418273413554, 0.13702845491934568, 0.15181294205831364, 0.11710976788890548, 0.10525261546717957, 0.07069741070154123, 0.3289668430807069, 0.15020853752503172, 0.09924172394676134, 0.1640654291259125, 0.1543020163080655, 0.10710578790167347, 0.17213082290254533, 0.14013124076882377, 0.11662881908705458, 0.15205286355922, 0.16363861999707296, 0.05164674701518379, 0.14008219965035096, 0.2882381941890344, 0.9472745039965957, 46.12220250070095, 62.33169570565224, 50.73403023183346, 50.85499294102192, 49.737427309155464, 62.248343378305435, 69.82580557465553, 47.32304826378822, 0.3503576765069738, 0.39190289564430714, 0.6977142265532166, 0.24010118970181793, 0.6425144104287028, 27.786062210798264, 63.5750649869442, 57.51075379550457, 63.22231471538544, 63.050518333911896, 64.04975831508636, 62.130238115787506, 61.183655709028244, 60.52844166755676, 59.78012502193451, 61.56568720936775, 62.45504088699818, 64.28782314062119, 61.0694794356823, 60.638172179460526, 51.700109392404556, 46.323416903615, 47.629380226135254, 47.84661456942558, 47.14711390435696, 47.63536110520363, 47.161743119359016, 45.776523649692535, 47.63205148279667, 46.7278216034174, 45.82274056971073, 45.04206106066704, 48.42440776526928, 46.591021344065666, 48.74612510204315, 45.09851463139057, 45.19840367138386, 46.84198647737503, 49.9962542206049, 48.28118585050106, 46.791661977767944, 45.80466493964195, 44.079549908638, 43.09906952083111, 45.795070454478264, 46.16798244416714, 46.99530445039272, 44.531509056687355, 46.20515204966068, 50.29942475259304, 50.41899673640728, 42.49188870191574, 44.51615408062935, 45.8090765029192, 45.275072157382965, 49.36674579977989, 52.44040086865425, 56.42374612390995, 58.978341445326805, 60.4176814109087, 63.41195493936539, 58.89299422502518, 61.208464577794075, 60.82435078918934, 55.638031885027885, 50.67739047110081, 46.71198405325413, 48.08599412441254, 47.105779722332954, 46.52482509613037, 46.69424280524254, 42.8463488817215, 45.59275031089783, 44.969511553645134, 42.597811818122864, 44.005146101117134, 41.61483496427536, 43.80742751061916, 43.6573089659214, 41.809426322579384, 40.59494689106941, 43.66211950778961, 41.927618980407715, 44.87894341349602, 43.024977296590805, 45.31840123236179, 43.3537470549345, 43.416512086987495, 43.19221772253513, 42.18747943639755, 44.93420384824276, 41.638781279325485, 44.91661079227924, 43.58795128762722, 42.38881163299084, 41.793881356716156, 42.9604871571064, 44.04723264276981, 46.88515976071358, 58.902698904275894, 58.417943716049194, 57.19752140343189, 58.06872345507145, 57.99119621515274, 58.106288239359856, 55.16757532954216, 57.832395136356354, 56.95595696568489, 57.1486522257328, 57.39404685795307, 56.34948670864105, 58.29005017876625, 55.67811593413353, 56.534430384635925, 53.09780739247799, 56.8275086581707, 52.50503920018673, 60.004594177007675, 41.107539385557175, 1.4130298211239278, 1.0138790518976748, 9.83315510675311, 1.722009766381234, 43.21212865412235, 67.11424827575684, 55.19120246171951, 43.499587029218674, 39.20968182384968, 48.181665390729904, 41.2828353792429, 0.5629908526316285, 0.14860155031783506, 0.21158395742531866, 0.1461331226164475, 0.09631580673158169, 0.26777385792229325, 0.12279897549888119, 0.18661007954506204, 0.12311823258642107, 0.21614926401525736, 0.12822267977753654, 0.06868840209790505, 0.12512387183960527, 0.1182183509808965, 0.08042229121201672, 0.17502257163869217, 0.134328996646218], [0.0105403059933451, 0.03453784222074319, 0.009135050295299152, 0.02223536965175299, 0.07321916171349585, 0.06335735495667905, 0.06086076646170113, 0.07315973052754998, 0.03699270346260164, 0.0857110285141971, 0.038122315309010446, 0.07715342013398185, 0.02727631312154699, 0.04655771052057389, 0.017814420061768033, 0.02151218013750622, 0.09439540313906036, 0.03393367835087702, 0.05883797988644801, 0.043862530728802085, 0.1262726867571473, 2.801726460456848, 39.79099363088608, 42.82112203538418, 37.223855182528496, 27.9232120513916, 41.87123380601406, 52.841062769293785, 54.60098013281822, 3.965419717133045, 0.5312649894040078, 0.1552587782498449, 0.17934598261490464, 0.24194683675887063, 6.133734891191125, 57.81626880168915, 58.33415821194649, 58.21262553334236, 56.680612340569496, 60.07696509361267, 57.75805212557316, 60.992009192705154, 61.61938212811947, 58.49058821797371, 56.59918650984764, 59.45156045258045, 57.90124364197254, 57.24909983575344, 57.76565171778202, 53.10803264379501, 44.846493154764175, 44.53330256044865, 46.376967430114746, 42.328904047608376, 40.29448181390762, 43.16851079463959, 42.89194643497467, 42.009246200323105, 44.42557454109192, 43.411633148789406, 44.503990933299065, 42.36406736075878, 41.53159663081169, 42.806306630373, 42.655181139707565, 42.80516669154167, 42.44418606162071, 40.50725519657135, 42.51265078783035, 41.2224680185318, 42.196021378040314, 39.99440051615238, 40.43716035783291, 40.30101366341114, 43.50296884775162, 42.480675503611565, 39.610491916537285, 41.84555098414421, 42.948331609368324, 42.23884887993336, 43.07608835399151, 38.778682351112366, 43.43453451991081, 42.89907865226269, 51.974994242191315, 49.18958030641079, 56.49526208639145, 49.741527289152145, 82.3258276283741, 94.86320167779922, 54.97171863913536, 56.24544449150562, 53.95257152616978, 50.87053410708904, 47.58269593119621, 47.85853452980518, 48.3673120290041, 47.57982328534126, 46.474227011203766, 45.57504326105118, 44.13710542023182, 42.37295128405094, 39.54590678215027, 40.00141493976116, 41.27869360148907, 41.58312186598778, 38.73846150934696, 39.56716664135456, 39.505119770765305, 41.19706638157368, 37.383112236857414, 38.9767999202013, 41.591188833117485, 41.822075843811035, 41.13569587469101, 40.25842174887657, 40.73546715080738, 40.58360069990158, 40.794348791241646, 40.73770523071289, 39.710092172026634, 38.237458392977715, 39.478699788451195, 39.13036487996578, 39.231040477752686, 40.97957745194435, 38.58792878687382, 44.42425221204758, 49.045264050364494, 50.50567768514156, 51.09999619424343, 51.92338541150093, 48.864412754774094, 54.39814321696758, 54.295062348246574, 50.622669607400894, 51.899085715413094, 50.688767060637474, 52.5878519564867, 53.534221574664116, 52.51639299094677, 51.84645093977451, 52.36869491636753, 55.702335834503174, 52.62244910001755, 59.08155910670757, 59.15385402739048, 16.66803739964962, 0.20360066002467647, 0.47464268398471177, 1.5814485400915146, 1.461617813911289, 43.58191341161728, 50.41160233318806, 35.058773159980774, 35.67725457251072, 34.867624416947365, 28.825927712023258, 2.49403013382107, 0.38381571241188794, 0.04356333760370035, 0.11847808782476932, 0.08126090324367397, 0.06035082937160041, 0.06481114804046229, 0.06648614566074684, 0.01732640972477384, 0.022411633435694966, 0.06135003102826886, 0.0669052216107957, 0.02155591304472182, 0.027065127578680404, 0.041131761245196685, 0.02499378599168267, 0.0634349390747957, 0.05709618155378848, 0.03087262717599515, 0.022441701548814308, 0.013145614484528778, 0.049007673587766476, 0.076224510994507, 0.0192103979861713, 0.07980207839864306, 0.034458358204574324, 0.03610909130657092, 0.03750152733118739, 0.017374144663335755, 0.02353106301598018, 0.02270482073072344, 0.022466645132226404, 0.06978431672905572, 0.021878524639760144, 0.06356275174766779, 0.024120578746078536, 0.10877774271648377, 0.07161626373999752, 0.09228368871845305, 6.852537095546722, 51.40664353966713, 46.28995209932327, 44.34130646288395, 39.934891909360886, 51.83887414634228, 58.38033713400364, 60.15003137290478, 4.226180724799633, 0.8323807222768664, 3.0155452620238066, 1.1402259534224868, 0.033084906317526475, 8.187609706074, 61.157098934054375, 59.03606414794922, 59.008827209472656, 60.59621103107929, 63.11300978064537, 60.95647729933262, 58.973872885107994, 62.887598276138306, 59.32071067392826, 57.94533647596836, 60.37192426621914, 60.488490611314774, 59.14685480296612, 59.489345625042915, 55.23523449897766, 47.68214799463749, 45.27562692761421, 46.78705282509327, 44.92384560406208, 41.226906180381775, 46.82259611785412, 44.597975090146065, 46.04732371866703, 45.214283019304276, 45.42752377688885, 45.93233808875084, 46.025315299630165, 46.68389976024628, 47.29165814816952, 45.490558594465256, 43.33814509212971, 42.4957986921072, 43.44580851495266, 44.76185269653797, 43.80764789879322, 44.97971400618553, 43.79971772432327, 43.30488167703152, 43.28909732401371, 42.81708665192127, 44.07025560736656, 41.680370047688484, 44.90258574485779, 44.6369343996048, 45.603990107774734, 45.10792672634125, 42.612106651067734, 43.836378157138824, 42.757680639624596, 49.33378256857395, 51.09800510108471, 54.54105354845524, 56.91605530679226, 74.95489194989204, 71.02176859974861, 58.542284443974495, 58.67458574473858, 57.435476034879684, 51.997470036149025, 49.54836845397949, 49.1557203233242, 50.67826062440872, 48.94944839179516, 47.14043006300926, 47.51122556626797, 45.1819771528244, 43.43155547976494, 42.11483873426914, 41.21470883488655, 42.66355209052563, 41.92419536411762, 41.64811357855797, 41.73574447631836, 41.95535369217396, 42.76058368384838, 41.02598436176777, 41.978555247187614, 43.77682015299797, 42.29031711816788, 42.17395976185799, 40.53741417825222, 42.340592220425606, 42.37335406243801, 42.8753337264061, 42.58453153073788, 39.996076226234436, 40.639978274703026, 39.51852165162563, 41.795063093304634, 40.98822958767414, 40.77468864619732, 42.60756589472294, 45.14563210308552, 51.917507126927376, 51.741929948329926, 55.00000052154064, 55.35820730030537, 53.57539616525173, 55.32241702079773, 53.53394038975239, 50.63851095736027, 53.66197071969509, 52.21428640186787, 53.96764151751995, 53.644617050886154, 55.087015852332115, 51.2897390127182, 52.44302272796631, 56.89168341457844, 54.746683314442635, 56.99699856340885, 58.782648146152496, 18.312855139374733, 0.7686517888214439, 1.9405253534205258, 2.8960452368482947, 2.3902265913784504, 50.194930359721184, 54.00201827287674, 39.85638052225113, 40.92063881456852, 39.19466122984886, 37.34346516430378, 5.096129793673754, 0.25921155174728483, 0.06304124457528815, 0.0625965125800576, 0.05333184526534751, 0.05190365627640858, 0.04856207699049264, 0.05423021131718997, 0.0055378447359544225, 0.06058589351596311, 0.08659911210997961, 0.06921339736436494, 0.012787363102688687, 0.1267718552844599, 0.03988166914496105, 0.04821293732675258, 0.05060029281594325, 0.03789074296946637, 0.15043039515148848, 0.10074865480419248, 0.19837516854749992, 0.18052871368126944, 0.1719731610501185, 0.15575908968457952, 0.21164209727430716, 0.1974641377455555, 0.10714551506680436, 0.18787857319694012, 0.13330560468602926, 0.1715896191308275, 0.08917243496398441, 0.14638077729614452, 0.15904009487712756, 0.18777119927108288, 0.22312531858915463, 0.1584211437148042, 0.2130867470987141, 0.21241312933852896, 0.23609227122506127, 7.85817070864141, 64.570132791996, 52.50765345990658, 49.86832268536091, 40.4323536157608, 54.80298109352589, 60.99343031644821, 68.30579593777657, 5.940104406327009, 1.4688374265097082, 4.053211156278849, 0.8204068522900343, 0.34200032183434814, 9.174574445933104, 64.49826344847679, 59.76435586810112, 61.70924350619316, 62.5740846991539, 66.3405641913414, 63.92238914966583, 63.00037242472172, 65.86731478571892, 62.82656595110893, 59.59631748497486, 62.375188171863556, 63.81852552294731, 62.60712392628193, 62.880994230508804, 57.91835032403469, 50.43872907757759, 48.807560205459595, 51.306112334132195, 48.26077714562416, 44.29516553878784, 50.25134213268757, 48.451124131679535, 46.93502448499203, 48.97454224526882, 47.15430311858654, 48.296977803111076, 48.299953043460846, 47.25621744990349, 50.12447074055672, 46.788884326815605, 45.245376750826836, 44.724656492471695, 45.14241747558117, 47.05472566187382, 46.40323922038078, 48.43052163720131, 45.48489689826965, 46.10333651304245, 46.10765688121319, 47.55231276154518, 46.92820005118847, 43.926691710948944, 46.5973100066185, 47.55150720477104, 47.07756623625755, 46.14746734499931, 43.76542456448078, 46.43439754843712, 45.922952592372894, 53.707192093133926, 53.21902468800545, 60.225404128432274, 57.23958894610405, 80.73270231485367, 74.39123019576073, 55.89211285114288, 61.39852657914162, 58.51607345044613, 55.14447256922722, 52.02484756708145, 51.914034113287926, 52.33787477016449, 50.965764597058296, 50.34127190709114, 50.26333428919315, 46.4830007404089, 45.99403157830238, 45.466384291648865, 44.2337304353714, 46.76859721541405, 45.484855100512505, 45.25708392262459, 45.38153104484081, 44.998925775289536, 46.38745106756687, 43.277473747730255, 42.89801090955734, 46.82424142956734, 46.513551101088524, 44.66870069503784, 43.68916265666485, 45.205330699682236, 44.219560995697975, 43.283519223332405, 44.878069460392, 43.20902042090893, 43.29729348421097, 41.96438580751419, 42.785567343235016, 43.13885718584061, 44.08694811165333, 43.734410628676414, 47.02981799840927, 54.06142048537731, 51.90619133412838, 56.54595136642456, 58.42456296086311, 53.99996638298035, 55.222280994057655, 56.0739216953516, 51.662514209747314, 55.159234777092934, 53.18301022052765, 56.157163828611374, 56.0585705190897, 55.592077150940895, 53.280102610588074, 54.778609201312065, 58.30117978155613, 57.365468591451645, 56.56080476939678, 58.40610355138779, 21.492288932204247, 0.7182524807285517, 1.5743808005936444, 6.11167517490685, 2.4001611582934856, 55.40119059383869, 61.01880915462971, 45.47231577336788, 46.09911113977432, 47.210414707660675, 52.526268661022186, 11.841886918991804, 0.7055163953918964, 0.2568986633559689, 0.20456638711038977, 0.22463287285063416, 0.17402426426997408, 0.16103675414342433, 0.22639105038251728, 0.15761871880386025, 0.20554599235765636, 0.21612180455122143, 0.1739762770012021, 0.10285343756549992, 0.1828247998491861, 0.11587354281800799, 0.11080864467658103, 0.15913788025500253, 0.26978774985764176], [0.06141640871646814, 0.033668286341708153, 0.08745700513827614, 0.05504031003511045, 0.004937410158163402, 0.07853955161408521, 0.04275201805285178, 0.07045283593470231, 0.019956083851866424, 0.10339972504880279, 0.02877988576074131, 0.06094302982091904, 0.04412394111568574, 0.04282648143998813, 0.016458905884064734, 0.07778209343086928, 0.0587813911261037, 0.07986924276337959, 0.020988696996937506, 0.06366769142914563, 0.18288084684172645, 0.4617052391404286, 15.353629980236292, 40.49115166068077, 34.171646162867546, 32.63505421578884, 32.20273621380329, 51.49431623518467, 57.80474781990051, 21.359489858150482, 1.2565309437923133, 0.15311775641748682, 2.160489968955517, 0.15684574231272563, 0.257131727412343, 29.907163493335247, 62.935395911335945, 54.307514280080795, 58.31665635108948, 58.82446490228176, 59.54302914440632, 57.39240534603596, 58.4573096036911, 58.502941355109215, 57.78967782855034, 58.24825622141361, 58.980811312794685, 57.572249695658684, 59.50232572853565, 53.083208575844765, 47.612547129392624, 42.67220422625542, 43.20888362824917, 45.947290286421776, 49.24797937273979, 49.35752369463444, 49.26366873085499, 53.41514736413956, 54.087243899703026, 49.4242063164711, 50.014295652508736, 45.20203247666359, 44.586689695715904, 43.67024727165699, 45.00440128147602, 43.3227901160717, 43.522594794631004, 42.14949667453766, 42.50397205352783, 42.76331953704357, 43.14342074096203, 41.74854598939419, 40.6060004979372, 41.09362073242664, 40.77770568430424, 42.89614520967007, 43.18496011197567, 42.51542083919048, 43.46329137682915, 42.236420810222626, 41.322364658117294, 40.684207901358604, 41.819066405296326, 44.807115867733955, 51.9658899307251, 54.150012731552124, 57.3598562926054, 54.186114594340324, 64.12527546286583, 99.55621585249901, 72.87484556436539, 55.90365283191204, 55.67432373762131, 53.28117795288563, 51.28785811364651, 53.888316974043846, 55.96027359366417, 56.78319163620472, 55.26593305170536, 51.93464420735836, 45.038671642541885, 40.97800433635712, 42.145206704735756, 40.37779614329338, 39.821338802576065, 39.36721757054329, 40.608557760715485, 40.25133512914181, 38.39801877737045, 40.00413179397583, 39.5160935819149, 40.25737300515175, 39.46622885763645, 40.76773501932621, 40.15367656946182, 39.47463400661945, 38.819530159235, 39.77552846074104, 39.61154825985432, 40.17957217991352, 40.971126705408096, 40.41373461484909, 38.72532181441784, 39.73317213356495, 37.95275866985321, 39.36783693730831, 39.216023683547974, 45.176087468862534, 49.460612162947655, 51.26741521060467, 50.05514346063137, 49.681004136800766, 56.644613072276115, 51.9865608215332, 50.10448761284351, 54.6156245470047, 55.61550669372082, 52.457040175795555, 52.013831958174706, 57.215205654501915, 54.499829560518265, 59.22301031649113, 55.096028968691826, 56.96506127715111, 52.00168780982494, 54.652767553925514, 39.73135203123093, 1.4287572959437966, 0.1733891639742069, 1.2099864101037383, 2.1204325184226036, 5.334703791886568, 57.945914044976234, 46.12456977367401, 35.361966490745544, 33.316597044467926, 23.738798685371876, 15.273350737988949, 0.532257508020848, 0.03773155600356404, 0.07695945241721347, 0.017052662988135125, 0.09312722118920647, 0.049361859855707735, 0.026432507911522407, 0.06682550010737032, 0.08355931975529529, 0.0362051920092199, 0.1001432997873053, 0.030025346859474666, 0.025203370350936893, 0.03408996723010205, 0.04508209087362047, 0.038462341399281286, 0.025547211080265697, 0.05209802846366074, 0.05758919767686166, 0.05571214293013327, 0.08224994118791074, 0.05196355872612912, 0.03819388432020787, 0.05511606104846578, 0.03093146649916889, 0.036709050909848884, 0.06371703682816587, 0.06006129158777185, 0.035967994190286845, 0.025797333400987554, 0.05508196307346225, 0.04408832544868346, 0.08493914298014715, 0.04096169810509309, 0.06459447060478851, 0.04925298679154366, 0.1813492173096165, 0.008645170673844405, 0.09157542750472203, 0.8944312739185989, 28.032473288476467, 49.95916061103344, 37.864497005939484, 38.68551895022392, 43.94748419523239, 56.78543731570244, 67.09477052092552, 24.351605102419853, 0.9462385845836252, 2.9132951237261295, 4.038786655291915, 1.1404792335815728, 0.4330995725467801, 33.311056941747665, 66.26799568533897, 56.503944620490074, 59.70215320587158, 61.765894666314125, 63.71254540979862, 59.88052323460579, 60.18590524792671, 60.167145654559135, 61.24100603163242, 58.585693314671516, 59.000361263751984, 63.638783767819405, 59.64260660111904, 55.52615448832512, 50.91658003628254, 44.74847361445427, 44.385346099734306, 46.07479244470596, 49.70326714217663, 51.90107300877571, 54.4840794056654, 53.77254478633404, 56.08468271791935, 52.11447715759277, 51.67441517114639, 46.76874540746212, 46.58223241567612, 46.946230083703995, 46.70830585062504, 45.26941046118736, 44.59865145385265, 42.95037589967251, 44.956349059939384, 44.69418592751026, 44.62303474545479, 44.81085866689682, 44.506529197096825, 42.92996719479561, 44.24205578863621, 44.8397371172905, 43.02863270044327, 45.029897913336754, 46.64050228893757, 43.9351462572813, 44.628175869584084, 42.1762852370739, 44.8246481269598, 46.76605135202408, 51.35058514773846, 57.08868384361267, 58.19193944334984, 55.41604779660702, 73.07533040642738, 84.62741732597351, 62.73593321442604, 59.01827350258827, 59.26154024899006, 53.42576019465923, 53.029692247509956, 54.94427651166916, 59.09884437918663, 56.99534185230732, 54.952643662691116, 51.547289192676544, 46.60692349076271, 41.56802907586098, 42.92569622397423, 42.74826854467392, 42.56049022078514, 40.62005214393139, 41.21036186814308, 40.877484530210495, 40.72576627135277, 41.17776721715927, 41.20312325656414, 41.16517849266529, 42.11666643619537, 41.547137796878815, 42.199118211865425, 40.58633655309677, 40.50064355134964, 42.47377507388592, 41.60700738430023, 42.41280734539032, 40.41646286845207, 41.69070929288864, 42.13138684630394, 39.22253653407097, 40.419046729803085, 41.27294071018696, 41.44273839890957, 48.3511058986187, 51.27225615084171, 53.574423417449, 52.14801035821438, 52.22102344036102, 57.38683104515076, 53.0659195035696, 51.87356248497963, 54.39106039702892, 55.12965716421604, 55.36662004888058, 53.38619291782379, 58.44117946922779, 54.398413002491, 60.39593517780304, 55.034183487296104, 58.71134877204895, 52.18365624547005, 54.38871972262859, 39.74668800830841, 1.9509043777361512, 1.6139936749823391, 3.7368256459012628, 1.6393384337425232, 5.408689621835947, 62.67489328980446, 54.072759076952934, 40.23539498448372, 43.68436351418495, 29.744978696107864, 24.73488863557577, 0.43381497322116047, 0.05310474807629362, 0.11801562592154369, 0.009634337566239992, 0.10851779064978473, 0.06293849422945641, 0.04689144690928515, 0.014569720733561553, 0.029553773238149006, 0.06298055915976875, 0.033364306364092045, 0.0341742343880469, 0.030083536803431343, 0.0264448145753704, 0.15755842672660947, 0.009941527332557598, 0.021219302689132746, 0.0987844867631793, 0.12434659089194611, 0.14280932518886402, 0.1451700969482772, 0.1328811259008944, 0.16281814605463296, 0.17394768947269768, 0.24418197775958106, 0.11000692480592988, 0.147379485424608, 0.1890658016782254, 0.0807180890114978, 0.15083692880580202, 0.14661014545708895, 0.09945112091372721, 0.19335400516865775, 0.12207507723360322, 0.144496449502185, 0.218587530835066, 0.2702517405850813, 0.14386250695679337, 0.2885881019756198, 0.9387331560719758, 36.76252193748951, 59.22494821250439, 45.130159333348274, 48.181760385632515, 47.19117633998394, 61.52554236352444, 69.43988308310509, 30.95344115048647, 1.71637621242553, 6.561329271644354, 6.848985236138105, 1.1368385539390147, 0.9228050045203418, 35.110575780272484, 66.27402976155281, 58.28513324260712, 62.30939470231533, 64.43076387047768, 64.38798576593399, 64.3943390250206, 62.9167503118515, 61.3639522343874, 62.37841799855232, 63.12276765704155, 60.7344514131546, 64.52011227607727, 64.51410099864006, 56.45246498286724, 53.971281722187996, 48.82076449692249, 47.95766361057758, 49.454540088772774, 53.61733451485634, 53.83172281086445, 56.24697960913181, 56.105558797717094, 59.49200548231602, 54.48866955935955, 55.558403357863426, 49.71654362976551, 48.93154755234718, 47.91266642510891, 49.32485304772854, 47.5295177847147, 48.39994087815285, 45.01856692135334, 48.20272386074066, 47.67354905605316, 47.44773857295513, 46.806059405207634, 47.010826617479324, 45.962364077568054, 48.05168956518173, 48.042216673493385, 47.37674318253994, 47.854024171829224, 50.14810927212238, 45.579097643494606, 45.55330462753773, 42.80665621161461, 48.38708616793156, 49.134076684713364, 57.22096234560013, 57.67023503780365, 63.63441400229931, 54.94375593960285, 80.25932371616364, 92.11088016629219, 58.22802610695362, 61.50259539484978, 56.45181141793728, 57.70551614463329, 55.25278575718403, 57.21739433705807, 59.62920092046261, 61.47825010120869, 58.28179322183132, 55.03386050462723, 48.088274002075195, 45.12604795396328, 44.971210062503815, 46.113014593720436, 44.32518012821674, 41.74827620387077, 45.572862178087234, 44.061185494065285, 43.139807134866714, 44.08565238118172, 42.12379865348339, 43.94858993589878, 44.68378208577633, 44.33139279484749, 44.58500258624554, 43.08476708829403, 42.42864869534969, 45.72630174458027, 43.036399483680725, 44.74922217428684, 44.59521263837814, 45.203974172472954, 45.28092384338379, 42.518544271588326, 40.90459607541561, 42.570647075772285, 42.7187555283308, 50.33645376563072, 53.15025217831135, 57.47016817331314, 55.67803993821144, 53.93984980881214, 56.848240345716476, 55.684028416872025, 55.07557086646557, 58.423225432634354, 56.06035262346268, 57.32722744345665, 57.59422391653061, 59.944200217723846, 54.60952587425709, 63.90368655323982, 56.42857946455479, 59.34414021670818, 54.85647462308407, 56.199645549058914, 41.973710507154465, 2.7352582896128297, 1.2587628490291536, 5.582912173122168, 6.025425503030419, 6.7434492241591215, 69.52635124325752, 60.22180192172527, 42.869208455085754, 47.416656240820885, 38.699798583984375, 39.08858232200146, 1.4772950601764023, 0.22293253830866888, 0.20484978362219408, 0.0914845366787631, 0.21202991396421567, 0.25256273976992816, 0.07869455657782964, 0.15556656173430383, 0.1817867430509068, 0.10805697631440125, 0.21330137620680034, 0.10056527753476985, 0.19145703117828816, 0.12977489648619667, 0.1927839615382254, 0.15462305455002934, 0.09595372030162252, 0.14796201197896153], [0.0399052954162471, 0.012946230945090065, 0.0377670195302926, 0.04488047903578263, 0.006293344576988602, 0.04885442009253893, 0.03165446862112731, 0.055518141816719435, 0.04429238637385424, 0.04837587955989875, 0.013755800882790936, 0.05801632592920214, 0.05098350447951816, 0.02035995690675918, 0.0666006887331605, 0.1138995710061863, 0.06471462431363761, 0.05070474639069289, 0.03385898489796091, 0.03788554051425308, 0.1532938829041086, 0.06267532124184072, 1.1572048673406243, 24.124852269887924, 34.32582288980484, 32.99226924777031, 23.81362047046423, 37.72994242608547, 48.61454576253891, 41.73933528363705, 0.9139277308713645, 2.8673527389764786, 3.6788305453956127, 0.22287046507699415, 0.048820663505466655, 3.933604024350643, 48.435123190283775, 58.61163832247257, 54.620397090911865, 60.26977054774761, 62.173267006874084, 59.03003387153149, 58.868964314460754, 60.582657158374786, 59.64156925678253, 57.39949196577072, 55.52515894174576, 61.69170744717121, 58.407019302248955, 56.20084248483181, 50.11967159807682, 43.71100768446922, 43.590930327773094, 51.56058847904205, 50.89570015668869, 56.79656691849232, 56.38393186032772, 57.75273621082306, 55.384061112999916, 56.334903091192245, 54.324757754802704, 48.13865929841995, 42.68586449325085, 44.60113272070885, 44.01559554040432, 42.74500831961632, 41.23163312673569, 42.96679101884365, 43.43317799270153, 43.53470094501972, 41.004002541303635, 41.784644052386284, 40.11572800576687, 40.97829312086105, 41.413605362176895, 44.48051579296589, 42.33059495687485, 43.97736959159374, 42.45421752333641, 46.03372044861317, 41.26361221075058, 44.0861501544714, 42.23938085138798, 49.10395190119743, 55.32700337469578, 58.84434163570404, 55.83859272301197, 59.02755260467529, 46.522564217448235, 50.19970290362835, 96.95658534765244, 66.2898901104927, 56.022027879953384, 55.86994104087353, 53.81825253367424, 55.82474626600742, 59.03119660913944, 59.442927315831184, 56.08493350446224, 56.18411958217621, 46.64233759045601, 40.58665573596954, 40.29893517494202, 40.71779049932957, 38.81725788116455, 42.26490028202534, 40.74991017580032, 39.96804893016815, 39.079037234187126, 40.38352243602276, 41.71282410621643, 40.134814381599426, 40.13100318610668, 38.23419816792011, 41.561801210045815, 40.15073552727699, 38.77483695745468, 38.51315639913082, 39.939641654491425, 40.53309381008148, 39.39506247639656, 39.75012682378292, 40.895313173532486, 41.280870884656906, 39.10938620567322, 37.99173317849636, 40.41591189801693, 45.404455214738846, 50.98570592701435, 51.040848568081856, 50.95546714961529, 49.329910576343536, 52.363090217113495, 53.51185217499733, 51.45502634346485, 51.19637422263622, 52.68019460141659, 54.16862413287163, 50.197658613324165, 53.98700147867203, 52.89002314209938, 56.67629577219486, 55.4302666336298, 56.15659385919571, 52.482833191752434, 56.88150376081467, 12.06166522577405, 0.20470185874728486, 1.156836049631238, 2.082278053276241, 0.7683577795978636, 19.472452215850353, 66.79207876324654, 35.2261807769537, 34.44339998066425, 31.25275868922472, 31.238680444657803, 14.234619475901127, 0.2521603769855574, 0.011866904242197052, 0.04370382986962795, 0.06822023307904601, 0.02452901786455186, 0.020658437570091337, 0.046242947137216106, 0.03916684363503009, 0.0480090099881636, 0.02051646471954882, 0.12950414617080241, 0.05652922896842938, 0.05713980870496016, 0.06759256168152206, 0.03362587631272618, 0.053941155929351225, 0.023092971387086436, 0.029745933825324755, 0.04366877081338316, 0.06902954512042925, 0.0665768286853563, 0.06777881848393008, 0.04344163280620705, 0.03171253796608653, 0.0509336098912172, 0.07475842794519849, 0.04740724696603138, 0.01812817412428558, 0.017837652994785458, 0.07236498684505932, 0.04785557095601689, 0.012280457685847068, 0.09784261230379343, 0.06879837354063056, 0.030382976692635566, 0.10347646311856806, 0.0766271557949949, 0.0399636356451083, 0.07766521259327419, 0.04505287994106766, 4.060407495126128, 41.12181141972542, 42.463553622365, 34.36865799129009, 33.31473134458065, 48.314194679260254, 58.98793213069439, 48.073420599102974, 1.0318839107640088, 1.9595486763864756, 5.786280585452914, 2.567649520933628, 0.10085346089908853, 4.713936327025294, 50.73718026280403, 59.89881545305252, 58.60479488968849, 61.041934713721275, 64.29705664515495, 62.295970022678375, 60.91923929750919, 59.5409544557333, 61.74446001648903, 60.43498948216438, 57.581718787550926, 65.58942049741745, 61.62928059697151, 58.383669555187225, 52.27827876806259, 45.536589324474335, 47.41159491240978, 50.92517137527466, 54.007091000676155, 57.92583592236042, 60.123094618320465, 60.93350373208523, 59.6667505055666, 60.52076227962971, 56.16037845611572, 51.18540421128273, 45.219272151589394, 47.208571806550026, 47.006350457668304, 44.924407973885536, 43.09453636407852, 44.147896841168404, 43.046149760484695, 45.74636086821556, 44.651312828063965, 43.77146244049072, 43.01660634577274, 43.71962562203407, 43.23963537812233, 48.6298019438982, 45.13734474778175, 44.8548299074173, 44.049223735928535, 45.851007252931595, 43.81660781800747, 45.35145565867424, 44.68896120786667, 50.86402885615826, 55.58905251324177, 59.992647618055344, 56.8570900708437, 61.07449136674404, 53.5089111328125, 62.504715621471405, 82.68388241529465, 62.62366823852062, 60.48215255141258, 58.91751430928707, 55.66101685166359, 56.984447836875916, 61.89657345414162, 61.567807495594025, 57.45128318667412, 56.33329577744007, 47.81809709966183, 44.34415630996227, 42.701272666454315, 41.004507914185524, 40.14001250267029, 43.727567195892334, 41.837066039443016, 42.145240902900696, 40.519904717803, 42.84316845238209, 43.59321020543575, 44.195344895124435, 41.9739954918623, 41.644458174705505, 43.16474139690399, 40.88301703333855, 39.7883565723896, 41.180753856897354, 42.11347460746765, 41.69461168348789, 40.90931162238121, 39.78311665356159, 43.497599735856056, 41.09932042658329, 39.37910333275795, 41.004971489310265, 40.17890341579914, 48.257136940956116, 52.81171314418316, 53.384129628539085, 53.38291369378567, 53.15421536564827, 53.517190888524055, 55.70946805179119, 53.27089190483093, 51.77274249494076, 54.61570434272289, 56.05316340923309, 54.05112683773041, 55.30916713178158, 56.4849304407835, 57.181231677532196, 58.28894063830376, 56.584192514419556, 54.85003776848316, 57.75770254433155, 12.949725072830915, 0.3803741361480206, 1.3037631218321621, 2.1465204935520887, 0.8417832583654672, 19.80617120862007, 71.81454285979271, 41.6355324536562, 45.87771601974964, 38.225572630763054, 37.50526048243046, 22.04524666070938, 0.5834542389493436, 0.04285423034161795, 0.011244400975556346, 0.035839316915371455, 0.011772621801355854, 0.042085038803634234, 0.034253139529027976, 0.015927594940876588, 0.07714360152021982, 0.006431634983528056, 0.09687272176961415, 0.010291641992807854, 0.011621509402175434, 0.10142403887584805, 0.02643012376211118, 0.07094171829521656, 0.03251132264267653, 0.02860011903976556, 0.11726203432772309, 0.10146857515792362, 0.2954531757859513, 0.26974253822118044, 0.1677712396485731, 0.14950665878131986, 0.1385895922430791, 0.18540685035986826, 0.1410602909163572, 0.12286975412280299, 0.08070002513704821, 0.1494599925354123, 0.10341110959416255, 0.11232384305913001, 0.3126542887184769, 0.20864693768089637, 0.20259877550415695, 0.1815304349293001, 0.1533385453512892, 0.15116099501028657, 0.3396673360839486, 0.17363174236379564, 5.732034696266055, 56.37616887688637, 47.082566767930984, 44.76988926529884, 39.96798813343048, 53.48711550235748, 61.29217028617859, 55.93515694141388, 1.492962569463998, 9.36632165685296, 13.075830806046724, 2.9210215341299772, 0.164167518960312, 5.799064049497247, 51.9141861051321, 61.07224568724632, 59.36344318091869, 63.722075298428535, 68.59271094202995, 64.92981389164925, 63.48102383315563, 63.60768623650074, 61.82705998420715, 60.54424501955509, 60.82604929804802, 68.80394160747528, 64.82414916157722, 61.33583374321461, 53.38089220225811, 48.5349590331316, 50.81275820732117, 55.06237417459488, 56.375994086265564, 60.52604019641876, 61.89627707004547, 64.09250602126122, 61.63549326360226, 62.75863699615002, 60.33734992146492, 54.85466592013836, 47.482111528515816, 48.45103673636913, 48.88435788452625, 46.49291820824146, 45.11073857545853, 44.97347854077816, 45.54551504552364, 48.078147545456886, 47.09496930241585, 45.422660037875175, 45.336435064673424, 46.34795978665352, 47.38420598208904, 50.826125890016556, 47.87251777946949, 47.397216483950615, 47.3279993981123, 48.33353564143181, 46.351394802331924, 45.831662490963936, 46.21418796479702, 53.343996182084084, 58.63002933561802, 62.162935361266136, 61.78556241095066, 60.27719534933567, 55.42910389602184, 76.8407079577446, 81.71234294772148, 63.34746100008488, 61.224655508995056, 61.50115147233009, 58.03641378879547, 60.184442326426506, 62.96627305448055, 63.877224773168564, 59.474845603108406, 60.14993257820606, 50.241477862000465, 47.009025514125824, 44.00899149477482, 43.40822473168373, 43.7053269892931, 46.71202965080738, 43.600585609674454, 44.26961950957775, 43.548817187547684, 45.18695488572121, 45.56306250393391, 44.64749403297901, 45.624535605311394, 43.67795705795288, 45.569081380963326, 44.15918983519077, 41.26262806355953, 43.7059273570776, 43.888515159487724, 45.482590422034264, 42.73104786872864, 43.76131698489189, 45.381876826286316, 45.358432084321976, 40.308932438492775, 42.32780210673809, 43.25124755501747, 51.75542302429676, 55.022753700613976, 56.16375267505646, 55.297235772013664, 54.2008426040411, 56.897588297724724, 56.63535676896572, 54.69260461628437, 53.9638265222311, 55.56965835392475, 57.082075998187065, 53.541509583592415, 57.94453851878643, 57.175493985414505, 59.97032381594181, 59.525979459285736, 58.914242684841156, 55.88103644549847, 59.55866530537605, 13.874950725585222, 0.4143518238561228, 1.8631048640236259, 7.970814239233732, 3.5025729658082128, 23.656280413269997, 76.74059852957726, 47.03837513923645, 48.95430073142052, 41.831731125712395, 49.87158291041851, 32.636061161756516, 0.6007989426143467, 0.2678986871615052, 0.18295636778930202, 0.2372441883198917, 0.1635489537147805, 0.18096395360771567, 0.23596643266500905, 0.16749882692238316, 0.19215916225221008, 0.13898551318561658, 0.28881653503049165, 0.08878429915057495, 0.11329565575579181, 0.17185180506203324, 0.17242797883227468, 0.17303958273259923, 0.12812890199711546, 0.15868600137764588], [0.07634531037183478, 0.01951432972418843, 0.06148758438939694, 0.018185150656790938, 0.030272385556600057, 0.009093952012335649, 0.020424937501957174, 0.044175486982567236, 0.031347935655503534, 0.012465604977478506, 0.05835595125972759, 0.024375703142140992, 0.04646188812330365, 0.029252260901557747, 0.061824467484257184, 0.043823720116051845, 0.03277576841355767, 0.08377060177735984, 0.04417752046720125, 0.1460369848064147, 0.029518888586608227, 0.10325137714971788, 0.1931253049406223, 9.014406390488148, 30.185616351664066, 33.07803064584732, 34.957637786865234, 32.58899308741093, 43.40029455721378, 61.783423125743866, 12.984178774058819, 0.8545024821069092, 5.2679570484906435, 1.4027354610152543, 0.26046432671137154, 0.024122803333739284, 18.785323686897755, 61.88933864235878, 59.68182049691677, 60.154078155756, 58.60344976186752, 58.39399740099907, 56.96334756910801, 59.45504106581211, 58.90748284757137, 60.865928158164024, 57.9856713116169, 62.05863855779171, 58.36562052369118, 53.74064549803734, 51.6877980530262, 46.42898663878441, 48.4372852742672, 54.24450986087322, 57.22384259104729, 55.34157179296017, 57.884516939520836, 57.16627188026905, 56.42209321260452, 59.70525003969669, 55.495049357414246, 51.48334242403507, 45.53877800703049, 45.66337712109089, 42.47883640229702, 43.133214488625526, 43.00986550748348, 42.85385727882385, 43.5977091640234, 42.749644070863724, 41.5574998408556, 42.05479055643082, 40.90152204036713, 40.59975743293762, 43.54263871908188, 42.6525554805994, 42.98389010131359, 44.982297867536545, 45.6542994081974, 44.54241067171097, 45.95796011388302, 44.04993809759617, 42.447814866900444, 44.97440569102764, 55.60555122792721, 55.82076407968998, 57.47754357755184, 57.79929891228676, 49.80313718318939, 24.032239839434624, 56.528795287013054, 80.89122980833054, 54.59996938705444, 57.0183040201664, 55.45815713703632, 58.5437473654747, 57.458517998456955, 59.18563932180405, 57.40927644073963, 55.471604615449905, 48.5335873067379, 42.869706228375435, 41.131181716918945, 42.309437692165375, 39.49973165988922, 40.15586905181408, 40.70558935403824, 41.15234278142452, 38.99772919714451, 39.86543923616409, 40.373487174510956, 40.9850187599659, 41.24093122780323, 39.03667710721493, 40.284343957901, 39.17484529316425, 38.46872918307781, 38.26836213469505, 41.256799176335335, 40.14736510813236, 38.35650220513344, 39.578197449445724, 40.90281397104263, 38.84043663740158, 40.84208182990551, 38.68479698896408, 39.35414247214794, 46.24164529144764, 51.68995253741741, 52.35071048140526, 54.80838820338249, 54.97101567685604, 54.437334313988686, 52.856155559420586, 53.131659775972366, 53.21754276752472, 52.88696810603142, 53.27225983142853, 54.88924026489258, 54.27466504275799, 55.08086398243904, 55.26942506432533, 56.75862975418568, 53.73691409826279, 55.795035660266876, 34.898178577423096, 0.3858113178284839, 0.9835458139423281, 1.5516878245398402, 2.4460653075948358, 0.41150159086100757, 31.108005456626415, 54.63986724615097, 32.45071090757847, 31.989871636033058, 28.163423761725426, 36.65822513401508, 6.5636970195919275, 0.24161257344530895, 0.10158728167880327, 0.011094244091509609, 0.06464250240242109, 0.024442791436740663, 0.007161638341131038, 0.036849331663688645, 0.03637057219748385, 0.03685333183966577, 0.03922498719475698, 0.07701044538407587, 0.06900344378664158, 0.03845121660560835, 0.08671251227497123, 0.03830444205959793, 0.12115791629184969, 0.06695753560052253, 0.07391501421807334, 0.05275341907690745, 0.03218392048438545, 0.09681418116088025, 0.055000768406898715, 0.021933699608780444, 0.009357962699141353, 0.036424029094632715, 0.040191760708694346, 0.0518063384515699, 0.060635739864665084, 0.0583778149302816, 0.04538122462690808, 0.015062148704600986, 0.03235171265259851, 0.009979712685890263, 0.02603893957711989, 0.024628345054225065, 0.07598574724397622, 0.10208822393906303, 0.1075890744687058, 0.05024206555390265, 0.0775134062860161, 0.3818876721197739, 20.59427361935377, 42.376272305846214, 34.86393481492996, 36.90026834607124, 37.34917625784874, 51.16878770291805, 67.95800060033798, 13.178204912692308, 1.3705562939867377, 6.7528000473976135, 3.0648231552913785, 0.3219626017380506, 0.05793388816528022, 22.123706750571728, 65.58485314249992, 59.361558482050896, 60.71854926645756, 61.339895725250244, 60.921256989240646, 59.96735617518425, 61.0173424333334, 62.65405520796776, 63.82467359304428, 59.51853185892105, 64.5379713177681, 61.634360924363136, 57.126305624842644, 54.16817955672741, 48.547775745391846, 51.06649339199066, 56.50989510118961, 58.37126702070236, 58.5927989333868, 58.51738438010216, 58.694219291210175, 57.545951306819916, 59.975377544760704, 58.12519982457161, 53.01545821130276, 48.46349626779556, 47.699619457125664, 46.704152673482895, 45.89942045509815, 43.34739379584789, 44.30337689816952, 44.64068479835987, 45.21659329533577, 45.031227841973305, 44.38606046140194, 43.0831141769886, 43.88359822332859, 43.608861565589905, 46.314023807644844, 44.46910880506039, 48.36621768772602, 46.47589132189751, 46.862554773688316, 43.90523426234722, 47.364226654171944, 43.775855004787445, 47.19121053814888, 56.9625648111105, 59.01345916092396, 58.881123661994934, 58.170994967222214, 51.620686054229736, 31.27908367663622, 69.01887327432632, 71.7308409512043, 56.57980754971504, 57.70704746246338, 58.46064582467079, 59.041995629668236, 60.31165570020676, 61.27352848649025, 61.510517969727516, 56.554599702358246, 49.381359815597534, 45.16221061348915, 44.2382749915123, 43.28889213502407, 41.04648046195507, 43.18603925406933, 42.55056135356426, 43.09189550578594, 42.14269883930683, 42.99218125641346, 42.82058626413345, 43.06072197854519, 42.565680742263794, 40.55690333247185, 43.11911344528198, 40.3121242672205, 39.877556785941124, 39.86531004309654, 43.63221511244774, 42.04930365085602, 41.15888603031635, 41.04072757065296, 41.47744193673134, 42.66120381653309, 41.893952786922455, 38.974444046616554, 42.42468550801277, 46.67754270136356, 54.948004111647606, 53.03666867315769, 56.26482345163822, 57.135843113064766, 55.16585022211075, 54.25456412136555, 55.939268320798874, 55.04880130290985, 55.05988910794258, 54.48102816939354, 55.517490953207016, 56.24648183584213, 57.9856713116169, 56.937866136431694, 58.49305808544159, 54.39220033586025, 56.36226162314415, 35.309392511844635, 0.6367472105193883, 2.409188048914075, 3.4593692841008306, 2.1700768545269966, 0.5022615613415837, 35.63020549714565, 56.731985583901405, 39.53957252204418, 40.927622839808464, 29.194555431604385, 44.980283975601196, 10.287491977214813, 0.5002838862128556, 0.013960684664198197, 0.05950467711954843, 0.1125844036869239, 0.05155446837306954, 0.03193700795236509, 0.01011628270134679, 0.06228287355042994, 0.017412209417670965, 0.09432386752450839, 0.09789517120225355, 0.02096261607221095, 0.0262793564616004, 0.05557391050388105, 0.032037984565249644, 0.06286059840931557, 0.025244936186936684, 0.02320657564268913, 0.17470928141847253, 0.13320247584488243, 0.16181577171664685, 0.13366858911467716, 0.1700385453295894, 0.09759408931131475, 0.09245226756320335, 0.12132471398217604, 0.10181280551478267, 0.19238787732319906, 0.07056533810100518, 0.15053772454848513, 0.08603867929195985, 0.12821929558413103, 0.16402146429754794, 0.2647143095964566, 0.09707022210932337, 0.19865752605255693, 0.1482914958614856, 0.3095425822539255, 0.11935023750993423, 0.27805773890577257, 0.6196697987616062, 27.738777548074722, 56.19556076824665, 40.49960620701313, 53.7743116915226, 45.96824996173382, 54.17968533933163, 77.0646983385086, 16.16899687796831, 2.3278541257604957, 17.395913042128086, 4.852113537490368, 0.4308000724995509, 0.27009704732336104, 24.359900057315826, 65.23138850927353, 64.03724938631058, 62.896018624305725, 63.425733000040054, 62.99644723534584, 62.608191668987274, 63.945157527923584, 63.77960041165352, 66.60252973437309, 61.19529828429222, 67.25600346922874, 64.89931672811508, 59.08617205917835, 56.504905968904495, 52.423271387815475, 54.31473769247532, 61.00389875471592, 60.7534883916378, 61.16548128426075, 62.16379411518574, 60.114940255880356, 60.00817358493805, 62.73847907781601, 61.687147691845894, 56.29294574260712, 51.725370436906815, 51.34034849703312, 47.71983057260513, 45.619056299328804, 47.92594291269779, 46.11787833273411, 47.16156452894211, 47.5100552290678, 46.26500263810158, 46.9249664247036, 45.50008088350296, 47.16526933014393, 48.01974467933178, 48.88939641416073, 46.121966913342476, 51.94220960140228, 50.28525911271572, 50.370138958096504, 48.218162432312965, 49.20929364860058, 45.84665648639202, 50.52503764629364, 59.44541618227959, 62.07057371735573, 60.53802475333214, 60.98725564777851, 53.29799585044384, 42.96943187713623, 73.93666818737984, 70.58246657252312, 57.341389283537865, 59.26771491765976, 61.092673391103745, 61.60598784685135, 62.29415751993656, 61.7085937410593, 62.238619700074196, 58.23072776198387, 52.538272216916084, 48.52393202483654, 46.77701756358147, 46.02046675980091, 44.42035362124443, 46.26488484442234, 44.003200605511665, 46.97260066866875, 43.84792573750019, 43.87380614876747, 43.539952263236046, 45.30515134334564, 44.05271954834461, 42.294337302446365, 45.208484530448914, 42.67603442072868, 42.18711845576763, 41.98642462491989, 45.72394207119942, 46.02042496204376, 43.5249924659729, 43.91510233283043, 44.99516777694225, 45.37001386284828, 43.113626539707184, 40.35995610058308, 44.43845584988594, 48.68396043777466, 56.80034391582012, 56.008907184004784, 59.87498693168163, 58.51734638214111, 60.63349463045597, 56.7707435041666, 56.757231429219246, 57.789442241191864, 55.57718575000763, 56.9037439674139, 57.22941309213638, 58.688439801335335, 59.69070442020893, 59.638734608888626, 60.1612863689661, 58.44146825373173, 57.75876648724079, 38.57325777411461, 0.9694919711910188, 2.8453789930790663, 4.79118618182838, 6.509246416389942, 0.5006926611531526, 38.59356388449669, 62.23333798348904, 45.418157279491425, 46.19372986257076, 40.60057058930397, 57.86512278020382, 14.554693400859833, 0.7971363072283566, 0.2385342339402996, 0.12334347440628335, 0.24663660151418298, 0.12560920673422515, 0.12749825458740816, 0.13151578197721392, 0.14533011883031577, 0.12532897177152336, 0.1518718685838394, 0.2121584687847644, 0.16769631241913885, 0.14436973520787433, 0.18104584218235686, 0.1223635277710855, 0.22928808321012184, 0.14898930763592944, 0.19481314171571285], [0.020141639324720018, 0.030788669864705298, 0.01804053390515037, 0.08807524383882992, 0.06322200948488899, 0.042456591327209026, 0.09790240714210086, 0.03499225924315397, 0.03578824602300301, 0.03106174866843503, 0.07427436954458244, 0.02621319770696573, 0.026419666901347227, 0.03384319570614025, 0.028065290316590108, 0.023267058822966646, 0.020662415481638163, 0.061851860155002214, 0.07163737784139812, 0.03988355048932135, 0.07180214204709046, 0.03876199836668093, 0.06041882494173478, 1.395822325721383, 22.639114893972874, 37.13470056653023, 42.940306439995766, 35.10677598416805, 29.51646275818348, 59.49911490082741, 31.444245614111423, 0.4313701012870297, 4.075252348557115, 2.1419436391443014, 0.23169843043433502, 0.10458793316502124, 1.2438833224587142, 40.771067440509796, 61.94221280515194, 55.832482650876045, 61.02243795990944, 60.234185457229614, 63.541885167360306, 59.20777693390846, 62.50154659152031, 59.25927937030792, 56.777906119823456, 58.50791908800602, 58.99438798427582, 54.724929481744766, 53.18217806518078, 54.54095095396042, 55.67213885486126, 56.66333846747875, 59.36544947326183, 62.10832469165325, 57.5487669557333, 58.43492120504379, 56.90607704222202, 58.30556854605675, 58.146531879901886, 48.38614001870155, 44.54789377748966, 44.949095249176025, 43.931502252817154, 44.40775729715824, 42.90330782532692, 41.03236801922321, 44.49577197432518, 41.200383603572845, 43.649637177586555, 40.86692489683628, 40.93506284058094, 41.806169897317886, 41.672515869140625, 42.801773473620415, 43.163476064801216, 46.92469283938408, 49.0774255245924, 49.90003198385239, 47.912328243255615, 43.760496228933334, 45.69381728768349, 44.56628479063511, 55.05025662481785, 56.094102412462234, 57.88738198578358, 57.03858733177185, 55.754723623394966, 34.11798544228077, 24.68934427946806, 65.06387829780579, 62.111079543828964, 56.04907862842083, 58.633354157209396, 56.649663001298904, 56.09294347465038, 58.17537613213062, 57.18601942062378, 53.427314311265945, 46.76367647945881, 41.081446185708046, 39.988571628928185, 40.03127373754978, 40.879996195435524, 40.806618332862854, 41.26149192452431, 38.70140589773655, 40.32772623002529, 39.48943421244621, 39.6845081448555, 39.17999021708965, 40.04729367792606, 38.213534876704216, 39.4980825483799, 39.77899007499218, 40.40270380675793, 40.13436980545521, 40.22952429950237, 39.68154050409794, 41.144651994109154, 38.92532028257847, 39.25640031695366, 39.22879479825497, 40.06666123867035, 38.56321111321449, 41.442821994423866, 44.76317122578621, 52.712143287062645, 51.8550992757082, 53.2790956646204, 54.16567549109459, 54.985819682478905, 54.90790106356144, 57.33792766928673, 54.710402861237526, 57.01905257999897, 52.83853590488434, 52.59198993444443, 51.337111070752144, 56.59885972738266, 53.7433547526598, 59.795624390244484, 51.90915137529373, 54.05085325241089, 7.688979087397456, 0.06614539597649127, 2.9150311555713415, 1.0245808213949203, 0.61999058467336, 0.8204813639167696, 46.71785093843937, 49.37801979482174, 22.94039312750101, 23.003255054354668, 35.12687310576439, 30.856616646051407, 0.8538884588051587, 0.05834755014802795, 0.019195601416868158, 0.027870025696756784, 0.10305050003807992, 0.021462209479068406, 0.03474478638963774, 0.0645056577923242, 0.016216516742133535, 0.008017629152163863, 0.029781636694679037, 0.04245003074174747, 0.004389427795103984, 0.02778728179691825, 0.05170510950847529, 0.06689042318612337, 0.051624200568767264, 0.06039723586582113, 0.05283717044221703, 0.05367971214582212, 0.08270455859019421, 0.052232609523343854, 0.03919855189451482, 0.028899618300783914, 0.04463279095944017, 0.06190422238432802, 0.0197379351084237, 0.020586170940077864, 0.04025843525596429, 0.08331324585014954, 0.011972500724368729, 0.06204914898262359, 0.06702677797875367, 0.027335890881658997, 0.041734444530447945, 0.01708516720100306, 0.062149910372681916, 0.011030092846340267, 0.0694328875397332, 0.10235673296847381, 0.21800639951834455, 0.05112694307172205, 3.2737444946542382, 36.00374825298786, 42.06692710518837, 51.44719496369362, 42.728627398610115, 35.49791939556599, 66.90101131796837, 35.41444927453995, 0.4312162392307073, 3.1333303917199373, 2.234494797885418, 0.8755725889932364, 0.21127427404280752, 1.825107615441084, 48.8576453179121, 63.36816228926182, 57.510818392038345, 63.61338213086128, 63.892575949430466, 64.87290814518929, 60.504605546593666, 64.02947500348091, 61.225031688809395, 59.23985481262207, 59.80364575982094, 61.59007430076599, 56.96221902966499, 55.44758230447769, 54.8427801579237, 56.24895550310612, 57.54956491291523, 61.993874832987785, 62.73830808699131, 59.68464754521847, 60.86970895528793, 59.56801280379295, 60.088227689266205, 59.86240580677986, 51.71298310160637, 46.768243834376335, 46.587563529610634, 45.42360998690128, 46.57248213887215, 44.61966432631016, 45.306861251592636, 44.402547776699066, 43.64692032337189, 45.29236502945423, 44.25080671906471, 43.564438149333, 44.47265401482582, 43.90849828720093, 45.148949325084686, 44.64304827153683, 48.24339307844639, 50.18197685480118, 50.62057591974735, 49.55541327595711, 46.088642701506615, 47.26582333445549, 46.36808730661869, 54.795218110084534, 56.73770047724247, 60.01060925424099, 61.319392025470734, 55.094972625374794, 32.67886586487293, 33.461217284202576, 65.2481760084629, 62.93137952685356, 57.016320526599884, 60.097882971167564, 59.20410253107548, 59.04378153383732, 59.91906076669693, 59.2601153254509, 56.67799048125744, 48.872483521699905, 42.79086045920849, 42.24499315023422, 41.419985219836235, 41.95780836045742, 41.40824005007744, 43.97258944809437, 42.715404108166695, 44.0270671248436, 41.62821404635906, 42.38019749522209, 42.25264213979244, 42.731568440794945, 40.17253875732422, 39.34378802776337, 41.16690739989281, 42.56213553249836, 41.26490794122219, 41.508368477225304, 41.12655356526375, 42.75910176336765, 40.062652453780174, 40.81242822110653, 39.28067721426487, 40.749423801898956, 40.155755057930946, 43.80904622375965, 43.902331218123436, 55.51468290388584, 54.0768438577652, 55.41818328201771, 56.80577002465725, 58.46379205584526, 57.111129239201546, 58.17179672420025, 55.58278284966946, 58.85689616203308, 54.389449283480644, 53.4429656714201, 53.173453733325005, 59.075798615813255, 56.888286396861076, 59.36444632709026, 53.43099631369114, 57.29800321161747, 7.974860072135925, 0.41487459267955273, 4.768546996638179, 2.6336448546499014, 1.8933929200284183, 1.3033506064675748, 54.05430346727371, 52.17720419168472, 32.04391613602638, 28.08583952486515, 35.78611113131046, 40.90564101934433, 1.0870000720024109, 0.04964039530023001, 0.037889217855990864, 0.0457949979318073, 0.05087953701149672, 0.04997330790502019, 0.040411610825685784, 0.02715629671001807, 0.05716953914088663, 0.022451314216596074, 0.028243322267371695, 0.016695246522431262, 0.02387743632425554, 0.031146260735113174, 0.05279861587041523, 0.01664184714172734, 0.010737029861047631, 0.031212430621962994, 0.018970263117807917, 0.11186207135324366, 0.15438987175002694, 0.18792271614074707, 0.19870471180183813, 0.159051330992952, 0.19782498478889465, 0.21218420646619052, 0.0781631120480597, 0.1341423168196343, 0.11152772640343755, 0.20468373550102115, 0.07334747904678807, 0.12825708574382588, 0.15047672000946477, 0.08908139570849016, 0.17837670806329697, 0.09983629555790685, 0.1978967059403658, 0.16652587131829932, 0.11431231643655337, 0.18217827047919855, 0.38634222059044987, 0.12064491413184442, 3.9208602206781507, 51.73998445272446, 49.41186837852001, 55.885827988386154, 50.83823584020138, 40.19989348948002, 71.66975542902946, 40.530962124466896, 1.1016729846596718, 12.103570327162743, 9.09667007625103, 2.3454543063417077, 0.23606694914633408, 2.376449005678296, 48.418031707406044, 64.76456075906754, 58.637142553925514, 65.34919738769531, 66.21152311563492, 69.00372728705406, 64.69454571604729, 69.22660812735558, 63.46362076699734, 59.85464662313461, 61.93332888185978, 64.92322504520416, 59.62372161448002, 58.93062740564346, 58.67883391678333, 60.59624522924423, 62.27290906012058, 63.16073901951313, 66.42121106386185, 61.28516346216202, 63.54255773127079, 60.79236030578613, 61.598635241389275, 62.858906015753746, 53.0565682053566, 49.99898247420788, 49.50038842856884, 47.804425433278084, 50.08435629308224, 47.274239882826805, 46.055174097418785, 48.32065433263779, 45.955247059464455, 48.89412336051464, 45.57638838887215, 45.32026693224907, 47.8078718483448, 46.02237805724144, 46.42865225672722, 48.56246195733547, 52.53944255411625, 54.839493334293365, 55.676835402846336, 55.150806829333305, 50.2481085062027, 51.621354818344116, 47.82842114567757, 58.086848482489586, 56.86389550566673, 64.71241235733032, 61.80911734700203, 58.94846744835377, 36.17772951722145, 44.55602914094925, 70.0892074406147, 58.47596660256386, 61.13813795149326, 60.65492548048496, 59.63352508842945, 58.43984954059124, 61.71438083052635, 60.870894491672516, 58.060504496097565, 50.00332944095135, 46.19751825928688, 45.14538511633873, 43.24649021029472, 45.459662452340126, 45.93198850750923, 46.49794913828373, 43.61946679651737, 46.50370202958584, 43.165516555309296, 45.39761558175087, 45.32065071165562, 44.35692362487316, 41.69578202068806, 43.56034196913242, 43.25211390852928, 44.08694811165333, 44.47125568985939, 41.79041214287281, 43.09047058224678, 46.382112354040146, 41.8879909068346, 43.8905518501997, 41.662131026387215, 42.946481108665466, 40.186882987618446, 45.339763686060905, 47.82628946006298, 57.619773745536804, 56.062127128243446, 56.491040512919426, 59.2361082136631, 60.01507021486759, 59.428769275546074, 61.369754523038864, 56.269816383719444, 61.229644641280174, 56.02490432560444, 55.30057579278946, 54.82966706156731, 62.868234515190125, 57.09638223052025, 64.13301184773445, 55.57980380952358, 60.45556157827377, 8.8339863717556, 0.43678163434378803, 8.018789514899254, 4.195737233385444, 4.227209044620395, 0.9000742679927498, 61.111839562654495, 57.63569489121437, 37.12306559085846, 35.230801329016685, 48.22866886854172, 49.83485788106918, 1.641276329755783, 0.3688838495872915, 0.13315670017618686, 0.14074321574298665, 0.22621744719799608, 0.1551549369469285, 0.11446348449680954, 0.13342976599233225, 0.11247753442148678, 0.14739906328031793, 0.11935800779610872, 0.16380465327529237, 0.14358225715113804, 0.129341036954429, 0.24299618904478848, 0.14024809934198856, 0.12722201237920672, 0.10739934441517107, 0.20710135577246547], [0.018249800996272825, 0.028216230166435707, 0.06232171013834886, 0.04033249417261686, 0.027269145830359776, 0.012452340015443042, 0.018098850014212076, 0.04035200894577429, 0.056115047482308, 0.0383662406966323, 0.025493665125395637, 0.05014001653762534, 0.06060187937691808, 0.030802920955466107, 0.050133270415244624, 0.021950640984869096, 0.013925831553933676, 0.06714037110214122, 0.057082321945927106, 0.08676579847815447, 0.012212302553962218, 0.03485873945464846, 0.04405703650263604, 0.07555322357802652, 10.776422191411257, 35.1729342341423, 36.61745332181454, 38.58247607946396, 27.71587997674942, 47.332422360777855, 59.15272928774357, 1.3420040323399007, 2.263594586402178, 2.1852522902190685, 0.19464207667624578, 0.21501052746316418, 0.06926841277163476, 4.584615016356111, 54.11622114479542, 60.4910858720541, 58.607808127999306, 58.82926784455776, 61.7562697827816, 60.12884370982647, 61.26826196908951, 59.6418846398592, 60.78294061124325, 59.081870689988136, 57.76535913348198, 60.20412527024746, 59.9462179094553, 58.063916712999344, 58.04506212472916, 58.41387413442135, 60.22554092109203, 59.876738637685776, 57.663551196455956, 60.3722358494997, 59.30210307240486, 57.215813621878624, 56.62366099655628, 54.35449875891209, 44.542923644185066, 43.06333623826504, 44.58378665149212, 44.5967211574316, 46.064890176057816, 44.29153673350811, 43.471985310316086, 42.664794623851776, 41.12000651657581, 42.34273910522461, 40.21401733160019, 42.218884751200676, 43.132294937968254, 46.63433521986008, 51.76582306623459, 56.11728496849537, 57.268414199352264, 56.54426045715809, 56.20607480406761, 53.28223429620266, 47.09482491016388, 41.93800762295723, 45.73520086705685, 54.11495961248875, 54.870655462145805, 60.56601405143738, 57.46389850974083, 57.20680430531502, 35.25032088160515, 36.69513255357742, 61.32244326174259, 58.39544132351875, 58.40479262173176, 58.02259773015976, 56.396995559334755, 54.473538771271706, 53.26504781842232, 47.96945057809353, 42.44669392704964, 41.75607718527317, 41.14599332213402, 40.48988252878189, 40.84179684519768, 41.27182736992836, 40.54154455661774, 39.80248801410198, 40.316589027643204, 39.42101888358593, 39.15644288063049, 40.06823055446148, 41.31154663860798, 41.370318084955215, 39.467919766902924, 40.85898332297802, 39.910622611641884, 40.333988294005394, 39.23200562596321, 39.27205167710781, 39.70382250845432, 41.715863943099976, 40.15491150319576, 39.00859281420708, 37.89252050220966, 39.10059727728367, 38.68262730538845, 39.30661082267761, 42.584048956632614, 49.354134276509285, 48.30898895859718, 50.49899384379387, 52.083881199359894, 54.12406012415886, 51.991527155041695, 54.026101380586624, 56.20256379246712, 58.906703889369965, 57.81942643225193, 53.37352439761162, 52.8879826515913, 58.550799787044525, 53.247253373265266, 57.152588814496994, 30.9956568852067, 0.23847846896387637, 0.8045687084086239, 3.296488174237311, 4.067544462159276, 0.5013246741145849, 6.191688906401396, 59.70399610698223, 29.291182346642017, 26.20741792023182, 25.60051828622818, 36.56060077250004, 13.812163844704628, 0.1640398844028823, 0.11605712046730332, 0.0351275008142693, 0.021436592396639753, 0.031737032550154254, 0.009788853640202433, 0.07479106760001741, 0.029032672391622327, 0.09147451026365161, 0.01689850221737288, 0.060399655267247, 0.009923935649567284, 0.08313154583447613, 0.05347889440599829, 0.033240530974580906, 0.08257163251983002, 0.03124249131360557, 0.08751297791604884, 0.0030235374651965685, 0.04322085500461981, 0.052213836897863075, 0.033988359791692346, 0.005981134645480779, 0.030019020050531253, 0.02682166417798726, 0.043800023340736516, 0.06777583505026996, 0.024657518879394047, 0.056215419244836085, 0.010793451638164697, 0.043828480993397534, 0.01167813712527277, 0.04359734652098268, 0.014436286292038858, 0.012175133015261963, 0.04609428382536862, 0.0304781367231044, 0.061347043883870356, 0.03509390007820912, 0.02024757533945376, 0.09635113296099007, 0.10607260701362975, 0.4944992606760934, 20.77996015548706, 44.23488937318325, 40.56732997298241, 46.338258907198906, 32.309096306562424, 53.582585379481316, 61.95702061057091, 1.222231371793896, 2.1906969230622053, 3.788384604267776, 2.686731331050396, 1.1625317065045238, 0.5855302338022739, 6.755020078271627, 60.008735954761505, 62.13645078241825, 60.3383606672287, 61.03169806301594, 63.16261611878872, 63.15791197121143, 62.57599599659443, 63.60179655253887, 63.45866963267326, 62.28932037949562, 60.35770922899246, 60.9443711489439, 60.64941197633743, 60.917130410671234, 59.22087103128433, 61.294560357928276, 61.84774987399578, 61.37813687324524, 59.727007672190666, 62.685711309313774, 59.17334698140621, 60.94392277300358, 57.61911258101463, 54.1638857871294, 44.19528029859066, 45.07921166718006, 46.23308055102825, 46.9731592386961, 47.3555289208889, 45.342833921313286, 46.07469744980335, 45.951439663767815, 44.75475087761879, 43.60454499721527, 42.99083612859249, 43.68591383099556, 45.21255411207676, 47.25380077958107, 53.067146837711334, 59.37687925994396, 58.13834711909294, 57.54436679184437, 56.40362620353699, 53.78450274467468, 48.52973431348801, 45.08548133075237, 49.135406613349915, 57.2704166918993, 59.66150298714638, 61.897994577884674, 59.5235475897789, 54.377077147364616, 35.44455125927925, 40.21967142820358, 63.54972034692764, 59.22769546508789, 59.639718756079674, 59.508158415555954, 57.52593018114567, 55.33886253833771, 56.14648640155792, 51.10825315117836, 45.8208292722702, 43.43496009707451, 42.47981294989586, 42.62249909341335, 43.06961350142956, 42.19524621963501, 42.20484830439091, 42.244909554719925, 42.54157483577728, 42.894249111413956, 41.41754575073719, 40.75704999268055, 42.93363779783249, 41.6274768859148, 41.56302094459534, 44.28298719227314, 42.531577572226524, 41.413073390722275, 40.816797986626625, 41.71278230845928, 40.44439896941185, 42.211448550224304, 42.41256795823574, 41.920631155371666, 39.672147408127785, 41.96065440773964, 40.77620096504688, 40.957705825567245, 44.91510607302189, 52.942730113863945, 50.549515932798386, 53.50695423781872, 54.14097301661968, 57.220593765378, 53.65724377334118, 56.04324594140053, 57.436950355768204, 58.482171669602394, 58.835769295692444, 56.35109782218933, 54.71360228955746, 59.81293626129627, 55.917248502373695, 58.785836175084114, 33.60519155859947, 0.28667627018876374, 1.3210362824611366, 8.334848005324602, 4.217677256092429, 1.6818930627778172, 6.796725690364838, 67.83408164978027, 37.57711462676525, 33.658943474292755, 26.7972032725811, 44.93434064090252, 18.927629850804806, 0.19655580836115405, 0.16134553210576996, 0.03398849337827414, 0.05099027657706756, 0.04870283271884546, 0.002615697630972136, 0.04283619986381382, 0.08879799177520908, 0.05164660600712523, 0.046875364569132216, 0.03854758448142093, 0.011620189306995599, 0.02513044877559878, 0.0389451455703238, 0.03944609154132195, 0.05898273208003957, 0.02392647002125159, 0.11218986313906498, 0.016773947572801262, 0.21516164357308298, 0.17534809245262295, 0.1148418610682711, 0.11910400033229962, 0.15607174165779725, 0.1361241628183052, 0.15186127071501687, 0.11075645685195923, 0.24503305787220597, 0.12318751207203604, 0.10101149382535368, 0.08840944778057747, 0.20078333385754377, 0.0920200630207546, 0.09629658510675654, 0.120778240961954, 0.20264199818484485, 0.1289230742258951, 0.10810177976964042, 0.1692014918080531, 0.09436959866434336, 0.17240385903278366, 0.2487198100425303, 0.33475506061222404, 26.83730822056532, 56.55756734311581, 44.67314265668392, 57.610152661800385, 38.99031199514866, 58.47136504948139, 70.94057455658913, 1.8383730598725379, 7.012946913018823, 4.539186079055071, 3.4807818476110697, 1.1958683864213526, 0.21811469370732084, 6.933287037536502, 61.059109792113304, 62.30440557003021, 62.17655383050442, 62.21970811486244, 66.8457242846489, 62.94653311371803, 66.09818279743195, 66.04439288377762, 65.69326892495155, 64.45843398571014, 63.32160718739033, 64.05950099229813, 65.35825610160828, 64.5828165113926, 62.03577898442745, 64.91178765892982, 64.50321078300476, 62.731187269091606, 61.47163845598698, 63.62073093652725, 62.077671736478806, 63.23491483926773, 60.461667850613594, 57.15913966298103, 47.877427116036415, 47.354700565338135, 50.319195091724396, 49.52338479459286, 50.65779112279415, 48.07995244860649, 49.033807665109634, 46.85560494661331, 47.27437287569046, 46.4120015501976, 45.3648841381073, 46.13900899887085, 47.61669270694256, 50.593745559453964, 57.19372160732746, 61.9573587924242, 61.011072769761086, 59.730324894189835, 60.10360166430473, 57.40237221121788, 52.887481078505516, 46.589132845401764, 50.51209554076195, 59.09070901572704, 60.98082259297371, 64.26295727491379, 61.04837916791439, 60.13596832752228, 40.54610811173916, 49.16932359337807, 64.20048102736473, 60.34311041235924, 61.55707307159901, 61.91784471273422, 58.98129388689995, 58.54650981724262, 58.10090392827988, 51.868884935975075, 47.93629735708237, 46.672279983758926, 45.44980198144913, 44.23009783029556, 45.672481432557106, 45.28918839991093, 46.254940778017044, 44.881496876478195, 45.382158011198044, 43.47698964178562, 44.16942648589611, 43.60446140170097, 44.980352371931076, 44.35713641345501, 42.757148668169975, 45.55913731455803, 44.48422819375992, 44.13062296807766, 43.234760239720345, 44.09566484391689, 43.845493867993355, 45.07318139076233, 43.98014724254608, 43.010253086686134, 42.563803642988205, 43.85551393032074, 42.520516365766525, 41.39786280691624, 46.55216082930565, 55.02601012587547, 52.64593183994293, 55.51771134138107, 57.015446573495865, 58.182048574090004, 55.264565125107765, 57.726099640131, 60.530527755618095, 60.19988089799881, 60.420542657375336, 57.71473444998264, 55.681695342063904, 62.10530385375023, 57.86533936858177, 62.66761668026447, 34.54996146261692, 0.4910040716640651, 1.4237168664112687, 5.228406395763159, 12.930931281298399, 3.349816887639463, 7.881918009370565, 74.72413033246994, 40.16406901180744, 41.37061066925526, 35.426247641444206, 57.79869094491005, 27.302296869456768, 0.27858222951181233, 0.23328238137764856, 0.15442298637935892, 0.11258580634603277, 0.10359664651332423, 0.10605285104247741, 0.19552315439796075, 0.23826501244911924, 0.17923510575201362, 0.11945666890824214, 0.1747776332194917, 0.2137267604121007, 0.16715157602448016, 0.09724418152472936, 0.14962342829676345, 0.19375547737581655, 0.1693109140614979, 0.3155006922315806, 0.13693595363292843], [0.037031154133728705, 0.035732443939195946, 0.04167339546256699, 0.06277862819842994, 0.020807106448046397, 0.03923037147615105, 0.03877870782162063, 0.05872336259926669, 0.0648008321877569, 0.08369096191017888, 0.044259579735808074, 0.04578845590003766, 0.0161567682880559, 0.02166943009797251, 0.044594959981623106, 0.06397549717803486, 0.05192733820877038, 0.023886865310487337, 0.03451689510256983, 0.03370869628270157, 0.05372222978621721, 0.04483348995563574, 0.12154484982602298, 0.032684896141290665, 0.6709095148835331, 33.45460943877697, 44.49393667280674, 40.56256502866745, 34.99680608510971, 30.51699087023735, 69.76101145148277, 15.714696105569601, 0.6425873783882707, 3.772917059250176, 1.017243533860892, 1.2318146950565279, 0.20580157317453995, 0.15831258235266432, 6.460122652351856, 58.07778216898441, 59.92051228880882, 60.93537323176861, 59.74322900176048, 61.77287109196186, 60.69698542356491, 63.07588957250118, 62.725920751690865, 64.68284234404564, 59.002945125103, 63.675288408994675, 60.01134641468525, 60.88514752686024, 61.12816348671913, 59.7776285558939, 61.82167947292328, 61.597195118665695, 59.53533075749874, 60.39906620979309, 58.3831337839365, 58.56608256697655, 56.10148161649704, 52.225279211997986, 43.99850785732269, 45.17392158508301, 44.08808425068855, 43.696876242756844, 44.72729355096817, 44.68566678464413, 44.944318905472755, 44.73799757659435, 42.2460000962019, 42.43473216891289, 42.46966369450092, 42.462033703923225, 42.54869565367699, 48.99734102189541, 57.38854095339775, 60.065007135272026, 58.70990104973316, 58.21736007928848, 54.94317837059498, 56.817891374230385, 56.807909309864044, 51.44619181752205, 44.144511222839355, 48.351694867014885, 53.2242152094841, 55.115373730659485, 58.52429240942001, 60.11113665997982, 55.647626370191574, 39.465810880064964, 46.17864467203617, 59.54549141228199, 59.43816617131233, 56.81503772735596, 56.13735169172287, 51.43614135682583, 47.505427077412605, 43.753147423267365, 43.264011070132256, 41.64553351700306, 40.258873924613, 40.218394696712494, 42.75374785065651, 43.30334275960922, 41.10375478863716, 39.993503764271736, 42.59849578142166, 41.06617480516434, 39.63812403380871, 40.15569806098938, 40.74946179986, 40.88545650243759, 42.49925270676613, 40.183888748288155, 38.03171843290329, 38.9651345461607, 40.269847735762596, 39.199988543987274, 40.26386305689812, 40.41164852678776, 39.86103907227516, 40.87379492819309, 39.07519184052944, 39.652114883065224, 40.62307298183441, 38.66970419883728, 41.41251102089882, 41.86505153775215, 45.10726556181908, 47.555265203118324, 47.22220927476883, 49.15879435837269, 52.546779960393906, 48.38598422706127, 53.78419876098633, 53.6672106385231, 56.072424575686455, 58.15204918384552, 55.77572509646416, 56.783051043748856, 53.71269039809704, 57.79316984117031, 13.506428450345993, 0.24821817758493125, 2.67194252461195, 2.4092535953968763, 1.642374589573592, 1.058219347614795, 17.31004524976015, 54.32049818336964, 26.273338682949543, 30.212600603699684, 23.045237101614475, 32.880220860242844, 1.964757009409368, 0.0634730038291309, 0.0953049941745121, 0.025970539536501747, 0.07232196454424411, 0.06577699386980385, 0.0321729329880327, 0.03842242127575446, 0.03578101750463247, 0.023518194175267126, 0.03140257627819665, 0.045058776304358616, 0.030722414630872663, 0.09793452729354613, 0.06026944916811772, 0.01285261829252704, 0.03815861746261362, 0.05633541710267309, 0.04793220141436905, 0.06825814940384589, 0.023597180952492636, 0.039990946679608896, 0.08172202928108163, 0.0923042165231891, 0.027067827140854206, 0.015998969138308894, 0.025788058410398662, 0.09044353355420753, 0.03428388670727145, 0.052885317272739485, 0.028048983476764988, 0.006085497770982329, 0.04042750020744279, 0.04525179036136251, 0.05560565216001123, 0.08008105913177133, 0.03555202412826475, 0.005997539356030757, 0.024946451812866144, 0.14470585389062762, 0.030697053589392453, 0.09352373584988527, 0.08223716140491888, 0.11415198285249062, 4.018835350871086, 41.992918476462364, 46.77288718521595, 47.43332974612713, 43.348210752010345, 37.44539849460125, 75.9227380156517, 15.646905843168497, 0.4801753058563918, 3.55895790271461, 2.230555834248662, 2.0498826541006565, 0.6331204832531512, 0.5749643070157617, 10.684758760035038, 62.087756395339966, 58.74645508825779, 60.70449762046337, 60.388977751135826, 63.51157419383526, 61.67210049927235, 64.9345788359642, 66.28447920084, 65.77920511364937, 60.263212099671364, 66.07094585895538, 62.49574050307274, 63.288564160466194, 63.29255394637585, 61.80864617228508, 60.44497914612293, 63.481130227446556, 61.15018330514431, 63.4653040766716, 60.61584457755089, 61.21696852147579, 56.981214210391045, 54.54956129193306, 46.065129563212395, 47.12874948978424, 46.61695875227451, 45.5307300388813, 47.16022700071335, 46.28170274198055, 46.20561182498932, 46.62465713918209, 43.43418873846531, 44.34316076338291, 43.49655479192734, 44.56021651625633, 44.228589311242104, 52.034533247351646, 60.71043290197849, 61.74747705459595, 60.55135443806648, 61.78228318691254, 60.184879302978516, 59.99385215342045, 58.48653383553028, 52.69310250878334, 45.31700290739536, 50.184796303510666, 55.216440707445145, 59.56518955528736, 58.59479382634163, 62.91781045496464, 55.91185659170151, 39.26455467939377, 50.358143001794815, 60.78019715845585, 61.24263994395733, 58.2191763818264, 59.306146055459976, 54.8369512706995, 49.80558045208454, 46.53579130768776, 43.54352407157421, 44.558031633496284, 42.36866891384125, 41.883070170879364, 44.18989218771458, 43.47724422812462, 42.2561227530241, 40.95336265861988, 44.23815719783306, 42.98868924379349, 43.01135502755642, 41.694193705916405, 43.36159363389015, 43.219317868351936, 43.24452951550484, 41.71700768172741, 41.27377286553383, 41.656009554862976, 43.38687367737293, 41.861487329006195, 42.53217414021492, 41.99473097920418, 41.52307368814945, 42.116822227835655, 40.53463272750378, 40.504040569067, 42.352724969387054, 41.42768740653992, 42.744130566716194, 44.55929696559906, 46.86283975839615, 50.126450434327126, 49.89929102361202, 50.53161509335041, 54.58761624991894, 51.260879561305046, 55.83068534731865, 56.224420219659805, 56.197973638772964, 60.021168887615204, 58.22563983500004, 57.542820274829865, 54.484170600771904, 58.454414159059525, 13.968229070305824, 0.22151521436171606, 2.2807395039126277, 11.032305210828781, 5.299245994538069, 1.1501738196238875, 18.573749139904976, 60.354426205158234, 32.17171087861061, 35.07317438721657, 24.074130691587925, 43.141942620277405, 3.4199297754094005, 0.2655172540107742, 0.027216933885938488, 0.08600262575782835, 0.054621152448817156, 0.06222984709893353, 0.02224090236268239, 0.07761872446280904, 0.08824136617477052, 0.03065418899495853, 0.0821224253741093, 0.045126664263079874, 0.025953074946301058, 0.045930621708976105, 0.0562066730344668, 0.11860452010296285, 0.021952518618491013, 0.05252729410130996, 0.03673535262350924, 0.02563136691605905, 0.16381744790123776, 0.14199909288436174, 0.11792404489824548, 0.20732253062305972, 0.11780255532357842, 0.15994159650290385, 0.10424053383758292, 0.21088065375806764, 0.1609675562940538, 0.158034811320249, 0.22337870264891535, 0.15484051866224036, 0.13413630542345345, 0.1730954961385578, 0.11438780769822188, 0.16453596559586003, 0.12718738376861438, 0.07112934064934961, 0.15143852855544537, 0.2896923286607489, 0.18664073024410754, 0.18774077121634036, 0.25492021639365703, 0.225206300674472, 3.6733469646424055, 58.4446144849062, 56.61299116909504, 55.668833032250404, 50.64650572836399, 41.211600601673126, 82.19886884093285, 19.44578904658556, 1.118920852895826, 15.590902548283339, 3.7631617952138186, 3.702217577956617, 0.26753886428195983, 0.344274856033735, 9.689835347235203, 63.51500540971756, 61.02884441614151, 64.67511355876923, 62.31284111738205, 67.29573413729668, 62.593125477433205, 68.89667943120003, 67.95336484909058, 69.3201819062233, 61.999251544475555, 69.7540882229805, 65.51229983568192, 66.33143708109856, 65.0156968832016, 62.66160920262337, 62.811450362205505, 66.8865416944027, 63.08978542685509, 65.7030799984932, 62.1595611423254, 63.56587328016758, 60.55571660399437, 57.30707332491875, 49.1591477394104, 49.93398316204548, 49.28990252315998, 46.97728581726551, 49.190948233008385, 48.82527865469456, 49.46243606507778, 49.29545782506466, 48.219944536685944, 47.853245213627815, 47.70193353295326, 46.83519244194031, 46.93846710026264, 53.95735166966915, 63.49220283329487, 64.51506614685059, 61.45102836191654, 62.975134178996086, 60.20841524004936, 61.32574528455734, 60.76459899544716, 57.930042296648026, 48.222482800483704, 53.44670467078686, 56.634270027279854, 62.16482765972614, 61.91677317023277, 65.27239590883255, 59.29970160126686, 47.68450006842613, 53.99799048900604, 62.50846982002258, 64.51769560575485, 61.55442841351032, 61.116254925727844, 56.1784540861845, 53.55200842022896, 48.978619426488876, 46.360141932964325, 46.532922461628914, 44.66863989830017, 43.12278404831886, 46.82536616921425, 46.76145739853382, 43.38732585310936, 43.665037751197815, 46.58362314105034, 44.47137348353863, 45.350319519639015, 44.73850674927235, 45.46852357685566, 45.58397278189659, 46.12585410475731, 44.92997847497463, 42.502182349562645, 43.57230752706528, 45.43169595301151, 43.428371250629425, 44.30632174015045, 43.1872133910656, 42.7131812274456, 44.94103588163853, 42.82583378255367, 42.76133604347706, 45.26186786592007, 45.459970235824585, 46.717341765761375, 47.335724383592606, 49.7616396099329, 52.082638666033745, 51.485386714339256, 52.35452547669411, 57.707248851656914, 53.991888016462326, 59.675254449248314, 58.589576706290245, 57.199710085988045, 59.200044348835945, 58.50003831088543, 61.232809871435165, 56.24479092657566, 61.784297078847885, 14.88225007429719, 0.2788548351963982, 4.719911031424999, 7.868656245991588, 6.353756384924054, 2.1745228534564376, 21.916655860841274, 66.53434619307518, 38.36268447339535, 47.33922399580479, 33.72375659644604, 56.64025090634823, 6.969005120918155, 0.48865947872400284, 0.20284533180529252, 0.17843750480096787, 0.3288151777815074, 0.13273073709569871, 0.09080770541913807, 0.14303820353234187, 0.15345271734986454, 0.08606332601630129, 0.19340447121066973, 0.15053065930260345, 0.17965176230063662, 0.17717034701490775, 0.13609073648694903, 0.27530003688298166, 0.13686875958228484, 0.13549115537898615, 0.11722581752110273, 0.12435695869498886], [0.02845223127224017, 0.04813376872334629, 0.02428469913866138, 0.049951874680118635, 0.03254483061027713, 0.01976273768377723, 0.05394580548454542, 0.07640202529728413, 0.03807166373007931, 0.0366322274931008, 0.005200534442337812, 0.04129001681576483, 0.05795988559839316, 0.030865751177771017, 0.028809178329538554, 0.025214573070115875, 0.057100166886812076, 0.05492793774465099, 0.04056746925925836, 0.02247473083116347, 0.027583705123106483, 0.03371365382918157, 0.08897800711565651, 0.1926173790707253, 0.05767007693066262, 16.546485722064972, 43.29084903001785, 34.266314283013344, 38.79106968641281, 28.2570431381464, 52.69926957786083, 46.199494153261185, 0.8062792697455734, 2.5579294050112367, 3.3962660701945424, 0.907565209781751, 4.4116392731666565, 0.3339951310772449, 0.09509435782092623, 8.299035876989365, 65.02205774188042, 61.07543371617794, 61.966983675956726, 58.84757146239281, 64.35216888785362, 63.3399374037981, 61.93541117012501, 62.10110887885094, 64.6621486544609, 60.66078096628189, 63.020872324705124, 63.94231528043747, 61.4964397251606, 64.91857409477234, 61.457985788583755, 62.25824564695358, 59.37810279428959, 60.369272008538246, 59.543291330337524, 57.94272221624851, 56.11426033079624, 51.30592234432697, 43.28029319643974, 45.22252857685089, 44.41239684820175, 46.20899744331837, 45.50630874931812, 45.36118693649769, 46.45624257624149, 43.19239251315594, 41.962280720472336, 41.139191687107086, 41.684633418917656, 42.128681391477585, 42.50427983701229, 49.262927770614624, 59.75633069872856, 57.58013427257538, 57.04262651503086, 54.43104565143585, 61.006570011377335, 60.934898257255554, 55.016571432352066, 56.65096253156662, 50.00593990087509, 44.9944344162941, 50.38925193250179, 53.92457462847233, 58.736127242445946, 57.53565385937691, 55.66096365451813, 53.30769672989845, 54.65585298836231, 56.772065833210945, 56.776781380176544, 54.21698033809662, 51.97533622384071, 45.707082375884056, 43.19803141057491, 42.741121128201485, 43.09439197182655, 42.52185009419918, 45.26235044002533, 44.105236530303955, 43.01132842898369, 40.856448858976364, 40.04229314625263, 39.13270555436611, 41.266207471489906, 40.51939934492111, 40.82352742552757, 41.9600198417902, 40.5828483402729, 40.81280820071697, 41.88107147812843, 40.17555199563503, 42.401115372776985, 38.13260681927204, 39.93100471794605, 38.72559919953346, 39.471350982785225, 41.518555730581284, 41.5003927052021, 40.15761315822601, 39.46051016449928, 42.05377981066704, 40.37483610212803, 38.1605239212513, 39.89373251795769, 41.84256054461002, 43.64395648241043, 41.923708990216255, 47.81469628214836, 46.618144288659096, 47.94383615255356, 50.81423632800579, 53.336981758475304, 54.694101735949516, 56.82285390794277, 57.27623797953129, 58.73271502554417, 57.12501369416714, 54.99736726284027, 45.056241899728775, 3.8493079226464033, 0.7900364475790411, 2.4420828837901354, 27.54266057163477, 7.739722989499569, 1.0071745491586626, 29.783428832888603, 41.18143402040005, 25.8588645234704, 36.47457338869572, 26.837353818118572, 20.32827079296112, 0.3135270840721205, 0.10535571462241933, 0.05473631892527919, 0.04934781842166558, 0.05290838693326805, 0.05629731895169243, 0.03365204072906636, 0.09628500018152408, 0.021189568542467896, 0.05079572627437301, 0.0822027628601063, 0.07248170441016555, 0.030160137575876433, 0.05457710969494656, 0.047202032001223415, 0.06931654846994206, 0.08248633748735301, 0.014827826707914937, 0.013500087407010142, 0.017624168649490457, 0.041049753926927224, 0.02484913398802746, 0.0374607351841405, 0.013016534594498808, 0.019751039581024088, 0.016554041794734076, 0.021567559197137598, 0.05518056852451991, 0.03158236897434108, 0.056374554260401055, 0.04378725840069819, 0.051981900905957446, 0.027376469661248848, 0.011150578666274669, 0.03781712191994302, 0.01753147254930809, 0.04713568770966958, 0.05413463011791464, 0.013791312649118481, 0.028542298314278014, 0.031124295019253623, 0.005930256711508264, 0.049013410389306955, 0.07437926469719969, 0.308410688303411, 25.49182891845703, 51.91312216222286, 38.76187965273857, 51.28624700009823, 33.04447464644909, 61.760476157069206, 47.207249477505684, 0.429640065995045, 2.944415691308677, 1.9897585990838706, 2.906687753275037, 5.453391848132014, 1.831516802776605, 0.31864739838056266, 11.881418097764254, 69.23496007919312, 60.578553378582, 62.35082387924194, 60.374595522880554, 65.1929421722889, 65.07021635770798, 65.40146738290787, 64.07918393611908, 66.42789110541344, 61.35703280568123, 65.06786808371544, 65.35596862435341, 62.61317320168018, 66.81355521082878, 64.02084186673164, 62.281367406249046, 60.898215025663376, 63.90639200806618, 60.84433771669865, 59.1278026252985, 58.67068715393543, 54.031231105327606, 46.352150961756706, 46.786243468523026, 46.814977526664734, 48.03184702992439, 47.32634648680687, 47.890411019325256, 47.356098890304565, 45.32395273447037, 45.03668434917927, 45.06683953106403, 43.426767736673355, 43.296810910105705, 44.17923375964165, 54.041794538497925, 61.19075372815132, 60.4169936478138, 60.814281329512596, 58.132886812090874, 60.55100105702877, 62.11452595889568, 59.50954534113407, 60.95762483775616, 52.62683026492596, 49.38963957130909, 53.03243190050125, 56.00331008434296, 60.21763734519482, 60.228827744722366, 57.614020854234695, 53.0863244086504, 55.1122161000967, 58.89302462339401, 59.863591343164444, 55.284305065870285, 52.830472737550735, 49.13364730775356, 46.302122846245766, 43.352728709578514, 43.9587239921093, 44.51003260910511, 46.86733491718769, 44.745631366968155, 45.46438939869404, 42.72619932889938, 43.24786193668842, 41.854309514164925, 42.95425929129124, 43.38346906006336, 41.21335230767727, 42.86454610526562, 42.30728320777416, 43.279172256588936, 43.70280772447586, 42.19395808875561, 44.16069075465202, 39.54674653708935, 42.94578194618225, 40.82865335047245, 41.560102701187134, 43.02311159670353, 43.669684901833534, 39.975067153573036, 41.319723799824715, 41.256369799375534, 42.001726403832436, 40.93354672193527, 43.660022020339966, 43.27411472797394, 45.22462226450443, 44.593533128499985, 50.5195127427578, 49.91415202617645, 51.80242270231247, 52.31928616762161, 56.305241882801056, 56.91236950457096, 59.095504358410835, 56.3039081543684, 62.102932780981064, 56.88070200383663, 56.774843484163284, 45.64485691487789, 3.562424029223621, 1.2215894437395036, 5.082938326522708, 8.741386290639639, 1.8581264186650515, 0.6577505241148174, 31.91333994269371, 46.12206570804119, 32.46434077620506, 41.46368287503719, 29.908423125743866, 32.78397962450981, 0.7481973676476628, 0.1165166063583456, 0.04586374307109509, 0.051459273090586066, 0.052591812709579244, 0.04299448512028903, 0.1347554792300798, 0.029397790494840592, 0.019827237738354597, 0.03262051111960318, 0.06705511317704804, 0.0228070571392891, 0.05401684386015404, 0.0227934016220388, 0.003053352552342403, 0.031281606206903234, 0.0472850300866412, 0.0063948578554118285, 0.017833246492955368, 0.07320393284317106, 0.12580494076246396, 0.16057549451943487, 0.1801297054043971, 0.14787509164307266, 0.08224723234889098, 0.145252030051779, 0.2171366024413146, 0.16680760541930795, 0.09642888035159558, 0.23371552844764665, 0.0953223455871921, 0.19697670999448746, 0.12138464240706526, 0.13692229811567813, 0.10064449437777512, 0.19814434577710927, 0.1715856560622342, 0.20217888319166377, 0.21280746208503842, 0.27042804518714547, 0.16296151414280757, 0.07721538946498185, 0.2031681512016803, 0.2997098380001262, 0.26508196955546737, 28.108248822391033, 62.832022458314896, 41.07652924954891, 57.50318840146065, 36.55321776866913, 66.16921618580818, 53.019991368055344, 0.8123427350074053, 8.856441266834736, 7.399994619190693, 8.056544288992882, 7.42833967320621, 2.152224937453866, 0.1518625026801601, 11.672295369207859, 70.11096507310867, 61.12981639802456, 66.53192192316055, 61.631666868925095, 67.93042168021202, 67.6879794895649, 66.24957427382469, 66.27927348017693, 70.98212152719498, 62.18767203390598, 67.57039859890938, 67.32529655098915, 63.72789278626442, 69.75763723254204, 68.19769933819771, 66.13101303577423, 63.89516741037369, 66.2939178943634, 63.45383249223232, 61.957472786307335, 61.783989295363426, 56.58977061510086, 48.85658137500286, 49.5852492749691, 47.73847617208958, 50.64587876200676, 51.041414737701416, 50.89676409959793, 51.89110614359379, 47.567253559827805, 47.89718985557556, 47.488388791680336, 46.04987718164921, 44.57215167582035, 47.5387778878212, 55.24957872927189, 65.7806034386158, 64.56928163766861, 61.71435423195362, 60.191019773483276, 61.32765658199787, 64.40181702375412, 62.32933983206749, 63.598274141550064, 57.03623905777931, 51.36366404592991, 54.72243681550026, 58.46747025847435, 62.61486791074276, 62.561594769358635, 58.484170362353325, 56.13867402076721, 60.393795892596245, 61.410571932792664, 60.724944323301315, 57.018285021185875, 54.94037412106991, 51.56081646680832, 48.47735412418842, 44.69843029975891, 46.960258930921555, 47.78452970087528, 49.792490154504776, 49.23602521419525, 47.42037624120712, 45.373540073633194, 45.30333884060383, 43.136387318372726, 45.87414041161537, 45.8025636523962, 43.60633850097656, 46.15041218698025, 44.68429505825043, 44.73067156970501, 46.98921337723732, 44.83167015016079, 46.84918709099293, 41.80899314582348, 43.95836301147938, 43.86995695531368, 43.57592113316059, 46.1827028542757, 46.065190359950066, 42.6394347846508, 42.73509085178375, 47.45978772640228, 43.63879635930061, 42.54355452954769, 44.28881987929344, 46.4382429420948, 47.334592044353485, 46.83594860136509, 52.702127024531364, 52.10118547081947, 53.387363255023956, 57.044275626540184, 57.8867132216692, 59.27835434675217, 60.40551446378231, 60.67372307181358, 59.39197205007076, 60.255213528871536, 56.19976334273815, 49.281561970710754, 4.878907799720764, 1.246736019384116, 6.899863081052899, 42.95186161994934, 21.52528066188097, 1.082282387651503, 36.82715266942978, 51.161963269114494, 38.30280728638172, 49.065760150551796, 39.717467576265335, 47.591435462236404, 1.1161342961713672, 0.28417555906344205, 0.19303725654026493, 0.11969644940108992, 0.16457250894745812, 0.13649848726345226, 0.20000899181468412, 0.2617509139236063, 0.16404770663939416, 0.11683715478284284, 0.0973427016288042, 0.22589793778024614, 0.11654289322905242, 0.17169604310765862, 0.11600749305216596, 0.1413224620046094, 0.19591840740758926, 0.05061804498836864, 0.14479893405223265, 0.18910810409579426], [0.037755171142634936, 0.052820995333604515, 0.03757607235456817, 0.06927461712621152, 0.04236320688505657, 0.02783735078992322, 0.05500084633240476, 0.03044856399355922, 0.07082450349116698, 0.04287397889129352, 0.05258256183878984, 0.06007626070640981, 0.0992356457572896, 0.05145301307493355, 0.030064088823564816, 0.008114353258861229, 0.0502667085675057, 0.08753948743105866, 0.03816670687228907, 0.042361767118563876, 0.015987033548299223, 0.057019513988052495, 0.04001492176030297, 0.03517850120260846, 0.050774571354850195, 1.034712977707386, 33.28956909477711, 42.82913200557232, 35.38314275443554, 41.77529275417328, 33.88701483607292, 60.859677493572235, 3.7662633787840605, 1.1945847677998245, 1.3453738577663898, 1.3557199900969863, 5.5398766323924065, 2.0810452569276094, 1.2253196560777724, 0.5307579541113228, 27.119258791208267, 74.19814735651016, 56.21351100504398, 65.64774736762047, 59.9143186211586, 64.91504788398743, 61.847829669713974, 64.45361584424973, 63.0374014377594, 65.63830867409706, 64.17390525341034, 64.96272772550583, 68.13147649168968, 61.57463952898979, 57.451176792383194, 60.73717586696148, 58.4358711540699, 60.73888957500458, 59.508724585175514, 60.215182676911354, 54.92187291383743, 49.23971861600876, 45.882427766919136, 45.8119111508131, 46.772746592760086, 47.81207822263241, 43.97827014327049, 43.17645616829395, 44.321467727422714, 45.556268468499184, 45.02018563449383, 43.68172645568848, 42.44720309972763, 43.18425714969635, 41.42926812171936, 47.96418786048889, 56.40872932970524, 57.70639009773731, 55.80210708081722, 55.39490193128586, 59.193159118294716, 45.95652379095554, 54.58572395145893, 59.0584297478199, 55.24442620575428, 53.86559799313545, 49.14032734930515, 51.50628179311752, 56.29313953220844, 59.619268253445625, 60.263162702322006, 59.67202462255955, 56.73584617674351, 55.05059480667114, 52.40421921014786, 51.02964676916599, 43.75973626971245, 43.032318502664566, 41.52656950056553, 44.14092041552067, 51.56644016504288, 55.17042897641659, 55.15073463320732, 55.78137159347534, 46.63182735443115, 41.8088373541832, 40.14973238110542, 42.06035725772381, 41.09629578888416, 42.32992999255657, 42.519049644470215, 42.16520503163338, 41.628567427396774, 40.490194112062454, 40.37551626563072, 39.984764233231544, 40.79045780003071, 43.85653607547283, 46.06000363826752, 43.20593498647213, 41.09805129468441, 40.38817338645458, 40.171626806259155, 41.378601640462875, 41.21654413640499, 40.49699954688549, 40.581898391246796, 39.24315422773361, 43.10579515993595, 43.4943775087595, 46.678686439991, 47.62531064450741, 47.76075437664986, 50.499848797917366, 48.95118109881878, 48.85067269206047, 53.425076231360435, 53.167298063635826, 59.53315727412701, 54.90511201322079, 62.29644499719143, 52.52373419702053, 59.016681388020515, 26.14628490060568, 0.44989784772042185, 1.5595682454295456, 1.457129898481071, 9.741547722369432, 1.0354583314619958, 0.14349591569043696, 41.4034903049469, 28.84497418999672, 35.913145914673805, 46.521621868014336, 31.807724609971046, 16.904787495732307, 0.5167466215789318, 0.044614411672228016, 0.03546241350704804, 0.04907827409624588, 0.0441496008716058, 0.026828187656064983, 0.14124740118859336, 0.02098958571878029, 0.02927124503912637, 0.059682061546482146, 0.016697075916454196, 0.05811025213915855, 0.08217971917474642, 0.04381532271509059, 0.07445113427820615, 0.012830011546611786, 0.04575564926199149, 0.0499941548332572, 0.058969818710465916, 0.0661641574697569, 0.04171829539700411, 0.05180051259230822, 0.021090304435347207, 0.04723030411696527, 0.06351518008159474, 0.024090497645374853, 0.02455522866512183, 0.030281920298875775, 0.03547012071067002, 0.048975805766531266, 0.05953478976152837, 0.0513062459503999, 0.04010160089819692, 0.05725739087210968, 0.03814405652519781, 0.036903567815897986, 0.04440626893483568, 0.11324928636895493, 0.05292889989505056, 0.0071822366498963675, 0.04319614890846424, 0.020238834695192054, 0.16978125757304952, 0.03212053365132306, 0.021409364853752777, 2.855676203034818, 47.42225334048271, 43.21080632507801, 41.55371904373169, 49.81165632605553, 41.15192860364914, 71.15474626421928, 3.0806680675596, 0.7807109167333692, 3.178362250328064, 1.845576404593885, 9.886790178716183, 2.671812856569886, 2.414287137798965, 0.40342746942769736, 30.420183464884758, 74.52818244695663, 58.896087259054184, 65.79139485955238, 61.096419990062714, 65.5429869890213, 63.16029064357281, 64.74715009331703, 64.6374499797821, 66.86586320400238, 64.33908239006996, 67.49507904052734, 67.91216745972633, 63.71335856616497, 60.29074162244797, 65.37376686930656, 60.92640571296215, 63.03200572729111, 62.94734247028828, 60.835256204009056, 57.094896510243416, 51.62555359303951, 48.23194809257984, 47.87576660513878, 48.36035840213299, 48.83204989135265, 44.50827710330486, 47.34783433377743, 46.16196356713772, 48.17056618630886, 46.79954655468464, 44.99705247581005, 44.8140162974596, 44.1766232997179, 44.22879450023174, 50.855023339390755, 59.58471670746803, 60.330536887049675, 57.56755314767361, 56.188523545861244, 57.10299767553806, 51.95982925593853, 57.9415138810873, 62.36881971359253, 57.515355348587036, 54.07776340842247, 50.77178120613098, 53.742040023207664, 58.93558233976364, 59.729192554950714, 61.535950005054474, 60.563490986824036, 59.92005251348019, 56.61014512181282, 54.94283638894558, 52.457606345415115, 46.904778108000755, 45.33188670873642, 43.45540679991245, 45.66560760140419, 51.390399411320686, 55.21851919591427, 57.73131676018238, 54.71590876579285, 47.22036637365818, 42.750647217035294, 42.58099012076855, 43.286555260419846, 43.52579042315483, 44.93959195911884, 43.82206812500954, 43.35521377623081, 44.21603478491306, 41.87663711607456, 42.85301752388477, 41.68776445090771, 43.666607066988945, 45.752444341778755, 48.991249948740005, 44.5371213555336, 43.89915078878403, 42.28091262280941, 41.18334911763668, 43.29245634377003, 42.29644998908043, 40.59738636016846, 41.65709629654884, 39.96702678501606, 43.68716016411781, 43.94914850592613, 49.72211793065071, 50.248089507222176, 49.502048939466476, 51.08485780656338, 53.018722236156464, 52.32660457491875, 55.221243649721146, 54.40619498491287, 60.55464506149292, 55.0122244656086, 63.30716796219349, 52.48699016869068, 60.733699053525925, 27.195891179144382, 0.7951514481101185, 2.726467461325228, 3.1975155975669622, 4.765472486615181, 1.046572735067457, 0.1815487808198668, 47.430882677435875, 34.43802706897259, 44.5154245197773, 51.84845343232155, 38.256134390830994, 25.092424750328064, 0.7485496206209064, 0.04018821695353836, 0.024646887613926083, 0.0040635085406393046, 0.042741301440401, 0.029224727222754154, 0.026940422649204265, 0.07594058755785227, 0.07074197666952386, 0.01265660039280192, 0.04143503989325836, 0.11547449001227506, 0.03462215019681025, 0.06119950121501461, 0.03597386457840912, 0.05008062616980169, 0.03191592353687156, 0.030716698238393292, 0.07500597872422077, 0.050551229433040135, 0.06060302228434011, 0.14327488926937804, 0.20595034409780055, 0.22194074699655175, 0.15604857180733234, 0.12167140084784478, 0.21039726329036057, 0.1014730057795532, 0.12648192787310109, 0.1208710836363025, 0.1849384215893224, 0.19040233542909846, 0.15820503031136468, 0.31427074573002756, 0.1773228435195051, 0.10346130846301094, 0.1234753911558073, 0.2841186511795968, 0.11304296931484714, 0.10088355498737656, 0.2738357795169577, 0.2521921705920249, 0.2162505968590267, 0.11848282272694632, 0.11474362298031338, 2.0437091728672385, 57.64113999903202, 52.92436569929123, 47.90934540331364, 54.595888406038284, 46.89403988420963, 71.72562763094902, 4.837216911837459, 2.0911033172160387, 8.3365398645401, 4.49914762750268, 11.23072961345315, 3.7339045526459813, 2.7498086588457227, 0.5765766080003232, 31.96804940700531, 73.58460947871208, 59.1236836463213, 66.68583646416664, 64.47203725576401, 67.54834458231926, 65.23896530270576, 67.03004479408264, 68.62325370311737, 69.78029161691666, 65.90180933475494, 69.25205916166306, 72.36181229352951, 65.03452107310295, 61.914390698075294, 67.00271666049957, 63.32834042608738, 65.85735931992531, 64.66086432337761, 61.76242545247078, 59.4454275816679, 52.96460933983326, 50.79353503882885, 49.339641854166985, 52.243252247571945, 52.151540368795395, 46.76772326231003, 48.72927300632, 47.60307423770428, 49.86761212348938, 50.067340806126595, 48.537425100803375, 47.114222869277, 47.636960819363594, 47.326669469475746, 53.82735304534435, 61.90883919596672, 62.83813253045082, 57.957541421055794, 57.477083802223206, 58.84003646671772, 51.14875137805939, 57.41747260093689, 65.52320525050163, 58.360790982842445, 58.61969769001007, 55.52773140370846, 56.26936800777912, 62.15832240879536, 63.283882811665535, 63.99407610297203, 64.30242955684662, 62.001394629478455, 59.77489650249481, 58.22981581091881, 55.30041240155697, 48.40459182858467, 47.02366232872009, 46.31111316382885, 49.24815036356449, 55.19986219704151, 60.15655942261219, 61.787211522459984, 59.351549819111824, 49.81255307793617, 46.32743328809738, 44.28259961307049, 47.44057975709438, 46.10211297869682, 46.88959412276745, 46.8549931794405, 47.190469577908516, 46.3326770067215, 44.993146285414696, 45.73016993701458, 43.237625285983086, 45.137226954102516, 50.01820184290409, 49.94741544127464, 46.070969849824905, 45.34626133739948, 44.07615289092064, 43.06540712714195, 45.609906390309334, 45.54949723184109, 44.02006410062313, 44.850342348217964, 43.2584747672081, 46.41269691288471, 46.951811984181404, 51.88729874789715, 54.19603206217289, 51.555865332484245, 53.65378595888615, 54.92531172931194, 53.91385160386562, 57.78333976864815, 58.25987979769707, 63.01660895347595, 55.847780629992485, 63.659872636199, 51.40879802405834, 63.710660710930824, 28.49412191659212, 0.7667474378831685, 3.0205790419131517, 5.154891740530729, 26.130931824445724, 3.8788503874093294, 0.2990851574577391, 51.30256712436676, 41.31832927465439, 50.46664237976074, 56.62245646119118, 48.10128830373287, 35.1809898018837, 0.8157226536422968, 0.1429727757931687, 0.09658247523475438, 0.050404284193064086, 0.10174921088037081, 0.2129319796222262, 0.16528871114132926, 0.10170184701564722, 0.13400172436377034, 0.17380058096023276, 0.07578679971629754, 0.16285321995383129, 0.0881158393167425, 0.13682869845069945, 0.16500639816513285, 0.11526382397278212, 0.11599289500736631, 0.1727665466023609, 0.18260282347910106, 0.24603078636573628], [0.02037750127783511, 0.04524195319390856, 0.034255607170052826, 0.0414547735999804, 0.012972163440281292, 0.07544650274212472, 0.04662707164243329, 0.026501575885049533, 0.02850449331162963, 0.03314868277811911, 0.059660969709511846, 0.039073377556633204, 0.04561387308058329, 0.010019678265962284, 0.027571051505219657, 0.05314809692208655, 0.07876504576415755, 0.004017891969851917, 0.09406577824847773, 0.028504075853561517, 0.11442574628745206, 0.016793423383205663, 0.022487280548375566, 0.1089566299924627, 0.18779701116727665, 0.3159415576374158, 5.253964299336076, 37.75407873094082, 24.81397569179535, 42.34081640839577, 32.642140835523605, 45.39315082132816, 25.70297408849001, 0.7305167976301163, 2.1360126323997974, 0.8218318945728242, 8.886902332305908, 2.967130159959197, 1.2051156652159989, 0.13748720608418807, 3.144092601723969, 60.30697055160999, 67.05657497048378, 60.01541219651699, 64.44487631320953, 64.38534870743752, 65.54376974701881, 66.243327409029, 67.26851999759674, 64.30407106876373, 64.33381587266922, 62.98477046191692, 59.57950338721275, 57.782830595970154, 56.82138718664646, 57.275728806853294, 60.46324096620083, 60.90599700808525, 59.547904282808304, 56.43677182495594, 54.46436986327171, 46.5744162350893, 44.36099700629711, 46.92858763039112, 44.84530761837959, 45.272609889507294, 44.762027487158775, 45.392611250281334, 45.912096574902534, 44.90402966737747, 42.91262872517109, 42.20477990806103, 42.64224283397198, 43.60974691808224, 43.4438706189394, 47.45196774601936, 52.76515044271946, 58.519732654094696, 56.556313410401344, 63.99590760469437, 43.180096372962, 47.6329330354929, 59.44086402654648, 58.408630415797234, 60.251508727669716, 56.52181126177311, 57.286045253276825, 53.9715401083231, 58.20746161043644, 59.4910479336977, 59.19764667749405, 60.05507826805115, 56.63440681993961, 55.4986135661602, 51.66545145213604, 46.73203557729721, 43.60333666205406, 46.01269617676735, 51.858731880784035, 53.72027859091759, 56.498252525925636, 57.96897500753403, 57.56325177848339, 59.1196558624506, 50.68408191204071, 41.80062219500542, 40.35380803048611, 40.6932932138443, 42.30109713971615, 41.94928541779518, 42.3662256449461, 42.27685064077377, 42.03244775533676, 40.76027601957321, 40.654839277267456, 40.76252169907093, 46.234266087412834, 51.804383397102356, 50.637093633413315, 47.75528647005558, 46.5128443390131, 46.1759278178215, 42.8193399310112, 41.974508464336395, 40.64694330096245, 40.957610830664635, 39.99118588864803, 40.16381062567234, 42.316349521279335, 47.06849232316017, 48.858462274074554, 49.49222646653652, 52.05967649817467, 50.07891118526459, 50.08225120604038, 50.80611616373062, 55.03796428442001, 53.360350504517555, 55.72298012673855, 58.833960592746735, 59.048622474074364, 57.190586775541306, 44.17594313621521, 5.760183585807681, 0.19796618580585346, 0.6608215905725956, 2.591630509123206, 3.6855438351631165, 0.9719743661116809, 2.830446269363165, 37.96519160270691, 26.776764169335365, 41.88709795475006, 35.53494840860367, 40.36519601941109, 7.173338681459427, 0.5194766563363373, 0.050083605892723426, 0.04282938323740382, 0.05692340215318836, 0.051489385732566006, 0.016161568128154613, 0.05865310347871855, 0.028870394380646758, 0.034047709341393784, 0.023707438122073654, 0.04446666862349957, 0.1261441913084127, 0.06020437023835257, 0.05723128953832202, 0.042734072922030464, 0.01817811880755471, 0.10108176778885536, 0.056802391263772734, 0.03730599368282128, 0.028097106187487952, 0.013560243114625337, 0.08939888648455963, 0.030375583046406973, 0.064271547307726, 0.07057643320877105, 0.026720546557044145, 0.057419282966293395, 0.05398431181674823, 0.04176367030595429, 0.0257996915752301, 0.03703965172462631, 0.04941380277159624, 0.07937984089949168, 0.05199179002374876, 0.032835273814271204, 0.055882209780975245, 0.006615775737373042, 0.04234610409184825, 0.045592339665745385, 0.0777724826184567, 0.06720038116327487, 0.05687488795956597, 0.09229862072970718, 0.02310773455974413, 0.13323174614924937, 0.2857701078755781, 11.84695204719901, 49.20008294284344, 25.346321426331997, 55.11228829622269, 33.639332726597786, 52.143849581480026, 23.78592375665903, 0.6171350972726941, 1.7861016397364438, 2.0103692868724465, 11.86970617622137, 3.6677940376102924, 4.862120300531387, 1.186265351716429, 4.453523475676775, 64.95314463973045, 62.92243480682373, 63.41772682964802, 64.42376464605331, 65.20354360342026, 65.45372977852821, 69.10543262958527, 67.46779650449753, 66.28042861819267, 65.86065754294395, 63.58635038137436, 61.64337784051895, 61.55748724937439, 58.833994790911674, 57.76698924601078, 60.62676519155502, 65.53779646754265, 62.192965149879456, 57.61407785117626, 56.88456639647484, 50.07742166519165, 47.230025455355644, 48.74842397868633, 47.27059967815876, 48.15717950463295, 46.78541511297226, 46.72921612858772, 48.87046203017235, 45.79572021961212, 46.47437900304794, 45.171406120061874, 45.478243455290794, 45.10104149580002, 45.868699103593826, 49.819350913167, 56.8048694729805, 62.18443840742111, 59.46280024945736, 63.811290711164474, 47.030832543969154, 46.38975754380226, 61.65676072239876, 61.20749182999134, 61.94714494049549, 59.12692487239838, 58.41270759701729, 56.239744797348976, 58.66121046245098, 62.190905660390854, 61.70710042119026, 62.41007409989834, 57.716356962919235, 57.98159413039684, 52.704125717282295, 50.118296071887016, 45.042049661278725, 48.22162784636021, 51.90596714615822, 57.02472187578678, 57.79184751212597, 61.37928821146488, 60.34199707210064, 62.494699358940125, 52.84983649849892, 44.41126450896263, 43.72295804321766, 42.714203372597694, 44.54610027372837, 44.62123364210129, 43.49578723311424, 43.03675666451454, 42.511605843901634, 41.957074999809265, 43.381420969963074, 44.477373361587524, 48.64823095500469, 53.56007158756256, 52.02800899744034, 49.93131570518017, 47.2714888304472, 47.218329682946205, 44.897231832146645, 44.95826415717602, 42.24512994289398, 44.54006239771843, 41.809760704636574, 43.1407380849123, 43.57191614806652, 49.65233847498894, 50.00460997223854, 51.00623622536659, 52.143959775567055, 53.499149456620216, 51.07871733605862, 55.02670928835869, 55.317747071385384, 56.66157156229019, 58.54033514857292, 60.41203871369362, 56.82207494974136, 57.25072234869003, 44.920710772275925, 6.4743049163371325, 0.8607666241005063, 3.4722007205709815, 4.473071526736021, 1.5010092314332724, 0.9498523687943816, 3.262173878028989, 44.74852301180363, 33.52611780166626, 50.47234587371349, 37.015512362122536, 47.77662232518196, 10.994812622666359, 0.6116006942465901, 0.08725303327082656, 0.1097832340747118, 0.05482386637595482, 0.014848719092697138, 0.04005576585768722, 0.0388058926910162, 0.02988948930578772, 0.04715451599622611, 0.009475508686591638, 0.03566548737580888, 0.032261749511235394, 0.06330528587568551, 0.0564738276443677, 0.04458407638594508, 0.015615622032782994, 0.007323410300159594, 0.06905594331328757, 0.04969293193425983, 0.02113066984748002, 0.0808281940408051, 0.11470253026345745, 0.07846970809623599, 0.24011015484575182, 0.13775129191344604, 0.2009186867508106, 0.1235260278917849, 0.15685132326325402, 0.11292403272818774, 0.12040702611557208, 0.15350578090874478, 0.1912457268917933, 0.27252060477621853, 0.12057170868501998, 0.11652476998278871, 0.14197785261785612, 0.17121446348028257, 0.09027804204379208, 0.14843403274426237, 0.10940027103060856, 0.29397039441391826, 0.13224319060100242, 0.15082595986314118, 0.22582020523259416, 0.16812686197226867, 0.26705925876740366, 13.307011350989342, 64.37910944223404, 34.64543513953686, 58.994315788149834, 44.32169571518898, 56.81300863623619, 32.46230028569698, 0.9951272956095636, 8.060724064707756, 5.523967361077666, 24.71412844955921, 7.473045699298382, 5.646459963172674, 0.78041922301054, 4.997927388176322, 66.18759959936142, 64.38397318124771, 62.14010998606682, 65.5726557970047, 68.8506107032299, 65.55672705173492, 71.83256149291992, 71.50323316454887, 65.96375361084938, 68.20594489574432, 68.9279593527317, 63.64775508642197, 63.55164684355259, 60.91089494526386, 61.66774593293667, 64.43717792630196, 68.30199614167213, 64.36961755156517, 59.745410084724426, 58.76450791954994, 51.30329288542271, 48.416849970817566, 51.49784244596958, 48.92425574362278, 50.07983833551407, 50.22548831999302, 48.88204760849476, 51.03698417544365, 49.43453796207905, 48.063928708434105, 46.79221674799919, 46.21945068240166, 48.81427064538002, 49.23080429434776, 52.378122210502625, 58.348795026540756, 63.810682743787766, 62.14019738137722, 68.61766800284386, 50.889848470687866, 49.35676373541355, 62.56898917257786, 62.594858184456825, 64.02510523796082, 62.084161788225174, 62.6972246915102, 60.48746086657047, 61.29594348371029, 64.20573994517326, 62.80822813510895, 64.84388530254364, 60.64891040325165, 61.03727616369724, 55.27423180639744, 52.04714857041836, 47.47367978096008, 51.373608112335205, 56.059288680553436, 57.015473172068596, 59.279904663562775, 62.22227677702904, 60.68856507539749, 64.84187141060829, 55.66497623920441, 46.96447670459747, 47.238206416368484, 44.36058282852173, 47.28428274393082, 47.70796000957489, 45.1565907150507, 44.5737361907959, 44.40901502966881, 42.93350100517273, 44.753504544496536, 45.58516971766949, 52.331232726573944, 55.52983269095421, 58.142226710915565, 51.865214332938194, 50.02323657274246, 51.247758865356445, 47.18903325498104, 46.241573095321655, 44.896718859672546, 46.857846826314926, 44.350745156407356, 44.31644819676876, 48.97106163203716, 52.65459917485714, 54.20726805925369, 53.49945344030857, 57.318400517106056, 55.34150339663029, 54.235937520861626, 56.411548778414726, 61.19158208370209, 58.18907059729099, 60.827576816082, 62.587570175528526, 58.219214379787445, 59.282606318593025, 48.06454047560692, 6.812926596030593, 0.6289613689295948, 3.1453484343364835, 8.265491276979446, 10.384401977062225, 1.6427314141765237, 4.059337377548218, 50.820483192801476, 39.509432539343834, 53.97510811686516, 40.856182873249054, 61.90958395600319, 12.98121303319931, 0.8878592890687287, 0.44624211732298136, 0.12769645254593343, 0.2903289132518694, 0.11779485183069482, 0.11938018316868693, 0.1279028141289018, 0.1134499408362899, 0.12703908781986684, 0.11373527435353026, 0.15353515511378646, 0.1554132637102157, 0.0917598808882758, 0.0776116740598809, 0.1664386541233398, 0.10449253750266507, 0.130248267960269, 0.14652735146228224, 0.1480333917425014, 0.11140740942209959], [0.060439734952524304, 0.024256091201095842, 0.050525673577794805, 0.03210849972674623, 0.04718735974165611, 0.05774527875473723, 0.021616709782392718, 0.028960903000552207, 0.07622232165886089, 0.09932626941008493, 0.050871725907200016, 0.07316439121495932, 0.05074531589343678, 0.020842944759351667, 0.049385616002837196, 0.06312025361694396, 0.05372943232941907, 0.06454505841247737, 0.04548931843601167, 0.03601825243094936, 0.032183727525989525, 0.030365443453774787, 0.01617822563275695, 0.09750126890139654, 0.047032718430273235, 0.14288109086919576, 0.2041454112622887, 27.013746052980423, 41.866924837231636, 30.889078304171562, 45.354503095149994, 35.96725881099701, 49.18002761900425, 0.7427553471643478, 1.8058530986309052, 1.1851668544113636, 12.130419686436653, 2.3662420408800244, 2.2564730560407043, 1.9553864747285843, 0.1464967304491438, 21.17160513997078, 74.93647053837776, 62.286356538534164, 71.11391365528107, 65.13824790716171, 66.58542305231094, 63.18987965583801, 62.28279232978821, 59.81595329940319, 59.15002003312111, 55.69131262600422, 57.60764479637146, 55.18517978489399, 57.63244986534119, 59.56578612327576, 59.52209986746311, 58.45288284122944, 58.28978419303894, 56.92882262170315, 51.62976756691933, 45.29944784939289, 48.6606714874506, 45.329105257987976, 46.84958606958389, 45.32424911856651, 44.30595315992832, 45.20378418266773, 45.95799431204796, 44.975386038422585, 43.83470244705677, 43.100327253341675, 42.47116461396217, 42.37982891499996, 44.77268971502781, 44.91081990301609, 49.617984518408775, 56.71935126185417, 56.443448066711426, 56.68622083961964, 52.94048823416233, 56.94806098937988, 57.65587940812111, 60.1480782777071, 59.96005296707153, 58.261103332042694, 56.4125557243824, 57.85446435213089, 58.05576615035534, 59.3807702511549, 60.716052800416946, 61.98964186012745, 57.874576672911644, 54.88338477909565, 49.69656430184841, 50.9230662882328, 52.25692771375179, 56.27035215497017, 55.755297392606735, 57.85218067467213, 57.89688527584076, 59.94538955390453, 56.43719360232353, 56.269018426537514, 48.34000289440155, 41.09043650329113, 42.59511776268482, 41.288234889507294, 42.291472256183624, 41.831970512866974, 43.05932745337486, 42.071262672543526, 40.68164303898811, 41.51803515851498, 39.705616012215614, 43.681494668126106, 51.77257910370827, 54.26953911781311, 55.055663734674454, 53.58409769833088, 47.744004875421524, 47.23722226917744, 44.95048977434635, 44.47828151285648, 44.059547781944275, 42.97090619802475, 40.16659587621689, 40.96949279308319, 45.68307526409626, 49.10938560962677, 49.210087805986404, 55.91889761388302, 51.26197390258312, 53.38275410234928, 51.74498498439789, 51.95598006248474, 51.34233579039574, 55.54990701377392, 53.38547095656395, 57.92767882347107, 50.70506438612938, 54.6303753554821, 15.206454377621412, 0.5337241699453443, 2.463496634736657, 2.834990113042295, 2.273598024621606, 0.48737283213995397, 0.3550624178024009, 7.7539437264204025, 30.224330574274063, 35.61512790620327, 28.67823153734207, 41.94857485592365, 24.797594770789146, 0.6015904876403511, 0.11400380564737134, 0.05546290005440824, 0.09588322369381785, 0.035413992081885226, 0.09416805361979641, 0.014561090483766748, 0.01742878714139806, 0.02199074107920751, 0.008600973924330901, 0.03247064923925791, 0.028960225790797267, 0.05863552571099717, 0.03301825774542522, 0.025815293374762405, 0.032536744911340065, 0.028278509344090708, 0.027784682424680796, 0.04169716645264998, 0.07740997316432185, 0.06494091998320073, 0.07454195831087418, 0.033828556843218394, 0.027227060490986332, 0.030328371321957093, 0.025110798560490366, 0.045775479447911493, 0.07804766355548054, 0.04738099349197, 0.05532495335501153, 0.025613225116103422, 0.034320856793783605, 0.028437069195206277, 0.033605378193897195, 0.0214773270272417, 0.06277202308410779, 0.036394881244632415, 0.01992416593566304, 0.06476352442405187, 0.030912521324353293, 0.10260405368171632, 0.01555737828311976, 0.07930593041237444, 0.04478129470953718, 0.09333648456959054, 0.015521265377174132, 0.18986641574883834, 0.6837849458679557, 37.308070063591, 40.31339719891548, 34.07414339482784, 58.949485793709755, 40.646468326449394, 52.01394975185394, 0.592419917229563, 1.838005785830319, 2.83476616255939, 9.31273978203535, 3.3149064984172583, 5.486157014966011, 4.8523215763270855, 0.24456906714476645, 26.35539337992668, 75.75607895851135, 60.13620391488075, 69.40725803375244, 66.07334733009338, 67.4879278242588, 65.69007709622383, 65.85476025938988, 62.30635866522789, 60.30408650636673, 59.415196403861046, 63.087691739201546, 56.711284294724464, 59.86393332481384, 61.65372088551521, 63.26009228825569, 59.24722261726856, 62.25297912955284, 58.410021141171455, 54.00471992790699, 47.34813071787357, 50.97796954214573, 48.08822840452194, 49.200630113482475, 48.09203960001469, 45.187304466962814, 46.08621083199978, 48.27602572739124, 45.86891949176788, 47.351227551698685, 45.00251278281212, 46.077581495046616, 47.25298762321472, 46.79481200873852, 47.6945885270834, 51.927496790885925, 59.84724462032318, 60.00990629196167, 58.95117670297623, 53.07213217020035, 57.44691722095013, 59.5561308413744, 61.2860032171011, 62.38910302519798, 60.62483489513397, 58.03479887545109, 59.79282774031162, 60.0864227861166, 61.97585619986057, 62.68205210566521, 62.729264572262764, 59.88205075263977, 56.11612603068352, 51.75448067486286, 51.479417234659195, 53.17673295736313, 56.97632387280464, 56.63050822913647, 60.12201927602291, 59.25304390490055, 60.70702828466892, 58.620868027210236, 59.607048109173775, 49.11253564059734, 43.78574587404728, 42.637223303318024, 42.16068707406521, 44.583543464541435, 44.84513662755489, 45.74805557727814, 44.23466898500919, 42.927288338541985, 43.87413293123245, 41.52901276946068, 45.23968085646629, 53.58979359269142, 56.469028294086456, 56.367094963788986, 56.51487663388252, 50.03076396882534, 49.43310923874378, 46.75979308784008, 47.08016909658909, 46.39111787080765, 44.44016955792904, 41.25434830784798, 42.78205633163452, 48.188603818416595, 50.82070358097553, 51.66693337261677, 57.587300688028336, 53.03246229887009, 56.46998964250088, 52.67310418188572, 54.75219301879406, 53.13895918428898, 57.029870599508286, 55.703221186995506, 58.32827992737293, 51.92624285817146, 56.674684658646584, 16.452592760324478, 1.312600497622043, 3.0618063546717167, 4.375222977250814, 3.741718833334744, 0.6273914594203234, 0.5487429234199226, 9.289606623351574, 34.528997987508774, 42.48552784323692, 31.94691874086857, 42.60236017405987, 34.79283683001995, 0.9459427942056209, 0.11830071453005075, 0.043665583289111964, 0.04220446520776022, 0.04961449063557666, 0.02614565299154492, 0.0447514343977673, 0.07284071092726663, 0.07396119806799106, 0.03734650010301266, 0.02012942171859322, 0.051985125537612475, 0.059630363539326936, 0.047264977256418206, 0.014873007730784593, 0.03570309199858457, 0.06982465245528147, 0.0775840513233561, 0.01712249908450758, 0.1050133173703216, 0.0525078312784899, 0.15556622034637257, 0.13245293637737632, 0.08599715612945147, 0.10758137097582221, 0.09818663485930301, 0.17890962946694344, 0.11585456610191613, 0.18107990676071495, 0.1969206630019471, 0.2411251308512874, 0.14277530513936654, 0.12167212073109113, 0.08827360506984405, 0.10081385989906266, 0.1994186727097258, 0.16893281950615346, 0.1269568727002479, 0.23181053926236928, 0.13543314911657944, 0.18913014588179067, 0.11037759788450785, 0.16166063316632062, 0.07699814057559706, 0.26288411405403167, 0.1326007573516108, 0.12410809431457892, 0.42085042514372617, 45.94728648662567, 56.32712110877037, 42.85860702395439, 59.488137289881706, 44.9796000123024, 58.1558907777071, 0.8738766331225634, 5.635621044784784, 7.146883551031351, 23.067439310252666, 8.981366213411093, 7.971449755132198, 6.782409008592367, 0.17353429837385193, 27.775217592716217, 74.89136695861816, 64.11291092634201, 72.59321227669716, 70.24434551596642, 71.55315488576889, 70.0044795870781, 67.43473827838898, 64.91291999816895, 64.51501294970512, 62.08139553666115, 65.31268894672394, 60.87072350084782, 62.49924771487713, 64.04487177729607, 64.61054742336273, 62.77245305478573, 63.020530343055725, 61.444367319345474, 58.17208930850029, 49.63571436703205, 52.94626772403717, 49.780604392290115, 51.1742328107357, 50.52739731967449, 47.665447890758514, 48.257718309760094, 51.249738559126854, 48.878065422177315, 49.584918692708015, 47.24295236170292, 47.808901593089104, 49.19735848903656, 50.56501530110836, 48.53380389511585, 53.519497364759445, 60.9171038120985, 61.74173556268215, 59.974066615104675, 58.13226744532585, 58.88881824910641, 61.453939005732536, 64.31018114089966, 62.771282717585564, 60.79432100057602, 60.17771288752556, 62.04860329627991, 63.300381526350975, 63.378364741802216, 64.44043055176735, 66.6559548676014, 63.76708388328552, 59.348969757556915, 54.77965794503689, 56.65121331810951, 57.603370025753975, 62.74188369512558, 59.788043797016144, 63.27992722392082, 62.70009733736515, 64.00918409228325, 60.29688589274883, 60.199250131845474, 52.57399410009384, 46.23026870191097, 45.810927003622055, 44.10418778657913, 47.0863551646471, 46.50563232600689, 49.54054847359657, 46.06995150446892, 44.787744507193565, 47.561398074030876, 44.36760485172272, 48.498784974217415, 55.704668909311295, 59.68915030360222, 60.20697131752968, 59.601166024804115, 52.5298822671175, 52.373106479644775, 48.640627562999725, 49.92356412112713, 48.94427686929703, 46.51145741343498, 44.416781812906265, 44.48703244328499, 50.66225588321686, 53.73268112540245, 54.83694367110729, 58.177393823862076, 55.30735082924366, 58.83168451488018, 55.21919555962086, 56.63438022136688, 55.94121761620045, 59.42881107330322, 57.72742956876755, 57.556267753243446, 54.14788104593754, 57.128965482115746, 16.87515288591385, 1.1151246191002429, 6.183530744165182, 7.39934247918427, 9.312989618629217, 3.4474742598831654, 0.8286284236237407, 9.772961586713791, 44.53014113008976, 47.88902789354324, 38.413225561380386, 53.34834694862366, 44.515473917126656, 1.077926040161401, 0.2518925804179162, 0.10601371017401107, 0.16421664913650602, 0.10765194921987131, 0.26043864840175956, 0.1339554737205617, 0.1264841840020381, 0.16149992850841954, 0.11811934848083183, 0.1865032102796249, 0.10292195263900794, 0.12871141370851547, 0.166354019602295, 0.10945044021354988, 0.12536124035250396, 0.1674712190288119, 0.09389163329615258, 0.16215851035667583, 0.16427156806457788, 0.1001355295011308], [0.10997356526786461, 0.007655581221115426, 0.031393956232932396, 0.020752224627358373, 0.037075219152029604, 0.038019030616851524, 0.04701466197730042, 0.034493929342716, 0.12157287332229316, 0.012335701303527458, 0.018224762789031956, 0.028367325867293403, 0.08688967776834033, 0.05177553932298906, 0.051350837893551216, 0.13138307112967595, 0.04416543088154867, 0.004289911821615533, 0.03119322755082976, 0.145889297418762, 0.07221298015792854, 0.044230843777768314, 0.12879756221082062, 0.022858992633700836, 0.0729183544171974, 0.11566592700546607, 0.06951768533326685, 5.929336734116077, 56.943261846899986, 22.61543456465006, 39.81910452246666, 29.71573356539011, 39.52871650457382, 12.19228321686387, 1.0669740778394043, 0.7440702547319233, 3.285692003555596, 4.882754143327475, 5.392816923558712, 1.7725101253017783, 0.5080965044908226, 2.3878624057397246, 55.59124119579792, 68.63770812749863, 64.93496641516685, 66.06149196624756, 60.547102466225624, 59.451940432190895, 57.36538119614124, 56.0180950909853, 55.08176453411579, 58.89075614511967, 51.18877463042736, 54.89928312599659, 55.09016968309879, 58.96168313920498, 56.41440622508526, 57.706067115068436, 56.14842809736729, 54.18649837374687, 48.382917791604996, 45.649534463882446, 45.9222724288702, 46.73689551651478, 45.97781024873257, 44.744628220796585, 47.795602306723595, 49.64419551193714, 51.37844905257225, 45.86506649851799, 43.43808352947235, 43.82412001490593, 43.62560346722603, 43.840922713279724, 43.35149757564068, 43.735542967915535, 47.72480830550194, 52.722459733486176, 57.2479522973299, 58.29030096530914, 55.59002906084061, 59.828511625528336, 58.22573482990265, 57.79227688908577, 56.12508974969387, 59.6739587187767, 58.51279802620411, 59.816291481256485, 59.71943847835064, 59.27219107747078, 56.66403383016586, 59.552741423249245, 59.79820065200329, 57.5213286280632, 55.37470981478691, 53.59107032418251, 56.862668171525, 60.30103147029877, 60.590047761797905, 58.464628010988235, 58.92759516835213, 58.68074141442776, 56.641482040286064, 54.053790494799614, 45.97843341529369, 40.32709926366806, 40.65218321979046, 40.070267245173454, 42.04964563250542, 41.36034741997719, 40.40509767830372, 42.47527219355106, 42.18508556485176, 41.39386922121048, 42.544329687952995, 45.160086527466774, 54.053243324160576, 55.28519421815872, 56.24048575758934, 53.046506345272064, 53.573237881064415, 48.851774632930756, 47.7186868339777, 45.7198952883482, 46.214731335639954, 45.06120443344116, 43.98023843765259, 40.950854793190956, 42.520387172698975, 50.13797141611576, 50.97440913319588, 53.95845741033554, 55.20031817257404, 53.51399526000023, 53.023817762732506, 55.11819697916508, 54.381389915943146, 56.04070767760277, 55.62144957482815, 52.68145613372326, 56.60808943212032, 29.856130331754684, 0.8379611978307366, 0.5785484053194523, 1.5357568231411278, 3.076293314807117, 3.6335847107693553, 0.29241431853733957, 0.019622069157776423, 9.289437532424927, 36.26782648265362, 40.42296051979065, 25.172940529882908, 45.18207974731922, 6.873863451182842, 0.23986689368030056, 0.11211866891244426, 0.1271988870576024, 0.044953955366509035, 0.09149648525635712, 0.07447351745213382, 0.05704073570086621, 0.05779150713351555, 0.07215907055069692, 0.1349168666638434, 0.031962085122358985, 0.04676157848734874, 0.09531064191833138, 0.018333494845137466, 0.025570076650183182, 0.03913234861101955, 0.009023306974995648, 0.09517322585452348, 0.08802853306406178, 0.016081861467682756, 0.030303257044579368, 0.06682144798105583, 0.05795130266051274, 0.03562052435881924, 0.04793783802597318, 0.03604201599955559, 0.039583006655448116, 0.039391324753523804, 0.10972771400702186, 0.04485113451664802, 0.05311333472491242, 0.07989688034285791, 0.02533817219955381, 0.02537245200073812, 0.0164359623886412, 0.03622505930252373, 0.09373811262776144, 0.02320548283023527, 0.03443648340180516, 0.06711151640047319, 0.0970948910980951, 0.04442497476702556, 0.05909125262405723, 0.058119592067669146, 0.06299123866483569, 0.08475318303680979, 0.05080791604996193, 0.054032744374126196, 11.042522862553596, 64.83722046017647, 23.339453414082527, 50.34333139657974, 34.79877591133118, 49.76877562701702, 11.834968440234661, 0.8400072099175304, 1.4722484559752047, 3.8809785107150674, 3.308297940529883, 5.310967890545726, 7.3380964156240225, 1.996990442276001, 3.055208483710885, 59.012307822704315, 69.67346414923668, 68.7621134519577, 68.25405791401863, 62.83899888396263, 59.86918464303017, 60.883927792310715, 57.89325647056103, 57.071915343403816, 59.66471001505852, 54.331969767808914, 56.752591878175735, 59.509488344192505, 60.21270900964737, 59.88294370472431, 58.84448602795601, 57.954300194978714, 55.65337926149368, 51.113599464297295, 49.554151743650436, 46.10354170203209, 48.357113376259804, 48.16995821893215, 48.65507058799267, 48.66145424544811, 51.23665206134319, 51.11187815666199, 47.3854561150074, 46.42271317541599, 46.64523683488369, 46.48159481585026, 45.08080378174782, 44.91162545979023, 46.086370423436165, 50.137367248535156, 54.647246450185776, 58.087011873722076, 60.30300356447697, 58.53321813046932, 59.81988608837128, 60.15869490802288, 58.56719210743904, 57.34714597463608, 61.27464942634106, 60.909671410918236, 62.707750126719475, 60.92804342508316, 60.70205055177212, 57.6075953990221, 62.918502017855644, 61.15748651325703, 58.50437767803669, 55.90469017624855, 54.57658924162388, 58.8076052069664, 62.27353982627392, 62.27328523993492, 61.78649716079235, 61.29791557788849, 60.71357533335686, 60.402816608548164, 57.13846117258072, 48.20243887603283, 42.4788174033165, 42.40986630320549, 41.9710810482502, 43.42799127101898, 43.36087167263031, 43.40904928743839, 42.669981345534325, 44.18492965400219, 43.26189078390598, 43.52634139358997, 47.612231746315956, 56.218374744057655, 58.16004015505314, 55.72899900376797, 55.20493872463703, 54.30532939732075, 51.85952603816986, 50.863375291228294, 46.970316991209984, 47.37629480659962, 48.28328333795071, 45.753979459404945, 43.72926190495491, 45.35240560770035, 50.47442436218262, 54.03259143233299, 56.15601249039173, 55.8598867803812, 54.945910423994064, 54.383738189935684, 56.74322158098221, 56.48577019572258, 59.70202401280403, 56.782595068216324, 53.6662644892931, 57.58799225091934, 32.538999170064926, 1.1381232412531972, 1.3113770820200443, 2.7900971844792366, 4.7342433873564005, 2.704954440705478, 0.30269030306953937, 0.03249643887102138, 11.790610570460558, 40.940135568380356, 48.20024639368057, 23.934159502387047, 55.02468399703503, 10.674570556730032, 0.4990907502360642, 0.17821508314227685, 0.02062041177850915, 0.04920216080790851, 0.08032703655771911, 0.06589108423213474, 0.029899549117544666, 0.03564520076906774, 0.015126650614547543, 0.015563657780148787, 0.038507348945131525, 0.014949161359254504, 0.03286729748651851, 0.045037038798909634, 0.060217038699192926, 0.06545714306412265, 0.06530177444801666, 0.06049062772945035, 0.04127722218981944, 0.016364751463697758, 0.0805929777561687, 0.21769739891169593, 0.19526022631907836, 0.10445113308378495, 0.13988073624204844, 0.10652525772457011, 0.12312350925640203, 0.15637545817298815, 0.1857624578406103, 0.23286676383577287, 0.17385299142915756, 0.14126411435427144, 0.19429013540502638, 0.1625874123419635, 0.12411506308126263, 0.14744725835043937, 0.2629035880090669, 0.18217457458376884, 0.1298379196668975, 0.12327472926699556, 0.20452797354664654, 0.21918083337368444, 0.16333490348188207, 0.15592203562846407, 0.11738279659766704, 0.1570407787221484, 0.15593410294968635, 0.1825316366739571, 12.37317156046629, 78.85370314121246, 32.397737950086594, 55.35958282649517, 41.349008828401566, 50.59098310768604, 16.210545748472214, 1.368898751679808, 4.497037790715694, 11.169951874762774, 15.853292718529701, 9.137908313423395, 8.21723386645317, 1.5237967274151742, 3.669694410637021, 59.119815453886986, 70.5188199877739, 70.298872590065, 69.34322386980057, 66.73156321048737, 61.69022552669048, 62.499509900808334, 61.19037754833698, 60.85320644080639, 64.06798213720322, 56.21190369129181, 59.190028086304665, 61.500509306788445, 62.3151133954525, 60.63182272017002, 61.49490460753441, 61.13932728767395, 58.72579179704189, 53.74586641788483, 50.90487286448479, 49.33342158794403, 50.86465582251549, 51.609237268567085, 49.707739502191544, 53.27720336616039, 55.1399128139019, 56.824400424957275, 50.62899246811867, 48.25100027024746, 48.12689892947674, 48.824959471821785, 46.50945492088795, 47.46065407991409, 47.7271793782711, 53.535429909825325, 55.03836326301098, 59.626985639333725, 64.75911945104599, 62.0019493997097, 63.88125255703926, 63.55603560805321, 61.523722261190414, 60.4470120370388, 63.024535328149796, 61.21856443583965, 63.6260886490345, 62.56749585270882, 61.58317007124424, 58.42422477900982, 64.70978289842606, 64.32434678077698, 61.62366829812527, 60.98473638296127, 55.5941404402256, 60.326953679323196, 64.99574035406113, 64.71264034509659, 61.957111805677414, 62.67865888774395, 62.41967998445034, 61.88802391290665, 60.33560961484909, 51.36363744735718, 46.32304832339287, 44.91468049585819, 43.80352512001991, 46.73660293221474, 45.5317559838295, 45.172280073165894, 45.46963311731815, 46.742226630449295, 45.20794875919819, 45.1631947606802, 49.59189131855965, 58.89417216181755, 61.27748407423496, 60.15246704220772, 56.76188997924328, 58.11116337776184, 55.280547067523, 53.275387063622475, 49.207686334848404, 50.802791342139244, 50.77629156410694, 48.76478590071201, 45.29100850224495, 46.65564827620983, 53.96675996482372, 54.61590953171253, 58.98114949464798, 58.07667262852192, 57.64084741473198, 55.40406323969364, 58.888206481933594, 59.22394126653671, 61.909640952944756, 59.64455209672451, 58.242966905236244, 58.39391380548477, 34.88063871860504, 1.0328217479400337, 2.144996775314212, 4.274869412183762, 8.167597129940987, 9.79739522561431, 1.8284782720729709, 0.10235049892798997, 15.432122368365526, 48.261578902602196, 55.20172029733658, 33.00036281347275, 65.93926012516022, 13.991913199424744, 0.5778045952320099, 0.35161425126716495, 0.2734837937168777, 0.18277178081916645, 0.2196703985100612, 0.22695909021422267, 0.16368035838240758, 0.14683482324471697, 0.21280802611727268, 0.2548568369820714, 0.15034978307085112, 0.13492431782651693, 0.14658733183750883, 0.08345220558112487, 0.08866803429555148, 0.1030117079790216, 0.17283120250795037, 0.14957891427911818, 0.12202790632727556, 0.11056876770453528, 0.163898000610061], [0.0419746740226401, 0.027491600885696243, 0.009969806869776221, 0.07024660793831572, 0.05007149404264055, 0.013604655086965067, 0.012081859895261005, 0.02399294047791045, 0.02927719891886227, 0.0269605329958722, 0.11329775603371672, 0.022152429082780145, 0.01990259170270292, 0.052871602383675054, 0.07319443335290998, 0.04015238977444824, 0.07407480603433214, 0.015712835956946947, 0.021206589699431788, 0.023881527413323056, 0.04001665467512794, 0.13793996069580317, 0.022870110005897004, 0.06573906270205043, 0.030027786669961642, 0.06058864317310508, 0.04283392147044651, 0.4015047725988552, 33.41079778969288, 46.34517453610897, 44.60532009601593, 59.44092482328415, 35.123567283153534, 22.75645449757576, 0.15611514245392755, 1.0508769541047513, 2.3438016325235367, 1.5676607424393296, 3.2740722270682454, 5.6140306033194065, 1.3875835365615785, 0.1028901145036798, 22.20349296927452, 74.07928973436356, 64.16309103369713, 70.35291329026222, 63.48448924720287, 67.91072353720665, 62.986221984028816, 63.881624937057495, 57.86598913371563, 57.85745479166508, 56.624580547213554, 53.319574892520905, 54.1592538356781, 57.664691135287285, 54.562849178910255, 55.542307421565056, 54.3302408605814, 52.944873198866844, 47.203966453671455, 46.253447458148, 47.9684816300869, 47.349760830402374, 48.71953412890434, 49.52602565288544, 51.1479078233242, 51.936319917440414, 53.472341895103455, 52.40880936384201, 45.94229735434055, 45.35414591431618, 42.667032703757286, 43.61589498817921, 43.436996787786484, 42.82290033996105, 45.82386530935764, 49.381694197654724, 53.965673223137856, 55.58879792690277, 58.59463043510914, 58.68462100625038, 58.34948278963566, 60.47706842422485, 57.54608429968357, 59.136124178767204, 58.46153877675533, 58.94525282084942, 55.88900461792946, 52.95180402696133, 59.32379610836506, 63.16015005111694, 59.20955143868923, 56.89364790916443, 58.67891751229763, 58.56181539595127, 59.36666540801525, 57.17498101294041, 56.40299543738365, 55.904735773801804, 57.50666901469231, 58.030611500144005, 56.82246632874012, 50.31363978981972, 46.71309359371662, 42.272169291973114, 41.10414996743202, 40.884696543216705, 42.06237114965916, 42.60677173733711, 41.265641301870346, 43.193437457084656, 41.86802297830582, 40.62684237957001, 40.72294682264328, 46.03317327797413, 54.65889662504196, 55.601990818977356, 57.39865601062775, 57.752329632639885, 56.96929045021534, 52.34035983681679, 48.277450650930405, 46.68361857533455, 47.33888581395149, 46.17221541702747, 44.95143212378025, 43.22865016758442, 42.17459812760353, 45.8191953599453, 51.6059048473835, 54.64980751276016, 54.267194643616676, 53.863439708948135, 52.89686277508736, 54.252082854509354, 55.6805744022131, 53.89105662703514, 50.83168499171734, 52.675045877695084, 44.41651202738285, 1.6265705251134932, 0.285149019327946, 0.9724225639365613, 2.283623549155891, 3.4031738620251417, 0.7956482714507729, 0.12558581423945725, 0.05190485855564475, 15.784508809447289, 50.39077565073967, 35.93415878713131, 34.78828467428684, 36.690770387649536, 0.8497790980618447, 0.020646238517656457, 0.09661993142799474, 0.02933837786258664, 0.013325243908184348, 0.019883986060449388, 0.0543331175140338, 0.05188844595977571, 0.031067886229720898, 0.024406921584159136, 0.02959821118565742, 0.02664857493073214, 0.020761694431712385, 0.0458880187215982, 0.019242583075538278, 0.08129142035613768, 0.004220817409077426, 0.006706224057779764, 0.012506610491982428, 0.03343304037116468, 0.135070372489281, 0.04300120897823945, 0.07614436646690592, 0.04568321935948916, 0.0723867466149386, 0.049138287868117914, 0.03153364697936922, 0.09274974261643365, 0.045524013839894906, 0.06449183900258504, 0.037081004193169065, 0.03209592403436545, 0.08715375617612153, 0.03251986105169635, 0.028213200348545797, 0.06918335522641428, 0.08176569725037552, 0.08385867986362427, 0.04971939320967067, 0.04439295480551664, 0.007495987465517828, 0.019239035609643906, 0.0221745487942826, 0.014077542309678392, 0.06378244972438551, 0.019831416029774118, 0.024740466869843658, 0.0677956132858526, 0.04742828314192593, 0.814774070167914, 46.094080209732056, 44.198662117123604, 40.99246636033058, 57.91446313261986, 41.10024377703667, 27.129400447010994, 0.14161975152092054, 2.6314694713801146, 2.4712684052065015, 3.125590682029724, 4.14690462872386, 6.866389727219939, 4.418875509873033, 0.42600395798217505, 27.4874210357666, 73.75344201922417, 66.01133465766907, 75.00916063785553, 65.30918553471565, 70.51172956824303, 65.2527129650116, 65.10628402233124, 59.147914946079254, 59.421739652752876, 58.06986339390278, 56.945678517222404, 56.97312444448471, 60.52617698907852, 56.75020180642605, 58.81333529949188, 57.220985144376755, 56.97425298392773, 48.587023839354515, 49.38949517905712, 49.84551630914211, 49.79677252471447, 49.59787219762802, 49.88496199250221, 51.13308101892471, 54.64044101536274, 55.74115075170994, 53.51514659821987, 49.131169840693474, 47.09773175418377, 45.559441298246384, 47.23611652851105, 46.652274057269096, 45.86766175925732, 49.76087965071201, 51.50307476520538, 56.11956104636192, 57.0141926407814, 60.10672889649868, 60.230780839920044, 61.35667182505131, 61.281774044036865, 58.16540166735649, 60.04781685769558, 60.36515682935715, 62.25759208202362, 58.75105284154415, 54.62547741830349, 59.90435555577278, 61.924509555101395, 61.92639425396919, 60.61321131885052, 61.30406364798546, 62.05594830214977, 60.61404727399349, 60.06074756383896, 58.60221102833748, 58.12938340008259, 60.361459627747536, 58.82228001952171, 57.19701603055, 52.13177762925625, 47.189010456204414, 44.04084138572216, 42.88208216428757, 43.126044273376465, 44.024038687348366, 44.105510115623474, 43.639613315463066, 45.70132948458195, 43.42758849263191, 43.28913152217865, 42.939079105854034, 46.18339441716671, 56.53936631977558, 58.10902029275894, 58.51417735219002, 59.614442512393, 57.4178221821785, 54.64657388627529, 50.34065634012222, 48.665048852562904, 49.03235234320164, 47.95432358980179, 46.90363056957722, 45.77319882810116, 44.83581192791462, 48.090375289320946, 53.48037466406822, 57.579153925180435, 56.4590310305357, 55.79456448554993, 56.3501288741827, 56.93055912852287, 57.36010707914829, 56.91830098628998, 54.38428916037083, 53.23508262634277, 46.220974400639534, 2.2246490512043238, 0.8296592370606959, 4.299707254394889, 4.231106685474515, 3.735711593180895, 1.035195195581764, 0.2501639403635636, 0.31377647537738085, 20.02909004688263, 58.78855682909489, 39.822410345077515, 33.491288870573044, 44.74940836429596, 1.5404050424695015, 0.07064932695357129, 0.047353582267533056, 0.06162016165035311, 0.047060511860763654, 0.07188886200310662, 0.03800092963501811, 0.01619056198251201, 0.019562996058084536, 0.055172768552438356, 0.03706916693772655, 0.03446992086537648, 0.04489122533414047, 0.02306166017660871, 0.033301179282716475, 0.08941033040173352, 0.0048823372344486415, 0.020195506258460227, 0.06639785977313295, 0.030580515995097812, 0.0657589893671684, 0.02226098487881245, 0.1764485935564153, 0.15134255401790142, 0.14740575745236129, 0.14184208412189037, 0.12896102765807882, 0.13052056194283068, 0.11056933173676953, 0.16395358747104183, 0.0739956040342804, 0.1346250541973859, 0.15335288364440203, 0.15239649277646095, 0.08151267684297636, 0.15977210481651127, 0.17267977469600737, 0.13924752100137994, 0.1418914517853409, 0.07943188771605492, 0.17484191805124283, 0.06327090217382647, 0.18290377920493484, 0.2175727329449728, 0.16415445716120303, 0.2007408533245325, 0.16823456244310364, 0.12548537197289988, 0.14275281806476414, 1.0375412134453654, 53.86573478579521, 63.478804752230644, 54.161966890096664, 67.97959864139557, 47.22174949944019, 30.08910723030567, 0.1732393985730596, 6.354730082675815, 9.405755940824747, 7.427084790542722, 8.123997319489717, 11.799481194466352, 4.740639394149184, 0.5502519174478948, 27.674819380044937, 76.18146613240242, 66.91918954253197, 77.56602063775063, 68.31781849265099, 75.31481623649597, 69.96479451656342, 71.2618625164032, 62.38648496568203, 62.83059373497963, 60.56415595114231, 60.02408713102341, 58.15085984766483, 63.06300446391106, 60.101082399487495, 61.91089488565922, 58.566139563918114, 58.87704648077488, 51.905628964304924, 50.003705620765686, 54.549325704574585, 53.35177816450596, 52.94267311692238, 52.439006343483925, 54.55502159893513, 56.607774049043655, 58.699330016970634, 57.49772809445858, 51.33977472782135, 51.344186291098595, 49.41293612122536, 48.943801894783974, 48.2614953070879, 48.57279360294342, 52.18845538794994, 54.4835664331913, 56.76964536309242, 60.27002893388271, 63.82329806685448, 61.513800993561745, 62.731365859508514, 64.00489792227745, 60.2234548330307, 61.879850551486015, 61.98551528155804, 64.86156955361366, 59.309524074196815, 55.19424989819527, 60.704474821686745, 66.6323733329773, 63.34905691444874, 61.83211371302605, 62.878326773643494, 64.63669002056122, 63.1278707832098, 60.83078384399414, 59.746044650673866, 58.56238156557083, 61.43302492797375, 61.86857655644417, 60.576729476451874, 55.291285291314125, 50.34803554415703, 47.215354442596436, 43.800774067640305, 45.61883211135864, 46.090219616889954, 46.62691041827202, 45.4511509090662, 48.755115419626236, 47.19047337770462, 45.524000599980354, 46.191605776548386, 51.00359536707401, 58.93411181867123, 59.914493411779404, 60.279539823532104, 64.07047480344772, 60.39608716964722, 55.38388632237911, 53.345850482583046, 52.028924748301506, 51.18508122861385, 50.72200767695904, 49.04977820813656, 49.01157885789871, 47.32940152287483, 51.033214777708054, 54.77495759725571, 58.817625269293785, 57.52757549285889, 57.43198402225971, 56.62683002650738, 59.49118472635746, 61.800495609641075, 59.06536437571049, 55.64403936266899, 55.38835108280182, 48.28189641237259, 2.6317646680399776, 0.7996979041490704, 4.083444708958268, 7.341594602912664, 11.18333475664258, 3.8819106481969357, 0.8191067876759917, 0.33563759294338524, 27.24519733339548, 62.24799759685993, 48.428921923041344, 45.80691821873188, 55.92294819653034, 1.7834743182174861, 0.21151179098524153, 0.1975924996077083, 0.08528750709956512, 0.11246319612837397, 0.0957835309964139, 0.13083659810945392, 0.20968377735698596, 0.15743920812383294, 0.17212791368365288, 0.14291971223428845, 0.10212044056970626, 0.10203897501924075, 0.15018303733086213, 0.1047839195234701, 0.2390079468023032, 0.19930322421714664, 0.06328049814328551, 0.1737578777829185, 0.09774277859833091, 0.291180987842381, 0.09976475252187811], [0.06932233722181991, 0.06663703170488589, 0.010923432309937198, 0.04314533405704424, 0.09251172843505628, 0.02244195573439356, 0.07393089617835358, 0.03425053087994456, 0.03694282000651583, 0.03610929910792038, 0.02303645684150979, 0.0306194267977844, 0.05437806939880829, 0.1261049762251787, 0.04787932339240797, 0.060889276064699516, 0.11566449466045015, 0.08138436693116091, 0.06510234452434815, 0.09343513083877042, 0.06610040698433295, 0.08488350416882895, 0.07257817618665285, 0.044271045917412266, 0.05041985816205852, 0.04789773236552719, 0.12999770406167954, 0.1381056080572307, 6.938189249485731, 58.040688559412956, 27.853162810206413, 52.84085378050804, 55.66045068204403, 23.76750234514475, 0.9394179505761713, 1.1912714643403888, 0.5743692233227193, 1.0278243036009371, 2.1372003061696887, 5.09677005931735, 3.411726728081703, 0.1932588469935581, 3.1459754006937146, 51.816789731383324, 68.73241424560547, 66.07368931174278, 66.19971334934235, 67.16179892420769, 64.19578447937965, 61.91614620387554, 59.97269868850708, 59.49455514550209, 53.20088446140289, 57.665720880031586, 56.748689487576485, 56.734797433018684, 55.5203939974308, 54.490003287792206, 50.20916439592838, 48.91642056405544, 48.449247032403946, 47.03969366848469, 46.98783405125141, 50.34531868994236, 52.128190621733665, 51.54671162366867, 56.017388328909874, 60.05641959607601, 55.45191787183285, 57.38829016685486, 52.12208814918995, 44.80904996395111, 43.59552428126335, 42.784605994820595, 45.09106703102589, 45.258736833930016, 44.09706696867943, 48.2969132065773, 50.50721660256386, 53.13491240143776, 54.50529366731644, 56.59241147339344, 59.05434116721153, 59.66797783970833, 59.97233010828495, 58.62944796681404, 60.899389162659645, 60.011266618967056, 59.961314499378204, 56.983657479286194, 50.26356227695942, 54.43858824670315, 60.0444920361042, 60.55132023990154, 59.11478452384472, 60.449808686971664, 57.910370752215385, 57.08787448704243, 58.94310973584652, 59.29771430790424, 58.21276232600212, 55.948437228798866, 52.1579772233963, 49.028062373399734, 45.121978372335434, 43.415672332048416, 40.97020335495472, 42.20306999981403, 41.33316367864609, 40.93057908117771, 40.77714331448078, 41.57776415348053, 41.14111438393593, 41.561569422483444, 42.94943355023861, 44.00130070745945, 52.363132014870644, 58.43857280910015, 56.90424174070358, 57.62809529900551, 57.36353449523449, 56.38070583343506, 53.98410603404045, 48.447856307029724, 46.58828169107437, 47.461049258708954, 47.15477429330349, 44.2182956635952, 41.245616376399994, 43.09908851981163, 46.29887402057648, 49.74102571606636, 54.88899327814579, 55.74339643120766, 52.34033323824406, 56.214574947953224, 55.15413925051689, 56.15518033504486, 50.30866585671902, 55.831179320812225, 7.353921616449952, 0.2157886841450818, 0.6019858445506543, 1.2545155081897974, 2.9543573828414083, 1.9870308204554021, 1.4507788955233991, 0.03285251390479971, 1.750369663350284, 34.021398425102234, 48.513178601861, 25.64548697322607, 49.68101553618908, 19.18255817145109, 0.40737545758020133, 0.09382668053149246, 0.023744263489788864, 0.018855855487345252, 0.012547162368719, 0.05641586962155998, 0.034220351444673724, 0.05103213741676882, 0.08618863023002632, 0.06763286030036397, 0.049118769384222105, 0.04101121790881734, 0.009884695518849185, 0.028490889744716696, 0.006291546724241925, 0.029132131312508136, 0.05275506293401122, 0.06660453305812553, 0.025554129751981236, 0.012536499561974779, 0.037202441817498766, 0.034801646033884026, 0.027848035861097742, 0.03701706446008757, 0.04061422085214872, 0.05073178283055313, 0.04318595179938711, 0.05210852985328529, 0.06875141043565236, 0.06350476774969138, 0.01418265639586025, 0.06843777882750146, 0.052257271090638824, 0.049810150449047796, 0.025401790953765158, 0.03781354476814158, 0.043657905771397054, 0.03152901597786695, 0.057930080947699025, 0.02328953105461551, 0.012428070858732099, 0.030476709944196045, 0.12482123886002228, 0.06080990337068215, 0.036941907164873555, 0.08868725592037663, 0.015010816205176525, 0.042518386253505014, 0.09102398209506646, 0.1023904635803774, 11.67017413303256, 67.3307454586029, 34.00542788207531, 65.32313838601112, 57.8214593231678, 30.716632157564163, 1.0795310977846384, 1.4491449831984937, 1.7904457566328347, 2.0624162815511227, 3.407820537686348, 7.768756756559014, 6.57857084646821, 1.1163272545672953, 3.1940824817866087, 56.618930250406265, 70.60196712613106, 67.90952280163765, 68.51504310965538, 69.12575393915176, 65.62380865216255, 62.6815315335989, 61.952704042196274, 59.969712048769, 56.99625000357628, 60.02081550657749, 58.31286795437336, 59.45551984012127, 57.68675655126572, 57.370940297842026, 52.42572605609894, 51.52939975261688, 50.763714239001274, 49.388176649808884, 48.76915566623211, 51.91738933324814, 54.14461322128773, 54.978231489658356, 57.4880538135767, 62.65948511660099, 58.05782563984394, 56.129166930913925, 53.099312111735344, 48.08087199926376, 46.211243122816086, 45.55172011256218, 46.752550676465034, 46.64254657924175, 47.61239893734455, 49.30888630449772, 53.83113384246826, 55.62057562172413, 56.90064333379269, 59.3052227050066, 60.375161692500114, 63.27958904206753, 61.77969932556152, 61.943649128079414, 62.33495593070984, 61.43290713429451, 59.876674041152, 55.92455931007862, 49.68552969396114, 58.135178089141846, 61.632825806736946, 62.10832469165325, 61.317336335778236, 59.90579567849636, 60.32218873500824, 59.968587309122086, 60.80298073589802, 62.81532995402813, 60.90856187045574, 57.82799117267132, 56.41637071967125, 51.26397259533405, 48.99080537259579, 43.694527968764305, 43.46832610666752, 44.93785545229912, 44.81052428483963, 43.85032720863819, 42.44197078049183, 43.17757710814476, 42.4570369720459, 43.84013995528221, 44.45039100944996, 46.18824675679207, 54.806305915117264, 59.96346898376942, 59.773741364479065, 59.3676533550024, 58.68741385638714, 58.457245007157326, 54.923024252057076, 50.746915340423584, 47.632518857717514, 48.759994357824326, 50.099205896258354, 47.90561020374298, 42.900594770908356, 45.89427553117275, 49.43608447909355, 52.77748078107834, 57.50843212008476, 58.49663369357586, 53.46510328352451, 59.63600255548954, 58.34825925529003, 58.44338335096836, 50.91435335576534, 57.441453114151955, 9.860494639724493, 0.7851948542520404, 1.7509179026819766, 5.692306878045201, 5.598206352442503, 3.2759804371744394, 0.8147545962128788, 0.2279334410559386, 2.6688034180551767, 36.36221721768379, 59.268440678715706, 26.473827324807644, 51.43410086631775, 24.813363924622536, 0.5117339780554175, 0.083125289529562, 0.026604610102367587, 0.13525976857636124, 0.029092389304423705, 0.047836078447289765, 0.046574583248002455, 0.02727865459746681, 0.02179263588914182, 0.048907520758803, 0.013802537632727763, 0.029667919261555653, 0.025093092772294767, 0.06368910238961689, 0.009633653862692881, 0.05228420362982433, 0.028430742386262864, 0.08562905830331147, 0.009972372845368227, 0.05688368240953423, 0.038505719930981286, 0.023750645959808026, 0.10210277745500207, 0.15047784807393327, 0.14247406739741564, 0.16864969016751274, 0.1878055458655581, 0.13640001910971478, 0.22437641629949212, 0.11987898062216118, 0.09641362179536372, 0.14732988027390093, 0.11652844361378811, 0.09199920124956407, 0.15882347681326792, 0.1214262397843413, 0.13305376429343596, 0.13172045146347955, 0.17381358338752761, 0.18607427860843018, 0.09155660663964227, 0.17976624600123614, 0.17019093793351203, 0.16168705362360924, 0.13401438540313393, 0.14002242707647383, 0.1499313156818971, 0.12225383092300035, 0.3572358418023214, 0.2925667556701228, 12.83491613343358, 82.30033859610558, 41.31246238946915, 67.20105081796646, 62.91927717626095, 37.45416842401028, 1.4153935317881405, 4.862207220867276, 4.856303762644529, 4.312173910439014, 9.041137956082821, 12.329122424125671, 8.986727725714445, 0.8184680063277483, 4.24646926112473, 55.25616377592087, 69.49321702122688, 70.31763598322868, 70.37082552909851, 72.525674700737, 68.26764598488808, 67.06213027238846, 64.8374180495739, 64.95014280080795, 58.110532611608505, 63.17481726408005, 62.58255824446678, 63.193079084157944, 59.29742552340031, 59.162680953741074, 54.744950607419014, 54.76853594183922, 53.63017402589321, 51.976966336369514, 50.97784034907818, 53.946165069937706, 58.816519528627396, 56.70838885009289, 60.85335463285446, 67.2629950940609, 60.71248859167099, 62.56797082722187, 54.44884769618511, 50.542577505111694, 48.50625917315483, 47.03630805015564, 50.24623520672321, 48.688930571079254, 50.55757150053978, 52.56043262779713, 56.00875899195671, 57.22495213150978, 58.1504000723362, 63.60656909644604, 64.80965673923492, 64.23654869198799, 64.85857531428337, 65.07538408041, 65.9462821483612, 63.91124814748764, 62.80983544886112, 58.12230437994003, 50.71868285536766, 55.16254439949989, 63.057566955685616, 62.36014857888222, 63.06925892829895, 61.52205415070057, 60.224788561463356, 61.787599101662636, 63.72105695307255, 63.879086673259735, 62.935661897063255, 60.539050698280334, 58.726213574409485, 53.28986048698425, 51.682778522372246, 47.182132825255394, 45.959879010915756, 47.20410704612732, 47.00639225542545, 46.80687636137009, 44.66263622045517, 44.922519475221634, 44.26664426922798, 45.3437040746212, 47.49631516635418, 48.32395255565643, 58.49661849439144, 62.758678793907166, 61.64506494998932, 60.663657411932945, 62.91874140501022, 62.936399057507515, 58.325760662555695, 53.4833575040102, 51.70354060828686, 51.40375189483166, 53.41644309461117, 48.28179381787777, 45.27474917471409, 47.53332518041134, 50.29774144291878, 54.43996377289295, 59.712994024157524, 60.73284409940243, 56.310565397143364, 62.38860905170441, 61.26986928284168, 62.38516643643379, 53.1561304628849, 60.92825621366501, 9.932096097618341, 0.5599674617405981, 1.9179304596036673, 3.3520943904295564, 9.540820643305779, 7.606094134971499, 3.8511000014841557, 0.37632447376381606, 3.915369752794504, 46.874926909804344, 63.030554205179214, 34.97168943285942, 63.72711002826691, 29.714836813509464, 0.7084881328046322, 0.1723444278468378, 0.1292298038606532, 0.20827516622375697, 0.08612932520918548, 0.13247877795947716, 0.13018649158766493, 0.14440509112318978, 0.16061380418250337, 0.1148841783287935, 0.14572359068552032, 0.15464324096683413, 0.15691197157138959, 0.1639575356966816, 0.17972294910578057, 0.16336868604412302, 0.1631685288157314, 0.16145148110808805, 0.07210743933683261, 0.14133031392702833, 0.10384201537817717, 0.11386547674192116], [0.031221280733007006, 0.03663685478386469, 0.06371515177306719, 0.0485759403090924, 0.027580608511925675, 0.0365758576663211, 0.04766809332068078, 0.09949139726813883, 0.08419001911533996, 0.03326530757476576, 0.013988061564305099, 0.04646192894142587, 0.06813979911385104, 0.04226871664286591, 0.035991405238746665, 0.04683137376559898, 0.011471808011265239, 0.020194216776872054, 0.003177546327606251, 0.1100906464853324, 0.09478333857259713, 0.04590999371430371, 0.007319905971598928, 0.06265486023039557, 0.05453551602840889, 0.059582498724921606, 0.057750073028728366, 0.10741565682110377, 0.2987771958578378, 28.90205092728138, 41.80374562740326, 26.99385032057762, 59.82167199254036, 36.20813548564911, 3.970054043456912, 0.545811855699867, 1.0096448916010559, 1.2374624982476234, 2.8970082476735115, 2.9950052266940475, 5.2240233309566975, 1.1972696799784899, 0.12246851198142394, 10.722808968275785, 65.72583317756653, 66.7116142809391, 67.4450509250164, 66.02818295359612, 68.13880249857903, 63.38326647877693, 60.97050994634628, 55.04522569477558, 60.27094468474388, 54.41474832594395, 56.741443276405334, 54.44859690964222, 56.42868585884571, 49.866202399134636, 50.07168397307396, 49.299193024635315, 47.33701631426811, 47.3430921882391, 54.777298271656036, 54.06668320298195, 55.59296250343323, 53.83312113583088, 55.77357821166515, 57.74166740477085, 58.77759821712971, 58.07508811354637, 61.46354489028454, 52.098073437809944, 43.309878408908844, 44.590687081217766, 44.61705006659031, 45.156298130750656, 43.45063045620918, 45.991854295134544, 50.057085156440735, 50.05171984434128, 53.01228918135166, 51.866217479109764, 58.70528809726238, 57.28368937969208, 56.738829016685486, 58.434632420539856, 61.15646056830883, 60.11970140039921, 58.29736478626728, 56.85553215444088, 57.5282746553421, 58.44775691628456, 53.079606369137764, 58.67964707314968, 57.89942353963852, 58.801084756851196, 59.68120492994785, 59.5340958237648, 59.16730150580406, 57.12200425565243, 55.69702371954918, 51.6886568069458, 51.60923346877098, 47.55193278193474, 45.70260241627693, 42.533884048461914, 40.25252066552639, 42.02906973659992, 42.46434397995472, 42.099552154541016, 41.63542985916138, 41.727020144462585, 40.72872631251812, 43.94283324480057, 42.07311697304249, 44.05642434954643, 50.470426976680756, 56.72014161944389, 58.28473426401615, 57.44228906929493, 57.76653327047825, 56.45642437040806, 56.24660722911358, 51.740858405828476, 49.36232663691044, 46.1903328448534, 46.44292809069157, 46.57967135310173, 43.64962577819824, 40.313913971185684, 46.60659670829773, 48.94257836043835, 53.329427763819695, 53.3856837451458, 58.01867254078388, 54.69504028558731, 57.71099545061588, 50.5081095546484, 56.572838723659515, 27.811418250203133, 0.056041504358290695, 0.11619515993515961, 1.0004677902907133, 9.438155852258205, 3.6850121011957526, 1.4785322500392795, 0.19190224556950852, 0.0627951261412818, 10.221839100122452, 53.68261121213436, 35.68863496184349, 27.873579114675522, 45.767081156373024, 2.0767512498423457, 0.12429823254933581, 0.0802652453421615, 0.044359602688928135, 0.0956705464341212, 0.02294635083671892, 0.06468863430200145, 0.07552408686024137, 0.00685415913721954, 0.03794329815718811, 0.09016247480758466, 0.01195417524286313, 0.03963178431149572, 0.016581859345023986, 0.03192537107679527, 0.03752620003069751, 0.03749664028873667, 0.0377708712767344, 0.0343830265046563, 0.006609138154090033, 0.019985968283435795, 0.06320827975287102, 0.09424041301826946, 0.00939018767894595, 0.02905002751504071, 0.022460407381004188, 0.010636269398673903, 0.030270396600826643, 0.037292928172973916, 0.03744077141163871, 0.06818271751399152, 0.06704611834720708, 0.02627205558383139, 0.06586969553609379, 0.12223340701893903, 0.11584094769204967, 0.05540643003769219, 0.015648074295313563, 0.03980264154961333, 0.025836648674157914, 0.012639791675610468, 0.0058919767343468266, 0.049441893061157316, 0.058228680354659446, 0.05298716219840571, 0.05154597449291032, 0.059154702539672144, 0.05907547827519011, 0.046273345506051555, 0.07442929287208244, 0.1319963374407962, 0.7334977376740426, 39.4781070202589, 41.55612051486969, 35.40623031556606, 68.04442316293716, 40.98380282521248, 5.345368394628167, 0.4161097639007494, 2.1298733493313193, 1.4123067911714315, 3.201601328328252, 3.8787214318290353, 5.317454617470503, 4.302548551931977, 0.12263084194273688, 13.042562641203403, 66.63317129015923, 67.18930184841156, 67.86889538168907, 67.98947051167488, 69.63903039693832, 67.04737186431885, 63.937261551618576, 58.775006756186485, 62.79084786772728, 56.013812720775604, 58.374861627817154, 57.48832359910011, 57.838733196258545, 51.53016731142998, 53.588030487298965, 50.96041448414326, 48.80863934755325, 49.27595727145672, 56.10947638750076, 54.72766153514385, 57.54848197102547, 56.978831738233566, 57.97448471188545, 59.022597670555115, 61.397994607687, 60.1055433601141, 62.57506504654884, 54.02006730437279, 45.79238019883633, 45.3931850194931, 46.86805687844753, 46.961999237537384, 45.7905562967062, 47.45255671441555, 50.49835167825222, 52.70586222410202, 55.833820179104805, 55.2660508453846, 59.414337649941444, 60.0438878685236, 59.99759495258331, 59.94489938020706, 60.67790284752846, 62.68167972564697, 60.76631650328636, 59.84258987009525, 58.845306783914566, 56.2704661488533, 55.50810545682907, 59.494266360998154, 59.69717927277088, 59.8043867200613, 59.48389291763306, 60.54804861545563, 60.54635010659695, 59.8385164886713, 59.61299479007721, 53.93753193318844, 54.63488191366196, 49.34316046535969, 46.587650924921036, 45.73675498366356, 43.55782650411129, 44.29930731654167, 44.668738692998886, 43.84430453181267, 44.68022167682648, 44.59808148443699, 42.83705838024616, 45.87994270026684, 45.784575417637825, 46.47633969783783, 52.95704394578934, 58.65049883723259, 60.707347467541695, 58.76391515135765, 59.88587714731693, 58.599722161889076, 58.143264055252075, 52.540476098656654, 50.72705380618572, 47.735858112573624, 50.228186175227165, 48.38311918079853, 45.03134183585644, 43.80229778587818, 48.54007735848427, 50.40298439562321, 55.61897970736027, 56.079507395625114, 59.34216812252998, 57.24294796586037, 60.98991170525551, 53.53836715221405, 57.16508634388447, 29.936893098056316, 0.13876230485038832, 0.9115214506164193, 4.4655583798885345, 10.090494398027658, 3.0561973806470633, 0.9855228359811008, 0.6309251510538161, 0.07986818891367875, 11.677038464695215, 62.04969383776188, 45.00907123088837, 28.92091691493988, 52.77974545955658, 3.5154241137206554, 0.18556090537458658, 0.13170307036489248, 0.046069982199696824, 0.023344717155850958, 0.029411618561425712, 0.05374972264689859, 0.04327980750531424, 0.016771862137829885, 0.031385818583657965, 0.08235607572714798, 0.042835761996684596, 0.015091586919879774, 0.011634508118731901, 0.05915786408877466, 0.0631200235511642, 0.06366097499267198, 0.02752865260845283, 0.07450349279679358, 0.04890289346803911, 0.04001688845164608, 0.014188293007464381, 0.08112005845759995, 0.08782213437370956, 0.13088773208437487, 0.21766566467704251, 0.17527988908113912, 0.14370971359312534, 0.09622193247196265, 0.18772674462525174, 0.24506562331225723, 0.16700037085684016, 0.0730824210040737, 0.12611055717570707, 0.22176603059051558, 0.25389667600393295, 0.1309069388662465, 0.10090832045534626, 0.1312935829628259, 0.10565183154540136, 0.15698162955231965, 0.11658234579954296, 0.13684118137462065, 0.21452692919410765, 0.15680035256082192, 0.07828320638509467, 0.1276095470529981, 0.18465772649506107, 0.13555186305893585, 0.17151666601421311, 0.14024231059011072, 0.7267314882483333, 47.124945893883705, 56.07471205294132, 43.59004497528076, 68.26633125543594, 50.93419589102268, 8.06614637374878, 1.1464407574385405, 3.9663238311186433, 5.712872324511409, 7.192281140014529, 11.531756110489368, 12.432959452271461, 4.395247902721167, 0.3086717758560553, 14.322310220450163, 69.69658210873604, 68.50539162755013, 70.03081977367401, 70.60614690184593, 74.80201855301857, 69.19444665312767, 68.04827615618706, 58.680559024214745, 67.11972758173943, 58.72783608734608, 62.703110575675964, 61.05455003678799, 61.63277640938759, 55.33004701137543, 55.404614210128784, 54.433329328894615, 51.32128871977329, 51.434895023703575, 60.03002241253853, 59.057172015309334, 61.78517863154411, 61.34364612400532, 60.41378282010555, 61.62960737943649, 64.42542135715485, 62.529934868216515, 66.55811011791229, 57.87290096282959, 50.164702981710434, 49.59675885736942, 50.83700470626354, 49.14263002574444, 47.413920387625694, 49.913794845342636, 53.07002708315849, 55.1335633546114, 58.62510859966278, 56.24592326581478, 62.74402678012848, 61.179840713739395, 59.70093347132206, 61.27918258309364, 64.60952147841454, 64.47444632649422, 64.46159541606903, 60.562829822301865, 59.320877864956856, 59.07683216035366, 54.31119628250599, 61.73384718596935, 60.74759490787983, 60.48985093832016, 60.658854469656944, 64.5675565302372, 63.978078961372375, 60.614092871546745, 61.041626930236816, 56.46945387125015, 58.672146275639534, 52.41330452263355, 50.09564928710461, 47.65083007514477, 45.884244069457054, 46.644332483410835, 47.27161802351475, 45.691225826740265, 47.66317181289196, 46.762506142258644, 45.38480266928673, 50.93459106981754, 49.42784272134304, 50.065573900938034, 54.740706235170364, 62.98589140176773, 64.15258079767227, 60.6420935690403, 61.812844946980476, 60.68374693393707, 60.705033391714096, 54.80186775326729, 52.4849458783865, 51.028499230742455, 51.98577046394348, 53.59362378716469, 47.83022604882717, 45.31750828027725, 51.09768971800804, 52.922948375344276, 58.81336189806461, 56.453110948204994, 62.39284202456474, 58.76227363944054, 64.51766520738602, 54.7272739559412, 59.2245302349329, 30.80365128815174, 0.26171119417995214, 0.8825910498853773, 1.9023421523161232, 16.55204102396965, 12.788559570908546, 4.597008526325226, 1.719551298301667, 0.3876940277405083, 17.007659375667572, 67.77695551514626, 48.79625961184502, 37.78619080781937, 63.40460233390331, 4.502430651336908, 0.3046704124426469, 0.24333635985385627, 0.18759510247036815, 0.12831532949348912, 0.15433677850523964, 0.1711987893213518, 0.19570383767131716, 0.10286557910148986, 0.13869313668692484, 0.1693713990971446, 0.18773251853417605, 0.2459727058885619, 0.1997778276563622, 0.14077454921789467, 0.23334061028435826, 0.13401474163401872, 0.16945267911069095, 0.22204605775186792, 0.13136104418663308, 0.1221741242625285, 0.1600317971315235, 0.27500032796524465], [0.030715603570570238, 0.004953178477080655, 0.04413204165757634, 0.08855578445945866, 0.016595913766650483, 0.051104407757520676, 0.08865324329235591, 0.03117245483736042, 0.058168340037809685, 0.03459085382928606, 0.12035705731250346, 0.025099410304392222, 0.050928459386341274, 0.015669271888327785, 0.055027081252774224, 0.07027510640909895, 0.05922258678765502, 0.04847154239541851, 0.06771192871383391, 0.03533271577907726, 0.0668646558187902, 0.03055618653888814, 0.024383729469263926, 0.03825039144430775, 0.08110186841804534, 0.010838693888217676, 0.04531102116743568, 0.08118324491078965, 0.2234244634746574, 8.117038942873478, 56.1522126942873, 31.59087974578142, 43.421056643128395, 59.218473359942436, 16.759014017879963, 0.061266839984455146, 0.8988299535121769, 0.2137806106475182, 2.2356874588876963, 4.647333975881338, 4.178612502291799, 2.384600043296814, 0.23951711948029697, 0.04115191797609441, 25.018233731389046, 73.84004697203636, 60.423293709754944, 68.49827840924263, 66.55068531632423, 65.51080271601677, 60.76417341828346, 58.8997882604599, 53.15428376197815, 58.47328394651413, 57.97312818467617, 55.281193032860756, 53.03368203341961, 52.86821611225605, 48.95854510366917, 49.07646417617798, 49.94873397052288, 53.89769107103348, 56.79503180086613, 57.04065062105656, 55.60894064605236, 56.17548264563084, 61.78898982703686, 60.57779721915722, 62.3410964012146, 61.97009950876236, 61.454691365361214, 59.265849217772484, 47.23973013460636, 44.09506447613239, 45.86553767323494, 46.77120767533779, 46.891159638762474, 44.38493952155113, 47.17611014842987, 49.19691011309624, 47.50654801726341, 48.19447070360184, 52.06729128956795, 49.261746034026146, 54.0256530046463, 53.36951561272144, 56.17801330983639, 54.23565253615379, 64.56377193331718, 53.25377382338047, 36.03120177984238, 69.60255235433578, 59.7934927046299, 62.346169129014015, 59.018885269761086, 62.069019600749016, 61.247534081339836, 62.21535734832287, 58.66841487586498, 56.476377099752426, 52.916549518704414, 50.78229904174805, 49.42617081105709, 48.58223229646683, 42.9616042971611, 41.50120586156845, 41.80178873240948, 42.47688710689545, 41.288322284817696, 41.16696439683437, 41.89646825194359, 43.65552306175232, 42.44121842086315, 45.042007863521576, 45.117589607834816, 44.52932417392731, 46.72122895717621, 55.443793907761574, 57.287375181913376, 56.49845011532307, 57.39318810403347, 56.71815052628517, 57.9208467900753, 55.29190085828304, 50.30155263841152, 48.68400603532791, 45.9095773100853, 46.84566468000412, 42.27462776005268, 44.19382877647877, 45.22456146776676, 46.00226953625679, 53.650464937090874, 54.92617808282375, 55.111737325787544, 57.551996782422066, 56.416169330477715, 55.35933963954449, 52.75950014591217, 3.8182191783562303, 0.43740661174524575, 0.8594249398447573, 6.5093551855534315, 13.345380742102861, 1.8478833558037877, 0.656860718736425, 0.37437452527228743, 0.4048856411827728, 26.4587839320302, 46.95030726492405, 23.219244964420795, 46.27558887004852, 25.475138314068317, 0.24869255837984383, 0.09092707245144993, 0.032236987754004076, 0.09972732601454481, 0.03805804160947446, 0.037685464922105893, 0.05072314423159696, 0.07417515924316831, 0.022138298591016792, 0.02946794014860643, 0.044481485601863824, 0.023169099040387664, 0.00875814410392195, 0.03534647519700229, 0.18490560381906107, 0.04894811623671558, 0.031385165493702516, 0.0465610947139794, 0.048158478530240245, 0.03328539009089582, 0.04002446949016303, 0.0403391029976774, 0.08365283778402954, 0.07624492747709155, 0.05193119737668894, 0.049102612829301506, 0.12305588476010598, 0.06774744048016146, 0.021901909713051282, 0.016907630633795634, 0.021417765965452418, 0.08955861150752753, 0.0447754688502755, 0.07274766787304543, 0.03372037026565522, 0.04674869109294377, 0.03289842316007707, 0.039332272062893026, 0.013525069953175262, 0.05561988284171093, 0.04311439392040484, 0.04886010865448043, 0.051528493204386905, 0.04559390559734311, 0.04170409811194986, 0.01187758096421021, 0.03746078713447787, 0.08384137297980487, 0.15402662014821544, 0.0558367606572574, 0.06615162259549834, 0.3911423427052796, 12.649126052856445, 67.75490149855614, 32.32817508280277, 53.22149075567722, 64.81635197997093, 19.20235700905323, 0.11688494167174213, 0.7709254324436188, 0.9837907226756215, 0.7499094132799655, 3.440772844478488, 7.121682353317738, 5.8703600987792015, 1.5467091416940093, 0.20121746056247503, 31.673777997493744, 71.86286866664886, 65.6705841422081, 69.74058374762535, 68.18984895944595, 65.85501864552498, 64.37253579497337, 61.69120967388153, 57.14471943676472, 59.62356202304363, 59.79502022266388, 58.062013015151024, 55.773338824510574, 53.94600547850132, 51.56813107430935, 50.98887875676155, 53.273004591464996, 56.06718845665455, 58.177891597151756, 58.44654478132725, 56.51600897312164, 59.6622059494257, 62.51565143465996, 62.70578183233738, 64.61655110120773, 64.03410315513611, 64.91078451275826, 61.25740595161915, 47.685754001140594, 45.864804312586784, 47.70859457552433, 48.44643518328667, 49.58994962275028, 46.11944764852524, 49.81726862490177, 52.1796740591526, 50.1713640242815, 51.1976433545351, 55.949413776397705, 53.673404306173325, 57.03392878174782, 58.479230627417564, 60.17722271382809, 56.289985701441765, 66.55917406082153, 52.121183797717094, 36.3845220208168, 69.2491789162159, 59.01538945734501, 61.593558713793755, 60.511464178562164, 61.7657046765089, 64.02472525835037, 61.66955843567848, 61.47005394101143, 58.659428358078, 56.17830589413643, 55.34372627735138, 51.423465237021446, 50.37927366793156, 45.97326949238777, 44.05534140765667, 43.43841031193733, 45.725492388010025, 43.8924365490675, 43.37288662791252, 42.70333595573902, 44.87860903143883, 44.864071011543274, 47.48654589056969, 47.133658826351166, 48.28699953854084, 50.42503461241722, 56.62180669605732, 57.4953456223011, 59.04703035950661, 59.327865689992905, 58.30006264150143, 59.11227285861969, 54.882214441895485, 52.32735313475132, 50.32671868801117, 48.701545894145966, 48.474766463041306, 46.69716864824295, 45.58987386524677, 46.914725974202156, 47.28105291724205, 54.55863520503044, 55.80554209649563, 56.52684599161148, 57.65568181872368, 59.94228512048721, 56.48951679468155, 55.814483016729355, 4.473751690238714, 0.7056001096498221, 1.6530200745910406, 11.0916618257761, 7.981292176991701, 0.7273390400223434, 1.1972536495886743, 0.21725064085330814, 0.6303775054402649, 30.11639926582575, 59.467462599277496, 26.646018885076046, 47.03462854027748, 32.13018670678139, 0.4185810562921688, 0.05197613070777152, 0.041107500437647104, 0.06554323219461367, 0.08311541154398583, 0.033026896344381385, 0.008320052475028206, 0.0307870093092788, 0.03326732992718462, 0.029587307180918287, 0.06930336050572805, 0.04074059004778974, 0.030594681738875806, 0.048304436713806354, 0.1274738973006606, 0.05400616806582548, 0.02462814281898318, 0.053497158660320565, 0.0038724952673874213, 0.06622793021961115, 0.028789971547666937, 0.07612727480591275, 0.01674946597631788, 0.20316325302701443, 0.1727752891019918, 0.22213458112673834, 0.31608443590812385, 0.13991304935188964, 0.19525013311067596, 0.1692786900093779, 0.16843752498971298, 0.18092938436893746, 0.23069716931786388, 0.2365388660109602, 0.23207412043120712, 0.1354436282417737, 0.07030245455098338, 0.13947371277026832, 0.1404932010336779, 0.14032676699571311, 0.14426869922317564, 0.13658194919116795, 0.11190769117092714, 0.13734278414631262, 0.2136711438652128, 0.1229411487292964, 0.13189117511501536, 0.170296604919713, 0.2508683275664225, 0.15349521272582933, 0.2580229577142745, 0.4754722269717604, 12.665139343589544, 81.28860488533974, 45.64940147101879, 54.47052173316479, 69.41944777965546, 29.51834935694933, 0.1664391439408064, 4.317483175545931, 3.5862537380307913, 6.516538700088859, 13.265129048377275, 17.30653803795576, 4.256155891343951, 1.1811551009304821, 0.3203680529259145, 29.428934454917908, 77.17018067836761, 63.34425017237663, 72.61810854077339, 70.70793583989143, 69.80688259005547, 68.27741146087646, 67.48684108257294, 58.80868814885616, 64.18066889047623, 63.565208315849304, 61.411335691809654, 58.94960358738899, 57.37051472067833, 54.49035286903381, 53.488643020391464, 54.95590768754482, 59.66848701238632, 61.83662787079811, 62.37858518958092, 58.37719850242138, 61.04766480624676, 65.88415548205376, 66.61147445440292, 69.68324482440948, 68.72373551130295, 66.6989229619503, 62.74379499256611, 50.123425796628, 48.80076237022877, 50.117832496762276, 51.32272884249687, 52.95530743896961, 49.58684138953686, 52.715213522315025, 54.13242347538471, 51.681114211678505, 54.3983294069767, 57.692988216876984, 55.77540971338749, 59.54886183142662, 59.947449043393135, 61.65174499154091, 59.7674261033535, 68.71248051524162, 55.95861688256264, 34.97407950460911, 70.43652400374413, 63.31602528691292, 63.568115159869194, 62.73027531802654, 63.43967825174332, 65.10144308209419, 64.69725117087364, 64.5341183245182, 62.1309182792902, 58.22146765887737, 56.38071343302727, 54.796916618943214, 53.15272204577923, 47.823059633374214, 46.45563840866089, 46.797794848680496, 47.150096744298935, 46.75266467034817, 46.73767447471619, 44.58285190165043, 46.57728508114815, 47.42278531193733, 48.5572524368763, 49.47949334979057, 50.281223729252815, 52.040586322546005, 59.753477051854134, 59.85071763396263, 60.92755705118179, 61.09839208424091, 60.650669708848, 62.88221776485443, 59.470909014344215, 54.662441834807396, 54.73343722522259, 49.92642916738987, 49.3219044059515, 50.60091197490692, 48.86117532849312, 49.9881986528635, 50.34085392951965, 57.12972164154053, 57.518759965896606, 60.011771991848946, 59.92843106389046, 64.63308781385422, 58.69617618620396, 56.717485561966896, 5.279400609433651, 1.0872993059456348, 0.980317055946216, 11.762903407216072, 32.20499329268932, 7.819969933480024, 2.5625131465494633, 0.7921922381501645, 1.065110752824694, 38.79108488559723, 62.037754878401756, 33.03252428770065, 57.796525061130524, 38.79562184214592, 0.37981102417688817, 0.18358836590778083, 0.11644030615570955, 0.17152272193925455, 0.12138156249420717, 0.14106118149356917, 0.13554130971897393, 0.209364713227842, 0.08749357075430453, 0.1511219283565879, 0.19904373970348388, 0.2873836853541434, 0.12686837901128456, 0.1874576715636067, 0.30015708587598056, 0.11864905638503842, 0.1292030420154333, 0.14076358027523383, 0.09698618872789666, 0.13244128465885296, 0.15233384066959843, 0.1833837854792364, 0.16473575175041333], [0.00955482015342568, 0.031083291360118892, 0.03811114227573853, 0.04447988627362065, 0.02270610650157323, 0.009743436985445442, 0.08468336920486763, 0.018551135217421688, 0.01223884917635587, 0.0220004149741726, 0.03792610630625859, 0.09715378051623702, 0.05447258932690602, 0.06746340572135523, 0.05183564957405906, 0.05004245751479175, 0.05172102857613936, 0.01699194974207785, 0.03610178486269433, 0.03961928654462099, 0.009972306052077329, 0.04147762061620597, 0.031637963256798685, 0.05547554996155668, 0.08461078716209158, 0.023111718037398532, 0.07078155540511943, 0.04490478808293119, 0.2270648759440519, 0.19720803742529824, 23.793643042445183, 53.61612617969513, 25.96260655671358, 61.27120681107044, 43.428610637784004, 3.834777264855802, 0.8070584654342383, 0.21932740753982216, 0.12878749868832529, 2.17038843780756, 0.8698540145996958, 6.744055291637778, 0.8397039980627596, 0.26356044807471335, 2.234301958233118, 41.69635958969593, 69.9935057759285, 68.77209171652794, 71.59970998764038, 65.71932792663574, 61.52923196554184, 59.082847237586975, 60.78250743448734, 56.99311897158623, 55.70057652890682, 55.27245730161667, 54.002880826592445, 48.773662224411964, 50.1000190526247, 50.4118949174881, 55.87774962186813, 59.60195638239384, 58.59963856637478, 58.27730946242809, 60.84087610244751, 60.57480677962303, 60.10043263435364, 61.70989327132702, 62.207035794854164, 65.89685440063477, 64.1080167889595, 62.645133286714554, 56.64581000804901, 45.06109043955803, 45.78210175037384, 44.22846011817455, 45.236131846904755, 46.474363803863525, 47.054140493273735, 45.325647443532944, 45.9752681851387, 46.448973566293716, 45.22663235664368, 45.586283057928085, 47.46840186417103, 49.46700341999531, 55.428583323955536, 58.59576657414436, 61.78505323827267, 57.75707557797432, 50.909835398197174, 60.007474422454834, 62.10875406861305, 60.273418352007866, 59.5956639200449, 58.76082971692085, 57.15623661875725, 57.269949316978455, 55.65575413405895, 54.035790860652924, 52.743442207574844, 51.84203937649727, 49.771412685513496, 46.10282354056835, 44.331689178943634, 43.17505404353142, 42.02238589525223, 43.127510994672775, 40.79270727932453, 41.75574280321598, 41.533374935388565, 44.59321014583111, 46.77526205778122, 47.55960837006569, 47.52744309604168, 44.97827388346195, 45.48389755189419, 51.05757147073746, 57.19055637717247, 60.80979377031326, 57.54204511642456, 55.69496423006058, 57.0576661080122, 58.02197456359863, 53.70369628071785, 50.636166483163834, 47.00595147907734, 47.11116783320904, 47.53983423113823, 46.97232328355312, 47.9096569865942, 52.406677678227425, 50.32604992389679, 56.83594800531864, 58.18229556083679, 60.070649832487106, 50.76132416725159, 61.567575708031654, 19.50155295431614, 0.19391380716115236, 0.27381479158066213, 1.2528376607224345, 14.763927273452282, 3.8850599667057395, 0.2582218829775229, 0.30905956286005676, 0.3501205157954246, 4.170682802796364, 47.45800942182541, 36.68349377810955, 29.469356685876846, 49.61660519242287, 5.286842985078692, 0.09521055588265881, 0.09053925576154143, 0.019841186403937172, 0.05470955336932093, 0.016795694355096202, 0.06414084025891498, 0.05189541101572104, 0.025867809599731117, 0.029963121487526223, 0.027760993070842233, 0.011416607994760852, 0.05525545864657033, 0.022378338835551403, 0.017422950149921235, 0.03287514569819905, 0.029276286077219993, 0.02918718568253098, 0.04241938004270196, 0.050930010474985465, 0.06293490223470144, 0.01661732287175255, 0.04450843669474125, 0.029983445201651193, 0.09552483315928839, 0.012161277118138969, 0.01970778906979831, 0.023022246568871196, 0.03249892877647653, 0.013004679713048972, 0.08579831250244752, 0.03247074200771749, 0.13553700526244938, 0.02878032548323972, 0.015435054720001062, 0.05757240658567753, 0.10573030624072999, 0.022281611018115655, 0.021646167479048017, 0.052317151275929064, 0.030832848060526885, 0.03449161384196486, 0.04168151084741112, 0.008980133461591322, 0.07117139815818518, 0.0086292367632268, 0.0108116212686582, 0.024876038696675096, 0.07316482166061178, 0.05545535241253674, 0.12833734159357846, 0.0974989534006454, 0.11098972870968282, 0.4802823532372713, 33.76455120742321, 53.50566990673542, 30.282632745802402, 73.39199781417847, 47.44629085063934, 4.3669042736291885, 0.21615015459246933, 0.8348577143624425, 1.2650205194950104, 0.687647913582623, 3.9887001179158688, 5.563688529655337, 4.1125577967613935, 0.9581016667652875, 2.6558325765654445, 51.16238884627819, 68.29340100288391, 71.9160658121109, 72.91838362812996, 70.01662373542786, 61.26173011958599, 62.6828158646822, 62.1469534188509, 58.4814079105854, 60.17378009855747, 58.51157069206238, 56.63548216223717, 52.37344466149807, 49.90567468106747, 52.01531007885933, 54.81326714158058, 61.999190747737885, 60.55398389697075, 62.07778953015804, 61.52050003409386, 60.96857585012913, 61.19225084781647, 64.01487618684769, 65.06368070840836, 68.33722785115242, 67.69506990909576, 64.73913252353668, 58.2724267244339, 46.92061185836792, 47.55520440638065, 46.20599180459976, 45.97481980919838, 46.87860511243343, 47.37400732934475, 48.33278328180313, 48.216688111424446, 49.86359193921089, 48.930741995573044, 49.031759575009346, 50.46808250248432, 51.76969885826111, 57.22892291843891, 61.36085920035839, 63.8563334941864, 60.93838647007942, 47.18467868864536, 61.438622027635574, 64.86543014645576, 64.69412013888359, 61.15989178419113, 60.878672674298286, 61.302653923630714, 61.08267232775688, 56.07440426945686, 55.6936988979578, 53.94185610115528, 54.338984191417694, 50.380394607782364, 49.79726269841194, 45.11711843311787, 43.721316531300545, 42.70199082791805, 45.558464750647545, 43.927162885665894, 43.951173797249794, 43.67905519902706, 48.31308513879776, 49.815410524606705, 51.520990803837776, 49.93014536798, 47.72270701825619, 47.2628290951252, 53.78214307129383, 60.281770303845406, 61.563631519675255, 59.93494771420956, 57.88865491747856, 58.759647980332375, 58.52097138762474, 55.539647564291954, 52.05345243215561, 49.57127742469311, 50.771750807762146, 49.56619709730148, 50.03524012863636, 50.3350630402565, 54.32433597743511, 51.920155584812164, 58.195469453930855, 59.86600421369076, 62.61466272175312, 52.08379380404949, 62.945712357759476, 23.614636547863483, 0.15670780674554408, 0.9234903333708644, 4.622226823121309, 10.294001027941704, 2.5963750295341015, 0.5025547393597662, 0.2548731642309576, 0.2578265854390338, 5.530255073681474, 57.29943573474884, 46.095812916755676, 27.959006130695343, 57.608651742339134, 8.173990286886692, 0.22719798755133525, 0.1355538668576628, 0.028283880637900438, 0.06046504218829796, 0.04126340340008028, 0.06956226614420302, 0.07140090732718818, 0.007569089011667529, 0.012785376929969061, 0.02028422630246496, 0.032646408362779766, 0.014885958207742078, 0.057396447082282975, 0.041472692755633034, 0.05103698364109732, 0.043636183108901605, 0.02278344014484901, 0.03346759105625097, 0.04122109727177303, 0.022831969181424938, 0.032000676801544614, 0.08943024222389795, 0.049459129440947436, 0.14089676609728485, 0.2293654001550749, 0.1257301025907509, 0.11689990336890332, 0.12410322582582012, 0.11205594259081408, 0.15624357853084803, 0.09947602738975547, 0.1261277007870376, 0.07239868034957908, 0.08078736849711277, 0.177500587888062, 0.2195747208315879, 0.14551944070262834, 0.16096096602268517, 0.16064665163867176, 0.12802795507013798, 0.1660125722992234, 0.1399210942327045, 0.17301636835327372, 0.1843098521931097, 0.1116762449964881, 0.07785652342136018, 0.08700402046088129, 0.1275165707920678, 0.10885667754337192, 0.3132529940921813, 0.19881834945408627, 0.32389485742896795, 0.47257366531994194, 38.46775643527508, 72.46568351984024, 37.65443667769432, 71.56811088323593, 57.17155359685421, 8.186617009341717, 1.678603389300406, 3.1283410219475627, 2.360667265020311, 9.358472228050232, 7.28761232458055, 20.14296803623438, 3.107240041717887, 0.44987985806073993, 3.1090580066666007, 49.70563441514969, 72.37973973155022, 73.21919068694115, 77.22336262464523, 72.4058823287487, 63.16529877483845, 64.6581968665123, 66.77848309278488, 62.75978833436966, 62.86300979554653, 60.10536476969719, 59.505639150738716, 53.384969383478165, 54.70238909125328, 54.29480016231537, 59.14091192185879, 64.31503728032112, 62.11806356906891, 65.1414929330349, 65.81823661923409, 65.50615176558495, 64.37448889017105, 67.02739253640175, 64.3998335301876, 70.72494372725487, 70.85189491510391, 68.69715213775635, 62.96218067407608, 50.997337102890015, 50.63617408275604, 48.81291411817074, 47.09281101822853, 48.99392120540142, 50.020512118935585, 50.47139972448349, 51.42512574791908, 52.00933679938316, 49.85001526772976, 50.48271931707859, 52.735158652067184, 53.35895977914333, 61.87910199165344, 64.89626169204712, 66.03456661105156, 63.84915187954903, 55.56037925183773, 64.67475637793541, 68.42763260006905, 65.0349086523056, 64.72527086734772, 64.27361190319061, 63.33138786256313, 61.94285497069359, 58.757368102669716, 58.24508339166641, 55.619105100631714, 56.455402225255966, 54.724431708455086, 51.06170944869518, 47.54597470164299, 48.03762272000313, 45.3986719250679, 47.91424334049225, 45.10221183300018, 46.61928802728653, 46.185936480760574, 50.841853246092796, 53.09551611542702, 55.066006779670715, 55.026390105485916, 49.460216984152794, 49.888188019394875, 56.154359579086304, 62.161620631814, 65.54532766342163, 60.519713535904884, 58.35135988891125, 60.28155751526356, 62.244011610746384, 58.39837856590748, 54.09864328801632, 52.37495318055153, 54.04445439577103, 50.971046313643456, 52.216095104813576, 52.01777994632721, 56.3075939565897, 54.34692196547985, 60.71495845913887, 62.46191091835499, 64.10514414310455, 55.11354982852936, 63.823913633823395, 22.862354815006256, 0.2638655004557222, 1.5529314265586436, 5.0031753815710545, 30.070528127253056, 12.126020472496748, 1.6594505170360208, 1.5176333393901587, 1.3602833077311516, 7.965742461383343, 61.2107140570879, 50.39313532412052, 37.850221171975136, 68.66283237934113, 10.410577822476625, 0.35969540826044977, 0.39329736144281924, 0.08857830121996813, 0.21479913411894813, 0.1345600569038652, 0.2260327711701393, 0.11063324549468234, 0.14916169369826093, 0.1220449386164546, 0.06202381577168126, 0.10098161495989189, 0.1950913728796877, 0.14174138952512294, 0.14161816332489252, 0.16179102851310745, 0.18364307703450322, 0.08312740465044044, 0.09003126309835352, 0.13467448123265058, 0.1166121504502371, 0.09531787785817869, 0.15533262194367126, 0.08661909072543494], [0.07134968429454602, 0.015962511133693624, 0.033312504456262104, 0.036789358709938824, 0.030827005502942484, 0.0640718056820333, 0.04193139568087645, 0.10182010824792087, 0.03334548920975067, 0.05940432019997388, 0.02074868458294077, 0.03285458078607917, 0.03925288452592213, 0.037498135716305114, 0.08319651344208978, 0.02796124121232424, 0.03862354329612572, 0.02592429631476989, 0.024583061058365274, 0.05019873526180163, 0.026332566594646778, 0.047108376675168984, 0.019514669256750494, 0.012634701470233267, 0.05689251025614794, 0.052106618823017925, 0.05411864796769805, 0.054847626233822666, 0.12652142497245222, 0.09477734201936983, 3.723968085832894, 48.35386075079441, 34.49438564479351, 35.83537928760052, 64.70266968011856, 20.49318764358759, 0.4060942732030526, 0.3556968056363985, 0.2063043782254681, 0.32192401005886495, 4.133395403623581, 4.396838592365384, 8.074813708662987, 3.205401599407196, 0.1186273040366359, 3.7532813753932714, 52.91176937520504, 72.01097711920738, 71.36831000447273, 69.30969446897507, 68.7039689719677, 63.13103601336479, 58.41959662735462, 61.92268185317516, 55.53410746157169, 53.438770696520805, 51.66024573147297, 49.62821736931801, 49.57919619977474, 51.73225946724415, 60.58097384870052, 65.03128364682198, 61.89414918422699, 58.82953003048897, 59.001812785863876, 62.41781048476696, 64.77035164833069, 67.69566267728806, 65.98317056894302, 63.793256878852844, 62.8343441337347, 64.74238514900208, 57.18823090195656, 45.53737588226795, 45.1580536365509, 46.00916616618633, 47.01514698565006, 47.38172471523285, 47.872152999043465, 45.530133470892906, 48.00684817135334, 47.09628403186798, 46.648937836289406, 45.12058764696121, 48.728573843836784, 53.50632347166538, 59.94551494717598, 59.8404885828495, 66.36916145682335, 50.45220695436001, 58.65066982805729, 66.44799962639809, 59.56922113895416, 60.74421688914299, 58.39835196733475, 59.25821162760258, 56.61421850323677, 58.24632592499256, 54.56444889307022, 54.73400339484215, 54.87504802644253, 50.16362763941288, 50.073112696409225, 45.6020750105381, 41.68346308171749, 41.824956089258194, 44.72824729979038, 43.008976355195045, 42.989946976304054, 45.521754920482635, 42.81820759177208, 45.33843755722046, 48.86385038495064, 49.90763917565346, 50.527435317635536, 49.30140070617199, 48.030064925551414, 47.904284074902534, 54.367661252617836, 57.338345646858215, 58.35829831659794, 60.221459940075874, 58.625822961330414, 57.51384682953358, 55.40012665092945, 52.87006661295891, 47.24042169749737, 45.81365905702114, 48.72297294437885, 52.44938738644123, 53.744707480072975, 54.576870426535606, 57.11098864674568, 57.414801344275475, 59.83608461916447, 58.61918091773987, 59.2269317060709, 49.0541859716177, 3.477232838049531, 0.194894110027235, 0.4980966879520565, 4.40060181543231, 10.342066548764706, 1.5004485240206122, 0.17178033624077216, 0.1150241399591323, 0.021948540706944186, 22.260592505335808, 44.95757259428501, 19.87635724246502, 46.26897722482681, 24.13617756217718, 0.12404227323713712, 0.03084271305851871, 0.01639790876652114, 0.02999760166858323, 0.05958768633718137, 0.038103193874121644, 0.06085516324674245, 0.028277418387006037, 0.013900669964641565, 0.1030398576403968, 0.035283808247186244, 0.05198966005991679, 0.008921234766603447, 0.09602131511201151, 0.04869333322858438, 0.03102153910731431, 0.008224105768022127, 0.04465930789592676, 0.08756071285461076, 0.009225104349752655, 0.10824795317603275, 0.042991234513465315, 0.005080135360913118, 0.03532368384185247, 0.06336548147373833, 0.11444737989222631, 0.14771094341995195, 0.011206330655113561, 0.09857852593995631, 0.08392181436647661, 0.10975374112604186, 0.07888573381933384, 0.060734972430509515, 0.0615586153435288, 0.01410631444741739, 0.008644979570817668, 0.015622533283021767, 0.018085801202687435, 0.08993967465357855, 0.03386426527868025, 0.0327999958244618, 0.01419825912307715, 0.035607414320111275, 0.023468089930247515, 0.03331041902129073, 0.023342243948718533, 0.04604233348800335, 0.03500593331409618, 0.04882332410488743, 0.04588710959069431, 0.00843359272039379, 0.03936899724067189, 0.11088253289926797, 0.3452454070793465, 6.5913343615829945, 62.23020315170288, 32.44313411414623, 44.364652410149574, 76.05584487318993, 19.436103366315365, 0.33726046211086214, 0.28960288502275944, 0.4025455901864916, 0.43263849103823304, 2.26686573587358, 4.653702434152365, 7.057324731722474, 3.9737210841849446, 0.2090186349232681, 5.389666892588139, 59.87420417368412, 69.09625992178917, 73.8700957596302, 71.16870671510696, 70.3010156750679, 65.2298229932785, 61.580130234360695, 63.93177464604378, 58.72901402413845, 58.49890597164631, 56.01512365043163, 52.93147511780262, 51.57989904284477, 52.909766882658005, 62.058566361665726, 65.84469079971313, 63.90923425555229, 61.105562299489975, 61.079845279455185, 65.14682024717331, 67.35007122159004, 70.00126495957375, 68.52746084332466, 65.41117206215858, 64.0515062212944, 66.86565801501274, 59.66368027031422, 46.752687469124794, 47.07700006663799, 47.69979044795036, 49.63333949446678, 48.774220794439316, 50.99077865481377, 49.341340363025665, 48.77604469656944, 49.49920289218426, 49.86526384949684, 48.32283541560173, 51.534392684698105, 54.9130991846323, 61.577523574233055, 60.189450457692146, 65.02120658755302, 54.4529514759779, 62.16760911047459, 67.22824215888977, 60.6578703224659, 62.31586955487728, 60.744520872831345, 60.00921852886677, 56.6332820802927, 59.46164511144161, 57.93719731271267, 57.50150129199028, 57.13932752609253, 53.23773868381977, 52.27569490671158, 48.45130652189255, 45.032489374279976, 44.281250685453415, 45.23707039654255, 45.4952247440815, 43.92921857535839, 45.97118720412254, 44.39950414001942, 46.72787860035896, 50.84555044770241, 50.819248259067535, 51.46288812160492, 50.306382179260254, 51.14286169409752, 51.08843341469765, 57.97311298549175, 59.34270389378071, 58.705067709088326, 60.95047362148762, 60.23944057524204, 58.78464303910732, 56.04746371507645, 54.05863903462887, 50.72696641087532, 48.464130833745, 50.85718922317028, 55.10319918394089, 55.30270367860794, 55.26796594262123, 58.30896556377411, 59.21318784356117, 62.5602762401104, 59.66751426458359, 60.23757867515087, 52.49656565487385, 4.683512784540653, 0.824033401440829, 2.163290656171739, 6.329563083127141, 3.491588942706585, 0.39318315975833684, 0.3988358611240983, 0.18182316765887663, 0.01723007153486833, 24.510168693959713, 57.797083631157875, 23.929233066737652, 44.70506474375725, 33.31313543021679, 0.26433278631884605, 0.029629732052853797, 0.028684701610472985, 0.028225646165083162, 0.06181071548780892, 0.009022164995258208, 0.016654051760269795, 0.017176970868604258, 0.057591487202444114, 0.07327347208047286, 0.02785786931781331, 0.018224636623926926, 0.04813629202544689, 0.014530640164593933, 0.0558064624783583, 0.025192781758960336, 0.0585986261285143, 0.013781945817754604, 0.029237250964797568, 0.03897479437000584, 0.042789203362190165, 0.039892975764814764, 0.03584778110962361, 0.022164776564750355, 0.17054323543561623, 0.1325751532567665, 0.28322118683718145, 0.12664748617680743, 0.14889728132402524, 0.28947318729478866, 0.1980136684142053, 0.30507856397889555, 0.16452419513370842, 0.26192024233751, 0.11787117429776117, 0.12415535427862778, 0.11113880391349085, 0.15532153425738215, 0.2798663527937606, 0.11448778241174296, 0.18396110215689987, 0.12052373625920154, 0.15619838173734024, 0.14004063938045874, 0.07585809784359299, 0.09623561025364324, 0.1370185546693392, 0.07267093722475693, 0.11855278498842381, 0.1294009282719344, 0.158753878204152, 0.14533132110955194, 0.17502611910458654, 0.44758023926988244, 6.81042680516839, 74.32154193520546, 48.2439174503088, 45.03912001848221, 80.6492891907692, 30.082928761839867, 0.8480471628718078, 1.6469167708419263, 0.8421253587584943, 4.043477028608322, 12.04442460089922, 13.365456964820623, 16.274921894073486, 5.473674684762955, 0.1536999415839091, 5.772518673911691, 60.40272541344166, 72.73008093237877, 75.49181833863258, 74.02735412120819, 72.79746651649475, 69.73252058029175, 62.98391930758953, 67.42317169904709, 60.96044808626175, 61.192129254341125, 58.45292463898659, 54.53461669385433, 54.64602671563625, 56.36334456503391, 65.0154460966587, 67.92734384536743, 66.36034592986107, 63.10867801308632, 63.28691504895687, 68.16659420728683, 70.84503248333931, 74.55326110124588, 71.28666758537292, 68.8979409635067, 66.26221999526024, 68.89051616191864, 61.650532856583595, 50.081498846411705, 48.94869603216648, 51.33309468626976, 52.566991075873375, 50.74156902730465, 54.29669626057148, 50.871548652648926, 50.991215631365776, 53.24449472129345, 53.97033177316189, 51.603989750146866, 54.924088194966316, 61.469981744885445, 64.71605256199837, 64.76994886994362, 70.31810715794563, 53.78080174326897, 62.90378540754318, 68.03180783987045, 62.44928419589996, 65.35159885883331, 62.7004849165678, 61.41079992055893, 59.77895848453045, 61.4814343303442, 61.272027567029, 58.95045094192028, 59.971630945801735, 54.69267301261425, 54.75147865712643, 51.15293875336647, 47.71763429045677, 46.66679687798023, 50.26230454444885, 48.38056951761246, 47.54254728555679, 51.05158679187298, 47.580716237425804, 47.537565752863884, 51.95402316749096, 53.36871765553951, 53.43968644738197, 53.22659768164158, 53.721536323428154, 54.64335925877094, 60.015423595905304, 61.429669708013535, 62.66466423869133, 64.16144952178001, 63.67031827569008, 60.62081851065159, 60.884759947657585, 57.321683540940285, 52.62987770140171, 50.5407802015543, 54.42289508879185, 57.6520150154829, 56.80693656206131, 58.73227044939995, 60.275553837418556, 61.727615520358086, 63.981627970933914, 62.271529734134674, 62.31832802295685, 54.29924592375755, 5.364528391510248, 1.0961316945031285, 1.5776337822899222, 9.807739220559597, 19.004858806729317, 6.390859493985772, 0.7171642547473311, 1.1305902642197907, 0.11481325869681314, 34.67386141419411, 60.799393728375435, 30.599340051412582, 57.35211990773678, 40.92305928468704, 0.25811581523157656, 0.18692331039346755, 0.16841502307215706, 0.12682889675488696, 0.1813429981120862, 0.11878049073857255, 0.11089333114796318, 0.2168655107379891, 0.12454539741156623, 0.19953210256062448, 0.13281066640047356, 0.1045785375754349, 0.10970144940074533, 0.24831422633724287, 0.09514112796750851, 0.13858182937838137, 0.1472758370800875, 0.09677083231508732, 0.1962685229955241, 0.12511742999777198, 0.2386951760854572, 0.1265211874851957, 0.06588775941054337, 0.1695222925627604], [0.016843045232235454, 0.08685591004905291, 0.013141921372152865, 0.04356984623882454, 0.035161617342964746, 0.031327901378972456, 0.015757828659843653, 0.06881115332362242, 0.09909614425851032, 0.03504448788589798, 0.0678262639848981, 0.05028839412261732, 0.0465146845090203, 0.007883542548370315, 0.06097299774410203, 0.0881094420037698, 0.032517211584490724, 0.029832013678969815, 0.018159351748181507, 0.03462366417807061, 0.10156909906072542, 0.061813324136892334, 0.02407197178399656, 0.06871454053907655, 0.036231913036317565, 0.05931414554652292, 0.020587273029377684, 0.029213266607257538, 0.06185320715303533, 0.22890387335792184, 0.43974143802188337, 21.157441399991512, 52.649587243795395, 34.06815491616726, 42.611430287361145, 57.56821811199188, 4.29196659475565, 0.09590424131602049, 0.6188063544686884, 0.10560397786321118, 1.9458888843655586, 1.084479857236147, 6.4328220672905445, 3.8976467913016677, 0.23821597133064643, 0.04792480220203288, 11.771486196666956, 69.92506384849548, 66.97437778115273, 74.2967976629734, 66.63879498839378, 67.07497358322144, 63.037895411252975, 61.24562278389931, 56.96255721151829, 54.15904864668846, 50.51420822739601, 51.558213606476784, 52.31189176440239, 64.91124048829079, 66.31052300333977, 67.15286180377007, 62.86702238023281, 64.29707184433937, 64.52632874250412, 66.15180552005768, 63.080487325787544, 66.03939235210419, 63.82699906826019, 63.906543999910355, 67.68711313605309, 65.06563380360603, 62.653599232435226, 48.313157334923744, 45.98336175084114, 46.925684586167336, 45.004731863737106, 46.12633287906647, 45.59679329395294, 45.26243023574352, 46.358128041028976, 45.784111842513084, 48.467930629849434, 51.34963519871235, 55.58277525007725, 60.761593356728554, 61.25444211065769, 60.271754041314125, 62.12742626667023, 53.66507135331631, 56.447236463427544, 62.84453138709068, 57.86867938935757, 55.72421886026859, 54.75629299879074, 56.66479378938675, 52.24577911198139, 55.2383579313755, 53.38969632983208, 52.77308441698551, 52.896440997719765, 51.376685947179794, 47.46209040284157, 43.56028117239475, 43.15638184547424, 45.75743727385998, 43.13708648085594, 42.654348984360695, 43.86000528931618, 43.736804500222206, 43.0668168514967, 47.68912822008133, 48.92561987042427, 53.23889762163162, 51.08713008463383, 51.67665705084801, 47.94058732688427, 45.68105757236481, 51.255442053079605, 58.2959208637476, 58.50336693227291, 57.772662341594696, 59.09999191761017, 58.065239042043686, 58.017354011535645, 55.69212198257446, 49.06474180519581, 45.28571538627148, 52.93363340198994, 55.749020129442215, 58.214335441589355, 57.65606179833412, 57.902885153889656, 58.859567418694496, 62.16272637248039, 54.740801230072975, 61.93040303885937, 16.47347643971443, 0.09615683869924396, 0.4771872115088627, 0.5128134170081466, 6.341146286576986, 1.8945491267368197, 0.45803528919350356, 0.05079096168628894, 0.14629786455770954, 4.240583851933479, 52.04421892762184, 32.93453134596348, 21.445553340017796, 48.69027189910412, 5.4892452992498875, 0.09972505504265428, 0.12086260088835843, 0.022966843389440328, 0.05445083326776512, 0.015654477174393833, 0.016898036519705784, 0.03142866647976916, 0.04817487999389414, 0.0667356037592981, 0.013641497153003002, 0.03905926561856177, 0.060250650567468256, 0.041810885741142556, 0.048843454860616475, 0.04628524955478497, 0.03717858548043296, 0.06752884088200517, 0.017368810476909857, 0.019579642430471722, 0.03878635194269009, 0.047634611328248866, 0.011886150914506288, 0.13106512022204697, 0.020399695204105228, 0.05123181967064738, 0.021911010298936162, 0.015231178404064849, 0.05642092364723794, 0.06658708516624756, 0.026030391891254112, 0.046852755040163174, 0.03488261434540618, 0.06004440030665137, 0.03731288081326056, 0.042204732380923815, 0.04063746862811968, 0.010830779810930835, 0.02271426641527796, 0.040962722268886864, 0.07807584290276282, 0.06064390719984658, 0.029562632626038976, 0.018779720412567258, 0.06392117938958108, 0.05759024410508573, 0.07116267792298459, 0.010530727649893379, 0.05311620683642104, 0.05582501988101285, 0.01909008286020253, 0.09343152400106192, 0.045287981192814186, 0.07876245566876605, 0.27258998074103147, 0.6622810091357678, 33.435029089450836, 56.059740856289864, 31.16238433867693, 59.39492829144001, 61.72072269022465, 4.122024988755584, 0.11051623107050546, 0.5750369187444448, 0.2722137118689716, 1.5885507152415812, 1.7992115300148726, 9.498025439679623, 5.209146179258823, 2.045402219519019, 0.10167826898396015, 15.798091180622578, 75.4552111029625, 69.30676102638245, 79.06426504254341, 68.52106958627701, 70.01530140638351, 64.66575086116791, 62.382647171616554, 59.153816029429436, 57.88914889097214, 52.766742557287216, 54.409086629748344, 54.35360200703144, 65.38925483822823, 68.10526549816132, 67.91906788945198, 66.79426744580269, 66.8196652829647, 66.60371527075768, 68.29666122794151, 65.71661487221718, 68.7360468506813, 66.11974284052849, 65.34126341342926, 68.6859655380249, 68.31656455993652, 62.61269822716713, 50.35858757793903, 48.86458374559879, 48.59313391149044, 47.719891369342804, 47.15303398668766, 46.735554188489914, 47.5803666561842, 48.41228261590004, 47.90776088833809, 49.87798936665058, 52.37459599971771, 56.7108853161335, 61.30008906126022, 62.74566829204559, 61.91458448767662, 66.13143861293793, 54.17404264211655, 57.69747197628021, 65.75006827712059, 61.01424179971218, 59.03533458709717, 57.30033628642559, 58.89516390860081, 55.260757729411125, 56.32232576608658, 55.475985780358315, 56.20045870542526, 53.408079743385315, 52.862774804234505, 49.426079615950584, 45.350258722901344, 43.95181976258755, 47.07321546971798, 45.78702628612518, 42.275763899087906, 45.02653129398823, 45.21005764603615, 46.00063942372799, 50.08284017443657, 55.08513115346432, 55.1326248049736, 55.37022985517979, 51.69853247702122, 50.10767184197903, 49.44765105843544, 52.87192091345787, 59.40919652581215, 63.90938624739647, 61.52578555047512, 61.40956498682499, 58.77183772623539, 59.63444463908672, 56.80448569357395, 51.81424006819725, 46.225784942507744, 55.60889884829521, 57.34618462622166, 60.24271979928017, 59.001246616244316, 60.04691630601883, 61.48114934563637, 64.46740910410881, 54.84567940235138, 63.85278448462486, 20.512264519929886, 0.23904069035779685, 2.499552662484348, 4.08164550550282, 4.103209348395467, 0.685524302534759, 0.2817978663370013, 0.05109999197884463, 0.08450692359474488, 5.323829250410199, 60.69554530084133, 39.63161878287792, 19.064074829220772, 54.30238075554371, 8.730550222098827, 0.26389043661765754, 0.05894053727388382, 0.01955429066583747, 0.08587678719777614, 0.04317086764785927, 0.05003171492717229, 0.03739166721061338, 0.02445274734782288, 0.04126708074181806, 0.08192372275516391, 0.049254170517087914, 0.02575757654994959, 0.05463167610287201, 0.027773572473961394, 0.0659298911341466, 0.030277558325906284, 0.06386037523043342, 0.018969585908052977, 0.02136240917025134, 0.060192273231223226, 0.054131375800352544, 0.03349533253640402, 0.03973692066210788, 0.03262704944063444, 0.2501359168672934, 0.13761004636762664, 0.09451939375139773, 0.18524679879192263, 0.22380751557648182, 0.07677822737605311, 0.15697251597885042, 0.16477076627779752, 0.26690602011512965, 0.14184702682541683, 0.16594757500570267, 0.1129430762375705, 0.13663827819982544, 0.1076847076183185, 0.14248816820327193, 0.2971760567743331, 0.17718634771881625, 0.06806891658925451, 0.1315795027767308, 0.21893344586715102, 0.1460626779589802, 0.21057285543065518, 0.09726327698444948, 0.1391717477235943, 0.15528309100773185, 0.08708552311873063, 0.14119147293968126, 0.1232930454716552, 0.09572953233146109, 0.3060366172576323, 0.5541453429032117, 37.02745132148266, 72.85250276327133, 43.568644523620605, 51.93442761898041, 74.55297991633415, 8.329033367335796, 0.4936408926732838, 2.8055312437936664, 0.7007695594802499, 7.445420706644654, 6.902238428592682, 13.275786526501179, 8.796022608876228, 1.5738292364403605, 0.17174725129734725, 16.693988107144833, 77.16942071914673, 72.0720474421978, 80.51506519317627, 72.36040636897087, 72.2846308350563, 69.86520946025848, 66.65748998522758, 61.11173316836357, 60.46927124261856, 56.037713438272476, 57.665831074118614, 57.26475119590759, 69.43447977304459, 71.2553496658802, 71.73980087041855, 67.9977996647358, 70.41130095720291, 69.3643507361412, 72.70846769213676, 67.69529789686203, 70.13437941670418, 64.78424370288849, 65.85791409015656, 71.8264590203762, 71.91987320780754, 68.95905688405037, 53.20708952844143, 53.39850805699825, 49.82047565281391, 49.08989265561104, 49.21066537499428, 47.743020728230476, 48.64373579621315, 51.56974598765373, 50.36780588328838, 52.51095548272133, 55.8856949955225, 59.989106208086014, 66.17989361286163, 67.26809442043304, 66.35406106710434, 67.76940152049065, 57.943770959973335, 62.11870953440666, 70.32623872160912, 64.72153946757317, 59.23002474009991, 61.032108440995216, 61.49954795837402, 57.79293045401573, 59.640037938952446, 57.891170382499695, 56.724800169467926, 55.26957705616951, 56.10319532454014, 51.306412518024445, 45.623483061790466, 47.0713459700346, 49.802058041095734, 47.756054028868675, 45.322440415620804, 47.103902623057365, 47.16907672584057, 49.3456607311964, 54.16787937283516, 57.709171548485756, 59.51594419777393, 58.44430290162563, 54.57030437886715, 52.8403902053833, 52.35857605934143, 56.42786890268326, 62.847362235188484, 65.4758369922638, 61.56507924199104, 62.12662070989609, 60.029513239860535, 62.553884983062744, 59.879079312086105, 55.00553302466869, 49.46846254169941, 57.50665761530399, 60.69105014204979, 63.47723163664341, 60.97940906882286, 62.16195121407509, 63.29399786889553, 66.82696089148521, 56.25297948718071, 64.06869649887085, 19.580336026847363, 0.398013680242002, 1.856770128943026, 3.0162838473916054, 18.801917396485806, 10.343789756298065, 0.7473449071403593, 0.5211543256882578, 0.6053008697926998, 8.149963226169348, 68.18645194172859, 47.27457046508789, 29.223924055695534, 67.0562481880188, 10.40559059008956, 0.4314687178703025, 0.2785057289293036, 0.18226096057333052, 0.15469934733118862, 0.13690404128283262, 0.08913611425668932, 0.09186577794025652, 0.09395616303663701, 0.11548704715096392, 0.19117605406790972, 0.15093480324139819, 0.11522536588017829, 0.2248155599227175, 0.18248035426950082, 0.19973824149928987, 0.10961824722471647, 0.17269160452997312, 0.11120336333988234, 0.13974404748296365, 0.20970546291209757, 0.17874365556053817, 0.11805550893768668, 0.144039464648813, 0.07291060639545321], [0.05003636448236648, 0.030391444597626105, 0.08645066773169674, 0.03805892847594805, 0.03645304335805122, 0.04269640150596388, 0.030727158809895627, 0.04370560731331352, 0.01705095975921722, 0.03760077102924697, 0.03164963723975234, 0.07744589311187156, 0.059058330953121185, 0.047485929462709464, 0.04447486193384975, 0.07894154332461767, 0.021270343895594124, 0.006020804758009035, 0.01942354650964262, 0.03134172387945, 0.06887781302793883, 0.05038716284616385, 0.02749869025137741, 0.04214248103380669, 0.022005645259923767, 0.10492019267985597, 0.010093728833453497, 0.0305370075875544, 0.1107837085146457, 0.07763212022837251, 0.24962769413832575, 2.903675464913249, 46.59159891307354, 37.7416267991066, 24.78557601571083, 67.08467066287994, 33.95424842834473, 0.6859048164915293, 0.19290175521746278, 0.06316480474197306, 0.4582144436426461, 2.6170214591547847, 6.011214265599847, 3.444531080313027, 3.304905197583139, 0.5310354579705745, 0.08029565855395049, 21.20552971959114, 67.51771062612534, 62.977440655231476, 76.57193318009377, 68.78393948078156, 65.67157968878746, 63.267091512680054, 59.07117426395416, 54.41852152347565, 55.13943783938885, 52.63268955051899, 59.05287064611912, 65.56083843111992, 68.87030884623528, 67.07742065191269, 65.84452360868454, 61.100554168224335, 65.38903445005417, 66.1501944065094, 70.02303779125214, 68.84608894586563, 65.2652294933796, 61.350101977586746, 60.89164897799492, 63.581209257245064, 60.25774039328098, 48.59925918281078, 45.4609239846468, 49.05429996550083, 46.377377808094025, 46.41180016100407, 46.86087906360626, 51.04801878333092, 56.634965389966965, 57.93014869093895, 58.2617074996233, 57.986518666148186, 61.8526516109705, 59.44797724485397, 63.59741158783436, 64.26813259720802, 60.60293287038803, 55.82013711333275, 59.674654081463814, 64.02176901698112, 59.36615623533726, 56.207587122917175, 54.19771537184715, 51.0913060605526, 54.4596429169178, 55.323040187358856, 53.95471081137657, 53.849076479673386, 49.062895104289055, 48.22141505777836, 43.249860629439354, 43.66695284843445, 42.35381931066513, 45.44372610747814, 42.907016426324844, 44.502661004662514, 42.34957493841648, 45.874281004071236, 44.611901342868805, 46.19740806519985, 50.11548802256584, 53.78109432756901, 55.576478987932205, 55.978269428014755, 54.48220610618591, 52.89697676897049, 49.00329910218716, 53.736750707030296, 59.38303492963314, 60.77915981411934, 63.02018076181412, 60.76449640095234, 58.24304670095444, 56.6872201859951, 52.71446496248245, 46.32157780230045, 50.43671518564224, 60.36533921957016, 58.800689578056335, 59.44434843957424, 62.151984348893166, 63.36181282997131, 55.00934801995754, 63.22345085442066, 32.3576121032238, 0.08409218178712763, 0.3596589539665729, 0.8649966877419502, 5.305265821516514, 3.202893496491015, 1.0972094116732478, 0.3809748007915914, 0.2023478108458221, 0.422139298170805, 27.107120342552662, 47.990714237093925, 20.659962594509125, 46.46210566163063, 23.015800081193447, 0.08501248943503015, 0.035146948794135824, 0.07601777833770029, 0.03977913402195554, 0.036940404315828346, 0.03171022988681216, 0.03086439861363033, 0.08454199007246643, 0.06631378928432241, 0.037516084557864815, 0.08412900715484284, 0.029187328545958735, 0.03529880334099289, 0.08829759870423004, 0.0637023571471218, 0.017563852452440187, 0.011628022675722605, 0.05500520645000506, 0.018717081293289084, 0.02127432180714095, 0.0207279842288699, 0.0051715456902456935, 0.03426203787967097, 0.02563682912295917, 0.030932720728742424, 0.04944737011101097, 0.017562199318490457, 0.04009122938441578, 0.05411242505942937, 0.055082233957364224, 0.023637127051188145, 0.05436007231764961, 0.012898707518615993, 0.0043386579363868805, 0.014348956847243244, 0.014027306333446177, 0.0401706132106483, 0.08240291266702116, 0.027615693543339148, 0.012667457085626666, 0.07230741102830507, 0.10300246824044734, 0.01822838075895561, 0.023719646451354492, 0.05680518544977531, 0.025807890451687854, 0.06914688608958386, 0.01244884357220144, 0.02261535668367287, 0.042345265464973636, 0.08799626448308118, 0.008068020979408175, 0.043009561850340106, 0.052350121186464094, 0.13963371980935335, 0.20534736395347863, 5.92793888412416, 60.36377750337124, 35.93505173921585, 28.113885819911957, 80.66734582185745, 32.67493687570095, 0.6349513912573457, 0.14461284794379026, 0.043704085910576396, 0.15542303037364036, 1.8546373746357858, 5.495971413329244, 10.904363226145506, 7.355797765776515, 1.1880645551718771, 0.13882788101909682, 28.34188688546419, 73.60037103295326, 64.9563516676426, 80.839324593544, 71.6871964931488, 68.31159442663193, 64.53733295202255, 62.750266045331955, 56.966824382543564, 58.3721561729908, 55.16204282641411, 61.64923332631588, 67.54241690039635, 72.07501888275146, 69.89238560199738, 68.61833676695824, 62.74812676012516, 67.2043414413929, 69.4279745221138, 72.47218877077103, 70.56783735752106, 66.08179047703743, 61.412304639816284, 64.20281410217285, 67.73011922836304, 61.39427460730076, 50.12533329427242, 45.437555238604546, 49.413148909807205, 49.696043729782104, 50.50214387476444, 49.50043402612209, 50.44789798557758, 57.109138146042824, 58.71985271573067, 59.69615712761879, 60.04068084061146, 63.60377624630928, 62.409367337822914, 64.30372908711433, 66.03627651929855, 61.081456393003464, 56.23421609401703, 63.772540390491486, 66.44199594855309, 59.65113714337349, 56.993202567100525, 55.473018139600754, 53.093798607587814, 56.20813429355621, 56.73174239695072, 56.955033615231514, 55.51591783761978, 52.55516231060028, 51.5578868240118, 46.832908764481544, 47.42171756923199, 45.25339052081108, 46.96645259857178, 44.689060002565384, 47.6178402453661, 44.96955715119839, 46.57643012702465, 47.092575430870056, 48.15239556133747, 49.769945964217186, 54.77899298071861, 56.321208626031876, 57.135782316327095, 55.255080834031105, 53.882047310471535, 49.80198584496975, 57.8013925999403, 58.58470156788826, 62.65492156147957, 62.513531148433685, 59.23185244202614, 59.832018837332726, 60.40727376937866, 52.836354821920395, 49.23775412142277, 52.02512115240097, 63.18430535495281, 60.02426952123642, 61.217040717601776, 64.51281666755676, 67.30859264731407, 56.938451305031776, 65.06553500890732, 35.85822746157646, 0.10584774368908256, 1.3236437737941742, 2.7829200820997357, 5.395856285467744, 1.4920064457692206, 0.6935941788833588, 0.20108145457925275, 0.022721535751770716, 0.45318211836274713, 31.27634782344103, 60.545293763279915, 25.262583419680595, 41.0755755007267, 34.32760879397392, 0.48940518870949745, 0.2559493971057236, 0.09848837726167403, 0.010085330504807644, 0.035093336045974866, 0.022598606410610955, 0.013584484440798406, 0.0199589003022993, 0.022855493407405447, 0.05544437975913752, 0.04410590321640484, 0.023091130860848352, 0.03560134726285469, 0.12160488215158693, 0.02943034665804589, 0.09064729762030765, 0.03769472321437206, 0.0185485655310913, 0.02439527914248174, 0.03619341041485313, 0.022173198085511103, 0.06037560597178526, 0.05280271252559032, 0.010383711905888049, 0.02612048676382983, 0.0880459883774165, 0.10669640440028161, 0.14386983937583864, 0.14860857103485614, 0.1628438095212914, 0.08812418847810477, 0.098194293823326, 0.24130909441737458, 0.1330386838526465, 0.1140634372131899, 0.11592635404667817, 0.14648752781795338, 0.12784970604116097, 0.15307184716220945, 0.10004051975556649, 0.34922931517940015, 0.13255029130959883, 0.11791340250056237, 0.08760159777011722, 0.15654383663786575, 0.2577511832350865, 0.14859524206258357, 0.16837987495819107, 0.12385851005092263, 0.07611144479596987, 0.29568249941803515, 0.09369592153234407, 0.1484952896134928, 0.25350805779453367, 0.38511919090524316, 0.36885751818772405, 5.790923936292529, 72.23784774541855, 51.206477880477905, 33.711886033415794, 80.95003545284271, 49.91577073931694, 1.737603535875678, 0.60164047870785, 0.755245751934126, 1.3394808489829302, 9.79504220187664, 15.906324572861195, 11.303520407527685, 7.750624129548669, 1.2049208069220185, 0.22238958306843415, 30.01870270818472, 82.65529274940491, 66.96016654372215, 81.54038697481155, 75.93812718987465, 69.97237130999565, 67.32442259788513, 64.64536115527153, 61.087562665343285, 61.525926142930984, 59.609878957271576, 65.16172304749489, 69.92683455348015, 73.35948675870895, 71.6169610619545, 71.62000849843025, 65.47411948442459, 69.70482766628265, 69.53067541122437, 75.43409183621407, 74.25264403223991, 66.4991144835949, 63.99735912680626, 66.20493426918983, 68.13506349921227, 63.16661350429058, 52.881477400660515, 47.93756648898125, 53.235512003302574, 52.21266768872738, 54.627582505345345, 53.39785449206829, 55.59452801942825, 61.05775706470013, 63.894445449113846, 65.24511337280273, 64.9811339378357, 66.65329501032829, 67.39126101136208, 67.84403711557388, 69.85834702849388, 62.18829520046711, 58.3043260127306, 66.00669890642166, 68.05155918002129, 64.04136836528778, 60.152155458927155, 58.61427158117294, 55.86862251162529, 59.98725950717926, 59.27242286503315, 58.302650302648544, 58.985595256090164, 53.571170791983604, 53.26828144490719, 48.56546759605408, 49.22751747071743, 47.21774451434612, 51.656058356165886, 49.44283291697502, 49.990961104631424, 47.6322490721941, 51.5701487660408, 50.081799030303955, 50.17758049070835, 51.809972897171974, 55.4681695997715, 60.03836676478386, 61.5556937456131, 60.639638900756836, 56.89496263861656, 52.785813733935356, 57.819225043058395, 63.279304057359695, 66.65974706411362, 66.26749411225319, 61.31870426237583, 63.12312103807926, 62.884767428040504, 56.159994676709175, 49.79475103318691, 54.68623995780945, 64.42892476916313, 62.62206472456455, 63.095116540789604, 65.13839229941368, 67.41755560040474, 58.9484940469265, 64.43789228796959, 35.81663869321346, 0.22709343378664926, 1.3356246496550739, 2.1111821522936225, 13.064599558711052, 9.933983646333218, 2.8533716266974807, 0.6874306127429008, 0.4075504856882617, 0.7711701036896557, 40.45729547739029, 65.43252691626549, 32.630357667803764, 56.884254813194275, 40.65626800060272, 0.4877547116484493, 0.32757528650108725, 0.24225861299782991, 0.12603748531546444, 0.2194103944930248, 0.09716707980260253, 0.14439195510931313, 0.13464973802911118, 0.10731982329161838, 0.07832316361600533, 0.19759125279961154, 0.09866560954833403, 0.12264820077689365, 0.1826667075511068, 0.11941518285311759, 0.20346413453808054, 0.09409699297975749, 0.09892461166600697, 0.0825535983312875, 0.10598080334602855, 0.15689577790908515, 0.11483897411380894, 0.10137265257071704, 0.17775262123905122, 0.10819093397003599], [0.029108111702953465, 0.05347086065739859, 0.018799901263264474, 0.05136640444106888, 0.03822351085545961, 0.03632863343227655, 0.020069508136657532, 0.05040094081778079, 0.013196582403907087, 0.033346301861456595, 0.01614151715330081, 0.0547911376634147, 0.05196614140004385, 0.020734752615680918, 0.05856417934410274, 0.016360786539735273, 0.055704806800349616, 0.052591066851164214, 0.07273409399203956, 0.041618769682827406, 0.06236553395865485, 0.054851938111823983, 0.02875188638427062, 0.03580361961212475, 0.1054147895774804, 0.02848227712092921, 0.06868835014756769, 0.06348382434225641, 0.01764004318829393, 0.0369506830611499, 0.034621775412233546, 0.26732420548796654, 15.575266387313604, 55.25294914841652, 29.428480379283428, 41.68672330677509, 62.25627355277538, 13.433710802346468, 0.10526836384087801, 0.12495899631176144, 0.20267152081942186, 0.9575312223751098, 7.497333521023393, 10.442971084266901, 9.6905411593616, 2.609333759173751, 0.11561755381990224, 1.2161970580928028, 49.245562702417374, 78.49102780222893, 75.90633049607277, 71.86447218060493, 73.6509159207344, 63.06476376950741, 60.56455112993717, 56.639270558953285, 57.411655113101006, 61.58946633338928, 67.90164202451706, 72.62809440493584, 71.43846943974495, 67.79717043042183, 67.03186869621277, 70.45286312699318, 69.5484584569931, 66.68303221464157, 63.815972059965134, 61.308760195970535, 63.19405563175678, 65.00356033444405, 64.8044966161251, 67.206309735775, 61.37977838516235, 47.869417145848274, 46.39008052647114, 48.2960544526577, 47.78275519609451, 47.18329556286335, 55.192790776491165, 61.39728024601936, 61.297964975237846, 62.87064738571644, 62.29960262775421, 61.1181016266346, 62.14300163090229, 62.50513359904289, 64.01191994547844, 60.912988632917404, 59.74286422133446, 54.88253362476826, 59.85944576561451, 59.18363682925701, 62.11055897176266, 59.87867273390293, 53.47484216094017, 53.31448316574097, 48.604552298784256, 50.818511098623276, 49.91888277232647, 48.38143207132816, 46.79501339793205, 44.71714809536934, 45.036277770996094, 44.123939126729965, 45.865670666098595, 44.65558759868145, 42.90934570133686, 42.11603187024593, 45.140509977936745, 46.795305982232094, 44.291867315769196, 44.46718230843544, 50.72786696255207, 52.85378448665142, 56.86501644551754, 56.32794946432114, 56.16768926382065, 52.81840078532696, 53.67628075182438, 52.14003838598728, 58.05246792733669, 58.53631116449833, 61.46904319524765, 60.91073535382748, 61.28707095980644, 57.56397753953934, 56.590811759233475, 51.86954990029335, 56.037781834602356, 56.52482070028782, 60.06440296769142, 62.98564821481705, 59.873265624046326, 64.1911943256855, 58.70365418493748, 43.03553692996502, 2.3239438980817795, 0.2506581513443962, 0.7631180982571095, 5.087753618136048, 8.583970237523317, 1.0029438324272633, 0.06458906034822576, 0.09080752730369568, 0.08606607938418165, 13.406485263258219, 53.00175994634628, 26.94905262440443, 29.03631292283535, 51.86359561979771, 4.151667673140764, 0.05428669246612117, 0.10444906991324387, 0.031264358694897965, 0.05336470756446943, 0.032613516377750784, 0.050287113917875104, 0.01698199939710321, 0.013743092531512957, 0.04679498255427461, 0.043853406023117714, 0.04035994250443764, 0.03613234650401864, 0.06215792927832808, 0.05230440117884427, 0.08824765958706848, 0.039791657763998955, 0.08421133359661326, 0.06400801808922552, 0.007364561461145058, 0.05946438592218328, 0.01435030570064555, 0.05023787613026798, 0.042813486434170045, 0.0506876361760078, 0.011598828441492515, 0.04038860053697135, 0.05841445847181603, 0.08417366960202344, 0.0021394160103227478, 0.012180183330201544, 0.051022296538576484, 0.05232721108768601, 0.040173971428885125, 0.06012266720063053, 0.05283541155222338, 0.031622734386473894, 0.0677399076812435, 0.052982171255280264, 0.05631391337374225, 0.021862943249288946, 0.018424819827487227, 0.045582227903651074, 0.0879096781136468, 0.027093340322608128, 0.010937495080725057, 0.07577088064863347, 0.0046494981415889924, 0.027595160172495525, 0.061898682251921855, 0.04686035834311042, 0.018364776369708125, 0.052332784616737626, 0.032623579900246114, 0.05569249828113243, 0.055979557291720994, 0.11178986038430594, 0.49735893378965557, 25.930701568722725, 59.53078620135784, 22.663699574768543, 56.64981499314308, 74.19152051210403, 13.083691634237766, 0.07432973376126029, 0.27965766086708754, 0.17827350500738248, 0.4127361683640629, 1.1326277861371636, 11.383465267717838, 10.085468217730522, 5.053486581891775, 0.17503575218142942, 2.138598393648863, 56.90678000450134, 78.39580491185188, 78.57377976179123, 72.30845555663109, 77.43150025606155, 63.03473778069019, 64.48797360062599, 61.095348447561264, 59.792702347040176, 63.457419499754906, 70.94571188092232, 73.69085937738419, 73.08155447244644, 69.18397441506386, 69.7119864821434, 71.48320823907852, 70.80696612596512, 65.97520619630814, 65.14376521110535, 62.47948877513409, 65.91400668025017, 64.38629105687141, 66.01628199219704, 69.78389382362366, 61.694086119532585, 50.115328431129456, 49.26975220441818, 50.21568104624748, 49.528579115867615, 49.5273631811142, 54.16132092475891, 63.55803430080414, 63.400703743100166, 65.3162531554699, 65.09812206029892, 61.599877774715424, 63.94647225737572, 64.31722596287727, 66.31556913256645, 62.81169354915619, 60.63438378274441, 57.567028775811195, 61.07033059000969, 62.89054311811924, 64.78980660438538, 61.43459804356098, 54.59071308374405, 54.46291074156761, 53.20503383874893, 53.02461192011833, 52.06943437457085, 48.47166582942009, 48.304163217544556, 46.965164467692375, 46.20929002761841, 45.852139592170715, 45.794386491179466, 46.609758138656616, 43.687676936388016, 44.607356786727905, 46.62771597504616, 48.047190606594086, 47.288302928209305, 48.66359353065491, 54.82354938983917, 55.06716571748257, 58.52747663855553, 57.353609427809715, 57.83598214387894, 54.90004688501358, 55.96125394105911, 52.688063979148865, 59.77622263133526, 61.32963627576828, 61.59182980656624, 60.23697830736637, 61.94572001695633, 59.623315036296844, 57.16486595571041, 53.296969905495644, 58.82555164396763, 58.7990290671587, 60.36311633884907, 67.09969505667686, 63.12044218182564, 63.99182662367821, 58.09976778924465, 49.36219364404678, 3.985408069565892, 0.6014148064423352, 3.280743956565857, 4.398094899952412, 1.1487183789722621, 0.5658649827819318, 0.11362787074176595, 0.06833189661847427, 0.039956793043529615, 19.46319781243801, 61.69625200331211, 38.99045258760452, 26.27013735473156, 60.283544808626175, 6.9040856044739485, 0.22748542134650052, 0.0025683168360046693, 0.07952533895149827, 0.10088590759551153, 0.01572829860378988, 0.029719446574745234, 0.036523695816867985, 0.02203504729550332, 0.03981363646744285, 0.06171550165163353, 0.05954584776191041, 0.04566777897707652, 0.0327493368240539, 0.05136599254910834, 0.06007074654917233, 0.0857247730891686, 0.021017132385168225, 0.005099283698655199, 0.08178331583621912, 0.034805063623934984, 0.03777407735469751, 0.02567667132097995, 0.02494082447810797, 0.0798887612472754, 0.04058824939420447, 0.10624074056977406, 0.12225088459672406, 0.11247818008996546, 0.2310411399230361, 0.12248288738192059, 0.1329643206554465, 0.09683462732937187, 0.13768206437816843, 0.10037872387329116, 0.1602063947939314, 0.1657025920576416, 0.15081237856065854, 0.10696849800297059, 0.11299518242594786, 0.08964401786215603, 0.11331198300467804, 0.19595080957515165, 0.19952609116444364, 0.13811712618917227, 0.12800990603864193, 0.09282156766857952, 0.09693655389128253, 0.11381869917386211, 0.08459180302452296, 0.15284212277038023, 0.11995992666925304, 0.2103780268225819, 0.13163336785510182, 0.1357917845598422, 0.14375171915162355, 0.2939479221822694, 0.43273606861475855, 27.035157904028893, 78.34858864545822, 40.354184210300446, 53.922024965286255, 81.38980865478516, 22.282086052000523, 0.16814501490443945, 0.9979283390566707, 0.51715771201998, 2.705588531680405, 15.843973718583584, 22.63852022588253, 23.899001888930798, 8.621546421200037, 0.16096705163363367, 2.234591217711568, 54.3338430672884, 81.72220721840858, 80.01845464110374, 74.84130084514618, 80.86621955037117, 68.72345432639122, 67.26570814847946, 64.22383457422256, 62.28350289165974, 68.3270063996315, 73.06004002690315, 79.82819125056267, 76.11066073179245, 70.67562997341156, 70.20738109946251, 75.74871495366096, 74.71107423305511, 68.17546293139458, 66.24447494745255, 61.88043192028999, 64.6411357820034, 66.31613910198212, 69.40993309020996, 74.77179497480392, 65.9426799416542, 54.34577442705631, 51.65773406624794, 52.96495892107487, 51.63597263395786, 52.73360073566437, 59.39806692302227, 66.26165002584457, 66.82860240340233, 67.72660821676254, 68.16936045885086, 63.48312892019749, 67.02214881777763, 67.01567396521568, 68.61683964729309, 65.74911832809448, 61.360072642564774, 59.16572459042072, 63.61789248883724, 65.80128192901611, 67.07150056958199, 65.0435645878315, 58.478957042098045, 59.88410264253616, 54.950352385640144, 56.63640171289444, 54.92232508957386, 51.083596274256706, 50.585488602519035, 50.55906102061272, 49.25268732011318, 48.81211996078491, 48.97762767970562, 49.32769529521465, 45.136470794677734, 47.199600487947464, 49.302229061722755, 51.13281883299351, 51.01321645081043, 51.98268502950668, 56.86144083738327, 59.11799535155296, 62.79505804181099, 61.06638640165329, 61.703304424881935, 57.77698650956154, 60.51027864217758, 57.24765971302986, 60.61646394431591, 64.04709085822105, 64.70263168215752, 61.846047565340996, 63.1213541328907, 61.19201526045799, 60.76399102807045, 58.85001093149185, 61.20199352502823, 62.49855995178223, 63.10400426387787, 69.41594436764717, 63.95834282040596, 67.19973608851433, 58.94839145243168, 48.98466870188713, 3.9970093220472336, 0.7475116825662553, 1.5603184676729143, 12.287520356476307, 18.147657103836536, 2.690442306920886, 0.47974958026316017, 0.28209243959281594, 0.23238439753185958, 24.621483720839024, 68.59948217868805, 41.3305988162756, 39.54286314547062, 68.840062469244, 8.807105664163828, 0.4475785471731797, 0.2138883259613067, 0.2643168153008446, 0.20733836805447936, 0.13264967972645536, 0.14790744928177446, 0.08590066208853386, 0.13541530788643286, 0.10938448554952629, 0.1298941596178338, 0.16962460504146293, 0.1873097021598369, 0.1569609236321412, 0.16315462096827105, 0.24585802922956645, 0.20053397223819047, 0.1207483843609225, 0.1593789891921915, 0.18856458482332528, 0.20829995395615697, 0.14894357649609447, 0.10381074127508327, 0.1886407143319957, 0.17193091800436378, 0.17226553754881024], [0.03996130901214201, 0.019024415778403636, 0.025490459047432523, 0.0688084147986956, 0.05133210237545427, 0.06354007171466947, 0.02243966249807272, 0.006310426033451222, 0.04518536814430263, 0.02297735776664922, 0.03819945042778272, 0.045847720102756284, 0.09620758675737306, 0.04448153755220119, 0.031194255425361916, 0.045058453470119275, 0.024727842937863898, 0.04155064052611124, 0.08528279446181841, 0.07878419317421503, 0.01236375726875849, 0.024569978850195184, 0.045359761716099456, 0.07195127662271261, 0.024250597452919465, 0.012015356969641289, 0.05228146139415912, 0.028348356572678313, 0.034345069361734204, 0.041750007367227226, 0.04205233235552441, 0.09419925350812264, 0.8079070074018091, 38.593681678175926, 47.13220350444317, 21.612039506435394, 54.04521815478802, 56.41745366156101, 5.218734489753842, 0.053059933488839306, 0.18179907754529268, 0.6869121186900884, 0.5990459898021072, 12.970265820622444, 18.792072124779224, 1.3071075361222029, 0.8298978523816913, 0.3575311868917197, 8.534370549023151, 62.994744926691055, 76.1744973063469, 76.91930294036865, 69.14570286870003, 71.10345661640167, 61.75878904759884, 59.35339272022247, 65.06794407963753, 68.12608078122139, 72.24898114800453, 70.42503342032433, 70.88314443826675, 71.83275908231735, 67.50571846961975, 66.29514902830124, 66.469536870718, 66.90934807062149, 67.99477502703667, 70.8858422935009, 65.16559883952141, 63.64355631172657, 66.41519218683243, 64.30090963840485, 57.130276411771774, 46.959392577409744, 46.34233608841896, 49.294545873999596, 48.0827035009861, 52.690594643354416, 61.46328650414944, 63.24658781290054, 66.62070035934448, 63.80860045552254, 67.33162701129913, 62.864932492375374, 66.97330623865128, 63.045217618346214, 65.40392965078354, 56.28491297364235, 61.44123248755932, 41.18897661566734, 50.87180323898792, 68.31616938114166, 62.91890859603882, 65.93115136027336, 58.03839348256588, 57.317834347486496, 51.36602371931076, 48.91714632511139, 45.75323089957237, 45.93411259353161, 45.39242886006832, 45.76633259654045, 44.103135243058205, 47.186232805252075, 45.47295033931732, 45.77823355793953, 44.51978288590908, 44.43029388785362, 46.57177157700062, 46.51579298079014, 44.960715025663376, 45.02852238714695, 49.02217648923397, 51.89689703285694, 55.9193991869688, 58.36707964539528, 58.412791192531586, 55.9171649068594, 52.89997860789299, 53.72859254479408, 54.95359741151333, 59.577831476926804, 65.00389471650124, 62.2834724932909, 60.30094787478447, 62.397979348897934, 60.20790986716747, 55.78620873391628, 53.90819750726223, 64.25058513879776, 59.83778312802315, 61.494722217321396, 64.89306226372719, 55.73368415236473, 54.45853337645531, 10.168546959757805, 0.15243321424350142, 0.49048367771320045, 2.4375012796372175, 1.189111398998648, 2.3099338123574853, 0.46218172763474286, 0.13683163735549897, 0.31467779888771474, 6.735413130372763, 42.830370739102364, 31.974801644682884, 18.739899024367332, 47.246987745165825, 18.161163479089737, 0.061613634461537004, 0.005446830991786555, 0.0337830743228551, 0.029144159670977388, 0.010610170847940026, 0.017199782632815186, 0.013380574728216743, 0.0619255405763397, 0.05109189514769241, 0.0272744076573872, 0.03186083762557246, 0.05255341027805116, 0.029373386823863257, 0.02627081619721139, 0.040708844680921175, 0.02661457343492657, 0.036438293172977865, 0.00440156144577486, 0.018004515623033512, 0.011049672557419399, 0.01410336626577191, 0.0375514330517035, 0.028106384888815228, 0.046757530071772635, 0.0049281374867859995, 0.022434604761656374, 0.06961046121432446, 0.005885567361474386, 0.027528886384970974, 0.07587725267512724, 0.06399452584446408, 0.03252428425184917, 0.013926120991527569, 0.07657420355826616, 0.054372091399272904, 0.07186260481830686, 0.06250283870031126, 0.028174491781101096, 0.058290842644055374, 0.05289315806294326, 0.04078640282386914, 0.03236952790757641, 0.04883082350715995, 0.04140241879213136, 0.017096330957429018, 0.0670305555104278, 0.04778897804499138, 0.034144429737352766, 0.06532877378049307, 0.033417967351851985, 0.045042374840704724, 0.07751686469418928, 0.05948240155703388, 0.019565474831324536, 0.03998441949079279, 0.09107669684453867, 0.0496463287709048, 0.2359177774633281, 2.0626794174313545, 52.64554426074028, 43.26729029417038, 24.779201857745647, 74.9059809744358, 55.268672704696655, 6.607160037383437, 0.10295470361597836, 0.06055889789422508, 0.18903538846643642, 0.4725013207644224, 2.631756355985999, 19.172220826148987, 8.44911927357316, 2.46734416577965, 0.3174520656466484, 11.858474928885698, 69.95949760079384, 76.7763090133667, 78.50859045982361, 71.77132397890091, 74.48114097118378, 63.23426127433777, 61.91594481468201, 64.72144827246666, 68.73508930206299, 72.98399090766907, 71.64422079920769, 72.50537618994713, 73.03911074995995, 69.45220202207565, 69.82246935367584, 68.02182957530022, 71.31354734301567, 70.30283197760582, 69.83579143881798, 65.05838379263878, 65.217724442482, 67.43789970874786, 67.9010796546936, 58.53512182831764, 48.33406761288643, 49.39131148159504, 51.413946747779846, 51.92098394036293, 54.780417904257774, 66.22270211577415, 66.28223732113838, 68.25972720980644, 66.50554373860359, 68.27874898910522, 65.70532947778702, 69.29782390594482, 66.51768028736115, 66.16252094507217, 57.85728380084038, 60.61014108359814, 47.98989728093147, 55.334108993411064, 69.05845195055008, 62.88857102394104, 65.5909252166748, 59.77793253958225, 57.658706456422806, 51.752725169062614, 51.2216504663229, 47.747968062758446, 49.85086262226105, 47.79257386922836, 48.98135527968407, 45.9830691665411, 48.14598150551319, 49.578599631786346, 47.568146511912346, 45.24976171553135, 47.488122805953026, 47.77317211031914, 47.58904539048672, 47.72410534322262, 46.54495641589165, 49.606991708278656, 54.62213359773159, 58.78123842179775, 62.79896043241024, 60.888772532343864, 56.00551396608353, 54.18035410344601, 57.62701615691185, 55.62900736927986, 62.21683166921139, 66.11282721161842, 64.04477298259735, 61.14085480570793, 64.09579664468765, 61.771810948848724, 55.643518790602684, 55.74596509337425, 64.84434127807617, 63.21059234440327, 63.179350420832634, 67.62874826788902, 56.013736724853516, 59.38878022134304, 12.111136671155691, 0.21598817344056442, 2.0413074642419815, 5.206121066585183, 3.3425485901534557, 1.0804006573744118, 0.4899622150696814, 0.12129787050071172, 0.3413118462776765, 13.801627960056067, 45.81201754510403, 49.67030771076679, 18.823956213891506, 51.987624764442444, 26.241597086191177, 0.057337138350703754, 0.11861102131661028, 0.06136684067314491, 0.027225667108723428, 0.06630223404499702, 0.017106700615840964, 0.03198870224878192, 0.03768564303754829, 0.034968454856425524, 0.024910455795179587, 0.031139607381192036, 0.058752432523760945, 0.009274153817386832, 0.012444183812476695, 0.02449702202284243, 0.07084415556164458, 0.02589521711342968, 0.009507125105301384, 0.06387583416653797, 0.011559714475879446, 0.01010946607493679, 0.03710661570949014, 0.04012352022982668, 0.04814178391825408, 0.054482571213156916, 0.07501903310185298, 0.17185492208227515, 0.12334184168139473, 0.09301150552346371, 0.25167587329633534, 0.12764570448780432, 0.1374646893236786, 0.13000876206206158, 0.1784215189400129, 0.14025415526703, 0.10974415257805958, 0.15575649216771126, 0.1700916385743767, 0.25620065862312913, 0.18178950384026393, 0.12606881879037246, 0.16230941866524518, 0.11527419919730164, 0.20446888374863192, 0.12246106824022718, 0.13071001740172505, 0.14444432104937732, 0.16655387997161597, 0.18525122199207544, 0.1525510524515994, 0.137244033976458, 0.23343220615061, 0.20384359464515, 0.07658492759219371, 0.18841847078874707, 0.2454907848732546, 0.13570131675805897, 0.26341988530475646, 1.8460675282403827, 59.24469195306301, 60.77516242861748, 32.08798237144947, 66.90503150224686, 75.8822625875473, 10.420464891940355, 0.14299420901807025, 0.30620472854934633, 1.0010298038832843, 1.676936347503215, 23.331929817795753, 43.1820684671402, 11.210511848330498, 2.265910324640572, 0.268813933362253, 12.484687976539135, 70.63975229859352, 79.37935933470726, 81.8367026746273, 75.02545416355133, 77.28349059820175, 66.2612472474575, 64.64393243193626, 70.80090925097466, 72.75569915771484, 78.26363280415535, 71.95166990160942, 75.04534229636192, 74.52709570527077, 73.15129593014717, 71.2616117298603, 69.20298099517822, 70.69335222244263, 73.44354584813118, 73.06315585970879, 68.76354217529297, 66.66492238640785, 69.33019056916237, 71.12244039773941, 58.67732919752598, 49.90016497671604, 51.67826056480408, 54.81173202395439, 53.817914351820946, 57.769204527139664, 69.0915709733963, 70.9554773569107, 72.35434949398041, 69.37785521149635, 73.07188019156456, 69.07589301466942, 72.6365527510643, 68.38740795850754, 66.45449727773666, 56.21261805295944, 61.509659215807915, 46.40540510416031, 54.97486487030983, 74.50513288378716, 65.67533388733864, 70.59993803501129, 63.092114701867104, 60.73618412017822, 55.805960074067116, 54.30527240037918, 51.099475622177124, 50.55903062224388, 51.82173706591129, 52.18383863568306, 49.24615167081356, 51.58449299633503, 52.94545456767082, 51.72581501305103, 50.19766241312027, 50.561777874827385, 51.161929070949554, 51.632226034998894, 50.30957780778408, 48.27840439975262, 51.69833868741989, 56.18209429085255, 61.60542167723179, 64.98462975025177, 64.22233745455742, 60.75707159936428, 56.24699480831623, 59.769481793046, 59.48170803487301, 64.30714890360832, 69.34578493237495, 63.506881445646286, 62.97175236046314, 65.93263328075409, 65.88236957788467, 58.03030751645565, 59.86495926976204, 68.17426219582558, 64.35234367847443, 65.53429305553436, 67.23210275173187, 58.84664811193943, 61.14555135369301, 11.927032750099897, 0.3058368607889861, 0.9735630371142179, 10.32349219545722, 8.529678750783205, 5.711876777932048, 1.1160511756315827, 0.421423630323261, 0.44899732572957873, 15.04839900881052, 57.79822736978531, 47.33217917382717, 29.813443422317505, 63.64700272679329, 30.88712900876999, 0.21277929015923291, 0.20470441173529252, 0.08930937605327927, 0.1212171842053067, 0.09106443656492047, 0.19792386854533106, 0.10492836372577585, 0.1676519468310289, 0.14985466666985303, 0.06301826768321916, 0.14352223224705085, 0.29462357342708856, 0.10879808498430066, 0.12312248509260826, 0.1478478399803862, 0.18642210838152096, 0.1956554496427998, 0.05894880108826328, 0.09791560252779163, 0.10544593751546927, 0.15714319510152563, 0.1555784954689443, 0.09380397823406383, 0.18939423171104863, 0.11381437245290726, 0.14134209923213348], [0.036313163363956846, 0.05206692134379409, 0.06058849103283137, 0.05304740974679589, 0.01299800502238213, 0.07440460904035717, 0.04948675959894899, 0.008338348270626739, 0.04836444306420162, 0.07990475452970713, 0.006552371278303326, 0.05102621878904756, 0.0399313447996974, 0.03769973642192781, 0.05049486331699882, 0.10158730394323356, 0.045019078825134784, 0.05681608017766848, 0.13986028265208006, 0.006424527064154972, 0.029217661976872478, 0.07451066936482675, 0.08762770652538165, 0.036356126292957924, 0.019226843978685793, 0.06387320696376264, 0.06238902293262072, 0.07305392253329046, 0.04464597150217742, 0.03423243360884953, 0.024584883030911442, 0.14286359102698043, 0.1876102274400182, 9.484172333031893, 61.370814666152, 40.5425439029932, 25.535444878041744, 60.58171860873699, 46.549010798335075, 5.502593033015728, 0.09070190484635532, 0.09671564621385187, 0.14180842030327767, 0.4956242971820757, 5.684404252097011, 11.210414953529835, 1.1021677893586457, 0.41731204313691705, 0.0750231223355513, 20.085745006799698, 73.47178593277931, 73.65180507302284, 82.55205988883972, 67.22464755177498, 69.09825101494789, 66.94885835051537, 71.12852767109871, 68.6468580365181, 75.8891250193119, 72.41612657904625, 71.32138252258301, 70.5378569662571, 71.76286563277245, 69.30537790060043, 74.4739517569542, 66.64991319179535, 69.78750362992287, 70.24404153227806, 65.365050137043, 69.04082089662552, 66.93049013614655, 66.7800410091877, 56.32632315158844, 46.94483935832977, 51.910173520445824, 47.480071038007736, 51.455166935920715, 61.12892724573612, 63.93061950802803, 65.13668239116669, 67.51268729567528, 63.07351469993591, 63.27363096177578, 62.71708242595196, 64.83242511749268, 60.21936245262623, 61.36401303112507, 57.089253813028336, 64.85888689756393, 28.11497636139393, 50.76359264552593, 67.04479560256004, 65.94761207699776, 66.16442084312439, 61.75854206085205, 57.58670412003994, 54.19130891561508, 51.54586426913738, 48.52124556899071, 47.97810651361942, 46.49720057845116, 46.88422121107578, 46.25628590583801, 46.399956196546555, 47.33604356646538, 44.557628855109215, 45.74405059218407, 45.32988041639328, 46.0966070741415, 46.68175287544727, 48.238073363900185, 48.28471206128597, 46.75624027848244, 51.298368349671364, 51.22738815844059, 52.32436269521713, 52.676504999399185, 56.287181451916695, 57.34009735286236, 54.13146212697029, 54.20853339135647, 58.63557703793049, 61.425964906811714, 64.72926825284958, 64.28564965724945, 60.63392020761967, 60.905100256204605, 59.43622827529907, 62.28960536420345, 57.05907963216305, 64.54404339194298, 66.53486296534538, 54.912681207060814, 60.574407801032066, 20.442982837557793, 0.02537381755246315, 0.4074030357878655, 2.924795444123447, 12.189417220652103, 1.4323628274723887, 0.06320632048300467, 0.1424530052463524, 0.4552176216384396, 9.587972313165665, 46.400317177176476, 50.38855656981468, 22.602501958608627, 41.61414720118046, 36.450509279966354, 1.222742444369942, 0.2382259606383741, 0.09784351772395894, 0.02554565257014474, 0.01906141740619205, 0.08599180524470285, 0.03428415388043504, 0.039797554127289914, 0.09482056470005773, 0.050814298519981094, 0.004520555085036904, 0.06338796112686396, 0.012107247839594493, 0.009688938298495486, 0.05171844219148625, 0.049629418936092407, 0.01647369317652192, 0.02841250225174008, 0.04767883219756186, 0.022578958050871734, 0.07017512427410111, 0.011467125059425598, 0.01661927657551132, 0.06006519528455101, 0.03955326879804488, 0.009142851195065305, 0.08993391558760777, 0.017735873007040936, 0.03707919706357643, 0.03779387043323368, 0.04130810666538309, 0.022126055009721313, 0.07436249958118424, 0.046704488777322695, 0.025131222464551684, 0.036995223053963855, 0.04308561714424286, 0.01821550449676579, 0.05002455320209265, 0.007887589108577231, 0.016202260085265152, 0.04343423730460927, 0.03436236140260007, 0.00894529612196493, 0.055639360507484525, 0.016884037759155035, 0.03692784717713948, 0.04436961797182448, 0.04064620370627381, 0.0711114177829586, 0.039144115362432785, 0.020249833323759958, 0.11871947877807543, 0.03658174660813529, 0.07372712469077669, 0.031457176082767546, 0.015463889940292574, 0.06298893058556132, 0.06388744877767749, 0.31612086051609367, 15.279231872409582, 73.62996384501457, 30.03837615251541, 35.47222897410393, 81.30685910582542, 41.92062735557556, 6.331698568537831, 0.08803556120255962, 0.013220098280726233, 0.10106250905664638, 0.20464857254410163, 1.200027500744909, 9.201564397662878, 6.02469309233129, 2.4089220631867647, 0.11452520891907625, 25.438985154032707, 78.24800044298172, 77.6375176012516, 82.37218514084816, 71.07558131217957, 71.97678655385971, 67.94840231537819, 73.85061800479889, 72.77945548295975, 78.71840760111809, 73.86386409401894, 71.54693081974983, 72.36482173204422, 73.8405941426754, 70.60901954770088, 74.01609152555466, 67.38689884543419, 68.57976883649826, 70.68270519375801, 67.01983094215393, 70.08815869688988, 70.78672081232071, 68.88630598783493, 60.23072004318237, 48.31472285091877, 52.94936075806618, 50.83311751484871, 53.36709514260292, 63.70802745223045, 65.73589503765106, 65.1445023715496, 70.91175690293312, 65.0977648794651, 66.34029060602188, 64.3587577342987, 69.30951967835426, 60.602146312594414, 62.05955430865288, 57.339280396699905, 65.70795133709908, 29.220272451639175, 49.94251750409603, 69.34687927365303, 68.96981030702591, 68.7639145553112, 64.80478540062904, 61.6081765294075, 57.42814242839813, 51.65333390235901, 50.469404831528664, 50.83796985447407, 46.25137276947498, 50.20466163754463, 46.88014402985573, 47.9902620613575, 48.86120952665806, 47.35832937061787, 48.04107293486595, 46.68616063892841, 47.997489273548126, 48.78683611750603, 48.46103020012379, 49.99460890889168, 50.35823419690132, 52.73754492402077, 54.6393770724535, 54.67235930263996, 57.08443187177181, 59.03135620057583, 57.123493775725365, 55.15548437833786, 58.942463770508766, 62.350687086582184, 63.02241884171963, 66.00772485136986, 64.78543683886528, 62.75706008076668, 61.562825962901115, 60.372159853577614, 62.586616426706314, 60.69917030632496, 64.23264250159264, 68.07542949914932, 55.65355405211449, 63.23666654527187, 24.756743162870407, 0.01080267560610082, 0.7636398577596992, 3.624017061665654, 5.871372744441032, 1.5636278525926173, 0.06350778086925857, 0.04733054229291156, 0.49391996988561004, 16.778704561293125, 40.700904205441475, 62.30877913534641, 21.686118431389332, 38.92138749361038, 47.80293211340904, 2.277480228804052, 0.4228041140595451, 0.06761190947145224, 0.03515998461807612, 0.04282719390175771, 0.06818652473157272, 0.05721321824239567, 0.030877629251335748, 0.008123516927298624, 0.06502255622763187, 0.03191017560311593, 0.025855686617433093, 0.05204653825785499, 0.02484038963302737, 0.04522139941400383, 0.09285963242291473, 0.02447734026645776, 0.02636575543874642, 0.0056742667857179185, 0.04405368570587598, 0.055456035188399255, 0.0056346105884585995, 0.02424305352178635, 0.0674148766847793, 0.03286953877250198, 0.06761330470908433, 0.05086206685518846, 0.08629702089820057, 0.1848298602271825, 0.11661695956718177, 0.1686863522627391, 0.14578633185010403, 0.12366469076368958, 0.1021861206390895, 0.06634570905589499, 0.11233568031457253, 0.11006443382939324, 0.1168365907506086, 0.13318635639734566, 0.1537481663399376, 0.19439256662735716, 0.09231592019204982, 0.1683654624503106, 0.1532783274888061, 0.18899381335359067, 0.2414548076922074, 0.11983702701400034, 0.14044534735148773, 0.1516398138483055, 0.19045094610191882, 0.17370181594742462, 0.14681583910714835, 0.20432305173017085, 0.16104735201224685, 0.19276563049061224, 0.09466653937124647, 0.14222485420759767, 0.14569696242688224, 0.23138187476433814, 0.4145093075931072, 16.224454902112484, 87.46104687452316, 50.69826275110245, 39.74434353411198, 70.21959364414215, 63.450549468398094, 9.7281638905406, 0.2243412533425726, 0.2123575276345946, 0.5220770230516791, 1.6468043206259608, 14.0601347386837, 29.663575664162636, 6.406307565048337, 1.3934252480976284, 0.1779471678310074, 24.43458314985037, 83.35611954331398, 77.09821254014969, 88.7204360961914, 73.67094844579697, 75.17090275883675, 72.57990539073944, 79.15923714637756, 76.1516909301281, 82.61259824037552, 76.2558813393116, 74.47549447417259, 73.80353093147278, 75.39966568350792, 73.41519176959991, 78.71864318847656, 70.49185663461685, 71.8984803557396, 71.5194582939148, 65.38642019033432, 71.27868801355362, 76.2031401693821, 74.65303614735603, 62.80100092291832, 52.54443548619747, 58.08017984032631, 53.498127311468124, 57.388544753193855, 66.88820600509644, 68.6740493774414, 68.09986978769302, 75.85828587412834, 68.1972661614418, 67.5998242199421, 65.5857726931572, 70.48473581671715, 62.35744692385197, 64.75753873586655, 58.86529751121998, 67.85016998648643, 33.0300772190094, 54.505540654063225, 71.45011201500893, 72.33457535505295, 70.8965577185154, 67.75270521640778, 65.22674515843391, 60.650168135762215, 56.29544600844383, 54.27546299993992, 53.14299836754799, 50.47155171632767, 51.45913392305374, 50.24006813764572, 51.80686466395855, 51.308855786919594, 48.75103443861008, 51.90220154821873, 50.270797088742256, 50.0726605206728, 50.477836579084396, 52.575711607933044, 54.35158811509609, 52.70818389952183, 55.76630540192127, 56.38178117573261, 56.246964409947395, 58.21572996675968, 62.190673872828484, 63.04132662713528, 58.830248191952705, 59.564197808504105, 62.388776242733, 65.6011314690113, 69.58346977829933, 63.2834230363369, 63.24495770037174, 66.74714997410774, 64.80495259165764, 65.4116128385067, 61.20393142104149, 67.17059165239334, 66.59624487161636, 60.481495186686516, 64.17480200529099, 23.069135919213295, 0.07157067360822111, 1.01538032758981, 4.796338705345988, 29.257117174565792, 6.626740861684084, 0.27412067516706884, 0.18363231589319184, 0.7892983965575695, 18.820764385163784, 57.74890221655369, 66.51038467884064, 36.371591314673424, 52.93148271739483, 57.73019582033157, 2.9561133636161685, 0.5814084643498063, 0.12618569220649078, 0.16044367424910888, 0.09928233426762745, 0.22597357747144997, 0.12224413847434334, 0.14931705489289016, 0.2582012809580192, 0.15469024860067293, 0.1490353950066492, 0.20949071506038308, 0.144932268303819, 0.12805808626580983, 0.11474349681520835, 0.10687062356737442, 0.12091000928194262, 0.10835738285095431, 0.12862717994721606, 0.1470701434300281, 0.19139500247547403, 0.08919946398236789, 0.11479733962914906, 0.15252589364536107, 0.15295623539714143, 0.09442459922865964, 0.13858061225619167], [0.05899579387914855, 0.032394549416494556, 0.0178940803380101, 0.06305714879999869, 0.03468852417427115, 0.053850220574531704, 0.021647252870025113, 0.06691492148092948, 0.11803993867943063, 0.025379986655025277, 0.06903977191541344, 0.03273542155511677, 0.04256005042407196, 0.024479460953443777, 0.054906782825128175, 0.04219088390527759, 0.0698790444585029, 0.020155716010776814, 0.04259067885868717, 0.05623817349260207, 0.04931533461785875, 0.0422051999339601, 0.08955894547398202, 0.016157796162588056, 0.08350710224476643, 0.04594091158651281, 0.016465598200738896, 0.05163414163689595, 0.08709218760486692, 0.03747484341147356, 0.011528076720423996, 0.07395699751214124, 0.11603079648921266, 0.3274067596066743, 27.859939746558666, 58.75201039016247, 39.035354778170586, 33.92208315432072, 68.48156690597534, 48.081867545843124, 7.962560132145882, 0.2839812351157889, 0.11209529868210666, 0.2634703810326755, 1.4948692359030247, 4.84965649433434, 11.413109377026558, 3.3836685586720705, 0.4744922061217949, 0.3258979436941445, 39.241664707660675, 83.55451449751854, 71.91517665982246, 77.80152440071106, 72.85805806517601, 70.6840731203556, 75.10038614273071, 72.45082631707191, 70.95147237181664, 70.56614264845848, 69.85748067498207, 70.82556992769241, 67.54794180393219, 66.20623379945755, 66.77089869976044, 68.5123984515667, 71.09013453125954, 74.75031092762947, 69.45758253335953, 65.20106613636017, 63.92376467585564, 63.01562860608101, 51.742830500006676, 45.866373628377914, 50.69656424224377, 49.412540942430496, 59.37967970967293, 62.01717518270016, 63.64185020327568, 64.26035821437836, 65.81443682312965, 64.45157155394554, 65.67027255892754, 63.46911907196045, 63.33453789353371, 62.96734839677811, 63.324958607554436, 56.383232697844505, 64.09730896353722, 39.43352781236172, 54.92946110665798, 69.82742428779602, 60.26839502155781, 62.30263106524944, 57.53239743411541, 60.36805607378483, 55.29815532267094, 54.65612657368183, 53.54632392525673, 52.592278718948364, 49.777268171310425, 48.90226632356644, 48.52992810308933, 47.36747927963734, 46.044044494628906, 48.56087364256382, 47.55634814500809, 48.148968145251274, 46.33674278855324, 48.25121305882931, 47.538622096180916, 51.35117031633854, 51.34850285947323, 51.54042296111584, 53.4118415415287, 52.930741757154465, 55.60599200427532, 54.55413244664669, 53.97664703428745, 56.16935737431049, 55.24884156882763, 61.50663837790489, 64.20742705464363, 66.48019149899483, 64.21671375632286, 65.43017864227295, 64.20770823955536, 61.396577283740044, 58.54017175734043, 67.93466225266457, 63.02494950592518, 54.372969567775726, 62.273726016283035, 24.920734763145447, 0.10726267792051658, 0.24505247245542705, 0.27523968543391675, 4.793828465044498, 2.7732631377875805, 0.3444921865593642, 0.09101666451897472, 0.7362010551150888, 12.06545077264309, 39.22493040561676, 46.88734844326973, 22.329868488013744, 33.95841680467129, 43.65984722971916, 8.586943577975035, 0.22241039288928732, 0.06089587746828329, 0.04475193163671065, 0.08469107269775122, 0.0431584440957522, 0.033856409645522945, 0.036102226440561935, 0.03066473491344368, 0.08071210730122402, 0.04458878160221502, 0.06155093040433712, 0.02291757962666452, 0.04224594755214639, 0.029686331945413258, 0.04256454783899244, 0.07738905202131718, 0.03907267622707877, 0.03054960925510386, 0.0723359317635186, 0.03015858277649386, 0.05200243984290864, 0.03277263655036222, 0.04476875612454023, 0.07812930722138844, 0.05262087521259673, 0.017425636724510696, 0.04802162649866659, 0.015706394115113653, 0.03363277457538061, 0.019771621191466693, 0.05549466026423033, 0.030134815497149248, 0.03277618030551821, 0.012411993157002144, 0.042100980135728605, 0.023727051229798235, 0.0369638747361023, 0.03883584948198404, 0.02074204050586559, 0.05974750041787047, 0.09648158025811426, 0.05578409414738417, 0.04348501504864544, 0.01839205957367085, 0.09639418494771235, 0.09330139582743868, 0.006930105428182287, 0.0675451458664611, 0.03223610088753048, 0.044497163471532986, 0.023386865577776916, 0.061222210933919996, 0.11204242066014558, 0.02501319129805779, 0.0058138791428064, 0.02103373422869481, 0.03044571785721928, 0.009953615062840981, 0.04949954309267923, 0.08277762302896008, 1.0251551843248308, 42.869637832045555, 66.05611145496368, 28.17157242447138, 43.27812731266022, 89.1260339319706, 44.64629329741001, 11.009359192103148, 0.5377626407425851, 0.07770127354888245, 0.026745519826363306, 0.6866738595999777, 2.1512968372553587, 12.256872151046991, 10.100904889404774, 1.3785729138180614, 0.3512817691080272, 47.70361304283142, 85.43118819594383, 76.62817776203156, 80.28983607888222, 75.77839136123657, 72.50357508659363, 76.8313604593277, 75.39402678608894, 74.10420879721642, 72.6627865433693, 73.07365089654922, 72.79600739479065, 70.51031604409218, 66.555115878582, 69.73602399230003, 71.3599656522274, 72.44099244475365, 71.72302097082138, 71.50286838412285, 67.0067748427391, 65.87832659482956, 65.54918825626373, 56.04718632996082, 49.04731594026089, 52.92818449437618, 50.55468365550041, 60.18614083528519, 66.55011534690857, 66.62529811263084, 68.32724958658218, 69.10024210810661, 65.65601572394371, 65.60563042759895, 66.8145203590393, 66.04460567235947, 62.67133288085461, 64.51257348060608, 55.238342732191086, 65.93383401632309, 40.352193117141724, 55.605463832616806, 69.93401616811752, 62.255023419857025, 65.40651351213455, 59.662194550037384, 60.96961319446564, 56.634501814842224, 55.588972717523575, 56.45305775105953, 54.67737503349781, 52.305215522646904, 49.673389345407486, 50.84592662751675, 51.06505326926708, 49.75227311253548, 49.83863107860088, 49.11768436431885, 50.427918657660484, 49.16896641254425, 50.06423257291317, 50.55129423737526, 52.76059448719025, 53.25996749103069, 51.90109580755234, 54.611178785562515, 54.55809563398361, 57.13769741356373, 56.50642588734627, 56.60104461014271, 58.78647454082966, 58.0723674595356, 62.15787783265114, 65.9360682964325, 67.14708611369133, 63.28627288341522, 63.68635341525078, 67.624781280756, 63.861448019742966, 62.245968505740166, 69.58701878786087, 67.35211551189423, 54.492454156279564, 65.41404470801353, 28.710385411977768, 0.22362147399690002, 1.0286781890317798, 0.9239341376814991, 0.33740328100975603, 1.0403958102688193, 0.6444564030971378, 0.08449033659417182, 0.5672205006703734, 17.878701835870743, 38.12868542969227, 62.14576408267021, 31.712144538760185, 32.26669818162918, 56.41280271112919, 13.593280389904976, 0.25498620816506445, 0.08074977129581384, 0.05803326173918322, 0.06362113650538959, 0.02562495104939444, 0.07160557681345381, 0.07174203550675884, 0.0038003272038622526, 0.07253848612890579, 0.05561070989642758, 0.035800907062366605, 0.0279394499011687, 0.013511509059753735, 0.03137590720143635, 0.04197829941404052, 0.05494613891642075, 0.03363329407875426, 0.02222454728325829, 0.01872528202511603, 0.035408908370300196, 0.022873171365063172, 0.008013769056560704, 0.044706066910293885, 0.08607733776443638, 0.03981410030974075, 0.021687577464035712, 0.029697655263589695, 0.173326111107599, 0.15580744802718982, 0.22734291414963081, 0.12476510280976072, 0.15380786469904706, 0.27381764142774045, 0.17064556275727227, 0.12421345702023245, 0.13646075647557154, 0.13081859360681847, 0.12802014767657965, 0.09588945773430169, 0.2200555583112873, 0.1394207085832022, 0.11806683411123231, 0.1106051032547839, 0.20439968589926139, 0.13711064035305753, 0.2528992888983339, 0.10412218354758807, 0.1635739640914835, 0.1285463897511363, 0.17668996966676787, 0.1337723562028259, 0.12190065026516095, 0.15986359678208828, 0.09159832276054658, 0.1701967415283434, 0.14400204556295648, 0.13825850532157347, 0.09314138136687689, 0.18338001536903903, 0.3559811372542754, 0.6691755610518157, 44.10008780658245, 80.79839318990707, 50.74227958917618, 46.29189759492874, 80.4852519929409, 66.44619092345238, 14.691904988139868, 0.46283692528959364, 0.3276411892147735, 0.6890677311457694, 5.074334163218737, 16.021885871887207, 24.55277770757675, 7.9993003606796265, 1.1055569699965417, 0.48098264378495514, 45.35993680357933, 92.36834675073624, 77.85576269030571, 80.27079150080681, 77.20604315400124, 75.41206061840057, 81.82139709591866, 78.08691188693047, 76.30601584911346, 74.90813925862312, 73.6333304643631, 75.20192429423332, 72.44913920760155, 67.41053357720375, 71.17374524474144, 70.26943176984787, 74.72751975059509, 74.5303863286972, 72.23014935851097, 73.12453016638756, 69.3572299182415, 68.04997086524963, 57.24390551447868, 50.972855016589165, 54.652030393481255, 53.313803002238274, 65.01395657658577, 71.39142036437988, 70.57324826717377, 73.17196682095528, 70.17371490597725, 70.22119715809822, 71.78166702389717, 70.68213522434235, 68.31086486577988, 68.12364891171455, 66.05034336447716, 57.11502023041248, 65.48048034310341, 45.939219519495964, 58.034985065460205, 72.9817870259285, 64.63857471942902, 67.20937997102737, 62.39783875644207, 63.94733861088753, 60.819331258535385, 60.17905801534653, 57.74639055132866, 57.282667234539986, 56.94793939590454, 51.79896488785744, 55.31125321984291, 55.122783333063126, 53.13148498535156, 53.19699726998806, 53.32558996975422, 54.410553351044655, 52.640102952718735, 54.28518667817116, 52.584158554673195, 54.6153699606657, 56.91683426499367, 54.092252030968666, 56.65627084672451, 56.766312941908836, 61.03040233254433, 60.57826839387417, 57.92979910969734, 62.156057730317116, 62.018828094005585, 68.0108405649662, 68.17315265536308, 69.72701847553253, 65.13764753937721, 66.0018427670002, 67.82609447836876, 66.50148555636406, 63.76901417970657, 71.83987990021706, 65.46024262905121, 62.43983030319214, 67.9605920612812, 26.425497718155384, 0.31826403457671404, 1.038285142276436, 0.6969594920519739, 12.654730752110481, 7.037132615223527, 1.0365339112468064, 0.30407191487029195, 0.8782070351298898, 20.670208744704723, 51.56776249408722, 59.004221856594086, 37.429272159934044, 45.11491075158119, 68.13333839178085, 16.231592819094658, 0.383817998226732, 0.411497731693089, 0.2401767551782541, 0.15106490172911435, 0.34395561378914863, 0.16593529988313094, 0.2137117096572183, 0.08565956057282165, 0.12863145471783355, 0.14053145132493228, 0.0930055312346667, 0.09252885720343329, 0.2337288871058263, 0.11731961014447734, 0.1364230108447373, 0.2041237850789912, 0.1683628500904888, 0.13879435078706592, 0.10841292518307455, 0.24909774132538587, 0.1032952380774077, 0.09142814087681472, 0.08953997617936693, 0.26265191088896245, 0.13106782163958997, 0.07046805738355033, 0.12068286014255136], [0.07223261738545261, 0.03534100927936379, 0.007799192826496437, 0.04532758961431682, 0.047476648906013, 0.03816638403804973, 0.03666308599349577, 0.047533441756968386, 0.022793451717006974, 0.03676130552776158, 0.03800159385718871, 0.03925741904822644, 0.10428979017888196, 0.016896194138098508, 0.019183665826858487, 0.05024108962970786, 0.0733981528901495, 0.08679106118506752, 0.04080097860423848, 0.028781429427908733, 0.051425531346467324, 0.02280241129483329, 0.04207845966448076, 0.035744700508075766, 0.02215692093159305, 0.023877282328612637, 0.06454251284594648, 0.015085958657437004, 0.025368334936501924, 0.04178807583230082, 0.033167314395541325, 0.009184885511785978, 0.061990385729586706, 0.16560648393351585, 2.5374853145331144, 41.29033997654915, 57.92743943631649, 34.57719840109348, 28.73726326972246, 72.77035117149353, 61.904442831873894, 17.051446326076984, 1.1955812643282115, 0.11454555118689314, 0.08430957168457098, 0.43575470976065844, 4.500685594975948, 9.727878905832767, 1.0807615192607045, 0.1260020848712884, 1.0274908714927733, 55.19174963235855, 92.96475514769554, 72.83499330282211, 77.85966888070107, 75.59718668460846, 72.4968646466732, 70.79064220190048, 73.56532171368599, 72.36837834119797, 69.0623277425766, 68.98974403738976, 69.39031094312668, 71.19808673858643, 74.16730061173439, 67.92625710368156, 71.39151155948639, 73.78962367773056, 65.96168652176857, 66.62966027855873, 68.25330555438995, 64.15957242250443, 54.760465174913406, 48.885638415813446, 52.19115324318409, 60.287610590457916, 64.09088730812073, 64.424007833004, 66.00102201104164, 63.97302523255348, 67.28875011205673, 67.6660318672657, 65.83434775471687, 60.62445871531963, 66.07168301939964, 60.459114387631416, 66.23622938990593, 62.19929181039333, 70.22162273526192, 31.813177317380905, 49.424046725034714, 75.26994064450264, 63.36281977593899, 65.47164961695671, 59.46267865598202, 59.043143168091774, 57.59571723639965, 58.705367892980576, 57.31027275323868, 57.32934013009071, 54.25324559211731, 48.91187600791454, 49.24263305962086, 50.250696167349815, 47.87403389811516, 48.32796134054661, 49.09147337079048, 48.57170306146145, 48.42079035937786, 47.75072291493416, 53.23317512869835, 54.9171307682991, 59.69962254166603, 60.343733578920364, 58.78515601158142, 57.02331215143204, 55.325954630970955, 54.9791244417429, 55.11782079935074, 53.61882783472538, 57.80926197767258, 60.98731644451618, 62.835974246263504, 66.3394546508789, 67.09438294172287, 65.07588565349579, 62.5152562558651, 66.54731869697571, 71.90709069371223, 57.367269694805145, 56.390615701675415, 63.17324034869671, 21.482348665595055, 0.06480359297711402, 0.24648305115988478, 0.5133195617236197, 1.2079763179644942, 0.6980718823615462, 0.09120776754571125, 0.10161433296161704, 0.9937201836146414, 19.082177057862282, 44.286798387765884, 54.31447550654411, 40.29952794313431, 24.673303440213203, 43.25190491974354, 20.970939807593822, 0.09543374937493354, 0.058758195300470106, 0.03695001141750254, 0.013189829787734197, 0.029636468898388557, 0.031816286500543356, 0.03340795577969402, 0.04559432120004203, 0.04877779334492516, 0.05633940614643507, 0.0329556946962839, 0.09320046374341473, 0.045596436320920475, 0.07078856870066375, 0.05393799066951033, 0.04107639331778046, 0.01809527657314902, 0.041156033184961416, 0.045320583740249276, 0.04201538824418094, 0.03875975336995907, 0.0197652016140637, 0.047141105387709104, 0.029244395991554484, 0.018763947919069324, 0.09885729145025834, 0.022535245552717242, 0.0101343623464345, 0.07326861843466759, 0.04218777801725082, 0.05928279351792298, 0.021047920381533913, 0.02546846921177348, 0.006846443120593904, 0.04051121446536854, 0.01486857525378582, 0.03334893277497031, 0.030532209602824878, 0.09789800620637834, 0.023285439965547994, 0.030299314385047182, 0.044751831446774304, 0.017794330124161206, 0.03905491663317662, 0.07010825676843524, 0.03787102039495949, 0.06918561877682805, 0.03534017436322756, 0.07609068692545407, 0.05872292102139909, 0.04938131525705103, 0.01748629245412303, 0.0271644788881531, 0.0476234048983315, 0.032546281508984976, 0.05746489165176172, 0.0391453065094538, 0.00935386233322788, 0.03417196712689474, 0.04094450254342519, 0.005199074730626307, 0.26422268128953874, 5.447141658514738, 55.93473516404629, 60.07006086409092, 29.048337377607822, 45.13114348053932, 90.63149034976959, 56.73467583954334, 17.490797750651836, 2.807017914019525, 0.08564833929995075, 0.09945610814611427, 0.3613769367802888, 1.9003523653373122, 12.508208714425564, 4.2261498514562845, 0.6978762522339821, 2.5620547961443663, 64.10695284605026, 91.76818415522575, 73.16945895552635, 81.38063594698906, 77.99477443099022, 76.82732507586479, 75.22884964942932, 76.29504963755608, 74.84521463513374, 68.66464868187904, 70.83242475986481, 70.28444856405258, 72.56952434778214, 73.87638822197914, 67.72955685853958, 71.37195780873299, 75.76566964387894, 69.6998955309391, 68.41165065765381, 71.73457995057106, 66.8398118019104, 55.93389920890331, 49.77365456521511, 55.36419577896595, 61.442197635769844, 67.19500914216042, 65.43311968445778, 67.1295614540577, 64.66253623366356, 68.61853435635567, 70.53132131695747, 69.88981693983078, 63.776279389858246, 68.15847784280777, 61.33251652121544, 66.04478806257248, 60.844645500183105, 70.42241916060448, 35.72482421994209, 52.35970839858055, 74.88406375050545, 66.09996870160103, 66.85924395918846, 61.789286211133, 63.40334080159664, 59.29408170282841, 59.69072341918945, 57.88129851222038, 58.94530601799488, 54.51945550739765, 49.86294597387314, 51.30974493920803, 52.16631397604942, 48.5761184245348, 51.53826467692852, 51.21534660458565, 51.792771220207214, 50.744935646653175, 50.59741236269474, 53.77654977142811, 58.49834360182285, 61.73712641000748, 62.2953886538744, 61.4021135866642, 58.66634398698807, 56.52569845318794, 56.905522271990776, 57.007436603307724, 56.611323058605194, 59.751197174191475, 64.39592733979225, 65.5402359366417, 67.8447362780571, 68.26564729213715, 64.88030254840851, 62.35609419643879, 67.42355927824974, 71.37628197669983, 62.0174677670002, 54.99322168529034, 67.26935595273972, 25.711483731865883, 0.2002971083857119, 0.6046027166303247, 1.4650787157006562, 0.8277475833892822, 0.44337457744404674, 0.06904960537212901, 0.2189037302741781, 1.1725277826189995, 24.524721913039684, 38.80352161824703, 53.81312280893326, 36.42356492578983, 23.94865572452545, 50.00000461935997, 29.959982559084892, 0.017739311006153002, 0.03740796477359254, 0.032599838596070185, 0.12254113113158382, 0.026178120097029023, 0.03647268058557529, 0.026158484724874143, 0.031567466648994014, 0.033485146559542045, 0.014979748975747498, 0.0608532262413064, 0.03688312164740637, 0.009102991371037206, 0.03557518284651451, 0.031612681996193714, 0.04698596312664449, 0.05578925949521363, 0.06210274688783102, 0.011647960473055718, 0.06591301469597965, 0.02709320488065714, 0.02422911042231135, 0.05591461194853764, 0.043289269888191484, 0.04786870696989354, 0.061644689631066285, 0.058154936850769445, 0.03305995531263761, 0.20814882300328463, 0.12979192135389894, 0.16884943179320544, 0.18647511256858706, 0.16242292273091152, 0.16934790270170197, 0.13893154420657083, 0.11372196022421122, 0.12781199009623379, 0.15740116563392803, 0.13829657749738544, 0.13204025774030015, 0.15387504390673712, 0.2584356808802113, 0.07310701577807777, 0.11344531725626439, 0.14937351748812944, 0.15126122947549447, 0.1611174998106435, 0.10550274149863981, 0.16352888604160398, 0.15687741717556491, 0.1517816976411268, 0.0750987471838016, 0.11208492345758714, 0.14372454170370474, 0.11748884207918309, 0.10766833584057167, 0.1599567214725539, 0.08376885030884296, 0.10993162650265731, 0.14821993798250332, 0.06773995221010409, 0.4031833918998018, 3.942058808170259, 63.38280290365219, 74.19276684522629, 48.05201634764671, 44.330849424004555, 81.30388766527176, 80.61667174100876, 26.623132713139057, 2.8196662478148937, 0.24483857065206394, 0.21133949398063123, 2.4080110620707273, 14.042505584657192, 21.6584350168705, 2.943546725437045, 0.5069465911947191, 2.3466260684654117, 60.53066074848175, 97.91755378246307, 78.95167708396912, 83.92011567950249, 80.807596296072, 79.995177090168, 78.47820729017258, 74.78140845894814, 76.93507969379425, 72.07906186580658, 72.98763871192932, 69.75869357585907, 71.58745184540749, 76.94441199302673, 71.58657029271126, 71.46297052502632, 76.13485783338547, 69.34262350201607, 70.11070668697357, 74.76707562804222, 70.88890492916107, 60.534137561917305, 53.61603118479252, 59.81891714036465, 68.50933581590652, 72.00435787439346, 69.87977027893066, 71.40300214290619, 69.59306046366692, 73.65539968013763, 74.12002354860306, 70.81725597381592, 66.2176787853241, 71.79604545235634, 62.36963286995888, 68.1856007874012, 65.78125700354576, 71.4565260708332, 37.38022059202194, 51.8150532245636, 79.20156687498093, 69.46214228868484, 71.67432278394699, 66.28634110093117, 66.40263766050339, 64.9820002913475, 62.87306785583496, 62.72791184484959, 62.32942342758179, 58.18399406969547, 52.04309418797493, 53.7863190472126, 55.01138851046562, 52.38128364086151, 54.086214154958725, 54.0716153383255, 55.36212868988514, 53.933910727500916, 51.15886643528938, 58.9725087583065, 61.80934153497219, 65.97066923975945, 66.98599755764008, 64.70773100852966, 61.59998416900635, 59.701032266020775, 61.127232536673546, 61.645585522055626, 61.009169071912766, 62.26924225687981, 64.67967331409454, 68.06661397218704, 68.58022481203079, 68.17849516868591, 63.48801165819168, 63.568844720721245, 68.34976717829704, 72.58524790406227, 61.6257543861866, 64.58303689956665, 66.9652658700943, 22.254809215664864, 0.2784284861991182, 0.918818365316838, 1.5394961787387729, 4.182363850995898, 4.696227852255106, 0.34346496511716396, 0.3263717604568228, 1.10548049909994, 30.21123267710209, 55.9900563955307, 65.61762258410454, 51.76570147275925, 35.00773809850216, 60.5744381994009, 36.614158898591995, 0.16602048359345645, 0.1541734318016097, 0.2076974042574875, 0.14837642724160105, 0.1485238177701831, 0.14106636168435216, 0.1206640615419019, 0.09495581369264983, 0.09077124370378442, 0.10894238075707108, 0.14628527773311362, 0.2174317991011776, 0.10210692606051452, 0.25383534491993487, 0.10798345174407586, 0.21227090415777639, 0.09922195313265547, 0.15778524189954624, 0.13305314088938758, 0.10285979777108878, 0.11518460712977685, 0.1256896703853272, 0.08837696397677064, 0.10157642405829392, 0.08254276297520846, 0.23680623213294894, 0.09735028637805954, 0.0843995570903644], [0.08561644921428524, 0.07688185345614329, 0.005588503736362327, 0.02191199549997691, 0.081232300872216, 0.025889172320603393, 0.0043588656899373746, 0.015888834423094522, 0.023227641504490748, 0.018858145012927707, 0.013791717119602254, 0.031650620585423894, 0.05814747455588076, 0.06339634739561006, 0.053153596236370504, 0.08304786868393421, 0.05117737571708858, 0.02800170495902421, 0.04894130332104396, 0.05528842484636698, 0.038656131000607274, 0.08592569472966716, 0.03743081550055649, 0.05020319556933828, 0.0759070276399143, 0.005737268165830756, 0.040196120826294646, 0.020083694289496634, 0.03590372791222762, 0.05212996307818685, 0.023073254378687125, 0.011630498665908817, 0.026025493716588244, 0.019665186082420405, 0.17378655436914414, 4.233435960486531, 44.80224072933197, 47.26442500948906, 35.78611113131046, 23.267593570053577, 61.9333440810442, 67.58374348282814, 26.047342009842396, 2.440296742133796, 0.1127000006090384, 0.1455826123128645, 0.3889389062533155, 10.716113727539778, 5.094205196946859, 0.05501895473571494, 0.14836633403319865, 2.549762693233788, 54.22753997147083, 88.43069404363632, 74.7313879430294, 72.76459068059921, 77.97657340765, 72.89050072431564, 70.84311738610268, 69.60445985198021, 71.69857308268547, 72.49622628092766, 70.46749994158745, 70.11728793382645, 70.18582105636597, 69.5921865105629, 79.74132031202316, 71.80628970265388, 70.56798934936523, 66.08112171292305, 70.7019017636776, 60.18570385873318, 49.36351977288723, 49.16500702500343, 58.70404936373234, 68.03199023008347, 69.22473102807999, 65.76115608215332, 64.35673624277115, 67.42701709270477, 67.37220883369446, 68.74746143817902, 68.9610555768013, 64.07819598913193, 68.60159486532211, 65.70398434996605, 63.2014462351799, 64.46300894021988, 69.26532045006752, 32.89466768503189, 55.12519620358944, 73.46528068184853, 64.54827636480331, 67.04674109816551, 62.91898839175701, 61.29575729370117, 59.34600971639156, 59.43530112504959, 59.84502553939819, 59.732186794281006, 51.83347463607788, 49.477205872535706, 48.36492955684662, 50.81017814576626, 48.58961910009384, 51.72148324549198, 49.79038506746292, 50.23551218211651, 50.91310702264309, 50.91484732925892, 53.998480662703514, 58.805500119924545, 61.387746557593346, 62.23139628767967, 63.77305716276169, 65.57302817702293, 65.0442485511303, 62.51603901386261, 60.81645481288433, 57.9295901209116, 58.58773000538349, 66.35040566325188, 65.2889858186245, 69.21535313129425, 65.4190756380558, 64.4856633245945, 67.55516141653061, 59.812879264354706, 60.47262266278267, 63.066716864705086, 57.291079983115196, 14.853480868041515, 0.09057236296939664, 0.40252068371046335, 0.04534769439487718, 0.5024756561033428, 1.516483307350427, 0.06318778163404204, 0.22989887074800208, 1.4558325055986643, 19.35962677001953, 52.742602452635765, 39.79640834033489, 65.826056599617, 63.96737113595009, 36.740410923957825, 39.37414839863777, 0.5894746596459299, 0.05405562107625883, 0.043801169958896935, 0.039014335998217575, 0.029577254790638108, 0.09610926703317091, 0.01827076295739971, 0.034643108447198756, 0.0035825439681502758, 0.044472973168012686, 0.050607287557795644, 0.01288329774979502, 0.04128308515646495, 0.04250785888871178, 0.09462071175221354, 0.02880266783904517, 0.057002288740477525, 0.04570926874293946, 0.026487471368454862, 0.06154366477858275, 0.022798832287662663, 0.03260647710703779, 0.017978720425162464, 0.04443135352630634, 0.03628175938501954, 0.06331297452561557, 0.029069644333503675, 0.02288594001583988, 0.08354495919775218, 0.04462060489458963, 0.07221174819278531, 0.06432277776184492, 0.01753227592416806, 0.03409891010960564, 0.062273054936667904, 0.07332850975217298, 0.03886675993271638, 0.03459333260252606, 0.04816622655198444, 0.03858907424728386, 0.006423931490644463, 0.052338944442453794, 0.037125666640349664, 0.04987141473975498, 0.012350380056886934, 0.05714903731131926, 0.012698754380835453, 0.0954600065597333, 0.036389990491443314, 0.0330882868001936, 0.04681873870140407, 0.040814203675836325, 0.07102519506588578, 0.016026499106374104, 0.058346663281554356, 0.016646249932819046, 0.0190790897977422, 0.039528414272353984, 0.10016046566306613, 0.04330396441218909, 0.05441425651952159, 0.02794083957269322, 0.004618711536750197, 0.21782801690278575, 10.609305258840322, 60.83875961601734, 51.15212939679623, 27.700141221284866, 38.885331228375435, 87.44995906949043, 72.83209785819054, 23.890819028019905, 4.409026438370347, 0.08967161833425052, 0.08459451928501949, 0.1715268037514761, 3.764526634477079, 9.479092955589294, 1.193337484728545, 0.20165463007288054, 3.9001138089224696, 63.6721383780241, 88.02654013037682, 75.718734562397, 74.77427244186401, 78.93800541758537, 75.87834119796753, 72.37009584903717, 68.11484858393669, 73.66234570741653, 71.40854984521866, 69.69570055603981, 69.86940443515778, 73.44841718673706, 71.47857248783112, 81.88375934958458, 72.86114349961281, 68.73160108923912, 68.87821242213249, 72.1711765229702, 62.90195770561695, 53.77444468438625, 51.101147532463074, 59.992780610919, 68.70054915547371, 71.52553036808968, 68.6967645585537, 68.00229862332344, 68.96329745650291, 72.99596786499023, 71.23907893896103, 67.4041423201561, 64.53681617975235, 68.95967245101929, 65.27315586805344, 64.8169219493866, 64.82073694467545, 70.62260001897812, 33.60951192677021, 54.89315025508404, 73.27890068292618, 66.69440880417824, 69.1834044456482, 64.13004040718079, 62.596993669867516, 61.51615306735039, 60.051115080714226, 62.47554838657379, 61.358290538191795, 54.34895485639572, 51.06393612921238, 50.15462972223759, 51.57011076807976, 51.020477861166, 53.2494230568409, 51.59599117934704, 53.21634583175182, 51.655689775943756, 52.1098680049181, 56.56423978507519, 59.62014980614185, 62.03689992427826, 63.5762695223093, 65.41636258363724, 68.297588378191, 65.95603242516518, 64.11672592163086, 61.348867043852806, 61.58158555626869, 60.94010777771473, 68.76179426908493, 67.03519731760025, 70.80601617693901, 67.10442960262299, 65.99998846650124, 67.08829566836357, 64.61628511548042, 61.96380704641342, 62.018630504608154, 62.53248833119869, 18.29266682267189, 0.03849168220767751, 0.5143146333284676, 0.2189604748855345, 0.9474845021031797, 0.7148813491221517, 0.033527927662362345, 0.26789408584591, 2.5370184145867825, 23.261846378445625, 50.24788811802864, 49.93720158934593, 69.40137594938278, 63.67947578430176, 38.35542306303978, 51.111156195402145, 1.4389020390808582, 0.15069237328134477, 0.029703011714445893, 0.020847438463533763, 0.0264179247096763, 0.034318307516514324, 0.03253460381529294, 0.026883284699579235, 0.02738482809945708, 0.055924003827385604, 0.018514400762796868, 0.0658354751067236, 0.024195914156734943, 0.05699717905372381, 0.01057182407748769, 0.04412254587805364, 0.04552674865408335, 0.038344232307281345, 0.05521263672562782, 0.039579403528478, 0.0540506709512556, 0.0510037465573987, 0.05533909497899003, 0.05978695669909939, 0.06726835446897894, 0.03170890886394773, 0.05313622626999859, 0.012107847123843385, 0.09159902037936263, 0.1194602609029971, 0.228933010075707, 0.2455894014565274, 0.1258954085642472, 0.17123576311860234, 0.19442508753854781, 0.11296476921415888, 0.07753426805720665, 0.1625692890956998, 0.08000559755600989, 0.06107676112151239, 0.08531575324013829, 0.12480238830903545, 0.0782075741153676, 0.12132701463997364, 0.1620721392100677, 0.1531837778748013, 0.17209721845574677, 0.13659438758622855, 0.17086161678889766, 0.19739522191230208, 0.19691138615598902, 0.15480008645681664, 0.16092305711936206, 0.09405261254869401, 0.14824290003161877, 0.11611503767198883, 0.11463961098343134, 0.13867992645828053, 0.16504317900398746, 0.18947012373246253, 0.13989839935675263, 0.16587417660048231, 0.10643360990798101, 0.3587447467725724, 8.14458841457963, 70.0297786295414, 65.00259518623352, 48.625002801418304, 35.76531104743481, 70.11560842394829, 84.17605474591255, 38.84116619825363, 5.31027015298605, 0.28478127031121403, 0.32776619656942785, 2.125173001550138, 21.388345509767532, 16.49747595191002, 0.501039867522195, 0.22521060513099656, 3.8755671260878444, 60.033860206604004, 91.60997584462166, 78.41892287135124, 74.72131088376045, 80.76047122478485, 78.51856872439384, 72.72175177931786, 70.67838102579117, 74.69329118728638, 75.02131998538971, 68.65016385912895, 72.21416741609573, 73.9362882077694, 69.83623221516609, 81.25775054097176, 75.59251293540001, 75.03869265317917, 73.01228418946266, 75.74090257287025, 64.7671066224575, 56.04170702397823, 53.67202877998352, 64.16082635521889, 72.58869051933289, 75.69491744041443, 73.49890127778053, 72.7099572122097, 73.4671425819397, 74.21537563204765, 75.5785296857357, 72.55802616477013, 66.74512848258018, 71.47096529603004, 68.97937059402466, 65.77941790223122, 66.72757342457771, 70.45855522155762, 39.61806111037731, 59.56786461174488, 76.46809235215187, 66.99411392211914, 72.92734354734421, 68.6055314540863, 65.18509939312935, 64.2346715927124, 64.08910140395164, 64.17391285300255, 65.07904708385468, 58.09251017868519, 55.41657976806164, 54.11975875496864, 55.516461208462715, 54.29663926362991, 57.17813864350319, 56.00162297487259, 56.481202840805054, 56.61734573543072, 57.53886468708515, 58.67569148540497, 61.19583785533905, 63.91130894422531, 64.97134566307068, 67.80934497714043, 69.95353952050209, 69.96984824538231, 66.59064397215843, 64.59807649254799, 62.035756185650826, 64.93700310587883, 72.10192903876305, 70.77529862523079, 72.64447152614594, 68.33057060837746, 66.1758354306221, 68.45072776079178, 60.378231927752495, 65.18963634967804, 69.21966210007668, 59.33410495519638, 15.558002013713121, 0.31991661933716387, 0.9738689207006246, 0.12413542019203305, 3.4096180787310004, 6.659797187894583, 0.17145037738373503, 0.610429763328284, 2.312637842260301, 32.0049112290144, 64.29841697216034, 50.640490651130676, 75.36246567964554, 68.66791650652885, 50.67668370902538, 60.756885409355164, 1.8032603315077722, 0.20271248737117276, 0.16738717822590843, 0.17611096089240164, 0.09711803126265295, 0.15927044267300516, 0.13168641657102853, 0.08389323425944895, 0.1628822082420811, 0.06616009050048888, 0.1141874871973414, 0.18732862692559138, 0.1302310501341708, 0.07758028121315874, 0.18758517253445461, 0.11343195117660798, 0.10068935720482841, 0.12522676319349557, 0.17839373293099925, 0.1649248955072835, 0.11851005954667926, 0.16831425426062196, 0.1640195940854028, 0.17633848852710798, 0.24808626825688407, 0.16483350744238123, 0.1519925269531086, 0.12468702887417749, 0.17223656410351396], [0.05686051998054609, 0.04935758879582863, 0.032252101591438986, 0.0237931005176506, 0.04459678566490766, 0.0750727200647816, 0.0024355067262149532, 0.03993903716036584, 0.010538093465584097, 0.054839317890582606, 0.05371356521209236, 0.027344356931280345, 0.030908309636288323, 0.08146763590048067, 0.057813255771179684, 0.039120555884437636, 0.0026512921931498568, 0.06934348100912757, 0.07028388601611368, 0.012275753397261724, 0.05464479727379512, 0.01699235235719243, 0.02170104744436685, 0.05977962056931574, 0.021326704445527866, 0.05850457004271448, 0.04047303467814345, 0.006407615373973385, 0.004588744541251799, 0.036685918166767806, 0.06561552479979582, 0.04534599487669766, 0.022752201293769758, 0.02121618566889083, 0.025281210510001983, 0.07725156174274161, 2.3032858315855265, 42.23651200532913, 50.22353142499924, 37.2954623401165, 28.226211592555046, 46.37361221015453, 73.63526076078415, 46.88495457172394, 6.970884120091796, 0.050248088082298636, 0.082936902763322, 0.15450371720362455, 6.005655163899064, 6.703229332342744, 0.21021135529736057, 0.3585564490640536, 1.385690881870687, 37.63211667537689, 84.64529916644096, 80.95467120409012, 70.41148334741592, 76.56469076871872, 78.87973174452782, 76.8089796602726, 72.16998338699341, 69.77348238229752, 70.93109026551247, 73.23917761445045, 74.74303811788559, 79.32427749037743, 70.38029462099075, 64.62253198027611, 68.95767375826836, 67.20485061407089, 73.04549440741539, 54.91346776485443, 51.627381294965744, 54.008101746439934, 68.12904462218285, 70.8455416560173, 67.86415323615074, 68.97252336144447, 67.90684774518013, 64.88408714532852, 68.4489494562149, 68.86240527033806, 68.86042937636375, 66.26740291714668, 62.97175616025925, 62.729830741882324, 60.78230984508991, 54.91200864315033, 62.86579504609108, 32.56620950996876, 53.08676138520241, 72.31182977557182, 65.72893381118774, 69.41698551177979, 66.23940601944923, 66.00914597511292, 66.91666647791862, 66.38151839375496, 63.436273634433746, 61.02121822535992, 51.892588064074516, 51.21648274362087, 49.6814639121294, 49.11201126873493, 49.76903781294823, 50.45690730214119, 48.8771116733551, 49.49551708996296, 49.72300708293915, 50.30053809285164, 58.3150490373373, 63.73144939541817, 66.31309166550636, 68.39545592665672, 67.40861847996712, 65.39170950651169, 65.12262314558029, 65.54546445608139, 65.6016406416893, 67.25323721766472, 65.9181560575962, 62.57119305431843, 63.55206862092018, 69.73674595355988, 69.4330358505249, 57.18996740877628, 56.67630337178707, 56.54669992625713, 66.85390144586563, 41.30263991653919, 6.134132919833064, 0.035369867691770196, 0.1822975039249286, 0.08643432563985698, 0.6275463604833931, 1.1356594297103584, 0.08680160710355267, 0.2952866972191259, 2.4514481937512755, 28.809254206717014, 56.252572908997536, 59.97068479657173, 22.99771875143051, 30.71276966482401, 37.327323630452156, 40.4714535176754, 5.206893850117922, 0.22505129571072757, 0.06198086397489533, 0.050884750598925166, 0.056775469856802374, 0.016536508555873297, 0.07073864442645572, 0.0076317508592183, 0.09080862568225712, 0.02462371405272279, 0.03786042994761374, 0.03689212760946248, 0.009631038719817298, 0.032816879684105515, 0.04809478370589204, 0.0418105888820719, 0.02325873007066548, 0.0688068191811908, 0.06252205290365964, 0.0644722166180145, 0.01827476869948441, 0.0254743080586195, 0.037749419498140924, 0.050641496854950674, 0.04961027894751169, 0.03666038086521439, 0.11240179825108498, 0.0766519435273949, 0.03001075252541341, 0.0536172604188323, 0.07528920454205945, 0.019477741843729746, 0.06267555130762048, 0.07391999402898364, 0.03731381591933314, 0.05547416956687812, 0.030240827582019847, 0.03803632265771739, 0.009960968818631954, 0.020598427508957684, 0.09294623363530263, 0.023465164013032336, 0.011623777591012185, 0.015961028693709522, 0.02245968749775784, 0.0503070554259466, 0.01851266042649513, 0.012893484654341592, 0.00973411746599595, 0.04078507437952794, 0.03912122381734662, 0.04258052627847064, 0.03523761326505337, 0.048437188379466534, 0.03697606451169122, 0.057710331020643935, 0.022900890580785926, 0.05285025450575631, 0.055987223677220754, 0.017092130401579197, 0.04806361350347288, 0.05901250333408825, 0.018490837574063335, 0.07596936804475263, 0.04847195799811743, 0.09823086686083116, 8.807099014520645, 57.538480907678604, 52.813913226127625, 26.225326359272003, 30.979251265525818, 71.00682020187378, 76.59798458218575, 39.58103969693184, 8.228185828775167, 0.07121985297999345, 0.08892476544133388, 0.3294637257931754, 1.942899632267654, 2.168329185806215, 1.119146109558642, 0.19973552523879334, 3.2970025716349483, 49.118695110082626, 84.97552424669266, 76.92353591322899, 71.36011004447937, 76.45941361784935, 79.10547763109207, 77.26426362991333, 72.70494908094406, 71.83206751942635, 72.02824339270592, 74.35206189751625, 74.53521206974983, 76.25589653849602, 74.9831548333168, 68.19345116615295, 74.924835562706, 71.980289965868, 74.17198956012726, 58.20387840270996, 52.96068795025349, 55.296156629920006, 70.96560001373291, 70.88366121053696, 71.3332986831665, 68.57330918312073, 69.460219591856, 69.38469484448433, 70.07919877767563, 69.97664228081703, 70.8011144399643, 66.40130013227463, 66.11506149172783, 63.378467336297035, 63.13936896622181, 59.55722138285637, 64.37112227082253, 35.94905398786068, 54.00368258357048, 74.1482712328434, 68.26516851782799, 70.95054522156715, 67.76646047830582, 69.22951877117157, 68.38877588510513, 67.33016029000282, 63.77585381269455, 61.80291227996349, 52.7436587959528, 53.05623762309551, 49.987051114439964, 50.79122856259346, 52.49178931117058, 50.399218797683716, 51.23855575919151, 51.75203740596771, 52.25201837718487, 53.88448677957058, 57.7742924541235, 63.946213871240616, 67.52927720546722, 70.42751088738441, 70.101807564497, 67.92316406965256, 66.6583639383316, 68.02820563316345, 67.58493661880493, 68.27868059277534, 67.95855537056923, 66.00736767053604, 66.04036509990692, 71.5624263882637, 68.79003435373306, 59.255395978689194, 59.11090113222599, 58.328196331858635, 70.22259548306465, 46.60313129425049, 8.84342696517706, 0.15236196806654334, 0.4560436320025474, 0.4137713456293568, 0.21319323044735938, 0.6985880015417933, 0.15436247165780514, 0.4691501084016636, 3.1959260953590274, 29.06499568372965, 54.37077708542347, 69.98687893152237, 26.79779414087534, 35.920528918504715, 45.820240303874016, 50.74768669903278, 8.222241047769785, 0.32023226958699524, 0.10637306550052017, 0.07513031814596616, 0.028985779790673405, 0.025375120021635666, 0.019898151804227382, 0.006910161137057003, 0.06672707648249343, 0.005038530562160304, 0.024700008689251263, 0.06072498312278185, 0.012265779860172188, 0.04347202746430412, 0.06446216051699594, 0.04508114834607113, 0.03993703707237728, 0.05502324063854758, 0.04238685542077292, 0.01743966517096851, 0.0028047490832250332, 0.01416071016137721, 0.019570395270420704, 0.050844722863985226, 0.045701016060775146, 0.018813057686202228, 0.06892021192470565, 0.08058604609686881, 0.0366290622332599, 0.06545351396198384, 0.1747423515189439, 0.21718602947657928, 0.11692384505295195, 0.16012379375752062, 0.10832005282281898, 0.21559235639870167, 0.11147590223117732, 0.1119748258497566, 0.12079000400262885, 0.13380509975831956, 0.11171245438163169, 0.16691842291038483, 0.09833864154643379, 0.19945871899835765, 0.14255226007662714, 0.10717854063841514, 0.13320957077667117, 0.14180160738760605, 0.18610368249937892, 0.2334015999804251, 0.21094011462992057, 0.12237791801453568, 0.14573089341865852, 0.18717074242886156, 0.10741352685727179, 0.166225791326724, 0.18629325670190156, 0.25947620160877705, 0.11730812169844285, 0.11831324940430932, 0.18960651563247666, 0.16428700473625213, 0.12751290458254516, 0.14932704420061782, 0.12873023457359523, 0.25919186999090016, 6.26227249391377, 67.34850570559502, 71.50001853704453, 50.14775589108467, 39.57115262746811, 62.513523548841476, 86.48232579231262, 62.57252298295498, 13.547785431146622, 0.187967749661766, 0.3182350017596036, 0.6753259466495365, 16.091813519597054, 19.239287227392197, 0.951521429233253, 0.8523292955942452, 2.411856218241155, 43.513976857066154, 87.93197840452194, 81.29171311855316, 69.57499623298645, 77.0453953742981, 78.60261261463165, 77.57764041423798, 73.07370409369469, 70.9239998459816, 72.34315529465675, 75.38306817412376, 77.7869863808155, 78.50474506616592, 75.81872999668121, 69.48815569281578, 73.39294776320457, 74.08836364746094, 79.16755869984627, 61.177937015891075, 57.19257406890392, 60.74152663350105, 76.14373415708542, 76.53608590364456, 73.74816790223122, 72.3021174967289, 72.2986900806427, 70.50007179379463, 73.7602436542511, 74.05934080481529, 73.29063445329666, 69.78327825665474, 67.09084153175354, 64.10737082362175, 65.70821732282639, 59.46040637791157, 66.93239003419876, 38.47561441361904, 54.25429053604603, 73.45672354102135, 70.842365026474, 73.52369874715805, 72.24648088216782, 75.22532343864441, 74.82465773820877, 70.23801505565643, 68.43512579798698, 64.54509973526001, 57.091533690690994, 54.801966547966, 52.105524837970734, 52.230963706970215, 55.61136111617088, 53.022461235523224, 53.84946785867214, 55.34886360168457, 55.20086534321308, 55.36722421646118, 62.62934133410454, 70.05641520023346, 72.20088332891464, 75.94947338104248, 75.48868730664253, 70.97164928913116, 68.82303938269615, 70.65596222877502, 70.97935527563095, 72.65479937195778, 70.42515501379967, 66.47779762744904, 69.81130555272102, 72.49025300145149, 67.63140052556992, 61.31450928747654, 64.66741517186165, 67.5047305226326, 72.73240640759468, 42.02195651829243, 7.602813011035323, 0.2656512561952695, 0.49765300238505006, 0.39795623801182956, 3.4456004854291677, 3.1483018258586526, 0.2868873963598162, 0.5482681863941252, 3.989391205832362, 44.120595306158066, 65.39310023188591, 72.22386449575424, 35.33548191189766, 39.36634361743927, 52.00448825955391, 60.076531916856766, 8.19484831765294, 0.3468178992625326, 0.19816902960883453, 0.20880384254269302, 0.22692008293233812, 0.16399808664573357, 0.15994714776752517, 0.13500902656232938, 0.19147454586345702, 0.11607936263317242, 0.14469593879766762, 0.07353288980084471, 0.1509990287013352, 0.2351857823668979, 0.08350857911864296, 0.170946266152896, 0.1674984410055913, 0.15449389116838574, 0.1609372766688466, 0.17688856838503852, 0.1100123647483997, 0.08992670933366753, 0.2093107590917498, 0.15601158316712826, 0.19642421073513106, 0.08270271064247936, 0.15976110618794337, 0.11549601229489781, 0.1119720353744924, 0.21017822582507506], [0.005190899046283448, 0.05774668883532286, 0.056748570714262314, 0.06798593705752864, 0.014067126267036656, 0.02665296102350112, 0.05355796281946823, 0.026965679790009744, 0.08001226204214618, 0.0313732837093994, 0.03752809621801134, 0.0639191830123309, 0.022794167889514938, 0.03265808234573342, 0.01278290743357502, 0.010209242263954366, 0.04654861921153497, 0.025143523562292103, 0.05818102705234196, 0.018810356268659234, 0.05720373730582651, 0.01691686480626231, 0.007739941147519858, 0.025158665230264887, 0.11480892455438152, 0.03163433415465988, 0.08314013248309493, 0.03957328823162243, 0.0336870218598051, 0.01724250065308297, 0.05353460001060739, 0.03687462776724715, 0.05224406086199451, 0.04426716077432502, 0.10295244748704135, 0.012948140119988238, 0.018065340191242285, 1.5972293308004737, 33.73311549425125, 48.56220357120037, 54.19890470802784, 33.611658811569214, 42.89006553590298, 74.16304484009743, 66.78713142871857, 14.9420284666121, 0.10739160381490365, 0.12186685285996646, 0.7147560745943338, 1.354530060198158, 0.5858503072522581, 0.09149405101197772, 0.1492422167211771, 0.09018136246595532, 18.39494403451681, 67.93491303920746, 87.99255475401878, 75.2639901638031, 67.17807725071907, 68.5544165968895, 75.21672829985619, 72.14565709233284, 74.83553275465965, 71.73500552773476, 74.24977138638496, 72.43947252631187, 69.16392669081688, 76.63734287023544, 73.02059814333916, 70.4630009829998, 59.90456834435463, 50.2396235615015, 49.9915386736393, 56.732129976153374, 71.67278006672859, 73.7459184229374, 70.91168850660324, 70.93756511807442, 69.75487858057022, 66.29680573940277, 68.40722769498825, 70.64226016402245, 68.86478394269943, 69.02657926082611, 67.11681693792343, 69.24593389034271, 55.590625628829, 58.42202089726925, 66.61816209554672, 28.56152269989252, 37.70486377179623, 66.8529286980629, 69.4555002450943, 70.47746300697327, 71.26685544848442, 68.72589379549026, 67.75713577866554, 66.93514868617058, 65.20988926291466, 55.32566964626312, 49.52981024980545, 51.0469738394022, 50.925786942243576, 57.732031121850014, 59.277290403842926, 60.08361853659153, 54.972964972257614, 53.32167237997055, 51.73480153083801, 52.000737860798836, 52.85489782691002, 61.411791667342186, 64.32009860873222, 65.5855143070221, 67.62917384505272, 71.00440353155136, 69.38721030950546, 68.82277339696884, 71.54300183057785, 69.44940537214279, 67.51951932907104, 69.0540973842144, 71.7473016679287, 72.1714349091053, 66.11962884664536, 67.82654285430908, 74.44929108023643, 45.766799971461296, 15.913273449987173, 0.37823698832653463, 0.04687455191742629, 0.03355414773977827, 0.23383992724120617, 0.3328052902361378, 0.21928399190073833, 0.08039113585255109, 0.11244409324717708, 4.135712329298258, 44.97088707983494, 53.74506466090679, 38.91040988266468, 24.438601434230804, 34.31060090661049, 44.95984107255936, 34.5283368229866, 3.334173602052033, 0.08577274551498704, 0.07902001801994629, 0.02898310991440667, 0.042613384866854176, 0.06704527972033247, 0.07296898373169824, 0.07879295051679946, 0.020126638664805796, 0.038204801312531345, 0.042697203025454655, 0.035704876863746904, 0.052910735830664635, 0.04992196612874977, 0.058634854067349806, 0.04763156481203623, 0.10690396826248616, 0.08029618547880091, 0.025455158793192822, 0.0034716863547146204, 0.02364080439292593, 0.056034012377494946, 0.08257857160060667, 0.02986408373544691, 0.06257441884372383, 0.09020155630423687, 0.006505239798570983, 0.0268043257528916, 0.054468603993882425, 0.004426458644957165, 0.0532635713898344, 0.05827858236443717, 0.037127503455849364, 0.037059337191749364, 0.030908882945368532, 0.02880410203943029, 0.07205070214695297, 0.020074270869372413, 0.051424510893411934, 0.09094608627492562, 0.07814820230123587, 0.046086038564681076, 0.03611238644225523, 0.006427148700822727, 0.03678699125885032, 0.0325398582208436, 0.01701669109024806, 0.026446480696904473, 0.060884099584654905, 0.08085599489277229, 0.024704461575311143, 0.051597197525552474, 0.03485403423837852, 0.01599970943061635, 0.061956669960636646, 0.06571506164618768, 0.025557471271895338, 0.07438556553097442, 0.005235528096818598, 0.02208039066317724, 0.01052549550877302, 0.07925369063741527, 0.019151321175741032, 0.10762529869680293, 0.033095155376940966, 0.02321495263458928, 0.057837264248519205, 0.08888990676496178, 8.63871295005083, 50.73393523693085, 52.29837968945503, 37.49227657914162, 26.74133487045765, 60.79169914126396, 89.12036463618279, 65.49688786268234, 12.976825218647718, 0.31370089505799115, 0.07930909196147695, 0.4020723671419546, 1.0940777859650552, 0.7750657259020954, 0.5143808922730386, 0.4311060451436788, 0.45286637905519456, 26.969613321125507, 74.62804108858109, 84.80915397405624, 74.91234183311462, 67.43480667471886, 70.34340620040894, 74.21491205692291, 71.18417948484421, 73.23798447847366, 71.1113677918911, 74.29846197366714, 78.5570378601551, 72.65038400888443, 76.91329166293144, 72.93936610221863, 70.58798387646675, 64.65718612074852, 53.04543860256672, 51.85540705919266, 59.89424429833889, 74.35297384858131, 75.42988166213036, 72.9914765059948, 73.31522673368454, 72.13605120778084, 68.28512504696846, 71.60689920186996, 73.4491391479969, 69.88540917634964, 69.69761565327644, 64.8851890861988, 69.04126927256584, 59.03766766190529, 56.38316810131073, 64.4878064095974, 31.616807654500008, 41.31042569875717, 66.90085932612419, 68.10981005430222, 71.55395284295082, 73.49092930555344, 68.99016201496124, 70.69925710558891, 68.78267794847488, 68.93372744321823, 58.600827902555466, 51.90258912742138, 53.21405075490475, 53.04448865354061, 56.63785323500633, 59.165040627121925, 59.6552599221468, 55.0340960919857, 55.284673646092415, 53.11176784336567, 54.59832027554512, 58.741401359438896, 63.494121730327606, 66.73549219965935, 66.81184530258179, 69.50333967804909, 73.82097959518433, 71.90964415669441, 67.84521505236626, 72.33566969633102, 72.91977435350418, 70.64042866230011, 68.32026556134224, 71.26218169927597, 71.60762876272202, 66.1213007569313, 65.67652702331543, 76.28144636750221, 51.756996139883995, 22.402923367917538, 0.9399968851357698, 0.12961864471435547, 0.5239113746210933, 0.2948348183417693, 0.4169377632206306, 0.1515928062144667, 0.16414994490332901, 0.10993613876053132, 4.102241825312376, 41.95370838046074, 65.85410669445992, 57.762748673558235, 31.938072815537453, 34.00852471590042, 47.31265962123871, 45.873851627111435, 6.098113227635622, 0.146515981759876, 0.09188249852741137, 0.0797830794181209, 0.04902864297037013, 0.059167248546145856, 0.012265620298421709, 0.047943467216100544, 0.048696105150156654, 0.024434798506263178, 0.024900087992136832, 0.08774314017500728, 0.0775126567168627, 0.010899929420702392, 0.029985653090989217, 0.012557878053485183, 0.12177519762190059, 0.10356347993365489, 0.024538051657145843, 0.03797876168391667, 0.018299320799997076, 0.03175243211444467, 0.006556758298756904, 0.021939545877103228, 0.030506651892210357, 0.0952876650262624, 0.014153020583762554, 0.019167689242749475, 0.056227330715046264, 0.044922499437234364, 0.10571458013146184, 0.15223933558445424, 0.14451025344897062, 0.12535764835774899, 0.1631967897992581, 0.08703627419890836, 0.18367298558587208, 0.15670094930101186, 0.09096920417505316, 0.15667350467992947, 0.16248110710876063, 0.1225296055781655, 0.17449459293857217, 0.08940524669014849, 0.15612848626915365, 0.14612399420002475, 0.13046208070591092, 0.12058650710969232, 0.06642143038334325, 0.15057604905450717, 0.09852428978774697, 0.15734182350570336, 0.1300583078409545, 0.08919774962123483, 0.10733135626651347, 0.13369774067541584, 0.17076041753171012, 0.1238041848409921, 0.12334354119957425, 0.244957804097794, 0.1229067130771, 0.12692999211139977, 0.09758375861565582, 0.2973010344430804, 0.13309266767464578, 0.26446073257829994, 0.18760362232569605, 0.2029443343053572, 6.811179639771581, 54.36992973089218, 74.91222783923149, 65.5115170776844, 48.50077606737614, 60.23120641708374, 85.14371082186699, 82.14713081717491, 24.962543919682503, 0.321776203927584, 0.19060375430854037, 3.1055132718756795, 5.771804312244058, 2.475008829496801, 0.9640628343913704, 0.3862180741271004, 0.4883861605776474, 23.11329524964094, 71.43598437309265, 89.49098914861679, 77.57575571537018, 71.19079113006592, 71.88072770833969, 73.77669677138329, 70.77121004462242, 74.17007446289062, 73.36043670773506, 73.01255777478218, 78.1443040072918, 74.86702546477318, 82.20179468393326, 78.72130304574966, 73.90960603952408, 67.40541905164719, 57.071322575211525, 54.68728110194206, 61.70377939939499, 76.75236269831657, 77.05411970615387, 77.72675201296806, 77.07751885056496, 76.7145623266697, 73.48210617899895, 72.16575801372528, 75.78486621379852, 73.98778304457664, 71.86698004603386, 67.83018305897713, 73.20941761136055, 62.68562771379948, 61.52193255722523, 67.22812056541443, 35.51444470882416, 42.608686834573746, 66.19601234793663, 69.94684427976608, 75.0670163333416, 77.39753767848015, 70.31531050801277, 72.76902124285698, 70.953668653965, 72.82119244337082, 61.19267262518406, 55.85495464503765, 58.147181645035744, 57.70084619522095, 64.30075004696846, 64.52336490154266, 66.3595099747181, 62.21990570425987, 60.62170386314392, 56.83603920042515, 60.67515179514885, 59.657950177788734, 64.74357068538666, 68.20022240281105, 66.04706034064293, 69.87272545695305, 74.96116161346436, 75.70207625627518, 72.50669091939926, 76.31151795387268, 73.4580610692501, 73.48178699612617, 73.89936178922653, 76.09622150659561, 70.51632732152939, 66.13017708063126, 71.99550434947014, 76.35522320866585, 49.760442674160004, 17.570889852941036, 0.6751036585774273, 0.23245095333550125, 0.3848568565445021, 0.47204389062244445, 1.8632525810971856, 1.7284627701155841, 0.882559820311144, 0.34309202106669545, 7.094877641648054, 60.566774010658264, 60.721497908234596, 48.679096698760986, 38.16836290061474, 43.977244198322296, 63.42255637049675, 56.196525916457176, 6.295429514721036, 0.3944493824383244, 0.22317161376122385, 0.145901468640659, 0.17681763391010463, 0.15453016734682024, 0.11384675235603936, 0.3066128503996879, 0.1586619854788296, 0.12125758672482334, 0.1694877678528428, 0.19353418378159404, 0.11840583974844776, 0.13816481659887359, 0.1523911938420497, 0.09358398339827545, 0.2197315514786169, 0.33006744808517396, 0.2137691222014837, 0.2763731824234128, 0.11080300435423851, 0.07030544540612027, 0.11649086125544272, 0.1783834319212474, 0.1271507068304345, 0.1601005348493345, 0.18273275869432837, 0.13091073866235092, 0.15182579605607316, 0.2047185570700094, 0.18912588595412672], [0.0645775644807145, 0.12921972549520433, 0.031132189615163952, 0.0679638581641484, 0.05312709785357583, 0.02981723937409697, 0.014963408739276929, 0.0522514563635923, 0.04915049619739875, 0.016585735211265273, 0.041112023827736266, 0.075257566786604, 0.036947024273104034, 0.043652224630932324, 0.03975994208303746, 0.011956696689594537, 0.02955553212814266, 0.004897669541605865, 0.0314149144833209, 0.01952951406565262, 0.08696205943124369, 0.014216741383279441, 0.04656339166103862, 0.02335500146728009, 0.07499264233047143, 0.06402905055438168, 0.03684892719320487, 0.0144822669790301, 0.07177649342338555, 0.011542407592060044, 0.08006174844922498, 0.051282842323416844, 0.04427542458870448, 0.010913778824033216, 0.02340002014534548, 0.045405203418340534, 0.03541083795425948, 0.032869909846340306, 0.5003035382833332, 24.400586374104023, 55.59384025633335, 48.73366177082062, 40.371256694197655, 35.785237178206444, 50.53508050739765, 73.11002254486084, 29.83013592660427, 1.0876751295290887, 0.16850880085257813, 0.10042629553936422, 1.271259190980345, 0.545766792492941, 0.2529037417843938, 0.07098669986589812, 0.6157666363287717, 2.007973277941346, 31.709118001163006, 69.84217509627342, 84.60804596543312, 76.2953232228756, 71.26297205686569, 73.41968312859535, 71.24586537480354, 74.7959616780281, 78.83372381329536, 68.8642443716526, 73.36159944534302, 67.80892699956894, 71.69060111045837, 66.9761560857296, 57.59977921843529, 55.10402373969555, 55.945701375603676, 65.47874003648758, 76.65996685624123, 69.85479041934013, 71.45142674446106, 73.25492396950722, 69.59679186344147, 68.57404634356499, 69.724852591753, 68.26916590332985, 73.38970273733139, 67.85590767860413, 70.41681066155434, 63.158497139811516, 54.94678817689419, 71.6912242770195, 76.45309835672379, 19.710619635879993, 38.860248774290085, 76.66643410921097, 69.71478313207626, 72.50512540340424, 69.23196583986282, 73.23751330375671, 70.88819056749344, 69.0165401995182, 65.58626666665077, 55.304945558309555, 51.597678288817406, 57.246933951973915, 64.50222283601761, 68.51156249642372, 65.45570567250252, 62.86994442343712, 58.86013738811016, 58.1756155192852, 55.25453366339207, 54.760377779603004, 60.29375486075878, 66.51776388287544, 71.78842306137085, 73.05658221244812, 73.14169764518738, 71.1173714697361, 65.73157086968422, 68.49401503801346, 66.88447460532188, 66.51250496506691, 71.87825784087181, 72.0174291729927, 70.2559120953083, 73.52617621421814, 72.41555660963058, 61.233718022704124, 20.27508694678545, 2.821908127516508, 0.022711539022566285, 0.10219374991720542, 0.18317599897272885, 0.3497694799443707, 0.390525083639659, 0.5501476605422795, 0.0611302514153067, 0.031096765051188413, 9.719158373773098, 59.19910579919815, 53.53913851082325, 22.83091150224209, 18.584082685410976, 35.53544618189335, 45.22589899599552, 15.310320854187012, 0.4295988322701305, 0.08205898659070954, 0.029100640131218825, 0.031896568325464614, 0.05551795256906189, 0.036923546431353316, 0.023748293351673055, 0.009435404881514842, 0.04971579008270055, 0.06678305668174289, 0.06727769810822792, 0.029627410985995084, 0.04857487161643803, 0.05617884991806932, 0.049565857698326, 0.05184853325772565, 0.038209714330150746, 0.01593017761479132, 0.0832553805958014, 0.059229492471786216, 0.016045032389229164, 0.08079235572949983, 0.09776640115887858, 0.041547445580363274, 0.026255019583913963, 0.07451581244822592, 0.04238413916027639, 0.04551914164039772, 0.05672117062204052, 0.03898964845575392, 0.044797803784604184, 0.05188378527236637, 0.047741621601744555, 0.013195666779211024, 0.07233348267618567, 0.03267429827246815, 0.0267616114433622, 0.011979980645264732, 0.047919907738105394, 0.02484114476828836, 0.05775335703219753, 0.05627979313430842, 0.0772522074112203, 0.052705045891343616, 0.023029120711726137, 0.07581022189697251, 0.04221008697641082, 0.048103622684720904, 0.021797804947709665, 0.037631484810844995, 0.061108543595764786, 0.044171423724037595, 0.06882139496156015, 0.033065755196730606, 0.035948943259427324, 0.01178497206637985, 0.010634991976985475, 0.019889559589501005, 0.027991546812700108, 0.050993586555705406, 0.1007654718705453, 0.00421140836806444, 0.06323504901956767, 0.09196333325235173, 0.05388440018577967, 0.025408822803001385, 0.059942996958852746, 0.05083407675556373, 0.01563646896102, 0.12844490847783163, 3.5114122414961457, 37.708507776260376, 66.66911736130714, 47.18245580792427, 38.90178434550762, 47.3026205599308, 79.90664944052696, 81.31513506174088, 26.586194895207882, 1.167134209536016, 0.11085018268204294, 0.0998516209074296, 0.04715326176665258, 0.3773706348147243, 0.4817921487847343, 0.1960489511839114, 0.6788328615948558, 4.780655521899462, 43.63296367228031, 74.13706183433533, 85.50545141100883, 74.44283902645111, 71.93006426095963, 73.09083357453346, 74.93018567562103, 74.44692760705948, 81.9449132680893, 71.66865348815918, 72.1218703687191, 72.9281111061573, 74.46018889546394, 71.02170020341873, 59.78982210159302, 55.725241005420685, 58.01383540034294, 65.64120411872864, 79.0794338285923, 71.06834650039673, 73.67154881358147, 71.18144363164902, 71.20284408330917, 69.77256283164024, 70.85770100355148, 69.31942194700241, 77.18219563364983, 68.77311766147614, 73.51509600877762, 64.86637249588966, 55.07194206118584, 68.97027388215065, 76.18844255805016, 22.86602921783924, 38.91112804412842, 75.47050908207893, 71.20736584067345, 73.27795073390007, 72.14610546827316, 75.52344784140587, 72.67190605401993, 69.36970084905624, 66.19390726089478, 58.16469870507717, 51.65429525077343, 56.0238441824913, 64.70748022198677, 70.51893398165703, 65.70141568779945, 66.34119495749474, 62.46427819132805, 61.094603687524796, 56.61552183330059, 55.729021802544594, 59.38402287662029, 65.67657262086868, 73.1152206659317, 74.11665692925453, 74.52115282416344, 70.8122706413269, 67.6523070037365, 71.28011673688889, 70.29486000537872, 66.97025880217552, 73.72589349746704, 73.75900492072105, 71.28833189606667, 70.53313761949539, 70.5752469599247, 64.35295924544334, 26.619325317442417, 4.0305510722100735, 0.1993859588401392, 0.24090566294034943, 1.044876838568598, 0.372728441725485, 0.4100028384709731, 0.21390276815509424, 0.11153742627357133, 0.0029719275880779605, 7.9590495955199, 57.75540366768837, 76.41389966011047, 36.575552970170975, 16.15695722401142, 36.05937346816063, 52.17979945242405, 24.842641353607178, 0.9894938010256737, 0.029817152171744965, 0.03797118435613811, 0.07261911305249669, 0.009622344459785381, 0.03184641398547683, 0.041816232915152796, 0.024696002947166562, 0.0030091006055954495, 0.04087426197656896, 0.04100561469385866, 0.036957607298973016, 0.05849342298461124, 0.02201052673626691, 0.00969404984061839, 0.09331645400379784, 0.01631257477129111, 0.02503221810911782, 0.025361358748341445, 0.028466888688853942, 0.034319446713197976, 0.07560080266557634, 0.08908097268431447, 0.05308706640789751, 0.05122564500197768, 0.04005653398053255, 0.015683699239161797, 0.03614684806962032, 0.03757623562705703, 0.04718251351732761, 0.04254224259057082, 0.047884655723464675, 0.16539589210879058, 0.21843982860445976, 0.14416738122235984, 0.1627631380688399, 0.1879791045212187, 0.09188091775286011, 0.12682441418292, 0.18129823176423088, 0.1179718466300983, 0.12674298573983833, 0.12619865010492504, 0.18203916231868789, 0.12585153279360384, 0.18491376744350418, 0.177049896446988, 0.13772990321740508, 0.18570605461718515, 0.1303653046488762, 0.2147471540956758, 0.14791785419220105, 0.2126558858435601, 0.1205338146246504, 0.13724446442211047, 0.1068096784001682, 0.14590465987566859, 0.1845073970616795, 0.2251988198258914, 0.09267526067560539, 0.16529068525414914, 0.11502934983582236, 0.23422484955517575, 0.1950418864726089, 0.15398641058709472, 0.13319300604052842, 0.17960027209483087, 0.15021581057226285, 0.1438853205763735, 0.2652917004888877, 1.8754536076448858, 39.712064266204834, 78.81758987903595, 63.006433099508286, 55.82843206822872, 52.146137058734894, 66.12783640623093, 87.91680961847305, 46.713800355792046, 3.126956708729267, 0.4253284848527983, 0.856265468755737, 1.9699896848760545, 2.0282321283593774, 0.7416332792490721, 0.1912545584491454, 0.7226917112711817, 3.9849326200783253, 37.559247985482216, 74.4372609257698, 88.46504420042038, 74.12859588861465, 70.14465406537056, 71.87375888228416, 72.84402161836624, 74.15411531925201, 83.42280596494675, 77.8692215681076, 75.88562160730362, 74.83190014958382, 75.86516350507736, 72.35663697123528, 61.33533596992493, 61.46568037569523, 61.39924854040146, 72.94396385550499, 83.20772230625153, 75.65798342227936, 78.68787243962288, 75.89072853326797, 73.35048124194145, 73.39057669043541, 73.56111913919449, 72.730453312397, 79.37554433941841, 71.68072164058685, 75.0090542435646, 62.14627705514431, 57.53304339945316, 73.86690393090248, 79.70073089003563, 27.94268410652876, 43.620713129639626, 79.5777390897274, 72.49843016266823, 77.51647889614105, 74.76376980543137, 82.70897626876831, 76.85441762208939, 73.1393113732338, 69.39151167869568, 60.61357609927654, 54.97871406376362, 61.438827216625214, 69.86717775464058, 72.38065928220749, 66.86243578791618, 68.83455276489258, 64.81613159179688, 65.614582747221, 62.2780691832304, 60.361725613474846, 64.3867090344429, 74.2217668890953, 79.16043788194656, 79.65136393904686, 80.91665044426918, 73.4312193095684, 68.75136002898216, 73.59369859099388, 72.77663603425026, 69.782305508852, 72.46635988354683, 72.19325333833694, 71.22605323791504, 71.22708678245544, 71.7233857512474, 62.24577471613884, 23.23182988911867, 2.8676142124459147, 0.1642424610326998, 0.2169127855449915, 0.8497007272671908, 1.8258857424370944, 2.0973145589232445, 2.4169054348021746, 0.3993140714010224, 0.09851729133515619, 16.414611898362637, 71.3167391717434, 62.026838064193726, 31.958215534687042, 28.28979168087244, 47.60440796613693, 62.80409015715122, 28.387001864612103, 1.0410148208029568, 0.2844917733455077, 0.10663982306141406, 0.19270937569672242, 0.2031108277151361, 0.18606408149935305, 0.1073919006739743, 0.07891220622695982, 0.15761526039568707, 0.16739308572141454, 0.11570008806302212, 0.10026485615526326, 0.11817449005320668, 0.12303798415814526, 0.07940890340250917, 0.12437533427146263, 0.1763899638899602, 0.07900071475887671, 0.17305752786342055, 0.15038751385873184, 0.1697119855089113, 0.2664700528839603, 0.18708975927438587, 0.11922711521037854, 0.17109944543335587, 0.12827636674046516, 0.1188293017912656, 0.12885074451332912, 0.205814887303859, 0.15002363885287195, 0.1082067342940718, 0.1397149552940391], [0.02453947101457743, 0.0430612635682337, 0.04509164973569568, 0.020953662060492206, 0.05243339386652224, 0.05881955235963687, 0.03969298551965039, 0.06716884730849415, 0.05543144783587195, 0.07996492044185288, 0.02692367237614235, 0.025615078629925847, 0.03866082879540045, 0.030719069400220178, 0.03411007572140079, 0.016086518444353715, 0.057549017801648006, 0.022625180863542482, 0.04545765470538754, 0.06495459776488133, 0.04018084000563249, 0.020403719499881845, 0.021910464820393827, 0.05251932714600116, 0.028904770661029033, 0.07226582849398255, 0.040792143336148, 0.07454342776327394, 0.045159485744079575, 0.01872012966487091, 0.049782676142058335, 0.021802662304253317, 0.02945094311144203, 0.02631042090797564, 0.1182730175787583, 0.03715630620718002, 0.03468208233243786, 0.05741177614254411, 0.07901848177425563, 0.011698807793436572, 16.427749693393707, 53.90581503510475, 61.410058960318565, 47.14112922549248, 32.89770372211933, 42.91667550802231, 73.49396154284477, 54.574845135211945, 7.827574275434017, 0.27737588330637664, 0.09825250788708217, 0.24564531486248598, 0.3812817530706525, 0.7534136564936489, 1.5783968288451433, 0.3937098471214995, 0.19599188002757728, 3.9247846975922585, 28.830221481621265, 70.04379987716675, 82.1263687312603, 79.28513959050179, 69.2644464969635, 79.618731290102, 70.02212584018707, 72.39963546395302, 79.00238156318665, 78.5192222893238, 74.14472222328186, 60.502082481980324, 55.97565896809101, 52.413726300001144, 53.10173638164997, 66.03707447648048, 76.28350585699081, 76.47837460041046, 72.07897827029228, 72.9484324157238, 75.25287955999374, 70.04094243049622, 68.98038133978844, 71.99296608567238, 73.96481707692146, 70.52290856838226, 73.9524981379509, 71.31902664899826, 59.58355776965618, 79.9064214527607, 49.537292048335075, 40.47639325261116, 41.46141439676285, 69.57450225949287, 67.5573880970478, 72.08317324519157, 72.5677764415741, 69.75736364722252, 70.43852269649506, 64.96946096420288, 57.38258667290211, 51.09034091234207, 59.788765758275986, 67.20710769295692, 72.56856679916382, 72.80250504612923, 72.03154161572456, 72.74226307868958, 67.95384362339973, 66.24782636761665, 63.12125913798809, 59.94761623442173, 57.673309072852135, 60.71936622262001, 65.27899235486984, 66.97016760706902, 71.93811982870102, 75.03555402159691, 72.7794174849987, 65.3640241920948, 71.87770307064056, 75.07011696696281, 73.32654252648354, 75.97398206591606, 80.0028146803379, 67.72942766547203, 31.136365234851837, 3.385000149719417, 0.16367136355256662, 0.08869267359841615, 0.7182649488095194, 0.5967490724287927, 0.40029700146988034, 0.46697579382453114, 0.2129609085386619, 0.31374613638035953, 0.36628731235396117, 23.922716416418552, 67.85098314285278, 39.81696143746376, 22.291880026459694, 31.643191538751125, 50.0911845266819, 45.267518162727356, 11.203036699444056, 0.09332720772363245, 0.15556449856376275, 0.15430145227583125, 0.01959406421519816, 0.039596970163984224, 0.06087568363000173, 0.05601241959084291, 0.026629716958268546, 0.07967867408297025, 0.07269082678249106, 0.052673393292934634, 0.018036951187241357, 0.06905267044203356, 0.04594342375639826, 0.04467274447961245, 0.04579832275339868, 0.034820418659364805, 0.01551621506223455, 0.10609050761559047, 0.028082892204110976, 0.02875181959097972, 0.029038962093181908, 0.03470367882982828, 0.014740122478542617, 0.016994044453895185, 0.017468690566602163, 0.014716521254740655, 0.015139504612307064, 0.019720210766536184, 0.06324405869236216, 0.015976372596924193, 0.02771554580249358, 0.017320092192676384, 0.03333695451146923, 0.03760638166568242, 0.0027971274585070205, 0.019435005269770045, 0.04143975624174345, 0.03091024478635518, 0.03812645278230775, 0.033267140679527074, 0.041938427530112676, 0.06625538968364708, 0.07325978687731549, 0.06489255421911366, 0.05948344427451957, 0.05394229883677326, 0.031245296631823294, 0.005490794892466511, 0.07546836641267873, 0.05898291761695873, 0.039850424727774225, 0.04727955674752593, 0.011016075532097602, 0.09725896510644816, 0.04307236609747633, 0.05547885622945614, 0.03305206628283486, 0.06533190564368851, 0.057262708360212855, 0.07389537699054927, 0.04225726159347687, 0.04695863353845198, 0.02750813222519355, 0.013756460466538556, 0.046151414353516884, 0.03491027790005319, 0.029154302974347956, 0.04558371590974275, 0.09072079992620274, 0.08066682887147181, 0.10365568436100148, 1.036808684002608, 27.804363928735256, 64.90158900618553, 64.0110231935978, 39.426091611385345, 30.01091692596674, 65.39636045694351, 88.32997664809227, 54.46360990405083, 4.899416249245405, 0.20315136382123455, 0.1549500596593134, 0.22901970776729286, 0.21949893271084875, 1.3600362022407353, 1.7482618452049792, 0.9719053166918457, 0.11016569987987168, 7.903936877846718, 38.24639551341534, 74.26759243011475, 80.40544867515564, 75.87287709116936, 69.96063753962517, 78.54687720537186, 74.32264387607574, 77.20778346061707, 82.55066156387329, 78.48439335823059, 72.47085124254227, 61.75461307168007, 57.574248388409615, 55.79726234078407, 57.12193205952644, 70.58093905448914, 78.27348947525024, 75.34513100981712, 75.8051723241806, 78.62256914377213, 75.13600543141365, 71.92154511809349, 73.78066375851631, 73.41700807213783, 72.8408981859684, 71.062570810318, 71.03715017437935, 68.43997433781624, 61.91823609173298, 75.73719397187233, 56.68823093175888, 35.36127492785454, 46.22378624975681, 70.64129501581192, 68.33389163017273, 74.62408170104027, 73.15761879086494, 71.4501728117466, 74.47775915265083, 68.25079768896103, 61.93820022046566, 53.56995105743408, 61.03036433458328, 68.09344813227654, 73.44460219144821, 70.95524936914444, 73.6681517958641, 72.77542009949684, 68.35558846592903, 67.17335030436516, 65.04993304610252, 61.88214562833309, 63.379443883895874, 64.86833319067955, 68.86320322751999, 68.99579331278801, 73.10131341218948, 77.49659076333046, 72.75238573551178, 67.04206734895706, 70.20865023136139, 75.8171720802784, 72.48326897621155, 73.215801268816, 75.4370328783989, 70.97293362021446, 35.24471998214722, 7.565181255340576, 0.48639239568728954, 0.3057261323556304, 2.1744891302660108, 1.4327457756735384, 0.6075690512079746, 0.4045916616450995, 0.24765153299085796, 0.23479425493860617, 0.5895213258918375, 20.24179693311453, 78.97703692317009, 62.77226686477661, 27.586508318781853, 16.632499806582928, 45.061728805303574, 53.33676517009735, 19.4652896001935, 0.261325782048516, 0.16041502734879032, 0.1467944058822468, 0.09004395382362418, 0.04403146951517556, 0.024713448983675335, 0.031030229656607844, 0.02630787348607555, 0.06986927037360147, 0.05633119057165459, 0.01956702963070711, 0.029513144363590982, 0.05710469027690124, 0.0569046480813995, 0.047453809311264195, 0.03929145022993907, 0.06407675580703653, 0.015351893362094415, 0.05167402465303894, 0.08098627891740762, 0.01708751980913803, 0.016901712006074376, 0.022224012936931103, 0.053466908721020445, 0.03833394242974464, 0.061745020575472154, 0.03823529616056476, 0.042478132163523696, 0.05263122817268595, 0.08662631182232872, 0.04734927038953174, 0.054121197244967334, 0.04479056042328011, 0.1602169036050327, 0.0841406143445056, 0.1279638780397363, 0.0842493241361808, 0.12273431959329173, 0.1481516010244377, 0.18384158669505268, 0.162164447538089, 0.2337307424750179, 0.28074656962417066, 0.11325095620122738, 0.20926280150888488, 0.1340460157371126, 0.11027758606360294, 0.15726542682386935, 0.14679298095870763, 0.17081972997402772, 0.12169720532256179, 0.1170579734025523, 0.2246775056119077, 0.12183330036350526, 0.22240013640839607, 0.10729761081165634, 0.15212010213872418, 0.0948490780137945, 0.16484668798511848, 0.21929215552518144, 0.12559391849208623, 0.16488057444803417, 0.13445474614854902, 0.14024378004251048, 0.09230279159964994, 0.13909892819356173, 0.15483041061088443, 0.22491969808470458, 0.31771330162882805, 0.3129580052336678, 0.16877638961886987, 0.1933311767061241, 0.43451348261442035, 25.391406007111073, 74.61180076003075, 79.69288811087608, 60.32410003244877, 44.48488175868988, 57.280858531594276, 82.77692422270775, 73.75206649303436, 12.027668450027704, 0.47516159364022315, 0.7867899967823178, 0.4524835792835802, 0.6427646626252681, 2.4747300194576383, 2.6244559977203608, 1.0107696312479675, 0.20416058076079935, 5.6019562762230635, 31.966871470212936, 71.27321630716324, 84.17398765683174, 77.30015650391579, 70.99013909697533, 80.34009978175163, 73.20216000080109, 75.67515090107918, 84.6818608045578, 84.17399525642395, 81.37517184019089, 68.17678526043892, 59.52711179852486, 59.8083309084177, 58.590587452054024, 73.04120823740959, 80.55167242884636, 77.30549901723862, 74.52968716621399, 82.22161442041397, 80.08235961198807, 75.76481848955154, 76.09720185399055, 77.70203053951263, 78.25354054570198, 73.18560808897018, 75.87426781654358, 71.00524708628654, 64.30434465408325, 77.61715069413185, 52.70344935357571, 52.58678421378136, 54.00139130651951, 70.63491895794868, 70.01638054847717, 77.3825740814209, 76.69640690088272, 74.44237545132637, 76.48146763443947, 70.76026663184166, 64.62885484099388, 57.37853229045868, 67.31463432312012, 74.96875360608101, 77.84858107566833, 78.86387899518013, 80.61832085251808, 77.20842182636261, 74.81018051505089, 73.50286066532135, 69.20989662408829, 68.11508417129517, 67.42590755224228, 63.51688250899315, 68.34490343928337, 70.26073783636093, 71.50992080569267, 76.1305944621563, 74.23484578728676, 68.70355099439621, 72.41198480129242, 76.2913030385971, 75.50402328372002, 75.05171075463295, 80.45401006937027, 70.27437150478363, 35.24000823497772, 4.414833476766944, 0.27520002506207675, 0.2663595322519541, 1.325017400085926, 2.180765918456018, 4.089294020086527, 2.898317277431488, 1.7073424346745014, 0.708428107900545, 0.7944427861366421, 33.95562395453453, 79.39202785491943, 49.05669003725052, 31.449202448129654, 43.114261105656624, 62.665131613612175, 62.91579656302929, 20.219883508980274, 0.24781070882454515, 0.2929194539319724, 0.2985165239078924, 0.15053588402224705, 0.1260757356067188, 0.17731132538756356, 0.16404301626607776, 0.11125238219392486, 0.2104359440272674, 0.1836553670000285, 0.08754019989282824, 0.10077517174067907, 0.15408585837576538, 0.15157885383814573, 0.13073182170046493, 0.12495950097218156, 0.1044493964582216, 0.13121484109433368, 0.2571042679483071, 0.15070390625623986, 0.08028625554288737, 0.10547622456215322, 0.12480931996833533, 0.16688305215211585, 0.1037216983968392, 0.2574528398690745, 0.10276754881488159, 0.12315491694607772, 0.2198060037335381, 0.19796952547039837, 0.14961778797442093, 0.1076560458750464, 0.08705004103831016], [0.010995143256877782, 0.050824399149860255, 0.017063014092855155, 0.045018770833848976, 0.027628887073660735, 0.08800479175988585, 0.02790955619275337, 0.019739744093385525, 0.05605884092801716, 0.08553018938982859, 0.005509127795448876, 0.04747415157908108, 0.07661190466023982, 0.039220957332872786, 0.054206852219067514, 0.06313549733022228, 0.045677649541175924, 0.0676876753277611, 0.031208085347316228, 0.018531666828494053, 0.032974578643916175, 0.017629341418796685, 0.052389462434803136, 0.007954888915264746, 0.04048568458529189, 0.02541960435337387, 0.07376806155662052, 0.035123333655064926, 0.03761870873859152, 0.02939646947197616, 0.02293696452397853, 0.08197827060939744, 0.045674873908865266, 0.028301790516707115, 0.0322150498686824, 0.10246682315482758, 0.06733804955729283, 0.022276868694461882, 0.019999076466774568, 0.05538184639590327, 0.1711895124753937, 5.5311076529324055, 39.581404477357864, 65.58847054839134, 56.15285865962505, 40.67569635808468, 35.60479626059532, 55.5204775929451, 67.79897913336754, 25.253296718001366, 1.7923128814436495, 0.2792744158068672, 0.7114450866356492, 1.0672582313418388, 0.661486554890871, 0.8177107782103121, 0.04893180383078288, 0.2060742976027541, 0.2329673248459585, 3.472053478471935, 32.076890766620636, 72.54186943173409, 79.80351537466049, 78.13726678490639, 83.23210179805756, 81.76203668117523, 73.06769281625748, 70.55589079856873, 70.32641351222992, 70.85561111569405, 70.2333565056324, 66.10862463712692, 63.283472433686256, 72.9416611790657, 78.2466933131218, 75.87769523262978, 76.59112975001335, 74.17420104146004, 72.73549184203148, 71.39060720801353, 68.178571164608, 72.13045790791512, 73.85116517543793, 71.66770353913307, 66.12483456730843, 65.26594385504723, 65.90303286910057, 87.13550314307213, 47.574602365493774, 50.190541595220566, 37.441382110118866, 63.92763286828995, 77.27116405963898, 69.49644684791565, 72.39854112267494, 74.4273966550827, 74.62322294712067, 59.344056621193886, 50.51223233342171, 60.771875604987144, 71.2835593521595, 74.23180595040321, 75.97063824534416, 71.47237122058868, 72.19249337911606, 72.52717182040215, 69.13742691278458, 69.0267388522625, 67.54946932196617, 63.75924110412598, 68.49085360765457, 74.00527730584145, 76.14364296197891, 80.21181866526604, 79.10724833607674, 72.96449795365334, 66.39233261346817, 75.50852224230766, 70.83280473947525, 80.15689641237259, 78.11607152223587, 65.83030477166176, 41.28990679979324, 9.15794463828206, 0.1324088973342441, 0.14192563510732725, 0.3078770247520879, 1.4582942984998226, 1.5139524056576192, 0.6779282726347446, 1.4307024353183806, 0.400679919985123, 0.1303417340386659, 2.3728467989712954, 38.641384318470955, 61.58989571034908, 23.885235227644444, 22.963036112487316, 40.3453154861927, 55.9221388399601, 39.362000450491905, 5.601904504001141, 0.14310183527413756, 0.13079591357382014, 0.05138280219398439, 0.020097624401387293, 0.08204146448406391, 0.08902563073206693, 0.10059252177597955, 0.024899368108890485, 0.08846798096783459, 0.08699199766851962, 0.07542810490122065, 0.050413794815540314, 0.01973324473510729, 0.05616786984319333, 0.03280367316619959, 0.010216111768386327, 0.051961703356937505, 0.03551056775904726, 0.038903974927961826, 0.02305229427292943, 0.033623453200561926, 0.0063253779899241636, 0.04797918307303917, 0.04134300987061579, 0.03030329229659401, 0.023270456003956497, 0.012379283925838536, 0.013648240492329933, 0.03119202156085521, 0.006959188804103178, 0.10614080296363682, 0.004409857265272876, 0.03934475127607584, 0.02774465840047924, 0.011035468778572977, 0.04744098871015012, 0.026027102321677376, 0.028368604216666427, 0.026819218801392708, 0.06260129201109521, 0.15345025341957808, 0.026891225679719355, 0.027496181792230345, 0.02277535073517356, 0.019437027622188907, 0.021715721559303347, 0.027729288522095885, 0.028147835691925138, 0.03155089078063611, 0.03532090820954181, 0.04836792744754348, 0.05765124493336771, 0.03955071581003722, 0.027630692347884178, 0.025521950228721835, 0.06475906411651522, 0.07534933334682137, 0.11341192803229205, 0.048274750806740485, 0.024546901768189855, 0.03743454108189326, 0.04620146850356832, 0.03685532821691595, 0.024577589574619196, 0.042350679432274774, 0.04876628634519875, 0.02114566865202505, 0.03638631686044391, 0.07782773551298305, 0.09581217789673246, 0.07693479827139527, 0.02017375019931933, 0.035389490076340735, 0.20616139605408534, 0.1631655008532107, 13.127686623483896, 52.98434928059578, 72.5701779127121, 45.25127023458481, 29.346007704734802, 48.21041464805603, 84.10375222563744, 83.2347084581852, 19.221811965107918, 0.9529791260138154, 0.2931560209253803, 0.24880594370188192, 0.362575386534445, 0.6267840263899416, 1.8456736556254327, 0.7402799581177533, 1.1928717722184956, 0.11253867254708894, 8.078429214656353, 42.107843309640884, 77.34704598784447, 80.53015798330307, 81.47000715136528, 81.37429028749466, 78.59462544322014, 71.83893755078316, 75.2638989686966, 76.07939600944519, 74.6133054792881, 70.16425341367722, 68.18677112460136, 65.87898775935173, 72.98880144953728, 78.5344822704792, 76.01155444979668, 74.76953789591789, 76.1316280066967, 74.69979643821716, 73.08973163366318, 68.50764110684395, 73.70957717299461, 75.86366638541222, 75.97560837864876, 69.40237909555435, 69.14186507463455, 64.92412939667702, 86.44159957766533, 50.33364951610565, 51.26237668097019, 43.446712866425514, 67.09666281938553, 78.53720292448997, 70.84345936775208, 75.29320299625397, 76.9015122950077, 77.59161606431007, 64.00074854493141, 52.994935512542725, 57.25981526076794, 70.21928206086159, 76.47519797086716, 76.68556988239288, 73.87619063258171, 74.81372952461243, 73.89395087957382, 72.24139675498009, 70.26747107505798, 70.14704033732414, 64.77089121937752, 66.12539693713188, 70.45154079794884, 76.40374660491943, 75.05898356437683, 80.72733700275421, 73.45540881156921, 68.97613316774368, 74.90514501929283, 74.7081483900547, 76.75102517008781, 77.88325041532516, 70.78256383538246, 50.30969940125942, 14.20293677598238, 0.7774195808451623, 0.6999422132503241, 1.3850037124939263, 2.593577904626727, 3.0045035295188427, 0.6452490168157965, 0.7069252291694283, 0.27139645884744823, 0.09205895898048766, 2.0990178175270557, 34.49935957789421, 77.34460651874542, 41.05157978832722, 19.698408991098404, 24.876362644135952, 56.85403883457184, 48.78923758864403, 10.018750447779894, 0.4674127703765407, 0.20536241470836103, 0.04371907729364466, 0.03121277943137102, 0.09407569334143773, 0.05482494249008596, 0.03015772559592733, 0.01818259395804489, 0.1145133568206802, 0.05680573834979441, 0.044266878758207895, 0.06555122512509115, 0.054897075533517636, 0.015515941395278787, 0.0047347263807751006, 0.02343002888665069, 0.08638353305286728, 0.01619503898837138, 0.015052000762807438, 0.041917769849533215, 0.07347465347265825, 0.0597762215329567, 0.019123481361020822, 0.018608913269417826, 0.04136981995543465, 0.06765252721379511, 0.04570242985209916, 0.060999247507425025, 0.04284522437956184, 0.0568339807796292, 0.10986782406689599, 0.03980332432547584, 0.022066874298616312, 0.03737995240953751, 0.11400576491723768, 0.13141343981260434, 0.09710088765132241, 0.11054484086344019, 0.07870467205066234, 0.2599436655873433, 0.2751489059301093, 0.09965758639737032, 0.14431132818572223, 0.2001912781270221, 0.11421802657423541, 0.11335077506373636, 0.21376653952756897, 0.13573156669735909, 0.10567903867922723, 0.13908708351664245, 0.1119337925047148, 0.20904011267703027, 0.11939815056393854, 0.14716193225467578, 0.07412444829242304, 0.132883871847298, 0.13885496940929443, 0.15777212072862312, 0.09400166411069222, 0.11333851478411816, 0.2844627108424902, 0.18131344579160213, 0.22850976325571537, 0.15800778230186552, 0.2258824120508507, 0.16547933919355273, 0.14549867541063577, 0.1187343143101316, 0.18455557728884742, 0.16213807160966098, 0.1699822163209319, 0.09078104005311616, 0.21056724479421973, 0.28362102631945163, 0.17228211712790653, 10.659242179244757, 56.01186342537403, 89.43077757954597, 67.51571953296661, 55.83071954548359, 53.16338047385216, 69.53629150986671, 89.22142401337624, 35.924032330513, 2.8948585130274296, 0.5742758314590901, 3.044500658288598, 4.333958141505718, 0.6421127007342875, 1.2736813235096633, 0.49542540160473436, 0.46381572901736945, 0.23603120731422678, 5.100455861538649, 35.427129194140434, 76.12494796514511, 81.8360111117363, 81.01685866713524, 85.78804984688759, 82.89005175232887, 77.75360897183418, 75.04474192857742, 78.3272185921669, 77.25375339388847, 77.4669523537159, 72.63899981975555, 72.40355685353279, 81.29153072834015, 85.42511612176895, 79.9828353524208, 81.75363153219223, 76.59236088395119, 77.95416980981827, 76.3856291770935, 75.07966965436935, 79.61257562041283, 80.11240839958191, 76.78465336561203, 70.51844000816345, 65.97292631864548, 69.30670022964478, 86.08618184924126, 58.93835999071598, 52.52269305288792, 51.58606231212616, 69.18939292430878, 83.04595738649368, 75.09264215826988, 77.84389212727547, 81.4942878484726, 84.45546135306358, 65.95195144414902, 54.578876718878746, 62.45767034590244, 73.35959315299988, 78.33044841885567, 78.88103887438774, 74.56077709794044, 75.49841478466988, 78.45782518386841, 74.14156839251518, 74.38831195235252, 74.88334938883781, 69.3156373500824, 69.96547088027, 82.55226507782936, 85.16003474593163, 84.84373211860657, 88.0391326546669, 78.96892815828323, 70.08145585656166, 76.19013726711273, 72.02576592564583, 76.93374216556549, 77.88452714681625, 67.25740939378738, 43.86692471802235, 11.407998651266098, 0.23039912281092256, 0.3327419998822734, 0.9909498947672546, 3.8053328823298216, 6.31072036921978, 5.015375576913357, 8.428476881235838, 1.1668686987832189, 0.28262672654818743, 4.1921516507864, 51.63971543312073, 68.15677553415298, 32.401476949453354, 36.14164285361767, 51.32536970078945, 69.92906883358955, 55.73594883084297, 9.852910246700048, 0.4530742100905627, 0.3081222006585449, 0.10373993296525441, 0.08168062486220151, 0.20588861225405708, 0.15271748648956418, 0.35750755690969527, 0.12225725222378969, 0.19902010972145945, 0.2219038177281618, 0.20460352418012917, 0.1744919954217039, 0.08819689668598585, 0.14157594996504486, 0.1410919360932894, 0.12533433007774875, 0.14606030308641493, 0.12718975864117965, 0.11076650553150102, 0.1617681555217132, 0.13300714257638901, 0.08738872755202465, 0.10747537002316676, 0.1351795720984228, 0.15533165715169162, 0.09889842869597487, 0.27050041942857206, 0.0717483734479174, 0.11129852151498199, 0.16758297162596136, 0.2497595886234194, 0.10011206279159524, 0.15301492443541065, 0.15407959464937449], [0.08710679307114333, 0.04350206960225478, 0.03213130963558797, 0.023839620189392008, 0.033990515730693005, 0.035170222545275465, 0.10395032441010699, 0.058696934720501304, 0.07275612093508244, 0.026516242578509264, 0.02360718139243545, 0.031761490026838146, 0.07376874433248304, 0.045089504928910173, 0.014179764802975114, 0.0498491688631475, 0.01719409592624288, 0.030474769228021614, 0.09661707415943965, 0.011570326259970898, 0.1405267312657088, 0.020250458583177533, 0.024092913336062338, 0.02130771474185167, 0.0916904084442649, 0.03157980114337988, 0.0070735365989094134, 0.14963104273192585, 0.10382423351984471, 0.06257887915126048, 0.006164785581859178, 0.002655187540767656, 0.019075560885539744, 0.04905413574306294, 0.07740531247691251, 0.07279422279680148, 0.10923667199676856, 0.05802784777188208, 0.04501038827584125, 0.04282159439753741, 0.07412827777443454, 0.22243546263780445, 1.2219715607352555, 25.437928810715675, 66.25595033168793, 61.99047401547432, 48.24743986129761, 33.078129440546036, 38.38155806064606, 64.98227387666702, 51.62602856755257, 9.824915248900652, 0.7670989190228283, 0.37144805886782706, 0.9288342716172338, 0.2913042437285185, 0.21283207170199603, 0.11105512676294893, 0.21573238482233137, 0.17361024976707995, 0.4048090515425429, 7.9467396810650826, 51.370142698287964, 78.65932837128639, 83.24832692742348, 74.4064749777317, 84.60570529103279, 85.79562664031982, 81.19250044226646, 75.51216244697571, 72.35903844237328, 69.1876982152462, 63.04714031517506, 70.08956462144852, 75.96411779522896, 83.31069678068161, 73.21172788739204, 75.37638053297997, 78.38659420609474, 75.41495606303215, 71.20493397116661, 74.28165167570114, 72.43669867515564, 70.8285641670227, 77.95075759291649, 76.84580728411674, 73.27211424708366, 63.34560289978981, 36.16940796375275, 36.82716406881809, 35.95086649060249, 57.91058734059334, 70.2677370607853, 68.06238859891891, 75.97345769405365, 71.19741037487984, 65.85402309894562, 59.23870727419853, 58.831319734454155, 70.91577708721161, 73.10025706887245, 74.52271074056625, 74.72669139504433, 77.6891416311264, 79.50241953134537, 81.6511358320713, 78.37141782045364, 76.65680542588234, 77.78147667646408, 74.17921677231789, 68.10814574360847, 73.46305400133133, 68.25082048773766, 65.77406778931618, 80.49371793866158, 89.01817291975021, 86.93732857704163, 66.54180899262428, 71.76964446902275, 77.90097266435623, 56.48598298430443, 17.44803674519062, 1.1141914129257202, 0.08968614958575927, 0.3851466503692791, 2.111053434200585, 0.9080417279619724, 1.5800937940366566, 3.518957211636007, 0.9953305847011507, 0.10934980498859659, 0.13841465319273993, 11.250188369303942, 57.02975280582905, 53.273114785552025, 18.44308365136385, 28.28696083277464, 48.565756380558014, 50.4348798841238, 26.394592076539993, 1.494360538199544, 0.11101656476967037, 0.3218381287297234, 0.018563705343694892, 0.10936383900116198, 0.019125616890960373, 0.05898230163438711, 0.049647961495793425, 0.05447897550766356, 0.009305432558903703, 0.10295637344825082, 0.09483811649261042, 0.04567463642160874, 0.060362343792803586, 0.04977350319677498, 0.038121877441881225, 0.019850533753924537, 0.01999141379201319, 0.05627132522931788, 0.027959239268966485, 0.047797668594284914, 0.08640560452477075, 0.01633663890970638, 0.04285313938453328, 0.02338121226785006, 0.02479579212376848, 0.03049261973501416, 0.03554940805770457, 0.04971903697878588, 0.08074246856267564, 0.014559801002178574, 0.012294587249925826, 0.023770845364197157, 0.05156675091711804, 0.026128750578209292, 0.07359321156400256, 0.065604110568529, 0.001850383466717176, 0.0602646066545276, 0.05881381184735801, 0.0337776084052166, 0.07062061325996183, 0.018847530445782468, 0.04562467504001688, 0.05536898868740536, 0.012557817753986456, 0.018498732169973664, 0.04603563189448323, 0.025874602106341626, 0.05797252437332645, 0.022176524762471672, 0.07561180129414424, 0.026358534341852646, 0.0739251148479525, 0.06152153393486515, 0.02970440880744718, 0.07187983006588183, 0.045900590703240596, 0.02061794228211511, 0.015113847639440792, 0.10376168531365693, 0.010368056300649187, 0.08667115980642848, 0.11559338949155062, 0.08249310587416403, 0.15074981551151723, 0.024246122302429285, 0.017561327294970397, 0.011568718582566362, 0.01883073193312157, 0.034331232018303126, 0.08547830584575422, 0.021217410212557297, 0.0834782698075287, 0.0331658820505254, 0.09504272660706192, 0.09677438720245846, 0.26399359514471143, 3.7080638017505407, 38.04545469582081, 76.3841624557972, 60.584431663155556, 39.62949849665165, 28.090560771524906, 60.40786273777485, 93.61871525645256, 51.07512652873993, 4.643684746697545, 0.4627558827633038, 0.5579440109431744, 1.1629669019021094, 0.4514804034261033, 0.7582791766617447, 0.3893816121853888, 0.7504711300134659, 1.0107744997367263, 0.22097966575529426, 13.756888210773468, 61.73979766666889, 81.95408597588539, 79.58304360508919, 79.14363518357277, 89.45349276065826, 86.12556293606758, 76.75446018576622, 75.21286010742188, 74.8521226644516, 72.6418724656105, 68.35565686225891, 73.88187512755394, 79.01764914393425, 85.26525869965553, 77.28900030255318, 79.59550693631172, 78.84555637836456, 78.92024517059326, 75.04395917057991, 77.00834736227989, 72.42966145277023, 69.67629879713058, 69.30870652198792, 72.8812824189663, 72.23031654953957, 65.0300145149231, 41.86426118016243, 42.8826255351305, 40.545237958431244, 58.421238139271736, 75.42321681976318, 72.7444289624691, 80.11271238327026, 72.79859885573387, 70.41782900691032, 60.16024522483349, 60.01046106219292, 71.27341389656067, 76.23562082648277, 74.66271802783012, 77.11158782243729, 75.8099676668644, 78.2237197458744, 81.19578346610069, 76.55664280056953, 77.31587246060371, 76.56868055462837, 73.32559257745743, 75.44468566775322, 79.64545145630836, 72.50317990779877, 73.05383875966072, 81.07224449515343, 84.03866171836853, 84.68394309282303, 65.5959865450859, 72.25332051515579, 82.62148216366768, 61.247515082359314, 22.997745350003242, 2.2200992703437805, 0.16052330669481307, 2.426928346976638, 3.329177345149219, 2.941201301291585, 1.8060508067719638, 1.357766417786479, 0.3304847131948918, 0.01756266316078836, 0.2390670811291784, 9.416204430162907, 56.280809193849564, 73.67670133709908, 26.628488525748253, 16.64393149316311, 40.27613639831543, 59.03687350451946, 37.196903228759766, 3.848907994106412, 0.17436271329643205, 0.27531446423381567, 0.05228778449236415, 0.026554902906354982, 0.14581981755327433, 0.03454309291555546, 0.032837132894201204, 0.0483875535428524, 0.06309728414635174, 0.044332896504784, 0.05594800859398674, 0.1259630182175897, 0.09191304532578215, 0.0934534618863836, 0.1068791731086094, 0.04046096364618279, 0.030398858652915806, 0.0648302212357521, 0.02810269084875472, 0.03495706660032738, 0.04234541760524735, 0.01777865967596881, 0.07202705732197501, 0.025261998162022792, 0.02021747568505816, 0.08206110913306475, 0.023856784209783655, 0.054488389650941826, 0.04096502292668447, 0.015740217495476827, 0.021484082426468376, 0.0076302637808112195, 0.04505608601903077, 0.050416733720339835, 0.005096923669043463, 0.15635040326742455, 0.14215492905350402, 0.12958131468622014, 0.15136510046431795, 0.08723315855604596, 0.23095570388250053, 0.2332184973056428, 0.1157069529290311, 0.2166976369335316, 0.1470866339514032, 0.08909055381081998, 0.15886892593698576, 0.25475510337855667, 0.1013850315939635, 0.08446255800663494, 0.11899594363057986, 0.12096681326511316, 0.11143991549033672, 0.22110606834758073, 0.09773850382771343, 0.2543934399727732, 0.14701737673021853, 0.1669718130142428, 0.09848398374742828, 0.23837479093344882, 0.09958305992768146, 0.2173617552034557, 0.38048361777327955, 0.19065125175984576, 0.30533852346707135, 0.09908625885145739, 0.10592152058961801, 0.1681305727106519, 0.17078899021726102, 0.12425090579199605, 0.23253560269949958, 0.3333766548894346, 0.1550767887965776, 0.08561561058741063, 0.21086514287162572, 0.16323630174156278, 0.4336598940426484, 2.713691834360361, 37.48860977590084, 89.79161381721497, 80.20793527364731, 62.124029248952866, 44.53750893473625, 54.51210290193558, 79.52116012573242, 68.83255407214165, 15.963325314223766, 1.193410512059927, 1.5332408831454813, 4.927072115242481, 2.1853555971756577, 1.976486979983747, 0.18740143161267042, 0.43531722854822874, 0.3810278495075181, 0.27649317285977304, 11.246127337217331, 54.224317744374275, 82.6665249466896, 82.76012152433395, 73.24357777833939, 89.70586001873016, 92.20108732581139, 84.35854375362396, 81.30996733903885, 78.56434106826782, 76.42474427819252, 70.3610448539257, 75.48722058534622, 81.4395023882389, 85.96809178590775, 76.26405090093613, 80.52164644002914, 84.28564846515656, 83.41622471809387, 75.64184188842773, 79.57254856824875, 76.45796969532967, 71.08514919877052, 74.45081099867821, 76.42720654606819, 70.27429550886154, 61.643286645412445, 45.547274351119995, 46.0568156093359, 50.935339629650116, 62.72049464285374, 74.54525113105774, 76.59641146659851, 82.38530963659286, 74.8846261203289, 72.91938677430153, 64.5208190381527, 66.0859702527523, 76.34029760956764, 82.35904544591904, 83.81613045930862, 83.72347623109818, 84.39573615789413, 86.38388827443123, 88.72104406356812, 79.90938529372215, 84.731425344944, 81.17748364806175, 79.55504670739174, 81.57064095139503, 79.16599318385124, 70.61874702572823, 71.34820148348808, 77.6004695892334, 84.95088636875153, 87.41629287600517, 66.419797539711, 78.50032970309258, 83.6717914044857, 60.68686656653881, 20.871026068925858, 2.079781824722886, 0.17499607696663588, 1.6669802879914641, 5.4947892017662525, 5.537782944738865, 8.821389097720385, 15.1083217933774, 3.2498568389564753, 0.21790410188259557, 0.32763287716079503, 17.751824744045734, 67.61824563145638, 61.34595260024071, 29.057456888258457, 43.742264807224274, 59.738198071718216, 68.85603681206703, 43.40921647846699, 4.263780657202005, 0.3139163850573823, 0.403391252621077, 0.2546229417202994, 0.1801444444572553, 0.14962375484174117, 0.21862759196665138, 0.16019861708628014, 0.2183360021444969, 0.17307136149611324, 0.23314315447350964, 0.25848139717709273, 0.25862252397928387, 0.17553993762703612, 0.20991088938899338, 0.20269394852221012, 0.24110772006679326, 0.15189227764494717, 0.1180709530308377, 0.15068596112541854, 0.14293557935161516, 0.1943268717150204, 0.1313234618282877, 0.1384861665428616, 0.11519283754751086, 0.08541275936295278, 0.12606494477950037, 0.1424720190698281, 0.21839354827534407, 0.1264722947962582, 0.07558256809716113, 0.060406939446693286, 0.11421884293667972, 0.15291189949493855, 0.11130448096082546, 0.12837339512770995], [0.0689693792082835, 0.029188627304392867, 0.06403254606993869, 0.05680920046870597, 0.10508042978472076, 0.023369419541268144, 0.013520955671992851, 0.06831794424215332, 0.025402774299436715, 0.024396303306275513, 0.06781703166780062, 0.018257446972711477, 0.08286078067612834, 0.047143550764303654, 0.08243177479016595, 0.010469403059687465, 0.044793536435463466, 0.035052183957304806, 0.034173002422903664, 0.04883024092123378, 0.05523220715986099, 0.020176043435640167, 0.05447916846605949, 0.04583362671837676, 0.0472217100468697, 0.08194232097594067, 0.05896440845390316, 0.04182126096566208, 0.07406493547023274, 0.06852352657006122, 0.11496263818116859, 0.023497825932281557, 0.015131565487536136, 0.015251584682118846, 0.01949710633198265, 0.06063619257474784, 0.039262717982637696, 0.022677882625430357, 0.11909887209185399, 0.044356504222378135, 0.05616647089482285, 0.042725983512355015, 0.13826657988829538, 0.09089818806387484, 13.004424087703228, 53.255107551813126, 62.91533678770065, 61.450070813298225, 33.673348501324654, 20.696296244859695, 43.72199289500713, 66.75807818770409, 39.609025195240974, 3.323931726627052, 0.8774361514952034, 2.8449847642332315, 0.41669626836664975, 2.354293819516897, 0.3405794355785474, 1.2653185660019517, 1.1881796177476645, 0.19739513285458088, 0.04185777092061471, 28.883984796702862, 78.98534327745438, 90.62658101320267, 71.9203519821167, 68.5277496278286, 74.82015118002892, 82.43571013212204, 83.70530560612679, 83.03428441286087, 78.04608687758446, 80.8057875931263, 78.18268194794655, 77.85076975822449, 80.55311635136604, 70.47832176089287, 74.85068634152412, 75.58349221944809, 79.46218729019165, 70.16121357679367, 74.53316777944565, 71.58630430698395, 71.57105192542076, 64.280975908041, 89.20614883303642, 64.76039618253708, 52.76526063680649, 55.517540350556374, 39.89286996424198, 69.9824483692646, 57.95423939824104, 74.03527289628983, 66.00834801793098, 83.24673861265182, 72.96544790267944, 76.82319849729538, 72.62084439396858, 80.32851800322533, 76.7282871901989, 79.85581576824188, 76.63795843720436, 79.67027172446251, 73.58358353376389, 77.7583435177803, 76.48443147540092, 78.50453227758408, 73.37267205119133, 76.45391911268234, 86.12655848264694, 92.88720890879631, 88.46778765320778, 85.19504606723785, 73.94051358103752, 65.43814301490784, 75.00126466155052, 89.3642507493496, 73.22383403778076, 29.099334441125393, 2.5675053661689162, 0.08779245588812046, 0.29194735921919346, 0.9972507879137993, 3.463391843251884, 1.5321002318523824, 4.670499907806516, 1.458596857264638, 0.8517013199161738, 0.2424945417442359, 3.1367592327296734, 35.320609509944916, 65.53965076804161, 44.12413291633129, 21.722858659923077, 35.56059703230858, 55.99284544587135, 42.97960393130779, 14.415307380259037, 0.013910075758758467, 0.10281500915880315, 0.06690981550491415, 0.05190271374885924, 0.035426304311840795, 0.038319444574881345, 0.10176483308896422, 0.059430948458611965, 0.05765729343693238, 0.08779238909482956, 0.02399238943326054, 0.05887410763534717, 0.08266267177532427, 0.05943999523879029, 0.05421175781521015, 0.0369042505917605, 0.02843801357812481, 0.045624470949405804, 0.07215544144855812, 0.05358096939744428, 0.04851304700423498, 0.020161050197202712, 0.059544994292082265, 0.04311062381020747, 0.0632722231966909, 0.04071874122018926, 0.012667171358771157, 0.08191248663933948, 0.10101582054630853, 0.05891242471989244, 0.09366858081193641, 0.03246837826736737, 0.053327926725614816, 0.0068194280174793676, 0.04350207331299316, 0.052190414717188105, 0.027910951430385467, 0.02659319587110076, 0.0367493272642605, 0.047530640149489045, 0.04365605411294382, 0.08577788117690943, 0.015209721987048397, 0.09708620054880157, 0.01988913099921774, 0.0208627675237949, 0.023528131532657426, 0.025191462591465097, 0.01967868574865861, 0.05885680075152777, 0.03512085117108654, 0.06932842283276841, 0.04858576263359282, 0.06763355791918002, 0.05314904687111266, 0.03616839261667337, 0.00769904741900973, 0.020855075163126457, 0.01946248514286708, 0.04099463461898267, 0.04444362493813969, 0.06378212317940779, 0.07427156422636472, 0.11539502083905973, 0.033230627013836056, 0.07255064250784926, 0.06545618569361977, 0.03820906866167206, 0.010982978528772946, 0.010910226719715865, 0.03991858357039746, 0.08426452332059853, 0.020021943892061245, 0.06567591335624456, 0.06855965431896038, 0.06553327257279307, 0.051794237733702175, 0.04673258648836054, 0.01341429328022059, 0.14424371853237972, 0.6989602628163993, 20.61355948448181, 64.96762946248055, 74.10641267895699, 52.8136320412159, 27.628604359924793, 32.525285705924034, 76.97320684790611, 91.99116379022598, 33.132006749510765, 1.5342640969902277, 0.5974498379509896, 1.0359922028146684, 1.541607677936554, 1.0547908628359437, 0.8647139591630548, 3.5027890792116523, 1.927226185798645, 0.43984747608192265, 1.7757264152169228, 40.9357164055109, 88.20253148674965, 83.01388710737228, 71.64254128932953, 73.71481329202652, 84.62481826543808, 88.431955575943, 87.19586670398712, 82.34697729349136, 76.79761826992035, 80.34329921007156, 79.52982366085052, 80.72333961725235, 77.74943679571152, 70.85979849100113, 77.38006621599197, 76.34777560830116, 76.64271578192711, 73.78164410591125, 79.1107365489006, 76.12203732132912, 77.91659742593765, 69.51438948512077, 79.46246847510338, 69.4205193221569, 54.915485456585884, 55.13683497905731, 48.04396837949753, 63.538754135370255, 70.60094878077507, 73.72172132134438, 72.04093471169472, 84.71449345350266, 75.93376502394676, 75.59178337454796, 73.73219355940819, 81.14264711737633, 76.50347605347633, 83.0813866853714, 80.21439492702484, 82.46543973684311, 80.09944349527359, 82.69307032227516, 80.70762366056442, 77.7833841741085, 78.84332969784737, 77.71532222628593, 77.73060500621796, 86.6411192715168, 84.8204393684864, 79.48119387030602, 80.96944481134415, 73.51194217801094, 79.04198303818703, 84.4449283182621, 79.45923864841461, 35.217182859778404, 6.1028943210840225, 0.3337845689384267, 1.1431249603629112, 4.751908639445901, 3.836087007075548, 2.262372951954603, 1.886070950422436, 0.7808325695805252, 0.5641195108182728, 0.23947775596752763, 1.831422164104879, 32.25070483982563, 77.13342145085335, 61.2802617251873, 27.35698163509369, 25.63126813620329, 53.84241543710232, 53.2203584164381, 20.413999892771244, 0.430634721997194, 0.13910836831200868, 0.14797572686802596, 0.10368773771915585, 0.027945112487941515, 0.03859796888718847, 0.03219687096134294, 0.019771649022004567, 0.06317037084954791, 0.06264567986363545, 0.038175308363861404, 0.04109534034796525, 0.04743850622617174, 0.057334384982823394, 0.011734641466318863, 0.10870077458093874, 0.025661999061412644, 0.03283810510765761, 0.061449118875316344, 0.055099667006288655, 0.04038273385958746, 0.03368904050148558, 0.06856850814074278, 0.06029487514751963, 0.07204175926744938, 0.02478842630807776, 0.03515775817504618, 0.06307858944637701, 0.03557886760972906, 0.024310819026140962, 0.036614297205233015, 0.04558087348414119, 0.0329996038635727, 0.034210046724183485, 0.03627096113632433, 0.01773428110027453, 0.07381918811006472, 0.12324692841502838, 0.18879107345128432, 0.21449982596095651, 0.11693726308294572, 0.18924136413261294, 0.09310535751865245, 0.23229372192872688, 0.18234837072668597, 0.15059840254252777, 0.08269381229183637, 0.17101466248277575, 0.04288592746888753, 0.11777761174016632, 0.1474964478984475, 0.10947968825348653, 0.17473994696047157, 0.16134538367623463, 0.1301500224508345, 0.08521026436937973, 0.13807191455271095, 0.1647165004396811, 0.14954167330870405, 0.07099581343936734, 0.14222547761164606, 0.19423307909164578, 0.15688265673816204, 0.19526055286405608, 0.13835207530064508, 0.13692722597625107, 0.17794295243220404, 0.18328700942220166, 0.06805149096180685, 0.09577062504831702, 0.11756843741750345, 0.2138768820441328, 0.11301226666546427, 0.10895942788920365, 0.21366900647990406, 0.16154603072209284, 0.13108517305226997, 0.22530013782670721, 0.11120517418021336, 0.25976932025514543, 0.3392263816203922, 17.085445001721382, 77.51265630126, 88.36305007338524, 75.89198246598244, 47.25764997303486, 39.090269431471825, 62.539426758885384, 84.42905277013779, 52.71288424730301, 5.247121816501021, 1.0059486399404705, 5.916605042293668, 6.43467066809535, 12.791706752032042, 1.7873060563579202, 1.7315615038387477, 1.9602410704828799, 0.3103627444943413, 0.7648700417485088, 34.60369437932968, 88.83269727230072, 87.04074382781982, 74.873386323452, 72.04710558056831, 81.59825026988983, 88.7894555926323, 92.43986651301384, 88.68696749210358, 82.16875925660133, 89.21690225601196, 83.4659792482853, 85.79375714063644, 83.78415137529373, 69.76389929652214, 75.50439566373825, 78.12837526202202, 84.71620336174965, 77.87603840231895, 80.65906226634979, 80.30575722455978, 78.14433440566063, 68.0375911295414, 85.6040409207344, 75.65637990832329, 74.84092846512794, 65.21252632141113, 56.684358939528465, 72.0085072517395, 68.83793458342552, 79.74195867776871, 75.01061215996742, 91.31512686610222, 83.31442058086395, 80.43368875980377, 77.89683848619461, 83.26923340559006, 78.37175980210304, 80.97775116562843, 78.47275078296661, 81.17318227887154, 76.44686669111252, 83.15141692757607, 79.9853964149952, 79.99576985836029, 80.75319841504097, 77.37744435667992, 81.1938227713108, 101.93482741713524, 101.11233875155449, 93.66306647658348, 87.2142805159092, 73.761186003685, 85.34185498952866, 90.38267210125923, 79.86968502402306, 32.568504586815834, 3.8068169401958585, 0.18849872663849965, 0.3680472413543612, 3.6996548529714346, 9.266993086785078, 6.84669965878129, 12.396045383065939, 9.492330495268106, 3.169766874052584, 0.2667364838998765, 4.841156825423241, 45.40043123066425, 76.86890244483948, 55.43077200651169, 36.46227344870567, 47.376583591103554, 68.38551566004753, 62.01945886015892, 24.215821288526058, 0.5340406810864806, 0.23327337170485407, 0.26493683515582234, 0.42251357808709145, 0.13557706639403477, 0.13005977729335427, 0.1788494412903674, 0.18839433614630252, 0.1449754019267857, 0.1580658182501793, 0.18787677719956264, 0.10601472691632807, 0.2301066424115561, 0.16922832786804065, 0.1332098973216489, 0.2369650368927978, 0.11147504876134917, 0.09419435533345677, 0.17014195618685335, 0.07715401385212317, 0.13724617136176676, 0.15227595315082, 0.20104373863432556, 0.2164547171560116, 0.12401660977047868, 0.11977261601714417, 0.07467650968465023, 0.1696331545826979, 0.2118375344434753, 0.10468642358318903, 0.15905127162113786, 0.09497945851762779, 0.1462849066592753, 0.06979434314416721, 0.13996284746099263, 0.13343485712539405, 0.10768680047476664], [0.06159873213618994, 0.05575733972364105, 0.15677013230742887, 0.025878728447423782, 0.03924417542293668, 0.05219846701947972, 0.007414975552819669, 0.08625031012343243, 0.05502196043380536, 0.020346971177787054, 0.047998690424719825, 0.04452217384823598, 0.021361431390687358, 0.07010002635070123, 0.07601135133882053, 0.04297333762224298, 0.03286751642008312, 0.025899241409206297, 0.09386103454744443, 0.04880243264778983, 0.042453548521734774, 0.2049270857241936, 0.09465352952247486, 0.04387856482935604, 0.015087335341377184, 0.008468383675790392, 0.06423284430638887, 0.04945447617501486, 0.01721250118862372, 0.06647604503086768, 0.04086357505002525, 0.05276165691611823, 0.03626987017923966, 0.08080668660113588, 0.05648226215271279, 0.1009325664199423, 0.003382267532288097, 0.01999775729927933, 0.03888182181981392, 0.06551552782184444, 0.06624678819207475, 0.0494045593222836, 0.03954284904466476, 0.11881677433848381, 0.18011196807492524, 3.2024976052343845, 24.2769543081522, 49.29066248238087, 62.41102784872055, 46.60455621778965, 22.2292422875762, 26.494142934679985, 43.55667896568775, 60.643051117658615, 23.53073514997959, 2.328114411793649, 1.004724868107587, 1.565973514225334, 3.415035638026893, 1.4508813712745905, 2.0404696092009544, 0.9086977271363139, 0.21016578743001446, 0.43094986758660525, 4.420040147379041, 44.6390812844038, 92.11932331323624, 102.39962607622147, 88.24672311544418, 75.40937796235085, 73.04250776767731, 74.47211265563965, 76.79430484771729, 77.37756595015526, 77.92716845870018, 80.38523375988007, 78.1240662932396, 74.69535827636719, 80.52305236458778, 77.2252245247364, 72.29164525866508, 76.53078138828278, 80.1643668115139, 76.52600884437561, 79.77060154080391, 85.97944557666779, 64.86050561070442, 15.854187570512295, 14.04556442052126, 40.09192228317261, 20.390188470482826, 85.68046241998672, 50.90790130198002, 63.42755690217018, 80.49013093113899, 79.02796179056168, 78.8508988916874, 72.79042929410934, 69.84605088829994, 72.21193313598633, 76.56464517116547, 73.46012815833092, 75.37245914340019, 77.52525642514229, 81.93388625979424, 87.16595470905304, 86.66785463690758, 87.5648421049118, 85.35846769809723, 85.55675625801086, 63.66787500679493, 66.27884030342102, 79.03860121965408, 79.42644640803337, 83.58559682965279, 95.53626716136932, 88.26042518019676, 34.2794843763113, 5.6921677105128765, 0.13521333981771022, 0.07691490129218437, 4.882905660197139, 1.7765534645877779, 2.347430675290525, 3.032758100889623, 1.434412223752588, 1.2162846908904612, 0.4129861533874646, 0.8707961265463382, 19.944886565208435, 62.27965749800205, 56.51452325284481, 32.85258114337921, 30.123615078628063, 48.63056570291519, 53.15790496766567, 31.478451378643513, 4.2025307938456535, 0.15509149816352874, 0.008979182584880618, 0.12324150331551209, 0.05229571062955074, 0.11207201750949025, 0.0642862195672933, 0.10382531705545262, 0.07246448658406734, 0.02514909894671291, 0.045484112270059995, 0.09371189255034551, 0.05457168088469189, 0.04721291930763982, 0.025739562770468183, 0.09490394499152899, 0.024608091844129376, 0.04933509429974947, 0.08275975953438319, 0.035184245425625704, 0.06113711999205407, 0.05770024152297992, 0.01802070371923037, 0.07867702704970725, 0.0141366330353776, 0.02624793392897118, 0.034451931205694564, 0.04323269226006232, 0.04805930162547156, 0.06408607718185522, 0.07407314362353645, 0.06449975771829486, 0.011868161254824372, 0.00919213351153303, 0.04515294000157155, 0.0503640449460363, 0.03446976872510277, 0.03611380023357924, 0.05943556832789909, 0.015273042026819894, 0.017724406825436745, 0.029444310166582, 0.07373434578767046, 0.034728451719274744, 0.035063831965089776, 0.03884782032400835, 0.07375744142336771, 0.02338055917789461, 0.05004728889616672, 0.027852516577695496, 0.04134840899496339, 0.014761205038666958, 0.03287315303168725, 0.0702227107831277, 0.056499331549275666, 0.02840742039552424, 0.02544095965276938, 0.06571451987838373, 0.038557648003916256, 0.039851905312389135, 0.062128818535711616, 0.02730395812250208, 0.030509394127875566, 0.006565623716596747, 0.06965322376345284, 0.09106503770453855, 0.05662829084030818, 0.041451864381087944, 0.10466837455169298, 0.01888135011540726, 0.012972943623026367, 0.008899178137653507, 0.09835229706368409, 0.070559623563895, 0.08183919955627061, 0.023728771157038864, 0.06147643733129371, 0.04236527376633603, 0.062006289954297245, 0.056903011645772494, 0.065667096641846, 0.05476845020893961, 0.12203756166854873, 0.12672959739575163, 6.697775674983859, 34.52719688415527, 68.75260636210442, 61.98971025645733, 32.758935168385506, 19.5731658115983, 44.56356793642044, 92.0000933110714, 80.53845673799515, 19.6053234860301, 1.0560698504559696, 0.3024762083077803, 1.928484512027353, 1.391951758414507, 2.2154107969254255, 4.839199455454946, 2.97054142691195, 0.28499183245003223, 0.2613467996707186, 10.453927796334028, 58.41137766838074, 98.12833607196808, 93.9387720823288, 82.36729860305786, 73.3693890273571, 76.94914653897285, 77.44239047169685, 80.89619994163513, 81.35967627167702, 85.33094197511673, 79.56275269389153, 78.1526255607605, 75.96592649817467, 82.57147684693336, 80.75274243950844, 78.92466813325882, 74.66485351324081, 76.99260100722313, 69.87101554870605, 70.63727483153343, 74.01107579469681, 74.85283702611923, 27.504909597337246, 29.52411364763975, 61.49645872414112, 41.405990570783615, 82.57890924811363, 52.269197255373, 77.97541826963425, 81.26545652747154, 82.82223299145699, 78.15311953425407, 77.85450115799904, 74.49688732624054, 79.72919896245003, 80.22479116916656, 77.5148069858551, 79.08820375800133, 76.95804566144943, 79.56996470689774, 86.83291777968407, 83.07431906461716, 88.40317592024803, 84.13833796977997, 85.97656533122063, 80.12590527534485, 68.13499510288239, 78.33291068673134, 86.80866748094559, 81.22804373502731, 88.21417406201363, 86.73865243792534, 46.38292171061039, 9.323952030390501, 0.714674616465345, 0.3194896172499284, 6.307347575202584, 6.3359662145376205, 4.249586518853903, 2.4241563957184553, 1.0014362633228302, 0.7489139260724187, 0.097693581628846, 0.4089676315197721, 18.111783228814602, 68.15488323569298, 70.12727379798889, 45.31177058815956, 28.29015266150236, 44.14368286728859, 62.674684301018715, 40.180544927716255, 7.059925217181444, 0.005029551966799772, 0.11508495153975673, 0.05568113971094135, 0.022903794233570807, 0.17075976444175467, 0.036212850973242894, 0.06204240286024287, 0.0378464293316938, 0.014684501293231733, 0.06457432129536755, 0.09693146275822073, 0.07105867334757932, 0.045791706506861374, 0.010004986525018467, 0.09128693985985592, 0.047299390644184314, 0.07995513893547468, 0.07931818327051587, 0.028171033372927923, 0.05616668611764908, 0.04453058980288915, 0.03661562564957421, 0.05478316328662913, 0.031733154828543775, 0.033566497077117674, 0.06880198779981583, 0.0709437888872344, 0.0491283764858963, 0.05144723545527086, 0.030385772734007332, 0.04911302887194324, 0.024458563930238597, 0.03636484281742014, 0.053891695497441106, 0.0387042184593156, 0.029106276742822956, 0.05973057202936616, 0.051616018390632235, 0.13655432645464316, 0.11252479438553564, 0.18601337797008455, 0.13234844198450446, 0.1493558840593323, 0.13974995497846976, 0.144155966991093, 0.2117085046484135, 0.17822810041252524, 0.1567152579082176, 0.08057875820668414, 0.09565190368448384, 0.16345189564162865, 0.2792824013158679, 0.17071188107365742, 0.15609031019266695, 0.12849043181631714, 0.08042946778004989, 0.28897630458232015, 0.20775195211172104, 0.136627487372607, 0.22174185141921043, 0.11811984571977518, 0.19587776740081608, 0.2560120343696326, 0.1984855704358779, 0.20815572497667745, 0.13855064433300868, 0.09891540161333978, 0.1708896254422143, 0.16885817429283634, 0.16949192387983203, 0.09619866614229977, 0.3030649689026177, 0.19165370031259954, 0.19450019288342446, 0.160654429346323, 0.20787859219126403, 0.19399934710236266, 0.16014029912184924, 0.09959221803001128, 0.11912813497474417, 0.11203312897123396, 0.20784065360203385, 0.2466073163668625, 5.922922678291798, 43.5321094840765, 85.02873659133911, 85.01068755984306, 57.53859490156174, 38.41127626597881, 39.120891988277435, 62.54377752542496, 76.57254874706268, 36.757468208670616, 4.154233485460281, 1.9413405284285545, 5.72219654917717, 13.668982777744532, 5.3989022970199585, 4.078743411228061, 2.068437533453107, 0.6268357986118644, 0.5399399832822382, 8.216993529349566, 47.86299929022789, 93.63557875156403, 98.99107977747917, 88.29628765583038, 74.94059711694717, 77.38320484757423, 79.64214563369751, 85.96343323588371, 83.2000695168972, 86.57982856035233, 76.5828537940979, 72.16184422373772, 81.84220477938652, 89.32804629206657, 80.9541392326355, 69.15684387087822, 75.41501685976982, 79.1375783085823, 71.79337039589882, 70.57787641882896, 78.58235210180283, 62.24843457341194, 17.6779206097126, 20.82896612584591, 62.89264440536499, 46.76062524318695, 99.07424971461296, 57.81520865857601, 76.89553141593933, 93.58169004321098, 81.27988055348396, 83.95375147461891, 80.5998158454895, 79.21472176909447, 80.5750259757042, 89.6360881626606, 82.83959046006203, 86.03649571537971, 81.0253170132637, 86.31624430418015, 91.41443833708763, 88.32000598311424, 97.71909803152084, 88.59329491853714, 95.3302726149559, 77.23787024617195, 46.686384826898575, 68.31984758377075, 84.159115254879, 90.37368178367615, 100.43462231755257, 90.3131814301014, 36.17592841386795, 5.439227633178234, 0.2933136827778071, 0.1687964127631858, 7.890909751877189, 8.643104564398527, 7.484906762838364, 10.554748736321926, 11.553085315972567, 6.9599649310112, 1.052430714480579, 1.7017581593245268, 27.693280689418316, 76.10249876976013, 69.52040076255798, 47.89226531982422, 42.90667064487934, 61.187782287597656, 72.44046047329903, 48.06836687028408, 7.791541758924723, 0.1673849072540179, 0.2997576619964093, 0.2506761410040781, 0.09947384547558613, 0.26153325685299933, 0.14756889635464177, 0.27529116079676896, 0.11094243163825013, 0.18274867034051567, 0.08517258553183638, 0.28805393376387656, 0.1315334450919181, 0.18901774019468576, 0.13037146447459236, 0.18172584241256118, 0.18760249426122755, 0.1455150471883826, 0.18047254794510081, 0.07816188008291647, 0.18876883870689198, 0.1198063614720013, 0.14147831301670521, 0.17594566976185888, 0.11241915708524175, 0.09925095626385882, 0.19206692813895643, 0.17079580313293263, 0.1291565687279217, 0.15371205343399197, 0.11363037177943625, 0.14378861873410642, 0.09558198595186695, 0.1411295629804954, 0.2257198965526186, 0.22375684173312038, 0.11416589812142774, 0.17735275207087398, 0.2570025937166065], [0.04180933836323675, 0.024350330968445633, 0.056211519258795306, 0.015217497839330463, 0.020610474421118852, 0.10963731299852952, 0.038100934034446254, 0.2100674677058123, 0.040252535181934945, 0.24594897200586274, 0.025401362363481894, 0.07757599902106449, 0.04511057821218856, 0.04345380773884244, 0.04218892463541124, 0.08568375458708033, 0.1373910831171088, 0.05557100499572698, 0.0669127915170975, 0.006286984835242038, 0.18850729102268815, 0.03531113783537876, 0.14386209135409445, 0.12142741237767041, 0.03759468912903685, 0.032532176992390305, 0.02459222472680267, 0.03524214778735768, 0.09468167918385006, 0.1010852336185053, 0.058952949693775736, 0.13294125470565632, 0.016538901982130483, 0.05042921293352265, 0.09556016681017354, 0.07882823963882402, 0.05726446725020651, 0.016657552841934375, 0.04727289968286641, 0.011589975547394715, 0.1508290768833831, 0.0616386003093794, 0.10838409274583682, 0.04777406087669078, 0.11046989136957563, 0.13472662452841178, 0.22571725450688973, 6.634555142372847, 46.0214015096426, 69.5837053656578, 58.13907667994499, 39.47658710181713, 21.364414393901825, 27.87140943109989, 59.35777768492699, 59.93337079882622, 16.87804453074932, 0.888753131730482, 0.6968713842798024, 5.7028403878211975, 5.024057636037469, 4.278865847736597, 0.14156279910821468, 0.275402957922779, 0.1831268539535813, 0.06468078237958252, 6.684202803298831, 33.64833064377308, 60.75791135430336, 91.50696337223053, 94.61266592144966, 95.87919116020203, 90.06334483623505, 86.18810757994652, 82.80444234609604, 76.77831530570984, 79.489925801754, 89.06097382307053, 79.69210535287857, 74.25664141774178, 69.75060001015663, 74.23887357115746, 74.18331295251846, 74.54442277550697, 50.38352183997631, 20.862360633909702, 1.5055059338919818, 0.7764835841953754, 0.384892865549773, 3.6162887513637543, 4.2396334279328585, 29.960459433496, 89.4346609711647, 46.2463266402483, 64.5576998591423, 79.43854495882988, 89.35184061527252, 81.77938655018806, 86.47978752851486, 85.07763236761093, 82.04442992806435, 84.92395341396332, 84.01546016335487, 76.53737783432007, 71.18909642100334, 78.4823490679264, 71.86422139406204, 94.60597068071365, 86.99775293469429, 79.88349348306656, 87.52337113022804, 69.30083334445953, 94.4677796959877, 82.57546663284302, 70.69884672760963, 38.96647207438946, 5.433776825666428, 0.2699439274147153, 0.2972849743673578, 0.18192156159784645, 3.24591098818928, 8.120630700141191, 7.007192121818662, 7.570528043434024, 0.9208983380813152, 1.7222841829061508, 0.095595300081186, 9.294879790395498, 49.30128291249275, 60.345793068408966, 35.80901250243187, 28.023707158863544, 47.45976872742176, 58.149343729019165, 41.561501026153564, 13.48497860133648, 0.21620326268021017, 0.07914089161204174, 0.08911020588129759, 0.04693814284109976, 0.026292377442587167, 0.05243834028078709, 0.03778500176849775, 0.03070995953748934, 0.07689012098126113, 0.09520188759779558, 0.12540937605081126, 0.10359058316680603, 0.05898711817280855, 0.024587571460870095, 0.07757772080367431, 0.06892189659993164, 0.06361926629324444, 0.11352914283634163, 0.0601150824513752, 0.06354308483423665, 0.06703839258989319, 0.08350264193722978, 0.02479084756487282, 0.009634537018428091, 0.02437673472741153, 0.04796788387466222, 0.1303437229944393, 0.010570519752945984, 0.033994578989222646, 0.040653599207871594, 0.03041425450646784, 0.10848768171854317, 0.08610072283772752, 0.042093061420018785, 0.03180946245265659, 0.021920287144894246, 0.028900826146127656, 0.09253473501303233, 0.31418507220223546, 0.03805770764301997, 0.069719096791232, 0.05532289760594722, 0.03491486066195648, 0.03221016282623168, 0.05245664906396996, 0.014512221914628753, 0.02044882538029924, 0.019764236822084058, 0.05181688437005505, 0.23428040673024952, 0.012861336672358448, 0.04041180007334333, 0.011348701482347678, 0.04392880080558825, 0.06919912586454302, 0.09646172780776396, 0.1127753805485554, 0.08699373429408297, 0.053698915216955356, 0.028288854882703163, 0.1645938234287314, 0.022741442007827573, 0.1559532355167903, 0.036330696602817625, 0.006193803092173766, 0.07404018484521657, 0.04292919096769765, 0.01972345580725232, 0.00604219855631527, 0.08277722226921469, 0.017465627352066804, 0.03559905402653385, 0.047472207152168266, 0.08544492404325865, 0.06941243394976482, 0.08315176193718798, 0.04357241778052412, 0.04124822648009285, 0.02398676395387156, 0.038472794549306855, 0.015442775838891976, 0.04887767157924827, 0.07131788326660171, 0.06470803404226899, 0.013571905037679244, 0.16057258530054241, 0.5239791178610176, 12.845345623791218, 61.45724102854729, 79.75700587034225, 49.69947874546051, 22.579118013381958, 15.836599264293909, 52.45284520089626, 97.4732132256031, 65.48486530780792, 11.695417128503323, 1.018590205349028, 0.5773288488853723, 3.0426900554448366, 0.3633177123265341, 2.2088779974728823, 1.388278305530548, 0.7286493759602308, 0.42985956359189004, 0.19298095721751451, 12.391744013875723, 48.96015241742134, 74.72575664520264, 100.68259701132774, 93.58184203505516, 93.61791729927063, 87.58483663201332, 84.16519492864609, 78.99972930550575, 75.63440188765526, 76.13504022359848, 81.45786300301552, 81.23261868953705, 70.76394483447075, 64.70205411314964, 80.26501581072807, 86.92365691065788, 82.04904288053513, 65.02815261483192, 39.877925366163254, 11.124287825077772, 0.2287812705617398, 0.47826276160776615, 10.085554663091898, 12.248649392277002, 57.41075076162815, 86.39556884765625, 54.280854910612106, 79.34491038322449, 89.00817945599556, 95.26665642857552, 84.820606559515, 85.2832393348217, 83.49374815821648, 81.2108002603054, 85.35584583878517, 84.01767164468765, 77.14423567056656, 80.47871634364128, 80.12395977973938, 77.96310693025589, 87.50527650117874, 91.75706595182419, 80.08276239037514, 80.51515638828278, 58.33986930549145, 86.77775233983994, 88.65505680441856, 80.21346017718315, 61.105022728443146, 13.62050212919712, 0.9884835302364081, 2.344704084098339, 1.2259348668158054, 5.686471816152334, 6.799249704927206, 3.461748668923974, 0.9814789029769599, 1.8234555353410542, 0.6475109048187733, 0.13792517711408436, 7.848390508443117, 52.162704169750214, 78.74806880950928, 49.260055124759674, 34.465833976864815, 42.903133034706116, 59.087194204330444, 56.65241025388241, 17.55981344729662, 0.6220234755892307, 0.2692215802380815, 0.08779172858339734, 0.03814765594142955, 0.026407645964354742, 0.07699494191911072, 0.007453203115801443, 0.015549822292086901, 0.04989375709556043, 0.13152703293599188, 0.07006843312410638, 0.058768637318280526, 0.09972262079827487, 0.0538597386184847, 0.004589138807205018, 0.04419798518938478, 0.04047938375151716, 0.10242008269415237, 0.02150582364265574, 0.07139595720218495, 0.0699772009102162, 0.029874993306293618, 0.041848078471957706, 0.05775603618531022, 0.03306136168248486, 0.02303273868164979, 0.010426159042253857, 0.08560742469853722, 0.030362871912075207, 0.048670352625777014, 0.02535343632189324, 0.04202047195576597, 0.08809383463812992, 0.05246813379926607, 0.04689399247581605, 0.09340347081888467, 0.06909731062478386, 0.05417550761194434, 0.19336112978635356, 0.02573160694737453, 0.146578396379482, 0.2554161788430065, 0.15395626454846933, 0.11165886389790103, 0.18086642056005076, 0.18092451588017866, 0.18917945417342708, 0.25037334475200623, 0.10749364912044257, 0.5783033184707165, 0.09160541769233532, 0.1854253892088309, 0.13935507304267958, 0.23356839024927467, 0.17590639530681074, 0.16157420264789835, 0.2930650336202234, 0.27925817761570215, 0.14880019356496632, 0.12658422550885007, 0.22039997420506552, 0.15353655035141855, 0.26597643562126905, 0.15903829887975007, 0.19498260371619835, 0.20487188478000462, 0.18846430582925677, 0.20374626939883456, 0.18088274780893698, 0.17347185406833887, 0.19330812559928745, 0.24564121820731089, 0.11622485326370224, 0.15049199340865016, 0.28160657035186887, 0.1618039418826811, 0.34445101220626384, 0.13620147976325825, 0.1252491315244697, 0.13677073671715334, 0.26828700851183385, 0.14204911363776773, 0.2272149530472234, 0.2949101018020883, 0.14262202195823193, 0.2409727976191789, 0.4010988771915436, 15.485184621065855, 74.55586776137352, 94.08726051449776, 74.34282839298248, 58.21993254125118, 35.31602695584297, 45.01770816743374, 79.23523306846619, 79.10844907164574, 25.76562512665987, 1.7632576217874885, 1.1243797349743545, 18.067160323262215, 12.746674418449402, 12.004784177988768, 2.7926601469516754, 1.2879968178458512, 0.24398562032729387, 0.19807507371297106, 8.674566876143217, 36.24286562204361, 65.03381431102753, 100.38393303751945, 100.17517223954201, 98.13860312104225, 91.2748946249485, 93.17714855074883, 85.12554779648781, 80.41460618376732, 83.4809884428978, 82.7665127813816, 80.13063222169876, 74.81316715478897, 82.59381964802742, 94.42848220467567, 96.03375166654587, 86.65642485022545, 55.821968615055084, 26.0195617005229, 6.99480383656919, 0.48901205824222416, 0.45507527771405876, 6.518769655376673, 11.048333700746298, 52.44619935750961, 108.16815733909607, 58.1434540450573, 80.28282165527344, 97.54759043455124, 100.3426368534565, 90.03645747900009, 91.98595806956291, 87.33769789338112, 80.80393329262733, 82.18644350767136, 80.40522828698158, 73.8625417649746, 73.08189645409584, 79.03011247515678, 71.57951027154922, 83.04148882627487, 96.49308621883392, 76.62091255187988, 114.39549878239632, 83.94085496664047, 96.13490223884583, 97.77041047811508, 68.51588666439056, 46.074013486504555, 5.488635431975126, 0.45313209760934114, 1.3576058764010668, 1.1024602549150586, 7.388738673180342, 20.968251451849937, 21.0984343662858, 20.57167623192072, 9.483395274728537, 2.752310587093234, 0.46600286790635437, 14.83099652454257, 61.86801798641682, 76.51251956820488, 47.80574016273022, 44.021078646183014, 59.752671495079994, 72.36825674772263, 64.43892583251, 22.92644027620554, 1.0635991464369, 0.40137462958227843, 0.3618546127108857, 0.1806525484425947, 0.16938533663051203, 0.15120160533115268, 0.1948250160785392, 0.12641005829209462, 0.21187378093600273, 0.21200935647357255, 0.15903820982202888, 0.3125707822619006, 0.23944266722537577, 0.15871087816776708, 0.2419939186074771, 0.13513011537725106, 0.2154363866429776, 0.1705116793164052, 0.20122289308346808, 0.2707836526678875, 0.23390688380459324, 0.1424074819078669, 0.1572989422129467, 0.15691957116359845, 0.14169708330882713, 0.13252490985905752, 0.15369293570984155, 0.13801937049720436, 0.06858038250356913, 0.17283988563576713, 0.1285477404599078, 0.21731063607148826, 0.12647266587009653, 0.1676829537609592, 0.12187716129119508, 0.16793198883533478, 0.12689108873018995, 0.08155209972755983, 0.39935836277436465, 0.169153445167467], [0.051407801438472234, 0.04079424361407291, 0.026716149332060013, 0.018974946069647558, 0.05554005372687243, 0.0751707206654828, 0.04481819429202005, 0.046317250962601975, 0.1434090398834087, 0.07808784343069419, 0.041658166592242196, 0.021925693690718617, 0.06340590625768527, 0.10074964928207919, 0.06132159935077652, 0.12059547967510298, 0.05402997987403069, 0.028210302261868492, 0.05767558737716172, 0.09206467351759784, 0.04408330853038933, 0.004718605077869142, 0.0552534956659656, 0.0787616912566591, 0.04737390969239641, 0.04789313104993198, 0.015603415558871347, 0.01998157847992843, 0.08934995668823831, 0.11676196780172177, 0.06773091285140254, 0.11492187200929038, 0.027835534383484628, 0.05218702681304421, 0.10214412250206806, 0.019995076290797442, 0.19831478741252795, 0.026170212513534352, 0.025126324289885815, 0.025543594965711236, 0.1214772772800643, 0.0815360619162675, 0.018750086455838755, 0.07679436908802018, 0.02343693828152027, 0.14332676539197564, 0.07882236182922497, 0.025231742656615097, 1.56959792599082, 20.709156654775143, 59.94494877755642, 66.83580681681633, 68.65606114268303, 39.13945399224758, 26.4541956782341, 46.102276369929314, 68.1133970618248, 49.10612538456917, 10.974247176200151, 1.08714030822739, 0.7654475513845682, 3.814039402641356, 0.7576012099161744, 0.6276512704789639, 1.4623210136778653, 0.07702257949858904, 0.2602814615238458, 0.12568959617055953, 1.4848704286850989, 11.202159896492958, 33.7146332859993, 55.98152965307236, 65.92160627245903, 76.51812806725502, 74.8197104036808, 82.09709510207176, 59.68101114034653, 61.326201260089874, 66.99583902955055, 76.32605597376823, 77.98838317394257, 62.90815897285938, 44.20444540679455, 20.802764631807804, 4.557264558970928, 0.3136910987086594, 0.048346612966270186, 0.11381356351193972, 0.09809344337554649, 0.16225911589572206, 0.13030139089096338, 1.9562514033168554, 17.228891104459763, 79.56227391958237, 68.21579396724701, 65.82127645611763, 79.9753649532795, 81.79913029074669, 74.43635657429695, 72.50786885619164, 62.06325151026249, 66.48013830184937, 64.31023433804512, 82.3685297369957, 85.38210242986679, 97.68221721053123, 82.23296821117401, 77.18539506196976, 80.45217096805573, 65.22221580147743, 51.93608433008194, 50.506639033555984, 49.08198527991772, 22.335596680641174, 4.974288381636143, 0.2553194324718788, 0.4117923049489036, 0.13460722781019285, 0.5491538357455283, 28.088330291211605, 3.4973385091871023, 5.067448457702994, 1.39597776113078, 1.9708756310865283, 0.32931476191151887, 8.46982341259718, 41.92834474146366, 68.98415833711624, 48.82787771522999, 32.57708452641964, 38.197370544075966, 47.39357627928257, 40.2936876565218, 23.64108882844448, 2.5557060493156314, 0.08798248280072585, 0.020698975531558972, 0.08349984404048882, 0.03575399961846415, 0.17524195049190894, 0.046198143681976944, 0.034221568566863425, 0.0349457302945666, 0.07615706461365335, 0.11201229688595049, 0.0984820986923296, 0.043734243081416935, 0.03823233499133494, 0.02511421243980294, 0.04214351261907723, 0.04877578954619821, 0.01433289213309763, 0.0513514835620299, 0.05334234294423368, 0.0423826548649231, 0.057735404479899444, 0.04157215167651884, 0.04247052514983807, 0.06265345757128671, 0.06557202010299079, 0.049646655315882526, 0.031158394849626347, 0.15699276176746935, 0.10241821248200722, 0.13013002899242565, 0.16631351318210363, 0.03361783143191133, 0.08903871479560621, 0.1140993348963093, 0.04081854523974471, 0.02624646447657142, 0.014912276619725162, 0.06618317871470936, 0.10926957882475108, 0.02185204666602658, 0.039399655361194164, 0.007624068703080411, 0.03464038105448708, 0.02477652411471354, 0.07728956712526269, 0.022611026251979638, 0.0765716283058282, 0.07035135466139764, 0.05313534311426338, 0.08762566561927088, 0.08017708561965264, 0.06481211283244193, 0.046561076160287485, 0.08721331352717243, 0.04715482398751192, 0.04085712578671519, 0.041005436578416266, 0.12469182314816862, 0.04629674913303461, 0.05144898321304936, 0.050237059767823666, 0.00323788038258499, 0.016623517949483357, 0.006431880819945945, 0.02625980272568995, 0.0586951201694319, 0.07710676873102784, 0.042443507263669744, 0.07284853316377848, 0.05113976738357451, 0.09895355542539619, 0.017512735175841954, 0.0409012984164292, 0.03386586831766181, 0.012496256604208611, 0.038931159797357395, 0.06567413962329738, 0.017716974216455128, 0.038719603180652484, 0.044665397217613645, 0.02037112437392352, 0.024756116908974946, 0.0679802596278023, 0.07670681792660616, 0.060835993572254665, 0.11292119772406295, 0.17060553131159395, 0.03554166374669876, 0.3008111851522699, 2.843550341203809, 32.08291344344616, 71.54262185096741, 73.4112399816513, 47.69064053893089, 19.478465393185616, 30.27253858745098, 74.10835057497025, 90.32050743699074, 50.664972737431526, 6.085046678781509, 1.2219149200245738, 0.23831291066017002, 3.3540467731654644, 1.6470001288689673, 0.4763626557542011, 1.2380790151655674, 0.34005182795226574, 0.4632866074098274, 0.11868511734064668, 2.9637388419359922, 20.63171111047268, 48.77048559486866, 72.92272299528122, 81.39300048351288, 85.92976704239845, 85.51197186112404, 85.6804396212101, 79.12137597799301, 82.32490807771683, 77.80165359377861, 81.60510510206223, 83.0891002714634, 79.11168649792671, 69.6649070084095, 40.471149533987045, 9.707757085561752, 0.505431363126263, 0.2273820253321901, 0.6472506781574339, 0.4396909422939643, 0.0863045833830256, 0.1742570908390917, 3.381547797471285, 48.18625934422016, 86.93470671772957, 69.38660994172096, 69.76922661066055, 88.92696261405945, 90.9541842341423, 82.86174327135086, 81.64661407470703, 72.92230501770973, 75.16943603754044, 76.18062257766724, 84.00822535157204, 80.60379043221474, 95.5178153514862, 79.8164726793766, 82.45133489370346, 93.87855291366577, 73.26015248894691, 71.20307967066765, 66.70476704835892, 74.51885774731636, 34.0848246216774, 10.9895746037364, 0.7371813431382179, 1.0893244785256684, 1.0698963585309684, 3.1940841441974044, 34.47193644940853, 9.927701633423567, 3.0257391650229692, 4.536666814237833, 0.35388029529713094, 0.23039285908453166, 4.878771957010031, 42.483411356806755, 80.42597517371178, 65.19401371479034, 37.138086184859276, 35.95446489751339, 51.593236327171326, 56.023160219192505, 31.317944191396236, 3.954052864573896, 0.1854794769315049, 0.0513625267194584, 0.08805910212686285, 0.13046349078649655, 0.07409900004859082, 0.13086135615594685, 0.08583911578170955, 0.03815734467934817, 0.011194245707883965, 0.0825228585745208, 0.1009883388178423, 0.023853010388847906, 0.060955972876399755, 0.13385409634793177, 0.0593682852195343, 0.03871442298986949, 0.061335993304965086, 0.03451135125942528, 0.09255906261387281, 0.09417849563760683, 0.028771679462806787, 0.11339663236867636, 0.08123061619699001, 0.07779546693200245, 0.02681395511899609, 0.05349401937564835, 0.05823867708386388, 0.22275451192399487, 0.04676843593188096, 0.07063765297061764, 0.019245473740738817, 0.07217038088128902, 0.027084590401500463, 0.20844341110205278, 0.02731467473495286, 0.029116687219357118, 0.040700065073906444, 0.03994633247202728, 0.020598971132130828, 0.05134503800945822, 0.04103409461094998, 0.21880089829210192, 0.13754956133197993, 0.07334096299018711, 0.18834134680218995, 0.20477295649470761, 0.1251802156912163, 0.1127294787147548, 0.11430715851020068, 0.2457273073378019, 0.267382093006745, 0.11978610826190561, 0.16074896411737427, 0.126654046762269, 0.20143352943705395, 0.16319901624228805, 0.19003854948095977, 0.18244495382532477, 0.10525721678277478, 0.11536571342730895, 0.2226642073947005, 0.1191791205201298, 0.06989244764554314, 0.1570281622116454, 0.20845953054958954, 0.17410195228876546, 0.15919183439109474, 0.10609874545480125, 0.12579628732055426, 0.1513876172248274, 0.19782939314609393, 0.09575939635396935, 0.19004358124220744, 0.12259947136044502, 0.1353418204234913, 0.12748974957503378, 0.14817267801845446, 0.3025395580334589, 0.09342142337118275, 0.2548089239280671, 0.12273635307792574, 0.14712437958223745, 0.18903739226516336, 0.11766136914957315, 0.20260475721443072, 0.20256834744941443, 0.2779576083412394, 0.23654809832805768, 0.3172258590348065, 2.8172165667638183, 39.466266855597496, 89.82863903045654, 92.11522713303566, 89.99190866947174, 56.10277734696865, 48.50945480167866, 68.74545514583588, 86.56226590275764, 65.74498414993286, 15.264490563422441, 1.4506930438801646, 1.3285240181721747, 8.914487902075052, 2.3128173826262355, 2.5039354898035526, 2.9071769770234823, 0.29004897514823824, 0.8262232120614499, 0.18699612992350012, 2.7560248877853155, 15.780994947999716, 40.610959231853485, 58.34246076643467, 73.31352442502975, 77.17078864574432, 79.37033861875534, 80.64790606498718, 72.25019708275795, 74.71770107746124, 68.52981671690941, 79.40610989928246, 69.92805048823357, 71.92222908139229, 70.66907912492752, 38.657917231321335, 9.902571681886911, 0.6497287389356643, 0.08585526491515338, 0.4020505183143541, 0.5062799050938338, 0.14145582594210282, 0.3190065681701526, 1.5805114153772593, 42.672485411167145, 113.07128503918648, 71.57947227358818, 69.43848475813866, 92.90354803204536, 104.07671928405762, 82.30410039424896, 80.23812085390091, 79.26785811781883, 80.31780257821083, 86.47680088877678, 99.51292857527733, 109.03567358851433, 97.09823414683342, 96.62930130958557, 70.3721022605896, 90.47480195760727, 75.5274224281311, 54.1109774261713, 60.63029520213604, 55.22430628538132, 23.289396800100803, 6.091398512944579, 0.7153439149260521, 0.9647513693198562, 0.4930286802118644, 1.5033209323883057, 46.08300380408764, 24.763797484338284, 14.254289120435715, 15.139936096966267, 3.6455229576677084, 0.3012893063714728, 12.793529704213142, 54.63923268020153, 85.66370531916618, 66.83911263942719, 47.79744140803814, 52.43985369801521, 66.66523396968842, 68.88454288244247, 38.70849251747131, 6.65949652902782, 0.2552056760760024, 0.06908498355187476, 0.26635136862751096, 0.16791803645901382, 0.3062869585119188, 0.1521145211881958, 0.16747816553106532, 0.15380925993667915, 0.18560205004177988, 0.2582784346304834, 0.17705895064864308, 0.16821652825456113, 0.12884195748483762, 0.133940274536144, 0.18612285959534347, 0.11940813245018944, 0.11311432681395672, 0.12903182854643092, 0.19018150196643546, 0.1623809023294598, 0.202270018926356, 0.2258861970040016, 0.13265928311739117, 0.24224979628343135, 0.2541212202049792, 0.2782699931412935, 0.14580764633137733, 0.23007668933132663, 0.1367450287216343, 0.2048072882462293, 0.27524410863406956, 0.13008665788220242, 0.15345550782512873, 0.264163309475407, 0.2692176616983488, 0.08933874283684418, 0.2891175204422325, 0.14657847059424967, 0.16908780962694436, 0.13186187512474135, 0.15485911688301712], [0.047228493276634254, 0.06236334462300874, 0.041217954276362434, 0.10010716461692937, 0.01184023794849054, 0.05332892120350152, 0.15009822469437495, 0.12793812551535666, 0.05198296959861182, 0.0796504873142112, 0.06541457347339019, 0.08662246007588692, 0.06553413346409798, 0.06432688183849677, 0.07722966096480377, 0.04737343100714497, 0.04101409373106435, 0.05033715322497301, 0.062252823991002515, 0.060237314173718914, 0.041303230755147524, 0.05569204928178806, 0.0623191348859109, 0.05311405460815877, 0.04922169784549624, 0.058664424941525795, 0.18928690231405199, 0.05712009355193004, 0.008699911486473866, 0.04161739670962561, 0.021199140392127447, 0.056045545352390036, 0.060619928408414125, 0.06985313608311117, 0.08015760424314067, 0.05054836845374666, 0.13558751583332196, 0.1911235842271708, 0.05731875164201483, 0.015057680047902977, 0.07781222462654114, 0.10760542398202233, 0.023107244742277544, 0.08363518951227888, 0.01942009366757702, 0.022458093735622242, 0.03485100998659618, 0.0521136840688996, 0.08560240035876632, 0.12057151572662406, 5.644665509462357, 33.623449578881264, 55.70147328078747, 70.47073736786842, 55.00693514943123, 32.897407338023186, 30.47161940485239, 47.84906163811684, 63.95364627242088, 48.52504916489124, 8.506407849490643, 1.77575942594558, 1.467600711621344, 1.294024244416505, 1.9093176280148327, 0.3670388110913336, 0.19606556044891477, 0.1999632309889421, 0.33004666795022786, 0.7847169111482799, 0.2096618988434784, 0.26939708332065493, 3.5413669841364026, 7.769775101915002, 13.912394866347313, 9.883802589029074, 0.5801244894973934, 5.062966123223305, 8.444856852293015, 4.904660442844033, 3.040445800870657, 1.4349668752402067, 0.2344516053562984, 0.17383114260155708, 0.2577090886188671, 0.2636957267532125, 0.07090629558661021, 0.2366021415218711, 0.08173126901965588, 0.1404909449047409, 0.24970211670733988, 0.2810859092278406, 1.1540231318213046, 10.225724391639233, 59.93231065571308, 97.00203090906143, 95.21861180663109, 85.41790410876274, 79.80402454733849, 75.39517432451248, 82.25955918431282, 71.68034926056862, 58.128410652279854, 38.017951771616936, 36.9676349312067, 23.456513732671738, 31.645247228443623, 23.780944123864174, 13.037051036953926, 10.657485723495483, 12.708913944661617, 2.9318300541490316, 1.6747027798555791, 0.07876889751059934, 0.13354589726077393, 0.257841547136195, 0.25545135664287955, 2.7152687497437, 6.649992763996124, 18.691381327807903, 3.8647619308903813, 1.0216317046433687, 0.3039417718537152, 5.493180938065052, 34.43498343229294, 59.32995557785034, 43.36212180554867, 30.14776848256588, 32.385878786444664, 53.15185949206352, 49.83763553202152, 26.415620148181915, 4.378244765102863, 0.11276230390649289, 0.134019149991218, 0.056685651434236206, 0.1046528562437743, 0.04435571012436412, 0.03551951806002762, 0.05168982868781313, 0.0934096380660776, 0.008342243618244538, 0.04413569302414544, 0.00930577858525794, 0.01523372768133413, 0.09219299827236682, 0.017460385934100486, 0.04031348034914117, 0.0390332756069256, 0.08055760699789971, 0.019527488002495375, 0.06241297203814611, 0.03397146851057187, 0.05140993140230421, 0.09600598234101199, 0.059168198495171964, 0.1078022712317761, 0.01916247379995184, 0.06403867620974779, 0.053092832895345055, 0.028566746514115948, 0.03034995297639398, 0.02089732006425038, 0.050301185037824325, 0.012285982975299703, 0.028930545449838974, 0.1320977444993332, 0.005559261262533255, 0.054013956905691884, 0.08343008215888403, 0.01275175671253237, 0.085832555196248, 0.053277972765499726, 0.04997976458980702, 0.0658839447714854, 0.15488491393625736, 0.023136817471822724, 0.07282159320311621, 0.04356368270236999, 0.09965783130610362, 0.07146912554162554, 0.021209361621004064, 0.042421728940098546, 0.06709466964821331, 0.13751987542491406, 0.1037651659862604, 0.01970014680409804, 0.06765015976270661, 0.06000753041007556, 0.07242933847010136, 0.06501345749711618, 0.02562238136306405, 0.09684172226116061, 0.021226234348432627, 0.05949767495621927, 0.055604420194868, 0.08090821982477792, 0.0017794828522710304, 0.06355123361572623, 0.07559936289908364, 0.01359519084871863, 0.06294853548752144, 0.0787458464037627, 0.03275205679528881, 0.03722991983522661, 0.027741522826545406, 0.03142479617963545, 0.018851087188522797, 0.03922602620150428, 0.08285384901682846, 0.04676891832787078, 0.0803698436357081, 0.15316477889427915, 0.07253873103763908, 0.03413917904254049, 0.03919664828572422, 0.10340786640881561, 0.03689374920213595, 0.03467598187853582, 0.08668225491419435, 0.026164260489167646, 0.0910709823074285, 0.04679370606027078, 0.18754592776531354, 0.026284006016794592, 0.1381836226209998, 9.856052678078413, 45.32264940440655, 72.45841830968857, 70.04930958151817, 43.022971004247665, 27.525453194975853, 40.6672266125679, 70.76325327157974, 82.53644272685051, 42.63382248580456, 3.1343950470909476, 2.006553579121828, 0.818918994627893, 0.8170636254362762, 0.3383057622704655, 1.5797819732688367, 1.1482575349509716, 0.38527305296156555, 0.4311839409638196, 0.5255274754017591, 0.4529731295770034, 1.659615095704794, 8.899279218167067, 14.783156141638756, 23.260877430438995, 23.34465153515339, 5.172621114179492, 16.151293627917767, 14.80552364140749, 15.375086478888988, 13.470081500709057, 5.426559112966061, 2.373716002330184, 0.6437724991701543, 0.2707152266521007, 0.7324183580931276, 0.4653684503864497, 1.8347855773754418, 0.6894597038626671, 0.8381822984665632, 0.2833415928762406, 0.49582812061998993, 2.1974472608417273, 29.865494929254055, 97.36162081360817, 109.58361178636551, 102.55991667509079, 86.48002311587334, 81.00856751203537, 74.79187309741974, 82.28693291544914, 81.52500540018082, 75.16498267650604, 56.11676439642906, 49.44902278482914, 40.814320519566536, 45.32692417502403, 34.559886530041695, 23.364224284887314, 20.4674269258976, 21.891240924596786, 9.0929358266294, 4.389220476150513, 0.721118951914832, 0.5958375963382423, 1.035585980862379, 0.5330563557799906, 4.138075802475214, 1.1779255117289722, 25.58619685471058, 6.973031479865313, 0.5835163418669254, 0.3961267549311742, 2.655099453404546, 35.7013338804245, 78.10783356428146, 64.10427019000053, 39.95281174778938, 37.37067550420761, 55.35285718739033, 65.89772835373878, 37.343434765934944, 8.21220388635993, 0.08840383714414202, 0.14677445695269853, 0.11073562476667576, 0.09285438543884084, 0.10191659486736171, 0.05296562136209104, 0.030855574477755, 0.09542716652504168, 0.0344128163123969, 0.03129377742880024, 0.04431131485034712, 0.06221199102583341, 0.015620462691003922, 0.09810812305659056, 0.00638585421256721, 0.05651187755574938, 0.03476824567769654, 0.011771984482038533, 0.02266963550937362, 0.011041909692721674, 0.040480901443515904, 0.02384031224210048, 0.06328399365884252, 0.1669469807529822, 0.0062749305016041035, 0.026226426489301957, 0.018880726711358875, 0.014416220474231523, 0.03651919098047074, 0.052762814666493796, 0.040171882283175364, 0.11195771934580989, 0.06754677116987295, 0.03968619115767069, 0.012274708824406844, 0.056098998538800515, 0.026273380317434203, 0.00933493942284258, 0.06940145016415045, 0.02709616604988696, 0.03908859900548123, 0.036714412926812656, 0.14342651003971696, 0.15757334389491007, 0.21154307993128896, 0.17304770182818174, 0.2457409183261916, 0.17888530186610296, 0.11111625746707432, 0.20216574717778713, 0.19891945965355262, 0.13287814246723428, 0.1793274882948026, 0.15457389468792826, 0.2742693421896547, 0.19532344245817512, 0.2169988301466219, 0.2151101385243237, 0.08479590105707757, 0.19154320936650038, 0.06405712600098923, 0.20344037096947432, 0.1420976352528669, 0.2025310619501397, 0.13990116014610976, 0.10350810087402351, 0.12393153738230467, 0.10698424637666903, 0.13602517516119406, 0.2858857047976926, 0.10813611894263886, 0.07795436817104928, 0.1396774174645543, 0.10763958503957838, 0.14419705228647217, 0.1599385982262902, 0.11564081272808835, 0.18495277472538874, 0.22087894147261977, 0.29525718942750245, 0.3441790596116334, 0.1386906875995919, 0.14250810228986666, 0.19852088182233274, 0.26009286695625633, 0.1320470409700647, 0.2717400435358286, 0.1603668471216224, 0.2461337816203013, 0.12829082377720624, 0.2734791627153754, 0.17787143908208236, 0.2726661547785625, 10.998677965253592, 58.548930287361145, 85.1374639570713, 92.56744086742401, 71.3795118033886, 51.532420590519905, 48.03101487457752, 67.3237082362175, 82.64352098107338, 62.24191792309284, 11.695996597409248, 1.6892531490884721, 2.8863652562722564, 1.9719645101577044, 5.613240720704198, 4.649400589987636, 1.1490368493832648, 0.25929476134479046, 0.5541521706618369, 1.33610152406618, 0.37413896759971976, 0.6492567923851311, 5.0447741243988276, 9.49107751250267, 15.3728018514812, 15.692353304475546, 2.854345324449241, 16.89485102891922, 9.626587741076946, 7.719187466427684, 6.570488680154085, 1.865881565026939, 0.7792844495270401, 0.3541865054285154, 0.3679315256886184, 0.4188819823320955, 0.351448425790295, 0.5431287840474397, 0.27769497712142766, 0.8179761108476669, 0.4362757271155715, 0.4585463320836425, 1.3726288452744484, 20.008077174425125, 101.530901491642, 127.14141324162483, 110.26518881320953, 79.9856624007225, 97.20399767160416, 86.17743775248528, 97.99278974533081, 88.13930287957191, 84.23928335309029, 40.61288572847843, 32.051044553518295, 26.229390241205692, 32.31384985148907, 30.78509498387575, 16.031375862658024, 16.255662627518177, 22.594381794333458, 7.515765381976962, 2.3419527942314744, 0.4212879063561559, 0.36447964841499925, 0.9654359857086092, 0.8266157191246748, 4.431681297719479, 18.186207935214043, 26.373885087668896, 7.609039451926947, 5.2888179291039705, 0.6116816180292517, 9.11755470559001, 45.90556472539902, 74.16527912020683, 57.15847089886665, 45.457697957754135, 48.22218261659145, 73.05701538920403, 75.58035358786583, 48.99671025574207, 12.853614930063486, 0.314745957730338, 0.3155636560404673, 0.2773259812965989, 0.23059227416524664, 0.1664062519557774, 0.20624653523555025, 0.2325810815091245, 0.1250483063631691, 0.1459913278813474, 0.07602769343066029, 0.16541725111892447, 0.12023582006804645, 0.12877172062871978, 0.2722287329379469, 0.11497018582304008, 0.13602256280137226, 0.16166584304301068, 0.2207609251490794, 0.18269553256686777, 0.15577452635625377, 0.21254624094581231, 0.21033912344137207, 0.12698974984232336, 0.296799669158645, 0.10055010061478242, 0.1384873391361907, 0.12694768491201103, 0.11027076572645456, 0.08952548945671879, 0.10844173535588197, 0.11339508128003217, 0.16158100072061643, 0.14316767861600965, 0.1284762122668326, 0.1675183157203719, 0.19763069052714854, 0.16403693065512925, 0.05784647801192477, 0.24914844485465437, 0.18510625086491928, 0.12066701528965496, 0.11214500031201169, 0.31253412016667426], [0.038710949738742784, 0.06023892834491562, 0.06937042839126661, 0.0594290819572052, 0.041199845873052254, 0.0599311225960264, 0.018455181088938843, 0.06569214412593283, 0.02488964411895722, 0.02783560488751391, 0.0234612547501456, 0.02218334881035844, 0.046891702950233594, 0.037045934004709125, 0.02850988686986966, 0.021334268785722088, 0.057741041091503575, 0.03045899487915449, 0.1059233833802864, 0.014388753588718828, 0.06602632580325007, 0.12485623854445294, 0.0547949003521353, 0.0216102512422367, 0.04470815976674203, 0.05863770391442813, 0.008372381307708565, 0.05843132377776783, 0.04688805900514126, 0.03613302927988116, 0.01737596106977435, 0.033571844251127914, 0.02352672516281018, 0.02170414591091685, 0.030988251928647514, 0.020864504149358254, 0.010187875832343707, 0.06017697756760754, 0.020410697543411516, 0.03027944894711254, 0.03758750513952691, 0.03319154180644546, 0.04650932991353329, 0.019545917384675704, 0.04280202767404262, 0.03148602707369719, 0.07552437629783526, 0.07056213202304207, 0.04893685043498408, 0.030862580351822544, 0.1625886294641532, 0.08061331260250881, 9.450157508254051, 38.694292679429054, 67.40816250443459, 60.84681898355484, 40.52580960094929, 32.36529529094696, 38.35006155073643, 47.936217561364174, 61.664671897888184, 40.50161249935627, 8.102845754474401, 1.0879871877841651, 1.3067895406857133, 1.8998737097717822, 3.0880294600501657, 2.040555104613304, 1.9398613390512764, 1.4955146075226367, 0.12652719888137653, 0.21042960608610883, 0.8401967247482389, 1.00071691442281, 0.5206800042651594, 0.19484015589114279, 0.775191712891683, 2.4814364220947027, 0.5149680201429874, 0.07839626516215503, 0.13350914610782638, 0.29016003012657166, 0.1519342089886777, 0.12786579580279067, 1.2979962187819183, 1.11683500232175, 1.815832075662911, 6.518818577751517, 1.7310664616525173, 0.22055376204662025, 0.15526006958680227, 0.08876232415786944, 0.015078871147125028, 0.3005087748169899, 0.633084325818345, 13.928086124360561, 29.190801233053207, 33.360587283968925, 31.647994481027126, 26.316489167511463, 13.898226376622915, 7.488417299464345, 3.404137110337615, 1.6056562098674476, 0.2719437185442075, 5.279762065038085, 6.874863272532821, 2.031538663432002, 1.8025964358821511, 0.22366457793395966, 1.212508762255311, 0.01906611149024684, 0.13982038479298353, 0.05006492603570223, 0.7138442422728986, 0.41591906163375825, 0.15306810673791915, 2.678512134589255, 4.346506018191576, 1.4043294754810631, 0.2606708515668288, 4.246861115098, 39.73457805812359, 54.620431289076805, 39.32631276547909, 24.558295011520386, 28.651463873684406, 48.704821318387985, 57.88441054522991, 30.222979746758938, 11.931847091764212, 0.3097728855209425, 0.2640961896395311, 0.0629685289459303, 0.07784967339830473, 0.07092137602739967, 0.03153944686346222, 0.019295277415949386, 0.06478585564764217, 0.05203640423133038, 0.04410576591908466, 0.018456067955412436, 0.07998856526683085, 0.019808468823612202, 0.0498107256134972, 0.008119967606035061, 0.0764948085998185, 0.013858124493708601, 0.06211717794940341, 0.03112142105237581, 0.04130087072553579, 0.06250317266676575, 0.03918307811545674, 0.061688216592301615, 0.036920525890309364, 0.014549224470101763, 0.054746731257182546, 0.021971409987600055, 0.05347582191461697, 0.06522354466142133, 0.033109018695540726, 0.03082013878156431, 0.053576950667775236, 0.05473743956827093, 0.035023952659685165, 0.023146893981902394, 0.025043289097084198, 0.029216580296633765, 0.06832944010966457, 0.033055483872885816, 0.03895138332154602, 0.0460609799483791, 0.03120445995591581, 0.03475348807114642, 0.020619634378817864, 0.0464184539305279, 0.06532689614687115, 0.0527849677746417, 0.024129803641699255, 0.02540581153880339, 0.01871098455012543, 0.04053655138704926, 0.017615223914617673, 0.058541428807075135, 0.1430359622463584, 0.04355091405159328, 0.04985312079952564, 0.010274363867210923, 0.06015626793669071, 0.06790561441448517, 0.07790012459736317, 0.03169286734191701, 0.07528029876993969, 0.01509289588284446, 0.1327994599705562, 0.011867191824421752, 0.03437675906752702, 0.02418070569547126, 0.04910488751193043, 0.015449560924025718, 0.033567335703992285, 0.0169070183619624, 0.10220356110949069, 0.07082891926984303, 0.07463876405381598, 0.08026966854231432, 0.020246434287400916, 0.05120170702866744, 0.03947835270082578, 0.10427411601995118, 0.06644008797593415, 0.010080663323606132, 0.047639635668019764, 0.04594220292347018, 0.03840998288069386, 0.04046224756166339, 0.05069837876362726, 0.04352362528152298, 0.032723294862080365, 0.061801895062671974, 0.033782231985242106, 0.030892557551851496, 0.10651569144101813, 0.0371360158897005, 0.05700473040633369, 0.04950825219566468, 0.1989211220643483, 0.22149833792354912, 15.759994424879551, 51.807795614004135, 80.41327625513077, 60.23542799055576, 36.486413553357124, 33.15178468823433, 50.87400712072849, 83.95823523402214, 91.42728164792061, 37.16899372637272, 1.813605276402086, 1.3878703024238348, 0.5064409808255732, 1.12438757205382, 2.9349964717403054, 0.28194104146678, 0.5877733009401709, 1.774693583138287, 0.6972841371316463, 0.392806000309065, 1.0715847741812468, 0.845410282490775, 0.5979600199498236, 0.22778049926273525, 1.9317315565422177, 3.8185554603114724, 1.3539028563536704, 0.2064510711352341, 0.3373755543725565, 0.9270459332037717, 1.700623920187354, 1.8048779759556055, 3.200101596303284, 4.313295800238848, 2.636175756342709, 8.733645156025887, 3.095290632918477, 1.3069075718522072, 0.7309505087323487, 0.10068605464766733, 0.2152290305821225, 0.14175776130286977, 5.207415847107768, 40.908338874578476, 58.19365315139294, 53.91070917248726, 49.85173277556896, 41.346812546253204, 28.33393771201372, 18.257571905851364, 10.699793603271246, 4.5308540761470795, 1.3847251399420202, 10.727851297706366, 16.452501565217972, 5.69478577002883, 4.8966514226049185, 0.8805717551149428, 3.777661817148328, 0.1573516198550351, 0.037367265395005234, 0.5900636280421168, 0.9206936240661889, 0.9955491917207837, 2.1062400424852967, 1.181481289677322, 2.566661573946476, 1.746303525287658, 0.2801374444970861, 2.233922928571701, 34.86713044345379, 68.20210710167885, 58.14715124666691, 30.818421095609665, 23.06630127131939, 44.863531440496445, 66.19035825133324, 42.14302562177181, 16.38588733971119, 0.6471384060569108, 0.16968057781923562, 0.045165233677835204, 0.08864788498613052, 0.019953970586357173, 0.06097317957028281, 0.05753685029048938, 0.03582235141948331, 0.02151225806301227, 0.08691318158525974, 0.017442082717025187, 0.04405532585224137, 0.028625487502722535, 0.018148482995457016, 0.07237933998112567, 0.04061353065480944, 0.03005719612701796, 0.02885682049964089, 0.007223685133794788, 0.047300091973738745, 0.04107369932171423, 0.10258866153890267, 0.05508709131390788, 0.05079335882328451, 0.05433980797533877, 0.04727353050839156, 0.01882997494249139, 0.030594121417379938, 0.06952679148525931, 0.05963750299997628, 0.03712154029926751, 0.00664979949760891, 0.05720741464756429, 0.04772112348291557, 0.05957325156487059, 0.0676382334495429, 0.030836740625090897, 0.011598275541473413, 0.04508271056693047, 0.07869175125961192, 0.03945005089917686, 0.03754747740458697, 0.030495310020342004, 0.04655760661989916, 0.0873025122564286, 0.11112051739473827, 0.13920386787503958, 0.13590623857453465, 0.12235578717081808, 0.17114680929807946, 0.2257221972104162, 0.1372460971469991, 0.1461916186963208, 0.46923696936573833, 0.10687499481718987, 0.11728095909347758, 0.13629755820147693, 0.18689892342081293, 0.15784540039021522, 0.11670088162645698, 0.09611001660232432, 0.20833346934523433, 0.08993173367343843, 0.25861652742605656, 0.14121633488684893, 0.14371142053278163, 0.4028910450870171, 0.11436656743171625, 0.1036720561387483, 0.14957827603211626, 0.19959779747296125, 0.19864078320097178, 0.20811465452425182, 0.16210078611038625, 0.14145659777568653, 0.11440265065175481, 0.14321775874122977, 0.09864629886578768, 0.13291940587805584, 0.16176060045836493, 0.08612437508418225, 0.09541219740640372, 0.20435460784938186, 0.0823379005305469, 0.3256193414563313, 0.08478084288071841, 0.17876488098409027, 0.1357102522160858, 0.1760985521832481, 0.10521199772483669, 0.16499281686265022, 0.1723672414664179, 0.19863014080328867, 0.11797721235780045, 0.16215270676184446, 0.1936711693997495, 0.26787084178067744, 18.38966991752386, 64.79799896478653, 95.48947647213936, 77.59405553340912, 59.49577867984772, 51.79689399898052, 56.718230322003365, 67.14031487703323, 80.47191470861435, 51.236644461750984, 11.264647543430328, 1.0401044134050608, 2.6021103467792273, 7.177584953606129, 14.81519602239132, 10.208868496119976, 6.5720693953335285, 4.560381816700101, 1.1579598393291235, 0.39940393064171076, 1.093389072921127, 1.1312311235815287, 0.8653267950285226, 0.35769822949077934, 2.1068204613402486, 7.1483678463846445, 1.9125782093033195, 0.3061371931107715, 0.37596301815938205, 0.7753795059397817, 1.235099381301552, 0.8343531133141369, 3.821279676631093, 3.6225299164652824, 8.512828554958105, 13.270326219499111, 5.32749985344708, 0.651368647813797, 0.3371123888064176, 0.1875524883507751, 0.17103484889958054, 0.20139756496064365, 3.0292542139068246, 30.694184862077236, 51.99862897396088, 41.7021656781435, 35.258216857910156, 32.3917380720377, 14.883718695491552, 9.821227546781301, 4.967372277751565, 2.8493716288357973, 0.3020603384356946, 11.377252601087093, 18.133994936943054, 3.8785751396790147, 5.635523200035095, 0.649930959334597, 2.5378809683024883, 0.15607701090630144, 0.2699889609357342, 0.430751001695171, 3.3052813773974776, 3.006981471553445, 7.917940076440573, 13.592754118144512, 12.401801124215126, 2.708853268995881, 0.2933482371736318, 7.100172657519579, 53.64646755158901, 69.56067100167274, 55.667195320129395, 35.72562597692013, 41.03365994989872, 63.9654104411602, 81.12758472561836, 52.84053459763527, 20.189870819449425, 0.9909170621540397, 0.41580052580684423, 0.18705331982346252, 0.20713335718028247, 0.14353170205140486, 0.17328472895314917, 0.17925020103575662, 0.18158159859012812, 0.10681415355065838, 0.274750342941843, 0.06878055457491428, 0.1522225482040085, 0.07522523883380927, 0.132705177529715, 0.08748050895519555, 0.20510353875579312, 0.08465302278636955, 0.18693709949729964, 0.11701084702508524, 0.18930981983430684, 0.21806277305586264, 0.2360217523528263, 0.1610317372251302, 0.23332238313741982, 0.07808323469362222, 0.20152185985352844, 0.1231408458261285, 0.16752042341977358, 0.13168047938961536, 0.15726691111922264, 0.1839566937997006, 0.28260027640499175, 0.08806563302641734, 0.1282714685657993, 0.11999005044344813, 0.198144672322087, 0.1123265890055336, 0.11917088268091902, 0.17450254876166582, 0.20343060430604964, 0.18526257685152814, 0.12024563126033172, 0.12795650109183043, 0.1668923141551204, 0.16567418264457956], [0.05079641276097391, 0.06531879189424217, 0.05068322781880852, 0.06145369050500449, 0.05823961961141322, 0.05944487114902586, 0.03370989485119935, 0.0017973753369915357, 0.019566263363230973, 0.0006800710241350316, 0.007466740817108075, 0.030580679267586675, 0.01680652414506767, 0.015598762292938773, 0.062415102001978084, 0.024487902883265633, 0.045946800528327, 0.007047376357149915, 0.04176054215349723, 0.026181060857197735, 0.04594577265379485, 0.06988149354583584, 0.09075213340111077, 0.026098261296283454, 0.016859999595908448, 0.029546511323133018, 0.015714151413703803, 0.03675773579743691, 0.031185245752567425, 0.10613660982926376, 0.03842605779937003, 0.010203922920482, 0.05699382454622537, 0.07832048446289264, 0.018606614466989413, 0.05376380118832458, 0.02258410484500928, 0.08311435027280822, 0.009875151499727508, 0.04241009948600549, 0.009752463356562657, 0.02842311867425451, 0.026104790340468753, 0.04494764711125754, 0.10949508039630018, 0.03931054197892081, 0.01664518680627225, 0.029833381086064037, 0.019783397219725884, 0.0505103148316266, 0.060470604585134424, 0.0031822895789446193, 0.4358556418446824, 0.5811589246150106, 22.5211426243186, 59.72623251378536, 69.93619725108147, 55.78097261488438, 41.727559715509415, 27.04052321612835, 25.099064894020557, 31.910558491945267, 64.7707012295723, 51.458115577697754, 20.1841464266181, 2.1335748257115483, 0.4909843602217734, 2.254781909286976, 2.190174451097846, 1.781219970434904, 0.25568629091139883, 1.5627707610838115, 1.7483614711090922, 1.7228190042078495, 1.800369517877698, 0.7433938316535205, 0.47778511536307633, 0.31754222174640745, 1.3521388010121882, 0.18123718269634992, 0.35861015086993575, 0.4196903295814991, 1.5148337208665907, 2.3149027582257986, 3.5246599931269884, 4.731011660769582, 0.306246496620588, 7.171592200174928, 3.479903619736433, 4.241626895964146, 1.223205307032913, 0.32512287434656173, 0.024644297518534586, 0.10529971958021633, 0.21703092061216012, 0.4161835927516222, 0.1826637241174467, 0.0969375335262157, 0.01534684397483943, 0.4153347836108878, 0.26901271019596606, 0.1462822497705929, 0.14423386281123385, 0.08174723261618055, 0.4138684185454622, 4.447228638455272, 2.061505517922342, 0.517868452006951, 0.6353650346864015, 0.18267012143041939, 0.4925502324476838, 0.12871830083895475, 1.0075561911799014, 0.8736330305691808, 0.8706908009480685, 1.8304666341282427, 0.8867345494218171, 2.8600668674334884, 0.14858045848086476, 12.492907885462046, 42.00729690492153, 59.050526171922684, 45.29056012630463, 27.045139968395233, 31.507274731993675, 51.74797922372818, 71.12919643521309, 50.18796533346176, 16.446457989513874, 0.21815171203343198, 0.1552831058506854, 0.052142145432299, 0.05177634455321822, 0.0038676729309372604, 0.06387505491147749, 0.039465342852054164, 0.04991487119696103, 0.02335039829631569, 0.08999829689855687, 0.042314945021644235, 0.053885543093201704, 0.02506009317585267, 0.01992052570130909, 0.04677212440583389, 0.023963863131939434, 0.03276445437222719, 0.0719059981929604, 0.04629105686035473, 0.06703620325424708, 0.024487184855388477, 0.031196504132822156, 0.005514080703505897, 0.051645604107761756, 0.012319124507484958, 0.03321423668239731, 0.09185397037072107, 0.013428387592284707, 0.05050784347986337, 0.04013379155367147, 0.017064849052985664, 0.03280219258158468, 0.0970356677134987, 0.02074112580885412, 0.02630688457429642, 0.06920339321368374, 0.03825231360679027, 0.03601441181672271, 0.04299985455872957, 0.04094326315680519, 0.04114476738322992, 0.05178447478101589, 0.08199942923965864, 0.02925806078565074, 0.11427225530496798, 0.035162237036274746, 0.012786812058038777, 0.03757882572244853, 0.02607445690955501, 0.038621817802777514, 0.07627756713191047, 0.03222596315026749, 0.05458217114210129, 0.028577756274899002, 0.010297196040482959, 0.03036603346117772, 0.050331182646914385, 0.08091716270428151, 0.03342370044265408, 0.062473687139572576, 0.03432499426708091, 0.06556534819537774, 0.018583205273898784, 0.022791889496147633, 0.01115659841161687, 0.033789070876082405, 0.03122814559901599, 0.04613075667293742, 0.027464039376354776, 0.07379180286079645, 0.02781957264232915, 0.038676833210047334, 0.048531463398830965, 0.11516076192492619, 0.02217155422840733, 0.012016665932605974, 0.017677491960057523, 0.10465069659403525, 0.018033405576716177, 0.08241530653322116, 0.08499704534187913, 0.035805705047096126, 0.05733700847486034, 0.05781925603514537, 0.05904308723984286, 0.08470722925267182, 0.0584683792112628, 0.07054265806800686, 0.0261748936100048, 0.03661833077785559, 0.08669645962072536, 0.05605366073723417, 0.02829228174960008, 0.022354428692779038, 0.08120945756672882, 0.017574318590050098, 0.06096971745137125, 0.08076302605331875, 0.04335968857049011, 0.2755092631559819, 1.9573312578722835, 29.64580401778221, 74.80609953403473, 78.88720974326134, 58.396497666835785, 39.85068842768669, 20.564015842974186, 30.529773384332657, 67.33900621533394, 93.04227098822594, 49.087050408124924, 6.061282753944397, 2.2634485317394137, 0.6321472011040896, 0.6529950792901218, 0.7488522387575358, 1.4750021207146347, 0.9991086507216096, 1.3042433210648596, 0.8498694619629532, 0.4849354410544038, 0.8758965216111392, 0.5039656511507928, 0.8108799322508276, 1.8536971625871956, 1.6033325158059597, 1.7576862894929945, 0.958526412723586, 0.8278151485137641, 4.096418637782335, 3.1756404088810086, 3.9487466868013144, 7.861556326970458, 3.7883686926215887, 5.220109540969133, 3.6347263120114803, 5.851867441087961, 4.78625594638288, 1.6121029201894999, 1.1243808036670089, 0.6609900877811015, 0.22554279043106362, 0.1447565425769426, 0.4618908651173115, 0.9130817418918014, 0.04991550944396295, 0.6626556452829391, 0.4269969218876213, 0.4209703562082723, 0.47988868842367083, 0.38435670838225633, 0.49389301508199424, 8.2308941334486, 2.479553623124957, 1.2239687098190188, 1.7870362708345056, 1.5726533182896674, 3.3361554332077503, 2.9901730734854937, 1.7952040513046086, 1.926968393381685, 0.9344688942655921, 1.8804069980978966, 0.7344182976521552, 0.9582703420892358, 0.5178740923292935, 5.377223510295153, 43.128350749611855, 73.62819314002991, 67.03425496816635, 35.605031847953796, 27.875933088362217, 42.664091661572456, 73.92966136336327, 64.54762279987335, 22.813345044851303, 1.0172343906015158, 0.12662292108871043, 0.05341676551324781, 0.23665051470743492, 0.057790672217379324, 0.0571431854768889, 0.09842232611845247, 0.009778661169548286, 0.030305390719149727, 0.04176095033471938, 0.016145157387654763, 0.06578263419214636, 0.013244505662441952, 0.024341039279534016, 0.06426184743759222, 0.025167483800032642, 0.01048355767125031, 0.025381040504726116, 0.07113525556633249, 0.02576313152530929, 0.02894511380873155, 0.04941169136145618, 0.03140889937640168, 0.0533787675522035, 0.04561363188258838, 0.0487310862808954, 0.005912414553677081, 0.08688595218700357, 0.016240835066128056, 0.0795154609659221, 0.03367230878211558, 0.026786581001942977, 0.05256055716017727, 0.02364456893701572, 0.024178117455448955, 0.026607443251123186, 0.04987615335267037, 0.07123277377104387, 0.012618171058420558, 0.040487443475285545, 0.04617885155312251, 0.03373019259015564, 0.046558300527976826, 0.019522819893609267, 0.12234544905368239, 0.09093912492971867, 0.040100376354530454, 0.20399171247845516, 0.1258961358689703, 0.08980272614280693, 0.1501293948967941, 0.17067553068045527, 0.11885385203640908, 0.1507337999646552, 0.09540411541820504, 0.0976901751710102, 0.11592811293667182, 0.14457683893851936, 0.07659502822207287, 0.13179827306885272, 0.129861356690526, 0.16771691443864256, 0.1760451472364366, 0.14738355239387602, 0.08490796535625122, 0.16047110402723774, 0.1204148112447001, 0.262232122477144, 0.1646661086124368, 0.1800375900347717, 0.13598691002698615, 0.14799668511841446, 0.19293724471936002, 0.15775229054270312, 0.13131988467648625, 0.0886870184331201, 0.17322954285191372, 0.1482564813341014, 0.14078459789743647, 0.13682991557288915, 0.20033994514960796, 0.09830036156927235, 0.10848135862033814, 0.11885567029821686, 0.13666744460351765, 0.14446830726228654, 0.12106059104553424, 0.1237049003248103, 0.12747928529279307, 0.11985185512457974, 0.21866845461772755, 0.31189780274871737, 0.13562901673140004, 0.11825467910966836, 0.16328832629369572, 0.12882659502793103, 0.2107323578093201, 0.22687408461933956, 0.10258411959512159, 0.4862358915852383, 1.5334048680961132, 31.905812546610832, 86.82683050632477, 93.99401351809502, 72.64498829841614, 59.06317189335823, 42.4177622795105, 37.90346011519432, 53.28014820814133, 84.24768090248108, 68.2743564248085, 25.614621229469776, 3.1105477642267942, 0.5160111235454679, 3.9753813575953245, 4.564541168510914, 5.673583382740617, 3.641353868879378, 5.12337195686996, 6.65579030290246, 4.366751806810498, 5.02296756953001, 2.37958122510463, 2.7160054352134466, 3.251979975029826, 5.0528909638524055, 3.2000882970169187, 1.0937772458419204, 0.6668166595045477, 4.526585005223751, 6.004127645865083, 7.585794674232602, 12.176871243864298, 3.643943667411804, 13.906701821833849, 10.251407213509083, 10.467849299311638, 6.880664136260748, 1.6601668973453343, 0.4562634858302772, 0.571517595089972, 0.24005554761970416, 0.5721122038085014, 0.24955057015176862, 0.6041222205385566, 0.0947546842508018, 0.612538056448102, 0.3161267680115998, 0.25075739133171737, 0.2477657940471545, 0.42557927139569074, 0.6583232246339321, 7.834277590736747, 4.538536313921213, 1.5020497818477452, 2.142269234173, 2.323927986435592, 3.9814132964238524, 5.93574034050107, 5.025439336895943, 10.796612408012152, 7.045348724350333, 8.683997970074415, 4.328588079661131, 4.326049815863371, 0.29141758452169597, 18.82354013621807, 52.43261128664017, 71.85004815459251, 59.96569566428661, 41.572083458304405, 47.225112318992615, 65.12300312519073, 91.22459292411804, 72.77203068137169, 28.782760128378868, 1.4074996928684413, 0.4018985264701769, 0.21517154382308945, 0.5504549690522254, 0.15882356587098911, 0.2568690961925313, 0.22478027822216973, 0.12912697187857702, 0.13030548754613847, 0.20816853444557637, 0.14430767681915313, 0.26957285357639194, 0.13288023532368243, 0.10738576311268844, 0.17383995931595564, 0.1541844304301776, 0.191998234950006, 0.16912880586460233, 0.12026664888253435, 0.12490950990468264, 0.10096665326273069, 0.1258927071467042, 0.11483961236081086, 0.16926366894040257, 0.11884262334206142, 0.12986710091354325, 0.1763247439521365, 0.10894983934122138, 0.11180324872839265, 0.1637798803858459, 0.11507679533679038, 0.09721813956275582, 0.16762712941272184, 0.12321667847572826, 0.10339724627556279, 0.14888798963511363, 0.08210816871724091, 0.11985847508185543, 0.09676705478341319, 0.10308251628885046, 0.17771800747141242, 0.14523530204314739, 0.1584178931079805, 0.12558861955767497, 0.24647840531542897, 0.2070347554399632, 0.1722654781769961], [0.07728973039775155, 0.06620336513151415, 0.0793741931556724, 0.015783091366756707, 0.04153812420554459, 0.08934059820603579, 0.0628209974092897, 0.05585978949966375, 0.023324799767578952, 0.01836770785303088, 0.017364526429446414, 0.00542865301213169, 0.023850715297157876, 0.03738321043783799, 0.036143734760116786, 0.01566795828694012, 0.05841580918058753, 0.03700822177052032, 0.018744427579804324, 0.10931076802080497, 0.049755454165278934, 0.03938357673177961, 0.03144815156701952, 0.028589005378307775, 0.027886916977877263, 0.060945115255890414, 0.023761846823617816, 0.03339399969263468, 0.04966274878825061, 0.02152583379938733, 0.04670736088883132, 0.029246453595987987, 0.03407275682548061, 0.05402115944889374, 0.10682283667847514, 0.033736890472937375, 0.026632054723449983, 0.03767795438761823, 0.022644118616881315, 0.01763506152201444, 0.07747747149551287, 0.026849439054785762, 0.050418488899595104, 0.04881094137090258, 0.049965003272518516, 0.01059215892382781, 0.027323196445649955, 0.01635200507735135, 0.030978498252807185, 0.01850591059337603, 0.02558435186074348, 0.08542496027075686, 0.1826173547306098, 0.05067959129519295, 0.34218348388094455, 3.7755149323493242, 30.941019617021084, 68.69349673390388, 65.47543421387672, 59.27784137427807, 55.04025176167488, 34.96294990181923, 15.93382179737091, 26.267167814075947, 52.336377650499344, 60.80804206430912, 46.77688457071781, 23.357855826616287, 9.359006099402905, 1.5393773163668811, 0.1487758065923117, 1.0361143900081515, 3.150716358795762, 3.268401031382382, 2.721830285154283, 3.2820755476132035, 2.0298964390531182, 2.9379011783748865, 0.792455670889467, 1.8919779709540308, 3.8518029637634754, 3.058587214909494, 3.0207060975953937, 2.449037223123014, 2.4279075069352984, 7.295426605269313, 4.607332097366452, 4.12148161791265, 2.312836144119501, 4.856996275484562, 4.32735457085073, 0.5471175606362522, 3.1985239684581757, 0.4716396873118356, 0.07365000070421956, 0.3902070288313553, 0.21128907246747985, 0.08009173863683827, 0.01577954761160072, 0.21886668226215988, 0.7126315729692578, 0.40845854789949954, 0.7927566266153008, 0.35757957492023706, 1.6815902665257454, 1.9736817805096507, 0.3985156986163929, 3.1455878214910626, 2.0457826741039753, 1.4416097500361502, 1.8184555973857641, 1.4482560683973134, 1.6955041699111462, 1.8991727661341429, 0.6406159373000264, 0.4077302338555455, 6.102605061605573, 26.177264638245106, 52.438945546746254, 47.166219279170036, 32.94803202152252, 24.51415278017521, 22.14258223772049, 49.614640697836876, 65.13829350471497, 53.00496697425842, 17.587797045707703, 2.607053881511092, 0.02751132531557232, 0.03962071888963692, 0.04868595256994013, 0.049440330840297975, 0.09671785039245151, 0.04066183704708237, 0.07012273606960662, 0.0066842309752246365, 0.04959987032634672, 0.05918192822718993, 0.0791795426630415, 0.040457905997755006, 0.03507494191580918, 0.02339601440326078, 0.06428009684896097, 0.04165740960161202, 0.0654475693590939, 0.049927339277928695, 0.043579906050581485, 0.012962367090949556, 0.05199001629080158, 0.01774013293470489, 0.0791064856457524, 0.055096683572628535, 0.07234820688609034, 0.011297673263470642, 0.010844456664926838, 0.009295936779381009, 0.038188782054930925, 0.05110636331664864, 0.04649835726013407, 0.03637497684394475, 0.027454547307570465, 0.02921601069829194, 0.04074762931850273, 0.007292620448424714, 0.06817198605858721, 0.07851995891542174, 0.033526758779771626, 0.05682744245859794, 0.025758359515748452, 0.03182273205311503, 0.06137532713182736, 0.03881553690007422, 0.01701958546618698, 0.0349947973882081, 0.04094701842404902, 0.028339350610622205, 0.05313744710292667, 0.03287762447143905, 0.057708954336703755, 0.01881510415842058, 0.020030421073897742, 0.0634581311896909, 0.03392297287064139, 0.06065908040909562, 0.029870822436350863, 0.05671542268828489, 0.02715155995247187, 0.030607600674557034, 0.08298768792883493, 0.05547772816498764, 0.026197736915491987, 0.056198988095275126, 0.015020277660369175, 0.05238503923465032, 0.03234999086998869, 0.02788122284982819, 0.006248869985938654, 0.05060665302153211, 0.00865518873979454, 0.07082298208842985, 0.04827853575989138, 0.02515478008717764, 0.03714034261065535, 0.07315459486562759, 0.03555189054168295, 0.03682744201796595, 0.04305758251575753, 0.07297723641386256, 0.06983228915487416, 0.04957732387993019, 0.07707219949224964, 0.013056667157798074, 0.05722797584894579, 0.02519550729630282, 0.01989014959690394, 0.007721601286903024, 0.07489592564525083, 0.026365362100477796, 0.017934961542778183, 0.022563463862752542, 0.015930114532238804, 0.05038395305746235, 0.02867012026399607, 0.04818871362658683, 0.02199593796831323, 0.03069800353841856, 0.1233885005058255, 0.025420411438972224, 0.05612666209344752, 0.1632779955980368, 0.4574336449149996, 5.964112468063831, 43.063925206661224, 79.45263460278511, 69.72802922129631, 53.376412242650986, 40.88962107896805, 22.55606845021248, 29.800039641559124, 61.620871648192406, 97.75325059890747, 75.54639101028442, 32.620975971221924, 6.394155342131853, 2.0833968557417393, 1.6396388551220298, 0.28081327385734767, 1.586302185896784, 1.8817085470072925, 0.5744991288520396, 1.1290562152862549, 0.9171870653517544, 1.3333013118244708, 2.0174608938395977, 1.5997342276386917, 1.3081891718320549, 1.6934424242936075, 1.1532622226513922, 3.265726687386632, 1.7304942361079156, 2.559236059896648, 2.7989661460742354, 3.088099993765354, 3.927863957360387, 4.229693161323667, 3.6013636272400618, 1.9778190460056067, 2.1786304330453277, 2.0416931435465813, 0.9166878671385348, 0.10564622090896592, 0.3924427041783929, 0.2668029209598899, 0.4532307735644281, 0.545630652923137, 0.6029975402634591, 1.6081678750924766, 1.583204639609903, 1.4147207303903997, 3.085171775892377, 1.958993668667972, 5.05465691909194, 2.249630098231137, 3.091084733605385, 1.104310043156147, 0.8815632050391287, 1.9536285940557718, 1.557327553164214, 1.6733690514229238, 0.7863580074626952, 1.0896903276443481, 0.8904867293313146, 2.0128092309460044, 9.658768214285374, 49.882750511169434, 75.99128633737564, 61.01436339318752, 36.138527020812035, 21.286662966012955, 44.063191786408424, 70.87421491742134, 68.65087062120438, 26.200390197336674, 4.580425266176462, 0.018237049043818843, 0.1870313670951873, 0.09572237060638145, 0.047952372988220304, 0.03624926815973595, 0.0368015150888823, 0.15297762409318238, 0.04346255765995011, 0.04584806891216431, 0.0897532916860655, 0.06705883875838481, 0.04234366613673046, 0.02962126785860164, 0.02533448743633926, 0.0907446451310534, 0.041566073487047106, 0.02395919873379171, 0.03404351249628235, 0.08099604558083229, 0.038253597522270866, 0.02668770837772172, 0.05148252457729541, 0.07586611303850077, 0.06833761857706122, 0.019953525297751185, 0.03650756894785445, 0.032331192269339226, 0.03517089789966121, 0.04835932966670953, 0.054739844126743264, 0.02890835708967643, 0.025276050728280097, 0.059927894253632985, 0.019132034612994175, 0.07105388649506494, 0.058728346120915376, 0.024784748966339976, 0.05942789081018418, 0.024565906314819586, 0.026619644158927258, 0.07172392710344866, 0.026795095291163307, 0.031735967568238266, 0.030269650742411613, 0.11174470811965875, 0.027488834530231543, 0.01918456382554723, 0.046498464871547185, 0.12737553304759786, 0.20122026588069275, 0.166441221954301, 0.06610563912545331, 0.09566452019498684, 0.22507684043375775, 0.09054590540472418, 0.11822631422546692, 0.1283680516644381, 0.14957938925363123, 0.15355894836829975, 0.11326217747409828, 0.14059652283322066, 0.17542966932523996, 0.18559928925242275, 0.106826718110824, 0.11616152580245398, 0.11540682840859517, 0.12184826948214322, 0.10999305406585336, 0.13934515794971958, 0.09517193451756611, 0.10684704553568736, 0.15776294778333977, 0.09886681320494972, 0.10558768772170879, 0.09167705720756203, 0.168317653296981, 0.19792274048086256, 0.14670956355985254, 0.16244987753452733, 0.1240379836235661, 0.17187064077006653, 0.12203583246446215, 0.2647783124120906, 0.1666691355057992, 0.1812477211933583, 0.13979291048599407, 0.0935597596981097, 0.08357678249012679, 0.15969876578310505, 0.15805476024979725, 0.18088439537677914, 0.11676049092784524, 0.12404919005348347, 0.18595995818031952, 0.14403763896552846, 0.10672596414224245, 0.08617375759058632, 0.2702379960101098, 0.21724452555645257, 0.19726144237210974, 0.24586076033301651, 0.3720697114476934, 0.8074219990521669, 6.008137380704284, 50.68728134036064, 96.01623460650444, 88.47721114754677, 75.75692251324654, 77.00013980269432, 46.843259409070015, 31.91931702196598, 40.20734488964081, 75.63894644379616, 79.17654141783714, 62.56328567862511, 30.78821461647749, 12.308191247284412, 2.288925927132368, 0.3032648441148922, 2.59736321400851, 5.7833742164075375, 6.216347683221102, 5.207149386405945, 8.254842348396778, 7.359038991853595, 9.557723086327314, 9.907291028648615, 8.202484957873821, 10.711289886385202, 14.42121036350727, 16.317960284650326, 17.39537727087736, 13.16294303163886, 24.506494291126728, 17.472824715077877, 18.218297213315964, 14.49641402810812, 17.879355400800705, 17.009760662913322, 8.013395704329014, 7.317772256210446, 1.0086298710666597, 0.15455983841093257, 0.6195154914166778, 0.634894750546664, 0.3266603668453172, 0.31878128182142973, 1.402145423926413, 2.6363778579980135, 2.8067557280883193, 5.730031728744507, 6.348014418035746, 7.2389397863298655, 11.522713545709848, 5.116608319804072, 10.457555651664734, 8.668853882700205, 6.249157497659326, 5.629582218825817, 7.295600920915604, 5.160554386675358, 4.310786984860897, 1.1961609707213938, 0.583550005685538, 8.884005937725306, 35.7161682844162, 66.67304635047913, 60.65327636897564, 50.62829710543156, 40.71338273584843, 35.98374992609024, 65.58188170194626, 81.99017643928528, 77.35928133130074, 30.71891013532877, 6.64318922907114, 0.09034643837367184, 0.349598370376043, 0.14905682823155075, 0.1751974067883566, 0.22789651178754866, 0.10555069166002795, 0.28504885907750577, 0.25582655682228506, 0.11465578238130547, 0.2132383084972389, 0.28901537123601884, 0.10330959121347405, 0.07089891121722758, 0.14042538357898593, 0.19348548405105248, 0.20062467752723023, 0.10405424734926783, 0.17711726861307397, 0.1504703820683062, 0.08706777094630525, 0.16724413668271154, 0.11855608754558489, 0.16619441332295537, 0.17222224065335467, 0.14826047408860177, 0.2372001195908524, 0.08625209127785638, 0.10975515862810425, 0.14479897858109325, 0.11101055337348953, 0.18250385066494346, 0.10817813192261383, 0.130597552342806, 0.1420665392652154, 0.159326029533986, 0.15083934820722789, 0.16524369246326387, 0.1720102090621367, 0.14239845739211887, 0.19685492356074974, 0.1283817962394096, 0.10015433552325703, 0.15773464227095246, 0.08079533174168319, 0.15479702880838886, 0.13832825236022472, 0.13580310973338783, 0.10956594065646641], [0.027326500858180225, 0.006470397820521612, 0.00605364293733146, 0.015445721237483667, 0.014569325539923739, 0.01605894765816629, 0.0070789491746836575, 0.0520103511371417, 0.11025120271369815, 0.04291947996534873, 0.025825434822763782, 0.1343158754752949, 0.026486428650969174, 0.028828088252339512, 0.02920775059465086, 0.0270110157362069, 0.04317567676480394, 0.08782378194155172, 0.06292855687206611, 0.06622540691751055, 0.055649297864874825, 0.06675611672108062, 0.06050038697139826, 0.020102574526390526, 0.01497379045758862, 0.02359013797104126, 0.02775966091576265, 0.05357841640943661, 0.005362980828067521, 0.04567926000163425, 0.023715826246188954, 0.04554673098027706, 0.005568519090957125, 0.044366500951582566, 0.00916534940188285, 0.07549693167675287, 0.03289208150818013, 0.031936781597323716, 0.010749303128250176, 0.07131043952540495, 0.032346235602744855, 0.039590669330209494, 0.01771695380739402, 0.014804455549892737, 0.0362058117025299, 0.04647680158086587, 0.034031471150228754, 0.025198852526955307, 0.07100442235241644, 0.07186437112977728, 0.05185071888263337, 0.015820085573068354, 0.2366486593382433, 0.01250905586857698, 0.14345076342578977, 0.04267168427759316, 0.05258479570329655, 10.544949062168598, 50.31697601079941, 66.39726474881172, 58.63043211400509, 55.030642077326775, 42.14599706232548, 32.42742195725441, 15.209197830408812, 16.780686154961586, 38.51575545966625, 50.198927745223045, 43.89961056411266, 51.73501431941986, 48.17975029349327, 42.78590552508831, 29.108767434954643, 19.681558795273304, 9.1776161827147, 2.8774200612679124, 0.39022107026539743, 0.03817792814515997, 0.3473895607749, 0.688375337049365, 1.3645741087384522, 1.0110941575840116, 6.002384489402175, 3.472817474976182, 1.7662506736814976, 1.009309678338468, 0.8607997535727918, 1.7312955181114376, 1.4927210449241102, 0.5332597636152059, 0.9525695198681206, 1.5889717801474035, 1.5879254112951458, 0.9460381453391165, 1.5423931670375168, 0.8050781779456884, 2.039076271466911, 0.955766454571858, 1.9748035515658557, 0.9934286680072546, 3.6372990114614367, 3.478194661438465, 2.1439162082970142, 0.6325753906276077, 2.203222238458693, 4.059239057824016, 1.3722795015200973, 1.6599332098849118, 1.3010561233386397, 0.9284399240277708, 0.11910474990145303, 0.726713736075908, 6.818891325965524, 18.966275677084923, 36.49601183831692, 46.45963579416275, 53.08069311082363, 97.27136805653572, 33.37893649935722, 19.026054069399834, 44.621427431702614, 54.09551225602627, 63.52774232625961, 58.69085267186165, 30.612023770809174, 2.8667072486132383, 0.06369189286488108, 0.0552771108050365, 0.048480878613190725, 0.12271862316993065, 0.04324419925978873, 0.01706414586806204, 0.022127403863123618, 0.06527998499223031, 0.009064340320037445, 0.05553684022743255, 0.049138336107716896, 0.01586836970091099, 0.05697373089788016, 0.036565638292813674, 0.0208643612859305, 0.058882727680611424, 0.09541181891108863, 0.026240193328703754, 0.026641734184522647, 0.008426159183727577, 0.05449353644507937, 0.03610449370171409, 0.07182594272308052, 0.046301231705001555, 0.029993397401995026, 0.0830906534974929, 0.03195751349267084, 0.08829067446640693, 0.025732028116181027, 0.05548787703446578, 0.026492501274333335, 0.02870507913030451, 0.05710620796889998, 0.036550513323163614, 0.03981305388151668, 0.024458792140649166, 0.031810237996978685, 0.013011394294153433, 0.03954125342715997, 0.006487455621027038, 0.03355306420417037, 0.030276517463789787, 0.08280972833745182, 0.06583382011740468, 0.010654159796104068, 0.02572039495134959, 0.025240451759600546, 0.04416964256961364, 0.02021692464040825, 0.014862144544167677, 0.09814798380830325, 0.017917576733452734, 0.01237381429746165, 0.01826019291911507, 0.05031285159930121, 0.011212991430511465, 0.05400479509262368, 0.0352884429594269, 0.01254072423762409, 0.017729470127960667, 0.0315908851189306, 0.0375327754591126, 0.06482753466116264, 0.048402177562820725, 0.06803229902288876, 0.033279029885306954, 0.053815139253856614, 0.046082090339041315, 0.047334909831988625, 0.053442247153725475, 0.017066307373170275, 0.05599329815595411, 0.058800516271730885, 0.03522056984365918, 0.028520768610178493, 0.05301831755787134, 0.010218664756393991, 0.012025067971990211, 0.05919763949350454, 0.06326590009848587, 0.03222440092940815, 0.013571962554124184, 0.03781724808504805, 0.04110924819542561, 0.02404211147222668, 0.04082965890120249, 0.03366611184901558, 0.02933361698524095, 0.018101043060596567, 0.03181139203661587, 0.04519669331784826, 0.06958257130463608, 0.026363918623246718, 0.024304601683979854, 0.047083154786378145, 0.03872314322507009, 0.04333582110120915, 0.06922392101841979, 0.03363772098964546, 0.06507183483336121, 0.05734811842557974, 0.055902637395774946, 0.17220989131601527, 0.01895227160275681, 0.04542287395452149, 0.14230650529498234, 0.2834470075322315, 16.17660216987133, 64.66012716293335, 78.44962522387505, 66.8260945379734, 54.749445766210556, 24.971600733697414, 16.4878548681736, 19.303674772381783, 40.82936771214008, 78.40159580111504, 91.85276001691818, 79.6375098824501, 63.86744409799576, 41.7553324252367, 28.266614824533463, 12.320251800119877, 1.1030564666725695, 2.4127888306975365, 1.3413514173589647, 0.8661112748086452, 0.11968027058173902, 0.583188075106591, 0.7834080595057458, 0.7722357683815062, 0.309015063685365, 0.9564729197882116, 1.3214512914419174, 0.6564313417766243, 1.1745905969291925, 1.5702335606329143, 1.808438147418201, 1.7448695772327483, 1.4189204550348222, 1.1650652205571532, 0.7783401408232749, 1.135994524229318, 0.6206568551715463, 0.4143616498913616, 0.2767237136140466, 0.7003227272070944, 1.008508277591318, 1.4252567337825894, 0.8253150607924908, 0.8164393901824951, 1.7537791491486132, 0.9240776393562555, 2.266458682715893, 1.5042649442330003, 3.0346048017963767, 1.5862124157138169, 1.3873150572180748, 0.6808497221209109, 1.0349417966790497, 0.6856052856892347, 1.3487616134807467, 3.162742001004517, 5.1385977398604155, 20.699064396321774, 48.34467664361, 70.66989988088608, 107.16758742928505, 52.30519272387028, 19.704885743558407, 24.036398716270924, 44.418829903006554, 67.58084803819656, 69.32399690151215, 40.65589562058449, 5.371468719094992, 0.12226221719174646, 0.06830526835983619, 0.019298719125799835, 0.05304037418682128, 0.07146864314563572, 0.07409683297737502, 0.025701937738631386, 0.06085242843255401, 0.04019140818854794, 0.06695870077237487, 0.04253233862982597, 0.03940854257962201, 0.013704090815735981, 0.051864515407942235, 0.017869608018372674, 0.07711433121585287, 0.03508416310069151, 0.038638115365756676, 0.05514329415746033, 0.04856565785303246, 0.026690973827498965, 0.0699880659522023, 0.009341033382952446, 0.029654736863449216, 0.031775924799148925, 0.06721239653415978, 0.06344066103338264, 0.044040004213456996, 0.04565350005577784, 0.0435346201993525, 0.031349475611932576, 0.05191193864447996, 0.011467405220173532, 0.0365416409476893, 0.05988587385218125, 0.014337710526888259, 0.04290632910851855, 0.017509555073047522, 0.048145053078769706, 0.04711576104455162, 0.00502960345329484, 0.08374162833206356, 0.014344290593726328, 0.060139380366308615, 0.0956149298872333, 0.017758194953785278, 0.0363875154289417, 0.08976216035080142, 0.01898445112601621, 0.06971529699512757, 0.1716128780390136, 0.0274153878854122, 0.160962687805295, 0.10216035327175632, 0.17830635246355087, 0.12306672011618502, 0.1423232036177069, 0.11868518413393758, 0.20723169174743816, 0.13968532875878736, 0.14055506646400318, 0.14431310934014618, 0.18863727076677606, 0.14312735031126067, 0.17345043568639085, 0.06131304238806479, 0.11706122400937602, 0.1675780734512955, 0.2006052777869627, 0.2186979475663975, 0.15794579812791198, 0.2030631373054348, 0.2173651393968612, 0.11426829223637469, 0.10849854676052928, 0.06918417158885859, 0.1241212006425485, 0.11220886211958714, 0.09108413316425867, 0.13261358166346326, 0.10290716905728914, 0.0838739235769026, 0.17578806728124619, 0.1378164376365021, 0.07739587977994233, 0.1450645487057045, 0.16834125359309837, 0.1188245000957977, 0.12377420207485557, 0.14600982220144942, 0.10299775560270064, 0.1004741492215544, 0.09005555359181017, 0.09976316432585008, 0.22119831730378792, 0.11139957976411097, 0.14551052008755505, 0.13824667548760772, 0.21482735057361424, 0.29821322299540043, 0.21279756183503196, 0.18262867990415543, 0.46338955813553184, 0.1089653502276633, 0.37881779309827834, 0.19587977119954303, 0.4805141407996416, 16.59420356154442, 75.84421902894974, 94.93025287985802, 81.35402977466583, 71.80490657687187, 58.80763940513134, 49.23818729817867, 24.964168332517147, 33.251837119460106, 54.51269946992397, 69.71587747335434, 62.892914190888405, 68.45831215381622, 61.81778848171234, 57.224347963929176, 39.197347685694695, 26.01796768605709, 11.35100170969963, 3.623287263326347, 0.706340060569346, 0.1288964311243035, 0.5971030471846461, 1.5495806001126766, 2.2242229990661144, 1.8029056442901492, 10.716383513063192, 7.254924103617668, 5.61794581823051, 4.840340344235301, 4.873169157654047, 8.240820150822401, 9.026102162897587, 9.631425831466913, 7.5738210417330265, 10.230861715972424, 10.431823432445526, 9.280324671417475, 6.931696347892284, 5.902639841660857, 6.7897791881114244, 4.33304856531322, 8.938007690012455, 4.847128679975867, 12.055142875760794, 11.71864528208971, 10.894227270036936, 8.383874874562025, 7.233904106542468, 9.692167472094297, 5.10895268060267, 5.6151581928133965, 3.147489381954074, 2.185155632905662, 0.45796511170919985, 1.0574098723009229, 9.98042855411768, 25.083671920001507, 49.33292381465435, 61.70621506869793, 69.58235263824463, 104.49548721313477, 48.37877981364727, 28.85613229125738, 63.24391655623913, 69.95651096105576, 88.76585125923157, 77.78494969010353, 47.72730477154255, 6.869887914508581, 0.18558955227490515, 0.46710979600902647, 0.14417735568713397, 0.1933030493091792, 0.2303726875106804, 0.19957931799581274, 0.3373300755629316, 0.2293092047329992, 0.11584214997128583, 0.1780377989052795, 0.12159179066657089, 0.10791303677251562, 0.1462242880370468, 0.09841891966061667, 0.13244303612736985, 0.30932059104088694, 0.2076480959658511, 0.15832941426197067, 0.1497192692477256, 0.10921347988187335, 0.184072706324514, 0.17683799844235182, 0.1543446897994727, 0.10936056612990797, 0.1208390154351946, 0.1527650878415443, 0.18597735412186012, 0.2337531850207597, 0.08880263019818813, 0.22826801607152447, 0.18064413248794153, 0.09094147753785364, 0.21652384079061449, 0.12154871641541831, 0.15699908486567438, 0.17802688933443278, 0.19462300348095596, 0.13614431954920292, 0.11833017037133686, 0.07552418333943933, 0.21119456738233566, 0.14469019457465038, 0.11342868572683074, 0.11637487841653638, 0.1919027799158357, 0.07193914250819944, 0.1553358428645879, 0.18967382842674851, 0.12135393975768238, 0.194413228018675], [0.05537052493309602, 0.021269828102958854, 0.056697640829952434, 0.0321940470894333, 0.04085400876647327, 0.025914229081536178, 0.04417010641191155, 0.021057757548987865, 0.01532829955976922, 0.045086120735504664, 0.02064857071673032, 0.10983495434629731, 0.03663454670459032, 0.037291206390364096, 0.03250542256864719, 0.08748965221457183, 0.02252576276077889, 0.038577752784476615, 0.04010505559563171, 0.06824671290814877, 0.03477480997389648, 0.024690071331860963, 0.007168589017965132, 0.03791526352870278, 0.021259749737509992, 0.04030173957289662, 0.05433901758806314, 0.023131221678340808, 0.06056264945073053, 0.022267222630034667, 0.0831066542014014, 0.04255270316207316, 0.051383254904067144, 0.05427350821264554, 0.07547155022621155, 0.03622432457632385, 0.03424494992941618, 0.027613201782514807, 0.020169497693132143, 0.03510200804157648, 0.03632690793892834, 0.09161400434095412, 0.03544204155332409, 0.016004948993213475, 0.034318537582294084, 0.039829043453210033, 0.05517506549949758, 0.010648800562194083, 0.028403279211488552, 0.017953507813217584, 0.0639046443393454, 0.04325322006479837, 0.16609980433713645, 0.012633656897378387, 0.14126626658253372, 0.021143815138202626, 0.04606856840837281, 0.2549015439581126, 0.5636177002452314, 16.99227400124073, 46.78062357008457, 55.974522829055786, 55.16809970140457, 58.94033968448639, 57.76687525212765, 50.75380437076092, 32.75381304323673, 13.194920215755701, 11.446106806397438, 19.12157144397497, 29.2735892906785, 23.545974232256413, 28.129012808203697, 42.558400332927704, 50.46564303338528, 60.17418287694454, 64.30750608444214, 55.83348199725151, 46.424343287944794, 39.01696376502514, 30.75715508311987, 22.988492846488953, 22.11314521729946, 14.080057069659233, 8.379793893545866, 3.333401056006551, 1.5382466395385563, 0.4329610284185037, 0.142294853576459, 0.07843465646146797, 0.18428838928230107, 0.30671054671984166, 0.3669830609578639, 0.4044344153953716, 0.6335973576642573, 0.547416735207662, 0.6625540601089597, 0.4496912634931505, 0.717946122167632, 0.16419557214248925, 0.2393878373550251, 0.1537893110071309, 0.09677988651674241, 0.37770270137116313, 1.910857257898897, 4.209221284836531, 8.458922747522593, 12.990256547927856, 23.374954909086227, 31.29590917378664, 46.538325771689415, 54.61152836680412, 54.19488072395325, 55.84118038415909, 55.14565050601959, 38.435784950852394, 30.76434999704361, 31.899934262037277, 36.361164674162865, 63.94205689430237, 65.89238584041595, 55.40649890899658, 31.665213257074356, 8.251210693269968, 0.07821019389666617, 0.24268114735605195, 0.0384407820092747, 0.08238579874159768, 0.01799297893740004, 0.021527973040065262, 0.06392746538040228, 0.030090483305684756, 0.030110142797639128, 0.10698557482101023, 0.09141115311649628, 0.017437154856452253, 0.010398502909083618, 0.05430240373243578, 0.01550616081658518, 0.05495013538165949, 0.01301762276852969, 0.06635667799855582, 0.0274758747764281, 0.06669014721410349, 0.058606659877114, 0.03822735518042464, 0.03777628895477392, 0.03966345546359662, 0.07556916491012089, 0.009659886000008555, 0.03230989634175785, 0.07848491470213048, 0.03547315238392912, 0.0326865919487318, 0.018117702420568094, 0.023885310511104763, 0.03467470909527037, 0.03030027732165763, 0.03306766622699797, 0.03984345225035213, 0.009102534022531472, 0.05804888023703825, 0.0547613701201044, 0.003575682812879677, 0.04272523023246322, 0.0510311021207599, 0.05968396144453436, 0.036760062430403195, 0.026656751542759594, 0.016136682061187457, 0.023169889427663293, 0.01262176027012174, 0.024431204656139016, 0.06889932046760805, 0.07985529038705863, 0.05197009704716038, 0.06800938150263391, 0.023613409866811708, 0.018139267376682255, 0.010926197737717303, 0.03901364209013991, 0.04132826339628082, 0.02785567627142882, 0.05267900392937008, 0.036692319190478884, 0.050603673298610374, 0.027826777040900197, 0.04010191260022111, 0.017564620575285517, 0.009990962716983631, 0.05018397765525151, 0.03554842100129463, 0.04355161538114771, 0.035991828262922354, 0.04033525496197399, 0.03428220945352223, 0.01324252320046071, 0.0286742744356161, 0.02641077782755019, 0.025147004234895576, 0.08263842581072822, 0.04782435622473713, 0.05787403024442028, 0.04081758415850345, 0.06970558970351703, 0.03833140428469051, 0.12646459130337462, 0.014087941653997405, 0.04910731433483306, 0.060105608936282806, 0.059394546115072444, 0.06944063556147739, 0.01699225031188689, 0.057096816090052016, 0.08735949435504153, 0.03730693621037062, 0.058978965680580586, 0.10256194422254339, 0.05267600194201805, 0.03215788965462707, 0.05040760530391708, 0.07148743432480842, 0.018559623531473335, 0.007910020522103878, 0.033376310602761805, 0.05816323035105597, 0.03326760823256336, 0.09056496375706047, 0.13884791900636628, 0.02783568466838915, 0.13417750946246088, 0.04444130572665017, 0.04977126562152989, 0.28056079521775246, 1.9724726141430438, 29.76330131292343, 64.92906913161278, 68.00128027796745, 61.67236268520355, 55.87445519864559, 34.08292092382908, 24.8597252368927, 26.055367179214954, 19.95388638228178, 18.91876682639122, 39.82353128492832, 59.61724296212196, 65.70375636219978, 72.81729385256767, 82.06193178892136, 78.69496285915375, 62.30157472193241, 52.02830918133259, 40.65085329115391, 25.951108373701572, 16.990013122558594, 15.4373100399971, 5.747439544647932, 2.7939010178670287, 4.1959381476044655, 1.517884482163936, 2.200755220837891, 1.9317460432648659, 0.883582856040448, 0.2487047147587873, 0.28101288189645857, 0.605247791390866, 0.43953149928711355, 0.4060012969421223, 0.25382718129549176, 0.13888323039282113, 0.32574375509284437, 0.620465618558228, 0.8048722764942795, 1.0113317635841668, 0.6795415235683322, 0.36999508214648813, 0.40994717739522457, 0.1633946760557592, 0.8267130295280367, 1.8991239625029266, 2.910033711232245, 2.3457003431394696, 5.089727137237787, 7.707681208848953, 15.94377726316452, 32.304639145731926, 54.827691167593, 76.74262002110481, 83.2492844760418, 79.60961937904358, 54.436065182089806, 33.63827258348465, 53.358746990561485, 30.14706552028656, 42.25288912653923, 73.9800314605236, 71.40766829252243, 45.588452741503716, 12.673427648842335, 0.23817570239771158, 0.36830429162364453, 0.04183058234048076, 0.0566553977841977, 0.06497611262602732, 0.07342340817558579, 0.0944697366503533, 0.023038861399982125, 0.09584323677700013, 0.06472427223343402, 0.057263706548837945, 0.0073899596100091, 0.018152715092583094, 0.02892205899115652, 0.022912740823812783, 0.04336279445851687, 0.04785810910107102, 0.05080396782432217, 0.0433960092777852, 0.11049597786040977, 0.047510294170933776, 0.03217106648662593, 0.020428726165846456, 0.0658023456344381, 0.019872814882546663, 0.018337624896958005, 0.051315021846676245, 0.017939620374818332, 0.02243260467366781, 0.0633935494988691, 0.010823173724929802, 0.03707976851728745, 0.025718619363033213, 0.01979514170670882, 0.036791102756978944, 0.06780070441891439, 0.04398485521960538, 0.09910767723340541, 0.055145283113233745, 0.022384431867976673, 0.08816087283776142, 0.03766882226045709, 0.046464782499242574, 0.017736333138600457, 0.023220646762638353, 0.048457560333190486, 0.05092890096420888, 0.01285513046241249, 0.02529709989175899, 0.06602218461921439, 0.06521996008814313, 0.03606184989621397, 0.21017736493377015, 0.10101372026838362, 0.11696360190398991, 0.10429871079395525, 0.1280444604344666, 0.1839672026108019, 0.10501386655960232, 0.11427336110500619, 0.17982635996304452, 0.15676823240937665, 0.18973751954035833, 0.1640183324343525, 0.08455698887701146, 0.07875653333030641, 0.16430950665380806, 0.13618737895740196, 0.11330299559631385, 0.0954947761783842, 0.13255182013381273, 0.19800075504463166, 0.10981833765981719, 0.09847521898336709, 0.0858198941568844, 0.06920584972249344, 0.1257786390488036, 0.11716053078998812, 0.14575051580322906, 0.19040229090023786, 0.10925945593044162, 0.16587747173616663, 0.27943926164880395, 0.12819182127714157, 0.19220899004722014, 0.167098542151507, 0.1691479978035204, 0.09805408728425391, 0.08166814935975708, 0.2501119900261983, 0.13065584062132984, 0.20600469899363816, 0.0971931811363902, 0.12330737634329125, 0.13816546968882903, 0.16862475400557742, 0.11581948478124104, 0.14322866831207648, 0.21387563523603603, 0.10682818756322376, 0.14621502603404224, 0.15735068474896252, 0.19135860755341128, 0.1924716361099854, 0.38972311886027455, 0.0987905501096975, 0.29022709059063345, 0.14140997605863959, 0.14228186599211767, 0.38959241181146353, 1.8170008691959083, 31.52248151600361, 80.99959999322891, 88.42168852686882, 77.30329513549805, 80.3729984164238, 76.25736325979233, 70.78084632754326, 51.38807013630867, 25.201131217181683, 22.30330601334572, 33.257419019937515, 41.79199665784836, 34.762218073010445, 42.90057957172394, 55.634900853037834, 66.92781507968903, 76.07355192303658, 79.76354151964188, 72.54172503948212, 62.711371332407, 52.01335318386555, 44.31777432560921, 31.86265256255865, 32.27547951042652, 21.92914769053459, 12.454512845724821, 5.322682661935687, 2.7004621317610145, 0.751548312837258, 0.17850285832537338, 0.3764105332084, 0.5271544412244111, 0.7289269985631108, 0.5412928888108581, 0.5952555150724947, 1.0136814625002444, 1.239775624126196, 1.5035922615788877, 1.0794030921533704, 0.8782529889140278, 0.683642216026783, 0.36085333675146103, 0.22604927653446794, 0.16492170427227393, 0.7402396446559578, 2.801763745956123, 5.4519840236753225, 11.847614161670208, 18.913046233356, 29.657117910683155, 44.9414424598217, 62.07735255360603, 74.75074410438538, 75.47754630446434, 75.12632355093956, 75.44739872217178, 58.06575961410999, 37.639013305306435, 50.59275381267071, 50.67246973514557, 82.7820235490799, 86.19976535439491, 78.51891070604324, 52.87238448858261, 15.595205817371607, 0.2559989725705236, 0.5961659224703908, 0.1312482971115969, 0.21791061793919653, 0.12109052928281017, 0.23792464868165553, 0.2187623511417769, 0.10275159263983369, 0.1822013215860352, 0.19624326028861105, 0.2934463194105774, 0.14784951723413542, 0.04796350149263162, 0.14396323123946786, 0.16163848747964948, 0.12063689893693663, 0.1656623082817532, 0.1578852834063582, 0.15418171416968107, 0.1692698139231652, 0.17082776001188904, 0.11584318155655637, 0.15982352080754936, 0.10895305284066126, 0.15345528518082574, 0.12879398505901918, 0.17838353582192212, 0.15428334387252107, 0.15329377900343388, 0.182168785831891, 0.13720483373617753, 0.16234217706369236, 0.11923167199711315, 0.11723613337380812, 0.11942731696763076, 0.24656097666593269, 0.06946915629669093, 0.18257236573845148, 0.09163657305180095, 0.1632148091448471, 0.18972021265653893, 0.10258173730107956, 0.16418782412074506, 0.12628741096705198, 0.12096231585019268, 0.11142971095978282, 0.13778856256976724, 0.10134706331882626, 0.13533687771996483, 0.17082312901038677, 0.13574213488027453, 0.12264673132449389], [0.06352985234116204, 0.04731349887151737, 0.02876918028050568, 0.07334626192459837, 0.0660328492813278, 0.05194435936573427, 0.012007642344542546, 0.07364669814705849, 0.03554233910108451, 0.06302841284195893, 0.031165463806246407, 0.06492523098131642, 0.016700183659850154, 0.03950932252337225, 0.011990900420641992, 0.05452228353533428, 0.020257418073015288, 0.0010256899508931383, 0.05299528500472661, 0.11013982119038701, 0.019769784375966992, 0.02277253985084826, 0.029060317392577417, 0.01696754050499294, 0.07344976926106028, 0.021185490440984722, 0.021616262638417538, 0.008769831074459944, 0.039059562477632426, 0.021747550417785533, 0.07087545192916878, 0.053433983339346014, 0.05417937420133967, 0.0193470848898869, 0.02728699448198313, 0.06738473064615391, 0.047321907404693775, 0.02019352472416358, 0.013263302407722222, 0.03215326607460156, 0.03374689091288019, 0.029603046277770773, 0.07251954652019776, 0.08433509414317086, 0.024007482861634344, 0.018253428243042435, 0.00688427409841097, 0.03404872979444917, 0.09118880567257293, 0.023464553596568294, 0.022696514242852572, 0.012594878753589, 0.035664678434841335, 0.03743016241060104, 0.03486063564196229, 0.09191107121296227, 0.04358453705208376, 0.07588430307805538, 0.11543754590093158, 0.6022641796153039, 1.4797895075753331, 23.219501450657845, 51.88602961599827, 59.764652252197266, 58.41858968138695, 55.66073186695576, 67.43237480521202, 56.013033762574196, 69.30967926979065, 42.228369042277336, 31.82152546942234, 32.81248949468136, 26.648657843470573, 16.46867159754038, 33.197511434555054, 28.58132913708687, 15.627434737980366, 20.07210373878479, 40.303111150860786, 45.64907468855381, 39.10471625626087, 40.374995693564415, 40.19637867808342, 43.36810648441315, 44.81619358062744, 46.53125815093517, 45.855346620082855, 40.17382308840752, 35.90458117425442, 34.7840479016304, 32.67358414828777, 25.601570829749107, 26.446136310696602, 27.313415072858334, 30.66172320395708, 28.57206903398037, 32.95446887612343, 32.31609933078289, 36.45273216068745, 34.57506291568279, 31.712150238454342, 44.0697730332613, 50.35170614719391, 59.387780874967575, 57.53397434949875, 58.221589252352715, 60.76133497059345, 60.374561324715614, 69.92463827133179, 66.63647711277008, 56.51920460164547, 35.23717358708382, 24.401203840970993, 28.444886058568954, 34.568291679024696, 54.28303599357605, 68.89231726527214, 65.71880355477333, 72.5068125128746, 51.83576971292496, 20.55239226669073, 5.73699533008039, 0.0895111437421292, 0.3195443283766508, 0.06349670060444623, 0.05611368193058297, 0.027968842659902293, 0.014296487934188917, 0.07021934143267572, 0.11243418557569385, 0.0958010605245363, 0.10482098237844184, 0.025840162743406836, 0.09528822163701989, 0.016989545183605514, 0.05288483858748805, 0.025259990652557462, 0.07895520626334473, 0.08936438403907232, 0.020822860387852415, 0.04025066868052818, 0.031153778691077605, 0.06621178108616732, 0.010566919409029651, 0.018925047770608217, 0.021945575826975983, 0.01746184796502348, 0.0284820804517949, 0.04859398562985007, 0.07311605513677932, 0.1464899769052863, 0.005040784835728118, 0.03310406857053749, 0.024299781434820034, 0.03090578262344934, 0.07902314988314174, 0.05490569928952027, 0.06170264023239724, 0.03159015781420749, 0.014557999438693514, 0.10423790663480759, 0.042904937581624836, 0.008042902991292067, 0.019142732671753038, 0.02956185708171688, 0.01715054298983887, 0.04375200267531909, 0.03908156344550662, 0.05101883813040331, 0.01005943233394646, 0.01058539981386275, 0.031068431708263233, 0.01240817851794418, 0.020046206554980017, 0.0861607922706753, 0.045117632325855084, 0.05314331006957218, 0.07355227469815873, 0.060887840008945204, 0.06778724928153679, 0.06155008064524736, 0.06276808970142156, 0.07502491091145203, 0.0547694929264253, 0.024503868335159495, 0.142715799738653, 0.018936625274363905, 0.07925372774479911, 0.04117049764317926, 0.0467265082988888, 0.03802255210757721, 0.021006022434448823, 0.06291968820733018, 0.03084943691646913, 0.021524199219129514, 0.03371726437762845, 0.029689599250559695, 0.04324432542489376, 0.012987379323021742, 0.09194380734697916, 0.029567966812464874, 0.016971841250779107, 0.016104558199003804, 0.007432845077346428, 0.05357185953471344, 0.016339765206794254, 0.06257198459934443, 0.06836498898337595, 0.026190309872617945, 0.036079835845157504, 0.034859689403674565, 0.06137659991509281, 0.060672520703519695, 0.013377706327446504, 0.026871352820307948, 0.015367510004580254, 0.011510049025673652, 0.024931887164711952, 0.07455271945218556, 0.018981848043040372, 0.03929264137696009, 0.004043351345899282, 0.05479950166773051, 0.03564780570741277, 0.03487703710561618, 0.04767738872033078, 0.08320769760757685, 0.02861502878658939, 0.015049349440232618, 0.029073933947074693, 0.14997758116805926, 0.08186825463781133, 0.1006402492930647, 0.13660997268743813, 0.11396270550903864, 0.7833670929539949, 4.697742545977235, 36.014452278614044, 64.56231281161308, 70.73496758937836, 67.26160436868668, 63.67878042161465, 56.78005300462246, 31.781029142439365, 29.070670679211617, 19.9922339245677, 21.051231399178505, 16.394953653216362, 18.66615068167448, 24.2191594094038, 40.2510729432106, 57.17413745820522, 49.1770675778389, 53.401707485318184, 73.4845532476902, 81.26343503594398, 70.87336376309395, 78.24198916554451, 70.41722103953362, 61.9963750988245, 63.994440883398056, 63.669106140732765, 50.627799332141876, 36.534564569592476, 28.36108535528183, 23.104705810546875, 20.515847727656364, 15.013864561915398, 14.055769722908735, 12.968626208603382, 9.546341747045517, 11.962732784450054, 15.029390528798103, 19.402497969567776, 26.2332546338439, 23.41878365725279, 22.810981571674347, 35.74423737823963, 37.27924861013889, 53.01996476948261, 60.22617168724537, 64.5981676876545, 65.31500682234764, 71.37723952531815, 87.78793573379517, 82.54349514842033, 78.66627439856529, 54.363534674048424, 36.864949241280556, 29.89103715866804, 36.521185487508774, 43.29105041921139, 50.76584592461586, 55.752329751849174, 79.36323300004005, 69.15285408496857, 34.67897593975067, 11.969823203980923, 0.720216678455472, 0.33622154442127794, 0.14675784768769518, 0.020107676791667473, 0.08553867955924943, 0.039915158558869734, 0.03733116733201314, 0.0986020965501666, 0.025442399419262074, 0.03734516794793308, 0.058557481461321004, 0.01980014563741861, 0.03594927351514343, 0.041764052512007765, 0.056649468024261296, 0.030586644279537722, 0.09454084924072959, 0.004825413579965243, 0.0419661319028819, 0.03907453530700877, 0.050343390976195224, 0.015841370368434582, 0.04523921095824335, 0.044081879896111786, 0.0358711995795602, 0.046583258954342455, 0.064626011881046, 0.028338042575342115, 0.05975550819130149, 0.10061115710414015, 0.021115249874128494, 0.039703134389128536, 0.03726848182850517, 0.007464266682291054, 0.03380001384357456, 0.039421804758603685, 0.0034367887155895005, 0.0601951342105167, 0.09046712642884813, 0.025690573602332734, 0.05766431044321507, 0.029574792715720832, 0.05442866531666368, 0.06996361960773356, 0.059565614865277894, 0.0630341273790691, 0.07084230761392973, 0.029488920663425233, 0.016678678075550124, 0.02130951630533673, 0.01990776447200915, 0.039165437265182845, 0.05900308919080999, 0.041970833408413455, 0.1422657910734415, 0.3433599363779649, 0.16769257199484855, 0.17314326076302677, 0.10899526620050892, 0.15402250865008682, 0.12567377358209342, 0.15918659482849762, 0.1787202333798632, 0.21222664247034118, 0.19974557391833514, 0.21827052987646312, 0.06846410280559212, 0.12775883747963235, 0.1092354251886718, 0.08282316863187589, 0.19741999480174854, 0.10355360194807872, 0.15377378527773544, 0.16742913925554603, 0.12981396313989535, 0.14968847011914477, 0.087161400297191, 0.231116809300147, 0.1281848450889811, 0.09393253305461258, 0.1825293805450201, 0.14417901809792966, 0.10499048890778795, 0.0938797218259424, 0.14490998903056607, 0.1461759742232971, 0.12606815085746348, 0.08974405194749124, 0.16575522517086938, 0.19853851525112987, 0.19262879330199212, 0.10757213865872473, 0.14643838279880583, 0.2663504483643919, 0.08210026484448463, 0.07387260789982975, 0.1666262690559961, 0.14072574558667839, 0.10822813783306628, 0.13383978774072602, 0.16470199887407944, 0.12688288057688624, 0.13774851628113538, 0.1792027777992189, 0.1748526346636936, 0.13293890951899812, 0.17121836717706174, 0.12506959115853533, 0.31987289199605584, 0.15239693806506693, 0.1980001910123974, 0.2681687398580834, 0.2598441287409514, 1.1708520725369453, 4.257533792406321, 41.654516234993935, 83.00490438938141, 87.19446077942848, 82.79558882117271, 77.24968761205673, 87.29526937007904, 71.09443590044975, 93.465256690979, 60.420823842287064, 48.628278225660324, 46.02944567799568, 43.890206068754196, 26.196007132530212, 43.35629291832447, 40.36202318966389, 25.845595635473728, 33.5707426071167, 56.970931962132454, 63.26920419931412, 51.657008305191994, 61.44292339682579, 56.95522740483284, 64.22606125473976, 68.98305639624596, 68.33718225359917, 68.8627852499485, 59.44178357720375, 53.76757085323334, 50.64603455364704, 45.81982232630253, 39.29054528474808, 39.16055046021938, 39.671041667461395, 42.814020216464996, 39.91322547197342, 48.24192255735397, 47.626936957240105, 52.674460709095, 51.01295806467533, 45.94571337103844, 57.719324603676796, 67.59899586439133, 76.9888924062252, 76.0955299437046, 74.4052666425705, 79.57940340042114, 79.55145210027695, 92.56573855876923, 88.11783403158188, 79.5463527739048, 48.829838410019875, 41.19358956813812, 41.637451350688934, 52.46764920651913, 72.15060442686081, 86.74837231636047, 86.10810667276382, 96.79076224565506, 77.22680523991585, 48.88334333896637, 17.346187010407448, 0.9432495106011629, 0.5022117483895272, 0.13089708314510062, 0.14880638307658955, 0.254102666513063, 0.13713734282646328, 0.17066377506125718, 0.18770258029690012, 0.2039220099686645, 0.12532932800240815, 0.19247389223892242, 0.18562839628430083, 0.10704864253057167, 0.22135188250103965, 0.11037292235414498, 0.16101128363516182, 0.26109818019904196, 0.08584759110817686, 0.11527155715157278, 0.2076051404583268, 0.15679861593525857, 0.16606622957624495, 0.23901689710328355, 0.09869539193459786, 0.10194518239586614, 0.21523842617170885, 0.13180388370528817, 0.1927437965059653, 0.2399833663366735, 0.24176129983970895, 0.1078397645324003, 0.21656868135323748, 0.13747240765951574, 0.14718888705829158, 0.10760010278318077, 0.20167085342109203, 0.09489316900726408, 0.1564192003570497, 0.18899722723290324, 0.14781846577534452, 0.1326487000915222, 0.13221258443081751, 0.14810579566983506, 0.21896941034356132, 0.12120242288801819, 0.1215207893983461, 0.22574444679776207, 0.12639695196412504, 0.11831044408609159, 0.11451392085291445, 0.130556081130635, 0.10105996349011548, 0.2236400276888162, 0.13261181535199285], [0.10061856373795308, 0.005610364160020254, 0.005673286686942447, 0.09254526608856395, 0.09775764381629415, 0.014668786316178739, 0.014573662465409143, 0.027728190143534448, 0.03441716529778205, 0.021479824354173616, 0.022136612060421612, 0.0017964960079552839, 0.07665414770599455, 0.06397442848538049, 0.0677643169183284, 0.035073550388915464, 0.013219791217125021, 0.011695039538608398, 0.05568705833866261, 0.03511187118419912, 0.012989104816369945, 0.05160083404916804, 0.06651950519881211, 0.009466217925364617, 0.03153847093926743, 0.08226478414144367, 0.061774045971105807, 0.011859980004373938, 0.03314340610813815, 0.0187831417133566, 0.047060077704372816, 0.07545351603766903, 0.06473867731983773, 0.034983238438144326, 0.026358027826063335, 0.015923520550131798, 0.07056999878841452, 0.01655723859585123, 0.013479131939675426, 0.023843518320063595, 0.08098436417640187, 0.09842926519922912, 0.025395132033736445, 0.04347335590864532, 0.03588496270822361, 0.06073256787203718, 0.08328580865054391, 0.05626052698062267, 0.05567311338381842, 0.022036613227101043, 0.05753117657150142, 0.04207128680718597, 0.12411571617121808, 0.03947596669604536, 0.05973112492938526, 0.017357093820464797, 0.013631806559715187, 0.0698913270025514, 0.06516801717225462, 0.11334305672789924, 0.07976488195708953, 0.2935845369938761, 2.410997226834297, 20.17304342240095, 40.45547917485237, 51.9413660466671, 51.96051701903343, 73.47188472747803, 62.04280860722065, 62.077884525060654, 74.11538779735565, 85.38603141903877, 79.52673822641373, 83.53263527154922, 64.23712626099586, 48.23872312903404, 53.38427022099495, 50.23097522556782, 31.725443825125694, 21.481997184455395, 57.64803662896156, 37.1372502297163, 29.166573733091354, 67.51205652952194, 42.492090091109276, 24.515771493315697, 42.38035708665848, 29.971689730882645, 27.889568656682968, 37.95055478811264, 30.02173114567995, 42.763064950704575, 33.93564462661743, 49.913407266139984, 53.931680247187614, 57.825072929263115, 44.49091203510761, 34.27981115877628, 20.511379167437553, 62.66974076628685, 81.29650086164474, 54.243928492069244, 56.63006365299225, 25.177543982863426, 22.813837118446827, 19.353372305631638, 28.232179172337055, 35.49780920147896, 34.422341510653496, 42.18060180544853, 52.31064163148403, 63.34618426859379, 74.02575820684433, 75.63488066196442, 58.758405447006226, 54.138643741607666, 50.37809193134308, 48.45781937241554, 31.527375653386116, 6.484301229938865, 0.15332833339925855, 0.4804480302846059, 0.059281420544721186, 0.030211219600460026, 0.05181733336939942, 0.04983522019756492, 0.04739024065202102, 0.05623464458039962, 0.05419495930254925, 0.02142592587915715, 0.030770463126827963, 0.04399058088893071, 0.05747075461840723, 0.008663480384711875, 0.07732511599897407, 0.032334587594959885, 0.0785066893149633, 0.025308488147857133, 0.0708423818286974, 0.045286073873285204, 0.08058085848460905, 0.012086133738193894, 0.06302181514911354, 0.03753373654035386, 0.017503040871815756, 0.006013533566147089, 0.0313422990438994, 0.08232734719058499, 0.03329609186039306, 0.11336115028825589, 0.01485712669818895, 0.04061714491399471, 0.04234705775161274, 0.030017103454156313, 0.04215658183966298, 0.013403007069427986, 0.09552785370033234, 0.02113455870130565, 0.07136782980524004, 0.023117933524190448, 0.0568817862222204, 0.02246921110781841, 0.011896476971742231, 0.038817700260551646, 0.04970544825482648, 0.09182133813737892, 0.036751408988493495, 0.06654024822637439, 0.009491195833106758, 0.02066365115751978, 0.011018045006494503, 0.05636504363792483, 0.0636664817284327, 0.03522374994645361, 0.04339929699199274, 0.0934583303751424, 0.04586414012010209, 0.03154815967718605, 0.042109989808523096, 0.028272390336496755, 0.01534369448563666, 0.01289236493903445, 0.04625885507266503, 0.038764555065426975, 0.023243486357387155, 0.05475749239849392, 0.0744529376970604, 0.017102433266700245, 0.061219984490890056, 0.04480505085666664, 0.02429242118523689, 0.030241042804846074, 0.028032021691615228, 0.020206117114867084, 0.02925630189565709, 0.03889967418217566, 0.0389663264650153, 0.034894288328359835, 0.01714573758363258, 0.08179493044735864, 0.014643189642811194, 0.006229941045603482, 0.05348074235371314, 0.028503875473688822, 0.02084268500766484, 0.03021089120011311, 0.04628996961400844, 0.02767944217339391, 0.01913009946292732, 0.02395295727183111, 0.024902835793909617, 0.02340809842280578, 0.06259571106056683, 0.03151140110276174, 0.0925707069109194, 0.03550687928509433, 0.08487209735903889, 0.058158298779744655, 0.040563747388659976, 0.04724167753010988, 0.04985312822100241, 0.02722057226492325, 0.040378069461439736, 0.02913805550633697, 0.00884389648490469, 0.08307959549711086, 0.03473539080005139, 0.06689109854050912, 0.10955979567370377, 0.023497363945352845, 0.01859322055679513, 0.08813724285573699, 0.0814045310835354, 0.10520421259570867, 0.07861130987294018, 0.3081273066345602, 0.026841086182685103, 0.1974584232084453, 5.644359150901437, 33.23618955910206, 57.97039233148098, 65.31974136829376, 66.6556204855442, 78.73856171965599, 68.35760995745659, 61.21693052351475, 55.87578132748604, 51.1505638808012, 44.489034935832024, 29.634227938950062, 38.20853054523468, 25.948744900524616, 13.368701990693808, 18.630360402166843, 24.796433933079243, 23.406776301562786, 40.91379918158054, 30.816961973905563, 30.24030301719904, 66.74497649073601, 48.65296930074692, 45.32439351081848, 60.804428458213806, 54.729550033807755, 56.27765156328678, 69.65593948960304, 60.907501727342606, 71.32691502571106, 64.29231449961662, 76.08537688851357, 84.20556396245956, 86.30587086081505, 72.9145610332489, 70.20413607358932, 55.115278735756874, 79.25750747323036, 82.29620441794395, 68.95638942718506, 79.26041811704636, 52.136740162968636, 42.91011705994606, 38.886642158031464, 43.67035746574402, 46.82722046971321, 36.24120131134987, 45.96261106431484, 52.165466621518135, 40.60876674950123, 51.925919875502586, 59.93946187198162, 66.7784982919693, 70.58323413133621, 70.44789299368858, 69.61478009819984, 48.68874818086624, 10.339512135833502, 0.7250116649083793, 0.5976299720350653, 0.06991678266786039, 0.14005248405737802, 0.03988313488662243, 0.033469309128122404, 0.046420784274232574, 0.053083114471519366, 0.05926677054958418, 0.03886422549840063, 0.048712907373555936, 0.024544675325159915, 0.012821738455386367, 0.0140867254594923, 0.03260780926211737, 0.028149345962447114, 0.023751119078951888, 0.09594672927050851, 0.035277637289254926, 0.016035735134209972, 0.03337248483148869, 0.003142314953947789, 0.07484105866751634, 0.07773936798912473, 0.05181175612960942, 0.034873300392064266, 0.018826340274245013, 0.027733789647754747, 0.015608005742251407, 0.08040327738854103, 0.07723003946011886, 0.02474928358424222, 0.08560011454392225, 0.04575389037199784, 0.03280936914961785, 0.03378384244570043, 0.03050988023460377, 0.02776768167677801, 0.03009132378792856, 0.018176307967223693, 0.033452451243647374, 0.008311527981277322, 0.07801758431014605, 0.01825633746193489, 0.045150502046453767, 0.07562104845419526, 0.009322234782302985, 0.018982298897753935, 0.024776225400273688, 0.00918618427022011, 0.0336175048869336, 0.038190114210010506, 0.06629104245803319, 0.06602248147828504, 0.027789458144980017, 0.04789906452060677, 0.19807540025794879, 0.13062706013442948, 0.13492370926542208, 0.16432880249340087, 0.18132723489543423, 0.1210990862455219, 0.14774923824006692, 0.10324496499379165, 0.10395169738330878, 0.13997055095387623, 0.11047357984352857, 0.10424684951431118, 0.14327711571240798, 0.18435935344314203, 0.12712341063888744, 0.09858542791334912, 0.10563151896349154, 0.08090758899925277, 0.18553371308371425, 0.13507112947991118, 0.15903899649856612, 0.2026324244798161, 0.14295288623543456, 0.12440863443771377, 0.1386559402453713, 0.14692558790557086, 0.2236280939541757, 0.09998681794968434, 0.14141952007776126, 0.147401349095162, 0.1399557970580645, 0.14993934571975842, 0.12453402770916, 0.12281748466193676, 0.06875480205053464, 0.18054554559057578, 0.2443771922844462, 0.20223258499754593, 0.13245151145383716, 0.15986355225322768, 0.2396649998263456, 0.1884065370541066, 0.20647421129979193, 0.1971816466539167, 0.1350326565443538, 0.1661984802922234, 0.14535958209307864, 0.12851714913267642, 0.11110743333119899, 0.1537757000187412, 0.12355578801361844, 0.13189708261052147, 0.2365915584960021, 0.13376367307500914, 0.21478461771039292, 0.18789400986861438, 0.1448041884577833, 0.2404907430172898, 0.22994862432824448, 0.4423825931735337, 0.15596024139085785, 0.37251820613164455, 4.196441620588303, 33.84604163467884, 65.82493185997009, 85.02892658114433, 82.0079442858696, 97.40165546536446, 79.00634855031967, 80.15408456325531, 89.14311781525612, 103.14642280340195, 98.6011902987957, 105.11515036225319, 86.19796425104141, 69.8643659055233, 71.38168528676033, 73.67321312427521, 50.08300356566906, 37.508851289749146, 72.16686755418777, 50.38924813270569, 41.312177404761314, 81.94394811987877, 53.03670287132263, 37.05061487853527, 53.22040781378746, 48.93234170973301, 44.504883885383606, 61.980412155389786, 47.996201142668724, 64.10337343811989, 53.20212699472904, 71.56081527471542, 76.92725971341133, 78.775275349617, 61.820269748568535, 49.64963302016258, 33.917382806539536, 78.73035416007042, 98.90420123934746, 71.3360345363617, 72.42888629436493, 39.92952659726143, 33.33419010043144, 36.07447765767574, 44.9074000865221, 57.25664243102074, 46.92189238965511, 56.06897436082363, 69.64409932494164, 88.16186606884003, 106.55723378062248, 96.05925589799881, 88.33687707781792, 84.1019207239151, 84.11017388105392, 77.12031975388527, 56.87806114554405, 15.907219424843788, 0.46309350058436394, 1.021643579006195, 0.2783027960686013, 0.30007767607457936, 0.11263650987530127, 0.23005921917501837, 0.11662575401715003, 0.13402991113252938, 0.1744739612331614, 0.11815042220405303, 0.23964018240803853, 0.0814504774461966, 0.1262112517724745, 0.09616896539228037, 0.12322671973379329, 0.09639575830078684, 0.15094246220542118, 0.21183168631978333, 0.15792914433404803, 0.3142453939653933, 0.10852715655346401, 0.09986232267692685, 0.17575609555933625, 0.182089910376817, 0.14104270201642066, 0.09232151598553173, 0.09605912753613666, 0.10400395942269824, 0.1648765371646732, 0.1282791720586829, 0.11201279412489384, 0.10726593594881706, 0.15928688866551965, 0.17045857122866437, 0.07913295805337839, 0.09513156168395653, 0.21954266005195677, 0.13014914671657607, 0.12733008392388, 0.05982160757412203, 0.09437559521757066, 0.10687523972592317, 0.15137036971282214, 0.10453138151206076, 0.1429536283831112, 0.15610878966981545, 0.08963347194367088, 0.15713494241936132, 0.11782228903030045, 0.1296789664775133, 0.0793133518891409, 0.12710840441286564, 0.13879956066375598, 0.14206229418050498, 0.11288766007055528, 0.21884020243305713], [0.02986223578773206, 0.006419611263481784, 0.030885202868375927, 0.04946910390572157, 0.01765136836183956, 0.04347903704911005, 0.11245392670389265, 0.05322389988577925, 0.008014673549041618, 0.038531242389581166, 0.03899928895407356, 0.05235200995230116, 0.027859192196046934, 0.06074528457247652, 0.031125616042118054, 0.0013864352968084859, 0.07393109655822627, 0.009399696446052985, 0.021042333864897955, 0.07451371959177777, 0.07631601038156077, 0.047967624122975394, 0.032443434683955275, 0.05304605161654763, 0.028075043992430437, 0.03194133096258156, 0.051445881035760976, 0.08130271584377624, 0.021187147285672836, 0.009109970342251472, 0.036927561450283974, 0.023114827636163682, 0.03148845389659982, 0.011760433881136123, 0.024794537894194946, 0.05253544659353793, 0.058052847016369924, 0.03362767973158043, 0.05742191387980711, 0.04788012491189875, 0.04766955906234216, 0.0078122972990968265, 0.017081970399885904, 0.03312681168608833, 0.028484889480751008, 0.07373716594884172, 0.04448208674148191, 0.072026263223961, 0.021554634695348796, 0.13044141931459308, 0.06561343194334768, 0.1033041364280507, 0.09349623927846551, 0.04128753062104806, 0.11498354448121972, 0.05685783711669501, 0.025442299229325727, 0.052473373361863196, 0.011809812676801812, 0.1755050863721408, 0.02665837870154064, 0.2155852466239594, 0.0373634878633311, 0.3337883687345311, 0.060358302798704244, 1.0408258996903896, 8.08101687580347, 34.46788966655731, 59.847677797079086, 65.76284319162369, 67.26378545165062, 69.79174420237541, 71.90470442175865, 76.61905065178871, 65.24742364883423, 86.95719391107559, 83.90613242983818, 80.71387812495232, 75.60326635837555, 76.40818476676941, 62.79930621385574, 75.16627460718155, 49.43365640938282, 62.705470249056816, 51.125280037522316, 66.77011594176292, 76.74344077706337, 56.512589156627655, 48.20321023464203, 42.12779603898525, 50.26958495378494, 43.05968463420868, 32.705004662275314, 36.52749314904213, 27.028897739946842, 31.273429580032825, 32.44857542216778, 39.299049228429794, 37.779886946082115, 44.490554854273796, 64.24293994903564, 50.561238303780556, 46.47745303809643, 55.103582963347435, 67.58948877453804, 66.54110983014107, 69.64969262480736, 62.596119716763496, 69.52632084488869, 53.11208322644234, 40.15840731561184, 34.68595236539841, 35.07374435663223, 37.98788018524647, 25.44760689139366, 12.514666467905045, 5.758963851258159, 0.6066962261684239, 0.06649395305430517, 0.2742989390389994, 0.016835831556818448, 0.11537910919287242, 0.11230653617531061, 0.16465171094750986, 0.037590362408082, 0.022021779550414067, 0.042397813231218606, 0.08714609721209854, 0.025299639892182313, 0.0215659209061414, 0.04040498715767171, 0.029515038695535623, 0.10544442353420891, 0.10138321333215572, 0.014638424127042526, 0.017818314481701236, 0.014912025217199698, 0.010044605151051655, 0.07616715040057898, 0.042662774794735014, 0.016661376757838298, 0.04746714199427515, 0.03892514840117656, 0.049817768594948575, 0.00770005673984997, 0.03695526953379158, 0.027874237384821754, 0.03949925900087692, 0.006920366595295491, 0.06068047652661335, 0.05811482376884669, 0.015463587515114341, 0.05846242718689609, 0.03649028803920373, 0.08550651487894356, 0.017097145464504138, 0.05269123452308122, 0.02249952041893266, 0.045796218764735386, 0.020253937400411814, 0.012403135624481365, 0.052393547957763076, 0.029060339657007717, 0.03912252257578075, 0.03360784212418366, 0.030156274697219487, 0.06225798191735521, 0.024995925232360605, 0.023259136396518443, 0.0380490022507729, 0.06838204353698529, 0.02520129975891905, 0.0050692123386397725, 0.031518789182882756, 0.0028630283168240567, 0.08750176406465471, 0.043965822842437774, 0.050332410901319236, 0.05778695034678094, 0.012129312817705795, 0.04639183680410497, 0.029452353192027658, 0.041248768247896805, 0.05182354143471457, 0.016530651155335363, 0.024597245355835184, 0.007100071161403321, 0.06515071028843522, 0.034916437725769356, 0.03190430892573204, 0.07239877682877705, 0.0396183328848565, 0.030672050634166226, 0.008355594854947412, 0.04505336233705748, 0.05094811516755726, 0.03945156488043722, 0.06527369900140911, 0.042135211697313935, 0.032167730532819405, 0.004934452235829667, 0.04599856532877311, 0.03490103074000217, 0.07533506184699945, 0.05051138352428097, 0.03256479438277893, 0.04540460227872245, 0.030940273936721496, 0.038253037200775, 0.016334455140167847, 0.07428590251947753, 0.016968158342933748, 0.03212541327229701, 0.03306812264781911, 0.0322695606155321, 0.03380028472747654, 0.050373848716844805, 0.019664712963276543, 0.029080199528834783, 0.017934690658876207, 0.04520519090874586, 0.06441066288971342, 0.0542333023622632, 0.050450909620849416, 0.048722443971200846, 0.06950277558644302, 0.05162913214007858, 0.024834413488861173, 0.09172447302262299, 0.031082398927537724, 0.03551096851879265, 0.10492307221284136, 0.06983771425439045, 0.14547338301781565, 0.047969345905585214, 0.1740003819577396, 0.09329278691438958, 0.17158072820166126, 0.1059010521566961, 0.2892184822121635, 0.15437275782460347, 4.945034701377153, 17.565287053585052, 50.248670876026154, 67.84724414348602, 74.6703328192234, 83.02774876356125, 82.99504771828651, 81.35175749659538, 87.00514733791351, 69.67781111598015, 72.00656175613403, 69.1570034623146, 70.31195148825645, 58.542147651314735, 43.629939034581184, 60.55327333509922, 53.311454728245735, 31.27901718020439, 73.09792399406433, 41.34359411895275, 28.943816386163235, 56.84853293001652, 34.77452181279659, 29.838732965290546, 35.19591920077801, 29.29280485957861, 36.320647448301315, 23.54147717356682, 38.29746477305889, 33.38523656129837, 34.3621451407671, 31.252488903701305, 23.761023692786694, 13.910581413656473, 46.366985365748405, 79.48798790574074, 47.014121040701866, 45.310341864824295, 28.719419427216053, 32.2276096791029, 37.537741139531136, 47.87234678864479, 55.56360527873039, 62.4963104724884, 60.412825271487236, 61.06373034417629, 62.398081943392754, 59.79121282696724, 67.10141256451607, 45.93886613845825, 27.370501309633255, 13.047715164721012, 2.20845693256706, 0.2668918005656451, 0.2982998761581257, 0.03722204564837739, 0.18098978034686297, 0.09846790882875212, 0.052491043898044154, 0.028496639533841517, 0.037418874344439246, 0.04378732519398909, 0.04939097801980097, 0.03429386859352235, 0.022488900285679847, 0.04108712477318477, 0.028677517620963044, 0.09481955537921749, 0.054147881164681166, 0.0553768814279465, 0.0443250186071964, 0.01511977276095422, 0.02239537483546883, 0.03497705634799786, 0.039310983556788415, 0.030871706912876107, 0.04998900432838127, 0.05365332508517895, 0.028447715303627774, 0.04157682720688172, 0.01984665788768325, 0.04870696648140438, 0.05121771515405271, 0.02778172867692774, 0.029653402853000443, 0.031148416674113832, 0.02253636619570898, 0.06080269340600353, 0.03822500628302805, 0.10580910748103634, 0.025809064900386147, 0.012378810806694673, 0.007311647259484744, 0.042336211263318546, 0.033232118730666116, 0.03981800029578153, 0.015594940232404042, 0.03197523226845078, 0.05046197504270822, 0.025834594780462794, 0.02213906485849293, 0.06460563250584528, 0.037045796707388945, 0.03677847882499918, 0.042591395031195134, 0.06468730585766025, 0.031241752876667306, 0.016939774905040395, 0.05917554204643238, 0.033564582336111926, 0.015619568403053563, 0.12650871940422803, 0.19623135623987764, 0.1853957329876721, 0.10514061796129681, 0.12719309830572456, 0.11837282901979052, 0.1574405885185115, 0.12131082097766921, 0.08261494425823912, 0.12070718774339184, 0.09527466259896755, 0.18678892229218036, 0.13698726572329178, 0.16053953004302457, 0.1463437292841263, 0.22786017623730004, 0.11724579613655806, 0.12389876414090395, 0.1522122768801637, 0.1231890483177267, 0.15287399059161544, 0.17245833267224953, 0.16173207230167463, 0.13717686961172149, 0.1575477101141587, 0.09001549988170154, 0.10880145433475263, 0.131113359821029, 0.12694949575234205, 0.17523118935059756, 0.14252952067181468, 0.13606198568595573, 0.1352553305332549, 0.13899704616051167, 0.09761642053490505, 0.10800553805893287, 0.11326876032399014, 0.14706825837492943, 0.14807939005549997, 0.15412587497849017, 0.1303933429880999, 0.11411982559366152, 0.07451438010320999, 0.10581324124359526, 0.1403573583229445, 0.237941762607079, 0.10644529131241143, 0.1731935635325499, 0.12014125561108813, 0.23657692334381863, 0.2604735887143761, 0.14974248362705112, 0.2225016473676078, 0.14182504441123456, 0.24217909929575399, 0.18146163783967495, 0.14940525172278285, 0.163444162462838, 0.17284016765188426, 0.25186381477396935, 0.12033922350383364, 0.3749805927509442, 0.1313604207825847, 0.5558403488248587, 0.10972564341500401, 2.6552165346220136, 17.505054585635662, 51.824423521757126, 76.83506906032562, 88.3890862762928, 93.01210060715675, 95.55085837841034, 92.4372598528862, 97.92566254734993, 83.2758754491806, 105.30950993299484, 102.74647906422615, 100.7111182808876, 95.38019433617592, 90.80317273736, 90.89581176638603, 95.38934424519539, 61.943238750100136, 96.9989986717701, 63.73905658721924, 93.07434886693954, 98.9828722178936, 74.65751230716705, 63.593892976641655, 63.33723574876785, 63.3691768348217, 63.28391321003437, 43.88937771320343, 51.99557013809681, 37.39627853035927, 42.98709332942963, 47.77180798351765, 53.7721724063158, 55.73610082268715, 62.742548659443855, 89.06444683670998, 64.51098516583443, 66.11558586359024, 68.55015322566032, 86.31283208727837, 81.06610402464867, 82.95114487409592, 82.22423627972603, 85.95839470624924, 82.88069665431976, 81.64466097950935, 73.20589140057564, 67.90857285261154, 77.31678441166878, 57.03766018152237, 37.52654314041138, 16.775102354586124, 2.865609582513571, 0.18853243498597294, 0.5985395482275635, 0.10520084324525669, 0.32883619540371, 0.2173739264253527, 0.3081823739921674, 0.2524376136716455, 0.3478146926499903, 0.20004835532745346, 0.19076793221756816, 0.155174084356986, 0.20119335560593754, 0.1479780868976377, 0.13044162711594254, 0.24867341096978635, 0.1281842662137933, 0.17289262264966965, 0.11205717455595732, 0.07719885441474617, 0.06943885440705344, 0.21532850805670023, 0.08525306402589194, 0.13666158163687214, 0.11564672764507122, 0.17734457360347733, 0.11375218789908104, 0.10904286013101228, 0.2192366577219218, 0.10721112092141993, 0.14762381528271362, 0.15583924163365737, 0.13118025701260194, 0.1424942835001275, 0.09350307445856743, 0.1732910520513542, 0.13741349597694352, 0.22121461486676708, 0.1388048447552137, 0.09024399230838753, 0.050500024954089895, 0.11440620553912595, 0.19696614181157202, 0.12077510909875855, 0.13558729318901896, 0.15001341205788776, 0.17672857618890703, 0.16608107252977788, 0.08922336113755591, 0.14908538607414812, 0.10415252254460938, 0.1071738354221452, 0.1616189838387072, 0.15836013917578384, 0.10677365455194376, 0.11178088781889528, 0.16756799508584663, 0.1040739736345131, 0.15613948489772156], [0.03919114526070189, 0.08785058089415543, 0.04661147540900856, 0.07960393981193192, 0.02680381923710229, 0.029144250584067777, 0.029293811894604005, 0.04073634496307932, 0.019132858396915253, 0.04853967526287306, 0.014529739382851403, 0.033509084532852285, 0.038783995623816736, 0.030758946850255597, 0.11772460013162345, 0.023394303752866108, 0.05393438754254021, 0.048411357929580845, 0.008643383953312878, 0.004484271021283348, 0.04007823808933608, 0.016073541992227547, 0.06791963358409703, 0.006215176017576596, 0.04188668499409687, 0.007253980993482401, 0.01741821524774423, 0.02666820102604106, 0.005290135322866263, 0.015350539870269131, 0.02998591840878362, 0.014117719401838258, 0.04180606178124435, 0.08114350290270522, 0.02605111450975528, 0.05103147319459822, 0.08831135812215507, 0.03158629493555054, 0.04111553047550842, 0.04736519687867258, 0.011972644515481079, 0.01727949671476381, 0.00937331402383279, 0.06076483645301778, 0.09479234082391486, 0.05593744783254806, 0.056925643439171836, 0.01160838173746015, 0.06884604168590158, 0.02136024209903553, 0.02786033695883816, 0.038619350161752664, 0.06317843057331629, 0.05112971870403271, 0.042517744295764714, 0.07320946184336208, 0.0552825989871053, 0.04312270968512166, 0.031650438759243116, 0.08061162050580606, 0.051049414614681154, 0.11842715422972105, 0.09073386172531173, 0.25154715520329773, 0.2649585949257016, 0.04776332942128647, 0.31574818363878876, 0.38912821328267455, 0.2748241421068087, 3.0681672133505344, 4.63594788685441, 9.911924879997969, 20.757763646543026, 28.436146527528763, 48.73490050435066, 55.973432287573814, 60.93361772596836, 55.76423071324825, 63.19795802235603, 73.80343973636627, 71.25058472156525, 66.36664599180222, 70.26247054338455, 63.49310338497162, 64.65101525187492, 59.88804683089256, 64.84960779547691, 72.55984246730804, 83.2627585530281, 81.65634155273438, 83.89056846499443, 78.49312528967857, 79.9877218902111, 82.97492399811745, 87.33267456293106, 88.53642717003822, 93.56801077723503, 89.11398857831955, 82.50200137495995, 75.11145114898682, 71.52746066451073, 76.72793760895729, 81.29073277115822, 80.37637263536453, 83.49012315273285, 83.3842684328556, 79.70032811164856, 65.05807220935822, 31.03036232292652, 12.410692647099495, 6.470158863812685, 5.86111044511199, 4.790608137845993, 3.1099526211619377, 0.3418256499571726, 0.1444873953005299, 0.16943917202297598, 0.027984414773527533, 0.04081525381479878, 0.20964049530448392, 0.026353426510468125, 0.005900385731365532, 0.03558922056981828, 0.07627983068232425, 0.08060323423705995, 0.06318234169157222, 0.06286567469942383, 0.064489456708543, 0.08168403132003732, 0.017651687485340517, 0.019733825465664268, 0.07992137863766402, 0.08708716326509602, 0.026434597057232168, 0.04404803054057993, 0.03878399933455512, 0.08938295257394202, 0.0626649682817515, 0.06986276915995404, 0.09609100277884863, 0.022431986835727002, 0.02427519779303111, 0.07618295072461478, 0.08517467096680775, 0.04037695995066315, 0.0031047441916598473, 0.03160027328704018, 0.11755103405448608, 0.01972633534023771, 0.034309260736336, 0.02119672099070158, 0.11516578626469709, 0.02564761623943923, 0.0701318793289829, 0.02903874687035568, 0.06970403119339608, 0.029658213825314306, 0.04311197451897897, 0.004292507019272307, 0.11591194153879769, 0.006368271806422854, 0.0442221717821667, 0.01157483851784491, 0.03997604064352345, 0.037159452913329005, 0.03485658722638618, 0.0712898894562386, 0.01699697593721794, 0.0595751959917834, 0.020914999877277296, 0.06374336080625653, 0.03158987579809036, 0.022567744199477602, 0.01626259854674572, 0.07908126746769994, 0.09623897218261845, 0.053670075358240865, 0.052833366935374215, 0.024743517096794676, 0.09864544539595954, 0.010162153921555728, 0.04591171549691353, 0.0375736752175726, 0.102176094223978, 0.016440083163615782, 0.052244031176087447, 0.03106551135715563, 0.05413131271780003, 0.09829082497162744, 0.06492275220807642, 0.015992234148143325, 0.03352181978698354, 0.022957284527365118, 0.0386700462695444, 0.007635435158590553, 0.09370116851641797, 0.06116848315286916, 0.031135748213273473, 0.01608522710739635, 0.016281593816529494, 0.08064773341175169, 0.0744134777050931, 0.05794134674943052, 0.08364343477296643, 0.06836999105871655, 0.0225079660594929, 0.0688080140389502, 0.08015355953830294, 0.015469348436454311, 0.07918397328467108, 0.05916049500228837, 0.03989711694885045, 0.07021493307547644, 0.025455205177422613, 0.014977534592617303, 0.042942082072841004, 0.05273669106827583, 0.04031339500215836, 0.04152757828705944, 0.09065254460438155, 0.05944266697042622, 0.0038038964703446254, 0.04944699161569588, 0.035028015918214805, 0.0664615212008357, 0.029509958694688976, 0.09064481142559089, 0.09641308002755977, 0.08450314606307074, 0.05754916252044495, 0.04485394725634251, 0.05972845319774933, 0.023058530168782454, 0.14216926734661683, 0.019137003291689325, 0.13038430362939835, 0.0026575723859423306, 0.17714158137096092, 0.08230653736973181, 0.29899143904913217, 0.04840463778236881, 0.19468657585093752, 0.1842737541301176, 0.5363470385782421, 1.4101894735358655, 6.4020460937172174, 10.192247238010168, 20.19004561007023, 35.032550767064095, 45.056507885456085, 67.45281770825386, 77.47845813632011, 81.85073912143707, 78.0038483440876, 83.94770219922066, 88.59906300902367, 72.97076001763344, 75.13058692216873, 70.63574731349945, 60.811750665307045, 62.49105155467987, 57.459958121180534, 70.85753381252289, 74.97385293245316, 70.45085683465004, 69.86484467983246, 75.4671348631382, 63.06328184902668, 64.12359595298767, 62.99325540661812, 57.43770271539688, 66.96087330579758, 71.84209138154984, 67.55032047629356, 70.79636469483376, 74.57157611846924, 77.77205318212509, 81.33028864860535, 78.85211482644081, 90.37112832069397, 95.86625665426254, 98.13167229294777, 95.25414749979973, 80.85438698530197, 54.90977816283703, 33.82244870066643, 14.194586724042892, 8.763615097850561, 7.339152283966541, 6.59498549066484, 1.2676008185371757, 0.3119605587562546, 0.3494414209853858, 0.03992879552242812, 0.06369216003804468, 0.20517628407105803, 0.12287710880627856, 0.06644271517870948, 0.028106600111641455, 0.03650966551504098, 0.06104683030571323, 0.06295740415225737, 0.06294227918260731, 0.0454002755577676, 0.05376967528718524, 0.050399875835864805, 0.03384454641491175, 0.01594925266545033, 0.0784232941805385, 0.04843250171688851, 0.05718957712815609, 0.036751557418028824, 0.04060764913447201, 0.018041192561213393, 0.022326011858240236, 0.017090326982724946, 0.08574571649660356, 0.029227128070488106, 0.08946722344262525, 0.07053585257381201, 0.03258823140640743, 0.008987148612504825, 0.06474553476436995, 0.07206906288047321, 0.021309286239556968, 0.01983860187465325, 0.03453565288509708, 0.0440168083878234, 0.05406734700954985, 0.018787718909152318, 0.025160429686366115, 0.02372884537180653, 0.06183112825965509, 0.17095714603783563, 0.03590134932892397, 0.07798443257343024, 0.04642495885491371, 0.021107770880917087, 0.07560699217719957, 0.05139937064086553, 0.02593640259874519, 0.04180057359917555, 0.01162048338301247, 0.06228581987670623, 0.06383321262546815, 0.012845076216763118, 0.037923865020275116, 0.01794413819879992, 0.022258359531406313, 0.08524432152626105, 0.01617689533304656, 0.061557520675705746, 0.12600005138665438, 0.22234641975956038, 0.12026310883811675, 0.16080002387752756, 0.08932962184189819, 0.1277482247678563, 0.10036894978838973, 0.17936348245711997, 0.1405543985310942, 0.15966153965564445, 0.10990242299158126, 0.17302401247434318, 0.231894921453204, 0.1948066256591119, 0.19179188820999116, 0.13327232678420842, 0.21810014761285856, 0.14432039723033085, 0.06891635275678709, 0.18428648938424885, 0.17475128697697073, 0.11537606638739817, 0.13144247262971476, 0.09945176658220589, 0.14352300408063456, 0.15527488285442814, 0.10448234781506471, 0.1804745220579207, 0.1886129134800285, 0.08844580559525639, 0.15071966947289184, 0.1519403391284868, 0.2334797036019154, 0.23465870908694342, 0.08112883064313792, 0.1269352762028575, 0.2740481524961069, 0.07782326778396964, 0.09433671410079114, 0.09605941697373055, 0.08901508481358178, 0.17863571760244668, 0.08595702078309841, 0.182094867923297, 0.17274760699365288, 0.1298393149045296, 0.07824934218660928, 0.19134334899717942, 0.19543599657481536, 0.1702569890767336, 0.21670692862244323, 0.14414476056117564, 0.23058011778630316, 0.08737306081457064, 0.2175493404502049, 0.18092510959831998, 0.10933255747659132, 0.20247516338713467, 0.19192689971532673, 0.19305199559312314, 0.09954779307008721, 0.45646766549907625, 0.1261368885752745, 0.4822705074911937, 0.314136179513298, 0.1682544668437913, 0.6712437781970948, 0.554429852636531, 0.41719496191944927, 3.1294617243111134, 7.075589876621962, 17.211812920868397, 33.83106283843517, 46.538310572505, 71.66080310940742, 78.81686791777611, 86.04585841298103, 86.785359531641, 95.93890115618706, 101.48612469434738, 95.12510642409325, 94.00821715593338, 93.76851081848145, 83.97794097661972, 87.21320897340775, 77.71204680204391, 90.06212890148163, 97.76428520679474, 104.1754911839962, 104.4781145453453, 105.96520274877548, 98.24400186538696, 104.82917010784149, 105.12380629777908, 107.45850741863251, 116.76616877317429, 118.67692664265633, 114.48625311255455, 108.68642672896385, 98.97891283035278, 91.68885201215744, 100.05803972482681, 107.10411563515663, 113.36332216858864, 110.8083088696003, 109.4868765771389, 99.50606614351273, 88.97792547941208, 62.435050159692764, 41.581069976091385, 19.028651230037212, 11.140350513160229, 10.859619677066803, 8.75373087823391, 1.1005601193755865, 0.23853119113482535, 0.5731895053759217, 0.11463762944913469, 0.2286812142119743, 0.5301647703163326, 0.12690741597907618, 0.215632165200077, 0.09471908342675306, 0.25151019624900073, 0.1791043096454814, 0.21571849181782454, 0.1477866424829699, 0.2809394389623776, 0.14072084741201252, 0.16248521860688925, 0.1655694210785441, 0.26738253829535097, 0.16483411600347608, 0.21939703583484516, 0.12706875888397917, 0.09740881956531666, 0.1656079979147762, 0.14285493758507073, 0.10940489461063407, 0.13777415006188676, 0.14219222939573228, 0.13637002150062472, 0.1824281961307861, 0.2646025421563536, 0.1376545603852719, 0.12241651711519808, 0.24290686415042728, 0.17879899009130895, 0.09386344652739353, 0.1715044502634555, 0.1894290532800369, 0.2500841149594635, 0.15557441365672275, 0.10757404597825371, 0.12240741838468239, 0.113884898746619, 0.19357663462869823, 0.2663567120907828, 0.10853333122213371, 0.18141216627554968, 0.14127251546597108, 0.15147416648687795, 0.16431145108072087, 0.07911021122708917, 0.14344819559482858, 0.2598123054485768, 0.1385564627707936, 0.11435635547968559, 0.16965725953923538, 0.09131674451055005, 0.23598746513016522, 0.10823376331245527, 0.1279958794475533, 0.27019557484891266, 0.09542862113448791, 0.16759683494456112], [0.07103010808350518, 0.05537687771720812, 0.045078610201017, 0.07315174501854926, 0.02306170285010012, 0.09769874697667547, 0.03796684650296811, 0.03815219046373386, 0.02357925066462485, 0.013098964936943958, 0.06666881788987666, 0.016517283220309764, 0.04610964628227521, 0.05614504138065968, 0.031125131790759042, 0.045832643372705206, 0.04178316281468142, 0.06184392659633886, 0.0482604941498721, 0.04753582034027204, 0.0773961321101524, 0.019742898221011274, 0.005826675160278683, 0.040187790218624286, 0.023428451822837815, 0.06656870958977379, 0.055386295571224764, 0.032169912446988747, 0.030117818459984846, 0.026191092838416807, 0.07254210038809106, 0.0383353673532838, 0.058875098402495496, 0.030590915339416824, 0.026672271706047468, 0.020392366495798342, 0.0195482198978425, 0.0405243912973674, 0.06198807022883557, 0.03675130137708038, 0.05295648552419152, 0.019295813617645763, 0.03942001989344135, 0.04922109670587815, 0.012490757289924659, 0.08006907344679348, 0.025761986762518063, 0.01946989919815678, 0.04484035111090634, 0.026086236648552585, 0.055875036923680454, 0.030214256839826703, 0.06498725968413055, 0.12984520755708218, 0.038891132062417455, 0.05206993817409966, 0.06287138923653401, 0.047950617808965035, 0.03566312734619714, 0.11139527530758642, 0.027018385262636002, 0.12215948911034502, 0.09672739441157319, 0.09001383747090586, 0.18052515137242153, 0.04183970333542675, 0.16504294151673093, 0.22292579960776493, 0.08041602006414905, 0.15973585832398385, 0.33508608816191554, 0.6916035013273358, 0.9427276323549449, 0.6517688138410449, 0.34508724056649953, 1.153249042108655, 1.3514228956773877, 0.16759582562372088, 6.292847078293562, 18.721473813056946, 26.973401717841625, 36.055254489183426, 42.01590724289417, 47.85183548927307, 45.72387367486954, 52.13494285941124, 55.32466270029545, 53.33058290183544, 46.03244371712208, 49.871381521224976, 48.052840903401375, 60.30133165419102, 49.55629862844944, 46.92781627178192, 50.64305931329727, 40.90909123420715, 44.374695271253586, 29.43674873560667, 27.755751237273216, 22.339379377663136, 16.418917067348957, 35.82072727382183, 28.03209900856018, 18.877926617860794, 17.158621475100517, 11.814224403351545, 9.762778133153915, 5.085279475897551, 0.36565589311067015, 0.21606547554256395, 0.08472964953398332, 0.29313815000932664, 0.2499117882689461, 0.3653153363848105, 0.08488840976497158, 0.05730235388909932, 0.24564233142882586, 0.08384756991290487, 0.04653201736800838, 0.043952237829216756, 0.013894613111915532, 0.06100275415519718, 0.09999284418881871, 0.055469876242568716, 0.019765142242249567, 0.020510423637460917, 0.0517597278667381, 0.04699205615906976, 0.03467184069450013, 0.005551766962526017, 0.02404281280178111, 0.04310533971874975, 0.02393757997197099, 0.03611205247580074, 0.04418207725393586, 0.029616807551064994, 0.04620090818207245, 0.043479641899466515, 0.05996862702886574, 0.05925472920353059, 0.029445351028698497, 0.08124601576128043, 0.1207523251650855, 0.03907516242179554, 0.005298144023981877, 0.04948910849634558, 0.021296005506883375, 0.06712480826536193, 0.020181346080789808, 0.04779139002494048, 0.03579567121050786, 0.05141542700584978, 0.04376992554171011, 0.03896728012477979, 0.036856723454548046, 0.004453460296645062, 0.03444411267992109, 0.0559427950065583, 0.03855752926028799, 0.031105685666261707, 0.02410228109511081, 0.04291584715247154, 0.05077251931652427, 0.02263924827275332, 0.042520497663645074, 0.027843521747854538, 0.058178266262984835, 0.008370805171580287, 0.05912197011639364, 0.04174817797320429, 0.0358439553383505, 0.023839892928663176, 0.03478534476016648, 0.06378565580234863, 0.05372882376832422, 0.08075327423284762, 0.055274004917009734, 0.03462861801381223, 0.0552789921493968, 0.02000951106310822, 0.045018837627139874, 0.04905076639261097, 0.044622204222832806, 0.06935340352356434, 0.026876317788264714, 0.019488170873955823, 0.03269893386459444, 0.016732578405935783, 0.015879544589552097, 0.01268193267605966, 0.03677388122014236, 0.04224187687213998, 0.0022968907023823704, 0.025981553008023184, 0.07972273539053276, 0.008777834209467983, 0.033921510839718394, 0.02268244126753416, 0.05720911416574381, 0.043151516147190705, 0.06647563684964553, 0.0037750999808849883, 0.007922723307274282, 0.015842901048017666, 0.04779321941896342, 0.024948437057901174, 0.05496997298905626, 0.016784725412435364, 0.05308420913934242, 0.021442479483084753, 0.046103905769996345, 0.020996853199903853, 0.0603245387901552, 0.013281157553137746, 0.04124174010939896, 0.01728709445160348, 0.053886288951616734, 0.028930834887432866, 0.014692343011120101, 0.0810849029221572, 0.01170746401840006, 0.007053018998703919, 0.04019252512080129, 0.03185862602549605, 0.015015066855994519, 0.01867972157924669, 0.10406730914837681, 0.04704827013483737, 0.05743974026700016, 0.02271355395350838, 0.02011804645007942, 0.061513073451351374, 0.017108158936025575, 0.06979285142733715, 0.06344444598653354, 0.12339366585365497, 0.03556580952135846, 0.11007790380972438, 0.05646638761390932, 0.15557383478153497, 0.021895005884289276, 0.10253375745378435, 0.18855967180570588, 0.009465563907724572, 0.21874237252632156, 0.33066256146412343, 0.3663286054506898, 0.5066674842964858, 0.1509463955881074, 0.5629717349074781, 1.0639318660832942, 3.6596885975450277, 6.702254209667444, 8.03489875048399, 21.11642450094223, 36.929082199931145, 51.880067735910416, 55.75300991535187, 64.70284447073936, 75.70707678794861, 66.3914130628109, 77.93757990002632, 77.31655642390251, 76.01079449057579, 73.2381820678711, 78.73283922672272, 75.0378642976284, 86.60190537571907, 74.89599511027336, 75.53518921136856, 80.25964289903641, 70.44951930642128, 76.13049566745758, 66.24414816498756, 59.84188690781593, 60.79280488193035, 55.300545394420624, 61.32876992225647, 54.18661616742611, 37.42170676589012, 33.520942479372025, 26.07108313590288, 19.3732775375247, 12.958172969520092, 3.184609115123749, 0.56883962941356, 0.3823516925331205, 0.638320385478437, 0.32760948466602713, 0.24289022519951686, 0.08215332840336487, 0.17969125939998776, 0.10706528890295886, 0.06785518547985703, 0.023761997108522337, 0.13373135996516794, 0.008079332237684866, 0.0890429005085025, 0.04884468682575971, 0.05878013318579178, 0.006257850436668377, 0.015444665532413637, 0.056792201576172374, 0.052912906612618826, 0.026554014184512198, 0.005264932915451936, 0.01821068610297516, 0.025347588198201265, 0.03197925470885821, 0.044395901131792925, 0.020451966520340648, 0.04713502719823737, 0.01721849217574345, 0.03240404519601725, 0.04149043750658166, 0.050125604029744864, 0.005944571348663885, 0.022423047666961793, 0.08631030534161255, 0.053342005267040804, 0.03506700093566906, 0.06601845161640085, 0.01936655884492211, 0.039282099169213325, 0.03217360092094168, 0.016356450541934464, 0.03976108127972111, 0.05632281543512363, 0.06116825679782778, 0.07087493984727189, 0.027052622390328906, 0.041253655290347524, 0.06574321130756289, 0.007488242226827424, 0.028745659765263554, 0.01983821224712301, 0.041796298828558065, 0.02098718672641553, 0.06473132263636217, 0.05516795201401692, 0.01740006231557345, 0.034832571327569894, 0.04168789702816866, 0.05097444656712469, 0.03308188577648252, 0.05032647000916768, 0.06175931805046275, 0.022051617597753648, 0.04004386923043057, 0.04977138807589654, 0.026193168996542227, 0.011947716702707112, 0.12209813576191664, 0.10692678930354305, 0.20191368414089084, 0.21401696983957663, 0.17671361449174583, 0.2155522210523486, 0.09677341498900205, 0.11110169652965851, 0.09882752390694804, 0.20295435329899192, 0.16863886965438724, 0.06294738515862264, 0.110446617618436, 0.20411384030012414, 0.11232856311835349, 0.15562709129881114, 0.16045758209656924, 0.11137298861285672, 0.138585718232207, 0.10087464179378003, 0.11602373124333099, 0.09295927316998132, 0.09967616235371679, 0.102496078616241, 0.10775219852803275, 0.14805537415668368, 0.12946490140166134, 0.1574113775859587, 0.2637107181362808, 0.11495190672576427, 0.12954245583387092, 0.12987548718228936, 0.1545492999139242, 0.15449999162228778, 0.11615418596193194, 0.09871657282928936, 0.11001618680893444, 0.11482885121949948, 0.13758665387285873, 0.1609131568693556, 0.1759353093802929, 0.05497055928572081, 0.13197742751799524, 0.09556823395541869, 0.05432516540167853, 0.17663234932115301, 0.1720915929763578, 0.1226634593331255, 0.10172512076678686, 0.11479430424515158, 0.14463782863458619, 0.1413737889379263, 0.17356830358039588, 0.14894951367750764, 0.1762890614918433, 0.11986057535978034, 0.10678230799385346, 0.16912868712097406, 0.15153925283811986, 0.24653170636156574, 0.1385140119236894, 0.1979700301308185, 0.17184877709951252, 0.34192491963040084, 0.3687798004830256, 0.2058639284223318, 0.2952489070594311, 0.29780275595840067, 0.2366121011436917, 0.3178964339895174, 0.792251966195181, 0.7713279139716178, 1.4321361458860338, 0.7454596145544201, 0.4768010869156569, 1.9246866158209741, 4.195679286494851, 6.392282517626882, 20.04427593201399, 33.0522034317255, 46.29612296819687, 56.01636238396168, 68.36476117372513, 80.36920621991158, 77.4530602991581, 93.54143500328064, 87.11479425430298, 86.67879045009613, 76.30300641059875, 85.5844035744667, 80.45062825083733, 91.9831994175911, 77.76252329349518, 77.93966978788376, 80.2820996940136, 68.63602861762047, 73.60502198338509, 64.36311230063438, 65.67909568548203, 61.75131864845753, 58.17788399755955, 62.73061349987984, 49.17991362512112, 33.14068168401718, 25.974017344415188, 19.91798210889101, 12.808404006063938, 8.706934489309788, 2.4399034632369876, 0.4286295280326158, 0.1848858775338158, 0.6652245449367911, 0.6413843866903335, 0.7513817748986185, 0.24043334531597793, 0.3452042327262461, 0.4319916944950819, 0.24015245726332068, 0.14851265586912632, 0.2572139276890084, 0.1750098809134215, 0.4363724438007921, 0.15697591501520947, 0.24597119190730155, 0.07960514951264486, 0.2598461473826319, 0.129450102976989, 0.08959753715316765, 0.16627783072181046, 0.16468573099700734, 0.16030196857172996, 0.06549422076204792, 0.12959068058989942, 0.11514881334733218, 0.1379081077175215, 0.20625659875804558, 0.11979637216427363, 0.1117292491835542, 0.14689839561469853, 0.13887868844904006, 0.14069031545659527, 0.12765658437274396, 0.18680662993574515, 0.12270411418285221, 0.09835269040195271, 0.10762853446067311, 0.10715183074353263, 0.25079236133024096, 0.1250604330562055, 0.12649718642933294, 0.15381682984298095, 0.3312749817268923, 0.18874422908993438, 0.1871923537692055, 0.19566287111956626, 0.16240554163232446, 0.17834973841672763, 0.15813753940165043, 0.1602246070979163, 0.09720064714201726, 0.15708232414908707, 0.12060958048095927, 0.14768133172765374, 0.1116972255113069, 0.2161073178285733, 0.18861226039007306, 0.28456842235755175, 0.12927592091728002, 0.14004519616719335, 0.16990013478789479, 0.21131881774635985, 0.10611171819618903, 0.11286728811683133, 0.09164814313407987, 0.191395893052686, 0.13892777409637347], [0.034802963346010074, 0.042171832974418066, 0.040327447568415664, 0.048226459257421084, 0.08307163225254044, 0.04748126506456174, 0.03585169593861792, 0.021439770644064993, 0.048489417022210546, 0.039626244179089554, 0.06220999835932162, 0.049751587575883605, 0.03920264483895153, 0.06939120852621272, 0.01793946823454462, 0.0320520259992918, 0.03477127735095564, 0.07064618024742231, 0.02395535626419587, 0.0378705973707838, 0.0688080363033805, 0.04330907038820442, 0.03498786572890822, 0.0829009160224814, 0.032512001707800664, 0.0601919466862455, 0.014771828882658156, 0.039446718656108715, 0.08979598002042621, 0.04065838234964758, 0.04352825999376364, 0.029759554090560414, 0.0372103790869005, 0.017897759535117075, 0.03429097792832181, 0.04659924852603581, 0.07631696775206365, 0.028187332791276276, 0.0324640997860115, 0.04932007323077414, 0.03828877161140554, 0.04270660974725615, 0.018493019488232676, 0.07001629724982195, 0.024421196794719435, 0.01922981256939238, 0.010714865620684577, 0.025477586495981086, 0.012684615539910737, 0.056550691879238, 0.041013192021637224, 0.05773921169748064, 0.055579903346369974, 0.07494993173168041, 0.02147910447092727, 0.07525262408307754, 0.016787228305474855, 0.007444571010637446, 0.021546196476265322, 0.017900121420098003, 0.07189591982751153, 0.08984036045148969, 0.05042691969720181, 0.05788401955214795, 0.12173665047157556, 0.014346585685416358, 0.21186800702707842, 0.2648058906197548, 0.21141917095519602, 0.06463951896876097, 0.05485055400640704, 0.13758279470494017, 0.15224509465042502, 0.13509210257325321, 0.058523205370875075, 0.15694394329329953, 0.14188863162416965, 0.2575210283976048, 0.35852655535563827, 0.6489030551165342, 0.06554389270604588, 0.1380846943357028, 0.026356396956543904, 0.1102901654667221, 0.04029037358122878, 0.29915931285358965, 0.5000911059323698, 1.4748018002137542, 1.194507465697825, 1.8814273620955646, 1.0591172869317234, 1.6068983869627118, 1.637695615645498, 0.8982795767951757, 1.767724638339132, 1.3855640636757016, 1.0045412904582918, 0.7799818308558315, 0.30795308004599065, 0.4034817055799067, 1.0891344887204468, 0.1572329059126787, 0.20684899587649852, 0.2276247669942677, 0.4105180670740083, 0.3795647498918697, 0.45872136019170284, 0.2776158641790971, 0.07705696320044808, 0.038968489825492725, 0.14051105710677803, 0.18827669089660048, 0.19623298896476626, 0.18114278151188046, 0.0918282920611091, 0.027903739610337652, 0.033939047789317556, 0.027317363164911512, 0.07481693144654855, 0.061702733000856824, 0.050947981580975465, 0.0580692521907622, 0.06362306608934887, 0.016071413883764762, 0.12277249566977844, 0.04645783228625078, 0.024961465460364707, 0.03913330227078404, 0.042766801634570584, 0.03194029566657264, 0.06145043618744239, 0.022597769639105536, 0.08127682231133804, 0.03134613965812605, 0.042683926003519446, 0.06280495959799737, 0.1019391709996853, 0.017707975675875787, 0.07245601125760004, 0.058735240672831424, 0.09004739738884382, 0.07598886426421814, 0.008235627610702068, 0.02055510278296424, 0.02085527368762996, 0.005538855912163854, 0.05000648561690468, 0.02170763400499709, 0.0042319278236391256, 0.07011735549895093, 0.02875802765629487, 0.010131829767487943, 0.0429335622175131, 0.01705062393739354, 0.01419459198586992, 0.03968600191001315, 0.0030702628509970964, 0.042870739416684955, 0.02466342080879258, 0.010596984739095205, 0.022763821471016854, 0.039887561797513627, 0.01997289164137328, 0.07467554489267059, 0.03171005919284653, 0.05564858169236686, 0.05220496823312715, 0.04606264606991317, 0.009566064618411474, 0.039733143130433746, 0.030427948986471165, 0.03226687404094264, 0.027521722804522142, 0.06349349452648312, 0.03746978196431883, 0.061954120683367364, 0.04979057630407624, 0.010001451119023841, 0.06011130863043945, 0.035084890405414626, 0.02905873847339535, 0.023830790487409104, 0.01424989961378742, 0.05358039794373326, 0.007546640899818158, 0.012771973742928822, 0.0024790888846837333, 0.037697918160120025, 0.06864209950435907, 0.04147110827034339, 0.012787375162588432, 0.018784741041599773, 0.015698122879257426, 0.04213170504954178, 0.07477450286387466, 0.014110014053585473, 0.01216577175000566, 0.04948945359501522, 0.021132846195541788, 0.0645006557169836, 0.0404735096526565, 0.01665043193497695, 0.04727193489088677, 0.04795193512109108, 0.04234397041727789, 0.0105417003032926, 0.049743958297767676, 0.01821424470108468, 0.0057934487449529115, 0.04067740359460004, 0.029956212092656642, 0.05857066571479663, 0.06497222377220169, 0.01782391955202911, 0.06459034426370636, 0.04607862079865299, 0.052700949236168526, 0.035874075401807204, 0.03953635154175572, 0.03360044662258588, 0.04380598278657999, 0.01625512697501108, 0.06331993587082252, 0.024628781065985095, 0.02378208148002159, 0.01661593505559722, 0.016822686266095843, 0.06918947052326985, 0.04881425506027881, 0.02629898070154013, 0.052392341967788525, 0.05380611473810859, 0.11271176364971325, 0.04314428391808178, 0.03457715378317516, 0.08632701850729063, 0.04620813298970461, 0.08484983292873949, 0.024557733413530514, 0.15461802278878167, 0.04498517751926556, 0.06057125094230287, 0.26629695435985923, 0.0650756197865121, 0.2743059449130669, 0.0600129221129464, 0.07582960679428652, 0.07069884304655716, 0.040071573603199795, 0.15655339549994096, 0.16833834437420592, 0.3007340314798057, 0.2935803809668869, 0.5194147909060121, 0.49750148551538587, 0.3048940363805741, 0.30835924262646586, 0.7419128611218184, 0.3838537400588393, 1.553094342816621, 3.1713903369382024, 5.121987881138921, 4.916807916015387, 6.230443976819515, 5.193918971344829, 5.376448351889849, 6.179959885776043, 7.453272985294461, 6.83630864135921, 3.770075524225831, 5.05721845664084, 4.037036374211311, 4.492659475654364, 2.7816381258890033, 3.523487993516028, 1.1345842061564326, 1.85268962290138, 0.8282564592082053, 0.47428384074009955, 0.5065145425032824, 0.3054155583959073, 0.14374456484802067, 0.19915981160011142, 0.4558433115016669, 0.145130347518716, 0.05878483098058496, 0.20497433084528893, 0.3267396579030901, 0.14693762554088607, 0.15359243407147005, 0.12441073471563868, 0.11883986997418106, 0.024431045094388537, 0.015619256701029371, 0.0730983549146913, 0.0669787016522605, 0.03991011566540692, 0.06866585565148853, 0.08132498769555241, 0.012112180338590406, 0.06893394165672362, 0.05796682096843142, 0.005171147249711794, 0.0329581512050936, 0.06438013093429618, 0.05500839768501464, 0.03434577440202702, 0.007286392901733052, 0.09088626175071113, 0.01590819334523985, 0.02006117567361798, 0.06061496715119574, 0.06936861012945883, 0.021538374239753466, 0.05298415278957691, 0.08619846368674189, 0.01488808909925865, 0.054165414403541945, 0.006637231226704898, 0.052939093293389305, 0.01986637489608256, 0.018734252735157497, 0.07586350810015574, 0.026380832168797497, 0.006638330069108633, 0.06307151677901857, 0.029658211969945114, 0.030097344460955355, 0.011873602124978788, 0.02226246546342736, 0.021912323900323827, 0.016349476209143177, 0.0211181479608058, 0.05852720183611382, 0.018652282524271868, 0.09681550960522145, 0.032087192666949704, 0.029410349488898646, 0.008262153824034613, 0.024326244565600064, 0.04834030471101869, 0.05129298377141822, 0.06743746023857966, 0.010487635772733483, 0.04134087990678381, 0.020145730413787533, 0.0111937067231338, 0.021043367305537686, 0.00791023481724551, 0.050601929251570255, 0.05868503809324466, 0.0546164509432856, 0.10374736186349764, 0.07033008470898494, 0.14233678492018953, 0.17092938971472904, 0.18427863746182993, 0.13575855118688196, 0.17624438420170918, 0.12900938600068912, 0.080881554458756, 0.17049930029315874, 0.13591873634140939, 0.10763896905700676, 0.18306625017430633, 0.3686294116778299, 0.09632776273065247, 0.1587001615553163, 0.11872528979438357, 0.14891081809764728, 0.2304685433045961, 0.14478556055109948, 0.20740097563248128, 0.14434923708904535, 0.09440701032872312, 0.20419995911652222, 0.16380655317334458, 0.1431016720016487, 0.09605871193343773, 0.12978276325156912, 0.252941235085018, 0.17472817649831995, 0.12325325893471017, 0.09697561312350444, 0.128168354567606, 0.1423846386023797, 0.09973542284569703, 0.14560092851752415, 0.13539654639316723, 0.09001301368698478, 0.1351025520125404, 0.154136843921151, 0.15771533158840612, 0.26062843040563166, 0.09274211333831772, 0.21088800102006644, 0.15412073931656778, 0.10324378497898579, 0.12384822388412431, 0.0773277654661797, 0.11106301579275168, 0.13619392469990999, 0.2143858023919165, 0.16531890170881525, 0.1915680119418539, 0.19935941963922232, 0.26686828932724893, 0.15878577571129426, 0.13389843225013465, 0.15783455019118264, 0.11086217578849755, 0.1664375260588713, 0.22834493225673214, 0.17382535384967923, 0.15164022945100442, 0.3201484662713483, 0.1973290223395452, 0.13087757950415835, 0.38380368961952627, 0.48868198064155877, 0.5089602456428111, 0.1252180800656788, 0.20680728717707098, 0.30984632845502347, 0.43036000861320645, 0.35172079398762435, 0.3087793872691691, 0.23941137827932835, 0.32898444682359695, 0.5747695674654096, 0.710877135861665, 1.1663854122161865, 0.27480992255732417, 0.3062130999751389, 0.18455479061231017, 0.5088279652409256, 1.2086600437760353, 1.9517091033048928, 2.301390445791185, 3.2019886700436473, 3.1626439187675714, 2.9757321858778596, 4.056956330314279, 4.143325220793486, 4.493998428806663, 2.2334227804094553, 2.4263125425204635, 2.428929889574647, 2.6179768703877926, 2.170922546647489, 1.5805479884147644, 0.5079332913737744, 0.7993378734681755, 0.276920412434265, 0.22705368435708806, 0.3592707513598725, 0.5653274897485971, 0.7029615074861795, 0.6864531745668501, 0.7415948656853288, 0.2522271405905485, 0.17202824325067922, 0.2527648414252326, 0.3200048755388707, 0.4463195678545162, 0.33679929154459387, 0.1982376931118779, 0.1809426984982565, 0.2208707481622696, 0.1553854183293879, 0.13647752901306376, 0.29161971586290747, 0.1937855195137672, 0.4564310924615711, 0.21108008368173614, 0.1830034941667691, 0.25016527622938156, 0.11849477130454034, 0.104783986316761, 0.12838667957112193, 0.16483558545587584, 0.17650501162279397, 0.12571181607199833, 0.26176373823545873, 0.2151178865460679, 0.16445006942376494, 0.16032764688134193, 0.1275005255592987, 0.21859354223124683, 0.06907097922521643, 0.15999915747670457, 0.09597130178008229, 0.17158006026875228, 0.2229879322112538, 0.0948206389148254, 0.10114612683537416, 0.18519318604376167, 0.09951785483281128, 0.2650028862990439, 0.10080703956191428, 0.07761599335935898, 0.19000745349330828, 0.11969556624535471, 0.16434149321867153, 0.2579007705207914, 0.12262298259884119, 0.2141512540401891, 0.0851557165151462, 0.06960008598980494, 0.12696660967776552, 0.13681609678315, 0.1767791312886402, 0.08402829029364511, 0.21720110991736874, 0.0598938074108446, 0.15775580832269043, 0.11398504415410571, 0.15394851652672514, 0.1338741194922477, 0.2055852668127045, 0.08225067591411062, 0.11739320892957039, 0.1249951240606606, 0.15154694148804992, 0.12699049199, 0.12580900773173198, 0.1262294640764594, 0.1609044588985853], [0.042281745045329444, 0.006427845391954179, 0.039093185478122905, 0.014399464635062031, 0.018596610316308215, 0.03701090834510978, 0.018085328083543573, 0.06452677931520157, 0.03041633994143922, 0.02680861722183181, 0.027123414001835044, 0.012668754916376201, 0.023753618261252996, 0.05172747783944942, 0.029320126595848706, 0.02735464495344786, 0.06167148116219323, 0.03368096593476366, 0.0601139098580461, 0.014685511541756568, 0.07404705713270232, 0.039077429682947695, 0.03355652261234354, 0.05588859967247117, 0.026307669395464472, 0.010359693224017974, 0.020077430563105736, 0.044713284296449274, 0.08804522396530956, 0.02644622651132522, 0.06612135781324469, 0.0264590675215004, 0.020847865198447835, 0.0293500499901711, 0.04467633647436742, 0.03065317967411829, 0.06886972361826338, 0.013823857680108631, 0.03200191247742623, 0.025868965494737495, 0.054520795529242605, 0.017335699558316264, 0.027894071281480137, 0.046548856698791496, 0.06243390802410431, 0.007539092794104363, 0.08834439111524262, 0.01562522356834961, 0.07098241767380387, 0.013524941005016444, 0.02917295314546209, 0.0870930781820789, 0.06749050895450637, 0.024647863538120873, 0.07730314842774533, 0.11870374524733052, 0.10018244807724841, 0.014037268738320563, 0.1335350173758343, 0.033025564189301804, 0.03721875051269308, 0.04158447132795118, 0.028717903442156967, 0.011095911140728276, 0.12294672225834802, 0.04420807097631041, 0.09965053599444218, 0.19331176212290302, 0.08002539063454606, 0.05663175666995812, 0.034277890154044144, 0.08217505106586032, 0.17249367374461144, 0.09228611554135568, 0.21710553613957018, 0.04348159003711771, 0.04777096241014078, 0.17370686255162582, 0.060738679458154365, 0.0866494223009795, 0.03039739291125443, 0.0987885166250635, 0.04343674205301795, 0.01881607637187699, 0.15544424095423892, 0.10679982267902233, 0.03574474132619798, 0.1513594007701613, 0.23976426949957386, 0.08732507354579866, 0.07903984078438953, 0.04917411133646965, 0.2355585334589705, 0.0644166000711266, 0.12367904389975592, 0.21456139453221112, 0.14107451046584174, 0.02740545980486786, 0.08308496864628978, 0.0559769671963295, 0.18014508270425722, 0.0718823385250289, 0.10023993483628146, 0.10103369146236219, 0.18223655875772238, 0.1692859036847949, 0.13520164357032627, 0.011160663525515702, 0.1026086846832186, 0.0507985612784978, 0.06241400362341665, 0.1581595218158327, 0.27507478022016585, 0.23446083767339587, 0.069482596591115, 0.07302428115508519, 0.03800210964982398, 0.027616227889666334, 0.01486842033045832, 0.029589648656838108, 0.062112350278766826, 0.06065332876460161, 0.03967129254306201, 0.03786912791838404, 0.03823900689894799, 0.027234960653004237, 0.02760703267995268, 0.036535195395117626, 0.025843778857961297, 0.048901234767981805, 0.014614991741837002, 0.022195746387296822, 0.0792265948257409, 0.024369934799324255, 0.14272630854975432, 0.02161139786039712, 0.008609516044089105, 0.02994625989231281, 0.0655752707098145, 0.020367361685202923, 0.044445740059018135, 0.02636490567965666, 0.02654216208611615, 0.05956454617262352, 0.020863045829173643, 0.0053934682546241675, 0.014437404151976807, 0.08393428244744428, 0.03946278244256973, 0.06702752012643032, 0.026816346689884085, 0.0477957464318024, 0.019024608736799564, 0.04713005851954222, 0.03432077886827756, 0.030674692679895088, 0.013468205670505995, 0.024553026341891382, 0.04287969713914208, 0.0081532232434256, 0.043157390246051364, 0.046788021209067665, 0.06318619343801402, 0.051153341264580376, 0.03428640258789528, 0.06041096930857748, 0.07780440981150605, 0.032716834466555156, 0.031193928880384192, 0.03317801616503857, 0.033586698336876, 0.03651149490906391, 0.027566965982259717, 0.019467127276584506, 0.08592866332037374, 0.026783410175994504, 0.034129980122088455, 0.034951749112224206, 0.031007998622953892, 0.022747262300981674, 0.07662479576538317, 0.0566083901503589, 0.05433751102827955, 0.019845565075229388, 0.008119231952150585, 0.03070819322601892, 0.034422887256368995, 0.04866478651820216, 0.02081632392219035, 0.046756761948927306, 0.052957706357119605, 0.030454438092419878, 0.05390166996221524, 0.0242852037990815, 0.02076551092613954, 0.0216899486258626, 0.04970269488694612, 0.029140864535293076, 0.06642787222517654, 0.023727598563709762, 0.03469961186056025, 0.006481460923168925, 0.035610857885330915, 0.06774370005587116, 0.07520698200096376, 0.014831790704192827, 0.059704081068048254, 0.07379461560049094, 0.04921924504742492, 0.022456800543295685, 0.032673374298610725, 0.028741039895976428, 0.04082421524799429, 0.02251803885883419, 0.042147939529968426, 0.05817929413751699, 0.058012166191474535, 0.022313389781629667, 0.04789658203662839, 0.021777102738269605, 0.11657541414024308, 0.0579990709957201, 0.03393051309103612, 0.02689607375941705, 0.036650090987677686, 0.010717800814745715, 0.05389166581153404, 0.005950198219579761, 0.02828077289450448, 0.1121993106789887, 0.09816257443162613, 0.010346287253923947, 0.02655246866197558, 0.0864236980851274, 0.038634096636087634, 0.09506328409770504, 0.04432720052136574, 0.01457359659980284, 0.08303415379486978, 0.11815459307399578, 0.019712061985046603, 0.09460920846322551, 0.11682626747642644, 0.08208714367356151, 0.0876618230540771, 0.032391116983490065, 0.09871364134596661, 0.17444197466829792, 0.062016687443247065, 0.09043735888553783, 0.08515809880918823, 0.041267863707616925, 0.12533735804026946, 0.10698431316995993, 0.07872540023527108, 0.06012219593685586, 0.03418540371058043, 0.09959725721273571, 0.11450997262727469, 0.11580464182770811, 0.160855655267369, 0.23680280341068283, 0.07496764679672197, 0.20790312759345397, 0.24621218210086226, 0.07548864188720472, 0.35002468968741596, 0.13285185559652746, 0.2928162063471973, 0.05991278412693646, 0.14679289190098643, 0.1576072897296399, 0.12447520508430898, 0.09545317880110815, 0.16477622848469764, 0.14134465222014114, 0.13881176157156006, 0.15480192698305473, 0.19653660157928243, 0.1462401996832341, 0.19991058303276077, 0.033232185523957014, 0.09667877631727606, 0.1465919183101505, 0.09077953349333256, 0.020343299402156845, 0.09223064742400311, 0.09509284383966587, 0.1612385589396581, 0.08456161987851374, 0.045684833530685864, 0.010750670535344398, 0.0378289888612926, 0.03065006821998395, 0.01762048759701429, 0.10830828978214413, 0.049652321613393724, 0.04147937950619962, 0.04525142299826257, 0.059343475222704, 0.01686317042185692, 0.01911077579279663, 0.03660288297396619, 0.025149861503450666, 0.02642104729602579, 0.06353057964588515, 0.005866645378773683, 0.020330627230578102, 0.03352857704157941, 0.0407190640544286, 0.012633859132620273, 0.07145158859202638, 0.015035708765935851, 0.019877180566254538, 0.0741568356170319, 0.02733602075750241, 0.02999770742462715, 0.013970152613183018, 0.029058372965664603, 0.0462859508843394, 0.029321345573407598, 0.008555008080293192, 0.027570199890760705, 0.07476851373212412, 0.023728828673483804, 0.018585628386063036, 0.021521113740163855, 0.06741331075318158, 0.023309734169743024, 0.02031585663644364, 0.052021813608007506, 0.007444782058882993, 0.03505120432237163, 0.0526578415883705, 0.04528954341367353, 0.04285916933440603, 0.07090055878506973, 0.044428882174543105, 0.034072912676492706, 0.012299880618229508, 0.05055176006862894, 0.0319113110890612, 0.025554840358381625, 0.051596303237602115, 0.028242210901225917, 0.036087019834667444, 0.06953261734452099, 0.02155811536795227, 0.022359441900334787, 0.015401839900732739, 0.0065546543100936105, 0.012396347756293835, 0.12134268879890442, 0.11003594278008677, 0.2019184487289749, 0.1433989912038669, 0.11952253451454453, 0.14875906374072656, 0.0788894816651009, 0.1217525324318558, 0.1363437346299179, 0.142259928106796, 0.17572615732206032, 0.17685086728306487, 0.11044868821045384, 0.1793045410886407, 0.19727325736312196, 0.09490762604400516, 0.11832680102088489, 0.10311603167792782, 0.1287527068052441, 0.11888676628586836, 0.15888661873759702, 0.11909202949027531, 0.15118556009838358, 0.13498173037078232, 0.15951867622788996, 0.06818521113018505, 0.0606890297785867, 0.18292239226866513, 0.1248613148345612, 0.20112696307478473, 0.09920805270667188, 0.21721570054069161, 0.09978889458579943, 0.09965328936232254, 0.12998851627344266, 0.09239448394509964, 0.12875913380412385, 0.12367244620691054, 0.08836414708639495, 0.1515805014059879, 0.13956962793599814, 0.11540734791196883, 0.13210437929956242, 0.0759020255645737, 0.1595913027995266, 0.11990551982307807, 0.14838922186754644, 0.13835108082275838, 0.09818405960686505, 0.140043904830236, 0.16974138939986005, 0.1841745141427964, 0.13858904305379838, 0.14328814402688295, 0.24321403907379135, 0.247506650921423, 0.16974993894109502, 0.18981733010150492, 0.2518574026180431, 0.15996304457075894, 0.1791504563880153, 0.16053635365096852, 0.15109396423213184, 0.2942467405227944, 0.288587745744735, 0.12326770112849772, 0.2754927281057462, 0.2557552809594199, 0.10708375353715383, 0.16492330731125548, 0.2513747097691521, 0.24570989655330777, 0.2776206732960418, 0.2541549730813131, 0.3141069982666522, 0.15650353801902384, 0.24427986703813076, 0.3278445376781747, 0.36611329356674105, 0.3272212523734197, 0.22433510835980996, 0.22338358598062769, 0.21263112779706717, 0.23979441553819925, 0.30512727855239064, 0.1874605956254527, 0.1325759696192108, 0.24975032662041485, 0.4807400208665058, 0.24875279108528048, 0.35406894923653454, 0.26397052919492126, 0.45969606726430357, 0.10395796853117645, 0.3713417239487171, 0.3334009676473215, 0.20746365742525086, 0.17486875411123037, 0.23180007498012856, 0.23998660210054368, 0.2217616667621769, 0.2673141419654712, 0.2460562568739988, 0.20159540668828413, 0.4311865830095485, 0.2852726908167824, 0.28518342529423535, 0.21509967424208298, 0.1796069514239207, 0.1637480125646107, 0.2000349372974597, 0.3470675874268636, 0.3827501367777586, 0.51008379785344, 0.12910237710457295, 0.14760475693037733, 0.17595490207895637, 0.1595107204047963, 0.16326344950357452, 0.18152572971303016, 0.16294986242428422, 0.25500179326627403, 0.12203016245621257, 0.2036011646850966, 0.1519405617727898, 0.0862403801875189, 0.11127976002171636, 0.12728401139611378, 0.12241632415680215, 0.12135687124100514, 0.11183040391188115, 0.060027917206753045, 0.1741091362782754, 0.08853706007357687, 0.24727513053221628, 0.11964580524363555, 0.17762544681318104, 0.10569722871878184, 0.19424802594585344, 0.08648662478663027, 0.1692477721371688, 0.24762526096310467, 0.14113878045463935, 0.15220991685055196, 0.09720084752188995, 0.09020218712976202, 0.1372282113879919, 0.2236298899515532, 0.1592718972824514, 0.12905882787890732, 0.13332672620890662, 0.17663834587438032, 0.0627330677525606, 0.16507317661307752, 0.13806915376335382, 0.1462597181671299, 0.18743258697213605, 0.1451530127087608, 0.12793595844414085, 0.17060832178685814, 0.12879419286036864, 0.136141647817567, 0.15044777625007555, 0.2265783239272423, 0.11264048036537133, 0.13903250597650185, 0.214514015824534, 0.21446602855576202, 0.14831525943009183, 0.13647432293510064, 0.20699521381175146, 0.12829527666326612, 0.1245462879887782, 0.11030417721485719, 0.14774974290048704, 0.05505629218532704], [0.0366482727258699, 0.02649792451848043, 0.05778254570032004, 0.019483970318106003, 0.04738161318528, 0.02807765264151385, 0.06727737898472697, 0.025277883833041415, 0.023365326596831437, 0.031187609492917545, 0.01448902608899516, 0.053531965386355296, 0.006346923464661813, 0.07705682219238952, 0.04518995832768269, 0.05510601979040075, 0.05767982132965699, 0.10357129474868998, 0.09678707792772911, 0.03785649656492751, 0.08216525471652858, 0.0031005596383693046, 0.02570365209976444, 0.055589807307114825, 0.018151993353967555, 0.02990797805978218, 0.02998448606376769, 0.013792180034215562, 0.028465207724366337, 0.04067762623890303, 0.04432905960129574, 0.037120905763003975, 0.03121038229437545, 0.052569448089343496, 0.03808840658166446, 0.02756140544079244, 0.03145745438814629, 0.02921577135566622, 0.06236020533833653, 0.03164794514304958, 0.04978297671186738, 0.017520744804642163, 0.03470862895483151, 0.022806385495641734, 0.041595907823648304, 0.05266584936180152, 0.05077159163192846, 0.043434359758975916, 0.01813686281820992, 0.11173994353157468, 0.04805820695764851, 0.03587593077099882, 0.05477841725223698, 0.09021377947647125, 0.13646675302879885, 0.028392516214807983, 0.032116284855874255, 0.007404296047752723, 0.038503916512127034, 0.06525437347590923, 0.20241693448042497, 0.09972458748961799, 0.01239915307451156, 0.06295073224464431, 0.04666689157602377, 0.04283235924958717, 0.12956532882526517, 0.13954724476207048, 0.05498416656337213, 0.013648464064317523, 0.040036091522779316, 0.0744034735544119, 0.15808839438250288, 0.07037545961793512, 0.051570884679676965, 0.05895327252801508, 0.04238434325088747, 0.03305107922642492, 0.057657245197333395, 0.08709483707207255, 0.05783814369351603, 0.10354238809668459, 0.08954103745054454, 0.0451132907619467, 0.07154432736570016, 0.03390122052223887, 0.05365176286431961, 0.053568456787616014, 0.09864706327789463, 0.06508244012366049, 0.04086600929440465, 0.04942599996866193, 0.12033483741106465, 0.0719854525232222, 0.058701962771010585, 0.111630009196233, 0.058340555406175554, 0.023513006563007366, 0.02709054057049798, 0.026101209477928933, 0.12525533587904647, 0.07435399456880987, 0.01932757382746786, 0.06602039604331367, 0.15880985098192468, 0.1530928202555515, 0.13982372445752844, 0.06835680309450254, 0.04994946641090792, 0.06780251525924541, 0.03014693476870889, 0.07126829295884818, 0.06791518811951391, 0.05994927923893556, 0.05282376354443841, 0.08836410255753435, 0.055507699798909016, 0.04563961447274778, 0.03987483767559752, 0.023852735794207547, 0.02917077308666194, 0.02182310476200655, 0.036673591093858704, 0.013994055334478617, 0.026005806394095998, 0.015083116231835447, 0.02629923303175019, 0.002179090529352834, 0.03258969714806881, 0.0342354727035854, 0.04514566695434041, 0.035868119666702114, 0.04590239412209485, 0.026758253225125372, 0.020752899981744122, 0.05990674675558694, 0.0732943115872331, 0.03290161810582504, 0.08260938557214104, 0.018003918194153812, 0.025070314404729288, 0.12768288608640432, 0.016420303072663955, 0.025897892555803992, 0.052547027808032, 0.04528104211203754, 0.05761130254541058, 0.04485212899453472, 0.020872202076134272, 0.06710660338285379, 0.10443079081596807, 0.025154678041872103, 0.016757239973230753, 0.012670690066443058, 0.028424384036043193, 0.012252874839759897, 0.07593503629323095, 0.024248231857200153, 0.036248589094611816, 0.0482116274361033, 0.0057654799820738845, 0.017061156868294347, 0.009511661482974887, 0.03186745758284815, 0.025065774316317402, 0.03161054461088497, 0.06409761757822707, 0.028322355428826995, 0.030652847563032992, 0.043826543987961486, 0.013525610793294618, 0.012011099825031124, 0.027657895770971663, 0.016502126709383447, 0.051566557958722115, 0.05272888738545589, 0.04913595752441324, 0.00919719495868776, 0.0065926258321269415, 0.009308201697422192, 0.04421583013026975, 0.007777016990075936, 0.04965343112417031, 0.05602700279268902, 0.0476110110321315, 0.004110682693863055, 0.0369141656847205, 0.021922949599684216, 0.021955288684694096, 0.06490751591627486, 0.052489875015453435, 0.05117170941957738, 0.05584378137427848, 0.03242287719331216, 0.06845776486443356, 0.06475141999544576, 0.018589964383863844, 0.034375367540633306, 0.055329699389403686, 0.039528885536128655, 0.03093351853749482, 0.03730292490217835, 0.011015133932232857, 0.03722292138263583, 0.023933889642648865, 0.01108768814447103, 0.051297095269546844, 0.027680829989549238, 0.03527516222675331, 0.015130419797060313, 0.03171680902596563, 0.060286993539193645, 0.08435466457740404, 0.052239403885323554, 0.0598672273918055, 0.03490504946967121, 0.030205208204279188, 0.03851311172184069, 0.031094423575268593, 0.020260156597942114, 0.019382266400498338, 0.04252621220075525, 0.012983920914848568, 0.02438366453134222, 0.012790906857844675, 0.08450147623079829, 0.0029216391976660816, 0.026239740618621, 0.008452592628600542, 0.05200431747653056, 0.1407281798310578, 0.025172786445182282, 0.07503749031457119, 0.034218447835883126, 0.0701207693782635, 0.033773508039303124, 0.12346178758889437, 0.03335868088470306, 0.02815577852743445, 0.05338461196515709, 0.0617190713819582, 0.032348243112210184, 0.05837749209604226, 0.05521455888811033, 0.10776186129078269, 0.08188553925720043, 0.045644130441360176, 0.10991339935571887, 0.04491158986638766, 0.07434217215632088, 0.04584639536915347, 0.088047561730491, 0.1597760827280581, 0.18514399649575353, 0.1336037105647847, 0.14590645587304607, 0.15343072009272873, 0.030574931333831046, 0.09339865428046323, 0.08806997459032573, 0.12364271577098407, 0.1888842723565176, 0.08446941545116715, 0.028300070589466486, 0.017363366823701654, 0.019275174490758218, 0.10709224370657466, 0.017047727706085425, 0.035952798716607504, 0.04844674353080336, 0.03434378915699199, 0.028441349531931337, 0.06581375986570492, 0.053094658578629605, 0.05756140424637124, 0.07033006986603141, 0.04732564040750731, 0.06852580496342853, 0.06631693599047139, 0.0796691449068021, 0.17333213734673336, 0.011386702226445777, 0.10486893996130675, 0.19047935551498085, 0.05874334121472202, 0.015677155352022965, 0.06482011318439618, 0.12499803327955306, 0.15965441503794864, 0.03323810044093989, 0.036019335966557264, 0.03299331045127474, 0.06081032639485784, 0.06588939955690876, 0.009250854091078509, 0.0877944374224171, 0.025303042639279738, 0.040946428416646086, 0.04007675379398279, 0.009301035333919572, 0.0763409242790658, 0.03376646505785175, 0.051058594981441274, 0.029813873734383378, 0.04311856107960921, 0.011440855814726092, 0.04509816208155826, 0.01797810815332923, 0.02629390626680106, 0.045780117870890535, 0.018117518739018124, 0.05537793898838572, 0.020683334769273642, 0.052735752251464874, 0.040052281474345364, 0.03197372941940557, 0.04561913119687233, 0.1013914734357968, 0.04795530447154306, 0.04108508386707399, 0.04498558570048772, 0.02386639502219623, 0.02403155442152638, 0.0049010110615199665, 0.041219379199901596, 0.046210953150875866, 0.04686587992182467, 0.05094566979096271, 0.04310981857997831, 0.022646686447842512, 0.0376275662711123, 0.010990105929522542, 0.09457723674131557, 0.029654952086275443, 0.010562041643424891, 0.033015801236615516, 0.06099708043620922, 0.013411720810836414, 0.03589810243283864, 0.0913101171317976, 0.05331419699359685, 0.03814849827904254, 0.0939661671873182, 0.04182903125183657, 0.0429279404488625, 0.027126421555294655, 0.0052736958241439424, 0.036177161091472954, 0.03360324823006522, 0.024731397825235035, 0.06419358469429426, 0.013640494325954933, 0.1316056857467629, 0.09261254177545197, 0.10753656009910628, 0.21584035246632993, 0.15739540656795725, 0.17558791005285457, 0.169215191854164, 0.1518306348589249, 0.10435288757435046, 0.12129216338507831, 0.0838414768804796, 0.08003431124961935, 0.08874724371707998, 0.1532328041503206, 0.1528564016916789, 0.11270165559835732, 0.22944714030018076, 0.1643810051609762, 0.1860154708265327, 0.09135091298958287, 0.17824699549237266, 0.14418114064028487, 0.16182861087145284, 0.09206520786392502, 0.0946181513427291, 0.20233035553246737, 0.10645406349794939, 0.09689700484159403, 0.08042980174650438, 0.2077645537792705, 0.14017327601322904, 0.13614672410767525, 0.1761323495884426, 0.11482140005682595, 0.11395113542675972, 0.17660077835898846, 0.16589911276241764, 0.12955670506926253, 0.17135073663666844, 0.12989689072128385, 0.11339726319420151, 0.22209885413758457, 0.10946780646918342, 0.10453960450831801, 0.07881823548814282, 0.1864668747293763, 0.12693520198808983, 0.12475750321755186, 0.10398240003269166, 0.23632500873645768, 0.14707429945701733, 0.1301468163728714, 0.11264507425948977, 0.2278732677223161, 0.22935872082598507, 0.20213623938616365, 0.15670458582462743, 0.16753244621213526, 0.09335118651506491, 0.20847774285357445, 0.28924721817020327, 0.2971456287195906, 0.11675502872094512, 0.13085150043480098, 0.15482241025893018, 0.0925783213460818, 0.2536248421529308, 0.2179206963046454, 0.1566320631536655, 0.12343938957201317, 0.17057262448361143, 0.19992014189483598, 0.43731678219046444, 0.32151185092516243, 0.09516002304735593, 0.24151780118700117, 0.2833131834631786, 0.3241632180288434, 0.20619497081497684, 0.4072838765569031, 0.32863326254300773, 0.26025228027720004, 0.3874214517418295, 0.2789555594790727, 0.2948109508724883, 0.2534136862959713, 0.12123000109568238, 0.2269049728056416, 0.10711459719459526, 0.18236962583614513, 0.14962618908612058, 0.06560741312569007, 0.18663384311366826, 0.14144218526780605, 0.196286957943812, 0.1617679774062708, 0.15263611741829664, 0.10166872496483847, 0.11427577308495529, 0.13876460550818592, 0.18479178805137053, 0.1623808578005992, 0.11138066984131001, 0.27993563970085233, 0.36190893792081624, 0.34948004235047847, 0.28779848653357476, 0.3939250996336341, 0.1971254957607016, 0.09663700082455762, 0.11960026706219651, 0.32043588522356004, 0.28149735589977354, 0.1967521509504877, 0.09765140537638217, 0.23862704692874104, 0.21373042662162334, 0.17245704133529216, 0.22110805730335414, 0.33163685293402523, 0.11272495903540403, 0.16896885819733143, 0.09068004117580131, 0.16987392213195562, 0.10841108465683647, 0.12749991699820384, 0.15581632411340252, 0.1318873604759574, 0.133969797170721, 0.07215803896542639, 0.1117418434296269, 0.10668389921193011, 0.14630016521550715, 0.24261426500743255, 0.10397510472103022, 0.16664645547280088, 0.12523749464889988, 0.08715379328350537, 0.13171305967262015, 0.13346581952646375, 0.21207560057519004, 0.32403574674390256, 0.12563255470013246, 0.1459178701043129, 0.08425713152973913, 0.12507877894677222, 0.1500532653881237, 0.12129476090194657, 0.1145530839858111, 0.19501306145684794, 0.13879769045161083, 0.23627886199392378, 0.11616398973274045, 0.19213913910789415, 0.07640847456059419, 0.1227515448408667, 0.17247794021386653, 0.11660713353194296, 0.12206412313389592, 0.16899104841286317, 0.12804969999706373, 0.08867039432516322, 0.11202578913071193, 0.15305020613595843, 0.11404984106775373, 0.084056068881182, 0.14875079621560872, 0.13866766617866233, 0.13261853920994326, 0.1116448595712427, 0.1056057887035422, 0.1982752457843162, 0.11606628599110991, 0.09619733769795857, 0.22758228646125644, 0.08793474044068716], [0.05008154272218235, 0.02313315126230009, 0.03645991935627535, 0.04739079355204012, 0.05982326627417933, 0.03148322175547946, 0.023328610695898533, 0.014105596419540234, 0.03183849526976701, 0.047325362102128565, 0.04636411387764383, 0.039212062692968175, 0.0861173469456844, 0.00972007046584622, 0.03867916726449039, 0.044026196555932984, 0.020014986257592682, 0.009642641271057073, 0.017580385647306684, 0.012392348508001305, 0.020571940258378163, 0.02964005161629757, 0.0076542578790395055, 0.03360750815772917, 0.026472938261576928, 0.012681880725722294, 0.026431624755787198, 0.016930316232901532, 0.027960326515312772, 0.041773919365368783, 0.05693463084753603, 0.023581610694236588, 0.018495841504773125, 0.0531209083419526, 0.0705016618303489, 0.001881174478057801, 0.02977519114210736, 0.021979727607686073, 0.026381188399682287, 0.02672243532288121, 0.0409712569671683, 0.037772177456645295, 0.06066029753128532, 0.023696597199887037, 0.042180597738479264, 0.029441599472193047, 0.06418433011276647, 0.033850067993626, 0.03384161122085061, 0.030351405730471015, 0.039770346993464045, 0.024740789704083, 0.04607911432685796, 0.01791066362784477, 0.012938879972352879, 0.05968663688690867, 0.05128788892761804, 0.027978202997474, 0.010350103748351103, 0.03292399014753755, 0.04699245691881515, 0.024587007428635843, 0.03822360362391919, 0.04002835834398866, 0.07040291908197105, 0.04670408059610054, 0.10476549941813573, 0.13091179251205176, 0.09951287502190098, 0.00209554557386582, 0.0353152010939084, 0.055795285734348, 0.1426920064841397, 0.046028006327105686, 0.13125555531587452, 0.02909201637521619, 0.04875699094554875, 0.07906676590209827, 0.12529477360658348, 0.11665261234156787, 0.03918963499017991, 0.03620151095674373, 0.07368678154307418, 0.03857652824081015, 0.02572205736214528, 0.10066803530207835, 0.03520594953442924, 0.03525051179167349, 0.01413106878317194, 0.023862623056629673, 0.08864832285325974, 0.12402494408888742, 0.06123085324361455, 0.021603683235298377, 0.012167892436991679, 0.11648809304460883, 0.09091756553971209, 0.11474694780190475, 0.009072256252693478, 0.08364748689928092, 0.0231233883096138, 0.03298790761618875, 0.01579853917064611, 0.07311812572879717, 0.1779509082552977, 0.04924191765894648, 0.07181035020039417, 0.1334926110575907, 0.014969739258958725, 0.01757796067977324, 0.022208095724636223, 0.03351030907651875, 0.027579493435041513, 0.13951356610050425, 0.03240148478653282, 0.0776365953788627, 0.033988278155447915, 0.02811051679600496, 0.022349170576489996, 0.04804716751095839, 0.03533545801474247, 0.03585826765629463, 0.02100927860738011, 0.07232210555230267, 0.016656037005304825, 0.04488608967221808, 0.08917906234273687, 0.050502778321970254, 0.06356542347930372, 0.0374113378347829, 0.07036219001747668, 0.036738280396093614, 0.049563408610993065, 0.0653123871597927, 0.05218077792960685, 0.04020323802251369, 0.03512605733703822, 0.07203110202681273, 0.010883858212764608, 0.026561966296867467, 0.03422742782277055, 0.0632092371233739, 0.03106341107923072, 0.031404695109813474, 0.02851483328413451, 0.034344932064414024, 0.03182358923368156, 0.01306760363149806, 0.0020734247027576203, 0.011938875868509058, 0.049090066822827794, 0.03522795421304181, 0.018710400108830072, 0.017124801597674377, 0.03172005221131258, 0.06823808915214613, 0.055356309094349854, 0.04221229115501046, 0.005463725983645418, 0.07204758512671106, 0.015808997886779252, 0.03313756540592294, 0.021747917780885473, 0.04596087535901461, 0.041294740585726686, 0.0439394357817946, 0.04309490883315448, 0.0321078651904827, 0.057864404589054175, 0.012859507278335514, 0.04023686102300417, 0.05949565631453879, 0.02437897044728743, 0.060936554582440294, 0.010925591031991644, 0.029788859646942, 0.01106756388253416, 0.039673493010923266, 0.010126708948519081, 0.07566726941149682, 0.0204375688554137, 0.02958929428132251, 0.01034170541970525, 0.05096152577607427, 0.017437238348065875, 0.037348377736634575, 0.00803219472800265, 0.061111604954930954, 0.031744895604788326, 0.03192114454577677, 0.021096302843943704, 0.05391702499764506, 0.045408027290250175, 0.043914666603086516, 0.04469295687158592, 0.011589178666326916, 0.014359278266056208, 0.016912775572563987, 0.005419603448899579, 0.10132141469512135, 0.0499779092206154, 0.05209799506701529, 0.08794959823717363, 0.032829830161063, 0.023805086202628445, 0.051859524464816786, 0.05393241342972033, 0.056385823772870935, 0.014037413457117509, 0.03251960501074791, 0.053924112507957034, 0.11292741692159325, 0.039531030342914164, 0.02036048568697879, 0.041147999436361715, 0.025800836338021327, 0.055930902090040036, 0.01461439245758811, 0.07195353275164962, 0.012931211731483927, 0.054829940854688175, 0.042822425602935255, 0.03606723046686966, 0.07379803690128028, 0.041976915308623575, 0.04920350038446486, 0.010846815766853979, 0.020564526203088462, 0.0948143974528648, 0.044836992892669514, 0.028316331045061816, 0.04192849388346076, 0.0429446499038022, 0.005959547888778616, 0.020041662755829748, 0.07709647514275275, 0.04049395211040974, 0.07090873725246638, 0.07957098103361204, 0.04592082535964437, 0.03434865393501241, 0.06976511736866087, 0.037616886766045354, 0.06364150845911354, 0.14882024639518932, 0.06788276368752122, 0.029232863016659394, 0.03756646896363236, 0.09509907788014971, 0.06912594268214889, 0.09035701397806406, 0.043981764174532145, 0.03744069348613266, 0.11257868914981373, 0.1441720567527227, 0.041077491696341895, 0.050890613565570675, 0.07418802808388136, 0.041194235236616805, 0.0450266227562679, 0.02301104941579979, 0.12165436855866574, 0.022620195486524608, 0.027605429640971124, 0.022240863399929367, 0.020126050512772053, 0.084555764333345, 0.20204550441121683, 0.03748905553948134, 0.04974758739990648, 0.05004064667446073, 0.03152618097374216, 0.044703038947773166, 0.024931306434154976, 0.04180392068519723, 0.042709504123195074, 0.03431707184063271, 0.02770139675703831, 0.02729295021708822, 0.09507581155048683, 0.16876963607501239, 0.019084728264715523, 0.059615249701892026, 0.10153199909836985, 0.05504871856828686, 0.07075503846863285, 0.03592095315980259, 0.08823375916108489, 0.06028138661349658, 0.10891470607020892, 0.047635253285989165, 0.06867893971502781, 0.02815727024426451, 0.005543659926843247, 0.023492578948207665, 0.04111997965082992, 0.04376916112960316, 0.03370204292878043, 0.022513398580485955, 0.04802723713510204, 0.026954753520840313, 0.014084754129726207, 0.03891590124112554, 0.031487860178458504, 0.009136708067671861, 0.0025656682964836364, 0.06765841244487092, 0.05624021439871285, 0.04803917829121929, 0.042845628850045614, 0.020301538752391934, 0.031154476309893653, 0.08313503392855637, 0.04139194337767549, 0.018691018922254443, 0.03506385051878169, 0.040145317107089795, 0.0844492216128856, 0.03416861633013468, 0.043565716187004, 0.018469274473318364, 0.02222466417151736, 0.029261773379403166, 0.061494883411796764, 0.009302320177084766, 0.004655499333239277, 0.024785068089840934, 0.09009453860926442, 0.0509827660425799, 0.04227174460538663, 0.023329555078817066, 0.02290359199832892, 0.03887648577801883, 0.021731455090048257, 0.006605940889130579, 0.059836443106178194, 0.043335631853551604, 0.03276420204201713, 0.031625706687918864, 0.05231951501627918, 0.05798919672088232, 0.021439817028294783, 0.05652551451930776, 0.011013983603334054, 0.040296511142514646, 0.0054178594018594595, 0.004243676021360443, 0.03463735309196636, 0.03294405782071408, 0.030908953449397814, 0.009309333472629078, 0.07429624063661322, 0.19386265834327787, 0.09424128875252791, 0.11529228533618152, 0.21507812227355316, 0.08665915185702033, 0.1330087604583241, 0.12916983832838014, 0.19254280807217583, 0.11063291152822785, 0.14830120315309614, 0.1314726928831078, 0.1546357007464394, 0.20540551864542067, 0.152349425770808, 0.12140114777139388, 0.11817261984106153, 0.10501407436095178, 0.13718648784561083, 0.12324667608481832, 0.08467412204481661, 0.07703234616201371, 0.10982275343849324, 0.09211859796778299, 0.14114093268290162, 0.13516824692487717, 0.09443693372304551, 0.17513292899820954, 0.13011343457037583, 0.2027080047992058, 0.18157615122618154, 0.1315436273580417, 0.09119239024585113, 0.07877525771618821, 0.10636193328537047, 0.139341744070407, 0.1537161649321206, 0.11052783083869144, 0.126058695896063, 0.11683305070619099, 0.11398789400118403, 0.15706316189607605, 0.17406471131835133, 0.3028859628830105, 0.05073465494206175, 0.12737290584482253, 0.11318505348754115, 0.24601987679488957, 0.16285896417684853, 0.06616731159738265, 0.12110384341212921, 0.10683122294722125, 0.18107313837390393, 0.23196652386104688, 0.23231711442349479, 0.31073331367224455, 0.18284998834133148, 0.1789872581139207, 0.16318135312758386, 0.16787766362540424, 0.12169074863777496, 0.15183425653958693, 0.17628584057092667, 0.11417504138080403, 0.15744857402751222, 0.16158816986717284, 0.16344757634215057, 0.15041289530927315, 0.21460619056597352, 0.23708076740149409, 0.12289370322832838, 0.13150732149370015, 0.18005940917646512, 0.23477823939174414, 0.14284895587479696, 0.29892823775298893, 0.1649796066340059, 0.11152802326250821, 0.22030922438716516, 0.28136819251812994, 0.30808476672973484, 0.2460003731539473, 0.18196732242358848, 0.13313746370840818, 0.14463686384260654, 0.09821176397963427, 0.2522300201235339, 0.12915946310386062, 0.2618905564304441, 0.11193627869943157, 0.1362097472883761, 0.15555219375528395, 0.2296623185975477, 0.2128629747312516, 0.11563503139768727, 0.24154388025635853, 0.18740779923973605, 0.17826994269853458, 0.20733830868266523, 0.11381474352674559, 0.2759348996914923, 0.2067854383494705, 0.11093756314949133, 0.1358330628136173, 0.2384613105095923, 0.28869912726804614, 0.20549996435875073, 0.17720825591823086, 0.25534896994940937, 0.11125363642349839, 0.2139064492075704, 0.15910265792626888, 0.21485719975316897, 0.16798482974991202, 0.2954545116517693, 0.1565276726614684, 0.2058520243735984, 0.16906968638068065, 0.09155706677120179, 0.0969115064071957, 0.1627385729807429, 0.12160674494225532, 0.17306089721387252, 0.1708098000381142, 0.18947237986139953, 0.0861879697185941, 0.11412026346079074, 0.19169431063346565, 0.12036634157993831, 0.24704873096197844, 0.13390493346378207, 0.19141979020787403, 0.17499727924587205, 0.16450819442979991, 0.14528253232128918, 0.14862633805023506, 0.14668821939267218, 0.15243769681546837, 0.12587005679961294, 0.11306678483379073, 0.14101582142757252, 0.09776283142855391, 0.16927201068028808, 0.06361202293192036, 0.17199742927914485, 0.07560848389402963, 0.2331368759041652, 0.15581452811602503, 0.1777686961577274, 0.12234647321747616, 0.0987596322374884, 0.11017059805453755, 0.14870369952404872, 0.15505998657317832, 0.09188553391140886, 0.15037755423691124, 0.13498285843525082, 0.16364731796784326, 0.24392286431975663, 0.13429536251351237, 0.17498870001873001, 0.10566617725999095, 0.10671290234313346, 0.10783670688397251, 0.08182529170881025, 0.11132826679386199, 0.13302663137437776, 0.10500328353373334, 0.12106291396776214, 0.08662485721288249, 0.07602804966154508, 0.1604420563671738, 0.18356761545874178, 0.08655846468172967, 0.14262613345636055, 0.08024453942198306, 0.13841066043823957], [0.01141819526310428, 0.04319671294069849, 0.08670381430420093, 0.06395603064447641, 0.036594500415958464, 0.055206528850249015, 0.01862403081759112, 0.0470705048792297, 0.048918344982666895, 0.02846546376531478, 0.024443780348519795, 0.02180187377234688, 0.017654557741479948, 0.0067232043966214405, 0.023462640710931737, 0.07326775012188591, 0.04444041886017658, 0.01636404456803575, 0.03099202203884488, 0.09691256025689654, 0.04971831338480115, 0.033122110180556774, 0.014928562122804578, 0.07742002184386365, 0.08281722402898595, 0.03001654869876802, 0.029676285121240653, 0.051356860421947204, 0.02546474919654429, 0.025594279941287823, 0.07146030140575022, 0.013883784249628661, 0.05874336347915232, 0.0024967151239252416, 0.09003261380712502, 0.04419956967467442, 0.02760245362878777, 0.06772435226594098, 0.043944170683971606, 0.009568896839482477, 0.00514738275342097, 0.0780146082979627, 0.036987649436923675, 0.01319153765507508, 0.011523919765750179, 0.05396101580117829, 0.01789215260942001, 0.05558410761295818, 0.05313056368322577, 0.08150512920110486, 0.0018240518352286017, 0.058866949621005915, 0.010944212444883306, 0.053781516253366135, 0.02225073581939796, 0.07404440766549669, 0.03088869467319455, 0.039141373126767576, 0.011788144747697515, 0.046885060728527606, 0.01582253466040129, 0.008445369676337577, 0.012363762834866066, 0.03987193958892021, 0.06699121426208876, 0.012812867935281247, 0.033005529912770726, 0.059816234424943104, 0.04992565460270271, 0.028859202793682925, 0.005533125604415545, 0.17904688225826249, 0.0739015219733119, 0.09987950339564122, 0.12383537730784155, 0.01471354802561109, 0.052633113227784634, 0.04304830566979945, 0.06502479751361534, 0.07992268481757492, 0.058117547450819984, 0.02985679398989305, 0.050993093027500436, 0.07749204727588221, 0.03197606718458701, 0.027622113120742142, 0.033512643130961806, 0.09359800998936407, 0.050300543080084026, 0.038222186121856794, 0.023572645550302695, 0.0543834685231559, 0.07717994449194521, 0.02262562615214847, 0.04175242305791471, 0.019023630957235582, 0.08687444889801554, 0.017641436570556834, 0.03822807877440937, 0.03040766423509922, 0.09404968106537126, 0.05868389518582262, 0.07765628455672413, 0.034393223613733426, 0.07523899083025753, 0.06290354649536312, 0.10037372921942733, 0.10218920055194758, 0.0516326907381881, 0.07969777696416713, 0.04679070407291874, 0.0681080945651047, 0.10382061183918267, 0.07988699493580498, 0.018832605856005102, 0.03524451894918457, 0.03724160123965703, 0.05173602738068439, 0.03990778532170225, 0.04376899414637592, 0.025696327102195937, 0.05659939160977956, 0.052448711794568226, 0.04250126119586639, 0.018435950187267736, 0.05705802032025531, 0.004540777217698633, 0.055312347976723686, 0.04738908290164545, 0.043269565867376514, 0.010989810925821075, 0.0283255856265896, 0.036624305066652596, 0.08185897037037648, 0.03902596545231063, 0.02365017957345117, 0.02967460786749143, 0.038380942642106675, 0.02508458219381282, 0.052052289902349, 0.09769104348379187, 0.06417241122107953, 0.059373881013016216, 0.060452381148934364, 0.02244679824798368, 0.049494726554257795, 0.052723922417499125, 0.019909976072085556, 0.026189124291704502, 0.05848425375006627, 0.024052184271567967, 0.06842590446467511, 0.01387866528602899, 0.010140708636754425, 0.024247714209195692, 0.01572821882291464, 0.006570153136635781, 0.01915766653837636, 0.05043012948590331, 0.03728397416125517, 0.012061127072229283, 0.015595960685459431, 0.018804732644639444, 0.04960587430105079, 0.015713383290858474, 0.010209059510088991, 0.05821304701385088, 0.04893313969660085, 0.04015438615169842, 0.007197242412075866, 0.04687122709583491, 0.02879240764741553, 0.03566296407370828, 0.1316600851714611, 0.041189986441168, 0.044508225182653405, 0.07822474741260521, 0.015609258116455749, 0.011203291560377693, 0.02495118857041234, 0.02638310870679561, 0.02384361479926156, 0.04646011067961808, 0.03310145992145408, 0.021464059282152448, 0.044652706492342986, 0.03595654656237457, 0.03166979025991168, 0.010615234150463948, 0.02513271047064336, 0.029261667623359244, 0.027749725413741544, 0.040096305674524046, 0.04646319059247617, 0.02210931030276697, 0.03603259814553894, 0.020321738156781066, 0.0333355889597442, 0.06474533438449726, 0.02393478021986084, 0.0689396339294035, 0.01372830338368658, 0.02716504106501816, 0.014142350355541566, 0.06763997007510625, 0.013137407258909661, 0.02409213408100186, 0.021456964350363705, 0.04892880555416923, 0.0551352900947677, 0.026967416415573098, 0.06696190685033798, 0.03149587537336629, 0.04912037242320366, 0.06353133663651533, 0.016859815914358478, 0.029715852724621072, 0.07372834181296639, 0.02073596973787062, 0.0391800315992441, 0.02560041750257369, 0.08285631294711493, 0.025225970603059977, 0.020961031586921308, 0.00926978535062517, 0.013051967507635709, 0.013695692487090128, 0.03836045194475446, 0.05370868559111841, 0.04274340913980268, 0.0749242608435452, 0.027346891365596093, 0.015993061642802786, 0.03566833351214882, 0.037714590507675894, 0.12369481453788467, 0.0176384345832048, 0.08538781577954069, 0.0594756257487461, 0.08095632583717816, 0.055709901644149795, 0.036049240807187743, 0.11410173945478164, 0.03102401602518512, 0.012305774198466679, 0.020488391128310468, 0.036754162356373854, 0.04580560322210658, 0.039450299518648535, 0.06183859797602054, 0.08541998045984656, 0.012841657699027564, 0.07287663087481633, 0.05502379724930506, 0.07331650180276483, 0.04507657671638299, 0.13092899549519643, 0.024009503358684015, 0.03668466022645589, 0.026871542067965493, 0.06732311012456194, 0.036792802275158465, 0.04396463540615514, 0.06795931622036733, 0.03931466460926458, 0.043351918284315616, 0.034903286868939176, 0.01995504670048831, 0.06444492042646743, 0.025101269384322222, 0.02081730170175433, 0.026638194140105043, 0.037848960055271164, 0.09984385804273188, 0.028405982484400738, 0.013990025472594425, 0.034324816151638515, 0.10644820053130388, 0.05718877189792693, 0.10504260993911885, 0.06214569497387856, 0.06735344912158325, 0.12261137540917844, 0.0916151175624691, 0.04850496130529791, 0.0013912229610468785, 0.044149137029307894, 0.07103080570232123, 0.07489945826819167, 0.05791603951365687, 0.08015967483515851, 0.03808809116890188, 0.01601192147063557, 0.020260113924450707, 0.031211387904477306, 0.05978631103062071, 0.041232392759411596, 0.02311335818376392, 0.06070948707929347, 0.06197492308274377, 0.0391521676647244, 0.0336267780221533, 0.03940875038097147, 0.03223794512450695, 0.03177832564688288, 0.020764961736858822, 0.014255156802391866, 0.06398230267222971, 0.024192207129090093, 0.0038381890271921293, 0.04120276622415986, 0.05326266596966889, 0.0301846228830982, 0.018623053038027138, 0.047685882600490004, 0.014146513804007554, 0.031041066868056078, 0.051142071752110496, 0.1033896095759701, 0.021334411649149843, 0.02139073138096137, 0.02060022350633517, 0.015938730866764672, 0.039702844951534644, 0.019058946054428816, 0.06196865193487611, 0.06106714288762305, 0.07040577635052614, 0.01684493399807252, 0.06210503270267509, 0.046464266706607305, 0.027174217721039895, 0.05204119850532152, 0.031059720749908593, 0.04650083232263569, 0.030282679144875146, 0.056469333940185606, 0.01596475613041548, 0.10539141192566603, 0.051146843761671335, 0.015127692404348636, 0.028151414699095767, 0.062157780848792754, 0.04165416270552669, 0.046361605418496765, 0.021307631250238046, 0.11385058925952762, 0.01814074239518959, 0.030016075579624157, 0.058321244723629206, 0.13542633620090783, 0.07241201674332842, 0.09523082393570803, 0.1660570566309616, 0.1527998351957649, 0.25097834353800863, 0.13166695745894685, 0.16788223525509238, 0.17016172700095922, 0.11875690528540872, 0.13992765481816605, 0.1780551503179595, 0.15104429970961064, 0.11473227554233745, 0.12508361774962395, 0.1782323158113286, 0.1282690788502805, 0.1129862989182584, 0.1166518108220771, 0.10529390856390819, 0.07524216722231358, 0.11563830426894128, 0.0921242382901255, 0.1256137783639133, 0.20612645574146882, 0.24839976627845317, 0.15166549215791747, 0.17220999521669, 0.09765668204636313, 0.15865781460888684, 0.14417910715565085, 0.10299117275280878, 0.05192249940591864, 0.08301251276861876, 0.11562804778805003, 0.11215264443308115, 0.24147132789948955, 0.13234112440841272, 0.10997258563293144, 0.18373551894910634, 0.18933239596663043, 0.07835499432985671, 0.10168828055611812, 0.13183684990508482, 0.1440781305427663, 0.1487264983006753, 0.163830183155369, 0.15381749777588993, 0.10551397019298747, 0.18402261135634035, 0.10177545322221704, 0.2403246652102098, 0.13764908333541825, 0.15433079679496586, 0.15165370685281232, 0.14686995651572943, 0.20090278994757682, 0.15335466479882598, 0.12464488972909749, 0.10423591025755741, 0.23988132103113458, 0.29476449242793024, 0.11443530514952727, 0.17416301619959995, 0.09073602137505077, 0.13767863565590233, 0.19433907262282446, 0.08797196656814776, 0.2339598286198452, 0.13755229243543, 0.17538698099087924, 0.09520898995106108, 0.17115923285018653, 0.3081452666083351, 0.2806486951885745, 0.18355715117650107, 0.35473438852932304, 0.14983023516833782, 0.1518887301790528, 0.2296194966766052, 0.16775544674601406, 0.26094669301528484, 0.17396294802892953, 0.1504794807988219, 0.1757987096789293, 0.184667611902114, 0.16936731728492305, 0.16195863514440134, 0.18182721978519112, 0.2769679395714775, 0.1389281006413512, 0.2493615006096661, 0.08774546309723519, 0.2023028366966173, 0.12595457257702947, 0.09381384879816324, 0.1929522361024283, 0.10256690919050016, 0.16720024606911466, 0.16745953762438148, 0.15906887536402792, 0.09305972285801545, 0.12053558093612082, 0.17737730231601745, 0.12826066289562732, 0.22223910520551726, 0.2436252631014213, 0.16649329103529453, 0.3760572709143162, 0.30355318333022296, 0.23205786739708856, 0.135563871008344, 0.17496297718025744, 0.23571261815959588, 0.28458780725486577, 0.23986135725863278, 0.15120061085326597, 0.14803055673837662, 0.12286369819776155, 0.10509076790185645, 0.17506009462522343, 0.14348206721479073, 0.13087137514958158, 0.08854862273437902, 0.13823218876495957, 0.2519721386488527, 0.10393660952104256, 0.13163684110622853, 0.13452802581014112, 0.1790973186143674, 0.11460752051789314, 0.07695499210967682, 0.08435553289018571, 0.14613986131735146, 0.17076507821911946, 0.17247546144062653, 0.17930108268046752, 0.09796245431061834, 0.14493176364339888, 0.14882815768942237, 0.09055049929884262, 0.13983886427013204, 0.198575978865847, 0.14764397201361135, 0.2138088271021843, 0.11325730156386271, 0.12786054139724, 0.13347053958568722, 0.12161349106463604, 0.0989742465026211, 0.09067860883078538, 0.1496894349111244, 0.19537801999831572, 0.2540402073645964, 0.09037739335326478, 0.15920471807476133, 0.12517726194346324, 0.16774887131759897, 0.18497609300538898, 0.07991306658368558, 0.11255442092078738, 0.0803313781216275, 0.1195668704167474, 0.09035952243721113, 0.16314242006046697, 0.13365154940402135, 0.14264372235629708, 0.08152435824740678, 0.21427823550766334, 0.1627428477513604, 0.2187313887407072, 0.13916051160776988, 0.17019476741552353, 0.07129285804694518, 0.1282321198959835, 0.20875450456514955, 0.22592490742681548, 0.10953561650239863], [0.026028877909993753, 0.03320264433568809, 0.0038310228956106585, 0.03424322814680636, 0.08307392548886128, 0.0512615167099284, 0.02427571358566638, 0.061211549982544966, 0.05313962530635763, 0.03452137767453678, 0.04878206440480426, 0.03941268747439608, 0.05292077337799128, 0.02800063997710822, 0.028484648282756098, 0.03872658307955135, 0.06985867250477895, 0.035296836649649777, 0.03575470094801858, 0.04252624188666232, 0.028038125856255647, 0.036689027765532956, 0.05011319532059133, 0.04649328468076419, 0.02867558432626538, 0.04313512581575196, 0.03349338068801444, 0.03306983700895216, 0.028082905191695318, 0.03939962938602548, 0.07491081312764436, 0.0293817434067023, 0.040955241420306265, 0.010579124027572107, 0.0804253265960142, 0.022196785394044127, 0.09513881246675737, 0.03444747831963468, 0.04595076730765868, 0.05896995971852448, 0.008956330002547475, 0.08069753152085468, 0.021011495773564093, 0.008907239716791082, 0.02833124264725484, 0.05689765705028549, 0.019967321823060047, 0.015978749324858654, 0.06630827512708493, 0.030591206632379908, 0.037373120940173976, 0.06748466825229116, 0.02908538528572535, 0.013666297872987343, 0.07854938507080078, 0.015409107381856302, 0.025874806196952704, 0.056027377577265725, 0.023515804459748324, 0.060983629009569995, 0.032865041357581504, 0.030556232923117932, 0.03191476207575761, 0.024402665367233567, 0.049909735535038635, 0.0536470502265729, 0.1191914698574692, 0.12183003491372801, 0.07601046076160856, 0.05191380514588673, 0.0288647410707199, 0.07696228742133826, 0.003884531743096886, 0.05739973108575214, 0.06014044163748622, 0.004877497967754607, 0.04422190831974149, 0.09264961205190048, 0.029009834652242716, 0.13115258974721655, 0.04678379096731078, 0.05691156489774585, 0.010399291440990055, 0.0605365852243267, 0.05205741443205625, 0.04876426770351827, 0.027248829537711572, 0.03186457804986276, 0.04827937809750438, 0.02611147523566615, 0.046132296629366465, 0.04513112085987814, 0.029952464246889576, 0.022647332116321195, 0.03347671947267372, 0.04815069340111222, 0.02624117481900612, 0.0252738150084042, 0.019726674872799776, 0.026500408857828006, 0.009102360545512056, 0.045745173847535625, 0.05730149299779441, 0.02776875779090915, 0.10281218899763189, 0.033341080852551386, 0.07788628354319371, 0.04418502729095053, 0.05438693435280584, 0.07599271601065993, 0.027924074456677772, 0.058336173024144955, 0.06897618470247835, 0.0856439012568444, 0.037508562891162, 0.015380896493297769, 0.08154120499966666, 0.04127924083149992, 0.02306215370481368, 0.05858908953086939, 0.04178667688393034, 0.0542824807780562, 0.009608104501239723, 0.030030753405299038, 0.01638976184040075, 0.025006916439451743, 0.056130832963390276, 0.014276674446591642, 0.04498006041103508, 0.053110562803340144, 0.03343750438943971, 0.037258707743603736, 0.04509409140155185, 0.02832389909599442, 0.017482774674135726, 0.01654442912695231, 0.04835455023567192, 0.06699868026771583, 0.028208849507791456, 0.017481186478107702, 0.012401543717714958, 0.05206794921832625, 0.0089558374020271, 0.04187824306427501, 0.018942016977234744, 0.04836571584746707, 0.024204580586228985, 0.02337245678063482, 0.04382438804896083, 0.029264502627484035, 0.0629512443265412, 0.029388610128080472, 0.05810210706840735, 0.021619370381813496, 0.010624859805830056, 0.040258546578115784, 0.08495058689732105, 0.019884013890987262, 0.05705987940018531, 0.08231372135924175, 0.03174365992890671, 0.03557741300028283, 0.029846602446923498, 0.029264949771459214, 0.037680473978980444, 0.04807737292139791, 0.032455049295094796, 0.04345869107055478, 0.038213477018871345, 0.06885328504722565, 0.03395911546249408, 0.0341232191567542, 0.023866044357419014, 0.03224339619919192, 0.05748864779889118, 0.025064471847144887, 0.0488041432981845, 0.04671632974350359, 0.018325360906601418, 0.0247680339452927, 0.07141845169826411, 0.03260836216213647, 0.028910910077684093, 0.032967498555080965, 0.01093589853553567, 0.05734494574426208, 0.014960196167521644, 0.019768442944041453, 0.020263678088667803, 0.032286206987919286, 0.04918347352941055, 0.023991007183212787, 0.05438255197077524, 0.06151109562779311, 0.04650318493077066, 0.021824965697305743, 0.06492025859188288, 0.04510920152824838, 0.03220769518520683, 0.03011241748026805, 0.043354890585760586, 0.059023732028435916, 0.03388911238289438, 0.04539072782790754, 0.015933914328343235, 0.03883447279804386, 0.04592259538185317, 0.06510128325317055, 0.020546722080325708, 0.044348266383167356, 0.021007790601288434, 0.08940158048062585, 0.046979506441857666, 0.02908853755798191, 0.04084154810698237, 0.024195455880544614, 0.02765022753010271, 0.017135573871200904, 0.020005325350211933, 0.018314490298507735, 0.011692222160490928, 0.0398464022873668, 0.0332128896843642, 0.03695256069477182, 0.03139212312817108, 0.003279182060396124, 0.04625277688319329, 0.025233666674466804, 0.031038758788781706, 0.031808159983484074, 0.02547670890635345, 0.07634067194885574, 0.007053820518194698, 0.04950025555444881, 0.03605542289733421, 0.050644895891309716, 0.06269291014177725, 0.06295340397628024, 0.006682126986561343, 0.04183870885754004, 0.05791638090158813, 0.03730663564056158, 0.028150216130597983, 0.008924061421566876, 0.09253288706531748, 0.07050408123177476, 0.0678525360126514, 0.09156023574178107, 0.07182986126281321, 0.061711041344096884, 0.0637803049176, 0.11034504728741013, 0.08547224249923602, 0.10916720697423443, 0.03595774142013397, 0.0253258692464442, 0.059791791791212745, 0.028020965546602383, 0.06492710861493833, 0.03952495586418081, 0.010109888171427883, 0.054026350771891885, 0.03016869268321898, 0.007705519874434685, 0.025223499251296744, 0.014232587163860444, 0.015689838655816857, 0.07569043184048496, 0.060973491272307, 0.033096027400461026, 0.05841043974214699, 0.0335228476615157, 0.03321839642012492, 0.023952745759743266, 0.04599351130309515, 0.010044613500213018, 0.05664316347974818, 0.07095198961906135, 0.07412599938106723, 0.010378407405369217, 0.10865998614463024, 0.0831472867866978, 0.04315768710512202, 0.027786187129095197, 0.03122150337731, 0.03634365821199026, 0.07259923833771609, 0.05103933253849391, 0.0070607211000606185, 0.09068096886039712, 0.032743343981564976, 0.028140904032625258, 0.030489623313769698, 0.12869360216427594, 0.030450304329860955, 0.08552403698558919, 0.04531665406830143, 0.053143566110520624, 0.06608675146708265, 0.026788274954014923, 0.05022994628234301, 0.025812059466261417, 0.03775108933041338, 0.029627965741383377, 0.036842411136603914, 0.026954885252052918, 0.02720900589338271, 0.036916796598234214, 0.035806380401481874, 0.0752305897185579, 0.014802628011238994, 0.029356135601119604, 0.04415603900270071, 0.004124651768506737, 0.03126192816125695, 0.06172019202494994, 0.06442303449148312, 0.028237236656423192, 0.11821274034446105, 0.018254175956826657, 0.05358783055271488, 0.04579655644192826, 0.014962481982365716, 0.03022984750714386, 0.025181809105561115, 0.06971848080866039, 0.036050825292477384, 0.05695637206372339, 0.045897251038695686, 0.028283765605010558, 0.06587325042346492, 0.0145812852497329, 0.0648071181785781, 0.022859361852169968, 0.028616238487302326, 0.06991942471358925, 0.01664445393544156, 0.037606674814014696, 0.020553961730911396, 0.05487580187036656, 0.003774284314204124, 0.028941221244167536, 0.0426138449984137, 0.010478357071406208, 0.07070050545735285, 0.05472903845657129, 0.02678566444956232, 0.05690968726412393, 0.03698854001413565, 0.023488966544391587, 0.05339321345672943, 0.05401755261118524, 0.113068142964039, 0.12270516803255305, 0.13727104815188795, 0.1537068880861625, 0.31628968426957726, 0.1620841768453829, 0.12076255196006969, 0.13349166110856459, 0.22207558038644493, 0.09836247932980768, 0.23393974610371515, 0.10944622481474653, 0.17877181264339015, 0.1481897325720638, 0.12552847590995952, 0.13236059836344793, 0.1889990083873272, 0.19949836452724412, 0.1497509441105649, 0.15559091902105138, 0.15017141529824585, 0.1875452746753581, 0.20480605628108606, 0.09713163482956588, 0.11048351720091887, 0.1444339903537184, 0.13870141905499622, 0.1438535121269524, 0.1466805604286492, 0.16086120653199032, 0.11851067552925088, 0.11557881371118128, 0.09493272547842935, 0.10216672089882195, 0.1636531957774423, 0.13833904318744317, 0.18709317315369844, 0.12992550793569535, 0.2248318723286502, 0.17384815262630582, 0.08382832602364942, 0.1161015231627971, 0.08118877391098067, 0.10704127300414257, 0.07056803209707141, 0.161639170255512, 0.11281912273261696, 0.1793563726823777, 0.1896648484398611, 0.14218221040209755, 0.0769422716984991, 0.126343977462966, 0.213889142323751, 0.13106808881275356, 0.21326897403923795, 0.16075368417659774, 0.09678824309958145, 0.20735371566843241, 0.0994848292612005, 0.12447422544937581, 0.11379552190192044, 0.20118349988479167, 0.17781888018362224, 0.13122564676450565, 0.14406318368855864, 0.10410964125185274, 0.18844153673853725, 0.332045984105207, 0.16182540479348972, 0.17998986993916333, 0.09413106497959234, 0.22094428015407175, 0.2659341035177931, 0.15644495288142934, 0.2099350982462056, 0.18038512294879183, 0.2075634614448063, 0.29850684630218893, 0.1344017864903435, 0.3201682964572683, 0.1913974218768999, 0.22648985992418602, 0.16621433256659657, 0.15410359570523724, 0.1442272576969117, 0.16182240651687607, 0.18797705619363114, 0.09610649140086025, 0.12023357878206298, 0.08302397895022295, 0.08281029236968607, 0.14113486191490665, 0.18867051898268983, 0.15126740414416417, 0.12125554581871256, 0.15634856274118647, 0.1352078330819495, 0.1712194358697161, 0.05983181210467592, 0.12589515623403713, 0.17016309255268425, 0.13965791382361203, 0.15463749674381688, 0.1913003044319339, 0.2858235128223896, 0.24249808921013027, 0.16234193957643583, 0.207443218678236, 0.11944248646614142, 0.21875040256418288, 0.14088386757066473, 0.1695336028933525, 0.18419953936245292, 0.2416032669134438, 0.11094877700088546, 0.1272581549710594, 0.26728427794296294, 0.2820281102322042, 0.07941168645629659, 0.1537813848699443, 0.14231852808734402, 0.240207806637045, 0.11805461093899794, 0.22076591238146648, 0.1761806634021923, 0.14734904252691194, 0.19072899915045127, 0.14650148019427434, 0.13009029440581799, 0.14623182825744152, 0.15185208292677999, 0.08157926975400187, 0.18663357594050467, 0.09400675524375401, 0.15922542399493977, 0.16899778711376712, 0.1105171958624851, 0.22814036667114124, 0.129403228929732, 0.15779061504872516, 0.12667953211348504, 0.1350914197973907, 0.20056693843798712, 0.23815021704649553, 0.12139943341026083, 0.19023575296159834, 0.11870862115756609, 0.11189600976649672, 0.12820261210436001, 0.16889771592104807, 0.16663459595292807, 0.20809240493690595, 0.15432904532644898, 0.08565069932956249, 0.1483347630710341, 0.10715541531681083, 0.20250620000297204, 0.10726854830863886, 0.23811624152585864, 0.2606165560428053, 0.12960041756741703, 0.2035613261978142, 0.10912136451224796, 0.09983928641304374, 0.11630819644778967, 0.2022189146373421, 0.09455978142796084, 0.1347500318661332, 0.1284424593904987, 0.19745910598430783, 0.0891963840695098, 0.13511683093383908, 0.06159840188047383, 0.11770223180064932, 0.15039483143482357, 0.15285496192518622], [0.03625627403380349, 0.017932844566530548, 0.10508747276617214, 0.03337883019412402, 0.060782859509345144, 0.016159994775080122, 0.043890531960641965, 0.041718091306393035, 0.016340939655492548, 0.024791539617581293, 0.004335695375630166, 0.09198622850817628, 0.018614624095789623, 0.024841736631060485, 0.02163379773264751, 0.0017915958619596495, 0.07519973863963969, 0.020587655235431157, 0.03577672046958469, 0.012767397474817699, 0.008836376673571067, 0.03681841379147954, 0.02308028437255416, 0.06360840125125833, 0.026383273834653664, 0.06976406351896003, 0.030474333216261584, 0.013896838627260877, 0.059013230638811365, 0.010681007915991358, 0.030479496708721854, 0.06379462094628252, 0.035762979605351575, 0.027011193851649296, 0.07081784642650746, 0.08745031096623279, 0.04887613533355761, 0.06269904770306312, 0.03186270783771761, 0.038144876598380506, 0.030390387037186883, 0.021439718693727627, 0.0802616607688833, 0.10004866853705607, 0.005456298940771376, 0.06154274822620209, 0.0346525485656457, 0.021299588224792387, 0.02435629412502749, 0.03231506168958731, 0.06456540810177103, 0.05019247153541073, 0.03077359313465422, 0.04782884250744246, 0.04095622476597782, 0.048575220425846055, 0.03567928019037936, 0.03106810516328551, 0.09692905077827163, 0.035598107788246125, 0.013830245716235368, 0.06374153512297198, 0.03986451440141536, 0.05044874626037199, 0.06880828863359056, 0.023424524006259162, 0.017642334569245577, 0.10237864858936518, 0.07826421482604928, 0.05381980365200434, 0.01925176715303678, 0.0815077118750196, 0.07076870882883668, 0.09124619595240802, 0.02068498419248499, 0.00842427969473647, 0.03166218695696443, 0.03506516040943097, 0.08142508857417852, 0.05854300958162639, 0.03131359648250509, 0.021687714761355892, 0.049007488050847314, 0.005146860930835828, 0.08083401247859001, 0.049298628873657435, 0.05076947280031163, 0.023678303259657696, 0.03204610737157054, 0.04358544247224927, 0.03554377515683882, 0.040090082766255364, 0.05855124371009879, 0.05061562558694277, 0.024181893131753895, 0.030425264267250896, 0.0608005300455261, 0.015497094555030344, 0.0767314423865173, 0.027592794576776214, 0.0954614240617957, 0.0768481896375306, 0.07915436159237288, 0.03402204587473534, 0.052188934132573195, 0.06675721509964205, 0.03802307903242763, 0.06300422624917701, 0.05306868340994697, 0.05807002402434591, 0.020076558539585676, 0.02637396359205013, 0.01900542793009663, 0.06581165958778001, 0.007763289577269461, 0.05340312854968943, 0.04064648201165255, 0.01267640182049945, 0.024231271927419584, 0.07379853414022364, 0.02819608085701475, 0.08748251275392249, 0.023048958319122903, 0.07405756594380364, 0.018197468452854082, 0.031747500543133356, 0.0369205184688326, 0.03173547775077168, 0.020386668657010887, 0.025242392475774977, 0.004612565162460669, 0.0643793516792357, 0.02865345904865535, 0.024222663014370482, 0.01809434332244564, 0.0776288696215488, 0.030956445334595628, 0.010650658714439487, 0.031396446138387546, 0.09116661545704119, 0.029373650286288466, 0.04209733990137465, 0.00904134858501493, 0.0033221099693037104, 0.0711535569280386, 0.05386989862017799, 0.03890279862389434, 0.02331077503185952, 0.04311823453463148, 0.07213403048808686, 0.06030819298757706, 0.01808865476050414, 0.007299189846889931, 0.03728597795998212, 0.024442945432383567, 0.042605833514244296, 0.021043838569312356, 0.05190332230995409, 0.050979986699530855, 0.020009961917821784, 0.037530660338234156, 0.049070032546296716, 0.00557858122192556, 0.04282121590222232, 0.07174900427344255, 0.07112456863978878, 0.02899316601542523, 0.05546966101974249, 0.08498385737766512, 0.01988315114431316, 0.061137669181334786, 0.052913789768354036, 0.020375933490868192, 0.02397927197307581, 0.05460538923216518, 0.07300309283891693, 0.05401414615334943, 0.01890656272735214, 0.06073271630157251, 0.02784857206279412, 0.01555228343931958, 0.07293163143913262, 0.04925135035591666, 0.028476347360992804, 0.018175504592363723, 0.03353560889081564, 0.04302617111534346, 0.05409973062342033, 0.03754154393391218, 0.017644857871346176, 0.01201106550070108, 0.01666293897869764, 0.06284296498051845, 0.010291676317137899, 0.029844025339116342, 0.011010029811586719, 0.014890173606545432, 0.020784498774446547, 0.0378364919743035, 0.039067744655767456, 0.041408144461456686, 0.052738965750904754, 0.020299187999626156, 0.0448158157087164, 0.024533741634513717, 0.024936492191045545, 0.0423905104980804, 0.01395822537233471, 0.05461843618832063, 0.030448545439867303, 0.12737486511468887, 0.037862066383240744, 0.03427812764130067, 0.015010028600954683, 0.08984679487184621, 0.035871848958777264, 0.005710491013815044, 0.04274610684660729, 0.06110797214205377, 0.06656223806203343, 0.007711119378654985, 0.052760517719434574, 0.03166979025991168, 0.026465314549568575, 0.0731655044364743, 0.015064275885379175, 0.055967048392631114, 0.0375545315182535, 0.05059002520283684, 0.022588939937122632, 0.060774621670134366, 0.03176732330757659, 0.028865069471066818, 0.04842991904297378, 0.03960501875553746, 0.03720712105860002, 0.038698418575222604, 0.016863229793671053, 0.03721480228705332, 0.08304343064082786, 0.032660546276019886, 0.11009841677150689, 0.051030252361670136, 0.029589791520265862, 0.05407719530921895, 0.0639204446633812, 0.029056415551167447, 0.041498456412227824, 0.02178153892600676, 0.06415902287699282, 0.02862666380679002, 0.03084469830355374, 0.04777619084052276, 0.06722220030496828, 0.08161710444255732, 0.032649699787725694, 0.07712115155300125, 0.05818336852826178, 0.07488112722057849, 0.044172525813337415, 0.1108048448804766, 0.033975813785218634, 0.01214748430356849, 0.04779646631504875, 0.011144338131998666, 0.037687175572500564, 0.08570551435695961, 0.08001838476047851, 0.06329954907414503, 0.04393493465613574, 0.024206981433962937, 0.024177145241992548, 0.01149155841631, 0.05081361574411858, 0.02151921569748083, 0.05565813684370369, 0.06503865341073833, 0.07083691962179728, 0.13115649344399571, 0.050431238996679895, 0.03489553142571822, 0.04262589005520567, 0.028985822464164812, 0.03350616789248306, 0.07985685631865636, 0.029007723242102657, 0.024161027649824973, 0.10060177635750733, 0.022978760425758082, 0.00812088415841572, 0.017752983221726026, 0.023749668180244043, 0.04543354603811167, 0.03643871990789194, 0.05202059277507942, 0.06320087311905809, 0.057321408530697227, 0.030050179120735265, 0.020903767472191248, 0.026253219875798095, 0.0629126674903091, 0.02100342491758056, 0.03301166376331821, 0.03317419781524222, 0.03247794084018096, 0.04580128763336688, 0.04857379921304528, 0.02774103486444801, 0.014734048927493859, 0.01752827945892932, 0.012685213896475034, 0.12374984478810802, 0.0019672544476634357, 0.049466231794212945, 0.030895874951966107, 0.08420568585279398, 0.07837028257199563, 0.021078875361126848, 0.02981549347168766, 0.07543776024249382, 0.04223627736791968, 0.030945481958042365, 0.06781098316423595, 0.03816766424279194, 0.026359161456639413, 0.026524738314037677, 0.03230646761949174, 0.08518834132701159, 0.021742787685070653, 0.0011723932971108297, 0.011702769006660674, 0.039863241618149914, 0.010439677262183977, 0.040308170282514766, 0.07420500100124627, 0.0305304562789388, 0.03529305540723726, 0.04167273495113477, 0.02339452268643072, 0.0055920934119058074, 0.01862097687990172, 0.004005640967079671, 0.056433265563100576, 0.018299356052011717, 0.023631186159036588, 0.03446747919952031, 0.02593949178844923, 0.059916064419667237, 0.07679381989873946, 0.026910944543487858, 0.016073068873083685, 0.03417232335777953, 0.18874416971812025, 0.08839561414788477, 0.20929204212734476, 0.06148792206658982, 0.10277320398017764, 0.11818912520539016, 0.11613650800427422, 0.1140870300878305, 0.12187211468699388, 0.1060063777549658, 0.1722263966803439, 0.2278354181908071, 0.1074850105214864, 0.1214188702579122, 0.15817589359357953, 0.08707220156793483, 0.13943008932983503, 0.12371271513984539, 0.14490466041024774, 0.13726080651395023, 0.07906405706307851, 0.16239941149251536, 0.09053619811311364, 0.15523053210927173, 0.14813720335951075, 0.14572258136468008, 0.12133174212067388, 0.13283255975693464, 0.17724962322972715, 0.11038745360565372, 0.10962502303300425, 0.14507813000818714, 0.1520689533208497, 0.09044423859450035, 0.26931087544653565, 0.136245756293647, 0.09704950876766816, 0.1411228094366379, 0.14331734011648223, 0.09591815658495761, 0.1073213001654949, 0.10388265538495034, 0.2605089743155986, 0.21962171362247318, 0.1216419153206516, 0.13338234275579453, 0.10825849167304114, 0.08757813106058165, 0.19640679995063692, 0.18815310846548527, 0.12514579488197342, 0.1789323243428953, 0.19835820305161178, 0.12445079584722407, 0.15448033955181018, 0.14785670122364536, 0.08620279040769674, 0.13237084000138566, 0.18686926719965413, 0.12888375524198636, 0.11730167985660955, 0.11917641168111004, 0.18411039258353412, 0.3168505697976798, 0.1717915723565966, 0.20087301498278975, 0.1111568529449869, 0.1674751820974052, 0.19372775073861703, 0.10738833094364963, 0.1850307299173437, 0.19946657092077658, 0.1777939885505475, 0.2097461771336384, 0.19587306218454614, 0.11291463713860139, 0.1559839307446964, 0.2038325514877215, 0.1864750383538194, 0.13531060569221154, 0.11717282075551338, 0.11222702247323468, 0.1503514900105074, 0.11577906741877086, 0.13833586679538712, 0.18886104313423857, 0.15322242892580107, 0.21337097481591627, 0.14192527887644246, 0.08494520632666536, 0.1496133944601752, 0.13210132165113464, 0.12296214408706874, 0.16444318229332566, 0.18137820559786633, 0.18044642434688285, 0.14720248320372775, 0.15513478021603078, 0.11638306430540979, 0.14539652620442212, 0.1679945518844761, 0.2063789640669711, 0.2445491182152182, 0.09906354171107523, 0.18987364426720887, 0.2160099777393043, 0.16553428780753165, 0.12266174497199245, 0.16281860618619248, 0.10810055522597395, 0.1199018387706019, 0.1828520663548261, 0.1754102250561118, 0.21091915637953207, 0.12828099774196744, 0.09935136142303236, 0.09467258787481114, 0.14784399565542117, 0.17850790492957458, 0.15400950622279197, 0.12225963451783173, 0.1338712399592623, 0.15678166528232396, 0.17135257716290653, 0.12768036278430372, 0.1711012117448263, 0.16649738769046962, 0.1826000033179298, 0.13312127004610375, 0.1672055450035259, 0.17143994278740138, 0.14601994509575889, 0.08144701161654666, 0.14786643820116296, 0.151156913198065, 0.14600937691284344, 0.0628692889586091, 0.18205001251772046, 0.06670030721579678, 0.24151459510903805, 0.17479545960668474, 0.08566455522668548, 0.1146633893949911, 0.12844235548982397, 0.17673764523351565, 0.16639333858620375, 0.14802506484556943, 0.0790382748527918, 0.19196166191250086, 0.1462026173248887, 0.22064777731429785, 0.12330264886259101, 0.061330471726250835, 0.1698411934194155, 0.1253728030133061, 0.0796743028331548, 0.1347155962139368, 0.20470592571655288, 0.22402959584724158, 0.1763982165721245, 0.12436174554750323, 0.2016777850803919, 0.12771420471835881, 0.12391948490403593, 0.16044484684243798, 0.20993057114537805, 0.14435668825171888, 0.14839944866253063, 0.24530477297957987, 0.12331126519711688, 0.18168027454521507, 0.16364019335014746, 0.12059935368597507, 0.10546614619670436, 0.08266290184110403, 0.18620139366248623], [0.04191509069642052, 0.02190160728787305, 0.012384611618472263, 0.05722194218833465, 0.058065782650373876, 0.03948588921048213, 0.01766132983902935, 0.067662731744349, 0.013177292130421847, 0.018143998568120878, 0.038334317214321345, 0.052364433504408225, 0.030077093106228858, 0.014244013455027016, 0.07448578515322879, 0.03667988450615667, 0.027516676200320944, 0.06415031748474576, 0.04661313781980425, 0.019909261754946783, 0.06025294751452748, 0.07273403462022543, 0.02885624719056068, 0.062321999575942755, 0.028910589098813944, 0.015245586273522349, 0.04633333330275491, 0.06139413315395359, 0.050597339068190195, 0.06473004614235833, 0.022913200955372304, 0.03300776006653905, 0.041155814251396805, 0.041645932287792675, 0.028146520235168282, 0.060549008776433766, 0.06190119813254569, 0.08647252398077399, 0.005496367029991234, 0.047160341855487786, 0.043851112786796875, 0.042102379084099084, 0.06358754690154456, 0.09296584117691964, 0.035279069634270854, 0.05349474668037146, 0.02988765434565721, 0.03254875657148659, 0.01733888337184908, 0.0424376739829313, 0.06427399639505893, 0.031738457473693416, 0.09370093102916144, 0.06052652170183137, 0.011609781613515224, 0.01532852313175681, 0.020912120344291907, 0.042021110202767886, 0.02948771281808149, 0.09797791324672289, 0.03218044723325875, 0.10170889741857536, 0.00961482001002878, 0.12820868287235498, 0.11944740690523759, 0.0644289939373266, 0.06459982148953713, 0.09483733723754995, 0.03197267185896635, 0.03249720328312833, 0.02861307508283062, 0.014667171217297437, 0.059220148832537234, 0.024183013774745632, 0.06147896063339431, 0.02175161924242275, 0.020669098521466367, 0.0670143766910769, 0.030304915744636673, 0.08299960682052188, 0.043014218827011064, 0.05889072061108891, 0.022740976310160477, 0.014724452958034817, 0.09106587633141316, 0.06249582540476695, 0.05680785347067285, 0.03662892493593972, 0.019988031453976873, 0.04612771015672479, 0.01082730841517332, 0.04463747020054143, 0.028882875449198764, 0.05841960897669196, 0.04240965790813789, 0.018912396008090582, 0.07891848479630426, 0.039959409114089794, 0.06339539744658396, 0.09771979428478517, 0.08134236879413947, 0.03314298308396246, 0.011533331125974655, 0.08135209835018031, 0.03094405332376482, 0.02690006651391741, 0.013965994730824605, 0.024844263643899467, 0.03741599110071547, 0.036842871268163435, 0.04644850348995533, 0.044615272563532926, 0.04399574623676017, 0.08497561211697757, 0.027992094146611635, 0.015056113188620657, 0.0738806527806446, 0.02427512728900183, 0.03107588658167515, 0.04193807872070465, 0.03325058707559947, 0.043215058831265196, 0.03468196729954798, 0.034592865049489774, 0.022789987742726225, 0.011050663324567722, 0.0766969176765997, 0.051341679791221395, 0.06760377553291619, 0.02927075336629059, 0.024862086320354138, 0.04236257234879304, 0.05964111725916155, 0.015901942606433295, 0.023596570536028594, 0.07706912700086832, 0.06657245743554085, 0.012676051155722234, 0.009776957940630382, 0.015889953210717067, 0.04914647375699133, 0.011012226568709593, 0.038188013932085596, 0.037653875406249426, 0.03613607579609379, 0.036959362478228286, 0.013544176545110531, 0.012239942916494329, 0.03993862155766692, 0.03658190616988577, 0.05713053928047884, 0.04819053930987138, 0.03500011487631127, 0.04505066463025287, 0.023648468923056498, 0.0628324413264636, 0.11585505591938272, 0.02863641748263035, 0.0102810970020073, 0.0021541026490012882, 0.04785823155543767, 0.03897004833561368, 0.035706713679246604, 0.08916021921322681, 0.06135634299425874, 0.06098197030951269, 0.028400646442605648, 0.02983399335789727, 0.011015710024366854, 0.020518353485385887, 0.03290657936304342, 0.045022362828603946, 0.03663689560198691, 0.05276862568280194, 0.11242880500503816, 0.04107420769287273, 0.024312002751685213, 0.015828429168323055, 0.03472691918432247, 0.045503103829105385, 0.0732732865435537, 0.01184050790470792, 0.09993994390242733, 0.02129382915882161, 0.07266977205290459, 0.04001570472610183, 0.02536170941311866, 0.04417759468196891, 0.03539173507306259, 0.09868054898106493, 0.05092401021101978, 0.0335457095206948, 0.008259980259026634, 0.036728792038047686, 0.052391618373803794, 0.054157072663656436, 0.039113290258683264, 0.0647325323370751, 0.014380547290784307, 0.03680289177282248, 0.017091727786464617, 0.011008445326297078, 0.02948652909253724, 0.04879960877588019, 0.06934542543604039, 0.04957357232342474, 0.014017921876074979, 0.013755604213656625, 0.016712017204554286, 0.02055177425063448, 0.0219213372838567, 0.0840461983170826, 0.05236205121036619, 0.05095014123071451, 0.04469371757295448, 0.04441270335519221, 0.0057691740221343935, 0.011059891003242228, 0.10261074043228291, 0.03894539790053386, 0.03376226079126354, 0.06286902178544551, 0.08585014409618452, 0.02365314259805018, 0.021854677579540294, 0.020292117187636904, 0.049855833349283785, 0.027557969297049567, 0.019882184496964328, 0.03351721476064995, 0.020336508750915527, 0.03811467860941775, 0.08515815818100236, 0.019457117559795734, 0.04272939739166759, 0.05862660509592388, 0.028111199571867473, 0.05626595208013896, 0.017967671701626386, 0.01302012844462297, 0.08303373077069409, 0.044672993099084124, 0.08316074192407541, 0.022905866680957843, 0.06897789164213464, 0.040885561174945906, 0.051893444324377924, 0.0606828105810564, 0.13109931838698685, 0.042671636037994176, 0.0633279510657303, 0.0334490150999045, 0.04401855985634029, 0.10789647203637287, 0.031018696681712754, 0.04612304946931545, 0.009968116628442658, 0.05058548696979415, 0.0359232315531699, 0.029666856135008857, 0.038417790274252184, 0.037683824775740504, 0.017696175527817104, 0.038926925844862126, 0.020465391971811187, 0.010138197394553572, 0.022889840001880657, 0.04279546337784268, 0.03296538343420252, 0.024012995163502637, 0.03888181810907554, 0.035915101325372234, 0.06382455918355845, 0.03265369625296444, 0.05890203465241939, 0.040811290746205486, 0.050487044791225344, 0.033810678505687974, 0.028413578365871217, 0.055638533012825064, 0.0979815868777223, 0.08732717382372357, 0.044261372022447176, 0.047003373911138624, 0.005089836158731487, 0.039915585293783806, 0.03499213307804894, 0.020359264854050707, 0.08054796649958007, 0.02303764056705404, 0.009181407622236293, 0.028434942942112684, 0.04500321541854646, 0.09047490413649939, 0.018651102509466, 0.07097790541592985, 0.05469039111630991, 0.03354199507157318, 0.0644636077049654, 0.016830150416353717, 0.06812929772422649, 0.024565930434619077, 0.03435562270169612, 0.04596545441017952, 0.061699990765191615, 0.04908814837108366, 0.013621354337374214, 0.07424223455018364, 0.010154603496630443, 0.06834490646724589, 0.021704607897845563, 0.02430518241453683, 0.0370629811368417, 0.05202344633289613, 0.027539985203475226, 0.04333436649176292, 0.040195029869209975, 0.05195933219511062, 0.044574428466148674, 0.027159601122548338, 0.04936146280670073, 0.016319124224537518, 0.044834918589913286, 0.052457706624409184, 0.042258645698893815, 0.03573431786207948, 0.03804089799814392, 0.06971630631596781, 0.02488710597390309, 0.029349261458264664, 0.08595578881795518, 0.05089740050607361, 0.03484500230115373, 0.01449435563699808, 0.030182153386704158, 0.019562086927180644, 0.023902767679828685, 0.02487011264747707, 0.07518438360420987, 0.044030077988281846, 0.04352204821771011, 0.02152667428163113, 0.010232555905531626, 0.06758001938578673, 0.03977944201324135, 0.00588066222917405, 0.013228732241259422, 0.03848788241157308, 0.04043341883516405, 0.045108177364454605, 0.103274190769298, 0.020556587078317534, 0.13708230515476316, 0.14066524570807815, 0.1347068982431665, 0.09855802039965056, 0.09005037340102717, 0.09845127729931846, 0.14547492668498307, 0.20741994492709637, 0.09384534554556012, 0.13604499050416052, 0.1504466333426535, 0.13987420534249395, 0.13022863073274493, 0.14695705496706069, 0.13078475167276338, 0.15970117034157738, 0.16814399074064568, 0.25957107776775956, 0.2601105300709605, 0.10692112671677023, 0.14393342658877373, 0.16068956261733547, 0.11320613048155792, 0.18970183708006516, 0.12776759482221678, 0.09137915170867927, 0.18490137357730418, 0.11106709760497324, 0.20643290336010978, 0.19550874189008027, 0.12399066428770311, 0.18736570462351665, 0.18718674313277006, 0.14309260295704007, 0.07927972517791204, 0.1907106681028381, 0.21630527829984203, 0.15946644387440756, 0.09494390964391641, 0.24898389587178826, 0.10665485897334293, 0.1553010509815067, 0.18303954770090058, 0.18782113096676767, 0.13494190672645345, 0.11661282580462284, 0.12154618569184095, 0.08452051974018104, 0.10844466683920473, 0.1289285661187023, 0.11041241203201935, 0.17510141740785912, 0.16546281898627058, 0.18000741431023926, 0.13013651536311954, 0.07765204689349048, 0.14147905516438186, 0.11420689435908571, 0.09933615481713787, 0.22504740685690194, 0.17955847433768213, 0.161924006533809, 0.1013095625967253, 0.22017504408722743, 0.28819476370699704, 0.17602295702090487, 0.16612647712463513, 0.1379398419521749, 0.23108565394068137, 0.07359128940152004, 0.16536580544197932, 0.1492835395038128, 0.3628175047924742, 0.20118363347137347, 0.20918866095598787, 0.20205467735650018, 0.10421447703265585, 0.19064149993937463, 0.23964451655047014, 0.19383494654903188, 0.15127400925848633, 0.2684654504992068, 0.15127075865166262, 0.14553688117302954, 0.2253987840958871, 0.20047663390869275, 0.11617639102041721, 0.12345012102741748, 0.1094496832229197, 0.11479533583042212, 0.19946692715166137, 0.14710676099639386, 0.11420063805417158, 0.09238539263606071, 0.1418629236286506, 0.09300277044530958, 0.1717907708371058, 0.17046465683961287, 0.13735203130636364, 0.19044073414988816, 0.22088961355620995, 0.12410917042871006, 0.14414207398658618, 0.18174037366406992, 0.156417760590557, 0.20914993569022045, 0.1611169654643163, 0.13596549164503813, 0.08257666428107768, 0.12653923651669174, 0.21575476799625903, 0.2536275435704738, 0.17094547947635874, 0.2548596274573356, 0.10910875542322174, 0.13141600764356554, 0.16046956036007032, 0.20899797353195027, 0.19247156189521775, 0.1816273742588237, 0.15392786997836083, 0.11585518950596452, 0.24301443103468046, 0.16203227103687823, 0.1854152960004285, 0.14165786822559312, 0.2533541957382113, 0.18181638442911208, 0.24130965844960883, 0.11161083952174522, 0.11366646242095158, 0.15526671922998503, 0.172059012693353, 0.14881864335620776, 0.21845262323040515, 0.13313833944266662, 0.166513106378261, 0.10018226254032925, 0.11019413155736402, 0.15204934577923268, 0.10524221797822975, 0.1918614422902465, 0.18288341467268765, 0.15210404206300154, 0.06774522888008505, 0.08593290840508416, 0.11440400136052631, 0.15836101491004229, 0.1639883645111695, 0.17003774381009862, 0.21322511311154813, 0.12008060730295256, 0.10202131932601333, 0.15463528514374048, 0.13729368365602568, 0.13861706655006856, 0.23706929379841313, 0.06187611725181341, 0.1246531869401224, 0.11697805894073099, 0.10622745612636209, 0.20378686487674713, 0.136235841200687, 0.15229857381200418, 0.11684938537655398, 0.12492516922065988, 0.09287667213357054, 0.1367998734349385, 0.0897296988114249, 0.1698644523276016, 0.08626862632809207, 0.12284307391382754, 0.13103832869092003, 0.19866236485540867, 0.27795894420705736, 0.05446991388453171], [0.0344108013814548, 0.05117497858009301, 0.020232708266121335, 0.07780792017001659, 0.050952616293216124, 0.05431943231087644, 0.037220275626168586, 0.016980496548058, 0.0365423942275811, 0.055828493132139556, 0.0351676918216981, 0.05327905630110763, 0.036567775678122416, 0.07085433782776818, 0.006577271724381717, 0.04402382910484448, 0.0399566854321165, 0.05485389738169033, 0.028708832542179152, 0.03320768351841252, 0.04105300082301255, 0.05661606766807381, 0.023245115371537395, 0.033516877083457075, 0.024407491182500962, 0.03235630283597857, 0.03348203325003851, 0.03908374535967596, 0.10142008322873153, 0.04221054339723196, 0.031571830477332696, 0.0398092652176274, 0.09622883444535546, 0.027435834053903818, 0.039891279957373627, 0.04192532862361986, 0.02615047324070474, 0.03435782688029576, 0.04874749887676444, 0.046786874590907246, 0.10960585335851647, 0.040825599353411235, 0.00925608344914508, 0.015574961616948713, 0.0396889556577662, 0.0261647799925413, 0.05953422201855574, 0.056699225315242074, 0.029432224291667808, 0.0946681275672745, 0.05129855730046984, 0.02791926348436391, 0.10737861623056233, 0.04553103826765437, 0.10800977572216652, 0.034003792752628215, 0.04976733966032043, 0.06904700785526074, 0.06961493636481464, 0.06079283768485766, 0.05026234473916702, 0.0629200370167382, 0.04545448573480826, 0.11880696314619854, 0.0111948357152869, 0.012956429909536382, 0.03516660086461343, 0.050349714074400254, 0.0794834818225354, 0.02592995519080432, 0.001997939007196692, 0.034293382486794144, 0.11936820490518585, 0.05388170247897506, 0.058920243245665915, 0.031245849531842396, 0.056542491147411056, 0.042345792389824055, 0.009325773899035994, 0.038994001151877455, 0.019842678120767232, 0.06932463045814075, 0.03259191616962198, 0.019233170787629206, 0.00990205249763676, 0.10215704329311848, 0.06011826255416963, 0.09387415571836755, 0.03571488843590487, 0.04129006134462543, 0.02427853374683764, 0.02697351130336756, 0.008674281416460872, 0.04272384612704627, 0.03528990127961151, 0.06779372080927715, 0.05119237823237199, 0.037215685442788526, 0.035083179755019955, 0.08661480111186393, 0.023991834677872248, 0.02496936562238261, 0.044722019374603406, 0.07616205926751718, 0.030887531356711406, 0.0654152562492527, 0.03190280607668683, 0.08708968656719662, 0.02615058456285624, 0.09755609135027044, 0.02377414235525066, 0.039463405846618116, 0.07953290885780007, 0.03573993220925331, 0.009730172951094573, 0.005477855083881877, 0.04027574585052207, 0.007424946770697716, 0.020901340649288613, 0.011165116411575582, 0.05510717383003794, 0.008245554763561813, 0.0705819547874853, 0.05877011048141867, 0.014298365567810833, 0.024024789745453745, 0.07268068904522806, 0.05304296799295116, 0.0714646652340889, 0.04915755402180366, 0.03184825080097653, 0.03430966149608139, 0.00692697542035603, 0.039006198348943144, 0.016298151131195482, 0.045853445772081614, 0.023021289198368322, 0.016019179674913175, 0.06789718361687846, 0.045817848658771254, 0.04010342658148147, 0.03212879746570252, 0.07161544737755321, 0.0490918145806063, 0.031877899600658566, 0.03677314649394248, 0.039672331549809314, 0.022079041809774935, 0.058829296758631244, 0.007682936784476624, 0.008640640789963072, 0.030254859739216045, 0.012457499797164928, 0.011350449240126181, 0.044225841702427715, 0.013376001243159408, 0.01771650666341884, 0.06114222967880778, 0.01193635442177765, 0.025636068421590608, 0.031919177854433656, 0.030868879330228083, 0.02369387908402132, 0.04819362293346785, 0.03421109686314594, 0.029623084265040234, 0.03466792215476744, 0.019296698628750164, 0.011104091463494115, 0.02167758073483128, 0.0858372455695644, 0.0355505954939872, 0.02588192710391013, 0.029365182381297927, 0.0035488191542754066, 0.08331812918186188, 0.04643538974050898, 0.01995214490307262, 0.04317124614317436, 0.053601289400830865, 0.03624388016760349, 0.05170857533812523, 0.04899783270957414, 0.07282246893737465, 0.04629014772945084, 0.022276664603850804, 0.06592852558242157, 0.030333197137224488, 0.0710232877463568, 0.08268892153864726, 0.04745963145978749, 0.052240160875953734, 0.023743152123643085, 0.07371162122581154, 0.038548901793546975, 0.010255008655803977, 0.05092773579235654, 0.05212448973907158, 0.037800108184455894, 0.07278995544766076, 0.038554330603801645, 0.038879873682162724, 0.0286500396032352, 0.06315568374702707, 0.0943876922247, 0.04408580585732125, 0.06011957986629568, 0.01664471554249758, 0.030270619245129637, 0.007922069289634237, 0.06877516658278182, 0.013285322856972925, 0.03748226859897841, 0.048543100274400786, 0.044553715124493465, 0.019228955388825852, 0.11006926521076821, 0.06868233875138685, 0.027247454709140584, 0.04844974922889378, 0.03545728155586403, 0.026102246629307047, 0.04304441681597382, 0.005713751825169311, 0.046731332258787006, 0.023267838078027125, 0.05067320882517379, 0.021474638597283047, 0.005737374849559274, 0.0979741060291417, 0.011189438446308486, 0.029435608485073317, 0.09733539147418924, 0.053386278086691163, 0.022512079412990715, 0.07989391917362809, 0.08165929553797469, 0.03306644539406989, 0.028375509900797624, 0.05020743694331031, 0.02578806768724462, 0.027307982418278698, 0.02971210858959239, 0.03535834213835187, 0.02898667036788538, 0.0633514326182194, 0.045046081868349575, 0.1113712890946772, 0.03853250775136985, 0.06897847051732242, 0.06713413706165738, 0.11427323493990116, 0.003983385813626228, 0.012126052006351529, 0.003018796069227392, 0.05722793132008519, 0.0859004320227541, 0.05697171225619968, 0.008395426848437637, 0.025419736084586475, 0.016978667154035065, 0.0270228344379575, 0.0035303104550621356, 0.09831717863562517, 0.02924036241893191, 0.04853597936744336, 0.06812068138970062, 0.07024166523478925, 0.06910358177265152, 0.023233602805703413, 0.00839765050841379, 0.01602420958079165, 0.005601975108220358, 0.03154928774165455, 0.040338360850000754, 0.015289984330593143, 0.008466359468002338, 0.0381085150729632, 0.0367052845103899, 0.07822074723662809, 0.01645731768803671, 0.06060262894607149, 0.0064982756703102496, 0.12105564834200777, 0.00454710309895745, 0.0313951288262615, 0.017707595325191505, 0.0418401337810792, 0.06933933982509188, 0.033300752547802404, 0.07312820409424603, 0.05659222988469992, 0.03853327958495356, 0.04106120526557788, 0.012525021320470842, 0.04470640458748676, 0.03788479465583805, 0.006211214804352494, 0.0740602302539628, 0.027228670951444656, 0.03830241970717907, 0.034436372079653665, 0.07573403301648796, 0.034184479736723006, 0.05154772225068882, 0.07708999619353563, 0.014882907053106464, 0.012529711693787249, 0.04476464833714999, 0.0381704621395329, 0.038343761043506674, 0.036470736158662476, 0.054794295501778834, 0.029263743781484663, 0.014806028902967228, 0.03017477829416748, 0.019505843265505973, 0.017013321739796083, 0.01510926209448371, 0.04204512981232256, 0.010075248428620398, 0.04914057739370037, 0.024797818186925724, 0.036099896096857265, 0.08015050188987516, 0.053360644305939786, 0.0035335258098712075, 0.01980443710635882, 0.014849852723273216, 0.03873567809932865, 0.06718064745655283, 0.09921242395648733, 0.01006661446808721, 0.04856337945966516, 0.08213714958401397, 0.03740851767361164, 0.008929463328968268, 0.03655181950307451, 0.00794873743870994, 0.045186960051069036, 0.033059740089811385, 0.022638324298895895, 0.06252428676816635, 0.04681225975218695, 0.03208601636288222, 0.006189850228111027, 0.032707654099795036, 0.06274272309383377, 0.062140856171026826, 0.06765922880731523, 0.034375230243313126, 0.03861005105136428, 0.1839168553124182, 0.18774563970509917, 0.09210903910570778, 0.16731150884879753, 0.08610827790107578, 0.1088053802959621, 0.13365971302846447, 0.15160426497459412, 0.10328441014280543, 0.20891045947792009, 0.1799268912873231, 0.09090924606425688, 0.21236039232462645, 0.2592392190126702, 0.09510862932074815, 0.12803353602066636, 0.13007307657971978, 0.18309912731638178, 0.1770100579597056, 0.1640020645572804, 0.19447841827059165, 0.1832186130923219, 0.07699644105741754, 0.1943426497746259, 0.13412437168881297, 0.08524102639057674, 0.12657579471124336, 0.20557441661367193, 0.343249564175494, 0.15857263089856133, 0.12838105409173295, 0.11612359463470057, 0.15575392433675006, 0.10558931302512065, 0.11324084814987145, 0.10425502798170783, 0.14185306790750474, 0.20621002156985924, 0.13051544112386182, 0.08777260343777016, 0.15752445120597258, 0.22356806905008852, 0.16219251556321979, 0.15944030543323606, 0.1496208307798952, 0.07708022210863419, 0.07984597643371671, 0.11454591483925469, 0.14890480670146644, 0.2375475040753372, 0.12938442290760577, 0.08885118892067112, 0.16008429665816948, 0.22179846244398504, 0.1640564639819786, 0.1125897619931493, 0.1816129617509432, 0.18706998846028, 0.13793489924864843, 0.19840874330839142, 0.14589953905669972, 0.15326924360124394, 0.083410348452162, 0.27029202436096966, 0.12060446708346717, 0.11023092723917216, 0.14398795960005373, 0.1040255484986119, 0.17330306000076234, 0.13433957967208698, 0.10846801480511203, 0.3107477707089856, 0.30291089904494584, 0.17368446453474462, 0.22140911692986265, 0.16667755146045238, 0.18749961775029078, 0.07893955436884426, 0.11379357747500762, 0.18870352971134707, 0.15970489592291415, 0.11469153163488954, 0.2374541715835221, 0.07894238937296905, 0.1016455476928968, 0.21159612864721566, 0.17060544225387275, 0.13484640716342255, 0.15976447553839535, 0.09210904652718455, 0.19185519340680912, 0.14053522143512964, 0.1718691416317597, 0.20712118595838547, 0.09391161933308467, 0.16464053420349956, 0.24432227335637435, 0.13462772592902184, 0.07612737870658748, 0.13127759710187092, 0.19515078922268003, 0.07607047824421898, 0.13659371965331957, 0.22011798777384683, 0.1562592526897788, 0.20316320849815384, 0.07958688525832258, 0.24841797858243808, 0.08794157562078908, 0.13826876180246472, 0.0818040143349208, 0.1028776315797586, 0.3279945702524856, 0.14181734091835096, 0.17743395786965266, 0.18347263539908454, 0.11837682177429087, 0.0971394644875545, 0.12003160329186358, 0.21116770163644105, 0.15124991914490238, 0.06176850583869964, 0.2092213006108068, 0.18945381132652983, 0.19539802829967812, 0.11632364796241745, 0.15543514222372323, 0.08157355521689169, 0.10103000298840925, 0.17958474636543542, 0.11389083592803217, 0.10459879820700735, 0.11990123763098381, 0.16820775606902316, 0.18325640325201675, 0.20542609097901732, 0.08964306791312993, 0.17199667228851467, 0.22163510089740157, 0.13957535731606185, 0.11829049515654333, 0.09450415745959617, 0.12443563377019018, 0.17010355746606365, 0.0842332789034117, 0.12106365611543879, 0.14763343351660296, 0.11208883457584307, 0.1455572308623232, 0.21349161834223196, 0.04657380770368036, 0.058311923348810524, 0.07582271224237047, 0.16199302626773715, 0.1278526894748211, 0.1514782482990995, 0.09595097435521893, 0.1752639774349518, 0.10423808475024998, 0.15273577300831676, 0.06758707721019164, 0.11350225482601672, 0.09671416191849858, 0.13524195703212172, 0.1284345777821727, 0.13241050037322566, 0.13618905621115118, 0.12986569083295763, 0.11551029121619649, 0.07025679762591608, 0.10298632652848028, 0.16451500734547153, 0.13853896292857826, 0.17251112905796617, 0.10319225024431944, 0.2558291098102927], [0.04686307831434533, 0.04662376537453383, 0.05947523612121586, 0.05679092137143016, 0.03607573547924403, 0.01582736789714545, 0.04046741290949285, 0.02262667072500335, 0.05052555112342816, 0.045695149383391254, 0.022851522917335387, 0.0811728993721772, 0.05475485035276506, 0.02399004795734072, 0.0409639319695998, 0.027108426329505164, 0.07303919832338579, 0.020356569002615288, 0.023605543101439252, 0.05791318595584016, 0.010467978136148304, 0.04194513654510956, 0.016460297410958447, 0.022012999943399336, 0.03981635643867776, 0.02946767483081203, 0.06307836680207402, 0.03557557247404475, 0.02028772923949873, 0.004888469229626935, 0.005295701894283411, 0.04054709730553441, 0.033550592852407135, 0.0312296039192006, 0.0848193974525202, 0.021504105570784304, 0.09190140102873556, 0.04311437165597454, 0.040485205900040455, 0.046725042557227425, 0.0441067752399249, 0.03952077015128452, 0.02637462595885154, 0.03616589900047984, 0.03257129188568797, 0.112457125360379, 0.06789883118472062, 0.0297312949624029, 0.03002709461725317, 0.04262538539478555, 0.07315859504160471, 0.014114030000200728, 0.04954233532771468, 0.049784568618633784, 0.03246455620683264, 0.05312675275490619, 0.021168190978642087, 0.03723346730112098, 0.03886437763867434, 0.031694032513769343, 0.007146529142119107, 0.053045071981614456, 0.029335355466173496, 0.031771152789588086, 0.05735689432185609, 0.011621734829532215, 0.009092952896025963, 0.04214974665956106, 0.03470642106549349, 0.022722441171936225, 0.04611429954820778, 0.0700961597613059, 0.005240643813522183, 0.03353420994244516, 0.02209191065048799, 0.03820805563009344, 0.04447990111657418, 0.11582285413169302, 0.056100891015375964, 0.004224523509037681, 0.06494230037787929, 0.036349391302792355, 0.02155900037905667, 0.08250480212154798, 0.041403632203582674, 0.06644245542702265, 0.022074026746849995, 0.030131579733279068, 0.03703152891830541, 0.10079546205815859, 0.012558441158034839, 0.016950424724200275, 0.015318364985432709, 0.036242759524611756, 0.06342034102999605, 0.04513296880759299, 0.03123236099781934, 0.05462250315758865, 0.041286064879386686, 0.03421613233513199, 0.028709938342217356, 0.15019633661722764, 0.03406216266739648, 0.042456075534573756, 0.02905290890339529, 0.025270863116020337, 0.08058822801103815, 0.10073987519717775, 0.08034245838643983, 0.05650209976010956, 0.05258370474621188, 0.05637220907374285, 0.07782398024573922, 0.059536938279052265, 0.08137150551192462, 0.03571579385607038, 0.049217267223866656, 0.01832188580010552, 0.02450617826980306, 0.06208724713360425, 0.005918637461945764, 0.04181809570582118, 0.061070144874975085, 0.020272888141334988, 0.017980232551053632, 0.05823166007758118, 0.04314761245041154, 0.05609419313259423, 0.01296552678468288, 0.04568173877487425, 0.025561538241163362, 0.024708931159693748, 0.02647936526045669, 0.039080528149497695, 0.08929163872380741, 0.0445915757882176, 0.12253109729499556, 0.07253758070874028, 0.061756338327541016, 0.007178375626608613, 0.014514220147248125, 0.023976822885742877, 0.03856519564578775, 0.011949530326091917, 0.029352474957704544, 0.016898338944884017, 0.052830784261459485, 0.05323636796674691, 0.08292732905829325, 0.02086468226480065, 0.014885939654050162, 0.0806819018907845, 0.006132677954155952, 0.017722571865306236, 0.06686003223876469, 0.056467875620000996, 0.028455357569328044, 0.027723846724256873, 0.047091715459828265, 0.06271172358538024, 0.037431817399919964, 0.04223033647576813, 0.10211057000560686, 0.038630723574897274, 0.012035484014631948, 0.035748693262576126, 0.02761704981821822, 0.029487846404663287, 0.03384460578672588, 0.03305886435555294, 0.04345391163951717, 0.05182781249459367, 0.07925998404971324, 0.07136337691918015, 0.017520479486847762, 0.04959373647579923, 0.016773815841588657, 0.04863745693000965, 0.015522092871833593, 0.10571013466687873, 0.05832895934872795, 0.026776259583130013, 0.030720457216375507, 0.03020746989932377, 0.034434453627909534, 0.01942603827046696, 0.0541194346442353, 0.11053542300942354, 0.021315895064617507, 0.06496198213426396, 0.07165026894654147, 0.017880155792227015, 0.027378293489164207, 0.07914994581369683, 0.042549003555905074, 0.022101979739090893, 0.008818115202302579, 0.026441409972903784, 0.03300619042420294, 0.01804054503736552, 0.040088108653435484, 0.03195615536242258, 0.051740506241912954, 0.07407100623822771, 0.012101736465410795, 0.04325636306020897, 0.03436258033616468, 0.016002778211259283, 0.01295383424803731, 0.027742161073547322, 0.02584015717729926, 0.10454576433403417, 0.05239666126726661, 0.02532487105781911, 0.024789096096355934, 0.038481355222756974, 0.11363584140781313, 0.0474722887884127, 0.03344946038851049, 0.043316091105225496, 0.043684875417966396, 0.0692037123371847, 0.02505761254724348, 0.01083372242646874, 0.07313854221138172, 0.05136179199325852, 0.031153236923273653, 0.008194497786462307, 0.019636906545201782, 0.05240427941316739, 0.05040690768510103, 0.047088008432183415, 0.03386700751434546, 0.00957960788582568, 0.030755100669921376, 0.029670915682800114, 0.060659347582259215, 0.010588705154077616, 0.05332954089681152, 0.0075262304471834796, 0.0051923304636147805, 0.025805365294218063, 0.025838197907432914, 0.032241381268249825, 0.0908366937073879, 0.05346823716536164, 0.055691013985779136, 0.02069567854050547, 0.03379328998562414, 0.08022381123737432, 0.04796690423972905, 0.038203769727260806, 0.05642067131702788, 0.10516923517570831, 0.07159996617701836, 0.04749604864628054, 0.04324252200603951, 0.01046562645569793, 0.01710581189399818, 0.04396946678753011, 0.07747943076537922, 0.08281210321001709, 0.05142583933775313, 0.020241443344275467, 0.0042400232632644475, 0.04545881245576311, 0.04419895740284119, 0.04106266729650088, 0.02895435169193661, 0.04175323942035902, 0.035087150245090015, 0.038677293341606855, 0.05695533305697609, 0.03638964168203529, 0.013889117508369964, 0.027164070706930943, 0.04416016905452125, 0.014210034223651746, 0.07845115440431982, 0.0360266312782187, 0.016404294947278686, 0.01480383492889814, 0.040840416331775486, 0.060813213349319994, 0.07253404066432267, 0.03552252375811804, 0.028120014430896845, 0.06533101506647654, 0.03241065402107779, 0.021621617233904544, 0.05630933061183896, 0.06325660840957426, 0.031696526129962876, 0.03900225754478015, 0.048606216223561205, 0.1293080855975859, 0.03887882354320027, 0.025523967015033122, 0.027123733125336003, 0.06385823042364791, 0.020935520260536578, 0.052483125182334334, 0.05180876156373415, 0.055983505517360754, 0.01654532527027186, 0.05620281757728662, 0.026965505385305732, 0.02205217235314194, 0.070169439422898, 0.04042593798658345, 0.012341789697529748, 0.035343324780114926, 0.08547835779609159, 0.07977898276294582, 0.04512885359872598, 0.03307731785753276, 0.04244508432748262, 0.12251992055098526, 0.05570517787418794, 0.014520087752316613, 0.0467266641499009, 0.011252035819779849, 0.014354181566886837, 0.03652409286587499, 0.06273893071920611, 0.02010038704611361, 0.04078775724337902, 0.034361170255579054, 0.02855143971828511, 0.013580576105596265, 0.08601804016507231, 0.007692022991250269, 0.025530416278343182, 0.020723356938106008, 0.032419897470390424, 0.014596059554605745, 0.023218162423290778, 0.027102047570224386, 0.024371647305088118, 0.07287350643309765, 0.006926515752638807, 0.06191971100633964, 0.029759934441244695, 0.06201663920364808, 0.015373034366348293, 0.023241488124767784, 0.03031761574675329, 0.029869230529584456, 0.05354330540285446, 0.03263057835283689, 0.037101372436154634, 0.08121285660308786, 0.12787266809027642, 0.1534270984120667, 0.17533822188852355, 0.22668163088383153, 0.12036385538522154, 0.15192810853477567, 0.09037285883096047, 0.14537009090417996, 0.16718748112907633, 0.2160979964537546, 0.1185591600369662, 0.29754392453469336, 0.12526220816653222, 0.1244076770672109, 0.2060018343036063, 0.08904868926038034, 0.1344750661519356, 0.11468534212326631, 0.09103198244702071, 0.23046864720527083, 0.1429701189044863, 0.12215180788189173, 0.11009497320628725, 0.08893094011000358, 0.144116529263556, 0.17007131857099012, 0.16004782752133906, 0.19247430784162134, 0.1352077885530889, 0.11520261905388907, 0.1062107874895446, 0.09653485903982073, 0.11644705227809027, 0.11656638962449506, 0.16347757395124063, 0.1459699688712135, 0.1490102510433644, 0.15658051357604563, 0.20290381304221228, 0.1240045424492564, 0.18114111910108477, 0.15004023327492177, 0.08325489077833481, 0.11857516816235147, 0.12265552577446215, 0.28220174310263246, 0.19422625133302063, 0.19140086544211954, 0.21462138975039124, 0.24795502686174586, 0.19238078239141032, 0.15267384820617735, 0.1485397294163704, 0.14203299419023097, 0.11485009148600511, 0.14032927545486018, 0.10192473622737452, 0.10782886980450712, 0.14575654204236344, 0.13132745458278805, 0.12275308108655736, 0.12182785299955867, 0.2199578026193194, 0.14003672084072605, 0.16143144312081859, 0.1141563689452596, 0.08592484125983901, 0.14563396893208846, 0.15979566058376804, 0.13657676900038496, 0.1571852748747915, 0.10787880150019191, 0.17975003749597818, 0.2921356272418052, 0.09431663900613785, 0.1116352339158766, 0.15372697060229257, 0.2186568474280648, 0.28313934279140085, 0.1510788986342959, 0.17493792227469385, 0.12549648934509605, 0.11289975707768463, 0.19491820014081895, 0.16221170750213787, 0.22909441235242411, 0.08549590216716751, 0.08317819723743014, 0.13302300969371572, 0.13758089480688795, 0.23732600267976522, 0.13719159382162616, 0.05770371848484501, 0.15377296891529113, 0.15026700391899794, 0.1540625697816722, 0.10261546049150638, 0.1349347227369435, 0.18219238612800837, 0.14232489571440965, 0.16160525410668924, 0.24850955960573629, 0.14118329447228462, 0.09740457448060624, 0.19726775062736124, 0.1718473224900663, 0.16565012221690267, 0.1704624155536294, 0.31415384262800217, 0.09677066162112169, 0.15321941580623388, 0.1768161793006584, 0.129244364798069, 0.16599290538579226, 0.1710812925011851, 0.1821232624934055, 0.1734276962815784, 0.21712043846491724, 0.17768750520190224, 0.24866506922990084, 0.11116447480162606, 0.14244179881643504, 0.21814954496221617, 0.15379930031485856, 0.12221422250149772, 0.1725688236183487, 0.15007208625320345, 0.18722717533819377, 0.08447386833722703, 0.12075999897206202, 0.12012214530841447, 0.11176752173923887, 0.16758953221142292, 0.1421015537925996, 0.1590685933479108, 0.16460768674733117, 0.2633576636435464, 0.1580646456568502, 0.12832061358494684, 0.16795925534097478, 0.12727388850180432, 0.1985828808392398, 0.1339537519379519, 0.12971602933248505, 0.11868041954585351, 0.0852213372127153, 0.13006804481847212, 0.11204888476640917, 0.1873394474387169, 0.07908258849056438, 0.12842365336837247, 0.1286184077616781, 0.06527205143356696, 0.20772982126800343, 0.1519219932379201, 0.17822967376559973, 0.12061363260727376, 0.07681738308747299, 0.13303817919222638, 0.1433492376236245, 0.1671517244540155, 0.23646836198167875, 0.16552740067709237, 0.17925282823853195, 0.12932208250276744, 0.19154429290210828, 0.10733376824646257, 0.16521713841939345, 0.16335298219928518, 0.1459784441976808, 0.09567095461534336, 0.16400668071582913, 0.14904680923791602, 0.12561575247673318, 0.1440042126341723, 0.23210478597320616], [0.022313317422231194, 0.04730087865027599, 0.05676690547261387, 0.028680029790848494, 0.07066841499181464, 0.058291889072279446, 0.06052918230125215, 0.034164601311204024, 0.04114981027669273, 0.006571828071173513, 0.029202600089774933, 0.029165188425395172, 0.05308569343469571, 0.029024165523878764, 0.03441096836468205, 0.01590398165717488, 0.013157177145330934, 0.07595337476232089, 0.027450591660453938, 0.021909487040829845, 0.06989581699599512, 0.015230400076688966, 0.046065714850556105, 0.027998109253530856, 0.030175320061971433, 0.008314728493132861, 0.014067173578951042, 0.04765935453178827, 0.019920761333196424, 0.046287665245472454, 0.03167852533806581, 0.030561392704839818, 0.045272911884239875, 0.024088031859719194, 0.03953795829147566, 0.05600610020337626, 0.059575095801847056, 0.03587442792195361, 0.06286949675995857, 0.07774452591547742, 0.034913981216959655, 0.05257738535874523, 0.03716036575497128, 0.016671475532348268, 0.03453701101534534, 0.034997925540665165, 0.01970852379599819, 0.026732517399068456, 0.04264663679350633, 0.06440318204113282, 0.005500661745827529, 0.06263859977480024, 0.09428183970157988, 0.02059046055364888, 0.04518431429460179, 0.10518736584344879, 0.050371830075164326, 0.05515241515240632, 0.036926633765688166, 0.061040102737024426, 0.04079127131262794, 0.015097786636033561, 0.04547802665911149, 0.045879873650847, 0.06288215779932216, 0.03980866036727093, 0.023218919413920958, 0.03466901311185211, 0.01858323495980585, 0.03365702425071504, 0.06973696028580889, 0.08713216710020788, 0.020648116151278373, 0.015077801526786061, 0.06656533281784505, 0.04466631748073269, 0.025193824476446025, 0.04051202711707447, 0.04373343414044939, 0.03338346861710306, 0.056832470509107225, 0.03803182524279691, 0.014294870979938423, 0.011835626428364776, 0.061965000568307005, 0.009290828020311892, 0.02092458471452119, 0.019703471625689417, 0.06995069139520638, 0.021472848166013137, 0.0675168180896435, 0.0240881413265015, 0.05139640947163571, 0.027861841663252562, 0.051358630444156006, 0.09333920825156383, 0.01812908139982028, 0.014047319273231551, 0.05514001015399117, 0.1014308666344732, 0.06017360821715556, 0.013487977412296459, 0.05900200565520208, 0.00236116185078572, 0.043277966979076155, 0.017836606566561386, 0.06063724271371029, 0.04126116582483519, 0.03420643988647498, 0.03408276468690019, 0.013651040244440082, 0.02919277219916694, 0.02356017561396584, 0.09476633596932516, 0.03170246702211443, 0.012207105664856499, 0.025281819071096834, 0.0415699697623495, 0.005746268561779289, 0.07490030431654304, 0.01649941044888692, 0.06444948463467881, 0.07397644920274615, 0.03888110935804434, 0.020682260510511696, 0.0205008221018943, 0.01586304664670024, 0.0584509610052919, 0.010054636204586131, 0.031804052196093835, 0.0665954417490866, 0.03287768384325318, 0.01786013450328028, 0.027805967220047023, 0.02335168406716548, 0.03817948294454254, 0.019502078721416183, 0.020338779722806066, 0.05476385631482117, 0.04954875861585606, 0.030621922269347124, 0.07794011893565767, 0.03890696578309871, 0.030604090316046495, 0.06721271565766074, 0.03754431956622284, 0.15852600918151438, 0.07878972217440605, 0.021669222296623047, 0.010382551372458693, 0.03935155305953231, 0.023092808114597574, 0.06552752834977582, 0.03412519326957408, 0.06870570156024769, 0.028991750368732028, 0.03517619312333409, 0.04865622213401366, 0.04929601651383564, 0.032907733402680606, 0.02362186849495629, 0.04837583874177653, 0.05765556052210741, 0.05195235600695014, 0.010540543480601627, 0.015256915157806361, 0.030449244914052542, 0.029887094024161343, 0.022314974266919307, 0.04275488274288364, 0.036369106455822475, 0.0690560917428229, 0.03294590576842893, 0.047092988243093714, 0.06323668174445629, 0.036874520155834034, 0.019961822508776095, 0.04162524863204453, 0.002230453874290106, 0.022489265793410596, 0.04862066212808713, 0.028114136621297803, 0.012560013583424734, 0.038245656542130746, 0.0762267893878743, 0.013895659540139604, 0.02180416886403691, 0.06036704529833514, 0.022683137030981015, 0.06125778949353844, 0.0486071476188954, 0.05753132871177513, 0.10812398482812569, 0.031083985268196557, 0.07250295951962471, 0.021922808591625653, 0.032281995299854316, 0.04184741424978711, 0.056219322941615246, 0.023134761722758412, 0.029929030933999456, 0.019953879673266783, 0.03934605745598674, 0.011291758346487768, 0.08604213027865626, 0.05944235155766364, 0.023960890830494463, 0.04067845002282411, 0.07981644637766294, 0.02864446050807601, 0.034045289939967915, 0.028241897343832534, 0.015043018920550821, 0.01462881795305293, 0.08658792794449255, 0.08145605839672498, 0.08694095275131986, 0.029548470592999365, 0.05103786679683253, 0.02778511101496406, 0.007754755342830322, 0.025911486845870968, 0.05940232011198532, 0.059702993821701966, 0.028476718434831128, 0.07478706742404029, 0.034703767887549475, 0.06751873283064924, 0.11681310177664272, 0.005460616848722566, 0.016644914067001082, 0.05618678347673267, 0.062434323626803234, 0.059799146474688314, 0.041838931501843035, 0.0912490086921025, 0.036420080868992954, 0.07255041986354627, 0.027371174437575974, 0.04146799496083986, 0.043627336708595976, 0.0190598347762716, 0.02906275349232601, 0.061045286638545804, 0.06952952258870937, 0.01790314567188034, 0.011762819885916542, 0.05391318067268003, 0.06757783747161739, 0.050871013445430435, 0.04611196920450311, 0.08610720920842141, 0.0714139839692507, 0.09079625408048742, 0.05360432478482835, 0.04214348293317016, 0.01883213273686124, 0.03547785760019906, 0.036087617263547145, 0.028464255919971038, 0.0897705763054546, 0.06228968646610156, 0.027291350888845045, 0.01322381272984785, 0.09722921240609139, 0.013607336095446954, 0.030512206867570058, 0.019934461379307322, 0.01705079648672836, 0.07370848194113933, 0.0807053166499827, 0.07881166005972773, 0.02483095693605719, 0.046274584892671555, 0.06952242765692063, 0.05258182340185158, 0.003804411799137597, 0.031243682460626587, 0.0594315162015846, 0.018092534337483812, 0.039073563093552366, 0.045360277508734725, 0.05928411083004903, 0.03270952802267857, 0.051468958117766306, 0.03652702805993613, 0.027981551938864868, 0.04468096376513131, 0.0376064521697117, 0.03541952850355301, 0.03819398451014422, 0.029907274874858558, 0.040942743653431535, 0.02020495194301475, 0.04793824991793372, 0.08453000438748859, 0.031069134893186856, 0.044212483044248074, 0.041802299092523754, 0.04346606430772226, 0.03453425022598822, 0.04576647719659377, 0.043007186977774836, 0.08258373694843613, 0.05220271210419014, 0.049713248226908036, 0.08161478152032942, 0.0663502658426296, 0.07251401009852998, 0.12445619868231006, 0.04371047951281071, 0.05258867342490703, 0.04171790576947387, 0.005929908365942538, 0.13769117795163766, 0.07903132835053839, 0.035597658788901754, 0.0354743732168572, 0.014383881389221642, 0.025109765119850636, 0.06875439386931248, 0.021428525251394603, 0.1046809836407192, 0.07077630842104554, 0.025202993710990995, 0.027805887439171784, 0.07855175252188928, 0.004875357335549779, 0.027987229368591215, 0.05179615618544631, 0.05884994701773394, 0.038625962697551586, 0.09103210119064897, 0.03309587154944893, 0.057972379654529504, 0.016521992147318088, 0.009373178581881803, 0.07933144544949755, 0.023964814936334733, 0.08903594658477232, 0.045443672643159516, 0.022117885819170624, 0.02737007049290696, 0.08294272862258367, 0.07517809761338867, 0.051267431626911275, 0.06703241087961942, 0.014096673021413153, 0.016410846255894285, 0.08889236327377148, 0.03040414274437353, 0.031538044204353355, 0.13456580112688243, 0.11766742507461458, 0.09686844699899666, 0.1458201589412056, 0.14027793367858976, 0.13012839626753703, 0.23317613551625982, 0.11741913956939243, 0.1822701483615674, 0.13700095092644915, 0.1275562311639078, 0.1366645353846252, 0.13169692538212985, 0.2135513018583879, 0.1315090135904029, 0.13524030946427956, 0.14500327699352056, 0.30063214944675565, 0.12162783677922562, 0.0866752045112662, 0.12854091270128265, 0.12363307527266443, 0.07051371430861764, 0.21290383738232777, 0.16327544261002913, 0.08718009499716572, 0.10637825311277993, 0.11423364878282882, 0.26154688268434256, 0.1570667835767381, 0.09627255436498672, 0.09348547071567737, 0.20880635100184008, 0.17350027832435444, 0.13731234124861658, 0.19071667949901894, 0.20658341090893373, 0.10557756482739933, 0.2002891228767112, 0.15653589565772563, 0.20925399963743985, 0.10772499881568365, 0.19963898666901514, 0.1449671047157608, 0.1225951594824437, 0.09048272637301125, 0.1803910156013444, 0.11116757697891444, 0.17133666551671922, 0.13943700614618137, 0.11317777301883325, 0.21571902616415173, 0.28063584119081497, 0.08332763609359972, 0.0938152291928418, 0.2207264449680224, 0.13931532361311838, 0.18049740989226848, 0.1473060276475735, 0.2584809222025797, 0.21541063411859795, 0.1480593520682305, 0.15358881239080802, 0.17449524602852762, 0.15918557066470385, 0.08001937181688845, 0.06611901262658648, 0.19393993075937033, 0.1339373059454374, 0.09226286405464634, 0.13324287836439908, 0.1463632329250686, 0.26489889656659216, 0.15650995017495006, 0.15333467134041712, 0.1341906751622446, 0.1800827868282795, 0.22428312833653763, 0.1954424977884628, 0.12300021626288071, 0.1845946884714067, 0.10561069429968484, 0.17188909056130797, 0.12823675089748576, 0.15783202688908204, 0.1063585194060579, 0.06957288627745584, 0.08286941927508451, 0.2749754808610305, 0.13154760526958853, 0.11722637413186021, 0.10999824909958988, 0.1520062269992195, 0.1363147611846216, 0.13897182798245922, 0.3096514998469502, 0.10176826181123033, 0.14932935970136896, 0.11982469251961447, 0.1920657852315344, 0.12860910122981295, 0.14873351901769638, 0.19037153630051762, 0.15036228083772585, 0.15857398160733283, 0.1859383616829291, 0.28127643337938935, 0.11118343667476438, 0.169931557320524, 0.1346553338225931, 0.11672434091451578, 0.18860046024201438, 0.17307959933532402, 0.2733564708614722, 0.12375606398563832, 0.09967120480723679, 0.1911466650199145, 0.12211222172481939, 0.17269748233957216, 0.15071227768203244, 0.22634068824118003, 0.11969255312578753, 0.2172460246947594, 0.1341638687881641, 0.1728158103651367, 0.19863017048919573, 0.10035095270723104, 0.12361772765871137, 0.15804474125616252, 0.09326690080342814, 0.13600191625300795, 0.11006916873157024, 0.22108654986368492, 0.20689579570898786, 0.22863192076329142, 0.12288552476093173, 0.1147773684351705, 0.11087086633779109, 0.24146077455952764, 0.12294970569200814, 0.13005481974687427, 0.17748687299899757, 0.1263697596732527, 0.08526020348654129, 0.16263057565083727, 0.1261016959324479, 0.3218387224478647, 0.160887879319489, 0.1199475847533904, 0.0950287890736945, 0.1939369473257102, 0.12327896693022922, 0.1958197314525023, 0.08778622184763663, 0.18776704324409366, 0.11717434215825051, 0.22756426711566746, 0.12981442327145487, 0.17243906651856378, 0.059059444174636155, 0.07405844909953885, 0.1648137514712289, 0.11497559607960284, 0.16521719779120758, 0.09409222839167342, 0.15747241181088611, 0.11782874571508728, 0.1146025703928899, 0.20471732510486618, 0.11298609111690894, 0.2045582383289002, 0.10001495276810601, 0.12248221944901161, 0.20748252281919122, 0.11637224379228428, 0.07833228461095132], [0.03218577585357707, 0.051705380392377265, 0.0541391089791432, 0.0312525103072403, 0.016524418970220722, 0.022137693740660325, 0.02065408116322942, 0.0689840959967114, 0.029428122070385143, 0.022519617778016254, 0.03804274594585877, 0.0583357871073531, 0.04694367555202916, 0.024658030961290933, 0.022444473470386583, 0.07944201803184114, 0.033394637939636596, 0.050569638406159356, 0.011786369159381138, 0.03291133281891234, 0.017893512595037464, 0.05147296942595858, 0.04695072224421892, 0.0553197805857053, 0.04012206190964207, 0.039885676742414944, 0.05012960791646037, 0.08824409727822058, 0.0453294969338458, 0.035519466109690256, 0.014349448520079022, 0.053508220371440984, 0.023723253289062995, 0.03829297958873212, 0.14611114020226523, 0.02099334840750089, 0.03995955012214836, 0.043155097009730525, 0.02313110850082012, 0.026319339667679742, 0.047947107450454496, 0.07999900728464127, 0.018890192804974504, 0.06528355472255498, 0.013306854416441638, 0.05144393660884816, 0.05230818242125679, 0.06917934762896039, 0.050236610768479295, 0.02180903364205733, 0.033559854855411686, 0.030727119847142603, 0.015480876772926422, 0.05737583021982573, 0.02463958488078788, 0.06084642816858832, 0.03178139071678743, 0.015888621055637486, 0.020055129025422502, 0.05327435479557607, 0.015013963839010103, 0.034526431700214744, 0.01050541948643513, 0.07244253385579214, 0.11758101682062261, 0.03331352490931749, 0.010843580930668395, 0.020370805250422563, 0.04272940110240597, 0.05487747912411578, 0.05209364608163014, 0.07670914827031083, 0.08189948421204463, 0.024787235161056742, 0.10096837504534051, 0.04328759263444226, 0.017410214895789977, 0.016593481377640273, 0.06828336758189835, 0.05967351571598556, 0.03963599228882231, 0.05089821315777954, 0.029957089682284277, 0.09282636194257066, 0.05726453775423579, 0.07692801504163072, 0.032764858842710964, 0.038049603390390985, 0.0622905176714994, 0.04327555499912705, 0.03753501303435769, 0.022044418765290175, 0.07219522056402639, 0.04326214810134843, 0.0036404973525350215, 0.039434610516764224, 0.03506472254230175, 0.05369890408474021, 0.025567391930962913, 0.029686762391065713, 0.05415644554886967, 0.04364050240837969, 0.03654495463706553, 0.04815847110876348, 0.06515187546028756, 0.02108290522301104, 0.03206244575267192, 0.04773163971549366, 0.030427615020016674, 0.04560999164823443, 0.016537037336092908, 0.058479470608290285, 0.04579139480483718, 0.034612008748808876, 0.0402425198990386, 0.03938454152375925, 0.0341630353796063, 0.06814384381868877, 0.04054643679410219, 0.035362015769351274, 0.071573664463358, 0.019415932074480224, 0.04846671472478192, 0.050165921202278696, 0.01346922055745381, 0.013174697396607371, 0.03184896326274611, 0.022588418578379788, 0.024321808377862908, 0.009060513621079735, 0.026285328895028215, 0.033642685957602225, 0.07650651969015598, 0.014097910552663961, 0.04479618961340748, 0.029732012990280055, 0.05029741492762696, 0.0744891693466343, 0.07357512542512268, 0.017781105052563362, 0.04787872596352827, 0.08825570446788333, 0.029340598739509005, 0.04219125126837753, 0.041184527945006266, 0.027424926338426303, 0.03933073952794075, 0.029743217564828228, 0.04826862437766977, 0.0404445844469592, 0.04663448198698461, 0.055768071179045364, 0.04273131213267334, 0.04213571264699567, 0.09130181249929592, 0.05137829364684876, 0.03417523628741037, 0.04609177165548317, 0.009664662647992373, 0.03331935447931755, 0.08215076799388044, 0.020834556635236368, 0.07871067602536641, 0.05038588264142163, 0.039200002793222666, 0.004277020252629882, 0.04128663262235932, 0.018752886207948904, 0.01744199365930399, 0.03236169082811102, 0.051335367825231515, 0.058585679362295195, 0.039360592418233864, 0.05088603080366738, 0.05363375836168416, 0.03401208625291474, 0.04897741622698959, 0.034910871618194506, 0.02838568474544445, 0.007750998220217298, 0.023073068841767963, 0.0033474935071353684, 0.04452249668247532, 0.06723188533214852, 0.03466859750915319, 0.09558512523653917, 0.05207547830650583, 0.008642816210340243, 0.06464029822382145, 0.027056945400545374, 0.02528534983866848, 0.022354159664246254, 0.07848511508200318, 0.0574711368244607, 0.04709328510216437, 0.024929729370342102, 0.02895342586270999, 0.06163697129522916, 0.10625104900100268, 0.006400282491085818, 0.049401108335587196, 0.0347418289311463, 0.014319074271043064, 0.08210954169044271, 0.05076850429759361, 0.04135214570851531, 0.010889728600886883, 0.05759743922681082, 0.06309320975560695, 0.07075005865772255, 0.10115887693245895, 0.014253460067266133, 0.016834989219205454, 0.0493191974965157, 0.04848503464017995, 0.0159481969603803, 0.06837856286438182, 0.03664499243313912, 0.04795216147613246, 0.044009431439917535, 0.07191351614892483, 0.070031867508078, 0.048337948392145336, 0.01168438044260256, 0.06553987768711522, 0.09752211582963355, 0.02793837007629918, 0.02798562632960966, 0.004401824444357771, 0.0193058975492022, 0.04219127724354621, 0.05382998591812793, 0.03572776469809469, 0.007489292365789879, 0.023554949038953055, 0.016410918615292758, 0.00633218441180361, 0.002635100386214617, 0.009576825759722851, 0.024775616839178838, 0.06835292166215368, 0.05887626357434783, 0.05461215019749943, 0.12347297175438143, 0.058575994335114956, 0.08976118071586825, 0.04312855780881364, 0.05224363041634206, 0.04104098174138926, 0.03853782152873464, 0.05733748716011178, 0.0388119337731041, 0.04031517615658231, 0.0482500038924627, 0.02610914674733067, 0.05378350520913955, 0.03631889274402056, 0.03861432953272015, 0.050173940107924864, 0.11081743170507252, 0.07092995525454171, 0.020436221857380588, 0.017355668896925636, 0.03679526620544493, 0.040547115859226324, 0.010901094592554728, 0.020391436955833342, 0.02774439493805403, 0.031925731018418446, 0.019350224174559116, 0.04663067476940341, 0.04359684186056256, 0.09402571711689234, 0.014590488808607915, 0.00901926319784252, 0.062035634473431855, 0.028749470693583135, 0.08204145706258714, 0.05617492766759824, 0.06050617201253772, 0.11963031662162393, 0.026429387180542108, 0.05907801642024424, 0.029250207007862628, 0.036397552976268344, 0.07503306711441837, 0.015199441386357648, 0.07948668790049851, 0.026444645736773964, 0.05573555397859309, 0.01649176632781746, 0.034871693642344326, 0.03038676721189404, 0.05383434603572823, 0.07470566124538891, 0.07170048265834339, 0.022476398808066733, 0.039045606390573084, 0.0296209672887926, 0.04502358366153203, 0.08039849053602666, 0.029238364186312538, 0.010732682731031673, 0.03496114841254894, 0.018930771584564354, 0.011863607251143549, 0.05341850584954955, 0.04278372631233651, 0.053710273787146434, 0.019417204857745674, 0.08001281865290366, 0.023239584515977185, 0.009636726354074199, 0.038487633792101406, 0.06557875138241798, 0.02477078731317306, 0.005242116048975731, 0.0604101455246564, 0.019099591627309565, 0.057501691044308245, 0.05028171850426588, 0.027812553780677263, 0.022681107257085387, 0.025481208176643122, 0.050783762853825465, 0.05575977767875884, 0.03566976585716475, 0.0721263195737265, 0.013840402934874874, 0.017463686635892373, 0.06733523681759834, 0.029888162716815714, 0.04491581639740616, 0.025005439565575216, 0.02385776570008602, 0.03465565445367247, 0.09245509514585137, 0.017884792359836865, 0.05731081808335148, 0.032919667137321085, 0.03616576170315966, 0.01732543380057905, 0.09481235654675402, 0.03501676495943684, 0.054110836863401346, 0.020733145865960978, 0.02195963210397167, 0.07039564603473991, 0.03567582920368295, 0.017676206189207733, 0.021465972167789005, 0.017414448848285247, 0.10162318678339943, 0.14833305613137782, 0.12067688585375436, 0.16155891440575942, 0.08858801593305543, 0.13847384689142928, 0.10101645137183368, 0.2013408945640549, 0.12375336998957209, 0.18723055953159928, 0.15089373278897256, 0.12024585390463471, 0.13013071176828817, 0.12946936913067475, 0.09186131021124311, 0.16560937830945477, 0.222142091661226, 0.16739611368393525, 0.07263733277795836, 0.10096737314597704, 0.13555952202295884, 0.16727006732253358, 0.09213458382873796, 0.22179179795784876, 0.12979255960090086, 0.13843008986441419, 0.10501708748051897, 0.1532314534415491, 0.16482144012115896, 0.1653849973808974, 0.09951015876140445, 0.15588699141517282, 0.18951947655295953, 0.23171239765360951, 0.25954629003535956, 0.14419825456570834, 0.14194243733072653, 0.13255201309220865, 0.10660474174073897, 0.0663426068786066, 0.1907861593645066, 0.08683775711688213, 0.07405116120935418, 0.13680720585398376, 0.17079215176636353, 0.22291012544883415, 0.11883119426784106, 0.18122904875781387, 0.11458962733740918, 0.15357138676336035, 0.09506490197964013, 0.11291975795757025, 0.11426222146837972, 0.09115333843510598, 0.10522753087570891, 0.13520839711418375, 0.105020709161181, 0.13106235943268985, 0.1328280771849677, 0.1375640628975816, 0.059758925781352445, 0.15171960956649855, 0.12653414538362995, 0.13724688382353634, 0.24058762297499925, 0.1107388234231621, 0.15213758713798597, 0.21929481241386384, 0.10146715023438446, 0.21643675718223676, 0.16917220666073263, 0.22665005992166698, 0.21934100368525833, 0.12902676709927619, 0.22534953517606482, 0.12193548667710274, 0.105201882252004, 0.1905206189258024, 0.14030776801519096, 0.1427668149699457, 0.14582303847419098, 0.15551939082797617, 0.141412410303019, 0.27785335143562406, 0.13778808759525418, 0.18794692499795929, 0.1552017664653249, 0.153383742144797, 0.21207466546911746, 0.09629996187868528, 0.15651734196580946, 0.12165243155322969, 0.14457246026722714, 0.14044807845493779, 0.18990472541190684, 0.120039566536434, 0.12282915122341365, 0.14174557523801923, 0.13843521068338305, 0.1996067477739416, 0.24057622358668596, 0.15106257138540968, 0.17051179806003347, 0.15431400941452011, 0.22591577901039273, 0.2706607826985419, 0.3212370484834537, 0.21308753377525136, 0.11388187820557505, 0.16179074649699032, 0.16603733034571633, 0.14341190457344055, 0.15752503008116037, 0.14138806785922498, 0.07655710447579622, 0.2600866329157725, 0.13593544950708747, 0.19955071562435478, 0.15595915785524994, 0.195644955674652, 0.14341600122861564, 0.12622014270164073, 0.14064189774217084, 0.15216615982353687, 0.11275729440967552, 0.19145305326674134, 0.10592146863928065, 0.1673190193832852, 0.11919950731680728, 0.07613186870003119, 0.17997924238443375, 0.1290799494017847, 0.14816366834565997, 0.06763371377019212, 0.15600390936015174, 0.11342133846483193, 0.09834218901232816, 0.17883672087918967, 0.10780195952975191, 0.08000731191714294, 0.11265312656178139, 0.16379297187086195, 0.10892596445046365, 0.15121012518648058, 0.18555529473815113, 0.1613685832126066, 0.12582493422087282, 0.12019745845464058, 0.20415216480614617, 0.12804613768821582, 0.10838545087608509, 0.1770022654091008, 0.14013118139700964, 0.1121480950678233, 0.18177562567871064, 0.13573227915912867, 0.13577063335105777, 0.17036188422935084, 0.10261393166729249, 0.09588245186023414, 0.18866168742533773, 0.10119699363713153, 0.12431575465598144, 0.14547114173183218, 0.08037955092731863, 0.08807522157439962, 0.1541748270392418, 0.13305762346135452, 0.14208932319888845, 0.06829940539319068, 0.12375503982184455, 0.1664779137354344, 0.13358217343920842, 0.08593252990976907, 0.13512183300917968, 0.14861029281746596], [0.046949015304562636, 0.024262701881525572, 0.032979250463540666, 0.031992416697903536, 0.022988078089838382, 0.04455461312318221, 0.062498704937752336, 0.09224292254657485, 0.038417356117861345, 0.016518535594514105, 0.0601554293098161, 0.06906542053911835, 0.08114273106912151, 0.08469021180644631, 0.04779655908350833, 0.03064552256546449, 0.021866787574253976, 0.0391335768654244, 0.05347872371203266, 0.046969454051577486, 0.049475055930088274, 0.03395801337319426, 0.008255824232037412, 0.03231758499168791, 0.025612462559365667, 0.00791110220234259, 0.039348291320493445, 0.023449243089999072, 0.06842514747404493, 0.01801255679310998, 0.023918733131722547, 0.045409381709760055, 0.004778503353009, 0.05937411107879598, 0.04993617825675756, 0.031045527175592724, 0.0186059094266966, 0.006586223880731268, 0.0289633836291614, 0.057163316232617944, 0.004811273347513634, 0.06448271058616228, 0.09239369726856239, 0.016920128400670364, 0.03283853184257168, 0.048471468180650845, 0.029192156216595322, 0.03601559925300535, 0.025053690296772402, 0.01621113988221623, 0.022884670943312813, 0.026044373953482136, 0.04994574825104792, 0.053168951271800324, 0.047548128859489225, 0.1074343960499391, 0.0065198109405173454, 0.03981880552601069, 0.033145910856546834, 0.007670187151234131, 0.01756320307322312, 0.01865346810518531, 0.01807081909646513, 0.06566179028595798, 0.09544922315399162, 0.031732178904348984, 0.007927957303763833, 0.13371650216868147, 0.056478306505596265, 0.017824073547672015, 0.03803324274485931, 0.07862741447752342, 0.035855851965607144, 0.024590643952251412, 0.06254795385757461, 0.04307179093302693, 0.03906522506440524, 0.06915180652868003, 0.015372261605079984, 0.009086545378522715, 0.058857999320025556, 0.08339230684214272, 0.034039208039757796, 0.01883696226286702, 0.02269069209432928, 0.0318908834742615, 0.11608181914198212, 0.030608910565206315, 0.08218607938033529, 0.01849878412031103, 0.02686047664610669, 0.045095508903614245, 0.03711341749294661, 0.09084781107958406, 0.028223792651260737, 0.07548487919848412, 0.040852624661056325, 0.029971474359626882, 0.054338423869921826, 0.035319063972565345, 0.045358852585195564, 0.03382296104973648, 0.04668099238188006, 0.09078740025870502, 0.043088422462460585, 0.12483243044698611, 0.04251905047567561, 0.024379881433560513, 0.04223681542498525, 0.010295711745129665, 0.06894785692566074, 0.0772883054742124, 0.09736192325362936, 0.016555759866605513, 0.011469499931990867, 0.04237158573232591, 0.03388285607798025, 0.0601995165925473, 0.011184276809217408, 0.05352834370569326, 0.029952716577099636, 0.03054902295843931, 0.04079389851540327, 0.06279658075072803, 0.037525654552155174, 0.01839599852246465, 0.06179381307447329, 0.04975232972356025, 0.025251595106965397, 0.0384227886388544, 0.06724202306941152, 0.011853097512357635, 0.02899571158195613, 0.04144071361224633, 0.07026569597655907, 0.08199010044336319, 0.043904681006097235, 0.01046766457875492, 0.03942579380236566, 0.0460424336779397, 0.05829571855429094, 0.12170829300885089, 0.03645245706138667, 0.053483673837035894, 0.03945728312828578, 0.0017097792988352012, 0.050840325639001094, 0.05995151310344227, 0.06177885508805048, 0.048664489659131505, 0.045560022845165804, 0.02602607630251441, 0.04141232646361459, 0.10569239733740687, 0.040825528849381953, 0.0356261980778072, 0.07608762927702628, 0.00654101456348144, 0.06212900778336916, 0.010075831942231162, 0.025149009888991714, 0.04982221777027007, 0.010389799372205744, 0.03500032638839912, 0.005838147835675045, 0.044173086134833284, 0.01564050624438096, 0.05251352355116978, 0.05992363432596903, 0.015167477085924475, 0.01195359080156777, 0.05966879936750047, 0.030864983054925688, 0.02739317911618855, 0.044578053857549094, 0.04735593116492964, 0.025366605732415337, 0.0531778533331817, 0.02570219563494902, 0.020015772934129927, 0.021612852469843347, 0.01967139971384313, 0.0357521961996099, 0.02405326595180668, 0.018936534361273516, 0.022107571821834426, 0.031549072518828325, 0.03970006189774722, 0.039454544603358954, 0.0570175881148316, 0.03848385254968889, 0.03652700579550583, 0.017314778415311594, 0.036875681616947986, 0.05568872446019668, 0.031037964690767694, 0.029043901085969992, 0.009213127941620769, 0.04563085713016335, 0.01938763954967726, 0.03315729911264498, 0.01146732822235208, 0.07490863121347502, 0.04122518279473297, 0.030513603960571345, 0.016754221287555993, 0.035929068544646725, 0.0157148824291653, 0.006645828079854255, 0.05263946601189673, 0.025122318547801115, 0.06384153210092336, 0.02254468752653338, 0.05320601041603368, 0.07407446464640088, 0.03727129827893805, 0.03365204443980474, 0.06426457111956552, 0.03874368958349805, 0.05312350585882086, 0.03654455016658176, 0.050427223977749236, 0.06518078211229295, 0.03318796094390564, 0.07885713886935264, 0.07529135677032173, 0.020172642543911934, 0.024490014293405693, 0.03871130225888919, 0.05491190364409704, 0.043996280583087355, 0.11116085312096402, 0.03583259676815942, 0.0068581356572394725, 0.023904880945337936, 0.0421087058930425, 0.039759478240739554, 0.018978282023454085, 0.03902463700796943, 0.02549295822973363, 0.06787008038372733, 0.03507932800857816, 0.026312652917113155, 0.025854230152617674, 0.022797926867497154, 0.02924915501353098, 0.04268962198693771, 0.03261067766288761, 0.06893072073580697, 0.0146336715988582, 0.013486438383552013, 0.03252707843785174, 0.025835446394921746, 0.05722615387639962, 0.02633160551340552, 0.024503341410309076, 0.0058405950676387874, 0.02497151042916812, 0.05277425116219092, 0.028692857813439332, 0.03554039838491008, 0.028919199867232237, 0.05391709550167434, 0.06167840168927796, 0.03382295362825971, 0.04452090106497053, 0.0757857903954573, 0.01844900456489995, 0.020201461993565317, 0.033406100410502404, 0.021152466724743135, 0.06657339254161343, 0.00733510561985895, 0.07205547415651381, 0.06588995616766624, 0.05029573767387774, 0.013846167566953227, 0.04319690589909442, 0.01564071590109961, 0.08597740015829913, 0.026286920801794622, 0.07459768617991358, 0.08932855314924382, 0.015047493143356405, 0.045566943372250535, 0.07263300605700351, 0.04498348913330119, 0.004128752598262508, 0.05497311598446686, 0.05423637485364452, 0.021928471178398468, 0.03897229704307392, 0.024780696840025485, 0.061734879127470776, 0.00903880580153782, 0.05021206052333582, 0.08870805089827627, 0.006329292818918475, 0.006362839749272098, 0.024298293428728357, 0.049640031647868454, 0.039612956024939194, 0.09295157709857449, 0.021604692556138616, 0.034465690623619594, 0.029981495208630804, 0.030762308779230807, 0.0354719389724778, 0.03493239761155564, 0.0677075500425417, 0.014297325633378932, 0.015605582630087156, 0.02558961739850929, 0.02782808878691867, 0.025281303278461564, 0.12325700678047724, 0.02459113562508719, 0.06483658886281773, 0.018942601418530103, 0.04051981966767926, 0.02554512564529432, 0.05942269948718604, 0.03219281883502845, 0.05280185905576218, 0.015269296964106616, 0.021424812657642178, 0.02738263505307259, 0.03943382384022698, 0.07888580061262473, 0.10953483724733815, 0.03617491980548948, 0.027304982286295854, 0.04634381984942593, 0.02666226755536627, 0.057004355621756986, 0.06393678675522096, 0.010169836077693617, 0.030382206714421045, 0.05375142216507811, 0.039195653807837516, 0.025714652583701536, 0.04107394051970914, 0.016719004524929915, 0.013005947857891442, 0.03482235195406247, 0.0074181987929478055, 0.0664827020955272, 0.01402880176101462, 0.022001303696015384, 0.023327109702222515, 0.0604851506795967, 0.06467283397796564, 0.09612804336939007, 0.12219795462442562, 0.18716407794272527, 0.10685721295885742, 0.10113040814758278, 0.139557397342287, 0.12119938008254394, 0.15185324067715555, 0.07856553420424461, 0.10716686665546149, 0.13290867442265153, 0.100486587616615, 0.13196908577810973, 0.19630266178864986, 0.11479644163046032, 0.1352401016629301, 0.13866312423488125, 0.18760978215141222, 0.253341905772686, 0.13794539321679622, 0.11337228992488235, 0.1002807826444041, 0.16532375535462052, 0.10893289610976353, 0.1301639006123878, 0.090042180090677, 0.19098861725069582, 0.1886267025838606, 0.12442291335901245, 0.09707410354167223, 0.10348295691073872, 0.1227899435616564, 0.09659284303779714, 0.19774138927459717, 0.19565203576348722, 0.15326036751503125, 0.2089101032470353, 0.12359163374640048, 0.13542473316192627, 0.1212105865124613, 0.05039351563027594, 0.2149344127974473, 0.21033487835666165, 0.15523305541137233, 0.19853284524288028, 0.21084762818645686, 0.18968059681355953, 0.10945521222311072, 0.0911749349324964, 0.1691153581487015, 0.10856761102331802, 0.12264708013390191, 0.1492249098373577, 0.12844795128330588, 0.11763314527343027, 0.30032510810997337, 0.07315099544939585, 0.11010499219992198, 0.13909161061747, 0.11929258005693555, 0.10169787652557716, 0.11052347443182953, 0.15068697044625878, 0.1860500845941715, 0.1520248400629498, 0.13990061095682904, 0.1408595102839172, 0.24798116530291736, 0.18379797809757292, 0.0902751179819461, 0.19734043657081202, 0.17383008875185624, 0.2296316233696416, 0.08438733391813003, 0.17629287613090128, 0.09971519190003164, 0.20538451586617157, 0.17067407607100904, 0.16466265020426363, 0.06742412384483032, 0.15609041409334168, 0.17824591195676476, 0.10209819840383716, 0.13188333803554997, 0.16784870502306148, 0.21235516760498285, 0.20856454444583505, 0.17506800591945648, 0.12077067847712897, 0.10473505652043968, 0.1019108209584374, 0.09625368154956959, 0.14768357301363721, 0.21166750841075554, 0.11390604253392667, 0.1816207988304086, 0.10892731515923515, 0.14078759617405012, 0.16317103727487847, 0.1733603241154924, 0.12429187976522371, 0.13720664457650855, 0.11040277895517647, 0.16236984432907775, 0.12620086170500144, 0.1726461702492088, 0.301275888341479, 0.09671887455624528, 0.15436616755323485, 0.11060787888709456, 0.1364655655925162, 0.12744321691570804, 0.16317342699039727, 0.1671383361099288, 0.12631163466721773, 0.14519746735459194, 0.12173324401373975, 0.19738017115741968, 0.10168110398808494, 0.17782867653295398, 0.13319153658812866, 0.0882432512298692, 0.09732623337185942, 0.2858362777624279, 0.18107144627720118, 0.157159804366529, 0.13526368711609393, 0.14215714065358043, 0.12407211499521509, 0.11833885349915363, 0.24114034487865865, 0.1966245609219186, 0.09515348472632468, 0.2501506410771981, 0.24693957588169724, 0.21813084284076467, 0.05692231861758046, 0.16667977790348232, 0.1586645087809302, 0.1217585289850831, 0.11294107243884355, 0.2624631085200235, 0.13451907550916076, 0.12705554865533486, 0.08937289647292346, 0.14804663165705279, 0.10644305744790472, 0.148206727753859, 0.15211309626465663, 0.168402376875747, 0.09511990254395641, 0.13911727408412844, 0.17660925368545577, 0.23241031332872808, 0.11701573035679758, 0.11112368636531755, 0.19001680455403402, 0.11078286988777108, 0.16114717087475583, 0.12902476330054924, 0.15893745585344732, 0.12160052574472502, 0.1443159146583639, 0.10041859204648063, 0.10196473056566902, 0.1041838782839477, 0.06481715201516636, 0.0918877158255782, 0.19184787583071738, 0.09408073994563892, 0.15558927145320922, 0.1713310697232373, 0.11992710889899172, 0.25137847987934947, 0.14608316123485565, 0.19108085136394948], [0.07181294029578567, 0.055090037640184164, 0.05488266673637554, 0.021970625166432, 0.03185282243066467, 0.04253229039022699, 0.06132424881798215, 0.05355238929041661, 0.0329500951920636, 0.027190008768229745, 0.04305893322452903, 0.010356834100093693, 0.02136393428372685, 0.06363000517012551, 0.04476283378608059, 0.0838912081962917, 0.021885135320189875, 0.022554734350705985, 0.04043702567287255, 0.037900420575169846, 0.039724582456983626, 0.01126722479966702, 0.03306575890746899, 0.017388948654115666, 0.027004469993698876, 0.023350956762442365, 0.011214130627195118, 0.017996164606302045, 0.014758322722627781, 0.010829831717273919, 0.038377970340661705, 0.036493950537987985, 0.0784099726297427, 0.019396712305024266, 0.03004124366270844, 0.05073253239970654, 0.020073330197192263, 0.030161343565850984, 0.09126200369792059, 0.04597689832735341, 0.1820016690180637, 0.006914149716976681, 0.007870467761676991, 0.05847101754625328, 0.06121989914390724, 0.04521540286077652, 0.006913145962244016, 0.02159247680538101, 0.03384263538464438, 0.024057240152615122, 0.012229787553224014, 0.02827610293024918, 0.03292295485152863, 0.04104166822799016, 0.042580953013384715, 0.04818164466996677, 0.03924008247849997, 0.025329631935164798, 0.015834455407457426, 0.009844670566963032, 0.030619361859862693, 0.01862992903625127, 0.04333159828092903, 0.044987029177718796, 0.05415927684225608, 0.03571962704882026, 0.08076260302914307, 0.01699379954516189, 0.043684886550181545, 0.05723757181840483, 0.017420289550500456, 0.02615743829665007, 0.033010658153216355, 0.02676713302207645, 0.020624489879992325, 0.15759497007820755, 0.057057029553106986, 0.03552359245077241, 0.04062559426529333, 0.02313132928975392, 0.04303839428757783, 0.04888688163191546, 0.04437727322510909, 0.07186561051639728, 0.0672587362350896, 0.04145131890254561, 0.02937108245532727, 0.04590938886394724, 0.026138956964132376, 0.05215795317781158, 0.02946957843960263, 0.036220791953383014, 0.041240920036216266, 0.036599265004042536, 0.03493691729090642, 0.034131931970478036, 0.022266591804509517, 0.03186227739206515, 0.048568092097411864, 0.024626523081678897, 0.012765176597895334, 0.0192207342479378, 0.045011412439635023, 0.03900020550645422, 0.01777171688445378, 0.0398766559374053, 0.026536178520473186, 0.06137283351563383, 0.0413548916549189, 0.04196874055196531, 0.020379436427901965, 0.026286429128958844, 0.03359520705998875, 0.0031874693058853154, 0.07143658236600459, 0.007066627204039833, 0.0504540785914287, 0.03394493673113175, 0.04544030700344592, 0.03701693087350577, 0.03494121061521582, 0.02286339171405416, 0.017780891685106326, 0.07812783034751192, 0.0629820731410291, 0.006437800375351799, 0.055467156271333806, 0.06199875715537928, 0.04482704811380245, 0.06636041100136936, 0.026856923614104744, 0.006641353393206373, 0.027497547343955375, 0.14712135161971673, 0.10010792160755955, 0.04070166440214962, 0.0354516226798296, 0.047241495703929104, 0.04299020663893316, 0.03381391055881977, 0.02647618701303145, 0.056695369858061895, 0.02344915032153949, 0.01095180276024621, 0.05792642958112992, 0.040650318915140815, 0.08009800978470594, 0.05991475823975634, 0.0054279581763694296, 0.023412399168591946, 0.02958889352157712, 0.06500838120700791, 0.020337837195256725, 0.07183300054748543, 0.04863699679845013, 0.015780078247189522, 0.020564528058457654, 0.02012808956351364, 0.027671091156662442, 0.026090424216818064, 0.07058002520352602, 0.03707168281835038, 0.03320055518997833, 0.03972658625571057, 0.037871536187594756, 0.025480304611846805, 0.03898357397702057, 0.011877694141730899, 0.05147426447365433, 0.06444669415941462, 0.04456307731743436, 0.03449686453677714, 0.014442252231674502, 0.021736928429163527, 0.05042363569373265, 0.015217484851746121, 0.09471990721067414, 0.03519475423672702, 0.05314017820637673, 0.028455865940486547, 0.0442896738240961, 0.006991447180553223, 0.0224351298311376, 0.012146197605034104, 0.021150574248167686, 0.01649055291636614, 0.035269696309114806, 0.020270186723791994, 0.08096239660517313, 0.06288730830419809, 0.04508634709054604, 0.023319337560678832, 0.08653468627016991, 0.05930163293669466, 0.017773431245586835, 0.041303186226286925, 0.048810818916535936, 0.029551663683378138, 0.035008230261155404, 0.018463422638888005, 0.029987439811520744, 0.029971708136145025, 0.023180461321317125, 0.03941253904486075, 0.09451848833123222, 0.03442837914917618, 0.05309849548211787, 0.027104309265268967, 0.022203544504009187, 0.05361402465496212, 0.01184342918350012, 0.023930921051942278, 0.012865494554716861, 0.043142818176420406, 0.05937201451160945, 0.112275952269556, 0.05535376723855734, 0.03070962742640404, 0.08091675452305935, 0.05968498189758975, 0.0698096833366435, 0.016863439450389706, 0.006704607567371568, 0.02612601576402085, 0.020313771201472264, 0.0064198835389106534, 0.008385919936699793, 0.02666141779627651, 0.04876345134107396, 0.03220659680664539, 0.06935140714631416, 0.02258101936604362, 0.025500459487375338, 0.048667302398825996, 0.015094433056219714, 0.01654960375162773, 0.031013599982543383, 0.0168549863883527, 0.0166039215400815, 0.031123024091357365, 0.06084368964366149, 0.031183045284706168, 0.02132478228304535, 0.021355598109948914, 0.024259193378384225, 0.030337759490066674, 0.03683472619741224, 0.0651653231761884, 0.015248072468239116, 0.03892645087034907, 0.02934152085799724, 0.06026391274644993, 0.05392895131080877, 0.054436012578662485, 0.022184022309374996, 0.0017362978587698308, 0.012521065673354315, 0.03705041657667607, 0.05037008973886259, 0.02987271120218793, 0.027143852748849895, 0.03556118223059457, 0.002628977204039984, 0.02488895206624875, 0.042243531861458905, 0.04590315111272503, 0.028468525124480948, 0.05555861112952698, 0.07720663954387419, 0.07019621611107141, 0.028516042984847445, 0.05968052901152987, 0.010220985823252704, 0.008046659186220495, 0.09675010413047858, 0.03200477716745809, 0.023536219086963683, 0.023660170736548025, 0.03506152017507702, 0.053131220483919606, 0.00887136893652496, 0.03859777221805416, 0.020767026762769092, 0.011998860882158624, 0.015488519038626691, 0.034732296044239774, 0.012448681227397174, 0.032247819399344735, 0.015412062057293952, 0.024603750280220993, 0.021132410183781758, 0.013307706958585186, 0.018110266100848094, 0.06907600356498733, 0.020243781109456904, 0.039500357379438356, 0.01768824011378456, 0.022531933718710206, 0.019374319854250643, 0.01661458249145653, 0.09484056557994336, 0.008590433571953326, 0.02645027678227052, 0.05041048483690247, 0.07012222398770973, 0.03974769664637279, 0.05914865403610747, 0.02806644064548891, 0.04427937281434424, 0.05166827671928331, 0.06819016867666505, 0.036528445561998524, 0.038537391083082184, 0.048389048970420845, 0.01867976981884567, 0.020590371495927684, 0.05826891960168723, 0.04467543105420191, 0.03399086454010103, 0.020206740518915467, 0.030335616538650356, 0.07001340287388302, 0.035362464768695645, 0.05449889475130476, 0.011588477336772485, 0.030144452284730505, 0.055800031768740155, 0.032058044816949405, 0.040226277997135185, 0.06314893762464635, 0.05849540451890789, 0.013854970366082853, 0.07112430888810195, 0.03734898258699104, 0.053031071365694515, 0.048170801892410964, 0.02221930215455359, 0.012866472334280843, 0.03904227043676656, 0.06602144247153774, 0.03866569728415925, 0.05547668544750195, 0.03925996832549572, 0.03150639160594437, 0.03317789742141031, 0.017564965673955157, 0.028749092198268045, 0.01812147253076546, 0.05424999326351099, 0.06439579025027342, 0.0979354623996187, 0.05078841983049642, 0.22750588977942243, 0.1643570337910205, 0.1649244799045846, 0.121128987375414, 0.13262695516459644, 0.08807249047094956, 0.19355821452336386, 0.13980965333757922, 0.1043243742606137, 0.15883291693171486, 0.1343744309269823, 0.11077668779762462, 0.15584075561491773, 0.09021576101076789, 0.08836926048388705, 0.14872971922159195, 0.11577613593544811, 0.10583436276647262, 0.07770020485622808, 0.10837607012945227, 0.10733689268818125, 0.08599392036558129, 0.10690958632039838, 0.070267350965878, 0.14900109294103459, 0.08439117082161829, 0.06972539020352997, 0.16882065130630508, 0.21624871180392802, 0.11608465414610691, 0.1489757708623074, 0.1512561977142468, 0.17228802462341264, 0.1727948075858876, 0.10177017655223608, 0.1270610702340491, 0.12355140192084946, 0.1307020615786314, 0.1610284866183065, 0.15197614033240825, 0.1936165028018877, 0.10789912892505527, 0.1548298614216037, 0.10876631364226341, 0.19716370152309537, 0.10130486480193213, 0.07780183455906808, 0.09758905012859032, 0.11354996750014834, 0.12213450099807233, 0.07536602424806915, 0.11050111352233216, 0.16389188531320542, 0.10923803012701683, 0.1657635223818943, 0.11620350909652188, 0.12821686133975163, 0.15536248596617952, 0.09108839309192263, 0.09462669346248731, 0.05442380796012003, 0.0731316625024192, 0.08842928538797423, 0.17966800049180165, 0.15700631338404492, 0.1402963389409706, 0.19171794061549008, 0.06845587238785811, 0.15312639501644298, 0.12400783016346395, 0.10851332292077132, 0.13523224974051118, 0.10596089894534089, 0.11238913721172139, 0.17953797621885315, 0.17939201061381027, 0.11919710275833495, 0.21564540511462837, 0.16246492828940973, 0.07653385298908688, 0.16739565355237573, 0.11516466562170535, 0.07416234235279262, 0.14471127156866714, 0.1256992292474024, 0.1294324843911454, 0.12851728271925822, 0.13801563007291406, 0.1600867012166418, 0.19324235647218302, 0.08748154054046609, 0.09375084046041593, 0.19642195460619405, 0.1702270656824112, 0.11459259592811577, 0.10254025866743177, 0.16334993939381093, 0.06127485517936293, 0.14020339236594737, 0.1266584699624218, 0.18892183987190947, 0.17647100641625002, 0.15922555758152157, 0.19747993064811453, 0.11028251392417587, 0.1416798506397754, 0.15967014856869355, 0.16918749490287155, 0.11034020848455839, 0.15639870223822072, 0.09119984140852466, 0.1501146558439359, 0.1095639294362627, 0.1419724349398166, 0.11009598994860426, 0.0404959744628286, 0.32367325213272125, 0.21715903014410287, 0.16456710611237213, 0.18248158623464406, 0.08980359445558861, 0.12945504568051547, 0.08750154142035171, 0.15105740603758022, 0.21852991048945114, 0.1026494953839574, 0.10795420370413922, 0.10565619537374005, 0.2105683134868741, 0.1452766841975972, 0.11580726903048344, 0.10094694924191572, 0.14791322319069877, 0.25682397361379117, 0.3055907052475959, 0.11709007128956728, 0.07045953010674566, 0.07984386873431504, 0.10310397919965908, 0.12441796323400922, 0.14091417688177899, 0.13568733469583094, 0.15094871108885854, 0.13618737895740196, 0.22355546738253906, 0.13023720995988697, 0.17400749173248187, 0.14267371996538714, 0.09273542658775114, 0.1538853597594425, 0.11186344432644546, 0.1260177293443121, 0.1910239434801042, 0.16954466089373454, 0.16491545538883656, 0.11303701729048043, 0.1236528683512006, 0.21350292867282405, 0.08414694486418739, 0.10215558868367225, 0.13695517525775358, 0.14333344472106546, 0.06535611450090073, 0.12291398612433113, 0.20050139195518568, 0.1081422416609712, 0.08212706379708834, 0.10439774297992699, 0.14414835255593061, 0.14217738644219935, 0.16843880148371682, 0.1178477521170862, 0.10750653280410916, 0.14412095246370882, 0.22376076027285308, 0.19052664516493678], [0.028581704500538763, 0.046666171692777425, 0.013378631228988525, 0.03757407597731799, 0.01216704453327111, 0.026049418702314142, 0.03885748308675829, 0.023121382655517664, 0.03665102238301188, 0.013845127632521326, 0.01301909685935243, 0.09976971748983487, 0.0318952881207224, 0.028402499956428073, 0.02146228183846688, 0.017759901893441565, 0.011286238623142708, 0.02276669914863305, 0.02054949214652879, 0.02245569288788829, 0.024307321655214764, 0.03379798406967893, 0.025930452429747675, 0.01620300408831099, 0.04456175629456993, 0.01005261385216727, 0.022165457485243678, 0.07537976140156388, 0.05624521276331507, 0.013406362504611025, 0.055879055653349496, 0.10786681581521407, 0.028109746817790437, 0.05153083839104511, 0.05665633660100866, 0.07472372511983849, 0.036423661731532775, 0.042821657480089925, 0.013741272414335981, 0.05577118819928728, 0.08434709467110224, 0.010134571075468557, 0.05134344239195343, 0.014486631735053379, 0.05119961788295768, 0.019697328498295974, 0.015322133240260882, 0.007066245925670955, 0.09115954278968275, 0.012314820050960407, 0.0467854459566297, 0.0456865516025573, 0.043024857513955794, 0.028239179227966815, 0.04744756413856521, 0.026105580727744382, 0.04796957226062659, 0.047080468211788684, 0.03180142870405689, 0.028528780094347894, 0.04881125678366516, 0.009890551991702523, 0.044420217600418255, 0.006967838535274495, 0.024681579307070933, 0.025277978456870187, 0.0478954725258518, 0.035426007452770136, 0.04028059949632734, 0.09712758270325139, 0.04865872317168396, 0.030893565017322544, 0.0685034588968847, 0.048346186231356114, 0.04364097738289274, 0.023414690549543593, 0.049416511610616, 0.015840223750274163, 0.03292584922746755, 0.012581391147250542, 0.06784432785934769, 0.05603768600849435, 0.07474471305613406, 0.018054987231153063, 0.02401650923275156, 0.040715201175771654, 0.10118786522070877, 0.02934606836788589, 0.07996818589163013, 0.05263917657430284, 0.017537326239107642, 0.03845927261863835, 0.006090428878451348, 0.011202975219930522, 0.014724027150805341, 0.02558812568167923, 0.017850996810011566, 0.03400591158424504, 0.06046831877029035, 0.010449783458170714, 0.021432543981063645, 0.009049661566677969, 0.06869617238407955, 0.06079210666939616, 0.030299371901492123, 0.08245117453043349, 0.04358628852060065, 0.025516037167108152, 0.06219406444870401, 0.027604251481534448, 0.0329084644181421, 0.046693141339346766, 0.06064563640393317, 0.04503017022216227, 0.020643709649448283, 0.028273253083170857, 0.01760858725901926, 0.028368925195536576, 0.021144126840226818, 0.012902026774099795, 0.027387377376726363, 0.08424787694821134, 0.02329048471438, 0.04274873404938262, 0.06026127441145945, 0.07664950186153874, 0.04137069197895471, 0.08302884001750499, 0.0035630484444482136, 0.0066210162276547635, 0.043443688555271365, 0.05067056306870654, 0.006185979000292718, 0.038527145734406076, 0.02523788578400854, 0.011384122335584834, 0.019671648333314806, 0.027236637906753458, 0.013488591539498884, 0.07217075195512734, 0.07333787565585226, 0.00846797920530662, 0.06818477326305583, 0.049182872389792465, 0.01232199012520141, 0.029890827026974875, 0.021635788543790113, 0.03027402013685787, 0.03479481085378211, 0.026275458330928814, 0.06432130830944516, 0.027167495718458667, 0.05209799135627691, 0.09429484212887473, 0.029503631885745563, 0.022891044136486016, 0.03360480674018618, 0.051936618765466847, 0.02470951931172749, 0.027524183024070226, 0.01163407025160268, 0.07168854150222614, 0.02812177517625969, 0.02020104082475882, 0.040883023029891774, 0.04822389513719827, 0.07504442939534783, 0.023578471409564372, 0.04114952083909884, 0.02417171828710707, 0.1016283743956592, 0.028499520922196098, 0.028125799472036306, 0.01864338046289049, 0.04154194626607932, 0.01982687408599304, 0.03735979938937817, 0.006250960059333011, 0.03441745102463756, 0.004039317309434409, 0.022255023577599786, 0.024303866957779974, 0.020114717917749658, 0.028948299477633554, 0.018011734864558093, 0.027784856829384807, 0.03905992612999398, 0.0760412153613288, 0.021692104564863257, 0.036993030007579364, 0.051135299654561095, 0.05420698580564931, 0.028403694814187475, 0.027724327264877502, 0.07641038930159993, 0.04041980042529758, 0.024076960871752817, 0.02880973679566523, 0.004237354778524605, 0.11306119646178558, 0.01324488694081083, 0.03759968749363907, 0.02567653402365977, 0.04684842089773156, 0.09152389277005568, 0.026600008786772378, 0.013369751432037447, 0.07093532840372063, 0.023549600009573624, 0.03583791425626259, 0.039964767420315184, 0.020418169115146156, 0.06604600013815798, 0.036211336991982535, 0.06282881222432479, 0.0058463805726205464, 0.05789615366666112, 0.060243318148422986, 0.04680797384935431, 0.06071060401154682, 0.06604493886698037, 0.029687786554859485, 0.00949937986661098, 0.0227401525262394, 0.02326949677808443, 0.03714711099746637, 0.015161866449489025, 0.027275927204755135, 0.04263272894604597, 0.038239619170781225, 0.07136623418773524, 0.0025636716873123078, 0.04497590067330748, 0.04448191975825466, 0.008303414451802382, 0.0320637556433212, 0.03456064470810816, 0.04976936201273929, 0.050689832933130674, 0.04850099081522785, 0.06461757366196252, 0.03267081388912629, 0.04010333010228351, 0.02073830193694448, 0.07528852176619694, 0.035528175212675706, 0.01934332034579711, 0.04749158462800551, 0.00834986083646072, 0.04346436478954274, 0.031205328268697485, 0.038518262226716615, 0.03259330027503893, 0.021256834952509962, 0.03605316305765882, 0.008681035888002953, 0.024992758117150515, 0.05000366174499504, 0.05324835736246314, 0.04423803147801664, 0.040320241314475425, 0.03586163329600822, 0.03630521125160158, 0.054350806603906676, 0.012341135679889703, 0.043829594214912504, 0.0542927929200232, 0.0057047922473429935, 0.05532578827114776, 0.03224853928259108, 0.05726002549636178, 0.04908723924017977, 0.034179785652668215, 0.025433207920286804, 0.02842115383828059, 0.025860781461233273, 0.012224196398165077, 0.04160582662734669, 0.05549280118430033, 0.027787576800619718, 0.04076513658219483, 0.06922304528416134, 0.15454269479960203, 0.046430654838331975, 0.04222688548907172, 0.03756203092052601, 0.012691459996858612, 0.04504919517785311, 0.10064616421004757, 0.026603921760397498, 0.04027059163490776, 0.017256618157261983, 0.030711592262377962, 0.0443676438590046, 0.01041320485455799, 0.0289574297494255, 0.08551346880267374, 0.023506221477873623, 0.028153728344477713, 0.029368275281740353, 0.024585612191003747, 0.05297410039929673, 0.06107684275775682, 0.15482416172744706, 0.020002644341730047, 0.026266025633958634, 0.031688329108874314, 0.030085538746789098, 0.018216818098153453, 0.035435035679256544, 0.011911678939213743, 0.02064908650936559, 0.03399736946448684, 0.0680481141898781, 0.05039799820224289, 0.033023155920091085, 0.06796953559387475, 0.02640279046318028, 0.050634004874154925, 0.03841639503662009, 0.020899388800899033, 0.01927889450598741, 0.05061723604740109, 0.016329013342328835, 0.03656445085653104, 0.1074989554763306, 0.0615814549382776, 0.061178004907560535, 0.024287766063935123, 0.021268764976412058, 0.02780694871034939, 0.03291585991973989, 0.06009527081914712, 0.009270097052649362, 0.06266275668167509, 0.04503383272094652, 0.07716444102698006, 0.03948004850826692, 0.0074115825464105, 0.046433248644461855, 0.040091288756229915, 0.07900270371465012, 0.019282284265500493, 0.05253048162558116, 0.044500503136077896, 0.06291099023655988, 0.056370628299191594, 0.051801399458781816, 0.06878673666506074, 0.03166469912684988, 0.06070681534765754, 0.012023984436382307, 0.14128385548247024, 0.09749806282343343, 0.09623814097722061, 0.10219469244475476, 0.13141940667992458, 0.1102097611874342, 0.1317157907760702, 0.17959950026124716, 0.1455417793476954, 0.19854693120578304, 0.09640280870371498, 0.3159222914837301, 0.12696487305220217, 0.14734335767570883, 0.1172229008807335, 0.23446656705345958, 0.08641733045806177, 0.10539976850850508, 0.11573277966817841, 0.11316020638332702, 0.08424117535469122, 0.09824314940487966, 0.09475394952460192, 0.24121570255374536, 0.11361831187969074, 0.14748564222827554, 0.10954429220873863, 0.24166051618522033, 0.15298224025173113, 0.19142502977047116, 0.2537431108066812, 0.11125372548121959, 0.17455982771934941, 0.150580026966054, 0.14552528882632032, 0.13616998301586136, 0.17186669254442677, 0.09500507745542563, 0.09427925702766515, 0.11683538847137243, 0.1514680660329759, 0.18068554432829842, 0.12554578279377893, 0.09411893828655593, 0.16457252379041165, 0.1525142864556983, 0.08493930625263602, 0.13153049134416506, 0.18469205824658275, 0.15670228516682982, 0.07280321762664244, 0.09736553751281463, 0.18910376995336264, 0.15347033593570814, 0.23284561262698844, 0.1060026150662452, 0.14963711349992082, 0.17411375243682414, 0.15677549061365426, 0.12454035080736503, 0.22618697461439297, 0.15681240503909066, 0.194802172773052, 0.23235460772411898, 0.15297266654670238, 0.1327448824304156, 0.2434346202062443, 0.1624780346173793, 0.15116378548555076, 0.22203283268027008, 0.21433147718198597, 0.10319651017198339, 0.2219350918312557, 0.11405817538616247, 0.1634580406243913, 0.16513444832526147, 0.1239576684019994, 0.09252125018974766, 0.20630436338251457, 0.13754196173977107, 0.17203208757564425, 0.16280734038446099, 0.2123489632504061, 0.13387121027335525, 0.12436075106961653, 0.10812889784574509, 0.17801062145736068, 0.11081090080551803, 0.19562567467801273, 0.16047583892941475, 0.224665705463849, 0.13663243007613346, 0.15542179840849712, 0.1499781006714329, 0.15614267613273114, 0.13253935205284506, 0.07719119545072317, 0.05845325424161274, 0.13934826012700796, 0.11226398884900846, 0.06573629449121654, 0.12100843290681951, 0.11345119506586343, 0.10891985657508485, 0.12153739124187268, 0.18215214688098058, 0.31891477934550494, 0.20502215484157205, 0.1318392693065107, 0.15228689240757376, 0.08918111809180118, 0.15451900544576347, 0.2061361333471723, 0.10336499253753573, 0.13197330117691308, 0.10077691578771919, 0.13774930295767263, 0.18324981298064813, 0.11159398534800857, 0.15701309661380947, 0.14494250994175673, 0.2036251954268664, 0.15604437125148252, 0.17858415318187326, 0.19952928239945322, 0.1409193719155155, 0.20381098467623815, 0.27487796265631914, 0.13103506324114278, 0.12092247736291029, 0.09382409785757773, 0.14818041119724512, 0.1358739848365076, 0.10230251908069476, 0.19381125719519332, 0.10206466817180626, 0.1850031962385401, 0.17841675435192883, 0.11777122927014716, 0.19825299619697034, 0.11521565116709098, 0.09612497829948552, 0.2223172236699611, 0.11456094332970679, 0.05511232804565225, 0.09614727241569199, 0.17696601891657338, 0.14008395111886784, 0.1800342058413662, 0.1281576676410623, 0.14767466724151745, 0.15200398571323603, 0.09861778555205092, 0.180626766232308, 0.14716390636749566, 0.1285057349014096, 0.11760925553971902, 0.11900812227395363, 0.20125015958910808, 0.16430598887382075, 0.15380992786958814, 0.11623467929894105, 0.08799888426437974, 0.1267305325018242, 0.09842346902587451, 0.21188428974710405, 0.14438891230383888, 0.10329360535251908, 0.13773953629424796, 0.10996385055477731, 0.23897769686300308, 0.21646191598847508, 0.06896779101225547, 0.1553547231014818, 0.10350323238526471, 0.1292234956054017], [0.005983222863505944, 0.04483027274545748, 0.04718098098237533, 0.039648163510719314, 0.08160298137227073, 0.05613691115286201, 0.03710441895236727, 0.029940573185740504, 0.016022677045839373, 0.07173553429311141, 0.044652910582954064, 0.06915218502399512, 0.048785708349896595, 0.016602019786660094, 0.034750200356938876, 0.04413148504681885, 0.03474367687886115, 0.04146517108893022, 0.047803004636080004, 0.026515116369409952, 0.0024757724122537184, 0.11756600317312405, 0.027266722718195524, 0.03197517289663665, 0.08083917782641947, 0.0441221562505234, 0.021057629528513644, 0.012300601429160452, 0.038614990044152364, 0.024964124204416294, 0.017052021030394826, 0.038423690348281525, 0.05154058650077786, 0.05084094904304948, 0.013847672271367628, 0.032778492095530964, 0.017896230710903183, 0.023934793207445182, 0.08921170941903256, 0.05358870257623494, 0.061721015808871016, 0.03472404336207546, 0.06605883929296397, 0.014073891870793886, 0.08070813681115396, 0.04824990741326474, 0.03662771894596517, 0.045392794709187, 0.008269210720754927, 0.03909069186192937, 0.021073294410598464, 0.056869344116421416, 0.03999357759312261, 0.05205133624258451, 0.07312850837479346, 0.032010339564294554, 0.03419738568481989, 0.057238447552663274, 0.02324026543647051, 0.10525838195462711, 0.09868932858807966, 0.010518791132199112, 0.03177850376232527, 0.054851459426572546, 0.06685019136057235, 0.07710524732829072, 0.08835725995595567, 0.060951679552090354, 0.009975549237424275, 0.04209037113469094, 0.04165549857134465, 0.01575209742441075, 0.028334402340988163, 0.02836940202541882, 0.06348809169139713, 0.0476135565986624, 0.0374045657372335, 0.021884170528210234, 0.02286506711243419, 0.07672816209378652, 0.06219709241122473, 0.013393734861892881, 0.0500964487582678, 0.046288871235447004, 0.07251293398439884, 0.06849152516224422, 0.017277585684496444, 0.09934357629390433, 0.08704692401806824, 0.028320878554950468, 0.028518095023173373, 0.07643030112376437, 0.04595768412400503, 0.03770284973143134, 0.0868465515668504, 0.12134672608226538, 0.02574747592007043, 0.010040331308118766, 0.05369271086237859, 0.02147056977264583, 0.0383942159533035, 0.07633574408828281, 0.05135445957421325, 0.018303521355846897, 0.015435005552717485, 0.07272749629919417, 0.02046739205979975, 0.03705423492647242, 0.019712789289769717, 0.05181711814657319, 0.010680274117476074, 0.04104459971131291, 0.01966890980838798, 0.012407894646457862, 0.01875314595963573, 0.02189976119552739, 0.12893723440356553, 0.03676029991765972, 0.02731328506342834, 0.026261485545546748, 0.04040565880131908, 0.07321105746086687, 0.0871265416208189, 0.013316572840267327, 0.016577508504269645, 0.04051242416608147, 0.00891247000254225, 0.04239604691974819, 0.021212474930507597, 0.09387439320562407, 0.03234139679989312, 0.023682155006099492, 0.11067968167481013, 0.009158822213066742, 0.005342312479115208, 0.03268575332185719, 0.04450602842553053, 0.06985151820117608, 0.002828145056810172, 0.006468754891102435, 0.03677417436847463, 0.06767937811673619, 0.026973325766448397, 0.047669232517364435, 0.019422826626396272, 0.006886995925015071, 0.029443384337355383, 0.030909756824257784, 0.03712058663950302, 0.12157771954662167, 0.07977507906616665, 0.035871437066816725, 0.049122131313197315, 0.027177674273843877, 0.04807811877981294, 0.02823581173288403, 0.08739964454434812, 0.0435017764539225, 0.02429892982036108, 0.040799034177325666, 0.02722388966503786, 0.013182440779928584, 0.031112947581277695, 0.06840456771897152, 0.021521319686144125, 0.08138762495946139, 0.023506522047682665, 0.016222106969507877, 0.03376663204107899, 0.009876909462036565, 0.04789930571860168, 0.07410512276692316, 0.056597528819111176, 0.07132041399017908, 0.03760655607038643, 0.03024497433216311, 0.05914277622650843, 0.0398389437032165, 0.08607086623669602, 0.04993682392523624, 0.0588347292796243, 0.0974806520389393, 0.06731114670401439, 0.06225663863006048, 0.026378451730124652, 0.0414875060232589, 0.0490315707429545, 0.059670962727977894, 0.03350525505084079, 0.02096924901707098, 0.025134255993179977, 0.02835107283317484, 0.026674162327253725, 0.04562925409118179, 0.11064437028835528, 0.034546974347904325, 0.029594420666398946, 0.11409975049900822, 0.037499824102269486, 0.038056512785260566, 0.054055168366176076, 0.052425415778998286, 0.016704614281479735, 0.027609834287432022, 0.01744324603350833, 0.04145147846429609, 0.03674880033941008, 0.001832157827266201, 0.02230432630312862, 0.11249927934841253, 0.04822585069632623, 0.08052832185057923, 0.027963059474132024, 0.011529782732395688, 0.0694587588077411, 0.0436251176870428, 0.08043979847570881, 0.051575831093941815, 0.02939596295618685, 0.018318434813409112, 0.08515858120517805, 0.050242796569364145, 0.041080130031332374, 0.04400146448460873, 0.03692153150041122, 0.07163283589761704, 0.02992920904944185, 0.01644238753215177, 0.06610673750401475, 0.026487597533559892, 0.06522951152874157, 0.004371358354546828, 0.0408231947949389, 0.03260260680690408, 0.020251777750672773, 0.03728475341631565, 0.048713423166191205, 0.053816033541806974, 0.03815464326180518, 0.04314200923545286, 0.024850725894793868, 0.04257143496943172, 0.03033762961422326, 0.06105333894083742, 0.047383175406139344, 0.05683387316821609, 0.0660476328630466, 0.08657211277750321, 0.013496187420969363, 0.1681881633703597, 0.05641656352963764, 0.0030381301758097834, 0.018863603509089444, 0.03762335087230895, 0.04541589776636101, 0.0887317476735916, 0.07184670801507309, 0.02678036365978187, 0.03764278029848356, 0.04076026438269764, 0.02634038512042025, 0.041458488049102016, 0.009542118295939872, 0.05897249415284023, 0.08613265003077686, 0.00906719851627713, 0.043769509939011186, 0.09611236921045929, 0.04916098645480815, 0.04274983242794406, 0.045617505893460475, 0.049639526987448335, 0.02019820767600322, 0.020473626100283582, 0.046351252458407544, 0.08322885623783804, 0.07912298358860426, 0.016011355583032127, 0.11138231740915217, 0.04042507709527854, 0.056411643090541475, 0.03644748838269152, 0.05198123297304846, 0.009302011258114362, 0.03694772931339685, 0.022257053351495415, 0.0046931433826102875, 0.02161362430342706, 0.03939377384085674, 0.017818130800151266, 0.10411692172056064, 0.047562415202264674, 0.04431391978869215, 0.06065533256332856, 0.02142052118870197, 0.09102395983063616, 0.017899603772093542, 0.04530853497271892, 0.0072976253068191, 0.030235801386879757, 0.014626900428993395, 0.02646372449817136, 0.05829970759805292, 0.020122067035117652, 0.06233446765691042, 0.040518635942135006, 0.05997055290208664, 0.06535060776514001, 0.04441278870217502, 0.009134171777986921, 0.04071094866958447, 0.05312029978085775, 0.023133856302592903, 0.06452128742239438, 0.019526456417224836, 0.023955051983648445, 0.018119149608537555, 0.05546180538658518, 0.028725690426654182, 0.04840309782593977, 0.04002972760645207, 0.027364144443708938, 0.019006086586159654, 0.06817266141297296, 0.03812290531641338, 0.05664809876179788, 0.02958550747280242, 0.06381886691087857, 0.06997509321081452, 0.038562008121516556, 0.014372956047736807, 0.09360538693726994, 0.016314726999553386, 0.047008446490508504, 0.03501036022498738, 0.027340165652276482, 0.027044187881983817, 0.06522896233946085, 0.008677832593093626, 0.06447423525969498, 0.04545213312667329, 0.04635937155399006, 0.037229637819109485, 0.01648471221415093, 0.017575702695467044, 0.055004349269438535, 0.07255599339259788, 0.033113571771536954, 0.027006679738406092, 0.05400047950388398, 0.02671734975592699, 0.015735180168121587, 0.10133394214790314, 0.13648420834215358, 0.19314575853059068, 0.14426636887947097, 0.19185783545253798, 0.24250533257145435, 0.12535978574305773, 0.13019857375184074, 0.15340714948251843, 0.14752012240933254, 0.17071070848032832, 0.1970453141257167, 0.2083839799161069, 0.12070355121977627, 0.13596523931482807, 0.15072449343279004, 0.09959203249309212, 0.16941229143412784, 0.20275116810807958, 0.12522599135991186, 0.147825219319202, 0.2698450139723718, 0.1138537359656766, 0.16932137834373862, 0.1407217825180851, 0.14829786348855123, 0.13961017888505012, 0.1804307650309056, 0.15239972854033113, 0.13343000347958878, 0.12311690414207987, 0.09049313128343783, 0.14749717520317063, 0.19044883840251714, 0.11308087079669349, 0.29436916520353407, 0.0698207932873629, 0.12144082298618741, 0.23123206483433023, 0.15250980388373137, 0.1881302206311375, 0.23016745399218053, 0.164165262831375, 0.09733211860293522, 0.18680581357330084, 0.17031048308126628, 0.11739096764358692, 0.2036365948151797, 0.11023789600585587, 0.1534443162381649, 0.08366704991203733, 0.10844180957064964, 0.2206666872370988, 0.09776649021659978, 0.21305575501173735, 0.16883059608517215, 0.14093583275098354, 0.19701932411408052, 0.07569382345536724, 0.20756366924615577, 0.19598631392000243, 0.13371712557272986, 0.07325243961531669, 0.21394180512288585, 0.12649089301703498, 0.09050508728250861, 0.1958931447006762, 0.1825359559734352, 0.14304820768302307, 0.17980532749788836, 0.10159700381336734, 0.2072275208774954, 0.1813245186349377, 0.3023305692477152, 0.18160225998144597, 0.18685344461118802, 0.1407219606335275, 0.127410295244772, 0.1682585634989664, 0.21820890193339437, 0.2130043983925134, 0.1439309329725802, 0.1380976670770906, 0.08309017110150307, 0.20903991971863434, 0.14105208276305348, 0.08947786584030837, 0.22324740188196301, 0.17994694411754608, 0.18155749363359064, 0.11692839441820979, 0.17999380332184955, 0.10672301781596616, 0.12502426077844575, 0.1101611356716603, 0.16498166980454698, 0.10400172555819154, 0.06459910160629079, 0.12914974096929654, 0.24256563949165866, 0.15094356058398262, 0.13376968447118998, 0.1889502047561109, 0.15418918017530814, 0.14138167054625228, 0.11816928017651662, 0.10946517926640809, 0.1059404453553725, 0.2168786319089122, 0.1579537836369127, 0.09383370124851353, 0.101767096639378, 0.1621555269230157, 0.12895437801489606, 0.16967487812507898, 0.11557189689483494, 0.27516636124346405, 0.14704396045999601, 0.09523385931970552, 0.2443184141884558, 0.12039178982377052, 0.36874800687655807, 0.1317523341276683, 0.13027587585384026, 0.07719440895016305, 0.15943592676194385, 0.1062655431451276, 0.09419247769983485, 0.1326863863505423, 0.1366082954336889, 0.24752443277975544, 0.10207899162196554, 0.2463103533955291, 0.08132219722028822, 0.18505211861338466, 0.10717187615227886, 0.16241829172940925, 0.23197287664515898, 0.05157771985977888, 0.07058973991661333, 0.12039075823849998, 0.19721787830349058, 0.14702277956530452, 0.15360163670266047, 0.1274448644835502, 0.10099010512931272, 0.07689872247283347, 0.12938878673594445, 0.10216945942374878, 0.21852573961950839, 0.20404097624123096, 0.20345687633380294, 0.1971763774054125, 0.1455791835905984, 0.12167819892056286, 0.12347861207672395, 0.1757628342602402, 0.10726259628427215, 0.15816053113667294, 0.10498759453184903, 0.13427652680547908, 0.09899518991005607, 0.11697986978106201, 0.22647494275588542, 0.20339069160399958, 0.07798426187946461, 0.13501008041203022, 0.14084431109949946, 0.09817900558118708, 0.16698972845915705, 0.1751888424041681, 0.11026448715711012, 0.150445505278185, 0.13681189622730017, 0.09873386487015523, 0.16861394833540544], [0.060936970185139216, 0.031119914492592216, 0.031780388817423955, 0.01872461780294543, 0.0483522532886127, 0.04705863422714174, 0.029501500066544395, 0.049642191297607496, 0.038785531869507395, 0.006592134623133461, 0.015559452585875988, 0.038144750433275476, 0.004695409716077847, 0.01319650633377023, 0.020931193539581727, 0.03278511947428342, 0.034556637110654265, 0.07091324208886363, 0.02528156303014839, 0.09667761856690049, 0.0723357536480762, 0.05898840579902753, 0.024307449675688986, 0.042385107662994415, 0.03628804908657912, 0.05010963672248181, 0.09164872200926766, 0.07170628625317477, 0.021889321033086162, 0.05970392521703616, 0.04639887607481796, 0.07147153752157465, 0.017816934087022673, 0.023646743429708295, 0.0039228312016348355, 0.055811405181884766, 0.04135162991588004, 0.02762749183602864, 0.014732752952113515, 0.0254048801434692, 0.03900270283338614, 0.06489745239377953, 0.024988973163999617, 0.01820706071157474, 0.021009412193961907, 0.09055157541297376, 0.017348830006085336, 0.026609614033077378, 0.04526129356236197, 0.07229339928016998, 0.01582929377036635, 0.06040824933734257, 0.041775021454668604, 0.06710064393701032, 0.062251963099697605, 0.046398107951972634, 0.019417158473515883, 0.011044640796171734, 0.042003161361208186, 0.029949406598461792, 0.007686296394240344, 0.03244700812501833, 0.08109131507808343, 0.007089029859344009, 0.03886484519171063, 0.007192872089945013, 0.036202271658112295, 0.023896659804449882, 0.04994514340069145, 0.020568524523696396, 0.015550448479189072, 0.019713661313289776, 0.06654720957158133, 0.027481982651806902, 0.009204468933603493, 0.06068409820727538, 0.05377786488679703, 0.059990665104123764, 0.018359844798396807, 0.05092644445539918, 0.06917301710927859, 0.10931797427474521, 0.04992874193703756, 0.06402661631000228, 0.04885090602329001, 0.04130263703700621, 0.010303450490027899, 0.00472292576887412, 0.053076720869285055, 0.09640691278036684, 0.03261804718931671, 0.008542263549315976, 0.030436476263275836, 0.023448419306077994, 0.020970922560081817, 0.021058609163446818, 0.006411737076632562, 0.021051352814538404, 0.05696899599570315, 0.006819765694672242, 0.028765308125002775, 0.019340969593031332, 0.016519246200914495, 0.02399420212896075, 0.04947752728185151, 0.032933612092165276, 0.07456180333974771, 0.21304794761817902, 0.023323987115873024, 0.006903342191435513, 0.036884813744109124, 0.012624310475075617, 0.05774276658485178, 0.04737114148156252, 0.05015798764361534, 0.07120841648429632, 0.041493120370432734, 0.03049240080144955, 0.056610197279951535, 0.03395241015823558, 0.008311302553920541, 0.0567194043105701, 0.04271694786439184, 0.025371754381922074, 0.1331180936540477, 0.049939848177018575, 0.04593248821038287, 0.03600985131924972, 0.03047273388801841, 0.05039873292844277, 0.08619976986665279, 0.026954122695315164, 0.010949989136861404, 0.029373949000728317, 0.030834439967293292, 0.0333047156163957, 0.04068514048412908, 0.04102856190002058, 0.05951455139438622, 0.026492028155189473, 0.03176723053911701, 0.0018233550281365751, 0.02450153428071644, 0.014596931578125805, 0.03749934912775643, 0.01934970096044708, 0.046536529625882395, 0.040072059709928, 0.05513881900697015, 0.06618801751756109, 0.08794708977802657, 0.03345290395373013, 0.04864275957515929, 0.08512939253705554, 0.04287357813154813, 0.05159906402695924, 0.026306977342756, 0.05891786466236226, 0.023278064873011317, 0.048885512369452044, 0.0727031019050628, 0.0357484335108893, 0.05337264483387116, 0.04686749780375976, 0.03792112649534829, 0.013382619345065905, 0.07531187715358101, 0.09747308955411427, 0.033654137296252884, 0.06731853107339703, 0.012251429507159628, 0.03948979290726129, 0.07895738075603731, 0.026336282899137586, 0.06975198877626099, 0.026661466035875492, 0.023855522558733355, 0.07406175907817669, 0.046510205647791736, 0.04245590484060813, 0.03334655048092827, 0.023979550278454553, 0.04942584040691145, 0.05471720120112877, 0.07033504967694171, 0.01401524828906986, 0.027110630508104805, 0.06349529794533737, 0.053111850429559126, 0.020628093006962445, 0.011077479903178755, 0.11924905309570022, 0.040839611101546325, 0.01596452792000491, 0.013495666989911115, 0.04683625709731132, 0.06711930895107798, 0.02157625902327709, 0.01449307635994046, 0.02327809270354919, 0.042293014557799324, 0.047891461217659526, 0.010823178363352781, 0.10544976699748076, 0.03122441630694084, 0.03126180199615192, 0.097026791627286, 0.011993172320217127, 0.03654185245977715, 0.00914020080017508, 0.015837975042813923, 0.06193840570631437, 0.022245164145715535, 0.020668588294938672, 0.024419372966804076, 0.004131890027565532, 0.010673147644411074, 0.05178771425562445, 0.02424255813821219, 0.01692860187176848, 0.0032861378394954954, 0.07845807122066617, 0.035763061241596006, 0.03422194335144013, 0.05068479375040624, 0.023157911164162215, 0.015359225781139685, 0.032081904864753596, 0.04854946419072803, 0.0068273926535766805, 0.013969827923574485, 0.03708540883962996, 0.03535817886586301, 0.053307877606130205, 0.05053507658885792, 0.03918881491699722, 0.027689112357620616, 0.03926024663087446, 0.038965287458267994, 0.020185472421871964, 0.07033684567431919, 0.024622936653031502, 0.007587592608615523, 0.05890928543522023, 0.02945754265965661, 0.036559856962412596, 0.0351342729118187, 0.021441462740767747, 0.07413230021484196, 0.03681960493850056, 0.012338551150605781, 0.012449264741007937, 0.046616952458862215, 0.0191822019405663, 0.025718966317072045, 0.009082287306227954, 0.06733896239893511, 0.03726554292370565, 0.03513281830237247, 0.03966210475482512, 0.04378716563223861, 0.028741301503032446, 0.04210152561427094, 0.0018047001026388898, 0.027000221198250074, 0.03682226553792134, 0.0942613415827509, 0.025431059402762912, 0.0012160163896623999, 0.012834092431148747, 0.07404021453112364, 0.055694190377835184, 0.03620198964199517, 0.04975491981895175, 0.022074577791499905, 0.06221793562872335, 0.06014179976773448, 0.054212165996432304, 0.04134746646741405, 0.01370096173559432, 0.023390682072204072, 0.016769841640780214, 0.11976894238614477, 0.03478987928247079, 0.04373052863229532, 0.021590543510683347, 0.029346723313210532, 0.11006945816916414, 0.08217026421334594, 0.03664242089143954, 0.07824310814612545, 0.033422397973481566, 0.07473480538465083, 0.002201255465479335, 0.05968068857328035, 0.07934378736536019, 0.014634461986133829, 0.05520012782653794, 0.005313568635756383, 0.010114952401636401, 0.008982644703792175, 0.10972634103382006, 0.007969614980538609, 0.11053998721763492, 0.026854988464037888, 0.06526891214889474, 0.044716705597238615, 0.07019087264779955, 0.0073476103443681495, 0.0760632126184646, 0.02817110944306478, 0.029098033337504603, 0.03138787062198389, 0.03037611739273416, 0.04529997801000718, 0.04273609156371094, 0.027152090588060673, 0.06747358798747882, 0.05263571445539128, 0.008161125260812696, 0.030196692059689667, 0.015549289801128907, 0.03176088517648168, 0.04834302839299198, 0.03829211498668883, 0.049825550013338216, 0.03718665262567811, 0.057268905293312855, 0.049388907427783124, 0.05364443044527434, 0.027205777550989296, 0.02101398382365005, 0.05050200277764816, 0.059209925748291425, 0.05248792687780224, 0.022073993350204546, 0.04990253299183678, 0.024174241589207668, 0.008697974481037818, 0.02583073375717504, 0.04780288589245174, 0.03989112410636153, 0.021024234738433734, 0.041977219589171, 0.08738799282582477, 0.03248935878218617, 0.05329340943717398, 0.023101172118913382, 0.018720283660513815, 0.0303423348304932, 0.04597961458784994, 0.03428683674428612, 0.12798559328075498, 0.10478735566721298, 0.10479258038685657, 0.13026762317167595, 0.19055999728152528, 0.1298779362696223, 0.10387887043179944, 0.17377991956891492, 0.16644803486997262, 0.14815946778981015, 0.07463721296517178, 0.15577929094433784, 0.13098422612529248, 0.15319213445764035, 0.06227403457160108, 0.17181684990646318, 0.0965448706119787, 0.17564181966008618, 0.06654738026554696, 0.24000827281270176, 0.14737688790773973, 0.14850269624730572, 0.14551950007444248, 0.16556140588363633, 0.1168238183890935, 0.16730557166738436, 0.12965775589691475, 0.2198799661709927, 0.17849908821517602, 0.1807844132417813, 0.1374057331122458, 0.1426314323907718, 0.0760571270075161, 0.17875322926556692, 0.09908455933327787, 0.1438468773267232, 0.1358033620635979, 0.16374709230149165, 0.12521278113126755, 0.17883220862131566, 0.09130347491009161, 0.10375344005296938, 0.10294704465195537, 0.14175836986396462, 0.15535705344518647, 0.29289852536749095, 0.11217656385269947, 0.17700732685625553, 0.10388275928562507, 0.14509524393361062, 0.10060090804472566, 0.13161494774976745, 0.23146547027863562, 0.17277999431826174, 0.16875782108400017, 0.22122258553281426, 0.1491232801345177, 0.1383795792935416, 0.13344134349608794, 0.13212143385317177, 0.11865178748848848, 0.14858324895612895, 0.2538934402400628, 0.13892366259824485, 0.23580684122862294, 0.12599191744811833, 0.10135970951523632, 0.24359324685065076, 0.11195805331226438, 0.12388852250296623, 0.12825819896534085, 0.10501968499738723, 0.21677400392945856, 0.11576714852708392, 0.20636719360481948, 0.1550570031395182, 0.14261949865613133, 0.09972606436349452, 0.08799221235676669, 0.10714673218899406, 0.25508102495223284, 0.2524613030254841, 0.10226466954918578, 0.11087341932579875, 0.16686098068021238, 0.22299818869214505, 0.1526376759284176, 0.11509662552271038, 0.1033497488242574, 0.25319730571936816, 0.14317569381091744, 0.13043662504060194, 0.09554996227961965, 0.06833724008174613, 0.16796424257336184, 0.11763014699681662, 0.1213508153159637, 0.11062030243920162, 0.18807540560374036, 0.08478844247292727, 0.10095880876178853, 0.11750317295081913, 0.0897913341759704, 0.11827751499367878, 0.2072822320042178, 0.12740613921778277, 0.2527239639312029, 0.23004295129794627, 0.13972918968647718, 0.10564711890765466, 0.15260819782270119, 0.23301636596443132, 0.1406318787485361, 0.1686936549958773, 0.11602235084865242, 0.1623085280880332, 0.1978777366457507, 0.3428415907546878, 0.17438298877095804, 0.1649847422959283, 0.13009635033085942, 0.11040289769880474, 0.18154067656723782, 0.16872253938345239, 0.2585621428443119, 0.23213978565763682, 0.16605321230599657, 0.18332910403842106, 0.13402624492300674, 0.16755006479797885, 0.29442354978527874, 0.17259871732676402, 0.21031280688475817, 0.21602712135063484, 0.09187430521706119, 0.14628587145125493, 0.08930173935368657, 0.18281115917488933, 0.11310679401503876, 0.09936056405422278, 0.10084932713652961, 0.16984352376312017, 0.10484605954843573, 0.143192392133642, 0.12075638471287675, 0.08977068020612933, 0.06299897184362635, 0.16669285454554483, 0.16548818559385836, 0.14642281254054978, 0.22947899327846244, 0.1560797420097515, 0.13911124784499407, 0.10279014721163549, 0.1572297592065297, 0.11437306864536367, 0.11423889576690271, 0.15683407575124875, 0.09499447958660312, 0.10722777471528389, 0.13255232479423285, 0.15447364537976682, 0.12402154505252838, 0.1142989429354202, 0.12547035090392455, 0.14566957717761397, 0.28689229453448206, 0.2328937780112028, 0.19735930196475238, 0.15980272582964972, 0.15933732502162457, 0.13635605428135023, 0.19507863762555644, 0.14588012447347865, 0.157062241632957, 0.21945324609987438], [0.009712224109534873, 0.028539648847072385, 0.03194208795321174, 0.06692519280477427, 0.012766126546921441, 0.035737412617891096, 0.06257600703975186, 0.012969985236850334, 0.044391299816197716, 0.10173659436986782, 0.0493353540514363, 0.03541088619385846, 0.021648598012689035, 0.04357735306257382, 0.014090894474065863, 0.03114567072771024, 0.04953280986228492, 0.021036908765381668, 0.09460439934628084, 0.006398670175258303, 0.06301566274487413, 0.04263627270120196, 0.0679850390588399, 0.03374172556505073, 0.013306877608556533, 0.06317204810329713, 0.049165532109327614, 0.05078878719359636, 0.048705619483371265, 0.03342760042869486, 0.08063355839112774, 0.03503189735056367, 0.030208614662114996, 0.025838420551735908, 0.03154858641210012, 0.023883783542260062, 0.01745492743793875, 0.03972574391809758, 0.045905937877250835, 0.013908508899476146, 0.028043046295351814, 0.033782573373173364, 0.04696047035395168, 0.02216821456386242, 0.00505053804772615, 0.01416053297361941, 0.03926854384189937, 0.02223890598543221, 0.013703857966902433, 0.051153385793440975, 0.02860481312382035, 0.010739577282947721, 0.02601166008389555, 0.008541983388568042, 0.02980724450026173, 0.03347235564433504, 0.015199971094261855, 0.13838560553267598, 0.040025786802289076, 0.07875412877183408, 0.01889520230179187, 0.01576846363605, 0.07780322979670018, 0.023221661649586167, 0.060354506713338196, 0.03602188895456493, 0.060970088525209576, 0.06334950303426012, 0.043406139593571424, 0.016259776530205272, 0.05568297652644105, 0.03847937368846033, 0.01840353688749019, 0.014738347817910835, 0.04801710310857743, 0.00970930097537348, 0.034743899523164146, 0.040007882489589974, 0.04191213323792908, 0.026656085465219803, 0.029413433112495113, 0.06100929247622844, 0.030369682972377632, 0.09544363478198647, 0.03532784729031846, 0.036303841989138164, 0.02391676087427186, 0.04595383237756323, 0.025001407848321833, 0.06340663356240839, 0.046045264971326105, 0.07357123657129705, 0.020081673792446963, 0.022570835244550835, 0.057973793445853516, 0.03423326481424738, 0.06261883638217114, 0.03628282807767391, 0.018528711225371808, 0.02890813073463505, 0.030243326764320955, 0.029049656441202387, 0.0763286862638779, 0.012452056143956725, 0.020171557152934838, 0.01834538961702492, 0.033593685657251626, 0.008690229242347414, 0.05153462705493439, 0.03717432926350739, 0.01680809749814216, 0.04822122340556234, 0.04131573594349902, 0.060389057398424484, 0.03112582013272913, 0.028019564742862713, 0.03825107793090865, 0.008944598503148882, 0.009394685093866428, 0.04032609685964417, 0.05589541629888117, 0.04492366831982508, 0.03354884509462863, 0.08530756735126488, 0.01049112664986751, 0.041602702185628004, 0.0866569254139904, 0.016416542239312548, 0.0592952059378149, 0.06427955508115701, 0.06722452322719619, 0.10113826749147847, 0.05487226924742572, 0.015145749785006046, 0.024811230650811922, 0.03927572412067093, 0.013130142560839886, 0.026612764449964743, 0.01784780000889441, 0.047123434851528145, 0.009789753494260367, 0.00967156833212357, 0.049515966820763424, 0.04844374896492809, 0.03619000024627894, 0.025131476650130935, 0.030772899226576556, 0.011394826888135867, 0.07179058680776507, 0.10405610271845944, 0.02032936372415861, 0.018259474891237915, 0.008263805102615152, 0.028079803014406934, 0.021219610680418555, 0.05401421294664033, 0.025711739654070698, 0.11566287677851506, 0.009405059390701354, 0.018251600704388693, 0.054697385858162306, 0.06342366585158743, 0.06657726655248553, 0.0580246565368725, 0.015207691285468172, 0.027795896276074927, 0.018465730718162376, 0.04087721201358363, 0.032585311055299826, 0.06262947135837749, 0.05320168740581721, 0.060892931142007, 0.011735705520550255, 0.047382488919538446, 0.006389765794665436, 0.034915654759970494, 0.0285626183176646, 0.0414639799419092, 0.03593110574001912, 0.05085869750473648, 0.007383624915746623, 0.02848158506822074, 0.035538376032491215, 0.07077207817928866, 0.03736897975613829, 0.03848920343443751, 0.0372631198115414, 0.04507079538598191, 0.03693175829539541, 0.021323900982679334, 0.03299994525150396, 0.011494948175823083, 0.029297105174919125, 0.019799750443780795, 0.0672104669502005, 0.06828450306784362, 0.061803776407032274, 0.008760201708355453, 0.05351891843019985, 0.020942758055753075, 0.04808295016118791, 0.06840366229880601, 0.049809998308774084, 0.01237698326804093, 0.04949631475028582, 0.009756565577845322, 0.013475592822942417, 0.01641030077735195, 0.07327839994104579, 0.029327542506507598, 0.03895346504577901, 0.016484758598380722, 0.019497998764563818, 0.05436789084342308, 0.04676953059970401, 0.015646816355001647, 0.014591858998755924, 0.004814962749151164, 0.008064689664024627, 0.023824630661692936, 0.07851967689930461, 0.024001976125873625, 0.01925400472828187, 0.02189169405028224, 0.023393179399135988, 0.030528361567121465, 0.044242057629162446, 0.03161316810292192, 0.055192621002788655, 0.1064736487751361, 0.10476434908923693, 0.036244433067622595, 0.06844534873380326, 0.024543599211028777, 0.02088494846248068, 0.06939730898011476, 0.015949271219142247, 0.048036788575700484, 0.011983978965872666, 0.0509838718426181, 0.04896512626146432, 0.027081493790319655, 0.010236491143587045, 0.034265347858308814, 0.03349942548084073, 0.04293789264920633, 0.02742520835454343, 0.031019462949188892, 0.07024918319075368, 0.02475301287631737, 0.05715452920412645, 0.038421475037466735, 0.04250697573297657, 0.041746344868442975, 0.022093446896178648, 0.03436266939388588, 0.015419109677168308, 0.017355303389194887, 0.06062900116376113, 0.07752237885142677, 0.02381619058724027, 0.005588803378486773, 0.05079993796243798, 0.04965216576238163, 0.0342899389215745, 0.07070980456774123, 0.08995846583275124, 0.06231933526578359, 0.01978130436327774, 0.051688155144802295, 0.05699700093828142, 0.061084134358679876, 0.09436492313398048, 0.011890264268004103, 0.041606821105233394, 0.041369300452061, 0.08659195780637674, 0.010111593255714979, 0.07777023391099647, 0.04153592373768333, 0.03347022196976468, 0.02576018334366381, 0.031183813407551497, 0.04010685901448596, 0.04632243486412335, 0.12312941675190814, 0.0172453931736527, 0.06039417079591658, 0.06805163939134218, 0.07473484249203466, 0.02881141219404526, 0.05173129989998415, 0.03498890844639391, 0.02520002883102279, 0.08642009866889566, 0.03182232387189288, 0.015343055310950149, 0.011001721468346659, 0.007881904257374117, 0.062275555974338204, 0.0456214392761467, 0.033828901941888034, 0.037703873895225115, 0.00772604396843235, 0.03851763511192985, 0.08533928674296476, 0.042624249908840284, 0.042675881122704595, 0.015027239933260716, 0.06156461560749449, 0.05400048321462236, 0.018480072722013574, 0.02550517769122962, 0.050221886558574624, 0.03367983044881839, 0.03350322898768354, 0.028603762984857894, 0.05013558220525738, 0.034903342530014925, 0.05208015012613032, 0.0658941938308999, 0.052839448835584335, 0.03523850013152696, 0.02287216018885374, 0.02598587416287046, 0.02794499374431325, 0.015897834819043055, 0.018108009971911088, 0.017998641524172854, 0.055686490595689975, 0.005034023406551569, 0.02531468137021875, 0.013811869212077, 0.05279322787828278, 0.012241138701938326, 0.0520208636589814, 0.006362477024595137, 0.04950175469275564, 0.04844592716835905, 0.07024057427770458, 0.06693117451504804, 0.037820409634150565, 0.022721444838680327, 0.01809872941521462, 0.02794574887957424, 0.0487669839640148, 0.03488496324280277, 0.01751995070662815, 0.019726673017430585, 0.05156827231985517, 0.05583603706327267, 0.07112302497262135, 0.1097363600274548, 0.18639717221958563, 0.15843855449929833, 0.11947903723921627, 0.10266014520311728, 0.09331447989097796, 0.13431214989395812, 0.08928410592488945, 0.19449550251010805, 0.29752525209914893, 0.18776637531118467, 0.20567028725054115, 0.15072309819515795, 0.1686224533477798, 0.1647233430412598, 0.09076503192773089, 0.056068978665280156, 0.10210471446043812, 0.1581885397899896, 0.15737593261292204, 0.17390275985235348, 0.10167077329242602, 0.12603983050212264, 0.09987990415538661, 0.1319377523032017, 0.14910824422258884, 0.1361663019633852, 0.13396782305790111, 0.13999841117765754, 0.1801286663976498, 0.13780818495433778, 0.14665761322248727, 0.14232165995053947, 0.22777760488679633, 0.17532723810290918, 0.0714222143869847, 0.09217060025548562, 0.19587551127187908, 0.1364824568736367, 0.17013361444696784, 0.11612939822953194, 0.18906743440311402, 0.11670315259834751, 0.11874717572936788, 0.22426690498832613, 0.12160655198385939, 0.15342864207923412, 0.09676127345301211, 0.07287426342372783, 0.14197740732925013, 0.11631008892436512, 0.09315309987869114, 0.12173293973319232, 0.15642378682969138, 0.1626762919477187, 0.281509289634414, 0.16890736384084448, 0.1591511201695539, 0.08923427070840262, 0.14912495738826692, 0.10645939211826771, 0.1615164932445623, 0.1244497048901394, 0.10849990489077754, 0.15272167220246047, 0.15705352881923318, 0.11498525884235278, 0.13224307185737416, 0.09554030693834648, 0.07224266606499441, 0.14668039715616032, 0.1505671432823874, 0.11883249302627519, 0.11490173012134619, 0.16148046939633787, 0.10142006096430123, 0.11250560244661756, 0.11452042948803864, 0.1385141455102712, 0.16667565156240016, 0.12895332416519523, 0.2161066498956643, 0.0758611703349743, 0.1704953669104725, 0.15427684265887365, 0.11050460903788917, 0.12338413667748682, 0.19760818860959262, 0.15025692555354908, 0.15777264023199677, 0.10657110018655658, 0.16149281873367727, 0.08397649580729194, 0.10036169900558889, 0.18707205163082108, 0.15935684350552037, 0.17020644881995395, 0.08938122336985543, 0.15812189492862672, 0.16374379716580734, 0.14257363392971456, 0.15869815775658935, 0.11989401653409004, 0.1180374005343765, 0.09370668267365545, 0.12853637075750157, 0.14465709478827193, 0.11877128068590537, 0.1277515644324012, 0.160310102510266, 0.07397221896098927, 0.10837785870535299, 0.15855428500799462, 0.2779347205068916, 0.14610601938329637, 0.1886822300730273, 0.17539383843541145, 0.12685841938946396, 0.12043444847222418, 0.09427728291484527, 0.10537192312767729, 0.15264775429386646, 0.10265714692650363, 0.14010048616910353, 0.14251209504436702, 0.11357134135323577, 0.16079457651358098, 0.13324155734153464, 0.1984162538428791, 0.18841337965568528, 0.10301331101800315, 0.16093559941509739, 0.1118494474212639, 0.08056499878875911, 0.14745522901648656, 0.12437424331437796, 0.10934109959634952, 0.14982302149292082, 0.11913478461792693, 0.11970146631938405, 0.11000403785146773, 0.10848116566194221, 0.0742895613075234, 0.1549018349032849, 0.13292374002048746, 0.08889186603482813, 0.07859743913286366, 0.08428070956142619, 0.16487785818753764, 0.17640920035773888, 0.07628895167727023, 0.07507235641242005, 0.09882465179543942, 0.20567396830301732, 0.12810292682843283, 0.1631266123149544, 0.13362284313188866, 0.28490989934653044, 0.1297225008602254, 0.07762585650198162, 0.1442341596703045, 0.10093076300108805, 0.14179800054989755, 0.12733759445836768, 0.2899017627350986, 0.07579946075566113, 0.15143413504119962, 0.08812724612653255, 0.1034290250390768, 0.17132701759692281, 0.13864650012692437, 0.12558873830130324, 0.10638218649546616, 0.10340098669985309, 0.13003954634768888, 0.19069230736931786], [0.0698050152277574, 0.010086568036058452, 0.08750343389692716, 0.04754054782097228, 0.03750419164134655, 0.02679852030269103, 0.019087394430243876, 0.04396357042423915, 0.06797901281970553, 0.04322569751820993, 0.03801300437771715, 0.02355097112740623, 0.030397699047171045, 0.03661688358988613, 0.009939726696757134, 0.02228735338576371, 0.004764299574162578, 0.03333792672492564, 0.020774169934156816, 0.04221260656777304, 0.046197902483982034, 0.010902240283030551, 0.03671579332149122, 0.06773046756279655, 0.06192035296407994, 0.010094086919707479, 0.00734222559913178, 0.03560074983397499, 0.0282577514735749, 0.07609444961417466, 0.08918258754420094, 0.04660605773096904, 0.024044196907198057, 0.028061479388270527, 0.026324898353777826, 0.028444776398828253, 0.02078319444990484, 0.02130787801434053, 0.05051039646787103, 0.024582543410360813, 0.06432625843444839, 0.04103828774532303, 0.028004491723550018, 0.0579150153498631, 0.10077424405608326, 0.014938270342099713, 0.01197121217046515, 0.05851170208188705, 0.07685705830226652, 0.08158909578924067, 0.018222302569483873, 0.031643495967728086, 0.035168215035810135, 0.08617146435426548, 0.034952710193465464, 0.04435485665453598, 0.06036197271896526, 0.046214277972467244, 0.013171430091460934, 0.045521074935095385, 0.00977001329374616, 0.03468188195256516, 0.060100213522673585, 0.009474590278841788, 0.024084291435428895, 0.043959076720057055, 0.01028368431434501, 0.03393794198927935, 0.026036097151518334, 0.062158482178347185, 0.01308898954448523, 0.01891861335025169, 0.06079478953324724, 0.048162493549170904, 0.056182976259151474, 0.017711948021315038, 0.017029194423230365, 0.10711898328736424, 0.03015996317117242, 0.08382083033211529, 0.026971839615725912, 0.03088781151745934, 0.015424280591105344, 0.04347141890320927, 0.05326139318640344, 0.05202684165851679, 0.051443962584016845, 0.030053129157749936, 0.062214699864853173, 0.041626803431427106, 0.0192321540453122, 0.05050364663475193, 0.026176387182204053, 0.10309557066648267, 0.010727471926657017, 0.05359444679925218, 0.015968101361067966, 0.019003589259227738, 0.05018407042371109, 0.0030249946257754345, 0.014725446508236928, 0.028933567846252117, 0.02280934109876398, 0.012334028688201215, 0.05219555408984888, 0.05989124329062179, 0.011612844828050584, 0.0162265505787218, 0.028172495403850917, 0.008451916346530197, 0.051237571315141395, 0.03670784120913595, 0.015079514032549923, 0.03926531549950596, 0.033001822885125875, 0.04216712404740974, 0.02176398156734649, 0.11480903587653302, 0.027872228019987233, 0.037505000582314096, 0.013500028962880606, 0.011672179534798488, 0.05782109285064507, 0.02825457508151885, 0.041394106738152914, 0.04922615073155612, 0.02270062017487362, 0.04613926539605018, 0.04658586760342587, 0.05933566040766891, 0.03136050763714593, 0.018621911985974293, 0.01378599237796152, 0.05840769750648178, 0.05803680920507759, 0.08465432896628045, 0.04894941499514971, 0.08151836169417948, 0.02676449283171678, 0.037021914395154454, 0.017584124216227792, 0.048695292498450726, 0.023734751011943445, 0.04213770902424585, 0.03251841015298851, 0.059609327363432385, 0.04033506200357806, 0.008840925111144315, 0.06364000189932995, 0.042810710801859386, 0.043638305651256815, 0.0025329583695565816, 0.048483286882401444, 0.05042385833803564, 0.05507544701686129, 0.06056603364413604, 0.01947538181411801, 0.004412545231389231, 0.03902223616023548, 0.05872131427167915, 0.05482284592289943, 0.018289828731212765, 0.020949003228452057, 0.06659947903244756, 0.06085600929509383, 0.030416356639761943, 0.014890439852024429, 0.08695143187651411, 0.02037299458606867, 0.05089537073217798, 0.06358511265716515, 0.08341198117705062, 0.05319229181623086, 0.04107201093574986, 0.030319179822981823, 0.04076942248502746, 0.037866437633056194, 0.010449628534843214, 0.05436664403532632, 0.051268637616885826, 0.01630519411264686, 0.041902322045643814, 0.03332451240567025, 0.04085435386514291, 0.04888382027274929, 0.03371473736478947, 0.029833542503183708, 0.018097480751748662, 0.046522851844201796, 0.01656205698964186, 0.03611534761148505, 0.026074302913912106, 0.03211460018064827, 0.02171757321775658, 0.07249493690324016, 0.06365622524754144, 0.08120012877043337, 0.04352126896264963, 0.10369731142418459, 0.024488641320203897, 0.10793905647005886, 0.012724283333227504, 0.031066296178323682, 0.03833370494248811, 0.009375207428092835, 0.045126872064429335, 0.014316652086563408, 0.02476379999279743, 0.019313165030325763, 0.05528373076231219, 0.04525679614744149, 0.025973569354391657, 0.0359225895954296, 0.012890857451566262, 0.05458362204080913, 0.046047331852605566, 0.05859856304596178, 0.05068312391813379, 0.01793321378499968, 0.06376006655045785, 0.03343747841427103, 0.02735895868681837, 0.007285580713869422, 0.014277180034696357, 0.019860155698552262, 0.1811183796962723, 0.12510508066043258, 0.00848402258270653, 0.04120171237445902, 0.044368003800627775, 0.021146663129911758, 0.03497911209706217, 0.053710195861640386, 0.06549597965204157, 0.020671126439992804, 0.10496843970031478, 0.03881316944898572, 0.022323210250760894, 0.03982293186709285, 0.06891855693538673, 0.08961516316048801, 0.05440355103928596, 0.02964430968859233, 0.03781931496632751, 0.01777392106305342, 0.10643703863024712, 0.05591255991021171, 0.028055981929355767, 0.0021601103344437433, 0.030864270593156107, 0.010215085749223363, 0.016542506964469794, 0.02819323472067481, 0.07508469832828268, 0.022678387285850476, 0.06366578410961665, 0.01851600009104004, 0.049587313187657855, 0.05392647995904554, 0.0539202904474223, 0.01518115765065886, 0.03845883846224751, 0.059402004699222744, 0.02246675459900871, 0.010809804862219607, 0.013934674243500922, 0.033170709721161984, 0.06391772840288468, 0.04066438632435165, 0.06320128872175701, 0.02034811408520909, 0.027339948574081063, 0.014753100786037976, 0.08527653073542751, 0.06591182725969702, 0.045154231338528916, 0.04700401215814054, 0.03210946451872587, 0.04505575205257628, 0.020880074407614302, 0.033825814607553184, 0.026901476594503038, 0.04001522233011201, 0.050232788707944565, 0.03579154115868732, 0.06122297534602694, 0.02581534532509977, 0.03888835271936841, 0.03906802667188458, 0.013486179559549782, 0.03069145037443377, 0.0385003170958953, 0.05123423907207325, 0.03933338157366961, 0.02394577328232117, 0.03616726826294325, 0.055456332047469914, 0.06671459355857223, 0.01076455333532067, 0.05374341068090871, 0.012113810280425241, 0.06189473773702048, 0.05188705814362038, 0.02722603632719256, 0.047739751389599405, 0.08623826506664045, 0.0288951505717705, 0.021539040317293257, 0.005513948044608696, 0.03798657278821338, 0.010491483808436897, 0.038007991170161404, 0.03460947802523151, 0.04490045022976119, 0.054102769718156196, 0.03878574338159524, 0.04694157156336587, 0.026694775478972588, 0.05432354380900506, 0.012883194776804885, 0.0890810543205589, 0.10591701575322077, 0.019975043869635556, 0.031101321837923024, 0.055636503238929436, 0.055898896971484646, 0.006741785455233185, 0.0392849601485068, 0.030188955170160625, 0.06801232040743344, 0.04093745585123543, 0.04348074769950472, 0.03601211115892511, 0.03985784249380231, 0.04771671141497791, 0.07139535606256686, 0.07038172334432602, 0.028157515152997803, 0.13682093558600172, 0.03896107948094141, 0.05457171057059895, 0.04480338473513257, 0.006009767166688107, 0.03643239680968691, 0.1351594747393392, 0.023669017136853654, 0.03282815290731378, 0.08744998442125507, 0.03991553334344644, 0.007525320852437289, 0.07314917718758807, 0.048027355878730305, 0.16643519571516663, 0.1217448734678328, 0.2252106645028107, 0.18396749946987256, 0.1541637393529527, 0.09369531297124922, 0.1357999481842853, 0.09333623223938048, 0.18079343775752932, 0.16584186349064112, 0.1493616431253031, 0.10445735228131525, 0.16909049620153382, 0.13059823511866853, 0.15518586966209114, 0.18920584494480863, 0.14507348416373134, 0.12912590318592265, 0.1813814858905971, 0.11650494721834548, 0.20174670091364533, 0.07563120103441179, 0.15456831373739988, 0.13266756548546255, 0.11007159555447288, 0.1351125561632216, 0.10981424842611887, 0.1232521902420558, 0.09918076393660158, 0.14156140387058258, 0.1299197637126781, 0.10562197494436987, 0.0959880743175745, 0.10201624303590506, 0.11557891019037925, 0.09709791163913906, 0.13139493064954877, 0.13527225150028244, 0.13323596154805273, 0.15181484195636585, 0.1856663794023916, 0.16799765406176448, 0.17770648933947086, 0.1166541560087353, 0.19199970440240577, 0.133444297243841, 0.12294399857637472, 0.12100271094823256, 0.1789021337754093, 0.1845163622056134, 0.18066154327243567, 0.16125654859934002, 0.10136967655853368, 0.2915417606709525, 0.15837514540180564, 0.14088875090237707, 0.14071228302782401, 0.1470234029693529, 0.08272346851299517, 0.18350802100030705, 0.1764368824660778, 0.11253796008531936, 0.14406658272491768, 0.17508403630927205, 0.2305603469721973, 0.11567271023523062, 0.10690951952710748, 0.13489961915183812, 0.0771776660985779, 0.14700781786814332, 0.13623866136185825, 0.11614843431743793, 0.13463210460031405, 0.19708821026142687, 0.11182615882717073, 0.09893583293887787, 0.11658927003736608, 0.21478488488355651, 0.12111320189433172, 0.1393540043500252, 0.11675320303766057, 0.09987338067730889, 0.1618563523516059, 0.14217462565284222, 0.16426190530182794, 0.13379994925344363, 0.15266758447978646, 0.07912177388789132, 0.20389832061482593, 0.13234388519776985, 0.11550436145626009, 0.18138895189622417, 0.10378228733316064, 0.14946325798518956, 0.0665023986948654, 0.22556996787898242, 0.1867640603450127, 0.2350424588075839, 0.16255129943601787, 0.16584313998464495, 0.11852298033772968, 0.08898623011191376, 0.10413640309707262, 0.26117239496670663, 0.1337079526274465, 0.13821828091749921, 0.15090274246176705, 0.16100263019325212, 0.09901237805024721, 0.17900477279908955, 0.13026029075263068, 0.1458135835127905, 0.1770852820482105, 0.11805137517512776, 0.09181100744172, 0.07359231356531382, 0.11166946176672354, 0.13853157113771886, 0.11467790580354631, 0.07999489578651264, 0.2157400141004473, 0.16601646115304902, 0.1564081571996212, 0.1448133762460202, 0.16303203301504254, 0.15258533967426047, 0.16131335258251056, 0.12976766796782613, 0.19393814960494637, 0.22892135835718364, 0.11422961892094463, 0.10337538260500878, 0.147944645723328, 0.17335483222268522, 0.15385904320282862, 0.221522398351226, 0.20515081356279552, 0.1696031421306543, 0.2735338144702837, 0.13272294454509392, 0.09911059387377463, 0.14135041128611192, 0.10742623984697275, 0.1105567671766039, 0.18344698677537963, 0.20920464681694284, 0.1119487764663063, 0.09535719684208743, 0.17718124174280092, 0.1744577824138105, 0.1322759935283102, 0.0813362980261445, 0.15537453844444826, 0.18787944893119857, 0.13349602493690327, 0.18767342873616144, 0.10723360799602233, 0.08607473282609135, 0.1535312514170073, 0.1397769691538997, 0.1400450774235651, 0.12884459953056648, 0.16642538452288136, 0.19171121675753966, 0.11698426329530776, 0.10381979547673836, 0.07444965740432963, 0.19921796629205346, 0.3404098696773872, 0.07223951193736866, 0.14753386698430404, 0.16716189187718555, 0.14042017370229587, 0.11662251825327985, 0.10682973865186796, 0.17847756593255326], [0.010964314442389878, 0.03354041058628354, 0.04492799504077993, 0.02116604617185658, 0.059194362911512144, 0.035819267795886844, 0.013813133646181086, 0.023797388275852427, 0.07503773522330448, 0.013704118646273855, 0.015498386819672305, 0.055523017726955004, 0.034541645727586, 0.013859195041732164, 0.030746983429708052, 0.04705900159024168, 0.007534796222898876, 0.031859479495324194, 0.026184443195234053, 0.04089477122761309, 0.13700708106625825, 0.0073536959553166525, 0.0467211091745412, 0.006379731494234875, 0.07397526176646352, 0.032573351345490664, 0.020718876221508253, 0.055973137714318, 0.05178801111469511, 0.011107193640782498, 0.05941728923062328, 0.04518516034295317, 0.049627407715888694, 0.06292552148806863, 0.007768149716866901, 0.037276712246239185, 0.028765308125002775, 0.05679160785803106, 0.03788087982684374, 0.031084604961506557, 0.01039700840919977, 0.013263923028716817, 0.020329050166765228, 0.04199103466817178, 0.05540640406252351, 0.03744150984857697, 0.07980534384842031, 0.046892738246242516, 0.06259502086322755, 0.038049317663535476, 0.09860135440248996, 0.03274562979640905, 0.032031479640863836, 0.07222469124826603, 0.011259770853939699, 0.06267281278269365, 0.009480533026362536, 0.027482973418955225, 0.02964741001051152, 0.0548383679415565, 0.031153845484368503, 0.04046145346364938, 0.029243212266010232, 0.03064277105295332, 0.006375306438712869, 0.054877646107343026, 0.003013919927070674, 0.04548611606878694, 0.04443452249688562, 0.028450401878217235, 0.02432461184071144, 0.020064611817360856, 0.015572442025586497, 0.037340815251809545, 0.010623055459291209, 0.052516785290208645, 0.009621237732062582, 0.012874058011220768, 0.0241097860634909, 0.005907668983127223, 0.010163511124119395, 0.07518073223764077, 0.07644871380762197, 0.01333256890575285, 0.09483883637585677, 0.0779699013219215, 0.03964315772464033, 0.03393681392481085, 0.022353426793415565, 0.037730888070655055, 0.06102647690568119, 0.043796579775516875, 0.020332753483671695, 0.009486245708103525, 0.040092023482429795, 0.009350070886284811, 0.055360361220664345, 0.05361433264624793, 0.06437670963350683, 0.04269003387889825, 0.005211657844483852, 0.060345437668729573, 0.03339729111758061, 0.022975986648816615, 0.027909385498787742, 0.03346323093865067, 0.02338325688469922, 0.010991243270837003, 0.05185552428883966, 0.030802620385657065, 0.008581332986068446, 0.026686626697483007, 0.005020702783440356, 0.0362304658483481, 0.034699029274634086, 0.00477579219477775, 0.03798581208684482, 0.021209283695498016, 0.017981807759497315, 0.01582977616635617, 0.022837861833977513, 0.04679498255427461, 0.0936899843509309, 0.06374253702233545, 0.07692603350733407, 0.009055052341864211, 0.014398365328815999, 0.021160190626687836, 0.03657755718450062, 0.029190905697760172, 0.0385702311177738, 0.0110942682113091, 0.014703338856634218, 0.06155039976874832, 0.021158225790713914, 0.02983809001307236, 0.08236599082010798, 0.039527657281723805, 0.012682967044383986, 0.010539757731748978, 0.06288842894718982, 0.019137921699439175, 0.020045225064677652, 0.04105085230548866, 0.018677925581869204, 0.05207501075346954, 0.022381196104106493, 0.1288549302262254, 0.04317289371101651, 0.05095187414553948, 0.030904376253602095, 0.05554803181439638, 0.018566937396826688, 0.002086385616166808, 0.06418888689950109, 0.022050983061490115, 0.08471972701954655, 0.030401116637222003, 0.11554788099601865, 0.027174952447239775, 0.020319326176831964, 0.02323045424418524, 0.0387319933361141, 0.04150951070187148, 0.024764989284449257, 0.01240432955455617, 0.046583923176513053, 0.01480910232203314, 0.02886261481762631, 0.025606837079976685, 0.0834489252883941, 0.023920800013002008, 0.02064199714368442, 0.048192424364970066, 0.05259699661110062, 0.0753628255915828, 0.05976210959488526, 0.03816272525000386, 0.02227240096544847, 0.06969252048293129, 0.08512375221471302, 0.034036235738312826, 0.018974218764924444, 0.02570044973253971, 0.03691881523991469, 0.0223447436655988, 0.02690345256269211, 0.03693826321978122, 0.056520412254030816, 0.004329337025410496, 0.016826448954816442, 0.042392740651848726, 0.053348859000834636, 0.020239799487171695, 0.043309088941896334, 0.06866546973469667, 0.0191571266259416, 0.02835665007296484, 0.03636576308053918, 0.0824546477815602, 0.04213600208458956, 0.03849250228086021, 0.05575792230956722, 0.003984103377661086, 0.026220813997497316, 0.023258596484083682, 0.05677503198967315, 0.040772869760985486, 0.021822993439855054, 0.03175245437887497, 0.04307118237193208, 0.1141798504977487, 0.0529902421112638, 0.04517569796007592, 0.030146092431095894, 0.0016667549107296509, 0.03821615988272242, 0.04156864873948507, 0.012830051437049406, 0.03424513175559696, 0.03522003549733199, 0.037203759129624814, 0.052130178301013075, 0.025009799683175515, 0.02800832677166909, 0.03202480773325078, 0.06525381686515175, 0.03512515562761109, 0.021451708089443855, 0.028532739452202804, 0.07892869674833491, 0.012827500304410933, 0.07370047416770831, 0.03241118094592821, 0.06215551729837898, 0.057666792927193455, 0.05126240728714038, 0.022376377710315865, 0.01690466575382743, 0.015897090815997217, 0.02676987525774166, 0.04351894975116011, 0.051851524112862535, 0.04525965341599658, 0.010351491564506432, 0.019804079020104837, 0.015865321329329163, 0.0413264080270892, 0.03311811371531803, 0.04598249783157371, 0.047311947782873176, 0.04643751970434096, 0.04312668017519172, 0.02439172054437222, 0.010508550421945984, 0.04332174998125993, 0.02311763666511979, 0.05697130036423914, 0.10823383010574616, 0.02618605736643076, 0.015928383472783025, 0.08111574657959864, 0.050959087820956483, 0.051286011293996125, 0.055135965449153446, 0.018753594958980102, 0.029707043431699276, 0.03753899836738128, 0.036207585435477085, 0.007305653489311226, 0.017159365270345006, 0.01053263960784534, 0.015727328245702665, 0.04615603051206563, 0.06507893718662672, 0.044564880736288615, 0.03341974108479917, 0.017419495452486444, 0.08545481687178835, 0.008274067149613984, 0.017946049229067285, 0.06369810464093462, 0.05304487160174176, 0.01884514444100205, 0.020096780208405107, 0.07509473958634771, 0.021074778705951758, 0.011280531507509295, 0.0046970118273748085, 0.00813724851468578, 0.03537107739248313, 0.04256273699866142, 0.04609752701071557, 0.036168923252262175, 0.01742207441566279, 0.012240603427926544, 0.043965871082036756, 0.04982355734682642, 0.11320570003590547, 0.021689061759389006, 0.04992985515855253, 0.01621542207431048, 0.1155940796888899, 0.024645696466905065, 0.08769945736275986, 0.03226098880986683, 0.030290226786746643, 0.026544759602984414, 0.04276706138625741, 0.039296741742873564, 0.024374636304855812, 0.04262535941961687, 0.02535252719098935, 0.05154729551577475, 0.03692124577355571, 0.06230611019418575, 0.02855660506611457, 0.033443456413806416, 0.016534540009160992, 0.02448344814183656, 0.02078248198813526, 0.033234597503906116, 0.031972916767699644, 0.06340296735288575, 0.021440369928313885, 0.016095860228233505, 0.05014995018427726, 0.048340965222450905, 0.0034068650893459562, 0.00961483299761312, 0.04965462598192971, 0.03471365700534079, 0.012105425867048325, 0.047807364753680304, 0.06240846720174886, 0.019650081521831453, 0.04004411413916387, 0.02323548043932533, 0.006894264797665528, 0.03455445890722331, 0.031064166214491706, 0.03196769204805605, 0.054053424319135956, 0.09416565648280084, 0.0290844891424058, 0.045190756136435084, 0.024864216284186114, 0.011283142939646496, 0.05789956012449693, 0.05046167076216079, 0.03759553517738823, 0.028127335717726965, 0.12134745338698849, 0.1657683018129319, 0.0371187535347417, 0.08910619086236693, 0.13880500802770257, 0.2423358111991547, 0.08241395582444966, 0.13187138945795596, 0.12818720511859283, 0.10628461634041741, 0.10445723353768699, 0.14382602297700942, 0.1462260098196566, 0.08595567749580368, 0.1408623601309955, 0.11487319454317912, 0.09739311572047882, 0.18875770649174228, 0.08305284849484451, 0.21137321717105806, 0.2647916116984561, 0.12781552271917462, 0.19048599031521007, 0.2131230678060092, 0.18494265183107927, 0.10762779231299646, 0.22296511859167367, 0.16132200602442026, 0.11361580342054367, 0.10290201855241321, 0.27300870046019554, 0.16727532172808424, 0.17817821324570104, 0.1431098801549524, 0.10351911434554495, 0.1784006942762062, 0.10653897261363454, 0.15145730489166453, 0.13945141865406185, 0.1162187973386608, 0.08300650879391469, 0.09683048614533618, 0.08927214992581867, 0.18436554295476526, 0.13136306282831356, 0.15789828583365306, 0.14753074996406212, 0.14962911314796656, 0.206347823550459, 0.1165291115466971, 0.17937348660780117, 0.1316277720616199, 0.12096785969333723, 0.07782991000567563, 0.1788429994485341, 0.11176981497555971, 0.16543026838917285, 0.22478191094705835, 0.1896783703705296, 0.17864306486444548, 0.11380488780559972, 0.1477210663142614, 0.10038144013378769, 0.12499954726081342, 0.06723995247739367, 0.14747013134183362, 0.1318523014197126, 0.14746765256859362, 0.19714599387953058, 0.10860404305276461, 0.1151840430975426, 0.13161779759684578, 0.1362783959484659, 0.10888585879001766, 0.1022379744972568, 0.11644044716376811, 0.19492671999614686, 0.0901274083298631, 0.13193849445087835, 0.08207218197640032, 0.07793346187099814, 0.2130390121601522, 0.2233932784292847, 0.13611656322609633, 0.17603422282263637, 0.1877938347752206, 0.16167093417607248, 0.11711090337485075, 0.10547730067628436, 0.10734191702795215, 0.1466052621253766, 0.11248022841755301, 0.16798944590846077, 0.16676564438967034, 0.13871050294255838, 0.10817715228768066, 0.19216647982830182, 0.17467457859311253, 0.1397148662363179, 0.12479306693421677, 0.12133359006838873, 0.17282516142586246, 0.17791883263271302, 0.10566940560238436, 0.18229710316518322, 0.1643004672951065, 0.11697413297952153, 0.1295942280557938, 0.126361106231343, 0.24880227749235928, 0.09269363625207916, 0.23990312532987446, 0.10849428683286533, 0.17815113969845697, 0.12514855567133054, 0.10058336367364973, 0.18718965235166252, 0.17227824311703444, 0.10760620323708281, 0.08805205172393471, 0.11300584708806127, 0.16230446111876518, 0.33362438378389925, 0.1283592646359466, 0.29363224224653095, 0.11149354308145121, 0.25744838698301464, 0.09953059008694254, 0.16494128212798387, 0.19500376976793632, 0.12440833015716635, 0.11970142921200022, 0.15893754491116852, 0.15359108336269855, 0.1023270322184544, 0.15237002779031172, 0.13429441256448627, 0.17260360065847635, 0.18527581676607952, 0.1226013118866831, 0.14136941026663408, 0.11073995890910737, 0.15856767335208133, 0.130446347175166, 0.19623497792053968, 0.1399918060633354, 0.18750828603515401, 0.1705779234180227, 0.24430748977465555, 0.15140925825107843, 0.14767358370590955, 0.11574072064831853, 0.09474203063291498, 0.07578533768537454, 0.08949897994170897, 0.10451243448187597, 0.14506177307339385, 0.15337731514591724, 0.2276200320920907, 0.13101036456646398, 0.14068215183215216, 0.15889858215814456, 0.1589942746795714, 0.11682563665090129, 0.17373504932038486, 0.15717512229457498, 0.1568828645395115, 0.17355730495182797, 0.12039816487231292, 0.14888790057739243, 0.1537168477079831, 0.08615763072157279, 0.16387300507631153, 0.09806704518268816, 0.13155199878383428, 0.18863583100028336], [0.07614667454618029, 0.05531529430299997, 0.17983691330300644, 0.017425840815121774, 0.032939578959485516, 0.011913400721823564, 0.06404522195225582, 0.03888057130097877, 0.04820679976546671, 0.06921584645169787, 0.07439939916366711, 0.0408487135428004, 0.003672026336971612, 0.07547584726125933, 0.056798569203238, 0.035346927907085046, 0.03658356858068146, 0.04881426248175558, 0.03851339373795781, 0.03699941618833691, 0.03493802680168301, 0.02965320247312775, 0.015451314247911796, 0.061601815759786405, 0.03239223391574342, 0.020204514075885527, 0.0351070509350393, 0.025554923849995248, 0.041968892692239024, 0.020997012761654332, 0.04949707545165438, 0.040572363723185845, 0.011398290862416616, 0.02261936057038838, 0.11981553441728465, 0.12003827519947663, 0.12461906298995018, 0.05781324092822615, 0.011345070524839684, 0.05233571610006038, 0.023173229092208203, 0.027428911671449896, 0.027111918134323787, 0.019983075762866065, 0.039470530464313924, 0.03025061836524401, 0.053228452961775474, 0.06232715750229545, 0.029592058781418018, 0.004027513914479641, 0.009220943684340455, 0.03961444403103087, 0.04923369466268923, 0.10784050668007694, 0.02151617474737577, 0.0413027928880183, 0.05331754407961853, 0.03847780404612422, 0.0351861935632769, 0.07612488509039395, 0.06179055133543443, 0.03964496485423297, 0.053922806328046136, 0.030860621081956197, 0.08483771365717985, 0.024890718377719168, 0.05804310261737555, 0.02739380066486774, 0.05519897007616237, 0.016335546097252518, 0.0135526156918786, 0.014045085408724844, 0.04630683863069862, 0.04088654080987908, 0.0151518019993091, 0.046499281233991496, 0.07824054773664102, 0.026518710219534114, 0.019635707976703998, 0.041739517109817825, 0.026867193082580343, 0.05155755941814277, 0.01863986639364157, 0.058276842028135434, 0.0324382730468642, 0.04011237688246183, 0.04413091730384622, 0.052537316805683076, 0.03523738691001199, 0.045861906255595386, 0.031546983373118564, 0.01431894253983046, 0.012546316320367623, 0.043769955227617174, 0.025713756440381985, 0.04251228951034136, 0.05304708320181817, 0.01173778260636027, 0.048476507363375276, 0.04004567636002321, 0.04369090907857753, 0.04431362292962149, 0.015589479880873114, 0.01602229669515509, 0.05621737851470243, 0.06691342234262265, 0.06813223662902601, 0.04815849708393216, 0.002420005812382442, 0.09331549663329497, 0.0370468468463514, 0.018196358942077495, 0.04954317395458929, 0.049904032130143605, 0.050330436788499355, 0.006371542822307674, 0.023885575828899164, 0.009111404542636592, 0.033960046857828274, 0.0036726784992424655, 0.061070133742759936, 0.007991922084329417, 0.032433656888315454, 0.004532799130174681, 0.04882562847342342, 0.041126540236291476, 0.08379527818760835, 0.04974037001375109, 0.035119292660965584, 0.007662436346436152, 0.07804686203598976, 0.03287583960627671, 0.0972237427777145, 0.041638414331828244, 0.019191491774108727, 0.010468989312357735, 0.02693439084396232, 0.03552881345967762, 0.016310602513840422, 0.0504552734491881, 0.057081806153291836, 0.031566906327498145, 0.01406401574058691, 0.0251402488356689, 0.08136177595588379, 0.03351281753566582, 0.014058429223950952, 0.062041601340752095, 0.034983709701919, 0.08513066903105937, 0.05373837149818428, 0.038592729324591346, 0.0320793147693621, 0.038662580263917334, 0.031851308449404314, 0.027199163159821182, 0.06004037415550556, 0.012462102040444734, 0.033077162006520666, 0.00442559218754468, 0.04331838063080795, 0.021198440917942207, 0.03793235147895757, 0.016131709671753924, 0.07432402664562687, 0.0917549233417958, 0.0792156184616033, 0.0233221113376203, 0.03751904201635625, 0.055842204310465604, 0.03383218965609558, 0.04296211634937208, 0.06462951481807977, 0.055386837339028716, 0.04033088742289692, 0.03727827075636014, 0.02564977403380908, 0.03739978630619589, 0.011083440276706824, 0.05064667704573367, 0.05732144563808106, 0.04849006640142761, 0.03413062950130552, 0.04030962118122261, 0.08064644207479432, 0.028608516440726817, 0.04077047262398992, 0.010873931059904862, 0.0747444384614937, 0.05633749140542932, 0.035744860069826245, 0.06625444715609774, 0.020357481844257563, 0.03321161690109875, 0.03756089914531913, 0.02691055677132681, 0.06491379448561929, 0.03395356790861115, 0.023382093568216078, 0.024578070115239825, 0.015776258042023983, 0.02022120312176412, 0.04403824532346334, 0.0107132226912654, 0.025011191210069228, 0.03624875607783906, 0.01734466841298854, 0.03544715866155457, 0.017814215971156955, 0.03193433993146755, 0.026305296378268395, 0.03389423691260163, 0.07232171963551082, 0.03436623541347217, 0.05361378345696721, 0.11551738614798523, 0.04061586099851411, 0.012013842060696334, 0.040489473249181174, 0.05806397181004286, 0.007012104397290386, 0.10867474746191874, 0.010588300683593843, 0.006927117819941486, 0.03799242833338212, 0.0455588947806973, 0.022123912058304995, 0.024817154844640754, 0.04302172936149873, 0.06105081192799844, 0.09190077762468718, 0.11717731817043386, 0.05458438645291608, 0.009922698118316475, 0.017757491768861655, 0.02188869948440697, 0.034321854982408695, 0.019171737658325583, 0.07697777604334988, 0.042122227823711, 0.04281486682884861, 0.07693232691963203, 0.04695571318734437, 0.06834908475866541, 0.08635333506390452, 0.03517682394885924, 0.0347746949410066, 0.0464922642277088, 0.07639008414116688, 0.04648206340789329, 0.0634188270487357, 0.01983001708140364, 0.0211698700877605, 0.026307008884032257, 0.060724218710674904, 0.029381784224824514, 0.0195952943249722, 0.08411656875978224, 0.027158625198353548, 0.037492673509404995, 0.038592566052102484, 0.026722574475570582, 0.026599825105222408, 0.05452792756841518, 0.032978641902445816, 0.04463611949176993, 0.09901949524646625, 0.07958026530104689, 0.026451924350112677, 0.00929357489440008, 0.018274002432008274, 0.05504779830516782, 0.027802718468592502, 0.01890967418148648, 0.024216202618845273, 0.04007506540801842, 0.040637019628775306, 0.05009912791138049, 0.050026594108203426, 0.05572044014115818, 0.03631710416811984, 0.04149489039264154, 0.08075756384641863, 0.061335395876085386, 0.02415831695543602, 0.12865854310803115, 0.00942381902859779, 0.034283972054254264, 0.01843079226091504, 0.021448746920214035, 0.028029748864355497, 0.044118048463133164, 0.04262895883584861, 0.024524539003323298, 0.04927103582303971, 0.022178166764206253, 0.047189660399453714, 0.024440064044028986, 0.03109080746071413, 0.0101043294853298, 0.03316167036246043, 0.024918543349485844, 0.0882457745319698, 0.02753227985522244, 0.03858772724925075, 0.02344482360058464, 0.057880297681549564, 0.03375822721864097, 0.01685003997408785, 0.034707831146079116, 0.015608940848323982, 0.045094373417668976, 0.008528296330041485, 0.05349924038455356, 0.045304839077289216, 0.06522791591123678, 0.004753994853672339, 0.012961207485204795, 0.024954294458439108, 0.012129472379456274, 0.008544887041352922, 0.03409109529457055, 0.04079363505297806, 0.03265630861278623, 0.035049267316935584, 0.058958538065780886, 0.03526813037751708, 0.056378042354481295, 0.04657831625081599, 0.05593183719611261, 0.022680374386254698, 0.023146895837271586, 0.04218485024466645, 0.039668706158408895, 0.02514477037038887, 0.006602842886422877, 0.026807541107700672, 0.022985027862887364, 0.047484701208304614, 0.02344065829674946, 0.05873011985386256, 0.014224957885744516, 0.07553835093858652, 0.02682912276213756, 0.02291491717187455, 0.0432025981717743, 0.034841866727219895, 0.04029259260278195, 0.060108866964583285, 0.06432256253901869, 0.04602386514307, 0.022187725626281463, 0.19533173966920003, 0.1602114413981326, 0.25718614167999476, 0.1523056093719788, 0.11698055997840129, 0.13763682305580005, 0.13877097313525155, 0.17077917902497575, 0.2377572943805717, 0.12393528522807173, 0.1258823912939988, 0.10035404746304266, 0.10973595184623264, 0.191735484986566, 0.14965912560001016, 0.08880397348548286, 0.19314127595862374, 0.12989503535209224, 0.1144301620661281, 0.29406188637949526, 0.14093607023824006, 0.11753820232115686, 0.145631505001802, 0.09461662251851521, 0.11209229298401624, 0.09512368749710731, 0.1073252187052276, 0.18349901132751256, 0.11084500991273671, 0.05500613042386249, 0.11593338218517601, 0.19731317006517202, 0.07362017378909513, 0.16862631251569837, 0.2245524388854392, 0.196037047135178, 0.3089548012940213, 0.19233411614550278, 0.14744792628334835, 0.12503067293437198, 0.1404800353338942, 0.12109657036489807, 0.05938637135841418, 0.16084688308183104, 0.05242896324489266, 0.22082705050706863, 0.08836478533339687, 0.10873661289224401, 0.2756093937205151, 0.07681259623495862, 0.09249055496184155, 0.0945685758779291, 0.20893742912448943, 0.23009932483546436, 0.19517823384376243, 0.2262013277504593, 0.19400547724217176, 0.17342662758892402, 0.23099212849047035, 0.32831517804879695, 0.10585707248537801, 0.14418103673961014, 0.13998903043102473, 0.13456363405566663, 0.22033301764167845, 0.11416038396419026, 0.08632020559161901, 0.15776348212966695, 0.2346372907049954, 0.07441131063387729, 0.11116180306999013, 0.07397583322017454, 0.17298933933489025, 0.1258304706425406, 0.09956059511750937, 0.1388125482480973, 0.24764558096649125, 0.1257807170622982, 0.20238169730873778, 0.13970925559988245, 0.06817786386818625, 0.13379555573919788, 0.09919498348608613, 0.11324721577693708, 0.14367992378538474, 0.158396266924683, 0.1754346862435341, 0.08943839100538753, 0.22296370851108804, 0.1824289234355092, 0.16131023556226864, 0.1452499520382844, 0.09550404560286552, 0.17955416988115758, 0.07664474469493143, 0.09155297753750347, 0.1432393552386202, 0.09195899168844335, 0.07407090975902975, 0.16024697542889044, 0.2189742639893666, 0.18457028665579855, 0.12938513536937535, 0.10086563212098554, 0.08619897576863877, 0.15694689704105258, 0.15952985297190025, 0.13950571417808533, 0.13931106368545443, 0.20372108090668917, 0.19041774241486564, 0.14121517713647336, 0.1267007426940836, 0.16807498584967107, 0.12093760233256035, 0.1742507825838402, 0.058176477687084116, 0.1370619554654695, 0.25451325229369104, 0.06080397361074574, 0.10856597087695263, 0.11924783597351052, 0.1628453828743659, 0.13381860684603453, 0.08133157054544427, 0.11645227699773386, 0.21829862758750096, 0.12446298933355138, 0.09972423868020996, 0.07206533729913644, 0.1233129647152964, 0.19817020220216364, 0.21822723298100755, 0.15369528089649975, 0.18147759401472285, 0.20598667964804918, 0.1940663333516568, 0.08081455336650833, 0.09637862953240983, 0.17405115970177576, 0.14373151789186522, 0.06514563399832696, 0.06924522807821631, 0.0954538986843545, 0.16156535624759272, 0.24698790453840047, 0.13176921056583524, 0.1369014586089179, 0.10200268399785273, 0.19162441516527906, 0.07352903063292615, 0.1453351357486099, 0.14222430501831695, 0.12694033765001222, 0.0778148444078397, 0.09432159655261785, 0.17927611683262512, 0.07293977279914543, 0.14246474602259696, 0.11536788792000152, 0.18981197179527953, 0.18398784915916622, 0.1096607129147742, 0.12240971904247999, 0.1422234292840585, 0.133231122745201, 0.2743000374175608, 0.10489600608707406, 0.14770890993531793, 0.1401396418805234, 0.0893961479596328, 0.11790455610025674, 0.22895295900525525, 0.15913175011519343, 0.17457706038840115, 0.11539725470356643], [0.02437054892652668, 0.09711076563689858, 0.1021128409774974, 0.05127971417095978, 0.038301748063531704, 0.023858910462877247, 0.057866285933414474, 0.03603864293836523, 0.021995117895130534, 0.041288061256636865, 0.010976663779729279, 0.0652942416490987, 0.05292406480293721, 0.05064234290330205, 0.02753218523139367, 0.03887289378326386, 0.009598450087651145, 0.059649755858117715, 0.05824879997817334, 0.0652865604206454, 0.05965482472674921, 0.050004548611468635, 0.07383686606772244, 0.06678029589238577, 0.05439729844511021, 0.04523661715211347, 0.02312331595021533, 0.036659787147073075, 0.02497373687219806, 0.04560769841191359, 0.05740635846450459, 0.003238175618207606, 0.02894053661293583, 0.030178457491274457, 0.06054922399925999, 0.06693143426673487, 0.03633577289292589, 0.02187011981732212, 0.01726729951769812, 0.012239300031069433, 0.02629709750181064, 0.051395110713201575, 0.07738750835414976, 0.00962973903369857, 0.060815966717200354, 0.06452952526160516, 0.06845675554359332, 0.03576350281946361, 0.02579310686996905, 0.021885092646698467, 0.041249306304962374, 0.022565541876247153, 0.04892183678748552, 0.048000812967075035, 0.016610433885944076, 0.031228063962771557, 0.09595157549483702, 0.03082920411543455, 0.07223978653200902, 0.01702042038232321, 0.018782447805278935, 0.024942190029833, 0.03428701114899013, 0.03154755482682958, 0.029881780246796552, 0.12232707347720861, 0.05087397090392187, 0.040096290831570514, 0.028857323304691818, 0.06084983091568574, 0.033120666703325696, 0.05705068790121004, 0.04567210198729299, 0.07200695996289141, 0.02761276762612397, 0.017619689788261894, 0.04710760113084689, 0.03993102196545806, 0.02655586213222705, 0.019585809677664656, 0.051043124913121574, 0.039402549737133086, 0.06485636709840037, 0.06293177037150599, 0.01740609968692297, 0.06246176082640886, 0.06896172766573727, 0.021172547385504004, 0.05460891443362925, 0.03169539064401761, 0.03426267983741127, 0.07495314523112029, 0.031061982444953173, 0.03729955555172637, 0.018385847797617316, 0.014223168382159201, 0.041489713912596926, 0.03452358927461319, 0.03385763418918941, 0.054863048062543385, 0.02794709216686897, 0.02394476210611174, 0.034985086385859177, 0.061106142748030834, 0.003914020517186145, 0.05009430766222067, 0.05610480213363189, 0.0496525034395745, 0.04015112070192117, 0.02142149896826595, 0.0488735044200439, 0.018655340172699653, 0.026944515593640972, 0.040969412730191834, 0.027668606817314867, 0.05617726543277968, 0.011883494025823893, 0.05250314832665026, 0.033815005226642825, 0.06532917454023845, 0.051812023302773014, 0.052585226148949005, 0.09510847346973605, 0.06344791923766024, 0.10880477173486724, 0.04249793266353663, 0.046324479480972514, 0.01707720395643264, 0.02005691574595403, 0.018173519347328693, 0.01685188977717189, 0.05638507049297914, 0.06372831005137414, 0.03862389952701051, 0.04928151123749558, 0.028114416782045737, 0.05023372381401714, 0.10367735507315956, 0.023086349574441556, 0.0774009338056203, 0.06319289503153414, 0.024712968443054706, 0.07218414029921405, 0.07851402915548533, 0.05967853263427969, 0.03135627739538904, 0.05995202147460077, 0.021355969183787238, 0.030273246447904967, 0.05176223632588517, 0.04870040589594282, 0.025369565046275966, 0.026604675040289294, 0.04484209515794646, 0.03233467665268108, 0.060922004777239636, 0.03546234671375714, 0.03002649904374266, 0.056074095773510635, 0.0860082363942638, 0.04967574008333031, 0.04522504335909616, 0.04561207337246742, 0.03746165173652116, 0.027823539421660826, 0.0297105352365179, 0.018876724680012558, 0.024048375198617578, 0.015731595594843384, 0.04042855405714363, 0.024714962964935694, 0.01578867231728509, 0.0070265888007270405, 0.07546521228505298, 0.0712971476605162, 0.06942760344827548, 0.045219321400509216, 0.09203182606142946, 0.05776172474725172, 0.057135363240377046, 0.003657870333881874, 0.06016896237269975, 0.030857747115078382, 0.056694460727158, 0.03552122871042229, 0.03675861153169535, 0.021826578013133258, 0.020058700611116365, 0.06929974624654278, 0.0484687556308927, 0.04248604345775675, 0.05892455141292885, 0.06419497993192635, 0.06190638574480545, 0.013920581786805997, 0.07214545214083046, 0.05405744675954338, 0.006042431868991116, 0.05417174492322374, 0.014089880514802644, 0.024219557126343716, 0.005946363171460689, 0.048299033878720365, 0.04041064232296776, 0.010694896282075206, 0.07085645294864662, 0.04151558146986645, 0.019496215754770674, 0.011229392894165358, 0.008535471042705467, 0.08806455691228621, 0.04594028818246443, 0.052345853837323375, 0.053814244965906255, 0.036549147771438584, 0.045151533631724305, 0.028534010380099062, 0.008876398842403432, 0.046810181738692336, 0.018025644567387644, 0.028812759192078374, 0.09615591843612492, 0.0308700704772491, 0.036030917181051336, 0.0885644082154613, 0.017892518117150757, 0.016636342261335813, 0.060507467060233466, 0.02249740715342341, 0.05334670677257236, 0.03676306070701685, 0.01507840823251172, 0.05327418781234883, 0.01201379845952033, 0.008625400787423132, 0.03979234053986147, 0.020738183193316218, 0.0027952732489211485, 0.04864418078796007, 0.040108354442054406, 0.08232724328991026, 0.07685229371418245, 0.02837116648152005, 0.03895755056873895, 0.03232940740417689, 0.08871412166627124, 0.03199135171598755, 0.07648309750948101, 0.016829547421366442, 0.013493887690856354, 0.0558683427516371, 0.018241169818793423, 0.05381804847274907, 0.01569843829202, 0.07509685470722616, 0.06170735287014395, 0.08298507556901313, 0.05826455577334855, 0.022279180484474637, 0.05010755128751043, 0.011750597641366767, 0.0166622395045124, 0.04913921555271372, 0.011410078950575553, 0.014923109192750417, 0.05446348317491356, 0.07090013576089405, 0.009898016141960397, 0.011535893390828278, 0.024859251316229347, 0.007658274753339356, 0.04468785089557059, 0.04465322599571664, 0.03611786349210888, 0.050915772371809, 0.034320341001148336, 0.016705096677469555, 0.05602662429737393, 0.07171912540798075, 0.05469373820233159, 0.03285314844106324, 0.11786543749622069, 0.03133256577712018, 0.03540878962667193, 0.00977758041699417, 0.04458036564756185, 0.044419976402423345, 0.024828891910146922, 0.04197390218905639, 0.06111136746767443, 0.09353810382890515, 0.04536296779406257, 0.020442472596187145, 0.044576309810508974, 0.058418028202140704, 0.07968951686052606, 0.001658378846514097, 0.04309057469072286, 0.04847316398809198, 0.0499525240593357, 0.03679354442283511, 0.04433758316736203, 0.028069019608665258, 0.05683350951585453, 0.018322820906178094, 0.007526499939558562, 0.020155771671852563, 0.04933484939101618, 0.04935448661854025, 0.05742774344980717, 0.06724784150719643, 0.05088150741357822, 0.04453771070984658, 0.02771103539998876, 0.01945401352713816, 0.0228343459093594, 0.038962693652138114, 0.04856996230955701, 0.021867741234018467, 0.04039501269289758, 0.03383305054740049, 0.028754747363564093, 0.046963130953372456, 0.02785071872494882, 0.028398672329785768, 0.01566275954246521, 0.05215498087636661, 0.040083139974740334, 0.06956149431061931, 0.05547685985220596, 0.039192462572827935, 0.06519992952235043, 0.0455700715247076, 0.013875293152523227, 0.07648997721844353, 0.03824361934675835, 0.050171520706498995, 0.030726941731700208, 0.05986242940707598, 0.00609676264502923, 0.017504783063486684, 0.010041568839369575, 0.10964521687128581, 0.07439291279297322, 0.029918904328951612, 0.00952299686105107, 0.04581537730700802, 0.026458028514753096, 0.01281504057260463, 0.04262578244379256, 0.03095075677265413, 0.08363512271898799, 0.17323279345873743, 0.14967408729717135, 0.15026510402094573, 0.12626406300114468, 0.12733038078295067, 0.1583179851877503, 0.15421793097630143, 0.11257028803811409, 0.12470234680222347, 0.1013453489576932, 0.19664847292006016, 0.2424007491208613, 0.20879646559478715, 0.1088261604309082, 0.11373537825420499, 0.15009016497060657, 0.19452078005997464, 0.11722845956683159, 0.14406342117581517, 0.17326102475635707, 0.17675446229986846, 0.1317034414387308, 0.0978857088193763, 0.10517755465116352, 0.11256910060183145, 0.13368530228035524, 0.11261435676715337, 0.15138763206778094, 0.12485732208006084, 0.14114630583208054, 0.12780075398040935, 0.06701739723212086, 0.05683672301529441, 0.09465023438679054, 0.19733543449547142, 0.16571514919633046, 0.18028174177743495, 0.0874984466645401, 0.09246988614904694, 0.13672847882844508, 0.12507785868365318, 0.14862837153486907, 0.15479250170756131, 0.10312567959772423, 0.14185324602294713, 0.15935999021166936, 0.14786968880798668, 0.1791630283696577, 0.1306066510733217, 0.10603230839478783, 0.20751787873450667, 0.1366979765589349, 0.2250268345233053, 0.16349105135304853, 0.09274482959881425, 0.06829349047620781, 0.1277875734376721, 0.08973320916993544, 0.1686528665595688, 0.1493896369356662, 0.14644852053606883, 0.10691134521039203, 0.11538807433680631, 0.14765384257771075, 0.22853021684568375, 0.15503236383665353, 0.14443437627051026, 0.12926783150760457, 0.09886660540360026, 0.1564095524372533, 0.09302369900979102, 0.22518170590046793, 0.09542137035168707, 0.18973343772813678, 0.146360709622968, 0.08423157938523218, 0.16271138068987057, 0.13259410770842806, 0.19222286820877343, 0.18586520076496527, 0.21283903304720297, 0.14620422036387026, 0.17242242756765336, 0.1546740549383685, 0.1352403688360937, 0.1529890828533098, 0.17662385915173218, 0.08425862324656919, 0.15718857001047581, 0.19208601617719978, 0.19515614752890542, 0.10964998888084665, 0.08272802529972978, 0.10233642780804075, 0.09524952605715953, 0.13836503319907933, 0.12573666317621246, 0.10629040509229526, 0.10553763728239574, 0.12728079047519714, 0.14589887112379074, 0.24148327647708356, 0.22336758527671918, 0.15650260291295126, 0.15636168391210958, 0.18022680800640956, 0.15650524495868012, 0.08274279403849505, 0.18407582334475592, 0.12474966613808647, 0.09875627772998996, 0.14137659425614402, 0.28503983456175774, 0.16834444482810795, 0.1360831072088331, 0.1134053451824002, 0.08794182052952237, 0.16095583036076277, 0.23414437106112018, 0.2131009369622916, 0.13651736750034615, 0.16085761453723535, 0.20799718738999218, 0.1264963106950745, 0.15658386808354408, 0.13236500672064722, 0.08709970556083135, 0.156978408631403, 0.10565756834694184, 0.10577800407190807, 0.08001521578989923, 0.13650129258167, 0.1260090313735418, 0.13563406333560124, 0.1769833851722069, 0.18129239848349243, 0.12960169406142086, 0.21946170658338815, 0.13962809432996437, 0.16574870911426842, 0.18593089567730203, 0.17091714427806437, 0.13407319318503141, 0.15006423433078453, 0.12289876467548311, 0.11836637233500369, 0.10516530921449885, 0.07713013896136545, 0.10433700561407022, 0.16902068979106843, 0.1040291108074598, 0.1254019545740448, 0.1463146074092947, 0.1448057172819972, 0.186138192366343, 0.2761162805836648, 0.09086461330298334, 0.137040997215081, 0.1163750713749323, 0.25636431702878326, 0.11498845007736236, 0.16202152473852038, 0.1937783948960714, 0.15523508889600635, 0.08928997631301172, 0.15190623002126813, 0.19313186552608386, 0.19372053706320003, 0.13890954694943503, 0.08341049688169733, 0.09989623140427284, 0.08760196884395555, 0.08672310272231698, 0.20830378343816847, 0.1748306374065578, 0.13022919476497918], [0.02149904968973715, 0.06930487448698841, 0.02565461469203001, 0.025346879447170068, 0.052240357545088045, 0.06843572307843715, 0.018215064774267375, 0.050484922248870134, 0.06568723110831343, 0.027151172180310823, 0.04806573604582809, 0.05362912736018188, 0.04934836018946953, 0.03205670895113144, 0.03791593146161176, 0.035538583833840676, 0.03677096086903475, 0.016675846782163717, 0.03582085970265325, 0.04968959226971492, 0.03228150919312611, 0.02770341725408798, 0.07897931121988222, 0.10654246070771478, 0.04331078103859909, 0.024641247291583568, 0.01164487499409006, 0.05011219342122786, 0.014345946510729846, 0.037098815737408586, 0.07919437819509767, 0.0544534493383253, 0.03776694902626332, 0.05979884219414089, 0.025060085754375905, 0.04712495625426527, 0.05278225893562194, 0.04387795997899957, 0.03815588264842518, 0.02686705021915259, 0.07238540332764387, 0.02324702825717395, 0.03454751240496989, 0.032643020458635874, 0.020824062667088583, 0.019569870200939476, 0.020145459529885557, 0.03509349931846373, 0.060706403455697, 0.025094699522014707, 0.024394581523665693, 0.014623841852881014, 0.026886093728535343, 0.06713168797432445, 0.028801476692024153, 0.035628769619506784, 0.007909312698757276, 0.04679305297031533, 0.05855459821759723, 0.03498464480799157, 0.036393768023117445, 0.019241096924815793, 0.022985037139733322, 0.03360658047313336, 0.030343256948981434, 0.07952539090183564, 0.10258932205033489, 0.013615601765195606, 0.023723550148133654, 0.023773066241119523, 0.03823118095169775, 0.012470059718907578, 0.032698529394110665, 0.11129647318739444, 0.06473218352766708, 0.021649540540238377, 0.025031923105416354, 0.0484390771453036, 0.04310125048505142, 0.039428517484338954, 0.029635845494340174, 0.05086385543108918, 0.07583066806546412, 0.010583825533103663, 0.019051925337407738, 0.06638958482653834, 0.04999634045816492, 0.031272244013962336, 0.08243999778642319, 0.04832932092540432, 0.04808307632629294, 0.010196168404945638, 0.08457698233542033, 0.059754253961727954, 0.02526095173379872, 0.02572602970758453, 0.03770674600673374, 0.014304050419013947, 0.013136936922819586, 0.04058636804984417, 0.010805224883370101, 0.05524425592739135, 0.02037341761024436, 0.03802237399213482, 0.052127321032457985, 0.01418131496393471, 0.018148688941437285, 0.027451899695734028, 0.009876389958662912, 0.12103136527002789, 0.03877389870467596, 0.016674696453264914, 0.04256390959199052, 0.024194077341235243, 0.030935438844608143, 0.08162481535691768, 0.04515387139690574, 0.03136739476758521, 0.015872212170506828, 0.02338105270609958, 0.08099758924799971, 0.058241085353074595, 0.0372204945597332, 0.02855265684047481, 0.018035526263702195, 0.022143669884826522, 0.030148643563734367, 0.037395956824184395, 0.08881811882019974, 0.009054743422893807, 0.07075238900142722, 0.040918037557275966, 0.05034207737480756, 0.03159975378366653, 0.03432754354435019, 0.034092913556378335, 0.02333372594875982, 0.02726034952502232, 0.043313898058841005, 0.029967173613840714, 0.007625142498000059, 0.005031910141042317, 0.06261229806113988, 0.040237970533780754, 0.01211281023643096, 0.027011333004338667, 0.025658961822045967, 0.0027066276516052312, 0.022617197209910955, 0.05408790450019296, 0.01578602099471027, 0.04760416843055282, 0.0452243049221579, 0.040331132331630215, 0.031700737818027847, 0.02947153028799221, 0.0409031352319289, 0.032204626404563896, 0.038811043195892125, 0.017964051876333542, 0.017377521435264498, 0.022155616607051343, 0.01334825605226797, 0.0294632330769673, 0.03919727911124937, 0.010440831301821163, 0.012585219701577444, 0.042683558640419506, 0.025666015935712494, 0.03282791170931887, 0.014121732565399725, 0.047063747624633834, 0.006646938982157735, 0.054380273577407934, 0.08459937293082476, 0.09831895236857235, 0.0314216420520097, 0.02718518480833154, 0.026564305917418096, 0.17527623771457002, 0.012315094645600766, 0.008921618828026112, 0.0724168035958428, 0.08582005742937326, 0.05075519016827457, 0.09112856554565951, 0.07653675478650257, 0.008114487773127621, 0.07695412379689515, 0.03412745310924947, 0.03698615400935523, 0.042806680939975195, 0.05292038375046104, 0.015851819807721768, 0.014191732861945638, 0.017465183918830007, 0.05028240499086678, 0.01825632632971974, 0.015745445925858803, 0.051221414760220796, 0.028901364203193225, 0.0577233297372004, 0.03876881499309093, 0.04193688015220687, 0.062284060986712575, 0.011738908815459581, 0.044497909329948016, 0.014789229462621734, 0.052688484865939245, 0.03166604241414461, 0.015703512726759072, 0.021480618452187628, 0.04753752356918994, 0.05563680751947686, 0.021142748300917447, 0.0860565947368741, 0.0983493952662684, 0.07418003515340388, 0.04613106466422323, 0.020524114406725857, 0.020800490201509092, 0.0024215369558078237, 0.004418574717419688, 0.04514481719525065, 0.05283838756440673, 0.010567263580014696, 0.0786504804273136, 0.011590029353101272, 0.015743610965728294, 0.02672578426427208, 0.02741916356171714, 0.022813320865679998, 0.016693493198545184, 0.04046271511469968, 0.03173792683810461, 0.06284032293478958, 0.061709482833975926, 0.04283613307052292, 0.021454472589539364, 0.011861889179272112, 0.0258157145435689, 0.06028528659953736, 0.0022345855495586875, 0.013769677188975038, 0.02570498239947483, 0.032965387144940905, 0.07651856474694796, 0.07599062315421179, 0.010865537369681988, 0.07382315860013478, 0.06995155228651129, 0.04094776799320243, 0.03815174517512787, 0.06036205806594808, 0.061077625723555684, 0.07881211276981048, 0.12270666717085987, 0.011228501389268786, 0.05969880810880568, 0.017602048937988002, 0.017628294990572613, 0.048559783754171804, 0.02665373100171564, 0.031034324456413742, 0.017811208417697344, 0.020859535470663104, 0.031321530041168444, 0.0497094929596642, 0.02001045173528837, 0.004227137260386371, 0.045363190438365564, 0.012348216696409509, 0.010758470507425955, 0.03057377729419386, 0.023174095549620688, 0.043112545972689986, 0.051210798337706365, 0.018036353758361656, 0.0139942362329748, 0.016291117426590063, 0.01727530914649833, 0.054316549067152664, 0.04110649482754525, 0.011010540038114414, 0.023670518130529672, 0.10257755900966004, 0.07227181020425633, 0.07250636597746052, 0.04916210709779989, 0.02302089771546889, 0.01671411006100243, 0.022984693896432873, 0.01776336030161474, 0.05510810893611051, 0.024578216689405963, 0.009874359257082688, 0.023586575662193354, 0.04438590811332688, 0.019419986056163907, 0.038107372165541165, 0.049864048924064264, 0.0528896959440317, 0.035427050170255825, 0.03987175034126267, 0.03394517050764989, 0.023449680957128294, 0.006859927943878574, 0.010048391959571745, 0.03772800482693128, 0.009840084094321355, 0.03424754744628444, 0.04126885818550363, 0.024425571755273268, 0.039091474827728234, 0.0326791778934421, 0.040243870607810095, 0.017569481642567553, 0.04245972690114286, 0.017671638270257972, 0.05830207504914142, 0.07069603772833943, 0.07161390371038578, 0.04245477306540124, 0.02419173215457704, 0.019005491012649145, 0.03195662662619725, 0.03431360972172115, 0.02096402986353496, 0.02157544637157116, 0.027694813907146454, 0.016943083028309047, 0.02472962409228785, 0.04474813926208299, 0.016822059151309077, 0.030186645235517062, 0.052475507036433555, 0.014524311500281328, 0.03528383051161654, 0.03491249692160636, 0.010768239026219817, 0.05052499080193229, 0.05989430093904957, 0.00674038557917811, 0.02381459496973548, 0.044563010524143465, 0.050728302157949656, 0.041090264057856984, 0.0014172439341564314, 0.05350081744836643, 0.04805290802323725, 0.018274989488418214, 0.12197374438983388, 0.1408342327340506, 0.16120627551572397, 0.1532579629565589, 0.25074575445614755, 0.08118960511637852, 0.13769905955996364, 0.18066189950332046, 0.14476806070888415, 0.14338422246510163, 0.13678056275239214, 0.18520875630201772, 0.12571852508699521, 0.16689146810676903, 0.14451423136051744, 0.10674197226762772, 0.10699330057832412, 0.23459639836801216, 0.08852633603964932, 0.09623112026019953, 0.15927425731206313, 0.10731211979873478, 0.12990563322091475, 0.2548917179228738, 0.18195623473729938, 0.22093972336733714, 0.14540158765157685, 0.10432082679471932, 0.11183384005562402, 0.14980546227889135, 0.07903048230218701, 0.1690035461797379, 0.1485382005921565, 0.11988868049229495, 0.11946840226300992, 0.20373672537971288, 0.13533610588638112, 0.11681459349347278, 0.10180605939240195, 0.1812616884126328, 0.15642853657482192, 0.24750322219915688, 0.13133496511727571, 0.12077661565854214, 0.14173318137181923, 0.0817444569838699, 0.13458086672471836, 0.05113985273055732, 0.11370354754035361, 0.24056298367213458, 0.17196976201375946, 0.18213044648291543, 0.08684009488206357, 0.0826404889812693, 0.20747642236528918, 0.12227351267938502, 0.15803617687197402, 0.12089893643860705, 0.1634573726914823, 0.09947240570909344, 0.18553825502749532, 0.18150517222238705, 0.1075420445704367, 0.06190379193867557, 0.16144733992405236, 0.11194874678039923, 0.13692884385818616, 0.14741313440026715, 0.1684171604574658, 0.09119176684180275, 0.07898824667790905, 0.36324189451988786, 0.18458979029674083, 0.1403159464825876, 0.20592563058016822, 0.1378137362189591, 0.1304283575154841, 0.16380536573706195, 0.13825620466377586, 0.13417848909739405, 0.1712594524724409, 0.1929442654363811, 0.13493653357727453, 0.20186456880765036, 0.1462292901123874, 0.1957619923632592, 0.12147928107879125, 0.1487436715979129, 0.13214447011705488, 0.14007719757501036, 0.12175826923339628, 0.10426799330161884, 0.15998545743059367, 0.1418494462268427, 0.1506258620065637, 0.09985722412238829, 0.1209230488166213, 0.09788051378563978, 0.15312287723645568, 0.1378543465398252, 0.16326962417224422, 0.09345784797915258, 0.07374938169959933, 0.09669928185758181, 0.17050514841685072, 0.16144606343004853, 0.14552813867339864, 0.18003454722929746, 0.062004868741496466, 0.16860039671882987, 0.1734749265597202, 0.12375371137750335, 0.16631720907753333, 0.15111461078049615, 0.124388796830317, 0.06395812350092456, 0.20273377216653898, 0.16992257733363658, 0.12873266881797463, 0.07528380170697346, 0.16523894271813333, 0.12012314720777795, 0.1467276125913486, 0.07965761935338378, 0.09392217267304659, 0.0900966908375267, 0.1170448299671989, 0.12189593762741424, 0.1364280129200779, 0.3009160654619336, 0.07192045522970147, 0.16025374381570145, 0.1488005497958511, 0.13815960672218353, 0.12548066675662994, 0.1442805290571414, 0.14586520730517805, 0.09714960964629427, 0.23308946751058102, 0.14305803371826187, 0.2284798547043465, 0.06602073743124492, 0.15009430615464225, 0.20981944195227697, 0.1754129264736548, 0.1910057311761193, 0.1588749818620272, 0.11325596569804475, 0.12091165684978478, 0.11798876759712584, 0.18264113314216956, 0.11265566470683552, 0.1292303085210733, 0.1417337157181464, 0.1256421729340218, 0.23631917545571923, 0.05811295355670154, 0.2137279330054298, 0.13658576383022591, 0.16397491679526865, 0.1035046498873271, 0.1576153197675012, 0.09312193709774874, 0.11333256275975145, 0.09902418561978266, 0.11705556884407997, 0.12062167748808861, 0.1862582570174709, 0.11862382336403243, 0.12675722013227642, 0.202334467030596, 0.0961714590084739, 0.10552228224696591, 0.13645373575855047, 0.10027355412603356, 0.1840879797236994, 0.21477591973962262], [0.09536798766930588, 0.03905899102392141, 0.016916538261284586, 0.02873071476642508, 0.029634710008394904, 0.018307076243218035, 0.035561490221880376, 0.02302138011145871, 0.0213276488284464, 0.03029449042514898, 0.04351038165623322, 0.04604771405865904, 0.08642778731882572, 0.03507903857098427, 0.0168843772917171, 0.026940205571008846, 0.010202439552813303, 0.052422569642658345, 0.032294352058670484, 0.039017835224512964, 0.018064625874103513, 0.043942070406046696, 0.014043384035176132, 0.004886702454314218, 0.056963489259942435, 0.03210280374332797, 0.026573723771434743, 0.00825184075438301, 0.03892687389452476, 0.04420934375957586, 0.040380666978308, 0.03171090153045952, 0.0283888166086399, 0.022520361781062093, 0.030485381939797662, 0.1345950862742029, 0.05808836249343585, 0.0291644518438261, 0.02078670666378457, 0.05591994799033273, 0.015603311658196617, 0.08859094741637819, 0.03123355214484036, 0.00913909871087526, 0.05902024764509406, 0.04904596469714306, 0.0104680894582998, 0.052748019952559844, 0.045595081901410595, 0.04192602253169753, 0.017442112402932253, 0.026623304802342318, 0.029083884292049333, 0.053044392916490324, 0.04296971223084256, 0.051387570492806844, 0.021597183877020143, 0.023386086322716437, 0.09918049676343799, 0.06309438977041282, 0.0377421427401714, 0.060890136956004426, 0.05396856344304979, 0.05409367469837889, 0.03688962657179218, 0.008143294235196663, 0.053422943892655894, 0.015490759396925569, 0.04524979398411233, 0.013371400855248794, 0.06457359399064444, 0.011852824773086468, 0.048447507942910306, 0.04581519177008886, 0.051603405590867624, 0.03486980116576888, 0.024835701115080155, 0.038687345731887035, 0.076979297446087, 0.027348153016646393, 0.04155752023507375, 0.043942285628872924, 0.09369523133500479, 0.03521936756442301, 0.049274702032562345, 0.04890202886599582, 0.03287257415649947, 0.023014650687400717, 0.013554787401517387, 0.021037539590906817, 0.041190736010321416, 0.03351217557792552, 0.04034255398437381, 0.071732083306415, 0.05950448045041412, 0.017959684337256476, 0.026675581684685312, 0.02114965027431026, 0.04482828007894568, 0.08189405169105157, 0.059915878882748075, 0.026878705648414325, 0.017726071091601625, 0.013226719165686518, 0.07145534385927022, 0.069684393965872, 0.036685610175482, 0.09953278684406541, 0.02517259905289393, 0.03198918093403336, 0.04053989105159417, 0.060942658747080714, 0.013936971190560143, 0.18461523111909628, 0.06340376145089976, 0.00833749572848319, 0.04711183508334216, 0.02254192302643787, 0.027882525319000706, 0.031109025330806617, 0.04101931473996956, 0.029731521317444276, 0.031072415185917635, 0.010395681820227765, 0.023402597253152635, 0.012595588432304794, 0.06614912155782804, 0.061714507173746824, 0.07033679372398183, 0.06755183261702769, 0.05756858823588118, 0.05069614118838217, 0.06739155840477906, 0.05734922051487956, 0.042503469085204415, 0.04486574369366281, 0.018863694422179833, 0.05489112350915093, 0.01307933791395044, 0.0060496868263726356, 0.10564472919213586, 0.07391981591354124, 0.016326454788213596, 0.05741226224927232, 0.02132055760739604, 0.0075378306792117655, 0.033561220407136716, 0.008059013161982875, 0.03267743384640198, 0.03177635895553976, 0.0460094118170673, 0.056081773291225545, 0.030377091461559758, 0.05063510325271636, 0.05748716721427627, 0.019881264233845286, 0.04267941745638382, 0.053797398213646375, 0.01098484131944133, 0.08696894656168297, 0.043636606133077294, 0.028187765092297923, 0.014821858912910102, 0.0692955160047859, 0.014388245217560325, 0.021674563904525712, 0.014675095499114832, 0.023410708927258383, 0.051575255929492414, 0.020098685672564898, 0.08847570672514848, 0.006936090385352145, 0.03432829682424199, 0.030644839789601974, 0.03436185303144157, 0.004679497142205946, 0.01439755267711007, 0.028719165093207266, 0.04576884464768227, 0.027530088664207142, 0.062183143745642155, 0.01880971987702651, 0.02563743768405402, 0.08467194013064727, 0.041571235124138184, 0.021479456991073675, 0.04294395970646292, 0.041597974704927765, 0.021283210880937986, 0.024254796153400093, 0.03996558749349788, 0.07956075423862785, 0.044006644675391726, 0.0518355530948611, 0.029319217464944813, 0.023091709736036137, 0.045147529745008796, 0.051366949919611216, 0.08466868210234679, 0.04877076520642731, 0.020798378791369032, 0.05229601862083655, 0.0309509627186344, 0.10137322402442805, 0.06760102216503583, 0.015414081626659026, 0.06443018137360923, 0.04787112266058102, 0.014485263400274562, 0.027640360676741693, 0.043788430994027294, 0.06062534979719203, 0.025045988659258, 0.05938040078035556, 0.021245765819912776, 0.043015836708946154, 0.008345608330273535, 0.05297422285366338, 0.03836929092358332, 0.0478292321349727, 0.026361760828876868, 0.012883756025985349, 0.007002981546975207, 0.03740546744666062, 0.06600670341867954, 0.04370615650259424, 0.024506315567123238, 0.0766742970154155, 0.03229030735383276, 0.03641883777163457, 0.019194148662791122, 0.042144666658714414, 0.025876553954731207, 0.015073690028657438, 0.0608655978430761, 0.027051050892623607, 0.012687675043707713, 0.013809094507450936, 0.022879943462612573, 0.04863261812715791, 0.04527667828369886, 0.02491384555469267, 0.022455538892245386, 0.09260669365176, 0.009990206654038047, 0.01599433999217581, 0.023301320070459042, 0.04451211032574065, 0.03563875892723445, 0.0026454150793142617, 0.06940655614016578, 0.05848794593475759, 0.039329733917838894, 0.059551098456722684, 0.04917266785923857, 0.05028811581723858, 0.04435817034391221, 0.05705372699594591, 0.07910463769803755, 0.012190969518997008, 0.022858213378640357, 0.03933865453291219, 0.05347431906557176, 0.04727170853584539, 0.04433226567925885, 0.07376239154837094, 0.05118543915159535, 0.03958212721045129, 0.03768497510463931, 0.06330901145702228, 0.005555175275731017, 0.0531537966162432, 0.0671519931347575, 0.0561360947904177, 0.09866186912404373, 0.034141409196308814, 0.06559805464348756, 0.03431765813729726, 0.032010410068323836, 0.014599052265111823, 0.10560282011283562, 0.05063289907411672, 0.06310429002041928, 0.04380062819109298, 0.046033179096411914, 0.04450508589798119, 0.023171323628048413, 0.01519041130450205, 0.06852889229776338, 0.03662513627205044, 0.025944258231902495, 0.05039796480559744, 0.0027692203866536147, 0.056050306229735725, 0.02229933721537236, 0.015494013714487664, 0.0411858044390101, 0.023453773901565, 0.039314404857577756, 0.02290067721332889, 0.010742082959041, 0.009701553881313885, 0.025606410345062613, 0.013177349646866787, 0.058614715890144, 0.02960063429782167, 0.020217882010911126, 0.08767219085711986, 0.1262157640303485, 0.07339050134760328, 0.01557516570755979, 0.05628339626127854, 0.03223550345865078, 0.07039258096483536, 0.054084787479951046, 0.018068394128931686, 0.054605118348263204, 0.03259027602325659, 0.029636086692335084, 0.03869577652949374, 0.028025386891386006, 0.023303041853068862, 0.04282656678697094, 0.04068822781846393, 0.12693043740000576, 0.046188744381652214, 0.027386002548155375, 0.053128133149584755, 0.018665336901904084, 0.025064610999834258, 0.049409312778152525, 0.03311308195407037, 0.03199424238118809, 0.02349037105886964, 0.011520777698024176, 0.03500621904095169, 0.02205796481575817, 0.04993173650291283, 0.06348139009787701, 0.017856466438388452, 0.018440067251503933, 0.036617302903323434, 0.03501001512631774, 0.02586401351436507, 0.06552175444085151, 0.02713991008931771, 0.028042630692652892, 0.04145106657233555, 0.018363768904237077, 0.0738271365116816, 0.011954411802435061, 0.020123341673752293, 0.21985651430441067, 0.11464508803328499, 0.2331127115758136, 0.20526065141893923, 0.10620173328788951, 0.08836763518047519, 0.1564548086025752, 0.20431476936209947, 0.1323691479046829, 0.17872336524305865, 0.14014312997460365, 0.1858532225014642, 0.2702391834463924, 0.12498743541073054, 0.14201026962837204, 0.127824027731549, 0.22912138199899346, 0.11411765110096894, 0.10970031391480006, 0.18550947454059497, 0.06885943002998829, 0.15981152770109475, 0.17091723333578557, 0.11700241622747853, 0.19133048015646636, 0.13108900253428146, 0.1459583023097366, 0.14801902376348153, 0.21958313678624108, 0.13269667251734063, 0.1583757094340399, 0.1444516534684226, 0.06219547081855126, 0.09023334991070442, 0.12792985799023882, 0.15741848736070096, 0.11078551193349995, 0.1658880992908962, 0.1584518389427103, 0.08891933292034082, 0.06835691441665404, 0.26990759186446667, 0.12197883552289568, 0.12354389880783856, 0.1428075588773936, 0.10034609906142578, 0.10696734025259502, 0.19124044280033559, 0.12049284065142274, 0.1221876239287667, 0.11017415294190869, 0.21498032205272466, 0.17539529304485768, 0.13126995298080146, 0.1262598327593878, 0.1976458600256592, 0.10766573090222664, 0.2141188964014873, 0.15573255048366264, 0.12870126112829894, 0.16617237153695896, 0.1680787856457755, 0.11711799830663949, 0.11963518511038274, 0.1358368477667682, 0.07483385983505286, 0.14449971495196223, 0.17030705435900018, 0.09230584924807772, 0.10070247095427476, 0.16289083199808374, 0.10858436129637994, 0.12098035746021196, 0.10395646939286962, 0.23401357495458797, 0.10511066488106735, 0.08528131016646512, 0.19668308668769896, 0.25483305857051164, 0.10353970152209513, 0.2082016342319548, 0.13384484918788075, 0.16866870399098843, 0.07645217221579514, 0.08499286705045961, 0.11211684322915971, 0.1093382052204106, 0.1288361835759133, 0.10129256741493009, 0.17753220337908715, 0.11125559569336474, 0.08040624597924761, 0.11839403217891231, 0.17738591122906655, 0.10793762412504293, 0.1107290196523536, 0.1167567579250317, 0.1269094939925708, 0.20040172152221203, 0.17701281874906272, 0.13058101729257032, 0.0881293835118413, 0.12631078861886635, 0.11835745914140716, 0.1905088929925114, 0.269324115361087, 0.11909429304068908, 0.17133858025772497, 0.14422664913581684, 0.17815238650655374, 0.18631181039381772, 0.1543530315393582, 0.18768801935948431, 0.3150131308939308, 0.16250936809228733, 0.12206372237415053, 0.11552048090379685, 0.12328618802712299, 0.10595870218821801, 0.09800420011742972, 0.16691558790626004, 0.14236391783924773, 0.09640664560720325, 0.12168593952083029, 0.09527306698146276, 0.1039919737377204, 0.22157906874781474, 0.14567532140063122, 0.19037817110074684, 0.13709907769225538, 0.09415027918294072, 0.15020705322967842, 0.27222923759836704, 0.12341828289208934, 0.08877287007635459, 0.1798785329447128, 0.07710816396865994, 0.19504789786878973, 0.08094952776446007, 0.1477197601343505, 0.11646101207588799, 0.14052698359591886, 0.1675592822721228, 0.10174881754210219, 0.17166928126243874, 0.15197480446659029, 0.08689545909874141, 0.07996870539500378, 0.17408752493793145, 0.08499116753228009, 0.07852654918679036, 0.11166065247380175, 0.19656067684991285, 0.10294567167875357, 0.13118484348524362, 0.1309278080589138, 0.2036623770254664, 0.11494936115923338, 0.0439686726895161, 0.1030848095251713, 0.0982119346735999, 0.09756243671290576, 0.15410837513627484, 0.10848784499103203, 0.1984690353856422, 0.1203792697924655, 0.14319684501970187, 0.0974459046847187, 0.18018052767729387, 0.1314113024272956, 0.16726077563362196, 0.08506982776452787, 0.1297412029816769, 0.11170927056809887, 0.16301441442919895, 0.15161897434154525], [0.03364084172062576, 0.01993684552871855, 0.016622812909190543, 0.09374653600389138, 0.07042544326395728, 0.029831323481630534, 0.02482303822034737, 0.08828911595628597, 0.02333212847588584, 0.016805590894364286, 0.09498680577962659, 0.07776691651088186, 0.031167285778792575, 0.04075568533153273, 0.032600859049125575, 0.029118438687874004, 0.027143212646478787, 0.0318386956496397, 0.041546080028638244, 0.014421925734495744, 0.06789040780859068, 0.04383646279165987, 0.018985365823027678, 0.04311262018745765, 0.02652283841598546, 0.09088043589144945, 0.06600381646421738, 0.01840283555793576, 0.025313577425549738, 0.07846584892831743, 0.035072656100965105, 0.03908595324901398, 0.07409983125398867, 0.042676753146224655, 0.02457497535942821, 0.025864510753308423, 0.05400509195169434, 0.02496094039088348, 0.014232325556804426, 0.03204807035217527, 0.019824823903036304, 0.03234965319279581, 0.12827482307329774, 0.04244270945491735, 0.0507563330756966, 0.015756617103761528, 0.030329903856909368, 0.08501562871970236, 0.026266083150403574, 0.020873792127531487, 0.01753757671394851, 0.024732742967898957, 0.06302692854660563, 0.08706233842531219, 0.025783245582715608, 0.021824167888553347, 0.07785025969496928, 0.04768865452206228, 0.022826891035947483, 0.011881015252583893, 0.0226709454000229, 0.03516313874570187, 0.04364536718640011, 0.025897816485667136, 0.04887616501946468, 0.03153191035380587, 0.0323692867095815, 0.04279327033145819, 0.04966351691109594, 0.04286136980226729, 0.06408076340449043, 0.1199129041924607, 0.0343285380222369, 0.013447200108203106, 0.016158347207237966, 0.04096462587767746, 0.03539088160323445, 0.009830562339629978, 0.03496491481200792, 0.030736220433027484, 0.02498351281246869, 0.03587934093957301, 0.035030988219659775, 0.013156244822312146, 0.05477612401591614, 0.018248518936161418, 0.040072330593829975, 0.029912764912296552, 0.0006193840431478748, 0.03479047671135049, 0.005841183683514828, 0.06472109584137797, 0.023972724375198595, 0.02385271724051563, 0.030029512163309846, 0.08414949043071829, 0.08001299676834606, 0.04074170326930471, 0.030134253320284188, 0.040175155154429376, 0.03165614958561491, 0.0349840844864957, 0.033019897891790606, 0.030782665890001226, 0.01698498283076333, 0.08260260976385325, 0.028631556415348314, 0.05470372751005925, 0.03448409217526205, 0.05162124311027583, 0.027967241476289928, 0.052695531558129005, 0.04074612646945752, 0.035802387646981515, 0.07600167373311706, 0.02179441518819658, 0.04970994566974696, 0.03317170048831031, 0.04881196924543474, 0.10292569306329824, 0.09288369285059161, 0.021529767182073556, 0.021244298222882207, 0.03578146279323846, 0.045796081467415206, 0.03846944746328518, 0.0032913215090957237, 0.029648885029018857, 0.013500410241249483, 0.025412735776626505, 0.0514364483387908, 0.026959575625369325, 0.02573043620941462, 0.017746038574841805, 0.03798075435042847, 0.04489440172619652, 0.05649227001413237, 0.07544499618234113, 0.03021697495569242, 0.038300530941342004, 0.04784485434356611, 0.07333980523981154, 0.007910331296443474, 0.05404400646511931, 0.06201462427270599, 0.04284262686269358, 0.01737512429826893, 0.03269005777838174, 0.024364641431020573, 0.020371621612866875, 0.02128909054590622, 0.01193287096612039, 0.06786762387491763, 0.02474522032571258, 0.03029364252142841, 0.013468010856740875, 0.03854337650409434, 0.089791601349134, 0.02750874264165759, 0.0316465907235397, 0.02276479368447326, 0.013854367371095577, 0.05429380966234021, 0.09952500913641416, 0.10399861595942639, 0.029465639490808826, 0.06065672409022227, 0.017397735682607163, 0.04778097769303713, 0.06101534469053149, 0.042504248340264894, 0.021203055221121758, 0.06455468406784348, 0.043998829860356636, 0.0237940523220459, 0.05208731185120996, 0.045354882095125504, 0.001751200763919769, 0.020818748889723793, 0.054191671588341706, 0.023236762499436736, 0.04557999403914437, 0.030721165967406705, 0.03723913359863218, 0.018517473254178185, 0.06224838594789617, 0.025482575583737344, 0.01421590739482781, 0.031597764827893116, 0.0250487995435833, 0.04884521746134851, 0.030399888382817153, 0.08006202304386534, 0.0755662631127052, 0.032638396878610365, 0.034417087372276, 0.08495216025039554, 0.03328419152239803, 0.004041869369757478, 0.06110044305387419, 0.0006492893476206518, 0.03635685730841942, 0.03544636827427894, 0.035183087675250135, 0.022187028007465415, 0.05137291307619307, 0.03369765683601145, 0.0465864130819682, 0.06739037096849643, 0.06093093652452808, 0.021733163885073736, 0.029689747680095024, 0.05852549489645753, 0.029546695004682988, 0.04883817076915875, 0.017875827215902973, 0.008955576722655678, 0.05608830048004165, 0.1006687106564641, 0.02698525207961211, 0.04114480449061375, 0.02491785129677737, 0.01904279135487741, 0.06912816170370206, 0.0422213564888807, 0.03855851260595955, 0.05238185913185589, 0.042739939599414356, 0.030735073814867064, 0.026918712974293157, 0.0035659108152685803, 0.026207926603092346, 0.058732843535835855, 0.017863585489976685, 0.049510114986333065, 0.033730533978086896, 0.015318008754547918, 0.03597453993279487, 0.022220203863980714, 0.058741129614645615, 0.024529157017241232, 0.009672925534687238, 0.03736705388291739, 0.069384685048135, 0.02774779211904388, 0.018042995980067644, 0.0641835063288454, 0.04369470516394358, 0.03415673454583157, 0.01981630590307759, 0.07204560359241441, 0.02986943090945715, 0.01948049150087172, 0.030573424774047453, 0.0292503016316914, 0.01902239899209235, 0.051746083481702954, 0.006117566899774829, 0.016871463922143448, 0.02134118003596086, 0.07194857520516962, 0.013377413179114228, 0.030681256976095028, 0.0629807669611182, 0.050338986329734325, 0.024957366949820425, 0.06790998566430062, 0.024408802928519435, 0.025521592142467853, 0.053300485815270804, 0.002686056941456627, 0.16385995812015608, 0.053846376249566674, 0.005197141899770941, 0.02573585388745414, 0.022578603675356135, 0.07921365177026019, 0.020200905382807832, 0.015126111629797379, 0.049365073355147615, 0.018495748736313544, 0.08536943278159015, 0.04812548264453653, 0.06244121817871928, 0.015459275637113024, 0.02970188550534658, 0.041591881672502495, 0.02836384519468993, 0.08852365688653663, 0.07258679252117872, 0.032954336566035636, 0.03611399690271355, 0.11335927265463397, 0.011424477543187095, 0.024554052361054346, 0.051547095135902055, 0.04491335617785808, 0.03538272168952972, 0.06432872978621162, 0.0336684310605051, 0.11318394768750295, 0.0254136003786698, 0.08245351229561493, 0.041309728258056566, 0.058989867829950526, 0.03940667607821524, 0.016029334110498894, 0.007823613195796497, 0.028628669460886158, 0.020738418825203553, 0.09657230781158432, 0.01477163314120844, 0.04921675514196977, 0.067817655071849, 0.06953622418222949, 0.013305243028298719, 0.09309199886047281, 0.013223763562564272, 0.043570209891186096, 0.02881846816308098, 0.035480251026456244, 0.04954993120918516, 0.020985793344152626, 0.04117455719097052, 0.05838420853251591, 0.038649659472866915, 0.02267485651827883, 0.053913499796180986, 0.04587476396409329, 0.031503675345447846, 0.01989676213270286, 0.04793690663063899, 0.07539608865045011, 0.03152858182147611, 0.012301131137064658, 0.02775978708086768, 0.07874534916481934, 0.019135313050355762, 0.015763044102641288, 0.01812262100429507, 0.11373777539120056, 0.026619892778398935, 0.02731115138885798, 0.012177805674582487, 0.040598435371066444, 0.03438949803239666, 0.04179441377345938, 0.01353513811409357, 0.030353450347320177, 0.041230737770092674, 0.023916169011499733, 0.06411505804862827, 0.11389477673219517, 0.18149876006646082, 0.18260714277857915, 0.1807273569284007, 0.15521326975431293, 0.11319453071337193, 0.15379748947452754, 0.13490040582837537, 0.08819580572890118, 0.18641994131030515, 0.19050052156671882, 0.14232750807423145, 0.08389195776544511, 0.1284903279156424, 0.12362163135549054, 0.10417815632536076, 0.14489075256278738, 0.11661413940601051, 0.11453021841589361, 0.13324976549483836, 0.17678536532912403, 0.11191293073352426, 0.1294704675092362, 0.10841487703146413, 0.13367114210268483, 0.20022632234031335, 0.18717911385465413, 0.12322220747591928, 0.08491086715366691, 0.1406174068688415, 0.1962497318163514, 0.0992047278850805, 0.1745015988126397, 0.17852988734375685, 0.14356156607391313, 0.12477161886636168, 0.07868714994401671, 0.19261991721577942, 0.11421519157011062, 0.14786913961870596, 0.18765414773952216, 0.11390358602511697, 0.1514116331236437, 0.21078656427562237, 0.1787674191291444, 0.12403095548506826, 0.11710875856806524, 0.1806875629699789, 0.09531459014397115, 0.0725271312694531, 0.1611048387712799, 0.18226021842565387, 0.12574892345583066, 0.16106777591630816, 0.16533592657651752, 0.1286209310637787, 0.14508304302580655, 0.1131831387465354, 0.2409231776255183, 0.13839952822308987, 0.09721663300297223, 0.1154515056987293, 0.1715565045014955, 0.1629212303669192, 0.15074591181473807, 0.07865764215239324, 0.16045045747887343, 0.17268053168663755, 0.1088426064234227, 0.08829243335640058, 0.12656869977945462, 0.19842489244183525, 0.12583262287080288, 0.16274765686830506, 0.14410520409001037, 0.09881203528493643, 0.14942751615308225, 0.07828454225091264, 0.15601386898197234, 0.1305536914151162, 0.1786418625852093, 0.14838543691439554, 0.11375851099728607, 0.12145963642979041, 0.23408252047374845, 0.11626360079389997, 0.10997506440617144, 0.07996525440830737, 0.10310193087207153, 0.11451390600996092, 0.23373138072201982, 0.12600873451447114, 0.12789211235940456, 0.11583112907828763, 0.09506667571258731, 0.28113230830058455, 0.1449672828312032, 0.17692886700388044, 0.15451343933818862, 0.20771567593328655, 0.18843603000277653, 0.16699026280548424, 0.07913393768831156, 0.12053483878844418, 0.1290185292600654, 0.28469167824368924, 0.1375027614994906, 0.2263929502805695, 0.12205878709210083, 0.09442801310797222, 0.1533414694131352, 0.231736057321541, 0.16471943934448063, 0.12499467877205461, 0.19987590989330783, 0.10181970748817548, 0.15831639699172229, 0.11705016600899398, 0.15375874936580658, 0.10645698755979538, 0.15157588524743915, 0.18704076268477365, 0.12616964697372168, 0.132313086069189, 0.11395995956263505, 0.10825587189174257, 0.1014407149341423, 0.11900115350726992, 0.1594417600426823, 0.05004817576264031, 0.13888354209484532, 0.16280150710372254, 0.3255356865702197, 0.0708371125801932, 0.13833512464771047, 0.15902228333288804, 0.17778796231141314, 0.1415360372629948, 0.191477469925303, 0.07892498600995168, 0.11043083955883048, 0.10111296767718159, 0.1193785949726589, 0.14390029711648822, 0.15769078134326264, 0.13738259294768795, 0.055264045295189135, 0.2018137910636142, 0.06482750497525558, 0.14335042505990714, 0.06493228880572133, 0.1672200910979882, 0.14469172339886427, 0.07216806538053788, 0.14932349673472345, 0.09778252802789211, 0.16014687455026433, 0.14758137927856296, 0.17068079992895946, 0.12584955868078396, 0.15005630819359794, 0.10746471278253011, 0.18365612399065867, 0.22052073647500947, 0.24749857635470107, 0.09771888886461966, 0.133302561880555, 0.12757027259794995, 0.20042183372424915, 0.18377734639216214, 0.12115577890654095, 0.0717881006130483, 0.11462364738690667, 0.16785706160590053, 0.07062373770168051, 0.2860744181089103], [0.045417897854349576, 0.03999293563538231, 0.0425628742959816, 0.044548675941769034, 0.0532472589839017, 0.029215090435172897, 0.040096695302054286, 0.051496603118721396, 0.053870659321546555, 0.017299299070145935, 0.02252415601105895, 0.033032232386176474, 0.05245607018878218, 0.012219484688102966, 0.027537784735613968, 0.05544740772165824, 0.020094127030461095, 0.03151107455778401, 0.038328120281221345, 0.03050824936508434, 0.03686363284941763, 0.017870576521090697, 0.0298765907791676, 0.10533955806749873, 0.06741182645782828, 0.08830978476908058, 0.020953554449079093, 0.045687575766351074, 0.03404665178095456, 0.057365518077858724, 0.027257254769210704, 0.029813411747454666, 0.059871260964428075, 0.02182458349125227, 0.04098604425962549, 0.08299323919345625, 0.033398241066606715, 0.048851740939426236, 0.03215109529264737, 0.07421550981234759, 0.03851213208690751, 0.10372221790021285, 0.006222353049452067, 0.03099909099546494, 0.04408314525790047, 0.007383028414551518, 0.019932286886614747, 0.0400831696606474, 0.05881063174456358, 0.04036233221995644, 0.0021142040941413143, 0.014187503547873348, 0.05250177906418685, 0.02394949144218117, 0.029981263287481852, 0.03257052005210426, 0.012771763158525573, 0.05185694921237882, 0.01250302035259665, 0.012711183499050094, 0.07631592132383958, 0.042780093499459326, 0.04730202526843641, 0.011989855847787112, 0.08180358388926834, 0.05404087089118548, 0.05297561809129547, 0.018200331287516747, 0.03304819227196276, 0.03110030695097521, 0.022303693622234277, 0.02688959109946154, 0.009851044687820831, 0.022240861544560175, 0.04311670571041759, 0.05344960925867781, 0.020940166104992386, 0.062481858185492456, 0.0166727297619218, 0.05783596177934669, 0.023758744646329433, 0.0891990632226225, 0.0491357237478951, 0.017435496156394947, 0.04120441008126363, 0.07025285682175308, 0.011027204964193515, 0.10259968243190087, 0.05415727304352913, 0.09547807785565965, 0.06337724451441318, 0.05166272174392361, 0.061435029201675206, 0.04030214775411878, 0.058101390895899385, 0.08400095699471422, 0.06841257549240254, 0.036097818083362654, 0.03834768329397775, 0.03249455010518432, 0.017308286478510126, 0.06803396143368445, 0.01771910046954872, 0.03348837490193546, 0.045915815862827, 0.051911563859903254, 0.008412533352384344, 0.07445943148923106, 0.0047703981726954225, 0.05196374797378667, 0.02655696422152687, 0.03720701715792529, 0.021484091703314334, 0.024731468329264317, 0.0372818664618535, 0.042172679022769444, 0.07317928611882962, 0.015968212683219463, 0.03682889662741218, 0.04231482256727759, 0.1057917189609725, 0.020703077752841637, 0.04453633773664478, 0.01340899712886312, 0.0835603364976123, 0.04545485680864658, 0.03244355342758354, 0.052384089285624214, 0.04301040789869148, 0.02821627840603469, 0.03468572627753019, 0.061959846352692693, 0.026317873926018365, 0.022224320928216912, 0.055295764686889015, 0.03978068882133812, 0.008157206721080001, 0.03473553551884834, 0.05154178506927565, 0.01213289275256102, 0.036680867851828225, 0.015196503409242723, 0.034015199562418275, 0.07654088854906149, 0.02757160440523876, 0.03730814591108356, 0.054362302471417934, 0.02280251334013883, 0.03644274976977613, 0.059959554273518734, 0.03315510977699887, 0.10919757565716282, 0.06705052670440637, 0.025180881420965306, 0.04634368255210575, 0.006813860054535326, 0.04916566569590941, 0.020029140869155526, 0.010498267038201448, 0.010982704861817183, 0.029446184089465532, 0.05126687872689217, 0.037456044810824096, 0.03247870896302629, 0.03349649028677959, 0.005233508063611225, 0.04970680638507474, 0.013947131192253437, 0.023844091629143804, 0.04524823176325299, 0.025135116884484887, 0.03839163327938877, 0.03804892061452847, 0.02636134893691633, 0.03181905842211563, 0.035404570517130196, 0.018173771677538753, 0.013346514788281638, 0.04613379205693491, 0.01371796990497387, 0.057516619344823994, 0.04595345388224814, 0.08816080604447052, 0.028433165498427115, 0.016714965386199765, 0.03606802085414529, 0.01650411566515686, 0.00653452772894525, 0.016737524820200633, 0.005170519207240432, 0.01645139534957707, 0.00407443156291265, 0.02699851796933217, 0.01808639121009037, 0.1396332893637009, 0.013789793101750547, 0.0223140020534629, 0.03917253590770997, 0.06725567858666182, 0.017691136345092673, 0.05996980704367161, 0.09693354077171534, 0.04138635500567034, 0.04657894707634114, 0.015439253420481691, 0.08790240506641567, 0.02701855410123244, 0.04925086053845007, 0.055913984833750874, 0.02652392751770094, 0.042965908723999746, 0.07700784044573084, 0.02513525603717426, 0.06501322743133642, 0.05055108842498157, 0.008961659550550394, 0.05582114215940237, 0.05547932749323081, 0.06848302757134661, 0.018520217345212586, 0.06336145161185414, 0.030237402570492122, 0.0204534600925399, 0.008698455021658447, 0.11266145345871337, 0.040434309412376024, 0.052156869642203674, 0.03952648097765632, 0.0378601071133744, 0.02025021367444424, 0.06628242612350732, 0.06492558721220121, 0.04277783737052232, 0.020637217712646816, 0.007997728462214582, 0.04101915888895746, 0.04379128084110562, 0.042744689344544895, 0.05939868358836975, 0.041101143942796625, 0.0637939159059897, 0.03386900389159564, 0.04798196612682659, 0.027578016561164986, 0.010648532461345894, 0.022884327700012363, 0.01547630236018449, 0.03369446931174025, 0.03304691948869731, 0.03236203592678066, 0.005177857192393276, 0.05487177571922075, 0.01727969338389812, 0.007140093794077984, 0.054575488102273084, 0.07162689871620387, 0.06632325166719966, 0.05471319360367488, 0.03619536968471948, 0.022457856248365715, 0.01655805124755716, 0.030677818976982962, 0.03016617123648757, 0.03774700751819182, 0.043839268109877594, 0.05090105929411948, 0.03346361314470414, 0.059751637891167775, 0.04899406631011516, 0.08321531204273924, 0.030855789700581226, 0.06363853244693018, 0.09108727987040766, 0.0752392208960373, 0.03047117166715907, 0.06728054795530625, 0.026116614608326927, 0.058550987669150345, 0.044401259438018315, 0.03786755827604793, 0.05361641065974254, 0.06758155563147739, 0.009460520086577162, 0.008710847960173851, 0.024562028593209106, 0.022715708037139848, 0.022100226415204816, 0.006794748360334779, 0.04147118619584944, 0.016131149350258056, 0.021484169628820382, 0.06664310247288086, 0.06292411882895976, 0.029830980238330085, 0.0463032577681588, 0.04690024878073018, 0.03555485171091277, 0.052949134551454335, 0.015996442125469912, 0.06310959637630731, 0.04540826106676832, 0.016215483301493805, 0.04520879403571598, 0.015623579711245839, 0.051862678592442535, 0.10557789137237705, 0.028576500189956278, 0.028391015221131966, 0.011750374997063773, 0.030047277323319577, 0.029136135199223645, 0.04029016577987932, 0.04490530387556646, 0.027240549025009386, 0.05441603025246877, 0.025870342178677674, 0.026775697406264953, 0.039879516916698776, 0.035215586322010495, 0.02106726446072571, 0.02616475958348019, 0.024255868556792848, 0.021837216700077988, 0.0398946938366862, 0.054290306725306436, 0.03876172377204057, 0.049631389338173904, 0.12867166427895427, 0.08575372427003458, 0.03324661658552941, 0.073555666313041, 0.029058927721052896, 0.022488269460154697, 0.0500201151589863, 0.009122134142671712, 0.10169331231736578, 0.04065426343004219, 0.03731215721927583, 0.02760737592325313, 0.04272413185390178, 0.04415382369188592, 0.034927729502669536, 0.053872139906161465, 0.027156751275470015, 0.05035890186263714, 0.034770212369039655, 0.027387232657929417, 0.017785626587283332, 0.00949933997617336, 0.028843380205216818, 0.025689152389531955, 0.035778724268311635, 0.14391901408089325, 0.12998531019547954, 0.2065009286161512, 0.14623432187363505, 0.20124416303588077, 0.15336566342739388, 0.2605483972001821, 0.20711671822937205, 0.1470763626275584, 0.17658928991295397, 0.17674165283096954, 0.060541650382219814, 0.15463871386600658, 0.12862811505328864, 0.08570926962420344, 0.1315436718869023, 0.15547063172562048, 0.12221699813380837, 0.18202917301096022, 0.06847381751867943, 0.10687182584661059, 0.08803601391264237, 0.15512927348027006, 0.1751966794836335, 0.15582644700771198, 0.15612398885423318, 0.10186118612182327, 0.12277247340534814, 0.12292581595829688, 0.2195699859294109, 0.12933032034197822, 0.25957820238545537, 0.13762576505541801, 0.09072004293557256, 0.18373557832092047, 0.3553412575274706, 0.22555267583811656, 0.1268995788996108, 0.16535592003492638, 0.19703036727150902, 0.15022581472294405, 0.22393523919163272, 0.21264125069137663, 0.10818532333360054, 0.19755971152335405, 0.07607562132761814, 0.10435971533297561, 0.1082584990945179, 0.18716511694947258, 0.11785459471866488, 0.19942288810852915, 0.11735451334971003, 0.20216494565829635, 0.22384972893632948, 0.20511093054665253, 0.15574774966808036, 0.1474190567387268, 0.15409195882966742, 0.12738313263980672, 0.10942095468635671, 0.16970483120530844, 0.15855802543228492, 0.1849282838520594, 0.15989449981134385, 0.17754477536072955, 0.09027927400893532, 0.13600676989881322, 0.1885380456224084, 0.13017112913075835, 0.1480513665592298, 0.16456351411761716, 0.10336772364098579, 0.0549460387264844, 0.11845884393551387, 0.1403574473806657, 0.2425406439579092, 0.04885302114416845, 0.11643599427770823, 0.15117377479327843, 0.18972827238030732, 0.1869310435722582, 0.1382078166352585, 0.14523613324854523, 0.06216327274159994, 0.11932720866752788, 0.11728195357136428, 0.15125441655982286, 0.21437707473523915, 0.18531599664129317, 0.23568196746055037, 0.19402812758926302, 0.17202350834850222, 0.16364446812076494, 0.1309008977841586, 0.15972999535733834, 0.18853541841963306, 0.2042365024681203, 0.18581908370833844, 0.1563821968738921, 0.14986964320996776, 0.10155298703466542, 0.1794823448290117, 0.09671457009972073, 0.18226305342977867, 0.24195593548938632, 0.10954021039651707, 0.08540929353330284, 0.15730856044683605, 0.12655406462727115, 0.16043368494138122, 0.1355428682290949, 0.1343524336698465, 0.11836766367196105, 0.07063279932481237, 0.08078895669314079, 0.16971921402728185, 0.2123062007012777, 0.12299917725613341, 0.15689202264184132, 0.11918141375645064, 0.2236988057848066, 0.17904894542880356, 0.11940420648897998, 0.21474572917213663, 0.15629349538357928, 0.14073658094275743, 0.15971170883858576, 0.13346847641514614, 0.14964879490435123, 0.2015072840731591, 0.104131846310338, 0.1270730930264108, 0.08971656279754825, 0.11133602965855971, 0.13561487139668316, 0.09668927770690061, 0.10858424997422844, 0.119609499379294, 0.09409342324943282, 0.08361066895304248, 0.07806043591699563, 0.10039768574642949, 0.08788479390204884, 0.2260461446712725, 0.07581590674817562, 0.07848522640415467, 0.09112844680203125, 0.14472903858404607, 0.07242856663651764, 0.14404494169866666, 0.12615103390999138, 0.21813078346895054, 0.1511734037194401, 0.07443159352988005, 0.11903069098480046, 0.06515019820653833, 0.19436377129750326, 0.14920076035195962, 0.13478924694936723, 0.24836582044372335, 0.15197775821434334, 0.17399811098584905, 0.1343424740480259, 0.16993779136100784, 0.12410712952259928, 0.12821623793570325, 0.13723162526730448, 0.12348362899501808, 0.1981495408108458, 0.1368842407828197, 0.16267838480416685, 0.09074060784769244, 0.10077349448692985, 0.10076585036586039, 0.07966141914948821, 0.20482836524024606], [0.06752056593541056, 0.051327519613550976, 0.07115485568647273, 0.01045159708155552, 0.04355725570349023, 0.04789686034200713, 0.017615971628401894, 0.06151001209218521, 0.04992728361685295, 0.0045478368974727346, 0.020828344859182835, 0.10732075839769095, 0.03495020544505678, 0.06472032400779426, 0.09613381727831438, 0.041154010832542554, 0.0243886925818515, 0.040115916926879436, 0.04436427821929101, 0.030714074746356346, 0.07373437547357753, 0.045589092769660056, 0.03628836078860331, 0.06003566522849724, 0.06625164925935678, 0.03309264320705552, 0.041007362451637164, 0.023594700323883444, 0.05225561239058152, 0.007305253193408134, 0.027103390857519116, 0.04192667933239136, 0.04389254318084568, 0.020828541528317146, 0.07986231110407971, 0.031439101076102816, 0.0672241447318811, 0.020601598334906157, 0.015187857388809789, 0.03325818295706995, 0.024466514187224675, 0.030070295033510774, 0.03825157145911362, 0.014821727181697497, 0.03982988579082303, 0.019460581534076482, 0.05255803385807667, 0.07734307597274892, 0.05040710064349696, 0.0597680987266358, 0.0336975343816448, 0.0463874915294582, 0.04301012588257436, 0.029623770751641132, 0.016603446565568447, 0.03383534749445971, 0.015553311313851736, 0.010829573820956284, 0.03083023755607428, 0.07156785344704986, 0.03526885397150181, 0.0977558626618702, 0.0050023958556266734, 0.09736175255966373, 0.06965411434066482, 0.05301754572428763, 0.026643405872164294, 0.04800760361831635, 0.08442997030215338, 0.01605511446541641, 0.03601105730922427, 0.006205590716490406, 0.05632998458168004, 0.04575021674099844, 0.02707940093387151, 0.026401712493679952, 0.1482979822321795, 0.04986382999049965, 0.043868486463907175, 0.012998874262848403, 0.03717973580933176, 0.03343675110954791, 0.09281635037041269, 0.07941399453557096, 0.027333501166140195, 0.03450886135397013, 0.03605786827392876, 0.05973381150397472, 0.05971536542347167, 0.04312965989811346, 0.06575415798579343, 0.0069942432219249895, 0.029112985757819843, 0.030819515377515927, 0.03398318702238612, 0.02133944712113589, 0.049456661799922585, 0.021244298222882207, 0.016255616792477667, 0.06273971739574336, 0.02320119136129506, 0.033661978086456656, 0.07444354210747406, 0.04661288548959419, 0.03383219336683396, 0.038957543147262186, 0.025558285778970458, 0.04544695664662868, 0.09477496714680456, 0.008974533029686427, 0.03799735990469344, 0.03448978815868031, 0.039541487203678116, 0.04474566419958137, 0.027516605696291663, 0.020956105581717566, 0.02147220991901122, 0.042833891784539446, 0.04169172279944178, 0.021803415584145114, 0.10656471029506065, 0.06758883610018529, 0.01355745171167655, 0.010678197959350655, 0.04227968558552675, 0.014089461201365339, 0.1212083303835243, 0.02223447536380263, 0.03959750079957303, 0.01972688638488762, 0.01158147146270494, 0.017421228367311414, 0.015488370609091362, 0.007881984965933952, 0.06584168688277714, 0.028397841124387924, 0.018221124410047196, 0.042711296409834176, 0.04572703575831838, 0.0803461171744857, 0.038833545113448054, 0.03654463180282619, 0.008303006270580227, 0.03693901278893463, 0.02554237042204477, 0.027857232926180586, 0.04297710402170196, 0.004749601803268888, 0.03973493912781123, 0.017750563820300158, 0.013702467367693316, 0.040371193463215604, 0.06959820093470626, 0.04423607591888867, 0.048318726767320186, 0.03398939879843965, 0.02359441830776632, 0.060503667264129035, 0.02026767826464493, 0.008332605902978685, 0.09107266698265448, 0.04287963776732795, 0.04670320857258048, 0.08861338996211998, 0.0488629251049133, 0.06248953941394575, 0.01881813397631049, 0.04487556972890161, 0.06030561402440071, 0.030641487137472723, 0.022319822346617002, 0.04613254524883814, 0.003944705540561699, 0.025525245364406146, 0.03957593027735129, 0.01928820289322175, 0.0348882324033184, 0.03153427409415599, 0.02423233505396638, 0.024389657373831142, 0.02650046080816537, 0.029154965341149364, 0.05124041003000457, 0.03930120205041021, 0.02387681663094554, 0.04674744057410862, 0.032674750982550904, 0.016382963767682668, 0.009219347139151068, 0.055482359166489914, 0.06271250284044072, 0.08609321230323985, 0.04639573679014575, 0.029961425680085085, 0.06283929877099581, 0.04790989987668581, 0.07734289785730653, 0.04243684648827184, 0.003847772472909128, 0.07599338394356892, 0.07336494178161956, 0.0344983562536072, 0.012220353928569239, 0.02387689641182078, 0.030496037325065117, 0.06349673771183006, 0.07120453505194746, 0.028418535912351217, 0.025913332938216627, 0.02517919860110851, 0.07795511031872593, 0.056114205144695006, 0.054442784676211886, 0.03678800057969056, 0.030800035856373142, 0.06976064221817069, 0.061696331977145746, 0.005751975213570404, 0.03833946771919727, 0.017109619111579377, 0.045175564373494126, 0.06169141153804958, 0.02322837623069063, 0.08046532835578546, 0.032454808097099885, 0.049903905965038575, 0.042771269363584, 0.03456074860878289, 0.03003690580953844, 0.021792012485093437, 0.041441960420343094, 0.041999235399998724, 0.03392289494513534, 0.047417169480468147, 0.03385545227502007, 0.048761978177935816, 0.04899001789453905, 0.006662971691184794, 0.04838455526623875, 0.0661280594067648, 0.015239215863402933, 0.026361230193288065, 0.03305405523860827, 0.006247818919291603, 0.030223576359276194, 0.06359505743603222, 0.020575519265548792, 0.049150292106787674, 0.022614532899751794, 0.05039418727392331, 0.024872977337508928, 0.020922263647662476, 0.09518741571810097, 0.05741654444136657, 0.026921772478090134, 0.026950922183459625, 0.006469832860602764, 0.015388645442726556, 0.0423192457674304, 0.12123962675104849, 0.02310018320713425, 0.027738891913031694, 0.13689305749721825, 0.046627027113572694, 0.01808429093216546, 0.05111002581543289, 0.049403538869228214, 0.050318306384724565, 0.011638037958618952, 0.04526201344560832, 0.04109918838366866, 0.01829605349485064, 0.042647523659979925, 0.05153806690941565, 0.04734060581540689, 0.0729459771537222, 0.07742227797280066, 0.02392035472439602, 0.05577307325438596, 0.08078663377091289, 0.034788183475029655, 0.05982053517072927, 0.019632884104794357, 0.07112134029739536, 0.06455308845033869, 0.024951607883849647, 0.01236458290804876, 0.07676929933950305, 0.018638979527167976, 0.03308235332951881, 0.036644272549892776, 0.08836174252792262, 0.04536676387942862, 0.044200237607583404, 0.012443484338291455, 0.04897649596387055, 0.08097732119495049, 0.05897386712604202, 0.017454623157391325, 0.05566529856878333, 0.05753291319706477, 0.02981612429721281, 0.039897714377730154, 0.054074274958111346, 0.055534598941449076, 0.014776102725591045, 0.03972271966631524, 0.056565545964986086, 0.032240108484984376, 0.00463538063740998, 0.06246052886126563, 0.038751953397877514, 0.04912839132884983, 0.10394338532933034, 0.013065219482086832, 0.10334986756788567, 0.05051133157394361, 0.025696277007227764, 0.05664819895173423, 0.01843829537392594, 0.012642492165468866, 0.03280583652667701, 0.0334509187086951, 0.019791048762272112, 0.05221946608799044, 0.10221455231658183, 0.06464248013799079, 0.0447866901231464, 0.019635982571344357, 0.03060539092984982, 0.007981319577083923, 0.028019041528750677, 0.06313145262538455, 0.023356829005933832, 0.027567604229261633, 0.028539936429297086, 0.047462785587413236, 0.04036337493744213, 0.01737925620545866, 0.07439470136887394, 0.012210313598188804, 0.07839947124011815, 0.049207971824216656, 0.013234982980065979, 0.012980919855181128, 0.01576078611833509, 0.020269106898922473, 0.02785186719847843, 0.06262800190597773, 0.047385286816279404, 0.04384041472803801, 0.06881442619487643, 0.14386275928700343, 0.16584003780735657, 0.1760363602079451, 0.06292872014455497, 0.08918183055357076, 0.13946989813121036, 0.20900766598060727, 0.14801249286392704, 0.13695015833945945, 0.09302011443651281, 0.10274535117787309, 0.2434007782721892, 0.15503977047046646, 0.19709950574906543, 0.17558020655997097, 0.10765833911136724, 0.15389677399070933, 0.1620218067546375, 0.16817213298054412, 0.13323033606866375, 0.15670688648242503, 0.14528397208778188, 0.1850829622708261, 0.16135768848471344, 0.18410421791486442, 0.12939988926518708, 0.09787131857592613, 0.07504099325160496, 0.10562177456449717, 0.16541450517252088, 0.13416979112662375, 0.1533536406350322, 0.10169871515245177, 0.0831001900951378, 0.1898576584062539, 0.10308358498150483, 0.23810703889466822, 0.1600242272252217, 0.12638659158255905, 0.10583156486973166, 0.1690476297517307, 0.04877642779320013, 0.1024163571128156, 0.09548412635922432, 0.1702102634590119, 0.15992175147403032, 0.13672972563654184, 0.17286163056269288, 0.1788755797315389, 0.14820444193901494, 0.13565628323704004, 0.15708262100815773, 0.1604887077701278, 0.11552596537512727, 0.13754683022852987, 0.15810356388101354, 0.0770116550847888, 0.09639137220801786, 0.15597499528666958, 0.12732609116937965, 0.19011488679097965, 0.16956741514150053, 0.0835925605497323, 0.3188942070119083, 0.1264747735694982, 0.08238606591476128, 0.10611690580844879, 0.1396230625687167, 0.19394919276237488, 0.14776770287426189, 0.1295642156037502, 0.09933165740221739, 0.18982901150593534, 0.16257332637906075, 0.1379589893622324, 0.18282693723449484, 0.20720717118820176, 0.09753150399774313, 0.1622745970962569, 0.09803752996958792, 0.11051804191083647, 0.13242718385299668, 0.19161257048835978, 0.14253090106649324, 0.09305850573582575, 0.09925838516210206, 0.301880709012039, 0.15086055878782645, 0.1953306412906386, 0.11126340308692306, 0.20268155465601012, 0.11897785007022321, 0.10578538101981394, 0.12034737970679998, 0.1176816075167153, 0.10570997881586663, 0.11231757191126235, 0.21311911958036944, 0.21446847764309496, 0.11169639430590905, 0.14630910067353398, 0.15333349874708802, 0.18491167458705604, 0.17485643445979804, 0.15176332206465304, 0.16217721247812733, 0.1654074399266392, 0.1690719573525712, 0.21537772729061544, 0.07331226413953118, 0.11976451918599196, 0.11258616999839433, 0.17328913731034845, 0.18017352180322632, 0.12513761641457677, 0.1279716260614805, 0.09720089205075055, 0.1726639669504948, 0.15805827802978456, 0.1015226035087835, 0.21884860354475677, 0.15253027231665328, 0.14024609554326162, 0.15353257243987173, 0.1159611830371432, 0.1018180005485192, 0.1905285005341284, 0.11496772189275362, 0.19130276836222038, 0.15375459333881736, 0.1848519910709001, 0.22575905226403847, 0.11103355252998881, 0.09132718652836047, 0.13897834403906018, 0.1474760239943862, 0.11267711277469061, 0.24405759380897507, 0.28442943294066936, 0.2627796493470669, 0.12197333620861173, 0.16257485520327464, 0.11537898302776739, 0.10237075213808566, 0.11897024305653758, 0.11380473937606439, 0.1073646564327646, 0.1303132058819756, 0.11945692865992896, 0.13845498149748892, 0.10858918525627814, 0.1962538284715265, 0.08844317097100429, 0.12084042551578023, 0.10691594652598724, 0.1939767858129926, 0.13650141132529825, 0.1192895372514613, 0.13492688565747812, 0.1170221870415844, 0.1993923561531119, 0.16179509548237547, 0.12103323548217304, 0.20604844117769971, 0.08629630843643099, 0.1815975399222225, 0.1443579647457227, 0.14887228579027578, 0.1539663429139182, 0.10448659289977513, 0.11785209368099459, 0.07337305345572531, 0.17820047767600045, 0.08666082168929279, 0.16650136560201645, 0.16977684921585023], [0.11762222085963003, 0.011095224654127378, 0.03178549850417767, 0.016344019568350632, 0.01500528442193172, 0.03536014926794451, 0.05584365891991183, 0.03660141723230481, 0.04791583705809899, 0.019774009051616304, 0.007535714630648727, 0.031250506508513354, 0.03198192272975575, 0.02367596549447626, 0.01469526707296609, 0.056279592754435726, 0.10051758712506853, 0.06496190049801953, 0.053006409798399545, 0.011314083076285897, 0.03075119140703464, 0.002857768345165823, 0.09954696928616613, 0.051217581567470916, 0.03233247247408144, 0.023977579876373056, 0.02828011980454903, 0.03931912862753961, 0.02662812505150214, 0.06610076321521774, 0.025592309539206326, 0.04125849038246088, 0.03113044185738545, 0.03756157821044326, 0.0512746193271596, 0.05814392708998639, 0.0688984669977799, 0.01557470557600027, 0.015972426226653624, 0.05663133364578243, 0.0038473151244033943, 0.05039855852373876, 0.04910722898785025, 0.058880363940261304, 0.07311393259442411, 0.02801030088448897, 0.022198518308869097, 0.031287287347367965, 0.02206132674473338, 0.039089099955162965, 0.016620896312815603, 0.07189411640865728, 0.01990789434785256, 0.04894460587820504, 0.02481142175383866, 0.029311725484149065, 0.03435397884459235, 0.031762703438289464, 0.05293472575431224, 0.06476034061051905, 0.06325548034510575, 0.06664722139248624, 0.04405576743010897, 0.031066906594787724, 0.05126974341692403, 0.040869630975066684, 0.0468203046330018, 0.019926520399167202, 0.037342032373999245, 0.059157801006222144, 0.032683437821106054, 0.03683507500682026, 0.03462754932115786, 0.026313387643313035, 0.04533749357506167, 0.03897846800100524, 0.022384971780411433, 0.031274296052288264, 0.026350465341238305, 0.01765658937074477, 0.08090524381259456, 0.037232346658129245, 0.062184613198041916, 0.02615133227664046, 0.049723597476258874, 0.04095653275726363, 0.02085552601784002, 0.026087283076776657, 0.10759307464468293, 0.06628769537201151, 0.029222387602203526, 0.05556136820814572, 0.03190146650013048, 0.05912193671974819, 0.0180374948104145, 0.01567747076478554, 0.03657060697150882, 0.01768988026014995, 0.03361412811500486, 0.03870044463837985, 0.09703278818051331, 0.08049987533013336, 0.08817319991067052, 0.05471992859384045, 0.04824023351829965, 0.04748440805997234, 0.03012505254446296, 0.0269140114687616, 0.0025890914048432023, 0.07136215237551369, 0.03002631536219269, 0.050001253475784324, 0.04606500981026329, 0.006673664647678379, 0.05033008797909133, 0.09827561094425619, 0.028722745955747087, 0.028552846088132355, 0.018141829641535878, 0.049749958561733365, 0.03782516309001949, 0.09804841727600433, 0.03403815419005696, 0.06023840884154197, 0.05060439318185672, 0.08332385114044882, 0.056034528170130216, 0.028322409234533552, 0.07239038313855417, 0.08053728699451312, 0.017498172383056954, 0.05185108624573331, 0.01951662481587846, 0.06463303259806708, 0.03635237102571409, 0.012526487989816815, 0.06072078256693203, 0.04040086452732794, 0.06879877430037595, 0.03794946169364266, 0.04927469461108558, 0.0435001400182955, 0.04139376163948327, 0.0316336884861812, 0.04117496537219267, 0.042688850153354, 0.06318757383269258, 0.04043078050017357, 0.08047306153457612, 0.05900862561247777, 0.020504222993622534, 0.007080105533532333, 0.010229929630440893, 0.01618242618860677, 0.10559630405623466, 0.0569629215169698, 0.01917530182254268, 0.027784311350842472, 0.05886763610760681, 0.07632309789187275, 0.027611110781435855, 0.021567770709225442, 0.01817776072130073, 0.022512225987156853, 0.08524814358679578, 0.023487996186304372, 0.03707830277562607, 0.016121369699249044, 0.04489006387302652, 0.03938640802516602, 0.012196492953080451, 0.050257839902769774, 0.05492097268870566, 0.06570700934389606, 0.017151121865026653, 0.02063007454125909, 0.07082465934217907, 0.00950438379732077, 0.039935734603204764, 0.08293892882647924, 0.01815859661292052, 0.025620837695896626, 0.07171358898631297, 0.04874622609349899, 0.07202465276350267, 0.030015938282303978, 0.03971432597609237, 0.014940359487809474, 0.0013670898260897957, 0.022969422352616675, 0.030005696644366253, 0.05936136469244957, 0.05089978651085403, 0.03096785585512407, 0.04237311084580142, 0.043320265685906634, 0.02914637869253056, 0.021515202533919364, 0.04728765728941653, 0.04152028668613639, 0.043323549689375795, 0.040256208812934346, 0.024401583686994854, 0.004890307436653529, 0.03244983199692797, 0.05709293836844154, 0.047975943598430604, 0.007926096368464641, 0.03251408343203366, 0.011046052732126554, 0.024844751605996862, 0.00961984156674589, 0.06360466082696803, 0.010394462842668872, 0.05207364149100613, 0.02941411959909601, 0.03703271635458805, 0.04783876873261761, 0.02477460937370779, 0.05766661110101268, 0.06502547286800109, 0.025628194234741386, 0.02085323092614999, 0.04983697166608181, 0.021908351554884575, 0.0340856405091472, 0.024218519974965602, 0.025386743909621146, 0.049600601341808215, 0.050018274632748216, 0.02861965051124571, 0.004097201581316767, 0.07223894790513441, 0.028115986424381845, 0.03318028713692911, 0.01834599817811977, 0.03432585515838582, 0.022890743566676974, 0.03921259703929536, 0.06541432114318013, 0.016346728407370392, 0.016484944135299884, 0.03508761408738792, 0.056120929002645425, 0.0656810193322599, 0.06108258698077407, 0.03998213367594872, 0.0349501349410275, 0.018001463540713303, 0.0033671490564302076, 0.07476844693883322, 0.027651628333842382, 0.01092951142709353, 0.02966100801131688, 0.03524049279803876, 0.0564907597436104, 0.08920536405639723, 0.061605314986081794, 0.013452666025841609, 0.054468154994538054, 0.0635100518411491, 0.04707897278422024, 0.06992057504248805, 0.03993675876699854, 0.052154543009237386, 0.027793586341431364, 0.042066852474818006, 0.06575104838702828, 0.011062614685215522, 0.012916770465380978, 0.048756868491182104, 0.042983375169569626, 0.035267102502984926, 0.023637106642127037, 0.051944582010037266, 0.04123866019654088, 0.029513105400837958, 0.03479241371678654, 0.0439903619553661, 0.02547464202507399, 0.06178519302920904, 0.02177297825255664, 0.05699866705981549, 0.01507337090515648, 0.056316462651011534, 0.051994409805047326, 0.05456387349113356, 0.0376145527116023, 0.026975939981639385, 0.0036419640218809946, 0.07127139513613656, 0.014194154118740698, 0.043575234230956994, 0.024759836924204137, 0.0617587540182285, 0.043606519466266036, 0.046595712192356586, 0.10617829626426101, 0.10115528493770398, 0.055173492146423087, 0.0073078043260466075, 0.05878879404917825, 0.0189721481729066, 0.04135753741138615, 0.0816759344888851, 0.13380824646446854, 0.03041038606170332, 0.0448665192379849, 0.08247942809248343, 0.09065877864486538, 0.08737027776078321, 0.044706493645207956, 0.0552733258518856, 0.028388280406943522, 0.03908750804839656, 0.01862140361481579, 0.06407823268091306, 0.041631093044998124, 0.05418473621830344, 0.012385543013806455, 0.041318162766401656, 0.026679771108319983, 0.03707736024807673, 0.09101997449761257, 0.0851172732654959, 0.04232884544762783, 0.02631792402098654, 0.029819057635904755, 0.03003480553161353, 0.04803485528100282, 0.06446917381254025, 0.028078251925762743, 0.05518571531865746, 0.0592102634254843, 0.0929003614874091, 0.017494699131930247, 0.015125585632631555, 0.02647904428158654, 0.01992992500163382, 0.04489511047722772, 0.06816530672949739, 0.03957367785915267, 0.05312696797773242, 0.03759881547011901, 0.04168435698375106, 0.05115110368933529, 0.06417060038074851, 0.019749408711504657, 0.05872134024684783, 0.04972386464942247, 0.045903173377155326, 0.10696495053707622, 0.22418371023377404, 0.1617506259935908, 0.15598409401718527, 0.19764863565796986, 0.07481868291506544, 0.10398576196166687, 0.1769714811234735, 0.15294056123821065, 0.1159251295030117, 0.17258130654226989, 0.14197666518157348, 0.13984327262733132, 0.12433593365130946, 0.10465727202245034, 0.1085501111811027, 0.12374901358271018, 0.1596694064210169, 0.08866668358677998, 0.1797260661260225, 0.17849513998953626, 0.12911865982459858, 0.12529029103461653, 0.19714822032256052, 0.14611456892453134, 0.13862313731806353, 0.1611983493785374, 0.13703952776268125, 0.10326048330171034, 0.11133444888400845, 0.10842865129234269, 0.13672116125235334, 0.16280690993880853, 0.0930352319846861, 0.1208673209475819, 0.1606697027455084, 0.21104404499055818, 0.11195196027983911, 0.16840835858602077, 0.12011410042759962, 0.21394523384515196, 0.16487681918079033, 0.08305089664645493, 0.10628745876601897, 0.15693628432927653, 0.22348992089973763, 0.11229902564082295, 0.07263574458193034, 0.1940219380776398, 0.13199063774663955, 0.0847735846764408, 0.17723777855280787, 0.13152842817362398, 0.1797764134244062, 0.22311228647595271, 0.12734655960230157, 0.07819010395905934, 0.15617197612300515, 0.10499085998162627, 0.1580043090507388, 0.17430552339646965, 0.13924722414230928, 0.1529825371108018, 0.1629258316825144, 0.13068148924503475, 0.13903632061555982, 0.11159109097206965, 0.17568440409377217, 0.11646477476460859, 0.13560568360844627, 0.1301317210891284, 0.14831243926892057, 0.22893888788530603, 0.11829079943709075, 0.10811606611241587, 0.1472309371456504, 0.15825647598830983, 0.13402940647210926, 0.07651874286239035, 0.09685611992608756, 0.10792692977702245, 0.28870313486550003, 0.25912412675097585, 0.16959748696535826, 0.11241052590776235, 0.1404426310909912, 0.2195317653240636, 0.10314795887097716, 0.13729463360505179, 0.2588807023130357, 0.13559472950873896, 0.12977169040823355, 0.21812952181790024, 0.15806313167558983, 0.1289185174391605, 0.09935156180290505, 0.31373654783237725, 0.08498334529576823, 0.07888033840572461, 0.1887526153586805, 0.18072216189466417, 0.1865851879119873, 0.1715546046034433, 0.21227096352959052, 0.1388258030056022, 0.15520253829890862, 0.16076851228717715, 0.14971285709179938, 0.12230213731527328, 0.07963407100760378, 0.12110847441363148, 0.1326075554243289, 0.19368846144061536, 0.1199811595142819, 0.1484180023544468, 0.17806600051699206, 0.192350666038692, 0.09493805409874767, 0.08388096655835398, 0.1337853734730743, 0.13525674061384052, 0.12550333194667473, 0.22962320741498843, 0.1377493326435797, 0.13560146820964292, 0.1089166579185985, 0.15949700551573187, 0.128966296906583, 0.14068374002818018, 0.2414291145396419, 0.21282093948684633, 0.11928348874789663, 0.19190846476703882, 0.15731329534901306, 0.2618933765916154, 0.21706572733819485, 0.11896687370608561, 0.10625954659190029, 0.10559597008978017, 0.11034390437998809, 0.16725841560401022, 0.17699088086374104, 0.11823246662970632, 0.13895931537263095, 0.09198527113767341, 0.11313571550999768, 0.15173375490121543, 0.160831312823575, 0.18118686508387327, 0.19790307356743142, 0.1278105058008805, 0.14001905772602186, 0.15225210052449256, 0.06123116494563874, 0.10740773810539395, 0.2398436050862074, 0.12214956659590825, 0.21719321346608922, 0.09865631043794565, 0.17325344000710174, 0.16502498154295608, 0.10151285168831237, 0.2017112707835622, 0.06793726701289415, 0.10400947357993573, 0.14366537769092247, 0.085957510600565, 0.12213501307996921, 0.10421570899779908, 0.1690283784409985, 0.17015443911077455, 0.12104450128390454, 0.10721364422352053, 0.1127644041844178, 0.16893014777451754, 0.13032822695095092, 0.20909805956762284]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.031730549890198745, 0.011200456556252902, 0.0445271054195473, 0.036193425257806666, 0.08772670902544633, 0.04792624567926396, 0.034655409544939175, 0.048833435866981745, 0.0509986999531975, 0.014181626665958902, 0.028679801580437925, 0.003966979711549357, 0.051841735185007565, 0.014656733837909997, 0.03968363816966303, 0.10372677468694746, 0.019822458307316992, 0.06465130427386612, 0.041665439639473334, 0.04385809268569574, 0.05551288370043039, 0.02259075077745365, 0.05919588431424927, 0.04568374999507796, 0.04933973272272851, 0.03780836457735859, 0.04216202549287118, 0.029173981019994244, 0.012561858748085797, 0.055433874658774585, 0.014914414005033905, 0.07926678954390809, 0.013548792703659274, 0.05246927299594972, 0.03549509769072756, 0.029134354044799693, 0.04388413093693089, 0.0366582991409814, 0.04898612904071342, 0.023650224102311768, 0.08407676737988368, 0.03261699705035426, 0.04000412351160776, 0.07920647520222701, 0.016177797042473685, 0.10718914592871442, 0.09966031007934362, 0.05408040880865883, 0.027241673378739506, 0.07126570286345668, 0.051677679730346426, 0.03970161669712979, 0.03769186223507859, 0.03812835639109835, 0.08503909542923793, 0.0033437066986152786, 0.020083187773707323, 0.043860326550202444, 0.06020052591338754, 0.012211325702082831, 0.04166003309364896, 0.019359532561793458, 0.07776530605042353, 0.037859279618714936, 0.05519506266864482, 0.02600686395453522, 0.03954923893616069, 0.031214156115311198, 0.10566474491497502, 0.04192630454781465, 0.030361517492565326, 0.017751252162270248, 0.07206039459560998, 0.03997519830591045, 0.12596465094247833, 0.026278603181708604, 0.036601569372578524, 0.007395481188723352, 0.03892220207490027, 0.05159847773029469, 0.015599192738591228, 0.019693278227350675, 0.015537141771346796, 0.016920126545301173, 0.03932911793526728, 0.023031094824546017, 0.04407312626426574, 0.021163791898288764, 0.00905754688574234, 0.02950033489469206, 0.009379847706441069, 0.04898467814200558, 0.015426898517034715, 0.021664765699824784, 0.0318759217771003, 0.01184264343464747, 0.03175289966748096, 0.07442650981829502, 0.013294059790496249, 0.04986423075024504, 0.09586575353750959, 0.0496401986310957, 0.060197253042133525, 0.006249652024052921, 0.07093928405083716, 0.0683595787268132, 0.01661468268139288, 0.018415507729514502, 0.03960879628721159, 0.04471715830732137, 0.024386332552239764, 0.03283948179159779, 0.020324767974670976, 0.042438861419213936, 0.01663689145061653, 0.04859533262788318, 0.057375596443307586, 0.0365385424811393, 0.009388251601194497, 0.06102435436332598, 0.03791535258642398, 0.06081199251639191, 0.0415173180954298, 0.008203610432246933, 0.03837695730908308, 0.020876792259514332, 0.024914691603044048, 0.03782520019740332, 0.02948916928289691, 0.012322779584792443, 0.05730243181460537, 0.0395897379348753, 0.02908566915721167, 0.034789998026099056, 0.0829367023834493, 0.04737683746498078, 0.03508931360556744, 0.009089741251955274, 0.044276920016272925, 0.02157699374947697, 0.03655378248367924, 0.047014643423608504, 0.039049257757142186, 0.030018979232409038, 0.012150219117756933, 0.038407589454436675, 0.04287410876713693, 0.02503290645108791, 0.08203842167858966, 0.019091257308900822, 0.054430045711342245, 0.05091983934107702, 0.06648055728874169, 0.03302150093077216, 0.05466349197376985, 0.013529352145269513, 0.042748774867504835, 0.011650025498965988, 0.0516452849842608, 0.012742137550958432, 0.055760085670044646, 0.05161813722224906, 0.08024875482078642, 0.03751479693164583, 0.01712120218144264, 0.039450217882404104, 0.09034372211317532, 0.03248455708671827, 0.026893142276094295, 0.04812409111764282, 0.01749843399011297, 0.05831549678987358, 0.030921787038096227, 0.028228596202097833, 0.03045117078727344, 0.025618728141125757, 0.090490838047117, 0.005099933077872265, 0.06899625979713164, 0.023944288986967877, 0.02750949963228777, 0.002546474502196361, 0.028456246291170828, 0.08766174141783267, 0.020963024253433105, 0.06817513276473619, 0.047860142585705034, 0.0048879919359023916, 0.05853125767316669, 0.030017908684385475, 0.06309407064691186, 0.015756496504764073, 0.059078710328321904, 0.028378818024066277, 0.03460891399299726, 0.04161313678196166, 0.06809115133364685, 0.07741316439933144, 0.06490599451353773, 0.032230527358478867, 0.028271124974708073, 0.032038674762588926, 0.019051947601838037, 0.017785630298021715, 0.025965066197386477, 0.03651986633485649, 0.028821778141718823, 0.05501283201738261, 0.04728489278932102, 0.02719334286666708, 0.07058707560645416, 0.03955230029532686, 0.020626013138098642, 0.04119662495213561, 0.1327973819570616, 0.012846602257923223, 0.051627299035317264, 0.048687566741136834, 0.03011312994203763, 0.05048055470979307, 0.03800888545811176, 0.049837275946629234, 0.03037001322809374, 0.036426474471227266, 0.02745617261098232, 0.07083995500579476, 0.05478731189214159, 0.08829217360471375, 0.027756382478401065, 0.05874499991477933, 0.05959729343885556, 0.014536137623508694, 0.042368320282548666, 0.059112622766406275, 0.022740018939657602, 0.023319652973441407, 0.08115577802527696, 0.036089958739466965, 0.002676781718946586, 0.015765424541314133, 0.07512370561016724, 0.043691513928934, 0.07415028245304711, 0.04657699893868994, 0.050515665716375224, 0.016804438710096292, 0.03887451166519895, 0.03063920132262865, 0.04227252386044711, 0.002221723898401251, 0.045913786088931374, 0.04173336841631681, 0.030477281397907063, 0.038851416029501706, 0.03385258016351145, 0.054598175556748174, 0.01789363319403492, 0.0320836971513927, 0.030471442551061045, 0.05616550239210483, 0.05439902393845841, 0.040160096978070214, 0.09461533118155785, 0.06286690666456707, 0.028054421563865617, 0.024925269062805455, 0.04440534125023987, 0.017980039592657704, 0.033158364094560966, 0.0473748856165912, 0.03988091215433087, 0.018973105543409474, 0.041252876035287045, 0.054490994589286856, 0.08099226804915816, 0.013597190009022597, 0.06723348837113008, 0.021698284799640533, 0.07519804654293694, 0.0663327808433678, 0.028442739203455858, 0.04376088618300855, 0.02583135530585423, 0.022151479133754037, 0.02429923966701608, 0.02342733489058446, 0.0066015534048347035, 0.02379492434556596, 0.028463587987062056, 0.06623335531912744, 0.0771705192164518, 0.046304730931296945, 0.03822494691121392, 0.05569247601670213, 0.025742997058841866, 0.09507515846053138, 0.04154271438892465, 0.02790997921692906, 0.10020477187936194, 0.02887266720790649, 0.012935844588355394, 0.021412600617622957, 0.07658043017727323, 0.03559343225788325, 0.035568306848290376, 0.05098587193060666, 0.030365085367520805, 0.06331396900350228, 0.015097381237865193, 0.041011128851096146, 0.08067730799666606, 0.05780201965535525, 0.04345614921476226, 0.043738284075516276, 0.038388779721572064, 0.03802786217420362, 0.01609255952644162, 0.05132208709255792, 0.016116675615194254, 0.008256750061264029, 0.06644733875873499, 0.04341531624959316, 0.024262219485535752, 0.045772544253850356, 0.11541447252966464, 0.06744773898390122, 0.07341235017520376, 0.038200853086891584, 0.05275353782053571, 0.014832447504886659, 0.04388138870126568, 0.03525189960782882, 0.085416915389942, 0.057611250595073216, 0.036935057141818106, 0.02060979721136391, 0.025790169820538722, 0.0175441521423636, 0.012754785602737684, 0.02094509211019613, 0.03829178473097272, 0.034020799066638574, 0.0594655102759134, 0.033829543899628334, 0.04428618573001586, 0.038312524047796614, 0.01957715994649334, 0.034369823697488755, 0.0353461412305478, 0.031521587079623714, 0.015533224159298697, 0.02558105672505917, 0.2283029118552804, 0.07661073206691071, 0.13023185165366158, 0.0855286605656147, 0.1566311132046394, 0.1312213868368417, 0.13865053741028532, 0.22277742944424972, 0.12001828174106777, 0.16070450947154313, 0.1610160036943853, 0.21420514880446717, 0.13797092309687287, 0.14224072132492438, 0.1738056424073875, 0.17090896581066772, 0.12236137554282323, 0.11954988265642896, 0.19907713634893298, 0.18039517162833363, 0.2093511912971735, 0.2666909754043445, 0.12131573399528861, 0.10029492055764422, 0.11552636613487266, 0.11168389653903432, 0.09133686413406394, 0.1929505736916326, 0.09811498050112277, 0.163568323769141, 0.15779695298988372, 0.20265458500944078, 0.12202203593915328, 0.0908624981821049, 0.21422420715680346, 0.1511062096687965, 0.1441120615345426, 0.16231946734478697, 0.1444057738990523, 0.09545585795422085, 0.12181755198980682, 0.1603485457599163, 0.18009713996434584, 0.16010207851650193, 0.17454112559789792, 0.17043075553374365, 0.18091998877935112, 0.17021146573824808, 0.066433037573006, 0.14457425626460463, 0.15825895476154983, 0.22033908840967342, 0.13857546175131574, 0.15348310087574646, 0.14047256932826713, 0.05997647524054628, 0.12474041897803545, 0.1453235582448542, 0.1382512619602494, 0.1268168888054788, 0.13476184685714543, 0.1517161214724183, 0.1419309785705991, 0.14604756783228368, 0.07677811605390161, 0.08622735549579374, 0.1425069000106305, 0.12473690119804814, 0.13904331164667383, 0.13385143945924938, 0.14880997507134452, 0.27244526194408536, 0.20933002524543554, 0.1543267149827443, 0.2879105805186555, 0.14609414502047002, 0.09435192070668563, 0.10471140427398495, 0.1610271804383956, 0.1380886574042961, 0.13520424108719453, 0.15265997004462406, 0.08337912629940547, 0.18328595557250082, 0.12864375952631235, 0.15750058373669162, 0.2048505109269172, 0.164882296230644, 0.10865283184102736, 0.08739479832001962, 0.09165241048322059, 0.22160905151395127, 0.15273710887413472, 0.2396783881704323, 0.15710911568021402, 0.08590395722421817, 0.15046753222122788, 0.21585455717286095, 0.17619043006561697, 0.10748705142759718, 0.19721897668205202, 0.13342750986339524, 0.21463391720317304, 0.20333998807473108, 0.131894618680235, 0.07903659759904258, 0.13268355134641752, 0.10917773804976605, 0.2012937088147737, 0.10345119299017824, 0.11291911228909157, 0.10629359632730484, 0.06922547210706398, 0.16233963891863823, 0.11489272787002847, 0.09193672725814395, 0.10850321486941539, 0.13153837295249104, 0.1039301602577325, 0.18284390273038298, 0.07736059807939455, 0.1930248478311114, 0.18856740498449653, 0.0925807333260309, 0.13220722612459213, 0.19217744877096266, 0.19274437538115308, 0.15641008678358048, 0.14247546263504773, 0.10886735704843886, 0.18882579111959785, 0.1304786157561466, 0.14841126365354285, 0.1395766338100657, 0.19672188616823405, 0.1221617081318982, 0.19447819562628865, 0.10533221822697669, 0.22462871682364494, 0.18059148453176022, 0.10294085514033213, 0.18117294239345938, 0.19394849514355883, 0.1442937838146463, 0.134616756986361, 0.12250545609276742, 0.08812360218144022, 0.19745279772905633, 0.1877056824741885, 0.13700161885935813, 0.18291796906851232, 0.14170573675073683, 0.12796467955922708, 0.12862581439549103, 0.24537091318052262, 0.15640033496310934, 0.21433641988551244, 0.1280194500577636, 0.18655253341421485, 0.12888065306469798, 0.10782315526739694, 0.1392319952719845, 0.13334789226064458, 0.09036059855134226, 0.10994431722792797, 0.09184838199871592, 0.14016990666277707, 0.10834746775799431, 0.10185288148932159, 0.10788063460495323, 0.07040683762170374, 0.17733737477101386, 0.12152484152466059, 0.12823367840610445, 0.06705941021209583, 0.188500463264063], [0.05234693737293128, 0.05573227739660069, 0.024625005389680155, 0.03873215289786458, 0.02317105831025401, 0.049089933236246, 0.007870413955970434, 0.028510647571238223, 0.06160860270028934, 0.059896750026382506, 0.05839996061695274, 0.03273863505455665, 0.053788997101946734, 0.061865723473601975, 0.030780127744947094, 0.023729771201033145, 0.06711013600579463, 0.0313764712336706, 0.06670034432318062, 0.03574700116587337, 0.004860205926888739, 0.027731993650377262, 0.08100380102405325, 0.016261362870864104, 0.11214314494282007, 0.02701732584682759, 0.030048056578380056, 0.0530464338226011, 0.039167789873317815, 0.01587685059348587, 0.03444460249738768, 0.028789980824512895, 0.04871741963142995, 0.06780716852517799, 0.02670308753295103, 0.03831978225207422, 0.03090728361712536, 0.008719601592019899, 0.012631306144612608, 0.054787297049188055, 0.04401063000841532, 0.021571952711383346, 0.025887430128932465, 0.01595009129232494, 0.027803341872640885, 0.07332817578571849, 0.10633631434757262, 0.03898757044225931, 0.028136478977103252, 0.01923268097016262, 0.028689145219686907, 0.01306340956944041, 0.06585739814909175, 0.04196977584797423, 0.019751601757889148, 0.07214945973828435, 0.008092498865153175, 0.05843055194418412, 0.02217830220615724, 0.09340823540696874, 0.028579366735357326, 0.01786272830941016, 0.01927254914335208, 0.025720025732880458, 0.016997727361740544, 0.04956859251251444, 0.03043936321773799, 0.07516280937124975, 0.04237364890286699, 0.032155039807548746, 0.07673101936234161, 0.04425831066328101, 0.04204438395390753, 0.010639175834512571, 0.0346890882065054, 0.023432398193108384, 0.04491039129788987, 0.04863779460720252, 0.012915054248878732, 0.024670922066434287, 0.031232832261594012, 0.014908018547430402, 0.0467340114118997, 0.035534223716240376, 0.026788850118464325, 0.02111342048010556, 0.026055916205223184, 0.07056749032926746, 0.06287435040576383, 0.017863312750705518, 0.02445348392939195, 0.02082062652334571, 0.04487531368795317, 0.006640898363912129, 0.033630889520281926, 0.07509124407079071, 0.020384221425047144, 0.03335586443427019, 0.030965668374847155, 0.041134421844617464, 0.02112619284162065, 0.06377003359375522, 0.05390669059124775, 0.04897252547380049, 0.03517113909765612, 0.011614967370405793, 0.03140926673950162, 0.018230564528494142, 0.04510239603405353, 0.04338347069278825, 0.007279056308107101, 0.038992772897472605, 0.045293510193005204, 0.011493664260342484, 0.05086630451842211, 0.017048451300070155, 0.010103708864335204, 0.021997346193529665, 0.0290451163527905, 0.04606999704265036, 0.0584875229105819, 0.00960563500484568, 0.015422097749251407, 0.053049728958285414, 0.05827651548315771, 0.013531700114981504, 0.04094800919119734, 0.07251229573739693, 0.01691118552116677, 0.02144587295333622, 0.045945917372591794, 0.01045197093844763, 0.06176219758344814, 0.024308423744514585, 0.0543251950875856, 0.06818647278123535, 0.04367373578133993, 0.020949678582837805, 0.021408745160442777, 0.03127988071355503, 0.04479845687455963, 0.05458665000332985, 0.012346219391474733, 0.030041501559026074, 0.030189829049049877, 0.011304126237519085, 0.04132489404582884, 0.035690234290086664, 0.03165990114212036, 0.009682883301138645, 0.05212560667132493, 0.013653024561790517, 0.06682060935418122, 0.0390834039717447, 0.04251630452927202, 0.03654378204373643, 0.06673149968264624, 0.014999528139014728, 0.042577717249514535, 0.06587185518583283, 0.02476687433954794, 0.033429971590521745, 0.05299114382069092, 0.04935866490995977, 0.007537775945820613, 0.04770471088704653, 0.05797848010843154, 0.04688539098424371, 0.03931233055482153, 0.04595162819896359, 0.03287193219875917, 0.009000660338642774, 0.020108057142351754, 0.05160987711860798, 0.08853743114741519, 0.07330854597967118, 0.017064633830159437, 0.06760019838111475, 0.05500329913047608, 0.03845148006803356, 0.060437348947743885, 0.031178636927506886, 0.0768998208513949, 0.024839105717546772, 0.023028406394587364, 0.03113347353064455, 0.050786564461304806, 0.026273808907717466, 0.011398018123145448, 0.06760882213711739, 0.0451971052098088, 0.03160359810863156, 0.062154923580237664, 0.04962343351508025, 0.0715103444235865, 0.07275036186911166, 0.022790351395087782, 0.0416036113165319, 0.018371149562881328, 0.061187322571640834, 0.07644187120604329, 0.008818489986879285, 0.09121491442783736, 0.01724828569422243, 0.053446766833076254, 0.006976953500270611, 0.014385873128048843, 0.021111750647833105, 0.02590401712950552, 0.0008587219724631723, 0.046273779662442394, 0.02333875028853072, 0.06511499072075821, 0.025593858772481326, 0.015712583626736887, 0.0053345672404248035, 0.06798305752454326, 0.03761129097256344, 0.032173111103475094, 0.012639289798244135, 0.06882866800879128, 0.06357917547575198, 0.03088489487709012, 0.032992987617035396, 0.01579628118633991, 0.009650907868490322, 0.03492715804895852, 0.01777116398443468, 0.024090416009130422, 0.011358135107002454, 0.045762926019961014, 0.14958399056922644, 0.020979251312382985, 0.03825458828941919, 0.023070916613505688, 0.10887261887546629, 0.009338184463558719, 0.020958179884473793, 0.06668479632935487, 0.06858278706204146, 0.051334840900381096, 0.028726931668643374, 0.042354423567303456, 0.040066812725854106, 0.03748438000911847, 0.025104660999204498, 0.04082984814886004, 0.03759762432309799, 0.04390099995362107, 0.019719515003089327, 0.04529083103989251, 0.06705828956910409, 0.04637238511350006, 0.022062334210204426, 0.010693597523641074, 0.06650285882642493, 0.036736202382599004, 0.012828090311813867, 0.049497917789267376, 0.03116319283435587, 0.02017712697124807, 0.011889901543327142, 0.05283912971208338, 0.042345721885794774, 0.04467006532649975, 0.0409948275773786, 0.020938201269018464, 0.09826515408349223, 0.02190536255511688, 0.07566740299807861, 0.024209664297814015, 0.036566213457263075, 0.004921494337395416, 0.003396719234842749, 0.0231646424435894, 0.057413360627833754, 0.024061121584963985, 0.049600913043832406, 0.020457187529245857, 0.07136880201869644, 0.018575232752482407, 0.010624111164361238, 0.028367923296173103, 0.0618293990555685, 0.044671364084933884, 0.05187147675314918, 0.037922774063190445, 0.009614849695935845, 0.011483982016216032, 0.024670736529515125, 0.051127358674420975, 0.05635944413370453, 0.06966802960960194, 0.03200913357432, 0.05422649686806835, 0.03202474465069827, 0.03933950800274033, 0.010911766676144907, 0.07468770127161406, 0.038354240168700926, 0.05319778741977643, 0.04546946598566137, 0.040435378105030395, 0.03906650155840907, 0.03410013465327211, 0.07394608051981777, 0.053027650064905174, 0.014822302346146898, 0.016181448409042787, 0.04602386514307, 0.05174263991648331, 0.022431233555835206, 0.051036170989391394, 0.04368409616290592, 0.017705263126117643, 0.04790743223566096, 0.03304144243884366, 0.03627472011430655, 0.04878904059296474, 0.012811478263756726, 0.04144748942053411, 0.03771399307879619, 0.0104427042970201, 0.04290121200028807, 0.02966348492918769, 0.038341972467605956, 0.0672351878893096, 0.026297377662558574, 0.04933479744067881, 0.0439450130215846, 0.060706559306709096, 0.06051027979992796, 0.03955399239202961, 0.06031079792592209, 0.05624002886179369, 0.06301036381046288, 0.04429374821484089, 0.02581513752375031, 0.03702530601003673, 0.05702902461052872, 0.05289990047458559, 0.03827082648058422, 0.05857288102561142, 0.04213177184283268, 0.029478506476152688, 0.04516247288847808, 0.08529031241778284, 0.05633057458908297, 0.01898052516480675, 0.07502476990339346, 0.07065083351335488, 0.020550276967696846, 0.13866640452761203, 0.3009148483397439, 0.1323609842802398, 0.1580489269690588, 0.10895651124883443, 0.10104290151502937, 0.21985845873132348, 0.1232376960979309, 0.140091001521796, 0.13784759299596772, 0.1370697034872137, 0.1233068791043479, 0.07615604044985957, 0.12446678912965581, 0.1440916524734348, 0.06711961323162541, 0.14927089330740273, 0.10996344979503192, 0.13772154663456604, 0.1864428143016994, 0.07550567417638376, 0.07667249359656125, 0.20903191936668009, 0.20256597257684916, 0.2739619149360806, 0.10705860215239227, 0.19572236167732626, 0.14693136181449518, 0.13919159275246784, 0.10453069873619825, 0.17370102927088737, 0.14529287785990164, 0.18568748608231544, 0.13441434362903237, 0.1368983119027689, 0.14004213851876557, 0.10559971051407047, 0.11594414332648739, 0.12137366604292765, 0.11177862426848151, 0.1587388719781302, 0.09867232598480769, 0.1135303896444384, 0.03610073101299349, 0.11453594779595733, 0.19930893875425681, 0.19101784302620217, 0.07198413150035776, 0.10932290955679491, 0.09825043729506433, 0.12417353689670563, 0.05456904254970141, 0.11087921549915336, 0.10774229085654952, 0.13402688317000866, 0.22247001703362912, 0.14035767002496868, 0.09718363711726852, 0.09647107886848971, 0.1845231602783315, 0.1619387901155278, 0.0906804196711164, 0.19685879757162184, 0.14694832731038332, 0.21245252253720537, 0.11009189329342917, 0.1846626988844946, 0.19221295311581343, 0.0677546912629623, 0.12311570186284371, 0.155307715467643, 0.1454290174297057, 0.17546717746881768, 0.0739695101219695, 0.09981965660699643, 0.1109485914639663, 0.07025509068625979, 0.0858115301525686, 0.07871754831285216, 0.2098776411730796, 0.17447700403863564, 0.11236177422688343, 0.14077402971452102, 0.09777392653631978, 0.13151962630217895, 0.0637791991175618, 0.1154455982032232, 0.225491804885678, 0.20394612976815552, 0.1610726592480205, 0.11524711080710404, 0.17566795810125768, 0.14579792419681326, 0.1692235781229101, 0.1545635046204552, 0.2933152858167887, 0.1197405626589898, 0.10437274002470076, 0.14115589438006282, 0.17170952050946653, 0.08130117217660882, 0.18433708901284263, 0.18171079165767878, 0.17396882583852857, 0.08199565912946127, 0.09537080783047713, 0.1620231129345484, 0.14739602047484368, 0.1796996159828268, 0.13968319137347862, 0.17003474553348497, 0.08651086332974955, 0.11742163318558596, 0.1491640685708262, 0.18524761515436694, 0.12881512142485008, 0.14765920088393614, 0.12191204965347424, 0.19506918266415596, 0.070235126913758, 0.10758623946458101, 0.07467234623618424, 0.13184772979002446, 0.13875054923119023, 0.12190284702228382, 0.14452981646172702, 0.19857520703226328, 0.18725166621152312, 0.11193015598109923, 0.13823653775034472, 0.15483637747820467, 0.0793716030602809, 0.156507441715803, 0.07078798982547596, 0.2002445494872518, 0.1572371955262497, 0.10251391984638758, 0.1756459756870754, 0.09009129542391747, 0.1414194903918542, 0.1943206525174901, 0.09820676932577044, 0.12737566663417965, 0.12381226682919078, 0.09079373077838682, 0.14701350271934643, 0.0987439209711738, 0.09392068095621653, 0.13635975017677993, 0.14722465857630596, 0.13530474272556603, 0.16356222331523895, 0.17665342631516978, 0.18020923394942656, 0.09160540284938179, 0.13946177903562784, 0.17658526747254655, 0.1444431781419553, 0.22968338074861094, 0.21535822364967316, 0.14109163923421875, 0.20363304734928533, 0.20561882673064247, 0.1298133545788005, 0.12048548596794717, 0.20000737393274903, 0.1037326970254071, 0.11830332688987255, 0.09564064530422911, 0.15291687188437209, 0.2610308228759095, 0.12409176706569269, 0.12275204207981005, 0.1057969882094767, 0.21896148420637473, 0.19234285864513367], [0.014593629948649323, 0.05432772210042458, 0.04775224173499737, 0.018778147059492767, 0.003965963896916946, 0.05516007040569093, 0.025358481070725247, 0.040254795021610335, 0.07394527157885022, 0.04923236250760965, 0.015027739955257857, 0.04991798450646456, 0.04249015124514699, 0.031256785077857785, 0.02870112904929556, 0.0358215573214693, 0.015367364358098712, 0.003868415310535056, 0.03264889455749653, 0.04085209031472914, 0.03345719356730115, 0.016140719344548415, 0.03665174597699661, 0.04565039787848946, 0.04266285272024106, 0.0159724317927612, 0.022106697942945175, 0.052351924605318345, 0.04257119377143681, 0.030236198435886763, 0.012601037651620572, 0.06968958899960853, 0.028082389399060048, 0.06755536523996852, 0.033916037500603124, 0.020256787247490138, 0.03822926992143039, 0.0972288339107763, 0.008151814090524567, 0.04168541825492866, 0.009064610276254825, 0.11328956272336654, 0.027351904573151842, 0.03845408129564021, 0.02940164224128239, 0.04999706034141127, 0.007016682520770701, 0.018420667511236388, 0.03641190240159631, 0.03790028327784967, 0.06140907629742287, 0.030307017877930775, 0.03470399424259085, 0.055010223368299194, 0.011091260657849489, 0.0009651607922478433, 0.008556891280022683, 0.04327459020714741, 0.09867971035419032, 0.06687696804874577, 0.06315874881693162, 0.04866418537858408, 0.034520064073149115, 0.06760054719052278, 0.03396627347683534, 0.07180108819738962, 0.022072740976000205, 0.036063174629816785, 0.01552485551655991, 0.04275182509445585, 0.03179413339239545, 0.04517895227763802, 0.03238917997805402, 0.016580757255724166, 0.058204352753818966, 0.046259010923677124, 0.052038292997167446, 0.07980096517712809, 0.054941404014243744, 0.06583124486496672, 0.044762173274648376, 0.014698572413180955, 0.014930696725059533, 0.022494783661386464, 0.025057443708647043, 0.03981594454671722, 0.047706584809930064, 0.005655087370541878, 0.01485111344663892, 0.05680446556652896, 0.02839595606928924, 0.04459615855012089, 0.03532743168761954, 0.011773360238294117, 0.019156980051775463, 0.03774851036723703, 0.01786110115062911, 0.027224952791584656, 0.03609062667237595, 0.034032150215352885, 0.009519664617982926, 0.05194947647396475, 0.06400061887688935, 0.035717237333301455, 0.010854742831725162, 0.036735835019499063, 0.07697152715991251, 0.0385484973230632, 0.0353331944643287, 0.026025508559541777, 0.028487802410381846, 0.05030618340242654, 0.07158791369874962, 0.07759513900964521, 0.033988382056122646, 0.014114298101048917, 0.04432404639373999, 0.023768984428897966, 0.02026391557592433, 0.039772206073394045, 0.04944565203913953, 0.07382621624856256, 0.016714957964723, 0.03543226746842265, 0.021997164367348887, 0.024018110416363925, 0.046015601328690536, 0.031621209272998385, 0.019718995499715675, 0.025315145212516654, 0.018206274035037495, 0.03343588650750462, 0.011289826907159295, 0.03438640327658504, 0.014332563732750714, 0.02160453484975733, 0.06673081690678373, 0.02625283581437543, 0.0034183424031652976, 0.05964919924736023, 0.0511969795479672, 0.013953676007076865, 0.0462846447044285, 0.009516564296063734, 0.0700379531190265, 0.05986560579913203, 0.0007339838202824467, 0.035955496423412114, 0.035431514188530855, 0.04434261492860969, 0.006454958829635871, 0.02834861817973433, 0.027861865783052053, 0.03540860408975277, 0.044468772612162866, 0.04018666215415578, 0.06062366512196604, 0.041247929621022195, 0.018999153071490582, 0.029229298852442298, 0.03340840477903839, 0.029107044865668286, 0.052779201287194155, 0.02637420107930666, 0.0075078140525874915, 0.03635071974713355, 0.028550367314892355, 0.042812948377104476, 0.0413052939256886, 0.035365047442610376, 0.026338056632084772, 0.035795674921246246, 0.01074078605597606, 0.014823836736468365, 0.09812724078074098, 0.029133841962902807, 0.020944114330632146, 0.03702906869875733, 0.04216953231662046, 0.05238794474280439, 0.02788037309073843, 0.05546400585444644, 0.050586826546350494, 0.03622495169111062, 0.0452162266446976, 0.0776910170679912, 0.04592442106513772, 0.048774060342111625, 0.012234687583259074, 0.04329399736889172, 0.02324567383766407, 0.06332018077955581, 0.026757490668387618, 0.0995653003337793, 0.03780991566600278, 0.02590271094959462, 0.030176449981809128, 0.008792797761998372, 0.028703936222882476, 0.0684513601299841, 0.033312779050902463, 0.054802915547043085, 0.03432359531871043, 0.027686596476996783, 0.038283661924651824, 0.012966840386070544, 0.024559855955885723, 0.08098427511868067, 0.04167399660218507, 0.011178275617567124, 0.03200174920493737, 0.023980674632184673, 0.04710672168585006, 0.05034500143665355, 0.03526085361954756, 0.03259323348174803, 0.06403137347660959, 0.09586006126482971, 0.041110268648480996, 0.018041047842416447, 0.012316547399677802, 0.026688726975407917, 0.04403042679768987, 0.022270419431151822, 0.01699195159744704, 0.03389735022210516, 0.023701090904069133, 0.05592530629655812, 0.020628104139177594, 0.05126133117300924, 0.09580276746419258, 0.05808984307805076, 0.017980542397708632, 0.05162818590179086, 0.05305080136167817, 0.026653721724869683, 0.037257857984513976, 0.04347427988250274, 0.07654065848328173, 0.061975030694156885, 0.0516599795082584, 0.01473075100875576, 0.01142548129791976, 0.014029890862730099, 0.02776200981315924, 0.020025509911647532, 0.01676390260399785, 0.05750465963501483, 0.041054370085475966, 0.049963945712079294, 0.05653695472574327, 0.08423836261499673, 0.037422659297590144, 0.07484598652808927, 0.05435835053503979, 0.02095686813845532, 0.042992681701434776, 0.062900563061703, 0.05021454671805259, 0.07120248672435991, 0.04270809033187106, 0.036738339767907746, 0.0758576970838476, 0.07182755318353884, 0.010910846413025865, 0.047075087641132995, 0.029237226844998077, 0.03425805254664738, 0.03669033023470547, 0.04680171754444018, 0.008226457448472502, 0.022196909703779966, 0.07940177878481336, 0.02534853443648899, 0.05004996433854103, 0.060628017818089575, 0.03509474241582211, 0.022846090396342333, 0.040088650421239436, 0.0511338821524987, 0.046090684409136884, 0.039787145506124943, 0.10337121915654279, 0.005551748408834101, 0.029319234163267538, 0.050989326628041454, 0.03759549435926601, 0.04534816194791347, 0.01758351194439456, 0.0904027970682364, 0.020364446900202893, 0.024792793847154826, 0.020530528418021277, 0.029054471124254633, 0.03123076538031455, 0.03800988364673685, 0.03857508476357907, 0.09662471085903235, 0.012304996798775392, 0.07272526985616423, 0.07161057888879441, 0.02077098426525481, 0.011268617254245328, 0.04703674087068066, 0.020878172654192895, 0.0404618022730574, 0.028923699137521908, 0.014265462450566702, 0.055053349569789134, 0.01035381819747272, 0.05003089114325121, 0.040107170716510154, 0.0413587434013607, 0.01530659730633488, 0.032670494765625335, 0.042270969061064534, 0.02194225657149218, 0.07916018745163456, 0.03509092777676415, 0.04509553858952131, 0.029006381810177118, 0.02728980907704681, 0.01286182092371746, 0.04947806162817869, 0.04324135312344879, 0.0509367306221975, 0.017663344769971445, 0.10276761560817249, 0.04476535708818119, 0.03280125376477372, 0.034815999169950373, 0.02071764425636502, 0.03750246985873673, 0.058334725836175494, 0.05406897602370009, 0.021413014364952687, 0.03031867145182332, 0.03307757760921959, 0.038761423202231526, 0.06508245496661402, 0.047680936186225154, 0.0075430887955008075, 0.03315331749035977, 0.03088093551923521, 0.055169061524793506, 0.05720600085624028, 0.038216482716961764, 0.04970293979567941, 0.013308925936144078, 0.03739409403351601, 0.0505642058851663, 0.027921636501559988, 0.07316117771551944, 0.22084140364313498, 0.1091757342510391, 0.13088780629914254, 0.1355112824239768, 0.13221443980000913, 0.12329660778050311, 0.18832791392924264, 0.1619960690732114, 0.12731090682791546, 0.14736364799318835, 0.09700388152850792, 0.07903479418018833, 0.13901527330745012, 0.09032657108036801, 0.1463462971150875, 0.14340709545649588, 0.19241802336182445, 0.09325518971309066, 0.08931522417697124, 0.09725759955472313, 0.11051968947867863, 0.08507180929882452, 0.1719440837041475, 0.23080316284904256, 0.11780653323512524, 0.16640172485494986, 0.0885074632242322, 0.1407993517932482, 0.08433931696345098, 0.146638332225848, 0.16512212867382914, 0.16160805942490697, 0.20612560969311744, 0.16538315685465932, 0.16521930549060926, 0.20208563975756988, 0.10503368932404555, 0.08927426504669711, 0.11744340037694201, 0.14536918548401445, 0.24389985774178058, 0.19285758258774877, 0.09547914654831402, 0.06301884655840695, 0.13208258984377608, 0.11399787588743493, 0.09556036719004624, 0.07609346997924149, 0.10193635083851404, 0.162135147547815, 0.10667705661035143, 0.16184710519155487, 0.20196400175336748, 0.2211047918535769, 0.10737471253378317, 0.11838111138786189, 0.11712404681020416, 0.25610020151361823, 0.15278065809980035, 0.16501208301633596, 0.07541901359218173, 0.15375481598312035, 0.16767671972047538, 0.08829828890156932, 0.23863020847784355, 0.0918044320133049, 0.09193982201395556, 0.08521493247826584, 0.13109620136674494, 0.11881563885253854, 0.11763782822526991, 0.19351913302671164, 0.1149783271830529, 0.15202777896774933, 0.23358547448879108, 0.13892321730963886, 0.1605152914999053, 0.16099967644549906, 0.17181287199491635, 0.12170818168669939, 0.1817575766472146, 0.16026091296225786, 0.12749384623020887, 0.102687738253735, 0.1023668484413065, 0.19470728177111596, 0.14385097398189828, 0.11774677550420165, 0.13742792332777753, 0.15426146535901353, 0.17401387420250103, 0.11565195978619158, 0.08444015998975374, 0.04367972862382885, 0.1799867083900608, 0.1107080168731045, 0.13144685130100697, 0.10794960981002077, 0.12111736534279771, 0.1411499868845567, 0.11967130543780513, 0.082169499801239, 0.15728647413197905, 0.1445144836907275, 0.0908590249309782, 0.22537533222930506, 0.1332373864715919, 0.1416316258837469, 0.08393618234549649, 0.07650128754903562, 0.23224715958349407, 0.08927240225602873, 0.17399928357917815, 0.15494891675189137, 0.0998714956222102, 0.12022499955492094, 0.12673347140662372, 0.07993062579771504, 0.13205247349105775, 0.0761338799202349, 0.1927384381997399, 0.08863452632795088, 0.09704273295938037, 0.17302701075095683, 0.09317010990343988, 0.1501260107033886, 0.1578031128155999, 0.12327570890192874, 0.21739279181929305, 0.18886804900830612, 0.17577890917891636, 0.13665316568221897, 0.1676414825487882, 0.16152703174157068, 0.13215799204772338, 0.08752356836339459, 0.06958612619200721, 0.1350456292857416, 0.13826923677697778, 0.1354026616900228, 0.15407107479404658, 0.1781654334627092, 0.09862537772278301, 0.21570027951383963, 0.166292272915598, 0.11760975277866237, 0.16250126383965835, 0.20371806778712198, 0.17220983194420114, 0.09472010759054683, 0.20609921892173588, 0.20040228555444628, 0.15983496472472325, 0.12836288631660864, 0.11883141691214405, 0.15486426738789305, 0.12352710400591604, 0.09807512717088684, 0.09533791584544815, 0.11584373074583709, 0.27848263329360634, 0.2124300948344171, 0.1222484651952982, 0.08142135557136498, 0.09560263992170803, 0.16594206826994196, 0.12172922157333232, 0.10810677442350425, 0.14682385430205613, 0.15705419675214216, 0.1625453622546047, 0.08772650864557363, 0.11932776527828537, 0.14724264823598787, 0.15330556430853903], [0.025422476464882493, 0.07557211865787394, 0.03477092854154762, 0.10457593263708986, 0.055220885697053745, 0.057938136960729025, 0.07401728216791525, 0.08500026626279578, 0.015672793379053473, 0.03300530726846773, 0.028489789510786068, 0.02361815219046548, 0.020648971476475708, 0.02120831148204161, 0.011826190948340809, 0.00943249937336077, 0.027248627302469686, 0.056071501967380755, 0.012775281866197474, 0.08251804203609936, 0.031423675536643714, 0.048793604801176116, 0.028586810476554092, 0.06294445367529988, 0.013681237305718241, 0.053885038432781585, 0.042528668709564954, 0.06372914125677198, 0.027773828514909837, 0.018651065402082168, 0.018568215746199712, 0.02579334435722558, 0.03607704536989331, 0.07697872599237598, 0.0342293425637763, 0.03553365597326774, 0.05002018566301558, 0.06568732758751139, 0.0843697672826238, 0.03465431487711612, 0.020915708628308494, 0.11797231418313459, 0.01634946693229722, 0.006610701766476268, 0.023597362778673414, 0.027756855597544927, 0.05324023084540386, 0.06580466113518924, 0.06252986771869473, 0.08903772773919627, 0.060696781511069275, 0.018891189138230402, 0.07475108068319969, 0.05431432633486111, 0.021463209523062687, 0.034795827596099116, 0.014986428304837318, 0.01808615001209546, 0.01066504617483588, 0.005869274436918204, 0.11840229970403016, 0.004208225018373923, 0.047122722389758565, 0.04304305126424879, 0.05145877214090433, 0.029883524293836672, 0.104493747203378, 0.031699565224698745, 0.021112056783749722, 0.060012194808223285, 0.03677890927065164, 0.02202082960138796, 0.010001991959143197, 0.08977876219432801, 0.07687435034313239, 0.06127461398136802, 0.029597355860460084, 0.040595188474981114, 0.029770252149319276, 0.04567501491692383, 0.03840831675915979, 0.025893280107993633, 0.020624282078642864, 0.013927263898949604, 0.05970179525320418, 0.025175235532515217, 0.021671753020200413, 0.03723327063198667, 0.05327041399141308, 0.08465501174214296, 0.03483736189082265, 0.0823778948688414, 0.06638660881435499, 0.010193529142270563, 0.025777182236197405, 0.025940458435798064, 0.07471881952369586, 0.05964371106529143, 0.06800509931053966, 0.06005973307765089, 0.06332422548439354, 0.06314907121122815, 0.07374618304311298, 0.0697651990049053, 0.03633265587268397, 0.06123671992099844, 0.07696774220676161, 0.051211659229011275, 0.025710118061397225, 0.03918845497537404, 0.03508562884235289, 0.014633750452048844, 0.03773143354919739, 0.08670428185723722, 0.037932770792394876, 0.0684202641423326, 0.02189834925957257, 0.02886935351853026, 0.039405577699653804, 0.05096648332255427, 0.0065988668302452425, 0.04413882859807927, 0.038354366333805956, 0.026391251922177617, 0.07705006122705527, 0.03294036563602276, 0.058514266202109866, 0.015845094094402157, 0.04626715228368994, 0.04227545163303148, 0.02027001974056475, 0.1378369505982846, 0.02623946787934983, 0.026436934822413605, 0.02177335489250254, 0.014302857416623738, 0.015777870357851498, 0.05140311477589421, 0.013937386793259066, 0.051786686381092295, 0.049380324489902705, 0.009708276811579708, 0.025385823646502104, 0.02836734442098532, 0.033940276043722406, 0.06373265161528252, 0.049896469645318575, 0.021980146921123378, 0.07049968771752901, 0.036714732050313614, 0.03252457740018144, 0.02951198290247703, 0.09842562867561355, 0.016635691026749555, 0.03928757992980536, 0.0052001202311657835, 0.012919584132760065, 0.0048719717506173765, 0.016470969494548626, 0.05130145167640876, 0.04381028353236616, 0.030198193053365685, 0.04178858049272094, 0.050580985844135284, 0.018073234787152614, 0.021606631416943856, 0.018051259794447105, 0.01921129227412166, 0.008180332042684313, 0.027409845897636842, 0.037379811401478946, 0.03789028283790685, 0.049003506428562105, 0.05552230155444704, 0.021571364559349604, 0.07181451364886016, 0.062240786355687305, 0.0206979068389046, 0.048241710392176174, 0.09098324560909532, 0.029546257137553766, 0.02634716463944642, 0.10973627839121036, 0.0656546582467854, 0.021727332459704485, 0.04460482312424574, 0.07061072043143213, 0.04953709947585594, 0.05504133790964261, 0.029505815655284096, 0.020141604072705377, 0.0517828123702202, 0.03596082504373044, 0.035331617400515825, 0.052444796965573914, 0.008537541634723311, 0.011836340745503549, 0.007005699198998627, 0.06096174678532407, 0.02215883938333718, 0.015143846176215447, 0.012270191928109853, 0.056813560586306266, 0.033975160695263185, 0.038838951659272425, 0.031017882174637634, 0.017785481868486386, 0.035334407875780016, 0.007836989479983458, 0.014818146319157677, 0.0665225183183793, 0.03563913742254954, 0.004503190684772562, 0.06619659674470313, 0.04432599453139119, 0.04088914945896249, 0.030172073165886104, 0.06195406131155323, 0.0441012647934258, 0.10737884629634209, 0.014704620916745625, 0.06869613527669571, 0.024367216683458537, 0.03166376773151569, 0.05826908287417609, 0.0619422277668491, 0.019131377812300343, 0.05643716183840297, 0.0337117873277748, 0.13670900487340987, 0.017439501898479648, 0.04895887366728857, 0.025056686718016863, 0.03192134121491108, 0.05948368547251448, 0.02958422355732182, 0.08059457337367348, 0.011994098149443744, 0.0630382685631048, 0.08883778573363088, 0.07185097536421381, 0.07531722061685286, 0.04932304553221911, 0.043835839387611486, 0.037779142512590624, 0.009885576819215203, 0.01482389981902088, 0.03600899413868319, 0.03194074466591701, 0.12579861766425893, 0.006363612046698108, 0.004959551206411561, 0.030154972228046972, 0.022121090041764546, 0.022894866197020747, 0.01971784331544768, 0.032673593232175335, 0.04142534744460136, 0.014814095120527782, 0.014228880136215594, 0.021573683770839125, 0.02277382376632886, 0.022858224510855507, 0.0365174951730296, 0.01703989619272761, 0.0728043308481574, 0.02830107434419915, 0.009592558362783166, 0.08073551463894546, 0.044152283735456876, 0.049150203049066477, 0.022575653638341464, 0.03084038271481404, 0.020571452296280768, 0.02314179357199464, 0.01575470236275578, 0.10261592804454267, 0.04621986263373401, 0.021360121500038076, 0.07553251023637131, 0.0412496328499401, 0.052307696314528584, 0.06103312654886395, 0.04366772438515909, 0.021552014914050233, 0.04360296828963328, 0.06660485218162648, 0.042422667756909505, 0.06182183657074347, 0.023691927235631738, 0.002003394488383492, 0.047932383240549825, 0.02334848169994075, 0.02946227199572604, 0.09397087982506491, 0.039266425010282546, 0.029571017039415892, 0.017373823684465606, 0.030201586523617152, 0.05544558574911207, 0.06630253090406768, 0.03057305555557832, 0.05117837390571367, 0.03699252163642086, 0.04727045801701024, 0.0352810734329978, 0.02272469730087323, 0.08104265987640247, 0.03271190289524384, 0.03265344763349276, 0.013134343116689706, 0.009083508139156038, 0.06139050405181479, 0.004969677811459405, 0.06776619455195032, 0.03671550759463571, 0.05786708374216687, 0.0272117963686469, 0.025973001611419022, 0.06435596660594456, 0.08263738680398092, 0.04152350389631465, 0.02875063772080466, 0.0416567045613192, 0.030420488546951674, 0.05239846097538248, 0.011923382608074462, 0.054853697001817636, 0.06411165159079246, 0.01125924392908928, 0.061048017741995864, 0.03582017321605235, 0.01612092812138144, 0.05959523768979125, 0.06230932369362563, 0.027052687328250613, 0.022153809477458708, 0.018242615151393693, 0.08606215342297219, 0.018118813786713872, 0.032055165283964016, 0.0512695504585281, 0.05012737034121528, 0.01856118946307106, 0.022875778158777393, 0.03216658762539737, 0.06565124436747283, 0.09291346781537868, 0.017762117204256356, 0.03341175557579845, 0.007968277259351453, 0.04170834690739866, 0.13751585298450664, 0.13867505796952173, 0.098443633178249, 0.19424085679929703, 0.18021710071479902, 0.19461316260276362, 0.10147696142666973, 0.1710858047590591, 0.10856408582185395, 0.21077595156384632, 0.16613931627944112, 0.12149889604188502, 0.14240926306229085, 0.11553047021152452, 0.1789784710854292, 0.1722129638073966, 0.07183277048170567, 0.16384061775170267, 0.07175912716775201, 0.20079369423910975, 0.10192702946369536, 0.10156400050618686, 0.13277379650389776, 0.14802111661992967, 0.1521746054640971, 0.09489215226494707, 0.19767309684539214, 0.18632988911122084, 0.07847042797948234, 0.10125308515853249, 0.11539879094925709, 0.14532980712829158, 0.13419564755167812, 0.2263008794398047, 0.08807761871139519, 0.12647682189708576, 0.11585988730075769, 0.15767712582601234, 0.16772872942965478, 0.20956886321073398, 0.1455937445280142, 0.23176278948085383, 0.12891443562693894, 0.32926527550444007, 0.16786699154181406, 0.13693448418052867, 0.10227325619780459, 0.2109365671640262, 0.19799364526988938, 0.2999603870557621, 0.13729251106269658, 0.15309004462324083, 0.18022956879576668, 0.21579753054538742, 0.18427495640935376, 0.2170913908048533, 0.1342078484594822, 0.15493769547902048, 0.11948216910241172, 0.13327171822311357, 0.24709413555683568, 0.13044054358033463, 0.1897092437138781, 0.1452735671773553, 0.19358420453500003, 0.18618460628204048, 0.1594263975857757, 0.1333327079191804, 0.09040731674758717, 0.24930539424531162, 0.07844178850064054, 0.08212580956751481, 0.10331821496947668, 0.2494571782881394, 0.12779463868355379, 0.22529483889229596, 0.1373147458070889, 0.08331442586495541, 0.10996886747307144, 0.15066023828694597, 0.10551921717706136, 0.16706337919458747, 0.09220413048751652, 0.10424917243653908, 0.1483873516554013, 0.12203281934489496, 0.12027050062897615, 0.10833355991053395, 0.1232174428878352, 0.1580568531062454, 0.16272594162728637, 0.09936308735632338, 0.19713121029781178, 0.13088807347230613, 0.1683935007895343, 0.1180190546438098, 0.16587238060310483, 0.13343473838176578, 0.1035149434756022, 0.11691394480294548, 0.14086160314036533, 0.1592359328060411, 0.16156817640876397, 0.22246614302275702, 0.14596358640119433, 0.14790293702390045, 0.17462739284383133, 0.11511345001053996, 0.08041422406677157, 0.08680563696543686, 0.10408438596641645, 0.10595249041216448, 0.16577351168962196, 0.13696224050363526, 0.0988577218959108, 0.24861558282282203, 0.1349589612800628, 0.14359754539327696, 0.2390230420860462, 0.17711685301037505, 0.163862629851792, 0.13371341483434662, 0.16065097093814984, 0.16430310934083536, 0.19610422634286806, 0.14671976066892967, 0.1448580386932008, 0.13397861388511956, 0.15416795475175604, 0.11707731377100572, 0.12980400351807475, 0.23013914847979322, 0.16926619224250317, 0.0921080594707746, 0.1071577901893761, 0.11984520548139699, 0.15425551333464682, 0.11808218914666213, 0.15395331080071628, 0.20015742135001346, 0.11694400920532644, 0.19354240677785128, 0.16558450151933357, 0.13340172765310854, 0.16002195625333115, 0.24387995334109291, 0.13794978673104197, 0.16465706925373524, 0.18534902221290395, 0.09612457753974013, 0.13686605816474184, 0.11848058144096285, 0.19835860381135717, 0.1530549261951819, 0.1781529950676486, 0.05225609478657134, 0.1453905741800554, 0.19654317700769752, 0.15756590757519007, 0.16012113686883822, 0.11649895066511817, 0.13407927879597992, 0.1619480669614859, 0.09550501039484516, 0.13353702117456123, 0.10681209780159406, 0.13106755446642637, 0.19805226009339094, 0.0915530146448873, 0.13217437866842374, 0.27671519375871867, 0.11316662596073002, 0.1897856849245727, 0.12228345003677532, 0.11398753034882247, 0.10141830207430758], [0.005502765734490822, 0.03790600152569823, 0.06358784376061521, 0.08456122654024512, 0.05708532393327914, 0.057105937084998004, 0.013431020361167612, 0.011906640684173908, 0.10136987693840638, 0.029854656604584306, 0.031029563579068054, 0.01994228361581918, 0.05028211926401127, 0.022277534772001673, 0.022930454033485148, 0.02098717373883119, 0.020528782515611965, 0.09446525407838635, 0.05222240128205158, 0.03330418869154528, 0.0005054993368958094, 0.021677582590200473, 0.02673829316336196, 0.0238300613273168, 0.0993522371572908, 0.0384796668367926, 0.0713594286935404, 0.04283733906049747, 0.013013833176955814, 0.06594198814127594, 0.04832249687751755, 0.055528817611048, 0.09008969238493592, 0.04690201880293898, 0.019040689221583307, 0.02107277305185562, 0.024435330997221172, 0.07743614129140042, 0.02843169233528897, 0.08545651638996787, 0.04673120238294359, 0.03408148077141959, 0.032285012130159885, 0.029263172327773646, 0.04191104970232118, 0.06899781088577583, 0.12112608557799831, 0.02749157305515837, 0.01612515094166156, 0.05936329056567047, 0.06950149909243919, 0.014925561990821734, 0.060261229882598855, 0.01622885680262698, 0.05833925293700304, 0.07101903524016961, 0.04969678368070163, 0.07184507529018447, 0.03926421712094452, 0.026412052466184832, 0.013728003741562134, 0.03605653611884918, 0.022160793087095954, 0.005586794941336848, 0.039849092572694644, 0.038723425241187215, 0.040999432603712194, 0.03709731659910176, 0.0715586582373362, 0.00889847588041448, 0.025840851085376926, 0.04708089123596437, 0.02472193544235779, 0.0742992092273198, 0.07514148004702292, 0.037272315021255054, 0.08581529284128919, 0.008933186127251247, 0.020899494556942955, 0.015235745395330014, 0.005558858647418674, 0.05631663334497716, 0.019245239964220673, 0.029448495879478287, 0.04773126493091695, 0.04707286490884144, 0.012842522301070858, 0.03691803227411583, 0.029968140261189546, 0.03571361565263942, 0.06114868265285622, 0.011772378747991752, 0.07960140908835456, 0.008654790763102937, 0.05325229445588775, 0.037697643565479666, 0.06438006414100528, 0.035938657092629, 0.07266384229296818, 0.03938989611924626, 0.016250909720838536, 0.017734253269736655, 0.05987501994241029, 0.027173907874384895, 0.04155946837272495, 0.03204793676559348, 0.04617691083694808, 0.0153994140055147, 0.056561931705800816, 0.007634483818037552, 0.023487231774197426, 0.06464528545620851, 0.05311129010806326, 0.08355913421837613, 0.02495875105523737, 0.024626452577649616, 0.04749005580379162, 0.038085764535935596, 0.03466723566816654, 0.0656659463129472, 0.06544361371197738, 0.025307914838776924, 0.03844807361019775, 0.028521573840407655, 0.019839889500872232, 0.009913922222040128, 0.009483711273787776, 0.01820998477342073, 0.018126196300727315, 0.02290585183800431, 0.07232885167468339, 0.08590030585764907, 0.044312313038972206, 0.04729580607090611, 0.07282622420461848, 0.046598773551522754, 0.042894699654425494, 0.06491900436230935, 0.052226906118448824, 0.037448241128004156, 0.16021809104131535, 0.030722910014446825, 0.01729464580421336, 0.13234767015092075, 0.05377327470341697, 0.09488032985245809, 0.04695195792010054, 0.053597066580550745, 0.019032523741771, 0.0480194111878518, 0.03622048767283559, 0.16859205497894436, 0.04868836826062761, 0.054430962263722904, 0.09749746910529211, 0.030603839841205627, 0.029545702382165473, 0.02415155599010177, 0.055418163392459974, 0.059295662358636037, 0.013115805195411667, 0.022226393375603948, 0.019316384095873218, 0.04456984570424538, 0.051874074270017445, 0.0685975854867138, 0.0762020016554743, 0.03030638148629805, 0.03205861255992204, 0.04840291599975899, 0.09637818424380384, 0.03731091783265583, 0.041517036079312675, 0.05171617121959571, 0.05642598509439267, 0.022620124982495327, 0.013835075242241146, 0.020538948083412834, 0.030095544752839487, 0.09285703490604647, 0.04483230251935311, 0.08107015644782223, 0.04196217254502699, 0.04174093461188022, 0.04492132684390526, 0.020756966951012146, 0.06029617761669215, 0.05446178365673404, 0.06485636709840037, 0.006992628123043687, 0.12217116309329867, 0.023205935540318023, 0.03129445649392437, 0.011927184259548085, 0.07430860481690615, 0.0363273383845808, 0.021628168542520143, 0.02443675221002195, 0.05812432325910777, 0.03516198841680307, 0.0639217508432921, 0.03466060086793732, 0.05587932653725147, 0.05025658196245786, 0.1091375359101221, 0.010665664940461284, 0.01807706241379492, 0.04493926084251143, 0.04785336306667887, 0.019525185489328578, 0.0371435857960023, 0.012417556481523206, 0.05979986264719628, 0.06292473481153138, 0.03864798592985608, 0.05230143629887607, 0.027863038376381155, 0.04149421503825579, 0.013439954891509842, 0.033830063403001986, 0.03549652261426672, 0.025299081426055636, 0.13499394612153992, 0.02544089285947848, 0.02960236535727745, 0.01822639551392058, 0.08616972772870213, 0.10739763747551478, 0.05360586474125739, 0.11289017595117912, 0.06596077932044864, 0.0535046543518547, 0.02281712251715362, 0.07291553425602615, 0.04220917042403016, 0.01675646628427785, 0.09206879243720323, 0.04554890176223125, 0.04938562342431396, 0.08879571338184178, 0.03269006891059689, 0.05902590652112849, 0.0580350577365607, 0.04624789726221934, 0.06122525373939425, 0.044868393160868436, 0.02817053798935376, 0.02169528837839607, 0.01986884068173822, 0.027591041252890136, 0.07335602858802304, 0.06828066616435535, 0.0476179167162627, 0.02355534608796006, 0.01851180881203618, 0.014549985171470325, 0.06487192251370288, 0.02974754614115227, 0.019084778359683696, 0.011780681525124237, 0.024147982549038716, 0.028604037579498254, 0.0037836928913748125, 0.05940288414421957, 0.0545891844376456, 0.030211518314899877, 0.008749695680307923, 0.02046877059910912, 0.057939502512454055, 0.0037838566277059726, 0.02726450369664235, 0.06294397127931006, 0.016013854765333235, 0.05516769968380686, 0.028791682198061608, 0.027448118453321513, 0.05043290882895235, 0.04623215630999766, 0.0296429664012976, 0.08210044295992702, 0.03483784799755085, 0.0016008058128136327, 0.018411238525004592, 0.02551362333178986, 0.041434538943576626, 0.017311409064859618, 0.033209832035936415, 0.034652426111279055, 0.031879677044344135, 0.02747643880866235, 0.030545380868716165, 0.02081448710669065, 0.03360320370120462, 0.037043306801933795, 0.11447725133621134, 0.033712251170072705, 0.021913628224865533, 0.05649018828989938, 0.06072172509448137, 0.02082411832816433, 0.010394812579761492, 0.02750272939010756, 0.05779000057373196, 0.002172878289457003, 0.031968463881639764, 0.03499337246466894, 0.023846110270824283, 0.03708633281348739, 0.06212666630744934, 0.004987142865502392, 0.019077034048677888, 0.03480724182736594, 0.05815133001306094, 0.05491500211064704, 0.039448325405828655, 0.03746830137970392, 0.026974644933943637, 0.012735826512653148, 0.04050835719681345, 0.055899331127875485, 0.058737756553455256, 0.019129934335069265, 0.011433624513301766, 0.013742495102633256, 0.07845993401133455, 0.05204637498536613, 0.024488537419529166, 0.02795136322674807, 0.027888033910130616, 0.03235211712308228, 0.02029117094934918, 0.058619773626560345, 0.04150518398091663, 0.024412851344095543, 0.046178083430277184, 0.0317959813401103, 0.004109581996090128, 0.031456957149202935, 0.05525219319679309, 0.013146656274329871, 0.06085361215809826, 0.03223285028070677, 0.030843874519632664, 0.04773785520228557, 0.040252924809465185, 0.025261326518375427, 0.03171578486217186, 0.03577877250791062, 0.017336699602310546, 0.07857921940740198, 0.02925800141383661, 0.059779546354548074, 0.10957777791190892, 0.06734800175763667, 0.1463710848474875, 0.32051823392976075, 0.16199975012568757, 0.12460877682315186, 0.1496203409624286, 0.1309182937256992, 0.13057531759841368, 0.17834418715210631, 0.14043700561160222, 0.17174576700199395, 0.1459681283449754, 0.09710092475870624, 0.24016293638851494, 0.11929233514820226, 0.1422176553751342, 0.19218682951759547, 0.19015968282474205, 0.07773109304253012, 0.1459619091474451, 0.1262967026559636, 0.207411439914722, 0.08959031605627388, 0.26371300395112485, 0.15807557007065043, 0.13489170785760507, 0.12862112402217463, 0.19129852327750996, 0.13828243216266856, 0.15945900755468756, 0.1671622777939774, 0.14627447206294164, 0.11836922218208201, 0.10592985490802675, 0.09159807785181329, 0.17475962871685624, 0.20568352716509253, 0.13422870280919597, 0.17395696631865576, 0.19806573749519885, 0.14377704123035073, 0.3059735940769315, 0.10714601230574772, 0.1411577794351615, 0.1025988809124101, 0.29220108466688544, 0.1421329317963682, 0.07099311944330111, 0.12828114617150277, 0.1454146791365929, 0.1838752653566189, 0.12470642861444503, 0.156966460053809, 0.1534327387344092, 0.16365772287826985, 0.14845551049802452, 0.17745929479133338, 0.09962091688066721, 0.09808757298742421, 0.15973090077750385, 0.12670451280428097, 0.09434114472242072, 0.1884473254904151, 0.1568075513932854, 0.14465705025941133, 0.10641664441209286, 0.11899753182660788, 0.13541413529310375, 0.14533259760355577, 0.05533413001103327, 0.12303785799304023, 0.11151872415211983, 0.21260571666061878, 0.2059610903961584, 0.14218980999430642, 0.1990848546847701, 0.14219720178516582, 0.10212046283413656, 0.09256546734832227, 0.08581257658079267, 0.11359725715010427, 0.0887255952693522, 0.19669298693770543, 0.09364889163407497, 0.1416414519189857, 0.16816448885947466, 0.18906730081653222, 0.2725464612012729, 0.10611508012516424, 0.12142673702328466, 0.08698896228452213, 0.266384735587053, 0.15186996868578717, 0.05858820637513418, 0.2774597459938377, 0.21263047470711172, 0.10922122790361755, 0.1424168181256391, 0.1468487162492238, 0.08191683562472463, 0.14294346095994115, 0.0963477636105381, 0.14109408832155168, 0.14179233054164797, 0.13179558649426326, 0.0921144567837473, 0.09422984483535402, 0.0859487681009341, 0.23176531278295442, 0.09889331529848278, 0.12925981631269678, 0.0906494572700467, 0.19488443242153153, 0.14248855412006378, 0.12535433837911114, 0.08381991749047302, 0.15967264218488708, 0.155627699859906, 0.18522112048231065, 0.159482637536712, 0.09921882869093679, 0.1860408077482134, 0.07610112894326448, 0.09603810249245726, 0.20821074780542403, 0.1060580980265513, 0.09633384834160097, 0.07355126537731849, 0.13922432146500796, 0.16834422218380496, 0.2267699019284919, 0.14061660534935072, 0.14475531061179936, 0.15422230964759365, 0.12505221005994827, 0.18334648513700813, 0.18897741188993677, 0.11606607818976045, 0.14653312537120655, 0.2688985678832978, 0.1427086305920966, 0.08213271896238439, 0.2054391527781263, 0.15478919172892347, 0.19457028131000698, 0.1079189516894985, 0.15766697324579582, 0.10980417748214677, 0.16616958106169477, 0.17634148680372164, 0.21148827974684536, 0.14470477035501972, 0.16184186562895775, 0.18215315620182082, 0.12028286480926909, 0.09810510993702337, 0.11603487830143422, 0.15787109354278073, 0.18563666380941868, 0.14192744594765827, 0.08068269598879851, 0.18091427424224094, 0.17070313857402653, 0.16538340918486938, 0.18536059971665964, 0.17213925370015204, 0.11255652119871229, 0.15380664757685736, 0.1005731443001423, 0.1938912904006429, 0.11963879194809124, 0.08555394553695805, 0.1938986821915023, 0.09992199877160601, 0.07358780872891657], [0.05572085203311872, 0.008453986010863446, 0.015227395306283142, 0.024378072448598687, 0.07165703733335249, 0.11296346303424798, 0.06284061979386024, 0.04421744430146646, 0.014910925910953665, 0.01977561209059786, 0.009093944590858882, 0.09127467958023772, 0.04684536324930377, 0.011249500457779504, 0.04902184860839043, 0.05205354042118415, 0.045445242285495624, 0.0025216988296961063, 0.03618510949308984, 0.03809922709478997, 0.030056149698793888, 0.021279492721077986, 0.044993949704803526, 0.09678097005235031, 0.03391796337382402, 0.01791245591448387, 0.05567599662754219, 0.049017507044482045, 0.08992693197797053, 0.05612648768874351, 0.04363781583379023, 0.04704963939730078, 0.03909816899977159, 0.08499599891365506, 0.03360550064826384, 0.05493010852660518, 0.1338646051590331, 0.03705362636537757, 0.05945627053733915, 0.012668463623413118, 0.03397581749595702, 0.047920033903210424, 0.09223281449521892, 0.02376111766352551, 0.008487414197588805, 0.021549090852204245, 0.02977017607918242, 0.05140717432368547, 0.052470961381914094, 0.024090649785648566, 0.02399167697149096, 0.0453073438256979, 0.07810694631189108, 0.012844385091739241, 0.03124862145341467, 0.04328972630901262, 0.04178852112090681, 0.042820510861929506, 0.014104367237450788, 0.043835735486936755, 0.0375997468654532, 0.04491480707656592, 0.0460237092920579, 0.03820706486294512, 0.022360883522196673, 0.04890425530902576, 0.02406040355708683, 0.0184320186599507, 0.07293805101653561, 0.010616330673656194, 0.05172999000933487, 0.023280207824427634, 0.0068038099834666355, 0.025183267425745726, 0.031623895847587846, 0.04435959526745137, 0.027026595271308906, 0.014777196465729503, 0.03130072022031527, 0.03535531788656954, 0.041795356301008724, 0.04617926344508305, 0.04676512224250473, 0.03024836965778377, 0.04540878057014197, 0.031188941647997126, 0.06045588408596814, 0.06331275930278935, 0.053554389378405176, 0.035651883808895946, 0.06558980196132325, 0.007557673852716107, 0.04663523526687641, 0.0659409788204357, 0.029520261559810024, 0.06822770650614984, 0.03489464826998301, 0.039579251388204284, 0.00992254876109655, 0.06237965702894144, 0.05586635750660207, 0.027289139288768638, 0.03642526477051433, 0.05971367332676891, 0.014402500946744112, 0.04379977843200322, 0.0336869550665142, 0.030407450867642183, 0.027276606269879267, 0.007584253871755209, 0.07517285805079155, 0.046581492642872036, 0.010716674605646404, 0.022935014530958142, 0.06017898878781125, 0.03081920924159931, 0.07206615366158076, 0.053668275650125, 0.025960104940168094, 0.04773931723320857, 0.03707258452777751, 0.04064716107677668, 0.05489451141329482, 0.029516543399950024, 0.03548040687746834, 0.039687619791948237, 0.07052492816001177, 0.027126636778120883, 0.02461733529344201, 0.0886299175908789, 0.05142556474311277, 0.07459508124156855, 0.05148023505171295, 0.08692205767147243, 0.017285766007262282, 0.038694151226081885, 0.01678858643572312, 0.08516834786860272, 0.03434229001868516, 0.03612488420912996, 0.06201154064910952, 0.033611690159887075, 0.009298815384681802, 0.023591577737533953, 0.06039069754478987, 0.048884814750635996, 0.025342196495330427, 0.01721330641885288, 0.09633054578443989, 0.0173375289523392, 0.04798635593033396, 0.043488284209161066, 0.022775907345931046, 0.0424699870927725, 0.05272717673506122, 0.024296981682709884, 0.02742885786574334, 0.012447880635590991, 0.06260226422455162, 0.04559145279927179, 0.011899956716661109, 0.05786657166026998, 0.038480505463667214, 0.08865234529366717, 0.0368417951540323, 0.011011810966010671, 0.030064593483984936, 0.03287250736320857, 0.008041079163376708, 0.02782861571176909, 0.06348228067508899, 0.05247658315056469, 0.002904831872001523, 0.06089883121603634, 0.034682149125728756, 0.02920153139712056, 0.038577637751586735, 0.03769820759771392, 0.009270680566260125, 0.04718078060250264, 0.07338443800108507, 0.029607961150759365, 0.05069549923064187, 0.021692551708838437, 0.018083116483467165, 0.011171868100063875, 0.02229225712653715, 0.031392256714752875, 0.007265159592861892, 0.034553171281004325, 0.03646476558060385, 0.06562288690474816, 0.0729793292703107, 0.07458616062649526, 0.032784332797746174, 0.040054370620055124, 0.02387877775618108, 0.027962220847257413, 0.07503338623791933, 0.045117439367459156, 0.08593176549766213, 0.02969243982079206, 0.049567701935302466, 0.022368907993950415, 0.07254204843775369, 0.034959998083650135, 0.09893461581668817, 0.10788855332066305, 0.027998662153549958, 0.03819103447312955, 0.060974827138124965, 0.029037962049187627, 0.031172510498436168, 0.02080539765302092, 0.028853133881057147, 0.02846977935405448, 0.012609135410457384, 0.022980474786891136, 0.08208943690988235, 0.014978876024542842, 0.04508931568125263, 0.04196188681817148, 0.06008114403812215, 0.023493757107644342, 0.05723396498069633, 0.07659427865291946, 0.028811785123252776, 0.053039357444504276, 0.043937387454207055, 0.023053572622302454, 0.0043534725955396425, 0.0378389039542526, 0.061202343640616164, 0.034108969921362586, 0.002593838366919954, 0.037647745266440324, 0.01867474362370558, 0.05732036952394992, 0.04419715769472532, 0.03667584351205733, 0.029541410913225263, 0.03382427465112414, 0.016299889612128027, 0.07259844423970208, 0.08188679348677397, 0.019995675575046334, 0.04571419289277401, 0.01684357030171668, 0.08364507491933182, 0.02400932709861081, 0.029254561559355352, 0.10177110423683189, 0.04549751174636185, 0.04292038909625262, 0.03379832916834857, 0.02227314867923269, 0.011490014749142574, 0.034271693220944144, 0.036991631059208885, 0.013986080030008452, 0.011468823649920523, 0.0042425841365911765, 0.03304470046714414, 0.01101282028685091, 0.02610081613966031, 0.024288413587782998, 0.011753519847843563, 0.012879184396297205, 0.023303099369513802, 0.03339523907925468, 0.0336989073548466, 0.010750952551461523, 0.031344425296992995, 0.07770127354888245, 0.029928409385320265, 0.060535557349794544, 0.057131069916067645, 0.02242156522697769, 0.028276793127588462, 0.05233340802078601, 0.038842911017127335, 0.017074973802664317, 0.04671855247579515, 0.012142040650360286, 0.041038302588276565, 0.033639472458162345, 0.04438904368726071, 0.012955502224940574, 0.023744987083773594, 0.04812202423636336, 0.03274344046076294, 0.08082378568360582, 0.07590070454170927, 0.06953586052986793, 0.038342855623341165, 0.009416545981366653, 0.027073218843725044, 0.05946702425717376, 0.05325688463926781, 0.015224708731693681, 0.011316182426526211, 0.043182912704651244, 0.09329534732387401, 0.0191787936273613, 0.03838933633232955, 0.07659539929591119, 0.03392351463844534, 0.03667607728857547, 0.033675333033897914, 0.05148083248059265, 0.04368808520666789, 0.03927299672795925, 0.024360166280530393, 0.031652709731133655, 0.04141910598264076, 0.028439961715776008, 0.03776535340875853, 0.06052550867025275, 0.0719293016300071, 0.00605032553721685, 0.01740846342727309, 0.0705919589381665, 0.04343560656707268, 0.07112024934031069, 0.0779411059920676, 0.06483473349362612, 0.0727586071297992, 0.058759857711265795, 0.006529662023240235, 0.041369712344021536, 0.021781093637400772, 0.04898180974123534, 0.02506928281945875, 0.04375211770820897, 0.03485056098725181, 0.020851664994552266, 0.020744706671393942, 0.09075018155272119, 0.027436314594524447, 0.05743470108427573, 0.011570400474738562, 0.039541476071462967, 0.001178017616894067, 0.023115233962016646, 0.060327503670123406, 0.04535881547781173, 0.03638002344814595, 0.03449279385677073, 0.00755071482672065, 0.05384324067563284, 0.021590404357993975, 0.044166143343318254, 0.11397303620469756, 0.08348454837687314, 0.10762737671029754, 0.1259145708172582, 0.20742616412462667, 0.1481597646488808, 0.1507358334492892, 0.10410281349322759, 0.1589417751529254, 0.10076680773636326, 0.09124886026256718, 0.13937589770648628, 0.11717897315975279, 0.2102643743273802, 0.10622255053021945, 0.13446580414893106, 0.23297771491343156, 0.11979064278420992, 0.15024950407678261, 0.09427058874280192, 0.08736506046261638, 0.10301207163138315, 0.15928691835142672, 0.17924637155374512, 0.18412505742162466, 0.1127817333326675, 0.16208344954065979, 0.08755478309467435, 0.19547577569028363, 0.11751361496862955, 0.154565894335974, 0.15902819082839414, 0.15779337583808228, 0.15143652475671843, 0.14637371205026284, 0.2282995721907355, 0.35920330497901887, 0.07856159340008162, 0.07829571157344617, 0.10820734285516664, 0.2071307151345536, 0.10721037135226652, 0.15438636881299317, 0.11537522033904679, 0.09466002331464551, 0.14091500808717683, 0.13628142391098663, 0.19737065682420507, 0.17539112217491493, 0.13568665191996843, 0.09289950059610419, 0.09469889700994827, 0.13966477126814425, 0.12235132686328143, 0.065803429170046, 0.12287770252441987, 0.12265118421055377, 0.1585268255439587, 0.12229936168296263, 0.13558837672462687, 0.14312368410173804, 0.15045972482766956, 0.2564796170918271, 0.1639755253563635, 0.08751746790949255, 0.10960194224026054, 0.09871550413663499, 0.10849852449609898, 0.14574934320989996, 0.1510980460443534, 0.22282639634795487, 0.09071688880794682, 0.183792604948394, 0.06732051260769367, 0.12262276737601496, 0.19697160401847214, 0.16628819110337645, 0.13933932466898113, 0.16008820035494864, 0.17624420608626679, 0.09822513748076744, 0.14532479020999745, 0.22082886134739965, 0.08672659823787399, 0.11878893637913279, 0.16456688346806914, 0.13186012365622446, 0.14195771072991192, 0.2153622906189412, 0.10525084173423238, 0.15974418522091582, 0.10804626712342724, 0.08781210795859806, 0.18905432807514444, 0.11364766382030211, 0.12087683528079651, 0.10396518962807022, 0.1979530497919768, 0.13022551371250302, 0.1444356527645141, 0.18481402279576287, 0.09043957048561424, 0.07984477415448055, 0.19813907652860507, 0.07902826328063384, 0.10500551739824004, 0.1369528894429095, 0.15951199689880013, 0.13761055102804676, 0.07492673219530843, 0.1130408319295384, 0.09905600891215727, 0.07225917142932303, 0.1523289128090255, 0.17047590779839084, 0.17898188496474177, 0.2859069005353376, 0.12031966049107723, 0.1362797021283768, 0.15217758889775723, 0.15843261731788516, 0.1492321235127747, 0.15594398835673928, 0.2356750803301111, 0.0996116029273253, 0.1468982471851632, 0.27081544627435505, 0.09994933207053691, 0.19236037333030254, 0.12897060136310756, 0.17515059211291373, 0.23319516418268904, 0.09103199728997424, 0.1877256017178297, 0.1512815643218346, 0.1071379600034561, 0.10563782721874304, 0.13493497506715357, 0.2214460907271132, 0.15332486014813185, 0.19288994022645056, 0.1327862497419119, 0.16313425643602386, 0.07704708521487191, 0.10636428589350544, 0.1472056150669232, 0.08314245540532283, 0.145055984321516, 0.19350458693224937, 0.16109191055875272, 0.13216415187343955, 0.15488455770537257, 0.11398235757951625, 0.10869741265196353, 0.13551509706303477, 0.1657532955869101, 0.10905453411396593, 0.08005581868928857, 0.10183243532082997, 0.20581415999913588, 0.14227990672225133, 0.13162654009647667, 0.12035778461722657, 0.23576254985528067, 0.11666223057545722, 0.11580874590435997, 0.11735127016436309, 0.13662046665558591, 0.21113188558956608, 0.15312548959627748, 0.12250133717316203, 0.16745496599469334, 0.09851244511082768, 0.1841185413650237, 0.1601997303077951, 0.1039103523362428], [0.021446386890602298, 0.07328642997890711, 0.027027905161958188, 0.035776297445409, 0.06540460643009283, 0.029132519084669184, 0.025479456708126236, 0.03019233379745856, 0.11369598505552858, 0.020538230055535678, 0.05765843634435441, 0.03099305547948461, 0.01437381415598793, 0.04098496072401758, 0.05570225381234195, 0.057900643660104834, 0.029593405779451132, 0.010180589797528228, 0.028418188958312385, 0.028306898348091636, 0.0749378495675046, 0.019495714805088937, 0.03424875714699738, 0.09698739100713283, 0.01996388382394798, 0.06414334871806204, 0.06262865499593318, 0.01412496276316233, 0.01481753033658606, 0.07375940811471082, 0.03047791964490898, 0.027779951233242173, 0.05192825847188942, 0.013670824973814888, 0.009325913051725365, 0.0777889508754015, 0.01937407309014816, 0.026518617451074533, 0.05401799047831446, 0.007780560745231924, 0.04695586903835647, 0.032577058373135515, 0.022977213047852274, 0.012146245844633086, 0.015058771932672244, 0.008019681190489791, 0.03177566875820048, 0.04328465372964274, 0.02753549335466232, 0.016515136558155064, 0.033201523692696355, 0.05911276377446484, 0.04525812830252107, 0.02135912702215137, 0.017559227017045487, 0.02396383715677075, 0.05231555194768589, 0.0583400581672322, 0.09199871885357425, 0.05857017218659166, 0.09783331319340505, 0.027679954255290795, 0.13061100005870685, 0.031000816488813143, 0.032019623831729405, 0.01654341980611207, 0.03249520690587815, 0.07836467935703695, 0.05667776982591022, 0.057462201366433874, 0.07841815851861611, 0.02712707093451172, 0.00627642732069944, 0.03149134085106198, 0.05422513873782009, 0.03472459997283295, 0.05206146655837074, 0.07271180729730986, 0.025320746572106145, 0.0756519811693579, 0.005065679251856636, 0.04983014761819504, 0.01184317035949789, 0.09071229491382837, 0.046956358855823055, 0.05527393070224207, 0.048064203510875814, 0.03139093940262683, 0.048824967961991206, 0.0507353525608778, 0.006963070700294338, 0.04056240781210363, 0.008934402321756352, 0.05570930050453171, 0.0026963185246131616, 0.09258435500669293, 0.08857886525220238, 0.038021108630346134, 0.03158326697302982, 0.028520829837361816, 0.03850106295431033, 0.06448431362514384, 0.014941626704967348, 0.05953355037490837, 0.020307574268372264, 0.04734637601359282, 0.04860726265178528, 0.03953430692490656, 0.06790269777411595, 0.03839305820292793, 0.03078939345869003, 0.021754441258963197, 0.013678797495231265, 0.03315444555482827, 0.03133648060611449, 0.02389802350080572, 0.02563555633969372, 0.06567700431332923, 0.02385678049904527, 0.02793868177832337, 0.0645542610436678, 0.05256215648842044, 0.02433994090097258, 0.023404524981742725, 0.026298344309907407, 0.014192213402566267, 0.09802213782677427, 0.06153085902042221, 0.03863697245833464, 0.018300166848348454, 0.02993873080413323, 0.09458042055484839, 0.08148131368216127, 0.06492832573712803, 0.022391116763174068, 0.03872608584060799, 0.07220984829473309, 0.037777962497784756, 0.07220826009870507, 0.040694651106605306, 0.049860078433994204, 0.05857942676811945, 0.06548062461661175, 0.05530092261324171, 0.05015422866563313, 0.08185270664398558, 0.03491971059702337, 0.018663238479348365, 0.05480742038344033, 0.007851077298255404, 0.028630109227378853, 0.037407923955470324, 0.01301247504670755, 0.0194484938037931, 0.027764757614932023, 0.023777621172484942, 0.05942973504716065, 0.024680935493961442, 0.019445000143605284, 0.006046257176421932, 0.046278117515612394, 0.05711839403375052, 0.04026468413940165, 0.010819770050147781, 0.04268189622962382, 0.019295963902550284, 0.07485048394300975, 0.008711284899618477, 0.031541740099783055, 0.04348044341895729, 0.00613443127804203, 0.03740213520359248, 0.02030871903116349, 0.012156695283920271, 0.01687184427282773, 0.038415003509726375, 0.012624058144865558, 0.0735830664052628, 0.021609256764349993, 0.041368665915797465, 0.04288783107767813, 0.009652228891354753, 0.009520355743006803, 0.01835180548368953, 0.05626428595860489, 0.003550302985786402, 0.029844398268323857, 0.0479439644550439, 0.048587900018901564, 0.01948775341588771, 0.05922272779571358, 0.028178245192975737, 0.0653624079131987, 0.01693865797278704, 0.012546850666694809, 0.02784466094453819, 0.04343506851000711, 0.02612827745906543, 0.030524185131071135, 0.017921892322192434, 0.039651206316193566, 0.08243634641985409, 0.06346151538309641, 0.05324040525010787, 0.04153856207267381, 0.06866421550512314, 0.025780410578590818, 0.0721079959475901, 0.02423588994133752, 0.005923255475863698, 0.014762394330318784, 0.06073379612644203, 0.04744635443785228, 0.04828102566534653, 0.058181067870464176, 0.0022361500896295183, 0.051077772077405825, 0.011502282450237544, 0.01402046465955209, 0.041771258765948005, 0.028319013908912893, 0.05065338234999217, 0.05534110248845536, 0.008694993830431486, 0.06201568183314521, 0.028694757711491548, 0.06504214892629534, 0.01308269520450267, 0.014241646003938513, 0.011399140621506376, 0.053114047186682, 0.04574057995341718, 0.023009819306025747, 0.007907508352218429, 0.03854908361972775, 0.021163647179491818, 0.011493701367726317, 0.010326181545678992, 0.08077394304564223, 0.0700020554359071, 0.01659372814174276, 0.017615342658245936, 0.06421591591788456, 0.03089323847234482, 0.049343027858412825, 0.01605618130270159, 0.0666465905669611, 0.04718552663689479, 0.05521201703231782, 0.07736649815342389, 0.028408765538188163, 0.04357095946033951, 0.031760502970428206, 0.02017940907535376, 0.03901253629010171, 0.04034382676763926, 0.013696340938622598, 0.011177488013345283, 0.031105362832022365, 0.004815389484065236, 0.03734805119165685, 0.012303368712309748, 0.015041683982417453, 0.005620222664219909, 0.08018317865207791, 0.02128441872628173, 0.023492385989811737, 0.04405960804433562, 0.039155878403107636, 0.04018045779957902, 0.09129153375397436, 0.08085359033429995, 0.09474099162616767, 0.08722975209821016, 0.03366474629729055, 0.05793704971438274, 0.040921295585576445, 0.017231190322490875, 0.022128511518531013, 0.029532531116274185, 0.09794371508178301, 0.008429596255155047, 0.06446326631703414, 0.06365703418850899, 0.009326310100732371, 0.06291882731602527, 0.04998794676794205, 0.06910822019563057, 0.04238528206769843, 0.07909205829491839, 0.09147580902208574, 0.04869033124123234, 0.023478441034967545, 0.039362993265967816, 0.027141017744725104, 0.031880790265859105, 0.09627154504414648, 0.04046117886900902, 0.06175059410452377, 0.00924724632568541, 0.032171734419534914, 0.01091616575649823, 0.018191252966062166, 0.03471314121270552, 0.017936328949872404, 0.02319969036761904, 0.038194210865185596, 0.05964038624370005, 0.03555813200364355, 0.014538108953274786, 0.01989439653698355, 0.05103571827930864, 0.03982152178650722, 0.06833410821855068, 0.022392918326659128, 0.04161187884164974, 0.05081296265416313, 0.020607448313967325, 0.031165712425718084, 0.03009849664522335, 0.0327181963075418, 0.026061966564157046, 0.017425130208721384, 0.07784263783833012, 0.06978781966608949, 0.08760301527217962, 0.04939166821714025, 0.014007619010953931, 0.06225487602932844, 0.043360100462450646, 0.022893817913427483, 0.0063662642969575245, 0.012006610759272007, 0.04368435220385436, 0.01451619333238341, 0.05369196500396356, 0.06542948322021402, 0.050492900336394086, 0.022353131789714098, 0.03850617264106404, 0.04286619747290388, 0.015602610328642186, 0.016460011684102938, 0.07375592744210735, 0.01828873220802052, 0.022899031500855926, 0.04447784536750987, 0.09013149756356142, 0.05898286937735975, 0.03689586061227601, 0.01905989229271654, 0.04449087005923502, 0.06699498437228613, 0.12991698808036745, 0.12648780568270013, 0.11244821958825924, 0.13253593817353249, 0.2125726020312868, 0.08946569461841136, 0.19459437142359093, 0.12220047050504945, 0.1423524590791203, 0.10275511784129776, 0.12095528029021807, 0.20606873149517924, 0.15138116054004058, 0.16793270129710436, 0.13247062917798758, 0.1162375885178335, 0.1005523864296265, 0.18814645882230252, 0.09468757183640264, 0.15192678751191124, 0.11104368284577504, 0.09646880789659917, 0.24401388131082058, 0.08723094695596956, 0.19500650087138638, 0.14701369567774236, 0.13965634047053754, 0.1099912506469991, 0.21084679698105901, 0.08279253277578391, 0.1189673412591219, 0.12039279914461076, 0.12829374783905223, 0.11052280649892054, 0.17399347998434678, 0.09188721116515808, 0.12154123556683771, 0.14195061579812318, 0.11794014950282872, 0.16335075575625524, 0.08789227475062944, 0.14287383266491815, 0.16699603671440855, 0.11361800017766654, 0.15511435631196946, 0.11313203445752151, 0.0923811698157806, 0.21232969709672034, 0.07443106660502963, 0.16959343483904377, 0.11930020933505148, 0.14782171638216823, 0.06407523440429941, 0.0771987801999785, 0.14076746912905946, 0.15450339065864682, 0.11219482810702175, 0.27429323934484273, 0.14872629049932584, 0.15854082244914025, 0.19153747998643667, 0.20670908619649708, 0.13509440323105082, 0.17042542691342533, 0.121040990925394, 0.15193233877653256, 0.13853554904926568, 0.11513504650793038, 0.19312586897285655, 0.2625778445508331, 0.0965743709821254, 0.10132364855962805, 0.13282883417559788, 0.11607303211349063, 0.1366506572230719, 0.20543400227325037, 0.11423272851970978, 0.10690682553104125, 0.14597246248740703, 0.1081743989198003, 0.17045983287971467, 0.13777413521893322, 0.13761203532340005, 0.1599697387428023, 0.14078550331760198, 0.08359295388800092, 0.10743155362433754, 0.12515608104877174, 0.15485493117012084, 0.11440525559009984, 0.21861549495952204, 0.07610878790728748, 0.23012351884972304, 0.13054529030341655, 0.27527628815732896, 0.20652283681556582, 0.17062073049601167, 0.1478484782273881, 0.10621395646012388, 0.14197657612385228, 0.12398823004332371, 0.15111092972801998, 0.13810228323563933, 0.17126369755715132, 0.12511909240856767, 0.1873304377659224, 0.14232974936021492, 0.1533583755372092, 0.11602606900851242, 0.13654729089466855, 0.261894564027898, 0.10006953772972338, 0.21347033354686573, 0.14224751939764246, 0.11931435466976836, 0.10783612800878473, 0.3310472017619759, 0.0814532233926002, 0.16693561105057597, 0.16278669383609667, 0.13914933486375958, 0.192233941052109, 0.1000896276673302, 0.18603095202706754, 0.08328766401973553, 0.20349303376860917, 0.15419824921991676, 0.156077946012374, 0.13032945891609415, 0.1205003511859104, 0.17467876430600882, 0.2168902984703891, 0.13445679447613657, 0.09183025875245221, 0.07402096322039142, 0.1855042201350443, 0.24209326249547303, 0.1923075324157253, 0.10659706793376245, 0.1761257296311669, 0.13253592333057895, 0.22063591779442504, 0.14020652422914281, 0.1322503449046053, 0.14662114408565685, 0.09409122649230994, 0.18732024065684527, 0.1585713544045575, 0.28680169314611703, 0.1469764843932353, 0.23083293781382963, 0.1781254168599844, 0.16888836486032233, 0.09642193384934217, 0.09771738972631283, 0.1868596044369042, 0.14624677511164919, 0.1902535348199308, 0.12670336989685893, 0.2165650448296219, 0.18174645927501842, 0.11644141195574775, 0.1172960024268832, 0.18675890984013677, 0.10414965043310076, 0.11150256759719923, 0.07737728898064233, 0.12739712954498827, 0.13285670924233273, 0.08942662796471268, 0.16324735974194482, 0.14447310153627768, 0.10778292344184592, 0.09343144236481749, 0.1351946673821658], [0.0423979690822307, 0.09612106718122959, 0.04919717357552145, 0.053117954594199546, 0.07367652506218292, 0.0013614277031592792, 0.021492034538823646, 0.02388538843661081, 0.07142383969039656, 0.0658602851035539, 0.07404974370729178, 0.01665890169533668, 0.03245638887165114, 0.04907453738269396, 0.05527742992853746, 0.04570368037093431, 0.03908106991730165, 0.04077652112755459, 0.06759560448699631, 0.11343500882503577, 0.007434692097376683, 0.0505580089520663, 0.026258977086399682, 0.037411241355584934, 0.026689816077123396, 0.03654121050203685, 0.04023420413432177, 0.01346202079730574, 0.03409146265767049, 0.0547689400264062, 0.041444465168751776, 0.06604696493013762, 0.04573082071146928, 0.052406398244784214, 0.02048638547421433, 0.04380104750453029, 0.045064683799864724, 0.006851973512311815, 0.004411191739563947, 0.01655960048083216, 0.030446870041487273, 0.03647821329650469, 0.04418600321514532, 0.058607472528819926, 0.03771213028812781, 0.014703922370244982, 0.012601713933690917, 0.014908925822965102, 0.016404085290560033, 0.06722962920321152, 0.012400584491842892, 0.07213973018224351, 0.0017702144714348833, 0.03416220046347007, 0.011200132794328965, 0.037739656545454636, 0.01863459900050657, 0.04487257516302634, 0.03253349430451635, 0.0210118260292802, 0.01640656220843084, 0.04994041963072959, 0.041003944861586206, 0.05532873830816243, 0.04302960725908633, 0.039696878084214404, 0.01995371640077792, 0.023371885326923802, 0.051500963236321695, 0.045437060107360594, 0.049488978620502166, 0.02840388406184502, 0.04666724780690856, 0.019889522482117172, 0.05659782938892022, 0.0970329440315254, 0.04211224222672172, 0.015062492875586031, 0.031188496359391138, 0.010275536460540025, 0.02844971724698553, 0.02035838355368469, 0.03324755911307875, 0.021734748370363377, 0.050196549636893906, 0.026320515971747227, 0.026482768007554114, 0.06396236858563498, 0.06222408061148599, 0.027234467124799266, 0.06739310207194649, 0.044744832994183525, 0.013006614863115828, 0.032130192703334615, 0.018926977354567498, 0.05992325211991556, 0.01858314404671546, 0.026628221530700102, 0.02802444065309828, 0.054670152749167755, 0.0462686217360897, 0.07904858328402042, 0.03783577951253392, 0.00984120752036688, 0.05641897922032513, 0.0662561392528005, 0.09330167042207904, 0.13101940392516553, 0.0747840765689034, 0.037447988797794096, 0.01999276635615388, 0.010708970185078215, 0.024503087224729825, 0.03716876315593254, 0.02949071851617191, 0.03652718020020984, 0.01846852304879576, 0.05569268381805159, 0.025625956659496296, 0.022289297812676523, 0.04494669345149305, 0.03867538602207787, 0.04212720392388292, 0.013164839820092311, 0.02483151725755306, 0.08271920858533122, 0.03674530111311469, 0.06512474996270612, 0.0735864728630986, 0.03617283065977972, 0.02284040554513922, 0.018761931132758036, 0.03981003334047273, 0.015538866337010404, 0.002542803654250747, 0.04782306117704138, 0.031878805020824075, 0.02783416141028283, 0.017448257385694887, 0.046114325523376465, 0.04131127192522399, 0.06079987695557065, 0.038261916997726075, 0.0452211841911776, 0.03148158160911407, 0.05852350594068412, 0.0467687810305506, 0.05844826329848729, 0.023802984069334343, 0.03496219855151139, 0.0460540297353873, 0.05681008362444118, 0.0069800046549062245, 0.05577257230470423, 0.012546964771900093, 0.046602755173807964, 0.03542827100318391, 0.013523659872589633, 0.01863773271907121, 0.06973022158490494, 0.07754047983326018, 0.0557710509019671, 0.02377073404204566, 0.024660019917064346, 0.02487626319634728, 0.05759215142461471, 0.04383828476420604, 0.033969594587688334, 0.05613975728920195, 0.03674706742458511, 0.06951544404728338, 0.08205374702811241, 0.05152761375939008, 0.052408591291168705, 0.022251086484175175, 0.05713202728657052, 0.018734080185822677, 0.07352651475230232, 0.05116554217238445, 0.07364260891336016, 0.05798047648568172, 0.01717791525152279, 0.049379545234842226, 0.02303687244420871, 0.042643519773264416, 0.07837315468350425, 0.03041495398065308, 0.022667757875751704, 0.005405450228863629, 0.03850421337119769, 0.032492653917870484, 0.020747042581206188, 0.044399860489647835, 0.07631037748069502, 0.0168128249788424, 0.02404310038400581, 0.041399776746402495, 0.05489539456903003, 0.047352880937978625, 0.0377918740559835, 0.061921518135932274, 0.02434265159536153, 0.06086669622163754, 0.06884313246700913, 0.04384375068184454, 0.03433508376474492, 0.03514541625918355, 0.024928091079345904, 0.02456354814057704, 0.030520841755787842, 0.027119614205730613, 0.0032414712177342153, 0.09124831849476323, 0.03096408017881913, 0.06229459948372096, 0.025982541919802316, 0.04987954867829103, 0.016775170261098538, 0.03480367951851804, 0.025424203813599888, 0.03239720259443857, 0.007202561755548231, 0.031911741534713656, 0.017866112502815668, 0.09149549819994718, 0.027411948030930944, 0.04472708453249652, 0.08663359971251339, 0.01327811567534809, 0.050145653149229474, 0.04453158428077586, 0.038360678299795836, 0.07752923629595898, 0.036563482353813015, 0.041253748058807105, 0.021875140446354635, 0.024486537331540603, 0.03578056479454972, 0.08607114083133638, 0.02942698287370149, 0.04134677998081315, 0.052838198316749185, 0.038223232550080866, 0.007894953996583354, 0.04244378556904849, 0.04537729866569862, 0.07674240390770137, 0.028296521268202923, 0.05014085145376157, 0.050641326160985045, 0.029419594793580472, 0.021597595768980682, 0.07077317655785009, 0.037115855448064394, 0.05393660656409338, 0.05225536006037146, 0.03284009777416941, 0.08541934221284464, 0.017776218010112643, 0.03582772085792385, 0.04570166543999221, 0.05554241004574578, 0.027436130912974477, 0.05376871791668236, 0.02981299243401736, 0.007539008374806144, 0.010978916197927902, 0.05561695506912656, 0.05573526083026081, 0.025116446304309648, 0.023736242728773504, 0.043139192785019986, 0.03519463920383714, 0.020166881622571964, 0.03588704814319499, 0.067058927816106, 0.04306862196244765, 0.04691322523285635, 0.0572169067163486, 0.03492734729661606, 0.05911757289140951, 0.031106444512261078, 0.015564708846795838, 0.02316476860869443, 0.061104535998310894, 0.037852255190955475, 0.06321619846858084, 0.06106866800109856, 0.03302546028862707, 0.02332333959202515, 0.032220530629274435, 0.03358952220878564, 0.07033895337372087, 0.055694683906040154, 0.07305372215341777, 0.046969442919362336, 0.04883705754764378, 0.017011646341416053, 0.03042511954845395, 0.07867780630476773, 0.03876407638017554, 0.05296776245813817, 0.037184630273259245, 0.0816922023659572, 0.0667355814948678, 0.041548031877027825, 0.06977542579988949, 0.007335959089687094, 0.05777238569862675, 0.05455999948026147, 0.035390202538110316, 0.029482497375283856, 0.03454544552369043, 0.06850368896266446, 0.04379024925583508, 0.040785400924505666, 0.014042381208128063, 0.05508232301508542, 0.07355041190749034, 0.004798120171471965, 0.016817923533380963, 0.060322475619614124, 0.12030847632559016, 0.03851541980111506, 0.010220321601082105, 0.018617212335811928, 0.03498283025692217, 0.04474298875720706, 0.015836939746805, 0.057701529149198905, 0.033245314116356894, 0.03972450453147758, 0.04368318332126364, 0.02541158359235851, 0.04817901746719144, 0.005687487682735082, 0.08510556217515841, 0.03869338681397494, 0.03793177260376979, 0.026516912366787437, 0.018691421537369024, 0.08679200371261686, 0.06772362496121787, 0.026192968616669532, 0.04171975371718872, 0.02981494428240694, 0.020513499839580618, 0.018356438340561, 0.05127156910020858, 0.01814090195694007, 0.04649256850825623, 0.04136624280363321, 0.08439053999609314, 0.1453962887171656, 0.09293841882026754, 0.15171380597166717, 0.1652835903223604, 0.10153964321943931, 0.13261000451166183, 0.12635007791686803, 0.21727530984207988, 0.16601039038505405, 0.09603004276868887, 0.10420450998935848, 0.09996807872084901, 0.19040666957153007, 0.13922124897362664, 0.1324783920426853, 0.09708222263725474, 0.19731029053218663, 0.2635071915574372, 0.14976739010307938, 0.10732921888120472, 0.23726088664261624, 0.12883029092336074, 0.13069138949504122, 0.13171659229556099, 0.061471865701605566, 0.13206951320171356, 0.13050073175691068, 0.13300450053066015, 0.12879618181614205, 0.13509118231013417, 0.1595720514887944, 0.10676405116100796, 0.11389787148800679, 0.13958694966277108, 0.07702685426920652, 0.15755913918837905, 0.12920912762638181, 0.20987161493394524, 0.14566497586201876, 0.11047567269997671, 0.08828113044728525, 0.18383993912721053, 0.07085559947881848, 0.1477298533427529, 0.08371899282792583, 0.15160140028456226, 0.10331534285796806, 0.1562677280162461, 0.19164102443028241, 0.10400293525890447, 0.20292264875024557, 0.11910545494174585, 0.186762397934217, 0.19253465929068625, 0.09079730050871149, 0.23346066009253263, 0.07465370348654687, 0.20338469505077228, 0.16541508404770866, 0.20122473360970616, 0.20503094187006354, 0.1792376587400213, 0.13414415734587237, 0.12220505697769113, 0.15688596671679989, 0.14794758462812752, 0.11165941308718175, 0.1716255390783772, 0.16850357613293454, 0.11719958260073327, 0.11331605739542283, 0.20186315872706473, 0.09250945746316575, 0.1898307926603593, 0.16259634779999033, 0.15957365452777594, 0.08944858069298789, 0.12354366132058203, 0.11006041881046258, 0.11417965753935277, 0.24331969121703878, 0.08020150227821432, 0.07715261861449108, 0.15088310523424298, 0.15777171996887773, 0.08638008948764764, 0.1557343316380866, 0.11316506002913229, 0.09890290384646505, 0.17712924687657505, 0.18526520405430347, 0.24374342785449699, 0.13098045601509511, 0.1268024614546448, 0.1153279232676141, 0.10100753075676039, 0.13893434952478856, 0.1361733375233598, 0.18288715509697795, 0.17288422153797, 0.14174262149026617, 0.13717730005737394, 0.1183995240717195, 0.16948462114669383, 0.10524853365495801, 0.15071876405272633, 0.15741689916467294, 0.1424994636909105, 0.1320321683306247, 0.1445043459534645, 0.2747317298781127, 0.1120341382920742, 0.12303146068006754, 0.09129000492976047, 0.11485381706734188, 0.13329285458894446, 0.12863200390711427, 0.15457416186109185, 0.18246487306896597, 0.09582605605828576, 0.11074890921008773, 0.159031500807032, 0.23797676229150966, 0.18283545708982274, 0.15825531823793426, 0.09285506821470335, 0.31013178813736886, 0.177966374612879, 0.12846552534028888, 0.14742003637365997, 0.1131498311588075, 0.16354199236957356, 0.11194799721124582, 0.13777935993857682, 0.17113854177296162, 0.23940061713801697, 0.1527672549127601, 0.13731398881645873, 0.1826840589637868, 0.15307744295569137, 0.17649067332968116, 0.07481642678612843, 0.13467483746353537, 0.0418199065461522, 0.149060316325631, 0.19764551863772795, 0.1728347796597518, 0.13419968483503908, 0.16011865809559822, 0.14102276792982593, 0.10319579771021381, 0.06655535093159415, 0.1758665419765748, 0.09989243160816841, 0.12345300798187964, 0.2532324241474271, 0.09282161961891688, 0.15047097578644753, 0.14485958236036822, 0.21184927521971986, 0.13545542838983238, 0.12728231929941103, 0.12334728904534131, 0.09092506865272298, 0.20597354363417253, 0.14090826938627288, 0.20246257656253874, 0.12176892647403292, 0.13313817617017776, 0.21919402875937521, 0.16823420621221885, 0.0869058194803074, 0.15155320521444082, 0.11116133551695384, 0.10473757240106352], [0.03935213935619686, 0.018134307974833064, 0.05657421424984932, 0.056063100855681114, 0.015157754023675807, 0.006102670140535338, 0.029169175613787957, 0.08996060321805999, 0.020571608147292864, 0.023929447888804134, 0.042487839455134235, 0.0067088206469634315, 0.0462604098720476, 0.017856668673630338, 0.011612145353865344, 0.02537555974413408, 0.024418280154350214, 0.023150729030021466, 0.015342956048698397, 0.05419810229795985, 0.04066245302965399, 0.036296075413702056, 0.0611978870438179, 0.14003860589582473, 0.024935193432611413, 0.032190336351050064, 0.023558036373287905, 0.04490833554882556, 0.02852402478310978, 0.0575243191269692, 0.047657309914939106, 0.07503951637772843, 0.07191736047388986, 0.022424240669352002, 0.029216535767773166, 0.04576953113428317, 0.042741294018924236, 0.015128671111597214, 0.03315541034680791, 0.03947136538045015, 0.04481139621930197, 0.03987941672676243, 0.048108420669450425, 0.07754194186418317, 0.034185941767646, 0.028322344296611845, 0.05780928899184801, 0.01112949332309654, 0.02772163883491885, 0.018351959479332436, 0.050469385387259535, 0.05663844713126309, 0.04571364741423167, 0.018180211664002854, 0.031156398472376168, 0.014927101947250776, 0.05198196027777158, 0.014919896620995132, 0.05275766416161787, 0.03709271157276817, 0.022624028679274488, 0.03515360214805696, 0.06488757440820336, 0.030514052959915716, 0.012478431144700153, 0.08486631602863781, 0.011613910737651167, 0.09484591646469198, 0.02844473743607523, 0.031130119023146108, 0.04310279786295723, 0.023013940081000328, 0.04378979283501394, 0.028829695002059452, 0.07365504730842076, 0.0447037180128973, 0.04288310359697789, 0.08385816036025062, 0.10311366422683932, 0.08098607111605816, 0.0621677516028285, 0.035874453897122294, 0.017696887989586685, 0.040796188040985726, 0.04966165040968917, 0.0566704708035104, 0.028237782134965528, 0.034351978756603785, 0.04472730346606113, 0.012433630472514778, 0.014619258163293125, 0.0179697051862604, 0.05581026227446273, 0.02767438072623918, 0.04499201269936748, 0.029546201476478018, 0.039305602986132726, 0.041596160153858364, 0.00416754280195164, 0.0068957050280005205, 0.015325833774113562, 0.024266160289698746, 0.029435981414280832, 0.02615393907035468, 0.010553002284723334, 0.009865303200058406, 0.03284626131062396, 0.05296243754855823, 0.018660301429918036, 0.03353149368194863, 0.010980356892105192, 0.022210210845514666, 0.03629005659604445, 0.02771392977592768, 0.009666974438005127, 0.04692145193985198, 0.01780054375558393, 0.03854284957924392, 0.06365638109855354, 0.10236178699415177, 0.04624428300303407, 0.07232805757666938, 0.02436447815853171, 0.06403707317076623, 0.05759984749602154, 0.00853022498631617, 0.03885060708853416, 0.023483339209633414, 0.07302414014702663, 0.06587379961274564, 0.023427490741596557, 0.01663248309341725, 0.03583055215131026, 0.019817656611849088, 0.01996692477405304, 0.026542110135778785, 0.02209667523857206, 0.016487324573972728, 0.03177615857566707, 0.014763499202672392, 0.07076388486893848, 0.023577729261887725, 0.046746193766011856, 0.07691683087614365, 0.06303852089331485, 0.03789767091802787, 0.060450280871009454, 0.05925602054048795, 0.023148881082306616, 0.030683171717100777, 0.06154659255116712, 0.024965356169559527, 0.015082632908161031, 0.05650433733535465, 0.007592617876071017, 0.07476240585674532, 0.04445921003934927, 0.04120786477869842, 0.013323878356459318, 0.023181071737781167, 0.016209252971748356, 0.04188474798866082, 0.03464807341515552, 0.014273803262767615, 0.05452619836432859, 0.02200502927735215, 0.028478404965426307, 0.036818565931753255, 0.05913212269661017, 0.06184742211189587, 0.023078994890965987, 0.07184868212789297, 0.02687643838726217, 0.03048177695745835, 0.04595393627823796, 0.03197685757186264, 0.020353056788735557, 0.08133827956044115, 0.03460516243649181, 0.015135711309994804, 0.06924053770489991, 0.008629912117612548, 0.08284322146209888, 0.07080094030243345, 0.06954763099201955, 0.020161363754596096, 0.05646134843118489, 0.011611700065259356, 0.020041842726641335, 0.09881696314550936, 0.03335834320751019, 0.00755257390665065, 0.050525465776445344, 0.04891616677923594, 0.004958420358889271, 0.046046470961300656, 0.027731767295335885, 0.03557509007805493, 0.08523896322003566, 0.028470469551393762, 0.03282760000729468, 0.05300445423927158, 0.026795585108629894, 0.03285268088802695, 0.05260698962956667, 0.018296161106263753, 0.030997710600786377, 0.04373398332973011, 0.07192936100182123, 0.019351153714524116, 0.02751457221165765, 0.08006672083865851, 0.03938362868211698, 0.011327692209306406, 0.0813565289718099, 0.03136749495752156, 0.010411118491902016, 0.10256172899971716, 0.01163015727797756, 0.05884316378796939, 0.031129128255997784, 0.05861697572981939, 0.03198328828148078, 0.03673489991342649, 0.032270451192744076, 0.017098017488024198, 0.0427439360646531, 0.012224035908730002, 0.054665310235577635, 0.03814436451648362, 0.028308737018960528, 0.019651922048069537, 0.08158407887094654, 0.058183613436995074, 0.07473192585166544, 0.02221213300799718, 0.03418060943658929, 0.0714523158967495, 0.07990342608536594, 0.09218220744514838, 0.0398736910574371, 0.010521804251766298, 0.020756625563080888, 0.028626096063817386, 0.021328045877453405, 0.029765652689093258, 0.05230751819908619, 0.01002558854452218, 0.016406224531237967, 0.05843962469953112, 0.0619751160411397, 0.04590598611684982, 0.03878595860442147, 0.04439738542714622, 0.07195572950877249, 0.087023383093765, 0.02434523241390707, 0.036686845851363614, 0.09840583559707738, 0.04557905522233341, 0.059817726141773164, 0.07123802075511776, 0.016602227588009555, 0.01762611307640327, 0.024301620105688926, 0.014294370957941283, 0.018753027216007467, 0.010398829454061342, 0.031180655569187365, 0.018402672285446897, 0.06281279667746276, 0.056215649310615845, 0.005105929167257273, 0.008525752618879778, 0.017922985134646297, 0.004823468689210131, 0.08659900078782812, 0.01862258548499085, 0.028530479612527415, 0.04877684339589905, 0.05908967556024436, 0.012686482041317504, 0.11920974153326824, 0.005910164454689948, 0.049459118308732286, 0.029149334295652807, 0.06288425807724707, 0.022740523600077722, 0.06689673144137487, 0.04518968744378071, 0.015719721232017037, 0.04126022329728585, 0.04089988462510519, 0.05063183780293912, 0.030999155933386646, 0.07743732130620629, 0.0634732042090036, 0.060703861599904485, 0.010997355784638785, 0.054580022624577396, 0.018713663703238126, 0.013994877263030503, 0.02356593653530581, 0.030624749851995148, 0.07337289760471322, 0.008416669897997053, 0.022523117004311644, 0.06079995117033832, 0.047977999347494915, 0.03722323679539841, 0.028769267482857686, 0.08287566073704511, 0.049772853817557916, 0.08219243216444738, 0.05390861275373027, 0.024942726231529377, 0.07358519636909477, 0.020066094257344957, 0.03559425975254271, 0.03862844518152997, 0.09452594691538252, 0.04527053330093622, 0.05746375616581645, 0.053772347018821165, 0.016856563452165574, 0.03282411562395282, 0.028953351647942327, 0.018708611532929353, 0.01819973756937543, 0.02257392814499326, 0.03471162352070678, 0.05606924954918213, 0.010509773110243259, 0.01632912095374195, 0.03455819191003684, 0.05150828081241343, 0.008874196519172983, 0.015448007052327739, 0.03803090126893949, 0.06936685123946518, 0.052925734635209665, 0.019078869008808397, 0.01762440057063941, 0.028362793200358283, 0.015669963941036258, 0.08220647359848954, 0.002859386227100913, 0.0327661130722845, 0.06662900908850133, 0.0027624276481219567, 0.021325624620658346, 0.020871138949587476, 0.11785632392275147, 0.2504815498832613, 0.13638099044328555, 0.132182379020378, 0.23422744707204401, 0.1591183469281532, 0.1506618710118346, 0.19200406823074445, 0.1688538253074512, 0.17199517315020785, 0.1429488934809342, 0.11047060383134522, 0.18485619162674993, 0.16974337835563347, 0.10557074449025095, 0.1142892727511935, 0.0861780323612038, 0.14844219636870548, 0.08572856546379626, 0.12642748391954228, 0.12216544113471173, 0.1101573507185094, 0.13487561809597537, 0.2055157721042633, 0.11029980596504174, 0.16992910823319107, 0.09232409865944646, 0.125770712911617, 0.23077692050719634, 0.16590743965934962, 0.1104153435153421, 0.23604751972015947, 0.13032040471443906, 0.12958547071320936, 0.06734455819241703, 0.17289867857471108, 0.15096751711098477, 0.17537788226036355, 0.1435432498692535, 0.08612674995674752, 0.14420831808820367, 0.3167248796671629, 0.1411826562252827, 0.17115302849560976, 0.17126451391959563, 0.19463688164250925, 0.12423963999026455, 0.11914135262486525, 0.1513160890317522, 0.18172732670791447, 0.11426985074649565, 0.09553001335007139, 0.17921825899975374, 0.08999334677355364, 0.17321680759778246, 0.10710645583458245, 0.20513595576630905, 0.17576794023625553, 0.16986635222565383, 0.10503110665013082, 0.09811959665967152, 0.12902538670459762, 0.14733779156813398, 0.11259189195698127, 0.16286684578517452, 0.1318253466160968, 0.13136193476384506, 0.2122440532548353, 0.11140251124743372, 0.095104502979666, 0.13044702995102853, 0.12801107863197103, 0.11000905476976186, 0.15036097465781495, 0.17836723825894296, 0.1298429662710987, 0.1484189968323335, 0.240256936813239, 0.15817090636119246, 0.1592157018603757, 0.10323039663489908, 0.15831457130843773, 0.13133471278706565, 0.15554834943031892, 0.22395324369426817, 0.10358130632084794, 0.17725327459629625, 0.10063073495985009, 0.14043522445717826, 0.08700486650923267, 0.14887381461448967, 0.11728332654456608, 0.1072929278598167, 0.11113523418316618, 0.13748668658081442, 0.16241517470916733, 0.121034571347991, 0.18648155441042036, 0.08626991766504943, 0.06180395823321305, 0.10590343445073813, 0.1384848158340901, 0.10369478812208399, 0.1722040877211839, 0.17449178762035444, 0.09248814298189245, 0.18703098117839545, 0.14330242294818163, 0.14628631673986092, 0.10708184621762484, 0.17420960823073983, 0.1474022545153275, 0.11388137354515493, 0.09985985874664038, 0.21797926659928635, 0.14645269140601158, 0.135915856808424, 0.12674393568886444, 0.1883611621451564, 0.17203176103066653, 0.1619463600218296, 0.16268347593722865, 0.11157475630170666, 0.1392168999882415, 0.12071811215719208, 0.06399215097189881, 0.1483024054323323, 0.07280927355168387, 0.2534899197053164, 0.2133737356052734, 0.08401809318456799, 0.13231927558081225, 0.13002068095374852, 0.1233415596652776, 0.14847995684249327, 0.12929080839967355, 0.1045587073895149, 0.1663337292848155, 0.09436555395950563, 0.10088932889630087, 0.167400952486787, 0.1014857113477774, 0.1268038121634163, 0.11549739268957637, 0.15998526447219774, 0.191572331241332, 0.20989956421544775, 0.20667760429205373, 0.1070361521851737, 0.28621450590435416, 0.13951049360912293, 0.10001242204452865, 0.1480890973471105, 0.15436319896252826, 0.1299561289488338, 0.1844575395807624, 0.14148197922622785, 0.16310097853420302, 0.11289509639027528, 0.16612917854217812, 0.16567204525927082, 0.14333479542983696, 0.09458691434701905, 0.1586047955788672, 0.11937542600207962, 0.1312554514151998, 0.10451951457071118, 0.1463991974014789, 0.19981909106718376, 0.14532520581269637, 0.07952876767376438, 0.12395956087857485, 0.06917430102475919, 0.19311739364638925, 0.20100939203985035, 0.18962484668008983], [0.03043146491108928, 0.06660495608230121, 0.030548134236596525, 0.04928031637973618, 0.025133062990789767, 0.04632540345482994, 0.022911584928806406, 0.0590336730965646, 0.02242649679828901, 0.07494210949516855, 0.025299977569375187, 0.0647697584645357, 0.026875896619458217, 0.04791707644471899, 0.08138626682921313, 0.07053338864352554, 0.036210086473147385, 0.06852073609479703, 0.010775671635201434, 0.08528661652235314, 0.016927770666370634, 0.013980870153318392, 0.044139763704151846, 0.03724452530150302, 0.0353746025939472, 0.013665413789567538, 0.036848700838163495, 0.04309253767132759, 0.07169982956838794, 0.06996220210567117, 0.0646764705015812, 0.07863593433285132, 0.02829306471539894, 0.009416699049324961, 0.02582873923529405, 0.028159331559436396, 0.031861683673923835, 0.015028006200736854, 0.0490043710306054, 0.04930738250550348, 0.052567199381883256, 0.03702839705510996, 0.006036994709575083, 0.08521211973857135, 0.02625106764753582, 0.008458584543404868, 0.025151490517600905, 0.020727002738567535, 0.03445279951847624, 0.01731631280563306, 0.034581632644403726, 0.039754097670083866, 0.05786918402009178, 0.024358479749935213, 0.03771786708966829, 0.02054945689451415, 0.059984226973028854, 0.008708204059075797, 0.04425926803378388, 0.0037932267059659353, 0.09438735083676875, 0.030605229512730148, 0.021115322233526967, 0.06621638240176253, 0.0394814697210677, 0.03725280024809763, 0.01534796832856955, 0.03944301533920225, 0.014389420593943214, 0.06178805029776413, 0.00840807675558608, 0.018206249915238004, 0.028562406805576757, 0.02265662380523281, 0.056884558143792674, 0.057753665023483336, 0.0054576125421590405, 0.021279654138197657, 0.03388822922715917, 0.07239551880047657, 0.031090638622117694, 0.044868541590403765, 0.013982460204715608, 0.01489475080234115, 0.02022201762883924, 0.035064269832219, 0.03006627444847254, 0.016378470063500572, 0.04970216425135732, 0.033973323879763484, 0.06678090445348062, 0.02500769383914303, 0.04700574507296551, 0.05455070408061147, 0.025692113558761775, 0.05082918971311301, 0.029269543665577658, 0.0493892673694063, 0.05963117990177125, 0.04483642886043526, 0.12594669096870348, 0.04060599414515309, 0.07594165625050664, 0.019669822650030255, 0.05676171414961573, 0.07567304332042113, 0.024363888151128776, 0.006519518256027368, 0.028141796465206426, 0.010191772107646102, 0.04208781443594489, 0.025345376598124858, 0.06505406781798229, 0.03432198485825211, 0.08816781191853806, 0.05712208250770345, 0.03241158541641198, 0.02585892980278004, 0.04414937451656442, 0.07436575018800795, 0.025646829562901985, 0.03422966168727726, 0.029882210692449007, 0.06492012500530109, 0.05944182092207484, 0.053442855714820325, 0.01088542692741612, 0.019293455443403218, 0.024852661044860724, 0.0945612508803606, 0.06453935871832073, 0.014527322764479322, 0.04269603785360232, 0.06701462902128696, 0.06033238329109736, 0.04431620560353622, 0.10100090337800793, 0.04473353750654496, 0.03124240225588437, 0.06531133331009187, 0.07812627183739096, 0.016343848874385003, 0.03176950151100755, 0.022740569984307513, 0.02948397239379119, 0.035536275754566304, 0.02344062118936563, 0.058516444405540824, 0.02110747587721562, 0.04281328234355897, 0.012420410967024509, 0.020308642961026635, 0.04766664613271132, 0.05830298046930693, 0.026180589593423065, 0.057335234741913155, 0.0379721602803329, 0.005191922746234923, 0.012584014639287489, 0.01606798145076027, 0.11002056548022665, 0.009298257846239721, 0.043218454156885855, 0.05520496291865129, 0.049984269426204264, 0.027699591482814867, 0.08993205279693939, 0.02744369710853789, 0.0448956670879852, 0.05432750687759835, 0.0183787027708604, 0.053047008987050503, 0.02412758462014608, 0.038179141556611285, 0.029606254211103078, 0.031510822227573954, 0.004403930752232554, 0.03341392264701426, 0.013266548376122955, 0.04282574671378825, 0.034898455487564206, 0.05424291317467578, 0.06826335928053595, 0.0600524934270652, 0.017832198209362105, 0.051615305928862654, 0.027014416627935134, 0.032957271760096774, 0.02380453144724015, 0.05124920076923445, 0.0674162273935508, 0.03310573098133318, 0.012631161425815662, 0.03202636624337174, 0.03936816974601243, 0.017544482398079708, 0.010093060900544515, 0.020946697004546877, 0.03340210023452528, 0.033847262675408274, 0.014546156617143424, 0.05209177215874661, 0.025069945186260156, 0.07199020226835273, 0.06536327622598037, 0.030460735215456225, 0.009145948733930709, 0.11475108156446368, 0.03958527020586189, 0.012248176117282128, 0.023382401559501886, 0.007267367482199916, 0.06080938757804688, 0.015396870294352993, 0.031503879436058924, 0.03384695839486085, 0.07229719907627441, 0.054768991976743564, 0.020684965638793074, 0.02601155618322082, 0.0395148886309471, 0.010366845672251657, 0.06132414120656904, 0.06715220835758373, 0.0612921026913682, 0.017592582844372373, 0.0187732043559663, 0.03775297067477368, 0.04093537412700243, 0.0026692164510677685, 0.052173649601172656, 0.05387905301176943, 0.07382528114248998, 0.04592055447574239, 0.03643139119958505, 0.08079438179265708, 0.05155433478648774, 0.032025935797719285, 0.042214361747028306, 0.08664098408189602, 0.03891749685863033, 0.0070380967281380435, 0.037019862356828526, 0.010745018153102137, 0.02659455029061064, 0.07423890972859226, 0.040468989973305725, 0.05811837865621783, 0.02404476465017069, 0.02320639010576997, 0.07578643606393598, 0.0333194991981145, 0.01929856327478774, 0.017711818145471625, 0.02949053668999113, 0.012956752743775724, 0.017811347570386715, 0.018851831191568635, 0.03730278760485817, 0.032615468226140365, 0.04913524506264366, 0.042813026302610524, 0.016163714790309314, 0.053768606594530866, 0.006590371094716829, 0.038477614798466675, 0.03901209100149572, 0.04897271101071965, 0.09039924218086526, 0.009108374724746682, 0.03969620644056704, 0.03987983232946135, 0.07563276696600951, 0.025403208455827553, 0.06521092815091833, 0.015274152465281077, 0.046141810962581076, 0.04014412967080716, 0.02359218073252123, 0.039492943324148655, 0.023204833451018203, 0.037756777892354876, 0.055392403446603566, 0.019466366575215943, 0.0068859397561027436, 0.04014025194919668, 0.01417862838934525, 0.042665034634410404, 0.03728089795913547, 0.05215915174630936, 0.04900887215626426, 0.038217529145185836, 0.01714134221401764, 0.03870879751048051, 0.04078714868228417, 0.030732220257050358, 0.028117045840190258, 0.023176835929916706, 0.043406139593571424, 0.04536827043921221, 0.07991185688297264, 0.059969814465148374, 0.04413667265907861, 0.013492721591319423, 0.039531227012048475, 0.02258329219330335, 0.04617154139850754, 0.024456641767756082, 0.07621339362231083, 0.00980223085207399, 0.04384124964417424, 0.05939200797001831, 0.05867498570296448, 0.05294612514262553, 0.027350028794899117, 0.12449227448087186, 0.04889774296316318, 0.020362751092761755, 0.07124618437956087, 0.00620646181232587, 0.0862635277735535, 0.01550411805510521, 0.045762031732010655, 0.031159875434241258, 0.04716051997093018, 0.043762003115261905, 0.008491772459819913, 0.007915618170954986, 0.07932537468150258, 0.058667430639616214, 0.013093990692141233, 0.018539693155616987, 0.014543760407832451, 0.007129807627279661, 0.01799521836801432, 0.03172001139319036, 0.09592903646989726, 0.0688688553054817, 0.02359655383770587, 0.04587468232784886, 0.0721688149496913, 0.031361902874778025, 0.018379669418209232, 0.037246391802909784, 0.04978675424354151, 0.04418243719555903, 0.012135386368754553, 0.0034552199531390215, 0.04498799396969844, 0.03630279185017571, 0.07454439255525358, 0.030395531975955237, 0.18487440393073484, 0.1354517473373562, 0.11036493684514426, 0.1449017511913553, 0.12528212741017342, 0.12624737952137366, 0.08278229113784619, 0.15377645700937137, 0.13762827351456508, 0.18270035652676597, 0.08232634529122151, 0.12995598051929846, 0.10811735744937323, 0.08143233935697936, 0.24523563450202346, 0.1188643831119407, 0.07150189878302626, 0.18477963167242706, 0.15321932674851269, 0.1853764965198934, 0.13155067776096985, 0.1744703543954529, 0.12967773451237008, 0.09445483432500623, 0.16742847132263705, 0.13951257162261754, 0.16263614175841212, 0.21679668396245688, 0.1353815253241919, 0.12764221639372408, 0.12980876810615882, 0.2789379854220897, 0.10598476641462184, 0.12396938691381365, 0.10429239511722699, 0.04385219632240478, 0.1709991812822409, 0.13109792314935476, 0.10977884056046605, 0.11730297861504368, 0.14474198163952678, 0.1810417603701353, 0.06538490983075462, 0.190605609677732, 0.08765475780819543, 0.1747353159589693, 0.1737065360066481, 0.2526375185698271, 0.11422075767768547, 0.09826182184042409, 0.09109516890021041, 0.16943495662417263, 0.1468995978939347, 0.07952855245093815, 0.2040308088180609, 0.14907308126566932, 0.1538630508002825, 0.10114079079357907, 0.12672564917011186, 0.1379347953479737, 0.20075106527656317, 0.14225290738977492, 0.15456288121640682, 0.21732343069743365, 0.23324754496570677, 0.14329678262583911, 0.13272475538542494, 0.13898315315600485, 0.12762053083861247, 0.18203456100309268, 0.1494556583929807, 0.15564552624709904, 0.09641270153224468, 0.14239722542697564, 0.21125423605553806, 0.24256096396129578, 0.15819564956473187, 0.10887273019761778, 0.09203702109516598, 0.1573814096627757, 0.17816599749494344, 0.11153195664519444, 0.10895699364482425, 0.12980150990188122, 0.15229287411784753, 0.16754291049437597, 0.0986344541888684, 0.12064736321917735, 0.08860103320330381, 0.27366404654458165, 0.12233891073265113, 0.1341807600692846, 0.1600687560858205, 0.1332707385881804, 0.07499394851038232, 0.13163575757062063, 0.17680304328678176, 0.17054469004506245, 0.10003490911913104, 0.1730708419927396, 0.2983827592106536, 0.12127040361519903, 0.21348473121179268, 0.11226668284507468, 0.13468730554450303, 0.2731959888478741, 0.11262240906944498, 0.0931407579628285, 0.09613811431336217, 0.1175922380934935, 0.09079213516088203, 0.1328079352970235, 0.16078623477369547, 0.16747767571359873, 0.2038576063932851, 0.10553358515608124, 0.20957252942025661, 0.11945396006922238, 0.09918375479173847, 0.19034762430237606, 0.13373857364058495, 0.10770386987132952, 0.11053869588067755, 0.12218722316902131, 0.11424417985836044, 0.11673188855638728, 0.08617850733571686, 0.08250712504377589, 0.13099255302222446, 0.21535299893002957, 0.140548683993984, 0.0824866714538075, 0.12476631993195042, 0.12317760440055281, 0.11540924781002104, 0.1670928721432574, 0.18893035972723737, 0.14693942153826356, 0.1909051404800266, 0.20343289012089372, 0.237413783906959, 0.12457978853490204, 0.16100323875434697, 0.10090737792779692, 0.24425797368166968, 0.11803224260802381, 0.11167041913722642, 0.12068694195477292, 0.12101091168005951, 0.13750883226748556, 0.06996067328145728, 0.08847155069815926, 0.1443779285182245, 0.157015590230003, 0.10669505369151011, 0.25880099565256387, 0.12937617022544146, 0.10815011584782042, 0.15290744660887867, 0.10000232141464949, 0.2842783910455182, 0.08681374121806584, 0.11155200205394067, 0.17601342784473673, 0.14596146385883912, 0.08834272870444693, 0.15404198260512203, 0.18645517848199233, 0.11594536787015386, 0.1477005088236183, 0.10636561433784664, 0.1738921322976239, 0.12225494414451532, 0.16171785275219008, 0.1017533297999762, 0.1782353883027099], [0.06400061887688935, 0.05291046865750104, 0.0201135360475746, 0.01324470975305303, 0.017853176868811715, 0.053811191028216854, 0.041785088687902316, 0.0824955698044505, 0.030968798382673413, 0.027103984575660434, 0.03155388534651138, 0.05049066647188738, 0.04141388497373555, 0.02446813949063653, 0.05419895576778799, 0.02148195060726721, 0.06868771190056577, 0.008904571695893537, 0.02325566871149931, 0.03294290378107689, 0.007664080667382223, 0.01690189012151677, 0.01892537246021675, 0.025033681995410006, 0.022263087012106553, 0.053535820843535475, 0.022872201006975956, 0.10290543985320255, 0.04316235521400813, 0.040354691809625365, 0.044302902606432326, 0.05125924202729948, 0.021875069942325354, 0.011126053468615282, 0.07891738641774282, 0.02823850572895026, 0.026703807416197378, 0.02292451314133359, 0.040443445250275545, 0.05593711757683195, 0.06762804376194254, 0.0692174791765865, 0.06848656761576422, 0.006021154495101655, 0.033784157858463004, 0.044765665079467, 0.032515582570340484, 0.10539061782765202, 0.01885774610855151, 0.03603427168854978, 0.06610443684621714, 0.011518494666233892, 0.008477185547235422, 0.03605603145842906, 0.01852419154602103, 0.06636811449425295, 0.0623288718634285, 0.12652759964112192, 0.035418192637735046, 0.04412232694448903, 0.0755094517080579, 0.07074401015415788, 0.03965345131291542, 0.014712777119711973, 0.02609047616715543, 0.027977221507171635, 0.01966421572433319, 0.04720842931419611, 0.03303571305877995, 0.031685256617492996, 0.017977447641897015, 0.04181929427431896, 0.06026174196449574, 0.010179245582548901, 0.04794909640622791, 0.08459110540570691, 0.055130480977823026, 0.03557490825187415, 0.04152437591983471, 0.03969795048760716, 0.02382231701631099, 0.05249290668871254, 0.03403045440791175, 0.028765866591129452, 0.017865604131657165, 0.08584467446780764, 0.02738559622230241, 0.014038095305295428, 0.014107976858213078, 0.007559590912933345, 0.05730663979193196, 0.02496125023753848, 0.08167396037606522, 0.08453845002804883, 0.08470471337204799, 0.023052160686347634, 0.08257390349172056, 0.017146386962849647, 0.055912689786055125, 0.04850086465012282, 0.02200740414991742, 0.07194863457698375, 0.014582496805815026, 0.014954542857594788, 0.03716670740686823, 0.035792598719126545, 0.01677386593655683, 0.02770717066596262, 0.05695448329788633, 0.03871988148603123, 0.01886018962977687, 0.008354014080396155, 0.045606225248775445, 0.05511538198334165, 0.03907719590642955, 0.049355020964867435, 0.03335773464641534, 0.07649318329640664, 0.02852423072909005, 0.0036488008254309534, 0.09670032086432911, 0.012317255223024404, 0.029168587461754214, 0.06930374642251991, 0.04024949979793746, 0.038282559835352004, 0.040517578381695785, 0.05323972989572212, 0.029225957332528196, 0.022611215499637183, 0.05532629293156788, 0.009324568836746039, 0.08169617285602726, 0.05700190653442405, 0.021079472790006548, 0.056286064282176085, 0.04141803728998639, 0.009037585896294331, 0.031967306131264195, 0.01769210855854908, 0.02865981554350583, 0.045335764370975085, 0.02054238793789409, 0.03885589860146865, 0.01897483474749606, 0.07293497852515429, 0.038212193103390746, 0.01536770574602997, 0.04787255129485857, 0.002222542580057052, 0.054164690809557214, 0.007945681645651348, 0.008446258398180362, 0.004823191311515984, 0.029171815804147627, 0.01208576730277855, 0.043463667170726694, 0.0540474388981238, 0.0027765889853981207, 0.03749117808183655, 0.014538213781634113, 0.054644114497932605, 0.07330914711928926, 0.009678080677986145, 0.024578715783718508, 0.008611703524366021, 0.055509421581518836, 0.05226661101914942, 0.04603055560437497, 0.060117976827314124, 0.10149486202863045, 0.01128014095229446, 0.04550285520963371, 0.11156105625559576, 0.009126373661274556, 0.07947231992147863, 0.003575856753741391, 0.02101034544466529, 0.05143522750586271, 0.027309275610605255, 0.028515469675767235, 0.03530038782628253, 0.036647816305048764, 0.09968284910428338, 0.0109222587889235, 0.04348381276940927, 0.042022564812214114, 0.047993903572205454, 0.0441922483878443, 0.04607556686096359, 0.009922033896145876, 0.03537422038789373, 0.06149681670649443, 0.03542756967362948, 0.026759379434224684, 0.03379067391506396, 0.049001005390891805, 0.09138580135186203, 0.06354511831887066, 0.062974926258903, 0.03110228291916428, 0.03160300439049024, 0.036872204655082896, 0.026520535902818665, 0.039688350807409734, 0.02881064221583074, 0.06272516387980431, 0.013956788388895802, 0.03176855156198144, 0.029139344987925142, 0.04508287012868095, 0.04055101213452872, 0.02166157075407682, 0.05673947569448501, 0.032589901238679886, 0.08249560691183433, 0.024532405768695753, 0.03509244546876289, 0.03196379948349204, 0.012496139715949539, 0.042401746613904834, 0.06165304992464371, 0.029408913433144335, 0.0669052661396563, 0.034662029502214864, 0.04716322509921156, 0.10905269358772784, 0.055692999230814166, 0.05969278186967131, 0.040189181745518, 0.059558660941547714, 0.06313900768873282, 0.03273913600423839, 0.06948410315089859, 0.0743502021941822, 0.041182642889907584, 0.06705298321321607, 0.04317024795454927, 0.005904946228838526, 0.050199395773233846, 0.05362860414606985, 0.06491562759038061, 0.06656251265667379, 0.008646971309644869, 0.06259573332499713, 0.04150794105953537, 0.03451877644693013, 0.05694700244930573, 0.01960049306944711, 0.01411336577803013, 0.027830446961161215, 0.03857583804347087, 0.01160160036306479, 0.06520652721519582, 0.08169580178218894, 0.03274169270298444, 0.011025762414647033, 0.0653856000280939, 0.02290987984451931, 0.023478027287637815, 0.0273884757552878, 0.08389652197365649, 0.046248338840086944, 0.004302161432860885, 0.05235018797975499, 0.048944739464786835, 0.04494704226090107, 0.04685572363086976, 0.06133277238404844, 0.02251060624985257, 0.039357427158392966, 0.02026860965997912, 0.032661117729730904, 0.056874312795116566, 0.02782220170047367, 0.062153305698302574, 0.015397354545712005, 0.018091215169988573, 0.017637022647249978, 0.04576546045427676, 0.06939794722711667, 0.017302045016549528, 0.03008931813383242, 0.011641893415799132, 0.0812114762084093, 0.05112108381581493, 0.005415557352534961, 0.010977862348227063, 0.05044090547016822, 0.013633365997520741, 0.027939327446802054, 0.05666434808517806, 0.04022704240924213, 0.03853469337627757, 0.02649964444572106, 0.02495857850590255, 0.0394274005520856, 0.01855644899478648, 0.050508678395999596, 0.0417417806602316, 0.07935554298455827, 0.0034250525777679286, 0.06201124007930048, 0.014863079650240252, 0.07591186644276604, 0.017413853274774738, 0.03317777125630528, 0.027810423816845287, 0.11891582136740908, 0.05307000072207302, 0.023385839558613952, 0.030163284282025415, 0.054267225932562724, 0.04035569741972722, 0.019085685635218397, 0.043847279594046995, 0.032557009253650904, 0.03204845626896713, 0.005866870806130464, 0.06442585465265438, 0.07530197690357454, 0.09571427377522923, 0.04484422883251682, 0.019845147617161274, 0.10050464406958781, 0.02030612336966442, 0.02280158380017383, 0.004224720178171992, 0.024700335234228987, 0.05375656153773889, 0.04489116225158796, 0.015586782174068503, 0.0507992255006684, 0.05072494765045121, 0.03250981608289294, 0.055892826203489676, 0.02543051577958977, 0.06317276056506671, 0.009277782919525634, 0.028909913744428195, 0.06892338089528494, 0.05787384099676274, 0.01915807657496771, 0.0484142894129036, 0.04338708124123514, 0.01556841772980988, 0.04480175572098233, 0.009978540092561161, 0.035612854262581095, 0.02371178154135123, 0.033896470777108334, 0.04891164709988516, 0.08752100795391016, 0.1350648805964738, 0.0945376357412897, 0.12632634403416887, 0.12639569031307474, 0.13229444331955165, 0.11337599324178882, 0.20606837526429445, 0.07379200324066915, 0.16573434113524854, 0.13969709922093898, 0.124443775130203, 0.12369097021291964, 0.162826725281775, 0.12179461962659843, 0.07771387521643192, 0.18239675875520334, 0.10456159434397705, 0.07037228322587907, 0.11830459596239962, 0.08231142070144415, 0.10003979987232015, 0.08557802822906524, 0.15742866962682456, 0.09506117639830336, 0.16216551623074338, 0.15068924141814932, 0.1664626254932955, 0.13728442165302113, 0.08365153160411865, 0.17457223642850295, 0.16143436718266457, 0.20530031179077923, 0.08726544940145686, 0.20850098691880703, 0.18179504026193172, 0.08897261170204729, 0.2433798200218007, 0.11824190674815327, 0.19337545323651284, 0.11985546196228825, 0.17098371492465958, 0.1744193836930208, 0.1172973976645153, 0.11652087370748632, 0.1467646606033668, 0.11034108421881683, 0.1822087133768946, 0.17807938886107877, 0.09706607350381091, 0.30458185938186944, 0.18077541841194034, 0.16021764575270936, 0.1302005775505677, 0.1490529245347716, 0.20805004314752296, 0.15415783185744658, 0.26089403021615, 0.13030547270318493, 0.14113305107457563, 0.19080980418948457, 0.16054537816671655, 0.1979074819246307, 0.09351409535156563, 0.12304329051403329, 0.2380798020749353, 0.2615508605958894, 0.10514403184060939, 0.1583675606525503, 0.1348658959614113, 0.1335763550014235, 0.15876766730798408, 0.1488961384166032, 0.1222593970305752, 0.09881992431473918, 0.20091898360988125, 0.10822568132425658, 0.13516098872059956, 0.17292551463469863, 0.11875833020894788, 0.13952659821370617, 0.12648390198592097, 0.12281963689019904, 0.21619456470943987, 0.0870084659254644, 0.2146481367526576, 0.34356370044406503, 0.08695352473296225, 0.11717294692061841, 0.09117370296735317, 0.13949311251053587, 0.15687958424678072, 0.13764547649770975, 0.1740806081215851, 0.16550078726140782, 0.14197102485923097, 0.1670103898504749, 0.1141325979551766, 0.16244879399891943, 0.163275605882518, 0.16090033255750313, 0.26068714912980795, 0.08073682081885636, 0.10975581913953647, 0.17367009655572474, 0.09558587480569258, 0.09461592489969917, 0.10126633249456063, 0.16934699728153646, 0.12178514982224442, 0.16624707612209022, 0.1372139621526003, 0.1311471572262235, 0.13763305294560269, 0.10080286127049476, 0.21375347772845998, 0.09016288298880681, 0.1426097023067996, 0.09276868964661844, 0.08804284909274429, 0.17048913286998868, 0.09911478700814769, 0.19577509869122878, 0.15021410363260657, 0.16122230590553954, 0.18420523905660957, 0.20452120515983552, 0.08512644621077925, 0.17917111777933314, 0.08891737365047447, 0.12696108809905127, 0.16916808031965047, 0.2713779645273462, 0.09839874066528864, 0.0879248179262504, 0.1051842191372998, 0.183939075213857, 0.1118344857241027, 0.15166277589742094, 0.113372809428256, 0.07163210859289393, 0.19935691118007526, 0.1073895109584555, 0.10702169514843263, 0.17310714785708115, 0.20733857585582882, 0.1168686144228559, 0.291736233048141, 0.19007656228495762, 0.0769470511295367, 0.17980311589781195, 0.15478126559173688, 0.17028643749654293, 0.13555998215451837, 0.13382466277107596, 0.09831728995777667, 0.09684450531494804, 0.15257106075296178, 0.10822228970937431, 0.18109240452758968, 0.1064535291516222, 0.19840285065583885, 0.13341993995709345, 0.19656014250358567, 0.17429456929676235, 0.10362590197473764, 0.1185656686720904, 0.1300788504886441, 0.12743186205625534, 0.1615026596118696, 0.14997925842180848, 0.11766333584091626, 0.187163736554794, 0.17392456415109336, 0.14386557944817469, 0.12962777313077822], [0.019476005218166392, 0.03926761986804195, 0.04692321454058401, 0.0759095286775846, 0.017037469369824976, 0.021882515538891312, 0.014503864404105116, 0.008910530214052415, 0.05265069841698278, 0.029672097552975174, 0.03522906743455678, 0.013766535121249035, 0.03250115150876809, 0.023643015993002336, 0.03320323063235264, 0.015530348337051691, 0.0352984471101081, 0.0327524130261736, 0.02465540932462318, 0.02938058751169592, 0.010395932295068633, 0.009843342122621834, 0.022493650030810386, 0.10328029122320004, 0.07582880527479574, 0.007573536795462132, 0.020878289542451967, 0.04438718831806909, 0.025361807747685816, 0.023932843214424793, 0.04285440103558358, 0.013353807316889288, 0.01498791074482142, 0.03497285579214804, 0.062146385171217844, 0.029253516986500472, 0.01510010863057687, 0.029074811536702327, 0.013199195691413479, 0.04452254121133592, 0.02063406544039026, 0.036781098606297746, 0.06008122938510496, 0.04515344466199167, 0.03658714944322128, 0.048151936498470604, 0.020638984024117235, 0.027243820040894207, 0.00620833851826319, 0.05969974692561664, 0.01843430261942558, 0.060435293198679574, 0.0066265642453799956, 0.04451178749150131, 0.05057817681517918, 0.028966051650058944, 0.010848148849618156, 0.03926667362975422, 0.021699631797673646, 0.04255409097822849, 0.05159604719665367, 0.01555890989038744, 0.03580210934160277, 0.007847023316571722, 0.04418226279085502, 0.05574524271651171, 0.0577847906970419, 0.005454534484670148, 0.022452288285421673, 0.01900477484014118, 0.03151038064970635, 0.02839130651409505, 0.07041595119517297, 0.022192022661329247, 0.0059467773826327175, 0.025811577070271596, 0.022413297701859847, 0.047833095013629645, 0.015244127953337738, 0.029064081936667208, 0.02049301841907436, 0.09422262373846024, 0.036444237775867805, 0.11036951589630917, 0.04232660045090597, 0.031048441960592754, 0.012321767480898416, 0.07047072169370949, 0.016049919431679882, 0.03372579536517151, 0.06842505841632374, 0.03502809384372085, 0.00948876993788872, 0.11116238936665468, 0.019504149313434027, 0.026978782407240942, 0.014835680485703051, 0.023396630385832395, 0.01955215513589792, 0.05392043887695763, 0.03275836876127869, 0.02342753898119554, 0.03922268653695937, 0.05455907179566566, 0.05065726007160265, 0.023544917057733983, 0.02332174582988955, 0.031415541598107666, 0.07393537875032052, 0.018079589426633902, 0.039424973729182966, 0.03290693188318983, 0.024747281640884466, 0.01692442729108734, 0.0315110560040921, 0.03228673762350809, 0.02609795701573603, 0.04798122026841156, 0.013934354192315368, 0.038016978578525595, 0.021050011382612865, 0.059174521593376994, 0.03268147484050132, 0.057215403867303394, 0.03683656301291194, 0.028597059535968583, 0.02720518568821717, 0.04693077702540904, 0.04955121883540414, 0.08854732397594489, 0.043356586393201724, 0.05324813842889853, 0.017842194938566536, 0.026441584377607796, 0.04665979664423503, 0.03255081603128929, 0.03177393213263713, 0.022980712274147663, 0.035955151324742474, 0.013086656417726772, 0.05034541703935247, 0.02600291572889546, 0.12990199669729918, 0.020617784575733822, 0.021381365477282088, 0.02035832603723975, 0.036368119399412535, 0.03438688567257486, 0.04716825686045922, 0.03264552891778294, 0.07733212929451838, 0.040731394838076085, 0.0065964362966042245, 0.006837570745119592, 0.07406517295748927, 0.0673977924452629, 0.027513954373716842, 0.06882474946905859, 0.01907316745928256, 0.10194449962000363, 0.03611443848058116, 0.03830363682936877, 0.024743700778344646, 0.04515376378549263, 0.058136943480349146, 0.019132782326778397, 0.049945540449698456, 0.04637563572032377, 0.050286115729250014, 0.053801209141965955, 0.04416290386870969, 0.026201581240457017, 0.0704161441535689, 0.018417138599033933, 0.04136564166401513, 0.07116073349607177, 0.10569653852144256, 0.06968782268813811, 0.04598741084919311, 0.033503288359497674, 0.02622470656206133, 0.05129331773787271, 0.019332112060510553, 0.03397374690393917, 0.08754076392506249, 0.01022456761347712, 0.06048739938705694, 0.03864150326990057, 0.04417597680003382, 0.021532097525778227, 0.015451581421075389, 0.01052173282005242, 0.006874789451103425, 0.020961391528544482, 0.02725010232097702, 0.019184133379894774, 0.040253396073239855, 0.0442431968258461, 0.10177501535508782, 0.07629425803315826, 0.060408141725929454, 0.009152137317869347, 0.03494871001748834, 0.09895807510474697, 0.06321389781078324, 0.036532531084958464, 0.02204232405347284, 0.04982005440979265, 0.020901355492242146, 0.06341432963381521, 0.0360583246947499, 0.0838501303223893, 0.05049893770774361, 0.049415186877013184, 0.1509726230870001, 0.041576344810891896, 0.10982210777001455, 0.06517535701277666, 0.0849921397457365, 0.043279080200591125, 0.03059830156416865, 0.04643029118597042, 0.05336903428542428, 0.022117197477200534, 0.01232379168868647, 0.0338840398035245, 0.05225759763561655, 0.04457409449969418, 0.022370585247699637, 0.015067389194882708, 0.07602097699418664, 0.01951548005308723, 0.09400031340192072, 0.05768876420916058, 0.06967002598685212, 0.072643255116418, 0.04317818893468939, 0.04594267418724485, 0.03032826556591317, 0.049241813758271746, 0.020966260017303284, 0.06567241041921079, 0.09069917374290526, 0.02422115830995608, 0.09417396111530252, 0.024132017097144853, 0.03494439442874864, 0.060331210697768256, 0.011912135360034881, 0.0257484778194339, 0.12187167681986466, 0.012506078001024434, 0.06065102439606562, 0.05671895531122573, 0.019874896606779657, 0.012505163304012967, 0.025520217313896865, 0.02645563323312672, 0.01432527213182766, 0.05943101525190286, 0.06011276323988568, 0.010768698230094742, 0.017593506818229798, 0.033655183724476956, 0.004120082921872381, 0.07373421220108867, 0.02427944287774153, 0.04340310792031232, 0.04408759814396035, 0.12332149941357784, 0.04309787371312268, 0.050786553329089656, 0.04428820808243472, 0.01329903681835276, 0.011408346963435179, 0.04791839746758342, 0.03729063493665308, 0.027526285157364327, 0.010833493288373575, 0.06100065387727227, 0.0295846929657273, 0.04565129958791658, 0.010498501742404187, 0.07137499153031968, 0.049742470291676, 0.04237911110976711, 0.00870362871864927, 0.03487130772555247, 0.050311812592553906, 0.006844511217423133, 0.0211692503944505, 0.04943542895489372, 0.07368578706518747, 0.02778987560304813, 0.03629901802923996, 0.009986406857933616, 0.019321794352435973, 0.051632245449582115, 0.020590074636857025, 0.05037895840359852, 0.02062643616227433, 0.04818687310034875, 0.04150431937887333, 0.03617939124524128, 0.0073713725214474835, 0.144225372641813, 0.025637831022322644, 0.044954575059819035, 0.030065777209529188, 0.03163230809150264, 0.0264466736553004, 0.04033621233247686, 0.041733101243153214, 0.05441427136247512, 0.07942780590383336, 0.02403367696388159, 0.024747042298258748, 0.006846902324468829, 0.11006058950442821, 0.049641397199593484, 0.05442217523523141, 0.06993333998252638, 0.0340209697606042, 0.009891764475469245, 0.021708387284888886, 0.0630109575286042, 0.07175747959990986, 0.043479504602146335, 0.04523137387877796, 0.027957999882346485, 0.006961893468542257, 0.07196058315457776, 0.04035367877804674, 0.06312616111245006, 0.028941026430402417, 0.08675007236888632, 0.028403479591361247, 0.017866485432023183, 0.017688794869172852, 0.022174738041940145, 0.021348163645598106, 0.043996510648867115, 0.02847003168426454, 0.04460859694518149, 0.04242543967848178, 0.047564263149979524, 0.06934584846021608, 0.024799812708806712, 0.04949188412865624, 0.06300802604528144, 0.11354479473084211, 0.03984421295172069, 0.34216415835544467, 0.24640521471155807, 0.14399662788491696, 0.22115944360848516, 0.08447515225270763, 0.10044734284747392, 0.08287736025522463, 0.1584757212549448, 0.20501715276623145, 0.1207149431866128, 0.16754951560869813, 0.14454510470386595, 0.10717665558331646, 0.10965101304464042, 0.14562374213710427, 0.19122506550047547, 0.08213717926992103, 0.0748324126470834, 0.16981152235530317, 0.13434401771519333, 0.09625957420212217, 0.11516059865243733, 0.14159563172142953, 0.2063013651059009, 0.23942936793901026, 0.13243439752841368, 0.15856197365792468, 0.1890791009645909, 0.24018607655307278, 0.09378301998367533, 0.11438255329267122, 0.15704445977462456, 0.1260274217929691, 0.24960136273875833, 0.14589878206606954, 0.19818354601738974, 0.15432361280545592, 0.21652816009009257, 0.16265800542896613, 0.21668479777872562, 0.2259286181651987, 0.114327582414262, 0.10797307651955634, 0.16352124192053452, 0.15156822628341615, 0.21437333431094885, 0.17462374147726223, 0.16159137594513595, 0.11828706643427722, 0.141765984299127, 0.1148889132309705, 0.10104964763741009, 0.10941590066067874, 0.2158482192317024, 0.17195172782521695, 0.09997499553719535, 0.10628376287058927, 0.11184509843587875, 0.2149039995856583, 0.11643413890851662, 0.09854063930106349, 0.08996372765977867, 0.1095402697683312, 0.15273243334377185, 0.1421577640576288, 0.1633631793083623, 0.1332170664682053, 0.11825285342638381, 0.16644367104163393, 0.09876076772343367, 0.1337862343643792, 0.09782474880921654, 0.24605299142422155, 0.10700736427679658, 0.187865897314623, 0.0883486881502904, 0.16619439848000184, 0.12586821627337486, 0.1269945886451751, 0.35713832359761, 0.16529384680325165, 0.18304778554011136, 0.08820758361252956, 0.18074974010232836, 0.1256181570352055, 0.08460946613922715, 0.172497755556833, 0.16203020786633715, 0.11412526553613134, 0.13768427597824484, 0.23274776787729934, 0.18656811851542443, 0.09299525248934515, 0.2478748600697145, 0.17178412119392306, 0.11682982978527434, 0.182297904684674, 0.09859338373644277, 0.07564271916635334, 0.15856188460020348, 0.2414622440119274, 0.14427563088247553, 0.08390861155930907, 0.11731911290553398, 0.11082130571594462, 0.1366807142039761, 0.08193242814741097, 0.2865195879712701, 0.18709859083173797, 0.152412063034717, 0.11767161820898764, 0.0765283388318494, 0.2109990708413534, 0.13033901777816936, 0.13830361305736005, 0.10904175433097407, 0.14136538782622665, 0.09506702452199534, 0.12359714790363796, 0.08963367232354358, 0.10199473559623584, 0.20403536560479552, 0.09089422499528155, 0.17175679531646892, 0.1569700668915175, 0.1181303100020159, 0.21173992718104273, 0.15254152327543125, 0.16151655261637643, 0.31127561582252383, 0.09551002731313929, 0.12058754611643963, 0.08144722683937289, 0.14358411252032965, 0.1352468552067876, 0.20310904656071216, 0.1164481061277911, 0.15114263427676633, 0.19674089999170974, 0.11576963472180068, 0.1381581966415979, 0.10730191526818089, 0.1943051119451411, 0.13003286701859906, 0.10549604732659645, 0.14526317710988224, 0.15690949279814959, 0.09985891621909104, 0.10470711466041394, 0.16461212479043752, 0.196897626738064, 0.08642440312542021, 0.13151560386177152, 0.15883331769146025, 0.23568613833049312, 0.1465411257231608, 0.14414508710615337, 0.12020224530715495, 0.17840882821474224, 0.18522831931477413, 0.17320684797596186, 0.101076535647735, 0.09493011311860755, 0.13479233428370208, 0.13820492225931957, 0.11406444653403014, 0.1493315416155383, 0.11805372778326273, 0.11483675509225577, 0.1569047727389261, 0.16612212813924998, 0.18908638885477558, 0.14700909436214715, 0.10808589780936018, 0.15297012840164825, 0.14855871355393901], [0.03600426294724457, 0.025862469847197644, 0.05211872325162403, 0.08121435574139468, 0.03866279548674356, 0.05511742660019081, 0.012836664900532924, 0.012043861934216693, 0.031567997284582816, 0.03919885246432386, 0.04712792855571024, 0.024838051867845934, 0.03544318817148451, 0.04263513721525669, 0.015438989958056482, 0.02752011234406382, 0.05465296460897662, 0.042529299535090104, 0.025274915242334828, 0.057127433392452076, 0.07489815208828077, 0.11426447759731673, 0.041097897046711296, 0.02459995048411656, 0.03291239780082833, 0.018600818293634802, 0.025751260873221327, 0.03595241651055403, 0.033731862422428094, 0.04758196708280593, 0.016409135605499614, 0.12912663049064577, 0.015083716443768935, 0.08566036209231243, 0.04443376179551706, 0.0469099597830791, 0.04588035604683682, 0.014333320723380893, 0.05052120213804301, 0.037736739905085415, 0.11111541884019971, 0.06233545471332036, 0.05885688980924897, 0.06146396553958766, 0.06616374928853475, 0.03938398491300177, 0.06846825883258134, 0.03405435898457654, 0.03345646255183965, 0.03729944051883649, 0.02447765011311276, 0.057988068656413816, 0.023153955517045688, 0.04795072913111653, 0.045298182012629695, 0.040411106165265664, 0.06012057805492077, 0.07797151920385659, 0.031563429365633056, 0.08297726817545481, 0.04985372936062049, 0.015770404352224432, 0.01705429756839294, 0.035087643773294985, 0.06258500186959282, 0.036848815871053375, 0.015886954934103414, 0.04165032209130004, 0.03916203451808542, 0.04581662782584317, 0.043453340185806155, 0.07120841648429632, 0.03698906693898607, 0.03434703605307732, 0.03125870352960192, 0.10613818318233825, 0.04492991720326245, 0.0609964867180679, 0.0003707888362214362, 0.04533091814664658, 0.040215502012870274, 0.026574102266749833, 0.04442671881406568, 0.0733550637960434, 0.04128034292079974, 0.11772339785238728, 0.0462145970959682, 0.017179791029775515, 0.09425688869669102, 0.07708555815042928, 0.005165324173503905, 0.07362843389273621, 0.06522541487356648, 0.10218422074103728, 0.04815440785023384, 0.02019286977883894, 0.06852571590570733, 0.009868788511084858, 0.020707725452666637, 0.026615315582603216, 0.005491758292919258, 0.07634161447640508, 0.03886283026076853, 0.04359798847872298, 0.025255864311475307, 0.03529184570652433, 0.04768800143210683, 0.04314560123020783, 0.06241090886760503, 0.027077796039520763, 0.039132099991547875, 0.02737235259701265, 0.0160886688172468, 0.022286995299509726, 0.015518576947215479, 0.05722864007111639, 0.04136162664508447, 0.06196379828907084, 0.07805448389262892, 0.028174948201922234, 0.012894823303213343, 0.016061786373029463, 0.027736494776036125, 0.034875434066634625, 0.022252478011068888, 0.07143889044527896, 0.02976979943923652, 0.0408468544628704, 0.026958831622323487, 0.03722707369888667, 0.03356818917382043, 0.028747437208949123, 0.08867772674420848, 0.06465289246989414, 0.06699838340864517, 0.03819860066869296, 0.05729865428293124, 0.007553366149295471, 0.06264897499931976, 0.09249396141967736, 0.06005768103932496, 0.08186284438124858, 0.02805321000778349, 0.046085648937150836, 0.04083942556462716, 0.13447836128761992, 0.03294339730928186, 0.0523319274361711, 0.043993916842737235, 0.022380568989319727, 0.03860628836264368, 0.018716149897954892, 0.047401354313478805, 0.02858939129509963, 0.011342344059812604, 0.045538422637037, 0.03850833229080308, 0.016549809697607998, 0.01670464211201761, 0.019115727773169056, 0.02170097694033757, 0.09678756032371894, 0.008580567646276904, 0.04072902738698758, 0.04075947399542201, 0.023740072210785, 0.06666765271802433, 0.017466170975239947, 0.046619694694527425, 0.021298985229805112, 0.053797721047885716, 0.02956274023745209, 0.022225584434636403, 0.07138165601645596, 0.05094404077681247, 0.05325665457348805, 0.041798569800448604, 0.02390260069660144, 0.03281234145106282, 0.03928409183572512, 0.018272917041031178, 0.004622274773282697, 0.03737180362804793, 0.03920992530765943, 0.04464892153919209, 0.02090281752316514, 0.03254621471569408, 0.039328976927208714, 0.08655703975819051, 0.021124593513377476, 0.0325756891106721, 0.05360680726880673, 0.030396667461900506, 0.05280871278955601, 0.08444462771876715, 0.041145806389977224, 0.061483881072490476, 0.09958484850358218, 0.03914886139682494, 0.042265061565558426, 0.05048020218964666, 0.02296494163601892, 0.03931431579985656, 0.012683506956818746, 0.03670611942652613, 0.06005691291647963, 0.09267491186619736, 0.08263136056484655, 0.05082859599497169, 0.022687690106977243, 0.028704184842354152, 0.024127007600327488, 0.03806760418228805, 0.02300866155565018, 0.09676743327872828, 0.03491320938337594, 0.024643607321195304, 0.02600706990051549, 0.08790024541667663, 0.07752010787953623, 0.04082180326804519, 0.04569204720610287, 0.031690982286818326, 0.009904085982270772, 0.04207661171676591, 0.033513515154481865, 0.027502413977344986, 0.021980141355015803, 0.02789641461276915, 0.040041416432359256, 0.03762340282264631, 0.021177527196414303, 0.061479725045501254, 0.09562895647832192, 0.003532317036842869, 0.02487298104824731, 0.05419724511739332, 0.01584232031746069, 0.045589664223371074, 0.025449366330576595, 0.06861208705231547, 0.036055842210771516, 0.03936331981094554, 0.012232590088387951, 0.07172487705247477, 0.043003387181670405, 0.03357447145390324, 0.02910218379838625, 0.010606140986055834, 0.015267113194568083, 0.07027549974736758, 0.0348930340987863, 0.0441190800484037, 0.036899159458698705, 0.019830057899525855, 0.009289490299124736, 0.02249903616757365, 0.03919068141840398, 0.07592955182190053, 0.08314446662552655, 0.03202005798812024, 0.02330958202946931, 0.06248670440982096, 0.014197416785464156, 0.062316708063008264, 0.03514298572554253, 0.0292713712042314, 0.04956597273121588, 0.12744881270918995, 0.025378730570082553, 0.037132164143258706, 0.02055979501164984, 0.08163710532244295, 0.05398034132667817, 0.09662089621997438, 0.04903759327135049, 0.0873373041395098, 0.09184217764413916, 0.028340638236841187, 0.01523881603134214, 0.0271359507314628, 0.07927231854409911, 0.014170907270454336, 0.013190578429203015, 0.06638166611082852, 0.029966576184961013, 0.03790349677728955, 0.0207223847246496, 0.03145792565192096, 0.015690591935708653, 0.040104899744619615, 0.09996775217587128, 0.025389556649315637, 0.04065288303536363, 0.05421228845079895, 0.0739860006433446, 0.018354642343183514, 0.03585834558180068, 0.01973004051251337, 0.029718105142819695, 0.08818353802780621, 0.014639590226579458, 0.02869163883588044, 0.020051321807841305, 0.07400997201330028, 0.04292258956411388, 0.030302464801934548, 0.05396325337642338, 0.051137722766725346, 0.04164333106018603, 0.03233660994737875, 0.011281838615104789, 0.01916775232530199, 0.01304844601691002, 0.03139257954899222, 0.027095080658909865, 0.03732593519089278, 0.009970743831217987, 0.02626089182740543, 0.0341152744658757, 0.007894500358816003, 0.021318188300938345, 0.022500501909235027, 0.038207510151551105, 0.05737438674259465, 0.024592681147623807, 0.03546033178281505, 0.08336116632563062, 0.025733894617587794, 0.07067402562825009, 0.053076743133715354, 0.03176614329277072, 0.029265200246300083, 0.021939681319054216, 0.022318571827781852, 0.05287870102620218, 0.01744385459460318, 0.04395400042994879, 0.03990947370766662, 0.03790170820138883, 0.03657233617559541, 0.04625922614650335, 0.006360619800034328, 0.05407710254075937, 0.019434348469076212, 0.08860696296324022, 0.04819376394152641, 0.01193108702864265, 0.0036489323247224092, 0.07435920444549993, 0.02984008639032254, 0.04806472672498785, 0.13408943137619644, 0.1187455133185722, 0.11307445864076726, 0.13649351487401873, 0.1602173043647781, 0.1460538464016281, 0.17145422170870006, 0.09468269592616707, 0.14313765132101253, 0.07370906823780388, 0.12134058852097951, 0.1364489711704664, 0.2158604795113206, 0.11729512669262476, 0.09954121022019535, 0.14776308671571314, 0.15185554133495316, 0.10687939575291239, 0.13633186026709154, 0.13447937060846016, 0.15059519646456465, 0.2915867051342502, 0.12522508593974635, 0.11886934807989746, 0.0990845519118011, 0.07125430347514339, 0.12216610164614394, 0.155176563130226, 0.17808678065193817, 0.13704420329304412, 0.1391373120713979, 0.18339479895075783, 0.15416215115692466, 0.14368302596267313, 0.160240919503849, 0.135717554949224, 0.16105919668916613, 0.12061786284903064, 0.18788605404552072, 0.1880947608151473, 0.20421722147148103, 0.14349357050377876, 0.21923558902926743, 0.12636990810278803, 0.2842650917591527, 0.1272414714912884, 0.21132368623511866, 0.15481046168133616, 0.0961035821819678, 0.1261748865363188, 0.11250155774177983, 0.15775625361129642, 0.16293654829496518, 0.12902403599582613, 0.18354440107941628, 0.10449551351484843, 0.21453277731779963, 0.1728543426725082, 0.1079708055476658, 0.1862828666344285, 0.1720555394422263, 0.07241016879561357, 0.11340272540110163, 0.16423239751020446, 0.23695083218626678, 0.14868386933812872, 0.1014841379947029, 0.07958931208122522, 0.14945594040909782, 0.16520475939614698, 0.16833822563057765, 0.20691109879408032, 0.13496452738763765, 0.10238077855319716, 0.1705979317193851, 0.1770083955489099, 0.10154992938623764, 0.12175463270978071, 0.1419049291871488, 0.1324551776633598, 0.09966722689568996, 0.1512884662952274, 0.14912791113601997, 0.14403659995878115, 0.1641728327376768, 0.17694041482172906, 0.1550739092635922, 0.19588239840231836, 0.17882414889754727, 0.13696209207409993, 0.14625280135078356, 0.12358660198515281, 0.15638198907254264, 0.19927330082282424, 0.11338397875078954, 0.11460944268037565, 0.12592447106726468, 0.175629114091862, 0.1801963205798529, 0.15292790019884706, 0.13991270796395838, 0.3277368372073397, 0.10846128352568485, 0.1294969324953854, 0.15531625016592443, 0.1513754460029304, 0.0922893438837491, 0.1050938997650519, 0.1903810803196393, 0.1429265845217742, 0.14131103293038905, 0.14281937386840582, 0.09798287821467966, 0.11930791282793507, 0.1121880894061178, 0.2291433050413616, 0.13065995211945847, 0.08786689330008812, 0.14112649048911408, 0.12203926860820502, 0.12680679559707642, 0.18891498242737725, 0.07387120524072088, 0.16988854244118556, 0.2278499791282229, 0.12567819678224623, 0.17610040755243972, 0.11955792753724381, 0.12699274811893702, 0.11179353401530534, 0.0847590682678856, 0.14087175572058186, 0.1217263494618237, 0.12130826798966154, 0.10837386595085263, 0.12461103295208886, 0.15512103564105928, 0.05818631485453807, 0.17332004033960402, 0.16211755864787847, 0.1953064472763799, 0.1112295759958215, 0.11752850245102309, 0.0832242846081499, 0.15120245137950405, 0.2270717333885841, 0.14972669072449207, 0.1478341399342753, 0.07750671953544952, 0.1606290478957817, 0.1461388816824183, 0.19139917334541678, 0.14261148346122354, 0.257528776419349, 0.13401380652794614, 0.20786796463653445, 0.12287799196201377, 0.09902982594212517, 0.08814891683869064, 0.1114739355398342, 0.14760671620024368, 0.12375403050100431, 0.10482711993972771, 0.1071464575943537, 0.177723454835359, 0.11649300606222823, 0.05750688607804477, 0.0964890091563575, 0.2267239333014004, 0.17943818704225123, 0.11789847048930824, 0.0690274967928417, 0.061045791298965923, 0.1323912787484005, 0.14149369031656533, 0.1046959676023107], [0.040363942680414766, 0.028430825877876487, 0.07026835286524147, 0.023530298603873234, 0.001954528934220434, 0.07086379278916866, 0.0075756421756523196, 0.049254159384872764, 0.02112919853971107, 0.037961514171911404, 0.03945053329516668, 0.047578790690749884, 0.028565317879838403, 0.0385342221125029, 0.021159042153158225, 0.019879618521372322, 0.024510028160875663, 0.06438100666855462, 0.04169530737271998, 0.022864881575515028, 0.011246919639233965, 0.023900865926407278, 0.07342611701460555, 0.01975433657207759, 0.02975275787321152, 0.015388209430966526, 0.043141152054886334, 0.038727488499716856, 0.025069574112421833, 0.025290127414336894, 0.014178932669892674, 0.020464801964408252, 0.028495878832472954, 0.0293255721044261, 0.06184298406878952, 0.023574194783577695, 0.04790081598912366, 0.04193896187643986, 0.07786103567923419, 0.018323418335057795, 0.002372616668253613, 0.03451077609497588, 0.037671857644454576, 0.010938304949377198, 0.05930710627580993, 0.056503795567550696, 0.038076502532931045, 0.010589104986138409, 0.060894634370924905, 0.04113703791517764, 0.03243459199438803, 0.06989208399318159, 0.015050535021146061, 0.02535858868213836, 0.018895256107498426, 0.04853105521760881, 0.061390845439746045, 0.010729904315667227, 0.05350713683583308, 0.07361693802522495, 0.02458304621541174, 0.04413491376908496, 0.007397701137961121, 0.014567297621397302, 0.0771045645524282, 0.06265171352424659, 0.05509945178346243, 0.07074695648043416, 0.0387419306935044, 0.018363091694482137, 0.030819224084552843, 0.033942365189432167, 0.03343190859595779, 0.09314893643022515, 0.01703400725091342, 0.04140949517022818, 0.02103226292092586, 0.0367555019329302, 0.028332828987913672, 0.02557864474511007, 0.05130624966113828, 0.03387373508303426, 0.06550668884301558, 0.05842831436893903, 0.017988976906053722, 0.02893266242608661, 0.023632735392311588, 0.04558789049042389, 0.0667713678558357, 0.015684682584833354, 0.03043385277123889, 0.025007435942825396, 0.03253579867305234, 0.04614354758814443, 0.03843543483526446, 0.0245421112049371, 0.05487206515681464, 0.036176656431052834, 0.04814336098206695, 0.030841692605463322, 0.046490408858517185, 0.04088135319761932, 0.01152459233708214, 0.04682900631451048, 0.01281126489629969, 0.05525459404452704, 0.05724598035158124, 0.031163912717602216, 0.037545785307884216, 0.0044192138921062, 0.030327625463542063, 0.06356729369144887, 0.10843905620276928, 0.044591813275474124, 0.04601783519319724, 0.01303780269154231, 0.04019966829218902, 0.025375930817972403, 0.02858071558875963, 0.06223929092811886, 0.059672532370314, 0.009951067640940892, 0.02314026845851913, 0.04553627411951311, 0.026672783787944354, 0.03202428822987713, 0.06418767719878815, 0.06700340774841607, 0.04861990142671857, 0.07319686759728938, 0.02658729579707142, 0.03446515627729241, 0.016223342645389494, 0.03150888893287629, 0.004881236536675715, 0.036372791219037026, 0.030418972710322123, 0.08153294489602558, 0.03810880079981871, 0.042707255415734835, 0.003833357645817159, 0.01643532970774686, 0.017679976299405098, 0.011216699385840911, 0.00437282316852361, 0.028215335878485348, 0.06244135176530108, 0.05756408711022232, 0.056947777993627824, 0.05591221481154207, 0.005311466038619983, 0.06071364681702107, 0.07292137495824136, 0.045909541004220955, 0.1006316849088762, 0.014185700129019096, 0.04560683009913191, 0.02847091298463056, 0.08852928978740238, 0.08237857022322714, 0.029493637011910323, 0.03353397245518863, 0.0464984611608088, 0.03217189398128539, 0.06429227549233474, 0.03409217140870169, 0.06118546720244922, 0.04304980851884466, 0.049493372134747915, 0.009479407744947821, 0.013567874248110456, 0.01724463432765333, 0.02152730510715628, 0.03868729749228805, 0.034317379831918515, 0.022730396995029878, 0.011375129361113068, 0.010341249926568707, 0.019716355309356004, 0.0843669545429293, 0.006259978545131162, 0.05595515918685123, 0.045167333955760114, 0.04690790032327641, 0.012562308675114764, 0.02219420828623697, 0.012463294115150347, 0.04789619611983653, 0.03285279221017845, 0.061067710630595684, 0.05000512377591804, 0.028834164586442057, 0.014508250496874098, 0.07726457901299, 0.036119692886131816, 0.012242681441421155, 0.030212529491109308, 0.0289992590478505, 0.031099889492907096, 0.007681586539547425, 0.011729634752555285, 0.008387429279537173, 0.046334810176631436, 0.02698605730984127, 0.015254132104018936, 0.05362523108487949, 0.021002578869229183, 0.023694355913903564, 0.04059151484398171, 0.03213374387996737, 0.04515283239015844, 0.009150250407401472, 0.016361480447812937, 0.0700228355708532, 0.034787025724654086, 0.0981620920356363, 0.021980651581543498, 0.027973173091595527, 0.026131118029297795, 0.06812930514570326, 0.02198046975536272, 0.022255363110161852, 0.03272460475272965, 0.03208934489521198, 0.008782506029092474, 0.03980039284215309, 0.014874550470267422, 0.09925995851517655, 0.04028977986308746, 0.031820943477214314, 0.050252366563654505, 0.038574342615902424, 0.03569021944713313, 0.0382548740162747, 0.02250609584734775, 0.053446009842446074, 0.031067619056557305, 0.054020832903916016, 0.0374174902390223, 0.05464015885081608, 0.04259237837686669, 0.03635814122390002, 0.022698339926137123, 0.15496512525714934, 0.012287997906241799, 0.0376666737429332, 0.029725784515903797, 0.023759390314808115, 0.044042045119567774, 0.036335906479507685, 0.04230737882608082, 0.03353950516611803, 0.021660500206053257, 0.028417292814992834, 0.038128282176330686, 0.04109945926757064, 0.027042820474889595, 0.018083600734826177, 0.02669877194421133, 0.03760637795494404, 0.07896272421930917, 0.023757303024467546, 0.12988943955861032, 0.02999249754793709, 0.026783206085383426, 0.020190090435789898, 0.035716940474230796, 0.026990270853275433, 0.005936632223892957, 0.041824700820143335, 0.01618793477973668, 0.03728116884303745, 0.039340487637673505, 0.006488618009825586, 0.0337509615928866, 0.04405584164487664, 0.021806252443639096, 0.008361103446077323, 0.03395129693672061, 0.01161133826826699, 0.055134633294073865, 0.08184570076991804, 0.09520752049866132, 0.07439398890710436, 0.015871993236942217, 0.05332016386091709, 0.025346413749502972, 0.01739147752232384, 0.016533248672203626, 0.026593613329168875, 0.0429347125464119, 0.026468873147678096, 0.022426585856010206, 0.025733668262546416, 0.01349674588709604, 0.039591014428879134, 0.029715396303799935, 0.05887140621780418, 0.04122120859392453, 0.04717344818345737, 0.02962158883747179, 0.05292317793646362, 0.0621200352179585, 0.011156428645335836, 0.010439777452120325, 0.008729842302273028, 0.043026946659665555, 0.023624775858479552, 0.0425963599991519, 0.04130840352445375, 0.03533909453835804, 0.029069017218716908, 0.040802774601615965, 0.011539336956047919, 0.05097317378385924, 0.08432177259237505, 0.0372223536396632, 0.013441775008686818, 0.04691147005360108, 0.03296261893410701, 0.04963944906194229, 0.04263729315425735, 0.06728317515808158, 0.07243945394293405, 0.0572597323480295, 0.036693376750918105, 0.052110325850662775, 0.06260553709580563, 0.055117029551183805, 0.021564412490988616, 0.02310576972377021, 0.036327894995338283, 0.0385689694667235, 0.13123363227350637, 0.07306407511350699, 0.05377884823246859, 0.0389186768734362, 0.09379137656651437, 0.03284076941781677, 0.024718566091905814, 0.05479180930706207, 0.01232414142577909, 0.08856964035658166, 0.06431920061004348, 0.07509566727094352, 0.02391791120317066, 0.023731322289677337, 0.02799710549879819, 0.04448078427230939, 0.027478002884890884, 0.028551064933708403, 0.03562999416317325, 0.09952184758731164, 0.1210382672434207, 0.15406728984089568, 0.20269431959604844, 0.1546899220556952, 0.1717255954281427, 0.1035866720485501, 0.1163341716164723, 0.07951437000883743, 0.18505050073144957, 0.0965767161687836, 0.15303877706173807, 0.10044001784990542, 0.16577238362515345, 0.11698296453687362, 0.0824693868344184, 0.04259207780705765, 0.112633118260419, 0.10769615895696916, 0.11674015608150512, 0.0474058257532306, 0.15720819239504635, 0.1692772947717458, 0.09229962262907065, 0.10742473328718916, 0.05592914320004638, 0.1668138097738847, 0.11690912084304728, 0.1611212847637944, 0.08748131789616309, 0.1761667407117784, 0.0512372818775475, 0.14355531719047576, 0.09409933816641569, 0.11996086919680238, 0.13663571036886424, 0.18273057678015903, 0.17777019529603422, 0.20901744748698547, 0.13540801999624819, 0.15122853044886142, 0.10268004218232818, 0.12737790792016312, 0.1095004980743397, 0.10885930474614725, 0.1985864431480877, 0.09866414751741104, 0.14430355047807097, 0.16189111454878002, 0.15538859472144395, 0.1872185812680982, 0.14045539603102952, 0.1583285236847587, 0.0884914402558934, 0.11110380422906019, 0.1626947714248672, 0.1428068315726705, 0.1431055460125208, 0.16815113020129502, 0.12618968496099114, 0.1671568601159379, 0.09651473941630684, 0.13595477503258735, 0.18857688963180408, 0.18269726919243112, 0.11761897767428309, 0.1452829924528487, 0.24075514054857194, 0.10330193967092782, 0.12401283966028132, 0.0762379661318846, 0.09483350033406168, 0.14284373115515336, 0.1482031654450111, 0.10603348098811693, 0.08071245611063205, 0.11603548686252907, 0.18295679823495448, 0.1657176873413846, 0.10965464214677922, 0.10972782532917336, 0.08903578331228346, 0.148398261226248, 0.17346003907732666, 0.14967048045946285, 0.17296652571531013, 0.2072598785161972, 0.15968303225236014, 0.186587072967086, 0.1358242757851258, 0.17138282710220665, 0.06132462360255886, 0.0945243364549242, 0.11833552125608549, 0.1374924901756458, 0.14038587163668126, 0.1218080153921619, 0.10192783840466291, 0.09649928790167905, 0.16452714888146147, 0.15958866075379774, 0.12100054387701675, 0.17660388053627685, 0.11976942478213459, 0.09116903485846706, 0.19505659583956003, 0.19840141088934615, 0.11693142980220728, 0.10469011947861873, 0.10177882999414578, 0.12929742835694924, 0.08980303042335436, 0.14261581760365516, 0.2436660960665904, 0.19144374673487619, 0.12474974035285413, 0.14104040135862306, 0.196235794282984, 0.13715892448090017, 0.17402674304321408, 0.17010336450766772, 0.28137549525126815, 0.23418793512973934, 0.22834565956145525, 0.0879533906118013, 0.16601040522800758, 0.20681258611148223, 0.17671413399511948, 0.105667668976821, 0.17758519272319973, 0.14252199529437348, 0.06524558644741774, 0.10652931727236137, 0.13992143562063575, 0.08626671900856309, 0.15157471265411004, 0.08377526246476918, 0.13384303834754974, 0.143390693992842, 0.167251780803781, 0.09484193113166839, 0.08363985762116499, 0.1481425913516432, 0.16335802880348638, 0.10072379285702482, 0.14760276797460392, 0.22956759086810052, 0.17842208297224715, 0.20681939902715385, 0.08430874047917314, 0.13392750959610566, 0.23029939300613478, 0.11404742908780463, 0.10543927302933298, 0.26769732765387744, 0.31840195530094206, 0.11555706878425553, 0.15033732983283699, 0.15706982638221234, 0.17377629788825288, 0.24736412888159975, 0.1419472019188106, 0.1091784356685821, 0.15511625621002167, 0.10724517807830125, 0.16763800929766148, 0.23141737910918891, 0.151010665576905, 0.15266537287971005, 0.16991439886623994, 0.15244143723975867, 0.057897385631804354, 0.20130062563112006, 0.10661295731551945, 0.1891074955346994, 0.13499068067176268], [0.030316357806441374, 0.03224019754270557, 0.023562945680168923, 0.0671706729917787, 0.023401070284307934, 0.03993712613009848, 0.06147879365016706, 0.01173617585664033, 0.024876695497368928, 0.02206962395575829, 0.002688052159101062, 0.0467054164619185, 0.025700629703351296, 0.10826439174707048, 0.008085659974312875, 0.0155732379789697, 0.04219260568788741, 0.016629449564788956, 0.05375900320359506, 0.0594340617681155, 0.1013617504213471, 0.056844304053811356, 0.08065217145485803, 0.06718124859617092, 0.09006418476928957, 0.028904152823088225, 0.03235390940972138, 0.032866006149561144, 0.10636891689500771, 0.05331950706022326, 0.037004989717388526, 0.0516079030057881, 0.09743945542140864, 0.007293537928489968, 0.00940457977776532, 0.010977872552757617, 0.032210292702075094, 0.04322129287174903, 0.024787340917100664, 0.051849067604052834, 0.04711972411314491, 0.05076630011899397, 0.010532073720241897, 0.02049979051662376, 0.031986253161448985, 0.04556292093184311, 0.029647192932316102, 0.08654214485432021, 0.017182811570819467, 0.03711105375259649, 0.02422026216663653, 0.03489739050564822, 0.031133774100453593, 0.05989990044326987, 0.02244035084004281, 0.04713549104053527, 0.030277504520199727, 0.06441212492063642, 0.03183870678185485, 0.046939593739807606, 0.02580209242296405, 0.035764252388617024, 0.05352064021280967, 0.02503088780940743, 0.04231933853588998, 0.02982578705996275, 0.08264298259746283, 0.07545729356934316, 0.08543258954887278, 0.025869885757856537, 0.00816010202470352, 0.024819681857479736, 0.056179246967076324, 0.017065702522813808, 0.012264522847544868, 0.025039481879503, 0.044574406201718375, 0.1290610691648908, 0.027132477480336092, 0.024872880858310964, 0.09323699225205928, 0.02766336539934855, 0.01896017918625148, 0.05091517865366768, 0.046602962975157425, 0.017402387093170546, 0.06204724537383299, 0.07864029073971324, 0.07784608140354976, 0.02949070738395676, 0.025538305308145937, 0.01391118619721965, 0.08578783337725326, 0.04391973176097963, 0.033509796994621865, 0.07308872925932519, 0.021675378411600832, 0.06196603586431593, 0.054903535929042846, 0.02169506944483146, 0.031058210479386616, 0.08968458365416154, 0.026607602812873665, 0.04079014695889782, 0.031089766598597635, 0.06517385045299307, 0.023654456199437845, 0.05125604337081313, 0.01629815855267225, 0.030693162880197633, 0.040590208664070815, 0.04117077223781962, 0.029619037704833318, 0.06979017227422446, 0.029218739946372807, 0.03936181325116195, 0.052769779722439125, 0.02632334355439525, 0.014581708273908589, 0.020171148971712682, 0.045750417120871134, 0.025766063008632045, 0.01806685973861022, 0.0446670002565952, 0.057919854152714834, 0.025293125690950546, 0.049865473847603425, 0.008885662700777175, 0.050721403895295225, 0.017203647366841324, 0.0180505083699245, 0.007053117333271075, 0.013851406201865757, 0.02546621679357486, 0.06352691343636252, 0.034897204968729056, 0.035397178726270795, 0.06492298227385618, 0.04248486344295088, 0.019849715536111034, 0.12406435213051736, 0.05778017824923154, 0.04734245376312174, 0.036011383854201995, 0.019139610085403547, 0.018457865808159113, 0.028368392704578582, 0.06775199726689607, 0.022264498948061373, 0.021336467398214154, 0.054464633503812365, 0.08416599579504691, 0.042783088065334596, 0.027565411182877142, 0.027897238396690227, 0.033103556488640606, 0.0222690965529182, 0.05065514866146259, 0.011464782655821182, 0.04922063657431863, 0.05866218365554232, 0.06923360604560003, 0.034837057610275224, 0.029831425526936073, 0.026125128897547256, 0.017786815878935158, 0.015616427263012156, 0.01871683638455579, 0.12438208039384335, 0.030719637143192813, 0.03754249759367667, 0.059799569498864, 0.04234037100104615, 0.048605893389321864, 0.04631378884369042, 0.04150534725340549, 0.020647082710638642, 0.06433830349124037, 0.03114112507319078, 0.02779768856271403, 0.03199838727596216, 0.06470563690527342, 0.044269620993873104, 0.025866210271487944, 0.009461150912102312, 0.02522256414522417, 0.026609437773004174, 0.011249239778408082, 0.02058274778391933, 0.06471840926678851, 0.006788243899791269, 0.01415992441252456, 0.011177526976098306, 0.06791741456254385, 0.012975117188034346, 0.06555562606081367, 0.073429248877801, 0.05893803252547514, 0.05455471167806536, 0.07931762665975839, 0.0442040893540252, 0.01041033181536477, 0.057055927463807166, 0.05929890554398298, 0.027727028682420496, 0.05004293991078157, 0.05544129242480267, 0.03396245512703899, 0.057207852514693514, 0.005189332650843426, 0.026803908294823486, 0.051657697404152714, 0.04675090640375856, 0.08097105746855959, 0.012655167120101396, 0.010070118332805578, 0.04215403627313208, 0.03505829554342199, 0.11067567407735623, 0.01239050612639403, 0.03522829931171145, 0.01681938927504234, 0.031118342994886916, 0.01974242324649822, 0.07694694722886197, 0.06308942480245605, 0.07904531041276641, 0.03948424906411674, 0.030482712063530926, 0.05065068093244918, 0.03757818747544661, 0.0373109475185629, 0.015424082994286437, 0.01087360173187335, 0.024693713421584107, 0.03329424391267821, 0.03597309645556379, 0.027016218191420194, 0.0677444867324084, 0.055888922506710514, 0.025643363733252045, 0.034451782776159234, 0.08782935547060333, 0.049953043562709354, 0.03518173696647864, 0.020292716471885797, 0.03672066181025002, 0.020666283926402684, 0.00860302596265683, 0.02399817076366162, 0.07045595295494422, 0.02964245060866233, 0.006642351117989165, 0.06650815033935942, 0.03451491356827319, 0.05668029312801082, 0.0464277493301779, 0.035366769225220196, 0.052143340290058404, 0.0313814733090112, 0.02810930338455364, 0.03818252946075518, 0.0025213678782165516, 0.08997198034194298, 0.055551271289004944, 0.028558202538988553, 0.032822111825225875, 0.05223931853834074, 0.05499934348335955, 0.04846941614232492, 0.02449668805638794, 0.045566657645395026, 0.08492260792991146, 0.044562105103977956, 0.02260159541037865, 0.05317439492500853, 0.004110781956114806, 0.07277155018527992, 0.0272065512399422, 0.024268371889775153, 0.02613983269839082, 0.06753803609171882, 0.04785783450643066, 0.021567395924648736, 0.06021535773470532, 0.05843824059411418, 0.07223460634122603, 0.03543406717653852, 0.07573407012387179, 0.0911847164388746, 0.07033621484879404, 0.027128145193273667, 0.06543831477756612, 0.010302370665158378, 0.02134301685146056, 0.019532734986569267, 0.016954797829384916, 0.028323307233222295, 0.0735839940898586, 0.05332927372364793, 0.02934158950665733, 0.05589366854110267, 0.04471116546483245, 0.040035653655650094, 0.10428861758555286, 0.0218652327748714, 0.02351663752051536, 0.020735227590193972, 0.018041135044768453, 0.014917829739715671, 0.04597510604071431, 0.03265075363742653, 0.02470667132001836, 0.023711054236628115, 0.0050817467490560375, 0.04136263225518633, 0.06554909516125917, 0.04536920925602317, 0.04118184508115519, 0.02751931082457304, 0.021881417160329875, 0.06205962439707946, 0.028384220859152265, 0.03585856451536529, 0.03283464669948444, 0.08897317573428154, 0.05774235098215286, 0.09148296332568862, 0.03652777762908954, 0.036236551459296606, 0.03088985427893931, 0.03364777337992564, 0.024314542752108537, 0.023117484524846077, 0.017958936623472255, 0.05195110548811499, 0.024709177923796233, 0.043564506486291066, 0.06116303578892257, 0.03598604322178289, 0.044480223950813524, 0.00818813201476587, 0.059193364722887054, 0.04535356849373784, 0.06746964718331583, 0.07093255277140997, 0.02405357765383087, 0.05956843131571077, 0.018546346509538125, 0.05077741378045175, 0.05151884899532888, 0.04152809407969471, 0.10901041343458928, 0.16871741856448352, 0.08841283939545974, 0.10953739023534581, 0.07606787330587395, 0.15385772217996418, 0.12242781260283664, 0.09780876294826157, 0.06278594577452168, 0.1050073876103852, 0.045726100652245805, 0.1160952594364062, 0.15709924511611462, 0.2681112085701898, 0.11933630739804357, 0.09803592693060637, 0.10209945263341069, 0.1553346702712588, 0.12805854639736935, 0.15331356466049328, 0.24925985606387258, 0.1553570237592794, 0.1342445847694762, 0.22766132518881932, 0.13881927210604772, 0.09749142060172744, 0.15820243279449642, 0.1512945519061759, 0.20610727864550427, 0.19073204195592552, 0.12036150277708657, 0.11929740401683375, 0.17009842180414125, 0.11148569858050905, 0.09378852671943605, 0.13713336491491646, 0.15112160181161016, 0.1215419702930376, 0.11832076736027375, 0.1442844030680135, 0.1269227487500757, 0.11869996771565638, 0.2655282971682027, 0.16429746901849285, 0.18075630068778992, 0.1544655708130449, 0.09870951500488445, 0.18579822935862467, 0.1384058958501555, 0.19820573623292148, 0.12634477898245677, 0.1335137919522822, 0.12161274149548262, 0.16343985800631344, 0.21901054016780108, 0.14561710733687505, 0.13171779457479715, 0.28225289192050695, 0.13212394231231883, 0.1492865674663335, 0.08401910250540823, 0.12104493915103376, 0.15089362888829783, 0.19376781187020242, 0.13863517495337874, 0.14523548015858978, 0.18820908124325797, 0.19298465311294422, 0.17835245467722416, 0.1701586545095779, 0.05129962970386259, 0.07238783757202327, 0.24484498280799016, 0.11821902633528225, 0.11837786078103818, 0.08081509513431229, 0.1587394211674109, 0.29151198570616543, 0.10188638203544542, 0.1597756374394521, 0.21732614695793018, 0.15599895181367174, 0.15494620049139485, 0.12463101156754419, 0.11475604653242044, 0.12949325144290924, 0.16253316134680063, 0.2527464658487588, 0.23918322724057361, 0.14290604187408462, 0.11462646754807793, 0.12733673356706277, 0.1614125183550641, 0.20462513552047312, 0.09350245105451904, 0.18798998440615833, 0.2273388917092234, 0.2430027347872965, 0.1141191205533687, 0.14545831741997972, 0.08672175201354548, 0.2165083002182655, 0.07492729622754268, 0.19523665570886806, 0.14030405727680773, 0.1877668799716048, 0.1009179609536659, 0.1697186499950476, 0.10126587236300111, 0.15261643566191196, 0.11953581895795651, 0.11748809251002967, 0.2349815284833312, 0.1959932455793023, 0.11494426260469481, 0.1870355973369442, 0.14961787703214213, 0.11759558517951518, 0.10322026631911285, 0.09712664017570205, 0.11539083512616344, 0.10426773354993202, 0.09903841259074397, 0.12818104529287666, 0.16504853731021285, 0.11401432187994942, 0.16721045802114531, 0.12388297865982167, 0.23047740454785526, 0.07099133828887716, 0.09076687245396897, 0.04944594518747181, 0.14793645241297781, 0.08853976891259663, 0.15980112279066816, 0.215875084977597, 0.14611669146688655, 0.10553469095611945, 0.09641772587201558, 0.06477122049545869, 0.2293885254766792, 0.19113756628939882, 0.13343184400582686, 0.12477139622205868, 0.08948005517595448, 0.10473909380380064, 0.14755135198356584, 0.17239286040421575, 0.14531033317325637, 0.13097475632093847, 0.17368799715768546, 0.24883925128960982, 0.15374545007944107, 0.09477282976149581, 0.18311794818146154, 0.17701467411825433, 0.1119141181698069, 0.1724694055155851, 0.10316831598174758, 0.16861991520272568, 0.16697479644790292, 0.14967049530241638, 0.15915984782623127, 0.1453302672598511, 0.13127920014085248, 0.09493340825429186, 0.14653940394055098, 0.145090687146876, 0.17863463406683877, 0.1578817210975103, 0.08291869788081385, 0.12652814883040264, 0.15840448992094025, 0.13916769559727982, 0.1306465786183253, 0.11036996860639192], [0.05617564012936782, 0.05866657716978807, 0.09575127725838684, 0.0633403449319303, 0.03109012839559, 0.06435765870264731, 0.02661993359652115, 0.02765082124824403, 0.022298997682810295, 0.07074982117046602, 0.032506736170034856, 0.045470787008525804, 0.006842926268291194, 0.026927889630314894, 0.04467001708690077, 0.07335856673307717, 0.05171713972231373, 0.0384717666747747, 0.03204159140295815, 0.021363262640079483, 0.04298146042856388, 0.04193349595880136, 0.024306874511239585, 0.028463370908866636, 0.04469278246688191, 0.05708402888558339, 0.06280062545556575, 0.03980988862167578, 0.042324941750848666, 0.01808568245905917, 0.05641503099468537, 0.008915294802136486, 0.025125632237177342, 0.09064233265235089, 0.04940866710967384, 0.042686148735811, 0.03408449389098678, 0.006285365561780054, 0.02358323043154087, 0.05081052840978373, 0.015653148730052635, 0.045725046802544966, 0.03492476091196295, 0.017228297801921144, 0.007469084148397087, 0.023773535649525, 0.08748686916078441, 0.02025673158641439, 0.05180168889637571, 0.019621440187620465, 0.018717344755714294, 0.013289123580761952, 0.06391035145497881, 0.02323144315596437, 0.037571560096694157, 0.052762079940293916, 0.05045502482971642, 0.10828451137058437, 0.05022948615078349, 0.06964576517930254, 0.042279693007003516, 0.025635582314862404, 0.024911314831115305, 0.02391591482592048, 0.030752428938285448, 0.04540350390016101, 0.02783159914542921, 0.035492863826220855, 0.05256439035292715, 0.007792110882292036, 0.06349973598844372, 0.033984077599598095, 0.009456585776206339, 0.02256979809317272, 0.007427660248140455, 0.04777184185513761, 0.0862141081597656, 0.052860358846373856, 0.13376245595281944, 0.049080140597652644, 0.04990038818505127, 0.020464423469093163, 0.021783561278425623, 0.03645485048764385, 0.015088102536537917, 0.05610843494650908, 0.0551538808940677, 0.07522503103245981, 0.020793000076082535, 0.031206541680148803, 0.02620947954710573, 0.02288025145389838, 0.08739793760469183, 0.03813631963566877, 0.05594164838839788, 0.03701687521243002, 0.03858956406475045, 0.03229955451388378, 0.045122578740119934, 0.012849886261392385, 0.10042513778898865, 0.04879605759924743, 0.052274370173108764, 0.04584104448440485, 0.027371844225854147, 0.042754237074404955, 0.06649134069448337, 0.05542302445974201, 0.07308895190362819, 0.015260637028404744, 0.0717510526010301, 0.03943892239476554, 0.015684606514696497, 0.05548819615796674, 0.08852132654283196, 0.055693399990559556, 0.027252503168710973, 0.04892443430435378, 0.04335068631917238, 0.04061394254676998, 0.022471296542789787, 0.029263265096233226, 0.05341527008567937, 0.043473285404616036, 0.06308279000222683, 0.05115662897878792, 0.03980402565503027, 0.0386341931152856, 0.04304804591811262, 0.021918413222010713, 0.01754388867993839, 0.06366166519001126, 0.03668865298095625, 0.02948229699541116, 0.06600638429517858, 0.02357030964049045, 0.077577921183547, 0.040971628041006625, 0.009650314150349004, 0.062250987175502814, 0.02548968721384881, 0.06297034720773809, 0.018564536549092736, 0.03170544674503617, 0.01969664757780265, 0.03569001164578367, 0.048721019047661684, 0.038281988381640986, 0.04025542955787387, 0.08380899307667278, 0.029943640111014247, 0.025993234412453603, 0.007173262692958815, 0.037652762184734456, 0.004404745259307674, 0.02170159663364757, 0.01752335716446396, 0.05537097393244039, 0.020793668008991517, 0.007433194814439048, 0.03733497083885595, 0.014880281705700327, 0.034563639273983426, 0.02686117612029193, 0.04777976428158581, 0.07110055274097249, 0.036519829227472655, 0.056042435753624886, 0.036459685579757206, 0.06228501835721545, 0.05131979756697547, 0.04185726254945621, 0.03443144050834235, 0.04256091873685364, 0.02378996865445515, 0.025063447683351114, 0.048774038077681325, 0.04733149595267605, 0.1357355891377665, 0.020127523675910197, 0.03901338975992985, 0.04883004425209947, 0.03155200771288946, 0.02491518698661821, 0.06490808736998588, 0.0029150466070859693, 0.011754732331610285, 0.03628603044489864, 0.07079505507135764, 0.03831889909633901, 0.01499959864304401, 0.035666849216795526, 0.02487551548256306, 0.0029082566516080988, 0.07439291279297322, 0.023577462088724133, 0.06117320321209263, 0.0471512208605418, 0.045082610376994126, 0.024955613625934348, 0.07666347650229, 0.041704665854922496, 0.05023533056373708, 0.010313597504136851, 0.014983811306592543, 0.013843074666510802, 0.08029995558899827, 0.047389223909704015, 0.029085468777338974, 0.044417683166102506, 0.08422470709774643, 0.030442296556429937, 0.06140901692560874, 0.0370599271991523, 0.0726357965322677, 0.024386367804254405, 0.05282450198137667, 0.026496750069782138, 0.03396749802050181, 0.021724623620684724, 0.04323154193116352, 0.001744092032822664, 0.03412236568692606, 0.04055996614624746, 0.05978937981126364, 0.042603295369190164, 0.043377117908676155, 0.044769446321879514, 0.0734553205256816, 0.02884114448534092, 0.014669765023427317, 0.05146013769262936, 0.029545429642894305, 0.04093623501830734, 0.01920954637171235, 0.0674966094084084, 0.047437719549634494, 0.02875922993553104, 0.04291755409212783, 0.0779947558476124, 0.031059084358275868, 0.028945175035914872, 0.023408946326526348, 0.04064635213580914, 0.010183353369939141, 0.009601360234228196, 0.07811543648131192, 0.027612645171757322, 0.011388431430532364, 0.07267289649462327, 0.03666831071313936, 0.0726643692178186, 0.025051200391317252, 0.020735964171763044, 0.009926791990437778, 0.03316282440209761, 0.09586829168256372, 0.0277309231023537, 0.029652740486199036, 0.0487811255879933, 0.024669528684171382, 0.03497437348414678, 0.017795691965147853, 0.12578732217662036, 0.021418337419163436, 0.0013947131424174586, 0.01217626664583804, 0.025386549095856026, 0.0239573192448006, 0.03171874974214006, 0.04050771523907315, 0.05804716216516681, 0.022455219768744428, 0.056111474041244946, 0.026962559059029445, 0.022213821393961553, 0.058382238130434416, 0.006042121558493818, 0.05716880441468675, 0.07686325523536652, 0.010789981170091778, 0.04633619428204838, 0.07341900723986328, 0.010661263077054173, 0.03232628296245821, 0.054901836410863325, 0.022874048954690807, 0.021854946608073078, 0.016712063588784076, 0.027299690773361363, 0.020833437847613823, 0.02324724348000018, 0.04015243430330884, 0.08664545181090944, 0.059931727446382865, 0.004983100943718455, 0.02256403531646356, 0.010817225411301479, 0.041569249879103154, 0.03395166429982055, 0.054599118084297515, 0.036763802854693495, 0.1024599805532489, 0.033193133713211864, 0.08437980111921206, 0.0023807821480659186, 0.049545333604328334, 0.05879903197637759, 0.05315072412486188, 0.029460591031238437, 0.06909746647579595, 0.12277720830752514, 0.06053189114027191, 0.047831844494794495, 0.008514185319654644, 0.03959223526180722, 0.03930108330678195, 0.07120779308024794, 0.018495151307433844, 0.017187455559906084, 0.022219207530724816, 0.04437031930137891, 0.025323125155409798, 0.01815865412936546, 0.018184261934948154, 0.047992296822485514, 0.024416964697593357, 0.005974597715976415, 0.03406405885471031, 0.03468326605798211, 0.01263530724827433, 0.06131176960479934, 0.058403868024470285, 0.015059068791742902, 0.01098418173569371, 0.06041898079274688, 0.06293464990449138, 0.03537846547260415, 0.07200530497357249, 0.013201160527387401, 0.01369989025988616, 0.05255811178358272, 0.049859495848068036, 0.05662255032802932, 0.05041989898018073, 0.041506319466861896, 0.05885907172341831, 0.030370592103281524, 0.059739199496107176, 0.02808307031955337, 0.013358362248254707, 0.03480433631921187, 0.15775619423948228, 0.1590896406560205, 0.31530915875919163, 0.21355421107728034, 0.15680251963203773, 0.14425176341319457, 0.08662095351610333, 0.13285469060065225, 0.1440599182387814, 0.1870961714303121, 0.07561384220025502, 0.1131623140827287, 0.1380486853304319, 0.24178117455448955, 0.12042445916449651, 0.2169172087451443, 0.1300329709192738, 0.1574138563591987, 0.18216811789898202, 0.09889373832265846, 0.06657748919678852, 0.13237944891443476, 0.22471740347100422, 0.10795530208270065, 0.17559720174176618, 0.19803505711024627, 0.16795202682260424, 0.15571055322652683, 0.11719152287696488, 0.1306466676760465, 0.1441729028010741, 0.07674241132917814, 0.11754782797652297, 0.14551371132256463, 0.1554776227567345, 0.1526187956915237, 0.12380471176584251, 0.10582847753539681, 0.17929662979440764, 0.12839712901040912, 0.09277043369365856, 0.16842688259202987, 0.09682207761215977, 0.07204529189039022, 0.14380317967152223, 0.11794727412052453, 0.14141960913548246, 0.09575917370966636, 0.17260342254303396, 0.0826279169996269, 0.12791623215889558, 0.15479426801903173, 0.15456344524864107, 0.15481915965210646, 0.16629712656140327, 0.24869122251402587, 0.21275561564834788, 0.1666691800346598, 0.09453346487134695, 0.1606513568549417, 0.1165934483287856, 0.06498530783574097, 0.11729055506293662, 0.1086987930466421, 0.11706101620802656, 0.09028584943735041, 0.10623695561662316, 0.12299760390305892, 0.09476643244852312, 0.2447979009593837, 0.21887257491471246, 0.14593042724300176, 0.09559222758980468, 0.2674020716222003, 0.16824014339363202, 0.16292969085043296, 0.1972432597540319, 0.209248433529865, 0.18078763416269794, 0.08815677618258633, 0.19527226395439357, 0.13164626638172194, 0.0751337394467555, 0.10428509980556555, 0.1258117685210891, 0.07324979756958783, 0.17811291909310967, 0.14608378463890404, 0.083522909990279, 0.07679662521695718, 0.07832964256522246, 0.12259341543540359, 0.1364883643691428, 0.11710500330082141, 0.1438131689792499, 0.11280024991719984, 0.10109339724294841, 0.181082637864165, 0.1155172599828802, 0.08497055809129961, 0.19320916762808338, 0.21001161367166787, 0.14686428650747985, 0.1296711145550944, 0.1260726185864769, 0.14391907345270738, 0.18412306846585125, 0.16458220139611512, 0.15912374976323918, 0.17392739915521815, 0.1440998012549244, 0.1638063750579022, 0.13366434402996674, 0.11172573882504366, 0.26640512980520725, 0.15170086291618645, 0.11205407237866893, 0.22310476109851152, 0.08020439665415324, 0.20191522780805826, 0.1034153917862568, 0.14592965540941805, 0.17046517634298652, 0.16504145722137764, 0.16155833553057164, 0.1420852859155275, 0.17125759710324928, 0.17667704145424068, 0.16122794622788206, 0.10360076543292962, 0.16374345577787608, 0.174827802402433, 0.10002989962231368, 0.14587917452445254, 0.16310495644574985, 0.18892998865339905, 0.10536468718782999, 0.1685561944032088, 0.15344295068643987, 0.23346913541899994, 0.07801350249792449, 0.12532046675914899, 0.15379898861283436, 0.1164471784431953, 0.1591534653562121, 0.22811554925283417, 0.11406379344407469, 0.17510846781078726, 0.12476266856538132, 0.18859832285670564, 0.10876262516831048, 0.06382954641594552, 0.12340677218162455, 0.15604745858581737, 0.13191627454943955, 0.1564393422449939, 0.1359240204328671, 0.18186627159593627, 0.06008707750879694, 0.1354472796083428, 0.09854434261796996, 0.11362247532815672, 0.18085447198245674, 0.130590116023086, 0.13108918064972386, 0.10036034087534063, 0.15962781646521762, 0.18457181548001245, 0.10381382118794136, 0.12099963103537448, 0.20500533777521923, 0.09628292958950624, 0.12794565089279786, 0.10004449766711332, 0.09203918074490502, 0.11477425883640535], [0.07619342984980904, 0.011960767369600944, 0.017535732476972044, 0.059375324490247294, 0.033673039797577076, 0.021158873314561788, 0.10459933255333453, 0.033372614707332104, 0.05239294681814499, 0.048629649536451325, 0.05952179846644867, 0.022966715368966106, 0.03845978841127362, 0.033362584581482224, 0.04445614125870634, 0.04490367486141622, 0.0392954949347768, 0.028479915235948283, 0.08668249240145087, 0.06945325949345715, 0.05578990145295393, 0.03307790415419731, 0.06226797864655964, 0.02873059787816601, 0.02611494292068528, 0.054587321646977216, 0.026203024717688095, 0.01200816370328539, 0.0798028873396106, 0.04343265281931963, 0.02255185852845898, 0.023910283780423924, 0.017103958380175754, 0.04477311253140215, 0.03550642286427319, 0.03710441895236727, 0.04830475583730731, 0.018723671564657707, 0.04450618056580424, 0.06015360733726993, 0.05264369254291523, 0.037403289243229665, 0.03049717466637958, 0.05832822833326645, 0.025938449070963543, 0.03990769255324267, 0.032441093208035454, 0.035473204334266484, 0.011330755423841765, 0.0297979342576582, 0.030379880081454758, 0.045443602139130235, 0.01674479601206258, 0.11880553080118261, 0.006205867630342254, 0.09055768328835256, 0.017044642227119766, 0.03223244952096138, 0.04168851672147866, 0.03282658326497767, 0.0073589828298281645, 0.045797502680215985, 0.02828948199748993, 0.014988923776400043, 0.03939541398722213, 0.04235565553244669, 0.052591642015613616, 0.04240821072016843, 0.027281641741865315, 0.015970899257808924, 0.04318331346439663, 0.05318061783327721, 0.055778090172680095, 0.04749686871946324, 0.019259990149294026, 0.03950346326746512, 0.07226720888866112, 0.06730871988111176, 0.036078436896787025, 0.026896537601714954, 0.08413314091740176, 0.029144527034077328, 0.009787263588805217, 0.07037943010800518, 0.02083355102513451, 0.07147838012315333, 0.06991348011069931, 0.03246207743359264, 0.02142971639841562, 0.06645207366091199, 0.0121506913092162, 0.0772791176859755, 0.02396563686488662, 0.019178422553522978, 0.038243715825956315, 0.03595455389586277, 0.006808625130361179, 0.051904955034842715, 0.0749227988126222, 0.040464366393280216, 0.07159550586948171, 0.029660058062290773, 0.015882537300058175, 0.02624487256980501, 0.09935247464454733, 0.044611632329178974, 0.011551198331289925, 0.022404709197871853, 0.06573701437446289, 0.010802248871186748, 0.04267216667358298, 0.02729916013777256, 0.0010185002793150488, 0.03430429947911762, 0.048226392464130186, 0.04272775353456382, 0.05421433306764811, 0.06798792601330206, 0.03384482472029049, 0.04002791305538267, 0.050415186342434026, 0.08653706114273518, 0.06616150800255127, 0.03929881233489141, 0.04565154078591149, 0.05048513747169636, 0.009276131640945096, 0.05421226618636865, 0.03663226460048463, 0.027636163831630256, 0.009523825283395126, 0.046309595709317364, 0.022101098438724875, 0.10737079399405047, 0.05192888929741457, 0.056044706725515425, 0.02913868818723131, 0.03536671727488283, 0.030813555931672454, 0.04653974683606066, 0.020971868798369542, 0.01930347443703795, 0.0461843211814994, 0.06309445656370372, 0.010087001264764694, 0.04245277668815106, 0.031488079112023115, 0.027465380808280315, 0.004271007928764448, 0.05306011902575847, 0.06453248643083498, 0.02808462882967433, 0.016840510797919706, 0.04308804767788388, 0.06230425482499413, 0.051861877072951756, 0.050826187725760974, 0.019041362720599864, 0.02003580164455343, 0.0016105055669868307, 0.11159477202454582, 0.09297567463363521, 0.054070913029136136, 0.06793592372559942, 0.06075727396819275, 0.030665634767501615, 0.07512689684517682, 0.05335157155059278, 0.046582431459682994, 0.04541803886240814, 0.07935462272143923, 0.03096462009125389, 0.013605227468360681, 0.015390807875519386, 0.07552883660537191, 0.02128515345248161, 0.03904559154761955, 0.037322717980714515, 0.028750858509738464, 0.025245594842999708, 0.023589560951222666, 0.028396946836437564, 0.07385908596916124, 0.013651705394295277, 0.031084640213521197, 0.043149542034370825, 0.014182929135131417, 0.02403680882707704, 0.0330938863044139, 0.03400243462237995, 0.049755673098843545, 0.01708445659460267, 0.05396402892074548, 0.08599695574957877, 0.033617003937251866, 0.032166732344194315, 0.0888704253884498, 0.05196436766709667, 0.040014090554905124, 0.006279650096985279, 0.08991447131847963, 0.03150067706883419, 0.02556929553975351, 0.03431444834859576, 0.13811277720378712, 0.02199595281126676, 0.054027567894081585, 0.027150005153089296, 0.03527741464495193, 0.043967533492832445, 0.0584957570390543, 0.053169938328210264, 0.042805408156709746, 0.07011483219685033, 0.07248424255521968, 0.04112147507839836, 0.037957246822770685, 0.03612584529037122, 0.0066071747096430045, 0.026245774279232137, 0.011280845992587274, 0.057965529631474055, 0.007977306413522456, 0.0030138700640236493, 0.018735332560027018, 0.014440345839830115, 0.02345085726119578, 0.04340213199611753, 0.020902227515762206, 0.06189825551700778, 0.041838701436063275, 0.039362555398838595, 0.03207013440260198, 0.03563448786735535, 0.011105344765383052, 0.06425098239560612, 0.01373827599309152, 0.008547414054191904, 0.014066278363316087, 0.011618651205935748, 0.06134750772616826, 0.042234752254444174, 0.039228898313012905, 0.05544707004446536, 0.0717063233605586, 0.04559194632747676, 0.03705147042637691, 0.06520758106489666, 0.0034584921286295867, 0.028528607545013074, 0.07385646618786268, 0.023724936108919792, 0.03728201860212721, 0.031991578071028925, 0.015812832934898324, 0.06703536462737247, 0.05824321531690657, 0.03176952377543785, 0.04980930440069642, 0.0024062593820417533, 0.028511820164567325, 0.06029378047969658, 0.014244679532566806, 0.034068114691763185, 0.04431915564055089, 0.02198398196924245, 0.0642749537655618, 0.06467709390562959, 0.052195832395227626, 0.005178239862289047, 0.043014003604184836, 0.028780410830222536, 0.031216723946272396, 0.035355763175175525, 0.009522059899609303, 0.03509545487759169, 0.051720197370741516, 0.050906391625176184, 0.14555283734807745, 0.04780912735441234, 0.026695703163568396, 0.023139581971918233, 0.03955223350203596, 0.03759787665330805, 0.030125011726340745, 0.040552351711085066, 0.01142652123235166, 0.008312257141369628, 0.032088996085803956, 0.06594042220967822, 0.04051914802403189, 0.05440392953460105, 0.059573418548097834, 0.01797335469746031, 0.03418823871470522, 0.006297056243056431, 0.03165575624734629, 0.04950417409418151, 0.015108577463252004, 0.05169130185095128, 0.031584406169713475, 0.010543545467953663, 0.005948875805188436, 0.008156457151926588, 0.010449741712363902, 0.04436060829902999, 0.03221076025511138, 0.04402328733704053, 0.02839679284079466, 0.05793057076516561, 0.03844881946861278, 0.04103229490283411, 0.032711509556975216, 0.05723111884435639, 0.040840713190846145, 0.07171919962274842, 0.03929994039935991, 0.040273237391375005, 0.037628545906045474, 0.057281699919258244, 0.0383355009398656, 0.07968993246322498, 0.057580952416174114, 0.04669453657697886, 0.026958998605550732, 0.03322390686662402, 0.03286773535364773, 0.011176203170180088, 0.03387199845747091, 0.048478893368155695, 0.03802445571636781, 0.009756421786732972, 0.032936272691586055, 0.008025298320717411, 0.027319892033119686, 0.04599706990120467, 0.08153873364790343, 0.04755549467517994, 0.048469093308085576, 0.04626599453331437, 0.07799875602358952, 0.04464489538804628, 0.059578654399956577, 0.022761129330319818, 0.029633481753990054, 0.06179081479785964, 0.07486484450055286, 0.032881936349440366, 0.030651385532109998, 0.06214196197106503, 0.08115868724416941, 0.14496290415991098, 0.1488105984753929, 0.11659033873002045, 0.13305605010828003, 0.16426442860392854, 0.0960808501986321, 0.07001410049269907, 0.19486853561829776, 0.07107983939931728, 0.18682316498598084, 0.09250700095435604, 0.14812096516834572, 0.11279863945674151, 0.11411593673983589, 0.12963814835529774, 0.16958491498371586, 0.12304936128202826, 0.0953693977498915, 0.13648943306179717, 0.12929270829772577, 0.15081960707902908, 0.22965733136516064, 0.15323874133173376, 0.18256411305628717, 0.16278143943054602, 0.14082966110436246, 0.06671258233836852, 0.0639270200917963, 0.10975965604302473, 0.16644110321067274, 0.15862090018345043, 0.08542914598365314, 0.10331549870898016, 0.15365639235824347, 0.0807440270727966, 0.21599180996418, 0.21469305153004825, 0.13364150072447956, 0.10581183116300963, 0.11024766266928054, 0.1274041205761023, 0.1768428520881571, 0.1248998471419327, 0.13138183916453272, 0.12489211396314204, 0.12563251017127186, 0.17340483813313767, 0.1393111379002221, 0.1442390726879239, 0.13825335481669754, 0.0951602531131357, 0.14519678457872942, 0.15469116886379197, 0.08902241723262705, 0.27466547093354166, 0.14031527854967862, 0.15273112716386095, 0.11095925612607971, 0.16467847279272974, 0.10886257761740126, 0.11605384017457254, 0.24353243527002633, 0.17882658314192668, 0.0752685654151719, 0.15691879933001474, 0.23558854591101408, 0.13125552562996745, 0.11992727959295735, 0.14043912815395743, 0.18016883142990991, 0.2065944837522693, 0.15907484223134816, 0.15257861581631005, 0.1656055191415362, 0.15240582899423316, 0.19771603750996292, 0.11956547517911531, 0.18994287180248648, 0.17349343572277576, 0.06728111940901726, 0.13839681196259335, 0.16862004878930748, 0.08743359037907794, 0.11592609429499134, 0.1633844047319144, 0.07333554531214759, 0.1560330015490763, 0.16328501631505787, 0.166879519529175, 0.11694993154378608, 0.11669905594317243, 0.18367837357800454, 0.2073903926066123, 0.10512549299164675, 0.15384886093670502, 0.2078183594858274, 0.15428698039613664, 0.21660795580828562, 0.1747620481182821, 0.14996969955973327, 0.15680554759455845, 0.16742674954002723, 0.0906589716032613, 0.2498647361062467, 0.18810690235113725, 0.09830606868490577, 0.2906061499379575, 0.11401775060221553, 0.14016576547874138, 0.06367102367221378, 0.11855257718707435, 0.055767399535398, 0.12762744765495881, 0.10544647928327322, 0.14789793494855985, 0.08749980479478836, 0.1372757533681579, 0.20745294081280008, 0.1506858572247438, 0.13005769927985966, 0.12471634370740503, 0.12417326972354203, 0.18561705626780167, 0.1033336367981974, 0.14301245100796223, 0.1583806224516593, 0.1576156314695254, 0.07854609735659324, 0.08527539524948224, 0.11034484690753743, 0.2352003284613602, 0.11856845914735459, 0.068260116095189, 0.13177243148675188, 0.169799959694501, 0.12596420565387234, 0.12397289727232419, 0.16311240760842338, 0.1226459298050031, 0.1260638315579854, 0.21172266482608393, 0.1349013260914944, 0.14077975909458473, 0.16922629438340664, 0.20878944487776607, 0.0811777233320754, 0.1075843618309591, 0.15356096700998023, 0.11258164289756678, 0.2045952418120578, 0.08160482189850882, 0.14568137732567266, 0.08706171502126381, 0.11046333820559084, 0.18462397361872718, 0.19502653885865584, 0.18655738706002012, 0.18091320554958656, 0.14662777888588607, 0.10479854725417681, 0.07250547540024854, 0.2771983912680298, 0.19650520873256028, 0.16925891919527203, 0.1456211891490966, 0.1401944865938276, 0.12537082890048623, 0.14829520659986883, 0.12106978625524789, 0.21052506112027913, 0.1412019965937361, 0.1542356683057733, 0.10161793979932554, 0.08277126282337122, 0.1446312532061711, 0.18263670994201675, 0.27218957722652704], [0.0028009369952997076, 0.05895661219255999, 0.06390189097146504, 0.02236456271930365, 0.019612979704106692, 0.017769308615243062, 0.025995601863542106, 0.022337531845550984, 0.038575526341446675, 0.02857297869923059, 0.03918574613635428, 0.021246626711217687, 0.017149216400866862, 0.02350590606511105, 0.025801329866226297, 0.038948923101997934, 0.051971525681437925, 0.03184392779076006, 0.08513260603649542, 0.08133237206493504, 0.016744632739573717, 0.07393371633952484, 0.057793933956418186, 0.04418788455950562, 0.015121529795578681, 0.013054236624157056, 0.024936699992395006, 0.00946264541198616, 0.05013695888919756, 0.020574172267515678, 0.05921069016039837, 0.0755441990622785, 0.058970954196411185, 0.032610455018584616, 0.07076169553329237, 0.028146386648586486, 0.04838297078094911, 0.021070416732982267, 0.05042143522587139, 0.027885952185897622, 0.013755489180766745, 0.07452786492649466, 0.06211301079019904, 0.0380299030803144, 0.04436079383594915, 0.015492451493628323, 0.029665451620530803, 0.027177984120498877, 0.042927176036755554, 0.022639875387540087, 0.023715861498203594, 0.02552384827140486, 0.059203027485636994, 0.05606217688182369, 0.0940382519911509, 0.021135736860742327, 0.04555874635116197, 0.06950469032744877, 0.06790294268284924, 0.0368701897241408, 0.017993786022998393, 0.031041693982842844, 0.07556519442005083, 0.04420621189638041, 0.053858918545302004, 0.055206094693858176, 0.01550047503769747, 0.05688435034244321, 0.07242680774652399, 0.030559323968191165, 0.041787519221543334, 0.028702511299343314, 0.017998524635913782, 0.08802100026514381, 0.07102653093170375, 0.047710258440929465, 0.046160950951161794, 0.0322653118200833, 0.044281922091613524, 0.035081676905974746, 0.01790989550499944, 0.05821713253681082, 0.032918197684921324, 0.1330210207379423, 0.04189648505416699, 0.02877741069823969, 0.07833227718947455, 0.03393207531189546, 0.059563102695392445, 0.029278111760504544, 0.0585297956422437, 0.06655339908320457, 0.045811043164576404, 0.009691006107459543, 0.08032342229853384, 0.038574171921936795, 0.05012905501644127, 0.019854676793329418, 0.029126149602234364, 0.03438595427724067, 0.061375134173431434, 0.02686851039470639, 0.12108785755117424, 0.1461944982293062, 0.02441455828375183, 0.023838833512854762, 0.007169381724452251, 0.03626048201113008, 0.024635920526634436, 0.04024187051982153, 0.04123405888094567, 0.007802050095051527, 0.04701966405264102, 0.030224474357964937, 0.0280795005892287, 0.018273841014888603, 0.01515133073553443, 0.043312257912475616, 0.0443199942674255, 0.030839082101010717, 0.03698698150401469, 0.026236543817503843, 0.023716850409982726, 0.024027001345530152, 0.054471138428198174, 0.03139182626910042, 0.016601559655100573, 0.027313405662425794, 0.11524632413056679, 0.04037462960695848, 0.07300658835447393, 0.01653195733524626, 0.015389536947623128, 0.02799571397190448, 0.03524107167322654, 0.06031209668435622, 0.023787209720467217, 0.027722863378585316, 0.03234556395909749, 0.056621132825966924, 0.016161464227479883, 0.0069231171801220626, 0.10291725484421477, 0.14960125292418525, 0.030354880836966913, 0.021473992928804364, 0.04692130351031665, 0.05790650291601196, 0.005376194767450215, 0.05212283846049104, 0.02312252741830889, 0.010761880676000146, 0.01917833349580178, 0.05352558662707452, 0.014766537369723665, 0.024827383494994137, 0.06790173298213631, 0.04699975594121497, 0.014883871845086105, 0.0415755024732789, 0.015082477057148935, 0.014770068137295311, 0.03727383642399218, 0.0179820767880301, 0.04430613094882574, 0.09138183828326873, 0.07475653546862304, 0.06770631807739846, 0.026232619711663574, 0.0209335016188561, 0.06683514802716672, 0.04317765087762382, 0.06362590851495042, 0.04265539413609076, 0.014236699589673663, 0.04614325815055054, 0.04639355858671479, 0.10737004442489706, 0.022956061839067843, 0.06560961730428971, 0.10035364670329727, 0.0404593012353871, 0.03851897097774781, 0.03653754058177583, 0.008764469057496171, 0.0449812515580561, 0.03597981660277583, 0.029824516132066492, 0.040552281207055785, 0.01634056487091584, 0.007276876249306952, 0.02890450163249625, 0.059093768504681066, 0.07483098772354424, 0.030313721326820087, 0.042407854489283636, 0.010985873832396464, 0.025255576729250606, 0.028446021351555828, 0.039305280151893385, 0.07582097561680712, 0.111646121222293, 0.021586534057860263, 0.031147707923082635, 0.01454114897569525, 0.025876320178213064, 0.06554893931024708, 0.04057391110109165, 0.006129357307145256, 0.056629144310136326, 0.049140514311147854, 0.040127379397745244, 0.08107231609756127, 0.01468488721002359, 0.06829790625488386, 0.00449350844064611, 0.012050381701556034, 0.03189708411809988, 0.021662726649083197, 0.04871918965363875, 0.02695038783713244, 0.041909713836503215, 0.06367186229908839, 0.06612316123209894, 0.05749953881604597, 0.01979648684937274, 0.029050983030174393, 0.059926309768343344, 0.013727987043239409, 0.03248507287935354, 0.0318847533344524, 0.0525555921922205, 0.03088852212385973, 0.04673753661336377, 0.05236393626546487, 0.034697882656473666, 0.028514104124042206, 0.022010832872183528, 0.056848927633836865, 0.04419697215780616, 0.0665373241645284, 0.03387750519323163, 0.023038473627821077, 0.05313231515174266, 0.08906109796953388, 0.04616589365468826, 0.020128573814872652, 0.05602876168268267, 0.03835996954876464, 0.03170004390995018, 0.012729343852697639, 0.05713575657864567, 0.06367681984556839, 0.05675272303051315, 0.019576516133383848, 0.07246618610224687, 0.0471314129390521, 0.09868472727248445, 0.0400615471880883, 0.01652319813729264, 0.07851098635001108, 0.020895629822916817, 0.04443270794581622, 0.05244930551270954, 0.09157377993687987, 0.0273627807473531, 0.054351070066331886, 0.05184378722333349, 0.015342744536610553, 0.009566502485540695, 0.012929555814480409, 0.039909800252644345, 0.03087515418883413, 0.06496381523902528, 0.019166505517205223, 0.05463295259687584, 0.052893191459588706, 0.035931387756136246, 0.01862140361481579, 0.062054718800936826, 0.05567014108237345, 0.03168088907841593, 0.02357216686505126, 0.05445100396173075, 0.066880678787129, 0.0022654013764622505, 0.020527660017251037, 0.020570739834511187, 0.018538531694503035, 0.026534319440543186, 0.04269633842341136, 0.06066762995033059, 0.030888126930221915, 0.024672215258760843, 0.01457357897379552, 0.05177949868084397, 0.05586152241448872, 0.017057286568160634, 0.011591704751481302, 0.03965968164266087, 0.02238291417597793, 0.018878962255257647, 0.008056646638578968, 0.03653551822935697, 0.10015275474870577, 0.034952138739754446, 0.026092537482327316, 0.07540348044130951, 0.0501249546505278, 0.024287569394800812, 0.03923940712411422, 0.014685855712741613, 0.07167816627770662, 0.02759749608230777, 0.02271816454594955, 0.008590807428845437, 0.010462225563969696, 0.05313553236192092, 0.06584568705875427, 0.09177474610623904, 0.04866495721216779, 0.04213279600662645, 0.027256041357759386, 0.04863061803916935, 0.01765361892466899, 0.013733384312217822, 0.05626202982966788, 0.013984656961838482, 0.06673696188954636, 0.07239514030516148, 0.09030409142724238, 0.0112921275649569, 0.027117710596940015, 0.015804524591658264, 0.018632886494742706, 0.02492267154593719, 0.04676337448472623, 0.035624880765681155, 0.011666670943668578, 0.09110471291933209, 0.029998328973306343, 0.02553391550463857, 0.020627935300581157, 0.040979042096296325, 0.019897910606232472, 0.059516317705856636, 0.04442101169843227, 0.08408251160290092, 0.036150206287857145, 0.052116340957582, 0.01518659573775949, 0.0481235419283621, 0.14425044239033014, 0.16415580786997452, 0.12693281227257103, 0.14246103528421372, 0.21799072535941377, 0.11785422364482656, 0.0861817727854941, 0.1847996102878824, 0.07603078076499514, 0.13375669688684866, 0.11253256467171013, 0.07278922072146088, 0.20947110751876608, 0.07786040485370904, 0.17440722731407732, 0.08234639069996774, 0.15194268431514502, 0.18214341922430322, 0.15853636956308037, 0.23800288588972762, 0.10288406600011513, 0.11242110893363133, 0.13363921490963548, 0.12623439193703234, 0.14693324686959386, 0.13007451634621248, 0.13046224397839978, 0.0851086420880165, 0.12810288229957223, 0.09513274912023917, 0.11675030124024488, 0.1673620639485307, 0.11170979749294929, 0.1527342144981958, 0.12948266841704026, 0.10183895137743093, 0.18851728033041582, 0.1402695622527972, 0.1693084352882579, 0.12473096401663497, 0.1100892067188397, 0.22001367149641737, 0.1659540316904895, 0.20925889781210572, 0.08565952346543781, 0.12616124586202204, 0.19427213090239093, 0.18787395703839138, 0.20815096038859338, 0.18099748383974656, 0.13801972672808915, 0.06556796055519953, 0.14948068361263722, 0.1498383839498274, 0.16979660518700257, 0.16889719641767442, 0.10425061962450854, 0.08876231673639268, 0.10498302290216088, 0.13379600102780387, 0.11824190674815327, 0.11952997083426453, 0.2539529901696369, 0.18761490297038108, 0.12634255253942683, 0.10061607012175955, 0.09473977450397797, 0.13883692037779838, 0.3520009992644191, 0.13642433186760172, 0.10255507193505764, 0.08874110615579411, 0.10151746042538434, 0.18262899160617962, 0.16059306857641786, 0.18420283449813724, 0.10306246345862746, 0.09732195117976516, 0.13009640970267355, 0.0896723530604504, 0.07697817680309527, 0.14660514338174835, 0.09634803820517845, 0.32290141854900867, 0.11952168104471639, 0.10129240414244123, 0.20563651953125373, 0.12472189497202635, 0.14552313659805804, 0.08601170964539051, 0.2178598995669745, 0.13716340705286711, 0.15264434041455388, 0.095984244835563, 0.2026088983984664, 0.1195571779680904, 0.2033118755207397, 0.1388818203122355, 0.09834955853875726, 0.16380733984988183, 0.18489600042812526, 0.17071882757591084, 0.1297357407747768, 0.16699504223652184, 0.12135886019677855, 0.09067382197827101, 0.1475626029423438, 0.14381674613105133, 0.13058144773822278, 0.15375490504084155, 0.08074315133853815, 0.07322347359149717, 0.13553096418036148, 0.09821128900512122, 0.11637590258033015, 0.22642250260105357, 0.12219583950354718, 0.06924467146745883, 0.13436453067697585, 0.062006486623431556, 0.19642814411781728, 0.13194857281632721, 0.10981951025314629, 0.13157331326510757, 0.2660741319414228, 0.07931760439532809, 0.09099721282836981, 0.10096585174323991, 0.41101595910731703, 0.19792464037891477, 0.18839389085769653, 0.14531370252370834, 0.12573837011586875, 0.12271526124095544, 0.10040803128504194, 0.1345240478985943, 0.10934760823147371, 0.11950950240134262, 0.09084841964067891, 0.13623536622617394, 0.08326324736117385, 0.1569799819844775, 0.17125455429777503, 0.25154955976177007, 0.1228273700689897, 0.10825458797626197, 0.15701982047175989, 0.11574339980143122, 0.0725494402286131, 0.162325790442992, 0.09930974920280278, 0.14987005881266668, 0.11198200241778977, 0.12236306021804921, 0.15403375960886478, 0.19960269564762712, 0.13720753515372053, 0.12302942719543353, 0.0863606452185195, 0.10548325270065106, 0.12671960808802396, 0.09157809923635796, 0.07600094642839395, 0.16107691917568445, 0.09684115822892636, 0.13340800622245297, 0.170045803533867, 0.16341728187398985, 0.11388898055884056, 0.16037417954066768, 0.19872584816766903, 0.16305426775943488, 0.12502390454756096, 0.08732321075513028, 0.058383522045915015, 0.20437121711438522], [0.011213738216611091, 0.05580169046879746, 0.023897949286038056, 0.0373865278379526, 0.049280175371677615, 0.08421451741014607, 0.05381775903515518, 0.04484996934479568, 0.06445428633014672, 0.03174944125930779, 0.02165895468351664, 0.032120233081514016, 0.05504874083271716, 0.07916131551610306, 0.031884590061963536, 0.03913401102181524, 0.030707317491760477, 0.014421219766518334, 0.04336722136940807, 0.03383772978850175, 0.03449420022661798, 0.06011766512528993, 0.027724260471586604, 0.05032979112002067, 0.1251557990326546, 0.04111182344786357, 0.05279530960251577, 0.04882002525846474, 0.03588312218198553, 0.03613437627791427, 0.05547505272261333, 0.015604090913257096, 0.04732817855256144, 0.08104910171823576, 0.050852136919274926, 0.042527099067228846, 0.01655395459238207, 0.03242290316848084, 0.009138746190728853, 0.012387273145577637, 0.02237363176391227, 0.022510541311930865, 0.0033291731278950465, 0.05058341266703792, 0.03910180923412554, 0.0927935961226467, 0.07389549573417753, 0.041193797369487584, 0.08736161689739674, 0.08270174585049972, 0.03259697761677671, 0.03805840155109763, 0.03596115901018493, 0.04926769244775642, 0.057255157007602975, 0.0013987930992698239, 0.013682210446859244, 0.08237025074777193, 0.03685072690132074, 0.03829725435934961, 0.0890329854155425, 0.058634486704249866, 0.008925247930164915, 0.14250900771003217, 0.026705454984039534, 0.03487946392851882, 0.047979157097870484, 0.041046187907340936, 0.014207799431460444, 0.029646118673554156, 0.04994171467842534, 0.07287706874194555, 0.0391099839907838, 0.05214952980168164, 0.0022775593788537662, 0.026655436086002737, 0.054301587369991466, 0.01773771167790983, 0.02194098193285754, 0.026865818254009355, 0.027340618362359237, 0.0521069565002108, 0.04252579659805633, 0.07654180139070377, 0.0022886009128342266, 0.041302314202766865, 0.05362871175748296, 0.02935423755843658, 0.08278059904114343, 0.012054865201207576, 0.0716505732270889, 0.018708945499383844, 0.03215531811292749, 0.05633547647448722, 0.06347245463985018, 0.04916507568850648, 0.03710349126777146, 0.03441772561927792, 0.006400205029422068, 0.06920026135048829, 0.021167808772588614, 0.023362653009826317, 0.04306300019379705, 0.047163451454252936, 0.020777504032594152, 0.0443243766494561, 0.04930745672027115, 0.06298545733443461, 0.025644399029260967, 0.050258678529644385, 0.04122060003282968, 0.13338355987798423, 0.014879348454996943, 0.031504525104537606, 0.016414119127148297, 0.06136583506304305, 0.014295269884314621, 0.03897335089277476, 0.01840613069362007, 0.035370235054870136, 0.02467104081006255, 0.03592605913581792, 0.018413999314361718, 0.06374674499966204, 0.05135337974934373, 0.04212190870021004, 0.04918990423902869, 0.03322252647194546, 0.02874351124773966, 0.04469885694561526, 0.06873745063785464, 0.040140315031749196, 0.026275599338987377, 0.08014610095415264, 0.014679850810352946, 0.04759230891068, 0.04710522625828162, 0.06143111808341928, 0.006742499308529659, 0.038742383403587155, 0.04845808354730252, 0.060902185723534785, 0.017777563152776565, 0.04263138565875124, 0.060255849311943166, 0.054559583877562545, 0.0050409624873282155, 0.03683135684696026, 0.021000845954404213, 0.0540394274139544, 0.0316980697971303, 0.04418083786731586, 0.01509409074060386, 0.012723077343252953, 0.009196689370583044, 0.05014430615119636, 0.03303763151052408, 0.047266480105463415, 0.019965874635090586, 0.015703559110988863, 0.05688384197128471, 0.006236783183339867, 0.04458592062292155, 0.0035362276912564994, 0.053708600244135596, 0.005179394829610828, 0.04235069798596669, 0.044981897226534784, 0.025004665876622312, 0.027564297961362172, 0.035664058741531335, 0.021516981832974125, 0.08778486371738836, 0.08268340738140978, 0.018003029472311027, 0.02527299122448312, 0.016859235183801502, 0.0313938671752112, 0.023645151522941887, 0.04529418554739095, 0.028397739079082385, 0.08279967223643325, 0.04478966613532975, 0.028525284578790888, 0.017600713072170038, 0.0221971676000976, 0.02438595962303225, 0.009658960170781938, 0.02698045595025178, 0.039546144180349074, 0.028697511079371907, 0.08016909268917516, 0.026364098594058305, 0.02936733089882182, 0.029564927717729006, 0.03535838295647409, 0.009664113458711654, 0.04727204250229988, 0.012793616624549031, 0.022570731343876105, 0.11376732029020786, 0.04642551917640958, 0.016643657982058357, 0.06236796820303425, 0.08811221763608046, 0.04304925190808717, 0.08434955860138871, 0.014631327339884592, 0.04186265425232705, 0.020943793351761997, 0.017547063216625247, 0.013282844083732925, 0.07545733809820376, 0.05475035293784458, 0.01231667634783662, 0.031131744326557964, 0.09604129372746684, 0.03129368466034066, 0.017129319421655964, 0.04320326610468328, 0.04736271810543258, 0.015350666963058757, 0.10545668381382711, 0.029753828421235085, 0.03143732734315563, 0.018317946851311717, 0.019783799834840465, 0.025678237252577674, 0.04864670780079905, 0.08631524804513901, 0.07082782831275836, 0.0008504300376444007, 0.05905322126636747, 0.07772108889184892, 0.043311705012456514, 0.007605508053529775, 0.02893234144721646, 0.06028562056599185, 0.03871068998705596, 0.08665471381391399, 0.016029933394747786, 0.04305141897930298, 0.03334713306685444, 0.013557941529143136, 0.01940828424267238, 0.05915921850828454, 0.04555991152301431, 0.019072002287430223, 0.01087347556676832, 0.08561512076994404, 0.023549856050522067, 0.056562640456832014, 0.011685124445648398, 0.04290395794669166, 0.03389773613889702, 0.08092667703749612, 0.049469905425212346, 0.03908721490006428, 0.028314288283581845, 0.017836992483353242, 0.046531779880751856, 0.06647132497164421, 0.005559682431339752, 0.05408755569078494, 0.035653227096190676, 0.033897940229508094, 0.053639298494090326, 0.09822125604841858, 0.053201783885015175, 0.1095130477915518, 0.03134645136015024, 0.02361309074331075, 0.010778372125059832, 0.04353542914032005, 0.011012606919393875, 0.0907768023898825, 0.019756531473831274, 0.06753969108103774, 0.03853779184282757, 0.026774675097840372, 0.0738273591559846, 0.026076251051563304, 0.08034927872358821, 0.052881769806845114, 0.014404659668798558, 0.022613069013459608, 0.07602418307214975, 0.028989065649511758, 0.02675757416000124, 0.05921566626057029, 0.053983410107321106, 0.029919757798779756, 0.034585165267344564, 0.08856957356329076, 0.03912210697308183, 0.03381727248779498, 0.04985370709619019, 0.026603231563058216, 0.050080203145626, 0.05719762200897094, 0.01038199197864742, 0.038592198689002544, 0.025866141622827854, 0.06706099098664708, 0.03535394120262936, 0.08622467634268105, 0.04179691481112968, 0.050825029975385405, 0.01079238201782573, 0.029733298761129845, 0.029360024454945233, 0.06526008801301941, 0.02299551069882, 0.06414175310055725, 0.049359151016687974, 0.011265652374277124, 0.020008021201647352, 0.027303019305691123, 0.034269307216163725, 0.07345078600337729, 0.024969578989839647, 0.0670603230537381, 0.04660648075514473, 0.013788678024866385, 0.06942232677829452, 0.06712996619171463, 0.018451227297191508, 0.06468986626714468, 0.0725406309356913, 0.02849140924809035, 0.014506911848002346, 0.07944221841171384, 0.02882950946514029, 0.02968935063108802, 0.029702657338930294, 0.04549378987576347, 0.016233131573244464, 0.03881345517584123, 0.0037437254559335997, 0.05541455655475147, 0.06632339267525822, 0.039109572098823264, 0.024321715609403327, 0.04370633832877502, 0.008708118712092983, 0.010538350434217136, 0.025518556758470368, 0.026937622897094116, 0.08102205785689875, 0.04156080052780453, 0.007952078958624043, 0.02170530551666161, 0.11742823829990812, 0.12994061806239188, 0.09455535080633126, 0.08870526042301208, 0.1000429317355156, 0.14464670472079888, 0.16965003102086484, 0.16187688015634194, 0.12349734388408251, 0.10911093733739108, 0.14138858736259863, 0.1185791906027589, 0.1502713974332437, 0.16405769594712183, 0.14976976497564465, 0.23190655832877383, 0.15226241637719795, 0.17724533361615613, 0.12312027349253185, 0.12736934353597462, 0.18937110638944432, 0.18989246513228863, 0.1191049131739419, 0.11897126722033136, 0.22818946716142818, 0.14611967490054667, 0.10670591131201945, 0.14923576003639027, 0.2005526892025955, 0.11573144380236045, 0.176167007884942, 0.12191036497824825, 0.10901894813287072, 0.14921687979949638, 0.1747566749691032, 0.1117764571972657, 0.09566374836140312, 0.17694519425276667, 0.08373603253858164, 0.0847007057745941, 0.1237025106092915, 0.21733346453402191, 0.09536803961964324, 0.12857200868893415, 0.11577598008443601, 0.19447426224360242, 0.14373945887200534, 0.14595873275538906, 0.14991895150160417, 0.12265999350347556, 0.10597715940093622, 0.1283552570384927, 0.13644681894220412, 0.12596496264450252, 0.2613422874128446, 0.12885016563814133, 0.17536664614453912, 0.1536450968706049, 0.19297677150461823, 0.1506887367577292, 0.16369971359381452, 0.158902159309946, 0.0796904593880754, 0.17047960369382054, 0.18556774797616526, 0.14337236294522882, 0.12415159901138395, 0.07426980533637106, 0.13678948336746544, 0.14825505641056225, 0.2000496763503179, 0.15150346647715196, 0.1642600796185434, 0.18815364281181246, 0.11870911839650944, 0.15015108045190573, 0.1382127741817385, 0.08098468329990283, 0.11782178436988033, 0.1831787746050395, 0.11262657251791097, 0.15965190657880157, 0.1015512652520556, 0.14884184289257973, 0.11190527176950127, 0.1990667314385064, 0.10153358729439788, 0.10208080246229656, 0.19917870667995885, 0.10483189937076531, 0.11893290560692549, 0.1681766749243252, 0.18128812371287495, 0.18380096153123304, 0.1793248759349808, 0.09578457742463797, 0.16985342401312664, 0.22797457088017836, 0.08220256990171038, 0.19812009239103645, 0.13694367196876556, 0.19821847148705274, 0.16744748514611274, 0.1273390490678139, 0.24168490315787494, 0.1759693442727439, 0.1964167892583646, 0.19619778147898614, 0.13419964030617848, 0.13303893618285656, 0.13801387860439718, 0.14012784173246473, 0.1276536306249909, 0.17152493353933096, 0.18046833254629746, 0.20510094123892486, 0.12119287886889651, 0.1788972207577899, 0.15743073279736564, 0.09873422852251679, 0.12474319461034611, 0.09074998859432526, 0.14002799318404868, 0.09588548724423163, 0.15117163740796968, 0.13047940243268386, 0.14226991741452366, 0.23377484088996425, 0.13935220835264772, 0.17840725486166775, 0.19643172126961872, 0.2020651861676015, 0.10433846764499322, 0.1345339184626937, 0.08013174039660953, 0.17456368688726798, 0.09695372718852013, 0.12396647027344443, 0.10536980058532208, 0.1260106047266163, 0.13593731971923262, 0.1425445862696506, 0.18727514776401222, 0.19541986228432506, 0.11857214019983076, 0.20931209495756775, 0.1741251815110445, 0.10073529614601284, 0.2047921484336257, 0.11314669187413529, 0.07708362114499323, 0.14499886863632128, 0.2705942268949002, 0.13495753635652363, 0.13098240044200793, 0.14205151819624007, 0.14320585469249636, 0.13373262161621824, 0.1300277907284908, 0.09343832949525677, 0.16083606256870553, 0.1409479446010664, 0.11625344079220667, 0.11586152744712308, 0.1031987440364901, 0.11941906428546645, 0.08045214039157145, 0.12875209824414924, 0.09453045175177976, 0.08238649636041373, 0.10563496252871118, 0.15210000477964059, 0.15327132161473855, 0.13185718475142494, 0.22412114718463272, 0.08598764179623686], [0.052864340468659066, 0.050352248508716, 0.03910225823346991, 0.014180175767251058, 0.043119395995745435, 0.04586850023770239, 0.025905276925186627, 0.007735473882348742, 0.0135973662690958, 0.04384111976833083, 0.006920705664015259, 0.010685547076718649, 0.025942146821762435, 0.07606094164657407, 0.04163549769145902, 0.06779377275961451, 0.05745532165747136, 0.03096453659964027, 0.048627204159856774, 0.03816344513325021, 0.015092579542397289, 0.045151704325689934, 0.04656570345105138, 0.0474870055768406, 0.02850190878234571, 0.009999874055210967, 0.04208471225865651, 0.05833485942275729, 0.055447760241804644, 0.0147980452493357, 0.035003317243536, 0.049882836392498575, 0.0689294516632799, 0.08582697424571961, 0.026151566053158604, 0.039289249762077816, 0.03305038160760887, 0.026719203269749414, 0.049000775325112045, 0.04353939963039011, 0.06748892075847834, 0.08850430167512968, 0.06106408894993365, 0.046886919808457606, 0.03245348336349707, 0.055219460773514584, 0.010825785157067003, 0.0296420145969023, 0.049901482852874324, 0.04193932552880142, 0.017252961224585306, 0.03587262450309936, 0.031385829715873115, 0.041971568134613335, 0.022041824959160294, 0.036854459904134274, 0.05133920472871978, 0.03139619751891587, 0.05142034002346918, 0.03325683224829845, 0.03280343567894306, 0.049788713513407856, 0.023101793667592574, 0.021504895958059933, 0.06154554241220467, 0.03472972821327858, 0.04028913419460878, 0.028340391472738702, 0.06823599629569799, 0.06279347115196288, 0.02816276955854846, 0.04282003217667807, 0.051923890932812355, 0.03941180060792249, 0.041781541222007945, 0.07670991268241778, 0.01949334178789286, 0.021988729859003797, 0.05673954248777591, 0.014860584178677527, 0.03872794863127638, 0.010186385970882839, 0.027272299957985524, 0.0631780743424315, 0.010339710897824261, 0.07620653617777862, 0.013659049873240292, 0.06303483241936192, 0.03602067554311361, 0.05137325446412433, 0.03875228365359362, 0.05278093791275751, 0.03205665329005569, 0.014545498888764996, 0.09902319114189595, 0.01263041371203144, 0.04407511522003915, 0.10662172207958065, 0.08862631817464717, 0.058778493039426394, 0.043587891559582204, 0.02139328065823065, 0.06381180908647366, 0.13391844055149704, 0.06807194455177523, 0.08567335709813051, 0.0070390749715443235, 0.009978849011531565, 0.044108664005761966, 0.04180716015980579, 0.013936973045929335, 0.02831836638506502, 0.054789579153293744, 0.02968603694171179, 0.09037204246851616, 0.016219847129832488, 0.02113833437761059, 0.08490015054121614, 0.009516073550912552, 0.04270373021427076, 0.024166974108084105, 0.03729174073669128, 0.03596783091779798, 0.04651478840969503, 0.08615566403022967, 0.04369177739135921, 0.051475600339472294, 0.051140728464815766, 0.015986634643923026, 0.04340052153565921, 0.049919787925318815, 0.014593291343771853, 0.03450447526120115, 0.036622342086047865, 0.007742418529232964, 0.0031569545126330922, 0.022914874498383142, 0.047056715775397606, 0.07060414500301704, 0.012610564972419525, 0.026313467424188275, 0.07360336414421909, 0.046536002701031975, 0.023627547780051827, 0.011760857832996408, 0.031578702764818445, 0.018643662479007617, 0.02007300550758373, 0.04317184728279244, 0.04537042637821287, 0.022126288786239456, 0.024656418645463418, 0.0247724385917536, 0.041568722954252735, 0.0725577819684986, 0.0924838385253679, 0.019273074212833308, 0.07289660206879489, 0.06724850201862864, 0.045818594517186284, 0.030874573458277155, 0.03280857505160384, 0.014969018448027782, 0.043122713395860046, 0.022825599698990118, 0.05667414814524818, 0.01293260975216981, 0.034071903355652466, 0.010291917515132809, 0.012907269119750708, 0.06618947212700732, 0.013121706197125604, 0.03413155718590133, 0.03654098785773385, 0.02729712850850774, 0.027596076724876184, 0.026613899935910013, 0.06037381368514616, 0.020144528134551365, 0.028920559852849692, 0.0074557343032211065, 0.04643836946343072, 0.01767955327522941, 0.14224385318811983, 0.06152136324089952, 0.01756286910676863, 0.0463082598434994, 0.045469985489035025, 0.05532143186428584, 0.046078750674496405, 0.04878914449363947, 0.01900562274386175, 0.040688532099011354, 0.031061867412063293, 0.02796333221340319, 0.0552263404824771, 0.008500680087308865, 0.02227914894319838, 0.04468897153856233, 0.060081567062297836, 0.037962363931001164, 0.03146689079585485, 0.05408584875112865, 0.04382133040053304, 0.07788520000758581, 0.061995974101591855, 0.049597079851082526, 0.011746101154130884, 0.060258443118073046, 0.05373841973778326, 0.01244705314093153, 0.09978803369449452, 0.05024176869483199, 0.034117920222342946, 0.03746173337276559, 0.053571384560200386, 0.0417924841895001, 0.009924231580953347, 0.021760897943750024, 0.03746440510440152, 0.021778984082629904, 0.026350546977482736, 0.07823970168828964, 0.016085820825537667, 0.06381283325026743, 0.05229402595432475, 0.04665195585403126, 0.05149120028363541, 0.025796980880841147, 0.015180310674622888, 0.052763285930268466, 0.03147623814584222, 0.03906038997229189, 0.025502891876385547, 0.05550202236918267, 0.0551263917441247, 0.024591196852270514, 0.04115264157007914, 0.0567856224370189, 0.07305188162717968, 0.016340694746759254, 0.03427371186262462, 0.022630839739576913, 0.05367903308069799, 0.050333453618804924, 0.04357334546511993, 0.040240107919089496, 0.054049279424361885, 0.048036113221314736, 0.01844988586526597, 0.03776352772547398, 0.055033463722793385, 0.024650229133840185, 0.06667377543635666, 0.04180285941401962, 0.020309355422796216, 0.021980512428854126, 0.041768319861148484, 0.05189990843064152, 0.04445305763510987, 0.038899522041901946, 0.016568565624766052, 0.010699045815272257, 0.04999207681976259, 0.02623138774652034, 0.05005254330171738, 0.031271854386432096, 0.09046291845152155, 0.03277490752225276, 0.06156729476060718, 0.019986805054941215, 0.01997487503103912, 0.04602042528858874, 0.0583271559298737, 0.05140240231412463, 0.0396468165126862, 0.02650714941410115, 0.006754352798452601, 0.02884681263822131, 0.007718786691839341, 0.05303585079673212, 0.06822688272222877, 0.04154434340307489, 0.02876983522583032, 0.01276761640838231, 0.03139669104712084, 0.08851031307131052, 0.009776072001841385, 0.04604754336469341, 0.0032097193570734817, 0.023672045099374373, 0.01463843896999606, 0.05368954189179931, 0.06770928666810505, 0.04221046547172591, 0.09811153693590313, 0.006252108532862621, 0.010680690647859592, 0.018204370426246896, 0.03578480987926014, 0.026855776995944325, 0.10278996167471632, 0.029532258377003018, 0.016007681952032726, 0.03742445900570601, 0.058898954739561304, 0.014552695865859278, 0.014906588985468261, 0.02655387874256121, 0.070237160398392, 0.030884765001246706, 0.017364977284159977, 0.052010395666002296, 0.07571815847768448, 0.032359501492464915, 0.03208329639164731, 0.01138129939135979, 0.059300857392372563, 0.04693383838457521, 0.03401382658921648, 0.05392100661993027, 0.01919527116115205, 0.06178653631650377, 0.08210625397623517, 0.028976232060813345, 0.05458412670122925, 0.03498867838061415, 0.08141501020872965, 0.03988017742813099, 0.021921641564404126, 0.049314340139972046, 0.03203998465323821, 0.053306352492654696, 0.04879087740846444, 0.053331414819695055, 0.061138667369959876, 0.018141840773751028, 0.07460628025000915, 0.03399043038371019, 0.0689978183072526, 0.030152356157486793, 0.04595125712512527, 0.04564773727906868, 0.04673161427490413, 0.020946164513588883, 0.014289959817688214, 0.03258212353102863, 0.027805302997876424, 0.04137106305279303, 0.03460105093836319, 0.01781211012712447, 0.04325895686633885, 0.13875329517759383, 0.2531254955101758, 0.13793798658298329, 0.06876085797557607, 0.08119670004816726, 0.1893332865438424, 0.22244965250138193, 0.18880023155361414, 0.14677605999168009, 0.11411286424845457, 0.07953687192639336, 0.12308299541473389, 0.09848739020526409, 0.14194559887982905, 0.09519695231574588, 0.14796601957641542, 0.11776116574765183, 0.1448305940721184, 0.2249717226368375, 0.1362612226512283, 0.15936021285597235, 0.11915481518371962, 0.16706360183889046, 0.1350921916309744, 0.1622399387997575, 0.06488320315838791, 0.14191212801961228, 0.13096064067212865, 0.16847650258569047, 0.11611033987719566, 0.09058549898327328, 0.10088113558595069, 0.11625390834524296, 0.13821535685565323, 0.05085561017040163, 0.21295007318258286, 0.15844590176129714, 0.14526470593409613, 0.12823615717934445, 0.18118116538971663, 0.10298194785718806, 0.17709887819364667, 0.16608344740234315, 0.1579067314742133, 0.14515428920276463, 0.114955951430602, 0.1492789975600317, 0.17954311188077554, 0.21196974063059315, 0.22384073410648853, 0.22289345681201667, 0.09972793457563967, 0.21201869269134477, 0.1206738207838498, 0.12650389544432983, 0.17002391017740592, 0.13682336983038113, 0.08065994174103253, 0.13385492755332962, 0.1339187819394283, 0.09672345360741019, 0.16959704167675227, 0.1353792691952549, 0.15871208044700325, 0.22261877311393619, 0.12114787503378466, 0.12428054717020132, 0.13415215769782662, 0.10059208390885033, 0.1072558130545076, 0.10620358865708113, 0.13082510966341943, 0.09779440239071846, 0.08896786195691675, 0.1087046782777179, 0.16203146951738745, 0.09883017337415367, 0.15342147293267772, 0.14271321706473827, 0.12286903423955664, 0.10762545454781502, 0.12621401256183162, 0.17500231100711972, 0.0892933011346031, 0.17907598929014057, 0.10968946371576749, 0.07019076874712482, 0.21933190495474264, 0.0969278188131284, 0.17945825471542776, 0.18863721139496192, 0.2485601740772836, 0.14458148478297517, 0.16803495440399274, 0.17537424573674798, 0.2023067997652106, 0.13455928507028148, 0.28454060666263103, 0.17011019226629287, 0.20229995716363192, 0.1582447500550188, 0.13936871371697634, 0.09939233539626002, 0.2135857375105843, 0.07488916467991658, 0.13737022876739502, 0.15588384470902383, 0.12495264352764934, 0.14434356708079576, 0.06761943484889343, 0.1570864356472157, 0.12464208441087976, 0.15804420690983534, 0.1873878503101878, 0.23590220720507205, 0.11276914650807157, 0.1161460297589656, 0.18842273071641102, 0.1097635820042342, 0.15617791330441833, 0.11089714578702115, 0.09059176270966418, 0.13047128333710134, 0.11961870943196118, 0.18191893439507112, 0.21409485081676394, 0.08157267948263325, 0.15235172642860562, 0.21083780215121806, 0.09937354421708733, 0.12386772752506658, 0.05909072198846843, 0.10493044916074723, 0.1549562788568437, 0.1299941714387387, 0.047668991319369525, 0.09765254828380421, 0.19846553244860843, 0.15173952881013975, 0.11408642894821241, 0.11662244403851219, 0.21520597947528586, 0.15227178228087723, 0.10228253304376267, 0.08275754051283002, 0.09533412347082049, 0.15694692672695965, 0.11799988496932201, 0.14568357408279553, 0.14278602175181732, 0.08744884151383303, 0.21895591809879988, 0.0928903128078673, 0.1680782067705877, 0.16041269700508565, 0.14590181002859026, 0.12697648024186492, 0.16328274534316733, 0.1512464162078686, 0.09206431728671305, 0.15788641147082672, 0.14541030046530068, 0.19549772841855884, 0.22683141112793237, 0.10871673075598665, 0.20213052484905347, 0.1732050668215379, 0.1094695134088397, 0.11635359362117015, 0.12644612666917965, 0.1038122181489598, 0.04730461165308952, 0.0911106204148382, 0.16570100386161357, 0.06815336557338014, 0.15326280175941065], [0.036314996468718164, 0.0489942555577727, 0.05022013509005774, 0.022284982223936822, 0.06694225477986038, 0.04493533859204035, 0.05860376921191346, 0.02055771699815523, 0.013359930962906219, 0.0281520047064987, 0.055707801366224885, 0.11495131300762296, 0.044422147184377536, 0.0220531111699529, 0.07633202592842281, 0.08951082461862825, 0.03237893834011629, 0.031132534713833593, 0.013812144734401954, 0.022520877573697362, 0.02957647553557763, 0.013807260475005023, 0.03344581644341815, 0.06633680328377523, 0.057503928619553335, 0.008688923062436515, 0.0437491899356246, 0.058017984629259445, 0.025564777715771925, 0.03298694282420911, 0.02812802962580463, 0.02868909141398035, 0.030045737366890535, 0.03279373951954767, 0.015357144984591287, 0.03710287899593823, 0.029876115804654546, 0.04905524154310115, 0.02996026050823275, 0.02750572210061364, 0.056729890857241116, 0.019199961534468457, 0.025781794684007764, 0.05560315112234093, 0.020485747227212414, 0.046862362141837366, 0.006199521803864627, 0.04700949662947096, 0.0649816935765557, 0.025697544224385638, 0.040963423598441295, 0.011542468819243368, 0.11228682473301888, 0.10577740293228999, 0.03030870069778757, 0.04109878762392327, 0.05201924577704631, 0.038383926075766794, 0.03908528160536662, 0.01865842379629612, 0.05263197403110098, 0.09012864029500633, 0.0830819777911529, 0.02017268336203415, 0.022110236131993588, 0.046824972741887905, 0.03522055871144403, 0.01687642517936183, 0.02578861873189453, 0.017886551249830518, 0.013281852388900006, 0.05648881531669758, 0.009443318031117087, 0.04109113237063866, 0.02027508304308867, 0.10547393132583238, 0.05907126658712514, 0.015221313406073023, 0.03016736238350859, 0.030523394743795507, 0.006596833809453528, 0.05481963984493632, 0.02868703752028523, 0.008396139310207218, 0.040153213558369316, 0.03858665113511961, 0.06492898624856025, 0.018144262030546088, 0.06777665883419104, 0.014914424209564459, 0.04139981385378633, 0.04183832665148657, 0.04154985384957399, 0.05408843884652015, 0.019250485092925373, 0.1012254624220077, 0.06720759483869188, 0.018866110112867318, 0.026506251415412407, 0.05663122603436932, 0.018974803206219804, 0.022445542163040955, 0.034332193099544384, 0.0365174283797387, 0.06411026377463713, 0.0640891793591436, 0.03222040075343102, 0.053602873886120506, 0.020257783580746036, 0.05915715162700508, 0.05354156506655272, 0.02712396133574657, 0.0572083868610207, 0.031032294682518113, 0.011261684667260852, 0.012475237126636785, 0.03093808645644458, 0.028398186223057564, 0.007163060017774114, 0.028922526544192806, 0.029719311132794246, 0.056952575978357345, 0.05744540656451136, 0.042149498040089384, 0.014824917489022482, 0.032948332591331564, 0.022114512757980265, 0.03825903004326392, 0.08389201713725924, 0.01983855549042346, 0.020838733071286697, 0.05958493668003939, 0.03393420156498905, 0.027469560955069028, 0.03133613550744485, 0.07297273157746531, 0.05439935419417452, 0.04413202310388442, 0.09543708903947845, 0.07932590902782977, 0.049840374413179234, 0.09991330080083571, 0.03436700724705588, 0.012180813228042098, 0.03342282841913402, 0.06516330453450792, 0.024888566149456892, 0.00802084543465753, 0.006984234896663111, 0.002695787889024359, 0.0898684878484346, 0.07190885546151549, 0.04114627023227513, 0.06247353128856048, 0.021197162568569183, 0.03593821922549978, 0.015542036235274281, 0.012964706711500185, 0.04234337298839819, 0.07202182518085465, 0.10481045130291022, 0.03744572153664194, 0.022292546564131044, 0.04164631449384615, 0.047841737323324196, 0.01389601669870899, 0.02415798484435072, 0.051019613674725406, 0.0471072226355318, 0.017488244302512612, 0.03942852490581572, 0.025946916975954082, 0.027571806640480645, 0.013980974053993123, 0.08824450545944273, 0.053937289339955896, 0.04991324960428756, 0.02434116915537743, 0.03016441420186311, 0.04691408612416126, 0.05258367506030481, 0.04011144548712764, 0.008615307579020737, 0.0009790740318749158, 0.020275543174648192, 0.010449609053466702, 0.02494045711500803, 0.043553110808716156, 0.0388145016040653, 0.023619905514351558, 0.022983387716521975, 0.05376686625822913, 0.061047182825859636, 0.01592868589796126, 0.01167582440757542, 0.04905205401882995, 0.044923096866114065, 0.043767903189291246, 0.020143529945926275, 0.01896298079373082, 0.0481204434618121, 0.03925247634469997, 0.04959909478202462, 0.051091197528876364, 0.0159612327843206, 0.04424399092386011, 0.07231037219753489, 0.04558384949632455, 0.016888145546545275, 0.027224904551985674, 0.007585718221889692, 0.023790200575604104, 0.038629061164101586, 0.023767184720782097, 0.045479247492039576, 0.10672458374756388, 0.04275915751350112, 0.05090918581117876, 0.0478081625624327, 0.02121232835634146, 0.024185264337575063, 0.08473562382278033, 0.019216298060200643, 0.004326425023464253, 0.04632756310456898, 0.04520630413026083, 0.01650006353884237, 0.038691613081027754, 0.03017541839653859, 0.014535775826516328, 0.04552696758764796, 0.048155769691220485, 0.02380298035859596, 0.0358619487087708, 0.02761626870778855, 0.023772711865603924, 0.07381782255833969, 0.05021114397095516, 0.053864451256231405, 0.010363445708208019, 0.04443005476787221, 0.026928416555165313, 0.059298104024492204, 0.05550980378757231, 0.017628859022806864, 0.09370263054734096, 0.021324064255168196, 0.10383766639279202, 0.050553648834466, 0.022177547070896253, 0.02603405995614594, 0.04841492394916713, 0.04002997993666213, 0.02462084750732174, 0.005491794008776196, 0.05309801679686643, 0.02809389083267888, 0.0328206683479948, 0.07157131185522303, 0.02525970121496357, 0.05493117721925955, 0.07471764693036675, 0.06651115603744984, 0.013926635856478242, 0.013056675506959436, 0.027679418053594418, 0.03081264309003018, 0.014118468043307075, 0.03450036376307253, 0.0450617671594955, 0.013868589703633916, 0.1288886385736987, 0.04792184103280306, 0.03131927762296982, 0.012029523641103879, 0.00887956874066731, 0.044225244273548014, 0.017065288775484078, 0.053590146053466015, 0.025221697687811684, 0.04223657422699034, 0.036679847398772836, 0.018177868332713842, 0.002352074948248628, 0.03020569060026901, 0.028085497142456006, 0.023923536682559643, 0.04522179646301083, 0.012853932821599301, 0.07842114195227623, 0.006272666951190331, 0.007575485860797926, 0.008632657136331545, 0.08269191981526092, 0.01779728387191426, 0.03994872960902285, 0.04843495822569821, 0.01786209748388501, 0.054261730329017155, 0.06782664990168996, 0.017152572763734497, 0.03005365051649278, 0.01373638815493905, 0.06369012655341066, 0.02299043997481931, 0.014667886462120805, 0.06548934485181235, 0.07914204194094054, 0.0374434060358908, 0.04245652453391813, 0.03438495608861558, 0.05983643568470143, 0.052990538970334455, 0.03639375318016391, 0.018965891867992468, 0.0696449339739047, 0.07528064757934771, 0.020676345593528822, 0.020307659615355078, 0.04462788907403592, 0.02067575744149508, 0.035902904128306545, 0.05589013220742345, 0.02211836264905287, 0.018136948165192734, 0.037472338663064875, 0.04274338687537238, 0.053614900389220566, 0.020682796712208074, 0.047606309526599944, 0.020670107842306606, 0.01530916884803446, 0.03369980906427372, 0.03165249450830743, 0.021250036879791878, 0.07042565106530674, 0.040617508566356264, 0.037173119562794454, 0.022585399892705027, 0.022573829810426105, 0.034380748111288995, 0.04454313209862448, 0.03641277442511637, 0.02133096622856101, 0.03170326483086683, 0.0266884876327822, 0.02813537688780343, 0.04930017254082486, 0.029133361422282178, 0.04934450102155097, 0.08789574800175615, 0.016151014788192697, 0.18737916718237102, 0.07761783388559707, 0.14934945706045255, 0.07805952307535335, 0.2497915900312364, 0.09370585888973437, 0.13809922558721155, 0.08462479891022667, 0.11275950600975193, 0.14276748290285468, 0.1159758330322802, 0.14227147592464462, 0.15110718930372968, 0.12394295903504826, 0.08913579513318837, 0.1621214475017041, 0.10103841894306242, 0.1141440864012111, 0.10680964129278436, 0.17358469020109624, 0.11869397858390585, 0.14793664537137374, 0.17189520585816354, 0.18751106166746467, 0.2116721690981649, 0.12451505841454491, 0.134018704702612, 0.15159923321334645, 0.10775502611068077, 0.11482756730401888, 0.17551301250932738, 0.14517643488943577, 0.07549540285253897, 0.12422098981915042, 0.08234784530941397, 0.17063961073290557, 0.15834602352697402, 0.19756121066166088, 0.15479953726753592, 0.15315076714614406, 0.16464561049360782, 0.19862439658027142, 0.15910930756945163, 0.18490302114514634, 0.12413250355166383, 0.2035782323218882, 0.101810252526775, 0.17287138238316402, 0.12700079299975187, 0.20907147583784536, 0.145517481432762, 0.11480625282274559, 0.2671403012936935, 0.1808725210139528, 0.07419507848680951, 0.18522374768508598, 0.10505931568332016, 0.09850864531472325, 0.19773037580307573, 0.08220950156101026, 0.20649796002544463, 0.20462325046537444, 0.1964222069364041, 0.12844057433540002, 0.11812907803687267, 0.10100431725732051, 0.22607289167353883, 0.10939869025605731, 0.1346998181543313, 0.09076080910745077, 0.16370210330933332, 0.17793226550566033, 0.11259909821092151, 0.1311790250474587, 0.14652312122052535, 0.2296542885596864, 0.06151670997496694, 0.14515982562443241, 0.1534232244011946, 0.1537155415280722, 0.12396183927194215, 0.17934135161340237, 0.15908493543975055, 0.12246022961335257, 0.10048781958175823, 0.11778513711760752, 0.21084442210849375, 0.12698244710918516, 0.13017393444897607, 0.12366748123895377, 0.13191655656555668, 0.09419800670002587, 0.12131661715102382, 0.19553591933799908, 0.13117996015353128, 0.30342927435413003, 0.2210927542182617, 0.17235330393305048, 0.13349534216104075, 0.13108422310324386, 0.10021982263424434, 0.05855427538335789, 0.12557040725369006, 0.0975919073971454, 0.1439121417934075, 0.14979922823840752, 0.1711263705510646, 0.20687609910964966, 0.14048160868696868, 0.21863902104087174, 0.1788141595898196, 0.1563215782516636, 0.09011175643536262, 0.2633068710565567, 0.07183409892604686, 0.17840859072748572, 0.14095371850999072, 0.3292808309197426, 0.08310168923344463, 0.1795694135944359, 0.11558075071661733, 0.07227091220556758, 0.15718098526122048, 0.16037866211263463, 0.16274017601972446, 0.10440065219881944, 0.06605801550904289, 0.11690785919199698, 0.14844376972177997, 0.19833831349387765, 0.11822530490462668, 0.19518105400493369, 0.15428378916112706, 0.12616356136277318, 0.10437901117256843, 0.09457718479097821, 0.12843149044783786, 0.11207301940885372, 0.10442232291097753, 0.19184922653948888, 0.11317830736516044, 0.16890967934159562, 0.21287704585120082, 0.12217180134030059, 0.08587864256696776, 0.16729822440538555, 0.1873328274814412, 0.11250576571910642, 0.13532245036913082, 0.08069008777965792, 0.2761182398535311, 0.18881154188420624, 0.11657364782877266, 0.15722045267466456, 0.0837112744920887, 0.09062246535904706, 0.09633434558054432, 0.1400606328388676, 0.09791687902179547, 0.14508204854791984, 0.1492953099659644, 0.11984663040493615, 0.12783875194145367, 0.12598341243574396, 0.1371510577155277, 0.1185220452316571, 0.15005734720034525, 0.1664154842728749, 0.14300912618637085, 0.12140433900640346, 0.113460011780262, 0.13594414747785777, 0.0914251574431546, 0.07816290424671024, 0.1977968425489962, 0.14417406055144966], [0.013631694309879094, 0.06187674807733856, 0.049531774566276, 0.05204371809668373, 0.06989943867665716, 0.07900795812020078, 0.045692845014855266, 0.03800424332439434, 0.0448176970530767, 0.0619069943059003, 0.033185719657922164, 0.019392144386074506, 0.06571644946234301, 0.020570233318721876, 0.042329027273808606, 0.07945502788061276, 0.03149341144307982, 0.04061074760102201, 0.0365460233297199, 0.035056440174230374, 0.019558023668651003, 0.015033789386507124, 0.04110499568923842, 0.03481053325231187, 0.04012978395621758, 0.009238988077413524, 0.03510743314109277, 0.11982191688730381, 0.04246362317644525, 0.05875138238479849, 0.009740888635860756, 0.026393374464532826, 0.0408473405695986, 0.024226902532973327, 0.012772406043950468, 0.055884710818645544, 0.006514200304081896, 0.02961419704661239, 0.023938810081745032, 0.03301836164609995, 0.07538644815213047, 0.00904460197489243, 0.033185433931066655, 0.02051676157861948, 0.0245002373776515, 0.014028466866875533, 0.08768109662923962, 0.07789573850459419, 0.04548387478280347, 0.07511617281124927, 0.07966734148794785, 0.004797091369255213, 0.014966444123274414, 0.04165019592619501, 0.04431622044648975, 0.024356737558264285, 0.05132950114784762, 0.037225852865958586, 0.029118232741893735, 0.07359720431850292, 0.0068448215279204305, 0.050182615814264864, 0.01665186799073126, 0.0624912537750788, 0.031864804404904135, 0.11159371817484498, 0.06421697718906216, 0.020142839748586994, 0.08258953312179074, 0.09509739320492372, 0.012145063974458026, 0.038099869052530266, 0.02317094327736413, 0.08632632830995135, 0.02983378555654781, 0.027363534027244896, 0.00747571431020333, 0.06195612819283269, 0.07186886854469776, 0.024173306483135093, 0.028257011181267444, 0.023236371016537305, 0.02105541050696047, 0.025579717148502823, 0.08711573595064692, 0.03741123393410817, 0.07479324951418675, 0.02433757901599165, 0.051862459658877924, 0.04754261841299012, 0.038122037003631704, 0.060980794005445205, 0.05339461611583829, 0.023655994300497696, 0.043405163669376634, 0.06348229551804252, 0.032431259751319885, 0.06287898882874288, 0.028396915295161307, 0.03565138656995259, 0.022531506983796135, 0.008519114107912173, 0.02755929217528319, 0.026085590980073903, 0.017827548654167913, 0.06400735015631653, 0.036065664535271935, 0.05741019907873124, 0.09480311680817977, 0.04850118748436216, 0.018920939983217977, 0.018329210797674023, 0.04003008012659848, 0.042042717832373455, 0.025481174779997673, 0.03624906406912487, 0.06427222266211174, 0.036101985242567025, 0.035478224963299, 0.011150330974487588, 0.03030190633580787, 0.02326596044440521, 0.009150035184575245, 0.06439006829168648, 0.10154722054721788, 0.022896884838701226, 0.04029236995847896, 0.09996094668167643, 0.018745563065749593, 0.07929175539175048, 0.045995322143426165, 0.018074310901283752, 0.11192171776201576, 0.05093831139674876, 0.03467099835688714, 0.05579920798481908, 0.044232762229512446, 0.07442276939400472, 0.05718568085285369, 0.04742107317724731, 0.040748493920546025, 0.027285638207104057, 0.05930167746555526, 0.05232755247561727, 0.02615743644128088, 0.037492799674510024, 0.04310827862354927, 0.07228392947581597, 0.00542983256309526, 0.020085156320419628, 0.030639438809885178, 0.017214582912856713, 0.06652493771980517, 0.0377199673675932, 0.04702287013060413, 0.041621857017162256, 0.0236577197938459, 0.11258116792305373, 0.05487896713020746, 0.048676356600481085, 0.003995465194748249, 0.03506495260808151, 0.034661227982724085, 0.012531338852568297, 0.03521271049976349, 0.04096361284609884, 0.10050462922663428, 0.013519360982172657, 0.03874273592373356, 0.01425128742994275, 0.10932824559859, 0.04158403717156034, 0.060102291536168195, 0.015425967121700523, 0.006972362389205955, 0.008832638104649959, 0.056842867998057045, 0.026626373582985252, 0.07548604437033646, 0.048772019436000846, 0.048836452697287314, 0.03984858420153614, 0.05309771993779577, 0.021340450875868555, 0.06253553030546755, 0.05933594613452442, 0.05706971656763926, 0.034257477382197976, 0.023972542549017817, 0.07090892278938554, 0.03229686051781755, 0.02857673211110523, 0.07448871663655154, 0.023518914058513474, 0.020202549239911605, 0.02146770137187559, 0.030191179757821374, 0.023744807112962008, 0.09173183512757532, 0.019262526438978966, 0.03224732958187815, 0.009359125087939901, 0.006079638978917501, 0.09943924655090086, 0.058397544926265255, 0.012349122116575018, 0.06501273019239306, 0.026891030865954235, 0.028284992004046217, 0.004111051448489889, 0.026648330021998845, 0.0540796184213832, 0.025077593018068, 0.04399590950924903, 0.02865029193344526, 0.011708144938893383, 0.04095942713320255, 0.018503450373827945, 0.012807844523194944, 0.043942311604041606, 0.03998019667051267, 0.03029289666301338, 0.0772680299996864, 0.11176357351359911, 0.03647720397566445, 0.032849882991285995, 0.028823904394812416, 0.024980271482490934, 0.05530113783606794, 0.049339139004587196, 0.023807301513443235, 0.033764179243007675, 0.08743020618567243, 0.038037576887290925, 0.0307892005002941, 0.020069189013156574, 0.024791200085019227, 0.018976777319039684, 0.01215221178426873, 0.02994025777297793, 0.03211374300008174, 0.03110909769020509, 0.05327996543201152, 0.04544879346212838, 0.03226465130865108, 0.03345619908941444, 0.026387719299236778, 0.04898973216768354, 0.03399194807570893, 0.03526476844854187, 0.06498613904113881, 0.0517146238416899, 0.07536736011388712, 0.03109341054368997, 0.10379442144767381, 0.008237088713940466, 0.0255276239477098, 0.058838202530751005, 0.06852553036878817, 0.04229024634696543, 0.017745255609042943, 0.003516316332934366, 0.05302841447701212, 0.04334920202381909, 0.041522568790242076, 0.05550141380808782, 0.015256717560987454, 0.030846293921058532, 0.06248103440157138, 0.048508523614145815, 0.05449551797937602, 0.08617587271146476, 0.046534028588212095, 0.02085831463773502, 0.027017114334739745, 0.026202451408607885, 0.028644857557083014, 0.020694205377367325, 0.03748093644389883, 0.0502699183562072, 0.018165971705457196, 0.10675921977963299, 0.017729642677295487, 0.052390850250958465, 0.040989806948346086, 0.01933769857714651, 0.04166804086707998, 0.016986010705295485, 0.02958487664727727, 0.052082242982578464, 0.007317970357689774, 0.07542779319919646, 0.02332517455215566, 0.033121906089945696, 0.02593432458525058, 0.03408854972803965, 0.014459758567682002, 0.0845020699489396, 0.04247130069416016, 0.12270506413187832, 0.04528607758402359, 0.11295118049019948, 0.06438696611439809, 0.008926405680540483, 0.05447304945846554, 0.0973985630844254, 0.07068930644891225, 0.06369134367560036, 0.015676641414756887, 0.009303217248088913, 0.02448933522828156, 0.05572930880589411, 0.00816418290924048, 0.007925792087917216, 0.05858951626578346, 0.04424871098308358, 0.013143539254087955, 0.02389724053500686, 0.028739993467752356, 0.02707031148020178, 0.05734539845434483, 0.06868639087770134, 0.005423311868071323, 0.04360677921795286, 0.005173118115635589, 0.015851723328523804, 0.037143563531572, 0.0028171948997623986, 0.028361774602672085, 0.01679035645793192, 0.01860572574514663, 0.006623052031500265, 0.011124568245577393, 0.03396272972167935, 0.04441214674443472, 0.05783057749795262, 0.018128224219253752, 0.011315316896798322, 0.013685329322470352, 0.031697557715233415, 0.08361897358554415, 0.024910776774049737, 0.023366571549559012, 0.0362436575233005, 0.0528351406683214, 0.028554280288517475, 0.031237841758411378, 0.01875909983937163, 0.05490991097758524, 0.05608822626527399, 0.040950914699351415, 0.01885082558146678, 0.2795376704307273, 0.1360293460311368, 0.22852286958368495, 0.14129770395811647, 0.1589080668054521, 0.3098338603740558, 0.11867682755109854, 0.09601819809176959, 0.19892640615580603, 0.17896845209179446, 0.16190892609301955, 0.10578929213806987, 0.10387245827587321, 0.14923549286322668, 0.06917749225976877, 0.14868446305627003, 0.23018796695396304, 0.08475226277369075, 0.10056679151603021, 0.11198407300980762, 0.15965204016538337, 0.10167174550588243, 0.17750796483596787, 0.0880484894150868, 0.1651815153309144, 0.09388172562466934, 0.17738378868671134, 0.1245711202500388, 0.1284959088661708, 0.1597328600473702, 0.1137895772990305, 0.09744025694089942, 0.1911086225300096, 0.1115097441652324, 0.12367088027531281, 0.12461824662750587, 0.07936271955259144, 0.16102358844364062, 0.12189086133730598, 0.06672048621112481, 0.17303789063589647, 0.047235621605068445, 0.2868605009280145, 0.1667531911516562, 0.14078909531235695, 0.13219401589594781, 0.19489743484882638, 0.27769435371737927, 0.16265052458038554, 0.1804669521516189, 0.13946678111096844, 0.15642161975847557, 0.23095508047845215, 0.12386527101625688, 0.15825689159100875, 0.1184340710460674, 0.14992588316090405, 0.1464558974839747, 0.12807151913875714, 0.16282178257824853, 0.1277246986865066, 0.10989969930960797, 0.10949125091428868, 0.15160821320023388, 0.146266070951242, 0.19657915632706136, 0.18077647226164117, 0.115099720278522, 0.21464496036060154, 0.23489064507884905, 0.17385202663717791, 0.14668532501673326, 0.13349592103622854, 0.145889074774459, 0.22821915306849405, 0.21456608490552753, 0.12791792425559834, 0.11502063702209853, 0.30133306339848787, 0.09532401541946456, 0.15715946297859773, 0.11210416734684259, 0.13292035582708195, 0.06765511730918661, 0.20419304230017588, 0.14441353676375002, 0.16596562403719872, 0.12051620346028358, 0.1305064611369744, 0.18625683209393173, 0.11377571398043074, 0.12930464203236625, 0.19526433781720698, 0.09502098168013617, 0.19967587140854448, 0.09894132483168505, 0.19466946192551404, 0.19707053230376914, 0.15732288389699534, 0.13648829015437514, 0.08245855889981613, 0.14401353400899097, 0.18820946716004983, 0.21460565621964633, 0.14082740497542545, 0.1873592776246369, 0.07322165532968938, 0.16659456450724974, 0.17075822077458724, 0.15753463347209617, 0.1300964245456271, 0.10912817000644282, 0.0856859736086335, 0.1794792278087698, 0.10323312031687237, 0.2259242840227671, 0.14371033699717373, 0.16939568216912448, 0.12233961577294394, 0.11244666849961504, 0.10433294606627896, 0.12941321823745966, 0.10540629940805957, 0.22764179186196998, 0.23635571880731732, 0.23467229038942605, 0.19599835155531764, 0.13809929980197921, 0.1242726952477824, 0.189457269734703, 0.15421718882862478, 0.25669614609796554, 0.17683725629467517, 0.14533145469613373, 0.08867011230904609, 0.0995990754745435, 0.1445576173136942, 0.10474268579855561, 0.20248354965588078, 0.10941631626337767, 0.09562903069308959, 0.11985538032604381, 0.17455249530030414, 0.1367355589172803, 0.09570100417477079, 0.1902534457622096, 0.15324099746067077, 0.17063842329662293, 0.10918727464741096, 0.18892160238465294, 0.10632917488692328, 0.1350952492794022, 0.1233848046103958, 0.07121700313291512, 0.10609956923872232, 0.14369178330525756, 0.08458145006443374, 0.2659963845508173, 0.13994464999996126, 0.1410330244107172, 0.1531070249620825, 0.08843251373036765, 0.11747024385840632, 0.15185861382633448, 0.16310866718413308, 0.1106136231101118, 0.21955391101073474, 0.12296909058932215, 0.07527171212132089, 0.08728636312298477, 0.1779258978785947, 0.11546486435690895, 0.11044036873499863, 0.15638676850358024, 0.07540679041994736, 0.09654608031269163], [0.03771813426283188, 0.05400663190812338, 0.054714425568818115, 0.010088617291330593, 0.0904037247528322, 0.008624525980849285, 0.031447513320017606, 0.015804489339643624, 0.04700005651102401, 0.07633799279574305, 0.011126581321150297, 0.031632270984118804, 0.049572830175748095, 0.053123910329304636, 0.07515178105677478, 0.04013770638266578, 0.021008388030168135, 0.044466431136243045, 0.07918542789411731, 0.034794013045029715, 0.05217546786298044, 0.02103299950249493, 0.03311720829515252, 0.021575553982984275, 0.03489235503366217, 0.02744890698522795, 0.06705489795422181, 0.01766936358762905, 0.021690531211788766, 0.03588261752156541, 0.011204415914107813, 0.007573726506961975, 0.04513844585744664, 0.017872394782898482, 0.035593024076661095, 0.06990173933445476, 0.010390676961833378, 0.05740175714890938, 0.05577646486926824, 0.012905317271361127, 0.034383627644274384, 0.045012881892034784, 0.02660802212631097, 0.04000319582701195, 0.011570851329452125, 0.024123755138134584, 0.047000034246593714, 0.06450863380450755, 0.04554397390165832, 0.041959886730182916, 0.06404528132406995, 0.006461065313487779, 0.03567412597476505, 0.08800649869954214, 0.0627122430887539, 0.07650253435713239, 0.09743624934344552, 0.039313610759563744, 0.03321495285490528, 0.06245128912269138, 0.026330471882829443, 0.03173957811668515, 0.12843724951380864, 0.031860752278589644, 0.011065331873396644, 0.061181700802990235, 0.03024611167347757, 0.011421663875808008, 0.04603844092343934, 0.058531480317469686, 0.07810014081769623, 0.01277828849197249, 0.07503999877371825, 0.04586091548844706, 0.03030927215149859, 0.037412528981803916, 0.06750353364623152, 0.04197961672616657, 0.032441026414744556, 0.12264966280781664, 0.04054325298056938, 0.034768791156238876, 0.048982355219777673, 0.10591520491288975, 0.018788062152452767, 0.018429285701131448, 0.06015709543135017, 0.023991407942958176, 0.03113573337031994, 0.02421415614662692, 0.018074832260026596, 0.03651153943792451, 0.05443449117592536, 0.020104732320760377, 0.04017062434286345, 0.051658283700817265, 0.10561522882198915, 0.061314496997511014, 0.00712878531885508, 0.034403687895974144, 0.06963494466617703, 0.018894196691690013, 0.10490379863767885, 0.0930379334022291, 0.038689100911142305, 0.03260610974393785, 0.03624638862675056, 0.06650194598478265, 0.09672222164226696, 0.043547745081014, 0.007021216579232714, 0.019910237679141574, 0.09261324681574479, 0.028335389397398103, 0.012938930995005649, 0.069862071541138, 0.020433284807950258, 0.05503819491423201, 0.060448217700468376, 0.10903245522058569, 0.07167927207774483, 0.03248611559683923, 0.07860589961637743, 0.08956273784860969, 0.03175156751240138, 0.056140584783861414, 0.0563809627055889, 0.05222647567279637, 0.061019834683975205, 0.011529267867445014, 0.03649659629445523, 0.02875015532481484, 0.020234467156114988, 0.041703047972987406, 0.036559155632858165, 0.028990921018703375, 0.0516279558360111, 0.04429823449754622, 0.02630975668580504, 0.03539182413078379, 0.03471294454357121, 0.08776282935286872, 0.022974691601120867, 0.00957384047069354, 0.046839307324262336, 0.03701694200572092, 0.009577566052030306, 0.03664868461783044, 0.07375308501650579, 0.03974132159783039, 0.03889983745466452, 0.013599114026874304, 0.02216050179413287, 0.10294671068550088, 0.043377600304665975, 0.08311419442179613, 0.02448163544613635, 0.05419843626441434, 0.021724909347540233, 0.0065656928290991345, 0.038032081283745356, 0.042671977425925434, 0.009523918051854707, 0.06483674471382983, 0.032182614304474555, 0.02942612012702739, 0.033496219402877614, 0.03553006026777439, 0.02286436578287976, 0.06391070026438683, 0.00977308764049667, 0.08127212451654486, 0.05088785277621355, 0.0434820130612934, 0.05150652192241978, 0.043143975926795974, 0.07099858165020123, 0.08361957472516224, 0.04840616289584432, 0.03203050000593066, 0.04543334565823898, 0.013109019182593329, 0.014591836734325625, 0.025753281370270997, 0.026714370033005252, 0.13231115648522973, 0.003499022204778157, 0.038797870074631646, 0.15785777941346169, 0.03455827354628127, 0.0529454015486408, 0.03306153979792725, 0.060562938888324425, 0.057917664817068726, 0.01882174823549576, 0.07153024882427417, 0.042704661609604955, 0.018077400090987794, 0.07513669319450855, 0.04459742391190957, 0.07690955782891251, 0.02211697483289754, 0.03806137014180422, 0.002349035389670462, 0.0772335498186294, 0.009419191737833899, 0.018868295737775043, 0.02742101150943199, 0.03495736345939804, 0.059357238351367414, 0.04408403954585083, 0.06344216017168947, 0.015665416431147605, 0.009787360068003181, 0.01869368879852118, 0.020144756344961934, 0.04827419790672138, 0.053175137072685175, 0.09084352146601304, 0.0290823424802511, 0.04165264130278956, 0.033980403968598694, 0.06712126822094433, 0.041827376262517646, 0.036313115124357864, 0.05142878566402942, 0.02422896013740683, 0.04232808103552088, 0.02817518383380957, 0.08740452787606046, 0.051258169623906724, 0.03271358014899306, 0.04038762090203818, 0.03664059520815499, 0.02462017957441276, 0.02178677292249631, 0.021447164290293586, 0.007551650860477821, 0.02444936315441737, 0.03419265820411965, 0.01636817461985629, 0.0536656410258729, 0.07849768706364557, 0.049324952851748094, 0.037908784579485655, 0.013047571210336173, 0.033328215722576715, 0.06503382945084013, 0.05378149027819745, 0.0327547582128318, 0.03737335100595374, 0.030419295544561464, 0.06317299805232324, 0.05297799296386074, 0.03770287199586164, 0.037252358670230024, 0.04181762815278489, 0.027703960877261125, 0.018900399190897588, 0.03972868653363548, 0.008846838172757998, 0.06279508903389797, 0.06223577314813156, 0.07738027241430245, 0.02963992730656173, 0.037813719172845595, 0.052079741944908164, 0.030645531842310447, 0.06107785207859706, 0.04503732081502676, 0.034913921845145524, 0.0675722787855193, 0.041226151297451, 0.09243498294381425, 0.05540680853300728, 0.04056489771755878, 0.06793901848141104, 0.10440933532663621, 0.03596984584874008, 0.02783488314889837, 0.026927696671918966, 0.04760599411383737, 0.020494101954682264, 0.011259713337494759, 0.06668679270660505, 0.03173398974468, 0.009679276463430142, 0.006781782576581463, 0.055004957830533385, 0.015596168486808892, 0.03949286539864261, 0.2303313053562306, 0.023037889186525717, 0.061376778030535206, 0.05347157682990655, 0.06158494303235784, 0.013136987945472356, 0.04565006020129658, 0.045580060832435265, 0.03850885550491512, 0.05468524803291075, 0.035285875128465705, 0.022183343244250864, 0.06456552684539929, 0.05111484235385433, 0.040936958612292074, 0.03210475930245593, 0.02934241700131679, 0.06317348786978982, 0.0315401593252318, 0.09183478585327975, 0.005511572244358831, 0.07162545894971117, 0.021999995660735294, 0.08004539893590845, 0.0437510267511243, 0.03340152507007588, 0.03796560711634811, 0.034183618845418096, 0.014897278742864728, 0.050766997737810016, 0.034096850649802946, 0.019463752360024955, 0.019547962001524866, 0.024336656897503417, 0.027209586623939686, 0.0203309816060937, 0.04176085385552142, 0.019606244713941123, 0.010870392870856449, 0.015399036437884206, 0.05941630217421334, 0.00854318102938123, 0.08582927490351722, 0.02668507004273124, 0.028353510788292624, 0.05891469569178298, 0.012395460889820242, 0.02484442877175752, 0.008536207624274539, 0.020291143118811306, 0.017878684484458063, 0.03972947692091111, 0.0292440824341611, 0.004782991491083521, 0.055757892623660155, 0.034550395648693666, 0.08005689480341971, 0.015204485207505058, 0.011570544265850913, 0.05671303668350447, 0.04319232684792951, 0.118059598171385, 0.1239267950586509, 0.1438523840624839, 0.12621463596588, 0.20514542557066306, 0.11078167503001168, 0.05296313887811266, 0.10807545579154976, 0.17642341990722343, 0.23377939767669886, 0.09089650338864885, 0.09732759892358445, 0.19553526624804363, 0.18349595367908478, 0.14500269811833277, 0.13633009395562112, 0.1945486551267095, 0.12570973805850372, 0.11678505601594225, 0.18680882669286802, 0.15614687668858096, 0.25952942844014615, 0.12213339519803412, 0.1710370456567034, 0.22975942119956017, 0.06052079232176766, 0.09892826303257607, 0.14059394015930593, 0.2286826985073276, 0.11601259160670452, 0.05637353009660728, 0.12726530927466229, 0.09338928095530719, 0.1188156685384456, 0.11107388083473779, 0.1973389819613658, 0.12740256206598133, 0.13386022648774087, 0.2128066011937335, 0.08925273534259759, 0.10326886214897968, 0.1704267627792433, 0.14788451691856608, 0.13701171206776053, 0.20616893627448007, 0.12415467892424203, 0.250190271763131, 0.21647797606419772, 0.18190177594078705, 0.09104911121539772, 0.13566889974754304, 0.12627369607798755, 0.09234073018888012, 0.17122460121754557, 0.12572251784149557, 0.2190000907285139, 0.1691140964976512, 0.18093606369802728, 0.09707779201562516, 0.14727689092978835, 0.12937345396494493, 0.13548708840971813, 0.1490972307510674, 0.09185621907818131, 0.12000380243989639, 0.21854159189388156, 0.259770032716915, 0.08884392329491675, 0.12178926132037304, 0.1607908954611048, 0.1454989128978923, 0.10070898701087572, 0.2129932661773637, 0.09619776072213426, 0.10747176318545826, 0.11673635628540069, 0.18068532168399543, 0.13431865110760555, 0.09892317932099104, 0.1594694866798818, 0.18433947872836143, 0.12903828523121774, 0.24114502040902153, 0.1693211853853427, 0.12656213919399306, 0.1838246954139322, 0.19258117710705847, 0.15771280828630552, 0.11998887785011902, 0.12117344202124514, 0.12090068048564717, 0.09853671333985403, 0.17528797849081457, 0.17819339758716524, 0.3190740442369133, 0.11240864085266367, 0.26452351827174425, 0.15864176937611774, 0.1550742209656164, 0.16206246160436422, 0.24647358135553077, 0.18604362790938467, 0.24127970536937937, 0.17305107117863372, 0.13758304703515023, 0.11647598861600272, 0.1745649633812718, 0.12465667503420264, 0.17831931036198512, 0.19167897786246613, 0.04866768831561785, 0.08912030651117675, 0.18299679999472573, 0.10302830240107141, 0.16117274528369308, 0.293627759674564, 0.13881943537853658, 0.12863687239587307, 0.16203483886783943, 0.24739969259826466, 0.1431731556658633, 0.05801656712719705, 0.17153613996924832, 0.13828151189954951, 0.12499418895458803, 0.19885168672772124, 0.11372897351975553, 0.18559759715572, 0.1630378217669204, 0.08330784301506355, 0.14364284608745947, 0.10424768071970902, 0.08416746524744667, 0.15252209384925663, 0.16640801826724783, 0.06385884640621953, 0.11789996962761506, 0.13362444617087021, 0.16711374133592471, 0.19362399849342182, 0.12317885863012634, 0.13361139921471477, 0.10284623131155968, 0.14905844611348584, 0.1008742484555114, 0.13504248257959262, 0.13747638557106256, 0.11723227420588955, 0.10147854220122099, 0.1109693270700518, 0.09333515612524934, 0.12068749114405364, 0.11522473505465314, 0.14850793580990285, 0.06624034635024145, 0.271714988630265, 0.08336141865584068, 0.24031325097894296, 0.07799502302077599, 0.09141306785750203, 0.16103803063742816, 0.146999565185979, 0.07167700110585429, 0.16943448164965957, 0.11061184937716462, 0.08823434545774944, 0.09080867763259448, 0.12053919519530609, 0.06578691638424061, 0.2120053191902116, 0.12065095521393232, 0.20268430060241371, 0.1381084875902161, 0.09985887169023044, 0.26497082551941276, 0.10363658147980459], [0.03733377227035817, 0.025007391413964797, 0.03608002880355343, 0.05753678720793687, 0.03774763834371697, 0.04365810986200813, 0.024092965286399703, 0.0639144035812933, 0.04761512253026012, 0.020975581392121967, 0.05149067706952337, 0.04694401322922204, 0.02741423941188259, 0.022180742016644217, 0.013554411689256085, 0.03104747160250554, 0.04564949245832395, 0.05252510105492547, 0.03799670681473799, 0.08856038577505387, 0.021204014446993824, 0.02314525940164458, 0.0349556231230963, 0.08905288981623016, 0.005760133271905943, 0.056832941772881895, 0.027390846917114686, 0.04325462272390723, 0.016448087226308417, 0.06055107936845161, 0.06721440033288673, 0.030854444557917304, 0.015902226477919612, 0.04712043657491449, 0.05078768510429654, 0.019779816357186064, 0.027734270188375376, 0.04670148678997066, 0.032760784451966174, 0.020321610136306845, 0.05258346725895535, 0.034226882344228216, 0.11184158065589145, 0.03422157598834019, 0.04462934739422053, 0.05454340876895003, 0.03737923252629116, 0.03930272345314734, 0.06863190239528194, 0.04180785035714507, 0.05022425400966313, 0.02425575723464135, 0.11126095399959013, 0.03338304188218899, 0.015832626013434492, 0.07343334553297609, 0.011583984560274985, 0.022402189606509637, 0.018542906655056868, 0.015747056386317126, 0.01764220098266378, 0.07188324394519441, 0.049242444583796896, 0.04283722773834597, 0.0326822540955618, 0.0208528969596955, 0.02293494402692886, 0.03746665010112338, 0.08644004017696716, 0.07665000652195886, 0.02988669140904676, 0.019443471319391392, 0.06765041951439343, 0.08147338012349792, 0.010934036672551883, 0.05144915761775337, 0.0478898284927709, 0.04213980930217076, 0.04163235098531004, 0.017277748956985306, 0.05509591916052159, 0.04906459631456528, 0.05292220572300721, 0.037570825370494276, 0.04979237972293049, 0.04945542983477935, 0.01693449266895186, 0.10649598742020316, 0.060114559237263165, 0.049374231457477435, 0.055629827620578, 0.10292506965924986, 0.07930340711027384, 0.028985609096707776, 0.017499766145192552, 0.03594619731302373, 0.07780313331750222, 0.04579994063533377, 0.00890452252860996, 0.038751381944166496, 0.025908900461217854, 0.03901742704329081, 0.06247535697184503, 0.03195329809386749, 0.022768355993321165, 0.022827727807452902, 0.036041058629052714, 0.030625000326836016, 0.04125849409319926, 0.0420385024335701, 0.06353513643261977, 0.032246821210719645, 0.03465096408035606, 0.06891100187203847, 0.09215635844157077, 0.053672724825446494, 0.048867518999031745, 0.03230163623811677, 0.03743922774447128, 0.04306354938307777, 0.04143128462601453, 0.04352065298007801, 0.022217682417249307, 0.006967400668145274, 0.03887760642101057, 0.018246029030706268, 0.07821170787792653, 0.02636343808262609, 0.003066483000111475, 0.015074693783390103, 0.0329247768240748, 0.0793145690113306, 0.019405662606004626, 0.05839481011207681, 0.026111273000424262, 0.01099605980925844, 0.05595199021627195, 0.015396849885291886, 0.010368413459218573, 0.04569280048599467, 0.07314737376873381, 0.020641588962462265, 0.0571642327849986, 0.021842389469384216, 0.06403711769962683, 0.01469711038225796, 0.035206543252570555, 0.057337427788297646, 0.01014366423987667, 0.029419693128147628, 0.014661859295301838, 0.08197758041205816, 0.02235453259345377, 0.024219668448495213, 0.004440699995029718, 0.029392985088634305, 0.03233343726606108, 0.048100067797349766, 0.05604295896773692, 0.0502135707938578, 0.03583895697374828, 0.033855103465612046, 0.0663821113994345, 0.05788942609797232, 0.05016655573854223, 0.022929268452571705, 0.03620951501943637, 0.038766551442677155, 0.057726546947378665, 0.046180940698832273, 0.02386481239227578, 0.007615286313011893, 0.027812741172965616, 0.020987632015021518, 0.022971954931563232, 0.02349042857531458, 0.0875564083980862, 0.053214029321679845, 0.0427519252843922, 0.027492702974996064, 0.02297931889188476, 0.13183144706999883, 0.0077760684325767215, 0.044207239770912565, 0.03542353239026852, 0.026351222331868485, 0.024455207567370962, 0.0247333311199327, 0.03463231390924193, 0.06285175200900994, 0.011023913539247587, 0.058280170560465194, 0.07155724815675057, 0.0240137336004409, 0.03252231013902929, 0.07575833835289814, 0.006490853265859187, 0.03187762129527982, 0.0500788747012848, 0.04588331350532826, 0.05339574418030679, 0.05466346970933955, 0.08374714991077781, 0.10099222767166793, 0.010938206614810042, 0.02853683054127032, 0.06666414978099056, 0.031724720320198685, 0.029037832173344214, 0.05989224147924688, 0.06203847689903341, 0.049753665589378215, 0.05694899882655591, 0.024082178169919644, 0.052369951372384094, 0.007167776366259204, 0.013467553508235142, 0.05368450270907488, 0.012389464336592937, 0.008924473313527415, 0.12703372951364145, 0.05629141516692471, 0.08098335485556163, 0.023587150826642755, 0.04860182642005384, 0.03494364114885684, 0.023176442591648083, 0.028011462345602922, 0.04084361869900022, 0.025016684958245605, 0.02170380081224721, 0.022747939510736614, 0.05697311491530854, 0.030962595883465838, 0.038658439079881646, 0.022127724841993768, 0.04170896660070866, 0.027451816204120405, 0.024029713895288296, 0.049129901599371806, 0.047289464419009164, 0.029427632252918556, 0.06959132122574374, 0.02939946403785143, 0.022796507510065567, 0.03284005695604719, 0.010433949737489456, 0.04887514085567091, 0.05306119142915122, 0.06071530551707838, 0.04255874424416106, 0.025372867603437044, 0.022356315603246912, 0.03947416327719111, 0.044315214836387895, 0.01877140279248124, 0.055862676454125904, 0.008615794613433536, 0.04239224341290537, 0.009890100209304364, 0.03259277706092689, 0.025204069825122133, 0.06964793225051835, 0.06400945785571821, 0.04179165669484064, 0.0838951044715941, 0.004871722203461104, 0.09502944958512671, 0.07786323985783383, 0.07085730641847476, 0.006619708656216972, 0.07608768864884041, 0.05968952384137083, 0.04100690232007764, 0.04066496519953944, 0.042201979013043456, 0.041588794338167645, 0.061733639740850776, 0.06092115130741149, 0.013840531883033691, 0.03546874773746822, 0.06245410186238587, 0.06180130134453066, 0.03907889542460907, 0.0693584575492423, 0.03747252791072242, 0.03157985680445563, 0.020399667373567354, 0.06853473299997859, 0.017800354507926386, 0.05102294962853193, 0.030142628456815146, 0.04535571330052335, 0.04891048934950959, 0.020508404995780438, 0.057877314247889444, 0.023577695865242276, 0.04792472056578845, 0.02893507255066652, 0.008317780575453071, 0.006075023748053354, 0.06503914322820492, 0.047527415517834015, 0.04486656005610712, 0.021845614101039246, 0.09258314530598, 0.05065130433649756, 0.09438472363399342, 0.03499491242109798, 0.07285107130883262, 0.01959540935786208, 0.038464497338281944, 0.029551775005529635, 0.09931858076015487, 0.030690001331095118, 0.027349796873750165, 0.05749958334490657, 0.0577309219079325, 0.03178919811034575, 0.04287844290956855, 0.06720130884787068, 0.027208987339690793, 0.07140838075429201, 0.014886102926539024, 0.02353580162889557, 0.03923447926354129, 0.015698915121902246, 0.024293031601700932, 0.04713408838142641, 0.02562779533036519, 0.023150953529693652, 0.027637152743409388, 0.040986363383126445, 0.043928147715632804, 0.08338854415342212, 0.004654101312553394, 0.04123058191908058, 0.01164222367151524, 0.05544380459468812, 0.05103511342895217, 0.011315223200654145, 0.02676055759366136, 0.0603488181513967, 0.0614228134509176, 0.01474238788432558, 0.011865422729897546, 0.056586741702631116, 0.011931054559681797, 0.04484800636419095, 0.0829565325693693, 0.03781200110097416, 0.017834886639320757, 0.23264325864147395, 0.10101834384840913, 0.10110947958310135, 0.11190337187144905, 0.07773344565066509, 0.24119076639181003, 0.15170929371379316, 0.18829775304766372, 0.19332791125634685, 0.07166871873778291, 0.15017494792118669, 0.20939160865964368, 0.14543403434799984, 0.13454421947244555, 0.10070768083096482, 0.07910849686595611, 0.1545452923164703, 0.1268089478253387, 0.1609801728045568, 0.23074453318258747, 0.14662037225207314, 0.10735309377196245, 0.11943148041609675, 0.14176871540257707, 0.06615260965190828, 0.27272508130408823, 0.21340590028557926, 0.16167776193469763, 0.07307770094485022, 0.13618895231047645, 0.1597794669214636, 0.09625617516576312, 0.11807031478383578, 0.15833665762329474, 0.15696929505793378, 0.10771539542474784, 0.1554303479497321, 0.09340700344182551, 0.10314140570699237, 0.062121656810631976, 0.13574149663327262, 0.07818130208761431, 0.15016253921203315, 0.10552388528594747, 0.20381027221446857, 0.17962599493330345, 0.10578998975688592, 0.1990073744673282, 0.16495803982252255, 0.1220956421457231, 0.2139950467972085, 0.15620716876583174, 0.20889209874439985, 0.11559027247130871, 0.08919757150579244, 0.18615217442857102, 0.1848338232957758, 0.14065347524592653, 0.1202226172608789, 0.15759507397888228, 0.11494573205709457, 0.20658528112107888, 0.1260550000006333, 0.09459279957809485, 0.18176079756813124, 0.13593098177807406, 0.17918505531270057, 0.13068698113784194, 0.14574392553186044, 0.1270810785354115, 0.14428376482101157, 0.13022236700635403, 0.1887976043508388, 0.17478652414865792, 0.16140739753609523, 0.12083019129931927, 0.179327889054548, 0.11476870757178403, 0.08811469640932046, 0.12626251933397725, 0.16765724576544017, 0.15770042926305905, 0.17523470713058487, 0.1303331251256168, 0.13494146143784747, 0.16775900905486196, 0.1831307279644534, 0.2506355009973049, 0.13163589115720242, 0.19564465881558135, 0.10094321623910218, 0.18650705460458994, 0.13482117414241657, 0.15275696874596179, 0.19522202055668458, 0.20151126198470592, 0.21737247181590647, 0.2761381887830794, 0.1352529408177361, 0.11658837203867733, 0.1711730961687863, 0.15520908404141665, 0.19746728445170447, 0.1435947697609663, 0.1904646906768903, 0.1310194781399332, 0.1796302548609674, 0.17430724517907947, 0.13734572305111215, 0.0576218558853725, 0.19051339040743187, 0.09091086394619197, 0.1436484418809414, 0.17624978703679517, 0.22074201522627845, 0.18851457891287282, 0.11479106105980463, 0.13522706954972818, 0.20913988701067865, 0.1527475583134219, 0.14381110580870882, 0.1597232121275738, 0.08976043114671484, 0.11744412026018836, 0.10650460375472903, 0.12349917698884383, 0.2420735510531813, 0.09467871059314348, 0.09096445442992263, 0.08601716443081386, 0.2022373050567694, 0.20502080413280055, 0.14856016816338524, 0.19008163857506588, 0.1028379044146277, 0.08104166539851576, 0.188371789699886, 0.2565101342042908, 0.1140311241033487, 0.11378024850273505, 0.17762420000508428, 0.1590077075525187, 0.20620114548364654, 0.16996465710690245, 0.23327340139076114, 0.15684963116655126, 0.1377096277428791, 0.15741942246677354, 0.06810071761719882, 0.13723944750381634, 0.12159307458205149, 0.14262807788327336, 0.10200252072536387, 0.06110369737143628, 0.07030287757515907, 0.07863050181185827, 0.2272856648778543, 0.18804917810484767, 0.18157368729589507, 0.15452363644726574, 0.1282467698911205, 0.1563441543839872, 0.128230323898606, 0.15997279639123008, 0.13524891837732866, 0.08330773169291206, 0.19117979449220002, 0.1543465896975249, 0.1445211036480032, 0.11037919350201264, 0.10509196275961585, 0.08530612758477218, 0.08428122164332308, 0.25303284579422325, 0.10621264285873622, 0.10783522258861922], [0.021790748978673946, 0.01828232932894025, 0.023458573741663713, 0.04246224278176669, 0.020838180171267595, 0.028318438744463492, 0.018566408616607077, 0.028735390296787955, 0.03413605831156019, 0.06174862741318066, 0.04177679889835417, 0.042497353788348846, 0.02125405560946092, 0.018594541579659563, 0.016543039455427788, 0.012501920118666021, 0.0352270710573066, 0.03209738606528845, 0.043495857826201245, 0.028863056395493913, 0.06753615103662014, 0.013570768624049379, 0.030470431374851614, 0.01610802031791536, 0.09905736704240553, 0.07493815384805202, 0.0208073495014105, 0.04465307756618131, 0.008712341532373102, 0.03270358713052701, 0.05002494282962289, 0.05105674332298804, 0.0521385608590208, 0.02970560180983739, 0.002996727380377706, 0.0017340402223453566, 0.03238446734030731, 0.04462529526790604, 0.03730195268872194, 0.016726130997994915, 0.02022462442255346, 0.04215362438117154, 0.016215978685067967, 0.02842916717781918, 0.011916758012375794, 0.02521580503525911, 0.005328551669663284, 0.04639172548195347, 0.050404273060848936, 0.026210897049168125, 0.053223291324684396, 0.008375567904295167, 0.05885460770514328, 0.021311677810444962, 0.057937446763389744, 0.04250751750078052, 0.018145052417821717, 0.017248482363356743, 0.04624582295946311, 0.042739479467854835, 0.015419991905218922, 0.03967021271819249, 0.002223747874268156, 0.032508903241250664, 0.012602880960912444, 0.10143440667889081, 0.00455813373264391, 0.08526641526259482, 0.05166703362192493, 0.042924010776914656, 0.05690220270480495, 0.02164854606235167, 0.010108340793522075, 0.0016656668526593421, 0.028117732326791156, 0.013754786923527718, 0.03583052246540319, 0.048125311950570904, 0.02988381929753814, 0.06921638821950182, 0.05533702809771057, 0.06579742519534193, 0.04925499430100899, 0.057065200599026866, 0.017506219119240995, 0.0535961463174317, 0.012902681719424436, 0.0889525811362546, 0.03363771356816869, 0.008056077040237142, 0.07075495683238842, 0.06256494903936982, 0.044376553341862746, 0.10375787067459896, 0.06977237557293847, 0.049307820372632705, 0.047427073441213, 0.043481363682076335, 0.06470582244219258, 0.07172324432758614, 0.03327262515085749, 0.0133659330822411, 0.014424280197999906, 0.0415750831598416, 0.05352524523914326, 0.0693177359062247, 0.02662408591277199, 0.016165299275598954, 0.04601130058290437, 0.013155955384718254, 0.027375614336051513, 0.06612555094761774, 0.0285527700179955, 0.029959954372316133, 0.07092006242601201, 0.058180585474474356, 0.07008683838648722, 0.06969004913116805, 0.01768444217304932, 0.06634273304371163, 0.003671421718536294, 0.0017320642541562847, 0.03133942693239078, 0.019065621672780253, 0.059960277867503464, 0.04071003582794219, 0.025614191763452254, 0.052626218675868586, 0.046137413737596944, 0.039136597406468354, 0.03382074573892169, 0.035380276312935166, 0.021368622801674064, 0.015263595414580777, 0.019766828772844747, 0.08652920922031626, 0.057977864125859924, 0.03111851925496012, 0.04433576490555424, 0.08040906614041887, 0.03699786509969272, 0.034806544208549894, 0.07043923978926614, 0.061353964410955086, 0.025622238499636296, 0.07492183402064256, 0.0100407886566245, 0.014898295485181734, 0.04081665276316926, 0.037424692782224156, 0.033039702102541924, 0.07009149907389656, 0.11479474953375757, 0.020158564002485946, 0.01543652695545461, 0.03274618640716653, 0.05664261800120585, 0.04180012459983118, 0.05209090384596493, 0.05017898671212606, 0.0617041987425182, 0.027320439367031213, 0.006057177879483788, 0.01971878398762783, 0.08131456794217229, 0.005810636421301751, 0.011793352769018384, 0.03848981941700913, 0.008152120226441184, 0.06517843692563474, 0.03770549919863697, 0.11401569485315122, 0.025105597960646264, 0.033155677519971505, 0.029865202523069456, 0.00993116045719944, 0.048554332679486834, 0.022272944588621613, 0.02251736350444844, 0.014638915799878305, 0.0382746151444735, 0.054355808679247275, 0.030279473066912033, 0.024247797700809315, 0.014639607852586778, 0.04395230091176927, 0.08800081384833902, 0.049485672352602705, 0.018952264181280043, 0.02913451175118098, 0.037059474489069544, 0.04466581282031257, 0.065199847886106, 0.01789141788322013, 0.02708523050387157, 0.1050245163787622, 0.044228342740098014, 0.041728811629582196, 0.09444581723073497, 0.042234329230268486, 0.04482342272240203, 0.09278690937208012, 0.01630667469726177, 0.017000662555801682, 0.050030460697598755, 0.046127602545311674, 0.04106511267309543, 0.04518059242400341, 0.07069691346259788, 0.06568376527866349, 0.026631726323103067, 0.0704392249463126, 0.10103290478582494, 0.0661057059187442, 0.04011214681668207, 0.06910056865308434, 0.04495175860938616, 0.017769624028005637, 0.061667766713071615, 0.017092807611334138, 0.027117287572764326, 0.041895390386343934, 0.022512263094540685, 0.029357998391787987, 0.020407574957062025, 0.018194947006122675, 0.05244711246632505, 0.01714012509182794, 0.005982336460874649, 0.08220193165470846, 0.03233550043660216, 0.017980132361117285, 0.02858367490262026, 0.016772986491560005, 0.06195174210006371, 0.04043622044264339, 0.02318174152605934, 0.042233824569848366, 0.013902632945246296, 0.026964438548020553, 0.019667744636535645, 0.059210259714745916, 0.016286113495880272, 0.070581932523055, 0.02900397539633559, 0.057670878450153396, 0.07472592929843813, 0.01076309501513606, 0.0031310166832554387, 0.08099845013930462, 0.08599438791861758, 0.0377105161169311, 0.03580102951673325, 0.01936980574100744, 0.012131388975831214, 0.03567077517800499, 0.02147763872926589, 0.05933100343099795, 0.10513826535316184, 0.017450205523346085, 0.03705582312250044, 0.05022905199439265, 0.011012622690032003, 0.0375520527450135, 0.02237629050796386, 0.030306383341667242, 0.03650673032097984, 0.013358176711335545, 0.014805520531808725, 0.03130547367618419, 0.04210739229165483, 0.027507952254381962, 0.08272585822851397, 0.057683272316353396, 0.08409403715631925, 0.05932598280196544, 0.0276698165180278, 0.022367258570739068, 0.048744292798801325, 0.004805432181456126, 0.010109310223924695, 0.023681655911786947, 0.04012166114989668, 0.05381420414778404, 0.06454093949287198, 0.01109096843720181, 0.062019830438657664, 0.05256195610854775, 0.058411074278410524, 0.0642689126834739, 0.0794798527203966, 0.07287000349606387, 0.055985412836889736, 0.0661232131824363, 0.03284105514467228, 0.015570499454042874, 0.014708289909322048, 0.08167584543116391, 0.0468746149999788, 0.019608174297900405, 0.059574657934717834, 0.04492470732657239, 0.05906113627133891, 0.04395286123326514, 0.021395271469373256, 0.044665935274679214, 0.028406175442796666, 0.018239954551972914, 0.06733548172633164, 0.054252067566267215, 0.03367200079082977, 0.06575725274160504, 0.03253572074754629, 0.012929646727570798, 0.062084360179142095, 0.09825002169236541, 0.10619545471854508, 0.024987572360259946, 0.053244346054270864, 0.02230953617981868, 0.07104529242496938, 0.04606695794791449, 0.003155232961944421, 0.0723062087490689, 0.02698601092561148, 0.018464016357029323, 0.05288266409479547, 0.0506460944598075, 0.05907150036364328, 0.01700785582215758, 0.018117015933967195, 0.040187983177020214, 0.0649655147572048, 0.029431606453727, 0.03360698865435552, 0.02412104073300725, 0.02855622657079948, 0.023417998672812246, 0.009731663740240037, 0.038020258871256374, 0.03645806398708373, 0.01621290804905584, 0.02452664299198659, 0.04271886260539759, 0.01176222060166765, 0.015890986651356798, 0.032275787234539166, 0.05825344211189076, 0.005042850325480686, 0.017364478189847432, 0.02172355121729197, 0.013995071149111027, 0.11938082141568884, 0.09548812653520145, 0.09310091205406934, 0.10080473148263991, 0.14470874826656654, 0.20980804256396368, 0.12428253612597473, 0.12692016607616097, 0.13108454964822158, 0.17289398820139468, 0.1588274398818612, 0.10293575658579357, 0.20173130877083167, 0.10736893862485886, 0.09983795796870254, 0.10006204945966601, 0.2568645839346573, 0.07471976947272196, 0.14350642450153828, 0.16737894038669765, 0.13773339131148532, 0.08823994125123136, 0.1651376989320852, 0.1514956887695007, 0.31797189556527883, 0.23816506000002846, 0.11365112964995205, 0.07591484987642616, 0.1377455031615682, 0.17840997112216428, 0.12444203108316287, 0.14473712799372151, 0.16439507628092542, 0.16114384605316445, 0.24562272388720885, 0.2120498035219498, 0.18705706024775282, 0.23190093284938484, 0.17906206659972668, 0.13642823556438088, 0.16607733210548759, 0.08797923219390213, 0.10279783586156555, 0.12631924910238013, 0.14830734813585877, 0.10468890977790579, 0.07199668121756986, 0.13317075645318255, 0.18326830730075017, 0.11965842175413854, 0.10138924699276686, 0.10738856843090616, 0.20107722433749586, 0.15390106360428035, 0.11477063715574332, 0.1164433934900444, 0.05217173857090529, 0.06009393866406754, 0.12124972738092765, 0.11761383459088393, 0.07447120195138268, 0.1410107154515572, 0.1375335457851179, 0.11889657747815363, 0.08925770773203112, 0.13235259801149368, 0.11090208849054761, 0.16338520625140518, 0.13946005725301802, 0.15346482919994742, 0.20228995301295072, 0.08430551213677973, 0.1063832848740276, 0.26364437013398856, 0.17000669235130772, 0.12655136320972815, 0.15076468815095723, 0.156145095534157, 0.11482224610517733, 0.14761418220587075, 0.11664376594126225, 0.13684122590348125, 0.16881925606867298, 0.1507618383038789, 0.11510993965202942, 0.14127579575870186, 0.20610010949894786, 0.19547908566892147, 0.18044057622319087, 0.07190019459812902, 0.1992043701466173, 0.13399439194472507, 0.21920152445090935, 0.17798071290599182, 0.12469056149711832, 0.1523209421429783, 0.24657187139382586, 0.17373599926941097, 0.1609439411549829, 0.1253593701403588, 0.12373696110444143, 0.2716859558131546, 0.11577291501453146, 0.10565902295638807, 0.14013100328156725, 0.24303204962052405, 0.15805752103915438, 0.11062796882470138, 0.14529685577144846, 0.07607400344568305, 0.13867934758309275, 0.10302067312295549, 0.15526725357631221, 0.12265122873941436, 0.17985010868869722, 0.15827694442123175, 0.14275675144745037, 0.16639353154459968, 0.1540265607764013, 0.08101814673864283, 0.12446988388546742, 0.16644220158923417, 0.17626955785090104, 0.19583718676585704, 0.19524057424860075, 0.10873072023969144, 0.10448622924741358, 0.15427773323608562, 0.08272599181509577, 0.11500750100822188, 0.1470882073044777, 0.15743528958410025, 0.10437458797241561, 0.1608025620225817, 0.15098739182576537, 0.121308698435314, 0.11336249357555062, 0.11461039262940176, 0.18266517872689292, 0.19419862859649584, 0.23372318741166964, 0.1784616691293195, 0.19243844726588577, 0.2591200894676149, 0.17929786175955087, 0.10790384898427874, 0.10106246452778578, 0.12158554178313352, 0.14594359294278547, 0.1021633663913235, 0.10951087329885922, 0.1631186861777678, 0.345087893656455, 0.05208363079873379, 0.11810032723587938, 0.13893979688873515, 0.19268035772256553, 0.16360629204427823, 0.10845936136320233, 0.13757970737060532, 0.11395379231544212, 0.11559517806745134, 0.06969127367483452, 0.15372024674434215, 0.18341419869102538, 0.07134978077374399, 0.09072933462448418, 0.15045010659378022, 0.0734728055249434, 0.18119752232450992, 0.09800725034438074, 0.1404310981160961, 0.14560092851752415, 0.151918564515654, 0.10678594451746903, 0.19268023897893727], [0.03546539694070816, 0.016604995798843447, 0.005701835716536152, 0.009535440822219243, 0.02095742845995119, 0.02087140983348945, 0.05605995414953213, 0.054212867325986736, 0.046342910718522035, 0.01113006199375377, 0.054804704122943804, 0.04781319061294198, 0.05784750959719531, 0.01689540375082288, 0.028522466272988822, 0.011379682437109295, 0.02040537634456996, 0.04837855129153468, 0.03866167855449021, 0.03160901949740946, 0.06847804776043631, 0.01038725937178242, 0.06806265286286362, 0.0324089693458518, 0.0401078238064656, 0.011810938885901123, 0.021024693014624063, 0.04595829639583826, 0.015372924899565987, 0.04782139505550731, 0.028344931561150588, 0.09181971283396706, 0.04726626488263719, 0.02934244112111628, 0.03879702402628027, 0.009698789381218376, 0.03201755323971156, 0.05061541036411654, 0.02672789752978133, 0.07014213580987416, 0.060206262714928016, 0.02553363719925983, 0.016006258883862756, 0.05112425278639421, 0.08031945922994055, 0.011345660532242619, 0.04714190690719988, 0.011085615697083995, 0.0932599839870818, 0.04919120670820121, 0.07652275788132101, 0.060254988420638256, 0.021006812821724452, 0.01542320818771259, 0.030560652412532363, 0.01662876493355725, 0.03425014867389109, 0.035181261991965584, 0.005306695420586038, 0.019476062734611332, 0.055828129479778, 0.044492929519037716, 0.04997464006009977, 0.05195834884943906, 0.06080107552406844, 0.009088797796721337, 0.018839698932424653, 0.04614646422851365, 0.031123766239034012, 0.06005048591759987, 0.024375842294830363, 0.02805049931339454, 0.03384011950402055, 0.03719141721376218, 0.053143131954129785, 0.03961749796872027, 0.007510482073485036, 0.0592077178589534, 0.0199839533524937, 0.06607183429878205, 0.053103723912499845, 0.04650894028600305, 0.021528403485717718, 0.023971154732862487, 0.024803571686788928, 0.04277460160665214, 0.04647222624043934, 0.03263257473008707, 0.044872085345559753, 0.02039876937487861, 0.01830073830205947, 0.009101772393478313, 0.020402350237418432, 0.02453086581226671, 0.038961892132647336, 0.03651005514257122, 0.052612492654589005, 0.0346408411860466, 0.004157992752880091, 0.13255982048576698, 0.02512148734240327, 0.05626051213766914, 0.04316343503887765, 0.030041046993574128, 0.027192348388780374, 0.05346067468053661, 0.033682632056297734, 0.020507033877947833, 0.06908602255862206, 0.02198338454036275, 0.05451206045108847, 0.07624175850651227, 0.04449201667739544, 0.048619871740811504, 0.09744398252223618, 0.03634113119915128, 0.06155435541586485, 0.004313418421588722, 0.027345460875949357, 0.03493841642921325, 0.08207456427044235, 0.02533478615077911, 0.026845359097933397, 0.053411859917105176, 0.02454758454405237, 0.05032536791986786, 0.05340027128113434, 0.034250282260472886, 0.04241526854457334, 0.043314473223290406, 0.020012570566905197, 0.07358881062828004, 0.045836394929210655, 0.035887307894881815, 0.048319828856620006, 0.017651993621257134, 0.022088832592999097, 0.028808586466766428, 0.053235533050610684, 0.012604269704752369, 0.043240533050266095, 0.03456504193309229, 0.0908352316764649, 0.0067608758126880275, 0.013343805021577282, 0.02645642733114073, 0.029018886998528615, 0.058238536075805314, 0.05557294571190141, 0.04892474229563959, 0.020753371245518792, 0.10431464470457286, 0.05246020024060272, 0.014302965028036851, 0.02989160071592778, 0.006481833388534142, 0.03335802779474761, 0.07787404552800581, 0.04308499374019448, 0.054252331028692424, 0.007552886536359438, 0.05886675666260999, 0.032462463350384496, 0.048052948841359466, 0.05778760714747477, 0.021109926819917746, 0.04550229488813784, 0.030234328223741613, 0.013523069865186699, 0.059766235935967416, 0.05394347143010236, 0.01319906488788547, 0.027538009235286154, 0.024753753168624826, 0.004217122441332322, 0.021124548984516878, 0.04098809258721303, 0.08559590656659566, 0.0036402362093213014, 0.06352172582410276, 0.038450886349892244, 0.07470624754205346, 0.0604262798151467, 0.04149359905568417, 0.031852629472268745, 0.05113938146678265, 0.061498716604546644, 0.01086058817236335, 0.034985015881829895, 0.02188095331803197, 0.009024155806400813, 0.08257049703388475, 0.0215780717189773, 0.005612804434349528, 0.048149505964829586, 0.04679291567299515, 0.02014411067648325, 0.029444603314914275, 0.04743090663396288, 0.06456411676481366, 0.00797598631834262, 0.016335071122739464, 0.07432966696796939, 0.039834817362134345, 0.06231316059711389, 0.006358179525705054, 0.04367447421827819, 0.09648431878304109, 0.01761736872140318, 0.025580591027392074, 0.015294736858777469, 0.047785942660993896, 0.009801360683923122, 0.022655252687400207, 0.12387695984216407, 0.10243806493235752, 0.10644986294209957, 0.019413098925724626, 0.035071461243205704, 0.016200885256694164, 0.04816679429495707, 0.05481689760927111, 0.07022225065156817, 0.05693941027857363, 0.09196734827128239, 0.05636177818814758, 0.08968050926341675, 0.0655221329361666, 0.01118796157243196, 0.008753587317187339, 0.044113573312642984, 0.014344339761009905, 0.07449378550518304, 0.02350098562601488, 0.012964090728928568, 0.02721651271713199, 0.0781481058220379, 0.0468580836604815, 0.010801120806718245, 0.02555315939389402, 0.07940634299302474, 0.052755504511878826, 0.024735962033446413, 0.04097004726645537, 0.07826283443137072, 0.01860257161752088, 0.021815800173499156, 0.04670166861615144, 0.0675601966213435, 0.03282769277575426, 0.05238484256551601, 0.056210220500361174, 0.04963924497133121, 0.014934361079212977, 0.06140722834970802, 0.021554265476879664, 0.05001746569178067, 0.018672932783374563, 0.050568020524224266, 0.05580127486609854, 0.016688938267179765, 0.08022746260394342, 0.03881986362102907, 0.034808930213330314, 0.04916700527246576, 0.03583684556360822, 0.04625270266842563, 0.047220956766977906, 0.02401883957645623, 0.019618087535491213, 0.021673916380677838, 0.09474389342358336, 0.1018474786542356, 0.010038139189418871, 0.05794746946776286, 0.06303272471996024, 0.03276283277955372, 0.0584064544091234, 0.06127862900029868, 0.030184112656570505, 0.014191760692483513, 0.03372051869519055, 0.049167587858391926, 0.033635973231866956, 0.03703960348502733, 0.07241769417305477, 0.03113090198894497, 0.05850848858244717, 0.04888350114924833, 0.04472634980629664, 0.016621402828604914, 0.04749390012875665, 0.0824782183917705, 0.012031799251417397, 0.07168221098254435, 0.011627182193478802, 0.020511958027782384, 0.033692064753267914, 0.03612931112002116, 0.017922241131600458, 0.0548153947602259, 0.03441404456680175, 0.06494946210295893, 0.03019566418515751, 0.030918683005438652, 0.048518954499741085, 0.05025473772548139, 0.08148777778842486, 0.015743418007332366, 0.0346811657800572, 0.03957114342483692, 0.03933876956580207, 0.03387406904948875, 0.05639918614178896, 0.005256349049886921, 0.02948302801087266, 0.02361340244533494, 0.023629714851267636, 0.06783054617699236, 0.061020970169920474, 0.07250493363244459, 0.04219637579808477, 0.02678566444956232, 0.029120082544977777, 0.026772678720590193, 0.0301315723118023, 0.030742977687623352, 0.007161875364545267, 0.03789778595091775, 0.043739074462791905, 0.026434812280058395, 0.02545118644775357, 0.040562608191976324, 0.008969806476670783, 0.016214314418903086, 0.02880481264583068, 0.076258991175564, 0.017920799509738572, 0.0058476436151977396, 0.029940675231046043, 0.06681695056613535, 0.010011901485995622, 0.023796466157364193, 0.01808083809009986, 0.0482959725195542, 0.06610376891330816, 0.033637142114457674, 0.019490606973704416, 0.0662411107623484, 0.04486626319703646, 0.07413154322421178, 0.057775617751758546, 0.1147837657481432, 0.2040746103739366, 0.09496552840573713, 0.14477751567028463, 0.08712239301530644, 0.3173519647680223, 0.1522199358441867, 0.12775664072250947, 0.11187733733095229, 0.16905229043914005, 0.09176739142276347, 0.09072444387129508, 0.17682763806078583, 0.13303035695571452, 0.09671452557086013, 0.16696146747563034, 0.10268459896906279, 0.11983467440586537, 0.21113083173986524, 0.14926793955964968, 0.07980644964845851, 0.10894134175032377, 0.14635867613833398, 0.15403135505039245, 0.1267084907158278, 0.049049834997276776, 0.17726022109854966, 0.10312216923921369, 0.15355066600022838, 0.21014420577557757, 0.11571546536288224, 0.28160858899354935, 0.10991406728862785, 0.2019524687784724, 0.10069709780509584, 0.15881246334174648, 0.1054077317530755, 0.1666718369233422, 0.2534981130156666, 0.17950812703929842, 0.11289089583442546, 0.10607521937345155, 0.14842024364043027, 0.13695195433683693, 0.19971971749328077, 0.21473464148584753, 0.16506351385032758, 0.17647174856392667, 0.3379888355266303, 0.1518031902378425, 0.15778472239617258, 0.14905443851603195, 0.08146120148012415, 0.07908851082902402, 0.15436198184033856, 0.08683157502673566, 0.11778072133893147, 0.10295638829120435, 0.12364730224362575, 0.13567188318120316, 0.1624279990210198, 0.19070306851062924, 0.119636320596328, 0.22669803234748542, 0.18706727219978347, 0.09155460284091532, 0.08241544011980295, 0.12190074674435891, 0.14474904688540846, 0.12656294071348384, 0.14734592550667003, 0.15119146759388968, 0.25160219287499785, 0.11515992329805158, 0.12780525139532983, 0.17762103845598176, 0.16818970703752711, 0.14074061822611839, 0.2230633789440617, 0.16335158696165308, 0.26714798994362354, 0.1650913740741089, 0.14595105894841254, 0.14126506430329755, 0.12712035299045965, 0.17294832825427875, 0.22196891892235726, 0.10324179602321237, 0.14619616064010188, 0.10791665845317766, 0.15509376913541928, 0.10705438675358891, 0.09617881369194947, 0.2606985188322142, 0.14448182919295505, 0.3038187534548342, 0.27991500799544156, 0.19906946254195645, 0.17142055789008737, 0.1654148317174986, 0.09482907713390887, 0.1621960778720677, 0.12835311965318397, 0.11922442863578908, 0.06127104425104335, 0.1800165872555226, 0.10758729331428185, 0.1710402814205736, 0.20289155276259407, 0.13560022140154615, 0.16891028790269047, 0.1585424254881218, 0.1351364830043167, 0.1470675755990669, 0.23916451027616858, 0.1933091349201277, 0.24570673500420526, 0.11515757811139338, 0.16218249656958506, 0.10690884417272173, 0.23510897008236498, 0.11876164760906249, 0.1350466682924889, 0.10191899942583404, 0.14218718279153109, 0.14326834352687, 0.16331084305420518, 0.06602147957892157, 0.14793633366934955, 0.08574195380788296, 0.14107670722296461, 0.1259335401118733, 0.14278924267273396, 0.14548445586115122, 0.10311073274351656, 0.129673415212892, 0.1254897951730527, 0.14149955328321084, 0.1644354936433956, 0.09305952989961952, 0.09292305636336096, 0.16360268520656973, 0.23985052190255374, 0.1527254719985649, 0.16986212198389694, 0.07623901998158544, 0.07372662745183334, 0.08621416011010297, 0.13479003362590447, 0.12963923189090565, 0.15923498285701498, 0.1686716577387415, 0.1514609859441407, 0.1271790568716824, 0.05575725808739662, 0.10547104437137023, 0.11255783480009995, 0.21397836331743747, 0.13523566361982375, 0.2080805305740796, 0.1813751776353456, 0.1350191791425459, 0.06377956276992336, 0.12201332312542945, 0.2502527605975047, 0.20011210581287742, 0.08290723169920966, 0.07686696597374976, 0.1677100421511568, 0.14580635499441996, 0.1646670140326023, 0.029713351686950773, 0.17087441141484305, 0.1304401279776357, 0.10610373268718831, 0.13390064385021105], [0.016756998775235843, 0.03689282151754014, 0.059666854940587655, 0.06241525785299018, 0.042783948956639506, 0.036638739838963374, 0.04927933303406462, 0.026794599907589145, 0.042502185169723816, 0.038287127754301764, 0.02345602075365605, 0.030788241274422035, 0.02080254038446583, 0.05136555468197912, 0.03926248049538117, 0.05221945495577529, 0.03963095310609788, 0.06022516892699059, 0.03096088894380955, 0.06408987697795965, 0.04211823135847226, 0.09826100547797978, 0.054169384893612005, 0.02283123816596344, 0.06946572015294805, 0.03930746948753949, 0.007096190192896756, 0.020082740629732143, 0.08062900902586989, 0.02948011693661101, 0.03051313826290425, 0.021170938780414872, 0.0298310433208826, 0.04333486744144466, 0.027879449116881005, 0.0565328098309692, 0.028009848174406216, 0.02009071315114852, 0.007177931729529519, 0.05332768923835829, 0.08095787692582235, 0.014972138251323486, 0.06540341157233343, 0.0570912425610004, 0.019199468006263487, 0.0040788802743918495, 0.03717095620231703, 0.055325072098639794, 0.011894578001374612, 0.04180391326372046, 0.061888503696536645, 0.0642925723514054, 0.030447777317021973, 0.03870823718898464, 0.04227111749059986, 0.02338737580430461, 0.010601486792438664, 0.006494913277492742, 0.042828277437365614, 0.022057786700315773, 0.021878285297134425, 0.038937931894906797, 0.012691567608271725, 0.06819773858296685, 0.0269137238865369, 0.005824988629683503, 0.03372378785570618, 0.04662699742766563, 0.07757888597552665, 0.10413739757495932, 0.027977063800790347, 0.02511344431695761, 0.04681661615904886, 0.03201441024430096, 0.08532667023246177, 0.05725597708078567, 0.047327967040473595, 0.029529824132623617, 0.057980988567578606, 0.050525410115369596, 0.04481935204239562, 0.01785488195309881, 0.030494098464259878, 0.024936983863881323, 0.05475278718222398, 0.08175457987817936, 0.024208944414567668, 0.022183686487551313, 0.05377184606913943, 0.026304997663828544, 0.011861322363984073, 0.10496697024791501, 0.05609084604657255, 0.05432313191704452, 0.10251624276861548, 0.09067772567505017, 0.05828690555063076, 0.10134312251466326, 0.08940096449805424, 0.04014117592305411, 0.007891432505857665, 0.026383262702438515, 0.031051575679157395, 0.04795137108885683, 0.039678161119809374, 0.015518314412474865, 0.014464371015492361, 0.07283520419150591, 0.030007731984369457, 0.026152534555876628, 0.01036407838910236, 0.03767081492696889, 0.061023897942504846, 0.023645643195777666, 0.023857862179283984, 0.01771131905115908, 0.06972359420615248, 0.06183248267916497, 0.02081328297208529, 0.048304095325875096, 0.06775228670448996, 0.07219799619633704, 0.013592696304840501, 0.018514857183618005, 0.041740767628652975, 0.023976132688403595, 0.04724164413346443, 0.07438417029334232, 0.030841662919556256, 0.03676938751596026, 0.06086935682105832, 0.024061544609139673, 0.04282531997887418, 0.01964367307664361, 0.03094103649345925, 0.027862440947501455, 0.05571171248448081, 0.03132696627289988, 0.07109456360922195, 0.07617213763296604, 0.046236163907451555, 0.06545844182255678, 0.025482970777375158, 0.031737871177028865, 0.014495362174784532, 0.0183352574458695, 0.02576484032033477, 0.0466769328340888, 0.06318378887954168, 0.06067928909033071, 0.0432348222238943, 0.011118702495878097, 0.07528455869760364, 0.02811095280776499, 0.05072356354503427, 0.027022246285923757, 0.06802013522246853, 0.021526989694393706, 0.01962205617019208, 0.00785155412813765, 0.034743038631859235, 0.02419106793240644, 0.018082517199218273, 0.01761704588716384, 0.05509601192898117, 0.020608077284123283, 0.030785786620981526, 0.021180594121688046, 0.011254397704760777, 0.0012702564845312736, 0.03645342185336631, 0.030085444122960325, 0.056938449197332375, 0.08250333266914822, 0.0381370432296535, 0.058294965274399146, 0.03401483591005672, 0.052827329564024694, 0.011629498621914536, 0.031414105542353354, 0.08998354300274514, 0.021099931946082506, 0.031509456675848924, 0.049779681576183066, 0.058698003413155675, 0.031131562500377186, 0.03679259076307062, 0.005285604511300335, 0.0644472507701721, 0.09002764883916825, 0.05723072179534938, 0.040131386995199136, 0.025483666540822014, 0.07334097041166387, 0.03454161233094055, 0.03787579611525871, 0.10337953121052124, 0.012291806051507592, 0.028948794861207716, 0.014291898678493453, 0.06865589602966793, 0.03759501938475296, 0.010897848624153994, 0.025367383132106625, 0.016612819890724495, 0.052408992050914094, 0.04195527057163417, 0.026023211612482555, 0.008392249528696993, 0.0520888295432087, 0.027743023820221424, 0.09623683479730971, 0.025096003846556414, 0.046113212301861495, 0.055942605758900754, 0.046408149210037664, 0.03572882596927229, 0.05563870370679069, 0.04193000044324435, 0.04390407615574077, 0.017664181541476864, 0.018273460664204322, 0.02859551772417035, 0.028656921167566907, 0.03166222035360988, 0.04375547963718418, 0.04649686183256563, 0.0034119288557121763, 0.047488604905083776, 0.0327747442497639, 0.044963031832594424, 0.052031680461368524, 0.015917620476102456, 0.0931110794772394, 0.03323339522466995, 0.027602264381130226, 0.015884715503489133, 0.0041789097213040804, 0.04296839491871651, 0.01798090790543938, 0.04265932380803861, 0.04641089886717964, 0.03607065918913577, 0.04945071348629426, 0.10278732705046423, 0.09404031516169198, 0.03464677465672139, 0.04159974472713657, 0.07288913606316783, 0.09431249040062539, 0.06037876009941101, 0.06369533643010072, 0.05340999341569841, 0.06375004013534635, 0.05039518917328678, 0.06387092114891857, 0.046985462176962756, 0.05119672350701876, 0.024259833480755333, 0.049695117559167556, 0.050378613304928876, 0.004734879912575707, 0.03626497942605056, 0.03536510681442451, 0.08861344191245735, 0.013912289214204066, 0.0565247092890786, 0.12957328464835882, 0.02801055135932984, 0.1044704437663313, 0.04573209720547311, 0.1765436033019796, 0.12084980626241304, 0.08845746473525651, 0.025938935177691747, 0.021400672449090052, 0.04869916279858444, 0.012273491702217143, 0.042794839973794296, 0.045209692034404725, 0.07293710848898627, 0.04881416600255761, 0.0237978150107665, 0.012000289516436169, 0.023736864277452696, 0.047109801598708145, 0.06447740423027426, 0.10172720620175824, 0.03393050566955935, 0.04263784234353807, 0.04856713472690899, 0.06498815026134253, 0.061655317185795866, 0.01594069013663102, 0.04466400569071993, 0.008506811154802563, 0.055992066190810874, 0.015501939851674251, 0.019888628194166813, 0.049717344882083125, 0.033337039858452044, 0.046278291920316406, 0.03255940639064647, 0.02983208974910667, 0.027948992064921185, 0.01572913351992611, 0.04479247145354748, 0.01997732226300286, 0.030168883786245715, 0.014667539508081973, 0.056226963351946324, 0.07183185764006339, 0.010994227632181719, 0.01728413328237366, 0.09632333210902289, 0.03595420508645475, 0.02044345408648951, 0.012793410678568762, 0.0933501697727479, 0.0163529234851012, 0.03776799545448739, 0.05620118114165962, 0.03873846486385446, 0.09480132081080228, 0.01767178484442411, 0.027371879477868788, 0.03207545560144354, 0.005129547553224256, 0.06920949366758578, 0.013542829547077417, 0.0037984774007782107, 0.027731396221497562, 0.035276809794595465, 0.023165150814747903, 0.025694224968901835, 0.033151168972835876, 0.034868146176449955, 0.03004230122314766, 0.03304939826193731, 0.06449502281611785, 0.04954822055879049, 0.02663250001205597, 0.013727739351452328, 0.04434724964085035, 0.013133562933944631, 0.056554391485406086, 0.08144247709424235, 0.02462549520714674, 0.07164879207266495, 0.03805817148531787, 0.03526100204908289, 0.03231003734981641, 0.07930320673040114, 0.11464821989648044, 0.15775258740177378, 0.10168417647946626, 0.18888614256866276, 0.11204041686141863, 0.08609515673015267, 0.10253426211420447, 0.26894695591181517, 0.12300652451813221, 0.16959782835328951, 0.14732379466295242, 0.19128654501400888, 0.19417381117818877, 0.13441743096336722, 0.1706809928873554, 0.11773743186495267, 0.15364025806775317, 0.12480762787163258, 0.14604972006054595, 0.2449040874489583, 0.22150060889543965, 0.1668688326026313, 0.18815506773535162, 0.1872187593835406, 0.13418999238638207, 0.10904041846515611, 0.10808515566168353, 0.17363178689265624, 0.12058406544383615, 0.1472321987967007, 0.10981932471622713, 0.060023501428077, 0.1827206468442455, 0.07020614604698494, 0.12265447934623808, 0.17182243085699156, 0.12502855039201677, 0.11831431809696369, 0.1708306247019209, 0.1486561872297898, 0.09884247076115571, 0.11502010267577134, 0.1015139055380132, 0.15635279298294336, 0.08272700855741277, 0.1648358823149465, 0.1375846055452712, 0.13270467286929488, 0.18699565494898707, 0.13757357723079622, 0.13283340580528602, 0.16446418507257476, 0.1954908561310731, 0.19358438265044242, 0.13410277519142255, 0.056722428562352434, 0.1622752205003053, 0.1173618457687553, 0.19817342312308028, 0.13411101303063333, 0.13035058043897152, 0.15281892323400825, 0.1412435420206748, 0.18686251365579665, 0.11375114889233373, 0.11730628859368153, 0.13362505473196507, 0.2733182947849855, 0.31471354071982205, 0.19075173855526373, 0.08523597236489877, 0.13089145766571164, 0.15694146452005953, 0.11166871219757013, 0.1592334095039405, 0.18119021959137172, 0.21600552485324442, 0.11805829941295087, 0.10766540435724892, 0.15463225718121976, 0.19923027110053226, 0.20203002321068197, 0.11595127536565997, 0.1854550454299897, 0.18553889327449724, 0.11333200614899397, 0.11227260518353432, 0.16891732346266508, 0.17499190609669313, 0.11136010492919013, 0.2576796995708719, 0.11160543668665923, 0.22324657067656517, 0.23024909023661166, 0.26715259125921875, 0.30285755346994847, 0.19934082141844556, 0.257601328776218, 0.11950133135542274, 0.19149749306961894, 0.1006375478755217, 0.1628975261701271, 0.1273091256734915, 0.16682621848303825, 0.12801766890333965, 0.16828458319650963, 0.16839027986861765, 0.2084966527763754, 0.111946052784333, 0.14058957633096725, 0.17071084206691012, 0.11562464875169098, 0.0871093015302904, 0.1900450952234678, 0.2296907131676562, 0.18473906588042155, 0.12947057140991092, 0.13326260464964435, 0.1556176957092248, 0.21543721784837544, 0.24128613236825913, 0.11523902881890535, 0.13648454973008484, 0.12871168088167906, 0.12693566211964935, 0.12932056852150708, 0.22691086545819417, 0.13059805700322613, 0.16701289830962196, 0.2039282291661948, 0.18814273324096575, 0.06317377730738372, 0.10901437650318258, 0.13916873460402712, 0.14344242168590426, 0.09231759002432227, 0.14751378446817398, 0.24307533167302608, 0.14661027904367074, 0.14521066274028271, 0.13093579356791452, 0.09753954887855798, 0.12086920600268058, 0.16142301232321188, 0.12242342651006766, 0.16680534929037094, 0.13420142146060243, 0.1273892479366623, 0.11259799241088331, 0.13206739065935835, 0.14331395592307672, 0.11136884742882103, 0.05526114720851183, 0.13353044574614614, 0.11302451210212894, 0.1294436166062951, 0.09745963441673666, 0.115470519522205, 0.10068213610793464, 0.10501675351406448, 0.17420524440240115, 0.08464086640742607, 0.07265729655046016, 0.17729306855471805, 0.11499116633785889, 0.16052605264121667, 0.128039235714823, 0.09841100094490685, 0.14928493474144489, 0.1293005602201447, 0.09555589203955606, 0.16709189250832424, 0.12608646706212312, 0.16829789732582867, 0.1855542408884503], [0.040463987897965126, 0.02811248163197888, 0.021603529239655472, 0.0651898882642854, 0.05607434439298231, 0.02147582603356568, 0.020218924728396814, 0.053766242854180746, 0.014815542308497243, 0.03694992607051972, 0.0735893301316537, 0.01703913734672824, 0.0647760221909266, 0.08150348905473948, 0.04764850062201731, 0.04183073077001609, 0.005738118388762814, 0.025548264929966535, 0.015558359773422126, 0.03350454258907121, 0.007563691278846818, 0.011351988268870628, 0.08004007031559013, 0.08380687053431757, 0.01990586271858774, 0.026230925759591628, 0.05939349968684837, 0.019726491191249806, 0.06761363867553882, 0.031206875646603294, 0.06547142198542133, 0.012807477160095004, 0.02290171065396862, 0.02862882160115987, 0.004506746499828296, 0.03985476629168261, 0.04461347285541706, 0.029228940766188316, 0.031747682369314134, 0.06756503542419523, 0.029825223027728498, 0.05871256435057148, 0.05131382327817846, 0.0914847593230661, 0.04296761937439442, 0.01118970747484127, 0.08543719828594476, 0.03217180121282581, 0.01805619878723519, 0.09704116702778265, 0.07709401121246628, 0.015426103491336107, 0.052916877102688886, 0.10371639946242794, 0.044883069131174125, 0.008301148118334822, 0.034998237242689356, 0.07192214732640423, 0.017063611521734856, 0.030527927410730626, 0.043886149578611366, 0.0038847833775434992, 0.04746921629703138, 0.024306393970618956, 0.058959476882591844, 0.049253851393586956, 0.01884635228634579, 0.05801758758025244, 0.007379385397143778, 0.08034694095840678, 0.05949643185886089, 0.09332906309282407, 0.042897994790109806, 0.04711798748758156, 0.03977242129622027, 0.13527116796467453, 0.19181565177859738, 0.23578260268550366, 0.061220626448630355, 0.17880215164041147, 0.18587226601084694, 0.056485030363546684, 0.17208381526870653, 0.013712376894545741, 0.25797934911679476, 0.19208761921618134, 0.15985304344212636, 0.1696517676464282, 0.13210313249146566, 0.1730916666565463, 0.15185739670414478, 0.05165833194041625, 0.029982565756654367, 0.060238920923438855, 0.034471969192964025, 0.03764150009374134, 0.09965311866835691, 0.05120269408507738, 0.03938618167012464, 0.052830350105068646, 0.03049039514735341, 0.06256782857235521, 0.22637617774307728, 0.06382737192325294, 0.044603531787288375, 0.02187485843023751, 0.02486437213519821, 0.02946324606455164, 0.032540923202759586, 0.011664174544421257, 0.02343608852243051, 0.01762519466865342, 0.01944994284713175, 0.0097026791627286, 0.05226963527093176, 0.037299169634934515, 0.0012191765472380212, 0.05970667858491652, 0.03220733895432204, 0.05529430265596602, 0.04566315168631263, 0.027382328917155974, 0.011304530708002858, 0.07097948619048111, 0.05206900306802709, 0.06139608500234317, 0.05345485253201332, 0.026160186098422855, 0.040086479639285244, 0.10641378714353777, 0.03785760978644248, 0.036458650283748284, 0.011423286396166077, 0.029908761025581043, 0.04155484108196106, 0.03014032594364835, 0.013361186120164348, 0.00859059869981138, 0.024887241415854078, 0.04065891669597477, 0.020482407562667504, 0.052282288888818584, 0.031971643984434195, 0.05055245026596822, 0.03763725500903092, 0.05663544143317267, 0.04040746222017333, 0.006289503498919657, 0.024362889962503687, 0.029026206429989543, 0.05713661004847381, 0.06412230140995234, 0.03355480825121049, 0.031083844260137994, 0.010532888227317017, 0.06811626561102457, 0.05213279808231164, 0.07040885626338422, 0.038752001637476496, 0.04785865457961336, 0.010510198917472735, 0.01885481833596714, 0.043968071549898013, 0.022265899751801044, 0.03239365883928258, 0.008144816565618385, 0.08783475830568932, 0.0425870868639322, 0.007954151406011079, 0.04959116122336127, 0.02271581193781458, 0.035459745486150496, 0.04131313842663076, 0.060058913004468195, 0.08467631138046272, 0.004869648828389472, 0.036193755513522774, 0.051411864697001874, 0.041665888638817705, 0.018089367222273722, 0.03612797525420319, 0.04252286882547196, 0.03127412164758425, 0.018117372164851986, 0.017639119214436505, 0.018434209850966, 0.017894592419906985, 0.05307938146870583, 0.01568112213135464, 0.06333661935059354, 0.08183726255083457, 0.01314660989010008, 0.03986082963820081, 0.014976184811530402, 0.06413476949092001, 0.00844431118821376, 0.0070734104338043835, 0.013332477064977866, 0.06013449703459628, 0.031104869303817395, 0.0970204165787436, 0.06957584744668566, 0.008630989159428282, 0.005881932693228009, 0.09504775836830959, 0.05422015150543302, 0.02364179330470506, 0.022919021248526406, 0.02283652782352874, 0.006329782172542764, 0.07372276086243801, 0.019509301673679147, 0.036226703159627505, 0.05406385149399284, 0.01904645570903085, 0.017371918220305815, 0.07000276789767668, 0.017546632770972792, 0.0780217329156585, 0.005256320755506749, 0.026662215605028905, 0.0761970663734246, 0.0690199936798308, 0.01967905311175855, 0.015343168488470837, 0.02827888041792903, 0.04734111047582701, 0.009134688498306787, 0.05074476299341768, 0.03915540342859458, 0.029490445776900742, 0.056619147580931894, 0.06575711173354648, 0.018060185975627974, 0.028209216870891396, 0.06681518425466493, 0.02875081769161625, 0.05438988438982051, 0.08841673567076214, 0.0373752620362211, 0.018309532752027735, 0.08556718545150943, 0.016148498907568865, 0.04593021352775395, 0.0781272143649403, 0.0442264873709064, 0.15284439374227077, 0.03961135669669602, 0.11334710143273696, 0.02064865049760556, 0.09595187235390767, 0.06981660015298985, 0.10524038487346843, 0.10915520644630305, 0.10206231556367129, 0.08277466185973026, 0.05670511796779465, 0.1104536977072712, 0.13932878617197275, 0.06609784657484852, 0.2384450871613808, 0.20750233816215768, 0.13850032672053203, 0.09962543656001799, 0.10063820096547715, 0.05529897076485213, 0.0567565191158792, 0.02437864946841728, 0.020817741424252745, 0.07202420747489668, 0.06857258995296434, 0.04616035723302048, 0.03671823498734739, 0.03950971215090249, 0.020417482628545258, 0.030525335459969938, 0.010654669094947167, 0.06667606125120074, 0.12128069720347412, 0.03568285363144241, 0.024701121910766233, 0.024705083123990335, 0.03766793910472188, 0.027241155730735045, 0.03089121983066434, 0.05084635558887385, 0.03846006300591398, 0.057754043518798426, 0.024731405246711802, 0.07058730567223392, 0.0416232633870095, 0.028724840667564422, 0.0559663656167686, 0.04919914026686456, 0.018260781071148813, 0.037098448374308646, 0.014482287388091208, 0.06479613439296372, 0.02706870473048184, 0.03567914660379756, 0.014660612487205071, 0.039497500110883266, 0.057040802494157106, 0.022265478582994547, 0.09636403890908696, 0.04233080100675579, 0.025937866485037375, 0.0247674587808433, 0.013309364730957896, 0.03811841903370805, 0.029096567595843226, 0.004083203284608317, 0.07969529819092713, 0.031653514961362816, 0.012587995333888102, 0.04386164386232849, 0.04525055097474251, 0.10131063128937967, 0.035113095727865584, 0.04523069481365383, 0.06853943821624853, 0.05195545818423852, 0.06257182874833234, 0.02098841312545119, 0.011652660123218084, 0.02954411418613745, 0.05158485560968984, 0.027644266228890046, 0.03354991749802139, 0.025113104784395546, 0.06331221011350863, 0.04260263856849633, 0.07662374191568233, 0.07368588354438543, 0.018975011007569265, 0.033807041982072406, 0.00693781773406954, 0.05520100727153476, 0.061476248083636165, 0.016748896377976052, 0.03374754400283564, 0.03990580007666722, 0.052554048525053076, 0.05452645069453865, 0.02922467527241679, 0.02841532797901891, 0.031078348656592425, 0.04312460216169711, 0.04428113912581466, 0.017996094102272764, 0.04999416967621073, 0.01897663445561193, 0.0829467955918517, 0.13616388256195933, 0.13577153877122328, 0.11425573509768583, 0.17048822744982317, 0.10602767739328556, 0.18116373976226896, 0.13795461069094017, 0.1122673878853675, 0.08223087541409768, 0.15666231309296563, 0.12997196638025343, 0.13893136609112844, 0.1472551905317232, 0.18609689926961437, 0.183212126721628, 0.08394737393246032, 0.11490855045849457, 0.12621528905583546, 0.08019028100534342, 0.09832016949076205, 0.16803535516373813, 0.17554732941789553, 0.25812807551119477, 0.15332255949033424, 0.14351138204801828, 0.15742484014481306, 0.0791509922419209, 0.17796205531340092, 0.14861722447676584, 0.15416857815580443, 0.0900590639503207, 0.09736698470078409, 0.09702567098429427, 0.17216840526089072, 0.17980934993829578, 0.16840973898069933, 0.13651186076458544, 0.1332952591474168, 0.1255769975250587, 0.13916977361077443, 0.16621283342828974, 0.13012376526603475, 0.192422105174046, 0.17964389553526416, 0.22508786874823272, 0.20134600054007024, 0.16769983019912615, 0.07330574808293022, 0.17476112785516307, 0.1519196480512619, 0.15805747651029378, 0.1262605155352503, 0.17313821415882558, 0.1368541838019155, 0.14504157181363553, 0.18570189859019592, 0.17960589757421985, 0.14078838285058737, 0.17952417227206752, 0.13969371502753347, 0.12215554088470526, 0.194348779914435, 0.18548102059867233, 0.15642457350622863, 0.22548177104908973, 0.06467728686402552, 0.2185202031978406, 0.1145072266808711, 0.17793836595956236, 0.22744375717593357, 0.2105536189628765, 0.20357667381176725, 0.22052260668715462, 0.17201245034812018, 0.3824805293697864, 0.40219470276497304, 0.37187449692282826, 0.28916653187479824, 0.36642882507294416, 0.36360483441967517, 0.1715259428601712, 0.24445838324027136, 0.18827161460649222, 0.33128091890830547, 0.34813046164344996, 0.19700612872838974, 0.2075000968761742, 0.238179279549513, 0.303676676703617, 0.24084933393169194, 0.09645976111642085, 0.08909233496524394, 0.19230630045058206, 0.1378144189948216, 0.1682066873763688, 0.2356111368862912, 0.11196020554052666, 0.12807788676582277, 0.09763585738255642, 0.16128445335198194, 0.20481150364503264, 0.33197898301295936, 0.1844010324566625, 0.13345792307518423, 0.169715681404341, 0.1387236686423421, 0.15675957896746695, 0.13015057164011523, 0.1510522555327043, 0.1713903821655549, 0.12420363098499365, 0.09713133054901846, 0.16826567327370867, 0.17933709168573841, 0.07966615405166522, 0.11187914074980654, 0.20568281470332295, 0.15780692745465785, 0.1649426031508483, 0.13458306348184124, 0.17469850543420762, 0.06644226246862672, 0.1601768276304938, 0.1849520325777121, 0.16288930317386985, 0.12613512226380408, 0.09639506810344756, 0.14547130500432104, 0.21070287970360368, 0.07609269072418101, 0.18363868352025747, 0.11317137570586056, 0.12471808033296838, 0.12851723819039762, 0.09790940559469163, 0.18107153533492237, 0.07913079098216258, 0.09198162719258107, 0.1358726341277361, 0.10041137837106362, 0.16419494873844087, 0.1390777769847773, 0.10148799716262147, 0.20010351174278185, 0.19596713682403788, 0.15653000300517306, 0.14089508884353563, 0.102815840364201, 0.13309572532307357, 0.10527544392971322, 0.17621042352402583, 0.12639030232094228, 0.1094843860482797, 0.2163369531626813, 0.1865026610903442, 0.1345826924080029, 0.1906757426331751, 0.132799148268532, 0.09779325206181966, 0.0692630693083629, 0.11267847090493888, 0.10168410968617536, 0.11465892166597769, 0.15554146229987964, 0.12276670691790059, 0.11418909765779972, 0.20977083127945662, 0.11396575573598966, 0.12231048647663556, 0.20454078301554546, 0.09715781037812121, 0.11661630647722632, 0.16425501817138866, 0.17781122121959925, 0.11412988911615685], [0.0811964699823875, 0.026875009752984624, 0.034614235191838816, 0.06706439744448289, 0.02505392778402893, 0.06636924998019822, 0.018486703811504412, 0.027808551749330945, 0.03899636860296596, 0.038235685788095, 0.0404209025145974, 0.034255410500918515, 0.03619243077991996, 0.04304038324335124, 0.01837745225202525, 0.04892640841717366, 0.054992586228763685, 0.02236597465525847, 0.05133935315825511, 0.08101046551018953, 0.04326785150624346, 0.029422090265143197, 0.012691027695836965, 0.058109617602895014, 0.025425645435461774, 0.015332585462601855, 0.025330108765047044, 0.027802965232694987, 0.006716109464832698, 0.12822593038436025, 0.008615407768957084, 0.024755740269029047, 0.021290172226144932, 0.028644709127547685, 0.05346770652977284, 0.024518202917533927, 0.04847951677220408, 0.11093518827692606, 0.01520077539680642, 0.017226373784069438, 0.03985094423114788, 0.03702027053805068, 0.0028459974191719084, 0.053992074681445956, 0.07682543538976461, 0.07057344235363416, 0.03195793651684653, 0.03739813873835374, 0.030632273374067154, 0.06466888575232588, 0.05484623099619057, 0.056837005031411536, 0.021582533881883137, 0.05768117574916687, 0.019490562444843818, 0.04162846955296118, 0.024064839744823985, 0.04121962410863489, 0.07041403645416722, 0.018837132956832647, 0.0599186174076749, 0.06272455531870946, 0.05050731655501295, 0.02261983183416305, 0.07431935853674076, 0.04568213211314287, 0.095512038533343, 0.14957066159695387, 0.3286531224148348, 0.13836589409038424, 0.03491244868200738, 0.23828530276659876, 0.024973065228550695, 0.30505404341965914, 0.4762647516326979, 4.724325919523835, 8.09237351641059, 9.450551737099886, 7.007559752091765, 6.171206580474973, 4.581631701439619, 4.217473017051816, 9.093483947217464, 11.964470241218805, 21.591079831123352, 22.375874519348145, 18.419386222958565, 19.182708263397217, 14.856918733567, 4.006622806191444, 2.3891270253807306, 0.6302312726620585, 1.0644093342125416, 1.5241493959911168, 0.999176453333348, 0.28501296881586313, 0.4793943290133029, 0.5032056325580925, 0.4013370769098401, 0.2436348664923571, 0.08559641122701578, 0.05335703746823128, 0.09182682260870934, 0.057137118419632316, 0.029378949220699724, 0.08926132941269316, 0.10682619118597358, 0.04512333202001173, 0.09637995797675103, 0.049437759298598394, 0.047875623786239885, 0.01620153278054204, 0.0437249328388134, 0.08252092156908475, 0.04182119417237118, 0.024180299369618297, 0.03374798929144163, 0.034558254992589355, 0.0654142172425054, 0.002158619777219428, 0.01949356072145747, 0.0315271902945824, 0.03388442572031636, 0.05945918717770837, 0.04358942409453448, 0.06387059460394084, 0.01921872673847247, 0.08394401942496188, 0.010703798343456583, 0.03951202023017686, 0.024986755997815635, 0.07909945008577779, 0.024798630838631652, 0.013433912881737342, 0.026743336056824774, 0.013177091750549152, 0.04547203010588419, 0.00884001876329421, 0.02630256156407995, 0.037199881408014335, 0.022378888024832122, 0.047580994869349524, 0.029618818771268707, 0.0541554213850759, 0.04566254312521778, 0.005874127155038877, 0.04571922094328329, 0.03202985433745198, 0.08331045537488535, 0.06180319753184449, 0.04216195869958028, 0.040244950432679616, 0.016700508349458687, 0.005948305743004312, 0.015015211574791465, 0.07491394499083981, 0.02357382185437018, 0.07789720795699395, 0.040576278552180156, 0.034190045844297856, 0.053038151454529725, 0.023809986232663505, 0.03393832790607121, 0.0344623027194757, 0.011222075318073621, 0.0654763424245175, 0.05814501433633268, 0.018599068680487107, 0.043874178736587055, 0.014177586599544156, 0.04836012376472354, 0.033150638337247074, 0.037229385488899425, 0.028115140376030467, 0.03639308153651655, 0.04522699149674736, 0.056203199783340096, 0.0030152771296343417, 0.09176821520668454, 0.08472514469758607, 0.024301742560055573, 0.03981430440035183, 0.07014755348791368, 0.041578671443858184, 0.029823772129020654, 0.026483174333407078, 0.0395576252049068, 0.03127526826574467, 0.009056379858520813, 0.024967330282379407, 0.0182324774141307, 0.03350488026626408, 0.0058177299615636, 0.008853639956214465, 0.012381463984638685, 0.038193476138985716, 0.08202735625673085, 0.05962360628473107, 0.020762770545843523, 0.10401826802990399, 0.03666927179438062, 0.0288988242027699, 0.05045795260230079, 0.011158092911500717, 0.044958007492823526, 0.018386090850981418, 0.08724836516194046, 0.027237619397055823, 0.04684261730290018, 0.032395718299085274, 0.03139269829262048, 0.04175487956672441, 0.05789901093521621, 0.01728385683236411, 0.01661988142586779, 0.01554208725792705, 0.024782956679700874, 0.007373592470685253, 0.06268680968787521, 0.043277748045511544, 0.05994392835418694, 0.10836890098289587, 0.018435319361742586, 0.019801997295871843, 0.021984560844430234, 0.07546384673332796, 0.025938658727682196, 0.05767835558799561, 0.07525415290729143, 0.033586349527467974, 0.03962958013289608, 0.06220629875315353, 0.026965911711158697, 0.024632532622490544, 0.024749910699028987, 0.08501507210894488, 0.037302761629689485, 0.05471488941111602, 0.020379863162816036, 0.004177118826191872, 0.07045377104077488, 0.026559172110864893, 0.0807787076337263, 0.2309729068656452, 0.4719778394792229, 0.22506876586703584, 0.032229332500719465, 0.1726067770505324, 0.08183070938684978, 0.31621873495168984, 0.1276606068131514, 2.9634887678548694, 5.494174584746361, 6.892493376508355, 5.876737581565976, 4.567512134090066, 3.2484820252284408, 3.3116576727479696, 8.11993058770895, 11.880549844354391, 21.280676387250423, 22.43298165500164, 18.65333776921034, 19.37526673078537, 14.62929479777813, 3.498388440348208, 1.6620755824260414, 0.37416984094306827, 0.5510188231710345, 0.8437907975167036, 0.7922791584860533, 0.27530288673006, 0.3075956320390105, 0.6463571917265654, 0.3153041418408975, 0.2755013370187953, 0.017423658900952432, 0.08973162097390741, 0.07694952248129994, 0.040410590372630395, 0.10441807040479034, 0.06360773331834935, 0.021745752565038856, 0.05322800025169272, 0.16291833599098027, 0.07559821257018484, 0.03981553636549506, 0.09002960068755783, 0.012402827633195557, 0.045892775888205506, 0.041172635028488, 0.012303063504077727, 0.006783125400033896, 0.03269578344770707, 0.06386443477822468, 0.04845753064728342, 0.032813907382660545, 0.013772580841759918, 0.011045741957786959, 0.011506869850563817, 0.028192104800837114, 0.0367220830230508, 0.03854842310829554, 0.06316913888440467, 0.019680658006109297, 0.021329654482542537, 0.053181886905804276, 0.026915723974525463, 0.013877159653929994, 0.0001602179713700025, 0.0365107008110499, 0.04433714158949442, 0.05024885249440558, 0.022681700975226704, 0.03910872605047189, 0.08592324564233422, 0.06405516673112288, 0.021125886705704033, 0.04545195130049251, 0.01840297285525594, 0.07224766071885824, 0.037584766614600085, 0.02341661642276449, 0.05066909361630678, 0.10911036588368006, 0.07668407852179371, 0.005279049491946353, 0.014153559568512719, 0.061644114466616884, 0.03465639289061073, 0.010625229951983783, 0.05484499160957057, 0.019674466639116872, 0.05314880567311775, 0.025249823229387403, 0.0653311338101048, 0.031054651881277096, 0.057217849243897945, 0.0937323461403139, 0.023056880745571107, 0.015022338047856465, 0.06333070443361066, 0.018352119041082915, 0.06702376485918649, 0.06545695010572672, 0.017717536393320188, 0.01234354673215421, 0.03289966254669707, 0.07021528188488446, 0.0034173493168054847, 0.03793065567151643, 0.033594498308957554, 0.15921032871119678, 0.20707517280243337, 0.21043745800852776, 0.15881335391895846, 0.07982454320881516, 0.15420261304825544, 0.11067337341955863, 0.19267557829152793, 0.10211698216153309, 0.0896066210407298, 0.09910186621709727, 0.15294124401407316, 0.16406464244937524, 0.1639164800872095, 0.13546469039283693, 0.14047046162886545, 0.12165912572527304, 0.08873165119439363, 0.12757190532283857, 0.19899820152204484, 0.1995116489706561, 0.16391397162806243, 0.07385501157841645, 0.22600888885790482, 0.11426383192883804, 0.10251797197270207, 0.18550945969764143, 0.1598318773903884, 0.09531827119644731, 0.22006784827681258, 0.20138635853072628, 0.14855635352432728, 0.15546067210379988, 0.12474340241169557, 0.17971193563425913, 0.09320929530076683, 0.12487464380683377, 0.27941767999436706, 0.042371381641714834, 0.1342960007605143, 0.10413097799755633, 0.12314470499404706, 0.15633274015272036, 0.15216200379654765, 0.21722169709391892, 0.2243129033013247, 0.15288374241208658, 0.15877887373790145, 0.11005543899955228, 0.19650216592708603, 0.12944354239152744, 0.24866429739631712, 0.17986484774155542, 0.13792115467367694, 0.17292587086558342, 0.1502314698882401, 0.14352165337186307, 0.17540195753099397, 0.24280472978716716, 0.20461829291889444, 0.1812305924249813, 0.18117861240170896, 0.13455894368235022, 0.13584156782599166, 0.18855118163628504, 0.13208848249632865, 0.1807450200431049, 0.5903714115265757, 0.7184611132834107, 0.2868578885681927, 0.10085437374073081, 0.7690970180556178, 0.31813887879252434, 1.025911106262356, 1.3971820590086281, 7.487715762108564, 12.991290092468262, 15.161333698779345, 11.544087398797274, 10.54920768365264, 7.844089139252901, 7.738906033337116, 12.990284096449614, 20.380050614476204, 32.4945567548275, 32.75124438107014, 29.39843349158764, 30.700194239616394, 23.679588362574577, 7.20724948681891, 4.019945366308093, 0.9742667118553072, 1.6293378453701735, 1.8182412651367486, 1.315892308484763, 0.3903857379918918, 0.6488370336592197, 0.8673465647734702, 0.5526260775513947, 0.586720104329288, 0.1517355360556394, 0.23331067204708233, 0.2504452143330127, 0.1344815079937689, 0.18733024480752647, 0.20320968178566545, 0.30231433105655015, 0.19207046076189727, 0.33115611935500056, 0.16195673524634913, 0.10543423384660855, 0.20679000997915864, 0.11869371883221902, 0.22090696496888995, 0.18522919504903257, 0.15476174710784107, 0.11481768931844272, 0.13320943719008937, 0.200608572922647, 0.13088793988572434, 0.18533886963268742, 0.1455384396831505, 0.07892152018030174, 0.254512332030572, 0.14807315601501614, 0.20043327764142305, 0.17800303670810536, 0.19069374713581055, 0.10410341463284567, 0.09437042244826443, 0.1188482265570201, 0.11035600138711743, 0.049850771902129054, 0.10942047229036689, 0.09646168327890337, 0.16235838556895033, 0.1203667423396837, 0.07805196801200509, 0.10832187108462676, 0.1468224442214705, 0.21582720160949975, 0.10614119630190544, 0.16106853290693834, 0.1488576061092317, 0.10142506303964183, 0.12016363136353903, 0.12065351562341675, 0.20429182215593755, 0.3456915565766394, 0.21816949389176443, 0.1687285804655403, 0.17232409300049767, 0.1454036359791644, 0.08098806749330834, 0.10537008260143921, 0.2574683359125629, 0.11432301820605062, 0.09831039540586062, 0.13222295965533704, 0.16618862457107753, 0.1272906907252036, 0.12174226852948777, 0.15810712618986145, 0.1654490892542526, 0.10556186098256148, 0.24263649975182489, 0.11318907592794858, 0.16056060703704134, 0.23751278640702367, 0.1149274232739117, 0.13879592414014041, 0.07877018884755671, 0.18289286963408813, 0.053602243060595356, 0.1426417037146166, 0.13956535316538066], [0.011224459467484849, 0.024240452294179704, 0.020428286443348043, 0.05627095786621794, 0.04128601292904932, 0.015815241204109043, 0.08830578459310345, 0.04304691785364412, 0.018223580918856896, 0.03671390084491577, 0.08414677417022176, 0.08949220413342118, 0.12988102360395715, 0.026314584356441628, 0.07189566007582471, 0.10174547045608051, 0.024390954276896082, 0.057006166462088004, 0.05928995153226424, 0.050255338865099475, 0.02648301662702579, 0.11445915777585469, 0.02271694927912904, 0.0470742675679503, 0.04537856031674892, 0.03540493416949175, 0.0387282974406844, 0.12112796321162023, 0.018765892345982138, 0.03823844657745212, 0.05298638665408362, 0.030028905457584187, 0.05775343866844196, 0.06872306781588122, 0.033913859297172166, 0.06086798384785652, 0.03451521784882061, 0.008842050392559031, 0.08927908900659531, 0.0515638825163478, 0.042135523399338126, 0.03578982679755427, 0.05119388850289397, 0.08505194200552069, 0.11732199243851937, 0.017249920274480246, 0.006759455527571845, 0.019364013278391212, 0.07296229698113166, 0.05829454225022346, 0.047906756881275214, 0.033280970601481386, 0.03408995980862528, 0.07603420206578448, 0.08403197876759805, 0.030573447038477752, 0.08265645999927074, 0.02066008142719511, 0.014764895367989084, 0.08370073599508032, 0.025938282087736297, 0.08638201165013015, 0.03336995781864971, 0.06215722794877365, 0.03793481540924404, 0.06869482909678482, 0.46208477346226573, 5.528233107179403, 21.743377558887005, 32.79299654066563, 42.95644797384739, 61.05157099664211, 56.72661267220974, 66.1041484773159, 76.30476951599121, 85.28813347220421, 101.30704030394554, 92.91245475411415, 97.87710875272751, 99.56800282001495, 96.31468579173088, 94.27155822515488, 106.70411869883537, 110.38630351424217, 131.61473840475082, 119.25209417939186, 124.83592495322227, 116.42386794090271, 111.64075300097466, 88.34155842661858, 81.36700987815857, 75.6599897146225, 68.9094315469265, 67.40103408694267, 55.82723893225193, 38.798954263329506, 20.6647427380085, 9.420020375400782, 2.697343686595559, 2.340926374308765, 0.6842983933165669, 0.2621256688144058, 0.16397423401940614, 0.3442905005067587, 0.11503232584800571, 0.14568174839951098, 0.15871659270487726, 0.11573048643185757, 0.041541077953297645, 0.03743446315638721, 0.030290367794805206, 0.06794556422391906, 0.08932747703511268, 0.028410799022822175, 0.02556767580244923, 0.012697373058472294, 0.011084336420026375, 0.025144030078081414, 0.03276369738159701, 0.07535765282227658, 0.03392824582988396, 0.008176871779141948, 0.04277624175301753, 0.04764143537613563, 0.030379995114344638, 0.03591682681872044, 0.08638303581392393, 0.0204698819652549, 0.030011450144229457, 0.029618416156154126, 0.016381236418965273, 0.05316032009432092, 0.06071747629903257, 0.031672309851273894, 0.05898521085327957, 0.043661245435941964, 0.07439918394084089, 0.03478044287476223, 0.015462393585039536, 0.052187371911713853, 0.02560223947511986, 0.015793852508068085, 0.05741647764807567, 0.019689973814820405, 0.02752627773588756, 0.012529041905509075, 0.0123533087571559, 0.025707993663672823, 0.02868186289560981, 0.05352947177016176, 0.055454072207794525, 0.015616275122738443, 0.03087008160946425, 0.06650480325333774, 0.027220282827329356, 0.0082416844634281, 0.06901637199916877, 0.07164819093304686, 0.03121319503406994, 0.029533573833759874, 0.033522580488352105, 0.03839465382043272, 0.028690085891867056, 0.06642715976340696, 0.05860996985575184, 0.05999384149617981, 0.09312461625086144, 0.04349327144154813, 0.056468688271706924, 0.03619752933445852, 0.02942911840364104, 0.014507108517136658, 0.0683630742423702, 0.025060306543309707, 0.07229567025206052, 0.061764921265421435, 0.00804969457021798, 0.029858565867471043, 0.0872219743905589, 0.017067789813154377, 0.07690913480473682, 0.04530688740487676, 0.05610044201603159, 0.02272974576044362, 0.08158034586813301, 0.04946383094647899, 0.037400008950498886, 0.034918215169454925, 0.07478049941710196, 0.051544375164667144, 0.04952221570420079, 0.007988570359884761, 0.049064856066252105, 0.05578244286880363, 0.06401810387615114, 0.05836834141518921, 0.023933427655720152, 0.03292243905889336, 0.05308987543685362, 0.02825144136295421, 0.03371638864337001, 0.02331257659534458, 0.008413398882112233, 0.043769242765847594, 0.03336676658364013, 0.07974281790666282, 0.022354907378030475, 0.024930039216997102, 0.06578767337487079, 0.05364132084650919, 0.015934571129037067, 0.013320629605004797, 0.04090840076969471, 0.02800209458655445, 0.03366984114109073, 0.061533523330581374, 0.04194726650894154, 0.06283038557739928, 0.030532012933690567, 0.04914805824228097, 0.05964280564512592, 0.03127252231934108, 0.05127549135067966, 0.029334275641303975, 0.06523366755573079, 0.01560924883960979, 0.01568705560202943, 0.0290593692989205, 0.06485388832516037, 0.061141420737840235, 0.05830404545122292, 0.056597168877488, 0.03529471410729457, 0.059102948871441185, 0.021355492353904992, 0.048597436616546474, 0.0818321194674354, 0.1017719205992762, 0.03106314761680551, 0.11984973258222453, 0.13092188572045416, 0.09665482721175067, 0.1795028429478407, 3.837928483262658, 17.234216518700123, 29.489873684942722, 41.79125189781189, 59.94191274046898, 55.660807862877846, 64.89460498094559, 77.91683301329613, 92.6049068570137, 110.11283218860626, 105.7973961532116, 108.48502993583679, 110.00249370932579, 107.11927682161331, 102.1124678850174, 116.23603641986847, 125.85351794958115, 150.6552278995514, 140.7069817185402, 143.02759319543839, 130.6506845355034, 124.32833299040794, 96.78570091724396, 90.24768054485321, 81.56745672225952, 74.42068621516228, 73.43684300780296, 61.93057022988796, 41.60245142877102, 21.815170906484127, 10.690719690173864, 2.9891252797096968, 2.9071197425946593, 1.058894523885101, 0.3280428989091888, 0.23768060083966702, 0.3319741738960147, 0.13983675657073036, 0.06784263576264493, 0.05581709374382626, 0.0505234174488578, 0.06512710999231786, 0.019970394314441364, 0.049328500317642465, 0.13919962279032916, 0.09056638868059963, 0.029275315719132777, 0.06506954901851714, 0.05886824095796328, 0.01674532479228219, 0.050513854876044206, 0.027428063767729327, 0.027387920999899507, 0.0838651588128414, 0.00966853851423366, 0.06947870773728937, 0.04034741876239423, 0.005634841581922956, 0.09779128537047654, 0.033540770527906716, 0.0496985388599569, 0.014401187345356448, 0.03429663680435624, 0.05331761087290943, 0.01684036793449195, 0.057700174729689024, 0.02113898932293523, 0.02689469522010768, 0.010852713985514129, 0.06695538337226026, 0.05527122557396069, 0.03446789109148085, 0.05500566658156458, 0.07463605521479622, 0.027964332257397473, 0.07611412394908257, 0.019119687131023966, 0.006539761261592503, 0.008926004920795094, 0.006478484910985571, 0.0772423813759815, 0.011843813244922785, 0.029353853497013915, 0.026060762429551687, 0.07072244334267452, 0.03980538749601692, 0.0787384768773336, 0.03661714705231134, 0.08214369532652199, 0.03933139632863458, 0.045431850230670534, 0.01476812742112088, 0.050555923517094925, 0.022206028843356762, 0.03004343856446212, 0.0190431475857622, 0.012810872485715663, 0.01105761539292871, 0.04474405744986143, 0.03373283092514612, 0.04559000561130233, 0.06372314470354468, 0.03845395513053518, 0.05475781894347165, 0.03360784212418366, 0.06959140286198817, 0.04339042090578005, 0.05163399320736062, 0.02442609125864692, 0.07501763786422089, 0.06610909011214972, 0.25795681751333177, 0.133198676048778, 0.22016306582372636, 0.10058443978778087, 0.1545934725436382, 0.11192382546141744, 0.13049391884123906, 0.07758860068861395, 0.23347450856817886, 0.19678701704833657, 0.21267887757858261, 0.12044483111822046, 0.161446048587095, 0.14165243570460007, 0.11383499673684128, 0.12237779927090742, 0.13695070752874017, 0.18202647159341723, 0.16173407610040158, 0.15238564257742837, 0.14966872899094597, 0.16381747758714482, 0.11676498092128895, 0.15425787336425856, 0.12517254188423976, 0.2202534445677884, 0.1081730482110288, 0.1572030270472169, 0.11172107071615756, 0.11251392934354953, 0.16582348791416734, 0.1549422522657551, 0.1194379519438371, 0.0706698621797841, 0.11707854573614895, 0.10607747550238855, 0.24813401803839952, 0.1199762019678019, 0.17505889234598726, 0.12613485509064049, 0.08381732739508152, 0.2115898797637783, 0.15137335314648226, 0.07773161996738054, 0.1994751946767792, 0.10326840943889692, 0.24019544245675206, 0.09002273582154885, 0.11663488985504955, 0.12799396470654756, 0.1827441729255952, 0.1478664975729771, 0.2320194835192524, 0.14278965827543288, 0.20218256424413994, 0.15037378412671387, 0.15513323654886335, 0.15856945450650528, 0.12887257849797606, 0.16197454679058865, 0.10321480411221273, 0.2613543992629275, 0.22903210163349286, 0.10411262468551286, 1.3441473548300564, 9.908648505806923, 32.1284843981266, 48.63284558057785, 65.32978042960167, 84.69674840569496, 80.2125558257103, 89.02169913053513, 104.5842656493187, 123.2903502881527, 140.99084168672562, 130.93009114265442, 136.385959982872, 135.35756796598434, 136.64078950881958, 130.09737342596054, 145.25222182273865, 153.5911327600479, 174.08922404050827, 161.84780091047287, 167.89365649223328, 154.2488470673561, 150.15558511018753, 122.22405910491943, 114.2520260810852, 107.12746918201447, 94.54019621014595, 97.0753213763237, 81.78843006491661, 60.08636198937893, 31.62439964711666, 17.19701461493969, 5.22074363194406, 4.274369264021516, 2.5503262504935265, 0.7512976450379938, 0.24758378975093365, 0.5127440113574266, 0.3602153866086155, 0.28755651670508087, 0.29950824100524187, 0.19972118694568053, 0.14684252673760056, 0.15956963208736852, 0.22185872483532876, 0.21453561232192442, 0.2395077535766177, 0.07553635456133634, 0.2017927437555045, 0.15614696574630216, 0.10751511945272796, 0.12881834234576672, 0.08597881023888476, 0.1550269906874746, 0.14220334676792845, 0.11422711046179757, 0.14310475933598354, 0.14194672694429755, 0.09877598175080493, 0.1604737906018272, 0.15927865082630888, 0.0901833588432055, 0.11878446865011938, 0.10922188841504976, 0.1525499243871309, 0.10177065152674913, 0.16498806711751968, 0.08517920548911206, 0.10683603206416592, 0.08261517432401888, 0.25471312750596553, 0.10910229131695814, 0.1187711842067074, 0.21572612109594047, 0.178226645803079, 0.06677704528556205, 0.1560569877619855, 0.08480551929096691, 0.08169523032847792, 0.11069902204326354, 0.09658372946432792, 0.13005455257371068, 0.1286992128007114, 0.20793146279174834, 0.11449780140537769, 0.16809931345051154, 0.1247982174390927, 0.1128286296443548, 0.07461926783435047, 0.16650437872158363, 0.1081037538824603, 0.1800537688541226, 0.13407123391516507, 0.14088039431953803, 0.13501978770364076, 0.08155131305102259, 0.13584033586084843, 0.21000484528485686, 0.18231996131362393, 0.24306834064191207, 0.1569478024612181, 0.2082873968174681, 0.12000141272437759, 0.1441199134569615, 0.13866834895452484, 0.07906920014647767, 0.1339944958453998, 0.130836182506755, 0.20653701183618978, 0.150996238226071], [0.07617273135110736, 0.035801619524136186, 0.03507158369757235, 0.023169880150817335, 0.05155645361810457, 0.01779115373210516, 0.045721165370196104, 0.05159230306162499, 0.0368373459787108, 0.052305870631244034, 0.03988963238953147, 0.02259445966046769, 0.030139561531541403, 0.02584574369393522, 0.019507323850120883, 0.02104437106027035, 0.06279347115196288, 0.056738139828667045, 0.04253522929502651, 0.025112976763921324, 0.04681440084823407, 0.06324456335278228, 0.06774262394174002, 0.04382525265100412, 0.11629376909695566, 0.05846640509844292, 0.08888736861990765, 0.07046520753647201, 0.028845480483141728, 0.031130723873502575, 0.047867675384623, 0.025031166114786174, 0.013517651259462582, 0.030562984611606225, 0.02857049064914463, 0.026830992974282708, 0.02129061565938173, 0.03371026221429929, 0.00860443326018867, 0.02449653035000665, 0.014894010510033695, 0.02690392382646678, 0.04327657174144406, 0.08244899261626415, 0.05176331244001631, 0.059373958938522264, 0.042766790502355434, 0.013865991259081056, 0.02584867146651959, 0.015871614741627127, 0.03298261981399264, 0.014681885222671553, 0.05851681919011753, 0.03168648858263623, 0.04126130312215537, 0.06578638203791343, 0.05854035640368238, 0.017990552114497405, 0.08447680724202655, 0.11434205429395661, 0.029575772350654006, 0.3085961064789444, 2.7337200846523046, 7.914363518357277, 18.524794466793537, 38.077445179224014, 62.65836037695408, 84.00314882397652, 100.19921734929085, 99.32114526629448, 104.04613092541695, 98.80933552980423, 116.970354616642, 102.38637238740921, 100.81385716795921, 95.3927032649517, 102.53498241305351, 90.5389729142189, 86.16681352257729, 91.30831763148308, 97.3668721318245, 105.55862456560135, 92.57482007145882, 93.93212243914604, 97.02365174889565, 106.91170156002045, 106.98797106742859, 105.07302582263947, 104.91328999400139, 108.09142425656319, 106.93449273705482, 107.36470565199852, 108.14676448702812, 115.80681145191193, 101.24050587415695, 103.10063526034355, 103.24129611253738, 117.44981288909912, 93.80568042397499, 81.93879559636116, 92.2076989710331, 72.0488990843296, 46.6438765078783, 14.616469535976648, 4.4808397348970175, 0.8478117536287755, 0.028914179238199722, 0.3955135925207287, 0.19631058792583644, 0.054580620053457096, 0.05698947556084022, 0.05308188250637613, 0.023370718299702276, 0.06326883158180863, 0.04770300765812863, 0.036323260283097625, 0.09917301591485739, 0.024122667891788296, 0.028896647854708135, 0.052374530423549004, 0.0644885512883775, 0.027614643404376693, 0.05957485089311376, 0.014512021534756059, 0.023145437517086975, 0.02269282762426883, 0.020911018254992086, 0.011863674044434447, 0.03219920130504761, 0.014277149421104696, 0.09492048746324144, 0.01315738587436499, 0.0704841768310871, 0.03626162120781373, 0.0233869138173759, 0.04451033288205508, 0.015477989818464266, 0.0367418018868193, 0.026169321936322376, 0.0764897619956173, 0.060391421138774604, 0.06160862867545802, 0.04844117000175174, 0.026791994969244115, 0.02389780456724111, 0.03808542314800434, 0.025394545737071894, 0.031317503890022635, 0.010682944921427406, 0.06415192794520408, 0.04987468390027061, 0.05062672069470864, 0.06782217475119978, 0.014601153470721329, 0.015101178250915837, 0.012764733164658537, 0.05030425752920564, 0.03739092506293673, 0.03552017857145984, 0.04824625233595725, 0.007695690592299798, 0.03391234531591181, 0.028238947306817863, 0.04035908532387111, 0.053677237083320506, 0.04898729421256576, 0.03787065303185955, 0.07261702019604854, 0.01566396367707057, 0.09280627200496383, 0.029739037418039516, 0.023807349753042217, 0.07604060680023395, 0.040043505578069016, 0.01785237906005932, 0.014239533666113857, 0.06640994193730876, 0.02963359122077236, 0.18917719804449007, 0.020797410288651008, 0.023588987642142456, 0.05407518779975362, 0.038991566907498054, 0.027751378547691274, 0.0674779963446781, 0.055760267496225424, 0.032026510962168686, 0.01745397563354345, 0.040082327323034406, 0.021660051206708886, 0.010614535603963304, 0.030269259259512182, 0.038066405613790266, 0.005326553437043913, 0.025483124773018062, 0.03239351783122402, 0.05889600841328502, 0.03835339412034955, 0.019905319095414598, 0.043579939447226934, 0.058431294091860764, 0.0023791153307684, 0.030519468782586046, 0.021832029087818228, 0.03253813643823378, 0.009850820188148646, 0.03652136176242493, 0.012465255240385886, 0.03548797307303175, 0.02009038104006322, 0.0689892316586338, 0.0177564416298992, 0.10950872849207371, 0.031810052460059524, 0.03218521182134282, 0.005085159236841719, 0.023160753589763772, 0.024038012961682398, 0.048915521110757254, 0.08782687669736333, 0.00883739619894186, 0.04914423989248462, 0.04624318091373425, 0.02038008580711903, 0.03296953203971498, 0.015333896280935733, 0.06365969849866815, 0.05189153700484894, 0.05387944635003805, 0.021258723718347028, 0.05328636274498422, 0.05799527862109244, 0.06981532365898602, 0.041162055713357404, 0.09323656922788359, 0.06588415999431163, 0.0835592306975741, 0.1438598649110645, 2.1633801888674498, 7.1090789046138525, 19.16497841477394, 39.47191335260868, 66.49177327752113, 93.29908400774002, 108.80956292152405, 113.58897686004639, 118.47176045179367, 113.61855447292328, 130.3485095500946, 124.59089130163193, 114.79716002941132, 110.19420102238655, 120.86088985204697, 106.1254021525383, 107.4213758111, 111.42335146665573, 115.66390872001648, 124.13879156112671, 117.36923441290855, 115.12436807155609, 114.11188960075378, 122.16191723942757, 124.94188606739044, 121.83785542845726, 120.9453821182251, 128.18423688411713, 125.01843675971031, 131.24292075634003, 129.82939660549164, 134.23904478549957, 118.31628039479256, 123.37572410702705, 121.1778536438942, 136.58554047346115, 117.40125149488449, 99.37078580260277, 108.63393634557724, 80.98196893930435, 51.34099826216698, 18.48480351269245, 5.882885176688433, 0.7218595559243113, 0.019103686427115463, 0.2847107365960255, 0.23350051342276856, 0.08893643200281076, 0.062103511299937963, 0.045059703988954425, 0.08055630081798881, 0.0666228641057387, 0.007866321939218324, 0.05576958887104411, 0.024774991579761263, 0.01653550109040225, 0.02730528842221247, 0.024229743103205692, 0.003869847887472133, 0.07383044649031945, 0.014031402988621267, 0.024198474566219375, 0.02981324661959661, 0.07278168050106615, 0.029442616214510053, 0.08726157539058477, 0.026752290068543516, 0.016528326377738267, 0.017554416044731624, 0.01939600540936226, 0.020257646283425856, 0.031140865321503952, 0.04190671555988956, 0.01303763478063047, 0.05901171294681262, 0.03113584840320982, 0.017221618472831324, 0.04528114601271227, 0.047195868464768864, 0.04276556595868897, 0.03784855558478739, 0.02192940257373266, 0.06946757552213967, 0.019245160183345433, 0.09826145076658577, 0.014109124404058093, 0.02736746369919274, 0.03266124760557432, 0.03743306049727835, 0.06935510304174386, 0.01295591040616273, 0.016782673374109436, 0.017446105157432612, 0.060336004971759394, 0.040631557421875186, 0.055216443943209015, 0.04561707544780802, 0.016153077958733775, 0.11128106620162725, 0.09521907573798671, 0.015308190140785882, 0.04241104572429322, 0.039316571928793564, 0.03527490247506648, 0.06643233995418996, 0.031601631417288445, 0.02498015273886267, 0.009436750024178764, 0.021072055023978464, 0.041861262725433335, 0.021601629341603257, 0.015276104313670658, 0.08552117229555734, 0.013890175068809185, 0.16750517970649526, 0.11827339607407339, 0.18508852837840095, 0.08053384342929348, 0.12381558422930539, 0.13098677911330014, 0.20207440364174545, 0.11154767533298582, 0.1634674658998847, 0.18220463156467304, 0.1002385544416029, 0.08240366965765134, 0.1086814861628227, 0.19621455401647836, 0.11702853240421973, 0.14228891639504582, 0.12067127521731891, 0.10073523677419871, 0.10704233427532017, 0.10563213494606316, 0.09052156296093017, 0.14367523341206834, 0.0951838014589157, 0.09382564894622192, 0.2189714735141024, 0.20083216717466712, 0.1604431844316423, 0.1166443967667874, 0.10615090359351598, 0.10513737477594987, 0.15125824604183435, 0.06534956133691594, 0.1484826731029898, 0.0828621833352372, 0.13810951175400987, 0.12796747003449127, 0.17600569466594607, 0.13592139323009178, 0.21176703041419387, 0.09228574446751736, 0.12127513109589927, 0.09508745584753342, 0.10345697432057932, 0.17322446656180546, 0.14290573017206043, 0.20947750483173877, 0.157462214701809, 0.1958354946691543, 0.12004906602669507, 0.08392565869144164, 0.10586812306428328, 0.15616874035913497, 0.17386306979460642, 0.1367653041961603, 0.23166994680650532, 0.1540916768135503, 0.21890347794396803, 0.19632636598544195, 0.21559617103775963, 0.21003904344979674, 0.19083445833530277, 0.568033360177651, 4.850220764055848, 14.963926691561937, 31.79621122777462, 56.23326234519482, 88.28329995274544, 115.89410796761513, 128.8312205672264, 130.5513882637024, 134.31677341461182, 127.11786210536957, 145.18267035484314, 132.50496983528137, 128.03849190473557, 119.83204945921898, 127.97342419624329, 117.80895441770554, 115.55472537875175, 120.6260472536087, 124.93643715977669, 133.37636947631836, 120.70116922259331, 123.01116406917572, 124.23253253102303, 135.98483830690384, 134.75130289793015, 135.5616170167923, 137.44171053171158, 142.81121760606766, 140.34127414226532, 141.91052913665771, 140.5664348602295, 149.0220147371292, 135.9469923377037, 139.28620755672455, 136.259046792984, 157.18701660633087, 134.83254253864288, 116.94855138659477, 131.14426285028458, 103.76312971115112, 67.1071882545948, 27.530900202691555, 8.907250240445137, 1.7581014172174037, 0.31273562810383737, 0.45672709064092487, 0.43736983090639114, 0.20771919371327385, 0.19946269690990448, 0.1956987613812089, 0.19832768593914807, 0.13193853897973895, 0.2609056670917198, 0.18928856472484767, 0.14301080344012007, 0.07497299025999382, 0.2072852005949244, 0.12966496957233176, 0.18745491077424958, 0.1568535200203769, 0.15074062772328034, 0.09267863002605736, 0.1582503755344078, 0.13881413644412532, 0.1082188609871082, 0.1657296804478392, 0.086130007985048, 0.14533915818901733, 0.19870264863129705, 0.10604106573737226, 0.155753226717934, 0.10116244666278362, 0.13333729439182207, 0.1063321805850137, 0.14869353210087866, 0.16155054297996685, 0.17098456097301096, 0.1785470309550874, 0.14385569404112175, 0.23783597687724978, 0.09746536379680037, 0.1058228817419149, 0.1746719959191978, 0.08207992257666774, 0.2033885393757373, 0.08817584195639938, 0.14867463702103123, 0.1234853285131976, 0.2455219253897667, 0.140904039144516, 0.1166912485496141, 0.11771760910050943, 0.09090170584386215, 0.09774000296602026, 0.13651395362103358, 0.1795538136502728, 0.25193906854838133, 0.15016383054899052, 0.179506583372131, 0.1337640144629404, 0.09403199568623677, 0.08887315649189986, 0.200613530469127, 0.12430382092134096, 0.15026804292574525, 0.12802559504052624, 0.09057102710357867, 0.15646289801225066, 0.13323199847945943, 0.1339685355196707, 0.19358332880074158, 0.12227326034917496, 0.19791316677583382, 0.14152947667753324], [0.06135520750831347, 0.04037028433231171, 0.008594585888204165, 0.0636307621607557, 0.07099416587152518, 0.023814895539544523, 0.024470119169563986, 0.0531550137384329, 0.05527316257939674, 0.024985416421259288, 0.0738568595261313, 0.014469703346549068, 0.0020868007550234324, 0.05118755798321217, 0.03803373627306428, 0.03371379483724013, 0.0365014944691211, 0.024063091987045482, 0.04181592863460537, 0.02807768789352849, 0.022517658508149907, 0.022309567721094936, 0.018706501978158485, 0.041311598470201716, 0.04920098450384103, 0.005103266248625005, 0.07624056364875287, 0.054282707133097574, 0.016454297146992758, 0.030631004301540088, 0.014418951577681582, 0.014075843719183467, 0.05802956584375352, 0.04090533569979016, 0.019220259273424745, 0.06970294765778817, 0.026490920499782078, 0.02080983940686565, 0.039073251391528174, 0.036585906345862895, 0.024968486177385785, 0.07194077523308806, 0.06214477100002114, 0.004742777291539824, 0.025019653548952192, 0.04633596421626862, 0.043656840789481066, 0.0458961860567797, 0.036220391193637624, 0.017321461455139797, 0.017674245063972194, 0.013206224757595919, 0.015327938690461451, 0.055326634319499135, 0.02740500152867753, 0.0179553854468395, 0.1618384220637381, 0.05057719346950762, 0.13665337348356843, 0.07357718117418699, 8.199926745146513, 35.59013284742832, 62.78720386326313, 77.7461613714695, 96.4126369357109, 99.59366664290428, 87.07338407635689, 97.58564919233322, 95.95443472266197, 104.84680876135826, 95.40039405226707, 83.92792046070099, 70.35545915365219, 62.28190317749977, 66.9899645447731, 41.4311908185482, 50.73793262243271, 53.41867357492447, 68.77134695649147, 53.183428198099136, 49.725526347756386, 66.01416170597076, 58.90318527817726, 59.631735384464264, 76.36308878660202, 64.69073832035065, 69.1193474829197, 70.70629432797432, 81.09015673398972, 61.00234843790531, 80.441774725914, 68.07467713952065, 56.69040821492672, 92.12011367082596, 86.27953827381134, 102.77494713664055, 92.7147589623928, 100.96533223986626, 108.84603336453438, 109.13489386439323, 107.23665252327919, 110.4673607647419, 109.63152721524239, 102.66440346837044, 91.21419668197632, 73.52435231208801, 50.471266731619835, 23.572223223745823, 6.209430629387498, 1.2371561396867037, 0.08244785713031888, 0.11695475550368428, 0.008421808342973236, 0.007485762525902828, 0.06050899959518574, 0.009499773204879602, 0.055847046824055724, 0.04784070573805366, 0.0488277139083948, 0.0777764902159106, 0.022351226325554308, 0.01642281153181102, 0.05594932590611279, 0.00968118471064372, 0.054305075464071706, 0.0713912297214847, 0.011306233009236166, 0.021523705690924544, 0.102463409275515, 0.05871852008567657, 0.04114858202228788, 0.03091596117883455, 0.0821359473047778, 0.06481140779214911, 0.027059605999966152, 0.0387177403899841, 0.04886457638349384, 0.013989801900606835, 0.058454534446354955, 0.062207757073338144, 0.009008541946968762, 0.031339319320977665, 0.013849398692400428, 0.02634574157127645, 0.05518709571333602, 0.051178733847336844, 0.04104875202756375, 0.0403924188867677, 0.013960213400423527, 0.06150916975457221, 0.0425547292252304, 0.02922225401562173, 0.0160204580242862, 0.09045802027685568, 0.032087192666949704, 0.025160602235700935, 0.018663225491764024, 0.03940016002161428, 0.02161132921173703, 0.021032851072959602, 0.08678502752445638, 0.016189825400942937, 0.04939475926221348, 0.07972351464559324, 0.05735502410971094, 0.05230922884948086, 0.054154007593751885, 0.020887022765236907, 0.08036277838982642, 0.052626849501393735, 0.008981946157291532, 0.0018826570340024773, 0.037489382084459066, 0.021616351696138736, 0.0422399918170413, 0.038746583959436975, 0.07713507424341515, 0.019930238559027202, 0.02303182027389994, 0.09846160799497738, 0.017371228022966534, 0.017073983035515994, 0.013105797333992086, 0.03655875116237439, 0.037688162628910504, 0.005156951820026734, 0.08795002126134932, 0.05301454002619721, 0.03858070653222967, 0.02703310576180229, 0.05968127115920652, 0.02794694373733364, 0.033003611461026594, 0.017404431710019708, 0.0033619635314607876, 0.06050052055798005, 0.02618974212964531, 0.01960993504326325, 0.004207607180433115, 0.037077664528624155, 0.06548722230945714, 0.019969193890574388, 0.02375646996370051, 0.011182858379470417, 0.004383979503472801, 0.023977166129043326, 0.028413264808477834, 0.07434473998728208, 0.017054191812349018, 0.05235266675299499, 0.009232198353856802, 0.06826445023762062, 0.043424110699561425, 0.025102497638727073, 0.07675085696973838, 0.061306626521400176, 0.014725436303706374, 0.022839886041765567, 0.04580182569043245, 0.05394047315348871, 0.03197809695848264, 0.06553543222253211, 0.01881121344922576, 0.05344654789951164, 0.03938968089642003, 0.02139076477760682, 0.040575039165560156, 0.041057090056710877, 0.05649664868542459, 0.04882474531768821, 0.07187640134361573, 0.06676887423964217, 0.07543206054833718, 0.029540555588027928, 0.04240593232680112, 0.04706726540462114, 8.346404135227203, 41.006396412849426, 68.1230865418911, 88.27179417014122, 104.63620126247406, 111.57354980707169, 100.32016485929489, 113.44745725393295, 117.264314442873, 120.08698537945747, 116.60178199410439, 101.978190690279, 97.24180564284325, 88.09004232287407, 95.42984247207642, 79.13512364029884, 87.04112380743027, 95.17804518342018, 103.32902580499649, 85.72574079036713, 87.90968880057335, 106.1226586997509, 86.72048181295395, 93.98862540721893, 117.96395570039749, 114.13606390357018, 118.974549472332, 109.10677537322044, 112.48113110661507, 87.72663742303848, 119.10625040531158, 107.08546623587608, 86.90219566226006, 116.07413470745087, 109.27054658532143, 124.21086609363556, 122.29884669184685, 134.61195677518845, 125.82419112324715, 127.80410528182983, 124.90665435791016, 131.89399302005768, 129.6342694759369, 117.83065125346184, 110.34566089510918, 86.28035143017769, 60.901129469275475, 26.874578520655632, 8.033838607370853, 1.0217256308533251, 0.05619588220724836, 0.12810320884454995, 0.03712636425916571, 0.009252229847334092, 0.1050231434055604, 0.01644600364670623, 0.09271860209992155, 0.08036973973503336, 0.02939689249615185, 0.021979842640575953, 0.052295844216132537, 0.03423421847401187, 0.029024224895692896, 0.041263536986662075, 0.04770382402057294, 0.08630716605694033, 0.018086374511767644, 0.0165894032761571, 0.033087396222981624, 0.0241720875055762, 0.05857095886312891, 0.07820717335562222, 0.019287620307295583, 0.04077441342815291, 0.07901140910689719, 0.012828330582124181, 0.017930258181877434, 0.02230025562312221, 0.0664556804986205, 0.024358917617064435, 0.05209051050769631, 0.03557676733180415, 0.021730245389335323, 0.02570289510913426, 0.052722512336913496, 0.03501117658743169, 0.07428270386299118, 0.006955048547752085, 0.032972764092846774, 0.018134788515453693, 0.018524508814152796, 0.01839530832512537, 0.011754123770515434, 0.011720782786142081, 0.010182351470575668, 0.06279642489971593, 0.05024786172725726, 0.06962088838918135, 0.007158437365433201, 0.07598955446155742, 0.06029566553479526, 0.034898351586889476, 0.06805468219681643, 0.053523081878665835, 0.06182619668834377, 0.018053922249237075, 0.037263698686729185, 0.03568345106032211, 0.08352342949365266, 0.03281058256106917, 0.061397294703056104, 0.01777703066181857, 0.015384136895590927, 0.03227448105462827, 0.040140693527064286, 0.04146343075262848, 0.13079077791189775, 0.08488134451908991, 0.10378160455729812, 0.2475863872678019, 0.16585642442805693, 0.14251074433559552, 0.13591931521659717, 0.15421542251715437, 0.1280022322316654, 0.05933002750680316, 0.2072605019202456, 0.169676911609713, 0.10013892111601308, 0.13925667910370976, 0.15862478903727606, 0.14312720188172534, 0.07992468861630186, 0.1515498655498959, 0.09485453279921785, 0.21773075102828443, 0.15892213792540133, 0.06708140004775487, 0.10773609392344952, 0.1305350783513859, 0.09954161840141751, 0.09452781712752767, 0.1609919432667084, 0.1339506497606635, 0.09677730384282768, 0.11167242293595336, 0.0875365782121662, 0.10344218331738375, 0.09257749756216072, 0.11341632896801457, 0.10256576628307812, 0.18210994836408645, 0.13498284359229729, 0.1590582774952054, 0.19632126000942662, 0.13772714242804796, 0.10218447307124734, 0.18237157026305795, 0.16210221103392541, 0.08781238255323842, 0.18250162422191352, 0.1635769326821901, 0.15157584071857855, 0.18575059832073748, 0.14867833291646093, 0.10094672659761272, 0.15892935160081834, 0.15460111666470766, 0.17451480904128402, 0.14762175211217254, 0.25049372110515833, 0.15225190756609663, 0.1955923967761919, 0.12169220324722119, 0.4439919552532956, 0.11156189488247037, 14.456983543932438, 59.327592104673386, 90.84965944290161, 108.86116415262222, 125.85276558995247, 128.22916567325592, 111.18351593613625, 121.93060845136642, 122.16770812869072, 127.52972960472107, 122.2004471719265, 106.82738408446312, 96.10299155116081, 83.43087673187256, 94.90315273404121, 65.36374300718307, 78.42451617121696, 77.6117853820324, 98.2480600476265, 79.4459317624569, 78.07773157954216, 94.76247668266296, 86.46218687295914, 84.71718370914459, 106.0345946252346, 96.41633793711662, 99.08658385276794, 103.04104685783386, 114.72383916378021, 84.46273416280746, 110.22684887051582, 95.80849215388298, 82.77668103575706, 123.87151390314102, 120.83214819431305, 135.41625201702118, 121.7773474752903, 127.18102231621742, 134.1926720738411, 138.35243046283722, 137.16766923666, 141.98467075824738, 143.07439148426056, 137.08404332399368, 128.9447584748268, 101.88146308064461, 76.59544631838799, 38.51258642971516, 11.742789186537266, 2.339619481936097, 0.1279202991281636, 0.35688352945726365, 0.1663756903144531, 0.15143187891226262, 0.1500360920908861, 0.13391303771641105, 0.23526930366642773, 0.18300707131857052, 0.13341921265237033, 0.1586951149511151, 0.13223796588135883, 0.1251596285146661, 0.19203507516067475, 0.12007895231363364, 0.18718467996222898, 0.24013185524381697, 0.06664737724349834, 0.07264815329108387, 0.16960063367150724, 0.1668165111914277, 0.08820205461233854, 0.09802385960938409, 0.1500797303742729, 0.07239624610519968, 0.11212892539333552, 0.07756393912131898, 0.11675413072225638, 0.0765849721210543, 0.13434600667096674, 0.15056392236147076, 0.19923534739064053, 0.11915840717847459, 0.1619338770979084, 0.11151468686875887, 0.1261477090884, 0.10182849451666698, 0.17231201083632186, 0.17379378288751468, 0.11099071576609276, 0.08650468123960309, 0.10363687091739848, 0.09397439018357545, 0.13212042453233153, 0.16870410443516448, 0.13914845912950113, 0.15795442188391462, 0.1291995687643066, 0.14483853505225852, 0.10107476191478781, 0.14221443445421755, 0.2632505272049457, 0.062100253271637484, 0.16758543555624783, 0.18049960664939135, 0.14770211186259985, 0.1694327301811427, 0.26406190241687, 0.11870521469973028, 0.21054382261354476, 0.09120884365984239, 0.14258387556765229, 0.06765180733054876, 0.15916214848402888, 0.07911847875220701, 0.17444320663344115, 0.0725950080959592], [0.053037142133689485, 0.06556348540470935, 0.03209307418728713, 0.016277131653623655, 0.02403192178462632, 0.08019823682843708, 0.03490940587653313, 0.04609688876371365, 0.0403535117948195, 0.038199131304281764, 0.04846045470912941, 0.00536250956429285, 0.03363011026522145, 0.04168239400314633, 0.0368478362361202, 0.06411278707673773, 0.0315618263266515, 0.04968596316757612, 0.01723950423183851, 0.07169650474679656, 0.03504680338664912, 0.007578447493870044, 0.03398845627089031, 0.07403966534184292, 0.0327567286149133, 0.043355439775041305, 0.08270149352028966, 0.08968051668489352, 0.022553257476829458, 0.045221098844194785, 0.011930453420063714, 0.036640253820223734, 0.07771541146212257, 0.11911134017282166, 0.06476499387645163, 0.041019678392331116, 0.033116258346126415, 0.07821846142178401, 0.0462233173311688, 0.030035603340365924, 0.05282340360281523, 0.04418562471983023, 0.029144211621314753, 0.0078003923226788174, 0.03080716047406895, 0.041000972560141236, 0.06497755981399678, 0.11132943196571432, 0.05215140372456517, 0.017806803771236446, 0.061458425407181494, 0.09323259873781353, 0.05855267234437633, 0.05763656154158525, 0.01872018718131585, 0.03342895855894312, 0.021705045764974784, 0.12022430935758166, 2.3222952615469694, 32.10246339440346, 78.67293164134026, 84.83336627483368, 82.81304508447647, 90.48782005906105, 71.3407614827156, 69.15548354387283, 73.84509310126305, 60.45952096581459, 41.83631747961044, 39.796092957258224, 30.293498262763023, 21.16602323949337, 25.724632926285267, 19.684226252138615, 23.824282698333263, 11.554557736963034, 14.350118078291416, 12.899845149368048, 15.936695393174887, 22.828798815608025, 24.456411078572273, 9.386514723300934, 19.652657546103, 13.838555328547955, 14.162047170102596, 18.690501675009727, 19.917951710522175, 17.06609643995762, 25.32611221075058, 37.575359120965004, 21.27486079931259, 23.923463076353073, 26.315752007067204, 30.786506608128548, 37.989335507154465, 39.39550705254078, 34.24554839730263, 39.124528393149376, 68.89645144343376, 47.10028901696205, 86.06650650501251, 68.35691079497337, 78.63358855247498, 84.2800323665142, 86.69324487447739, 107.21715196967125, 98.09066489338875, 106.42558604478836, 99.1073839366436, 64.57212388515472, 31.224750392138958, 3.882132461294532, 0.02469364662829321, 0.09571615883032791, 0.0361009944754187, 0.06875827530166134, 0.010928417686955072, 0.036515190804493614, 0.015920449914119672, 0.058480847292230465, 0.07215652498416603, 0.07131685910280794, 0.030363768055394758, 0.056660232876311056, 0.04765657889947761, 0.029740903919446282, 0.07234785807668231, 0.037984249865985475, 0.03484815271804109, 0.011572322637221077, 0.02907439964474179, 0.042884899594355375, 0.04231518993037753, 0.05497822567122057, 0.04809141806617845, 0.010075983154820278, 0.0491029245313257, 0.005793101327071781, 0.017556794628035277, 0.039487941248808056, 0.027826418954646215, 0.07592359979753383, 0.04321927423006855, 0.04624033848813269, 0.017577003309270367, 0.0176751950129983, 0.02898634753364604, 0.05356371075322386, 0.04843897695536725, 0.051736068198806606, 0.042933833101415075, 0.020163701519777533, 0.014044952749827644, 0.015864486413192935, 0.019336115947226062, 0.03953663726861123, 0.0488741018489236, 0.0174605158099439, 0.019910293340217322, 0.03533152092131786, 0.07444743096129969, 0.053850335607421584, 0.01994136706343852, 0.0824980485776905, 0.11878598263137974, 0.04267996293492615, 0.011098775830760133, 0.024406943848589435, 0.08237864443799481, 0.05095447908388451, 0.05473496079503093, 0.02878839262848487, 0.03162883484037593, 0.04028080358693842, 0.11236569276661612, 0.04298296327760909, 0.058268407519790344, 0.026691159364418127, 0.015443087540916167, 0.009477833464188734, 0.055123753409134224, 0.00959621344009065, 0.028101438474550378, 0.0066574287757248385, 0.05325500329490751, 0.05550156223762315, 0.048420011371490546, 0.027177535121154506, 0.030166661053954158, 0.056920522620202973, 0.024465675560350064, 0.07644124038051814, 0.037253371701808646, 0.0755193222721573, 0.03790559705521446, 0.022140892397146672, 0.03758074417419266, 0.05583045982348267, 0.03759667437407188, 0.05368512240238488, 0.043738065141951665, 0.03819674901023973, 0.073222271312261, 0.03578096555429511, 0.02233115679700859, 0.03527761873556301, 0.020109431970922742, 0.09526632828055881, 0.04874046702752821, 0.04873424411925953, 0.028117580186517444, 0.06964731626794674, 0.09559729645843618, 0.053629038302460685, 0.03767091140616685, 0.02388844237430021, 0.05005471408367157, 0.08302177477162331, 0.0648502072726842, 0.010234122764813947, 0.030555169796571136, 0.03749990573851392, 0.020721184300782625, 0.048588990975986235, 0.004839342764171306, 0.065176522184629, 0.06707640539389104, 0.05494191609614063, 0.050280230498174205, 0.026612664260028396, 0.07853494287701324, 0.011379771494830493, 0.04539442001259886, 0.03619163668190595, 3.1104487320408225, 39.65441755950451, 91.72613561153412, 100.27697637677193, 100.83801627159119, 101.6456401348114, 86.09748244285583, 88.95722419023514, 97.66603767871857, 82.17170029878616, 62.61562407016754, 70.40105670690536, 62.487513944506645, 56.60083182156086, 51.426721662282944, 42.26406812667847, 44.29820537567139, 22.588421814143658, 27.486590780317783, 23.065484315156937, 36.643314734101295, 40.65505966544151, 40.279700607061386, 28.443987406790257, 38.665258437395096, 34.27417226135731, 33.25880974531174, 39.3114023655653, 33.55398930609226, 35.67155107855797, 50.433785542845726, 55.67511789500713, 42.30090714991093, 43.752934634685516, 40.19347943365574, 56.16094082593918, 61.74827121198177, 70.14410689473152, 65.82788050174713, 65.35583943128586, 110.50521433353424, 85.5217981338501, 124.98980909585953, 97.73066461086273, 108.42671066522598, 110.87998822331429, 105.33053040504456, 120.3078219294548, 116.00825384259224, 124.82302844524384, 115.82267940044403, 77.94958725571632, 38.95950324833393, 6.619748761877418, 0.056519057834520936, 0.0789701531175524, 0.0376221003534738, 0.01670087942329701, 0.056674678780836985, 0.024289556495205034, 0.025507400423521176, 0.022939541631785687, 0.06303000103798695, 0.03994977603724692, 0.029693777541979216, 0.07908364234026521, 0.04045329354994465, 0.031317800749093294, 0.050220658304169774, 0.018023052616626956, 0.03042452211957425, 0.03713064274052158, 0.04661837738240138, 0.06844422809081152, 0.03484374436084181, 0.008546309181838296, 0.04042621629196219, 0.054228853186941706, 0.08894993909052573, 0.03222593717509881, 0.0516198998229811, 0.003653436465356208, 0.053499555797316134, 0.055460350777138956, 0.009505188099865336, 0.055814021252444945, 0.010033504477178212, 0.04167696890363004, 0.015352721784438472, 0.04521460134128574, 0.02046817317022942, 0.02687624357349705, 0.07765765752992593, 0.050285533143323846, 0.0812635527108796, 0.057058406237047166, 0.022789399590692483, 0.032161040071514435, 0.04290178716473747, 0.005104464353280491, 0.025666743240435608, 0.05479668892803602, 0.037863272373215295, 0.022432025798480026, 0.03651620754681062, 0.08593909049523063, 0.06780131298000924, 0.023893492689239793, 0.06397108139935881, 0.0514209560060408, 0.07692536557442509, 0.07048812505672686, 0.01013363875244977, 0.03110034034762066, 0.011368877694621915, 0.02440915359329665, 0.08777676688623615, 0.03221221857529599, 0.18168523209169507, 0.09425181240658276, 0.19468213780783117, 0.06864771014079452, 0.22871009859954938, 0.18469241447746754, 0.13866402965504676, 0.10606279582134448, 0.22319401177810505, 0.10766818741103634, 0.14892999519361183, 0.10942928158328868, 0.1136183638300281, 0.1111391453014221, 0.1251384921488352, 0.22335879824822769, 0.15689974097767845, 0.145054173481185, 0.08712350623682141, 0.18216185417259112, 0.09456052357563749, 0.08606332601630129, 0.22737844818038866, 0.12129169583204202, 0.07750206626951694, 0.10129100890480913, 0.21064405707875267, 0.20481692132307217, 0.12222779638250358, 0.10576218890491873, 0.09519828818156384, 0.16743880201829597, 0.19478394562611356, 0.1766556824441068, 0.1660830614855513, 0.18086688069161028, 0.17419014911865816, 0.1404438036843203, 0.10250149629428051, 0.10503837969736196, 0.15339466655859724, 0.13268536218674853, 0.18227075692266226, 0.09474180056713521, 0.13292473449837416, 0.12024218027363531, 0.13351471221540123, 0.19262417714344338, 0.2474177416297607, 0.1489191598375328, 0.1873760056332685, 0.2639204787556082, 0.1500183844473213, 0.15455830958671868, 0.18734155513811857, 0.13338455435587093, 0.16088603879325092, 0.38801077636890113, 4.815993150696158, 52.45065651834011, 110.48721849918365, 113.63004505634308, 109.3461625277996, 112.68858477473259, 91.99508517980576, 92.74564370512962, 99.24469336867332, 81.2198057770729, 56.93967863917351, 58.90285089612007, 46.141475066542625, 38.499397337436676, 41.68007746338844, 29.42304667085409, 36.643827706575394, 22.451273873448372, 27.445053309202194, 19.84577838331461, 29.724644087255, 36.47765502333641, 37.21358813345432, 20.311646685004234, 37.830162048339844, 23.535357601940632, 22.633798979222775, 28.92405364662409, 29.628005772829056, 29.304650723934174, 43.216821402311325, 56.22881278395653, 31.2277028337121, 33.47868114709854, 39.48455147445202, 50.22062458097935, 57.42424763739109, 55.863181203603745, 50.61376288533211, 57.35341563820839, 96.72548934817314, 67.33006909489632, 112.8153383731842, 94.78762373328209, 106.54443606734276, 111.66546687483788, 110.78958347439766, 133.84394198656082, 129.47448045015335, 139.08685505390167, 132.36407339572906, 95.47081187367439, 51.02238915860653, 9.84563173726201, 0.15507319680182263, 0.23925623972900212, 0.18042677227640525, 0.13948045147117227, 0.1637526584090665, 0.1830279256682843, 0.08072538432315923, 0.3856445720884949, 0.16864915582118556, 0.14835686422884464, 0.1143078190216329, 0.1685548882232979, 0.13965423277113587, 0.14250161591917276, 0.15394753689179197, 0.14679970481665805, 0.14963113178964704, 0.13141940667992458, 0.17558611405547708, 0.15014738455647603, 0.15019105252576992, 0.10036763618700206, 0.1811840894515626, 0.10578334753517993, 0.16064714145613834, 0.17272204742766917, 0.13147330144420266, 0.13872447016183287, 0.2137833714368753, 0.16848379047587514, 0.15108798252185807, 0.11282220264547504, 0.08773326218943112, 0.1451395353069529, 0.08432309361523949, 0.100403326068772, 0.12131581563153304, 0.21737034927355126, 0.16989241645205766, 0.11519109350047074, 0.13001419458305463, 0.15811809513252228, 0.10112840434885584, 0.0838812708389014, 0.23197396018076688, 0.12747563392622396, 0.08057162616751157, 0.11113769069197588, 0.1419329081545584, 0.12733432900859043, 0.12226368664414622, 0.18043036427116022, 0.19182691758032888, 0.13402186625171453, 0.12889577803434804, 0.15613906929502264, 0.18772071838611737, 0.17283868335653096, 0.10425220782053657, 0.09674824133981019, 0.08247446312452666, 0.12284076583455317, 0.2742928534280509, 0.11049735825508833], [0.04365791319287382, 0.028746908428729512, 0.06888071482535452, 0.05380256727221422, 0.026921887510980014, 0.06101453574956395, 0.039265987143153325, 0.016028232021199074, 0.01286436834561755, 0.04073235591931734, 0.04159033429459669, 0.04508284786425065, 0.04311402284656651, 0.011455874100647634, 0.0240482156368671, 0.053560367377940565, 0.03850386456178967, 0.03666859272925649, 0.027646039961837232, 0.03620721065090038, 0.022720409542671405, 0.031249864550773054, 0.06070604722481221, 0.04196400936052669, 0.026901046148850583, 0.03337895635922905, 0.016829129963298328, 0.06982797727687284, 0.047483806920354255, 0.04440392745891586, 0.017244712253159378, 0.023929824528750032, 0.06338508901535533, 0.11132500134408474, 0.026272519426129293, 0.03332013002363965, 0.09229011571733281, 0.029321122929104604, 0.022632324034930207, 0.09098055903450586, 0.05934369415626861, 0.01717611183266854, 0.07031467772321776, 0.03893244742357638, 0.021366984510677867, 0.024953120009740815, 0.03657078508695122, 0.02784918062388897, 0.02208829639130272, 0.03790022761677392, 0.10282570350682363, 0.054590119543718174, 0.12847401550970972, 0.018347354452998843, 0.022377563291229308, 0.0667667888046708, 0.35501215956173837, 8.500749953091145, 41.722543984651566, 51.389916837215424, 66.343132853508, 80.39361611008644, 67.14295953512192, 51.76095932722092, 53.38127978146076, 33.30625779926777, 25.91177098453045, 27.356823943555355, 57.11450345814228, 36.1199726164341, 42.545640617609024, 30.043749064207077, 59.11129631102085, 75.16824290156364, 87.2667708992958, 114.76780280470848, 108.57733458280563, 125.28642117977142, 101.9247579574585, 115.52480578422546, 135.50968140363693, 108.01679626107216, 75.6494414806366, 104.90649595856667, 105.08747264742851, 115.94900742173195, 133.59204590320587, 96.06069222092628, 71.3481330871582, 77.74237677454948, 90.92961475253105, 98.0105347931385, 80.65197184681892, 68.15115943551064, 79.6556805074215, 72.97379985451698, 79.71681162714958, 74.95805338025093, 38.853971511125565, 38.95449511706829, 26.893157623708248, 41.53528243303299, 32.74982325732708, 31.93801961839199, 51.46539978682995, 60.06946809589863, 66.12757042050362, 83.19019004702568, 89.74047616124153, 99.64532867074013, 102.14921191334724, 75.94015628099442, 29.17850699275732, 1.2690640962682664, 0.15809431672096252, 0.007652793528905022, 0.030968833634688053, 0.046527026424882933, 0.0426750387850916, 0.015230820317810867, 0.0675637811946217, 0.03866693667077925, 0.06939151280676015, 0.05568319174926728, 0.0059358307044021785, 0.08161012825439684, 0.02617845035274513, 0.051249104290036485, 0.045668276216019876, 0.03281497607531492, 0.17837985476944596, 0.04472355933103245, 0.009622753568692133, 0.06232568062841892, 0.026741491819848306, 0.102513207384618, 0.04266291951353196, 0.024458742045680992, 0.03459037143329624, 0.024646592610224616, 0.024231516836152878, 0.037646127384505235, 0.05511214621947147, 0.05204765890084673, 0.04168456478510052, 0.01975203962501837, 0.019799934125330765, 0.053191330734989606, 0.04031421507534105, 0.052548066814779304, 0.10927402428933419, 0.004954028700012714, 0.05908670696953777, 0.07756866660201922, 0.03537418699124828, 0.03405939816730097, 0.05820342877996154, 0.0350016140146181, 0.01981754528969759, 0.03360475107911043, 0.04161608681897633, 0.08191604894818738, 0.043794260564027354, 0.006931006209924817, 0.07116689332178794, 0.0672984634002205, 0.048167187633225694, 0.022271523375820834, 0.0495558980765054, 0.014341552996484097, 0.05670120684953872, 0.05039542666054331, 0.030381171418412123, 0.01749253391608363, 0.026937450347759295, 0.03158021303534042, 0.009510142863291549, 0.015059820216265507, 0.035614702210295945, 0.031926992669468746, 0.02600959505798528, 0.05570650260779075, 0.015208697823254624, 0.021631202071148437, 0.035034613611060195, 0.042233331041643396, 0.01582612665515626, 0.040156000322895125, 0.04373810596007388, 0.015719181319582276, 0.01944500570971286, 0.05168395087821409, 0.0062819748745823745, 0.03880503179971129, 0.04104252911929507, 0.07062047967338003, 0.09523110595182516, 0.03458204824710265, 0.04016451275674626, 0.07926872654934414, 0.0917613874480594, 0.016802171448944137, 0.03075370728765847, 0.02350898226723075, 0.016912163300730754, 0.040724463178776205, 0.042077086691278964, 0.05238450117758475, 0.035282179233036004, 0.0840695017541293, 0.02437333569105249, 0.02414415492239641, 0.02799935420625843, 0.07266729327966459, 0.03095416323048994, 0.06260128458961844, 0.04801866532943677, 0.03605548969062511, 0.056532219823566265, 0.0640927194035612, 0.07340757074416615, 0.06750558197381906, 0.05491912103025243, 0.06789117964217439, 0.015403508805320598, 0.047413930005859584, 0.036961336591048166, 0.07643532546353526, 0.0533680991793517, 0.08750885157496668, 0.045635877759195864, 0.05042360600782558, 0.3642999002477154, 9.295167624950409, 52.07883507013321, 65.9563060104847, 78.94012570381165, 85.99380120635033, 78.82533386349678, 76.8988524377346, 74.99903798103333, 49.81071777641773, 52.84148074686527, 51.64335563778877, 66.71165227890015, 38.95048253238201, 33.05838569998741, 21.138507016003132, 40.66972307860851, 35.32215602695942, 54.57133412361145, 57.23135098814964, 54.03806313872337, 52.248955741524696, 51.19645021855831, 61.7988882958889, 80.46879887580872, 52.923016771674156, 37.85255044698715, 52.714810743927956, 47.482248321175575, 60.579294338822365, 66.71373456716537, 55.262634828686714, 53.80510903894901, 62.10791431367397, 55.42911909520626, 52.4775742739439, 52.52623066306114, 52.58524909615517, 64.66219425201416, 57.23662510514259, 53.7907800078392, 50.747010335326195, 48.88438068330288, 38.12783807516098, 41.42521373927593, 59.58465211093426, 53.06264787912369, 53.17926362156868, 75.08506536483765, 99.04611602425575, 82.17565208673477, 105.5331963300705, 102.99145191907883, 116.59143894910812, 117.33305275440216, 95.54358556866646, 41.17087058722973, 2.9866658616811037, 0.027448157416074537, 0.07816662982804701, 0.0070398008847405436, 0.041888046835083514, 0.05927479316596873, 0.0165222110808827, 0.05151133103936445, 0.04022396620712243, 0.015963743098836858, 0.04607171140378341, 0.021392185990407597, 0.05414473816927057, 0.02683477050595684, 0.013137376645318, 0.04489152219321113, 0.10238983275485225, 0.08880911656888202, 0.04022181768959854, 0.06313367164693773, 0.01477983294535079, 0.020701994217233732, 0.04273239566828124, 0.11057181051000953, 0.053864221190451644, 0.030892878530721646, 0.012705648932751501, 0.04521224873315077, 0.07076957714161836, 0.00864742680278141, 0.03347407000546809, 0.0636812430457212, 0.06765015976270661, 0.012405376910464838, 0.07489642288419418, 0.04998951269953977, 0.05441643843369093, 0.009022312497108942, 0.067991391842952, 0.04626087742508389, 0.04162559001997579, 0.014664338996226434, 0.005222911586315604, 0.04635638069885317, 0.024540558260923717, 0.045744461385766044, 0.02899269475165056, 0.030241595704865176, 0.04170647298451513, 0.045969317288836464, 0.03442315442953259, 0.10923762194579467, 0.04274225138942711, 0.042889675314654596, 0.06460066753788851, 0.09786767463083379, 0.026015615731012076, 0.01987351250136271, 0.007202966226032004, 0.021771111751149874, 0.09613049987819977, 0.064521903404966, 0.061394930962705985, 0.13676347851287574, 0.1442314582527615, 0.16019177448470145, 0.17219776462297887, 0.1317755930358544, 0.18999422842171043, 0.08779387339018285, 0.15106594073586166, 0.0979132424981799, 0.18810244946507737, 0.08165364037267864, 0.16655724932206795, 0.1406125829089433, 0.13681346958037466, 0.08385144392377697, 0.12753812276059762, 0.08760049197007902, 0.18383811344392598, 0.12005622775177471, 0.13158336194464937, 0.16282350436085835, 0.1586080016568303, 0.09825888293562457, 0.15642332669813186, 0.2178493165411055, 0.16364154405891895, 0.14850942010525614, 0.1815829789848067, 0.12002876828773879, 0.10621597510180436, 0.1227043813560158, 0.13573529227869585, 0.11215871520107612, 0.25604685593862087, 0.20135057216975838, 0.10694873461034149, 0.15445599710801616, 0.13072717585600913, 0.1434450934175402, 0.1557434006826952, 0.19431663007708266, 0.12552460189908743, 0.12790132983354852, 0.13123845623340458, 0.1147476454207208, 0.14921848283847794, 0.2505531522911042, 0.18078373046591878, 0.1459412180702202, 0.16492532595293596, 0.22043365286663175, 0.24485166213707998, 0.2518206514650956, 0.16426957910880446, 0.08689647584105842, 0.1284857266000472, 0.5164619337301701, 13.845598250627518, 66.71256422996521, 79.86716955900192, 89.32059869170189, 98.76383677124977, 91.89337983727455, 77.02783271670341, 77.63326942920685, 53.311059549450874, 38.41736353933811, 41.448643282055855, 78.54892149567604, 55.06723411381245, 58.70124511420727, 46.251460164785385, 87.80552119016647, 106.8092742562294, 121.65260776877403, 158.19303542375565, 150.74300318956375, 180.53860276937485, 136.72120839357376, 154.1155046224594, 179.3743908405304, 155.11825561523438, 104.44496512413025, 139.79384511709213, 148.41464012861252, 154.83910739421844, 181.90377831459045, 130.73625594377518, 100.3549025952816, 111.0312657058239, 127.51196175813675, 134.72069174051285, 113.16791385412216, 97.61622235178947, 110.67838624119759, 100.36657556891441, 109.80280682444572, 101.96370586752892, 54.42511796951294, 53.61229598522186, 40.332582369446754, 58.67575988173485, 51.34457387030125, 50.03417618572712, 72.22556680440903, 85.37229895591736, 90.12240886688232, 111.80982872843742, 111.28335937857628, 127.15145990252495, 137.04713970422745, 112.95764833688736, 48.984706699848175, 4.07654570415616, 0.1852686921483837, 0.22011864086380228, 0.08641974985948764, 0.3156080364715308, 0.14049173158127815, 0.2577632653992623, 0.13394684996455908, 0.15531662123976275, 0.10187193242018111, 0.13237726700026542, 0.10535037858062424, 0.18565536593087018, 0.09714462983538397, 0.08625488175312057, 0.11338624972268008, 0.21350684721255675, 0.25769062398467213, 0.16159418126335368, 0.07956056870170869, 0.13560314546339214, 0.0994203588925302, 0.13452573999529704, 0.18550947454059497, 0.13567759771831334, 0.1654928017524071, 0.12711885385215282, 0.13875299831852317, 0.17995834350585938, 0.10748008266091347, 0.14689998381072655, 0.15710593928815797, 0.12011378872557543, 0.08545268690795638, 0.12652834178879857, 0.1462570612784475, 0.1990136827225797, 0.20650472841225564, 0.1385848128120415, 0.2235452554305084, 0.14647151227109134, 0.11118237540358678, 0.09387276790221222, 0.16066308278823271, 0.1372095092665404, 0.1269363597384654, 0.23287696094485, 0.08039382984861732, 0.1011494145495817, 0.09198074403684586, 0.13339025405002758, 0.2390339071280323, 0.16016149485949427, 0.14428579830564559, 0.13733813830185682, 0.17759823967935517, 0.10395364923169836, 0.11134611544548534, 0.16519923781743273, 0.1122261764248833, 0.21959930076263845, 0.09949012819561176, 0.12824656208977103], [0.04857318694121204, 0.028532657815958373, 0.0660417031031102, 0.06140572550066281, 0.03024635287147248, 0.02546489762607962, 0.04805147196748294, 0.02731635198870208, 0.0835390442807693, 0.0203109083668096, 0.026638114359229803, 0.0557388045854168, 0.05534320276638027, 0.018269772190251388, 0.022018480703991372, 0.03885151250869967, 0.023289000419026706, 0.006885014390718425, 0.009981976236304035, 0.03399408917175606, 0.04214063679683022, 0.03185500063409563, 0.047126440549618565, 0.017512803824502043, 0.043728253949666396, 0.027669387927744538, 0.018959160588565283, 0.11200010339962319, 0.018040871582343243, 0.03605429483286571, 0.03170706833770964, 0.06936805351870134, 0.04988718166714534, 0.03207650202966761, 0.012244326226209523, 0.01901886636915151, 0.02255447645438835, 0.010573877043498214, 0.029185103958297987, 0.03772934440348763, 0.10179759148741141, 0.10687054193112999, 0.0258672604104504, 0.02139608968718676, 0.0334354263759451, 0.043066595899290405, 0.014892155140842078, 0.04616214209818281, 0.05127533178892918, 0.01158928163931705, 0.045770751967211254, 0.03062206698814407, 0.017726735313772224, 0.06792531843530014, 0.16105750459246337, 6.894800327718258, 37.57419638335705, 76.14864349365234, 70.82742422819138, 39.57874462008476, 52.56780803203583, 38.00850547850132, 36.586143001914024, 23.355813436210155, 13.169694319367409, 26.726316176354885, 45.42124651372433, 40.15825152397156, 44.49559338390827, 88.32221746444702, 113.12416300177574, 130.68111330270767, 87.25314483046532, 88.3348859846592, 61.039506644010544, 43.805086836218834, 49.11872170865536, 40.180753916502, 66.22729226946831, 57.07821540534496, 42.728129625320435, 66.15624368190765, 71.13711521029472, 88.22450190782547, 79.06063243746758, 87.39430725574493, 54.761251732707024, 73.98781344294548, 79.37745943665504, 73.30880507826805, 84.0420663356781, 87.70868718624115, 58.0613062530756, 51.444576904177666, 46.12182252109051, 54.574810937047005, 63.52132447063923, 60.80093264579773, 107.65314057469368, 112.91639015078545, 118.04480776190758, 87.78463751077652, 76.37547612190247, 61.11299090087414, 30.290593318641186, 22.26688116788864, 39.889381751418114, 51.31037190556526, 66.88604012131691, 81.12985700368881, 69.4749704003334, 92.4802203476429, 97.58247256278992, 64.26910534501076, 11.663306951522827, 0.40993188915308565, 0.18570894899312407, 0.04113438473723363, 0.06467855593655258, 0.015487855744140688, 0.018699514657782856, 0.0583227735478431, 0.03001254481205251, 0.06682781560812145, 0.08045917595154606, 0.03233601251849905, 0.004790951024915557, 0.028909397951792926, 0.08389339011046104, 0.029130383554729633, 0.03131661702354904, 0.016285334240819793, 0.06167354804347269, 0.03628561113146134, 0.03724533424247056, 0.07160618537454866, 0.10876723390538245, 0.05282050922687631, 0.02591929423942929, 0.12347694224445149, 0.08070489362580702, 0.04964741972798947, 0.03370560523762833, 0.024868290674930904, 0.009705836073408136, 0.024643080396344885, 0.004698104639828671, 0.03321822943689767, 0.009627139661461115, 0.06337242797599174, 0.041112524777418, 0.01515401081633172, 0.05759882704296615, 0.011804897803813219, 0.03302405762951821, 0.0580426276428625, 0.044968460642849095, 0.0920226753805764, 0.03186584341165144, 0.03535925497999415, 0.02080626039969502, 0.023534821993962396, 0.04474520777876023, 0.04737201721582096, 0.04607867274899036, 0.03308031242340803, 0.04997975345759187, 0.01465754741730052, 0.017717259943310637, 0.039958800552994944, 0.04389326677483041, 0.040551398051320575, 0.07286045205546543, 0.07029646541923285, 0.014458570203714771, 0.021058700076537207, 0.04206860394333489, 0.07635591566213407, 0.010930357475444907, 0.037993797595845535, 0.04067419751663692, 0.07024216989520937, 0.04404204140882939, 0.006857998359919293, 0.04394075680465903, 0.015438375830854056, 0.04097376913705375, 0.03516819648211822, 0.028813070894102566, 0.02130319506250089, 0.010464806382515235, 0.03216090648493264, 0.013560077059082687, 0.029474380135070533, 0.019792449566011783, 0.03968574957980309, 0.060853103786939755, 0.04948275942297187, 0.06600761626032181, 0.03817100761807524, 0.03643839336291421, 0.033472429859102704, 0.03598314884584397, 0.050420221814420074, 0.029706605564570054, 0.016531343208043836, 0.07485907059162855, 0.062408296507783234, 0.08689839058206417, 0.040753418070380576, 0.023422084195772186, 0.05626587415463291, 0.051574925673776306, 0.030907094369467814, 0.015274136694642948, 0.0008433683285602456, 0.011896513151441468, 0.09992878942284733, 0.0128252720060118, 0.02857111034245463, 0.06986899577896111, 0.049923494952963665, 0.03584128731745295, 0.02816615189658478, 0.1470696832984686, 0.09196749670081772, 0.04917939913866576, 0.0397213355608983, 0.04764446333865635, 0.027375547542760614, 0.13060584955383092, 9.53544108197093, 46.33955843746662, 91.09583303332329, 80.89648112654686, 51.063426956534386, 71.5469080209732, 68.37009608745575, 63.10991294682026, 40.220883563160896, 39.944444596767426, 46.66074380278587, 32.35960699617863, 30.82702573388815, 45.636242777109146, 65.91567859053612, 82.13378593325615, 76.86992079019547, 74.34359595179558, 69.44918498396873, 58.965144753456116, 45.35444989800453, 44.30077403783798, 39.64982360601425, 56.11184366047382, 50.328660383820534, 44.37282957136631, 56.38378746807575, 54.49500761926174, 61.55657149851322, 59.6801333874464, 59.61122788488865, 52.888723611831665, 57.1016563475132, 55.59581995010376, 54.06916446983814, 65.58696582913399, 63.57071042060852, 42.4689607322216, 39.16509121656418, 38.01142752170563, 40.15539787709713, 43.20996657013893, 48.004169315099716, 62.03039847314358, 74.02827367186546, 74.34019893407822, 60.90043790638447, 42.711201533675194, 38.60625520348549, 39.6231946349144, 32.01976843178272, 69.73268017172813, 81.40292555093765, 84.30773288011551, 101.90069764852524, 83.75493094325066, 104.89373624324799, 111.2097117304802, 84.54008281230927, 17.621575333178043, 0.7024370762519538, 0.22735089965863153, 0.07852734328480437, 0.060814612297690473, 0.042956602192134596, 0.03325990473967977, 0.10138368830666877, 0.0659547456598375, 0.038663337254547514, 0.02496948065527249, 0.02064223648631014, 0.002079551131828339, 0.006310647286227322, 0.045732089783996344, 0.039359423535643145, 0.015091239038156345, 0.063377726910403, 0.01856752554886043, 0.018380118417553604, 0.03369892590853851, 0.022235779688344337, 0.09876777359750122, 0.017778663386707194, 0.05302465178829152, 0.035366676456760615, 0.11183691254700534, 0.07234625503770076, 0.0020140614697083947, 0.08262301140348427, 0.04218728448904585, 0.039851708643254824, 0.04118639444641303, 0.05939898044744041, 0.027324884831614327, 0.02695438244700199, 0.07413805185933597, 0.02197983892983757, 0.10475099785253406, 0.035778011806542054, 0.02598731021862477, 0.057379863792448305, 0.05822571547469124, 0.03701082299812697, 0.07080531897372566, 0.022852116635476705, 0.027018743348889984, 0.01605343906703638, 0.07133779508876614, 0.027005744632333517, 0.018381226072961, 0.011079296309617348, 0.030870669761497993, 0.057820521396934055, 0.021113368529768195, 0.05281136225676164, 0.022469812247436494, 0.02580245978606399, 0.028825444351241458, 0.018620687442307826, 0.029949241470603738, 0.0403001736412989, 0.09583111750544049, 0.13939403579570353, 0.12108568305848166, 0.11968107952270657, 0.13453417079290375, 0.11659148163744248, 0.1379389365320094, 0.06395549629814923, 0.1786519112647511, 0.14389444899279624, 0.11395846042432822, 0.09465034570894204, 0.34962529549375176, 0.08770330168772489, 0.10213340588961728, 0.15437544439919293, 0.10279772453941405, 0.05780896986834705, 0.11409606202505529, 0.11885253843502142, 0.22636034031165764, 0.17597819067304954, 0.12779465352650732, 0.12346755407634191, 0.16014927910873666, 0.07059368072077632, 0.1481626441818662, 0.12019005182082765, 0.1461893625673838, 0.07188783783931285, 0.11854286247398704, 0.12489359825849533, 0.2405172525322996, 0.22351543593686074, 0.11027340035070665, 0.10643065616022795, 0.07884122722316533, 0.11277175886789337, 0.13556709192926064, 0.1220014932914637, 0.24444928450975567, 0.2465099169057794, 0.11184880917426199, 0.10797353665111586, 0.21636138466419652, 0.19698717427672818, 0.1134943138458766, 0.15259051986504346, 0.44987905654124916, 0.1726399065228179, 0.13945808314019814, 0.19781714770942926, 0.08669788454426453, 0.16058822977356613, 0.3486815211363137, 13.433723151683807, 59.040422514081, 105.81531599164009, 96.74058213829994, 61.282503604888916, 79.0714618563652, 61.99322126805782, 57.22686342895031, 38.2361626625061, 23.191664144396782, 42.34329767525196, 65.25282695889473, 57.42688089609146, 65.58569669723511, 118.53360593318939, 157.6199957728386, 181.7312827706337, 133.77542406320572, 132.22583681344986, 90.67632034420967, 67.41268426179886, 76.39027252793312, 59.354886040091515, 94.48841258883476, 81.1975845694542, 67.43414551019669, 103.2835802435875, 100.06392180919647, 130.5464181303978, 118.73978286981583, 134.23124760389328, 86.17011934518814, 110.20139023661613, 117.78627723455429, 104.59094569087029, 122.59170457720757, 120.10423645377159, 80.35026043653488, 71.41880929470062, 63.88721063733101, 78.75335052609444, 87.37922966480255, 88.15998136997223, 151.16509974002838, 167.00523376464844, 162.3989537358284, 121.74586236476898, 108.24729949235916, 85.48000037670135, 44.490125477313995, 34.37743932008743, 57.159097865223885, 72.46398121118546, 90.0077386200428, 106.4485216140747, 95.04219487309456, 114.24442648887634, 126.28311529755592, 98.9809039235115, 22.63717319816351, 0.7618567440658808, 0.3971067164093256, 0.19193322281353176, 0.19739869516342878, 0.12012053484795615, 0.13466955337207764, 0.23214475804707035, 0.25100571394432336, 0.18541596393333748, 0.21741199860116467, 0.23952378396643326, 0.09812788644921966, 0.2056347977486439, 0.1850927883060649, 0.11196885156095959, 0.13382516743149608, 0.1612723563448526, 0.09264952299417928, 0.08245057339081541, 0.1411123896832578, 0.12673785007791594, 0.23245589603902772, 0.17212561302585527, 0.1529410807415843, 0.2620992483571172, 0.21170684223761782, 0.10479205346200615, 0.17660307901678607, 0.14315231615910307, 0.1477152924053371, 0.10051828474388458, 0.06651918607531115, 0.19113910995656624, 0.0882732859463431, 0.13129419152392074, 0.19235023559303954, 0.1301431204774417, 0.17146021826192737, 0.12170862697530538, 0.08560199959902093, 0.1555219735018909, 0.09546547618811019, 0.28481439978349954, 0.13816444552503526, 0.12584519485244527, 0.10562794923316687, 0.1716012114775367, 0.25903557369019836, 0.13912102935137227, 0.32613664807286114, 0.10763463491457514, 0.08892497324268334, 0.18777118442812935, 0.14159879327053204, 0.16070799756562337, 0.24150390818249434, 0.1270563353318721, 0.13487876480212435, 0.11130220256745815, 0.1325004338286817, 0.15407668543048203], [0.03956861641199794, 0.009131877613981487, 0.06612788129132241, 0.08003801456652582, 0.056232128699775785, 0.018545934617577586, 0.017386768595315516, 0.023970362490217667, 0.0565413519507274, 0.03454990954196546, 0.044000284469802864, 0.02397260192083195, 0.0649643421638757, 0.14334506675368175, 0.07736588959232904, 0.0044483404053607956, 0.029904560469731223, 0.07826137982192449, 0.09642035307479091, 0.043134109073434956, 0.02965909141494194, 0.020925623721268494, 0.07451732642948627, 0.043772137141786516, 0.021689495915779844, 0.02326849858945934, 0.07371070838416927, 0.026334284666518215, 0.07483434965251945, 0.015431324500241317, 0.04317972889111843, 0.00751173166463559, 0.038473967142635956, 0.008568838929932099, 0.03362564624694642, 0.029093663943058345, 0.029726148168265354, 0.0736931269057095, 0.09408261015778407, 0.057783866723184474, 0.054285404839902185, 0.020783370709978044, 0.02802347586111864, 0.06398567944415845, 0.014629802226409083, 0.011803573997895, 0.06172938352392521, 0.048276012457790785, 0.08697498022229411, 0.05485745226906147, 0.06055487916455604, 0.026080418210767675, 0.09926732804160565, 5.038126381114125, 30.46505145728588, 66.42978340387344, 89.46019560098648, 67.73646488785744, 72.24214151501656, 39.464678540825844, 23.57053991407156, 15.951754935085773, 15.887346491217613, 43.3894157409668, 61.75091207027435, 58.518197536468506, 89.69057723879814, 121.37367233633995, 95.48234045505524, 60.38675867021084, 33.26506420969963, 19.43874802440405, 8.036884143948555, 2.0030059944838285, 0.842664692318067, 0.026633965753717348, 0.21712085406761616, 0.10292000821209513, 0.5350608075968921, 0.5327602091711015, 0.0848631990083959, 0.07457191139110364, 0.20101740723475814, 0.11142164381453767, 0.185297442949377, 0.3448697319254279, 0.09389690996613353, 0.06319852793239988, 0.8973169222008437, 1.2117473781108856, 0.5326490057632327, 0.17807600466767326, 0.44296031061094254, 0.49664139572996646, 0.31505335529800504, 0.4813020344590768, 0.8924832253251225, 0.3920426272088662, 1.800222632009536, 6.402589464560151, 26.272656619548798, 55.94481602311134, 61.83975890278816, 73.14835488796234, 104.73545953631401, 94.32350903749466, 42.57224299013615, 33.720994144678116, 32.70955681800842, 40.010010078549385, 64.06049653887749, 77.36166000366211, 77.36099123954773, 89.66210916638374, 82.85947859287262, 47.93774887919426, 12.17643141746521, 1.382827260531485, 0.30069903179537505, 0.14621398702729493, 0.0336900757974945, 0.04466120037250221, 0.016180513302970212, 0.03239225618017372, 0.07716800333582796, 0.053391684632515535, 0.03427062452828977, 0.028224675806995947, 0.01775523749529384, 0.09511544223641977, 0.017830984797910787, 0.028434839041437954, 0.02699853095691651, 0.06353858741931617, 0.13950384396594018, 0.06076797944842838, 0.0763384677702561, 0.05667680874466896, 0.05188972245377954, 0.07762230161461048, 0.03952823615691159, 0.021826279298693407, 0.058443758462090045, 0.019131171866320074, 0.031148542839218862, 0.01896079887956148, 0.02856962975783972, 0.03773147807805799, 0.03570532957382966, 0.03218026911781635, 0.049007510315277614, 0.04052283649798483, 0.04098986632016022, 0.06616008307901211, 0.045304965242394246, 0.02780750161036849, 0.016991463635349646, 0.004884238987870049, 0.07446138333762065, 0.02950772483018227, 0.05129222678078804, 0.06289280761848204, 0.09287173685152084, 0.061402723513310775, 0.08248768819612451, 0.024776683676464017, 0.06990913112531416, 0.009185384606098523, 0.041029786443687044, 0.047836249141255394, 0.01878943327028537, 0.02687226195121184, 0.03298591494967695, 0.015978120354702696, 0.07692651590332389, 0.04275534287444316, 0.02976633360958658, 0.02909497754444601, 0.032441174844279885, 0.029895394945924636, 0.05840095880557783, 0.05580149751040153, 0.06982074133702554, 0.06147532782051712, 0.06055930607544724, 0.02883547447709134, 0.05954932843451388, 0.041797159719862975, 0.0541720640467247, 0.06260310285142623, 0.07476319995475933, 0.03592344306525774, 0.019796754022536334, 0.04274745755537879, 0.06607238348806277, 0.017964504586416297, 0.04332324540882837, 0.030703914744663052, 0.02720050273637753, 0.036039730184711516, 0.005531388978852192, 0.03262696409365162, 0.03656838052847888, 0.024802250663924497, 0.07451998331816867, 0.0346675102628069, 0.04855230661632959, 0.03130390774458647, 0.028027427797496784, 0.0019344078032190737, 0.008416160599153955, 0.03212342060578521, 0.0267340128266369, 0.03552026391844265, 0.045016648291493766, 0.027020431734854355, 0.016420110114268027, 0.004389078521853662, 0.06267723598284647, 0.029689127986785024, 0.03408000760828145, 0.07988398181623779, 0.08581281406804919, 0.0839529994118493, 0.08154783237841912, 0.07037950432277285, 0.06694341253023595, 0.051699825417017564, 0.07346939906710759, 7.550044292584062, 42.232252433896065, 82.89613902568817, 102.7648700773716, 84.70574632287025, 92.29586184024811, 55.05083039402962, 41.03039212524891, 26.737740263342857, 23.266408033668995, 33.34953747689724, 24.811707213521004, 40.653801932930946, 68.52528735995293, 71.96110099554062, 62.88185678422451, 55.87143816053867, 40.78241743147373, 27.166813239455223, 12.265779823064804, 3.3651858754456043, 0.9476612519938499, 0.09094961889786646, 0.049060666642617434, 0.05469496645673644, 0.17335691023617983, 0.17057235731044784, 0.1400433259550482, 0.3162106010131538, 0.11866811473737471, 0.18689595483010635, 0.08669839662616141, 0.31804415106307715, 0.23998109536478296, 0.23816758330212906, 0.6267270888201892, 1.717593097127974, 0.4965727619128302, 0.1828860121895559, 0.5013847583904862, 0.13734791980823502, 0.07847318876883946, 0.42981859704013914, 0.5273294693324715, 0.13891817070543766, 2.4517479026690125, 7.945034997537732, 24.54894371330738, 44.38155010342598, 62.916256338357925, 71.20807260274887, 71.69217422604561, 49.638058841228485, 38.54077711701393, 37.52428986132145, 52.468367367982864, 69.88258972764015, 88.4952449798584, 95.29870390892029, 86.63060903549194, 104.00094375014305, 101.6457237303257, 65.2288806438446, 19.464446045458317, 2.7062872191891074, 0.23209295613924041, 0.2291292932932265, 0.013575556404248346, 0.03104541956417961, 0.022976120235398412, 0.04699254968727473, 0.04084938147570938, 0.0261510576820001, 0.020764755790878553, 0.03249744819186162, 0.033272558357566595, 0.059578550499281846, 0.0637099493178539, 0.013939170730736805, 0.023930984134494793, 0.05099664049339481, 0.04004332375188824, 0.062428438395727426, 0.058581029807101004, 0.03870082313369494, 0.0794920907355845, 0.06894391612149775, 0.012417056459526066, 0.018619409092934802, 0.05266866210149601, 0.04843331807933282, 0.06187278871948365, 0.0048110474563145544, 0.01859450447227573, 0.03836134623270482, 0.03573438465537038, 0.06566396477865055, 0.02425184426101623, 0.012103250446671154, 0.038692852467647754, 0.04671470815083012, 0.02359852980589494, 0.04502772484556772, 0.007537175270044827, 0.05266230560664553, 0.024228531547123566, 0.06630248637520708, 0.07032937966869213, 0.07621015043696389, 0.019976248004240915, 0.015946983548928984, 0.03141191249596886, 0.010428167479403783, 0.04630309449566994, 0.032427081459900364, 0.045568802452180535, 0.029464676554198377, 0.039660650145378895, 0.03875910028000362, 0.04700480625615455, 0.04805057767953258, 0.06339687432046048, 0.025093595577345695, 0.14125013229204342, 0.147104341594968, 0.17480291076935828, 0.1636959583265707, 0.10305202886229381, 0.08197275645215996, 0.15787073731189594, 0.1680140258395113, 0.2031274072942324, 0.1362247089855373, 0.13887592765968293, 0.19033082207897678, 0.11708869089488871, 0.2121361598256044, 0.16350458812667057, 0.11023190687410533, 0.11456598993390799, 0.24847277876688167, 0.2070132183143869, 0.31916829699184746, 0.12523278943262994, 0.13304776774020866, 0.158723464992363, 0.10660536514478736, 0.12628202297491953, 0.11070276246755384, 0.13565953384386376, 0.15565829118713737, 0.17944626160897315, 0.13362711790250614, 0.14491628244286403, 0.14006317098392174, 0.13539302861317992, 0.13414161920081824, 0.11969322848017327, 0.1757189881755039, 0.11682986689265817, 0.17307379574049264, 0.24881358782295138, 0.10879324618144892, 0.10224986370303668, 0.15808530704816803, 0.1088347025506664, 0.16648217366309837, 0.231347335211467, 0.12508067884482443, 0.23399562982376665, 0.1406536385184154, 0.20282349782064557, 0.19324934750329703, 0.1657284187967889, 0.13974395842524245, 0.34324083651881665, 10.279173273593187, 52.90714122354984, 100.47566771507263, 119.00069206953049, 90.33183842897415, 97.04329669475555, 59.51242558658123, 40.01742348074913, 28.72960288077593, 29.65855423361063, 65.37927657365799, 82.54145085811615, 79.95115265250206, 129.99141991138458, 161.6284766793251, 130.75241267681122, 89.27139893174171, 54.96595434844494, 34.72762852907181, 14.451595433056355, 3.6594076501205564, 1.5820270590484142, 0.36990937893278897, 0.4503215249860659, 0.16817242983961478, 0.6913483806420118, 1.0273787775076926, 0.31786627310793847, 0.47138495254330337, 0.35672652069479227, 0.8331319538410753, 0.2853904844960198, 1.043908721767366, 0.3661036159610376, 0.4603736777789891, 2.14262617751956, 3.4667340014129877, 1.6813860274851322, 1.3219457399100065, 1.2613654718734324, 0.7961395138408989, 0.8972042938694358, 1.1529518268071115, 1.6091515473090112, 0.9810402640141547, 4.366735182702541, 11.194561254233122, 39.42400172352791, 81.82980224490166, 92.71525293588638, 107.76718005537987, 145.86310744285583, 134.702467918396, 60.49968481063843, 49.051275327801704, 51.05928897857666, 58.89522470533848, 86.32569059729576, 100.54538637399673, 98.5925343632698, 113.37943330407143, 115.69018810987473, 75.7501132786274, 22.604762837290764, 2.950837821699679, 0.4937608237378299, 0.38655560289043933, 0.1465076400199905, 0.18781108228722587, 0.18085430870996788, 0.09588625907781534, 0.19585761066991836, 0.19066616892814636, 0.08563299910747446, 0.1549652440007776, 0.08893056161468849, 0.21651162503985688, 0.1140858797589317, 0.17571977485204116, 0.12625842267880216, 0.11670203195535578, 0.20519025129033253, 0.1946368074277416, 0.20195807941490784, 0.2504283527377993, 0.18472875002771616, 0.2015199896413833, 0.11952948843827471, 0.11323399070533924, 0.1426957023795694, 0.1760279294103384, 0.15779342036694288, 0.08368401540792547, 0.10409629001514986, 0.11935987800825387, 0.21311258868081495, 0.14499248616630211, 0.07622422897838987, 0.1346355926943943, 0.16784005158115178, 0.13960501353722066, 0.08508815139066428, 0.1504148100502789, 0.10465217346791178, 0.12921954737976193, 0.129415622795932, 0.1519765707780607, 0.1301793521270156, 0.10731194910476916, 0.15595656033838168, 0.13326572166988626, 0.17065807536710054, 0.2004507032688707, 0.14205056824721396, 0.06321731169009581, 0.1283566077472642, 0.15855262259719893, 0.08235879198764451, 0.13801539258565754, 0.169123477244284, 0.22068445425247774, 0.13601809507235885, 0.10049418720882386], [0.03879605923430063, 0.03294838454166893, 0.020518457386060618, 0.04404501371027436, 0.03470444695267361, 0.04782015566888731, 0.015493520186282694, 0.023317988707276527, 0.03285431732365396, 0.04100446807569824, 0.07544180494733155, 0.032838914048625156, 0.06767928163753822, 0.02751569656538777, 0.030077172887104098, 0.023075000281096436, 0.03976607964432333, 0.04695427342085168, 0.02015702961216448, 0.036367740904097445, 0.0745412681135349, 0.07209218078060076, 0.03586216764233541, 0.07584048667922616, 0.07458436462911777, 0.03196018893504515, 0.026369814986537676, 0.02467762922606198, 0.07378438138402998, 0.1083713278057985, 0.0319962090725312, 0.013824620236846386, 0.013683801425941056, 0.060015363778802566, 0.060517667880048975, 0.03438487445237115, 0.09929199703037739, 0.02471665691700764, 0.019725422498595435, 0.05664880751282908, 0.05263505023322068, 0.005501452596945455, 0.005151139876033994, 0.03584912068617996, 0.13805668568238616, 0.015976246431819163, 0.016496835196448956, 0.07338986310060136, 0.14356711733853444, 0.14678267994895577, 0.11358611009200104, 0.7204648526385427, 28.261513598263264, 71.41798853874207, 76.42639338970184, 65.92606723308563, 68.62612634897232, 47.51916714012623, 31.23127844184637, 39.24496293067932, 32.921220660209656, 70.8796714246273, 76.05627045035362, 73.21217626333237, 125.24942636489868, 108.25525626540184, 37.99169898033142, 19.00258842855692, 9.740302339196205, 4.035132676362991, 0.3250978491269052, 0.17703898687614128, 0.14502341888146475, 0.22963692230405286, 0.09113861422520131, 0.09591608599293977, 0.1869765669107437, 0.07186355476733297, 0.4237596143502742, 0.21989503176882863, 0.22878590156324208, 0.21905964065808803, 0.4535325901815668, 0.21255649742670357, 0.3547814110061154, 0.2839987794868648, 0.3487447224324569, 0.26656457281205803, 0.10249625673168339, 0.06477340240962803, 0.07157691507018171, 0.26683225063607097, 0.1765141251962632, 0.21183305187150836, 0.27064219932071865, 0.5661713413428515, 0.37215796764940023, 0.29242847871501, 0.051144583921995945, 0.0881318177562207, 0.6390312442090362, 0.2229432252352126, 0.4116352665005252, 4.398576999083161, 28.44077467918396, 46.76980175077915, 104.59742814302444, 91.37052029371262, 42.40383982658386, 25.25726940482855, 20.67308709025383, 38.448905646800995, 71.42354384064674, 79.10411730408669, 66.30704239010811, 84.83102560043335, 87.55968198180199, 48.171983510255814, 10.780347380787134, 2.0009968522936106, 0.23054550401866436, 0.02097295790008502, 0.016051515049184673, 0.05148989781446289, 0.04481035721255466, 0.04470724692509975, 0.14101959153776988, 0.024588476881035604, 0.012331748439464718, 0.03218148624000605, 0.025927962524292525, 0.015158958158281166, 0.03905019286321476, 0.03254518684116192, 0.046388883056351915, 0.022290531633188948, 0.03325398240122013, 0.10530134488362819, 0.035967133298981935, 0.01066014150637784, 0.054346283213817514, 0.014027714514668332, 0.06737411793437786, 0.014412676719075534, 0.015061449230415747, 0.06722298698150553, 0.03970526064222213, 0.008205936137528624, 0.07397589259198867, 0.05194821111217607, 0.03112351205345476, 0.04159855729085393, 0.04981582045729738, 0.034745962693705224, 0.058370085462229326, 0.011032855491066584, 0.011542526335688308, 0.07310258515644819, 0.05703158873075154, 0.04152757457632106, 0.008538277288607787, 0.03714944876264781, 0.04352341376943514, 0.06277195629081689, 0.01801021531719016, 0.010557618443272077, 0.08579718443797901, 0.036142573299002834, 0.05851018810062669, 0.04187940081465058, 0.03383113209565636, 0.024210493647842668, 0.05732558682211675, 0.05349966340872925, 0.09069872845429927, 0.02897638605645625, 0.015997228802007157, 0.042280472262063995, 0.07015399532974698, 0.017472655490564648, 0.025704388681333512, 0.022198631486389786, 0.03366868339071516, 0.03564836231817026, 0.03140476190310437, 0.02809183508361457, 0.027705257780326065, 0.06098675345128868, 0.06654664553934708, 0.05060330222477205, 0.03883411285642069, 0.04561887515592389, 0.01815396190067986, 0.03267515545303468, 0.0034912004321085988, 0.03175714475219138, 0.022300468990579247, 0.021288719472067896, 0.021382864615588915, 0.041873322625178844, 0.02324685570783913, 0.013605193144030636, 0.06551364276674576, 0.012065343398717232, 0.05598129391728435, 0.04258411827322561, 0.0172410330560524, 0.04353444208391011, 0.02099019427987514, 0.09304575563874096, 0.03530171998136211, 0.028058837342541665, 0.044919734937138855, 0.012728348447126336, 0.004831732039747294, 0.043266100037726574, 0.047885056483210064, 0.024672274630574975, 0.08323468209709972, 0.024093666615954135, 0.15740392642328516, 0.08885641364031471, 0.13358533498831093, 0.0633849851146806, 0.23395972471917048, 0.1329325864207931, 0.08155518706189469, 2.1377652883529663, 42.28934057056904, 88.51962447166443, 92.05853417515755, 81.0578964650631, 90.80250397324562, 68.28968480229378, 48.380455523729324, 42.39524468779564, 25.804124660789967, 37.10677966475487, 36.63195714354515, 48.516210839152336, 86.96821331977844, 75.39770498871803, 39.63261812925339, 26.11483968794346, 14.347186535596848, 6.331749390810728, 0.7651571638416499, 0.12130674658692442, 0.2508171193767339, 0.09531166608212516, 0.08098755541141145, 0.1128597701608669, 0.110570333636133, 0.23186870879726484, 0.43934112356510013, 0.3301313618430868, 0.372952867182903, 0.6788119627162814, 0.3756729274755344, 0.1679165818495676, 0.7777591282501817, 1.099179487209767, 1.347247394733131, 0.4923934314865619, 0.28327381995040923, 0.17130565858678892, 0.09583275765180588, 0.22342324635246769, 0.12823030905565247, 0.04830854450119659, 0.12023451388813555, 0.19049246184295043, 0.07696040978771634, 0.03072412157052895, 0.0611978870438179, 0.290129097411409, 0.7043605449143797, 0.08238789159804583, 0.5615025793667883, 6.614851774647832, 33.030449599027634, 58.027799651026726, 78.57089951634407, 65.11081337928772, 39.30066794157028, 29.671431742608547, 44.50383134186268, 61.31656877696514, 95.60138806700706, 98.44729855656624, 82.84380823373795, 105.4170897603035, 106.84782698750496, 69.68956008553505, 20.115903988480568, 4.666768983006477, 0.18701503984630108, 0.11791286073275842, 0.018076722881232854, 0.06994776733336039, 0.05234587981249206, 0.0597160444885958, 0.07803763714036904, 0.02915502842370188, 0.04920132960251067, 0.016762735576776322, 0.015226161485770717, 0.023576859093736857, 0.03083915260504, 0.02052986790658906, 0.03923538839444518, 0.06933438227861188, 0.04128269923967309, 0.08835221335175447, 0.07268071130965836, 0.053923047526041046, 0.07131530059268698, 0.08100726685370319, 0.043292379486956634, 0.0007432518532368704, 0.016052249775384553, 0.012620387296919944, 0.031127295151236467, 0.02961525275168242, 0.017919485908350907, 0.021145820792298764, 0.0066144078664365225, 0.08831853469018824, 0.007052239279801142, 0.06000843954097945, 0.028448769153328612, 0.08993363357149065, 0.04518131972872652, 0.011648946601781063, 0.007308242657018127, 0.05453621364722494, 0.055381798156304285, 0.01932895051140804, 0.062271310889627784, 0.023727657935523894, 0.0278033826907631, 0.07347863138420507, 0.06309263830189593, 0.02210141199611826, 0.03379706380655989, 0.05483844215632416, 0.04186139631201513, 0.012963763256266247, 0.036332852541818283, 0.06045927199011203, 0.09093105778447352, 0.0348961548297666, 0.13125459052389488, 0.17414125642972067, 0.2165812681778334, 0.17237653315532953, 0.13986391917569563, 0.10980874169035815, 0.07198453968157992, 0.16561628028284758, 0.1523044367786497, 0.11756563209928572, 0.12002381074125879, 0.15145096695050597, 0.25315345963463187, 0.07631595843122341, 0.09824452237808146, 0.13318383309524506, 0.12346955787506886, 0.12182107719127089, 0.168972272076644, 0.0782228252501227, 0.19665672560222447, 0.09048815147252753, 0.10805610800161958, 0.1487320347223431, 0.2014605881413445, 0.17067125590983778, 0.1148567559721414, 0.16088822070742026, 0.1701740169664845, 0.2629521838389337, 0.18692408222705126, 0.13638738775625825, 0.15332974347984418, 0.2270696553750895, 0.13869340386008844, 0.062458502798108384, 0.14661442022770643, 0.10535004461416975, 0.13117365189827979, 0.11729876321624033, 0.20977283507818356, 0.17426231555873528, 0.16737683268729597, 0.12693880882579833, 0.45814512704964727, 0.17869578703539446, 0.18507657980080694, 0.31484377279412, 0.5595024616923183, 0.2796906419098377, 0.19890902505721897, 3.4213867597281933, 52.94391945004463, 102.03153982758522, 109.01634022593498, 89.91038024425507, 90.01269355416298, 66.75541833043098, 46.19207315146923, 56.73162840306759, 52.720863819122314, 102.31333270668983, 104.76423919200897, 104.70746263861656, 176.32475048303604, 149.54802811145782, 55.15594035387039, 30.804574638605118, 16.30340326577425, 8.531469404697418, 1.1316613317467272, 0.38638119818642735, 0.4341124853817746, 0.41143812239170074, 0.17839692416600883, 0.4038900352315977, 0.641316109104082, 0.6354180537164211, 1.0013596736826003, 0.9500821377150714, 0.9019938774872571, 1.197630779352039, 1.045334239024669, 0.7368702348321676, 0.7416133896913379, 0.7002130674663931, 0.8124375517945737, 0.5344818730372936, 0.28668826329521835, 0.18626680655870587, 0.23915754893096164, 0.533685281407088, 0.24408714612945914, 0.4681128531228751, 0.40270375669933856, 0.8923911990132183, 0.5099785316269845, 0.571313415421173, 0.1617057409021072, 0.24890614848118275, 0.6901432515587658, 0.2960382850142196, 0.9262192400638014, 7.855101898312569, 45.820437893271446, 73.66127416491508, 152.85947442054749, 129.8020988702774, 62.74605207145214, 39.00618754327297, 30.793099254369736, 53.41068260371685, 96.37326344847679, 102.72876441478729, 85.96253648400307, 110.18938288092613, 121.50400534272194, 79.74721759557724, 23.68108358234167, 4.353740829974413, 0.3621479688445106, 0.2480153931537643, 0.11710469902027398, 0.15990598825737834, 0.16954433434875682, 0.24129911995260045, 0.32013023912440985, 0.18944080889923498, 0.13120874064043164, 0.12644125818042085, 0.0808284389495384, 0.10619509848766029, 0.1896412333007902, 0.13217096478911117, 0.10659877487341873, 0.12146707274951041, 0.151071046711877, 0.1953783317003399, 0.24040077987592667, 0.10588823526632041, 0.15404934471007437, 0.10510414140298963, 0.17251481011044234, 0.09134678664850071, 0.07765660368022509, 0.11747678960091434, 0.12256093163159676, 0.1984538955730386, 0.2340993078541942, 0.12993086624192074, 0.1455926609924063, 0.12951521901413798, 0.12874671025201678, 0.11697739842929877, 0.17328314075712115, 0.17750731174601242, 0.13783383357804269, 0.10377212733146735, 0.0847365143999923, 0.12205699109472334, 0.08413706687861122, 0.16030103346565738, 0.11257387261139229, 0.154632821213454, 0.15359489800175652, 0.09672344618593343, 0.1529742102138698, 0.13822488603182137, 0.1179966343624983, 0.11805573158198968, 0.16600587812718004, 0.10734407667769119, 0.21701255987863988, 0.1615424090414308, 0.2599051332799718, 0.1403633548761718], [0.05455083395645488, 0.004096983111594454, 0.02555515762651339, 0.04298199106415268, 0.047460581408813596, 0.0501155924575869, 0.03590829954191577, 0.03130845710984431, 0.11042236423236318, 0.004077007279192912, 0.04211327752273064, 0.029001923358009662, 0.036233107894076966, 0.01799124787794426, 0.062409239035332575, 0.015195118376141181, 0.025246335135307163, 0.07681834787945263, 0.04041796732053626, 0.044620230110012926, 0.03794472308072727, 0.08085390945780091, 0.06914129771757871, 0.022923323849681765, 0.03295875605545007, 0.025508810504106805, 0.041231954892282374, 0.03491100149403792, 0.02238706834759796, 0.05534263873414602, 0.04924363202007953, 0.05008834079490043, 0.059911047501373105, 0.05016116403567139, 0.05333378227078356, 0.05309841755661182, 0.02249700453830883, 0.09003005339764059, 0.044430774651118554, 0.046114143697195686, 0.017956168412638362, 0.05062104326498229, 0.018504873441997916, 0.01818797638406977, 0.034860939922509715, 0.03075091681239428, 0.05626177378871944, 0.06435808914829977, 0.1231208152603358, 2.4773905891925097, 35.35887725651264, 70.12795776128769, 85.96305325627327, 78.77176433801651, 62.628265991806984, 46.38545237481594, 17.62859545648098, 27.37925983965397, 46.120773777365685, 36.084881499409676, 33.46909046173096, 39.743021205067635, 45.07518008351326, 25.272882767021656, 8.15288431942463, 1.691346955485642, 0.38306139351334423, 0.11880478865350597, 0.26153313810937107, 0.1847384127904661, 0.07571822527097538, 0.13814390287734568, 0.06088962487410754, 0.08529109909432009, 0.10088469789479859, 0.1143024607154075, 0.08611817815108225, 0.04205166442261543, 0.09271136616007425, 0.1524414520827122, 0.11957159789744765, 0.05456775121274404, 0.15513292484683916, 0.07537483354099095, 0.07539685306255706, 0.492790094576776, 0.9065003169234842, 0.13178164896089584, 0.048564674507360905, 0.03707561991177499, 0.13838217681040987, 0.17198815243318677, 0.19834398350212723, 0.09958507856936194, 0.16914445033762604, 0.2461960181244649, 0.20113563135964796, 0.16330023034242913, 0.14478461060207337, 0.04149317603150848, 0.40404048340860754, 0.21605049900244921, 0.2553455263841897, 0.11561749444808811, 0.3201664856169373, 0.05844866405823268, 9.191472139209509, 32.74609945714474, 78.36219191551208, 106.67534664273262, 54.75936323404312, 34.01757963001728, 21.905484460294247, 42.59177014231682, 43.91469955444336, 57.52674713730812, 79.40828338265419, 77.76221930980682, 77.02907904982567, 46.49189606308937, 11.580796279013157, 0.572748432168737, 0.23891734541393816, 0.0730064844537992, 0.004397895236252225, 0.08229936080169864, 0.01495048330980353, 0.06111329705163371, 0.014641304587712511, 0.026755212275020313, 0.03237906450522132, 0.03963160990679171, 0.0680123500933405, 0.04261770045559388, 0.009586913402017672, 0.015331933300331002, 0.02985961786180269, 0.06206195474078413, 0.022557374541065656, 0.00024278436455915653, 0.024659901173436083, 0.02621752628328977, 0.05176196173124481, 0.008976526623882819, 0.04561638896120712, 0.04689004425017629, 0.018305541852896567, 0.01779841008101357, 0.05789811664726585, 0.038702400197507814, 0.11732359547750093, 0.026467726529517677, 0.03442342902417295, 0.036525324831018224, 0.02629101560160052, 0.024153624726750422, 0.01384109869832173, 0.041149090393446386, 0.03598099290684331, 0.06023624548106454, 0.04437731404323131, 0.06272851838730276, 0.0391194797703065, 0.049789136537583545, 0.028465562099881936, 0.05760624851973262, 0.03230974791222252, 0.07495048092096113, 0.07160543580539525, 0.05093032588774804, 0.02484469223418273, 0.17009482980938628, 0.009378027589264093, 0.04217958099616226, 0.011089126055594534, 0.054125156602822244, 0.04859207088884432, 0.024121235546772368, 0.03914955159416422, 0.05423306858574506, 0.06676863675238565, 0.048529615451116115, 0.03969211349613033, 0.02258353153592907, 0.09042306512128562, 0.02938796631497098, 0.04698675351392012, 0.044557444416568615, 0.06539583424455486, 0.017270436947001144, 0.061426442553056404, 0.017525750590721145, 0.04326857510022819, 0.021619220096908975, 0.04024069421575405, 0.07933448083349504, 0.06418495351681486, 0.06743750476744026, 0.05345812169252895, 0.028093736837035976, 0.053118652213015594, 0.11936174822039902, 0.03759929044463206, 0.02964943978440715, 0.02161434975278098, 0.06460608521592803, 0.019290787422505673, 0.02613175442093052, 0.06853848826722242, 0.006574708531843498, 0.04413054251926951, 0.09079294410184957, 0.021965565574646462, 0.061039653737680055, 0.06233028194401413, 0.021592586272163317, 0.03370408383489121, 0.03720927699760068, 0.03652871273516212, 0.02811808299156837, 0.13781250425381586, 0.06462512130383402, 0.0438005354226334, 0.032288823058479466, 0.1717697235289961, 4.907203931361437, 51.803585439920425, 86.87260285019875, 100.04288613796234, 88.62937018275261, 85.24351626634598, 71.27633973956108, 40.74918061494827, 38.26126791536808, 39.62309964001179, 35.07202684879303, 29.050022587180138, 44.792923629283905, 55.78364007174969, 35.490980967879295, 13.99161871522665, 4.168112715706229, 0.6960712897125632, 0.26524037355557084, 0.40829269273672253, 0.36729755345731974, 0.11080298951128498, 0.11713640356902033, 0.018937714376079384, 0.03939138041459955, 0.22184978937730193, 0.20235670177498832, 0.12338673419435509, 0.403699065791443, 0.31610714562702924, 0.35894316737540066, 0.42880621855147183, 0.7575066306162626, 0.32408012717496604, 0.33454598276875913, 0.8330883155576885, 0.7792639068793505, 2.1694567753002048, 1.4296649722382426, 0.9664890042040497, 1.1092713894322515, 0.956748048774898, 0.3232417971594259, 0.600485400063917, 0.22531708847964182, 0.5740113893989474, 0.5384011846035719, 0.461266006459482, 0.15962181991199031, 0.04856928324443288, 0.1000896944606211, 0.307093791780062, 0.16247040533926338, 0.07280534016899765, 0.15814755839528516, 0.4231800860725343, 0.5287625268101692, 10.979658085852861, 35.99304802715778, 61.94687135517597, 64.35535311698914, 31.4689651876688, 35.82941360771656, 47.40287058055401, 69.84400659799576, 70.7186208665371, 73.84645342826843, 87.53472492098808, 91.6600951552391, 101.31053611636162, 65.3663344681263, 20.73734164237976, 1.8233308545313776, 0.09294817806221545, 0.16089498909423128, 0.08760288910707459, 0.11118823837023228, 0.05834191353642382, 0.05457329134515021, 0.023030625416140538, 0.012295542765059508, 0.03915066110494081, 0.03918757553037722, 0.024142859874700662, 0.027413495408836752, 0.07137145148590207, 0.025966815810534172, 0.030878701654728502, 0.022416602114390116, 0.08878512293449603, 0.03186396206729114, 0.04256821775925346, 0.03661880946310703, 0.0937926085316576, 0.040604279784020036, 0.04425273713422939, 0.016818233380035963, 0.10813038214109838, 0.021838198190380353, 0.014566125955752796, 0.021401223493739963, 0.046709687521797605, 0.08251090257545002, 0.040915462304838, 0.12664095527725294, 0.0726979439787101, 0.029745213942078408, 0.020639373651647475, 0.02762539155810373, 0.030028339569980744, 0.0017336785413135658, 0.06049395626178011, 0.01779231519321911, 0.01808810371585423, 0.03694916536915116, 0.05499251201399602, 0.08667151603731327, 0.04608988660038449, 0.06951077593839727, 0.029156605487514753, 0.04340218765719328, 0.035798817916656844, 0.12334481769357808, 0.013593891162599903, 0.02295149206474889, 0.05981314337986987, 0.053212455968605354, 0.19907706213416532, 0.06708099928800948, 0.12381229651509784, 0.10158027580473572, 0.1261231885291636, 0.12718965474050492, 0.14838723291177303, 0.16507607098901644, 0.27179730765055865, 0.12026855620206334, 0.13433279644232243, 0.14683562476420775, 0.16468703717691824, 0.08327311792527325, 0.12914772232761607, 0.22278663207544014, 0.09205410533468239, 0.13914517883677036, 0.12773134832968935, 0.2734655071981251, 0.11764974711695686, 0.16523453436093405, 0.2175833604997024, 0.17312834359472618, 0.1511085993843153, 0.1793922035722062, 0.11407180121750571, 0.17196934641106054, 0.08548221696401015, 0.16482056438690051, 0.13132521329680458, 0.1574744304525666, 0.1797476626234129, 0.13822849286952987, 0.12991535535547882, 0.2351676145917736, 0.10128067078767344, 0.1423854846507311, 0.12356410748907365, 0.19274872436653823, 0.10599288551020436, 0.16448214504634961, 0.07954165135743096, 0.13635642535518855, 0.27637897117529064, 0.22593470377614722, 0.2980203536571935, 0.30982685449998826, 0.3779253753600642, 4.462540866807103, 58.832896649837494, 104.21003893017769, 110.07566258311272, 100.6578603386879, 83.76572236418724, 68.81012007594109, 29.31478288024664, 39.056595638394356, 69.66108441352844, 56.9744885712862, 54.28293339908123, 62.17157229781151, 71.60627603530884, 40.79812578856945, 13.413717225193977, 3.3996220026165247, 1.852206455077976, 0.32893157622311264, 0.47647074214182794, 0.423289003665559, 0.24574454000685364, 0.4027855710592121, 0.28836409212090075, 0.19285774586023763, 0.2856733021326363, 0.2835099119693041, 0.16899085545446724, 0.2326038951287046, 0.1890148309757933, 0.2080103530897759, 0.17267590068513528, 0.5851861147675663, 0.32126551726832986, 0.28760045184753835, 0.27701668383087963, 0.6602984655182809, 1.6857663611881435, 0.4966310056624934, 0.4132007231237367, 0.7230886118486524, 0.5149125668685883, 0.3717146086273715, 0.47491647710558027, 0.2224526507779956, 0.4634898668155074, 0.49821685650385916, 0.33311384555418044, 0.6091407418716699, 0.33502989273983985, 0.3163077629869804, 0.6458188674878329, 0.4371392010943964, 0.5770480795763433, 0.32970287546049803, 0.6601213593967259, 0.8261974446941167, 15.62029967084527, 51.499559953808784, 110.27036413550377, 142.94001549482346, 74.29767921566963, 52.4835741519928, 37.04037442803383, 58.53170961141586, 63.237483501434326, 77.07120358943939, 99.07252460718155, 104.35241729021072, 116.89493626356125, 72.22877383232117, 19.9643225222826, 1.3893110188655555, 0.3252050746232271, 0.29669297800865024, 0.30036096868570894, 0.23496076319133863, 0.1634058082709089, 0.17546766728628427, 0.09476108898525126, 0.10843444004422054, 0.11644590937066823, 0.07235228127683513, 0.1624635627376847, 0.07997013774001971, 0.12227631799760275, 0.11352853427524678, 0.14012739644385874, 0.13615123636554927, 0.21769658254925162, 0.1183198470971547, 0.12931096513057128, 0.09597712763934396, 0.21376265067374334, 0.1543154937098734, 0.15002976899268106, 0.1046554018103052, 0.14303088595625013, 0.13584241387434304, 0.14923430542694405, 0.08001349400728941, 0.17404669197276235, 0.12486526306020096, 0.19543859409168363, 0.28205806331243366, 0.13621774764033034, 0.0839444127632305, 0.0462358447839506, 0.17456341971410438, 0.18910359183792025, 0.1194607061916031, 0.19510795245878398, 0.1329411953338422, 0.07929723244160414, 0.21937738376436755, 0.17950720677617937, 0.13498269516276196, 0.1421530736843124, 0.1760230609215796, 0.19441825977992266, 0.1290253718616441, 0.1140314358053729, 0.3479773714207113, 0.08659266284666955, 0.06818244291935116, 0.13483165326761082, 0.10834910048288293], [0.012447837034414988, 0.019021629013877828, 0.053983684701961465, 0.020913174193992745, 0.01731889547954779, 0.04601891872880515, 0.015061577250889968, 0.12355929095065221, 0.005376234194045537, 0.043636895570671186, 0.047700298819108866, 0.03853605521726422, 0.06530505474074744, 0.043407033881521784, 0.092004129110137, 0.030666733146063052, 0.04467763894353993, 0.027863196082762443, 0.024076927475107368, 0.06437834977987222, 0.03484621200186666, 0.06814863067120314, 0.0324399762757821, 0.0840239116223529, 0.034376811017864384, 0.04746092279674485, 0.0275152475660434, 0.07750581411528401, 0.06984800042118877, 0.03557054813427385, 0.05877553558093496, 0.03590847765735816, 0.0532075763476314, 0.03445679598371498, 0.05327926410245709, 0.0344661767303478, 0.07529049587901682, 0.06786150857806206, 0.050313063111389056, 0.0630554641247727, 0.06489839492132887, 0.009887458163575502, 0.028147360717412084, 0.06273777296883054, 0.0835046308930032, 0.05728044568968471, 0.10204871941823512, 0.09342146047856659, 13.383731134235859, 73.46537187695503, 83.99792030453682, 78.25287938117981, 75.02785563468933, 64.83580693602562, 34.61671628057957, 19.25180945545435, 29.899161122739315, 57.24729873239994, 48.15709210932255, 27.645445056259632, 30.882341265678406, 17.547794692218304, 4.20188007876277, 0.28116638772189617, 0.2507361659081653, 0.06205112309544347, 0.00802470553026069, 0.05178254148631822, 0.1960433999192901, 0.17664331826381385, 0.1347864416311495, 0.03320562405860983, 0.03806324406468775, 0.06774979308829643, 0.1251720223808661, 0.04724739206722006, 0.059721020588767715, 0.07201858941698447, 0.5484497454017401, 0.304662783164531, 0.2638441859744489, 0.16015935747418553, 0.41440516943112016, 0.9697085595689714, 1.1102719232439995, 2.763907089829445, 3.2518341578543186, 0.8970424463041127, 0.8713267324492335, 0.32684720994438976, 0.046370028794626705, 0.7181954837869853, 0.1320474417298101, 0.10565703400061466, 0.2783827402163297, 0.40496065746992826, 0.19980760262114927, 0.12464352417737246, 0.042225308425258845, 0.05814449854369741, 0.20558069518301636, 0.047633197536924854, 0.08277930770418607, 0.05367211255361326, 0.31263371638488024, 0.08968245369032957, 0.21528822428081185, 0.05339223753253464, 5.9722307324409485, 39.04877185821533, 96.73310413956642, 81.61971151828766, 51.14172175526619, 27.552129663527012, 25.107409246265888, 58.432401940226555, 63.055123686790466, 74.57755699753761, 71.58196493983269, 74.8431171476841, 78.50864365696907, 41.64835296571255, 8.681986927986145, 0.2072006551316008, 0.2896902506472543, 0.01811442954931408, 0.05432972960988991, 0.06449171283748001, 0.06442222555051558, 0.046747143715037964, 0.02434320078464225, 0.02941928123618709, 0.048303186194971204, 0.1051162532530725, 0.02362363851716509, 0.028756875472026877, 0.1401844379142858, 0.05849125962413382, 0.09647435173974372, 0.04778030233865138, 0.08956781413871795, 0.039806344866519794, 0.025901623703248333, 0.03416839368583169, 0.02688537941139657, 0.04226068289426621, 0.03422975445573684, 0.041225357199436985, 0.03162525768857449, 0.056776204583002254, 0.03654944463050924, 0.03487926354864612, 0.015238701926136855, 0.027105867775389925, 0.014912648621248081, 0.023756123009661678, 0.019464494507701602, 0.039556612173328176, 0.027068678755313158, 0.06224796663445886, 0.03515540556691121, 0.057943840365624055, 0.06397518547601067, 0.06527117569930851, 0.10745167324785143, 0.07109440775820985, 0.018263951897097286, 0.028203546862641815, 0.0526243558852002, 0.03856568546325434, 0.012536358553916216, 0.01722482640616363, 0.040357445177505724, 0.04787605052115396, 0.03817090742813889, 0.020355372289486695, 0.051468212259351276, 0.03973580001911614, 0.03395570158318151, 0.027930974574701395, 0.07648412909475155, 0.05564965038502123, 0.025225280405720696, 0.05693432285625022, 0.05437632164102979, 0.07481387379812077, 0.02479602404491743, 0.010159433950320818, 0.08935794961871579, 0.0463040110480506, 0.01662170710915234, 0.023779105467838235, 0.05195226323849056, 0.028168085191282444, 0.04197809161269106, 0.027581595568335615, 0.06333619632641785, 0.056448423929396085, 0.020525533764157444, 0.013294412310642656, 0.049722105759428814, 0.08306108633405529, 0.04347705180407502, 0.055718221119605005, 0.015882537300058175, 0.043419279318186454, 0.017455450652050786, 0.048083139408845454, 0.03638105503341649, 0.0033827251127149793, 0.06847559867310338, 0.052673474929179065, 0.14554783527273685, 0.09478460022364743, 0.037278719755704515, 0.0846521915809717, 0.07303481223061681, 0.04045726775075309, 0.020460985469981097, 0.05195368445129134, 0.2327623585006222, 0.03924769691366237, 0.38064145774114877, 0.0013354808288568165, 21.45493123680353, 93.66438120603561, 95.20805597305298, 91.94944962859154, 97.75792434811592, 87.07816421985626, 50.87535224854946, 36.51431165635586, 19.64139875024557, 38.772902861237526, 44.37647357583046, 34.3653217703104, 41.955574080348015, 23.933884017169476, 6.3766824547201395, 0.347644651774317, 0.2557356288889423, 0.17019733524648473, 0.028501649030658882, 0.09311660847743042, 0.10524005090701394, 0.3704234497854486, 0.5526710813865066, 0.3067699779057875, 0.21073838404845446, 0.6284934596624225, 0.7430129020940512, 1.0374665237031877, 0.9866652090568095, 2.116324701346457, 4.439810486510396, 2.99055899027735, 1.370052583515644, 1.884219499770552, 1.685636336915195, 2.1652477886527777, 7.522541843354702, 5.514209959656, 7.896360084414482, 6.827599983662367, 4.415530739352107, 2.979823616333306, 2.5874785194173455, 2.1528310049325228, 0.5793169734533876, 1.24892185209319, 0.822864311048761, 0.8591391833033413, 0.9425008913967758, 0.6228963006287813, 0.25201236305292696, 0.5700704664923251, 0.5286008573602885, 0.04529258992988616, 0.04230893733620178, 0.0941909859830048, 0.2645695611136034, 0.1013641178724356, 0.2797292632749304, 0.05654684384353459, 7.068189298734069, 41.76604405045509, 70.67967295646667, 62.856546342372894, 37.22260124981403, 29.838288389146328, 34.92740660905838, 79.32426229119301, 89.39847931265831, 86.03183716535568, 83.17405611276627, 89.8387236893177, 98.78944739699364, 60.46799451112747, 18.247743733227253, 0.20073139836313203, 0.25469344574958086, 0.04535788779321592, 0.042471886990824714, 0.07563141625723802, 0.013233994995971443, 0.0087977933435468, 0.031032606384542305, 0.06570001089130528, 0.014223344642232405, 0.02410589349892689, 0.05233027615759056, 0.02430519354675198, 0.06499172741314396, 0.010236832531518303, 0.03909846956958063, 0.04695559444371611, 0.039514391392003745, 0.031613854589522816, 0.010836748533620266, 0.013883343599445652, 0.02048180642304942, 0.05176719758310355, 0.029900640074629337, 0.031990854477044195, 0.027190199871256482, 0.0527236849302426, 0.0541156051622238, 0.02158315728593152, 0.03875541551678907, 0.052125302390777506, 0.06345658010104671, 0.024059275492618326, 0.06373520460329019, 0.028301764541538432, 0.06158886528282892, 0.09072937915334478, 0.025600363696867134, 0.07586923748021945, 0.03622224285209086, 0.012939734369865619, 0.0634422640723642, 0.03334506618557498, 0.06822358016506769, 0.030811284959781915, 0.017771110178728122, 0.012541724281618372, 0.015478543646167964, 0.035022449810639955, 0.01953057162609184, 0.053851382035645656, 0.04364027605333831, 0.048136822661035694, 0.16406807117164135, 0.10267101024510339, 0.20133001467911527, 0.12641259643714875, 0.1480049081146717, 0.13856799574568868, 0.10171575486310758, 0.1520486778463237, 0.15468508325284347, 0.14842563163256273, 0.11384649260435253, 0.17167771206004545, 0.172150949947536, 0.09504542802460492, 0.16643764480249956, 0.08455020564724691, 0.10647328512277454, 0.12958627223270014, 0.10278687434038147, 0.1350339627242647, 0.22027095925295725, 0.1703371707117185, 0.17649175686528906, 0.21242782386252657, 0.12959033920196816, 0.14111258264165372, 0.1254914130549878, 0.1345641238731332, 0.2354790345998481, 0.1352537126513198, 0.12257689522812143, 0.10926411661785096, 0.21095408184919506, 0.12843138654716313, 0.12192893351311795, 0.18932104110717773, 0.21515255968552083, 0.22961703274631873, 0.15784474730025977, 0.2224606808158569, 0.20572915440425277, 0.13181940943468362, 0.09039349795784801, 0.12481916084652767, 0.2705039520515129, 0.11713952058926225, 0.4679822945035994, 0.2368300996022299, 22.353294230997562, 107.39054426550865, 108.45707103610039, 94.50875669717789, 97.79527634382248, 86.82736247777939, 49.310641810297966, 28.663826510310173, 45.580013394355774, 80.73459461331367, 71.31885185837746, 47.0349857211113, 52.697856053709984, 28.072224855422974, 7.926730429753661, 1.033960736822337, 0.7265507010743022, 0.18748731294181198, 0.12369727104669437, 0.4422952275490388, 0.5417923245113343, 0.5892458406742662, 0.48843769531231374, 0.23470132320653647, 0.16618782305158675, 0.37128054129425436, 0.4646043648244813, 0.5418196355458349, 0.9903752943500876, 1.3892060494981706, 1.7627577111124992, 1.1998083000071347, 0.983779679518193, 1.0617556516081095, 1.261056975927204, 2.914267871528864, 5.150606520473957, 8.216377012431622, 8.442303389310837, 7.43513323366642, 4.206124451011419, 1.4432029332965612, 1.3931467942893505, 3.413104866631329, 0.375944078550674, 0.775180907221511, 0.4995550378225744, 0.7743371743708849, 0.5244880530517548, 0.3019347373628989, 0.16689422889612615, 0.2966057904995978, 0.305793549050577, 0.08171334615326487, 0.14020220492966473, 0.20958038134267554, 0.7343000883702189, 0.24869813933037221, 0.34568223520182073, 0.17235787556273863, 10.245134700089693, 60.60609050095081, 144.37229543924332, 117.34306901693344, 72.27537453174591, 40.13505756855011, 33.45250055193901, 75.5869272351265, 86.03886678814888, 94.79737401008606, 88.04606348276138, 106.95764109492302, 110.20424008369446, 65.59630572795868, 17.104062102735043, 0.24287607986479998, 0.5569120100699365, 0.09717651992104948, 0.1835272871539928, 0.11361949931597337, 0.12838961847592145, 0.12560767791001126, 0.11938042065594345, 0.14009324280777946, 0.10599713059491478, 0.22046832600608468, 0.1170605857623741, 0.12716663331957534, 0.3012084716465324, 0.08395188619033433, 0.17419256852008402, 0.17878018406918272, 0.11397851325455122, 0.17667174251982942, 0.093202615971677, 0.10900520355789922, 0.11425703385611996, 0.16361286747269332, 0.09120302522205748, 0.1452075011911802, 0.17873552162200212, 0.15133099135709926, 0.11687164238537662, 0.12645865412196144, 0.20118879881920293, 0.12436578283086419, 0.09028293279698119, 0.07638353097718209, 0.1050825671700295, 0.10493249006685801, 0.16362964001018554, 0.15302605665056035, 0.15191138052614406, 0.26907908788416535, 0.11719642847310752, 0.08308329881401733, 0.19594074605265632, 0.16595645109191537, 0.14662065426819026, 0.1269734522793442, 0.16988410439807922, 0.07691986626014113, 0.11000702870660461, 0.07466503608156927, 0.058955105632776394, 0.14295607747044414, 0.19764039781875908, 0.0993573282903526], [0.03678778535686433, 0.01756238671077881, 0.02999237138283206, 0.05356444547942374, 0.05624478973913938, 0.07158000982599333, 0.03408416734600905, 0.0314726572833024, 0.041715304541867226, 0.021729074651375413, 0.027672048527165316, 0.056487037873012014, 0.027171041328983847, 0.03333375585498288, 0.06359864200931042, 0.04974252966349013, 0.02418777465209132, 0.05918132337683346, 0.026524621425778605, 0.030364909107447602, 0.030861571030982304, 0.02948045832454227, 0.048400971572846174, 0.048002579278545454, 0.0349952834949363, 0.05407337324868422, 0.02936852575658122, 0.06452092377003282, 0.031571667204843834, 0.010138661236851476, 0.04353658689069562, 0.02134565518645104, 0.025468921921856236, 0.02086881417199038, 0.07606779166962951, 0.023895917656773236, 0.014929738426872063, 0.059836535874637775, 0.04121839956496842, 0.059252959181321785, 0.019626638932095375, 0.047951296874089167, 0.039699290064163506, 0.017639679535932373, 0.12222410048707388, 0.06382161285728216, 6.4429394993931055, 32.21708804368973, 78.98833751678467, 79.79762569069862, 73.56757119297981, 49.329249411821365, 26.19461640715599, 24.67772640287876, 40.025532245635986, 57.7790953963995, 82.15862900018692, 60.87733514606953, 34.50763173401356, 13.981217723339796, 2.9047707561403513, 0.2875583275454119, 0.12061896122759208, 0.058127841039095074, 0.008045705526456004, 0.054948806937318295, 0.0376498084369814, 0.05559977435041219, 0.1406548556406051, 0.3437622991623357, 0.0993384035245981, 0.19745407422306016, 0.1975234056590125, 0.275711216381751, 1.248576189391315, 1.2913697306066751, 0.913305573631078, 1.8748549022711813, 3.306747623719275, 3.4333238191902637, 2.4112577503547072, 0.9768729563802481, 1.6016545495949686, 4.57981207408011, 9.348624106496572, 2.355392910540104, 4.880130859091878, 7.081567905843258, 4.611604968085885, 3.814017791301012, 4.871618365868926, 0.8042782614938915, 2.0019019162282348, 1.3632403803057969, 3.3931438252329826, 2.637238036841154, 1.1518526170402765, 0.9975681896321476, 0.2612358337501064, 0.15623988263541833, 0.37773223884869367, 0.13704553915886208, 0.13851359632099047, 0.045477306775865145, 0.10597661763313226, 0.07353204375249334, 0.16637209831969813, 0.05415436753537506, 0.14661609748145565, 0.06307780276983976, 5.41334817185998, 36.72856315970421, 95.98345756530762, 85.78284412622452, 57.513854429125786, 29.013386853039265, 22.979920506477356, 51.76281362771988, 50.795195549726486, 58.751391023397446, 71.24920159578323, 84.47997763752937, 74.04998570680618, 39.87511731684208, 8.221390843391418, 0.34537183935754, 0.024841430495143868, 0.04244085408572573, 0.01969830998859834, 0.020430364456842653, 0.03161710519634653, 0.011183387159690028, 0.04891848970146384, 0.05259484067209996, 0.006562036360264756, 0.037357398541644216, 0.01870394899015082, 0.028549302332976367, 0.04044472545501776, 0.0744174185092561, 0.022180203959578648, 0.016054383449954912, 0.048957534090732224, 0.01360243699309649, 0.045734605664620176, 0.06343567380099557, 0.02596867303509498, 0.05392140366893727, 0.049472072496428154, 0.02689448927412741, 0.042739950731629506, 0.07756998020340689, 0.013915398812969215, 0.026258110628987197, 0.04083532519871369, 0.05543154060433153, 0.058192496944684535, 0.03529240231728181, 0.028014208292006515, 0.021565458919212688, 0.03697974556416739, 0.0542086704808753, 0.06598252424737439, 0.011349857377354056, 0.02257795429613907, 0.03418429791054223, 0.0323786711669527, 0.039666928714723326, 0.05095262000395451, 0.0016575828931308934, 0.016062660251918714, 0.07284481500391848, 0.03384113253559917, 0.009706502150947927, 0.0442561881209258, 0.08318506210343912, 0.027304549985274207, 0.01914513537485618, 0.006747367333446164, 0.03010326123330742, 0.055158493341878057, 0.01786158169124974, 0.028165365220047534, 0.04180868898401968, 0.060608488201978616, 0.004876029443039442, 0.07313219684874639, 0.017712541739456356, 0.012946640053996816, 0.051731084677157924, 0.024072676824289374, 0.01709485408355249, 0.038704259277437814, 0.024083124408207368, 0.01816003081330564, 0.05797871759568807, 0.021703362945117988, 0.013268853672343539, 0.04368384754343424, 0.08777860741247423, 0.042269213881809264, 0.05910387284529861, 0.005172131059225649, 0.06342018517898396, 0.03809198002272751, 0.05473126489960123, 0.02881810079998104, 0.03754796722205356, 0.0249741487641586, 0.032743663105065934, 0.10356755432439968, 0.03576105744286906, 0.0689938775030896, 0.04319060877605807, 0.03678760724142194, 0.027508035745995585, 0.07185673443018459, 0.059982690727338195, 0.0659151298168581, 0.07832252536900342, 0.2952869643922895, 0.1443359229597263, 11.677192356437445, 50.843300968408585, 95.59577956795692, 87.72092252969742, 90.44439598917961, 64.5060682296753, 52.35335893929005, 38.84192235767841, 34.29314844310284, 30.017756558954716, 50.95449440181255, 60.10973833501339, 40.06148971617222, 19.88446030765772, 4.5551428478211164, 0.19205018528737128, 0.1929873545304872, 0.10912648533121683, 0.08167013089405373, 0.09417666995432228, 0.4984546999912709, 0.41998514032457024, 1.262111181858927, 1.1411865893751383, 0.9673960867803544, 1.9213218963705003, 1.731657567434013, 2.7227051882073283, 3.040932649746537, 4.450231427326798, 5.650627864524722, 7.357412204146385, 9.517538342624903, 6.168688265606761, 5.960347345098853, 6.544024050235748, 4.310513399541378, 9.714483674615622, 10.223147179931402, 12.237387746572495, 13.189796190708876, 14.972669072449207, 9.118703193962574, 7.496231105178595, 6.954060522839427, 5.78428141772747, 5.547216888517141, 4.249537596479058, 5.3632264863699675, 7.132825730368495, 5.179529143497348, 2.9506713431328535, 2.203556620515883, 1.7514910781756043, 1.1440695659257472, 0.8425310463644564, 0.8824455889407545, 0.33172840427141637, 0.27820132963825017, 0.09740537600009702, 0.0941177953791339, 0.05095998953038361, 0.3468842472648248, 0.07853736969991587, 6.93397575058043, 37.19515152275562, 71.03613182902336, 50.48963874578476, 35.21424561738968, 39.861943423748016, 39.306690618395805, 79.201969653368, 78.90503838658333, 74.72590863704681, 80.03236189484596, 96.2949800491333, 92.77129232883453, 60.51388084888458, 16.20876744389534, 0.13776972686173394, 0.015672106892452575, 0.03698204251122661, 0.03512699615384918, 0.009169542536255904, 0.04081014412804507, 0.05865210900083184, 0.06251421582419425, 0.0377905901405029, 0.02227005948952865, 0.053072223454364575, 0.016331317710864823, 0.12386113725369796, 0.03202771695214324, 0.054734567456762306, 0.030224494767026044, 0.02075363099720562, 0.0468567552161403, 0.0265049248264404, 0.036458902613958344, 0.03847159598080907, 0.04592397948727012, 0.007250325452332618, 0.034347344044363126, 0.055102546539274044, 0.02532907161366893, 0.05059488627011888, 0.03511508839437738, 0.06125699539552443, 0.01804653787985444, 0.013181188405724242, 0.02974257746245712, 0.10278654779540375, 0.040407814740319736, 0.03495741912047379, 0.03414046666875947, 0.07737760810414329, 0.047475097817368805, 0.057163984165526927, 0.05414566214312799, 0.07951229941681959, 0.017452569263696205, 0.04028922696306836, 0.033191285765497014, 0.0627292382705491, 0.043478803272591904, 0.026316816365579143, 0.022590776752622332, 0.04738913485198282, 0.04298448096960783, 0.039915366360219195, 0.12472680798964575, 0.1323561603203416, 0.09044582679052837, 0.11991331237368286, 0.12313611834542826, 0.1998229353921488, 0.1619367121020332, 0.18489600042812526, 0.12089055759133771, 0.09262302832212299, 0.12624772090930492, 0.16542035329621285, 0.1704982464434579, 0.11414839827921242, 0.18309955776203424, 0.08821220719255507, 0.16185210726689547, 0.13501129753421992, 0.08986188273411244, 0.17375726922182366, 0.1913055291515775, 0.12512237270129845, 0.11082603319664486, 0.27145010128151625, 0.10317953725461848, 0.1424221764318645, 0.1035246804531198, 0.18063521187286824, 0.2133641767431982, 0.13995711808092892, 0.17265872738789767, 0.13838265178492293, 0.13365818420425057, 0.1262510012020357, 0.23917104117572308, 0.1160010215244256, 0.15623348532244563, 0.22058960777940229, 0.2050768065964803, 0.2142986742546782, 0.18835249386029318, 0.1784843936911784, 0.14273570413934067, 0.13665850914549083, 0.39284325612243265, 0.1946688533644192, 13.061744961887598, 55.48452392220497, 109.81685847043991, 97.09046736359596, 89.33667942881584, 67.83566996455193, 36.12733282148838, 36.68104290962219, 57.86850459873676, 81.99010044336319, 114.5410917699337, 83.90106350183487, 54.784586280584335, 24.443248584866524, 5.737359635531902, 0.632781945168972, 0.5070009164046496, 0.2089523759786971, 0.08996438074973412, 0.15724470606073737, 0.6040329253301024, 0.2839887159643695, 0.7278080773539841, 0.678018102189526, 0.814449128229171, 1.7424175213091075, 1.1354847578331828, 1.2765437574125826, 5.0685518234968185, 5.943908477202058, 4.279545536264777, 7.622396685183048, 6.910181902348995, 5.548132164403796, 6.805942095816135, 4.6369999554008245, 6.753565706312656, 12.482030969113111, 20.03447625786066, 12.02079651877284, 18.053819239139557, 20.212331414222717, 15.585473589599133, 14.931422285735607, 11.822564955800772, 9.052422400563955, 6.967869456857443, 6.541539933532476, 7.847528904676437, 6.844697166234255, 5.109434304758906, 3.202099814079702, 1.4050603425130248, 1.5104551683180034, 0.6956501060631126, 0.5363343330100179, 0.7184264401439577, 0.32479244051501155, 0.26960616116411984, 0.2760331303579733, 0.5357988586183637, 0.13660764234373346, 0.3652602987131104, 0.21141737495781854, 8.783434834331274, 56.47377423942089, 135.9564158320427, 121.24207779765129, 82.89445951581001, 43.97550769150257, 33.03467497229576, 71.74570575356483, 71.20195493102074, 79.51498925685883, 87.60609269142151, 111.41523510217667, 102.98494666814804, 66.04353412985802, 13.444370180368423, 0.32352111185900867, 0.10662087603122927, 0.19881058658938855, 0.1441314909607172, 0.17969761218409985, 0.23303350957576185, 0.14706785761518404, 0.14260510099120438, 0.1325729861855507, 0.1039038882299792, 0.1504744787234813, 0.05687815340934321, 0.23719531047390774, 0.106995497335447, 0.15374662267277017, 0.09479516098508611, 0.07772300363285467, 0.21302467386703938, 0.0998357537901029, 0.114359806466382, 0.11306576066999696, 0.11221315915463492, 0.10607026924844831, 0.1048050336248707, 0.14580162009224296, 0.1943080805358477, 0.24141686910297722, 0.05016825154598337, 0.15388991654617712, 0.16418467741459608, 0.17399852658854797, 0.16594962333329022, 0.14952464844100177, 0.16468392015667632, 0.2210499026114121, 0.0655987967911642, 0.166205515852198, 0.09038131931447424, 0.1901520387036726, 0.12482730962801725, 0.1467462701839395, 0.15019790997030213, 0.09594755305442959, 0.12995733122806996, 0.0949430264881812, 0.11363520316081122, 0.17672542948275805, 0.17296049947617576, 0.11791564378654584, 0.1348261020029895, 0.16209458175580949], [0.07275579439010471, 0.05984402043395676, 0.036938945995643735, 0.07203024855698459, 0.03034179491805844, 0.08496882146573626, 0.05931032348598819, 0.04219312519126106, 0.0356671646295581, 0.03111965474090539, 0.08380767205380835, 0.05798498874355573, 0.005289194186843815, 0.08289196572150104, 0.06271187201491557, 0.03586009333957918, 0.04031232630950399, 0.005592511797658517, 0.026689105470723007, 0.046730987160117365, 0.011122800078737782, 0.06486197773483582, 0.1340646288008429, 0.06512496518553235, 0.04493697502766736, 0.03425644950766582, 0.11442951639764942, 0.03330742816615384, 0.029243780008982867, 0.011560394468688173, 0.07663928248803131, 0.09051397079019807, 0.03952498183934949, 0.01736238718876848, 0.07247337751323357, 0.013706115023524035, 0.051790942598017864, 0.10832846877747215, 0.036478391411947086, 0.07524472021032125, 0.02774910200969316, 0.10284539268468507, 0.16863431286765262, 0.2706906170351431, 9.95979756116867, 42.99800254404545, 69.14729118347168, 83.83530423045158, 72.6360359787941, 59.4772394746542, 35.55091895163059, 30.815464854240417, 40.06042957305908, 44.80191394686699, 53.97953487932682, 66.06301188468933, 28.88656485825777, 12.627682853490114, 1.3062442699447274, 0.316565377288498, 0.23851861915318295, 0.016932756043388508, 0.08928269584430382, 0.031734932272229344, 0.06766365942894481, 0.027964289583906066, 0.16582172160269693, 0.2994726476026699, 0.22036160517018288, 0.2758560539223254, 1.3973494875244796, 1.8385816924273968, 1.0178259713575244, 1.3650005171075463, 3.0309978453442454, 4.816123768687248, 3.7269563879817724, 6.255627600476146, 19.429423324763775, 9.517743531614542, 3.9497643196955323, 7.6035207230597734, 0.6359460472594947, 3.1899734772741795, 15.694010015577078, 12.729600984603167, 10.206086095422506, 7.637773035094142, 4.808060601353645, 7.595053352415562, 7.383575700223446, 2.407369134016335, 2.773970849812031, 2.797430078499019, 1.8608113308437169, 4.082916537299752, 3.0666399328038096, 1.1241722898557782, 1.2373241619206965, 3.590531595982611, 2.398617728613317, 0.20981139707146212, 0.16418541956227273, 0.07514853787142783, 0.1242056125192903, 0.02360418682656018, 0.03231123220757581, 0.055564433278050274, 0.05467866147228051, 0.10241793788736686, 0.23466768907383084, 0.13313158589880913, 10.724253840744495, 47.757425755262375, 70.48031285405159, 64.7523482143879, 41.262400075793266, 19.744027443230152, 18.634616173803806, 46.300424337387085, 65.09703531861305, 71.95935308933258, 75.69171041250229, 78.79856050014496, 74.49247196316719, 25.755705758929253, 0.6963214231655002, 0.13768277683993801, 0.010145007527171401, 0.048075313461595215, 0.032208422489929944, 0.07039628428174183, 0.06545978510985151, 0.045882790291216224, 0.019816391250060406, 0.042586689814925194, 0.061132433329476044, 0.028910984292451758, 0.053078361015650444, 0.03360928189067636, 0.029093868033669423, 0.04671318303735461, 0.026742970549094025, 0.05870240434887819, 0.022848418884677812, 0.011153181749250507, 0.03486160043394193, 0.04072798466950189, 0.10305785472155549, 0.06699721081531607, 0.020079230271221604, 0.036435447036637925, 0.006345100100588752, 0.08844851443427615, 0.06345316622173414, 0.03602177392167505, 0.018422101711621508, 0.06149755143269431, 0.018228109875053633, 0.03237286757212132, 0.07465414877515286, 0.03449646377703175, 0.034760583002935164, 0.06912256591022015, 0.014172046467137989, 0.05689484802132938, 0.004055874624100397, 0.07609982276335359, 0.07745577109744772, 0.03466160276730079, 0.08214301255065948, 0.039878574389149435, 0.06409407753380947, 0.01982644920644816, 0.032879776699701324, 0.012744231335091172, 0.04501932744460646, 0.03687591910420451, 0.010830742703547003, 0.033035264059435576, 0.010416570494271582, 0.016176010321942158, 0.06318692074273713, 0.015187665358098457, 0.058280066659790464, 0.030674586923851166, 0.03299470939964522, 0.03284761573013384, 0.014960163698560791, 0.05381688701163512, 0.03738455372513272, 0.047141498725977726, 0.04245792719302699, 0.03280730226833839, 0.08283260132884607, 0.004510787957769935, 0.035608171310741454, 0.09083060809643939, 0.02119564487657044, 0.02971997164422646, 0.05458661289594602, 0.018395287916064262, 0.05302141602442134, 0.011962341650360031, 0.07757308980217203, 0.05599614800303243, 0.10240440111374483, 0.06480042400653474, 0.030906289139238652, 0.022724734408257063, 0.021517590394068975, 0.03891726679285057, 0.04665516193199437, 0.0223471333811176, 0.01902188319945708, 0.014781991667405237, 0.04856093037233222, 0.04953634248522576, 0.11518880768562667, 0.8034375566057861, 19.2802794277668, 58.61185111105442, 88.28559502959251, 96.64207622408867, 82.88032427430153, 86.8200820684433, 65.9614509344101, 43.989772126078606, 18.651954643428326, 29.218952022492886, 45.64168408513069, 52.909774482250214, 37.05898962914944, 15.920899640768766, 2.8303973469883204, 0.30067465966567397, 0.44267179328016937, 0.031806334300199524, 0.08356090052984655, 0.1281130051938817, 0.7091861078515649, 0.8078286366071552, 1.4832329540513456, 2.944469600915909, 2.750535844825208, 3.946888823993504, 5.281230211257935, 5.432187085971236, 4.677322441712022, 6.316211549565196, 8.32263071089983, 5.600769789889455, 7.336471052840352, 6.568753598257899, 14.817122519016266, 13.664279580116272, 10.824534259736538, 10.34481855109334, 8.781569134443998, 10.00643815845251, 13.052029833197594, 16.031632348895073, 18.74368742108345, 13.127579279243946, 10.39332389831543, 9.278030544519424, 3.6062988499179482, 3.4093981655314565, 4.135781675577164, 4.659069646149874, 5.357035668566823, 4.391209194436669, 4.353923220187426, 4.604683639481664, 3.1104126339778304, 6.204326078295708, 3.6664258735254407, 2.020220495760441, 2.3327634623274207, 1.2640096549876034, 0.9123603149782866, 0.722649497911334, 0.15316099394112825, 0.0196284479170572, 0.11638063748250715, 0.05451881399494596, 0.32445497112348676, 0.1283257789327763, 11.821075435727835, 51.49629592895508, 62.36111752688885, 48.064270690083504, 38.14638487994671, 35.61521530151367, 35.32932624220848, 69.72201034426689, 85.77332183718681, 79.69477280974388, 86.02212488651276, 92.38501265645027, 93.54287132620811, 46.57147899270058, 1.5486409817822278, 0.28007572749629617, 0.004540530453596148, 0.06345997913740575, 0.0394993517693365, 0.11149795143865049, 0.0477554441022221, 0.06108599714934826, 0.020999218795623165, 0.05704056500690058, 0.041183503781212494, 0.06132672759122215, 0.027608526252151933, 0.009089795057661831, 0.02020830273977481, 0.06000483641400933, 0.017534871585667133, 0.04626900023140479, 0.045703791693085805, 0.05583352118264884, 0.020746361660712864, 0.04381961975013837, 0.08560363974538632, 0.015480074325751048, 0.01783670304575935, 0.025285231095040217, 0.009398525708093075, 0.018065210315398872, 0.03272998161264695, 0.06510706458357163, 0.01640169557504123, 0.04910014147753827, 0.025960865641536657, 0.07690897153224796, 0.040561828936915845, 0.04042175227368716, 0.040259570741909556, 0.015325071217375807, 0.0909875649085734, 0.03753412245714571, 0.03390523554116953, 0.02119433498592116, 0.03629863953392487, 0.023996499076019973, 0.023234749423863832, 0.039989109864109196, 0.02225593270850368, 0.019499497902870644, 0.05522827006643638, 0.03177062957547605, 0.1659768304671161, 0.16534383787075058, 0.16416471364209428, 0.11597517252084799, 0.1237208119709976, 0.15607785695465282, 0.17146294936537743, 0.2059843047754839, 0.19722250930499285, 0.14042286027688533, 0.18121413158951327, 0.14399731066077948, 0.21803749550599605, 0.21631709329085425, 0.13974094530567527, 0.16887165169464424, 0.17136370937805623, 0.20110809768084437, 0.19942081009503454, 0.18903158867033198, 0.086946763767628, 0.2532470296137035, 0.31595625216141343, 0.22898050752701238, 0.27875571395270526, 0.11032156573492102, 0.3786604281049222, 0.08568955076043494, 0.21460069867316633, 0.2220333818695508, 0.1933150869444944, 0.21428936772281304, 0.06840337286121212, 0.13584560510935262, 0.09846639484749176, 0.14842506760032848, 0.18322616815567017, 0.1426850599818863, 0.16541042336029932, 0.09049246335052885, 0.1037241549056489, 0.2385108414455317, 0.2601815387606621, 0.9989223419688642, 20.931361131370068, 66.32552459836006, 101.14970594644547, 111.25103071331978, 90.86845323443413, 78.3850134909153, 50.462812185287476, 41.763627380132675, 53.196666687726974, 63.472219705581665, 76.73031628131866, 91.47014334797859, 44.79250565171242, 21.980754621326923, 3.208442386239767, 0.6076442159246653, 0.43685564131010324, 0.1322128961328417, 0.3276992845349014, 0.23936273792060092, 0.47400820709299296, 0.5283571360632777, 1.3501107785850763, 2.170312204398215, 1.6715895594097674, 3.1109467428177595, 6.239917343482375, 6.259231232106686, 5.794480545446277, 5.841095494106412, 11.347312107682228, 16.696761958301067, 13.656631540507078, 19.64801799505949, 38.97141560912132, 27.44997214525938, 18.837587982416153, 20.06603356450796, 10.485882181674242, 12.680607363581657, 32.58778475224972, 33.47460776567459, 27.234328016638756, 24.98716849833727, 16.23655155301094, 21.58039480447769, 16.774802170693874, 8.957669734954834, 13.107442259788513, 13.065149579197168, 9.372025150805712, 13.650297280400991, 15.444219019263983, 10.855554845184088, 8.271193820983171, 11.174164898693562, 6.069667004048824, 1.3528788113035262, 1.227859107311815, 0.630889052990824, 0.5460814037360251, 0.2852541074389592, 0.11335119808791205, 0.10755951472674496, 0.5432608269620687, 0.3032967267790809, 0.3784674103371799, 0.3752374945906922, 17.896488681435585, 75.65152376890182, 103.53327244520187, 87.07417443394661, 60.02580463886261, 30.633823201060295, 26.382227540016174, 65.47399029135704, 84.47844251990318, 90.04282593727112, 92.52150133252144, 102.83871531486511, 105.75078025460243, 45.86022175848484, 1.1497158254496753, 0.2766105212504044, 0.07522865271312185, 0.1840763576910831, 0.1891466957749799, 0.20268502790713683, 0.1339363559964113, 0.21118667093105614, 0.06716987147228792, 0.10247149126371369, 0.1605184975778684, 0.13267663453007117, 0.144582983921282, 0.1002647151472047, 0.11316094853100367, 0.16770377842476591, 0.12704450549790636, 0.16072992060799152, 0.14954694255720824, 0.18026554811513051, 0.11469888631836511, 0.17862782115116715, 0.33355705614667386, 0.13612083799671382, 0.13741846836637706, 0.2407107304316014, 0.13264304492622614, 0.1348718925146386, 0.1485827294527553, 0.168697128247004, 0.1379073061980307, 0.19547772011719644, 0.07529658891144209, 0.2024620125303045, 0.17798387445509434, 0.17992807872360572, 0.11398182323318906, 0.12896031519630924, 0.16125264490256086, 0.12950318137882277, 0.12543284276034683, 0.16569441359024495, 0.12137986297602765, 0.2037183943320997, 0.13687808095710352, 0.14705703710205853, 0.266738532227464, 0.20954959705704823, 0.11576941207749769, 0.14662611647509038], [0.07979473855812103, 0.03994062906713225, 0.008146471554937307, 0.03426737021072768, 0.028045296858181246, 0.03714318503625691, 0.015053583392727887, 0.0614860221685376, 0.028226529320818372, 0.0710579905717168, 0.012736862736346666, 0.07824638843885623, 0.0327171350363642, 0.016679724503774196, 0.0177136159982183, 0.024294296963489614, 0.015703225144534372, 0.058418959597474895, 0.04316786194976885, 0.042165955164819025, 0.052154620934743434, 0.03969870747823734, 0.020945867654518224, 0.037652862374670804, 0.013949585845693946, 0.008577553599025123, 0.09522015185211785, 0.089703382254811, 0.06570710582309403, 0.05782961641671136, 0.06583615788258612, 0.05481423329911195, 0.06693452160106972, 0.07674404405406676, 0.025299471053585876, 0.09528094858978875, 0.10111546871485189, 0.056087202101480216, 0.03129162891127635, 0.02067536781396484, 0.29161146318074316, 0.4214074811898172, 6.065710466355085, 43.33273038268089, 75.38821309804916, 77.68583580851555, 78.85080769658089, 73.35167437791824, 49.928158074617386, 17.77611494064331, 40.42133800685406, 42.206474617123604, 72.81945213675499, 54.97014172375202, 29.240175783634186, 11.670461967587471, 1.1007273104041815, 0.07148655859054998, 0.12700298975687474, 0.17076363845262676, 0.06940355044207536, 0.17775898886611685, 0.1659937365911901, 0.060667700454359874, 0.2555106393992901, 0.34134758810978383, 0.7683587889187038, 1.8771864334121346, 2.511998894624412, 2.6417018473148346, 2.7406682493165135, 3.3261633943766356, 4.178010709583759, 11.672511007636786, 3.163574868813157, 3.8517728028818965, 11.67615121230483, 8.409308809787035, 12.201970797032118, 7.512087179347873, 6.053921123966575, 12.300408314913511, 5.0518156215548515, 14.557873830199242, 5.87388725951314, 14.0718400105834, 12.072377800941467, 15.060595404356718, 9.430196229368448, 5.007038824260235, 3.9868890400975943, 9.035380315035582, 15.734266955405474, 19.822992905974388, 15.351188611239195, 9.826000090688467, 9.932114146649837, 7.126037394627929, 4.762371378019452, 3.6394095607101917, 3.3056746562942863, 2.9758476046845317, 1.8691731384024024, 1.0036780242808163, 1.5018373494967818, 0.21073811687529087, 0.21600179927190766, 0.09426681121112779, 0.16482850536704063, 0.05561661739193369, 0.15900747006526217, 0.132675877539441, 0.28351098066195846, 0.5654546048026532, 14.718982335180044, 71.64845377206802, 66.82868599891663, 57.498461455106735, 60.46783111989498, 22.705090753734112, 22.332294657826424, 60.869925543665886, 52.00193099677563, 70.78426614403725, 74.2181570827961, 80.97268983721733, 40.19648887217045, 1.5609402093105018, 0.2227051739464514, 0.06299102344200946, 0.07261451173690148, 0.03628323996963445, 0.045046575396554545, 0.11341065153828822, 0.057862463872879744, 0.03146041926811449, 0.08653130949824117, 0.08044506030273624, 0.05479629187902901, 0.03639204252976924, 0.039971402220544405, 0.03407907621294726, 0.028361982404021546, 0.01902622290799627, 0.007169214277382707, 0.03717864856298547, 0.025119333258771803, 0.03598126379074529, 0.04074336939083878, 0.015409356929012574, 0.04326028902141843, 0.026783053945109714, 0.05247440123639535, 0.02851445293345023, 0.03855090559227392, 0.04366535693407059, 0.030958655079302844, 0.012799732849089196, 0.011616588963079266, 0.06960145154152997, 0.019257580024714116, 0.03749649185920134, 0.053231484635034576, 0.05856668409251142, 0.006358151231324882, 0.012669247516896576, 0.010614989241730655, 0.020605947320291307, 0.010319755474483827, 0.03109797846263973, 0.12014536710921675, 0.049729289748938754, 0.03533690149197355, 0.04817857960006222, 0.0858771508501377, 0.0645144448208157, 0.014201405829226132, 0.11867425972013734, 0.021652945142704993, 0.013469684399751713, 0.014511120753013529, 0.046568386314902455, 0.07584561491967179, 0.06422255071811378, 0.007975073476700345, 0.012934940095874481, 0.03417903237277642, 0.01724381982057821, 0.06392374722054228, 0.029879041721869726, 0.07017664567683823, 0.01300578458540258, 0.04536176180408802, 0.03730685457412619, 0.08856638232828118, 0.08569380326662213, 0.048849377199076116, 0.06108190049417317, 0.04018145969894249, 0.04845691095397342, 0.09362189230159856, 0.060517667880048975, 0.06567796168383211, 0.017384391867381055, 0.02943072515336098, 0.04046130874485243, 0.0446237330470467, 0.09256969759007916, 0.057833397659123875, 0.047056715775397606, 0.025940643972717226, 0.07221807129099034, 0.058635518289520405, 0.04749460145831108, 0.04655132805055473, 0.030685787787660956, 0.24763939145486802, 0.5665465712081641, 12.429906316101551, 61.58716365695, 91.52628153562546, 90.39986237883568, 89.92355793714523, 90.68070530891418, 72.39898189902306, 28.15542709082365, 35.74509233236313, 35.19997738301754, 49.8994430154562, 52.986746951937675, 37.255762070417404, 16.89652293920517, 2.260867995209992, 0.10306609998224303, 0.3105245326878503, 0.1301284259534441, 0.09264446896850131, 0.15307325724279508, 0.4485615366138518, 1.0435133054852486, 1.275039513129741, 2.455212129279971, 4.810338579118252, 8.03202610462904, 6.099482104182243, 4.429828422144055, 9.063066579401493, 4.339479245245457, 4.995830850675702, 1.7137202736921608, 5.44469696469605, 3.3402967359870672, 5.471944352611899, 3.3789907721802592, 9.00025025010109, 10.653862617909908, 16.719579733908176, 13.65340931341052, 11.42760369926691, 15.596641190350056, 13.595425374805927, 13.831933233886957, 14.652214217931032, 9.300820771604776, 5.850981138646603, 3.564060553908348, 4.081752374768257, 10.992441549897194, 15.946524515748024, 15.017769802361727, 12.326322924345732, 8.533848077058792, 6.84289226308465, 6.143869897350669, 3.0926763731986284, 2.417037240229547, 6.498993616551161, 4.598184088245034, 2.8346775798127055, 2.094139354303479, 3.0229197163134813, 1.4531158888712525, 0.778568722307682, 0.35398188047111034, 0.43223057698924094, 0.23856274725403637, 0.14911906473571435, 0.03408338438021019, 0.2613969094818458, 0.554646203527227, 16.99242029339075, 50.65300717949867, 48.25688995420933, 41.09124965965748, 43.569423481822014, 42.07982361316681, 43.74036870896816, 84.0524397790432, 65.60484766960144, 79.57389369606972, 82.64865830540657, 91.914172321558, 64.52160179615021, 4.408122086897492, 0.20092564809601754, 0.051158217174815945, 0.03934764194127638, 0.06312265075393952, 0.0745784274477046, 0.045539046041085385, 0.04068112175446004, 0.03829286455584224, 0.0741654667945113, 0.022307717918010894, 0.05558858647418674, 0.04329410498030484, 0.05827993678394705, 0.11009852067218162, 0.0237931450465112, 0.0762047698663082, 0.003888642081619764, 0.07046879953122698, 0.037718505336670205, 0.07655324530787766, 0.020444897563720588, 0.037752840798930265, 0.013726590877922717, 0.045124667885829695, 0.06691870643408038, 0.02177845159167191, 0.05041794713179115, 0.01847968866059091, 0.060357924303389154, 0.1012577532674186, 0.036921880309819244, 0.05098175672173966, 0.0850639796408359, 0.06750187123543583, 0.008731884136068402, 0.014830844465905102, 0.04596743223373778, 0.04589361080434173, 0.07548242268967442, 0.03892405002261512, 0.037834480754099786, 0.037987737960065715, 0.06020880457072053, 0.030943300043873023, 0.046333811988006346, 0.04564778551866766, 0.06845923431683332, 0.060985269155935384, 0.17676391726126894, 0.18664889386855066, 0.13259906525490806, 0.08908811956644058, 0.11697233698214404, 0.08862454444169998, 0.17641454382101074, 0.15501706075156108, 0.0834910866979044, 0.08483306039124727, 0.19257901003584266, 0.14837197435554117, 0.07890782013419084, 0.09833971766056493, 0.2520232874667272, 0.10239122799248435, 0.17383140977472067, 0.12478337448555976, 0.16413234116043895, 0.2712164435070008, 0.12260916380910203, 0.18242059653857723, 0.12609292374690995, 0.12541627802420408, 0.17253122641704977, 0.10921917215455323, 0.26974417094606906, 0.15843560075154528, 0.23608136165421456, 0.15859931852901354, 0.16835584421642125, 0.19249017495894805, 0.12986515648663044, 0.1346598015516065, 0.11214994301553816, 0.18598728405777365, 0.27238770097028464, 0.15037552075227723, 0.1405356073519215, 0.14916337095201015, 0.431782616651617, 0.8311449573375285, 14.970850870013237, 71.0419075191021, 106.99702218174934, 100.86062505841255, 100.85833758115768, 90.50928130745888, 71.39720365405083, 22.32230879366398, 48.47899183630943, 61.86711743474007, 104.04123678803444, 77.64839261770248, 48.23003299534321, 22.318250611424446, 3.1635646568611264, 0.7475130481179804, 0.35027179517783225, 0.30559563310816884, 0.2679435128811747, 0.2649675600696355, 0.34805028000846505, 0.70897480356507, 0.652041983557865, 1.0155621240846813, 3.763814647682011, 7.154224757105112, 6.254989234730601, 8.838287740945816, 12.435129135847092, 10.868499800562859, 14.84003433957696, 25.562336035072803, 14.773400165140629, 13.10915406793356, 28.565290197730064, 23.10295980423689, 30.98413970321417, 24.537059850990772, 18.33373311907053, 31.2169836089015, 20.476666130125523, 29.407646097242832, 24.037745743989944, 32.51591920852661, 24.12624679505825, 33.28425318002701, 23.28555330634117, 16.60272840410471, 14.206137154251337, 19.88673448562622, 24.989822655916214, 27.315962836146355, 26.840254962444305, 18.464919179677963, 18.969940580427647, 17.421151287853718, 14.780241698026657, 13.455475084483624, 16.444366201758385, 13.322816602885723, 6.17314257659018, 4.9199707712978125, 3.8004917046055198, 0.6848444952629507, 0.38791474245954305, 0.1830028707627207, 0.23853736580349505, 0.2956952346721664, 0.2603188360808417, 0.19277673301985487, 0.39502433908637613, 1.1061574565246701, 25.88721290230751, 106.67536944150925, 87.80736029148102, 76.90975025296211, 77.48137637972832, 30.672717913985252, 33.28774519264698, 80.59090912342072, 71.7776620388031, 89.33614745736122, 91.72978341579437, 104.52696472406387, 67.32340425252914, 2.6048618741333485, 0.30164408264681697, 0.10246055200695992, 0.3216050349874422, 0.1458115054992959, 0.15233447891660035, 0.37562189740128815, 0.2134921378456056, 0.18346113211009651, 0.1562396006193012, 0.14404088957235217, 0.12789439817424864, 0.11199878237675875, 0.10836455941898748, 0.14071580080781132, 0.13602787657873705, 0.12864411575719714, 0.11560163475223817, 0.158326861273963, 0.10149200476007536, 0.12317776767304167, 0.10985477711074054, 0.09463841939577833, 0.1324595118057914, 0.1330386393237859, 0.1997197323362343, 0.10569187783403322, 0.07942968353745528, 0.21891656942898408, 0.13537358434405178, 0.11816066384199075, 0.1098946007550694, 0.23870028206147254, 0.12725586915621534, 0.3387620049761608, 0.26771418924909085, 0.13194791972637177, 0.12017523113172501, 0.10756409377790987, 0.17094028444262221, 0.06410688700270839, 0.16231688467087224, 0.14951320452382788, 0.18147122638765723, 0.07720208275713958, 0.06998974320595153, 0.17875465418910608, 0.18230557849165052, 0.151318701391574], [0.02068966714432463, 0.05979483088594861, 0.06579533976037055, 0.029848986596334726, 0.010667968381312676, 0.055871274234959856, 0.024821937986416742, 0.06429422734072432, 0.030619551107520238, 0.07245028187753633, 0.06189224041008856, 0.050089813958038576, 0.025065264089789707, 0.1121496238920372, 0.01118523696277407, 0.006050073670849088, 0.03065453223825898, 0.01176717165435548, 0.03174757475790102, 0.005409937439253554, 0.02581028573331423, 0.07564263753010891, 0.03880519878293853, 0.049913661496248096, 0.02343444652069593, 0.03514463700412307, 0.04407823595101945, 0.04449124855455011, 0.07256892160512507, 0.007451573637808906, 0.0659731806081254, 0.06992756607360207, 0.010854675110749668, 0.038306397618725896, 0.04412631598825101, 0.04646658220735844, 0.007484682237191009, 0.043820577120641246, 0.13409106410108507, 1.3752293307334185, 8.00144724547863, 27.152596302330494, 76.03432282805443, 79.0211221575737, 75.95847889780998, 62.54775211215019, 51.20199412107468, 26.84801794588566, 23.266366235911846, 56.51176460087299, 96.39536306262016, 59.43903632462025, 21.385725550353527, 11.338544078171253, 1.6829532058909535, 0.11432505169068463, 0.1592353094019927, 0.04233523162838537, 0.022269341461651493, 0.09711236125440337, 0.19367200060514733, 0.3277127322508022, 0.16852021508384496, 0.42343256471212953, 0.9164305496960878, 2.5524427369236946, 2.7308792620897293, 7.666380275040865, 8.310177829116583, 3.70340240187943, 6.0461372416466475, 4.181677037850022, 8.617611732333899, 9.928991664201021, 25.833717472851276, 19.107415303587914, 16.542199552059174, 6.990277329459786, 9.25405953079462, 9.335331469774246, 11.193093582987785, 5.952988089993596, 9.28763072937727, 6.396883595734835, 8.654072675853968, 6.6481617372483015, 16.653111800551414, 5.341723440214992, 6.55743258073926, 8.43916380777955, 16.125059835612774, 43.79461079835892, 51.75618298351765, 56.9531337171793, 57.610650435090065, 40.28603486716747, 32.97836199402809, 32.31977753341198, 22.066398225724697, 15.879921689629555, 6.505046216771007, 5.615885378792882, 4.021751694381237, 2.570133162662387, 2.121157804504037, 3.5614277701824903, 0.6064280436839908, 0.3209946333663538, 0.05773537479399238, 0.12202079655253328, 0.08766428698436357, 0.01836781175370561, 0.0690571307495702, 0.024458929437969346, 0.16300913033774123, 3.9773909747600555, 36.786973625421524, 75.25916442275047, 80.73750525712967, 44.42432440817356, 28.30252669751644, 18.812471330165863, 31.913959309458733, 51.29714861512184, 66.8886923789978, 72.26273640990257, 83.46201986074448, 51.84211917221546, 2.125964784063399, 0.3460746235214174, 0.04862777561356779, 0.028351622022455558, 0.07992128215846606, 0.012406296245899284, 0.03005364866112359, 0.023344093751802575, 0.08033672900637612, 0.042036175800603814, 0.04979887351510115, 0.03331325402541552, 0.09141746879322454, 0.04611477081198245, 0.0136769087293942, 0.06554881314514205, 0.030028536239115056, 0.013831282867613481, 0.025020069151651114, 0.15700661024311557, 0.06577177657163702, 0.07887017098255455, 0.038088818473625, 0.030305557702376973, 0.026647367085388396, 0.020441552333068103, 0.0042275853320461465, 0.032883038438740186, 0.022301593344309367, 0.050577037618495524, 0.029198037736932747, 0.029441725637298077, 0.025637543440097943, 0.014906213273206959, 0.05858703749254346, 0.004402970598675893, 0.05615718291664962, 0.029514751113310922, 0.011570636106625898, 0.05007812142139301, 0.021768636688648257, 0.02167185506550595, 0.025289465047535487, 0.03546145984728355, 0.044487615741672926, 0.04691018984885886, 0.05893227345950436, 0.002499646839169145, 0.02361606304475572, 0.04323284811107442, 0.08261788316303864, 0.00997604833173682, 0.08013874627067707, 0.01983026013476774, 0.022877440569573082, 0.028465001778386068, 0.021863156616745982, 0.05139078028150834, 0.05224393469688948, 0.014684541183669353, 0.017169849961646833, 0.10770299413707107, 0.01955090647243196, 0.07526370434788987, 0.025942766515072435, 0.02256581276014913, 0.026939754716295283, 0.09179488799418323, 0.05141543813806493, 0.05202917571295984, 0.04359381760878023, 0.047843091742834076, 0.0640943818143569, 0.018871822794608306, 0.036826425275648944, 0.017553143261466175, 0.05130204539455008, 0.06912346390890889, 0.04372230192529969, 0.04608196788467467, 0.01577686103701126, 0.03468337366939522, 0.037271365072228946, 0.08534529071766883, 0.04223456671752501, 0.011601885162235703, 0.0956933452107478, 2.591361911036074, 13.063324727118015, 44.24524001777172, 99.187992811203, 97.143664509058, 96.07944801449776, 78.55268329381943, 75.18205896019936, 49.61929924786091, 23.5900404676795, 31.886707171797752, 63.424551263451576, 52.85501182079315, 31.887071952223778, 17.307373993098736, 2.851958340033889, 0.13009572692681104, 0.17644194391323254, 0.10220943891908973, 0.1030637622170616, 0.24964158714283258, 0.7378129404969513, 1.287292786873877, 1.1105753132142127, 3.621581867337227, 9.207623172551394, 7.510107485577464, 8.318714071065187, 9.94956186041236, 5.672493791207671, 4.27671848796308, 5.161567982286215, 4.484163131564856, 6.32108336314559, 10.243013463914394, 22.109941989183426, 22.447496876120567, 21.647767089307308, 11.149613466113806, 5.32887632958591, 6.431640330702066, 12.285283226519823, 16.040901951491833, 14.786783996969461, 11.4039490185678, 6.489505050703883, 2.4963157111778855, 4.542707065120339, 1.991508761420846, 2.181914644315839, 5.215495163574815, 18.600596599280834, 46.957078501582146, 56.61764971911907, 59.35225658118725, 59.898511469364166, 48.321931064128876, 40.7340232282877, 34.49383847415447, 24.593889601528645, 15.87574951350689, 8.75321315601468, 6.0240960493683815, 5.196074405685067, 2.107705338858068, 4.508174993097782, 4.2468164674937725, 4.183356072753668, 1.4288433850742877, 0.36654650000855327, 0.4861971811624244, 0.4254975460935384, 0.20194975251797587, 0.05299394171743188, 0.032920472367550246, 0.12361107801552862, 4.591441350057721, 30.94587005674839, 52.455976232886314, 60.70944495499134, 28.308233991265297, 28.1351038813591, 35.45398995280266, 52.219670712947845, 71.25297859311104, 88.81506621837616, 79.91883918642998, 92.04156428575516, 71.88388153910637, 9.514916483312845, 0.1739942963467911, 0.06477010727394372, 0.017843512250692584, 0.04474605382711161, 0.043829705537064, 0.0782535872713197, 0.0142371560104948, 0.022913004286237992, 0.03574717557057738, 0.014743294232175685, 0.0424494036269607, 0.05512039890163578, 0.06938591701327823, 0.04730880478746258, 0.07961582159623504, 0.040520309485145845, 0.01835003731684992, 0.04930605777190067, 0.08393126932787709, 0.018722602872003336, 0.03817242140939925, 0.0588606005476322, 0.06547511045937426, 0.012441270882845856, 0.03766147870919667, 0.06255055879591964, 0.019078445984632708, 0.0019447106683401216, 0.03347371006384492, 0.010857086163014174, 0.05202393243962433, 0.02596728336357046, 0.027005727934010793, 0.033659796172287315, 0.038652884104521945, 0.05226706743997056, 0.05707595802959986, 0.029257570968184154, 0.011463817863841541, 0.020367723482195288, 0.02111516267177649, 0.03819710524112452, 0.03559493139619008, 0.029308708653843496, 0.03976127794885542, 0.06916342113981955, 0.032412416621809825, 0.06685996544547379, 0.12262107527931221, 0.2164803954656236, 0.08340431479155086, 0.11765421484597027, 0.17242671718122438, 0.15083274309290573, 0.11595474861678667, 0.09982956427847967, 0.1524566364241764, 0.16429139825049788, 0.17049186397343874, 0.04972563838236965, 0.1380426887772046, 0.10232080559944734, 0.14054608647711575, 0.11812949363957159, 0.1467075597611256, 0.11931480737985112, 0.12565225129947066, 0.11570524598937482, 0.1911871269112453, 0.19512683269567788, 0.1589583992608823, 0.14643010043073446, 0.1765783061273396, 0.10341738074203022, 0.20026486949063838, 0.1490323373582214, 0.16924857365665957, 0.19052357267355546, 0.30248739989474416, 0.10410622737254016, 0.10020019282819703, 0.14764064719201997, 0.16470579867018387, 0.15657430922146887, 0.11216298255021684, 0.26619516138453037, 3.04186241235584, 15.658398326486349, 55.12563318014145, 119.93590548634529, 109.46833357214928, 103.29213738441467, 82.47113943099976, 70.20821705460548, 41.723110154271126, 34.779351353645325, 79.26925644278526, 127.58274435997009, 81.4625595510006, 36.119558438658714, 21.90320648252964, 4.0861002914607525, 0.7144285796675831, 0.313969433773309, 0.28972210362553596, 0.11479307970148511, 0.2571647975128144, 0.3158493235241622, 0.855233883485198, 0.4849262977950275, 2.6256097108125687, 6.008341144770384, 9.998117554932833, 9.960917551070452, 18.672737628221512, 20.82202009856701, 15.863422974944115, 16.557334139943123, 13.398847673088312, 16.521004289388657, 19.028301648795605, 37.159102857112885, 27.701512947678566, 26.52822520583868, 17.728326804935932, 26.73884980380535, 28.941876590251923, 29.182223193347454, 22.742256559431553, 28.93418200314045, 22.97492567449808, 26.06940172612667, 21.611399240791798, 40.16533434391022, 21.816719323396683, 18.337192833423615, 17.058578543365, 23.800298385322094, 54.60913069546223, 62.237521559000015, 66.48212939500809, 64.26242530345917, 48.503663912415504, 41.0994154214859, 40.129152685403824, 29.59653966128826, 24.26352772861719, 14.805938769131899, 17.248608246445656, 20.524782948195934, 12.740583345293999, 12.235695887356997, 9.147496148943901, 2.784469211474061, 0.5889023747295141, 0.2000590570969507, 0.28361734526697546, 0.12789687694748864, 0.2927679073764011, 0.17314235534286126, 0.07797615762683563, 0.2987851813668385, 6.908489568158984, 57.00179770588875, 107.95891776680946, 107.767294049263, 58.92142049968243, 41.94764010608196, 27.73007031530142, 43.420205488801, 69.63558778166771, 86.07007071375847, 88.34307834506035, 105.57595163583755, 77.52990737557411, 6.710613761097193, 0.26970860722940415, 0.18094642407959327, 0.10023900715168566, 0.12913840095279738, 0.11252506155869924, 0.1492582619539462, 0.13929614651715383, 0.19124470272799954, 0.17324281245237216, 0.1472860638750717, 0.12736220407532528, 0.1289638626622036, 0.16896520683076233, 0.10414960590424016, 0.21820366237079725, 0.16420847066910937, 0.11127623482025228, 0.13022444501984864, 0.2657609456218779, 0.10293037601513788, 0.31464858795516193, 0.24531351547921076, 0.11922698904527351, 0.06480767478933558, 0.12428109635948204, 0.12744934705551714, 0.08862663729814813, 0.15917047538096085, 0.12730373768135905, 0.12111504242056981, 0.14900257723638788, 0.08197149480110966, 0.13332596921827644, 0.14541430806275457, 0.12158295168774202, 0.1709332934115082, 0.17090230132453144, 0.12277808404178359, 0.12891358957858756, 0.08874855731846765, 0.0678212619095575, 0.09861558879492804, 0.08353501441888511, 0.13509802491171286, 0.2399409600184299, 0.14984184235800058, 0.1299480692250654], [0.06699186735204421, 0.011567565470613772, 0.02272956022352446, 0.07421662303386256, 0.03982847942097578, 0.031792174122529104, 0.05274961185932625, 0.08731015637749806, 0.04197258116619196, 0.028371619191602804, 0.036297945625847206, 0.04868873562372755, 0.02998263997142203, 0.07374837237875909, 0.009593968443368794, 0.0410915665270295, 0.0224448018707335, 0.014338756027427735, 0.024059767165454105, 0.0073021153002628125, 0.05040666648710612, 0.07410525635350496, 0.04686141219281126, 0.1271485842880793, 0.04330351541284472, 0.019383012258913368, 0.059578079235507175, 0.06479911040514708, 0.08660648163640872, 0.05367482881410979, 0.013046025687799556, 0.08226787889725529, 0.06374366508680396, 0.055259696309803985, 0.057693209673743695, 0.07199515239335597, 0.06123609280621167, 0.029250281222630292, 4.258774425834417, 36.932855397462845, 64.14545238018036, 77.16581091284752, 75.74244529008865, 57.25294142961502, 28.330261409282684, 25.221703313291073, 27.594656981527805, 40.48783823847771, 56.51513881981373, 49.01922784745693, 32.58009776473045, 12.90343215689063, 3.937210268341005, 0.054272402412607335, 0.12241209391504526, 0.05480053696373943, 0.06593899728613906, 0.09334636997664347, 0.22288327454589307, 0.1607517249067314, 0.3382214839803055, 0.9492832899559289, 2.4323494685813785, 4.065735284239054, 7.2616687417030334, 9.861823618412018, 9.88999530673027, 9.558904822915792, 3.161043729633093, 3.190524447709322, 7.037114566192031, 6.979938559234142, 24.914484098553658, 36.801268458366394, 56.18860714137554, 56.53664566576481, 53.499320447444916, 32.905063927173615, 24.998932667076588, 9.607076738029718, 23.32809392362833, 14.435696136206388, 9.724231101572514, 10.626960061490536, 3.72284690849483, 4.212770294398069, 9.14355956017971, 10.086711701005697, 7.904359605163336, 16.85493227094412, 63.92206236720085, 88.90366986393929, 89.77207526564598, 98.06266039609909, 97.28149071335793, 103.77839729189873, 93.75273406505585, 93.17793890833855, 78.29238206148148, 62.037572488188744, 49.37174253165722, 33.47211889922619, 15.671178940683603, 6.553719229996204, 5.634859660640359, 4.12910733371973, 3.7678250949829817, 2.1865411335602403, 1.0009041731245816, 0.7733366405591369, 0.1330865523777902, 0.01861050332081504, 0.08785933823673986, 0.004426841778695234, 0.04082408166141249, 0.30184781702701, 0.6637414963915944, 12.732268441468477, 43.05753394961357, 91.21576979756355, 80.70595934987068, 40.26677370071411, 37.634544745087624, 63.43458652496338, 45.32565884292126, 57.39074103534222, 63.116547390818596, 82.83761456608772, 77.66989946365356, 11.859774459153414, 0.38272024306934327, 0.14800333476159722, 0.0821643418748863, 0.057548108670744114, 0.06456646195147187, 0.016095813844003715, 0.022283356920524966, 0.050578325244714506, 0.07668596357689239, 0.03557934258424211, 0.04405349645821843, 0.007627527575095883, 0.052780095575144514, 0.03478677710518241, 0.05931459083512891, 0.07473651232430711, 0.018835429727914743, 0.02412121513771126, 0.023080518149072304, 0.06761433629435487, 0.12700714578386396, 0.08023385991691612, 0.060764328081859276, 0.04559749759209808, 0.027387494264985435, 0.05242649931460619, 0.04147060360992327, 0.041299271397292614, 0.052801899873884395, 0.02306174923432991, 0.030153165098454338, 0.028078641553292982, 0.03896563626767602, 0.05017077855882235, 0.060522120766108856, 0.07456572930095717, 0.0499377627420472, 0.060143569789943285, 0.10818256996572018, 0.0325813554081833, 0.04969341061951127, 0.03274952978244983, 0.036250206976546906, 0.025502151584078092, 0.04064018117787782, 0.018874440720537677, 0.06813480445998721, 0.011457098644314101, 0.02004146052058786, 0.018976332030433696, 0.037967013486195356, 0.057546550160623156, 0.08208709914470091, 0.05730296987167094, 0.008446790889138356, 0.034876487916335464, 0.03835244417132344, 0.025027184492500965, 0.013738853940594709, 0.021147451661818195, 0.02741489250183804, 0.05963330986560322, 0.04237547458615154, 0.0046860363909217995, 0.02432855821098201, 0.083756137319142, 0.042685258158599027, 0.055510327001684345, 0.08220070711104199, 0.031333281949628145, 0.03513547148031648, 0.04198212889605202, 0.055424282400053926, 0.05981817143037915, 0.06355694815283641, 0.010878286539082183, 0.0339163083845051, 0.06670746151939966, 0.056962583839776926, 0.040103315259329975, 0.05333440196409356, 0.020343234464235138, 0.06425593252060935, 0.02323708904441446, 5.883442796766758, 47.492598965764046, 79.69003066420555, 94.17834162712097, 92.92057871818542, 71.47853448987007, 50.860734432935715, 48.06239739060402, 32.72349826991558, 33.47537152469158, 46.108846217393875, 49.36309799551964, 37.38430917263031, 20.418913029134274, 4.669242650270462, 0.16273192333756015, 0.3607463190564886, 0.0625682293321006, 0.15963338257279247, 0.32541902095545083, 0.7352282479405403, 1.1141594708897173, 1.7456116061657667, 3.5619136691093445, 5.2741084434092045, 8.915672488510609, 12.407653760164976, 13.787995241582394, 8.761111032217741, 8.245885279029608, 3.402276635169983, 2.5264319451525807, 2.7243381505832076, 8.587632291018963, 25.768011398613453, 43.51052284240723, 61.76791995763779, 63.18513751029968, 54.18850466609001, 38.56197237968445, 26.741059385240078, 10.453154537826777, 7.036308059468865, 5.981178777292371, 5.201111035421491, 1.4234908972866833, 2.525683860294521, 1.7238983837887645, 3.9733320800587535, 7.2805380541831255, 8.423456400632858, 22.508267015218735, 67.49806568026543, 95.84806323051453, 96.5404012799263, 105.69945260882378, 103.29890102148056, 105.92956066131592, 98.3819268643856, 98.5671441257, 85.38223162293434, 69.85681191086769, 52.32462488114834, 34.56663116812706, 19.838458076119423, 9.342172052711248, 5.105516714975238, 4.162944043055177, 6.800896441563964, 5.087583577260375, 4.629877237603068, 2.001438816078007, 0.42786271136719733, 0.30603822029661387, 0.4061299853492528, 0.17186329350806773, 0.027444025508884806, 0.21012446464737877, 0.8496122038923204, 13.950853552669287, 40.77199839055538, 64.83247071504593, 53.875709250569344, 34.48314964771271, 37.111468613147736, 64.54202950000763, 64.12617221474648, 75.51887288689613, 75.70034354925156, 95.29483571648598, 99.1662959754467, 26.409225091338158, 0.5199771013576537, 0.29223742021713406, 0.10030832374468446, 0.09368231054395437, 0.04357530844572466, 0.058832614158745855, 0.0314377095492091, 0.018698768799367826, 0.035152882264810614, 0.017813644517445937, 0.013448381978378166, 0.010135854990949156, 0.013280782768561039, 0.024041842443693895, 0.06467746497946791, 0.027082477135991212, 0.023260757989191916, 0.028440453388611786, 0.023526432014477905, 0.07267060325830244, 0.04939509693940636, 0.04228072830301244, 0.06780936528230086, 0.09892412927001715, 0.030038807562959846, 0.047438650944968686, 0.024607049126643687, 0.09566892113070935, 0.09372920685564168, 0.061139160898164846, 0.03750952768314164, 0.014783381338929757, 0.011675712157739326, 0.07185695707448758, 0.02723621673794696, 0.03471611351415049, 0.022329958228510804, 0.09031853362102993, 0.028894946481159423, 0.10648630239302292, 0.04877901417785324, 0.04066250126925297, 0.007113377405403298, 0.025841632195806596, 0.02568756419350393, 0.0634147081291303, 0.21949105110252276, 0.12252840329892933, 0.10742010970716365, 0.1590542698977515, 0.13448027602862567, 0.19963052618550137, 0.18455036741215736, 0.17554743331857026, 0.1647035128553398, 0.10009525314671919, 0.19418443873291835, 0.11217965860851109, 0.16851499036420137, 0.1199588505551219, 0.08707127388333902, 0.12411782387061976, 0.15571821219054982, 0.06854141975054517, 0.08722002254216932, 0.16301330120768398, 0.12060743567417376, 0.13675803114892915, 0.2109754557022825, 0.26290640817023814, 0.18416301085380837, 0.12059021784807555, 0.08784842866589315, 0.12634998885914683, 0.1392703939927742, 0.10302957147359848, 0.08887149408110417, 0.2085233255638741, 0.12178135002613999, 0.1065816089976579, 0.11822740518255159, 0.10440938727697358, 0.12424685366568156, 0.2328499616123736, 8.538064900785685, 58.35986763238907, 100.30761793255806, 111.90089464187622, 100.6588938832283, 77.52309054136276, 39.68079574406147, 39.45671796798706, 40.24766452610493, 55.11227689683437, 78.12749370932579, 70.8586585521698, 51.188478246331215, 24.004484228789806, 7.863478073850274, 0.45577969460282475, 0.4837387427687645, 0.143385291157756, 0.5320719117298722, 0.32088675478007644, 0.5683903628960252, 0.8622081717476249, 1.3592528505250812, 2.503041587769985, 7.516697281971574, 14.276674669235945, 22.460269890725613, 23.29462341964245, 22.57447086274624, 21.781588308513165, 11.648560892790556, 9.967507347464561, 17.160542272031307, 14.545616637915373, 32.77884989976883, 42.95718893408775, 66.90898329019547, 63.36974300444126, 61.65175259113312, 39.73085045814514, 36.26301974058151, 25.097261890769005, 45.63718892633915, 28.623043298721313, 26.43602315336466, 26.14316336810589, 17.943815141916275, 16.435953453183174, 21.741888038814068, 21.72857355326414, 12.392703462392092, 27.676139809191227, 69.91263091564178, 101.22955486178398, 98.02324891090393, 104.78598162531853, 107.15499490499496, 109.07420352101326, 98.21408227086067, 101.06023594737053, 83.88370603322983, 71.38496071100235, 57.199668288230896, 41.86132773756981, 27.754635997116566, 16.434427835047245, 18.386918865144253, 15.361905936151743, 15.67385969683528, 8.47289364784956, 3.774429140612483, 1.4575466886162758, 0.3421787638217211, 0.21400810859631747, 0.35832445370033383, 0.2581206540344283, 0.2675838384311646, 0.48258514842018485, 1.7963506397791207, 20.894347317516804, 67.29058921337128, 127.25954130291939, 99.47547018527985, 55.47731950879097, 52.57864125072956, 75.3537717461586, 54.24692653119564, 77.34356537461281, 80.44654726982117, 107.47327342629433, 110.50829976797104, 23.164955377578735, 0.4144405550323427, 0.20880261057754979, 0.15715199697297066, 0.29469280096236616, 0.1969455843209289, 0.12793518661055714, 0.1554650953039527, 0.10939146173768677, 0.14978870458435267, 0.09091832995181903, 0.1476008680765517, 0.17042894469341263, 0.17137107148300856, 0.11591249814955518, 0.17340743565000594, 0.17260766762774438, 0.13593071460491046, 0.10778056341223419, 0.09013041402795352, 0.10789322142954916, 0.18811267626006156, 0.25406469823792577, 0.26867699227295816, 0.20296656904974952, 0.1061475119786337, 0.16490021167555824, 0.12813771871151403, 0.24765451642451808, 0.27439565572422, 0.12046013420331292, 0.11740604808437638, 0.1726847025565803, 0.11842620428069495, 0.16731168696423993, 0.07423692819429561, 0.22133223043056205, 0.09754184211487882, 0.1689171008183621, 0.16011732222978026, 0.20309659332269803, 0.1758217459428124, 0.14935217332094908, 0.08362620952539146, 0.19689798296894878, 0.14149956812616438, 0.2026701404247433], [0.026474943915673066, 0.08599927125032991, 0.09538532423903234, 0.019834933809761424, 0.12390962918289006, 0.041432264260947704, 0.009183158163068583, 0.035117960505886, 0.12092831064364873, 0.01805188319849549, 0.08494809328112751, 0.03507494191580918, 0.07505125715397298, 0.012588200352183776, 0.03566755425708834, 0.01357650913632824, 0.030187532101990655, 0.052548526946338825, 0.060158431297168136, 0.0725866218272131, 0.050593275809660554, 0.07736462794127874, 0.0694477601791732, 0.08805406294413842, 0.13956849987152964, 0.059904895097133704, 0.15126936341403052, 0.061089663358870894, 0.14047736360225827, 0.010115529421454994, 0.11373681059922092, 0.03798815356276464, 0.15263792825862765, 0.09655432557337917, 0.0814333709422499, 0.022427055264415685, 0.20338724803877994, 7.626161333173513, 75.09339451789856, 29.093461856245995, 36.95161499083042, 76.12323045730591, 43.734505623579025, 41.90178796648979, 50.416557267308235, 43.591994270682335, 44.807860627770424, 61.29866413772106, 26.534327678382397, 22.361021116375923, 6.102052666246891, 0.4457402176922187, 0.18443567591020837, 0.13471601181663573, 0.05227845198533032, 0.08439359022304416, 0.1351258999784477, 0.11154431340401061, 0.15878881851676852, 0.8832361840177327, 2.8183239698410034, 2.7848534658551216, 4.588617626577616, 9.275238644331694, 16.84197686612606, 8.20807920768857, 3.5623679822310805, 3.6332548409700394, 2.7240078058093786, 9.9334117770195, 21.07587307691574, 53.50603088736534, 73.00976112484932, 85.63843667507172, 90.36555781960487, 97.8317391872406, 81.75151884555817, 76.10073566436768, 53.39121624827385, 33.996882140636444, 23.61551620066166, 14.877843260765076, 9.588745571672916, 7.266642674803734, 17.79216717928648, 40.758984088897705, 68.82149666547775, 90.66310465335846, 75.63216000795364, 49.85222674906254, 91.14465281367302, 95.75506702065468, 106.68717160820961, 103.13115522265434, 107.79394581913948, 103.78510773181915, 105.57909786701202, 105.00422671437263, 105.46729266643524, 98.5108083486557, 90.13547256588936, 78.37109863758087, 56.573910266160965, 38.766469806432724, 24.60663791745901, 11.446170452982187, 7.930634245276451, 6.887386450544, 2.514566844329238, 3.053451790474355, 2.8863685810938478, 0.908422835636884, 0.48104213434271514, 0.27541797899175435, 0.08652160220663063, 0.17566065536811948, 0.09585076215444133, 0.12282576703000814, 2.3043476371094584, 22.96866361051798, 59.20918665826321, 75.53164780139923, 98.8965180516243, 166.76662176847458, 40.97399555146694, 16.99026770889759, 62.53072142601013, 73.21501851081848, 71.23929932713509, 85.11892095208168, 27.7803473174572, 1.699440402444452, 0.3367308061569929, 0.039017742456053384, 0.03942669922253117, 0.10370201664045453, 0.03506445536913816, 0.01975003397092223, 0.07796562655130401, 0.04643591295462102, 0.06033134057361167, 0.03325517725897953, 0.03945508266042452, 0.04175704292720184, 0.06123085695435293, 0.1747343214810826, 0.13538903585867956, 0.11633681366220117, 0.11503837435157038, 0.06817467263317667, 0.0881926367583219, 0.022719524531567004, 0.0327337999624433, 0.005714833969250321, 0.09133305691648275, 0.029073856021568645, 0.09915616174112074, 0.11169772275025025, 0.04333070399297867, 0.009866870059340727, 0.03202101535862312, 0.04726193074020557, 0.0228991261246847, 0.01967603813682217, 0.0339907606394263, 0.07066986960126087, 0.04984492377843708, 0.03470872914476786, 0.019713958172360435, 0.0725965369201731, 0.10862471928703599, 0.004147824402025435, 0.04226056786137633, 0.022486404814117122, 0.029681793712370563, 0.013548481929319678, 0.023541317641502246, 0.015995872527128085, 0.022115831925475504, 0.028114136621297803, 0.07530284521635622, 0.024447197938570753, 0.0048685778165236115, 0.037048884041723795, 0.06537536581163295, 0.04055603647429962, 0.04512609652010724, 0.005623423176075448, 0.07610052038216963, 0.012392849457683042, 0.01929619025759166, 0.06046613685612101, 0.0499470136128366, 0.053968466963851824, 0.01850424818258034, 0.0726506691717077, 0.09751364050316624, 0.10095739125972614, 0.11490843171486631, 0.038433156441897154, 0.04126373736653477, 0.05810966955323238, 0.13708905869862065, 0.04828805751458276, 0.08979955717222765, 0.032517085419385694, 0.10430610258481465, 0.07254865355207585, 0.07021538578555919, 0.03964165116485674, 0.0837698818941135, 0.06490245446912013, 0.17338166828267276, 10.374298319220543, 96.63351148366928, 37.596926763653755, 45.14236807823181, 92.02001184225082, 67.17642813920975, 67.80807584524155, 50.440739169716835, 40.791878923773766, 43.059680834412575, 50.71418769657612, 35.038322657346725, 28.577785827219486, 9.097050055861473, 0.41757411032449454, 0.08859389374265447, 0.11346493221935816, 0.12619413784705102, 0.45018119970336556, 0.628770844778046, 0.9630663378629833, 1.8280089972540736, 2.187339565716684, 4.658772312104702, 6.69292951002717, 7.040185276418924, 8.384842872619629, 5.908038401976228, 5.682565625756979, 1.905776693020016, 2.371284607797861, 1.951202186755836, 9.139670468866825, 22.029384411871433, 53.555470034480095, 76.4403386414051, 90.82891255617142, 93.31240609288216, 102.0269724726677, 90.6447896361351, 82.03256696462631, 58.80000941455364, 36.60435922443867, 21.349701583385468, 9.421018771827221, 3.5690057510510087, 5.869544567540288, 16.680211946368217, 42.043949738144875, 70.67348688840866, 91.67395681142807, 79.72918376326561, 54.51664745807648, 97.54885196685791, 102.93823957443237, 112.52896293997765, 106.86171904206276, 111.96488320827484, 109.09065663814545, 112.56265953183174, 110.2401253581047, 110.40457293391228, 105.5994875729084, 95.72172001004219, 83.65906968712807, 58.075494691729546, 42.50204935669899, 27.24721122533083, 12.49555254355073, 5.039993030950427, 5.517278295010328, 2.428134069778025, 4.220108175650239, 3.16208534874022, 1.6418733727186918, 0.6632253178395331, 0.37320199131499976, 0.04151576700678561, 0.08414855532464571, 0.10022112881415524, 0.22223278210731223, 3.2622026139870286, 23.42447765171528, 49.008983597159386, 54.78807829320431, 73.20263117551804, 147.6641348004341, 51.23865835368633, 35.432034730911255, 80.20545780658722, 82.41769149899483, 78.69763031601906, 104.45853799581528, 53.00263769924641, 6.392674371600151, 0.2607821737183258, 0.06548383069457486, 0.04123474165680818, 0.07312148765777238, 0.03666370197606739, 0.017016088095260784, 0.033629891331656836, 0.013468720535456669, 0.015842318462091498, 0.04462218566914089, 0.03663610892544966, 0.011734806594176916, 0.049765105795813724, 0.12622640642803162, 0.04456442802620586, 0.10487140389159322, 0.04027022427180782, 0.02805975018418394, 0.03497754987620283, 0.061152530688559636, 0.029743512568529695, 0.018439291707181837, 0.0695570711104665, 0.06031637887645047, 0.04499450631556101, 0.012018085290037561, 0.034447834550519474, 0.01551634122733958, 0.03157216815452557, 0.019259589389548637, 0.04734293615911156, 0.04306694841943681, 0.026046299826703034, 0.034412044478813186, 0.056086192780639976, 0.0410456869576592, 0.01858719431766076, 0.10578429748420604, 0.0035289240304337, 0.02073150571959559, 0.02709665957809193, 0.030832133743388113, 0.08124270578264259, 0.042536761829978786, 0.16623880859697238, 0.17279612860875204, 0.22814425552496687, 0.11869328838656656, 0.170678335998673, 0.1365366781828925, 0.09252782561816275, 0.11264366417890415, 0.15846300084376708, 0.08704584048246033, 0.180247291282285, 0.0962534366408363, 0.2231637469958514, 0.06590816105017439, 0.10013513616286218, 0.162699862557929, 0.10170989931793883, 0.23420626617735252, 0.1498337826342322, 0.15611049660947174, 0.2676210051868111, 0.15495751082198694, 0.15292562922695652, 0.2679883979726583, 0.277134922798723, 0.1512284710770473, 0.25124839623458683, 0.20077778259292245, 0.20400293375132605, 0.16568049089983106, 0.23610128089785576, 0.16039371286751702, 0.1818610171903856, 0.16235970659181476, 0.17991656059166417, 0.15262770146364346, 0.429315124056302, 15.768559165298939, 117.59650021791458, 50.98944492638111, 56.9603381305933, 103.34819197654724, 70.02054512500763, 60.5253030359745, 59.14101451635361, 58.74643228948116, 66.1422224342823, 88.40583577752113, 42.98571020364761, 40.098875910043716, 13.410403802990913, 1.2806702172383666, 0.44248925463762134, 0.38158784445840865, 0.32775037398096174, 0.4869126412086189, 0.4468194191576913, 0.6005904881749302, 1.2699110945686698, 2.4464621488004923, 7.116973930969834, 10.846471432596445, 12.644494101405144, 23.64006668329239, 32.12210454046726, 26.211168318986893, 20.390230268239975, 15.627828016877174, 13.45082888379693, 17.406432777643204, 28.369967378675938, 60.3664905577898, 83.4818547964096, 96.12014383077621, 101.08271554112434, 107.65754073858261, 92.76461228728294, 86.88337907195091, 63.08297619223595, 44.54224348068237, 36.98054663836956, 36.4822793751955, 22.309569977223873, 17.270869351923466, 24.00898888707161, 43.66314545273781, 69.94937494397163, 91.0169492661953, 85.79248800873756, 65.3619647026062, 99.93309482932091, 109.93932589888573, 117.36477345228195, 113.72513115406036, 120.6927640736103, 117.0418743789196, 116.90996065735817, 116.45302757620811, 115.34316793084145, 109.63484823703766, 99.65571731328964, 87.1598370373249, 60.6427813321352, 49.59415979683399, 33.48365128040314, 24.726975560188293, 21.322618536651134, 17.9300294816494, 6.974767511710525, 9.279358573257923, 5.923165865242481, 3.1772890454158187, 1.2130732694640756, 0.866602873429656, 0.1910710401716642, 0.23186563630588353, 0.18230670655611902, 0.2821123885223642, 5.595470974221826, 38.1579552590847, 85.7667937874794, 103.25293868780136, 116.26330375671387, 165.935879945755, 50.65575823187828, 24.586658589541912, 78.97792607545853, 89.59159255027771, 90.106350928545, 117.21908926963806, 53.259378522634506, 4.232246149331331, 0.35486996406689286, 0.17795675637898967, 0.2031607594108209, 0.3285628475714475, 0.15209106932161376, 0.10212409193627536, 0.22805044805863872, 0.1533933455357328, 0.11443578754551709, 0.1335916284006089, 0.1514024898642674, 0.09783001063624397, 0.20903609023662284, 0.3197126177838072, 0.15632975671906024, 0.20115088991587982, 0.17050128924893215, 0.21180338080739602, 0.15340440353611484, 0.16496805881615728, 0.11750626028515399, 0.05372079001972452, 0.24144282942870632, 0.13857311656465754, 0.1883410054142587, 0.2526765555376187, 0.16831793531309813, 0.11133243024232797, 0.12651729863137007, 0.17627027031267062, 0.08636211467091925, 0.17104801459936425, 0.13728056248510256, 0.12402622058289126, 0.1690839059301652, 0.1461062123416923, 0.12444320367649198, 0.21572537894826382, 0.14054724422749132, 0.07071911852108315, 0.09798428087378852, 0.08139003693941049, 0.16381997120333835, 0.15806308714672923], [0.09087497368454933, 0.08769403968472034, 0.08305172785185277, 0.08785941987298429, 0.05893870045838412, 0.04446792656381149, 0.05556635915127117, 0.1399290352128446, 0.1765707807498984, 0.22795392433181405, 0.13804628077195957, 0.041478637358522974, 0.04004739814263303, 0.0068474362069537165, 0.029233297173050232, 0.048688769020373, 0.05444205366075039, 0.02381832240644144, 0.14039308531209826, 0.10791625769343227, 0.08573413157137111, 0.04642763429728802, 0.0323636649409309, 0.12320951675064862, 0.20087408367544413, 0.10713805648265406, 0.2884447487303987, 0.3718025085981935, 0.28740737470798194, 0.14927487121894956, 0.4117720591602847, 0.13633640221087262, 0.22859194868942723, 0.08229953891714104, 0.16142529813805595, 1.1123422184027731, 14.851238038390875, 56.14366315305233, 92.4417132139206, 71.24412506818771, 34.87859442830086, 45.58823995292187, 17.643912434577942, 16.25955741852522, 50.66072076559067, 68.47259938716888, 38.79186764359474, 31.700311973690987, 11.902648508548737, 2.125459173694253, 0.12134393560700119, 0.2505353110609576, 0.11506430499139242, 0.11918823409359902, 0.15753789892187342, 0.31773105380125344, 0.417968665715307, 0.9844057552982122, 1.8247303669340909, 2.7966496953740716, 3.2542353915050626, 8.003840167075396, 7.14618343859911, 4.993467377498746, 4.1988468915224075, 9.745867140591145, 12.437563855201006, 27.149991542100906, 48.44762831926346, 77.23407045006752, 86.44068762660027, 95.305315554142, 100.61211839318275, 94.47556167840958, 92.73992121219635, 100.01159101724625, 98.03116008639336, 96.54831245541573, 88.39422360062599, 80.68846508860588, 56.093133464455605, 27.058482952415943, 25.631403028964996, 51.47582642734051, 114.7557270526886, 128.00364017486572, 141.38944029808044, 127.26497501134872, 147.27743715047836, 52.41903841495514, 93.60541597008705, 103.31164553761482, 94.46784809231758, 97.68710374832153, 86.74630522727966, 93.60248252749443, 91.48380741477013, 94.783253967762, 91.001256108284, 91.21154442429543, 93.91864836215973, 100.03732323646545, 92.36837714910507, 83.3801494538784, 63.65920767188072, 36.65599085390568, 26.967190951108932, 9.259005915373564, 7.779398085549474, 2.85717427264899, 2.002319418825209, 1.5184607449918985, 0.2702882542507723, 1.3361585210077465, 0.2440474709146656, 0.1579130842583254, 0.2223280441830866, 0.18593567510833964, 0.3209630772471428, 1.7318035033531487, 15.110126696527004, 45.495874509215355, 50.834306851029396, 36.426498368382454, 44.074518978595734, 20.992703139781952, 19.75497655570507, 56.02120332419872, 70.8959573507309, 72.215086966753, 74.7842887043953, 52.00375109910965, 5.73625816963613, 0.555011221440509, 0.05268777982564643, 0.044042746449122205, 0.04769846942508593, 0.13054658164037392, 0.18435939797200263, 0.07068113540299237, 0.20236667623976246, 0.06039159183274023, 0.04798431502422318, 0.23924044682644308, 0.297038551652804, 0.17626180982915685, 0.43420940986834466, 0.19531646627001464, 0.34201935050077736, 0.26175014209002256, 0.09706611061119474, 0.03408238248084672, 0.03458785926341079, 0.039702592621324584, 0.06714379240293056, 0.057274768259958364, 0.013307756125868764, 0.0392774792999262, 0.036143619727226906, 0.019879713145201094, 0.05184209512663074, 0.052057570283068344, 0.0682591216173023, 0.2649314620066434, 0.046352792414836586, 0.2600658230949193, 0.11768678028602153, 0.012809792660846142, 0.03954825930122752, 0.033402671688236296, 0.09532365918857977, 0.07537708966992795, 0.025000363275466952, 0.10028412973042578, 0.04582253532134928, 0.03203008069249336, 0.06272341241128743, 0.02627438778290525, 0.09508128117886372, 0.031021852664707694, 0.04786986100953072, 0.04452313492947724, 0.07858376877265982, 0.09931041713571176, 0.11362600795109756, 0.0942330360703636, 0.07616377362865023, 0.07697977984207682, 0.04667256900575012, 0.04192706153844483, 0.04399537145218346, 0.045424577183439396, 0.05261403632175643, 0.035094345366815105, 0.036683758517028764, 0.08098276855889708, 0.05732938661822118, 0.03615388734033331, 0.06671479393844493, 0.04234236366755795, 0.2548204123741016, 0.12226869614096358, 0.2554845158010721, 0.23393907817080617, 0.23410710040479898, 0.23872575256973505, 0.305963916471228, 0.10526700571062975, 0.2076005985145457, 0.18890517123509198, 0.05469098483445123, 0.7422842911910266, 18.0470822006464, 80.98196893930435, 108.16601425409317, 82.10525706410408, 41.87295891344547, 66.573636084795, 32.911648973822594, 26.414601802825928, 59.72638450562954, 54.814289286732674, 39.98486302793026, 36.86130903661251, 16.312971152365208, 3.0822124471887946, 0.04061717459990177, 0.2777013892773539, 0.10079868297907524, 0.11047291933209635, 0.3484561457298696, 1.515853253658861, 2.2048817994073033, 4.225782221183181, 5.116534698754549, 6.1271123215556145, 6.257199291139841, 6.0238580871373415, 3.759147785604, 1.788736917078495, 0.026315552859159652, 3.9663653913885355, 13.651375472545624, 28.82837288081646, 52.43793100118637, 80.54568395018578, 91.4395397901535, 100.65767034888268, 104.29687187075615, 97.46247500181198, 98.48262906074524, 103.92541900277138, 101.12433090806007, 99.91503059864044, 94.80961695313454, 86.49128571152687, 60.13040542602539, 29.26233619451523, 28.753866478800774, 56.60834401845932, 121.8533281981945, 138.0962786078453, 151.01225674152374, 138.0394944548607, 154.8825466632843, 61.92567229270935, 91.43760949373245, 107.6102864742279, 96.70437768101692, 100.09409219026566, 90.99082186818123, 98.07380899786949, 97.48366266489029, 101.0855121910572, 99.24651727080345, 100.3826031088829, 102.18352407217026, 107.44029879570007, 101.07013061642647, 89.19544100761414, 69.8455873131752, 42.664984613657, 30.525511913001537, 8.897148482501507, 1.747910245321691, 1.6151349199935794, 3.814823585562408, 1.9620151002891362, 2.1302925143390894, 3.8872070889919996, 0.5208575853612274, 0.18247089930810034, 0.19331281597260386, 0.07352742017246783, 0.2499511220958084, 0.751743942964822, 15.691713988780975, 38.73552426695824, 54.552559331059456, 46.791430190205574, 40.111514031887054, 24.723707735538483, 39.24136832356453, 85.72412967681885, 88.59362170100212, 79.45303738117218, 86.59559771418571, 77.91001617908478, 20.82660835236311, 0.7311301084700972, 0.1591633359203115, 0.013521107812266564, 0.05390622674894985, 0.03197024132532533, 0.2096382837044075, 0.043003168248105794, 0.15158360358327627, 0.03205190354492515, 0.08059804662480019, 0.08256240020273253, 0.19519432360539213, 0.137314107560087, 0.36397172254510224, 0.1691706184647046, 0.299803497036919, 0.22870926739415154, 0.12620430527022108, 0.07683820032980293, 0.01732094751787372, 0.017891746283567045, 0.05457071238197386, 0.10212524226517417, 0.07368537888396531, 0.03038778766494943, 0.047704347234684974, 0.03799892954702955, 0.006845400403108215, 0.06691502538160421, 0.07309022839763202, 0.15515915234573185, 0.10921514971414581, 0.13881774328183383, 0.08564658783143386, 0.07950384635478258, 0.01817623746319441, 0.07475475431419909, 0.06643515269388445, 0.048572006926406175, 0.07622251461725682, 0.11028062886907719, 0.0662760139675811, 0.07836844946723431, 0.1972253739950247, 0.2084764515166171, 0.15258303901646286, 0.15378711425000802, 0.21580956818070263, 0.13087545696180314, 0.17116454662755132, 0.2289992244914174, 0.31462368147913367, 0.3454470040742308, 0.16972501762211323, 0.21734677866334096, 0.09241382431355305, 0.11469588804175146, 0.09865106345387176, 0.12173247218015604, 0.14999655046267435, 0.12868131219875067, 0.24509590293746442, 0.1921910746023059, 0.18141209206078202, 0.10907351825153455, 0.10840390808880329, 0.17327413108432665, 0.4682995774783194, 0.2934771927539259, 0.6259566207882017, 0.451689837500453, 0.42767910403199494, 0.30491113546304405, 0.4528352682245895, 0.2492833079304546, 0.4160900821443647, 0.2583816822152585, 0.22109453537268564, 1.2535579595714808, 27.040673308074474, 102.4991275370121, 125.90378165245056, 92.48246982693672, 55.52254468202591, 69.34509336948395, 29.06793862581253, 28.16400323063135, 71.41902968287468, 94.99510779976845, 55.699463188648224, 48.73039774596691, 24.09530695527792, 4.705416709184647, 0.4016107216011733, 0.41085844568442553, 0.4591090581379831, 0.3785129188327119, 0.5697506899014115, 1.4462330332025886, 2.6132717728614807, 4.6427723206579685, 6.649328749626875, 9.90613304078579, 13.760513216257095, 20.25373589247465, 19.39967092126608, 20.18322877585888, 18.762798495590687, 24.6350109949708, 23.038264475762844, 35.79306095838547, 54.330487847328186, 84.62128445506096, 90.2246005833149, 102.38726153969765, 108.20948392152786, 100.03425300121307, 99.82546180486679, 107.90244519710541, 102.195303440094, 101.4870822429657, 97.94559627771378, 90.60287028551102, 65.52097097039223, 36.673405319452286, 35.15737026929855, 62.09999553859234, 121.50544926524162, 137.90751993656158, 145.86775839328766, 134.57833617925644, 148.77080261707306, 74.27127063274384, 95.12158021330833, 112.96735301613808, 100.70500820875168, 104.80363547801971, 95.2114985883236, 103.71919646859169, 100.2580001950264, 103.49725037813187, 102.15133979916573, 100.26782646775246, 107.17978477478027, 110.40407136082649, 104.67840179800987, 92.71493375301361, 77.80162319540977, 47.50681020319462, 35.419841185212135, 20.088003985583782, 18.58321823179722, 7.931806957349181, 7.53304922953248, 7.045751502737403, 2.976767630316317, 5.883683608844876, 0.4909383470658213, 0.17257582949241623, 0.2968612080439925, 0.35281347285490483, 0.4161052516428754, 3.2283746916800737, 22.59893774986267, 68.22489827871323, 70.44162333011627, 49.92425188422203, 56.50052100419998, 27.829533778131008, 30.704896487295628, 77.8859330713749, 91.0925880074501, 84.84331414103508, 100.51522359251976, 89.10972520709038, 16.97878472507, 0.7548416673671454, 0.2519813709659502, 0.13674658723175526, 0.28555515222251415, 0.3097659390186891, 0.3609273734036833, 0.1290210970910266, 0.2134588747867383, 0.3199434850830585, 0.30855398217681795, 0.20292665634769946, 0.42776991322170943, 0.35304481512866914, 0.6336773908697069, 0.31188670021947473, 0.43536704150028527, 0.37297777365893126, 0.18275244045071304, 0.15922077815048397, 0.07401406124699861, 0.08352210847078823, 0.12949541851412505, 0.19262808084022254, 0.13344351056730375, 0.10633295241859742, 0.10269550111843273, 0.17889137263409793, 0.1308320413227193, 0.140140576986596, 0.15934783383272588, 0.38758267590310425, 0.32510669552721083, 0.27504859725013375, 0.21412290399894118, 0.1285531432949938, 0.13806456729071215, 0.16914347070269287, 0.1317962841130793, 0.24353887711185962, 0.17055159201845527, 0.21724204678321257, 0.13022307946812361, 0.09609017899492756], [0.05179259016586002, 0.018521694219089113, 0.06151747809781227, 0.06599350803298876, 0.006480568954430055, 0.028086380298191216, 0.05731372730224393, 0.13263275875942782, 0.07297981908777729, 0.06700969373923726, 0.055867084811325185, 0.034391605731798336, 0.04413904753164388, 0.06142357786302455, 0.03568061234545894, 0.037672681428375654, 0.019798726279987022, 0.026204503446933813, 0.16880877694347873, 0.02130043983925134, 0.05607806255284231, 0.039188607115647756, 0.12981377018149942, 0.18614289758261293, 0.2602161525283009, 0.2345988029264845, 0.348594689858146, 0.5178588931448758, 0.14977935352362692, 0.03046351826924365, 0.12416756260790862, 0.15543244080618024, 0.10498670395463705, 0.06136046562460251, 2.9406398814171553, 29.404277577996254, 70.3121642768383, 85.05509197711945, 80.29612854123116, 64.06495749950409, 56.49288721382618, 37.83633291721344, 59.98628295958042, 67.14745849370956, 54.10527013242245, 34.81716692447662, 27.868899665772915, 7.089172247797251, 0.5939806834794581, 0.09894723974866793, 0.2664414653554559, 0.16796783456811681, 0.1979021681472659, 0.25455819675698876, 0.24554329924285412, 1.567266513593495, 1.3355405791662633, 1.8174906866624951, 5.291547132655978, 3.2713838713243604, 4.822451379150152, 3.49560318980366, 8.216327615082264, 9.462582841515541, 38.006658777594566, 45.748104974627495, 70.06257846951485, 104.6653001010418, 97.91452914476395, 101.09704077243805, 93.1759250164032, 93.04942220449448, 89.70801070332527, 87.64368787407875, 83.8933727145195, 91.87397047877312, 100.8492636680603, 100.45556679368019, 95.75918599963188, 91.63552567362785, 91.9055087864399, 69.83655899763107, 63.78552809357643, 104.56389874219894, 112.62423142790794, 82.2678579390049, 84.80310469865799, 75.30919253826141, 98.37437286973, 48.9295868575573, 79.92399170994759, 96.90297782421112, 105.86936429142952, 100.53081035614014, 88.99608850479126, 81.48243248462677, 80.63257768750191, 83.13173398375511, 80.39768189191818, 81.98646783828735, 90.8374696969986, 96.57766968011856, 97.75493010878563, 95.0953920185566, 79.2325884103775, 88.33740904927254, 67.93723091483116, 42.66986735165119, 10.346901789307594, 1.6083964565768838, 2.328771776519716, 0.3984005766687915, 1.991372206248343, 2.667612419463694, 0.2789700758876279, 0.22625615762080997, 0.10708038418670185, 0.1498132845154032, 0.26133537059649825, 0.05896213377127424, 0.0364920877473196, 9.155551716685295, 27.33866471797228, 44.562910571694374, 64.96831342577934, 68.20339903235435, 31.453055441379547, 9.615868516266346, 29.76036787033081, 61.24028027057648, 59.45890925824642, 67.90839046239853, 67.31571346521378, 23.330843076109886, 0.7254247739911079, 0.04998360149329528, 0.13899473065976053, 0.17646183347096667, 0.09569119298248552, 0.06331889686407521, 0.21851707133464515, 0.06780251525924541, 0.06998039956670254, 0.5275335302576423, 0.23652452771784738, 0.17700655502267182, 0.35349132085684687, 0.36046516383066773, 0.1853189800749533, 0.3124168608337641, 0.10867852499359287, 0.02314565088454401, 0.017469989325036295, 0.04831402897252701, 0.04754534951644018, 0.027484856618684717, 0.013780319586658152, 0.07924977209768258, 0.06533897831104696, 0.027723483071895316, 0.06450301574659534, 0.02352089559281012, 0.10103361724759452, 0.04926970366796013, 0.11807637813035399, 0.15175867622019723, 0.021073418720334303, 0.01440613097656751, 0.03130689117824659, 0.018080496702168602, 0.03906558129529003, 0.0719232605479192, 0.021512143030122388, 0.15767230186611414, 0.11538023725734092, 0.1034438754140865, 0.0027207959465158638, 0.02674785202543717, 0.025835112428467255, 0.07328128689550795, 0.06451936525991186, 0.04167605235124938, 0.09442094044061378, 0.08288478915346786, 0.014615758936997736, 0.11041740668588318, 0.07457626037648879, 0.05945730583334807, 0.02589128187537426, 0.022815957345301285, 0.019554225727915764, 0.0638596479257103, 0.032318052544724196, 0.04957028089847881, 0.06297718980931677, 0.07846011954825372, 0.021954954718239605, 0.03714138161740266, 0.09365540026919916, 0.08901185647118837, 0.22531643538968638, 0.18085187446558848, 0.2386357745854184, 0.33402915112674236, 0.11945951875532046, 0.08513427586876787, 0.05052003325545229, 0.0839236103638541, 0.06719651457387954, 0.2418858915916644, 3.3793185045942664, 36.67085185647011, 94.80870500206947, 101.62795588374138, 97.62637540698051, 90.66998228430748, 76.54894441366196, 38.6532586812973, 33.907761722803116, 42.05364301800728, 38.7516999989748, 35.007707700133324, 31.35528288781643, 9.960018899291754, 0.7165017246734351, 0.11738652960048057, 0.2680662047350779, 0.28307566652074456, 0.18579903087811545, 0.418015094473958, 1.0723245469853282, 3.454489395953715, 3.713703411631286, 2.4162411829456687, 3.6233829706907272, 4.574789218604565, 3.0208623642101884, 3.2147999200969934, 6.048294100910425, 12.014805190265179, 39.92820046842098, 54.244126081466675, 76.46198987960815, 108.6682941019535, 103.05734798312187, 104.59815010428429, 97.152069658041, 96.83962762355804, 93.60097020864487, 92.17312082648277, 85.7770000398159, 93.09015601873398, 98.7312725186348, 101.9767239689827, 100.98772823810577, 94.14776846766472, 96.5768413245678, 79.28567916154861, 70.99874183535576, 112.67843171954155, 125.37680312991142, 93.48310813307762, 96.39692857861519, 89.50589194893837, 107.0966300368309, 59.301506504416466, 79.56137716770172, 100.00621050596237, 108.75400230288506, 108.07978928089142, 96.53024822473526, 88.14792841672897, 83.90781953930855, 88.92915889620781, 85.26671782135963, 87.47727960348129, 96.02397099137306, 98.95313501358032, 101.7510236799717, 99.01671320199966, 87.4457260966301, 93.69674786925316, 74.63472113013268, 49.06705588102341, 15.338712930679321, 1.8326790654100478, 1.4624151773750782, 1.5466497698798776, 1.859217791352421, 2.2469415049999952, 0.2963677985826507, 0.7420865830499679, 0.25790691550355405, 0.18227035616291687, 0.1951732169254683, 0.03980379558925051, 0.09516839447314851, 8.691714406013489, 30.373293980956078, 46.683067604899406, 45.29967203736305, 32.02241688966751, 21.380878910422325, 22.89505586028099, 58.50669175386429, 87.5278852880001, 72.9353079199791, 79.12251591682434, 94.51325565576553, 45.83492271602154, 3.213711753487587, 0.18799137964379042, 0.13183726550778374, 0.015749991580378264, 0.04224109390634112, 0.11917246345547028, 0.10163740633288398, 0.08522530770278536, 0.13051211630227044, 0.35783858445938677, 0.18123013229342178, 0.2196643574279733, 0.208938364230562, 0.2791539503959939, 0.1904914079932496, 0.24265852669486776, 0.02840365399606526, 0.062290050118463114, 0.015539233700110344, 0.0138105852965964, 0.053258187108440325, 0.000831699505852157, 0.06290114193689078, 0.04742866163724102, 0.02660629848833196, 0.028328678527032025, 0.04565393792290706, 0.11993165826424956, 0.09521645595668815, 0.08652890493976884, 0.15998753544408828, 0.1489504487835802, 0.023512327497883234, 0.06367280482663773, 0.055088249064283445, 0.0464855143945897, 0.07811988194589503, 0.06279479217482731, 0.0212799547080067, 0.09254114716895856, 0.075757039594464, 0.05918418806686532, 0.1020559182506986, 0.07894241905887611, 0.11919375567231327, 0.223243112268392, 0.1934176665963605, 0.10723787534516305, 0.15603349136654288, 0.2288335474440828, 0.1926757415640168, 0.2937763376394287, 0.1523220702074468, 0.17201351904077455, 0.0970404916733969, 0.17533203237690032, 0.10713475392549299, 0.10596400854410604, 0.09562519378960133, 0.11035073213861324, 0.28276221302803606, 0.2553939737845212, 0.1490302148158662, 0.13971403503092006, 0.18375769432168454, 0.2799831668380648, 0.48238224524538964, 0.4449620906962082, 0.5753524205647409, 0.5854723462834954, 0.35531320434529334, 0.2817005559336394, 0.23390045680571347, 0.3358469676459208, 0.3136037033982575, 0.49494790378957987, 6.6593545116484165, 51.796966195106506, 116.90949708223343, 119.7357626259327, 108.79600524902344, 95.42920410633087, 79.57176581025124, 55.802221074700356, 82.0065687596798, 92.46460318565369, 72.04757675528526, 53.86194258928299, 46.91200911998749, 15.57627808302641, 1.212709320243448, 0.45044204976875335, 0.6620897131506354, 0.4586500843288377, 0.25355888006743044, 0.7838118472136557, 2.400347823277116, 5.445930948480964, 7.600526958703995, 5.698695285245776, 10.912718027830124, 14.61067484691739, 13.566660918295383, 15.884500443935394, 21.781510412693024, 19.22086201608181, 46.73011288046837, 57.72802613675594, 82.22467705607414, 106.53764963150024, 104.41548630595207, 107.56924107670784, 101.95332482457161, 97.22654566168785, 95.28352752327919, 93.77342775464058, 90.2333477139473, 94.85399097204208, 99.50157478451729, 103.98516699671745, 109.87698644399643, 100.43680340051651, 100.18624484539032, 92.12887600064278, 82.87419140338898, 123.06952893733978, 126.17694139480591, 99.1422888636589, 103.9288692176342, 96.46443575620651, 115.8702452480793, 63.73694010078907, 88.46933797001839, 104.77715849876404, 113.20023491978645, 114.75673779845238, 103.01455467939377, 91.16612926125526, 90.55284217000008, 93.50622609257698, 89.51813489198685, 89.50032904744148, 96.68509751558304, 100.96037730574608, 102.39393398165703, 99.73539903759956, 91.79568707942963, 92.20104172825813, 81.64721444249153, 53.85391362011433, 17.8701313957572, 7.040139203891158, 6.6749450750648975, 4.7419194504618645, 5.724892979487777, 5.638306075707078, 1.2146006687544286, 1.5208771778270602, 0.27159102028235793, 0.3511135093867779, 0.5322150571737438, 0.29003591334912926, 0.24501340580172837, 15.300802364945412, 45.582578256726265, 71.66511967778206, 90.08245021104813, 92.78166577219963, 44.987735375761986, 18.03831797093153, 46.34278826415539, 84.92735043168068, 76.0095177590847, 88.99986550211906, 110.6402362883091, 46.501254960894585, 1.819608835503459, 0.20485475601162761, 0.3717467881506309, 0.29250503866933286, 0.40461208554916084, 0.38148067833390087, 0.28846027445979416, 0.2850691642379388, 0.2742961485637352, 0.8595448709093034, 0.4145491757662967, 0.3336666862014681, 0.5691533500794321, 0.5728775658644736, 0.39542972983326763, 0.5087637843098491, 0.22568498592590913, 0.11789996962761506, 0.11880405392730609, 0.11939811345655471, 0.17243964539375156, 0.08828139762044884, 0.17628794827032834, 0.17720527248457074, 0.09345983693492599, 0.11335015165968798, 0.3165746689774096, 0.19517296459525824, 0.1745234476402402, 0.22130505298264325, 0.30742654111236334, 0.48335793195292354, 0.1709471270442009, 0.11120822440716438, 0.23082901927409694, 0.1095217680267524, 0.25435051415115595, 0.16442121472209692, 0.09867339467746206, 0.20939482958056033, 0.21828434866620228, 0.19428918545600027], [0.09032159869093448, 0.07571274079964496, 0.06213425476744305, 0.08736140167457052, 0.0566443768911995, 0.07250181661220267, 0.07285132363904268, 0.09322613463154994, 0.06286044255830348, 0.05937368805462029, 0.03269858134444803, 0.045043888821965083, 0.03609253770264331, 0.02358750149141997, 0.0401142656482989, 0.05028960753406864, 0.04798575479071587, 0.015548092160315719, 0.18279926996910945, 0.025272273196605965, 0.016651237165206112, 0.03694519116834272, 0.08453367059701122, 0.08379365288419649, 0.1132243947358802, 0.1467722305096686, 0.223580002784729, 0.07843227416742593, 0.1171324479219038, 0.138870554510504, 0.15838884544791654, 0.032000506107578985, 0.7158907293342054, 12.257916145026684, 62.967166006565094, 90.27123168110847, 83.65877330303192, 80.03714203834534, 46.695561334490776, 32.01238542795181, 29.22162137925625, 41.687376871705055, 71.68325990438461, 80.58700293302536, 52.194158881902695, 16.725762002170086, 1.6951455641537905, 0.18821335601387545, 0.07683500167331658, 0.09804935980355367, 0.007813897555024596, 0.3285784920444712, 0.2240651595639065, 0.3841102262958884, 0.4537716507911682, 2.451589023694396, 4.617442404851317, 5.3146403934806585, 6.076676677912474, 4.035737318918109, 4.165861336514354, 15.484589952975512, 52.42505729198456, 89.36867371201515, 102.3275363445282, 92.02001184225082, 94.66712459921837, 98.83217990398407, 88.36111977696419, 85.90795621275902, 82.4261574447155, 83.6113366484642, 87.24384292960167, 90.65653860569, 90.21566346287727, 95.68823620676994, 92.97965034842491, 89.45475429296494, 90.8883261680603, 94.1817158460617, 96.10831886529922, 91.91176325082779, 50.472106486558914, 57.96666093170643, 78.39563772082329, 78.0125042796135, 78.26611787080765, 69.44989934563637, 87.59031593799591, 35.58284103870392, 65.88152602314949, 106.86550363898277, 100.6225374341011, 97.44900092482567, 92.36450135707855, 93.83566841483116, 86.11061453819275, 75.13646140694618, 73.16379725933075, 76.63137719035149, 89.58675161004066, 93.92896860837936, 93.15308824181557, 92.98076748847961, 98.45368981361389, 104.12873089313507, 98.3577373623848, 80.2826164662838, 47.89738744497299, 15.751347988843918, 1.7521172133274376, 1.1103229830041528, 0.6845901464112103, 0.48208443622570485, 1.5372348250821233, 1.2439719052053988, 0.40276784857269377, 0.14722237276146188, 0.13084302510833368, 0.05477659899042919, 0.13789569900836796, 0.07721890724496916, 3.3422716800123453, 23.62427093088627, 54.97872166335583, 87.36453965306282, 124.98068958520889, 62.02478237450123, 20.119401700794697, 15.078804977238178, 44.492842331528664, 70.64894020557404, 65.55798098444939, 76.89175441861153, 38.38984161615372, 4.722052691504359, 0.28735204017721117, 0.08504560406436212, 0.05164361144124996, 0.015024143322079908, 0.07018828255240805, 0.0194413005374372, 0.11566096203750931, 0.2317255039815791, 0.11734939253074117, 0.1395435637095943, 0.22131076751975343, 0.23382780054816976, 0.07453824757249095, 0.034515978550189175, 0.05913264219998382, 0.013195188093959587, 0.026548494461167138, 0.0979925187129993, 0.010017141976277344, 0.04087727138539776, 0.054129987984197214, 0.03053805216040928, 0.10655404563294724, 0.04054580596857704, 0.03156281709379982, 0.02465234611008782, 0.02725098362134304, 0.06898446707054973, 0.18582080549094826, 0.13564642751589417, 0.08537796005839482, 0.027062580156780314, 0.04294611564546358, 0.09315012386650778, 0.029939383894088678, 0.026321131954318844, 0.03728420051629655, 0.07066562451655045, 0.07368436956312507, 0.06482751239673235, 0.035457990306895226, 0.031481514815823175, 0.08574118939577602, 0.05498105696460698, 0.0293996031905408, 0.044729281289619394, 0.06868696233141236, 0.027621795852610376, 0.10150275847990997, 0.14182142273057252, 0.0789391907164827, 0.011375359426892828, 0.05044331002864055, 0.04455468733794987, 0.0220993005859782, 0.023123579412640538, 0.10489243635674939, 0.11320482430164702, 0.08107995279715396, 0.03168248098518234, 0.013022237071709242, 0.010396051966381492, 0.12321551330387592, 0.12536627211375162, 0.22900817479239777, 0.11044436148949899, 0.2802845975384116, 0.07889623520895839, 0.14360498171299696, 0.1258383967797272, 0.27307662181556225, 0.06142211954283994, 0.8700232836417854, 12.81170317903161, 79.97019723057747, 114.02442589402199, 104.99822303652763, 96.56727343797684, 67.62836068868637, 52.54608079791069, 54.38106693327427, 47.495247423648834, 68.49969953298569, 74.43483665585518, 48.29666621983051, 22.29234740138054, 3.075309405103326, 0.07481546199414879, 0.2044235385255888, 0.29323988361284137, 0.056000730764935724, 0.379020458785817, 0.19217685505282134, 0.6516738783102483, 0.27595799532718956, 3.910718089900911, 4.4969142973423, 2.8232748666778207, 6.393047226592898, 1.9489490264095366, 1.0995352431200445, 17.908800020813942, 55.66936120390892, 95.39816737174988, 104.90958899259567, 98.76598745584488, 100.34064576029778, 104.36889320611954, 90.21489590406418, 90.74577301740646, 86.59368261694908, 87.5410021841526, 89.44276213645935, 93.50300386548042, 93.13739508390427, 97.68714934587479, 93.11927765607834, 90.01662254333496, 93.59078675508499, 97.78236463665962, 100.20625457167625, 92.85459145903587, 57.67900876700878, 65.78238174319267, 89.75092560052872, 84.59364473819733, 85.7113091647625, 78.21750327944756, 98.07675763964653, 40.95013663172722, 66.96743935346603, 108.41160267591476, 101.73188790678978, 102.25942119956017, 96.08396977186203, 96.02158471941948, 89.99402895569801, 81.1103792488575, 77.61694550514221, 81.0926266014576, 94.56703037023544, 99.05888333916664, 101.22383996844292, 94.93852123618126, 98.66042152047157, 107.37294360995293, 103.34590449929237, 86.08438074588776, 53.66281807422638, 20.1730415225029, 1.5172340045683086, 0.6516781530808657, 0.931826017331332, 2.14364571031183, 5.805594949051738, 2.7729394426569343, 1.5666717267595232, 0.13819561572745442, 0.39791586517822, 0.0984722949215211, 0.043620816941256635, 0.03677818567666691, 3.3366660308092833, 24.05073344707489, 40.61896540224552, 74.32784959673882, 97.20588237047195, 46.25094719231129, 24.336679503321648, 26.726821549236774, 64.88890528678894, 90.10499060153961, 73.65983784198761, 93.92250895500183, 61.76915109157562, 11.748432833701372, 0.4906706395559013, 0.07382732204860076, 0.058611958811525255, 0.04963201274222229, 0.047934873146004975, 0.0127745016834524, 0.04756274545798078, 0.1797445901320316, 0.12525398517027497, 0.13493067061062902, 0.2641952515114099, 0.13906983600463718, 0.17386142222676426, 0.06216004068846814, 0.014815259364695521, 0.07627057610079646, 0.022026347469363827, 0.11809040472144261, 0.04713560236268677, 0.01587143291544635, 0.04053929733345285, 0.08031544421100989, 0.052100755856372416, 0.009592292117304169, 0.12799702235497534, 0.06974230374908075, 0.10610172888846137, 0.019552125449990854, 0.12744179199216887, 0.20662408060161397, 0.04269781529728789, 0.047031675712787546, 0.039860295291873626, 0.04462971104658209, 0.08391890514758416, 0.03983825350587722, 0.018655444073374383, 0.06815962929977104, 0.06400660058716312, 0.10699633596232161, 0.18087163043674082, 0.12904904637252912, 0.20739998115459457, 0.161309716058895, 0.16668182623106986, 0.16902741364901885, 0.14184643310727552, 0.13675659138243645, 0.198417114734184, 0.14524361409712583, 0.15106962178833783, 0.15909529582131654, 0.1634174451464787, 0.1504897075938061, 0.1076638161612209, 0.11502933499286883, 0.22909923631232232, 0.10127834786544554, 0.2505063673015684, 0.11402909804019146, 0.10380352759966627, 0.12874384556198493, 0.40637679398059845, 0.3146547032520175, 0.37953447026666254, 0.20155556820100173, 0.5941425310447812, 0.1998892388655804, 0.3187672107014805, 0.28745006304234266, 0.5084268492646515, 0.1648394000949338, 1.791016438510269, 21.542360745370388, 104.34068351984024, 134.61893320083618, 119.31409925222397, 105.72069346904755, 67.17009767889977, 44.16069835424423, 50.073488876223564, 65.23438274860382, 92.20294922590256, 103.55981782078743, 79.23565864562988, 31.764771714806557, 3.508191676810384, 0.6122387631330639, 0.3803636570228264, 0.4836661310400814, 0.24383466748986393, 0.6692996481433511, 1.4914082153700292, 3.1101264618337154, 3.0211981711909175, 6.872660340741277, 11.08166741207242, 14.343318343162537, 17.33622394502163, 13.303603883832693, 13.406547959893942, 21.574522219598293, 59.59019601345062, 96.00860461592674, 105.11825859546661, 97.89103880524635, 103.81052076816559, 107.41722643375397, 94.25080373883247, 91.28608882427216, 88.40468063950539, 87.86110460758209, 92.03881323337555, 95.63101887702942, 93.21583047509193, 98.63494768738747, 94.51225250959396, 90.9692770242691, 96.33002936840057, 100.4308833181858, 105.26643544435501, 99.2829193174839, 66.29723891615868, 72.77820155024529, 103.52989822626114, 93.95979255437851, 95.16715496778488, 85.9673622250557, 103.0462221801281, 47.453803047537804, 73.78418996930122, 110.11559844017029, 104.35785099864006, 105.79128608107567, 100.30348375439644, 100.2884441614151, 93.22991251945496, 83.68882969021797, 78.97514462471008, 82.77647584676743, 98.070297986269, 103.68080332875252, 103.88539955019951, 98.83955150842667, 98.79873409867287, 110.53872853517532, 109.4569493830204, 87.29251071810722, 55.45292481780052, 22.762032598257065, 6.798318279907107, 7.698330385610461, 3.3745200745761395, 2.9628276033326983, 8.570306170731783, 4.0937326569110155, 1.8867823434993625, 0.7362555584404618, 0.48769587418064475, 0.1708167465403676, 0.2818411187035963, 0.21850815071957186, 6.712417239323258, 40.13452559709549, 80.95796942710876, 111.24079406261444, 144.52150583267212, 79.90821495652199, 29.512763656675816, 20.33976897597313, 61.382008865475655, 95.29264703392982, 82.8318464756012, 111.63430854678154, 69.11824554204941, 10.196863990277052, 0.5020323861390352, 0.21772948937723413, 0.23415318777551875, 0.17489171616034582, 0.19458111666608602, 0.18258419557241723, 0.25342006876599044, 0.38923665590118617, 0.2310784996370785, 0.310469405958429, 0.49366817402187735, 0.3174662555102259, 0.291386058088392, 0.23114901850931346, 0.14498524280497804, 0.14699101564474404, 0.13735240238020197, 0.28396351262927055, 0.15655559225706384, 0.1665699400473386, 0.19690451386850327, 0.223787997092586, 0.2764109428972006, 0.1194194947311189, 0.15144844364840537, 0.1772680730209686, 0.17944406485185027, 0.17475152446422726, 0.21494312561117113, 0.3466827393276617, 0.1550090455566533, 0.1516926844487898, 0.1258920837426558, 0.18588394741527736, 0.20195926685119048, 0.1770423265406862, 0.08033743404666893, 0.1497392330202274, 0.24901643162593246, 0.23413936898577958], [0.10086290843901224, 0.04714251175755635, 0.016022198360587936, 0.047117167414398864, 0.006651000849160482, 0.018923580173577648, 0.05238883903075475, 0.06123296465375461, 0.09923081437591463, 0.11912627960555255, 0.05731212797400076, 0.04469653402338736, 0.030906135143595748, 0.061076813071849756, 0.02739492316322867, 0.0054458137856272515, 0.08878587992512621, 0.059940150822512805, 0.066548523172969, 0.0025138404134850134, 0.04031982200103812, 0.07041769524221309, 0.20335239678388461, 0.04254551175108645, 0.06415771669708192, 0.10999042686307803, 0.14274604967795312, 0.20912281761411577, 0.02270441997097805, 0.06417786600650288, 0.11292847819277085, 3.2423097314313054, 32.929736003279686, 79.34146776795387, 92.6513859629631, 74.82685402035713, 57.69642323255539, 41.60711757838726, 25.85313443094492, 32.50524178147316, 37.915915846824646, 35.55850714445114, 31.572190448641777, 27.029216922819614, 6.752109909430146, 0.47758286527823657, 0.16734771081246436, 0.14225179416825995, 0.10648068433511071, 0.32992038410156965, 0.4282346460968256, 0.5003467609640211, 0.2595806960016489, 0.11978631606325507, 0.13658865820616484, 1.9377333344891667, 1.8832779815420508, 2.4096190882846713, 1.5997050167061388, 2.1573955100029707, 30.637469105422497, 84.83447581529617, 99.13990259170532, 92.35335275530815, 85.38212522864342, 94.9778263270855, 99.21788960695267, 92.42493331432343, 82.67266541719437, 75.6394936144352, 80.50327062606812, 89.1206306219101, 95.73400095105171, 92.52866014838219, 89.60919320583344, 91.28358855843544, 88.08836281299591, 84.65470746159554, 91.9233450293541, 91.84811666607857, 97.5218278169632, 94.0480238199234, 67.631476521492, 41.07675723731518, 79.27833035588264, 67.90069967508316, 74.21988219022751, 68.55661287903786, 83.03267329931259, 28.52113276720047, 85.61984047293663, 104.65129405260086, 93.12230989336967, 97.46054470539093, 93.31239089369774, 97.75857031345367, 96.05833634734154, 79.61767494678497, 72.75056943297386, 70.8476847410202, 82.76965901255608, 91.35267645120621, 95.03129705786705, 96.81431338191032, 99.65775400400162, 91.61683067679405, 87.56485730409622, 96.05642884969711, 91.96155577898026, 56.50164194405079, 14.451249651610851, 1.4285828615538776, 0.5644491431303322, 0.999059253372252, 2.1584981633350253, 1.1025413568131626, 1.2513129925355315, 1.2213203706778586, 0.2508026920258999, 0.057610894364188425, 0.003312960911898699, 0.0775084932683967, 0.04108892448130064, 1.6956308693625033, 20.341927260160446, 40.62977962195873, 45.516488403081894, 75.06091386079788, 101.91152706742287, 50.306974947452545, 25.574730969965458, 27.016208320856094, 50.201526805758476, 55.37243373692036, 66.19819343090057, 54.0154467523098, 14.714525174349546, 1.1217633378691971, 0.2226836368208751, 0.2061817902722396, 0.051625625492306426, 0.08853358682245016, 0.0069726796573377214, 0.1357389584882185, 0.02491448936780216, 0.18583275406854227, 0.11070277731050737, 0.037876927890465595, 0.0609244909719564, 0.054282640339806676, 0.000731253006733823, 0.06240300499484874, 0.03185242909239605, 0.06857621163362637, 0.022327390397549607, 0.0362949584814487, 0.07608405954670161, 0.043424674731795676, 0.02974541061121272, 0.018318768779863603, 0.03140460976283066, 0.09828610491240397, 0.05048819140938576, 0.056957039996632375, 0.09901965851895511, 0.09725182564579882, 0.0839284565881826, 0.006610426707993611, 0.09181236557196826, 0.05854472765349783, 0.033979142317548394, 0.02122890051396098, 0.02162739670893643, 0.06622764078201726, 0.07627493992913514, 0.05205538465816062, 0.027960456391156185, 0.06722162885125726, 0.03400694688025396, 0.05192167191125918, 0.05090201666462235, 0.07446582880220376, 0.04218464615405537, 0.11718447247403674, 0.021183449534873944, 0.04365544184111059, 0.022076607565395534, 0.04184599674772471, 0.045183813344920054, 0.03960575348173734, 0.012607012868102174, 0.010640627660905011, 0.023633835626242217, 0.042246630328008905, 0.07684672018513083, 0.0911825271032285, 0.04183651210041717, 0.08690945600392297, 0.07700102753005922, 0.06135874384199269, 0.07502695923903957, 0.06096034783695359, 0.14115688885794953, 0.18387024843832478, 0.04559463661280461, 0.12553519976790994, 0.12568898760946468, 3.1162937683984637, 38.48625384271145, 101.47676959633827, 110.17979979515076, 90.5926488339901, 73.17872285842896, 68.95189806818962, 48.30365024507046, 43.353131487965584, 39.55284520983696, 39.89422649145126, 41.6734354197979, 35.90031400322914, 12.691604923456907, 0.900506554171443, 0.2591228799428791, 0.14135903504211456, 0.15426808531628922, 0.7291504740715027, 0.8683777938131243, 0.41317934927064925, 0.10664276196621358, 0.4228643170790747, 0.4784732050029561, 1.8772759661078453, 2.6831360114738345, 2.9344758996739984, 1.9168048887513578, 3.0459652421995997, 35.51871567964554, 89.3738566339016, 103.19300070405006, 96.14023715257645, 89.80095371603966, 95.47083467245102, 102.13813170790672, 96.50820940732956, 87.69615545868874, 79.03907239437103, 84.01887238025665, 90.44503435492516, 98.30922916531563, 97.94149249792099, 90.84072232246399, 92.34359487891197, 91.52465522289276, 88.574478328228, 94.27385330200195, 93.451357036829, 99.21437859535217, 100.03129675984383, 71.53778851032257, 49.01750274002552, 89.70647558569908, 77.8837063908577, 83.25493857264519, 76.21450915932655, 93.52014854550362, 35.34591235220432, 89.20494809746742, 109.39758136868477, 96.92910522222519, 100.49162685871124, 98.13199907541275, 102.90991589426994, 101.30086943507195, 84.15677458047867, 74.85197067260742, 75.72741329669952, 87.27104187011719, 95.9385135769844, 96.62403479218483, 97.75673881173134, 103.57280552387238, 97.84892946481705, 91.21491104364395, 100.1248325407505, 96.04768931865692, 63.92402306199074, 20.820834562182426, 2.6663796231150627, 0.47278084326535463, 0.6381628720555454, 3.2919419556856155, 1.8505398882552981, 1.2110073678195477, 2.073980486020446, 1.101677615661174, 0.2711716474732384, 0.06739434888004325, 0.08378898477531038, 0.0733017479069531, 1.5003886772319674, 22.819895893335342, 43.07308651506901, 51.374440267682076, 67.97873988747597, 84.34577643871307, 45.75362227857113, 44.83968012034893, 47.25083313882351, 69.6920907497406, 71.35922089219093, 80.2817653119564, 78.02589476108551, 28.90987280756235, 2.1908389404416084, 0.1495074454578571, 0.11561362043721601, 0.03247829336032737, 0.015888552406977396, 0.07726846044533886, 0.08261792769189924, 0.007169632199293119, 0.09363839766592719, 0.10263817021041177, 0.05128292767039966, 0.04075578923220746, 0.023473394430766348, 0.06120938291132916, 0.08239444476203062, 0.020864548678218853, 0.054333510852302425, 0.05698219138139393, 0.0391027925797971, 0.10881651993258856, 0.027742107267840765, 0.029686606540053617, 0.05629953055176884, 0.03234059899114072, 0.09077940732822753, 0.07321099808905274, 0.06420732184778899, 0.09291483336710371, 0.13720578368520364, 0.07106450662831776, 0.01995342696318403, 0.05646803147101309, 0.052775471995119005, 0.08654832694446668, 0.031096145357878413, 0.04117808610317297, 0.02210787424701266, 0.050194701689179055, 0.024961179733509198, 0.2155582027626224, 0.1284685533028096, 0.2939561154926196, 0.15026137843960896, 0.1102455475484021, 0.1096594735281542, 0.11600358193391003, 0.19342643878189847, 0.2136514472658746, 0.18138718558475375, 0.19113875372568145, 0.16519186086952686, 0.15853176824748516, 0.17455489985877648, 0.16736216784920543, 0.07460047665517777, 0.16579380200710148, 0.12576676468597725, 0.19069290108745918, 0.17277818347793072, 0.13041728467214853, 0.13507215364370495, 0.2252216631313786, 0.17218212014995515, 0.15783257607836276, 0.1592716746381484, 0.3049036249285564, 0.46390793344471604, 0.11614067887421697, 0.26930401800200343, 0.30021405313163996, 6.203591292724013, 57.40399852395058, 121.79393738508224, 129.70062911510468, 101.46869122982025, 82.24416241049767, 61.938093826174736, 39.480098113417625, 44.542870447039604, 55.11707603931427, 53.21069933474064, 51.89719341695309, 47.30556920170784, 16.348341554403305, 1.4391422574408352, 0.6915717967785895, 0.310428855009377, 0.5797330511268228, 0.8839615888427943, 2.223850144073367, 1.8419833411462605, 1.2614273373037577, 1.5980351250618696, 3.5072747385129333, 7.4081613309681416, 6.940493350848556, 9.482044447213411, 11.059993375092745, 6.188497552648187, 36.434705927968025, 92.31749787926674, 107.1970434486866, 99.92558643221855, 95.50187900662422, 99.55491632223129, 103.3901797235012, 97.68987759947777, 91.21665894985199, 80.90098768472672, 86.03945955634117, 94.4749841094017, 102.34865561127663, 100.87085410952568, 94.46585699915886, 94.50680360198021, 90.6355333328247, 93.17994520068169, 97.47028738260269, 95.69421708583832, 105.35838291049004, 104.31630402803421, 76.95037767291069, 57.093471586704254, 101.33243814110756, 87.11029529571533, 91.83672487735748, 83.05867150425911, 104.4012750685215, 41.98444113135338, 91.38650983572006, 116.28212034702301, 104.23198655247688, 107.03416898846626, 101.33720308542252, 106.97758242487907, 108.74432042241096, 90.71541264653206, 79.02751341462135, 77.48105719685555, 89.57329273223877, 97.95681327581406, 100.33008992671967, 98.22718396782875, 108.62330451607704, 102.68179133534431, 95.90562254190445, 106.45723074674606, 101.16060376167297, 65.59767365455627, 22.07799330353737, 4.974954770877957, 2.884794515557587, 5.45371008105576, 5.10848150588572, 4.787391610443592, 5.003416193649173, 3.6345676705241203, 2.4675700161606073, 0.26326065009925514, 0.09394065957167186, 0.26753188809379935, 0.12783545680576935, 3.5533429915085435, 35.67606903612614, 58.526344299316406, 63.48503261804581, 91.58133298158646, 125.92127591371536, 68.22327196598053, 34.826104044914246, 38.74967470765114, 76.91693186759949, 77.83289551734924, 95.39932250976562, 88.78743410110474, 27.066407427191734, 1.5237765409983695, 0.4131537600187585, 0.26950950385071337, 0.22737933875760064, 0.1560624351259321, 0.13628057786263525, 0.24106512079015374, 0.09523082393570803, 0.35522586840670556, 0.31542837736196816, 0.27073300851043314, 0.20664229290559888, 0.271221490111202, 0.21773315558675677, 0.12077881241566502, 0.09549286885885522, 0.16325504839187488, 0.2597397827776149, 0.14899297384545207, 0.15954622474964708, 0.15873057476710528, 0.0712936744093895, 0.10238784379907884, 0.09714805113617331, 0.21402918559033424, 0.2444529061904177, 0.17699276591883972, 0.39214014541357756, 0.3140900476137176, 0.23597147926921025, 0.15546475391602144, 0.12282492098165676, 0.1307874234043993, 0.27854221290908754, 0.13339587952941656, 0.10520542971789837, 0.15179000969510525, 0.10503440178581513, 0.12727783672744408], [0.05742728702898603, 0.07245825996506028, 0.029515600872400682, 0.040946576846181415, 0.03129384793282952, 0.006475364180005272, 0.028286986525927205, 0.0271705644991016, 0.04221092560328543, 0.023528736383013893, 0.027617240921244957, 0.07946323603391647, 0.02035474703006912, 0.04228097321174573, 0.0698158357408829, 0.03371589140442666, 0.031523572324658744, 0.05752647135523148, 0.08454587892629206, 0.039430172473657876, 0.09491066142800264, 0.04217905407131184, 0.11801375570939854, 0.03411099227378145, 0.04168343300989363, 0.029775825678370893, 0.14000703493366018, 0.14363505353685468, 0.3235971671529114, 0.3518821665784344, 6.591499652713537, 42.686951234936714, 97.97235444188118, 102.85124704241753, 89.94561955332756, 50.59415593743324, 37.276573553681374, 19.285583943128586, 24.656529240310192, 58.8394170999527, 62.87629768252373, 46.67187720537186, 32.15145796537399, 12.143378891050816, 1.5210531558841467, 0.07396720204269513, 0.06484096753410995, 0.1807635885779746, 0.14041442947927862, 1.4570362097583711, 0.77484967187047, 0.5589641968254, 0.10440033307531849, 0.18110741075361148, 0.18838596472050995, 1.485188186634332, 0.7500725076533854, 1.107202044222504, 3.8020576955750585, 50.89919596910477, 104.41611707210541, 96.58723756670952, 84.62962120771408, 85.7050471007824, 84.55458283424377, 92.30401620268822, 87.66365200281143, 79.58560466766357, 71.68162599205971, 79.58859890699387, 92.07314819097519, 95.71878656744957, 93.68107751011848, 93.228058218956, 87.3367403447628, 86.54235497117043, 89.13698494434357, 90.34590527415276, 91.94374233484268, 92.22081586718559, 95.97468763589859, 91.3278865814209, 87.10635870695114, 44.609336480498314, 49.12626810371876, 78.27976673841476, 83.02981585264206, 87.85954669117928, 62.22077205777168, 39.29959259927273, 95.51655381917953, 87.0844566822052, 84.7411148250103, 85.3858794271946, 98.16679760813713, 99.78522196412086, 92.17695102095604, 70.5698512494564, 69.94793102145195, 73.1209659576416, 78.06668177247047, 87.8553669154644, 91.15636378526688, 96.95867523550987, 97.97978684306145, 92.46232330799103, 77.46242299675941, 82.7237118780613, 88.12026590108871, 95.68736985325813, 59.93124671280384, 21.76374066621065, 1.5691928914748132, 2.27249204646796, 1.0410477127879858, 6.287697404623032, 1.1013123602606356, 0.7099543197546154, 0.10200637989328243, 0.24751744174864143, 0.05059548369899858, 0.03795279022597242, 0.00738785933208419, 0.045547309855464846, 0.8059692895039916, 15.072634108364582, 35.98948381841183, 48.962736278772354, 44.501110687851906, 58.7292268127203, 37.52222277224064, 23.686027117073536, 20.328840762376785, 30.062208473682404, 67.84905284643173, 70.24049252271652, 66.32433906197548, 30.201100520789623, 9.501695092767477, 0.4924802330788225, 0.10457152427989058, 0.0976641480519902, 0.02061567131022457, 0.052477629578788765, 0.04869217918894719, 0.12521475524408743, 0.1172315543226432, 0.08117899982607923, 0.02163573844882194, 0.026720683854364324, 0.03778523183427751, 0.007462786097676144, 0.09845482476521283, 0.009038097050506622, 0.04097129036381375, 0.01936950702656759, 0.05873742629773915, 0.09133575091254897, 0.06993422313826159, 0.033443786669522524, 0.11573827898246236, 0.020986507661291398, 0.06530463171657175, 0.06086423229135107, 0.021467348851729184, 0.09066841914318502, 0.067440881539369, 0.07692322818911634, 0.036783907635253854, 0.04149220010731369, 0.054071117119747214, 0.052287086873548105, 0.04292969933885615, 0.04444820027856622, 0.012008616413368145, 0.007888754280429566, 0.031758013064973056, 0.027351646676834207, 0.029769582361041103, 0.042294654704164714, 0.07032816996797919, 0.012729159243463073, 0.07518880680436268, 0.08785957572399639, 0.03119958404568024, 0.014153200554574141, 0.06308962518232875, 0.036125474216532893, 0.008668129939906066, 0.044674061791738495, 0.0616243473632494, 0.06612244877032936, 0.05881451317691244, 0.022990126417425927, 0.0659261061809957, 0.05188825300137978, 0.03786216286243871, 0.03737916944373865, 0.06377954792696983, 0.025906432820193004, 0.06251262020668946, 0.03771486139157787, 0.08680634200572968, 0.13629031484015286, 0.244127415062394, 0.5315002799034119, 7.797093261033297, 51.07400558888912, 117.36709132790565, 110.81875830888748, 107.55727931857109, 73.49053412675858, 59.799956157803535, 33.484274446964264, 35.273822620511055, 51.76930747926235, 50.92925615608692, 50.63408799469471, 35.32784432172775, 17.25688800215721, 1.5166326868347824, 0.2407856725039892, 0.043356875830795616, 0.06274874191149138, 0.5570448841899633, 1.8304339796304703, 0.730332329403609, 0.5125231482088566, 0.20060416456544772, 0.19879047438735142, 0.24979313369840384, 0.4704799479804933, 0.4185632150620222, 1.036588770803064, 5.017660204321146, 55.802821442484856, 108.0733448266983, 97.56477311253548, 87.64900758862495, 90.15032976865768, 91.36333107948303, 98.16356778144836, 93.67644175887108, 81.82395815849304, 75.29686599969864, 83.64112704992294, 95.98587423563004, 100.02676740288734, 95.30682027339935, 92.83971905708313, 89.36954766511917, 87.82325103878975, 91.92934110760689, 92.07960784435272, 94.36807304620743, 96.05696842074394, 99.39926907420158, 93.25946733355522, 91.23717784881592, 48.96890714764595, 55.72693571448326, 87.75834292173386, 89.355678409338, 98.62541019916534, 68.51406276226044, 48.233133628964424, 100.13405844569206, 92.90800899267197, 87.18163266777992, 89.36188727617264, 99.83984783291817, 102.43135437369347, 96.48538023233414, 75.42961567640305, 74.20383185148239, 77.4642924964428, 83.61351773142815, 93.16714748740196, 95.91731831431389, 100.5315475165844, 102.10514187812805, 97.98196792602539, 81.2820540368557, 85.19557803869247, 91.24205678701401, 99.11978647112846, 65.1385746896267, 27.3946376144886, 3.5742976795881987, 2.129508093930781, 0.2451648484566249, 6.659117974340916, 0.5457716609816998, 0.520877237431705, 0.36633003037422895, 0.6505361956078559, 0.357830123975873, 0.1293118260218762, 0.05299919612298254, 0.05346899415599182, 0.9240510407835245, 16.899245493113995, 30.466616973280907, 40.96395269036293, 41.51502572000027, 53.40655982494354, 34.80509117245674, 26.1240503937006, 41.35056294500828, 52.62921653687954, 81.27602756023407, 82.68258288502693, 86.34823858737946, 52.835617661476135, 18.011166527867317, 0.715938345529139, 0.12097613463993184, 0.0254699702054495, 0.05423805210739374, 0.03289908738224767, 0.05713721860956866, 0.08741722602280788, 0.11633628673735075, 0.07905452788691036, 0.03705027556861751, 0.06817128843977116, 0.05324586745700799, 0.0749575016379822, 0.018256758630741388, 0.02483177144313231, 0.03509126545395702, 0.01565674443554599, 0.10030021207057871, 0.04551529731543269, 0.09932489643688314, 0.02445742102281656, 0.011851385006593773, 0.06771962478524074, 0.029766582229058258, 0.06867930336738937, 0.03145350616250653, 0.010339483615098288, 0.07118123903637752, 0.12642009212868288, 0.03341028241266031, 0.054667800141032785, 0.018068611207127105, 0.015739989285066258, 0.03459736988588702, 0.07974637279403396, 0.051627952125272714, 0.043819541824632324, 0.1288741221651435, 0.12530385749414563, 0.14055502193514258, 0.17664043873082846, 0.16837421979289502, 0.04807805198652204, 0.14847477665171027, 0.19932603783672675, 0.1413792511448264, 0.12897239736048505, 0.14265227189753205, 0.12280396273126826, 0.08437127384240739, 0.14131587173324078, 0.1238797428959515, 0.11902042708243243, 0.16472729126689956, 0.15826463961275294, 0.146974777453579, 0.08326729948748834, 0.14964793401304632, 0.10998665675288066, 0.34877520985901356, 0.12488516746088862, 0.10419677681056783, 0.17023836117004976, 0.25054858066141605, 0.36064120125956833, 0.43612444773316383, 0.7779123075306416, 15.689349565654993, 72.73560583591461, 136.52165830135345, 127.42373049259186, 119.12545457482338, 79.8530039191246, 58.208685144782066, 31.695541329681873, 36.39402151107788, 78.07264745235443, 84.12854969501495, 69.5235013961792, 51.36237971484661, 23.642893731594086, 3.4490464255213737, 0.5684477160684764, 0.13454028608975932, 0.27997797180432826, 0.6794914731290191, 5.3143672831356525, 3.001415482722223, 1.988391384948045, 0.505876176757738, 0.4262886755168438, 1.1757104680873454, 5.557266399264336, 3.48406748380512, 4.611213114112616, 5.491323787719011, 58.664086908102036, 114.30135503411293, 102.49785080552101, 90.07583096623421, 93.49455311894417, 93.2818253338337, 103.86540502309799, 99.30725321173668, 85.55709823966026, 77.92373344302177, 86.97868555784225, 99.08210009336472, 102.09640234708786, 98.67925330996513, 98.71677249670029, 89.72135558724403, 87.86417484283447, 94.4905936717987, 94.95970129966736, 97.9939752817154, 100.46993762254715, 102.25686773657799, 96.97316005825996, 93.2651974260807, 55.972987711429596, 66.62621006369591, 98.84782746434212, 99.36149150133133, 105.56665733456612, 77.53258243203163, 55.94980515539646, 101.90907999873161, 98.10497492551804, 91.47542506456375, 95.72999596595764, 104.15012374520302, 108.45834776759148, 101.84950679540634, 78.87449562549591, 76.02603927254677, 80.47111675143242, 86.2126998603344, 96.85389965772629, 100.77883824706078, 101.19679301977158, 105.17584070563316, 103.64750951528549, 84.16514173150063, 90.92812523245811, 95.64221307635307, 103.56669545173645, 64.8702634871006, 26.662517599761486, 4.341113157570362, 8.475748244673014, 6.758585711941123, 14.62805226445198, 5.871789772063494, 2.375439922325313, 2.1253428049385548, 1.1821204866282642, 0.5955095076933503, 0.22249342437135056, 0.27458050986751914, 0.13382513774558902, 1.8674277258105576, 28.888517953455448, 55.33618748188019, 72.79675215482712, 60.41869975626469, 76.771080493927, 51.98347918689251, 34.15870785713196, 29.872910231351852, 49.96049053966999, 91.44394755363464, 95.4556354880333, 106.22205376625061, 56.51027888059616, 16.842083260416985, 0.6833881046622992, 0.24799982289550826, 0.20574358175508678, 0.13428567006485537, 0.1998813424143009, 0.18303033022675663, 0.17357526492560282, 0.18572975881397724, 0.2434924483532086, 0.13465649157296866, 0.18785429012496024, 0.1570702568278648, 0.16736779332859442, 0.180755885085091, 0.16640663787256926, 0.1865406145225279, 0.1628274971153587, 0.21092320850584656, 0.16460546030430123, 0.22901786724105477, 0.10070103118778206, 0.14896533626597375, 0.15090136206708848, 0.08982899817056023, 0.19229154655477032, 0.20255417242879048, 0.14881364128086716, 0.15223041496938094, 0.14434378972509876, 0.08193081768695265, 0.10153314942726865, 0.13169011246645823, 0.12085143898730166, 0.15015542943729088, 0.14264394500060007, 0.15377339936094359, 0.127466639096383], [0.024131961436069105, 0.045138059940654784, 0.1023485248151701, 0.04887384580797516, 0.03386438031157013, 0.021058546080894303, 0.04706895007984713, 0.02784585209155921, 0.013471189104166115, 0.0657612232316751, 0.03775944220251404, 0.0678426877129823, 0.10052434066892602, 0.047583302948623896, 0.05021114397095516, 0.0747146041248925, 0.010654869474819861, 0.06049090232409071, 0.028873676528746728, 0.10137357283383608, 0.059404038183856755, 0.0394794993189862, 0.012463686525734374, 0.05808341236843262, 0.0033691980797811993, 0.043203904351685196, 0.14125443674856797, 0.1617288068518974, 0.17710462241666391, 8.604695275425911, 56.45159862935543, 105.42282745242119, 91.84826865792274, 89.10744532942772, 46.095622926950455, 31.11011814326048, 19.318245090544224, 47.85296022891998, 79.28924337029457, 68.01959529519081, 58.040319979190826, 27.25884810090065, 13.823621179908514, 0.25500778981950134, 0.12681797234108672, 0.06861202025902458, 0.3202286775922403, 0.10030319550423883, 0.4635281616356224, 0.6557090242858976, 0.27875164698343724, 0.12344793169177137, 0.1389834945439361, 0.207475220086053, 0.024993537372210994, 0.9384081547614187, 1.912710964679718, 13.944016769528389, 63.32815803587437, 98.95533129572868, 86.76170960068703, 84.55619394779205, 79.17369917035103, 78.15589338541031, 73.04398208856583, 75.58831036090851, 74.56517726182938, 70.7400669157505, 79.38786327838898, 91.55605673789978, 93.71918946504593, 96.6227276623249, 89.9993334710598, 87.72058814764023, 87.20652893185616, 88.01321804523468, 86.98407366871834, 87.44943469762802, 81.72122687101364, 83.40749278664589, 85.22108227014542, 92.01100632548332, 90.19016683101654, 84.68225598335266, 33.3519883453846, 52.9596734046936, 70.83057045936584, 78.04360941052437, 39.03777524828911, 70.39562299847603, 92.58275404572487, 76.29056587815285, 76.8961925804615, 87.49617978930473, 96.59918412566185, 94.2101839184761, 84.42329227924347, 70.22485256195068, 73.27054113149643, 78.82960483431816, 83.56687903404236, 87.36466884613037, 89.97416362166405, 95.74106857180595, 92.69148901104927, 86.25468000769615, 70.91442435979843, 80.56348979473114, 87.22463116049767, 90.7842269539833, 89.10767331719398, 81.46766647696495, 58.11732664704323, 12.946952171623707, 0.48459740763064474, 4.890470104292035, 1.4277084334753454, 0.3785982955014333, 0.2632514771539718, 0.7410812994930893, 0.44244864431675524, 0.06701626916765235, 0.07874747912865132, 0.09229964489350095, 0.462850165204145, 0.8042655559256673, 9.743387773633003, 36.662480905652046, 56.1539264023304, 42.18420401215553, 67.0294900238514, 58.80909852683544, 20.77033907175064, 21.49384304881096, 29.17558114975691, 56.044727861881256, 63.03995870053768, 60.62210664153099, 53.32184337079525, 19.904076755046844, 1.1009900900535285, 0.06984019302763045, 0.02954656141810119, 0.049375170274288394, 0.02828722215781454, 0.12513886322267354, 0.11170055033289827, 0.007373553044089931, 0.0772808691544924, 0.007778357958159177, 0.024274040042655542, 0.0924254537676461, 0.007630860745848622, 0.07526678426074795, 0.018250064458698034, 0.04738481555250473, 0.03129745105979964, 0.06453993017203175, 0.007973182855494088, 0.03951954931835644, 0.021386447333497927, 0.09904673948767595, 0.029320777830434963, 0.06086342706112191, 0.04365042863355484, 0.01963594175322214, 0.030450807134911884, 0.04322318534832448, 0.023484847624786198, 0.07512085576308891, 0.038399143813876435, 0.048716855599195696, 0.028117422480136156, 0.02119526638125535, 0.07454687874997035, 0.09176952880807221, 0.02787687386444304, 0.015373158676084131, 0.05745290967752226, 0.10896840045461431, 0.02303657372976886, 0.038895069155842066, 0.060424001421779394, 0.03429888922255486, 0.016498542136105243, 0.010033818034571595, 0.0358581414911896, 0.04924447064695414, 0.0479704776807921, 0.016542022713110782, 0.05025425532949157, 0.02688893800950609, 0.04626757901860401, 0.004238519022692344, 0.025404577718290966, 0.06894237987580709, 0.07244098276714794, 0.027278359593765344, 0.0607287569437176, 0.08220115239964798, 0.027335885315551423, 0.06030551754520275, 0.10290178848663345, 0.22613242676015943, 0.1967091954429634, 8.46549829468131, 65.53240075707436, 121.08346670866013, 105.4178649187088, 104.07127037644386, 70.07620453834534, 51.84800885617733, 37.78918504714966, 43.449517115950584, 43.71120907366276, 47.609769478440285, 52.043698355555534, 32.8495717048645, 17.965785562992096, 0.5063311429694295, 0.08616094070021063, 0.1045499871543143, 0.5242585216183215, 0.6184108788147569, 0.8531377022154629, 1.0092324949800968, 0.49482806178275496, 0.09784213732928038, 0.09653117798734456, 0.4848792456323281, 0.06683233528747223, 0.3736236202530563, 2.1050317073240876, 15.986382476985455, 68.34862723946571, 100.61312153935432, 89.07917484641075, 87.1584615111351, 82.74425357580185, 81.02310553193092, 75.82556203007698, 79.26857247948647, 77.18707457184792, 74.34972122311592, 84.38977807760239, 95.37363588809967, 95.50307214260101, 99.84590470790863, 93.36935743689537, 91.50833129882812, 88.47760632634163, 90.56995645165443, 91.70576870441437, 90.7706768810749, 84.65057328343391, 87.22233608365059, 88.48029658198357, 96.38324931263924, 93.7344342470169, 89.66994434595108, 41.607584953308105, 60.31190648674965, 80.03235429525375, 88.10655623674393, 48.595307394862175, 75.22732973098755, 96.32705792784691, 82.62143656611443, 79.46624547243118, 87.67825841903687, 99.87770140171051, 99.2392672598362, 87.25040137767792, 73.18111672997475, 76.50168254971504, 81.67784839868546, 88.18897381424904, 90.63950791954994, 91.406010389328, 99.1162146627903, 96.6671396791935, 91.43947139382362, 72.00664535164833, 84.87756550312042, 90.57920515537262, 95.69860205054283, 93.14586862921715, 86.68851032853127, 63.58003132045269, 18.026641197502613, 2.191455219872296, 2.230093921534717, 1.1594596900977194, 0.4549381881952286, 0.6341618648730218, 0.12804241210687906, 0.5488942621741444, 0.40699865436181426, 0.26516791025642306, 0.11222323009860702, 0.2854187157936394, 1.0490004485473037, 12.898130491375923, 35.550405979156494, 40.80214977264404, 30.417293719947338, 35.64042314887047, 39.15952071547508, 21.162818111479282, 31.538503356277943, 53.58938321471214, 71.44375875592232, 76.44107580184937, 79.38413187861443, 75.9126989543438, 34.1928718239069, 1.6869723214767873, 0.12593903200468048, 0.013130260376783554, 0.034698958770604804, 0.019731459869944956, 0.11726443146471865, 0.03126050694845617, 0.058846878237091005, 0.010728430224844487, 0.05075652603409253, 0.08662375883432105, 0.04615472804289311, 0.020112990569032263, 0.1275945408269763, 0.03562918151146732, 0.021688052438548766, 0.05316516260791104, 0.0649037458060775, 0.0405355457769474, 0.04610496333043557, 0.0463583436794579, 0.04239410991431214, 0.049610872665653005, 0.006275050636759261, 0.05354614040697925, 0.02684497318114154, 0.08022146605071612, 0.05621962351142429, 0.035725731213460676, 0.06743584235664457, 0.04217846777464729, 0.054420141750597395, 0.008181214270734927, 0.05670509199262597, 0.024221239946200512, 0.03843403588689398, 0.1603999172220938, 0.19643218140117824, 0.16894884989596903, 0.1502016355516389, 0.10042532332590781, 0.12723713734885678, 0.13139623682945967, 0.1640228446922265, 0.15350600355304778, 0.14926166099030524, 0.12218621384818107, 0.13487848278600723, 0.13569822942372411, 0.057049719398492016, 0.2165576975676231, 0.21221027069259435, 0.12309330384596251, 0.1386068545980379, 0.0787036182009615, 0.21688087319489568, 0.13366544240852818, 0.1601132849464193, 0.19437607610598207, 0.22474189434433356, 0.1386708574136719, 0.17295212805038318, 0.3065486397827044, 0.36830384633503854, 0.38897218415513635, 16.367490626871586, 86.55297920107841, 138.7914589047432, 115.46714007854462, 117.26828143000603, 71.19526728987694, 45.53194597363472, 26.89375229179859, 68.01265686750412, 102.31051325798035, 90.97774296998978, 81.11420184373856, 44.29188251495361, 25.259220600128174, 0.7400868809781969, 0.24387213110458106, 0.1802447679801844, 0.8757446485105902, 0.7506133848801255, 2.6553815882653, 2.9279725486412644, 1.5140921669080853, 0.5187875870615244, 0.37838526943232864, 0.5789594957605004, 0.335302171879448, 4.01958866044879, 4.345688112080097, 18.64039946347475, 73.82743164896965, 105.15473663806915, 94.2663449048996, 92.17956528067589, 85.79266279935837, 86.73391789197922, 81.0403262078762, 83.72619688510895, 81.20570093393326, 75.24187535047531, 86.49580746889114, 100.51516279578209, 99.78783622384071, 103.98192197084427, 97.3305232822895, 95.6796182692051, 91.04998469352722, 94.70481857657433, 96.45088568329811, 94.76177752017975, 90.16894116997719, 94.04128298163414, 93.93988162279129, 101.67735323309898, 98.0569227039814, 90.4775682091713, 47.26035922765732, 68.39601069688797, 88.94200220704079, 96.32641196250916, 57.7826976031065, 80.53847953677177, 100.65507888793945, 85.72260215878487, 85.40521278977394, 96.55469611287117, 106.4829021692276, 106.45507246255875, 94.60122093558311, 77.43868947029114, 80.47172471880913, 85.26490911841393, 89.76107865571976, 93.51519361138344, 94.80205535888672, 98.86768519878387, 101.33935377001762, 97.54902675747871, 75.10385915637016, 89.38113704323769, 96.58933505415916, 100.93163564801216, 97.53017216920853, 86.93180367350578, 59.22330290079117, 14.991282373666763, 4.710884615778923, 10.901603624224663, 4.894072785973549, 1.657405870500952, 2.3993558390066028, 2.4253236455842853, 2.007610397413373, 0.7000256306491792, 0.5158014816697687, 0.32279915059916675, 0.9226299764122814, 1.5348215983249247, 19.58306048065424, 56.67063407599926, 81.41295701265335, 64.27163600921631, 87.61775806546211, 78.82056131958961, 28.89233484864235, 30.477837771177292, 46.317249834537506, 78.8439604640007, 85.53237676620483, 94.66925248503685, 89.84838277101517, 34.88588243722916, 1.4226233563385904, 0.25562374270521104, 0.16897783818421885, 0.15231488621793687, 0.19913168420316651, 0.30148903315421194, 0.2849698351928964, 0.18673964368645102, 0.3053722169715911, 0.10932237521046773, 0.14869347272906452, 0.14746339264092967, 0.18999915628228337, 0.2140181721188128, 0.14382584486156702, 0.15485533192986622, 0.121766032098094, 0.16728939284803346, 0.11980604234850034, 0.15578096819808707, 0.1534913238720037, 0.13584202795755118, 0.11167720978846774, 0.13548011222155765, 0.12542298703920096, 0.16586549347266555, 0.11665945494314656, 0.16955647588474676, 0.09801305393921211, 0.182682337181177, 0.1321185246342793, 0.18473870964953676, 0.1972975255921483, 0.14058041822863743, 0.19052155403187498, 0.16629582038149238], [0.027110103583254386, 0.05248734429187607, 0.010495656533748843, 0.05183597982977517, 0.09899219163344242, 0.022056287562008947, 0.008871827212715289, 0.017028444854076952, 0.03648495199740864, 0.1338247666717507, 0.05298573356412817, 0.042832444596569985, 0.012473953211156186, 0.06358953585731797, 0.06911161181051284, 0.04083438267116435, 0.02223044550191844, 0.02587795846920926, 0.07085811535944231, 0.021863549955014605, 0.08426376632996835, 0.06910634256200865, 0.05054647597717121, 0.03381349866685923, 0.05537305565667339, 0.01983824564376846, 0.060400074580684304, 1.1403321102261543, 19.972714371979237, 56.87269203364849, 95.24235293269157, 98.50185602903366, 70.41519194841385, 56.743639558553696, 26.247743256390095, 19.708736836910248, 45.84047041833401, 51.501026675105095, 63.163246884942055, 55.53987555205822, 30.531162209808826, 13.805261515080929, 0.6763232743833214, 0.15648306958610192, 0.2054522739490494, 0.023194946188596077, 0.23923485103296116, 0.24639672454213724, 1.2762670847587287, 2.5716649554669857, 0.24340045172721148, 0.1024462137138471, 0.062655164510943, 0.1944457192439586, 1.9142738683149219, 11.94861939176917, 46.22694008052349, 80.73090881109238, 86.86665996909142, 90.33921003341675, 89.42435592412949, 83.60491499304771, 70.0594474375248, 68.1431494653225, 68.43112081289291, 68.90439301729202, 63.00134137272835, 72.6900614798069, 83.49381655454636, 91.938696205616, 94.1814498603344, 89.45937484502792, 80.45113742351532, 81.33730307221413, 88.17128956317902, 87.13832259178162, 84.20703068375587, 77.08526283502579, 76.51611417531967, 76.63635492324829, 78.99939492344856, 79.81211811304092, 85.37485241889954, 87.88876712322235, 82.88831144571304, 29.968043826520443, 67.04661950469017, 61.09565243124962, 54.58949714899063, 94.66422915458679, 79.61087331175804, 76.16579577326775, 63.84998023509979, 71.1940361559391, 79.71370339393616, 77.36786887049675, 70.93709394335747, 77.04080522060394, 83.13593655824661, 88.67742240428925, 91.31380453705788, 88.30552875995636, 88.94992098212242, 91.34354174137115, 90.73595434427261, 87.22796738147736, 68.97320732474327, 70.17468005418777, 82.59410843253136, 88.84463623166084, 88.01851496100426, 93.05066093802452, 97.67536237835884, 94.28093612194061, 52.558612525463104, 12.735343426465988, 0.8498875703662634, 0.8499564416706562, 0.6641713483259082, 0.6691855355165899, 0.5081346211954951, 0.5856650078203529, 0.09576039825333282, 0.05417514395958278, 0.07076368448906578, 0.017439809889765456, 0.29843117692507803, 2.1660485956817865, 15.04564130678773, 48.11834938824177, 48.975796177983284, 48.77490095794201, 78.72511804103851, 36.575716361403465, 11.630935538560152, 26.125847697257996, 38.568314239382744, 54.72719796001911, 65.79425990581512, 67.66183689236641, 26.77907444536686, 4.1630922351032495, 0.34122676646802574, 0.09349695916171186, 0.01273733771085972, 0.057304639703943394, 0.06861330417450517, 0.02684554463485256, 0.06169441723614, 0.03670647565741092, 0.03399654939130414, 0.02584531881439034, 0.015389186282845913, 0.03720282402355224, 0.04501417693973053, 0.009720153957459843, 0.01360815802399884, 0.05520910410268698, 0.045912661735201254, 0.0628335916553624, 0.03976051724748686, 0.028604672115761787, 0.07903995952801779, 0.016976804363366682, 0.07623964338563383, 0.04969303212419618, 0.03725657777977176, 0.010313605853298213, 0.07688952726311982, 0.041977249275078066, 0.06496139583759941, 0.0492373089218745, 0.013087809529679362, 0.03578693242161535, 0.022517795805470087, 0.055919506412465125, 0.04081697188667022, 0.04214683001919184, 0.09004356048535556, 0.006209041239344515, 0.08269523721537553, 0.07161897257901728, 0.04122098966035992, 0.04059862461872399, 0.016967353112704586, 0.03517930272209924, 0.04474914487218484, 0.09546360597596504, 0.035436022735666484, 0.018355100619373843, 0.0270590642321622, 0.030890423877281137, 0.04588718009472359, 0.05410520767327398, 0.06466012098826468, 0.04731867906230036, 0.12066048439010046, 0.046973172211437486, 0.03248661654652096, 0.021854217447980773, 0.08292762591736391, 0.11885397820151411, 0.1256929655210115, 1.2282781535759568, 22.099032774567604, 64.88342598080635, 108.79187867045403, 112.99350321292877, 83.59268724918365, 77.98312425613403, 40.969960168004036, 28.128357343375683, 18.589123114943504, 46.82633891701698, 60.034213587641716, 46.48488163948059, 38.22087228298187, 16.44793801009655, 0.9511172259226441, 0.1642531034303829, 0.27476785762701184, 0.07129722929676063, 0.22321826516417786, 1.0861657792702317, 2.587613412179053, 5.115605648607016, 0.48078475752845407, 0.0666949711740017, 0.24854984338162467, 0.24089868675218895, 2.6236067432910204, 13.437651190906763, 49.625941291451454, 82.10635140538216, 85.98590523004532, 93.62949147820473, 92.4703560769558, 86.16316571831703, 73.60085740685463, 71.76101893186569, 71.430284678936, 71.70723661780357, 66.15972429513931, 73.6709788441658, 87.51754984259605, 95.82121387124062, 97.17883542180061, 93.40844213962555, 85.27858838438988, 84.71578538417816, 92.64767736196518, 90.46939104795456, 85.9645427763462, 82.38648757338524, 79.1732507944107, 81.46483942866325, 82.85942539572716, 81.32471054792404, 88.79670560359955, 90.87223023176193, 86.8621002137661, 39.176862984895706, 74.41222786903381, 69.41985815763474, 63.47016021609306, 96.30621984601021, 83.91783580183983, 80.42174220085144, 67.5119349360466, 73.76880079507828, 81.8891778588295, 79.63032826781273, 73.27241823077202, 79.50985193252563, 88.73936668038368, 91.82993844151497, 95.15627235174179, 92.57174223661423, 94.28554147481918, 94.51578631997108, 94.16701823472977, 90.63187032938004, 73.34633186459541, 75.63011571764946, 86.92139983177185, 92.22027629613876, 91.48938551545143, 94.72060292959213, 98.79719138145447, 101.33452042937279, 59.90794636309147, 18.856670558452606, 1.4722216199152172, 0.4964366223430261, 0.9267609484959394, 0.6438075879123062, 0.39707189484033734, 0.5416136747226119, 0.3918384772259742, 0.10814906199811958, 0.057501037954352796, 0.052623235242208466, 0.1365787282702513, 4.250520318746567, 19.381262809038162, 45.335048139095306, 41.871013417840004, 44.845987781882286, 47.72277541458607, 27.850206568837166, 18.686287701129913, 48.25468227267265, 59.02754880487919, 69.50647071003914, 81.53894305229187, 86.60042345523834, 45.52528113126755, 7.0873374212533236, 0.2929951826808974, 0.1311846950557083, 0.073676109459484, 0.11095177527749911, 0.02464134191541234, 0.06118997946032323, 0.035552962945075706, 0.00955584710027324, 0.026121624105144292, 0.019885770925611723, 0.06976542164920829, 0.035016828041989356, 0.04590894728607964, 0.03308355931949336, 0.07280293561052531, 0.023393012415908743, 0.060633480024989694, 0.018453496413712855, 0.03220661536033731, 0.0239467844585306, 0.047151803446467966, 0.05683166156813968, 0.012106571557524148, 0.09786431270185858, 0.047505588954663835, 0.05779416773293633, 0.018812296984833665, 0.08179505661246367, 0.05241943035798613, 0.05728011172323022, 0.0624493150098715, 0.014721539100719383, 0.0686406745808199, 0.05664477022946812, 0.07863509570597671, 0.16581569536356255, 0.16299499984597787, 0.1533975312486291, 0.2598232892341912, 0.12712486524833366, 0.1496437334571965, 0.15818585321540013, 0.13721007329877466, 0.22794432094087824, 0.08786433289060369, 0.23421818506903946, 0.12926569412229583, 0.10272444487782195, 0.1420431022415869, 0.1307530322810635, 0.2024086521123536, 0.31944974907673895, 0.26589242450427264, 0.20742116204928607, 0.3783834882779047, 0.13663676421856508, 0.159859633713495, 0.10572935629170388, 0.16811764449812472, 0.25967622525058687, 0.22939471498830244, 2.644107830710709, 36.804631277918816, 89.91367846727371, 129.6089780330658, 122.96693444252014, 99.47167798876762, 80.022794008255, 46.23838126659393, 32.58825212717056, 65.97188517451286, 72.93185010552406, 86.72270089387894, 81.92241087555885, 49.775569662451744, 25.171137526631355, 1.2124653020873666, 0.6029797880910337, 0.4741683922475204, 0.4442295018816367, 0.43960743583738804, 2.4148727813735604, 4.93554518558085, 7.19084576703608, 0.903001535916701, 0.24831272719893605, 0.4271578788757324, 0.4101475572679192, 3.4978312952443957, 14.55728106200695, 52.352310195565224, 88.21548879146576, 87.42307171225548, 98.04477855563164, 98.10901790857315, 92.34560877084732, 76.82504519820213, 74.89673987030983, 73.78846853971481, 75.27860417962074, 69.36679020524025, 80.11678576469421, 92.11629867553711, 99.49845895171165, 99.89584922790527, 97.97591105103493, 88.90431582927704, 88.42095136642456, 94.42124739289284, 94.00941789150238, 91.97895124554634, 85.77197670936584, 82.90940791368484, 84.97157245874405, 87.66368240118027, 87.31262683868408, 92.83040955662727, 97.91990965604782, 88.75778809189796, 46.750570982694626, 81.80565074086189, 77.34692439436913, 69.52432215213776, 101.6028468310833, 89.05759200453758, 83.21684181690216, 71.10860913991928, 78.79248082637787, 87.01466962695122, 82.64678880572319, 76.11628443002701, 83.09412360191345, 92.05061540007591, 96.13396748900414, 99.55074414610863, 94.89809900522232, 96.49352699518204, 97.06112533807755, 98.47664818167686, 94.56531286239624, 77.79137134552002, 78.45256626605988, 91.96876779198647, 98.31953421235085, 96.0053063929081, 100.59297502040863, 105.09059607982635, 105.54028674960136, 60.9217319637537, 17.277334704995155, 1.3703547860495746, 1.95225769886747, 2.723972420208156, 3.474706211127341, 1.95089214714244, 2.2460145922377706, 0.962778206449002, 0.20905884448438883, 0.20988684380427003, 0.34135346591938287, 0.8966926869470626, 7.099936595186591, 29.30850561708212, 72.87111416459084, 70.87397933006287, 69.17649641633034, 103.34895953536034, 53.8920521736145, 18.912092484533787, 41.17961011826992, 57.097381576895714, 77.10783362388611, 94.16285365819931, 104.98328983783722, 50.48457361757755, 6.45415079779923, 0.554370837053284, 0.3511589585104957, 0.1609707623720169, 0.1977132767206058, 0.13701965304790065, 0.11788025818532333, 0.14529780572047457, 0.07897820541984402, 0.07685241245781071, 0.15715751855168492, 0.16501073230756447, 0.15126404963666573, 0.13206402130890638, 0.05818182115035597, 0.35939433379098773, 0.13363753765588626, 0.1423095481004566, 0.12471643276512623, 0.14239189680665731, 0.14824018377112225, 0.14552515523973852, 0.15933316899463534, 0.10693279327824712, 0.18015492358244956, 0.12062726586009376, 0.2084193506743759, 0.14844985533272848, 0.22339014656608924, 0.13690476858755574, 0.11680510142468847, 0.18507954839151353, 0.11797762796049938, 0.11766283860197291, 0.18389457603916526], [0.06752495944965631, 0.06735333779943176, 0.08301536261569709, 0.0058595815244189, 0.037723967543570325, 0.028080535885237623, 0.09575101008522324, 0.03425557377340738, 0.017246897878067102, 0.009756197287060786, 0.01212168725032825, 0.01649572568567237, 0.07207975722849369, 0.022995130348135717, 0.04062953135871794, 0.020334050386736635, 0.018418277795717586, 0.009940649742929963, 0.032938795993686654, 0.11555895383935422, 0.0430177291855216, 0.022625370111200027, 0.0667639983294066, 0.07301234742044471, 0.056383367264061235, 0.0188624401926063, 0.29376262275036424, 21.73843402415514, 76.33992522954941, 108.70254546403885, 98.58579352498055, 79.87012580037117, 59.26464468240738, 24.070752672851086, 27.748691216111183, 63.748400285840034, 120.26018008589745, 54.12888586521149, 41.82808332145214, 30.397960357367992, 13.185832053422928, 0.045852803814341314, 0.06878096275613643, 0.1007743256923277, 0.04514946303970646, 0.07768421899527311, 0.2139169431757182, 0.5696009541861713, 1.5226468141190708, 3.104823133908212, 0.5386199103668332, 0.4991498251911253, 0.49582791281864047, 10.876162089407444, 39.29754450917244, 82.81156316399574, 91.32594868540764, 89.2147895693779, 81.4996987581253, 88.7601287662983, 84.59471628069878, 82.50485122203827, 79.45677638053894, 68.25622379779816, 66.66065901517868, 68.00129547715187, 66.96211203932762, 66.69201493263245, 75.86064174771309, 87.77898341417313, 85.0489591062069, 80.67306071519852, 70.76971292495728, 76.09850898385048, 87.73228392004967, 85.75892820954323, 78.96421641111374, 77.70982012152672, 76.51346191763878, 72.41065487265587, 72.62564733624458, 71.42022281885147, 76.84998705983162, 80.59752836823463, 85.02414643764496, 70.17116144299507, 24.24911320209503, 37.00397238135338, 83.78382459282875, 81.24041587114334, 75.84548056125641, 67.46018171310425, 69.83063131570816, 67.3731055855751, 68.77189412713051, 65.88271155953407, 70.08239820599556, 83.78972947597504, 88.67482334375381, 90.74701175093651, 88.25058370828629, 90.7542085647583, 88.72219160199165, 87.47272744774818, 86.76655814051628, 83.44378843903542, 67.26145997643471, 69.1473899781704, 74.83525916934013, 89.05175551772118, 83.8537560403347, 83.69647487998009, 82.45055213570595, 86.58360555768013, 93.28351244330406, 90.69174751639366, 39.80444870889187, 4.753833711147308, 0.4784969240427017, 0.3485430363798514, 0.26919839554466307, 0.5198063480202109, 0.32210648932959884, 0.07178380357800052, 0.05072878455393948, 0.11047637774026953, 0.043616182229015976, 0.6334086740389466, 1.790556781925261, 6.597984954714775, 24.120085425674915, 36.22835040092468, 51.61421500146389, 56.87051475048065, 45.839216485619545, 18.515688255429268, 14.686930105090141, 37.44765557348728, 49.38392847776413, 61.9060767441988, 70.81857070326805, 53.47697004675865, 11.39755206182599, 1.6952016111463308, 0.0343018912099069, 0.07356744419666938, 0.05434618673461955, 0.03817739379883278, 0.076197244488867, 0.02133280304406071, 0.006352805448841536, 0.02821956240950385, 0.018786522196023725, 0.05329372484993655, 0.00635999314908986, 0.07920677948277444, 0.0182956193384598, 0.037028148435638286, 0.04968882043613121, 0.012121449763071723, 0.030257969337981194, 0.017698422379908152, 0.01559014039230533, 0.06661993262241594, 0.07018197429715656, 0.010167961227125488, 0.008883832379069645, 0.019693688263942022, 0.16747521178331226, 0.05209031754930038, 0.0774295510200318, 0.04800599315785803, 0.03776117511733901, 0.07326213948545046, 0.034000727682723664, 0.0654452019080054, 0.028761384019162506, 0.017112001405621413, 0.009643513294577133, 0.029222769808257, 0.0030369197793334024, 0.12493913643993437, 0.12660187378060073, 0.05190403106098529, 0.024100130722217727, 0.056387820150121115, 0.050154043128713965, 0.03408136573852971, 0.07362301621469669, 0.05432670906884596, 0.060137176187708974, 0.04776498812134378, 0.031459376550628804, 0.03519725527439732, 0.06949311282369308, 0.08094063683529384, 0.038584751237067394, 0.036905011293129064, 0.03451602678978816, 0.020262937796360347, 0.04080790655279998, 0.09088013161090203, 0.5623145482968539, 25.12015376240015, 91.91294878721237, 123.21357920765877, 114.3273076415062, 94.0189477801323, 76.97899773716927, 47.910219356417656, 46.24880410730839, 53.76266531646252, 94.92129296064377, 44.10620927810669, 40.12652322649956, 37.26599492132664, 17.446632720530033, 0.11790039265179075, 0.15145797282457352, 0.07521101186284795, 0.053024748267489485, 0.0262387888142257, 0.7324528531171381, 0.8989550499245524, 2.3421921813860536, 2.439745534211397, 0.34866560949012637, 1.0587531002238393, 0.9847154386807233, 12.053955439478159, 43.74893344938755, 86.23213201761246, 93.18717241287231, 90.71701616048813, 83.88502836227417, 90.31331822276115, 89.97807741165161, 86.92151382565498, 83.14668238162994, 70.86842402815819, 70.96227139234543, 69.4120305776596, 69.68915730714798, 69.16838005185127, 80.57933494448662, 89.35393050312996, 90.19739404320717, 83.88594031333923, 73.8600642979145, 80.26098042726517, 91.24958038330078, 88.19345757365227, 83.71719136834145, 81.54062256217003, 81.29118114709854, 76.61522045731544, 77.10643529891968, 74.1517898440361, 79.031320810318, 83.77979680895805, 90.28920471668243, 73.99690255522728, 31.571004912257195, 45.065065026283264, 87.46822848916054, 85.92152908444405, 78.36148515343666, 70.50917610526085, 73.29294472932816, 70.86374267935753, 72.01654002070427, 68.3688573539257, 73.50587770342827, 86.81518793106079, 91.55943095684052, 93.89918580651283, 90.46837270259857, 92.91658893227577, 90.63370943069458, 86.93314880132675, 90.5271403491497, 88.10191288590431, 70.66038519144058, 71.6871052980423, 79.22558918595314, 91.01868197321892, 88.69342714548111, 88.55322986841202, 86.36786833405495, 87.82575130462646, 95.65251052379608, 100.11784851551056, 51.042596474289894, 7.385547319427133, 0.12022202354273759, 0.2227203582879156, 0.059300950160832144, 0.30208871816284955, 0.31260572257451713, 0.02125032631738577, 0.06388701091054827, 0.03239466073864605, 0.03644152151537128, 0.19257994514191523, 1.0864679818041623, 9.926418252289295, 27.791110239923, 38.92981544137001, 44.432809352874756, 46.0709660500288, 34.34095747768879, 20.769674107432365, 32.90689542889595, 55.81479460000992, 60.788210928440094, 74.14396226406097, 87.819002866745, 77.6479822397232, 19.460106678307056, 1.9252337864600122, 0.07110106482286938, 0.04584796872222796, 0.10927316339802928, 0.04679645942815114, 0.020796209864784032, 0.020722215886053164, 0.031812946835998446, 0.022819512232672423, 0.05932164494879544, 0.023903699075162876, 0.004940321232425049, 0.035130885007674806, 0.03041778712940868, 0.021017865255998913, 0.03279828517406713, 0.007046037244435865, 0.02300614938576473, 0.008112765062833205, 0.0409242938621901, 0.06707622727844864, 0.06675670301774517, 0.020075938846275676, 0.03379188732651528, 0.06263741975999437, 0.1292007413576357, 0.05032251065131277, 0.008789222465566127, 0.03377805740456097, 0.0626317052228842, 0.012091842709196499, 0.06456555653130636, 0.09117664929362945, 0.15877603873377666, 0.12374391502817161, 0.2101925789611414, 0.1046118006343022, 0.17963978403713554, 0.259686199715361, 0.3022715833503753, 0.14310521946754307, 0.11619116718065925, 0.10858499954338185, 0.11811907388619147, 0.12209390552015975, 0.18283041048562154, 0.18715293088462204, 0.12122560015995987, 0.11815075617050752, 0.1252431349712424, 0.0857776214252226, 0.1490227784961462, 0.1811260831891559, 0.17171354294987395, 0.09289371184422635, 0.1877293866709806, 0.1938240963499993, 0.11866474538692273, 0.22880282253026962, 0.8045676990877837, 35.99302522838116, 111.25054433941841, 135.23732721805573, 126.99116930365562, 110.19600212574005, 84.99496400356293, 40.46742953360081, 42.21471257507801, 86.50947153568268, 148.5349264740944, 70.79124256968498, 63.60931634902954, 48.66170883178711, 24.15705744177103, 0.40672008180990815, 0.1657841689302586, 0.20955678104655817, 0.25421369180548936, 0.15370291017461568, 2.7908925293013453, 3.4625618252903223, 3.715154933743179, 5.298744896426797, 1.4223262597806752, 1.7926832428202033, 1.959434801246971, 14.017938952893019, 48.656791895627975, 95.8312377333641, 98.925761282444, 95.25276437401772, 85.1213376224041, 92.03620657324791, 92.9352231323719, 91.03147208690643, 86.32363110780716, 76.09172254800797, 75.30464798212051, 73.5475766658783, 72.14285284280777, 73.8374251127243, 84.76386800408363, 95.23683562874794, 95.06095066666603, 89.91307809948921, 78.46420884132385, 83.71274560689926, 96.99257701635361, 93.30466210842133, 88.63936364650726, 85.62313869595528, 86.75168573856354, 82.36965447664261, 83.17249819636345, 79.69991013407707, 85.50561100244522, 89.11594927310944, 96.33620023727417, 77.32826739549637, 37.86985091865063, 54.283134788274765, 90.4819455742836, 92.39955827593803, 83.8382376730442, 77.03316763043404, 76.59814417362213, 74.10629868507385, 74.16084095835686, 70.64090743660927, 77.7840605378151, 93.11489269137383, 94.29480537772179, 97.55085065960884, 92.50527620315552, 95.89327320456505, 94.37378033995628, 91.23942732810974, 95.52058920264244, 93.2351790368557, 74.66168448328972, 75.48817813396454, 85.28143063187599, 97.09265604615211, 93.70576858520508, 92.88920000195503, 90.60382023453712, 93.4162849187851, 103.77834409475327, 109.27518233656883, 54.04576912522316, 6.270699491724372, 1.60887879319489, 1.6255578794516623, 1.3643996743485332, 1.6725847497582436, 1.5412798267789185, 0.6046742002945393, 0.27791667147539556, 0.3661516180727631, 0.20119826862355694, 1.1936573800630867, 3.4669515397399664, 16.775925010442734, 39.329329803586006, 57.11233377456665, 72.46939972043037, 73.2062865793705, 65.58115214109421, 27.19940599054098, 22.628258876502514, 58.180703446269035, 70.86750447750092, 84.50714617967606, 103.86749491095543, 87.46730893850327, 22.366804406046867, 2.642575087957084, 0.17566409893333912, 0.23374276526737958, 0.18023820739472285, 0.17266763316001743, 0.23127850843593478, 0.12211007691803388, 0.08830554710584693, 0.16356014530174434, 0.14009085309226066, 0.19137040770146996, 0.10687544752727263, 0.1564240243169479, 0.08119557940517552, 0.10670148069038987, 0.15873956959694624, 0.12432580333552323, 0.20060229435330257, 0.09555638927849941, 0.08429330380749889, 0.1695564016699791, 0.13677701528649777, 0.11979898452409543, 0.12042385060340166, 0.1324611742165871, 0.1902393449563533, 0.18080053268931806, 0.09849632566329092, 0.11289520771242678, 0.14479627716355026, 0.12602293922100216, 0.19176233588950709, 0.20787516346899793], [0.07179791180533357, 0.03126987656287383, 0.05400319947511889, 0.046624848910141736, 0.02919340673543047, 0.02293083438416943, 0.029160934063838795, 0.027643633547995705, 0.0287532408037805, 0.03579199386877008, 0.03829490546195302, 0.030350222004926763, 0.035586207450251095, 0.03544059436535463, 0.013657446834258735, 0.05682978764525615, 0.04772396590851713, 0.02692152942472603, 0.006941538676983328, 0.01102139209251618, 0.06813120504375547, 0.03771156996663194, 0.026836956130864564, 0.05350564140826464, 0.049868917412823066, 0.588099667802453, 30.338491648435593, 88.39614629745483, 98.45197230577469, 95.05184635519981, 72.05855816602707, 57.204547226428986, 37.59006813168526, 30.12810453772545, 38.89495991170406, 77.303766310215, 61.91901125013828, 58.19416232407093, 41.69989340007305, 17.02727772295475, 1.184687961358577, 0.02056648547295481, 0.2247089726733975, 0.062090338178677484, 0.3514041641028598, 0.04162329307291657, 0.13090975902741775, 0.4554915038170293, 3.010564441792667, 0.9375878737773746, 0.2657122310483828, 0.9013733232859522, 13.18829907104373, 53.755795285105705, 83.93115788698196, 80.98385363817215, 80.89065983891487, 87.26074442267418, 87.35306426882744, 80.97286462783813, 88.86802017688751, 89.63019087910652, 82.66525581479073, 81.52239874005318, 71.11174017190933, 63.550434708595276, 63.250585198402405, 62.91019946336746, 62.62074239552021, 73.21042075753212, 70.14542162418365, 67.92125657200813, 64.7963498532772, 65.16085669398308, 73.50025400519371, 78.37837144732475, 77.87913903594017, 79.80399414896965, 79.79584738612175, 79.96911808848381, 70.01927599310875, 71.63403734564781, 63.33699256181717, 76.89958199858665, 70.48419624567032, 94.72922846674919, 41.89325362443924, 37.58406065404415, 94.48326006531715, 72.21157595515251, 81.35004758834839, 67.67708167433739, 70.21193325519562, 65.49322485923767, 66.81805416941643, 61.967686638236046, 70.4172894358635, 79.34102699160576, 87.98738703131676, 79.86857548356056, 87.46068209409714, 82.81061321496964, 89.44167539477348, 83.78427296876907, 88.45283165574074, 78.54906588792801, 67.74790227413177, 63.54234114289284, 67.7060741186142, 69.40981149673462, 73.09443578124046, 70.0152026116848, 69.74933087825775, 76.77727416157722, 84.23064261674881, 82.04257562756538, 79.50783044099808, 54.12636660039425, 15.03903441131115, 0.22521979291923344, 0.15982355049345642, 0.20968313910998404, 0.2968012128258124, 0.07453467042068951, 0.09443610993912444, 0.1713061484042555, 0.004363667385405279, 0.12078115760232322, 0.08638929954031482, 2.274241615086794, 9.889874663203955, 26.86388399451971, 40.69430395960808, 36.8474929779768, 58.909302949905396, 77.8445152938366, 25.214958675205708, 19.411087408661842, 40.32909795641899, 43.62307660281658, 49.28256131708622, 62.243798822164536, 59.85064543783665, 21.544243544340134, 3.6441348446533084, 0.05588386477029417, 0.06096057048125658, 0.00777103156906378, 0.02162165990739595, 0.05294796566886362, 0.01904552616906585, 0.0710122668533586, 0.05114001971378457, 0.05127480486407876, 0.06941478655789979, 0.06156322036986239, 0.013901676502428018, 0.06936662859516218, 0.04740935837617144, 0.04100297635886818, 0.037890999010414816, 0.002806303882607608, 0.03629210121289361, 0.07810571434674785, 0.04743456913274713, 0.025192388420691714, 0.0032101797205541516, 0.024243278021458536, 0.021086753258714452, 0.08135907453834079, 0.031332996222772636, 0.019760271898121573, 0.02789997321087867, 0.016982502202154137, 0.04180661839200184, 0.10695631193812005, 0.030735554355487693, 0.0488643426069757, 0.026410677637613844, 0.02614770688524004, 0.04727012405055575, 0.03510734408337157, 0.007077809514157707, 0.05674785454175435, 0.01977163974515861, 0.0568297097197501, 0.0371231804456329, 0.053904363958281465, 0.0077355749999696855, 0.055611084681004286, 0.04005986251286231, 0.011097008591605118, 0.08375529869226739, 0.03510279471811373, 0.050662510766414925, 0.0403676088899374, 0.11290395021205768, 0.006764960407963372, 0.013127013480698224, 0.04934372176649049, 0.05857955293322448, 0.790918831480667, 35.9966616332531, 99.96451914310455, 113.51717591285706, 107.51787543296814, 87.75208085775375, 76.87304422259331, 56.97687104344368, 32.12791822850704, 37.51683086156845, 74.02408629655838, 73.15253466367722, 51.93937495350838, 46.56444936990738, 25.093925669789314, 1.5156925935298204, 0.020519097488431726, 0.12908159696962684, 0.06989396904828027, 0.19350760005181655, 0.11744072122382931, 0.11343255231622607, 0.4518179618753493, 2.835360118187964, 2.5030510872602463, 0.3195753798354417, 1.4198569860309362, 15.542819928377867, 59.637412279844284, 86.90092653036118, 85.97746968269348, 87.57241129875183, 94.54044699668884, 88.65357488393784, 84.03628304600716, 90.19245430827141, 92.2953450679779, 87.23267912864685, 85.12924879789352, 73.56581568717957, 66.32994756102562, 66.25565394759178, 66.67227879166603, 65.25490164756775, 73.58886525034904, 73.09739202260971, 70.36168321967125, 67.19574630260468, 66.62789717316628, 76.94430559873581, 83.95964115858078, 79.44812044501305, 85.1787905395031, 82.73493647575378, 83.90774354338646, 75.85358932614326, 73.68490889668465, 65.67404195666313, 79.94274750351906, 74.32370021939278, 96.14658281207085, 47.759200260043144, 41.73885650932789, 100.97100153565407, 76.26057028770447, 85.1990282535553, 72.30621367692947, 71.88787892460823, 69.56289008259773, 69.478739798069, 65.98857387900352, 73.21020036935806, 81.09188184142113, 90.0680261850357, 83.21548148989677, 87.65327095985413, 86.16087824106216, 93.15627247095108, 85.80749720335007, 93.16558197140694, 81.21990457177162, 71.6082975268364, 67.64251112937927, 70.54136797785759, 72.16017231345177, 76.50443360209465, 74.17239993810654, 76.1907072365284, 82.10732415318489, 86.5777538716793, 83.26354891061783, 79.01078671216965, 59.89995539188385, 18.55613898485899, 0.7236500910948962, 0.14458399324212223, 0.05548083776375279, 0.2852991409599781, 0.06126331849372946, 0.09020948986290023, 0.05951128594460897, 0.16894660860998556, 0.08913046651287004, 0.12774923408869654, 1.6479119611904025, 13.021931648254395, 31.604009941220284, 39.644253104925156, 35.562960505485535, 50.54826959967613, 55.491507947444916, 21.681634671986103, 34.09375034272671, 63.60524296760559, 61.32203668355942, 62.60696813464165, 75.18905818462372, 83.12991008162498, 33.65048512816429, 4.716900642961264, 0.012167723598395241, 0.02544177601521369, 0.033433964345022105, 0.09301989179220982, 0.030933160451240838, 0.11704698961693794, 0.06267978897085413, 0.08912996927392669, 0.06307455958449282, 0.03172220443957485, 0.03334452812850941, 0.0232781131126103, 0.042003298658528365, 0.02584382709756028, 0.09332248766440898, 0.029275098640937358, 0.06523221294628456, 0.05460195679916069, 0.016315804969053715, 0.031308011821238324, 0.04815348016563803, 0.05883170131710358, 0.05046643906098325, 0.020722952467622235, 0.08284332536277361, 0.028794821482733823, 0.05709230754291639, 0.03203266707714647, 0.04604735782777425, 0.014984987610660028, 0.06302573368884623, 0.23648715316085145, 0.14528536732541397, 0.11774955113651231, 0.13138652953784913, 0.20380575995659456, 0.1493233334622346, 0.09910453052725643, 0.14879737340379506, 0.09307591652031988, 0.16337042266968638, 0.08536609311704524, 0.2592736546648666, 0.1089340538601391, 0.20374861458549276, 0.13861248007742688, 0.14051001810003072, 0.1323394471546635, 0.16877404443221167, 0.18183912383392453, 0.11827115478808992, 0.2051126374863088, 0.2196127484785393, 0.13865712768165395, 0.2144081113510765, 0.16761001548729837, 0.9845065686386079, 48.26019577682018, 122.56759867072105, 124.59297358989716, 119.10975381731987, 100.3489825129509, 85.77221229672432, 57.430125921964645, 44.27272014319897, 52.38863244652748, 98.08070182800293, 75.08152395486832, 83.73245894908905, 65.39670243859291, 32.12451361119747, 2.800143607892096, 0.18209313129773363, 0.4543023754376918, 0.21293344907462597, 0.8616171847097576, 0.4339334199903533, 0.5021418677642941, 2.482626708224416, 6.581069212406874, 4.874493861570954, 1.2348171276971698, 1.6394795011729002, 15.925453696399927, 67.60048538446426, 93.74552205204964, 91.62073686718941, 91.49288892745972, 98.0268283188343, 90.9341137111187, 84.95496734976768, 94.30691912770271, 95.11534854769707, 92.15555056929588, 86.86770111322403, 77.75123029947281, 68.32238584756851, 71.11999332904816, 69.20054152607918, 67.8611969947815, 80.10103940963745, 78.63565564155579, 73.2003664970398, 71.74794003367424, 70.48389986157417, 80.88907912373543, 87.28585347533226, 87.13174894452095, 90.64904540777206, 87.26113200187683, 86.88701167702675, 80.5702306330204, 76.40297144651413, 69.45529505610466, 84.13898393511772, 77.58500441908836, 99.19035628437996, 53.16949054598808, 48.046529442071915, 103.1769123673439, 81.70750200748444, 89.41208258271217, 75.25158002972603, 75.34748688340187, 75.66362991929054, 72.4236349761486, 67.38541692495346, 77.52958059310913, 87.15687319636345, 93.90980243682861, 85.48710599541664, 92.06138402223587, 92.89024114608765, 99.26226362586021, 90.92842161655426, 96.77027374505997, 87.23002687096596, 75.02337947487831, 71.40889182686806, 72.92473688721657, 75.6661605834961, 79.82784166932106, 78.3506253361702, 79.28294330835342, 85.53879082202911, 91.55550196766853, 84.29197132587433, 83.11049312353134, 65.73027893900871, 18.342799432575703, 1.103931963443756, 0.34397229726891965, 0.626317304559052, 0.9535862028133124, 0.18598177732201293, 0.2867414604406804, 0.49960396019741893, 0.4892023152206093, 0.18334143853280693, 0.396383092738688, 4.051289409399033, 21.692355796694756, 46.05339199304581, 58.65253172814846, 53.77422049641609, 77.60824397206306, 93.8376747071743, 36.506746262311935, 28.089179545640945, 58.28716613352299, 67.70553454756737, 75.3204171359539, 91.80201753973961, 99.02613669633865, 40.69233566522598, 6.151934489607811, 0.1376017788425088, 0.3454236115794629, 0.11506833485327661, 0.1557719288393855, 0.19861755397869274, 0.16442145220935345, 0.14087221585214138, 0.19929353176848963, 0.18568527448223904, 0.18932745326310396, 0.1973970772814937, 0.1375528416247107, 0.14659482752904296, 0.17768754973076284, 0.17849193391157314, 0.19442620076006278, 0.19730381900444627, 0.13747349119512364, 0.2164386273943819, 0.163897332677152, 0.13673833454959095, 0.10187787702307105, 0.1733699275064282, 0.18672781385248527, 0.15641277335816994, 0.17632110742852092, 0.16467168956296518, 0.13761041744146496, 0.12237312374054454, 0.15217862790450454, 0.21632498974213377], [0.08698272082256153, 0.03393755978322588, 0.009607095180399483, 0.07731752382824197, 0.06335592261166312, 0.06290115677984431, 0.05697010921721812, 0.020811817230423912, 0.027820427967526484, 0.022998983949946705, 0.012078648251190316, 0.10264780328725465, 0.03852156107313931, 0.03858614276396111, 0.04822208429686725, 0.026497479229874443, 0.011712564428307815, 0.05163352565432433, 0.02585443238785956, 0.1207977371814195, 0.054418765066657215, 0.11878797900862992, 0.033326482807751745, 0.07329005165956914, 0.07271649767062627, 14.031465277075768, 92.82796248793602, 96.01932764053345, 98.21723610162735, 85.07567167282104, 54.971388056874275, 23.39336682111025, 22.172404937446117, 55.131769850850105, 76.84013798832893, 54.50775973498821, 42.85866022109985, 35.411059856414795, 14.411033559590578, 0.9003685740754008, 0.0778446787444409, 0.049385627135052346, 0.1432997512165457, 0.07032174296909943, 0.135169078130275, 0.1982864225283265, 0.09338778923847713, 0.1265928937937133, 1.142424016725272, 1.3257058756425977, 2.505104639567435, 17.520922534167767, 47.14307092130184, 79.49013099074364, 79.95086386799812, 79.36109751462936, 79.95857745409012, 81.34198442101479, 88.75291675329208, 83.20576161146164, 81.72832489013672, 83.43485891819, 87.92457640171051, 83.44537675380707, 78.34693193435669, 65.48388496041298, 65.06996557116508, 62.105824425816536, 62.30724781751633, 62.05634728074074, 62.002998143434525, 60.8042498677969, 62.050985768437386, 62.10722275078297, 60.8450710773468, 72.80395656824112, 79.6803791821003, 83.35931897163391, 80.28513953089714, 80.86709350347519, 75.30579552054405, 71.57692641019821, 62.18907795846462, 63.908877074718475, 66.50544494390488, 83.37647885084152, 65.49447879195213, 34.001445695757866, 88.69300156831741, 74.91613402962685, 85.19845828413963, 76.35412126779556, 72.0586721599102, 63.86167600750923, 64.77913677692413, 61.191160306334496, 65.30882075428963, 74.24300774931908, 82.42464512586594, 83.88448879122734, 83.88741463422775, 77.55237177014351, 81.60425394773483, 84.20752465724945, 83.92970636487007, 68.1676809489727, 62.29745954275131, 63.62868010997772, 65.36454856395721, 61.83233790099621, 61.079244911670685, 68.51697340607643, 74.0816380083561, 76.84236466884613, 83.52599322795868, 87.71055668592453, 77.36161440610886, 87.98491716384888, 84.03561428189278, 41.32006958127022, 1.2396889412775636, 0.18741942127235234, 0.1135946818976663, 0.05135464140039403, 0.13135682878782973, 0.028624567239603493, 0.07040562049951404, 0.1401232701027766, 0.0977669503481593, 0.1871370934532024, 1.6110985865816474, 11.49944644421339, 26.807797104120255, 38.11486937105656, 40.41762560606003, 50.815946236252785, 80.19246250391006, 20.069493278861046, 11.561923641711473, 20.664412155747414, 39.68078814446926, 57.34942205250263, 60.51836460828781, 53.68615262210369, 33.51086921989918, 8.00727043300867, 0.07043122459435835, 0.041392741186427884, 0.0435842847218737, 0.06853939368738793, 0.045631116881850176, 0.04210650542518124, 0.06230875223991461, 0.04390523761685472, 0.029888522658438887, 0.04973533454176504, 0.029855662214686163, 0.06923198074218817, 0.011840848364954581, 0.05891797969525214, 0.04122368365642615, 0.021755435736849904, 0.07018377029453404, 0.08520431976648979, 0.039426784569513984, 0.013848545222572284, 0.03913204061973374, 0.10053969570435584, 0.05886634477064945, 0.09586060303263366, 0.008192508830688894, 0.07893251880886964, 0.028777277111657895, 0.05183054359804373, 0.0348812153970357, 0.06643110798904672, 0.14194827061146498, 0.007787626454955898, 0.017255048514925875, 0.05505677829205524, 0.01037336729496019, 0.018648093100637197, 0.02829031876899535, 0.03420896318857558, 0.03547380547388457, 0.0051718944996537175, 0.03192829513864126, 0.0016355673142243177, 0.017351069436699618, 0.07568236469523981, 0.09971281702746637, 0.023492283944506198, 0.029537438567786012, 0.05901816963159945, 0.057383203456993215, 0.07242768348078243, 0.018344452655583154, 0.04514325497439131, 0.053245852614054456, 0.14587405370548368, 0.06331753873382695, 18.22576381266117, 109.13244679570198, 111.14281252026558, 111.79335281252861, 94.23660770058632, 70.50264045596123, 46.84027656912804, 40.616738721728325, 60.35287208855152, 51.671124547719955, 44.67676006257534, 44.34385612607002, 45.64948886632919, 20.113398022949696, 1.4012200548313558, 0.05031729335314594, 0.051486825323081575, 0.0950098865723703, 0.07660866889636964, 0.16097502229968086, 0.3881273529259488, 0.18436134239891544, 0.5519776185974479, 1.1718870420008898, 2.0599981863051653, 4.273132905364037, 18.372825421392918, 52.91412144899368, 84.70579192042351, 86.03104680776596, 83.54524299502373, 83.81503611803055, 84.65835526585579, 92.06633895635605, 86.1791780591011, 82.65129536390305, 85.7499910891056, 90.24591743946075, 86.62537291646004, 82.69785806536674, 68.31949040293694, 67.59901866316795, 64.20650750398636, 64.16596367955208, 63.38099040091038, 64.01672288775444, 64.02890503406525, 64.92786839604378, 65.7821461558342, 64.13556531071663, 74.71019268035889, 84.16981548070908, 84.84706073999405, 84.57995027303696, 84.69039514660835, 78.6928653717041, 74.81483906507492, 66.37384280562401, 66.0284261405468, 70.85155293345451, 87.49278277158737, 71.33152797818184, 37.699726447463036, 92.75873020291328, 80.05514547228813, 88.20715963840485, 78.94612178206444, 74.31134328246117, 66.6100001335144, 65.98164305090904, 65.11468917131424, 69.7891603410244, 77.9625141620636, 85.35721376538277, 86.39239981770515, 87.62206703424454, 80.31825095415115, 83.58451008796692, 86.5826404094696, 86.42491087317467, 70.65656259655952, 63.54221574962139, 66.23759731650352, 68.68446841835976, 65.48239544034004, 65.23928448557854, 71.81096345186234, 78.6220295727253, 78.62909719347954, 87.14586138725281, 88.60807612538338, 78.18930119276047, 90.43247982859612, 89.01631861925125, 47.044451013207436, 1.8139767064712942, 0.24932290893048048, 0.18735362245934084, 0.10895639992668293, 0.09924537531333044, 0.08795241097686812, 0.04833406695979647, 0.048488852989976294, 0.15678184339776635, 0.20395141385961324, 1.4175003999844193, 12.342973630875349, 33.67660492658615, 40.158027336001396, 37.270623072981834, 44.686084762215614, 49.659599885344505, 24.60144929587841, 25.865814350545406, 40.533834770321846, 57.347666546702385, 71.17326647043228, 73.0296340584755, 72.97860279679298, 46.53051719069481, 12.868813164532185, 0.051052490816800855, 0.02689669530809624, 0.04507258767262101, 0.04855470375332516, 0.09325496706878766, 0.047028517874423414, 0.03290493550593965, 0.03492557356366888, 0.020781420716957655, 0.016052466853579972, 0.039042188800522126, 0.06201418269483838, 0.0304384318224038, 0.03337054411531426, 0.05735187740356196, 0.030281597464636434, 0.026715832063928246, 0.024604921018180903, 0.04570126468024682, 0.025572492340870667, 0.06282821850618348, 0.022964257004787214, 0.04949706060870085, 0.02138480904250173, 0.013883417814213317, 0.05967883320408873, 0.019458874594420195, 0.11512471581227146, 0.06547082826728001, 0.0801021138613578, 0.23172226821770892, 0.14369729004101828, 0.09849375041085295, 0.20537650067126378, 0.20885929581709206, 0.158121123095043, 0.1190886452968698, 0.1694426898029633, 0.1464906003093347, 0.0827604868391063, 0.10022383023169823, 0.15743052499601617, 0.10593976257950999, 0.2583493839483708, 0.1919047540286556, 0.1291949674487114, 0.09384462566231377, 0.22677331580780447, 0.18607246776809916, 0.14480154641205445, 0.13169216079404578, 0.19204096781322733, 0.11683571501635015, 0.1971183711430058, 0.2258171624271199, 25.997391790151596, 127.73738086223602, 121.44538968801498, 125.66743433475494, 111.11696630716324, 77.429478764534, 41.6561995446682, 33.89575816690922, 75.52415460348129, 102.10049852728844, 73.29726129770279, 69.9643537402153, 57.27015070617199, 24.930469840765, 2.9492810927331448, 0.2452778775477782, 0.11798777311923914, 0.21687358530471101, 0.3116767614847049, 0.4133150732377544, 0.730193933704868, 0.47203397552948445, 1.285525169223547, 3.794070524163544, 4.112126519903541, 5.670982422307134, 19.20074589550495, 62.55709961056709, 92.3392479121685, 89.2063008248806, 89.13388431072235, 87.9985736310482, 89.21503275632858, 96.60879001021385, 88.32695201039314, 82.50189498066902, 86.04516685009003, 95.10298401117325, 90.68175405263901, 87.7271693944931, 72.08383440971375, 71.15745171904564, 67.46212720870972, 68.32701399922371, 69.51182082295418, 68.78245756030083, 66.67759090662003, 68.80759701132774, 69.07001093029976, 67.52257436513901, 80.72285324335098, 89.59756582975388, 89.6241720020771, 89.63478103280067, 89.28249433636665, 82.28583097457886, 80.57114258408546, 71.31942942738533, 69.57882642745972, 74.95458036661148, 90.46504408121109, 75.85287496447563, 42.37327806651592, 96.414605230093, 83.36793690919876, 91.92253947257996, 85.06158962845802, 79.5129069685936, 70.97531989216805, 70.83371669054031, 68.27470600605011, 73.29733729362488, 83.70702311396599, 88.81875962018967, 90.49384653568268, 90.63865676522255, 83.49811032414436, 88.6682040989399, 92.72554278373718, 94.16347682476044, 76.82496160268784, 67.94380456209183, 70.67510560154915, 71.70778378844261, 69.09985452890396, 68.38670119643211, 76.41557157039642, 83.55454489588737, 84.56115648150444, 91.47071331739426, 93.13123941421509, 78.60177665948868, 93.34022060036659, 92.75154858827591, 49.915576949715614, 1.8778082937933505, 0.7032180530950427, 0.7663827762007713, 0.23465921374736354, 0.37672211648896337, 0.24238036974566057, 0.35094628867227584, 0.39753597462549806, 0.5102557979989797, 0.3529124753549695, 3.0009421706199646, 22.152492105960846, 46.63379564881325, 56.62249065935612, 59.50452581048012, 68.47652837634087, 99.1609838604927, 30.375959537923336, 18.92510298639536, 33.647813871502876, 62.463058456778526, 82.93189510703087, 88.38996782898903, 87.81569704413414, 54.577451795339584, 15.44789057224989, 0.20949120487784967, 0.15447499608853832, 0.20668683660915121, 0.22230517119169235, 0.21016470389440656, 0.27802104712463915, 0.13349047367228195, 0.2253642593859695, 0.06706577041768469, 0.14261023665312678, 0.17168789432616904, 0.1738505720277317, 0.10415682700113393, 0.12715104821836576, 0.11146030970849097, 0.08197327595553361, 0.09712304075947031, 0.12166918924776837, 0.19259542634245008, 0.12615909363375977, 0.26114021544344723, 0.14877595502184704, 0.13295137759996578, 0.25217483402229846, 0.08831286468193866, 0.16577576781855896, 0.1261385064572096, 0.2485558547778055, 0.0891580076131504, 0.2920379606075585], [0.0615164984628791, 0.06527367673697881, 0.020605902791430708, 0.0690374786790926, 0.02951308313640766, 0.05400250927777961, 0.04032606346299872, 0.02720845670410199, 0.05018588497478049, 0.015973977315297816, 0.03219630692910869, 0.040969861729536206, 0.04125002618820872, 0.060980070411460474, 0.028835311204602476, 0.040690862442716025, 0.05514081167348195, 0.033299249698757194, 0.0931111685349606, 0.045597044882015325, 0.026660360235837288, 0.0018638056712916296, 0.0672835684963502, 0.12595176725881174, 4.9667600356042385, 82.2241298854351, 107.7678108215332, 112.31784626841545, 87.3925669491291, 71.56119525432587, 38.54629822075367, 25.124198645353317, 44.481104761362076, 42.27457456290722, 66.91147595643997, 54.33392286300659, 35.951185673475266, 17.657916583120823, 0.7689409889280796, 0.01694373055215692, 0.06499540846562013, 0.09256615012418479, 0.056961504014907405, 0.17716218339046463, 0.17243054666323587, 0.14002316922415048, 0.0615580179146491, 0.16716193640604615, 0.19893415417755023, 0.9511163353454322, 16.498946473002434, 42.34990172088146, 72.44237557053566, 75.72334751486778, 78.22188064455986, 70.9977462887764, 72.66805306077003, 82.02726244926453, 86.96112290024757, 85.79155325889587, 85.42796596884727, 78.71967673301697, 78.83158832788467, 84.03833493590355, 79.34326887130737, 68.43806684017181, 61.82398974895477, 63.629402071237564, 62.046790793538094, 65.95666319131851, 64.68948438763618, 62.94535517692566, 61.553368270397186, 60.532370656728745, 61.85217663645744, 63.427431508898735, 68.07135611772537, 77.31322780251503, 80.85466057062149, 80.32487779855728, 77.23132699728012, 68.84586095809937, 61.277263686060905, 65.8187609910965, 74.56342175602913, 79.60484683513641, 74.07463118433952, 23.18847231566906, 73.85054960846901, 86.7410159111023, 82.640450745821, 75.21691828966141, 63.329434767365456, 67.5761666893959, 65.78410685062408, 60.98957732319832, 62.46079757809639, 66.36990621685982, 80.3531102836132, 83.66978511214256, 82.99612686038017, 67.62277498841286, 64.17445242404938, 68.08869078755379, 65.84086060523987, 62.57287636399269, 65.28816506266594, 61.888742074370384, 62.69212916493416, 62.64711298048496, 67.07191094756126, 75.76900586485863, 82.8919668495655, 85.17379760742188, 80.51377326250076, 71.37489885091782, 82.49523773789406, 86.24293863773346, 79.4839297235012, 94.06377017498016, 65.85450947284698, 2.9956718534231186, 0.38979347446002066, 0.11323709288262762, 0.11513950681546703, 0.029737731238128617, 0.07917849623481743, 0.01593839504494099, 0.023192304142867215, 0.17129477870184928, 0.02687054202397121, 0.45867629698477685, 4.357287464663386, 17.811738029122353, 32.15987451374531, 34.327559396624565, 35.52363261580467, 64.14232894778252, 44.026892334222794, 11.69590350240469, 27.874287776649, 40.03638066351414, 58.99821437895298, 56.65103852748871, 71.64653867483139, 50.07714048027992, 5.880545927211642, 0.0639926407893654, 0.0234128296142444, 0.02029084997047903, 0.02714633894356666, 0.03953734601964243, 0.03669728415843565, 0.03102951348409988, 0.049394243469578214, 0.06922546468558721, 0.05432350670162123, 0.041583090933272615, 0.037829764405614696, 0.07902691257186234, 0.06751597204129212, 0.04410893488966394, 0.05637930771626998, 0.049053438124246895, 0.08016358595341444, 0.050280390059924684, 0.020176312464172952, 0.0447302312386455, 0.02009547402849421, 0.04517343440966215, 0.09433882922166958, 0.046158405384630896, 0.029453173265210353, 0.018070640981022734, 0.050034843079629354, 0.028959260998817626, 0.03762497246498242, 0.011536111396708293, 0.034685414575506, 0.08356400270713493, 0.04712534588179551, 0.03212019968486857, 0.04476222151424736, 0.04282424386474304, 0.0690599212248344, 0.08508462618920021, 0.02005622925935313, 0.027864784278790466, 0.010052355955849634, 0.04851820121984929, 0.04876857958151959, 0.007195621747086989, 0.041155124054057524, 0.05586138511716854, 0.08948032234911807, 0.04667102162784431, 0.04488869461056311, 0.034396893533994444, 0.06779519768315367, 0.09225274116033688, 7.191457059234381, 102.24348485469818, 118.36620971560478, 125.51742598414421, 101.61746084690094, 90.98740965127945, 54.83747184276581, 36.00091740489006, 45.279814302921295, 36.14172264933586, 55.99007539451122, 51.611577942967415, 45.953480154275894, 21.4344085380435, 0.9936430596280843, 0.05840571968292352, 0.045287038665264845, 0.15733308100607246, 0.06369561844621785, 0.2966357732657343, 0.3753163997316733, 0.10672121439711191, 0.09924323050654493, 0.22870165295898914, 0.7849201408680528, 1.4793835231103003, 18.406710103154182, 46.73995055258274, 80.77579960227013, 82.65759542584419, 83.57355907559395, 75.45095533132553, 77.6626418530941, 87.8841769695282, 88.67571249604225, 88.29983666539192, 88.77830699086189, 81.25749215483665, 81.59545361995697, 89.82854783535004, 83.33330556750298, 72.56304189562798, 65.02288609743118, 67.67448261380196, 64.85339999198914, 68.55019122362137, 67.1040116250515, 64.31195944547653, 63.539027720689774, 64.58610713481903, 64.60886791348457, 67.5025874376297, 72.14063376188278, 81.0746231675148, 82.5606170296669, 83.5913497209549, 79.56852838397026, 71.66315898299217, 63.32591615617275, 68.60375314950943, 79.68496173620224, 83.88000503182411, 77.64047384262085, 26.089907325804234, 74.8919977247715, 87.63045698404312, 86.75921693444252, 78.97452905774117, 67.20232754945755, 69.53634470701218, 68.12997937202454, 65.11253088712692, 64.13162112236023, 68.88614639639854, 82.92315557599068, 86.08732178807259, 85.72087705135345, 73.70863482356071, 68.37030127644539, 70.39841964840889, 67.51595512032509, 66.18793398141861, 67.29543775320053, 63.73706929385662, 65.6114213168621, 65.64207807183266, 71.13017678260803, 82.32803151011467, 87.12894469499588, 88.88580322265625, 85.61543270945549, 71.45141154527664, 87.28250205516815, 89.373689442873, 81.9546939432621, 97.11518123745918, 72.3750887811184, 4.144611926749349, 0.5146518058609217, 0.05655607987137046, 0.11061937475460581, 0.17069187277229503, 0.3451666800538078, 0.03759362043638248, 0.07340753363678232, 0.05809912734548561, 0.05558782948355656, 0.09687212805147283, 3.512767106294632, 19.800463914871216, 38.64831134676933, 36.299801766872406, 34.72120687365532, 47.60037638247013, 25.57663656771183, 14.642310999333858, 45.23122251033783, 58.77779200673103, 75.42521551251411, 70.81236943602562, 84.19634565711021, 63.75091955065727, 9.139091949909925, 0.038411493151215836, 0.012413724216457922, 0.06135229457868263, 0.025781154581636656, 0.015108674870134564, 0.03901933436281979, 0.024193038334487937, 0.08592800280894153, 0.06064865694497712, 0.008287261607620167, 0.0601721832936164, 0.05740947548474651, 0.05647208359732758, 0.06194641719048377, 0.0442344988550758, 0.059369598820921965, 0.03861665987642482, 0.03741353088116739, 0.04343765489466023, 0.0018916546468972228, 0.04044630622956902, 0.009772014309419319, 0.039311762811848894, 0.013193744616728509, 0.05213616001128685, 0.03585048623790499, 0.0275732111549587, 0.052468126377789304, 0.052884374745190144, 0.11682902826578356, 0.10527283156989142, 0.15438452828675508, 0.18827183725079522, 0.10390438546892256, 0.10399149134173058, 0.24612830457044765, 0.08293397870147601, 0.15282172855222598, 0.1668988005258143, 0.08745361352339387, 0.12460585276130587, 0.1358100413926877, 0.15026096283691004, 0.16001938842236996, 0.0917118342476897, 0.15146653720876202, 0.0752537595690228, 0.26483032212127, 0.1473479886772111, 0.21196977031650022, 0.15640106226783246, 0.1948696785257198, 0.2755193266784772, 9.782161843031645, 122.73689478635788, 130.20952820777893, 139.52877134084702, 113.75082537531853, 97.47124493122101, 55.27352124452591, 37.241786420345306, 60.86475022137165, 58.086487501859665, 85.8267393708229, 83.61822947859764, 57.37513147294521, 30.84962122142315, 1.9526044302619994, 0.22170912270667031, 0.2725534373894334, 0.3435768513008952, 0.21338759892387316, 0.6633850873913616, 0.774953750660643, 0.4977610887726769, 0.15286364505300298, 0.6868551217485219, 2.36800039652735, 1.825003121048212, 20.914645828306675, 54.01972912251949, 90.73566555976868, 87.27317735552788, 90.49852028489113, 79.34117138385773, 83.10002088546753, 92.04876869916916, 94.70791161060333, 92.0288197696209, 90.96573561429977, 80.01568838953972, 81.15238979458809, 94.64206874370575, 85.85157483816147, 74.73362982273102, 69.8028852045536, 70.91038897633553, 67.6353371143341, 72.0542111992836, 70.5720703303814, 68.24250653386116, 68.09409409761429, 66.89839705824852, 67.24587321281433, 68.9420185983181, 77.6280865073204, 84.63055595755577, 86.18879154324532, 86.82646572589874, 83.52075710892677, 74.63829293847084, 66.49922087788582, 72.42178067564964, 83.64162102341652, 91.14156737923622, 82.78843760490417, 32.519943192601204, 78.46211895346642, 92.64491870999336, 91.81921541690826, 85.09685173630714, 71.20837658643723, 72.91416585445404, 71.89043998718262, 67.31740817427635, 68.2871313393116, 73.09706524014473, 87.25493833422661, 89.25709649920464, 91.84858024120331, 78.13901469111443, 70.99226698279381, 76.57664492726326, 71.69764593243599, 68.88412490487099, 69.68563109636307, 68.56504082679749, 69.6099391579628, 69.91553395986557, 75.32610163092613, 85.66109865903854, 92.06806406378746, 94.54695984721184, 87.12158069014549, 71.22603043913841, 90.96483126282692, 96.65665224194527, 84.93412926793098, 101.16906210780144, 74.65347692370415, 4.039520490914583, 0.9054269932676107, 0.2867523254826665, 0.26732548198197037, 0.21685745101422071, 0.4066727327881381, 0.17038892809068784, 0.32367758627515286, 0.45393694192171097, 0.2937753580044955, 0.9509375074412674, 7.830499168485403, 31.767849549651146, 53.2170145958662, 52.48367294669151, 51.080054864287376, 84.60670083761215, 59.72503937780857, 19.800874292850494, 41.60094290971756, 60.17900101840496, 86.49055615067482, 85.3063116967678, 96.55655801296234, 73.7935222685337, 11.724723055958748, 0.16076313913799822, 0.17612718424061313, 0.12853006250225008, 0.17397504503605887, 0.11809905074187554, 0.1161223923554644, 0.1269387494539842, 0.18898906360846013, 0.20942341710906476, 0.16984935704385862, 0.21318849554518238, 0.12020879847113974, 0.1350364860263653, 0.24199759965995327, 0.1309267245233059, 0.1322945175343193, 0.194547081773635, 0.09755526014487259, 0.21811562881339341, 0.20925637451000512, 0.10409341048216447, 0.1842917883186601, 0.16311240760842338, 0.20639364374801517, 0.1560321555007249, 0.12238533206982538, 0.15194399049505591, 0.14549812622135505, 0.12954727979376912], [0.04768364131450653, 0.09259515325538814, 0.08823640120681375, 0.030024140869500116, 0.06437443124013953, 0.05935964662057813, 0.015547732218692545, 0.03745587782759685, 0.03960847716371063, 0.04145542668993585, 0.010700487437134143, 0.027957851452811155, 0.03133569764031563, 0.015641168611182366, 0.04203185650112573, 0.03400767789571546, 0.02166199377825251, 0.06941080864635296, 0.04113565752049908, 0.01327278612734517, 0.084360957989702, 0.0431380832742434, 0.01982189427508274, 0.9811226127203554, 56.13286793231964, 112.49097257852554, 99.10547643899918, 79.14255604147911, 70.86430504918098, 35.08993148803711, 21.91103596240282, 40.888237953186035, 63.27589564025402, 77.95615330338478, 56.54162339866161, 30.978084728121758, 16.697143837809563, 0.7741769298445433, 0.09374160072184168, 0.005444254347821698, 0.03626690901000984, 0.04335206300311256, 0.07207571994513273, 0.04999601762392558, 0.2516101783839986, 0.05644879500323441, 0.14245082333218306, 0.24247870431281626, 0.26055145484860986, 11.827553138136864, 41.3507529348135, 66.50120437145233, 78.54727238416672, 77.35694825649261, 75.72528541088104, 66.13621115684509, 69.95922401547432, 75.58593168854713, 84.124476313591, 86.45079508423805, 83.04620057344437, 82.63174921274185, 78.21502581238747, 81.85535207390785, 79.35859724879265, 68.38936105370522, 63.03043261170387, 63.002633303403854, 69.48712974786758, 69.42512467503548, 69.602559953928, 65.49992009997368, 63.95693689584732, 59.77493070065975, 61.49337328970432, 58.76714117825031, 56.347294226288795, 62.105839625000954, 78.5831880569458, 77.07379505038261, 80.48018306493759, 68.73793914914131, 70.71815729141235, 72.70646139979362, 81.72606781125069, 77.74749130010605, 84.1474574804306, 25.08562881499529, 69.35245737433434, 80.83552479743958, 70.62620982527733, 66.66903376579285, 59.32799868285656, 65.73942124843597, 62.42636002600193, 60.71972340345383, 60.20456604659557, 61.23980909585953, 68.15486803650856, 77.74852484464645, 79.76340472698212, 69.38281014561653, 59.8265965282917, 62.0529730618, 61.896862238645554, 62.370187640190125, 61.53292916715145, 57.749962359666824, 60.44719822704792, 61.46609455347061, 70.57960152626038, 80.71082308888435, 81.652762144804, 79.63649913668633, 74.12877067923546, 80.67095562815666, 86.46299242973328, 77.42469102144241, 81.93774685263634, 75.32192185521126, 88.3915713429451, 72.92651519179344, 2.976602101698518, 0.47665521036833525, 0.013071957255306188, 0.05012502515455708, 0.07515072720707394, 0.0730960542568937, 0.03513416901114397, 0.16021675517549738, 0.09769239419256337, 0.04930048053211067, 0.18099874549079686, 0.4002756573027, 6.329075759276748, 26.570469439029694, 38.01352120935917, 43.53607267141342, 90.66427499055862, 74.92599070072174, 20.550328977406025, 14.240316320210695, 30.51637340337038, 60.53695701062679, 71.18856444954872, 66.83734193444252, 41.25363014638424, 3.470419328659773, 0.07834751348127611, 0.0069814184462302364, 0.09615081246010959, 0.03223672058084048, 0.05082596508145798, 0.027179414610145614, 0.022281967249000445, 0.026404502968944144, 0.03731730401341338, 0.03008336054335814, 0.042909011972369626, 0.05587941188423429, 0.01527747357613407, 0.05362899377360009, 0.01445291132768034, 0.056820629542926326, 0.04681877209804952, 0.028220234053151216, 0.06453374066040851, 0.03888790372002404, 0.037596529655274935, 0.008048677827900974, 0.017902852523548063, 0.09777860206668265, 0.027706519431376364, 0.0399169582669856, 0.05413110491645057, 0.04012134944787249, 0.03463931236183271, 0.06121481172158383, 0.04625783833034802, 0.017307896850979887, 0.029676448393729515, 0.052857868940918706, 0.024027361287153326, 0.024902915574784856, 0.022685617659590207, 0.017227633579750545, 0.030410977924475446, 0.07198810941190459, 0.06969864320126362, 0.01429948621080257, 0.08529800848918967, 0.0223824781642179, 0.043756963932537474, 0.04238852525304537, 0.022101822032709606, 0.026334318063163664, 0.02619573126139585, 0.04715495386335533, 0.08424595478572883, 1.6436501336283982, 72.6854257285595, 128.31955522298813, 113.79622533917427, 89.60080325603485, 79.9274343252182, 52.953544333577156, 37.466198578476906, 42.061409801244736, 48.982168436050415, 49.7863344848156, 48.802335485816, 41.19616962969303, 20.900181904435158, 1.2305789301171899, 0.14937258238205686, 0.10266231227433309, 0.06123541374108754, 0.11036616138881072, 0.20797563542146236, 0.2807075920281932, 0.20552375761326402, 0.06282501242822036, 0.2915109466994181, 0.6621362012811005, 0.7532801886554807, 13.753911070525646, 43.92071843147278, 73.37758898735046, 85.133595764637, 82.76370093226433, 80.35007804632187, 69.32534202933311, 73.05006176233292, 79.11006018519402, 88.33841979503632, 90.09422197937965, 86.23342394828796, 84.93742749094963, 79.4334988296032, 82.91544198989868, 83.18320602178574, 72.73007333278656, 65.41326954960823, 67.64542937278748, 72.38279476761818, 72.44821965694427, 74.09860029816628, 70.09523391723633, 67.06007838249207, 62.6677230745554, 64.27257835865021, 60.811914056539536, 60.95737785100937, 66.68343499302864, 80.18896669149399, 80.68601042032242, 83.00743505358696, 71.19639962911606, 72.95539364218712, 77.17389687895775, 85.85113406181335, 81.12259179353714, 86.32722571492195, 27.028631754219532, 71.43872022628784, 84.1563718020916, 73.88836517930031, 70.44390320777893, 61.7428071051836, 69.58692759275436, 68.71467679738998, 63.62263083457947, 63.88775020837784, 65.20455434918404, 71.60442933440208, 80.26476502418518, 83.37201029062271, 71.43383368849754, 61.980617344379425, 64.75816190242767, 64.30629014968872, 66.83251619338989, 63.369214832782745, 61.073001846671104, 60.79125076532364, 64.26361083984375, 74.52569738030434, 82.22520902752876, 83.90873149037361, 81.79928228259087, 75.23145630955696, 83.8198770582676, 90.20621716976166, 82.31575816869736, 85.15222236514091, 79.92602840065956, 92.2130186855793, 78.17244529724121, 4.5228255819529295, 0.7207390910480171, 0.20991363533539698, 0.2309665540815331, 0.13969772262498736, 0.240312137757428, 0.13941138720838353, 0.06955969831324182, 0.05253503470157739, 0.08057108439970762, 0.17223263072082773, 0.13636567251523957, 5.213825153186917, 31.6237897798419, 37.0659014582634, 42.490083798766136, 77.34041154384613, 42.2738716006279, 20.17119102180004, 25.174361653625965, 44.77831721305847, 71.00758776068687, 81.23057439923286, 78.69696155190468, 57.42124579846859, 6.175248138606548, 0.058211948635289446, 0.007209775894807535, 0.037892924883635715, 0.02310348576429533, 0.035469879512675107, 0.08397994679398835, 0.05126693438796792, 0.05145115028426517, 0.047420026749023236, 0.03606415797548834, 0.039788915528333746, 0.0178568096816889, 0.03155415994115174, 0.024399073372478597, 0.031480928519158624, 0.053985588310752064, 0.0445642870181473, 0.07076683119521476, 0.012541522974061081, 0.0756703493243549, 0.03824354884272907, 0.0185816300654551, 0.025680239195935428, 0.06439175296691246, 0.01685985116637312, 0.04499379014305305, 0.016964380811259616, 0.053203483403194696, 0.11882440361659974, 0.18570367974461988, 0.14206578227458522, 0.12199228323879652, 0.11822888205642812, 0.1243939547566697, 0.15817247971426696, 0.17225213436177, 0.12382967019220814, 0.18783490522764623, 0.07287543601705693, 0.15294963028281927, 0.16360756853828207, 0.146716985036619, 0.18729471077676862, 0.11892266396898776, 0.11863609848660417, 0.18675708415685222, 0.09907595784170553, 0.09208994364598766, 0.17148834565887228, 0.10899796761805192, 0.16576206777244806, 2.102624299004674, 90.09362921118736, 142.07762897014618, 124.47586387395859, 103.18654865026474, 95.10898768901825, 54.33232694864273, 36.57892718911171, 56.45760230720043, 88.00421252846718, 110.19320547580719, 83.18941488862038, 52.55945608019829, 29.49165388941765, 1.7572805425152183, 0.3134184336522594, 0.27866962482221425, 0.15246012451825663, 0.3126802045153454, 0.3367674385663122, 0.5894489516504109, 0.48444980930071324, 0.2260554363601841, 0.6024822522886097, 1.1212397972121835, 1.7758173728361726, 15.4269764944911, 50.03024339675903, 81.27025946974754, 90.48962116241455, 88.6301377415657, 85.05911976099014, 73.73776406049728, 76.389140188694, 82.72039085626602, 92.67834931612015, 95.33332765102386, 88.25125247240067, 88.02679091691971, 80.43291360139847, 86.48049429059029, 88.94780829548836, 76.04485586285591, 68.88937622308731, 69.25721168518066, 76.502336114645, 76.87828794121742, 78.1829023361206, 72.53472581505775, 70.98396822810173, 65.28314173221588, 69.9947141110897, 63.41181814670563, 64.44070413708687, 71.55855059623718, 85.1589860022068, 84.84134584665298, 88.75778049230576, 77.01548337936401, 76.35255575180054, 79.22413766384125, 94.22301203012466, 84.99752506613731, 90.9149931371212, 33.520136922597885, 74.71694871783257, 87.32757523655891, 78.43231335282326, 73.24407175183296, 66.377954185009, 73.78499552607536, 71.97126165032387, 68.98873329162598, 69.13010090589523, 69.23291578888893, 75.13909086585045, 83.56652945280075, 87.71501764655113, 77.68906563520432, 65.87961092591286, 67.61858001351357, 70.91434836387634, 69.50531557202339, 66.2909160554409, 63.87963384389877, 66.15848556160927, 67.84711495041847, 79.8331005871296, 87.07260891795158, 87.7439796924591, 84.09596264362335, 75.20205348730087, 86.54525801539421, 94.69803214073181, 83.00205454230309, 87.90139764547348, 81.20186313986778, 96.88965573906898, 82.37019404768944, 4.253438087180257, 0.8820046938490123, 0.5661587545182556, 0.22040745505364612, 0.12886450393125415, 0.32316217955667526, 0.1064003245846834, 0.22952942963456735, 0.2059879116131924, 0.18560825439635664, 0.3127990965731442, 0.6960198737215251, 11.847947593778372, 45.331392735242844, 57.03737899661064, 61.16798534989357, 118.19563686847687, 98.41842010617256, 31.67670004069805, 24.27521590143442, 49.45320636034012, 85.243189483881, 92.75303810834885, 91.18198201060295, 65.18284991383553, 6.780889090150595, 0.1745103858411312, 0.11861149629112333, 0.2333755060681142, 0.11765955088776536, 0.20718599029351026, 0.14648932381533086, 0.11446807096945122, 0.10325957788154483, 0.10031612371676601, 0.09027111780596897, 0.13637729454785585, 0.17201032780576497, 0.12961340515175834, 0.1528360668453388, 0.11440051326644607, 0.24841693957569078, 0.1630878128344193, 0.33040797512512654, 0.1637013760046102, 0.1205638938699849, 0.07878841599449515, 0.08391450421186164, 0.07351684456807561, 0.20801029371796176, 0.1490285524050705, 0.13165307929739356, 0.22260496916715056, 0.15675503702368587], [0.09764368704054505, 0.029402141335594933, 0.023637841368326917, 0.009404892407474108, 0.046118618847685866, 0.06276007450651377, 0.010560452519712271, 0.03620263159973547, 0.05152123871084768, 0.04337348880653735, 0.024893746340239886, 0.02206282217230182, 0.0398427063919371, 0.01544639102576184, 0.04265360184945166, 0.062170645978767425, 0.09849547961493954, 0.05428633252449799, 0.020885137710138224, 0.09308036198490299, 0.03363783602253534, 0.06979982761549763, 0.05381788520026021, 28.809195309877396, 114.77676272392273, 94.07127857208252, 93.70609536767006, 66.93647101521492, 53.510571643710136, 31.34915191680193, 42.09683530032635, 73.37274044752121, 64.57886472344398, 48.800640776753426, 36.681491285562515, 16.275776848196983, 0.6603887106757611, 0.043650090956361964, 0.059435193543322384, 0.10983229003613815, 0.10707821711548604, 0.11902209691470489, 0.05054789347923361, 0.0384524671244435, 0.19547645846614614, 0.13311724760569632, 0.05725365044781938, 0.3783500619465485, 5.792189268395305, 27.611053101718426, 63.89943838119507, 77.52945899963379, 80.8269676566124, 79.64249521493912, 69.05731961131096, 62.41585358977318, 65.25068387389183, 74.9547703564167, 75.82221060991287, 76.80555984377861, 80.38418501615524, 82.40145117044449, 77.80440464615822, 77.70565554499626, 79.49614986777306, 71.47966682910919, 67.29536935687065, 64.12127807736397, 71.1515012383461, 75.00528484582901, 80.52863046526909, 75.24653390049934, 72.10328936576843, 63.55242200195789, 62.19638116657734, 58.118413388729095, 57.791699320077896, 59.147538766264915, 72.23113730549812, 74.76629287004471, 77.08182021975517, 66.96724936366081, 68.31238478422165, 72.25064545869827, 76.91667348146439, 73.03136676549911, 75.17816036939621, 31.45219288766384, 70.98206833004951, 77.86860600113869, 64.78156104683876, 62.33505852520466, 58.869659677147865, 67.35257148742676, 61.22434392571449, 60.09847193956375, 58.99536453187466, 65.25251537561417, 63.964718878269196, 65.66780269145966, 70.03451317548752, 64.52055305242538, 61.36671468615532, 60.94997584819794, 62.179046496748924, 62.908246368169785, 62.01277881860733, 58.689100965857506, 60.073271691799164, 57.784924283623695, 68.1660470366478, 79.6671786904335, 79.00091484189034, 78.23459476232529, 74.511349350214, 77.83417224884033, 83.61205860972404, 75.28266236186028, 69.10687655210495, 79.23470109701157, 78.93739745020866, 84.5863339304924, 72.62204512953758, 3.272622604854405, 0.34783404786139727, 0.5298924318049103, 0.028944983932888135, 0.030782754947722424, 0.12599610316101462, 0.10780274620628916, 0.038866700560902245, 0.04856187661061995, 0.1839260579436086, 0.028587029410118703, 0.03335861780215055, 1.7339602438732982, 28.02361026406288, 46.630003452301025, 26.800172813236713, 90.23521721363068, 93.21268424391747, 24.27962936460972, 25.591714158654213, 47.938755825161934, 59.068088829517365, 70.83126962184906, 77.88730099797249, 37.171383798122406, 0.339686899096705, 0.05668285353749525, 0.058075983470189385, 0.04378020799777005, 0.05476717371493578, 0.014090126351220533, 0.06994868017500266, 0.07052920293062925, 0.07163255388149992, 0.06737435542163439, 0.06739840100635774, 0.02198633643274661, 0.05473507582792081, 0.0868277381232474, 0.08893235761206597, 0.03466215937805828, 0.008845850188663462, 0.011009096560883336, 0.07978879395523109, 0.06673277617665008, 0.014065864615986357, 0.02115375620633131, 0.022207971414900385, 0.05324881749402266, 0.015478042696486227, 0.04885970789473504, 0.013312642240634887, 0.047080731674213894, 0.10053344682091847, 0.07095296925399452, 0.07632329085026868, 0.016350092191714793, 0.04236302505887579, 0.04182831879006699, 0.05408878394518979, 0.041586475126678124, 0.07881816127337515, 0.0599329594115261, 0.0317663696478121, 0.10581713009742089, 0.0327914314402733, 0.016508950757270213, 0.025281030539190397, 0.05709770666726399, 0.09981894414522685, 0.01946148695424199, 0.02356234639592003, 0.04019995772978291, 0.03477196383755654, 0.12573934975080192, 0.11991067774943076, 38.177843391895294, 130.10965436697006, 106.895020455122, 108.19198206067085, 80.92836141586304, 74.97104868292809, 43.61478544771671, 40.10661609470844, 41.83451257646084, 52.455900236964226, 46.24309301376343, 46.22472859919071, 19.902231954038143, 0.7468907721340656, 0.04979911842383444, 0.11053807989810593, 0.062193125631893054, 0.20554517599521205, 0.049229442156502046, 0.05012800116674043, 0.11418251480790786, 0.42659061087761074, 0.3935350268147886, 0.4497678828192875, 0.4852152010425925, 6.13790231756866, 33.21057893335819, 70.5312529206276, 84.34747114777565, 86.0243971645832, 84.57416698336601, 73.68712797760963, 65.78447923064232, 68.98706138134003, 77.77208358049393, 79.71722960472107, 81.00111991167068, 83.14796671271324, 86.50602132081985, 79.06060963869095, 79.97886076569557, 84.07877996563911, 76.28035962581635, 70.845967233181, 67.675212174654, 73.9419575035572, 78.87210175395012, 83.86132523417473, 78.77405181527138, 75.7010655105114, 66.06338426470757, 64.36911597847939, 59.58160847425461, 61.17313787341118, 61.0028500109911, 75.2049033343792, 79.99357357621193, 80.06567850708961, 69.66483861207962, 72.20887050032616, 75.71988210082054, 81.55333667993546, 77.78900787234306, 80.34288883209229, 36.63973152637482, 72.94344708323479, 81.90493941307068, 70.22798359394073, 65.4867348074913, 59.89459007978439, 69.27706182003021, 65.04944667220116, 62.24935792386532, 61.48000180721283, 65.27751043438911, 65.84640070796013, 68.5311010479927, 73.64574059844017, 66.51401728391647, 64.55088302493095, 62.9356998950243, 63.097613006830215, 64.93685871362686, 64.1158975660801, 62.11440056562424, 62.4498275667429, 60.865346789360046, 70.2458806335926, 81.45486876368523, 81.65569558739662, 81.70273706316948, 75.18066823482513, 78.94679814577103, 87.30989098548889, 80.43168246746063, 73.02679181098938, 81.70256227254868, 83.7798424065113, 86.7098119854927, 79.30567368865013, 5.056287981569767, 0.4401994025101885, 0.34184349118731916, 0.5344184045679867, 0.4171378759201616, 0.38826880627311766, 0.16486939770402387, 0.17721009644446895, 0.09255499564460479, 0.1549115718808025, 0.06701575708575547, 0.06964789514313452, 1.2207557447254658, 29.429069347679615, 36.05661101639271, 25.427355878055096, 82.5727991759777, 75.69604218006134, 26.47658597677946, 38.457394391298294, 64.43589359521866, 68.78872722387314, 80.40303200483322, 89.29621160030365, 52.29684837162495, 0.9823809983208776, 0.05183064378798008, 0.04875481274211779, 0.07972490988322534, 0.0018175220952798554, 0.03410105491639115, 0.00784996964284801, 0.011175298677699175, 0.04432446199643891, 0.05851156107382849, 0.03128089374513365, 0.04957264463882893, 0.013298396715981653, 0.03543061247910373, 0.041354505738127045, 0.043170095814275555, 0.007044184194455738, 0.0437368851271458, 0.017286996117036324, 0.0196935602434678, 0.03399102410185151, 0.02731112726905849, 0.023270290876098443, 0.0929709842603188, 0.03025438476470299, 0.007293182161447476, 0.004963733208569465, 0.02607267575513106, 0.22366212884662673, 0.1650872774189338, 0.14552298816852272, 0.07818217040039599, 0.11622572157648392, 0.18254707334563136, 0.13606811582576483, 0.12171523208962753, 0.14503830636385828, 0.13832375494530424, 0.1259969046805054, 0.31909811950754374, 0.18533607915742323, 0.15041216800455004, 0.1394933054689318, 0.24546863918658346, 0.1814620682853274, 0.2595131902489811, 0.11386125392164104, 0.2325595443835482, 0.11152158884215169, 0.24798110593110323, 0.2975037298165262, 45.81956014037132, 146.1005187034607, 119.25669953227043, 123.09776902198792, 90.5811582505703, 77.67138138413429, 44.243974685668945, 58.52393142879009, 99.37086179852486, 90.28127834200859, 69.98715251684189, 59.40973609685898, 27.314712703227997, 1.5770418453030288, 0.10304465933586471, 0.2935988752869889, 0.22723130998201668, 0.48127896850928664, 0.36367513064760715, 0.28161764319520444, 0.2788010146468878, 0.7874206441920251, 0.4444844741374254, 0.7455599529203027, 0.9133794321678579, 7.701974865049124, 38.02367426455021, 77.03943729400635, 90.07640093564987, 91.73159211874008, 87.75464951992035, 76.59233808517456, 68.94559800624847, 72.08299845457077, 83.18942248821259, 82.85874903202057, 84.5747597515583, 88.63263040781021, 90.60538575053215, 80.6396909058094, 82.95700415968895, 87.20453783869743, 79.15071040391922, 75.08298307657242, 70.4864913225174, 77.60120674967766, 81.58127278089523, 88.1339679658413, 80.81834971904755, 78.9267960190773, 69.1047790646553, 68.37527140974998, 62.7669395506382, 64.85289081931114, 64.6716557443142, 78.10284823179245, 83.74405592679977, 83.4618678689003, 73.19638431072235, 76.47312328219414, 79.39673960208893, 87.10504397749901, 80.33053949475288, 84.9514639377594, 42.28687450289726, 79.08079415559769, 87.29082360863686, 73.30622121691704, 69.73504364490509, 65.0743505358696, 72.6698237657547, 68.82769793272018, 66.11360996961594, 65.30173793435097, 69.9642625451088, 70.5150505900383, 71.0014320909977, 77.52261936664581, 70.88282525539398, 67.78207004070282, 66.92017748951912, 66.7169339954853, 68.06195542216301, 69.03219535946846, 65.50266355276108, 67.44243666529655, 62.49003700911999, 74.28182646632195, 86.58495828509331, 87.26203635334969, 85.62780484557152, 77.66824275255203, 80.86791425943375, 91.41224205493927, 83.5291850566864, 75.24154096841812, 84.90553200244904, 86.5431909263134, 89.56244051456451, 80.4093624651432, 5.077054817229509, 0.8383722882717848, 1.4613581215962768, 1.083119767718017, 0.254537565051578, 0.2871376188704744, 0.3842097631422803, 0.22639346978394315, 0.21997576259309426, 0.28873356292024255, 0.2317224018042907, 0.22643454023636878, 3.261267151683569, 48.232483863830566, 66.16611555218697, 32.89156325161457, 104.21678736805916, 113.89204859733582, 35.37131778895855, 38.73268201947212, 66.50599971413612, 83.1323267519474, 91.42040401697159, 98.08299690485, 59.47223134338856, 1.073791030794382, 0.09997855784604326, 0.21372668619733304, 0.17193995736306533, 0.18759519152808934, 0.1332915187231265, 0.20691480953246355, 0.08463434292934835, 0.23492644628277048, 0.16997823840938509, 0.1295458251843229, 0.26999866822734475, 0.16443325235741213, 0.18615169945405796, 0.14301749761216342, 0.16968641109997407, 0.12419637278071605, 0.11652630622847937, 0.15915440046228468, 0.22914392844540998, 0.16027238656533882, 0.14695181540446356, 0.08847094955854118, 0.15312492556404322, 0.10167787564569153, 0.135930729447864, 0.2137277103611268, 0.14385081070940942], [0.011979335904470645, 0.036536375409923494, 0.05658875663357321, 0.018151388503611088, 0.024797484220471233, 0.05329794767021667, 0.011738647208403563, 0.10842474759556353, 0.1279252566746436, 0.07246810084325261, 0.09077477632672526, 0.10173505812417716, 0.09054865877260454, 0.017319361177214887, 0.06269897348829545, 0.021422161335067358, 0.07972056089784019, 0.036400157914613374, 0.013972349370305892, 0.09988496560254134, 0.0721040774078574, 0.2401161365560256, 4.825002942234278, 92.10100829601288, 102.36899971961975, 91.18598699569702, 74.01061981916428, 38.73628042638302, 19.41593024879694, 34.81624737381935, 58.81027266383171, 67.72767215967178, 56.64261817932129, 45.16738213598728, 14.134729485958815, 0.12959642481291667, 0.07765574278892018, 0.057534809384378605, 0.04329148890974466, 0.11861229781061411, 0.026301106954633724, 0.02837299030943541, 0.04854667371546384, 0.10092855882248841, 0.03796154756855685, 0.07513268559705466, 0.17145313817309216, 1.644364376552403, 24.566703960299492, 57.28461652994156, 70.91227367520332, 83.0340488255024, 77.84375533461571, 78.48116353154182, 63.40839833021164, 62.89870128035545, 62.498096376657486, 67.66965687274933, 67.97279700636864, 70.96495404839516, 74.52092483639717, 77.31727078557014, 79.35445547103882, 78.12427148222923, 79.27009999752045, 74.85604405403137, 71.13402977585793, 67.84646898508072, 72.5078384578228, 72.97025084495544, 78.1233823299408, 79.04184624552727, 74.85779196023941, 71.42537534236908, 60.719799399375916, 56.681296303868294, 56.01477786898613, 56.015047654509544, 69.20288220047951, 78.0048742890358, 74.73394140601158, 70.55858865380287, 70.09593307971954, 66.99365794658661, 72.41061687469482, 76.08727678656578, 64.62076127529144, 39.69713106751442, 63.00315387547016, 79.90117773413658, 65.77647686004639, 66.69714465737343, 57.82886892557144, 62.96223007142544, 61.226635202765465, 63.21732938289642, 59.266742169857025, 63.1469913572073, 59.0398221462965, 60.35626910626888, 58.32168348133564, 61.099482625722885, 59.94076520204544, 60.701499581336975, 58.97525981068611, 62.480643913149834, 61.39975771307945, 61.44665099680424, 60.176892131567, 61.78161442279816, 57.72402495145798, 71.13461494445801, 73.23062807321548, 77.57792919874191, 79.19224977493286, 78.19541126489639, 81.13025218248367, 74.81938362121582, 68.87318149209023, 61.909553557634354, 75.83966687321663, 80.05174845457077, 85.44329434633255, 70.54245471954346, 12.367952540516853, 0.4567014123313129, 1.9452394754625857, 0.5723704711999744, 0.38672677183058113, 0.09494139376329258, 0.10865984513657168, 0.06578799249837175, 0.10375918427598663, 0.13228011986939237, 0.05031949753174558, 0.07092868618201464, 0.880418160231784, 38.09202119708061, 56.027533784508705, 76.74489229917526, 117.69791677594185, 69.64747354388237, 16.086372211575508, 15.884952619671822, 49.77768994867802, 68.00656959414482, 69.00435045361519, 72.95620679855347, 17.67391562461853, 0.14123368629952893, 0.11410134611651301, 0.02408997628663201, 0.02366647528106114, 0.07000357683864422, 0.03030479700100841, 0.04451883789442945, 0.12211504188599065, 0.03559387012501247, 0.022799019679951016, 0.015672036388423294, 0.0028788511372113135, 0.010851628594537033, 0.035654303210321814, 0.04284337643184699, 0.0478868190839421, 0.025114620621025097, 0.08559264853829518, 0.012416306890372653, 0.035445848770905286, 0.03863440091663506, 0.04472624961636029, 0.049786520467023365, 0.10762678299215622, 0.05251905997283757, 0.1039649076119531, 0.047835447621764615, 0.025210350249835756, 0.006162015051813796, 0.014903384762874339, 0.017601366162125487, 0.02488350470230216, 0.059122055463376455, 0.023150450724642724, 0.10726720502134413, 0.04772023661644198, 0.00894138314833981, 0.031217859432217665, 0.040353957083425485, 0.032670873260940425, 0.03850964589219075, 0.04874391801422462, 0.028546257672132924, 0.06223005861102138, 0.05363899050280452, 0.0896315646241419, 0.07710031946771778, 0.1352454599691555, 0.2184066694462672, 7.400463419035077, 112.51062512397766, 113.33400294184685, 105.6930385529995, 86.56203031539917, 55.315037816762924, 41.03454150259495, 42.904907539486885, 38.49207893013954, 69.43184271454811, 50.08879445493221, 48.39814357459545, 18.77318523824215, 0.02435481354041258, 0.08743502272409387, 0.1036238536471501, 0.08939684557844885, 0.19675207673572004, 0.1071118883555755, 0.28779703192412853, 0.3966546297306195, 0.44677153578959405, 0.0619020812882809, 0.39449690957553685, 0.3601073892787099, 2.325059613212943, 25.815417654812336, 67.22370520234108, 78.1722629070282, 87.95356124639511, 84.63114112615585, 82.86016255617142, 67.92375683784485, 67.83332169055939, 65.74221789836884, 71.06414392590523, 71.35536029934883, 73.81876811385155, 77.62803331017494, 82.49266907572746, 79.77984264492989, 77.12953805923462, 83.04028049111366, 79.33397457003593, 75.21435722708702, 70.24509027600288, 75.48875570297241, 76.84779837727547, 80.15667602419853, 81.06331497430801, 79.54515963792801, 75.5861596763134, 65.49820259213448, 60.042041167616844, 58.96679386496544, 59.62950110435486, 72.08411559462547, 82.1957378089428, 79.13158982992172, 73.39758351445198, 72.81708866357803, 70.18015936017036, 74.27840664982796, 80.0491113960743, 73.50210830569267, 44.58846040070057, 64.09160926938057, 85.77709883451462, 69.94499757885933, 69.95984718203545, 59.09695968031883, 65.74851796030998, 64.9720524251461, 67.2470511496067, 60.80340251326561, 64.46447566151619, 62.022156715393066, 63.81980985403061, 61.83901034295559, 64.3465755879879, 62.216915264725685, 63.61591659486294, 60.252451077103615, 65.74686884880066, 65.79014092683792, 66.55569344758987, 64.68125402927399, 65.51092430949211, 61.78295575082302, 73.69170293211937, 77.01378107070923, 81.00424334406853, 81.30583316087723, 79.56871837377548, 83.79881098866463, 79.26864847540855, 73.47916513681412, 63.89195278286934, 79.89059150218964, 83.18662583827972, 86.8872244656086, 77.89508298039436, 16.993520334362984, 0.7626314868684858, 1.0645380523055792, 1.6915933485142887, 0.6218648934736848, 0.4970475286245346, 0.36503358744084835, 0.059272915532346815, 0.2605049667181447, 0.0738867829204537, 0.025195520283887163, 0.0743366579990834, 1.2246513669379056, 36.2468858063221, 45.08597530424595, 80.48880860209465, 115.68598553538322, 64.88562986254692, 28.76958053559065, 25.469964891672134, 56.05967625975609, 78.22360575199127, 75.19626259803772, 87.08289116621017, 25.766924656927586, 0.11314070274238475, 0.03638069138105493, 0.03700340894283727, 0.06407265915186144, 0.018602302588988096, 0.0544726820953656, 0.03938255627872422, 0.03917542657291051, 0.05695176332665142, 0.053571566386381164, 0.020017793431179598, 0.05393077328335494, 0.026220413237751927, 0.020749933246406727, 0.07332338151172735, 0.07472892757505178, 0.04479648276173975, 0.011401077626942424, 0.03276684779848438, 0.05647100377245806, 0.044673590527963825, 0.05926972800807562, 0.040311094344360754, 0.07668750724405982, 0.09416271015652455, 0.03356689783686306, 0.08374808501685038, 0.11145679934998043, 0.15020914608612657, 0.20019053597934544, 0.14957034989492968, 0.16178372577996925, 0.1752810468315147, 0.12455175019567832, 0.27308582444675267, 0.20384249626658857, 0.21072281379019842, 0.1753129591816105, 0.10741245074314065, 0.21091477770823985, 0.14345423667691648, 0.1756995142204687, 0.07333269546506926, 0.2349036475061439, 0.13349065178772435, 0.11621161334915087, 0.20696938707260415, 0.29394379584118724, 0.41306698811240494, 8.963205087929964, 125.6946636736393, 126.1650176346302, 117.57252350449562, 99.42198425531387, 61.249479576945305, 34.248565435409546, 52.41048127412796, 83.25660288333893, 93.31215530633926, 82.01555907726288, 72.7446873486042, 24.28126137703657, 0.6127221090719104, 0.10584011441096663, 0.1929148318595253, 0.1708924604463391, 0.5510445905383676, 0.14791405439609662, 0.257801441475749, 0.2907942101592198, 0.4391658282838762, 0.11435819600592367, 0.6764799566008151, 1.3727816683240235, 4.9353319220244884, 32.572912350296974, 73.64395469427109, 78.75265896320343, 94.41068395972252, 85.27889236807823, 86.11716538667679, 70.42313352227211, 71.83049440383911, 68.2534347474575, 74.91138428449631, 75.28247237205505, 78.17461878061295, 81.6365522146225, 87.56570845842361, 81.17442861199379, 81.41667321324348, 86.23141005635262, 85.14491155743599, 77.2211055457592, 75.31709611415863, 79.2494747042656, 80.01743629574776, 81.68093383312225, 84.31943625211716, 82.96125993132591, 78.1819599866867, 68.74270409345627, 64.34851348400116, 63.245501071214676, 63.12065117061138, 77.79789179563522, 87.3961691558361, 83.35773065686226, 78.1455959379673, 77.18378394842148, 75.73711037635803, 78.64831656217575, 84.40552443265915, 76.5403188765049, 49.299835190176964, 69.3411947786808, 90.61138942837715, 74.06665161252022, 73.34502473473549, 64.18180882930756, 71.02006629109383, 69.22131881117821, 71.35377958416939, 65.85025370121002, 69.64674398303032, 65.84681868553162, 66.9260823726654, 64.95537891983986, 67.8239893913269, 64.09110009670258, 67.60494634509087, 66.01095467805862, 68.63832369446754, 67.45040863752365, 68.14173594117165, 67.90777489542961, 68.48361879587173, 65.8420081436634, 77.98655927181244, 80.98105698823929, 86.63672670722008, 84.99035105109215, 81.78690254688263, 87.71629437804222, 81.78798168897629, 77.276331782341, 66.03953674435616, 82.0346112549305, 87.26652771234512, 91.43072426319122, 77.93975338339806, 15.585542935878038, 1.225899956189096, 3.5248696943745017, 3.3626882219687104, 0.7831725315190852, 0.4108367156004533, 0.3502150357235223, 0.20506812346866354, 0.35009166109375656, 0.2454450834193267, 0.18285329831996933, 0.10744126833742484, 2.1210877457633615, 62.430805787444115, 73.0107794702053, 78.28575521707535, 121.3223522901535, 85.57339936494827, 23.197361938655376, 25.9630511328578, 67.16666266322136, 90.17424568533897, 87.77592837810516, 98.28471288084984, 29.14576794952154, 0.18956103682285175, 0.2264213893795386, 0.14400761167053133, 0.1328445231774822, 0.29238077346235514, 0.1059964626620058, 0.07523949549067765, 0.19431674882071093, 0.1084382546832785, 0.24436761857941747, 0.10233900306047872, 0.2008448282140307, 0.09732464517583139, 0.18108079733792692, 0.14577837602701038, 0.11384137178538367, 0.17818106309277937, 0.1682647381676361, 0.1376662269467488, 0.11056721661589108, 0.14771600486710668, 0.2217898386879824, 0.09448656113818288, 0.22280074772424996, 0.1577578714932315, 0.1655248922179453, 0.12272600011783652], [0.05915241672482807, 0.03547574990079738, 0.08864095332683064, 0.06340986932627857, 0.045701587514486164, 0.028098635011701845, 0.09359671123092994, 0.03868405801767949, 0.008174318791134283, 0.12658844090765342, 0.0726519976160489, 0.014285623819887405, 0.02237961904029362, 0.02093273535137996, 0.07289240893442184, 0.028332754773146007, 0.006400484726327704, 0.07995729116373695, 0.046818649643682875, 0.029096862599544693, 0.1908150437520817, 0.049946078506764024, 38.913381323218346, 109.22328472137451, 90.85611909627914, 74.393859654665, 52.712409272789955, 54.40040409564972, 31.451776809990406, 50.38743183016777, 62.55793556571007, 28.730535730719566, 45.05582012236118, 19.41617913544178, 0.1214873036951758, 0.022242533232201822, 0.15479342197068036, 0.047260683932108805, 0.1143609345308505, 0.1540296184248291, 0.09278047495172359, 0.0794760677672457, 0.06613247518544085, 0.03332257168949582, 1.499210384208709, 0.33277560432907194, 9.681141413748264, 57.71949179470539, 77.48326867818832, 73.01906302571297, 76.55600443482399, 81.96846440434456, 81.45571231842041, 72.4249117076397, 59.63599115610123, 60.70423923432827, 58.90533596277237, 66.11569225788116, 64.85443353652954, 66.2199054658413, 75.2089311182499, 78.05631592869759, 79.41381588578224, 73.90649780631065, 78.21654573082924, 76.06110379099846, 72.89018914103508, 71.86146274209023, 72.75449082255363, 79.90648224949837, 79.35149922966957, 75.80932170152664, 77.25693002343178, 77.43850708007812, 65.40958374738693, 54.70612049102783, 56.31100617349148, 54.06045153737068, 67.24845707416534, 72.70493388175964, 76.03845700621605, 72.29746654629707, 66.22827261686325, 60.233816877007484, 66.50267109274864, 68.99522334337234, 82.01913088560104, 38.55075538158417, 48.94145742058754, 86.55003815889359, 70.83322271704674, 76.78652286529541, 64.35106694698334, 61.16524949669838, 58.96259129047394, 64.13496494293213, 60.450804233551025, 60.69013059139252, 55.26739217340946, 58.488270342350006, 59.33380477130413, 61.8255552649498, 57.364602237939835, 58.704330548644066, 59.96348798274994, 64.38648864626884, 64.41966846585274, 64.97905164957047, 65.7889173924923, 64.06579345464706, 61.16947866976261, 60.64811244606972, 64.25573766231537, 75.3853252530098, 77.71601378917694, 77.35361203551292, 76.57797485589981, 80.51134139299393, 68.12193900346756, 62.23089851438999, 66.15557491779327, 76.24952048063278, 79.02107656002045, 80.72768658399582, 74.69197645783424, 26.426649056375027, 0.8216896397061646, 2.1283961785957217, 0.9550425934139639, 0.2741924853762612, 0.2140028987196274, 0.234785393695347, 0.023860374349169433, 0.03707852913066745, 0.06112377617682796, 0.02662290589796612, 0.037027172511443496, 1.8324418156407773, 22.475543171167374, 38.10314700007439, 76.33832171559334, 73.86775508522987, 36.81608386337757, 26.241253204643726, 39.80100989341736, 62.83912047743797, 70.91667383909225, 76.56361162662506, 58.96480657160282, 4.333188207820058, 0.06300666049355641, 0.029168496548663825, 0.01989138898352394, 0.03655512577097397, 0.0955061755666975, 0.05917303358728532, 0.05518005273188464, 0.05516388875548728, 0.09444826631806791, 0.07388144687865861, 0.07026164385024458, 0.1030807351344265, 0.003952688730350928, 0.04361748098745011, 0.03132806465146132, 0.041032083390746266, 0.014188165914674755, 0.07915313704870641, 0.049243646863033064, 0.009344082682218868, 0.05477483638969716, 0.06809115133364685, 0.11048582528019324, 0.053610425238730386, 0.09697556117316708, 0.050676567043410614, 0.08576038875617087, 0.030184238821675535, 0.08611353230662644, 0.06700145590002649, 0.045455320650944486, 0.06662255240371451, 0.027704549029294867, 0.055109938330133446, 0.027275363172520883, 0.02860554970538942, 0.01636802433495177, 0.059686662862077355, 0.02847400031896541, 0.02264400915009901, 0.09056825147126801, 0.041097036155406386, 0.039845281644375063, 0.04249183592037298, 0.04355951554316562, 0.03832052811048925, 0.13297873316332698, 0.09009920671815053, 54.64384563267231, 128.8081330060959, 103.07320073246956, 87.60809898376465, 65.28194859623909, 70.65669178962708, 41.06753513216972, 47.92386442422867, 56.2016936391592, 33.252410888671875, 48.04521091282368, 24.30806703865528, 0.4113628389313817, 0.04914235854812432, 0.035780720645561814, 0.3790414467221126, 0.24098220805171877, 0.5082401842810214, 1.0316255246289074, 0.9718009410426021, 0.25031890079844743, 0.2923591324361041, 1.871840595267713, 0.3736504859989509, 9.65908644720912, 58.654671013355255, 80.26462823152542, 78.3778090775013, 79.95022550225258, 86.71747997403145, 86.03028684854507, 78.43871980905533, 64.26165774464607, 64.82250764966011, 63.25591631233692, 70.23353889584541, 67.51635029911995, 69.39110890030861, 77.23622113466263, 82.4631218612194, 82.47816905379295, 73.41469779610634, 79.09033164381981, 79.30343940854073, 76.66527897119522, 74.78646218776703, 75.63946321606636, 81.92304164171219, 79.43670585751534, 80.26146680116653, 81.72701016068459, 80.45544639229774, 69.23945903778076, 57.48839199542999, 60.09906090795994, 56.0680928081274, 69.07997399568558, 77.28863552212715, 80.00168234109879, 74.07447159290314, 69.1373661160469, 62.94921196997166, 69.99477490782738, 71.59287795424461, 86.14098250865936, 41.45070657134056, 50.65854348242283, 90.95532417297363, 73.87551426887512, 80.90172484517097, 67.90796488523483, 61.76584906876087, 61.40243656933308, 68.33521395921707, 64.25774395465851, 63.93168345093727, 59.109138026833534, 62.45211124420166, 61.889635026454926, 64.39304709434509, 60.99721111357212, 62.30804577469826, 62.06703990697861, 65.8943997323513, 67.43220001459122, 69.24710422754288, 68.49866598844528, 68.55149835348129, 63.98905277252197, 63.36809389293194, 68.86417597532272, 79.12836000323296, 79.1379202902317, 78.42503294348717, 79.04473409056664, 85.75948297977448, 72.16425329446793, 66.59196630120277, 68.65263372659683, 80.12255385518074, 84.41886931657791, 83.48265275359154, 82.15019345283508, 32.25380927324295, 1.3968948181718588, 1.2854665098711848, 1.207710332237184, 0.7461158512160182, 0.9258471569046378, 0.4070909775327891, 0.014048208922758931, 0.011622059519140748, 0.11835756304208189, 0.024270780158985872, 0.08055673126364127, 2.314728442579508, 28.692402876913548, 42.425339072942734, 89.91841301321983, 68.78462344408035, 33.21661300957203, 36.30563445389271, 56.25516057014465, 70.288065969944, 78.68603333830833, 84.27597418427467, 72.60277256369591, 6.395017420873046, 0.24992541410028934, 0.04040986306790728, 0.029533024644479156, 0.01249078790351632, 0.06717247641063295, 0.027836219014716335, 0.07160021850722842, 0.08691655093571171, 0.044572959013748914, 0.028749988341587596, 0.058377083914820105, 0.07444136761478148, 0.031574238746543415, 0.06078852580685634, 0.041017288676812313, 0.04447811625141185, 0.017551790697325487, 0.08310498436912894, 0.04235099855577573, 0.02234109415439889, 0.10826223209733143, 0.04294202270102687, 0.02587561513792025, 0.20052917796419933, 0.0947384163737297, 0.07264870248036459, 0.14385559014044702, 0.14811137662036344, 0.1729523655376397, 0.1971122410031967, 0.15904861473245546, 0.12396020654705353, 0.1940160899539478, 0.12907021242426708, 0.10415292330435477, 0.33540084783453494, 0.2282470726640895, 0.10850294027477503, 0.0695296487538144, 0.18412042642012239, 0.16396424471167848, 0.11036991665605456, 0.2136921466444619, 0.2516219043172896, 0.10601189933368005, 0.18028088088613003, 0.33722445310559124, 0.17622813116759062, 64.07873556017876, 143.65465074777603, 113.37236568331718, 102.97943696379662, 73.6537429690361, 77.08391770720482, 45.40589153766632, 68.43383386731148, 84.5920792222023, 40.96311293542385, 70.60821399092674, 31.859432235360146, 0.7498533662874252, 0.19506876706145704, 0.33453683950938284, 0.33743465901352465, 0.4944830818567425, 0.39667787379585207, 1.027885100338608, 0.7245546206831932, 0.21277494117384776, 0.39184530498459935, 2.618150948546827, 2.8408650727942586, 13.195949010550976, 67.04918056726456, 86.2954594194889, 77.97629982233047, 82.15470761060715, 88.12918022274971, 91.03080332279205, 81.2733145058155, 65.34313291311264, 66.4048719406128, 65.67759856581688, 74.4240452349186, 69.57222238183022, 72.84883975982666, 80.80179020762444, 86.1111769080162, 83.41814741492271, 72.98339813947678, 82.87924513220787, 82.22281515598297, 81.6693976521492, 79.08767178654671, 77.9283919930458, 85.28948619961739, 82.35469087958336, 81.53319016098976, 83.75486254692078, 85.26060774922371, 72.722557336092, 60.58475084602833, 61.942843571305275, 59.438287764787674, 72.06355109810829, 78.4797652065754, 83.98290351033211, 78.71654570102692, 72.52051457762718, 65.44914722442627, 73.49306479096413, 75.41303336620331, 91.2345939874649, 46.561743915081024, 56.232308596372604, 94.8973922431469, 76.69969752430916, 84.06712219119072, 73.17689895629883, 65.22740632295609, 66.73273354768753, 73.24945986270905, 68.90659689903259, 67.40415751934052, 62.77649223804474, 64.33012247085571, 64.18014451861382, 68.66390392184258, 64.13977548480034, 65.147063434124, 67.32433900237083, 70.88239967823029, 70.54088160395622, 69.84060198068619, 71.37982338666916, 70.7155430316925, 68.11659649014473, 67.13570952415466, 70.38486957550049, 83.79808902740479, 85.40542557835579, 79.89964261651039, 83.45182120800018, 89.53051462769508, 76.22292190790176, 69.60768207907677, 72.80071154236794, 82.81994551420212, 86.10761269927025, 87.35407501459122, 82.7923133969307, 29.742653220891953, 2.1175035880878568, 4.8550180066376925, 4.064714089035988, 0.603544651530683, 0.7937783561646938, 0.624367652926594, 0.15420871350215748, 0.17574580939253792, 0.18548289081081748, 0.44280270813032985, 0.14138070575427264, 4.532157881185412, 40.344726517796516, 53.856486082077026, 86.06706127524376, 84.44392517209053, 48.82639579474926, 36.86251737177372, 57.30053387582302, 80.95030903816223, 92.57846027612686, 95.29848352074623, 83.9734648168087, 6.864225268363953, 0.4223508696304634, 0.21216214983724058, 0.1303924375679344, 0.07298062802874483, 0.14567403006367385, 0.16530773980775848, 0.2111113874707371, 0.1869285202701576, 0.15062127553392202, 0.15360715828137472, 0.11200010339962319, 0.16576989000895992, 0.09827552188653499, 0.14096971921389922, 0.1610077658551745, 0.13782350288238376, 0.10133613890502602, 0.18980552995344624, 0.19082583457930014, 0.0989950711664278, 0.2147101506125182, 0.19515775056788698, 0.20275495306123048, 0.4656351188896224, 0.12726015876978636, 0.20507699955487624], [0.04619648498191964, 0.03102805516391527, 0.057254203347838484, 0.01706903291051276, 0.04330591626057867, 0.042347054040874355, 0.05342602380551398, 0.05281823825498577, 0.04461391443328466, 0.04398795739689376, 0.04869440563197713, 0.01672222359047737, 0.0194326248310972, 0.042713415241451, 0.03020061987626832, 0.014742250587005401, 0.03340604846016504, 0.017628192945267074, 0.06669531998340972, 0.07539326848927885, 0.10882849077461287, 1.826451199594885, 81.27491801977158, 88.12170222401619, 83.39651897549629, 69.1834120452404, 42.28125840425491, 15.102680996060371, 44.76826675236225, 32.10036590695381, 31.42569500952959, 52.83056013286114, 28.770513385534286, 0.5345896922517568, 0.041565201463527046, 0.04241998118232004, 0.07208471477497369, 0.2135793847264722, 0.15333738760091364, 0.39047743775881827, 0.15680158452596515, 0.9013672673609108, 1.393617494031787, 0.2002760610776022, 0.2703772229142487, 19.909996837377548, 86.31413921713829, 91.02404728531837, 85.1864205300808, 80.70798084139824, 80.41586011648178, 83.37118193507195, 78.46263572573662, 70.3035843372345, 61.67833596467972, 60.079111978411674, 61.63144648075104, 66.40099614858627, 68.76155868172646, 71.1484082043171, 73.93688097596169, 74.71008628606796, 83.01590099930763, 76.41440123319626, 73.30530166625977, 72.96893611550331, 79.16019469499588, 71.94973960518837, 77.0396576821804, 73.28212291002274, 74.73426058888435, 74.58627372980118, 72.73803010582924, 78.08289930224419, 69.26361814141273, 53.155248910188675, 58.01537811756134, 51.75895683467388, 61.95417836308479, 73.77041190862656, 75.18690750002861, 71.53418630361557, 65.66630557179451, 56.72322705388069, 62.32466608285904, 61.452179700136185, 80.3116849064827, 51.218869015574455, 32.77889169752598, 71.12276718020439, 71.4616633951664, 78.57694879174232, 71.35869652032852, 61.40898361802101, 53.03623929619789, 60.133608654141426, 59.69002425670624, 59.54493284225464, 53.68066571652889, 58.64182010293007, 57.360331267118454, 60.53420975804329, 55.31885281205177, 58.551761135458946, 61.67656525969505, 64.26557153463364, 66.97031199932098, 67.25098013877869, 68.85471448302269, 68.88847947120667, 63.77209201455116, 64.0517570078373, 65.34728989005089, 73.24310660362244, 71.3035386800766, 75.87895676493645, 74.85544368624687, 78.41139167547226, 73.8710305094719, 62.5487856566906, 60.17878443002701, 70.14499604701996, 74.67882916331291, 81.64757922291756, 81.47528126835823, 75.11412620544434, 21.597668677568436, 0.4272351512918249, 0.8702679548878223, 2.907632477581501, 0.302753682481125, 0.18170176714193076, 0.05290505840093829, 0.13050552603090182, 0.08502198892529123, 0.08122397397528403, 0.1086416476755403, 0.04410731700772885, 9.425196647644043, 24.763170517981052, 28.170221596956253, 54.97924983501434, 63.07234816253185, 19.37236938625574, 18.14252357929945, 53.20867784321308, 66.94327265024185, 68.99729043245316, 73.18215787410736, 41.14174135029316, 1.334702605381608, 0.043131110796821304, 0.020616138863260858, 0.05891866247111466, 0.03036698526557302, 0.06731079789460637, 0.052552898196154274, 0.0637433904921636, 0.09127985234954394, 0.04267261567292735, 0.060598777199629694, 0.05422520924184937, 0.07211780713987537, 0.05221333594818134, 0.03228530898923054, 0.06784172292100266, 0.034707771774264984, 0.08802361262496561, 0.04094571224413812, 0.04053458098496776, 0.05835551339259837, 0.0355840811971575, 0.06513011569040827, 0.02389430534094572, 0.03003943096700823, 0.13359796634176746, 0.04156647795753088, 0.019613566000771243, 0.008646476853755303, 0.03629646133049391, 0.07716365435044281, 0.039172012693597935, 0.07295876435819082, 0.08538240552297793, 0.018222853614133783, 0.04620267078280449, 0.020759866893058643, 0.04862895562837366, 0.014740988008270506, 0.02676509026059648, 0.05034696812799666, 0.023511158615292516, 0.05227939451287966, 0.03274573740782216, 0.0817740241473075, 0.20351333892904222, 0.16364469076506793, 3.4973354218527675, 104.14855062961578, 100.40170088410378, 94.99020606279373, 82.48280480504036, 61.407193914055824, 25.283370204269886, 29.839409328997135, 19.143406972289085, 33.89492221176624, 42.83844530582428, 33.0895022302866, 0.7347159879282117, 0.04174706104095094, 0.131562463066075, 0.35048583056777716, 0.15941140620270744, 0.8955201529897749, 1.6494068247266114, 1.6196570335887372, 1.4667727123014629, 3.127548764459789, 0.30496985418722034, 0.5424533109180629, 22.041007988154888, 90.98967432975769, 97.20313131809235, 90.85400640964508, 84.54949110746384, 82.15039864182472, 86.04410290718079, 82.98480346798897, 74.5667351782322, 64.91671979427338, 63.293374702334404, 66.20530664920807, 69.28199395537376, 72.95755192637444, 71.8223324418068, 76.95708811283112, 78.88787090778351, 84.73118215799332, 76.60039365291595, 74.35405299067497, 77.3013724386692, 81.50120347738266, 74.81401830911636, 79.25357088446617, 74.62541162967682, 75.85963100194931, 75.43649330735207, 76.66338667273521, 79.29882645606995, 73.08304399251938, 55.64525909721851, 60.826585069298744, 55.56611314415932, 64.10971149802208, 74.52070444822311, 78.98723557591438, 74.18834388256073, 69.38436806201935, 58.836590051651, 67.21366614103317, 65.78805103898048, 83.78124833106995, 51.68945476412773, 34.978133887052536, 77.68157243728638, 73.24520409107208, 82.12652832269669, 74.75492388010025, 65.07508769631386, 55.78693449497223, 63.93917664885521, 64.49195578694344, 63.39539922773838, 57.54236049950123, 61.23440958559513, 60.71951061487198, 61.3205623626709, 57.23332308232784, 59.371187165379524, 66.01020231842995, 66.57537639141083, 71.60331219434738, 72.24729403853416, 73.46572905778885, 71.55443161725998, 67.1902745962143, 67.82807797193527, 68.08067321777344, 74.59123626351357, 77.27759331464767, 78.43292132019997, 77.44435876607895, 82.19482585787773, 76.5000182390213, 65.54665759205818, 63.94552990794182, 72.4166813492775, 78.04805517196655, 86.73215478658676, 85.50327032804489, 78.83649006485939, 28.15263234078884, 1.3919381028972566, 0.8197982318233699, 1.8003940978087485, 1.0243758698925376, 0.9072302933782339, 0.34716783673502505, 0.27595312683843076, 0.030169284545991104, 0.2729975979309529, 0.17513392347609624, 0.103834616165841, 10.675925184041262, 29.300963021814823, 30.737829320132732, 53.82332906126976, 41.297540590167046, 26.771586947143078, 26.04459285736084, 61.24710850417614, 74.55162718892097, 77.95793160796165, 84.54901233315468, 54.35048997402191, 1.8607977940700948, 0.05868703447049484, 0.0473450735444203, 0.03419039465370588, 0.056629292739671655, 0.05435924482299015, 0.015543321078439476, 0.09515056808595546, 0.039829492452554405, 0.027185969629499596, 0.0560878032410983, 0.03418556327233091, 0.08926049820729531, 0.031566687393933535, 0.03283983802248258, 0.04383754261652939, 0.09469621785683557, 0.07454562452039681, 0.033416624064557254, 0.03528468398144469, 0.009692435669421684, 0.030658140931336675, 0.05704034607333597, 0.04197117108560633, 0.045302427097340114, 0.04650550785299856, 0.20092916587600484, 0.09108276019105688, 0.1310028985608369, 0.09988536636228673, 0.15737568028271198, 0.13124189979862422, 0.19965507643064484, 0.16435880010249093, 0.14019916212419048, 0.20046605088282377, 0.13504703936632723, 0.11541805710294284, 0.18497417826438323, 0.17894970544148237, 0.08534239634172991, 0.1458311575697735, 0.09257822486688383, 0.11709789352607913, 0.10785741280415095, 0.36659209756180644, 0.47487518400885165, 4.441454848274589, 127.63963490724564, 111.953354626894, 110.91366201639175, 90.5189859867096, 61.762448251247406, 25.203895568847656, 66.6586147248745, 47.59230561554432, 47.64953814446926, 80.2718098461628, 45.12612394988537, 1.3558845687657595, 0.140442987321876, 0.21643798914738, 0.38263216498307884, 0.6498671346344054, 1.064470843411982, 2.3958657262846828, 2.152682337909937, 3.4722467930987477, 5.77100683003664, 1.37809912674129, 2.5759347388520837, 27.9403605312109, 96.6655133664608, 99.19572919607162, 91.71567857265472, 86.06288149952888, 82.81174555420876, 89.57398429512978, 84.77712169289589, 77.94020175933838, 67.62166544795036, 66.30562886595726, 67.96484783291817, 72.82200559973717, 76.35756388306618, 75.65415322780609, 79.11164849996567, 81.24464124441147, 87.69275084137917, 78.09820488095284, 75.14561131596565, 81.82834312319756, 84.73457157611847, 77.57634088397026, 83.6046490073204, 77.63830795884132, 77.90807068347931, 78.77111837267876, 80.42176499962807, 84.23782423138618, 75.75310751795769, 59.47461001574993, 62.83148668706417, 56.897177919745445, 68.02982434630394, 79.8451079428196, 82.05548733472824, 81.14487379789352, 74.05890762805939, 62.60379910469055, 69.47538077831268, 68.85352894663811, 87.19397440552711, 58.67408037185669, 40.23749627172947, 81.35982066392899, 77.07358986139297, 86.03959634900093, 79.59749042987823, 68.74626830220222, 59.65846695005894, 67.6752881705761, 69.81518894433975, 68.10605585575104, 61.110665425658226, 64.40249338746071, 63.798059821128845, 65.721265822649, 59.277959167957306, 63.19097399711609, 68.05473580956459, 71.09824329614639, 76.60697489976883, 73.6379662156105, 76.85095220804214, 75.27962252497673, 72.06508621573448, 70.47835975885391, 71.71474501490593, 81.12355694174767, 80.96479386091232, 81.53634399175644, 79.7785659134388, 84.80010285973549, 80.45012667775154, 68.4879657626152, 68.01059737801552, 77.05519884824753, 78.84105741977692, 88.65195617079735, 88.79218384623528, 79.0113414824009, 24.574871622025967, 2.8685596492141485, 5.33419081941247, 6.839038319885731, 0.8819846261758357, 0.9460430731996894, 1.070976925548166, 0.6634122203104198, 0.2678659139201045, 0.3446007479215041, 0.3176367119885981, 0.3344085073331371, 17.37475197762251, 44.82342839241028, 40.942871421575546, 73.45928460359573, 81.35893911123276, 26.683490574359894, 27.06475831568241, 71.64662227034569, 86.96065932512283, 88.94807428121567, 95.8928856253624, 58.68570774793625, 1.849757011514157, 0.12669774441746995, 0.10899421235080808, 0.1447561863460578, 0.12958983454154804, 0.1719510302064009, 0.1208278386911843, 0.101423563901335, 0.13275847857585177, 0.10741749734734185, 0.10173406364629045, 0.14783601014642045, 0.18569101870525628, 0.10869784309761599, 0.13612607755931094, 0.12661708780797198, 0.11965042140218429, 0.1869335223454982, 0.1797148448531516, 0.11204505528439768, 0.142956908675842, 0.11396764079108834, 0.18061943381326273, 0.07647534206626005, 0.12455556483473629, 0.17832027515396476], [0.0229347584900097, 0.04986424188246019, 0.042591888559400104, 0.029103050255798735, 0.035210788337280974, 0.03938724294130225, 0.006703008702970692, 0.07457743296981789, 0.06920288855326362, 0.057145437895087525, 0.08472597590298392, 0.05600562522886321, 0.0230004682453, 0.01578263494593557, 0.02713478184887208, 0.049120491166831926, 0.04112195747438818, 0.062333866517292336, 0.10111616633366793, 0.2644854906247929, 0.4339354089461267, 23.163486756384373, 105.1043513417244, 84.9560084939003, 94.60126653313637, 55.55334962904453, 30.86105290800333, 92.5777155160904, 148.86547833681107, 105.28844386339188, 55.14409638941288, 44.302818328142166, 5.479397177696228, 0.21858897060155869, 0.19132877321681008, 0.08963036234490573, 0.10324247137759812, 0.4592667199904099, 0.42740041273646057, 1.2604950810782611, 0.6571696302853525, 2.0971473678946495, 0.9711545601021498, 0.6152581761125475, 35.42246304452419, 95.07618024945259, 83.71951684355736, 76.88068181276321, 80.9088684618473, 83.40139031410217, 85.94323351979256, 79.69174057245255, 79.39195185899734, 65.2022896707058, 60.947323590517044, 61.017855405807495, 68.19279760122299, 69.40846636891365, 71.37866824865341, 74.12602722644806, 76.34430259466171, 76.96062952280045, 76.21782258152962, 70.71268558502197, 71.60878390073776, 72.51241341233253, 76.63402944803238, 74.77771505713463, 73.64277675747871, 72.9673022031784, 77.12467432022095, 68.69234159588814, 72.0426370203495, 77.26207494735718, 67.44845554232597, 52.53604173660278, 56.49895168840885, 53.235633596777916, 61.25808231532574, 71.1386351287365, 75.68896695971489, 66.06749564409256, 61.30896158516407, 56.63671709597111, 62.21020482480526, 63.12192030251026, 76.65344640612602, 57.8706780821085, 33.343024626374245, 64.7894874215126, 72.0567798614502, 75.38145706057549, 70.50305843353271, 59.10192981362343, 54.882841408252716, 57.67968513071537, 55.49282647669315, 57.13962770998478, 53.986811488866806, 58.957271575927734, 57.621206268668175, 55.29594004154205, 54.89849656820297, 58.434013053774834, 61.3451774418354, 68.84193196892738, 69.93151590228081, 69.56948652863503, 71.36767163872719, 67.62085229158401, 70.97680181264877, 70.28230547904968, 68.8176740705967, 71.98321580886841, 75.97762987017632, 68.46254512667656, 71.5358430147171, 74.5814859867096, 75.97387567162514, 69.44639593362808, 57.18113288283348, 65.95912545919418, 72.42436453700066, 75.53784906864166, 80.27554884552956, 81.98311641812325, 70.65612182021141, 12.117290440946817, 1.7045767768286169, 1.3101926143281162, 1.0647749458439648, 0.16980390792014077, 0.10460962614160962, 0.24549688532715663, 0.07438701271894388, 0.1888909813715145, 0.05733938334742561, 0.07687048375373706, 0.04837471067730803, 18.415046855807304, 50.61747528612614, 35.53405165672302, 45.4634128510952, 47.706633880734444, 32.99268342554569, 41.418640092015266, 58.73751416802406, 67.36636474728584, 69.60353270173073, 75.00957101583481, 25.07068231701851, 0.2950454695383087, 0.0440720946789952, 0.021216983477643225, 0.023328282295551617, 0.047274695680243894, 0.014691766918986104, 0.04652548646845389, 0.06834141095168889, 0.07368776117800735, 0.011354556099831825, 0.057570050266804174, 0.022475022124126554, 0.07316596456803381, 0.0752834825834725, 0.04443402525794227, 0.08166753337718546, 0.042252745624864474, 0.02631206290971022, 0.028872158836747985, 0.03213397765648551, 0.0579998242756119, 0.053568319490295835, 0.021188787432038225, 0.02645019514602609, 0.14194310526363552, 0.022345185243466403, 0.05605140460829716, 0.04357829559012316, 0.07597724223160185, 0.03326840604131576, 0.021335918208933435, 0.03309558211185504, 0.044798067247029394, 0.09100586627027951, 0.049938701558858156, 0.09522363994619809, 0.05654509979649447, 0.0193468418365228, 0.04638989608793054, 0.01642275215999689, 0.015833984143682756, 0.06462728095357306, 0.01855523372796597, 0.09066606653505005, 0.2557958319084719, 0.3975388838443905, 30.830392353236675, 124.68072608113289, 96.97029501199722, 106.26547783613205, 70.6632350385189, 43.296674117445946, 65.29493629932404, 114.41556930541992, 81.11202076077461, 51.8059641122818, 52.11478114128113, 6.198813049122691, 0.02918383303040173, 0.09151630802080035, 0.2276826396700926, 0.017864086439658422, 0.8943006559275091, 1.5563962468877435, 3.0652931425720453, 2.063142517581582, 1.7624197667464614, 0.6498817994724959, 0.7647334865760058, 38.50021429359913, 97.64549598097801, 89.5905590057373, 79.95790868997574, 87.73723125457764, 87.51188814640045, 88.99909794330597, 82.92955443263054, 83.01118165254593, 68.89025777578354, 63.594751730561256, 63.241572082042694, 71.97430148720741, 71.49213775992393, 75.70105791091919, 77.00519353151321, 80.8085310459137, 79.90207448601723, 79.60830464959145, 71.83801040053368, 73.14015492796898, 74.45360004901886, 79.44839403033257, 76.60608574748039, 78.76359477639198, 77.17393487691879, 78.6576184630394, 72.68666446208954, 76.04031130671501, 79.97629210352898, 70.4573392868042, 54.90171879529953, 58.49971152842045, 55.59479400515556, 63.4688188880682, 74.75297838449478, 77.66276344656944, 68.60281839966774, 65.20461514592171, 59.162931740283966, 65.39170950651169, 65.55535152554512, 80.32226353883743, 60.587672889232635, 37.240954264998436, 70.614263266325, 74.02469426393509, 79.12348106503487, 75.27773782610893, 60.67550517618656, 56.321045234799385, 60.22374741733074, 59.03860621154308, 59.56354424357414, 56.71778194606304, 60.98646529018879, 60.0233119726181, 58.57769854366779, 59.06567595899105, 60.43005354702473, 63.75856474041939, 70.8599428832531, 73.66562873125076, 73.22289928793907, 73.27307939529419, 71.4600370824337, 74.00218427181244, 72.88204997777939, 73.65369737148285, 76.40550211071968, 78.69388371706009, 70.34652963280678, 71.57156109809875, 79.10146504640579, 78.93638670444489, 72.76584461331367, 60.16084559261799, 70.38635149598122, 77.37620562314987, 78.19756954908371, 83.26650515198708, 83.16567376255989, 74.37480747699738, 15.490735173225403, 0.4640427668346092, 0.44746838277205825, 3.0040708277374506, 1.1424639145843685, 0.7842188409995288, 0.3635075537022203, 0.35992965975310653, 0.5900195147842169, 0.04161745237070136, 0.0761524929839652, 0.08410067195654847, 21.49211224168539, 44.42812420427799, 33.272982984781265, 36.72288626432419, 38.287649899721146, 32.23959423601627, 50.72881691157818, 68.73811393976212, 75.16736894845963, 77.9568600654602, 88.965515345335, 34.59136784076691, 0.23450279870303348, 0.0670120760332793, 0.06681968909106217, 0.04443382116733119, 0.15945544524583966, 0.05925375699007418, 0.017518327258585487, 0.05431751756987069, 0.1325927273137495, 0.05099910071294289, 0.013443897551042028, 0.02662785045686178, 0.022650031678494997, 0.09195535516482778, 0.03056064870179398, 0.053817206135136075, 0.07564009196357802, 0.048492352216271684, 0.040717164156376384, 0.01929703816131223, 0.0234754854318453, 0.04240714573825244, 0.031501586199738085, 0.03802936502324883, 0.03593145083868876, 0.07340000825934112, 0.15012517949799076, 0.22017050214344636, 0.18117643048753962, 0.14719880215125158, 0.09558628298691474, 0.12383705456159078, 0.18603402451844886, 0.18522503902204335, 0.13961059448774904, 0.18407614988973364, 0.21985584637150168, 0.12771462032105774, 0.13807627838104963, 0.11853912947117351, 0.08370827621547505, 0.24029597378103063, 0.15293115080567077, 0.12881233094958588, 0.5099986586719751, 0.6872632435988635, 39.481880217790604, 138.8984763622284, 109.67489048838615, 118.72682556509972, 76.37314304709435, 46.04916661977768, 108.09305816888809, 163.39945524930954, 112.45225265622139, 73.54981854557991, 70.97791895270348, 9.087148737162352, 0.4895651660626754, 0.3227498126216233, 0.542184712830931, 0.3206115070497617, 1.908161302562803, 2.044538240879774, 5.28843984939158, 6.44260891713202, 8.030097708106041, 7.2020309418439865, 3.0981238558888435, 43.53315822780132, 102.60359153151512, 89.35540482401848, 81.66009575128555, 89.53432202339172, 90.57792842388153, 89.39105451107025, 84.2755638062954, 87.79894754290581, 72.63796627521515, 67.90961399674416, 67.47761517763138, 76.35533720254898, 73.4133830666542, 77.63666644692421, 79.93596866726875, 82.97473400831223, 83.61460447311401, 80.5996410548687, 73.39034110307693, 75.08637249469757, 77.54820719361305, 82.47141301631927, 78.71357426047325, 78.00061851739883, 78.97632256150246, 82.31788605451584, 75.87443500757217, 77.78623402118683, 82.86468431353569, 74.9974724650383, 58.400605246424675, 63.04516062140465, 58.44597861170769, 67.60112375020981, 78.52176055312157, 80.24845629930496, 71.90163418650627, 68.45885172486305, 62.26419612765312, 66.3070347905159, 70.21961644291878, 85.1062524318695, 65.99580109119415, 44.05940338969231, 72.00985237956047, 79.13419649004936, 82.23602324724197, 78.57045114040375, 62.95862786471844, 60.69898411631584, 63.94591748714447, 63.50111335515976, 62.43106797337532, 60.83545379340649, 65.82097247242928, 62.68986828625202, 60.4109101742506, 62.37808361649513, 64.25451412796974, 67.44294583797455, 75.79146265983582, 78.7257032096386, 76.35866582393646, 77.2369658946991, 74.30177539587021, 78.19259941577911, 77.96578958630562, 75.29175907373428, 79.00289073586464, 81.87079444527626, 70.55589839816093, 74.9393279850483, 80.2439497411251, 82.83047094941139, 76.96012794971466, 64.43173661828041, 73.43005657196045, 80.56579247117043, 81.74842581152916, 87.93625697493553, 87.89441362023354, 76.00944176316261, 13.88162886723876, 4.366710959002376, 8.275119010359049, 6.223660865798593, 1.2425575498491526, 0.6326642108615488, 1.0598003002814949, 0.7239061023574322, 1.0534059558995068, 0.18091008852934465, 0.12265265366295353, 0.2776471828110516, 33.719132244586945, 71.54737919569016, 49.696549102663994, 66.64343073964119, 61.48471735417843, 46.3288240134716, 57.609620690345764, 77.46877625584602, 86.28513157367706, 89.42454591393471, 98.56372430920601, 37.16011360287666, 0.4126623395131901, 0.16763330408139154, 0.14592581108445302, 0.1196392223937437, 0.21865390852326527, 0.12853706837631762, 0.10658794693881646, 0.1255898069939576, 0.20938871428370476, 0.0907123542856425, 0.13609490735689178, 0.18559799791546538, 0.08706760767381638, 0.207237257855013, 0.146806666161865, 0.16222058358835056, 0.12786288658389822, 0.12148771187639795, 0.17787602555472404, 0.1231171638937667, 0.09063148245331831, 0.11149944315548055, 0.1402240537572652, 0.19028694630833343, 0.19416131341131404], [0.06299753207713366, 0.06105096406827215, 0.0543287573964335, 0.04256380198057741, 0.02407236326689599, 0.036126565173617564, 0.006921733538547414, 0.08639713661978021, 0.017829533899202943, 0.05469341907883063, 0.0022611224312640843, 0.016250481130555272, 0.05293326001265086, 0.07914708854514174, 0.12918494845507666, 0.01430719712516293, 0.011389544652047334, 0.05131163394253235, 0.04521892806224059, 0.06382447754731402, 0.18528699351008981, 58.082611709833145, 95.35689398646355, 80.6563264131546, 69.10593420267105, 52.19130523502827, 31.975892186164856, 96.11005157232285, 137.14482486248016, 82.21862778067589, 46.57823123037815, 15.019042734056711, 0.07676776309381239, 0.039020555195747875, 0.11358378716977313, 0.09700265698484145, 0.18492065457394347, 0.12909974990179762, 2.154185869731009, 1.7149106785655022, 1.2598617025651038, 0.5296518572140485, 1.695343628525734, 35.283504500985146, 94.98351842164993, 79.07912224531174, 81.93121120333672, 74.53354015946388, 74.3958431482315, 79.75080460309982, 88.22394713759422, 83.7511919438839, 77.39962756633759, 64.68240156769753, 57.88068674504757, 65.2355606853962, 75.36087736487389, 74.28773894906044, 75.44967859983444, 76.03484719991684, 80.1563036441803, 75.36580950021744, 75.82417130470276, 74.358019977808, 76.80833369493484, 71.80732324719429, 74.82754558324814, 74.15126547217369, 76.849455088377, 73.33299458026886, 72.39097952842712, 69.95909482240677, 76.19733408093452, 73.81108492612839, 65.054971575737, 51.61267228424549, 57.30037808418274, 54.21802528202534, 59.24114294350147, 66.92961618304253, 67.98879414796829, 61.09795890748501, 62.93570749461651, 61.05192057788372, 65.88566780090332, 62.01920807361603, 74.82320621609688, 58.43423344194889, 40.140232890844345, 77.55206018686295, 63.97883892059326, 67.55683332681656, 62.7936103194952, 59.34180334210396, 52.73370712995529, 57.796346470713615, 55.09708151221275, 57.70171254873276, 53.77106286585331, 55.46861417591572, 57.117474898695946, 57.4140489846468, 54.18091647326946, 56.87915928661823, 62.48553805053234, 66.87215566635132, 70.90690836310387, 72.44036167860031, 72.0026783645153, 70.49366533756256, 70.69668084383011, 72.06665933132172, 71.39853358268738, 72.002412378788, 67.93327912688255, 70.34874871373177, 67.3428364098072, 69.83182445168495, 74.18364733457565, 71.52234613895416, 57.51842558383942, 63.894521445035934, 71.15491345524788, 77.5332359969616, 75.93522414565086, 79.81399521231651, 78.66435170173645, 64.40610319375992, 3.4561477694660425, 0.9996959567070007, 2.2892700461670756, 1.554830374661833, 0.5064348655287176, 0.08057575993007049, 0.10795191788929515, 0.14457799668889493, 0.031303536670748144, 0.04580090542731341, 0.09149250734481029, 1.0169567679986358, 27.265180461108685, 35.92656299471855, 44.81952980160713, 43.802145794034004, 54.48891654610634, 29.59304764866829, 35.33567190170288, 60.04838302731514, 66.54024347662926, 73.77060189843178, 70.92323988676071, 4.350396059453487, 0.1822519805864431, 0.07300334516912699, 0.03605767531553283, 0.019393547045183368, 0.050037344117299654, 0.04193214153929148, 0.008795335907052504, 0.10086678244988434, 0.08422986502409913, 0.042617032522684895, 0.060489288152894005, 0.07980123235029168, 0.08048446092288941, 0.032998115857481025, 0.11991604347713292, 0.051935939700342715, 0.047194124417728744, 0.02905289406044176, 0.08925767062464729, 0.03377695531526115, 0.09422076094779186, 0.013060101446171757, 0.07980393376783468, 0.027004113762814086, 0.03935419510526117, 0.041990960453404114, 0.01172996779132518, 0.011179864741279744, 0.01599703769898042, 0.06811490748077631, 0.015501099369430449, 0.02047190246230457, 0.050020627240883186, 0.015105968814168591, 0.013748579785897164, 0.051120278585585766, 0.09653638786403462, 0.1562441128771752, 0.034771911887219176, 0.020619383903976995, 0.02048936890787445, 0.02988859316246817, 0.008535420020052698, 0.037510403417400084, 0.45547927322331816, 75.30966371297836, 108.71320769190788, 89.9661460518837, 79.72297489643097, 66.61266759037971, 39.875352904200554, 108.71281251311302, 163.8364925980568, 94.68476325273514, 56.72981970012188, 17.967827953398228, 0.09910398133797571, 0.11875560652697459, 0.2488161704968661, 0.3400577057618648, 0.9446749091148376, 0.897850199835375, 2.262932709418237, 1.325427065603435, 1.4740677271038294, 0.612339754588902, 2.502620997838676, 40.393956676125526, 98.45950350165367, 84.71417427062988, 86.2939091026783, 80.81997603178024, 77.98091277480125, 85.76502308249474, 89.0855661034584, 86.2591789662838, 80.3085994720459, 67.04692348837852, 62.094812616705894, 67.46438428759575, 76.46847233176231, 78.4173421561718, 78.6442431807518, 79.63838383555412, 80.12439295649529, 77.35083058476448, 77.53965005278587, 74.92826297879219, 77.75561526417732, 75.53231656551361, 76.4020062983036, 76.86067208647728, 79.88480061292648, 75.4209977388382, 74.74991574883461, 74.53216463327408, 77.41082176566124, 78.3773835003376, 67.91875630617142, 54.841362833976746, 59.543849900364876, 55.396699234843254, 63.61227259039879, 69.7944724559784, 70.71469187736511, 65.15833362936974, 66.25642910599709, 66.25183895230293, 70.87114468216896, 66.4508418738842, 78.72147023677826, 60.376586616039276, 43.658049926161766, 80.22322565317154, 66.24172389507294, 71.17282569408417, 65.0216093659401, 62.25134901702404, 56.54423385858536, 61.3885635137558, 58.5687006264925, 60.85422858595848, 56.34379841387272, 59.01534765958786, 57.91744217276573, 58.016590252518654, 57.095728665590286, 60.28624266386032, 64.78273138403893, 71.65037646889687, 73.58122766017914, 74.98413518071175, 74.46354031562805, 74.72739055752754, 73.12906712293625, 75.02375185489655, 75.5051252245903, 74.75420951843262, 71.23868376016617, 71.42857477068901, 71.0093204677105, 71.81468725204468, 78.22102189064026, 74.15637999773026, 61.53329014778137, 67.26851999759674, 73.60892817378044, 80.35719886422157, 79.75079700350761, 84.27345111966133, 82.06784427165985, 69.76527482271194, 5.719687733799219, 0.7167133258190006, 0.6982729746960104, 1.5392301930114627, 1.9758189283311367, 0.7073859544470906, 0.4133853694656864, 0.30680257303174585, 0.1450198417296633, 0.2201492915628478, 0.06932319811312482, 1.0325297573581338, 29.870425164699554, 33.67915078997612, 44.7990071028471, 35.924465507268906, 63.515411987900734, 40.53275942802429, 41.456482261419296, 67.46536463499069, 75.24166256189346, 82.25830525159836, 86.25685349106789, 7.219484830275178, 0.21463149780174717, 0.09173275539069436, 0.01333728525423794, 0.07904423429863527, 0.0292056391845108, 0.007019935446805903, 0.011803794786828803, 0.013329741323104827, 0.042207660153508186, 0.01150369995229994, 0.0019947899818362202, 0.023221017836476676, 0.029314215389604215, 0.052008777784067206, 0.07736535524600185, 0.07831232825992629, 0.0582713167386828, 0.05687034972652327, 0.08799214556347579, 0.028615264418476727, 0.02389615328866057, 0.045668183447560295, 0.08338753483258188, 0.02267992909764871, 0.24729761760681868, 0.10460108402185142, 0.15897266333922744, 0.11209095711819828, 0.11226261587580666, 0.1204288229928352, 0.1463938390952535, 0.21551664249273017, 0.11217515377211384, 0.22718486638041213, 0.13271421688841656, 0.16002680989913642, 0.15140695759328082, 0.15301790786907077, 0.26434721366968006, 0.04265934236173052, 0.11898474462213926, 0.21040370513219386, 0.13456203101668507, 0.09447031552554108, 0.8107909339014441, 89.51925203204155, 119.89863708615303, 103.48242357373238, 93.1386186182499, 70.1735021173954, 45.39614886045456, 105.57687118649483, 142.12307453155518, 92.7919328212738, 69.09459561109543, 25.700747407972813, 0.35686509450897574, 0.3238593233982101, 0.3479782916838303, 0.6696451921015978, 2.1877900790423155, 0.49376156588550657, 5.852236021310091, 6.150455418974161, 5.189385814592242, 3.3034790866076946, 5.132432095706463, 45.99295623600483, 101.69333517551422, 85.47713533043861, 87.72992044687271, 82.35685676336288, 78.81819784641266, 87.64773845672607, 91.52932897210121, 89.74365279078484, 83.51086243987083, 71.96035623550415, 65.80142632126808, 71.2229374051094, 80.53515091538429, 82.3429723083973, 82.41456806659698, 81.52788564562798, 84.6089655160904, 79.74676162004471, 78.74629810452461, 77.59116768836975, 82.13410511612892, 77.96841904520988, 79.69894498586655, 81.54018938541412, 82.79108986258507, 82.64323219656944, 79.4246757030487, 77.00236648321152, 80.9472844004631, 81.8447582423687, 72.4069994688034, 58.414504900574684, 62.368420735001564, 59.52661782503128, 67.21217662096024, 74.96074363589287, 74.07402321696281, 70.47146692872047, 69.94593992829323, 68.85505646467209, 73.63793581724167, 70.90752393007278, 82.92029812932014, 65.33465176820755, 48.9658635109663, 82.47982576489449, 69.75279629230499, 75.73088631033897, 68.88461887836456, 65.9497095644474, 59.34704706072807, 66.14758774638176, 62.988441064953804, 65.14121174812317, 59.36101891100407, 61.0076567530632, 61.0260933637619, 62.491784915328026, 59.834135323762894, 61.338626593351364, 68.01920011639595, 75.27739584445953, 75.90103358030319, 78.46126019954681, 77.2630324959755, 76.89100965857506, 77.24239960312843, 78.01759600639343, 76.9392366707325, 77.42069363594055, 72.8300991654396, 74.18239340186119, 69.62508514523506, 73.70766207575798, 82.05574572086334, 78.57018515467644, 65.54475009441376, 70.61695352196693, 78.22978422045708, 85.33627688884735, 82.64709278941154, 87.93878003954887, 83.72203230857849, 70.61904340982437, 4.7026134096086025, 4.041615128517151, 9.348835945129395, 5.4537020064890385, 1.828448586165905, 0.372957824729383, 0.7403468107804656, 0.5674806679598987, 0.5938451376277953, 0.32261572137940675, 0.2596487361006439, 2.3015034897252917, 45.89040353894234, 54.21444587409496, 63.43562386929989, 61.24528080224991, 70.6014883518219, 40.23727208375931, 52.415964379906654, 78.57269302010536, 88.21207657456398, 92.37834021449089, 96.76829785108566, 7.835873505100608, 0.39668292040005326, 0.281724720261991, 0.13979953044326976, 0.1432578347157687, 0.21077041514217854, 0.1402953444630839, 0.09065964695764706, 0.11496790000819601, 0.1257703863666393, 0.09526137815555558, 0.06326934366370551, 0.23231816827319562, 0.18522788886912167, 0.14067777316085994, 0.14472068200120702, 0.19109426939394325, 0.09519509694655426, 0.17020726518239826, 0.14337234810227528, 0.14892851089825854, 0.1806293785921298, 0.10802165008499287, 0.16948039090493694, 0.12446334556443617], [0.09898946795146912, 0.0402177544310689, 0.06228505546459928, 0.04134974857151974, 0.04835773404920474, 0.02878598250390496, 0.019478029425954446, 0.06275580715737306, 0.011584979038161691, 0.027112062853120733, 0.022205565001058858, 0.033020695700543, 0.05761034146416932, 0.130129286844749, 0.02551581637817435, 0.0199030611111084, 0.10491596243809909, 0.06538640154758468, 0.20760653569595888, 0.24907797051128, 7.509807301685214, 90.41487917304039, 87.10679948329926, 83.71931925415993, 73.01536962389946, 38.90224792063236, 64.06276881694794, 85.32078132033348, 47.714978232979774, 38.21916237473488, 33.24314698576927, 2.151048663072288, 0.08821168026770465, 0.22097947279689834, 0.16381127323256806, 0.17901523708133027, 0.24426291638519615, 0.8783698326442391, 1.3288700371049345, 1.8430202105082572, 0.15143449127208441, 1.4977087522856891, 29.372653774917126, 91.0011725127697, 81.15793749690056, 85.8094123005867, 75.74318245053291, 67.48756304383278, 70.47490194439888, 81.30353808403015, 83.2435467839241, 82.61527329683304, 77.12230324745178, 63.806343376636505, 54.88017775118351, 66.79313510656357, 76.28353625535965, 79.70200002193451, 76.80415391921997, 76.69532775878906, 75.33126935362816, 74.36799064278603, 73.24373736977577, 73.07121902704239, 73.41082200407982, 71.88261240720749, 69.02990028262138, 70.27279078960419, 69.53725665807724, 68.36808979511261, 67.0286312699318, 68.81182998418808, 71.90376207232475, 66.93087011575699, 54.026694148778915, 52.96221546828747, 56.1761400103569, 52.0577310025692, 57.19456896185875, 62.546726167201996, 66.03908076882362, 64.32072177529335, 67.04697668552399, 69.79884222149849, 72.86309659481049, 68.28727573156357, 77.09165409207344, 53.31077076494694, 42.283291295170784, 76.59567430615425, 58.137089386582375, 60.813490971922874, 53.871362283825874, 53.23208458721638, 53.79302188754082, 56.6574639827013, 53.06373082101345, 55.39769098162651, 52.919490560889244, 56.82564675807953, 55.67308880388737, 55.13299338519573, 53.17095346748829, 57.75744415819645, 62.22322292625904, 72.34991133213043, 68.29305902123451, 70.44229969382286, 69.90733399987221, 70.61176300048828, 71.93001866340637, 74.54090416431427, 70.62657460570335, 67.3598974943161, 71.20760902762413, 73.0768883228302, 73.58066529035568, 73.51305931806564, 73.35689529776573, 75.25873884558678, 58.38718816637993, 61.295495107769966, 70.13871878385544, 69.67224821448326, 76.02474734187126, 73.39786469936371, 77.80431345105171, 82.59501278400421, 55.81447921693325, 1.547252987511456, 1.8894940917380154, 1.4844515011645854, 1.4419581438414752, 0.3604730009101331, 0.047912553054629825, 0.3848070139065385, 0.3670006350148469, 0.21983960818033665, 0.15755075291963294, 0.03246266373025719, 10.884970016777515, 26.590828746557236, 34.45323385298252, 43.78240965306759, 38.586674854159355, 45.49220010638237, 31.91535383462906, 43.2778537273407, 57.11358770728111, 65.52886694669724, 80.34912809729576, 31.71324647963047, 0.5881835601758212, 0.14952356490539387, 0.08384054177440703, 0.005571583697019378, 0.053548236974165775, 0.0018357944668423443, 0.027822691517940257, 0.044472995432442985, 0.044780775206163526, 0.022305573111225385, 0.02673216487892205, 0.02191603463870706, 0.07589513101265766, 0.044305919436737895, 0.04515599022852257, 0.01621543135115644, 0.05898641684325412, 0.04856052219111007, 0.033601752802496776, 0.04994976698071696, 0.032236483093583956, 0.056241424099425785, 0.07530199916800484, 0.05208374212088529, 0.03098786786722485, 0.029148735011403915, 0.06994812356424518, 0.01911324343382148, 0.017785698946681805, 0.016891872983251233, 0.035657461048685946, 0.020709339623863343, 0.010907580035564024, 0.039548578424728476, 0.014274953591666417, 0.032533256817259826, 0.046726259679417126, 0.06896362014231272, 0.0890763416828122, 0.08697820114321075, 0.046898430518922396, 0.02239218731119763, 0.19845074886688963, 0.4126233619172126, 10.002258382737637, 110.67463204264641, 96.98662653565407, 95.68364605307579, 80.84131568670273, 50.848841071128845, 51.31150044500828, 84.1909271478653, 51.555891931056976, 40.993773490190506, 40.95759183168411, 2.8627355117350817, 0.16292767220875248, 0.1411900034872815, 0.5300046445336193, 0.12318806868279353, 0.8988418872468174, 2.004813984967768, 1.2511442578397691, 2.0623998949304223, 0.7140569714829326, 2.561514750123024, 35.49565091729164, 94.64959233999252, 85.18772006034851, 91.22441053390503, 81.09984621405602, 70.37308260798454, 74.17078122496605, 86.49912849068642, 87.51622751355171, 85.24843320250511, 80.4993188381195, 66.38852521777153, 57.63406477868557, 72.29060411453247, 81.76478013396263, 82.80742898583412, 81.32401138544083, 79.38656374812126, 76.32991656661034, 77.25047796964645, 75.55386140942574, 76.46953627467155, 75.36229088902473, 75.29870510101318, 71.61848098039627, 72.81288608908653, 72.04553246498108, 73.59805315732956, 70.2132099866867, 73.97801756858826, 74.31287840008736, 69.63882520794868, 56.09221011400223, 57.28989824652672, 60.02507887780666, 54.26617629826069, 58.417662531137466, 65.19642278552055, 67.58807525038719, 66.67969599366188, 71.22313499450684, 73.25444519519806, 76.80004253983498, 70.97053214907646, 80.2571502327919, 54.481058567762375, 46.019843593239784, 79.11829054355621, 61.21109023690224, 64.15670737624168, 56.520298942923546, 57.150882706046104, 56.605843752622604, 59.6491764485836, 58.32774795591831, 58.42440716922283, 55.16201242804527, 57.59007453918457, 57.865848541259766, 57.922898679971695, 55.93368262052536, 61.843748688697815, 65.55116415023804, 74.710124284029, 70.65819650888443, 71.72529324889183, 72.7409103512764, 71.37840986251831, 75.57112768292427, 76.01497426629066, 72.87055939435959, 68.8277131319046, 72.46285647153854, 72.64470711350441, 75.75232475996017, 75.57800531387329, 76.40407338738441, 78.65948036313057, 61.902170553803444, 62.965330705046654, 74.65362131595612, 72.90749341249466, 79.78704705834389, 76.71951726078987, 80.57278409600258, 84.06208366155624, 64.63276863098145, 2.548845517449081, 0.4631076013902202, 0.2288308014976792, 2.7656542835757136, 1.396647000219673, 0.4674546868773177, 0.903883563587442, 0.3767614206299186, 0.2262107827118598, 0.23765857389662415, 0.0875489498139359, 10.894181672483683, 33.36467586457729, 31.580413207411766, 38.05968873202801, 39.21199969947338, 45.10906286537647, 43.03598530590534, 52.49688483774662, 63.70419725775719, 72.12093561887741, 91.77147477865219, 44.762806445360184, 0.8754822250921279, 0.19068920519202948, 0.053877854443271644, 0.037781450591864996, 0.060124199735582806, 0.007759480040476774, 0.03520403479342349, 0.01206245551657048, 0.01621224011614686, 0.032368451793445274, 0.054432832475868054, 0.10907159608905204, 0.038960352176218294, 0.03515077827614732, 0.048244545396300964, 0.05338933573511895, 0.006311803181233699, 0.06078020262066275, 0.05353720494895242, 0.014067177289689425, 0.026315272698411718, 0.039620496245333925, 0.0663301907479763, 0.026425669020682108, 0.12135659664636478, 0.13128973863786086, 0.18275071866810322, 0.11173976541613229, 0.14919470442691818, 0.0882308796280995, 0.10369271753006615, 0.14854821958579123, 0.09976040353649296, 0.1792641237261705, 0.09844822707236744, 0.16941649198997766, 0.22925116878468543, 0.367909261258319, 0.19359725149115548, 0.20325458172010258, 0.21501408977201208, 0.19788953679380938, 0.4618087538983673, 0.5658627266529948, 12.925682812929153, 123.02995026111603, 109.05634447932243, 106.80149227380753, 95.55709764361382, 54.407338723540306, 78.7558963894844, 98.01039800047874, 60.58030508458614, 59.91927735507488, 54.487909600138664, 4.783782754093409, 0.2105077839223668, 0.7857492682524025, 1.5527165005914867, 1.3630464719608426, 0.9561787324491888, 3.1123987399041653, 6.772583210840821, 6.41096469014883, 3.800175846554339, 3.346147947013378, 41.177280843257904, 97.12834373116493, 87.23736807703972, 94.0682615339756, 81.63489550352097, 73.61899003386497, 78.95965665578842, 88.85434091091156, 88.78219038248062, 88.15631836652756, 86.45593240857124, 71.65954917669296, 60.58909021317959, 74.87345471978188, 83.68512868881226, 86.33354857563972, 83.73906299471855, 83.40524330735207, 77.33612537384033, 78.63310217857361, 78.43566477298737, 79.52503591775894, 77.33280435204506, 78.85732054710388, 74.91136908531189, 76.77831530570984, 75.5536562204361, 77.02714115381241, 73.61147403717041, 77.1629610657692, 78.25897425413132, 73.82974952459335, 59.00207497179508, 59.276861026883125, 62.25132241845131, 57.20559976994991, 62.62721724808216, 70.98543494939804, 71.2431675195694, 69.18629229068756, 74.89886775612831, 77.93758749961853, 80.43687298893929, 76.62395238876343, 80.73759645223618, 59.547030329704285, 50.07493659853935, 81.8733099102974, 65.61488673090935, 67.79657766222954, 59.58037734031677, 59.26819749176502, 60.913247019052505, 62.27235049009323, 59.56765942275524, 62.013553977012634, 59.650293588638306, 61.98921628296375, 60.11198401451111, 62.27647706866264, 58.628148436546326, 65.51979303359985, 68.65403965115547, 78.50218400359154, 72.97363266348839, 74.06652241945267, 76.47161856293678, 75.92241123318672, 77.79542192816734, 78.87910857796669, 75.3185248374939, 69.90876272320747, 73.50116595625877, 77.80768766999245, 79.47246193885803, 80.07865101099014, 78.30058202147484, 83.50407600402832, 64.18660417199135, 66.96085810661316, 77.37930625677109, 76.89642056822777, 81.61601811647415, 79.86121907830238, 84.80991393327713, 87.92209133505821, 64.77629452943802, 2.0167641062289476, 6.6612491849809885, 6.990020368248224, 4.969708677381277, 1.495272251777351, 0.23056684818584472, 2.4349214555695653, 1.8634861498139799, 0.32517488405574113, 0.5188815132714808, 0.1928802180918865, 18.20881862193346, 45.497546419501305, 48.95369276404381, 58.496622294187546, 48.89535069465637, 59.69831541180611, 46.5658362954855, 60.56795574724674, 78.07469174265862, 83.33685457706451, 101.10468596220016, 50.86513079702854, 0.9906688879709691, 0.3217632608721033, 0.2035299185081385, 0.16418512270320207, 0.1998866265057586, 0.11931459957850166, 0.14416874677408487, 0.11474064696813002, 0.14660033426480368, 0.16635127365589142, 0.1628429486299865, 0.18888869555667043, 0.11598873155890033, 0.1241980203485582, 0.13905423606047407, 0.12180128411273472, 0.15714230452431366, 0.1598631514934823, 0.20582729601301253, 0.18674926192034036, 0.0956113230495248, 0.12103561035473831, 0.19791402766713873, 0.17210512974997982], [0.08729042267077602, 0.05116957203426864, 0.060585489045479335, 0.0057765667406783905, 0.0132529717120633, 0.044576012951438315, 0.033948491618502885, 0.03323362900118809, 0.04276052306522615, 0.04969875779352151, 0.057381804508622736, 0.05732585028454196, 0.03132402736810036, 0.001682624579188996, 0.07220766638056375, 0.028460595276555978, 0.056990124940057285, 0.10485227132448927, 0.2516308397753164, 0.22543163155205548, 32.32972539961338, 104.1489990055561, 74.43506464362144, 76.31388902664185, 48.16423572599888, 37.78818570077419, 55.88896282017231, 83.54268193244934, 73.05028215050697, 49.83276039361954, 13.715312741696835, 0.05455424041429069, 0.005794011849502567, 0.10837747278856114, 0.12304065588978119, 0.1194805586419534, 0.7970384624786675, 3.1031521735712886, 1.0558197763748467, 0.43935198860708624, 0.40057245700154454, 19.162571243941784, 82.71080017089844, 82.44628116488457, 88.99733483791351, 77.69911989569664, 80.79818040132523, 71.90670311450958, 66.23312875628471, 79.31912496685982, 82.15042144060135, 80.89109301567078, 76.79134860634804, 58.996519669890404, 54.276215359568596, 68.9224648475647, 77.23599314689636, 76.62519112229347, 76.52067393064499, 76.54819965362549, 75.5670391023159, 74.2522868514061, 74.13178011775017, 70.98135396838188, 73.13738107681274, 68.78962397575378, 63.923377096652985, 60.050248727202415, 62.02467978000641, 61.38104751706123, 59.10491265356541, 60.65366394817829, 56.65423795580864, 53.337943106889725, 51.258956864476204, 54.22423034906387, 52.327049151062965, 56.88957452774048, 54.36006926000118, 56.604909002780914, 63.5383627563715, 67.39058464765549, 72.0180295407772, 69.48257759213448, 76.45686775445938, 69.2632457613945, 73.44101518392563, 50.56717358529568, 50.51452361047268, 76.75278067588806, 60.268007442355156, 60.23692891001701, 54.081342816352844, 53.3803678303957, 52.27237768471241, 53.411218374967575, 50.29119059443474, 52.90462575852871, 53.01306053996086, 57.536037638783455, 54.54038858413696, 54.2376322299242, 51.47265739738941, 56.711250096559525, 61.298006772994995, 66.65984585881233, 68.1266051530838, 69.4419577717781, 66.80770352482796, 72.94276311993599, 67.0612259209156, 67.32719644904137, 66.65828794240952, 67.76868715882301, 71.69007673859596, 70.94100773334503, 70.37256583571434, 72.57425889372826, 73.94158512353897, 67.84243360161781, 59.45817969739437, 57.40627080202103, 66.30758956074715, 73.18661883473396, 71.26276686787605, 73.041732609272, 77.76697665452957, 76.29914581775665, 82.35182583332062, 61.75270177423954, 1.4918429357931018, 1.0354398074559867, 2.981681004166603, 1.3060788600705564, 0.2030122556607239, 0.2088494400959462, 0.21755143330665305, 0.47814464138355106, 0.08082161119091325, 0.063863789109746, 0.1524538014200516, 21.341087445616722, 31.293144822120667, 41.35196506977081, 70.72750478982925, 107.27805510163307, 30.532765723764896, 29.37609639018774, 50.66025719046593, 61.00183546543121, 73.82015123963356, 64.99966934323311, 1.93558051250875, 0.2076422775280662, 0.008966494642663747, 0.051735092274611816, 0.038499396832776256, 0.08017951244255528, 0.024000219091249164, 0.07810906143276952, 0.027845588629134, 0.05496736805071123, 0.041918285642168485, 0.008034720813157037, 0.06659410588326864, 0.036727059123222716, 0.060588209016714245, 0.02755745535978349, 0.013224475096649257, 0.017677124596957583, 0.05658942827722058, 0.03500449354760349, 0.011867023913509911, 0.022663961790385656, 0.10391645279014483, 0.0682010040327441, 0.045772648154525086, 0.04481318850594107, 0.05459162981424015, 0.020558756004902534, 0.020743320710607804, 0.05069388134870678, 0.03318452108942438, 0.020388041630212683, 0.06755660462658852, 0.07495403580833226, 0.015429685281560523, 0.06610354626900516, 0.06286017538513988, 0.022179445113579277, 0.05835792537254747, 0.031795688191778027, 0.07323512531002052, 0.12055346669512801, 0.1582789927488193, 0.307354285614565, 43.080613911151886, 116.51519224047661, 83.6821648478508, 85.48119351267815, 62.3555014282465, 41.34715832769871, 47.98745781183243, 90.9511823952198, 53.53384159505367, 57.210756093263626, 16.858059503138065, 0.03476693949778564, 0.1168103409872856, 0.25577392370905727, 0.5371788970660418, 0.6300303584430367, 1.007958019617945, 3.1700283475220203, 2.681431327946484, 0.45734506216831505, 1.3976730639114976, 20.969345793128014, 85.51689639687538, 87.90496185421944, 90.5674409866333, 81.91851988434792, 85.36234349012375, 77.09166169166565, 68.93453299999237, 82.49679565429688, 84.5593173801899, 84.52068105340004, 80.75135171413422, 63.41271869838238, 55.37999153137207, 71.61894455552101, 81.07981368899345, 80.88427618145943, 79.42893147468567, 77.65821129083633, 77.98620209097862, 77.8919367492199, 75.80003499984741, 74.40257638692856, 76.34553372859955, 72.88140401244164, 68.8759933412075, 63.18018637597561, 64.40713673830032, 63.157364800572395, 61.78948760032654, 62.35306195914745, 59.132385179400444, 54.89128455519676, 52.854191064834595, 58.06729853153229, 56.86366371810436, 59.32487145066261, 56.81523531675339, 57.978569492697716, 65.78306570649147, 70.53436115384102, 74.23893436789513, 71.99893176555634, 77.19453737139702, 72.17500671744347, 74.46189120411873, 52.45278060436249, 53.636933863162994, 80.19314646720886, 63.705720975995064, 62.00498163700104, 57.83156678080559, 55.50412327051163, 54.62828926742077, 56.50634229183197, 53.702115565538406, 55.90439759194851, 57.555443197488785, 59.781914725899696, 55.534058064222336, 56.96158446371555, 54.16108153760433, 59.2123518884182, 63.19795802235603, 70.77098205685616, 70.1355953514576, 71.7274059355259, 69.33110252022743, 75.54838210344315, 69.75231751799583, 71.84353530406952, 67.59101629257202, 71.51432856917381, 74.29586291313171, 74.14156079292297, 72.69813984632492, 75.57248041033745, 77.6219916343689, 71.20185613632202, 61.85945704579353, 60.15520669519901, 67.6317349076271, 78.52862298488617, 72.25734069943428, 76.33548706769943, 79.9382409453392, 79.92453888058662, 83.56128573417664, 70.50034537911415, 2.4535235948860645, 0.8862358855549246, 1.2669543782249093, 1.789708121214062, 0.6251079007051885, 0.9912667621392757, 0.9961013495922089, 0.6373575527686626, 0.29569660022389144, 0.0436641806300031, 0.047479127679253, 26.16682279855013, 34.0597003698349, 34.76194828748703, 61.22290760278702, 94.7025614976883, 38.11618410050869, 43.40272642672062, 61.877141296863556, 69.15623590350151, 83.08023154735565, 80.01546040177345, 4.467943226918578, 0.29155146796256304, 0.04341926076449454, 0.03403331167646684, 0.014673056448373245, 0.06523771226056851, 0.005334674851837917, 0.029616095089295413, 0.05231863557128236, 0.03845271574391518, 0.0862192215572577, 0.04328746646933723, 0.05050710133218672, 0.0675634917570278, 0.04548593424260616, 0.06459791417000815, 0.044584035567822866, 0.03293492198281456, 0.019849637610604987, 0.03732971643330529, 0.012177686930954223, 0.01972186018974753, 0.03810652611718979, 0.05963860880001448, 0.18632576277013868, 0.23495442525018007, 0.12011291299131699, 0.11599682096857578, 0.21775442553916946, 0.12626388488570228, 0.13955481466837227, 0.20194286538753659, 0.08662991123856045, 0.22836134856333956, 0.3037424013018608, 0.1783216407056898, 0.16841947595821694, 0.0614439498167485, 0.20044534496264532, 0.07800733525073156, 0.1433739808271639, 0.2503805287415162, 0.34965940460097045, 0.5085197661537677, 49.966676607728004, 134.3826922774315, 96.95763409137726, 97.6768670976162, 67.10552394390106, 56.742902398109436, 69.08609926700592, 96.03533998131752, 104.84927862882614, 76.93377256393433, 22.642553709447384, 0.0965941789036151, 0.31642335990909487, 0.3470674389973283, 1.6381520661525428, 1.1705407267436385, 2.1384233655408025, 9.002591874450445, 5.105827348306775, 3.633502540178597, 2.7489230688661337, 26.524558402597904, 90.26617035269737, 89.31223914027214, 94.24015671014786, 84.28728237748146, 86.8169054389, 79.5107638835907, 72.35132485628128, 85.61557710170746, 88.60087171196938, 89.51412230730057, 83.98063883185387, 66.45239979028702, 60.754898115992546, 76.83898285031319, 82.45192766189575, 84.76230248808861, 82.13466748595238, 79.76721972227097, 80.37089332938194, 81.64456978440285, 77.60451257228851, 77.73387283086777, 81.82370737195015, 76.25727966427803, 72.19282776117325, 66.16800025105476, 67.96433106064796, 66.7235304415226, 66.0817676782608, 66.39576762914658, 62.397044599056244, 59.76790867745876, 56.164239048957825, 60.80894261598587, 58.0249498039484, 64.04985710978508, 60.9100665897131, 61.78123824298382, 69.44112941622734, 74.88543167710304, 78.22427451610565, 73.55097368359566, 82.9909211397171, 77.30609178543091, 76.39270439743996, 55.07767215371132, 61.172655299305916, 82.84562453627586, 67.3742987215519, 65.26750177145004, 62.37448140978813, 58.94815966486931, 57.79497854411602, 59.81360882520676, 57.58864961564541, 58.70795555412769, 60.39351850748062, 63.38418982923031, 59.06335808336735, 60.55475525557995, 56.971190348267555, 61.43312372267246, 69.83391433954239, 73.49717617034912, 74.2159304022789, 74.97178584337234, 72.60877624154091, 79.04878467321396, 72.02847898006439, 71.7926712334156, 70.86796045303345, 71.94769531488419, 78.63125547766685, 77.29245811700821, 77.71421268582344, 76.51885002851486, 81.23055920004845, 72.2526441514492, 65.27665168046951, 63.65514948964119, 72.8645633161068, 81.94967061281204, 78.00831690430641, 78.96875336766243, 84.35928091406822, 83.3936995267868, 88.46585735678673, 70.94171449542046, 1.8866188335232437, 5.7313070353120565, 9.026836473494768, 6.3770961575210094, 1.3758755335584283, 0.8335192955564708, 1.3978035631589592, 2.7089292649179697, 0.8763142616953701, 0.13461034483043477, 0.6064576108474284, 34.428386986255646, 49.576642736792564, 55.99692262709141, 79.86098349094391, 121.64132997393608, 41.16194486618042, 45.08341424167156, 68.40657413005829, 81.46236956119537, 91.59145563840866, 91.03038534522057, 4.680111492052674, 0.3198454325320199, 0.1757958746748045, 0.14454486721660942, 0.07730327459285036, 0.15604748827172443, 0.15796844847500324, 0.18909373611677438, 0.18328181438846514, 0.20094001607503742, 0.08016691819648258, 0.13556249061366543, 0.12121575928176753, 0.13837567559676245, 0.11947422070079483, 0.1082297928223852, 0.15257725026458502, 0.11006178436218761, 0.11546345427632332, 0.15343704319093376, 0.16244340600678697, 0.11058677962864749, 0.1658910233527422, 0.11155878528370522], [0.050917638873215765, 0.026734914536064025, 0.05145966642885469, 0.03960498535889201, 0.017420577132725157, 0.046331574412761256, 0.02644287200382678, 0.010859283847821644, 0.04474231340282131, 0.07076277906890027, 0.05654365260852501, 0.024858815304469317, 0.058421631329110824, 0.06785685531212948, 0.02509433586965315, 0.020080966896784957, 0.04241792172251735, 0.04007797091617249, 0.03031375843420392, 0.6622317305300385, 64.57352221012115, 83.51986035704613, 79.4437050819397, 66.2029355764389, 43.4552776068449, 31.80825088173151, 20.990801341831684, 33.44463877379894, 47.204061448574066, 28.0718182772398, 1.1046320758759975, 0.11358294112142175, 0.17847323179012164, 0.2621290826937184, 0.23543504008557647, 0.16364325099857524, 1.036127689294517, 1.7636773805133998, 0.6222740840166807, 1.043565790168941, 8.943610489368439, 81.11813083291054, 82.49655246734619, 85.32924726605415, 81.41380056738853, 85.19169464707375, 79.91855800151825, 72.495656311512, 61.64102956652641, 77.45911717414856, 78.68525058031082, 75.67883670330048, 78.70806455612183, 58.06819908320904, 54.98824015259743, 67.36432805657387, 75.99026799201965, 72.37324967980385, 70.13973712921143, 72.3166175186634, 73.72232928872108, 74.06651481986046, 71.86862155795097, 69.76165741682053, 68.31372231245041, 64.89592730998993, 62.996340841054916, 56.028476133942604, 56.32477663457394, 54.35547150671482, 53.945530503988266, 50.24033412337303, 51.391752138733864, 51.48809976875782, 52.85189598798752, 52.81727984547615, 57.137693613767624, 55.32311238348484, 56.83459907770157, 52.69439443945885, 55.248708575963974, 59.517574310302734, 65.65595492720604, 67.45120659470558, 70.14965459704399, 66.84046536684036, 74.99843761324883, 56.921770200133324, 41.32922329008579, 75.85581600666046, 62.909181118011475, 67.77477443218231, 61.34796269237995, 63.18209387362003, 51.40924260020256, 52.804052755236626, 51.20542153716087, 53.47431018948555, 50.516423508524895, 54.95404198765755, 54.524767622351646, 55.14220789074898, 51.5383330732584, 52.48875707387924, 56.16008207201958, 68.04167971014977, 61.822705417871475, 68.4441389143467, 67.12008476257324, 67.71483644843102, 68.1244544684887, 66.90270602703094, 67.73832678794861, 71.0748441517353, 69.00106742978096, 65.80866113305092, 62.41010069847107, 66.47345066070557, 69.44539278745651, 65.27554214000702, 56.34033299982548, 57.42419444024563, 59.74463492631912, 63.62801514565945, 65.24124518036842, 67.50896349549294, 69.72358345985413, 77.07327827811241, 69.61595043540001, 83.97052377462387, 56.54771447181702, 0.2772207447560504, 2.5238677952438593, 1.9316871464252472, 0.8218144986312836, 0.29462767008226365, 0.5128013051580638, 0.7466418854892254, 0.49772959202528, 0.24413425766397268, 0.0894284833339043, 5.3368848748505116, 30.98992869257927, 42.22957357764244, 90.84487929940224, 124.87707674503326, 84.89464178681374, 24.47506047785282, 50.450994819402695, 56.230792477726936, 64.69957664608955, 72.55708381533623, 22.42602612823248, 0.5699950049165636, 0.13869209768017754, 0.19807105127256364, 0.09177179235848598, 0.17501216672826558, 0.028560191494761966, 0.010780913053167751, 0.034633375180419534, 0.034310700502828695, 0.018985985516337678, 0.02505202603060752, 0.07187073133536614, 0.01307449540036032, 0.05878633754036855, 0.08452428242890164, 0.02754044904577313, 0.07228187372675166, 0.037090091791469604, 0.004999715310987085, 0.019566296759876423, 0.025696267730381805, 0.07345696067204699, 0.03170615920680575, 0.029636353865498677, 0.06282168018515222, 0.04327837516029831, 0.046892163081793115, 0.031148086418397725, 0.019779929534706753, 0.03872273875458632, 0.02294745292601874, 0.04343195520050358, 0.014930398938304279, 0.027599807872320525, 0.03190852432453539, 0.01715242804493755, 0.08202525597880594, 0.03203504194971174, 0.047796325306990184, 0.080493403802393, 0.04673993003962096, 0.03450922871707007, 1.3887661043554544, 82.30824217200279, 96.33732497692108, 90.03461077809334, 74.74674671888351, 54.925106540322304, 41.37350991368294, 33.22313345968723, 35.31248174607754, 52.647254168987274, 33.310395777225494, 1.2695518950931728, 0.0884034438058734, 0.1043824695807416, 0.8970449992921203, 0.6039639946538955, 0.7519588095601648, 2.2446592524647713, 4.43745176307857, 0.2054023719392717, 0.6871344067621976, 10.756788644939661, 87.10395723581314, 88.58080878853798, 87.88556009531021, 86.26126125454903, 87.19086617231369, 84.30527821183205, 74.6812154352665, 65.1367735862732, 79.68676283955574, 81.62641435861588, 81.58187314867973, 80.7834143936634, 61.97652876377106, 58.82623940706253, 70.60005202889442, 78.37393328547478, 76.10094085335732, 71.7281886935234, 73.64726811647415, 76.81534051895142, 75.87759643793106, 73.78204688429832, 73.73587936162949, 72.27932631969452, 69.29610639810562, 66.29724651575089, 59.03554357588291, 57.84424290060997, 55.91149561107159, 57.111410424113274, 53.99292916059494, 54.781618639826775, 53.224792778491974, 56.63595333695412, 54.404481276869774, 58.237521797418594, 59.243863597512245, 58.54727357625961, 56.072895750403404, 56.91054940223694, 61.888065710663795, 67.67933115363121, 70.96205100417137, 73.10078904032707, 71.4229966700077, 79.09547656774521, 59.12645369768143, 44.40364211797714, 79.03238475322723, 66.91471338272095, 72.61585906147957, 65.69008469581604, 65.35871967673302, 53.84110830724239, 54.85098011791706, 53.42873923480511, 57.011209800839424, 53.60823020339012, 56.927910670638084, 57.258295342326164, 57.60813497006893, 55.5257935076952, 56.066010519862175, 59.40464437007904, 70.94321921467781, 67.18936264514923, 71.14331647753716, 67.71273896098137, 70.28890192508698, 69.28368106484413, 70.79679027199745, 69.33960646390915, 73.02979364991188, 71.77496418356895, 70.70890858769417, 65.31435325741768, 69.52370658516884, 71.79701820015907, 66.78390920162201, 57.78256081044674, 60.305283442139626, 61.68012946844101, 67.99710810184479, 69.01912406086922, 71.28406092524529, 73.32627654075623, 80.79666808247566, 74.06053394079208, 85.02192735671997, 63.11647139489651, 0.8956269035115838, 0.5996511073317379, 0.42834279185626656, 1.616619334090501, 1.4219002076424658, 0.8134732930921018, 2.328922343440354, 0.5123976361937821, 0.4631655482808128, 0.04041770756884944, 3.8210535887628794, 36.377097219228745, 31.293152421712875, 74.85456213355064, 119.5893868803978, 73.17060649394989, 34.337720051407814, 54.84937280416489, 64.83258470892906, 69.95438307523727, 86.61386713385582, 31.778593473136425, 0.5229115532711148, 0.09661663629231043, 0.17976259463466704, 0.07805161920259707, 0.1508374631521292, 0.06075233126466628, 0.04296032777347136, 0.05713490681955591, 0.021286845549184363, 0.034843659013858996, 0.05366378936741967, 0.054594205066678114, 0.06928007933311164, 0.035782052800641395, 0.1020407339092344, 0.03890421241521835, 0.08226904406910762, 0.021188182581681758, 0.07196270569693297, 0.0057077742894762196, 0.027962337735516485, 0.05136582927661948, 0.02836727577232523, 0.21116216521477327, 0.20057930261828005, 0.1587092157569714, 0.10795804802910425, 0.18354033411014825, 0.12857420544605702, 0.11699672395479865, 0.12972088297829032, 0.14571710431482643, 0.1312215204234235, 0.12482140213251114, 0.12491369561757892, 0.16649873839924112, 0.12955643789609894, 0.10519732546526939, 0.17313073331024498, 0.15333079732954502, 0.10794366520713083, 0.11215838123462163, 1.586211584508419, 98.72710034251213, 110.6848306953907, 104.54838797450066, 88.0366399884224, 62.499373108148575, 49.74213145673275, 36.63419522345066, 51.95099852979183, 70.11473447084427, 44.6636887639761, 2.663119873031974, 0.32819791871588677, 0.3229608794208616, 1.3169002044014633, 1.4154543285258114, 0.606901355786249, 5.3387258760631084, 8.310306072235107, 3.4614240238443017, 4.0130306873470545, 13.02553290501237, 93.13555598258972, 90.4749083518982, 91.91428631544113, 88.49880918860435, 92.05957531929016, 87.07745745778084, 78.90525877475739, 66.45784109830856, 82.65064179897308, 86.4146438241005, 85.58888733386993, 85.21725967526436, 64.81047749519348, 61.96633391082287, 74.57542151212692, 81.09204143285751, 77.68233239650726, 72.23955005407333, 73.92680391669273, 80.28606668114662, 81.1602857708931, 76.69625490903854, 76.82898178696632, 74.68954458832741, 72.20408275723457, 70.98997190594673, 63.69852416217327, 61.46087363362312, 59.31863598525524, 58.919767588377, 55.70268161594868, 56.8758724629879, 55.96322603523731, 59.92233619093895, 57.134118005633354, 62.159906923770905, 62.11324542760849, 61.36134937405586, 59.291653633117676, 61.126829758286476, 64.75894466042519, 72.09205716848373, 75.95774933695793, 77.4660935997963, 74.45926934480667, 83.69937032461166, 64.39722687005997, 48.39562050998211, 82.96148791909218, 69.4676823914051, 74.18021991848946, 69.38471004366875, 70.84212943911552, 57.43824228644371, 57.806609719991684, 56.9143757969141, 59.439591094851494, 57.555511593818665, 60.84346756339073, 60.41641607880592, 60.88129833340645, 58.01716022193432, 59.63741607964039, 62.76717893779278, 75.73089390993118, 69.64538365602493, 75.30615270137787, 72.83407375216484, 73.33558604121208, 73.25518995523453, 73.66122096776962, 71.39874637126923, 75.16243681311607, 75.6623911857605, 72.25192978978157, 70.01663133502007, 74.65265616774559, 75.64582407474518, 71.80540814995766, 59.543652310967445, 63.61885763704777, 65.60774311423302, 72.29653179645538, 71.86200991272926, 74.0458819270134, 76.61879986524582, 83.95861521363258, 75.81908717751503, 88.06092068552971, 67.22473874688148, 0.782512673176825, 8.065730296075344, 6.729555744677782, 3.7407451355829835, 2.064073230139911, 1.0422413237392902, 4.27278189919889, 1.2406348530203104, 1.1207144754007459, 0.1384703884832561, 8.793096765875816, 50.17225697636604, 60.536736622452736, 96.43796637654305, 130.82389444112778, 89.7676295042038, 36.75992667675018, 63.25738683342934, 76.5309789776802, 79.53780323266983, 98.19107070565224, 34.815943390131, 0.7384919165633619, 0.2305913539021276, 0.30776015133596957, 0.35540166834834963, 0.2863078680820763, 0.2095323198591359, 0.1271615718724206, 0.1798486095503904, 0.12112365133361891, 0.14703834982356057, 0.17430432111723348, 0.22203673637704924, 0.10907932184636593, 0.14567883918061852, 0.15975223010173067, 0.1565350199234672, 0.24484812951413915, 0.11745891126338392, 0.13054396928055212, 0.11917726515093818, 0.06872606609249488, 0.12437296682037413, 0.12977557926205918], [0.015398262748931302, 0.0531234761729138, 0.08552310187951662, 0.01622168765607057, 0.049994080618489534, 0.04238925626850687, 0.009613963757146848, 0.03376364489668049, 0.0416319613577798, 0.04009052805486135, 0.07155243161832914, 0.0725939690892119, 0.1116559695219621, 0.018300502670172136, 0.07997803419129923, 0.08806869067484513, 0.016036404922488146, 0.0787794211646542, 0.2805881359381601, 6.585280811414123, 87.29476019740105, 74.68203619122505, 77.02727034687996, 65.45841112732887, 36.9807518273592, 25.39851162582636, 30.89652020484209, 53.55417050421238, 43.37191008031368, 12.442612834274769, 0.028932154054928105, 0.026783894427353516, 0.1772120557143353, 0.30706116696819663, 0.7871666515711695, 0.5877600016538054, 1.2397876172326505, 1.1814860394224524, 1.1489825835451484, 2.839631801471114, 79.42160546779633, 88.44932064414024, 84.91038054227829, 82.48373195528984, 84.90025788545609, 80.70956915616989, 78.24631333351135, 73.93891766667366, 56.81813836097717, 68.02079603075981, 78.95478531718254, 78.9791952073574, 72.854273468256, 55.44236898422241, 57.377464547753334, 63.809482008218765, 73.41032803058624, 71.211097240448, 72.2631011903286, 73.55591341853142, 70.67528039216995, 65.45785635709763, 63.11562404036522, 64.67768222093582, 64.49521601200104, 61.77591472864151, 57.3859266936779, 54.92474555969238, 53.82287688553333, 50.205676183104515, 51.07074536383152, 51.854160726070404, 52.24636808037758, 49.844832345843315, 53.58032450079918, 52.81764082610607, 55.66392369568348, 52.63737089931965, 55.4294952750206, 51.0086452960968, 52.309950068593025, 49.45931263267994, 52.63067565858364, 53.32690469920635, 59.108967036008835, 59.72913555800915, 67.49656856060028, 61.856147423386574, 38.942415565252304, 71.17021903395653, 65.87751343846321, 70.98834559321404, 67.24528804421425, 66.21693402528763, 57.92329005897045, 51.137952357530594, 51.189352199435234, 50.3217713534832, 51.40179879963398, 51.886379197239876, 53.60113978385925, 51.53112106025219, 54.403531327843666, 51.506300792098045, 51.99370063841343, 62.5090017914772, 70.63671246170998, 59.10740152001381, 68.06802749633789, 66.28495797514915, 65.51028594374657, 67.16400280594826, 71.57035276293755, 70.38993090391159, 68.62368687987328, 65.9281875193119, 61.563004553318024, 56.91700525581837, 62.49872334301472, 57.90842145681381, 56.524619311094284, 54.47591744363308, 56.1335214972496, 57.52162501215935, 58.14237490296364, 54.713017120957375, 62.54709094762802, 65.14272406697273, 76.70909821987152, 68.30442801117897, 82.95803770422935, 36.2281110137701, 0.5450609209947288, 0.4437340737786144, 0.8381932822521776, 1.7863654880784452, 0.6238229165319353, 0.2719238883582875, 0.3831079707015306, 0.4356275947066024, 0.04239005036652088, 0.0558548208209686, 11.801997609436512, 34.05091144144535, 76.65191888809204, 101.29266187548637, 67.18544125556946, 31.758967526257038, 39.07008111476898, 50.54188214242458, 55.92352196574211, 67.35460057854652, 46.27503789961338, 0.48902918701060116, 0.07799646278726868, 0.024706396725378, 0.050702742591965944, 0.01808299588446971, 0.018545910497778095, 0.03332674255943857, 0.015594955075357575, 0.04635675548342988, 0.01840697859734064, 0.028915550356032327, 0.09908924970659427, 0.02094100658723619, 0.056560632947366685, 0.04065732107846998, 0.029255220215418376, 0.04161887729424052, 0.013133058273524512, 0.03377593857294414, 0.03366092423675582, 0.018804363426170312, 0.010464280385349412, 0.022781035586376674, 0.0014446283717006736, 0.027848865211126395, 0.12476903619244695, 0.0272201399639016, 0.033126344133052044, 0.003820043980340415, 0.027434937910584267, 0.03418245367356576, 0.004480866882659029, 0.06294395643635653, 0.019927796893171035, 0.011553832027857425, 0.019486541859805584, 0.09823817701544613, 0.0883137849450577, 0.015293374090106227, 0.12440930979209952, 0.08729584777029231, 0.2873858524253592, 9.735005423426628, 105.82125127315521, 84.42626371979713, 88.52917715907097, 74.11082044243813, 50.96043348312378, 33.399098217487335, 35.25436386466026, 64.59135845303535, 50.2228132635355, 16.10939897596836, 0.1128265516308602, 0.11121849573100917, 0.7267635490279645, 0.4665821883827448, 1.6202574013732374, 2.1659182151779532, 2.130848946981132, 2.1914243465289474, 0.1896004003356211, 3.1527171889320016, 84.57640886306763, 92.41176322102547, 90.11663317680359, 88.35576206445694, 90.13373225927353, 83.42402189970016, 83.0936448276043, 79.19323772192001, 61.792588233947754, 72.3913823068142, 82.59036183357239, 82.4305348098278, 76.08328700065613, 58.71357545256615, 60.28504192829132, 67.84923523664474, 76.60250633955002, 76.12724304199219, 74.92307245731354, 76.88711866736412, 73.76801803708076, 69.93160709738731, 68.03264379501343, 67.39594995975494, 68.24156418442726, 66.42846867442131, 61.255620047450066, 56.45068287849426, 55.626385509967804, 52.56509877741337, 52.609309405088425, 53.211295902729034, 55.57973921298981, 53.37690621614456, 56.472516506910324, 54.1194661706686, 55.26011176407337, 55.18624372780323, 54.88573685288429, 54.03354898095131, 52.89413072168827, 52.09852561354637, 56.67566880583763, 56.602268144488335, 60.85652746260166, 63.23022209107876, 70.81258222460747, 65.31384408473969, 42.14142210781574, 71.89344942569733, 68.02736967802048, 72.39674001932144, 70.65647900104523, 70.23852422833443, 60.75355678796768, 53.538260757923126, 55.44026769697666, 54.713951870799065, 54.172986298799515, 55.683823227882385, 57.09294341504574, 55.308794751763344, 55.916724130511284, 54.827273190021515, 54.83187094330788, 64.64681267738342, 71.80090919137001, 65.72266414761543, 70.28990507125854, 70.14419049024582, 69.26145985722542, 68.05728927254677, 74.01187375187874, 71.88946723937988, 72.1652564406395, 70.84462970495224, 66.70319393277168, 58.14658507704735, 64.21083927154541, 59.42623481154442, 59.25109460949898, 56.82220034301281, 59.073799923062325, 61.81941099464893, 61.682287752628326, 57.99856022000313, 65.32922565937042, 67.6339615881443, 79.23595502972603, 72.34681069850922, 85.74745282530785, 42.66909599304199, 0.3707042190944776, 0.37436312588397413, 1.819679131731391, 1.8375628720968962, 1.2340265326201916, 1.049496321938932, 0.8116185176186264, 0.5081654351670295, 0.06925075707840733, 0.09701137722004205, 13.103712759912014, 35.40610872209072, 62.936957627534866, 105.08153736591339, 57.57707543671131, 27.362973913550377, 49.14198026061058, 59.31199014186859, 64.55925017595291, 74.92697864770889, 61.712249144911766, 0.9724145487416536, 0.05377760884584859, 0.02564731938036857, 0.06746535756974481, 0.022212593139556702, 0.04242940645781346, 0.04864670037932228, 0.08263400261057541, 0.02659397512616124, 0.04039299034047872, 0.022539485071320087, 0.051232832702226005, 0.02651720180438133, 0.021457467155414633, 0.01331292240138282, 0.0675625418080017, 0.11814310462796129, 0.012760883273585932, 0.014172115115798078, 0.04956639575539157, 0.0185518847865751, 0.016545993203180842, 0.0059812144263560185, 0.05514009921171237, 0.12769538385327905, 0.30026692373212427, 0.07751429686322808, 0.12637586012715474, 0.15263593930285424, 0.11044721875805408, 0.10844278920558281, 0.12341498033492826, 0.08394261676585302, 0.12409908464178443, 0.15120708238100633, 0.15466271492186934, 0.24170099291950464, 0.1209058755193837, 0.12680157087743282, 0.2261038837605156, 0.1871008172747679, 0.6305128731764853, 13.049160987138748, 121.33527159690857, 96.68527230620384, 100.43630182743073, 84.731934517622, 52.37556114792824, 34.29648846387863, 46.567291617393494, 76.01944282650948, 65.49181893467903, 22.169452495872974, 0.2669846877688542, 0.3245488676475361, 0.9615724836476147, 1.2903184932656586, 1.839257343672216, 3.037517345510423, 5.637023169547319, 7.876259637996554, 9.038371704518795, 3.7043860740959644, 89.95463266968727, 92.46327325701714, 91.82727098464966, 90.9094986319542, 92.3166087269783, 86.36144667863846, 85.91721251606941, 82.2553414106369, 64.67143535614014, 76.59584149718285, 87.27361813187599, 85.76800972223282, 81.41152828931808, 62.41028688848019, 64.32465076446533, 68.49991232156754, 79.6090418100357, 79.8306155204773, 77.01845481991768, 77.57583171129227, 77.19379261136055, 73.52886646986008, 71.70454636216164, 70.7263420522213, 70.7647579908371, 68.6007209122181, 64.23627510666847, 59.672742784023285, 59.37062859535217, 55.128536224365234, 55.77669404447079, 57.52199739217758, 57.549158334732056, 55.72633154690266, 59.981054440140724, 57.424414828419685, 59.354114681482315, 59.65995267033577, 60.18058553338051, 57.38816477358341, 58.06148484349251, 54.95721101760864, 60.15968665480614, 59.00798365473747, 65.56114241480827, 66.60037904977798, 74.3470461666584, 69.23118308186531, 44.48997348546982, 75.88579639792442, 71.0080361366272, 75.8431626856327, 74.90063086152077, 73.2514737546444, 64.05109584331512, 56.83741472661495, 57.7555176615715, 56.67920261621475, 56.22250512242317, 58.31002190709114, 57.84516245126724, 58.630333319306374, 59.940632209181786, 57.0073302090168, 59.06169377267361, 70.91029018163681, 75.84823921322823, 68.91661316156387, 75.55893033742905, 73.21387097239494, 70.66018760204315, 70.5209630727768, 79.19324532151222, 75.40883079171181, 75.29805913567543, 74.08510342240334, 68.50307375192642, 62.074472308158875, 68.38376015424728, 63.972804844379425, 62.31759086251259, 59.21864055097103, 61.8214400857687, 65.24815320968628, 64.70285966992378, 60.414143800735474, 68.95816773176193, 72.38651856780052, 82.44172140955925, 75.80764219164848, 88.08357506990433, 44.40624117851257, 1.0885330522432923, 5.3377654775977135, 6.81756567209959, 6.9099197164177895, 2.4109901022166014, 1.5550200082361698, 1.5531221288256347, 1.4385555451735854, 0.13279426493681967, 0.20808293513255194, 19.969951920211315, 57.0911081135273, 88.4799014031887, 106.42858788371086, 75.70597484707832, 45.38721174001694, 55.38946442306042, 67.80953496694565, 75.37483021616936, 84.20217454433441, 72.79694214463234, 1.0667409840971231, 0.17932612274307758, 0.09014496754389256, 0.23776388465194032, 0.12711736955679953, 0.12156145909102634, 0.09042174409842119, 0.12134395787143148, 0.1356165189645253, 0.0840918107132893, 0.11005382111761719, 0.2622374065686017, 0.09876293479464948, 0.10917408668319695, 0.11640541779343039, 0.11979802715359256, 0.16564117191592231, 0.15261677704984322, 0.08069377625361085, 0.10727035172749311, 0.08854934261762537, 0.12343342270469293, 0.13615159259643406], [0.011846165853057755, 0.03229254492907785, 0.027864197982125916, 0.11207595831365325, 0.041846801977953874, 0.04205388715490699, 0.06277247579419054, 0.05184046982321888, 0.03449164723861031, 0.039482052306993864, 0.04465490324946586, 0.12797107687219977, 0.05088577476271894, 0.010109453087352449, 0.04249465237080585, 0.032051732850959525, 0.04414087321492843, 0.24777622864348814, 0.3267287334892899, 30.895555056631565, 99.45329457521439, 73.63815620541573, 80.8178861439228, 58.74840818345547, 35.4298460483551, 30.11295475065708, 55.99690742790699, 29.10460475832224, 31.927387788891792, 1.504460871219635, 0.09155492196441628, 0.11764660041080788, 0.5011339124757797, 1.2729169707745314, 0.4515195591375232, 0.8377003180794418, 2.6326960930600762, 2.802592101506889, 0.5542890226934105, 65.45396536588669, 96.5578119456768, 80.32949835062027, 84.9746198952198, 78.18492382764816, 84.42098200321198, 82.94698029756546, 82.89851769804955, 71.75158023834229, 58.50796468555927, 57.874227091670036, 68.99977549910545, 72.2662778198719, 61.681797578930855, 54.67175133526325, 54.98503692448139, 61.477151960134506, 73.46463471651077, 73.93359035253525, 75.17604768276215, 70.74777290225029, 68.13877210021019, 61.56954400241375, 60.76332986354828, 57.88117311894894, 57.61638432741165, 55.24637170135975, 55.488635301589966, 51.79492190480232, 52.80022636055946, 50.88243126869202, 50.74866704642773, 50.790753588080406, 50.42121961712837, 50.604620575904846, 53.444447591900826, 51.751353442668915, 54.21662695705891, 50.65567843616009, 50.78288421034813, 49.73212279379368, 50.914311558008194, 49.8259549587965, 52.53988333046436, 50.97743757069111, 49.795807376503944, 54.63833972811699, 65.63502565026283, 63.12310963869095, 40.50967946648598, 60.64512960612774, 61.16345979273319, 64.60103273391724, 66.75959810614586, 62.99660682678223, 59.51448507606983, 51.146201714873314, 52.077322751283646, 52.85193018615246, 55.101120695471764, 51.15630157291889, 54.89823438227177, 54.759564623236656, 52.851516008377075, 50.94391576945782, 51.61674186587334, 51.636599600315094, 62.757508456707, 67.53059193491936, 58.84038224816322, 64.36916917562485, 64.41879451274872, 65.97402825951576, 67.50986024737358, 69.16568979620934, 68.97801026701927, 64.95162472128868, 64.44255083799362, 59.62253987789154, 53.77852946519852, 56.755772307515144, 58.977440893650055, 55.97818203270435, 53.53118933737278, 54.45485897362232, 58.05869959294796, 61.19872190058231, 60.78272022306919, 66.01105347275734, 69.97007623314857, 74.7425289452076, 71.69095829129219, 66.50943472981453, 17.13273536413908, 0.10892845064518042, 1.3559729140251875, 1.318043943028897, 1.6764529421925545, 0.9331869380548596, 0.10990019654855132, 0.18071745667839423, 0.3351317154010758, 0.07941406132886186, 0.7761270564515144, 18.139799125492573, 30.355963110923767, 52.555302903056145, 60.64030386507511, 29.904769621789455, 19.455062448978424, 44.65802326798439, 58.3019283413887, 62.036029770970345, 64.91357356309891, 14.921403173357248, 0.4213851870736107, 0.08101770145003684, 0.01149696960055735, 0.06475052941823378, 0.02325894900423009, 0.014139885497570504, 0.12546999467303976, 0.05315785245329607, 0.0365652338223299, 0.05174158977752086, 0.01710489348624833, 0.039775085606379434, 0.056647356614121236, 0.016284358316625003, 0.033336386768496595, 0.040195913024945185, 0.025647128277341835, 0.03256430085457396, 0.019164898767485283, 0.04274791026546154, 0.047877493998385035, 0.026184088819718454, 0.0509248896560166, 0.038924135369597934, 0.053576271602651104, 0.04209483515296597, 0.09087868442293257, 0.012137159174017143, 0.06380027611157857, 0.024251434224424884, 0.030584824162360746, 0.05626470156130381, 0.04029421790619381, 0.05726103481720202, 0.02202723248046823, 0.03908670652890578, 0.06074821976653766, 0.09295433046645485, 0.101857571862638, 0.27959267841652036, 0.33579745155293494, 41.97826266288757, 114.02662977576256, 80.17258197069168, 90.62215805053711, 74.45100098848343, 49.25348527729511, 28.479412905871868, 35.90501815080643, 27.091028206050396, 37.56799131631851, 1.334461912047118, 0.3010488802101463, 0.011271725925325882, 0.7098931074142456, 1.2107207207009196, 1.8957643490284681, 3.335936707444489, 2.5413698935881257, 0.9346382226794958, 0.6108330166898668, 72.43224531412125, 99.67192724347115, 83.92481222748756, 87.20127761363983, 83.83692294359207, 87.93204680085182, 86.1697469651699, 85.80782398581505, 74.04996290802956, 61.21361330151558, 61.69172264635563, 74.73581850528717, 73.96152645349503, 64.89268988370895, 59.6703565120697, 58.12859684228897, 65.34256294369698, 75.76359495520592, 76.68585866689682, 76.41333729028702, 72.68607169389725, 72.03597217798233, 63.74092608690262, 63.387358859181404, 61.73227407038212, 60.05127087235451, 58.9442078769207, 58.011677116155624, 53.66620369255543, 54.872859343886375, 52.97640010714531, 54.65838745236397, 52.793094143271446, 51.85379974544048, 53.39554041624069, 55.89766055345535, 52.68990308046341, 55.66498003900051, 53.47853176295757, 51.72937922179699, 53.760134652256966, 52.651414945721626, 52.01668180525303, 54.50887307524681, 54.46759968996048, 51.69922024011612, 57.4071941524744, 69.20752555131912, 66.26233398914337, 42.935537695884705, 61.59915201365948, 63.54667291045189, 66.54416486620903, 69.95006650686264, 67.04250812530518, 62.764819264411926, 54.524877816438675, 55.32706417143345, 55.900947377085686, 56.635770946741104, 54.02353271842003, 56.785923689603806, 57.19124414026737, 56.87198527157307, 54.09420132637024, 53.34202028810978, 53.62119510769844, 65.75343489646912, 69.98916640877724, 64.66800794005394, 67.13765501976013, 67.08907842636108, 68.18417206406593, 72.09695890545845, 71.42073959112167, 71.37252777814865, 68.48853573203087, 67.92001783847809, 62.068521827459335, 55.73366895318031, 60.294400826096535, 58.89191508293152, 57.485777735710144, 57.57870934903622, 58.30884017050266, 62.32113987207413, 65.39548650383949, 64.82419475913048, 69.7087262570858, 72.85171240568161, 76.99745714664459, 74.46704372763634, 72.30910152196884, 22.5792833045125, 0.4735015577170998, 0.9474549943115562, 0.9889492427464575, 1.402390985749662, 1.7269117408432066, 1.5302345319651067, 0.9665832866448909, 0.5501087126322091, 0.12819284544093534, 0.29030005855020136, 21.696429178118706, 33.44768241047859, 61.03473789989948, 63.82756903767586, 24.824993200600147, 31.1681030318141, 51.303368881344795, 68.77165853977203, 67.12412774562836, 77.83467382192612, 26.833267137408257, 0.46524825214874, 0.07669767466722988, 0.07067299404297955, 0.04530034166236874, 0.053692992878495716, 0.04102737446373794, 0.04195711109787226, 0.04102626124222297, 0.06293816026300192, 0.031198155411402695, 0.02377205506491009, 0.03647871424618643, 0.03924668017134536, 0.0624219817109406, 0.02075133590551559, 0.05899134099308867, 0.04725309176137671, 0.035524961713235825, 0.037864133264520206, 0.04542779439361766, 0.07947317339130677, 0.021984171216899995, 0.12260077011887915, 0.1872249785810709, 0.2583557367324829, 0.13875112810637802, 0.12766960164299235, 0.1337091252207756, 0.1301234238781035, 0.1004143469617702, 0.1537390230805613, 0.13048247492406517, 0.21337953920010477, 0.2792150143068284, 0.13871554954675958, 0.1188764652761165, 0.15869492199271917, 0.2193125052144751, 0.21845324663445354, 0.43112730025313795, 0.5194974958430976, 47.72440932691097, 128.29505413770676, 96.1185023188591, 105.16709357500076, 80.71708515286446, 51.24315731227398, 40.96609577536583, 74.92254808545113, 42.51232400536537, 55.129402577877045, 2.5941022764891386, 0.36740320560056716, 0.18562079669209197, 2.0740750059485435, 3.01185114774853, 0.9650590340606868, 7.545036161318421, 9.210007544606924, 9.82535507529974, 0.8492010540794581, 74.39820662140846, 102.29417413473129, 87.7475742995739, 91.42389222979546, 85.55806338787079, 94.69139009714127, 89.44724589586258, 90.06998687982559, 77.54878476262093, 64.185281842947, 64.65651735663414, 75.82361653447151, 77.4002431333065, 67.62184023857117, 61.8267560005188, 61.76563248038292, 67.94081032276154, 80.57274609804153, 81.01612910628319, 79.45437490940094, 75.12511521577835, 75.92999562621117, 68.91028270125389, 69.39129889011383, 64.08429086208344, 62.240401804447174, 62.535011395812035, 62.45600983500481, 57.448589131236076, 57.413061037659645, 55.75011447072029, 57.56463870406151, 55.937186032533646, 55.00472366809845, 56.65723979473114, 58.10288742184639, 55.35971961915493, 59.076398983597755, 55.85466966032982, 56.12256668508053, 55.54931044578552, 56.123729422688484, 55.897003188729286, 58.4865528345108, 58.42334322631359, 55.79669237136841, 62.776214852929115, 74.45350885391235, 70.18342718482018, 46.94965749979019, 62.604315876960754, 67.08904802799225, 68.23258146643639, 74.22423675656319, 69.07525464892387, 67.69482672214508, 56.47068880498409, 58.639775812625885, 56.82850420475006, 60.39511062204838, 56.0218720883131, 59.99772794544697, 61.6640867292881, 61.04189671576023, 57.44330741465092, 55.15554517507553, 57.63724900782108, 70.82540273666382, 72.71770879626274, 68.22617501020432, 70.05600482225418, 71.59075006842613, 70.94606906175613, 74.13413599133492, 74.78684976696968, 74.90739449858665, 72.31456562876701, 71.35251805186272, 65.79769492149353, 59.10990558564663, 64.12345916032791, 61.453844010829926, 61.0155413299799, 59.486146196722984, 61.697566732764244, 65.26448473334312, 67.69022136926651, 68.30644190311432, 73.28722983598709, 77.1920295059681, 80.36298215389252, 77.12194606661797, 76.16400986909866, 24.005909152328968, 0.8717608591541648, 5.09610746987164, 5.014154417440295, 5.13433531858027, 3.6189934937283397, 2.0284097688272595, 1.0381541680544615, 1.758242603391409, 0.3111647389596328, 1.2836669501848519, 29.825201891362667, 47.552624344825745, 64.93235975503922, 73.6622317135334, 42.06365928053856, 34.18986618518829, 59.46575649082661, 78.19392174482346, 77.38251328468323, 89.46287825703621, 27.810261212289333, 0.86620805086568, 0.1885201153345406, 0.12085034803021699, 0.21189371502259746, 0.12327736389124766, 0.1481045488617383, 0.2849812642671168, 0.09412437080754898, 0.1612153890891932, 0.1097015458799433, 0.12841382733313367, 0.11641719567705877, 0.23536882566986606, 0.15360120625700802, 0.15664067206671461, 0.11996918867225759, 0.09772654782864265, 0.11660268064588308, 0.10530535990255885, 0.11623324695392512, 0.15091267239768058, 0.12173401584732346], [0.05892423228942789, 0.04914449593343306, 0.04977117285307031, 0.053512075828621164, 0.04943086103594396, 0.037541881611105055, 0.10047069081338122, 0.02562201399996411, 0.03886347221850883, 0.018527225074649323, 0.02171100706618745, 0.04366590983408969, 0.01636586839595111, 0.03429408010561019, 0.04471231579373125, 0.019713692854566034, 0.036295121753937565, 0.03389911653357558, 0.6901633786037564, 70.02958863973618, 83.02157789468765, 77.51263350248337, 56.246098056435585, 40.29561795294285, 33.873099982738495, 58.188481628894806, 46.32243275642395, 62.57063448429108, 18.725305907428265, 0.2911174006294459, 0.18846586433937773, 0.0485375193238724, 0.11786459144786932, 0.2940435108030215, 2.405499159358442, 3.7579199764877558, 0.39853496477007866, 1.8273094785399735, 43.251798525452614, 99.0138253569603, 76.22280791401863, 81.0702458024025, 77.33681693673134, 76.81476294994354, 80.72584748268127, 78.76664221286774, 81.59834906458855, 72.38699734210968, 56.37433737516403, 55.68046800792217, 58.28055068850517, 59.211295545101166, 56.42069108784199, 57.335283011198044, 54.19465273618698, 59.76599358022213, 71.80614531040192, 71.03294000029564, 73.02375957369804, 66.55670419335365, 65.10689958930016, 57.70195193588734, 54.94746454060078, 54.3196090310812, 54.480724185705185, 50.51088720560074, 52.23231263458729, 49.75106097757816, 51.37800447642803, 49.7511787712574, 50.63021220266819, 50.53032696247101, 47.69538268446922, 51.79172247648239, 52.92320296168327, 52.129759937524796, 52.944599613547325, 50.319039300084114, 50.80208458006382, 49.03674490749836, 50.84131747484207, 52.82017529010773, 54.04555633664131, 54.91085730493069, 54.709031134843826, 54.21664595603943, 65.15319630503654, 63.21598045527935, 43.62705118954182, 63.80765810608864, 62.18617111444473, 66.88483938574791, 63.37567828595638, 64.85880330204964, 55.77996946871281, 52.158478796482086, 50.374246537685394, 52.272434681653976, 51.899378299713135, 51.216433346271515, 50.48833541572094, 54.07920353114605, 49.766419753432274, 50.332897156476974, 50.84558844566345, 48.73301200568676, 50.425973162055016, 61.31999999284744, 65.07828712463379, 61.12257018685341, 61.220787316560745, 65.41676536202431, 67.20807284116745, 69.74404916167259, 66.80375933647156, 67.90514543652534, 65.4575827717781, 61.70182250440121, 51.733087822794914, 51.81104063987732, 54.280262142419815, 55.397086814045906, 54.58629012107849, 61.082915514707565, 64.7307425737381, 69.8872558772564, 69.16828885674477, 71.0172164440155, 71.4776149392128, 73.47381502389908, 71.21631056070328, 55.62231592833996, 64.64457079768181, 25.485906936228275, 0.7208490476477891, 1.0224568541161716, 1.165613103657961, 1.0140579985454679, 0.581866221036762, 0.055191967912833206, 0.24528268666472286, 0.05392026447225362, 0.038058164063841105, 5.7954661175608635, 22.901574410498142, 31.73247914761305, 58.65698888897896, 58.12923140823841, 35.091497004032135, 39.254321828484535, 48.16594563424587, 50.2227258682251, 62.7815193682909, 55.286850929260254, 1.1465346836484969, 0.15644296392565593, 0.050272493608645163, 0.09412779210833833, 0.020165657078905497, 0.030167154582159128, 0.054149094576132484, 0.003739589838005486, 0.011835781351692276, 0.05448018891911488, 0.05441507659270428, 0.05340581512427889, 0.05861325014848262, 0.02999468873895239, 0.04534947554930113, 0.056736603582976386, 0.058615335583454, 0.02319421331776539, 0.022566636544070207, 0.014228970121621387, 0.07290273220860399, 0.04159480573434848, 0.04305691829358693, 0.04255810970789753, 0.026406421420688275, 0.021528902580030262, 0.021798229827254545, 0.04114368013688363, 0.05700608482584357, 0.15640796424122527, 0.037991341087035835, 0.030961948359617963, 0.013561451887653675, 0.029366336420935113, 0.09899247364955954, 0.12474962160922587, 0.02950671550934203, 0.021881613829464186, 0.07968720878125168, 0.021610349576803856, 1.0113654867745936, 84.32810738682747, 94.06189307570457, 85.12647494673729, 68.41248661279678, 46.729835495352745, 43.926323130726814, 46.40415117144585, 44.822550639510155, 61.46113961935043, 19.592138193547726, 0.09438494627829641, 0.06647876129136421, 0.31028478930238634, 0.5004829599056393, 1.1127789574675262, 3.583668926730752, 2.7022492233663797, 0.25082056294195354, 0.9323514578863978, 45.199961587786674, 105.26611626148224, 79.30327221751213, 85.06928041577339, 79.4729483127594, 82.54079729318619, 82.8707791864872, 85.22653877735138, 83.41122418642044, 77.01103761792183, 59.00872081518173, 59.25750866532326, 60.75823053717613, 61.79495170712471, 56.50613330304623, 59.318407997488976, 56.31022721529007, 63.71188044548035, 73.39920222759247, 73.84237244725227, 75.41873306035995, 71.57021597027779, 68.24930816888809, 61.97965979576111, 57.28159189224243, 56.526986584067345, 57.55538620054722, 53.23131702840328, 55.137154161930084, 53.107512071728706, 53.56899730861187, 50.60147054493427, 50.81909626722336, 53.09120714664459, 50.832403153181076, 54.05156381428242, 54.321018755435944, 56.0506821423769, 54.79736119508743, 53.188170343637466, 51.53150863945484, 51.759739592671394, 55.426276847720146, 57.21996679902077, 57.40686357021332, 57.29313187301159, 57.10166394710541, 56.3400936126709, 67.1615481376648, 66.12452298402786, 46.334649100899696, 65.68802520632744, 64.51038479804993, 68.33067700266838, 67.16486155986786, 69.0739095211029, 57.75310859084129, 55.05485437810421, 53.34077015519142, 54.84722971916199, 54.77239653468132, 55.131914243102074, 52.342157140374184, 56.04264557361603, 52.85881161689758, 53.53200629353523, 53.823093473911285, 50.92128798365593, 52.875124141573906, 62.587011605501175, 66.6696797311306, 64.80676129460335, 65.15317350625992, 66.93409234285355, 70.32841980457306, 72.23087131977081, 68.57017055153847, 71.47712096571922, 67.85615086555481, 66.48105025291443, 54.75912764668465, 55.543420761823654, 55.99694162607193, 56.76787085831165, 57.56567224860191, 64.54464375972748, 69.59346324205399, 72.64833211898804, 71.56744211912155, 75.25911122560501, 74.48856577277184, 77.6159955561161, 75.1455657184124, 60.11084407567978, 73.21517050266266, 32.74077594280243, 1.7178766569122672, 0.8083283097948879, 0.46128788497298956, 0.4584184451960027, 1.792697492055595, 0.9495729650370777, 0.39443065063096583, 0.08194720430765301, 0.1630063695483841, 6.365969404578209, 37.15290538966656, 33.73019725084305, 69.5973314344883, 51.40032447874546, 31.941283643245697, 51.6458673030138, 52.60578319430351, 57.6850276440382, 67.47511491179466, 70.1128801703453, 2.4545227037742734, 0.15153226180700585, 0.04234412626828998, 0.06134945957455784, 0.02226380503998371, 0.014978981780586764, 0.022112375372671522, 0.07791882671881467, 0.059697976903407834, 0.02292516437591985, 0.06045851499948185, 0.0024134129898811807, 0.07650991872651502, 0.053266621616785415, 0.02519668731110869, 0.018375231375102885, 0.02574348502093926, 0.03368222387507558, 0.11770217242883518, 0.025795786023081746, 0.029254967885208316, 0.023481834505219012, 0.16636914457194507, 0.13383257406530902, 0.07478867046302184, 0.1430728766717948, 0.10457277850946411, 0.11507989751407877, 0.2934143180027604, 0.2208627774962224, 0.14776975120184943, 0.17368691362207755, 0.18393435515463352, 0.0951552733022254, 0.17719497147481889, 0.31645444105379283, 0.1475660316646099, 0.09177519881632179, 0.12279428512556478, 0.1932413619942963, 1.3055783556774259, 100.30656158924103, 104.20126140117645, 98.51894751191139, 77.39015087485313, 59.74746197462082, 46.03489078581333, 80.58210119605064, 67.83855020999908, 95.35938665270805, 32.580416947603226, 0.3053562162676826, 0.6382516329176724, 0.30993948283139616, 2.410638858564198, 1.361511116847396, 5.886238496750593, 9.444739948958158, 5.130542172119021, 6.049485811963677, 49.30928148329258, 106.56992509961128, 82.56408244371414, 88.548753708601, 83.7654335796833, 83.76999333500862, 84.57602888345718, 84.41221207380295, 88.03366094827652, 80.4374049603939, 61.64661906659603, 61.65426425635815, 63.41772302985191, 65.71892514824867, 60.03810457885265, 62.93873593211174, 60.02083070576191, 65.63946381211281, 77.46830508112907, 77.14746549725533, 77.82661825418472, 73.42200860381126, 71.09698176383972, 64.89190712571144, 60.30119106173515, 59.766031578183174, 60.39656214416027, 56.679916977882385, 58.84981334209442, 55.819749534130096, 56.43149010837078, 55.262361243367195, 54.570908546447754, 57.35049359500408, 51.87888979911804, 57.2826824337244, 58.846541717648506, 57.326133102178574, 58.95508289337158, 57.570175006985664, 55.73507107794285, 55.3132177144289, 57.48591832816601, 59.101625829935074, 62.352788373827934, 62.21213512122631, 59.81971889734268, 60.15204146504402, 70.42077764868736, 70.7549849152565, 48.694812655448914, 67.06938788294792, 68.33187013864517, 71.73094734549522, 70.78304260969162, 72.81812220811844, 61.12624078989029, 58.99753041565418, 55.77452436089516, 58.3057851344347, 58.272939696908, 56.53759181499481, 54.86937493085861, 59.78724583983421, 54.950557574629784, 56.300663128495216, 56.570232063531876, 54.09824810922146, 57.473405599594116, 67.94988423585892, 71.08347728848457, 68.9850702881813, 67.76577651500702, 70.20146861672401, 73.6918169260025, 76.33825331926346, 71.62350431084633, 75.58079436421394, 68.28158363699913, 67.06605926156044, 58.53251896798611, 57.67797142267227, 59.60545599460602, 59.679715409874916, 61.70355141162872, 66.86016350984573, 72.61838972568512, 74.38341781497002, 75.70764675736427, 77.58267894387245, 77.77941718697548, 81.99517697095871, 78.93189534544945, 63.11125807464123, 70.96648916602135, 29.638732597231865, 1.1123291566036642, 4.073058441281319, 5.3484733030200005, 3.7394211441278458, 2.2940449649468064, 1.4079427253454924, 1.3161303894594312, 0.4681107454234734, 0.318828274612315, 11.304937731474638, 47.74023927748203, 45.04381276667118, 74.9876081943512, 68.83214369416237, 49.11212906241417, 55.746808648109436, 67.29372024536133, 69.4908307492733, 79.56954672932625, 78.43590036034584, 2.556006470695138, 0.2806888008490205, 0.17789456440368667, 0.17945495957974344, 0.10266288372804411, 0.11622865305980667, 0.14338399982079864, 0.1321284842560999, 0.12285508186323568, 0.14345045172376558, 0.13661780976690352, 0.1648754091002047, 0.21403825463494286, 0.07939279137644917, 0.07070707346429117, 0.10795064139529131, 0.14827375853201374, 0.1209192415990401, 0.15926420863252133, 0.13625602761749178, 0.17093854781705886, 0.15522888454142958], [0.030023450672160834, 0.04204398319416214, 0.06409073786926456, 0.02368940393353114, 0.044298679786152206, 0.03890109910571482, 0.06664977438049391, 0.09508569695753977, 0.04391715279780328, 0.02834654016623972, 0.05157607600267511, 0.0319075484003406, 0.06923621098394506, 0.0980408770556096, 0.03321864875033498, 0.032441954099340364, 0.11236578182433732, 0.23039075138513, 9.719488006085157, 91.58483639359474, 66.91507056355476, 82.21298888325691, 54.10689264535904, 49.836712181568146, 37.27986037731171, 69.93355259299278, 46.17460548877716, 32.706642374396324, 1.7484931577928364, 0.017722800075716805, 0.2240396148408763, 0.18060798989608884, 0.06354742639814503, 0.8234604040626436, 5.438215937465429, 0.5573388934135437, 2.03377484343946, 14.274156354367733, 103.11655640602112, 81.62108704447746, 82.7393290400505, 71.58425241708755, 75.79327896237373, 79.29362073540688, 82.85450085997581, 80.65603002905846, 78.43691870570183, 69.15739104151726, 63.333249762654305, 55.38301236927509, 60.11265657842159, 57.91856311261654, 55.48432633280754, 55.40083721280098, 54.02153022587299, 56.48354351520538, 69.83150526881218, 69.39018175005913, 72.31922417879105, 68.12614917755127, 66.27484291791916, 57.1856926381588, 54.792740643024445, 51.338004022836685, 53.198232203722, 50.659664422273636, 50.22542752325535, 48.8588460534811, 50.684556886553764, 49.144556522369385, 48.82991820573807, 48.63272778689861, 50.95011703670025, 51.762809827923775, 52.05068998038769, 56.667267456650734, 55.78737907111645, 51.390072628855705, 52.09664471447468, 49.54492203891277, 51.78517922759056, 62.034931629896164, 64.1690643131733, 61.671739518642426, 61.30213335156441, 56.541642397642136, 64.36517179012299, 57.29026302695274, 44.414182752370834, 67.53113150596619, 62.41886302828789, 66.136135160923, 63.613135144114494, 63.06966930627823, 52.04226203262806, 51.49229094386101, 48.576904982328415, 51.40409007668495, 49.565984308719635, 52.24093057215214, 51.645415127277374, 52.00369410216808, 50.83698570728302, 49.14250463247299, 47.77912639081478, 49.74077872931957, 47.83242993056774, 50.31794875860214, 55.24099498987198, 60.147747695446014, 57.646083533763885, 59.92623098194599, 63.51703070104122, 66.00414544343948, 68.13290521502495, 66.04279696941376, 66.92888662219048, 65.37878260016441, 54.120746701955795, 52.58641183376312, 52.339482083916664, 50.43639600276947, 59.0151272714138, 67.37479269504547, 73.36245819926262, 71.07371181249619, 69.78961631655693, 71.50965481996536, 72.88904920220375, 69.87152472138405, 78.91120925545692, 79.19471964240074, 70.44942811131477, 84.25039395689964, 57.49429687857628, 10.060335416346788, 1.0954954661428928, 1.3716306863352656, 1.3342937710694969, 1.9786617695353925, 0.35136278194841, 0.059119680590811186, 0.038851631252327934, 0.273022890323773, 11.713037732988596, 27.858615517616272, 41.695033460855484, 55.38304656744003, 25.645868852734566, 30.828695744276047, 34.47918266057968, 47.173902466893196, 52.96666122972965, 63.2182527333498, 15.443412512540817, 0.6244603323284537, 0.17772532504750416, 0.07816119730705395, 0.027394346143410075, 0.08522750445990823, 0.07497172118746676, 0.03241810147301294, 0.0514647093223175, 0.04121044745261315, 0.06363055435940623, 0.033066408286686055, 0.04071049224876333, 0.04583232424920425, 0.0372326657816302, 0.05770400050096214, 0.06039957734174095, 0.04082150640897453, 0.0623128934239503, 0.06838837405666709, 0.04185632373264525, 0.018533080619818065, 0.0071868453869683435, 0.02880850668589119, 0.035080493180430494, 0.03336969806696288, 0.07146967473090626, 0.03193924552761018, 0.07214963785372674, 0.06639290964812972, 0.05335049172572326, 0.018696837360039353, 0.026500214044062886, 0.019928383189835586, 0.0180712903602398, 0.03353388710820582, 0.10485145496204495, 0.11131656312500127, 0.06710216533974744, 0.203026044764556, 13.88126503676176, 107.75075733661652, 76.30388036370277, 90.94580948352814, 62.40685947239399, 60.21155767142773, 31.500782780349255, 57.54543073475361, 44.66050073504448, 35.26903107762337, 2.606563470326364, 0.1033439303864725, 0.34559567109681666, 0.8213868434540927, 1.2472981517203152, 2.7271621115505695, 3.190010762773454, 0.7518742047250271, 1.080334517173469, 14.909671302884817, 109.21374723315239, 83.93696397542953, 87.27119386196136, 74.43666815757751, 80.6531497836113, 79.84480395913124, 86.79412946105003, 82.77930289506912, 83.29289093613625, 71.4411672949791, 67.4498538672924, 57.75680959224701, 62.50182397663593, 60.245668441057205, 58.69162403047085, 58.018151968717575, 57.35551692545414, 59.80942524969578, 74.17504459619522, 73.72701063752174, 74.57366600632668, 72.08394840359688, 69.44556757807732, 61.81528061628342, 58.04400958120823, 52.94787883758545, 55.18703408539295, 53.013311326503754, 52.122745513916016, 51.2965102493763, 53.91034439206123, 51.444550305604935, 51.74417182803154, 51.248933002352715, 52.91705869138241, 53.28506514430046, 55.84631010890007, 59.086422845721245, 60.11409670114517, 53.785524889826775, 52.83468671143055, 51.67326383292675, 56.01862706243992, 64.46386009454727, 68.36121216416359, 63.2491222769022, 64.90004628896713, 62.53689609467983, 67.92412161827087, 61.02190978825092, 45.97404845058918, 70.25973469018936, 66.76782846450806, 69.0917457640171, 65.39550170302391, 63.826444298028946, 54.5754949003458, 54.27962377667427, 51.174020022153854, 52.039514780044556, 51.391444355249405, 54.1460495442152, 53.632225915789604, 53.66456598043442, 52.77708560228348, 52.47161619365215, 50.67612133920193, 51.87969155609608, 51.88450209796429, 51.80929273366928, 58.16413253545761, 63.1620005518198, 61.37538582086563, 64.24797847867012, 65.65237551927567, 69.54386070370674, 71.1059720814228, 68.56967657804489, 70.09785577654839, 69.59075018763542, 56.81496933102608, 56.3120549172163, 54.52311471104622, 52.30024538934231, 62.02165514230728, 72.85723730921745, 76.0501679778099, 74.05842885375023, 72.34704628586769, 74.68090385198593, 76.89342632889748, 69.37904074788094, 77.21174284815788, 81.78437188267708, 72.41361871361732, 85.08036062121391, 66.09740003943443, 14.967875629663467, 0.4412183118984103, 0.8779435430187732, 0.26109357888344675, 1.8627378274686635, 1.50114068062976, 0.3807277843588963, 0.1186548822443001, 0.29015854583121836, 21.848124638199806, 38.46618331968784, 44.95691142976284, 57.945606261491776, 24.468367137014866, 42.268947064876556, 41.49695388972759, 58.8260418176651, 59.42534565925598, 74.04227212071419, 26.31379511207342, 0.5705287575256079, 0.03480828083411325, 0.04476455185795203, 0.05624602912575938, 0.028293714094616007, 0.0384463592490647, 0.06400709782610647, 0.054046466684667394, 0.02466058766003698, 0.0554699244821677, 0.0892684020800516, 0.04525942335021682, 0.021381719852797687, 0.027453953589429148, 0.029825848287146073, 0.05626936967018992, 0.025559248715580907, 0.0411372902453877, 0.012774449733115034, 0.03618228933191858, 0.01582877983310027, 0.11777520718169399, 0.10199299154919572, 0.19788367382716388, 0.17026452929712832, 0.07819747348548844, 0.10801019874634221, 0.1645921907038428, 0.22135299572255462, 0.13763922761427239, 0.10157571159652434, 0.1306317950366065, 0.14470257359789684, 0.32547842245548964, 0.1699915376957506, 0.14320671558380127, 0.25825444841757417, 0.31758482102304697, 0.3219989372882992, 17.296981550753117, 123.21724221110344, 86.22420564293861, 103.80213841795921, 75.16915485262871, 69.11977306008339, 47.44494192302227, 97.81641840934753, 60.26391126215458, 53.14417630434036, 3.660320076160133, 0.20081551338080317, 0.6206072797067463, 1.4093656302429736, 1.4097517845220864, 4.057706315070391, 12.510683331638575, 8.30556582659483, 7.182868095114827, 15.711555574089289, 110.0522330403328, 86.27523690462112, 90.24919286370277, 78.59546139836311, 85.29453232884407, 82.98864126205444, 90.66805198788643, 86.9849856197834, 86.05464354157448, 74.97669517993927, 69.56547394394875, 61.99683867394924, 65.43129578232765, 62.37696647644043, 61.803729236125946, 61.433313712477684, 61.111900359392166, 62.96313062310219, 77.86752685904503, 78.42953190207481, 75.01986846327782, 74.73229229450226, 72.510756701231, 64.3991419672966, 59.720042645931244, 56.34188711643219, 58.78604516386986, 55.66133603453636, 58.02059903740883, 54.83276769518852, 56.129315122962, 55.20322501659393, 55.66644296050072, 54.10425178706646, 55.272841081023216, 56.56914912164211, 59.03423644602299, 62.764184698462486, 61.20898135006428, 57.66951687633991, 56.64663076400757, 54.845914989709854, 58.317347913980484, 69.5224678516388, 70.8482851088047, 68.05576175451279, 67.77279853820801, 65.84287449717522, 71.05822384357452, 64.7743110358715, 50.820395797491074, 71.77329987287521, 69.50048983097076, 73.68139788508415, 71.06132447719574, 66.76763087511063, 57.90524862706661, 56.03686608374119, 53.21848511695862, 53.9656276255846, 53.12175750732422, 57.30263516306877, 56.409078910946846, 55.99941149353981, 55.15326529741287, 56.47680267691612, 53.00552174448967, 55.7522651553154, 54.877977669239044, 57.32557453215122, 62.85990156233311, 68.27029824256897, 65.17323642969131, 67.91413575410843, 69.22778606414795, 74.9886417388916, 74.66983884572983, 70.75219586491585, 72.41168841719627, 70.98243311047554, 60.4988906532526, 60.686577782034874, 57.81448669731617, 55.49916073679924, 64.6407862007618, 77.62652859091759, 78.97458225488663, 76.88800022006035, 73.7784218788147, 77.6526939868927, 80.4382561147213, 73.0335858464241, 77.72693440318108, 83.27877089381218, 73.24910268187523, 89.83893647789955, 63.16666290163994, 11.90244996920228, 2.532901572994888, 5.032127927988768, 6.698516635224223, 4.735962795093656, 2.1448352839797735, 0.695794498315081, 0.1969306671526283, 0.5848588573280722, 22.946847081184387, 46.36313997209072, 57.320972979068756, 70.94760417938232, 33.58374550938606, 45.494631975889206, 48.959863632917404, 66.96807011961937, 69.39015135169029, 87.61711210012436, 27.841613329946995, 0.8936221548356116, 0.23495072935475037, 0.23460770869860426, 0.15387768595246598, 0.2936074248282239, 0.29421272047329694, 0.20722928718896583, 0.18853215296985582, 0.10655840946128592, 0.1270833791932091, 0.16649766970658675, 0.08797115020570345, 0.18597227783175185, 0.15007005276856944, 0.16057547967648134, 0.22671124257612973, 0.09121293289354071, 0.14184536441462114, 0.17669592169113457, 0.12707337504252791, 0.13413318840321153], [0.06996394615271129, 0.07320849705138244, 0.035876509646186605, 0.05723565707739908, 0.07165740098571405, 0.017718707131280098, 0.10217166360234842, 0.02836936491803499, 0.05216697398282122, 0.05988618555420544, 0.07817791047273204, 0.051051826594630256, 0.1054710295284167, 0.04756315734994132, 0.040368577392655425, 0.0485649194160942, 0.24736634048167616, 0.10767813961138017, 43.25357683002949, 89.20899108052254, 79.41421866416931, 62.57854945957661, 48.61589469015598, 25.72123020887375, 64.68359470367432, 109.46246668696404, 63.0309683829546, 25.24538554251194, 0.04409417357237544, 0.2512739261146635, 0.13511053752154112, 0.5181915534194559, 0.2886791783384979, 1.552079322282225, 2.85452866461128, 0.4598755482584238, 0.6709536875132471, 78.39175432920456, 87.90382191538811, 85.37942737340927, 73.08257281780243, 68.84079962968826, 71.59633576869965, 79.20030534267426, 77.32724905014038, 78.34738790988922, 76.93885669112206, 74.05532822012901, 65.69148302078247, 58.09298895299435, 54.2790462076664, 58.222045227885246, 55.79699635505676, 54.898583963513374, 53.266031965613365, 58.69017630815506, 68.32236304879189, 73.74889746308327, 72.46578991413116, 71.55085980892181, 66.50248870253563, 57.92080119252205, 55.44924661517143, 51.46356828510761, 51.69624499976635, 51.0413159430027, 50.12491911649704, 47.998541817069054, 49.71555948257446, 49.63256053626537, 46.918677762150764, 49.351337626576424, 51.63707077503204, 51.654530838131905, 59.28690008819103, 59.04140666127205, 57.00316183269024, 51.15369491279125, 49.72075380384922, 47.887648567557335, 52.896440997719765, 58.47245939075947, 67.57311165332794, 64.95822876691818, 69.19690132141113, 61.05615735054016, 69.17468011379242, 55.90248629450798, 45.09645514190197, 70.14737471938133, 60.019018203020096, 63.80866125226021, 59.77882169187069, 60.06035998463631, 46.82341307401657, 52.28655852377415, 49.259549751877785, 50.96164561808109, 49.04853567481041, 50.71032330393791, 48.12353231012821, 50.3486967086792, 49.89253118634224, 50.69404877722263, 45.11893853545189, 48.17550592124462, 48.88081647455692, 49.3778146058321, 48.15017648041248, 51.303471475839615, 56.90394915640354, 58.20857875049114, 58.81080083549023, 62.23434492945671, 63.98985832929611, 68.6710475385189, 65.93336284160614, 65.03583580255508, 58.92696060240269, 49.67852286994457, 51.6787963360548, 49.94907595217228, 60.24023473262787, 69.91106539964676, 70.29440402984619, 70.72880432009697, 72.0494082570076, 70.18513709306717, 70.74635937809944, 69.96102511882782, 72.9042711853981, 69.28947195410728, 70.65013334155083, 67.42508679628372, 75.93613609671593, 79.02658626437187, 28.545559756457806, 0.3499367303447798, 1.949083919171244, 1.8297084560617805, 0.2541235653916374, 0.6504105648491532, 0.1593008410418406, 0.06279856228502467, 6.848657978698611, 13.308860901743174, 36.344468370079994, 32.24281646311283, 30.69540459662676, 23.6316292360425, 26.853565648198128, 46.55897006392479, 56.13597996532917, 58.76137688755989, 58.78074064850807, 3.4454047959297895, 0.4079201346030459, 0.01876265658211196, 0.11411759915063158, 0.013458059584081639, 0.04815784399397671, 0.039913655709824525, 0.030360135242517572, 0.04193598586425651, 0.03712221936439164, 0.06705138017423451, 0.02748203645751346, 0.03223474275728222, 0.10968193091684952, 0.08551703853299841, 0.0367369556624908, 0.04211443898384459, 0.029613286060339306, 0.05925662539084442, 0.12095761805539951, 0.04988190870790277, 0.028101794705435168, 0.023544061732536647, 0.050296869449084625, 0.04829862940823659, 0.1516967811039649, 0.023938262747833505, 0.0426268585579237, 0.05553716306167189, 0.080942061758833, 0.01641895421926165, 0.017645154730416834, 0.04307488939957693, 0.1045523323409725, 0.05855591552972328, 0.007007583790255012, 0.013090680713503389, 0.11825353620224632, 0.06249319820199162, 55.31268574297428, 99.35880124568939, 86.40306204557419, 72.99520790576935, 59.348437786102295, 38.755176812410355, 55.96678264439106, 82.23536968231201, 62.02361963689327, 26.573049500584602, 0.013831996257067658, 0.06441288933274336, 0.36393066693563014, 1.3076969794929028, 0.9008188499137759, 4.540303219109774, 3.96133778616786, 0.6932318327017128, 0.9861164353787899, 83.83433908224106, 90.52573442459106, 89.06025186181068, 75.86103692650795, 70.8369693160057, 73.56763958930969, 81.65249615907669, 78.89623045921326, 82.63572379946709, 79.12202954292297, 77.7214702963829, 70.34232705831528, 61.85137487947941, 56.849646270275116, 61.058175042271614, 56.98018826544285, 58.058137223124504, 55.21047502756119, 62.24720723927021, 69.61294859647751, 76.81584969162941, 74.79644805192947, 72.06150680780411, 68.43232914805412, 62.19247117638588, 57.76939071714878, 53.97084854543209, 55.4360157251358, 53.64844724535942, 52.870784774422646, 50.09414456784725, 51.782739758491516, 52.12242633104324, 48.36512714624405, 52.49377280473709, 53.24957884848118, 53.67095723748207, 62.79567740857601, 61.532100811600685, 60.12030176818371, 53.93870607018471, 53.13605614006519, 50.02504147589207, 54.39754284918308, 62.17328980565071, 70.96279576420784, 68.5727696120739, 72.39211946725845, 64.30148720741272, 71.68198317289352, 59.896923154592514, 47.81050130724907, 72.1961335837841, 62.9298710078001, 65.93428239226341, 63.48649173974991, 61.40724331140518, 49.52708959579468, 52.79398709535599, 52.04663559794426, 52.471430003643036, 51.5766654163599, 53.302529007196426, 51.08987353742123, 53.645141422748566, 51.05410985648632, 50.87660998106003, 48.36249388754368, 50.83863861858845, 51.65477782487869, 52.5458300113678, 50.38756862282753, 52.82166860997677, 58.74560013413429, 62.35419049859047, 64.12208363413811, 66.59787878394127, 68.59917059540749, 70.33837527036667, 69.39639821648598, 68.46305429935455, 60.87643079459667, 50.60903213918209, 55.257353112101555, 53.49445290863514, 63.51617954671383, 73.3930541574955, 74.52280953526497, 74.72611382603645, 75.06248697638512, 71.20421960949898, 70.67770466208458, 70.4778353869915, 74.63219046592712, 71.7485024034977, 73.71352136135101, 70.72422936558723, 77.2988873720169, 85.1215048134327, 37.75506667792797, 1.2237482029013336, 0.504560200497508, 0.7400012074504048, 0.8672782871872187, 1.0755322873592377, 0.33094825863372535, 0.1878994720755145, 3.598225233145058, 22.661873772740364, 36.55009813606739, 38.20404678583145, 31.098638959228992, 34.67234529554844, 40.46371713280678, 51.54679521918297, 64.28403854370117, 65.82560822367668, 75.42012378573418, 7.343866406008601, 0.48278092697728425, 0.03369307036336977, 0.10033193888375536, 0.05592180707026273, 0.07433056496665813, 0.07619475087267347, 0.045438622328219935, 0.02948776847915724, 0.0355388658499578, 0.06312944882665761, 0.011925272301596124, 0.029603682669403497, 0.0897281922516413, 0.018542478064773604, 0.04693778661021497, 0.10536383371800184, 0.05708719414542429, 0.04698159187682904, 0.07022271820460446, 0.04209080900182016, 0.13361724733840674, 0.1373989795683883, 0.11770641009206884, 0.14027471275767311, 0.2784125745529309, 0.16642862028675154, 0.2835785161005333, 0.082210176915396, 0.18861450167605653, 0.17237717140233144, 0.27106246270705014, 0.15067321102833375, 0.19118021009489894, 0.22798415942816064, 0.16518000134965405, 0.17857233819086105, 0.27769088046625257, 0.11905706691322848, 67.45588034391403, 109.65241849422455, 102.04648062586784, 81.59271776676178, 69.86557424068451, 37.15039372444153, 89.58696439862251, 131.37039631605148, 85.58846175670624, 40.68860046565533, 0.13716361485421658, 0.2823608001926914, 0.5164049367886037, 3.8832738250494003, 0.6979006540495902, 8.746078088879585, 11.323379091918468, 6.341522466391325, 0.6592912820633501, 88.5695917904377, 90.13578414916992, 92.64792054891586, 78.01377341151237, 76.09408602118492, 76.00397005677223, 86.48015230894089, 80.391526222229, 85.84134578704834, 82.20738038420677, 80.2790142595768, 73.5343685746193, 64.80430662631989, 59.11008417606354, 64.59606260061264, 59.98972937464714, 61.3888218998909, 58.52385923266411, 65.85252597928047, 74.18749272823334, 81.09721675515175, 77.68629938364029, 75.40237113833427, 71.68915718793869, 65.07217705249786, 62.887195497751236, 56.91226691007614, 57.95734763145447, 56.088151931762695, 55.06783828139305, 54.50145207345486, 56.09659507870674, 56.85003384947777, 50.31434275209904, 54.0049859136343, 56.06974571943283, 55.44556841254234, 66.0197702050209, 65.33810198307037, 61.88597962260246, 57.092795222997665, 55.886025577783585, 53.09045858681202, 57.623201161623, 66.33914306759834, 74.73154753446579, 73.66945132613182, 74.08631175756454, 67.6339539885521, 74.61187675595284, 63.716706186532974, 51.852549612522125, 75.0413829088211, 66.62975147366524, 69.6590705215931, 65.7536780834198, 65.86517930030823, 51.625169813632965, 57.673206478357315, 55.0447241216898, 55.44814087450504, 54.42674808204174, 56.52232803404331, 52.57368631660938, 55.34981355071068, 54.96025465428829, 53.79505477845669, 51.35394036769867, 54.4569830596447, 55.634068697690964, 55.38802430033684, 53.40193547308445, 57.30865404009819, 61.43869422376156, 65.22211700677872, 66.77921265363693, 68.77788260579109, 71.90298691391945, 74.63728219270706, 71.65259554982185, 70.18458992242813, 64.94062051177025, 54.20203574001789, 57.76114135980606, 56.29459485411644, 67.19331443309784, 76.62448436021805, 76.23859986662865, 75.50907701253891, 78.52457240223885, 75.01432836055756, 73.82562294602394, 72.12623253464699, 77.84243300557137, 76.45008891820908, 77.49315574765205, 74.33902099728584, 81.93774685263634, 86.90571427345276, 33.143805116415024, 0.7530993421096355, 6.650082059204578, 7.016655039042234, 1.299366638995707, 1.7330148071050644, 0.3391171671682969, 0.3135197516530752, 10.376807134598494, 25.07167786359787, 51.20576351881027, 45.30813418328762, 38.05125318467617, 33.96676115691662, 42.74183169007301, 62.0395939797163, 76.19770646095276, 76.86530023813248, 83.03053021430969, 6.685559805482626, 0.5937493708916008, 0.2311415079748258, 0.17795635561924428, 0.14319835900096223, 0.14250108157284558, 0.19344468077179044, 0.13697116111870855, 0.11610461791860871, 0.10081292479299009, 0.23239778587594628, 0.10069231095258147, 0.17597829457372427, 0.2792430674890056, 0.1398384486674331, 0.1029868089244701, 0.23128812666982412, 0.1584204164100811, 0.21391839778516442, 0.267188748694025, 0.136034392635338], [0.02117162526701577, 0.05048128943599295, 0.01935110176418675, 0.03163023378874641, 0.014893906609358964, 0.032672435481799766, 0.08379246544791386, 0.00833736956337816, 0.0406166810716968, 0.059668335525202565, 0.049899189616553485, 0.018717218590609264, 0.03617012182075996, 0.044212416250957176, 0.052385722010512836, 0.12637878418900073, 0.15856146899750456, 9.31789230555296, 89.6269990503788, 75.19851207733154, 81.04507595300674, 64.39230233430862, 44.74060423672199, 20.76060399413109, 49.06985253095627, 65.23467153310776, 41.80732123553753, 2.312461626715958, 0.06244672491448, 0.04743961202620994, 0.2181235104217194, 1.2440559756942093, 1.1799893947318196, 2.926481841132045, 2.513597896322608, 1.113927683327347, 37.05786868929863, 99.2431278526783, 78.94122004508972, 80.94416096806526, 69.5975898206234, 64.5432074368, 70.91200768947601, 76.25239312648773, 78.90202134847641, 76.7570972442627, 77.35498756170273, 72.03453585505486, 67.1500651538372, 59.628262370824814, 54.863838627934456, 54.1209252923727, 54.11263033747673, 50.94313681125641, 53.45774307847023, 56.429753601551056, 64.13530692458153, 68.13896968960762, 70.53949847817421, 69.0258876979351, 67.53998503088951, 63.05932626128197, 57.125097289681435, 49.75704945623875, 51.27062223851681, 50.3234888613224, 48.56729529798031, 46.931008100509644, 50.67802883684635, 48.74426320195198, 50.512855499982834, 48.314453065395355, 54.77111220359802, 61.20638608932495, 64.4808679819107, 64.407889097929, 61.47372454404831, 51.61583751440048, 49.02327463030815, 48.66563782095909, 50.414721965789795, 60.02619221806526, 65.5046546459198, 63.26386548578739, 66.4143942296505, 59.58021394908428, 68.26605767011642, 48.830130994319916, 43.0040518194437, 69.4509556889534, 56.08692839741707, 60.17231337726116, 54.93189677596092, 54.481195360422134, 46.94689504802227, 51.43137641251087, 54.13613587617874, 55.528115183115005, 53.37491512298584, 54.33140739798546, 52.77107052505016, 50.32199554145336, 48.69156002998352, 50.757034197449684, 46.82601973414421, 45.78837901353836, 44.79568228125572, 48.62853281199932, 47.662506848573685, 47.974181324243546, 48.28959099948406, 54.05827045440674, 52.643636763095856, 58.985629454255104, 61.88833549618721, 66.66238412261009, 67.7491258084774, 67.7396111190319, 55.96881553530693, 48.57028193771839, 50.935047045350075, 53.33193942904472, 61.831315755844116, 66.13564878702164, 67.39461243152618, 70.7246321439743, 70.0315873324871, 68.59059065580368, 69.48553383350372, 71.15568101406097, 70.5046771466732, 67.6850688457489, 68.03677797317505, 69.3197563290596, 68.52584213018417, 70.34370258450508, 83.83596539497375, 40.670281648635864, 0.8441270201001316, 1.320684920065105, 0.8328916761092842, 0.38190833351109177, 0.4780983313685283, 0.0689458976557944, 3.4879323514178395, 24.758513867855072, 30.195611715316772, 33.91711302101612, 27.159266844391823, 16.586801558732986, 15.176667775958776, 34.42019462585449, 54.43509243428707, 59.52817194163799, 68.37103083729744, 31.44588142633438, 0.6809965486172587, 0.038340777609846555, 0.06820716385846026, 0.021244077433948405, 0.08717657721717842, 0.06442880840040743, 0.03803379193414003, 0.02575760994659504, 0.023174616908363532, 0.025748034386197105, 0.06378480233252048, 0.027245673554716632, 0.021562494039244484, 0.06483164615929127, 0.01924683187098708, 0.020804017258342355, 0.006281004516495159, 0.036378735821926966, 0.034792487931554206, 0.025958934202208184, 0.014076999614189845, 0.04673507639381569, 0.014077676823944785, 0.02755207293375861, 0.05960213595244568, 0.07774583951686509, 0.056464190856786445, 0.04881090055278037, 0.057945710577769205, 0.012692053714999929, 0.04963567895174492, 0.12146751061663963, 0.05278459670080338, 0.05526636821741704, 0.05852461174072232, 0.04741368880786467, 0.1554091670550406, 12.516818102449179, 106.92679435014725, 82.46151074767113, 93.69886815547943, 68.78517061471939, 56.84584267437458, 31.468400917947292, 44.330317452549934, 69.55468252301216, 46.354902014136314, 3.6283483542501926, 0.021535346277232748, 0.11384474113583565, 0.8564802166074514, 1.3830051384866238, 3.67808198556304, 4.919818304479122, 1.491541089490056, 0.45092676125932485, 41.07105374336243, 103.63152757287025, 83.00045862793922, 84.6930930018425, 73.68245422840118, 68.70367258787155, 74.80714067816734, 80.44118955731392, 80.85551172494888, 81.5547502040863, 79.35785248875618, 76.32762908935547, 70.3106215596199, 63.86591657996178, 59.13508303463459, 56.57383047044277, 56.90210245549679, 55.645088106393814, 56.65134631097317, 59.98967617750168, 68.50930541753769, 72.44817405939102, 71.90262213349342, 71.92827835679054, 69.32496964931488, 65.16502127051353, 59.666191935539246, 52.35179342329502, 52.65813298523426, 52.227456495165825, 50.939823389053345, 50.435423254966736, 53.64196099340916, 51.205653324723244, 53.35562735795975, 50.22559091448784, 58.56634855270386, 64.19396817684174, 67.71215379238129, 67.79441937804222, 63.30406732857227, 54.600151777267456, 50.03120854496956, 51.33615732192993, 51.393245458602905, 62.37149477005005, 67.04536557197571, 65.10560005903244, 68.5638476908207, 63.34188289940357, 70.70428043603897, 48.51614624261856, 44.75279778242111, 71.11088901758194, 58.81276533007622, 62.79042609035969, 58.686460107564926, 55.95759093761444, 50.335659608244896, 54.39911596477032, 56.65674202144146, 58.68210934102535, 55.96161872148514, 58.62188257277012, 55.10531187057495, 52.70070590078831, 51.64352662861347, 52.950284108519554, 48.73737797141075, 47.69266963005066, 46.8668257445097, 51.14888057112694, 50.717117339372635, 49.97330725193024, 49.50869858264923, 55.57643719017506, 55.55077716708183, 63.1059193611145, 64.32077497243881, 70.12996405363083, 69.19883161783218, 70.71417510509491, 58.718556985259056, 52.48979441821575, 53.7720812112093, 53.80540922284126, 63.787245601415634, 69.98091325163841, 70.15122011303902, 73.48655954003334, 71.66852429509163, 70.21036013960838, 72.97272071242332, 73.58836367726326, 72.92333096265793, 72.34380885958672, 68.89810055494308, 73.8434287905693, 72.34575435519218, 71.78779989480972, 84.93746548891068, 50.95805861055851, 1.7676731036044657, 0.35258349613286555, 1.520695856306702, 1.1327475984580815, 0.9211183700244874, 0.040955241420306265, 0.2800016908440739, 22.670708298683167, 41.24115161597729, 32.64606222510338, 29.397941417992115, 21.678505539894104, 27.73530263453722, 42.845284938812256, 61.66087970137596, 66.58053651452065, 74.8384889960289, 44.333695471286774, 1.0129817062988877, 0.09894265327602625, 0.04655174365325365, 0.024555887321184855, 0.08217969691031612, 0.040599953063065186, 0.06557524102390744, 0.02004257188673364, 0.00672956738526409, 0.02624929020385025, 0.01881925647467142, 0.059169437881791964, 0.06708088796585798, 0.06186758626427036, 0.09324638042016886, 0.020763343854923733, 0.05002662008337211, 0.03515278578561265, 0.03418060943658929, 0.05821194121381268, 0.12623535672901198, 0.15668521577026695, 0.0906765901891049, 0.09935070091160014, 0.12752939510392025, 0.12509568507084623, 0.13777895917883143, 0.17660226265434176, 0.1512995094526559, 0.1443208276759833, 0.16166979126865044, 0.17913242219947278, 0.16517643904080614, 0.15174862754065543, 0.13640082062920555, 0.22652938670944422, 0.24568000284489244, 15.106860771775246, 120.95770865678787, 94.26053121685982, 102.9282309114933, 80.81366837024689, 63.769340962171555, 30.971651673316956, 66.60717308521271, 79.05880853533745, 62.88164399564266, 4.487384408712387, 0.2766041684662923, 0.14153591851936653, 2.2208031825721264, 3.118121945299208, 6.9191213976591825, 12.266747821122408, 8.365181777626276, 3.6559797590598464, 42.65963450074196, 105.91791808605194, 84.3487174808979, 87.43062570691109, 77.989781498909, 72.56817162036896, 78.27815562486649, 84.46432247757912, 84.92344424128532, 83.44803661108017, 84.61081981658936, 79.27109554409981, 75.00300496816635, 65.1683346927166, 62.82204419374466, 58.68908956646919, 60.24696037173271, 57.505236491560936, 59.249342903494835, 63.53383719921112, 70.50825655460358, 75.50338491797447, 75.8073154091835, 75.00061109662056, 71.99749544262886, 68.4341910481453, 63.70141580700874, 55.32455250620842, 56.26213699579239, 55.32303638756275, 52.87673905491829, 53.26578877866268, 57.60314963757992, 54.03295621275902, 57.400943487882614, 54.30073544383049, 60.5688600987196, 68.33870217204094, 71.22607603669167, 70.4160127043724, 67.29753524065018, 56.52374915778637, 53.22538174688816, 53.843270391225815, 54.5788349211216, 64.8561130464077, 71.69747114181519, 67.80458763241768, 70.73624432086945, 67.12422654032707, 73.59135791659355, 53.6098413169384, 49.35168340802193, 72.5955605506897, 62.257424890995026, 66.34717583656311, 60.95050401985645, 59.21786539256573, 52.65451937913895, 56.39808610081673, 61.03063032031059, 61.50242060422897, 58.501201048493385, 59.39909666776657, 58.336069509387016, 57.828770130872726, 56.57120481133461, 54.86084058880806, 52.35274717211723, 51.1091461032629, 50.77648155391216, 52.97109179198742, 53.613850101828575, 51.2779026478529, 52.67687737941742, 58.998639956116676, 59.30493772029877, 64.99567955732346, 68.78490462899208, 73.67721050977707, 74.90025848150253, 72.37970933318138, 61.35811194777489, 55.53123481571674, 59.62385840713978, 57.82773278653622, 67.91358858346939, 71.88129767775536, 73.16579595208168, 78.31239178776741, 75.79416811466217, 74.58084762096405, 76.4415317773819, 78.51865991950035, 78.03233921527863, 72.90148973464966, 72.73103848099709, 76.66133478283882, 76.28656849265099, 74.39537197351456, 89.77893009781837, 46.80005572736263, 1.352980574592948, 6.5145547315478325, 6.2456198874861, 1.2634088122285903, 1.545240639243275, 0.18718750012340024, 6.333683962002397, 34.344187304377556, 49.316128715872765, 46.72437898814678, 36.72202371060848, 25.20616214722395, 26.877948939800262, 50.02288319170475, 71.81708112359047, 76.35971456766129, 86.97962030768394, 48.475606217980385, 1.1985915340483189, 0.2153197507141158, 0.13433583924779668, 0.12102905719075352, 0.25126932479906827, 0.10832688058144413, 0.15380445081973448, 0.16277643735520542, 0.09007730594021268, 0.15172988089034334, 0.12190945213660598, 0.12098363775294274, 0.13269658345961943, 0.15237387211527675, 0.1821135255158879, 0.10658452563802712, 0.07935151312267408, 0.23277151660295203, 0.16353914252249524, 0.16878216352779418], [0.040624050598125905, 0.05547249973460566, 0.039097018670872785, 0.025182428798871115, 0.047121186144067906, 0.05756270300480537, 0.0272949243299081, 0.04609278839780018, 0.06728667067363858, 0.05037197108322289, 0.09839384249062277, 0.03603806035243906, 0.03501142520690337, 0.11272471412667073, 0.02268169726448832, 0.3066416457295418, 0.09704518204671331, 30.213191471993923, 90.78777596354485, 70.85284486413002, 72.20953926444054, 46.30441032350063, 21.73682291060686, 31.657140590250492, 42.38705612719059, 29.71403505653143, 27.78895005583763, 1.017734301276505, 0.048764156381366774, 0.048314674641005695, 1.3229570793919265, 0.35603457188699394, 2.603910737670958, 3.7507110508158803, 1.1694228742271662, 6.946019679307938, 83.7926097214222, 84.99492600560188, 81.09831869602203, 74.29771721363068, 66.02173089981079, 60.12477792799473, 62.29826129972935, 66.1567984521389, 71.4257401227951, 70.75864031910896, 72.60882943868637, 68.50167542695999, 62.758215218782425, 55.177295207977295, 55.02350226044655, 53.95333908498287, 54.89729583263397, 51.5645706653595, 53.52192923426628, 54.68447305262089, 62.82733350992203, 67.43898645043373, 69.13583099842072, 69.25325989723206, 72.26736456155777, 64.31911826133728, 54.592818170785904, 51.49921417236328, 51.633951142430305, 49.829226583242416, 48.80595289170742, 45.77550150454044, 49.272704645991325, 48.63742433488369, 49.25047963857651, 55.98427690565586, 61.35569907724857, 63.66598270833492, 68.09828907251358, 64.35472995042801, 57.28074073791504, 49.879243299365044, 49.37941811978817, 47.622289806604385, 48.70728738605976, 60.09586147964001, 63.64037208259106, 59.992605820298195, 63.70632514357567, 60.86489841341972, 64.95720282196999, 46.182224079966545, 43.29950496554375, 68.58522534370422, 52.47822783887386, 54.74753066897392, 50.26147998869419, 52.837213575839996, 51.01382441818714, 57.05007791519165, 54.77561116218567, 57.47165769338608, 58.96076738834381, 57.00978487730026, 54.50810171663761, 52.43755482137203, 48.61308664083481, 48.522290512919426, 47.02946461737156, 45.350748896598816, 43.64408567547798, 46.648706048727036, 46.46880850195885, 48.53206738829613, 45.742735862731934, 47.12084211409092, 48.28240938484669, 51.48427337408066, 56.827307268977165, 64.23127457499504, 63.80553022027016, 65.82216560840607, 55.796278193593025, 47.761867716908455, 46.7843321710825, 52.71139092743397, 59.35680873692036, 64.34301897883415, 65.80834195017815, 69.74939167499542, 66.81029498577118, 71.60132110118866, 67.77411326766014, 68.06308776140213, 64.40559402108192, 64.02943700551987, 57.239805534482, 59.28099900484085, 62.680429592728615, 73.26788887381554, 67.1500651538372, 84.21960800886154, 37.78554864227772, 0.5760238564107567, 1.2165384460240602, 0.7773974351584911, 0.5028041603509337, 0.4451909096678719, 0.2020622621057555, 10.701699201017618, 36.30573704838753, 27.64935504645109, 46.393549740314484, 41.0834676772356, 23.67062084376812, 29.085220098495483, 46.47774942219257, 53.40306021273136, 55.56968875229359, 52.88594976067543, 8.775710798799992, 0.4632367054000497, 0.06032649063854478, 0.0467607027530903, 0.06417148353648372, 0.09527839560178109, 0.07046385682770051, 0.01759198356012348, 0.05332210086635314, 0.08213081906433217, 0.040968588946270756, 0.05470964242704213, 0.050628334865905344, 0.038067414934630506, 0.008284531431854703, 0.026284412342647556, 0.06255411368329078, 0.041077688365476206, 0.06836537490016781, 0.0650153796595987, 0.02460060171870282, 0.057777120600803755, 0.10383391854702495, 0.054414931873907335, 0.016889566759346053, 0.030290069080365356, 0.012524269895948237, 0.047381397962453775, 0.03799825790338218, 0.009728615368658211, 0.06359032253385521, 0.09491034972597845, 0.035236414696555585, 0.10910068827797659, 0.05518197860510554, 0.27893341379240155, 0.10032980149844661, 40.386881455779076, 102.13847368955612, 77.57479816675186, 83.24476271867752, 58.512433245778084, 32.267431542277336, 30.67058052867651, 37.69308440387249, 36.55546724796295, 33.978711515665054, 0.9932320285588503, 0.08689047186635435, 0.21700374316424131, 1.068490433972329, 1.6806848463602364, 7.9388251807540655, 9.040792174637318, 1.019895791541785, 9.503699485212564, 88.04275766015053, 88.56877863407135, 86.04572162032127, 76.98587536811829, 68.67442935705185, 63.22102278470993, 64.74430024623871, 70.24721816182137, 75.26139110326767, 74.31740775704384, 75.9988859295845, 72.88795486092567, 64.0533073246479, 58.1156737357378, 58.095044642686844, 56.951021030545235, 55.94133920967579, 52.15709567070007, 54.66489650309086, 57.711117044091225, 63.694864958524704, 70.37224665284157, 72.38489225506783, 72.40934774279594, 72.78577074408531, 68.24772745370865, 59.13677394390106, 54.29758921265602, 54.37382452189922, 53.177869096398354, 51.38590805232525, 48.579416647553444, 51.996862068772316, 52.52469554543495, 52.932748049497604, 58.14786180853844, 64.85925927758217, 67.0726253092289, 68.00678238272667, 65.9789527952671, 60.66912531852722, 52.72926516830921, 52.22363010048866, 49.6247785538435, 50.85446856915951, 61.730153784155846, 68.28093007206917, 64.54418018460274, 65.70048853754997, 63.106975704431534, 65.56841522455215, 47.89622850716114, 47.7794835716486, 72.18997791409492, 55.624166429042816, 57.145000621676445, 52.989285215735435, 55.65405562520027, 53.349836468696594, 57.91159428656101, 58.1119005382061, 60.124124363064766, 62.8902543336153, 59.83209103345871, 55.354175716638565, 55.00652477145195, 51.39156214892864, 51.31952561438084, 48.92935886979103, 47.485550343990326, 46.53816618025303, 50.191879123449326, 48.40964175760746, 51.12402990460396, 48.67140211164951, 49.490976333618164, 50.484661012887955, 52.76192061603069, 58.876202926039696, 68.57436552643776, 67.03951388597488, 68.00213903188705, 59.00494761765003, 50.07987253367901, 51.21714390814304, 54.625883996486664, 64.01305988430977, 66.56783759593964, 69.87633526325226, 71.00459352135658, 70.40350377559662, 73.56811836361885, 70.5590446293354, 70.98185554146767, 66.69108778238297, 68.72683614492416, 59.048778265714645, 61.66093289852142, 65.14242008328438, 76.2094022333622, 69.27895411849022, 85.05398243665695, 47.165102139115334, 0.8808497933205217, 0.7688393443822861, 1.582764694467187, 1.2940677045844495, 0.8800799190066755, 0.3957858419744298, 6.652637422084808, 46.40323542058468, 33.20176340639591, 42.29962281882763, 31.3179973885417, 28.95944494754076, 41.2338750064373, 53.57108719646931, 60.71985639631748, 63.31490054726601, 66.37103855609894, 15.106055215001106, 0.5009463569149375, 0.094586216728203, 0.029420913961075712, 0.039115023173508234, 0.09115543129155412, 0.012517725081124809, 0.04013422571006231, 0.06968434201553464, 0.046656854028697126, 0.053815335922990926, 0.020783029322046787, 0.020437425991985947, 0.012765902974933852, 0.07872298083384521, 0.012823491779272445, 0.012831086733058328, 0.03585941427445505, 0.017593868615222163, 0.011379873540136032, 0.08239804417826235, 0.19619292783318087, 0.14968192437663674, 0.11273030249867588, 0.09858074496150948, 0.089558374020271, 0.18706488248426467, 0.16209768393309787, 0.1761442091083154, 0.11692170024616644, 0.306896380498074, 0.10500250427867286, 0.20669672201620415, 0.22135869541671127, 0.125771603488829, 0.42083590873517096, 0.37454854405950755, 49.47936035692692, 112.33600929379463, 86.47998511791229, 94.01279971003532, 66.72011822462082, 34.831993728876114, 44.15364593267441, 60.675824359059334, 47.082163989543915, 43.678268641233444, 2.236807686276734, 0.19243452872615308, 0.3022276778938249, 3.0506978882476687, 3.0367599986493587, 8.038558904081583, 8.386530932039022, 7.81189726665616, 9.301203601062298, 94.71849024295807, 89.63927239179611, 89.17990744113922, 79.454595297575, 73.21781516075134, 67.31202766299248, 68.34077686071396, 73.10267373919487, 78.63447770476341, 76.20771512389183, 78.39005962014198, 76.02325022220612, 69.3008941411972, 61.30258932709694, 61.408052667975426, 61.435707584023476, 58.26439395546913, 54.26959231495857, 58.08082200586796, 61.131777092814445, 68.24320569634438, 74.21650797128677, 76.71538308262825, 75.77928051352501, 76.87473893165588, 71.04210510849953, 61.56905762851238, 56.46647483110428, 57.52636715769768, 56.33485749363899, 55.08116036653519, 50.5362356454134, 55.12776866555214, 55.65230771899223, 55.35968542098999, 61.2790571898222, 70.21836251020432, 68.946053981781, 72.45044633746147, 69.24176931381226, 65.38404151797295, 57.11388789117336, 56.38525038957596, 52.19499483704567, 55.03821887075901, 67.26076081395149, 69.58543047308922, 67.28689581155777, 68.02647292613983, 65.92494249343872, 68.31202760338783, 50.41273847222328, 52.15554155409336, 75.07957085967064, 58.157163709402084, 60.08242540061474, 57.787272557616234, 57.79549911618233, 58.019994869828224, 62.410655468702316, 59.7807177901268, 64.1065576672554, 66.42445608973503, 64.48565572500229, 59.38726410269737, 57.20750726759434, 54.739908277988434, 55.22886984050274, 53.018106669187546, 50.60943491756916, 50.31725339591503, 52.53764905035496, 50.779741778969765, 52.452708408236504, 51.27890199422836, 51.57757356762886, 52.846371084451675, 56.013102158904076, 63.10194477438927, 72.94521018862724, 69.34176474809647, 70.33718213438988, 62.04606883227825, 52.5727591663599, 52.02434599399567, 58.93679827451706, 66.59848675131798, 68.43473061919212, 72.89996981620789, 75.70586085319519, 73.51460203528404, 77.81572803854942, 73.51798385381699, 75.33323004841805, 69.83102649450302, 72.5189034640789, 64.38322082161903, 65.83370178937912, 69.92491945624352, 81.76911950111389, 71.96735545992851, 89.64148387312889, 45.913624092936516, 0.7638763950672001, 6.071238219738007, 5.4405005648732185, 2.386509203352034, 1.401138596702367, 0.5112120404373854, 15.882217716425657, 55.5765587836504, 43.68982382118702, 62.57920302450657, 54.70509074628353, 32.113266214728355, 42.49574549496174, 63.253697231411934, 71.2313349545002, 74.7788017988205, 79.54338133335114, 15.8023127540946, 0.8087589335627854, 0.20421483175596222, 0.2964299311861396, 0.14507888699881732, 0.2288605913054198, 0.13396377093158662, 0.0930033196345903, 0.23789702594513074, 0.1875673609902151, 0.14169105706969276, 0.14409230556339025, 0.12110012525226921, 0.10341726199840195, 0.12133113355957903, 0.11898311189725064, 0.12899034249130636, 0.154420314647723, 0.13926086481660604, 0.12998940685065463], [0.05406320211477578, 0.006560529800481163, 0.065585074480623, 0.04808267185580917, 0.02132588066160679, 0.022844760096631944, 0.05362140160286799, 0.020924749842379242, 0.015971390930644702, 0.0824197668407578, 0.057380064172321, 0.04667274341045413, 0.1264049077872187, 0.03762600405025296, 0.03587206418160349, 0.03953006555093452, 1.1035500839352608, 65.0163884460926, 82.69271314144135, 73.26680973172188, 58.193755745887756, 29.36775393784046, 18.029361851513386, 57.310819923877716, 47.950212210416794, 39.8143395781517, 7.7971987053751945, 0.6500229856465012, 0.10497495575691573, 0.19857885839883238, 0.4093738237861544, 0.7692409353330731, 4.836847856640816, 4.058216437697411, 0.3259895247174427, 41.33887097239494, 92.47674733400345, 76.7519523203373, 79.71764758229256, 66.4920012652874, 63.667065650224686, 59.87434096634388, 58.808338567614555, 56.473914831876755, 58.8129211217165, 61.5424020588398, 63.1492218375206, 60.117159336805344, 59.28114339709282, 51.70482873916626, 52.70403452217579, 52.44373708963394, 52.80043914914131, 51.91149964928627, 52.958655059337616, 50.95991291105747, 58.590450659394264, 66.41206115484238, 67.57982969284058, 66.43267124891281, 70.38433760404587, 66.45628318190575, 57.8548139333725, 49.52738218009472, 50.70541776716709, 50.40365315973759, 48.56258735060692, 48.73131349682808, 51.49625413119793, 54.91711176931858, 60.972542837262154, 62.52114214003086, 63.08395653963089, 63.970198184251785, 67.28416755795479, 59.429833218455315, 54.573234021663666, 47.910253554582596, 46.81663043797016, 48.08097459375858, 48.5674624890089, 52.90486894547939, 65.9022881090641, 63.21587786078453, 65.26065453886986, 60.21083950996399, 68.76610323786736, 50.71222700178623, 46.467394977808, 68.17096397280693, 52.548144087195396, 51.173514649271965, 51.33863478899002, 57.22383879125118, 56.89440406858921, 55.45448653399944, 59.81254868209362, 58.0241784453392, 54.10641007125378, 51.51571288704872, 52.48463809490204, 50.35839378833771, 48.39284285902977, 47.30015829205513, 48.145289942622185, 47.20594994723797, 43.782508447766304, 42.5953533500433, 45.630041509866714, 46.56208209693432, 48.11404801905155, 47.557058706879616, 49.030505642294884, 48.91559600830078, 51.8328020721674, 59.358264058828354, 61.26899532973766, 60.70880278944969, 52.04858489334583, 48.527074456214905, 50.747549906373024, 49.80407573282719, 58.181945979595184, 60.97409315407276, 62.077800929546356, 64.31574404239655, 66.626286059618, 64.30229276418686, 65.01723200082779, 59.77804273366928, 57.52225577831268, 54.35412257909775, 55.47149822115898, 53.9668245613575, 56.30041994154453, 56.99276179075241, 70.19362583756447, 69.36542227864265, 77.87797629833221, 18.717751912772655, 0.2614988212008029, 1.70589150628075, 0.16774450748926029, 0.17817396816099063, 0.14226323808543384, 0.8162245829589665, 40.01291312277317, 39.37396600842476, 40.408635288476944, 59.034886211156845, 21.768839992582798, 21.490592323243618, 33.684736490249634, 49.197955057024956, 55.71198731660843, 54.926599860191345, 42.70480267703533, 1.3345235399901867, 0.2009200819884427, 0.016721459178370424, 0.03667398443212733, 0.0484360677364748, 0.07788024988258258, 0.06921680382220075, 0.029476413619704545, 0.027918853447772563, 0.04879317064478528, 0.021339237464417238, 0.04813258128706366, 0.05531656708626542, 0.0342281031771563, 0.031199758450384252, 0.0239301417968818, 0.023644941866223235, 0.08154729803209193, 0.032218727210420184, 0.04844262461119797, 0.02497064953786321, 0.047147510122158565, 0.050801767356460914, 0.032935734634520486, 0.03778292375500314, 0.09236090918420814, 0.030289698006527033, 0.06634031364228576, 0.05964759249764029, 0.01629459067771677, 0.017102891542890575, 0.030458185938186944, 0.01447566279239254, 0.06627534603467211, 0.0649384486314375, 1.9345071888528764, 80.82354784011841, 92.417531311512, 82.86313399672508, 65.74388980865479, 42.78067700564861, 29.831346161663532, 42.80702859163284, 39.20647859573364, 48.37274193763733, 9.279084037989378, 0.3912512899842113, 0.3714202134869993, 1.112496703863144, 1.976755578070879, 2.482671355828643, 3.291898970492184, 1.8348720227368176, 0.16758065612521023, 43.81838232278824, 95.253866314888, 81.2628498673439, 83.94869774580002, 68.5968679189682, 66.60295531153679, 62.797334119677544, 62.903925999999046, 59.45358954370022, 62.92860567569733, 65.0060074031353, 66.04610279202461, 63.05048033595085, 62.21609450876713, 56.01302996277809, 54.89471577107906, 54.548064172267914, 55.218671187758446, 55.35961702466011, 55.2033694088459, 53.9564511179924, 60.512030348181725, 69.7943964600563, 70.65549105405807, 69.15059700608253, 73.60561475157738, 71.7563071846962, 60.68201802670956, 51.79154388606548, 53.107192888855934, 51.18809446692467, 50.689489021897316, 50.77087685465813, 53.928260430693626, 57.69060954451561, 64.75505366921425, 64.55570116639137, 66.43770977854729, 66.61203682422638, 68.91845986247063, 62.61041074991226, 57.73470617830753, 50.75831852853298, 48.879874125123024, 50.863409489393234, 50.17797186970711, 56.714346930384636, 67.88850992918015, 64.12906005978584, 68.54540348052979, 61.66534446179867, 70.75551688671112, 52.71377719938755, 48.867106810212135, 71.44521787762642, 56.82550996541977, 53.154709339141846, 54.57662343978882, 58.46952214837074, 59.48372572660446, 59.953236132860184, 60.52381731569767, 59.2906428873539, 55.90281307697296, 55.55548131465912, 55.904986560344696, 53.205147832632065, 52.58821673691273, 49.383924677968025, 49.88266311585903, 48.52334305644035, 48.095493614673615, 46.55664838850498, 49.44489240646362, 49.2585352063179, 48.89184348285198, 47.241276651620865, 50.73216833174229, 51.37030228972435, 55.10658100247383, 61.31219521164894, 64.38418596982956, 65.1185117661953, 54.91185285151005, 51.12928122282028, 53.41076239943504, 54.41551588475704, 61.91612720489502, 62.84048080444336, 63.74006353318691, 66.40654385089874, 68.74884456396103, 68.24955895543098, 66.87463313341141, 62.375024780631065, 59.38369229435921, 56.44573174417019, 58.69262337684631, 57.58695490658283, 59.012471213936806, 59.00424465537071, 73.61970439553261, 70.61533480882645, 81.71361207962036, 24.28857408463955, 0.22337306232657284, 0.9580102341715246, 0.6621469475794584, 0.4079379461472854, 0.16370300872949883, 0.7283057319000363, 38.62460821866989, 48.5678006708622, 38.43686409294605, 47.33099743723869, 21.44666288048029, 33.71899925172329, 41.724010705947876, 57.98880614340305, 63.93619000911713, 66.27741158008575, 60.202544555068016, 3.897559870965779, 0.3287460986757651, 0.017416699411114678, 0.0830555053835269, 0.009539914117340231, 0.0863192779070232, 0.05524418913410045, 0.01686047085968312, 0.08192650580895133, 0.04861807574343402, 0.03192205367668066, 0.116329414449865, 0.02091808164550457, 0.014277885074989172, 0.015098435087566031, 0.0244519235639018, 0.07972281702677719, 0.03486997928121127, 0.0418019354401622, 0.12456441123504192, 0.11170489931828342, 0.14451703667873517, 0.18516320327762514, 0.10604958559270017, 0.12869734258856624, 0.13982129021314904, 0.1052723491739016, 0.26988508994691074, 0.1882422700873576, 0.12389077121042646, 0.0955107100890018, 0.23350232426309958, 0.16094018588773906, 0.1733308014809154, 0.2580543654039502, 3.062001094222069, 94.87873524427414, 101.60986125469208, 94.49321553111076, 76.10391989350319, 48.16618502140045, 28.710820488631725, 82.53376767039299, 68.82344216108322, 61.62610396742821, 13.326070178300142, 0.8072631794493645, 0.44325497292447835, 1.795611698180437, 4.364876132458448, 4.728759806603193, 13.408795539289713, 12.072202060371637, 1.6541171469725668, 49.23754133284092, 95.11411741375923, 85.0467324256897, 85.05975812673569, 72.40288808941841, 67.91306421160698, 66.62760838866234, 66.42293617129326, 63.3394206315279, 65.86450293660164, 68.12478125095367, 70.66815957427025, 66.77932664752007, 65.55269166827202, 59.097449854016304, 57.44469054043293, 57.80939497053623, 58.326353430747986, 58.66761311888695, 57.587866857647896, 56.66999191045761, 63.19138437509537, 72.7301873266697, 73.23109924793243, 72.39727959036827, 75.44016391038895, 73.69055539369583, 62.979686334729195, 54.04919274151325, 56.33803032338619, 55.49514055252075, 52.88053125143051, 52.905849292874336, 58.17494675517082, 59.19099323451519, 67.39069104194641, 69.00897860527039, 67.43023931980133, 68.79384934902191, 72.98575401306152, 64.81050029397011, 60.78273542225361, 53.24303939938545, 52.44512781500816, 55.34763626754284, 52.8230669349432, 58.23094815015793, 72.12540417909622, 67.8275839984417, 71.18639096617699, 66.04607239365578, 72.3674663901329, 55.64478412270546, 53.61149042844772, 74.01382684707642, 60.720031186938286, 56.16712309420109, 57.781595662236214, 62.402238920331, 63.02112691104412, 60.614092871546745, 66.14708617329597, 65.41510105133057, 58.694287687540054, 57.35838957130909, 58.12762789428234, 57.205223590135574, 54.79019857943058, 52.594338208436966, 53.70910719037056, 51.99567273259163, 50.563689172267914, 50.32943934202194, 52.04363375902176, 50.59006355702877, 52.10975781083107, 53.38899716734886, 54.09293979406357, 53.796536698937416, 56.9719997048378, 64.06946405768394, 66.41032084822655, 67.07095339894295, 56.5524148195982, 54.94617260992527, 55.309953689575195, 55.42396657168865, 64.48874115943909, 66.05526030063629, 67.08267197012901, 71.05527520179749, 71.81749150156975, 72.63819426298141, 71.60335019230843, 65.82284957170486, 63.57658110558987, 60.020389929413795, 62.290490716695786, 61.0031121969223, 61.41627922654152, 63.429703786969185, 76.72011762857437, 75.59407845139503, 85.37155419588089, 23.947397992014885, 1.386170368641615, 8.924913592636585, 1.6378780058585107, 0.6506086292210966, 0.35849499923642725, 2.6418569264933467, 51.312184408307076, 56.3375249505043, 57.18201823532581, 78.19120869040489, 31.515163108706474, 31.67437456548214, 48.17556671798229, 66.00130319595337, 73.050646930933, 75.98351195454597, 68.07068735361099, 3.639637310989201, 0.34459739341400564, 0.17238598811673, 0.17875487683340907, 0.1648451591609046, 0.18346228986047208, 0.18163501837989315, 0.15724326629424468, 0.13098814466502517, 0.17636042641242966, 0.12127096764743328, 0.14371372119057924, 0.1362025336129591, 0.1244224161200691, 0.2690169552806765, 0.10444500294397585, 0.18385356495855376, 0.222838849585969, 0.10100795378093608], [0.052209866407793015, 0.04830677447898779, 0.027616849438345525, 0.09811144787818193, 0.0573559629265219, 0.03658844820165541, 0.10394158933195285, 0.02981875149998814, 0.07074536828440614, 0.04261798989318777, 0.07342809112742543, 0.0547794748126762, 0.08156658645020798, 0.04289787604648154, 0.06570282363099977, 0.17372311558574438, 19.383732676506042, 83.99683356285095, 69.97810140252113, 69.39848810434341, 62.27161332964897, 25.922735296189785, 23.0235630646348, 47.91912227869034, 41.31355293095112, 26.961196772754192, 1.8084292416460812, 0.09692981519037858, 0.046685716151841916, 0.7239643461070955, 0.5260815925430506, 1.4329883689060807, 10.027105249464512, 10.271691475063562, 2.917355205863714, 85.94904720783234, 82.58067235350609, 84.0885378420353, 72.13877186179161, 64.5895953476429, 59.4416543841362, 61.334906592965126, 57.469073832035065, 58.66451248526573, 52.23899267613888, 52.41846464574337, 51.895810291171074, 54.635824263095856, 52.20986723899841, 51.795909851789474, 49.90625225007534, 53.863637298345566, 51.0177344083786, 52.00177140533924, 49.77026894688606, 52.58066274225712, 53.43638822436333, 64.65232238173485, 68.28612819314003, 68.4159292280674, 68.02015006542206, 66.61031931638718, 55.707834139466286, 49.16410647332668, 47.78980381786823, 50.17521321773529, 47.441506907343864, 53.21389876306057, 60.575897321105, 62.25059665739536, 61.73994205892086, 63.56542490422726, 66.20245680212975, 63.401148319244385, 60.366038382053375, 55.11742182075977, 47.06374257802963, 47.2634294629097, 48.04594807326794, 47.21393331885338, 46.57972075045109, 49.06877338886261, 60.36989897489548, 57.89180114865303, 61.34818308055401, 57.775371596217155, 66.55094370245934, 54.2092477530241, 48.93763102591038, 67.06399217247963, 51.8813406676054, 51.08295410871506, 55.78292950987816, 55.65151356160641, 51.95389777421951, 55.928070321679115, 53.278430700302124, 56.05315200984478, 52.39465892314911, 51.785490810871124, 50.660196393728256, 51.35720819234848, 47.17731848359108, 44.98077794909477, 44.85795333981514, 45.22903002798557, 43.38451400399208, 44.4843839854002, 43.499640226364136, 44.33996133506298, 46.864363476634026, 46.82405523955822, 49.07824628055096, 46.67463965713978, 50.64268313348293, 54.90530200302601, 58.07835973799229, 56.297790482640266, 50.60327164828777, 47.513771429657936, 51.28244340419769, 49.92698773741722, 56.236674562096596, 61.990865394473076, 58.99622328579426, 59.94983151555061, 60.15671141445637, 60.18161527812481, 57.285102903842926, 52.948767989873886, 51.21114782989025, 51.93448081612587, 58.69049549102783, 57.35252648591995, 65.51882788538933, 62.9931528121233, 65.33711403608322, 65.22017911076546, 77.5673657655716, 49.42610241472721, 1.5012673800811172, 1.125320065766573, 0.8110915927682072, 0.4172338207717985, 0.29441728605888784, 0.06394539566827007, 11.761940158903599, 64.55704629421234, 35.3560958057642, 45.39602726697922, 33.35009604692459, 19.31515395641327, 28.505247719585896, 57.28502690792084, 67.27795869112015, 62.96481393277645, 62.88620375096798, 31.511536203324795, 1.134577200282365, 0.15675150440074503, 0.11792643461376429, 0.05233924872300122, 0.029000711801927537, 0.02341631585295545, 0.013480174657161115, 0.014603353938582586, 0.03605223166232463, 0.05926372032263316, 0.019066924141952768, 0.012493475405790377, 0.04556839427095838, 0.029761734149360564, 0.05309550462698098, 0.019176361238351092, 0.10598835098790005, 0.021286917908582836, 0.019990044529549778, 0.026671475752664264, 0.048808406936586834, 0.04856994746660348, 0.058768830276676454, 0.024375339489779435, 0.10077229962917045, 0.01311055913902237, 0.08767272520344704, 0.007531296532761189, 0.0760434269614052, 0.04307549796067178, 0.09381298790685833, 0.010357500177633483, 0.22037619579350576, 0.15256559854606166, 26.38393934816122, 97.65381753444672, 77.30049088597298, 80.3361327946186, 70.61863303184509, 41.575385481119156, 28.939509317278862, 48.22706535458565, 46.463849768042564, 36.59051276743412, 2.447333252057433, 0.03317966744361911, 0.871652327477932, 1.8031617742963135, 2.1583770448341966, 2.2652907203882933, 5.034833382815123, 2.8361725620925426, 4.643258219584823, 89.30368959903717, 86.34093537926674, 87.33333572745323, 75.18130660057068, 68.23077276349068, 62.10555464029312, 63.45052666962147, 59.75042201578617, 61.41428053379059, 56.861102655529976, 54.81789529323578, 55.02729445695877, 57.89893716573715, 56.56757980585098, 55.495493933558464, 51.72875985503197, 54.851652681827545, 54.378087893128395, 55.54490268230438, 52.905583307147026, 55.38124546408653, 55.93536972999573, 67.06124871969223, 72.02824339270592, 71.3806289434433, 71.24251395463943, 69.48639258742332, 58.172925263643265, 51.45413339138031, 51.540609151124954, 52.35270157456398, 50.4473964124918, 54.312290623784065, 63.644023686647415, 65.28810426592827, 67.16568991541862, 67.01242133975029, 69.02188271284103, 65.96670985221863, 63.24639402329922, 58.07727299630642, 52.56760664284229, 49.67886485159397, 50.91093733906746, 50.03809757530689, 48.91668654978275, 52.07558624446392, 63.673643097281456, 61.75519064068794, 65.23344039916992, 60.07416844367981, 68.8153637945652, 56.650426760315895, 52.34359726309776, 68.65459442138672, 54.28609862923622, 53.060896173119545, 57.163634821772575, 58.782465755939484, 56.1342016607523, 59.00425225496292, 56.028495132923126, 58.33051420748234, 55.98672777414322, 54.81091886758804, 51.16760216653347, 53.42072166502476, 48.674476146698, 48.10801014304161, 48.630542904138565, 48.02727967500687, 45.910595655441284, 45.38713574409485, 46.2527596950531, 46.7645276337862, 49.11291562020779, 49.613569155335426, 51.22298039495945, 49.45819929242134, 54.29355762898922, 56.64636857807636, 60.80451965332031, 58.660845682024956, 53.96762251853943, 48.5843525826931, 53.77488926053047, 52.12584234774113, 58.57836350798607, 63.39587800204754, 60.80301493406296, 63.34642745554447, 63.256870061159134, 63.388293609023094, 59.617003574967384, 56.04558661580086, 53.31912271678448, 54.94379013776779, 61.56577840447426, 61.00851930677891, 66.77084550261497, 66.87002018094063, 68.72363671660423, 70.28860554099083, 81.25240802764893, 55.1093814522028, 2.0787967275828123, 1.6011935868300498, 2.1584026934579015, 1.6994048980996013, 0.2785284980200231, 0.07764228765154257, 9.550982248038054, 69.98659014701843, 35.98925583064556, 40.177877470850945, 24.759915992617607, 24.773008190095425, 45.931570529937744, 64.47791934013367, 76.01125046610832, 69.83613342046738, 70.44023260474205, 46.51889741420746, 1.6780778300017118, 0.14878692396450788, 0.10985354514559731, 0.027494319001561962, 0.14244133868487552, 0.0414615234330995, 0.01332363437541062, 0.03129740653093904, 0.03571810193534475, 0.026081830146722496, 0.060182402667123824, 0.039801331658964045, 0.044120564343756996, 0.030568033071176615, 0.07411781349219382, 0.01914974782266654, 0.02068420493742451, 0.00939235196710797, 0.11401703814044595, 0.11876966280397028, 0.11846006847918034, 0.15925016719847918, 0.2644984039943665, 0.13762157934252173, 0.23672526382142678, 0.08890971468645148, 0.24582579033449292, 0.14454614371061325, 0.1841612148564309, 0.17431824380764738, 0.18839706724975258, 0.20538456039503217, 0.3267372236587107, 0.4024698317516595, 32.931149527430534, 109.69346389174461, 89.50305730104446, 89.70410451292992, 81.72353714704514, 40.01610495150089, 35.20556688308716, 68.62330690026283, 61.92892871797085, 46.613839119672775, 3.6217371840029955, 0.15981234406353906, 1.4273637207224965, 2.7681937348097563, 3.8276832830160856, 4.953983696177602, 23.154650330543518, 20.15406534075737, 3.6896528396755457, 93.89467164874077, 89.81219351291656, 92.26805493235588, 75.30715584754944, 71.68261393904686, 66.22818142175674, 68.85265499353409, 61.76533229649067, 66.96330517530441, 58.41821350157261, 59.15631249547005, 59.592814072966576, 60.34820593893528, 58.34731310606003, 57.45185695588589, 54.09583903849125, 59.507223665714264, 57.92206272482872, 58.92678961157799, 54.809805527329445, 58.06315295398235, 59.360623732209206, 70.00859096646309, 73.75042498111725, 73.07924419641495, 73.1971138715744, 73.06294307112694, 59.10433888435364, 54.62127484381199, 54.79542329907417, 55.660971254110336, 51.26376360654831, 57.741249427199364, 66.0955685377121, 68.56152981519699, 69.87996026873589, 68.01907852292061, 70.82151174545288, 69.75215032696724, 67.05609619617462, 61.809824109077454, 53.77373792231083, 52.583455592393875, 54.32653985917568, 53.669091537594795, 51.89504273235798, 55.495512932538986, 66.52401834726334, 63.06504875421524, 68.36417600512505, 64.61853459477425, 72.62706845998764, 58.706249445676804, 56.067477241158485, 72.24994629621506, 57.4773345887661, 55.55224388837814, 62.049956023693085, 61.489843279123306, 58.26424956321716, 62.88195177912712, 58.42167891561985, 62.83624783158302, 58.781531006097794, 57.59725235402584, 55.77968828380108, 57.22003899514675, 51.78490564227104, 50.683709532022476, 51.6211724281311, 51.880975887179375, 48.50457966327667, 49.258504807949066, 50.33680334687233, 48.681615963578224, 51.50710254907608, 51.32869832217693, 54.57577608525753, 51.3301270455122, 57.4802490323782, 59.332436844706535, 63.78675922751427, 62.51806430518627, 55.793481543660164, 50.51175735890865, 57.081183046102524, 55.77727161347866, 61.487183421850204, 68.0380243062973, 63.310036808252335, 65.8639557659626, 66.97188511490822, 66.6900922358036, 62.69996054470539, 57.76474356651306, 57.776211351156235, 56.636242121458054, 65.07626563310623, 62.74911470711231, 71.2796151638031, 69.43171352148056, 71.31898105144501, 72.79583260416985, 84.0974673628807, 57.123398780822754, 2.3307146597653627, 4.31142820045352, 5.240709660574794, 1.979688664432615, 0.42051654774695635, 0.16471606999402866, 14.400018900632858, 79.85374867916107, 48.84996972978115, 62.63141602277756, 46.67347311973572, 26.405134610831738, 45.598784387111664, 72.30506613850594, 87.06693962216377, 78.47751572728157, 83.68032574653625, 48.121803402900696, 1.9849761994555593, 0.2992141724098474, 0.3003437805455178, 0.13894733710912988, 0.20727987197460607, 0.15765778545755893, 0.09582752551068552, 0.07815520075382665, 0.17431511194445193, 0.19078918732702732, 0.2878757886355743, 0.1509439168148674, 0.13935939234215766, 0.09228744398569688, 0.11763511938625015, 0.1292431031470187, 0.17264082678593695, 0.13648639025632292], [0.06779261500923894, 0.022116013751656283, 0.05509373724635225, 0.060284355204203166, 0.0613385351607576, 0.061917684943182394, 0.06605825299629942, 0.02120432058291044, 0.05572834772465285, 0.10022458722232841, 0.09621299701393582, 0.006661382567472174, 0.03232452036172617, 0.027029085176764056, 0.05631998414173722, 0.2712379954755306, 54.26156334578991, 80.57926654815674, 70.37289261817932, 52.715084329247475, 31.037961915135384, 24.280184134840965, 55.226627960801125, 45.1192045211792, 31.10491242259741, 19.32407207787037, 0.4630492388969287, 0.10198672040132806, 0.34847279952373356, 0.6992461974732578, 0.9840587864164263, 1.8364229332655668, 0.9098216355778277, 0.7747929717879742, 37.957675606012344, 97.96615317463875, 75.61414137482643, 78.46089541912079, 64.2675094306469, 62.40299127995968, 58.02581235766411, 60.745782405138016, 54.816675558686256, 54.48591850697994, 53.89234855771065, 55.8239521086216, 52.28696510195732, 52.04432152211666, 52.3157599568367, 52.56794862449169, 51.200808584690094, 52.078135907649994, 51.71087421476841, 51.55281029641628, 50.54837219417095, 51.51314042508602, 52.89215102791786, 63.02553087472916, 69.23036992549896, 68.11041802167892, 68.22862967848778, 64.59606260061264, 53.71412672102451, 47.33240716159344, 48.47861185669899, 46.366126611828804, 52.7354284375906, 61.82308919727802, 62.9523354023695, 63.29058565199375, 66.02489992976189, 64.70950931310654, 62.21559673547745, 61.57258003950119, 55.809714272618294, 52.0819129049778, 45.89764215052128, 47.074978575110435, 46.067196652293205, 45.82106865942478, 46.42652057111263, 45.975724160671234, 55.44643476605415, 60.34935727715492, 59.39411133527756, 58.34164761006832, 63.81799355149269, 57.11528621613979, 51.41116909682751, 64.09388914704323, 49.629570096731186, 52.28234454989433, 53.02586205303669, 55.9257410466671, 54.953217431902885, 56.270519345998764, 52.08245627582073, 50.22754780948162, 47.685153633356094, 45.55836595594883, 44.92149353027344, 45.02368524670601, 45.128050446510315, 45.805345103144646, 44.63837452232838, 48.17935511469841, 44.730701968073845, 45.76273798942566, 43.7163046002388, 43.76594893634319, 45.04043094813824, 47.657886296510696, 46.28396362066269, 49.17020134627819, 46.642455384135246, 50.829530507326126, 53.02800513803959, 52.43721283972263, 48.0372579395771, 50.54573893547058, 50.60592010617256, 49.51824367046356, 53.13445262610912, 60.963009148836136, 62.2989946603775, 61.465026810765266, 58.546931594610214, 54.68166880309582, 50.49210101366043, 54.46991376578808, 51.06688857078552, 56.922963336110115, 61.59790188074112, 70.07032245397568, 62.963780388236046, 69.4036178290844, 67.48444721102715, 73.4424439072609, 68.71104419231415, 72.26478070020676, 6.976518267765641, 0.2847745316103101, 0.5402269866317511, 0.5450730922166258, 0.1144513652252499, 0.044797978189308196, 0.1506892265751958, 43.599403873085976, 54.385839477181435, 34.71387326717377, 62.19261176884174, 34.2836831510067, 12.866225503385067, 39.588171914219856, 58.6485343426466, 55.80034777522087, 55.01467153429985, 62.63566039502621, 11.473340895026922, 1.1709690350107849, 0.19876677019055933, 0.14703627181006595, 0.03699655149830505, 0.017319003090960905, 0.05801925370178651, 0.04895323334494606, 0.027787229846580885, 0.016889125181478448, 0.08078485261648893, 0.02206003169703763, 0.029140300503058825, 0.015453310625161976, 0.03942509618354961, 0.020163486296951305, 0.02858069146896014, 0.019258771171735134, 0.04868756303039845, 0.02889331561163999, 0.012715986122202594, 0.02806364089337876, 0.009403233707416803, 0.01390430092214956, 0.07615563969011419, 0.03659910544229206, 0.08902319648768753, 0.04014242273115087, 0.04915055927995127, 0.05565851904975716, 0.04455950387637131, 0.03150082549836952, 0.13225537666585296, 0.2235214176471345, 67.81199723482132, 92.34282732009888, 76.00725308060646, 60.47614507377148, 43.52697215974331, 27.71467164158821, 34.67785879969597, 38.48928987979889, 40.9604112803936, 27.64641210436821, 0.24274411116493866, 0.16901892347959802, 1.1407732428051531, 1.6586899640969932, 2.6844141678884625, 3.5851653339341283, 0.305734058492817, 0.3762404032750055, 40.95233291387558, 100.13510718941689, 78.6160258948803, 81.60805374383926, 69.03186097741127, 67.65141785144806, 62.73953162133694, 63.8216869533062, 57.85534590482712, 58.90005424618721, 57.162776067852974, 60.305918008089066, 55.37091001868248, 56.54463283717632, 54.83701206743717, 54.87528741359711, 53.96179363131523, 55.72204917669296, 54.03527028858662, 55.1100730150938, 52.89305157959461, 53.121343329548836, 56.649792194366455, 67.63650745153427, 71.44359916448593, 72.0979468524456, 70.31742319464684, 67.89509877562523, 56.04455307126045, 49.656658843159676, 52.505232989788055, 48.836210668087006, 54.2462045699358, 67.44743719696999, 67.54672586917877, 66.21510252356529, 68.03563803434372, 66.82196035981178, 65.71726083755493, 65.18924117088318, 58.36704924702644, 54.132735058665276, 48.888416066765785, 50.07305949926376, 48.199391439557076, 48.47075007855892, 49.06742826104164, 50.316493436694145, 56.81683123111725, 63.089466243982315, 60.485405176877975, 60.597886741161346, 65.2881270647049, 59.05649185180664, 53.74161444604397, 68.09926182031631, 52.33377479016781, 56.057890355587006, 57.13750742375851, 58.98615762591362, 57.2021609544754, 57.44297303259373, 54.600159376859665, 51.94802328944206, 48.90838019549847, 49.23391632735729, 48.4246851503849, 48.45648564398289, 47.650845274329185, 49.121617153286934, 47.14419946074486, 49.23481687903404, 48.13572585582733, 48.81446823477745, 45.28855003416538, 45.87798960506916, 46.547236293554306, 50.23252934217453, 49.910090044140816, 52.71186210215092, 50.078592002391815, 55.4025699198246, 55.50872102379799, 56.284901574254036, 50.60206711292267, 53.91958549618721, 50.91215707361698, 52.03502342104912, 55.26781015098095, 64.91970643401146, 63.73029425740242, 66.0955685377121, 60.30369132757187, 56.51607736945152, 53.23611617088318, 58.0812019854784, 53.63708585500717, 61.722273007035255, 64.5004977285862, 73.75905051827431, 67.51727744936943, 71.79871290922165, 70.68136006593704, 75.78979834914207, 71.2618701159954, 76.86733692884445, 8.845868334174156, 0.8703969104681164, 1.7758430214598775, 1.7827231460250914, 0.5109120346605778, 0.1076026631926652, 0.09451227655517869, 44.301815181970596, 61.99651949107647, 35.65658748149872, 41.56451806426048, 29.550723619759083, 21.937638334929943, 49.448479413986206, 63.54200296103954, 64.41985085606575, 61.136792823672295, 71.63035914301872, 18.881264738738537, 1.2929899874143302, 0.11280077684205025, 0.10100287749082781, 0.014789576416660566, 0.06010938646795694, 0.06672684641671367, 0.009214880337822251, 0.049878465142683126, 0.025229605271306355, 0.023334147117566317, 0.03340005190693773, 0.10506610633456148, 0.04011952747532632, 0.050111169257434085, 0.04706323925347533, 0.030030315538169816, 0.03926167897589039, 0.18988223833730444, 0.08285263931611553, 0.1900192684843205, 0.14721529267262667, 0.07307108098757453, 0.18765851156786084, 0.16433588258223608, 0.16569604631513357, 0.21018977364292368, 0.20865896047325805, 0.1850164806819521, 0.11907643696758896, 0.19400583347305655, 0.2616246894467622, 0.25577552674803883, 0.47631967056076974, 78.88652577996254, 100.35038083791733, 89.16134163737297, 70.32898977398872, 45.44051147997379, 33.378491923213005, 74.61754605174065, 65.84393084049225, 47.84925542771816, 34.66195285320282, 1.0378117114305496, 0.21768542064819485, 2.213537972420454, 2.8371027996763587, 5.157240489497781, 7.414992889389396, 6.9724491611123085, 2.367559620179236, 43.221194967627525, 101.59121185541153, 81.92053377628326, 83.98019805550575, 69.13257837295532, 70.43397054076195, 64.89482536911964, 68.31794008612633, 62.1393196284771, 60.72737239301205, 60.12874111533165, 63.18053595721722, 57.55041226744652, 58.86893771588802, 59.733619317412376, 58.82802911102772, 55.51434092223644, 58.34336891770363, 58.091427236795425, 57.97461770474911, 56.34868495166302, 56.07998996973038, 58.79562444984913, 70.81581205129623, 73.9436674118042, 73.11354875564575, 73.75191450119019, 73.0023743212223, 60.320752412080765, 51.13202087581158, 54.51154053211212, 50.48174276947975, 57.872631177306175, 69.69956874847412, 69.80332598090172, 68.79891067743301, 71.62757769227028, 69.67946782708168, 68.53631436824799, 68.73264983296394, 61.27921678125858, 56.27928927540779, 53.042467162013054, 53.027761951088905, 51.05799324810505, 51.58394202589989, 53.18269483745098, 52.74652384221554, 59.89603780210018, 65.88263556361198, 63.26040767133236, 64.58593994379044, 67.69860371947289, 62.19799987971783, 58.87748345732689, 71.16482332348824, 55.470498874783516, 58.47510404884815, 59.25052843987942, 60.85318364202976, 58.950420543551445, 60.73356606066227, 57.56304278969765, 57.273243740200996, 51.816550344228745, 50.419524908065796, 49.706686958670616, 50.51834620535374, 50.89105300605297, 52.6562786847353, 49.9684739112854, 52.60550580918789, 51.40698552131653, 52.62582331895828, 49.72371004521847, 49.15688306093216, 49.400123208761215, 53.02083872258663, 52.964844927191734, 55.344330444931984, 51.90260052680969, 56.02540209889412, 59.344664588570595, 59.632936120033264, 53.05171586573124, 56.62728600203991, 55.68291887640953, 55.41919022798538, 58.675338104367256, 66.9614964723587, 67.30458006262779, 67.74137422442436, 63.69390740990639, 60.3125486522913, 56.25787742435932, 59.93596225976944, 57.21462808549404, 64.73632827401161, 68.35078552365303, 77.02725514769554, 70.2366091310978, 76.07577100396156, 76.00629553198814, 79.45166185498238, 75.808424949646, 81.53463408350945, 9.2247574031353, 1.4979027793742716, 4.279798222705722, 2.9450284084305167, 0.37365793716162443, 0.18148218048736453, 0.35632142680697143, 54.71708670258522, 69.32446047663689, 52.54148304462433, 85.0764088332653, 48.80974888801575, 22.847725600004196, 54.46229137480259, 71.82347998023033, 75.68522796034813, 70.89159518480301, 81.84658974409103, 18.813474476337433, 1.2045956868678331, 0.35839130636304617, 0.19616039207903668, 0.1709155857679434, 0.1662724872585386, 0.19240905821789056, 0.12289190723095089, 0.12154109455877915, 0.20260644931113347, 0.17890574061311781, 0.18045120377792045, 0.25748196174390614, 0.22506597539177164, 0.11420561786508188, 0.12613835802767426, 0.0899280006706249, 0.09301049620262347], [0.03718212552485056, 0.06775662084692158, 0.02975440729642287, 0.060735362058039755, 0.03227697096008342, 0.04715025977930054, 0.043419772846391425, 0.06805661920225248, 0.05959579430054873, 0.06377344747306779, 0.07633514294866472, 0.014329796449601417, 0.0521582797227893, 0.06555788218975067, 0.14027774072019383, 8.88102974742651, 78.4852597117424, 70.58417648077011, 71.2411992251873, 47.69940286874771, 22.21669726073742, 28.411708138883114, 57.51313626766205, 43.81454072892666, 47.08940640091896, 15.506246890872717, 0.03352029096276965, 0.3657063888385892, 0.5679315968882293, 0.824288462754339, 1.9552243896760046, 1.1374992434866726, 2.565547046251595, 7.053483612835407, 90.99129304289818, 77.56181806325912, 80.90161845088005, 70.31376779079437, 64.36393305659294, 59.83610361814499, 59.30909089744091, 58.67316462099552, 53.82651329040527, 53.14334034919739, 50.95612071454525, 53.453973680734634, 52.64027774333954, 51.94773070514202, 53.36216680705547, 51.99531175196171, 53.75447675585747, 50.461413860321045, 51.69857047498226, 50.54637350142002, 49.656795635819435, 51.427014246582985, 56.64246618747711, 61.322420462965965, 68.23337942361832, 66.35563418269157, 69.27958488464355, 57.81350255012512, 51.20917573571205, 49.01882126927376, 49.1503170132637, 46.51917099952698, 59.97270628809929, 63.996979147195816, 63.61644096672535, 62.6522047072649, 57.49965839087963, 58.149317130446434, 62.65703424811363, 59.47974354028702, 55.47421507537365, 48.701458498835564, 49.679879397153854, 45.96701502799988, 52.18151316046715, 53.42364750802517, 52.7422034740448, 46.49532347917557, 49.928766041994095, 52.9990278929472, 56.86492145061493, 54.35559689998627, 60.71484066545963, 55.64038395881653, 50.95129117369652, 63.322017565369606, 52.50455282628536, 52.13056169450283, 55.56584715843201, 56.221091598272324, 51.948711052536964, 52.26754054427147, 46.03264130651951, 45.842123329639435, 46.71723537147045, 46.758083179593086, 45.7464786618948, 46.06973111629486, 44.5584724098444, 45.88053546845913, 43.88193391263485, 43.9469750225544, 45.53833343088627, 44.90376368165016, 42.963819578289986, 43.51185657083988, 43.62723357975483, 43.93285118043423, 47.152095437049866, 48.24179336428642, 48.91142003238201, 48.87271910905838, 49.56098757684231, 51.56965099275112, 48.65714147686958, 51.351903676986694, 50.22603549063206, 49.36534367501736, 53.0945585668087, 62.49571390450001, 62.76448108255863, 62.27748781442642, 59.625484719872475, 56.07128843665123, 51.44964583218098, 54.286873787641525, 55.09313352406025, 59.70044329762459, 63.063551634550095, 68.85561883449554, 67.84402951598167, 71.23692065477371, 67.89500758051872, 74.42872658371925, 70.42317152023315, 69.16095525026321, 14.735985472798347, 0.6801131553947926, 0.6966492743231356, 1.502589590381831, 0.34604882646817714, 0.08785283702309243, 0.0664643784693908, 7.21578192897141, 75.05360305309296, 32.60328412055969, 39.093605652451515, 47.237530052661896, 25.645124092698097, 22.015509456396103, 42.38835945725441, 52.54665456712246, 56.12925812602043, 53.44981290400028, 50.696579441428185, 4.393463423475623, 0.08997873388580047, 0.012382532677293057, 0.022881496406625956, 0.04332442542363424, 0.07947534788399935, 0.024745090449869167, 0.0483589808573015, 0.057078971149167046, 0.024102767201839015, 0.0547218210704159, 0.03998087202489842, 0.060302634301478975, 0.05550544366997201, 0.03978349042881746, 0.08435076830210164, 0.07941285162814893, 0.05206511792493984, 0.08855965847033076, 0.039466148082283325, 0.08813225562334992, 0.024489546740369406, 0.09456069426960312, 0.0726618904445786, 0.07909703810582869, 0.0015762828184051614, 0.12106249836506322, 0.04236406777636148, 0.044344615016598254, 0.016498191471328028, 0.1349586941068992, 0.19739869516342878, 12.479278016835451, 93.12191471457481, 77.19019040465355, 80.54567635059357, 57.335009425878525, 30.09124841541052, 33.50666664540768, 57.404579892754555, 37.94979102909565, 53.44730883836746, 13.713046163320541, 0.08578443434089422, 0.016315469147230033, 1.7838784027844667, 2.218865524046123, 4.981626262888312, 2.7481645345687866, 1.908841347321868, 8.463073074817657, 93.99744853377342, 81.0277108848095, 84.00869652628899, 71.8078476190567, 69.36482951045036, 62.089496701955795, 62.87569351494312, 61.09090268611908, 57.60272026062012, 56.81298203766346, 54.891029968857765, 55.95226362347603, 55.33281706273556, 55.56623853743076, 56.43503151834011, 54.91586163640022, 55.71978069841862, 52.51740373671055, 55.46913854777813, 51.814209669828415, 53.47927652299404, 53.901908844709396, 58.47896084189415, 62.864685505628586, 71.12460628151894, 70.24243801832199, 72.7174200117588, 61.53038330376148, 53.85367043316364, 50.68315476179123, 52.30008579790592, 50.273909121751785, 62.80005857348442, 68.05677250027657, 66.23000532388687, 63.62173408269882, 60.50588607788086, 60.505855679512024, 66.06103599071503, 62.49323643743992, 58.541041910648346, 50.483220890164375, 50.53607225418091, 48.55963110923767, 54.644218012690544, 56.40435956418514, 55.110734179615974, 48.947962671518326, 53.06070998311043, 56.27789095044136, 58.187546879053116, 57.110099494457245, 65.31012028455734, 56.46170988678932, 53.69945950806141, 68.09934541583061, 54.86419200897217, 53.82519096136093, 59.89899404346943, 60.403082594275475, 54.99246172606945, 55.4787178337574, 49.94469478726387, 48.77116575837135, 48.375713378190994, 50.22124394774437, 48.051339983940125, 47.7994628995657, 47.51697085797787, 47.91140489280224, 47.937779277563095, 46.34533032774925, 48.063533529639244, 47.950907573103905, 47.06408455967903, 44.47491109371185, 47.58854001760483, 47.010397240519524, 48.96582931280136, 50.99708631634712, 50.464525893330574, 51.68804123997688, 51.39498956501484, 52.501493990421295, 51.1209786683321, 52.22766548395157, 52.24101796746254, 51.47211402654648, 56.50809399783611, 65.92815712094307, 66.72775581479073, 63.58566641807556, 60.80920860171318, 58.83210629224777, 52.8509346395731, 57.46595039963722, 58.38669799268246, 63.12511973083019, 67.86718547344208, 70.00318005681038, 71.9510467350483, 72.91844442486763, 69.54736411571503, 77.15834811329842, 73.84586066007614, 72.03227877616882, 17.23157186061144, 0.6041089806240052, 1.0373980086296797, 2.8224405739456415, 2.1807773178443313, 0.39981508045457304, 0.05802827450679615, 6.187422210350633, 79.08593147993088, 43.17965179681778, 40.2524408698082, 39.60579916834831, 29.415880255401134, 35.26033714413643, 54.52027626335621, 61.349585205316544, 65.34589916467667, 59.66278351843357, 67.83749386668205, 7.979994546622038, 0.2800453291274607, 0.022342882730299607, 0.030981335112301167, 0.037992476572981104, 0.05163362584426068, 0.004315455153118819, 0.06502456744783558, 0.09744826471433043, 0.04018764178908896, 0.09495770616922528, 0.038705936531187035, 0.01880840256490046, 0.0331609245040454, 0.07681468166993, 0.03430499338719528, 0.041677466142573394, 0.1223375006520655, 0.14345727948239073, 0.14386277412995696, 0.2611495368182659, 0.2018382225651294, 0.13597080542240292, 0.15401764016132802, 0.200938027119264, 0.10580747475614771, 0.2499667665688321, 0.2259977417998016, 0.20512690156465396, 0.20458842889638618, 0.34558358893264085, 0.5317465541884303, 15.920391418039799, 105.35687059164047, 88.47207382321358, 90.43181866407394, 65.111915320158, 35.91040626168251, 44.704023599624634, 82.82638236880302, 64.41900730133057, 69.81360822916031, 20.872112810611725, 0.2740471134893596, 0.9555277205072343, 4.424045607447624, 3.580583967268467, 5.9424954280257225, 7.2328325640410185, 7.848873557522893, 8.632334992289543, 99.01841551065445, 82.4549750983715, 88.25773492455482, 74.29086238145828, 72.56092920899391, 64.1573229432106, 65.3845202922821, 64.29648667573929, 61.47706836462021, 59.820304065942764, 57.807434275746346, 59.57374669611454, 59.48622599244118, 59.25528198480606, 60.12985445559025, 57.604810148477554, 59.77996923029423, 55.55668964982033, 58.249844536185265, 54.00218166410923, 57.20148079097271, 56.03089280426502, 62.5545309484005, 66.76911279559135, 75.0915402173996, 74.02698174118996, 76.72685846686363, 65.32484829425812, 55.41388191282749, 53.186205849051476, 55.109389051795006, 53.771591037511826, 66.00591614842415, 72.15888038277626, 68.29385697841644, 66.0015919804573, 63.14391732215881, 64.10549372434616, 68.8581570982933, 67.25436195731163, 60.68060830235481, 54.98263165354729, 53.93966741859913, 51.36873297393322, 57.38164432346821, 59.9860055744648, 59.057172015309334, 51.99519395828247, 54.609343484044075, 60.9027785807848, 60.86087062954903, 61.372311785817146, 66.22071102261543, 61.396337896585464, 57.687828093767166, 70.77784448862076, 59.51752871274948, 56.71764515340328, 63.0362007021904, 62.91353948414326, 58.86854253709316, 59.012984186410904, 53.854118809103966, 51.93085961043835, 52.64957584440708, 52.16742731630802, 50.82647927105427, 49.301602095365524, 49.180255606770515, 50.16315646469593, 50.76118357479572, 49.009918347001076, 51.27446763217449, 50.07038064301014, 48.379212990403175, 48.092218190431595, 49.684245362877846, 49.80358175933361, 51.996371895074844, 54.32799518108368, 53.035110756754875, 54.297019243240356, 54.67626549303532, 56.17892146110535, 55.70672079920769, 55.6984106451273, 54.9576061964035, 54.290886372327805, 60.69530211389065, 69.54788088798523, 69.28894758224487, 67.30337172746658, 63.93528565764427, 62.71040238440037, 55.92481009662151, 61.044678166508675, 60.53117372095585, 66.43925249576569, 71.05686351656914, 73.14391672611237, 73.43302801251411, 77.89255231618881, 73.12256947159767, 80.75016617774963, 76.59127414226532, 74.26226511597633, 19.142265133559704, 1.9026113441213965, 4.1384771559387445, 5.2978899423033, 2.2587291849777102, 0.48543820157647133, 0.18147380906157196, 10.616987496614456, 88.36461558938026, 47.947297766804695, 57.747013717889786, 62.36723519861698, 40.14541581273079, 35.33973008394241, 58.014507964253426, 68.46745446324348, 73.97250026464462, 69.71512511372566, 75.27524515986443, 7.571275653317571, 0.42200485069770366, 0.10594189254334196, 0.16203393344767392, 0.14072230202145875, 0.16039553855080158, 0.1218405734107364, 0.11860785976750776, 0.16797773481812328, 0.102674550289521, 0.19570864678826183, 0.10018624045187607, 0.13900762918638065, 0.15634476294508204, 0.20710815384518355, 0.2067717383033596, 0.10540168324951082], [0.028682065130851697, 0.04291365039534867, 0.02830185359925963, 0.0370245601516217, 0.06216734713234473, 0.19764535536523908, 0.0525871965510305, 0.05108177967485972, 0.01379480074319872, 0.04456599766854197, 0.028331849352980498, 0.06810872539062984, 0.034714762805378996, 0.14701776264701039, 0.22965051844948903, 32.0712024718523, 90.76674789190292, 63.99843826889992, 68.07015538215637, 38.32183286547661, 23.685202561318874, 28.560985028743744, 45.18226973712444, 34.1939851641655, 53.54443922638893, 5.438595442101359, 0.0713876006193459, 0.09829285103478469, 1.4826651220209897, 1.3859227881766856, 2.502727867104113, 1.2999391020275652, 0.842601164476946, 44.91578243672848, 90.86897760629654, 76.92648455500603, 73.7058837711811, 60.42662613093853, 64.28546726703644, 60.69323502480984, 62.47814364731312, 59.23760913312435, 56.30076192319393, 53.27305018901825, 54.212963953614235, 53.073245510458946, 50.03571130335331, 51.166792809963226, 52.757197469472885, 52.108990252017975, 50.78141748905182, 50.92430882155895, 51.812435165047646, 52.35175162553787, 51.0707301646471, 50.22007741034031, 55.54533965885639, 60.486613512039185, 64.40301015973091, 65.42051196098328, 59.47526358067989, 48.900567814707756, 48.31396669149399, 49.780270010232925, 48.38584363460541, 47.509895637631416, 62.55353920161724, 65.4002058506012, 64.08456444740295, 57.11852744221687, 61.84654913842678, 62.77593366801739, 64.3521536886692, 58.20333123207092, 55.42586646974087, 50.26357747614384, 47.083433121442795, 53.14325675368309, 63.03921394050121, 61.625742986798286, 57.892629504203796, 48.63866686820984, 44.88354116678238, 45.028894767165184, 50.96418008208275, 53.22660908102989, 63.77663657069206, 54.797285199165344, 53.005088567733765, 64.84051868319511, 49.1711550951004, 52.659740298986435, 54.02516283094883, 52.01294660568237, 48.95132549107075, 46.62399597465992, 44.92109075188637, 46.52959384024143, 48.54342877864838, 52.204714715480804, 48.3830089867115, 43.946116268634796, 43.7363675236702, 45.869512259960175, 44.904907420277596, 45.60978479683399, 44.41956326365471, 45.40841080248356, 44.8786736279726, 44.78092387318611, 44.130045399069786, 46.120139211416245, 43.971738293766975, 48.942711353302, 48.72381649911404, 48.93202632665634, 47.7772568911314, 46.82092420756817, 49.00913178920746, 49.410603046417236, 49.398819878697395, 49.97890815138817, 51.24002248048782, 63.99988979101181, 63.70036706328392, 61.92463114857674, 60.250452384352684, 55.858800038695335, 56.20226360857487, 55.72852402925491, 56.43138751387596, 58.02030265331268, 62.26483829319477, 66.60797864198685, 68.11570733785629, 68.42065617442131, 60.11927582323551, 64.8553378880024, 61.51340961456299, 69.3754081428051, 28.58927071094513, 0.2963167388224974, 1.1267079412937164, 1.165862346533686, 1.2756870221346617, 0.4316229955293238, 0.0551977900613565, 0.12215932583785616, 38.13666880130768, 70.10408744215965, 26.27432093024254, 52.04028993844986, 34.57008898258209, 14.885341208428144, 17.32567761093378, 34.38749738037586, 54.60880011320114, 48.501581624150276, 67.64840081334114, 34.217308312654495, 1.0729543631896377, 0.030306422304420266, 0.08541408038581721, 0.027635954174911603, 0.05562871810980141, 0.08211925640353002, 0.05815743417770136, 0.017916214892466087, 0.042229323444189504, 0.05149012416950427, 0.07480998494429514, 0.034334041047259234, 0.039447624076274224, 0.07815605422365479, 0.013384381018113345, 0.06851967482361943, 0.03091545651841443, 0.038591237607761286, 0.014084621470829006, 0.015740397466288414, 0.0939565860608127, 0.03865635735564865, 0.03475510224234313, 0.023371117204078473, 0.012496092404035153, 0.026757462837849744, 0.02994863662024727, 0.10789714739075862, 0.1288375788135454, 0.1372557895956561, 0.18878377071814612, 41.6203560680151, 101.84615537524223, 70.77730491757393, 84.96471762657166, 48.98120328783989, 34.72719915211201, 28.832195475697517, 34.956395253539085, 38.99436637759209, 60.862284153699875, 5.594361908733845, 0.18340539681958035, 0.7461435184814036, 2.0679965196177363, 3.4439589735120535, 5.843121260404587, 2.133294828236103, 0.3407401847653091, 50.14197640120983, 93.8825199007988, 81.09269499778748, 75.77050298452377, 64.03077453374863, 65.59170037508011, 61.93276271224022, 65.44375911355019, 61.06823310256004, 58.84011246263981, 56.62673503160477, 56.85090400278568, 55.89932106435299, 53.741903230547905, 55.48019215464592, 54.98415917158127, 54.877240508794785, 54.80160556733608, 54.05099384486675, 53.6070104688406, 54.5659764111042, 54.14321109652519, 52.46270567178726, 58.40673811733723, 63.109833151102066, 66.93228363990784, 67.43384912610054, 61.85302399098873, 51.22344397008419, 52.04842530190945, 50.65401792526245, 51.454593166708946, 49.959954768419266, 65.03120765089989, 67.42919057607651, 66.55687898397446, 61.405719593167305, 64.70239609479904, 66.93907767534256, 67.13795900344849, 59.87904891371727, 58.97728890180588, 51.84013947844505, 48.97303752601147, 56.47613011300564, 66.80794671177864, 65.20698621869087, 60.026933178305626, 50.95522776246071, 46.620218977332115, 47.70723804831505, 54.27370369434357, 54.657433703541756, 66.3954408466816, 57.29932554066181, 55.11775620281696, 65.71874275803566, 51.21989496052265, 54.51290465891361, 56.53478756546974, 55.06379149854183, 51.8713054060936, 48.26222866773605, 47.103397250175476, 49.183135852217674, 51.048144176602364, 54.86830338835716, 51.876028552651405, 45.58729760348797, 46.461775079369545, 47.34668679535389, 45.873258858919144, 48.259811997413635, 47.62919783592224, 47.87255957722664, 47.8127583861351, 46.45866684615612, 46.33707337081432, 48.578550294041634, 47.36066244542599, 51.55683808028698, 51.04681044816971, 50.641364604234695, 49.53500457108021, 50.35596951842308, 51.503298953175545, 51.77581652998924, 52.028366178274155, 51.84568338096142, 53.75950388610363, 64.35999646782875, 66.76824644207954, 66.56800478696823, 61.53277337551117, 57.355152145028114, 59.83125127851963, 58.76543886959553, 59.37464497983456, 59.462701454758644, 63.71094189584255, 68.33245530724525, 72.37076461315155, 69.19866442680359, 62.251713797450066, 66.24428495764732, 60.454311445355415, 70.44487595558167, 33.84724237024784, 0.2942112955497578, 0.7073470065370202, 2.930130595341325, 2.0398666290566325, 0.6875960226170719, 0.1822895184159279, 0.146052673808299, 36.90037854015827, 77.87005752325058, 33.166041523218155, 46.176417991518974, 34.9546929448843, 25.63540231436491, 30.601350143551826, 42.644667103886604, 60.963419526815414, 56.082440838217735, 76.01632699370384, 44.00568947196007, 1.2619721330702305, 0.16844813770148903, 0.12546196463517845, 0.06622832355787978, 0.023829458332329523, 0.006100927021179814, 0.036703703735838644, 0.12158931931480765, 0.025223948250641115, 0.043876048948732205, 0.03825057327048853, 0.011821489442809252, 0.030051841531530954, 0.0699719761905726, 0.03203392872819677, 0.07519452876294963, 0.11262710686423816, 0.1299536501755938, 0.17963779508136213, 0.20490651339059696, 0.2086798445088789, 0.2353436520206742, 0.12898213433800265, 0.1619531580945477, 0.07571727532194927, 0.15752691513625905, 0.13010951603064314, 0.18174436641857028, 0.30034104944206774, 0.2880595740862191, 0.3338387457188219, 51.063537150621414, 114.54519554972649, 81.77399083971977, 90.8821552991867, 55.2003637701273, 36.024270951747894, 41.732507050037384, 61.37200020253658, 51.63046672940254, 73.09417739510536, 7.3742391262203455, 0.11510758704389445, 0.46965052373707294, 4.102970911189914, 5.233482448384166, 7.495153388008475, 8.998924121260643, 2.140657170675695, 52.03536920249462, 95.78341349959373, 86.17170006036758, 78.85121807456017, 67.99973756074905, 69.77146849036217, 65.74293985962868, 69.53049302101135, 65.17355561256409, 64.1514104604721, 60.15337899327278, 59.60333950817585, 59.50468920171261, 55.81867419183254, 57.806944102048874, 58.39459776878357, 59.47987653315067, 56.555431857705116, 57.97402113676071, 57.02234700322151, 59.3480122089386, 57.7882719039917, 55.95153406262398, 62.29051731526852, 66.21917590498924, 69.41129341721535, 72.17081934213638, 64.44150969386101, 54.10790339112282, 52.89658159017563, 52.68623627722263, 53.72239887714386, 53.070217072963715, 70.08921504020691, 71.96010544896126, 68.12272176146507, 62.123299688100815, 67.76744842529297, 70.71139365434647, 70.55537402629852, 62.17195987701416, 61.74577854573727, 56.47808700799942, 51.83931492269039, 58.572785407304764, 69.17469531297684, 68.37438985705376, 63.85445639491081, 53.40690180659294, 49.79909040033817, 49.522507041692734, 57.633855789899826, 58.40769946575165, 69.28901597857475, 61.057198494672775, 59.438641145825386, 70.63273787498474, 55.71919932961464, 56.36208303272724, 59.41326230764389, 56.49387516081333, 54.22676861286163, 52.46858395636082, 50.092012882232666, 51.36538155376911, 54.27332751452923, 57.75743655860424, 53.588596656918526, 47.6148422062397, 49.07477326691151, 49.88804742693901, 48.74177433550358, 51.322782039642334, 50.36426827311516, 51.0045301169157, 51.20148114860058, 49.87144231796265, 48.45900110900402, 51.491439789533615, 49.75180193781853, 54.17018584907055, 53.646513149142265, 53.15693221986294, 51.92437715828419, 51.680719032883644, 53.45401167869568, 54.20765183866024, 53.80378670990467, 54.4790218770504, 55.4974128305912, 68.5201196372509, 70.1578089594841, 68.2729808986187, 64.7807402908802, 61.86520613729954, 61.681470796465874, 60.645612180233, 63.663687631487846, 62.61112131178379, 68.03708955645561, 72.81538635492325, 76.14514768123627, 71.89905792474747, 64.65866044163704, 66.91813319921494, 62.9048303514719, 71.81103944778442, 37.35846295952797, 1.0795864323154092, 6.431501638144255, 5.87857193313539, 6.094020372256637, 0.8319272403605282, 0.28270379116293043, 0.400062037515454, 47.573067247867584, 84.48554813861847, 41.695668026804924, 69.09325808286667, 48.22524905204773, 23.077499270439148, 28.43244932591915, 49.32055927813053, 70.46307697892189, 65.36118194460869, 86.74568966031075, 51.108781322836876, 1.75149547168985, 0.21312349825166166, 0.15797345055034384, 0.17595700977835804, 0.12307567783864215, 0.14193391747539863, 0.15531135199125856, 0.2558961702743545, 0.10088225622894242, 0.12427141875377856, 0.1863433516700752, 0.16778342571342364, 0.28969366452656686, 0.24432559817796573, 0.08919478103052825, 0.16535387170733884], [0.043776831225841306, 0.023816914181225002, 0.038182930220500566, 0.020259445991541725, 0.03137703155516647, 0.04341893050877843, 0.03701327950693667, 0.03334966007969342, 0.029529044877563138, 0.042057946702698246, 0.022328501763695385, 0.07285698622581549, 0.033036618478945456, 0.05668705409334507, 0.3435360925504938, 51.61323465406895, 73.22590112686157, 64.4525671005249, 29.565506726503372, 54.68166500329971, 28.561630994081497, 51.86295345425606, 61.379975974559784, 42.37551234662533, 47.433686926960945, 0.6071523204445839, 0.6971756054554135, 0.5438565637450665, 0.5054443061817437, 1.1554522113874555, 5.409770663827658, 3.8778251549229026, 5.853743590414524, 75.54266721010208, 81.92723661661148, 76.13084524869919, 65.38279518485069, 65.09949758648872, 69.7010050714016, 71.15362152457237, 70.36140203475952, 66.66871458292007, 65.65166115760803, 62.632023990154266, 60.753028616309166, 53.32665391266346, 54.18022111058235, 52.02975310385227, 52.850573658943176, 52.951819226145744, 52.682257890701294, 53.6596642434597, 53.3548180013895, 51.98023036122322, 50.379083678126335, 49.964062348008156, 53.10715489089489, 59.78682406246662, 61.2676578015089, 58.07111352682114, 52.524174973368645, 50.885018929839134, 49.723930433392525, 49.494947120547295, 48.42174030840397, 49.559665247797966, 63.18903610110283, 64.20887857675552, 66.53613209724426, 64.12014573812485, 63.46132569015026, 60.30984319746494, 63.542724922299385, 59.20435331761837, 55.506444945931435, 49.12211112678051, 48.334869369864464, 57.81222581863403, 64.2987209558487, 63.10636393725872, 61.05813704431057, 52.933109030127525, 53.96720074117184, 51.29087895154953, 52.2763978689909, 53.37980166077614, 64.41638544201851, 54.239855110645294, 50.30161343514919, 63.45774628221989, 48.351592272520065, 52.49723821878433, 52.62064799666405, 49.843297228217125, 45.85131123661995, 41.95446074008942, 44.97820168733597, 47.91072092950344, 51.14625871181488, 55.34514740109444, 54.89452578127384, 48.50093945860863, 44.611806347966194, 45.222866758704185, 43.57182875275612, 43.87648120522499, 44.0933583676815, 45.85511103272438, 46.2312376499176, 45.33904552459717, 45.031820610165596, 44.42760743200779, 44.97028671205044, 46.22967593371868, 49.95905041694641, 46.30762115120888, 48.85283097624779, 46.82503558695316, 49.05131332576275, 49.554269537329674, 47.88975365459919, 50.40498308837414, 51.43798805773258, 61.68900579214096, 61.526328921318054, 61.704204976558685, 59.8617522418499, 58.93796481192112, 57.646144330501556, 57.983782812952995, 61.90181337296963, 58.140718191862106, 58.702905625104904, 62.91981294751167, 67.77687951922417, 66.87631264328957, 62.0181555300951, 60.04264913499355, 63.18094253540039, 62.38992378115654, 40.353659838438034, 0.8301659754943103, 0.48530660395044833, 1.8750984454527497, 2.7879716735333204, 0.8160876121837646, 0.08227885526139289, 0.01950704554474214, 6.522639747709036, 69.83583703637123, 51.025197207927704, 37.923245653510094, 44.14182856678963, 22.470362149178982, 11.584990303963423, 30.666735135018826, 40.808985605835915, 55.003914311528206, 55.16838848590851, 47.538302913308144, 6.813034415245056, 0.2376123529393226, 0.08817301437375136, 0.13797929452266544, 0.059283364971634, 0.0496104088233551, 0.002455672965879785, 0.052882575037074275, 0.016584781551500782, 0.03678099099488463, 0.08765998994931579, 0.03010708143847296, 0.03647993507911451, 0.010977779784298036, 0.047849459369899705, 0.019163095348631032, 0.060323922807583585, 0.04163844401773531, 0.013230710992502281, 0.023897542960185092, 0.0651367504906375, 0.032921926976996474, 0.044102040337747894, 0.021485444267455023, 0.03769159877265338, 0.028657353468588553, 0.04946306653437205, 0.03924645381630398, 0.0505083889584057, 0.021074214673717506, 0.9424202644731849, 67.84266918897629, 83.00136297941208, 72.80184388160706, 38.99071857333183, 61.61168374121189, 27.73324314504862, 29.851542077958584, 51.951986476778984, 51.5411601215601, 52.75488719344139, 0.6888352311216295, 1.4602980972267687, 4.272855995222926, 0.9982400410808623, 5.199835253879428, 11.964238453656435, 2.1674623573198915, 6.123265977948904, 83.11757594347, 83.90915706753731, 83.15884932875633, 67.44739919900894, 68.3599354326725, 72.31892019510269, 74.98319283127785, 72.33848914504051, 71.38694420456886, 67.79949590563774, 66.44244432449341, 61.632301434874535, 55.94515800476074, 55.73470629751682, 56.515359207987785, 55.18669590353966, 56.59877233207226, 54.16993126273155, 56.704433262348175, 54.5782383531332, 53.95534537732601, 52.27547071874142, 52.83340238034725, 54.29827317595482, 60.317176803946495, 62.87769980728626, 61.20834678411484, 54.31885667145252, 51.24998554587364, 53.02428513765335, 49.91757184267044, 49.86962981522083, 51.20099477469921, 66.31303086876869, 65.10543286800385, 66.92883342504501, 64.37087908387184, 65.72286173701286, 63.51389966905117, 66.01957261562347, 61.63841150701046, 57.67357885837555, 50.768422186374664, 50.19051879644394, 60.0077024102211, 67.03624606132507, 65.15468582510948, 63.61670695245266, 55.50943158566952, 56.71373516321182, 54.96718928217888, 54.98035937547684, 56.58856227993965, 66.35957837104797, 57.74403467774391, 52.6333849132061, 65.99677383899689, 51.09617739915848, 55.17494693398476, 53.99039849638939, 53.10892939567566, 48.1746281683445, 45.79236499965191, 46.57661631703377, 51.30187176167965, 53.00406642258167, 56.666762083768845, 59.09045822918415, 51.30926996469498, 47.58999913930893, 46.75541952252388, 45.45829452574253, 47.0083187520504, 47.7010215818882, 47.896274104714394, 49.89745952188969, 47.27642476558685, 47.70961292088032, 47.93457604944706, 47.40631699562073, 47.57655546069145, 52.524706944823265, 48.88115085661411, 51.21370889246464, 48.754378259181976, 49.62313324213028, 52.058620154857635, 51.1102594435215, 52.788735777139664, 53.242560625076294, 64.38300043344498, 64.95501413941383, 64.55942496657372, 62.842088118195534, 62.939579486846924, 60.39493203163147, 61.85662999749184, 63.773072361946106, 61.5886265784502, 62.32890285551548, 66.76705330610275, 70.27688696980476, 71.26197651028633, 61.764051765203476, 61.3254489004612, 65.1654240489006, 61.347871497273445, 45.704927891492844, 2.8848185017704964, 0.4383759159827605, 2.8726612916216254, 3.251019576564431, 1.9759513274766505, 0.6586979795247316, 0.03919616217899602, 5.389179568737745, 72.33725041151047, 58.00040312111378, 40.35698086023331, 35.17024777829647, 11.762958504259586, 11.149313282221556, 38.37457783520222, 49.740052968263626, 61.76060914993286, 61.83310925960541, 61.011768132448196, 10.779858157038689, 0.3505335655063391, 0.041891661094268784, 0.06357743885018863, 0.02427293424261734, 0.1180030094110407, 0.06665131804766133, 0.056235319934785366, 0.03710123884957284, 0.024266800392069854, 0.08834133346681483, 0.04150148437474854, 0.01940227099112235, 0.022249926878430415, 0.008062463220994687, 0.04170321124547627, 0.19238452281570062, 0.15004608139861375, 0.07464694252121262, 0.13355446164496243, 0.13463079842040315, 0.21291351498803124, 0.14523730584187433, 0.06219087321369443, 0.1058019012270961, 0.1332708276459016, 0.16489425965119153, 0.12913841579575092, 0.1370804794714786, 0.14749159425264224, 1.2395763723179698, 80.9381952881813, 91.38261884450912, 81.93782284855843, 44.63184267282486, 69.67178463935852, 36.28202252089977, 70.12047216296196, 87.5524927675724, 59.501512572169304, 61.484405770897865, 0.6554926140233874, 1.1269100429490209, 2.354760244488716, 3.2114689238369465, 6.673660269007087, 17.826825119554996, 9.572213608771563, 7.054303418844938, 90.6382691860199, 85.5433277785778, 86.20808690786362, 69.92729812860489, 73.00335466861725, 75.93398541212082, 77.09894210100174, 75.76734155416489, 72.80493691563606, 69.59018021821976, 68.76079112291336, 65.55848255753517, 59.08780597150326, 58.635736629366875, 57.929168343544006, 57.52970337867737, 58.901961743831635, 56.317348033189774, 59.42083530128002, 57.79816277325153, 56.85651250183582, 53.98133598268032, 55.51795072853565, 56.75636127591133, 64.37403291463852, 66.60623833537102, 65.51600843667984, 56.874968111515045, 55.990523770451546, 55.74743561446667, 55.37853620946407, 52.28116661310196, 55.279065147042274, 67.30993777513504, 67.62797310948372, 70.70861980319023, 67.78235122561455, 67.90644496679306, 65.87486118078232, 68.0501076579094, 65.74882194399834, 61.81751869618893, 54.81528863310814, 54.47732336819172, 62.883600890636444, 69.80352357029915, 68.36557433009148, 67.09850192070007, 58.239889070391655, 58.56659173965454, 58.578960075974464, 57.69251324236393, 60.0075314193964, 69.5888502895832, 62.033046931028366, 57.06970766186714, 69.54415708780289, 54.3669430911541, 59.71218466758728, 58.279368951916695, 57.98068977892399, 53.68261881172657, 49.16821405291557, 51.008329913020134, 54.92925971746445, 55.943497493863106, 60.07386825978756, 60.12348599731922, 54.30011607706547, 50.7859468460083, 48.785958364605904, 49.50390323996544, 49.318598583340645, 48.526344895362854, 51.64161153137684, 52.96701841056347, 50.7844003289938, 51.13338500261307, 48.86294603347778, 50.36879763007164, 49.86027471721172, 55.400267243385315, 50.74942320585251, 53.22413921356201, 49.29853945970535, 53.73961575329304, 53.58975179493427, 52.78555914759636, 55.62736965715885, 55.74813097715378, 67.19561710953712, 68.73448893427849, 68.52945193648338, 66.12014561891556, 65.49613550305367, 64.03506830334663, 64.98291984200478, 66.92713111639023, 62.56435342133045, 65.69978177547455, 69.57219198346138, 74.29246589541435, 73.26567739248276, 65.21732166409492, 63.39682795107365, 69.61787313222885, 63.74778471887112, 52.31240093708038, 3.87821510899812, 2.705350569449365, 8.680865038186312, 7.73147695697844, 3.925859327428043, 0.5464536650106311, 0.07806114837876521, 9.123261999338865, 80.76643690466881, 63.934989273548126, 54.94068570435047, 56.73724830150604, 31.079847067594528, 19.502012729644775, 42.19799347221851, 55.354852080345154, 74.33869421482086, 69.67118427157402, 74.35257107019424, 12.918932475149632, 0.45317635929677635, 0.23085305001586676, 0.2417964331107214, 0.18638145353179425, 0.2604927954962477, 0.20294360700063407, 0.2312882454134524, 0.0903011451009661, 0.1254784848424606, 0.17222192895133048, 0.2568240329856053, 0.18253779649967328, 0.16981073567876592, 0.13719338981900364, 0.13546020782086998], [0.04740177362691611, 0.0968139065662399, 0.062378172733588144, 0.006046711741873878, 0.07435374966007657, 0.03337785055919085, 0.08237590591306798, 0.0286727252023411, 0.038636185781797394, 0.03940248665458057, 0.10611300211166963, 0.017913621086336207, 0.058608871477190405, 0.12945439259056002, 4.0891586523503065, 74.2297312617302, 70.47773659229279, 79.19294893741608, 56.26624457538128, 98.82540106773376, 63.09576630592346, 60.40787413716316, 31.87271062284708, 62.26101569831371, 22.352234087884426, 0.384228554321453, 0.3399634233210236, 5.122937830165029, 0.5396737006958574, 2.720293030142784, 9.737820122390985, 2.7047122037038207, 34.052347764372826, 84.35631707310677, 73.43986004590988, 69.75233271718025, 62.3410090059042, 71.91038891673088, 74.21689555048943, 77.5937819480896, 76.70997217297554, 72.39806994795799, 71.44413113594055, 70.66160872578621, 69.4037090241909, 67.82040998339653, 60.53843513131142, 58.400913029909134, 51.82779014110565, 52.86087490618229, 52.70908065140247, 52.80064433813095, 52.99477972090244, 50.63059598207474, 50.31419076025486, 50.439812019467354, 50.00757001340389, 53.15519191324711, 54.690944105386734, 55.59344507753849, 51.94521524012089, 48.56426306068897, 47.569765225052834, 50.49194522202015, 49.36253562569618, 48.185506984591484, 57.25900590419769, 59.36177887022495, 61.60887569189072, 62.41213358938694, 62.07786172628403, 63.185798674821854, 63.337813317775726, 60.74840046465397, 55.45234724879265, 49.004849418997765, 51.62592597305775, 61.16473652422428, 64.20177295804024, 61.7085937410593, 61.93528197705746, 62.314733415842056, 60.70758305490017, 58.460030257701874, 60.145106837153435, 56.37693263590336, 63.493468165397644, 50.70145457983017, 50.857132226228714, 62.07914225757122, 48.00845928490162, 50.27161784470081, 46.44164755940437, 44.65003229677677, 41.9504177570343, 46.01613499224186, 45.08428819477558, 48.1212904304266, 50.61558298766613, 55.70654600858688, 59.273798391222954, 51.45045518875122, 41.90413624048233, 45.30069038271904, 43.874581307172775, 45.151829570531845, 42.81378082931042, 47.97600522637367, 47.25471653044224, 47.73423179984093, 44.500244334340096, 46.00403644144535, 44.254469722509384, 45.104142129421234, 45.712132304906845, 47.61899158358574, 46.91585071384907, 48.29850152134895, 47.70921014249325, 50.28882332146168, 47.197757586836815, 48.757456094026566, 53.650225549936295, 63.021335899829865, 62.72926077246666, 61.310990676283836, 59.44303371012211, 59.01980862021446, 60.85371941328049, 61.89348042011261, 63.571553975343704, 64.06989723443985, 60.40709137916565, 62.779866456985474, 65.12432545423508, 67.2069177031517, 63.02014276385307, 66.11124649643898, 61.97604238986969, 64.3608932197094, 59.059797674417496, 9.119177218526602, 0.7000642223283648, 1.870636297389865, 0.7027028838638216, 1.32729965262115, 0.3803791233804077, 0.1375887170433998, 0.1600689787301235, 34.411519691348076, 70.32324448227882, 41.80330865085125, 41.58846817910671, 69.75039482116699, 33.591352701187134, 14.640158414840698, 29.290042407810688, 42.35323414206505, 54.26593691110611, 60.044940412044525, 25.548255890607834, 0.6990204658359289, 0.07135383290005848, 0.05862592232006136, 0.025678148194856476, 0.0638833521225024, 0.06562790382304229, 0.016233578717219643, 0.020799451194761787, 0.07548213325208053, 0.04380909609608352, 0.027780249947682023, 0.08002426999155432, 0.05497657068190165, 0.010396178131486522, 0.01988732943573268, 0.004841721347474959, 0.04108532135433052, 0.030731515216757543, 0.06944612745428458, 0.05641712385113351, 0.0796802771219518, 0.07921338459709659, 0.05528086607228033, 0.08226968231610954, 0.044594889477593824, 0.07790515635861084, 0.04187027981970459, 0.06924563625943847, 0.11226672737393528, 6.794888963922858, 91.4741863310337, 76.08492851257324, 89.16859164834023, 55.67398175597191, 109.06641393899918, 52.48943343758583, 48.31077106297016, 40.30968479812145, 72.68856436014175, 24.692040234804153, 0.48388966592028737, 6.2702197674661875, 7.424267241731286, 2.3699021944776177, 3.653611298650503, 9.828965831547976, 2.9850314743816853, 39.279902055859566, 89.4654469192028, 76.36177405714989, 74.23891916871071, 65.45639723539352, 75.431287586689, 76.95219397544861, 78.6538490653038, 78.14745023846626, 76.62760019302368, 76.02581888437271, 74.91485729813576, 73.66242170333862, 70.91832295060158, 63.68010275065899, 59.46673683822155, 54.636759012937546, 55.235033109784126, 55.73670119047165, 55.86963325738907, 54.3886399269104, 53.490546718239784, 53.79608832299709, 52.184632793068886, 53.111558854579926, 56.33227363228798, 57.19062477350235, 57.70274989306927, 54.35052037239075, 50.55794008076191, 50.164763778448105, 49.946302101016045, 50.186897590756416, 49.911229982972145, 57.66792096197605, 62.375264167785645, 64.83525216579437, 62.09691770374775, 64.33775246143341, 65.27901515364647, 65.00169843435287, 63.61727312207222, 57.51944772899151, 51.96206733584404, 54.04559813439846, 65.19952341914177, 65.59905678033829, 64.6046881377697, 63.04801046848297, 65.54053232073784, 63.28215770423412, 62.496226876974106, 64.46864023804665, 59.23282898962498, 67.47709080576897, 53.05565245449543, 53.14131125807762, 63.68998222053051, 52.97621011734009, 51.44434131681919, 48.6174526065588, 46.64762690663338, 44.804345816373825, 48.65858539938927, 48.523438051342964, 50.87840348482132, 52.9289710521698, 59.23228181898594, 60.98008543252945, 55.345052406191826, 44.842195585370064, 46.988635808229446, 45.333083644509315, 48.23875352740288, 46.32665812969208, 49.48893964290619, 50.40197744965553, 50.11597439646721, 46.67503863573074, 46.95424385368824, 47.02729873359203, 47.592035830020905, 48.85573022067547, 48.03155064582825, 47.778298035264015, 50.95048941671848, 50.287774577736855, 51.1624838411808, 50.63843496143818, 51.073880195617676, 55.77749200165272, 64.67764422297478, 66.44508138298988, 64.59887444972992, 62.01033174991608, 61.770268231630325, 63.794989585876465, 64.90912780165672, 66.80094748735428, 67.63592228293419, 63.840404748916626, 66.68589726090431, 68.61008360981941, 69.43275466561317, 66.47464379668236, 67.66287803649902, 64.72350776195526, 68.20585370063782, 63.23225498199463, 14.99425571411848, 0.32959084084723145, 0.891645192168653, 3.222907022573054, 3.208820465952158, 1.311689733993262, 0.2071725277346559, 0.11415640605264343, 33.65727536380291, 78.72175142168999, 44.591697826981544, 32.85407446324825, 45.15284791588783, 24.731985591351986, 22.537964321672916, 44.812199994921684, 50.142382979393005, 60.54112158715725, 69.88173097372055, 40.242097824811935, 0.8907211292535067, 0.02272938767418964, 0.06880937959067523, 0.03350146267621312, 0.046262421092251316, 0.0316939100594027, 0.06908396680955775, 0.07673271145904437, 0.041281931116827764, 0.03247923217713833, 0.040221572780865245, 0.014740665174031164, 0.0266872037173016, 0.050410915282554924, 0.018792772934830282, 0.10243995740893297, 0.21862177352886647, 0.2599293569801375, 0.19806745927780867, 0.20575523347361013, 0.1770435881917365, 0.1368941113469191, 0.12621334462892264, 0.12436125573003665, 0.20882754673948511, 0.3360487724421546, 0.1558591311913915, 0.2502188889775425, 0.38938000914640725, 10.513365156948566, 105.19239261746407, 86.06253191828728, 98.42743322253227, 70.5715611577034, 107.26398065686226, 77.26414203643799, 85.34252375364304, 46.723531633615494, 81.79763317108154, 30.757761150598526, 0.43707525765057653, 4.845250630751252, 13.648261539638042, 5.702242394909263, 11.644983384758234, 20.28002478182316, 6.327994242310524, 38.06264117360115, 94.19758379459381, 77.5509050488472, 79.07127186655998, 66.81743860244751, 78.5588389635086, 82.61480212211609, 84.62676376104355, 80.01295253634453, 80.37958726286888, 76.92135483026505, 77.81831189990044, 76.68911129236221, 74.62674155831337, 65.47881603240967, 64.42245751619339, 56.95782646536827, 59.760639667510986, 57.96479903161526, 57.3109795153141, 57.27631777524948, 55.489817038178444, 54.976726770401, 55.26337578892708, 54.91698257625103, 57.21470408141613, 59.19399507343769, 61.527419462800026, 57.1392173320055, 53.06869335472584, 53.89420285820961, 54.41658742725849, 52.59003683924675, 53.08697037398815, 62.47647553682327, 65.57785391807556, 67.01736867427826, 68.1467592716217, 66.1038064956665, 68.69062408804893, 68.42948690056801, 65.68395182490349, 61.09551563858986, 54.48259748518467, 57.02961981296539, 68.58233749866486, 67.73031681776047, 66.13246455788612, 65.78571796417236, 67.86349967122078, 66.6055315732956, 64.99978333711624, 68.3897790312767, 63.28797519207001, 70.10902717709541, 55.297691747546196, 57.55679592490196, 66.98037385940552, 54.38933528959751, 54.47131969034672, 52.37018443644047, 48.527401238679886, 49.083243012428284, 51.660302728414536, 51.4927963167429, 53.63969251513481, 55.634954050183296, 61.003670766949654, 66.44576534628868, 60.06982147693634, 46.86916261911392, 51.32422596216202, 49.44469481706619, 51.78740970790386, 48.90792042016983, 53.819654658436775, 54.59505245089531, 53.9346706867218, 48.47131244838238, 50.6318499147892, 49.95403088629246, 49.523726776242256, 49.80822131037712, 51.652551144361496, 51.444782093167305, 54.07994829118252, 53.945728093385696, 55.608515068888664, 52.74990566074848, 53.145472034811974, 60.09683042764664, 68.26654404401779, 69.44115981459618, 68.80734622478485, 64.225232899189, 64.44160848855972, 67.16594070196152, 68.53619277477264, 71.9172665476799, 68.41423451900482, 65.99398478865623, 70.83185479044914, 70.8275306224823, 73.00218433141708, 68.62975895404816, 71.20628669857979, 69.2853681743145, 70.23888900876045, 65.71789160370827, 20.066438242793083, 1.5523457829840481, 8.378353770822287, 5.3851627092808485, 5.480316253378987, 1.5653591346926987, 0.4097207332961261, 0.3400409925961867, 43.92008766531944, 83.60497578978539, 54.575369507074356, 57.66233906149864, 87.43893206119537, 45.26168167591095, 26.638556085526943, 42.64875948429108, 58.84309530258179, 71.24397307634354, 78.17113056778908, 45.807822570204735, 1.2035159510560334, 0.24708583834581077, 0.15524406888289377, 0.16019793431041762, 0.16230842418735847, 0.21098550438182428, 0.165878317784518, 0.18240612465888262, 0.09741803703946061, 0.07568131084553897, 0.06937645463040099, 0.17425844154786319, 0.09309329761890694, 0.15850760391913354, 0.1026891334913671], [0.0627592507225927, 0.033637201486271806, 0.045150008518248796, 0.08018890803214163, 0.036639337267843075, 0.0545675842295168, 0.05982926653814502, 0.060386671393644065, 0.07869230044889264, 0.009853170013229828, 0.055585584486834705, 0.06479326970293187, 0.14126479713013396, 0.26156611915212125, 20.285621881484985, 77.77070805430412, 61.351105123758316, 62.74821035563946, 51.11014924943447, 10.864568911492825, 24.999738223850727, 48.44216041266918, 38.909573927521706, 72.63873383402824, 3.942082794383168, 0.13165952113922685, 7.985835783183575, 7.808882128447294, 2.1994290919974446, 6.1609637551009655, 12.28402929380536, 4.981264807283878, 75.24604752659798, 84.26069140434265, 75.21224454045296, 65.76214402914047, 69.20678079128265, 73.14528465270996, 74.15765672922134, 76.14864349365234, 77.7054351568222, 74.3828022480011, 72.05024421215057, 74.24091026186943, 72.02100098133087, 67.14390188455582, 70.13629451394081, 67.01885059475899, 60.64164899289608, 52.769520208239555, 51.49516358971596, 51.00710637867451, 54.984542950987816, 50.78139089047909, 51.25253900885582, 50.05414791405201, 50.91576687991619, 48.9143268764019, 52.59144276380539, 50.271104872226715, 50.47845594584942, 49.22259293496609, 48.41623440384865, 48.49973492324352, 47.74857223033905, 46.70324072241783, 49.10824567079544, 53.76952014863491, 55.84903076291084, 60.30449688434601, 62.402208521962166, 59.50619012117386, 61.164740324020386, 59.23667058348656, 55.1997672021389, 53.38099479675293, 54.03597705066204, 59.93332900106907, 62.934229373931885, 55.16355514526367, 56.169281378388405, 57.92822599411011, 61.145171374082565, 62.098114639520645, 59.930042177438736, 56.986788511276245, 59.943778440356255, 47.84490466117859, 50.34853711724281, 60.976772010326385, 50.85015580058098, 49.372863471508026, 44.90566737949848, 45.213382467627525, 47.347446754574776, 49.64934043586254, 48.956656605005264, 50.06448715925217, 47.2412234544754, 58.54005016386509, 56.3635079562664, 56.928974613547325, 47.86516897380352, 43.278218507766724, 44.989973455667496, 44.56075228750706, 44.97191682457924, 46.41145057976246, 47.163920402526855, 48.67831774055958, 47.282162457704544, 45.663802698254585, 44.71177898347378, 44.51268866658211, 46.34510233998299, 46.82306349277496, 46.59442596137524, 48.88392850756645, 46.439633667469025, 47.262878492474556, 47.58829303085804, 48.47284376621246, 53.90524126589298, 64.07529294490814, 62.259670570492744, 61.90709888935089, 63.58608439564705, 61.5128168463707, 63.89630734920502, 64.16093274950981, 66.68237864971161, 66.89164862036705, 63.55948582291603, 66.95016548037529, 66.5026330947876, 68.17015081644058, 68.33765342831612, 64.30690571665764, 64.77779164910316, 66.47837519645691, 66.45285576581955, 36.60699248313904, 1.2730965111404657, 1.142289717681706, 1.92682103253901, 0.6270973908249289, 1.3377197622321546, 0.32232272147666663, 0.09626083585317247, 4.959038374945521, 66.39126107096672, 61.79917708039284, 47.72428773343563, 49.94905315339565, 74.09119829535484, 50.0435046851635, 9.997391793876886, 27.689826674759388, 48.365381732583046, 53.21275882422924, 53.94341021776199, 1.348142959177494, 0.1659121151897125, 0.09040299002663232, 0.056848664171411656, 0.03551125424564816, 0.048456228178110905, 0.07642288706847467, 0.06724495455273427, 0.04844652459723875, 0.05352364962163847, 0.07075760629959404, 0.03375968924956396, 0.027432787537691183, 0.05547783206566237, 0.04339007209637202, 0.030531905322277453, 0.0644686988380272, 0.03354835898790043, 0.04075155156897381, 0.020415352664713282, 0.014596385171898874, 0.13554836012190208, 0.05326384227373637, 0.06849856814369559, 0.05975149688310921, 0.06448593150707893, 0.014471873200818663, 0.12842881871620193, 0.28110553161241114, 29.108332358300686, 91.21278315782547, 67.79631167650223, 71.12361073493958, 58.852021023631096, 22.924240194261074, 22.536592595279217, 50.08288197219372, 46.311348751187325, 82.86335438489914, 3.5929998010396957, 0.37435101403389126, 6.331721367314458, 6.234008660539985, 4.0386679116636515, 4.651905130594969, 9.285999666899443, 7.034965306520462, 75.63125565648079, 86.46024897694588, 78.68021965026855, 68.14213871955872, 72.36836314201355, 76.75227910280228, 77.06166610121727, 78.4688749909401, 79.60103943943977, 77.15298280119896, 76.25674769282341, 76.27041935920715, 73.76980394124985, 71.9214615225792, 71.85460790991783, 70.75611725449562, 63.57487499713898, 55.91055706143379, 54.2179074883461, 54.06443752348423, 57.424426227808, 54.02867764234543, 53.13607133924961, 53.022316843271255, 51.004712507128716, 54.591009467840195, 54.016111716628075, 53.84752616286278, 51.522096544504166, 50.68302556872368, 51.239707097411156, 50.31625024974346, 50.18424913287163, 50.01876801252365, 51.09708175063133, 56.47703066468239, 59.166412353515625, 62.29164585471153, 64.9964927136898, 63.29780526459217, 64.05918180942535, 62.34414383769035, 58.06927062571049, 55.78256852924824, 57.4432048201561, 63.257326036691666, 66.59763559699059, 56.34229749441147, 58.50539602339268, 59.374154806137085, 62.280045077204704, 63.376563638448715, 62.56181515753269, 59.26642678678036, 61.50648258626461, 49.63539898395538, 52.52772398293018, 63.92000287771225, 52.94181056320667, 49.67818468809128, 46.3995686173439, 47.52004489302635, 49.74006436765194, 53.03261809051037, 51.8711344152689, 52.72407844662666, 51.08313649892807, 61.276492327451706, 58.91251377761364, 60.24263620376587, 49.1302464902401, 45.75600855052471, 48.13485190272331, 45.966403260827065, 46.59975707530975, 49.4643397629261, 51.75256557762623, 51.4948596060276, 48.3547955006361, 48.590941429138184, 46.87030255794525, 46.87352858483791, 47.67282709479332, 49.642793387174606, 48.7039777636528, 49.93380457162857, 48.506392166018486, 49.8707165569067, 48.43993753194809, 49.97412420809269, 56.56365841627121, 65.84573954343796, 65.5026027560234, 64.70550432801247, 66.4427787065506, 64.42513257265091, 65.41390791535378, 66.9182775914669, 68.50514084100723, 69.79476124048233, 67.15710997581482, 69.13272276520729, 67.33311653137207, 71.94100767374039, 69.22313511371613, 66.63474440574646, 68.06093707680702, 68.47771391272545, 67.91766956448555, 48.35324518382549, 4.449793500825763, 0.5400498805101961, 0.23465265316190198, 2.1036305325105786, 2.033557305112481, 0.7610950630623847, 0.14868599188048393, 4.44400736130774, 70.29043704271317, 66.17048531770706, 47.1610401570797, 53.29546898603439, 73.75300124287605, 52.661267817020416, 19.482158794999123, 34.4347820430994, 56.946810856461525, 60.146744549274445, 64.53089609742165, 3.153042308986187, 0.17410680593457073, 0.01603829368832521, 0.03664229472633451, 0.023193302331492305, 0.09688956110039726, 0.03059304344787961, 0.06711020279908553, 0.0363229782669805, 0.008358181239600526, 0.04657824203604832, 0.050613243292900734, 0.019283846486359835, 0.04928045367705636, 0.03264211874920875, 0.10106811227160506, 0.09449501420021988, 0.18524809012888, 0.14689510047901422, 0.18425048037897795, 0.0934483484888915, 0.2386577718425542, 0.1725607638945803, 0.15621482772985473, 0.1604784809751436, 0.3064223856199533, 0.1405735607841052, 0.33881128358189017, 0.41324979392811656, 35.70301339030266, 103.54663252830505, 78.87304410338402, 83.07920560240746, 67.20917478203773, 21.740736700594425, 37.64752484858036, 67.39082783460617, 55.939089730381966, 90.27197644114494, 6.328296326100826, 0.6315753317903727, 16.818091347813606, 20.51266349852085, 7.847242020070553, 20.393178910017014, 34.62478704750538, 8.053774237632751, 79.38183680176735, 89.8339131474495, 83.31342503428459, 71.11337408423424, 76.11753076314926, 79.90348041057587, 79.8477678000927, 82.016182243824, 80.66913932561874, 82.15896338224411, 77.82962769269943, 80.55926442146301, 77.07824841141701, 72.00297474861145, 74.86726105213165, 74.94230702519417, 65.61740979552269, 57.90480025112629, 57.328097596764565, 56.27879150211811, 58.442460000514984, 55.90118296444416, 56.67086586356163, 55.71165293455124, 55.633023753762245, 55.79232260584831, 57.22103454172611, 56.383928060531616, 54.419342279434204, 54.59372632205486, 55.038549453020096, 53.06658446788788, 51.60092331469059, 51.51664763689041, 53.64790767431259, 59.674817472696304, 59.82739068567753, 64.52744588255882, 67.68665716052055, 64.62983518838882, 66.80644199252129, 66.09746843576431, 60.76477758586407, 58.81882220506668, 60.90948902070522, 65.1133668422699, 69.08492892980576, 58.5921111702919, 59.5879465341568, 61.70523852109909, 64.72952663898468, 66.85752645134926, 65.39008319377899, 61.152812764048576, 64.7601529955864, 52.503390088677406, 55.594623014330864, 65.09565219283104, 57.404709085822105, 53.530113995075226, 51.76322400569916, 50.151297301054, 52.6254927366972, 56.963309571146965, 53.85348804295063, 55.815546959638596, 53.087023571133614, 65.3223480284214, 60.42047046124935, 62.422529831528664, 52.82668434083462, 48.2880786806345, 50.49689635634422, 49.889954924583435, 48.44372972846031, 51.730773746967316, 54.8914897441864, 55.37876799702644, 52.15057522058487, 52.7037039399147, 49.25345487892628, 49.812503680586815, 50.68273678421974, 50.72124011814594, 50.29860399663448, 53.37751418352127, 50.659896209836006, 52.83838391304016, 50.89965954422951, 52.68590569496155, 59.67053510248661, 69.38607037067413, 68.54214325547218, 67.44683682918549, 67.42473721504211, 66.55311718583107, 69.33842092752457, 69.02777999639511, 71.90598875284195, 72.21049681305885, 69.53194454312325, 72.50623494386673, 72.0919431746006, 76.28656849265099, 73.36333215236664, 70.71376472711563, 72.0797610282898, 72.7660346031189, 72.82245397567749, 51.412453427910805, 5.584375094622374, 5.536883343011141, 8.613753989338875, 5.0663389172405005, 4.309145472943783, 1.4550408418290317, 0.18213783827377483, 6.651717871427536, 80.0141228735447, 76.02242946624756, 62.12604694068432, 59.83511947095394, 86.86254858970642, 59.60275813937187, 18.308646865189075, 40.685203447937965, 68.22361394762993, 66.6029705107212, 75.60852527618408, 4.144919710233808, 0.24524053267668933, 0.2952738432213664, 0.08535726155969314, 0.14456679025897756, 0.2977759495843202, 0.23160192155046389, 0.14848675491521135, 0.11270014903857373, 0.16216554591665044, 0.2011691319057718, 0.17015886231092736, 0.12293466978007928, 0.11578683028346859, 0.08924378504161723], [0.05045236051955726, 0.048504126389161684, 0.06339591694995761, 0.0723260389349889, 0.006875737080918043, 0.02706227587623289, 0.008603783880971605, 0.10779761054436676, 0.030608461565861944, 0.06027281480783131, 0.07712855818681419, 0.05272749585856218, 0.13632430520374328, 0.10280923524987884, 48.17025080323219, 76.45201921463013, 63.49234342575073, 64.9713684618473, 34.50502127408981, 30.029237642884254, 53.552099615335464, 34.21964518725872, 54.98196288943291, 55.73320157825947, 0.4149968986166641, 0.12394977937219664, 7.492191921919584, 2.6829286850988865, 1.096762460656464, 11.668784357607365, 1.7777105025015771, 19.746489711105824, 86.94345384836197, 72.90316924452782, 74.65174421668053, 64.6821203827858, 67.5041301548481, 66.82465061545372, 73.47936272621155, 68.77054139971733, 75.76807871460915, 68.13315600156784, 69.68731060624123, 68.43706369400024, 68.9461375772953, 67.54390642046928, 68.71502637863159, 66.68575286865234, 68.94902542233467, 58.22793871164322, 52.13265158236027, 51.626480743288994, 54.5033747702837, 53.0651481449604, 49.780270010232925, 49.48372632265091, 50.342408046126366, 48.93599711358547, 50.668248161673546, 50.172241777181625, 49.156183898448944, 47.41835854947567, 45.99060036242008, 47.48959332704544, 48.680681213736534, 47.29995310306549, 49.65557970106602, 51.881507858633995, 56.805895417928696, 61.1426293104887, 60.944306552410126, 61.4695143699646, 62.58286602795124, 60.546855479478836, 62.40778662264347, 58.16355496644974, 57.675049379467964, 59.15655568242073, 62.39851512014866, 57.17427805066109, 57.409759014844894, 59.06920976936817, 60.12868791818619, 56.44914396107197, 61.28830589354038, 56.927637085318565, 61.59044288098812, 43.1595204770565, 49.77308079600334, 62.006866335868835, 50.02376854419708, 49.662008956074715, 44.95348781347275, 50.006456673145294, 49.40845236182213, 54.32062737643719, 51.408421844244, 50.34426234662533, 51.11833021044731, 56.24985225498676, 58.353339582681656, 56.161290407180786, 49.299151226878166, 44.41105172038078, 43.48021186888218, 43.36564801633358, 44.03340898454189, 49.81903553009033, 48.5688304156065, 49.072652980685234, 49.47238773107529, 45.42014837265015, 45.87941072881222, 44.43815566599369, 42.822003588080406, 46.25692427158356, 45.54955042898655, 48.45423236489296, 44.28091250360012, 46.81215427815914, 47.82471254467964, 47.48490817844868, 53.96598480641842, 65.02074301242828, 60.828051790595055, 64.38299283385277, 64.71786886453629, 64.26101177930832, 64.15773332118988, 66.78281486034393, 64.88424673676491, 64.07296746969223, 65.3948101401329, 65.63599839806557, 66.38723328709602, 68.41825470328331, 64.31600242853165, 59.48552303016186, 60.46104468405247, 70.9326633810997, 58.546718806028366, 62.118823528289795, 29.001235105097294, 0.7147966255433857, 2.7373724011704326, 2.5625917548313737, 1.6254312987439334, 0.29708575224503875, 0.13583663996541873, 0.15172934654401615, 31.84740398079157, 68.89650464057922, 41.02115862071514, 59.958297461271286, 83.56671184301376, 125.76825052499771, 51.85465469956398, 24.712958112359047, 46.98152258992195, 50.82516834139824, 59.167784079909325, 5.256502563133836, 0.417836177512072, 0.02555311115429504, 0.17897461191751063, 0.03818969118583482, 0.1060064890771173, 0.03648430261819158, 0.048798091083881445, 0.05399506553658284, 0.058549325258354656, 0.03789296941249631, 0.11202993031474762, 0.028619533622986637, 0.030882712962920777, 0.02396808224148117, 0.06526219571242109, 0.13810152624500915, 0.024801629115245305, 0.04098791818250902, 0.016224930841417518, 0.061378165846690536, 0.028540993989736307, 0.06992778871790506, 0.0683468286297284, 0.03856212686514482, 0.03776481906243134, 0.006018832964400644, 0.09317425850895233, 0.23826370626920834, 62.66127862036228, 83.49753275513649, 71.60579726099968, 69.96599525213242, 41.975975185632706, 20.508080944418907, 37.74731129407883, 41.20714344084263, 64.14499640464783, 58.47855806350708, 0.30320285994093865, 0.18893836007919163, 5.984609993174672, 2.9972672928124666, 3.7867357302457094, 19.402288980782032, 2.1147105004638433, 22.012237831950188, 91.5645606815815, 76.45120605826378, 77.97645181417465, 66.518075466156, 67.42399245500565, 69.15375843644142, 74.8683249950409, 72.04018235206604, 78.58617469668388, 71.65329471230507, 75.89721098542213, 71.01358383893967, 72.04249262809753, 70.7261672616005, 70.5860535800457, 69.53831300139427, 70.76171815395355, 62.43650548160076, 54.61155876517296, 53.86322312057018, 56.84139311313629, 54.560823887586594, 52.49620847404003, 52.5438579171896, 51.208347380161285, 49.94208812713623, 52.840701788663864, 51.54051415622234, 50.3091636300087, 50.37136249244213, 48.19674298167229, 49.252440333366394, 50.78014835715294, 49.97296907007694, 50.77455885708332, 54.82010297477245, 60.81234723329544, 63.945955485105515, 64.54076796770096, 64.19375538825989, 65.52458077669144, 62.40121677517891, 65.94283953309059, 60.662688463926315, 60.69566689431667, 62.42673620581627, 64.5271646976471, 58.926649019122124, 60.09535610675812, 60.07872439920902, 63.95319789648056, 59.62415099143982, 63.23823966085911, 59.401045963168144, 63.63176554441452, 43.87231282889843, 52.4753437936306, 66.03421702980995, 53.5138014703989, 52.522005289793015, 49.28000405430794, 50.8524014800787, 53.5980923473835, 56.75965189933777, 53.70347209274769, 50.270177721977234, 54.24136362969875, 59.984698444604874, 62.19167321920395, 58.14481437206268, 52.473812475800514, 47.21258819103241, 44.679944291710854, 45.41328974068165, 46.78085155785084, 49.93473932147026, 52.270306795835495, 51.55286729335785, 50.826707258820534, 47.11463324725628, 48.58136594295502, 45.712105706334114, 45.43277129530907, 48.49750064313412, 48.085340559482574, 50.12695960700512, 46.88024662435055, 48.79698157310486, 50.7842293381691, 48.58253248035908, 57.63601407408714, 67.9367445409298, 64.01511177420616, 66.5006572008133, 65.49510195851326, 66.21110513806343, 65.70924326777458, 69.63073924183846, 66.09073519706726, 62.83286601305008, 68.39177772402763, 66.92172780632973, 69.63135480880737, 68.20791319012642, 66.95011988282204, 60.988965556025505, 65.28503403067589, 73.21104392409325, 62.501713782548904, 61.387651562690735, 40.03375120460987, 0.6424643599893898, 0.8097849378827959, 0.21070705057354644, 2.2871711337938905, 0.850958697265014, 0.3066703223157674, 0.16512239584699273, 31.969265341758728, 77.12279722094536, 51.22932605445385, 68.41786712408066, 87.02421471476555, 110.48543259501457, 55.111129358410835, 31.038364693522453, 53.36003132164478, 56.78781978785992, 72.41632416844368, 11.395104043185711, 0.5413780873641372, 0.11573545139981434, 0.0670171671663411, 0.03724026166310068, 0.15590498107485473, 0.011786469349317485, 0.045579956931760535, 0.02325617151655024, 0.027405927357904147, 0.04102942650206387, 0.07767444491037168, 0.02104057311953511, 0.020714894599223044, 0.05130712168465834, 0.13436476816423237, 0.17803917929995805, 0.14639873726991937, 0.1992775162216276, 0.15431740845087916, 0.11363155179424211, 0.15804917929926887, 0.18374001636402681, 0.1638939930126071, 0.11402022937545553, 0.14921799302101135, 0.1578075360157527, 0.11556955170817673, 0.35959174507297575, 69.74471792578697, 94.52023968100548, 80.67825123667717, 82.67534047365189, 49.77856770157814, 47.59345695376396, 73.27621042728424, 53.6727811396122, 73.76911997795105, 66.80710315704346, 0.6862391391769052, 0.40447092906106263, 16.32599875330925, 10.01205900683999, 4.367402996867895, 28.411900028586388, 6.561515461653471, 22.37358894199133, 93.56409698724747, 78.39673966169357, 81.71010866761208, 70.06360441446304, 71.98051035404205, 73.21010157465935, 80.48821583390236, 73.6886402964592, 79.86862868070602, 73.72656986117363, 78.3912755548954, 73.35475221276283, 75.70950865745544, 74.4766116142273, 72.29444190859795, 72.14640185236931, 73.01834106445312, 63.994988054037094, 58.96112076938152, 55.37685289978981, 59.47593994438648, 56.80605120956898, 54.23325106501579, 54.96148198843002, 55.48938386142254, 54.246793538331985, 55.80096334218979, 54.46801386773586, 53.76845620572567, 51.50768391788006, 50.93594379723072, 52.411693409085274, 53.67200218141079, 52.02063359320164, 54.19933408498764, 56.82851180434227, 62.9782348126173, 68.88342574238777, 65.05716785788536, 67.16705784201622, 69.01432871818542, 64.35936570167542, 68.80392640829086, 63.22912395000458, 65.56333109736443, 62.68371261656284, 67.16084897518158, 59.797254502773285, 63.835009038448334, 63.164037242531776, 67.23703488707542, 60.96514083445072, 64.9133075773716, 63.63740064203739, 65.37880539894104, 46.77311897277832, 59.023095443844795, 68.20262387394905, 55.57259939610958, 54.9753550440073, 51.282154619693756, 53.694242388010025, 56.65809854865074, 60.235291197896004, 58.031812235713005, 53.577379658818245, 57.47556388378143, 62.145973071455956, 63.725609108805656, 61.45311065018177, 56.3317758589983, 48.78656253218651, 46.63870118558407, 47.74210877716541, 49.32748630642891, 53.449926897883415, 54.91195924580097, 54.37489986419678, 53.82872857153416, 50.05566403269768, 52.03179359436035, 49.03133399784565, 46.75090156495571, 51.20485916733742, 51.96098819375038, 53.07522140443325, 47.90947459638119, 52.41856724023819, 53.29443924129009, 50.699923262000084, 61.468078047037125, 73.26841324567795, 66.60822182893753, 69.56561833620071, 69.48308676481247, 68.97741749882698, 69.25540298223495, 72.53591895103455, 68.79473090171814, 68.91314774751663, 71.43190339207649, 70.1554074883461, 73.76253873109818, 71.06906846165657, 71.62624776363373, 63.25449898838997, 66.52410954236984, 76.90975025296211, 65.97490221261978, 60.499973595142365, 41.235147938132286, 1.002210946753621, 11.21108466759324, 7.723029060289264, 4.9424266163259745, 0.9498420380987227, 0.40387483604718, 0.16806078114314005, 38.55385981500149, 83.34114834666252, 56.94313645362854, 69.07609820365906, 90.73610633611679, 126.6564528644085, 65.28678193688393, 35.03845565021038, 66.70013889670372, 65.77463775873184, 86.29062607884407, 13.911877144128084, 0.693984548561275, 0.2179661751142703, 0.28309873247053474, 0.1043861209473107, 0.22474474419141188, 0.1493528560968116, 0.12496962386649102, 0.21664203522959724, 0.14886637829476967, 0.14469023910351098, 0.2028956642607227, 0.10930519449175335, 0.24481174943502992, 0.18436238140566275], [0.0068594478671002435, 0.004597371544150519, 0.03548238099028822, 0.04079381687915884, 0.0670367524435278, 0.044325909184408374, 0.016255857990472578, 0.014898379904479953, 0.10751481517218053, 0.05719869441236369, 0.07080392373609357, 0.026774535945151, 0.23018526553642005, 3.957050903700292, 73.28364282846451, 63.404294550418854, 70.6792625784874, 55.15241414308548, 24.233748726546764, 24.871160723268986, 37.5132742524147, 34.22285221517086, 80.44286146759987, 27.44325790554285, 0.3334076172905043, 0.17184292897582054, 2.9993372317403555, 1.4616434625349939, 3.8284259056672454, 9.339132215827703, 2.0595084875822067, 37.36502140760422, 90.98113238811493, 73.842653632164, 75.2927166223526, 64.75067630410194, 65.75715869665146, 66.88179194927216, 75.17360061407089, 69.07908484339714, 73.03845718502998, 69.36484470963478, 71.28865867853165, 67.24518164992332, 66.63136258721352, 66.2331135571003, 66.87426075339317, 69.01146367192268, 67.84723654389381, 64.98609647154808, 52.680114805698395, 49.990489929914474, 51.2895680218935, 50.27052350342274, 50.418586358428, 48.60837109386921, 50.338505655527115, 48.47480446100235, 47.47722119092941, 46.44847199320793, 48.93786281347275, 46.33320517838001, 48.645001128315926, 46.25005804002285, 45.571163669228554, 49.70988258719444, 53.65220904350281, 56.787990778684616, 60.6019639223814, 58.38645480573177, 62.93307043612003, 60.22899493575096, 57.914341539144516, 59.39284600317478, 68.43293711543083, 62.26813651621342, 61.43159240484238, 61.29795737564564, 60.782321244478226, 59.21208970248699, 61.610213220119476, 59.76061686873436, 63.483117520809174, 58.869891464710236, 62.98527203500271, 58.32317680120468, 63.54420684278011, 38.668043687939644, 44.47945944964886, 61.91736973822117, 50.698141157627106, 52.44349390268326, 47.98686124384403, 50.946735218167305, 51.281200870871544, 54.10304345190525, 50.19222870469093, 46.011457443237305, 49.94089879095554, 57.25620165467262, 57.43082508444786, 56.107694283127785, 51.41181506216526, 48.26560288667679, 46.286000311374664, 45.818781182169914, 46.245517283678055, 50.53013317286968, 52.32787750661373, 52.620233818888664, 48.995030745863914, 45.53583316504955, 45.448008477687836, 46.10846623778343, 42.970944195985794, 45.66514402627945, 44.72176104784012, 47.1049589663744, 46.49829491972923, 44.81141723692417, 45.3715717792511, 47.51445919275284, 55.080670192837715, 62.764800265431404, 59.08503971993923, 60.39903961122036, 60.74800908565521, 64.48010042309761, 64.29900214076042, 64.525887966156, 59.20830510556698, 60.475191324949265, 68.3948403596878, 63.85700985789299, 64.18155044317245, 62.80057914555073, 60.57562753558159, 61.109677478671074, 66.77622601389885, 68.68577554821968, 67.68376931548119, 59.8841368407011, 75.08620530366898, 24.95515901595354, 0.36309204006101936, 1.9646620145067573, 1.4137198403477669, 0.5287410342134535, 0.20349235099274665, 0.05453027275507338, 5.102295437827706, 71.40686273574829, 50.58602437376976, 44.77358266711235, 65.82547143101692, 92.62433901429176, 35.80190308392048, 16.860434375703335, 32.31916196644306, 48.452898636460304, 61.975274831056595, 23.420159183442593, 0.29821138246916234, 0.07481006658053957, 0.07996723594260402, 0.0784197096072603, 0.07252526847878471, 0.09616108378395438, 0.045700396367465146, 0.03820045974862296, 0.018298242830496747, 0.075360435876064, 0.026819803242688067, 0.014670267828478245, 0.05780056133517064, 0.022828225046396255, 0.04949229973135516, 0.05455737598822452, 0.0927294374560006, 0.06304170470684767, 0.07915801295894198, 0.00917617177037755, 0.016283044715237338, 0.035049245052505285, 0.02556750325311441, 0.00408640054956777, 0.030091218031884637, 0.08282218899694271, 0.10483250793186016, 6.885008253157139, 86.57141581177711, 71.07846155762672, 79.65324863791466, 66.87147170305252, 43.48350249230862, 26.747832521796227, 40.47831594944, 42.12469160556793, 86.8796780705452, 27.79016599059105, 0.37575557304080576, 0.07084812605171464, 4.527614749968052, 1.979369125328958, 4.7025255393236876, 20.636234767735004, 3.2798099191859365, 40.9629837423563, 90.28422698378563, 77.17894300818443, 78.53901162743568, 67.13615030050278, 69.40512254834175, 68.8539545238018, 76.38375967741013, 73.82304668426514, 76.7150031030178, 71.74410223960876, 72.60288655757904, 70.301783233881, 70.30625179409981, 68.87724727392197, 70.20618036389351, 71.31208062171936, 70.99768549203873, 65.90296447277069, 55.96759580075741, 52.664216458797455, 52.5297112762928, 53.35233673453331, 52.84388981759548, 51.200295612215996, 53.09526152908802, 51.45306184887886, 51.81369669735432, 49.92604918777943, 52.14463233947754, 48.956649005413055, 50.6721505522728, 47.83357746899128, 48.46837520599365, 49.83604721724987, 56.82389885187149, 57.85129152238369, 61.110612228512764, 60.88045857846737, 65.15676811337471, 63.812423050403595, 60.44149473309517, 62.115076929330826, 67.96762928366661, 64.56393912434578, 64.04320746660233, 62.979386150836945, 62.934168577194214, 62.23245643079281, 64.76189330220222, 62.108077704906464, 65.94166159629822, 62.53477580845356, 64.65733051300049, 59.92968499660492, 65.68115517497063, 40.57828098535538, 46.69291667640209, 64.74629893898964, 53.64883862435818, 54.56575222313404, 49.67406190931797, 55.546715185046196, 53.91596049070358, 55.10897867381573, 53.75396378338337, 49.93299901485443, 52.14311622083187, 59.42736715078354, 59.34649609029293, 60.066242069005966, 55.15226595103741, 51.32379278540611, 49.26804229617119, 47.9958363622427, 48.87932315468788, 53.257851004600525, 54.76279444992542, 55.67091532051563, 53.46315398812294, 48.553650230169296, 45.46155855059624, 49.0412362664938, 45.09410686790943, 47.83343307673931, 46.47681087255478, 47.949946224689484, 48.858215287327766, 46.92815825343132, 48.506194576621056, 49.187406823039055, 56.455048844218254, 65.43098419904709, 63.19108039140701, 62.34625272452831, 62.432736083865166, 67.34764695167542, 65.57758793234825, 67.73781761527061, 61.78348012268543, 63.54347728192806, 72.3031510412693, 65.47038808465004, 65.47642976045609, 65.51079511642456, 63.39802488684654, 65.007633715868, 67.7371184527874, 70.67974895238876, 68.42267006635666, 61.53094567358494, 74.13830056786537, 36.64070427417755, 0.5209988309070468, 0.3695337037788704, 0.5486490565817803, 1.0101383901201189, 0.6070087000261992, 0.026825890709005762, 5.134281171485782, 73.7463515996933, 58.21297891438007, 49.96534287929535, 68.4949953854084, 93.77028912305832, 43.50623667240143, 22.851394303143024, 43.66611689329147, 53.26540119946003, 71.88992321491241, 34.0374905616045, 0.4940838657785207, 0.043555819647735916, 0.037750773917650804, 0.0068094739617663436, 0.0952726588002406, 0.03538630255206954, 0.014830099535174668, 0.017127703395090066, 0.04835109553823713, 0.1197604151093401, 0.008822372346912744, 0.028737533248204272, 0.008336531864188146, 0.019601149870140944, 0.19725471851415932, 0.13083413417916745, 0.21962732425890863, 0.14762040140340105, 0.23782889678841457, 0.13101711811032146, 0.08169805048964918, 0.13622053811559454, 0.16554969479329884, 0.13329896988580003, 0.1984606491168961, 0.2799323742510751, 0.3803557011997327, 8.740458190441132, 102.38266378641129, 80.78105092048645, 90.9799088537693, 71.09862327575684, 37.96311691403389, 39.6138509362936, 57.41346001625061, 49.653554409742355, 98.4758198261261, 31.956080049276352, 0.3984583751298487, 0.39359496266115457, 8.40510243549943, 10.213893726468086, 8.457448426634073, 22.110012285411358, 3.658884228207171, 43.86909820139408, 97.08176583051682, 81.37028530240059, 80.37314280867577, 71.17600232362747, 71.46669432520866, 70.88805377483368, 80.7277549803257, 76.68980285525322, 78.0420894920826, 72.82960519194603, 76.07042849063873, 72.20326200127602, 71.9410988688469, 69.86223801970482, 73.03626090288162, 74.30592477321625, 73.54773625731468, 69.46378380060196, 57.703905031085014, 54.525778368115425, 54.680646657943726, 54.91860888898373, 55.491583943367004, 54.23569813370705, 56.221308186650276, 53.629790246486664, 54.324423372745514, 52.61466331779957, 55.098308846354485, 50.9347278624773, 53.24344217777252, 52.71907791495323, 51.006050035357475, 53.919916078448296, 58.9027065038681, 59.62956950068474, 63.75909671187401, 63.61494764685631, 67.92257890105247, 64.06127169728279, 61.301187202334404, 65.03314554691315, 67.54151254892349, 65.5055133998394, 66.50984510779381, 66.67135164141655, 66.42381772398949, 64.20377925038338, 66.37468636035919, 65.45034036040306, 68.80476996302605, 63.22658948600292, 68.51964846253395, 63.65526348352432, 68.17940711975098, 44.87467624247074, 50.160048231482506, 66.8292635679245, 56.34060278534889, 56.73662133514881, 54.04299907386303, 57.869500145316124, 57.43030071258545, 59.84773859381676, 56.85440741479397, 51.36427581310272, 54.77464221417904, 61.88545525074005, 61.324521750211716, 61.617999002337456, 57.903861701488495, 54.51116435229778, 53.60959053039551, 50.32510757446289, 51.29588708281517, 55.61045676469803, 57.9146721214056, 58.8997882604599, 55.29198445379734, 50.243020579218864, 48.682706505060196, 51.071151942014694, 47.508026137948036, 51.472797989845276, 49.054584950208664, 50.70438042283058, 52.38883763551712, 49.173780754208565, 49.99063432216644, 52.120302245020866, 60.463339760899544, 68.35139349102974, 66.91383183002472, 64.5806810259819, 63.49502608180046, 69.22055125236511, 68.54311600327492, 68.92313361167908, 63.85371923446655, 66.32911160588264, 76.77268400788307, 68.08706447482109, 68.49652290344238, 69.78308066725731, 66.44084841012955, 67.26135358214378, 71.25009834766388, 74.89754542708397, 71.37388810515404, 62.96482913196087, 77.04855680465698, 36.01634457707405, 0.8133587054908276, 8.268282227218151, 6.947264587506652, 2.056762184947729, 1.0837413906119764, 0.13067347405012697, 7.281898856163025, 84.45318907499313, 64.8467655479908, 59.93329860270023, 72.44149401783943, 97.75534808635712, 45.06321832537651, 26.072490960359573, 50.76240710914135, 62.550970539450645, 82.5967986881733, 40.154219940304756, 0.6500825949478894, 0.25463980331551284, 0.16652407532092184, 0.16707363567547873, 0.2045814972370863, 0.16040015470935032, 0.08741572688450105, 0.13255700032459572, 0.15324168023653328, 0.15095813636435196, 0.15395920345326886, 0.07715695275692269, 0.18833147623809054, 0.13461435242788866], [0.047697278278064914, 0.016234500835707877, 0.03647682548034936, 0.006810088552811067, 0.015007618476374773, 0.04375674128823448, 0.028182649839436635, 0.020590788953995798, 0.032932877365965396, 0.04264395764039364, 0.019382307218620554, 0.08092013871646486, 0.06060704472474754, 16.986473612487316, 79.86136347055435, 63.400008380413055, 74.43381831049919, 39.14287380874157, 13.040039576590061, 20.192350186407566, 28.643138520419598, 47.19917491078377, 75.37994474172592, 6.1423499789088964, 0.2994009858230129, 0.47641766373999417, 2.129135951399803, 1.3166035828180611, 6.494537880644202, 2.785399449057877, 6.820867694914341, 53.63143555819988, 79.16160821914673, 70.56586146354675, 71.99437201023102, 64.93318051099777, 66.4420111477375, 70.12163490056992, 68.55806440114975, 66.24822914600372, 69.07215401530266, 69.75015163421631, 73.0509053170681, 70.80175280570984, 69.07138645648956, 70.25737881660461, 65.38995400071144, 67.33294174075127, 68.65979254245758, 64.74452063441277, 55.27197852730751, 49.032299146056175, 49.463716596364975, 48.58592189848423, 50.60053959488869, 48.44496466219425, 50.02971522510052, 51.41361616551876, 49.34577092528343, 46.37238867580891, 47.48316027224064, 46.35228395462036, 44.71940517425537, 43.904269114136696, 45.95247320830822, 52.55918629467487, 61.2970682233572, 62.630196288228035, 62.83557526767254, 60.42760647833347, 64.55189377069473, 60.24144306778908, 58.35333578288555, 53.86646434664726, 58.59177678823471, 60.127228796482086, 57.6557844132185, 60.300282910466194, 61.86839796602726, 62.9200105369091, 63.31398859620094, 56.986685916781425, 61.466174349188805, 60.26535898447037, 61.802201718091965, 58.107994347810745, 63.63687627017498, 33.55408810079098, 42.110769152641296, 62.609229013323784, 50.087004750967026, 55.18372066318989, 50.5762854963541, 52.86438591778278, 50.52331633865833, 54.3673724681139, 50.222501680254936, 50.90230040252209, 49.98500682413578, 57.57810138165951, 56.58485367894173, 56.775899827480316, 54.07326065003872, 51.872323751449585, 50.3896889090538, 53.47717523574829, 52.515085861086845, 55.06689973175526, 55.38098327815533, 55.03340072929859, 51.71643331646919, 48.66069048643112, 43.744153305888176, 45.13684317469597, 43.64347390830517, 44.41993944346905, 43.94623026251793, 45.50193138420582, 47.316250428557396, 46.48175820708275, 46.22818261384964, 46.22495658695698, 53.804588466882706, 62.91513919830322, 59.416199550032616, 60.6350639462471, 63.24836991727352, 66.68680161237717, 61.828519105911255, 64.70984369516373, 56.29067346453667, 64.48808759450912, 64.28307339549065, 62.00210139155388, 58.92675921320915, 57.47740298509598, 57.15862289071083, 60.56430034339428, 65.79310476779938, 66.34111896157265, 64.4512827694416, 71.98978185653687, 64.15582582354546, 77.71042808890343, 22.624411582946777, 0.2512182353530079, 1.7637285590171814, 0.7939589652232826, 0.10924548871116713, 0.05105961914523505, 0.067981254105689, 31.57909467816353, 73.77953141927719, 47.43162743747234, 63.00671808421612, 38.380011543631554, 20.422021262347698, 16.809161826968193, 28.930405005812645, 52.44583457708359, 53.49953703582287, 40.416903644800186, 1.2296324246563017, 0.02914718206739053, 0.024818488855089527, 0.09983772790292278, 0.03343687356391456, 0.038162914497661404, 0.09058633018867113, 0.08713937335414812, 0.037232610120554455, 0.03121637142612599, 0.04798862319148611, 0.051883210107916966, 0.028031179354002234, 0.04149982567469124, 0.054082661226857454, 0.05292601294058841, 0.021389107932918705, 0.019100571262242738, 0.03606674807087984, 0.020574578593368642, 0.017263050722249318, 0.04297862913517747, 0.07751934346742928, 0.07469985765055753, 0.04320191539591178, 0.0604720257979352, 0.13233959558419883, 25.832653529942036, 91.60080313682556, 70.72485253214836, 80.7181490957737, 49.49928268790245, 22.11071714758873, 26.350541040301323, 34.9336838722229, 53.43747116625309, 82.44805946946144, 5.937671111896634, 0.21399492805358022, 0.5504088965244591, 3.139152629300952, 5.271794367581606, 9.023144021630287, 3.1220989068970084, 6.855757897719741, 58.02919417619705, 83.77604261040688, 75.73392614722252, 75.05834519863129, 67.30554521083832, 69.15722385048866, 74.26390662789345, 72.19888463616371, 68.68286490440369, 72.34093621373177, 74.10780340433121, 75.1517441868782, 73.45939099788666, 71.52756705880165, 71.21675133705139, 67.94139549136162, 69.22278553247452, 69.9360528588295, 65.33475816249847, 58.104950711131096, 51.167066395282745, 51.89741000533104, 50.35671807825565, 51.27257913351059, 49.924255684018135, 51.75581820309162, 52.66129821538925, 51.609803438186646, 49.17118929326534, 49.167796075344086, 49.283355474472046, 49.11700040102005, 48.76848690211773, 47.586556524038315, 56.36825770139694, 64.78103667497635, 64.57464694976807, 65.0661201775074, 62.94981233775616, 64.48072358965874, 61.276860907673836, 61.68764926493168, 55.66855184733868, 61.56460426747799, 60.83859242498875, 60.889904871582985, 62.902535274624825, 63.66316705942154, 64.86903235316277, 63.199280351400375, 59.35474544763565, 64.68873202800751, 59.80108469724655, 65.58906331658363, 59.91178035736084, 66.4247752726078, 35.76460048556328, 45.370925813913345, 65.83721280097961, 53.429913371801376, 58.893978372216225, 51.57532028853893, 56.56774319708347, 53.888461366295815, 57.815657034516335, 52.25622095167637, 51.68603494763374, 55.043762773275375, 61.23048819601536, 57.35697604715824, 58.16763214766979, 57.3570254445076, 53.892739936709404, 53.76417003571987, 55.04362218081951, 57.32646748423576, 58.57156567275524, 57.01079562306404, 57.400764897465706, 54.86319646239281, 50.09030297398567, 46.237602308392525, 48.492978885769844, 46.85279689729214, 45.93492574989796, 46.73910699784756, 47.99286492168903, 48.557731211185455, 48.58937971293926, 48.88004511594772, 48.903619050979614, 54.265203550457954, 66.48080706596375, 61.58904455602169, 62.744623348116875, 64.93950337171555, 67.17897400259972, 64.59235399961472, 65.01150190830231, 58.101553693413734, 65.71959391236305, 65.45494571328163, 65.01041516661644, 60.844474509358406, 58.46329428255558, 58.852792382240295, 63.88074338436127, 67.72045254707336, 71.1316891014576, 65.30214071273804, 74.0897923707962, 66.45874544978142, 81.00165948271751, 33.485946357250214, 0.10451403752085753, 0.45742375950794667, 1.5229882020503283, 1.7427450162358582, 0.3965256147785112, 0.07248734473250806, 33.31725440919399, 78.70621785521507, 50.463119968771935, 65.17958968877792, 45.94398446381092, 26.57199315726757, 24.359316788613796, 38.95391754806042, 57.7149548381567, 61.87945917248726, 51.21468544006348, 2.2667344054207206, 0.041300674056401476, 0.032468946010340005, 0.07366456164163537, 0.007753068348392844, 0.0485809201200027, 0.03167480346746743, 0.03287707528215833, 0.04136411283980124, 0.09767651223228313, 0.014711413423356134, 0.07932160457130522, 0.03818986559053883, 0.006950430069991853, 0.23946942907059565, 0.13335653085960075, 0.146930604823865, 0.13779804721707478, 0.13762784306891263, 0.08582404276239686, 0.087432825966971, 0.20525422442005947, 0.16517734446097165, 0.2284020627848804, 0.12579352653119713, 0.2209881113958545, 0.3514247661223635, 30.292806699872017, 104.47543948888779, 80.77128544449806, 94.10482317209244, 53.379319086670876, 22.834939286112785, 30.97234133630991, 45.94672031700611, 62.36106812953949, 90.41387602686882, 7.972011175006628, 0.4084656131453812, 0.9247458691243082, 7.28284215554595, 6.096162982285023, 17.01911386102438, 9.904441181570292, 9.275293741375208, 61.496701911091805, 85.92674240469933, 79.16774109005928, 79.14723739027977, 70.78420534729958, 72.52888932824135, 78.20927292108536, 75.6171128153801, 71.77367985248566, 73.43416795134544, 74.84060928225517, 78.55769142508507, 76.36558145284653, 72.89319097995758, 75.2955436706543, 71.48564770817757, 72.27731242775917, 73.67241516709328, 69.60209637880325, 60.865662172436714, 54.49302792549133, 53.4118415415287, 53.11682537198067, 54.71321851015091, 51.09595701098442, 55.19871845841408, 54.993571266531944, 56.21204428374767, 52.92182743549347, 52.261061891913414, 51.42096497118473, 51.07298344373703, 50.020743906497955, 48.60142506659031, 59.7705989331007, 66.68620124459267, 67.78957083821297, 66.56404539942741, 66.84925809502602, 67.98899173736572, 64.01357665657997, 63.729287311434746, 57.93177880346775, 62.966987416148186, 62.23320499062538, 62.57688134908676, 65.21915316581726, 66.30562126636505, 67.06555768847466, 67.99722969532013, 62.612694427371025, 64.11823824048042, 63.86360630393028, 67.08124324679375, 65.47997877001762, 67.49653056263924, 40.486823692917824, 50.27059189975262, 66.58104568719864, 55.535334795713425, 60.489341765642166, 55.39783917367458, 60.80087944865227, 55.77560730278492, 61.479834616184235, 55.22598959505558, 55.278791561722755, 56.79362967610359, 63.18822294473648, 59.312962889671326, 60.68110607564449, 59.19858902692795, 56.749126464128494, 55.38803189992905, 59.8341429233551, 60.16802340745926, 60.425197407603264, 59.904762133955956, 59.927006140351295, 58.433541879057884, 52.573165744543076, 48.181691989302635, 49.06510278582573, 49.738894030451775, 48.38123828172684, 48.777256831526756, 50.082030817866325, 51.64299085736275, 51.1867493391037, 50.5479846149683, 51.38593465089798, 56.97073437273502, 67.90897563099861, 64.49568718671799, 65.16468688845634, 68.36201012134552, 71.12300276756287, 67.65996739268303, 68.59991535544395, 60.777791887521744, 69.06485840678215, 67.83286571502686, 68.58196511864662, 65.01378178596497, 62.8836502879858, 63.40336360037327, 66.81149572134018, 72.48196184635162, 72.9582054913044, 68.74002903699875, 77.14853703975677, 70.2278696000576, 82.99776837229729, 34.90364268422127, 0.37419682543259114, 7.187858177348971, 4.819538360461593, 2.0116398436948657, 0.46469796448946, 0.1329594076378271, 41.79787874221802, 84.9290831387043, 63.681402280926704, 71.83124676346779, 48.41176584362984, 29.062250331044197, 25.757303573191166, 43.12670163810253, 67.40070730447769, 70.7315781712532, 63.4626442193985, 2.7781152399256825, 0.10044737253338099, 0.18773097486700863, 0.18448158516548574, 0.12370170908980072, 0.15862167201703414, 0.22968099103309214, 0.14918958360794932, 0.08255091917817481, 0.1529569923877716, 0.10749714463599958, 0.22476123471278697, 0.13462741422699764, 0.07652929620235227], [0.07347941806074232, 0.035725326742976904, 0.09050562905031256, 0.0726669147843495, 0.07360682255239226, 0.055543604903505184, 0.02014390287513379, 0.021251228026812896, 0.058937353460351005, 0.09581317979609594, 0.0504980100231478, 0.050881696661235765, 0.4127469740342349, 48.31250376999378, 69.95840325951576, 57.97241762280464, 47.14453004300594, 24.626672342419624, 36.489039212465286, 35.74799157679081, 31.97418987751007, 67.270967066288, 55.66443286836147, 0.10141953403945081, 0.08351831609616056, 0.7134247804060578, 1.732320156879723, 3.156387316994369, 3.5867301374673843, 1.526020795572549, 15.144929978996515, 71.88024893403053, 77.77282074093819, 72.29904726147652, 70.6079176068306, 70.03404200077057, 67.6823253929615, 69.00638714432716, 70.52318215370178, 69.84298065304756, 65.77839195728302, 69.75221872329712, 68.98388475179672, 69.08270984888077, 66.55748695135117, 69.27868813276291, 65.60886785387993, 65.95320537686348, 64.91597503423691, 65.93403920531273, 59.83113348484039, 48.78847002983093, 50.000111013650894, 49.971958324313164, 49.16186459362507, 49.245159924030304, 48.84123019874096, 49.106672555208206, 50.04009626805782, 47.86581873893738, 47.14753568172455, 46.11239902675152, 46.374410167336464, 44.218994826078415, 47.52842724323273, 59.30471733212471, 61.83972850441933, 63.83324593305588, 60.44644206762314, 60.43080970644951, 60.43433591723442, 59.934126958251, 57.92966231703758, 61.40376269817352, 53.59836973249912, 53.192429915070534, 59.64138686656952, 60.69588728249073, 61.53808169066906, 59.68094654381275, 63.624515533447266, 56.00293390452862, 60.692691653966904, 54.29841376841068, 64.19809475541115, 55.01277543604374, 63.896390944719315, 28.320338241755962, 38.56097683310509, 65.82642138004303, 53.508170172572136, 57.213472947478294, 52.24721543490887, 53.91990847885609, 50.59944525361061, 49.76620316505432, 49.3772978335619, 49.7853921353817, 49.49245065450668, 58.16127508878708, 52.85195678472519, 56.906403824687004, 56.22453421354294, 54.08107303082943, 54.647485837340355, 53.459308594465256, 56.564186587929726, 57.34393134713173, 54.704554975032806, 55.67845031619072, 54.73286345601082, 48.2530103623867, 44.29610028862953, 45.11925771832466, 44.36065122485161, 43.33806149661541, 45.585040524601936, 44.78856526315212, 46.03500097990036, 46.44276849925518, 46.464921310544014, 46.510070487856865, 51.529658138751984, 60.944108963012695, 58.79464790225029, 62.26730816066265, 61.245706379413605, 63.345367312431335, 64.24158722162247, 60.42053125798702, 57.180011942982674, 61.57062694430351, 56.422009617090225, 56.58880166709423, 55.64770996570587, 54.46503862738609, 56.618637666106224, 64.86767962574959, 66.64270117878914, 64.16961908340454, 67.21409931778908, 66.44385024905205, 66.19844421744347, 64.41976726055145, 74.13732782006264, 11.021946016699076, 1.043418904300779, 1.1470972909592092, 0.5259588116314262, 0.3629943140549585, 0.21861672692466527, 6.62958643399179, 60.211135894060135, 56.402946040034294, 37.82444715499878, 37.20791503787041, 34.83810380101204, 19.86262857913971, 27.20004055649042, 41.617179438471794, 50.83828143775463, 53.24447572231293, 6.211233157664537, 0.31666663591749966, 0.04872341247391887, 0.13056341354968026, 0.025675224133010488, 0.050086656119674444, 0.035332801126060076, 0.055739613526384346, 0.013052036156295799, 0.0047043563063198235, 0.10287309705745429, 0.03450437878200319, 0.04112557915505022, 0.05249223504506517, 0.014773006114410236, 0.011017724027624354, 0.041419540139031596, 0.0952962294104509, 0.009511674470559228, 0.025074071527342312, 0.03894169829436578, 0.05274977142107673, 0.02977699270559242, 0.07281231635715812, 0.08172205154551193, 0.034317895624553785, 0.3098532749572769, 62.59649209678173, 75.60179963707924, 64.88034054636955, 61.47078350186348, 38.742451295256615, 40.35546474158764, 33.66244688630104, 38.61554570496082, 74.5722296833992, 57.644951194524765, 0.2161824083304964, 0.034368068518233486, 1.93806474795565, 2.918579690158367, 5.958962794393301, 6.636620806530118, 0.507091695908457, 17.94586893171072, 74.55005407333374, 80.64513981342316, 76.05005398392677, 74.2475751042366, 72.45871469378471, 70.95800042152405, 68.78419786691666, 73.18104073405266, 71.16403296589851, 68.70001718401909, 71.46275013685226, 73.42920541763306, 71.59959599375725, 69.79853823781013, 69.73113745450974, 68.17464977502823, 68.31841886043549, 67.88151830434799, 68.17862436175346, 63.01424168050289, 50.61412386596203, 53.00466299057007, 50.43090149760246, 52.40911714732647, 49.566311091184616, 50.1821668446064, 52.722098752856255, 51.92434675991535, 49.65166211128235, 50.70726066827774, 47.626826763153076, 48.041274324059486, 45.527800396084785, 50.08445128798485, 62.37627871334553, 62.47730389237404, 65.48743396997452, 62.670918703079224, 63.75621646642685, 62.36398257315159, 62.2006369382143, 61.123698726296425, 58.92292141914368, 55.993491411209106, 52.35653556883335, 60.49043610692024, 62.91499860584736, 64.6822951734066, 62.304029390215874, 65.28042867779732, 59.84303444623947, 62.88911059498787, 61.020762249827385, 65.04763036966324, 58.13259802758694, 63.89844283461571, 34.777706041932106, 41.98995463550091, 67.75762215256691, 57.44905270636082, 59.211542531847954, 55.330088809132576, 56.0653455555439, 53.345728889107704, 51.45024240016937, 53.53769838809967, 51.194196939468384, 52.750088050961494, 61.16019956767559, 55.12553058564663, 59.36446152627468, 59.237259551882744, 55.10927505791187, 57.09852911531925, 56.64933621883392, 60.43169125914574, 60.718306079506874, 58.541520684957504, 59.347727224230766, 56.23958520591259, 49.73076246678829, 46.23961240053177, 46.378802731633186, 46.14937864243984, 46.047962084412575, 49.49074074625969, 46.802020221948624, 47.76026800274849, 48.96661967039108, 47.91502229869366, 49.20272760093212, 53.98182235658169, 62.968419939279556, 61.2554794549942, 64.20601353049278, 64.63381737470627, 65.32361716032028, 64.42552015185356, 60.86229555308819, 58.67224507033825, 62.84674286842346, 59.02540571987629, 58.536934331059456, 57.06454373896122, 55.44425368309021, 59.920694679021835, 68.25050890445709, 70.91152891516685, 65.32951444387436, 69.30361479520798, 68.72818127274513, 67.42765545845032, 66.80775672197342, 79.9112319946289, 16.594190262258053, 0.8243944414425641, 0.9708048007450998, 1.603638636879623, 1.1281899805180728, 0.23413555434672162, 6.052981624379754, 64.70535233616829, 65.0540292263031, 43.34230586886406, 41.57352738082409, 34.16744738817215, 25.067817270755768, 32.083004638552666, 48.41119587421417, 57.12603583931923, 64.44469392299652, 9.157671052962542, 0.42497364920563996, 0.0871796126011759, 0.1442639940069057, 0.03887359140207991, 0.09749351345817558, 0.029396298778010532, 0.024137286345649045, 0.04745886704768054, 0.044712620074278675, 0.037728821189375594, 0.03461482519924175, 0.025534791238897014, 0.031221336394082755, 0.17464404663769528, 0.12067478557582945, 0.1726934895850718, 0.22685033589368686, 0.15764108713483438, 0.18414971156744286, 0.08459733202471398, 0.18446531728841364, 0.15920743433525786, 0.14369786891620606, 0.1341141597367823, 0.11825437482912093, 0.8060412481427193, 74.36407685279846, 86.81960329413414, 75.94883501529694, 66.20980560779572, 39.13430146872997, 53.943007439374924, 55.737065970897675, 48.46186615526676, 82.5511859357357, 66.03841960430145, 0.5076910543721169, 0.12395393539918587, 1.634508774150163, 7.499304665252566, 9.255089275538921, 8.848651684820652, 3.970731357112527, 23.078046441078186, 76.7815451323986, 84.504015147686, 79.07195582985878, 77.57816478610039, 76.27466753125191, 73.65831032395363, 72.91907519102097, 76.44072622060776, 74.515460729599, 70.19647568464279, 73.83007630705833, 74.58922997117043, 73.06178793311119, 74.38122153282166, 72.47118562459946, 71.21139362454414, 70.88409438729286, 72.97902077436447, 72.13839188218117, 66.58951163291931, 52.69515059888363, 54.60211627185345, 54.87705051898956, 54.551487788558006, 52.98326253890991, 54.025835394859314, 54.46614816784859, 54.266662672162056, 52.3076131939888, 52.897649332880974, 49.49652023613453, 51.73332720994949, 47.521762400865555, 52.04902186989784, 64.45405662059784, 65.6009490787983, 67.2310084104538, 64.28222984075546, 67.38496854901314, 66.30255103111267, 65.37049144506454, 63.98273751139641, 60.8932600915432, 58.48816014826298, 54.40454587340355, 60.10995112359524, 68.87535497546196, 65.4767033457756, 64.961496591568, 69.04218882322311, 63.41910995543003, 66.37913972139359, 63.63942213356495, 69.11189988255501, 60.90505085885525, 66.7974516749382, 37.2417788207531, 44.62000630795956, 68.7166602909565, 61.849417984485626, 60.815721452236176, 59.7742011398077, 60.21876208484173, 56.419471353292465, 54.99821461737156, 55.8552510291338, 54.51603189110756, 54.56213481724262, 65.53941518068314, 56.91493436694145, 59.7619353979826, 60.99145442247391, 59.420778304338455, 60.763318464159966, 59.17568385601044, 63.38455080986023, 63.757113218307495, 61.2834307551384, 60.61209797859192, 58.724173083901405, 52.624402195215225, 49.764299467206, 50.363261327147484, 48.000095933675766, 50.03159612417221, 51.59966178238392, 49.56290267407894, 50.55671654641628, 52.417362704873085, 50.85971228778362, 50.8763287961483, 55.502964332699776, 64.94074210524559, 63.985838145017624, 66.10479444265366, 66.270070374012, 67.74740070104599, 68.50028470158577, 62.80497170984745, 62.03841224312782, 66.04944661259651, 62.44650274515152, 61.275762766599655, 61.46892920136452, 59.3153415620327, 64.20864298939705, 71.20044261217117, 74.4096440076828, 69.12856578826904, 71.868986338377, 73.8171038031578, 70.57575613260269, 68.64699482917786, 82.3257364332676, 18.983082175254822, 1.7795139807276428, 7.594235446304083, 2.4387288512662053, 1.20532073546201, 0.35166008630767465, 9.341661930084229, 73.31327363848686, 70.25120034813881, 51.19974844157696, 50.18797293305397, 45.31262934207916, 30.198408365249634, 38.704548329114914, 58.6999835819006, 66.0216473042965, 75.80452635884285, 12.68722090870142, 0.614068127470091, 0.29409415496047586, 0.24179402855224907, 0.11823884909972548, 0.1589892726042308, 0.15014454955235124, 0.13896174961701035, 0.21705870662117377, 0.09842930230661295, 0.24879352014977485, 0.12612437596544623, 0.17900748905958608, 0.1514830722589977], [0.0742896503652446, 0.027213625762669835, 0.03318214992759749, 0.025350556788907852, 0.04249996614817064, 0.023637243939447217, 0.06761296332115307, 0.07783396955346689, 0.016431374060630333, 0.009214933215844212, 0.08972877112682909, 0.03814060182776302, 2.1048419550061226, 61.59448966383934, 63.165279775857925, 66.06448620557785, 34.932821318507195, 21.044703349471092, 37.038379535079, 38.21254312992096, 37.54066318273544, 86.92245617508888, 19.35253445059061, 0.23068398877512664, 0.08832586710923351, 0.7058982155285776, 1.408056600484997, 7.774420827627182, 2.687995950691402, 0.6296998949255794, 27.43708323687315, 80.10710388422012, 73.96002933382988, 71.93308889865875, 69.3990808725357, 69.8319460451603, 71.06326997280121, 69.78156074881554, 70.95810681581497, 68.49741205573082, 67.0100274682045, 74.53815311193466, 71.11272811889648, 68.61106395721436, 69.89259839057922, 67.54124656319618, 66.08872130513191, 65.07356777787209, 65.9009125828743, 63.32608334720135, 64.77748766541481, 54.23862777650356, 46.035605147480965, 48.99845816195011, 50.29326528310776, 48.097328916192055, 47.748534232378006, 48.81135620176792, 50.50001218914986, 49.44369547069073, 48.154234662652016, 46.241538897156715, 47.11171120405197, 45.45233264565468, 52.86840610206127, 60.567340180277824, 59.05058316886425, 60.54460220038891, 62.445674389600754, 60.62068931758404, 62.54874765872955, 58.994881957769394, 57.17851482331753, 53.60197953879833, 59.43475775420666, 49.633077308535576, 57.66387037932873, 56.80365353822708, 60.811442881822586, 60.3068071603775, 62.853092327713966, 53.6231330037117, 58.89407716691494, 54.64065000414848, 62.81781502068043, 56.37349382042885, 68.61135274171829, 23.127728775143623, 24.81473945081234, 61.52720287442207, 53.84959705173969, 62.24705524742603, 51.394309401512146, 54.93592455983162, 48.863409608602524, 53.60826440155506, 49.106072187423706, 52.1223883330822, 51.08484260737896, 58.81533779203892, 55.691122636199, 53.27032193541527, 56.03109039366245, 53.77140484750271, 52.59176194667816, 54.71042566001415, 55.50288453698158, 57.27137804031372, 56.690541207790375, 59.16015408933163, 56.77803531289101, 51.40835724771023, 46.96133427321911, 43.14833767712116, 44.25081051886082, 43.76795142889023, 43.71558263897896, 45.004868656396866, 45.20449474453926, 47.2963622957468, 46.941050961613655, 44.78546462953091, 50.50848953425884, 57.96741709113121, 59.47704568505287, 58.93253870308399, 61.197049990296364, 59.991131499409676, 60.39845064282417, 58.98585744202137, 58.14652428030968, 55.30485436320305, 54.53815430402756, 52.930414974689484, 53.169748932123184, 55.142249688506126, 62.2862159460783, 63.544070050120354, 67.22296804189682, 63.787967562675476, 66.69057860970497, 63.25928673148155, 65.35594582557678, 66.19413524866104, 71.34747952222824, 56.61660097539425, 1.3976338785141706, 0.7503630733117461, 2.390144420787692, 0.26468017080333084, 0.016178223777387757, 0.07955661305459216, 33.60535494983196, 69.37244430184364, 50.33262737095356, 44.89670746028423, 43.49478028714657, 28.38821589946747, 25.46866536140442, 35.57185582816601, 49.74387176334858, 53.124721348285675, 17.609571777284145, 0.8903172228019685, 0.07526916655478999, 0.07898169351392426, 0.06437460935558192, 0.04745757942146156, 0.03224985659471713, 0.04482500720769167, 0.034314247968723066, 0.03621895513788331, 0.0553954944916768, 0.10228847022517584, 0.02220916070655221, 0.041748719741008244, 0.09711705162771977, 0.031189550209091976, 0.062759272987023, 0.03821140271611512, 0.03953071493015159, 0.0072190360424428945, 0.041365797515027225, 0.09171125537250191, 0.015165708919084864, 0.04182941345789004, 0.05468282863148488, 0.019106204163108487, 4.661783650517464, 74.83280450105667, 70.81782594323158, 75.71429640054703, 40.89954614639282, 23.47156472504139, 30.133023373782635, 37.35297605395317, 45.073682963848114, 93.46365317702293, 21.50251228362322, 0.337180636706762, 0.20150510215898976, 2.4381313333287835, 3.2834050012752414, 9.585072118788958, 4.027340719476342, 2.067071981728077, 30.558843724429607, 81.5624637901783, 76.56607389450073, 74.37989920377731, 72.69230335950851, 72.78716906905174, 73.13120260834694, 72.51210942864418, 73.80525603890419, 72.91252434253693, 68.54883849620819, 73.95084142684937, 73.60132858157158, 71.14989012479782, 70.74805408716202, 71.738470941782, 69.61614042520523, 68.10708940029144, 68.02297711372375, 66.45653396844864, 67.9115442931652, 56.000958010554314, 48.950242549180984, 51.30915217101574, 52.286231741309166, 50.968249663710594, 50.55805027484894, 49.817006438970566, 53.88008661568165, 51.35880030691624, 48.60016733407974, 47.05008991062641, 48.62179957330227, 47.72564426064491, 56.09881415963173, 63.212340250611305, 60.97878210246563, 63.15905191004276, 64.72522526979446, 62.90215149521828, 64.81518924236298, 61.82125009596348, 60.29243253171444, 56.322272568941116, 58.97120922803879, 52.9744204133749, 57.4584686011076, 58.66762451827526, 62.34994612634182, 62.57340833544731, 63.13120700418949, 55.840439423918724, 60.272859781980515, 58.86096954345703, 64.16791677474976, 58.71394783258438, 67.10319846868515, 30.33532451838255, 29.739560186862946, 59.44550357758999, 57.49692253768444, 64.61044862866402, 57.49692253768444, 56.081300899386406, 53.7590479105711, 54.37836527824402, 51.264523565769196, 56.498723700642586, 54.966440722346306, 60.60990549623966, 58.62766966223717, 55.92043273150921, 59.22664292156696, 58.05172696709633, 54.705626517534256, 55.599349960684776, 58.5678418725729, 58.45411777496338, 58.60559284687042, 59.554413333535194, 59.79737609624863, 53.63990530371666, 49.408003985881805, 44.817732498049736, 47.7945763617754, 45.323059782385826, 46.29709951579571, 46.03243991732597, 46.92952238023281, 48.32672260701656, 48.35386075079441, 48.37083823978901, 52.581259310245514, 60.3773807734251, 63.665994107723236, 61.55533656477928, 61.34584240615368, 61.09849847853184, 62.14057736098766, 61.79364837706089, 60.41478976607323, 57.920728996396065, 55.919855162501335, 54.72562864422798, 55.53567297756672, 58.66352453827858, 64.91246402263641, 67.67051562666893, 67.6245304942131, 66.93368196487427, 68.4390851855278, 67.7184310555458, 65.7076321542263, 70.23896500468254, 72.61726498603821, 65.09675413370132, 1.8356398190371692, 0.9111943119205534, 1.7926023784093559, 1.1938518821261823, 0.2137465460691601, 0.12148008259828202, 33.54234293103218, 75.7089614868164, 58.04954968392849, 44.5560747385025, 30.238281525671482, 30.59186965227127, 34.44662220776081, 44.06130328774452, 57.04193115234375, 63.96347254514694, 27.14670281857252, 1.0180847137235105, 0.12018896828521974, 0.014220409448171267, 0.09436897526029497, 0.11081114571425132, 0.052725610803463496, 0.005639043993141968, 0.02365394597291015, 0.01740397714456776, 0.029746126783720683, 0.033147736539831385, 0.010326281735615339, 0.09971475403290242, 0.21461004973389208, 0.21870839700568467, 0.14091741264564916, 0.13270284718601033, 0.1629974934621714, 0.14741898252395913, 0.15216155850794166, 0.24636225920403376, 0.14075379876885563, 0.18764365377137437, 0.22471125848824158, 0.3696358826709911, 6.647446425631642, 90.259680300951, 79.68705162405968, 85.17757460474968, 49.811800718307495, 31.767769753932953, 48.474644869565964, 56.49294801056385, 53.10430884361267, 102.99568489193916, 23.27961042523384, 0.4997165291570127, 0.2784228161908686, 4.067685529589653, 6.779994238168001, 19.522594325244427, 9.617337137460709, 2.16221293900162, 34.07377101480961, 86.32844164967537, 78.12285035848618, 77.83607214689255, 76.33981123566628, 75.82151904702187, 77.79162973165512, 75.29376536607742, 77.30327993631363, 75.56350529193878, 69.2993514239788, 76.18433877825737, 78.06767731904984, 73.9801150560379, 75.69893762469292, 74.64962393045425, 71.53297036886215, 70.93407690525055, 73.21234345436096, 69.79966297745705, 72.72678270936012, 58.49214993417263, 51.92938908934593, 53.25706824660301, 54.13883753120899, 52.06243135035038, 53.77963900566101, 54.48436439037323, 56.14116668701172, 55.69349370896816, 52.20875009894371, 51.67818836867809, 51.379687786102295, 49.83149506151676, 57.47719019651413, 67.21653878688812, 65.25894463062286, 65.98053351044655, 67.56246462464333, 65.08070379495621, 67.63444036245346, 65.18946155905724, 60.19326165318489, 60.06733641028404, 57.619910538196564, 53.0043476074934, 59.482692182064056, 59.31058041751385, 65.05244091153145, 65.8943921327591, 67.96268954873085, 57.54463657736778, 63.76935616135597, 61.39764882624149, 66.55109569430351, 62.1140243858099, 71.2686337530613, 29.972461089491844, 31.439340077340603, 62.670215740799904, 60.11316575109959, 67.10336565971375, 58.74405361711979, 59.167388901114464, 54.85692299902439, 58.13379876315594, 53.59579727053642, 58.575813844799995, 55.62526077032089, 64.20162096619606, 60.23886300623417, 58.81680451333523, 63.36957201361656, 60.26165418326855, 58.2298120111227, 57.93831445276737, 62.1757672727108, 60.2147077023983, 61.6155481338501, 63.01414668560028, 61.89134493470192, 57.011107206344604, 51.025919169187546, 47.0502533018589, 49.970012828707695, 49.526641219854355, 47.136368080973625, 48.73371496796608, 50.08282117545605, 51.56588539481163, 50.11124365031719, 48.96352283656597, 55.13806611299515, 63.29565457999706, 66.36163786053658, 64.60859432816505, 65.38912564516068, 64.89716604351997, 66.20637059211731, 65.20691782236099, 63.81932348012924, 61.3468873500824, 60.12601666152477, 58.23019579052925, 58.62044245004654, 60.96973858773708, 67.44946628808975, 70.04661172628403, 71.09616860747337, 70.17064467072487, 71.14553555846214, 68.65084782242775, 69.37391102313995, 74.88339498639107, 74.68632236123085, 67.78575584292412, 1.9699222384952009, 3.5855783242732286, 8.19476567208767, 1.417896409984678, 0.26361088443081826, 0.23762658733176067, 41.2635438144207, 81.75347194075584, 65.68304747343063, 63.085651248693466, 54.54492174088955, 38.53442765772343, 37.94135168194771, 53.017703890800476, 67.13039740920067, 76.42365753650665, 33.775832802057266, 1.1411523912101984, 0.31803604681044817, 0.13436841953080148, 0.11471301681012847, 0.21678500255802646, 0.1613491983152926, 0.11980319992289878, 0.12590544240083545, 0.17976865055970848, 0.15042551181977615, 0.20457710372284055, 0.10308497279766016, 0.39168048882856965], [0.035253754977020435, 0.01651339993259171, 0.05949836515355855, 0.01656578628171701, 0.1240208993840497, 0.04150228218350094, 0.07777035265462473, 0.03327390535559971, 0.07094450134900399, 0.035000337520614266, 0.09815260738832876, 0.25288949254900217, 18.198619969189167, 73.16723987460136, 61.90726228058338, 51.444858089089394, 29.41210325807333, 32.408707961440086, 65.48817113041878, 40.244575291872025, 52.822462767362595, 76.29782348871231, 3.376046405173838, 0.09853078357991762, 0.14901853341143578, 2.3941869288682938, 0.9354918112512678, 1.7707758746109903, 3.375102155841887, 4.46008762344718, 41.75522223114967, 82.62582913041115, 70.972371250391, 76.5188880264759, 70.91101974248886, 74.1169685125351, 71.22007235884666, 73.16217854619026, 75.2327710390091, 71.54620125889778, 64.84257817268372, 73.58375832438469, 68.12243297696114, 70.11778950691223, 65.28481364250183, 66.35124161839485, 65.41405990719795, 66.05725899338722, 66.07062667608261, 64.30483102798462, 65.00442668795586, 56.93584464490414, 47.8272470086813, 49.300804138183594, 48.92734877765179, 49.39921125769615, 49.67148184776306, 49.011985436081886, 48.30656088888645, 48.489061295986176, 45.24029262363911, 44.52244274318218, 45.73397733271122, 48.95043633878231, 56.99888326227665, 60.289548486471176, 58.69181402027607, 60.89372746646404, 62.34053783118725, 59.779213070869446, 59.23509746789932, 56.01422689855099, 64.81200501322746, 55.7880250364542, 52.64292240142822, 59.72954213619232, 54.74046304821968, 57.83790864050388, 59.12518836557865, 60.49496166408062, 59.44496400654316, 54.19667802751064, 56.04558281600475, 54.83711466193199, 62.69618734717369, 57.04277090728283, 63.919227719306946, 19.432054683566093, 18.196885362267494, 53.707302287220955, 46.927664279937744, 57.66501411795616, 56.17754213511944, 58.787739872932434, 52.11422637104988, 54.66439113020897, 51.83253988623619, 52.19484284520149, 51.396262496709824, 56.61646418273449, 53.52059170603752, 57.14447245001793, 57.11227297782898, 52.9188521951437, 48.73316779732704, 49.736853539943695, 50.95482878386974, 54.8540997505188, 55.67731037735939, 57.413866594433784, 56.691399961709976, 55.07810913026333, 47.992678731679916, 44.31686617434025, 43.04526060819626, 45.024384409189224, 42.95998938381672, 45.72257414460182, 42.13370472192764, 45.95231741666794, 45.70908486843109, 44.85466651618481, 44.8941045999527, 55.451059117913246, 57.48394623398781, 59.49583187699318, 58.654275834560394, 57.44133152067661, 55.836426839232445, 57.728584706783295, 53.59644703567028, 53.689165860414505, 51.589238941669464, 53.02253343164921, 55.51199644804001, 61.44398733973503, 63.34017679095268, 66.33843630552292, 67.29751244187355, 66.63773104548454, 64.015833735466, 60.75629264116287, 57.98559531569481, 65.72625875473022, 63.64505723118782, 73.55741053819656, 24.029076509177685, 0.8579164801631123, 1.9452334195375443, 1.7044618329964578, 0.5195908877067268, 0.14525406353641301, 6.181397633627057, 63.99830907583237, 60.41652247309685, 52.37303428351879, 63.69845576584339, 27.869712822139263, 13.200495466589928, 32.66905479133129, 46.96737214922905, 52.57628917694092, 43.80679674446583, 4.5345118548721075, 0.45200394408311695, 0.030933809830457903, 0.06456336719566025, 0.0073898037589970045, 0.08717295553651638, 0.06510505336336792, 0.049332366907037795, 0.03521858830936253, 0.1440031290985644, 0.074466615478741, 0.045004265557508916, 0.0708660414966289, 0.09937298760632984, 0.09755090373801067, 0.10160406905924901, 0.02063364241621457, 0.06235973778530024, 0.06854210994788446, 0.0419275773310801, 0.10335577506339177, 0.08191741449991241, 0.02771217088593403, 0.20694923034170642, 0.189799785730429, 26.769198775291443, 87.30901703238487, 66.87699660658836, 63.513063713908195, 37.92097717523575, 41.84129141271114, 45.10292239487171, 43.662541285157204, 61.45412139594555, 81.87881961464882, 4.287366941571236, 0.1449111319379881, 0.3776748856762424, 3.463056511245668, 1.9492840021848679, 4.641831396147609, 3.709651166573167, 5.500719733536243, 44.195911064743996, 83.9868400990963, 72.071872651577, 76.82402685284615, 74.31580424308777, 76.55339017510414, 74.65582519769669, 77.36241236329079, 74.05417308211327, 74.43058848381042, 66.77207663655281, 72.71910712122917, 68.03300857543945, 73.17012012004852, 70.14527723193169, 69.24402639269829, 67.71004870533943, 69.5066075026989, 68.84078443050385, 67.1609477698803, 69.04949963092804, 59.28819201886654, 50.76606251299381, 50.51811061799526, 51.0023832321167, 50.945526883006096, 50.58827385306358, 50.55018089711666, 49.73589979112148, 51.56413368880749, 47.474264949560165, 48.12792107462883, 47.80353628098965, 51.946860551834106, 59.3742536008358, 64.03917208313942, 60.926572903990746, 62.896858379244804, 63.54078322649002, 61.977642104029655, 61.25326797366142, 61.75999358296394, 65.75491681694984, 60.72372078895569, 55.34908778965473, 59.76022928953171, 56.2204722315073, 60.059535428881645, 61.41511268913746, 63.61145183444023, 60.79416900873184, 57.91928507387638, 57.07509957253933, 58.2987555116415, 62.46712803840637, 60.528966039419174, 61.76223166286945, 24.892806261777878, 25.439650118350983, 51.61497876048088, 50.54358445107937, 58.27426962554455, 57.10117757320404, 61.05277933180332, 56.00107580423355, 56.18264526128769, 55.99419817328453, 55.651631355285645, 54.099547639489174, 57.81808890402317, 56.042968556284904, 58.40857341885567, 60.564972907304764, 54.44663621485233, 52.09895879030228, 52.91101321578026, 53.240649327635765, 58.65172237157822, 57.686395570635796, 58.851420655846596, 59.72350426018238, 57.80356228351593, 50.46821169555187, 46.307328566908836, 44.769505485892296, 46.907624155282974, 46.47989630699158, 47.6166433095932, 45.58263145387173, 46.99591241776943, 47.91390895843506, 48.30835439264774, 48.66448648273945, 55.668886229395866, 59.794123470783234, 62.18001924455166, 60.000194013118744, 57.66985885798931, 58.45933489501476, 59.75143276154995, 56.26814067363739, 56.34629487991333, 53.56154590845108, 55.9005293995142, 58.3996856957674, 65.5741985142231, 65.49305006861687, 70.33930242061615, 68.55038121342659, 69.29296776652336, 66.18863314390182, 63.82393643260002, 61.580764800310135, 68.67299303412437, 66.3279564678669, 79.41482663154602, 30.993622094392776, 0.743084920104593, 1.9610917498357594, 1.589070693589747, 1.013419039081782, 0.24344842415302992, 5.662191594019532, 67.55904480814934, 68.36875095963478, 55.03221519291401, 44.02286075055599, 22.368558011949062, 23.37259903550148, 41.202150508761406, 53.670299872756004, 60.13126038014889, 57.29651369154453, 6.88948156312108, 0.40147247433196753, 0.04554316867142916, 0.06388009409420192, 0.019138392963213846, 0.05238544741587248, 0.1295455134822987, 0.05850405796081759, 0.03613625391153619, 0.06625645095482469, 0.05241327795374673, 0.01709914369712351, 0.044013965962221846, 0.14584880584152415, 0.12369028001558036, 0.25697480770759284, 0.17506444361060858, 0.15756902459543198, 0.15599809092236683, 0.3124861477408558, 0.11195485465577804, 0.20667018281528726, 0.20750860188854858, 0.31247926061041653, 0.42200565221719444, 33.49353834986687, 99.89980101585388, 74.97273579239845, 72.34787464141846, 43.60540755093098, 46.00972853600979, 84.86143916845322, 59.76799987256527, 66.29234477877617, 92.20416516065598, 5.344008067622781, 0.25207897822838277, 0.38915988814551383, 8.077485915273428, 8.099836315959692, 10.412496719509363, 9.175601340830326, 6.664794869720936, 47.05151483416557, 89.5518010854721, 75.65438121557236, 81.16280123591423, 74.48804140090942, 79.37641829252243, 78.86117354035378, 79.45467129349709, 78.79745855927467, 76.357411891222, 70.7675014436245, 71.80545374751091, 71.06734335422516, 76.00185737013817, 70.73051422834396, 71.25575244426727, 71.66528686881065, 73.26020568609238, 71.42948672175407, 71.22734516859055, 72.08698064088821, 63.501804918050766, 53.33823189139366, 53.65454591810703, 53.51177617907524, 54.213906303048134, 54.223949164152145, 53.107329681515694, 52.8776928037405, 53.347153812646866, 49.53707166016102, 50.24523966014385, 51.51069715619087, 54.91613142192364, 62.711755111813545, 65.66863104701042, 65.12576177716255, 66.206796169281, 65.16942903399467, 65.224928855896, 65.55481195449829, 62.15315468609333, 68.40051725506783, 60.88188350200653, 58.895771875977516, 60.85833616554737, 58.638233095407486, 63.63125637173653, 63.05950865149498, 65.34461483359337, 65.8576937019825, 60.49892105162144, 60.009944289922714, 59.97207932174206, 67.51875177025795, 64.44472432136536, 68.45187529921532, 25.21298088133335, 26.523564755916595, 54.69333037734032, 49.984034076333046, 59.402417689561844, 61.00355677306652, 65.44957280158997, 59.128672778606415, 58.937489837408066, 57.69513890147209, 58.32972764968872, 56.608442813158035, 61.955808475613594, 58.14807079732418, 61.06366954743862, 63.76340568065643, 58.04791957139969, 55.1230189204216, 54.50862608850002, 57.0034696161747, 60.642511546611786, 60.95227092504501, 62.42653101682663, 62.02083818614483, 60.64036086201668, 52.865381464362144, 49.85234834253788, 48.43440882861614, 49.7566656768322, 49.01300758123398, 50.94628304243088, 47.83382445573807, 50.94383217394352, 50.60393661260605, 48.78723509609699, 51.78620137274265, 59.649564027786255, 62.80043475329876, 65.47377750277519, 63.82635310292244, 59.788704961538315, 60.92081241309643, 63.31966169178486, 58.65772224962711, 59.033218100667, 57.85800576210022, 58.470346704125404, 60.507109612226486, 69.0179993212223, 67.64528498053551, 72.14780777692795, 73.7669312953949, 71.63716077804565, 69.09959614276886, 66.56839236617088, 64.90151301026344, 72.76870205998421, 70.53978726267815, 81.23881235718727, 34.07378241419792, 0.9702622017357498, 6.707273265346885, 4.826254500076175, 1.6112162615172565, 0.23988837143406272, 8.17024178802967, 77.565997838974, 73.50334703922272, 70.91147571802139, 82.14964628219604, 37.240490689873695, 23.110453002154827, 48.4717608243227, 65.70362716913223, 69.44017186760902, 68.36700305342674, 8.36405798792839, 0.620502547826618, 0.3165777266258374, 0.17342668696073815, 0.1146710706234444, 0.1561908860458061, 0.26747726602479815, 0.1989621776738204, 0.13081237440928817, 0.16477328957989812, 0.16242495621554554, 0.09524030858301558, 0.1408977754181251], [0.05086992990982253, 0.04610496704117395, 0.05635348839859944, 0.030766785785090178, 0.16453449614346027, 0.07447641924954951, 0.05681032482243609, 0.04719881108030677, 0.04098695710126776, 0.050379218155285344, 0.09348627965664491, 0.3332588018383831, 25.590370930731297, 67.51562833786011, 60.19693985581398, 47.10863716900349, 20.8521543815732, 22.66361217945814, 48.79942484200001, 40.38713984191418, 74.99080002307892, 44.168898314237595, 0.22269840555964038, 0.044347472285153344, 0.3446641570189968, 2.588953315280378, 1.983242779970169, 3.021533265709877, 1.1424937192350626, 8.37473351508379, 51.49466961622238, 78.47227960824966, 70.27964562177658, 73.59397977590561, 69.06539797782898, 73.5168819129467, 70.47453716397285, 74.95993047952652, 68.68173256516457, 73.2471115887165, 59.21508774161339, 71.02980896830559, 71.35728299617767, 67.86287650465965, 68.63515466451645, 66.37531712651253, 66.15709483623505, 64.13431137800217, 67.00175911188126, 62.34974853694439, 64.25075992941856, 56.7775147408247, 49.49854172766209, 48.94866183400154, 48.89010697603226, 47.71750129759312, 47.434116303920746, 47.720662727952, 49.4938375800848, 47.323238253593445, 47.556268349289894, 44.54277165234089, 44.98647004365921, 51.88183084130287, 59.59183752536774, 63.20931941270828, 61.892009899020195, 59.162175580859184, 60.67526958882809, 54.778404012322426, 58.520264625549316, 61.73090994358063, 58.01960349082947, 60.57240530848503, 56.92874662578106, 53.95551636815071, 57.1813190728426, 57.64482960104942, 62.4627772718668, 58.44106927514076, 56.379125118255615, 49.67778190970421, 56.732183173298836, 53.9949544519186, 60.04566237330437, 56.79950416088104, 60.19241809844971, 18.277450539171696, 19.40656755119562, 58.596583530306816, 54.75808650255203, 58.96451398730278, 52.87721402943134, 57.557844668626785, 57.50619783997536, 58.18582937121391, 54.17811222374439, 55.23701660335064, 52.81822979450226, 54.25466291606426, 55.54433651268482, 53.66116136312485, 55.46402782201767, 51.314551681280136, 48.07879351079464, 50.11789329349995, 47.66313761472702, 49.63845022022724, 54.087046310305595, 55.66829726099968, 55.42112052440643, 55.20115412771702, 52.821459621191025, 43.48843842744827, 43.79028283059597, 42.088095769286156, 44.57945488393307, 45.60742512345314, 42.95634537935257, 42.91528098285198, 45.83876430988312, 45.69478243589401, 46.21547609567642, 46.48577079176903, 58.91919381916523, 56.604464426636696, 59.1946866363287, 54.5758330821991, 56.35669872164726, 54.61782082915306, 51.84876501560211, 49.13020849227905, 52.64020174741745, 54.23250250518322, 58.910161703825, 61.52168557047844, 64.46017429232597, 61.48123674094677, 65.6873032450676, 65.1711617410183, 64.53013613820076, 58.739471063017845, 57.17645153403282, 61.02676212787628, 65.82602620124817, 69.292663782835, 60.251808911561966, 1.9335847883485258, 3.4508000314235687, 2.002692986279726, 0.2584921137895435, 0.028384998258843552, 0.10838121321285143, 35.26802413165569, 71.74084961414337, 54.54460255801678, 52.27096416056156, 47.400047332048416, 17.89190612733364, 21.055658161640167, 37.24223479628563, 49.040651097893715, 56.93575344979763, 15.696019157767296, 1.2344867829233408, 0.04013698278868105, 0.14137191872578114, 0.046163659790181555, 0.09599496886949055, 0.0634510065719951, 0.04669042878958862, 0.054898314920137636, 0.013607732216769364, 0.009098838127101772, 0.039543401944683865, 0.025873956437862944, 0.05643718039209489, 0.04303832378354855, 0.053210125624900684, 0.026049019797937945, 0.15091760025825351, 0.007761209244563361, 0.02623947901156498, 0.05456260812934488, 0.05950222061073873, 0.08984879867057316, 0.11828987175249495, 0.30816040642093867, 37.769562900066376, 75.92257082462311, 66.85977593064308, 54.48418200016022, 27.027869895100594, 22.322521582245827, 40.60229949653149, 46.54331110417843, 80.7974736392498, 49.510632678866386, 0.09990691090933979, 0.14199502591509372, 2.0000324165448546, 5.875336406752467, 4.0231395699083805, 5.346004860475659, 0.8727435814216733, 10.080525632947683, 54.62425768375397, 81.77292689681053, 72.0911680161953, 76.4106622338295, 72.15285390615463, 76.01101487874985, 72.69033506512642, 78.1651496887207, 73.79152357578278, 75.48735737800598, 62.76965640485287, 71.92702442407608, 71.453607827425, 71.06762453913689, 70.78102111816406, 69.84089836478233, 67.812240421772, 65.76278239488602, 68.8632184267044, 65.49778461456299, 65.96293285489082, 60.63942611217499, 51.33739985525608, 51.2728451192379, 49.904044568538666, 50.587700083851814, 48.083702847361565, 49.009154587984085, 52.35936261713505, 50.50671882927418, 48.27960893511772, 48.159843161702156, 47.22219027578831, 54.25389535725117, 60.23146480321884, 64.38908010721207, 64.24208879470825, 61.08803763985634, 63.170090317726135, 57.39189237356186, 61.75121605396271, 63.224738985300064, 60.94697780907154, 62.54942402243614, 58.576953783631325, 57.55451984703541, 58.45255225896835, 59.75042201578617, 64.64732944965363, 63.14361713826656, 58.61484535038471, 53.98562215268612, 58.81654232740402, 56.62109233438969, 60.82034960389137, 60.85341162979603, 61.002101451158524, 24.26242768764496, 25.049203969538212, 59.01559464633465, 57.82033458352089, 59.10805508494377, 55.92473030090332, 58.20437617599964, 60.37006616592407, 59.073997512459755, 55.151809975504875, 55.736526399850845, 56.59027598798275, 57.009606286883354, 58.34628336131573, 55.643169209361076, 56.83159723877907, 53.1027889251709, 51.237810999155045, 52.649921625852585, 51.19113050401211, 51.21639534831047, 57.03824155032635, 56.62646144628525, 59.24789138138294, 58.76924626529217, 53.83135803043842, 45.39385378360748, 45.315349996089935, 44.430202692747116, 46.81067615747452, 47.07360304892063, 45.99245086312294, 45.69098263978958, 47.085397616028786, 48.4396867454052, 47.83982813358307, 49.34964291751385, 59.2367921769619, 58.530201092362404, 61.041273549199104, 56.36768013238907, 58.78758408129215, 56.022928431630135, 54.487704411149025, 50.493237152695656, 54.0901355445385, 57.68586739897728, 61.56711973249912, 63.20451647043228, 67.59060591459274, 64.67066019773483, 67.38800078630447, 68.70108872652054, 67.64789164066315, 61.1271945387125, 59.52427335083485, 63.84840711951256, 69.80140328407288, 70.61901301145554, 70.2437299489975, 2.6349807204678655, 3.6651923647150397, 1.3224983727559447, 1.2221166654489934, 0.3037040471099317, 0.13803114095935598, 35.86934946477413, 79.09114480018616, 59.05143812298775, 47.975579649209976, 34.86513935029507, 24.945670925080776, 27.941880449652672, 46.793702468276024, 55.848749577999115, 66.93719297647476, 25.298385098576546, 1.264246548525989, 0.09178717707982287, 0.05576313960773405, 0.0369991527259117, 0.03351067272888031, 0.0743415932811331, 0.056665201555006206, 0.043833290110342205, 0.0688798539340496, 0.059573155085672624, 0.04690737710916437, 0.03617358022893313, 0.26544796710368246, 0.12330668614595197, 0.2620603301329538, 0.09109265301958658, 0.3629402263322845, 0.2035415850696154, 0.1667229857412167, 0.12914997845655307, 0.10043267800938338, 0.20340961636975408, 0.25479155767243356, 0.4058550641639158, 50.802878737449646, 88.08996632695198, 77.06712260842323, 65.31961977481842, 31.003936640918255, 33.44677425920963, 65.73941364884377, 55.01182168722153, 86.51795268058777, 55.04007697105408, 0.5909271910786629, 0.23994029208552092, 2.1734425239264965, 10.34232398495078, 6.75961023196578, 10.318723451346159, 8.24980191886425, 11.589209977537394, 57.786372005939484, 84.49814826250076, 76.66169196367264, 79.5173679292202, 75.12950778007507, 79.54894423484802, 75.34168839454651, 80.59949666261673, 77.87679076194763, 75.13474389910698, 67.57807418704033, 71.56922042369843, 71.95239946246147, 74.00511011481285, 72.20165848731995, 73.73898759484291, 71.42865836620331, 69.55509290099144, 71.8141096830368, 68.03360894322395, 69.06646952033043, 63.31870034337044, 52.97345906496048, 54.112402349710464, 52.499548494815826, 54.0138204395771, 49.54951599240303, 51.67332462966442, 56.32555179297924, 53.831874802708626, 50.063088834285736, 50.77541761100292, 50.37300020456314, 58.80403719842434, 63.318825736641884, 68.75721171498299, 66.87212526798248, 65.54098069667816, 65.56773886084557, 60.82618989050388, 63.88575151562691, 64.84649196267128, 63.11927944421768, 64.68688532710075, 62.33189329504967, 60.28396278619766, 59.95926260948181, 60.60415640473366, 67.59251341223717, 64.48585331439972, 60.90352714061737, 55.086054503917694, 62.00489804148674, 59.23800811171532, 65.5588473379612, 64.43385690450668, 64.74018886685371, 22.80539207160473, 25.669431388378143, 61.90528258681297, 61.8475066870451, 63.06663326919079, 56.989102587103844, 61.826923191547394, 62.167126536369324, 62.64403514564037, 56.63460060954094, 59.753606244921684, 59.61207903921604, 59.48927342891693, 59.61173325777054, 59.148378521203995, 60.67551277577877, 58.08567814528942, 54.929746091365814, 55.93641087412834, 53.40388096868992, 53.580715879797935, 60.3270448744297, 59.043504148721695, 62.62766942381859, 60.48779904842377, 58.16299259662628, 47.882366850972176, 48.412681594491005, 45.20529270172119, 50.644066259264946, 50.923849046230316, 48.87022644281387, 48.712504506111145, 49.920987859368324, 51.53374291956425, 52.14753158390522, 51.375770196318626, 65.345329195261, 60.97982704639435, 65.52597150206566, 59.1578172147274, 62.062837332487106, 61.03034533560276, 59.157862812280655, 52.357979491353035, 59.11640703678131, 60.808114260435104, 63.805879801511765, 66.14786133170128, 71.92095994949341, 67.0547054708004, 72.29985281825066, 69.22725409269333, 72.10648119449615, 63.93838629126549, 63.93688157200813, 66.06567934155464, 72.63802707195282, 72.21599131822586, 74.53170865774155, 2.9006349155679345, 7.919474244117737, 4.9749381467700005, 1.125670715700835, 0.414127932745032, 0.14767034794203937, 45.708522498607635, 84.2027597129345, 67.12066233158112, 69.44087862968445, 63.34591828286648, 28.097086921334267, 32.40763261914253, 57.90354251861572, 64.73953530192375, 79.14370357990265, 32.01372675597668, 1.8578930874355137, 0.2703140809899196, 0.24413513339823112, 0.24133975995937362, 0.19314137985929847, 0.11192165096872486, 0.21509833837626502, 0.11582148857996799, 0.1979698074865155, 0.17654434544965625, 0.15517059626290575, 0.1307630809606053], [0.037724334906670265, 0.07431759964674711, 0.008848505221976666, 0.04341293024481274, 0.05519481775991153, 0.08176425006240606, 0.027476431387185585, 0.07119021160178818, 0.012713855230686022, 0.12486247258493677, 0.0960389114334248, 1.2908485648222268, 45.653957426548004, 70.54009884595871, 63.186220452189445, 47.031056731939316, 25.315377786755562, 49.65060576796532, 50.987484231591225, 46.65876030921936, 84.89556133747101, 15.961659103631973, 0.10905735427513719, 0.19390668254345655, 1.0704179992899299, 2.024118136614561, 0.9056428098119795, 2.9764315858483315, 2.5905098067596555, 14.070173799991608, 61.26998707652092, 75.48075333237648, 70.46417891979218, 75.0031341612339, 70.85792139172554, 69.30813655257225, 67.72472351789474, 70.9841126203537, 69.21472236514091, 75.17500653862953, 64.10599529743195, 55.75525559484959, 73.26180920004845, 63.46668720245361, 69.15277048945427, 64.49070185422897, 68.81115362048149, 62.563559263944626, 64.25006836652756, 62.70885966718197, 63.52106608450413, 57.19334162771702, 49.41019266843796, 47.23046623170376, 48.464039638638496, 46.703776493668556, 49.010131135582924, 48.412381410598755, 45.53715169429779, 46.1513165384531, 48.08876417577267, 45.26223264634609, 46.253774240612984, 51.69176124036312, 59.74608264863491, 58.47708374261856, 54.76540111005306, 57.76454217731953, 57.96406947076321, 54.298501163721085, 64.66392695903778, 57.19423457980156, 62.05464877188206, 56.95151500403881, 60.81738196313381, 54.755791425704956, 53.79087120294571, 55.380637496709824, 58.44800390303135, 54.63565707206726, 56.90488010644913, 50.547019466757774, 53.21688160300255, 49.108652248978615, 59.46819595992565, 56.08649142086506, 61.345831006765366, 19.27483431994915, 25.444204173982143, 65.21790683269501, 56.27524249255657, 59.756019115448, 57.370210736989975, 56.27620004117489, 54.99253772199154, 58.083314672112465, 56.218203753232956, 56.679126620292664, 55.375982746481895, 53.87762054800987, 52.988050282001495, 55.38741633296013, 55.42372718453407, 49.46413077414036, 49.80624541640282, 48.24963994324207, 49.904789328575134, 50.329948514699936, 51.42869375646114, 50.63830576837063, 53.34116913378239, 52.2103688120842, 53.64650554955006, 47.29375563561916, 41.70702941715717, 43.96551042795181, 44.7411248087883, 43.631842732429504, 43.82431000471115, 43.467277362942696, 45.61097793281078, 44.54130493104458, 45.77648185193539, 45.772184282541275, 52.81459338963032, 56.75110995769501, 52.868744283914566, 55.744338780641556, 51.88218042254448, 48.6437775939703, 47.36472062766552, 50.61835303902626, 52.13564582169056, 56.14935524761677, 57.64751985669136, 62.02743463218212, 61.28074809908867, 60.80915540456772, 66.14071771502495, 61.5344300866127, 59.93590526282787, 55.505210012197495, 56.33252061903477, 59.49961647391319, 66.65277063846588, 65.48949345946312, 74.32779639959335, 20.303374528884888, 3.751484309323132, 0.9732144058216363, 0.4342645069118589, 0.36727353755850345, 0.6093978218268603, 8.680501207709312, 63.630637004971504, 63.35964694619179, 47.200888618826866, 44.076517671346664, 25.818649381399155, 26.992180310189724, 37.56167225539684, 38.64019498229027, 54.10958290100098, 36.52102969586849, 4.591970471665263, 0.39051329833455384, 0.006304833950707689, 0.061305027193157, 0.02399968660029117, 0.11100837888079695, 0.09883238497423008, 0.05375775268475991, 0.08086877467576414, 0.021896039324929006, 0.05210770235862583, 0.04207421086903196, 0.04637271907995455, 0.0381513629690744, 0.09313286893302575, 0.0985661766026169, 0.03781760060519446, 0.04332126016379334, 0.010844583757716464, 0.0468108311179094, 0.04877859115367755, 0.10314749131794088, 0.08210177140426822, 2.2116371244192123, 67.9951474070549, 76.72359824180603, 74.99863520264626, 54.06109370291233, 34.14513498544693, 41.82466350495815, 52.74316102266312, 54.87600177526474, 91.86287507414818, 16.979147605597973, 0.39066193567123264, 0.33143199048936367, 2.795132389292121, 3.7119115702807903, 3.5981677612289786, 2.920828931964934, 1.6994897997938097, 16.515952460467815, 63.4745679795742, 77.81483128666878, 75.82527324557304, 76.6287325322628, 74.31999921798706, 73.59483852982521, 71.76431715488434, 74.2982491850853, 72.62117117643356, 76.43597647547722, 66.43971607089043, 57.9068673402071, 72.45847150683403, 66.53114676475525, 69.69321548938751, 67.87012651562691, 69.40110236406326, 66.3578836619854, 67.25155770778656, 64.75308537483215, 65.89814633131027, 59.509712532162666, 52.10400491952896, 49.214229583740234, 50.902015417814255, 48.88038709759712, 49.65594448149204, 49.88996632397175, 49.1305922716856, 47.666812017560005, 52.0233428478241, 47.56317637860775, 49.25508499145508, 55.667727291584015, 61.27597935497761, 62.30855114758015, 56.7661989480257, 59.534665793180466, 58.905039578676224, 58.210672438144684, 65.47672614455223, 60.296897292137146, 62.495421320199966, 59.83280539512634, 63.50115895271301, 57.43215501308441, 56.22794263064861, 59.17031854391098, 59.790935441851616, 57.82175190746784, 56.689538061618805, 53.46231423318386, 54.448851495981216, 52.16731712222099, 60.834990218281746, 60.31686522066593, 60.475354716181755, 23.873868137598038, 32.067277282476425, 66.29797607660294, 59.741405099630356, 60.846822783350945, 60.97158908843994, 59.07451808452606, 57.83521458506584, 59.5611085742712, 59.799124002456665, 58.5657861828804, 58.4718856215477, 56.227463856339455, 57.223223224282265, 59.53356385231018, 57.65585660934448, 52.688261568546295, 50.45802064239979, 50.38357883691788, 53.25668826699257, 52.19998776912689, 51.91107027232647, 54.1144048422575, 54.724800288677216, 54.526439532637596, 55.06517082452774, 49.70113925635815, 44.62797828018665, 44.96418423950672, 47.00426056981087, 45.73205463588238, 46.51419326663017, 45.761757642030716, 47.99862541258335, 46.73352889716625, 49.455056861042976, 47.4857023358345, 55.14118954539299, 58.41214142739773, 55.54042652249336, 56.43500491976738, 53.03997449576855, 52.057111635804176, 51.29467874765396, 51.74126498401165, 54.63842712342739, 58.88457007706165, 61.56740091741085, 65.00144764780998, 64.74582016468048, 63.870673924684525, 68.56953218579292, 64.85516309738159, 61.732357665896416, 55.87252490222454, 59.33184027671814, 61.47627800703049, 67.69783616065979, 66.57361328601837, 78.48957628011703, 26.56208898872137, 3.669911711476743, 2.786514451727271, 2.0986328506842256, 0.8244568412192166, 0.49349264125339687, 8.44850655645132, 66.61862567067146, 70.88610827922821, 51.317697912454605, 40.05324795842171, 23.08281898498535, 37.347071170806885, 47.34141267836094, 47.881903275847435, 61.08988434076309, 49.19421225786209, 5.811810465529561, 0.3264258778654039, 0.03400781148229726, 0.021232679901004303, 0.0720221665687859, 0.07328958410653286, 0.03018716102815233, 0.02814989329635864, 0.04947015404468402, 0.10765943748992868, 0.04159807118412573, 0.03556096700776834, 0.15560595493298024, 0.15439328562933952, 0.19040309241972864, 0.21663320367224514, 0.13242188491858542, 0.191731195372995, 0.11018190838512965, 0.2860479976516217, 0.10494166301214136, 0.2883948170347139, 0.27724861982278526, 4.414376076310873, 82.17429175972939, 89.32384371757507, 82.30817377567291, 62.76351973414421, 37.351771518588066, 65.79185843467712, 71.47816970944405, 59.967352375388145, 102.83961966633797, 20.58875061571598, 0.4022493842057884, 0.3627054998651147, 5.090142739936709, 6.133153047412634, 5.571170803159475, 12.61331107467413, 6.567788925021887, 19.654848128557205, 67.93381869792938, 81.66169926524162, 78.62370908260345, 81.26544892787933, 76.47687748074532, 75.61585128307343, 73.42890903353691, 75.81208035349846, 75.56122541427612, 79.52397957444191, 69.6395243704319, 64.72750514745712, 71.22896388173103, 66.95175379514694, 72.54577562212944, 67.79710203409195, 73.49639341235161, 68.88642758131027, 69.56984370946884, 67.7505013346672, 69.58324179053307, 62.35536463558674, 54.67988669872284, 50.61009228229523, 52.132203206419945, 52.2727120667696, 51.175821125507355, 52.81899735331535, 50.73934234678745, 49.39431332051754, 54.25993323326111, 50.76794721186161, 51.33222833275795, 57.71694973111153, 65.7126858830452, 63.94978567957878, 58.02787184715271, 61.91205382347107, 65.1596711575985, 60.76964892446995, 69.37108397483826, 64.79561269283295, 66.52256682515144, 61.79487571120262, 64.05532121658325, 59.55798514187336, 59.62576970458031, 62.235051691532135, 63.937945514917374, 59.18463997542858, 61.00996322929859, 56.62957727909088, 59.554481729865074, 53.34986686706543, 66.10341131687164, 62.73267298936844, 66.17886766791344, 24.351960383355618, 32.07518845796585, 71.15029290318489, 62.19015710055828, 64.64911535382271, 63.400737941265106, 59.43829536437988, 58.4184604883194, 61.376700550317764, 61.04005001485348, 59.17991302907467, 59.564497992396355, 58.36987629532814, 59.47137638926506, 59.830483719706535, 61.204520389437675, 54.678811356425285, 55.38055010139942, 54.07078318297863, 56.466068252921104, 55.286337956786156, 55.136356204748154, 56.18606507778168, 58.129938170313835, 56.75174452364445, 59.017752930521965, 52.603700906038284, 46.53684005141258, 48.07633504271507, 49.157171845436096, 47.55261294543743, 49.82351168990135, 48.87189455330372, 50.12095972895622, 48.83823595941067, 52.34204314649105, 51.475207060575485, 58.071018531918526, 63.4137674421072, 59.626651257276535, 61.996052116155624, 57.60827176272869, 55.07050573825836, 54.458719566464424, 55.63948340713978, 57.87296935915947, 61.85737855732441, 63.01772229373455, 67.98360362648964, 66.99263960123062, 66.5295660495758, 73.03834319114685, 67.91218265891075, 65.68609490990639, 60.284513756632805, 63.521898239851, 64.04642969369888, 72.31684550642967, 70.19636169075966, 84.49743390083313, 28.125530295073986, 4.592848224565387, 11.129380501806736, 3.0681114038452506, 0.9450789936818182, 0.69017851841636, 11.42168266698718, 72.68252268433571, 74.8861612379551, 61.847624480724335, 58.96014042198658, 34.091527462005615, 38.69503363966942, 52.66967296600342, 58.28821487724781, 70.58856144547462, 60.38185313344002, 7.4276376608759165, 0.4919841221999377, 0.09700638998765498, 0.18210735084721819, 0.1465983156231232, 0.22454187070252374, 0.12145683111157268, 0.13014117605052888, 0.2159224933711812, 0.16600158851360902, 0.14482266793493181, 0.1589993212837726], [0.05011162196751684, 0.027453419243101962, 0.05265827574476134, 0.0636142939038109, 0.03446456998062786, 0.011527187070896616, 0.09203920300933532, 0.04356783130788244, 0.03735832993697841, 0.27404717286117375, 0.14448705391259864, 16.849998235702515, 73.12780559062958, 55.98042391240597, 56.339557841420174, 30.00507853925228, 17.873127534985542, 55.35546764731407, 46.24715119600296, 62.09802344441414, 68.52315187454224, 3.4902433399111032, 0.09917067072819918, 0.06779618473956361, 2.1301483595743775, 2.605982101522386, 3.5626209061592817, 2.914388277567923, 1.8227387988008559, 24.631121903657913, 65.79717054963112, 67.05577701330185, 73.16681429743767, 68.15571919083595, 73.26420307159424, 69.31412503123283, 71.14222213625908, 68.03875386714935, 69.05146792531013, 65.47396749258041, 70.24726375937462, 50.92937774956226, 50.78244723379612, 65.19216701388359, 67.88054555654526, 66.38527259230614, 67.04435482621193, 65.57031512260437, 65.61893731355667, 64.35921370983124, 63.53344202041626, 58.75523641705513, 52.1832724660635, 47.65564061701298, 47.40892745554447, 47.24282316863537, 48.065627217292786, 47.76417039334774, 46.74196444451809, 48.45612086355686, 49.934819117188454, 45.886877328157425, 45.980534702539444, 50.45050084590912, 59.53210853040218, 57.16124475002289, 55.64530469477177, 53.547957837581635, 55.37590675055981, 59.96719278395176, 59.38114643096924, 57.76946671307087, 56.702993139624596, 57.89023943245411, 57.59713836014271, 57.20000647008419, 59.00551378726959, 54.805200174450874, 58.22721295058727, 54.326414465904236, 52.44436405599117, 46.7429143935442, 50.47870673239231, 49.72556434571743, 60.334446877241135, 55.31651593744755, 55.82445368170738, 18.246157318353653, 28.59945986419916, 62.460698783397675, 53.62388156354427, 57.38271206617355, 54.609978049993515, 62.26765774190426, 54.88242723047733, 50.91608606278896, 51.21403567492962, 60.44982768595219, 58.114613592624664, 55.69279074668884, 53.101105615496635, 52.33777977526188, 52.95377232134342, 53.13771665096283, 51.276587918400764, 53.34583908319473, 52.68607668578625, 53.02973784506321, 50.55540181696415, 51.02702111005783, 51.33976712822914, 52.11497113108635, 51.242518946528435, 47.34179265797138, 42.72593334317207, 43.193445056676865, 44.676361083984375, 45.11147193610668, 43.46923805773258, 43.0513820797205, 44.98100973665714, 46.173271760344505, 45.68673826754093, 43.954373225569725, 49.03709828853607, 49.99099910259247, 49.732650965452194, 50.454794615507126, 50.587529093027115, 47.423636466264725, 47.53520607948303, 48.7911830842495, 53.54219734668732, 54.95787978172302, 56.8348802626133, 58.41066710650921, 60.78433893620968, 60.07267892360687, 56.82164177298546, 54.97755512595177, 52.73389331996441, 52.92854167521, 56.845941469073296, 57.906434163451195, 62.55744159221649, 64.96685430407524, 72.4394117295742, 50.80136641860008, 0.8192969555966556, 1.3399317185394466, 2.599866329692304, 0.3054758801590651, 0.07771145581500605, 0.11513476449181326, 42.42411933839321, 71.88907966017723, 56.788667142391205, 48.61195050179958, 45.73801651597023, 17.103359140455723, 22.440719939768314, 43.22162054479122, 47.93421506881714, 51.11851640045643, 22.324149794876575, 0.41648909042123705, 0.038134753704071045, 0.07202235952718183, 0.042129935027332976, 0.1481411515851505, 0.058588317697285675, 0.05777827092970256, 0.030542853855877183, 0.015267102990037529, 0.028003133593301754, 0.05727466807002202, 0.09707069708383642, 0.00885565952557954, 0.09174625505693257, 0.055147865787148476, 0.017106051236623898, 0.0228516082643182, 0.09538548009004444, 0.018737132268142886, 0.009051892648130888, 0.18844766687834635, 0.20175048586679623, 26.17264598608017, 85.13383135199547, 64.73553031682968, 63.25741723179817, 37.946485206484795, 23.63397181034088, 44.294071197509766, 55.97654812037945, 66.6190056502819, 76.12594351172447, 3.0455026170238853, 0.08065016765613109, 0.6512485980056226, 2.7599678887054324, 5.747735928744078, 4.749588388949633, 1.1413499806076288, 2.246744865551591, 27.406776063144207, 69.79371249675751, 70.75626164674759, 76.00223734974861, 72.40837499499321, 73.72701823711395, 70.73330327868462, 72.40415722131729, 71.71818763017654, 74.05988797545433, 69.77067053318024, 73.19198414683342, 54.43682134151459, 52.69025646150112, 66.53095677495003, 69.41300332546234, 67.7890844643116, 70.0089481472969, 67.10175454616547, 67.33872503042221, 66.72777101397514, 65.65080240368843, 60.54801061749458, 53.32491360604763, 47.649070769548416, 49.181019365787506, 49.09487798810005, 49.350250884890556, 50.01150280237198, 50.56754216551781, 48.828234896063805, 52.152269929647446, 46.6519320756197, 50.04303351044655, 51.52055382728577, 62.569585740566254, 58.81203576922417, 57.427998036146164, 54.135212525725365, 58.97348150610924, 61.150274500250816, 61.81237377226353, 61.17689207196236, 58.546099439263344, 59.86694276332855, 60.0029868632555, 59.36203345656395, 59.76956158876419, 56.866984739899635, 60.07777065038681, 58.09762090444565, 54.01387743651867, 49.83307957649231, 51.24156899750233, 51.813951283693314, 61.764420345425606, 57.392694130539894, 56.568731144070625, 19.4509681686759, 35.323748141527176, 62.5807761400938, 58.92294801771641, 59.23901505768299, 59.09482799470425, 63.215615674853325, 58.65350067615509, 54.98053036630154, 49.651513919234276, 60.662285685539246, 61.905928552150726, 58.07066895067692, 56.6722147911787, 54.5796062797308, 54.61977772414684, 55.67726477980614, 54.16909530758858, 55.06933160126209, 54.64937813580036, 54.95566830039024, 54.08572018146515, 52.3637779802084, 53.81823353469372, 54.7012035548687, 52.72374786436558, 50.59651181101799, 44.45124976336956, 45.581438317894936, 47.338707223534584, 48.721551820635796, 45.02673268318176, 44.73033718764782, 46.553152576088905, 47.82855033874512, 47.726256027817726, 46.92475363612175, 51.109149903059006, 52.76185221970081, 52.41475984454155, 51.93940535187721, 52.66368068754673, 50.40952384471893, 50.31485952436924, 51.936456710100174, 55.49601450562477, 57.353814616799355, 61.704273372888565, 60.58271035552025, 63.97705301642418, 60.99279575049877, 59.3835137039423, 57.75955684483051, 56.30539767444134, 55.88643595576286, 60.73444381356239, 59.58478510379791, 67.72135689854622, 66.8977738916874, 73.89781907200813, 59.03951816260815, 0.5067368899472058, 2.5372487772256136, 1.5630008862353861, 0.9623792278580368, 0.2216537288040854, 0.09021848469274119, 47.047065272927284, 75.81739246845245, 65.28654634952545, 44.47508588433266, 36.96146406233311, 26.38753965497017, 29.70739111304283, 53.40182527899742, 53.56991305947304, 62.28182718157768, 28.567174896597862, 0.4329155496088788, 0.03604047975386493, 0.052197609838913195, 0.04198142756649759, 0.14348810829687864, 0.06741644261637703, 0.034927395536215045, 0.0469839036668418, 0.030987439276941586, 0.031162009108811617, 0.10148505825782195, 0.16381397465011105, 0.10342593770474195, 0.212409537343774, 0.14438912010518834, 0.14792573580052704, 0.09838895173743367, 0.35356927604880184, 0.2840099117020145, 0.1658821917953901, 0.4350538848666474, 0.30403287790250033, 30.70226702839136, 102.66544461250305, 71.5956974029541, 75.70383936166763, 44.821076318621635, 28.807095922529697, 67.40746334195137, 65.22435888648033, 73.80314335227013, 80.37045255303383, 5.212569320574403, 0.24526944675017148, 0.9029033349361271, 8.942898977547884, 11.539891473948956, 11.093214992433786, 11.997408773750067, 4.355210401117802, 33.26741248369217, 71.6570109128952, 72.39991664886475, 79.3676483631134, 74.33722749352455, 78.3598056435585, 74.99653771519661, 76.20115667581558, 74.86210852861404, 74.24914062023163, 69.01232242584229, 73.71628001332283, 58.16479369997978, 56.98321670293808, 66.6671946644783, 74.06840711832047, 70.13950914144516, 72.3237307369709, 69.94802221655846, 71.06808051466942, 68.14876556396484, 69.96564567089081, 64.51127395033836, 55.43334446847439, 51.552795097231865, 52.30121813714504, 51.73039756715298, 51.96734145283699, 51.529350355267525, 53.14362533390522, 53.06524693965912, 54.338334426283836, 48.22367213666439, 52.428853288292885, 55.11832617223263, 65.46602591872215, 61.11286550760269, 59.99585844576359, 56.30792833864689, 60.551012456417084, 67.20891639590263, 64.45304587483406, 62.924813479185104, 60.45937657356262, 63.14302437007427, 61.29953809082508, 59.83021393418312, 62.33419597148895, 61.440122947096825, 61.85508728027344, 60.2249975502491, 56.77145026624203, 51.897064223885536, 54.58868399262428, 53.28201770782471, 66.89478725194931, 61.41499109566212, 61.65710270404816, 21.277830339968204, 34.952158480882645, 67.16143414378166, 62.27535992860794, 63.80545422434807, 58.5208535939455, 66.85573294758797, 60.80662094056606, 54.889000877738, 52.821718007326126, 63.8692831993103, 64.55900698900223, 58.649225905537605, 58.678613528609276, 59.85007546842098, 58.14478017389774, 58.11444640159607, 57.59734354913235, 58.10367397964001, 57.84300036728382, 57.81375713646412, 56.966113820672035, 55.22766910493374, 56.71335518360138, 57.15377055108547, 55.37440963089466, 52.56756864488125, 47.171003222465515, 48.61826576292515, 50.31446814537048, 50.95105938613415, 46.98007486760616, 48.12459625303745, 48.61402899026871, 51.66853308677673, 51.28885366022587, 49.96666520833969, 53.70620794594288, 55.42473413050175, 56.97659745812416, 55.59102460741997, 56.45449787378311, 53.958358615636826, 52.87809558212757, 55.88822565972805, 58.63542504608631, 61.3650693744421, 63.977486193180084, 64.87323492765427, 66.24616205692291, 65.29608383774757, 61.36413462460041, 62.48937204480171, 59.41657193005085, 58.10754217207432, 61.83211751282215, 63.654321134090424, 69.68563869595528, 71.7890614271164, 74.3716536462307, 65.7910680770874, 0.7775206910446286, 7.864767154678702, 6.950526237487793, 1.3807532843202353, 0.5056212935596704, 0.21996525378199294, 54.105859100818634, 81.78026050329208, 71.79117411375046, 63.59176129102707, 59.16357010602951, 25.38580510765314, 36.00761264562607, 63.348901122808456, 65.38646578788757, 73.90920326113701, 34.63788494467735, 0.835108085302636, 0.16776190343080088, 0.15211360092507675, 0.16624195530312136, 0.24945394252426922, 0.24394686537561938, 0.08613777827122249, 0.13708359649172053, 0.11501665168907493, 0.13616668788017705, 0.21295131999067962], [0.0709080025262665, 0.0712093738547992, 0.014524456219078274, 0.11080774667789228, 0.02321518084499985, 0.041017782205017284, 0.015530531090917066, 0.06243358147912659, 0.11953992303460836, 0.02538336342695402, 1.2608630675822496, 57.52931959927082, 81.57563388347626, 44.00449253618717, 56.43261484801769, 54.05177280306816, 33.300071731209755, 83.29367369413376, 45.63883423805237, 79.90060776472092, 39.69490058720112, 0.49907739157788455, 0.011812649536295794, 0.6983048573601991, 1.3888309383764863, 2.2743969317525625, 4.057846907526255, 0.6374121154658496, 4.178067706525326, 49.85104501247406, 67.61041805148125, 68.14944192767143, 69.60753008723259, 73.0622211098671, 69.1286189854145, 72.04980343580246, 69.22907799482346, 70.92543616890907, 64.69734236598015, 69.27463755011559, 64.78530004620552, 68.93003404140472, 53.70923638343811, 58.15560199320316, 66.98912099003792, 65.90032741427422, 66.33990302681923, 63.55610400438309, 63.73386986553669, 65.30591011047363, 64.63321700692177, 61.27915598452091, 55.26724398136139, 47.3112802952528, 46.409930661320686, 48.00568923354149, 47.839052975177765, 48.00450749695301, 46.42484866082668, 48.4063321352005, 48.225081861019135, 45.683166459202766, 46.11347436904907, 47.487066462635994, 58.06817628443241, 60.44896513223648, 60.25840535759926, 59.41282533109188, 59.41945597529411, 57.224731743335724, 56.73182599246502, 56.68680600821972, 55.89601144194603, 56.907536163926125, 55.6100007891655, 59.76260796189308, 53.036680072546005, 56.34238488972187, 59.404416382312775, 57.40870647132397, 53.94659824669361, 45.939614698290825, 46.974090188741684, 50.40273740887642, 57.41561070084572, 55.354817882180214, 54.16876472532749, 17.98939749598503, 27.289656847715378, 64.16033238172531, 51.4069589227438, 53.26594837009907, 52.70003333687782, 58.167787939310074, 55.656495094299316, 57.48886317014694, 41.04121394455433, 44.63226445019245, 50.175653994083405, 56.08210265636444, 49.78109076619148, 61.87320090830326, 58.78029987215996, 54.446716010570526, 55.77648885548115, 52.29944743216038, 53.40365678071976, 55.53294472396374, 53.22734624147415, 52.38715812563896, 51.44360035657883, 51.162890419363976, 51.38661481440067, 46.53656646609306, 41.94214180111885, 44.48392800986767, 45.18906757235527, 44.86170753836632, 44.99861419200897, 41.13182008266449, 45.18329568207264, 46.885467544198036, 44.803813844919205, 45.19201621413231, 44.35736060142517, 45.89912787079811, 47.567192763090134, 47.39801824092865, 45.87743103504181, 45.06025068461895, 46.955372393131256, 47.16273486614227, 48.79174925386906, 49.22299571335316, 49.92947280406952, 51.2258530408144, 50.039910078048706, 51.983175203204155, 50.00049099326134, 49.10072207450867, 51.40717551112175, 53.04408587515354, 53.342377468943596, 57.53251902759075, 60.954923182725906, 66.02451995015144, 65.42854472994804, 75.71069419384003, 9.10861473530531, 2.4859493924304843, 1.6939620464108884, 0.6589574937243015, 0.28213869023602456, 0.0502512607636163, 11.653745714575052, 66.83468967676163, 60.42588137090206, 52.16290555894375, 44.60357218980789, 18.406189531087875, 15.472525600343943, 31.244910210371017, 42.16112405061722, 51.90548837184906, 43.74533124268055, 3.6582819605246186, 0.19931670161895454, 0.09095864341361448, 0.022990972465777304, 0.06372235060553066, 0.07720050198258832, 0.08428743341937661, 0.028706073608191218, 0.012623430102394195, 0.048784732425701804, 0.06830712372902781, 0.026706215685408097, 0.019695814517035615, 0.04483850687392987, 0.016422755870735273, 0.04089954694791231, 0.019693439644470345, 0.037686604118789546, 0.02922597403085092, 0.012806919621652924, 0.11114223263575695, 1.5478344750590622, 70.67913338541985, 88.18222537636757, 55.837961956858635, 61.79932527244091, 65.92096790671349, 35.5937996506691, 74.66199606657028, 54.54269126057625, 85.57407572865486, 44.30562637746334, 0.18090265220962465, 0.013524039295589318, 1.7460603383369744, 4.0305866952985525, 6.184181934222579, 1.1974000604823232, 0.721860327757895, 6.1486429162323475, 52.29326896369457, 69.56776902079582, 71.29312723875046, 74.68537241220474, 74.26479578018188, 75.84475859999657, 73.58953401446342, 72.58197247982025, 73.16912457346916, 67.51790061593056, 69.11550208926201, 67.18793392181396, 69.8367489874363, 56.36137627065182, 60.25590509176254, 68.5848605632782, 68.33722785115242, 68.92587706446648, 67.17233195900917, 67.65682876110077, 67.89485558867455, 67.77149140834808, 63.60045902431011, 57.91186027228832, 50.79689785838127, 49.243051037192345, 48.829443231225014, 50.40656380355358, 50.82555592060089, 47.97549985349178, 50.283796191215515, 51.206675469875336, 49.31207433342934, 47.865165174007416, 50.922819301486015, 60.76881296932697, 63.0244555324316, 62.587782964110374, 61.1048973351717, 60.12010797858238, 60.89511439204216, 57.90308654308319, 60.74698694050312, 57.67244651913643, 58.15291553735733, 55.32349616289139, 61.0250598192215, 56.6595196723938, 59.02243047952652, 62.192003801465034, 61.16259343922138, 54.606771022081375, 47.522928938269615, 48.55462297797203, 52.62983590364456, 58.99030700325966, 59.15187053382397, 55.10937385261059, 20.33516552299261, 32.68932290375233, 64.83754724264145, 54.39643330872059, 55.30565991997719, 54.5035457611084, 59.0494280308485, 56.86953440308571, 57.91129790246487, 42.88558177649975, 47.03451834619045, 52.62213371694088, 55.35670258104801, 51.697149351239204, 60.628258511424065, 61.68179377913475, 55.987350940704346, 56.093038469552994, 53.905355259776115, 55.765560641884804, 56.316105499863625, 56.56089596450329, 55.316196754574776, 53.14194582402706, 52.96978086233139, 53.57009544968605, 48.66214580833912, 44.44395035505295, 48.644161373376846, 49.160352274775505, 47.46299095451832, 47.41236247122288, 43.81611384451389, 47.53276661038399, 50.254264175891876, 46.88611350953579, 47.95940771698952, 47.385528311133385, 49.534719586372375, 49.70601059496403, 49.954277873039246, 48.13250742852688, 48.34895521402359, 49.58009295165539, 50.069468691945076, 49.17168706655502, 51.994734182953835, 52.43245169520378, 54.049416929483414, 51.89226508140564, 54.75626640021801, 52.846868857741356, 52.41745010018349, 54.983342215418816, 56.07604198157787, 56.99271239340305, 61.59945219755173, 63.09241108596325, 71.59848645329475, 67.78747335076332, 80.8073379099369, 11.078193448483944, 3.124572574160993, 1.8512242077849805, 2.3244761070236564, 0.4823939414927736, 0.19246431853389367, 11.76710408180952, 73.17255958914757, 67.7096839249134, 55.02668268978596, 41.259698420763016, 22.325502522289753, 19.103543311357498, 39.13145922124386, 51.32150150835514, 60.39077125489712, 53.57102259993553, 5.122597748413682, 0.23859071137849241, 0.0572598881990416, 0.020221954546286725, 0.0991068386065308, 0.03650535363703966, 0.03251576068578288, 0.04745343823742587, 0.014635905463364907, 0.0515645244740881, 0.09958197639207356, 0.15424947225255892, 0.17539987951749936, 0.1305926393251866, 0.26199751475360245, 0.13831361720804125, 0.15958082367433235, 0.10213089000899345, 0.18311074934899807, 0.2546153124421835, 0.2881544205592945, 2.123295902274549, 81.77630111575127, 101.39141097664833, 64.32101055979729, 72.57525444030762, 65.84333807229996, 46.587479934096336, 101.22171968221664, 63.87843310832977, 94.26388263702393, 49.18022520840168, 1.1122254934161901, 0.11837720026960596, 3.151163784787059, 6.327045718207955, 10.408001560717821, 12.290337905287743, 6.381023721769452, 6.770424451678991, 59.24471855163574, 70.03770500421524, 75.33839017152786, 74.67602491378784, 78.532073199749, 77.12202966213226, 78.4525890648365, 73.08197245001793, 74.55693170428276, 70.65616741776466, 72.97909677028656, 67.73786321282387, 72.04363256692886, 59.087030813097954, 63.75680923461914, 69.86014813184738, 71.56976759433746, 71.5607088804245, 71.14723026752472, 69.02765840291977, 70.34228146076202, 69.61411893367767, 66.75443798303604, 60.36754310131073, 53.28331343829632, 50.25749020278454, 51.84679292142391, 51.48204669356346, 53.05580444633961, 51.25634640455246, 54.14852321147919, 53.72722461819649, 52.10225321352482, 50.703764855861664, 52.66718029975891, 64.1270537674427, 66.71729117631912, 65.59312149882317, 64.4072051346302, 63.88801619410515, 63.818441927433014, 61.864062398672104, 63.47767621278763, 59.52266223728657, 61.708988919854164, 59.881043806672096, 63.2196244597435, 60.436672791838646, 60.59374496340752, 63.79174456000328, 63.42211179435253, 58.02437983453274, 52.103286758065224, 52.49863274395466, 55.60595400631428, 62.33616426587105, 63.88176932930946, 59.017513543367386, 24.164151661098003, 34.96633931994438, 67.61482581496239, 57.38732881844044, 58.175429329276085, 57.450603023171425, 62.22084045410156, 57.61714048683643, 60.413604229688644, 46.237104535102844, 48.66337314248085, 52.16502204537392, 58.40781345963478, 52.90344022214413, 57.74683892726898, 63.83668094873428, 58.106098249554634, 60.29645651578903, 56.10122703015804, 58.96983750164509, 60.61039187014103, 60.04535458981991, 57.2514633089304, 54.90672692656517, 57.05885164439678, 56.29671514034271, 50.4842734336853, 47.39779405295849, 51.298231557011604, 51.73292823135853, 49.28878918290138, 50.01372188329697, 46.28742143511772, 49.812564477324486, 52.127651050686836, 49.27703261375427, 50.952978283166885, 49.881610572338104, 52.1266783028841, 53.67859102785587, 52.51119486987591, 50.195564925670624, 50.33160142600536, 53.443512842059135, 54.799625873565674, 53.13305430114269, 54.950010403990746, 55.06782308220863, 58.09841126203537, 54.06144708395004, 57.53448732197285, 54.79700021445751, 55.17682783305645, 59.03130680322647, 59.86306697130203, 59.48849067091942, 65.3236323595047, 68.22248160839081, 74.8737359046936, 69.2719092965126, 84.21474426984787, 12.867759671062231, 4.533287845551968, 9.652331359684467, 2.7401958871632814, 0.672396719455719, 0.19201083661755547, 15.581588298082352, 81.13389998674393, 72.82850325107574, 66.99876487255096, 57.49325193464756, 28.21840301156044, 24.989803656935692, 47.72361136972904, 62.30599768459797, 69.44751307368279, 63.03463138639927, 7.493511401116848, 0.46896914311219007, 0.2653814113000408, 0.11706611476256512, 0.11681598873110488, 0.18266425846377388, 0.17162059637485072, 0.21913496864726767, 0.1687749646953307, 0.16305659810313955, 0.37799510755576193], [0.044786775470129214, 0.03894748333550524, 0.01861206368630519, 0.034812511075870134, 0.13045237341430038, 0.014694994333694922, 0.15183210431132466, 0.05468467657919973, 0.2428722206968814, 0.3557819448178634, 9.403554908931255, 73.69985729455948, 63.58045309782028, 40.70522077381611, 58.99883754551411, 43.51004786789417, 36.18126332759857, 58.123866096138954, 47.57899112999439, 83.08205544948578, 19.05297562479973, 0.08769238469540142, 0.09877235264866613, 0.5721304309554398, 1.2563826330006123, 4.708391474559903, 1.7173896892927587, 0.5877614265773445, 32.53981612622738, 72.74084955453873, 63.94375920295715, 69.2915466427803, 68.54004576802254, 70.54990991950035, 68.12607318162918, 70.74645817279816, 71.13052636384964, 70.07569536566734, 67.10895135998726, 68.15085545182228, 67.20226675271988, 66.49874970316887, 66.71459332108498, 66.41133159399033, 64.84121784567833, 64.34079229831696, 63.10821443796158, 63.53847675025463, 65.76987281441689, 64.22937467694283, 64.14536878466606, 64.09144207835197, 62.369423881173134, 54.16811116039753, 45.27068339288235, 46.47671587765217, 46.77854508161545, 49.232802987098694, 45.001661628484726, 47.45224513113499, 47.83251732587814, 48.71017523109913, 47.79846355319023, 43.128821924328804, 48.19068990647793, 60.080107524991035, 57.204425632953644, 60.92288330197334, 58.56629155576229, 57.278430461883545, 58.33945892751217, 55.114404782652855, 54.698851481080055, 54.04518775641918, 55.71516774594784, 53.932451605796814, 55.74953690171242, 57.13056139647961, 58.21007966995239, 53.76889318227768, 53.023927956819534, 45.943988263607025, 46.363546550273895, 47.68553741276264, 57.40475848317146, 55.59410624206066, 55.653561651706696, 17.58096121251583, 28.661404140293598, 63.07845823466778, 53.62958885729313, 48.717607632279396, 46.71460211277008, 52.19835385680199, 53.650054559111595, 55.95892086625099, 57.12487690150738, 53.2863874733448, 51.387336775660515, 43.48266653716564, 50.176125168800354, 60.562290251255035, 52.95927822589874, 56.48584999144077, 55.64897149801254, 56.49149648845196, 54.581095799803734, 56.28863677382469, 55.76880566775799, 57.224294766783714, 57.50886149704456, 52.10319556295872, 49.44565236568451, 46.37031778693199, 42.33874931931496, 44.79304902255535, 44.465540796518326, 43.196807876229286, 42.6112174987793, 43.36113005876541, 44.67303246259689, 45.90075418353081, 46.048117876052856, 45.14050617814064, 48.296514227986336, 45.813636258244514, 44.443665370345116, 45.41399650275707, 45.03810167312622, 45.30779220163822, 46.58227801322937, 47.68314354121685, 47.85172529518604, 48.52221451699734, 47.346682995557785, 46.022237464785576, 47.46169902384281, 46.49502329528332, 46.5742452442646, 48.83630186319351, 51.883514150977135, 57.081912606954575, 58.46364766359329, 61.01907514035702, 66.69928774237633, 66.10426247119904, 67.93293714523315, 70.51125839352608, 40.73365084826946, 1.6568748489953578, 3.262668801471591, 3.3431480079889297, 0.5355360789690167, 0.007304717455554055, 1.7027341132052243, 45.13553984463215, 69.90691602230072, 52.747937366366386, 51.93909376859665, 36.037828624248505, 13.280792757868767, 33.33309955894947, 47.09872730076313, 45.58550789952278, 56.42252258956432, 17.0920205488801, 0.5623822915367782, 0.04930935661832336, 0.028649204687098972, 0.07174910075264052, 0.010414120479254052, 0.1141625658783596, 0.03993410929979291, 0.030950094405852724, 0.026833705524040852, 0.07865710038458928, 0.08668661874253303, 0.06239635535166599, 0.06132725080533419, 0.028704385222226847, 0.17978300369577482, 0.03582070756237954, 0.16407856513978913, 0.11086235390393995, 0.16850308631546795, 0.25715310126543045, 12.075798567384481, 86.26762971282005, 70.77524542808533, 47.593209967017174, 64.68196839094162, 51.81902401149273, 38.7899449467659, 62.747625187039375, 55.156054347753525, 92.57650718092918, 19.159088730812073, 0.08936925994930789, 0.14714575343532488, 1.6071739909239113, 3.871453134343028, 3.719167518429458, 0.3935118718072772, 0.91186159173958, 35.986694768071175, 74.61959034204483, 65.41249439120293, 72.03144282102585, 71.41860410571098, 73.85513976216316, 69.16495263576508, 72.10629120469093, 73.75594228506088, 71.72242820262909, 68.99049639701843, 69.95659455657005, 72.31286332011223, 69.8395000398159, 67.97304779291153, 66.18177071213722, 66.88012763857841, 67.19783619046211, 64.48858916759491, 67.34281361103058, 67.7161131799221, 66.41670450568199, 67.59350895881653, 64.54832956194878, 64.50182005763054, 55.42707100510597, 48.37637834250927, 47.92168714106083, 49.65347841382027, 51.22092470526695, 47.24009111523628, 50.04143759608269, 50.28236746788025, 50.57638809084892, 48.329416662454605, 45.66881462931633, 49.287744238972664, 60.71363613009453, 61.6483061760664, 62.689579501748085, 61.48492254316807, 61.99958212673664, 61.67620427906513, 57.40475468337536, 55.37917457520962, 56.919661313295364, 58.252675384283066, 56.404534354805946, 59.55594465136528, 61.78518243134022, 60.61684772372246, 57.2783088684082, 56.629854664206505, 47.61792004108429, 49.18313965201378, 50.26187516748905, 59.835860431194305, 58.696681559085846, 57.3138103634119, 18.79315696656704, 31.66774772107601, 63.123090639710426, 57.30934180319309, 51.18642255663872, 50.78019015491009, 54.65623676776886, 56.454516872763634, 58.10362458229065, 59.39726896584034, 56.832186207175255, 52.4488478153944, 46.70786127448082, 47.6347341388464, 59.84523452818394, 56.93551406264305, 57.18606501817703, 59.76631656289101, 57.121118903160095, 57.99537219107151, 58.37586097419262, 58.445385843515396, 57.97790452837944, 59.21348422765732, 55.154355838894844, 52.350072115659714, 48.45352180302143, 46.51920139789581, 47.051712423563, 47.763163447380066, 46.09881095588207, 45.280319675803185, 46.18173390626907, 48.58198530972004, 47.0586546510458, 48.40837262570858, 47.02639438211918, 49.40548852086067, 47.12216064333916, 47.135098949074745, 45.84390543401241, 48.0862221121788, 46.93619102239609, 49.50351566076279, 51.37305714190006, 50.19815258681774, 51.012258902192116, 50.63139773905277, 50.02437271177769, 51.36714845895767, 49.88462761044502, 49.65371020138264, 52.54281297326088, 56.28863297402859, 58.53158041834831, 61.620339676737785, 62.897424548864365, 68.69871765375137, 69.10173162817955, 71.0352198779583, 70.50692662596703, 53.336312994360924, 6.069197254255414, 3.3141052164137363, 3.717115866020322, 0.5586912645958364, 0.27081865235231817, 1.659364071674645, 47.63345740735531, 75.70923507213593, 60.40188565850258, 47.8943096101284, 29.203788936138153, 22.32554242014885, 44.309232383966446, 55.14107175171375, 51.79615303874016, 65.37801504135132, 21.987248472869396, 0.5976026610005647, 0.029382184984569903, 0.050889741542050615, 0.05066252932010684, 0.04489207138249185, 0.0757770256313961, 0.052680692315334454, 0.02730759650148684, 0.0964850015589036, 0.04485662269871682, 0.17644059320446104, 0.18347183387959376, 0.3286668669898063, 0.11568393150810152, 0.3080392879201099, 0.11458262146334164, 0.2681984851369634, 0.18945422692922875, 0.42069110088050365, 0.6377434695605189, 15.550759602338076, 96.16219237446785, 81.3815326988697, 57.55311392247677, 75.08316546678543, 53.05841490626335, 47.74045966565609, 74.55271393060684, 61.94163143634796, 100.15002518892288, 24.611921533942223, 0.14916445448761806, 0.399002488120459, 3.6286114901304245, 8.048614114522934, 13.432995490729809, 8.885059431195259, 1.3191435090266168, 41.38079032301903, 75.76025873422623, 66.65176749229431, 73.10213416814804, 74.61116999387741, 76.0202407836914, 70.70778384804726, 75.58387979865074, 76.04505345225334, 74.48358803987503, 73.30112189054489, 72.13706195354462, 73.93804371356964, 72.26341277360916, 72.90186211466789, 70.77254757285118, 70.81459611654282, 70.15613704919815, 67.04143658280373, 69.91044983267784, 70.3585597872734, 69.885713160038, 68.39313045144081, 67.60765179991722, 68.75633776187897, 59.40699644386768, 50.87400332093239, 50.612379759550095, 51.318366676568985, 54.49804365634918, 49.76926200091839, 54.29737642407417, 53.64889182150364, 54.63401176035404, 52.32587121427059, 47.61713348329067, 52.76590660214424, 66.56039759516716, 62.672111839056015, 65.46104058623314, 65.7661946117878, 62.81276509165764, 64.34289738535881, 60.098004564642906, 58.98553065955639, 60.72082534432411, 59.49170149862766, 61.71284571290016, 60.45606315135956, 64.1860494017601, 62.255562990903854, 59.0103205293417, 58.2513340562582, 50.012665539979935, 53.1057907640934, 52.144689336419106, 62.674615904688835, 62.46113955974579, 60.11044889688492, 23.04133091121912, 36.78710661828518, 66.68479532003403, 62.11991786956787, 52.345759347081184, 53.406518027186394, 55.92890627682209, 57.39417985081673, 62.03708231449127, 60.43709456920624, 58.54762315750122, 53.95277291536331, 49.27324801683426, 47.850406765937805, 63.572583720088005, 60.52300415933132, 59.20818731188774, 61.47761933505535, 61.36134937405586, 61.669064462184906, 59.944405406713486, 61.42447918653488, 60.27327015995979, 61.89550571143627, 58.630831092596054, 56.44809901714325, 50.57712905108929, 47.52482123672962, 49.4121989607811, 50.61973996460438, 48.50782468914986, 47.67211273312569, 48.72217498719692, 49.81561951339245, 50.31235545873642, 49.79961857199669, 49.01468709111214, 53.58215980231762, 51.07220068573952, 48.80536012351513, 50.19092157483101, 51.64066918194294, 49.42831389605999, 52.06535339355469, 53.3298609405756, 53.49263660609722, 54.27638255059719, 53.77793289721012, 52.41331212222576, 55.7415497303009, 51.25168785452843, 53.36183622479439, 54.413030818104744, 59.0291029214859, 61.70578949153423, 64.74756047129631, 65.48168107867241, 74.10133615136147, 71.44804492592812, 75.71637868881226, 71.81584239006042, 56.88169755041599, 5.588367255404592, 9.132057577371597, 7.674170807003975, 1.1456517060287297, 0.24720637797145173, 1.9249071227386594, 57.658938243985176, 80.15716999769211, 67.73571252822876, 66.57125741243362, 48.776637464761734, 25.183589458465576, 50.159755647182465, 66.99936524033546, 62.3977817595005, 76.24545469880104, 28.7653798609972, 1.161987860687077, 0.2107594016706571, 0.20157605147687718, 0.22441159409936517, 0.1197703079378698, 0.25096109602600336, 0.17480279202573, 0.09799073013709858, 0.28804767003748566, 0.18033358821412548], [0.09310905341408215, 0.09525508474325761, 0.04534356434305664, 0.04845517061767168, 0.0803413377434481, 0.08262423594715074, 0.06074755554436706, 0.04050535520946141, 0.17344605701509863, 0.019566094524634536, 24.85893487930298, 78.26751619577408, 59.129231348633766, 39.29945580661297, 22.18117106705904, 47.56540685892105, 58.7489477545023, 56.775143668055534, 60.72142191231251, 77.73753583431244, 5.981730222702026, 0.06087634785217233, 0.03787999667110853, 1.3339178287424147, 2.620095256716013, 3.7791404128074646, 0.14226485596736893, 22.876590751111507, 82.90964350104332, 69.65216249227524, 73.30015674233437, 68.65456402301788, 71.14149257540703, 72.08942010998726, 69.09418523311615, 66.50930553674698, 66.6902594268322, 68.29460173845291, 68.08232992887497, 67.60542511940002, 67.62820109724998, 67.04435482621193, 65.28333932161331, 66.52377516031265, 63.46284560859203, 64.20646950602531, 64.77681890130043, 64.42850679159164, 65.71644008159637, 62.76806429028511, 66.53480976819992, 62.517011761665344, 62.368918508291245, 55.05266189575195, 45.54625980556011, 48.09365451335907, 47.870412692427635, 47.474804520606995, 45.26877209544182, 48.72022569179535, 47.27702893316746, 49.469830468297005, 47.634551748633385, 44.94976781308651, 45.59373825788498, 46.2822575122118, 52.59922094643116, 55.18597774207592, 56.724499985575676, 56.802532598376274, 57.2531808167696, 55.40792763233185, 56.73167020082474, 55.60933202505112, 54.91942584514618, 56.59977927803993, 58.618208169937134, 56.802300810813904, 56.12802319228649, 53.50667305290699, 49.20616641640663, 43.19800481200218, 45.81970073282719, 49.77762535214424, 55.06515942513943, 56.34072057902813, 50.770128294825554, 18.835667185485363, 23.985937424004078, 56.312898471951485, 53.5496411472559, 49.54058267176151, 44.98047396540642, 48.21463622152805, 48.927888348698616, 54.78006072342396, 52.1330201625824, 57.73755222558975, 57.31659561395645, 53.415591940283775, 45.90459197759628, 41.13239385187626, 57.67412982881069, 53.19250971078873, 57.117611691355705, 53.42311933636665, 53.483935073018074, 55.48646181821823, 57.89262570440769, 56.293861493468285, 56.58985421061516, 52.37205013632774, 50.58819405734539, 42.999362871050835, 42.6646426320076, 43.51792864501476, 44.388868510723114, 46.318199783563614, 45.52811197936535, 44.29035499691963, 41.95562727749348, 44.49535399675369, 47.47516930103302, 47.74438865482807, 44.87696751952171, 44.60663102567196, 44.491858184337616, 46.614773869514465, 45.715700313448906, 44.94269259274006, 47.380049005150795, 45.992583855986595, 45.799478217959404, 46.03327587246895, 47.43993379175663, 48.793155178427696, 46.35622054338455, 48.3765759319067, 50.36345511674881, 50.03345042467117, 55.66502183675766, 57.36497841775417, 61.12965680658817, 62.49244228005409, 69.02735441923141, 70.28656125068665, 69.8774828016758, 62.85270854830742, 75.32267421483994, 50.62228962779045, 0.9062102856114507, 4.960437174886465, 1.4901453768834472, 0.13504375907359645, 0.14000568422488868, 20.947831347584724, 68.84412065148354, 59.11386117339134, 57.64750465750694, 55.57953782379627, 15.596505347639322, 10.306443460285664, 36.47439859807491, 49.34603311121464, 51.32761538028717, 44.71026286482811, 2.1918826969340444, 0.07890131892054342, 0.041517232748446986, 0.019644251951831393, 0.04566262105072383, 0.023998337746888865, 0.006597994806725183, 0.05079446091258433, 0.04159218224231154, 0.01226703408974572, 0.0715712079545483, 0.012608478609763552, 0.006140067889646161, 0.045620203600265086, 0.17286504444200546, 0.03812051560089458, 0.030311363152577542, 0.048645438728271984, 0.23064839537255466, 0.03066452896746341, 31.490998305380344, 88.54753017425537, 70.79172134399414, 49.67680536210537, 36.00567474961281, 45.08297346532345, 46.13681271672249, 65.64754977822304, 68.2122753560543, 83.6578081548214, 6.304015154018998, 0.09479958418523893, 0.3808332880726084, 2.396545889787376, 4.40303890965879, 0.4269276943523437, 0.17826289229560643, 26.111319176852703, 85.6302823126316, 73.09923112392426, 76.81603208184242, 71.53617739677429, 73.30856949090958, 73.41233432292938, 71.44986882805824, 68.52006644010544, 68.58105316758156, 70.7119408249855, 70.35526156425476, 69.51930642127991, 70.14115825295448, 70.68019732832909, 66.89871624112129, 67.33867183327675, 67.08048328757286, 65.48018395900726, 66.5635134279728, 67.78218403458595, 67.70106598734856, 66.49873450398445, 68.03104028105736, 63.13356287777424, 65.76784372329712, 55.82787349820137, 47.19316363334656, 49.27727200090885, 48.252136409282684, 49.787463024258614, 47.632313668727875, 50.99838964641094, 50.63875414431095, 51.002618819475174, 47.96351529657841, 45.817614644765854, 48.47109965980053, 48.62289771437645, 55.199128836393356, 58.438078835606575, 59.212040305137634, 58.819631561636925, 59.569179341197014, 56.591480523347855, 58.74072879552841, 57.55792446434498, 56.24554328620434, 61.80554933845997, 60.632392689585686, 57.85802476108074, 60.26850141584873, 56.442152336239815, 51.49204395711422, 45.98393552005291, 47.800268456339836, 52.841731533408165, 57.125663459300995, 60.14755390584469, 53.9182023704052, 19.743556268513203, 26.265444606542587, 58.706747218966484, 58.669592812657356, 53.022883012890816, 48.01073916256428, 48.825696632266045, 51.37102045118809, 55.54687477648258, 55.87327726185322, 58.41570943593979, 59.93557088077068, 56.95360869169235, 49.02012079954147, 45.90995728969574, 60.84037832915783, 55.772001296281815, 58.741211369633675, 57.053262144327164, 56.57312750816345, 58.297060802578926, 58.97611476480961, 58.98920886218548, 60.22390700876713, 54.202176332473755, 52.480929493904114, 46.26195900142193, 45.732936188578606, 46.2717092782259, 48.46723146736622, 46.88936613500118, 48.00634279847145, 46.539834290742874, 44.32213269174099, 46.17937423288822, 50.62852889299393, 48.6081925034523, 47.946021035313606, 46.86573140323162, 47.535483464598656, 49.2814289778471, 48.68385784327984, 47.7380657941103, 48.95370036363602, 47.6590870320797, 48.6233688890934, 47.698384523391724, 49.01835009455681, 50.74861764907837, 49.08888950943947, 51.71820402145386, 51.401939392089844, 52.94051483273506, 57.860506027936935, 61.27171218395233, 64.51819717884064, 65.90915814042091, 70.5515818297863, 71.55603513121605, 72.53529578447342, 66.68102592229843, 78.02410885691643, 61.061484664678574, 1.495152439456433, 4.686042973771691, 1.5589264361187816, 0.42318352963775396, 0.16080967179732397, 21.807647310197353, 76.72884196043015, 68.18101823329926, 56.63598373532295, 45.861829072237015, 20.658522471785545, 21.819635666906834, 45.98655357956886, 57.204323038458824, 58.52566033601761, 54.07697305083275, 2.953546126373112, 0.04101555205124896, 0.019305125715618487, 0.023314854988711886, 0.048770709545351565, 0.010928505816991674, 0.02117116699082544, 0.06200853124028072, 0.024411996018898208, 0.05646265832183417, 0.16783381754066795, 0.16862212680280209, 0.13695609552087262, 0.11469740944448858, 0.3280350618297234, 0.1668870894354768, 0.11917732452275231, 0.197202515846584, 0.31997046957258135, 0.06701160848024301, 40.565270483493805, 102.66173601150513, 79.37780141830444, 58.6377277225256, 35.87080858647823, 57.29214012622833, 74.5669935643673, 77.22026199102402, 74.60680022835732, 91.65213838219643, 8.487643506377935, 0.1361883437493816, 0.6700900057330728, 5.35761371254921, 10.775174908339977, 13.704226836562157, 2.720274031162262, 29.075581915676594, 89.13905203342438, 76.39993160963058, 79.15580213069916, 72.22715511918068, 77.19965949654579, 76.51576459407806, 74.62819308042526, 73.44383463263512, 71.97604939341545, 73.07592317461967, 72.88363829255104, 74.35352101922035, 73.21885630488396, 72.86080151796341, 72.02709585428238, 71.3886085152626, 70.69424137473106, 67.85955548286438, 70.26965975761414, 69.32817667722702, 70.19174873828888, 67.83699229359627, 72.61791855096817, 65.68852677941322, 68.49263951182365, 57.54463657736778, 50.534362345933914, 53.29486861824989, 52.28892579674721, 51.405636593699455, 49.42482568323612, 52.672173231840134, 52.59760983288288, 53.14041070640087, 51.80928133428097, 49.63761806488037, 50.41930831968784, 50.478315353393555, 59.6727579832077, 61.08550317585468, 63.693880811333656, 62.445605993270874, 64.61098819971085, 59.68044497072697, 63.67502622306347, 61.49051584303379, 61.04931391775608, 63.61695773899555, 64.39078241586685, 61.30674250423908, 62.638943418860435, 59.81488935649395, 54.50739115476608, 49.89794209599495, 49.582825005054474, 55.1827897131443, 60.5024928599596, 63.1290677189827, 57.093437388539314, 24.94991909712553, 33.59196826815605, 62.0345326513052, 60.683929324150085, 53.805025443434715, 52.1196448802948, 51.25777132809162, 54.993092492222786, 57.88516290485859, 58.20694483816624, 61.40627056360245, 63.47234129905701, 57.02621899545193, 55.310683250427246, 52.70642839372158, 61.67396999895573, 57.24107086658478, 61.12620659172535, 59.11475032567978, 57.906966134905815, 61.45448997616768, 63.588052690029144, 62.320151925086975, 60.90468987822533, 57.619526758790016, 54.544344171881676, 47.929005548357964, 50.295020788908005, 47.521359622478485, 50.43192744255066, 50.9504172205925, 50.44620707631111, 48.503990694880486, 46.149758622050285, 48.003439754247665, 53.7046804279089, 52.8643137216568, 49.62108515202999, 48.65567475557327, 49.12753343582153, 53.8331401348114, 52.713788598775864, 50.60391001403332, 55.06699092686176, 51.9915347546339, 50.981165170669556, 50.91609366238117, 52.986420169472694, 54.80673149228096, 51.83123275637627, 54.10363242030144, 55.234071761369705, 56.292489767074585, 62.32158824801445, 64.23882097005844, 66.03354066610336, 67.47120872139931, 76.19905918836594, 74.75474908947945, 75.19177123904228, 69.22783926129341, 78.36393982172012, 65.53718850016594, 1.6810867935419083, 11.364583130925894, 3.725510803051293, 0.7225450628902763, 0.18769462447380647, 26.935713440179825, 82.97926336526871, 73.97182390093803, 70.65886527299881, 70.03750741481781, 24.874470345675945, 19.184268079698086, 52.98597179353237, 65.40019065141678, 69.13116484880447, 65.07128790020943, 4.221984799951315, 0.1711749960668385, 0.23711784509941936, 0.13301233761012554, 0.1049302116734907, 0.07963235664647073, 0.10686606678063981, 0.12908061733469367, 0.18498817516956478, 0.14252926834160462], [0.013693787950614933, 0.08458053722279146, 0.005007295421819435, 0.018025015597231686, 0.0355387990566669, 0.033009429898811504, 0.039316204565693624, 0.104916600685101, 0.14451437979005277, 1.2166301161050797, 42.022803872823715, 69.17661041021347, 47.642561718821526, 29.85344957560301, 17.902347967028618, 42.24620908498764, 56.54516860842705, 48.29973265528679, 74.45199653506279, 55.83019517362118, 1.244091005064547, 0.00829954415166867, 0.36790391779504716, 0.44624698581174016, 2.4999487912282348, 1.6870321682654321, 5.947952885180712, 75.85213780403137, 72.15392544865608, 70.17649635672569, 69.19038087129593, 73.97392138838768, 69.1714882850647, 68.13196286559105, 63.80370631814003, 64.45601731538773, 59.868386685848236, 58.80765840411186, 62.1516727656126, 65.62057882547379, 63.30655999481678, 62.670781910419464, 64.22404736280441, 62.78358265757561, 61.06898546218872, 62.42085412144661, 59.14501190185547, 61.488057374954224, 61.78469605743885, 62.28870861232281, 63.540479242801666, 59.50470060110092, 65.07085472345352, 54.38569128513336, 43.606726080179214, 47.56185784935951, 44.75341334939003, 46.70674413442612, 45.33267326653004, 47.778993397951126, 51.00422993302345, 48.37909899652004, 48.68033543229103, 43.725826889276505, 43.987739235162735, 43.811185508966446, 45.948259234428406, 48.0267933011055, 50.199022740125656, 53.639430329203606, 53.62353578209877, 53.18121671676636, 53.504225984215736, 55.59903837740421, 57.28693440556526, 57.836255729198456, 56.712716817855835, 54.05333451926708, 51.37969918549061, 47.87288635969162, 40.94967685639858, 41.9968094676733, 44.213952496647835, 52.298322692513466, 56.334207728505135, 57.7775526791811, 49.02745820581913, 19.688715711236, 24.584260918200016, 53.60350705683231, 56.21419116854668, 53.71673338115215, 50.67213535308838, 48.370173275470734, 40.857649594545364, 45.90603210031986, 50.16841158270836, 53.67793746292591, 54.5502794533968, 56.05504430830479, 50.78076772391796, 58.06893244385719, 57.08832286298275, 58.03814649581909, 55.96687003970146, 51.99922554194927, 51.18500903248787, 54.795100316405296, 53.20836625993252, 56.70067146420479, 56.631484776735306, 55.78688509762287, 48.63958641886711, 41.29770018160343, 42.86468669772148, 44.020778462290764, 46.37727901339531, 47.35407739877701, 46.6059735417366, 44.79095533490181, 42.18378223478794, 45.02658449113369, 46.33858948945999, 44.7471284866333, 45.67164547741413, 48.207116425037384, 43.950429037213326, 45.696226358413696, 44.8342502117157, 46.078079268336296, 43.92543017864227, 45.0830152630806, 43.59244644641876, 46.98984034359455, 45.16103267669678, 46.228376403450966, 45.63845805823803, 47.11348570883274, 50.672671124339104, 56.125857308506966, 55.154834613204, 61.90798044204712, 61.23277187347412, 71.30355387926102, 63.71734835207462, 70.00324845314026, 64.66187506914139, 71.94681376218796, 63.659355863928795, 85.07650002837181, 22.138487957417965, 4.005244430154562, 2.792211058549583, 0.261682725395076, 0.03214877608115785, 3.850985770113766, 57.643020898103714, 68.30554515123367, 52.97391124069691, 52.32215501368046, 39.77913446724415, 10.601255390793085, 23.48448783159256, 39.99795712530613, 47.353097051382065, 55.02804681658745, 9.97264752164483, 0.18187348527135327, 0.12569645361509174, 0.05141035813721828, 0.055041278537828475, 0.040689485758775845, 0.08198058611014858, 0.051653281625476666, 0.04952094292093534, 0.039256394884432666, 0.03756180827622302, 0.048772260633995757, 0.006649081469731755, 0.06873073420138098, 0.014300464918051148, 0.029483104081009515, 0.02706993298488669, 0.05833354211063124, 0.1198076008586213, 1.1283447034657001, 57.83070042729378, 77.70848259329796, 56.02693721652031, 36.36827029287815, 25.02002913504839, 42.81270168721676, 50.17337031662464, 57.41838075220585, 80.34548029303551, 60.43159246444702, 0.8617014333140105, 0.08804560246062465, 0.3276415157597512, 2.0614782068878412, 3.187787882052362, 0.5259848164860159, 6.894210409373045, 79.63728949427605, 75.46176195144653, 72.83250823616982, 73.59821274876595, 76.16348549723625, 71.23852416872978, 70.66207230091095, 67.21791431307793, 65.94794645905495, 61.767068803310394, 61.21792986989021, 63.93799111247063, 68.72063487768173, 65.10452091693878, 65.3611059486866, 66.19039624929428, 65.417700111866, 63.015290424227715, 63.61565060913563, 62.25681692361832, 63.782298266887665, 63.28760281205177, 64.30264994502068, 65.58986127376556, 62.222953140735626, 67.26225793361664, 56.57889559864998, 45.72739988565445, 49.761567413806915, 46.76408685743809, 48.950611129403114, 47.56353355944157, 49.321505427360535, 51.21338210999966, 51.39250449836254, 52.44578517973423, 46.35115921497345, 45.924221724271774, 47.07105338573456, 48.74157294631004, 50.45471861958504, 52.397656962275505, 55.38824088871479, 55.85663415491581, 57.41504453122616, 56.538914144039154, 59.62348982691765, 59.768364652991295, 61.033521965146065, 58.494357615709305, 55.745642110705376, 55.188675597310066, 51.096165999770164, 44.279312789440155, 45.24536155164242, 49.46480333805084, 55.7124774903059, 57.43001192808151, 62.535113990306854, 51.09021171927452, 22.464713752269745, 26.093133352696896, 55.642515644431114, 57.44538590312004, 56.23483166098595, 51.93669609725475, 48.61927650868893, 45.58967247605324, 48.201055750250816, 52.97709546983242, 56.02409116923809, 57.48478218913078, 56.44944794476032, 53.39515283703804, 60.943045020103455, 58.619142919778824, 58.471714630723, 59.69263471662998, 55.28568439185619, 54.367976635694504, 57.283883169293404, 55.271252766251564, 60.79372063279152, 58.350972309708595, 57.91066333651543, 50.8566040545702, 43.43016855418682, 44.118801802396774, 47.670114040374756, 47.756981179118156, 49.19854022562504, 48.33539754152298, 46.35328330099583, 45.52262507379055, 47.121172696352005, 49.62231628596783, 47.84541003406048, 47.53376975655556, 49.5060159265995, 47.219762206077576, 48.90476278960705, 47.69999943673611, 47.52092644572258, 46.272769421339035, 48.08118358254433, 45.397250801324844, 48.19179944694042, 48.17321464419365, 49.02877673506737, 47.92970471084118, 48.281121253967285, 51.967174261808395, 58.42767119407654, 58.02508659660816, 65.77767759561539, 63.524915277957916, 71.9970090687275, 65.69497883319855, 71.44478470087051, 67.68373131752014, 74.80173736810684, 65.50880402326584, 84.80075642466545, 31.423322036862373, 2.3931032745167613, 4.159073950722814, 0.29046451847534627, 0.06398198354872875, 4.603735590353608, 59.663250893354416, 77.23093941807747, 57.51479297876358, 50.45709729194641, 33.931221663951874, 16.813784278929234, 33.97620365023613, 49.26222860813141, 55.20554669201374, 64.50274720788002, 12.521861381828785, 0.24583573511336, 0.011230494983465178, 0.008984201358543942, 0.08831250845105387, 0.015615247248206288, 0.04467651087907143, 0.019024495559278876, 0.07091159452102147, 0.03834241404547356, 0.14185590291162953, 0.2096706413431093, 0.13049464614596218, 0.21280401851981878, 0.14011286519235, 0.09155700739938766, 0.14411324897082523, 0.2748133958084509, 0.3192480036523193, 1.8134307232685387, 73.06011602282524, 86.68911829590797, 65.13613522052765, 44.967763647437096, 27.653413228690624, 51.75308234989643, 75.6974709033966, 65.75348049402237, 87.28328481316566, 67.11683973670006, 1.7610904318280518, 0.14133884862530977, 0.6838553014677018, 2.820152621716261, 10.180615112185478, 7.337103243917227, 7.972716037184, 81.75919443368912, 77.35243409872055, 75.19365593791008, 76.18782699108124, 77.32610151171684, 74.28048133850098, 72.62032762169838, 68.19095849990845, 69.53952893614769, 63.83329913020134, 64.37322735786438, 67.84875646233559, 72.65460938215256, 68.12475085258484, 69.04058530926704, 72.59417742490768, 66.85463860630989, 64.0245732665062, 68.32380697131157, 63.84984344244003, 66.24728679656982, 68.15419167280197, 65.73802292346954, 67.97655120491982, 63.29444244503975, 71.53105527162552, 60.34134350717068, 46.95903919637203, 52.86370575428009, 48.50035808980465, 52.046107426285744, 49.390312135219574, 52.95012451708317, 55.05199313163757, 54.12278339266777, 55.311557203531265, 48.48722979426384, 49.09579373896122, 48.38317237794399, 52.77448274195194, 54.08724769949913, 55.12537479400635, 59.034046456217766, 60.22490635514259, 59.880116656422615, 58.45591127872467, 62.09220975637436, 61.75596959888935, 63.270883709192276, 63.61611798405647, 57.55641594529152, 57.48077340424061, 53.41064840555191, 47.57404759526253, 49.50711406767368, 51.11502058804035, 59.27161730825901, 59.532830491662025, 66.38304591178894, 54.56534564495087, 27.860428020358086, 30.226842239499092, 57.3613154143095, 61.60769395530224, 59.231309071183205, 56.390908285975456, 52.51798890531063, 48.00212502479553, 52.2941505163908, 54.83427621424198, 60.310101583600044, 59.98747989535332, 60.85295185446739, 56.502025723457336, 61.81670553982258, 62.50255733728409, 63.18425975739956, 64.4988714158535, 56.9322956353426, 56.776644587516785, 60.092171877622604, 57.33444705605507, 60.53933188319206, 61.662289425730705, 61.929912865161896, 55.16596421599388, 44.721088483929634, 47.29934513568878, 50.003576427698135, 50.57503916323185, 52.363253608345985, 52.65026740729809, 48.93839858472347, 47.61559456586838, 49.45792570710182, 51.21177479624748, 49.37826298177242, 49.60875481367111, 53.463484570384026, 49.28767964243889, 51.308977380394936, 49.55152988433838, 49.48176562786102, 49.660378843545914, 51.89641825854778, 48.01723301410675, 52.91461542248726, 50.74675194919109, 52.13774710893631, 50.996858328580856, 51.684218645095825, 56.3339227437973, 61.392686292529106, 60.7235573977232, 68.14343065023422, 65.55025979876518, 75.81938356161118, 69.3747241795063, 74.46537181735039, 68.38434532284737, 78.977470099926, 68.26560169458389, 89.61513608694077, 31.847364082932472, 4.753289390355349, 12.605350501835346, 0.801875009201467, 0.23161706136306748, 6.744144111871719, 69.10658776760101, 82.053731828928, 65.77679604291916, 67.8202123939991, 52.46521353721619, 17.214316986501217, 36.172964572906494, 57.28061534464359, 64.09767374396324, 76.78773120045662, 15.92669053003192, 0.36784451629500836, 0.3843296645209193, 0.13528645620681345, 0.2726771088782698, 0.19812847865978256, 0.17741470655892044, 0.17864840832771733, 0.1010440666868817, 0.13444159529171884], [0.079430232726736, 0.05490563249622937, 0.04936925535730552, 0.06034061370883137, 0.022617781651206315, 0.06573297709110193, 0.06969551875954494, 0.05419183486083057, 0.1817960198968649, 4.835504153743386, 62.572124004364014, 62.10374593734741, 54.14421804249287, 40.42410045862198, 18.5395547747612, 20.77142011374235, 47.54425719380379, 55.72191618382931, 83.08540686964989, 33.85959930717945, 0.0427674621460028, 0.023726969593553804, 0.036186296929372475, 1.5575338108465075, 1.6216468205675483, 0.03717049607075751, 43.68396833539009, 85.54009795188904, 67.32412621378899, 70.91359600424767, 66.40422597527504, 75.7036417722702, 72.4789448082447, 74.8221042752266, 70.43311938643456, 62.59688727557659, 62.009746581315994, 59.612417221069336, 57.5521107763052, 52.610639333724976, 49.46283124387264, 50.54006204009056, 50.49971200525761, 53.08053731918335, 51.079427897930145, 51.30279891192913, 51.835492327809334, 56.21244706213474, 57.62339875102043, 60.40575385093689, 64.27669733762741, 65.65761163830757, 60.266609117388725, 47.99572616815567, 45.11331483721733, 46.89018689095974, 45.188805386424065, 46.83027930557728, 45.504184663295746, 46.678606644272804, 49.4391281157732, 47.45130658149719, 46.919080540537834, 48.0454009026289, 41.101630702614784, 42.5358447432518, 45.499476715922356, 47.205714359879494, 45.21326087415218, 50.18718257546425, 54.01197373867035, 53.11866447329521, 52.09164038300514, 52.6932393014431, 52.53494739532471, 53.033146262168884, 48.513645976781845, 46.07082925736904, 44.37480926513672, 46.34464256465435, 43.18130850791931, 45.89277841150761, 51.89798377454281, 54.97712194919586, 55.151638984680176, 57.33836844563484, 43.84367756545544, 16.810535453259945, 24.367644041776657, 45.45070633292198, 58.885694816708565, 55.19269958138466, 54.79262284934521, 52.665212005376816, 46.52004115283489, 41.21663153171539, 44.37832787632942, 49.50523316860199, 52.25282773375511, 52.78620511293411, 55.38572922348976, 50.446245074272156, 53.67522440850735, 55.3608101606369, 56.18062376976013, 54.33615334331989, 57.780421525239944, 56.23702794313431, 56.68253503739834, 56.33779853582382, 55.03742091357708, 51.373171135783195, 44.201321974396706, 42.279647290706635, 42.081347331404686, 44.51466076076031, 47.42576815187931, 47.07132317125797, 43.96019831299782, 43.43863070011139, 42.02653527259827, 43.5366540402174, 48.08122158050537, 46.03566974401474, 48.541772067546844, 45.952940583229065, 45.4119598120451, 43.963367342948914, 45.324275717139244, 44.948487281799316, 45.205801874399185, 44.54053357243538, 44.34056170284748, 46.42430528998375, 46.32996775209904, 43.14776010811329, 47.44843773543835, 50.732080936431885, 53.57495918869972, 55.51617622375488, 56.78624667227268, 63.3879554271698, 63.09630587697029, 65.62724366784096, 68.35988223552704, 64.93464723229408, 68.43346908688545, 66.21319502592087, 66.42920583486557, 68.40731129050255, 72.47371628880501, 4.35985280200839, 3.5587809747084975, 1.0749942599795759, 0.07298344076843932, 0.172916890878696, 29.517232216894627, 70.28513252735138, 58.59054185450077, 61.15031249821186, 59.8693860322237, 29.734540656208992, 10.313801765441895, 28.13963133841753, 45.34445263445377, 55.33251687884331, 26.368358284235, 0.2459458846715279, 0.04640115817892365, 0.019284130357846152, 0.03668223711429164, 0.020002414275950287, 0.04115534669836052, 0.0697761308401823, 0.02675648320291657, 0.11403916898416355, 0.13720671879127622, 0.07555222910013981, 0.02466096429998288, 0.048628859149175696, 0.02640949020133121, 0.06805785858887248, 0.08298905348055996, 0.09726721778861247, 0.24503504682797939, 5.814986145123839, 76.3812518119812, 70.48824682831764, 65.1891727745533, 46.34547472000122, 28.320725820958614, 27.632552348077297, 47.2683198004961, 64.70359683036804, 87.74667754769325, 35.97638592123985, 0.028409292463038582, 0.1588786777574569, 0.8969740499742329, 3.333525499328971, 0.24647757411003113, 0.14406883885385469, 47.224204167723656, 88.5540734231472, 71.30709528923035, 74.52195838093758, 68.66305276751518, 77.22292184829712, 71.70637026429176, 77.10067480802536, 73.01331013441086, 65.18333628773689, 64.08887341618538, 61.65723189711571, 57.83500179648399, 56.34420499205589, 52.60083205997944, 53.53464715182781, 53.06225650012493, 55.699318796396255, 54.29463677108288, 54.39158096909523, 55.39554409682751, 58.151323422789574, 61.9636170566082, 62.99388237297535, 66.0572437942028, 67.57910013198853, 61.08419604599476, 49.93396416306496, 47.80968435108662, 47.811671644449234, 47.40853987634182, 47.59564943611622, 49.0972338616848, 49.584823697805405, 51.36760823428631, 50.57633489370346, 49.17566545307636, 48.95042113959789, 43.08932304382324, 45.076574608683586, 48.79481568932533, 50.275109857320786, 47.62825928628445, 52.52719961106777, 55.52633687853813, 56.014371290802956, 53.93224261701107, 56.204019114375114, 53.47540073096752, 54.85829472541809, 50.90617619454861, 47.31710538268089, 45.45186527073383, 48.10144789516926, 44.83859717845917, 48.45090374350548, 54.474310129880905, 59.97942052781582, 59.264530688524246, 62.1940328925848, 44.50242921710014, 19.86460257321596, 25.69872971624136, 48.15832704305649, 60.80471344292164, 55.76848268508911, 57.614165246486664, 54.17086221277714, 48.00952322781086, 43.73012825846672, 47.36708790063858, 49.84351001679897, 56.64616718888283, 54.48750302195549, 56.59079656004906, 52.08692863583565, 56.87239184975624, 57.56418652832508, 57.472144067287445, 58.07517930865288, 58.125591203570366, 58.64675223827362, 57.99891360104084, 58.43795724213123, 58.83585289120674, 52.13591180741787, 45.64982324838638, 44.22002837061882, 44.811523631215096, 45.895100086927414, 48.510636538267136, 49.11231145262718, 47.77297832071781, 45.0517163425684, 43.8155210763216, 45.45080132782459, 49.81580190360546, 48.13076712191105, 50.372730419039726, 48.54215204715729, 46.30340337753296, 46.679077818989754, 46.39164984226227, 45.78448802232742, 47.04127058386803, 48.60609881579876, 47.77786485850811, 47.54568971693516, 47.639894261956215, 45.796590372920036, 47.31439232826233, 53.00465539097786, 58.52320186793804, 55.10935105383396, 59.22831483185291, 64.39084321260452, 64.54804077744484, 66.68277382850647, 69.3206986784935, 65.37503600120544, 69.27334561944008, 67.36216977238655, 70.21786093711853, 70.19076839089394, 76.18542551994324, 7.717800065875053, 4.142961390316486, 2.798238485120237, 0.17872161377454177, 0.05380881986638997, 30.737650729715824, 77.33864083886147, 64.77815642952919, 62.00055107474327, 52.91974514722824, 25.460626892745495, 17.18152854591608, 35.25126323103905, 53.636736273765564, 64.17306169867516, 32.8924448043108, 0.4332416789839044, 0.006873688753330498, 0.056856282317312434, 0.059572353566181846, 0.056200798935606144, 0.017399114221916534, 0.024179887477657758, 0.038136223156470805, 0.02687746069568675, 0.2585684659425169, 0.1257665123557672, 0.16172153380466625, 0.1220734445087146, 0.0577158488886198, 0.14254108333261684, 0.2193517202977091, 0.15132040833123028, 0.388675028225407, 8.123577442020178, 91.90153419971466, 78.62647533416748, 75.14446377754211, 54.277758076786995, 28.926084637641907, 28.215387873351574, 67.04968214035034, 70.61430886387825, 94.81723174452782, 42.283112704753876, 0.400911588803865, 0.3149047773331404, 2.0192175870761275, 6.312080221250653, 9.714107494801283, 0.9148960851598531, 51.4825102686882, 91.16327181458473, 74.86122697591782, 76.24009698629379, 72.39915668964386, 80.20778328180313, 74.1886554658413, 79.35373350977898, 77.9554845392704, 67.78501868247986, 68.07191088795662, 65.26173368096352, 63.102320954203606, 58.89997065067291, 54.61138777434826, 54.29026700556278, 56.951955780386925, 57.80518099665642, 57.46267877519131, 58.20772759616375, 57.51428760588169, 60.59373736381531, 65.00881925225258, 65.58274045586586, 69.88046184182167, 70.13494938611984, 66.16963416337967, 53.05235803127289, 50.91982126235962, 50.50695441663265, 49.07350413501263, 51.633255779743195, 52.308756932616234, 52.367524579167366, 55.966246873140335, 50.87269999086857, 51.566044986248016, 53.25241729617119, 45.284651443362236, 47.666150853037834, 51.305101588368416, 53.439173474907875, 50.06525091826916, 56.39738313853741, 58.31124164164066, 57.816789373755455, 57.057593911886215, 59.593387842178345, 57.60856434702873, 59.100710079073906, 52.315843552351, 51.37162081897259, 48.763208985328674, 52.569992914795876, 48.67968946695328, 53.06042119860649, 56.69598251581192, 61.482673063874245, 61.87299191951752, 64.48491856455803, 49.0621617436409, 22.576004080474377, 30.785150080919266, 52.34452061355114, 65.42888671159744, 60.47012619674206, 60.44257387518883, 56.21430516242981, 51.43715590238571, 45.84506817162037, 49.81601469218731, 53.143450543284416, 57.72111430764198, 56.82328708469868, 60.27561083436012, 56.55355855822563, 59.84736241400242, 60.823712423443794, 60.34464552998543, 59.88727547228336, 61.10585108399391, 62.17212326824665, 61.56991258263588, 61.254126727581024, 61.998719573020935, 55.30753321945667, 47.69619204103947, 47.31485590338707, 47.452226132154465, 49.14191946387291, 50.69879852235317, 52.90022559463978, 49.35682833194733, 45.99088154733181, 45.63787288963795, 48.469226360321045, 51.315269842743874, 49.89037670195103, 52.563784047961235, 50.87251000106335, 48.19790191948414, 49.61360715329647, 50.29764644801617, 49.38054285943508, 48.836005479097366, 52.53971613943577, 51.04029759764671, 52.21093878149986, 51.77551634609699, 48.86608086526394, 51.827672347426414, 55.46152375638485, 60.90959921479225, 57.96670272946358, 62.7864933013916, 68.49942594766617, 67.4133226275444, 71.28260940313339, 72.86007195711136, 67.32711285352707, 73.69427919387817, 70.89495420455933, 74.75545585155487, 72.80344739556313, 79.79226037859917, 7.1945177949965, 6.697911042720079, 4.12794079631567, 0.206268502806779, 0.23630051786312833, 37.275270223617554, 83.13417345285416, 69.98225077986717, 75.38899585604668, 76.59519553184509, 43.481006026268005, 19.010001830756664, 47.14009948074818, 62.754141837358475, 75.49849078059196, 40.941583290696144, 0.8163914771284908, 0.17377862823195755, 0.07553893723525107, 0.0981980342476163, 0.14005525968968868, 0.24978479195851833, 0.16648888267809525, 0.13455778593197465, 0.1471595573821105], [0.09449533332372084, 0.05758167972089723, 0.032523156187380664, 0.03821290185442194, 0.012141069364588475, 0.08378304017242044, 0.04217158435494639, 0.1494252451811917, 0.15741379698738456, 12.449523713439703, 68.28916043043137, 54.199140295386314, 41.30717687308788, 17.110445760190487, 16.083556562662125, 18.91784157603979, 46.696697473526, 61.903690472245216, 79.3729604780674, 18.876798078417778, 0.2369812157121487, 0.17658928991295397, 0.9266487951390445, 0.7818131544627249, 1.7480773176066577, 9.480159748345613, 77.75213465094566, 66.89104825258255, 68.48295003175735, 61.14617832005024, 66.4148198068142, 69.94689747691154, 75.19678696990013, 69.89174723625183, 69.86499667167664, 69.61699157953262, 68.33890736103058, 65.62852039933205, 67.16578111052513, 58.31713892519474, 56.75338603556156, 50.31982205808163, 48.545974642038345, 47.03889951109886, 48.299455270171165, 47.363181710243225, 48.11972491443157, 47.36683711409569, 53.52352514863014, 54.67366263270378, 57.33991116285324, 55.64352259039879, 49.23780731856823, 47.115066424012184, 44.8839021474123, 47.91345298290253, 46.05946406722069, 44.09750014543533, 43.51775765419006, 46.25418461859226, 47.936415150761604, 48.312549367547035, 46.38382986187935, 43.99099946022034, 43.417910411953926, 45.46863377094269, 41.020056679844856, 43.15962687134743, 43.32934856414795, 46.15922011435032, 46.65267303586006, 49.72717545926571, 48.45415636897087, 49.14754316210747, 46.12296625971794, 45.21174095571041, 45.46379663050175, 45.27402341365814, 45.037512704730034, 48.291076719760895, 44.02417168021202, 49.22722868621349, 58.02998833358288, 59.43425618112087, 56.743339374661446, 63.332444205880165, 40.90463027358055, 27.935882471501827, 31.97417087852955, 34.42000463604927, 56.94813698530197, 52.38242357969284, 54.159633815288544, 54.95881453156471, 51.375150829553604, 40.462702587246895, 46.4666236191988, 45.22655636072159, 48.329811841249466, 48.299865648150444, 50.84334656596184, 48.29716019332409, 50.24026192724705, 48.76141548156738, 52.98606298863888, 51.01702764630318, 53.789366483688354, 54.233570247888565, 52.70851448178291, 50.31524710357189, 46.623384207487106, 40.47336861491203, 39.95074465870857, 40.409091264009476, 42.820639461278915, 44.107835590839386, 48.74031141400337, 47.017499059438705, 44.78481486439705, 43.30753393471241, 43.80513243377209, 41.527226865291595, 47.67932094633579, 44.5380637049675, 47.98945650458336, 46.83527983725071, 45.2678107470274, 45.09503781795502, 45.25497503578663, 44.45067219436169, 46.32593236863613, 41.36467918753624, 44.41943407058716, 45.05007483065128, 45.502444356679916, 44.171075597405434, 48.05046983063221, 48.667176738381386, 51.99028082191944, 53.8663237541914, 57.09363117814064, 57.91579686105251, 60.902201011776924, 61.36320747435093, 64.26722064614296, 58.3072404563427, 61.443690955638885, 58.91890503466129, 67.3752410709858, 62.39422895014286, 79.22485202550888, 37.309555783867836, 0.9156525414437056, 2.6821188535541296, 0.27922400913666934, 0.22311059437924996, 7.458916632458568, 64.67246130108833, 65.61763778328896, 53.802357986569405, 65.06627976894379, 43.83034408092499, 18.166906870901585, 19.35070674866438, 37.825678288936615, 54.216600358486176, 44.06913846731186, 1.9462718325667083, 0.06514043896459043, 0.021359305137593765, 0.030806477698206436, 0.03302169388916809, 0.010700823258957826, 0.036601695537683554, 0.04324580600950867, 0.05608045968983788, 0.036770148217328824, 0.03568678701412864, 0.08398424382903613, 0.04070191673235968, 0.029413609372568317, 0.06585989176528528, 0.06901691376697272, 0.13309018890140578, 0.1577013940550387, 15.537822246551514, 78.39683845639229, 61.944112703204155, 50.200926437973976, 26.158425249159336, 24.380361959338188, 22.193351313471794, 51.516754031181335, 69.9676063656807, 83.87831032276154, 20.68509254604578, 0.2080791798653081, 0.259799332707189, 2.1175674721598625, 1.4114063582383096, 2.4473957112058997, 10.205776412039995, 82.69864842295647, 69.30495232343674, 73.86728391051292, 62.9074864089489, 70.94597026705742, 71.62500143051147, 77.07048162817955, 72.01872110366821, 70.47000020742416, 71.81717991828918, 71.00553587079048, 69.21098336577415, 69.0033321082592, 60.867455676198006, 59.311993941664696, 52.872430086135864, 51.83025240898132, 48.51475931704044, 50.70155717432499, 49.70534183084965, 50.77967718243599, 49.596238285303116, 54.26768861711025, 57.01980873942375, 58.79400573670864, 58.23836915194988, 51.455638110637665, 47.65713773667812, 49.33559127151966, 49.7071847319603, 47.6508566737175, 46.50758542120457, 45.819115564227104, 48.767555952072144, 49.84950989484787, 49.96012955904007, 50.04597455263138, 47.2378758341074, 44.63499270379543, 47.65062488615513, 43.480071276426315, 44.752357006073, 45.63705213367939, 49.30249124765396, 48.01311023533344, 51.189815774559975, 49.70043249428272, 50.33469446003437, 47.79701583087444, 46.9749641418457, 46.914140805602074, 46.504385992884636, 47.731503546237946, 49.16922479867935, 46.844330951571465, 53.36807169020176, 57.68790788948536, 61.03913426399231, 56.57703749835491, 65.49812659621239, 42.641923651099205, 30.80901850014925, 32.93229326605797, 36.14643059670925, 57.609407901763916, 55.74061498045921, 55.72944737970829, 58.37358869612217, 54.77971114218235, 42.399272471666336, 49.41407985985279, 45.964963138103485, 50.49758791923523, 50.97875230014324, 51.29298023879528, 50.765747129917145, 52.62814499437809, 50.45924797654152, 56.358613818883896, 54.18953441083431, 56.741382479667664, 56.599885672330856, 55.15190117061138, 51.85550205409527, 49.70450207591057, 42.01111949980259, 42.2820183634758, 41.75661675632, 43.87436851859093, 44.705946296453476, 49.20532666146755, 49.855346381664276, 47.39755466580391, 45.16197122633457, 45.6007906794548, 43.184329345822334, 50.86142219603062, 46.1644334346056, 49.553292989730835, 48.967273235321045, 47.19430357217789, 47.54409000277519, 47.100068628787994, 47.02365092933178, 46.35752387344837, 44.112927317619324, 46.89002349972725, 45.84707826375961, 49.00842882692814, 47.19373740255833, 50.95343045890331, 49.94774602353573, 54.70449037849903, 56.940225809812546, 59.3983519077301, 58.509458005428314, 64.16406378149986, 61.43919199705124, 65.66917061805725, 59.39492829144001, 62.362572848796844, 61.03179305791855, 69.64875027537346, 64.8715478181839, 83.1201522052288, 41.458127573132515, 0.43831802846398205, 4.100408898666501, 0.5655376065988094, 0.3374605451244861, 8.480381146073341, 70.53677022457123, 70.88542431592941, 58.82344275712967, 61.703338623046875, 34.10564750432968, 19.372979253530502, 27.34752394258976, 45.33704683184624, 62.006729543209076, 52.08455376327038, 3.0021364940330386, 0.13223900488810614, 0.06034511112375185, 0.076135052513564, 0.01747886541124899, 0.1407780818408355, 0.0317526028084103, 0.011183995720784878, 0.03736418548214715, 0.13022846746025607, 0.0983976200222969, 0.16125546506373212, 0.14011500257765874, 0.185731228266377, 0.21813155530253425, 0.22891635628184304, 0.25272672472056, 0.47809212701395154, 20.729156881570816, 92.95619040727615, 70.3351454436779, 61.85584343969822, 28.735705353319645, 21.249567456543446, 27.10575621575117, 65.20934209227562, 76.32579758763313, 92.34816983342171, 24.45502795279026, 0.4833351925481111, 0.8790188853163272, 4.120860826224089, 6.061245230957866, 7.257247678935528, 10.058642607182264, 88.29494252800941, 69.1395851969719, 76.40291064977646, 66.06711566448212, 73.2695759832859, 74.08517941832542, 80.34399837255478, 72.8912302851677, 75.35981342196465, 75.27508556842804, 73.39847266674042, 69.88531038165092, 74.75654259324074, 63.17946821451187, 62.72715948522091, 54.877267107367516, 55.26561766862869, 50.71636117994785, 54.251474887132645, 51.54598206281662, 53.53213548660278, 51.66050411760807, 58.24974574148655, 59.45870026946068, 62.937531396746635, 61.365905329585075, 53.23895461857319, 50.94511650502682, 50.79659007489681, 52.895798832178116, 50.20884521305561, 48.72538201510906, 47.29997970163822, 51.239482909440994, 52.102010026574135, 54.13977608084679, 51.50595121085644, 47.92678266763687, 47.848579064011574, 52.25726969540119, 45.68268768489361, 45.45098751783371, 48.24373126029968, 49.74181607365608, 51.836522072553635, 52.99498490989208, 53.564251363277435, 52.37974852323532, 50.705284774303436, 49.54255096614361, 50.457519069314, 49.159417524933815, 50.27155324816704, 52.3111280053854, 48.92897889018059, 55.07807493209839, 63.16326588392258, 62.80563287436962, 61.32237106561661, 68.46056923270226, 46.46521769464016, 34.75474387407303, 38.107957541942596, 37.56215862929821, 60.091598108410835, 59.49034497141838, 58.19632440805435, 60.50340101122856, 56.284567192196846, 44.222228452563286, 52.05690644681454, 49.46736820042133, 54.910237938165665, 55.990360379219055, 55.85358291864395, 52.53509558737278, 55.48991583287716, 53.72442036867142, 58.83524872362614, 56.94973669946194, 59.632259756326675, 59.301350712776184, 57.74883762001991, 55.95451310276985, 52.71954528987408, 45.36562129855156, 45.47227397561073, 44.03240963816643, 48.05372625589371, 49.528476521372795, 53.33427630364895, 52.67843909561634, 50.210486724972725, 47.65511244535446, 49.550591334700584, 46.52833990752697, 54.22380477190018, 48.60264480113983, 50.9057430177927, 49.46530491113663, 49.97607730329037, 50.01798525452614, 50.51455020904541, 49.324583262205124, 50.19444778561592, 45.68629369139671, 48.920581340789795, 50.51480859518051, 51.90196596086025, 49.880368039011955, 54.50666919350624, 54.457013458013535, 57.32848137617111, 58.97074185311794, 62.391557693481445, 62.38449767231941, 66.86109825968742, 65.35872727632523, 70.27887806296349, 62.39677481353283, 66.63620352745056, 63.457031920552254, 74.4620355963707, 67.47266784310341, 88.6569795012474, 40.61923898756504, 1.6830743243917823, 6.954500824213028, 0.8661270677112043, 0.33846663020085543, 10.816742777824402, 79.0094643831253, 76.04541823267937, 68.96471858024597, 77.6853646337986, 56.37373700737953, 27.034019865095615, 34.044972360134125, 55.420067980885506, 71.35200887918472, 65.80724760890007, 4.994062045589089, 0.24292574438732117, 0.1751508889719844, 0.35840027150698006, 0.1437815386452712, 0.19056670629652217, 0.17342788923997432, 0.18105774623109028, 0.17217345186509192], [0.08296559419250116, 0.04201350318908226, 0.015307716093957424, 0.05589590240560938, 0.017450615559937432, 0.12878549488959834, 0.07594127775519155, 0.21820149529958144, 0.048650707976776175, 27.398063130676746, 66.8321818113327, 56.398428082466125, 43.61806087195873, 15.662013832479715, 28.825160153210163, 40.341424494981766, 54.348092302680016, 73.65836352109909, 68.9853210747242, 7.264930866658688, 0.2816405310295522, 0.2578400034690276, 1.0444637294858694, 0.9632953943219036, 0.4423497011885047, 42.47929997742176, 75.54123848676682, 72.39641323685646, 69.63253274559975, 59.40336383879185, 59.98895041644573, 67.52765089273453, 68.72577220201492, 73.53836596012115, 70.24372234940529, 72.03824445605278, 69.25112441182137, 71.18745490908623, 63.86000409722328, 62.200458347797394, 63.183613792061806, 61.53044410049915, 53.87007415294647, 52.917339876294136, 49.57093924283981, 46.93259261548519, 47.43805289268494, 49.14554826915264, 47.472456246614456, 45.61778336763382, 48.1417865306139, 45.90939871966839, 44.85308200120926, 46.79000146687031, 44.695139676332474, 47.605232521891594, 43.89486841857433, 42.849099934101105, 44.22101631760597, 48.653326481580734, 49.83807250857353, 46.24994784593582, 46.10624335706234, 47.27184221148491, 42.69998073577881, 43.41004863381386, 42.639377787709236, 44.04658667743206, 42.292141020298004, 42.166249975562096, 43.75684082508087, 44.86969470977783, 42.56261430680752, 45.20254924893379, 43.663768619298935, 45.051533952355385, 43.16669449210167, 45.16737073659897, 47.46636137366295, 47.32196532189846, 45.80263204872608, 51.46560117602348, 54.88401174545288, 58.858476877212524, 53.79882797598839, 62.31559596955776, 50.93422248959541, 33.32306809723377, 35.29974102973938, 35.71233429014683, 59.68368239700794, 53.635869920253754, 54.573439210653305, 54.57862973213196, 55.212830901145935, 43.24259161949158, 45.12507140636444, 42.83792473375797, 46.735117211937904, 45.770922750234604, 46.464537531137466, 42.92004592716694, 44.07398700714111, 42.544390484690666, 43.94402638077736, 42.74978846311569, 47.41890951991081, 44.440655931830406, 41.57132349908352, 41.591120436787605, 40.047742053866386, 40.313598588109016, 37.30687312781811, 39.80394333600998, 40.97888968884945, 42.99104891717434, 44.07645307481289, 46.048836037516594, 43.9311982691288, 44.02469225227833, 43.41255649924278, 42.04392693936825, 45.37411384284496, 46.851713955402374, 44.645225554704666, 47.36363388597965, 45.405800342559814, 44.6052934974432, 45.53981155157089, 45.42887270450592, 44.62216839194298, 44.49109822511673, 44.87285614013672, 44.93344388902187, 46.45794868469238, 48.05615812540054, 47.196727842092514, 45.135030671954155, 49.94518496096134, 51.74068361520767, 51.81080885231495, 51.39873616397381, 53.852344304323196, 53.29874821007252, 50.70575214922428, 51.89687043428421, 50.44330783188343, 54.47185926139355, 60.016951113939285, 69.24634426832199, 69.34124037623405, 70.98665848374367, 5.47588711604476, 3.2984697679057717, 0.3793788864277303, 0.08109881076961756, 0.5405447445809841, 36.910645589232445, 72.14781537652016, 55.91842643916607, 61.27913698554039, 58.94820146262646, 19.692160226404667, 13.59687214717269, 35.61063654720783, 50.38945332169533, 51.62629455327988, 11.354127041995525, 0.06000691813824233, 0.05938614129263442, 0.11464448689366691, 0.08404078806051984, 0.03511312541377265, 0.08878775755874813, 0.017869643270387314, 0.04730189168185461, 0.029952024524391163, 0.05872644622286316, 0.024872995891200844, 0.08586123920395039, 0.038251196674536914, 0.18067347700707614, 0.09806156071135774, 0.0941847667854745, 0.05661201554175932, 33.66622768342495, 77.8020715713501, 60.5185241997242, 51.62736989557743, 18.29238373786211, 22.287097983062267, 36.534906551241875, 60.79919993877411, 79.98288094997406, 77.94888809323311, 7.661684202030301, 0.26022286154329777, 0.1081419076945167, 1.118736444041133, 0.9786074445582926, 0.8733570110052824, 48.915197029709816, 80.62385335564613, 76.6551411151886, 72.03614696860313, 63.951305598020554, 63.43830272555351, 70.64660713076591, 69.69999432563782, 75.3891934454441, 71.3118526339531, 71.37427568435669, 70.70117980241776, 72.67018854618073, 66.03433102369308, 66.23068928718567, 67.05621778964996, 63.5352773219347, 57.489714324474335, 55.35357154905796, 52.75982692837715, 49.3169304728508, 50.781303495168686, 52.504693418741226, 48.32443132996559, 47.557856664061546, 51.53231039643288, 48.71719345450401, 47.53866769373417, 50.31060375273228, 46.471920534968376, 48.57465170323849, 45.82463286817074, 45.03044128417969, 46.49822652339935, 49.57351930439472, 51.426113694906235, 48.03475767374039, 48.32047954201698, 48.910728469491005, 43.90826649963856, 45.726563930511475, 44.37476746737957, 45.629501938819885, 44.564901664853096, 44.1810804605484, 44.62257497012615, 47.331556007266045, 45.64122051000595, 46.24930568039417, 44.79855492711067, 46.84030696749687, 46.75670005381107, 46.657521575689316, 46.23914122581482, 47.564570903778076, 47.50937506556511, 54.4378624856472, 57.72787034511566, 61.05114921927452, 56.3348650932312, 64.932352155447, 52.26195864379406, 37.41074815392494, 36.600559428334236, 38.963717222213745, 59.963108003139496, 57.2467477619648, 56.354548037052155, 55.40280930697918, 57.654203698039055, 45.439732521772385, 47.28019796311855, 46.15020699799061, 48.74889135360718, 49.194987416267395, 49.48402650654316, 44.84150022268295, 45.013623386621475, 45.95816910266876, 44.9260912835598, 45.26881009340286, 48.318602442741394, 46.01404130458832, 43.8936410844326, 43.814134150743484, 41.52981452643871, 43.20776268839836, 42.572045400738716, 42.172964215278625, 42.4475184828043, 45.5246389657259, 44.89240609109402, 47.20643252134323, 45.655880123376846, 46.38085462152958, 45.192517787218094, 45.17185069620609, 46.774726286530495, 46.53334803879261, 46.388028636574745, 49.69397284090519, 47.434655874967575, 47.676037922501564, 48.80592629313469, 46.15444377064705, 46.58844128251076, 47.17927157878876, 47.49569199979305, 46.628897711634636, 49.06677469611168, 50.17750069499016, 50.41253708302975, 48.29529449343681, 51.720122918486595, 53.83441686630249, 52.95507185161114, 55.01437894999981, 55.77268905937672, 55.40953494608402, 54.4399181753397, 54.63798634707928, 52.381656020879745, 57.33993776142597, 63.190875202417374, 70.31418576836586, 71.34513884782791, 74.81633618474007, 7.08737731911242, 2.027701106853783, 1.248915083706379, 0.11566178582143039, 0.6861202174331993, 40.666611045598984, 78.05277451872826, 59.5920617133379, 65.0412467122078, 52.47569717466831, 18.63340973854065, 16.955757960677147, 42.28532798588276, 57.25120112299919, 61.127205938100815, 15.082844160497189, 0.1975712741841562, 0.07224546396173537, 0.03752537253603805, 0.19987844803836197, 0.026863853418035433, 0.06982927603530698, 0.029410314236884005, 0.014905017487762962, 0.2986958861583844, 0.108161760144867, 0.1362938474630937, 0.21336353849619627, 0.13980681833345443, 0.18222916696686298, 0.23850515659432858, 0.25231296254787594, 0.27600270230323076, 43.047152906656265, 90.42877122759819, 71.62752449512482, 62.22169540822506, 29.14733726531267, 38.858945444226265, 56.904465928673744, 72.69525200128555, 85.21169677376747, 83.98230314254761, 8.89050928875804, 0.37820495723281056, 0.9400049597024918, 3.871205672621727, 7.077484549954534, 0.8731726615224034, 54.015116170048714, 80.89263573288918, 79.79132562875748, 75.57925924658775, 66.45755231380463, 66.65242865681648, 71.83829918503761, 73.02296921610832, 77.70469039678574, 74.23293828964233, 75.55006921291351, 76.17058351635933, 77.07938075065613, 68.12190100550652, 67.7502353489399, 70.36397069692612, 67.24939942359924, 59.29281637072563, 57.44668923318386, 55.30068218708038, 50.710300505161285, 53.44838038086891, 54.18216660618782, 50.256680846214294, 49.292136803269386, 53.79678748548031, 50.30909903347492, 48.86782497167587, 51.643036454916, 49.218439757823944, 51.25244401395321, 47.08457686007023, 48.134536519646645, 47.943190187215805, 52.23676219582558, 55.347871854901314, 49.74809713661671, 50.77164441347122, 50.79163134098053, 46.72752521932125, 48.60011413693428, 47.18372493982315, 49.88952934741974, 46.17155805230141, 45.67925646901131, 46.72762781381607, 50.96408508718014, 46.39510005712509, 49.66992013156414, 47.54629008471966, 49.68280144035816, 50.56821092963219, 49.049903601408005, 49.70435008406639, 49.9850220233202, 51.827277168631554, 56.44529476761818, 58.978117257356644, 64.4639664888382, 59.33814033865929, 68.71998891234398, 55.72334870696068, 41.142843291163445, 40.4618514329195, 40.938197672367096, 61.77523456513882, 60.682926177978516, 60.24919085204601, 59.41579297184944, 61.21281534433365, 47.88916848599911, 51.04372501373291, 47.89092779159546, 50.73048882186413, 52.01095171272755, 51.422332897782326, 49.013132974505424, 47.63426676392555, 46.47943273186684, 47.38376520574093, 48.03210161626339, 51.98493450880051, 48.72432567179203, 45.58306083083153, 44.81308914721012, 45.84780402481556, 45.69045826792717, 45.070966109633446, 44.28128868341446, 45.23792915046215, 47.72561386227608, 45.59290610253811, 50.24653159081936, 47.515287548303604, 49.653049036860466, 48.80677744746208, 47.13859096169472, 49.20949123799801, 48.98213803768158, 47.87945240736008, 51.220077350735664, 49.442783519625664, 51.459350511431694, 51.68057084083557, 49.78505775332451, 48.20332042872906, 48.99799458682537, 50.65073110163212, 50.08482366800308, 51.400731056928635, 53.28333243727684, 53.43257702887058, 50.42602255940437, 55.25513403117657, 57.07950733602047, 56.49009056389332, 58.00003454089165, 59.08844813704491, 57.95613169670105, 55.81333927810192, 58.804831355810165, 54.30963836610317, 60.00237889587879, 66.25626191496849, 75.39816096425056, 75.33792659640312, 79.16995257139206, 7.3223391361534595, 8.276852667331696, 1.7097275191918015, 0.29448051704093814, 1.0894480906426907, 46.964298114180565, 85.5884313583374, 68.71073260903358, 76.75337344408035, 72.26632341742516, 32.36654922366142, 24.687495678663254, 54.58945915102959, 67.02382072806358, 71.3505345582962, 20.91585986316204, 0.31657523300964385, 0.22371072467649356, 0.1564498955849558, 0.3088268847204745, 0.1391971143311821, 0.12196167706861161, 0.11064025136874989, 0.21703201899072155], [0.07167546486016363, 0.11057348776375875, 0.04256949796399567, 0.09018480603117496, 0.01195215474581346, 0.03557758740498684, 0.04775565190357156, 0.10305804025847465, 0.0928013664088212, 38.29473651945591, 70.52648797631264, 48.829101249575615, 36.06339745223522, 20.75765535235405, 43.42160761356354, 46.878407523036, 58.14576432108879, 71.53132885694504, 56.22052922844887, 1.3174325320869684, 0.09347841289127246, 0.40365492284763604, 0.45265537162777036, 0.6772721547167748, 14.894085489213467, 79.42187145352364, 71.17998450994492, 71.99165135622025, 67.35931232571602, 64.5111371576786, 52.115609496831894, 66.90091252326965, 68.34035128355026, 69.93695721030235, 63.890113681554794, 64.57567289471626, 59.58595924079418, 60.66513553261757, 63.32274712622166, 64.66464892029762, 65.09691372513771, 63.82513716816902, 62.03704811632633, 60.3040637075901, 58.13301220536232, 52.65377461910248, 45.086408481001854, 49.47947435081005, 47.75884687900543, 47.528039664030075, 44.270839244127274, 47.284495532512665, 44.98421296477318, 46.13333210349083, 45.42625844478607, 47.45317608118057, 43.59654642641544, 44.72353175282478, 45.14011099934578, 47.38529272377491, 47.32415400445461, 46.167534068226814, 45.440127700567245, 44.60806354880333, 42.38022789359093, 40.92020943760872, 41.98135569691658, 44.04743403196335, 41.27691529691219, 42.431171759963036, 40.50627864897251, 44.272556751966476, 43.19915235042572, 44.32192750275135, 45.95879606902599, 46.248990297317505, 42.678960263729095, 46.58773832023144, 45.5593691021204, 44.73677024245262, 44.543163031339645, 46.321999579668045, 56.81457035243511, 56.996675580739975, 56.101588010787964, 56.29050627350807, 57.10517875850201, 42.74711720645428, 41.767237186431885, 45.21136857569218, 59.67374213039875, 55.256718546152115, 53.10117781162262, 53.624903708696365, 49.62336502969265, 44.22610804438591, 43.182193860411644, 43.41706305742264, 44.62404549121857, 45.09366229176521, 42.70739793777466, 45.43802261352539, 42.84505695104599, 45.36352761089802, 41.957880556583405, 42.19204679131508, 42.88415685296059, 42.152863293886185, 40.147745087742805, 41.474428698420525, 38.44960480928421, 40.656123608350754, 39.97074298560619, 40.52086226642132, 39.892588779330254, 42.77395896613598, 44.82741057872772, 46.488168463110924, 43.89166139066219, 43.57730805873871, 41.51851013302803, 41.80236630141735, 44.18074227869511, 45.485292077064514, 45.629064962267876, 47.37879127264023, 44.05258655548096, 45.656522288918495, 44.656947925686836, 45.92433571815491, 44.958321154117584, 45.437426045536995, 44.538265094161034, 46.46673381328583, 44.74604174494743, 49.95451346039772, 45.89355356991291, 47.11661294102669, 44.945800825953484, 47.87849485874176, 46.211482509970665, 48.2406572252512, 46.62334240972996, 49.32296834886074, 51.29217088222504, 58.132818415760994, 55.88207758963108, 60.70675849914551, 58.45725640654564, 69.48059409856796, 65.81607833504677, 82.43906915187836, 22.913669161498547, 0.8163295523263514, 1.6162780649028718, 0.2136874117422849, 0.004659383548641927, 24.481459334492683, 69.53194454312325, 58.6923535913229, 54.83565554022789, 60.21701417863369, 33.737834841012955, 29.946533180773258, 33.534826934337616, 46.404056176543236, 55.69174200296402, 25.84449179470539, 0.3317360929213464, 0.0911105981504079, 0.043648072314681485, 0.07566324697108939, 0.036777517743757926, 0.044493560344562866, 0.06473579778685234, 0.02350444960029563, 0.07609352192957886, 0.031224939521052875, 0.04245744850777555, 0.06514315522508696, 0.048098538973135874, 0.022571627487195656, 0.041444290764047764, 0.00428412724431837, 0.09293248906033114, 45.91338090598583, 79.83149707317352, 56.69100098311901, 45.20202487707138, 21.96571882814169, 34.36306469142437, 39.207398146390915, 66.37276366353035, 76.57175078988075, 63.408523723483086, 1.1232392024248838, 0.07586653606267646, 0.36675168899819255, 0.25576400861609727, 0.07030336739262566, 19.624670147895813, 78.39932352304459, 73.69407400488853, 74.30803745985031, 69.88603234291077, 67.51875177025795, 55.55591069161892, 69.30008098483086, 71.8876813352108, 72.4373522400856, 68.02054524421692, 68.37229996919632, 63.69110696017742, 65.41990399360657, 65.04752397537231, 66.20326235890388, 66.7357885837555, 68.30435961484909, 64.73491474986076, 63.267007917165756, 60.25905892252922, 54.40288536250591, 47.08524942398071, 49.81705583631992, 50.494111105799675, 49.18030500411987, 46.280091628432274, 48.8617604970932, 48.81169058382511, 47.81973101198673, 47.19138912856579, 49.37737002968788, 45.930027812719345, 47.14891500771046, 48.41136686503887, 49.295891001820564, 48.5973896831274, 48.7016598880291, 44.31784652173519, 48.67462433874607, 44.8513150960207, 45.34346468746662, 43.384210020303726, 45.337001234292984, 42.56181254982948, 44.33809943497181, 44.63172867894173, 47.06293322145939, 44.818169474601746, 46.68633162975311, 46.1846749484539, 46.63980312645435, 45.6879997998476, 47.73742362856865, 47.45640970766544, 47.2792100161314, 46.08792833983898, 49.392850399017334, 57.69616864621639, 59.46355640888214, 58.38135547935963, 59.861611649394035, 57.718766033649445, 47.78676778078079, 46.49501949548721, 48.14692385494709, 62.58565127849579, 56.894141882658005, 58.09954360127449, 55.74535712599754, 51.96214333176613, 45.363440215587616, 46.549242585897446, 45.1298401504755, 45.343244299292564, 46.50026701390743, 45.80837354063988, 47.72041194140911, 45.32394893467426, 45.852413177490234, 44.87840764224529, 44.97152164578438, 42.813685834407806, 44.11514259874821, 42.4151898175478, 43.09018559753895, 42.1154049038887, 41.61271847784519, 41.914190500974655, 42.86537066102028, 43.67318071424961, 44.12593021988869, 45.78161157667637, 47.37064450979233, 45.78411944210529, 45.694071874022484, 43.76949034631252, 43.38842399418354, 46.59845754504204, 48.74291807413101, 47.41563409566879, 48.228528276085854, 47.69725978374481, 47.83994972705841, 45.859245210886, 47.69195906817913, 48.27475279569626, 48.63729514181614, 47.820958346128464, 49.23547804355621, 48.13591964542866, 51.55596412718296, 49.407369419932365, 49.30548548698425, 46.95593096315861, 49.94744583964348, 50.21635740995407, 51.481989696621895, 49.75446939468384, 52.56379544734955, 52.70267799496651, 60.709277763962746, 58.72402489185333, 63.86033847928047, 62.618302926421165, 72.42573246359825, 67.19635426998138, 85.48459053039551, 25.877361930906773, 0.628096143482253, 1.637790729291737, 0.2032898337347433, 0.057517016393831, 25.989003740251064, 76.36558905243874, 64.41908329725266, 63.046144768595695, 54.55980934202671, 33.543555065989494, 35.95006853342056, 40.8101711422205, 52.80286721885204, 64.01106119155884, 30.9381602704525, 0.40468906110618263, 0.04855351631704252, 0.05760281237598974, 0.04577906773192808, 0.10146375861950219, 0.01871505708550103, 0.05969780992018059, 0.01662658301938791, 0.16452584270155057, 0.16584358527325094, 0.1466823712689802, 0.1886274150456302, 0.18428531679091975, 0.12631828431040049, 0.09005909363622777, 0.1814041510806419, 0.28794296784326434, 59.29670736193657, 88.78795847296715, 67.12364137172699, 52.80198946595192, 32.171817272901535, 58.3333108574152, 63.72466675937176, 76.036526709795, 81.84026688337326, 70.85802778601646, 1.6259490209631622, 0.2409077706397511, 1.1307860724627972, 4.120354978367686, 2.884389362297952, 19.525250382721424, 77.96202778816223, 72.05193132162094, 76.04073688387871, 73.22495877742767, 68.14433500170708, 58.447194546461105, 71.90574556589127, 75.35906106233597, 77.01982274651527, 69.37090158462524, 71.22614443302155, 65.38133606314659, 68.87905597686768, 67.17895120382309, 68.27731266617775, 70.23611515760422, 71.68643653392792, 67.94116750359535, 67.57618188858032, 62.768573462963104, 58.923058211803436, 48.64593207836151, 53.84826332330704, 53.48748788237572, 53.14675636589527, 47.71666154265404, 51.74370065331459, 50.04381626844406, 50.97421154379845, 48.87534476816654, 53.53344641625881, 49.82728108763695, 50.394955426454544, 51.655989959836006, 53.51461462676525, 52.05393500626087, 50.778670236468315, 48.79212163388729, 50.61739929020405, 48.49454440176487, 46.56998187303543, 46.62137411534786, 48.504933044314384, 44.99702587723732, 47.442863434553146, 48.46025504171848, 49.83050711452961, 46.951564997434616, 48.205771297216415, 49.00413125753403, 49.5476046949625, 45.422831028699875, 50.82211330533028, 51.5810389816761, 49.61256600916386, 47.580845430493355, 52.68487975001335, 61.61541514098644, 62.676812186837196, 61.68800264596939, 64.04506176710129, 60.65559804439545, 50.97356557846069, 47.97824710607529, 52.09493860602379, 65.79365193843842, 60.15655182301998, 60.232650339603424, 59.11188147962093, 53.73814523220062, 48.25844407081604, 50.106676295399666, 48.26230466365814, 48.752748146653175, 49.912430718541145, 47.07077980041504, 50.92633031308651, 46.34427398443222, 50.328557789325714, 45.98703235387802, 47.986435666680336, 45.07853910326958, 47.52232477068901, 45.596865490078926, 44.66492369771004, 44.63108271360397, 45.49447998404503, 45.28707571327686, 45.855019837617874, 44.942726790905, 46.509033143520355, 47.8779286891222, 51.31821468472481, 47.880634143948555, 47.91017755866051, 46.555732637643814, 47.317226976156235, 48.81540298461914, 50.65238781273365, 48.32617923617363, 51.280361115932465, 49.492230266332626, 50.729774460196495, 48.1693160533905, 50.27898944914341, 49.34209652245045, 51.80230870842934, 49.57934059202671, 52.237468957901, 50.16015462577343, 56.049238219857216, 52.423271387815475, 53.004385605454445, 50.50054416060448, 52.956253588199615, 52.37969912588596, 55.08429519832134, 51.585355550050735, 54.71501961350441, 56.868063881993294, 63.29635374248028, 60.664360374212265, 65.70880249142647, 65.01485332846642, 77.17695951461792, 72.02861577272415, 89.16306674480438, 27.336576730012894, 2.9012704314664006, 5.445979395881295, 0.66819948842749, 0.41035877249669284, 30.489220060408115, 82.8730970621109, 69.61099550127983, 71.94746732711792, 71.66885107755661, 51.81301273405552, 43.580032512545586, 49.25783224403858, 63.43621663749218, 75.61348780989647, 38.430700823664665, 0.7747192319948226, 0.2204795175930485, 0.18354045285377651, 0.1343787502264604, 0.3781246271682903, 0.17732312553562224, 0.23430510540492833, 0.1613765093497932], [0.026841201215574984, 0.01057647177731269, 0.04710318906290922, 0.046030473968130536, 0.009889661414490547, 0.1345772747299634, 0.06378613819833845, 0.02084322306473041, 1.413568442221731, 55.62472879886627, 62.42908827960491, 47.62177683413029, 36.42214000225067, 18.88611327856779, 34.32495653629303, 50.038287565112114, 62.26855829358101, 81.29381820559502, 36.37012079358101, 0.03991714009316638, 0.08492103457683697, 0.1368937996448949, 0.7311722030863166, 6.50281336158514, 75.94638794660568, 81.67632848024368, 74.65812787413597, 74.29303586483002, 72.31898859143257, 67.84483507275581, 54.63292881846428, 58.10026936233044, 66.10034108161926, 67.59584203362465, 66.43885731697083, 67.70960032939911, 65.07346138358116, 62.52585768699646, 66.01674556732178, 64.46949139237404, 63.48350130021572, 64.63450133800507, 63.98768484592438, 59.95740830898285, 62.90964089334011, 57.87593699991703, 48.15844863653183, 45.916599333286285, 46.017236933112144, 47.59097568690777, 45.61800755560398, 44.58435662090778, 45.63970439136028, 45.73040932416916, 45.57846687734127, 45.730097740888596, 45.11545792222023, 43.286494463682175, 44.630611538887024, 46.79698549211025, 45.97263492643833, 47.18650259077549, 45.01279503107071, 44.37746152281761, 44.20466959476471, 42.02966250479221, 42.29595981538296, 42.2711281478405, 40.185431465506554, 39.57750968635082, 41.87638632953167, 43.08737754821777, 44.193372800946236, 44.81208600103855, 46.66502617299557, 44.51630987226963, 46.81823015213013, 44.58516977727413, 44.892223700881004, 43.38416062295437, 43.907939717173576, 43.69090296328068, 49.648702070117, 51.640604585409164, 53.014797046780586, 54.15089048445225, 53.85915353894234, 44.56940822303295, 47.115700989961624, 48.753542304039, 54.239908307790756, 51.96809761226177, 51.57378137111664, 47.80366167426109, 45.94994254410267, 45.31054325401783, 45.4086197912693, 44.9134873598814, 44.993085488677025, 42.380843460559845, 41.50957301259041, 42.735942006111145, 44.92212429642677, 42.8449809551239, 43.94982106983662, 43.3153311163187, 40.72620324790478, 41.62031427025795, 39.6363989263773, 39.35734950006008, 38.489183485507965, 40.949027091264725, 38.99796098470688, 39.649903401732445, 42.10399031639099, 42.49696522951126, 43.626219034194946, 43.7268528342247, 45.04445493221283, 44.38541069626808, 42.701006680727005, 43.37239645421505, 43.88980709016323, 45.05575552582741, 46.521732062101364, 44.32305604219437, 44.76038597524166, 46.58857427537441, 46.1467681825161, 45.02306208014488, 43.95617812871933, 44.91384454071522, 44.766701236367226, 47.698015943169594, 46.25978171825409, 48.555527329444885, 46.715301275253296, 48.59649673104286, 45.96012979745865, 48.95623102784157, 46.98949456214905, 48.766913786530495, 48.788747414946556, 55.70558845996857, 59.39752355217934, 64.66458052396774, 59.94950093328953, 64.94704976677895, 62.341290190815926, 67.6054935157299, 65.51033914089203, 78.05622473359108, 44.021671414375305, 0.5975515418685973, 0.6524848379194736, 0.2506850764621049, 0.06266374373808503, 13.124414999037981, 63.349585086107254, 64.89268988370895, 57.07848139107227, 56.12541653215885, 28.868570923805237, 9.966621994972229, 24.19467732310295, 43.81039895117283, 58.68530876934528, 45.37298150360584, 2.445323634892702, 0.14815807255217806, 0.1246122649172321, 0.04848379525355995, 0.049423328237026, 0.03905651225068141, 0.01438051574950805, 0.03239413010305725, 0.028952026914339513, 0.10345959410187788, 0.05720162960642483, 0.025318152765976265, 0.03473967299214564, 0.05692091966920998, 0.07107643294148147, 0.11993851570878178, 2.635390148498118, 65.38240760564804, 69.90546450018883, 57.237423062324524, 45.33456176519394, 24.680481255054474, 31.552944481372833, 50.6720669567585, 67.23031684756279, 87.54207372665405, 39.31071080267429, 0.07118800000171177, 0.17345423548249528, 0.5348162550944835, 0.7124834402929991, 6.650945087894797, 81.78675055503845, 80.13674229383469, 78.86355221271515, 74.72308158874512, 74.64387103915215, 68.75921040773392, 57.72028215229511, 60.88831275701523, 69.01297599077225, 68.2724717259407, 68.50155383348465, 69.06719908118248, 68.84749487042427, 65.23181408643723, 68.5139411687851, 65.02556875348091, 65.37031665444374, 66.44752845168114, 66.87706500291824, 63.15004259347916, 64.23556834459305, 61.47958002984524, 50.210315734148026, 48.35932105779648, 47.75068111717701, 48.77588890492916, 50.01996114850044, 46.4582222700119, 48.79767693579197, 48.58594849705696, 47.83916316926479, 48.36195431649685, 47.886242642998695, 45.574002116918564, 46.956744119524956, 48.473668321967125, 48.138001933693886, 47.93986156582832, 47.07749783992767, 46.13627314567566, 46.6282669454813, 43.54642331600189, 44.45173613727093, 43.97803075611591, 43.61615337431431, 42.409003749489784, 43.42044487595558, 43.76388564705849, 45.30816078186035, 46.3317346572876, 47.22079195082188, 46.170972883701324, 48.30176554620266, 46.51548519730568, 45.13654679059982, 46.7185615003109, 45.73422811925411, 44.40839186310768, 50.981602147221565, 52.23719537258148, 54.550655633211136, 54.73062917590141, 57.838072031736374, 49.647174552083015, 51.256350204348564, 51.57899849116802, 58.37668173015118, 54.95066776871681, 54.11634273827076, 49.90650303661823, 47.10774801671505, 48.19925844669342, 45.862334445118904, 47.653212547302246, 46.87262423336506, 44.42473478615284, 44.596405774354935, 43.63282687962055, 47.53917686641216, 43.945462703704834, 44.901776388287544, 44.80445981025696, 42.98396609723568, 43.77433888614178, 41.611726731061935, 40.108109414577484, 40.36776468157768, 43.123395815491676, 43.55702094733715, 42.331571504473686, 44.22759756445885, 45.20117372274399, 45.895419269800186, 46.36313617229462, 46.40061356127262, 47.21844367682934, 45.6295171380043, 44.084501042962074, 46.3646636903286, 48.68024043738842, 47.36630134284496, 46.23531483113766, 47.37338416278362, 48.56139421463013, 48.05332727730274, 46.4710807800293, 45.80974906682968, 47.242587581276894, 48.444805070757866, 50.63273146748543, 48.68761204183102, 51.59396208822727, 49.6488768607378, 50.913771986961365, 49.13694553077221, 50.243681743741035, 49.46028918027878, 50.50810195505619, 52.2926951944828, 59.28637571632862, 60.979542061686516, 66.3325010240078, 64.81750711798668, 66.85732126235962, 65.32542586326599, 69.509958922863, 69.8569031059742, 79.82015088200569, 47.7828273922205, 0.8840472623705864, 1.4998792670667171, 0.7814578141551465, 0.04738861163787078, 12.797066364437342, 70.79293727874756, 69.94379684329033, 63.73139999806881, 61.31553903222084, 40.471578910946846, 21.92848652601242, 34.78708773851395, 53.50693143904209, 68.43508780002594, 52.36924588680267, 3.026410541497171, 0.23356062738457695, 0.021864305090275593, 0.019285430971649475, 0.02416734703729162, 0.04816759952518623, 0.01856448459875537, 0.06449009495554492, 0.10022245725849643, 0.22189140901900828, 0.2246175252366811, 0.11974776149145328, 0.10675262950826436, 0.2303241955814883, 0.19146298320265487, 0.2216055485769175, 4.311362178996205, 79.59606170654297, 78.80021721124649, 66.29904761910439, 52.72940956056118, 29.72467828541994, 46.569195315241814, 68.48405197262764, 73.9922060072422, 95.33111616969109, 45.13501547276974, 0.1918557277531363, 0.1813933305675164, 1.4818295231088996, 3.6225907132029533, 6.5016876719892025, 81.75787970423698, 82.6971285045147, 79.46830496191978, 78.74606251716614, 77.66758158802986, 73.5443240404129, 59.04297597706318, 65.20891651511192, 72.3319610953331, 71.70183330774307, 73.45327332615852, 72.33022078871727, 70.47631546854973, 66.31382122635841, 70.00181972980499, 67.38178431987762, 66.52988523244858, 69.58993703126907, 70.74341833591461, 64.41356599330902, 68.27145338058472, 63.59520770609379, 52.775729075074196, 50.908866450190544, 50.251406729221344, 52.095234990119934, 49.99178186058998, 49.08605106174946, 50.81663019955158, 50.39025507867336, 50.74679754674435, 50.04134260118008, 50.38083538413048, 49.96878169476986, 49.18184772133827, 50.56072153151035, 49.799177795648575, 50.58504402637482, 48.5017716139555, 48.551317155361176, 49.42020133137703, 44.29645746946335, 47.15785212814808, 47.994590029120445, 44.86485376954079, 45.38664557039738, 45.148493349552155, 47.031588703393936, 46.84627264738083, 48.282021805644035, 50.62223643064499, 47.57184751331806, 51.25335596501827, 48.36889274418354, 47.24340073764324, 49.37062159180641, 48.64558629691601, 46.95392847061157, 55.6910390406847, 56.5518182516098, 57.846754565835, 61.18321493268013, 59.18617129325867, 52.43201091885567, 53.33468668162823, 54.64802920818329, 59.60310012102127, 57.29107618331909, 56.75396740436554, 52.65128195285797, 50.06411857903004, 50.24002633988857, 48.766871988773346, 51.173309460282326, 49.770082756876945, 47.199292704463005, 46.22611552476883, 45.74998587369919, 50.137177258729935, 47.003409415483475, 47.54948191344738, 47.936536744236946, 45.627263858914375, 46.02446794509888, 44.59232099354267, 43.274198323488235, 44.8856196552515, 48.28984938561916, 46.473334059119225, 43.86433705687523, 46.55945643782616, 46.78163431584835, 48.191047087311745, 47.75897987186909, 48.42174030840397, 50.47294244170189, 49.10631537437439, 47.228019163012505, 48.02839681506157, 50.715684816241264, 50.45363947749138, 47.47708059847355, 48.849407359957695, 51.95805475115776, 50.52677035331726, 49.97306406497955, 47.3785936832428, 50.31204007565975, 50.854723155498505, 53.50414998829365, 51.414220333099365, 54.37098607420921, 52.867551147937775, 54.41090293228626, 50.96313513815403, 52.96707920730114, 53.36549162864685, 53.56682762503624, 53.63748103380203, 61.84380568563938, 64.17560756206512, 70.67644312977791, 66.660415828228, 70.09259685873985, 68.00090029835701, 71.91322356462479, 72.6082518696785, 83.93231302499771, 49.81158033013344, 1.216313426848501, 5.824861340224743, 1.5325243840925395, 0.11074120571720414, 16.208461560308933, 79.38901081681252, 76.31268069148064, 72.10162505507469, 71.55438601970673, 41.65978655219078, 19.511179737746716, 41.802978068590164, 63.40683661401272, 77.11506843566895, 64.3291649222374, 3.8160000974312425, 0.3024383884621784, 0.24627654114738107, 0.09891756868455559, 0.10935350088402629, 0.15768839162774384, 0.15065761108417064, 0.11723676419933327], [0.04273210994142573, 0.03778952144784853, 0.04669603942602407, 0.03397362816031091, 0.10029839380877092, 0.02455492995068198, 0.010277183100697584, 0.16582163254497573, 5.900955582037568, 71.01228430867195, 60.738046020269394, 34.06245522201061, 31.42695654183626, 24.922533966600895, 44.92402799427509, 48.69528383016586, 64.38108533620834, 75.57548224925995, 20.83112820982933, 0.17906472348840907, 0.23343358654528856, 0.19343129242770374, 1.1479866807349026, 41.57116390764713, 69.87281665205956, 67.8215043246746, 75.22836327552795, 69.0264044702053, 71.7182332277298, 63.32825303077698, 57.661886885762215, 50.003302842378616, 55.18499739468098, 59.2313052713871, 61.6793467104435, 63.52484688162804, 63.9143867790699, 63.974332362413406, 64.80103880167007, 62.83889248967171, 65.05555674433708, 65.13254061341286, 63.31756420433521, 63.62353138625622, 62.11068816483021, 62.16095946729183, 55.160222724080086, 45.06994016468525, 46.80226340889931, 45.17712861299515, 46.1756694316864, 44.60396356880665, 45.65448559820652, 44.215487614274025, 46.738195046782494, 45.41829787194729, 46.503090262413025, 44.25278261303902, 45.97531758248806, 44.97983179986477, 46.483855694532394, 46.66434980928898, 44.637257382273674, 42.99318440258503, 44.67447638511658, 42.561626359820366, 41.425928100943565, 41.08044683933258, 41.20110556483269, 41.805603727698326, 39.704517871141434, 41.14180214703083, 43.235197216272354, 40.290993601083755, 44.00526009500027, 43.881588131189346, 42.86955043673515, 41.509185433387756, 42.12311089038849, 42.66238935291767, 43.31379219889641, 43.33857446908951, 44.793721586465836, 43.797806426882744, 47.21047930419445, 52.091154009103775, 58.10951426625252, 49.51380170881748, 47.553616091609, 49.686122462153435, 53.20342272520065, 50.20485542714596, 44.204202219843864, 42.107277140021324, 43.033990412950516, 40.142109990119934, 42.24661186337471, 41.51953607797623, 41.41031473875046, 42.242834866046906, 43.41190293431282, 41.61860056221485, 42.32942461967468, 42.5429617613554, 40.55750750005245, 39.52662281692028, 42.23868548870087, 37.925046756863594, 39.430799558758736, 40.310706943273544, 39.28366005420685, 39.12314906716347, 39.776277020573616, 40.68518064916134, 41.630060747265816, 43.133461475372314, 43.87936145067215, 46.344045996665955, 45.57428330183029, 44.39308248460293, 43.7073864787817, 43.85977730154991, 44.07232649624348, 46.45217299461365, 46.068602576851845, 45.34436523914337, 44.85503889620304, 45.155009999871254, 45.111114755272865, 44.8897348344326, 45.15095181763172, 45.54772272706032, 45.6989736109972, 45.42054735124111, 47.22149111330509, 48.49252291023731, 48.511236906051636, 46.708260253071785, 48.502592369914055, 49.52562667429447, 51.29893071949482, 55.043926164507866, 58.95316019654274, 62.572313994169235, 64.53847289085388, 67.5508600473404, 67.08590939640999, 67.65627399086952, 65.80174550414085, 66.86447247862816, 66.59437537193298, 72.7739229798317, 60.838763415813446, 2.8467915672808886, 1.4871845045126975, 0.14406775531824678, 0.04290210999897681, 0.788487852551043, 43.742017820477486, 71.73342481255531, 56.33045732975006, 54.10706743597984, 44.115047603845596, 11.520170532166958, 14.758698754012585, 41.28345474600792, 50.07758505642414, 53.8555209338665, 4.238879168406129, 0.15157854213612154, 0.008756453862588387, 0.06405747481039725, 0.024046395519690122, 0.06778279639547691, 0.042022646448458545, 0.03619369243097026, 0.03560970013495535, 0.020074051935807802, 0.05617897979391273, 0.08401261613471434, 0.10904249647865072, 0.10832719970494509, 0.08938851868151687, 0.2523576992098242, 8.503608349710703, 81.39439880847931, 66.78326323628426, 45.01701280474663, 41.19735896587372, 32.984084486961365, 36.42180182039738, 56.053148210048676, 70.38757503032684, 83.05658161640167, 22.249191217124462, 0.20389783079735935, 0.1405521424021572, 0.45191087876446545, 0.7708437368273735, 52.26037032902241, 76.00298210978508, 71.5728834271431, 77.07570254802704, 74.1482712328434, 73.2510557770729, 66.8335497379303, 59.32304374873638, 53.242028653621674, 57.547349631786346, 60.30058689415455, 66.87864571809769, 65.70830851793289, 65.81415563821793, 65.82534983754158, 66.82825282216072, 64.00698781013489, 67.40658178925514, 67.3612730205059, 65.10883748531342, 66.87416195869446, 62.81087279319763, 64.14945736527443, 57.403504550457, 46.344304382801056, 48.52893255650997, 47.761293947696686, 48.74846577644348, 47.0565989613533, 48.008653074502945, 45.45748516917229, 49.0268312394619, 48.21812443435192, 48.050595223903656, 46.34465016424656, 49.32559780776501, 46.33358135819435, 48.73043954372406, 49.53314267098904, 45.927386954426765, 43.9165348559618, 47.302624359726906, 44.72526825964451, 44.15832728147507, 44.55671310424805, 43.955273777246475, 42.82681792974472, 41.88268259167671, 42.8912852704525, 45.109845623373985, 43.52560803294182, 45.937365218997, 45.335416719317436, 45.348381623625755, 44.301917776465416, 46.04217879474163, 43.50351221859455, 45.18526017665863, 45.99153891205788, 45.83645023405552, 45.62225952744484, 51.03088930249214, 54.12885546684265, 58.74550133943558, 53.0681461840868, 49.37795899808407, 53.96433189511299, 57.922218516469, 54.40591759979725, 46.251897141337395, 46.28499336540699, 45.43768063187599, 43.419658318161964, 44.36310589313507, 44.038565307855606, 43.53466674685478, 43.98525036871433, 45.46352684497833, 44.21836405992508, 45.35447649657726, 43.45204398036003, 42.8101672232151, 41.76998443901539, 44.49698030948639, 40.73995091021061, 41.18170000612736, 44.037801548838615, 41.52838960289955, 41.3171361386776, 43.44244949519634, 42.93677642941475, 45.60412310063839, 45.59111259877682, 45.90895414352417, 47.48479798436165, 47.131967917084694, 45.98861686885357, 46.31091557443142, 44.76251006126404, 48.09267796576023, 48.76702398061752, 48.89784716069698, 49.37561832368374, 47.68563240766525, 46.22071981430054, 47.040472626686096, 46.419566944241524, 46.69366143643856, 47.478440925478935, 48.67585927248001, 49.629269912838936, 50.038108974695206, 50.125447288155556, 51.8643593788147, 50.63986748456955, 49.88068342208862, 50.83472482860088, 54.99594993889332, 57.49463886022568, 62.69548058509827, 65.53461983799934, 67.20238834619522, 68.4961961209774, 70.89553937315941, 72.99886330962181, 69.67662557959557, 68.87134999036789, 68.95635902881622, 73.5083855688572, 63.135154992341995, 3.7085404386743903, 1.595820200163871, 0.5000562546774745, 0.06811639919760637, 0.6211581907700747, 49.16541360318661, 77.1882601082325, 62.79544182121754, 61.36073760688305, 45.404831394553185, 12.879496291279793, 21.401654295623302, 47.17078283429146, 57.921089977025986, 61.688169836997986, 6.658201748505235, 0.3316398512106389, 0.09337088311440311, 0.08277243541670032, 0.05315233087458182, 0.032561577172600664, 0.04394449722894933, 0.026329926404287107, 0.18931553437141702, 0.27436386211775243, 0.12014320003800094, 0.0877103372476995, 0.23989362583961338, 0.19008064409717917, 0.3079582453938201, 0.43242739455308765, 12.248119320720434, 95.87274670600891, 75.2160595357418, 52.48276099562645, 41.584611386060715, 32.927197739481926, 59.519778192043304, 65.79421430826187, 77.18158006668091, 90.57779923081398, 26.716847084462643, 0.3348340548109263, 0.6033275881782174, 1.239791417028755, 1.0888090124353766, 55.60207441449165, 82.76616320014, 75.8054231107235, 79.50017005205154, 74.69370916485786, 76.50483638048172, 69.01951164007187, 63.00602272152901, 54.31152306497097, 58.23179170489311, 63.15457575023174, 68.23520332574844, 71.61788061261177, 69.27887812256813, 68.29632684588432, 71.35191768407822, 67.24208101630211, 70.85144653916359, 71.44197285175323, 67.91809514164925, 66.9644147157669, 64.92939591407776, 67.31312960386276, 60.66262386739254, 48.3731447160244, 50.90121366083622, 50.700386837124825, 50.70610553026199, 50.16732484102249, 51.020189076662064, 47.95335844159126, 51.212367564439774, 50.950250029563904, 51.08471721410751, 49.90312121808529, 50.58366850018501, 50.11945880949497, 49.977661818265915, 51.83157093822956, 49.36693958938122, 46.23704373836517, 50.58410167694092, 48.354594111442566, 47.7006796002388, 47.16554291546345, 47.30971857905388, 47.12907247245312, 43.78847032785416, 44.800580218434334, 49.819518104195595, 44.86629009246826, 47.1187674254179, 48.18184018135071, 46.633339673280716, 47.48984031379223, 48.646980822086334, 46.04099705815315, 47.741185426712036, 48.44866566359997, 49.53826479613781, 48.61335642635822, 54.90081824362278, 57.33244836330414, 61.79201826453209, 57.60936610400677, 53.887158036231995, 58.37985835969448, 59.80731636285782, 56.013949513435364, 49.625299125909805, 48.30889396369457, 48.59495021402836, 45.71874015033245, 47.323565036058426, 45.83074674010277, 45.399059504270554, 46.03074140846729, 47.10123896598816, 46.63106359541416, 47.66710840165615, 47.14899480342865, 45.38560062646866, 44.472262635827065, 48.046822026371956, 41.60242483019829, 43.68882067501545, 45.94547018408775, 43.84764455258846, 44.294576570391655, 46.80275358259678, 45.35500466823578, 47.34544426202774, 47.00495973229408, 47.206341326236725, 49.397011175751686, 50.61729669570923, 48.44229340553284, 48.59465003013611, 48.483889773488045, 49.938824102282524, 50.62548525631428, 51.55069760978222, 50.98202012479305, 47.7953477203846, 49.23566423356533, 49.08435635268688, 49.73323613405228, 49.776489213109016, 50.995228216052055, 50.75676441192627, 52.526584044098854, 52.92471148073673, 52.04557925462723, 53.58442448079586, 54.11910519003868, 53.22624810039997, 55.201648101210594, 57.92811959981918, 60.68896785378456, 65.79790771007538, 69.87188950181007, 69.81670126318932, 73.07055026292801, 71.65789246559143, 72.63997256755829, 71.41019135713577, 72.32134446501732, 71.11657351255417, 76.56127855181694, 66.16582676768303, 4.1717899683862925, 4.879364250227809, 1.8049334292300045, 0.1483525152434595, 1.3451698562130332, 56.65785536170006, 81.79210066795349, 69.79732230305672, 71.45947471261024, 56.91760182380676, 21.948256865143776, 27.261450961232185, 59.925110042095184, 67.84659057855606, 76.01776331663132, 10.068763364106417, 0.5576490517705679, 0.2395053193322383, 0.20119246502872556, 0.12742939812596887, 0.10777196192066185, 0.09978562913602218, 0.10191613473580219], [0.017587339571036864, 0.026697846114984713, 0.05084542790427804, 0.04060715189552866, 0.0783667054201942, 0.053248101321514696, 0.167130098270718, 0.2546299179084599, 12.147569116204977, 74.06088352203369, 51.563616916537285, 39.66220714151859, 26.26893661916256, 19.848816320300102, 48.45174349844456, 55.739794224500656, 66.78858295083046, 70.46189144253731, 9.363392014056444, 0.5632629536557943, 0.31394149933476, 0.8723039331380278, 13.502916488796473, 53.859058544039726, 73.02870690822601, 78.87596994638443, 72.64833971858025, 70.35776183009148, 67.8016085922718, 60.108792185783386, 56.24971926212311, 55.945606380701065, 53.26181419193745, 52.82120883464813, 55.285539999604225, 57.759028673172, 57.39357948303223, 58.74076299369335, 60.543922036886215, 63.03932413458824, 64.00885730981827, 65.13560324907303, 60.237092301249504, 61.97569280862808, 61.15367531776428, 63.78006398677826, 54.89064998924732, 44.21750150620937, 46.877886950969696, 45.94248354434967, 46.09070599079132, 42.129847928881645, 46.32426045835018, 46.80222161114216, 45.92473469674587, 47.15480849146843, 43.19209232926369, 44.5045381039381, 45.17830274999142, 44.29491475224495, 46.95500761270523, 42.23029933869839, 48.02432723343372, 43.953670263290405, 44.95756879448891, 42.79231958091259, 40.298384204506874, 40.677098482847214, 41.14496737718582, 39.402483478188515, 39.39060531556606, 42.31015965342522, 41.000392735004425, 38.343404307961464, 40.0393483042717, 40.37845350801945, 41.375877186656, 42.72804982960224, 44.8889634758234, 45.516085624694824, 48.70319500565529, 44.1800507158041, 48.30661028623581, 47.74660773575306, 49.344289004802704, 52.6884363591671, 58.351667672395706, 46.8564523011446, 42.988016679883, 49.08573567867279, 54.734181985259056, 51.31213881075382, 45.87908394634724, 42.4656967073679, 41.82268001139164, 44.09265920519829, 41.874083653092384, 39.41322170197964, 41.28006532788277, 42.702686190605164, 42.86128208041191, 39.02851514518261, 41.147216856479645, 41.54382437467575, 42.213352248072624, 41.15050747990608, 37.25917808711529, 38.806002885103226, 39.893743917346, 37.89439000189304, 39.67671476304531, 39.14549946784973, 40.15581205487251, 39.934770315885544, 44.63365517556667, 45.30193291604519, 45.19754111766815, 45.59462361037731, 45.93514993786812, 44.05428886413574, 44.25090551376343, 42.889370173215866, 46.57220855355263, 45.74016720056534, 44.77311909198761, 44.10125434398651, 45.89237563312054, 46.04440547525883, 43.72981287539005, 43.76214154064655, 46.844460144639015, 45.118756145238876, 45.24139456450939, 45.07510408759117, 47.42587074637413, 50.25731161236763, 51.11803002655506, 49.68285843729973, 54.553843662142754, 53.83738070726395, 60.53441494703293, 61.388928294181824, 61.79864890873432, 61.4754306524992, 66.00371986627579, 64.8689791560173, 72.99189448356628, 78.07122632861137, 71.3474415242672, 67.16134294867516, 69.9808144569397, 68.08280110359192, 72.89151147007942, 6.260770624503493, 0.7474179938435555, 0.2707684534834698, 0.03285665137809701, 0.036935687967343256, 26.219704560935497, 73.04119303822517, 60.3170096129179, 58.486169055104256, 54.14259172976017, 28.761971443891525, 23.342726938426495, 33.25487695634365, 44.53512266278267, 60.13376444578171, 10.166405774652958, 0.310295001254417, 0.15999715367797762, 0.014881868046359159, 0.15147796628298238, 0.020118443499086425, 0.05898063551285304, 0.0717359795817174, 0.07998858010978438, 0.05167775394511409, 0.026474507903913036, 0.031322186841862276, 0.07194603706011549, 0.0968534556159284, 0.06483452569227666, 0.2635829203063622, 16.09634667634964, 83.157017827034, 58.99767480790615, 44.6311055123806, 33.00433360040188, 24.275662377476692, 47.11771868169308, 61.67933151125908, 71.89862474799156, 76.9895687699318, 10.56749040260911, 0.5091983859892935, 0.6790747423656285, 1.6067468700930476, 22.314887791872025, 65.92205464839935, 75.78529939055443, 79.38544660806656, 74.68005269765854, 72.73033931851387, 69.95755970478058, 62.38145783543587, 56.21061556041241, 57.1694865077734, 55.07605344057083, 56.561458334326744, 58.59546639025211, 60.22926852107048, 58.89872431755066, 61.41675040125847, 62.92027272284031, 64.91231203079224, 65.6080774962902, 66.07886463403702, 62.64136388897896, 64.08925339579582, 63.22951912879944, 65.68060800433159, 56.93448431789875, 47.93762728571892, 47.132963463664055, 46.67505003511906, 49.49433155357838, 44.80318307876587, 47.434819266200066, 49.486226588487625, 48.06678615510464, 49.32132303714752, 45.97392685711384, 47.15996101498604, 47.13287226855755, 47.03854613006115, 47.79624067246914, 45.76664038002491, 48.74766401946545, 47.087179720401764, 45.894628912210464, 44.16460074484348, 43.890977427363396, 44.675331339240074, 43.35695408284664, 42.968664318323135, 43.325974345207214, 44.03134189546108, 43.84983703494072, 41.65953956544399, 40.8643714338541, 44.207975417375565, 44.15101267397404, 45.41543282568455, 46.75545372068882, 48.18734608590603, 49.959449395537376, 46.233331337571144, 49.80390854179859, 50.34814193844795, 50.603435039520264, 53.94952028989792, 59.69560235738754, 48.564118668437004, 45.874375998973846, 52.571296244859695, 56.66319787502289, 55.14585189521313, 49.635915756225586, 43.30869287252426, 45.55895112454891, 45.493773221969604, 44.5896003395319, 42.29131266474724, 43.392808958888054, 45.30962750315666, 45.72530619800091, 41.206641867756844, 43.6894666403532, 44.09212723374367, 44.30950976908207, 43.40077333152294, 41.97822466492653, 41.80964671075344, 43.1087552011013, 41.502923369407654, 42.103967517614365, 42.37893596291542, 44.18430268764496, 42.9862155765295, 45.656153708696365, 46.038546189665794, 45.3374420106411, 46.99968941509724, 48.17210890352726, 47.59632959961891, 46.09449818730354, 45.77458955347538, 46.918601766228676, 47.342077642679214, 48.48705880343914, 47.0759741216898, 47.92019382119179, 48.347689881920815, 45.33845275640488, 44.70334343612194, 48.99367801845074, 46.60303629934788, 47.58657552301884, 49.215164333581924, 49.41721089184284, 52.04102709889412, 53.87947864830494, 52.38679714500904, 58.08127798140049, 57.1966702491045, 64.36576455831528, 63.33653658628464, 66.8562725186348, 63.193869441747665, 67.52431467175484, 67.24802389740944, 71.17416322231293, 75.66036969423294, 73.74518126249313, 69.41123262047768, 72.72251933813095, 68.12727391719818, 76.11441493034363, 6.643024412915111, 1.262362205889076, 1.5278711775317788, 0.016782168713689316, 0.04258647830283735, 28.416792266070843, 79.77924227714539, 66.40737220644951, 64.33656692504883, 57.50055894255638, 34.981238320469856, 27.46557980775833, 41.76430754363537, 50.36613017320633, 69.62163493037224, 14.707593396306038, 0.5837710469495505, 0.1006115207565017, 0.06677487821434624, 0.11827741851448081, 0.03251789807109162, 0.08038890198804438, 0.09036955627379939, 0.14211175090167671, 0.14348527329275385, 0.16643614566419274, 0.12580575712490827, 0.15325253043556586, 0.26677166169974953, 0.2975305955624208, 0.4566483339294791, 22.764966040849686, 96.21304124593735, 65.10488569736481, 56.00908577442169, 36.56264126300812, 30.47842863947153, 64.29810538887978, 71.80220872163773, 77.4688370525837, 87.08967760205269, 13.184240888804197, 0.6880118034314364, 1.4418183825910091, 3.7003867886960506, 21.799606941640377, 72.81304568052292, 75.53823664784431, 82.49148353934288, 76.55971303582191, 75.95597863197327, 73.30605402588844, 66.52211844921112, 59.49772037565708, 59.531466364860535, 58.43840941786766, 58.95858630537987, 62.02272668480873, 63.51026326417923, 62.95493446290493, 64.83957633376122, 65.69808706641197, 68.45782577991486, 69.66219395399094, 70.21819531917572, 66.36612921953201, 66.40336722135544, 65.97239434719086, 68.03837388753891, 60.00380001962185, 49.78844717144966, 50.16241930425167, 50.57271748781204, 50.358211398124695, 46.87133230268955, 52.662536948919296, 51.64136454463005, 50.544146820902824, 52.372342720627785, 47.65987738966942, 51.65090203285217, 49.60540719330311, 49.11425694823265, 50.832718536257744, 47.09611304104328, 51.3958141207695, 49.32487204670906, 49.6374698728323, 46.88199073076248, 45.42548708617687, 45.55075876414776, 44.87330071628094, 46.11920066177845, 44.96878199279308, 46.8904946744442, 47.09746956825256, 43.61403688788414, 43.71992580592632, 46.979432702064514, 45.52049718797207, 47.8184162825346, 50.077117681503296, 49.6559102833271, 53.49016293883324, 48.67645584046841, 53.349768072366714, 52.13037550449371, 54.50899086892605, 58.06215360760689, 61.821033507585526, 54.24030728638172, 48.98548565804958, 55.734485909342766, 59.68024358153343, 57.641409784555435, 50.42539179325104, 45.90087577700615, 48.61834175884724, 49.07672256231308, 47.04837240278721, 44.181357845664024, 45.78134559094906, 48.59372287988663, 48.213420286774635, 43.58298495411873, 45.93265347182751, 47.0377291738987, 46.27987504005432, 47.37650379538536, 42.67418771982193, 44.79869931936264, 45.227787494659424, 44.46906320750713, 44.5234040915966, 44.848526045680046, 46.211946085095406, 44.61950093507767, 48.87048862874508, 49.03698429465294, 46.93297639489174, 49.88425903022289, 51.21631555259228, 48.63982580602169, 47.42302089929581, 48.962504491209984, 51.972680166363716, 50.571759939193726, 50.213051587343216, 48.29011917114258, 51.119971722364426, 51.51993826031685, 47.61313609778881, 47.74004548788071, 51.39908194541931, 49.629646092653275, 50.80157160758972, 50.108682587742805, 51.99143975973129, 55.73118768632412, 57.595481649041176, 54.82992924749851, 60.85611328482628, 58.17712403833866, 67.78751894831657, 67.60487034916878, 69.39533427357674, 66.11645221710205, 71.56454667448997, 70.40285781025887, 76.15679785609245, 77.47337400913239, 75.39241567254066, 72.56199315190315, 75.50096824765205, 72.76067689061165, 78.12418788671494, 7.422566832974553, 4.063754165545106, 3.4029055014252663, 0.17886750516481698, 0.19804369570920244, 33.257692605257034, 87.32484698295593, 70.94759657979012, 76.51058167219162, 67.75456711649895, 43.404755517840385, 35.74163071811199, 54.06387135386467, 60.3437639772892, 80.52543863654137, 24.33101210743189, 0.6648902816232294, 0.24675041728187352, 0.22941694973269477, 0.3103859885595739, 0.17382771387929097, 0.12330120909609832, 0.15340198413468897], [0.0367256898607593, 0.08366236696019769, 0.029620902350870892, 0.05172992321604397, 0.03392851671378594, 0.048381338056060486, 0.17728071921737865, 0.25032783625647426, 16.41195774078369, 73.92844542860985, 51.600011363625526, 44.577976763248444, 17.429398745298386, 31.738197840750217, 41.14440880715847, 58.12825866043568, 68.11584413051605, 56.997283548116684, 1.5160929970443249, 0.06952750394702889, 0.31755065254401416, 8.157332930713892, 49.76161681115627, 69.04469668865204, 82.56638512015343, 67.81796291470528, 72.42233544588089, 62.039031609892845, 63.586544170975685, 54.54844415187836, 53.54299910366535, 50.75148269534111, 55.49744322896004, 51.21080964803696, 53.45500722527504, 50.703457072377205, 54.82286162674427, 52.360415160655975, 59.00891840457916, 58.805526718497276, 60.980184227228165, 59.9219524115324, 65.52011981606483, 62.959285229444504, 59.90922309458256, 62.11662344634533, 54.675562530756, 46.628878712654114, 47.84138984978199, 43.793451860547066, 46.016370579600334, 46.846337243914604, 45.85611417889595, 43.07308651506901, 45.272492095828056, 46.6701976954937, 43.79570133984089, 44.055303409695625, 45.16982540488243, 44.36468280851841, 46.74628861248493, 46.05693720281124, 45.38109786808491, 43.290191665291786, 46.29216358065605, 45.10929465293884, 43.836780935525894, 42.795085832476616, 40.64987674355507, 40.62744274735451, 39.37781140208244, 39.73674014210701, 42.35532782971859, 40.259307101368904, 40.37414453923702, 38.60994480550289, 40.36910220980644, 40.99777087569237, 45.014702528715134, 49.545575603842735, 52.726445719599724, 52.06967756152153, 53.58084887266159, 50.610411465168, 53.952278941869736, 52.90146052837372, 56.035577952861786, 45.69907620549202, 36.52594283223152, 44.306735917925835, 54.11318890750408, 52.009937167167664, 52.01962284743786, 51.8013321608305, 50.254203379154205, 50.35904735326767, 45.855920389294624, 41.34258717298508, 38.93053740262985, 40.49413450062275, 39.70356412231922, 39.69292089343071, 38.71475078165531, 41.17267929017544, 40.80686911940575, 39.68397617340088, 38.135954439640045, 39.969397857785225, 38.725154623389244, 39.90815654397011, 40.152297243475914, 38.547168374061584, 40.364139676094055, 43.246250823140144, 46.21706061065197, 43.99419508874416, 44.707781597971916, 44.13641005754471, 46.58593341708183, 43.012586161494255, 45.02893656492233, 43.55450928211212, 44.77400824427605, 47.02928602695465, 47.393245697021484, 47.43751712143421, 46.131417006254196, 43.8350710272789, 45.46383082866669, 43.54792043566704, 45.922808200120926, 48.253827318549156, 52.94211074709892, 54.19455014169216, 56.41480140388012, 56.39752373099327, 59.011407271027565, 56.36191964149475, 59.93228405714035, 59.49918709695339, 63.00932854413986, 61.17952913045883, 65.00304356217384, 63.386792689561844, 63.22868697345257, 57.25361779332161, 54.3672850728035, 52.09044724702835, 71.56973719596863, 63.74350234866142, 74.29508775472641, 62.921633049845695, 81.4789442718029, 11.523255966603756, 1.1796265142038465, 0.2873200981412083, 0.0833567208610475, 0.11584625404793769, 13.049772754311562, 70.05408212542534, 62.75628112256527, 59.232612401247025, 40.045203790068626, 15.370326284319162, 12.961801774799824, 31.731508299708366, 46.11420013010502, 65.30426859855652, 34.69308838248253, 0.09078154471353628, 0.03859573131194338, 0.059839875539182685, 0.01531924350274494, 0.014238156054489082, 0.027253594125795644, 0.06921880019945092, 0.04018825406092219, 0.0739126319240313, 0.05513537173101213, 0.037824576793354936, 0.060362102594808675, 0.043140179841429926, 0.22738781408406794, 0.21772332955151796, 22.251851074397564, 83.8032491505146, 56.14267520606518, 52.9492961615324, 21.746896170079708, 31.782153882086277, 43.65026034414768, 64.87930700182915, 73.40805575251579, 62.545628026127815, 1.7614527186378837, 0.0347314277314581, 0.11378161405446008, 12.854640875011683, 58.907543644309044, 67.31240764260292, 83.92772287130356, 71.11961334943771, 72.6552401483059, 64.72703397274017, 66.06374144554138, 55.8381025493145, 54.74148519337177, 52.99489751458168, 58.188728615641594, 53.58277536928654, 54.07196491956711, 53.295366391539574, 56.99745073914528, 56.219480484724045, 60.26078782975674, 60.24601422250271, 62.993878573179245, 62.7857219427824, 65.7565051317215, 64.69775274395943, 63.76336008310318, 64.83311668038368, 56.75819657742977, 48.19094829261303, 50.26482380926609, 46.347424015402794, 48.55370722711086, 47.30949819087982, 48.33174213767052, 46.35697290301323, 48.678427934646606, 47.379216849803925, 46.63336627185345, 46.322770938277245, 46.06276609003544, 46.22629791498184, 48.693193942308426, 49.112691432237625, 46.667906418442726, 45.5084328353405, 48.108751103281975, 45.71054399013519, 46.32364869117737, 43.50302204489708, 43.31400878727436, 42.80520848929882, 42.30861313641071, 42.57831506431103, 43.46973203122616, 42.02459737658501, 42.65948250889778, 41.8567755818367, 42.672717198729515, 43.8728030025959, 49.298087283968925, 51.61840237677097, 53.546149134635925, 55.78406564891338, 55.068716034293175, 51.67645186185837, 57.226320058107376, 55.246789678931236, 59.0908458083868, 48.86671543121338, 39.20209743082523, 48.00736874341965, 55.89450292289257, 55.81061102449894, 55.65958812832832, 54.14968594908714, 53.2686348259449, 51.70748859643936, 49.629338309168816, 43.82667347788811, 41.810053288936615, 42.48457029461861, 42.5421068072319, 43.10107581317425, 43.64215537905693, 42.689877077937126, 42.590352818369865, 40.668712332844734, 41.757752895355225, 42.09878459572792, 41.76918648183346, 42.045123875141144, 42.42020174860954, 40.04416644573212, 43.04993435740471, 46.56663045287132, 47.681878209114075, 45.56979574263096, 47.07171455025673, 46.56670644879341, 46.273806765675545, 46.09143175184727, 46.56379200518131, 42.82072305679321, 49.348328188061714, 47.87867344915867, 48.67386057972908, 48.75149801373482, 48.52165214717388, 46.70922540128231, 47.252991423010826, 47.59270839393139, 48.7960734218359, 52.23263941705227, 56.56164072453976, 55.60182362794876, 58.86578768491745, 58.9674436300993, 59.70312215387821, 58.41716095805168, 62.27471396327019, 63.24685379862785, 65.5904008448124, 64.10563811659813, 67.91105031967163, 64.55391526222229, 65.60271978378296, 56.81229427456856, 58.53065326809883, 50.46370893716812, 71.9587755203247, 66.67123004794121, 76.63969874382019, 64.49096024036407, 81.72558143734932, 12.933070566505194, 1.132243531756103, 1.214910945855081, 0.15145154582569376, 0.10744140192400664, 13.898802045732737, 78.84877860546112, 67.27402210235596, 67.98152893781662, 44.845660999417305, 24.26711093634367, 23.625921942293644, 40.74060447514057, 51.617862805724144, 75.2506984770298, 39.53896075487137, 0.1432704066974111, 0.07911841195891611, 0.08321530462126248, 0.020240107478457503, 0.056199214450316504, 0.01871402550023049, 0.06490557891083881, 0.14662245026556775, 0.20515065029030666, 0.09945302081177942, 0.14019549591466784, 0.11828017188236117, 0.25475685484707355, 0.4368391359457746, 0.41763244313187897, 31.580101624131203, 95.85209861397743, 65.36843195557594, 63.78367379307747, 26.416488401591778, 45.41802428662777, 57.042432725429535, 72.72910058498383, 80.33721953630447, 71.62204518914223, 2.279480346478522, 0.12636082421522588, 0.8486693794839084, 14.664322268217802, 63.14874306321144, 71.77559494972229, 87.5085823237896, 76.82523518800735, 75.75411066412926, 67.37701177597046, 69.90832194685936, 58.71673308312893, 58.165679052472115, 54.16039377450943, 62.077800929546356, 58.41670498251915, 58.0023106187582, 56.37268826365471, 60.46104848384857, 59.07700315117836, 65.45016556978226, 64.3147560954094, 66.6200315952301, 66.59008160233498, 69.6750296652317, 68.69159683585167, 67.71637916564941, 69.78856757283211, 59.95175041258335, 49.852279946208, 51.605327278375626, 47.27104425430298, 50.489247366786, 51.2623842805624, 50.877335742115974, 47.25826933979988, 50.3312062472105, 50.99997416138649, 47.1903707832098, 49.013056978583336, 49.9922264367342, 48.24283070862293, 52.31360927224159, 49.058684930205345, 50.07918857038021, 48.64680603146553, 50.021549463272095, 48.561401814222336, 48.39886173605919, 46.732905730605125, 45.81914596259594, 45.243207067251205, 45.52976109087467, 46.23447127640247, 46.75446957349777, 45.44846445322037, 46.37754499912262, 44.11489561200142, 45.597036480903625, 47.03465893864632, 51.31056189537048, 54.75192703306675, 55.84077760577202, 58.81564177572727, 57.54589430987835, 55.5131059885025, 60.24205103516579, 59.16766628623009, 60.69921590387821, 52.521910294890404, 43.45474563539028, 52.37971432507038, 58.82495127618313, 57.54664286971092, 59.02072437107563, 58.99705544114113, 57.19828516244888, 54.90704230964184, 52.168947234749794, 46.15862734615803, 43.523856326937675, 45.09273134171963, 45.84729865193367, 44.87777307629585, 44.58015784621239, 45.32095089554787, 46.973619014024734, 45.456383228302, 43.54322388768196, 44.48390141129494, 45.31012147665024, 46.02815754711628, 44.63133729994297, 42.65132814645767, 45.767905712127686, 48.47941741347313, 50.78938566148281, 49.22478161752224, 48.62998053431511, 48.13445672392845, 50.96595838665962, 48.504503667354584, 51.38375736773014, 46.747234761714935, 53.34148071706295, 50.47465994954109, 50.01174598932266, 51.15101605653763, 50.89866779744625, 47.2140359133482, 50.1374926418066, 47.95877695083618, 52.55198948085308, 54.48421619832516, 59.68497812747955, 59.14308920502663, 62.511703446507454, 60.090062990784645, 64.24973398447037, 61.25892587006092, 65.76959162950516, 65.43787702918053, 68.6704395711422, 67.80988454818726, 72.36908510327339, 67.40072250366211, 68.94130423665047, 58.70589606463909, 59.814592972397804, 58.423920795321465, 75.30752822756767, 67.4866358935833, 79.7670829296112, 67.48847499489784, 86.68719559907913, 14.922275226563215, 4.537461446598172, 4.661934217438102, 0.15654842311050743, 0.19300467625726014, 17.605796679854393, 86.81496754288673, 73.12471255660057, 77.6614411175251, 49.06463921070099, 23.422313667833805, 26.239845380187035, 48.724861443042755, 62.70178824663162, 84.72492769360542, 49.2593901604414, 0.4934887820854783, 0.17947955435374752, 0.15911607595626265, 0.1013084567966871, 0.17543461202876642, 0.09663585049565881, 0.2806780842365697], [0.06251437167520635, 0.023512936058978084, 0.0354297998273978, 0.05957997542282101, 0.060767964605474845, 0.02516036845918279, 0.09847972381976433, 0.18828758562449366, 24.77801252156496, 68.50776270031929, 46.83255918323994, 32.15727925300598, 20.269560143351555, 41.0308974981308, 45.06914980709553, 62.72763825953007, 67.78261721134186, 46.36002413928509, 0.23464965488528833, 0.21458343631820753, 0.26424913143273443, 10.8162697032094, 66.93545266985893, 71.46015107631683, 76.29310414195061, 67.39534959197044, 62.45984002947807, 55.240778401494026, 55.21841660141945, 49.61552985012531, 49.50099639594555, 49.39558245241642, 51.161484494805336, 52.026823461055756, 50.414421781897545, 50.895198583602905, 50.88163711130619, 49.829344376921654, 51.427485421299934, 53.73483560979366, 54.13309223949909, 56.25265270471573, 56.93820431828499, 58.077227398753166, 59.304489344358444, 58.714491203427315, 50.239916145801544, 44.76167030632496, 46.62200108170509, 45.99520951509476, 44.99417223036289, 44.90710750222206, 45.232221856713295, 45.79708054661751, 45.82858845591545, 45.58294303715229, 44.60252344608307, 43.84420193731785, 45.15997253358364, 42.85152420401573, 46.61142624914646, 44.31997060775757, 43.5609233379364, 45.12412525713444, 48.47405970096588, 48.44834268093109, 49.126085713505745, 43.359127566218376, 41.81983396410942, 39.149850234389305, 37.31334798038006, 39.19536419212818, 39.34711664915085, 41.140073239803314, 39.359496384859085, 39.445660561323166, 39.863888919353485, 39.00988094508648, 39.61954303085804, 41.10726200044155, 45.716008096933365, 55.23040495812893, 54.13734421133995, 54.69427652657032, 52.76182562112808, 54.29916612803936, 62.27372981607914, 36.587412133812904, 37.566870376467705, 39.08489651978016, 57.09872670471668, 55.121377408504486, 54.999369755387306, 53.07401306927204, 53.22543874382973, 49.81552831828594, 44.18804548680782, 39.185952097177505, 38.87993931770325, 39.12900075316429, 40.00713363289833, 38.92518728971481, 41.209362521767616, 38.94799366593361, 39.433816596865654, 38.58347922563553, 39.842005893588066, 39.585333466529846, 39.02410738170147, 39.77269001305103, 41.82455711066723, 43.20047087967396, 45.25511562824249, 45.11266887187958, 44.27598416805267, 45.15429183840752, 45.79746812582016, 44.08051125705242, 45.296791791915894, 43.007304444909096, 43.37449014186859, 40.60523293912411, 44.591200053691864, 46.27756476402283, 46.28513015806675, 43.58084186911583, 45.23169368505478, 46.02486692368984, 46.425999999046326, 45.678124129772186, 51.49542197585106, 56.83772251009941, 56.47241771221161, 59.048048704862595, 60.057795122265816, 58.0358362197876, 60.36401689052582, 59.0868978202343, 62.055461928248405, 60.931725427508354, 65.97807884216309, 60.56873470544815, 60.468879863619804, 56.74872748553753, 61.307852044701576, 58.424718752503395, 61.92070595920086, 43.16082760691643, 67.66480833292007, 64.89565372467041, 75.07599145174026, 62.91113421320915, 83.86766329407692, 22.26962272077799, 0.9213147719856352, 0.5934577959123999, 0.10321026216843165, 0.02908693451900035, 6.08763481490314, 61.24221816658974, 65.31169340014458, 60.57904735207558, 60.129181891679764, 43.145354837179184, 11.275120731443167, 29.407573901116848, 40.24794191122055, 56.778719276189804, 41.691921427845955, 0.3477285144617781, 0.008393516745854868, 0.04187846199783962, 0.0367562774772523, 0.01344575384791824, 0.03734488593181595, 0.05263478677079547, 0.026218680322926957, 0.06872329788166098, 0.02890256277169101, 0.026253748656017706, 0.050645515584619716, 0.0266323385949363, 0.03355274508066941, 0.0551011846982874, 33.830310478806496, 78.27064722776413, 51.85900166630745, 41.643120646476746, 21.759644486010075, 40.7588092982769, 48.96516814827919, 68.25476467609406, 74.30344730615616, 52.76556462049484, 0.23426738946000114, 0.2718564122915268, 0.45887225365731865, 12.305667232722044, 68.75598058104515, 70.15426754951477, 78.83749321103096, 70.91102734208107, 67.04530477523804, 57.246557772159576, 56.86757370829582, 52.59028762578964, 52.59650409221649, 51.64850436151028, 52.548185884952545, 54.05691012740135, 52.45524287223816, 52.923624739050865, 54.56338495016098, 52.117676585912704, 55.11721283197403, 56.86537362635136, 57.894480004906654, 58.703608587384224, 61.134820729494095, 60.25730721652508, 60.8413852751255, 59.118580520153046, 52.404678985476494, 46.16096422076225, 49.11187447607517, 47.47950866818428, 48.60014833509922, 46.17749333381653, 47.42606073617935, 48.513406589627266, 47.61679910123348, 46.57795764505863, 46.7455780506134, 45.992857441306114, 48.50874803960323, 46.729561910033226, 47.945299074053764, 46.86234198510647, 46.592073887586594, 48.27107459306717, 50.208978205919266, 50.27821809053421, 51.74808941781521, 46.275341883301735, 44.667116180062294, 41.376158371567726, 40.411929711699486, 42.88297891616821, 44.667211174964905, 43.021511882543564, 40.965749993920326, 42.8876830637455, 43.076411336660385, 41.559692323207855, 42.86948963999748, 44.84811566770077, 49.04096648097038, 56.572580337524414, 56.40822395682335, 56.2255297601223, 56.93000055849552, 56.94492995738983, 63.96262899041176, 39.178071320056915, 39.17183205485344, 41.07092075049877, 56.98101282119751, 57.028396278619766, 56.91372223198414, 55.78554376959801, 55.28021648526192, 50.85192270576954, 45.31338170170784, 42.54611559212208, 40.57938292622566, 41.67324163019657, 42.20623902976513, 42.03234516084194, 43.06522473692894, 41.32668122649193, 41.01987048983574, 40.99878542125225, 41.50226600468159, 42.27232128381729, 40.57880535721779, 41.85044892132282, 44.312002435326576, 47.75272160768509, 49.287675842642784, 48.6264543235302, 46.7883637547493, 46.9078179448843, 46.36926144361496, 45.34418664872646, 47.19608947634697, 45.13184264302254, 45.84873877465725, 42.82670013606548, 46.629866659641266, 48.86272944509983, 47.56098009645939, 45.56188836693764, 47.815342247486115, 47.50254303216934, 47.16088816523552, 47.35875114798546, 53.147326335310936, 59.98417787253857, 61.64281167089939, 62.34926216304302, 62.780219838023186, 60.03632627427578, 63.11346955597401, 61.500646099448204, 65.3887228667736, 62.416845336556435, 66.55849009752274, 61.22847430408001, 64.27086845040321, 56.893978491425514, 63.00490938127041, 59.116581827402115, 63.78701001405716, 47.11690552532673, 70.27950122952461, 68.46786484122276, 77.3603680729866, 65.6909966468811, 84.1078332066536, 25.053311549127102, 0.7576089282520115, 1.781648041214794, 0.3668566286796704, 0.05887725063075777, 5.87774452753365, 68.60598742961884, 71.47729575634003, 69.3416203558445, 54.557043090462685, 30.230472944676876, 15.66393842920661, 36.29152201116085, 47.3987478017807, 65.86769476532936, 49.091450572013855, 0.5265408335253596, 0.06634305216721259, 0.05885362807021011, 0.028861620339739602, 0.026745319446490612, 0.019174921471858397, 0.10491676395758986, 0.20577782444888726, 0.16820625693071634, 0.20614171429770067, 0.23302261484786868, 0.19958124757977203, 0.14826835569692776, 0.17277481412747875, 0.2848214056575671, 47.066695019602776, 85.70902928709984, 59.851063415408134, 48.5198662430048, 31.311771422624588, 58.78728769719601, 62.060033082962036, 77.08335533738136, 78.66760432720184, 60.65448470413685, 0.34264984948094934, 0.49014597083441913, 1.0904477932490408, 14.843091275542974, 73.01363691687584, 75.12093544006348, 83.74625220894814, 72.27281346917152, 70.47241687774658, 59.30885151028633, 61.41004756093025, 56.66098639369011, 53.718751072883606, 53.41024562716484, 55.365871489048004, 57.318066135048866, 57.17564597725868, 54.95802417397499, 57.444394156336784, 56.3224321603775, 57.610418647527695, 60.431071892380714, 59.721535965800285, 61.37076146900654, 62.710854560136795, 62.47540779411793, 63.805537819862366, 63.830525279045105, 54.85641002655029, 48.55400361120701, 50.36655195057392, 49.389043003320694, 50.939584001898766, 47.8914787620306, 49.48436088860035, 50.32497838139534, 51.57913528382778, 49.58151027560234, 48.79955403506756, 47.86385424435139, 51.94622978568077, 48.32290381193161, 53.25790420174599, 48.21833722293377, 48.06218460202217, 48.808848336339, 50.806085765361786, 51.99351444840431, 54.41314861178398, 46.58868066966534, 47.590895891189575, 44.52327109873295, 43.431817665696144, 46.02607525885105, 46.249985843896866, 46.78430177271366, 43.35310868918896, 45.84839679300785, 45.51419712603092, 45.473056733608246, 45.049888640642166, 46.43884710967541, 51.28025472164154, 60.65087869763374, 58.07336300611496, 59.56718444824219, 58.519801050424576, 59.667024090886116, 69.27007779479027, 43.56326021254063, 42.727453261613846, 45.983802527189255, 62.631131038069725, 60.56140869855881, 57.78161846101284, 59.14161868393421, 58.62916678190231, 56.71822652220726, 48.424472361803055, 45.07554866373539, 42.696693912148476, 45.22115685045719, 45.72632074356079, 45.42776316404343, 47.97877907752991, 45.199653804302216, 43.052332028746605, 43.548441007733345, 45.347686260938644, 46.20994359254837, 43.934435695409775, 45.539161786437035, 48.240414038300514, 51.79384656250477, 51.80000223219395, 48.54542747139931, 48.227551728487015, 50.38609430193901, 48.86180229485035, 48.47677655518055, 49.452260211110115, 48.11030521988869, 48.67688901722431, 44.37729813158512, 49.5930540561676, 51.350034177303314, 49.82720889151096, 47.685332223773, 49.98326651751995, 51.323682591319084, 51.66855588555336, 49.84625346958637, 55.68895295262337, 62.119294703006744, 64.13017719984055, 62.29172945022583, 66.61550223827362, 62.20634423196316, 66.78886413574219, 64.22271743416786, 68.62955376505852, 65.22517964243889, 71.33919596672058, 64.38015058636665, 66.28692626953125, 60.249741822481155, 65.13072431087494, 58.78704451024532, 63.7818118929863, 48.67772117257118, 73.40978845953941, 70.21875008940697, 81.51437357068062, 68.71418282389641, 88.74347046017647, 26.08272571116686, 2.069557998329401, 7.752054277807474, 0.5935985071118921, 0.16663520451402292, 7.610507123172283, 74.00080114603043, 76.5096165239811, 76.8543416261673, 76.70889303088188, 54.7523108124733, 20.779046304523945, 43.70295211672783, 58.064809665083885, 73.1496012210846, 59.1641590744257, 1.2181322230026126, 0.20094791252631694, 0.1681712720892392, 0.15408867853693664, 0.122452652285574, 0.1825909936451353, 0.14892494858941063], [0.05626220423437189, 0.051316075696377084, 0.060640296651399694, 0.02692075759114232, 0.0015418211910400714, 0.03485949644527864, 0.07052982633467764, 0.25205080630257726, 41.13315001130104, 70.48359587788582, 49.95059587061405, 26.22992031276226, 15.760826580226421, 42.24251188337803, 53.07250075042248, 58.66487726569176, 70.39709731936455, 31.010658480226994, 0.08867789743817411, 0.3057302290108055, 0.16293824039166793, 13.89027340337634, 65.22826507687569, 72.54696875810623, 73.67515102028847, 66.96051612496376, 59.024812951684, 54.50679838657379, 54.95182290673256, 55.34347929060459, 51.71076402068138, 50.114135295152664, 48.11560593545437, 48.48689541220665, 48.81688870489597, 48.05984392762184, 47.569484040141106, 49.27555449306965, 48.86734239757061, 50.32115578651428, 50.84712356328964, 50.98092958331108, 53.20719972252846, 51.98816053569317, 52.01303780078888, 50.50457574427128, 47.66902729868889, 44.68723610043526, 43.309680819511414, 44.748032838106155, 44.699916020035744, 45.94330810010433, 43.45742829144001, 44.05394308269024, 47.994384840130806, 48.25238719582558, 43.62607464194298, 44.57093194127083, 43.11548464000225, 44.77753445506096, 45.07379315793514, 45.48109330236912, 43.78691241145134, 44.20164875686169, 49.231096878647804, 52.147371992468834, 48.8795131444931, 47.92418360710144, 45.97916677594185, 44.88609462976456, 40.29635891318321, 40.43934144079685, 40.69254845380783, 40.274700075387955, 37.85970166325569, 39.52143609523773, 39.37695264816284, 38.577722534537315, 39.20525886118412, 41.02104462683201, 41.18089444935322, 44.42014083266258, 49.43016819655895, 50.12530669569969, 54.12576623260975, 51.54575027525425, 44.26723703742027, 35.42558267712593, 40.10052502155304, 40.06133392453194, 41.919396221637726, 43.90438310801983, 52.65427619218826, 49.06734086573124, 45.12721449136734, 41.89436316490173, 39.0716390311718, 37.476496025919914, 38.88529323041439, 39.95281934738159, 39.29908722639084, 41.04011580348015, 39.67545323073864, 39.21374760568142, 39.50656369328499, 39.50392663478851, 40.41863635182381, 41.21089763939381, 42.39799953997135, 44.63679000735283, 48.408513218164444, 47.29641169309616, 45.634244084358215, 44.749412164092064, 47.34125688672066, 46.03185474872589, 43.37704360485077, 43.15160550177097, 45.1877186447382, 42.04963803291321, 41.805037558078766, 42.61675760149956, 42.737511321902275, 43.32658231258392, 43.974550142884254, 42.26746514439583, 44.23389382660389, 44.41713139414787, 45.9124119579792, 45.034966841340065, 56.06668308377266, 54.589713737368584, 63.17079707980156, 56.787827387452126, 55.999818071722984, 63.22150155901909, 60.47837175428867, 62.98518843948841, 61.01987309753895, 63.22805620729923, 62.16549262404442, 60.880154594779015, 60.319722667336464, 63.59396517276764, 65.53762167692184, 63.695826306939125, 67.37461790442467, 57.92965091764927, 66.97369381785393, 62.24636748433113, 69.96518209576607, 61.563323736190796, 77.59398713707924, 45.804813131690025, 0.31294770422391593, 0.5148106254637241, 0.30343049147631973, 0.04583650254062377, 1.473317148629576, 51.90709188580513, 67.57841616868973, 61.997013464570045, 69.708551466465, 63.07953357696533, 14.590679369866848, 20.030142590403557, 36.76112741231918, 51.15729711949825, 55.20925909280777, 2.235156437382102, 0.08126015367452055, 0.04706759937107563, 0.052643547824118286, 0.04404087252623867, 0.03773339281906374, 0.02418875057628611, 0.02386762327660108, 0.057707117521204054, 0.024102663301164284, 0.056428226380376145, 0.01451193062166567, 0.04643459935323335, 0.1115347768063657, 0.21602909546345472, 52.18145236372948, 77.51306667923927, 54.5828703045845, 33.918385952711105, 24.46291822940111, 46.05274982750416, 60.277757719159126, 65.67073613405228, 77.06139251589775, 34.358181953430176, 0.05732078512664884, 0.356376672280021, 0.4707059171050787, 16.283030658960342, 67.0094347000122, 74.73818197846413, 77.55422607064247, 68.20880234241486, 59.959608390927315, 58.27887497842312, 57.54196532070637, 57.531732469797134, 52.402965277433395, 53.25178273022175, 50.980728194117546, 50.6634908169508, 51.405507400631905, 50.36885842680931, 49.338475316762924, 51.26540891826153, 53.89723129570484, 51.86999447643757, 52.683416828513145, 53.92267853021622, 55.12047305703163, 55.001486241817474, 52.416659742593765, 53.4209306538105, 51.18071526288986, 46.46533168852329, 47.15800032019615, 47.80343368649483, 46.50614149868488, 47.02843487262726, 46.94592610001564, 46.42922982573509, 49.72614951431751, 48.16337317228317, 47.28599265217781, 46.832471787929535, 46.452625170350075, 45.62993511557579, 46.33943684399128, 47.235968336462975, 47.33988136053085, 46.318233981728554, 49.90596726536751, 53.94953928887844, 50.494008511304855, 49.69188295304775, 49.270534962415695, 47.85209007561207, 44.104875549674034, 41.54250204563141, 43.04880581796169, 42.380501478910446, 42.199384197592735, 42.31790743768215, 40.96487604081631, 41.4435363560915, 40.93551501631737, 42.116693034768105, 43.083820939064026, 46.60644091665745, 50.988274589180946, 52.94608913362026, 56.236218586564064, 54.362223744392395, 50.16457758843899, 39.659995660185814, 43.253633826971054, 43.079059794545174, 45.903839617967606, 46.04828506708145, 52.79214419424534, 50.48422783613205, 48.668548464775085, 42.94520437717438, 41.581343561410904, 40.94217225909233, 41.19814932346344, 40.37752255797386, 41.27370826900005, 44.15937602519989, 42.70448349416256, 43.296081349253654, 43.384320214390755, 42.034792229533195, 42.24196471273899, 43.61050687730312, 44.91731755435467, 48.82245160639286, 51.14818520843983, 49.93995264172554, 46.414156034588814, 47.43728153407574, 49.65301863849163, 47.59982921183109, 44.994449615478516, 45.904850363731384, 47.05058008432388, 44.399975314736366, 44.28447291254997, 46.23651176691055, 44.282181635499, 47.115127220749855, 46.48606717586517, 43.6780596524477, 46.29009649157524, 45.76619580388069, 49.24894072115421, 49.0580465644598, 58.82929444313049, 58.18510740995407, 62.37004704773426, 57.68136464059353, 59.71482552587986, 64.06089171767235, 63.54493260383606, 64.18066129088402, 62.553174421191216, 63.990314304828644, 64.27345231175423, 60.36492504179478, 62.065683379769325, 65.3406098484993, 66.29790768027306, 66.47473499178886, 70.47342762351036, 60.057160556316376, 70.69814756512642, 67.05802649259567, 71.87529399991035, 65.07823392748833, 79.82170879840851, 50.66077396273613, 0.21742295270087197, 1.0436740843579173, 1.500497090164572, 0.09467201642110012, 1.7230998328886926, 57.00490973889828, 73.89191418886185, 69.5246109366417, 66.66812181472778, 45.29378995299339, 20.393000319600105, 28.39317463338375, 43.28905552625656, 59.391451478004456, 63.35090361535549, 3.2317398861050606, 0.037636839406332, 0.05652193365676794, 0.028494357429735828, 0.022285672421276104, 0.03382279406650923, 0.05237336896243505, 0.12117926788050681, 0.14550988184055313, 0.20712844416266307, 0.16315012355335057, 0.10949024901492521, 0.12341217501671053, 0.17078210308682173, 0.7326107227709144, 67.07001104950905, 85.77849715948105, 67.3369163274765, 41.26864694058895, 28.208552040159702, 55.45449033379555, 70.80942839384079, 71.23154774308205, 83.5747142136097, 39.540218487381935, 0.18622787349158898, 0.8155099244322628, 1.9694418017752469, 17.390741519629955, 69.53531876206398, 74.77233454585075, 80.1503911614418, 72.67247602343559, 63.87825071811676, 60.22005781531334, 61.24024987220764, 59.944652393460274, 55.55319003760815, 55.47246336936951, 53.74876946210861, 53.75981166958809, 54.61113318800926, 52.836913391947746, 53.91247607767582, 55.44774949550629, 56.616031005978584, 55.28666473925114, 56.11205644905567, 57.13386721909046, 57.69983544945717, 58.63926284015179, 53.916553258895874, 54.838919565081596, 53.777807503938675, 47.46780149638653, 47.73511715233326, 49.2846892029047, 48.36734622716904, 50.76534055173397, 50.107307061553, 48.5174647718668, 51.960220634937286, 53.874664306640625, 50.18351197242737, 49.064232632517815, 49.573025330901146, 48.81955236196518, 48.551849126815796, 50.90040810406208, 49.51531782746315, 48.13831351697445, 54.25663121044636, 55.666013583540916, 52.02242709696293, 52.06778906285763, 50.23157939314842, 50.79890415072441, 49.27349500358105, 45.70811212062836, 45.01512050628662, 44.87682692706585, 44.49165299534798, 45.13560824096203, 42.99808233976364, 44.09074030816555, 44.47000175714493, 47.31336638331413, 46.60187356173992, 50.55361971259117, 54.43191200494766, 56.959399580955505, 58.75162661075592, 55.62411703169346, 55.23976005613804, 44.12292838096619, 48.079184889793396, 46.30718037486076, 50.201431810855865, 49.684689939022064, 56.196575313806534, 53.35491679608822, 51.55323587357998, 45.86909808218479, 44.28687438368797, 43.343540802598, 43.98036003112793, 45.679108276963234, 43.4894909709692, 47.259473875164986, 45.31318411231041, 45.62163256108761, 48.419259041547775, 45.38747772574425, 46.92924499511719, 46.22242972254753, 46.77032232284546, 51.13472253084183, 53.419741317629814, 53.18572327494621, 47.76646167039871, 47.9162610322237, 51.60038374364376, 48.67152750492096, 47.89631970226765, 47.524540051817894, 49.95810806751251, 46.84524670243263, 46.8832902610302, 48.655522763729095, 46.101429015398026, 48.64752419292927, 48.86840634047985, 46.983840465545654, 46.60304769873619, 48.97877521812916, 51.41460791230202, 50.70110499858856, 60.762110128998756, 61.745615154504776, 66.42406091094017, 66.46612465381622, 63.91705423593521, 66.83575361967087, 65.89889109134674, 67.85034477710724, 63.99620398879051, 65.15734568238258, 66.96690738201141, 64.10660326480865, 64.91812571883202, 67.64080122113228, 70.98120957612991, 69.27171170711517, 71.8599808216095, 60.976300835609436, 73.20849046111107, 68.58832597732544, 74.49001729488373, 66.39914944767952, 84.2945171892643, 51.99023522436619, 0.1996254053665325, 5.850684754550457, 2.627082606777549, 0.12562762683955953, 2.434941167011857, 63.29128861427307, 79.43605989217758, 75.14120355248451, 90.5757549405098, 80.62867149710655, 24.636861495673656, 32.12534576654434, 55.80334201455116, 66.65075674653053, 75.28890162706375, 4.311747858300805, 0.23866730101872236, 0.1976249017752707, 0.18421867192955688, 0.10088621187605895, 0.2022186919930391, 0.09932989851222374], [0.03370039907167666, 0.06298582840827294, 0.027955168588960078, 0.040919848397606984, 0.05653942978824489, 0.14298641646746546, 0.022065067169023678, 1.8623886024579406, 60.994076281785965, 59.01747554540634, 41.17293007671833, 26.99568562209606, 22.34472569078207, 51.89785078167915, 53.18743318319321, 61.49135559797287, 70.20544320344925, 31.328937001526356, 0.11851849034428596, 0.3855123807443306, 0.20810208254260942, 23.7349608913064, 71.01478457450867, 71.65166839957237, 72.78643950819969, 67.15822711586952, 63.66612330079079, 64.94942083954811, 67.46123805642128, 66.13820225000381, 65.03401950001717, 59.55623343586922, 55.7630679756403, 51.150970458984375, 50.467983707785606, 48.418084904551506, 47.70656928420067, 47.49074466526508, 47.69634023308754, 44.65641215443611, 48.308475986123085, 46.702119782567024, 47.75136888027191, 47.833231687545776, 47.59015113115311, 45.22349372506142, 43.572664707899094, 44.85120490193367, 45.36071576178074, 43.99817727506161, 46.64210580289364, 46.36652559041977, 45.92160366475582, 45.94706229865551, 44.923085644841194, 46.241177916526794, 43.93521845340729, 43.51819083094597, 43.30216482281685, 44.55963894724846, 44.72044251859188, 45.052426904439926, 46.07961818575859, 43.217284977436066, 44.79006238281727, 46.07257716357708, 45.90448558330536, 41.55606731772423, 42.21176013350487, 42.39055573940277, 45.631132051348686, 42.20829091966152, 38.97208817303181, 39.99018654227257, 39.36729356646538, 39.4566685706377, 40.39977416396141, 38.53624016046524, 38.98322917521, 39.96560946106911, 40.02155005931854, 39.69988211989403, 42.21781700849533, 42.26376414299011, 46.757387816905975, 46.11250162124634, 41.602808609604836, 42.83292420208454, 47.48523876070976, 42.255199402570724, 35.888166055083275, 45.90600170195103, 41.3173945248127, 40.292999893426895, 38.26970726251602, 38.696017786860466, 37.96986535191536, 40.16373462975025, 38.90003263950348, 39.238928854465485, 38.51507529616356, 39.85119380056858, 38.597093895077705, 38.922538831830025, 40.978019535541534, 39.488776847720146, 41.749701127409935, 45.85309714078903, 45.52033379673958, 46.54447004199028, 42.33796276152134, 42.002490162849426, 42.27933190762997, 45.44735871255398, 46.526010632514954, 46.106205359101295, 43.18128950893879, 43.35997112095356, 42.8857109695673, 43.29666651785374, 41.24599635601044, 43.79109978675842, 44.02884162962437, 46.318294778466225, 43.020174354314804, 45.68262308835983, 44.039549455046654, 43.605046570301056, 42.373536452651024, 46.47518076002598, 56.4042379707098, 58.64590868353844, 50.553323328495026, 43.14326114952564, 58.15761208534241, 60.99255636334419, 61.87336429953575, 61.36853478848934, 59.4554628431797, 60.27771972119808, 62.295179665088654, 62.36036516726017, 61.996310502290726, 64.65840205550194, 61.497758254408836, 64.20175775885582, 64.40546482801437, 66.2957113981247, 63.6994893103838, 67.08074927330017, 64.202601313591, 68.38374495506287, 62.8902505338192, 74.50485169887543, 3.341904762201011, 2.450728132389486, 0.18461797706549987, 0.13619393954286352, 0.1551132876193151, 35.17133831977844, 69.60306912660599, 61.583139672875404, 61.72336734831333, 55.11319264769554, 23.966501466929913, 17.672574296593666, 35.390514358878136, 50.42091183364391, 68.38721796870232, 5.314700240269303, 0.33429801638703793, 0.21000845212256536, 0.029816293135809246, 0.01842759917053627, 0.030844969187455717, 0.04838141227082815, 0.06742811659933068, 0.03061408147914335, 0.047564274282194674, 0.11042565194657072, 0.0254411767309648, 0.058248751738574356, 0.10866353361052461, 2.82246598508209, 72.97344267368317, 65.60934662818909, 48.806617856025696, 30.451697073876858, 21.21695190668106, 41.924814730882645, 58.348741829395294, 66.96122288703918, 77.995785176754, 32.76718072593212, 0.0892227896838449, 0.19167310005286708, 0.013661116754519753, 27.464016191661358, 72.70561024546623, 72.94429823756218, 75.17091795802116, 69.25420984625816, 67.1892486512661, 68.13511669635773, 69.16894242167473, 68.5645392537117, 67.954071611166, 63.6349193751812, 57.02574402093887, 53.11315856873989, 52.810276821255684, 49.55757535994053, 50.90032070875168, 50.42611375451088, 48.449444621801376, 48.028848990798, 50.42768307030201, 48.47339853644371, 48.63865926861763, 50.54209113121033, 48.893918171525, 46.83829307556152, 46.16327449679375, 46.691924929618835, 46.684070751070976, 46.13970436155796, 48.18660892546177, 47.00229227542877, 46.40017278492451, 47.76339903473854, 47.899329140782356, 48.7962444126606, 46.404432356357574, 45.764774680137634, 47.50609204173088, 46.96036532521248, 46.740683913230896, 46.32338270545006, 47.60767959058285, 45.38481026887894, 48.150305673480034, 46.66101358830929, 47.243746519088745, 42.33279883861542, 43.928363621234894, 45.460262820124626, 47.686259374022484, 44.45370063185692, 42.784237414598465, 43.57073061168194, 41.619402319192886, 43.01419347524643, 41.91480226814747, 41.27378806471825, 42.713158428668976, 42.30836234986782, 42.959016636013985, 42.835473865270615, 44.068602696061134, 44.75043050944805, 48.04599367082119, 47.71983817219734, 45.028681978583336, 44.01185654103756, 48.77349503338337, 45.44947139918804, 40.739886313676834, 47.25224666297436, 42.944243028759956, 42.78631590306759, 40.66488593816757, 40.29919356107712, 40.506111457943916, 41.55133277177811, 41.15585379302502, 43.026607409119606, 40.90776890516281, 43.078752011060715, 42.00473964214325, 42.33059115707874, 43.95909257233143, 43.276607394218445, 43.4097446501255, 46.854381412267685, 47.766404673457146, 45.80994665622711, 43.45864422619343, 44.081423208117485, 43.15865412354469, 46.9824231415987, 47.71946579217911, 48.26382838189602, 44.84937720000744, 47.272841557860374, 44.23415221273899, 45.03417268395424, 43.73130239546299, 45.31573757529259, 45.443729907274246, 48.47132004797459, 45.07719397544861, 47.59800910949707, 45.76777271926403, 47.015260979533195, 44.49193798005581, 48.58386240899563, 57.692304253578186, 61.506486386060715, 53.58832307159901, 48.122179582715034, 60.551107451319695, 62.434142008423805, 63.82499277591705, 63.65082532167435, 63.847958743572235, 63.086620196700096, 63.42384830117226, 63.762592524290085, 63.2751926779747, 64.56159085035324, 63.88544753193855, 65.81891298294067, 67.84256279468536, 69.80552986264229, 64.10236269235611, 69.15324926376343, 66.3818983733654, 72.25025787949562, 66.53102517127991, 76.5504415333271, 4.489806303754449, 1.9209578284062445, 0.95878871739842, 0.039377954963129014, 0.15592904150253162, 37.715187817811966, 76.72415301203728, 65.9488508105278, 68.84292751550674, 47.09059573709965, 21.916178986430168, 22.073232159018517, 47.97715276479721, 57.778878808021545, 77.45072722434998, 7.493469128385186, 0.375109399901703, 0.2012026176089421, 0.023922796390252188, 0.02619223203510046, 0.0496737733919872, 0.03181653512001503, 0.16805420571472496, 0.2012545382604003, 0.15791238663950935, 0.24710638099350035, 0.22225267166504636, 0.2988410502439365, 0.2848559897392988, 4.122389769181609, 85.92711478471756, 72.76445388793945, 56.6258192807436, 39.46208328008652, 32.86670498549938, 68.41431051492691, 69.02333423495293, 73.73088642954826, 85.12517541646957, 38.92899088561535, 0.2664647391065955, 0.9028574998956174, 1.1805674387142062, 27.07858007401228, 74.3564772605896, 75.61698362231255, 78.96020382642746, 70.32480999827385, 69.74601745605469, 70.49578562378883, 71.14428162574768, 72.04644441604614, 71.48185551166534, 66.45913302898407, 60.377570763230324, 56.02694481611252, 54.52597975730896, 54.24538381397724, 53.62008556723595, 53.532025292515755, 52.45419032871723, 50.464028120040894, 54.17947635054588, 51.39027401804924, 53.582524582743645, 53.763771057128906, 50.74853025376797, 49.29670795798302, 48.694041296839714, 50.29060922563076, 49.00005027651787, 46.8432442098856, 50.54749444127083, 49.40120615065098, 49.90828514099121, 49.443634673953056, 49.04730834066868, 51.707302406430244, 49.19380187988281, 49.43170711398125, 49.90819774568081, 49.457044154405594, 49.026227071881294, 47.96978875994682, 49.60627354681492, 46.82346247136593, 48.6893105506897, 47.92323365807533, 48.80100175738335, 42.78692007064819, 44.73104774951935, 44.878118857741356, 48.726301565766335, 48.9113250374794, 45.3089739382267, 45.92497028410435, 45.60023210942745, 47.096929997205734, 44.87351730465889, 44.33585375547409, 47.501558884978294, 45.25595158338547, 45.44819466769695, 45.85233338177204, 48.60676757991314, 47.49536141753197, 51.28992520272732, 51.192312240600586, 45.53814724087715, 49.33746077120304, 52.15333007276058, 50.16954392194748, 42.95186161994934, 51.24627694487572, 45.81155776977539, 46.99421010911465, 43.02121549844742, 44.057670682668686, 43.7624379247427, 44.24644835293293, 45.92454090714455, 45.19395790994167, 43.90949383378029, 46.390475705266, 44.71853122115135, 46.14844009280205, 47.48624570667744, 45.60965560376644, 47.01795883476734, 49.4647691398859, 48.88172462582588, 47.31000356376171, 42.99321100115776, 43.9015256613493, 44.506760984659195, 48.522564098238945, 49.63843882083893, 51.13392077386379, 46.98275372385979, 48.35832551121712, 46.25553734600544, 48.81666451692581, 47.3109383136034, 48.08984711766243, 50.08950121700764, 51.754860654473305, 47.461075857281685, 51.44232362508774, 48.554626777768135, 48.12213398516178, 47.30786807835102, 51.174525395035744, 60.50453335046768, 63.58389191329479, 57.60197930037975, 48.30964632332325, 63.56756418943405, 64.72659319639206, 65.64653903245926, 65.85813447833061, 63.2349718362093, 64.69288900494576, 65.2116371691227, 65.46797901391983, 67.33380049467087, 69.19197678565979, 67.38860875368118, 68.36714744567871, 70.18609464168549, 72.46039420366287, 68.43807443976402, 72.75409564375877, 69.0456010401249, 75.09097784757614, 68.69550302624702, 79.0331219136715, 4.134639361873269, 6.337180724367499, 3.1759873777627945, 0.37211726827081293, 0.5150908604264259, 43.80584679543972, 84.84017550945282, 70.47633066773415, 79.24782559275627, 71.0562327504158, 34.006461426615715, 28.996776044368744, 53.95584315061569, 66.00558936595917, 88.31709533929825, 10.97970463335514, 0.6178697047289461, 0.3107237844960764, 0.17429816129151732, 0.097682427149266, 0.1831257258891128, 0.17142321477876976], [0.07050422223983333, 0.06049768555385526, 0.053330290465964936, 0.016348841672879644, 0.033914464147528633, 0.046547283345717005, 0.09003780884086154, 3.0160373356193304, 69.88423123955727, 52.22573898732662, 40.61494141817093, 26.349232010543346, 27.630914635956287, 50.2008618414402, 52.242051512002945, 62.28041745722294, 68.57644021511078, 21.021725982427597, 0.4323904059128836, 0.5464993813075125, 0.08958750331657939, 32.87540651857853, 67.35033720731735, 71.44343197345734, 72.24721804261208, 70.1279653608799, 65.64687341451645, 67.7693635225296, 67.67248392105103, 66.15742921829224, 64.41757097840309, 63.14960941672325, 58.02469901740551, 55.22228479385376, 48.51868450641632, 44.28699217736721, 45.28848543763161, 45.953001379966736, 47.5910896807909, 47.169870883226395, 42.039473578333855, 45.53179398179054, 45.13783872127533, 46.02486312389374, 45.26702418923378, 44.87857863306999, 44.535924419760704, 44.60379637777805, 44.19469512999058, 44.54070456326008, 44.63339678943157, 44.877518489956856, 43.47400680184364, 42.747269198298454, 42.700030133128166, 45.35377733409405, 43.00812900066376, 43.69817957282066, 43.36284376680851, 43.47254768013954, 44.45644788444042, 46.30390875041485, 43.951435983181, 44.60313521325588, 46.8386160582304, 46.67297154664993, 41.60611443221569, 40.420144870877266, 41.651309207081795, 40.35843998193741, 40.045655965805054, 46.647102534770966, 41.284644082188606, 39.862912371754646, 39.75890055298805, 36.53185911476612, 38.68091739714146, 36.29601716995239, 37.10942432284355, 40.17702631652355, 38.40981334447861, 39.06869038939476, 37.80115820467472, 39.94649648666382, 41.552943885326385, 44.75635439157486, 39.56690065562725, 42.106308192014694, 45.40183715522289, 38.75057905912399, 40.62977582216263, 41.45029619336128, 37.92731523513794, 41.25947803258896, 37.268350794911385, 37.6300647854805, 36.66905835270882, 38.92546087503433, 37.56327576935291, 39.45510305464268, 37.76127174496651, 40.167682617902756, 39.86461088061333, 42.02671766281128, 42.99053594470024, 43.14722813665867, 42.874345779418945, 46.094217002391815, 42.749902456998825, 43.39899122714996, 42.421926856040955, 39.888105019927025, 40.97263902425766, 42.200121358036995, 45.00810608267784, 45.387785509228706, 41.88712455332279, 44.830302223563194, 43.090713769197464, 43.60907435417175, 41.73565708100796, 40.01244194805622, 41.292669251561165, 46.06947273015976, 42.129718735814095, 43.897133097052574, 43.458059057593346, 44.86784040927887, 41.502281203866005, 45.301894918084145, 54.75587882101536, 61.78329773247242, 55.90350843966007, 58.56791786849499, 59.25066143274307, 58.7879678606987, 59.42687317728996, 62.92008653283119, 59.1529306769371, 59.31030683219433, 59.40121315419674, 60.903154760599136, 59.18673366308212, 60.23703910410404, 56.60590834915638, 60.411461144685745, 57.784890085458755, 64.3166483938694, 58.573438972234726, 64.99753385782242, 57.378289103507996, 70.53115412592888, 62.30272226035595, 83.35185617208481, 20.1099706068635, 1.2298078089952469, 0.9107093035709113, 0.08551097518648021, 0.0314974004868418, 22.78519995510578, 69.49386298656464, 62.85776987671852, 60.52940681576729, 56.020021587610245, 44.86762762069702, 15.45222993940115, 23.03912702947855, 43.95351827144623, 61.65998674929142, 14.794922210276127, 0.4572585871210322, 0.21968497429043055, 0.05721475819882471, 0.11592213864787482, 0.0026605586026562378, 0.12307377794058993, 0.042112880473723635, 0.10459467186592519, 0.054759054619353265, 0.02735135352850193, 0.06868220516480505, 0.13460483809467405, 0.14158356440020725, 4.634427493438125, 80.48686310648918, 61.00444592535496, 47.58526459336281, 35.48144727945328, 35.37978753447533, 52.82888062298298, 59.070026725530624, 67.75161847472191, 76.37760400772095, 24.263736717402935, 0.3774049220373854, 0.23994097486138344, 0.3652148199034855, 38.32010015845299, 67.81244561076164, 71.86263307929039, 74.07846137881279, 71.80015683174133, 68.683130890131, 69.9228523671627, 70.64860582351685, 69.36670660972595, 66.22555196285248, 65.37426844239235, 60.079070180654526, 56.95775806903839, 50.739300549030304, 47.758926674723625, 49.3564635515213, 48.89346219599247, 49.48928162455559, 48.98228622972965, 44.700550585985184, 47.755092680454254, 48.02403084933758, 48.40111501514912, 45.534583032131195, 46.60047523677349, 48.46903257071972, 47.23638251423836, 46.129752695560455, 45.74387580156326, 46.881770342588425, 46.980325654149055, 44.78310875594616, 46.803882122039795, 45.19359692931175, 46.32394127547741, 46.11601643264294, 46.81954488158226, 44.56427089869976, 45.572998970746994, 46.216627433896065, 46.878631711006165, 46.67128823697567, 46.98720708489418, 46.95038326084614, 46.38589695096016, 43.613508716225624, 42.409604117274284, 41.6239582747221, 40.8051136136055, 43.03225390613079, 46.09104037284851, 43.95715467631817, 42.726928889751434, 42.18963012099266, 41.55997730791569, 40.754241943359375, 39.11593705415726, 38.88695374131203, 41.28591701388359, 40.38305506110191, 42.25995294749737, 40.949000492691994, 41.75405569374561, 43.16767863929272, 46.9413473457098, 41.99210911989212, 46.40597887337208, 47.307248711586, 42.12345287203789, 45.07393375039101, 44.0080301463604, 39.91908095777035, 42.19001770019531, 38.33201251924038, 39.596292078495026, 40.64612254500389, 40.99763788282871, 39.185891300439835, 40.8084574341774, 40.39125122129917, 42.082160487771034, 42.30326682329178, 43.545131385326385, 44.47336457669735, 46.0123123973608, 45.32028213143349, 44.99825321137905, 42.42087051272392, 42.88574896752834, 42.458689883351326, 39.09859478473663, 41.139328479766846, 43.3922465890646, 47.937786877155304, 45.56196816265583, 42.75267630815506, 44.95444156229496, 45.62581613659859, 45.482514426112175, 43.5393100976944, 42.33551949262619, 43.84045913815498, 46.902642622590065, 43.698764741420746, 46.69828198850155, 45.02000704407692, 46.149887815117836, 43.78025136888027, 47.41631045937538, 56.51915900409222, 63.94004300236702, 56.2738099694252, 62.90402099490166, 61.950431764125824, 61.039772629737854, 63.00694987177849, 65.99602907896042, 60.70081561803818, 63.157440796494484, 61.0114261507988, 63.08107629418373, 61.83294966816902, 63.490793108940125, 57.303376123309135, 63.1833516061306, 60.61793066561222, 66.21790677309036, 61.89234048128128, 66.27280622720718, 59.62176471948624, 73.83628517389297, 63.56969967484474, 86.2807846069336, 22.02640727162361, 0.9003625775221735, 2.1421483531594276, 0.021862377361685503, 0.057443610567133874, 25.172706842422485, 76.80134207010269, 68.67463454604149, 67.47158110141754, 57.48080000281334, 35.244393199682236, 16.908807680010796, 28.420346975326538, 49.52472612261772, 73.17898124456406, 18.21881588548422, 0.19621765619376674, 0.19145762489642948, 0.029702900392294396, 0.09041224460816011, 0.05128931756189559, 0.04013004741864279, 0.2762847184203565, 0.21842685586307198, 0.19520588626619428, 0.23423097969498485, 0.2701860753586516, 0.3000021551270038, 0.4278792761033401, 7.05738315358758, 92.66574919223785, 68.23817476630211, 58.36996749043465, 36.97539411485195, 40.22399939596653, 68.67180749773979, 68.41405212879181, 73.06388542056084, 84.85135450959206, 28.736518509685993, 0.4934276291169226, 0.9516587562393397, 0.5584785947576165, 38.15878741443157, 67.938462048769, 75.50736710429192, 76.94109857082367, 74.91955384612083, 71.98053315281868, 71.7521046102047, 73.86957898736, 72.25262895226479, 70.07101401686668, 67.28093773126602, 63.6595306545496, 60.34622624516487, 55.120055079460144, 48.76358516514301, 51.99688106775284, 52.52243846654892, 54.214062094688416, 52.570771872997284, 47.512304708361626, 50.843464359641075, 51.10001519322395, 52.11932569742203, 49.436593651771545, 49.42434310913086, 49.5310527831316, 48.59958216547966, 48.612303882837296, 48.72263476252556, 49.720655009150505, 49.77426253259182, 47.07870237529278, 49.063134491443634, 46.16617374122143, 49.46726180613041, 49.27115812897682, 48.40743027627468, 47.279145419597626, 48.13618943095207, 48.608530685305595, 49.48957420885563, 48.78041446208954, 48.369565308094025, 50.577600225806236, 47.820179387927055, 44.46250855922699, 43.57021763920784, 42.70725354552269, 42.13710553944111, 42.37732104957104, 49.975560531020164, 45.212892293930054, 46.49957925081253, 45.53573817014694, 43.7100425362587, 43.20612497627735, 41.57921947538853, 42.43837997317314, 45.53971655666828, 43.41060720384121, 44.79434475302696, 43.166922479867935, 45.347978845238686, 46.827893033623695, 49.93120551109314, 44.54973667860031, 50.85801377892494, 50.305337235331535, 44.055140018463135, 46.99709415435791, 47.050325497984886, 42.82231517136097, 47.91075512766838, 41.97210319340229, 42.211209163069725, 43.08346375823021, 43.82828079164028, 41.928717121481895, 44.218789637088776, 43.0926288664341, 45.035232827067375, 46.97159752249718, 45.54586462676525, 49.353104531764984, 48.36035840213299, 46.853241473436356, 46.4199773222208, 42.459434643387794, 43.666599467396736, 43.02262902259827, 40.09859472513199, 41.91399671137333, 43.94461914896965, 48.79358075559139, 49.53424081206322, 44.18902963399887, 48.137298971414566, 47.93862663209438, 49.70938481390476, 46.96296438574791, 45.08882515132427, 46.157065629959106, 49.312492311000824, 45.61078794300556, 47.6253030449152, 49.08361919224262, 49.27917569875717, 44.85481470823288, 49.074986055493355, 59.11984205245972, 65.64799815416336, 58.90237972140312, 63.0067028850317, 64.24148842692375, 65.00511825084686, 67.07950294017792, 70.54029643535614, 63.46425913274288, 65.50841644406319, 65.08680626749992, 66.66898056864738, 63.919364511966705, 67.13953211903572, 60.65571963787079, 66.72031581401825, 63.99295896291733, 68.72582539916039, 65.15623614192009, 70.02562165260315, 63.71699497103691, 76.43727600574493, 68.30449640750885, 88.41373175382614, 22.342257723212242, 2.671264261007309, 3.9261322002857924, 0.35071657912340015, 0.21037480590166524, 27.964377142488956, 84.25787955522537, 73.64924401044846, 75.24419322609901, 69.5779600739479, 66.14355236291885, 26.16037454456091, 39.46401357650757, 60.81541746854782, 83.40000718832016, 25.69444354623556, 0.665126700187102, 0.47504531394224614, 0.1875397382536903, 0.4469313647132367, 0.12092145319911651, 0.19895198056474328], [0.030757553467992693, 0.07490725081879646, 0.03937290464818943, 0.06963310413993895, 0.09226733178365976, 0.0641287506732624, 0.0965573090070393, 8.087449930608273, 70.03768220543861, 50.046495124697685, 46.00419603288174, 16.859138645231724, 21.63896106183529, 34.23632629215717, 56.60908117890358, 64.47136089205742, 69.6182607114315, 13.247753530740738, 0.35269116691779345, 0.4496758565073833, 0.3090210008667782, 37.87072867155075, 69.22243595123291, 69.14364337921143, 71.06973722577095, 70.36763370037079, 68.77867296338081, 69.80380475521088, 67.78689578175545, 69.7894187271595, 66.51964098215103, 65.1639573276043, 57.32398621737957, 53.97915109992027, 51.46245114505291, 48.92219625413418, 46.2435831874609, 45.402722507715225, 41.79226644337177, 44.445732459425926, 42.80288301408291, 44.58545096218586, 44.075275138020515, 42.62580871582031, 45.01425415277481, 43.31131853163242, 43.35734166204929, 44.16140131652355, 45.53813584148884, 44.37347553670406, 44.94754873216152, 45.10481849312782, 43.49718555808067, 44.77586254477501, 44.36025224626064, 45.445382818579674, 43.8419296592474, 42.96022117137909, 42.55354419350624, 41.01406820118427, 42.919563353061676, 43.38662289083004, 45.52097216248512, 44.62384790182114, 42.174130752682686, 47.41953648626804, 43.52729894220829, 42.0189318805933, 41.164657920598984, 43.32972854375839, 41.85369394719601, 41.29608526825905, 43.58425788581371, 43.648333847522736, 37.64671549201012, 37.62988239526749, 39.41605255007744, 37.29568652808666, 37.90153741836548, 39.0925645083189, 39.4074460119009, 39.16895180940628, 38.16637560725212, 39.27263684570789, 40.414296984672546, 40.611730590462685, 40.8611986041069, 40.73658809065819, 40.673120096325874, 38.909110352396965, 39.95169460773468, 38.69483605027199, 36.1846337467432, 37.59397052228451, 38.683436661958694, 37.26282209157944, 37.56822310388088, 39.109598994255066, 38.83745759725571, 39.87602926790714, 39.2044723033905, 39.20323356986046, 39.98192198574543, 39.76564139127731, 43.74934762716293, 43.78797635436058, 42.52301283180714, 40.70290669798851, 39.65780317783356, 38.99032339453697, 39.62672084569931, 39.31512616574764, 40.55373430252075, 41.542935222387314, 44.07094717025757, 42.952397391200066, 43.92259553074837, 43.84860210120678, 42.00637735426426, 38.87078940868378, 40.70087380707264, 39.504485204815865, 41.092765778303146, 44.071638733148575, 44.35115173459053, 43.96617539227009, 44.17023964226246, 44.924278780817986, 44.982392862439156, 44.3426363915205, 45.75672671198845, 54.33833822607994, 58.42058077454567, 58.203916400671005, 54.40084487199783, 56.82158097624779, 55.06501883268356, 57.06405356526375, 52.68914312124252, 55.77338822185993, 52.326585575938225, 53.75916950404644, 50.51784463226795, 52.62373723089695, 48.6296309530735, 53.861099034547806, 51.153508722782135, 54.59108926355839, 51.894172579050064, 57.220992743968964, 52.880694642663, 66.08683660626411, 60.654644295573235, 79.73099246621132, 40.65790191292763, 0.12791793909855187, 1.2508288747631013, 0.3065732790855691, 0.20878347801044583, 15.574252791702747, 68.04683983325958, 62.28780806064606, 63.585841208696365, 49.642105624079704, 62.82442286610603, 29.5497090741992, 43.38555134832859, 39.98408406972885, 71.45575851202011, 22.138284668326378, 0.4439011757494882, 0.1934932469157502, 0.06060514111595694, 0.08332198834978044, 0.04458328228793107, 0.03667467834020499, 0.04276545834727585, 0.03158701481879689, 0.10695281642256305, 0.033236352683161385, 0.1394817724940367, 0.11746793577913195, 0.15476052998565137, 10.66299732774496, 80.91765359044075, 56.27280302345753, 53.64746309816837, 20.434169210493565, 25.52281815558672, 44.55133259296417, 63.22361424565315, 69.54126164317131, 75.46444460749626, 14.603768717497587, 0.35446362337097526, 0.1302136541926302, 0.4810704250121489, 43.24918046593666, 71.7691732943058, 70.43964743614197, 73.55731174349785, 72.80509650707245, 69.07334715127945, 71.23445078730583, 69.7574320435524, 69.67240780591965, 69.8465296626091, 67.02375993132591, 60.658178105950356, 57.488076612353325, 54.9636896699667, 51.08570896089077, 49.13725331425667, 48.12273055315018, 45.74388340115547, 45.819742530584335, 45.36953888833523, 46.40635505318642, 47.38936610519886, 47.1016189455986, 46.69962331652641, 44.55557696521282, 44.82160449028015, 46.11517667770386, 48.38144727051258, 46.102629750967026, 46.015926003456116, 47.02170543372631, 44.09331277012825, 46.77724935114384, 46.926197558641434, 47.707450836896896, 46.166367530822754, 44.18540842831135, 44.82477352023125, 45.24984911084175, 46.290434673428535, 46.51532560586929, 46.132154166698456, 45.80267384648323, 43.53055156767368, 48.358770087361336, 43.82820099592209, 42.85200297832489, 42.28495940566063, 42.18250930309296, 42.583604380488396, 42.61021435260773, 44.925384521484375, 46.482141986489296, 40.34026175737381, 41.19532227516174, 39.846497252583504, 42.02594630420208, 40.1721777766943, 42.837111577391624, 41.998990550637245, 41.12621158361435, 41.1806208640337, 41.844851821660995, 43.63118156790733, 42.20529668033123, 44.06854949891567, 42.5678276270628, 44.70165632665157, 42.782101929187775, 42.58441373705864, 40.752045661211014, 40.26438742876053, 40.86034744977951, 42.30166330933571, 40.39522960782051, 40.30015490949154, 41.7208568751812, 40.746497958898544, 41.7056804895401, 40.93390390276909, 41.57327279448509, 41.55530355870724, 43.555094450712204, 46.035536751151085, 43.05432312190533, 43.80502983927727, 42.03941658139229, 39.852630123496056, 40.015147402882576, 40.03687083721161, 41.205999702215195, 40.14235317707062, 41.43702730536461, 46.22019924223423, 45.1327545940876, 45.82593619823456, 46.145795434713364, 43.62010136246681, 42.011423483490944, 42.33520790934563, 41.618285179138184, 44.55514378845692, 46.440002247691154, 46.3235916942358, 45.99332481622696, 44.705988094210625, 46.774160116910934, 45.75921177864075, 45.799744203686714, 47.20258332788944, 57.90613017976284, 59.53497737646103, 59.815364331007004, 55.432903692126274, 59.55352038145065, 56.844182163476944, 57.73868076503277, 56.53501935303211, 57.19798877835274, 54.558278024196625, 56.13216497004032, 52.64660060405731, 54.880945309996605, 51.66365794837475, 55.91145001351833, 54.61445041000843, 57.89062321186066, 53.8672661036253, 59.75154295563698, 55.1702655851841, 68.76786634325981, 64.06250283122063, 81.98221206665039, 44.16196368634701, 0.14354219601955265, 2.4470166815444827, 0.2681606059195474, 0.2278363681398332, 16.097404919564724, 76.15261808037758, 65.74155673384666, 71.43204778432846, 53.89674112200737, 62.91423484683037, 30.26144128292799, 47.44585007429123, 46.73903100192547, 79.23736095428467, 27.51259658485651, 0.5525621341075748, 0.0866986192704644, 0.08927500719437376, 0.08941918422351591, 0.05122201961057726, 0.040771159110590816, 0.06372412433847785, 0.16458901431178674, 0.22863662597956136, 0.1377271127421409, 0.27453449671156704, 0.4071263631340116, 0.3568254935089499, 15.12091526761651, 94.56549525260925, 61.968199610710144, 63.75655844807625, 28.420757353305817, 30.333046540617943, 47.581951171159744, 75.28953239321709, 73.25970411300659, 84.43967700004578, 15.879436265677214, 0.3457458224147558, 0.46491345448885113, 0.7900593057274818, 41.955745071172714, 71.10316023230553, 74.64615851640701, 76.07963919639587, 76.20251700282097, 73.72751981019974, 74.26693886518478, 74.11318391561508, 74.24708113074303, 71.17338046431541, 70.36199480295181, 63.20043168962002, 59.96837072074413, 55.47890782356262, 54.646019116044044, 52.66781106591225, 51.62261635065079, 47.73375302553177, 49.891026467084885, 47.37642399966717, 48.59822563827038, 51.06778532266617, 49.48831647634506, 50.50078734755516, 47.36913979053497, 47.663502395153046, 48.393268436193466, 51.010397002100945, 47.88352958858013, 48.97814065217972, 49.4940959662199, 46.231834217906, 49.22976695001125, 49.75998289883137, 49.692494720220566, 48.2620120793581, 47.238977774977684, 47.64035403728485, 46.1090400069952, 48.28497804701328, 49.597651809453964, 50.49933582544327, 47.957948595285416, 44.94031772017479, 49.508573189377785, 46.37597568333149, 42.763235941529274, 41.62305772304535, 43.36341753602028, 43.843529373407364, 42.20292940735817, 45.0847327709198, 49.05928909778595, 42.99823813140392, 43.834603652358055, 46.41786843538284, 45.029985308647156, 42.69350968301296, 47.01104700565338, 45.89043393731117, 43.65125209093094, 43.415980115532875, 43.04733909666538, 46.78884632885456, 45.983563140034676, 45.97173057496548, 45.4349409788847, 48.46514157950878, 44.32898372411728, 45.27488976716995, 41.76975645124912, 41.7964082211256, 43.352447524666786, 46.017468720674515, 41.963652446866035, 41.509132236242294, 42.44274593889713, 44.272666946053505, 44.54219028353691, 43.50519172847271, 45.768335089087486, 43.88280786573887, 46.97008520364761, 48.970788046717644, 44.63075213134289, 44.81164142489433, 42.6829082518816, 40.70184275507927, 39.297848492860794, 40.472863242030144, 41.37979477643967, 40.22933430969715, 42.4158775806427, 47.67680928111076, 49.24125753343105, 49.734623059630394, 48.3932114392519, 46.88451759517193, 44.44335758686066, 44.26455818116665, 42.90725961327553, 47.27545201778412, 49.56325225532055, 49.011795446276665, 48.06801348924637, 48.87630991637707, 48.05943734943867, 49.43283185362816, 48.57010334730148, 50.64733788371086, 60.6942343711853, 62.827219516038895, 64.73401039838791, 59.93517570197582, 62.19307154417038, 59.527932554483414, 61.32816195487976, 58.68474639952183, 59.83594782650471, 58.88450928032398, 60.19655987620354, 56.323317512869835, 57.313126400113106, 56.47456459701061, 59.48475167155266, 58.56461964547634, 60.886724442243576, 56.99889086186886, 61.8804395198822, 59.09157916903496, 71.37742951512337, 67.88837313652039, 84.38488394021988, 47.7882345020771, 0.37822410464286804, 6.426289742812514, 0.4279784270329401, 0.2939794783014804, 19.321632608771324, 82.58724600076675, 73.19025903940201, 78.10392737388611, 65.86670681834221, 76.84101954102516, 42.33928129076958, 59.85422104597092, 55.81550516188145, 88.69644418358803, 37.464192286133766, 0.8223127468954772, 0.3394130466040224, 0.21883395354961976, 0.16323925548931584, 0.17433936533052474, 0.13169998303055763], [0.0811755785252899, 0.0027986242776023573, 0.0576894024561625, 0.041429718694416806, 0.01566464088682551, 0.027286061231279746, 0.22411731770262122, 10.457367561757565, 66.69066980481148, 50.02866268157959, 46.17491327226162, 32.28479281067848, 45.9121535718441, 35.125858560204506, 60.12802675366402, 65.10595723986626, 66.25139817595482, 8.699925765395164, 0.43985522410366684, 0.45427678618580103, 0.8633612317498773, 36.857676431536674, 70.61604917049408, 62.29903265833855, 68.67060676217079, 67.73991510272026, 68.11740204691887, 66.62526771426201, 67.15507328510284, 68.32019716501236, 63.07028867304325, 62.033825889229774, 55.534726828336716, 53.974557146430016, 49.53332506120205, 48.42813916504383, 45.013118013739586, 44.40639317035675, 43.750738352537155, 44.83466438949108, 43.746425583958626, 43.43209505081177, 44.28875908255577, 44.59000691771507, 42.145377695560455, 43.34590047597885, 44.07049119472504, 45.744487568736076, 43.94159451127052, 41.52134858071804, 43.05806592106819, 43.77285696566105, 43.599069491028786, 43.26779566705227, 43.850509598851204, 44.10324923694134, 45.71211710572243, 44.48591150343418, 42.956615164875984, 42.09966994822025, 44.017563834786415, 42.986793145537376, 43.17596219480038, 44.40159022808075, 48.64245526492596, 47.29834198951721, 43.06147053837776, 41.654208451509476, 42.07027092576027, 42.21065439283848, 40.553487315773964, 40.6631950289011, 38.3267156034708, 41.93686008453369, 41.932421922683716, 39.69430021941662, 38.672246262431145, 37.569606229662895, 38.28723952174187, 39.09018583595753, 38.18109221756458, 38.596561923623085, 37.75833070278168, 38.76797452569008, 40.28270624577999, 40.58931939303875, 40.57095877826214, 39.317007064819336, 40.31262964010239, 40.05151905119419, 40.92966713011265, 39.97461497783661, 37.792544066905975, 38.33765521645546, 37.62191042304039, 37.6936923712492, 38.06432448327541, 38.581795915961266, 37.98621967434883, 39.38617095351219, 37.90657974779606, 38.284587264060974, 41.0014870762825, 42.30647765100002, 43.470947965979576, 39.99014854431152, 39.73138242959976, 39.75526414811611, 39.90524969995022, 38.940280079841614, 41.19651161134243, 40.32885476946831, 39.44646991789341, 43.12395438551903, 43.5202731192112, 42.1695975959301, 43.36119085550308, 42.84971930086613, 41.23797118663788, 40.195671916007996, 41.30618512630463, 41.45654305815697, 44.39750924706459, 43.779654800891876, 42.583870366215706, 42.531569972634315, 43.89697350561619, 43.68190884590149, 44.04680326581001, 44.11742627620697, 42.364713326096535, 44.11369867622852, 45.791263058781624, 47.35575690865517, 49.41816084086895, 47.05650396645069, 46.16668291389942, 48.036684170365334, 47.029031440615654, 46.383081302046776, 46.693528443574905, 48.0768708139658, 46.75640746951103, 48.92052814364433, 49.84452836215496, 50.87083049118519, 49.50013004243374, 53.358275815844536, 50.269406363368034, 52.32071489095688, 52.18685567378998, 62.85275414586067, 65.8527235686779, 75.5521211028099, 56.66417442262173, 0.7152279024012387, 1.9508775416761637, 0.4743778856936842, 0.27283655188512057, 8.71281087398529, 67.05308675765991, 60.54853118956089, 64.02167782187462, 55.91214157640934, 59.25702229142189, 20.573756620287895, 26.841267608106136, 37.96496361494064, 67.11632296442986, 36.37656904757023, 0.49477415217552334, 0.0523882749985205, 0.020145376038271934, 0.03799815029196907, 0.021483061973412987, 0.10958085782476701, 0.03107811302470509, 0.08007394935702905, 0.02955650990770664, 0.13524716690881178, 0.03520425743772648, 0.12352199802990071, 0.4154983232729137, 15.162571482360363, 77.85311043262482, 57.673411667346954, 53.47856976091862, 37.258661314845085, 34.33145418763161, 33.792236521840096, 70.20497962832451, 67.67211154103279, 76.93845391273499, 8.754257149994373, 0.3850646282080561, 0.20669468853157014, 0.7518977159634233, 43.67898680269718, 74.71266254782677, 64.2285843193531, 70.76277449727058, 68.93017083406448, 71.67200490832329, 68.12733471393585, 68.936957269907, 69.21645507216454, 67.40190804004669, 63.48347470164299, 59.57513742148876, 55.50668053328991, 51.501224264502525, 50.61001628637314, 48.39104935526848, 48.78877781331539, 46.10369369387627, 46.450926661491394, 45.83405636250973, 45.702872201800346, 47.17115141451359, 45.99108673632145, 44.53038431704044, 43.45550559461117, 47.64642991125584, 48.02504539489746, 47.69524209201336, 42.74970106780529, 45.84150396287441, 46.70029208064079, 45.96835635602474, 45.68994529545307, 47.177675664424896, 45.9177278727293, 46.03076420724392, 46.28872096538544, 44.89769160747528, 43.83589178323746, 45.7744375616312, 44.56796430051327, 45.14973968267441, 45.40000185370445, 50.245292857289314, 48.483110815286636, 41.964818984270096, 42.141748890280724, 41.90851740539074, 42.330070585012436, 41.126884147524834, 41.849267184734344, 38.49119357764721, 41.009747833013535, 45.332749262452126, 41.99793040752411, 41.17133416235447, 41.334584802389145, 40.880151987075806, 42.80345298349857, 41.19377575814724, 42.30417497456074, 41.731625497341156, 43.07173378765583, 43.42150121927261, 43.68489168584347, 43.90385493636131, 41.55357085168362, 42.684910744428635, 42.8526945412159, 44.8011539876461, 42.24057398736477, 41.90621852874756, 41.45212769508362, 40.68158224225044, 39.85549136996269, 41.67504273355007, 39.99084010720253, 41.94377951323986, 41.97980538010597, 40.44843055307865, 41.02977275848389, 43.0374064296484, 43.84851850569248, 42.552039474248886, 40.445193126797676, 40.02376914024353, 39.40539412200451, 39.57022927701473, 39.24333281815052, 40.62814190983772, 39.896981343626976, 39.69741605222225, 43.76344487071037, 45.3611109405756, 44.76327382028103, 46.35509580373764, 44.158034697175026, 43.101938366889954, 42.98614338040352, 43.49160745739937, 43.150587156414986, 44.97336074709892, 45.914239659905434, 45.162051022052765, 45.91184958815575, 44.59775470197201, 44.46015648543835, 47.62517765164375, 44.70235928893089, 45.42424075305462, 46.223307475447655, 47.678276002407074, 49.63522419333458, 50.152467638254166, 47.822493463754654, 48.88578660786152, 50.39052866399288, 50.64443103969097, 49.344786778092384, 49.4016545265913, 51.63631461560726, 50.126860812306404, 50.87628699839115, 53.43759275972843, 53.19005124270916, 52.03198358416557, 54.79909770190716, 52.597047463059425, 55.63681215047836, 54.91031013429165, 64.73859295248985, 69.12289649248123, 77.7052603662014, 60.758747309446335, 1.2191011710092425, 1.7335030809044838, 0.21930543996859342, 0.3322686580941081, 8.916486594825983, 73.64900082349777, 67.2549319267273, 68.47052469849586, 60.07625073194504, 59.43755820393562, 26.776403188705444, 38.25747951865196, 45.74828736484051, 76.02431416511536, 43.30772012472153, 0.4123178048757836, 0.07345080826780759, 0.0774675935099367, 0.03287434417870827, 0.049361125129507855, 0.04382007617095951, 0.08070087860687636, 0.13336464995518327, 0.1333048625383526, 0.281090154312551, 0.19705796032212675, 0.16070321813458577, 0.6654952210374177, 21.837677098810673, 89.57767769694328, 64.02899622917175, 65.13263180851936, 46.645833402872086, 63.04354190826416, 49.609974548220634, 78.52536275982857, 73.90375435352325, 82.94827222824097, 10.20948976278305, 0.5732226942200214, 0.47068308864254504, 1.5064417524263263, 43.088270500302315, 70.78172788023949, 64.92666006088257, 71.13216027617455, 72.18809321522713, 74.4466844201088, 70.87638840079308, 71.40031948685646, 72.70110368728638, 69.28670570254326, 68.8517202436924, 60.616938918828964, 59.14303980767727, 54.282105043530464, 53.052912801504135, 51.84243455529213, 50.871761441230774, 50.05639739334583, 49.028286561369896, 48.63363593816757, 47.82139532268047, 49.508462995290756, 49.13100264966488, 46.496942192316055, 47.64829561114311, 49.70477186143398, 51.125553622841835, 49.89116705954075, 45.3178046643734, 48.85962501168251, 48.32653261721134, 47.93933719396591, 47.83279471099377, 48.49849998950958, 46.56423658132553, 49.70563441514969, 48.00212502479553, 47.15036652982235, 46.10789626836777, 47.73702844977379, 45.93064337968826, 46.86520703136921, 49.141573682427406, 52.757060676813126, 49.27803575992584, 45.707732141017914, 43.100334852933884, 43.536418452858925, 43.45981456339359, 41.46721288561821, 43.404231145977974, 37.968360632658005, 42.11844094097614, 46.95869341492653, 43.824150413274765, 43.87759454548359, 44.43232677876949, 43.747599720954895, 45.83778776228428, 43.902012035250664, 45.42797975242138, 43.36316674947739, 44.71900999546051, 47.1594974398613, 47.08314433693886, 46.9812224060297, 45.67612163722515, 45.67108690738678, 45.43299928307533, 47.47515790164471, 45.585013926029205, 43.93919683992863, 43.91688443720341, 43.869614973664284, 42.49582529067993, 44.24973897635937, 44.47206124663353, 43.45483683049679, 43.93824689090252, 43.753508403897285, 44.21877823770046, 47.29860417544842, 44.135087728500366, 42.39371716976166, 41.428834944963455, 40.34384496510029, 38.56628514826298, 39.98946838080883, 39.728289395570755, 41.73316441476345, 40.6872933357954, 40.60546472668648, 44.919244050979614, 45.841883942484856, 47.806519120931625, 47.30805046856403, 47.375838831067085, 45.07099650800228, 44.55177716910839, 47.000209987163544, 45.08272647857666, 50.862972512841225, 48.78600776195526, 46.656096652150154, 46.56354121863842, 47.080834060907364, 48.565680384635925, 50.09026117622852, 46.20765991508961, 46.761639788746834, 48.29308681190014, 50.52163302898407, 52.85772867500782, 53.24220724403858, 52.216471284627914, 51.2169349193573, 54.1067710518837, 54.26632069051266, 53.47493715584278, 52.548793852329254, 54.082611948251724, 52.5775583088398, 54.20168995857239, 56.43988385796547, 56.98673531413078, 55.99645145237446, 61.65548779070377, 57.35613249242306, 60.34139670431614, 59.544150084257126, 67.71593078970909, 72.11978048086166, 80.1705376803875, 64.87358450889587, 1.2691672844812274, 6.5499659813940525, 1.2647322099655867, 0.5078415025491267, 10.692875124514103, 80.38222432136536, 74.89845737814903, 78.54822233319283, 71.82786494493484, 71.6648156940937, 36.205893605947495, 41.31399370729923, 56.180429980158806, 83.20655956864357, 56.77405692636967, 1.1196714313700795, 0.258015061262995, 0.15451939136255533, 0.12972257507499307, 0.0920127157587558, 0.21859314147150144], [0.17560303502250463, 0.08964680833742023, 0.08987082561361603, 0.04899653766187839, 0.17543878289870918, 0.10207280953181908, 0.19992796413134784, 17.8009732067585, 72.11453676223755, 48.07423755526543, 49.004309847950935, 19.826479218900204, 43.52441869676113, 51.371780410408974, 57.99612835049629, 66.71052753925323, 63.31499934196472, 8.966791145503521, 0.5786439345683903, 0.42312430625315756, 1.7152210744097829, 32.90928170084953, 66.92126423120499, 65.25072947144508, 66.50467738509178, 69.71829414367676, 68.04202169179916, 68.96639049053192, 68.83917331695557, 68.99751842021942, 62.86574184894562, 62.65684425830841, 55.59755265712738, 53.578956574201584, 49.0141399204731, 47.90138483047485, 44.58800062537193, 43.530053794384, 44.532975777983665, 44.635543674230576, 42.93099693953991, 42.63564258813858, 42.8581016510725, 41.544204354286194, 44.146380722522736, 41.05989754199982, 41.92482613027096, 43.75934109091759, 45.975089594721794, 45.83157889544964, 42.40630969405174, 44.24662694334984, 41.55729465186596, 42.817801013588905, 42.48034492135048, 44.04108077287674, 42.90552690625191, 44.28347736597061, 41.438687816262245, 41.95460893213749, 42.09171697497368, 43.08759793639183, 41.507855504751205, 43.295670971274376, 49.641326665878296, 46.37203149497509, 41.70314982533455, 42.12111599743366, 39.01244580745697, 43.56361359357834, 41.35247424244881, 40.674860402941704, 42.299748212099075, 39.366005435585976, 40.51285609602928, 42.28693529963493, 38.531262427568436, 37.811444252729416, 36.7843821644783, 37.75546945631504, 39.16873902082443, 40.758478716015816, 37.60781317949295, 40.20240895450115, 38.26626844704151, 41.921231523156166, 40.157863944768906, 39.84017439186573, 37.700102627277374, 39.54493783414364, 41.035601645708084, 40.46492546796799, 37.45923735201359, 38.15137021243572, 38.0453597009182, 38.01421657204628, 36.88652068376541, 39.20485608279705, 37.03229606151581, 38.019589483737946, 39.17823851108551, 41.30935415625572, 44.44594144821167, 42.989278212189674, 39.67072248458862, 38.85301776230335, 37.84474566578865, 43.344334959983826, 41.65610834956169, 38.316383957862854, 39.548665434122086, 39.09979932010174, 39.8987140506506, 41.2599416077137, 42.580860927700996, 40.59276960790157, 41.94444827735424, 42.26571723818779, 41.81486003100872, 40.58700531721115, 41.90091401338577, 39.74560886621475, 43.0801123380661, 44.39426802098751, 43.19486618041992, 43.420395478606224, 42.83388555049896, 43.37539069354534, 42.77298241853714, 42.3472760617733, 43.29378627240658, 40.07803022861481, 41.78932920098305, 43.12877632677555, 43.589155822992325, 43.985998928546906, 44.703039452433586, 44.011681750416756, 46.90903767943382, 45.95822989940643, 46.27655401825905, 47.41273485124111, 46.620382368564606, 47.50025175511837, 47.32692405581474, 51.863774210214615, 54.31585103273392, 51.27297431230545, 54.28274340927601, 55.09572498500347, 55.04966765642166, 61.623417511582375, 66.9517157971859, 71.74870759248734, 65.14675185084343, 3.1785748014226556, 0.9647065436001867, 0.09915148621075787, 0.20747253351146355, 3.620673716068268, 64.11335170269012, 60.04362188279629, 62.04655900597572, 52.73292817175388, 49.437889382243156, 16.060020625591278, 19.435400404036045, 40.411405339837074, 61.790384352207184, 52.563088685274124, 1.1418685340322554, 0.16622916067717597, 0.04634993885701988, 0.006666845702056889, 0.08841717353789136, 0.04126242747588549, 0.04484126024181023, 0.054877942966413684, 0.12514787289546803, 0.05270969915727619, 0.14460288832196966, 0.11629869695752859, 0.2886194799793884, 21.373720094561577, 83.12358722090721, 53.71161125600338, 60.315299704670906, 28.796304501593113, 34.38209027051926, 50.73597572743893, 68.16277161240578, 71.15774810314178, 71.29818856716156, 8.971945568919182, 0.4711617442080751, 0.26199377432931215, 1.8303258041851223, 38.305691331624985, 73.54360967874527, 67.14999675750732, 66.99517026543617, 70.8212685585022, 71.76995605230331, 71.56047329306602, 69.28868919610977, 69.84206110239029, 64.45657208561897, 63.626882806420326, 58.544530123472214, 55.45249544084072, 51.05814903974533, 50.15839911997318, 47.616415321826935, 46.82741425931454, 46.68029375374317, 47.28030815720558, 45.812693908810616, 47.00408197939396, 44.382085874676704, 44.42560873925686, 46.370629370212555, 44.424962773919106, 42.35527083277702, 46.60316549241543, 48.548847287893295, 46.35779365897179, 44.29947450757027, 45.188307613134384, 42.12898537516594, 46.15488834679127, 44.99843180179596, 44.96375486254692, 46.42022430896759, 45.2748441696167, 44.07612629234791, 45.67970484495163, 44.58486199378967, 45.75079143047333, 44.39080260694027, 45.5573970079422, 51.35613664984703, 49.04537044465542, 42.67492488026619, 41.92423336207867, 40.98571412265301, 44.18580740690231, 43.23570638895035, 41.65022626519203, 43.06923732161522, 39.891502037644386, 41.838103383779526, 46.533291041851044, 41.493184491992, 40.60230329632759, 39.69947174191475, 42.32114866375923, 40.747459307312965, 42.941051200032234, 38.8552026450634, 42.79761649668217, 41.81010268628597, 44.843149334192276, 42.51360073685646, 42.03417286276817, 41.5439535677433, 42.81209371984005, 42.26429231464863, 42.30140872299671, 40.32100059092045, 40.946918204426765, 40.82587189972401, 41.612129509449005, 39.733605310320854, 40.859914273023605, 39.505780935287476, 41.50379732251167, 41.1858531832695, 44.31726895272732, 45.60240939259529, 42.897851318120956, 39.50686387717724, 40.697533786296844, 38.898083344101906, 42.771470099687576, 43.063659220933914, 38.188965395092964, 39.85586754977703, 41.173294857144356, 38.884187489748, 42.940238043665886, 46.06848478317261, 43.18665862083435, 44.91559624671936, 43.8627677410841, 43.65729756653309, 42.62083858251572, 44.1323708742857, 41.954612731933594, 44.60300222039223, 47.87239998579025, 45.34451723098755, 46.1664929240942, 45.024908781051636, 44.78352293372154, 44.19775016605854, 44.03340898454189, 44.68652553856373, 44.415353089571, 43.78660462796688, 45.246547088027, 47.92470417916775, 47.00590208172798, 45.98549343645573, 46.61659017205238, 49.52272742986679, 48.280178904533386, 49.07290376722813, 51.07666924595833, 50.274619683623314, 50.05925104022026, 51.40708431601524, 53.881671130657196, 56.25479198992252, 54.99703288078308, 55.63328213989735, 57.31436513364315, 56.75591289997101, 64.52578157186508, 71.72970861196518, 76.04593500494957, 67.65656277537346, 3.547974117100239, 1.3474378595128655, 0.6193708616774529, 0.17415057780453935, 3.4467883966863155, 70.72878912091255, 66.22004225850105, 69.87749800086021, 59.28800582885742, 58.24291750788689, 21.53539951890707, 24.45697344839573, 47.96698071062565, 68.90687808394432, 62.71173991262913, 1.6601721220649779, 0.21763513272162527, 0.034687782026594505, 0.045118964480934665, 0.06364918968756683, 0.03499355058011133, 0.14840771618764848, 0.20308791019488126, 0.19916996418032795, 0.17028591799316928, 0.21948751847958192, 0.19981926918262616, 0.45266279310453683, 28.67776796221733, 94.83534157276154, 61.96186155080795, 68.01193490624428, 31.406205855309963, 61.82893328368664, 67.75227963924408, 73.08888047933578, 77.37834870815277, 77.75675520300865, 10.094261895865202, 0.6753920274786651, 0.7078837277367711, 2.7993686869740486, 40.58566778898239, 70.06195530295372, 68.69687095284462, 69.48866486549377, 73.88914793729782, 71.58495157957077, 74.2488594353199, 71.964680403471, 71.85939565300941, 68.2920178771019, 69.19915840029716, 61.818134263157845, 58.16702798008919, 54.704657569527626, 53.40499050915241, 51.30912937223911, 51.47214822471142, 50.29058262705803, 50.40120229125023, 48.60457889735699, 49.75177153944969, 48.52393202483654, 46.38132579624653, 49.148037135601044, 47.05597959458828, 44.30489681661129, 48.58282506465912, 51.972129195928574, 50.356797873973846, 46.12900033593178, 48.02151918411255, 46.561170145869255, 47.88338519632816, 47.70454399287701, 48.15486162900925, 47.96623595058918, 48.13294440507889, 47.02819548547268, 47.74274334311485, 47.1123381704092, 47.75603123009205, 46.99753113090992, 46.43503971397877, 54.028400257229805, 50.834021866321564, 42.617441564798355, 42.946633100509644, 39.95661534368992, 44.70643267035484, 43.28794218599796, 41.98037534952164, 43.233722895383835, 41.76625303924084, 43.49538065493107, 49.78894114494324, 44.8099847137928, 42.18006603419781, 41.722243800759315, 44.371058866381645, 43.66875395178795, 46.1413648724556, 42.169867381453514, 46.20774731040001, 43.33645038306713, 47.193315625190735, 43.1543755531311, 44.58830080926418, 42.49227628111839, 45.33480495214462, 44.96554836630821, 45.73218382894993, 42.89115607738495, 44.39288109540939, 43.9829932898283, 43.45140181481838, 43.60874377191067, 45.2738144248724, 41.79250203073025, 43.331138268113136, 42.851964980363846, 48.01355481147766, 47.80501440167427, 45.08923552930355, 40.28420336544514, 39.831218272447586, 38.273890838027, 44.91233602166176, 43.46555985510349, 39.304349943995476, 41.27216175198555, 41.53709873557091, 41.19154527783394, 43.359974920749664, 47.28708699345589, 44.8805583268404, 46.17630019783974, 47.23379485309124, 46.08875669538975, 44.812526777386665, 46.36339455842972, 44.33724448084831, 47.628833055496216, 50.53093872964382, 46.792501732707024, 48.091796413064, 46.85175195336342, 46.8244694173336, 45.531368404626846, 47.11400628089905, 47.899275943636894, 46.090743988752365, 46.12559951841831, 47.90827766060829, 48.72414328157902, 50.42106382548809, 49.88954834640026, 49.03902858495712, 53.04977037012577, 51.56452126801014, 53.87665919959545, 54.273521304130554, 54.311633259058, 53.03507275879383, 52.81525835394859, 58.16435672342777, 59.56263609230518, 57.74080105125904, 60.70835441350937, 60.46190343797207, 60.297539457678795, 66.95457324385643, 75.20573928952217, 77.88597866892815, 72.06960037350655, 4.314709324389696, 4.266202552244067, 2.2593305027112365, 0.4534445417812094, 4.366315305233002, 76.26110225915909, 71.5751101076603, 77.00942650437355, 69.56602111458778, 63.25269788503647, 30.42038105428219, 33.33360493183136, 58.96553993225098, 78.17160934209824, 73.1879411637783, 2.6071391394361854, 0.4004641331266612, 0.2553121594246477, 0.10329119337256998, 0.22245645057410002, 0.19678070879308507], [0.04325131274526939, 0.06637486061663367, 0.037947205564705655, 0.06042302178684622, 0.08333644538652152, 0.14194411458447576, 0.16610360413324088, 24.634965397417545, 72.97620892524719, 54.126921370625496, 46.029198691248894, 26.078553535044193, 37.76311844587326, 43.99546802043915, 67.06597566604614, 62.08547651767731, 65.52150294184685, 6.949033392593265, 0.27127379667945206, 0.2635057072620839, 1.5832774294540286, 40.237861052155495, 51.50058589875698, 67.1309369802475, 65.95527246594429, 70.94457194209099, 66.87075734138489, 66.45663276314735, 62.00082466006279, 63.060344606637955, 59.78178933262825, 57.46322974562645, 50.556591153144836, 47.51863516867161, 46.12709663808346, 45.774182975292206, 41.54216006398201, 44.16474513709545, 42.346706092357635, 44.134031385183334, 42.14750558137894, 43.31099174916744, 46.196811497211456, 42.42309719324112, 40.90976759791374, 49.4298680126667, 51.41276501119137, 52.268042117357254, 54.829450473189354, 55.594573616981506, 55.76693996787071, 56.90373256802559, 47.13217310607433, 40.93217119574547, 44.9997541308403, 40.42190417647362, 41.83640107512474, 42.45974622666836, 41.2107190489769, 42.48956702649593, 42.25614935159683, 40.75495630502701, 40.3438525646925, 40.717000141739845, 46.31129555404186, 48.55690285563469, 42.406150102615356, 42.07897625863552, 40.75415074825287, 44.8098137229681, 40.37034094333649, 44.38824534416199, 45.68927273154259, 43.00325386226177, 43.785339295864105, 43.75808335840702, 43.024950698018074, 38.91216538846493, 38.70896369218826, 40.75887769460678, 38.39207969605923, 39.13043327629566, 38.20752739906311, 38.8586300611496, 38.87665629386902, 42.18313246965408, 38.222221210598946, 37.82273344695568, 37.013642862439156, 39.202279821038246, 41.47868067026138, 38.640251979231834, 38.09201739728451, 39.642691388726234, 38.6615764349699, 38.963040858507156, 37.796951830387115, 38.49698066711426, 39.47697468101978, 38.97819064557552, 39.78304825723171, 43.97829294204712, 41.168157532811165, 42.21319265663624, 41.631945446133614, 42.18048021197319, 39.256696701049805, 40.36022588610649, 43.27886067330837, 40.54521515965462, 39.472893700003624, 39.844954535365105, 39.11255903542042, 39.95583638548851, 43.990912064909935, 39.54349771142006, 41.98656141757965, 42.32820488512516, 40.50907909870148, 39.586481004953384, 40.820947363972664, 40.21856188774109, 42.624463587999344, 43.281349539756775, 42.03197658061981, 41.668742671608925, 42.457257360219955, 42.38448366522789, 41.690591499209404, 42.56296768784523, 42.59001463651657, 43.841010108590126, 41.76487371325493, 42.230941504240036, 43.014087080955505, 42.63292573392391, 43.44188332557678, 43.00591751933098, 44.35505032539368, 43.464009538292885, 44.662708416581154, 45.850064903497696, 47.69938386976719, 49.3961676210165, 50.86565896868706, 52.85167559981346, 56.004286631941795, 56.23584620654583, 58.0596761405468, 58.229660019278526, 60.809375792741776, 61.759180426597595, 68.48540470004082, 68.64292904734612, 68.97550240159035, 4.920019693672657, 0.7636405108496547, 0.4078899143496528, 0.11500114080263302, 0.8806853333953768, 55.367030426859856, 66.5078616142273, 58.848821595311165, 57.26605832576752, 45.8392620831728, 19.385039806365967, 20.714219883084297, 40.146236568689346, 53.02604824304581, 54.35144752264023, 1.6828995337709785, 0.04037118975247722, 0.06533855528687127, 0.025681437764433213, 0.03462502601905726, 0.038249248536885716, 0.0669177713280078, 0.04830471872992348, 0.040340646664844826, 0.0239793628861662, 0.03770726179936901, 0.024434887563984375, 0.233320883999113, 29.400416985154152, 82.63018369674683, 61.63859769701958, 51.802126318216324, 28.5326936468482, 42.38307014107704, 51.01553812623024, 74.58691969513893, 66.18696883320808, 73.21912229061127, 7.22614492289722, 0.22147770621813834, 0.07715768748312257, 1.7601810931228101, 43.663639426231384, 57.177549675107, 68.53260576725006, 66.47874757647514, 73.11889126896858, 67.11760729551315, 68.67322102189064, 62.941201999783516, 64.0562179684639, 63.24310339987278, 58.965904712677, 52.852226570248604, 51.69844128191471, 47.653022557497025, 48.503724709153175, 44.225633069872856, 44.79498691856861, 44.954316169023514, 45.96195749938488, 43.371362909674644, 45.85105665028095, 48.38031493127346, 45.010484755039215, 44.618505388498306, 50.44989287853241, 54.43861864507198, 54.6620162576437, 58.019497096538544, 59.431558325886726, 58.03346514701843, 59.99134808778763, 47.63369299471378, 43.460441529750824, 44.63089272379875, 42.34805881977081, 42.3782330006361, 45.200227573513985, 42.580431550741196, 44.124771282076836, 43.51222135126591, 43.78335200250149, 42.37782642245293, 43.15100893378258, 47.749989554286, 50.57812079787254, 42.62559212744236, 41.44701696932316, 42.061109617352486, 43.59963946044445, 42.368725910782814, 44.98776197433472, 44.569917395710945, 43.75179469585419, 43.815608471632004, 45.91333910822868, 44.18492205440998, 41.43688291311264, 41.89389958977699, 43.90725955367088, 41.995585933327675, 41.324294954538345, 40.314111560583115, 40.16419060528278, 40.86915537714958, 44.19255204498768, 41.07495233416557, 40.07218234241009, 40.810083746910095, 41.73120751976967, 44.073603227734566, 41.999488323926926, 39.744077548384666, 42.472426146268845, 41.8036088347435, 41.67505793273449, 40.535138100385666, 41.9427003711462, 41.47149905562401, 42.622449696063995, 41.42403960227966, 45.39986506104469, 42.22631715238094, 41.722817569971085, 42.60696932673454, 40.70982612669468, 40.111308842897415, 42.70596921443939, 44.79768857359886, 41.082962304353714, 38.96923452615738, 40.493632927536964, 39.98521260917187, 42.07728534936905, 45.55412918329239, 41.360928788781166, 44.87402267754078, 44.94236581027508, 42.58725978434086, 43.25074218213558, 42.35236398875713, 42.447678074240685, 43.3510871976614, 44.91968862712383, 44.10580649971962, 44.05898921191692, 44.62534882128239, 44.36711847782135, 44.51727122068405, 43.92125800251961, 44.002307653427124, 46.29305273294449, 44.80754144489765, 45.55260166525841, 45.06424427032471, 43.60460579395294, 44.8205291479826, 45.567409470677376, 47.076745480298996, 46.049660593271255, 47.27883763611317, 48.96044500172138, 50.30104726552963, 51.452689468860626, 53.4086649119854, 55.683317855000496, 59.870005398988724, 58.753507509827614, 61.30980893969536, 61.32816955447197, 63.91599029302597, 64.47892248630524, 70.498156696558, 72.19445407390594, 72.37184375524521, 5.457096174359322, 1.3991876388899982, 1.150206949096173, 0.10376515114330687, 0.7771191594656557, 59.83731955289841, 72.87689745426178, 66.2771911919117, 63.58383871614933, 51.443341970443726, 26.54426034539938, 21.958476416766644, 48.214689418673515, 58.92495810985565, 66.20161324739456, 2.708265488035977, 0.08944073619204573, 0.10129402944585308, 0.10536400441196747, 0.038902423839317635, 0.04095465141290333, 0.22598732204642147, 0.24208747374359518, 0.24331100808922201, 0.1271224458469078, 0.2280223651905544, 0.276311970083043, 0.48501027922611684, 35.88077925145626, 93.64691734313965, 70.3775055706501, 61.889103055000305, 36.322653740644455, 53.39069947600365, 57.73738123476505, 84.61913377046585, 70.08777871727943, 80.6504063308239, 8.622059393674135, 0.3559789404971525, 0.45148322358727455, 2.380055249668658, 47.307203114032745, 58.04908610880375, 67.33784347772598, 68.24024945497513, 74.60027977824211, 71.31995379924774, 71.79177448153496, 66.06010884046555, 69.36249643564224, 66.90874770283699, 61.84051886200905, 55.234003365039825, 52.770850136876106, 50.25720901787281, 51.84007488191128, 47.47882850468159, 50.011567398905754, 46.82627812027931, 50.03940470516682, 45.56134879589081, 47.550447061657906, 50.700044855475426, 47.20746226608753, 47.796829640865326, 55.47546900808811, 58.284901455044746, 57.54361443221569, 62.96577908098698, 61.332907900214195, 61.767087802290916, 61.235082149505615, 51.787269115448, 45.00202640891075, 48.50625537335873, 45.527861192822456, 45.82260377705097, 47.088543847203255, 45.41719973087311, 45.97805343568325, 46.08178406953812, 45.77431596815586, 43.82429860532284, 46.059547662734985, 50.03205969929695, 52.127692848443985, 42.71183229982853, 41.683554276824, 43.87349836528301, 45.054896771907806, 44.85943526029587, 47.40452729165554, 45.96348121762276, 43.820601403713226, 45.628909170627594, 46.92879281938076, 47.70519755780697, 44.38443414866924, 45.00821627676487, 46.95116601884365, 42.69711188971996, 45.06781607866287, 43.74521344900131, 42.501942962408066, 44.067789539694786, 46.30320578813553, 43.252117708325386, 42.823949083685875, 43.10361787676811, 45.323907136917114, 47.69535608589649, 45.928732082247734, 42.70444929599762, 44.16708581149578, 44.89346623420715, 44.25571225583553, 43.6589352786541, 44.79567088186741, 43.78466673195362, 43.73887538909912, 44.047456830739975, 46.50892674922943, 42.18402922153473, 43.97697061300278, 42.45897486805916, 44.06213544309139, 39.92631956934929, 43.06914992630482, 44.282622411847115, 41.492169946432114, 40.091937482357025, 40.110374093055725, 40.5401424318552, 42.79729351401329, 48.12372989952564, 43.809152618050575, 45.782705917954445, 47.98214949667454, 45.074678510427475, 44.875667989254, 44.80759844183922, 44.58268091082573, 46.49625062942505, 49.25256572663784, 46.59983687102795, 45.974789410829544, 47.032941430807114, 46.77307717502117, 48.897600173950195, 45.762639194726944, 45.971206203103065, 50.30557282269001, 46.79614953696728, 48.5213253647089, 48.59731748700142, 47.733741626143456, 49.370435401797295, 49.47624072432518, 50.39358749985695, 49.750453010201454, 51.356801614165306, 51.773434057831764, 54.831304773688316, 55.703870952129364, 56.656833216547966, 60.335674211382866, 64.25800994038582, 62.7497036755085, 64.28639441728592, 63.966527581214905, 67.86641791462898, 66.66363805532455, 74.08748209476471, 76.51346191763878, 76.91713705658913, 6.687131496146321, 2.789809349924326, 1.421738003846258, 0.1250103084021248, 1.2027084943838418, 65.34557238221169, 80.3133188188076, 70.6718909740448, 74.67833518981934, 59.77294720709324, 34.397840425372124, 33.01537200808525, 60.47293044626713, 67.30448886752129, 78.51039156317711, 4.225887190550566, 0.2893234812654555, 0.17329041380435228, 0.17423213983420283, 0.12950898497365415, 0.15160500712227076], [0.05323192621290218, 0.05364179211028386, 0.05483112829097081, 0.019959226847277023, 0.03513157891575247, 0.036250437042326666, 0.030483938462566584, 31.917390525341034, 67.35276907682419, 45.01863531768322, 46.28260709345341, 44.63377296924591, 31.115266866981983, 38.59232135117054, 67.72976964712143, 61.36380784213543, 61.71251133084297, 4.846480814740062, 0.18452688585966825, 0.35436266160104424, 0.9945819654967636, 43.42278175055981, 70.64108222723007, 67.34762415289879, 67.37165406346321, 65.40779024362564, 65.01143351197243, 64.50292199850082, 61.82112470269203, 58.96474577486515, 55.514120534062386, 50.160287618637085, 48.34370769560337, 46.443201676011086, 46.21954567730427, 45.936639457941055, 47.97581143677235, 44.71620574593544, 43.84267441928387, 45.79687535762787, 44.300880432128906, 44.663977548480034, 41.09183482825756, 45.26604384183884, 53.81977625191212, 54.905195608735085, 56.222311332821846, 57.762619480490685, 56.901414692401886, 55.0878632068634, 56.548041254282, 57.58010387420654, 55.13843849301338, 48.054319024086, 43.07121701538563, 42.32366792857647, 41.524415016174316, 43.0150256305933, 40.746961534023285, 43.25641147792339, 41.17711365222931, 42.6534978300333, 41.41343057155609, 41.057511270046234, 44.624129086732864, 46.912332102656364, 41.38330198824406, 40.44725641608238, 41.79467171430588, 43.20491284132004, 43.08158665895462, 42.21462897956371, 43.69505614042282, 42.57687874138355, 41.59890241920948, 41.683869659900665, 42.18500576913357, 40.99112883210182, 38.042639046907425, 38.59355628490448, 38.915421813726425, 40.11456526815891, 38.39916251599789, 38.98379534482956, 41.096751764416695, 40.54293908178806, 40.298342406749725, 38.78365248441696, 38.34595017135143, 39.62016239762306, 41.12896263599396, 40.268715396523476, 37.57917411625385, 39.73375350236893, 37.078231796622276, 38.45057375729084, 38.56935158371925, 38.22594881057739, 36.37213468551636, 40.10968632996082, 41.985261887311935, 40.53990304470062, 41.984395533800125, 43.81816193461418, 42.83945985138416, 47.46974319219589, 46.49655841290951, 40.55513262748718, 41.24669171869755, 38.656553104519844, 38.504086285829544, 37.877849489450455, 36.95860281586647, 42.985223829746246, 43.82697746157646, 39.89883564412594, 40.35112537443638, 38.95326778292656, 38.12539100646973, 39.48433868587017, 40.64253553748131, 39.656446650624275, 41.457200422883034, 43.95493559539318, 42.3115161806345, 42.86774933338165, 42.39936366677284, 43.43472070991993, 42.58796274662018, 41.40003249049187, 41.611437946558, 39.97650347650051, 41.882838383316994, 42.17680960893631, 40.76589971780777, 42.76103585958481, 42.42244742810726, 43.20373110473156, 43.44861276447773, 43.769243359565735, 45.74487514793873, 45.42678661644459, 45.73792912065983, 48.89592066407204, 50.96185080707073, 52.90642686188221, 55.949713960289955, 56.71710558235645, 61.17999270558357, 61.76549568772316, 62.38429248332977, 62.97899857163429, 68.07283043861389, 68.53342652320862, 69.99526888132095, 6.000843197107315, 0.7253297790884972, 0.54249795852229, 0.08593904596637003, 0.1898480550153181, 46.434386149048805, 70.11379212141037, 62.53954455256462, 54.46030408143997, 52.907152622938156, 18.642272762954235, 12.15886116027832, 32.91833661496639, 51.93293049931526, 70.26711389422417, 5.22542355582118, 0.2034113826812245, 0.03725411013874691, 0.07082526048179716, 0.03283236459537875, 0.055519737434224226, 0.055465363984694704, 0.011486517378216377, 0.06855853367596865, 0.029340290748223197, 0.014717984213348245, 0.12795368093065917, 0.0744257825135719, 40.6679979711771, 76.85158297419548, 53.55708494782448, 58.190727308392525, 46.30589984357357, 38.93376722931862, 42.98995077610016, 73.84249404072762, 67.57685825228691, 69.28541377186775, 5.619229199364781, 0.20890851505100727, 0.36461917217820883, 1.138231297954917, 46.25030882656574, 73.56345981359482, 70.91035857796669, 69.77721378207207, 67.63582348823547, 66.26122444868088, 67.61084362864494, 65.01331821084023, 59.358685836195946, 58.52146536111832, 53.53808976709843, 50.13492397964001, 48.9617445319891, 49.13588158786297, 48.588197976350784, 48.547939136624336, 46.371358931064606, 47.26252891123295, 48.338361382484436, 46.89400188624859, 47.14373588562012, 45.18253952264786, 47.47194707393646, 54.80193994939327, 59.13601018488407, 59.78014402091503, 60.48638552427292, 59.67518985271454, 57.47960686683655, 59.168958216905594, 58.2379549741745, 57.776211351156235, 48.76953564584255, 44.42651689052582, 47.05640897154808, 44.468421041965485, 44.10301744937897, 42.44959317147732, 46.06863297522068, 43.137569054961205, 44.538018107414246, 45.66301614046097, 41.923914179205894, 46.23808108270168, 48.37521180510521, 41.7327768355608, 39.57439765334129, 42.64086350798607, 45.09560778737068, 43.40504810214043, 43.138427808880806, 43.901677653193474, 42.513931319117546, 42.70924463868141, 43.42728450894356, 43.041441813111305, 42.31416083872318, 41.94634437561035, 42.338593527674675, 41.71594753861427, 40.76024182140827, 41.55954413115978, 41.205672919750214, 44.06921826303005, 42.81057380139828, 42.8389772772789, 41.438045650720596, 41.02121941745281, 42.32743352651596, 42.83325478434563, 40.98566472530365, 41.506525576114655, 41.5664217621088, 40.8358159661293, 40.67471981048584, 41.34664535522461, 40.87700195610523, 39.38346929848194, 42.81301327049732, 44.2014017701149, 40.22430717945099, 43.014729246497154, 43.98906156420708, 43.67326810956001, 47.146486937999725, 47.60898292064667, 41.68929196894169, 41.33826680481434, 39.37935031950474, 37.95882694423199, 36.75121754407883, 37.27931320667267, 44.1275679320097, 45.089315325021744, 42.12790623307228, 42.22638554871082, 41.68601654469967, 40.615040212869644, 41.17806360125542, 43.54553036391735, 42.255833968520164, 44.174335822463036, 45.632344186306, 44.78285036981106, 44.462341368198395, 42.03296832740307, 44.922743663191795, 43.63183133304119, 43.600836396217346, 44.72386233508587, 42.453586757183075, 43.84542927145958, 44.72634740173817, 42.102888375520706, 44.5413239300251, 45.64179427921772, 46.31148174405098, 46.09151914715767, 45.24034582078457, 48.902410715818405, 48.75580318272114, 49.8608522862196, 51.97093985974789, 53.94769258797169, 54.55722168087959, 59.403139650821686, 58.4895508736372, 63.23055647313595, 63.47978129982948, 66.112629622221, 64.25378456711769, 71.57517850399017, 70.67198976874352, 73.56479734182358, 6.355051165446639, 0.9455105673987418, 1.1517105996608734, 0.16489599627675489, 0.14080649125389755, 50.76786741614342, 76.36605262756348, 68.14445659518242, 63.8727106153965, 55.35935863852501, 25.921260975301266, 16.844045855104923, 39.10798028111458, 60.124124363064766, 78.88404071331024, 7.545898240059614, 0.27415997930802405, 0.13195363426348194, 0.11078564552008174, 0.027850726146425586, 0.11663506054901518, 0.1924266025889665, 0.14786354382522404, 0.26546503650024533, 0.14944183960324153, 0.12301917071454227, 0.21720418240875006, 0.21355266741011292, 50.27385972440243, 88.29428896307945, 59.259522557258606, 60.509450286626816, 53.882811069488525, 42.59658448398113, 55.1077551394701, 81.1503455042839, 72.85352110862732, 75.22542983293533, 6.254748897626996, 0.4930154699832201, 0.5707445740699768, 1.6877908213064075, 49.69913676381111, 75.53881421685219, 73.50012481212616, 70.03341123461723, 71.68499261140823, 68.88144984841347, 71.62438586354256, 66.85022324323654, 61.820843517780304, 61.87625594437122, 56.50596231222153, 51.51157110929489, 52.59714625775814, 52.66226716339588, 51.84611275792122, 53.43842871487141, 49.39431332051754, 47.92665347456932, 52.900951355695724, 48.461037799715996, 49.87985506653786, 45.871244966983795, 51.24462403357029, 59.78619709610939, 61.887609735131264, 62.67410673201084, 63.35042104125023, 62.349778935313225, 59.155932515859604, 61.781519427895546, 60.86245134472847, 60.16730144619942, 53.492587208747864, 48.68955373764038, 47.50858470797539, 47.192088291049004, 46.22512377798557, 43.946089670062065, 49.10199120640755, 47.59595721960068, 47.350285202264786, 47.324146404862404, 44.81354132294655, 48.567891865968704, 49.56614010035992, 41.75492584705353, 40.86929976940155, 43.162776902318, 45.45928627252579, 44.87459644675255, 44.024870842695236, 44.15615759789944, 43.62124130129814, 43.511335998773575, 44.47491109371185, 45.35773292183876, 45.572896376252174, 43.76548916101456, 44.48873095214367, 45.0179323554039, 44.454016014933586, 45.02553954720497, 43.20666454732418, 47.54817098379135, 45.74541091918945, 45.48312999308109, 43.799497336149216, 43.70724208652973, 45.25038108229637, 45.97822442650795, 45.19513584673405, 43.83690632879734, 45.03136843442917, 41.073668003082275, 42.95171342790127, 46.27477191388607, 42.36055634915829, 41.28853127360344, 45.481442883610725, 46.21255785226822, 41.815703585743904, 43.84239703416824, 45.098989605903625, 44.39448080956936, 48.87884438037872, 49.24971967935562, 42.69230894744396, 42.94770464301109, 41.05712369084358, 36.94648526608944, 38.253390938043594, 37.12159886956215, 46.16175837814808, 48.097689896821976, 44.15512025356293, 44.53637659549713, 42.86694757640362, 40.838810205459595, 42.65176132321358, 46.636143922805786, 44.22057554125786, 45.785312578082085, 47.227289602160454, 46.31062299013138, 47.40010052919388, 44.81126144528389, 48.23278784751892, 47.51489996910095, 45.301792323589325, 46.9524085521698, 44.50136907398701, 47.386729046702385, 48.76205004751682, 44.69966523349285, 46.38090021908283, 47.98150733113289, 50.19257448613644, 48.58086436986923, 49.092746302485466, 51.09613940119743, 52.54964880645275, 52.267133966088295, 55.28823785483837, 55.960645973682404, 58.71826060116291, 63.75002279877663, 61.31785690784454, 66.682538241148, 69.59417000412941, 70.21833211183548, 68.55839118361473, 72.8412401676178, 73.60121458768845, 77.03490033745766, 8.021563366055489, 2.5127491168677807, 2.9355381801724434, 0.22692254686262459, 0.33348842232953757, 55.01672722399235, 82.9225704073906, 75.76372414827347, 71.00813493132591, 69.35207739472389, 33.81046034395695, 24.39402412623167, 51.075681298971176, 69.53861698508263, 90.56073054671288, 11.160422936081886, 0.7166993734426796, 0.17359061253955588, 0.23861146182753146, 0.19343774911249056, 0.1887186843669042], [0.04923503794998396, 0.024965422962850425, 0.052227974811103195, 0.0362021603359608, 0.0486943907890236, 0.15069339744513854, 0.10808344872202724, 39.67300236225128, 61.735940873622894, 44.831263571977615, 23.71244139969349, 49.783245250582695, 53.49418692290783, 42.59658068418503, 66.32211998105049, 61.77363105118275, 62.39326760172844, 3.6227267934009433, 0.1812622821307741, 0.43349893705453724, 0.36158720206003636, 36.62698321044445, 72.91629374027252, 66.07529282569885, 67.9192578792572, 63.51321950554848, 63.24990123510361, 57.74989776313305, 57.44032457470894, 53.42012509703636, 50.811059698462486, 47.67000384628773, 45.99767558276653, 45.43113358318806, 43.92574556171894, 48.73503729701042, 44.878350645303726, 44.97399151325226, 43.842894807457924, 44.951386526227, 42.43044599890709, 45.814373418688774, 49.71294142305851, 55.9942589700222, 53.57058942317963, 61.02183759212494, 59.782659485936165, 54.670740589499474, 52.031839191913605, 59.05770778656006, 59.73203860223293, 54.20834340155125, 51.99694566428661, 45.48369996249676, 44.11624453961849, 43.922147154808044, 41.99647128582001, 43.50386179983616, 43.36563281714916, 42.06001527607441, 41.98375716805458, 40.30635617673397, 40.292304530739784, 40.556386560201645, 43.10456782579422, 46.9501780718565, 43.31774778664112, 41.96530535817146, 39.51724871993065, 43.65500248968601, 47.45806261897087, 44.6485161781311, 45.56155778467655, 45.62338046729565, 43.58228579163551, 43.077843859791756, 43.32231134176254, 42.17019036412239, 38.218858391046524, 41.21435545384884, 39.27632264792919, 41.033553555607796, 37.06757336854935, 38.73004496097565, 40.95253810286522, 41.73399657011032, 38.7813726067543, 36.82291589677334, 37.67700746655464, 38.24629671871662, 42.353899106383324, 39.77265581488609, 37.18095928430557, 37.905177623033524, 40.71641117334366, 38.70004937052727, 37.45563894510269, 37.448396533727646, 39.8024196177721, 41.70970447361469, 39.40710783004761, 42.32584521174431, 45.24990990757942, 43.76431882381439, 40.45651651918888, 43.21960285305977, 42.59421341121197, 40.773381516337395, 39.313849434256554, 37.730964571237564, 37.50471331179142, 37.92392961680889, 38.043076023459435, 42.173511385917664, 43.52072149515152, 37.87371911108494, 40.25150611996651, 41.35862611234188, 41.29031717777252, 41.833908408880234, 42.22502902150154, 40.277169942855835, 43.985508754849434, 41.01971469819546, 41.9402951002121, 41.14927254617214, 42.832593619823456, 42.6427748054266, 42.56167195737362, 41.2873837351799, 41.5231154859066, 39.28984232246876, 42.49417617917061, 42.95798309147358, 44.14195775985718, 42.35741391777992, 44.13661144673824, 44.85703378915787, 44.186305180191994, 43.76120679080486, 44.17439661920071, 43.32752846181393, 45.810197442770004, 45.638393461704254, 47.79387339949608, 50.64800664782524, 57.24281497299671, 58.167240768671036, 62.695188000798225, 59.94536675512791, 63.58630858361721, 61.197437569499016, 69.49868112802505, 67.50922948122025, 72.3471450805664, 6.114879352971911, 0.7737565774004906, 0.9190808481071144, 0.19524706061929464, 0.0850042887032032, 35.70623941719532, 73.59923869371414, 64.04693126678467, 61.54484912753105, 45.208332538604736, 28.95363125950098, 8.592666070908308, 26.71623721718788, 49.657661989331245, 66.18276625871658, 9.189911372959614, 0.3583618876291439, 0.020937435001542326, 0.02506674652977381, 0.01006784272249206, 0.06360916566336527, 0.04577386898745317, 0.0674223797977902, 0.02197205751144793, 0.030301542683446314, 0.052746817673323676, 0.10777627379866317, 0.05851081521541346, 47.59734034538269, 72.0764248073101, 50.6837323307991, 34.52195696532726, 53.63852597773075, 56.5810576826334, 48.41242700815201, 72.69722029566765, 66.30319699645042, 67.71020829677582, 3.798563308082521, 0.34734022279735655, 0.15324653388233855, 0.7024108339101076, 40.021139681339264, 74.98532071709633, 68.91212940216064, 70.39309993386269, 66.4109668135643, 65.46559274196625, 59.03191477060318, 59.25046764314175, 56.61935202777386, 52.335974872112274, 49.5642364025116, 48.83236527442932, 48.80754880607128, 47.59264379739761, 49.030539840459824, 45.59996612370014, 47.69016556441784, 46.94398820400238, 46.08612343668938, 44.75420370697975, 49.289416149258614, 52.13515184819698, 59.45960082113743, 56.979671493172646, 61.59380190074444, 62.45693318545818, 57.10875056684017, 53.38661089539528, 60.128444731235504, 59.950553476810455, 56.94632068276405, 55.0217467546463, 48.03762272000313, 47.05815687775612, 45.08145734667778, 45.977981239557266, 45.41789509356022, 45.53691230714321, 44.23454359173775, 44.24313873052597, 42.17606484889984, 43.25867995619774, 43.281030356884, 43.5352823138237, 48.38101029396057, 44.805151373147964, 41.51591867208481, 40.498477667570114, 46.01630978286266, 48.15260834991932, 45.228783041238785, 45.04707679152489, 45.6627881526947, 44.70867834985256, 45.27309246361256, 44.137591794133186, 43.611133843660355, 41.97004370391369, 42.59462758898735, 42.421455681324005, 42.72940635681152, 40.53975485265255, 40.54841458797455, 40.6311209499836, 43.70547518134117, 43.94495353102684, 40.490650087594986, 40.280008390545845, 41.872875317931175, 44.67431679368019, 42.181445360183716, 40.64499020576477, 42.3406720161438, 41.813663095235825, 42.3121203482151, 40.779700577259064, 40.0649893283844, 42.54432588815689, 46.322463154792786, 41.288869455456734, 43.781026527285576, 45.62809221446514, 43.15798915922642, 40.14221638441086, 43.290826231241226, 42.33113072812557, 40.52913822233677, 39.417720660567284, 36.95371247828007, 38.34110923111439, 37.645624950528145, 39.43337582051754, 45.073641166090965, 45.00948540866375, 40.79604730010033, 41.425000950694084, 42.98194080591202, 43.4232035279274, 44.060911908745766, 42.4557526409626, 43.17214719951153, 45.60339733958244, 43.18717919290066, 44.071243554353714, 41.7311505228281, 44.75106507539749, 44.758630469441414, 44.79595586657524, 43.21506209671497, 43.828884959220886, 41.69717654585838, 44.82684060931206, 45.58395758271217, 46.29467524588108, 44.6028046309948, 46.333053186535835, 45.811998546123505, 47.36275613307953, 45.32379314303398, 46.53262607753277, 46.021139323711395, 47.49395169317722, 48.616084679961205, 50.753029212355614, 53.198160007596016, 58.54056313633919, 60.302220806479454, 66.51127383112907, 60.699432492256165, 67.09185227751732, 64.59900364279747, 71.82442992925644, 68.8810470700264, 75.83598867058754, 6.538889100775123, 0.7534974301233888, 2.216340797021985, 0.1696078325039707, 0.018175024051743094, 36.27071052789688, 80.52923083305359, 68.72818127274513, 72.05890774726868, 48.609739020466805, 34.791598096489906, 16.890960037708282, 36.60426042973995, 55.74277326464653, 78.04238587617874, 13.150219414383173, 0.4269523930270225, 0.09412177329068072, 0.07781704858643934, 0.022703388385707512, 0.0686609277909156, 0.09822515974519774, 0.15810599812539294, 0.1773092325311154, 0.09753851729328744, 0.24059419840341434, 0.2510972652817145, 0.30305603344459087, 54.24837425351143, 81.14479780197144, 58.6347296833992, 36.78668484091759, 60.0425161421299, 71.3984651863575, 56.64546802639961, 81.71481281518936, 71.85249522328377, 78.04215028882027, 3.8887414941564202, 0.4579943820135668, 0.4357260628603399, 1.7052510031498969, 42.90018059313297, 80.34688621759415, 72.43020102381706, 74.04873937368393, 70.95420062541962, 67.69361838698387, 61.670933961868286, 63.99834707379341, 58.762950003147125, 57.34363116323948, 53.31323683261871, 51.362562105059624, 48.875766545534134, 48.93446959555149, 53.54454942047596, 48.19224402308464, 50.021576061844826, 49.15525294840336, 48.07364098727703, 47.763163447380066, 52.56714306771755, 53.477289229631424, 64.4526506960392, 58.698182478547096, 64.90139901638031, 64.3576329946518, 59.54941280186176, 55.36763459444046, 62.91486941277981, 64.67754542827606, 58.97594757378101, 57.42831341922283, 51.02530740201473, 49.13613997399807, 47.61044584214687, 47.93776787817478, 48.64284664392471, 48.11856597661972, 45.78381925821304, 47.310736924409866, 43.44512455165386, 44.92006480693817, 44.99575674533844, 46.53046019375324, 51.386899799108505, 47.25902169942856, 42.844384387135506, 40.36928839981556, 45.79600140452385, 49.62989687919617, 46.862569972872734, 45.17883472144604, 48.0136726051569, 46.32438205182552, 45.944288447499275, 46.46229185163975, 47.002698853611946, 44.67840917408466, 45.63511423766613, 45.20126111805439, 47.181593254208565, 42.86888167262077, 43.56085114181042, 45.36323502659798, 48.60828369855881, 44.75660137832165, 43.283656015992165, 42.781330570578575, 44.901932179927826, 47.63717360794544, 44.434910640120506, 42.55648523569107, 45.03321513533592, 45.98665617406368, 44.21818546950817, 41.53962180018425, 42.565296962857246, 45.596968084573746, 46.27335458993912, 42.71756999194622, 43.351486176252365, 48.53198379278183, 43.76968793570995, 39.99322637915611, 43.338570669293404, 43.733544275164604, 40.7061555236578, 40.01520819962025, 37.09774374961853, 39.02034938335419, 37.93450064957142, 40.05313016474247, 47.71493263542652, 48.83429937064648, 40.95061540603638, 45.189295560121536, 45.073401778936386, 47.312013655900955, 45.878266990184784, 45.845657140016556, 43.48741628229618, 49.52913388609886, 46.20254538953304, 45.75388066470623, 44.57752838730812, 48.25363352894783, 46.870838329195976, 46.77821069955826, 46.542741134762764, 46.774657890200615, 44.018935561180115, 47.28617124259472, 47.443437203764915, 49.91080820560455, 46.67488284409046, 49.492564648389816, 49.87177290022373, 49.20840069651604, 48.82249340415001, 50.03944270312786, 48.041787296533585, 50.75329139828682, 50.878433883190155, 53.63387882709503, 56.37760140001774, 62.91256673634052, 63.848095536231995, 70.25989428162575, 64.6596559882164, 69.29264098405838, 67.64505699276924, 73.85314106941223, 74.10474076867104, 78.78014668822289, 8.855184484273195, 2.7241550479084253, 5.3862912487238646, 0.5229491950012743, 0.10311486650607549, 41.66626140475273, 85.65412983298302, 74.98916611075401, 79.1353440284729, 62.19038888812065, 40.33342592418194, 20.420818626880646, 43.26786786317825, 65.50370469689369, 88.79864349961281, 18.76926764845848, 0.5048327171243727, 0.39322673866990954, 0.16869105747900903, 0.2660398150328547, 0.3071097924839705], [0.004395086671138415, 0.04054332348459866, 0.11782341709476896, 0.06879621389089152, 0.022214389136934187, 0.04144014215853531, 0.12620673951460049, 39.972338899970055, 61.330240443348885, 45.20157650113106, 46.94831617176533, 23.75746328383684, 29.43104524165392, 43.87990862131119, 66.61554023623466, 60.6410676240921, 56.640444695949554, 2.590556829236448, 0.15144553442951292, 0.7792242465075105, 0.163925044471398, 31.164238639175892, 72.16906383633614, 64.2678590118885, 64.84544321894646, 62.27716863155365, 61.55772663652897, 58.855691626667976, 56.45549722015858, 54.44667421281338, 52.16590739786625, 52.00671873986721, 54.59011651575565, 53.297304287552834, 54.2158517986536, 53.318529948592186, 56.479660123586655, 52.98657976090908, 51.781314834952354, 49.200398325920105, 50.96623957157135, 53.866646736860275, 57.24534563720226, 53.235299214720726, 67.58426025509834, 41.94721832871437, 41.40487723052502, 51.606391221284866, 55.26341758668423, 58.22807930409908, 55.051711946725845, 51.50126986205578, 45.15104681253433, 50.85761100053787, 47.255400493741035, 47.79581889510155, 42.273404225707054, 43.48508320748806, 41.913787722587585, 43.61975938081741, 41.894511356949806, 41.433018520474434, 40.24329476058483, 42.58457712829113, 40.4947766661644, 44.71048705279827, 45.96821956336498, 40.93368351459503, 39.47444401681423, 41.711524575948715, 46.88698746263981, 44.58306469023228, 44.38487492501736, 45.07693558931351, 43.50918911397457, 46.29011929035187, 41.809255331754684, 40.674518421292305, 40.02142086625099, 40.08365012705326, 39.900127574801445, 39.36395734548569, 37.31503888964653, 39.56770621240139, 37.74698831140995, 40.14562860131264, 40.22528372704983, 39.064681604504585, 38.129669576883316, 40.14159321784973, 41.610989570617676, 41.256225407123566, 38.70232544839382, 40.57921953499317, 37.46951960027218, 39.0333104878664, 38.036798760294914, 41.31117045879364, 40.44410638511181, 38.89079533517361, 38.21989953517914, 41.56197600066662, 43.99977698922157, 46.325206607580185, 46.6392407566309, 42.49144032597542, 37.76670545339584, 38.289990574121475, 37.510591596364975, 38.130209147930145, 36.72225929796696, 36.24179407954216, 38.096413761377335, 46.37395419180393, 40.26788704097271, 37.42976613342762, 37.93363429605961, 39.29091766476631, 40.22154472768307, 38.603002578020096, 41.222627609968185, 42.14095093309879, 41.37303113937378, 42.23133288323879, 41.42410799860954, 41.151582822203636, 41.74267150461674, 42.907548397779465, 42.00740709900856, 41.950736939907074, 41.83665946125984, 40.37880688905716, 44.13865573704243, 41.39703445136547, 44.566546976566315, 39.946492686867714, 42.91252613067627, 42.61503629386425, 42.47960016131401, 43.200657069683075, 44.65932659804821, 44.22626383602619, 44.91548605263233, 45.71739122271538, 48.22115667164326, 46.55037112534046, 52.34207734465599, 55.53838223218918, 61.27444803714752, 59.60591197013855, 66.46827533841133, 62.720304653048515, 69.22134920954704, 64.51142594218254, 78.0255375802517, 5.5449194367975, 0.17116288421675563, 0.7601649442221969, 0.05402161958045326, 0.16246835701167583, 25.98297156393528, 74.4065509736538, 66.15657806396484, 61.66354335844517, 51.39782041311264, 43.76733586192131, 15.203002262860537, 35.7352052628994, 46.877921149134636, 69.36551347374916, 11.794089283794165, 0.22575841401703656, 0.1342164573725313, 0.12907876196550205, 0.07959078153362498, 0.07282230566488579, 0.16468632471514866, 0.046420832513831556, 0.0008941811506701924, 0.06824885771493427, 0.0781321051181294, 0.07945196281070821, 0.05809821821458172, 47.881173714995384, 71.07979908585548, 51.07193470001221, 44.669175669550896, 31.62740718573332, 34.36297729611397, 49.01847928762436, 74.13690224289894, 64.21376511454582, 61.79351918399334, 2.593150665052235, 0.23482113552745432, 0.3250267216935754, 0.0431560766446637, 33.11355493962765, 75.35391613841057, 68.221615254879, 67.36703351140022, 64.89509895443916, 63.394673466682434, 60.221554934978485, 59.870871752500534, 57.180407121777534, 55.24719625711441, 53.79839859902859, 56.94529473781586, 56.29089765250683, 57.440218180418015, 54.91305358707905, 58.26886631548405, 54.44098211824894, 54.600683748722076, 49.60138700902462, 53.46546806395054, 56.82855360209942, 60.84462650120258, 56.34774260222912, 68.28880324959755, 45.18568195402622, 42.29365713894367, 51.77388243377209, 55.84448240697384, 60.00768341124058, 56.258078813552856, 54.506999775767326, 48.24222654104233, 52.62843757867813, 49.76509362459183, 48.62494960427284, 45.12871541082859, 44.87410247325897, 43.49215842783451, 45.56615933775902, 43.980553820729256, 42.25822404026985, 42.8565589338541, 45.442263185977936, 43.01358550786972, 46.866369768977165, 47.52415247261524, 42.2501190751791, 39.76260535418987, 41.60501629114151, 48.653197288513184, 45.9574319422245, 45.56544117629528, 45.90458817780018, 44.52421344816685, 46.95999674499035, 44.152866974473, 41.94392390549183, 42.117654383182526, 40.37576325237751, 41.73841193318367, 41.54199667274952, 40.28801076114178, 40.881523713469505, 40.22095575928688, 43.06794919073582, 42.74941988289356, 39.472996294498444, 41.36305667459965, 42.20636062324047, 43.14820468425751, 43.38626191020012, 41.753747910261154, 41.42916552722454, 39.00387726724148, 42.941480576992035, 39.944786578416824, 44.694565907120705, 43.1028351187706, 40.48710487782955, 38.2065736502409, 43.866863921284676, 45.33200830221176, 46.239300817251205, 47.61915497481823, 43.18964906036854, 38.17288465797901, 38.82825069129467, 38.01205828785896, 37.80044764280319, 35.977605655789375, 37.5452571362257, 39.77063052356243, 47.77020446956158, 42.501486986875534, 39.35657054185867, 41.60193845629692, 41.910580694675446, 40.01225955784321, 41.17862977087498, 44.63348038494587, 42.222201973199844, 43.17057028412819, 43.92535038292408, 43.36519204080105, 44.5014488697052, 43.81193786859512, 44.6008325368166, 43.62601764500141, 44.73311863839626, 45.87917134165764, 43.65693278610706, 45.47958858311176, 43.250187411904335, 46.205402836203575, 42.98164822161198, 45.624269619584084, 44.88872028887272, 45.588665530085564, 44.54002059996128, 48.31819586455822, 46.6466161608696, 48.29564407467842, 48.831742107868195, 50.71011431515217, 48.61336022615433, 54.12133947014809, 57.469434812664986, 64.02570560574532, 61.08690530061722, 68.06697875261307, 66.2457212805748, 72.22653195261955, 66.9862711429596, 80.81459552049637, 6.05994095094502, 0.8028829644899815, 2.5329167721793056, 0.4916611989028752, 0.13182314985897392, 27.78994370251894, 82.19611018896103, 71.96779623627663, 69.20036673545837, 55.30752941966057, 39.54677313566208, 20.608253069221973, 43.79310227930546, 54.27523501217365, 79.83647480607033, 15.411996748298407, 0.31486262334510684, 0.07900645156041719, 0.0388634796399856, 0.055436123366234824, 0.08000629517482594, 0.319085176452063, 0.16906201257370412, 0.21189920691540465, 0.20239009842043743, 0.1582589399185963, 0.15266123169567436, 0.2135510792140849, 56.418646797537804, 82.13548824191093, 58.90199974179268, 64.79590147733688, 34.177725836634636, 45.10824590921402, 59.81623448431492, 79.469004124403, 73.78260165452957, 68.71444880962372, 3.3016240736469626, 0.3065906453412026, 1.0989097016863525, 0.8928486588411033, 35.861153304576874, 77.84928783774376, 71.07786878943443, 70.27778372168541, 68.73277142643929, 67.81694456934929, 64.51272547245026, 62.564509212970734, 59.71759557723999, 57.4564129114151, 56.089523658156395, 58.49240832030773, 58.22925344109535, 60.998142063617706, 57.64254592359066, 63.236180171370506, 59.698528200387955, 57.812123224139214, 54.79399837553501, 56.16759806871414, 59.16966497898102, 62.202244251966476, 59.28075201809406, 73.19146737456322, 47.38188810646534, 44.41623844206333, 52.124683409929276, 59.05945189297199, 64.20368045568466, 59.06807363033295, 57.436410784721375, 50.56122310459614, 54.44052614271641, 53.401768282055855, 52.775368094444275, 45.98597601056099, 46.53281606733799, 47.05393150448799, 46.964925080537796, 46.19433403015137, 44.556557312607765, 44.35589388012886, 48.26736979186535, 46.87440253794193, 48.899682462215424, 47.9974664747715, 41.78415767848492, 40.15398435294628, 41.36643849313259, 50.428724214434624, 46.9639865309, 45.104305520653725, 45.92727676033974, 43.46739135682583, 48.50037328898907, 44.56031911075115, 44.49565038084984, 45.21884277462959, 44.48700964450836, 45.932695269584656, 43.537790179252625, 43.09911131858826, 44.09650839865208, 42.01761715114117, 45.15464901924133, 46.332563012838364, 43.826380893588066, 43.747926503419876, 44.60819274187088, 45.516241416335106, 46.39132685959339, 43.4282610565424, 45.489297062158585, 41.612463891506195, 46.171831637620926, 44.03892628848553, 45.820943266153336, 43.05148467421532, 42.040374130010605, 39.70618978142738, 44.26922433078289, 45.03106065094471, 47.78296038508415, 49.694295823574066, 44.198061749339104, 38.49791541695595, 38.760226741433144, 39.01083089411259, 39.99717436730862, 36.949148923158646, 37.840641885995865, 40.420342460274696, 49.876929223537445, 45.68753622472286, 41.01549692451954, 45.259937569499016, 45.486348420381546, 44.44479390978813, 43.25491815805435, 47.07796521484852, 45.24687007069588, 45.133719742298126, 45.77406518161297, 44.99506518244743, 45.88375009596348, 46.073181331157684, 47.190667167305946, 45.18581874668598, 48.02014745771885, 46.320935636758804, 44.666740000247955, 49.06968913972378, 46.95094183087349, 50.88053897023201, 44.88886088132858, 47.5945170968771, 46.8258373439312, 46.65795095264912, 48.05712327361107, 50.254545360803604, 49.013630747795105, 49.81364741921425, 51.39218911528587, 55.632818564772606, 51.68346628546715, 57.3776089400053, 61.64683945477009, 68.45920130610466, 64.96251493692398, 72.98292696475983, 68.86120453476906, 77.60829716920853, 71.11035704612732, 85.20788177847862, 7.102512381970882, 1.263819308951497, 4.453674042597413, 1.067741874139756, 0.2589031448587775, 31.522891893982887, 90.01144722104073, 76.68411836028099, 75.54033413529396, 67.15808272361755, 58.49060341715813, 28.21565765887499, 56.384802013635635, 62.03233256936073, 93.59918430447578, 22.229738160967827, 0.508578959852457, 0.2664754557190463, 0.18221419042674825, 0.27668678434565663, 0.19879854895407334], [0.04209228587569669, 0.023443946010957006, 0.01501403527072398, 0.03242569735448342, 0.028950973064638674, 0.11048091226257384, 0.06163610298244748, 33.71184803545475, 60.75893349945545, 46.87355898320675, 47.80700549483299, 22.787593826651573, 35.72127141058445, 47.332258969545364, 68.140330016613, 56.256524696946144, 59.97737243771553, 3.4958454268053174, 0.4550720419501886, 0.30897059419658035, 0.15677215094910935, 23.447800800204277, 67.80747547745705, 66.0820184648037, 64.0772308409214, 59.35492783784866, 57.606132477521896, 56.6072990745306, 57.05838046967983, 56.1275140196085, 57.84836187958717, 59.539236947894096, 61.233220249414444, 59.23567123711109, 60.87809130549431, 58.08753244578838, 59.995615258812904, 57.85889871418476, 60.26827722787857, 54.38575208187103, 56.00539617240429, 54.190419763326645, 60.204113870859146, 54.67557393014431, 56.13593436777592, 53.14007632434368, 46.72490336000919, 61.201225966215134, 54.97863046824932, 57.47404396533966, 51.63324438035488, 49.16095644235611, 48.52381803095341, 48.16787593066692, 51.459350511431694, 53.564224764704704, 51.73779956996441, 45.73322877287865, 41.87732107937336, 41.39190852642059, 40.39636954665184, 41.46632753312588, 40.602014511823654, 40.87845727801323, 40.16232490539551, 41.01028360426426, 45.73710076510906, 44.90265414118767, 39.900359362363815, 43.85639928281307, 44.57377798855305, 43.144070506095886, 43.41526575386524, 47.03183948993683, 41.81412287056446, 44.69055712223053, 42.10594341158867, 37.853040620684624, 39.991649463772774, 39.82432544231415, 39.28937874734402, 41.08460381627083, 39.969036877155304, 38.6838698387146, 38.71072679758072, 41.03457190096378, 40.27618579566479, 37.013753056526184, 39.506312906742096, 39.613254368305206, 42.14442394673824, 39.672911167144775, 39.13324132561684, 39.15584251284599, 37.69246503710747, 40.81421412527561, 39.75562132894993, 41.67463235557079, 39.13231797516346, 40.779700577259064, 42.31465861201286, 43.68435591459274, 44.1714745759964, 45.733004584908485, 45.83421975374222, 39.60362568497658, 38.128940016031265, 38.99576470255852, 38.432509526610374, 36.94196730852127, 35.913590490818024, 35.737063363194466, 41.63840509951115, 47.80556537210941, 37.91363216936588, 39.52641002833843, 39.33647342026234, 39.56888794898987, 38.677151799201965, 39.58913706243038, 40.318409129977226, 42.07185924053192, 41.95741318166256, 40.3982200473547, 40.18702358007431, 42.238461300730705, 45.92943884432316, 50.78326798975468, 51.9815868884325, 51.579644456505775, 50.04946656525135, 46.63360945880413, 44.23730604350567, 44.26600590348244, 44.50248621404171, 43.711429461836815, 42.175415083765984, 44.31475728750229, 47.27095685899258, 43.84237423539162, 44.70650486648083, 44.66202065348625, 46.559524834156036, 44.579435884952545, 46.807362735271454, 45.169631615281105, 46.633218079805374, 48.42550590634346, 52.732912972569466, 52.09670551121235, 62.99218766391277, 60.21655060350895, 70.51988393068314, 62.46450237929821, 78.69030430912971, 7.31312558054924, 0.3047884732950479, 1.7500453745014966, 0.32275138597469777, 0.1815730638918467, 15.787140168249607, 77.41772219538689, 64.01039242744446, 71.81793227791786, 49.87562209367752, 64.43315014243126, 25.378462001681328, 33.83701711893082, 46.11928425729275, 68.02366107702255, 15.020012632012367, 0.27006771764717996, 0.03937348352337722, 0.02301183238159865, 0.07820145881851204, 0.08310642413562164, 0.012049466076859972, 0.018749837836367078, 0.02109281103912508, 0.03427939671382774, 0.04127683998376597, 0.031536129463347606, 0.22083110263338313, 44.5568422973156, 71.08900979161263, 51.771917939186096, 53.09681184589863, 29.934767112135887, 33.5587390512228, 53.77007111907005, 73.96242320537567, 63.47566992044449, 66.87618345022202, 3.553442736156285, 0.38423110730946064, 0.147939242888242, 0.12221929879160598, 25.118821933865547, 71.23041540384293, 69.20539006590843, 67.74795547127724, 62.33278624713421, 60.198383778333664, 59.47053283452988, 58.64877752959728, 57.315174490213394, 58.93063500523567, 61.42349123954773, 62.67707817256451, 62.84873776137829, 64.33896079659462, 58.682401925325394, 61.818392649292946, 58.66526484489441, 60.915545895695686, 56.45404949784279, 58.526344299316406, 57.826676443219185, 61.64947651326656, 58.477824702858925, 57.81548984348774, 53.70294012129307, 47.56040632724762, 63.15087854862213, 57.37190164625645, 58.45337301492691, 55.23276083171368, 51.83112256228924, 49.41951736807823, 50.29442422091961, 55.55614247918129, 56.022233068943024, 54.69479329884052, 46.98881819844246, 43.868862614035606, 43.099229112267494, 42.26669378578663, 43.15108872950077, 43.14346253871918, 42.99582526087761, 41.67760759592056, 42.48828649520874, 47.39775985479355, 44.146175533533096, 39.65610086917877, 42.89331816136837, 45.61921589076519, 45.512570813298225, 43.12730960547924, 47.1628450602293, 43.18140350282192, 46.056279838085175, 43.71195003390312, 38.69609758257866, 41.745832934975624, 42.555554285645485, 40.86785204708576, 41.87403805553913, 42.49446116387844, 41.234786957502365, 40.90231999754906, 43.6641675978899, 45.35741753876209, 40.26717267930508, 40.838434025645256, 42.72277571260929, 43.44257868826389, 41.27747766673565, 41.51010878384113, 40.14303334057331, 39.32446226477623, 42.46255807578564, 41.338187009096146, 42.674613296985626, 40.882234275341034, 41.634700298309326, 44.83793221414089, 45.10139487683773, 45.09378768503666, 47.302400171756744, 46.90161667764187, 37.6000539958477, 39.5397587120533, 37.57823936641216, 37.6157433539629, 36.747398748993874, 35.51569104194641, 34.59711313247681, 41.96534335613251, 47.40299977362156, 40.67589394748211, 41.87636353075504, 41.96681387722492, 42.901829704642296, 42.45535746216774, 42.3824317753315, 42.52517111599445, 43.56995925307274, 44.57999065518379, 43.20481784641743, 42.739107236266136, 43.448582366108894, 47.376773580908775, 54.27255615592003, 53.639342933893204, 52.937919571995735, 51.4967443048954, 46.947594210505486, 46.57515339553356, 46.84493891894817, 48.68676468729973, 46.29304513335228, 45.969036519527435, 46.525239273905754, 49.866099804639816, 46.99232541024685, 47.46733032166958, 48.077854961156845, 48.295492082834244, 46.866438165307045, 47.534487918019295, 47.39650972187519, 48.13040994107723, 51.57227665185928, 56.4770420640707, 54.89724263548851, 65.67808493971825, 63.08735355734825, 72.44640335440636, 65.69688633084297, 82.69316911697388, 9.065535496920347, 0.6640929775312543, 1.816457617096603, 0.3375157609116286, 0.11430003389250487, 17.11003728210926, 82.05715164542198, 69.5026633143425, 78.63169625401497, 55.6838346272707, 56.763318702578545, 23.730298541486263, 39.9946741014719, 53.22260029613972, 79.06225875020027, 21.487208604812622, 0.2956100954907015, 0.11502204710268416, 0.02085166870529065, 0.08508029204676859, 0.01900455405120738, 0.06320204571238719, 0.1418152332189493, 0.12619189656106755, 0.16856159723829478, 0.1315081972279586, 0.13938959775259718, 0.4053086950443685, 53.58240678906441, 81.68041706085205, 62.0547741651535, 65.19343614578247, 33.70027765631676, 51.43073804676533, 63.6393803358078, 77.7532821893692, 70.06498754024506, 71.91497907042503, 4.476104713976383, 0.6657104438636452, 0.6159136409405619, 0.4137341195018962, 28.32922976464033, 75.52008882164955, 71.70567870140076, 70.26351928710938, 62.99933888018131, 63.18075634539127, 62.459258660674095, 62.06112362444401, 60.20586937665939, 60.778882429003716, 63.61523263156414, 65.55963009595871, 65.20304962992668, 66.63551196455956, 60.463529750704765, 64.84897702932358, 63.19394163787365, 65.12282073497772, 59.59040120244026, 61.49264372885227, 61.64979189634323, 64.1465163230896, 58.570110350847244, 59.85374607145786, 52.81799040734768, 48.591131418943405, 66.20597541332245, 60.50235986709595, 63.33732694387436, 56.813757196068764, 53.837490901350975, 53.268045857548714, 52.363929972052574, 56.80121786892414, 58.12137342989445, 58.46230633556843, 49.64718975126743, 44.63107131421566, 45.376397520303726, 43.79494518041611, 46.065068766474724, 46.304231733083725, 44.58141937851906, 43.4390676766634, 43.688174709677696, 50.37302300333977, 44.295408725738525, 41.589551120996475, 45.405921936035156, 45.89838311076164, 47.804425433278084, 43.68117928504944, 48.73140849173069, 42.65909492969513, 44.382249265909195, 43.88636827468872, 39.03043024241924, 43.90572063624859, 44.433075338602066, 44.80322867631912, 44.02832105755806, 45.76312176883221, 44.45751562714577, 43.51095221936703, 47.23550856113434, 47.10611790418625, 42.33209207653999, 44.10566210746765, 44.94680017232895, 47.686491161584854, 43.6448722332716, 43.958488404750824, 42.7607698738575, 41.78692013025284, 46.11209884285927, 43.125075325369835, 45.001969411969185, 42.20472291111946, 43.459123000502586, 43.861092031002045, 45.01325100660324, 46.54526039958, 47.371138483285904, 47.027427926659584, 40.048194229602814, 39.18917432427406, 39.65830475091934, 38.091827407479286, 38.33817578852177, 35.61442494392395, 35.95632679760456, 42.50422663986683, 52.10497386753559, 43.13057363033295, 44.860221818089485, 44.494362249970436, 44.68513481318951, 43.377932757139206, 44.78258438408375, 44.2209555208683, 47.04249031841755, 48.11164654791355, 45.28278574347496, 45.5459064245224, 45.75755126774311, 51.005852445960045, 55.41136644780636, 56.796171739697456, 54.851462692022324, 55.48551946878433, 51.987111791968346, 48.09646636247635, 49.01417791843414, 51.06852248311043, 47.91138209402561, 47.06465072929859, 50.483965650200844, 53.13656531274319, 48.38717736303806, 50.394047275185585, 51.23543992638588, 50.99077865481377, 49.20067571103573, 50.87554603815079, 50.18581084907055, 51.65208376944065, 55.035452619194984, 59.25233714282513, 56.86880484223366, 69.57297474145889, 65.72731509804726, 77.72710159420967, 68.69443148374557, 89.65871214866638, 10.230983309447765, 1.0200357902795076, 4.485121630132198, 1.588322608731687, 0.2260857159853913, 18.728058859705925, 90.50643905997276, 73.53212669491768, 85.07934227585793, 66.00571855902672, 85.71401461958885, 36.373187229037285, 53.30317497253418, 61.323431208729744, 90.69372341036797, 30.434229411184788, 0.5306157586164773, 0.23322811553953215, 0.13355146336834878, 0.15790992270922288, 0.1601136857061647], [0.054380744841182604, 0.06262329668970779, 0.040197590278694406, 0.0816390645923093, 0.0656111461285036, 0.04744930818560533, 0.2529278170550242, 25.10162975639105, 65.57957902550697, 39.29071247577667, 23.262266255915165, 21.751946099102497, 37.884700521826744, 46.99465088546276, 68.43086242675781, 54.60398577153683, 60.6065084785223, 5.077548315748572, 0.17974646034417674, 0.24589884735178202, 0.2808509749593213, 15.019032284617424, 68.99494215846062, 67.41688683629036, 64.10925552248955, 62.273186445236206, 60.340313762426376, 59.340993985533714, 56.91767781972885, 60.97028575837612, 62.13043570518494, 61.76467873156071, 61.84340290725231, 61.98412835597992, 62.037401497364044, 63.637814819812775, 61.0719683021307, 57.98725202679634, 56.164900213479996, 58.717056065797806, 58.3832173794508, 58.59074704349041, 54.87049587070942, 53.162468522787094, 56.933055594563484, 58.541410490870476, 59.612451419234276, 53.54738786816597, 55.18270991742611, 55.14882333576679, 49.42196823656559, 48.353906348347664, 57.471764087677, 63.421180844306946, 56.42041750252247, 52.69523799419403, 55.58912850916386, 49.5710114389658, 42.296051010489464, 45.21063521504402, 41.68498679995537, 42.889050990343094, 40.26557296514511, 40.98931632936001, 40.73585093021393, 41.29430316388607, 44.24091964960098, 47.2887247055769, 40.318587720394135, 44.293444231152534, 41.86724402010441, 48.851387053728104, 42.92620159685612, 46.78897172212601, 44.665702655911446, 45.18105000257492, 42.14800715446472, 38.38509947061539, 36.67638435959816, 40.078216418623924, 41.33552335202694, 38.91553960740566, 39.57564018666744, 39.074329286813736, 39.94747683405876, 39.29567500948906, 40.714024901390076, 38.64890031516552, 38.85986119508743, 40.64416565001011, 39.815490916371346, 41.71989552676678, 38.98619681596756, 40.45047864317894, 39.64035451412201, 40.54857797920704, 40.73157615959644, 40.562131851911545, 40.73160655796528, 41.33998431265354, 43.04536700248718, 42.798995822668076, 44.83521156013012, 41.35273642838001, 39.21615667641163, 39.18593689799309, 38.21453042328358, 36.48609437048435, 37.70651288330555, 37.02899403870106, 37.30958618223667, 35.12120760977268, 44.60233725607395, 44.12699416279793, 39.37776580452919, 40.67796103656292, 37.65327014029026, 39.138633236289024, 39.41485561430454, 39.87781137228012, 39.620739966630936, 39.77165266871452, 42.2993416339159, 43.28778639435768, 44.40359652042389, 45.25267235934734, 55.102640613913536, 54.29681025445461, 56.74683898687363, 54.119504168629646, 55.768459886312485, 54.43153962492943, 49.90466773509979, 50.38200192153454, 50.70133298635483, 49.915200769901276, 49.45355974137783, 49.274737536907196, 49.858902990818024, 52.518300488591194, 50.868109837174416, 51.61582611501217, 53.867923468351364, 50.84552764892578, 52.54298776388168, 47.81775511801243, 48.60151246190071, 46.29868023097515, 49.60671432316303, 48.73723737895489, 57.08644576370716, 60.33864185214043, 67.53262862563133, 64.13358941674232, 77.66724720597267, 11.441245917230844, 0.6663661461789161, 0.9925710421521217, 0.22415754210669547, 0.07463962494512089, 9.979410208761692, 74.92187172174454, 62.404359206557274, 74.92202371358871, 48.94170440733433, 66.3458839058876, 37.72034794092178, 32.904531955718994, 45.592757910490036, 72.46550112962723, 23.050298430025578, 0.36869409726932645, 0.14804424194153398, 0.04483419870666694, 0.05231890645518433, 0.03715810220455751, 0.03843425110972021, 0.04562575115414802, 0.026727272270363756, 0.06060623207304161, 0.041842304563033395, 0.19586832728236914, 0.21981827885610983, 34.830090031027794, 77.36341550946236, 48.26078474521637, 33.888929933309555, 20.80076403915882, 42.152118533849716, 52.84221410751343, 74.31503668427467, 60.615962371230125, 67.14384868741035, 5.2120639476925135, 0.26401820476166904, 0.17996658134507015, 0.2112363651394844, 14.814997483044863, 71.97090446949005, 69.28601413965225, 66.98243334889412, 65.01816675066948, 61.77670128643513, 59.59811098873615, 58.36368642747402, 62.13838867843151, 64.38598707318306, 64.26345124840736, 64.0505638718605, 63.839804381132126, 63.18390637636185, 64.15960282087326, 62.74192929267883, 59.44255493581295, 59.80975203216076, 61.089834943413734, 60.51859259605408, 61.3915691524744, 58.07539589703083, 53.68210203945637, 57.921287566423416, 58.88954780995846, 62.379170358181, 57.254468947649, 57.344090938568115, 56.160587444901466, 52.55084194242954, 51.13619305193424, 59.02287505567074, 64.67244610190392, 58.619477301836014, 56.58904105424881, 57.84754492342472, 53.3065339922905, 43.50125893950462, 46.34115435183048, 43.76284450292587, 44.334212243556976, 43.11574302613735, 43.51858600974083, 42.73593060672283, 42.811987325549126, 45.470621064305305, 49.062089547514915, 39.44857880473137, 41.84292532503605, 41.76865451037884, 48.983144983649254, 44.168168753385544, 46.56479895114899, 44.4412487000227, 45.81371985375881, 42.67782412469387, 39.60749767720699, 38.03837947547436, 41.507486924529076, 45.41722632944584, 42.69524618983269, 42.049421444535255, 40.96604637801647, 43.19229371845722, 42.595790326595306, 43.410827592015266, 40.63449136912823, 39.8580676317215, 41.29876412451267, 41.462542936205864, 43.70011366903782, 41.06069929897785, 42.56813921034336, 42.7912138402462, 42.200387343764305, 42.7669445425272, 42.51967281103134, 41.355920657515526, 44.30658392608166, 43.21889229118824, 42.96758137643337, 45.563602074980736, 40.80524280667305, 38.77527013421059, 40.14547660946846, 37.92649067938328, 38.46686348319054, 37.55119241774082, 36.07138082385063, 36.6488092392683, 35.87745442986488, 45.54846748709679, 47.63959027826786, 40.86482360959053, 42.071536257863045, 38.95258001983166, 41.33193254470825, 40.925643146038055, 41.793778762221336, 42.64965243637562, 42.45851509273052, 43.12271565198898, 44.24960978329182, 45.777929574251175, 47.92006462812424, 56.217303201556206, 57.673069685697556, 57.86122418940067, 57.8126285970211, 57.69852451980114, 55.86153209209442, 52.95222580432892, 53.38556595146656, 52.62914054095745, 53.07801425457001, 52.338539734482765, 53.678670823574066, 52.503705471754074, 54.030208960175514, 53.2834692299366, 55.12241095304489, 55.983345955610275, 53.467899933457375, 55.788173228502274, 49.892956763505936, 52.11127392947674, 48.19703936576843, 52.35052429139614, 51.727274134755135, 59.96404655277729, 63.57985273003578, 72.6275472342968, 66.7081792652607, 81.45359203219414, 13.009493965655565, 0.7965609943494201, 2.092032842338085, 0.6640368711668998, 0.07626702863490209, 10.499633643776178, 80.74320495128632, 67.67766684293747, 82.18113899230957, 55.38857527077198, 66.74645841121674, 30.98914783447981, 41.674453765153885, 51.911701038479805, 82.55099594593048, 29.861858524382114, 0.40322474436834455, 0.07457908053766005, 0.07918475996120833, 0.021902317894273438, 0.08520431234501302, 0.10108121859957464, 0.1144838787149638, 0.09908305277349427, 0.12654777121497318, 0.21068383619422093, 0.40833834966178983, 0.4771014192374423, 46.25632010400295, 86.55427873134613, 54.85069513320923, 39.511457830667496, 32.24530532956123, 53.501987904310226, 63.74507166445255, 80.64924359321594, 67.90268316864967, 72.16104626655579, 6.398910786956549, 0.47298775403760374, 1.2073454330675304, 0.39488953538239, 18.4188162535429, 76.1282841861248, 70.47900572419167, 69.18945372104645, 67.56126388907433, 66.64564222097397, 62.162908762693405, 62.2117855399847, 66.5930226445198, 67.46899724006653, 66.10510602593422, 67.0412465929985, 67.12529808282852, 67.05457627773285, 68.80501314997673, 66.73960357904434, 60.02883307635784, 63.89754608273506, 64.90278974175453, 63.922031968832016, 62.77727119624615, 58.924935311079025, 56.6841309517622, 58.03674057126045, 61.22607283294201, 65.12449264526367, 57.385801300406456, 61.33139558136463, 58.18529739975929, 53.82154315710068, 54.060196951031685, 62.43121616542339, 65.15258833765984, 62.385614812374115, 57.85597287118435, 59.658276960253716, 56.1443205177784, 46.181486919522285, 49.16817985475063, 44.78088587522507, 47.13388681411743, 45.92675618827343, 45.05605190992355, 44.67224210500717, 46.32191978394985, 48.93195413053036, 48.13733696937561, 39.78336364030838, 43.78045655786991, 41.8451140075922, 50.35333625972271, 44.258269518613815, 46.79606594145298, 46.3256473839283, 46.74544505774975, 42.48573683202267, 39.16694551706314, 40.56733377277851, 42.9184690117836, 46.339281052351, 45.04951626062393, 45.11471316218376, 43.0318321287632, 45.34465402364731, 43.54453481733799, 46.97498694062233, 42.72303409874439, 43.2523038983345, 45.45902028679848, 43.42530481517315, 47.58219055831432, 43.11236880719662, 45.62817960977554, 44.27855663001537, 44.79422315955162, 44.93685990571976, 44.17138338088989, 44.66181546449661, 42.77511790394783, 46.99985280632973, 46.006715297698975, 45.516685992479324, 42.968706116080284, 39.74293000996113, 39.89804528653622, 39.00546558201313, 37.93985076248646, 40.278002098202705, 36.873772367835045, 36.999089643359184, 36.770440712571144, 46.95709750056267, 49.5037854462862, 42.97178395092487, 44.05038647353649, 41.34789168834686, 42.132181003689766, 43.85478436946869, 44.064187332987785, 44.527025297284126, 44.874756038188934, 47.108523175120354, 47.74918019771576, 48.474295288324356, 50.01982435584068, 59.963176399469376, 60.310907140374184, 61.31875365972519, 59.87576588988304, 60.12233845889568, 58.021898567676544, 55.118375569581985, 56.8588075786829, 55.24080879986286, 53.79423402249813, 54.020758867263794, 54.81481745839119, 55.06355971097946, 55.90060539543629, 55.447190925478935, 57.19447396695614, 59.417381286621094, 57.222090885043144, 58.53800967335701, 52.89905525743961, 54.993673861026764, 50.38925193250179, 55.57657778263092, 54.31546725332737, 64.13635566830635, 67.01451122760773, 76.5367242693901, 69.55985024571419, 86.33025035262108, 14.847175106406212, 1.7086924309842288, 5.773181738331914, 1.1429241648875177, 0.18705688213231042, 11.959167625755072, 90.62856450676918, 72.4923200905323, 89.6761304140091, 63.20782609283924, 84.8386099934578, 49.81196030974388, 51.231089159846306, 60.01423425972462, 94.56805631518364, 39.6954857558012, 0.554250015411526, 0.22286139603238553, 0.23383789375657216, 0.13109308434650302, 0.16860277159139514], [0.13195945270126686, 0.032900549413170666, 0.0356666339939693, 0.09582669430528767, 0.050839075120165944, 0.08172624467988499, 0.15519551758188754, 22.26739414036274, 64.74121481180191, 34.28500548005104, 37.0280858874321, 26.974078081548214, 37.36911378800869, 49.07234899699688, 68.3324933052063, 57.61533938348293, 62.873345240950584, 5.432210834696889, 0.2239949078648351, 0.14212821173714474, 0.2923796750837937, 6.889082584530115, 58.45054216682911, 70.56412115693092, 61.42114296555519, 63.15491773188114, 58.72495964169502, 59.20245721936226, 58.26378598809242, 60.152550637722015, 61.967299059033394, 60.189484655857086, 58.34486223757267, 59.66831982135773, 52.38862484693527, 47.4491710960865, 46.568511351943016, 50.27145065367222, 57.72005416452885, 57.0803888887167, 58.8073506206274, 58.36028181016445, 58.29863391816616, 58.04210588335991, 57.59431891143322, 55.2593632042408, 54.64015983045101, 54.45980250835419, 54.965152591466904, 47.8121580183506, 48.40799264609814, 54.4951444119215, 53.6425955593586, 56.41741566359997, 56.49359777569771, 57.83794283866882, 53.41168574988842, 51.02297432720661, 43.49623180925846, 42.0923363417387, 42.80374936759472, 45.8085635304451, 40.43309077620506, 41.480113193392754, 40.832654535770416, 40.51011644303799, 40.621309876441956, 53.470601588487625, 41.88900165259838, 38.373582288622856, 40.747622698545456, 48.19731295108795, 46.377643793821335, 44.83281008899212, 44.2562860250473, 45.7990450412035, 45.990448370575905, 38.80165211856365, 39.512339383363724, 37.44334660470486, 40.822980254888535, 42.587685361504555, 41.935704946517944, 38.60967881977558, 38.91509123146534, 42.75146797299385, 39.79350909590721, 37.93102003633976, 36.53915852308273, 38.754515647888184, 40.3313360363245, 41.04658305644989, 41.147380247712135, 41.47504426538944, 40.341261103749275, 40.187259167432785, 38.18279072642326, 39.967262372374535, 41.100593358278275, 42.99869790673256, 42.101387456059456, 45.77720761299133, 38.42413857579231, 36.868000477552414, 37.52148561179638, 36.26416727900505, 37.41501912474632, 37.69499570131302, 36.5457321703434, 37.571973502635956, 36.00135438144207, 35.67876309156418, 44.30082343518734, 39.27489772439003, 38.07752877473831, 39.932988211512566, 37.81218521296978, 39.79205757379532, 40.23216515779495, 38.255587220191956, 41.66770912706852, 43.398778438568115, 42.09729887545109, 43.72461095452309, 44.316862374544144, 52.781816348433495, 52.74388678371906, 56.27564527094364, 54.196457639336586, 52.002417370676994, 58.60336236655712, 56.746219620108604, 56.940301805734634, 54.888191521167755, 56.28568433225155, 55.79602360725403, 57.60629586875439, 53.746037408709526, 55.16605921089649, 57.456253319978714, 56.60783104598522, 57.06070214509964, 60.58423787355423, 59.254392832517624, 61.50413431227207, 58.6107187718153, 58.43023605644703, 53.42369310557842, 50.972760021686554, 45.95566123723984, 54.83794681727886, 59.58115629851818, 68.84103521704674, 59.211998507380486, 78.25667917728424, 14.242937229573727, 0.6952876411378384, 1.3600052101537585, 0.37170706840697676, 0.05020416036131792, 6.536817736923695, 74.26810160279274, 63.141363859176636, 77.16299146413803, 55.64758837223053, 55.060671865940094, 29.367611445486546, 30.794830061495304, 44.4952742010355, 70.97015216946602, 28.322209641337395, 0.4544907028321177, 0.04014603327959776, 0.05593975220108405, 0.05967743054497987, 0.09219282015692443, 0.019262034766143188, 0.04128283653699327, 0.0749069316952955, 0.03815515163296368, 0.09766833376488648, 0.07578533026389778, 0.119702230731491, 29.082349352538586, 75.86495831608772, 40.954232811927795, 41.29839934408665, 21.872701719403267, 40.02411112189293, 56.18099994957447, 72.89781153202057, 63.88802379369736, 68.77741143107414, 6.342089585959911, 0.3000604879343882, 0.4759172780904919, 0.2435636054724455, 8.267798703163862, 60.80886662006378, 72.44246676564217, 63.366042003035545, 65.09879842400551, 60.52600979804993, 60.356717482209206, 59.91449721157551, 62.81283348798752, 65.03843486309052, 63.45722571015358, 59.66504819691181, 61.0210320353508, 56.842681244015694, 51.161218509078026, 50.766552686691284, 53.917575404047966, 59.76358450949192, 60.053885132074356, 61.312396600842476, 59.91390444338322, 57.552939131855965, 61.21548280119896, 59.92550902068615, 57.980180606245995, 54.424179419875145, 57.93930999934673, 56.9998712092638, 49.04417730867863, 50.32850839197636, 56.08950085937977, 55.78674450516701, 62.86043733358383, 58.76566685736179, 57.7005498111248, 55.62153697013855, 55.32766833901405, 44.75209482014179, 43.05322118103504, 44.850676730275154, 45.397748574614525, 42.001262828707695, 43.67480702698231, 41.85435131192207, 43.11489187180996, 41.53837166726589, 55.58501712977886, 43.91471855342388, 38.429834470152855, 42.5454468280077, 47.94999562203884, 46.51787906885147, 44.965054392814636, 45.15996113419533, 45.598940178751945, 45.16407251358032, 38.47923941910267, 38.73322919011116, 38.086895272135735, 42.59001083672047, 45.09664513170719, 43.41827519237995, 41.44907645881176, 40.96007689833641, 46.97886273264885, 44.381778091192245, 41.43983155488968, 39.04242619872093, 40.813549160957336, 43.47565971314907, 43.007236048579216, 43.88095736503601, 43.25411260128021, 42.515550032258034, 43.28674525022507, 39.72062900662422, 41.04866914451122, 40.987203642725945, 43.544341027736664, 42.99431674182415, 44.363212287425995, 39.489221423864365, 36.6228224337101, 37.96069264411926, 35.463052466511726, 37.03267224133015, 36.935454457998276, 36.86983197927475, 37.94170506298542, 35.97389705479145, 34.31302137672901, 47.79600888490677, 42.39706479012966, 41.25730074942112, 41.71747885644436, 40.7079566270113, 40.10090120136738, 41.71187035739422, 39.285518154501915, 42.073876932263374, 44.17126938700676, 44.44806553423405, 45.42106792330742, 47.0801804959774, 56.25946953892708, 55.2815730124712, 56.129938289523125, 56.9939549267292, 54.93820823729038, 61.75140604376793, 60.05414351820946, 57.94440932571888, 58.27278770506382, 58.50774049758911, 58.65441642701626, 58.28099526464939, 55.69283254444599, 57.09167428314686, 58.58372502028942, 59.671515449881554, 57.52081945538521, 62.84350544214249, 61.05777986347675, 62.2466828674078, 59.60710510611534, 60.529858991503716, 56.67284935712814, 54.41199727356434, 49.18141454458237, 57.925695329904556, 62.8180468082428, 72.38454267382622, 63.12199629843235, 81.32925510406494, 17.043652944266796, 0.7728939049411565, 1.0770419938489795, 0.5092766974121332, 0.07505192508688197, 6.665420886129141, 82.0913878083229, 67.18087390065193, 84.13499414920807, 59.07267898321152, 65.97283512353897, 45.98903484642506, 40.13421021401882, 52.68630467355251, 81.34082168340683, 36.47199332714081, 0.3562330815475434, 0.17749641701811925, 0.08706514374352992, 0.08149193381541409, 0.019217060616938397, 0.2243539589107968, 0.10416967357741669, 0.11776815677876584, 0.2260595775442198, 0.2044329044292681, 0.20908247446641326, 0.26323604048229754, 41.29291623830795, 83.91483396291733, 50.78789234161377, 53.545411974191666, 38.03085967898369, 53.09117294847965, 62.81768582761288, 78.94837886095047, 70.0609065592289, 74.51463997364044, 7.649370487779379, 0.41427947930060327, 0.859150345204398, 0.5670805613044649, 10.414023287594318, 66.55256241559982, 73.94986867904663, 67.05645337700844, 65.77690243721008, 64.1898187994957, 62.55276784300804, 62.84594491124153, 67.06485092639923, 69.28419023752213, 64.76709142327309, 63.24782274663448, 64.51119795441628, 58.95728677511215, 52.95963540673256, 53.09622287750244, 54.57845114171505, 62.470190674066544, 59.634368643164635, 62.52852514386177, 61.98541268706322, 58.452784046530724, 61.38124890625477, 63.389927521348, 60.228637754917145, 58.39381121098995, 58.930912390351295, 61.33470140397549, 51.27743907272816, 53.220635801553726, 57.97192744910717, 58.723306730389595, 59.708605259656906, 56.120412200689316, 61.58091679215431, 57.7206127345562, 58.010597974061966, 47.375648841261864, 44.80030283331871, 47.28573426604271, 50.35224951803684, 42.6793060451746, 45.53260713815689, 44.234224408864975, 44.08307991921902, 44.902308359742165, 58.56156840920448, 44.928762540221214, 37.59481027722359, 42.83231623470783, 48.17576430737972, 48.77971149981022, 45.35237520933151, 44.009048491716385, 46.233323737978935, 46.826357915997505, 39.260728284716606, 39.882952496409416, 40.38695365190506, 46.338103115558624, 48.001099079847336, 47.63023518025875, 43.1253869086504, 42.96905569732189, 49.819354712963104, 46.84189908206463, 42.29688696563244, 41.73211567103863, 43.59663002192974, 46.09143175184727, 47.48911835253239, 46.713868752121925, 46.513209119439125, 46.183819994330406, 46.05282202363014, 43.088202103972435, 42.99416474997997, 43.18393036723137, 43.81863310933113, 43.2846287637949, 45.94778425991535, 39.80402313172817, 36.86186760663986, 37.51088798046112, 36.85597412288189, 37.57421538233757, 37.923443242907524, 36.7170649766922, 39.412070363759995, 36.751396134495735, 34.67077977955341, 49.84571389853954, 43.47044259309769, 43.981222584843636, 45.77791057527065, 41.663031578063965, 44.023841097950935, 43.79194714128971, 40.907685309648514, 45.1990420371294, 48.10272462666035, 46.35066144168377, 49.21757720410824, 49.273407608270645, 58.29183228313923, 59.444565027952194, 60.2680454403162, 58.342551961541176, 55.493890419602394, 64.7751621901989, 62.658212184906006, 61.89385659992695, 60.17718091607094, 60.469035655260086, 60.6655915081501, 63.21086212992668, 60.32880038022995, 59.210626780986786, 60.33162362873554, 61.71521678566933, 62.08363741636276, 67.75424793362617, 64.42423582077026, 65.9668618440628, 63.89367029070854, 63.37720200419426, 60.14013670384884, 56.86451867222786, 51.39406621456146, 61.15139544010162, 65.59824362397194, 76.10277235507965, 65.31686872243881, 85.39594128727913, 18.8187200948596, 1.310302927158773, 4.300190778449178, 0.9912352357059717, 0.20363269111840054, 8.310968186706305, 90.47933891415596, 73.80699634552002, 90.76531156897545, 69.34181034564972, 72.13244140148163, 45.84414482116699, 48.523464649915695, 62.17591166496277, 90.92841401696205, 45.692855939269066, 0.6777452887035906, 0.2927619108231738, 0.12022037597489543, 0.15651058842195198, 0.18798915320076048], [0.05022092547733337, 0.04367442226794083, 0.08367671267478727, 0.025732918693393003, 0.04491841762501281, 0.15502877184189856, 0.21369529335061088, 31.323201209306717, 68.21327850222588, 47.59421691298485, 37.564005330204964, 27.305691987276077, 50.49683935940266, 41.9187730550766, 74.90763768553734, 55.42085833847523, 69.45564463734627, 7.279891613870859, 0.07299523349502124, 0.4758701368700713, 0.04394787400087807, 0.5085729039274156, 41.503721326589584, 70.49779191613197, 64.96677070856094, 67.13613510131836, 63.064220398664474, 61.22845150530338, 62.251945585012436, 60.86644493043423, 59.345238357782364, 61.40694312751293, 59.27365019917488, 58.27202394604683, 53.245459869503975, 50.276018008589745, 50.724773928523064, 51.27689570188522, 47.817675322294235, 53.632279112935066, 59.95535261929035, 58.466657102108, 59.348506182432175, 55.88667914271355, 56.97892673313618, 58.912563174963, 51.1950708925724, 48.01511272788048, 46.07729651033878, 45.11091336607933, 51.565171033144, 53.771222457289696, 55.17427437007427, 33.58762130141258, 36.49639941751957, 50.66148452460766, 54.63894009590149, 50.05051910877228, 46.11791253089905, 44.261715933680534, 41.3728753477335, 41.38163007795811, 41.73039436340332, 43.78041855990887, 40.72085693478584, 42.61352017521858, 39.90542829036713, 45.926330611109734, 51.38207785785198, 42.3441032320261, 41.527903228998184, 41.496809497475624, 47.7902065962553, 45.88546380400658, 44.89038459956646, 45.86179107427597, 44.23186093568802, 38.54734696447849, 36.80894024670124, 37.35573090612888, 36.92177899181843, 44.43836845457554, 38.6349892616272, 37.29051120579243, 39.851634576916695, 42.55577087402344, 43.59341159462929, 38.29747997224331, 39.06987592577934, 41.53163082897663, 40.95381863415241, 39.57177199423313, 40.41295185685158, 41.583532243967056, 39.289333149790764, 40.43081469833851, 37.08880662918091, 39.23889085650444, 45.82633137702942, 43.889149725437164, 41.576335430145264, 41.03366754949093, 38.62078942358494, 37.85758897662163, 37.81650558114052, 39.01840768754482, 36.588278487324715, 37.674043625593185, 37.77352228760719, 35.71163892745972, 38.6180117726326, 43.072869926691055, 43.66184212267399, 36.791236996650696, 39.77307379245758, 37.929773703217506, 40.190055817365646, 40.59465050697327, 41.497968435287476, 40.69845713675022, 40.96822366118431, 40.876678973436356, 44.68028247356415, 40.98304286599159, 46.857178062200546, 50.09138211607933, 56.482156589627266, 54.06795613467693, 48.060919269919395, 50.04681050777435, 49.53497037291527, 53.64832945168018, 56.752436086535454, 55.72413146495819, 57.32924893498421, 57.50313900411129, 58.35403874516487, 58.64126913249493, 58.839295506477356, 58.25981140136719, 59.441521391272545, 60.67280352115631, 63.18209767341614, 59.41602475941181, 61.447893530130386, 60.734470412135124, 61.00697658956051, 59.42405752837658, 62.064885422587395, 51.68354608118534, 55.61794616281986, 59.49416756629944, 67.85362020134926, 63.82800221443176, 74.80043023824692, 19.439475685358047, 0.14115170866716653, 1.2224132870323956, 0.508597424486652, 0.06723975209752098, 4.228278212249279, 71.53202801942825, 65.41319355368614, 74.1991277039051, 56.78130313754082, 53.37341420352459, 10.926325097680092, 19.467069804668427, 41.65276072919369, 66.73144161701202, 31.222516112029552, 0.4699760000221431, 0.04269876895705238, 0.03035952297068434, 0.046606473333667964, 0.012064592901879223, 0.031051952319103293, 0.07060562929837033, 0.0383991512353532, 0.0698261070647277, 0.03313639281259384, 0.264461207552813, 0.2792270964710042, 37.421315386891365, 76.68767496943474, 52.89846628904343, 41.97713032364845, 27.03284192830324, 52.936616241931915, 49.57788906991482, 79.88380506634712, 61.326733231544495, 76.25546336174011, 7.982018887996674, 0.06369653870933689, 0.3301296994322911, 0.5326902098022401, 0.7772612955886871, 41.91400811076164, 75.08478417992592, 65.56092962622643, 66.84456914663315, 64.94912445545197, 64.55176457762718, 62.84888215363026, 62.92059950530529, 63.13012786209583, 62.846051305532455, 61.81413687765598, 59.11199927330017, 55.332266092300415, 50.40223963558674, 52.42164507508278, 50.846910774707794, 48.832608461380005, 55.105110481381416, 61.1769300699234, 60.79896815121174, 59.98002089560032, 57.94662460684776, 58.170611187815666, 58.25458288192749, 53.31577509641647, 50.85218109190464, 49.14861470460892, 49.83849808573723, 53.83849784731865, 56.486237570643425, 55.64373157918453, 36.779127046465874, 41.28349654376507, 54.70461197197437, 55.967379212379456, 51.25644899904728, 47.87740431725979, 46.82560935616493, 42.3356106877327, 44.594638869166374, 42.65862375497818, 44.77833241224289, 42.64484949409962, 43.246980383992195, 40.91370418667793, 47.82432496547699, 54.034669920802116, 41.141908541321754, 41.83306485414505, 41.352918818593025, 48.4804243594408, 46.46523669362068, 44.54693242907524, 45.76338395476341, 45.57907484471798, 38.947389498353004, 37.82282844185829, 37.87786468863487, 40.25791257619858, 45.05999989807606, 43.12765918672085, 40.24710975587368, 42.39426054060459, 45.10209023952484, 45.41088066995144, 42.05874614417553, 43.886098489165306, 44.10934790968895, 42.23873108625412, 42.52317242324352, 42.242766469717026, 45.05490817129612, 39.805885031819344, 40.610890835523605, 38.26135911047459, 38.76072831451893, 46.803213357925415, 46.50601230561733, 42.51101687550545, 40.93876764178276, 37.67763063311577, 37.370189130306244, 38.029354959726334, 38.421961292624474, 35.87607890367508, 38.33973370492458, 36.98500379920006, 34.601999670267105, 39.96108390390873, 42.61457271873951, 45.607884898781776, 38.71608830988407, 40.89393384754658, 40.48507198691368, 42.113307416439056, 40.62964662909508, 42.92062729597092, 40.51933474838734, 42.69908018410206, 43.53250466287136, 44.609492272138596, 43.531102538108826, 49.83194723725319, 53.86977396905422, 57.47514970600605, 54.655693396925926, 48.93475838005543, 51.62210337817669, 52.53070682287216, 56.188686937093735, 60.060641169548035, 57.37806871533394, 58.72530162334442, 57.13413320481777, 61.29590928554535, 61.81643195450306, 62.54813589155674, 61.434001475572586, 62.13450148701668, 63.2068457454443, 62.02080398797989, 61.634763702750206, 64.5597517490387, 62.13346414268017, 65.78735947608948, 62.38770470023155, 64.45006683468819, 55.888890624046326, 58.26105773448944, 62.31163278222084, 72.9881402850151, 65.94470143318176, 79.17981684207916, 21.447056159377098, 0.23077494639437646, 1.7539560771547258, 0.37126341252587736, 0.11938833937165327, 4.737048111855984, 76.17857828736305, 69.8981460928917, 80.83539560437202, 65.46712785959244, 59.564353600144386, 21.74871437251568, 29.488159976899624, 47.7450156211853, 76.57330110669136, 39.07157063484192, 0.35266254970338196, 0.10831883570062928, 0.058681442387751304, 0.05245374355581589, 0.08577533561037853, 0.19400598190259188, 0.23099937185179442, 0.19334858749061823, 0.1691910275258124, 0.1614441635319963, 0.4240541876060888, 0.4832900402834639, 51.28674477338791, 87.16630429029465, 62.40237571299076, 51.848871409893036, 37.66474172472954, 68.73461052775383, 58.57087790966034, 86.92548841238022, 66.51402488350868, 81.95901051163673, 9.660841953009367, 0.3347685083281249, 1.6860156040638685, 0.6855764903593808, 0.8516404044348747, 46.74040652811527, 75.83511471748352, 68.88918623328209, 70.57131037116051, 69.35517802834511, 67.58292272686958, 65.75915738940239, 65.71137115359306, 65.35571023821831, 64.43562760949135, 64.77326229214668, 61.25216603279114, 56.100869849324226, 49.004849418997765, 48.85390631854534, 50.24153485894203, 48.48148450255394, 57.6541543006897, 62.83190466463566, 61.69160485267639, 64.34221342206001, 60.87974041700363, 61.78142823278904, 61.655069813132286, 54.36579555273056, 53.91436457633972, 52.82131142914295, 53.317568600177765, 56.08582265675068, 57.821763306856155, 59.07730333507061, 39.87661823630333, 42.61569745838642, 53.68402473628521, 57.64028124511242, 54.82710599899292, 51.855388060212135, 48.796369805932045, 43.89648713171482, 44.87813025712967, 45.45374996960163, 46.22739985585213, 43.695135936141014, 45.85883863270283, 42.15015783905983, 48.838843926787376, 54.76743400096893, 42.037543281912804, 41.41467310488224, 40.58767408132553, 48.655933141708374, 47.57228069007397, 45.67672200500965, 46.57696209847927, 46.33015014231205, 40.130406618118286, 39.008805602788925, 38.21960315108299, 40.71989178657532, 46.309954226017, 46.03790782392025, 42.22391568124294, 43.48102502524853, 47.82146371901035, 49.34837758541107, 42.085633501410484, 46.41404204070568, 47.31079012155533, 46.38185016810894, 44.087176099419594, 46.52477949857712, 47.84575201570988, 41.487556993961334, 43.37103992700577, 37.77740187942982, 38.3675330132246, 48.72120603919029, 46.1786712706089, 43.31599608063698, 43.24335917830467, 37.997843250632286, 37.999625355005264, 37.1546570956707, 38.76760594546795, 37.20234453678131, 38.85669596493244, 36.77933983504772, 35.75843721628189, 39.62493114173412, 44.15506325662136, 47.755617052316666, 40.42484901845455, 45.715802907943726, 42.680863961577415, 45.94678871333599, 45.19049629569054, 45.42137570679188, 42.94099800288677, 44.22810673713684, 45.737754330039024, 47.358241975307465, 44.89106476306915, 52.94359266757965, 53.710467517375946, 60.95330446958542, 57.7941007912159, 50.607896000146866, 54.468694031238556, 54.099471643567085, 58.160826712846756, 62.70752973854542, 59.713362604379654, 62.31771245598793, 60.959216952323914, 61.10150411725044, 63.67780767381191, 64.43791508674622, 64.13770079612732, 65.34645393490791, 65.85442587733269, 65.73603183031082, 63.24656881392002, 67.50252664089203, 66.20993480086327, 66.16667792201042, 64.32151213288307, 67.96567618846893, 58.42824876308441, 60.602875873446465, 66.45177662372589, 76.10703572630882, 70.65334796905518, 82.4074624478817, 22.441014423966408, 0.6926391238812357, 4.8349598329514265, 2.2620300203561783, 0.3173416934441775, 5.662128897383809, 83.75091075897217, 76.14204704761505, 84.62896004319191, 75.89927047491074, 66.39739394187927, 16.341311931610107, 36.55947983264923, 59.713518396019936, 84.85707700252533, 52.19217158854008, 0.779676481615752, 0.14495756069663912, 0.212992271699477, 0.1344617223367095, 0.19491466751787812], [0.07598959899041802, 0.050873343789135106, 0.029665659421880264, 0.02632117462781025, 0.04168496925558429, 0.3014676593011245, 0.03869121603202075, 38.20997826755047, 65.78350648283958, 44.5835130661726, 47.9220063239336, 23.888753838837147, 38.322627022862434, 48.415854424238205, 69.2825335264206, 58.939667120575905, 67.61737167835236, 9.2898222617805, 0.1494240725878626, 0.08292722515761852, 1.0384695511311293, 0.5111446534283459, 13.631210904568434, 70.41322365403175, 67.24797070026398, 66.17616221308708, 57.68735311925411, 62.85275034606457, 59.28949914872646, 64.83715206384659, 60.971668884158134, 60.732764303684235, 58.62072363495827, 58.5145079344511, 55.89359477162361, 62.05467917025089, 56.20562642812729, 57.04357646405697, 57.40940183401108, 59.77356277406216, 55.99328242242336, 56.09149195253849, 56.08596324920654, 54.479181468486786, 49.82778646051884, 48.87667089700699, 48.078618720173836, 48.20785738527775, 45.80913729965687, 48.22564423084259, 49.983243718743324, 54.33070443570614, 55.72210997343063, 56.61541163921356, 46.88745863735676, 47.21022851765156, 51.668061912059784, 54.42192614078522, 52.831551879644394, 48.864344358444214, 45.64032755792141, 40.37229023873806, 40.329265147447586, 42.47003607451916, 43.17153923213482, 41.61601670086384, 40.47314442694187, 41.92633084952831, 52.48570203781128, 50.08037030696869, 43.21409694850445, 42.28033885359764, 42.489783614873886, 51.31804369390011, 49.70664516091347, 48.173974603414536, 43.91233988106251, 44.947320744395256, 40.35425640642643, 38.069932982325554, 38.190637305378914, 42.888484820723534, 40.12779615819454, 36.92912399768829, 42.429138869047165, 39.31112498044968, 40.69529950618744, 38.253881111741066, 42.27984867990017, 41.49146318435669, 40.09878471493721, 43.897699266672134, 39.61412072181702, 41.06856867671013, 43.18917788565159, 36.78540050983429, 40.30754171311855, 43.72440196573734, 45.601641833782196, 42.29877546429634, 41.86400659382343, 38.843708261847496, 35.53073823451996, 36.984684616327286, 38.311877399683, 37.85767637193203, 37.39972874522209, 38.67204487323761, 37.875831797719, 33.948415741324425, 41.53125464916229, 49.59983289241791, 40.73889076709747, 37.587537467479706, 39.41325969994068, 38.1685034930706, 39.67673376202583, 38.73741656541824, 42.66574077308178, 41.50174543261528, 41.649945080280304, 40.077418461441994, 43.16053882241249, 41.415216475725174, 43.77393610775471, 51.62736229598522, 54.00863751769066, 54.707100838422775, 54.67812739312649, 52.70974561572075, 53.03035721182823, 52.844938561320305, 53.41362364590168, 54.57487553358078, 59.50975053012371, 56.983832269907, 58.764363527297974, 57.68418788909912, 62.78158396482468, 57.523338720202446, 62.05650307238102, 56.90858490765095, 62.780956998467445, 62.055701315402985, 64.15923044085503, 60.050058737397194, 82.46554613113403, 74.48626309633255, 60.51813282072544, 57.558608427643776, 56.07960619032383, 57.191133946180344, 68.19646820425987, 62.51642279326916, 79.52957287430763, 22.776103243231773, 0.36407903709914535, 0.5443727422971278, 0.15324668231187388, 0.12173551498563029, 3.3254454704001546, 69.37278628349304, 65.88146522641182, 78.29837054014206, 57.84694455564022, 60.40405534207821, 57.67937734723091, 22.03819803893566, 37.24071107804775, 66.60008266568184, 46.61532483994961, 0.4632592963753268, 0.11468434022390284, 0.011800222273450345, 0.12856455752626061, 0.05508756628842093, 0.023401229846058413, 0.04499420574575197, 0.03339036316901911, 0.02829256005497882, 0.018488106470613275, 0.1561550996848382, 0.15293213044060394, 45.89112929999828, 75.61823755502701, 53.4139010310173, 54.03575286269188, 28.034390285611153, 46.792296543717384, 52.03585937619209, 79.55858051776886, 61.43429405987263, 75.44238299131393, 10.786871630698442, 0.14834292669547722, 0.4758761334232986, 2.7636216301470995, 1.0518671572208405, 13.785519674420357, 71.17081180214882, 68.76214385032654, 68.360535800457, 59.73980538547039, 64.75795671343803, 61.35144330561161, 65.96406519412994, 62.88528420031071, 61.59003630280495, 58.31314533948898, 60.258857533335686, 57.083405926823616, 61.480735167860985, 55.10533466935158, 56.33698157966137, 57.81944923102856, 62.035824581980705, 58.48027937114239, 58.093631118535995, 59.9962954223156, 55.890870317816734, 53.602857291698456, 53.15804935991764, 49.28986452519894, 50.52478305995464, 47.047164067626, 50.640490651130676, 53.64320732653141, 56.8930247426033, 58.07470813393593, 56.00581414997578, 47.041707560420036, 50.28911590576172, 54.454243406653404, 56.777184158563614, 52.937645986676216, 51.59860923886299, 48.26353579759598, 44.89240989089012, 41.16860590875149, 44.54682603478432, 44.96604613959789, 43.21949265897274, 42.711193934082985, 43.92041824758053, 53.60913075506687, 52.781679555773735, 43.41914154589176, 43.213709369301796, 42.863995134830475, 52.14454874396324, 50.34051954746246, 47.76444397866726, 46.570080667734146, 44.7164261341095, 40.222057700157166, 38.787934854626656, 38.84839341044426, 44.42020922899246, 42.93044976890087, 38.36779519915581, 44.33106981217861, 39.81809377670288, 44.327684193849564, 41.72733932733536, 44.85089331865311, 45.2799016982317, 41.92945048213005, 44.161078333854675, 41.291700303554535, 45.44896982610226, 44.22565206885338, 40.234019458293915, 40.452386140823364, 43.926760107278824, 46.03167995810509, 41.66833609342575, 40.596972182393074, 39.29792828857899, 36.417933627963066, 36.83948680758476, 37.636912018060684, 38.69025729596615, 37.97278359532356, 37.56209023296833, 37.66911529004574, 35.23360937833786, 42.74597726762295, 51.29437856376171, 43.15224006772041, 40.720883533358574, 40.48970393836498, 41.4347018301487, 42.32242539525032, 40.51389344036579, 43.52938503026962, 42.110715955495834, 43.607448041439056, 41.62833943963051, 45.10876268148422, 42.7691750228405, 44.969579949975014, 53.31615127623081, 58.31758730113506, 57.33986176550388, 55.48395395278931, 55.14916531741619, 54.476814195513725, 53.576444908976555, 55.43775603175163, 58.31039808690548, 59.40793119370937, 58.185153007507324, 61.29134193062782, 59.11987625062466, 63.56401897966862, 61.01256608963013, 64.1146132349968, 58.57203684747219, 64.95741561055183, 62.90161572396755, 65.57731434702873, 64.29919973015785, 76.51456385850906, 75.3195507824421, 65.19241020083427, 59.951625019311905, 58.99261727929115, 60.409033074975014, 70.27610421180725, 66.5121477842331, 83.33892926573753, 25.09476352483034, 0.5140400386881083, 2.2056165849789977, 0.3956319799181074, 0.27402752079069614, 3.456291686743498, 75.00974580645561, 71.53058409690857, 82.60181441903114, 66.83670356869698, 63.34438316524029, 32.84784659743309, 25.079186260700226, 44.1251702606678, 72.9550364613533, 56.91695585846901, 0.6287804630119354, 0.10132225332199596, 0.035437941187410615, 0.09796438389457762, 0.039700425550108775, 0.09064861864317209, 0.14205708430381492, 0.0956362443685066, 0.12065537841408513, 0.08723542210645974, 0.38172701199073344, 0.32044942199718207, 56.30327358841896, 83.56162011623383, 60.24653099477291, 63.56715381145477, 34.69873107969761, 53.34569849073887, 61.36228032410145, 84.27801087498665, 68.36218491196632, 81.68262854218483, 12.357854582369328, 0.26820133498404175, 1.0321522713638842, 4.099039547145367, 0.9963282686658204, 16.270383037626743, 74.54408839344978, 71.89810037612915, 71.89211949706078, 62.413870096206665, 67.73499056696892, 63.27318258583546, 69.47306290268898, 65.53846523165703, 65.40165737271309, 61.28199443221092, 61.672149896621704, 55.8881800621748, 64.05272215604782, 56.97475455701351, 58.584902957081795, 59.58324618637562, 64.27856683731079, 61.22180566191673, 63.318776339292526, 63.46682779490948, 59.46358300745487, 55.08725143969059, 55.05230091512203, 51.6700492054224, 53.3961445838213, 49.270569160580635, 52.796867340803146, 55.22964119911194, 59.83058251440525, 59.19980876147747, 58.139886036515236, 50.7232616096735, 52.04367935657501, 58.543580174446106, 56.349832490086555, 53.039362728595734, 54.29974749684334, 50.646209344267845, 46.35841302573681, 43.7993149459362, 46.27422094345093, 46.55908025801182, 45.70012494921684, 45.21530896425247, 46.14640340209007, 56.06490857899189, 52.14949227869511, 44.41208526492119, 42.743530198931694, 41.933425068855286, 52.75611072778702, 51.40247896313667, 49.21391800045967, 44.49173279106617, 46.23445227742195, 42.20866709947586, 38.22315216064453, 39.57420766353607, 47.82477334141731, 45.527371019124985, 42.55047395825386, 47.54510834813118, 43.18350479006767, 45.3168623149395, 43.369185626506805, 48.554387390613556, 48.16805452108383, 43.44150334596634, 48.153368309140205, 44.66153047978878, 46.295811384916306, 45.64848572015762, 39.14235323667526, 41.03551425039768, 45.87552733719349, 48.661575838923454, 42.156970873475075, 41.17799520492554, 40.947613567113876, 35.779108107089996, 36.79444022476673, 36.4790153503418, 41.32226586341858, 38.10326099395752, 40.228342562913895, 36.9726924598217, 35.71154773235321, 42.58522309362888, 53.897147700190544, 45.785570964217186, 43.451850190758705, 41.838813945651054, 41.673693805933, 43.26907239854336, 42.535248175263405, 45.91018907725811, 44.77263651788235, 45.09325571358204, 44.82932187616825, 47.94002115726471, 45.59700608253479, 46.10402427613735, 57.1683693677187, 58.46190355718136, 58.91841486096382, 56.44158236682415, 57.28887230157852, 54.92902413010597, 57.25660063326359, 57.43670716881752, 59.847043231129646, 62.11473874747753, 59.31617371737957, 62.89112448692322, 60.94873331487179, 66.01745992898941, 61.969468742609024, 65.33506974577904, 62.915123999118805, 67.00627326965332, 65.2747517824173, 67.70765483379364, 66.7387068271637, 78.43495801091194, 76.47857218980789, 68.50944221019745, 63.3305899053812, 62.61663481593132, 63.544370234012604, 74.12415772676468, 69.20302659273148, 85.98620921373367, 28.460132740437984, 0.84391446900554, 3.990404801443219, 1.5954159968532622, 0.4541533818701282, 4.227680694311857, 81.57345280051231, 76.30479991436005, 90.25528773665428, 71.9559408724308, 83.00833940505981, 73.68913426995277, 36.43678441643715, 55.020815804600716, 82.17182949185371, 69.62748661637306, 1.2081850692629814, 0.2479317827965133, 0.19189690210623667, 0.16965326678473502, 0.16359020228264853], [0.11936923649045639, 0.051538786792661995, 0.018296127709618304, 0.06783968943636864, 0.04835567087866366, 0.06986889187828638, 0.08899512846255675, 32.56818540394306, 63.82369324564934, 39.442803114652634, 37.12919846177101, 25.213959328830242, 40.94727538526058, 44.571015536785126, 75.13498708605766, 55.67310780286789, 71.41573145985603, 11.670416370034218, 0.05249441324849613, 0.28011565504129976, 2.1424169512465596, 3.210265813395381, 1.7276944988407195, 56.168749406933784, 68.41832309961319, 68.98044213652611, 61.12785570323467, 65.1162850856781, 59.765492007136345, 65.21649330854416, 62.55660563707352, 61.80759742856026, 57.20431163907051, 57.02352873980999, 52.78554014861584, 53.94708462059498, 51.75177901983261, 60.456815510988235, 57.68769510090351, 57.254240959882736, 53.62978644669056, 54.813544526696205, 49.34218771755695, 48.907658234238625, 48.056655898690224, 49.71031196415424, 48.33234250545502, 48.347560688853264, 49.76597137749195, 51.32264144718647, 53.1902564316988, 55.53097642958164, 52.907897382974625, 48.47003571689129, 50.82443878054619, 52.93936349451542, 50.43408952653408, 48.84422063827515, 69.17616203427315, 58.77118796110153, 51.83564051985741, 45.74203670024872, 38.3216542750597, 41.53873264789581, 38.52207452058792, 38.570107743144035, 41.317485719919205, 40.91162949800491, 43.10331389307976, 52.83390775322914, 49.008349031209946, 41.613398641347885, 45.735721439123154, 53.204137086868286, 51.07439696788788, 47.864477410912514, 47.92885735630989, 45.959749817848206, 42.31591634452343, 41.013255044817924, 38.56394827365875, 36.09379202127457, 42.363246604800224, 39.41510260105133, 41.23105175793171, 41.936932280659676, 41.87770485877991, 42.59679727256298, 38.729091212153435, 41.18744529783726, 41.69707015156746, 42.39754356443882, 40.886744633316994, 39.987629279494286, 36.96199223399162, 38.35521787405014, 36.388014033436775, 42.46609948575497, 46.21366739273071, 41.04366861283779, 39.632572531700134, 39.915425553917885, 39.13560479879379, 38.38342756032944, 40.60206010937691, 36.56949229538441, 34.59970459342003, 36.175290048122406, 37.44916409254074, 37.260572612285614, 50.55263936519623, 44.8039810359478, 38.17892253398895, 38.234524950385094, 38.61231587827206, 38.09052027761936, 40.01395806670189, 40.33675454556942, 39.20510306954384, 41.944581270217896, 43.997223526239395, 46.83154083788395, 47.242150604724884, 46.78873613476753, 44.122814387083054, 46.73073224723339, 52.4192626029253, 50.8006976544857, 52.4640242010355, 56.139422580599785, 56.62206508219242, 51.65937177836895, 53.368444070219994, 52.87752941250801, 57.2586677223444, 56.07267536222935, 61.041642129421234, 61.21830604970455, 56.81733660399914, 60.83257354795933, 60.33952720463276, 60.95100559294224, 62.526032477617264, 57.313358187675476, 60.877171754837036, 57.60469235479832, 75.12685552239418, 63.14771331846714, 69.48257759213448, 65.83786636590958, 57.17156119644642, 56.176690980792046, 65.62408983707428, 61.65172599256039, 80.20722091197968, 24.224057346582413, 0.17557490762555972, 0.8831039036158472, 0.13587264897068962, 0.05639783172227908, 2.0011144084855914, 60.58790847659111, 70.56843772530556, 74.85574007034302, 65.94712570309639, 45.181817561388016, 43.3791296929121, 24.98258214443922, 43.0480420589447, 59.566040709614754, 55.92122308909893, 0.7409996632486582, 0.21832990169059485, 0.041269767316407524, 0.0723161461064592, 0.054602687814622186, 0.12579998321598396, 0.009922912413458107, 0.06037075974745676, 0.047059617572813295, 0.05326258062268607, 0.05893631816434208, 0.07733740596449934, 41.44046612083912, 74.39186856150627, 46.75991088151932, 49.373163655400276, 29.890535585582256, 45.63550181686878, 50.672705322504044, 81.29009440541267, 61.91504806280136, 79.96744617819786, 12.58559726178646, 0.0313436052238103, 0.7786364655476063, 7.005307897925377, 5.555240632966161, 0.9942998306360096, 60.24330876767635, 68.5392478108406, 73.5084767639637, 61.61821939051151, 68.05443942546844, 62.140106186270714, 66.62044957280159, 63.12625586986542, 64.85438033938408, 56.77253320813179, 58.80289725959301, 52.93234907090664, 54.92170952260494, 52.50264912843704, 62.45856709778309, 59.21429358422756, 60.54900996387005, 56.46542228758335, 57.20433443784714, 51.917909905314445, 53.39155822992325, 49.24690403044224, 51.07016399502754, 51.094186305999756, 51.481081545352936, 52.169137224555016, 53.3183703571558, 55.71342743933201, 58.73032495379448, 53.64509202539921, 51.47166945040226, 52.56369665265083, 54.808126017451286, 50.189580246806145, 54.75983440876007, 65.99342241883278, 58.8493649661541, 54.19850192964077, 47.341701462864876, 41.59101404249668, 43.43850530683994, 42.900172993540764, 41.45864434540272, 44.098856672644615, 43.51423144340515, 45.787987634539604, 54.947935715317726, 50.42692691087723, 41.808483973145485, 46.13870121538639, 54.18132685124874, 50.35736404359341, 47.67073340713978, 48.72416228055954, 47.56040632724762, 42.12973393499851, 39.56047900021076, 38.41683156788349, 38.73441852629185, 45.86394175887108, 42.444292455911636, 43.58440987765789, 43.13855320215225, 43.988305404782295, 43.38059641420841, 41.79170407354832, 43.78559768199921, 41.37337312102318, 43.48776966333389, 41.11215613782406, 43.246809393167496, 37.933349311351776, 38.48608285188675, 37.66741298139095, 43.161150589585304, 46.70006409287453, 41.9800865650177, 40.14920800924301, 40.32845199108124, 38.77726882696152, 38.15151460468769, 39.60805244743824, 37.82535530626774, 37.405348643660545, 36.04426547884941, 37.55559258162975, 37.314012944698334, 53.339915201067924, 45.66735930740833, 40.32913215458393, 40.99320352077484, 39.4265665858984, 40.253691002726555, 41.516568437218666, 42.54618398845196, 41.586439087986946, 42.866096422076225, 45.57564742863178, 49.863645136356354, 49.532093927264214, 48.25804889202118, 46.17657758295536, 48.89801815152168, 54.76618766784668, 54.055523201823235, 55.06922900676727, 56.833945512771606, 57.08693973720074, 55.44628657400608, 56.5673404186964, 55.92604123055935, 57.61501260101795, 58.16779933869839, 62.58315861225128, 62.32304356992245, 56.87769636511803, 63.336962163448334, 62.52176910638809, 62.864316925406456, 61.21325612068176, 58.422207087278366, 61.53569161891937, 59.93657022714615, 71.36753484606743, 65.7516261935234, 72.59559854865074, 66.58695057034492, 58.73486191034317, 60.23948237299919, 70.20500242710114, 65.35435751080513, 82.03188300132751, 27.988247461616993, 0.41767587361391634, 2.313271933235228, 0.31458829587791115, 0.12251050269696862, 2.17807091306895, 67.38078877329826, 75.12831464409828, 81.92194730043411, 72.8464762866497, 57.13370002806187, 52.66552358865738, 36.513057723641396, 53.43432113528252, 67.36348450183868, 66.00700289011002, 1.3119883742183447, 0.22787697846069932, 0.0894381312537007, 0.028341849792923313, 0.018524727747717407, 0.17122142482548952, 0.1556219407939352, 0.14802564372075722, 0.14052714686840773, 0.1626404165290296, 0.3032145561883226, 0.24046791455475613, 50.836259946227074, 85.65877318382263, 53.84160228073597, 50.454023256897926, 35.12221835553646, 59.229268580675125, 58.77514734864235, 87.89805382490158, 66.39075949788094, 87.47338861227036, 13.92241207882762, 0.13944752980023623, 2.1274087065830827, 9.578695110976696, 6.2018215376883745, 2.2206400288268924, 66.01283937692642, 68.9363645017147, 77.04695329070091, 64.12227362394333, 71.88187524676323, 63.24600264430046, 69.86938923597336, 64.49358969926834, 67.34845250844955, 57.29660488665104, 60.87540104985237, 53.336271196603775, 56.19717188179493, 52.695310190320015, 63.80057528614998, 60.664428770542145, 63.27917866408825, 57.78833270072937, 60.49123406410217, 56.28250390291214, 56.12308345735073, 51.013425439596176, 54.685567393898964, 53.837661892175674, 53.12978267669678, 54.613458663225174, 55.71082837879658, 57.979675233364105, 61.69896125793457, 55.33598609268665, 52.92719654738903, 52.63084664940834, 57.422853112220764, 54.254742711782455, 60.39124622941017, 64.8572301864624, 61.70823276042938, 56.90557926893234, 50.448258966207504, 43.506749644875526, 44.80708546936512, 45.505229607224464, 43.80492344498634, 46.17848128080368, 46.333455964922905, 48.89574587345123, 57.39594295620918, 51.88709355890751, 41.817592084407806, 47.57202610373497, 56.30430333316326, 52.84075878560543, 50.733684450387955, 50.81517107784748, 47.60089695453644, 42.071638852357864, 41.03176385164261, 38.36320884525776, 39.88977313041687, 47.49829486012459, 46.13962076604366, 45.50831884145737, 47.962219566106796, 46.13221876323223, 46.39752432703972, 44.24227997660637, 46.28609910607338, 44.24877002835274, 45.84083139896393, 45.28584457933903, 44.072744473814964, 38.77062298357487, 39.18363802134991, 37.692985609173775, 44.343206360936165, 47.349282056093216, 42.162982150912285, 38.76312218606472, 41.88158065080643, 39.48035649955273, 39.84773978590965, 40.982263907790184, 37.30267055332661, 36.425685212016106, 36.198100224137306, 37.52710171043873, 37.7701860666275, 55.00140264630318, 49.1740657389164, 42.320954874157906, 42.719906866550446, 41.3454370200634, 42.032322362065315, 43.470997363328934, 43.47173072397709, 43.88419099152088, 46.09413720667362, 48.00287738442421, 52.08179131150246, 52.225484400987625, 52.5532928109169, 48.25874425470829, 52.49529272317886, 60.87850168347359, 57.64753885567188, 57.13924393057823, 59.071991220116615, 61.003336384892464, 56.49794094264507, 58.256095200777054, 58.54187786579132, 61.28894425928593, 60.257717594504356, 65.56212276220322, 65.47991037368774, 60.866923704743385, 65.74997708201408, 64.00091573596, 65.35776972770691, 67.01169937849045, 60.3886129707098, 63.76308649778366, 59.53941933810711, 73.82062241435051, 70.0597058236599, 73.00135597586632, 70.17958179116249, 60.79402841627598, 62.91735827922821, 73.52592542767525, 69.72720846533775, 84.89749923348427, 30.515098571777344, 0.6638653459958732, 6.633565770462155, 2.323916112072766, 0.3607562044635415, 2.8031772701069713, 72.76118606328964, 82.61939227581024, 88.69304716587067, 80.33042550086975, 66.47770643234253, 57.462196201086044, 37.5439690053463, 61.21161840856075, 77.28731319308281, 80.38095518946648, 2.620646464638412, 0.42838767694775015, 0.2432157311704941, 0.24461730674374849, 0.12947310955496505], [0.006463976387749426, 0.06452827103203163, 0.026780176267493516, 0.041895219692378305, 0.03731355616764631, 0.12864827178418636, 0.10780192242236808, 29.906088151037693, 67.42054224014282, 39.615192264318466, 36.701497212052345, 27.50853080302477, 47.163259238004684, 48.43173377215862, 71.32509872317314, 59.4092383235693, 69.62166532874107, 14.635313674807549, 0.3091454738751054, 0.5147675215266645, 1.905450860504061, 2.2593150660395622, 0.1321684118011035, 21.396826654672623, 78.25206622481346, 58.905795738101006, 64.9771897494793, 63.231438025832176, 61.03049352765083, 59.409956485033035, 61.34716473519802, 60.82676365971565, 61.13390497863293, 57.50437393784523, 59.33797314763069, 60.836301147937775, 60.431467071175575, 59.55332659184933, 59.43937070667744, 56.94119855761528, 51.16096772253513, 49.88807022571564, 48.96611429750919, 48.73897768557072, 51.48872673511505, 52.72379346191883, 50.81541806459427, 51.65982395410538, 51.74432002007961, 53.69412839412689, 52.742404863238335, 54.767194613814354, 56.12487696111202, 56.65552228689194, 51.11465960741043, 49.603758081793785, 52.67444171011448, 47.41076275706291, 60.0395181030035, 59.16066326200962, 50.93506224453449, 50.63850715756416, 39.44773145020008, 41.00116789340973, 39.50192794203758, 38.91952559351921, 40.706322714686394, 41.7305463552475, 38.944577649235725, 48.09209659695625, 54.25905168056488, 43.3623193949461, 43.20804387331009, 50.50160050392151, 46.7405167222023, 47.377552539110184, 45.47611556947231, 51.590937450528145, 47.95910753309727, 43.517955243587494, 38.098112270236015, 38.332411497831345, 44.59958240389824, 41.91908083856106, 39.87077794969082, 40.474056378006935, 41.179306134581566, 41.41108229756355, 41.83873035013676, 40.87580882012844, 41.09927862882614, 39.784457981586456, 44.832635298371315, 37.86941774189472, 36.91833257675171, 39.04255919158459, 36.570210456848145, 45.314259454607964, 43.28930251300335, 41.53270997107029, 40.3999337553978, 41.472019627690315, 38.14630888402462, 40.62733255326748, 41.9218584895134, 38.66605259478092, 36.251540556550026, 37.03116752207279, 35.77912710607052, 47.69894689321518, 49.9778176099062, 41.67486034333706, 39.52734097838402, 38.24581414461136, 39.595022946596146, 40.672246143221855, 39.00244474411011, 38.95865589380264, 38.939071744680405, 42.82578818500042, 50.294310227036476, 54.04888495802879, 52.72044204175472, 54.28789973258972, 50.14052867889404, 47.45063781738281, 47.7654243260622, 51.9521726667881, 55.0835732370615, 55.399309694767, 54.972159415483475, 55.58314763009548, 52.27973788976669, 55.710653588175774, 55.45051194727421, 58.704235553741455, 57.47577287256718, 49.966239631175995, 61.94807209074497, 61.80412441492081, 58.75859163701534, 58.40233035385609, 60.521077662706375, 59.009545370936394, 58.873208686709404, 59.33967545628548, 49.0099373459816, 47.70102918148041, 65.60260578989983, 59.52386297285557, 65.6024917960167, 54.71620135009289, 68.20854395627975, 62.65924572944641, 82.41948500275612, 24.842759147286415, 0.10531995794735849, 0.5029899347573519, 0.29554300534073263, 0.15814841928659007, 2.2991013061255217, 60.004028007388115, 69.61897507309914, 75.38128986954689, 63.46872769296169, 54.15534004569054, 21.40006598085165, 9.350356813520193, 31.399064138531685, 54.20987851917744, 66.3591755926609, 1.678045412991196, 0.09912746289046481, 0.10635793310939334, 0.06704047802486457, 0.06675676981103607, 0.09795394929824397, 0.03000153876200784, 0.06832524697529152, 0.007779338520776946, 0.038594462239416316, 0.2211565789184533, 0.21195325010921806, 38.41722674667835, 76.57610535621643, 44.43692833185196, 37.43366852402687, 33.62081252038479, 55.08385442197323, 53.05909886956215, 78.20803418755531, 63.88854056596756, 75.64613565802574, 16.0313568636775, 0.3915427759056911, 0.9865974064450711, 1.4648455032147467, 4.556269012391567, 0.21894647798035294, 23.378938995301723, 77.30733051896095, 59.679859802126884, 66.75686225295067, 65.38435310125351, 62.29361794888973, 60.66153332591057, 62.046851590275764, 60.802764147520065, 59.759549126029015, 59.70869265496731, 59.81979489326477, 61.15894563496113, 61.066895574331284, 62.55086034536362, 61.3062409311533, 58.46019744873047, 52.57485285401344, 52.37696707248688, 51.0734698176384, 52.2507568448782, 55.26147209107876, 54.8745084553957, 52.926995158195496, 54.29758541285992, 53.07376608252525, 54.897770807147026, 54.884786903858185, 56.232369393110275, 58.37607756257057, 58.12917821109295, 52.99000717699528, 49.56447958946228, 52.33935669064522, 49.37806539237499, 58.44345174729824, 60.013538897037506, 51.992632895708084, 53.67699891328812, 42.14552968740463, 42.35677555203438, 42.0895054936409, 40.70507638156414, 42.713029235601425, 44.064213931560516, 42.607949674129486, 50.25081396102905, 55.84158316254616, 44.46720130741596, 43.96100006997585, 48.57674919068813, 47.72294640541077, 49.68250885605812, 45.85933640599251, 50.85023559629917, 48.405591174960136, 43.304896876215935, 39.30109731853008, 38.81031185388565, 46.32208697497845, 45.63295595347881, 43.22718724608421, 41.98519729077816, 42.995289489626884, 43.60984571278095, 43.86063225567341, 43.31208989024162, 43.20332072675228, 41.77082039415836, 46.3118427246809, 39.8160532861948, 37.699323669075966, 39.45180483162403, 38.15764367580414, 46.40267305076122, 43.90205763280392, 42.16721132397652, 38.07707279920578, 41.510196179151535, 38.90824019908905, 39.752342104911804, 43.00544634461403, 39.479026570916176, 35.7612718641758, 36.753197237849236, 37.529723569750786, 50.116073191165924, 50.683511942625046, 43.32754746079445, 40.34356378018856, 40.19499555230141, 40.3034683316946, 42.35658556222916, 42.427037581801414, 43.54918956756592, 41.214138865470886, 43.44825938344002, 52.716851234436035, 55.99724180996418, 57.946153432130814, 56.86242878437042, 52.477680668234825, 50.70954814553261, 50.3163718432188, 53.98008204996586, 57.50041455030441, 57.25794196128845, 57.9476011544466, 57.46932841837406, 54.4310038536787, 58.08908276259899, 58.8689187169075, 61.003355383872986, 59.23136226832867, 51.59778468310833, 62.86323018372059, 63.503853008151054, 59.90468233823776, 61.16220586001873, 60.544993579387665, 61.68701469898224, 59.360502138733864, 59.557791352272034, 50.458902195096016, 50.07172957062721, 66.74426972866058, 63.01179461181164, 68.29732239246368, 57.464236691594124, 69.63511660695076, 64.0184859931469, 85.50908401608467, 28.439241461455822, 0.07965757482452318, 1.659089180175215, 0.8026681572664529, 0.07327387284021825, 2.373655680567026, 65.99134013056755, 75.03685355186462, 81.93329349160194, 71.44818171858788, 58.35178166627884, 29.43901341408491, 19.64221190661192, 39.477989226579666, 61.511931493878365, 78.70466753840446, 2.755257091484964, 0.1956089911982417, 0.17782659851945937, 0.08336608676472679, 0.03381719085155055, 0.1830132756731473, 0.13084526639431715, 0.1580989922513254, 0.1046910991135519, 0.09221177460858598, 0.37615104869473726, 0.5153287039138377, 49.58483889698982, 87.08063408732414, 55.38488566875458, 52.04128548502922, 38.87756444513798, 62.208536714315414, 62.20788694918156, 85.7506674528122, 70.26898339390755, 85.52705705165863, 18.476027883589268, 0.4732735105790198, 2.4472551187500358, 4.512581331655383, 6.799194607883692, 0.3139290906256065, 29.124870970845222, 78.63133147358894, 62.75228753685951, 69.03329730033875, 68.73894989490509, 65.47899082303047, 64.29850816726685, 63.9962799847126, 63.543367087841034, 61.41576625406742, 60.974602326750755, 63.18329460918903, 62.82201759517193, 62.6945686340332, 64.43071827292442, 64.70485836267471, 61.64449878036976, 55.47960698604584, 57.59046591818333, 53.62277962267399, 53.490048944950104, 58.18920359015465, 57.51795440912247, 54.53372374176979, 56.65774516761303, 55.68144075572491, 57.642515525221825, 56.08249023556709, 58.98033253848553, 61.179677322506905, 60.04866421222687, 55.71939691901207, 52.87891633808613, 55.0114569067955, 52.414790242910385, 61.92547470331192, 63.41227412223816, 54.95227508246899, 55.71850776672363, 43.686973974108696, 44.962823912501335, 43.95090401172638, 40.38363263010979, 45.55895112454891, 47.07146376371384, 45.77665664255619, 53.36217440664768, 59.47789303958416, 46.14269480109215, 45.261548683047295, 52.83306799829006, 48.83367620408535, 49.07952681183815, 47.96105682849884, 52.24320665001869, 49.540540874004364, 44.641186371445656, 40.60906693339348, 39.604180455207825, 47.817804515361786, 47.2388181835413, 44.73381780087948, 44.05421666800976, 46.74907386302948, 45.97667030990124, 46.77794471383095, 44.223026409745216, 47.24309675395489, 44.0705443918705, 49.08192828297615, 40.78668840229511, 38.12059186398983, 38.79119887948036, 38.46830740571022, 48.69281776249409, 44.83248710632324, 43.89057844877243, 39.917363449931145, 41.460160464048386, 40.11439807713032, 40.67613713443279, 43.17093886435032, 41.1272869259119, 35.90879514813423, 37.52164140343666, 38.16391333937645, 53.08724395930767, 54.61706466972828, 48.101102113723755, 44.95379939675331, 42.5685153901577, 43.70938517153263, 45.76265439391136, 44.26646187901497, 44.79752138257027, 44.36105020344257, 45.67854970693588, 56.89586699008942, 58.200219199061394, 60.78902028501034, 58.62313270568848, 55.23736618459225, 54.62938740849495, 51.328451335430145, 58.370754048228264, 59.34091418981552, 58.22358034551144, 60.427633076906204, 61.19506649672985, 56.478881165385246, 61.326003670692444, 61.922579258680344, 63.25322985649109, 55.653630048036575, 50.34024216234684, 66.69405162334442, 68.33708345890045, 61.91740393638611, 63.66730883717537, 64.63200107216835, 61.80640049278736, 62.218792364001274, 59.01693217456341, 54.26451958715916, 54.297566413879395, 66.963981539011, 68.42340722680092, 71.0749277472496, 62.38206200301647, 74.61063802242279, 68.2514588534832, 87.10556834936142, 30.756227932870388, 0.5308850691653788, 4.1785498056560755, 1.849990461487323, 0.2142172458115965, 3.401230266317725, 72.7935603260994, 81.2126013636589, 88.01111295819283, 78.84153619408607, 71.53348714113235, 29.56502605229616, 19.489082023501396, 50.458309426903725, 69.90510731935501, 92.4827130138874, 5.129137197509408, 0.30330871988553554, 0.3482640185393393, 0.16994451521895826, 0.12880384078016505], [0.018562401019153185, 0.03897932889231015, 0.10289118319633417, 0.05004831305996049, 0.020666489872382954, 0.26831900991965085, 0.18893735075835139, 33.37644003331661, 67.86264091730118, 41.29993066191673, 55.08278287947178, 27.662375047802925, 42.46950030326843, 48.0672687292099, 71.95546969771385, 57.192722260951996, 69.39381435513496, 16.66528444737196, 0.27823395445011556, 0.31275320216082036, 0.739487106911838, 4.793322142213583, 0.6142779474612325, 2.606930388137698, 52.88916818797588, 61.53143584728241, 59.88690689206123, 64.42096039652824, 57.403215765953064, 61.60419054329395, 59.92558881640434, 60.82759961485863, 58.348639234900475, 61.54689721763134, 60.260324254631996, 60.00500835478306, 56.320452466607094, 56.94383181631565, 52.40538574755192, 53.03275488317013, 48.461037799715996, 49.16434966027737, 50.76139636337757, 51.720818281173706, 56.37149132788181, 61.15090146660805, 53.27170126140118, 54.65895742177963, 51.283191964030266, 57.24295176565647, 52.05014280974865, 54.742172956466675, 51.46593175828457, 53.85855697095394, 50.582539960742, 52.87383981049061, 48.86369839310646, 56.04452267289162, 51.90936416387558, 45.49543373286724, 54.629854783415794, 49.172443225979805, 39.88954894244671, 39.93942506611347, 39.05692622065544, 41.82472810149193, 40.00006601214409, 41.023955270648, 40.299474745988846, 40.93243718147278, 50.35922974348068, 48.04901830852032, 43.67349609732628, 40.3087804466486, 42.51388572156429, 51.00070372223854, 49.368831887841225, 47.663578391075134, 51.94138124585152, 49.923586919903755, 41.35740637779236, 40.36209538578987, 39.2090168595314, 44.65172700583935, 39.57894220948219, 40.56659661233425, 42.02145114541054, 44.44298140704632, 42.98197880387306, 42.850874438881874, 41.256730780005455, 40.19445598125458, 43.021633476018906, 40.76966531574726, 39.032060354948044, 36.88953772187233, 38.33637088537216, 46.68897248804569, 43.92015606164932, 41.28964081406593, 39.61369514465332, 39.36505168676376, 43.78035016357899, 44.065961837768555, 44.176273718476295, 38.94550859928131, 34.79270003736019, 38.06850805878639, 44.70420219004154, 51.73293583095074, 41.12287916243076, 36.70622415840626, 39.47950914502144, 40.10453000664711, 39.06617872416973, 36.73677831888199, 39.1078282892704, 39.42695416510105, 39.6656459569931, 47.51037061214447, 54.92170192301273, 55.17349161207676, 46.99530825018883, 51.199642047286034, 52.11565129458904, 51.95352539420128, 52.30192869901657, 50.25542691349983, 50.63654646277428, 54.727467745542526, 52.915485575795174, 56.00671090185642, 54.165930077433586, 57.18943163752556, 54.367969036102295, 59.4664366543293, 33.59900929033756, 45.56111320853233, 59.335001707077026, 55.404545813798904, 58.84005926549435, 58.96385282278061, 58.951252698898315, 61.86670705676079, 58.41072030365467, 55.061496421694756, 49.06063802540302, 53.604665994644165, 63.48883621394634, 74.58349987864494, 65.78011706471443, 55.933857411146164, 64.82634544372559, 62.07723096013069, 77.5350371003151, 23.773980997502804, 0.1969237651792355, 0.7984639203641564, 0.36597083089873195, 0.07001709876931272, 3.3471629675477743, 67.17948317527771, 67.67021164298058, 73.61411109566689, 60.70371486246586, 49.07950021326542, 51.78246237337589, 27.568521983921528, 35.45472331345081, 45.70400454103947, 63.53866294026375, 3.832975449040532, 0.32747770892456174, 0.07624874211614951, 0.06221242147148587, 0.15423921577166766, 0.030297674238681793, 0.06387408269802108, 0.040486927682650276, 0.030351004970725626, 0.07054567860905081, 0.10871392543776892, 0.14444478118093684, 41.60761535167694, 74.58322629332542, 47.6395408809185, 58.133240193128586, 31.629267185926437, 49.98900040984154, 54.71671812236309, 77.28279143571854, 63.94914731383324, 75.18815383315086, 18.908581472933292, 0.3117407049285248, 0.45085014193318784, 3.484207126311958, 9.095209054648876, 0.2369492588331923, 2.4680464155972004, 56.268950030207634, 60.30169643461704, 62.778479531407356, 65.08945092558861, 60.46344615519047, 61.567442715168, 61.43600016832352, 62.233242988586426, 59.01359215378761, 62.946810498833656, 61.58520296216011, 60.70729807019234, 59.39396694302559, 59.19974036514759, 56.15386180579662, 54.032207652926445, 49.361407086253166, 50.04571236670017, 54.207955822348595, 55.914915427565575, 59.37557972967625, 65.12965276837349, 56.1811937391758, 56.26054488122463, 53.35592374205589, 56.99933543801308, 53.245828449726105, 56.51593677699566, 53.04468244314194, 55.31269334256649, 56.4873281121254, 54.302574545145035, 52.88065664470196, 57.02357433736324, 53.01525682210922, 51.428944543004036, 57.11873263120651, 51.65972135961056, 41.683406084775925, 41.36975571513176, 41.19543246924877, 42.62620769441128, 42.73763671517372, 44.446374624967575, 42.6125094294548, 44.91848789155483, 54.16923210024834, 50.01438304781914, 45.30513994395733, 41.369725316762924, 43.46173346042633, 50.484197437763214, 50.10997451841831, 47.91127569973469, 51.571273505687714, 52.041486874222755, 42.34402723610401, 38.484133556485176, 40.587480291724205, 46.77085429430008, 42.61595584452152, 41.962322518229485, 45.02086199820042, 45.92092350125313, 44.12873066961765, 46.0339218378067, 43.98057661950588, 42.09778144955635, 44.72519226372242, 42.49018259346485, 38.61887812614441, 36.38407364487648, 39.16901260614395, 47.52834364771843, 44.04965691268444, 42.20026195049286, 41.66579782962799, 39.646669775247574, 44.36272971332073, 47.1386631578207, 44.93712969124317, 40.00391140580177, 35.224858447909355, 38.8800685107708, 45.22171922028065, 53.296095952391624, 43.02596144378185, 39.435317516326904, 40.696762427687645, 41.92319221794605, 41.4437947422266, 40.08502185344696, 40.95668748021126, 41.64035439491272, 40.359929502010345, 48.747215643525124, 54.78571102023125, 58.21371607482433, 48.00442010164261, 53.134110644459724, 55.66581219434738, 53.8219041377306, 55.86309380829334, 52.285578176379204, 51.25459849834442, 55.89303620159626, 54.79579567909241, 58.47271017730236, 55.29457971453667, 58.41053031384945, 55.24514436721802, 61.08497880399227, 37.99182817339897, 46.70553959906101, 57.71604157984257, 57.6994364708662, 60.953129678964615, 60.658554285764694, 63.18414196372032, 60.72128891944885, 58.15727770328522, 56.092799082398415, 51.78477264940739, 54.24099884927273, 63.30050691962242, 71.6853953897953, 71.56609699130058, 58.27115759253502, 66.62439376115799, 63.63366924226284, 79.83752354979515, 26.008960269391537, 0.1095377909950912, 1.6797975939698517, 0.9802040713839233, 0.11058278687414713, 3.9999161660671234, 72.6308986544609, 71.33282750844955, 78.79260241985321, 67.09434494376183, 60.188660100102425, 41.524764597415924, 22.274788543581963, 41.56835965812206, 54.34300437569618, 75.59948936104774, 5.246321484446526, 0.16942361660767347, 0.1808004139456898, 0.015364621194748906, 0.08352486183866858, 0.11332064386806451, 0.15466969111002982, 0.25836517685092986, 0.10518950322875753, 0.1758221467025578, 0.2711807907326147, 0.3268154460238293, 54.42704066634178, 84.98278185725212, 55.11748641729355, 72.3532323539257, 35.032208785414696, 56.02328561246395, 65.97094282507896, 84.18005213141441, 67.58103802800179, 82.94031545519829, 21.893606297671795, 0.39004909980576485, 1.473646187223494, 8.221754673868418, 13.057715278118849, 0.7144284015521407, 3.9706852845847607, 61.736541241407394, 62.965330705046654, 65.31246855854988, 66.70584619045258, 62.0466274023056, 63.69248628616333, 65.31263574957848, 63.75256106257439, 60.9200182557106, 65.42569488286972, 65.38810729980469, 63.700731843709946, 62.86605343222618, 61.16405636072159, 57.58158579468727, 58.761688470840454, 52.51253239810467, 51.69451989233494, 56.605201587080956, 59.191855788230896, 60.6574447453022, 61.327926367521286, 60.17284534871578, 61.2108888477087, 58.76369096338749, 61.301950961351395, 55.73353596031666, 58.61677944660187, 56.06801301240921, 58.83752480149269, 56.234976053237915, 56.63669429719448, 55.18417663872242, 54.07904013991356, 54.70722623169422, 53.31504933536053, 57.378665283322334, 55.27817599475384, 43.561132326722145, 44.16824854910374, 42.49818876385689, 45.71671865880489, 45.374364629387856, 46.635653749108315, 44.083129316568375, 45.235387086868286, 57.018277421593666, 49.73502203822136, 48.070916533470154, 42.24689684808254, 42.41379149258137, 51.839421316981316, 50.83529479801655, 51.63928605616093, 54.217371717095375, 51.20189152657986, 41.952032670378685, 40.47966107726097, 42.21312806010246, 47.7155975997448, 45.06301313638687, 45.03992557525635, 46.58449329435825, 48.994061797857285, 44.58553075790405, 46.38287611305714, 45.05046620965004, 44.442172050476074, 48.16905006766319, 43.924506828188896, 40.11886663734913, 37.28080652654171, 39.39176045358181, 48.43956895172596, 45.42298682034016, 45.24786941707134, 40.391030833125114, 40.5705825984478, 44.875656589865685, 45.97987353801727, 47.11397968232632, 40.94936907291412, 34.757939502596855, 38.0095200240612, 46.6795451939106, 57.547786608338356, 44.42295268177986, 42.42747835814953, 41.71136498451233, 44.539895206689835, 42.62883335351944, 41.16208925843239, 42.91310749948025, 44.287733137607574, 43.7078994512558, 52.556579634547234, 59.813658222556114, 59.18727703392506, 49.4647691398859, 54.560018330812454, 56.639680936932564, 56.319168135523796, 57.41007059812546, 54.86487977206707, 54.69486549496651, 60.51879398524761, 58.86918470263481, 61.582942083477974, 58.982080444693565, 62.775956466794014, 58.71938914060593, 59.59921292960644, 33.52656617760658, 50.058962255716324, 59.75463218986988, 60.1693419367075, 63.50017860531807, 63.607142865657806, 64.9212795495987, 66.72347724437714, 60.10840840637684, 55.73353596031666, 54.29924972355366, 56.000958010554314, 61.96520917117596, 72.22454085946083, 73.89326691627502, 62.75296010077, 70.06019219756126, 68.49855959415436, 82.29454010725021, 29.421935230493546, 0.3158914775121957, 5.028014648705721, 1.4740953943692148, 0.2315959843690507, 5.437248889356852, 82.45103850960732, 78.29349920153618, 85.08441880345345, 75.35534486174583, 70.92809602618217, 67.48747944831848, 41.97532922029495, 53.89261454343796, 64.27202358841896, 90.69037199020386, 9.58761228248477, 0.576632417505607, 0.3485346055822447, 0.18794060189975426, 0.2473847902729176], [0.03388820696272887, 0.05236937620793469, 0.0874983798712492, 0.039534863535664044, 0.0029690364590351237, 0.13671319058630615, 0.30543028260581195, 37.515873312950134, 66.10272735357285, 44.24566559493542, 40.08072428405285, 23.84027224034071, 39.439520090818405, 47.95463517308235, 73.84926527738571, 56.86096206307411, 70.61569958925247, 20.51880966871977, 0.25349659903440624, 0.5837588757276535, 1.2089633150026202, 3.49436208140105, 1.1378357629291713, 0.03891587155521847, 33.57127457857132, 70.00365123152733, 56.25383444130421, 62.62108437716961, 59.911974146962166, 63.301092088222504, 60.228930339217186, 62.055629119277, 60.33005431294441, 60.68198002874851, 58.90852399170399, 60.41077338159084, 57.26646110415459, 54.77026104927063, 51.86284326016903, 50.995725989341736, 51.27743527293205, 51.079769879579544, 54.36635032296181, 55.80846033990383, 55.7300591468811, 53.333550542593, 48.94483543932438, 58.24995473027229, 53.628589510917664, 54.27268534898758, 49.658809527754784, 55.82677535712719, 52.73179963231087, 55.79225420951843, 49.67954121530056, 54.36640352010727, 50.10762244462967, 63.802877962589264, 43.84670600295067, 47.38318383693695, 53.926896303892136, 48.44239979982376, 39.61732394993305, 39.948620572686195, 41.14343225955963, 39.57638494670391, 40.362201780080795, 40.086055397987366, 41.4184994995594, 38.18417385220528, 46.12065598368645, 52.162369787693024, 45.71264907717705, 41.50226220488548, 42.45625041425228, 42.89203003048897, 49.64259199798107, 48.56113202869892, 53.042417764663696, 53.32696549594402, 49.70440328121185, 44.40725952386856, 39.3494763225317, 41.163449585437775, 43.092275485396385, 39.17542666196823, 43.0645065754652, 45.402380526065826, 44.55713488161564, 44.724717289209366, 43.82676847279072, 41.54504030942917, 40.49680955708027, 39.978779554367065, 37.0633327960968, 35.079713836312294, 38.84408824145794, 46.846800819039345, 43.41927833855152, 42.61496029794216, 39.97402220964432, 43.124414160847664, 49.400655180215836, 45.47374829649925, 42.97941394150257, 38.76188725233078, 39.076301380991936, 44.47500988841057, 48.1381843239069, 47.25766137242317, 38.03500525653362, 40.2509019523859, 40.44740840792656, 40.610385462641716, 38.77460137009621, 40.29928855597973, 39.894545674324036, 40.49017891287804, 41.08059123158455, 47.970579117536545, 52.742902636528015, 54.6622708439827, 52.576372772455215, 51.49493560194969, 55.11187791824341, 55.00746712088585, 55.585989877581596, 54.55475941300392, 61.58415421843529, 51.73984386026859, 53.62795874476433, 52.66832023859024, 57.57669925689697, 54.454410597682, 58.63471068441868, 52.009321600198746, 40.22970288991928, 53.99123825132847, 51.55213013291359, 56.76749087870121, 56.08326159417629, 56.32230296730995, 58.583155050873756, 59.65331822633743, 59.22815904021263, 53.64562399685383, 50.448319762945175, 57.345094084739685, 58.35738256573677, 62.38529942929745, 71.21499583125114, 62.63949438929558, 67.55147561430931, 62.88779206573963, 78.07529211044312, 21.058475710451603, 0.006857627749923267, 0.9875267534516752, 0.40729245578404516, 0.038238802808336914, 5.03464006818831, 71.0065846145153, 67.14412227272987, 74.04766783118248, 63.68150867521763, 45.94310291111469, 33.116260394454, 24.267620109021664, 37.06087052822113, 50.97747556865215, 61.2190318107605, 4.407502245157957, 0.26141765993088484, 0.05088177458674181, 0.0366551338811405, 0.10835557943210006, 0.052259716467233375, 0.037120401102583855, 0.01959138135134708, 0.03369859936356079, 0.03842278121737763, 0.03134993945423048, 0.3587658831384033, 46.76291272044182, 73.45038548111916, 51.12323194742203, 44.12392392754555, 21.716683991253376, 49.934948310256004, 55.328131914138794, 80.60996890068054, 60.746751353144646, 78.76301720738411, 21.970677562057972, 0.1893681229557842, 1.0220141778700054, 2.553449207916856, 6.374988695606589, 1.6078749345615506, 0.10502652759896591, 38.76137048006058, 67.64162957668304, 56.90977044403553, 64.74276512861252, 63.088299706578255, 65.47212839126587, 62.28845402598381, 64.48219791054726, 61.56310714781284, 62.69779086112976, 60.17741650342941, 62.51141846179962, 58.98713417351246, 55.879182144999504, 55.27109697461128, 53.02594944834709, 51.49660751223564, 55.113101452589035, 56.40266865491867, 57.625340446829796, 57.745322808623314, 58.575323671102524, 51.90191276371479, 60.03093436360359, 54.937482476234436, 55.48100911080837, 54.34802770614624, 58.23469094932079, 54.355946481227875, 57.96827584505081, 50.57237170636654, 54.32685524225235, 52.983547523617744, 62.1371803432703, 49.399522840976715, 48.63903544843197, 55.765492245554924, 50.01739628612995, 40.8680534362793, 41.25090189278126, 42.10471607744694, 42.240091413259506, 42.068902999162674, 40.86472101509571, 42.611635476350784, 39.822478741407394, 47.31772854924202, 54.03492450714111, 47.821953892707825, 43.69073957204819, 42.71921910345554, 42.7399317920208, 48.691290244460106, 50.52425868809223, 54.42946873605251, 54.871727004647255, 51.432022377848625, 45.04266142845154, 40.19952870905399, 42.69806943833828, 45.476700738072395, 44.57619085907936, 46.07260376214981, 49.365393072366714, 45.07328398525715, 46.973242834210396, 45.10575324296951, 43.87995041906834, 44.615708738565445, 40.81415332853794, 37.78423771262169, 34.69727575778961, 38.7753689289093, 48.239308297634125, 45.741622522473335, 42.72991552948952, 40.28459474444389, 42.17766836285591, 50.745965391397476, 49.51289735734463, 45.29434472322464, 40.02960562705994, 39.19823303818703, 46.17391012609005, 49.9828827381134, 48.59923638403416, 39.98682752251625, 41.57417334616184, 41.21268354356289, 42.5240083783865, 39.775357469916344, 41.42946571111679, 42.18650668859482, 41.39673426747322, 42.03525960445404, 51.15195080637932, 55.12116841971874, 56.165071204304695, 54.3084642291069, 53.42737130820751, 58.039666414260864, 57.68733412027359, 57.92294427752495, 57.003253027796745, 63.5361360758543, 54.6424625068903, 56.631260588765144, 56.04761190712452, 58.45249526202679, 55.33262327313423, 61.955903470516205, 52.855957970023155, 43.20703312754631, 53.58048789203167, 54.889255464076996, 59.90393377840519, 57.27660275995731, 58.68233732879162, 61.72128885984421, 61.75628498196602, 59.15191613137722, 57.73980550467968, 51.66409492492676, 58.12305673956871, 54.51536312699318, 63.206370770931244, 73.5810224711895, 62.51326136291027, 70.82634508609772, 64.01294589042664, 81.79302781820297, 22.972811087965965, 0.05094230415124912, 1.4450877509079874, 0.6719659175723791, 0.12865740020060912, 6.131735248491168, 76.81945949792862, 75.04718899726868, 77.88733899593353, 71.92634806036949, 51.41597963869572, 32.12280750274658, 24.366741590201855, 44.018859565258026, 55.989330634474754, 76.43144711852074, 6.532211909070611, 0.19513426901539788, 0.12116797981434502, 0.04028020615805872, 0.023931850591907278, 0.2385457669151947, 0.10146801854716614, 0.1949521608185023, 0.12442052364349365, 0.19158812414389104, 0.4064144060248509, 0.7281574804801494, 59.043135568499565, 82.39541709423065, 61.564258486032486, 54.08226236701012, 33.24195384979248, 54.072690680623055, 61.319589614868164, 86.20354235172272, 66.26873284578323, 85.65751925110817, 23.79711225628853, 0.24592085945187137, 2.5575028778985143, 5.375850833952427, 16.56443975865841, 3.2133716717362404, 0.1309591712197289, 41.63542225956917, 70.3303425014019, 56.34219489991665, 68.76978144049644, 64.72847789525986, 69.04988721013069, 64.90151301026344, 66.10316053032875, 64.10104036331177, 65.61919569969177, 63.00706386566162, 66.95287853479385, 61.03888727724552, 58.92374977469444, 56.61373592913151, 55.78044444322586, 53.785722479224205, 57.796080484986305, 59.699858129024506, 59.78427439928055, 59.48479346930981, 55.17111673951149, 53.573332875967026, 62.968537732958794, 59.19504761695862, 59.890106320381165, 56.524638310074806, 60.63358582556248, 57.82908171415329, 58.82548324763775, 53.22890415787697, 58.95958565175533, 56.358211040496826, 61.09879486262798, 54.953380823135376, 54.10059258341789, 57.055732011795044, 53.57397124171257, 43.83458085358143, 44.834968373179436, 44.28211323916912, 44.055105820298195, 43.79445120692253, 44.49847362935543, 43.81848871707916, 42.94078141450882, 49.56512175500393, 55.49439199268818, 50.14130383729935, 45.04600144922733, 44.61451180279255, 43.79914775490761, 48.914843648672104, 50.96888042986393, 55.964977741241455, 54.85386796295643, 52.55916729569435, 45.699972957372665, 40.34355238080025, 43.875044882297516, 48.34466904401779, 46.778070107102394, 47.15425752103329, 50.79959571361542, 47.771959975361824, 49.50317367911339, 47.57268346846104, 47.78901346027851, 45.75286231935024, 42.59087339043617, 38.48067194223404, 35.62932014465332, 39.633309692144394, 49.76602077484131, 47.43771471083164, 43.53325702250004, 40.77281914651394, 43.802746161818504, 53.97911690175533, 49.913509860634804, 46.34138233959675, 40.2572476118803, 40.019501969218254, 47.84170903265476, 53.366103395819664, 50.92378444969654, 42.148276939988136, 44.98032957315445, 44.93786685168743, 44.94889385998249, 43.21313560009003, 44.133560210466385, 44.786311984062195, 43.210851922631264, 44.09242741763592, 55.77735520899296, 57.99849562346935, 60.31301602721214, 55.89753895998001, 54.89375822246075, 58.86761538684368, 61.58571593463421, 61.49434603750706, 59.82953377068043, 66.26921162009239, 55.20943768322468, 59.69351626932621, 57.36989535391331, 60.765222162008286, 58.739144280552864, 64.84760150313377, 50.242515206336975, 44.71345089375973, 56.03587433695793, 54.9593199044466, 62.460064217448235, 61.48075416684151, 61.383946761488914, 61.87977455556393, 64.06424313783646, 60.57219251990318, 57.09178827702999, 55.861516892910004, 58.64946909248829, 57.96810105443001, 71.03664860129356, 75.86190328001976, 66.75419479608536, 74.80160817503929, 68.36609110236168, 86.05480313301086, 26.052830815315247, 0.12379463340039365, 3.7224120693281293, 1.8068450829014182, 0.2518382255220786, 7.428423268720508, 83.02987664937973, 79.52990725636482, 84.52407047152519, 78.00935044884682, 64.0774816274643, 49.48616199195385, 37.796590849757195, 53.80116105079651, 66.98326170444489, 91.85098171234131, 9.688978493213654, 0.4651029099477455, 0.2947662438964471, 0.14709507959196344, 0.3189179260516539], [0.053919236597721465, 0.007888698619353818, 0.0230754288713797, 0.09792395168915391, 0.08305774666951038, 0.18117436731699854, 0.23579878150485456, 45.717372223734856, 58.918433859944344, 37.386551052331924, 34.39163535833359, 51.79868370294571, 28.079290576279163, 46.55200503766537, 72.52720981836319, 56.73694811761379, 67.52060607075691, 26.00435681641102, 0.0500102223304566, 0.5971135559957474, 1.9868411868810654, 7.027765167877078, 1.939979251474142, 0.12485718849347904, 9.571548644453287, 64.66018036007881, 62.6654963940382, 66.07171341776848, 59.032017365098, 65.9319569170475, 60.08890025317669, 59.576056972146034, 59.37557972967625, 61.225305274128914, 55.91221757233143, 57.365331798791885, 51.35508030653, 50.73806941509247, 46.414311826229095, 50.21283119916916, 52.22342871129513, 55.278688967227936, 54.87334191799164, 55.36221228539944, 54.51063998043537, 48.541559278964996, 45.77076695859432, 53.01151402294636, 51.5284726023674, 54.59423929452896, 55.48833891749382, 51.79127790033817, 50.85733741521835, 48.98909166455269, 54.25910107791424, 49.97363023459911, 55.50498962402344, 57.72923827171326, 37.45780102908611, 55.460292622447014, 52.204201743006706, 46.878487318754196, 36.97338402271271, 41.317246332764626, 37.73091897368431, 39.628122970461845, 37.792810052633286, 41.58827818930149, 40.27425169944763, 41.253763139247894, 41.550945192575455, 51.369595527648926, 45.04519209265709, 44.08129021525383, 43.25149454176426, 43.324739411473274, 45.36309823393822, 52.91460022330284, 49.04871806502342, 54.24491263926029, 53.83049167692661, 51.5619146078825, 39.410254061222076, 40.85774838924408, 45.38545623421669, 42.56926015019417, 41.74510337412357, 47.330408468842506, 45.6975144892931, 45.19258998334408, 42.106805965304375, 42.14985765516758, 43.76776523888111, 38.89299921691418, 37.29631729424, 35.97148798406124, 38.84268991649151, 49.61459890007973, 41.9549623131752, 41.210099682211876, 45.16601420938969, 43.143382743000984, 48.921155110001564, 43.365351632237434, 39.38267894089222, 41.36999890208244, 41.871545389294624, 43.46543446183205, 47.35237888991833, 43.59973445534706, 38.8747563958168, 39.047179743647575, 39.23487067222595, 39.04743053019047, 38.29562567174435, 39.03640352189541, 37.13130734860897, 38.92400935292244, 42.06774406135082, 48.08937594294548, 49.80240382254124, 51.07068456709385, 52.880550250411034, 52.423149794340134, 52.90804177522659, 53.820589408278465, 57.79095835983753, 50.76568253338337, 40.38824178278446, 53.76168876886368, 55.47887742519379, 54.27506402134895, 53.61573480069637, 54.57640305161476, 57.11378909647465, 51.670163199305534, 45.59946075081825, 55.61164230108261, 55.151551589369774, 58.90204533934593, 57.16711923480034, 60.55401049554348, 63.04924540221691, 56.90111830830574, 61.49338088929653, 52.521226331591606, 56.47733844816685, 54.574081376194954, 46.03247791528702, 48.37644673883915, 72.7114999294281, 62.26192004978657, 68.29809755086899, 62.13073968887329, 76.24980166554451, 18.06259296834469, 0.07918300107121468, 0.9390575636643916, 0.777607848867774, 0.4645081824855879, 9.436306301504374, 76.13491863012314, 66.60237774252892, 71.88119888305664, 64.02173101902008, 44.72437910735607, 36.35241374373436, 17.64692947268486, 34.24898341298103, 55.998282954096794, 63.16747225821018, 3.7899722065776587, 0.2913249348057434, 0.16605730896117166, 0.01909188627905678, 0.06880169836222194, 0.0843124437960796, 0.024602009943919256, 0.08143870698404498, 0.07102540286723524, 0.06146648513094988, 0.17079742101486772, 0.22732933284714818, 54.86583352088928, 68.48726660013199, 46.96912005543709, 53.060132414102554, 38.528363183140755, 31.570946015417576, 55.05740404129028, 77.57144674658775, 60.212199836969376, 75.7754199206829, 28.41229520738125, 0.0719839459634386, 0.1970121994963847, 3.5812389571219683, 7.075001858174801, 5.597596485167742, 0.37306047859601676, 11.35786984115839, 67.37295359373093, 62.06342250108719, 66.79451063275337, 59.078781455755234, 66.5502293407917, 61.00204065442085, 61.998487785458565, 59.23355475068092, 63.25805179774761, 58.34146901965141, 58.36477316915989, 53.47502835094929, 53.24761055409908, 48.49256090819836, 51.99230991303921, 55.15693590044975, 57.101584151387215, 55.83703100681305, 56.39307036995888, 57.173358500003815, 49.90110732614994, 47.411340326070786, 53.63332785665989, 53.966205194592476, 55.15100821852684, 55.24534195661545, 52.760997265577316, 51.90383926033974, 50.05429990589619, 55.58732360601425, 53.345223516225815, 54.09835830330849, 58.73852111399174, 43.52106727659702, 57.48813360929489, 54.17747385799885, 47.77885280549526, 37.722673416137695, 41.900606229901314, 39.69870798289776, 41.125246435403824, 41.69814929366112, 43.197013065218925, 42.56413422524929, 43.441362753510475, 43.77113185822964, 51.86606548726559, 48.212287947535515, 44.88243542611599, 44.07171092927456, 42.53102660179138, 46.216969415545464, 53.37440215051174, 50.87543964385986, 56.35866701602936, 52.150947600603104, 51.52463860809803, 41.50256618857384, 42.27071776986122, 46.03705666959286, 45.207378789782524, 45.102633610367775, 50.16716144979, 44.293915405869484, 47.502117455005646, 43.86104643344879, 44.069966822862625, 43.793030083179474, 39.07239519059658, 39.88641031086445, 36.5181190520525, 38.97903420031071, 50.29705747961998, 42.34030343592167, 40.80054245889187, 44.928093776106834, 42.82576538622379, 50.854688957333565, 45.106482803821564, 40.170984640717506, 42.38076366484165, 45.61445854604244, 46.19631752371788, 48.5850365459919, 45.46673767268658, 41.42857275903225, 40.13986811041832, 41.802943870425224, 40.870975479483604, 39.715693071484566, 41.34105585515499, 39.34571452438831, 41.60018675029278, 43.2239194214344, 49.7159318625927, 53.229629918932915, 52.57574200630188, 54.288769885897636, 54.357352405786514, 55.446795746684074, 55.89112490415573, 58.516567423939705, 51.554527804255486, 42.48666398227215, 56.87000937759876, 57.989835888147354, 56.95537559688091, 57.06268563866615, 55.68542294204235, 58.80669325590134, 52.830172553658485, 48.17932851612568, 55.9138248860836, 57.19722121953964, 58.11415381729603, 61.02385528385639, 62.73662097752094, 63.78237426280975, 56.3813403993845, 64.30729329586029, 55.89943505823612, 58.113507851958275, 57.04826541244984, 50.45418664813042, 49.55062173306942, 74.88493010401726, 64.69212144613266, 72.04005315899849, 63.15486453473568, 80.3931525349617, 19.78124264627695, 0.15127031336305663, 1.752126831561327, 1.1934671527706087, 0.2920515864389017, 10.760373752564192, 84.6196885406971, 72.22719311714172, 77.60360062122345, 71.01397901773453, 52.838395312428474, 29.17954433709383, 21.024501733481884, 41.060212925076485, 61.867030039429665, 74.78516265749931, 5.873909583315253, 0.29687910864595324, 0.16595284425420687, 0.01646628097660141, 0.026687212994147558, 0.18087528180330992, 0.11188691103598103, 0.14115053607383743, 0.24562821578001603, 0.1478053446044214, 0.24721066758502275, 0.8649796480312943, 69.27021458745003, 75.3078930079937, 51.6617276519537, 49.187140837311745, 64.11743268370628, 45.31066484749317, 58.041672706604004, 84.32861655950546, 65.75210496783257, 85.06206840276718, 29.728189297020435, 0.16253086068900302, 1.1222224007360637, 11.113219019025564, 16.806786954402924, 7.697500605136156, 0.2941036247648299, 13.787221033126116, 70.91262325644493, 62.63594537973404, 70.25481775403023, 59.34050761163235, 71.21669813990593, 62.14157670736313, 64.4182625412941, 63.07152360677719, 66.03336587548256, 60.11443108320236, 62.37057521939278, 54.69312138855457, 56.80007413029671, 50.9325847774744, 56.051423102617264, 59.35516722500324, 59.264245703816414, 60.04871740937233, 60.34108132123947, 55.71275107562542, 48.87858599424362, 49.19510900974274, 58.850383311510086, 55.92905826866627, 56.87714919447899, 57.88271963596344, 55.370511040091515, 55.11866435408592, 52.836860194802284, 56.80678457021713, 58.26017238199711, 55.07497809827328, 60.48600174486637, 48.86354260146618, 60.06221428513527, 57.25688561797142, 49.90927308797836, 40.01323230564594, 44.5974887162447, 42.65736602246761, 44.22455012798309, 45.27699865400791, 47.23940335214138, 45.04267282783985, 45.522853061556816, 47.44748018682003, 55.10259121656418, 50.9314676374197, 45.8426059037447, 44.4243548065424, 44.33112680912018, 47.47389256954193, 54.91379454731941, 52.49424397945404, 58.12671974301338, 54.6211114525795, 54.50948104262352, 41.384183540940285, 42.29696676135063, 50.40115289390087, 48.226274996995926, 45.39186269044876, 50.43961443006992, 47.15688318014145, 48.11800740659237, 45.929127261042595, 48.99833656847477, 45.455494076013565, 38.7133714556694, 39.803312569856644, 36.45488664507866, 40.08938021957874, 51.612717881798744, 43.30105908215046, 41.811413615942, 48.066330179572105, 46.77453629672527, 54.25166867673397, 46.05975665152073, 42.169703990221024, 43.74711714684963, 47.21540004014969, 48.55103597044945, 50.11327654123306, 46.78722761571407, 44.29078057408333, 41.776584684848785, 43.08403752744198, 42.15229332447052, 41.7081693559885, 45.041388496756554, 40.34393236041069, 43.65905687212944, 46.224542409181595, 53.343517407774925, 57.281774282455444, 56.1793128401041, 57.37139247357845, 59.033746272325516, 57.352013513445854, 57.631860896945, 60.931691229343414, 55.903485640883446, 45.62009744346142, 63.60858678817749, 58.61221969127655, 59.1395477950573, 58.72711792588234, 57.773004323244095, 60.11461727321148, 53.3849123865366, 49.83920864760876, 58.73606264591217, 59.55208405852318, 60.33706113696098, 62.766703963279724, 64.3891029059887, 67.43123486638069, 58.69668535888195, 61.036489605903625, 57.98664025962353, 62.14800216257572, 57.4346324801445, 52.70120367407799, 53.292520344257355, 79.01480689644814, 68.87997552752495, 76.8794658780098, 67.15659320354462, 84.69994783401489, 22.62876234948635, 0.3775369352661073, 4.274129876866937, 2.4943398172035813, 0.6207781517878175, 11.848015990108252, 91.66981503367424, 77.22131833434105, 84.95062798261642, 78.44808250665665, 66.84402197599411, 48.76763194799423, 28.94350290298462, 53.60810860991478, 69.85528439283371, 93.30433532595634, 9.710030313581228, 0.7010680809617043, 0.4425967769930139, 0.25757075229194015, 0.2460643759695813], [0.06306976531050168, 0.04179024290351663, 0.06407708977349102, 0.08764257174334489, 0.021467623446369544, 0.013994465371069964, 1.42589331837371, 55.81773944199085, 54.377255737781525, 34.74479220807552, 17.560968585312366, 38.0895209312439, 36.67150542140007, 49.603457897901535, 71.7640283703804, 57.27445587515831, 63.815356492996216, 32.37780421972275, 0.31259188894182444, 0.8884792495518923, 2.496708990074694, 3.1984653091058135, 0.9563664067536592, 0.19763588556088507, 0.7524917309638113, 52.416230365633965, 65.73821291327477, 62.83984623849392, 59.16336491703987, 59.04825009405613, 58.81354808807373, 57.01409764587879, 56.7475875467062, 56.33796192705631, 54.85640622675419, 55.21170996129513, 50.10707147419453, 51.36855438351631, 51.839960888028145, 55.14604568481445, 53.416329100728035, 54.23279128968716, 60.24941883981228, 57.55659833550453, 42.460566982626915, 39.892436787486076, 42.2034727782011, 45.789009779691696, 49.81488235294819, 50.294883996248245, 48.802381083369255, 52.16755270957947, 61.26725122332573, 57.79511533677578, 53.05856689810753, 48.38254541158676, 54.98517371714115, 38.92287701368332, 47.848613262176514, 56.381629183888435, 47.41463854908943, 39.40643526613712, 39.226400926709175, 39.31549094617367, 38.11977110803127, 42.63232536613941, 41.9714230298996, 42.873471826314926, 41.41194865107536, 40.506829619407654, 39.93578106164932, 46.752182096242905, 42.43556812405586, 43.854685574769974, 44.13591228425503, 46.77042871713638, 43.448779955506325, 43.30104008316994, 46.04773409664631, 55.277256444096565, 53.207925483584404, 51.592445969581604, 39.61451210081577, 40.56067653000355, 44.503854140639305, 41.125075444579124, 39.33314859867096, 45.89554086327553, 42.22226656973362, 45.867904946208, 41.262107491493225, 45.43152496218681, 40.021363869309425, 37.85120531916618, 36.63314647972584, 36.68342538177967, 42.584751918911934, 45.35180144011974, 39.56519074738026, 46.472794488072395, 48.79462569952011, 47.880231365561485, 48.35536926984787, 42.78948113322258, 39.15830858051777, 41.88430890440941, 40.49818128347397, 47.376165613532066, 45.56839741766453, 42.31615573167801, 40.16964331269264, 39.061311185359955, 40.611320212483406, 40.88283844292164, 38.52159574627876, 40.452009961009026, 37.475914657115936, 38.447233736515045, 43.453487902879715, 50.29475100338459, 50.29196575284004, 50.34101352095604, 47.92219631373882, 51.37552320957184, 53.8072445243597, 53.02457772195339, 55.511559471488, 49.480644688010216, 29.18438907712698, 42.56723865866661, 57.02483206987381, 54.571793898940086, 57.213894724845886, 52.26822830736637, 57.02159844338894, 53.50867934525013, 51.8144566565752, 55.08510075509548, 53.38974952697754, 60.18522508442402, 54.344927072525024, 54.503009989857674, 55.41224040091038, 64.24931600689888, 52.3324828594923, 56.310857981443405, 65.23219406604767, 64.63104352355003, 65.58768019080162, 64.5182503759861, 72.14847654104233, 64.2428183555603, 69.00920659303665, 63.169558346271515, 75.45712620019913, 12.648371793329716, 0.2580805483739823, 0.8666857564821839, 0.0875777896726504, 0.266628545941785, 12.826090157032013, 75.45079573988914, 67.23003566265106, 75.1879334449768, 64.77086082100868, 49.94999550282955, 35.105259865522385, 18.597271777689457, 28.975569382309914, 52.89902105927467, 70.0616817176342, 5.184206692501903, 0.2670371427666396, 0.06622030094149522, 0.06959212274523452, 0.06180947239045054, 0.02347729812754551, 0.04216264889691956, 0.14824330079136416, 0.014845906353002647, 0.06388540045008995, 0.10554921478615142, 1.7738259234465659, 67.08001971244812, 63.962249010801315, 44.26079258322716, 27.015113979578018, 50.60542993247509, 35.4145784676075, 56.89317673444748, 78.28409850597382, 63.87050673365593, 70.96002951264381, 35.23615904152393, 0.18504775478504598, 0.046662832028232515, 2.4342978140339255, 3.981821774505079, 5.486520370468497, 0.6979771249461919, 1.041049612686038, 53.24614003300667, 67.62529045343399, 67.03105553984642, 59.415709376335144, 61.9195432215929, 60.1298962533474, 59.813179448246956, 58.527621030807495, 58.393283039331436, 58.2269773632288, 56.94028280675411, 53.01323913037777, 51.45456276834011, 52.209293469786644, 56.95466123521328, 56.36541925370693, 57.28666841983795, 63.242370039224625, 58.19905266165733, 46.40184849500656, 43.233046531677246, 45.531968772411346, 48.63617800176144, 50.852519273757935, 51.75047568976879, 52.14226886630058, 53.86014148592949, 60.97758136689663, 57.08689033985138, 53.759929463267326, 49.3056982755661, 55.239824652671814, 44.373794719576836, 50.23872680962086, 58.09725992381573, 49.43399839103222, 42.88702949881554, 40.54182194173336, 42.89821609854698, 40.071768164634705, 43.4445583820343, 44.55908037722111, 45.5963297188282, 43.60554814338684, 41.37878783047199, 42.9236975312233, 49.27956707775593, 45.76038211584091, 45.814426615834236, 43.29821303486824, 47.79950089752674, 42.73909583687782, 43.630136623978615, 46.99626199901104, 57.11729630827904, 54.53425571322441, 52.14912749826908, 41.21263414621353, 40.94930447638035, 46.27208925783634, 43.73557336628437, 41.57717518508434, 47.52032607793808, 41.85945063829422, 46.29076145589352, 43.74325655400753, 47.18701556324959, 42.10353434085846, 39.04930002987385, 37.4848023802042, 37.474387139081955, 43.719705417752266, 46.5920814871788, 40.304498076438904, 47.16408759355545, 50.06507232785225, 49.84157592058182, 50.30958540737629, 44.37259778380394, 40.23808903992176, 43.31220008432865, 42.6515257358551, 49.276048466563225, 48.24433542788029, 44.53199163079262, 41.35570786893368, 43.872115239501, 43.134654611349106, 41.095440834760666, 39.90849852561951, 40.881052538752556, 39.18470196425915, 41.31953381001949, 45.03033109009266, 51.89187750220299, 52.49088495969772, 52.87064418196678, 52.52338081598282, 52.337965965270996, 56.08473591506481, 56.28077879548073, 55.552893653512, 52.58360758423805, 36.41656190156937, 46.057970747351646, 57.80512019991875, 57.640106454491615, 56.34602129459381, 55.30685305595398, 58.42202849686146, 52.8973301500082, 54.70002941787243, 55.891702473163605, 56.61499746143818, 62.12564796209335, 57.650301307439804, 55.845937728881836, 56.09160594642162, 68.39630708098412, 58.1217610090971, 57.75240942835808, 66.96936205029488, 65.06889402866364, 67.8774981200695, 64.32515993714333, 74.3218307197094, 65.11910453438759, 70.35406082868576, 65.75609475374222, 78.66039231419563, 14.369967263191938, 0.3921701875515282, 2.016460597515106, 1.1150957643985748, 0.4072417819406837, 15.273673720657825, 83.05244743824005, 73.00510257482529, 78.9153890311718, 69.93015557527542, 58.818955197930336, 30.963387116789818, 18.42723850160837, 39.18329983949661, 59.45901185274124, 82.96830475330353, 8.170950450003147, 0.2883503178600222, 0.10570856131380424, 0.09422408576938324, 0.04756373993586749, 0.20278302108636126, 0.11096293717855588, 0.3012717916863039, 0.21737107657827437, 0.1890076618292369, 0.412502748076804, 3.4335784055292606, 81.08713209629059, 72.81141936779022, 50.272450000047684, 27.68813766539097, 47.5850860029459, 52.49975748360157, 61.97336733341217, 84.71742689609528, 68.92901569604874, 78.59895721077919, 39.874744936823845, 0.2763867488829419, 2.6869935169816017, 8.5629241168499, 13.294218387454748, 10.164519175887108, 0.9023602015804499, 1.6721106064505875, 57.609989270567894, 70.16170755028725, 69.10500705242157, 62.09282532334328, 64.45966511964798, 63.01319293677807, 60.72149030864239, 58.65649491548538, 60.40305979549885, 61.81020028889179, 59.771100506186485, 55.24506077170372, 54.99588534235954, 55.93604989349842, 59.58501309156418, 58.28612878918648, 60.86954936385155, 64.73133534193039, 57.92262889444828, 47.53147467970848, 45.34308470785618, 47.160747572779655, 49.383658692240715, 52.34031803905964, 54.1684303432703, 54.14586715400219, 54.6326894313097, 61.83812119066715, 57.18268319964409, 55.651194378733635, 51.702955439686775, 54.43024009466171, 50.75823113322258, 52.09731347858906, 61.23664766550064, 50.38533054292202, 43.75464454293251, 42.799466997385025, 43.78750137984753, 42.00258135795593, 46.1298742890358, 46.80118426680565, 48.0565495043993, 47.253728583455086, 44.42580632865429, 46.02650463581085, 52.49044418334961, 47.286399230360985, 46.0346931964159, 47.07139536738396, 51.23480536043644, 45.30874975025654, 43.98511737585068, 48.198669478297234, 58.538750633597374, 56.21762238442898, 55.74382960796356, 39.69066381454468, 42.089140713214874, 49.44606274366379, 47.40421570837498, 43.42926800251007, 49.45012092590332, 42.47610814869404, 48.0780753493309, 46.63986012339592, 51.53400130569935, 42.93056756258011, 38.825184255838394, 37.80930116772652, 38.019433692097664, 44.75126266479492, 48.217972442507744, 40.025403052568436, 48.5432767868042, 51.23638227581978, 49.61757034063339, 51.4521536976099, 46.18516132235527, 42.54714533686638, 45.51105089485645, 43.90259340405464, 54.61440101265907, 49.496980011463165, 47.188368290662766, 44.63260643184185, 45.50223536789417, 45.74461296200752, 45.14713302254677, 42.083163633942604, 44.54591408371925, 41.6291905939579, 42.93369859457016, 47.70506836473942, 55.08840657770634, 56.29290774464607, 56.683165803551674, 55.10199464857578, 56.59294344484806, 58.79303678870201, 60.01326911151409, 58.623216301202774, 55.333330035209656, 34.55773204565048, 46.676163375377655, 62.16357372701168, 58.860783353447914, 61.190286353230476, 57.12992683053017, 59.588467106223106, 55.631420239806175, 58.74374583363533, 56.8426888436079, 58.512220457196236, 65.33122435212135, 59.45376813411713, 56.82566575706005, 59.05467934906483, 62.890607714653015, 58.69352772831917, 63.050347343087196, 67.82750800251961, 67.12212145328522, 69.97401282191277, 63.99194821715355, 78.54538008570671, 67.73880556225777, 76.25449061393738, 68.54008376598358, 84.0584434568882, 16.361986622214317, 0.47411718405783176, 3.7159118056297302, 2.9769718693569303, 0.5919936869759113, 17.153765335679054, 90.88514193892479, 77.42796644568443, 88.16302120685577, 79.9548764526844, 71.45130515098572, 50.190480798482895, 31.983560174703598, 49.939451068639755, 68.72539982199669, 95.766322016716, 11.438013240695, 0.5600338394287974, 0.41551028669346124, 0.23538080393336713, 0.19453770102700219], [0.051300045306561515, 0.10543931755819358, 0.03973755148763303, 0.06156101248052437, 0.05654479180520866, 0.15965264872647822, 1.4640242722816765, 53.538671135902405, 52.096230536699295, 36.96189343929291, 25.85794497281313, 29.970542192459106, 38.94376069307327, 44.512479677796364, 68.66996839642525, 58.25643718242645, 61.79840952157974, 39.65075455605984, 0.12246834870893508, 0.279885470517911, 1.285700078587979, 3.2614075066521764, 6.725915540009737, 0.67624781280756, 0.25310058903414756, 31.515831872820854, 74.08177480101585, 59.28971953690052, 61.459391713142395, 56.83826208114624, 58.06810408830643, 53.815657272934914, 52.865408062934875, 52.88387507200241, 53.63050080835819, 50.9206648170948, 50.81782713532448, 52.731909826397896, 53.13063383102417, 54.39907796680927, 54.98716861009598, 61.407220512628555, 48.477593511343, 42.380379885435104, 40.44431537389755, 51.57697319984436, 54.17420603334904, 52.05924712121487, 49.279548078775406, 45.41692614555359, 43.334729075431824, 45.32675698399544, 46.89737610518932, 57.22544610500336, 61.414595916867256, 52.67275080084801, 42.19635955989361, 47.08757869899273, 58.42905431985855, 50.06844274699688, 48.00584502518177, 39.542053788900375, 38.898022547364235, 36.195637956261635, 38.8092403113842, 39.35723930597305, 39.2109015583992, 39.580462127923965, 36.718991473317146, 40.41615128517151, 38.64101193845272, 42.024749368429184, 44.175441563129425, 43.150492161512375, 48.03470827639103, 45.43622151017189, 45.43399102985859, 42.4742728471756, 48.06661896407604, 53.80515083670616, 54.41624544560909, 53.61697353422642, 46.40838034451008, 40.53323820233345, 42.78457559645176, 40.33899262547493, 39.683296009898186, 42.94248752295971, 42.547209933400154, 42.73720733821392, 41.602105647325516, 41.31519444286823, 37.86529116332531, 37.93441705405712, 36.4516644179821, 39.28297609090805, 45.95170184969902, 46.27018176019192, 46.78398258984089, 48.9082358032465, 46.89304433763027, 43.4358948469162, 48.896809816360474, 42.20634162425995, 41.65297731757164, 42.46543072164059, 41.63770213723183, 46.62828594446182, 43.303962126374245, 40.04277192056179, 37.71637715399265, 35.938220769166946, 38.52180853486061, 38.92625883221626, 36.38805203139782, 38.33139695227146, 40.02660758793354, 40.43954662978649, 44.6991066634655, 50.503861382603645, 50.67769065499306, 50.35017102956772, 49.39569644629955, 50.20713530480862, 49.37873035669327, 52.0045680552721, 51.69116087257862, 56.89042568206787, 57.59210363030434, 48.971544206142426, 48.73035594820976, 52.01626382768154, 52.87263907492161, 51.93791963160038, 56.045628413558006, 52.361425906419754, 52.092654928565025, 50.80130182206631, 53.75855393707752, 55.74435777962208, 57.052988559007645, 60.934263691306114, 65.92562645673752, 50.36784008145332, 53.82657788693905, 63.34324702620506, 62.63221018016338, 66.5088039636612, 62.087456211447716, 58.925269693136215, 65.41432589292526, 66.82195276021957, 74.0000867843628, 65.96249967813492, 65.81716507673264, 6.680125622078776, 0.03938496454793494, 0.9444143855944276, 1.3085053861141205, 0.29545130557380617, 14.582716897130013, 76.44178256392479, 66.12179473042488, 74.77763146162033, 59.37623329460621, 55.70344537496567, 56.222619116306305, 24.596315771341324, 29.522952809929848, 55.39877772331238, 61.07382260262966, 2.301820060238242, 0.044612070196308196, 0.10476123206899501, 0.07822755273082294, 0.06905456291860901, 0.06674130345345475, 0.11495879385620356, 0.037200122606009245, 0.09881298523396254, 0.04541575304756407, 0.1608780087553896, 1.9879061984829605, 66.10053107142448, 58.95594544708729, 44.68008488416672, 31.301202289760113, 25.0762927159667, 36.712129041552544, 53.20254497230053, 73.2764308154583, 63.773604333400726, 70.45026406645775, 41.9676498323679, 0.07319508644286543, 0.13070560904452577, 2.026866814121604, 2.054170724004507, 2.9526211135089397, 1.3848168100230396, 0.30648546817246825, 35.11160172522068, 73.93333956599236, 60.840769708156586, 63.176264986395836, 58.07491712272167, 60.99609397351742, 56.29828825592995, 56.33597083389759, 55.85690774023533, 55.965106934309006, 52.71491713821888, 52.3808428645134, 54.11094702780247, 56.147261559963226, 58.00242841243744, 59.20127548277378, 62.12402164936066, 50.791319757699966, 44.99320708215237, 45.50116382539272, 54.47900667786598, 52.74317242205143, 52.21059300005436, 49.44827042520046, 47.38498114049435, 45.01885950565338, 48.33243370056152, 47.36094743013382, 60.418517366051674, 61.39588192105293, 53.111121878027916, 46.95282652974129, 48.46982292830944, 60.24147726595402, 52.234341725707054, 49.13115084171295, 40.82640387117863, 41.09897084534168, 38.182277753949165, 42.788816168904305, 41.401651203632355, 40.62505267560482, 40.180054754018784, 38.23990546166897, 41.17287687957287, 41.59863643348217, 45.396179258823395, 43.93379732966423, 45.68000502884388, 48.515378683805466, 47.05130584537983, 46.91928192973137, 44.415254294872284, 50.51405243575573, 57.58304871618748, 55.544990077614784, 54.389612674713135, 47.28106051683426, 42.79107704758644, 42.87368841469288, 41.082947105169296, 40.4133166372776, 44.82367157936096, 42.09159918129444, 42.0291381329298, 44.77108620107174, 43.50544631481171, 38.7378915399313, 39.24753539264202, 35.84718905389309, 40.01545898616314, 46.90368376672268, 46.44734725356102, 46.409071907401085, 50.277389734983444, 49.348852559924126, 46.773320361971855, 49.29776810109615, 42.75412783026695, 41.44430011510849, 45.13191103935242, 45.61418876051903, 47.724496722221375, 44.29772660136223, 41.815293207764626, 40.412305891513824, 40.20011007785797, 40.29717206954956, 41.151658818125725, 39.43828135728836, 40.16254909336567, 43.04638534784317, 43.182125464081764, 47.08762049674988, 51.052947118878365, 51.52569115161896, 52.021351754665375, 51.80156774818897, 51.40033207833767, 50.88145472109318, 54.23371843993664, 54.8782854527235, 56.525812447071075, 61.30507439374924, 52.779080495238304, 49.5681007951498, 51.094125509262085, 53.2639192789793, 54.25593204796314, 56.815208718180656, 53.09605948626995, 53.52324016392231, 52.29041911661625, 56.807293742895126, 56.25112898647785, 58.84577415883541, 59.803136587142944, 71.38720259070396, 55.78737147152424, 55.74569530785084, 65.47736451029778, 63.93094629049301, 65.03094166517258, 64.55016866326332, 61.60550907254219, 66.92618876695633, 69.85743507742882, 74.04879257082939, 69.94061261415482, 68.75222638249397, 8.544669896364212, 0.28884645842481405, 1.3451334019191563, 1.1710760230198503, 0.3165333461947739, 16.423822604119778, 84.1570633649826, 70.60670927166939, 82.75103241205215, 65.93256488442421, 63.328473418951035, 49.14167247712612, 23.18549707531929, 37.13826857507229, 61.492928713560104, 75.22467747330666, 4.471033411100507, 0.23454618465621024, 0.09573578121489845, 0.054402159512392245, 0.008910400338209001, 0.21979645971441641, 0.2101174439303577, 0.1054598527844064, 0.18706847447901964, 0.14573631109669805, 0.3519849985605106, 3.0689618457108736, 79.65891793370247, 68.08527857065201, 54.5612570643425, 38.72909501194954, 40.39313592016697, 52.46143653988838, 58.288192078471184, 80.08647859096527, 68.79290699958801, 77.46307656168938, 48.095725402235985, 0.19129724678350613, 0.7718468829989433, 9.371638521552086, 12.110218070447445, 16.850881688296795, 1.6949359816499054, 0.35704166628420353, 40.05979500710964, 75.08514136075974, 66.81562229990959, 66.79623574018478, 61.399681717157364, 62.34935715794563, 59.06536437571049, 57.86583714187145, 56.92369669675827, 60.104521214962006, 55.039415806531906, 55.11098496615887, 55.18205255270004, 58.52570213377476, 61.487612798810005, 60.01199617981911, 62.9163209348917, 52.116912826895714, 49.622152894735336, 48.99093076586723, 52.93897211551666, 50.00082537531853, 52.12928496301174, 48.55765901505947, 49.926391169428825, 49.416982904076576, 51.5321584045887, 52.300860956311226, 59.2609740793705, 58.66696335375309, 52.83624082803726, 52.053072452545166, 52.24772460758686, 63.65868330001831, 55.35633400082588, 50.31042516231537, 42.62600250542164, 43.57250891625881, 40.3442857414484, 44.64648328721523, 42.54882864654064, 42.50332608819008, 43.287368416786194, 39.95080545544624, 44.15975220501423, 42.739217430353165, 47.70991690456867, 46.15000560879707, 46.59857153892517, 52.300499975681305, 48.63791070878506, 49.93817813694477, 44.67362903058529, 52.082243487238884, 59.42737475037575, 57.18907065689564, 56.869823187589645, 49.65161271393299, 43.183652982115746, 45.04146829247475, 44.99894097447395, 42.9893010109663, 46.49115510284901, 43.51311430335045, 44.00388836860657, 46.75786279141903, 45.69312572479248, 39.139757975935936, 40.81896387040615, 34.868319779634476, 41.00830391049385, 49.19114202260971, 47.86838740110397, 47.363276705145836, 53.33808369934559, 51.9299590587616, 47.882005870342255, 52.83298820257187, 45.06341591477394, 42.81484477221966, 47.80633673071861, 48.784039467573166, 50.01502901315689, 47.11334511637688, 45.43630890548229, 42.09327109158039, 43.1048908084631, 42.012111246585846, 43.497633934020996, 41.30042843520641, 42.705843821167946, 45.28701111674309, 46.183390617370605, 49.21898312866688, 53.71399752795696, 55.99901631474495, 56.446860283613205, 55.983672738075256, 54.50516827404499, 55.275782123208046, 57.76256628334522, 57.988327369093895, 58.88293236494064, 60.897914841771126, 48.36679905653, 48.33863116800785, 55.16025312244892, 55.518475100398064, 55.14497794210911, 55.94082623720169, 57.576273679733276, 53.88106316328049, 54.638826102018356, 58.09403769671917, 58.83243687450886, 59.081604704260826, 61.11919976770878, 65.39458215236664, 55.144898146390915, 61.38850651681423, 67.55560979247093, 68.53093385696411, 68.45951288938522, 66.60838901996613, 63.59741158783436, 70.77004730701447, 70.7385241985321, 77.30806767940521, 70.21978363394737, 74.33214336633682, 9.596550352871418, 0.36233876016922295, 3.980128727853298, 4.872764479368925, 0.4467354970984161, 16.97418127208948, 91.94686576724052, 76.5803611278534, 88.01017820835114, 71.26617908477783, 74.28561106324196, 67.62970581650734, 37.99602314829826, 49.43794257938862, 71.48038879036903, 88.93304228782654, 7.623995449393988, 0.5505758500657976, 0.19439998810412362, 0.1870191513444297, 0.21026217757025734], [0.022220150058274157, 0.04368568064819556, 0.05999638706271071, 0.15916246018605307, 0.03762438616831787, 0.14483531413134187, 1.4103602268733084, 52.58643463253975, 55.20534910261631, 41.53603859245777, 23.958183713257313, 76.24854013323784, 58.15169960260391, 43.418259993195534, 67.01771825551987, 63.07862922549248, 59.472873508930206, 55.320551320910454, 0.8638134668581188, 0.11764355760533363, 0.8376185037195683, 0.7480461476370692, 2.148989411070943, 0.8401302876882255, 0.2606625988846645, 14.423676431179047, 77.05562442541122, 58.53749290108681, 65.02790182828903, 56.37557610869408, 58.038955852389336, 51.75460986793041, 51.55698627233505, 50.634855553507805, 54.11744847893715, 52.81690366566181, 57.39028885960579, 55.03458246588707, 58.32693859934807, 60.241758450865746, 53.558103293180466, 43.1887599080801, 42.9277329146862, 56.42279237508774, 53.35227973759174, 50.596671402454376, 53.82831059396267, 46.0076804459095, 53.64890702068806, 51.55184894800186, 53.924202248454094, 47.64143317937851, 49.500597417354584, 34.9099313467741, 53.242382034659386, 52.10614800453186, 47.58655272424221, 56.2672059237957, 52.55879111588001, 51.043162643909454, 39.81539212167263, 38.25273737311363, 37.502805814146996, 40.155196487903595, 36.25651828944683, 37.42101900279522, 38.06831046938896, 37.27744370698929, 38.24101880192757, 39.33728277683258, 42.95498505234718, 43.12018498778343, 44.73701722919941, 45.65089859068394, 44.63515229523182, 44.66928206384182, 45.2002389729023, 47.04832300543785, 48.079526871442795, 55.31101003289223, 54.697445556521416, 55.097674280405045, 50.12262403964996, 43.58790569007397, 42.099457159638405, 40.82928031682968, 40.115853399038315, 44.01414401829243, 46.42382651567459, 43.31326022744179, 41.28990299999714, 42.172071263194084, 37.913692966103554, 40.26881419122219, 38.801226541399956, 43.191970735788345, 49.750084429979324, 48.13488610088825, 46.36379353702068, 51.00087471306324, 46.60248152911663, 47.108952552080154, 43.2316368073225, 42.454639300704, 42.34912656247616, 44.18643817305565, 40.13949193060398, 41.6196721047163, 44.17556315660477, 37.05248437821865, 37.71527901291847, 40.52837826311588, 37.864462807774544, 37.887067794799805, 37.47717998921871, 37.66578666865826, 38.4574019908905, 40.604655370116234, 43.210946917533875, 48.24499659240246, 50.63078977167606, 52.66163259744644, 50.65874107182026, 51.74903176724911, 48.28675635159016, 45.77567249536514, 52.419224604964256, 51.17489397525787, 51.91829368472099, 51.87538258731365, 49.98943738639355, 50.622232630848885, 47.909318804740906, 51.082479134202, 52.73298516869545, 47.250494956970215, 50.513953641057014, 52.412346974015236, 55.85754990577698, 57.53731817007065, 56.26289315521717, 51.70674003660679, 41.768833100795746, 48.58076177537441, 64.85453993082047, 61.75077147781849, 61.578587517142296, 59.82216976583004, 64.25864070653915, 62.7861475199461, 62.39455193281174, 60.89211255311966, 75.15029266476631, 69.15511876344681, 53.21706399321556, 3.3797269826754928, 0.3370560152688995, 1.5824282937683165, 0.6994398089591414, 0.3594001225428656, 16.20095696300268, 75.8713647723198, 69.15983811020851, 73.2480539381504, 67.94174507260323, 47.27843105792999, 75.94793066382408, 30.062554255127907, 30.12095332145691, 61.80657148361206, 67.36850783228874, 3.8483691355213523, 0.07314625312574208, 0.17734549386659637, 0.09421756229130551, 0.08946252564783208, 0.06388368608895689, 0.06498716320493259, 0.06854259234387428, 0.08609210650320165, 0.09122643255977891, 0.22126693627797067, 1.5227146167308092, 65.42238146066666, 60.07718548178673, 46.05267383158207, 19.427648819983006, 47.557556480169296, 54.57653224468231, 48.927253782749176, 73.28618109226227, 67.82315343618393, 66.03578254580498, 59.3316350877285, 0.924583962187171, 0.06604169568163343, 1.2675257725641131, 1.5199366095475852, 5.348080499097705, 2.701424192637205, 0.4758773505454883, 16.623836271464825, 79.25379127264023, 61.051760986447334, 69.21806618571281, 59.30603586137295, 60.811157897114754, 54.71750847995281, 54.479086473584175, 52.407639026641846, 56.78971588611603, 53.11354994773865, 58.36609549820423, 55.2886026352644, 58.64945389330387, 61.7209392786026, 57.13984049856663, 44.936882704496384, 46.61859266459942, 56.95043206214905, 55.71329444646835, 51.81085824966431, 52.65263848006725, 47.666975408792496, 55.2806306630373, 51.91449008882046, 55.19842207431793, 49.559802040457726, 49.22143019735813, 39.22557257115841, 60.290490835905075, 57.16026060283184, 49.10042569041252, 57.844702675938606, 55.87954692542553, 53.407334983348846, 42.82566659152508, 40.94363138079643, 40.45319929718971, 41.172223314642906, 37.583559080958366, 39.341333359479904, 40.775843784213066, 40.62454730272293, 40.621078088879585, 40.94470292329788, 42.544200494885445, 45.17976187169552, 47.65472486615181, 47.835823148489, 48.26176889240742, 47.04053722321987, 47.524095475673676, 49.89875145256519, 49.828443825244904, 55.829036235809326, 54.24000330269337, 56.97235308587551, 51.88133306801319, 44.217999279499054, 42.68892712891102, 43.66327844560146, 42.157263457775116, 46.072067990899086, 46.43092453479767, 42.57404789328575, 43.71601581573486, 43.101167008280754, 39.596231281757355, 41.51399977505207, 37.7872509509325, 42.15923935174942, 51.1611957103014, 48.6437775939703, 48.011989295482635, 50.77125683426857, 49.92577560245991, 48.416530787944794, 43.233962282538414, 43.93792390823364, 46.37427717447281, 45.33584609627724, 43.91026899218559, 47.2584593296051, 45.0519785284996, 38.802476674318314, 41.05832062661648, 41.6844130307436, 40.90889744460583, 40.77221117913723, 39.04593341052532, 40.17298333346844, 38.70895989239216, 40.26650011539459, 45.50139561295509, 49.7435449808836, 52.90293104946613, 54.0428850799799, 50.98722964525223, 52.13488966226578, 50.14564320445061, 48.18616434931755, 54.789723604917526, 52.480177134275436, 52.017441764473915, 53.45084644854069, 52.50809423625469, 51.630656719207764, 48.31731431186199, 52.77308061718941, 52.14297942817211, 48.74606430530548, 51.51960387825966, 53.87759394943714, 56.91636309027672, 56.757144033908844, 56.58364154398441, 57.067439183592796, 46.415945738554, 50.875268653035164, 69.28558856248856, 64.6034874022007, 64.1447152197361, 62.35564202070236, 67.67930075526237, 62.90445417165756, 63.78942668437958, 60.83790086209774, 76.14059552550316, 71.05465963482857, 56.06110118329525, 3.5454600770026445, 0.300059033324942, 2.9630033439025283, 1.364349089562893, 0.26607603183947504, 17.337225191295147, 81.4800538122654, 73.56827035546303, 79.20492589473724, 73.97852674126625, 55.32794192433357, 85.86923629045486, 38.22571702301502, 35.459579452872276, 67.99346029758453, 77.6722477376461, 5.5106619000434875, 0.34844655718188733, 0.27259087131824344, 0.06643884858931415, 0.19062146195210516, 0.17206402961164713, 0.1891900965711102, 0.20824577717576176, 0.3107818204443902, 0.27552374987863004, 0.23961950617376715, 2.9308402072638273, 83.37536931037903, 68.67768958210945, 56.3863979279995, 34.35833394527435, 87.64445543289185, 70.24179205298424, 58.58073078095913, 78.60433772206306, 71.8029534816742, 71.90574556589127, 66.13171219825745, 1.0825634538196027, 0.32185154675971717, 5.759796956554055, 4.0172788593918085, 8.633788414299488, 5.437699165195227, 0.8097486023325473, 20.62389872968197, 80.84408953785896, 63.52036312222481, 71.54386818408966, 62.83855810761452, 62.860688120126724, 55.65745644271374, 57.784118726849556, 54.85017456114292, 59.54168401658535, 57.54257708787918, 59.42667178809643, 58.39970849454403, 62.8094744682312, 63.763063699007034, 55.101610869169235, 50.8442547172308, 50.74939660727978, 56.222216337919235, 51.883787736296654, 51.41924366354942, 51.85714736580849, 50.31865932047367, 56.96112848818302, 54.74702529609203, 53.74632239341736, 50.839295983314514, 51.901479586958885, 45.1574532687664, 57.61369027197361, 54.383206218481064, 54.45974551141262, 59.89887244999409, 57.90038488805294, 55.952920988202095, 44.535479843616486, 41.60913527011871, 42.779597863554955, 44.8192448168993, 39.327794685959816, 40.665976479649544, 44.03079092502594, 42.105742022395134, 43.35812821984291, 43.405500277876854, 47.4147829413414, 47.26771183311939, 49.997375160455704, 49.37597170472145, 48.51214125752449, 49.98319052159786, 48.765944838523865, 51.79365657269955, 50.905359238386154, 59.602632746100426, 57.555169612169266, 58.574141934514046, 52.45719596743584, 44.30924378335476, 45.14967508614063, 47.21167244017124, 44.13752719759941, 48.00565883517265, 47.47385457158089, 45.54809130728245, 47.97728955745697, 44.02429327368736, 40.32710686326027, 41.952401250600815, 38.22197802364826, 44.315612241625786, 53.4234993159771, 50.21164946258068, 51.17612510919571, 53.63715425133705, 50.99620096385479, 49.93056334555149, 47.062861025333405, 44.83203873038292, 48.10704119503498, 46.98639012873173, 45.742059499025345, 48.74251149594784, 48.56146261096001, 41.79144948720932, 43.018399849534035, 43.95054683089256, 44.02230218052864, 42.670718505978584, 42.50359207391739, 43.2136295735836, 40.79455018043518, 43.22615750133991, 48.21991413831711, 51.884338706731796, 54.89110216498375, 56.7394407838583, 52.332528457045555, 56.57321870326996, 53.28588970005512, 50.12040115892887, 57.66008958220482, 54.539541229605675, 55.22751711308956, 53.451898992061615, 51.06633000075817, 52.20759496092796, 48.616487458348274, 53.69519613683224, 54.728083312511444, 51.619356125593185, 51.76067054271698, 53.45855623483658, 57.46925622224808, 58.655339777469635, 57.60515972971916, 53.0353881418705, 49.08096693456173, 56.48542061448097, 69.76956099271774, 67.81971842050552, 68.24830502271652, 65.98711475729942, 70.00495076179504, 65.96494674682617, 66.79084002971649, 64.1353677213192, 77.65700295567513, 71.01261109113693, 60.609282329678535, 4.408024242147803, 0.7854513998609036, 4.648494813591242, 3.9919218700379133, 0.5458367918618023, 19.909763149917126, 89.12212014198303, 79.14907649159431, 86.65456295013428, 79.60056066513062, 63.1821508705616, 93.02589386701584, 41.8326772749424, 46.665881127119064, 77.8943458199501, 91.7894934117794, 9.225129783153534, 0.7594358583446592, 0.6051278603263199, 0.3750493749976158, 0.43150092707946897], [0.04728601343231276, 0.031996569014154375, 0.049494507620693184, 0.03817069962678943, 0.07996208543772809, 0.07359625436947681, 1.7617550399154425, 55.900107622146606, 54.96564656496048, 39.06124658882618, 41.111244186758995, 96.42991080880165, 78.9969402551651, 43.02663780748844, 60.7519456744194, 68.93254950642586, 56.6054105758667, 60.791976526379585, 3.0704264296218753, 0.23818592919269577, 0.5780747369863093, 0.7892238849308342, 0.7727325323503464, 1.1590596428140998, 0.3097099217120558, 9.234881959855556, 70.2105501294136, 59.81163293123245, 63.936607986688614, 57.41189830005169, 57.72968664765358, 51.807195246219635, 51.97157062590122, 51.46423324942589, 57.1594550460577, 55.23331940174103, 58.796889781951904, 58.95553506910801, 56.69379383325577, 42.8135072439909, 42.37450160086155, 50.38130655884743, 60.70893958210945, 53.99164862930775, 48.17519053816795, 39.870337173342705, 58.74113917350769, 52.607656493783, 51.349597200751305, 48.418932259082794, 47.461710423231125, 45.12596055865288, 51.028655022382736, 53.43989163637161, 39.52110171318054, 49.29878644645214, 55.45253723859787, 56.903918758034706, 50.501228123903275, 44.4021487981081, 38.79376374185085, 37.32210651040077, 38.991106152534485, 37.899329736828804, 37.233339473605156, 34.848811626434326, 39.661496579647064, 38.41739013791084, 37.73921012878418, 38.42094674706459, 40.47952048480511, 41.86138093471527, 46.17032691836357, 46.71810932457447, 45.58383598923683, 44.90814484655857, 45.99300563335419, 46.82692788541317, 46.06932453811169, 50.27625359594822, 53.266495540738106, 54.371244460344315, 52.686228677630424, 44.8689841479063, 43.36492605507374, 40.16954451799393, 37.97673158347607, 43.134320229291916, 45.52803598344326, 40.32571233808994, 42.11802676320076, 43.654557913541794, 37.24264897406101, 38.75752508640289, 40.77419087290764, 45.07961064577103, 49.1045218706131, 43.75931069254875, 48.74133735895157, 50.1119352132082, 48.68626311421394, 45.083535835146904, 42.94435702264309, 48.155933171510696, 43.05852569639683, 41.69609360396862, 42.348036020994186, 41.19378335773945, 39.98200558125973, 37.4045392870903, 37.12579384446144, 37.30991676449776, 39.38073344528675, 39.78103056550026, 38.19572903215885, 39.32045727968216, 36.97675444185734, 39.1067111492157, 41.360377818346024, 44.57077614963055, 54.6683619171381, 50.74877344071865, 51.9795273989439, 54.41445954144001, 49.796270951628685, 48.05051162838936, 45.70753075182438, 51.94001331925392, 55.804500952363014, 54.92701403796673, 54.693303778767586, 56.21522091329098, 57.575217336416245, 52.0544707775116, 47.176045551896095, 45.87115377187729, 51.76177628338337, 48.46579894423485, 50.4263873398304, 44.338737800717354, 43.37108552455902, 43.972673043608665, 53.045168817043304, 61.2024001032114, 57.151285484433174, 62.36976206302643, 64.27756369113922, 63.53316843509674, 60.93023210763931, 59.56104017794132, 62.43500456213951, 54.72394533455372, 64.1622930765152, 70.10664090514183, 42.91678570210934, 1.9680126034654677, 0.3610878257313743, 1.2320807995274663, 0.1921201846562326, 0.1614081545267254, 20.428372621536255, 77.67633631825447, 66.35155320167542, 75.63523024320602, 66.6022789478302, 49.57764968276024, 32.23669119179249, 15.856522545218468, 32.39467911422253, 57.27665215730667, 62.12665490806103, 3.1354929506778717, 0.19480819901218638, 0.03426063893130049, 0.047136804641922936, 0.020528634086076636, 0.0720485944475513, 0.028791372351406608, 0.050446927998564206, 0.09069691761396825, 0.02753357490291819, 0.2438611027901061, 2.120835059322417, 68.56973737478256, 60.259723886847496, 47.207112684845924, 40.15096731483936, 93.77213582396507, 82.55311623215675, 51.08945555984974, 69.11477252840996, 75.23014917969704, 63.40784355998039, 68.05229634046555, 3.2436448847875, 0.2071911407983862, 0.832197085255757, 1.7612955020740628, 3.585778526030481, 3.061079168692231, 0.3138245962327346, 9.719601050019264, 72.66770347952843, 62.303455621004105, 66.63920536637306, 60.804143473505974, 60.56480951607227, 55.06279215216637, 54.393290877342224, 51.83583050966263, 56.18725821375847, 56.01200021803379, 60.09281404316425, 59.300366565585136, 57.73659847676754, 46.4222875982523, 47.648683190345764, 51.78539961576462, 58.807677403092384, 52.633525505661964, 48.92203286290169, 43.6299504339695, 59.6544049680233, 51.84741988778114, 54.12858948111534, 52.02707804739475, 49.08078074455261, 47.30738930404186, 53.30237701535225, 51.30518138408661, 43.49715135991573, 57.188177704811096, 57.48869977891445, 56.32579877972603, 53.308392092585564, 46.048991829156876, 41.480310782790184, 37.64237992465496, 40.669099912047386, 41.00733496248722, 38.147239834070206, 37.92713664472103, 40.12309581041336, 39.59934711456299, 40.085968002676964, 41.71544976532459, 43.8309520483017, 44.23883356153965, 49.885208979249, 48.30701306462288, 49.66042064130306, 48.23536790907383, 47.77801305055618, 48.708267733454704, 46.597279608249664, 53.14905904233456, 55.15837222337723, 57.17052385210991, 53.22606950998306, 43.579671531915665, 45.7953592389822, 40.37096031010151, 39.87663343548775, 43.56286883354187, 44.69269260764122, 40.945090502500534, 42.91864760220051, 43.86507801711559, 38.44455108046532, 37.99998253583908, 38.76548185944557, 45.16203582286835, 49.93266463279724, 44.801875948905945, 49.76537100970745, 52.69196256995201, 49.51341412961483, 46.536482870578766, 45.149918273091316, 49.351588413119316, 45.15486180782318, 46.3478571921587, 44.18505884706974, 42.776261642575264, 43.6725727468729, 39.9951034784317, 39.117985144257545, 39.835238456726074, 41.380881518125534, 41.510823145508766, 41.80399261415005, 41.13080553710461, 39.01340715587139, 41.00560985505581, 42.72613473236561, 45.89726597070694, 54.534704089164734, 53.10044825077057, 54.33887779712677, 57.03287623822689, 51.86896853148937, 50.77674373984337, 46.930897906422615, 53.08655619621277, 57.96116642653942, 56.23005911707878, 59.21305865049362, 58.48937228322029, 57.96871282160282, 53.03302466869354, 50.113603323698044, 45.70035673677921, 52.834245935082436, 49.954087883234024, 51.31628438830376, 47.572903856635094, 47.41273485124111, 46.77580542862415, 54.844338074326515, 62.91791684925556, 60.381397157907486, 64.07243549823761, 66.48982778191566, 64.44691300392151, 64.88242283463478, 63.887499421834946, 64.8792614042759, 59.59062919020653, 65.95670118927956, 70.97202926874161, 48.2393728941679, 2.488238294608891, 0.2922893111826852, 4.172206046059728, 1.2186456704512239, 0.2570615796139464, 22.42256261408329, 81.64488896727562, 72.14085415005684, 79.87723901867867, 73.76863360404968, 54.688174054026604, 56.87298461794853, 22.488099597394466, 37.97926224768162, 67.01804503798485, 73.75102534890175, 5.1957594975829124, 0.21065211680252105, 0.1911316587938927, 0.05173081379325595, 0.056558762735221535, 0.22109990852186456, 0.18159607046982273, 0.19272021105280146, 0.17519198911031708, 0.20686202798970044, 0.286151779582724, 2.9817294515669346, 82.47852623462677, 69.60116922855377, 54.76781018078327, 54.402528181672096, 104.7137551009655, 83.55718195438385, 62.82831385731697, 76.15639507770538, 79.87964808940887, 67.48479679226875, 76.59603148698807, 3.8898431975394487, 0.6584997964091599, 1.7300712713040411, 3.634281735867262, 8.077610358595848, 7.981959041208029, 0.5955657921731472, 12.799520082771778, 73.27732756733894, 63.99179622530937, 66.78651586174965, 62.83996403217316, 60.696533247828484, 59.82060804963112, 54.86152835190296, 55.96271686255932, 60.731358379125595, 58.580331802368164, 62.19509683549404, 62.14181609451771, 59.574024081230164, 51.323245614767075, 51.36174134910107, 54.83276009559631, 55.7574100792408, 54.87608917057514, 48.53960618376732, 50.34817233681679, 60.72071895003319, 50.95086179673672, 55.73498748242855, 52.32910864055157, 51.69669337570667, 49.95944179594517, 54.184332489967346, 54.89720083773136, 44.482518285512924, 52.776139453053474, 59.36341278254986, 60.24279959499836, 54.78900924324989, 47.28788115084171, 42.35798008739948, 40.66455155611038, 44.36095520853996, 43.56139451265335, 40.90213380753994, 40.266880095005035, 43.91017019748688, 41.380680128932, 42.32785910367966, 45.28697311878204, 46.535160541534424, 46.73486642539501, 52.19851344823837, 50.505001321434975, 51.650997027754784, 49.12938013672829, 49.77576345205307, 51.32442355155945, 47.76855915784836, 55.257543101906776, 58.615935891866684, 59.978174194693565, 56.233330741524696, 45.3733766824007, 47.469196021556854, 42.54873365163803, 43.08634400367737, 45.261772871017456, 45.86334899067879, 42.342803701758385, 43.946378454566, 46.612133011221886, 38.52870516479015, 37.5770728290081, 39.5942097902298, 46.00618712604046, 51.29670023918152, 46.24249644577503, 52.84132495522499, 55.647318586707115, 50.98139315843582, 48.64616386592388, 46.899845972657204, 51.86619468033314, 46.25714845955372, 47.348423302173615, 47.18821629881859, 46.99289917945862, 45.49133375287056, 40.90459607541561, 41.99686646461487, 42.471430599689484, 43.75633925199509, 43.36630918085575, 42.7716638892889, 43.197225853800774, 38.95923726260662, 42.38379210233688, 46.12874574959278, 48.891691491007805, 57.92763702571392, 53.44733163714409, 57.10952192544937, 59.38366189599037, 53.336476385593414, 52.71375060081482, 50.221950709819794, 57.4125100672245, 60.65111808478832, 58.645555302500725, 61.77876077592373, 61.17198273539543, 61.78296335041523, 53.52888286113739, 51.23175032436848, 49.84898932278156, 52.27490074932575, 51.44706957042217, 52.25742548704147, 48.84775824844837, 50.56355997920036, 49.96427893638611, 57.08758570253849, 64.00086253881454, 59.97926093637943, 67.96195238828659, 68.4897668659687, 67.60619267821312, 64.81815308332443, 66.09749883413315, 65.33274427056313, 60.768592581152916, 66.53344944119453, 72.3036678135395, 50.318370535969734, 3.27110696118325, 0.9656695544254035, 3.972603469155729, 2.2565257782116532, 0.44964352855458856, 24.84509602189064, 89.56004664301872, 77.12361797690392, 87.93221399188042, 77.27268397808075, 64.54269826412201, 45.58048456907272, 25.031920596957207, 51.43549159169197, 73.48664313554764, 89.02908593416214, 9.018688760697842, 0.6091139058116823, 0.5379986437037587, 0.19712600042112172, 0.16579123417614028], [0.05967006101855077, 0.055390496127074584, 0.05253280825854745, 0.03579327407351229, 0.06621556603931822, 0.09771664757863618, 1.2555147358216345, 57.614587023854256, 55.5691833794117, 32.443780079483986, 16.103646084666252, 82.03850984573364, 68.31951320171356, 41.970427483320236, 54.19735439121723, 70.89166358113289, 56.22745245695114, 66.37299925088882, 6.054916670545936, 0.1245437646866776, 0.4053867392940447, 0.5094457289669663, 4.6600195951759815, 2.139885574579239, 0.1687271406990476, 7.307126652449369, 69.01968643069267, 57.21151605248451, 64.10610929131508, 57.341826260089874, 60.15156269073486, 53.820718601346016, 53.206014186143875, 52.123646065592766, 60.64194157719612, 58.81092242896557, 61.75846226513386, 49.1423412412405, 45.470286682248116, 51.316455379128456, 67.67319068312645, 62.060067281126976, 53.62187907099724, 49.60294492542744, 58.870423436164856, 50.33396489918232, 43.777861297130585, 58.09926241636276, 53.90950843691826, 50.159223675727844, 49.68576528131962, 51.40302233397961, 45.575890615582466, 40.845285058021545, 44.0581950545311, 42.01689898967743, 53.444508388638496, 50.928925573825836, 47.87025690078735, 41.78041487932205, 39.86971780657768, 36.70751988887787, 39.59243908524513, 36.07299953699112, 38.12994696199894, 39.6984001994133, 40.06300963461399, 37.098321318626404, 37.74176359176636, 37.05330513417721, 39.08336900174618, 42.386520355939865, 43.57621371746063, 47.01964594423771, 42.99134150147438, 43.175977393984795, 44.86072339117527, 45.973717868328094, 47.73450158536434, 48.6695060133934, 51.45265907049179, 52.0486418902874, 51.40030927956104, 47.77033366262913, 44.13142092525959, 39.96867589652538, 40.09939648211002, 43.47119875252247, 44.33743827044964, 42.58306480944157, 43.219762444496155, 41.066961362957954, 39.02394779026508, 38.16609442234039, 42.41754189133644, 49.385057017207146, 49.19879861176014, 47.91902728378773, 52.507170885801315, 52.01074652373791, 45.84976091980934, 46.75996407866478, 44.82322320342064, 45.20970806479454, 43.134259432554245, 41.773187667131424, 42.12301969528198, 39.99326817691326, 40.76802760362625, 35.713516026735306, 34.79436434805393, 36.579960733652115, 37.25631304085255, 36.26478664577007, 35.784484818577766, 39.84643645584583, 37.89946272969246, 39.36216004192829, 41.03668458759785, 41.89712181687355, 48.226411789655685, 53.37515451014042, 53.30285958945751, 54.20545555651188, 52.63610556721687, 50.4626601934433, 46.302894204854965, 44.979451820254326, 49.57489103078842, 54.021583423018456, 50.76182194054127, 53.8044136762619, 54.63425114750862, 58.661814630031586, 48.59602555632591, 45.35195343196392, 54.69423092901707, 54.65467885136604, 54.57582548260689, 58.531489223241806, 61.01868376135826, 64.44465592503548, 61.393928825855255, 58.415029272437096, 61.47693917155266, 57.82325282692909, 61.54936708509922, 60.5397080630064, 61.38990484178066, 65.43365925550461, 64.63406816124916, 57.503746971488, 62.218682169914246, 68.14016282558441, 35.56735686957836, 0.48044993018265814, 0.08473676673020236, 2.30698493309319, 0.33070566540118307, 0.23414719122229144, 32.35198840498924, 76.52081832289696, 65.61380758881569, 74.9200402200222, 64.93816584348679, 55.92607922852039, 30.41599988937378, 26.62370838224888, 41.51346020400524, 60.54633870720863, 53.94388139247894, 3.8332148361951113, 0.2012718896730803, 0.12446168315364048, 0.04503638941969257, 0.020920849856338464, 0.06043685170880053, 0.03190304727468174, 0.03325743709865492, 0.007986002528923564, 0.025087166723096743, 0.07559628298622556, 2.2597351809963584, 66.1022561788559, 63.648663237690926, 36.88639909029007, 25.735015869140625, 101.9939674437046, 78.49159017205238, 51.90885879099369, 63.440928384661674, 75.64045876264572, 61.035125479102135, 70.80081045627594, 6.154005853459239, 0.21780455019325018, 1.2555329035967588, 1.4176945458166301, 3.0412059975787997, 1.9683776213787496, 0.24174998950911686, 8.754809070378542, 71.43526241183281, 57.903595715761185, 68.19732695817947, 58.895616084337234, 62.351321652531624, 55.09144641458988, 55.24818040430546, 54.077733010053635, 63.27813372015953, 59.49616625905037, 61.9216825067997, 50.86236834526062, 46.8802884221077, 52.14837893843651, 64.86437380313873, 59.11729238927364, 54.80774983763695, 54.36961814761162, 61.421823129057884, 52.65224330127239, 49.94542054831982, 58.2823745906353, 55.137917920947075, 52.78268650174141, 53.062328696250916, 50.82961790263653, 48.13214264810085, 42.61763535439968, 47.97763913869858, 48.452701047062874, 54.55455042421818, 53.99412989616394, 49.407335221767426, 43.51021885871887, 42.85024747252464, 38.252953961491585, 39.15737763047218, 37.478152737021446, 39.12822939455509, 41.63542605936527, 42.33777277171612, 39.845554903149605, 39.570487663149834, 40.05922503769398, 41.94345273077488, 44.58452381193638, 45.60812808573246, 49.06313829123974, 46.59518592059612, 45.17598107457161, 46.82110659778118, 47.64571934938431, 46.944121196866035, 50.23282192647457, 52.850657254457474, 55.01224346458912, 54.78975400328636, 47.484759986400604, 44.419415071606636, 42.70877726376057, 44.12323996424675, 44.956839233636856, 44.81377311050892, 43.216547816991806, 43.76255191862583, 41.35494031012058, 39.147775545716286, 38.17272126674652, 42.91377626359463, 49.89468187093735, 51.325612887740135, 49.49591986835003, 52.02126815915108, 54.21804428100586, 48.51411335170269, 48.424137979745865, 47.29952372610569, 47.015792950987816, 46.71508848667145, 45.234494134783745, 44.084922820329666, 42.435913905501366, 42.5299284607172, 38.270748406648636, 37.53389574587345, 37.15083450078964, 38.1800776720047, 38.211707174777985, 37.75084510445595, 40.71439728140831, 38.56768727302551, 40.79040080308914, 42.760663479566574, 44.25918906927109, 50.79251669347286, 55.34670911729336, 55.29858469963074, 56.70580878853798, 55.66534481942654, 52.80488111078739, 48.5497934371233, 47.878198474645615, 50.334705859422684, 56.95813424885273, 52.5938518345356, 57.74079345166683, 57.14527040719986, 60.808372646570206, 52.450170144438744, 45.87724104523659, 55.08772261440754, 58.21126140654087, 56.21737539768219, 60.801305025815964, 61.646185889840126, 65.66614598035812, 64.43843185901642, 61.039457246661186, 63.91580030322075, 61.155598014593124, 61.70362360775471, 63.89000728726387, 65.36777079105377, 68.93585532903671, 65.32873928546906, 59.85404245555401, 65.75952976942062, 69.43802878260612, 41.195101886987686, 0.5957512103486806, 0.07426884054439142, 5.501799350604415, 0.6705968035385013, 0.059204003409831785, 35.29211103916168, 82.65937373042107, 72.14847654104233, 80.44302865862846, 70.8722086250782, 63.09514693915844, 32.389944568276405, 21.749166548252106, 49.51116465032101, 67.19934850931168, 67.88905709981918, 4.398048352450132, 0.2538243611343205, 0.12478607590310276, 0.07089357517543249, 0.022604886835324578, 0.14672936405986547, 0.1745789751294069, 0.10520629060920328, 0.19334254640853032, 0.2141360696987249, 0.2150680439081043, 2.9829624854028225, 77.63101235032082, 74.20577734708786, 48.20060737431049, 24.866675063967705, 92.87037581205368, 76.0346420109272, 58.56198638677597, 67.18348056077957, 83.81620645523071, 67.04901337623596, 78.77085238695145, 7.452556723728776, 0.29262289172038436, 5.522396620362997, 3.301767515949905, 12.29470957070589, 7.858636183664203, 0.48272087238729, 10.731500051915646, 73.96905764937401, 60.36492504179478, 69.25272032618523, 62.68851175904274, 65.09429946541786, 57.79502794146538, 59.04039591550827, 57.874945253133774, 65.25145903229713, 63.17861706018448, 66.16694390773773, 54.063396379351616, 52.59122237563133, 54.431855008006096, 64.50888767838478, 57.191023752093315, 55.68363703787327, 56.04184001684189, 63.5513124614954, 54.25625503063202, 55.752192959189415, 60.62684118747711, 55.942460149526596, 55.30163213610649, 52.78185814619064, 52.98071287572384, 50.84664858877659, 45.86635462939739, 42.503512278199196, 47.362281158566475, 57.281493097543716, 55.437345653772354, 53.643100932240486, 46.61323495209217, 45.27693785727024, 38.646453246474266, 43.20994757115841, 40.4314074665308, 43.39505083858967, 44.68661293387413, 44.649074748158455, 41.473322957754135, 42.43733882904053, 41.00772254168987, 42.465008944272995, 47.23570615053177, 48.74021641910076, 51.40826225280762, 47.44165889918804, 47.565239667892456, 49.850672632455826, 50.60267128050327, 50.57829558849335, 53.03322605788708, 56.19507819414139, 59.572754949331284, 55.86573086678982, 50.32826140522957, 47.45344966650009, 43.604024425148964, 46.354028061032295, 47.47629404067993, 45.73355175554752, 45.204506143927574, 45.59674009680748, 44.002797827124596, 39.98743548989296, 38.456984013319016, 46.273430585861206, 51.226483806967735, 52.51117207109928, 51.76724798977375, 54.317161962389946, 57.54991449415684, 49.15564052760601, 50.81628821790218, 48.06617058813572, 49.82260353863239, 48.034765273332596, 48.81460502743721, 46.36670418083668, 45.87083078920841, 45.2990260720253, 39.4695308804512, 38.099715784192085, 40.12594185769558, 40.4081679135561, 41.1296845972538, 39.32329572737217, 44.98086914420128, 39.91075940430164, 43.98155316710472, 45.814776197075844, 45.672420635819435, 50.75871750712395, 58.873603865504265, 57.21069909632206, 58.13475251197815, 57.56622701883316, 54.98129032552242, 52.28628493845463, 49.65261586010456, 51.7714923620224, 61.13183408975601, 55.257911682128906, 59.315440356731415, 61.18429787456989, 63.40755857527256, 53.974830731749535, 49.129429534077644, 55.775147527456284, 58.873938247561455, 57.90328033268452, 64.8122026026249, 64.83687847852707, 67.88765877485275, 64.83513057231903, 63.40661242604256, 66.35146200656891, 63.26323091983795, 64.70842257142067, 65.9736330807209, 67.63939529657364, 72.36451014876366, 68.87448102235794, 61.94841407239437, 67.91722878813744, 72.5889641046524, 44.042612090706825, 1.1464191460981965, 0.8413938386365771, 6.820497214794159, 3.528641229495406, 0.30464167648460716, 39.50032822787762, 88.55226472020149, 77.83566176891327, 84.54287946224213, 76.77568584680557, 72.30234548449516, 41.096785962581635, 36.522849798202515, 59.82401266694069, 78.05475041270256, 83.91475036740303, 7.446107994765043, 0.38863290392328054, 0.26334543304983526, 0.14546725287800655, 0.12146290930104442], [0.05272546979540493, 0.05233398318523541, 0.013026459891989361, 0.12718913523713127, 0.04236808279529214, 0.08632544515421614, 0.8490566618274897, 49.69923555850983, 58.317879885435104, 44.09091129899025, 29.965412467718124, 43.58876824378967, 48.76067832112312, 44.87571358680725, 59.37288947403431, 71.45678445696831, 55.61833754181862, 71.01513415575027, 14.663470163941383, 0.2898101817118004, 0.49570130242500454, 1.365027828142047, 0.9148968569934368, 1.9920206652022898, 0.16164838772965595, 10.182257574051619, 72.48338297009468, 55.51571644842625, 65.19263818860054, 59.14492450654507, 63.75134512782097, 52.05581970512867, 60.19315525889397, 59.11872871220112, 57.23001345992088, 55.90774901211262, 55.344064459204674, 57.926303297281265, 64.73584190011024, 66.08559027314186, 60.74726812541485, 51.0917392373085, 56.18495933711529, 55.319008603692055, 54.32967469096184, 55.636933743953705, 50.00763081014156, 46.48146942257881, 50.723728984594345, 54.94785591959953, 50.882336273789406, 49.70519743859768, 50.21302118897438, 61.18890322744846, 45.20243525505066, 39.47955474257469, 58.753560706973076, 50.06549410521984, 43.76357786357403, 39.719629660248756, 38.59739787876606, 36.4611829072237, 39.36128608882427, 38.076331838965416, 42.659991681575775, 38.19960482418537, 37.30835884809494, 37.32506275177002, 37.90279895067215, 38.44151884317398, 38.98181565105915, 39.62198629975319, 40.81507667899132, 43.64990696310997, 45.30167832970619, 43.29776465892792, 43.95132578909397, 45.365359112620354, 46.62870392203331, 43.71993340551853, 50.21311238408089, 54.0638979524374, 52.96459034085274, 50.190119817852974, 44.964119642972946, 40.912788435816765, 37.394990399479866, 42.54832327365875, 44.08927358686924, 40.357535630464554, 43.83804626762867, 39.77871648967266, 39.30667161941528, 36.77476108074188, 47.22384698688984, 52.213264256715775, 47.915406078100204, 46.52011334896088, 52.57791168987751, 49.26891624927521, 44.522925317287445, 47.38535352051258, 45.478064864873886, 44.853051602840424, 41.631364077329636, 45.34681610763073, 38.86049576103687, 37.30678953230381, 35.232241451740265, 39.13253456354141, 37.54700504243374, 37.30807766318321, 37.29258209466934, 36.62252224981785, 38.387858122587204, 37.8648541867733, 38.92703779041767, 38.85355353355408, 37.86916695535183, 39.88842040300369, 45.60903623700142, 52.607208117842674, 55.147839188575745, 53.62103931605816, 52.51483127474785, 53.37358519434929, 51.18245556950569, 49.99147407710552, 46.439291685819626, 49.519094824790955, 50.46513006091118, 53.17103326320648, 52.61869490146637, 56.018152087926865, 51.201237961649895, 51.37269236147404, 56.9224389642477, 58.64914990961552, 60.61850443482399, 59.11813594400883, 57.32773281633854, 55.032382383942604, 56.69010043144226, 62.350987270474434, 60.251276940107346, 60.66658325493336, 61.37465626001358, 61.75981879234314, 58.36377762258053, 59.11405496299267, 63.47072258591652, 62.001162841916084, 48.77564191818237, 59.44467902183533, 23.416536077857018, 0.09166962088784203, 0.1421200777986087, 4.01090850122273, 0.7301814062520862, 0.2908380562439561, 41.96094699203968, 72.82230958342552, 69.34147596359253, 69.70494166016579, 65.57706356048584, 54.25329878926277, 49.446856901049614, 39.94577072560787, 37.307051718235016, 66.25619351863861, 44.69855949282646, 1.222117377910763, 0.1086479336663615, 0.13215563201811165, 0.07422226335620508, 0.11810054988018237, 0.040722730263951235, 0.08508297862135805, 0.01632741401408566, 0.05702135822502896, 0.03150023549096659, 0.08333283112733625, 1.3297600205987692, 63.02255943417549, 66.20686456561089, 48.110723197460175, 26.46694589406252, 64.23822060227394, 57.4333443492651, 51.361258774995804, 62.993939369916916, 78.81043866276741, 60.46474568545818, 80.94048276543617, 16.2862091884017, 0.2900151925859973, 1.0598906641826034, 1.649911010172218, 4.856668543070555, 1.8314693053252995, 0.16533619374968112, 11.87925411388278, 73.24740797281265, 56.85701787471771, 68.7593699991703, 60.03218449652195, 66.9364482164383, 55.75145959854126, 60.62448911368847, 60.47145992517471, 60.88384419679642, 57.47708760201931, 59.432679265737534, 59.715190306305885, 64.11844342947006, 62.86651320755482, 58.53540301322937, 54.228030145168304, 58.6343877017498, 57.37326577305794, 57.429491356015205, 56.54334470629692, 52.14304402470589, 48.690233901143074, 54.099901020526886, 56.16131700575352, 51.536638364195824, 50.677379071712494, 47.286638617515564, 63.63896615803242, 52.42388315498829, 42.23419792950153, 58.61508093774319, 51.64568491280079, 46.51125982403755, 41.522150337696075, 42.283454686403275, 38.002422004938126, 40.40507107973099, 39.82723988592625, 45.524027198553085, 41.02004528045654, 38.17411579191685, 39.05734419822693, 39.19681951403618, 40.05207762122154, 41.067219749093056, 41.99623189866543, 45.27564972639084, 46.28538094460964, 48.05979073047638, 46.1503703892231, 46.26923181116581, 44.95861753821373, 47.9879479855299, 44.4432207942009, 51.90181016921997, 54.01784062385559, 55.0859747081995, 51.75687834620476, 46.400788351893425, 40.885768085718155, 39.07405570149422, 42.37885236740112, 42.32625178992748, 42.931430116295815, 44.81386050581932, 41.0869786888361, 38.584539368748665, 36.30297839641571, 47.61779084801674, 51.97097405791283, 49.02075156569481, 48.847796246409416, 52.85854943096638, 49.87969547510147, 46.256734281778336, 46.52906186878681, 46.884164214134216, 46.751821115612984, 44.59661856293678, 46.18144892156124, 42.908825129270554, 39.46119412779808, 38.70365537703037, 40.41370801627636, 38.14034320414066, 38.90897735953331, 38.722076788544655, 39.153889417648315, 39.73875783383846, 39.40316364169121, 40.00758960843086, 39.59236688911915, 41.13923728466034, 41.7423827201128, 49.08207267522812, 53.41214932501316, 56.5043929964304, 53.57902117073536, 54.70148093998432, 55.70053093135357, 53.27209644019604, 52.00424127280712, 50.14611437916756, 51.57459832727909, 51.84672072529793, 54.526488929986954, 55.33469796180725, 55.608070492744446, 53.88174332678318, 53.1812547147274, 58.83722461760044, 57.966657131910324, 62.235291078686714, 61.49058423936367, 60.0114756077528, 57.61609934270382, 58.04357260465622, 65.29589384794235, 63.17161783576012, 61.90422244369984, 63.090427592396736, 66.69769182801247, 62.70993120968342, 63.28350283205509, 64.85548987984657, 64.32871654629707, 54.78368192911148, 63.5690613090992, 26.789491586387157, 0.03185713059792761, 0.11075659043854102, 5.6011103466153145, 1.0492068249732256, 0.22598384879529476, 46.354164853692055, 80.01954898238182, 74.05713692307472, 76.6445928812027, 69.38146501779556, 67.49665975570679, 38.91252636909485, 31.878469213843346, 46.044694259762764, 74.32832837104797, 59.44452702999115, 2.123647858388722, 0.1627666558488272, 0.061624206355190836, 0.05516438228369225, 0.044264767348067835, 0.09075671245227568, 0.1701515744207427, 0.08873408543877304, 0.20721272245282307, 0.23043281631544232, 0.24584848521044478, 1.5901805902831256, 73.92070144414902, 77.25312262773514, 61.532366797327995, 43.622016459703445, 58.28835166990757, 57.541551142930984, 61.66563704609871, 69.98514622449875, 85.66634237766266, 64.59999158978462, 88.34772929549217, 17.488736361265182, 0.43193609279114753, 3.2930239476263523, 3.9601501123979688, 7.3913192097097635, 7.574432333931327, 0.504190610954538, 15.52806532010436, 75.54957523941994, 58.14762622117996, 71.38692900538445, 61.612158715724945, 70.10677009820938, 57.288222536444664, 64.8636594414711, 64.12592142820358, 61.87817484140396, 61.760020181536674, 61.7841412872076, 61.75302475690842, 64.80066642165184, 61.305724158883095, 62.19928041100502, 57.522308975458145, 60.59461511671543, 58.07985305786133, 60.03628067672253, 57.70562633872032, 54.296221286058426, 52.551685497164726, 56.895376816391945, 57.30519242584705, 54.557841047644615, 53.329933136701584, 52.343889847397804, 56.35543718934059, 49.61519926786423, 46.290005296468735, 61.06184184551239, 55.4446716606617, 47.31417194008827, 43.46916206181049, 42.56265610456467, 40.735497549176216, 43.11050310730934, 44.13623906672001, 47.2673736512661, 42.30770878493786, 40.937228724360466, 40.93130104243755, 42.10477687418461, 44.12519305944443, 43.51799324154854, 43.10398645699024, 47.655321434140205, 49.31271269917488, 50.258010774850845, 47.12014675140381, 48.598677814006805, 49.95086185634136, 52.58098192512989, 47.154709696769714, 55.219047367572784, 58.63776572048664, 59.01542365550995, 53.450029492378235, 45.895065888762474, 43.96914683282375, 42.03338250517845, 45.048361122608185, 45.0959687680006, 45.86639642715454, 46.37613907456398, 43.099023923277855, 39.89677615463734, 35.57583801448345, 49.34055760502815, 51.846238151192665, 50.184108540415764, 52.351128458976746, 55.46397842466831, 53.562552854418755, 47.18094728887081, 49.39584083855152, 49.278947710990906, 50.274380296468735, 46.98306530714035, 51.156681552529335, 44.943581745028496, 42.86160886287689, 40.64437843859196, 43.13572235405445, 40.60887314379215, 40.48914156854153, 40.400480926036835, 39.85758125782013, 41.391061171889305, 43.29310990869999, 41.88305117189884, 41.780889853835106, 43.3977372944355, 43.17129984498024, 50.746170580387115, 56.07129603624344, 59.84696723520756, 56.974860951304436, 57.186110615730286, 58.5842227935791, 56.7096883803606, 54.0028390288353, 51.77789121866226, 53.546749502420425, 54.60672162473202, 57.24813088774681, 57.2831080108881, 58.45022678375244, 55.87205372750759, 55.21357946097851, 60.14175921678543, 61.776078119874, 66.21214628219604, 64.51457977294922, 62.45221383869648, 59.99301999807358, 61.46425545215607, 68.3199767768383, 65.30035480856895, 62.93499693274498, 66.05529829859734, 66.31125256419182, 64.88236203789711, 64.8230092227459, 68.42410638928413, 66.18489414453506, 58.24571415781975, 68.0576540529728, 30.728709809482098, 0.2209481393219903, 0.557557619176805, 13.72360959649086, 5.099988961592317, 0.6880455266218632, 51.92514091730118, 85.20876333117485, 80.13324648141861, 80.46114608645439, 77.3728846013546, 73.3442647755146, 66.84561789035797, 52.5642666220665, 56.34316384792328, 82.80068054795265, 74.46320593357086, 2.9427473433315754, 0.2751425531459972, 0.2430758363334462, 0.2321464946726337, 0.2379579859552905], [0.0233558178297244, 0.015001680367277004, 0.0653485074872151, 0.059724315724452026, 0.056266705360030755, 0.21070127666462213, 0.2876537380507216, 42.793755903840065, 63.63592252135277, 39.953362718224525, 19.698760472238064, 23.075396083295345, 36.520011350512505, 49.13765229284763, 67.00498133897781, 68.7949588894844, 58.40496741235256, 70.45885920524597, 21.534470468759537, 0.2091189584461972, 0.7758302567526698, 0.9055461524985731, 1.3689543236978352, 0.33585005498025566, 0.024704235220269766, 9.932832308113575, 75.48319280147552, 53.67683932185173, 63.83452266454697, 57.89859518408775, 60.76543875038624, 56.78634166717529, 59.858875796198845, 51.47895745933056, 58.58069658279419, 58.557050451636314, 63.73629793524742, 61.5331419557333, 58.33355784416199, 52.111889496445656, 55.23774616420269, 53.544811606407166, 51.461546793580055, 49.97621789574623, 53.24928246438503, 52.49003380537033, 56.83817848563194, 50.995338410139084, 48.40331509709358, 50.89545696973801, 58.91269996762276, 61.18702992796898, 63.10841202735901, 44.24095384776592, 34.09277379512787, 53.007790222764015, 52.260822504758835, 49.58445131778717, 39.783394038677216, 41.24519839882851, 33.810251355171204, 37.926882058382034, 37.139568105340004, 40.293737053871155, 36.97884812951088, 36.32103882730007, 39.67142164707184, 37.98592709004879, 35.65984770655632, 35.17356500029564, 37.65431888401508, 40.8346152305603, 41.257099360227585, 42.55246125161648, 44.62446726858616, 45.18826201558113, 44.685871973633766, 42.35579900443554, 47.28162668645382, 47.29839138686657, 48.1581674516201, 50.61105363070965, 51.994555592536926, 51.05565257370472, 49.29259277880192, 42.147076204419136, 35.83331219851971, 42.67791152000427, 42.5533352047205, 40.664699748158455, 44.73414458334446, 40.22698223590851, 38.60281638801098, 42.54370652139187, 48.56699511408806, 50.10403163731098, 51.41829751431942, 49.54079546034336, 52.119907066226006, 48.463222682476044, 45.64811334013939, 45.86971364915371, 44.10653606057167, 44.58666309714317, 42.89988420903683, 42.78065040707588, 40.17484903335571, 38.17942030727863, 37.588582411408424, 35.916850715875626, 35.902487486600876, 37.80260592699051, 35.376185327768326, 36.8185119330883, 39.912784695625305, 37.84387931227684, 38.89088273048401, 41.04795478284359, 37.901252433657646, 40.682638585567474, 40.607957392930984, 50.789226070046425, 54.0331955999136, 54.50484909117222, 54.10238988697529, 52.95683115720749, 52.314194440841675, 54.5866397023201, 51.25846669077873, 49.993894547224045, 47.76058338582516, 50.86619853973389, 50.9591643512249, 55.38962781429291, 52.53261812031269, 54.240824058651924, 54.77334648370743, 55.737966522574425, 55.498419776558876, 56.672609969973564, 52.310945615172386, 58.348665833473206, 55.68565092980862, 56.749529242515564, 58.216668516397476, 60.6827399879694, 59.88277651369572, 60.296194329857826, 63.36252339184284, 63.75695362687111, 60.33455327153206, 62.67571024596691, 45.48925146460533, 53.68433631956577, 16.418854370713234, 0.23017989238724113, 0.22678971727145836, 6.023964481428266, 0.9248546976596117, 0.4287765029584989, 45.3043457865715, 72.93669104576111, 67.54076018929482, 68.51847052574158, 60.44744901359081, 53.730317652225494, 54.10688504576683, 46.45868204534054, 41.54334180057049, 65.20741179585457, 43.73144678771496, 0.28569874295499176, 0.03312010638182983, 0.09310971392551437, 0.02328130620298907, 0.06205860394402407, 0.037427665083669126, 0.018371377773291897, 0.1500269488315098, 0.02896358957514167, 0.09109393693506718, 0.2824225171934813, 0.35638629051391035, 55.08179113268852, 70.62425673007965, 46.63444921374321, 28.15231505781412, 31.351051814854145, 40.38217730820179, 54.978470876812935, 67.62999460101128, 76.47912696003914, 60.305481031537056, 78.20803418755531, 23.671971671283245, 0.21674985444406047, 0.16897193068871275, 1.8933051684871316, 4.226400163024664, 1.0127009963616729, 0.1144775704597123, 13.476207721978426, 76.66884317994118, 54.35582488775253, 67.22486034035683, 60.36198779940605, 64.66021075844765, 58.92412215471268, 60.325657948851585, 55.34518539905548, 59.28348407149315, 57.526724338531494, 64.12871807813644, 62.26343996822834, 57.998085245490074, 54.60510291159153, 59.26059789955616, 54.583162888884544, 55.49180433154106, 52.57152043282986, 56.71143248677254, 54.368527606129646, 58.62219035625458, 52.37723305821419, 51.31507225334644, 53.972900435328484, 59.57916900515556, 57.38993547856808, 64.33296471834183, 51.29116013646126, 37.01435722410679, 53.6133599281311, 55.057267248630524, 51.3298686593771, 42.34458580613136, 42.61017255485058, 35.92345476150513, 38.515098094940186, 39.707356318831444, 41.989464461803436, 38.20965148508549, 37.72247962653637, 40.215050876140594, 39.151795729994774, 38.716665878891945, 37.658316269516945, 39.98373068869114, 42.26210743188858, 43.215381279587746, 44.994252026081085, 48.51396895945072, 47.636694833636284, 47.79910571873188, 45.34249573945999, 47.633309215307236, 47.63034537434578, 50.300294905900955, 52.06026926636696, 55.785619765520096, 53.677169904112816, 50.36720171570778, 43.97714160382748, 39.86048050224781, 43.76633271574974, 43.682642206549644, 44.05286394059658, 45.637614503502846, 42.16801308095455, 39.72279869019985, 41.889210641384125, 49.42553624510765, 50.30688375234604, 52.28947676718235, 50.296958684921265, 54.21471945941448, 49.501592963933945, 45.04326939582825, 46.803110763430595, 48.54187846183777, 46.73343010246754, 45.84460459649563, 46.18668884038925, 43.66712383925915, 39.35066565871239, 41.143675446510315, 37.805379778146744, 36.815194711089134, 38.811945766210556, 37.493097335100174, 38.50790128111839, 40.48361286520958, 38.593784272670746, 39.15239229798317, 41.86681464314461, 40.23874640464783, 43.165223971009254, 41.99540734291077, 52.33641944825649, 54.17688488960266, 54.764511957764626, 54.702453687787056, 54.31674398481846, 54.69029814004898, 55.18309749662876, 53.12909871339798, 52.98423908650875, 50.76479718089104, 53.54291930794716, 53.82622070610523, 57.65438228845596, 55.95811150968075, 55.318811014294624, 57.185012474656105, 56.52113489806652, 56.833945512771606, 59.17287200689316, 56.56161792576313, 59.43576470017433, 57.315201088786125, 58.50382670760155, 60.19445098936558, 63.874549716711044, 61.357199996709824, 64.60946828126907, 63.50384160876274, 67.55383148789406, 64.7883702814579, 65.11326044797897, 50.155587270855904, 60.38414441049099, 16.773616634309292, 0.2342551143374294, 0.44264955853577703, 3.3500750362873077, 0.5734250333625823, 0.6835415214300156, 49.86752092838287, 77.56787493824959, 75.24920135736465, 71.82880729436874, 63.866053372621536, 62.630428075790405, 50.932508781552315, 46.142151430249214, 47.51132056117058, 75.12320011854172, 52.626701071858406, 0.9301872365176678, 0.10388459239038639, 0.04725299157144036, 0.026251236486132257, 0.05952110455837101, 0.16423738474259153, 0.1370032664272003, 0.28346437378786504, 0.21253531653201208, 0.19430996559094638, 0.3960799996275455, 0.7666494743898511, 68.52773442864418, 80.47960549592972, 57.13627249002457, 32.10210241377354, 36.13940477371216, 51.432991325855255, 61.156730353832245, 72.89191424846649, 81.59613758325577, 67.2453336417675, 83.75832036137581, 26.551529355347157, 0.3233643702697009, 3.4653375763446093, 3.9504069602116942, 7.524683503434062, 4.478018386289477, 0.314653129898943, 17.130217999219894, 79.39467251300812, 54.988863319158554, 68.37222397327423, 62.90590949356556, 66.11281961202621, 58.439853340387344, 62.930729761719704, 58.92764836549759, 61.9510093331337, 59.766650944948196, 64.82212007045746, 62.74062976241112, 60.88608227670193, 58.86626645922661, 60.77817566692829, 55.90847097337246, 56.37485034763813, 54.645874723792076, 57.584796622395515, 58.11203733086586, 60.993931889534, 55.072230845689774, 54.84659135341644, 57.13740862905979, 59.82533119618893, 57.522635757923126, 59.304557740688324, 48.40020306408405, 41.18728570640087, 56.96339316666126, 57.89579853415489, 54.17791463434696, 42.53492899239063, 44.65136982500553, 37.82161630690098, 41.153904497623444, 41.48857153952122, 43.348320946097374, 40.58626815676689, 40.604818761348724, 42.15742684900761, 41.81015968322754, 41.656549125909805, 38.386623188853264, 42.26947903633118, 43.64254675805569, 45.22080346941948, 47.341579869389534, 50.98813019692898, 49.94427300989628, 50.69972187280655, 47.07438960671425, 51.009625643491745, 50.810371935367584, 53.81653122603893, 54.72815550863743, 57.78345376253128, 55.15202656388283, 53.60583633184433, 44.555424973368645, 41.624855026602745, 45.24455979466438, 44.68506261706352, 46.54950097203255, 48.193585351109505, 44.26429599523544, 40.245871022343636, 43.757547587156296, 51.973546519875526, 50.79625189304352, 55.737195163965225, 50.430646911263466, 58.36568132042885, 53.18060114979744, 48.88395130634308, 49.42796051502228, 49.77076292037964, 50.11009231209755, 47.69820973277092, 48.832015693187714, 45.63377670943737, 42.42194205522537, 43.162343725562096, 40.297905430197716, 39.64043810963631, 41.69852167367935, 38.583528622984886, 40.8585349470377, 43.83357010781765, 40.40882907807827, 42.28579916059971, 44.54352021217346, 43.35658550262451, 45.31336650252342, 44.08389687538147, 54.98966507613659, 57.78622381389141, 58.41569043695927, 57.14355669915676, 57.01280951499939, 55.15324629843235, 60.291098803281784, 55.768049508333206, 54.7786395996809, 53.222505301237106, 56.59245707094669, 55.89715898036957, 59.91892397403717, 58.54133829474449, 57.86648690700531, 60.71140564978123, 59.001520201563835, 60.549462139606476, 63.21255683898926, 57.24799409508705, 61.70947149395943, 59.765020832419395, 61.76018737256527, 62.96989046037197, 65.2511778473854, 64.88097131252289, 67.19631627202034, 67.7895936369896, 69.054956138134, 67.75788053870201, 68.49864318966866, 55.124231055378914, 66.70602098107338, 21.922395452857018, 0.20849289750913158, 0.6501183367799968, 12.283521071076393, 2.7069939812645316, 0.6930275936610997, 54.697350561618805, 83.13408225774765, 79.27488014101982, 78.7482587993145, 70.08318096399307, 70.7769325375557, 70.44251248240471, 60.42053505778313, 60.49797870218754, 85.59122800827026, 67.79737561941147, 1.5568592282943428, 0.16497295699082315, 0.19438845512922853, 0.09590441943146288, 0.2534105989616364], [0.10587098033283837, 0.03579579366487451, 0.05007849249523133, 0.09718733301269822, 0.06835242442321032, 0.23776560643455014, 0.24599562340881675, 40.55404208600521, 65.48668920993805, 43.873353973031044, 28.505990579724312, 24.653983376920223, 29.17487818747759, 44.634882509708405, 62.66212597489357, 70.29951855540276, 58.063840717077255, 68.37823525071144, 27.276534251868725, 0.13792905112495646, 0.2595492289401591, 1.460747541859746, 4.52362971380353, 0.8063015935476869, 0.05726929863158148, 18.879036158323288, 64.00301322340965, 46.868778839707375, 60.92295549809933, 58.0714251101017, 61.77877977490425, 49.77523148059845, 54.28708657622337, 59.522540643811226, 62.65931032598019, 57.85050116479397, 57.1244703233242, 52.243579030036926, 55.83344019949436, 55.94307191669941, 52.23421633243561, 47.026158794760704, 45.68863816559315, 48.707127794623375, 49.99948024749756, 48.694736659526825, 52.43159294128418, 51.70232467353344, 55.527909994125366, 52.17611365020275, 52.28211276233196, 43.82077619433403, 39.14816692471504, 37.3500844091177, 53.41156415641308, 55.45233204960823, 55.75919218361378, 45.90196631848812, 40.880022794008255, 38.492382913827896, 37.87839666008949, 38.446325585246086, 37.64991872012615, 37.42942415177822, 38.5277134180069, 40.07755525410175, 36.231071054935455, 36.34968928992748, 34.89232309162617, 36.89454585313797, 40.13608731329441, 41.39509655535221, 40.8651427924633, 39.906834214925766, 46.30999222397804, 44.93469402194023, 45.9463707357645, 43.97589907050133, 45.027694031596184, 43.71248580515385, 44.34897065162659, 47.28845112025738, 49.92056608200073, 51.38506069779396, 51.112630516290665, 44.39011864364147, 36.106661930680275, 42.183219864964485, 43.88441517949104, 39.35012988746166, 43.67020547389984, 39.80518966913223, 39.07141484320164, 46.384787410497665, 52.4900908023119, 49.315262362360954, 54.524311646819115, 52.19837285578251, 49.921546429395676, 45.73943004012108, 44.61749844253063, 44.27860602736473, 44.710756838321686, 42.56720446050167, 42.62586571276188, 43.189732655882835, 39.44950595498085, 39.866666570305824, 36.59326381981373, 38.38390253484249, 34.78400610387325, 35.51269680261612, 35.80736719071865, 37.56035752594471, 36.6533499956131, 36.6089341789484, 37.67915055155754, 39.37167093157768, 37.551538199186325, 40.28921529650688, 43.0465829372406, 44.52742427587509, 49.41464602947235, 54.05727110803127, 53.442920073866844, 55.2668260037899, 54.72121708095074, 54.60655063390732, 52.342407926917076, 51.294089779257774, 51.88978001475334, 51.12937621772289, 50.7032784819603, 54.23110418021679, 52.93516851961613, 57.73183353245258, 57.10106737911701, 52.95064888894558, 51.46436244249344, 51.80844157934189, 51.51866152882576, 57.21731074154377, 55.01020297408104, 57.73067459464073, 56.30212604999542, 59.158121198415756, 60.842681005597115, 62.99412935972214, 57.35743962228298, 64.36024725437164, 59.92632977664471, 63.09443637728691, 44.522822722792625, 50.615947768092155, 8.66147942841053, 0.15014713222626597, 0.3192064433824271, 2.597933658398688, 0.11373186047421768, 0.592890438856557, 55.99097214639187, 70.5027012526989, 71.4506059885025, 62.27236568927765, 67.40346595644951, 54.45097178220749, 43.440093621611595, 31.022517643868923, 42.71821215748787, 72.48440131545067, 35.80709360539913, 0.6308789004106075, 0.09068579282029532, 0.07730348981567658, 0.050754833937389776, 0.08414631403866224, 0.007849864814488683, 0.06599374552024528, 0.02240170906588901, 0.05844478262588382, 0.031991440773708746, 0.36950772861018777, 0.24244076572358608, 49.158706963062286, 72.38028690218925, 53.41588452458382, 29.10316653549671, 30.092566944658756, 42.22064785659313, 50.20165979862213, 66.2448701262474, 74.4708663225174, 63.48816744983196, 73.68558526039124, 30.065320506691933, 0.18162902182666585, 0.06537497989484109, 2.181898020207882, 4.646330829709768, 0.793782512191683, 0.11801167769590393, 21.595886573195457, 68.11146676540375, 49.60159979760647, 62.37242192029953, 58.85469987988472, 63.210341557860374, 51.40325412154198, 56.77956283092499, 61.034559309482574, 63.46939265727997, 58.39330203831196, 59.17363576591015, 56.10593497753143, 58.28075587749481, 57.405514642596245, 55.66007450222969, 49.099468141794205, 50.33181421458721, 49.778810888528824, 52.13012471795082, 52.583850771188736, 54.11300651729107, 53.867915868759155, 56.462682634592056, 50.36146402359009, 50.83977475762367, 47.883404195308685, 45.35147465765476, 39.41570296883583, 54.151935428380966, 57.02230520546436, 56.7776895314455, 48.63447189331055, 44.39068481326103, 41.24986834824085, 38.34596537053585, 38.86136591434479, 39.82079543173313, 39.979018941521645, 38.60893405973911, 39.67379651963711, 38.601938635110855, 37.908935621380806, 38.39191250503063, 37.682232186198235, 40.60410439968109, 42.208138927817345, 42.80453972518444, 42.903543412685394, 48.00693176686764, 46.35072223842144, 48.18066984415054, 46.05122230947018, 47.98452816903591, 46.342347487807274, 49.05603267252445, 51.260879561305046, 51.969590932130814, 53.87014254927635, 52.39536568522453, 45.401160791516304, 39.22454662621021, 44.738206565380096, 44.63860251009464, 42.401742339134216, 45.069309398531914, 41.12570621073246, 40.133982226252556, 46.034157425165176, 53.59055735170841, 51.267369613051414, 54.5401643961668, 52.727768048644066, 51.733577996492386, 47.98960089683533, 46.41802042722702, 47.327653616666794, 47.750779911875725, 44.96908597648144, 45.597678646445274, 45.39963327348232, 42.8902593255043, 41.89149431884289, 39.28117498755455, 39.15194392204285, 37.78922684490681, 37.48998910188675, 36.89659394323826, 37.9358571767807, 38.53353850543499, 38.47064808011055, 38.90926614403725, 41.14279009401798, 40.610351264476776, 43.49940083920956, 44.10180151462555, 47.66273483633995, 51.70630685985088, 56.007132679224014, 54.528350830078125, 56.013402342796326, 56.02636344730854, 57.382662668824196, 55.35568803548813, 53.1844275444746, 54.98540550470352, 52.70718455314636, 52.42970824241638, 56.078660041093826, 56.195632964372635, 58.80387380719185, 59.619207456707954, 55.44012330472469, 53.5220318287611, 53.37766617536545, 56.16129420697689, 58.531196638941765, 56.79524078965187, 60.72712540626526, 58.31592679023743, 60.875233858823776, 61.091704443097115, 65.78066423535347, 61.34856306016445, 64.83377784490585, 63.048914819955826, 63.57337027788162, 50.10734125971794, 57.16294325888157, 10.120671428740025, 0.1518477636273019, 1.8990135309286416, 4.13682471960783, 0.4603896487969905, 0.5331457103602588, 59.66313309967518, 75.16938284039497, 78.85156765580177, 65.75912699103355, 72.32886806130409, 60.25820016860962, 59.31715406477451, 40.42962156236172, 50.16755662858486, 82.09106102585793, 48.191981837153435, 0.6152829935308546, 0.10803759141708724, 0.0513823123765178, 0.025803929238463752, 0.03823460967396386, 0.2114814965170808, 0.2503726916620508, 0.18457666912581772, 0.1586296278401278, 0.16107050701975822, 0.5372955033089966, 0.3294465970247984, 57.38318704068661, 83.65305081009865, 62.87926912307739, 43.2052244246006, 39.33177687227726, 42.58633263409138, 61.246109157800674, 74.11098763346672, 82.69158840179443, 67.83836022019386, 82.94932097196579, 32.6220703125, 0.2769977442221716, 2.7053142338991165, 5.780256483703852, 15.307088177651167, 5.035315006971359, 0.21802131668664515, 25.626377798616886, 72.23829612135887, 51.33567474782467, 64.13061037659645, 58.378095254302025, 65.65882757306099, 54.87872622907162, 59.1421240568161, 62.43013322353363, 65.59919357299805, 62.01119810342789, 62.215114161372185, 59.267247542738914, 60.95438741147518, 59.15276728570461, 57.222212478518486, 51.918312683701515, 51.88754193484783, 52.994867116212845, 55.9707610309124, 54.85929027199745, 56.640273705124855, 56.18319623172283, 57.94204205274582, 51.61419220268726, 56.13800145685673, 50.83513520658016, 49.566953256726265, 44.4780383259058, 57.29123957455158, 59.201020896434784, 59.7076553106308, 51.144959181547165, 47.243609726428986, 42.369326278567314, 40.781030505895615, 41.06045611202717, 42.12702468037605, 42.028077989816666, 41.782086789608, 43.525965213775635, 40.66294424235821, 42.45711296796799, 38.588673546910286, 40.40230102837086, 44.73204709589481, 46.25808700919151, 45.75085982680321, 45.1127752661705, 52.184830382466316, 47.90143422782421, 50.048759803175926, 48.2055851072073, 48.903182074427605, 48.769015073776245, 50.8856762945652, 54.27692212164402, 53.724906742572784, 55.81046663224697, 53.09856355190277, 47.96320751309395, 42.08265446126461, 47.00439736247063, 45.96044138073921, 43.90553444623947, 47.867000475525856, 40.978388115763664, 39.4317951053381, 47.15776473283768, 53.634653985500336, 52.84448258578777, 58.236640244722366, 56.45906142890453, 55.614792332053185, 51.542615443468094, 48.9173287153244, 50.25213249027729, 51.2169349193573, 47.000631764531136, 48.812602534890175, 49.304406344890594, 44.90733928978443, 44.2459087818861, 40.30461207032204, 42.71829955279827, 39.506115317344666, 38.55876915156841, 41.37224838137627, 41.41696058213711, 41.25588722527027, 40.61490722000599, 40.77600717544556, 42.78173714876175, 41.14807941019535, 46.18293084204197, 45.118189975619316, 50.70363566279411, 55.021697357296944, 60.20350590348244, 58.20823296904564, 58.54810193181038, 58.53944979608059, 61.11180156469345, 58.499194756150246, 56.640813276171684, 58.03933963179588, 54.42463159561157, 54.803220480680466, 59.29876305162907, 58.849380165338516, 61.46378427743912, 60.5579698830843, 57.97261901199818, 55.52975669503212, 56.918924152851105, 56.790536642074585, 61.81473724544048, 60.59918247163296, 61.78146243095398, 61.047387421131134, 65.56660652160645, 66.2675929069519, 69.78505656123161, 62.29091629385948, 71.53118446469307, 66.53957471251488, 68.40526700019836, 54.316876977682114, 66.92665234208107, 11.550344713032246, 0.1392291602678597, 1.766219800338149, 6.577460831031203, 1.0698473174124956, 0.6664579350035638, 66.31544753909111, 81.20788961648941, 82.69221916794777, 74.2788778245449, 76.44106820225716, 71.71736687421799, 60.69216728210449, 46.720343604683876, 62.73200802505016, 93.17744493484497, 61.297174617648125, 1.664624058175832, 0.22931319748749956, 0.23737952637020499, 0.20079994312254712, 0.29048948432318866], [0.06878358995891176, 0.04048795184644405, 0.1167332763725426, 0.0617103956756182, 0.12151938673923723, 0.2564635273301974, 0.2290401019854471, 26.89692322164774, 70.78082352876663, 43.40678080916405, 43.18068914115429, 22.24075186997652, 15.93196939677, 48.02029184997082, 70.83052486181259, 69.16965678334236, 60.99824845790863, 63.45460765063763, 38.58586549758911, 0.022464106987172272, 0.17141506599728018, 1.3356563542038202, 2.364763682708144, 0.6740510556846857, 0.05003076497814618, 24.55846980214119, 60.70437602698803, 48.40323910117149, 53.70426245033741, 49.40445877611637, 50.63559651374817, 51.873763874173164, 63.86531621217728, 59.96511809527874, 58.167138174176216, 53.60688507556915, 55.603069961071014, 55.34718029201031, 51.89147472381592, 47.76661366224289, 43.83193239569664, 44.32837575674057, 43.39049108326435, 43.8253815472126, 47.817033156752586, 47.93677993118763, 48.61264206469059, 50.910667553544044, 48.43238353729248, 39.937376976013184, 44.636322632431984, 47.15734675526619, 54.4727598130703, 55.301806926727295, 52.913179099559784, 52.183679044246674, 51.47559083998203, 39.34057340025902, 42.82184399664402, 39.816528260707855, 36.42754711210728, 36.00067041814327, 36.53826557099819, 39.48488585650921, 35.480527728796005, 35.69619655609131, 38.942673951387405, 35.296693593263626, 37.09063433110714, 35.56452602148056, 36.424492076039314, 36.545591577887535, 38.982993587851524, 41.869299709796906, 45.026956871151924, 45.18852420151234, 46.26357011497021, 45.73643580079079, 44.88705977797508, 45.01015417277813, 45.970279052853584, 47.2819534689188, 49.50020223855972, 49.744475930929184, 46.9040447473526, 46.71731136739254, 39.66381445527077, 40.18143408000469, 43.5989934951067, 37.472415044903755, 44.93738807737827, 41.043870002031326, 43.67443844676018, 48.38585123419762, 50.74536882340908, 49.794728234410286, 51.57531648874283, 51.60848490893841, 48.08462239801884, 46.152065098285675, 45.48120729625225, 43.114356100559235, 43.816003650426865, 41.794223338365555, 42.87669025361538, 43.421166837215424, 42.32611119747162, 38.30130256712437, 35.874205604195595, 35.31456023454666, 35.28085224330425, 36.484844237565994, 34.73430097103119, 35.84807060658932, 38.83742339909077, 37.880292758345604, 38.02605673670769, 38.16629201173782, 38.64898391067982, 38.0903796851635, 41.23677805066109, 40.588441640138626, 47.16707423329353, 53.32759626209736, 54.94452349841595, 54.197141602635384, 55.919125601649284, 54.58781763911247, 54.89802919328213, 56.090929582715034, 50.82980029284954, 54.268805757164955, 52.987586706876755, 51.54125891625881, 52.77389757335186, 55.30385501682758, 54.777347669005394, 51.33044242858887, 43.80225978791714, 48.90559874475002, 53.135345578193665, 60.627745538949966, 58.634133115410805, 60.763858035206795, 57.038317546248436, 61.70034818351269, 52.590443417429924, 60.95961973071098, 65.56431904435158, 70.72309702634811, 58.214696422219276, 56.65678381919861, 47.98408359289169, 56.92755348980427, 5.667391614988446, 0.18080020614434034, 0.38166787766385823, 0.6174937624018639, 0.15578951773932204, 1.567301305476576, 62.14106373488903, 70.30254319310188, 62.75152377784252, 63.56499932706356, 63.42802047729492, 62.0938740670681, 24.01465818285942, 21.13834362477064, 41.88429370522499, 65.48836871981621, 32.67525605857372, 0.7040810224134475, 0.1294022344518453, 0.12321838541538455, 0.05326845472154673, 0.11189284079591744, 0.021447689359774813, 0.05554367911827285, 0.140703035867773, 0.12048002376104705, 0.10052036275737919, 0.49390257394406945, 0.3303731535561383, 35.16186162829399, 78.79007175564766, 52.66196697950363, 41.842689737677574, 26.860673166811466, 29.283345267176628, 50.756297037005424, 74.15051311254501, 71.6510072350502, 65.41695535182953, 70.76992571353912, 40.62096789479256, 0.13233638950623572, 0.2608204388525337, 1.854769536294043, 3.8534511253237724, 0.926517880288884, 0.08959660946857184, 29.164491444826126, 65.45727878808975, 48.417853116989136, 55.85685834288597, 49.81278866529465, 55.61544589698315, 55.21613672375679, 66.58794611692429, 59.780926778912544, 60.59593744575977, 56.78717762231827, 58.58665846288204, 56.078660041093826, 55.53457483649254, 48.5348716378212, 46.84734798967838, 45.08412480354309, 46.886307299137115, 47.31623902916908, 49.90513131022453, 50.07529757916927, 50.89040704071522, 52.87313684821129, 49.482479989528656, 42.59988650679588, 47.20758765935898, 48.16112369298935, 54.60946887731552, 57.342932000756264, 55.83747558295727, 54.54750180244446, 54.603290408849716, 42.441093027591705, 44.672458693385124, 40.99535420536995, 39.492797031998634, 39.03016425669193, 38.34148161113262, 39.21222008764744, 38.22063289582729, 36.791852563619614, 41.46725848317146, 37.10370182991028, 39.313268065452576, 38.99359121918678, 39.28063161671162, 38.44684235751629, 41.78356871008873, 43.8260693103075, 47.86818981170654, 45.973805263638496, 47.12328538298607, 46.85875117778778, 46.6075124591589, 47.7051405608654, 47.58012346923351, 52.06222616136074, 53.536072075366974, 50.04451543092728, 48.90173055231571, 46.2145983427763, 43.136892691254616, 41.91700614988804, 45.14720901846886, 40.019186586141586, 45.49573391675949, 42.264588698744774, 44.373160153627396, 48.57445411384106, 51.60406954586506, 52.449201196432114, 53.89903999865055, 51.445982828736305, 50.116563364863396, 46.509872898459435, 47.304862439632416, 45.79732373356819, 48.11329185962677, 45.056310296058655, 45.14971308410168, 45.31531199812889, 43.53275544941425, 38.684398010373116, 37.44216486811638, 37.77994394302368, 38.30838918685913, 38.467881828546524, 36.03654429316521, 38.09446066617966, 38.89699660241604, 38.95848490297794, 40.59465430676937, 39.796685725450516, 39.731625616550446, 39.51097525656223, 42.91236273944378, 41.696321591734886, 50.21573044359684, 55.56954436004162, 56.23410589993, 56.810679361224174, 55.89800253510475, 56.04538142681122, 55.0912906229496, 57.28243924677372, 52.66680411994457, 55.72616055607796, 56.71437732875347, 54.3233822286129, 56.10109783709049, 58.54089751839638, 55.391451716423035, 52.835359275341034, 45.91250315308571, 51.08005866408348, 55.325920432806015, 63.87211784720421, 61.31055749952793, 63.51628974080086, 62.22120523452759, 62.94068902730942, 56.10053166747093, 63.59835773706436, 67.16119855642319, 71.81341052055359, 60.696723237633705, 61.641356348991394, 51.698247492313385, 59.951590821146965, 6.845184015110135, 0.21006267343182117, 1.5349611220881343, 2.5658370181918144, 0.3859100234694779, 1.7613395559601486, 68.45439836382866, 75.50981417298317, 70.71720734238625, 68.10623064637184, 71.36427462100983, 66.54732629656792, 39.680655151605606, 31.26958418637514, 47.069601863622665, 76.29523202776909, 40.759926438331604, 1.0440762690268457, 0.11994206317467615, 0.14237911702366546, 0.05260606936644763, 0.08404692562180571, 0.11814835161203519, 0.15552185475826263, 0.3135333477985114, 0.3758457291405648, 0.2081415944849141, 0.6761354219634086, 0.42049698473419994, 38.868859112262726, 91.06194645166397, 61.408653035759926, 59.60240475833416, 31.96517676115036, 28.91034208238125, 60.7745810598135, 79.170241355896, 78.5040383040905, 69.0773293375969, 76.39799371361732, 44.736044481396675, 0.14036025269888341, 0.7038707274477929, 4.6861940156668425, 7.6848050113767385, 2.69939296413213, 0.18844230857212096, 34.14803043007851, 68.41690957546234, 50.654690489172935, 57.1896406263113, 54.73162852227688, 60.15161208808422, 57.82564289867878, 65.11729583144188, 65.30447378754616, 63.60579013824463, 57.908809036016464, 61.274786219000816, 59.69631291925907, 58.39163392782211, 50.0799485296011, 47.7949183434248, 48.50568540394306, 50.27645878493786, 49.83570523560047, 54.2919959127903, 51.59646615386009, 51.708229556679726, 53.82732644677162, 55.04128910601139, 47.028921246528625, 48.55542093515396, 49.62171211838722, 57.07039922475815, 58.69481585919857, 59.72852759063244, 58.192391619086266, 56.9388996809721, 42.74200268089771, 46.40027157962322, 43.195641338825226, 41.75435587763786, 38.800667971372604, 40.55736690759659, 43.108610808849335, 39.49938207864761, 39.11415874958038, 43.96367132663727, 37.72066332399845, 40.939132422208786, 41.4292149245739, 41.264353170990944, 40.23018926382065, 44.59067948162556, 45.81208594143391, 48.444014713168144, 49.51710373163223, 49.65555690228939, 49.86873306334019, 47.936646938323975, 51.21481843292713, 51.47576183080673, 51.88688836991787, 53.897371888160706, 52.285296991467476, 49.40086416900158, 48.35888788104057, 48.00817050039768, 45.75467102229595, 45.89716337621212, 41.05648912489414, 47.10955671966076, 43.19939933717251, 46.68025955557823, 49.83294278383255, 53.74473787844181, 55.49890235066414, 56.405469104647636, 58.3791060000658, 52.36754737794399, 50.05733974277973, 51.14725425839424, 47.56108269095421, 50.61337150633335, 48.45763698220253, 47.015070989727974, 50.08477807044983, 46.444968581199646, 42.860985696315765, 39.08108912408352, 39.847382605075836, 39.35984596610069, 39.8553241789341, 38.547734543681145, 40.16303926706314, 40.863413885235786, 41.885437443852425, 43.38829480111599, 41.59465804696083, 43.019858971238136, 40.40991581976414, 43.93349714577198, 43.54706548154354, 51.745178773999214, 59.13593418896198, 58.77769701182842, 59.615761041641235, 59.376951456069946, 58.71251530945301, 57.48386263847351, 60.864077657461166, 54.82896409928799, 59.75523255765438, 54.39657770097256, 55.92756114900112, 59.111376106739044, 59.91747245192528, 59.321409836411476, 55.928944274783134, 48.07700760662556, 53.317200019955635, 56.61820828914642, 66.87096253037453, 61.92322142422199, 66.4426039159298, 64.57207068800926, 65.90562433004379, 58.54252763092518, 68.20516973733902, 71.57080113887787, 75.80555990338326, 63.60483638942242, 64.80173796415329, 55.08149474859238, 66.66868418455124, 9.2561218701303, 0.29705470078624785, 2.11635391227901, 0.7070698589086533, 0.6052962981630117, 1.860038903541863, 74.59608480334282, 80.2240464091301, 76.40309303998947, 75.04042536020279, 75.13000175356865, 77.3777787387371, 35.7972027361393, 34.07233849167824, 61.498844996094704, 84.90358650684357, 52.730712890625, 1.5773350233212113, 0.25913335906807333, 0.2889958972809836, 0.22151200828375295, 0.1829174644080922], [0.07650085710338317, 0.079562847095076, 0.020006134291179478, 0.10536124362261035, 0.019542071204341482, 0.2891103661386296, 0.22876154427649453, 11.12832985818386, 69.02391940355301, 53.074085265398026, 48.08597132563591, 29.409337006509304, 26.96957342326641, 52.160390093922615, 68.50549802184105, 62.8228535503149, 61.481077149510384, 59.94512736797333, 51.64281606674194, 0.5523479799740016, 0.14293008745880798, 1.2558973277918994, 1.1594750080257654, 0.7493328535929322, 0.19417240109760314, 29.98702760785818, 57.57373921573162, 47.16654606163502, 58.53693053126335, 55.68695046007633, 61.84005528688431, 59.80372175574303, 59.911620765924454, 55.75936317443848, 56.16308011114597, 52.80643902719021, 53.09605948626995, 49.11728918552399, 47.33346730470657, 44.832061529159546, 42.93135792016983, 42.8314308822155, 44.62839625775814, 45.91727189719677, 50.86702689528465, 50.26670850813389, 53.79933714866638, 52.17599205672741, 56.07145182788372, 51.69094808399677, 51.187482699751854, 54.90697391331196, 55.54608441889286, 49.877290204167366, 52.137735709548, 49.866270795464516, 45.108044520020485, 42.90219448506832, 44.08631354570389, 39.15259748697281, 36.65521949529648, 36.3082867115736, 37.06252723932266, 38.62593434751034, 36.110708713531494, 37.5191867351532, 39.668605998158455, 37.114436253905296, 37.02068388462067, 36.78314723074436, 36.1697955429554, 39.12847638130188, 41.81751228868961, 43.1045488268137, 44.20887216925621, 44.578398540616035, 45.93024060130119, 45.29933765530586, 45.87547414004803, 45.683284252882004, 46.295750588178635, 43.478612154722214, 50.71913503110409, 49.92466986179352, 45.02943053841591, 44.310372322797775, 39.965153485536575, 39.5112906396389, 44.608394131064415, 38.15256714820862, 41.339988112449646, 44.08329650759697, 49.23911824822426, 48.913506120443344, 50.79433299601078, 51.870249062776566, 49.53835219144821, 50.08354693651199, 45.45588165521622, 44.42610651254654, 44.6028920263052, 44.95365500450134, 46.0404384881258, 43.203168734908104, 41.12094886600971, 42.77327120304108, 40.85449576377869, 36.754663959145546, 35.757738053798676, 37.237591445446014, 37.41800956428051, 36.005028784275055, 36.60142958164215, 38.67601566016674, 34.94981400668621, 37.69387096166611, 39.3212628364563, 35.120162665843964, 39.690755009651184, 38.011742904782295, 41.42207130789757, 43.46176765859127, 42.99457512795925, 48.99625428020954, 54.61123198270798, 51.048436760902405, 56.34212650358677, 56.72929912805557, 52.88881100714207, 53.46758835017681, 54.218709245324135, 53.04841764271259, 57.087486907839775, 54.97345894575119, 50.62426932156086, 54.30085323750973, 51.70494273304939, 47.05415569245815, 42.58843012154102, 46.06677107512951, 55.357724726200104, 59.498168751597404, 57.619598954916, 61.319882199168205, 58.819525167346, 61.86755821108818, 56.73324331641197, 50.22389240562916, 43.86162020266056, 62.91091002523899, 58.394533172249794, 54.453301057219505, 48.213625475764275, 52.419961765408516, 3.970481283031404, 0.3780318290228024, 2.941624503582716, 9.518429394811392, 0.09293165043345653, 2.458881069906056, 67.99581617116928, 65.96921771764755, 61.137993559241295, 68.43228355050087, 69.43495854735374, 59.35092285275459, 36.68865010142326, 31.909323558211327, 46.5151584148407, 71.36276230216026, 28.053942136466503, 0.35255217750091106, 0.11441763461334631, 0.04036533791804686, 0.03755717356398236, 0.042746481631184, 0.06333911296678707, 0.05004997547075618, 0.047399725299328566, 0.08108913316391408, 0.07347811188083142, 0.5739948246628046, 0.3310362476622686, 16.47887594997883, 79.53341826796532, 57.71610237658024, 52.80534468591213, 24.228280819952488, 31.928178146481514, 56.33425332605839, 73.37988406419754, 69.80307519435883, 64.36539977788925, 65.37578836083412, 55.307320430874825, 0.7852161687333137, 0.3040335903642699, 0.8120012877043337, 2.040092241950333, 0.23727742169285193, 0.38578394742216915, 31.0868101939559, 60.959011763334274, 48.944694846868515, 59.18863736093044, 55.18453001976013, 64.21012490987778, 63.03253389894962, 60.501767098903656, 59.11726199090481, 60.173020139336586, 55.45004077255726, 54.685559794306755, 51.323374807834625, 51.36344365775585, 46.410341039299965, 45.38026951253414, 46.203601732850075, 47.338065057992935, 49.045986011624336, 53.480652049183846, 52.35513724386692, 57.165272533893585, 53.930205926299095, 59.35409188270569, 52.813400253653526, 50.85007980465889, 57.856459245085716, 55.915489196777344, 50.46481467783451, 53.93991820514202, 52.16919802129269, 48.11958812177181, 43.51951315999031, 44.98410277068615, 40.024365708231926, 39.0779846906662, 37.82638505101204, 39.05446395277977, 40.465214252471924, 38.53865683078766, 39.60116721689701, 40.78329138457775, 39.19513240456581, 37.63450674712658, 38.43145318329334, 38.25650677084923, 40.22106975317001, 45.197020545601845, 44.82669621706009, 46.40123292803764, 46.59975327551365, 47.0149227976799, 48.98613542318344, 47.208571806550026, 48.80255967378616, 48.3613121509552, 48.1061140447855, 53.92211236059666, 52.979310750961304, 45.78083261847496, 46.20606020092964, 43.947229608893394, 40.53415775299072, 45.37849120795727, 40.61985835433006, 42.43406720459461, 45.55360101163387, 52.65069678425789, 51.566884741187096, 52.69390046596527, 53.23195159435272, 51.704334765672684, 51.871096417307854, 48.08738484978676, 46.69599071145058, 47.268297001719475, 46.288333386182785, 49.06774364411831, 44.57250125706196, 44.55296650528908, 45.1023106276989, 43.82837578654289, 40.16911894083023, 38.66957500576973, 39.18744541704655, 39.11240704357624, 37.50596344470978, 39.96691279113293, 39.12765942513943, 36.65871910750866, 40.456014946103096, 38.53178679943085, 37.414832934737206, 40.7131053507328, 39.159205332398415, 43.02995502948761, 45.02750404179096, 45.89009955525398, 50.55104345083237, 56.021495908498764, 53.93933303654194, 56.47638089954853, 58.19711856544018, 56.11185126006603, 54.54999826848507, 55.69008149206638, 54.56652358174324, 61.155297830700874, 56.549196392297745, 54.35216188430786, 55.764808282256126, 53.795016780495644, 47.877563908696175, 45.1053998619318, 48.883673921227455, 57.86022484302521, 62.26757034659386, 58.6907272785902, 63.21573346853256, 61.18685133755207, 64.81635957956314, 58.240421041846275, 53.45294773578644, 46.98138199746609, 64.84643876552582, 60.82079038023949, 58.142287507653236, 50.75435534119606, 57.47682921588421, 4.214585646986961, 0.310703776194714, 4.473138973116875, 10.150390584021807, 0.34905606822576374, 3.33164032548666, 73.42115744948387, 71.6738212108612, 67.36117422580719, 73.05374756455421, 73.42413648962975, 72.10752233862877, 41.95685841143131, 30.120341554284096, 56.52228243649006, 78.43280732631683, 35.450798124074936, 0.7326126226689667, 0.12052970312652178, 0.15840616717468947, 0.08699403115315363, 0.025365407163917553, 0.1858294737758115, 0.24124786723405123, 0.17835061415098608, 0.1988679397618398, 0.217625544173643, 0.8076540241017938, 0.46769627078901976, 19.47636790573597, 91.36746525764465, 66.47010684013367, 66.10306173563004, 41.34425908327103, 42.30287164449692, 65.5955457687378, 80.31147211790085, 73.97335901856422, 70.3572678565979, 70.59190526604652, 62.45740436017513, 0.8586284669581801, 0.5583469674456865, 3.3637875504791737, 8.819123469293118, 1.790813624393195, 0.3293084091274068, 35.82590639591217, 64.70423519611359, 52.3967070132494, 61.429901495575905, 57.64255352318287, 63.4196837246418, 64.0505638718605, 63.65798033773899, 61.11686289310455, 60.85683524608612, 58.276256918907166, 56.613990515470505, 52.74731419980526, 54.97842527925968, 49.85307790338993, 47.82873272895813, 49.04930703341961, 48.00490267574787, 51.24012887477875, 55.400601625442505, 56.47855058312416, 58.349478989839554, 57.15039633214474, 60.26415444910526, 52.41310693323612, 52.604035288095474, 58.792816400527954, 59.95397329330444, 55.08596330881119, 57.36597776412964, 54.09678138792515, 50.90994939208031, 47.107512429356575, 49.41343389451504, 42.30553910136223, 40.242937579751015, 39.67510744929314, 40.35772182047367, 43.34427796304226, 40.48548236489296, 41.69870026409626, 44.21745590865612, 41.99873976409435, 40.3557763248682, 40.38329064846039, 39.12344165146351, 41.707888171076775, 46.40977866947651, 46.92970857024193, 49.14875529706478, 48.39974328875542, 51.20132155716419, 51.77916035056114, 49.68070775270462, 51.60748936235905, 49.609529972076416, 49.16788347065449, 57.189161852002144, 56.448695585131645, 47.40053750574589, 49.90404836833477, 46.69118016958237, 45.427056401968, 49.642827585339546, 42.96047955751419, 43.84530387818813, 47.74168320000172, 53.200679272413254, 53.10306631028652, 54.20940354466438, 55.3763285279274, 52.512718588113785, 55.20751878619194, 50.912993028759956, 50.002846866846085, 48.638355284929276, 48.43698889017105, 52.271834313869476, 47.812754586339, 46.273567378520966, 48.273042887449265, 44.75744493305683, 41.08523078262806, 40.431369468569756, 42.27724961936474, 40.789450854063034, 40.65270759165287, 40.9531194716692, 43.77136744558811, 38.85345093905926, 41.94776929914951, 42.45758034288883, 39.17854629456997, 43.16534176468849, 42.32467867434025, 44.968329817056656, 47.43203401565552, 48.06974619626999, 52.66908019781113, 60.80978997051716, 56.8861623108387, 58.072390258312225, 61.88493847846985, 59.76146802306175, 58.32596965134144, 57.909880578517914, 58.60071770846844, 60.55632457137108, 55.189644545316696, 57.26432941854, 58.02434183657169, 56.65469013154507, 51.128924041986465, 47.5849150121212, 51.537470519542694, 61.0031121969223, 66.03322148323059, 61.53783090412617, 64.36720088124275, 63.555553033947945, 66.02095574140549, 58.00621680915356, 51.56704053282738, 47.693307995796204, 69.70947861671448, 62.085096538066864, 60.48372186720371, 54.90199238061905, 61.986689418554306, 5.463717319071293, 0.4662146471673623, 9.071837458759546, 26.325213499367237, 0.8296125708147883, 2.6979495165869594, 80.77819347381592, 76.76810145378113, 77.56973683834076, 80.5927862226963, 81.97680115699768, 77.76582911610603, 48.89256924390793, 43.92379626631737, 67.82606407999992, 89.37400862574577, 44.677166640758514, 1.1740954359993339, 0.26362264005001634, 0.2699456491973251, 0.22515127784572542, 0.15604175889166072], [0.016612226172583178, 0.07317779440199956, 0.03987772091932129, 0.040122009959304705, 0.14997333608334884, 0.3642691456479952, 0.13776607549516484, 5.6285724230110645, 67.66341000795364, 50.298193618655205, 43.09169411659241, 33.66674445569515, 39.20664578676224, 48.34795206785202, 73.91216710209846, 64.5409731566906, 66.71831712126732, 59.63358208537102, 60.1152328401804, 3.323743399232626, 0.5736661422997713, 0.2894091547932476, 2.529264693148434, 0.4519225750118494, 0.05469859555887524, 29.518945924937725, 68.29916909337044, 52.27206610143185, 66.51082545518875, 62.40251250565052, 62.535782754421234, 56.02757938206196, 58.90822760760784, 56.077105924487114, 56.081342697143555, 49.54026348888874, 48.84719207882881, 47.96840563416481, 44.44830872118473, 41.85613341629505, 44.18999098241329, 45.28737969696522, 48.92479531466961, 50.17621636390686, 54.07199911773205, 52.09354408085346, 53.631910532712936, 52.44616895914078, 49.429784417152405, 49.512372985482216, 56.27710059285164, 52.019277065992355, 50.59810772538185, 51.33948214352131, 46.074640452861786, 40.03632366657257, 38.99285025894642, 44.7202867269516, 44.32842895388603, 39.86016511917114, 36.8467216193676, 38.18855121731758, 37.65937641263008, 36.001023799180984, 39.292635172605515, 39.10160042345524, 37.3199026286602, 35.7911192625761, 37.173253297805786, 36.31037659943104, 37.960685044527054, 40.16306586563587, 41.4172949641943, 43.8780315220356, 44.76912550628185, 43.480405658483505, 45.87096758186817, 45.21032363176346, 44.836279302835464, 45.65830439329147, 43.938535675406456, 47.00855813920498, 51.92591607570648, 51.64314664900303, 46.6834057867527, 42.739407420158386, 40.73295168578625, 38.83095234632492, 45.756312534213066, 42.830655723810196, 42.499112114310265, 43.25438238680363, 47.48757943511009, 52.933280020952225, 50.65113388001919, 53.21907788515091, 49.088072553277016, 48.79635840654373, 42.53098480403423, 44.45607170462608, 45.07439352571964, 45.64238704741001, 45.818971171975136, 41.735782474279404, 41.97822846472263, 42.55363538861275, 39.96988423168659, 37.492747753858566, 34.90903839468956, 35.47149941325188, 35.49487575888634, 34.55933935940266, 37.05915302038193, 38.63489046692848, 40.02907745540142, 35.03540441393852, 36.02835573256016, 40.1169553399086, 37.64571234583855, 38.45247745513916, 41.2901271879673, 43.63419100642204, 40.980120822787285, 43.41639809310436, 45.802917033433914, 51.10950328409672, 52.673324570059776, 51.236146688461304, 56.23572841286659, 57.982692271471024, 57.124523520469666, 55.43194614350796, 51.03893727064133, 54.79036957025528, 53.97834934294224, 49.58465650677681, 50.71386471390724, 46.004169434309006, 43.81478011608124, 43.4794557094574, 45.59296689927578, 59.459889605641365, 58.84352467954159, 60.2322019636631, 59.41363088786602, 61.626461148262024, 60.20736649632454, 68.93355265259743, 53.37958887219429, 59.43077936768532, 64.89764481782913, 64.3452912569046, 51.42015181481838, 50.9948406368494, 1.9463445036672056, 0.4305368772475049, 1.2603188655339181, 8.724784031510353, 0.32498456770554185, 6.080377204343677, 68.77855896949768, 64.90964457392693, 62.03061506152153, 64.31651920080185, 71.53949081897736, 55.7930825650692, 42.113949581980705, 46.270907521247864, 45.97058683633804, 70.49228981137276, 16.322100162506104, 0.4172333754831925, 0.07021845085546374, 0.009087788475881098, 0.02345175340451533, 0.07715483763604425, 0.07834608855773695, 0.07867360574891791, 0.03910970197466668, 0.10051884135464206, 0.08069955016253516, 0.40369283175095916, 0.3541934519307688, 7.723554857075214, 78.65951836109161, 57.17163719236851, 56.659413278102875, 36.12650826573372, 38.372962921857834, 57.13099077343941, 77.68775850534439, 70.30852407217026, 69.33101892471313, 65.46585872769356, 64.5974001288414, 3.5423620557412505, 0.8603008522186428, 0.3291640168754384, 2.916100323200226, 0.5362754955422133, 0.20975727966288105, 30.99277473986149, 68.01483035087585, 54.839398339390755, 68.92885610461235, 64.3081596493721, 64.77371826767921, 58.30108478665352, 61.335617154836655, 59.14199486374855, 56.95623815059662, 52.0632217079401, 51.79143749177456, 48.905078172683716, 44.56824168562889, 43.93234200775623, 47.624562084674835, 49.109423607587814, 50.50771437585354, 52.26334556937218, 57.11072266101837, 55.2654542773962, 54.18304055929184, 53.88026140630245, 51.89665004611015, 51.776641085743904, 57.55895420908928, 53.674331456422806, 51.40864223241806, 53.651023507118225, 47.84024991095066, 42.13654696941376, 41.29974067211151, 45.00426448881626, 47.56316877901554, 41.95146270096302, 40.170623660087585, 39.427995309233665, 41.28065429627895, 38.484604731202126, 38.89540448784828, 40.963185131549835, 39.02882672846317, 36.89664714038372, 37.504717111587524, 38.65027204155922, 40.053589940071106, 40.79647667706013, 43.15931148827076, 45.60724273324013, 46.29016488790512, 45.90663246810436, 47.391573786735535, 47.623969316482544, 46.74104489386082, 48.54296140372753, 47.317629754543304, 47.57293425500393, 53.31431217491627, 55.15808343887329, 50.430183336138725, 46.450052708387375, 42.497903779149055, 41.078607738018036, 46.56327523291111, 44.538325890898705, 43.87174665927887, 43.89557518064976, 50.20755708217621, 55.22554501891136, 52.316090539097786, 53.9129738509655, 51.330784410238266, 50.7259214669466, 47.600277587771416, 48.048338145017624, 46.416447311639786, 46.376040279865265, 49.38932038843632, 44.8158174008131, 43.578599989414215, 44.93821643292904, 41.879350170493126, 40.23342669010162, 36.9749191403389, 37.7464297413826, 36.28641128540039, 37.15814910829067, 38.054729998111725, 41.046757847070694, 43.16836640238762, 37.53613382577896, 38.845026791095734, 39.840143993496895, 39.921360835433006, 40.430837497115135, 43.507931381464005, 45.50728529691696, 43.90102408826351, 45.903144255280495, 49.43562090396881, 53.816155046224594, 55.23947887122631, 53.29388067126274, 56.45640157163143, 60.07842801511288, 58.68271350860596, 55.334770157933235, 55.77526532113552, 58.43695789575577, 55.91969557106495, 53.91754500567913, 54.179160967469215, 47.591633051633835, 45.35408511757851, 47.14667312800884, 48.584759160876274, 62.69981235265732, 62.48268440365791, 61.39992490410805, 62.662627547979355, 64.85776975750923, 61.834556981921196, 69.32496204972267, 57.160537987947464, 62.277472615242004, 67.35433459281921, 65.66622957587242, 53.52860547602177, 55.83163909614086, 2.213704688474536, 0.6101183581631631, 7.333718575537205, 5.81715582869947, 0.3317042102571577, 5.730761289596558, 76.01177483797073, 71.37127384543419, 70.75059995055199, 69.85703989863396, 77.29197934269905, 65.74325904250145, 32.73136384785175, 37.68330752849579, 55.566067546606064, 79.5522652566433, 23.396321162581444, 0.6829435878898948, 0.03696388957905583, 0.021356008146540262, 0.12545758596388623, 0.09616597453714348, 0.14975447673350573, 0.2044499886687845, 0.12087957380572334, 0.19307850510813296, 0.2758012240519747, 0.6352318043354899, 0.4720601881854236, 9.22528462484479, 88.24119821190834, 65.65002724528313, 63.024132549762726, 45.83862751722336, 54.0901393443346, 61.31004832684994, 83.0032704770565, 78.03234681487083, 76.42165884375572, 71.2825258076191, 74.01144817471504, 3.7803318863734603, 1.367810822557658, 4.195152064785361, 10.073034334927797, 2.1601859852671623, 0.390966305276379, 34.353234618902206, 68.78717690706253, 58.32077153027058, 69.23429131507874, 64.63760197162628, 66.92672833800316, 60.980286821722984, 62.925569638609886, 62.779748663306236, 61.22965984046459, 54.942258819937706, 53.87621842324734, 51.182322576642036, 48.043664395809174, 47.31307379901409, 49.28359106183052, 49.981127232313156, 53.967170342803, 55.20287163555622, 58.573153987526894, 56.70504502952099, 57.6484128087759, 56.26081466674805, 51.827064380049706, 52.44471363723278, 55.12136600911617, 57.24421709775925, 54.45721484720707, 57.052251398563385, 50.00869855284691, 44.60888430476189, 44.37403790652752, 48.567644879221916, 48.867570385336876, 44.0612006932497, 41.78133063018322, 41.31321854889393, 42.76922062039375, 39.51126404106617, 40.781999453902245, 41.89717881381512, 39.20861408114433, 40.7364246994257, 41.67101874947548, 41.43600896000862, 41.64715223014355, 42.21165753901005, 45.76755613088608, 48.359917625784874, 48.06377671658993, 47.8568322211504, 50.479413494467735, 50.96413068473339, 49.05318282544613, 50.340804532170296, 48.26680362224579, 50.34204326570034, 56.77498787641525, 57.01579995453358, 51.35801374912262, 48.02356727421284, 45.914756432175636, 44.641330763697624, 50.44709622859955, 48.44288617372513, 45.56213155388832, 47.94512428343296, 52.19754070043564, 58.85754592716694, 53.540814220905304, 56.31597250699997, 53.828238397836685, 53.17373491823673, 49.03520219027996, 51.332368925213814, 49.045317247509956, 50.91278783977032, 53.54614533483982, 44.97984319925308, 46.31305865943432, 48.24664190411568, 43.755016922950745, 43.10644492506981, 38.87361265718937, 39.07019890844822, 37.373886331915855, 38.04980166256428, 40.37996582686901, 44.25106130540371, 44.90670472383499, 39.91845399141312, 38.962645679712296, 43.58478985726833, 41.6670935600996, 41.126644760370255, 46.133259907364845, 48.34573678672314, 46.48250296711922, 48.20262886583805, 50.48420883715153, 57.42258332669735, 59.10797908902168, 55.984854474663734, 59.91993851959705, 62.3568769544363, 63.243433982133865, 57.30893522500992, 58.14571492373943, 58.866847828030586, 56.694204211235046, 56.95484362542629, 56.12782180309296, 50.39315052330494, 47.834584414958954, 50.12807674705982, 50.48911817371845, 65.25595039129257, 64.67689946293831, 65.01179829239845, 64.34390053153038, 66.21267065405846, 64.57915350794792, 71.8640086054802, 53.24632242321968, 61.39537654817104, 68.3113132417202, 70.44124335050583, 55.34253314137459, 58.0098570138216, 3.1808546790853143, 0.7027791172731668, 9.042438436299562, 24.176417402923107, 0.7895148661918938, 6.884329989552498, 80.41994109749794, 77.02320456504822, 78.11167135834694, 76.01412311196327, 83.00087660551071, 70.00257968902588, 55.59297390282154, 59.1443507373333, 66.32771328091621, 88.41522887349129, 32.45433211326599, 0.8841392293106765, 0.16040054062614217, 0.1719999228953384, 0.2716427034465596, 0.1831740397028625], [0.013361638830247102, 0.02825570871209493, 0.039452318160329014, 0.0252685476152692, 0.09522825610474683, 0.13547393755288795, 0.024940677903941832, 2.646965514868498, 63.32701049745083, 55.24420581758022, 38.72834265232086, 16.117718629539013, 28.001058474183083, 39.53722044825554, 59.438451156020164, 64.02652636170387, 65.2156649529934, 58.075365498661995, 65.42986705899239, 8.93642507493496, 1.2727323244325817, 0.35566946491599083, 1.3492812355980277, 0.8440426527522504, 0.2866171655477956, 31.598120257258415, 75.6153193116188, 60.64023166894913, 65.32103329896927, 56.41743466258049, 60.74736692011356, 58.39609868824482, 55.908638164401054, 51.62405267357826, 49.8121502995491, 47.375675439834595, 44.71247814595699, 44.12957042455673, 44.4908132404089, 50.43274059891701, 47.72002436220646, 48.456576839089394, 52.32015252113342, 54.28938165307045, 52.38721512258053, 51.38892889022827, 50.18138408660889, 51.57150909304619, 48.740064427256584, 41.78821586072445, 40.660481974482536, 56.92024648189545, 54.47609983384609, 49.69340667128563, 47.96411946415901, 47.150020748376846, 43.24653960764408, 41.806853860616684, 46.19746886193752, 41.48053877055645, 38.841736167669296, 38.71820479631424, 36.558788269758224, 37.89403282105923, 41.09757252037525, 36.30670219659805, 37.11354710161686, 34.85985763370991, 39.288554191589355, 37.610096856951714, 37.26205453276634, 37.90060646831989, 40.54637409746647, 42.40892015397549, 42.86947064101696, 43.52082408964634, 44.59778130054474, 44.65852864086628, 45.164023116230965, 44.28495168685913, 45.91697171330452, 46.2559325248003, 49.23690676689148, 50.1406654715538, 49.6601090580225, 45.268426313996315, 38.66368532180786, 39.84184630215168, 42.701743841171265, 40.12699820101261, 43.54029804468155, 41.85325317084789, 47.45901636779308, 53.037177845835686, 51.183496713638306, 50.10541096329689, 48.40256653726101, 45.97151778638363, 43.669806495308876, 44.947069957852364, 45.70773594081402, 43.758987709879875, 45.7551421970129, 43.39046448469162, 42.854503244161606, 41.018692553043365, 38.52213531732559, 37.752129435539246, 36.62472993135452, 35.38297936320305, 35.83751477301121, 35.18542416393757, 35.383480936288834, 37.14174918830395, 35.86587265133858, 37.712854743003845, 34.87834744155407, 37.48775102198124, 39.54471364617348, 38.7226277589798, 39.399173855781555, 44.81749691069126, 41.66867807507515, 41.51902690529823, 40.512635707855225, 43.23584318161011, 45.88097244501114, 51.07761159539223, 48.444033712148666, 52.16038629412651, 55.85618197917938, 55.343646481633186, 49.25372466444969, 50.33644616603851, 55.24930514395237, 53.33404831588268, 52.466497868299484, 53.471733927726746, 50.32191574573517, 49.24617826938629, 44.07558672130108, 45.70439592003822, 51.27440303564072, 56.31966590881348, 58.86612966656685, 60.24139367043972, 55.8375895768404, 61.03673279285431, 64.42208513617516, 65.82335874438286, 62.21295207738876, 64.54294145107269, 67.29307428002357, 57.20780745148659, 0.4595469846390188, 0.28342435718514025, 5.826869057491422, 5.205858405679464, 0.7035054126754403, 10.193454623222351, 73.29010248184204, 65.30157074332237, 63.34338761866093, 64.77828562259674, 70.54845079779625, 53.808893635869026, 67.34037414193153, 40.526835545897484, 44.048562571406364, 68.13602104783058, 15.096344836056232, 0.39322011871263385, 0.09205276946886443, 0.010639475476637017, 0.060592123845708556, 0.04997620970243588, 0.0033216644487765734, 0.05649628132232465, 0.02546659714425914, 0.022342227784974966, 0.0818915877607651, 0.15781777765369043, 0.09195165184792131, 3.7459848169237375, 74.70673486590385, 62.77182228863239, 45.1381579041481, 25.972943902015686, 46.24647103250027, 45.96551790833473, 69.71488192677498, 69.1347898542881, 70.83749368786812, 61.82644061744213, 71.37084826827049, 9.045247435569763, 1.0536334686912596, 0.49947114544920623, 1.5785194910131395, 0.5411826947238296, 0.2772344002733007, 32.55444534122944, 75.51005735993385, 64.19081434607506, 65.69955378770828, 56.98346368968487, 62.239862233400345, 60.94203047454357, 58.97256575524807, 52.88560777902603, 51.836514472961426, 50.31237445771694, 47.022370398044586, 47.42954134941101, 48.67274343967438, 51.40478923916817, 49.273434206843376, 49.925498217344284, 53.55867326259613, 56.379888877272606, 55.25481104850769, 52.99010217189789, 52.705189660191536, 53.35979573428631, 50.221601128578186, 42.56447620689869, 45.944090858101845, 59.65096615254879, 56.119914427399635, 50.79174153506756, 48.95496569573879, 48.064426481723785, 45.022077932953835, 44.36375945806503, 47.0717753469944, 42.4156191945076, 40.59443011879921, 39.50486518442631, 38.62112380564213, 39.53608810901642, 41.166193038225174, 37.715932577848434, 39.17835630476475, 35.70282340049744, 39.19662572443485, 39.26148064434528, 40.85676044225693, 37.53679879009724, 42.08409458398819, 43.21477711200714, 44.86779101192951, 46.257798224687576, 46.495714858174324, 46.57763086259365, 48.049436286091805, 47.09663361310959, 47.55235455930233, 49.28458660840988, 50.85195690393448, 54.467132315039635, 50.86685210466385, 44.94168944656849, 43.204396069049835, 40.857505202293396, 44.322995245456696, 41.46124720573425, 44.79099713265896, 43.158148750662804, 49.2089706659317, 54.84982877969742, 52.94190175831318, 53.9314978569746, 51.79755136370659, 46.86207979917526, 46.57744847238064, 46.00009985268116, 47.842799574136734, 46.496178433299065, 45.68689025938511, 45.23448273539543, 46.379186511039734, 42.64558665454388, 42.56278149783611, 40.3316780179739, 37.64323867857456, 37.84724973142147, 37.5604373216629, 37.782098427414894, 38.22984740138054, 38.22860486805439, 39.7959865629673, 39.41896699368954, 36.42975479364395, 39.9813824146986, 40.89637331664562, 41.59535340964794, 40.5918500572443, 46.838756650686264, 45.06315752863884, 43.31508032977581, 42.85111762583256, 45.902201905846596, 47.68460266292095, 55.20013578236103, 51.334762796759605, 54.255582466721535, 57.357895597815514, 58.45544010400772, 52.47684471309185, 53.253177255392075, 57.09435693919659, 55.91828964650631, 52.96057015657425, 54.46457505226135, 52.18159295618534, 52.8722058981657, 46.72010041773319, 49.39857289195061, 53.799614533782005, 59.09695588052273, 61.979477405548096, 63.05364176630974, 60.05072370171547, 61.130747348070145, 66.34857416152954, 69.29216220974922, 63.893457502126694, 68.85258659720421, 69.09736946225166, 60.17655774950981, 0.4801301535917446, 0.3316483413800597, 6.412279894575477, 3.9314281661063433, 0.7218100398313254, 10.997384134680033, 80.19418001174927, 69.92994278669357, 69.10341113805771, 70.93071788549423, 75.99657565355301, 63.2568396627903, 54.828739911317825, 42.77720019221306, 50.94306081533432, 78.12706053256989, 21.932504810392857, 0.49594769545365125, 0.10070681251818314, 0.022663269737677183, 0.054845021295477636, 0.048618747387081385, 0.09743878748849966, 0.17200504371430725, 0.17648279172135517, 0.11954260960919783, 0.22191015566932037, 0.40328996430616826, 0.1696633006213233, 4.117055330425501, 85.45663923025131, 71.51564329862595, 57.501375898718834, 26.729941181838512, 39.57221657037735, 57.093292996287346, 77.25073635578156, 74.2732085287571, 77.22546011209488, 67.7932034432888, 78.03967282176018, 11.527003515511751, 2.0217658253386617, 1.5875252452678978, 5.064954366534948, 1.2563240923918784, 0.3359298506984487, 36.082719415426254, 77.05949261784554, 64.51686725020409, 71.11579835414886, 63.220091834664345, 66.20007053017616, 62.17496931552887, 61.23505935072899, 55.2427276968956, 54.59150344133377, 51.9902428239584, 49.09166716039181, 50.76061360538006, 50.64039185643196, 54.72575403749943, 50.9485325217247, 53.800556883215904, 57.3505087941885, 57.42998532950878, 57.419167309999466, 55.83678402006626, 51.527617648243904, 56.345295533537865, 50.954118221998215, 46.071631014347076, 46.137777864933014, 59.2896169424057, 59.01647239923477, 54.93747487664223, 52.23353996872902, 52.02107056975365, 47.76734322309494, 46.745794638991356, 49.393887743353844, 44.116924703121185, 42.70362474024296, 42.10321135818958, 40.81724256277084, 41.3433775305748, 44.97509725391865, 40.422648936510086, 41.45566910505295, 38.01553890109062, 42.713397815823555, 41.184622049331665, 42.15991951525211, 40.88113993406296, 44.554121643304825, 46.97701223194599, 49.252398535609245, 47.69170828163624, 50.016035959124565, 48.892565444111824, 50.7602222263813, 48.117000460624695, 49.21436257660389, 51.713245287537575, 54.409223422408104, 57.561215087771416, 54.704589173197746, 48.085272163152695, 45.989882200956345, 43.9580362290144, 47.2071772813797, 43.081993237137794, 45.645708069205284, 43.79410542547703, 48.19038212299347, 54.42839339375496, 54.691434279084206, 55.72332210838795, 52.12821342051029, 49.565642327070236, 50.11892303824425, 49.203365966677666, 49.71084013581276, 50.38708604872227, 49.735086634755135, 46.58773452043533, 48.59044745564461, 46.26683034002781, 45.09611316025257, 42.55531869828701, 39.60662752389908, 39.43416237831116, 39.78840596973896, 39.032010957598686, 40.30899703502655, 39.46140691637993, 40.633264034986496, 42.30393558740616, 38.56786586344242, 40.16651228070259, 44.01382863521576, 44.291935712099075, 44.11678411066532, 47.5866325199604, 46.68753616511822, 46.61262698471546, 46.028385534882545, 48.22225861251354, 49.40797358751297, 57.453373074531555, 56.04711793363094, 56.52925506234169, 59.550469145178795, 59.391561672091484, 54.53214302659035, 58.31017769873142, 57.41246446967125, 58.176991045475006, 55.40920436382294, 56.90441653132439, 55.31354829668999, 56.36918485164642, 49.50915455818176, 52.43514955043793, 56.32282733917236, 61.60067953169346, 65.39070636034012, 66.9830185174942, 61.22087091207504, 66.63393884897232, 68.55946272611618, 71.36666849255562, 65.025135576725, 72.23992243409157, 69.09881338477135, 64.43683594465256, 1.314658799674362, 1.0712209437042475, 10.771944131702185, 10.189823918044567, 0.9669354802463204, 12.496463544666767, 86.70746371150017, 76.38777986168861, 76.8944750726223, 76.13965317606926, 78.80294546484947, 73.3163970708847, 85.44554382562637, 54.114545434713364, 61.478421092033386, 89.44042146205902, 28.819186873733997, 0.8340432518161833, 0.23080859537003562, 0.1711749960668385, 0.17212338658282533, 0.1590704041882418], [0.13708904385566711, 0.028699084432446398, 0.07296660885913298, 0.04609238763805479, 0.016665887160343118, 0.09252910211216658, 0.28530677023809403, 0.8769462746568024, 49.53994430601597, 59.71496991813183, 44.26126375794411, 29.129324331879616, 26.48221157491207, 37.320050820708275, 67.08239078521729, 60.80919720232487, 66.55823931097984, 59.23801191151142, 64.62495625019073, 13.225032649934292, 1.0517779807560146, 0.5092070542741567, 1.2324233748950064, 0.5787300236988813, 0.1817660074448213, 38.146837055683136, 73.68725717067719, 55.793515741825104, 60.413296446204185, 60.58675713837147, 56.93012595176697, 53.37767757475376, 52.3205628991127, 50.94765856862068, 49.50715586543083, 49.938824102282524, 48.67797575891018, 50.31594626605511, 49.521127715706825, 51.229098066687584, 51.41563005745411, 56.145897433161736, 52.88889080286026, 55.936517268419266, 50.46148605644703, 51.5175823867321, 52.43391461670399, 50.47983527183533, 50.84200903773308, 52.58766956627369, 40.612262561917305, 40.80729469656944, 57.36244775354862, 53.74452129006386, 53.356182128190994, 48.749780505895615, 55.39621666073799, 49.52197887003422, 43.49660038948059, 43.24075631797314, 37.76459276676178, 39.486648961901665, 39.93931867182255, 36.370082795619965, 35.944752618670464, 38.23619306087494, 42.24880434572697, 42.00347051024437, 39.99281220138073, 38.02688889205456, 38.15705470740795, 36.921022832393646, 39.65049237012863, 41.19415573775768, 39.8661307990551, 42.76038609445095, 47.08896562457085, 43.97643484175205, 46.77764073014259, 44.80727165937424, 45.36559849977493, 44.528697207570076, 46.79269552230835, 51.85978062450886, 48.920444548130035, 44.9503567814827, 39.84063416719437, 37.43589900434017, 41.63375794887543, 40.99546059966087, 44.032234847545624, 40.98019681870937, 48.16230162978172, 48.99790719151497, 51.94624878466129, 51.75634257495403, 47.52012848854065, 44.822877421975136, 42.993925362825394, 43.53683643043041, 45.248959958553314, 43.979147896170616, 45.945694372057915, 43.50891172885895, 44.86715264618397, 41.336051523685455, 39.292790964245796, 38.376857712864876, 36.5582524985075, 34.97486986219883, 35.56193836033344, 35.233115404844284, 36.965826228260994, 36.16262912750244, 37.65987418591976, 36.65732458233833, 38.93684886395931, 38.19794811308384, 39.16032247245312, 40.27659237384796, 43.013228327035904, 42.488024309277534, 41.43814064562321, 42.373460456728935, 47.4831260740757, 48.78509201109409, 51.27463862299919, 48.68154376745224, 61.089998334646225, 64.66800034046173, 53.920250460505486, 52.04655960202217, 52.64985702931881, 48.76217544078827, 53.580115512013435, 55.636926144361496, 52.8649976849556, 53.62311400473118, 55.65882056951523, 57.80202716588974, 55.47887742519379, 54.91731695830822, 46.77812710404396, 47.73208871483803, 52.2201456874609, 56.899074018001556, 58.30624870955944, 61.6388750821352, 55.95400393009186, 63.37935648858547, 63.536071479320526, 62.705143466591835, 64.9481289088726, 59.68402057886124, 0.17212604347150773, 0.6491916615050286, 8.42865452170372, 2.562923999503255, 0.553107523592189, 16.23189490288496, 76.98612615466118, 62.13339574635029, 60.286459252238274, 66.8870584666729, 65.7647430896759, 57.215232253074646, 49.328820034861565, 24.84083265066147, 50.5006467550993, 68.22913125157356, 8.86902904137969, 0.6061665702145547, 0.26350600412115455, 0.05299149634083733, 0.1517041283659637, 0.12833413551561534, 0.08956619625678286, 0.005824078571095015, 0.11200656750588678, 0.07573797382065095, 0.2696283959085122, 0.048959326377371326, 0.2147722980589606, 1.1615282041020691, 61.12332634627819, 65.95453530550003, 52.969845458865166, 29.675005450844765, 32.67495207488537, 47.332027181982994, 74.79601487517357, 68.10261324048042, 72.74895071983337, 62.650160416960716, 72.33532011508942, 13.08667827397585, 0.7586893765255809, 0.6285221362486482, 3.4119851142168045, 0.6570605642627925, 0.4183448158437386, 40.41345342993736, 73.49725976586342, 59.211166352033615, 63.92659172415733, 62.096955701708794, 60.402919203042984, 56.50387242436409, 53.83503623306751, 54.25980404019356, 51.93783223628998, 52.64488309621811, 50.863736271858215, 52.26434871554375, 51.11605413258076, 53.43787394464016, 54.55596774816513, 57.483041882514954, 54.97841767966747, 57.81181924045086, 54.13843095302582, 52.77740478515625, 55.12059085071087, 52.93649464845657, 54.278366044163704, 53.38873878121376, 42.572018802165985, 43.65456931293011, 58.11946213245392, 55.88951379060745, 55.75529359281063, 50.962291583418846, 56.10019728541374, 50.13962812721729, 44.80058401823044, 44.13955628871918, 39.861077070236206, 39.809418842196465, 41.944547072052956, 39.01348315179348, 36.68390415608883, 40.189968422055244, 43.62441033124924, 41.971369832754135, 40.852025896310806, 40.3622929751873, 40.638150572776794, 39.43018399178982, 41.78826905786991, 43.678261041641235, 42.86527946591377, 44.76825915277004, 47.12398074567318, 47.57004640996456, 47.662867829203606, 44.65184859931469, 47.68191620707512, 47.002999037504196, 48.47568981349468, 51.61649487912655, 50.114469677209854, 46.10386088490486, 42.13668376207352, 40.913449600338936, 43.26443664729595, 42.43390381336212, 46.834383085370064, 42.538318410515785, 49.64350774884224, 51.507664918899536, 53.20983298122883, 53.475548923015594, 49.032135754823685, 44.80633310973644, 47.111319825053215, 46.31596930325031, 46.08372576534748, 48.20783458650112, 47.23207734525204, 47.433626130223274, 44.62154522538185, 44.048889353871346, 42.45563104748726, 40.861346796154976, 36.727487817406654, 38.02630752325058, 37.80812703073025, 37.95004181563854, 38.100848123431206, 37.31381915509701, 39.077844098210335, 37.818603068590164, 39.82514999806881, 39.218185767531395, 40.8824622631073, 41.44085370004177, 45.255073830485344, 44.508691281080246, 43.196173310279846, 45.40506698191166, 46.97932630777359, 50.11437468230724, 54.20926295220852, 52.08244867622852, 58.81118081510067, 64.9720524251461, 57.98208810389042, 53.28378081321716, 55.72692811489105, 51.80042400956154, 55.517053976655006, 59.24764059484005, 54.937987849116325, 56.001543179154396, 57.2015605866909, 60.309869796037674, 57.766624465584755, 56.59814536571503, 49.529806450009346, 50.783883556723595, 53.07279713451862, 59.88264352083206, 61.26870274543762, 65.41356593370438, 60.532499849796295, 66.33316218852997, 63.83177921175957, 67.80025586485863, 67.93182760477066, 63.80724012851715, 0.49325209634844214, 0.17723069846397266, 6.401740210130811, 1.9137099548242986, 0.6229549599811435, 17.659204714000225, 82.1879406273365, 69.02101635932922, 68.76031994819641, 71.4496636390686, 73.08182045817375, 59.286181926727295, 55.1032941788435, 32.602797746658325, 57.28960946202278, 80.13411283493042, 11.998437568545341, 0.8683553512673825, 0.3295861801598221, 0.06291122030233964, 0.07161412635468878, 0.04609174568031449, 0.19289776246296242, 0.13991258922033012, 0.23596528975758702, 0.16299765673466027, 0.2875189343467355, 0.15926944819511846, 0.3825581580167636, 1.8895295960828662, 73.97635325789452, 72.63516202569008, 64.0402664244175, 37.808750197291374, 40.4103983938694, 55.380998477339745, 81.6064502298832, 72.78065621852875, 77.85718381404877, 67.69095093011856, 78.01771000027657, 14.619171191006899, 1.180930556729436, 0.8644784311763942, 3.1170219043269753, 1.471905643120408, 0.454306056490168, 42.95560821890831, 77.45461821556091, 61.25492848455906, 66.66608512401581, 65.10568365454674, 62.53016285598278, 58.76005835831165, 57.339246198534966, 55.675076097249985, 55.035213232040405, 53.5347231477499, 53.77991259098053, 54.045662730932236, 54.22533988952637, 56.80157884955406, 56.80396892130375, 61.97923421859741, 58.24355207383633, 58.9814230799675, 56.460596546530724, 55.2094566822052, 57.110958248376846, 53.578272610902786, 54.313069581985474, 55.81879198551178, 44.60700340569019, 44.36402164399624, 59.79321911931038, 57.06885650753975, 57.3771757632494, 53.80266577005386, 59.78900134563446, 53.06225270032883, 48.04538570344448, 46.731841787695885, 41.35528229176998, 42.14036576449871, 45.043523982167244, 39.20626200735569, 38.33896994590759, 42.71971307694912, 47.269790321588516, 45.405655950307846, 45.09027287364006, 42.573348730802536, 43.478570356965065, 41.2003418058157, 45.185195580124855, 45.993852987885475, 44.806918278336525, 49.0369538962841, 52.00485683977604, 51.25077210366726, 50.274011716246605, 48.32075692713261, 49.65486913919449, 48.90083000063896, 50.47616086900234, 54.24677833914757, 52.98200860619545, 48.62600214779377, 44.269699305295944, 41.86428017914295, 47.36663192510605, 44.42617870867252, 50.02760253846645, 44.39864918589592, 50.9794856607914, 52.85437725484371, 56.83597080409527, 56.70258276164532, 51.71449922025204, 46.95848062634468, 48.54322738945484, 48.93486097455025, 48.560311272740364, 48.92226845026016, 49.228026643395424, 49.83489967882633, 49.648888260126114, 47.21491366624832, 45.2489447593689, 43.94069015979767, 39.968531504273415, 38.846083134412766, 40.12494631111622, 40.39336010813713, 41.181251630187035, 39.87696401774883, 40.854974538087845, 40.04585735499859, 42.26925864815712, 42.24087797105312, 43.503694608807564, 43.92963655292988, 47.980063408613205, 46.568587347865105, 46.30762115120888, 46.33833110332489, 49.258615002036095, 53.02869290113449, 55.966881439089775, 54.03859131038189, 58.232171684503555, 66.1230106651783, 60.69696642458439, 54.41325880587101, 56.062244921922684, 55.39628505706787, 59.546095579862595, 62.2621214389801, 58.76760475337505, 57.953426241874695, 59.81006361544132, 62.818943560123444, 58.75217378139496, 59.38506402075291, 53.14871706068516, 53.263854682445526, 55.84457740187645, 63.156103268265724, 64.15557503700256, 67.1960274875164, 61.301555782556534, 68.46119999885559, 67.48281329870224, 69.8199462890625, 70.30386552214622, 68.32998543977737, 1.0561663890257478, 0.9366832848172635, 19.51115693897009, 12.70525949075818, 1.152349084150046, 19.22950655221939, 86.09984591603279, 71.97620138525963, 74.68886822462082, 78.79381835460663, 77.77287393808365, 73.84160488843918, 62.88161739706993, 38.479304015636444, 68.0200968682766, 89.51899364590645, 17.590379007160664, 1.210500095039606, 0.5770170874893665, 0.2009270284906961, 0.3045265842229128, 0.1965117099462077], [0.058558939781505615, 0.031191980742732994, 0.07621428419952281, 0.017039465747075155, 0.03693995160574559, 0.07723020273260772, 0.26148338452912867, 0.42124017141759396, 46.236059591174126, 61.401235833764076, 45.62579333782196, 32.778982892632484, 48.56750048696995, 42.58822873234749, 58.556374087929726, 65.27360424399376, 64.62255477905273, 57.297475039958954, 65.57066470384598, 19.85787693411112, 0.554066615877673, 0.6532130332197994, 0.9438871638849378, 0.6678227742668241, 0.17010891577228904, 40.914296954870224, 71.72838628292084, 60.679950937628746, 56.75544932484627, 53.841093108057976, 53.13472621142864, 53.32445003092289, 48.27605612576008, 46.829762533307076, 46.55312977731228, 48.1204354763031, 51.70945689082146, 53.93317736685276, 51.2360592931509, 52.13875025510788, 51.41314119100571, 51.217497289180756, 53.37002858519554, 51.167108193039894, 50.26154078543186, 54.6518138051033, 52.80790954828262, 53.67858722805977, 50.80718010663986, 51.574807316064835, 50.21734535694122, 46.49451032280922, 46.69174633920193, 51.605893447995186, 54.22190107405186, 53.66651147603989, 51.29199229180813, 54.9253611266613, 46.181965693831444, 41.834124997258186, 40.0347201526165, 40.72857812047005, 36.61571681499481, 37.13970489799976, 42.76465706527233, 45.24359464645386, 43.02020475268364, 37.70577572286129, 38.003561943769455, 36.9592259824276, 38.26909929513931, 36.356449127197266, 38.8641207665205, 38.7672221660614, 40.52701033651829, 42.45245821774006, 43.561732694506645, 42.307028621435165, 43.20474945008755, 45.83904929459095, 45.84493897855282, 43.52845408022404, 46.43339440226555, 49.520793333649635, 48.73714618384838, 45.37344127893448, 41.019524708390236, 40.34253403544426, 41.45637206733227, 43.2282891869545, 43.166029527783394, 44.83214132487774, 51.04936011135578, 48.63298237323761, 52.82338611781597, 49.23249140381813, 46.45248457789421, 42.75374785065651, 42.32839487493038, 45.732480213046074, 45.65099358558655, 44.14329148828983, 44.72255140542984, 44.072090908885, 41.09316095709801, 39.28326487541199, 38.06307815015316, 38.995008543133736, 36.26339592039585, 36.28381222486496, 35.84544874727726, 36.99912764132023, 38.35126608610153, 37.32934512197971, 37.06518329679966, 38.16059611737728, 36.08209624886513, 38.99045258760452, 40.304729864001274, 40.46010732650757, 44.76031757891178, 43.862668946385384, 47.58563697338104, 51.85374654829502, 51.08499459922314, 51.67089655995369, 51.85981102287769, 57.449907660484314, 57.78541825711727, 46.674457266926765, 49.94964972138405, 49.808662086725235, 48.62486980855465, 49.81779679656029, 48.98296259343624, 55.29149428009987, 58.57316538691521, 58.605551049113274, 59.33492951095104, 55.1681225001812, 57.796407267451286, 58.2914675027132, 56.618956848978996, 50.37626422941685, 43.67520600557327, 49.15465258061886, 51.02881841361523, 56.537295430898666, 59.06206235289574, 60.26831142604351, 57.278593853116035, 62.98168882727623, 64.39122319221497, 61.833629831671715, 0.6615454517304897, 0.2633115911157802, 2.323371316306293, 1.6682046535424888, 0.7091038185171783, 19.852574318647385, 74.39700588583946, 62.79277816414833, 53.55728633701801, 69.00157660245895, 63.35213094949722, 55.85397429764271, 31.11102819442749, 27.65165962278843, 51.5844663977623, 72.78220653533936, 9.784143436700106, 0.575881126569584, 0.1598271424882114, 0.1465118702617474, 0.07068560313200578, 0.0038206678482310963, 0.02844261489372002, 0.026614755261107348, 0.06119589066656772, 0.026639485477062408, 0.0692517144489102, 0.06840139874839224, 0.24445050163194537, 0.6164343317504972, 57.442748844623566, 68.99909153580666, 55.180707424879074, 40.629859417676926, 46.44637830555439, 52.84884475171566, 71.06570184230804, 72.50412225723267, 69.48128566145897, 60.75376957654953, 71.30789324641228, 20.32556913793087, 0.47957226634025574, 0.9189043950755149, 4.3670538906008005, 0.43435050698462874, 0.17806147341616452, 40.618479028344154, 74.49223637580872, 61.96023903787136, 61.8192134052515, 56.71835571527481, 56.848084554076195, 56.83454208076, 50.379828438162804, 49.092377722263336, 50.01078084111214, 50.3691092133522, 55.36496713757515, 54.155655428767204, 54.96038004755974, 56.67298994958401, 53.120887354016304, 55.450337156653404, 54.894202798604965, 51.55578553676605, 53.4530009329319, 56.460820734500885, 56.313996613025665, 56.170919090509415, 53.50429818034172, 55.234181955456734, 52.042497619986534, 45.650150030851364, 49.023407623171806, 54.191293716430664, 57.80614234507084, 55.282325372099876, 50.53470052778721, 56.545054614543915, 48.06629978120327, 44.146319925785065, 42.5848963111639, 42.588251531124115, 37.99516819417477, 38.00348974764347, 43.525323048233986, 48.039207234978676, 43.75030517578125, 40.189729034900665, 38.75766187906265, 39.1655357927084, 39.815756902098656, 38.300443813204765, 41.23845376074314, 41.17059700191021, 42.45666839182377, 43.772279396653175, 47.41931229829788, 45.88563099503517, 45.7796660810709, 45.833737179636955, 47.793793603777885, 45.81350326538086, 48.978231847286224, 53.50863754749298, 50.26644632220268, 45.555189326405525, 43.60982671380043, 43.04993815720081, 44.07079517841339, 44.08494561910629, 43.62588845193386, 46.36730454862118, 51.53606839478016, 49.896334782242775, 54.95397739112377, 50.63394360244274, 48.52127976715565, 45.19820228219032, 45.2765616774559, 46.268198266625404, 47.75364875793457, 46.496444419026375, 47.46500864624977, 45.69565258920193, 44.985041320323944, 42.23211944103241, 39.85959514975548, 39.79165479540825, 37.866959273815155, 39.66412603855133, 37.244066298007965, 39.74400155246258, 41.05612814426422, 39.269148632884026, 39.278572127223015, 39.92305554449558, 38.385722637176514, 40.969101414084435, 41.649071127176285, 41.852671802043915, 46.387994438409805, 47.00343981385231, 49.897999092936516, 54.576087668538094, 52.662973925471306, 54.810835272073746, 54.40642297267914, 58.19878287613392, 58.39738681912422, 49.26697455346584, 50.50196908414364, 49.9693288654089, 48.76953184604645, 51.28140605986118, 52.09729827940464, 57.92017042636871, 58.943071737885475, 60.74417509138584, 60.82417219877243, 59.65356521308422, 59.984151273965836, 61.15977019071579, 57.03422136604786, 53.67694191634655, 44.791646897792816, 51.56977258622646, 53.92464302480221, 60.06632946431637, 60.63544772565365, 63.06847617030144, 58.782062977552414, 67.6987937092781, 66.7420582473278, 67.54167973995209, 0.8466596435755491, 0.03201161234756, 3.960240832529962, 0.6730768829584122, 0.48857668472919613, 22.100866176187992, 80.84412753582001, 67.93035328388214, 60.246679186820984, 74.29212391376495, 69.45187523961067, 64.8520776629448, 39.56525534391403, 26.726519465446472, 58.58646847307682, 82.36825615167618, 13.183023054152727, 0.7040259253699332, 0.2379457256756723, 0.1755893201334402, 0.1897735137026757, 0.050650666089495644, 0.16147442831424996, 0.10703607797040604, 0.1425844692857936, 0.11623341022641398, 0.17566010617883876, 0.1751105606672354, 0.4881275666411966, 0.7528131699655205, 68.54420274496078, 75.67593365907669, 64.89251509308815, 42.552544847130775, 64.83188554644585, 61.40497483313084, 69.96115431189537, 78.01035359501839, 73.86916100978851, 66.97961390018463, 78.22764113545418, 23.725619092583656, 0.7654793746769428, 2.516796849668026, 6.4307682774960995, 1.3313437043689191, 0.2779354032827541, 45.60751251876354, 75.6979800760746, 63.85982930660248, 62.9283282905817, 58.768436908721924, 59.90585267543793, 57.83594034612179, 52.49648965895176, 52.263550758361816, 51.55895836651325, 52.498731538653374, 59.01642680168152, 56.843574196100235, 56.96301318705082, 57.3476779460907, 54.77097161114216, 57.16606669127941, 59.170778319239616, 56.015450432896614, 53.896505534648895, 59.53085459768772, 59.85771685838699, 59.10403490066528, 55.174019783735275, 55.52886754274368, 51.79759316146374, 49.09636750817299, 52.020777985453606, 56.28759942948818, 58.52373383939266, 56.54722049832344, 53.623395189642906, 59.21550951898098, 51.857189163565636, 45.28164580464363, 44.493898674845695, 45.20137891173363, 40.52740551531315, 41.00867249071598, 46.75549931824207, 49.98102083802223, 45.386231392621994, 42.99019016325474, 41.98390915989876, 41.53492525219917, 42.31033444404602, 40.25110334157944, 42.73141264915466, 44.00230385363102, 44.53046031296253, 46.39560543000698, 49.98601756989956, 49.119979441165924, 47.0167239010334, 48.5388196259737, 50.64662732183933, 46.23484745621681, 50.407939329743385, 54.96278531849384, 51.709335297346115, 47.17305511236191, 45.80987066030502, 45.194045305252075, 47.43717133998871, 46.09553933143616, 45.99494732916355, 47.89264149963856, 52.59215712547302, 49.44683790206909, 56.20369993150234, 53.86621356010437, 50.70471480488777, 48.43020625412464, 46.554463505744934, 49.153767228126526, 52.26975202560425, 48.565053418278694, 51.03202544152737, 47.89057821035385, 46.416576504707336, 44.72844108939171, 43.48183058202267, 42.83551946282387, 39.831286668777466, 42.50709928572178, 38.980326130986214, 41.07325002551079, 44.397041872143745, 41.752813160419464, 42.50816322863102, 40.85522532463074, 40.11835366487503, 43.68985801935196, 46.60537697374821, 43.751148730516434, 51.71042203903198, 49.24185410141945, 52.84632928669453, 56.19715668261051, 55.184617415070534, 57.47399836778641, 56.94100096821785, 57.72040754556656, 62.33393378555775, 54.03864450752735, 51.609347462654114, 50.85547171533108, 51.69629439711571, 52.87113815546036, 52.67129547894001, 59.80437912046909, 60.18845111131668, 62.16511644423008, 64.68962877988815, 62.47592456638813, 63.05046893656254, 63.028874695301056, 59.21827957034111, 56.48395009338856, 47.94386275112629, 54.22907128930092, 56.434374153614044, 62.857686281204224, 63.41553054749966, 63.86146321892738, 60.98637789487839, 68.34437146782875, 68.33088979125023, 68.99457737803459, 1.773210356477648, 0.49990687519311905, 10.255961269140244, 8.190832883119583, 0.9815256879664958, 24.712201952934265, 87.27762311697006, 74.97059270739555, 67.66146451234818, 79.77225825190544, 75.55363342165947, 73.93495067954063, 44.380269572138786, 39.7530222684145, 69.335016310215, 92.88726970553398, 19.63993962854147, 1.0349251725710928, 0.40642723033670336, 0.40809183788951486, 0.24368888000026345, 0.18899455550126731], [0.13534863333916292, 0.0737526397278998, 0.08461883204290643, 0.04127937070734333, 0.02096258453093469, 0.03431631485000253, 0.3217142494395375, 0.051795614417642355, 41.433569490909576, 61.35851092636585, 48.45591947436333, 21.603584960103035, 25.085875801742077, 40.91862492263317, 59.800263941287994, 68.46212714910507, 65.76142966747284, 59.486036002635956, 62.320186123251915, 31.23785398900509, 0.2451297894003801, 0.5902164510916919, 5.438075819984078, 0.32116716785822064, 0.20696604740805924, 39.824811816215515, 70.39751529693604, 58.52424681186676, 55.719522312283516, 51.582695692777634, 50.03143273293972, 49.450288116931915, 46.55655339360237, 45.08762061595917, 44.27469223737717, 47.24129565060139, 48.298999294638634, 52.257041707634926, 54.84876103699207, 54.27673973143101, 54.57773678004742, 54.23741564154625, 49.48759451508522, 52.402596697211266, 54.17334347963333, 50.82943931221962, 48.038785457611084, 48.89264903962612, 50.67805163562298, 52.475681975483894, 47.55235455930233, 43.16672869026661, 42.341534569859505, 44.75461408495903, 43.35364066064358, 47.75304839015007, 38.52851137518883, 52.68904812633991, 46.57752446830273, 43.820335417985916, 39.85081762075424, 38.37918318808079, 38.92720118165016, 44.76219467818737, 41.58469118177891, 36.34821116924286, 36.13869421184063, 36.46284341812134, 36.07267655432224, 39.047419130802155, 37.14325770735741, 36.60613752901554, 37.6291224360466, 38.6383330821991, 39.54675033688545, 40.01159839332104, 41.966988667845726, 45.08063659071922, 45.69878362119198, 47.61213295161724, 43.964818865060806, 43.94468754529953, 45.76264299452305, 48.40679571032524, 50.756365433335304, 47.793200835585594, 41.3366024941206, 41.13064594566822, 38.88327933847904, 43.765975534915924, 43.76778423786163, 47.1519510447979, 48.31463545560837, 49.69339907169342, 48.11404801905155, 45.518091917037964, 44.86164674162865, 43.57597433030605, 45.20574867725372, 45.1723712682724, 43.915588706731796, 45.65923914313316, 44.38728019595146, 41.346983537077904, 40.32146796584129, 37.82546930015087, 37.539644837379456, 37.2524144500494, 35.68982429802418, 35.615431889891624, 37.011609971523285, 36.918697357177734, 33.934413492679596, 37.657742500305176, 35.218915566802025, 37.911542281508446, 36.036327704787254, 38.10039974749088, 38.934751376509666, 42.41753809154034, 41.59933939576149, 46.826091930270195, 52.21261069178581, 53.030866384506226, 52.40865737199783, 52.83346317708492, 51.421063765883446, 47.132465690374374, 32.53925375640392, 45.790997073054314, 46.765097603201866, 47.90719851851463, 49.248967319726944, 49.074883460998535, 47.04497538506985, 47.24864825606346, 43.041483610868454, 46.927827671170235, 49.402319490909576, 57.89770223200321, 55.80592967569828, 58.09555761516094, 56.32232956588268, 55.72020247578621, 46.46354578435421, 45.99295623600483, 47.71883122622967, 55.106258019804955, 49.74970445036888, 55.54583363234997, 53.005483746528625, 64.42561134696007, 60.987757220864296, 63.31118814647198, 1.6583610442467034, 0.05228853777225595, 3.091303934343159, 0.5619429994840175, 0.3010681760497391, 23.359962813556194, 72.12394505739212, 59.144521728158, 59.521776884794235, 67.59311378002167, 67.86486759781837, 47.725963443517685, 26.285750716924667, 31.936473101377487, 53.469305858016014, 65.10768994688988, 4.740226166322827, 0.2813892695121467, 0.13104472600389272, 0.11040767712984234, 0.06297955726040527, 0.06630333242355846, 0.06087872643547598, 0.032097797957248986, 0.08188125706510618, 0.02278543652209919, 0.11366310049197637, 0.03761390704312362, 0.255015745642595, 0.290670805843547, 50.02357095479965, 70.26396006345749, 58.11308987438679, 26.84455443173647, 38.214013651013374, 48.895559683442116, 60.63339203596115, 73.31145733594894, 72.20012336969376, 63.837463706731796, 67.90984198451042, 32.90147311985493, 0.4741099110106006, 0.2887524134712294, 4.775142017751932, 0.3736728394869715, 0.2748369664186612, 41.89638465642929, 71.669010668993, 61.049325317144394, 55.754628628492355, 54.22367937862873, 53.57021704316139, 51.17700666189194, 48.15284013748169, 47.93989956378937, 46.46686300635338, 50.491949021816254, 50.92190735042095, 55.378897190093994, 56.7752880603075, 55.12870341539383, 56.14984542131424, 55.572508201003075, 51.809167340397835, 55.68748623132706, 56.58832289278507, 53.823488652706146, 52.08750620484352, 50.908395275473595, 54.320942759513855, 55.83524130284786, 49.23335015773773, 47.74731829762459, 41.51107773184776, 45.44946759939194, 45.78044883906841, 51.088688001036644, 39.671805426478386, 53.30937243998051, 49.203031584620476, 44.26704324781895, 42.527196407318115, 41.25011533498764, 42.57516123354435, 45.22451587021351, 44.42674867808819, 37.682000398635864, 38.13946545124054, 37.089532390236855, 39.949863106012344, 39.596565663814545, 38.51127550005913, 38.47787529230118, 40.39220117032528, 42.167097330093384, 40.77076345682144, 43.222266510128975, 42.58262783288956, 46.921653002500534, 46.11437872052193, 48.462717309594154, 45.98859786987305, 46.55800871551037, 47.45034143328667, 51.91972240805626, 52.58925408124924, 48.30892816185951, 43.69815677404404, 43.22221711277962, 41.13359458744526, 45.90873755514622, 46.47798880934715, 48.68724726140499, 48.58053378760815, 51.35382637381554, 50.150898322463036, 47.15876407921314, 46.907487362623215, 46.400214582681656, 47.80551977455616, 45.856881737709045, 46.72073118388653, 48.23935389518738, 46.02813854813576, 44.95902791619301, 42.58848711848259, 39.35580298304558, 38.43754045665264, 39.14057873189449, 37.37832449376583, 36.92191958427429, 37.97086849808693, 37.78314717113972, 35.88397867977619, 40.28790436685085, 37.19591908156872, 40.45307770371437, 39.03650991618633, 40.64951576292515, 41.175437942147255, 44.26378682255745, 43.814392536878586, 49.874820336699486, 55.350470915436745, 56.128634959459305, 53.80658715963364, 55.05446679890156, 54.35287244617939, 48.078223541378975, 34.98400077223778, 47.41008259356022, 47.077311649918556, 49.97260428965092, 49.500392228364944, 49.40402179956436, 46.286840066313744, 48.3988731354475, 44.79695901274681, 48.51142689585686, 50.482620522379875, 61.37314394116402, 57.810082733631134, 60.22834897041321, 58.186988309025764, 58.72986137866974, 48.8519000262022, 49.059517085552216, 50.62162086367607, 58.29294562339783, 52.9089917242527, 58.465099185705185, 54.64998610317707, 67.66125172376633, 65.16577363014221, 69.62080657482147, 2.3886211775243282, 0.01930447262566304, 3.6893823416903615, 0.5149983591400087, 0.3632430819561705, 25.40243111550808, 80.87983801960945, 65.3195209801197, 61.71361327171326, 74.01701867580414, 71.27100482583046, 55.44445127248764, 30.974892899394035, 35.52987188100815, 63.63326646387577, 74.94068831205368, 7.339439168572426, 0.42310943361371756, 0.19987046252936125, 0.11301939128316008, 0.06476943934103474, 0.06751099223038182, 0.2548675535945222, 0.17807122523663566, 0.2235960034886375, 0.15266019268892705, 0.23531680111773312, 0.1784066017717123, 0.3435523604275659, 0.40408970264252275, 57.71474204957485, 77.3196342587471, 65.93910813331604, 28.605060763657093, 36.10233776271343, 55.98255179822445, 70.77304914593697, 78.96914094686508, 79.04261380434036, 68.64435777068138, 72.8331010043621, 36.598131358623505, 0.45730774698313326, 3.2247401867061853, 12.980557568371296, 0.5634543090127409, 0.3668894909787923, 45.22470586001873, 74.33731108903885, 64.9457198381424, 59.760054498910904, 57.41351701319218, 55.00954940915108, 53.80554981529713, 51.14310868084431, 50.86291931569576, 48.239798471331596, 53.206272572278976, 53.96469667553902, 56.47310167551041, 58.89497771859169, 59.29250858724117, 60.191962122917175, 59.20055352151394, 53.762406930327415, 57.694181352853775, 56.9132624566555, 57.84124866127968, 53.874569311738014, 53.093369230628014, 56.37184850871563, 57.04312428832054, 53.12439076602459, 48.44178043305874, 41.274730414152145, 47.734839767217636, 46.39900624752045, 52.446313351392746, 40.35235270857811, 57.838372215628624, 51.577208787202835, 48.39185491204262, 44.419928044080734, 42.6412320882082, 42.448305040597916, 48.99496614933014, 45.166151002049446, 38.397410809993744, 40.76094478368759, 38.99373561143875, 39.79157119989395, 42.85997495055199, 40.64607694745064, 40.73160655796528, 41.10907830297947, 42.78121277689934, 44.16702501475811, 44.680673852562904, 47.00332961976528, 50.73460020124912, 50.168905556201935, 49.269497618079185, 48.26848693192005, 49.56674046814442, 48.59368868172169, 53.557768911123276, 54.55184876918793, 50.05059890449047, 46.69222131371498, 46.55569463968277, 43.625884652137756, 47.35636107623577, 47.671063989400864, 49.89257298409939, 50.985504537820816, 53.57178255915642, 52.88751147687435, 49.522594437003136, 48.42422537505627, 48.16750355064869, 50.739232152700424, 47.85573408007622, 49.77753035724163, 51.835287138819695, 48.73928166925907, 46.086799800395966, 45.72176858782768, 41.73298582434654, 40.48968493938446, 41.958944499492645, 38.84430482983589, 39.09168295562267, 40.507524982094765, 40.206425338983536, 37.82262705266476, 42.57956899702549, 38.550265207886696, 41.94313734769821, 40.15846811234951, 42.86034733057022, 43.551784828305244, 46.774950474500656, 46.30973383784294, 52.12406404316425, 56.61503545939922, 58.134543523192406, 56.79665811359882, 58.151384219527245, 54.67271268367767, 52.29076869785786, 37.925966307520866, 49.29218240082264, 49.651255533099174, 50.00742942094803, 50.9509339928627, 50.946066454052925, 46.95664532482624, 49.98599857091904, 47.352565079927444, 49.56676706671715, 51.69665917754173, 62.03845404088497, 59.549165815114975, 63.11821170151234, 60.4123654961586, 60.441319942474365, 50.311219319701195, 51.85251921415329, 53.60001504421234, 60.6067630648613, 55.95897786319256, 62.473914474248886, 57.84963861107826, 69.29069548845291, 65.72691231966019, 70.46404212713242, 3.2890080381184816, 0.11361630808096379, 9.437953513115644, 4.070931980386376, 0.4295202833600342, 28.29339388757944, 85.68278789520264, 69.65627387166023, 71.97911202907562, 79.64811131358147, 79.23963323235512, 64.41512390971184, 39.95541460812092, 47.8340220451355, 71.03311479091644, 88.64538252353668, 11.488978005945683, 0.7787767611443996, 0.341924533713609, 0.20086603879462928, 0.143958110420499, 0.19114709546556696], [0.0736187859729398, 0.03992480276792776, 0.08327867661137134, 0.06467053332016803, 0.08766577870119363, 0.05674200270732399, 0.38141563651151955, 0.1763451233273372, 29.13539830595255, 72.00330913066864, 41.293030232191086, 39.20555904507637, 40.60644507408142, 42.991010919213295, 59.57264095544815, 57.470901533961296, 60.62970623373985, 59.508545994758606, 62.26228483021259, 40.404983684420586, 0.15196077787550166, 0.5349330394528806, 1.3338113157078624, 0.5168827611487359, 0.1292256181477569, 35.8523453772068, 72.25333571434021, 61.11824981868267, 55.2567071467638, 48.114173412323, 47.71784707903862, 48.17227229475975, 46.23725272715092, 42.38464705646038, 41.364948973059654, 42.27314583957195, 43.984026834368706, 46.19290150702, 52.649655640125275, 53.224579989910126, 52.472345754504204, 53.46067272126675, 54.11039225757122, 53.5625946521759, 52.176212444901466, 48.49129557609558, 42.48026892542839, 43.77536483108997, 49.412746131420135, 50.030387789011, 52.613040804862976, 51.51714541018009, 49.668654799461365, 49.16046626865864, 47.653888911008835, 48.05350586771965, 51.06354475021362, 53.34856353700161, 46.401996687054634, 44.0167810767889, 40.68785570561886, 38.71203012764454, 40.32179854810238, 41.658923998475075, 38.31325672566891, 36.78444296121597, 38.3792819827795, 38.03675316274166, 38.054068833589554, 39.00321610271931, 35.724945813417435, 38.25530603528023, 38.630486503243446, 38.705543875694275, 39.560661390423775, 41.314347088336945, 40.71535862982273, 42.18010023236275, 42.743264213204384, 45.4916225373745, 43.70144359767437, 42.86811411380768, 44.84198659658432, 49.673267751932144, 49.67976160347462, 46.08848690986633, 43.484547436237335, 41.492831110954285, 39.20800991356373, 44.33349788188934, 45.34131400287151, 43.82111057639122, 48.342852741479874, 44.980367571115494, 44.86119456589222, 43.85664626955986, 44.871841594576836, 43.2907160371542, 41.339585334062576, 43.74462828040123, 45.07996402680874, 42.52071015536785, 43.80482845008373, 40.339460000395775, 40.98807379603386, 39.08611245453358, 37.363801673054695, 36.417948827147484, 34.69593442976475, 35.12522019445896, 34.76186089217663, 37.41708241403103, 33.50474774837494, 34.142353534698486, 34.9112992733717, 37.34944224357605, 40.054102912545204, 40.39502061903477, 41.17405101656914, 44.84348751604557, 42.74691961705685, 48.0576628446579, 53.32204096019268, 51.31585881114006, 53.624774515628815, 53.14297176897526, 52.109332233667374, 48.210608437657356, 50.43239861726761, 50.833782479166985, 52.08662085235119, 55.76673477888107, 55.06919480860233, 54.73654165863991, 49.76236917078495, 54.69149887561798, 45.594532415270805, 46.70276574790478, 50.17953738570213, 59.905860275030136, 53.923320695757866, 55.74412979185581, 54.84067887067795, 53.02623823285103, 44.822147861123085, 44.431540220975876, 43.10270592570305, 52.58753277361393, 49.74224925041199, 54.41674321889877, 56.214042976498604, 66.85673609375954, 61.11312389373779, 68.66862326860428, 2.823387673124671, 0.10110170929692686, 1.103986466769129, 0.7511094957590103, 0.03739293628314044, 34.74436283111572, 73.53099435567856, 63.25036861002445, 63.63675847649574, 67.50451013445854, 67.36673712730408, 46.969682425260544, 31.829934418201447, 34.285385459661484, 61.410100758075714, 57.13780000805855, 2.9258088022470474, 0.04342162450484466, 0.0380367197067244, 0.06068786831747275, 0.08519896888174117, 0.02541986967116827, 0.08859781970386393, 0.07273691415321082, 0.21125261817360297, 0.006363211286952719, 0.11346181519911624, 0.004445052227310953, 0.49869818380102515, 0.16601292853010818, 38.86046536266804, 79.15714725852013, 46.43638104200363, 30.750744827091694, 34.246239960193634, 51.73431135714054, 63.62649902701378, 66.52610823512077, 66.37256607413292, 62.78463900089264, 66.21076315641403, 44.43673834204674, 0.24408876401139423, 0.5582772649358958, 4.892752831801772, 0.8431624656077474, 0.04867429714067839, 36.87293641269207, 76.5868891775608, 63.395361229777336, 56.9634273648262, 49.582885801792145, 50.629015266895294, 49.731416031718254, 47.79354281723499, 44.60850052535534, 43.6230044066906, 45.06579838693142, 47.14065805077553, 48.795359060168266, 54.03029255568981, 55.53200617432594, 54.38547469675541, 55.17381079494953, 55.18298350274563, 56.22075341641903, 52.759496346116066, 51.844592839479446, 45.442707762122154, 46.36987701058388, 51.36601611971855, 53.96870166063309, 56.40823155641556, 52.632412165403366, 53.00737224519253, 49.73672814667225, 49.26631718873978, 48.30920934677124, 52.265401259064674, 55.32794572412968, 49.32020589709282, 44.843483716249466, 42.80967704951763, 39.13881562650204, 41.6597143560648, 43.813157603144646, 39.02340441942215, 38.77886854112148, 40.02637580037117, 39.8626995831728, 39.200657308101654, 41.219215393066406, 38.47871124744415, 39.971103966236115, 39.84284944832325, 40.89350067079067, 42.45548665523529, 43.30368474125862, 43.959286361932755, 46.78199149668217, 46.86226598918438, 48.54382395744324, 45.164855271577835, 45.29165826737881, 45.14625146985054, 51.12416289746761, 52.263926938176155, 48.633776530623436, 45.039940774440765, 44.91995081305504, 41.24068424105644, 45.21486818790436, 46.137530878186226, 44.175981134176254, 48.97651053965092, 47.73468017578125, 47.40515045821667, 46.577273681759834, 45.62537156045437, 43.423036336898804, 43.6558498442173, 45.72237275540829, 44.97288957238197, 45.89847810566425, 46.680844724178314, 42.32047989964485, 42.68787458539009, 42.49501593410969, 38.87606352567673, 38.38672578334808, 36.61987379193306, 37.57315143942833, 36.80878445506096, 39.624178782105446, 36.17184743285179, 35.987302735447884, 36.61354713141918, 37.06827253103256, 40.67725047469139, 41.08177676796913, 44.717273488640785, 45.53603075444698, 44.68540079891682, 51.21874362230301, 54.249100014567375, 52.79170721769333, 53.52419011294842, 54.47022154927254, 52.54566662013531, 51.01811818778515, 51.65441684424877, 51.487305611371994, 51.838931143283844, 57.79750920832157, 56.96460150182247, 58.18467043340206, 54.95423577725887, 54.91388954222202, 46.5829885751009, 48.506673350930214, 50.18712177872658, 59.55209545791149, 57.119515389204025, 59.81319844722748, 57.50654362142086, 57.369146794080734, 46.43730439245701, 48.48085753619671, 45.14370560646057, 55.40923856198788, 51.512087881565094, 58.313525319099426, 57.331388220191, 70.32171696424484, 62.890915498137474, 73.00295189023018, 3.6262207059189677, 0.12365334332571365, 5.341774737462401, 0.9666096477303654, 0.013506147042789962, 35.615355893969536, 80.51193416118622, 68.03807750344276, 69.85707029700279, 75.09131982922554, 71.99792861938477, 57.30924680829048, 34.91372354328632, 39.365336671471596, 69.32911902666092, 68.18185418844223, 4.507723767310381, 0.27230567880906165, 0.1360443967860192, 0.08303642476676032, 0.12041072943247855, 0.06138278571597766, 0.26495292491745204, 0.21349185582948849, 0.4005628387676552, 0.10321216948796064, 0.24584248865721747, 0.11426222146837972, 0.6173335178755224, 0.3805168956751004, 43.35023984313011, 89.58563446998596, 58.46609853208065, 52.809497863054276, 54.32439297437668, 61.11950375139713, 70.09885132312775, 69.28282991051674, 71.1268025636673, 68.00669118762016, 73.20541262626648, 48.58696684241295, 0.2875307493377477, 1.852878900244832, 9.688670709729195, 1.7097510304301977, 0.29191604058723897, 41.752505376935005, 77.02641159296036, 64.0892305970192, 59.73511263728142, 51.41008995473385, 52.30390839278698, 52.97497898340225, 51.72601260244846, 46.10769867897034, 44.33021105825901, 47.4508012086153, 49.45982560515404, 50.92951454222202, 56.28702946007252, 57.67071381211281, 56.61093927919865, 58.07140231132507, 58.01905632019043, 59.62368741631508, 55.82694634795189, 54.626750349998474, 48.59108202159405, 48.3541951328516, 52.7684410661459, 55.785121992230415, 59.23833109438419, 54.11283552646637, 53.945427909493446, 52.365320697426796, 50.266894698143005, 51.07401318848133, 56.23231999576092, 57.29114077985287, 52.100904285907745, 47.752812802791595, 44.42143656313419, 40.73321387171745, 43.95900137722492, 47.06177808344364, 41.410200744867325, 40.3613506257534, 41.36960372328758, 42.838620096445084, 41.78501643240452, 44.317557737231255, 40.680856481194496, 42.81570352613926, 40.998454838991165, 44.11936417222023, 43.629475459456444, 46.04791268706322, 47.28571526706219, 50.151662081480026, 50.24172484874725, 50.06902411580086, 45.674092546105385, 44.61305268108845, 46.165698766708374, 53.84804293513298, 52.335606291890144, 48.1815779954195, 48.26904930174351, 47.81771332025528, 43.33750292658806, 47.66235865652561, 48.50924961268902, 45.87546654045582, 49.2639385163784, 48.84123779833317, 47.33633995056152, 46.856155917048454, 47.78790012001991, 46.458343863487244, 45.79667776823044, 47.27374590933323, 47.18615680932999, 49.81095336377621, 50.20773187279701, 46.02342300117016, 44.88969303667545, 45.027120262384415, 41.1914274841547, 41.650047674775124, 38.76324377954006, 39.855966344475746, 37.90848724544048, 42.22400687634945, 38.36552672088146, 39.73969258368015, 39.22167778015137, 39.311862140893936, 44.026215970516205, 43.96030850708485, 47.52170540392399, 49.23011273145676, 46.88656568527222, 53.169783130288124, 58.168046325445175, 53.547315672039986, 56.07424087822437, 57.267832830548286, 54.27720330655575, 53.77352513372898, 53.006315901875496, 53.08722496032715, 54.37067449092865, 59.97441999614239, 58.39364781975746, 58.82793411612511, 56.218640729784966, 57.97648720443249, 47.87198580801487, 53.282770067453384, 53.14845867455006, 63.4876012802124, 58.42793717980385, 61.62623696029186, 60.973633378744125, 58.66561062633991, 50.51100879907608, 49.22732748091221, 46.097021251916885, 57.11131162941456, 53.01456145942211, 60.9661515802145, 59.46801356971264, 71.99010863900185, 64.82041776180267, 76.01093888282776, 5.738994972780347, 0.19028393318876624, 7.062352811917663, 2.32282652053982, 0.13511046330677345, 40.501779690384865, 85.39211869239807, 74.23426061868668, 76.25620052218437, 80.40386036038399, 77.87854626774788, 66.93001136183739, 43.320753425359726, 49.96491730213165, 76.17651119828224, 80.77373251318932, 7.70865585654974, 0.691654501715675, 0.2228078426560387, 0.2325666244723834, 0.2099209083826281, 0.13996367866639048], [0.03937915724236518, 0.022924136501387693, 0.0892337215191219, 0.043892253743251786, 0.01920497845276259, 0.04708973392553162, 0.4348424915224314, 0.035225445753894746, 23.22157233953476, 71.98924988508224, 49.45006772875786, 60.12174569070339, 44.509067460894585, 43.71505446732044, 55.12641213834286, 49.215130135416985, 58.50478805601597, 64.29442718625069, 56.44613832235336, 56.12766981124878, 0.7290062005631626, 0.20057226705830544, 1.9111404614523053, 0.4738889291184023, 0.08719614765141159, 24.610823392868042, 72.76033490896225, 60.76974391937256, 60.54178275167942, 47.435119450092316, 46.7297974973917, 42.04966843128204, 46.52168266475201, 44.88174006342888, 44.59898583590984, 41.277036890387535, 40.4471006244421, 41.16318739950657, 41.95986405014992, 46.20901644229889, 49.3214750289917, 48.57558265328407, 49.98797066509724, 48.41957062482834, 46.93225063383579, 41.89551830291748, 40.169593915343285, 41.67190410196781, 47.248317673802376, 53.0428471416235, 51.61929912865162, 54.14604194462299, 52.31832481920719, 54.623604118824005, 51.08129359781742, 51.83797359466553, 51.09528064727783, 48.98260921239853, 44.09553945064545, 43.7927109003067, 41.174271404743195, 41.247554272413254, 42.26981341838837, 41.504108905792236, 43.07183638215065, 45.15810303390026, 38.189995139837265, 37.40529544651508, 36.7913281917572, 37.70481817424297, 36.6354301571846, 36.487409099936485, 38.42895671725273, 39.62457396090031, 39.171091094613075, 42.91404224932194, 42.645997032523155, 41.892581060528755, 46.10169120132923, 44.14375886321068, 42.0638682693243, 41.29143051803112, 42.146544232964516, 47.10040681064129, 50.822421088814735, 48.9129551500082, 44.50505867600441, 43.30639399588108, 40.166713669896126, 44.96467441320419, 45.56094601750374, 43.21780934929848, 49.78166073560715, 44.53569643199444, 43.46526347100735, 44.22466792166233, 42.734931260347366, 41.523761451244354, 42.75514617562294, 45.53254634141922, 43.441894724965096, 43.77713933587074, 38.7656756490469, 39.85756225883961, 40.863892659544945, 39.32467885315418, 38.19023072719574, 36.18243746459484, 36.15090295672417, 37.162309885025024, 36.565563306212425, 40.96634656190872, 42.87574790418148, 42.26475968956947, 42.199452593922615, 39.59748521447182, 39.46585647761822, 39.561520144343376, 40.08834667503834, 42.89799191057682, 43.75603906810284, 50.28485253453255, 50.45004487037659, 53.771762028336525, 52.774836122989655, 55.199710205197334, 52.649553045630455, 55.58987706899643, 52.07637660205364, 52.45839670300484, 52.841533944010735, 53.89004588127136, 51.94741152226925, 50.10681688785553, 53.627913147211075, 52.89153926074505, 53.586202785372734, 61.46177418529987, 59.412589743733406, 56.04859225451946, 54.00454893708229, 55.188177824020386, 49.298231676220894, 48.089649528265, 45.92014454305172, 44.23791401088238, 44.94510926306248, 47.73339584469795, 49.35786947607994, 54.05673913657665, 56.020853742957115, 65.99641665816307, 61.98792055249214, 67.23455742001534, 4.726624321192503, 0.10026739430031739, 2.345305164344609, 0.34627651737537235, 0.24680046772118658, 37.688817232847214, 69.71199408173561, 59.626556262373924, 62.866691797971725, 66.98308691382408, 63.143506944179535, 40.094285756349564, 32.06875540316105, 44.33119900524616, 59.00064244866371, 53.21127690374851, 1.0667997621931136, 0.04937523706757929, 0.09816839286941104, 0.032450778235215694, 0.07043241203064099, 0.0626400024339091, 0.060470500684459694, 0.011234132434765343, 0.12441405953723006, 0.05583933219895698, 0.03760648185561877, 0.019795841180894058, 0.44243991666007787, 0.12760239274939522, 27.84846816211939, 79.20949324965477, 53.81903149187565, 51.81596137583256, 36.68189786374569, 54.57673743367195, 57.82691203057766, 56.351933777332306, 64.23692867159843, 68.18646714091301, 61.88059911131859, 60.35807400941849, 0.5860974721144885, 0.1162031306012068, 1.915722421836108, 2.6979851396754384, 0.11410406237700954, 28.365723006427288, 75.60093328356743, 63.08101549744606, 61.39164514839649, 48.69199700653553, 50.587418898940086, 44.318560883402824, 48.914741054177284, 46.89593218266964, 46.52721896767616, 43.17172922194004, 43.84022355079651, 42.51890145242214, 44.74120460450649, 48.415056467056274, 51.64171412587166, 52.01447032392025, 54.32934030890465, 51.65294252336025, 51.29894971847534, 43.268494829535484, 41.413742154836655, 42.71547630429268, 48.94396148622036, 55.66131703555584, 52.405245155096054, 55.55131673812866, 55.07728077471256, 56.33712977170944, 53.14881585538387, 54.54529032111168, 54.18325334787369, 51.15351252257824, 46.58516205847263, 45.56378826498985, 43.73010165989399, 42.5902958214283, 44.43836085498333, 41.804015412926674, 45.09696051478386, 45.65423861145973, 40.3350218385458, 40.42251214385033, 37.75836110115051, 39.97356243431568, 39.63628113269806, 38.0358412116766, 40.32046861946583, 40.92484138906002, 41.28931403160095, 45.33540531992912, 44.50684458017349, 45.58493413031101, 46.92242056131363, 46.84197887778282, 41.924951523542404, 42.23797872662544, 43.54238033294678, 47.73362763226032, 53.4439992159605, 48.941221833229065, 45.756251737475395, 46.46490231156349, 42.429507449269295, 46.633313074707985, 45.87182253599167, 43.78245525062084, 50.87689496576786, 45.66993556916714, 46.330754309892654, 44.690158143639565, 44.92964409291744, 42.487853318452835, 45.026280507445335, 46.24019376933575, 46.4691998809576, 45.87704345583916, 43.078307434916496, 43.030996173620224, 43.51725988090038, 41.08291670680046, 39.257494658231735, 37.602664455771446, 36.95747047662735, 38.62754926085472, 37.14705750346184, 44.858359917998314, 45.429853051900864, 45.32728895545006, 43.47132034599781, 43.3793006837368, 42.041267082095146, 41.818868815898895, 41.431734189391136, 45.359401032328606, 44.44470651447773, 52.420664727687836, 52.85597696900368, 55.25908961892128, 53.97583767771721, 57.02815689146519, 54.39049042761326, 57.13813818991184, 53.86590197682381, 53.7704548984766, 54.13208909332752, 55.69964177906513, 55.31498081982136, 52.77422055602074, 56.33104629814625, 55.78006446361542, 52.81237430870533, 62.34633632004261, 61.19735397398472, 59.43555571138859, 57.30275675654411, 58.6373021453619, 51.30579315125942, 50.898268818855286, 47.68784388899803, 47.69914448261261, 46.55130587518215, 51.49919517338276, 51.007463559508324, 56.48940660059452, 58.83810617029667, 70.59220924973488, 63.38888257741928, 74.6304501593113, 6.9413920026272535, 0.10676051853806712, 5.408752793446183, 1.2459132447838783, 0.2231312557705678, 40.53909748792648, 77.95142635703087, 63.672005385160446, 67.8544333577156, 73.92576277256012, 70.50402358174324, 49.85221914947033, 30.637301914393902, 45.295986235141754, 65.44198080897331, 64.22632724046707, 2.4315367871895432, 0.16556749149458483, 0.03856447947327979, 0.04962157072441187, 0.09426991338841617, 0.02192591633502161, 0.13719310780288652, 0.18903715477790684, 0.2107573236571625, 0.1720400433987379, 0.08250094295362942, 0.10384622335550375, 0.5944091698620468, 0.24024617567192763, 32.597481831908226, 91.04222550988197, 65.41234999895096, 75.73462530970573, 58.22017192840576, 62.48216763138771, 66.93564265966415, 62.69991874694824, 70.90226501226425, 75.58674484491348, 67.5395518541336, 67.58780166506767, 0.9123234450817108, 0.9796101751271635, 9.367028418928385, 3.5910350689664483, 0.337941397447139, 28.50478794425726, 77.18056932091713, 66.33691638708115, 64.50647860765457, 51.47198103368282, 51.68797664344311, 46.50151714682579, 52.238749489188194, 49.143424183130264, 51.06984481215477, 45.40721006691456, 45.55127173662186, 45.06511062383652, 46.97553031146526, 51.357075199484825, 54.8929450660944, 53.37140031158924, 58.565470799803734, 53.01372170448303, 52.05510154366493, 44.78668436408043, 43.2366943359375, 46.78339742124081, 50.631272345781326, 57.98208810389042, 55.44530242681503, 56.88889056444168, 55.258588045835495, 58.19109968841076, 53.6617237329483, 57.85318002104759, 57.64680169522762, 52.63220317661762, 49.515921995043755, 47.090379148721695, 46.90278701484203, 45.550549775362015, 45.774361565709114, 46.53512254357338, 47.26265050470829, 48.45648944377899, 42.84674406051636, 42.14495211839676, 40.414502173662186, 42.62989729642868, 41.0101468116045, 40.43649539351463, 41.601805463433266, 44.318397492170334, 43.228536173701286, 46.46836392581463, 48.216463923454285, 49.46873612701893, 49.04678396880627, 47.55616195499897, 44.71191577613354, 42.93071195483208, 42.41680473089218, 48.814213648438454, 53.533199429512024, 52.5228526443243, 46.60752385854721, 48.15399527549744, 45.91050446033478, 47.987317219376564, 48.27372305095196, 45.30607469379902, 53.25900614261627, 47.54616089165211, 48.371271416544914, 46.98134019970894, 46.01898863911629, 46.00525237619877, 46.49839371442795, 50.382856875658035, 50.11993758380413, 47.36446604132652, 45.741124749183655, 45.384114906191826, 46.43441654741764, 43.759363889694214, 40.65846048295498, 39.627488404512405, 40.118323266506195, 40.57921193540096, 39.814563766121864, 46.6708854585886, 47.2722639888525, 48.90495277941227, 46.39115586876869, 43.74631159007549, 43.09128753840923, 43.43374416232109, 45.19768550992012, 47.07894556224346, 47.418525740504265, 55.65531335771084, 55.016320645809174, 57.318468913435936, 56.41600213944912, 59.972402304410934, 57.51427620649338, 59.097769036889076, 56.24005638062954, 57.573401033878326, 57.109233140945435, 58.98960784077644, 57.99628794193268, 56.13436505198479, 57.94434852898121, 57.55371809005737, 54.78209361433983, 63.121357932686806, 65.34100502729416, 62.68626607954502, 60.76778702437878, 59.4126733392477, 51.925532296299934, 53.0396743118763, 50.717493519186974, 49.440838024020195, 49.058521538972855, 53.09200510382652, 53.487537279725075, 58.157893270254135, 61.21747389435768, 71.91696256399155, 65.68851917982101, 76.4830407500267, 9.675411321222782, 0.20806135347811505, 7.54914659075439, 4.108551861718297, 0.39599868992809206, 44.929834082722664, 82.24166974425316, 70.24369955062866, 75.51774814724922, 78.89803156256676, 75.35830870270729, 59.409382715821266, 44.8339082300663, 61.289062052965164, 72.70651459693909, 76.71906888484955, 3.856241600587964, 0.278013328788802, 0.28199815715197474, 0.12596264714375138, 0.1870661144494079, 0.12677203339990228], [0.02269719887408428, 0.10668881965102628, 0.047736192791489884, 0.020672106074925978, 0.01585661779245129, 0.08993542956886813, 0.5763829371426255, 0.08712175476830453, 17.394752204418182, 73.1896510720253, 45.437802225351334, 40.45013666152954, 23.09247236698866, 39.856908693909645, 64.1136784851551, 56.53379961848259, 53.71341995894909, 65.33513054251671, 52.54925362765789, 62.316070944070816, 3.248572745360434, 0.1913388367393054, 2.4759176932275295, 1.0431779734790325, 0.044314272308838554, 13.334853406995535, 74.83530476689339, 59.53063040971756, 60.247640535235405, 47.26092539727688, 48.832103088498116, 45.972653925418854, 49.00514580309391, 47.929735109210014, 49.239699617028236, 46.415425166487694, 44.21361431479454, 38.6738345772028, 40.560186356306076, 40.712960958480835, 39.98179279267788, 39.776045233011246, 41.19279161095619, 40.56368976831436, 40.28350420296192, 40.73729485273361, 43.40227425098419, 40.34114710986614, 42.47798904776573, 45.17629645764828, 48.707857355475426, 48.792991787195206, 49.03622813522816, 48.14162693917751, 50.57297967374325, 48.538804426789284, 48.43270651996136, 45.81447221338749, 45.12260913848877, 44.21122044324875, 41.673511415719986, 40.1964470744133, 41.57340198755264, 39.48983699083328, 38.20941589772701, 40.00733882188797, 37.704966366291046, 37.59289138019085, 37.50472091138363, 38.22879105806351, 37.983153238892555, 37.00847513973713, 39.20400112867355, 38.93841437995434, 42.04312518239021, 45.40889337658882, 47.694740518927574, 44.82477732002735, 42.15975232422352, 38.47461886703968, 41.74986071884632, 40.48529997467995, 39.555755853652954, 42.660858035087585, 48.00333335995674, 50.19670106470585, 44.77152697741985, 43.73977214097977, 40.62566824257374, 48.17653566598892, 43.54441702365875, 46.022518649697304, 51.60925626754761, 43.22678826749325, 41.28470487892628, 41.822383627295494, 41.78555980324745, 41.00052572786808, 41.42638027667999, 42.94954754412174, 44.366274923086166, 45.05848377943039, 40.95113977789879, 38.739305064082146, 40.4296063631773, 39.14045713841915, 35.41502684354782, 37.32920452952385, 36.84870891273022, 37.51938812434673, 35.45820392668247, 38.13703738152981, 37.758319303393364, 42.82520681619644, 44.71635773777962, 39.13495123386383, 40.90296596288681, 40.04127860069275, 39.618741273880005, 40.77920660376549, 44.65823605656624, 49.14680600166321, 49.892732575535774, 51.79620623588562, 49.61309798061848, 49.28492099046707, 50.74815407395363, 50.46554043889046, 54.014762789011, 51.04091316461563, 50.593806356191635, 52.73034431040287, 50.61707250773907, 50.80121822655201, 49.13918361067772, 54.490379467606544, 46.99123106896877, 51.80436819791794, 56.44884377717972, 54.748621210455894, 51.36584132909775, 50.48491559922695, 43.55032190680504, 46.1664055287838, 41.90426543354988, 45.95132566988468, 44.634608924388885, 46.57154738903046, 48.31673674285412, 51.932778507471085, 54.30579677224159, 67.16572791337967, 58.58725503087044, 64.62815567851067, 6.691675577312708, 0.21296093822456896, 5.493741882964969, 0.9742367884609848, 0.3263302892446518, 40.38129195570946, 70.36194160580635, 61.23706944286823, 66.33925706148148, 63.20767790079117, 58.85803610086441, 35.23522809147835, 32.40409500896931, 44.10655125975609, 58.19085270166397, 39.53022122383118, 0.5262283002957702, 0.07602732235682197, 0.023874224680184852, 0.018874613269872498, 0.1035620846960228, 0.0221872747715679, 0.05316198250511661, 0.05819677913677879, 0.052234012182452716, 0.055385609084623866, 0.056598790470161475, 0.14749767986359075, 0.46173450944479555, 0.09789070347324014, 21.85931123793125, 81.4843475818634, 51.61914713680744, 50.53167589008808, 32.16676354408264, 52.652657479047775, 66.74658760428429, 60.66231608390808, 59.15863797068596, 72.47964397072792, 57.43166483938694, 70.58533161878586, 3.1520534120500088, 0.16838046867633238, 2.2008965257555246, 2.587877498008311, 0.08840710259391926, 14.924861937761307, 75.95161646604538, 61.58376283943653, 62.06293612718582, 48.861395716667175, 49.8499658703804, 48.289268016815186, 51.87214136123657, 50.63803218305111, 50.77836625277996, 46.412742510437965, 45.3611109405756, 40.91765597462654, 43.64227697253227, 43.08905705809593, 42.38265596330166, 42.52788037061691, 43.3628323674202, 41.80191792547703, 42.304756343364716, 43.03880475461483, 43.69060277938843, 41.59240856766701, 44.59404230117798, 47.08629056811333, 50.927056074142456, 50.995099022984505, 52.17236705124378, 51.30015045404434, 52.38381430506706, 50.96269056200981, 51.96135677397251, 47.09865130484104, 45.67457892000675, 45.387492924928665, 42.58850231766701, 41.92199908196926, 45.22147983312607, 41.9779396802187, 41.267229616642, 41.20252288877964, 39.61044631898403, 38.96250508725643, 39.029119312763214, 38.709624856710434, 39.875938072800636, 39.454388692975044, 41.52457840740681, 40.14055587351322, 42.20945745706558, 46.65888570249081, 47.598415687680244, 46.84412956237793, 44.54804576933384, 41.30327448248863, 42.35718972980976, 40.26985913515091, 40.39506621658802, 41.515580490231514, 49.793003126978874, 51.584755182266235, 45.48322878777981, 45.895400270819664, 42.18576952815056, 50.61052925884724, 44.13124233484268, 46.82650990784168, 51.57418794929981, 43.66956330835819, 42.031516805291176, 42.75397963821888, 43.193034678697586, 41.83512054383755, 43.44283327460289, 45.61386577785015, 46.25016823410988, 46.2080816924572, 42.96630844473839, 41.84037946164608, 43.626355826854706, 40.26864320039749, 37.12316818535328, 38.44811148941517, 39.0779884904623, 39.180677980184555, 37.79519632458687, 39.86831568181515, 39.446773901581764, 44.80525016784668, 46.27979524433613, 40.15404514968395, 41.35946586728096, 41.490026861429214, 40.304019302129745, 44.86199252307415, 46.4641347527504, 49.64438930153847, 50.43627440929413, 53.01523022353649, 52.25924178957939, 52.78924494981766, 52.664216458797455, 52.78078280389309, 55.763520151376724, 52.90097415447235, 52.746444046497345, 54.30088743567467, 53.79082180559635, 53.953342884778976, 51.04591749608517, 55.262490436434746, 51.51651844382286, 54.410348162055016, 58.616889640688896, 57.37413212656975, 53.06987889111042, 52.98559941351414, 44.571384117007256, 49.11582626402378, 44.25459511578083, 49.532325714826584, 47.173617482185364, 49.50903296470642, 49.78172533214092, 54.790707752108574, 57.539734840393066, 71.49026066064835, 61.60923287272453, 71.46461963653564, 10.514286607503891, 0.09470156132010743, 3.440442499704659, 0.6476015062071383, 0.33590259903576225, 43.41099098324776, 77.95147195458412, 66.83105707168579, 73.42324733734131, 70.21640941500664, 64.58040744066238, 47.397379875183105, 34.699266850948334, 52.446921318769455, 66.22688189148903, 50.82569271326065, 0.6760455924086273, 0.042323093803133816, 0.028682994670816697, 0.013950911506981356, 0.11452610691776499, 0.001983191605177126, 0.19712484267074615, 0.3176371572772041, 0.18309691571630538, 0.19750372390262783, 0.17791014950489625, 0.21541305352002382, 0.7362619112245739, 0.22927044978132471, 24.44061152637005, 95.22207722067833, 59.6507153660059, 57.05116465687752, 31.93080760538578, 58.76005835831165, 73.10317531228065, 69.1095744073391, 65.42669802904129, 77.04097241163254, 62.93498933315277, 74.66370597481728, 4.8385553900152445, 0.3544416557997465, 7.725870832800865, 4.869865709915757, 0.18439686158671975, 15.543773677200079, 79.89746913313866, 64.27700132131577, 66.48528322577477, 50.99255695939064, 51.61840997636318, 50.03763400018215, 51.66658379137516, 52.0254061371088, 53.041129633784294, 49.909968450665474, 49.710843935608864, 44.027785286307335, 46.34448677301407, 45.07904827594757, 44.089303985238075, 45.07689379155636, 44.453423246741295, 45.194980055093765, 44.944448098540306, 46.8307238817215, 46.35762646794319, 44.28914286196232, 46.881530955433846, 50.26592954993248, 52.766484171152115, 53.356318920850754, 53.94336462020874, 53.23834665119648, 53.85284207761288, 53.32796484231949, 54.73530292510986, 49.44419324398041, 49.01671998202801, 48.5777485370636, 45.460278019309044, 44.09758374094963, 47.700622603297234, 43.098355159163475, 44.73897412419319, 43.933424949645996, 41.658384427428246, 41.188197657465935, 40.866430923342705, 42.48862847685814, 43.57364125549793, 40.53598925471306, 42.856475338339806, 41.62247635424137, 44.46939378976822, 51.43307492136955, 51.33332647383213, 49.770527333021164, 47.40876026451588, 43.249716237187386, 44.98837374150753, 42.629300728440285, 42.298505678772926, 41.67090095579624, 51.24048225581646, 54.63186487555504, 47.765040546655655, 47.3623913526535, 44.417252987623215, 51.05894699692726, 44.42428261041641, 47.96095423400402, 52.53651671111584, 43.588692247867584, 43.464815095067024, 42.237062975764275, 44.35338221490383, 43.427900075912476, 46.319658905267715, 47.640186846256256, 49.67189222574234, 51.00275561213493, 47.64033503830433, 44.72189024090767, 45.51444411277771, 44.483582228422165, 38.69868144392967, 41.42915792763233, 42.99897149205208, 40.96494063735008, 39.83836188912392, 42.430613189935684, 42.95770950615406, 48.251425847411156, 48.40928457677364, 43.177444115281105, 43.95021624863148, 42.11678422987461, 41.899466291069984, 46.71746715903282, 48.47857005894184, 52.2506732493639, 53.08372154831886, 55.302046313881874, 55.33641166985035, 54.64402802288532, 55.24116978049278, 55.39210148155689, 57.69986964762211, 55.2373281866312, 55.85354492068291, 56.534225195646286, 56.75678305327892, 57.56947964429855, 54.173183888196945, 58.57407733798027, 52.61577665805817, 57.54299886524677, 61.00915387272835, 60.38326285779476, 56.290046498179436, 56.374854147434235, 47.747588083148, 52.11974747478962, 45.84427401423454, 51.94360412657261, 49.13888342678547, 52.45024234056473, 51.54484212398529, 57.93296433985233, 59.50809381902218, 74.57981407642365, 63.79588633775711, 71.62359550595284, 16.147406436502934, 0.22892340668477118, 12.318660635501146, 3.7816831888630986, 0.5594566266518086, 48.53894881904125, 85.12689292430878, 70.9278604388237, 78.45878273248672, 74.00281503796577, 72.58560508489609, 54.617729634046555, 42.4538641422987, 61.69801890850067, 76.26829907298088, 60.6481808423996, 1.3147835992276669, 0.2085829942370765, 0.18027866928605363, 0.085653860878665, 0.16237183328485116, 0.15637798147508875], [0.06821371702244505, 0.08285951902507804, 0.07041914243018255, 0.014885999025864294, 0.0829179779975675, 0.12089995318092406, 0.3148569830227643, 0.05618756273179315, 9.895868841558695, 67.77871862053871, 47.48431921005249, 26.2850933521986, 16.262392066419125, 35.64055614173412, 60.949056297540665, 62.52982087433338, 46.01782590150833, 64.52543199062347, 50.95186874270439, 64.6918934583664, 8.057916965335608, 0.24085862562060356, 0.6184719130396843, 2.4027457321062684, 0.1929645854397677, 2.6277915062382817, 65.6144231557846, 61.57954886555672, 61.9153368473053, 49.544177278876305, 48.17614048719406, 45.925046280026436, 50.53981505334377, 50.52602179348469, 53.786159455776215, 53.15891191363335, 54.47425313293934, 47.64505818486214, 42.464708760380745, 38.028139024972916, 39.83746513724327, 40.968398451805115, 38.882458582520485, 38.82642678916454, 41.16351418197155, 39.09157656133175, 39.90902669727802, 39.715658873319626, 39.51551981270313, 38.37892860174179, 41.09446428716183, 41.502957567572594, 44.9266916513443, 47.2802397608757, 47.981024757027626, 46.56578689813614, 47.72264242172241, 44.02807407081127, 42.769505605101585, 44.14359547197819, 40.15204265713692, 40.16039840877056, 41.41064912080765, 37.89212912321091, 37.63931728899479, 37.649390548467636, 37.7326250821352, 39.00423064827919, 40.24285018444061, 39.780692383646965, 38.90174254775047, 38.796681985259056, 38.473361134529114, 38.6561693251133, 40.814096331596375, 44.981226325035095, 49.28855359554291, 48.683656454086304, 47.34338857233524, 48.63356754183769, 41.92369759082794, 41.17818519473076, 40.277272537350655, 40.313598588109016, 45.37225194275379, 51.3429019600153, 47.89981551468372, 49.80015054345131, 42.42411933839321, 48.87604393064976, 42.05635227262974, 47.02724553644657, 47.96932138502598, 42.65520393848419, 42.98335812985897, 41.7617616802454, 40.767807215452194, 41.40625275671482, 40.38804419338703, 43.530802354216576, 46.75374001264572, 41.70860253274441, 39.671942219138145, 41.2195535749197, 40.391999781131744, 38.69040548801422, 35.98128005862236, 36.71943224966526, 38.698236867785454, 36.49062752723694, 36.581803634762764, 36.61363832652569, 36.03568933904171, 34.16588567197323, 41.05539858341217, 40.39604276418686, 38.632473796606064, 40.26466481387615, 39.7351898252964, 40.586477145552635, 43.25943611562252, 45.82973599433899, 45.83175748586655, 46.59141272306442, 45.92851169407368, 46.49536907672882, 45.40370285511017, 46.93801872432232, 45.917629078030586, 47.349092066287994, 48.62239234149456, 46.976689249277115, 45.13521306216717, 44.08775746822357, 48.082673102617264, 51.322937831282616, 54.27362009882927, 54.27920199930668, 54.29862655699253, 54.52339969575405, 51.245547384023666, 53.09591889381409, 44.98246505856514, 47.13972710072994, 43.41909974813461, 44.92563150823116, 45.13975001871586, 46.03943154215813, 44.31754633784294, 48.97101603448391, 54.36377786099911, 64.22866031527519, 60.233018919825554, 68.79811272025108, 12.46440276503563, 0.2341869703377597, 5.347797889262438, 0.36149796622339636, 0.4183273308444768, 43.46453011035919, 71.4825850725174, 55.158060640096664, 63.20819467306137, 61.92226007580757, 61.03074811398983, 36.635468155145645, 19.835631027817726, 30.848410986363888, 62.15383104979992, 32.34213173389435, 0.31479416764341295, 0.05541497215745039, 0.0013329908074410923, 0.018405024893581867, 0.12305696829571389, 0.11027961212676018, 0.0770763035689015, 0.07229581126011908, 0.0381977063807426, 0.06270634301472455, 0.12268544916878454, 0.11285676446277648, 0.3928665892453864, 0.07290307359653525, 13.06886387988925, 78.91551822423935, 57.30602838099003, 35.35141445696354, 26.7330190166831, 51.54336780309677, 64.62540462613106, 68.93406182527542, 53.5314667224884, 72.25186139345169, 55.31717710196972, 73.36204782128334, 7.700039818882942, 0.27054052508901805, 0.5565606476739049, 4.227660745382309, 0.211430199269671, 3.740601218305528, 67.19026699662209, 63.394665867090225, 64.1814136505127, 52.58731238543987, 50.44693283736706, 47.960999831557274, 51.56713932752609, 52.161385640501976, 55.18551416695118, 56.07564300298691, 55.6407031416893, 49.68529790639877, 44.712573140859604, 40.58189459145069, 41.391258761286736, 42.83072032034397, 40.07693588733673, 39.651780501008034, 42.59357884526253, 40.24080969393253, 43.77225659787655, 42.45211623609066, 42.77348779141903, 40.95858737826347, 42.52027317881584, 45.01433774828911, 48.029293566942215, 48.49279269576073, 50.567181184887886, 49.7112201154232, 49.802924394607544, 45.60733772814274, 45.766765773296356, 45.65903775393963, 41.48453235626221, 40.57103857398033, 42.34662249684334, 39.89613398909569, 38.944972828030586, 40.60970149934292, 41.64982728660107, 41.50014951825142, 41.157799288630486, 40.302989557385445, 40.152316242456436, 38.707310780882835, 41.273005306720734, 39.88759584724903, 42.46719002723694, 47.09005616605282, 51.97470545768738, 50.587418898940086, 49.297555312514305, 49.656126871705055, 42.04075790941715, 41.279951333999634, 41.07018359005451, 39.43584568798542, 46.20758391916752, 52.75297209620476, 48.49060021340847, 48.95813472568989, 42.679131254553795, 50.95322906970978, 44.02806647121906, 48.82552944123745, 48.196552991867065, 41.03161185979843, 43.92620533704758, 43.30037511885166, 40.68702735006809, 41.996220499277115, 41.01937651634216, 45.80798976123333, 49.6831776201725, 44.47824351489544, 43.28952670097351, 42.47472122311592, 43.36468666791916, 40.98547473549843, 37.608041167259216, 39.02197189629078, 38.893751576542854, 40.41388660669327, 37.32266128063202, 38.6101233959198, 36.53719402849674, 35.60618318617344, 42.28104181587696, 41.01046219468117, 39.89169202744961, 41.609617844223976, 42.0226176828146, 42.16768629848957, 46.01263538002968, 46.11326918005943, 48.47931481897831, 48.59984055161476, 48.19424271583557, 48.57497848570347, 46.56126134097576, 49.033971056342125, 48.07359158992767, 48.91620397567749, 50.36348931491375, 48.26855152845383, 47.563411965966225, 47.062218859791756, 51.152934953570366, 53.19286689162254, 54.405742809176445, 56.96315757930279, 57.37396873533726, 56.82611033320427, 53.037280440330505, 54.87267695367336, 48.07522930204868, 49.500867202878, 45.976343527436256, 48.03639158606529, 46.60248152911663, 48.58353182673454, 46.90734677016735, 52.498362958431244, 55.613086223602295, 67.4838088452816, 63.1276123970747, 73.14501866698265, 18.436941280961037, 0.2717236866010353, 2.0817109337076545, 0.7261387200560421, 0.501380602363497, 46.83579660952091, 79.00331631302834, 61.493931859731674, 70.1341362297535, 68.42773139476776, 65.77155992388725, 45.337620601058006, 23.50561659783125, 37.05450966954231, 68.7341621518135, 40.26657611131668, 0.6082419713493437, 0.0788735700189136, 0.03631499275797978, 0.05242264014668763, 0.012205274415464373, 0.014008296220708871, 0.1462374537368305, 0.2504096506163478, 0.1650143094593659, 0.16474767064210027, 0.33230757631827146, 0.27958510851021856, 0.44887335738167167, 0.16532697627553716, 15.1934096775949, 91.73591628670692, 61.826520413160324, 43.54254372417927, 24.490284360945225, 53.14518325030804, 71.88800051808357, 76.62079095840454, 55.99973827600479, 80.22283047437668, 58.394901752471924, 81.21080785989761, 10.836154986172915, 0.38496987079270184, 3.190832706168294, 8.871310818940401, 0.3866506274789572, 3.885446833446622, 72.95185223221779, 63.965197652578354, 68.52189794182777, 52.727904841303825, 51.63363575935364, 49.620298594236374, 55.600934475660324, 55.43110638856888, 59.62290085852146, 57.53773994743824, 60.023228377103806, 51.71096161007881, 47.488027811050415, 44.968010634183884, 43.358663991093636, 45.273331850767136, 42.108367681503296, 43.271933645009995, 46.10731489956379, 42.33322061598301, 43.961258456110954, 43.675198405981064, 44.05461564660072, 42.67579883337021, 45.76320916414261, 47.0000883936882, 49.42414551973343, 50.631545931100845, 53.44864256680012, 50.9427872300148, 51.43031246960163, 48.001330867409706, 46.31998188793659, 49.63530018925667, 43.57160836458206, 43.308411687612534, 45.735371857881546, 41.77503436803818, 41.80792540311813, 42.635509595274925, 44.232278913259506, 43.65402214229107, 43.9783651381731, 43.668742552399635, 42.34425902366638, 42.543455734848976, 44.02515962719917, 42.9826133698225, 44.364584013819695, 50.20977236330509, 54.91574004292488, 53.49011354148388, 50.929309353232384, 50.39550259709358, 42.27561190724373, 41.80739343166351, 40.66481754183769, 41.79535187780857, 44.79620285332203, 54.1859246045351, 48.80987428128719, 52.905986085534096, 46.23077027499676, 52.05032899975777, 44.74905118346214, 49.66170497238636, 50.22014960646629, 43.133195489645004, 44.11757826805115, 46.08161307871342, 41.86587229371071, 43.851444348692894, 42.83405274152756, 46.44999951124191, 52.122958302497864, 49.000263065099716, 46.14206783473492, 47.440366968512535, 43.85816238820553, 43.74277018010616, 39.16947618126869, 40.89208334684372, 42.05021180212498, 42.508923187851906, 39.80622701346874, 41.32132351398468, 39.4835939258337, 38.5874880105257, 43.82556013762951, 43.8022293895483, 42.152365520596504, 44.5457810908556, 43.155241906642914, 43.777029141783714, 48.71936313807964, 48.44993479549885, 50.72431415319443, 51.901943162083626, 49.7488608956337, 52.54456087946892, 51.46362908184528, 52.22579598426819, 51.26843735575676, 50.91379478573799, 53.65518048405647, 51.73802375793457, 52.31351427733898, 49.945059567689896, 52.68685944378376, 54.98751059174538, 57.72141449153423, 58.85985240340233, 59.986149966716766, 59.81732502579689, 56.41488119959831, 58.16779173910618, 51.05258993804455, 52.05670885741711, 48.7760104984045, 50.721756890416145, 48.87270390987396, 50.96857264637947, 47.924282401800156, 56.02390117943287, 58.48223626613617, 70.40407374501228, 65.92141628265381, 74.35535252094269, 24.100818559527397, 0.1918860964360647, 10.463637225329876, 2.851976864039898, 0.7094972161576152, 53.31313043832779, 85.56483462452888, 64.76052537560463, 78.3205309510231, 72.17785656452179, 75.81888198852539, 51.41617342829704, 29.479851722717285, 47.30221778154373, 78.26549470424652, 50.67883059382439, 1.0345429368317127, 0.22376439679646865, 0.15028512716526166, 0.07470413984265178, 0.2423927339259535, 0.1104181339906063], [0.012516583101387369, 0.02293400335474871, 0.016771565278759226, 0.019600396590249147, 0.09944301666109823, 0.14341892529046163, 0.1347438126686029, 0.12529098865343258, 4.309623297303915, 61.574555933475494, 46.71946965157986, 30.162025317549706, 24.907722361385822, 39.93666261434555, 64.08122062683105, 61.89524732530117, 41.90781444311142, 59.737510308623314, 52.555405497550964, 64.32022020220757, 19.83712624758482, 0.19659389537991956, 0.17106049752328545, 1.4015446999110281, 0.3367143007926643, 0.1440012440434657, 45.04293881356716, 67.51284688711166, 60.70959314703941, 56.997283548116684, 46.51935338973999, 44.9605668336153, 48.26944828033447, 48.81001867353916, 51.57815493643284, 53.30812230706215, 52.086286470294, 52.93767258524895, 50.26898078620434, 45.19205041229725, 41.4944726228714, 39.925046637654305, 40.14498643577099, 40.1130947470665, 40.29430702328682, 40.134426802396774, 39.761860594153404, 40.28990685939789, 41.50420010089874, 40.745221227407455, 43.04921619594097, 45.727525278925896, 46.17422550916672, 48.07046435773373, 47.201633378863335, 46.90991163253784, 47.01683409512043, 42.243933007121086, 41.622316762804985, 42.34095320105553, 40.46488367021084, 40.16002602875233, 37.503497377038, 37.41946488618851, 39.48346473276615, 36.233917102217674, 38.09480644762516, 38.127876073122025, 38.1871072947979, 38.74258428812027, 37.34765633940697, 38.63839387893677, 38.7531591206789, 39.335409477353096, 40.17645634710789, 46.90486550331116, 48.66936922073364, 49.21477295458317, 46.62656843662262, 41.43533639609814, 43.993024751544, 40.51360845565796, 41.07301823794842, 38.198278695344925, 43.02072152495384, 44.041335359215736, 46.53615988790989, 49.3266237527132, 44.577703177928925, 49.56330545246601, 43.64032007753849, 47.705725729465485, 47.08389289677143, 39.51992757618427, 41.08811482787132, 39.42080229520798, 39.61197003722191, 41.05865880846977, 40.91182328760624, 46.60961374640465, 42.95411489903927, 41.87466882169247, 44.86662447452545, 43.22877176105976, 41.06527045369148, 37.57760480046272, 36.68561786413193, 35.3741068392992, 35.70288799703121, 37.84106746315956, 35.719268918037415, 35.79992339015007, 37.19347961246967, 36.14264219999313, 34.362331330776215, 39.875482097268105, 39.89923842251301, 39.705239832401276, 39.67264138162136, 41.12772390246391, 42.878255769610405, 43.5731852799654, 46.33581563830376, 48.97638514637947, 49.15438659489155, 48.866445645689964, 46.88244670629501, 43.15442495048046, 43.71268719434738, 42.28536978363991, 40.708150416612625, 43.25255088508129, 41.8016367405653, 40.32230392098427, 45.16795210540295, 54.92291785776615, 52.164668664336205, 53.65752875804901, 51.77685387432575, 52.91047364473343, 54.38438035547733, 50.95113918185234, 50.112695172429085, 49.39864128828049, 43.75370979309082, 46.73567958176136, 46.792801916599274, 47.939390391111374, 47.237366661429405, 47.92923353612423, 50.82200311124325, 62.7517631649971, 57.48013123869896, 68.60786452889442, 13.24546605348587, 0.42673595307860523, 1.3338096532970667, 0.4122505959821865, 0.746912145987153, 45.43745644390583, 67.07836300134659, 54.604274556040764, 63.5871559381485, 58.39210130274296, 58.42807397246361, 45.66851444542408, 32.92479246854782, 37.01607093214989, 65.14659985899925, 19.25522167235613, 0.3049353591632098, 0.0833187451644335, 0.028246216643310618, 0.05101284528791439, 0.05517865007277578, 0.0740477473300416, 0.04791311337612569, 0.03592017019400373, 0.07193371740868315, 0.06842883594799787, 0.030569825357815716, 0.08488078048685566, 0.26472713390830904, 0.013755372292507673, 5.868972698226571, 73.15508052706718, 52.679335847496986, 35.833524987101555, 24.657956063747406, 47.9489316791296, 70.65888047218323, 68.0633157491684, 47.91407994925976, 68.03251460194588, 58.37590277194977, 71.75471886992455, 21.505726911127567, 0.11430963728344068, 0.13226833456428722, 3.7390734627842903, 0.7858115492854267, 0.2793372015003115, 48.35978463292122, 70.25207430124283, 61.79740637540817, 59.30330000817776, 48.71682487428188, 46.876959800720215, 49.26679976284504, 51.63607902824879, 53.57301369309425, 55.34627974033356, 54.34119947254658, 55.1947932690382, 53.032367303967476, 45.58059096336365, 42.66849182546139, 41.55598372220993, 42.52521671354771, 42.393732368946075, 43.16194474697113, 41.668244898319244, 41.332175731658936, 43.918776735663414, 41.46776385605335, 43.35993692278862, 46.44022263586521, 46.10044866800308, 48.43510419130325, 49.206504598259926, 49.23257119953632, 49.14205625653267, 47.91585065424442, 45.64221605658531, 44.282048642635345, 43.43005836009979, 42.70790331065655, 40.2948921918869, 40.22836536169052, 39.3477588146925, 40.679397359490395, 38.34457464516163, 39.5091437548399, 39.78742182254791, 39.47153717279434, 41.26690283417702, 39.67650197446346, 40.66520892083645, 41.37592278420925, 42.819446325302124, 44.38101053237915, 48.98826330900192, 51.623402908444405, 53.10790345072746, 50.70775084197521, 44.757026955485344, 44.621754214167595, 39.86788250505924, 40.073664262890816, 38.1962838023901, 43.16248431801796, 44.9159762263298, 48.06164503097534, 49.54740710556507, 46.588285490870476, 49.72429521381855, 45.375204384326935, 48.332414701581, 46.46771416068077, 41.13346539437771, 40.554619655013084, 41.41171306371689, 39.636132940649986, 42.523430809378624, 40.979151874780655, 49.002045169472694, 45.771842300891876, 42.58067473769188, 47.001042142510414, 45.57826168835163, 41.753679513931274, 39.12511356174946, 38.42454515397549, 37.25174568593502, 37.44146190583706, 39.411770179867744, 38.24214354157448, 38.016895428299904, 38.560365065932274, 37.68010050058365, 35.92535465955734, 41.95445314049721, 41.44819490611553, 42.05822937190533, 40.36075405776501, 43.46335597336292, 44.71202977001667, 45.68767301738262, 49.10369731485844, 50.77407628297806, 50.578181594610214, 51.85096889734268, 49.35087785124779, 45.692665949463844, 45.425061509013176, 45.369820073246956, 44.02399308979511, 45.50158180296421, 42.70138666033745, 43.837647289037704, 46.84090733528137, 55.786125138401985, 54.9702937155962, 54.957891181111336, 54.57522511482239, 54.91805411875248, 56.11158907413483, 54.3943852186203, 51.46087042987347, 50.27471087872982, 46.40028677880764, 49.77849170565605, 49.75041501224041, 50.033537819981575, 49.48733612895012, 51.30135498940945, 53.956291526556015, 65.92568725347519, 58.93603831529617, 71.99760183691978, 18.392949141561985, 0.3867565467953682, 1.8886536243371665, 0.26836953533347696, 1.1375493532977998, 50.830214470624924, 74.31007415056229, 57.91757516562939, 66.27167388796806, 64.17801663279533, 65.6971675157547, 51.44439831376076, 32.58407235145569, 42.904934138059616, 73.65743637084961, 26.676818132400513, 0.38847574673127383, 0.08938382830820046, 0.050214876973768696, 0.08860910034854896, 0.08322389869135804, 0.1295838231453672, 0.16938192275119945, 0.18010629806667566, 0.1388745175790973, 0.12500874989200383, 0.21177851886022836, 0.20856089307926595, 0.32751894264947623, 0.16696173464879394, 6.308192554861307, 85.48569247126579, 62.253283113241196, 45.80072075128555, 30.754058249294758, 57.887123599648476, 76.90797194838524, 75.44103026390076, 54.284267127513885, 76.5744486451149, 60.05567103624344, 78.37442725896835, 25.260113552212715, 0.2186007855925709, 2.682601665146649, 7.201445298269391, 0.8596658706665039, 0.3321893373504281, 50.628004521131516, 69.95597898960114, 65.60501486063004, 62.44728170335293, 52.429993227124214, 49.08884011209011, 53.25668066740036, 53.451572209596634, 55.96033439040184, 57.62747973203659, 55.789434760808945, 58.12498323619366, 55.942372754216194, 50.12770056724548, 45.344110652804375, 43.343244418501854, 44.82981584966183, 44.0406209975481, 45.849293544888496, 44.829736053943634, 42.73577481508255, 45.371970757842064, 44.040681794285774, 45.06092704832554, 50.60995548963547, 49.8979876935482, 50.7191464304924, 53.05368036031723, 50.58921620249748, 53.00085939466953, 50.77665254473686, 46.517024114727974, 48.16239282488823, 46.23982518911362, 44.32941310107708, 42.70163744688034, 42.6998857408762, 41.47227041423321, 43.69096755981445, 40.83432264626026, 42.0744165033102, 42.25027486681938, 43.859161734580994, 43.411135375499725, 40.30587740242481, 43.57954613864422, 45.03915421664715, 44.985907673835754, 46.80922083556652, 53.13759885728359, 55.14794938266277, 56.35227955877781, 55.23247204720974, 47.833015099167824, 44.61308307945728, 39.48231719434261, 40.36429926753044, 38.737538158893585, 44.72917824983597, 45.43892316520214, 47.305394411087036, 52.62388922274113, 49.46268305182457, 52.18770682811737, 46.833072155714035, 50.33243738114834, 47.39897578954697, 40.81792272627354, 43.06316904723644, 41.496706902980804, 39.83261659741402, 43.73764805495739, 41.29337601363659, 48.49257230758667, 48.836613446474075, 49.17095750570297, 51.8418949842453, 48.34113523364067, 44.920942559838295, 40.701831355690956, 41.46478861570358, 39.365910440683365, 40.022762194275856, 42.19282574951649, 41.18307553231716, 40.674742609262466, 40.632139295339584, 39.2674957215786, 37.82985046505928, 44.21536222100258, 45.02128377556801, 43.265553787350655, 43.812960013747215, 45.46191953122616, 46.58496826887131, 48.972642347216606, 52.25612215697765, 52.42873169481754, 53.98253671824932, 54.167465195059776, 51.82964064180851, 49.01112288236618, 47.80085742473602, 47.69471392035484, 45.34479081630707, 48.26208047568798, 45.97670830786228, 45.40987752377987, 48.72090205550194, 60.68365193903446, 58.56711611151695, 56.75311245024204, 57.47720539569855, 56.90744496881962, 60.794214606285095, 58.1942193210125, 55.786820501089096, 54.29612249135971, 49.63324449956417, 51.82214364409447, 52.869660034775734, 53.47021780908108, 52.42820352315903, 53.23425807058811, 56.233475133776665, 69.03442963957787, 63.37651804089546, 76.02361500263214, 25.709416642785072, 0.2614497800823301, 5.826474828645587, 1.4629030949436128, 1.652311293873936, 53.977463990449905, 80.92624112963676, 64.5929391682148, 75.47386050224304, 69.51644897460938, 73.39816108345985, 62.98610419034958, 44.07538913190365, 52.865183874964714, 83.72612088918686, 35.363372415304184, 0.6390200229361653, 0.1607912516919896, 0.1573241307050921, 0.10844613629160449, 0.19701141281984746, 0.18023218115558848], [0.04727006467874162, 0.048718069010647014, 0.08328421303303912, 0.018425689995638095, 0.1357256295159459, 0.035394781589275226, 0.17173705418827012, 0.02627396104799118, 2.3804029310122132, 54.534259513020515, 57.566033229231834, 34.63739097118378, 30.14141522347927, 42.03878581523895, 55.78552097082138, 58.082585111260414, 51.09795190393925, 58.824328109622, 54.10460516810417, 57.75768354535103, 37.936932519078255, 0.2130257128737867, 0.5339900369290262, 2.614975506439805, 0.6543763051740825, 0.2888683072524145, 20.075527355074883, 71.33486419916153, 58.73339518904686, 58.61978128552437, 45.295173078775406, 46.816375851631165, 44.13308523595333, 50.70176236331463, 50.097036212682724, 52.53264471888542, 53.032545894384384, 54.921625927090645, 52.62008182704449, 52.32142925262451, 43.33206921815872, 42.750803008675575, 38.5669919103384, 39.36030954122543, 42.40513555705547, 42.59942673146725, 40.52039489150047, 41.48198649287224, 40.8784306794405, 46.42114005982876, 46.50711044669151, 46.349114924669266, 48.62699009478092, 51.47044591605663, 47.600790560245514, 48.26309882104397, 45.132990181446075, 42.75947034358978, 43.646859526634216, 42.127644047141075, 40.64673811197281, 40.55765189230442, 40.933052748441696, 43.49033832550049, 42.92338974773884, 43.946519047021866, 46.00663170218468, 40.39898760616779, 38.391718715429306, 38.65664429962635, 41.02816924452782, 38.67595486342907, 39.91998910903931, 39.372548684477806, 43.802069798111916, 44.25537407398224, 50.440233796834946, 49.42143626511097, 43.841944858431816, 49.53721225261688, 40.21304838359356, 39.31386463344097, 38.43632832169533, 38.63661177456379, 39.8603019118309, 44.89749401807785, 40.7207353413105, 51.6616440564394, 47.17696510255337, 53.245760053396225, 42.43198111653328, 45.635657608509064, 39.9698918312788, 42.11579628288746, 38.811592385172844, 39.98820684850216, 39.75675366818905, 41.11075401306152, 40.1673786342144, 46.69108137488365, 39.33476731181145, 47.18562863767147, 46.96118988096714, 48.033397346735, 40.871944427490234, 39.97890114784241, 38.12222197651863, 37.753071784973145, 37.751802653074265, 37.2699961066246, 36.49221584200859, 38.185579776763916, 34.99291509389877, 36.1752824485302, 35.78589454293251, 37.0456637442112, 36.920737847685814, 40.85847795009613, 39.39083330333233, 41.69466868042946, 42.42513008415699, 43.78867171704769, 44.851664677262306, 46.423564329743385, 49.96563546359539, 51.066763177514076, 48.01767759025097, 48.781071826815605, 39.78232629597187, 41.87514379620552, 40.970575734972954, 40.63601128757, 39.39100429415703, 40.40287099778652, 39.555147886276245, 46.62596806883812, 53.07467423379421, 56.01366072893143, 51.27772405743599, 53.94310623407364, 53.30509386956692, 49.63067963719368, 47.852971628308296, 48.99471916258335, 47.836556509137154, 47.507304176688194, 44.43569339811802, 46.33416272699833, 45.09614355862141, 47.480747401714325, 44.98645104467869, 56.4115259796381, 57.89950333535671, 63.205557614564896, 7.555449977517128, 0.9013414999935776, 0.5809030320961028, 0.5559003143571317, 2.2111474256962538, 56.73238456249237, 63.05827371776104, 62.839644849300385, 65.88405668735504, 64.82288762927055, 59.21899393200874, 35.173226818442345, 20.199679993093014, 41.22954323887825, 63.22208292782307, 12.19750888645649, 0.4259360663127154, 0.009190565724566113, 0.07213716977275908, 0.027188364911125973, 0.1330723476712592, 0.06801925948821008, 0.027709688401955646, 0.023634015597053804, 0.09664700497523881, 0.05282875077682547, 0.07084804441547021, 0.045967606638441794, 0.13209459779318422, 0.023264930714503862, 3.029065174050629, 66.78969249129295, 61.44333377480507, 39.549429193139076, 20.71425788104534, 43.73180016875267, 64.53769773244858, 64.45679247379303, 53.06485936045647, 64.04214352369308, 59.78656567633152, 64.15219321846962, 42.98745810985565, 0.22342679381836206, 0.30588118184823543, 2.602871968410909, 1.4433469693176448, 0.16544122248888016, 22.160063199698925, 73.72121214866638, 60.842236429452896, 61.67501114308834, 47.16023460030556, 47.17247374355793, 47.48837359249592, 51.55176155269146, 53.035418540239334, 55.43451480567455, 56.25209793448448, 57.84214161336422, 53.789222091436386, 54.71282713115215, 44.085640981793404, 44.50086370110512, 41.91621199250221, 41.905238181352615, 43.5804732888937, 43.709183782339096, 41.44184544682503, 43.34102153778076, 42.96392597258091, 46.62227846682072, 47.72915527224541, 49.18725863099098, 49.313951432704926, 55.418327674269676, 49.72807601094246, 50.441784113645554, 46.85846999287605, 45.24384543299675, 44.28253881633282, 45.01717999577522, 41.48826375603676, 42.492888048291206, 42.11607366800308, 44.05775047838688, 43.108173832297325, 44.44540947675705, 46.6693389415741, 41.7243716865778, 40.44747680425644, 41.11201174557209, 42.123004496097565, 40.30541002750397, 42.457230761647224, 41.581404358148575, 45.01568667590618, 47.28728458285332, 52.73804269731045, 52.389046624302864, 46.53148993849754, 48.49883817136288, 40.669871270656586, 39.116913601756096, 38.83414797484875, 37.555843368172646, 40.52691154181957, 44.52583596110344, 40.76501436531544, 53.1079338490963, 50.1602990180254, 54.50468949973583, 43.42412307858467, 45.753645077347755, 40.257395803928375, 41.1504390835762, 39.95694972574711, 40.489654541015625, 38.70466612279415, 41.38345777988434, 41.65934577584267, 48.1840630620718, 40.996714532375336, 49.09418262541294, 49.19551178812981, 49.642003029584885, 42.60647535324097, 40.702644512057304, 40.319385677576065, 40.52380710840225, 38.508247062563896, 37.97714576125145, 38.905173763632774, 39.282808899879456, 37.73467317223549, 37.893972024321556, 36.702371165156364, 40.05317956209183, 39.99950744211674, 42.67012573778629, 41.19929686188698, 43.68177965283394, 42.88160718977451, 45.50349310040474, 46.68222784996033, 48.90547715127468, 51.28926403820515, 52.94660210609436, 50.135075971484184, 52.53745146095753, 42.840406000614166, 44.807115867733955, 41.3570149987936, 43.0028510838747, 42.38550201058388, 43.142113611102104, 41.95087753236294, 49.83586102724075, 55.40014944970608, 56.85796022415161, 53.81031855940819, 56.614864468574524, 55.83156310021877, 52.16708533465862, 51.84999614953995, 52.45181165635586, 50.03486014902592, 50.2692923694849, 46.80574782192707, 49.47689808905125, 48.6838236451149, 51.817321702837944, 47.54596710205078, 60.51242172718048, 60.63247248530388, 68.5789404809475, 15.322344359010458, 0.8595052699092776, 0.36742826050613075, 0.3531339322216809, 2.583333416841924, 61.68341629207134, 71.19880869984627, 66.93960204720497, 71.46666392683983, 67.99252554774284, 65.39563089609146, 44.91361275315285, 23.665967993438244, 47.7598462253809, 71.48080676794052, 18.545303866267204, 0.599998194957152, 0.11683522519888356, 0.1129587875038851, 0.032647944608470425, 0.06595041151740588, 0.08530214967322536, 0.17293890297878534, 0.15112560940906405, 0.13528360635973513, 0.15162903786404058, 0.30105511425063014, 0.16451569012133405, 0.21774022083263844, 0.1500772516010329, 3.3620522310957313, 77.22887992858887, 72.70238041877747, 51.829902827739716, 41.43377088010311, 60.70459641516209, 67.90512263774872, 69.28054243326187, 61.27768166363239, 73.8283284008503, 64.26839098334312, 69.05451536178589, 48.00840228796005, 0.3567150916205719, 1.7683904338628054, 8.285858184099197, 2.1384829748421907, 0.32043413375504315, 25.134974867105484, 76.353300511837, 61.92874252796173, 65.76772972941399, 49.864777475595474, 49.523658379912376, 49.52574826776981, 54.0180192142725, 56.008135825395584, 57.78551705181599, 57.775645181536674, 60.31257905066013, 57.724811509251595, 57.9631195217371, 47.911188304424286, 48.194675892591476, 44.14994493126869, 45.24656988680363, 46.45883023738861, 46.042019203305244, 44.89687465131283, 45.58656804263592, 45.55124133825302, 50.69752559065819, 51.87652252614498, 51.81954838335514, 52.579108625650406, 57.18032732605934, 51.13289102911949, 53.12554590404034, 50.83152160048485, 47.1873689442873, 47.30627976357937, 45.81992872059345, 44.825689271092415, 44.62333492934704, 45.14423377811909, 47.30704352259636, 46.416918486356735, 46.65422335267067, 49.29392270743847, 43.569921255111694, 42.085770294070244, 43.90046551823616, 44.540632367134094, 41.6680359095335, 44.563906118273735, 44.292973056435585, 46.94693684577942, 50.34963145852089, 54.81471486389637, 55.33766560256481, 49.2618790268898, 52.63971537351608, 42.52261005342007, 37.16161452233791, 39.603580087423325, 37.02709414064884, 40.11684514582157, 46.62730559706688, 41.660595908761024, 55.54894186556339, 52.47670032083988, 56.17821469902992, 44.49158079922199, 47.92012922465801, 40.13494737446308, 42.55996584892273, 39.665904343128204, 41.525991931557655, 40.9359709918499, 41.722338795661926, 42.43492975831032, 51.34100206196308, 46.64728492498398, 51.64446517825127, 52.83110350370407, 53.027328774333, 46.35367847979069, 45.13674817979336, 41.65257453918457, 41.58913314342499, 42.055945694446564, 40.41355982422829, 40.01232035458088, 41.74890697002411, 38.95816192030907, 40.34563846886158, 38.508760035037994, 42.170855328440666, 40.87032191455364, 43.826456889510155, 43.349821865558624, 47.09222964942455, 45.79264998435974, 47.51700505614281, 48.13180446624756, 50.882746651768684, 53.60271289944649, 55.212462320923805, 53.25042240321636, 55.55791698396206, 44.67133015394211, 47.42254592478275, 43.34746979176998, 46.37885592877865, 44.356995820999146, 45.62224052846432, 44.35815095901489, 51.958959102630615, 56.80705055594444, 60.36972418427467, 55.294997692108154, 59.35723431408405, 57.46905103325844, 54.44374457001686, 53.30861248075962, 54.68893401324749, 52.982502579689026, 51.88368134200573, 48.8705912232399, 53.185708075761795, 51.075620502233505, 53.29524099826813, 49.71860311925411, 63.92866641283035, 64.3642446398735, 76.63939476013184, 25.105097070336342, 0.6334638898260891, 4.42843864671886, 1.1842943262308836, 3.509674547240138, 69.0293151140213, 78.11579033732414, 73.1391441822052, 77.93967738747597, 73.0677080154419, 74.33420285582542, 52.132993564009666, 28.841233290731907, 57.42400445044041, 82.94888019561768, 25.79496145248413, 0.9304982854519039, 0.28219331230502576, 0.2284880925435573, 0.13033201190410182, 0.17687274579657242, 0.2064184908522293], [0.009810611554712523, 0.10090838724863715, 0.03648325990070589, 0.025342010958411265, 0.06844235787866637, 0.026348930950916838, 0.10707051362260245, 0.21711643086746335, 1.1256524291820824, 48.2403190433979, 57.733497843146324, 43.300591707229614, 44.13481794297695, 29.046188592910767, 46.46344318985939, 58.790597319602966, 60.803269520401955, 53.007155656814575, 59.724237620830536, 55.08112236857414, 52.970985397696495, 1.0243262350559235, 0.11129802427603863, 1.6151961917057633, 0.9400964516680688, 0.045030348337604664, 7.6377958338707685, 69.93726879358292, 60.46324096620083, 60.81369996070862, 44.81314234435558, 45.65605491399765, 42.72717587649822, 48.10178987681866, 49.15470577776432, 48.148667961359024, 52.81163714826107, 54.15194682776928, 52.80625283718109, 54.35151591897011, 49.80704337358475, 40.94529189169407, 39.708241671323776, 40.37028394639492, 39.14513848721981, 40.638948529958725, 39.655177518725395, 41.27493180334568, 41.561972200870514, 47.211683839559555, 47.58984334766865, 49.25103060901165, 49.19143460690975, 50.41109696030617, 49.108876436948776, 45.27880735695362, 43.06642547249794, 41.18567079305649, 43.84678199887276, 42.45867848396301, 38.51841911673546, 42.2533755004406, 42.17090852558613, 44.26088757812977, 42.73990899324417, 42.62520454823971, 39.054262563586235, 37.242333590984344, 36.11436031758785, 39.938475117087364, 41.93365305662155, 40.91103293001652, 42.460430189967155, 40.929279550909996, 42.42902107536793, 48.042946234345436, 52.01655641198158, 54.42833639681339, 50.00437058508396, 59.06466141343117, 48.61172251403332, 40.50804175436497, 37.112350165843964, 38.31152401864529, 38.63034971058369, 40.30056148767471, 40.43913245201111, 53.8131570070982, 52.45745435357094, 49.710809737443924, 39.59339663386345, 41.66740134358406, 39.84881512820721, 38.78258094191551, 40.569773241877556, 39.091667756438255, 38.2114601880312, 38.90529915690422, 43.618912026286125, 42.24630407989025, 50.94414755702019, 50.815285071730614, 46.82456061244011, 44.2716334015131, 40.00786319375038, 38.60153205692768, 38.6307030916214, 38.09208579361439, 37.627378329634666, 37.97067850828171, 35.09425565600395, 36.156424060463905, 38.174499571323395, 39.80710096657276, 34.969154968857765, 39.65091794729233, 38.14549572765827, 39.96863789856434, 40.18820911645889, 40.44681943953037, 43.933500945568085, 40.517575442790985, 44.8212169110775, 49.16666753590107, 49.74604904651642, 52.44676172733307, 48.44863146543503, 48.571117892861366, 48.55830118060112, 44.60853472352028, 39.41765606403351, 39.77648600935936, 40.730489417910576, 40.195276737213135, 40.60283526778221, 40.120295360684395, 44.300880432128906, 48.999438509345055, 51.96506157517433, 52.00690492987633, 51.41248382627964, 50.87390452623367, 49.871476516127586, 49.24730680882931, 46.79989993572235, 47.51194752752781, 44.43301074206829, 46.39062389731407, 47.13985249400139, 49.485299438238144, 50.51936075091362, 56.4817576110363, 53.98056082427502, 61.98903389275074, 12.203410919755697, 0.9294132655486465, 0.8162380603607744, 0.4975919087883085, 6.001649703830481, 66.92777708172798, 59.26564782857895, 62.719062119722366, 63.141398057341576, 64.60702881217003, 51.73692561686039, 39.41595375537872, 33.34433935582638, 38.30897435545921, 56.73371069133282, 5.834549870342016, 0.12710133916698396, 0.1242937648203224, 0.05299162250594236, 0.014911189373378875, 0.043574499504757114, 0.07706531978328712, 0.022279521872405894, 0.09818905426072888, 0.06281074092839845, 0.04548544071440119, 0.039275419840123504, 0.023917419530334882, 0.09243914639228024, 0.04164761325228028, 1.40186459524557, 56.92914180457592, 67.42683470249176, 47.31641761958599, 36.046712547540665, 44.49076384305954, 55.71682445704937, 65.90304046869278, 64.69402134418488, 59.1556741297245, 65.52485436201096, 61.496838703751564, 57.64971233904362, 1.1990168737247586, 0.08884846523869783, 3.0561902560293674, 3.084272174164653, 0.10244325996609405, 8.808290250599384, 72.44372069835663, 61.74171656370163, 63.005927726626396, 45.815779343247414, 48.00865687429905, 45.19936501979828, 50.05830109119415, 51.61874055862427, 51.6583838313818, 56.37166231870651, 57.12486170232296, 55.24180434644222, 57.75185465812683, 50.85921071469784, 44.16693761944771, 40.73268949985504, 41.47012732923031, 41.24769866466522, 43.799865916371346, 41.64694704115391, 41.54699720442295, 43.10539998114109, 49.48967680335045, 50.0092077255249, 50.246915370225906, 52.657365426421165, 50.55798187851906, 51.85507267713547, 49.130398482084274, 45.77381059527397, 44.67417620122433, 44.81213539838791, 43.11117947101593, 41.68846361339092, 42.46445797383785, 44.5846302062273, 45.74053198099136, 45.11096276342869, 44.51935350894928, 42.304832339286804, 40.391125828027725, 38.62517058849335, 40.44333502650261, 42.4229945987463, 42.07442410290241, 44.5844554156065, 41.52716986835003, 45.42955666780472, 47.7763107419014, 53.892652541399, 55.33625967800617, 50.728034153580666, 62.20701679587364, 48.10711719095707, 39.929849579930305, 36.43518850207329, 39.242067486047745, 38.368384167551994, 40.77391728758812, 42.27406919002533, 54.04759682714939, 53.58374431729317, 48.88745091855526, 39.34949912130833, 41.44432671368122, 39.34199072420597, 38.027451261878014, 40.28544209897518, 41.56982637941837, 38.41661497950554, 37.95068018138409, 44.8359677195549, 45.105232670903206, 53.02467651665211, 53.50492514669895, 48.60867887735367, 47.25676082074642, 42.598343789577484, 40.47101654112339, 39.978213384747505, 38.977472484111786, 38.955125883221626, 41.217756271362305, 36.13908179104328, 38.91730271279812, 39.8501830548048, 42.220837846398354, 37.23553955554962, 41.64964869618416, 39.723813235759735, 42.27346882224083, 41.55233971774578, 43.38735245168209, 44.683383107185364, 42.38418348133564, 45.88809326291084, 51.3105770945549, 54.263128861784935, 53.60636830329895, 51.22115269303322, 50.369891971349716, 48.90817500650883, 46.653721779584885, 42.68692843616009, 41.6877568513155, 42.62240789830685, 42.20821112394333, 42.35796108841896, 41.43194317817688, 46.565585508942604, 52.48836189508438, 52.32232980430126, 55.196263790130615, 53.75940129160881, 53.90183664858341, 52.649716436862946, 51.68722428381443, 48.52251090109348, 50.053619742393494, 48.399963676929474, 50.56943066418171, 49.0143109112978, 53.82381543517113, 54.39737185835838, 60.92098340392113, 56.125154346227646, 68.21599155664444, 16.7677079513669, 0.47618258104193956, 1.6944099473766983, 0.371282619307749, 7.115521933883429, 70.95553055405617, 65.44859245419502, 68.24309930205345, 69.76925700902939, 69.48837608098984, 60.12197747826576, 42.87035219371319, 25.569825433194637, 44.18547682464123, 65.26965245604515, 9.775373507291079, 0.28003957006148994, 0.23976327502168715, 0.025094337725022342, 0.04725792314275168, 0.03765766778087709, 0.06804300079238601, 0.1871303844382055, 0.17038888356182724, 0.2006877155508846, 0.12258329996257089, 0.14868343889247626, 0.10866704396903515, 0.23638984275748953, 0.2900414646137506, 1.805029611568898, 65.65744444727898, 76.25878438353539, 60.60642868280411, 56.22243292629719, 44.925889894366264, 60.161844938993454, 70.76104938983917, 72.58015617728233, 64.86444979906082, 70.62811732292175, 66.20626419782639, 65.18913477659225, 1.8664970132522285, 0.5081701255403459, 7.6532890275120735, 5.3257533721625805, 0.14315112872282043, 9.502515848726034, 75.06089106202126, 64.69351977109909, 66.3891027867794, 49.01318997144699, 51.64485275745392, 48.157905265688896, 52.18732304871082, 53.219032287597656, 52.58418135344982, 57.5631719827652, 59.143199399113655, 58.12171161174774, 58.70659902691841, 53.93924944102764, 46.10314652323723, 44.063852950930595, 44.29062478244305, 42.31465861201286, 47.09363177418709, 44.15942922234535, 44.47561025619507, 46.017058342695236, 53.10332089662552, 52.509169578552246, 56.11697718501091, 55.47575779259205, 52.28689290583134, 54.4430910050869, 51.1168596893549, 46.91028781235218, 46.80573262274265, 47.685780599713326, 45.01490771770477, 42.81129576265812, 46.043048948049545, 46.211319118738174, 48.73652681708336, 46.979862079024315, 48.58105055987835, 43.89695070683956, 41.18815965950489, 40.58770827949047, 44.56764131784439, 44.68477763235569, 43.27301658689976, 47.58920878171921, 43.703677877783775, 48.79597842693329, 53.01431827247143, 55.53822264075279, 57.76059798896313, 53.61866444349289, 61.237517818808556, 50.14828786253929, 38.75091344118118, 36.028971299529076, 38.57956923544407, 37.34325237572193, 40.72166249155998, 42.52671383321285, 55.769892409443855, 58.31255257129669, 50.228930935263634, 38.62878039479256, 41.893420815467834, 40.786973387002945, 38.74219290912151, 40.609294921159744, 40.1144702732563, 37.72554226219654, 38.25283236801624, 46.920402869582176, 51.66984021663666, 54.03217725455761, 57.62833088636398, 52.75126598775387, 49.30697500705719, 43.95154617726803, 42.02847696840763, 42.9387941211462, 41.33666329085827, 42.53282390534878, 43.14463667571545, 37.995878756046295, 41.276273131370544, 41.30955934524536, 43.83502922952175, 38.7132802605629, 44.14542697370052, 42.62347184121609, 44.9712822586298, 45.47244876623154, 43.67436245083809, 47.476100251078606, 44.97032091021538, 49.931862875819206, 53.24901647865772, 55.40774144232273, 54.6754789352417, 52.548691257834435, 52.407851815223694, 51.72861546278, 49.917602241039276, 46.4660232514143, 43.694201186299324, 44.98805835843086, 45.75624793767929, 45.370051860809326, 45.3935270011425, 49.476081132888794, 53.4444285929203, 56.27934247255325, 55.57650178670883, 57.02114246785641, 55.423016622662544, 56.36737994849682, 54.81390930712223, 52.810193225741386, 53.64457905292511, 50.5517578125, 53.3868008852005, 52.354274690151215, 55.82057408988476, 58.03872786462307, 64.83580693602562, 59.9463927000761, 74.30217057466507, 23.46757873892784, 0.6088338489644229, 4.034572206437588, 0.4970218800008297, 8.04043885320425, 76.41967535018921, 70.98697766661644, 72.30920031666756, 74.85611245036125, 72.67148047685623, 66.01499766111374, 55.910234078764915, 44.360210448503494, 55.19632078707218, 77.25234746932983, 16.251957826316357, 0.6633919745218009, 0.4103615926578641, 0.2549641812220216, 0.14044282404938713, 0.16867435915628448, 0.22470052703283727], [0.03765615379961673, 0.07169975535362028, 0.026094372442457825, 0.03188113165379036, 0.10387259186245501, 0.05997656800900586, 0.0518280277174199, 0.15777746419189498, 0.1760647993069142, 38.28339792788029, 60.547832027077675, 40.86758606135845, 22.86014523357153, 14.232735726982355, 46.8705989420414, 57.84463807940483, 63.67577478289604, 52.89476528763771, 62.50243954360485, 51.73559948801994, 59.97770681977272, 4.419878656044602, 0.08303401278681122, 1.1153116403147578, 0.8505808550398797, 0.12441091283108108, 1.7482237285003066, 56.870887130498886, 64.32902052998543, 56.02665223181248, 44.40351292490959, 44.428169801831245, 43.847655951976776, 46.47585332393646, 50.394081473350525, 49.09601792693138, 53.80705453455448, 55.73304198682308, 54.07227270305157, 54.10227969288826, 51.255407854914665, 46.01996898651123, 38.68993051350117, 40.286046266555786, 39.079018235206604, 40.50497151911259, 38.67696940898895, 42.798490449786186, 44.25184786319733, 48.43472421169281, 49.111885875463486, 49.996767193078995, 46.49899788200855, 51.094596683979034, 46.39304056763649, 43.64842124283314, 38.410428911447525, 43.02937366068363, 44.136740639805794, 42.54002831876278, 39.98027667403221, 41.685701161623, 41.160550341010094, 40.584702640771866, 37.63837493956089, 36.71884328126907, 37.22476713359356, 38.800892159342766, 40.33659115433693, 39.060771614313126, 39.759717509150505, 40.27515225112438, 39.79166239500046, 42.572429180145264, 44.76186789572239, 47.579283714294434, 49.517080932855606, 52.65300326049328, 51.881944835186005, 49.85933996737003, 47.82514952123165, 39.874942526221275, 38.36231969296932, 38.35052512586117, 39.73519742488861, 38.05818401277065, 37.02041409909725, 51.816379353404045, 52.61454552412033, 44.28984582424164, 38.94777327775955, 41.284283101558685, 38.75852823257446, 40.8732021600008, 37.92006142437458, 38.87053482234478, 37.77349188923836, 39.84813116490841, 44.927751794457436, 56.50349244475365, 52.976027727127075, 52.20371916890144, 51.53780110180378, 45.907878801226616, 40.601201355457306, 39.59998548030853, 39.76966917514801, 38.76268520951271, 36.66052781045437, 36.9134384393692, 37.903456315398216, 39.252159744501114, 37.43474006652832, 44.564206302165985, 39.8958034068346, 35.580659955739975, 39.93808373808861, 39.25341747701168, 40.52522823214531, 39.906731620430946, 43.26043926179409, 45.07549546658993, 43.31937789916992, 49.83985461294651, 48.09949479997158, 50.868839398026466, 51.23321704566479, 52.410314083099365, 49.903812780976295, 45.20407296717167, 42.66195237636566, 41.398417577147484, 41.02852642536163, 42.051556929945946, 39.78667326271534, 40.529898181557655, 40.64169958233833, 42.952773571014404, 45.70813111960888, 49.21983428299427, 49.91996191442013, 49.771617874503136, 48.93906734883785, 47.833034098148346, 46.63890637457371, 44.829926043748856, 45.12730948626995, 46.70942299067974, 48.736652210354805, 53.926862105727196, 55.76016113162041, 57.79709503054619, 55.761745646595955, 61.140873804688454, 10.985048096626997, 1.1424901569262147, 1.4703404833562672, 0.9217435552272946, 13.873607497662306, 68.47723513841629, 60.82622788846493, 61.99944153428078, 63.18646743893623, 62.97756604850292, 51.77211552858353, 32.65728682279587, 29.068466797471046, 44.315456449985504, 51.006726399064064, 2.4071012483909726, 0.07226590270875022, 0.06062248881789856, 0.04194220877252519, 0.04803306299436372, 0.041238760386477225, 0.03922566625988111, 0.12158266225014813, 0.0927440651867073, 0.02203861888119718, 0.053257096151355654, 0.00991023003734881, 0.07687611665460281, 0.08166379295289516, 0.2545660932082683, 0.3168634237954393, 47.71216258406639, 66.40376999974251, 49.493712186813354, 32.19797506928444, 27.21960000693798, 54.46626216173172, 60.423388704657555, 69.07464668154716, 57.17363588511944, 67.85736680030823, 56.53982229530811, 67.18269780278206, 4.308333266526461, 0.06229025049833581, 2.8728933166712523, 4.416996510699391, 0.1638827272108756, 2.1143946424126625, 60.6595042347908, 66.8063659965992, 59.95782628655434, 46.739046201109886, 46.683538779616356, 46.32388807833195, 49.612136632204056, 50.65586842596531, 52.146490439772606, 54.558870792388916, 56.56260207295418, 54.72961463034153, 56.232361793518066, 52.98120304942131, 49.00860741734505, 41.5445539355278, 42.47561417520046, 41.05860561132431, 42.724143639206886, 40.34080132842064, 45.97660571336746, 47.70752303302288, 49.99541066586971, 51.2825345993042, 50.69778397679329, 49.80607442557812, 52.26921245455742, 49.23034451901913, 45.27702145278454, 42.22960017621517, 45.64907468855381, 45.889142006635666, 42.95333594083786, 42.95926362276077, 43.59959006309509, 43.25730822980404, 42.78656288981438, 39.17758874595165, 38.52636829018593, 38.77981089055538, 39.79777246713638, 41.57424554228783, 40.33470645546913, 42.03249715268612, 42.26982481777668, 42.87131354212761, 44.20607931911945, 47.08179160952568, 48.64688202738762, 50.541034787893295, 54.313525557518005, 55.063536912202835, 52.22098544239998, 47.64697328209877, 40.98147355020046, 39.2767558246851, 38.99432457983494, 39.888747185468674, 39.10985358059406, 36.741235479712486, 51.63824111223221, 53.86125482618809, 47.53496669232845, 39.24874372780323, 40.47928869724274, 39.184485375881195, 39.49864111840725, 39.17013734579086, 37.28709898889065, 38.111833333969116, 39.869763404130936, 46.439926251769066, 58.14416840672493, 55.78934736549854, 54.680886045098305, 53.30184504389763, 47.023054361343384, 42.20591984689236, 41.01304605603218, 42.069290578365326, 40.29430702328682, 38.850962072610855, 38.7260627746582, 38.04236926138401, 40.29713787138462, 39.594232589006424, 47.41815336048603, 41.36648789048195, 38.92832592129707, 42.82710291445255, 39.6660715341568, 42.490228191018105, 41.08370326459408, 47.324568182229996, 46.302388831973076, 45.01337260007858, 52.095329985022545, 51.253314167261124, 53.01503263413906, 53.990428894758224, 53.4606309235096, 50.22236868739128, 46.88194893300533, 43.880634382367134, 43.178918436169624, 43.63180473446846, 44.26166273653507, 41.51609346270561, 42.09292151033878, 41.40599437057972, 44.92716662585735, 47.38526612520218, 54.188918843865395, 51.5373033285141, 52.630044892430305, 50.22907912731171, 49.94856297969818, 49.37556132674217, 48.4801659733057, 48.130729123950005, 49.663851857185364, 51.270276457071304, 56.367839723825455, 59.20012794435024, 63.30104649066925, 58.867087215185165, 66.62858873605728, 13.665792848914862, 1.3439967879094183, 0.35002071177586913, 0.8001531078480184, 15.55971097201109, 75.65705627202988, 66.25673308968544, 68.47102627158165, 69.45705816149712, 68.11089679598808, 58.84693309664726, 44.37678895890713, 33.027793541550636, 51.14226512610912, 61.5468630194664, 4.380870899185538, 0.22099323221482337, 0.10053230391349643, 0.03910056242602877, 0.032477599452249706, 0.015532454181084177, 0.044535513952723704, 0.16831038024974987, 0.15750622405903414, 0.13403586315689608, 0.15563558146823198, 0.10882463160669431, 0.16651539219310507, 0.14004378608660772, 0.3927864076104015, 0.3945894999196753, 55.46243570744991, 79.16867583990097, 59.31899316608906, 32.09994412958622, 24.008755199611187, 61.334948390722275, 68.04554030299187, 76.91013023257256, 62.31486640870571, 74.08136442303658, 60.55742271244526, 75.21555036306381, 5.919836293905973, 0.13905336032621562, 9.700340833514929, 6.3304047379642725, 0.3523752198088914, 2.538155266083777, 62.88678511977196, 68.47009912133217, 62.047881335020065, 48.47271077334881, 49.04769591987133, 48.25525984168053, 51.08249433338642, 53.50209429860115, 54.191346913576126, 57.116908729076385, 59.09808062016964, 58.05763565003872, 59.57181639969349, 56.31576731801033, 51.03033073246479, 43.166322112083435, 44.37433809041977, 43.146084398031235, 45.096690729260445, 43.098913729190826, 49.64675657451153, 51.21407367289066, 52.535787150263786, 55.38216881453991, 52.788264602422714, 50.5796255171299, 56.396790370345116, 52.30959668755531, 47.07703046500683, 44.39573474228382, 47.15693637728691, 49.031056612730026, 45.247656628489494, 43.4858887642622, 46.54257394373417, 44.98884491622448, 43.30822929739952, 41.19572125375271, 39.3594241887331, 40.51523856818676, 43.29803444445133, 44.55887518823147, 41.95048615336418, 44.1200215369463, 44.97553423047066, 44.204194620251656, 45.50553739070892, 49.55662161111832, 51.33668169379234, 54.47676099836826, 55.79779051244259, 59.05107334256172, 51.86582989990711, 47.24145524203777, 40.5021558701992, 39.40773859620094, 38.40225175023079, 39.26115766167641, 38.133552968502045, 35.43796621263027, 54.70699444413185, 56.29948139190674, 46.172242015600204, 39.7417026758194, 40.890517830848694, 37.69963525235653, 40.40476329624653, 40.54156355559826, 37.74522140622139, 38.387379348278046, 40.25108814239502, 48.27900096774101, 58.84024925529957, 55.85875064134598, 59.65931810438633, 55.169714614748955, 50.32296068966389, 44.35723900794983, 42.612323239445686, 44.66634102165699, 43.74333634972572, 40.30616998672485, 42.24558971822262, 39.943304657936096, 43.60823079943657, 41.69772371649742, 49.15620669722557, 42.91080102324486, 41.11603952944279, 43.953446075320244, 41.28767251968384, 44.136459454894066, 43.081453666090965, 49.61853168904781, 49.0032497048378, 48.4283709526062, 53.540882617235184, 53.75340521335602, 55.28296373784542, 57.438648864626884, 57.95058399438858, 52.332365065813065, 49.65885132551193, 46.4580512791872, 44.19371858239174, 47.04111859202385, 46.16141639649868, 43.20409208536148, 44.48903873562813, 42.76323974132538, 49.109355211257935, 49.461854696273804, 54.90731589496136, 55.223113149404526, 55.30399560928345, 53.93547244369984, 54.67001862823963, 52.95240819454193, 51.850725710392, 50.72337180376053, 54.341556653380394, 54.26418900489807, 60.160062834620476, 62.72335208952427, 65.61457514762878, 61.45472936332226, 73.75461995601654, 16.32677961140871, 1.151391773018986, 3.353307000361383, 1.4887493080459535, 16.877354867756367, 81.03142708539963, 73.85509416460991, 71.00131809711456, 76.69319987297058, 72.90441557765007, 66.53292506933212, 49.995600655674934, 41.3107904791832, 61.58721685409546, 76.14836990833282, 8.017024509608746, 0.6001810601446778, 0.36086957494262606, 0.19741736759897321, 0.14538920862833038, 0.14481670106761158, 0.12116985002649017], [0.0673020257090684, 0.1439305322128348, 0.04245880292728543, 0.021647533030773047, 0.011561809187696781, 0.04914913064567372, 0.03205972578143701, 0.2675582194933668, 0.03990815639554057, 28.733699060976505, 62.88815684616566, 43.5869937390089, 36.07866883277893, 36.68869949877262, 38.52041780948639, 60.73366105556488, 61.73753298819065, 57.30659835040569, 59.67057690024376, 52.43040360510349, 61.20708145201206, 13.673826567828655, 0.300031098886393, 1.9683725154027343, 3.9564688224345446, 0.4074941121507436, 0.2615810511633754, 43.29960376024246, 65.41542783379555, 54.23167794942856, 46.067702025175095, 49.06928636133671, 43.64831484854221, 46.220529824495316, 50.00555232167244, 49.70845766365528, 51.64922632277012, 55.69533661007881, 52.58599765598774, 54.784115105867386, 53.10643672943115, 47.99836702644825, 38.66340413689613, 40.32484978437424, 39.74821552634239, 39.120831191539764, 37.43405990302563, 43.2234900444746, 42.498272359371185, 46.41362406313419, 49.200664311647415, 53.35269391536713, 47.39459082484245, 48.410534709692, 44.34452868998051, 42.6713302731514, 43.48447144031525, 42.94183015823364, 42.097811847925186, 41.37794427573681, 40.9004694968462, 39.88383784890175, 39.90596406161785, 40.06499692797661, 39.34094958007336, 39.29900363087654, 39.51073966920376, 42.030779644846916, 37.80404604971409, 39.688870310783386, 39.45008732378483, 40.44165551662445, 39.82303351163864, 41.5497862547636, 44.71067704260349, 47.37569443881512, 49.52235884964466, 50.5576740950346, 54.661446288228035, 52.74270124733448, 39.750138223171234, 40.67505419254303, 36.561695113778114, 41.50382772088051, 37.57405199110508, 40.14188960194588, 36.99671097099781, 45.60384191572666, 54.079404920339584, 44.19168949127197, 40.04564456641674, 38.77956010401249, 37.343632355332375, 40.50437115132809, 38.921064510941505, 40.662324875593185, 37.748622223734856, 41.688551008701324, 47.9949814081192, 54.647520035505295, 51.909360364079475, 51.9097251445055, 50.448114573955536, 46.78491733968258, 41.02055825293064, 39.178781881928444, 37.64150217175484, 39.21747900545597, 39.85107220709324, 38.31745930016041, 40.321315973997116, 39.081153720617294, 39.40724462270737, 38.96831497550011, 43.72855134308338, 40.686970353126526, 38.42220447957516, 39.77933585643768, 38.62096421420574, 40.30502624809742, 43.03381182253361, 44.14800323545933, 42.71377019584179, 44.22705799341202, 49.455991610884666, 49.82307851314545, 49.87741939723492, 48.38784612715244, 51.76767356693745, 47.8227024525404, 45.34510239958763, 46.560337990522385, 41.67520232498646, 42.48072870075703, 42.40514695644379, 39.870561361312866, 40.94276502728462, 40.078474804759026, 40.460935682058334, 39.10382330417633, 44.03541907668114, 44.2717207968235, 46.90501369535923, 44.75042670965195, 45.27927093207836, 42.09903158247471, 44.96035784482956, 44.69957023859024, 48.242507725954056, 53.05763594806194, 58.442752584815025, 60.04372447729111, 56.683431789278984, 60.818806886672974, 3.0319741554558277, 0.621284059016034, 1.2432609871029854, 1.0639360221102834, 20.314179249107838, 64.29190412163734, 59.07581001520157, 63.84469851851463, 62.3091097176075, 61.84912160038948, 51.993301659822464, 24.852260537445545, 25.273895412683487, 39.85290750861168, 47.08874523639679, 2.6046122750267386, 0.141885633347556, 0.08077668157056905, 0.02286791324877413, 0.01445976320610498, 0.04459871895960532, 0.04447509942110628, 0.09552891497150995, 0.07521764666307718, 0.054482534105773084, 0.04937227218761109, 0.03362748306244612, 0.03712508034368511, 0.040882414468796924, 0.3325923829106614, 0.027756057788792532, 37.187548130750656, 72.2459489107132, 50.78961744904518, 35.12734428048134, 30.634999237954617, 53.867125511169434, 62.02151834964752, 70.60966551303864, 60.722447857260704, 67.78018534183502, 55.477247312664986, 68.20912912487984, 14.557635392993689, 0.2886295138159767, 0.4768660693662241, 4.462862424552441, 0.5477806250564754, 0.4347770637832582, 46.18982367217541, 68.52741524577141, 57.39468902349472, 47.893728241324425, 50.73069021105766, 45.11644966900349, 47.198992520570755, 51.994726583361626, 53.44372943043709, 53.232502564787865, 57.9767531901598, 55.052483305335045, 56.83609999716282, 54.443603977561, 50.09312242269516, 40.94784915447235, 41.82148687541485, 40.869808942079544, 41.51105113327503, 40.10124318301678, 43.93146425485611, 44.100486785173416, 48.11302587389946, 51.628908812999725, 52.83262722194195, 50.69413237273693, 50.03992907702923, 46.4422707259655, 45.49022801220417, 42.839212864637375, 46.042114198207855, 44.31667238473892, 41.99590511620045, 41.998021602630615, 41.49451062083244, 42.317413464188576, 40.3598915040493, 41.01501055061817, 41.577270179986954, 41.48261345922947, 41.95660002529621, 41.04114554822445, 40.62176585197449, 41.69377192854881, 42.17176727950573, 42.030863240361214, 43.08555744588375, 46.727358028292656, 48.31300534307957, 51.14958353340626, 53.52248400449753, 55.51607362926006, 53.280224204063416, 40.040469244122505, 38.92793074250221, 36.44697546958923, 40.86764685809612, 37.300652861595154, 39.41813863813877, 36.827122271060944, 46.83950141072273, 54.66397315263748, 44.535958617925644, 38.72464545071125, 38.77864435315132, 36.80466167628765, 40.413909405469894, 38.772507682442665, 39.779020473361015, 37.26972632110119, 40.59267461299896, 47.33670473098755, 54.695078283548355, 54.472843408584595, 54.27613936364651, 52.946564108133316, 49.51541282236576, 42.78664268553257, 40.93855485320091, 39.93347078561783, 41.05874240398407, 41.50154024362564, 41.044048592448235, 42.07182504236698, 39.25992272794247, 41.74324907362461, 41.79270721971989, 45.68899914622307, 43.23567599058151, 41.78845904767513, 40.2078502625227, 39.84390579164028, 42.10275158286095, 45.452328845858574, 45.98748452961445, 42.172740027308464, 48.6377739161253, 53.04896101355553, 51.956686824560165, 52.227053716778755, 52.76292376220226, 52.9624130576849, 48.23592267930508, 47.64940895140171, 49.25261132419109, 44.225899055600166, 44.84764449298382, 44.17112499475479, 43.059012070298195, 42.90519632399082, 41.5117122977972, 42.251931577920914, 42.18764282763004, 46.92516401410103, 46.9643285125494, 49.60286892950535, 47.71112523972988, 47.44537889957428, 45.99894851446152, 48.46228413283825, 48.41784931719303, 52.48270399868488, 55.863010212779045, 62.288788408041, 61.962807700037956, 62.389464005827904, 62.760650888085365, 4.683686625212431, 1.1966677685268223, 1.473066124599427, 0.8098281011916697, 23.186163939535618, 70.38312166929245, 64.15215522050858, 67.12353497743607, 68.68402764201164, 65.06902322173119, 62.17492751777172, 34.74780544638634, 26.78041387349367, 49.06481400132179, 57.686942741274834, 4.036148171871901, 0.2571842120960355, 0.023736404145893175, 0.03340420051245019, 0.09526996480417438, 0.011692240714182844, 0.06286743358941749, 0.13923224760219455, 0.3039421874564141, 0.16901052236789837, 0.1360538072185591, 0.08287824341095984, 0.12764251325279474, 0.21896587772062048, 0.5102317524142563, 0.12508508720202371, 43.239570781588554, 83.80270957946777, 59.80761654675007, 48.34675133228302, 46.66097179055214, 59.82760347425938, 68.52160155773163, 76.24810695648193, 66.54425606131554, 74.08530861139297, 60.223732218146324, 74.15698036551476, 16.662930473685265, 0.29097072256263345, 7.723916312679648, 7.78532481752336, 1.0622807359322906, 0.9591344394721091, 49.638769403100014, 70.7162193953991, 61.117379665374756, 50.595117285847664, 53.30315597355366, 48.00379693508148, 50.04608854651451, 53.79890397191048, 54.24398548901081, 55.52520453929901, 60.859711691737175, 56.79737627506256, 58.586111292243004, 58.19502867758274, 52.301476523280144, 43.29561397433281, 43.51625293493271, 44.45024661719799, 43.708290830254555, 41.32882431149483, 46.60989113152027, 47.252896428108215, 50.69878712296486, 53.777815103530884, 56.442494317889214, 54.068541303277016, 51.30094841122627, 49.11757417023182, 49.37536373734474, 48.285673409700394, 48.56096863746643, 46.86234198510647, 45.96099615097046, 43.986143320798874, 43.148022294044495, 45.57381212711334, 42.86913625895977, 43.75112593173981, 44.69004034996033, 44.32520292699337, 45.177273005247116, 43.9652406424284, 43.633909821510315, 44.62240397930145, 45.52102155983448, 45.347739458084106, 45.73177345097065, 50.15967205166817, 51.72742612659931, 54.750361517071724, 56.41216054558754, 58.81662592291832, 54.86232630908489, 40.85582949221134, 40.105392560362816, 35.29605522751808, 41.403547301888466, 38.49674507975578, 41.67555570602417, 36.328725814819336, 45.77078975737095, 57.547262236475945, 44.64812479913235, 38.971271216869354, 37.95561611652374, 36.677786484360695, 40.83348289132118, 38.88493224978447, 40.41848435997963, 37.34809711575508, 42.2030434012413, 47.29003943502903, 54.231366366147995, 59.45809230208397, 55.70525407791138, 55.74152693152428, 51.64741761982441, 44.96274411678314, 43.9687592536211, 41.30060322582722, 42.803905159235, 44.98656123876572, 42.52501532435417, 45.36103494465351, 42.452017441391945, 43.990509286522865, 43.90795111656189, 47.30657994747162, 45.64559407532215, 43.05557705461979, 42.53296449780464, 42.1941252797842, 44.578235149383545, 47.66876891255379, 48.565175011754036, 45.57200722396374, 51.05939157307148, 54.1101148724556, 54.40890423953533, 53.12691003084183, 52.71598868072033, 56.5666526556015, 51.993088871240616, 48.36376301944256, 52.08103895187378, 46.72137714922428, 47.12268501520157, 46.859860718250275, 45.93167692422867, 44.35150511562824, 45.4257682710886, 45.056808069348335, 43.83094444870949, 48.29370617866516, 49.73553881049156, 53.14743272960186, 50.446989834308624, 50.55239997804165, 48.97119082510471, 51.07112534344196, 51.163395792245865, 54.32087816298008, 60.56186847388744, 63.723747208714485, 67.70497977733612, 64.51871395111084, 70.12828454375267, 4.8371280916035175, 0.9356657706666738, 6.135138440877199, 1.453133225440979, 26.78729720413685, 77.06076934933662, 69.692941904068, 72.3768062889576, 73.29514101147652, 72.7420274913311, 67.79692724347115, 35.813492462038994, 36.03296868503094, 57.6820258051157, 68.87655571103096, 7.887521758675575, 0.3846487880218774, 0.37193101888988167, 0.14570140046998858, 0.202611866989173, 0.20543769816868007, 0.1617231368436478], [0.031197235148283653, 0.02647834666277049, 0.059770629450213164, 0.03250264322559815, 0.06318052342976443, 0.01945730866282247, 0.03800961276283488, 0.4037586157210171, 0.11933805144508369, 18.793734535574913, 58.3494333922863, 44.66851830482483, 50.81433892250061, 46.416694298386574, 33.770703077316284, 53.195655941963196, 62.01077252626419, 56.87530629336834, 58.36897574365139, 50.83709970116615, 62.18921475112438, 19.047013744711876, 0.45959840063005686, 1.0469591268338263, 4.068595580756664, 0.8439318649470806, 0.06965124965063296, 26.11260160803795, 68.45544710755348, 56.424889862537384, 51.666158214211464, 52.844227999448776, 48.92931327223778, 47.44528390467167, 49.49669122695923, 55.2797757089138, 49.735310822725296, 54.68653254210949, 54.72168065607548, 54.41201627254486, 51.76588386297226, 48.66893224418163, 39.31813560426235, 38.6832694709301, 40.07578834891319, 38.467566445469856, 39.63098041713238, 40.29190935194492, 39.59797538816929, 42.92767211794853, 45.08976750075817, 47.339444383978844, 46.89086705446243, 48.21187376976013, 44.591792821884155, 44.49346549808979, 42.81808219850063, 43.992112800478935, 43.684006333351135, 39.3374727666378, 39.77773994207382, 40.037038028240204, 38.6236734688282, 38.874011635780334, 36.04524202644825, 38.02304349839687, 38.98050092160702, 38.00689436495304, 38.63935522735119, 38.807553201913834, 41.10127732157707, 41.28988020122051, 39.58573244512081, 43.877446353435516, 45.202458053827286, 50.80083064734936, 50.56917987763882, 48.89016017317772, 53.132738918066025, 53.65827351808548, 39.61795091629028, 41.081024408340454, 37.66664162278175, 41.184698045253754, 38.254986852407455, 38.82132366299629, 38.556154891848564, 43.08949023485184, 51.94794349372387, 42.59117357432842, 40.15193626284599, 38.71814399957657, 37.73444518446922, 40.423059314489365, 39.15819078683853, 38.864417150616646, 39.93826612830162, 41.12949080765247, 42.882663533091545, 47.36051045358181, 52.28424444794655, 52.50008426606655, 52.0798534154892, 46.82778663933277, 44.84784588217735, 39.38628874719143, 37.48620070517063, 38.61974447965622, 39.35247056186199, 38.30031082034111, 39.518840834498405, 38.806937634944916, 40.314369946718216, 37.78688997030258, 40.40461130440235, 37.41805896162987, 38.861115127801895, 40.5935637652874, 39.8266015201807, 39.152464494109154, 44.05369229614735, 45.038550049066544, 40.76735503971577, 43.475621715188026, 50.90459927916527, 50.1035338640213, 49.499723464250565, 50.196799859404564, 50.63473016023636, 48.53647895157337, 45.84394343197346, 47.59624220430851, 46.08111910521984, 40.7556364685297, 38.60245160758495, 40.20971596240997, 41.29464514553547, 40.99554419517517, 41.73638664186001, 39.295473620295525, 40.92152796685696, 41.842526346445084, 43.33741173148155, 40.64968675374985, 43.80073606967926, 43.549546748399734, 46.88098378479481, 45.524532571434975, 49.21378120779991, 51.17895595729351, 61.207370236516, 56.0448494553566, 68.83301004767418, 43.80661815404892, 0.22920585324754938, 0.8458610333036631, 0.7769787451252341, 0.14770304696867242, 28.529188334941864, 70.50473034381866, 57.016312927007675, 63.27054172754288, 57.85896711051464, 66.01928383111954, 52.72629372775555, 37.37924784421921, 32.8419379144907, 43.14633518457413, 42.379239946603775, 0.23400983453029767, 0.1101826060039457, 0.06601422879612073, 0.15038939891383052, 0.04502832227444742, 0.03424251939577516, 0.07312464920687489, 0.06022548062901478, 0.02021804713876918, 0.02158546536520589, 0.019118592463200912, 0.06763973258784972, 0.08446695894235745, 0.08234241278842092, 0.28673130786046386, 0.027270611572021153, 25.340462140738964, 73.52872967720032, 50.89491359889507, 51.888461485505104, 41.927413791418076, 45.26717998087406, 57.88313001394272, 68.68593513965607, 61.621848195791245, 66.78174331784248, 55.405404567718506, 69.4594444334507, 20.988536663353443, 0.5734369077254087, 0.9152938763145357, 8.133697248995304, 2.5308299716562033, 0.18979031592607498, 31.65700949728489, 71.20728984475136, 57.148766219615936, 53.82049821317196, 55.888434648513794, 51.06828689575195, 49.66494619846344, 51.658296436071396, 57.79022879898548, 53.287709802389145, 57.51901835203171, 56.20509825646877, 55.611543506383896, 53.28604929149151, 51.998841762542725, 41.65915198624134, 40.57987689971924, 42.77186527848244, 40.450851023197174, 40.97974084317684, 42.07994520664215, 40.721183717250824, 46.10283873975277, 47.032170072197914, 49.950846657156944, 50.56502290070057, 50.255806893110275, 46.882036328315735, 45.94250254333019, 43.30464988946915, 46.11278660595417, 43.74191142618656, 42.70210862159729, 41.81507661938667, 42.3352725058794, 41.0639975219965, 41.7562747746706, 38.97279493510723, 40.807408690452576, 38.21486480534077, 41.03305958211422, 41.574047952890396, 41.216160356998444, 42.143747583031654, 43.29538978636265, 41.42099976539612, 46.84073254466057, 46.14138387143612, 53.20108585059643, 52.348761186003685, 52.41170860826969, 55.141793712973595, 53.02705518901348, 39.882359728217125, 39.728315994143486, 36.94469556212425, 39.94661048054695, 36.072893142700195, 38.20687383413315, 38.928344920277596, 42.767069935798645, 52.42960944771767, 42.60339751839638, 39.28435541689396, 38.51867750287056, 37.44102492928505, 39.970024824142456, 37.63273984193802, 37.44562268257141, 39.71444293856621, 41.806872859597206, 43.78916189074516, 48.39984588325024, 53.73820602893829, 55.08540853857994, 54.07997868955135, 48.44258598983288, 45.481579676270485, 41.73680081963539, 38.84597674012184, 38.89749437570572, 39.802009239792824, 40.09656183421612, 41.86862334609032, 39.659345895051956, 40.5988834798336, 39.43833455443382, 40.776683539152145, 41.49308569729328, 40.18994562327862, 42.11464874446392, 41.26947529613972, 40.99015228450298, 44.77848440408707, 45.89291900396347, 44.326646849513054, 44.8498559743166, 53.62758256494999, 53.30375634133816, 52.188645377755165, 52.08468675613403, 52.57729612290859, 51.444816291332245, 49.754594787955284, 49.097830429673195, 47.62027971446514, 43.37868511676788, 41.76410615444183, 42.040408328175545, 42.8434382379055, 44.250381141901016, 43.436552211642265, 41.736614629626274, 42.66388267278671, 43.07217836380005, 45.67597344517708, 44.218455255031586, 47.14350029826164, 45.54549224674702, 48.8877435028553, 48.36235709488392, 52.57817007601261, 53.67140181362629, 63.9383102953434, 59.274315163493156, 71.65347710251808, 46.785540506243706, 0.5652817734517157, 1.3592600938864052, 0.3201363544212654, 0.24516122677596286, 31.67143352329731, 77.00780019164085, 63.334382101893425, 70.87870627641678, 64.9647568166256, 72.57873505353928, 59.78498876094818, 34.580827206373215, 32.585656866431236, 51.35492451488972, 53.55330415070057, 1.1910082097165287, 0.12282031966606155, 0.06263350864173844, 0.19658108591102064, 0.06986607171711512, 0.041458591949776746, 0.028403570504451636, 0.11768567448598333, 0.2582743379753083, 0.1888797600986436, 0.15301186678698286, 0.13205953873693943, 0.17265979608055204, 0.2076540034613572, 0.44104922097176313, 0.12778975535184145, 30.567731447517872, 84.35818657279015, 57.968682423233986, 69.415792375803, 52.92908884584904, 53.52338835597038, 62.808843702077866, 74.38178390264511, 65.78320249915123, 71.8712966144085, 60.432572811841965, 76.27971366047859, 22.71930579096079, 0.5964527477044612, 3.762434609234333, 12.29927597567439, 2.6308033196255565, 0.31694713805336505, 32.99916207790375, 70.3931987285614, 60.41144594550133, 55.42051635682583, 59.73376750946045, 54.699812829494476, 51.627613082528114, 54.275246411561966, 60.3024297952652, 54.989817067980766, 59.819259122014046, 58.40073063969612, 58.12374830245972, 56.700789257884026, 53.30170065164566, 43.79388123750687, 43.96562062203884, 45.63261777162552, 41.740783005952835, 45.076844394207, 44.8827014118433, 44.9946928024292, 47.5114269554615, 48.116563484072685, 53.36344733834267, 51.43410086631775, 53.7883747369051, 49.31474559009075, 48.86515371501446, 47.24041409790516, 49.2529609054327, 46.970712170004845, 44.6196985244751, 43.884760960936546, 45.764903873205185, 42.0587233453989, 43.30096408724785, 39.84376519918442, 43.2643910497427, 41.00509688258171, 43.92077162861824, 44.77026544511318, 41.60793833434582, 45.2976543456316, 46.77537985146046, 44.03141409158707, 49.41118061542511, 49.79865722358227, 55.88578999042511, 54.21843186020851, 52.96664223074913, 57.557073310017586, 58.491116389632225, 39.83887866139412, 40.374190136790276, 36.25058300793171, 41.97943300008774, 36.36249840259552, 38.050314635038376, 39.34236690402031, 44.913388565182686, 55.323750749230385, 43.63155774772167, 39.493423998355865, 39.62016239762306, 37.78149425983429, 39.16604496538639, 38.853732123970985, 37.996574118733406, 41.06935143470764, 43.773521929979324, 42.74044096469879, 48.45916070044041, 56.142150834202766, 57.43777871131897, 56.83878265321255, 50.72004698216915, 48.71519096195698, 44.660128355026245, 41.14066980779171, 41.05472221970558, 42.1824599057436, 43.4793721139431, 43.6137443035841, 41.24661572277546, 42.59865537285805, 43.139902129769325, 43.772674575448036, 42.2405131906271, 41.178234592080116, 43.94105114042759, 42.86338336765766, 43.968607261776924, 48.78669932484627, 49.379448518157005, 46.97466395795345, 47.9329839348793, 56.00706048309803, 55.472375974059105, 52.93382339179516, 55.340154469013214, 56.63534916937351, 51.65882080793381, 51.5760612487793, 50.80776147544384, 51.10246606171131, 46.98539838194847, 44.80071701109409, 44.44455452263355, 44.52594615519047, 46.35628134012222, 45.68164274096489, 44.58927355706692, 44.92764540016651, 45.96635766327381, 48.10646742582321, 48.21387626230717, 49.22853581607342, 50.1283123344183, 53.14732253551483, 52.064536437392235, 53.2755808532238, 57.977539747953415, 68.07066455483437, 64.71360549330711, 73.48093584179878, 50.62468349933624, 1.1162994685582817, 1.2707863538525999, 2.3374987207353115, 0.38805589894764125, 35.20862191915512, 81.55514538288116, 66.41498699784279, 75.14882594347, 69.93428215384483, 79.08213168382645, 67.990602850914, 48.55835817754269, 44.472091645002365, 61.65480762720108, 65.35260960459709, 2.6655408181250095, 0.380349526531063, 0.21874949714401737, 0.298726818873547, 0.18387738789897412, 0.24519656784832478, 0.19992977497167885], [0.06522039795527235, 0.020177540718577802, 0.055029515497153625, 0.020798080076929182, 0.06412950766389258, 0.016145996014529373, 0.04009575648524333, 0.28242180473171175, 0.11478608124889433, 12.022778112441301, 58.24123799800873, 47.02486306428909, 38.786604925990105, 75.84052562713623, 52.43939392268658, 43.939614817500114, 65.83010718226433, 55.31807005405426, 60.876449793577194, 52.93109133839607, 60.75102612376213, 31.975413411855698, 0.22596112423343584, 0.3655046731000766, 3.5175455873832107, 1.1584133212454617, 0.17040384525898844, 15.721770375967026, 61.08293831348419, 58.72274436056614, 54.72462549805641, 54.75498586893082, 46.818784922361374, 45.64561307430267, 49.885208979249, 54.42563094198704, 53.78196068108082, 55.713150054216385, 52.855418398976326, 53.36274437606335, 53.12269605696201, 48.91249917447567, 40.54610811173916, 38.51913347840309, 38.7058212608099, 39.386224150657654, 38.96329164505005, 36.879107281565666, 39.27865572273731, 40.15127889811993, 42.77439974248409, 42.67802931368351, 43.84503409266472, 43.703909665346146, 44.47483889758587, 44.56222280859947, 41.427360624074936, 42.141680493950844, 41.235018745064735, 41.64863035082817, 38.82904104888439, 40.08184142410755, 39.0477991104126, 39.54025648534298, 40.91832093894482, 39.035818353295326, 37.955559119582176, 38.69721092283726, 37.632154673337936, 38.00530605018139, 36.89829625189304, 40.820578783750534, 38.186092749238014, 43.29987734556198, 46.797228679060936, 51.35045975446701, 51.600250750780106, 52.15052202343941, 50.977768152952194, 54.1099438816309, 42.79150642454624, 38.49216632544994, 38.354294523596764, 39.726625084877014, 38.94789107143879, 38.68787482380867, 37.96197697520256, 42.540917471051216, 48.89050215482712, 39.506293907761574, 39.47119139134884, 37.35999047756195, 38.0335309356451, 40.72571687400341, 39.1814873367548, 39.81066137552261, 39.738184064626694, 40.99129602313042, 41.3630148768425, 46.1433407664299, 53.935943618416786, 49.62285205721855, 50.3264033049345, 49.04554903507233, 48.000164330005646, 44.13174010813236, 40.34089632332325, 35.79821728169918, 36.06933273375034, 35.90003281831741, 36.92906320095062, 36.17318116128445, 37.06386856734753, 37.42243252694607, 41.13076373934746, 40.80816105008125, 40.92225752770901, 40.56485630571842, 39.42364074289799, 38.42792697250843, 42.396278232336044, 42.98498444259167, 45.76720654964447, 47.76522673666477, 51.35221526026726, 50.72337560355663, 49.450827687978745, 47.68146023154259, 48.92060033977032, 48.31553980708122, 50.95233231782913, 45.744126588106155, 44.868197590112686, 41.39805659651756, 39.76688012480736, 37.983624413609505, 40.39174899458885, 37.89149075746536, 42.176634818315506, 39.522184655070305, 40.63456356525421, 40.477024018764496, 42.91454762220383, 38.83816435933113, 43.04663613438606, 45.156898498535156, 50.059023052453995, 48.06892544031143, 53.89137960970402, 50.98930813372135, 62.817606031894684, 53.045161217451096, 62.70492687821388, 18.738964274525642, 0.04050207862746902, 1.3802622794173658, 1.0505601461045444, 0.6786068330984563, 40.750229358673096, 67.53462731838226, 59.77544367313385, 61.84173859655857, 56.995113864541054, 57.02022671699524, 48.87065961956978, 35.796883553266525, 31.092886067926884, 52.44389288127422, 33.27675238251686, 0.2993630472337827, 0.10162045567994937, 0.01983246245799819, 0.0328020552842645, 0.03233910727431066, 0.04775384848471731, 0.07222521075163968, 0.050596500441315584, 0.01151377646237961, 0.0815892664832063, 0.01189454738778295, 0.12159708960098214, 0.10928577990853228, 0.023808436999388505, 0.3802056686254218, 0.06799642360419966, 15.666281953454018, 68.83133053779602, 52.464130595326424, 45.92658519744873, 61.27097122371197, 52.41046607494354, 51.7279276996851, 70.61547920107841, 62.66721770167351, 66.53858676552773, 58.616733849048615, 67.14481383562088, 35.08222550153732, 0.2510603656992316, 0.5396884842775762, 5.343508869409561, 3.879948053508997, 0.1912844818434678, 18.2553718239069, 66.27295061945915, 61.429190933704376, 57.530926913022995, 57.19030939042568, 50.31020097434521, 47.789283245801926, 52.517399936914444, 56.91566772758961, 55.504096671938896, 56.48548141121864, 55.30171573162079, 54.55246813595295, 55.40716767311096, 51.978930830955505, 41.15928500890732, 40.44276125729084, 41.626682728528976, 42.25055605173111, 42.74898290634155, 40.304285287857056, 41.734095364809036, 42.54495285451412, 46.57745987176895, 46.279217675328255, 44.814137890934944, 45.6218833476305, 45.556287467479706, 45.11677265167236, 43.684469908475876, 44.58803102374077, 43.67019407451153, 43.51491540670395, 41.42459437251091, 42.29867286980152, 41.370496675372124, 40.621119886636734, 41.17978110909462, 41.51571728289127, 38.676422238349915, 40.36274515092373, 39.05173949897289, 40.043908059597015, 40.23783065378666, 42.316683903336525, 41.372863948345184, 46.49909287691116, 49.15560632944107, 52.657426223158836, 54.60968166589737, 54.59368072450161, 53.85820358991623, 57.710972651839256, 41.95845812559128, 37.47784875333309, 36.94214969873428, 38.72840724885464, 38.25739972293377, 39.63630013167858, 38.20949949324131, 42.298418283462524, 50.46595461666584, 38.97189058363438, 37.61227034032345, 37.72991202771664, 37.60259605944157, 39.88752365112305, 39.55720357596874, 39.46063555777073, 38.553350642323494, 39.170832708477974, 40.72847932577133, 48.89534309506416, 55.428256541490555, 51.94382831454277, 53.2591999322176, 50.632214695215225, 48.64435516297817, 44.363641664385796, 41.13283462822437, 38.21303330361843, 38.025513365864754, 37.592013627290726, 39.856334924697876, 38.112980872392654, 41.07372120022774, 39.53132316470146, 43.43536667525768, 42.5540229678154, 42.00886622071266, 40.16838937997818, 40.94014696776867, 40.73700986802578, 44.33664411306381, 44.62380610406399, 45.71833737194538, 49.11397956311703, 52.882438749074936, 54.03352618217468, 51.22049532830715, 48.11776801943779, 51.33849419653416, 50.868041440844536, 51.71269811689854, 48.316364362835884, 47.417317405343056, 43.42087045311928, 41.46392986178398, 40.00220149755478, 42.20376156270504, 38.72761309146881, 41.68794684112072, 41.81049786508083, 43.40437173843384, 43.09664525091648, 44.629737585783005, 40.59331297874451, 45.57466708123684, 45.51534466445446, 53.996964544057846, 49.667575657367706, 56.14401273429394, 54.85566906630993, 65.08173733949661, 55.81302009522915, 66.65495172142982, 22.807782143354416, 0.05363666015909985, 3.343137321062386, 0.34501973481383175, 0.7295752794016153, 46.97173811495304, 71.83782801032066, 63.80653336644173, 66.72889575362206, 66.75959050655365, 63.802004009485245, 56.12299606204033, 37.89022162556648, 35.30883774161339, 61.09917104244232, 43.778427466750145, 0.40340069273952395, 0.04132179557927884, 0.0543542538798647, 0.09060938129550777, 0.044505609112093225, 0.0633419405494351, 0.04079757956787944, 0.14713745622429997, 0.10116174162249081, 0.17770786973414943, 0.09525561166810803, 0.13787410251097754, 0.19243681454099715, 0.1375360690872185, 0.5770633975043893, 0.17261969042010605, 18.319400288164616, 81.77292689681053, 60.09608566761017, 55.77629506587982, 82.05367103219032, 68.71618151664734, 55.537873059511185, 78.44087049365044, 65.74056878685951, 72.0452892780304, 63.444025218486786, 73.18774357438087, 38.651237189769745, 0.3708570421440527, 1.010868544690311, 11.259025745093822, 4.171461760997772, 0.5879568785894662, 21.79142978042364, 65.7100260257721, 61.742776706814766, 61.85638681054115, 59.975970312952995, 53.433188796043396, 49.9111083894968, 54.62948240339756, 59.06294010579586, 57.765689715743065, 60.45634053647518, 56.42028450965881, 57.35577531158924, 59.627586007118225, 54.47483070194721, 44.1779950261116, 42.396441623568535, 43.42494763433933, 44.35354180634022, 45.13408072292805, 42.04401433467865, 44.54917810857296, 44.429849311709404, 49.36551846563816, 48.03613319993019, 47.436293587088585, 49.080225974321365, 49.810128808021545, 48.954821303486824, 45.28601177036762, 46.968432292342186, 46.02343440055847, 45.45944206416607, 42.940914407372475, 45.427143797278404, 43.61504003405571, 43.50353501737118, 44.40970279276371, 43.85610669851303, 40.92409282922745, 43.73787224292755, 41.56971998512745, 41.178037002682686, 42.18609631061554, 46.13753467798233, 44.181916415691376, 48.71191933751106, 51.52481719851494, 54.65671934187412, 56.73463024199009, 58.536812737584114, 54.93401326239109, 60.24905785918236, 43.85957971215248, 37.447701171040535, 36.81211307644844, 38.9388095587492, 37.86917455494404, 38.74479576945305, 37.47963085770607, 43.53823095560074, 51.09594561159611, 39.319552928209305, 38.841614574193954, 38.20741340517998, 37.62385971844196, 41.16800554096699, 39.374296590685844, 40.254222974181175, 38.98919105529785, 41.481868699193, 40.74399009346962, 49.6059163659811, 58.31905782222748, 54.680544063448906, 55.14886513352394, 54.02993157505989, 51.67265586555004, 47.61319689452648, 44.74762625992298, 41.05258293449879, 40.61458803713322, 39.22985874116421, 40.64326889812946, 39.5714870095253, 41.163715571165085, 41.04073517024517, 45.19563741981983, 44.801431372761726, 43.11384692788124, 43.37858632206917, 42.634445652365685, 41.897357404232025, 46.672428175807, 47.505993247032166, 48.95474150776863, 51.07286185026169, 56.61490246653557, 56.16051524877548, 54.882738813757896, 51.11736126244068, 54.39598873257637, 53.68775613605976, 55.052517503499985, 50.412449687719345, 50.44610448181629, 45.60884244740009, 43.495308458805084, 42.38010250031948, 44.17319968342781, 40.74402429163456, 45.38664177060127, 44.0399294346571, 45.88280014693737, 45.874820575118065, 48.36550712585449, 42.90931910276413, 47.96405486762524, 48.68904076516628, 55.84075100719929, 54.60098393261433, 58.6814633756876, 58.53488624095917, 67.99306511878967, 59.41220596432686, 71.06344476342201, 25.872690081596375, 0.15649470646167174, 5.193937020376325, 3.584298980422318, 1.0530108958482742, 48.41820649802685, 77.57881075143814, 69.50504198670387, 73.99738892912865, 70.14882624149323, 69.1361653804779, 64.49097543954849, 48.979124799370766, 44.449042081832886, 72.05948531627655, 56.11750155687332, 1.2601578491739929, 0.21799072535941377, 0.1422179225482978, 0.18665250070625916, 0.17273252655286342, 0.1330123672960326, 0.15639313613064587], [0.08346661066752858, 0.05014869966544211, 0.02364522388234036, 0.11010349306161515, 0.021054759272374213, 0.13699784874916077, 0.02702463785681175, 0.3088432119693607, 0.07117838176782243, 6.515217320993543, 64.52975615859032, 48.66800129413605, 45.03106065094471, 91.05345010757446, 66.84064775705338, 39.41642113029957, 63.059341460466385, 54.99263271689415, 54.73798178136349, 52.82648675143719, 53.94994206726551, 52.13500365614891, 2.6851869514212012, 0.48696833197027445, 4.937682095915079, 4.147203387692571, 0.033990738374996, 3.125580232590437, 49.444379433989525, 59.062206745147705, 61.98440194129944, 55.92545226216316, 45.244354605674744, 47.812332808971405, 52.578242272138596, 55.70881828665733, 53.23121823370457, 52.72421903908253, 54.290947169065475, 52.94105440378189, 52.204543724656105, 44.316151812672615, 38.56812804937363, 38.399933874607086, 38.05310368537903, 37.64262691140175, 38.360203206539154, 38.29878710210323, 37.96367168426514, 38.53828825056553, 40.0204823166132, 39.449030980467796, 41.55118837952614, 40.28300642967224, 41.67823076248169, 41.29320502281189, 40.05451329052448, 41.18247136473656, 40.809012204408646, 39.15555752813816, 41.27735607326031, 40.02553604543209, 39.62996207177639, 40.22716462612152, 40.78046813607216, 37.58828602731228, 38.01634065806866, 38.10364097356796, 37.218280881643295, 37.778378427028656, 38.76307278871536, 37.19617746770382, 39.16461244225502, 47.18177564442158, 51.9829586148262, 52.65883594751358, 52.623896822333336, 51.74913056194782, 52.12814122438431, 55.01752898097038, 46.12348683178425, 38.591014221310616, 38.68218652904034, 38.373118713498116, 39.30263623595238, 38.85842107236385, 40.501335114240646, 43.27882647514343, 49.85387206077576, 40.67092001438141, 39.64620620012283, 38.925206288695335, 40.25785177946091, 39.864618480205536, 39.06712867319584, 39.75573152303696, 40.49885384738445, 39.34736743569374, 41.50019131600857, 47.21885785460472, 56.00834101438522, 51.24227575957775, 51.10450655221939, 49.86585661768913, 43.27585503458977, 44.11203056573868, 43.58469106256962, 40.11286295950413, 38.083559051156044, 36.48525841534138, 33.82415100932121, 35.26364676654339, 36.37764438986778, 36.36383593082428, 37.58395045995712, 40.16748882830143, 42.4523214250803, 41.08418583869934, 40.378844887018204, 39.19133260846138, 43.411940932273865, 42.99867510795593, 47.84650817513466, 49.77480970323086, 51.11981213092804, 52.13275797665119, 51.59408748149872, 51.053406894207, 50.84922105073929, 47.48079679906368, 48.94882142543793, 45.00776030123234, 44.0608549118042, 38.74984569847584, 39.848986119031906, 38.52026201784611, 39.93547707796097, 40.3675252944231, 38.128347247838974, 39.62104395031929, 42.307560592889786, 40.940933525562286, 39.98928599059582, 37.89513856172562, 44.40082646906376, 46.94582350552082, 50.99986016750336, 49.33577746152878, 56.78313843905926, 53.37095573544502, 60.69998346269131, 54.849243611097336, 52.373133078217506, 8.676328081637621, 0.18807472282787785, 1.0956948366947472, 0.9078532224521041, 1.8358293338678777, 52.11857333779335, 63.30791272222996, 60.71551702916622, 62.9975263774395, 47.1781962364912, 57.648165822029114, 40.63071437180042, 26.337604634463787, 29.63376436382532, 53.421785607934, 24.905830062925816, 0.3306581382639706, 0.12658916821237653, 0.10172305759624578, 0.06205869300174527, 0.10685743560316041, 0.04094464355148375, 0.03739223124284763, 0.01687603184109321, 0.03817038792476524, 0.11313678420265205, 0.07601468358188868, 0.09694802749436349, 0.15455571206985041, 0.037490591785172, 0.32585326640401036, 0.11186041636392474, 9.170834496617317, 76.10072806477547, 56.385307386517525, 49.896676763892174, 84.28032875061035, 65.51706477999687, 46.35690450668335, 68.32044795155525, 63.09054158627987, 64.28356736898422, 59.22451123595238, 59.73968379199505, 56.419471353292465, 2.2152089327573776, 0.2971172786783427, 1.574111133813858, 5.212571695446968, 0.03822529943136033, 4.4562954269349575, 52.58635863661766, 61.31395071744919, 63.17805469036102, 59.56441059708595, 49.01718735694885, 49.67371232807636, 53.707602471113205, 55.49151174724102, 55.71227230131626, 54.10749301314354, 54.992689713835716, 53.069221526384354, 54.07471217215061, 47.44245305657387, 41.11111119389534, 39.242113083601, 40.77485203742981, 40.34344978630543, 40.04265792667866, 40.22245667874813, 39.60877060890198, 40.480462834239006, 43.14374752342701, 41.868330761790276, 43.83311413228512, 42.704111114144325, 45.009386613965034, 44.86955791711807, 40.78406274318695, 42.572729364037514, 42.15545475482941, 41.482377871870995, 41.898189559578896, 42.24352262914181, 40.19434578716755, 42.21896834671497, 43.64552579820156, 40.1070910692215, 40.03627046942711, 39.25204575061798, 39.598735347390175, 39.33269262313843, 40.02666458487511, 39.72022242844105, 41.64604648947716, 48.93291927874088, 52.649792432785034, 53.38723786175251, 54.08666633069515, 53.429218009114265, 53.78723859786987, 57.7526868134737, 44.728824868798256, 38.59740927815437, 38.062747567892075, 38.49194213747978, 40.62673218548298, 37.7897360175848, 39.29752171039581, 43.85715924203396, 51.4192246645689, 39.93615344166756, 39.7306414693594, 38.32661300897598, 40.03899872303009, 37.771063819527626, 37.36880600452423, 39.3784611672163, 39.376295283436775, 41.52788423001766, 39.532577097415924, 48.0045834928751, 57.67575614154339, 52.60031148791313, 52.749111503362656, 50.774691849946976, 47.25662402808666, 46.86829246580601, 44.51973348855972, 41.01509414613247, 38.64396817982197, 38.35462510585785, 36.520604118704796, 36.54923938214779, 39.44259412586689, 38.924313336610794, 38.82592521607876, 42.87372261285782, 44.15094427764416, 41.66815370321274, 41.64737641811371, 40.95704086124897, 44.46239456534386, 44.799337685108185, 49.58544306457043, 50.69276064634323, 53.82785841822624, 54.7635468095541, 52.176957204937935, 53.337316140532494, 52.8639717400074, 48.84808883070946, 50.267160683870316, 49.62075836956501, 46.60204075276852, 40.66640205681324, 41.78502023220062, 41.318659856915474, 42.52673663198948, 42.29799270629883, 43.078383430838585, 41.993321254849434, 44.53175604343414, 43.84760655462742, 43.40222865343094, 40.6077142059803, 45.17071835696697, 49.02233228087425, 53.566360250115395, 51.784050688147545, 59.367269575595856, 56.23250998556614, 65.6825914978981, 57.241659834980965, 59.34960812330246, 9.742156639695168, 0.12884930474683642, 3.350700340233743, 0.5644536553882062, 2.277568099088967, 57.052346393465996, 70.20979017019272, 65.46167895197868, 70.39470344781876, 55.161526054143906, 66.8839730322361, 51.45167872309685, 30.45064453035593, 33.903266564011574, 61.691954433918, 33.33580121397972, 0.2814630389912054, 0.04901305786916055, 0.07019803437287919, 0.04947781300870702, 0.08038041181862354, 0.0313988469861215, 0.031188652210403234, 0.14564052951755002, 0.1709707421832718, 0.16601932584308088, 0.3357791353482753, 0.13582709594629705, 0.3640451654791832, 0.21798906294861808, 0.5630320566706359, 0.32701751799322665, 9.914215207099915, 86.39784872531891, 63.49750354886055, 61.408421248197556, 97.51498058438301, 76.7034213244915, 54.54663924872875, 74.10512074828148, 67.98380121588707, 67.74834305047989, 65.97275912761688, 63.62169988453388, 62.3519030213356, 3.1007179291918874, 0.7625922420993447, 11.765511017292738, 7.291197432205081, 0.2204181271372363, 7.43709297850728, 57.39552117884159, 60.46311177313328, 66.13359689712524, 60.754537135362625, 51.00440472364426, 52.44139641523361, 56.97617568075657, 58.22950042784214, 57.02441409230232, 55.61010338366032, 57.672948092222214, 56.99126087129116, 58.19248281419277, 48.73197466135025, 43.589421808719635, 42.017666548490524, 43.02789553999901, 42.56995551288128, 41.97735831141472, 41.05337329208851, 43.29522639513016, 42.66852222383022, 45.53546078503132, 43.26166279613972, 47.46620938181877, 44.388226345181465, 47.990550845861435, 46.720727384090424, 43.238989412784576, 45.06940059363842, 45.423773378133774, 43.34713540971279, 44.24427106976509, 44.67820778489113, 42.560923397541046, 44.72815230488777, 45.72198897600174, 40.67436642944813, 42.11109973490238, 42.74895250797272, 40.29906816780567, 41.11025243997574, 42.856114357709885, 42.88257233798504, 44.38478372991085, 51.21147841215134, 55.26281721889973, 56.73456184566021, 59.289913326501846, 55.68771801888943, 57.149218395352364, 59.65001620352268, 46.86668515205383, 38.32557186484337, 38.835329711437225, 38.60364094376564, 40.370546132326126, 38.75295013189316, 41.01480536162853, 45.188148021698, 55.13138227164745, 41.19903467595577, 39.761682003736496, 38.837104216217995, 39.37455877661705, 39.883355274796486, 37.8098901361227, 40.024939477443695, 40.69727540016174, 40.67180536687374, 40.96839465200901, 49.60774406790733, 61.7603013664484, 56.294564455747604, 56.43518730998039, 53.157692179083824, 48.543497174978256, 48.30632530152798, 47.554091066122055, 44.223641976714134, 40.71671895682812, 41.21550679206848, 37.659327015280724, 39.30916428565979, 39.375660717487335, 40.12814573943615, 41.2529119849205, 46.461406499147415, 46.98542878031731, 46.33003234863281, 44.14890378713608, 43.96293796598911, 48.576399609446526, 46.39058589935303, 52.45432332158089, 53.74443009495735, 56.06941893696785, 56.23029850423336, 53.73720668256283, 55.19452728331089, 55.924589708447456, 51.78456746041775, 52.36104212701321, 50.73152996599674, 49.440872222185135, 43.71404372155666, 44.97012332081795, 42.710464373230934, 43.72318983078003, 46.2278900295496, 44.19369198381901, 44.17172156274319, 47.20825642347336, 45.17942748963833, 45.54138466715813, 42.47040465474129, 46.970712170004845, 53.36763471364975, 57.503864765167236, 54.81036029756069, 63.46040993928909, 58.584868758916855, 68.3945743739605, 58.42941530048847, 63.63602511584759, 11.913261339068413, 0.14954251935705543, 4.910029079765081, 1.8707356858067214, 2.4066369608044624, 61.968123614788055, 76.20167344808578, 70.1579837501049, 72.83020555973053, 57.57154293358326, 76.14325538277626, 53.857926204800606, 37.336747124791145, 41.97924301028252, 70.86245074868202, 42.72591054439545, 0.43398676556535065, 0.20749733608681709, 0.2650178479962051, 0.1474115758901462, 0.22081526520196348, 0.14147607173072174, 0.12922781490487978], [0.015294084696506616, 0.05151562065293547, 0.02080176112940535, 0.058212612857460044, 0.014413471744774142, 0.06800992327043787, 0.03397932043299079, 0.19942265062127262, 0.16754374169977382, 1.2257771752774715, 55.435586348176, 56.78461275994778, 40.170255079865456, 67.79780119657516, 59.728979766368866, 40.42553298175335, 63.56702841818333, 55.35328656435013, 49.77958984673023, 57.8819976747036, 52.12860479950905, 63.15818175673485, 13.380830939859152, 0.2906881127273664, 3.4228610806167126, 3.043508199043572, 0.9068985830526799, 0.3116999758640304, 28.198351487517357, 53.153345212340355, 59.964213743805885, 53.33442449569702, 46.55815690755844, 49.137207716703415, 55.37740767002106, 55.59769704937935, 53.535756692290306, 51.57867930829525, 53.67341190576553, 54.08090963959694, 50.818389505147934, 43.194774985313416, 39.847887977957726, 37.97004394233227, 39.0032123029232, 38.657043278217316, 39.929849579930305, 38.11296947300434, 39.12539854645729, 39.7520837187767, 38.20378080010414, 39.66043643653393, 37.4837726354599, 37.92369402945042, 39.61540125310421, 40.05113527178764, 41.356220841407776, 39.68996085226536, 43.41987870633602, 40.340421348810196, 43.290670439600945, 42.12287910282612, 39.64328795671463, 37.92845517396927, 41.42056658864021, 38.926509618759155, 37.92011082172394, 40.08511304855347, 37.88731098175049, 38.3585274964571, 38.52962851524353, 37.94866628944874, 42.072026431560516, 52.82521761953831, 51.8132559210062, 51.2022715061903, 51.873551085591316, 51.1477330327034, 49.09805081784725, 53.81959766149521, 48.22175703942776, 39.06754285097122, 36.73354469239712, 39.250085055828094, 38.505640402436256, 38.4817510843277, 39.86451968550682, 40.66167891025543, 48.909349143505096, 41.964921578764915, 39.15510915219784, 38.74650187790394, 39.60384227335453, 39.904774725437164, 40.6583046913147, 38.070320561528206, 40.963154733181, 40.708279609680176, 42.65026420354843, 52.025717720389366, 54.79245945811272, 53.51673871278763, 51.172914281487465, 50.154568925499916, 49.41427364945412, 41.468691006302834, 40.87061449885368, 40.421748384833336, 38.0836958438158, 39.001559391617775, 36.76944136619568, 36.155189126729965, 37.54573591053486, 38.901522159576416, 36.664031222462654, 38.746080100536346, 39.30977985262871, 40.37557326257229, 39.828250631690025, 40.36118723452091, 42.429009675979614, 43.2409805059433, 48.31979937851429, 49.46001939475536, 50.85212029516697, 50.59856370091438, 51.46499700844288, 49.93482671678066, 49.32026669383049, 47.510298416018486, 44.65857423841953, 41.39612630009651, 40.55118463933468, 39.95922580361366, 38.95529307425022, 38.34956377744675, 39.58662539720535, 39.52203646302223, 37.63562008738518, 37.527390494942665, 38.773545026779175, 40.7772421091795, 43.372658640146255, 40.028119906783104, 42.54831187427044, 46.82357266545296, 51.40151001513004, 55.59750325977802, 55.08567072451115, 56.596154272556305, 59.984561651945114, 60.12539729475975, 51.203305050730705, 1.4766916050575674, 0.14100074098678306, 3.4102949174121022, 0.8645649359095842, 5.4459029249846935, 60.36111384630203, 56.52072452008724, 56.893343925476074, 44.95445676147938, 44.89982709288597, 53.28307405114174, 38.35575744509697, 34.59734492003918, 30.465756319463253, 54.806427508592606, 14.497103691101074, 0.29160258709453046, 0.053615980214090087, 0.027711237635230646, 0.04535505278909113, 0.017212510465469677, 0.025286628188041504, 0.0793533239630051, 0.02638228306750534, 0.031274963985197246, 0.05113973398692906, 0.07233431388158351, 0.024514187898603268, 0.01961006306373747, 0.04947510788042564, 0.2307496391586028, 0.1631846631062217, 2.5009474251419306, 64.99191015958786, 63.24072852730751, 45.73048911988735, 75.10923206806183, 64.93439644575119, 47.967569679021835, 68.95809173583984, 60.27365393936634, 54.53411132097244, 64.68528181314468, 57.42256432771683, 67.04297930002213, 12.994992043823004, 0.49878290737979114, 2.169828680343926, 5.600456781685352, 0.8969115314539522, 0.2909503283444792, 33.42444285750389, 54.55717608332634, 60.563490986824036, 55.977710857987404, 48.20579029619694, 50.76179914176464, 58.59925098717213, 56.21321462094784, 56.21846213936806, 53.662145510315895, 55.26475511491299, 55.44579640030861, 53.51932257413864, 44.51793238520622, 42.464279383420944, 39.35142561793327, 41.02993614971638, 39.543759897351265, 42.079641222953796, 39.94820639491081, 41.18758589029312, 39.95752349495888, 40.75217865407467, 40.606612265110016, 39.189527705311775, 40.33185660839081, 42.90486194193363, 42.14336760342121, 44.630011171102524, 40.939869582653046, 44.997622445225716, 42.946017533540726, 45.533382296562195, 42.640646919608116, 40.49107566475868, 39.40548151731491, 42.39245183765888, 39.94426980614662, 40.97227044403553, 41.921273320913315, 39.608778208494186, 40.5391088873148, 40.84794491529465, 38.56074504554272, 42.98519343137741, 53.87485809624195, 52.51087948679924, 53.35886858403683, 54.77602154016495, 53.7930940836668, 52.72782124578953, 56.40857733786106, 47.37419731914997, 38.99593569338322, 36.56531631946564, 38.833570405840874, 38.61967608332634, 38.914316073060036, 39.79351669549942, 41.806116700172424, 48.9562614262104, 41.01075477898121, 39.48412969708443, 38.06675635278225, 39.42164584994316, 39.73354451358318, 38.85907843708992, 38.01751099526882, 41.1393778771162, 40.85916191339493, 42.48710095882416, 52.59987831115723, 54.99548256397247, 55.324187725782394, 51.79403655230999, 52.24133715033531, 50.24829849600792, 42.732905969023705, 44.15254019200802, 42.362999618053436, 41.8279617279768, 39.73197139799595, 37.586302533745766, 38.6127794533968, 39.960384741425514, 39.00808364152908, 39.62984807789326, 40.82681804895401, 41.447176560759544, 42.06547558307648, 42.26420111954212, 41.722053810954094, 44.37821768224239, 45.808593928813934, 49.21688184142113, 50.33910222351551, 52.638970613479614, 52.26298838853836, 54.3069177120924, 52.51225121319294, 51.24609835445881, 49.01112288236618, 49.5210213214159, 44.26143854856491, 43.44849497079849, 41.13925628364086, 41.33963093161583, 41.115625351667404, 41.13814294338226, 40.908107087016106, 41.31497785449028, 39.43721741437912, 42.5097743421793, 43.73859040439129, 44.27512161433697, 42.619086876511574, 44.706580862402916, 49.72405582666397, 54.476643204689026, 58.065049052238464, 59.91349786520004, 59.96528908610344, 63.84296581149101, 63.21931667625904, 53.007892817258835, 1.676247634459287, 0.29523780453018844, 3.8251711428165436, 0.8022982114925981, 6.332016326487064, 67.45630592107773, 62.59503297507763, 62.08866834640503, 50.51664009690285, 46.728771552443504, 59.48380932211876, 44.374771267175674, 34.18470986187458, 34.942073822021484, 62.31071703135967, 19.67426508665085, 0.3751572535838932, 0.008555251133657293, 0.04704420316556934, 0.04474847693927586, 0.049244025358348154, 0.072073137271218, 0.07202447464806028, 0.09311028537922539, 0.09414619737071916, 0.16394466685596853, 0.1742652544635348, 0.1463129895273596, 0.15304349712096155, 0.19183545227861032, 0.3315367817413062, 0.27451959438622, 2.201912496238947, 74.05305594205856, 73.53113874793053, 52.198395654559135, 78.47766011953354, 66.62510052323341, 53.88785719871521, 74.79883432388306, 66.9455449283123, 62.14083194732666, 73.6292190849781, 61.361573562026024, 73.76734167337418, 15.124642867594957, 0.6208181090187281, 9.798366073518991, 10.949471555650234, 1.3376042246818542, 0.9053388854954392, 40.294398218393326, 55.310117080807686, 66.02723300457001, 59.25303630530834, 52.260377928614616, 52.719020918011665, 62.133749127388, 59.486480578780174, 56.50392182171345, 55.30941031873226, 57.82250426709652, 58.05424623191357, 58.52806180715561, 46.91738203167915, 44.30699050426483, 42.009854167699814, 43.65074671804905, 42.3639989644289, 45.793227553367615, 42.722684517502785, 43.8590819388628, 44.43999856710434, 42.83205784857273, 44.25442032516003, 41.22086450457573, 42.45228722691536, 45.41535682976246, 45.399412885308266, 47.04052582383156, 44.071038365364075, 46.91395081579685, 44.54070456326008, 49.17834430932999, 44.60247024893761, 42.7150659263134, 40.48663750290871, 45.140775963664055, 42.65762060880661, 41.50326155126095, 45.389164835214615, 40.62338836491108, 43.35185095667839, 43.04792806506157, 41.37508682906628, 45.8894307911396, 57.436213195323944, 55.57213582098484, 57.531869262456894, 56.92604877054691, 56.845436096191406, 54.04766142368317, 58.00440810620785, 50.04161238670349, 38.9640212059021, 34.59901303052902, 39.85350787639618, 38.411356061697006, 37.898885160684586, 40.316220447421074, 41.16884149610996, 50.70210434496403, 41.701413318514824, 39.59037959575653, 39.40052278339863, 40.75008116662502, 39.97811459004879, 40.16286447644234, 37.53538526594639, 41.35265663266182, 41.568302661180496, 42.24527433514595, 55.77553890645504, 58.19168105721474, 59.30870711803436, 55.89186206459999, 56.1816269159317, 53.10800604522228, 44.55440282821655, 46.858059614896774, 43.5362284630537, 43.065752908587456, 42.84349903464317, 41.391900926828384, 40.1378808170557, 42.130189910531044, 42.94374905526638, 41.046457663178444, 43.68058651685715, 42.6787056773901, 43.92427124083042, 44.823682978749275, 42.968303337693214, 46.94947890937328, 49.08787116408348, 51.52350626885891, 54.01662088930607, 54.58017624914646, 54.35730300843716, 55.98846048116684, 54.635394886136055, 55.721904784440994, 52.47661292552948, 51.91156044602394, 47.56131447851658, 45.64067713916302, 43.7215331196785, 44.026884734630585, 42.67337456345558, 45.64616024494171, 44.17350746691227, 42.965825870633125, 41.59644015133381, 45.4454930126667, 46.22885897755623, 47.4909308552742, 45.48727177083492, 47.637485191226006, 51.5816355496645, 57.68212080001831, 61.947217136621475, 62.494193986058235, 62.529136911034584, 67.61066883802414, 63.861592411994934, 57.78291039168835, 2.707158559933305, 0.1573052949970588, 12.138995826244354, 1.674631533678621, 7.4439155124127865, 70.72272464632988, 68.73077273368835, 65.74847996234894, 58.170481994748116, 59.65271405875683, 64.32589709758759, 52.12330408394337, 45.795621424913406, 43.48704770207405, 74.36276212334633, 25.6583321839571, 0.5398698057979345, 0.18704457732383162, 0.2015718657639809, 0.12652059376705438, 0.13645323109813035, 0.2847606089198962, 0.19913285679649562], [0.04840546898776665, 0.07759533196804114, 0.06227728517842479, 0.05071309184131678, 0.05458899890072644, 0.027318225911585614, 0.04294021928217262, 0.023292427285923623, 0.2754083904437721, 0.18922384944744408, 34.335903748869896, 61.72656297683716, 39.33097131550312, 34.26467277109623, 35.43806120753288, 40.295872539281845, 54.74009446799755, 61.08387306332588, 55.0687350332737, 63.86471584439278, 52.26217523217201, 61.65812864899635, 34.32529851794243, 0.5336002609692514, 1.1415947112254798, 1.8089087284170091, 0.4451643110951409, 0.5111330165527761, 14.24388812854886, 56.4530273526907, 61.88380993902683, 49.41351369023323, 48.43869499862194, 53.91830876469612, 56.67312674224377, 52.98220619559288, 53.367794305086136, 55.49008682370186, 54.731305539608, 52.754822596907616, 46.06739804148674, 40.651278868317604, 38.52915734052658, 40.02107508480549, 37.25368358194828, 40.149109214544296, 39.03824642300606, 38.91621597111225, 37.80926316976547, 38.63498546183109, 37.8519044816494, 38.90165135264397, 37.823501005768776, 39.072398990392685, 38.4350173920393, 38.524555787444115, 40.12414835393429, 40.647437274456024, 41.44530326128006, 41.08419343829155, 42.72040843963623, 40.66622346639633, 38.99429038167, 39.35904420912266, 38.68869557976723, 37.98057317733765, 37.099377661943436, 38.013338819146156, 37.093442380428314, 37.814229503273964, 37.379605025053024, 37.5774110108614, 45.6782229244709, 51.67466215789318, 51.11655570566654, 50.1519850641489, 48.18017207086086, 48.242180943489075, 51.25332936644554, 54.28334377706051, 50.207074508070946, 37.838643193244934, 38.25198881328106, 40.1937036216259, 40.55153802037239, 38.14186692237854, 40.25306783616543, 42.091466188430786, 49.173773154616356, 40.08895844221115, 39.54295054078102, 39.909387677907944, 40.9953998029232, 39.699528738856316, 39.33559186756611, 39.41958636045456, 40.15420854091644, 39.958747029304504, 43.45092684030533, 53.37760157883167, 53.69162432849407, 50.00897213816643, 51.3351009786129, 50.627301558852196, 49.73628357052803, 46.627001613378525, 38.712660893797874, 38.16236302256584, 40.24605721235275, 38.52123096585274, 37.375334054231644, 37.58201636373997, 37.18045771121979, 37.271394431591034, 37.97248341143131, 37.92224630713463, 38.727993071079254, 39.24443855881691, 41.68007746338844, 40.72233505547047, 41.2742630392313, 43.982001543045044, 46.835978999733925, 48.41376453638077, 48.09398889541626, 47.891995534300804, 47.01284050941467, 47.52464644610882, 44.40487325191498, 42.95037969946861, 39.64977040886879, 39.19920198619366, 37.63741739094257, 38.53804126381874, 37.87787988781929, 36.870804727077484, 40.13767562806606, 39.85568895936012, 38.73591564595699, 40.20293712615967, 38.112844079732895, 41.419958621263504, 41.66261740028858, 39.94662947952747, 40.5121835321188, 46.90874509513378, 51.06625020503998, 55.37891238927841, 56.702658757567406, 59.518672451376915, 56.63597233593464, 64.95572090148926, 26.883249655365944, 0.12371466698823497, 0.1006809932005126, 1.349842061754316, 0.24370211991481483, 11.752866245806217, 66.43468514084816, 54.83597472310066, 56.10707871615887, 53.78197968006134, 70.5120487511158, 50.755989253520966, 37.814829871058464, 31.889047846198082, 32.50857800245285, 51.316504776477814, 7.755747679620981, 0.561916638398543, 0.11554620374226943, 0.024252523326140363, 0.048123567903530784, 0.07686864322749898, 0.08679712453158572, 0.014662766570836538, 0.09193940641125664, 0.04035211284644902, 0.07874756818637252, 0.008286759730253834, 0.07564464875031263, 0.02936393371783197, 0.03495845441648271, 0.04725030128611252, 0.3371470025740564, 0.2429701545042917, 44.65694032609463, 69.25548657774925, 43.23245756328106, 49.336469024419785, 48.55110056698322, 45.54450809955597, 62.673415169119835, 67.22201809287071, 60.030577182769775, 66.90121650695801, 58.461162596940994, 67.16958090662956, 37.58605554699898, 0.28400005598086864, 1.7067375546321273, 5.241311453282833, 3.471656874753535, 0.40110074740368873, 18.731966949999332, 59.00304012000561, 62.528829127550125, 50.787573158741, 50.33865384757519, 56.185187324881554, 56.33368335664272, 53.454429656267166, 54.75187763571739, 55.837190598249435, 57.82414957880974, 54.94318976998329, 49.534521996974945, 42.6968003064394, 40.160880982875824, 41.08025684952736, 39.92395229637623, 42.20116630196571, 41.22455410659313, 41.90465301275253, 40.251924097537994, 40.1191022247076, 41.1602957546711, 39.69817981123924, 38.99001941084862, 41.11334927380085, 40.87590001523495, 40.92943154275417, 42.231652066111565, 42.37542875111103, 42.79931880533695, 44.36025604605675, 43.13151977956295, 43.61583799123764, 39.55215744674206, 41.09937742352486, 40.84238201379776, 40.12879550457001, 39.040233716368675, 38.662590980529785, 38.134077340364456, 39.20873187482357, 39.08776916563511, 40.92917315661907, 48.76093290746212, 53.165633752942085, 54.55866560339928, 52.22765028476715, 51.72691695392132, 53.81928227841854, 51.93770684301853, 55.642329454422, 50.09734399616718, 37.383849397301674, 37.61467941105366, 39.77736756205559, 40.38908153772354, 38.23644004762173, 40.02629220485687, 43.48187617957592, 50.7134011387825, 39.172831401228905, 40.1082956045866, 38.68025243282318, 39.81175571680069, 38.63452948629856, 40.18667779862881, 40.06485253572464, 39.9973301589489, 38.43657910823822, 43.407464772462845, 55.08257769048214, 55.19778370857239, 51.74155376851559, 53.36003132164478, 52.44075424969196, 52.16330833733082, 47.41667903959751, 41.359557062387466, 39.44453202188015, 40.8376170694828, 40.50066635012627, 39.3312107026577, 40.43576963245869, 39.14947025477886, 38.91490504145622, 39.52708639204502, 40.550143495202065, 41.261009350419044, 41.22146487236023, 43.42408128082752, 42.45438851416111, 44.52696070075035, 47.18214802443981, 47.54328824579716, 49.43680264055729, 49.51019190251827, 49.73039008677006, 49.71024736762047, 48.77582810819149, 46.44376024603844, 46.00329168140888, 41.40406787395477, 41.571578085422516, 40.32538175582886, 41.66542164981365, 40.76431140303612, 39.74707178771496, 42.24043719470501, 41.96363724768162, 41.50826208293438, 42.100570499897, 40.45148938894272, 43.110050931572914, 43.83113443851471, 43.24943505227566, 42.243838012218475, 48.12901921570301, 53.2756682485342, 59.53832879662514, 59.58258502185345, 61.49243474006653, 59.24650065600872, 66.11174046993256, 31.265434809029102, 0.06053306373360101, 0.9825925994664431, 2.0822125067934394, 0.4508776607690379, 12.485807966440916, 72.35294356942177, 61.472478210926056, 61.44437111914158, 57.16073177754879, 71.37217059731483, 53.64129222929478, 44.376845955848694, 33.4270229190588, 37.27357551455498, 60.211470276117325, 11.224193964153528, 0.5262017017230392, 0.10664237604942173, 0.12362942390609533, 0.017773164072423242, 0.024130226665874943, 0.13099659030558541, 0.08393935131607577, 0.14304801472462714, 0.18101165886037052, 0.21620096202241257, 0.16661044646752998, 0.216515053762123, 0.0595455175061943, 0.2004229766316712, 0.14904450858011842, 0.4298147378722206, 0.46220250776968896, 48.555971905589104, 80.14727532863617, 52.320574298501015, 45.88293693959713, 46.724553778767586, 54.68438185751438, 64.99489679932594, 73.74426931142807, 65.73208764195442, 73.38056042790413, 63.067256435751915, 69.85129460692406, 42.90043517947197, 0.5620379350148141, 5.133549235761166, 11.035476140677929, 2.3907547630369663, 0.3969198139384389, 22.333746179938316, 59.08179089426994, 65.11249288916588, 55.511392280459404, 53.476939648389816, 59.132248386740685, 58.89617085456848, 55.925969034433365, 56.36225402355194, 59.024569764733315, 61.95785276591778, 57.89585933089256, 51.42105996608734, 45.21114058792591, 43.44390481710434, 44.44591484963894, 42.63335131108761, 45.93703843653202, 41.94546282291412, 44.663703963160515, 42.2875090688467, 44.14951175451279, 44.190629348158836, 43.479546904563904, 41.561098247766495, 45.475765988230705, 44.841545820236206, 43.47719103097916, 46.131398007273674, 47.62194782495499, 47.07243651151657, 46.478247195482254, 46.66619651019573, 44.78092387318611, 40.22326223552227, 44.27625015377998, 44.45062279701233, 43.27719256281853, 41.69623799622059, 41.57423414289951, 41.777732223272324, 41.44570603966713, 41.352679431438446, 42.26860888302326, 49.92421768605709, 58.965391740202904, 56.131910383701324, 53.843543976545334, 53.75614866614342, 55.17794497311115, 53.90854708850384, 58.091263845562935, 53.92126880586147, 39.79578897356987, 37.672516107559204, 39.44640152156353, 40.97787134349346, 37.27523982524872, 41.014026403427124, 45.13568043708801, 52.27623447775841, 39.656085669994354, 40.29435642063618, 40.60310125350952, 41.05863980948925, 38.8937933743, 39.58516627550125, 39.72951292991638, 40.43302997946739, 38.633332550525665, 43.34425136446953, 58.10771696269512, 58.54427933692932, 55.372946709394455, 59.3856567889452, 56.26783289015293, 53.44702385365963, 48.812541738152504, 44.777435660362244, 41.79585725069046, 42.502687722444534, 42.255131006240845, 41.2115778028965, 41.85842849314213, 40.91062255203724, 42.47243754565716, 41.69454328715801, 43.289625495672226, 44.14142198860645, 43.29627513885498, 47.093928158283234, 45.393511801958084, 47.302331775426865, 49.8949858546257, 51.27944156527519, 53.04555259644985, 51.4285683631897, 51.30142338573933, 51.77170895040035, 50.64331389963627, 49.1484285145998, 49.02968488633633, 43.6450432240963, 43.83982837200165, 42.22285933792591, 44.38984125852585, 41.98886789381504, 39.82893079519272, 45.834679529070854, 43.989300951361656, 43.66521634161472, 45.62388963997364, 42.70481027662754, 46.13810084760189, 47.28433974087238, 44.96346987783909, 45.46366363763809, 52.58046895265579, 54.862672090530396, 62.98939101397991, 62.45387054979801, 63.353745862841606, 63.35183836519718, 67.42254093289375, 37.08625316619873, 0.17978491843678057, 1.6701469430699944, 5.658420771360397, 0.7808053772896528, 15.592689402401447, 78.91155883669853, 66.18218868970871, 65.86783915758133, 66.80820509791374, 79.78558033704758, 62.91484661400318, 52.846507877111435, 40.844958275556564, 46.40349380671978, 72.5560350716114, 17.226100154221058, 0.7884303212631494, 0.16743531392421573, 0.26157229382079095, 0.12121077947085723, 0.15156976995058358, 0.22935211571166292, 0.20773369527887553], [0.07497328711906448, 0.028834344557253644, 0.100088744511595, 0.04496559966355562, 0.0950634473701939, 0.1317976348218508, 0.0854966591577977, 0.05124582028656732, 0.29217288305517286, 0.004839418834308162, 7.992581371217966, 66.54498562216759, 46.28416880965233, 24.224906601011753, 15.7201611623168, 29.044370390474796, 49.6231484413147, 56.81135572493076, 56.861976608633995, 63.01410868763924, 57.1579959243536, 54.83782522380352, 51.78132243454456, 2.2900903271511197, 1.239293406251818, 3.8861505081877112, 2.40685046184808, 0.10781685443362221, 2.9176667891442776, 54.51939471065998, 62.412293180823326, 55.456169843673706, 50.46061970293522, 58.12423087656498, 55.59052303433418, 51.91996179521084, 54.492541551589966, 57.002344876527786, 54.36054043471813, 52.356410175561905, 43.91137853264809, 37.67701506614685, 38.45750078558922, 40.38422539830208, 44.73715402185917, 49.722319319844246, 45.8086509257555, 46.153026446700096, 37.87921741604805, 39.01083089411259, 37.98634506762028, 37.64099679887295, 37.1531979739666, 37.46658615767956, 37.25621044635773, 39.03980053961277, 38.6531712859869, 39.92245517671108, 40.5339677631855, 38.5926329344511, 38.86728219687939, 42.88194917142391, 38.774437978863716, 38.34184259176254, 38.384936079382896, 38.85175622999668, 39.197537675499916, 38.09958279132843, 36.71108029782772, 37.380832359194756, 37.630456164479256, 43.18912088871002, 49.06304709613323, 49.436019882559776, 50.09706661105156, 49.306910410523415, 50.40358476340771, 51.29028618335724, 51.416602805256844, 52.62432999908924, 49.84512113034725, 40.316547229886055, 38.76411013305187, 39.303996562957764, 39.17986482381821, 41.278906390070915, 38.51324379444122, 41.96253530681133, 49.02529612183571, 41.704673543572426, 40.33636316657066, 40.37977583706379, 40.03273285925388, 39.67976599931717, 40.8617951720953, 40.624182522296906, 40.515147373080254, 41.68042704463005, 46.529707834124565, 55.11218950152397, 53.44821698963642, 51.96334406733513, 49.03904378414154, 48.89438174664974, 46.07033148407936, 51.164322942495346, 41.23553931713104, 38.0274398624897, 37.11923539638519, 39.091101586818695, 37.89981611073017, 40.371093302965164, 38.48082773387432, 40.37819892168045, 38.417450934648514, 40.8001396805048, 39.00824323296547, 38.79647299647331, 39.69495378434658, 40.51637850701809, 40.87035611271858, 43.6015697568655, 45.01714579761028, 44.75146405398846, 43.986504301428795, 44.164380356669426, 44.177843034267426, 43.39392989873886, 41.37131743133068, 40.25806836783886, 38.72990816831589, 39.531095176935196, 37.227670177817345, 38.33960071206093, 39.804840087890625, 40.13339705765247, 40.46320416033268, 43.36928442120552, 40.923910439014435, 43.027481362223625, 40.775053426623344, 40.075138583779335, 39.64250899851322, 42.0347086340189, 40.55854484438896, 44.13935489952564, 47.21099607646465, 58.22395272552967, 55.60999318957329, 63.039137944579124, 52.323747128248215, 62.80101992189884, 10.029183737933636, 0.17284019733779132, 0.778900432633236, 0.6469675339758396, 0.31035906344186515, 22.072641290724277, 65.84861218929291, 51.73103593289852, 63.64971958100796, 61.035889238119125, 63.26439745724201, 52.82946579158306, 31.01526953279972, 57.93103024363518, 46.006844490766525, 46.22611552476883, 4.0312302857637405, 0.3285599680384621, 0.16132816585013643, 0.09347152576083317, 0.07037054660031572, 0.12015847343718633, 0.09687814686913043, 0.026189140990027227, 0.11080980984843336, 0.10801425829413347, 0.07455653409124352, 0.012313548195379553, 0.14756474032765254, 0.08632421318907291, 0.054183489410206676, 0.07289707704330795, 0.616530692204833, 0.1142865713336505, 15.498349964618683, 72.91806444525719, 48.43864940106869, 28.233883380889893, 29.33629922568798, 41.221597865223885, 54.5991600304842, 61.84520021080971, 62.67480209469795, 68.67959707975388, 62.083356231451035, 60.01459904015064, 57.185449451208115, 2.3534547770395875, 1.0276865609921515, 3.078261846676469, 5.18375214189291, 0.08323365793330595, 4.290325557813048, 57.00661204755306, 63.01659755408764, 57.8264332562685, 51.32608786225319, 59.87866133451462, 56.40767678618431, 54.47501689195633, 55.08456118404865, 58.09922821819782, 55.987350940704346, 54.62290495634079, 45.4921393096447, 41.37466885149479, 40.206622928380966, 41.29565969109535, 46.597743183374405, 50.62495708465576, 48.24361726641655, 48.5135243833065, 41.070726960897446, 41.19417853653431, 40.00040799379349, 40.0562459975481, 38.53942818939686, 40.007449015975, 40.30828267335892, 41.72931522130966, 41.13729938864708, 40.40443651378155, 42.01966904103756, 42.23944924771786, 42.35136464238167, 41.604282930493355, 40.53686700761318, 41.41984082758427, 39.99302119016647, 39.875740483403206, 41.814160868525505, 39.04840707778931, 39.03549537062645, 37.95694224536419, 40.082358196377754, 44.22552287578583, 52.96387977898121, 52.96510711312294, 53.6629244685173, 50.31123071908951, 52.43978530168533, 54.12178784608841, 52.92852267622948, 55.2712831646204, 52.01651841402054, 40.550265088677406, 37.188900858163834, 39.48116585612297, 37.64119818806648, 40.21095849573612, 38.2560545951128, 40.98219931125641, 51.177192851901054, 41.58701665699482, 39.3533331155777, 38.72578538954258, 39.779457449913025, 39.9530853331089, 40.591990649700165, 38.700501546263695, 40.3345962613821, 40.87968461215496, 45.730234533548355, 56.71069152653217, 53.56517471373081, 54.88545186817646, 51.06765612959862, 51.36242911219597, 48.539036214351654, 51.882184222340584, 44.67919573187828, 39.82501320540905, 38.52512575685978, 41.47280618548393, 40.06269425153732, 41.69886365532875, 40.69399617612362, 42.9509686678648, 40.453845262527466, 41.52869738638401, 39.70082066953182, 43.14707614481449, 41.695052459836006, 41.81786946952343, 44.65018808841705, 45.64792335033417, 46.82165376842022, 47.439432218670845, 45.80003298819065, 47.87081927061081, 46.09488196671009, 45.224675461649895, 43.0528412014246, 42.46646046638489, 40.434542298316956, 41.64859615266323, 41.0972685366869, 40.77678233385086, 41.1800204962492, 42.38720051944256, 43.07747907936573, 45.977612659335136, 42.498238161206245, 44.81210500001907, 43.35839420557022, 42.40136995911598, 41.64587549865246, 44.358709529042244, 42.06932097673416, 45.3666016459465, 51.13591566681862, 60.25828376412392, 57.7206127345562, 64.70411360263824, 53.79059001803398, 65.58272525668144, 11.386835686862469, 0.14847924438072369, 2.4474329967051744, 1.798701526131481, 0.2020374298444949, 23.439393751323223, 71.48380860686302, 56.63755685091019, 66.49753376841545, 68.51706460118294, 69.392469227314, 59.17151927947998, 41.23897813260555, 56.78491294384003, 48.39151673018932, 54.427223056554794, 6.053188713267446, 0.512818107381463, 0.1511809290968813, 0.13688455248484388, 0.032963769263005815, 0.030691578394907992, 0.050270178107894026, 0.017070572866941802, 0.23072452488122508, 0.2170812085387297, 0.1491773233283311, 0.12294074796955101, 0.24469422292895615, 0.20717430888907984, 0.26850306254345924, 0.34207388351205736, 0.9142996952868998, 0.5643188813701272, 17.751910239458084, 88.22579383850098, 61.28957882523537, 35.1576704531908, 25.278875045478344, 45.36396078765392, 67.64748886227608, 68.81710410118103, 69.91724386811256, 74.39316809177399, 67.93843165040016, 66.08695060014725, 63.24111230671406, 3.1665857322514057, 2.9607602767646313, 10.244828816503286, 5.268676159903407, 0.1687091658823192, 5.689817536622286, 60.249551832675934, 65.55737301707268, 60.70230893790722, 52.87447437644005, 64.48048800230026, 57.41647705435753, 58.901087790727615, 56.169703155756, 62.01804153621197, 58.47059369087219, 58.19146826863289, 48.248450607061386, 44.50540065765381, 44.37781110405922, 46.75611108541489, 47.89287708699703, 55.406612902879715, 50.59431552886963, 51.39900214970112, 44.67284247279167, 43.41208152472973, 43.99939700961113, 42.146688625216484, 41.456398665905, 41.67293384671211, 43.03955711424351, 42.410907447338104, 43.431715071201324, 42.633906081318855, 45.52142433822155, 43.5278233140707, 43.848127126693726, 45.467292442917824, 44.22531768679619, 43.147482722997665, 42.78301768004894, 43.14013011753559, 42.95169822871685, 43.91074396669865, 41.27654671669006, 40.96136502921581, 43.48810404539108, 47.27545961737633, 55.82492105662823, 54.11883160471916, 57.61905938386917, 53.185837268829346, 57.21258759498596, 55.49516715109348, 55.74759900569916, 57.6923156529665, 55.725970566272736, 40.038523748517036, 36.82649150490761, 39.14730817079544, 37.91333198547363, 40.72799675166607, 37.96139180660248, 41.95267103612423, 53.62238064408302, 42.63284973800182, 40.58745749294758, 40.098609924316406, 39.510633274912834, 40.25773398578167, 40.9187351167202, 38.890783935785294, 41.05728708207607, 41.61124795675278, 47.24827967584133, 58.24634492397308, 55.03299415111542, 58.18172559142113, 55.22598199546337, 54.251372292637825, 51.09291337430477, 56.987833455204964, 47.619778141379356, 43.364553675055504, 40.711965411901474, 46.094243600964546, 40.90304955840111, 44.12580482661724, 41.819305792450905, 46.180954948067665, 43.044648841023445, 43.73294770717621, 42.14724339544773, 44.39922675490379, 44.40948240458965, 44.86441299319267, 46.97811417281628, 48.41572903096676, 49.347830414772034, 49.36074212193489, 49.30333100259304, 50.09982526302338, 49.53761883080006, 48.43715988099575, 46.09597630798817, 46.13366648554802, 42.20454052090645, 43.544470220804214, 43.57674948871136, 42.04441711306572, 43.56799855828285, 45.96414238214493, 43.52985240519047, 49.22623313963413, 45.06341591477394, 49.41654212772846, 45.94952456653118, 47.55013167858124, 44.955543503165245, 46.43893450498581, 47.20878839492798, 49.60710950195789, 51.67024299502373, 64.71940398216248, 60.40852390229702, 68.37732329964638, 54.45170894265175, 67.81175404787064, 14.328591283410788, 0.24758306244621053, 3.058234308846295, 7.2459556348621845, 0.656746665481478, 26.400160677731037, 78.4457266330719, 62.5639658421278, 73.6998800933361, 70.0541353225708, 74.50164467096329, 65.90626269578934, 46.59391678869724, 65.62497138977051, 57.53878489136696, 67.87049129605293, 9.521500580012798, 0.806563482619822, 0.33450371003709733, 0.3273161285324022, 0.16012048377888277, 0.25531254534143955, 0.3023707342799753, 0.10843715630471706], [0.06479381889221258, 0.06394996729795821, 0.046236175039666705, 0.09411156876012683, 0.035415472666500136, 0.034386418119538575, 0.04252906575857196, 0.12155155884101987, 0.18779756035655737, 0.012304853007663041, 3.909504530020058, 58.077535182237625, 49.739775583148, 41.117624044418335, 18.84009774774313, 28.977001905441284, 47.56736375391483, 57.10176274180412, 61.553239077329636, 59.948790371418, 58.43564696609974, 52.28423684835434, 54.89719323813915, 11.144968215376139, 0.9326271212194115, 4.752573128789663, 4.042502855882049, 0.4147114686202258, 0.2725856762845069, 26.2764735147357, 65.1352308690548, 59.298033490777016, 55.34915618598461, 56.86719752848148, 52.945009991526604, 57.136477679014206, 55.31833603978157, 55.11850096285343, 54.23864297568798, 45.02126857638359, 39.02719281613827, 39.55790273845196, 38.87124538421631, 48.58982428908348, 52.354833260178566, 53.714050725102425, 51.020576655864716, 48.28120104968548, 42.59656548500061, 38.99908572435379, 37.305816784501076, 38.43801163136959, 36.16466201841831, 38.10957245528698, 36.584007516503334, 36.11850969493389, 36.40605166554451, 38.57997581362724, 38.62268552184105, 38.74250449240208, 39.00472082197666, 40.548995956778526, 40.18597483634949, 42.395601868629456, 38.72903801500797, 39.66515198349953, 38.51264342665672, 39.03696969151497, 35.80427035689354, 37.3678332567215, 40.01055724918842, 47.059053629636765, 52.14153550565243, 50.199965089559555, 50.30697874724865, 51.0063274204731, 49.898607060313225, 52.232757210731506, 51.82751275599003, 53.46878528594971, 50.28897151350975, 40.507954359054565, 39.08775396645069, 38.454624339938164, 38.712926879525185, 39.305816665291786, 38.276793882250786, 42.005431205034256, 50.12947127223015, 41.89827315509319, 38.79231981933117, 39.539325535297394, 39.529491662979126, 39.01100568473339, 39.205023273825645, 42.23395474255085, 39.709632396698, 40.018688812851906, 44.66756835579872, 56.30504809319973, 51.323519200086594, 54.06268201768398, 49.97390761971474, 48.26937608420849, 49.28943894803524, 48.30072820186615, 47.55628354847431, 39.88437741994858, 36.476184502243996, 39.65348660945892, 37.91631482541561, 39.68966826796532, 38.10064673423767, 38.121617808938026, 40.33265836536884, 40.877682119607925, 37.302206978201866, 39.493921771645546, 38.200653567910194, 41.08005166053772, 41.490061059594154, 41.82347036898136, 43.45778167247772, 42.38308534026146, 42.367517575621605, 40.98500356078148, 40.83480902016163, 38.89821253716946, 37.79343321919441, 37.902897745370865, 37.70994409918785, 40.50754398107529, 38.041936084628105, 37.65384390950203, 38.94205458462238, 43.909987807273865, 46.794105246663094, 48.43538157641888, 46.35861821472645, 47.7670506387949, 45.36273345351219, 44.95735600590706, 39.72409062087536, 39.34622369706631, 40.85232228040695, 43.064920753240585, 44.42200653254986, 56.969613432884216, 55.89569225907326, 61.01205311715603, 50.24907745420933, 55.42929768562317, 2.4889799673110247, 0.12377022416330874, 1.115566345397383, 0.1046701631275937, 0.19854725775076076, 31.702331565320492, 64.18697655200958, 55.480617731809616, 62.2243020683527, 58.59705090522766, 63.44355784356594, 47.18675717711449, 30.36223467439413, 52.80306860804558, 56.035475358366966, 37.27465085685253, 0.9856120718177408, 0.21123332233401015, 0.022266306077654008, 0.03415968829358462, 0.14654388651251793, 0.08948936912929639, 0.037343798685469665, 0.058312416877015494, 0.14739750477019697, 0.0553080732061062, 0.033139680526801385, 0.06209698040038347, 0.04494288623391185, 0.06512945517897606, 0.051744087104452774, 0.056774761105771177, 0.475539198378101, 0.05673873354680836, 5.400817869231105, 67.32464298605919, 54.16053056716919, 38.79185624420643, 18.920474834740162, 38.612494468688965, 58.342722952365875, 62.06373408436775, 64.13933470845222, 62.724153846502304, 64.32192251086235, 59.05000180006027, 62.30952009558678, 10.715314820408821, 1.0121947922743857, 5.5558115523308516, 5.870573362335563, 1.8179280194453895, 0.39441082044504583, 30.798388570547104, 66.22031584382057, 60.58856204152107, 56.64767570793629, 58.129330202937126, 54.6559251844883, 59.60024267435074, 57.17149280011654, 59.10100646317005, 55.03838986158371, 47.75557525455952, 41.21290773153305, 39.97911773622036, 41.63388714194298, 47.53582164645195, 54.52299691736698, 54.80102799832821, 52.37152956426144, 50.216763988137245, 45.94496861100197, 40.068097561597824, 39.73512902855873, 41.02786146104336, 38.662701174616814, 40.217459946870804, 39.04463768005371, 38.94253335893154, 39.059700071811676, 40.04352048039436, 41.151461228728294, 42.96959146857262, 42.33373738825321, 43.15512791275978, 42.190739661455154, 41.98928587138653, 40.71153603494167, 40.52866704761982, 40.638975128531456, 39.253679662942886, 38.05200934410095, 38.11287447810173, 39.67280097305775, 49.78283867239952, 53.2022599875927, 52.75947354733944, 51.56695693731308, 53.82761523127556, 51.87908738851547, 55.29542326927185, 54.182531386613846, 55.89734137058258, 50.57445779442787, 40.76321326196194, 37.95150473713875, 38.67096193134785, 38.58025699853897, 40.48089221119881, 37.801838368177414, 41.902331337332726, 51.733585596084595, 44.13953348994255, 37.48167894780636, 41.081119403243065, 40.14332972466946, 39.25751745700836, 39.13127303123474, 40.95933213829994, 39.247881174087524, 40.5936473608017, 44.826950803399086, 57.8290893137455, 53.20669434964657, 55.18950775265694, 52.00003869831562, 51.10876992344856, 50.08995719254017, 52.886424735188484, 47.75233402848244, 41.44449010491371, 38.52300927042961, 40.22097855806351, 40.41372701525688, 41.676281467080116, 40.712250396609306, 41.600980907678604, 42.249275520443916, 41.25753253698349, 38.559593707323074, 39.88631531596184, 40.864082649350166, 42.428470104932785, 42.753573060035706, 45.17415337264538, 46.72187492251396, 45.48386335372925, 43.63374263048172, 43.35749365389347, 42.379882112145424, 39.86035890877247, 40.635099336504936, 40.98968870937824, 40.01487001776695, 43.45050126314163, 39.87423576414585, 42.24485255777836, 41.0635681450367, 46.707059517502785, 48.71680587530136, 49.343012273311615, 47.92559713125229, 49.635554775595665, 47.626499980688095, 47.9693403840065, 42.10492506623268, 41.8879909068346, 44.47062112390995, 46.53687044978142, 48.11937913298607, 60.53244285285473, 58.45208868384361, 60.76770342886448, 51.777078062295914, 58.19728575646877, 4.348288122564554, 0.08118818019283935, 4.081878243014216, 0.5105088406708091, 0.20392126782098785, 34.61257450282574, 71.7676229774952, 59.87906411290169, 67.69471272826195, 64.96993973851204, 70.2766589820385, 53.9742873609066, 41.91237419843674, 58.14516395330429, 61.51836454868317, 45.598039627075195, 2.308161207474768, 0.2305498975329101, 0.035457025514915586, 0.027760994926211424, 0.11772301935707219, 0.12992909993045032, 0.024723102469579317, 0.028546259527502116, 0.37459559622220695, 0.1546186610357836, 0.256330386037007, 0.21143269288586453, 0.16951081895967945, 0.1697707932908088, 0.29095908568706363, 0.2148817796842195, 0.5751538812182844, 0.15851355594350025, 7.033686675131321, 73.90607222914696, 65.70962324738503, 54.507702738046646, 26.59723900258541, 45.81495098769665, 60.505479499697685, 68.64989027380943, 69.8115411400795, 70.46101748943329, 67.98884734511375, 62.09614634513855, 67.15223863720894, 13.942978475242853, 1.7304653814062476, 16.68797492980957, 11.012883502990007, 1.390672770794481, 0.41731637727934867, 33.512427136301994, 69.36146289110184, 65.22923022508621, 59.75812800228596, 59.741112515330315, 58.30326206982136, 61.43055886030197, 58.506079986691475, 60.7396799325943, 59.145144894719124, 48.60243961215019, 43.250392600893974, 42.38169461488724, 45.20540289580822, 52.814650386571884, 57.08076126873493, 59.34061400592327, 55.50104543566704, 52.16651916503906, 48.00674557685852, 43.40826652944088, 43.53797636926174, 43.60095798969269, 41.197320967912674, 44.79568228125572, 41.174871772527695, 41.926889419555664, 40.73047421872616, 42.379942908883095, 44.10348482429981, 44.805744141340256, 44.61996830999851, 44.617836624383926, 43.64601217210293, 48.81538398563862, 44.06601503491402, 41.45634546875954, 43.482575342059135, 42.15637810528278, 39.2843896150589, 40.86217135190964, 43.54233093559742, 52.32464388012886, 56.58152125775814, 55.61809815466404, 55.44744171202183, 55.963708609342575, 53.166610300540924, 57.72235304117203, 57.562484219670296, 57.84019231796265, 53.40305261313915, 42.50919297337532, 40.335645005106926, 39.90679621696472, 39.15541313588619, 40.37484370172024, 37.92126975953579, 43.25698144733906, 54.1409008204937, 43.83590318262577, 38.49469318985939, 39.51680414378643, 39.87772777676582, 39.06537316739559, 39.24346961081028, 41.852740198373795, 39.51556161046028, 41.753284335136414, 45.04931107163429, 61.39134116470814, 55.675805658102036, 59.11904029548168, 55.011707693338394, 54.31453250348568, 53.24484810233116, 55.220506489276886, 51.002086848020554, 44.76287484169006, 40.04728987812996, 44.60377357900143, 43.3822151273489, 44.893029257655144, 42.9824423789978, 41.79089851677418, 42.88729548454285, 44.70851495862007, 40.87490066885948, 43.236131966114044, 42.85686291754246, 45.81275090575218, 45.843384861946106, 47.98789478838444, 49.31188814342022, 48.86215567588806, 45.83981305360794, 45.77877312898636, 45.216274112463, 43.29930737614632, 43.14387671649456, 44.248485043644905, 41.89129672944546, 46.96828790009022, 42.0807583630085, 45.099529176950455, 44.099894016981125, 49.6074590831995, 51.91892825067043, 52.46807858347893, 49.542410373687744, 52.71413438022137, 49.67634938657284, 51.15461066365242, 46.92732609808445, 43.333247154951096, 47.00386919081211, 49.76359650492668, 50.27638278901577, 64.13772359490395, 61.593763902783394, 65.73936805129051, 53.33250939846039, 61.07911951839924, 5.512553248554468, 0.1983623145497404, 4.446180844679475, 6.297924080863595, 0.3412622114410624, 39.03175637125969, 78.15831005573273, 64.9865448474884, 73.17646577954292, 69.4389483332634, 74.85940307378769, 59.94833439588547, 42.18156315386295, 58.84580075740814, 66.83012992143631, 58.35960164666176, 5.101412935182452, 0.37486636138055474, 0.18479854159522802, 0.2310559680336155, 0.3070348355686292, 0.28739493631292135, 0.2224401233252138, 0.15332104550907388], [0.03519742225762457, 0.03894437373674009, 0.09918271578499116, 0.039738913328619674, 0.01732419441395905, 0.05206598623772152, 0.027479631899041124, 0.055393160437233746, 0.0449008027499076, 0.1828320135246031, 0.30199704808183014, 34.6684543043375, 58.45779597759247, 32.66189597547054, 35.304084196686745, 34.33347187936306, 51.51735059916973, 60.664436370134354, 59.54330272972584, 57.41383619606495, 56.97195030748844, 49.77708578109741, 55.966151878237724, 18.925657756626606, 1.1408944800496101, 1.4805779652670026, 3.0687355203554034, 0.9709711011964828, 0.02328653648874024, 4.704822041094303, 54.64260309934616, 62.289023995399475, 59.03725728392601, 51.107519790530205, 56.75775200128555, 60.32588593661785, 54.00647923350334, 52.42716617882252, 47.508926689624786, 41.280141323804855, 40.85592448711395, 40.55038668215275, 45.066394954919815, 53.04896481335163, 52.70844988524914, 53.93549904227257, 51.449558436870575, 51.7732934653759, 44.82920028269291, 38.668799847364426, 38.71344365179539, 35.86019575595856, 38.394625559449196, 36.64971359074116, 36.54509760439396, 37.817299738526344, 38.55192951858044, 37.61065162718296, 39.92345452308655, 38.49861077964306, 39.0143609046936, 38.67739878594875, 37.923006266355515, 40.65654158592224, 40.28446555137634, 38.88770990073681, 37.786893770098686, 38.529598116874695, 36.75361901521683, 37.08721451461315, 43.5467728972435, 49.50034663081169, 51.424115002155304, 50.982331708073616, 49.1203024238348, 52.7189677208662, 50.15211425721645, 50.62615782022476, 51.5409891307354, 53.094391375780106, 48.95333558320999, 40.10928735136986, 39.73411068320274, 38.2890710234642, 38.10417294502258, 39.431665912270546, 37.39662051200867, 41.42439678311348, 51.34806968271732, 40.235717967152596, 39.800724908709526, 39.708610251545906, 41.010477393865585, 40.883769392967224, 39.2657820135355, 39.585641250014305, 38.91982577741146, 39.73786488175392, 47.377142161130905, 54.55214895308018, 54.53867107629776, 50.68928383290768, 51.30038984119892, 50.347313582897186, 48.034275099635124, 48.08413602411747, 50.17548680305481, 45.18177576363087, 36.1770835518837, 37.88390256464481, 37.266602888703346, 40.19770860671997, 39.95990976691246, 37.60633885860443, 38.378590419888496, 40.836161747574806, 39.6973742544651, 39.64103847742081, 38.72330792248249, 39.617635533213615, 40.745126232504845, 41.86684124171734, 42.74480693042278, 43.082662001252174, 39.40203130245209, 38.43499079346657, 39.539815708994865, 38.14123995602131, 39.760044291615486, 39.38736788928509, 36.805729418992996, 37.64228492975235, 37.10571572184563, 40.954567193984985, 48.34272734820843, 49.580647721886635, 52.70418271422386, 50.911172926425934, 51.199341863393784, 52.74350680410862, 52.50660091638565, 50.51953174173832, 48.33587631583214, 43.14687855541706, 40.267256274819374, 41.39177553355694, 43.95785003900528, 54.98170830309391, 57.66099013388157, 59.05735060572624, 55.25710612535477, 47.74515621364117, 2.423011944629252, 0.10022411224781536, 2.7998070884495974, 0.7610041054431349, 0.4602320760022849, 44.78448808193207, 58.21639493107796, 55.87618410587311, 59.46872793138027, 59.58481550216675, 59.19015347957611, 45.2032446116209, 23.704410530626774, 25.212245620787144, 50.525212436914444, 33.99036169052124, 0.5159415397793055, 0.046566286036977544, 0.07411864469759166, 0.044094834083807655, 0.052825173625024036, 0.02061309049167903, 0.03220145372324623, 0.019606341193139087, 0.03289460109954234, 0.055265273549593985, 0.05654045395203866, 0.022526883403770626, 0.013914533283241326, 0.04140312012168579, 0.04881006192590576, 0.03461449494352564, 0.04794544503965881, 0.10636483508278616, 0.5536566535010934, 44.377902299165726, 64.56140846014023, 35.567592456936836, 32.100145518779755, 44.39244791865349, 55.24547874927521, 66.45588040351868, 65.30212551355362, 62.694929614663124, 63.74810390174389, 54.78253439068794, 61.916320994496346, 21.804613173007965, 0.8227662288118154, 2.4166484735906124, 5.864958688616753, 3.7211735732853413, 0.08151898509822786, 6.638561552390456, 56.689363270998, 65.12140721082687, 59.20119188725948, 55.37981294095516, 60.53840093314648, 61.24505281448364, 55.02773143351078, 53.667890802025795, 50.218743681907654, 42.56468519568443, 42.385578006505966, 41.52521297335625, 45.766575783491135, 55.76825089752674, 53.5662804543972, 55.26593305170536, 54.00764957070351, 55.02822920680046, 47.67797961831093, 41.61796599626541, 40.6156899780035, 38.90414781868458, 39.931719079613686, 38.448510468006134, 39.00334909558296, 39.96481150388718, 39.74531628191471, 41.24340869486332, 42.13476866483688, 39.161435812711716, 41.599479988217354, 41.50435209274292, 40.47000579535961, 40.62701717019081, 40.82282826304436, 41.057264283299446, 39.04956601560116, 40.588525235652924, 39.300371557474136, 39.595364928245544, 43.763361275196075, 52.44042746722698, 53.22943612933159, 53.8888755440712, 51.928507536649704, 54.92461256682873, 52.43096597492695, 54.10927511751652, 54.04889635741711, 55.62826260924339, 50.60002662241459, 39.47564095258713, 38.039800599217415, 37.72289760410786, 38.43228913843632, 39.04280237853527, 36.64825826883316, 42.59896695613861, 52.64274001121521, 40.96337892115116, 40.70876598358154, 39.612000435590744, 40.0140530616045, 40.04630193114281, 38.604039922356606, 38.99492874741554, 40.25521472096443, 39.66841220855713, 47.9422440379858, 54.811203852295876, 55.91756008565426, 52.58296921849251, 53.20665255188942, 51.855749040842056, 52.49256446957588, 50.080522298812866, 51.050401255488396, 45.14216288924217, 38.58455456793308, 39.83110427856445, 38.36784079670906, 41.147216856479645, 41.56355671584606, 42.06059284508228, 40.904102101922035, 41.37237377464771, 40.75375936925411, 40.561668276786804, 40.61447024345398, 41.035730838775635, 42.44609735906124, 44.359971061348915, 44.175468161702156, 44.64014522731304, 42.45702177286148, 40.778450444340706, 41.94251038134098, 40.166516080498695, 41.70723840594292, 39.54932659864426, 39.64845947921276, 39.46055196225643, 39.40563730895519, 42.497576996684074, 50.30547022819519, 53.229759112000465, 55.06591938436031, 53.76314029097557, 53.353526070714, 55.50833724439144, 53.88634867966175, 54.45709705352783, 51.16314500570297, 45.33128634095192, 41.87832422554493, 43.84041354060173, 45.352325811982155, 58.836757242679596, 59.22627054154873, 63.2006748765707, 54.54300284385681, 50.77097944915295, 3.248408641666174, 0.13485200295690447, 5.975945508107543, 0.48546984675340354, 0.5626499396748841, 49.53940853476524, 63.78759518265724, 63.90676438808441, 64.14029225707054, 67.72097691893578, 64.09328877925873, 55.4950113594532, 27.095261178910732, 26.21723849326372, 57.53797173500061, 40.0811992585659, 0.9066512400750071, 0.06735113362083212, 0.008472222434647847, 0.0763076612201985, 0.06092452065786347, 0.012862528747064061, 0.0025825688544500736, 0.02723871777561726, 0.14225246210116893, 0.14398735103895888, 0.2027859748341143, 0.11690805957186967, 0.15433887136168778, 0.1423382543725893, 0.09580746525898576, 0.12075275561073795, 0.21555962768616155, 0.3667980880709365, 0.4644197481684387, 51.12698994576931, 74.65396329760551, 46.306359618902206, 42.713036835193634, 52.228151857852936, 62.934502959251404, 70.19626289606094, 71.68574497103691, 67.25738659501076, 69.50968533754349, 61.64695344865322, 67.64169797301292, 25.190869867801666, 1.644086753949523, 7.131883855909109, 13.4014961309731, 4.1163561679422855, 0.08324966605869122, 7.572307297959924, 58.97341310977936, 65.688336789608, 62.64411114156246, 57.28055074810982, 61.42092637717724, 62.41765469312668, 59.32848505675793, 56.06726445257664, 52.87632867693901, 45.86401775479317, 46.62456214427948, 43.59308861196041, 48.71593952178955, 57.23322428762913, 57.26043842732906, 57.997975051403046, 55.38865506649017, 58.69753651320934, 48.83740000426769, 43.39151322841644, 44.602219462394714, 42.08951689302921, 43.489650562405586, 41.946963742375374, 40.95392122864723, 44.24537681043148, 43.696028888225555, 43.57314348220825, 46.70213118195534, 42.233855947852135, 42.90703162550926, 43.663510233163834, 42.338095754384995, 44.25464451313019, 46.211885288357735, 43.7686999887228, 41.61355063319206, 43.774148896336555, 42.64113329350948, 40.82617588341236, 45.32999441027641, 55.09655714035034, 56.2920717895031, 56.35075964033604, 53.98238852620125, 58.7965402007103, 55.89939326047897, 54.87030208110809, 58.430361449718475, 58.026606515049934, 52.72684469819069, 41.124646067619324, 38.89894589781761, 38.06403569877148, 38.072326853871346, 39.39442791044712, 37.12245762348175, 42.626298889517784, 55.17416797578335, 40.89458741247654, 40.12749217450619, 39.686750024557114, 41.172565296292305, 40.5520585924387, 38.2672031968832, 39.414506033062935, 40.186719596385956, 39.22733187675476, 47.931194230914116, 58.29969026148319, 58.945241421461105, 56.18039198219776, 55.61407797038555, 55.2879186719656, 52.889187186956406, 54.55211095511913, 54.91015054285526, 49.725492149591446, 41.7193179577589, 43.69251027703285, 42.130927070975304, 44.72410932183266, 44.01203513145447, 42.931198328733444, 42.46074557304382, 43.82587932050228, 43.436628207564354, 41.84572957456112, 44.13965508341789, 43.825624734163284, 43.525288850069046, 45.728262439370155, 47.30070926249027, 47.555789574980736, 45.837012603878975, 42.78237171471119, 43.83077345788479, 42.80225224792957, 44.38864812254906, 42.93244086205959, 41.90321668982506, 41.814134269952774, 40.95542974770069, 46.40064395964146, 54.06512528657913, 55.00414989888668, 57.37733915448189, 54.75675277411938, 55.90909793972969, 59.68260705471039, 57.38007500767708, 57.28853411972523, 53.96311976015568, 47.85737559199333, 45.17098434269428, 47.841196060180664, 48.086567893624306, 60.77870763838291, 63.47685545682907, 64.77986633777618, 55.54403632879257, 52.48552344739437, 4.539833944290876, 0.40267306147143245, 9.613284654915333, 1.5953024779446423, 0.629521660739556, 56.7152588814497, 68.44024032354355, 69.13334593176842, 70.17493084073067, 73.25829818844795, 68.9935514330864, 61.36620171368122, 31.11691027879715, 35.01559227705002, 65.2639527618885, 50.328876972198486, 1.4069436164572835, 0.16810980741865933, 0.1898917675134726, 0.25927798880729824, 0.11710673992638476, 0.18812573805917054, 0.20708813070086762, 0.1204745689756237], [0.00645155283564236, 0.014043437840882689, 0.025594007202016655, 0.02454995013977168, 0.013233586814749287, 0.019539904133125674, 0.05144795162777882, 0.05987481585179921, 0.02583271900221007, 0.5104250670410693, 0.02914797431003535, 13.542425818741322, 61.7009599506855, 44.21560540795326, 28.66824757307768, 18.481788374483585, 53.62462252378464, 62.88341470062733, 62.833462581038475, 53.36831107735634, 59.279304295778275, 52.44893901050091, 57.133612632751465, 26.041862703859806, 0.28356753231491894, 2.5334827043116093, 5.3181039076298475, 2.3172211088240147, 0.11537383252289146, 0.23908398725325242, 31.898467540740967, 61.98697440326214, 48.49162995815277, 62.780930399894714, 56.03225313127041, 55.34581236541271, 49.7159318625927, 46.32248215377331, 41.66751153767109, 43.40303801000118, 41.54692500829697, 44.895628318190575, 50.03950349986553, 53.88469196856022, 53.688565492630005, 53.50283905863762, 53.19704666733742, 52.90641926229, 47.510271817445755, 40.71700394153595, 39.21032778918743, 38.87846879661083, 36.56764179468155, 37.781095281243324, 37.57401779294014, 37.26022683084011, 36.81907810270786, 38.17192330956459, 39.12968471646309, 39.606779515743256, 39.408521354198456, 40.31139850616455, 39.840641766786575, 40.238427221775055, 40.39175659418106, 37.67736464738846, 37.16232508420944, 36.797016486525536, 36.96818970143795, 39.191575795412064, 44.926877841353416, 49.04451169073582, 48.93261529505253, 51.00440472364426, 49.39009554684162, 48.05350586771965, 50.22518813610077, 52.41344511508942, 51.96182034909725, 53.59412156045437, 51.05101302266121, 40.514163225889206, 40.592788606882095, 39.37330104410648, 38.58692564070225, 38.58796298503876, 37.95763000845909, 43.96260358393192, 54.196472838521004, 42.83302299678326, 39.39865328371525, 40.46638838946819, 39.89167682826519, 40.9346828609705, 38.23390178382397, 40.61410926282406, 39.65928889811039, 41.9206577539444, 48.20037938654423, 52.93559789657593, 52.2835148870945, 52.21902094781399, 50.510617420077324, 52.23961964249611, 49.823618084192276, 47.566523998975754, 48.628468215465546, 47.85687401890755, 38.976769521832466, 35.091667994856834, 35.203887373209, 36.49621702730656, 35.31532399356365, 34.699225053191185, 38.566600531339645, 37.662047669291496, 41.15373730659485, 40.43019153177738, 37.13981129229069, 39.369949623942375, 39.744848906993866, 42.46559411287308, 41.18200398981571, 38.44361253082752, 38.18658672273159, 39.43524532020092, 37.42209434509277, 37.64109179377556, 35.55308863520622, 36.08811512589455, 37.02635698020458, 36.81513771414757, 38.242356330156326, 46.36065490543842, 53.79736505448818, 51.74102559685707, 51.11587934195995, 52.57673755288124, 50.266035944223404, 52.194364070892334, 52.64274001121521, 56.30821332335472, 54.0121029317379, 48.77297826111317, 40.623452961444855, 40.28035417199135, 40.70171736180782, 49.46317322552204, 56.69259309768677, 58.891079127788544, 47.28740997612476, 27.070036232471466, 9.40069081261754, 0.15855115314479917, 4.148642085492611, 0.49466526426840574, 3.958826595917344, 59.69363026320934, 54.27453204989433, 60.39569579064846, 58.80364961922169, 58.39079037308693, 59.7417850792408, 36.25339485704899, 32.40319445729256, 27.88340538740158, 51.28224581480026, 20.46615779399872, 0.6763993296772242, 0.0153404104821675, 0.045195164493634365, 0.01438252975276555, 0.03413242920942139, 0.10348309791879728, 0.028681408330157865, 0.037947906894260086, 0.04110181187570561, 0.05175117832550313, 0.06125573374447413, 0.01703514459222788, 0.06744879283360206, 0.09973502950742841, 0.030207377130864188, 0.08044742775382474, 0.0195791600344819, 0.5527644138783216, 0.22711467405315489, 20.438789762556553, 72.2849728167057, 47.75336377322674, 31.363188363611698, 31.96630150079727, 58.44389632344246, 66.7840763926506, 67.45632871985435, 57.78358295559883, 65.72010308504105, 57.30521522462368, 62.30357341468334, 28.780991323292255, 0.18685673974687234, 2.6214007241651416, 5.053065279498696, 6.190671036019921, 0.6757824565283954, 0.49126557481940836, 34.659342393279076, 62.08511933684349, 50.50288863480091, 62.69776426255703, 58.975126817822456, 58.68614472448826, 52.27229408919811, 48.62248733639717, 43.42548340559006, 44.315148666501045, 43.35419163107872, 45.69624915719032, 51.54136911034584, 55.9562686085701, 57.21712455153465, 54.45282608270645, 53.021150305867195, 53.93694296479225, 50.50830714404583, 43.35838280618191, 41.01717263460159, 40.907248333096504, 38.71014162898064, 40.9890541434288, 40.14218218624592, 39.56219270825386, 39.39316637814045, 41.18925780057907, 40.70164516568184, 41.37024208903313, 40.58418206870556, 41.837674006819725, 40.82991488277912, 41.197184175252914, 41.6249044239521, 40.03283925354481, 39.054467752575874, 39.512897953391075, 39.41998153924942, 40.38614049553871, 45.35848908126354, 52.018881887197495, 52.800921723246574, 53.29418085515499, 51.689705550670624, 50.5827983468771, 51.69058330357075, 54.749829545617104, 53.0488546192646, 55.85806667804718, 51.18919260799885, 40.393800884485245, 38.32017235457897, 38.54505568742752, 39.202295020222664, 38.77762980759144, 38.5760772228241, 44.68587577342987, 55.12323170900345, 42.8143659979105, 38.858535066246986, 40.75671561062336, 39.43654105067253, 40.186632201075554, 38.90349805355072, 39.404584765434265, 38.8148146122694, 40.76451659202576, 49.15546573698521, 56.235071048140526, 54.223485589027405, 54.34164024889469, 52.378578186035156, 53.04611496627331, 53.1648775935173, 49.78807479143143, 52.036041766405106, 50.60748182237148, 40.12209266424179, 36.203484535217285, 38.189086988568306, 37.468505054712296, 36.5003702044487, 35.85707612335682, 38.93407121300697, 40.17001949250698, 42.99397096037865, 41.90816402435303, 38.494765385985374, 40.36090984940529, 42.163548320531845, 45.054664984345436, 43.84941145777702, 41.71580694615841, 40.71308255195618, 43.02853770554066, 40.20163379609585, 39.77363236248493, 38.44971500337124, 38.700037971138954, 39.12905395030975, 39.373722821474075, 39.84300523996353, 48.50986897945404, 56.56489335000515, 54.39417243003845, 55.44276036322117, 54.88088071346283, 51.5755482763052, 54.998340010643005, 55.33043459057808, 57.641143798828125, 56.58092848956585, 52.51917064189911, 43.69408339262009, 43.60661968588829, 43.67625094950199, 54.07752402126789, 57.87980519235134, 62.29211702942848, 48.87064442038536, 29.995968528091908, 12.445044703781605, 0.08886331561370753, 6.80474990978837, 0.07215746751171537, 4.192353039979935, 64.12896126508713, 60.51645331084728, 67.30206459760666, 64.50121968984604, 64.16230827569962, 61.503845527768135, 46.529141664505005, 32.94640190899372, 28.450435660779476, 61.16272643208504, 26.845367588102818, 0.4179079580353573, 0.026031759298348334, 0.09146032782155089, 0.03550902409187984, 0.009997447232308332, 0.05983862873108592, 0.021979182129143737, 0.028463424714573193, 0.22780194733059034, 0.10303625822416507, 0.19053293857723475, 0.2404732134891674, 0.21921225590631366, 0.2183049061568454, 0.09097501519136131, 0.18220215279143304, 0.1063680782681331, 0.848509194329381, 0.3959235252114013, 23.375467881560326, 81.21368810534477, 58.54198805987835, 36.10480383038521, 31.015822403132915, 65.89023515582085, 72.04022035002708, 73.11664938926697, 63.128345757722855, 70.42374148964882, 61.970927864313126, 67.87958040833473, 34.16372358798981, 0.37260474055074155, 9.638262614607811, 12.200929652899504, 6.936319274827838, 0.6673651363234967, 0.46160389145370573, 36.87489710748196, 62.731529250741005, 53.36558662354946, 62.941312193870544, 60.55853985249996, 60.470536574721336, 56.36423371732235, 50.47591768205166, 47.97873727977276, 47.30369970202446, 46.20295576751232, 48.59485521912575, 54.57387998700142, 58.92341159284115, 60.551400035619736, 55.57496286928654, 57.41123713552952, 54.782116413116455, 54.759899005293846, 45.35612180829048, 44.3601306527853, 42.85362549126148, 41.311637833714485, 43.19386683404446, 44.33441363275051, 42.193707302212715, 43.170593082904816, 43.66023100912571, 43.07212896645069, 45.15244133770466, 45.56006446480751, 44.79236885905266, 44.2529422044754, 43.28614488244057, 43.64330671727657, 42.19526521861553, 41.65942557156086, 41.463865265250206, 41.31793789565563, 43.47697824239731, 49.38864402472973, 53.07112142443657, 56.74191825091839, 57.358951941132545, 54.93944317102432, 52.9819668084383, 53.95254872739315, 57.94589504599571, 57.10179693996906, 59.15729284286499, 54.72022533416748, 42.78878577053547, 39.17713277041912, 37.31854610145092, 38.70489031076431, 37.25256644189358, 38.91243517398834, 46.36128947138786, 60.11578381061554, 44.80369605123997, 40.01235835254192, 39.905230700969696, 39.51081186532974, 40.73593832552433, 38.69392029941082, 39.70365531742573, 40.49307815730572, 40.954137817025185, 49.57786247134209, 57.36158140003681, 57.763744220137596, 56.76349729299545, 55.183006301522255, 57.43202202022076, 55.429757460951805, 50.81869728863239, 54.27385948598385, 52.31115460395813, 43.382872492074966, 37.33431525528431, 39.765326008200645, 39.05191048979759, 38.460061848163605, 37.468212470412254, 42.35923781991005, 41.297969967126846, 45.21342806518078, 44.84970398247242, 40.77843904495239, 41.107429191470146, 44.07373622059822, 47.55974516272545, 46.619276627898216, 42.319453954696655, 44.339862540364265, 44.76960428059101, 42.17779375612736, 43.17916162312031, 39.89820867776871, 40.23360148072243, 40.95161855220795, 42.29104287922382, 42.010481134057045, 50.43346256017685, 58.8703740388155, 56.413802057504654, 58.33055600523949, 57.396330535411835, 52.60668374598026, 56.154009997844696, 57.645825147628784, 59.04581442475319, 59.93859551846981, 55.210592821240425, 46.43119812011719, 45.85269056260586, 45.38948021829128, 57.061952278018, 63.52490767836571, 65.10860189795494, 54.10760320723057, 37.99529358744621, 16.577957533299923, 0.21356372541049495, 15.5203165858984, 1.009757223073393, 5.100439237430692, 71.86642527580261, 65.31213417649269, 72.27881714701653, 68.94268736243248, 69.59004342556, 68.87875959277153, 49.93856951594353, 43.04256655275822, 38.69357451796532, 69.41642314195633, 36.43349379301071, 0.7828437304124236, 0.13184606737922877, 0.21635525452438742, 0.13171991711715236, 0.1474807588965632, 0.13941689394414425, 0.09181167537462898, 0.10003748437156901], [0.08218062459491193, 0.03842252888716757, 0.028814306569984183, 0.037929278987576254, 0.040572226425865665, 0.012988579746888718, 0.054714815196348354, 0.042411858375999145, 0.05067644829978235, 0.1152002441813238, 0.12450489099137485, 3.0472163250669837, 53.36356893181801, 45.58545470237732, 36.831180453300476, 31.400395967066288, 40.07947415113449, 61.305887550115585, 59.77952465415001, 56.40534371137619, 58.405647575855255, 55.593217089772224, 54.24230977892876, 43.7366297096014, 1.844653885345906, 2.3249876545742154, 3.1683675991371274, 4.556126520037651, 2.005352843552828, 0.18560461787274107, 17.240923158824444, 60.374382734298706, 55.5215073376894, 57.867186069488525, 53.79296489059925, 54.54730801284313, 46.603385880589485, 46.54410146176815, 44.89314705133438, 49.921751618385315, 49.12003643810749, 51.49371586740017, 49.0161994099617, 55.560675635933876, 53.592282459139824, 49.70555081963539, 52.13769771158695, 53.77099446952343, 46.782968044281006, 40.07492959499359, 38.873308673501015, 37.7661544829607, 34.83958952128887, 36.17480367422104, 37.14682951569557, 37.37064890563488, 38.12912240624428, 38.0088322609663, 38.54400314390659, 39.1971804946661, 40.65175764262676, 40.55430427193642, 39.529328271746635, 37.74243235588074, 37.91937746107578, 38.39107275009155, 36.96698896586895, 37.93144941329956, 38.808753937482834, 39.47247572243214, 45.7841270416975, 47.74631515145302, 50.9991268068552, 49.66252192854881, 49.46720100939274, 50.124983713030815, 50.799937695264816, 53.06769780814648, 52.61206805706024, 53.653964549303055, 48.203411623835564, 41.06229521334171, 40.7090699672699, 39.7001139074564, 39.06487159430981, 38.391623720526695, 40.819712430238724, 43.00218231976032, 51.73338420689106, 43.153338208794594, 39.31733004748821, 40.69369979202747, 39.770497530698776, 39.62328962981701, 38.32063212990761, 39.26602900028229, 39.7345856577158, 41.14113338291645, 46.07008069753647, 54.28449131548405, 53.461178094148636, 52.848909348249435, 50.2372220903635, 50.891957357525826, 49.1620659828186, 48.937878012657166, 49.17128808796406, 49.85338568687439, 43.37789095938206, 37.21268758177757, 36.77090048789978, 34.94405351579189, 37.59172484278679, 35.80795995891094, 36.577456668019295, 39.530468210577965, 37.757342755794525, 38.34140941500664, 38.645723685622215, 39.023700803518295, 41.2675715982914, 41.99227251112461, 42.17543788254261, 40.36362670361996, 39.979148134589195, 39.2319942265749, 38.799801617860794, 37.36966855823994, 38.6427978426218, 37.01874598860741, 36.03513836860657, 36.71071171760559, 38.93440939486027, 51.196822598576546, 51.99626550078392, 54.39108319580555, 54.2422641813755, 53.67065705358982, 52.55922429263592, 54.16719160974026, 55.817458257079124, 50.21587863564491, 54.02619257569313, 56.84032917022705, 49.36914727091789, 41.49265632033348, 38.65843400359154, 45.55872693657875, 52.19346731901169, 59.37007762491703, 55.9661290794611, 36.834463477134705, 15.19368326291442, 0.2811996953096241, 3.364124782383442, 0.21309247647877783, 9.560375344008207, 63.933203369379044, 53.373281210660934, 58.93027402460575, 55.245220363140106, 62.94128179550171, 51.01463757455349, 34.72656458616257, 21.51022206991911, 27.036427035927773, 54.11030486226082, 10.018974635750055, 0.4643115133512765, 0.04370499504148029, 0.1151876721996814, 0.05880451644770801, 0.05975308136839885, 0.05879651980649214, 0.06943246451555751, 0.060831989685539156, 0.030111267151369248, 0.1404050042037852, 0.02180992978537688, 0.06684681458864361, 0.0387079143547453, 0.03249911802413408, 0.025890022079693154, 0.08613832003902644, 0.035480251026456244, 0.3847253182902932, 0.11090668980614282, 4.695657407864928, 61.94576941430569, 54.54026699066162, 29.02835614979267, 30.95828589051962, 52.18468979001045, 65.36364421248436, 66.55735775828362, 61.20112717151642, 63.76867979764938, 59.28967773914337, 59.51920062303543, 48.827592730522156, 1.6103404085151851, 1.9708476075902581, 3.9332157326862216, 5.594433154910803, 2.8577620536088943, 0.21346173947677016, 21.208009086549282, 60.104091838002205, 56.22316628694534, 59.35009829699993, 56.52195945382118, 57.00212448835373, 50.532519444823265, 48.53451065719128, 47.012779712677, 52.05479755997658, 50.85848495364189, 53.555264845490456, 53.1630764901638, 57.97184005379677, 55.963237434625626, 51.636728793382645, 56.367873921990395, 54.966543316841125, 50.04912078380585, 41.28854267299175, 40.61849802732468, 39.82726648449898, 38.241702765226364, 38.73249962925911, 39.40944090485573, 38.91653895378113, 40.71898743510246, 40.51343746483326, 41.24504640698433, 40.58572098612785, 42.58371837437153, 42.72342547774315, 39.94644708931446, 41.147775426506996, 40.83608955144882, 40.18575444817543, 37.83537536859512, 39.65205408632755, 41.3901150226593, 40.0898551940918, 49.83285918831825, 50.15427254140377, 53.103187903761864, 52.4758605659008, 52.0307220518589, 52.04717516899109, 53.22432920336723, 54.685054421424866, 54.860312417149544, 56.19043484330177, 48.949547186493874, 41.745559349656105, 39.80222202837467, 40.343062207102776, 38.43030944466591, 39.012844786047935, 40.34047834575176, 42.86795072257519, 55.056283101439476, 42.84105196595192, 39.692043140530586, 41.24786585569382, 39.12311866879463, 39.82206076383591, 38.75827744603157, 39.45033051073551, 39.40199710428715, 40.300253704190254, 48.02710108458996, 55.717386826872826, 54.29941311478615, 55.33224329352379, 54.247922077775, 52.92655058205128, 53.65446612238884, 50.12465313076973, 50.23528039455414, 52.367087602615356, 43.623498380184174, 39.77007195353508, 37.58629493415356, 37.02836327254772, 39.48039069771767, 38.77300165593624, 38.85232999920845, 40.37538707256317, 40.15011616051197, 40.95334745943546, 40.28139531612396, 41.43690191209316, 41.740524619817734, 45.39725460112095, 43.29173818230629, 42.650173008441925, 42.72135078907013, 40.567945539951324, 40.690553560853004, 39.598967134952545, 40.542494505643845, 38.87789122760296, 40.62956303358078, 38.55396620929241, 42.01828591525555, 55.039491802453995, 53.68196524679661, 56.42251878976822, 58.48828934133053, 55.59980973601341, 55.54722435772419, 56.424582079052925, 59.90311302244663, 54.029840379953384, 55.721399411559105, 57.618497014045715, 51.20310366153717, 44.002341851592064, 41.22424632310867, 48.07622864842415, 55.206785425543785, 61.17805480957031, 59.82182778418064, 41.609059274196625, 17.30508081614971, 0.22598732204642147, 3.618567679077387, 0.691558972466737, 10.828366354107857, 69.56197813153267, 57.114165276288986, 64.21307355165482, 62.078674882650375, 68.29057395458221, 57.20012046396732, 48.03816609084606, 23.7212398275733, 29.78783469647169, 62.691141217947006, 13.759668711572886, 0.5640521831810474, 0.035745546556427144, 0.07717227068496868, 0.07242478168336675, 0.07694460204220377, 0.09214950099703856, 0.0036075562002224615, 0.06141285011835862, 0.12612488062586635, 0.24717952706851065, 0.14392266544746235, 0.09940890013240278, 0.11439303241786547, 0.11135050895973109, 0.11208945797989145, 0.18295007437700406, 0.1388934423448518, 0.3853811987210065, 0.21292380115482956, 4.87353203818202, 71.40787348151207, 62.794917449355125, 48.15772287547588, 42.38632656633854, 57.25134551525116, 68.82073670625687, 72.27451577782631, 66.51864543557167, 71.32688462734222, 65.76356515288353, 65.44167682528496, 56.589979603886604, 2.703370163217187, 6.580629386007786, 13.081230316311121, 9.99250715598464, 4.539090609177947, 0.3404181817313656, 24.010791890323162, 63.081646263599396, 54.307290092110634, 60.553748309612274, 58.52900415658951, 58.95550087094307, 51.74702927470207, 51.841659396886826, 49.447518065571785, 55.82602299749851, 53.076718524098396, 56.73201598227024, 54.48037460446358, 60.81400394439697, 56.13362789154053, 53.7503045797348, 59.319684728980064, 56.92233256995678, 52.003542110323906, 44.8655491322279, 42.7486827224493, 42.684234380722046, 39.3868625164032, 39.63471941649914, 41.39687865972519, 42.11182549595833, 44.1295400261879, 41.767373979091644, 43.66100996732712, 42.077650129795074, 46.00396804511547, 45.37312209606171, 41.49831801652908, 41.90734326839447, 42.502790316939354, 41.19670160114765, 40.3988242149353, 43.16176995635033, 44.40397270023823, 43.87748435139656, 51.923757791519165, 50.59012435376644, 56.74637161195278, 54.770831018686295, 54.73298504948616, 53.69622968137264, 55.67613244056702, 58.35669860243797, 57.28633403778076, 59.138252064585686, 51.18859604001045, 42.847291231155396, 40.99430166184902, 39.424222111701965, 37.35028199851513, 38.717000260949135, 39.590314999222755, 44.1302277892828, 57.90739171206951, 42.726731300354004, 39.42378893494606, 40.3898186981678, 39.64554123580456, 39.76003289222717, 38.22268858551979, 39.5050323754549, 39.33493070304394, 40.702807903289795, 47.792756259441376, 57.389274314045906, 57.75158107280731, 57.35853396356106, 54.425311759114265, 58.13760235905647, 55.95338076353073, 52.43177533149719, 54.027404710650444, 55.99942289292812, 45.77556990087032, 42.18175694346428, 40.64393386244774, 39.432205483317375, 42.82355010509491, 40.273396745324135, 41.46983854472637, 41.9910603761673, 42.13039509952068, 43.34228307008743, 42.9295340180397, 44.018240198493004, 44.889480248093605, 49.03670310974121, 47.70020082592964, 44.42133016884327, 46.00337527692318, 43.46054792404175, 43.2781121134758, 41.20036460459232, 43.71473528444767, 40.98290987312794, 41.96203373372555, 40.65580062568188, 43.35552915930748, 56.97949290275574, 57.0218226313591, 57.556541338562965, 59.91493418812752, 59.438409358263016, 57.95708924531937, 58.84178437292576, 62.978743985295296, 57.808908596634865, 56.769063994288445, 62.33849734067917, 52.94997252523899, 47.6470872759819, 45.71602709591389, 52.18195013701916, 56.88285268843174, 64.75956782698631, 62.583831176161766, 43.573960438370705, 19.882461614906788, 0.29376425547525287, 13.371655382215977, 0.9473294229246676, 12.20003955066204, 73.03988590836525, 61.88802011311054, 68.05432543158531, 66.73422306776047, 70.785603672266, 63.29805985093117, 50.037413612008095, 31.764205545186996, 38.39739941060543, 74.81308355927467, 18.929801434278488, 0.5706387141253799, 0.11989147096755914, 0.19967873609857634, 0.10948048235150054, 0.17388867388945073, 0.2118702037842013, 0.11979663191596046, 0.15428107290063053], [0.06876557803479955, 0.06122510530985892, 0.023035887243167963, 0.026976088411174715, 0.0750158196024131, 0.02600675077701453, 0.04439705517143011, 0.08026591327507049, 0.06975035605137236, 0.021292793862812687, 0.15561192180030048, 0.1475045076222159, 36.54721409082413, 55.708597898483276, 33.0887346714735, 24.815753996372223, 36.01009011268616, 58.81624974310398, 56.055162101984024, 58.25121246278286, 56.52399994432926, 57.23207674920559, 49.75347384810448, 50.519725531339645, 6.499612033367157, 1.5936146560125053, 3.451735731214285, 5.224742917343974, 4.446809235960245, 0.5609513120725751, 19.556368812918663, 64.96632233262062, 51.514755338430405, 57.45186075568199, 56.447221264243126, 54.08262714743614, 54.67229850590229, 53.387997820973396, 51.568290665745735, 53.19392703473568, 52.29877486824989, 54.1240069270134, 52.51628279685974, 55.15025965869427, 43.845718055963516, 49.535791128873825, 56.49868190288544, 54.134817346930504, 46.126450672745705, 36.364166513085365, 38.65884058177471, 39.75569352507591, 38.36030960083008, 37.697324976325035, 37.99025125801563, 36.48603357374668, 36.67191959917545, 39.4447486102581, 38.368110582232475, 39.00598235428333, 39.79322411119938, 42.035802975296974, 40.300975665450096, 38.906203508377075, 39.77239742875099, 37.80429683625698, 36.100308671593666, 39.13530841469765, 38.40936116874218, 40.502440854907036, 47.71880082786083, 47.49622397124767, 49.51959639787674, 51.407772079110146, 51.797239780426025, 49.932007268071175, 50.72741478681564, 49.64882746338844, 51.529589742422104, 50.62811091542244, 43.183257803320885, 39.66513678431511, 43.48723769187927, 40.16151174902916, 41.68344788253307, 42.37088419497013, 39.99847009778023, 43.39448846876621, 52.63570658862591, 44.75757792592049, 40.57597830891609, 41.49201415479183, 37.606779634952545, 40.093738585710526, 38.80254127085209, 40.57228870689869, 39.84146632254124, 41.92810915410519, 47.899663522839546, 54.80998791754246, 53.54748286306858, 52.26764313876629, 50.326338708400726, 50.10098040103912, 52.01480470597744, 48.98706257343292, 49.33458812534809, 48.84119600057602, 48.74755762517452, 38.699437603354454, 35.65191753208637, 36.784503757953644, 37.14129701256752, 37.877009734511375, 36.50156334042549, 36.02208986878395, 36.9122339040041, 37.47788295149803, 36.30757234990597, 39.126952663064, 39.6057915687561, 39.409934878349304, 44.393876641988754, 42.42146708071232, 41.07057876884937, 39.8863685131073, 38.545659855008125, 36.10533580183983, 37.27876603603363, 36.095042154192924, 37.33658753335476, 36.991835832595825, 38.969386518001556, 45.79263098537922, 55.10313078761101, 53.777541518211365, 52.914550825953484, 53.80767770111561, 54.88134428858757, 51.080963015556335, 47.607436403632164, 51.43391467630863, 54.42352585494518, 53.33704635500908, 54.370446503162384, 47.7911451458931, 39.967862740159035, 42.15741164982319, 53.05447071790695, 56.80247560143471, 60.57299807667732, 45.95739394426346, 2.5857239635661244, 0.4354849539231509, 2.861086162738502, 0.5282046692445874, 16.15483693778515, 58.873337879776955, 54.89456757903099, 58.38795192539692, 57.766153290867805, 60.461987033486366, 50.925536155700684, 34.94939982891083, 24.755420833826065, 36.381394788622856, 45.995551496744156, 3.390676095150411, 0.3542497957823798, 0.07195660524303094, 0.026175459497608244, 0.09284032174036838, 0.05435038729046937, 0.03092814909905428, 0.045573819370474666, 0.04142974466958549, 0.051819359432556666, 0.008904527167032938, 0.06473952336818911, 0.03193318218109198, 0.04047635207825806, 0.06595516126253642, 0.051289280454511754, 0.0925460527651012, 0.06714449744322337, 0.1268445560708642, 0.17518471606308594, 0.5975914990995079, 45.28450705111027, 64.04855757951736, 35.84763742983341, 30.81580113619566, 49.125382751226425, 64.51840236783028, 63.57783503830433, 63.052619621157646, 63.4901737421751, 63.25373902916908, 56.8389118462801, 55.52178092300892, 6.1701649613678455, 1.1732055712491274, 1.422305004671216, 6.1133637093007565, 4.1088734194636345, 0.30450948514044285, 22.7943479642272, 66.12503975629807, 51.71104520559311, 60.03450997173786, 58.15370209515095, 56.80323176085949, 56.22209474444389, 55.052414909005165, 52.360422760248184, 55.61424136161804, 55.04056714475155, 56.70267015695572, 56.914147809147835, 59.4781856238842, 46.084227338433266, 50.20395487546921, 57.467230930924416, 55.44400289654732, 48.98739695549011, 39.00798484683037, 39.692822098731995, 41.186860129237175, 40.965723395347595, 40.72813734412193, 40.11243738234043, 37.51196712255478, 39.957812279462814, 39.61005873978138, 41.39532834291458, 40.54499477148056, 41.743226274847984, 44.33239974081516, 43.148778453469276, 40.066991820931435, 41.97829686105251, 39.02902811765671, 39.42755453288555, 41.84248074889183, 39.33784134685993, 43.47228929400444, 50.42056605219841, 49.388606026768684, 51.580810993909836, 51.22810252010822, 54.45308446884155, 52.240037620067596, 52.4119707942009, 52.23817951977253, 54.54296484589577, 52.61779434978962, 45.09620815515518, 41.39601990580559, 42.74142511188984, 40.28736859560013, 40.05013592541218, 42.408190593123436, 40.62406472861767, 43.763703256845474, 53.46519447863102, 44.72239941358566, 39.242926239967346, 40.77426306903362, 39.768977612257004, 40.359063148498535, 39.122503101825714, 39.5609387755394, 37.87726432085037, 41.10634244978428, 46.197453662753105, 55.90967930853367, 54.80654150247574, 54.117266088724136, 53.8607494533062, 52.833482176065445, 51.50843247771263, 52.314642816782, 51.5676598995924, 52.68371321260929, 51.120537891983986, 39.800956696271896, 37.88721218705177, 38.26141230762005, 39.411394000053406, 39.02280405163765, 38.72227817773819, 39.395476654171944, 38.17611828446388, 39.141095504164696, 37.62612819671631, 41.2812964618206, 41.30704388022423, 41.994917169213295, 46.19205415248871, 43.70653912425041, 42.71586388349533, 42.49377340078354, 41.60546466708183, 38.564035668969154, 38.935024961829185, 37.134654968976974, 37.837237268686295, 39.6172821521759, 42.474193051457405, 49.18386161327362, 56.12844876945019, 54.89144414663315, 54.57796096801758, 56.4727558940649, 56.2492822855711, 52.50742167234421, 51.76356598734856, 53.58309455215931, 56.004184037446976, 55.433941036462784, 56.317982599139214, 51.49677090346813, 42.97683008015156, 46.27346858382225, 56.0765777528286, 60.30154064297676, 62.697270289063454, 50.39132662117481, 3.8025939418002963, 1.556748440489173, 1.7815007991157472, 0.7582085835747421, 19.14371855556965, 67.04558596014977, 60.532610043883324, 64.681436419487, 63.54009546339512, 65.8197869360447, 56.19280591607094, 40.6877227127552, 22.061036713421345, 40.701470375061035, 56.44928455352783, 6.142928022891283, 0.42816022352781147, 0.053058233970659785, 0.09702756346086971, 0.10112401083461009, 0.06982762104598805, 0.028423905350791756, 0.05803312444186304, 0.03109922712610569, 0.10879540583118796, 0.11924565405934118, 0.0826255050196778, 0.07149749784730375, 0.10393617165391333, 0.1987611298682168, 0.18308044003788382, 0.22873604408232495, 0.21767489699414, 0.2015226020012051, 0.3025533619802445, 0.6187756592407823, 52.39596985280514, 74.39044743776321, 45.61877131462097, 34.003786370158195, 51.534461081027985, 70.03170892596245, 67.97494769096375, 70.24900406599045, 68.00910785794258, 65.83530530333519, 61.62413567304611, 62.32781611382961, 9.215412754565477, 4.682734776288271, 12.52934318035841, 15.501101016998291, 11.0835150629282, 0.6175500468816608, 26.32508620619774, 62.010099962353706, 53.19338746368885, 62.59230472147465, 61.465171203017235, 59.624120593070984, 59.846826642751694, 57.17976875603199, 55.61291143298149, 58.35072912275791, 58.34504462778568, 59.0813235193491, 59.15993370115757, 60.65071530640125, 48.42870153486729, 52.863204181194305, 59.847795590758324, 59.9402142316103, 51.92487493157387, 39.937798753380775, 42.83118009567261, 45.651487559080124, 44.12994660437107, 42.98384070396423, 43.331917226314545, 41.0935827344656, 42.54075028002262, 42.48847648501396, 42.53478839993477, 43.858914747834206, 43.90249840915203, 47.04854719340801, 45.47804206609726, 42.019106671214104, 43.690720573067665, 41.40192858874798, 40.981716737151146, 44.78199541568756, 43.30381393432617, 44.42315027117729, 53.669794499874115, 50.625895634293556, 55.70468030869961, 55.23281402885914, 58.62209156155586, 55.05053400993347, 54.82962526381016, 54.817222729325294, 55.260791927576065, 56.64612919092178, 46.37708142399788, 42.42541886866093, 44.26948271691799, 39.50053721666336, 40.63260667026043, 42.48416371643543, 40.69044716656208, 44.4857557117939, 55.52301585674286, 47.43164263665676, 41.11420802772045, 43.68506647646427, 38.746395483613014, 39.471221789717674, 39.68675762414932, 39.61315177381039, 38.492063730955124, 40.844015926122665, 48.26220206916332, 60.30036270618439, 58.14535394310951, 56.5383555740118, 55.02547815442085, 56.8453449010849, 55.38400411605835, 55.4532516002655, 56.71422153711319, 55.03255717456341, 53.1789406388998, 45.0263375043869, 39.47311408817768, 41.16007536649704, 41.44738554954529, 44.54756699502468, 40.81850789487362, 39.8293449729681, 39.44187976419926, 40.486789494752884, 39.29668955504894, 44.08368028700352, 42.66328230500221, 43.506935834884644, 49.91581633687019, 48.30915994942188, 45.78345827758312, 44.27631855010986, 43.833798095583916, 40.5945099145174, 41.43817864358425, 39.29669715464115, 39.858573004603386, 41.651282608509064, 44.90024507045746, 51.45992048084736, 60.23800045251846, 57.6534703373909, 56.34402260184288, 58.239847272634506, 60.31173549592495, 53.58108066022396, 54.436863139271736, 56.70582018792629, 57.32106797397137, 56.918445378541946, 60.1919811218977, 54.91731695830822, 46.1526008695364, 48.97350490093231, 58.2318677008152, 62.79851205646992, 65.1255413889885, 54.001577496528625, 5.222465889528394, 2.3733106115832925, 11.115261409431696, 1.2826505047269166, 21.468386314809322, 70.09794697165489, 65.0815549492836, 68.23589488863945, 69.18647468090057, 70.53011298179626, 62.40894936025143, 47.08293154835701, 35.00632457435131, 48.87830100953579, 67.88535609841347, 9.242477752268314, 0.5603823519777507, 0.19892075099051, 0.24101078073726967, 0.1396826421841979, 0.19396103743929416, 0.1122065911476966, 0.11923927901079878, 0.1211205120489467], [0.06398003170033917, 0.055336549412459135, 0.037202798048383556, 0.02241583584691398, 0.04139770244364627, 0.017691830253170338, 0.06858692824607715, 0.056243398212245665, 0.065755093091866, 0.013452627063088585, 0.2270041682641022, 0.23614147561602294, 14.73928939551115, 56.492077857255936, 31.087482757866383, 19.73481483757496, 27.264931574463844, 53.33267278969288, 61.07820376753807, 60.595690459012985, 55.500160083174706, 55.376651510596275, 49.47610393166542, 62.798930034041405, 20.78467570245266, 1.3763290154747665, 1.638979115523398, 2.473091594874859, 5.069993371143937, 0.4972224379889667, 28.00225730985403, 49.73646216094494, 50.72928808629513, 55.67465431988239, 55.34788325428963, 55.95834709703922, 54.886382818222046, 53.20074766874313, 55.20828254520893, 54.81820687651634, 54.911978244781494, 54.25762675702572, 53.25887694954872, 51.19845271110535, 49.251266196370125, 54.57941249012947, 52.36885830760002, 51.73079654574394, 41.20144374668598, 37.68647275865078, 37.39419624209404, 37.89823539555073, 37.52263695001602, 37.692480236291885, 37.403015568852425, 37.17811703681946, 35.696029365062714, 39.44510959088802, 40.21527126431465, 38.98977242410183, 40.257695987820625, 40.24296797811985, 40.23668311536312, 38.33660267293453, 39.59776259958744, 39.54244516789913, 36.306694597005844, 38.47371071577072, 37.21678376197815, 40.94353638589382, 49.47822421789169, 47.82149411737919, 49.037805050611496, 50.37565626204014, 50.19015021622181, 49.142345041036606, 52.88025766611099, 51.62163980305195, 54.279327392578125, 49.21879693865776, 44.884730502963066, 40.2226846665144, 40.94747677445412, 42.275402918457985, 41.74728825688362, 39.81351502239704, 38.927220180630684, 43.14566642045975, 48.31315353512764, 44.028480648994446, 40.38772501051426, 41.23740881681442, 42.44334630668163, 42.79682993888855, 41.1868829280138, 38.860856741666794, 40.8455890417099, 41.85276299715042, 48.72708812355995, 53.25840197503567, 52.55534470081329, 52.55198188126087, 51.931072399020195, 50.36841005086899, 52.14470833539963, 48.076046258211136, 49.64964061975479, 48.34237016737461, 48.92129950225353, 43.06881934404373, 36.171680241823196, 36.782299876213074, 37.64321208000183, 36.654907912015915, 36.251890137791634, 38.16403113305569, 37.75181025266647, 37.806006744503975, 38.30753803253174, 37.20598094165325, 38.6206716299057, 41.77619330585003, 41.419909223914146, 43.413149267435074, 40.545906722545624, 39.530434012413025, 37.0714757591486, 38.69625337421894, 37.1632294356823, 37.04902656376362, 38.28016810119152, 38.79413992166519, 39.247102215886116, 38.298676908016205, 46.869937777519226, 50.84834709763527, 52.36534349620342, 52.59935773909092, 51.71071842312813, 55.16569443047047, 54.9314484000206, 53.021347895264626, 51.7488531768322, 58.270029053092, 56.82250812649727, 54.930802434682846, 42.972015738487244, 42.945956736803055, 50.43405532836914, 57.00301744043827, 55.457644164562225, 45.05483977496624, 0.9500744193792343, 0.579163022339344, 0.9090825158637017, 0.19625093409558758, 31.4179852232337, 58.884615674614906, 52.74785377085209, 57.20534138381481, 57.01434463262558, 61.33355766534805, 43.09157632291317, 40.24205982685089, 25.240134224295616, 45.952374413609505, 32.98847325146198, 1.228372436016798, 0.081508906732779, 0.022483530847239308, 0.07933729357318953, 0.09825941728195176, 0.0825870172411669, 0.07616855305968784, 0.05598870797257405, 0.01478568014135817, 0.06537267923704349, 0.039805680644349195, 0.018442091459291987, 0.061751414177706465, 0.011415608878451167, 0.020890277082799003, 0.16220431571127847, 0.04841926180233713, 0.013403400407696608, 0.029165353553253226, 0.36973215406760573, 0.21684449311578646, 21.494356021285057, 65.27260109782219, 35.572365000844, 20.30030619353056, 36.485034227371216, 59.43718582391739, 66.42715394496918, 64.42523896694183, 59.75475378334522, 61.445697247982025, 54.788564667105675, 65.56705489754677, 21.909721232950687, 0.9573234210256487, 2.4705920414999127, 3.5754920030012727, 7.917297910898924, 0.7212331239134073, 30.66258005797863, 50.30315615236759, 52.39418774843216, 57.85593867301941, 59.465729892253876, 58.6520529538393, 57.914546728134155, 55.51244102418423, 57.71884202957153, 56.92314572632313, 55.2898907661438, 57.12409794330597, 57.26294249296188, 52.90879413485527, 49.49860632419586, 57.13179253041744, 54.279654175043106, 54.20415982604027, 43.70821863412857, 39.64918904006481, 39.66585494577885, 39.96694698929787, 40.80859802663326, 39.22967255115509, 39.44197095930576, 39.41753827035427, 40.33265456557274, 40.370819717645645, 41.62913739681244, 41.29117593169212, 40.8560536801815, 41.96937493979931, 41.26964248716831, 40.86209915578365, 40.82065477967262, 40.1866701990366, 38.54657560586929, 41.568105071783066, 39.8482109606266, 44.30878400802612, 51.62692531943321, 51.79010756313801, 50.2553129196167, 52.83607363700867, 52.0645060390234, 54.04313966631889, 54.55949775874615, 53.106687515974045, 54.890524595975876, 51.06247700750828, 45.79036630690098, 39.80586603283882, 39.30515930056572, 41.1656154692173, 40.99680952727795, 39.69200134277344, 39.480603486299515, 43.507255017757416, 51.26740761101246, 44.84460845589638, 39.49789635837078, 40.44481314718723, 41.1577232927084, 41.62566818296909, 40.545933321118355, 39.759949296712875, 41.146882474422455, 41.45058877766132, 48.58507074415684, 53.24147388339043, 55.339075326919556, 53.51420044898987, 55.35588562488556, 52.765541821718216, 53.52059930562973, 51.091895028948784, 51.19053773581982, 49.87181469798088, 50.20853742957115, 44.864595383405685, 38.8058926910162, 39.255051389336586, 38.82703475654125, 38.68899956345558, 38.868900910019875, 39.18871454894543, 38.31566199660301, 39.31731104850769, 39.35445785522461, 39.76909540593624, 42.19462685286999, 43.42487923800945, 42.604073882102966, 45.26296980679035, 44.38029237091541, 41.48409157991409, 39.82467122375965, 41.573025807738304, 38.905971720814705, 40.22130914032459, 40.03736861050129, 40.357125252485275, 40.49391411244869, 40.996790528297424, 48.975625187158585, 52.872517481446266, 53.75428296625614, 54.77608993649483, 53.04915480315685, 57.37976722419262, 56.43122412264347, 55.00180162489414, 51.26901112496853, 59.75578732788563, 59.14354518055916, 55.89465871453285, 46.44558794796467, 44.38754618167877, 53.93936723470688, 61.05102762579918, 58.13327059149742, 47.389001324772835, 1.8980710627511144, 2.2433438105508685, 0.8942849223967642, 0.15597894351230934, 34.933448284864426, 64.20451641082764, 60.85188791155815, 61.79433614015579, 64.50696498155594, 66.28861337900162, 54.4993431866169, 46.361452862620354, 23.964160792529583, 51.99069879949093, 40.40947884321213, 1.5022536646574736, 0.09339581185486168, 0.03204051528882701, 0.11361424491042271, 0.04650262832001317, 0.06252424966078252, 0.05363454874895979, 0.038933798132347874, 0.06711078167427331, 0.22617006849031895, 0.14410222065635026, 0.1053753518499434, 0.08231148749473505, 0.09486095237662084, 0.1030932180583477, 0.19214189989725128, 0.13485604024026543, 0.10882126225624233, 0.11349516731570475, 0.38088823668658733, 0.4698611452477053, 24.677449017763138, 77.3102867603302, 42.16981418430805, 27.014722600579262, 41.131542697548866, 64.4279596209526, 72.06754848361015, 69.41523000597954, 67.78347596526146, 66.74936905503273, 59.675341844558716, 71.93417564034462, 27.601656205952168, 1.646101358346641, 7.7145312912762165, 7.781498422846198, 11.522201523184776, 1.827571545727551, 34.32566709816456, 52.137777507305145, 52.182007133960724, 59.45523865520954, 59.468834325671196, 61.567412316799164, 59.12896916270256, 59.66638572514057, 59.55274902284145, 60.1226120442152, 59.10409189760685, 61.772608906030655, 59.234155118465424, 55.77855974435806, 51.58241830766201, 58.155586794018745, 55.487681552767754, 56.81679703295231, 45.131223276257515, 41.56562380492687, 41.704551950097084, 42.97263890504837, 43.10443863272667, 43.331138268113136, 41.9199737906456, 41.86891213059425, 41.6787551343441, 45.00369071960449, 45.06828725337982, 44.06346537172794, 44.065593257546425, 43.16230192780495, 44.119789749383926, 42.64321558177471, 42.60280855000019, 41.467440873384476, 40.41720762848854, 45.66770888864994, 41.88958302140236, 47.24135644733906, 54.874196872115135, 55.351766645908356, 53.253150656819344, 55.05212612450123, 54.14965935051441, 55.362124890089035, 57.28366658091545, 54.60115112364292, 57.348601296544075, 53.469340056180954, 46.7163348197937, 41.04581169784069, 39.788934141397476, 41.295207515358925, 42.54607379436493, 40.4222347587347, 39.95992496609688, 45.424400344491005, 53.28882314264774, 46.82113319635391, 41.244468837976456, 40.04673890769482, 41.985406279563904, 42.41575598716736, 40.95668368041515, 39.24570009112358, 40.66294804215431, 42.681361734867096, 49.99204404652119, 55.64125031232834, 57.8705944865942, 56.5156289935112, 58.41682277619839, 56.15801118314266, 56.36463649570942, 54.25098471343517, 53.87545846402645, 50.82394100725651, 52.62688346207142, 47.987017035484314, 41.419590041041374, 41.30275771021843, 40.723824575543404, 39.84219968318939, 40.25169990956783, 41.72856666147709, 41.133514791727066, 42.536612302064896, 41.1765056848526, 40.292794704437256, 44.54695142805576, 46.23137824237347, 44.881823658943176, 47.63903550803661, 47.505126893520355, 44.28386874496937, 43.544899597764015, 43.814289942383766, 42.254789024591446, 42.364603132009506, 42.69996553659439, 42.73055009543896, 42.905447110533714, 42.36043855547905, 50.34978725016117, 57.443649396300316, 55.761050283908844, 58.24425123631954, 55.47443926334381, 60.03962069749832, 60.15354238450527, 55.890760123729706, 54.06246542930603, 64.19559448957443, 62.79889963567257, 59.43275906145573, 48.33166614174843, 49.06213514506817, 54.27696771919727, 65.23138850927353, 58.08212533593178, 50.97804933786392, 2.4054877599701285, 3.4693416114896536, 3.5818127263337374, 0.45622777368407696, 41.83898113667965, 70.37015676498413, 65.58359161019325, 66.63944095373154, 68.78596097230911, 69.2875948548317, 59.73588399589062, 51.19877569377422, 34.682460352778435, 61.68168358504772, 51.59962758421898, 2.3716980731114745, 0.2482534889713861, 0.14212424866855145, 0.24817327765049413, 0.2038001047912985, 0.18573787790955976, 0.25936416699551046, 0.19389810331631452, 0.10182139958487824], [0.04904603891191073, 0.046092350530670956, 0.06739950680639595, 0.02830582594469888, 0.014180696198309306, 0.010516924630792346, 0.042617526050889865, 0.08073942575720139, 0.20007962943054736, 0.06079662263800856, 0.12491157307522371, 0.18474095093552023, 5.150088323280215, 54.53233681619167, 40.436787977814674, 36.851296573877335, 31.20006501674652, 44.84414108097553, 57.77920179069042, 57.47524090111256, 55.01599386334419, 60.18322639167309, 48.545408472418785, 47.823086231946945, 37.605468705296516, 0.6211975542828441, 0.6196639209520072, 1.5014794562011957, 12.865028567612171, 1.6172928479500115, 28.7109287828207, 57.41428457200527, 55.81723026931286, 56.430688351392746, 55.661149844527245, 57.7723241597414, 59.203844144940376, 56.579860746860504, 53.46669539809227, 51.559406742453575, 55.44454626739025, 53.320346251130104, 50.48607833683491, 49.24909271299839, 56.20119966566563, 52.776105254888535, 50.821623131632805, 44.35136452317238, 37.702203914523125, 38.51971484720707, 38.91732931137085, 38.57692077755928, 36.95213936269283, 37.97001354396343, 36.194368824362755, 37.35543452203274, 37.250780537724495, 37.8814060986042, 37.890670001506805, 39.6081018447876, 40.276440382003784, 39.715890660881996, 38.03628958761692, 41.19271941483021, 39.886965081095695, 38.432045951485634, 36.234954446554184, 37.71378569304943, 36.49315059185028, 40.878111496567726, 47.25008077919483, 50.258877128362656, 49.67852286994457, 48.88633757829666, 50.743837505578995, 52.52675883471966, 52.88203217089176, 52.18796141445637, 51.12463407218456, 45.97871080040932, 43.88025440275669, 42.530335038900375, 41.286528781056404, 39.90672402083874, 37.44859792292118, 40.01472942531109, 37.99612574279308, 44.530832692980766, 46.51916339993477, 46.310577392578125, 41.45070657134056, 40.47768138349056, 41.13453693687916, 41.53002731502056, 41.70441895723343, 42.03434005379677, 40.048118233680725, 38.16530026495457, 46.57036945223808, 50.81133708357811, 52.25913539528847, 51.99029602110386, 50.073481276631355, 51.352694034576416, 47.833668664097786, 50.735493153333664, 50.87027192115784, 48.80077376961708, 49.98160980641842, 47.286707013845444, 36.507449224591255, 34.75173823535442, 34.28484208881855, 35.840376019477844, 35.31031586229801, 37.300284281373024, 36.88718944787979, 38.85888084769249, 37.29692526161671, 38.57569344341755, 36.78674563765526, 38.63026611506939, 39.354461655020714, 37.48515956103802, 38.39912451803684, 37.38653965294361, 35.49120895564556, 35.06563179194927, 36.50342144072056, 34.47226703166962, 36.657582968473434, 38.14330704510212, 39.30349498987198, 37.69668661057949, 37.67299488186836, 41.7167416960001, 45.336932837963104, 46.48893602192402, 50.60196451842785, 51.09818749129772, 55.530516654253006, 54.745870158076286, 52.58130870759487, 45.28126962482929, 52.86107249557972, 56.319415122270584, 50.07503159344196, 41.1641601473093, 52.640900909900665, 54.940370321273804, 59.63391646742821, 36.76121860742569, 0.37218691140878946, 3.769628335721791, 0.30855240882374346, 0.521740741096437, 38.64606186747551, 59.35297854244709, 53.940351381897926, 59.35688853263855, 58.1335935741663, 53.59284482896328, 40.87779611349106, 30.125201493501663, 27.74414476007223, 53.47162373363972, 19.252312928438187, 0.8054594043642282, 0.03374329149664845, 0.1888480258639902, 0.02976049105200218, 0.12073908525053412, 0.030467794895230327, 0.029119514802005142, 0.080194711626973, 0.03988933181972243, 0.061633742952835746, 0.05973834231554065, 0.07544176041847095, 0.015360122852143832, 0.07971244922373444, 0.028287903078307863, 0.02081902162899496, 0.05542245300603099, 0.022726561946910806, 0.01714876740152249, 0.2019216399639845, 0.27480342134367675, 7.8376684337854385, 62.84608170390129, 44.03371296823025, 30.74592288583517, 36.74657419323921, 56.296836733818054, 62.40860737860203, 65.80645725131035, 60.215954035520554, 65.10681599378586, 52.39829532802105, 56.922522559762, 39.235854819417, 0.7116326421964914, 1.6670296853408217, 2.287562037818134, 17.01359085738659, 2.0582650043070316, 32.26392813026905, 57.58996054530144, 56.13048546016216, 56.583599746227264, 57.10389822721481, 58.47905583679676, 59.26117166876793, 59.77392375469208, 55.789031982421875, 52.83984303474426, 57.7146128565073, 55.59141978621483, 52.0236012339592, 49.43677984178066, 57.74857923388481, 54.1426145285368, 53.107614666223526, 47.2376174479723, 39.801925644278526, 39.30173568427563, 41.98656141757965, 40.328964963555336, 40.035453513264656, 39.43483494222164, 39.54608537256718, 40.391821190714836, 39.48390930891037, 41.1286586523056, 41.23814217746258, 42.2827061265707, 42.094148844480515, 40.94684600830078, 41.33396543562412, 41.88031151890755, 41.74111358821392, 40.01223295927048, 38.59945736825466, 39.99803692102432, 38.77326004207134, 44.213120341300964, 50.064289569854736, 51.45321764051914, 51.044868752360344, 52.51957342028618, 53.65328438580036, 54.34169724583626, 53.287383019924164, 53.59262444078922, 54.66019995510578, 48.10356818139553, 44.211912006139755, 41.454593762755394, 41.40884421765804, 40.54694786667824, 38.056660294532776, 39.897418320178986, 38.86665143072605, 45.20031876862049, 48.96595470607281, 47.90115304291248, 43.08353595435619, 39.68003958463669, 41.62669412791729, 40.57063579559326, 42.01141208410263, 41.308001428842545, 40.30301995575428, 38.248880580067635, 45.748336762189865, 52.28618994355202, 54.82359118759632, 53.96896384656429, 52.55347900092602, 53.74007172882557, 50.56017056107521, 52.06828683614731, 52.541908621788025, 50.099156498909, 51.56656935811043, 50.76372563838959, 39.72467198967934, 36.11347496509552, 35.885954573750496, 38.91196019947529, 37.39146038889885, 39.040739089250565, 38.181977570056915, 40.4979494959116, 39.69774663448334, 40.365606397390366, 39.182308092713356, 40.23830562829971, 41.493363082408905, 41.60289980471134, 39.69827100634575, 39.2448603361845, 38.48729878664017, 39.15474057197571, 37.62528844177723, 37.79494933784008, 38.74723523855209, 41.308199018239975, 40.56258402764797, 39.17225383222103, 39.40159052610397, 44.86003942787647, 46.88618950545788, 49.769980162382126, 51.932546719908714, 54.014481604099274, 55.958092510700226, 56.90964885056019, 53.32717448472977, 46.29295013844967, 54.089428782463074, 59.66989293694496, 52.17867091298103, 44.2054333537817, 56.20868146419525, 58.40022526681423, 60.17789147794247, 39.19923238456249, 0.9209241054486483, 5.481938291341066, 0.3732484794454649, 0.5504861986264586, 44.11605454981327, 64.23901095986366, 60.36780908703804, 65.31290173530579, 67.34144568443298, 60.18121249973774, 48.640927746891975, 35.66500782966614, 29.727999307215214, 59.34365764260292, 24.62259516119957, 0.8645474212244153, 0.01455489540603594, 0.10736505719251, 0.010488443786016433, 0.06807214493164793, 0.0258077253238298, 0.02634268021211028, 0.03063929409108823, 0.014866336750856135, 0.09173301514238119, 0.14995665260357782, 0.24819785758154467, 0.14242774253943935, 0.16610102145932615, 0.10600417357636616, 0.14612458791816607, 0.18827219348168, 0.23092570627341047, 0.12048697026330046, 0.303038073470816, 0.4123621853068471, 9.087956193834543, 75.54427832365036, 53.958510607481, 47.010028660297394, 44.72087189555168, 60.60155354440212, 66.8860325217247, 69.97074499726295, 65.51173746585846, 70.40867149829865, 60.02487748861313, 63.62458012998104, 43.808723241090775, 0.665872588288039, 5.57280614040792, 11.24921752139926, 18.61790657043457, 3.1459238659590483, 35.69746568799019, 58.467671647667885, 56.592054292559624, 59.15720924735069, 57.02580101788044, 61.070892959833145, 61.3263114541769, 62.399917244911194, 56.787990778684616, 56.607481464743614, 58.71291808784008, 57.128562703728676, 53.530611768364906, 50.89734926819801, 58.79663899540901, 57.439583614468575, 54.969552755355835, 49.44571316242218, 41.647304221987724, 41.38836331665516, 44.396114721894264, 44.87976796925068, 41.69918283820152, 43.557248935103416, 41.387253776192665, 42.50630512833595, 42.32415430247784, 43.16590033471584, 43.55026111006737, 46.39915443956852, 46.345881298184395, 45.00654436647892, 42.561728954315186, 44.13961708545685, 43.112691789865494, 42.63999715447426, 40.099354684352875, 42.58265823125839, 42.59739764034748, 45.575632229447365, 52.01889328658581, 55.917385295033455, 52.601934000849724, 55.617288798093796, 57.761076763272285, 56.71450272202492, 58.198847472667694, 57.11098864674568, 56.038655787706375, 49.36424933373928, 45.49947291612625, 43.12296263873577, 41.145571544766426, 40.55556200444698, 38.041206523776054, 40.461338460445404, 38.27058881521225, 48.46640311181545, 50.64598135650158, 48.470932468771935, 42.83584624528885, 41.3273423910141, 41.41920246183872, 40.474253967404366, 42.31599614024162, 43.27705197036266, 38.206201270222664, 37.50257782638073, 46.68909788131714, 54.86513055860996, 57.75035373866558, 56.647888496518135, 54.08668152987957, 55.89157707989216, 50.81636041402817, 56.816922426223755, 56.68004237115383, 52.37328886985779, 53.10719668865204, 53.10428984463215, 42.99631543457508, 39.6253415197134, 37.053498923778534, 42.98808507621288, 38.95438872277737, 41.40009708702564, 39.712596237659454, 42.73575581610203, 41.93674609065056, 42.95410729944706, 41.949794590473175, 44.02473405003548, 45.18657110631466, 43.79637770354748, 42.54070468246937, 43.42888042330742, 41.19793273508549, 41.022868528962135, 41.18981257081032, 39.633712470531464, 39.88755784928799, 44.02729511260986, 43.35800662636757, 42.87718042731285, 40.972635224461555, 45.92851549386978, 47.67833299934864, 52.47141860425472, 55.167012959718704, 57.06403836607933, 59.74222585558891, 60.5723787099123, 53.13675910234451, 49.24194149672985, 55.73481269180775, 62.40242511034012, 54.93752807378769, 47.33612336218357, 57.02658757567406, 60.64202897250652, 61.79246284067631, 45.95521666109562, 1.7016786010935903, 7.134596910327673, 2.8313677199184895, 0.6126837548799813, 48.732886612415314, 68.01454916596413, 65.72012588381767, 68.04820775985718, 70.85475236177444, 64.92593050003052, 54.585488364100456, 41.620344668626785, 37.451139986515045, 69.87368300557137, 31.293338611721992, 0.8503684226889163, 0.07096298082615249, 0.1931062911171466, 0.20960500580258667, 0.14571606530807912, 0.09822924897889607, 0.18044219410512596, 0.22799120983108878, 0.18417804676573724], [0.051483875286066905, 0.07609093925566413, 0.03819124598521739, 0.06395067975972779, 0.11929043525015004, 0.03473670811217744, 0.04997724128770642, 0.050052435690304264, 0.05229267153481487, 0.038362006744137034, 0.07042119075777009, 0.09915863309288397, 0.3757621336262673, 37.75630161166191, 50.79079158604145, 27.29692205786705, 20.38082767277956, 39.4320534914732, 54.346564784646034, 60.513189285993576, 58.466136530041695, 57.97952324151993, 52.89348095655441, 54.43655535578728, 49.60762247443199, 2.6063378574326634, 1.3411482470110059, 2.770584993995726, 3.134092725813389, 2.089809011667967, 36.730702444911, 61.28743574023247, 61.04945071041584, 58.25830288231373, 58.343802094459534, 54.22203786671162, 55.08736163377762, 54.44651462137699, 53.49233642220497, 58.73421214520931, 56.86621718108654, 56.486948132514954, 53.71436230838299, 53.464787900447845, 54.35362860560417, 51.86575770378113, 49.41440664231777, 38.93594071269035, 39.67546463012695, 38.03894564509392, 40.69853313267231, 38.62920977175236, 35.06870962679386, 37.76136294007301, 36.55269719660282, 37.77773626148701, 39.00407865643501, 39.0314219892025, 40.777447298169136, 40.57087518274784, 39.29264657199383, 39.825222194194794, 39.1736825555563, 38.411827236413956, 37.54077337682247, 37.905272617936134, 36.50763921439648, 37.395168989896774, 36.096850857138634, 41.2497391551733, 48.28302875161171, 49.12773862481117, 50.597408562898636, 50.06508372724056, 49.67528164386749, 50.57149015367031, 50.27189522981644, 52.36852012574673, 52.65401400625706, 46.23032569885254, 44.348643869161606, 41.83541692793369, 40.31406216323376, 39.889613538980484, 40.02969682216644, 39.16288733482361, 39.711695685982704, 44.536919966340065, 46.78515672683716, 46.73776566982269, 44.69497628509998, 40.41762560606003, 39.92577999830246, 39.65451255440712, 42.62209251523018, 41.20547533035278, 42.47038185596466, 40.38031540811062, 45.23202046751976, 49.57236796617508, 53.7527896463871, 50.783704966306686, 52.2825725376606, 49.92294855415821, 49.27482113242149, 49.660276249051094, 50.141714215278625, 49.35623176395893, 47.37838089466095, 47.97953903675079, 38.00655238330364, 33.74844007194042, 35.01855991780758, 37.655778005719185, 35.64617983996868, 36.64458006620407, 37.152912989258766, 37.25135810673237, 36.941397339105606, 38.93665887415409, 39.01510566473007, 38.40725988149643, 37.44538329541683, 35.85536241531372, 37.20015965402126, 38.71089018881321, 37.063917964696884, 36.29260495305061, 36.66765622794628, 37.346307411789894, 36.78951568901539, 36.90920166671276, 37.04355485737324, 37.974767088890076, 37.43425749242306, 37.26322486996651, 39.77413773536682, 39.102584570646286, 41.194904297590256, 47.82389558851719, 52.05654166638851, 51.558677181601524, 51.59308813512325, 39.12241570651531, 54.25699979066849, 55.36903291940689, 54.33059424161911, 46.09282247722149, 52.14421436190605, 56.295389011502266, 54.791805893182755, 27.839331552386284, 0.816367669031024, 3.2367226062342525, 0.9169539122376591, 3.299587620422244, 48.648284152150154, 53.03832158446312, 56.850391030311584, 52.15287409722805, 47.40497186779976, 47.812769785523415, 37.396840900182724, 28.27133607119322, 34.537368938326836, 44.286859184503555, 4.771229177713394, 0.5156735354103148, 0.058434451930224895, 0.11217163599212654, 0.028561052386066876, 0.10973127631586976, 0.06658902959316038, 0.05625574754958507, 0.06737208444974385, 0.0737042145919986, 0.06671073439065367, 0.04161411641689483, 0.12216345217893831, 0.05234278134594206, 0.04357621757662855, 0.029340964247239754, 0.060325447921059094, 0.03253036615205929, 0.03918564965715632, 0.05170584423467517, 0.09699893882498145, 0.09051852757693268, 1.0868052137084305, 46.94865055382252, 55.11046439409256, 32.87814237177372, 30.873474441468716, 46.551427468657494, 59.71955247223377, 66.97468176484108, 62.043131589889526, 64.51528653502464, 58.2112880051136, 58.71150456368923, 52.986978739500046, 3.567273519001901, 2.418350069783628, 3.7644634628668427, 5.416199443861842, 2.063612979836762, 41.056029349565506, 61.61761902272701, 63.66801179945469, 59.48433369398117, 59.50294129550457, 56.64040669798851, 58.18145200610161, 56.8083880841732, 55.952415615320206, 58.769603446125984, 56.81560389697552, 57.4351492524147, 55.80283664166927, 55.10510668158531, 57.08871804177761, 55.85576020181179, 52.22459904849529, 41.00220903754234, 41.901240795850754, 42.007103115320206, 42.27168291807175, 39.71484191715717, 37.98858694732189, 40.46441249549389, 39.32815946638584, 40.319385677576065, 40.74558600783348, 41.999222338199615, 43.37915249168873, 41.47153705358505, 41.91915683448315, 40.736113116145134, 39.92532022297382, 41.80337704718113, 39.28460620343685, 40.79769641160965, 37.878183871507645, 39.93163928389549, 39.49340879917145, 42.57129684090614, 51.63483649492264, 52.592012733221054, 51.49055063724518, 54.03740957379341, 50.499161034822464, 51.70354060828686, 51.84405706822872, 52.6908378303051, 54.57644484937191, 46.46926447749138, 44.38496232032776, 42.03560158610344, 41.28843627870083, 40.273233354091644, 39.948696568608284, 39.73992817103863, 40.03788158297539, 47.270174100995064, 49.827965050935745, 47.375565245747566, 45.4744778573513, 42.25660152733326, 40.75041554868221, 40.268962383270264, 41.01780340075493, 41.380471140146255, 43.4856341779232, 39.648360684514046, 44.98906530439854, 50.38287207484245, 54.009921848773956, 52.68283165991306, 53.62358517944813, 51.720157116651535, 50.23882560431957, 50.87865047156811, 51.26497954130173, 51.84013567864895, 50.58171160519123, 47.48137816786766, 40.02756513655186, 36.34775139391422, 37.93875262141228, 38.84506478905678, 39.388583824038506, 38.42798016965389, 39.7226656973362, 38.68019163608551, 39.33872289955616, 39.86160524189472, 40.721544697880745, 39.9258141964674, 40.80814965069294, 37.26472198963165, 38.90950933098793, 38.57556425035, 38.39890792965889, 38.56086663901806, 39.800398126244545, 38.70859131217003, 39.33008216321468, 39.64627079665661, 39.9470816552639, 39.57225076854229, 40.88214688003063, 39.838206097483635, 41.09362453222275, 40.915987864136696, 44.287938326597214, 50.83874501287937, 55.60695715248585, 54.746709913015366, 54.75295677781105, 41.65656812489033, 56.01846367120743, 58.68801422417164, 57.27287895977497, 48.30267369747162, 54.98539410531521, 59.14538808166981, 57.388217970728874, 29.63720317929983, 1.6617985535413027, 4.054851718246937, 1.2651317822746933, 5.064288452267647, 54.23796281218529, 58.956431820988655, 62.062442153692245, 59.52036336064339, 55.008835047483444, 53.12723681330681, 48.30664448440075, 27.05890852957964, 36.106319949030876, 55.535190403461456, 7.211211724206805, 0.4265493177808821, 0.04254739309544675, 0.1081632889690809, 0.024441817367915064, 0.10191666166065261, 0.02432532430248102, 0.038809436446172185, 0.018641321003087796, 0.08749985674512573, 0.15762125694891438, 0.2206645646947436, 0.15136694099055603, 0.171403948625084, 0.16192065202631056, 0.12028514320263639, 0.10289829297107644, 0.21893503406317905, 0.14517826057272032, 0.15668002073653042, 0.15306261484511197, 0.17656674346653745, 1.0787019110284746, 54.51557211577892, 66.95210337638855, 37.227670177817345, 30.50361178815365, 52.75758504867554, 64.3472595512867, 72.16012671589851, 68.16652581095695, 69.43094596266747, 63.20391230285168, 65.04787355661392, 58.0270054936409, 4.504655906930566, 3.6888667568564415, 13.506941422820091, 6.295984284952283, 3.9124268107116222, 47.48937673866749, 60.30744172632694, 68.08679848909378, 61.73882111907005, 63.84133189916611, 57.89513736963272, 58.783221915364265, 57.29976251721382, 58.85184623301029, 61.17491617798805, 60.05160145461559, 58.84312950074673, 58.53985637426376, 57.48057201504707, 59.76640775799751, 59.529923647642136, 54.78974260389805, 42.23860189318657, 46.28975071012974, 42.36123651266098, 45.66128723323345, 42.042517215013504, 39.66018944978714, 43.7945120036602, 42.02668346464634, 43.66041719913483, 43.044075071811676, 43.72801937162876, 45.512346625328064, 44.42072980105877, 44.32185150682926, 43.040712252259254, 41.941047459840775, 42.40965351462364, 40.525729805231094, 43.13628472387791, 39.237986505031586, 43.894990012049675, 40.912590846419334, 45.14931030571461, 52.55791716277599, 53.794237822294235, 55.520568788051605, 55.578477680683136, 53.104054257273674, 54.69126708805561, 54.34934623539448, 55.92268221080303, 59.40270647406578, 47.090515941381454, 44.97630938887596, 43.68974782526493, 42.180012837052345, 41.48173950612545, 40.935032442212105, 41.66719615459442, 40.9560377150774, 49.06701408326626, 50.03683224320412, 49.22755926847458, 47.50797674059868, 42.03218176960945, 40.27129925787449, 39.64539684355259, 41.58788301050663, 42.32852406799793, 44.42639909684658, 39.37008261680603, 46.07264555990696, 53.206382766366005, 57.13560752570629, 54.52195957303047, 57.672598510980606, 53.42806667089462, 52.65394940972328, 54.19430315494537, 52.89337836205959, 53.64829525351524, 54.18591320514679, 51.89167611300945, 42.12872698903084, 37.94756814837456, 38.21245953440666, 42.024270594120026, 41.0683748871088, 41.628069654107094, 40.90423509478569, 40.80924779176712, 41.55514396727085, 41.055368185043335, 44.49935518205166, 42.600068897008896, 43.10698829591274, 39.596436470746994, 41.24406985938549, 43.32717128098011, 42.04795852303505, 40.67343927919865, 41.52968153357506, 41.749530136585236, 41.46285071969032, 41.12311854958534, 41.64909392595291, 42.1528746932745, 42.09262892603874, 42.196648344397545, 44.1613557189703, 43.85763801634312, 45.68171113729477, 54.23409081995487, 56.93813592195511, 57.56541386246681, 56.02574408054352, 42.51113846898079, 56.82817742228508, 60.64170978963375, 59.70776170492172, 52.35952980816364, 59.148876294493675, 62.500874027609825, 56.15920051932335, 33.2409431040287, 3.324940809980035, 8.625232223421335, 2.8886299347504973, 5.719985067844391, 58.18092383444309, 65.71531534194946, 65.17405718564987, 64.25969704985619, 60.699090510606766, 61.605839654803276, 51.71196475625038, 37.949460446834564, 43.322520330548286, 65.17789497971535, 10.929148346185684, 0.684475083835423, 0.17162645934149623, 0.1995141277438961, 0.08387884401599877, 0.1484810552210547, 0.07218372469651513, 0.21594382269540802, 0.2549293002812192, 0.20002779783681035], [0.05691060381650459, 0.00958487527896068, 0.02100974987115478, 0.043749264150392264, 0.10459397424710914, 0.019911688577849418, 0.11438980407547206, 0.03854714290355332, 0.058669634818215854, 0.1606772726518102, 0.05064408323960379, 0.18871299951570109, 0.09288007859140635, 18.220949470996857, 58.5711894929409, 24.04798049479723, 22.041800245642662, 33.845642656087875, 50.822428688406944, 58.345363810658455, 47.01153717935085, 57.49540641903877, 56.31020061671734, 51.94182962179184, 52.88118101656437, 8.997048921883106, 1.1054287268780172, 1.0565248760394752, 5.105053139850497, 21.451266333460808, 43.69783379137516, 63.515138402581215, 56.79889619350433, 55.339744091033936, 54.39019784331322, 56.640110313892365, 54.66773875057697, 57.19313643872738, 55.15439383685589, 54.237035661935806, 53.42599958181381, 58.00379253923893, 54.201309978961945, 53.78172889351845, 52.342491522431374, 50.424848422408104, 42.36002437770367, 39.813955798745155, 38.94937299191952, 38.76584284007549, 38.9361497014761, 36.91058859229088, 36.919024139642715, 35.31864121556282, 36.824542209506035, 36.22667469084263, 39.57540459930897, 41.694467291235924, 40.591348484158516, 40.80634854733944, 39.21336382627487, 41.36673867702484, 39.853462278842926, 40.11421948671341, 39.49528589844704, 38.26261684298515, 38.05280350148678, 36.830424293875694, 37.29456938803196, 40.41044019162655, 46.91317945718765, 48.63867066800594, 49.38478343188763, 49.43427957594395, 50.41079677641392, 51.44840329885483, 50.16233190894127, 50.882438868284225, 51.15869544446468, 45.05917154252529, 42.48803570866585, 41.91083528101444, 41.15144982933998, 38.53041887283325, 40.266416519880295, 40.07040023803711, 40.53359918296337, 44.57352340221405, 42.71015278995037, 43.86997975409031, 44.88339677453041, 42.642387226223946, 40.86701609194279, 38.66599939763546, 39.81932491064072, 41.048190370202065, 41.42203330993652, 42.74100333452225, 41.184382662177086, 47.146760523319244, 52.2989496588707, 50.52082747220993, 50.59565685689449, 50.394176468253136, 48.96866396069527, 46.983464285731316, 50.41013561189175, 48.24625812470913, 47.88796775043011, 48.368752151727676, 37.88614444434643, 35.584740936756134, 34.33779984712601, 37.591610848903656, 36.35627433657646, 36.75189770758152, 36.401347517967224, 37.736968249082565, 36.6060995310545, 37.797225415706635, 37.002330869436264, 37.50430293381214, 36.47021122276783, 35.6742375344038, 35.89953884482384, 35.923975333571434, 35.908814147114754, 36.07782527804375, 36.25887796282768, 36.82646870613098, 37.67433241009712, 38.11496436595917, 37.459396943449974, 38.47727112472057, 42.14473932981491, 46.10927939414978, 46.87416315078735, 47.16193310916424, 46.42850786447525, 49.05138172209263, 51.10357940196991, 54.32177871465683, 55.42243145406246, 43.98357465863228, 52.23634421825409, 55.21938934922218, 53.37957367300987, 51.692673191428185, 54.60725739598274, 56.40599727630615, 53.77433829009533, 22.76251707226038, 1.1942440923303366, 1.012939908541739, 0.5764056765474379, 5.86133130826056, 56.54954217374325, 55.759249180555344, 56.80344074964523, 54.443140402436256, 54.97481547296047, 47.680506482720375, 27.4753300845623, 30.257415398955345, 44.28848549723625, 34.97520424425602, 1.199705230537802, 0.31218456861097366, 0.0472794083179906, 0.11788091127527878, 0.059725714672822505, 0.10550005492405035, 0.014939059801690746, 0.009952013879228616, 0.02207372246630257, 0.04607887312886305, 0.06421829079044983, 0.040740942567936145, 0.03050801002245862, 0.008976219560281606, 0.04656375531340018, 0.02180951789341634, 0.14082078501814976, 0.10132388604688458, 0.04044797235110309, 0.10065297712571919, 0.04213693719066214, 0.2588430605828762, 0.05122124777699355, 25.536208637058735, 66.06794402003288, 24.777081571519375, 21.734208650887012, 46.02843873202801, 55.35741314291954, 64.14938896894455, 61.276302337646484, 65.16746073961258, 61.15345872938633, 57.88048155605793, 57.12657541036606, 9.341553635895252, 1.7236296669580042, 3.1755420891568065, 8.226757105439901, 23.998697139322758, 45.51630221307278, 61.61730743944645, 61.94273717701435, 57.942646220326424, 56.126765459775925, 57.86478079855442, 57.508485317230225, 56.3337479531765, 56.49682380259037, 55.5077862739563, 56.837023347616196, 59.90919269621372, 57.02442929148674, 55.108598694205284, 56.6099551320076, 52.126096934080124, 43.92197996377945, 41.494066044688225, 41.65754087269306, 39.840512573719025, 41.38631522655487, 38.57403293251991, 38.757243901491165, 38.083996027708054, 38.68398003280163, 40.54344065487385, 41.59043647348881, 43.54652591049671, 42.424867898225784, 41.603348180651665, 41.08633652329445, 42.191932797431946, 42.16795988380909, 39.73770149052143, 41.57106131315231, 39.92194980382919, 39.910880997776985, 38.381976038217545, 41.06062330305576, 41.73635244369507, 49.05446335673332, 52.30657584965229, 52.90902592241764, 50.80998815596104, 51.95533409714699, 52.620123624801636, 51.25700756907463, 51.76945187151432, 52.516826167702675, 44.17844720184803, 41.626219153404236, 42.71750919520855, 40.237355679273605, 38.627431467175484, 41.768608912825584, 40.5135552585125, 43.52511025965214, 46.24139070510864, 44.460601061582565, 46.59226767718792, 45.751201808452606, 42.07465209066868, 41.71643391251564, 40.43278679251671, 38.255689814686775, 40.35790041089058, 42.18724384903908, 42.38960959017277, 42.123734056949615, 47.992462143301964, 52.74430476129055, 53.69383580982685, 52.0258355140686, 54.31649699807167, 51.40331871807575, 49.64636519551277, 51.737529784440994, 50.21991781890392, 50.84962382912636, 49.51781049370766, 40.792350098490715, 35.710377395153046, 36.801405251026154, 39.54520761966705, 38.40570956468582, 38.45554769039154, 38.53910520672798, 39.12889435887337, 39.00642693042755, 38.41013252735138, 39.686932414770126, 39.16341170668602, 39.35807526111603, 38.31520602107048, 37.02231779694557, 38.64928789436817, 37.87245757877827, 38.127876073122025, 38.356198221445084, 38.60484167933464, 39.16304312646389, 40.93206100165844, 38.60715575516224, 41.24964036047459, 45.86912848055363, 47.832065150141716, 49.21440437436104, 47.39362947642803, 48.75445045530796, 50.47049917280674, 52.248834148049355, 56.02361619472504, 56.902398839592934, 47.88566127419472, 53.01631696522236, 57.98588789999485, 55.24811580777168, 55.710619390010834, 57.13949851691723, 59.473386481404305, 55.70146948099136, 26.742898486554623, 0.9050247492268682, 2.441558986902237, 0.5786916695069522, 6.950679179280996, 60.59054173529148, 60.3864698857069, 63.38155277073383, 59.02745001018047, 55.63147723674774, 54.05048847198486, 40.17943538725376, 29.447095580399036, 46.42737552523613, 44.158034697175026, 2.0739655243232846, 0.3567860706243664, 0.044971570241614245, 0.05365734381484799, 0.07328983643674292, 0.0746415025787428, 0.044604897339013405, 0.015045437394292094, 0.04499122602283023, 0.0704405533906538, 0.1458993460983038, 0.1155918012955226, 0.05905133250053041, 0.1503928127931431, 0.20949025492882356, 0.11582335137063637, 0.18665998155483976, 0.17025854758685455, 0.13824042660417035, 0.21813197090523317, 0.11758618216845207, 0.32848895934876055, 0.17835223203292117, 28.2929740101099, 80.83199858665466, 32.955228835344315, 31.878408417105675, 48.90820540487766, 60.446062088012695, 71.03858649730682, 59.98750649392605, 69.03194457292557, 67.75561586022377, 61.019759103655815, 63.853232860565186, 11.019828580319881, 2.7533180080354214, 7.5766590144485235, 12.903435956686735, 30.23899208754301, 48.46338227391243, 61.15200340747833, 64.81397330760956, 59.6589495241642, 59.263139963150024, 61.746420711278915, 60.78876569867134, 61.01145654916763, 60.96811227500439, 58.05626392364502, 57.90011890232563, 62.68305145204067, 59.929422810673714, 56.87404856085777, 58.53240117430687, 54.37532924115658, 46.96810930967331, 44.090238735079765, 42.561899945139885, 41.942111402750015, 45.06812386214733, 40.099962651729584, 41.713823452591896, 40.728224739432335, 40.48531137406826, 41.182015389204025, 44.61943633854389, 46.68514609336853, 45.815840139985085, 43.85315425693989, 44.220925122499466, 45.71367122232914, 45.09700231254101, 43.83159041404724, 43.85603070259094, 40.99326811730862, 41.025577783584595, 42.35407769680023, 42.6543527841568, 45.493704825639725, 50.96048668026924, 53.59407216310501, 56.7943250387907, 53.86235676705837, 54.97736893594265, 56.23106986284256, 53.63473758101463, 53.505966290831566, 53.3182867616415, 44.870675057172775, 42.73194842040539, 42.47574336826801, 40.11007010936737, 39.756483882665634, 42.196203768253326, 41.72559902071953, 44.97413970530033, 47.5334657728672, 45.94100542366505, 46.13368548452854, 49.582011848688126, 44.711133018136024, 42.79366470873356, 40.56575305759907, 40.060817152261734, 41.40249855816364, 43.03880475461483, 44.17602673172951, 43.08141566812992, 47.420421838760376, 53.45733270049095, 54.91482429206371, 54.70577850937843, 54.55284431576729, 54.14402425289154, 52.00333692133427, 53.90353515744209, 53.11532065272331, 52.50486060976982, 51.528810784220695, 42.26131707429886, 38.90858598053455, 38.39263066649437, 43.46603102982044, 39.369847029447556, 39.90081533789635, 39.86591801047325, 41.661333069205284, 39.800732508301735, 42.16806247830391, 40.3863038867712, 41.81365169584751, 41.09818808734417, 41.705771684646606, 38.836340457201004, 41.4164400100708, 39.3854071944952, 41.137287989258766, 39.50244091451168, 41.68285511434078, 41.85193844139576, 43.854951560497284, 41.061516255140305, 43.849992826581, 47.80222535133362, 50.06472274661064, 52.48098649084568, 49.919274151325226, 51.461212411522865, 54.02224838733673, 55.23328900337219, 58.930038437247276, 59.580620527267456, 47.24044069647789, 55.70959344506264, 61.352647840976715, 59.85414884984493, 58.927868753671646, 60.20499162375927, 62.76314355432987, 58.62315930426121, 35.235387682914734, 1.2313691689632833, 3.941973550245166, 1.1542507633566856, 7.950318614020944, 70.14096066355705, 64.75585922598839, 66.70800447463989, 66.93664580583572, 62.89309658110142, 58.854798674583435, 41.21292293071747, 38.55976089835167, 54.54060897231102, 54.03629623353481, 2.9689728235825896, 0.5199514527339488, 0.19819724606350064, 0.2031562026240863, 0.13557768979808316, 0.11523891007527709, 0.13794286991469562, 0.1294715065159835, 0.12907068739878014, 0.14218397671356797], [0.05826100459671579, 0.056836544899852015, 0.018301376549061388, 0.006298519201664021, 0.036806320495088585, 0.05442050540295895, 0.02592038148577558, 0.008507211914547952, 0.01823467046051519, 0.024257119075627998, 0.059481637144926935, 0.13274186931084841, 0.19130112079437822, 3.1093684025108814, 46.405237913131714, 41.51218347251415, 27.714170068502426, 24.855843745172024, 46.04787848889828, 52.928796261548996, 42.87179231643677, 55.66311813890934, 56.28365524113178, 53.92468102276325, 56.27233564853668, 18.58829475939274, 1.5480942861177027, 1.4769958262331784, 2.839388852007687, 20.58617625385523, 30.83701729774475, 57.77519300580025, 58.57576444745064, 55.892998203635216, 50.420398861169815, 47.0051459223032, 49.4623676687479, 50.80722190439701, 51.423206850886345, 51.36306747794151, 50.0742070376873, 52.30599068105221, 50.8523178845644, 49.415918961167336, 47.61488780379295, 43.48152279853821, 39.51850265264511, 39.74240183830261, 38.293908163905144, 38.90081539750099, 37.836431711912155, 38.07398356497288, 37.45456360280514, 35.59419862926006, 35.85886962711811, 37.49067306518555, 38.842154145240784, 41.60452991724014, 40.92725045979023, 39.79674272239208, 40.760519206523895, 40.425658375024796, 41.113242879509926, 39.13337051868439, 38.93787860870361, 39.3918364495039, 37.28619463741779, 36.617939695715904, 38.642980232834816, 37.55776606500149, 44.8971102386713, 48.02980273962021, 50.40375955402851, 51.8475528806448, 50.71532003581524, 51.96996331214905, 49.15686786174774, 49.25339788198471, 44.15244519710541, 42.32093587517738, 40.074496418237686, 41.54334560036659, 37.26632930338383, 39.76575158536434, 39.64271418750286, 38.852292001247406, 41.81053966283798, 40.7208227366209, 39.109006226062775, 41.28730393946171, 40.04776865243912, 39.12470318377018, 39.888078421354294, 39.43692483007908, 37.51951351761818, 37.79415898025036, 40.1248437166214, 38.722266778349876, 41.356863006949425, 43.98261331021786, 49.73451666533947, 51.10576048493385, 50.51585353910923, 51.36350445449352, 50.23808844387531, 47.819958999753, 50.10826840996742, 49.43313203752041, 47.18740314245224, 46.914357393980026, 39.57575038075447, 36.57383546233177, 35.31402446329594, 34.148011431097984, 36.078148260712624, 37.65746511518955, 36.99299477040768, 37.41719260811806, 38.77381481230259, 36.03082939982414, 35.11579290032387, 36.4497759193182, 35.55234007537365, 35.890035554766655, 36.08508288860321, 35.112008303403854, 34.691902846097946, 36.25824339687824, 38.131744265556335, 38.119292333722115, 37.3752086609602, 37.99386866390705, 40.865686163306236, 49.15499456226826, 51.30522318184376, 52.7758164703846, 52.18175254762173, 52.76962660253048, 51.15062087774277, 52.65848636627197, 50.23390866816044, 51.14825360476971, 53.055922240018845, 43.05197864770889, 48.695276230573654, 58.08881677687168, 53.974051773548126, 56.49101011455059, 51.079899072647095, 63.68853449821472, 35.35044550895691, 2.935609188862145, 0.2989505318691954, 1.2416579481214285, 0.6275887519586831, 16.14205252379179, 64.65470865368843, 53.10873180627823, 53.427424505352974, 58.37647274136543, 60.392321571707726, 40.993078127503395, 27.3740142211318, 32.75208033621311, 49.891189858317375, 18.126585334539413, 0.5197600973770022, 0.04507856196141802, 0.14920374378561974, 0.021635298726323526, 0.07758232211926952, 0.05251713409961667, 0.04087202069058549, 0.05948567813902628, 0.030709085658600088, 0.08268797158962116, 0.074072490533581, 0.08564809439121746, 0.023388093832181767, 0.020768811627931427, 0.05106182703457307, 0.06986613851040602, 0.03089412162808003, 0.03886025500833057, 0.05827245222462807, 0.06656168887275271, 0.075786784873344, 0.14365960378199816, 0.16441897343611345, 6.140098599717021, 60.89216575026512, 39.80677418410778, 26.894229166209698, 36.41128398478031, 53.77241559326649, 59.55145329236984, 45.170007795095444, 61.88342235982418, 63.76782864332199, 57.25823454558849, 61.1115887761116, 19.815530106425285, 0.981206267606467, 2.2597406432032585, 3.141747177578509, 26.674884036183357, 33.30730654299259, 57.6911187171936, 61.971072256565094, 59.19638514518738, 53.08708816766739, 49.84011299908161, 50.63516713678837, 54.94858928024769, 55.10762594640255, 54.30011607706547, 52.49356761574745, 54.24341931939125, 53.30729775130749, 53.15315902233124, 50.948844105005264, 46.25324986875057, 42.831195294857025, 42.264847084879875, 39.224729016423225, 38.96330304443836, 40.32016843557358, 40.3633227199316, 39.96356137096882, 38.08656468987465, 38.55460837483406, 41.31339713931084, 42.27056957781315, 42.96965606510639, 43.16121518611908, 41.82723976671696, 43.33492286503315, 42.608299255371094, 42.29679577052593, 41.7731686681509, 40.90585000813007, 41.79975964128971, 39.57641154527664, 37.09372356534004, 40.05762532353401, 39.97966110706329, 46.691134572029114, 51.528047025203705, 49.99497748911381, 53.48682291805744, 52.33105033636093, 53.372304663062096, 51.51815615594387, 52.301795706152916, 45.88761068880558, 42.49481074512005, 40.4324372112751, 41.519414484500885, 37.754340916872025, 40.36999136209488, 41.43697790801525, 41.05461202561855, 44.087271094322205, 43.61942499876022, 42.55563408136368, 43.34029957652092, 42.63475723564625, 41.10256925225258, 41.05218015611172, 41.3380616158247, 38.35727356374264, 38.201451525092125, 40.84514446556568, 40.38041800260544, 43.20647455751896, 43.95982213318348, 51.71972393989563, 51.6033323854208, 53.261992782354355, 53.62923167645931, 52.261681258678436, 50.23920938372612, 51.47945523262024, 51.60406194627285, 49.29313614964485, 48.35098050534725, 40.79461097717285, 38.02739046514034, 37.78279758989811, 37.28910908102989, 37.962144166231155, 39.228809997439384, 37.887523770332336, 39.179340451955795, 40.8253513276577, 37.98076316714287, 37.283800765872, 37.82448895275593, 38.08854438364506, 37.24691994488239, 36.8847119808197, 37.38022059202194, 38.237621784210205, 38.62994693219662, 40.66021978855133, 41.01551592350006, 39.406686052680016, 41.23810037970543, 44.13677863776684, 52.74411477148533, 54.351933896541595, 55.77616207301617, 54.52409885823727, 54.949710220098495, 53.997409120202065, 55.45535668730736, 53.95355187356472, 52.394742518663406, 55.02105139195919, 47.04764284193516, 49.26559142768383, 59.587779343128204, 56.226255521178246, 59.97311286628246, 54.7824127972126, 67.28890970349312, 35.367301404476166, 5.005141776055098, 0.09283399864216335, 0.8529005711898208, 0.45963405340444297, 16.17974080145359, 69.2764462530613, 59.67825248837471, 58.8282684981823, 63.472022116184235, 63.404579535126686, 51.50892645120621, 36.10335610806942, 33.28071556985378, 57.14690051972866, 24.44346897304058, 0.3691325878025964, 0.028380074109009, 0.05406686832429841, 0.07339797477470711, 0.0480559953575721, 0.06078408405301161, 0.07250073307659477, 0.028572308910952415, 0.05861328354512807, 0.07608238229295239, 0.20457340782741085, 0.12633300852030516, 0.09566990076564252, 0.1137128243863117, 0.10333224898204207, 0.1407533831661567, 0.10332127261790447, 0.13257395097753033, 0.19478871021419764, 0.10028981458162889, 0.1888374873669818, 0.23137826792662963, 0.2932259312365204, 7.099025594070554, 72.85364270210266, 51.29540830850601, 37.82444715499878, 37.560729905962944, 58.60987141728401, 64.23416242003441, 54.16733220219612, 65.7476744055748, 67.07747384905815, 62.504483833909035, 65.41191682219505, 23.782642632722855, 1.7859330237843096, 5.725932698696852, 6.043046107515693, 27.884454131126404, 39.684504345059395, 57.43942402303219, 65.10143548250198, 62.577234730124474, 57.63568349182606, 49.613337367773056, 53.37309122085571, 56.427583917975426, 58.15769948065281, 56.06759123504162, 54.55657571554184, 56.270572543144226, 57.58313611149788, 54.45375323295593, 53.13990533351898, 48.25455687940121, 45.12610115110874, 45.26944845914841, 41.53519503772259, 41.897384002804756, 42.84157253801823, 43.9358302205801, 43.402293249964714, 39.1124602407217, 42.28134959936142, 43.246680200099945, 45.23724898695946, 45.81445321440697, 47.145920768380165, 45.52300125360489, 45.763300359249115, 45.758960992097855, 46.21456414461136, 40.88505372405052, 43.09185370802879, 44.037235379219055, 41.50786690413952, 39.72526855766773, 43.013384118676186, 41.9098549336195, 48.34625355899334, 55.29223524034023, 55.57584822177887, 55.149210914969444, 56.80287458002567, 54.463195726275444, 53.21110211312771, 52.422431632876396, 45.92737935483456, 40.44511333107948, 41.072474867105484, 42.451683059334755, 39.383172914385796, 41.570506542921066, 42.4065300822258, 42.0325693488121, 47.58401446044445, 46.54657892882824, 43.8813791424036, 46.2050836533308, 44.30056504905224, 41.775889322161674, 41.97849065065384, 42.850505858659744, 39.149918630719185, 38.62249933183193, 40.25196589529514, 39.32670034468174, 43.63445699214935, 43.983099684119225, 51.25215522944927, 54.1478506475687, 56.068180203437805, 57.099904641509056, 53.922188356518745, 52.3033232241869, 53.812735229730606, 53.11425670981407, 50.885509103536606, 50.23699410259724, 42.448217645287514, 40.694258362054825, 40.30573680996895, 38.078877702355385, 39.838198497891426, 41.964131221175194, 39.4784490019083, 40.66876173019409, 42.95495085418224, 40.315817669034004, 39.76466864347458, 41.95555128157139, 40.295880138874054, 39.48429308831692, 40.311368107795715, 38.70044834911823, 39.25622172653675, 41.165026500821114, 42.64279380440712, 42.94858239591122, 41.32036976516247, 43.575461357831955, 47.11944378912449, 54.40762370824814, 57.75822311639786, 56.48893162608147, 57.51357324421406, 56.84749558568001, 56.28956772387028, 58.39134894311428, 56.308619901537895, 53.91833536326885, 58.44325415790081, 45.430506616830826, 48.69697093963623, 61.80547334253788, 57.746215760707855, 61.4324701577425, 57.18101128935814, 71.5680880844593, 38.28531302511692, 8.238446228206158, 0.7417586131487042, 3.2722110394388437, 3.19095263723284, 21.895973570644855, 75.97167178988457, 63.509598299860954, 63.40749017894268, 69.75066840648651, 70.5556172132492, 53.118478283286095, 39.497865960001945, 41.181396022439, 65.04383057355881, 32.821156829595566, 0.7254366483539343, 0.18031117535429075, 0.18968939868500456, 0.15863860782701522, 0.15257722057867795, 0.13038467470323667, 0.1723376297741197, 0.14714872202603146, 0.13229977193986997, 0.1276018435601145], [0.025202592951245606, 0.059975380572723225, 0.04391908980323933, 0.02072410650725942, 0.04142267571296543, 0.006745863556716358, 0.01820165602111956, 0.05884075551875867, 0.03223815292585641, 0.02692918096727226, 0.02467953097948339, 0.001199716623432323, 0.22469169547548518, 0.11086216836702079, 28.10155738145113, 51.09150744974613, 30.34379616379738, 26.857728324830532, 37.12693378329277, 57.99286812543869, 69.38015788793564, 52.12090641260147, 54.673742428421974, 49.53850798308849, 56.58044971525669, 23.0160603672266, 0.44734975788742304, 5.714267799630761, 0.23454523470718414, 2.3871233453974128, 27.45749194175005, 54.65492203831673, 58.507554307579994, 57.08560600876808, 50.99630355834961, 44.874885231256485, 40.72618044912815, 41.188600435853004, 43.37031036615372, 43.190169632434845, 44.46190819144249, 43.118000105023384, 43.78163069486618, 41.27728007733822, 41.83736242353916, 37.86203093826771, 40.07513478398323, 38.85034650564194, 37.982826456427574, 37.83093340694904, 37.61110380291939, 38.98574464023113, 37.09121190011501, 38.69908422231674, 36.916322484612465, 38.17741401493549, 39.691108390688896, 40.204023867845535, 40.742553770542145, 41.75068907439709, 39.40661385655403, 38.5402375459671, 39.88714747130871, 38.29304561018944, 38.84159177541733, 36.37796737253666, 37.485045567154884, 38.118923753499985, 36.93491488695145, 36.747562140226364, 45.00160463154316, 46.48854464292526, 49.54736910760403, 49.154382795095444, 48.67049016058445, 50.13144716620445, 48.84154938161373, 47.327748611569405, 43.93161624670029, 40.47186769545078, 40.79222850501537, 39.03190076351166, 38.36223989725113, 40.32084099948406, 40.59252642095089, 36.97461135685444, 40.59427052736282, 40.85035398602486, 41.23689964413643, 40.02628080546856, 41.39558292925358, 39.43661704659462, 41.23650446534157, 39.693388268351555, 40.535411685705185, 39.949399530887604, 38.33262048661709, 39.46945108473301, 38.16662259399891, 41.08110800385475, 46.52820311486721, 51.380280554294586, 50.22398740053177, 52.78156936168671, 49.08894270658493, 50.22540472447872, 49.78998988866806, 49.36003535985947, 49.681038334965706, 44.5130230486393, 37.49052107334137, 35.363030433654785, 35.025973320007324, 35.83267763257027, 36.694946363568306, 35.95002293586731, 37.09224544465542, 38.05442601442337, 37.308887019753456, 37.32891194522381, 36.238385662436485, 35.853796899318695, 35.86912527680397, 35.920289531350136, 36.87472991645336, 35.67962184548378, 37.092344239354134, 35.9346641600132, 36.45048268139362, 36.05461612343788, 37.26132117211819, 41.977107524871826, 47.10191152989864, 49.77416753768921, 50.94905309379101, 52.961330115795135, 53.56819935142994, 51.2299682199955, 53.25856916606426, 50.71131885051727, 51.76795855164528, 49.704498276114464, 51.96857638657093, 51.78039148449898, 48.707351982593536, 51.98422014713287, 54.91363875567913, 59.11155089735985, 57.77469143271446, 52.07950383424759, 16.373391710221767, 1.5059430291876197, 0.14240439457353204, 0.7090452185366303, 0.32352060719858855, 33.26885640621185, 51.28978841006756, 49.20650079846382, 52.44443625211716, 59.08411256968975, 49.181995913386345, 34.99655529856682, 28.87679748237133, 27.718678526580334, 44.62835446000099, 5.815546615049243, 0.45568357163574547, 0.05927380239882041, 0.08625548289273866, 0.05122675822349265, 0.15265622962033376, 0.044494810863398015, 0.03277920084656216, 0.03290387423476204, 0.044320895976852626, 0.08558792105759494, 0.010446046744618798, 0.04342306427133735, 0.06800062416004948, 0.023804900665709283, 0.0555170211737277, 0.1171092780714389, 0.06592310048290528, 0.04314564946980681, 0.02069565813144436, 0.05645125151204411, 0.03249186724133324, 0.07876915726228617, 0.21186809608479962, 0.3489401744445786, 39.61956202983856, 55.32777093350887, 33.53302963078022, 35.93474015593529, 47.598373889923096, 60.04348888993263, 64.70000982284546, 54.04421500861645, 62.19863064587116, 55.33131614327431, 63.21870870888233, 25.300640277564526, 0.411253001075238, 7.373967915773392, 1.3324665441177785, 3.6018317146226764, 28.12594447284937, 54.806222319602966, 62.54960261285305, 59.77577045559883, 52.438732758164406, 46.945587918162346, 44.086328744888306, 44.39601972699165, 45.27312286198139, 46.58329255878925, 48.53737190365791, 45.49868255853653, 45.97361147403717, 43.42718951404095, 43.67461323738098, 40.461004078388214, 41.04432977735996, 41.39349304139614, 40.28798036277294, 40.70425562560558, 39.3355006724596, 39.34221111238003, 39.14587564766407, 40.09456694126129, 39.95641775429249, 41.07578068971634, 41.52918376028538, 42.263688147068024, 42.52434656023979, 43.5063012689352, 42.49546431005001, 40.652950778603554, 41.44433431327343, 40.1077826321125, 40.79124055802822, 37.76363521814346, 39.57230016589165, 40.32872937619686, 39.45562742650509, 39.45496626198292, 46.03571154177189, 48.31334352493286, 49.902372658252716, 50.32869078218937, 50.596139430999756, 51.71926036477089, 50.72399877011776, 48.57736095786095, 44.21853505074978, 40.91460853815079, 39.60551418364048, 40.87075129151344, 40.42829543352127, 39.874136969447136, 41.653972864151, 40.3347634524107, 42.18711085617542, 41.54801554977894, 42.110947743058205, 42.455129474401474, 41.75090566277504, 40.18136948347092, 42.34503798186779, 40.38152374327183, 42.159680128097534, 39.819545298814774, 39.28081400692463, 39.83001373708248, 38.82466748356819, 41.66838549077511, 47.588623613119125, 52.06802085042, 52.01847530901432, 52.607911080121994, 50.63539892435074, 50.55884063243866, 50.90558722615242, 52.31053903698921, 50.696948021650314, 48.71194213628769, 40.707823634147644, 37.448328137397766, 37.44264364242554, 37.54423879086971, 37.93253615498543, 37.643652856349945, 39.23213481903076, 39.57036606967449, 38.54860469698906, 38.911211639642715, 39.011017084121704, 38.98539125919342, 38.40822882950306, 38.84379185736179, 39.23460468649864, 38.008938655257225, 38.065475821495056, 38.894481137394905, 38.786836713552475, 39.94426220655441, 39.754306599497795, 43.939367830753326, 49.67782750725746, 52.16345272958279, 53.01940239965916, 55.348206236958504, 55.592308938503265, 53.52249540388584, 55.11448077857494, 52.94522278010845, 54.63043615221977, 52.62184493243694, 53.99617038667202, 53.15796956419945, 50.179985761642456, 52.9829091578722, 56.86220459640026, 60.4515527933836, 58.36866036057472, 54.27309192717075, 20.837905146181583, 1.692217702511698, 0.22165058209793642, 0.7376564957667142, 0.3810356865869835, 36.58018872141838, 57.484208419919014, 53.77301596105099, 57.526158168911934, 64.37935262918472, 54.10198710858822, 44.13474194705486, 27.813907116651535, 27.429610937833786, 52.66060285270214, 8.194428440183401, 0.5319730576593429, 0.03593703921069391, 0.05808349029393867, 0.05586008264799602, 0.07767546907416545, 0.05026228536735289, 0.017410272412234917, 0.031278314781957306, 0.0007858431865770399, 0.10976375269819982, 0.13465994998114184, 0.12181093203253113, 0.15369167405879125, 0.13132686086464673, 0.1798162964405492, 0.17276170779950917, 0.174830949108582, 0.15324743930250406, 0.12649211013922468, 0.12691321957390755, 0.09931358610629104, 0.14765525265829638, 0.38346633897162974, 0.487998848548159, 50.31592346727848, 66.45873785018921, 40.66895551979542, 36.72176152467728, 50.70909596979618, 67.9624691605568, 76.78492695093155, 63.44252809882164, 65.62266111373901, 60.11671856045723, 65.64818054437637, 30.457489863038063, 0.61892248573713, 12.963112704455853, 1.026239194907248, 3.576037986204028, 35.780377238988876, 58.1514336168766, 65.32220363616943, 63.17246899008751, 56.22404783964157, 48.88021990656853, 46.46367497742176, 46.05559207499027, 48.43628592789173, 48.61405938863754, 48.454236164689064, 46.27766735851765, 50.07605753839016, 45.537250488996506, 47.51579292118549, 42.48349495232105, 44.630964919924736, 44.635251089930534, 42.01724857091904, 42.890517711639404, 42.11892731487751, 43.085937425494194, 42.31082081794739, 44.01350565254688, 42.20692679286003, 42.89718635380268, 44.475298672914505, 44.95916090905666, 45.91561518609524, 45.94618834555149, 45.07297620177269, 41.66862107813358, 42.55830533802509, 40.99885381758213, 43.353648260235786, 38.98749254643917, 40.85037678480148, 43.36510844528675, 42.27462396025658, 41.47908344864845, 49.10265237092972, 50.70526197552681, 53.80093306303024, 53.82796101272106, 52.93612986803055, 53.93044911324978, 52.09817983210087, 49.32885803282261, 45.124980211257935, 41.170737594366074, 41.24138720333576, 41.19843430817127, 41.41672499477863, 40.991782397031784, 43.996664956212044, 40.913396403193474, 45.669418796896935, 44.571779295802116, 46.4698800444603, 44.43737670779228, 46.20675176382065, 42.46259227395058, 44.343035370111465, 41.9440682977438, 43.66028420627117, 41.98429673910141, 39.21241767704487, 40.61595976352692, 38.87967713177204, 41.513498201966286, 46.39331415295601, 52.96795696020126, 55.53151220083237, 56.24261364340782, 53.15659023821354, 53.115373849868774, 54.15943622589111, 53.29005427658558, 53.785764276981354, 48.916671350598335, 43.03471997380257, 40.961589217185974, 39.696219116449356, 39.97616149485111, 39.648790061473846, 38.77427078783512, 41.650203466415405, 42.51273438334465, 40.7362575083971, 39.88056242465973, 40.401879251003265, 40.3894767165184, 40.4051660746336, 40.264436826109886, 40.87576322257519, 40.7953405380249, 41.372898146510124, 41.028252840042114, 41.17387242615223, 40.381675735116005, 42.571760416030884, 46.5168721228838, 51.92763738334179, 53.31638306379318, 55.67499630153179, 56.649055033922195, 57.99554318189621, 55.24529255926609, 57.775250002741814, 54.75100748240948, 57.216706573963165, 52.14282363653183, 54.98395778238773, 51.72440528869629, 50.62134347856045, 53.99492785334587, 60.02485848963261, 61.00209765136242, 61.41647681593895, 54.054212272167206, 26.877846345305443, 2.634962908923626, 0.39707456657197326, 1.98153869016096, 0.35837150586303324, 42.276064082980156, 61.26729302108288, 59.000988230109215, 63.61850045621395, 69.13123324513435, 60.2341702580452, 49.47967953979969, 37.64453440904617, 37.81707175076008, 63.8402983546257, 11.670212130993605, 0.7334033364895731, 0.07585990126244724, 0.2882360271178186, 0.1356162369484082, 0.22477812599390745, 0.15872456337092444, 0.09987355137127452, 0.24695283063920215, 0.1670633049798198, 0.2991607377771288], [0.006851864509371808, 0.019194126398360822, 0.029884158830100205, 0.04117227879760321, 0.0322843219328206, 0.03680812020320445, 0.031001347124401946, 0.02806101183523424, 0.04464944846404251, 0.01649868685490219, 0.020352848987386096, 0.06581603083759546, 0.17779342451831326, 0.04073863819940016, 8.466163258999586, 55.87613470852375, 31.289457120001316, 22.20552586019039, 33.71918924152851, 54.51053738594055, 63.195833936333656, 53.42585898935795, 57.22188949584961, 48.88338513672352, 58.7210838496685, 32.09939695894718, 0.14540163218043745, 2.711279201321304, 2.4722356908023357, 0.3990379924653098, 26.798092424869537, 63.90750154852867, 55.93259207904339, 59.18078698217869, 49.06132958829403, 50.833550691604614, 44.36753265559673, 41.78490623831749, 39.17332537472248, 38.49218152463436, 38.08874577283859, 41.23795598745346, 39.16506081819534, 39.894674867391586, 37.44217626750469, 38.92833352088928, 37.84743972122669, 39.14605803787708, 38.170031011104584, 37.5003245472908, 37.4664493650198, 38.7907999008894, 37.95945391058922, 36.77933983504772, 37.92607270181179, 38.667694106698036, 39.05550889670849, 40.15950545668602, 39.69958573579788, 39.77830991148949, 39.38218496739864, 38.11122536659241, 38.26487772166729, 37.67713665962219, 39.60457183420658, 39.39906366169453, 39.71377417445183, 38.99915412068367, 37.60868713259697, 36.15670144557953, 41.79664000868797, 45.59901997447014, 45.832768231630325, 47.284468933939934, 48.08272249996662, 51.6297447681427, 49.90147590637207, 43.45226436853409, 42.14312821626663, 40.117122530937195, 40.29222473502159, 40.63704863190651, 39.66377645730972, 38.73622722923756, 38.35880488157272, 37.68225118517876, 38.6260749399662, 39.99165326356888, 39.545089825987816, 39.66515578329563, 37.85228066146374, 40.5591756105423, 36.85052141547203, 39.90262024104595, 39.98486302793026, 40.44111214578152, 41.40977896749973, 39.26729813218117, 37.75489188730717, 40.27148924767971, 41.58198952674866, 46.82335987687111, 49.16161000728607, 49.95207779109478, 52.037911266088486, 50.49949921667576, 48.549052476882935, 49.552555829286575, 46.77597261965275, 43.524722680449486, 34.022994339466095, 36.01619638502598, 37.75782153010368, 35.83696760237217, 35.88657394051552, 36.955699771642685, 36.87730237841606, 37.01931215822697, 37.42540016770363, 37.98093415796757, 36.60342067480087, 37.38518312573433, 38.62643212080002, 36.93359635770321, 37.259425073862076, 37.796495854854584, 37.550003081560135, 38.038873448967934, 38.29758636653423, 36.77253060042858, 39.00459162890911, 40.723972767591476, 46.801685839891434, 48.414687886834145, 52.960839942097664, 53.69371801614761, 52.94375225901604, 54.133738204836845, 53.77171643078327, 55.4058301448822, 52.901988700032234, 50.51633611321449, 53.19359265267849, 56.14926025271416, 53.53277005255222, 48.67759197950363, 51.369743719697, 48.699778988957405, 55.09863182902336, 32.54577040672302, 2.071042531169951, 0.24573103291913867, 0.04147921623371076, 0.6497437006328255, 0.12578579335240647, 42.68155172467232, 55.02443701028824, 55.63339613378048, 55.45963905751705, 57.90981598198414, 41.609283462166786, 30.742085091769695, 26.86901181936264, 35.81278569996357, 34.09508407115936, 1.5936286677606404, 0.10739494347944856, 0.10255916859023273, 0.03835405092104338, 0.0892124070378486, 0.019212604020140134, 0.048781611694721505, 0.04405869149195496, 0.017434186265745666, 0.04489742226724047, 0.03572474044631235, 0.022757559599995147, 0.0602235287806252, 0.032241288499790244, 0.07936591078760102, 0.051962438083137386, 0.044120159873273224, 0.0432327850285219, 0.04997380143322516, 0.026358315408288036, 0.038704363178112544, 0.04171838074398693, 0.08255811801063828, 0.3189582098275423, 0.2192833536537364, 15.41221808642149, 64.59744572639465, 32.029039934277534, 25.49642477184534, 49.47534017264843, 62.946776300668716, 69.95615378022194, 57.475685477256775, 61.493665874004364, 55.30174233019352, 62.11623586714268, 36.52182385325432, 0.1468398401630111, 4.860589457675815, 1.8847862631082535, 0.14938079053536057, 30.962260477244854, 62.96471893787384, 60.5346505343914, 60.654336512088776, 52.60163001716137, 51.78557060658932, 46.48276135325432, 43.37598346173763, 40.48229053616524, 41.0940995067358, 39.822110161185265, 40.85512273013592, 41.64674945175648, 41.52070261538029, 40.31705640256405, 40.12134030461311, 40.509094297885895, 39.50415462255478, 40.70509158074856, 39.27712820470333, 40.56246243417263, 41.04061737656593, 41.4108657091856, 39.073402136564255, 38.53922300040722, 40.26921696960926, 41.56725011765957, 44.13197189569473, 41.75225079059601, 43.33690255880356, 41.57951965928078, 40.12562267482281, 40.33492684364319, 40.9453184902668, 39.45337414741516, 41.0844100266695, 41.49511858820915, 41.12642057240009, 40.70943854749203, 40.8168625831604, 43.552514389157295, 47.94238843023777, 47.52585478127003, 49.954585656523705, 50.04421904683113, 53.8985650241375, 49.662643522024155, 45.30714623630047, 43.61987717449665, 40.03752060234547, 41.21287353336811, 40.11735811829567, 41.822573617100716, 40.2177981287241, 39.182178899645805, 40.983989015221596, 40.22934190928936, 42.99533128738403, 41.62467643618584, 42.120268642902374, 40.50636224448681, 42.23370015621185, 40.56070692837238, 41.77110157907009, 41.687840446829796, 42.00719431042671, 41.36066660284996, 39.993237778544426, 38.9779968559742, 39.61747594177723, 42.738104090094566, 46.534047201275826, 51.46982654929161, 52.5493486225605, 54.3900116533041, 52.29616820812225, 49.93844412267208, 49.22266513109207, 47.572527676820755, 45.31140200793743, 36.65233924984932, 37.627378329634666, 38.98771293461323, 37.86216393113136, 38.747383430600166, 38.38384173810482, 38.62313389778137, 38.59341189265251, 39.559323862195015, 40.66291764378548, 38.333946615457535, 39.69474479556084, 39.53576512634754, 38.37948717176914, 39.44561876356602, 39.97694045305252, 40.07697008550167, 39.651104137301445, 39.94741603732109, 39.66361306607723, 41.183584704995155, 42.64617182314396, 49.745137095451355, 50.258284360170364, 54.28040273487568, 53.94139252603054, 53.18595126271248, 56.180540174245834, 55.19074268639088, 55.69383569061756, 55.93633487820625, 53.32263372838497, 55.23028716444969, 56.10198698937893, 54.28199864923954, 48.71980391442776, 51.43681392073631, 50.38474537432194, 58.11568133533001, 34.04068998992443, 3.6486340407282114, 0.5825093958992511, 0.4264971299562603, 0.43634317349642515, 0.09400656228535809, 45.813157483935356, 60.26553377509117, 60.57120457291603, 59.81386341154575, 64.79637265205383, 47.644978389143944, 43.711653649806976, 23.719995394349098, 38.56932118535042, 41.76669381558895, 2.380131483078003, 0.1549925550352782, 0.09074626301298849, 0.06053422148397658, 0.05925490731897298, 0.033279386116191745, 0.07395319029456005, 0.03297145049145911, 0.021883769768464845, 0.029101077998348046, 0.01822500955313444, 0.16603770141955465, 0.11190564284333959, 0.13810667674988508, 0.18312354397494346, 0.13098907977109775, 0.2302423515357077, 0.1380688272183761, 0.1387279137270525, 0.09031753914314322, 0.1717554742936045, 0.11546099034603685, 0.1815863186493516, 0.46569072059355676, 0.41497000318486243, 16.99481226503849, 75.86867451667786, 40.18241822719574, 30.6890931352973, 47.34901987016201, 65.9300646185875, 72.13330775499344, 62.94430263340473, 66.9343963265419, 58.141018375754356, 70.85092976689339, 40.844745486974716, 0.21203503478318453, 8.783580176532269, 5.71182263083756, 1.4696267154067755, 32.776300236582756, 67.15824231505394, 62.25055105984211, 63.86377349495888, 54.17572595179081, 54.67935852706432, 47.54989229142666, 46.99441909790039, 45.29385834932327, 43.04064005613327, 42.98601798713207, 44.19775016605854, 44.927090629935265, 45.6205078214407, 42.79740750789642, 43.127271607518196, 42.974808588624, 41.69750712811947, 43.898789808154106, 41.367282047867775, 43.126241862773895, 44.40083786845207, 43.233456909656525, 40.14793507754803, 41.468383222818375, 42.83801592886448, 44.13547910749912, 46.751737520098686, 44.55059163272381, 45.56014806032181, 44.703605622053146, 41.57063953578472, 41.41752675175667, 42.56357945501804, 41.485353112220764, 42.743530198931694, 42.115545496344566, 43.973873779177666, 42.45534606277943, 43.9133620262146, 46.2493284791708, 50.97789354622364, 50.44889733195305, 51.82194985449314, 53.26367229223251, 56.9564775377512, 50.67500799894333, 46.16815723478794, 42.559559270739555, 40.0068524479866, 42.84691125154495, 43.07204157114029, 43.95755745470524, 41.433945670723915, 42.61868789792061, 44.796069860458374, 42.222768142819405, 45.739145055413246, 42.652281895279884, 44.959993064403534, 43.756149262189865, 44.935845360159874, 40.73450580239296, 44.874885231256485, 42.95077867805958, 44.72175344824791, 42.83118009567261, 41.980724930763245, 38.44493106007576, 41.303928047418594, 41.3534089922905, 47.5654486566782, 52.230009958148, 54.324157387018204, 56.18267945945263, 55.19795089960098, 51.33723646402359, 53.365400433540344, 50.47606207430363, 47.587498873472214, 37.53046452999115, 40.2391491830349, 41.60395994782448, 40.32559834420681, 39.392630606889725, 40.15694059431553, 39.07393030822277, 41.85580663383007, 41.80665247142315, 42.55457393825054, 40.936575159430504, 43.02370436489582, 42.912849113345146, 41.82663179934025, 41.51159070432186, 42.23901987075806, 42.26886726915836, 41.86456896364689, 42.28846661746502, 42.30789877474308, 44.4039499014616, 44.449908435344696, 51.95355199277401, 51.931672766804695, 56.774965077638626, 57.764823362231255, 54.850854724645615, 57.231704369187355, 56.94160893559456, 58.03137145936489, 56.89925640821457, 53.973998576402664, 58.42706702649593, 57.66412876546383, 54.68497462570667, 48.458206951618195, 52.461155354976654, 52.383654713630676, 60.20310692489147, 38.36062878370285, 5.677649639546871, 1.0250369156710804, 1.031937226653099, 1.1322527937591076, 0.18462535401340574, 49.43521812558174, 66.27626404166222, 63.47545713186264, 65.6666399538517, 68.59339490532875, 53.36170323193073, 45.48580504953861, 36.627184599637985, 48.03061969578266, 51.52108579874039, 2.940111472271383, 0.20315770176239312, 0.20735966769279912, 0.17346775741316378, 0.13196633983170614, 0.10922743225819431, 0.1557167575811036, 0.12189967805170454, 0.12643346562981606, 0.16868537262780592, 0.1572672970360145], [0.022711056626576465, 0.07631054075318389, 0.026701638489612378, 0.02151603373931721, 0.01522782946267398, 0.048277021778631024, 0.07763574190903455, 0.0687213460332714, 0.04897441052889917, 0.06468600709922612, 0.068705055891769, 0.05298925505485386, 0.10825720775756054, 0.19969914515968412, 0.6808674149215221, 40.61086043715477, 53.888993337750435, 32.039645165205, 22.595656625926495, 46.12700544297695, 60.68100728094578, 61.05608135461807, 54.03487130999565, 50.20684652030468, 52.83185586333275, 44.51239228248596, 0.3671356168342754, 5.079654827713966, 2.4040333880111575, 0.20679802517406642, 13.60272953286767, 63.4160815179348, 56.68698079884052, 58.388951271772385, 55.09658373892307, 57.379995211958885, 51.18685573339462, 51.97286255657673, 45.57630859315395, 41.238989531993866, 40.444007590413094, 40.95641769468784, 40.00729322433472, 38.698787838220596, 38.776710256934166, 38.1119891256094, 37.280073165893555, 37.796024680137634, 38.41103307902813, 38.947628885507584, 37.66210846602917, 38.33662547171116, 35.40280669927597, 37.14671552181244, 37.866830080747604, 38.34176279604435, 38.79967242479324, 38.021295592188835, 41.15588799118996, 42.14803755283356, 39.049444422125816, 38.569670766592026, 37.99597755074501, 39.18747201561928, 40.53513050079346, 37.164642959833145, 39.38971996307373, 40.01184158027172, 37.53502808511257, 41.04040078818798, 39.64875966310501, 43.29973675310612, 44.123775735497475, 46.10649414360523, 50.55134743452072, 53.36660876870155, 50.22634707391262, 43.39520663022995, 39.66532677412033, 40.333619713783264, 40.994974225759506, 41.823515966534615, 38.76601003110409, 36.93156346678734, 38.359656035900116, 37.43556462228298, 39.274491146206856, 39.9703212082386, 40.611156821250916, 39.33631382882595, 37.52205938100815, 39.08677741885185, 37.6442114263773, 37.668761909008026, 38.17164972424507, 40.4074801504612, 41.50563642382622, 40.28721660375595, 39.0843341499567, 39.304357543587685, 40.22237308323383, 42.76707373559475, 47.108488976955414, 51.931767761707306, 48.664748668670654, 47.991219609975815, 48.9500829577446, 45.00724732875824, 46.64616018533707, 41.49020165205002, 36.18716821074486, 36.985216587781906, 38.189360573887825, 37.13642567396164, 37.21856206655502, 36.91096477210522, 37.90852904319763, 38.157400488853455, 37.67358385026455, 35.97219094634056, 35.44171281158924, 36.13451063632965, 35.76917544007301, 36.24726198613644, 35.13422191143036, 36.194361224770546, 36.278560906648636, 37.20212034881115, 38.066528365015984, 37.93958097696304, 36.6269376128912, 40.16299366950989, 44.217862486839294, 47.28961765766144, 49.572972133755684, 51.69303797185421, 52.06586256623268, 51.71381525695324, 53.534692749381065, 48.3499051630497, 49.55061033368111, 49.63436543941498, 50.69071255624294, 51.07326082885265, 55.77228248119354, 50.634220987558365, 52.78504617512226, 48.513980358839035, 52.23450891673565, 10.330179836601019, 0.7534706534352154, 0.5786830605939031, 0.1767484360607341, 0.48782292986288667, 0.3465652128215879, 44.18896123766899, 57.23279871046543, 52.37128637731075, 53.84862430393696, 56.58041551709175, 37.61635132133961, 23.30865416675806, 25.940607637166977, 41.962459310889244, 15.752969551831484, 0.7905331521760672, 0.06492131244158372, 0.09582866841810755, 0.04021727203507908, 0.11022214763215743, 0.017783539296942763, 0.026819801387318876, 0.025150252986350097, 0.0625038034922909, 0.026159518165513873, 0.06458478557760827, 0.01831293549912516, 0.04120662168134004, 0.06658617232460529, 0.07206551541457884, 0.06825543314334936, 0.02640511709614657, 0.09128181904088706, 0.05172822369786445, 0.04740331358334515, 0.05093618143291678, 0.055988314634305425, 0.014772496815567138, 0.13777653977740556, 0.16993863740935922, 2.8335955878719687, 52.74315342307091, 50.165698528289795, 26.898534335196018, 38.34966257214546, 57.6978025585413, 65.9530533850193, 66.34355843067169, 60.527655109763145, 55.499327927827835, 57.42864780128002, 45.706679597496986, 0.47465262876357883, 4.25189726985991, 1.3903336389921606, 0.3549086151178926, 16.418178007006645, 65.68414181470871, 59.09576654434204, 60.43205603957176, 56.413794457912445, 58.069688603281975, 53.94640825688839, 53.34187209606171, 47.90015369653702, 44.511510729789734, 42.27468095719814, 41.97218678891659, 42.3410139977932, 40.48101380467415, 42.11138091981411, 39.3533331155777, 38.16651999950409, 41.266044080257416, 40.28406277298927, 41.26555010676384, 39.755180552601814, 39.99734155833721, 38.740137219429016, 38.32360737025738, 41.26310683786869, 40.47466054558754, 39.96988423168659, 41.21562458574772, 43.49894106388092, 44.01745744049549, 40.2147126942873, 39.840402379631996, 39.51917141675949, 40.90759411454201, 41.58953972160816, 41.05720728635788, 41.70445315539837, 41.66458189487457, 39.12209652364254, 40.60900993645191, 42.52034917473793, 45.41370391845703, 46.44525736570358, 47.35377721488476, 53.080396726727486, 56.16759806871414, 52.51045770943165, 42.37525776028633, 40.89993752539158, 40.884096175432205, 43.425806388258934, 42.7851227670908, 40.22287845611572, 41.3520410656929, 40.78117869794369, 39.723581448197365, 41.75786308944225, 42.31418363749981, 41.07966788113117, 39.4550384581089, 40.4293517768383, 40.016355738043785, 38.93382802605629, 40.239764750003815, 41.20134875178337, 41.187236309051514, 40.36113403737545, 38.9521886408329, 39.11729358136654, 40.52137903869152, 40.779290199279785, 44.32432517409325, 47.20751166343689, 54.137355610728264, 50.75461372733116, 49.953187331557274, 50.288777723908424, 47.662677839398384, 47.05263577401638, 43.062211498618126, 37.68712252378464, 37.342785000801086, 38.702610433101654, 39.31212432682514, 38.7856587767601, 38.34445305168629, 39.36458431184292, 40.22549271583557, 40.93150243163109, 39.0944530069828, 38.083825036883354, 37.37526185810566, 37.63779737055302, 39.38002668321133, 38.36842596530914, 37.999127581715584, 37.375258058309555, 39.10237558186054, 40.312800630927086, 40.03250867128372, 40.3151299059391, 42.9963306337595, 47.613835260272026, 50.74182741343975, 52.47248634696007, 52.682926654815674, 53.111988231539726, 53.41550454497337, 54.42838579416275, 51.77959732711315, 51.98676601052284, 51.30724847316742, 53.63518975675106, 52.7018990367651, 58.24472241103649, 49.124816581606865, 53.81766356527805, 48.6422348767519, 54.31370794773102, 12.67352644354105, 1.1275517335161567, 0.9335659677162766, 0.10110821051057428, 0.15518511267146096, 0.3399474819889292, 50.28139851987362, 62.7117133140564, 57.21816569566727, 59.978637769818306, 60.65128527581692, 48.35996702313423, 35.07924646139145, 22.70913753658533, 49.42293718457222, 21.770618297159672, 0.6767125159967691, 0.04384004365419969, 0.07550026391982101, 0.01337812100246083, 0.013072500878479332, 0.06609402451431379, 0.06889065960422158, 0.044793328634114005, 0.09386183606693521, 0.05484948160301428, 0.05121694703120738, 0.11076778202550486, 0.1453749297070317, 0.2571974223246798, 0.22136316314572468, 0.1641690923133865, 0.12093247409211472, 0.18297634640475735, 0.1507519677397795, 0.1355267339386046, 0.155230873497203, 0.18338479480007663, 0.30129334365483373, 0.3300968965049833, 0.3661518555600196, 4.86886446364224, 63.80129724740982, 65.30282467603683, 39.12691846489906, 32.21332624554634, 59.20066751539707, 70.66738441586494, 73.51258054375648, 65.22149384021759, 61.77987791597843, 60.204155668616295, 53.953247889876366, 0.40646053792443126, 13.71289037168026, 10.6996463611722, 1.014068922959268, 19.324953630566597, 68.06108146905899, 61.025667786598206, 64.9396325647831, 59.957009330391884, 63.38964633643627, 56.7302642762661, 57.710053101181984, 50.0340735912323, 46.584956869482994, 45.58310642838478, 45.82872524857521, 46.00567415356636, 42.58414775133133, 44.67414580285549, 41.149591729044914, 41.00420393049717, 45.03290355205536, 42.3901491612196, 44.9462454020977, 42.44362369179726, 42.63612516224384, 40.683497339487076, 41.10283903777599, 42.509633749723434, 43.57120558619499, 43.43453451991081, 43.437521159648895, 46.05743117630482, 48.3217828720808, 42.954901456832886, 41.85142166912556, 41.402456760406494, 42.87673585116863, 43.53608787059784, 42.55840793251991, 44.04282867908478, 44.28016014397144, 41.68950475752354, 44.45014402270317, 44.32552210986614, 49.7138761729002, 48.94892781972885, 49.94718745350838, 55.13806991279125, 57.433940917253494, 54.03512969613075, 45.56081682443619, 42.39187806844711, 42.456596195697784, 44.441039711236954, 44.458002001047134, 41.93166196346283, 41.593966484069824, 43.75622905790806, 42.996380031108856, 43.61432567238808, 44.328413754701614, 45.173515006899834, 43.07760447263718, 42.44509041309357, 43.03961791098118, 41.57635062932968, 42.15631350874901, 41.25660538673401, 44.12237361073494, 41.77439980208874, 40.60344323515892, 40.86596354842186, 40.87579742074013, 40.98741643130779, 44.93887759745121, 48.07122811675072, 55.293891951441765, 51.61877475678921, 51.59309573471546, 52.58400656282902, 48.65754425525665, 49.06822241842747, 45.23111991584301, 39.45751592516899, 41.26326262950897, 41.06702595949173, 42.26551204919815, 40.5371367931366, 40.86972534656525, 42.146038860082626, 40.20206317305565, 42.20975764095783, 42.182919681072235, 39.784807562828064, 39.67296816408634, 39.380763843655586, 41.98127210140228, 39.34014782309532, 40.4231733083725, 40.32013803720474, 42.98386350274086, 42.545135244727135, 42.846398279070854, 40.9199358522892, 45.01233525574207, 50.05476728081703, 53.54860000312328, 54.656711742281914, 55.555572509765625, 54.66713458299637, 55.12548878788948, 58.03493566811085, 53.97529050707817, 53.55153724551201, 55.04917748272419, 56.09528034925461, 57.17965476214886, 61.12645357847214, 51.42285346984863, 53.62189806997776, 50.984619185328484, 57.25690841674805, 17.571001946926117, 1.7605533543974161, 1.6346745402552187, 0.4041764448629692, 0.6496663391590118, 0.22288006846792996, 56.8703855574131, 66.73743769526482, 61.84865802526474, 65.17586588859558, 68.36441159248352, 48.940279483795166, 36.931259483098984, 33.30401211977005, 58.88514384627342, 30.19254717975855, 0.7933355018030852, 0.14764573832508177, 0.16210624831728637, 0.11436170636443421, 0.16542710684007034, 0.13213756814366207, 0.1379489852115512, 0.15356322313891724, 0.1820361491991207, 0.1367897802265361, 0.12424611151800491], [0.05293499292747583, 0.08233624554122798, 0.03683829592773691, 0.037038223090348765, 0.02957423981570173, 0.019886186528310645, 0.08625160888186656, 0.013368127983994782, 0.04171147505985573, 0.019180979252269026, 0.01692907499091234, 0.048273155189235695, 0.03745921378140338, 0.2605064806994051, 0.16271050495561212, 26.771997325122356, 57.62957341969013, 27.745734974741936, 29.68895260244608, 35.472088381648064, 54.46896381676197, 61.14192254841328, 56.69732004404068, 53.75534690916538, 50.758329927921295, 53.881215155124664, 1.37573114130646, 2.891099564731121, 0.17371751979226246, 0.21959713369142264, 5.2818728517740965, 49.985850378870964, 57.57265247404575, 59.49074774980545, 64.75179344415665, 59.572937339544296, 60.72461374104023, 55.25145582854748, 54.648382589221, 50.913840383291245, 46.08023755252361, 42.781725749373436, 41.81350730359554, 38.09205159544945, 40.54928474128246, 40.86823582649231, 38.316376358270645, 40.90047709643841, 39.74810153245926, 41.090132519602776, 38.04531790316105, 37.627119943499565, 37.36182577908039, 37.065274491906166, 37.6587950438261, 37.33409866690636, 37.15667858719826, 38.69840785861015, 38.30580152571201, 40.470359176397324, 39.9086657166481, 39.53866437077522, 39.9279610812664, 38.55739742517471, 39.540423676371574, 41.146384701132774, 42.09476821124554, 41.332320123910904, 40.42019806802273, 38.56632314622402, 40.570354610681534, 43.413012474775314, 43.64916980266571, 47.41537190973759, 50.19090637564659, 54.91456590592861, 50.72728559374809, 45.62525376677513, 44.21156622469425, 40.30554682016373, 40.88399738073349, 36.872510835528374, 37.39421524107456, 36.12250708043575, 36.436248645186424, 38.48935827612877, 39.653574004769325, 38.183391094207764, 39.44285251200199, 37.91751556098461, 38.75412426888943, 37.54530653357506, 37.073489651083946, 37.215852811932564, 37.181141674518585, 38.04469093680382, 37.607645988464355, 40.14589458703995, 40.58895081281662, 39.8740191757679, 40.45470781624317, 37.63346180319786, 41.135513484478, 46.02987885475159, 50.2838683873415, 48.00112187862396, 49.45089228451252, 45.5864654481411, 44.73209269344807, 39.03651371598244, 36.905869245529175, 35.81084780395031, 37.57009640336037, 38.004454895853996, 37.86380544304848, 36.533527225255966, 37.30716951191425, 39.07733112573624, 37.37917184829712, 37.032980024814606, 37.98734061419964, 33.91970068216324, 37.522389963269234, 35.79848326742649, 36.60624772310257, 36.84445694088936, 36.5856908261776, 35.22653415799141, 36.584410294890404, 38.33710044622421, 38.530532866716385, 40.743325129151344, 41.49778604507446, 44.72399912774563, 47.53565065562725, 46.01084567606449, 48.622791320085526, 47.988388761878014, 47.365849167108536, 44.807476848363876, 46.55840389430523, 44.33605894446373, 51.56289495527744, 50.05509026348591, 58.34075465798378, 47.14888080954552, 49.660473838448524, 49.00294952094555, 43.13540697097778, 0.6552474084310234, 2.406103564426303, 4.613777501508594, 0.10814846827997826, 0.16032165032811463, 2.445251438766718, 59.00676392018795, 50.99653534591198, 56.89646735787392, 54.87790547311306, 50.5024478584528, 26.306438706815243, 26.18037287145853, 30.234050452709198, 42.679363042116165, 3.23034702334553, 0.36454938061069697, 0.021125587991264183, 0.07742374000372365, 0.074872117547784, 0.027410146467445884, 0.03641901217633858, 0.05722419089579489, 0.027518112256075256, 0.05785371766251046, 0.09203302091918886, 0.00800987927505048, 0.04470109452086035, 0.016036625711421948, 0.12440311285899952, 0.0333150945516536, 0.039175292986328714, 0.0770762590400409, 0.06299791799392551, 0.0716543136513792, 0.042002723494078964, 0.03942768256820273, 0.057516793749528006, 0.06325985901639797, 0.03515800308377948, 0.06272451821132563, 0.49284320266451687, 36.8403759598732, 63.324958607554436, 26.528985165059566, 28.055232167243958, 52.191081047058105, 62.316686511039734, 66.87619104981422, 59.74153809249401, 59.41810704767704, 54.787534922361374, 57.81246900558472, 1.7939945287071168, 4.7572364285588264, 1.302798092365265, 0.394366736873053, 7.041202671825886, 56.6017209738493, 59.35021989047527, 63.643347322940826, 64.60530370473862, 62.07073710858822, 61.040297001600266, 59.56303887069225, 56.128292977809906, 52.22347430884838, 47.59310357272625, 43.91341142356396, 44.28601182997227, 43.20141702890396, 42.31370486319065, 43.04406367242336, 40.11777989566326, 42.233882546424866, 41.96709506213665, 42.95875445008278, 41.30460441112518, 41.32882051169872, 38.5569604486227, 40.613858476281166, 39.38828743994236, 40.039526894688606, 39.329132214188576, 41.008710488677025, 40.51059141755104, 41.66548624634743, 42.15162456035614, 41.593597903847694, 41.723623126745224, 41.50683335959911, 40.73173575103283, 41.35777495801449, 42.71897591650486, 42.116598039865494, 40.85060857236385, 40.78090891242027, 44.539534226059914, 46.827136874198914, 44.60961386561394, 47.789180651307106, 51.717155277729034, 56.072029396891594, 52.39177867770195, 46.99350714683533, 44.30681951344013, 42.49940849840641, 43.86133521795273, 40.26463441550732, 39.91487078368664, 38.82626719772816, 38.94268535077572, 39.06664229929447, 40.90933442115784, 40.19501835107803, 41.00583404302597, 39.952332973480225, 40.657582730054855, 39.253052696585655, 38.29254403710365, 39.69168595969677, 38.66374231874943, 39.472053945064545, 39.50042702257633, 43.19577433168888, 40.98946072161198, 41.20441518723965, 41.2033474445343, 37.40627199411392, 43.51739667356014, 47.73947931826115, 51.930513828992844, 48.89176748692989, 50.476567447185516, 46.25530555844307, 45.78940495848656, 38.98533806204796, 37.4637059122324, 38.25452707707882, 39.742508232593536, 39.35647554695606, 39.82242934405804, 38.01433056592941, 37.50209145247936, 39.22564096748829, 39.724550396203995, 38.42504292726517, 39.13242816925049, 36.351251006126404, 38.451185524463654, 37.26539455354214, 37.92881615459919, 36.48044027388096, 39.01904985308647, 37.13823817670345, 38.73004876077175, 40.742990747094154, 41.58735103905201, 41.74569994211197, 43.128616735339165, 45.735645443201065, 49.23257119953632, 47.48832419514656, 50.26042744517326, 49.85443443059921, 50.69221347570419, 48.7384457141161, 48.6356308311224, 46.46090492606163, 53.11585262417793, 51.252630203962326, 59.57802526652813, 47.9913754016161, 50.56627683341503, 50.1325187087059, 46.74189604818821, 1.377747526858002, 4.552976964041591, 6.191956317052245, 0.23233973508467898, 0.36512003280222416, 3.099432410672307, 64.09426912665367, 56.26176841557026, 60.134824588894844, 63.37324261665344, 55.21945774555206, 39.268187284469604, 27.984683252871037, 31.962361112236977, 52.79094725847244, 5.362373907119036, 0.2884469454875216, 0.07104226446244866, 0.068381798628252, 0.12852685642428696, 0.05147114374267403, 0.06016526647727005, 0.021188902464928105, 0.01939186422532657, 0.013914973933424335, 0.07362806281889789, 0.07558759243693203, 0.18933497864054516, 0.13986203412059695, 0.1859609823441133, 0.12974170764209703, 0.2179661751142703, 0.1741485294769518, 0.14988974056905136, 0.16554475208977237, 0.0994352092675399, 0.14208918961230665, 0.14823280682321638, 0.2513036713935435, 0.20577320829033852, 0.3838927176548168, 0.4210010514361784, 45.0976786762476, 72.17521950602531, 38.14945511519909, 37.03018717467785, 49.34350624680519, 63.43114770948887, 72.51087069511414, 65.47971278429031, 64.43262577056885, 57.89432801306248, 64.08226177096367, 1.641881566029042, 6.322915339842439, 4.3604346457868814, 0.6586644938215613, 10.016621612012386, 55.966786444187164, 63.172928765416145, 63.73441323637962, 69.02575090527534, 63.963662534952164, 64.90085944533348, 61.87703490257263, 59.10821847617626, 55.59861280024052, 50.921626165509224, 46.48869663476944, 46.910618394613266, 45.423165410757065, 45.06683573126793, 44.96960274875164, 42.26699776947498, 45.61997964978218, 45.20940788090229, 46.97095535695553, 44.12374533712864, 43.77119645476341, 41.12639777362347, 41.181954592466354, 41.266883835196495, 43.24098810553551, 41.77368924021721, 43.68524506688118, 43.812032863497734, 45.62293589115143, 44.92128074169159, 44.21787388622761, 45.35972021520138, 43.721179738640785, 43.10297571122646, 44.55874979496002, 45.897699147462845, 45.18503598868847, 44.266826659440994, 43.51109281182289, 47.18013033270836, 47.59107828140259, 47.6041229814291, 51.220746114850044, 53.5807728767395, 58.33402141928673, 52.66781486570835, 48.94304193556309, 47.45781563222408, 43.53042237460613, 44.646228700876236, 41.44270420074463, 43.31544890999794, 41.561938002705574, 40.591519474983215, 43.55427369475365, 44.861798733472824, 41.66798651218414, 42.22762808203697, 42.07374393939972, 42.711459919810295, 42.02748902142048, 40.073405876755714, 43.64656314253807, 40.134084820747375, 41.939782127738, 39.969603046774864, 43.88999328017235, 43.16890597343445, 42.42274381220341, 43.06436978280544, 37.94003315269947, 43.65726716816425, 48.81175898015499, 54.447255581617355, 51.813411712646484, 54.039754047989845, 47.82120533287525, 49.11975525319576, 40.41411079466343, 38.957242369651794, 39.978950545191765, 41.780886054039, 39.94083099067211, 41.55996970832348, 40.05745053291321, 40.4558439552784, 41.57752476632595, 39.92634616792202, 41.03568144142628, 42.221935987472534, 37.724352926015854, 41.234813556075096, 39.565506130456924, 39.64551463723183, 40.339125618338585, 42.87333503365517, 38.69958959519863, 42.361111119389534, 42.79003970324993, 43.4935187548399, 44.90402966737747, 45.740763768553734, 47.710338681936264, 52.259443178772926, 50.528822243213654, 54.00444254279137, 52.249537110328674, 52.8456225246191, 50.81533446907997, 51.00311279296875, 48.2104716449976, 56.09738923609257, 53.182200863957405, 61.794218346476555, 48.01345221698284, 52.56367385387421, 49.18141454458237, 49.27188389003277, 2.95877939555794, 6.153692370280623, 9.649627804756165, 0.4117331706220284, 1.1730780405923724, 2.756711463443935, 70.9151691198349, 59.159200340509415, 67.57404640316963, 63.409887850284576, 62.97046422958374, 38.500769063830376, 37.59397052228451, 39.82907138764858, 63.878349512815475, 9.712393786758184, 0.4784267762443051, 0.1964803913142532, 0.1705783835495822, 0.17434775159927085, 0.15838782128412277, 0.11355723312590271, 0.23829815676435828, 0.1268310786690563, 0.14016922388691455, 0.1744312432128936, 0.13019808393437415], [0.016060012640082277, 0.02874766541935969, 0.05046251309977379, 0.11067623810959049, 0.026422854425618425, 0.025946438290702645, 0.006228235497474088, 0.046960926774772815, 0.10484298705705442, 0.010203407127846731, 0.15464107389561832, 0.05004034610465169, 0.0619888383516809, 0.366651380318217, 0.12720464612357318, 8.63677790388465, 54.73904192447662, 40.72125971317291, 30.66400308161974, 23.66197820752859, 43.145389035344124, 61.99005603790283, 60.82532733678818, 52.658231779932976, 52.178484722971916, 53.05928125977516, 4.57785090431571, 2.834580922499299, 0.15130893472814932, 0.20584150071954355, 2.3696290841326118, 44.08926598727703, 60.72950407862663, 56.289324536919594, 58.62835742533207, 54.86675687134266, 58.83184790611267, 55.83224706351757, 57.849957793951035, 52.96127311885357, 50.72302222251892, 49.38324451446533, 43.25524494051933, 42.073800936341286, 38.67644503712654, 39.344293400645256, 38.090239092707634, 37.82847873866558, 39.32668894529343, 37.783831134438515, 39.746786803007126, 37.79904171824455, 37.94825591146946, 38.90269249677658, 38.53041127324104, 38.483848571777344, 37.8138343244791, 38.55757601559162, 39.80351395905018, 38.91756109893322, 39.59571070969105, 37.71027848124504, 39.25046883523464, 38.84997792541981, 38.9473021030426, 37.22244545817375, 40.50561748445034, 39.436408057808876, 39.873434007167816, 39.950832054018974, 43.69175411760807, 42.29681096971035, 43.68156686425209, 45.622951090335846, 50.38180433213711, 50.708867982029915, 48.95011715590954, 41.820780113339424, 41.349609196186066, 38.7523839622736, 38.16759534180164, 35.73367014527321, 36.87566466629505, 36.78149811923504, 39.20911185443401, 38.5283137857914, 38.79265420138836, 37.62596860527992, 37.421691566705704, 39.27083574235439, 40.24268299341202, 38.497843220829964, 37.415931075811386, 37.03320041298866, 37.90855184197426, 37.87486284971237, 37.75576204061508, 39.07017230987549, 39.36459191143513, 39.421425461769104, 41.330519020557404, 39.99895267188549, 39.76748809218407, 41.78511902689934, 49.56240490078926, 46.55773513019085, 46.07629336416721, 43.40266562998295, 41.46449603140354, 39.24111373722553, 36.195774748921394, 35.68380922079086, 37.405622228980064, 38.656074330210686, 37.77951076626778, 36.23860985040665, 38.77935491502285, 37.1644339710474, 37.50183306634426, 36.775741428136826, 37.94714257121086, 35.80259844660759, 36.20192661881447, 35.506518334150314, 35.692685544490814, 34.82420414686203, 36.17244400084019, 37.28733077645302, 36.43047295510769, 37.069363072514534, 35.933547019958496, 35.83758316934109, 37.37107068300247, 37.152544409036636, 40.44404558837414, 41.754648461937904, 41.23013220727444, 40.99295273423195, 41.67004980146885, 39.21590968966484, 41.88636839389801, 45.416990742087364, 50.05325496196747, 52.94523797929287, 52.95334294438362, 50.99691912531853, 54.507736936211586, 49.82023246586323, 40.14519162476063, 0.5657768156379461, 1.3418592838570476, 1.1816870723851025, 0.3431318298680708, 0.4858628287911415, 9.110514633357525, 65.50699532032013, 51.21907040476799, 55.25521382689476, 47.620283514261246, 41.856505796313286, 28.200458474457264, 23.37438113987446, 35.329930409789085, 30.029693618416786, 0.3091689554275945, 0.04509550519287586, 0.15679055621149018, 0.05243063307716511, 0.03051876374229323, 0.036751408988493495, 0.0516284864715999, 0.030005178996361792, 0.09084733610507101, 0.07091806604876183, 0.06212096290255431, 0.04474637666135095, 0.05835184347233735, 0.020334299006208312, 0.05604976075119339, 0.03570747438061517, 0.021848610522283707, 0.06158460906590335, 0.028012143266096245, 0.05924673256231472, 0.035223790764575824, 0.02086730946757598, 0.016559079122089315, 0.05198488062887918, 0.07160539869801141, 0.375624984735623, 0.15991167310858145, 14.073479622602463, 63.58954980969429, 37.77776665985584, 30.750148259103298, 35.86601324379444, 51.030558720231056, 68.82544085383415, 63.04065026342869, 57.29206793010235, 56.55020333826542, 56.86761170625687, 5.0557104125618935, 4.3517278879880905, 0.8104062045458704, 0.2230508069624193, 2.519066040404141, 48.5188402980566, 60.64396686851978, 57.565398663282394, 60.65958023071289, 55.92024654150009, 62.109810411930084, 58.00430171191692, 61.24044746160507, 54.94896925985813, 53.97020258009434, 51.38846151530743, 46.03183954954147, 44.55781124532223, 41.52681648731232, 41.738347336649895, 41.39711044728756, 38.52500416338444, 40.612999722361565, 39.152825474739075, 41.67981147766113, 39.095235764980316, 38.662400990724564, 41.08450122177601, 39.534214809536934, 41.45096115767956, 39.98873122036457, 41.03034272789955, 42.52357140183449, 39.850304648280144, 41.53624378144741, 40.8782596886158, 40.50451934337616, 41.124133095145226, 40.65203122794628, 39.57309052348137, 41.84609815478325, 42.737218737602234, 41.860879361629486, 42.41172820329666, 45.202758237719536, 44.12749193608761, 44.57780197262764, 48.01277965307236, 51.1290380358696, 53.5677395761013, 48.777291029691696, 44.821615889668465, 44.50471289455891, 41.14722065627575, 40.82583770155907, 38.96789699792862, 38.97067464888096, 39.42557103931904, 40.285445898771286, 40.4101438075304, 40.61390407383442, 39.3464744836092, 39.351657405495644, 40.44507533311844, 41.57277122139931, 38.89952726662159, 39.432232081890106, 38.992443680763245, 40.75516529381275, 40.050314515829086, 39.721951335668564, 38.822098821401596, 40.87283357977867, 41.8516306579113, 43.20292554795742, 39.753603637218475, 40.429670959711075, 42.51990459859371, 48.996421471238136, 49.190218672156334, 49.61172625422478, 44.175905138254166, 43.59918728470802, 39.99475009739399, 37.52039887011051, 37.265709936618805, 39.90064434707165, 39.4527205824852, 39.682292863726616, 38.41922923922539, 39.54898461699486, 38.7761364877224, 41.182383969426155, 37.85099633038044, 38.48729878664017, 37.365534380078316, 38.33216451108456, 37.907913476228714, 38.03852766752243, 36.437080800533295, 39.332707822322845, 38.16412232816219, 38.63461308181286, 38.01807336509228, 38.20255346596241, 37.69078552722931, 39.22919377684593, 40.37733256816864, 44.07919652760029, 44.416842609643936, 45.062435567379, 44.2743806540966, 43.65637041628361, 40.42404346168041, 45.63395909965038, 46.851303577423096, 52.540966272354126, 54.88166727125645, 55.53211636841297, 50.762281715869904, 53.66483956575394, 49.80844549834728, 43.510503843426704, 0.8219879830721766, 1.8940077745355666, 3.4646661998704076, 0.2532717876601964, 0.5859044543467462, 9.59838280454278, 71.47893726825714, 55.16195923089981, 60.169383734464645, 53.7656519562006, 50.65046511590481, 38.70006076991558, 21.079057306051254, 40.05528464913368, 37.8805473446846, 0.8261773770209402, 0.019770047838392202, 0.10487178980838507, 0.016209045170398895, 0.06076636156649329, 0.05208766808209475, 0.011120851013401989, 0.03510712143906858, 0.0966523187526036, 0.04747416271129623, 0.09377122725709341, 0.08139276062138379, 0.11966547215706669, 0.14041591377463192, 0.19890323630534112, 0.1483348966576159, 0.1286654153955169, 0.15409066749271005, 0.1678593474207446, 0.1525296934414655, 0.15505876945098862, 0.15671629691496491, 0.24364794313441962, 0.10893239887082018, 0.21565165399806574, 0.6655329221393913, 0.4229201265843585, 15.907334368675947, 73.58799129724503, 53.67768667638302, 38.08116517961025, 33.46811391413212, 54.592776373028755, 69.77168887853622, 71.16392657160759, 61.80254749953747, 60.297968834638596, 62.93677903711796, 5.790673149749637, 10.203359741717577, 2.6094544027000666, 0.4120418743696064, 4.408242730423808, 49.790996834635735, 62.58358418941498, 58.96271288394928, 64.02847945690155, 59.176033437252045, 63.438458517193794, 57.81767852604389, 63.84547367691994, 57.294002026319504, 56.84116132557392, 55.64030036330223, 47.49800607562065, 47.306097373366356, 43.58790189027786, 44.37421269714832, 43.24443832039833, 42.98662215471268, 42.5645712018013, 41.53440847992897, 45.529411509633064, 41.58839978277683, 42.678454890847206, 44.11833442747593, 42.506092339754105, 44.074313789606094, 43.32215555012226, 42.92276658117771, 45.90524174273014, 42.39324599504471, 45.790879279375076, 41.47211842238903, 41.97575859725475, 44.19184908270836, 42.23041333258152, 40.29524177312851, 43.668708354234695, 43.75209487974644, 43.47151793539524, 43.91332782804966, 48.37500661611557, 46.695329546928406, 47.79661685228348, 49.86657477915287, 54.13573309779167, 53.934784680604935, 50.98460778594017, 45.90895414352417, 46.92375808954239, 43.42017509043217, 44.07118275761604, 41.57308280467987, 41.41492389142513, 41.33971452713013, 42.62127935886383, 42.24470056593418, 42.70208582282066, 42.738404273986816, 40.6367826461792, 42.220188081264496, 44.58989292383194, 42.046077623963356, 41.83019980788231, 40.610617250204086, 43.08282919228077, 43.10839042067528, 42.42130748927593, 41.46658591926098, 42.02289506793022, 41.96009203791618, 43.495240062475204, 42.087503001093864, 41.44604802131653, 44.497379288077354, 50.24496227502823, 51.50361053645611, 51.93491779267788, 47.75878608226776, 45.95178924500942, 42.235322669148445, 41.019456312060356, 39.45628099143505, 42.21242129802704, 41.34417548775673, 42.01287120580673, 39.47911396622658, 42.86935284733772, 41.42709083855152, 43.16209673881531, 41.87626093626022, 42.87809617817402, 39.42866787314415, 40.75262703001499, 39.55816492438316, 40.65028332173824, 38.63932862877846, 41.4802385866642, 40.72623364627361, 40.98078578710556, 41.222164034843445, 40.03941290080547, 40.249146446585655, 41.949821189045906, 41.188068464398384, 46.14986501634121, 45.53680971264839, 45.81411123275757, 45.90519614517689, 47.253128215670586, 42.40311786532402, 49.01708096265793, 49.79421146214008, 55.377130284905434, 57.34348677098751, 58.01382400095463, 51.85907386243343, 57.34529547393322, 49.26664777100086, 50.36691673099995, 1.3657271093688905, 2.5645142141729593, 6.485998788848519, 0.46538795402739197, 1.015608434099704, 10.114152878522873, 79.45375934243202, 58.60918365418911, 64.57832515239716, 58.57152387499809, 56.29328012466431, 39.3245230615139, 32.19406507909298, 48.6736211925745, 48.54137308895588, 1.3960406952537596, 0.25333213910926133, 0.28274941840209067, 0.14215130737284198, 0.19739213457796723, 0.18723346875049174, 0.17844379821326584, 0.2198962340480648, 0.1751689231605269, 0.12173920345958322, 0.1666172593832016, 0.16954286489635706], [0.06824738084105775, 0.046486690698657185, 0.05366394521843176, 0.04678477060224395, 0.04708276144810952, 0.0195531329154619, 0.043655119006871246, 0.08375277539016679, 0.05162172550626565, 0.020081504953850526, 0.045762833251501434, 0.025600970402592793, 0.03505933083943091, 0.06448283675126731, 0.03010538377566263, 0.28575903503224254, 34.31000433862209, 48.34844224154949, 29.615133963525295, 32.13710233569145, 35.67898727953434, 58.8080345839262, 62.235146686434746, 55.560546442866325, 49.09096799790859, 57.69801154732704, 8.209378737956285, 4.650626024231315, 0.2648027735995129, 0.1951107577770017, 0.8914841164369136, 41.980983316898346, 65.58660104870796, 58.99673245847225, 57.581692188978195, 58.108860701322556, 52.65415459871292, 54.15821269154549, 55.85254557430744, 56.09054200351238, 55.678343921899796, 49.363576769828796, 47.675840333104134, 41.64195790886879, 40.81714376807213, 39.553620368242264, 39.70692694187164, 38.15466083586216, 38.82024832069874, 37.26743504405022, 38.331476747989655, 37.91026555001736, 39.18598249554634, 38.24892237782478, 38.519152477383614, 37.96400226652622, 37.111210227012634, 38.650800213217735, 37.36089862883091, 38.23484793305397, 38.05966593325138, 41.276968494057655, 38.9772292971611, 40.164380595088005, 38.80331262946129, 40.067299604415894, 39.992534816265106, 41.063146367669106, 39.90341439843178, 42.22784847021103, 43.4067390114069, 41.95694960653782, 42.88375407457352, 46.244643330574036, 49.134069085121155, 47.55738168954849, 44.22509729862213, 39.27888751029968, 38.88674855232239, 39.7542230039835, 37.27321453392506, 37.01250672340393, 37.14456483721733, 37.744385451078415, 36.87792934477329, 39.076909348368645, 37.81032711267471, 40.237663462758064, 37.06992544233799, 36.96687497198582, 38.75932238996029, 36.69644348323345, 35.12658432126045, 35.99562428891659, 37.77756527066231, 37.51586191356182, 37.550405859947205, 36.669939905405045, 39.13890682160854, 40.719504207372665, 41.36373683810234, 40.78664280474186, 39.90441374480724, 41.627351492643356, 45.79641938209534, 44.397239461541176, 43.78331400454044, 42.11251325905323, 41.3841987401247, 39.43303383886814, 37.835789546370506, 36.73709750175476, 38.832901641726494, 37.94335797429085, 38.00039291381836, 35.774099975824356, 36.576753705739975, 36.582791581749916, 37.492113187909126, 36.47784881293774, 38.56093503534794, 34.85123969614506, 36.495134085416794, 35.19221439957619, 35.87860956788063, 35.19919082522392, 36.3372677564621, 37.26178854703903, 37.9613272100687, 35.9515580534935, 36.564157381653786, 36.062234714627266, 38.14465597271919, 35.69583557546139, 36.89684472978115, 37.76200890541077, 39.01554264128208, 38.3560424298048, 42.28011466562748, 41.74762263894081, 48.38490888476372, 49.75154735147953, 54.35539931058884, 50.35923734307289, 55.08586071431637, 52.42986783385277, 54.68445785343647, 52.467569410800934, 49.27286043763161, 1.0826585674658418, 0.3903887065825984, 0.47853385331109166, 0.3543174499645829, 0.15654244140023366, 18.107823841273785, 64.80641171336174, 48.93917374312878, 53.75581428408623, 48.8423815369606, 37.163271233439445, 22.825002819299698, 28.12334731221199, 46.9305407255888, 10.044058039784431, 0.4429995850659907, 0.06662719082669355, 0.10514270339626819, 0.03388974320841953, 0.04598548497597221, 0.024033973822952248, 0.018327722791582346, 0.04544413277471904, 0.02395399071247084, 0.056162975379265845, 0.037108241012902, 0.07254117270349525, 0.03386519667401444, 0.040855734259821475, 0.01842765668698121, 0.016252870846074075, 0.040240508678834885, 0.07644783807336353, 0.07104565607733093, 0.03650927588751074, 0.07073984670569189, 0.12734614399960265, 0.058596214148565196, 0.016690604388713837, 0.03344043216202408, 0.07281874335603788, 0.05640432922518812, 1.0627171187661588, 44.76428836584091, 54.43490244448185, 22.181165367364883, 32.912507727742195, 45.698635429143906, 62.303592413663864, 66.7958253622055, 59.46348041296005, 54.682250171899796, 62.04340897500515, 8.883824497461319, 3.8229862600564957, 0.6524537864606827, 0.2634734089951962, 1.2914209091104567, 45.42487531900406, 65.77149912714958, 60.511122196912766, 60.95529556274414, 61.02472543716431, 55.84469139575958, 57.245159447193146, 58.55469077825546, 55.98053030669689, 57.40717135369778, 52.30966128408909, 49.02584709227085, 44.46676813066006, 43.56797955930233, 42.88535378873348, 43.57040002942085, 40.628822073340416, 40.847728326916695, 39.28179055452347, 41.12969219684601, 41.98228284716606, 40.839718356728554, 40.85238687694073, 40.337719693779945, 40.15298120677471, 38.647566586732864, 39.94789481163025, 39.850965812802315, 40.21206043660641, 42.28523679077625, 41.56726911664009, 39.58602122962475, 42.12935395538807, 40.08968040347099, 40.7396849244833, 42.12639011442661, 41.781893000006676, 43.577406853437424, 45.0732421875, 46.175988614559174, 44.82263423502445, 46.41171656548977, 48.26868072152138, 51.862600073218346, 50.13195253908634, 46.15013860166073, 41.24670311808586, 39.87474873661995, 40.39228856563568, 39.399113059043884, 39.98383708298206, 39.14626322686672, 38.95337417721748, 40.859253108501434, 40.36262735724449, 40.309901386499405, 41.06688156723976, 40.28029337525368, 38.71117517352104, 41.747797429561615, 39.89898003637791, 37.606008276343346, 38.566961511969566, 39.25267651677132, 40.00788599252701, 38.856338784098625, 38.73928986489773, 41.02819964289665, 42.29859687387943, 41.43040806055069, 41.38216584920883, 40.08526124060154, 41.891722306609154, 48.105715066194534, 46.86435207724571, 45.167522728443146, 43.98215353488922, 43.28318864107132, 42.292946577072144, 39.82338689267635, 39.30725298821926, 41.66063390672207, 40.21121688187122, 40.02487488090992, 37.30855643749237, 38.373529091477394, 38.151791989803314, 38.93561773002148, 37.655880600214005, 39.931616485118866, 36.91261388361454, 37.64654450118542, 36.64855845272541, 37.91493929922581, 37.32591390609741, 38.732222244143486, 38.390730768442154, 40.38073718547821, 37.94706277549267, 39.058696925640106, 38.51010136306286, 39.89874444901943, 37.93728590011597, 38.57005834579468, 40.026884973049164, 41.39547273516655, 40.45015186071396, 45.419194623827934, 44.22894649207592, 50.76795481145382, 53.31848055124283, 57.49976098537445, 51.84504881501198, 55.612288266420364, 53.191977739334106, 56.56778119504452, 54.45111237466335, 51.553566455841064, 1.2057389505207539, 0.6844185024965554, 1.119129485450685, 0.44013667618855834, 0.15541311528068036, 19.05854992568493, 71.23812898993492, 51.03075630962849, 59.89541843533516, 49.03175577521324, 48.83062116801739, 28.121705800294876, 23.315955474972725, 56.54996395111084, 13.470140397548676, 0.39288831932935864, 0.022494588847621344, 0.07968093763338402, 0.01781970600859495, 0.07148094053263776, 0.021442370016302448, 0.07090429920936003, 0.040361300634685904, 0.11987620498985052, 0.020897223585052416, 0.05067009180493187, 0.07489200710551813, 0.17859326675534248, 0.0649061800504569, 0.1626349543221295, 0.15511343604885042, 0.10199669486610219, 0.10759935321402736, 0.15366434818133712, 0.17233656108146533, 0.11859249731060117, 0.14792701229453087, 0.19015784229850397, 0.12695017852820456, 0.13644420658238232, 0.23744507285300642, 0.19977563089923933, 1.2841711356304586, 51.973930299282074, 63.11376594007015, 36.69169373810291, 42.222228571772575, 49.30945247411728, 66.93383395671844, 68.9534255862236, 63.60387124121189, 59.984896034002304, 67.27724432945251, 12.476150784641504, 9.520033858716488, 3.7565632117912173, 0.709816220914945, 1.4809122285805643, 47.17096522450447, 68.2831871509552, 63.04118223488331, 62.35964700579643, 64.45887476205826, 58.44185583293438, 60.537979155778885, 59.954060688614845, 58.17647807300091, 59.982916340231895, 55.21636091172695, 52.277363017201424, 46.72743022441864, 45.66869683563709, 45.84330506622791, 47.56014034152031, 42.80068293213844, 44.1878516972065, 43.62761735916138, 43.49515646696091, 43.68840649724007, 43.57821621000767, 42.953161150217056, 43.09587009251118, 41.66979901492596, 40.300724878907204, 42.31720827519894, 40.49037650227547, 42.32782870531082, 44.655127823352814, 45.28263755142689, 41.82821251451969, 43.62122990190983, 43.04471343755722, 42.193236127495766, 44.00191627442837, 45.934940949082375, 46.86613418161869, 46.51831604540348, 49.16019268333912, 45.02681627869606, 47.51198932528496, 50.17593137919903, 53.94043877720833, 50.047000497579575, 47.45533436536789, 42.260036543011665, 41.067383140325546, 43.25809098780155, 40.764379799366, 41.75153262913227, 41.98091112077236, 43.13278131186962, 41.95949167013168, 43.458693623542786, 43.04314412176609, 45.647064596414566, 40.78598164021969, 40.385141149163246, 43.607223853468895, 40.73123797774315, 39.08222906291485, 39.34791460633278, 42.33491152524948, 43.351178392767906, 41.419023871421814, 41.639073863625526, 44.8675250262022, 44.08154100179672, 43.350844010710716, 41.91417150199413, 42.76023410260677, 42.92514905333519, 48.390361592173576, 46.89710631966591, 47.220309376716614, 46.96528986096382, 45.393599197268486, 42.44233176112175, 43.47021460533142, 41.232651472091675, 43.768745586276054, 41.818576231598854, 43.503079041838646, 39.5958437025547, 39.4729582965374, 40.88745519518852, 42.30287164449692, 41.10724300146103, 43.937977105379105, 38.95644821226597, 40.79731643199921, 38.165444657206535, 41.59704811871052, 39.61583063006401, 41.71741805970669, 40.46636939048767, 42.90848694741726, 39.9015448987484, 43.761286586523056, 40.96303693950176, 42.50378966331482, 39.2924527823925, 41.2734916806221, 42.112285271286964, 44.64715205132961, 43.39016430079937, 49.31405022740364, 46.18805676698685, 53.74650478363037, 54.806340113282204, 60.632149502635, 52.60655075311661, 59.017418548464775, 54.18679855763912, 61.913414150476456, 55.31426265835762, 55.841761752963066, 2.1705188183113933, 1.3373843114823103, 2.938583241775632, 1.1532267183065414, 0.29930533783044666, 21.438231132924557, 77.03816056251526, 57.2013022005558, 65.49456998705864, 56.37940250337124, 51.62057965993881, 34.18814867734909, 35.941169410943985, 63.84183347225189, 20.940731428563595, 0.8466935448814183, 0.38699044205714017, 0.15713283471995965, 0.05581759840424638, 0.13920474360929802, 0.136860046768561, 0.15143431315664202, 0.2051109602325596, 0.1654448886984028, 0.2024358295602724, 0.0942194473464042, 0.20851916953688487], [0.07942579468362965, 0.02249406934424769, 0.03979285633249674, 0.05059260416601319, 0.027092787422589026, 0.04861291410634294, 0.06459282303694636, 0.011716749213519506, 0.04803299620107282, 0.0503220839163987, 0.11051459834561683, 0.08451891670119949, 0.0308722171394038, 0.00807393125796807, 0.17284310655668378, 0.22985955176409334, 13.938938342034817, 55.34544758498669, 44.47644241154194, 26.96842398494482, 26.39143254607916, 54.30912919342518, 49.58586864173412, 50.90981259942055, 48.74169073998928, 60.49350634217262, 13.924235980957747, 1.2609523627907038, 0.45785387861542404, 0.4426895157666877, 0.6438569852616638, 36.88078299164772, 69.0618945658207, 56.446894481778145, 57.356413677334785, 54.5993310213089, 62.60168641805649, 55.50228796899319, 55.330157205462456, 51.122217401862144, 52.419179007411, 50.67758806049824, 48.10683600604534, 45.340561643242836, 40.88945388793945, 40.464511290192604, 39.91660729050636, 38.75648774206638, 38.71445059776306, 37.18560263514519, 40.05004093050957, 39.16609816253185, 37.06098452210426, 39.24067296087742, 39.92121644318104, 39.12862077355385, 38.76642420887947, 37.6490181684494, 38.05192954838276, 40.10628551244736, 39.52014036476612, 40.195542722940445, 39.316216707229614, 40.13615570962429, 39.68679562211037, 40.940074771642685, 39.862027019262314, 39.57806445658207, 40.12269303202629, 44.129543825984, 44.597769901156425, 42.39449232816696, 45.1706537604332, 44.98621545732021, 45.557100623846054, 45.645905658602715, 40.946462228894234, 39.58082690834999, 38.383476957678795, 40.278781056404114, 37.55287952721119, 37.72162467241287, 37.94406093657017, 37.30593077838421, 39.23276178538799, 37.58889399468899, 39.44916017353535, 38.39624047279358, 38.153395503759384, 39.8524135351181, 38.72393488883972, 37.608717530965805, 35.47956258058548, 37.53412753343582, 37.673504054546356, 38.378871604800224, 37.397836446762085, 36.30642481148243, 36.911606937646866, 36.88070319592953, 37.923469841480255, 38.75381648540497, 41.78876683115959, 44.00138810276985, 49.91562254726887, 46.890817657113075, 41.621845588088036, 41.508832052350044, 40.492390394210815, 42.15166635811329, 40.45264832675457, 35.6919901818037, 38.83887492120266, 38.54179546236992, 37.5359970331192, 36.88341245055199, 37.28676080703735, 38.381409868597984, 35.37653490900993, 36.06832578778267, 34.97931942343712, 37.14286632835865, 37.047977820038795, 34.80243891477585, 35.01850292086601, 34.89953130483627, 34.863706827163696, 35.82182541489601, 36.29675433039665, 35.835702270269394, 37.6204627007246, 36.135414987802505, 38.20156931877136, 37.53304839134216, 38.827741518616676, 37.505739256739616, 37.44370378553867, 41.18298053741455, 45.726297944784164, 45.93720942735672, 51.518262550234795, 52.661070227622986, 52.227714881300926, 48.97114522755146, 55.07305920124054, 52.61250123381615, 53.37026037275791, 52.35128045082092, 55.383494943380356, 3.8662804244086146, 0.052090243334532715, 0.32955542556010187, 0.17693796573439613, 0.0892736490641255, 21.120647974312305, 61.10834375023842, 46.438132748007774, 61.82764135301113, 47.48032942414284, 37.94633321464062, 28.08715045452118, 34.131068140268326, 37.49601557850838, 0.7753468514420092, 0.14876654458930716, 0.08687081979587674, 0.03210682618373539, 0.020884321347693913, 0.03324348101159558, 0.017950028995983303, 0.04817767417989671, 0.053448844846570864, 0.009826091827562777, 0.04619623265170958, 0.041599477553972974, 0.04219820890284609, 0.0028454296761992737, 0.04065594810526818, 0.03240738114982378, 0.0695546146016568, 0.0306825909865438, 0.041787289155763574, 0.03675878222566098, 0.07101048569893464, 0.05196400772547349, 0.012440604805306066, 0.08565922660636716, 0.03625064484367613, 0.0546152338210959, 0.0818397116381675, 0.3003733477089554, 0.23655440658330917, 18.30196112394333, 62.995121106505394, 39.089756458997726, 27.210085317492485, 39.22398425638676, 62.14037597179413, 58.979086205363274, 57.4879702180624, 54.41801615059376, 67.27019190788269, 16.642403975129128, 2.404602882452309, 0.895633731270209, 0.5395647534169257, 0.6932406197302043, 40.65143845975399, 71.54507651925087, 60.54047182202339, 60.661282539367676, 57.55028687417507, 62.814193814992905, 58.13714258372784, 57.98630207777023, 53.08699317276478, 55.07758855819702, 51.33697807788849, 50.745011642575264, 47.64932155609131, 44.70478355884552, 42.223205119371414, 41.86456136405468, 42.452788800001144, 40.69789096713066, 40.28467074036598, 42.057515010237694, 41.2355887144804, 40.16846917569637, 41.03594742715359, 42.523518204689026, 40.22287845611572, 40.07472820580006, 39.638120234012604, 39.48065668344498, 41.875440180301666, 42.531174793839455, 41.982921212911606, 40.54009683430195, 40.13747423887253, 40.88755019009113, 42.31165677309036, 43.124113976955414, 41.644123792648315, 43.07190477848053, 45.85764929652214, 46.26983217895031, 45.653007477521896, 45.311903581023216, 47.45264030992985, 47.07844778895378, 46.99139446020126, 42.4115040153265, 42.105700224637985, 40.45972354710102, 42.673883736133575, 39.70109045505524, 39.459267631173134, 39.0644384175539, 40.880030393600464, 40.92543415725231, 38.99724282324314, 38.878453597426414, 39.927242919802666, 40.49540363252163, 42.496463656425476, 39.860491901636124, 39.81611408293247, 38.770398795604706, 39.344996362924576, 38.1887374073267, 39.16468843817711, 37.62821048498154, 36.913776621222496, 37.95808978378773, 39.2920196056366, 38.75936798751354, 41.46815903484821, 42.70562343299389, 44.00749057531357, 50.96663475036621, 47.570255398750305, 43.0939169973135, 43.85751262307167, 41.663924530148506, 42.849726900458336, 41.80780380964279, 36.765432581305504, 39.83545124530792, 39.507946819067, 38.46308648586273, 37.51498036086559, 38.341166228055954, 39.16006788611412, 37.865990325808525, 38.58752980828285, 37.284746915102005, 38.95368196070194, 37.259303480386734, 37.830796614289284, 38.26456993818283, 37.073273062705994, 39.492059871554375, 37.55289852619171, 37.47268483042717, 38.337412029504776, 39.447932839393616, 38.21324609220028, 39.723847433924675, 39.8453801125288, 41.54064014554024, 40.383750423789024, 39.5876931399107, 42.68755540251732, 46.840660348534584, 50.24212382733822, 53.075251802802086, 53.85804779827595, 54.13218028843403, 50.56593105196953, 55.83431415259838, 55.42816534638405, 56.75699584186077, 55.85178181529045, 57.384566366672516, 4.245860343798995, 0.22706382209435105, 1.3361224229447544, 0.026605823513818905, 0.07863321065087803, 23.226196691393852, 69.53069061040878, 49.56810459494591, 67.04833701252937, 51.972953751683235, 52.20161408185959, 26.516607329249382, 34.2693617194891, 48.56798306107521, 2.0635317591950297, 0.12368069146759808, 0.046418914062087424, 0.03328987266286276, 0.009182079265883658, 0.03649622522061691, 0.026615681090333965, 0.06500215458800085, 0.10350046417443082, 0.04667830951802898, 0.05443622409075033, 0.02203969685069751, 0.05917045462410897, 0.16617998597212136, 0.09030412853462622, 0.13074718415737152, 0.1628664301824756, 0.07665301222004928, 0.09581906502717175, 0.16602250223513693, 0.1435675923130475, 0.15691275824792683, 0.2005443919915706, 0.20179985353024676, 0.255863931379281, 0.1281358188134618, 0.19549017335521057, 0.37441843072883785, 0.4332639434142038, 22.999426759779453, 73.35924357175827, 55.341757982969284, 35.71097396314144, 40.067592188715935, 65.54861068725586, 64.87502843141556, 63.18638764321804, 57.69596725702286, 71.94534704089165, 20.831284001469612, 3.8784141233190894, 2.736602467484772, 1.219794990029186, 0.7218937540892512, 43.86634334921837, 72.84770742058754, 62.487950921058655, 63.44745643436909, 61.630363538861275, 65.50694212317467, 59.94652949273586, 59.952920749783516, 55.26292361319065, 56.7744293063879, 54.0422049164772, 53.687125369906425, 49.99073691666126, 48.244916796684265, 45.00633157789707, 44.08835023641586, 44.938110038638115, 43.979797661304474, 42.43195831775665, 46.75223529338837, 44.834178015589714, 40.891049802303314, 43.403664976358414, 44.612425714731216, 42.64544606208801, 42.58304961025715, 41.905169785022736, 41.04751020669937, 45.843582451343536, 45.66950999200344, 45.397911965847015, 44.33896578848362, 42.93806076049805, 43.95990192890167, 45.146076679229736, 43.84789913892746, 44.11293491721153, 44.281258285045624, 49.586966782808304, 49.90113392472267, 49.743130803108215, 48.14149394631386, 47.978923469781876, 50.175878182053566, 48.73649261891842, 44.76200468838215, 44.80813041329384, 41.99465498328209, 44.90508981049061, 42.393500581383705, 40.63067637383938, 41.211676597595215, 42.31915757060051, 42.888348028063774, 41.30053482949734, 42.28460982441902, 42.8737910091877, 42.06318810582161, 45.297042578458786, 41.599609181284904, 42.19287134706974, 40.8859770745039, 42.006381154060364, 40.89527137577534, 42.08814136683941, 39.80399653315544, 38.969511911273, 40.86689829826355, 40.662427470088005, 40.82178331911564, 41.11415483057499, 44.27053906023502, 45.25064326822758, 53.366969749331474, 49.47786703705788, 46.195781752467155, 45.13645179569721, 44.33070883154869, 46.260670870542526, 45.072106048464775, 38.799167051911354, 44.08939138054848, 41.771671548485756, 41.67517572641373, 40.63328303396702, 41.28413110971451, 41.061679646372795, 39.32111844420433, 40.21448090672493, 39.26391251385212, 39.72680367529392, 40.119360610842705, 39.849852472543716, 39.429169446229935, 38.63158844411373, 40.920163840055466, 40.034655556082726, 40.43854348361492, 40.51836960017681, 42.84256808459759, 40.77420227229595, 44.604157358407974, 42.31125019490719, 43.07144120335579, 42.915892750024796, 42.99809753894806, 45.40423482656479, 50.20718090236187, 52.604723051190376, 55.93330644071102, 55.55260866880417, 56.98114201426506, 53.02523508667946, 60.24127207696438, 57.352184504270554, 60.338349267840385, 57.01587975025177, 61.035760045051575, 5.301858354359865, 0.16055386833613738, 1.9823514902964234, 0.6683637702371925, 0.1573891576845199, 27.32095006853342, 75.34204557538033, 54.74740527570248, 69.93139430880547, 57.64020524919033, 51.88242740929127, 38.13689298927784, 42.493290826678276, 60.09154111146927, 3.333786497823894, 0.3818643093109131, 0.2388528230949305, 0.30699600640218705, 0.06849778888863511, 0.1691198704065755, 0.100694804568775, 0.16561693337280303, 0.22554400755325332, 0.15636839292710647, 0.10147860899451189, 0.1599715050542727, 0.10593202197924256], [0.028431968785298523, 0.10202780569670722, 0.035203515290049836, 0.05747298106143717, 0.05119622626807541, 0.04730561726319138, 0.07644066892680712, 0.04115680501854513, 0.06728362786816433, 0.006798762451580842, 0.016491063142893836, 0.026377952635812107, 0.08397621379117481, 0.09905340397381224, 0.09772033605258912, 0.14542925491696224, 2.148658591322601, 42.054771557450294, 42.36593306064606, 26.328942999243736, 25.816276408731937, 32.40925133228302, 47.643994241952896, 58.945617601275444, 48.54427233338356, 62.860285341739655, 19.780619479715824, 1.7724952823482454, 0.6223279936239123, 0.6984314974397421, 0.2989130682544783, 31.38718217611313, 71.37657836079597, 57.0169322937727, 56.155450120568275, 47.96696551144123, 51.78491324186325, 53.56482893228531, 57.70258650183678, 54.248123466968536, 52.78688907623291, 47.683816105127335, 44.921337738633156, 41.797669753432274, 40.89890018105507, 39.578987807035446, 41.24666132032871, 37.252923622727394, 37.84928262233734, 38.68029423058033, 39.530829191207886, 40.37925146520138, 39.05165210366249, 39.936890602111816, 39.645993411540985, 39.72273029386997, 39.74887289106846, 37.80505679547787, 39.593658819794655, 38.76740075647831, 38.84519778192043, 40.74721232056618, 39.36876408755779, 39.562496691942215, 40.87355174124241, 40.563872158527374, 40.68726293742657, 37.93873742222786, 41.672952845692635, 44.94235821068287, 43.07009607553482, 41.971533223986626, 42.91226774454117, 43.823557645082474, 41.43183298408985, 41.0562839359045, 38.70876990258694, 38.40547017753124, 38.82258519530296, 38.732856810092926, 38.50253216922283, 35.02758823335171, 37.70188093185425, 38.675092309713364, 37.03066974878311, 36.723585426807404, 38.371754586696625, 37.63706021010876, 38.58198210597038, 37.71483063697815, 38.224337697029114, 37.43322774767876, 36.12673245370388, 36.26058407127857, 37.76803158223629, 37.80359387397766, 36.752323284745216, 38.77080537378788, 36.83895103633404, 38.305246755480766, 36.59224547445774, 35.99480353295803, 39.47005145251751, 41.657088696956635, 44.124995470047, 43.58926221728325, 43.15852113068104, 40.58412127196789, 40.247208550572395, 43.170000314712524, 42.23284900188446, 36.695124953985214, 37.13606849312782, 38.322163447737694, 37.37451329827309, 35.18463760614395, 37.21396051347256, 36.981492787599564, 39.36871849000454, 37.16078236699104, 36.84027336537838, 34.58649270236492, 35.36198168992996, 35.0483313202858, 36.0393675416708, 35.35169184207916, 34.01204712688923, 36.52870528399944, 35.81706807017326, 34.27795685827732, 35.2561991661787, 35.37943795323372, 37.76468776166439, 35.50402566790581, 36.88536934554577, 36.41621612012386, 40.50473213195801, 40.90996138751507, 44.69794772565365, 46.67090825736523, 51.380725130438805, 49.07555602490902, 51.72554522752762, 52.95624598860741, 52.65337184071541, 46.290898248553276, 53.46898287534714, 49.25715208053589, 59.27167050540447, 7.16264178045094, 0.182739348965697, 0.6963210075628012, 0.3124220558675006, 0.2615444187540561, 21.434180550277233, 57.185620442032814, 49.461736902594566, 53.78861412405968, 37.25342519581318, 37.90603257715702, 22.789757810533047, 41.20785780251026, 23.306524381041527, 0.45647731341887265, 0.09888486223644577, 0.01946798260178184, 0.0655256284517236, 0.06974958421778865, 0.04082360668689944, 0.043128943725605495, 0.019965698375017382, 0.03404418042919133, 0.023621176442247815, 0.07010525107034482, 0.017253740479645785, 0.06095373159041628, 0.01542804606287973, 0.08069330870057456, 0.07242331223096699, 0.03472199503448792, 0.032788960088510066, 0.0353394581907196, 0.02274986352858832, 0.0209808413637802, 0.047981279640225694, 0.05035114641941618, 0.11544012115336955, 0.04524325195234269, 0.04214339758618735, 0.04017596409539692, 0.1324079028563574, 0.11113626576843672, 3.931746161542833, 53.514318242669106, 45.34903898835182, 21.070198081433773, 30.88658183813095, 43.572349324822426, 51.87380567193031, 62.04418033361435, 53.61760810017586, 67.41353541612625, 22.62456737458706, 2.207488459534943, 0.30657948344014585, 0.6098527880385518, 0.17949785571545362, 32.366036251187325, 73.2687172293663, 60.37397615611553, 60.04785105586052, 52.89979241788387, 56.35285712778568, 56.250464022159576, 60.420474261045456, 56.04166142642498, 54.434530064463615, 49.01445910334587, 46.744669899344444, 44.32516112923622, 42.714666947722435, 43.67252714931965, 43.88022780418396, 38.96828457713127, 41.003858149051666, 40.0748535990715, 42.1608542650938, 43.14640738070011, 42.192069590091705, 41.46931417286396, 43.444835767149925, 42.934466153383255, 40.497679710388184, 39.67325694859028, 41.409095004200935, 40.781220495700836, 40.69446735084057, 43.07924598455429, 40.82564391195774, 40.92310108244419, 42.044515907764435, 42.91005626320839, 43.34295183420181, 41.032747998833656, 41.89146012067795, 46.702009588479996, 44.986097663640976, 45.055922716856, 45.440222695469856, 46.52081251144409, 44.3090233951807, 42.56003424525261, 40.46629339456558, 40.56581385433674, 41.06576442718506, 40.27675576508045, 39.80083890259266, 36.81934408843517, 38.77792239189148, 39.5651413500309, 39.50229272246361, 40.53214766085148, 39.56167593598366, 40.01276113092899, 41.55302748084068, 39.613938331604004, 39.05262865126133, 40.19695244729519, 38.727445900440216, 38.487579971551895, 38.1312844902277, 38.995787501335144, 39.21170711517334, 38.835439905524254, 40.15724457800388, 39.31078299880028, 39.45488266646862, 36.99242860078812, 40.015318393707275, 43.222730085253716, 44.69808831810951, 44.6577762812376, 44.98850293457508, 42.813435047864914, 42.0048688352108, 43.93875606358051, 43.18670801818371, 39.38316531479359, 39.82061304152012, 39.89229239523411, 38.95746275782585, 37.63588607311249, 37.78316617012024, 40.724975913763046, 40.06128832697868, 39.49721239507198, 38.29892389476299, 37.768970131874084, 38.32985043525696, 37.919362261891365, 37.961638793349266, 36.70171000063419, 37.742044776678085, 38.651905953884125, 37.65234678983688, 38.04694041609764, 38.07935267686844, 39.020398780703545, 39.86714914441109, 37.48736724257469, 38.98146227002144, 38.487287387251854, 41.6466810554266, 43.3126674592495, 47.80934236943722, 48.85718174278736, 53.323777467012405, 51.14574193954468, 54.47538547217846, 53.88787239789963, 54.061792865395546, 50.611232221126556, 55.1893025636673, 52.16461926698685, 60.63838876783848, 8.500945642590523, 0.2896789106307551, 0.524279895471409, 0.40773857559543103, 0.27399430226068944, 25.39879661053419, 62.376225516200066, 55.64018256962299, 61.89814656972885, 44.09343056380749, 49.63957116007805, 21.83206669986248, 45.57708755135536, 30.22491954267025, 0.5915726814419031, 0.04619732360879425, 0.044686548426398076, 0.03252521564718336, 0.05349344792193733, 0.04620899388100952, 0.05981893955322448, 0.03404198738280684, 0.023945426328282338, 0.031138019185164012, 0.03645901393610984, 0.0447513898689067, 0.011683883203659207, 0.12266795674804598, 0.15563035674858838, 0.15370951528893784, 0.1868827297585085, 0.16960709035629407, 0.1500402481178753, 0.141464464541059, 0.10425919885165058, 0.17612258292501792, 0.12014544132398441, 0.25210812978912145, 0.08381608800846152, 0.3073216608026996, 0.17597462836420164, 0.264118246268481, 0.3306509245885536, 4.098162744194269, 62.15996392071247, 54.01938334107399, 34.64610390365124, 37.90633276104927, 44.1817682236433, 57.31425493955612, 69.11453694105148, 57.969316989183426, 74.1859196126461, 28.019994758069515, 3.9276473689824343, 3.5674012871459126, 1.1368824890814722, 0.35000714531634003, 35.61407156288624, 76.83407351374626, 63.46919886767864, 60.99214218556881, 53.99702154099941, 57.512687891721725, 58.563464507460594, 63.27459990978241, 58.57937805354595, 57.40285098552704, 51.492716521024704, 49.18627068400383, 46.67621657252312, 44.671052768826485, 45.6484667211771, 45.76195143163204, 40.8257807046175, 43.40684920549393, 43.87372635304928, 45.02179674804211, 44.64917354285717, 44.31573763489723, 45.25154381990433, 45.153296291828156, 45.454832911491394, 42.96145610511303, 40.147916078567505, 44.83316347002983, 42.78718985617161, 43.28805238008499, 46.194949597120285, 42.79940240085125, 42.593404054641724, 44.751540049910545, 44.8096389323473, 45.068439245224, 42.63856083154678, 44.94326636195183, 49.381128028035164, 49.24098774790764, 46.69504836201668, 47.106543481349945, 48.93637329339981, 45.6901428848505, 45.00331833958626, 41.53704933822155, 41.593134328722954, 43.73974174261093, 42.7423332631588, 42.11603567004204, 39.954460859298706, 41.75755150616169, 43.386755883693695, 41.93307928740978, 42.024749368429184, 43.69639366865158, 42.33463034033775, 43.6828625947237, 42.064890414476395, 42.6700459420681, 41.91940762102604, 39.93278682231903, 41.802567690610886, 41.73213467001915, 41.27213895320892, 41.908103227615356, 43.11242200434208, 42.06440784037113, 43.11606600880623, 40.30624978244305, 39.14265722036362, 41.22772693634033, 45.62550075352192, 47.163225039839745, 45.4562084376812, 47.25411616265774, 44.56753872334957, 43.63553233444691, 47.11388848721981, 45.93836456537247, 41.62935398519039, 42.10077948868275, 40.67217394709587, 41.41261741518974, 40.845182463526726, 40.12110471725464, 41.997592225670815, 43.37348699569702, 41.091401651501656, 41.1478666216135, 37.87098705768585, 40.053795129060745, 38.7883148342371, 39.98263634741306, 39.824485033750534, 40.83697110414505, 40.540556609630585, 41.05504900217056, 39.87929329276085, 38.9894038438797, 40.5367948114872, 43.64188939332962, 39.62244227528572, 40.53195767104626, 41.146145313978195, 44.87433806061745, 48.131937459111214, 51.27508319914341, 52.25352309644222, 56.81040957570076, 52.65841796994209, 57.62092888355255, 57.82784678041935, 57.52336911857128, 53.12833875417709, 58.89122352004051, 53.99933561682701, 63.10194477438927, 9.847799520939589, 0.3156491811387241, 1.8871162505820394, 0.9367650398053229, 0.5479085713159293, 29.39538985490799, 68.01809817552567, 59.52475592494011, 68.23530212044716, 48.37581217288971, 50.515678748488426, 31.31646417081356, 54.9774107336998, 38.56657013297081, 0.8154776261653751, 0.15553971083136275, 0.19960315577918664, 0.15931995876599103, 0.14401636901311576, 0.16846697340952232, 0.07824065163731575, 0.11611457011895254, 0.12752463051583618, 0.11006145781720988, 0.1667171821463853, 0.06913069242727943, 0.17468045640271157], [0.06961044637137093, 0.07834976961021312, 0.09220131032634526, 0.04178029812464956, 0.03078969217312988, 0.05827566572406795, 0.005825946927870973, 0.026361927812104113, 0.036314562312327325, 0.015286161342373816, 0.03993701480794698, 0.0937942041491624, 0.06615862846956588, 0.025883658163365908, 0.05220430772169493, 0.11269970374996774, 0.20733706187456846, 16.342408172786236, 57.397223487496376, 32.42082171142101, 29.05091743916273, 25.60755930840969, 46.141843646764755, 61.93023964762688, 49.94306467473507, 59.14052814245224, 25.989811196923256, 0.4257081972900778, 0.6115293886978179, 0.8487139677163213, 0.18374102568486705, 22.96822853386402, 71.873280107975, 57.752458825707436, 57.357648611068726, 44.29304525256157, 44.41713139414787, 42.92500466108322, 48.08969132602215, 45.714172795414925, 45.38827568292618, 43.279814422130585, 43.58653016388416, 39.733692705631256, 39.34011362493038, 38.411261066794395, 38.73040594160557, 38.925111293792725, 40.091405510902405, 39.1799446195364, 40.100384429097176, 40.55432707071304, 42.06431284546852, 39.917200058698654, 39.6051912009716, 39.94826339185238, 38.97154860198498, 38.80407638847828, 37.7450580149889, 39.22243393957615, 40.08050389587879, 40.935674607753754, 39.82597075402737, 40.57087518274784, 39.88824561238289, 40.44517792761326, 41.5969455242157, 40.22518113255501, 40.51270790398121, 44.1583576798439, 41.727491319179535, 42.1788614988327, 39.5467085391283, 40.17875522375107, 41.67864114046097, 39.129236340522766, 40.118691846728325, 38.701204508543015, 39.1439263522625, 37.625926807522774, 37.11315952241421, 37.20767185091972, 37.14549958705902, 38.93814079463482, 37.88618624210358, 38.85498985648155, 40.209278985857964, 37.95595049858093, 40.952636897563934, 38.542916402220726, 38.71954992413521, 38.52033041417599, 36.87655761837959, 36.47909514605999, 37.632093876600266, 37.330409064888954, 37.16373860836029, 35.684394389390945, 35.21756283938885, 36.629551872611046, 36.25581152737141, 37.676794677972794, 37.05229438841343, 38.417443335056305, 40.18254742026329, 42.257190495729446, 42.312781512737274, 39.29132804274559, 38.745487332344055, 41.50401771068573, 42.33079254627228, 36.56968608498573, 36.30200944840908, 38.80080856382847, 38.875444158911705, 37.2543029487133, 35.70294879376888, 37.90865823626518, 38.02813522517681, 36.17401711642742, 36.213474199175835, 35.15754505991936, 36.182346269488335, 34.14352387189865, 36.792540326714516, 35.16609840095043, 35.78055202960968, 33.979311883449554, 33.84299039840698, 35.02047881484032, 35.773795992136, 36.85477718710899, 36.65389336645603, 35.82016110420227, 35.82166202366352, 36.02572247385979, 36.84944607317448, 37.88531608879566, 41.60763815045357, 44.94873806834221, 50.27496926486492, 49.46911230683327, 53.37306462228298, 46.511571407318115, 43.55186082422733, 43.86392667889595, 55.91357409954071, 47.48558834195137, 61.311230063438416, 11.91819442436099, 0.2741002512630075, 0.7318237493745983, 0.36899834813084453, 0.4320387466577813, 22.267620228230953, 56.16391606628895, 43.278708681464195, 52.18731164932251, 38.522310107946396, 31.83325543999672, 27.08527721464634, 46.82633511722088, 5.601851781830192, 0.21179172908887267, 0.03041789103008341, 0.08363748274859972, 0.07921558135421947, 0.04253653547493741, 0.018115366510755848, 0.10612342186504975, 0.016983841778710485, 0.0215863262565108, 0.10112513889907859, 0.061390017945086583, 0.06002373520459514, 0.05567491680267267, 0.06827371966210194, 0.04822474489628803, 0.019602060856414028, 0.02979537755891215, 0.018155709658458363, 0.05949853584752418, 0.027671382449625526, 0.047965123085305095, 0.009501763088337611, 0.034709115061559714, 0.054934784056968056, 0.09382838004967198, 0.041549523593857884, 0.0806797348195687, 0.02498199883120833, 0.09048560590599664, 0.2840057259891182, 24.186806045472622, 60.24438410997391, 32.106380984187126, 28.63182082772255, 35.73455169796944, 52.37493418157101, 69.42841529846191, 53.0682297796011, 66.30129709839821, 28.60353324562311, 1.0029137902893126, 0.9883096895646304, 0.8805165393278003, 0.1557779699214734, 24.515290819108486, 75.07030695676804, 60.48925817012787, 58.40703830122948, 45.71204870939255, 46.85388743877411, 46.5273367613554, 49.49088133871555, 47.36099302768707, 47.76857815682888, 44.58583474159241, 45.69303832948208, 43.671546801924706, 42.82081425189972, 40.50285883247852, 43.38081680238247, 42.09065303206444, 42.77631103992462, 41.0564549267292, 42.2793585062027, 43.98655749857426, 42.751908749341965, 40.05802430212498, 40.12016996741295, 40.48115439713001, 41.546203047037125, 41.64043039083481, 39.991900250315666, 41.30638271570206, 42.41803586483002, 42.730238512158394, 42.45136767625809, 41.09643638134003, 41.90540537238121, 42.21093937754631, 43.11407871544361, 43.167701438069344, 43.67905519902706, 47.58085682988167, 44.9771985411644, 43.97469833493233, 41.98005996644497, 42.180073633790016, 42.640491127967834, 40.99653214216232, 42.53328748047352, 39.63702969253063, 40.67137598991394, 40.87094888091087, 40.254599153995514, 40.6930386275053, 39.98023867607117, 41.554315611720085, 41.27612113952637, 40.97870729863644, 41.835941299796104, 40.48513278365135, 41.39734983444214, 39.39760833978653, 40.93020290136337, 41.08080022037029, 39.40811477601528, 40.59558905661106, 38.426927626132965, 37.87122264504433, 39.099761322140694, 37.35981948673725, 38.21759685873985, 38.201527521014214, 39.51160982251167, 39.777261167764664, 40.30112765729427, 41.403478905558586, 43.04003968834877, 45.43209873139858, 43.33844527602196, 42.35393710434437, 42.07165025174618, 43.42535421252251, 45.35916164517403, 38.726955726742744, 37.90996916592121, 41.00497528910637, 40.28695061802864, 37.46760070323944, 36.944972947239876, 39.79355089366436, 39.85139898955822, 38.0838630348444, 38.974634036421776, 37.092199847102165, 38.3617003262043, 37.61527217924595, 38.88759970664978, 36.64907902479172, 38.47376391291618, 37.67119377851486, 37.29271128773689, 37.13473476469517, 38.66410709917545, 37.65307255089283, 39.71172608435154, 37.65076607465744, 37.512468695640564, 38.294903710484505, 40.035932287573814, 40.46895705163479, 45.69473683834076, 45.97070463001728, 51.76771156489849, 52.573036551475525, 56.309030279517174, 47.84497305750847, 47.95455537736416, 46.394545286893845, 58.20784918963909, 49.10832166671753, 63.62964905798435, 12.182075064629316, 0.281891911290586, 0.7253491342999041, 0.21851111931027845, 0.20233157265465707, 26.87895778566599, 60.975331887602806, 51.27767466008663, 57.48001344501972, 49.305109307169914, 37.717691883444786, 24.230782985687256, 56.18776358664036, 8.312008380889893, 0.24209191178670153, 0.05982606046018191, 0.06146663356048521, 0.04501688577875029, 0.022431326324294787, 0.04206777273793705, 0.10678478676709346, 0.029956820653751493, 0.0381543278490426, 0.05156672865268774, 0.06979507044889033, 0.09719633526401594, 0.02634805150592001, 0.1311342290136963, 0.11323113343678415, 0.19599688210291788, 0.2500233775936067, 0.13177844288293272, 0.15854420664254576, 0.22069635830121115, 0.16273563407594338, 0.13345109531655908, 0.12521110387751833, 0.16215036157518625, 0.12618931388715282, 0.13034591975156218, 0.23337612947216257, 0.1361090675345622, 0.22800177801400423, 0.6062495126388967, 31.607439257204533, 73.69886174798012, 40.99532000720501, 38.10922287404537, 38.68139237165451, 55.590842217206955, 74.72045212984085, 58.20819117128849, 70.85722982883453, 32.0569684356451, 0.9094318002462387, 3.905526618473232, 1.4298993721604347, 0.2915558317909017, 26.343435421586037, 75.49684926867485, 62.69093602895737, 61.79924167692661, 48.2513802498579, 48.438915386796, 48.61803397536278, 51.29570849239826, 48.382412418723106, 50.73795162141323, 47.26592592895031, 48.93638089299202, 45.63270516693592, 46.40103153884411, 42.282322347164154, 45.26031754910946, 44.39402483403683, 46.86548061668873, 44.42664988338947, 44.75389212369919, 45.524703562259674, 44.8291090875864, 43.77317234873772, 42.626317888498306, 42.92240560054779, 44.20095719397068, 45.24853438138962, 42.32596680521965, 43.542737513780594, 45.53872860968113, 46.24673321843147, 44.51874554157257, 45.08493036031723, 43.34073655307293, 45.04473231732845, 44.221635684370995, 46.43517270684242, 43.87643940746784, 48.1924644112587, 46.80349454283714, 46.69212631881237, 44.052901938557625, 43.69768559932709, 46.29506662487984, 41.269851475954056, 46.172671392560005, 42.07495227456093, 43.61963018774986, 42.26648099720478, 40.93838386237621, 42.72950515151024, 40.396278351545334, 45.551647916436195, 44.58067461848259, 43.616115376353264, 43.238430842757225, 42.28688970208168, 44.24808606505394, 43.46609562635422, 43.78966346383095, 43.357068076729774, 40.676353722810745, 42.73603320121765, 42.40564852952957, 40.432509407401085, 41.2394493073225, 39.08112712204456, 38.34910400211811, 41.71320788562298, 41.79566726088524, 43.9362595975399, 42.395746260881424, 42.90839195251465, 44.56656597554684, 47.39681750535965, 45.68569712340832, 43.26345629990101, 42.51820608973503, 45.15175737440586, 47.73846857249737, 40.523681715130806, 40.392033979296684, 43.31207849085331, 43.06884594261646, 40.612520948052406, 38.485683873295784, 42.32976280152798, 42.257825061678886, 40.31896010041237, 40.71527123451233, 40.12465372681618, 40.594855695962906, 38.52652408182621, 41.91420949995518, 39.941074177622795, 40.51528036594391, 40.16941152513027, 38.84188435971737, 39.22668591141701, 41.16766355931759, 42.332840636372566, 42.173967361450195, 39.90705080330372, 39.534799978137016, 40.86747966706753, 42.80440293252468, 42.36886270344257, 47.62789070606232, 48.62240754067898, 53.661244958639145, 54.52188737690449, 59.53618571162224, 51.227296963334084, 49.86267998814583, 48.921208307147026, 63.01592878997326, 52.5192466378212, 65.60358613729477, 14.24753688275814, 0.27076551457867026, 1.6047648014500737, 0.9187446848955005, 0.5990022327750921, 29.633851759135723, 70.53610906004906, 54.95027258992195, 65.19009232521057, 50.78383795917034, 43.46325717866421, 35.49576871097088, 67.49637097120285, 10.626494586467743, 0.3919463261263445, 0.15464862895896658, 0.20782190695172176, 0.13923818478360772, 0.14383715519215912, 0.14743303880095482, 0.22256432916037738, 0.14481110527412966, 0.10811614032718353, 0.21436715964227915, 0.1844937415444292, 0.20469464507186785, 0.13961521064629778], [0.1094014362024609, 0.024397455490543507, 0.019302095897728577, 0.05722671419789549, 0.017546443523315247, 0.012622043213923462, 0.10988585083396174, 0.05050009174738079, 0.110533152037533, 0.05159428088518325, 0.040175270187319256, 0.14063599024666473, 0.03242465463699773, 0.08111536066280678, 0.059796842106152326, 0.1751072655315511, 0.1289172112592496, 3.162490976974368, 42.346500903367996, 33.162465915083885, 34.15586560964584, 23.885221928358078, 37.87203200161457, 60.74767850339413, 50.52548602223396, 57.380629777908325, 32.810977175831795, 1.326929172500968, 0.45000664656981826, 0.6144541630055755, 0.10339077474782243, 11.686749793589115, 70.58061987161636, 58.58963370323181, 58.47522184252739, 51.49406164884567, 47.79557950794697, 40.377207174897194, 43.85920733213425, 39.80298578739166, 41.839741095900536, 38.87614332139492, 39.265519827604294, 38.46825420856476, 39.426855370402336, 38.471149653196335, 40.83498761057854, 38.0524767190218, 39.076567366719246, 37.57906012237072, 39.814597964286804, 40.00166952610016, 39.66211594641209, 39.78414639830589, 38.61350521445274, 37.69794434309006, 37.86920115351677, 38.49027022719383, 39.47523817420006, 40.36431826651096, 40.139932706952095, 40.49381151795387, 39.27808575332165, 38.42478074133396, 41.570289954543114, 42.2572360932827, 40.97629442811012, 40.083748921751976, 42.26806931197643, 42.68181011080742, 41.26900792121887, 39.94475997984409, 39.46742959320545, 40.150412544608116, 41.34830206632614, 41.35323420166969, 40.76007843017578, 39.3162927031517, 39.42907065153122, 37.788881063461304, 38.672109469771385, 36.67836405336857, 38.43023344874382, 38.20605307817459, 40.41824497282505, 40.48988252878189, 41.14712566137314, 40.45085862278938, 42.45357155799866, 41.70843914151192, 41.12574800848961, 39.7872394323349, 39.859359562397, 37.48298607766628, 39.51555021107197, 37.86009304225445, 37.34188824892044, 37.46240258216858, 37.657244727015495, 38.29264663159847, 35.62485918402672, 36.48098744452, 37.07100458443165, 39.06482979655266, 40.297468453645706, 38.4085214138031, 41.6209564357996, 39.94953632354736, 40.163221657276154, 42.29278698563576, 43.50205309689045, 36.899694576859474, 36.38247013092041, 38.01765538752079, 36.50493375957012, 35.80660343170166, 36.7818059027195, 36.43214866518974, 37.480337619781494, 37.4986070394516, 36.23383730649948, 36.32563278079033, 35.72228975594044, 35.737929716706276, 35.780726820230484, 36.06266029179096, 34.52225334942341, 35.87551273405552, 36.84753857553005, 36.692989468574524, 36.64857745170593, 36.13072603940964, 38.61762419342995, 36.49544186890125, 38.40472161769867, 36.951599791646004, 40.14454945921898, 36.476328894495964, 37.64231152832508, 37.576081082224846, 40.408190712332726, 39.50261950492859, 41.17835998535156, 38.67445394396782, 44.47948604822159, 46.71408154070377, 55.89846611022949, 48.957059383392334, 59.94586452841759, 10.644306130707264, 0.2944012259831652, 0.051007275469601154, 0.40544824849348515, 0.17452877626055852, 29.709403105080128, 55.9958016872406, 48.49112078547478, 45.92644460499287, 29.589065462350845, 24.353706389665604, 41.08408324420452, 30.15218574553728, 0.7882875914219767, 0.030613432099926285, 0.020121666275372263, 0.06348712689941749, 0.08590648794779554, 0.020182537227810826, 0.08662118358188309, 0.08815826047793962, 0.03596059497795068, 0.037589416169794276, 0.03721743691130541, 0.019753238193516154, 0.05832665498019196, 0.02323458800674416, 0.09936863119946793, 0.042685269290814176, 0.08376404119189829, 0.058495044577284716, 0.015238919004332274, 0.03362307099450845, 0.03487057671009097, 0.13784315495286137, 0.08278025023173541, 0.061482203818741255, 0.011045631563320057, 0.1558426406700164, 0.07451934507116675, 0.07966964956722222, 0.09955983812687919, 0.21462858858285472, 0.1572929456597194, 6.0554353427141905, 55.24607911705971, 34.67895694077015, 35.10370194911957, 32.1625267714262, 45.90600170195103, 64.98564809560776, 57.368804812431335, 61.528688594698906, 36.02571487426758, 1.0646484838798642, 0.7892825442831963, 0.6723549810703844, 0.08214672328904271, 12.210172656923532, 72.56590694189072, 60.09368799626827, 61.02315992116928, 54.620096907019615, 49.504929184913635, 43.63325625658035, 43.950136452913284, 41.46124720573425, 43.56201007962227, 40.684534683823586, 41.384844705462456, 42.450877502560616, 40.90114966034889, 40.75464092195034, 43.498017713427544, 39.6723335981369, 42.51558043062687, 40.359158143401146, 42.41802826523781, 41.606513410806656, 41.8770132958889, 41.444691494107246, 40.87523505091667, 40.06886512041092, 39.89896863698959, 40.091166123747826, 41.518240347504616, 41.2416797876358, 43.303053975105286, 42.162347584962845, 41.72315575182438, 40.30392050743103, 42.59264029562473, 43.43801513314247, 42.897995710372925, 43.162583112716675, 43.314020186662674, 45.78091241419315, 43.4643629193306, 42.693794667720795, 41.37216858565807, 41.921531707048416, 42.76318274438381, 42.341371178627014, 42.998230531811714, 40.713888108730316, 40.91639444231987, 40.42809784412384, 41.38392135500908, 39.48416769504547, 40.53692400455475, 39.59953710436821, 40.97984343767166, 42.30013959109783, 43.100293055176735, 43.318317756056786, 43.543030098080635, 43.5571463406086, 42.02748902142048, 41.94941461086273, 42.04169265925884, 39.31899815797806, 40.75896508991718, 39.17604602873325, 40.65791331231594, 39.203883334994316, 38.43605473637581, 38.80982547998428, 37.49403968453407, 38.806276470422745, 38.891505897045135, 41.54767356812954, 42.8591313958168, 39.93915908038616, 42.8871700912714, 40.47073915600777, 41.76651522517204, 43.052932396531105, 45.04671201109886, 38.524521589279175, 39.33013916015625, 39.79619935154915, 39.566672667860985, 36.606836691498756, 37.92715944349766, 38.510800525546074, 40.68679556250572, 38.12441065907478, 39.04426530003548, 38.05707447230816, 38.395191729068756, 37.74533540010452, 38.326263427734375, 37.730896174907684, 36.04670874774456, 36.19846120476723, 39.13358710706234, 38.263475596904755, 39.79380927979946, 37.17877820134163, 39.328961223363876, 37.90852144360542, 41.023837476968765, 38.307902812957764, 41.41288720071316, 37.0292866230011, 41.597808077931404, 40.17971657216549, 44.28850069642067, 42.74977706372738, 43.91467295587063, 41.398812755942345, 46.90398395061493, 47.724325731396675, 59.61910866200924, 52.42814652621746, 62.13317535817623, 11.850963681936264, 0.05779672814242076, 0.11184511327883229, 0.5373055371455848, 0.1938167936168611, 32.79579699039459, 62.336726635694504, 55.338638350367546, 50.675878152251244, 40.02752333879471, 24.941633641719818, 41.58233530819416, 39.68508571386337, 1.315566475968808, 0.11443735347711481, 0.038575767539441586, 0.05649945029290393, 0.04438732561538927, 0.004588822466757847, 0.08831306506181136, 0.05524998159671668, 0.03857879179122392, 0.08258617119281553, 0.029513604495150503, 0.042626717549865134, 0.07405289783491753, 0.013246651396912057, 0.18188121845014393, 0.17098735144827515, 0.09450846191612072, 0.11820777537650429, 0.15937360120005906, 0.1549271569820121, 0.14918527915142477, 0.2440093393670395, 0.14806368621066213, 0.15447925601620227, 0.11339570468408056, 0.2308143544360064, 0.1854401727905497, 0.1346418118919246, 0.21613014629110694, 0.5199608334805816, 0.4862450051587075, 6.7931462824344635, 64.09732416272163, 42.52451755106449, 42.95190341770649, 37.48124197125435, 50.39032347500324, 70.11017471551895, 62.928989455103874, 65.33271387219429, 43.53118233382702, 2.484101504087448, 2.937786472029984, 1.3511564349755645, 0.13904156017815694, 13.66660600528121, 73.19269090890884, 61.70433036983013, 63.922039568424225, 57.47997544705868, 52.12923936545849, 45.97229294478893, 46.49829491972923, 44.839246943593025, 46.265530809760094, 43.10117080807686, 43.22611190378666, 45.290267542004585, 43.78417655825615, 43.553422540426254, 48.38267840445042, 42.51549303531647, 45.636782348155975, 40.99686652421951, 44.20155756175518, 44.133955389261246, 43.89262653887272, 43.714773282408714, 43.14686335623264, 42.45166786015034, 42.990171164274216, 41.8126105517149, 45.02124197781086, 44.87333111464977, 45.04319339990616, 44.50926885008812, 43.43290060758591, 41.54964566230774, 44.767233207821846, 46.94811478257179, 44.51520033180714, 45.77525831758976, 46.30632922053337, 49.12439100444317, 45.07791593670845, 44.5799108594656, 43.87490049004555, 43.64605017006397, 44.386896416544914, 45.77873133122921, 46.05282202363014, 43.43046873807907, 43.60930994153023, 40.523278936743736, 44.57788936793804, 42.10377372801304, 43.121663108468056, 42.39245563745499, 42.305854484438896, 44.2370780557394, 45.46143315732479, 44.75617200136185, 48.921440094709396, 45.923089385032654, 44.01166275143623, 44.53099988400936, 45.25046847760677, 42.07987681031227, 43.852147310972214, 40.80550119280815, 44.66418653726578, 41.705908477306366, 40.95696486532688, 40.77143982052803, 41.257828921079636, 41.57921567559242, 41.369178146123886, 43.892615139484406, 45.410835072398186, 40.12221805751324, 45.74965909123421, 42.28706829249859, 44.24788847565651, 44.66192565858364, 47.28427514433861, 39.65633645653725, 40.43658658862114, 41.42668426036835, 40.76420120894909, 40.0006739795208, 40.31762637197971, 40.80883741378784, 41.93212553858757, 39.53858457505703, 41.50277137756348, 41.53758890926838, 40.489244163036346, 41.70101813971996, 40.77779307961464, 40.275832414627075, 39.14248242974281, 40.330465883016586, 41.808457374572754, 42.628065794706345, 41.627359092235565, 39.64021012187004, 43.14307115972042, 41.612190306186676, 44.303802475333214, 40.88548690080643, 43.673860877752304, 40.33602878451347, 43.14004272222519, 42.13286876678467, 46.14907845854759, 43.60608771443367, 45.33363461494446, 43.83662514388561, 48.23395058512688, 51.21277414262295, 62.425892651081085, 53.60227212309837, 65.2215926349163, 14.454857558012009, 0.3045517875580117, 0.673239502357319, 1.1985755036585033, 0.3390935075003654, 39.445975944399834, 69.12957653403282, 59.71406176686287, 55.04024796187878, 40.69433815777302, 33.32654491066933, 52.838456109166145, 49.205072075128555, 1.490090754814446, 0.2141903800657019, 0.13525985763408244, 0.21315509889973328, 0.18593282526126131, 0.12013459112495184, 0.3011780435917899, 0.22187750117154792, 0.14896374806994572, 0.1287573081208393, 0.10999554768204689, 0.13264166453154758, 0.24088609992759302, 0.08561019290937111], [0.06680230057099834, 0.03994853665062692, 0.08185301834600978, 0.043948942693532445, 0.04081615923496429, 0.0419399711972801, 0.0775927492941264, 0.025697093369672075, 0.017609732021810487, 0.028738164073729422, 0.05391247192164883, 0.045177375213825144, 0.02968831904581748, 0.006749993608536897, 0.015090497818164295, 0.06580674657016061, 0.07309816937777214, 0.09509432813501917, 15.88565368205309, 47.25161969661713, 45.12870021164417, 37.44412936270237, 27.513799220323563, 55.706986784935, 52.29041151702404, 57.15252421796322, 38.59933577477932, 0.7514425716362894, 0.3722772456239909, 0.5230097542516887, 0.03247638604079839, 1.7541661346331239, 56.15060158073902, 61.630055755376816, 58.052350133657455, 53.472178503870964, 54.81142424046993, 48.1535355001688, 43.472388088703156, 42.19299674034119, 41.799307465553284, 41.95846952497959, 39.36538986861706, 39.43018779158592, 39.2893635481596, 38.326973989605904, 39.38908539712429, 38.83108913898468, 39.80726435780525, 40.86421184241772, 39.91954833269119, 39.420243725180626, 40.48458181321621, 37.555645778775215, 38.60953442752361, 38.63933242857456, 38.83114613592625, 38.91974598169327, 38.93779121339321, 38.784503638744354, 40.38106016814709, 40.31040295958519, 40.784967094659805, 40.58125242590904, 40.98470717668533, 41.136653423309326, 42.25401006639004, 39.11620683968067, 40.183622762560844, 41.74003444612026, 42.31828361749649, 40.241736844182014, 40.528895035386086, 40.15549287199974, 40.398748219013214, 39.51792128384113, 40.64139939844608, 39.31119717657566, 39.935302287340164, 38.84315349161625, 38.194813281297684, 38.80278825759888, 39.487807899713516, 40.022264420986176, 42.10465528070927, 44.974648877978325, 44.66662600636482, 44.92396719753742, 46.13237455487251, 45.13675197958946, 47.871689423918724, 45.10002315044403, 42.48212322592735, 40.74390649795532, 39.35690872371197, 38.0703167617321, 36.828797981143, 36.01276516914368, 37.68801547586918, 35.667671486735344, 36.173454746603966, 38.298308327794075, 38.31527441740036, 38.279305547475815, 39.94689166545868, 40.012745931744576, 39.140734523534775, 38.227974101901054, 39.53125096857548, 40.456425324082375, 41.51360459625721, 37.21636578440666, 36.5442768484354, 37.892737090587616, 38.704650923609734, 35.8115241676569, 37.11266554892063, 37.71310932934284, 38.420676961541176, 37.762024104595184, 35.13470068573952, 35.728118643164635, 36.07106164097786, 35.69571778178215, 35.36535210907459, 34.95156191289425, 36.05076313018799, 36.697047650814056, 35.85087485611439, 35.49615629017353, 37.30430066585541, 37.45182394981384, 37.62184962630272, 34.58748444914818, 37.73256428539753, 38.13947305083275, 38.21519918739796, 38.05819161236286, 38.61160151660442, 35.996916219592094, 37.44047395884991, 38.6385078728199, 42.07017593085766, 41.00407853722572, 48.1013149023056, 49.83971782028675, 56.06542535126209, 51.70590788125992, 53.72795417904854, 4.514192920178175, 0.21833926759427413, 0.19874842429999262, 0.1326003862777725, 0.3813949751202017, 41.82181365787983, 48.40880200266838, 53.33845987915993, 37.17245914041996, 31.358829997479916, 31.092906966805458, 43.58600579202175, 14.669586885720491, 0.3864709980553016, 0.05813181523990352, 0.0004979698428542179, 0.07949790917336941, 0.0419333104218822, 0.01700497628917219, 0.0539618766924832, 0.04175967384071555, 0.06703093400574289, 0.016697107457730453, 0.030214741091185715, 0.04296253937354777, 0.02897143036534544, 0.03967477321566548, 0.02414639435301069, 0.06119384604971856, 0.043779963089036755, 0.046045895796851255, 0.039202596599352546, 0.04299632193578873, 0.10490838511032052, 0.028319340453890618, 0.059931705181952566, 0.021364724671002477, 0.07489096809877083, 0.0662594343884848, 0.04714109054475557, 0.04830372425203677, 0.014020566704857629, 0.06202527409186587, 0.02151461067114724, 0.2589355321833864, 26.711517870426178, 50.51233872771263, 45.852302983403206, 40.48711247742176, 41.14506997168064, 62.07694597542286, 56.84269644320011, 60.91540530323982, 44.78257678449154, 0.4817327472846955, 0.22297669609542936, 0.4275615478400141, 0.03952784652938135, 1.9738828134723008, 58.543014004826546, 64.36777085065842, 62.20390476286411, 56.050283163785934, 57.575483322143555, 49.16033707559109, 46.61357693374157, 44.25727017223835, 44.71022106707096, 44.12711575627327, 42.233316376805305, 40.92450700700283, 40.949722453951836, 40.97254402935505, 42.54730112850666, 40.33334232866764, 42.72182196378708, 41.70063056051731, 43.21425274014473, 40.63756540417671, 42.43012301623821, 40.45476481318474, 40.89425303041935, 40.739244148135185, 42.52810835838318, 40.91451734304428, 40.82763120532036, 42.026979848742485, 42.41134822368622, 43.06895233690739, 41.86551131308079, 41.80063359439373, 42.82743729650974, 43.29434484243393, 43.63699905574322, 40.88314242660999, 43.33604760468006, 43.31905871629715, 42.595832124352455, 41.48541010916233, 42.783895432949066, 42.317352667450905, 42.042775601148605, 41.134293749928474, 42.61758595705032, 42.28743687272072, 41.66921764612198, 40.91289862990379, 41.030046343803406, 41.20728403329849, 40.988233387470245, 41.9240927696228, 45.07102690637112, 45.35917304456234, 46.234798058867455, 46.248492524027824, 46.21081754565239, 46.163289695978165, 46.79111860692501, 45.56091941893101, 44.10499334335327, 42.52592347562313, 41.664764285087585, 41.56276635825634, 38.627955839037895, 38.17876294255257, 39.605320394039154, 38.379300981760025, 37.55206257104874, 39.7590259462595, 40.42573817074299, 39.22608554363251, 42.70782731473446, 41.63514867424965, 40.75651802122593, 40.94944126904011, 40.86712248623371, 41.758843436837196, 42.05130614340305, 38.14896494150162, 38.94506402313709, 39.14751335978508, 38.74985709786415, 38.188862800598145, 38.846425116062164, 38.42551790177822, 39.144576117396355, 39.18345183134079, 38.00158604979515, 37.64794662594795, 39.20657739043236, 37.260736003518105, 37.597853913903236, 37.95676365494728, 38.06553661823273, 37.477225586771965, 37.68686793744564, 38.74280847609043, 39.814768955111504, 39.14022535085678, 39.54524181783199, 38.148885145783424, 39.95609477162361, 38.518346920609474, 40.86184836924076, 40.21486848592758, 40.69056116044521, 40.03296084702015, 40.36473624408245, 40.41587010025978, 44.50667358934879, 42.22118742763996, 49.239475429058075, 52.59178474545479, 58.629691153764725, 53.8375137001276, 57.11519122123718, 5.561260459944606, 0.34543670306447893, 0.16347555530956015, 0.05050711246440187, 0.5898770224303007, 45.588581934571266, 55.1040655374527, 57.821497321128845, 45.713272243738174, 39.296579360961914, 25.62223222106695, 51.08575075864792, 18.620602525770664, 0.4225198714993894, 0.07999203851795755, 0.04549735218461137, 0.022845368657726794, 0.10382406282587908, 0.0038543240134458756, 0.0473105265700724, 0.045669719693250954, 0.021411045818240382, 0.026033015383291058, 0.01434458652511239, 0.023231749291880988, 0.01795637064788025, 0.07307456908165477, 0.08933013392379507, 0.1745222305180505, 0.1172045327257365, 0.164239848672878, 0.13979859533719718, 0.09534933749819174, 0.22284652339294553, 0.14363757683895528, 0.12078695377567783, 0.11006266751792282, 0.25240576069336385, 0.1955448993248865, 0.1328724279301241, 0.11261682069743983, 0.1493489820859395, 0.15515766805037856, 0.16923399787629023, 0.3624876053072512, 36.42497085034847, 62.893890738487244, 51.01240709424019, 49.375606924295425, 40.525953993201256, 67.13954731822014, 60.91831974685192, 66.55079931020737, 47.90842965245247, 0.8295023173559457, 2.5518699176609516, 1.314110797829926, 0.0958618349977769, 2.420000131241977, 60.004552379250526, 66.71242743730545, 64.62874084711075, 57.88081593811512, 59.99425873160362, 52.04129308462143, 48.14470857381821, 47.29912854731083, 48.33788260817528, 46.87537528574467, 45.01219466328621, 45.03381930291653, 43.56903210282326, 44.13641765713692, 45.202157869935036, 42.54978619515896, 44.68988075852394, 44.645533338189125, 45.107273161411285, 43.806458562612534, 45.9343595802784, 43.386953473091125, 42.957310527563095, 42.23216123878956, 43.8459612429142, 44.694136530160904, 43.39882783591747, 44.91741254925728, 45.33792458474636, 45.0106443464756, 43.94504092633724, 45.3774880617857, 46.526842787861824, 46.7219053208828, 47.69848711788654, 41.74312748014927, 44.51108895242214, 45.122932121157646, 45.41766710579395, 43.64236056804657, 45.216650292277336, 44.424240812659264, 43.995456621050835, 43.11982020735741, 43.930989280343056, 44.469279795885086, 44.994628205895424, 44.90708850324154, 42.78658948838711, 44.36926916241646, 42.760982662439346, 44.92010660469532, 47.10647128522396, 48.38935844600201, 48.408547416329384, 50.183869153261185, 50.00622868537903, 48.94668973982334, 51.3550841063261, 49.43390339612961, 46.461132913827896, 43.275072276592255, 44.99066881835461, 43.512297347187996, 41.37986697256565, 41.49649031460285, 42.37992011010647, 39.36423473060131, 40.31902849674225, 42.38858364522457, 43.57607692480087, 40.37394694983959, 44.651278629899025, 43.153691589832306, 42.20538027584553, 41.09835147857666, 43.18964906036854, 43.69871914386749, 45.204566940665245, 39.870610758662224, 41.847466081380844, 40.90303435921669, 41.234562769532204, 40.44512093067169, 39.917458444833755, 41.04768119752407, 41.011609733104706, 41.96618691086769, 39.12058040499687, 41.20953731238842, 41.09460487961769, 40.04927717149258, 39.99271720647812, 40.208070650696754, 40.36029428243637, 41.486306861042976, 39.86313655972481, 39.59397040307522, 41.620876640081406, 41.34401969611645, 42.24074877798557, 39.02869753539562, 43.12940329313278, 41.5033071488142, 43.82575012743473, 41.80629529058933, 42.660994827747345, 41.543664783239365, 42.12453581392765, 42.21531294286251, 47.52568759024143, 45.245718732476234, 51.67855314910412, 54.14414964616299, 61.69527165591717, 54.10616688430309, 57.62494906783104, 6.555469036102295, 0.39874285517726094, 0.5276368372142315, 0.2925403352128342, 0.9070842387154698, 53.04478503763676, 62.25900940597057, 62.89960943162441, 50.211695060133934, 45.517457351088524, 38.245700150728226, 60.42657673358917, 23.44269387423992, 0.6217416969593614, 0.2622938988497481, 0.18303381832083687, 0.22234141768421978, 0.18384412484010682, 0.1467630427214317, 0.14253495319280773, 0.1632212509866804, 0.21827922784723341, 0.18148584669688717, 0.10760489705717191, 0.13479741057381034, 0.11134013373521157, 0.15925398183753714], [0.017171757281175815, 0.03882575998432003, 0.014456701846938813, 0.05681736409314908, 0.027736210904549807, 0.024145023235178087, 0.041865107050398365, 0.038440192001871765, 0.016257494426099584, 0.0829084636643529, 0.08970842143753543, 0.07224249537102878, 0.009737683485582238, 0.09386772129801102, 0.028464196548156906, 0.029901615998824127, 0.04105620690097567, 0.0824345949513372, 0.6994728196877986, 29.23173263669014, 52.162935957312584, 43.0566143989563, 24.126362688839436, 45.368695333600044, 56.31100237369537, 49.87852893769741, 39.77954484522343, 0.07719288012594916, 0.44419726298656315, 0.7953066460322589, 0.519475172040984, 0.2927435649326071, 27.998007237911224, 69.17720317840576, 59.10419449210167, 61.484215781092644, 55.005681216716766, 55.004058703780174, 45.83425015211105, 45.859325006604195, 41.88705615699291, 43.52058470249176, 40.58022268116474, 40.36276414990425, 38.809122517704964, 39.27842773497105, 38.878856375813484, 39.35662753880024, 38.9232911914587, 40.070122852921486, 37.81103007495403, 39.69150736927986, 37.89736144244671, 40.315878465771675, 40.00455357134342, 40.140259489417076, 39.06773664057255, 39.75813679397106, 38.949483186006546, 40.11797748506069, 40.97887448966503, 40.921330377459526, 38.79773072898388, 40.79849436879158, 40.340094566345215, 42.25344769656658, 42.43899554014206, 39.190762639045715, 39.443369284272194, 41.48192949593067, 41.336693689227104, 39.7922969609499, 40.62174305319786, 40.60008801519871, 41.828831881284714, 40.16108997166157, 40.568469911813736, 42.37882576882839, 38.707584366202354, 38.700364753603935, 39.08293962478638, 40.08105106651783, 37.395898550748825, 39.638576209545135, 46.51667833328247, 48.167328760027885, 49.9349445104599, 48.06464307010174, 48.347313702106476, 49.58106949925423, 46.70316092669964, 47.00252786278725, 45.91973416507244, 46.01543962955475, 45.608002692461014, 40.0485248118639, 37.7090435475111, 36.8538386374712, 38.1406319886446, 36.600730419158936, 36.2546905875206, 36.68150648474693, 36.215780675411224, 38.451812490820885, 36.871807873249054, 38.55965070426464, 38.52724224328995, 38.36065158247948, 38.96159313619137, 41.64664305746555, 39.45647098124027, 38.277728632092476, 37.143797278404236, 39.57778327167034, 37.95441918075085, 36.85962192714214, 37.21138805150986, 39.53155875205994, 38.59382227063179, 39.83862027525902, 36.69143155217171, 36.69711224734783, 35.43137736618519, 36.61530263721943, 35.65795920789242, 38.0653390288353, 36.269342601299286, 37.73718863725662, 39.99047912657261, 41.96043021976948, 44.20196793973446, 44.674533382058144, 44.119291976094246, 43.653212785720825, 40.89051403105259, 41.96600832045078, 40.00808738172054, 39.011473059654236, 37.89582632482052, 38.033318147063255, 39.31728444993496, 41.68551117181778, 41.14363744854927, 44.3859426677227, 46.965396255254745, 50.272115617990494, 52.544173300266266, 57.95656867325306, 39.85472001135349, 0.4360379133140668, 0.17664619779679924, 0.08095821089227684, 0.07065302284900099, 1.5834881993941963, 46.02720379829407, 51.400001496076584, 49.09687668085098, 31.958215534687042, 22.572873048484325, 30.716014690697193, 42.19906501471996, 2.476575532928109, 0.09433009414351545, 0.07419664441840723, 0.038218653498915955, 0.08359542523976415, 0.050118041544919834, 0.03409826444112696, 0.04793308085936587, 0.028760157620126847, 0.04135824245167896, 0.015250833257596241, 0.005751998405685299, 0.006518280260934262, 0.05748949755798094, 0.058567281521391124, 0.05414166938862763, 0.06059106999600772, 0.0272099818175775, 0.02984614417073317, 0.04641794184863102, 0.01588078768691048, 0.012892594077129615, 0.043131548663950525, 0.10060864864499308, 0.04015816739411093, 0.0031330902902482194, 0.05842363512783777, 0.018792210757965222, 0.05059283794253133, 0.05340692092431709, 0.09696024324512109, 0.12306405580602586, 0.06331860000500455, 4.046960016712546, 40.69383278489113, 53.83067026734352, 42.830568328499794, 32.03956916928291, 53.00659328699112, 59.39761854708195, 56.26029409468174, 42.01984763145447, 0.04524193464021664, 0.5438947398215532, 0.7288937503471971, 0.9045772638637573, 0.604707389138639, 29.803497456014156, 68.58910113573074, 60.245299860835075, 62.766054198145866, 57.420736625790596, 57.63982906937599, 48.179849088191986, 47.41857513785362, 44.0679719299078, 44.194204956293106, 42.28460982441902, 42.02970050275326, 40.927759632468224, 41.69758692383766, 42.16730631887913, 42.41185359656811, 41.05471462011337, 41.72697074711323, 41.988031938672066, 41.45701423287392, 40.88975787162781, 41.31361372768879, 40.80583557486534, 43.360267505049706, 42.2775574028492, 42.370853796601295, 40.62312237918377, 44.24015589058399, 42.15420462191105, 41.78331412374973, 41.143641248345375, 42.78803341090679, 43.08950923383236, 43.638385981321335, 43.91598008573055, 40.94804294407368, 42.45641380548477, 43.6295210570097, 44.07593630254269, 42.651818320155144, 43.6136569082737, 42.04617261886597, 43.1479424983263, 42.136520370841026, 42.43793919682503, 44.39457580447197, 41.139602065086365, 41.032162830233574, 39.611829444766045, 40.25033958256245, 40.01942217350006, 42.1280088275671, 47.23803922533989, 50.43475829064846, 49.162658751010895, 50.110799074172974, 49.806500002741814, 50.51894277334213, 48.338593170046806, 49.23101708292961, 47.951534539461136, 48.68044562637806, 46.73637494444847, 41.958207339048386, 39.9861815571785, 40.753178000450134, 38.64397577941418, 38.94803546369076, 38.00749093294144, 39.08785656094551, 38.0828370898962, 40.06103754043579, 39.020854756236076, 40.9822753071785, 41.04157492518425, 40.295872539281845, 40.051393657922745, 42.034336254000664, 40.81697277724743, 39.55841191112995, 39.51845325529575, 40.6192921847105, 40.92420682311058, 39.42909725010395, 38.738309517502785, 40.98746582865715, 40.74018269777298, 40.39357289671898, 40.12151509523392, 39.04833108186722, 37.882762625813484, 37.91288360953331, 36.95404306054115, 39.88147437572479, 38.78840982913971, 41.15277975797653, 41.76447473466396, 45.2936227619648, 45.18543116748333, 45.18282450735569, 45.61907149851322, 45.00170722603798, 43.02289120852947, 43.76052662730217, 41.65912538766861, 40.04611574113369, 40.33593378961086, 40.18831931054592, 40.50262704491615, 43.673218712210655, 43.72026778757572, 45.610069781541824, 49.32709872722626, 54.35155391693115, 54.225381687283516, 60.00734902918339, 40.72731278836727, 0.5135233257897198, 0.651274899719283, 0.14990191179094836, 0.033480545243946835, 2.0477500185370445, 50.57837538421154, 59.1494994610548, 52.887625470757484, 43.47811438143253, 29.55435622483492, 30.378300212323666, 52.844946160912514, 4.164908537641168, 0.13600271777249873, 0.07855016432586126, 0.01928183155541774, 0.12522171658929437, 0.04960137688613031, 0.052979729589424096, 0.047373056222568266, 0.013176613065297715, 0.0293314591908711, 0.0441024373867549, 0.023242072566063143, 0.034599752179929055, 0.009762974023033166, 0.0327926708268933, 0.13942468649474904, 0.17155883484520018, 0.17466156132286415, 0.15432625485118479, 0.12302092218305916, 0.15214500861475244, 0.11644533791695721, 0.1584718027152121, 0.1765749664627947, 0.18596880458062515, 0.19724858837435022, 0.1446619484340772, 0.11816452300990932, 0.2380187826929614, 0.14269608829636127, 0.272970138466917, 0.24002887483220547, 0.24841547012329102, 5.736547904089093, 54.72484588623047, 60.513470470905304, 51.21606096625328, 35.42260743677616, 57.67275050282478, 65.11429399251938, 58.5464072227478, 51.806860864162445, 0.10591890822979622, 2.4720948608592153, 1.798686208203435, 1.3430449389852583, 0.5601714632939547, 31.93546235561371, 69.06383246183395, 63.69022160768509, 65.9255276620388, 59.277674183249474, 60.20268514752388, 50.26241473853588, 50.87822489440441, 45.71808658540249, 46.68581485748291, 45.19291676580906, 45.06069906055927, 44.42542254924774, 43.64496722817421, 43.653307780623436, 43.86083364486694, 42.555288299918175, 43.43333758413792, 43.145449832081795, 43.79572033882141, 43.01692932844162, 45.987180545926094, 44.342442601919174, 47.1317171305418, 46.87992364168167, 44.47477050125599, 42.903680205345154, 46.85669168829918, 44.895723313093185, 45.059475526213646, 43.194911777973175, 46.47644229233265, 45.4760205745697, 46.63356386125088, 45.61592906713486, 43.84531907737255, 43.317288011312485, 48.26793596148491, 46.8539634346962, 44.46986496448517, 45.886113569140434, 43.89195017516613, 45.21008804440498, 43.635083958506584, 44.58211474120617, 47.645707949995995, 42.455661445856094, 43.535054326057434, 41.32709540426731, 44.45835918188095, 42.96763837337494, 44.18310575187206, 50.49671396613121, 53.07894520461559, 51.824704706668854, 51.75908602774143, 52.112265676259995, 53.50204110145569, 49.60695371031761, 51.66065230965614, 50.89858800172806, 50.43019473552704, 49.399420246481895, 42.585249692201614, 43.047016113996506, 42.97391563653946, 41.290431171655655, 40.862418338656425, 39.91804741322994, 41.85970902442932, 39.85953435301781, 43.48270833492279, 40.64598195254803, 43.30775432288647, 41.93456880748272, 41.07880152761936, 42.271021753549576, 44.19412896037102, 42.27333202958107, 43.21060873568058, 40.357965007424355, 43.74000012874603, 42.72205375134945, 40.895259976387024, 41.96912795305252, 43.74538064002991, 44.30667132139206, 43.303996324539185, 41.47542044520378, 40.652335211634636, 39.85081382095814, 40.39022907614708, 38.788808807730675, 42.63138301670551, 40.303950905799866, 42.490459978580475, 44.419259279966354, 47.65451967716217, 48.74697245657444, 49.27967347204685, 47.66578987240791, 48.26440215110779, 45.65724804997444, 46.923180520534515, 44.7749087959528, 42.68503613770008, 42.68098555505276, 41.76137790083885, 43.810790330171585, 46.16647392511368, 46.85296408832073, 47.66031816601753, 52.56204754114151, 55.84330826997757, 59.22729268670082, 59.41655293107033, 43.902107030153275, 0.9824140090495348, 0.8921616082079709, 0.21589975396636873, 0.4486834863200784, 2.927502323873341, 57.9067837446928, 63.88071298599243, 59.36925686895847, 44.72345195710659, 33.163674250245094, 39.72580812871456, 61.7732472717762, 5.837411116808653, 0.32424049044493586, 0.21452580112963915, 0.1937417476437986, 0.19665954576339573, 0.08780217802268453, 0.2528229961171746, 0.1389469363493845, 0.09023740203701891, 0.15911466587567702, 0.16945291659794748, 0.12267563797649927, 0.1258517405949533, 0.1597232566564344, 0.20173629600321874], [0.04712320107501, 0.04847370204515755, 0.04488819366088137, 0.058876946350210346, 0.0223325928527629, 0.033759051002562046, 0.011362872792233247, 0.012256983554834733, 0.04857699415879324, 0.04776878049597144, 0.023597240324306767, 0.09231702599208802, 0.04535883774224203, 0.026340507574786898, 0.03492163275950588, 0.055043115353328176, 0.03425114686251618, 0.03800007245445158, 0.20774171047378331, 13.634424582123756, 50.29099300503731, 52.65161253511906, 35.14051057398319, 26.36858057230711, 56.58674217760563, 51.044226586818695, 58.24825242161751, 4.275262216106057, 0.6410305306781083, 0.46042482659686357, 0.6275029003154486, 0.2006963244639337, 3.940690881572664, 61.09418570995331, 59.63096022605896, 63.28559271991253, 55.62217153608799, 56.331137493252754, 51.732111275196075, 44.97461847960949, 41.94230519235134, 42.951762825250626, 40.866286531090736, 40.97119130194187, 39.18824337422848, 40.09512171149254, 38.4334746748209, 39.74947705864906, 39.56125795841217, 39.689675867557526, 39.69988971948624, 40.747957080602646, 39.10426028072834, 40.806413143873215, 38.547099977731705, 38.15647713840008, 39.16535720229149, 40.50724759697914, 38.18426884710789, 39.67168763279915, 39.8856845498085, 39.934728518128395, 40.30233979225159, 41.65762446820736, 39.98140141367912, 40.63378840684891, 41.85873247683048, 41.39018341898918, 40.83068624138832, 41.28161184489727, 41.75291955471039, 40.37423953413963, 39.01424691081047, 39.691245183348656, 39.88394424319267, 40.81850029528141, 40.49270957708359, 40.55719971656799, 40.301515236496925, 39.84607547521591, 40.72138510644436, 38.03253158926964, 38.85120525956154, 41.454019993543625, 49.91524636745453, 54.35746259987354, 54.1821476072073, 52.312864512205124, 55.4946693778038, 53.6606901884079, 51.005278676748276, 50.18767274916172, 51.88182704150677, 50.54885096848011, 49.4540461152792, 44.94843788444996, 38.64343620836735, 37.98878453671932, 37.51749962568283, 36.22727885842323, 37.15619221329689, 37.10354603827, 35.9762567281723, 36.497254371643066, 37.19395838677883, 38.23537230491638, 38.04219447076321, 39.20307777822018, 38.172759264707565, 39.89052169024944, 38.152487352490425, 37.66742818057537, 37.6712241768837, 37.633704990148544, 37.278735637664795, 37.50637002289295, 37.57143773138523, 39.85131919384003, 38.10210585594177, 38.59469622373581, 37.55305051803589, 39.01884466409683, 37.48457819223404, 37.459123358130455, 36.222616508603096, 41.08284071087837, 41.89820475876331, 43.09807777404785, 43.529977798461914, 47.36811384558678, 46.40657164156437, 49.66368846595287, 47.39747866988182, 50.42992874979973, 48.513182401657104, 51.057552471756935, 44.70674425363541, 44.78410430252552, 41.83150693774223, 39.34712424874306, 35.54513566195965, 41.56028889119625, 39.706653356552124, 47.18891926109791, 46.49379976093769, 53.9165760576725, 48.34987096488476, 60.35513676702976, 20.22586438804865, 0.03131716621282976, 0.34928402630612254, 0.1372255544993095, 0.10639871412422508, 3.966933935880661, 48.47976319491863, 45.926862582564354, 47.55504481494427, 27.467512004077435, 25.568556301295757, 40.254367366433144, 13.702393434941769, 0.1555102624115534, 0.09049067477462813, 0.037519813849939965, 0.07556694588856772, 0.01774503482010914, 0.039722170477034524, 0.032124511562869884, 0.06473493689554743, 0.013210938323027221, 0.0520987446361687, 0.06136109645012766, 0.03794644115259871, 0.068355548864929, 0.03783726009714883, 0.030574267111660447, 0.04115651929168962, 0.04982266676961444, 0.07524549946538173, 0.0282980538031552, 0.05660087590513285, 0.032254899488179944, 0.016528784653928597, 0.031508540123468265, 0.011023615752492333, 0.02111158551997505, 0.04325969530327711, 0.0789315317524597, 0.037458063452504575, 0.045662238844670355, 0.021266223120619543, 0.050477463664719835, 0.03341014882607851, 0.04637927224393934, 0.07410907099256292, 24.142365530133247, 56.29497483372688, 50.515557155013084, 35.13532005250454, 38.309171944856644, 60.786797404289246, 54.62284415960312, 59.699360355734825, 3.867760207504034, 0.6156312685925514, 0.6681176740676165, 0.7533826644066721, 0.30245818896219134, 5.507341353222728, 61.39277368783951, 59.62457276880741, 64.2635728418827, 58.83575789630413, 60.18833711743355, 53.76763164997101, 46.68596304953098, 44.44989323616028, 44.65927340090275, 42.372423112392426, 42.48041711747646, 40.8506465703249, 42.04923525452614, 41.68219394981861, 40.94724498689175, 40.63084356486797, 41.851205080747604, 41.42480716109276, 42.50371366739273, 42.42175206542015, 43.93289677798748, 40.50924628973007, 41.363672241568565, 41.49986073374748, 41.879460364580154, 40.11790908873081, 43.21717478334904, 41.05474881827831, 39.94270049035549, 41.343829706311226, 44.18203040957451, 41.589285135269165, 43.505127131938934, 43.356699496507645, 44.49438124895096, 43.268084451556206, 44.130592569708824, 43.353921845555305, 42.554114162921906, 41.115693747997284, 42.85856142640114, 42.47917838394642, 43.04635114967823, 43.16643990576267, 42.299748212099075, 41.21582977473736, 43.314305171370506, 42.529468685388565, 41.13223046064377, 40.44605188071728, 42.878221571445465, 51.144617199897766, 55.20387478172779, 55.30174992978573, 54.998708590865135, 54.14328329265118, 56.61554463207722, 51.661571860313416, 50.591294690966606, 51.81063026189804, 51.77886016666889, 50.31590826809406, 45.874512791633606, 39.27243925631046, 39.88248132169247, 38.40436063706875, 39.49725419282913, 38.820339515805244, 38.96935611963272, 36.526246815919876, 38.83671283721924, 39.729619324207306, 39.78508874773979, 40.087453722953796, 41.899295300245285, 40.683736726641655, 42.52888731658459, 40.06240166723728, 38.60476568341255, 39.829595759510994, 39.63930957019329, 38.184078857302666, 38.18423844873905, 39.83324736356735, 41.65340669453144, 42.285514175891876, 40.833194106817245, 39.65155251324177, 41.1815632134676, 40.23239694535732, 39.24870193004608, 38.19067910313606, 44.72936064004898, 42.44368828833103, 45.63293695449829, 45.478399246931076, 48.92874710261822, 48.82910504937172, 51.16772376000881, 49.96552146971226, 52.060687243938446, 50.792740881443024, 52.36980065703392, 47.78369754552841, 46.08899228274822, 41.41023874282837, 40.53011476993561, 38.948521837592125, 43.72344061732292, 41.72449328005314, 49.650020599365234, 48.77259448170662, 58.23776118457317, 51.5187831223011, 62.535037994384766, 21.142576597630978, 0.08517186564859003, 0.5066440918017179, 0.2636414609150961, 0.04325429988966789, 4.878815654665232, 57.33374409377575, 52.17346139252186, 53.308080509305, 39.67791549861431, 22.88843661546707, 43.10812063515186, 20.576082095503807, 0.35361787187866867, 0.036686849562102, 0.02978147898829775, 0.10820238530868664, 0.05382335853937548, 0.00947392791204038, 0.08557554945582524, 0.05434339997009374, 0.06392331677488983, 0.07978797017131001, 0.027350919372111093, 0.026525836692599114, 0.031234290581778623, 0.03700095614476595, 0.04144109210756142, 0.14583329495508224, 0.11980060982750729, 0.1461293821921572, 0.12298215238843113, 0.1343236828688532, 0.11904206068720669, 0.1774085615761578, 0.10846397010027431, 0.15098007424967363, 0.07366306992480531, 0.178928361274302, 0.20413361111423, 0.1088560615608003, 0.1384776021586731, 0.1026494953839574, 0.1623047876637429, 0.1373521945788525, 0.2528239757521078, 0.2216348485671915, 33.2106739282608, 65.80253586173058, 59.89902824163437, 46.430973932147026, 39.68480072915554, 67.048868983984, 60.6962026655674, 69.65501233935356, 7.003461197018623, 0.9026913775596768, 1.086229900829494, 1.2905401876196265, 0.364841430564411, 6.410565236583352, 63.25814299285412, 59.916347712278366, 68.15921500325203, 61.13641284406185, 60.466136410832405, 56.38104781508446, 49.14555586874485, 46.997132152318954, 47.30161361396313, 46.03191554546356, 45.26984743773937, 43.23199398815632, 44.699376448988914, 43.68939444422722, 44.328447952866554, 44.33443263173103, 44.584083035588264, 43.64044547080994, 44.77172076702118, 44.88354116678238, 47.06136390566826, 42.88873180747032, 42.89763852953911, 44.752072021365166, 46.96428671479225, 42.44206577539444, 44.069073870778084, 43.203237131237984, 42.67230302095413, 43.81544128060341, 45.901077166199684, 43.798699378967285, 44.57164250314236, 44.99785043299198, 46.651020124554634, 44.993275478482246, 47.88004517555237, 45.78601934015751, 44.43262696266174, 42.03655153512955, 46.46934427320957, 44.83858957886696, 45.65017282962799, 45.38424029946327, 44.20725345611572, 44.081225618720055, 43.84895548224449, 46.21821194887161, 42.88994014263153, 43.27221862971783, 45.73402673006058, 53.85367423295975, 56.39363653957844, 57.63971507549286, 54.87876042723656, 58.21919918060303, 57.55033627152443, 55.541380271315575, 51.62431865930557, 54.64267909526825, 53.155488297343254, 53.13223734498024, 49.131899401545525, 43.21300260722637, 41.21549539268017, 41.07689782977104, 40.5169864743948, 40.41272006928921, 40.94433434307575, 38.46355386078358, 41.38756535947323, 42.002436965703964, 41.89245946705341, 42.45313838124275, 45.00504344701767, 43.81728038191795, 45.87659887969494, 41.24900959432125, 40.828178375959396, 43.907020166516304, 43.16811181604862, 40.19051939249039, 40.15350557863712, 41.01531833410263, 43.62893208861351, 44.09845009446144, 42.05531872808933, 42.460574582219124, 42.84189932048321, 41.84964336454868, 41.80075518786907, 39.47426162660122, 47.36495241522789, 46.1698367446661, 47.821543514728546, 47.968014255166054, 52.19915561378002, 52.11855813860893, 54.121157079935074, 52.77848772704601, 55.50618276000023, 53.11199203133583, 55.710577592253685, 49.643006175756454, 47.54755161702633, 44.97206501662731, 43.63626189529896, 40.25795817375183, 46.03685908019543, 44.03107970952988, 52.37279869616032, 52.54712954163551, 60.203186720609665, 53.84682700037956, 64.33724328875542, 24.172649905085564, 0.14788969710934907, 0.7618240301962942, 0.5392768001183867, 0.23217279638629407, 5.758923478424549, 64.34089109301567, 56.81536450982094, 60.95756024122238, 42.25900299847126, 35.570335909724236, 54.16581608355045, 29.489258117973804, 0.4466094804229215, 0.10154821502510458, 0.09567275061272085, 0.18020130781223997, 0.15989248116966337, 0.0963253433292266, 0.2128835322218947, 0.16284910845570266, 0.09885548060992733, 0.13800210814224556, 0.15037387318443507, 0.08452002992271446, 0.360862331581302, 0.16811523993965238, 0.08246357581811026], [0.03904556928318925, 0.015002959644334624, 0.04489622369874269, 0.014304429842013633, 0.05119135035783984, 0.03222526553145144, 0.029871087754145265, 0.03755986756004859, 0.06125971907749772, 0.08640890708193183, 0.008962466636148747, 0.04569180600810796, 0.0044515701392811025, 0.047073332461877726, 0.020530346591840498, 0.04116600764973555, 0.09690841907286085, 0.011566329794732155, 0.07962128380313516, 4.55464887432754, 49.5156180113554, 49.431380331516266, 40.33154122531414, 36.794048845767975, 52.808099538087845, 47.92069539427757, 59.29094307124615, 14.733320865780115, 0.6507644802331924, 0.9312000602949411, 0.3664804488653317, 0.07883428072091192, 0.13760148198343813, 32.46946670114994, 67.79900193214417, 58.99946451187134, 61.42975710332394, 55.40150597691536, 52.45688818395138, 47.76362702250481, 44.424233213067055, 41.12947180867195, 42.54357352852821, 39.18907552957535, 39.87851433455944, 40.92677168548107, 39.64617200195789, 40.44974148273468, 39.771249890327454, 41.06995180249214, 40.0981767475605, 40.62344156205654, 42.20504969358444, 39.563252851367, 38.80135953426361, 39.455015659332275, 40.15135869383812, 38.79420451819897, 38.51686120033264, 39.060349836945534, 39.58037473261356, 42.12515518069267, 40.09763717651367, 39.267757907509804, 41.48930869996548, 41.14043042063713, 42.82210238277912, 41.23693764209747, 42.21958011388779, 41.34798288345337, 40.361799001693726, 40.878119096159935, 39.6883687376976, 42.61440172791481, 39.75913994014263, 40.12118451297283, 40.58923579752445, 41.4290477335453, 40.70241652429104, 40.72634004056454, 40.02722695469856, 40.81966683268547, 40.053004771471024, 40.963629707694054, 48.0311668664217, 54.92129534482956, 53.461493477225304, 53.24052773416042, 56.87527969479561, 53.808696046471596, 52.25800305604935, 53.13009425997734, 54.14435863494873, 55.40529437363148, 51.72917403280735, 46.7809047549963, 40.853610411286354, 40.50228886306286, 37.89833799004555, 38.171284943819046, 37.65661396086216, 38.3353715389967, 37.31283500790596, 37.83953234553337, 38.41224901378155, 36.470002233982086, 38.81423704326153, 37.86778382956982, 37.97722175717354, 36.86624117195606, 38.936772868037224, 38.94248016178608, 37.412936836481094, 40.10118618607521, 37.12150387465954, 36.94228649139404, 36.72021120786667, 37.848549261689186, 37.827942967414856, 37.2675908356905, 36.349468901753426, 37.01735906302929, 36.03640370070934, 37.07081839442253, 37.42026664316654, 40.37142388522625, 43.13009485602379, 46.10632695257664, 47.36761227250099, 49.94346745312214, 49.38631474971771, 48.430210053920746, 48.98371495306492, 49.756551682949066, 48.86839494109154, 48.83792817592621, 48.24707508087158, 48.93998309969902, 44.30871181190014, 42.7181551605463, 39.40458856523037, 43.19121077656746, 40.71667715907097, 49.46154311299324, 48.102105259895325, 54.18995998799801, 50.4528833180666, 55.968914330005646, 7.514573195949197, 0.13523708854336292, 0.9564538020640612, 0.38394781469833106, 0.3119586588582024, 11.016331817954779, 53.166112527251244, 49.741800874471664, 37.729893028736115, 20.401350371539593, 35.5662777274847, 32.21494495868683, 2.4577252194285393, 0.0961132301017642, 0.013505984697985696, 0.020835300638282206, 0.03270107496064156, 0.020938960115017835, 0.0408329763013171, 0.05864367449248675, 0.029215810318419244, 0.03026842990948353, 0.010931504093605326, 0.028885322681162506, 0.017523616916150786, 0.009636191080062417, 0.08803934615571052, 0.07363711702055298, 0.056608623926877044, 0.06472491048043594, 0.043295296127325855, 0.06112079645390622, 0.07757746847346425, 0.004063659289386123, 0.056142317698686384, 0.0111426265539194, 0.10396248821052723, 0.039157358987722546, 0.01996030296140816, 0.03901159747329075, 0.07225338267744519, 0.04221235423756298, 0.02631061572174076, 0.04215033295622561, 0.1297709037316963, 0.14105126640060917, 0.17093914153520018, 9.75502559915185, 57.52911441028118, 49.589231461286545, 41.13951846957207, 41.06126926839352, 60.78970804810524, 53.80679614841938, 66.98830023407936, 15.112435072660446, 0.7044398062862456, 1.274944399483502, 0.7197608216665685, 0.058132798585575074, 0.21520304057048634, 36.79618053138256, 69.10449028015137, 60.384585186839104, 63.121399730443954, 57.31098331511021, 55.873763635754585, 50.14972798526287, 45.37822522222996, 42.79690973460674, 44.38321441411972, 42.55360499024391, 41.76117271184921, 42.14182108640671, 41.226845383644104, 41.77664928138256, 42.51647338271141, 42.870963960886, 42.90348261594772, 42.103298753499985, 43.91237787902355, 41.93562515079975, 41.17250069975853, 41.49197235703468, 41.41272760927677, 41.376200169324875, 40.47375239431858, 41.93481579422951, 42.67606861889362, 42.88342349231243, 42.86197364330292, 43.02207425236702, 43.380144238471985, 42.72388905286789, 43.07382367551327, 42.08477094769478, 44.975154250860214, 42.95653536915779, 43.51456582546234, 41.21182858943939, 41.3574405759573, 42.879654094576836, 43.02194885909557, 41.38284981250763, 42.4389461427927, 42.17987224459648, 42.77173608541489, 43.30026112496853, 42.06347309052944, 42.173461988568306, 39.71635043621063, 42.5267518311739, 49.19054925441742, 54.873372316360474, 54.93971295654774, 55.569730550050735, 58.22834528982639, 57.06959366798401, 53.77973020076752, 54.44622963666916, 55.43057441711426, 56.61337494850159, 51.331665962934494, 47.91738197207451, 43.2161146402359, 41.567109525203705, 41.23677425086498, 39.05017018318176, 38.51162128150463, 40.10493278503418, 38.41531924903393, 41.090698689222336, 39.30256024003029, 39.36718337237835, 40.16877695918083, 39.021436125040054, 39.04761292040348, 38.64175669848919, 40.184249728918076, 39.968858286738396, 39.687669575214386, 41.1599575728178, 39.05321381986141, 39.47109639644623, 38.11976730823517, 39.58171226084232, 40.6879772990942, 38.59506480395794, 39.02916111052036, 39.69755284488201, 37.84351073205471, 38.24604973196983, 40.96589058637619, 42.76167802512646, 45.71794219315052, 48.36008861660957, 50.48119179904461, 51.03353776037693, 51.8188264220953, 50.73993131518364, 51.37485824525356, 50.83820164203644, 52.42118529975414, 50.94216026365757, 49.95640575885773, 49.42542605102062, 45.966642647981644, 45.82283556461334, 41.76764376461506, 45.18614932894707, 44.40033249557018, 52.71097294986248, 50.7366406917572, 56.604806408286095, 51.64825737476349, 58.913581520318985, 8.37969509884715, 0.12610834557563066, 1.7066530091688037, 0.5300524982158095, 0.24263972067274153, 12.878000121563673, 61.76872931420803, 51.939279958605766, 47.73754142224789, 29.997558742761612, 32.633754685521126, 43.959784135222435, 4.535277988761663, 0.13613792223623022, 0.01536079820652958, 0.061564174029626884, 0.08248550628195517, 0.02539022458222462, 0.015520308006671257, 0.0459996748395497, 0.019822703216050286, 0.06694459996651858, 0.04463869103346951, 0.025678558231447823, 0.018980886961799115, 0.020555633418553043, 0.057342062500538304, 0.004278579226593138, 0.22889297863002867, 0.1291081213275902, 0.1746091211680323, 0.12757711519952863, 0.23142447404097766, 0.0761230371426791, 0.11785074297222309, 0.07735256804153323, 0.13535553531255573, 0.10631151177221909, 0.18158403283450752, 0.1036302286956925, 0.11794501799158752, 0.13428262725938112, 0.1101562226540409, 0.22899820032762364, 0.2349966682959348, 0.16668408236000687, 0.269141131429933, 11.867867074906826, 69.18145135045052, 55.545856431126595, 49.992154240608215, 51.1855486035347, 66.3241794705391, 58.330871388316154, 70.37619084119797, 20.556604340672493, 0.7561784237623215, 2.9619586374610662, 1.8404294620268047, 0.27572421880904585, 0.19513235427439213, 36.58602520823479, 70.57849958539009, 62.71457076072693, 65.93210890889168, 59.76674973964691, 58.78276214003563, 53.59873831272125, 48.7671759724617, 45.975743159651756, 47.915835455060005, 45.47703891992569, 44.829101487994194, 44.92498554289341, 43.30060310661793, 46.18645325303078, 43.942411467432976, 46.29727430641651, 45.24947293102741, 44.46271754801273, 47.628806456923485, 44.01247210800648, 43.49613681435585, 43.21493290364742, 45.30515894293785, 42.38727271556854, 42.562868893146515, 43.41089978814125, 44.54493373632431, 46.58029451966286, 46.38263672590256, 43.70405785739422, 46.065703332424164, 45.14657825231552, 46.8133208155632, 45.21199554204941, 46.688493713736534, 46.481480821967125, 45.43470539152622, 42.856311947107315, 43.69069017469883, 46.45489364862442, 44.0246656537056, 44.03807893395424, 43.540757820010185, 46.44360065460205, 46.01510524749756, 46.037174463272095, 44.99227613210678, 45.68916633725166, 42.232886999845505, 44.99010644853115, 52.112265676259995, 58.477858901023865, 57.331297025084496, 57.51322366297245, 61.82223044335842, 58.35019715130329, 57.5739786028862, 57.58364908397198, 58.35607923567295, 58.94650675356388, 55.16277998685837, 50.920820608735085, 45.479668378829956, 43.39076466858387, 42.99400895833969, 41.88801370561123, 39.85180176794529, 42.303794994950294, 40.14107644557953, 42.23384074866772, 42.22512401640415, 39.72340285778046, 42.301146537065506, 42.308597937226295, 39.34891015291214, 40.45092701911926, 43.50472815334797, 41.9265778362751, 41.73815354704857, 43.90613481402397, 40.922804698348045, 42.62669026851654, 41.57230764627457, 42.40478217601776, 42.58594885468483, 41.60914666950703, 42.152186930179596, 41.92071855068207, 39.52153109014034, 40.88804416358471, 43.04004728794098, 44.71395626664162, 48.233236223459244, 50.580780655145645, 52.87114195525646, 54.92086596786976, 54.576414451003075, 52.134809866547585, 53.66521194577217, 55.137317553162575, 54.879083409905434, 53.32896798849106, 51.2541539222002, 53.677572682499886, 47.357007041573524, 48.637899309396744, 44.376408979296684, 48.956124633550644, 45.57644918560982, 55.06408028304577, 53.17854166030884, 60.36977358162403, 53.16213794052601, 60.6993792951107, 9.678343813866377, 0.25527122255880386, 2.478895070962608, 1.362405731342733, 0.4656580957816914, 16.622789427638054, 68.01311284303665, 56.2197008728981, 50.29785543680191, 32.96825833618641, 45.14962948858738, 53.46471190452576, 7.502215309068561, 0.3525863162940368, 0.14160185091895983, 0.24239283782662824, 0.1735478054615669, 0.11927386309253052, 0.17591562762390822, 0.1944457192439586, 0.11893438248080201, 0.1214784498733934, 0.10284327756380662, 0.17179884540382773, 0.10874567451537587, 0.07618053132318892, 0.12261777272215113, 0.23994186543859541], [0.05936235545959789, 0.0310579266079003, 0.031537402246613055, 0.022860853569000028, 0.056766371126286685, 0.04687208798713982, 0.025263170755351894, 0.0703687134955544, 0.04006909111922141, 0.04171445107203908, 0.03578863193979487, 0.017956856754608452, 0.06204979094036389, 0.051137229238520376, 0.06661362436716445, 0.023185932805063203, 0.010015869193011895, 0.07866210245992988, 0.11796667386079207, 0.36613668606150895, 22.097362764179707, 54.632298052310944, 47.53453351557255, 45.34705549478531, 36.99922263622284, 48.4684132039547, 61.45647346973419, 27.432912960648537, 0.2189095041831024, 1.2308920570649207, 0.4400150530273095, 0.22064615943236277, 0.5229968705680221, 7.8744803834706545, 67.26664289832115, 60.09751819074154, 59.22033526003361, 53.178891241550446, 54.36601594090462, 46.61659017205238, 45.27435779571533, 43.75003919005394, 44.09453630447388, 43.461866453289986, 42.53594733774662, 40.191359147429466, 40.908912643790245, 40.62054231762886, 40.80876141786575, 41.406522542238235, 41.15016929805279, 39.279643669724464, 41.34552821516991, 41.87673211097717, 40.71762330830097, 40.5062672495842, 40.453647673130035, 40.91644763946533, 40.20130321383476, 41.214944422245026, 41.65694050490856, 40.74313893914223, 40.43424591422081, 43.376378640532494, 41.55965432524681, 40.23967355489731, 42.42992542684078, 41.02281533181667, 42.048159912228584, 41.11593693494797, 39.43468675017357, 40.80552019178867, 39.14704978466034, 40.870109125971794, 41.40453524887562, 40.669612884521484, 41.0218121856451, 41.160481944680214, 40.97776874899864, 42.075944021344185, 39.12896275520325, 39.36982803046703, 41.56565420329571, 39.30791795253754, 45.63346892595291, 49.2332361638546, 49.87222507596016, 54.55284431576729, 56.27084992825985, 58.32425594329834, 55.032108798623085, 55.29480390250683, 56.97244428098202, 51.941559836268425, 51.34635977447033, 46.0959193110466, 41.656214743852615, 38.51312220096588, 38.27881917357445, 38.30460838973522, 39.093210473656654, 40.652282014489174, 39.700395092368126, 39.591378942131996, 37.390932217240334, 39.16146621108055, 40.00543512403965, 37.76510573923588, 38.548608496785164, 37.74380028247833, 39.61340256035328, 38.29011216759682, 36.59506492316723, 39.96777534484863, 38.52341964840889, 37.677216455340385, 37.86709226667881, 37.47469112277031, 37.74550259113312, 36.27692699432373, 37.591679245233536, 36.199703738093376, 37.486212104558945, 35.86981683969498, 37.406378388404846, 41.30775824189186, 43.509158715605736, 45.74735641479492, 47.139008939266205, 47.05383650958538, 50.827205032110214, 51.992625296115875, 51.46404325962067, 52.756289318203926, 53.14227260649204, 51.54162749648094, 49.889654740691185, 49.69808042049408, 47.29270689189434, 46.079090014100075, 43.11588741838932, 42.63511821627617, 47.8426855802536, 51.01981669664383, 52.98840746283531, 51.48938789963722, 56.116483211517334, 37.99823082983494, 1.439401712268591, 0.1272590455482714, 0.5731572664808482, 0.5518886796198785, 0.16717578488169238, 23.824018612504005, 56.157688200473785, 38.508247062563896, 31.202949061989784, 20.160876475274563, 37.150484919548035, 22.227598875761032, 0.1741390151437372, 0.048632918696966954, 0.060230979943298735, 0.011001948751072632, 0.043688983205356635, 0.06864719805889763, 0.030447456338151824, 0.03800664788286667, 0.06432406167732552, 0.0685625709593296, 0.027245026030868758, 0.02887873983127065, 0.00406653047321015, 0.10501520984689705, 0.004929307760903612, 0.03274273170973174, 0.03253625509387348, 0.009744686576595996, 0.01200800228616572, 0.08527572921593674, 0.04384804400615394, 0.015678444833611138, 0.04031074553495273, 0.1143062234041281, 0.030462373506452423, 0.05214468728809152, 0.08254093729192391, 0.07901773962657899, 0.04043545603053644, 0.019004056812264025, 0.01989283802686259, 0.03679710302094463, 0.021708533859055024, 0.08836690787575208, 0.021600441905320622, 0.6773804489057511, 33.75318221747875, 57.61930637061596, 46.83791309595108, 54.651156440377235, 50.01456543803215, 51.68437063694, 68.08268710970879, 29.002000764012337, 0.1965281114098616, 2.1873246040195227, 0.8701968868263066, 0.2878009504638612, 0.5990410025697201, 9.32752763852477, 69.12487238645554, 60.42353689670563, 62.798569053411484, 56.57851181924343, 57.43071109056473, 49.958583042025566, 48.04138831794262, 45.276975855231285, 46.14173345267773, 46.22217893600464, 45.17718940973282, 42.90966108441353, 43.107402473688126, 42.65764340758324, 42.23513647913933, 43.05536426603794, 43.350148648023605, 42.20378816127777, 42.65930011868477, 44.63840112090111, 42.812450900673866, 43.12572129070759, 42.780190631747246, 42.25236475467682, 42.252060770988464, 42.52609446644783, 43.4708833694458, 43.04160140454769, 41.40751048922539, 44.647212848067284, 43.24110969901085, 43.26616555452347, 43.96848566830158, 42.671440467238426, 44.82448473572731, 42.35664635896683, 43.36399510502815, 41.3309445977211, 41.886045411229134, 41.870781630277634, 43.329378962516785, 42.58794754743576, 42.780156433582306, 43.388317599892616, 44.121461659669876, 43.54060962796211, 42.170133367180824, 42.5210939347744, 42.15514697134495, 40.267412066459656, 46.33323177695274, 50.82598149776459, 51.194523721933365, 54.75006893277168, 57.01586455106735, 57.479477673769, 55.759382173419, 58.37573558092117, 59.48458068072796, 54.54377040266991, 54.462861344218254, 47.52279594540596, 43.751680701971054, 41.000263541936874, 40.89480020105839, 39.91416022181511, 39.83128286898136, 40.5852460116148, 40.64980074763298, 39.21943970024586, 39.41903159022331, 40.85893012583256, 42.39466331899166, 39.56646367907524, 40.22573210299015, 40.58329291641712, 41.02725729346275, 39.550113156437874, 38.31172160804272, 40.93037009239197, 39.832392409443855, 39.544599652290344, 38.92462112009525, 39.19793665409088, 39.9071229994297, 39.886235520243645, 41.83249868452549, 38.36090236902237, 39.67951521277428, 37.64574654400349, 40.6002514064312, 43.072911724448204, 46.303460374474525, 47.160720974206924, 50.76806880533695, 49.33187887072563, 53.18462513387203, 52.89134167134762, 53.05037833750248, 53.79099279642105, 55.19907183945179, 53.0257822573185, 52.36274063587189, 51.68604634702206, 50.87938763201237, 48.301693350076675, 45.443600714206696, 44.13030378520489, 50.28726540505886, 52.809197679162025, 55.622646510601044, 54.24341931939125, 56.89930960536003, 40.337487906217575, 1.7813854990527034, 0.29986251262016594, 2.105710683390498, 0.3388697054469958, 0.06288856253377162, 26.268632635474205, 64.9861952662468, 44.36603553593159, 43.75546529889107, 19.878352135419846, 38.74043360352516, 29.708335362374783, 0.49407338665332645, 0.10453412745846435, 0.07315593815292232, 0.05982299167953897, 0.05311938322847709, 0.05590398439380806, 0.024643160177220125, 0.05525472392037045, 0.016921417882258538, 0.07291779780643992, 0.07595004994072951, 0.034923940838780254, 0.012324310264375526, 0.028542480140458792, 0.06820140479248948, 0.014065986142668407, 0.12551639374578372, 0.09148343830020167, 0.09705983946332708, 0.1663398594246246, 0.09490753698628396, 0.15287430229363963, 0.11722342780558392, 0.22345357050653547, 0.15765144751640037, 0.16076226340373978, 0.15169344143941998, 0.11474215352791362, 0.13719799113459885, 0.18537983618443832, 0.18661120760953054, 0.11996905508567579, 0.11767670192057267, 0.17882297630421817, 0.4639001260511577, 0.6416219333186746, 38.666827753186226, 69.26500126719475, 54.86504316329956, 58.28701414167881, 48.712873086333275, 57.090830728411674, 74.42270770668983, 34.15116526186466, 0.45928990468382835, 3.8769849250093102, 1.5394492750056088, 0.7537726778537035, 0.6624815077520907, 11.294845473021269, 69.16757449507713, 64.2051699757576, 64.89193752408028, 58.5900554805994, 60.43890707194805, 52.83437132835388, 51.110316440463066, 48.25742952525616, 49.90024857223034, 49.108557254076004, 47.5878294557333, 45.84876537322998, 45.9469673037529, 43.97524930536747, 45.12046605348587, 45.02934314310551, 46.1025233566761, 43.93190883100033, 44.25131969153881, 47.57524073123932, 46.09207771718502, 46.22195474803448, 44.91260580718517, 44.222433641552925, 43.788477927446365, 44.2192380130291, 46.10949598252773, 45.5890417098999, 43.67517560720444, 48.112482503056526, 45.688892751932144, 45.63519023358822, 47.57354222238064, 45.13306237757206, 46.944482177495956, 44.18638877570629, 45.14383099973202, 43.933732733130455, 43.54338347911835, 43.84480610489845, 46.991823837161064, 46.521663665771484, 45.71505434811115, 45.64227305352688, 45.631781816482544, 47.625531032681465, 43.62277261912823, 44.01959292590618, 45.204095765948296, 42.17703379690647, 48.137443363666534, 51.63029193878174, 52.90397219359875, 57.797915786504745, 57.89236731827259, 59.91223633289337, 57.0526921749115, 59.1563580930233, 61.854277923703194, 56.05621084570885, 55.33950850367546, 49.91662949323654, 46.17743633687496, 41.77003003656864, 42.63064205646515, 40.87434209883213, 43.039720505476, 43.668142184615135, 43.41743163764477, 41.274240240454674, 40.484201833605766, 43.31281565129757, 46.317797005176544, 41.61625228822231, 43.114527091383934, 42.08948269486427, 44.107516407966614, 42.57834166288376, 39.548262655735016, 43.63463558256626, 42.04866148531437, 39.94366943836212, 40.397178903222084, 40.68723253905773, 41.73196367919445, 41.65401466190815, 44.524023458361626, 40.451348796486855, 42.804748713970184, 40.03711402416229, 42.29405991733074, 44.41558487713337, 48.1690576672554, 50.248363092541695, 52.75417663156986, 52.40405581891537, 54.95083495974541, 54.62366871535778, 54.539514631032944, 58.060204312205315, 57.50425234436989, 54.82669562101364, 54.52199377119541, 54.751083478331566, 53.8235342502594, 51.65181018412113, 46.97268046438694, 47.79352381825447, 52.11666204035282, 56.99959382414818, 58.3267068117857, 57.535600662231445, 58.91532562673092, 42.91677050292492, 2.2748187091201544, 0.30265666893683374, 2.088850988075137, 1.8793830717913806, 0.31299241119995713, 32.486166805028915, 68.88124465942383, 48.73399615287781, 44.486025497317314, 27.914886698126793, 50.905891209840775, 39.746957793831825, 0.6909800379071385, 0.18163207947509363, 0.17167290294310078, 0.14487887819996104, 0.13677294831722975, 0.14438119396800175, 0.12693935801507905, 0.10086659691296518, 0.1930669869761914, 0.21785216638818383, 0.1398276281543076, 0.08619805550551973, 0.16620284412056208, 0.15171018429100513, 0.14526319195283577, 0.11581044542253949], [0.010503133671591058, 0.027880432462552562, 0.06234531043446623, 0.027415816475695465, 0.046123045758577064, 0.04277274252672214, 0.051583842578111216, 0.016509409033460543, 0.0031887089244264644, 0.040401135411229916, 0.04193954817310441, 0.044191632405272685, 0.11376827023923397, 0.015530865057371557, 0.0482109632139327, 0.04958653764333576, 0.023815368658688385, 0.02415601073153084, 0.24190998170524836, 0.11069842090364546, 3.449242115020752, 47.62550063431263, 44.11143019795418, 34.504576697945595, 32.33550488948822, 45.334413573145866, 59.44811023771763, 39.02629606425762, 0.6519224087242037, 0.5517941596917808, 0.5323371256235987, 0.07622753153555095, 0.057358360063517466, 0.1849532051710412, 32.91665330529213, 69.00707110762596, 59.095367565751076, 58.848118633031845, 53.360377103090286, 50.44737361371517, 47.6266747713089, 45.46144835650921, 43.69545891880989, 46.983574479818344, 45.20672142505646, 45.52481755614281, 42.210232615470886, 42.19363510608673, 39.314244613051414, 41.071490719914436, 40.19729442894459, 40.82622528076172, 41.63522087037563, 41.8578927218914, 41.263042241334915, 41.41862489283085, 38.11904534697533, 40.02170205116272, 40.87634839117527, 42.64535866677761, 41.10655143857002, 43.08351695537567, 42.16488964855671, 41.23294025659561, 42.87312984466553, 41.65610074996948, 41.739616468548775, 41.95945747196674, 42.47610054910183, 40.55364690721035, 40.023199170827866, 40.83265833556652, 41.09908103942871, 41.17866776883602, 41.808457374572754, 40.373650565743446, 40.7741566747427, 41.60139508545399, 43.29504020512104, 41.04262746870518, 42.41329371929169, 40.761830136179924, 39.70983758568764, 41.54699720442295, 42.87997327744961, 47.51233130693436, 50.29807962477207, 54.570859149098396, 57.00130753219128, 56.395460441708565, 57.204547226428986, 56.214498952031136, 55.636006593704224, 49.95633736252785, 48.286258578300476, 43.89997534453869, 41.22534826397896, 40.73066420853138, 40.71845926344395, 39.87558849155903, 40.35567373037338, 40.390730649232864, 38.60684037208557, 39.746023043990135, 39.23936203122139, 39.89289276301861, 39.347903206944466, 39.0696707367897, 40.38196071982384, 36.30813091993332, 39.073257744312286, 38.34298253059387, 39.20020513236523, 37.66584746539593, 37.516010105609894, 37.3544579744339, 39.13335531949997, 37.801735773682594, 39.26536783576012, 38.017985969781876, 38.93300347030163, 37.031923681497574, 35.65826699137688, 37.4969769269228, 37.13478036224842, 39.784568175673485, 45.7879838347435, 43.89528639614582, 46.081225499510765, 49.17733736336231, 49.836009219288826, 47.67257630825043, 50.093479603528976, 47.51686066389084, 51.188075467944145, 49.39025893807411, 53.83841425180435, 48.756650537252426, 52.642531022429466, 47.262380719184875, 50.31607165932655, 47.93777547776699, 51.74394004046917, 50.21736055612564, 53.96956041455269, 48.98848369717598, 56.69058680534363, 16.47765811532736, 0.2298228451400064, 0.2697253500809893, 1.602947786450386, 1.0072303586639464, 2.0707782078534365, 46.12674705684185, 56.67562700808048, 35.41018970310688, 19.232992865145206, 26.38579934835434, 37.704297602176666, 5.983517551794648, 0.035712071985471994, 0.07080531897372566, 0.021891989053983707, 0.04798098649189342, 0.07416006395942532, 0.012344541210040916, 0.01815013984014513, 0.06252243139897473, 0.016440752951893955, 0.056376402208115906, 0.05193943150516134, 0.05490815579832997, 0.022704332768626045, 0.011391050284146331, 0.04207186197163537, 0.046604410163126886, 0.050763197941705585, 0.03974703613494057, 0.0070555599268118385, 0.061779344905517064, 0.05065066237875726, 0.013117721791786607, 0.04843041628191713, 0.06975483120186254, 0.03793269657762721, 0.016548577732464764, 0.029048251926724333, 0.026332830057071988, 0.13122500851750374, 0.02984889011713676, 0.011575643748074071, 0.0824183716031257, 0.054639954760205, 0.07111296887160279, 0.22442928689997643, 0.1980367788928561, 7.072321102023125, 56.97442017495632, 48.94950918853283, 40.03684043884277, 45.06250396370888, 52.5946269929409, 65.21862879395485, 42.39839091897011, 0.8283688500523567, 1.2178015219978988, 0.9940076619386673, 0.3173360234359279, 0.0517380608653184, 0.20218338060658425, 36.58134385943413, 70.39871603250504, 58.846678510308266, 60.12241445481777, 56.113732159137726, 53.09638626873493, 50.20990155637264, 47.256232649087906, 46.274509727954865, 49.40398760139942, 47.2355617582798, 48.26056815683842, 43.50697763264179, 42.63121582567692, 43.079147189855576, 44.073542430996895, 42.43151754140854, 43.604282811284065, 43.536608442664146, 43.30704376101494, 42.59985990822315, 44.64181713759899, 39.495593681931496, 42.912161350250244, 42.27606788277626, 44.113793671131134, 43.122776448726654, 43.74268278479576, 44.243081733584404, 43.47108095884323, 44.59684655070305, 42.74417616426945, 44.74871300160885, 44.05189499258995, 44.002531841397285, 43.44862796366215, 42.36075393855572, 42.69334249198437, 42.09447182714939, 44.57589067518711, 43.6709426343441, 42.410934045910835, 41.66822969913483, 45.00274837017059, 43.2211721688509, 43.48962776362896, 43.27857568860054, 41.72338753938675, 41.608322113752365, 43.50808337330818, 43.94124872982502, 48.20622347295284, 52.82084785401821, 58.26219007372856, 60.00354163348675, 56.16722568869591, 57.02659137547016, 58.370670452713966, 57.640551030635834, 51.93744085729122, 50.77343791723251, 46.683983355760574, 43.706694915890694, 42.98095665872097, 42.60794207453728, 40.824241787195206, 41.13206326961517, 41.32848612964153, 41.185598596930504, 40.419517904520035, 40.88685862720013, 40.037767589092255, 40.73018543422222, 39.408202171325684, 42.222133576869965, 39.24171790480614, 39.33483190834522, 40.359834507107735, 42.192430570721626, 39.65318642556667, 39.47437942028046, 38.93927313387394, 40.26697129011154, 38.8390839099884, 41.37174300849438, 39.54990416765213, 39.6749060600996, 39.780331403017044, 37.80766725540161, 39.0881073474884, 40.369611382484436, 42.23681218922138, 46.94155253469944, 46.86157062649727, 50.72816714644432, 52.09348328411579, 52.747644782066345, 50.835154205560684, 53.287504613399506, 49.501893147826195, 51.82297959923744, 51.59059166908264, 55.62956973910332, 51.27632573246956, 52.689675092697144, 49.76914420723915, 51.35620504617691, 49.08403716981411, 54.908231645822525, 50.812165439128876, 56.29280894994736, 52.52326302230358, 60.038294568657875, 18.58224358409643, 0.13407329708570614, 0.47162241011392325, 4.200816610828042, 0.5986969429068267, 2.3415552405640483, 52.276755049824715, 60.0973130017519, 42.63115502893925, 29.25777453929186, 22.83424772322178, 46.90319739282131, 9.998387340456247, 0.06512972977361642, 0.10529827239224687, 0.05154143254912924, 0.10984581938828342, 0.02410146287729731, 0.042121682345168665, 0.02731927605054807, 0.058839523553615436, 0.03638256159320008, 0.014917841799615417, 0.016057287102739792, 0.12591679726028815, 0.05371687890146859, 0.06668052898021415, 0.046454730108962394, 0.033102176093962044, 0.1811285619623959, 0.257326407590881, 0.16544220212381333, 0.11973070693784393, 0.13352207432035357, 0.2084362567984499, 0.18483719264622778, 0.26386128505691886, 0.1283486222382635, 0.18888857681304216, 0.18880934512708336, 0.15853862569201738, 0.19281520595541224, 0.08409705027588643, 0.16383799054892734, 0.17756957793608308, 0.19504473631968722, 0.24521135143004358, 0.35197502409573644, 0.34402543504256755, 10.67204749211669, 65.95714196562767, 56.740812510252, 43.439732640981674, 43.23210038244724, 56.7237514257431, 69.05570849776268, 49.58294279873371, 2.569210287183523, 1.8304282799363136, 2.1623758552595973, 0.6352598872035742, 0.13255824713269249, 0.31145649205427617, 37.86616511642933, 72.35371872782707, 62.61672221124172, 63.23877923190594, 58.80761660635471, 55.579822808504105, 53.55091407895088, 51.64907433092594, 48.278077617287636, 51.65841042995453, 51.04344762861729, 51.86104975640774, 46.56197190284729, 47.484425604343414, 45.47720991075039, 45.90026780962944, 44.82245944440365, 45.89480370283127, 45.82394130527973, 44.607030004262924, 46.286695674061775, 47.16567970812321, 41.28888465464115, 43.89905959367752, 44.30155299603939, 47.682805359363556, 43.447940200567245, 46.59849174320698, 46.54605075716972, 46.44872657954693, 46.69711925089359, 45.680669993162155, 46.58235400915146, 45.96905551850796, 46.387660056352615, 45.43540455400944, 44.317694529891014, 45.687718614935875, 44.003295600414276, 45.66205859184265, 44.7168593108654, 42.62534134089947, 43.1100395321846, 48.18421505391598, 47.57995627820492, 45.304630771279335, 48.68340186774731, 46.165417581796646, 43.060015216469765, 46.21969386935234, 44.905652180314064, 50.58587238192558, 55.21965533494949, 60.22174492478371, 62.1305762976408, 57.4407197535038, 60.46708256006241, 59.860144928097725, 59.92278076708317, 52.90508173406124, 53.52506786584854, 48.45215767621994, 46.362087428569794, 45.44361971318722, 44.948099702596664, 43.43136928975582, 42.8795401006937, 45.323367565870285, 42.696959897875786, 43.69450516998768, 43.43862310051918, 43.9153341203928, 42.80522368848324, 42.59459339082241, 44.0846112370491, 40.39361089468002, 41.756251975893974, 41.37135162949562, 43.768445402383804, 43.82012262940407, 39.70441907644272, 41.62834323942661, 42.72178776562214, 41.78449206054211, 43.52290257811546, 40.744947642087936, 42.98746570944786, 42.58106231689453, 40.74591279029846, 42.16601438820362, 42.974538803100586, 43.681243881583214, 50.01862742006779, 48.91645856201649, 52.45055012404919, 55.06262496113777, 54.59233179688454, 52.93529391288757, 55.23850232362747, 51.821155697107315, 55.389487221837044, 52.574218288064, 58.405073806643486, 53.50931391119957, 57.89568454027176, 51.264033392071724, 55.18692009150982, 52.38681234419346, 59.036318734288216, 53.28144393861294, 60.56171268224716, 54.65494863688946, 61.43539600074291, 19.83253989368677, 0.7743488112464547, 0.48241285141557455, 7.608901709318161, 2.4940655194222927, 3.9566742489114404, 55.77691063284874, 64.78235900402069, 46.854886785149574, 33.46856229007244, 34.71180997788906, 58.92635643482208, 15.064615588635206, 0.24773175915470347, 0.21418858406832442, 0.11712688181432895, 0.2560744935180992, 0.21638474747305736, 0.1837100335978903, 0.07814942684490234, 0.13180806941818446, 0.07934225111966953, 0.21998609328875318, 0.09533825723337941, 0.38635014672763646, 0.1450390336685814, 0.1002657096250914, 0.08396937118959613, 0.11220858010347001], [0.018917416637123097, 0.010006029242504155, 0.02861350181774469, 0.014623698061768664, 0.03720484266523272, 0.10814031949848868, 0.07352663349593058, 0.06386982277035713, 0.035285819467389956, 0.04587363589962479, 0.03268016123911366, 0.0431546814070316, 0.14056002401048318, 0.0064096822552528465, 0.12053224869305268, 0.04002233581559267, 0.006049871899449499, 0.05362877855077386, 0.03860044766042847, 0.1320669602137059, 0.6070813117548823, 30.22508293390274, 46.078026071190834, 40.144040286540985, 34.76603306829929, 33.611693009734154, 51.064395904541016, 63.65019455552101, 6.990693407133222, 0.034497721717343666, 0.5863971216604114, 0.17810533434385434, 0.24231592164142057, 0.15650781278964132, 5.3609798569232225, 58.23980547487736, 61.027579084038734, 59.67894405126572, 56.271522492170334, 54.45873476564884, 46.42431288957596, 47.63848073780537, 46.02156110107899, 45.801872089505196, 44.927288219332695, 44.93521839380264, 44.62795168161392, 42.405686527490616, 39.95859123766422, 38.97443264722824, 41.593453511595726, 40.200953632593155, 42.490364983677864, 41.71689748764038, 40.662735253572464, 41.964116021990776, 42.93008878827095, 40.93678794801235, 42.03885041177273, 42.217212840914726, 44.58539396524429, 41.732472851872444, 41.59945338964462, 42.149511873722076, 43.021101504564285, 42.30830155313015, 42.724356427788734, 42.22240336239338, 42.632097378373146, 43.61643835902214, 41.612258702516556, 40.866799503564835, 42.02866695821285, 40.81651300191879, 42.53086321055889, 40.83354748785496, 41.19272701442242, 41.37031428515911, 41.88998579978943, 43.71925704181194, 40.9284245967865, 39.6987459808588, 41.50968700647354, 40.26537537574768, 47.4672657251358, 49.5162183791399, 52.733794525265694, 52.186217308044434, 83.24317440390587, 78.34835305809975, 59.15994510054588, 57.355110347270966, 53.9574770629406, 47.873311936855316, 47.54570111632347, 46.06103718280792, 46.58432990312576, 45.57715594768524, 44.23780761659145, 42.14777156710625, 41.80418640375137, 40.50936408340931, 40.560718327760696, 38.77565011382103, 39.84977647662163, 39.21359181404114, 37.12300479412079, 38.01316022872925, 39.561596140265465, 39.35274034738541, 37.163476422429085, 37.50618003308773, 39.3987824767828, 37.18320116400719, 38.44501845538616, 36.63895636796951, 38.44788730144501, 38.209469094872475, 37.40312576293945, 39.35073785483837, 36.60592094063759, 36.37912631034851, 38.39290805160999, 36.018149480223656, 37.8307244181633, 36.8059878051281, 42.78789281845093, 43.61903741955757, 49.65501353144646, 49.59355942904949, 53.14932882785797, 50.507767572999, 52.33872212469578, 50.50745598971844, 50.75758896768093, 47.52418667078018, 47.68638476729393, 50.57578772306442, 52.10278898477554, 49.625530913472176, 51.77954412996769, 50.39092004299164, 52.576551362872124, 53.33304896950722, 55.00644497573376, 53.083577156066895, 40.5578076839447, 4.65149000287056, 0.15515379403950647, 0.4309026966802776, 2.213011938147247, 1.1344317393377423, 21.137249283492565, 51.359776854515076, 46.52634121477604, 31.92749798297882, 25.349878035485744, 36.54070883989334, 23.536860421299934, 0.5803110357373953, 0.028893660710309632, 0.024851239832059946, 0.03992113284766674, 0.10357011473388411, 0.015431461797561496, 0.14665969123598188, 0.06498424656456336, 0.03939252332202159, 0.03059624581510434, 0.04395349576952867, 0.015207299802568741, 0.04967219261743594, 0.027856327506015077, 0.04657847581256647, 0.04276840096281376, 0.01333748006800306, 0.022889871543156914, 0.027639844884106424, 0.018884775126934983, 0.04911139614705462, 0.02606295733130537, 0.14483093546004966, 0.07123345654690638, 0.1005795638775453, 0.04078019475855399, 0.025000947716762312, 0.018757212928903755, 0.04247317090630531, 0.017476063803769648, 0.039050118648447096, 0.03834855160675943, 0.03214700234821066, 0.036548368516378105, 0.11969158833380789, 0.015269494560925523, 0.0679565999598708, 1.6644246876239777, 42.654607370495796, 51.115829944610596, 39.532725289464, 36.41517497599125, 45.4604984074831, 55.87568253278732, 65.52708864212036, 5.53848828189075, 0.08174733651685528, 0.5032872688025236, 0.21720747754443437, 0.43572983297053725, 0.5669682892039418, 6.78201905451715, 62.41769649088383, 62.34285190701485, 60.13143517076969, 57.64033064246178, 56.06810040771961, 49.612976387143135, 48.77984829246998, 49.15835738182068, 49.22840282320976, 47.951036766171455, 46.48252196609974, 46.3511174172163, 44.22102011740208, 42.2916204482317, 42.64407433569431, 43.957006484270096, 42.28223495185375, 43.97566728293896, 43.71354974806309, 42.73893244564533, 43.40922027826309, 43.14184382557869, 43.455152213573456, 43.332312405109406, 43.96216660737991, 46.20148904621601, 44.08027186989784, 42.27224908769131, 44.899469912052155, 43.84691119194031, 43.74389871954918, 45.64662382006645, 44.07686345279217, 43.190633207559586, 44.76239986717701, 43.334394693374634, 43.54920096695423, 42.53929875791073, 42.785498946905136, 43.682247027754784, 42.329306825995445, 42.4434906989336, 43.2760564237833, 42.56375044584274, 45.73920205235481, 43.51789064705372, 43.14326874911785, 41.061919033527374, 42.97517716884613, 48.145282343029976, 53.62337999045849, 51.875393986701965, 55.24362064898014, 61.51986546814442, 62.28495441377163, 63.13251793384552, 57.772008776664734, 57.1067176759243, 49.16973777115345, 48.25238719582558, 46.38972334563732, 48.83479714393616, 47.420558631420135, 42.9687175154686, 42.96734198927879, 44.23063360154629, 42.03227676451206, 42.660231068730354, 40.95068380236626, 41.700771152973175, 40.567337572574615, 40.32998330891132, 39.98571038246155, 41.670714765787125, 40.77315352857113, 40.684834867715836, 40.573888421058655, 41.251430064439774, 39.0062103420496, 40.2894052863121, 40.10943554341793, 40.99230296909809, 37.91528508067131, 39.920125901699066, 39.30663362145424, 40.48913016915321, 39.41596895456314, 39.657320603728294, 40.671148002147675, 38.77044439315796, 38.99634227156639, 45.24853438138962, 45.854807049036026, 52.207853347063065, 52.82582178711891, 53.23335751891136, 52.570996060967445, 52.390334755182266, 51.99554733932018, 52.29380093514919, 49.62645426392555, 52.354179695248604, 53.30812990665436, 53.2503692060709, 52.3977367579937, 54.50568124651909, 50.085439234972, 56.1123376339674, 55.8150377869606, 55.93549892306328, 56.36704556643963, 43.320692628622055, 5.253689289093018, 0.20448527036933228, 2.7425007009878755, 4.1110150795429945, 0.8730010769795626, 22.72079151123762, 59.565896317362785, 50.28742499649525, 38.40326249599457, 25.908297970891, 37.394287437200546, 34.13512632250786, 1.1095910472795367, 0.13119861774612218, 0.13158144720364362, 0.008530713876098162, 0.1018473895965144, 0.04931635136017576, 0.011898950178874657, 0.06639820116106421, 0.052252291279728524, 0.07878448261180893, 0.0194354134509922, 0.08754425201914273, 0.13040885387454182, 0.010442523398523917, 0.0494735011307057, 0.041156756778946146, 0.019948346962337382, 0.11413079453632236, 0.11320408957544714, 0.11078860668931156, 0.22478050086647272, 0.10719250785768963, 0.30397997761610895, 0.2313588681863621, 0.2629998297197744, 0.147465797199402, 0.1594139146618545, 0.18553512316429988, 0.14065144176129252, 0.14728686539456248, 0.09460051791393198, 0.1956660029827617, 0.09538375830743462, 0.1548634807113558, 0.21516366221476346, 0.08350892792805098, 0.27587356860749424, 1.511151718441397, 49.786828458309174, 62.45174266397953, 54.32917691767216, 43.06223429739475, 50.6099858880043, 58.50680194795132, 76.82652711868286, 11.02798294275999, 0.1720240426948294, 1.3895202451385558, 0.35532659268938005, 0.47835645033046603, 0.42939198086969554, 7.952932873740792, 64.58491399884224, 64.89722684025764, 63.49886007606983, 60.902588590979576, 60.626586601138115, 52.03639514744282, 52.6590221375227, 50.88647045195103, 51.54123991727829, 50.92083960771561, 51.025147810578346, 49.91808481514454, 47.51526094973087, 45.24513736367226, 45.309209525585175, 46.01912543177605, 44.60280083119869, 45.88756129145622, 46.66729465126991, 45.77740140259266, 46.49856470525265, 47.18915104866028, 44.692464619874954, 45.71032740175724, 45.85136443376541, 47.860092446208, 46.02949507534504, 43.622058257460594, 46.294352263212204, 44.116084948182106, 47.59265899658203, 47.408140897750854, 45.11062078177929, 44.76381339132786, 46.15752160549164, 45.43845199048519, 45.288724824786186, 46.752284690737724, 44.63131070137024, 46.108504235744476, 44.4517969340086, 44.67416860163212, 46.33624501526356, 44.81910042464733, 47.02004112303257, 46.057119593024254, 43.47632087767124, 44.513646215200424, 45.414015501737595, 50.249229446053505, 53.71221162378788, 54.9058947712183, 57.76646867394447, 68.13938766717911, 67.08813607692719, 61.860676780343056, 58.05338367819786, 57.96222276985645, 50.91224826872349, 50.18797293305397, 50.01706190407276, 50.80717630684376, 49.97558332979679, 46.0984917730093, 46.64752051234245, 46.14869847893715, 43.59362058341503, 44.62948299944401, 43.2902866601944, 44.767370000481606, 43.42962898313999, 41.70011378824711, 41.26012399792671, 43.879494443535805, 44.027124121785164, 41.632530614733696, 41.90300390124321, 43.448711559176445, 41.721822023391724, 42.6919137686491, 40.51514357328415, 42.787410244345665, 40.60887694358826, 40.58987036347389, 42.312481328845024, 41.3444908708334, 40.734038427472115, 43.80240797996521, 41.97018429636955, 40.64160838723183, 42.27115474641323, 48.80904972553253, 48.55645067989826, 54.113131910562515, 55.17295204102993, 56.210064589977264, 53.47320444881916, 54.45520855486393, 52.50240594148636, 54.23075459897518, 50.42454443871975, 52.80921287834644, 52.9546994715929, 54.42800961434841, 56.18888832628727, 56.987499073147774, 53.11378553509712, 58.80645006895065, 60.622650012373924, 58.53352591395378, 55.89546047151089, 43.57912436127663, 6.969260657206178, 0.36599900282453746, 2.0954163232818246, 7.685181191191077, 1.5845636604353786, 25.849933102726936, 65.04437014460564, 55.06281495094299, 44.0202084928751, 38.39078776538372, 47.616278529167175, 43.1686057895422, 2.086596521548927, 0.2792593650519848, 0.2049965359037742, 0.17077966884244233, 0.3080021508503705, 0.12042593603837304, 0.2644297108054161, 0.1521103354752995, 0.12161772130639292, 0.13459425506880507, 0.12378079234622419, 0.1906213877373375, 0.14194104209309444, 0.058423698210390285, 0.0748883186315652, 0.10873251623706892, 0.1518601574935019], [0.03797524390392937, 0.06353325137752108, 0.05755406069511082, 0.007772777471473091, 0.022447536684921943, 0.07151976227760315, 0.08451919129583985, 0.02681722427951172, 0.01443469438527245, 0.0879806125885807, 0.024950633815024048, 0.11065925034927204, 0.00808997927379096, 0.02077666355035035, 0.04665866857976653, 0.10102857806487009, 0.05949886981397867, 0.012631449935724959, 0.05101950235257391, 0.07278459714143537, 0.19946314219851047, 6.014037039130926, 50.70738226175308, 40.2849405258894, 34.76684242486954, 33.71030151844025, 42.55256004631519, 59.09796662628651, 37.10821218788624, 0.6530481576919556, 0.0903009224566631, 0.11956013171584345, 0.24557093682233244, 0.023183708217402454, 0.11050365908886306, 34.212034195661545, 66.83311656117439, 57.45820641517639, 57.2909963876009, 55.16869246959686, 51.116962283849716, 45.26780314743519, 47.41577088832855, 44.40821707248688, 48.38414892554283, 43.6939238011837, 46.87817573547363, 43.56387197971344, 43.697229623794556, 42.43234969675541, 41.673116236925125, 41.28440849483013, 46.14825390279293, 45.191180258989334, 48.83791297674179, 46.99570342898369, 43.38126517832279, 40.8540815860033, 41.474652886390686, 40.999792367219925, 43.402380645275116, 41.928827315568924, 42.12635591626167, 42.41865523159504, 42.98376090824604, 42.707010358572006, 42.9572269320488, 43.29563297331333, 42.72550016641617, 42.547681108117104, 42.558400332927704, 40.37796713411808, 43.25181372463703, 41.87054984271526, 42.147547379136086, 41.80564172565937, 42.421448081731796, 41.352960616350174, 41.58896215260029, 42.95770950615406, 41.5131676197052, 43.4832327067852, 43.6217200756073, 46.25590592622757, 50.61763487756252, 55.09194418787956, 55.21524757146835, 56.17042511701584, 88.64079236984253, 90.4370167851448, 57.71319933235645, 55.905165150761604, 55.86912028491497, 49.691936150193214, 49.76295433938503, 54.232240319252014, 55.71340084075928, 54.11942057311535, 49.97903734445572, 47.30564899742603, 42.08919771015644, 42.5455342233181, 40.960715264081955, 39.29860845208168, 38.84694188833237, 40.671269595623016, 38.61378259956837, 39.57734629511833, 38.576419204473495, 39.38273973762989, 39.74541127681732, 40.70687748491764, 37.409327030181885, 40.05242720246315, 37.76345282793045, 36.5174350887537, 37.54385881125927, 38.066486567258835, 39.92585599422455, 38.17008800804615, 36.98802463710308, 37.25605085492134, 37.315540462732315, 36.81039176881313, 36.62463113665581, 36.826008930802345, 38.61510872840881, 46.393105164170265, 51.266795843839645, 50.853944197297096, 50.07430203258991, 52.476506531238556, 51.96231052279472, 51.98756016790867, 55.10044813156128, 55.89646361768246, 50.85984148085117, 48.914931043982506, 48.774965554475784, 54.148272424936295, 51.57171428203583, 52.883046716451645, 52.7024994045496, 55.07210925221443, 50.09594567120075, 51.28835208714008, 19.69481248408556, 1.175897370558232, 0.07439836757839657, 2.7847606083378196, 3.2904645474627614, 1.0308247175998986, 34.96817082166672, 58.50519083440304, 43.77927102148533, 45.78799903392792, 43.7547243386507, 35.69150760769844, 17.174698412418365, 0.11539916202309541, 0.21895179175771773, 0.07464056747267023, 0.10119254817254841, 0.02442572204017779, 0.024917938499129377, 0.045459461834980175, 0.04371823124529328, 0.031066049414221197, 0.062160237357602455, 0.024626395061204676, 0.05422643749625422, 0.05510958952072542, 0.10838116868399084, 0.14072084741201252, 0.011924317714147037, 0.03307491329906043, 0.030122981952445116, 0.06668376474408433, 0.03153521291096695, 0.004016880329800188, 0.03399642322619911, 0.07695890322793275, 0.019787907622230705, 0.017390898647136055, 0.031732364441268146, 0.060662653850158677, 0.0637049695069436, 0.13164392119506374, 0.025403540566912852, 0.06969606052734889, 0.03615237706981134, 0.12078253799700178, 0.025080754567170516, 0.0602588735637255, 0.142766043136362, 0.10697196383262053, 0.32671199063770473, 13.03394565358758, 59.86778251826763, 41.37588858604431, 37.620842680335045, 43.68369095027447, 49.99982602894306, 65.74566051363945, 35.84152735769749, 0.7182364503387362, 0.5030292388983071, 0.15576726815197617, 0.38591780117712915, 0.9666452708188444, 0.20202433835947886, 39.97004762291908, 70.38123697042465, 57.87971019744873, 60.4073079675436, 56.61864906549454, 54.90030527114868, 47.70697206258774, 50.4257033765316, 46.59522391855717, 50.962736159563065, 47.21951901912689, 49.45253759622574, 46.498690098524094, 45.65386243164539, 43.40234264731407, 44.91474129259586, 40.92908576130867, 46.51521921157837, 46.13679751753807, 49.892185404896736, 48.63243520259857, 44.043847024440765, 42.35314294695854, 45.26289381086826, 43.109382167458534, 44.31481808423996, 45.5051726102829, 43.9409751445055, 44.51770819723606, 43.94250646233559, 44.41069073975086, 43.844224736094475, 43.4578500688076, 44.24457885324955, 44.75780591368675, 43.609203547239304, 42.843483835458755, 44.90531399846077, 43.464077934622765, 44.47687938809395, 44.27030727267265, 42.50951215624809, 43.57814781367779, 40.848834067583084, 44.005936458706856, 43.09379160404205, 48.101333901286125, 43.64013768732548, 47.934538051486015, 50.64486801624298, 57.937030121684074, 53.97109553217888, 62.465733513236046, 79.70831528306007, 73.49523827433586, 63.44046100974083, 57.0149601995945, 59.43619407713413, 49.08861592411995, 53.221441358327866, 53.911803513765335, 57.56350256502628, 55.86496330797672, 51.746626496315, 47.06300541758537, 44.10876654088497, 41.71386145055294, 41.98273502290249, 40.52141323685646, 41.11874878406525, 42.32930302619934, 41.215415596961975, 42.04505167901516, 40.057188346982, 40.02862527966499, 43.0826848000288, 42.02895574271679, 39.41680870950222, 40.33953219652176, 40.16069479286671, 39.68434855341911, 39.24466274678707, 38.864116966724396, 40.743412524461746, 38.12321372330189, 39.714560732245445, 40.59189945459366, 39.730622470378876, 39.13335531949997, 39.32924620807171, 37.89696626365185, 40.81831410527229, 47.256540432572365, 54.145236387848854, 50.910067185759544, 52.42189206182957, 54.601899683475494, 51.32401317358017, 53.869587779045105, 56.249023899436, 54.750954285264015, 52.03668773174286, 50.62671259045601, 50.40408633649349, 55.72589837014675, 53.95123019814491, 55.19751392304897, 55.20355559885502, 57.073853239417076, 52.910298854112625, 51.85499668121338, 23.319164402782917, 1.3513651862740517, 0.6723297480493784, 6.61418586038053, 2.3563575837761164, 0.6005108112003654, 39.730185493826866, 61.9769923388958, 49.45444129407406, 48.82577262818813, 42.45423652231693, 41.945531219244, 24.329938665032387, 0.2315402787644416, 0.14988234877819195, 0.057636850979179144, 0.05850996916706208, 0.026476307612028904, 0.02500483657058794, 0.035867763435817324, 0.06032726618286688, 0.03512074355967343, 0.09171753394184634, 0.07483541834517382, 0.06851544458186254, 0.07485875888960436, 0.04467864826438017, 0.048105311070685275, 0.03957881352107506, 0.02874475063435966, 0.08968195645138621, 0.17758298112312332, 0.1294286994379945, 0.07057006558170542, 0.15587455302011222, 0.21034834091551602, 0.18020930816419423, 0.11671076703350991, 0.11263956752372906, 0.1962733024265617, 0.06386303954059258, 0.3325735917314887, 0.13296452845679596, 0.19345091481227428, 0.15490021702134982, 0.26213971024844795, 0.19112788868369535, 0.17533160193124786, 0.21794653788674623, 0.22163266665302217, 0.8211266761645675, 14.52982658520341, 67.57507234811783, 50.58563679456711, 46.22306428849697, 46.839778795838356, 54.20913755893707, 70.97222685813904, 46.71001195907593, 0.7591876841615885, 0.603490088833496, 0.31988966453354806, 0.39717163948807865, 0.5680331820622087, 0.3565133165102452, 39.03275951743126, 70.48627853393555, 61.53235159814358, 62.688652351498604, 59.32161122560501, 57.95915253460407, 51.74278490245342, 53.55174243450165, 48.33640068769455, 52.90714122354984, 49.08963046967983, 54.27934259176254, 47.90404848754406, 47.60765299201012, 45.667370706796646, 48.40638913214207, 42.34138257801533, 49.80358935892582, 49.29500564932823, 52.16824047267437, 51.595474407076836, 47.93168440461159, 44.4659473747015, 47.73081958293915, 45.34219555556774, 47.77200177311897, 45.79815208911896, 45.83035156130791, 44.54795837402344, 45.86744897067547, 45.75039625167847, 46.71105310320854, 47.10195332765579, 48.51887449622154, 46.177421137690544, 46.372069492936134, 43.792182728648186, 49.68502052128315, 44.695800840854645, 46.40380539000034, 47.28785075247288, 46.53281606733799, 44.851474687457085, 45.00420369207859, 45.745103135704994, 44.557758048176765, 48.38720016181469, 49.23548944294453, 49.88794103264809, 54.38257925212383, 58.36739502847195, 56.832478791475296, 59.05094414949417, 93.81782457232475, 80.91360300779343, 58.54022495448589, 59.91865038871765, 60.7949061691761, 53.089280650019646, 55.67194886505604, 58.104760721325874, 59.08013038337231, 59.03512939810753, 52.62051500380039, 52.67190724611282, 46.982134357094765, 44.75308656692505, 44.17225353419781, 42.94716887176037, 43.64875562489033, 44.71906319260597, 43.9261407405138, 43.69245707988739, 41.53782829642296, 42.96541929244995, 43.338753059506416, 43.870139345526695, 42.81379222869873, 42.10471227765083, 42.005609795451164, 42.15885557234287, 41.87607854604721, 42.33856312930584, 44.548984318971634, 41.5066509693861, 41.875489577651024, 42.60196499526501, 40.573751628398895, 41.112076342105865, 42.23192945122719, 39.34190332889557, 43.6772008985281, 50.26854380965233, 54.16415177285671, 55.536125153303146, 55.127122700214386, 57.268406599760056, 55.02994291484356, 54.278966411948204, 59.56037141382694, 59.418760612607, 54.882488027215004, 51.739889457821846, 53.314524963498116, 55.86539648473263, 58.7332583963871, 57.500665336847305, 57.95911453664303, 58.485678881406784, 54.54228848218918, 51.61843277513981, 26.14427100867033, 2.1225224062800407, 0.3342692804289982, 7.941498812288046, 9.874123558402061, 1.9664103956893086, 44.592564180493355, 68.50215420126915, 53.9483043551445, 54.26027521491051, 50.04540838301182, 51.330921202898026, 34.028576239943504, 0.3773014369653538, 0.20905079960357398, 0.21380058926297352, 0.12828800361603498, 0.15216105384752154, 0.24296696326928213, 0.15761713060783222, 0.08412158567807637, 0.1304600472212769, 0.21858612075448036, 0.1441499259090051, 0.15941554738674313, 0.19050246599363163, 0.1560250308830291, 0.24341006996110082, 0.09706772107165307, 0.07444112270604819], [0.007055148962535895, 0.014104456295171985, 0.03486355970380828, 0.1229735954257194, 0.02048519061645493, 0.020837514093727805, 0.0619719285168685, 0.046495871065417305, 0.06792805696022697, 0.08707614237209782, 0.061941945750731975, 0.03149947850033641, 0.03532206595991738, 0.09125772150582634, 0.03608409948355984, 0.05642756957968231, 0.032959119707811624, 0.04604463785653934, 0.024903661433199886, 0.020183949163765647, 0.2453691023401916, 0.6305864942260087, 27.810479700565338, 45.551484525203705, 25.402358919382095, 24.237058348953724, 34.991809353232384, 49.86682176589966, 60.15263423323631, 6.851672641932964, 0.7338628743309528, 0.4879582382272929, 1.159007870592177, 0.3671718336408958, 0.2543465362396091, 6.886202814057469, 60.46345755457878, 61.850067749619484, 60.49747332930565, 56.74042113125324, 53.09520833194256, 48.98756414651871, 47.77280732989311, 48.476233184337616, 49.34503756463528, 46.950037479400635, 45.22426888346672, 45.70018574595451, 42.439584508538246, 43.45129542052746, 41.903342083096504, 46.49686239659786, 49.6335256844759, 51.375948786735535, 53.25862996280193, 50.524699464440346, 49.15033221244812, 45.91127581894398, 45.188641995191574, 49.28962133824825, 40.76795160770416, 42.89746753871441, 42.97752924263477, 43.36901843547821, 42.485383450984955, 42.74337060749531, 41.301211193203926, 41.47194743156433, 39.96924586594105, 41.13462433218956, 41.75948180258274, 40.95684327185154, 42.15538635849953, 42.157168462872505, 40.61670832335949, 43.006635680794716, 40.84161825478077, 41.43647253513336, 39.414513632655144, 43.63215431571007, 42.557621374726295, 43.853443041443825, 42.352888360619545, 49.3373391777277, 52.128293216228485, 57.26095899939537, 52.866711392998695, 60.87511986494064, 34.1614855080843, 51.884353905916214, 85.42591407895088, 55.13008654117584, 56.94802679121494, 51.60872809588909, 54.460623264312744, 54.38729479908943, 58.13953645527363, 52.62747623026371, 53.25919233262539, 51.34389750659466, 44.56988699734211, 41.910117119550705, 41.99302487075329, 38.86824734508991, 37.79339902102947, 40.914555341005325, 38.70028115808964, 39.00122120976448, 39.502889290452, 40.0906303524971, 39.768225252628326, 38.938231989741325, 38.58864314854145, 38.12576338648796, 38.953624963760376, 36.9956736266613, 37.026246786117554, 38.15398067235947, 37.850399762392044, 39.553483575582504, 36.64524883031845, 36.71537786722183, 36.86964198946953, 39.326669946312904, 36.347196623682976, 38.39301824569702, 36.422333791852, 39.860450103878975, 46.776861771941185, 50.28281584382057, 50.42103722691536, 52.715943083167076, 50.30051149427891, 52.07555204629898, 49.05995026230812, 51.797068789601326, 54.40419629216194, 51.82722397148609, 46.87929667532444, 51.11657090485096, 48.07048335671425, 52.7188803255558, 50.471471920609474, 53.41453179717064, 44.45422500371933, 42.22742289304733, 8.567404076457024, 0.1451701414771378, 1.6727888700552285, 6.488936981186271, 2.8565406566485763, 2.652550502680242, 45.721270814538, 50.86039625108242, 31.023754477500916, 30.17110113054514, 27.576788440346718, 43.06082837283611, 4.83773035928607, 0.5145860812626779, 0.08996304488391615, 0.07067080470733345, 0.12867120414739475, 0.07764643625705503, 0.1162239997938741, 0.029256697089294903, 0.0014043454075363115, 0.01830818389862543, 0.09330449800472707, 0.06572044963832013, 0.017611682014830876, 0.018280449839949142, 0.008362084936379688, 0.1127691390865948, 0.06077726371586323, 0.04146787250647321, 0.08754552851314656, 0.06954753451282158, 0.07781995038385503, 0.04458475545106921, 0.0259350500346045, 0.018533759684942197, 0.07887522500823252, 0.059066064131911844, 0.0692939203872811, 0.07917049588286318, 0.015600749393342994, 0.024487756309099495, 0.09845273933024146, 0.014742818329978036, 0.04889307856501546, 0.07591247500386089, 0.0882806332083419, 0.06610790267586708, 0.07510829862440005, 0.10468856096849777, 0.1548222915153019, 1.4545754855498672, 38.651598170399666, 49.60069164633751, 27.8208227455616, 35.24480737745762, 44.12208862602711, 55.5831628292799, 62.61669561266899, 5.525131048634648, 0.39378729765303433, 1.5266312565654516, 2.0159583119675517, 1.7638737824745476, 0.5980857694521546, 9.752532932907343, 60.70156417787075, 64.60414856672287, 60.79425260424614, 58.95027995109558, 54.16518151760101, 51.66180744767189, 49.230652302503586, 52.205170691013336, 51.82074151933193, 49.795499593019485, 45.737917721271515, 49.014565497636795, 45.38474567234516, 45.662206783890724, 43.780296966433525, 48.00851248204708, 50.99553219974041, 54.072778075933456, 55.215076580643654, 53.201899006962776, 52.32818529009819, 46.408129557967186, 45.747660398483276, 48.29400256276131, 43.140529096126556, 44.13470774888992, 44.507353752851486, 45.48046633601189, 43.96012231707573, 45.661496222019196, 43.52824129164219, 44.85473491251469, 40.92553675174713, 42.58409835398197, 43.12699422240257, 43.35678689181805, 45.033021345734596, 42.10865266621113, 43.83311793208122, 43.4263801574707, 42.32170723378658, 43.14979299902916, 41.96961812674999, 44.57441255450249, 43.42177100479603, 46.73466503620148, 44.833528250455856, 50.078652799129486, 51.95678561925888, 58.73630963265896, 53.04342471063137, 64.35838535428047, 46.68509669601917, 51.57907448709011, 68.44793111085892, 55.78876219689846, 60.18748216331005, 53.93039211630821, 53.683044388890266, 56.5127145498991, 58.47225800156593, 54.57927189767361, 55.44865004718304, 52.49021999537945, 44.38395917415619, 42.33056455850601, 43.01415927708149, 40.877708718180656, 39.13929060101509, 41.47474408149719, 40.869793742895126, 41.367814019322395, 41.563233733177185, 40.79029440879822, 40.796689465641975, 41.85692377388477, 40.469622015953064, 39.61791291832924, 40.596235021948814, 40.04549637436867, 40.87776951491833, 40.19700564444065, 38.4894684702158, 42.42855370044708, 38.18116821348667, 39.69550855457783, 40.6000842154026, 40.62807351350784, 39.626397863030434, 40.063701197505, 37.77520179748535, 43.14559802412987, 47.28286921977997, 54.44612704217434, 50.89229553937912, 54.02447126805782, 51.05538658797741, 55.2043117582798, 50.315995663404465, 54.30887080729008, 53.74254159629345, 54.973291754722595, 49.205535650253296, 53.5291488468647, 48.1335523724556, 54.19959247112274, 51.499130576848984, 53.55989299714565, 45.87089158594608, 46.18655204772949, 9.203622937202454, 0.7913568173535168, 2.9809818416833878, 6.326434900984168, 2.4580213660374284, 2.6374292140826583, 52.66821764409542, 55.14401279389858, 42.47611954808235, 48.240550830960274, 33.2906786352396, 48.512232452631, 9.219867065548897, 0.85282540647313, 0.16373932943679392, 0.07029119617072865, 0.07948595317429863, 0.10510293912375346, 0.05753626028308645, 0.09450998331885785, 0.0346563780476572, 0.04197196147288196, 0.04703035097918473, 0.0636304727231618, 0.04285358838387765, 0.06299638916971162, 0.011401176889194176, 0.03544747036357876, 0.022047302009013947, 0.07055290712742135, 0.1353623779141344, 0.1506455140770413, 0.192960889544338, 0.2123150322586298, 0.12861938739661127, 0.1643413002602756, 0.13730339094763622, 0.22039777744794264, 0.18184476415626705, 0.31367132789455354, 0.11608835746301338, 0.11917828931473196, 0.15987894439604133, 0.23378371697617695, 0.18122737150406465, 0.1609711186029017, 0.19701898272614926, 0.15510573255596682, 0.18048048892524093, 0.33544600009918213, 0.3611237753648311, 1.352178817614913, 44.51466456055641, 59.347373843193054, 35.482499822974205, 36.49146728217602, 47.825708091259, 57.851622104644775, 72.10908025503159, 8.249374441802502, 0.6139350752346218, 1.4127285685390234, 2.7327853348106146, 2.500678589567542, 0.2948634949279949, 10.587492529302835, 62.916085347533226, 64.24331232905388, 65.93588590621948, 61.94604679942131, 55.771393328905106, 55.12972556054592, 53.598286136984825, 54.702993258833885, 55.718260779976845, 52.593437656760216, 50.11978179216385, 52.02461197972298, 47.49004170298576, 46.95422865450382, 45.89555226266384, 51.3663125038147, 54.42642129957676, 56.26784048974514, 58.708137944340706, 54.402543380856514, 55.371103808283806, 49.347427636384964, 48.9277895539999, 51.331924349069595, 47.26842999458313, 46.47655628621578, 46.556428000330925, 46.48037888109684, 45.999537482857704, 48.25913563370705, 45.924119129776955, 46.4177468419075, 43.21753956377506, 43.87757554650307, 44.89006921648979, 43.895666375756264, 47.74468503892422, 45.375504568219185, 45.97600154578686, 47.60183170437813, 46.464571729302406, 45.99877372384071, 45.80600246787071, 47.84973420202732, 46.31273567676544, 47.41914510726929, 47.29556433856487, 51.26736581325531, 55.15002027153969, 59.745888859033585, 55.853396728634834, 60.746185183525085, 53.548360615968704, 59.70631778240204, 69.4100470840931, 57.5406239926815, 60.92137098312378, 55.90784400701523, 56.20574802160263, 57.84835807979107, 58.682318329811096, 54.7583144903183, 57.42201715707779, 57.05737732350826, 48.05909536778927, 44.546043276786804, 45.80286383628845, 43.87736655771732, 41.459955275058746, 44.96134579181671, 42.19964638352394, 43.886569663882256, 45.21746724843979, 43.97947087883949, 43.80529962480068, 44.79173809289932, 42.38593518733978, 42.84550912678242, 44.114454835653305, 40.247911512851715, 43.008581176400185, 42.987598702311516, 41.87421664595604, 46.09786860644817, 41.40778787434101, 41.60473890602589, 42.66448684036732, 43.141703233122826, 41.134061962366104, 43.167659640312195, 40.16361303627491, 45.62895096838474, 50.22799998521805, 56.419581547379494, 53.95131379365921, 57.91833892464638, 52.71154671907425, 58.275090381503105, 52.19390049576759, 56.474112421274185, 57.820733562111855, 56.07525922358036, 49.9436042457819, 53.9522485435009, 46.723695024847984, 56.37907572090626, 51.434002071619034, 55.03914222121239, 47.25121311843395, 47.67193414270878, 10.078304652124643, 0.5505432549398392, 3.777814758941531, 15.058001093566418, 6.8450286984443665, 2.836135751567781, 57.10634529590607, 61.34554982185364, 42.69043184816837, 43.50831516087055, 38.05119998753071, 59.00779366493225, 13.985523842275143, 1.3216454372741282, 0.2470516847097315, 0.25372506177518517, 0.2018076163949445, 0.19467247504508123, 0.26855349889956415, 0.1542877225438133, 0.09682627074653283, 0.13297983154188842, 0.1675294924643822, 0.14986486377893016, 0.11913050242583267, 0.12516780698206276, 0.19745002209674567, 0.15033876959932968, 0.09485721195233054, 0.15807739575393498], [0.057384361207368784, 0.08681583407451399, 0.07889560438343324, 0.014379516633198364, 0.0972449904656969, 0.06882763642352074, 0.04265336807293352, 0.025619837651902344, 0.03173873577907216, 0.048133082236745395, 0.022834882111055776, 0.03958404195145704, 0.05640799172397237, 0.040622870583320037, 0.06699960795231164, 0.05633350978314411, 0.13236416067229584, 0.032148679601959884, 0.04935290584398899, 0.0752428722626064, 0.10647099930793047, 0.3883376478916034, 9.652814883738756, 54.807730838656425, 39.64753232896328, 38.05812321603298, 36.333080381155014, 35.66618196666241, 64.8170055449009, 26.582949869334698, 0.2745626389514655, 0.7818580989260226, 0.7320930005516857, 4.910669345408678, 0.026455030238139443, 0.8264974504709244, 40.78467071056366, 68.10018137097359, 58.509579598903656, 59.25686649978161, 53.98736245930195, 54.441989064216614, 47.738096192479134, 49.18236829340458, 45.54975561797619, 48.088137209415436, 44.68077264726162, 46.25872537493706, 44.75126266479492, 44.73489314317703, 46.82597793638706, 51.239543706178665, 51.32200688123703, 54.519542902708054, 52.707925513386726, 52.17003397643566, 54.74088482558727, 53.05596403777599, 56.76754407584667, 53.488669618964195, 51.05518139898777, 43.80189120769501, 40.88968187570572, 44.632937014102936, 44.32019479572773, 44.81395550072193, 43.085329458117485, 43.89310911297798, 41.43310211598873, 41.92235626280308, 41.70117773115635, 41.865089535713196, 42.80692599713802, 41.82606562972069, 41.82449251413345, 42.029115334153175, 41.63329437375069, 41.73330120742321, 40.646931901574135, 42.52376139163971, 42.03953817486763, 42.766708955168724, 41.99735663831234, 49.649351835250854, 56.250103041529655, 57.05174222588539, 55.436566695570946, 56.19338348507881, 33.12184989452362, 29.328655935823917, 69.57077845931053, 61.68915018439293, 55.633589923381805, 55.74254147708416, 55.75558617711067, 57.6248312741518, 56.813954785466194, 57.19594828784466, 55.31194098293781, 51.55981332063675, 43.27173225581646, 41.76992744207382, 39.722749292850494, 40.743522718548775, 39.99322257936001, 41.61484256386757, 38.84784244000912, 39.4235647469759, 38.25720593333244, 39.26820248365402, 40.99278174340725, 37.61518478393555, 38.06359112262726, 39.14499029517174, 38.925267085433006, 37.59256459772587, 37.84690394997597, 38.226370587944984, 36.492546424269676, 38.52987930178642, 38.62533397972584, 38.65926995873451, 37.639484480023384, 37.68059067428112, 36.366514787077904, 37.16199450194836, 36.725420728325844, 36.46453432738781, 40.383385643363, 40.409938618540764, 43.10636892914772, 45.56435063481331, 47.0920130610466, 47.883506789803505, 49.293808713555336, 48.5906146466732, 48.73615063726902, 50.51088720560074, 51.335594952106476, 51.2342581897974, 51.133536994457245, 48.68146397173405, 50.87931923568249, 51.85069151222706, 51.943600326776505, 31.159122213721275, 0.9228341560810804, 0.8059537934605032, 1.1519112763926387, 5.494229681789875, 1.2114205956459045, 9.062290471047163, 57.07000784575939, 41.77864037454128, 25.299549736082554, 22.99678210169077, 34.59266737103462, 38.34683932363987, 0.9083260002080351, 0.02716425067774253, 0.026109898171853274, 0.042413865885464475, 0.07202394030173309, 0.027883477123396005, 0.08715296949958429, 0.07149354962166399, 0.024043219127634075, 0.04582709581882227, 0.07462201378075406, 0.012246505357325077, 0.051475522413966246, 0.03426735165703576, 0.02125212602550164, 0.021923715867160354, 0.050587884106789716, 0.08690043148817495, 0.059903314322582446, 0.12365407063043676, 0.06356785030220635, 0.04218182228214573, 0.06972415081690997, 0.10602287569781765, 0.03290718792413827, 0.0757398662972264, 0.06859088389319368, 0.01893194788863184, 0.04201240109978244, 0.07923446159111336, 0.07563393213786185, 0.023992487767827697, 0.020995968188799452, 0.040646359557285905, 0.06207154699950479, 0.04091223396244459, 0.026492313882044982, 0.06076124816900119, 0.17126203514635563, 0.4695560928666964, 14.552557915449142, 62.07462050020695, 37.90120683610439, 33.95159237086773, 44.542570263147354, 42.47841842472553, 71.87016427516937, 26.42580360174179, 0.29842559597454965, 1.9055481115356088, 4.7364558186382055, 4.85276092775166, 0.27538119815289974, 1.2480728351511061, 44.91127967834473, 68.04319202899933, 60.68347714841366, 60.27734734117985, 56.69610410928726, 57.44213327765465, 50.672329142689705, 51.936251521110535, 48.789416179060936, 49.99601483345032, 47.85142131149769, 47.172314152121544, 47.16727942228317, 47.23810002207756, 48.346378952264786, 53.08953903615475, 53.42189200222492, 56.51981256902218, 55.36527492105961, 54.99179296195507, 55.69449305534363, 54.544043987989426, 57.55130521953106, 57.256247252225876, 51.09453588724136, 46.21861092746258, 44.223334193229675, 47.013057097792625, 45.513102784752846, 46.06330566108227, 44.383552595973015, 45.30332364141941, 43.90969902276993, 44.31246221065521, 43.87783393263817, 44.100023210048676, 44.52930137515068, 44.47217524051666, 43.71649459004402, 44.207804426550865, 43.98125298321247, 42.69469901919365, 42.50022165477276, 43.40738497674465, 44.161754697561264, 44.475640654563904, 44.109412506222725, 50.903523936867714, 56.43491372466087, 59.02612768113613, 58.79970923066139, 56.228903979063034, 34.14436362683773, 33.93900744616985, 67.61975795030594, 64.87864583730698, 55.201066732406616, 58.79394493997097, 57.224648147821426, 60.3370763361454, 58.13603304326534, 60.896550714969635, 55.08198872208595, 53.74037191271782, 45.3475646674633, 41.67650945484638, 40.43918564915657, 40.80034486949444, 42.224500849843025, 43.704114854335785, 40.43761633336544, 39.84413377940655, 41.07786297798157, 41.57574646174908, 42.03634634613991, 39.7974418848753, 39.78161193430424, 43.21715958416462, 41.46104581654072, 39.98190678656101, 38.91623876988888, 40.36649934947491, 38.30734804272652, 39.309236481785774, 40.423625484108925, 39.93922367691994, 40.36901481449604, 39.270812943577766, 38.4906692057848, 39.16919879615307, 37.59001113474369, 38.29591065645218, 41.5881983935833, 44.34807009994984, 45.928519293665886, 48.94691772758961, 49.3793611228466, 51.307373866438866, 50.50143711268902, 50.838885605335236, 50.57589031755924, 52.544473484158516, 51.89985707402229, 53.424939438700676, 53.669536113739014, 51.23618848621845, 49.613268971443176, 51.764044761657715, 52.78426721692085, 31.96922354400158, 1.3585462071932852, 1.1788264196366072, 4.766841363161802, 5.11915560811758, 1.6157452622428536, 9.561641626060009, 60.416674464941025, 47.00628966093063, 33.175123035907745, 24.604943208396435, 37.12521627545357, 46.39018692076206, 2.0964866783469915, 0.03422758738452103, 0.05087318793812301, 0.033613263512961566, 0.032828505427460186, 0.04328140683355741, 0.06199225223099347, 0.02607597089081537, 0.11200287161045708, 0.05719068292819429, 0.0592233437782852, 0.07381101706414483, 0.029371123273449484, 0.0379585715563735, 0.006708725095450063, 0.08931395510444418, 0.06958732104976662, 0.08278996494482271, 0.16082516784081236, 0.23366158915450796, 0.21451223467011005, 0.08905959140975028, 0.27239316317718476, 0.14248061313992366, 0.12901812850032002, 0.12202998434077017, 0.18610847677337006, 0.07750133896479383, 0.16673983249347657, 0.23720905504887924, 0.1749904514872469, 0.09849456677329727, 0.16043938463553786, 0.10877896726015024, 0.2655508287716657, 0.1291328645311296, 0.27963364496827126, 0.1815363424248062, 0.3060375672066584, 0.7099094346631318, 14.417924489825964, 74.10443678498268, 50.68670377135277, 48.78074884414673, 51.397060453891754, 44.9932374805212, 77.04395145177841, 32.212524488568306, 0.2764630416641012, 2.9790572449564934, 6.50404354557395, 15.231893062591553, 0.1517278325627558, 1.5577654796652496, 47.067466378211975, 70.64526200294495, 62.78427042067051, 63.90254661440849, 58.42616647481918, 59.99228663742542, 53.0047769844532, 56.072561368346214, 50.82534313201904, 51.67417198419571, 50.770253688097, 49.81809698045254, 49.235694631934166, 50.05725994706154, 51.01358883082867, 55.89943885803223, 56.274611726403236, 60.08951961994171, 57.85562328994274, 58.06851826608181, 57.7629728615284, 56.50208652019501, 60.234478041529655, 58.4019123762846, 53.48247595131397, 49.47233073413372, 46.26633636653423, 48.4516105055809, 48.012426272034645, 46.54089443385601, 46.163384690880775, 47.085336819291115, 46.27118870615959, 48.050739616155624, 47.02439568936825, 45.47114543616772, 47.330013290047646, 47.927626222372055, 44.33755986392498, 47.44470253586769, 46.167423874139786, 45.258581042289734, 43.67194578051567, 47.557803466916084, 46.62742339074612, 46.68132349848747, 46.24079413712025, 53.22503976523876, 58.56537200510502, 63.0409200489521, 59.452548399567604, 56.86670735478401, 37.07304127514362, 45.33343322575092, 73.34423437714577, 61.357921957969666, 57.52049647271633, 59.23015773296356, 58.78357529640198, 61.4107771217823, 61.532408595085144, 60.65042272210121, 56.808312088251114, 55.69440945982933, 47.858990505337715, 45.616407841444016, 42.60419547557831, 43.660519793629646, 44.9417844414711, 46.526869386434555, 42.04401433467865, 43.09157632291317, 42.68517293035984, 43.67138721048832, 45.10731875896454, 41.29831574857235, 40.54852098226547, 45.887116715312004, 44.39930275082588, 42.65730142593384, 40.97308740019798, 42.95202121138573, 40.937665700912476, 43.14203381538391, 42.068055644631386, 43.19946773350239, 42.79008910059929, 42.49543771147728, 39.93931487202644, 40.79493395984173, 38.41258339583874, 39.97376762330532, 44.722144827246666, 45.953917130827904, 47.547840401530266, 51.56819947063923, 51.33787102997303, 54.20621171593666, 52.21783921122551, 53.55532184243202, 53.017035126686096, 56.29772208631039, 54.28970083594322, 56.96598842740059, 55.711006969213486, 52.352534383535385, 51.44028693437576, 52.38103665411472, 52.37213373184204, 32.22680412232876, 1.5656671556644142, 1.3543283147737384, 6.124544609338045, 14.125799015164375, 4.202278107404709, 11.094258986413479, 69.24477875232697, 50.47953888773918, 37.38662324845791, 33.43387395143509, 45.9001500159502, 55.43886557221413, 3.0076046381145716, 0.15675082162488252, 0.1716085587395355, 0.10467168453033082, 0.10445035382872447, 0.13939598022261634, 0.3169959713704884, 0.1982732568285428, 0.16405330243287608, 0.1678386118146591, 0.14420713065192103, 0.12148873604019172, 0.17620745493331924, 0.17009278148179874, 0.07566323954961263, 0.21737429749919102, 0.190642568632029, 0.21563758287811652], [0.045975848188390955, 0.025720111079863273, 0.024501938751200214, 0.03864735881506931, 0.047648749241488986, 0.03621498093707487, 0.05215158555074595, 0.0596076204237761, 0.05669951104209758, 0.05274765630019829, 0.0500721916614566, 0.030389561397896614, 0.09532368887448683, 0.022209208946151193, 0.057575204482418485, 0.01467299336582073, 0.013357978186832042, 0.03268031337938737, 0.09212954464601353, 0.019428075465839356, 0.04384649662824813, 0.1815205643652007, 0.5490571784321219, 25.48713807016611, 45.6637267023325, 34.47855569422245, 40.072866305708885, 35.14827735722065, 45.56546397507191, 49.46217767894268, 2.6408174447715282, 2.4660237366333604, 3.5168549744412303, 2.3319674050435424, 0.5417235719505697, 0.1859172698459588, 8.813970945775509, 63.807680904865265, 60.7991049438715, 62.66330771148205, 56.54918499290943, 57.47032776474953, 51.99665687978268, 51.20452478528023, 47.70430460572243, 47.66275003552437, 46.24343879520893, 46.83943301439285, 43.03573451936245, 48.82975481450558, 49.258778393268585, 49.63271252810955, 50.12436054646969, 54.16635565459728, 52.65687145292759, 55.115312933921814, 54.53199103474617, 57.74933159351349, 54.206945076584816, 56.98901139199734, 54.50847029685974, 49.872855842113495, 40.966331362724304, 44.40377131104469, 44.48974169790745, 42.006571143865585, 43.986093923449516, 41.99038781225681, 40.49599640071392, 43.2729671895504, 42.425221279263496, 42.044645100831985, 42.28790044784546, 41.542764231562614, 42.75331847369671, 42.04910606145859, 43.10991793870926, 45.06117403507233, 45.838350132107735, 44.15968380868435, 45.03237918019295, 43.04742269217968, 44.64845158159733, 47.502159252762794, 56.287652626633644, 54.290886372327805, 58.00812430679798, 54.979474022984505, 51.32591687142849, 33.308948054909706, 28.726532645523548, 55.260218158364296, 57.74122662842274, 60.05490727722645, 56.517323702573776, 56.710383743047714, 55.465224757790565, 55.433264672756195, 54.79104593396187, 49.158079996705055, 43.16143557429314, 40.7329098880291, 40.450011268258095, 40.85513032972813, 40.31202167272568, 39.84391339123249, 38.70585545897484, 40.705251172184944, 37.40741953253746, 40.18617242574692, 38.89242544770241, 38.76798212528229, 39.54889342188835, 39.00611534714699, 37.22030617296696, 39.07989598810673, 37.94454351067543, 37.71020248532295, 36.499104872345924, 37.70435079932213, 37.46898002922535, 37.61251352727413, 37.690508142113686, 36.23853385448456, 36.1513627320528, 37.29341045022011, 38.11186373233795, 37.35349282622337, 37.21341334283352, 38.44671696424484, 38.75686012208462, 38.526056706905365, 39.70377691090107, 41.73866651952267, 43.43292720615864, 44.05532620847225, 46.7084426432848, 46.53022460639477, 48.76662500202656, 49.64866027235985, 53.98400343954563, 53.00150915980339, 49.549117013812065, 50.59160627424717, 49.06595014035702, 6.0328830778598785, 0.22515874385135248, 1.2411228893324733, 2.4563399562612176, 3.9213287830352783, 0.7026311627123505, 16.49520367383957, 67.70188674330711, 29.235545732080936, 22.95340932905674, 24.802669398486614, 41.750396490097046, 15.857543740421534, 0.28322178055532277, 0.09208435527398251, 0.03750990246771835, 0.028169220677227713, 0.06537388151627965, 0.019216350010538008, 0.059910015916102566, 0.0657018439960666, 0.06599361935514025, 0.0772077008150518, 0.03073171745199943, 0.06709417983074673, 0.02696500814636238, 0.04148785112192854, 0.012360055807221215, 0.03288145024271216, 0.04432396475749556, 0.04225391079671681, 0.01815413445001468, 0.01826392221119022, 0.03971056328737177, 0.10283153678756207, 0.09336416667792946, 0.04739137242722791, 0.04164972837315872, 0.06963046209421009, 0.0385540300339926, 0.060612892848439515, 0.06083941858378239, 0.03585264959838241, 0.09561645128997043, 0.03127239615423605, 0.018737063619482797, 0.036691814530058764, 0.025495524205325637, 0.04343838219938334, 0.07315913680940866, 0.05608414074231405, 0.004863694948653574, 0.12757073272950947, 1.2562299286946654, 38.60304057598114, 52.02354043722153, 37.21028991043568, 48.490862399339676, 40.63135653734207, 54.020424485206604, 52.96488292515278, 1.7993835895322263, 1.1113133048638701, 5.640907511115074, 4.747038725763559, 2.5511451065540314, 0.514134558616206, 11.777657065540552, 66.89310014247894, 62.343691661953926, 65.635686814785, 59.48260098695755, 60.305925607681274, 55.626909881830215, 52.674042731523514, 49.40705023705959, 51.50431349873543, 47.61476621031761, 48.17870154976845, 45.145457312464714, 51.19235783815384, 52.35585160553455, 51.430016085505486, 52.86315098404884, 56.4425703138113, 54.947711527347565, 55.45088432729244, 57.41801597177982, 59.65138033032417, 58.25706034898758, 59.235682636499405, 58.38442571461201, 50.73867358267307, 42.8358044475317, 45.02935454249382, 45.13767533004284, 44.607425183057785, 46.19951695203781, 45.29491849243641, 42.116685435175896, 44.21730011701584, 43.962698578834534, 42.91747346520424, 44.81955260038376, 41.598279252648354, 43.40242624282837, 43.92208635807037, 44.26797039806843, 45.648341327905655, 46.53592810034752, 46.209278628230095, 46.62110432982445, 45.67998602986336, 45.55929310619831, 48.8500951230526, 57.957226037979126, 56.80679976940155, 59.36808653175831, 54.01219792664051, 51.98669381439686, 35.95351114869118, 31.697114445269108, 58.84210355579853, 57.33880542218685, 60.541923344135284, 57.21067249774933, 58.68139497935772, 58.73873010277748, 57.21956022083759, 55.584298968315125, 50.171785801649094, 43.86942878365517, 42.19980977475643, 41.37795187532902, 43.484984412789345, 41.07072316110134, 42.07697756588459, 41.47993080317974, 41.43548458814621, 39.16577138006687, 42.2261081635952, 41.81367449462414, 40.44865854084492, 40.15079252421856, 39.83225181698799, 39.24157351255417, 39.2533490806818, 39.69055362045765, 40.537041798233986, 40.26437982916832, 39.8332055658102, 39.56152394413948, 38.250415697693825, 39.46190848946571, 38.75917799770832, 38.45643684267998, 37.85178668797016, 39.52663041651249, 37.909448593854904, 39.69287529587746, 39.76911440491676, 42.28465162217617, 40.59851489961147, 43.74566562473774, 44.689154997467995, 46.071346029639244, 46.27319499850273, 49.99219983816147, 48.28881964087486, 52.67403893172741, 53.29671531915665, 56.86275936663151, 53.625933453440666, 51.90517298877239, 49.91268910467625, 50.92656970024109, 6.940794484689832, 0.6264383043162525, 3.654226865619421, 4.705222919583321, 2.3519350960850716, 0.6409292423631996, 17.90611356496811, 70.52211061120033, 33.30383352935314, 33.23910400271416, 25.890150144696236, 45.80767057836056, 21.03448759764433, 0.49053663737140596, 0.07196584498160519, 0.06434356531826779, 0.11772191355703399, 0.03249647226766683, 0.03136486775474623, 0.04807169178093318, 0.08499453688273206, 0.05794509830593597, 0.013370179094636114, 0.034775767344399355, 0.03886095262714662, 0.016596021378063597, 0.013630040248244768, 0.06527013669256121, 0.06642204636591487, 0.04803034302312881, 0.01122713490985916, 0.18032388092251495, 0.10094765428220853, 0.13442234398098662, 0.16537741263164207, 0.13741532166022807, 0.1709561367169954, 0.1685265827109106, 0.23036100610625, 0.11442446979344822, 0.16181079932721332, 0.15834027930395678, 0.15685015066992491, 0.12900520028779283, 0.08463126301649027, 0.11755306753912009, 0.07944943950860761, 0.07703359297011048, 0.10432346141897142, 0.2484603997436352, 0.19918399077141657, 0.10772636436740868, 0.4374118958367035, 1.1417274666018784, 42.940785214304924, 62.679487243294716, 45.630470886826515, 55.2391254901886, 44.96100381016731, 58.19240681827068, 61.264469772577286, 3.062805701047182, 5.754635883495212, 10.90375715866685, 6.344300117343664, 2.960572661831975, 0.31419605598784983, 11.951189953833818, 69.92244198918343, 66.00565016269684, 69.40196871757507, 63.080118745565414, 65.52142694592476, 58.68499718606472, 55.90744502842426, 52.28940077126026, 54.60162229835987, 50.913798585534096, 52.44146101176739, 48.77548612654209, 55.09984016418457, 54.61919255554676, 53.931216672062874, 54.218872636556625, 58.57829891145229, 57.4847137928009, 60.73151417076588, 59.834857285022736, 62.954037711024284, 58.64834435284138, 62.90625527501106, 58.89965146780014, 54.51221689581871, 44.629061222076416, 47.04963393509388, 47.52077825367451, 45.91768227517605, 49.30135890841484, 47.429674342274666, 43.61843325197697, 46.88497357070446, 45.49408480525017, 46.03343166410923, 46.81005299091339, 44.89700764417648, 47.10386462509632, 47.6950217038393, 46.483452916145325, 50.09012818336487, 50.43180204927921, 48.953939750790596, 49.728740975260735, 48.557826206088066, 47.487051263451576, 50.97814433276653, 58.53154622018337, 57.74602957069874, 61.69043831527233, 57.55217157304287, 51.60224564373493, 41.392296105623245, 39.68749858438969, 56.28843538463116, 59.22999054193497, 63.01683694124222, 60.86571156978607, 59.67954441905022, 60.521541237831116, 57.12934926152229, 56.791566386818886, 51.113006696105, 47.032633647322655, 45.93782499432564, 43.93773011863232, 45.339702889323235, 45.02039462327957, 44.10011440515518, 44.80213053524494, 44.0690016746521, 40.71846306324005, 45.751783177256584, 43.68288919329643, 43.33253279328346, 43.73642452061176, 43.35896797478199, 41.2932126224041, 41.80839657783508, 41.372556164860725, 42.69574776291847, 42.40236170589924, 43.11121366918087, 43.00264209508896, 40.58410607278347, 41.63943484425545, 40.563237592577934, 39.56121236085892, 42.99370117485523, 42.926148399710655, 41.145871728658676, 41.910854279994965, 43.46789672970772, 44.42326806485653, 41.23792938888073, 44.18801508843899, 47.227479591965675, 48.85209761559963, 49.292452186346054, 52.42367036640644, 48.77881474792957, 54.33649152517319, 55.519660636782646, 57.75169886648655, 57.57744021713734, 53.01271475851536, 50.27459688484669, 50.389168336987495, 8.574924822896719, 0.4744601750280708, 3.857003222219646, 7.4272857047617435, 11.024070102721453, 1.6030535870231688, 21.19586493819952, 78.99551913142204, 38.56097303330898, 38.71928013861179, 33.09016339480877, 55.79529024660587, 26.947099529206753, 0.5951121321413666, 0.19797636807197705, 0.20104690018342808, 0.20725359994685277, 0.18976303457748145, 0.1083847829431761, 0.1214622042607516, 0.19867208698997274, 0.28643332072533667, 0.12675960984779522, 0.11689987368299626, 0.1678508275654167, 0.12523381359642372, 0.07479911990230903, 0.14923115872079507, 0.1972580433357507, 0.09449433884583414, 0.13364357873797417], [0.026365581034042407, 0.02839087235770421, 0.06913222867297009, 0.027743957070924807, 0.08014087623450905, 0.07014914168394171, 0.01833363770856522, 0.031697271988377906, 0.00831606343126623, 0.04686703396146186, 0.04761013900861144, 0.026677418500185013, 0.022615805683017243, 0.02133179372322047, 0.0711387288174592, 0.035905349504901096, 0.018385033290542196, 0.04866431525442749, 0.04710347107902635, 0.009438469951419393, 0.09701145885628648, 0.1676720887189731, 0.22158061241498217, 4.381894469261169, 39.87917549908161, 32.332259863615036, 35.52646726369858, 39.40462276339531, 34.11695569753647, 60.275090262293816, 14.462465699762106, 0.22872275963891298, 4.38504402525723, 2.501687672920525, 1.5227859816513956, 0.2070440471288748, 0.26567470806185156, 28.052716702222824, 70.21540626883507, 58.67370419204235, 63.40525969862938, 53.28759580850601, 55.8336415886879, 49.798775017261505, 49.553266391158104, 47.11091324687004, 47.504226341843605, 44.93229255080223, 48.024988397955894, 48.311948999762535, 49.50563594698906, 50.36142982542515, 52.35165663063526, 52.84637488424778, 55.98059110343456, 52.48632900416851, 55.44159382581711, 55.95525786280632, 58.849448561668396, 58.823978528380394, 56.2840162217617, 49.254970997571945, 42.80430033802986, 43.275064677000046, 43.0279715359211, 43.14910523593426, 44.522891119122505, 43.383522257208824, 42.866901978850365, 43.48222196102142, 40.30002951622009, 40.532873421907425, 42.98076666891575, 42.4137306958437, 41.56766049563885, 42.59151555597782, 46.73405706882477, 50.52118845283985, 48.75304073095322, 47.65453867614269, 48.16518187522888, 45.97984313964844, 43.49572263658047, 45.42660042643547, 51.253511756658554, 56.29153981804848, 56.11101150512695, 58.1582922488451, 57.70265489816666, 52.854852229356766, 33.69446016848087, 46.302225440740585, 57.872194200754166, 57.22734600305557, 56.987825855612755, 56.744855493307114, 55.35167545080185, 53.285011947155, 50.75898349285126, 45.743062645196915, 40.48436142504215, 39.31974671781063, 39.33255963027477, 39.78788539767265, 40.873574540019035, 37.9061009734869, 38.620667830109596, 39.79026786983013, 39.99543786048889, 40.42801424860954, 38.67582567036152, 38.91228698194027, 39.576020166277885, 38.09652775526047, 38.958906680345535, 39.14047613739967, 37.756210416555405, 38.765785843133926, 36.62733279168606, 36.65996544063091, 36.69547073543072, 37.887899950146675, 36.92719750106335, 38.09488624334335, 38.666842952370644, 38.206064477562904, 35.932319685816765, 36.32050305604935, 39.33017335832119, 38.6535968631506, 39.692856296896935, 39.63722728192806, 39.35258835554123, 41.452150493860245, 42.27602228522301, 42.88488261401653, 40.67448802292347, 45.52826777100563, 46.31847716867924, 50.41974529623985, 52.69833102822304, 55.93976989388466, 48.93144875764847, 54.17771704494953, 21.397461220622063, 0.23993125272681937, 0.508598790038377, 1.6744726547040045, 3.8751102006062865, 2.2392390808090568, 0.08193308865884319, 36.0440830886364, 51.68345108628273, 28.33304475992918, 20.588486529886723, 24.91916734725237, 40.197241231799126, 4.018995417281985, 0.056486340254195966, 0.03478083621303085, 0.008273875118902652, 0.017835101862146985, 0.05817929042677861, 0.02767077759926906, 0.04096046613994986, 0.07467106974218041, 0.054663955816067755, 0.03527700275299139, 0.010773351496027317, 0.054409755393862724, 0.0543716052925447, 0.005489626009875792, 0.022928880680410657, 0.06275430801906623, 0.02444760611979291, 0.03580727097869385, 0.04100835692952387, 0.10191260953433812, 0.04889511576038785, 0.06333048921078444, 0.04782165109645575, 0.08622962646768428, 0.03124329654383473, 0.06766301376046613, 0.029339003122004215, 0.06603702757274732, 0.015612165479979012, 0.028464918286772445, 0.02237941309431335, 0.04075112483405974, 0.03362416195159312, 0.058292278699809685, 0.07538839257904328, 0.06810973471147008, 0.034498686509323306, 0.035191878414480016, 0.05626077931083273, 0.19129476801026613, 0.29394142096862197, 8.878934159874916, 50.737396851181984, 37.06519469618797, 38.95040273666382, 46.47569753229618, 40.37176586687565, 66.51211738586426, 12.71038731560111, 0.636509545147419, 3.1006796937435865, 3.3260790864005685, 6.382797276601195, 0.9780037519522011, 0.36170279898215085, 31.866019181907177, 70.39727210998535, 61.37944780290127, 63.51304851472378, 56.83417730033398, 57.73143455386162, 52.483836337924004, 53.08339096605778, 49.1634339094162, 50.3488676995039, 46.671060249209404, 48.34875762462616, 51.22743375599384, 52.376013323664665, 53.81438434123993, 55.09637475013733, 55.298812687397, 57.50706799328327, 55.51982022821903, 58.16976763308048, 56.6782982647419, 58.7717617303133, 59.47079502046108, 57.81630299985409, 50.721027329564095, 44.35300223529339, 44.09535326063633, 45.06243176758289, 45.16086168587208, 46.569461300969124, 45.2043579518795, 44.99974653124809, 44.65984337031841, 42.99878150224686, 43.84580925107002, 44.239540323615074, 43.44797819852829, 43.72293524444103, 45.34240074455738, 49.566884860396385, 50.2819836884737, 51.40348210930824, 49.81476455926895, 49.34396222233772, 46.33233122527599, 45.84107078611851, 46.22749485075474, 54.50254261493683, 58.911617025732994, 57.593577951192856, 59.03937757015228, 59.6600666642189, 51.63263261318207, 32.666064351797104, 49.54735770821571, 60.53727239370346, 58.91022250056267, 57.91605904698372, 57.66518130898476, 58.5823342949152, 56.87097452580929, 54.416522830724716, 49.266871958971024, 44.305424988269806, 42.47371427714825, 40.69493092596531, 42.63178959488869, 42.15217553079128, 40.60389161109924, 40.131356567144394, 40.32006964087486, 40.37278801202774, 41.12094886600971, 40.71537382900715, 39.80037532746792, 42.75083340704441, 39.62672844529152, 41.354324743151665, 40.84221862256527, 40.24535425007343, 39.652981236577034, 38.24788123369217, 38.33562612533569, 39.26322095096111, 39.17818911373615, 38.71813639998436, 40.57071939110756, 39.97342184185982, 39.841139540076256, 38.49651329219341, 38.478464260697365, 41.87974914908409, 40.68278297781944, 42.243442833423615, 41.69643938541412, 43.44011642038822, 43.01761709153652, 44.416808411478996, 44.479577243328094, 42.65035159885883, 47.011822164058685, 49.6770865470171, 51.23505614697933, 54.98045817017555, 58.050951808691025, 49.53221932053566, 54.794070571660995, 23.007326535880566, 0.35386619449127465, 2.61549417860806, 5.548599539324641, 4.710435764864087, 2.2760667046532035, 0.016177166216948535, 39.21689383685589, 58.97554099559784, 35.6239016354084, 25.315396785736084, 24.868229180574417, 50.479645282030106, 6.138486536219716, 0.07156456573284231, 0.09085926983971149, 0.07013713373453356, 0.11738172790501267, 0.04066700239491183, 0.03908934857463464, 0.07851696063880809, 0.034366691834293306, 0.05402248047175817, 0.07506077890866436, 0.1362880735541694, 0.04829915633308701, 0.05731479970563669, 0.015567785048915539, 0.02788880759908352, 0.03358777074026875, 0.062448335374938324, 0.03045331559405895, 0.09245210429071449, 0.16520015808055177, 0.17201075825141743, 0.1780234754551202, 0.11219109510420822, 0.24268983048386872, 0.20660015376051888, 0.1567698354483582, 0.13706041179830208, 0.15114966983674094, 0.1126567333994899, 0.1088968722615391, 0.0995096392580308, 0.13997847709106281, 0.13455980457365513, 0.1761721435468644, 0.24448045471217483, 0.14813766349107027, 0.20867911720415577, 0.18586349382530898, 0.18421847897116095, 0.3360875422367826, 0.3710475662956014, 8.511615470051765, 59.17171306908131, 44.25305999815464, 48.020280450582504, 51.827638149261475, 45.119071528315544, 71.40180140733719, 18.217406161129475, 1.4795802813023329, 13.926634602248669, 8.534805625677109, 10.93633471056819, 0.4729413549648598, 0.32041005848441273, 31.50073528289795, 74.70763921737671, 64.65961799025536, 68.11763763427734, 58.73955845832825, 60.13252191245556, 54.480260610580444, 56.100919246673584, 51.4626981317997, 55.13662979006767, 49.815813302993774, 51.047403216362, 54.06639061868191, 53.94740380346775, 56.191115006804466, 57.62462608516216, 56.383867263793945, 62.7774041891098, 57.35997408628464, 61.324316561222076, 59.40570831298828, 60.23713789880276, 61.79363697767258, 60.37607744336128, 53.299356177449226, 47.069712057709694, 47.27021209895611, 46.93040393292904, 46.453928500413895, 49.00696590542793, 47.402027025818825, 45.913023725152016, 48.01964968442917, 44.08661372959614, 47.30284094810486, 46.64621338248253, 46.07846684753895, 45.63985638320446, 46.0024481266737, 51.85059651732445, 54.55896198749542, 54.04912814497948, 51.45276166498661, 51.062355414032936, 50.38240469992161, 49.556868597865105, 49.24123853445053, 55.76399512588978, 60.80812186002731, 60.362523570656776, 61.34266197681427, 61.90160818397999, 55.47628976404667, 38.92258062958717, 49.78146314620972, 61.51214428246021, 61.49194456636906, 59.24315303564072, 60.9283360093832, 61.31906524300575, 56.94538213312626, 56.78135633468628, 51.18010349571705, 46.09739363193512, 45.54628260433674, 43.256540670990944, 44.524091854691505, 44.596679359674454, 42.19022288918495, 42.10527464747429, 42.89303697645664, 42.53302909433842, 45.56027725338936, 43.99032309651375, 40.23172818124294, 44.28087830543518, 41.36540114879608, 43.750635758042336, 43.94039757549763, 41.876811906695366, 42.524194568395615, 40.379430055618286, 42.089946269989014, 41.81331351399422, 42.77741678059101, 40.30838146805763, 42.54343293607235, 42.04853989183903, 41.46572716534138, 39.12826359272003, 40.952758491039276, 44.660626128315926, 43.802936151623726, 45.209514275193214, 45.17526291310787, 45.40814481675625, 46.239703595638275, 47.305709794163704, 48.315995782613754, 44.89057458937168, 48.43110300600529, 51.77661828696728, 53.64573799073696, 59.29617919027805, 60.70429243147373, 51.99370063841343, 54.914550706744194, 25.72213266044855, 0.537516544573009, 2.008197228424251, 7.655529957264662, 11.938938461244106, 8.186932392418385, 0.11743230526917614, 43.939641416072845, 64.66151028871536, 41.59485563635826, 32.339984849095345, 35.22276856005192, 60.278407484292984, 7.883985573425889, 0.34303591470234096, 0.34958171658217907, 0.18886098376242444, 0.2336488984292373, 0.2073117991676554, 0.1729690787033178, 0.1887474351678975, 0.20168036775430664, 0.1685530031681992, 0.19948038971051574, 0.1451384072424844, 0.13516107777832076, 0.22205390967428684, 0.161399174539838, 0.1389660986023955, 0.1481246462208219, 0.19398368778638542, 0.15828384639462456], [0.021353290030674543, 0.026827007641259115, 0.030220418520912062, 0.08161924182786606, 0.03318454706459306, 0.09424680290976539, 0.05849783876328729, 0.07565322797745466, 0.01624794298550114, 0.013766573156317463, 0.02248994856927311, 0.06371410534484312, 0.031406164562213235, 0.02245397296064766, 0.04573616046400275, 0.030273242737166584, 0.057251346079283394, 0.02241729416709859, 0.0682663352927193, 0.033517886404297315, 0.045968423000886105, 0.02172792432247661, 0.011781086923292605, 0.13335621915757656, 16.638482585549355, 45.009181424975395, 35.00109225511551, 45.21084800362587, 29.31667897850275, 48.43506999313831, 43.10821942985058, 0.5616607458796352, 2.1515212627127767, 4.066708507016301, 3.503537639044225, 1.0929404594935477, 0.12956118764122948, 2.697636508382857, 61.02094084024429, 61.24243475496769, 63.240329548716545, 55.9649283438921, 58.23823995888233, 53.257490023970604, 51.793732568621635, 47.096819803118706, 47.290035635232925, 46.22880958020687, 48.99461276829243, 48.111049979925156, 50.388712361454964, 50.77718451619148, 52.58105032145977, 56.03334367275238, 55.887518897652626, 56.4383677393198, 59.823237508535385, 56.69276408851147, 58.05181436240673, 59.13483984768391, 55.95736674964428, 46.4189437776804, 43.28459456562996, 42.87406459450722, 44.26152594387531, 42.64341697096825, 43.41914154589176, 43.26286733150482, 44.55093361437321, 44.954384565353394, 43.04304912686348, 41.402859538793564, 42.443536296486855, 40.663799196481705, 41.687118485569954, 46.12452417612076, 51.57018296420574, 53.521845638751984, 54.67797540128231, 51.95943407714367, 50.51021844148636, 49.00595135986805, 46.458663046360016, 45.45902408659458, 44.65942919254303, 49.106843546032906, 53.46513748168945, 55.87455779314041, 57.325585931539536, 55.9527537971735, 48.90481598675251, 47.80981354415417, 59.218883737921715, 57.26419262588024, 57.33566679060459, 54.78783890604973, 53.23790967464447, 46.986800506711006, 46.7985700070858, 41.26991607248783, 39.33496870100498, 40.141175240278244, 40.58518901467323, 40.41626527905464, 42.213181257247925, 38.83885592222214, 40.52028849720955, 40.35639949142933, 38.3695051074028, 36.88924893736839, 38.92445392906666, 37.76386320590973, 38.93863096833229, 38.22257459163666, 39.23621580004692, 37.48870477080345, 36.96283958852291, 38.762791603803635, 39.15563352406025, 39.237959906458855, 38.91357511281967, 37.83615432679653, 39.10848565399647, 37.440960332751274, 37.345133274793625, 38.646194860339165, 39.690154641866684, 38.322114050388336, 37.72648461163044, 37.14823544025421, 40.59967763721943, 41.377906277775764, 42.254401445388794, 43.099624291062355, 43.87235842645168, 42.687354013323784, 43.83284814655781, 44.61765043437481, 47.43945121765137, 49.288112819194794, 55.16225941479206, 50.813666358590126, 49.70734052360058, 46.43654443323612, 6.181244691833854, 0.27314768987707794, 1.7958794650621712, 3.7161918031051755, 4.041131129488349, 0.411956527386792, 0.8896567113697529, 48.19746874272823, 39.91457439959049, 25.445241518318653, 27.12843719869852, 37.82370239496231, 24.27099622786045, 0.043031733512179926, 0.06040998596290592, 0.05343409466149751, 0.052283539407653734, 0.10077298982650973, 0.048467048691236414, 0.010586636417428963, 0.04227410834573675, 0.04009899224911351, 0.036034783770446666, 0.05756830250902567, 0.05013085472455714, 0.0340633315499872, 0.07831851035007276, 0.09527115224045701, 0.1161111042893026, 0.08126229848130606, 0.016922863214858808, 0.02188409631344257, 0.06916041544172913, 0.02586578168120468, 0.0348000133089954, 0.01840391538280528, 0.004962186758348253, 0.01683959795627743, 0.02319024468306452, 0.13162486284272745, 0.01803797720640432, 0.024404168216278777, 0.051466490476741455, 0.04775519548275042, 0.07204932175227441, 0.032017089397413656, 0.01676008054346312, 0.013600855290860636, 0.025778775998333003, 0.028019542478432413, 0.029960874635435175, 0.01891627372970106, 0.06930566116352566, 0.025184126461681444, 0.025177406314469408, 0.3635647881310433, 25.33072516322136, 49.406195282936096, 36.45674854516983, 52.98026069998741, 33.97302322089672, 55.77652305364609, 43.29652972519398, 0.1785792104783468, 0.9337467548903078, 2.191315102390945, 5.250703124329448, 3.477801620028913, 0.2388991924817674, 4.11777064204216, 65.57889506220818, 61.86333283782005, 65.86645603179932, 59.54934060573578, 59.86728094518185, 53.96294876933098, 53.47699284553528, 49.30551968514919, 48.59472222626209, 48.634547889232635, 51.54019497334957, 49.84875753521919, 53.530980348587036, 51.52496159076691, 55.73003634810448, 58.35199825465679, 58.55839937925339, 56.984713822603226, 62.53410704433918, 60.68329095840454, 57.761574536561966, 59.40695084631443, 61.647086441516876, 49.824252650141716, 44.682645946741104, 44.16259445250034, 44.77313809096813, 43.870781511068344, 45.80456614494324, 44.64754343032837, 46.406963020563126, 46.21346600353718, 44.153539538383484, 43.6393853276968, 45.26550807058811, 42.28840582072735, 43.28196510672569, 46.64467066526413, 53.96970480680466, 55.69320112466812, 55.740402191877365, 53.343859389424324, 52.03876622021198, 50.34069053828716, 47.42278531193733, 46.489353999495506, 47.23732486367226, 51.8334898352623, 55.92332437634468, 58.60050491988659, 59.10845026373863, 57.94745676219463, 47.46102645993233, 46.848069950938225, 59.865282252430916, 58.76985803246498, 57.901228442788124, 56.928913816809654, 54.95705142617226, 49.9014987051487, 48.590667843818665, 41.81445725262165, 40.413138046860695, 41.063815131783485, 41.75375550985336, 41.045180931687355, 43.95905837416649, 41.317485719919205, 41.48722641170025, 41.959579065442085, 41.5233700722456, 40.37581264972687, 41.47361174225807, 40.023396760225296, 40.57635448873043, 39.87739339470863, 41.231572329998016, 40.76444059610367, 40.23904278874397, 40.60910113155842, 41.01408340036869, 41.832038909196854, 38.96901033818722, 38.41897465288639, 39.15092557668686, 39.902605041861534, 39.75315906107426, 41.10228046774864, 40.75019136071205, 40.20854942500591, 39.25185576081276, 40.966958329081535, 41.33700527250767, 43.03536593914032, 43.19285228848457, 45.24799481034279, 44.94417071342468, 45.17525531351566, 45.88261015713215, 47.377039566636086, 50.060197189450264, 52.199759781360626, 56.50298707187176, 54.02488924562931, 51.171876937150955, 48.78191538155079, 6.352818310260773, 0.6446563079953194, 6.344605525955558, 7.212575376033783, 3.5713559249415994, 0.6872962543275207, 1.2842980725690722, 52.99541428685188, 46.40905290842056, 33.88357222080231, 25.440605767071247, 43.1146714836359, 32.36474432051182, 0.2581533679040149, 0.02220027905423194, 0.04276333209418226, 0.055517121363664046, 0.033263778750551865, 0.01235663543411647, 0.01952512055140687, 0.037871855311095715, 0.02051326235232409, 0.030277053665486164, 0.02362742347031599, 0.04097809214727022, 0.04540090638329275, 0.0333431366016157, 0.03618892042140942, 0.016963310263236053, 0.10292359278537333, 0.03653840518381912, 0.03483566237264313, 0.1900622239918448, 0.10946958762360737, 0.15595023724017665, 0.1778351777466014, 0.08724494386115111, 0.15290878247469664, 0.15976074995705858, 0.2023909889976494, 0.094622158940183, 0.10529420542297885, 0.10721568512963131, 0.13436276436550543, 0.1368713570991531, 0.10456277435878292, 0.11293295334326103, 0.11583570812945254, 0.10466952488059178, 0.10072523262351751, 0.149642382748425, 0.15012607007520273, 0.19078927638474852, 0.08102839579805732, 0.06186610939039383, 0.33874101703986526, 26.991418451070786, 61.96709766983986, 41.87545917928219, 61.58446580171585, 38.305459544062614, 59.41350929439068, 52.34670549631119, 0.43491121439728886, 8.8831433840096, 13.086091205477715, 9.705406911671162, 3.431799625977874, 0.2486294016125612, 4.447213914245367, 66.47062361240387, 63.868128061294556, 67.96237796545029, 61.44472450017929, 63.185893669724464, 58.60259860754013, 56.938295513391495, 51.84414066374302, 51.290719360113144, 50.415588319301605, 53.447996601462364, 52.59591892361641, 55.79636558890343, 53.575046584010124, 56.95861682295799, 62.43640288710594, 61.77203133702278, 59.61668819189072, 63.56963887810707, 62.35547102987766, 60.18028914928436, 61.84691771864891, 63.488342240452766, 51.57354958355427, 46.831100061535835, 46.75319664180279, 46.543375700712204, 46.235219836235046, 48.353435173630714, 46.47280968725681, 47.749734967947006, 48.43524098396301, 46.10564298927784, 46.03398643434048, 47.377202957868576, 44.736044481396675, 45.33055678009987, 49.84759099781513, 55.81398904323578, 57.5627426058054, 59.387788474559784, 55.08200392127037, 56.68551407754421, 52.946906089782715, 49.83548104763031, 48.00542324781418, 48.60254980623722, 52.628509774804115, 58.891698494553566, 60.64545638859272, 61.12081468105316, 57.42778904736042, 50.57973571121693, 48.534313067793846, 62.77078114449978, 59.92232859134674, 59.67530384659767, 57.53278121352196, 56.8032431602478, 50.57554833590984, 49.983878284692764, 43.45202878117561, 42.38236717879772, 43.84632222354412, 44.46938619017601, 43.153296411037445, 47.633985579013824, 41.63663059473038, 44.42492477595806, 45.06815426051617, 43.571859151124954, 40.90800829231739, 43.98867778480053, 42.86589503288269, 42.35943540930748, 40.830097272992134, 44.76868472993374, 41.68596334755421, 40.64696989953518, 43.5681277513504, 43.84567245841026, 45.65174214541912, 42.61599384248257, 40.97345598042011, 42.619789838790894, 41.873319894075394, 41.45076736807823, 43.89927998185158, 43.67084763944149, 41.35821953415871, 41.30618892610073, 42.54505164921284, 44.89318124949932, 45.25947019457817, 45.951344668865204, 47.31272041797638, 49.82056684792042, 47.30111204087734, 47.59372293949127, 49.79489542543888, 52.14946947991848, 52.711877301335335, 59.831084087491035, 56.82506538927555, 53.243658766150475, 50.115328431129456, 8.443770110607147, 0.4210420179879293, 8.31549184396863, 11.54815698042512, 7.466418379917741, 1.975552230142057, 1.2163074896670878, 58.7246822565794, 50.00227689743042, 39.32584539055824, 38.014349564909935, 52.746702432632446, 40.77354870736599, 0.49595811520703137, 0.15671307599404827, 0.17854857462225482, 0.2156172480317764, 0.12775793205946684, 0.12898145156214014, 0.1454851683229208, 0.14783537189941853, 0.07330243810429238, 0.13880711572710425, 0.1791058384696953, 0.11189996541361324, 0.14628582692239434, 0.15183600800810382, 0.16691518714651465, 0.22262019803747535, 0.20532754861051217, 0.15373261092463508, 0.1130740281951148], [0.04662491941417102, 0.023902151697257068, 0.0492789619602263, 0.09629601365304552, 0.03303060708276462, 0.04839520879613701, 0.018222465841972735, 0.024185153015423566, 0.07069030834827572, 0.013729122529184679, 0.04452222950931173, 0.025431543654121924, 0.07933989851153456, 0.007593426817038562, 0.03508598878397606, 0.032710303567000665, 0.0736534442694392, 0.09352342414786108, 0.042632892218534835, 0.02795150052406825, 0.0038320637577271555, 0.02617882699269103, 0.06778803595807403, 0.1181839375931304, 2.6442161248996854, 39.6405179053545, 36.65551207959652, 32.79415927827358, 40.346835404634476, 31.00898467004299, 65.860186368227, 5.022949995473027, 1.2626974191516638, 0.957047282718122, 6.876764120534062, 4.212070181965828, 0.5680325883440673, 0.5699916800949723, 16.859777010977268, 71.59866884350777, 57.33505882322788, 61.76127791404724, 55.917985662817955, 56.10268235206604, 49.684860929846764, 51.505495235323906, 45.767917111516, 51.08298450708389, 51.2333994358778, 52.22850903868675, 48.443551138043404, 54.58289310336113, 55.11584110558033, 56.1986044049263, 56.59600228071213, 58.1241624802351, 58.400073274970055, 59.37044620513916, 60.18148608505726, 55.97558297216892, 51.92377679049969, 46.691168770194054, 45.34419044852257, 41.883260160684586, 44.627267718315125, 43.75241406261921, 43.238807022571564, 43.30673597753048, 45.97275272011757, 42.71562449634075, 43.278982266783714, 41.50657117366791, 41.87383286654949, 42.79526062309742, 42.36436374485493, 51.38935066759586, 55.81335827708244, 55.40733106434345, 56.92465804517269, 55.53065724670887, 58.55435259640217, 55.20743519067764, 51.532154604792595, 47.40250200033188, 44.43331852555275, 46.06932833790779, 49.66969594359398, 52.0121106505394, 55.63302755355835, 56.60366266965866, 56.086780205368996, 53.22063960134983, 57.500391751527786, 56.12317845225334, 56.00714407861233, 52.168476060032845, 49.240942150354385, 45.229656994342804, 42.89125107228756, 40.72620704770088, 42.96341300010681, 43.572888895869255, 46.153068244457245, 42.25194677710533, 40.54992310702801, 38.97856682538986, 41.46139159798622, 40.125295892357826, 39.05713140964508, 40.35755082964897, 38.23764458298683, 38.68952393531799, 40.9609280526638, 39.79329250752926, 39.326430559158325, 38.18279832601547, 39.07388471066952, 38.38004574179649, 37.788634076714516, 37.23660729825497, 37.98381820321083, 38.09865564107895, 38.179807886481285, 37.569769620895386, 39.40537132322788, 37.80932016670704, 36.486037373542786, 38.361901715397835, 39.35955338180065, 37.24570021033287, 41.04494534432888, 46.09095677733421, 48.009793013334274, 44.487492218613625, 50.038340762257576, 46.25522956252098, 49.76826645433903, 48.7338175624609, 54.301898181438446, 50.13713926076889, 56.44413203001022, 50.03239028155804, 56.8855619430542, 29.165040515363216, 0.5474973027594388, 0.7957887451630086, 4.734421977773309, 4.330926379188895, 3.467216338030994, 1.068464310374111, 6.819538716226816, 60.82622028887272, 26.69650487601757, 34.990395829081535, 27.347305454313755, 36.59138672053814, 12.509900573641062, 0.15638059383491054, 0.0929563120007515, 0.052802129939664155, 0.09973465101211332, 0.06483846649643965, 0.045262904022820294, 0.08563978975871578, 0.02100329875247553, 0.025672693409433123, 0.08176664719940163, 0.1971620539552532, 0.0625632717856206, 0.08159402364981361, 0.08720958794583566, 0.06920063984580338, 0.015890641552687157, 0.004268051397957606, 0.050138814258389175, 0.07478216182789765, 0.028632508219743613, 0.054240742392721586, 0.0797885045176372, 0.03996919433120638, 0.06674026444670744, 0.07391192688373849, 0.02088984849251574, 0.04383090781630017, 0.09520777282887138, 0.0098881669146067, 0.0168227623362327, 0.027413417483330704, 0.06968910660361871, 0.058758974555530585, 0.030254483099270146, 0.026514325982134324, 0.04985086095985025, 0.03564750142686535, 0.0279333197613596, 0.0883571634767577, 0.010830353076016763, 0.06887992814881727, 0.08266999677289277, 0.09112924090004526, 5.340872285887599, 48.75386528670788, 38.45371998846531, 40.71605019271374, 47.2939608246088, 35.42047955095768, 71.01514935493469, 4.853406418114901, 1.086501230020076, 1.6974702081643045, 2.5522028747946024, 7.024606112390757, 1.125469682738185, 0.4734185559209436, 21.543567180633545, 74.1045355796814, 58.64694982767105, 64.15592461824417, 56.160063073039055, 57.361421808600426, 51.407813876867294, 54.84198600053787, 48.44276078045368, 51.931843757629395, 51.83084897696972, 54.19214107096195, 51.43583357334137, 56.65841393172741, 55.93905173242092, 57.29898735880852, 57.888160943984985, 61.370723471045494, 59.24923650920391, 59.43782418966293, 61.40937499701977, 59.707841500639915, 53.384859189391136, 49.83105048537254, 45.41462726891041, 45.03538101911545, 45.134654492139816, 46.11373655498028, 44.95495833456516, 44.94116887450218, 47.21984200179577, 44.72220942378044, 46.27397395670414, 43.56224186718464, 44.48689945042133, 44.60720479488373, 44.105099737644196, 52.818894758820534, 58.84103201329708, 56.29729650914669, 58.51408235728741, 56.36658199131489, 59.419585168361664, 54.419779255986214, 53.41610491275787, 50.004347786307335, 45.95604121685028, 48.31640236079693, 53.33527185022831, 54.23888236284256, 58.603229373693466, 55.845078974962234, 55.499498918652534, 55.240922793745995, 58.6810377985239, 58.23762819170952, 56.95748068392277, 54.26843337714672, 52.03451804816723, 48.30956652760506, 44.74899798631668, 42.86554165184498, 44.10085156559944, 44.42604951560497, 47.03383058309555, 44.39365245401859, 44.178580194711685, 41.94498024880886, 42.17866770923138, 41.747736632823944, 40.80018147826195, 39.92355331778526, 39.99769873917103, 39.881683364510536, 43.566011264920235, 42.22594857215881, 41.73280343413353, 40.170863047242165, 39.849594086408615, 41.777150854468346, 39.4465459138155, 38.80642466247082, 39.35551039874554, 40.07001645863056, 40.07733106613159, 38.89216706156731, 40.543961226940155, 41.063659340143204, 39.42123167216778, 40.02950683236122, 41.83344483375549, 40.61349369585514, 44.31384153664112, 47.64595873653889, 49.98059146106243, 45.83820194005966, 51.353043615818024, 48.65270331501961, 51.17994010448456, 48.603883534669876, 55.45287162065506, 52.540871277451515, 57.45104379951954, 53.035152554512024, 54.86415021121502, 30.166765563189983, 0.4308141436195001, 1.161848574411124, 9.33844255283475, 11.999682001769543, 2.5281470781192183, 1.4229412330314517, 6.790109295397997, 66.01849347352982, 32.186146304011345, 39.43100854754448, 30.221457928419113, 42.01966144144535, 17.863464653491974, 0.31423717096913606, 0.20921239483868703, 0.05807805406220723, 0.09899123426293954, 0.08696275705005974, 0.030333503273141105, 0.0015980948865035316, 0.04692662841989659, 0.0032328384168067714, 0.02292000088345958, 0.067769318993669, 0.07923269527964294, 0.05285984305373859, 0.06365105989971198, 0.025430502792005427, 0.014687644288642332, 0.00921619950531749, 0.019165692865499295, 0.04913938253594097, 0.10764650927740149, 0.14420957973925397, 0.18242948746774346, 0.1599548661033623, 0.15282149106496945, 0.14449067559326068, 0.09584211613400839, 0.07262758837896399, 0.13325209583854303, 0.11550099952728488, 0.20567065832437947, 0.1608895862591453, 0.3137869545025751, 0.14433620497584343, 0.14305050834082067, 0.10591970232781023, 0.13022028899285942, 0.0967134717211593, 0.17785966861993074, 0.2423991757677868, 0.10555962711805478, 0.3029973740922287, 0.18526708910940215, 0.2677220560144633, 4.578546267002821, 57.34499529004097, 48.26531410217285, 44.35835234820843, 53.93641859292984, 38.978585824370384, 78.74194353818893, 5.899331644177437, 2.5658113695681095, 2.751605249941349, 15.738608222454786, 15.722026862204075, 1.2917770212516189, 0.377333972719498, 20.45287750661373, 76.64239659905434, 60.73684148490429, 67.03650444746017, 59.71248485147953, 63.034224808216095, 53.73684570193291, 58.080776408314705, 50.20724929869175, 55.87311767041683, 54.68550659716129, 58.46990592777729, 53.12930770218372, 58.603639751672745, 57.898013815283775, 60.01206077635288, 59.96245823800564, 63.68649780750275, 63.10120761394501, 62.86153927445412, 65.07183507084846, 61.61033481359482, 55.79872526228428, 52.279627695679665, 48.71383063495159, 45.93983508646488, 47.84612059593201, 48.08949753642082, 44.903980270028114, 47.124011144042015, 50.42774386703968, 46.54522620141506, 47.50628583133221, 46.16530358791351, 46.901837065815926, 47.21676416695118, 45.54269939661026, 55.80496832728386, 61.173932030797005, 58.520538210868835, 60.61857283115387, 58.22913184762001, 62.35495425760746, 58.99264767765999, 57.297433242201805, 52.87485055625439, 48.12443666160107, 50.215331465005875, 55.187775045633316, 56.617797911167145, 60.637777000665665, 60.842878594994545, 57.98016160726547, 57.069555670022964, 61.84420846402645, 60.78940786421299, 60.59198945760727, 55.74176251888275, 51.90456122159958, 50.400126948952675, 47.15849049389362, 44.94156025350094, 46.703955084085464, 47.420798018574715, 49.94075059890747, 46.88127636909485, 46.99929043650627, 44.400583282113075, 43.936913162469864, 44.36567075550556, 43.21466691792011, 43.35160776972771, 42.579272612929344, 41.14356145262718, 45.163244158029556, 44.81476105749607, 43.82913574576378, 43.103560879826546, 43.01694072782993, 45.332654267549515, 41.823078989982605, 40.00225089490414, 42.66400046646595, 43.23191799223423, 43.14199201762676, 41.379878371953964, 43.83725970983505, 42.120371237397194, 39.872275069355965, 42.98764809966087, 45.58583088219166, 42.14780196547508, 45.00754751265049, 51.47562883794308, 53.43750536441803, 49.29289296269417, 54.533351361751556, 50.22897273302078, 53.37456934154034, 52.10706375539303, 59.76200759410858, 54.3461050093174, 60.5512860417366, 55.13329356908798, 57.821504920721054, 32.96640783548355, 0.8783109358046204, 1.980887500103563, 8.77965783700347, 8.449079375714064, 10.803536586463451, 2.6920082978904247, 9.133958425372839, 74.29811999201775, 36.50025621056557, 51.69163204729557, 36.09936632215977, 53.8141867518425, 24.801947437226772, 0.5237239971756935, 0.45244700624607503, 0.12379493768094108, 0.281626905198209, 0.14930515084415674, 0.09934596600942314, 0.14672032470116392, 0.14707113790791482, 0.13582394924014807, 0.14004826865857467, 0.2551552694058046, 0.1651591618428938, 0.1317905992618762, 0.1611091135418974, 0.11174410698004067, 0.10179465258261189, 0.07992121536517516, 0.14208164939191192, 0.20720715634524822], [0.08335850201547146, 0.03623144919401966, 0.035383912836550735, 0.029552854830399156, 0.021594133650069125, 0.023562572750961408, 0.02780075177724939, 0.04126169646042399, 0.04151101355091669, 0.0056085445066855755, 0.023295078608498443, 0.06854671868495643, 0.07223379740025848, 0.04363226456916891, 0.014589015645469772, 0.042616516730049625, 0.02845739662006963, 0.0253552824142389, 0.08093922675470822, 0.027244096490903758, 0.04997108146199025, 0.01653022442042129, 0.07001355872489512, 0.03907614205672871, 0.03915324748959392, 13.859735392034054, 45.15004746615887, 28.364134691655636, 39.826156944036484, 31.95013716816902, 48.14303666353226, 20.6065184623003, 0.694802098441869, 3.0407749582082033, 2.4317571753636003, 2.692846627905965, 0.4124895972199738, 0.10811089334310964, 0.4350638890173286, 38.93256649374962, 66.9703271985054, 63.464236333966255, 64.99377965927124, 61.49818003177643, 53.583295941352844, 52.07628920674324, 52.253473699092865, 52.69580036401749, 54.797551184892654, 53.475111946463585, 54.07448798418045, 56.25586353242397, 55.61066955327988, 59.042896181344986, 59.921036660671234, 55.949147790670395, 58.392424285411835, 60.020655915141106, 57.21057370305061, 51.83607369661331, 50.533685982227325, 46.83382831513882, 42.67794571816921, 44.67881955206394, 42.321460247039795, 43.10788504779339, 43.65877568721771, 43.809350207448006, 43.05196724832058, 43.55863966047764, 44.708697348833084, 41.23904272913933, 43.42246636748314, 41.3231398165226, 43.88067997992039, 56.9045989215374, 57.83893458545208, 57.86216653883457, 57.155119478702545, 57.98380181193352, 57.63488173484802, 59.460299983620644, 61.05663612484932, 55.08660927414894, 51.981032118201256, 46.439933851361275, 47.72955805063248, 51.09733633697033, 57.31814593076706, 57.25775197148323, 57.75959104299545, 58.20505253970623, 57.99685411155224, 53.97666223347187, 50.867653861641884, 47.88351058959961, 44.958784729242325, 43.74529704451561, 43.10134939849377, 44.92846995592117, 46.19852900505066, 47.181661650538445, 48.22332255542278, 46.14353835582733, 44.63476471602917, 38.260036781430244, 41.29255145788193, 39.59912292659283, 40.42487941682339, 37.64119438827038, 40.38511835038662, 38.28439727425575, 40.79985469579697, 39.67080608010292, 39.35730390250683, 38.435374572873116, 39.04901884496212, 38.651073798537254, 40.05879566073418, 36.310270205140114, 38.25784049928188, 37.65662156045437, 39.548570439219475, 37.626211792230606, 37.876074984669685, 36.47065959870815, 39.91906575858593, 38.53502042591572, 39.65385138988495, 42.388055473566055, 46.63938894867897, 45.259679183363914, 46.993659138679504, 46.983376890420914, 49.40752141177654, 48.78609895706177, 54.57576088607311, 48.03805589675903, 54.54361841082573, 50.35657748579979, 58.43435123562813, 48.00502426922321, 58.8366736471653, 12.916087377816439, 0.09119126218138263, 1.2745290342718363, 9.823583420366049, 12.944392058998346, 1.8005874124355614, 1.225069344509393, 15.508352927863598, 49.75391082465649, 25.457207076251507, 53.783579394221306, 39.45182003080845, 40.139024555683136, 6.427140897139907, 0.4553740663686767, 0.17907517292769626, 0.033319046488031745, 0.10599998786346987, 0.03097757427894976, 0.03055636650969973, 0.02605265261081513, 0.06795136781875044, 0.06169947868329473, 0.04305295893573202, 0.06872286001453176, 0.09557987083098851, 0.032980029718601145, 0.08714576324564405, 0.03846451589197386, 0.006117488510426483, 0.025945362176571507, 0.021548185432038736, 0.02080049947835505, 0.04697422977187671, 0.020219559264660347, 0.029736215401499067, 0.022763767665310297, 0.02234429837699281, 0.009455468843952985, 0.03403635819267947, 0.0285548721512896, 0.06677926430711523, 0.03660787762783002, 0.09216490798280574, 0.06293057551374659, 0.08092244679573923, 0.06728877837304026, 0.005990398040012224, 0.02086912587401457, 0.1131624699337408, 0.07534933334682137, 0.0906207287334837, 0.08870661113178357, 0.04523220137343742, 0.06241660856176168, 0.016878944770724047, 0.028684044809779152, 0.1098154803912621, 21.64044488221407, 52.462709471583366, 30.34795504063368, 50.38096457719803, 37.0621320605278, 57.50421814620495, 22.584511823952198, 0.5232015845831484, 2.4529529130086303, 1.9659534702077508, 2.007928155362606, 3.5450288001447916, 0.3558249003253877, 0.4335356585215777, 47.24519804120064, 70.72930589318275, 66.29209399223328, 65.88143482804298, 62.939074113965034, 54.59378331899643, 53.99973079562187, 52.6830368489027, 55.67831352353096, 54.083333909511566, 55.40755905210972, 56.138959005475044, 57.74123802781105, 59.895106852054596, 61.51148311793804, 62.10352934896946, 58.1708087772131, 61.0089410841465, 61.35271243751049, 60.04295691847801, 55.851314440369606, 52.592115327715874, 47.925448939204216, 44.817937687039375, 46.67901702225208, 45.26197046041489, 45.46972431242466, 44.667978733778, 45.05001783370972, 46.11735016107559, 47.032189071178436, 45.87211512029171, 43.029719442129135, 43.16040202975273, 43.240068554878235, 45.77887952327728, 57.5730324536562, 59.30510871112347, 59.570482671260834, 58.66350553929806, 60.40747135877609, 60.76344385743141, 61.79716698825359, 62.35367752611637, 56.07193820178509, 52.34206214547157, 48.758554235100746, 50.15284761786461, 53.039860501885414, 60.04266433417797, 60.39601877331734, 58.83516512811184, 59.982186779379845, 59.89006832242012, 55.266442224383354, 54.079492315649986, 49.009264782071114, 46.980359852313995, 44.491865783929825, 44.51836936175823, 45.23150369524956, 47.18825809657574, 49.924787655472755, 50.08472867310047, 47.59361274540424, 46.75506234169006, 40.895913541316986, 42.89594002068043, 41.655416786670685, 42.99087792634964, 40.197522416710854, 42.78575353324413, 40.305828005075455, 42.289329171180725, 41.271025612950325, 40.79580411314964, 40.652616396546364, 42.07575023174286, 40.43016113340855, 42.08178050816059, 38.44255618751049, 40.82541972398758, 39.312006533145905, 41.76627963781357, 39.05432716012001, 39.78358782827854, 38.347941264510155, 41.56437747180462, 40.77005669474602, 41.85653239488602, 43.52001093327999, 49.42224182188511, 48.117171451449394, 49.92714732885361, 47.55975656211376, 51.86782859265804, 49.789229929447174, 55.9215384721756, 52.49192990362644, 56.03132978081703, 53.30647699534893, 60.7566574215889, 48.197366148233414, 60.803999081254005, 14.892003200948238, 0.3524879668839276, 2.5249410001561046, 9.878442026674747, 10.664920024573803, 2.441885294392705, 0.864377380348742, 17.89657797664404, 55.71202151477337, 30.47883901745081, 61.859141662716866, 42.361464500427246, 49.06334348022938, 8.810895960777998, 0.4642831633100286, 0.15300735452910885, 0.049551289339433424, 0.04854811719269492, 0.0356925943196984, 0.02026019927143352, 0.0629488323465921, 0.045451383557519875, 0.022754559468012303, 0.026835692624445073, 0.05781747488072142, 0.03859046948491596, 0.06388039837474935, 0.17251684359507635, 0.027515895089891274, 0.0018400615840619139, 0.02540615292673465, 0.06709961235173978, 0.014613192033721134, 0.17655163333984092, 0.1498442469164729, 0.08032093610381708, 0.1748799456981942, 0.08487668383168057, 0.0875019644445274, 0.14478861819952726, 0.10215509886620566, 0.13223572459537536, 0.11003328589140438, 0.11186273186467588, 0.1692055884632282, 0.1646733668167144, 0.13769099983619526, 0.1782166861812584, 0.06994068724452518, 0.13440631359117106, 0.1395307097118348, 0.23456156195607036, 0.2431959900422953, 0.12288625948713161, 0.17861602100310847, 0.12984160071937367, 0.1311027174233459, 0.12143436630140059, 22.534719295799732, 63.749403432011604, 37.43726313114166, 53.09471055865288, 41.31923742592335, 60.0711590051651, 26.341769210994244, 0.8996146114077419, 8.796611577272415, 4.963615229353309, 12.08266669884324, 2.7186937909573317, 0.31156974378973246, 0.6904338765889406, 45.447940081357956, 73.23494464159012, 67.7153380215168, 71.16526409983635, 65.64077094197273, 58.808030784130096, 57.11423747241497, 56.447829231619835, 57.85724200308323, 58.43716688454151, 58.65927256643772, 62.02445559203625, 60.917620584368706, 61.18066906929016, 64.80296149849892, 63.29423725605011, 58.656472116708755, 63.062438294291496, 63.52167405188084, 64.41667422652245, 57.135086953639984, 54.19465273618698, 49.89654377102852, 46.041171848773956, 50.76654888689518, 46.86218619346619, 47.41299323737621, 47.521887794137, 48.25673796236515, 48.25606159865856, 47.38895572721958, 48.49218472838402, 46.38861760497093, 45.92884227633476, 45.430206432938576, 47.78251200914383, 60.17988637089729, 61.869963482022285, 63.377806171774864, 61.28706716001034, 62.7879524230957, 61.749354153871536, 64.74991634488106, 64.81081947684288, 57.7777274698019, 57.19240687787533, 50.4482551664114, 51.393306255340576, 54.69821311533451, 61.424517184495926, 62.83698499202728, 60.587680488824844, 62.04382695257664, 62.18303628265858, 57.81791031360626, 53.81919488310814, 49.73333112895489, 48.34645114839077, 46.375766694545746, 47.04988092184067, 49.30853672325611, 50.11498644948006, 53.14264498651028, 52.29249760508537, 50.23338049650192, 51.32744438946247, 43.006536886096, 44.675821512937546, 42.25827343761921, 44.97893504798412, 41.204928159713745, 45.91461203992367, 42.31207475066185, 44.90600176155567, 44.4015484303236, 42.3221518099308, 41.666177809238434, 44.63664561510086, 41.93417362868786, 44.28345836699009, 40.59520147740841, 42.72473640739918, 41.14182494580746, 43.386961072683334, 41.030559316277504, 40.657248347997665, 40.2074208855629, 43.57877478003502, 43.511765375733376, 44.39947374165058, 47.77947597205639, 51.61967530846596, 48.846937492489815, 51.42622008919716, 52.63240836560726, 53.55160564184189, 53.42756129801273, 58.35430473089218, 53.0155798047781, 57.92240470647812, 56.27107031643391, 59.99237783253193, 49.4274627417326, 61.31171263754368, 16.025638170540333, 0.3160535328788683, 2.789469030685723, 18.00689745694399, 23.658491894602776, 6.942214658483863, 1.4717718190513551, 20.478178448975086, 61.91828168928623, 38.73157247900963, 65.86308941245079, 45.73733635246754, 61.88657999038696, 10.546473730355501, 0.7197833235841244, 0.24025848048040643, 0.10404393149656244, 0.14752448623767123, 0.15548415365628898, 0.09933481152984314, 0.15503197791986167, 0.14303661533631384, 0.15101069526281208, 0.10099549312144518, 0.10790776010253467, 0.14822125900536776, 0.15660000237403437, 0.22288060281425714, 0.1488443513517268, 0.1380222203442827, 0.10976374527672306, 0.14820445678196847, 0.13628287852043286], [0.0754521727503743, 0.030321354315674398, 0.04933372503728606, 0.09315794610301964, 0.019375149204279296, 0.02396355885139201, 0.02957328801130643, 0.029126526242180262, 0.01314204197115032, 0.040536399246775545, 0.03129429322143551, 0.02710103082790738, 0.07345407371758483, 0.018952395912492648, 0.03026707548997365, 0.039496616955148056, 0.07051047112327069, 0.04544164286926389, 0.029622028559970204, 0.04621168416633736, 0.07033357280306518, 0.03355710148753133, 0.02413418045762228, 0.038263571987045, 0.113831382477656, 1.4178349007852376, 19.686686620116234, 34.87527720630169, 30.597901828587055, 41.9027379155159, 34.32803437113762, 51.3107480853796, 1.2803758517839015, 0.9887459536548704, 0.49641046905890107, 2.3092329874634743, 0.42020152090117335, 1.2919133389368653, 0.2830623969202861, 3.0498825944960117, 60.479591488838196, 68.56643915176392, 64.52942177653313, 61.49043224751949, 58.80230449140072, 57.973473966121674, 56.32840923964977, 54.41757157444954, 55.88958598673344, 56.70988976955414, 58.83512333035469, 60.583109334111214, 58.64079795777798, 59.51778329908848, 56.71483710408211, 58.368439972400665, 58.362763077020645, 57.867083474993706, 56.55422732234001, 53.30946363508701, 49.18449617922306, 47.809254974126816, 41.43872581422329, 43.948593735694885, 43.486492931842804, 43.48485141992569, 42.33225926756859, 43.72043497860432, 44.904968217015266, 44.26232010126114, 44.67384181916714, 41.164908707141876, 42.05973409116268, 42.08751440048218, 45.229820385575294, 55.17463155090809, 57.19573549926281, 56.713480576872826, 56.64712093770504, 55.64863331615925, 57.9042948782444, 53.880451396107674, 48.02025765180588, 58.96798700094223, 56.94037400186062, 51.875203996896744, 48.72915521264076, 51.83656767010689, 55.225795805454254, 58.60115848481655, 58.774440586566925, 56.36978521943092, 55.36515332758427, 53.796149119734764, 48.07829953730106, 45.46487957239151, 44.21459086239338, 44.504215121269226, 47.37520806491375, 48.01219828426838, 49.75073039531708, 50.98707005381584, 53.55163984000683, 51.37736991047859, 45.766799971461296, 39.40703943371773, 41.280715093016624, 41.6574040800333, 40.05534164607525, 41.04462616145611, 41.888731867074966, 39.02485214173794, 41.42169892787933, 39.06029663980007, 38.904960975050926, 39.071654230356216, 39.06619772315025, 39.73772808909416, 39.24661584198475, 37.76463456451893, 39.55275401473045, 37.90107764303684, 37.8120294213295, 36.968254297971725, 38.344536647200584, 40.30700594186783, 39.06291849911213, 36.84305101633072, 38.656313717365265, 42.2009003162384, 46.43929548561573, 46.813864186406136, 49.792566150426865, 48.774931356310844, 50.64973555505276, 50.750646740198135, 52.18354605138302, 52.58227005600929, 54.204441010951996, 57.778476029634476, 54.27350990474224, 51.39690846204758, 40.68756312131882, 2.6738414727151394, 0.4749913152772933, 1.1682799668051302, 12.745536379516125, 20.514629893004894, 1.4708850416354835, 0.41306185245048255, 19.911402761936188, 33.09815056622028, 29.55150067806244, 34.229099079966545, 39.00581896305084, 25.171694196760654, 0.8092647220473737, 0.07638061433681287, 0.01786733333574375, 0.10520614217966795, 0.010360131091147196, 0.07012512578512542, 0.034511432895669714, 0.06207675687619485, 0.07321902070543729, 0.024310397857334465, 0.05778426377219148, 0.06200788928254042, 0.02301822227309458, 0.03627302801760379, 0.013884651634725742, 0.040031764801824465, 0.03822931816102937, 0.036028197209816426, 0.038660034697386436, 0.033052797298296355, 0.04890071155386977, 0.056843476559151895, 0.051121287906426005, 0.02617712005303474, 0.027793836816272233, 0.05296635237755254, 0.043330548141966574, 0.05325607940903865, 0.019638743360701483, 0.06995688832830638, 0.0329023788071936, 0.008641232652735198, 0.08367410773644224, 0.013695711040782044, 0.02741709668043768, 0.037750695992144756, 0.10720717269578017, 0.04692263566539623, 0.02900625935581047, 0.0238640554016456, 0.03135710117931012, 0.030527467279171105, 0.046360228734556586, 0.09858732038992457, 0.17789294652175158, 3.2213388942182064, 33.71133126318455, 36.636144518852234, 33.9086926728487, 50.66069036722183, 41.01149953901768, 54.54434797167778, 1.2062202184461057, 1.0162207949906588, 1.2410527118481696, 3.3962309220805764, 6.51455283164978, 3.151631159707904, 0.3920314949937165, 4.7621543146669865, 64.55284371972084, 69.07250359654427, 65.001630038023, 64.1579233109951, 61.11495539546013, 59.4586318731308, 58.5198200494051, 56.66673168540001, 57.86222733557224, 59.91209574043751, 59.688846319913864, 63.256227895617485, 62.38056868314743, 61.86331003904343, 58.9774788916111, 60.3614292293787, 60.15937887132168, 59.103924706578255, 58.274216428399086, 56.48768149316311, 52.27698303759098, 49.916238114237785, 43.75598207116127, 46.47184453904629, 45.862790420651436, 45.10756194591522, 43.58085326850414, 45.15570916235447, 46.61529064178467, 46.476677879691124, 46.82494439184666, 43.915071934461594, 44.27599936723709, 44.50154006481171, 47.660793140530586, 56.767289489507675, 59.938135743141174, 59.24947589635849, 58.26422296464443, 58.30730885267258, 60.467173755168915, 56.01287417113781, 54.64071460068226, 62.97134578227997, 58.34607437252998, 53.637199848890305, 51.45460456609726, 53.668962344527245, 56.832623183727264, 59.80908326804638, 59.62200790643692, 57.91262023150921, 56.70344531536102, 56.43695421516895, 51.002413630485535, 47.63745479285717, 46.57212495803833, 46.37326642870903, 48.5171227902174, 49.49888750910759, 51.44149906933308, 54.12053771317005, 54.68383468687534, 52.60895222425461, 47.5474414229393, 41.13842032849789, 42.647642344236374, 43.21427173912525, 40.857554599642754, 41.280680894851685, 41.46468602120876, 40.594787299633026, 43.4590508043766, 41.29812575876713, 42.14822754263878, 42.342461720108986, 41.24374307692051, 41.44183024764061, 41.09565742313862, 39.73539121448994, 40.71131944656372, 40.47784477472305, 39.83176924288273, 39.27647463977337, 41.40514701604843, 42.0186734944582, 40.90568661689758, 39.73588518798351, 41.466513723134995, 45.28169520199299, 48.3813750743866, 50.42486362159252, 52.27044738829136, 50.783275589346886, 53.647789880633354, 52.503424286842346, 55.18872119486332, 54.36952315270901, 58.285251036286354, 58.0707411468029, 56.69700846076012, 50.72608485817909, 42.230394333601, 3.551389896310866, 1.6959496960043907, 1.7982909106649458, 10.763762220740318, 6.623766096308827, 0.17644612962612882, 0.4184778977651149, 23.115856312215328, 38.328098729252815, 37.92954571545124, 39.22373726963997, 42.95245058834553, 35.54436810314655, 2.0184811390936375, 0.12860672635724768, 0.013155397846276173, 0.10702835963456891, 0.027322756723151542, 0.05034239649830852, 0.035489720830810256, 0.05750452233769465, 0.06414281437173486, 0.06395850199623965, 0.06245288474019617, 0.02774173433863325, 0.05355782552214805, 0.03756360798433889, 0.004891027319899877, 0.026831146969925612, 0.048054381186375394, 0.06018647334713023, 0.08508253333275206, 0.024014106529648416, 0.1896324462722987, 0.11030060006305575, 0.13522873196052387, 0.15533465542830527, 0.12289829712244682, 0.07973076542839408, 0.14679494022857398, 0.1819255988812074, 0.22978324413998052, 0.20420270506292582, 0.13773006648989394, 0.09815044773858972, 0.1663667251705192, 0.09407799399923533, 0.10955889025353827, 0.07888084306614473, 0.16231922985753044, 0.15515512990532443, 0.23881587898358703, 0.0843771590734832, 0.21174170833546668, 0.07965996454004198, 0.08915600381442346, 0.10749964567366987, 0.22441969835199416, 2.3368380311876535, 39.790579453110695, 49.84197489917278, 38.104397132992744, 55.78293330967426, 45.02456299960613, 64.46589678525925, 1.6661607194691896, 3.286451487801969, 4.688225481659174, 7.525599729269743, 8.625807892531157, 5.748041812330484, 0.18641188158653677, 4.478373667225242, 65.9593078494072, 71.30954995751381, 69.42459270358086, 65.74708163738251, 65.0731498003006, 64.15107607841492, 63.21796774864197, 58.79591703414917, 61.57558187842369, 62.75344267487526, 62.70831249654293, 65.5858638882637, 65.35884886980057, 61.56308814883232, 60.777837485075, 62.14216187596321, 63.13827462494373, 61.209091544151306, 61.54881231486797, 58.748096600174904, 53.677572682499886, 52.62273408472538, 45.29630161821842, 48.829393833875656, 47.871989607810974, 47.065562680363655, 46.020839139819145, 46.86381630599499, 50.47733500599861, 50.06138272583485, 52.13174343109131, 45.66745810210705, 46.8823517113924, 46.35168358683586, 50.40946684777737, 58.60097609460354, 62.230738922953606, 59.66428443789482, 59.63487781584263, 57.37616881728172, 62.49491594731808, 57.43011072278023, 54.254450127482414, 65.16698196530342, 60.96648596227169, 57.34825171530247, 53.66521194577217, 55.210551023483276, 59.58241783082485, 62.39885710179806, 61.87595196068287, 61.3221088796854, 59.46798697113991, 58.82005713880062, 53.795309364795685, 51.08853600919247, 48.45514051616192, 49.43274065852165, 51.992154121398926, 51.83241829276085, 54.81870085000992, 56.82368986308575, 56.75275906920433, 55.45687660574913, 49.58700478076935, 43.38022783398628, 45.22757090628147, 44.90633614361286, 42.56337806582451, 44.085694178938866, 43.66636008024216, 42.43428759276867, 43.90302278101444, 41.73579007387161, 43.855920508503914, 44.46269854903221, 42.82619096338749, 43.79574693739414, 43.73130239546299, 42.88616694509983, 43.57051782310009, 42.57067367434502, 42.30777718126774, 41.40490002930164, 44.13818456232548, 44.7671914100647, 43.53029318153858, 40.97375996410847, 43.292171359062195, 45.98623439669609, 50.89889958500862, 52.242283299565315, 55.45159488916397, 53.138210624456406, 55.340207666158676, 56.35868601500988, 57.307457104325294, 57.62966461479664, 58.89406196773052, 60.6812808662653, 56.170174330472946, 51.51156350970268, 44.5225415378809, 3.2990041142329574, 1.9618607335723937, 5.326177999377251, 23.34794595837593, 35.038923025131226, 5.191827183589339, 0.6106521701440215, 26.08665280044079, 45.63588559627533, 41.56400129199028, 40.817424952983856, 49.56649348139763, 45.63729152083397, 1.7107801814563572, 0.267068877001293, 0.09208126793964766, 0.23239284317241982, 0.09009102082927711, 0.14302506751846522, 0.06690284673823044, 0.12481732032028958, 0.16332524071913213, 0.12618257518624887, 0.1523061140323989, 0.2233942729071714, 0.21536741143791005, 0.09408694430021569, 0.07494521167245694, 0.09126132092205808, 0.12287120131077245, 0.14907743025105447, 0.16367872565751895, 0.16839609830640256], [0.009775405924301594, 0.04236001565004699, 0.014422165077121463, 0.04349708979134448, 0.039807068460504524, 0.0766085872601252, 0.06071837058698293, 0.02874555029848125, 0.034212558894068934, 0.0058698226985143265, 0.0932711162022315, 0.008629166259197518, 0.0324629939859733, 0.07587522661196999, 0.0651093281339854, 0.07656211397261359, 0.015587396301270928, 0.06935574871022254, 0.059310212163836695, 0.038794897773186676, 0.03691056997922715, 0.01023936047204188, 0.09823700442211702, 0.01341985938779544, 0.07463754693162628, 0.03873184119584039, 3.8850735034793615, 41.01916752755642, 25.11938240379095, 37.68094405531883, 34.30654652416706, 41.16517089307308, 10.938834976404905, 1.2137207784689963, 0.7659211603458971, 0.6387119425926358, 8.745197486132383, 2.9209595499560237, 1.3972876220941544, 0.7443580299150199, 14.492517337203026, 75.82024231553078, 66.28357484936714, 63.61455626785755, 60.51836080849171, 59.39333237707615, 56.955386996269226, 59.50490579009056, 58.734797313809395, 60.41615769267082, 63.85769382119179, 60.023897141218185, 61.42434999346733, 54.72463309764862, 56.71270541846752, 58.53428587317467, 59.8616648465395, 57.29390703141689, 55.37535198032856, 55.39271704852581, 53.815417885780334, 47.09409914910793, 43.63789960741997, 44.60163429379463, 43.73598374426365, 43.33472527563572, 45.11410139501095, 43.732096552848816, 43.438189923763275, 43.64494822919369, 46.7827932536602, 43.30693356692791, 40.570886582136154, 43.123342618346214, 42.98119604587555, 52.23131708800793, 57.53138668835163, 60.28148911893368, 56.425961405038834, 54.91459250450134, 51.239270120859146, 52.6083442568779, 32.85810984671116, 45.289496183395386, 59.40339043736458, 54.22849752008915, 52.95790649950504, 53.64158861339092, 56.57399766147137, 56.663186475634575, 60.355653539299965, 57.85432755947113, 54.27616596221924, 49.9502956867218, 46.25640369951725, 46.32897600531578, 47.234760001301765, 48.47815588116646, 48.27509857714176, 51.71169117093086, 53.96055489778519, 57.799998074769974, 55.18018685281277, 55.154158249497414, 52.20067173242569, 41.856179013848305, 40.25353141129017, 40.4769404232502, 39.73481364548206, 40.359097346663475, 41.34568780660629, 39.47994992136955, 41.074910536408424, 40.67280851304531, 38.388055711984634, 39.16477583348751, 40.10910876095295, 43.576156720519066, 45.70433132350445, 46.24339319765568, 43.492735996842384, 40.58048106729984, 40.45686990022659, 38.299338072538376, 38.30174334347248, 38.870109245181084, 39.9957000464201, 38.77815417945385, 37.1466813236475, 39.62476395070553, 43.02656941115856, 49.11357298493385, 50.20244635641575, 51.38258323073387, 52.11464434862137, 54.527408480644226, 51.63015514612198, 55.129695162177086, 52.691605389118195, 59.32985678315163, 53.8095586001873, 51.807522028684616, 11.333406753838062, 0.2092187327798456, 1.3893327489495277, 1.8217551265843213, 7.097667641937733, 2.6680695824325085, 0.39347060839645565, 0.7006169145461172, 33.92298750579357, 36.3252642005682, 33.89773406088352, 30.37526037544012, 41.96039222180843, 8.686973210424185, 0.2493211574619636, 0.04552265570964664, 0.05755817219323944, 0.06332366145215929, 0.007545258649770403, 0.050468131157686, 0.0664520291320514, 0.05125349409354385, 0.022573759306396823, 0.07411346450680867, 0.0485668230248848, 0.027988075416942593, 0.04257391374267172, 0.042900184125755914, 0.054182799212867394, 0.0463124641100876, 0.05586141109233722, 0.03624207303801086, 0.0264111303476966, 0.06904304478666745, 0.04081333536305465, 0.0454249964968767, 0.030645882507087663, 0.02923543084762059, 0.04436222618096508, 0.1481282530585304, 0.01895013607281726, 0.07263666484504938, 0.059110440852236934, 0.046897499123588204, 0.04422561534738634, 0.01932043622218771, 0.07457228988641873, 0.07704984600422904, 0.028671266882156488, 0.043264300329610705, 0.011157733897562139, 0.047121208408498205, 0.032719910668674856, 0.025335862264910247, 0.022956382817937993, 0.019747672085941304, 0.007240641352836974, 0.011889099096151767, 0.06665205277386121, 0.02679793400602648, 7.494144067168236, 50.42282693088055, 26.205149441957474, 50.740926861763, 41.66564963757992, 52.63892121613026, 9.7073258087039, 0.8689777459949255, 2.0052530989050865, 1.6067315521650016, 5.734165906906128, 3.110594074241817, 3.579664654098451, 0.7445718871895224, 19.47994541376829, 75.51716297864914, 65.01957267522812, 65.97360268235207, 61.88050031661987, 60.76948173344135, 59.75549094378948, 61.342126205563545, 60.74690714478493, 62.223853692412376, 63.083686754107475, 63.593421801924706, 62.208897694945335, 56.97878614068031, 57.76230409741402, 59.629626497626305, 62.28693790733814, 58.9547561109066, 57.351834923028946, 57.31669060885906, 56.03924095630646, 47.49482944607735, 45.4137609153986, 45.54735414683819, 46.27905048429966, 45.19196301698685, 45.68484976887703, 45.9521996229887, 44.75049130618572, 46.41447901725769, 47.891258373856544, 43.79326947033405, 42.298840060830116, 45.70073291659355, 44.74391765892506, 54.21982258558273, 57.93798767030239, 60.07358327507973, 58.68019424378872, 56.883722841739655, 52.816117107868195, 53.84412534534931, 35.260694324970245, 48.8760781288147, 60.77038988471031, 55.914771035313606, 55.018543526530266, 54.88688439130783, 59.30126331746578, 58.35666440427303, 62.09321290254593, 59.40285086631775, 56.53385281562805, 52.01606243848801, 48.617988377809525, 47.51799680292606, 48.72004710137844, 50.11258877813816, 49.66646611690521, 52.916636914014816, 54.924756959080696, 59.13850285112858, 57.334982827305794, 56.53601109981537, 52.66642414033413, 44.63789954781532, 41.18520721793175, 42.88729168474674, 41.78528241813183, 42.596029713749886, 42.90931910276413, 43.02473410964012, 42.37047001719475, 41.78947739303112, 40.24024352431297, 41.06891445815563, 41.69148065149784, 43.946424052119255, 45.65200053155422, 46.933702155947685, 44.68714490532875, 43.344000577926636, 41.268160566687584, 41.335580348968506, 39.6977998316288, 40.61528719961643, 41.65903799235821, 40.46085208654404, 39.890206307172775, 42.7722642570734, 46.623699590563774, 50.809190198779106, 51.10550209879875, 53.52723374962807, 54.19114552438259, 55.80816775560379, 54.45549733936787, 59.124333411455154, 54.32319603860378, 60.68849667906761, 53.148945048451424, 52.55522310733795, 15.071939695626497, 0.4535136208869517, 4.12016118876636, 5.020071174949408, 7.361578205600381, 1.846488118171692, 0.2913560753222555, 0.5974294734187424, 37.60644905269146, 41.3363479077816, 42.382249385118484, 27.206395715475082, 48.97157460451126, 14.332114644348621, 0.2747364796232432, 0.060943738571950234, 0.010762264737422811, 0.1058637815003749, 0.036760659859282896, 0.03859513388306368, 0.06407988767023198, 0.030890212365193292, 0.038994001151877455, 0.024006902131077368, 0.0887862806848716, 0.10494807516806759, 0.06231563937035389, 0.02018736118770903, 0.0771665338834282, 0.030332312126120087, 0.04153300709731411, 0.01830864403018495, 0.09221527754561976, 0.04254216837580316, 0.09859236699412577, 0.2234612888423726, 0.1857600681250915, 0.128294772002846, 0.20153272489551455, 0.2206741680856794, 0.13079456286504865, 0.12636512867175043, 0.1098615603405051, 0.20646296034101397, 0.16329772188328207, 0.1425760830170475, 0.1740703813266009, 0.1609606691636145, 0.21795042674057186, 0.17339196929242462, 0.1155784352158662, 0.1594438380561769, 0.1623675288283266, 0.1966658837045543, 0.10964744331431575, 0.10679631974198855, 0.20901553274597973, 0.08738804477616213, 0.15902563784038648, 0.16765596927143633, 8.202272169291973, 62.26575404405594, 33.626478016376495, 48.97124782204628, 46.60093881189823, 55.32949224114418, 12.697788141667843, 1.2659625126980245, 5.699349325150251, 3.4325268119573593, 24.007554464042187, 5.128393387421966, 3.3406646037474275, 0.7987885060720146, 18.19762632250786, 78.75884503126144, 68.35767075419426, 70.6936714053154, 65.74291706085205, 64.88041654229164, 60.50477273762226, 64.61845859885216, 64.14148539304733, 65.99748820066452, 68.71732145547867, 66.41597494482994, 63.20387050509453, 59.76627476513386, 59.54055167734623, 63.3314448595047, 64.0255156159401, 63.59217926859856, 60.98106577992439, 59.730127304792404, 59.85672511160374, 50.66318303346634, 48.15234616398811, 48.73125649988651, 49.31073300540447, 48.68166156113148, 49.28531616926193, 47.3484081029892, 46.099730506539345, 47.824818938970566, 50.62519647181034, 46.07248216867447, 44.41507190465927, 48.970909640192986, 48.455934673547745, 56.96327157318592, 59.86083269119263, 64.90596637129784, 60.307460725307465, 59.09046582877636, 52.86492928862572, 55.39383798837662, 35.31088583171368, 49.58649940788746, 64.94502827525139, 57.25422576069832, 57.44645744562149, 55.79657457768917, 60.682265013456345, 61.42687305808067, 62.0124938338995, 61.42914533615112, 57.08706513047218, 54.50351156294346, 49.504655599594116, 49.47144538164139, 51.918776258826256, 53.237210512161255, 51.08261212706566, 57.13851056993008, 58.53055827319622, 60.222763270139694, 59.87977087497711, 56.80660218000412, 54.406609162688255, 45.07299140095711, 43.3486857265234, 45.77914550900459, 43.077517077326775, 45.360035598278046, 45.38899004459381, 44.79377098381519, 45.49826078116894, 44.36311349272728, 42.22121402621269, 43.20295214653015, 42.881436198949814, 46.80872306227684, 50.44624887406826, 50.56701019406319, 46.73208877444267, 46.12800858914852, 44.77466940879822, 43.77325214445591, 42.21589811146259, 41.94359712302685, 43.80331613123417, 43.326730504631996, 42.279673889279366, 43.96550662815571, 47.7733962982893, 53.90385814011097, 54.13040578365326, 57.12436392903328, 56.28325626254082, 58.90392243862152, 56.96255721151829, 59.18902114033699, 55.13023093342781, 60.408288314938545, 53.62482771277428, 52.67524726688862, 14.667994771152735, 0.5012864980380982, 5.786237837746739, 6.559093566611409, 20.065649785101414, 10.45032273977995, 1.6413191962055862, 0.8960966533049941, 44.65781807899475, 46.70848064124584, 48.38016673922539, 38.20137172937393, 59.14444573223591, 16.26773077994585, 0.6121368217281997, 0.21092144219437614, 0.1886794692836702, 0.16758932441007346, 0.11921043915208429, 0.17260127031477168, 0.18372947786701843, 0.10326120318495668, 0.18440726649714634, 0.16317486675688997, 0.1409597002202645, 0.23614879319211468, 0.1305782119743526, 0.12903007707791403, 0.10659606603439897, 0.14272725849878043, 0.11058419695473276, 0.16610400489298627, 0.1840270493994467, 0.1849665044574067], [0.04012939061794896, 0.028486323681136128, 0.05965071693935897, 0.024361591204069555, 0.08179700103937648, 0.013701603693334619, 0.011418718477216316, 0.0503763942833757, 0.05072956751973834, 0.007266885086210095, 0.03625008452218026, 0.07814173077349551, 0.03404875948035624, 0.053305009205359966, 0.043774615915026516, 0.05179691317607649, 0.03279206226579845, 0.005282403999444796, 0.018192733550677076, 0.005365327406252618, 0.018990642493008636, 0.06301028959569521, 0.028089773768442683, 0.03584135040000547, 0.2240027894731611, 0.1060224007233046, 0.25881598703563213, 22.67819009721279, 42.36810654401779, 26.745147965848446, 44.22495290637016, 34.21545781195164, 27.909175604581833, 0.11306886284728535, 0.1680945191765204, 0.8920244593173265, 5.253170616924763, 0.9334327967371792, 1.1648428137414157, 0.45309513865504414, 0.36735962668899447, 32.456881776452065, 73.88856276869774, 62.7384714782238, 66.4292362332344, 60.77958159148693, 64.26180973649025, 59.55806873738766, 66.7339114844799, 61.488042175769806, 62.51898765563965, 58.499871119856834, 55.68765342235565, 55.11783219873905, 64.8050057888031, 60.28884172439575, 59.864260107278824, 58.02835062146187, 57.90312074124813, 58.285585418343544, 56.60375386476517, 48.31264816224575, 43.181251510977745, 44.097629338502884, 44.26984749734402, 44.802981689572334, 45.026759281754494, 46.73753768205643, 46.54618375003338, 46.21049076318741, 44.957789182662964, 46.46960265934467, 40.51954373717308, 44.0379573404789, 41.18994176387787, 46.7437769472599, 50.94481252133846, 58.05045023560524, 56.87901109457016, 60.46264059841633, 51.59559600055218, 60.14028489589691, 56.88743144273758, 45.105532854795456, 61.909811943769455, 55.49935072660446, 58.156700134277344, 56.182470470666885, 57.932793349027634, 58.18603076040745, 59.073286950588226, 55.458320528268814, 55.36364860832691, 53.042622953653336, 50.73645070195198, 50.06094194948673, 51.0925067961216, 51.44971042871475, 53.43468211591244, 55.49639828503132, 57.312526032328606, 56.442741304636, 55.35887226462364, 54.72671538591385, 54.081943184137344, 44.203233271837234, 38.091200441122055, 40.642831921577454, 40.57046480476856, 41.15688733756542, 40.9692420065403, 40.107167065143585, 41.026820316910744, 38.39708022773266, 39.210312590003014, 38.96262668073177, 44.26419720053673, 50.21238662302494, 49.09376464784145, 49.41586956381798, 49.44605514407158, 49.744434133172035, 48.37046205997467, 45.13577543199062, 42.74267144501209, 39.99584823846817, 37.725956439971924, 38.82248640060425, 37.813355550169945, 37.18825489282608, 39.37213450670242, 46.36752873659134, 48.963633030653, 52.351025864481926, 52.33859673142433, 54.58833061158657, 53.34331601858139, 55.2250662446022, 54.385128915309906, 55.58510072529316, 55.057293847203255, 26.29006538540125, 0.930804762756452, 0.8448502875398844, 2.0607968559488654, 3.1929083447903395, 4.915553983300924, 1.3761526811867952, 0.12035011081025004, 2.23748832475394, 26.179261431097984, 38.73715437948704, 26.54920767992735, 36.93328857421875, 28.97866241633892, 0.9102608682587743, 0.038878556370036677, 0.041437704203417525, 0.11661810989608057, 0.02183964166761143, 0.055617808538954705, 0.007465779735866818, 0.018304629011254292, 0.002917468559644476, 0.03231563685403671, 0.022916011839697603, 0.01797918426746037, 0.010243756769341417, 0.0069005271325295325, 0.06485008852905594, 0.001767533462952997, 0.035422322689555585, 0.04577615109155886, 0.02320516370673431, 0.02857435538317077, 0.025952531323127914, 0.020427310519153252, 0.016255097289104015, 0.04363848005596083, 0.057508830504957587, 0.014705479024996748, 0.04539227520581335, 0.013678714931302238, 0.026206330985587556, 0.03570732966181822, 0.0468016470404109, 0.03521608356095385, 0.06516721565276384, 0.006871494315419113, 0.015069856835907558, 0.058307359140599146, 0.05782510786957573, 0.06702637721900828, 0.01891125866677612, 0.018853669862437528, 0.0040961546892503975, 0.04532458020548802, 0.05959285168501083, 0.07181510736700147, 0.06545138399815187, 0.1483809988712892, 0.044479411299107596, 0.5168270110152662, 33.78302201628685, 37.948202714324, 29.063880443572998, 55.59648111462593, 41.195451468229294, 31.055167391896248, 0.32489533186890185, 1.0187495592981577, 2.050712672062218, 3.3752781338989735, 3.974889521487057, 5.138230109587312, 2.665084130130708, 0.2399315347429365, 37.38450676202774, 72.85595297813416, 62.696996703743935, 68.25571462512016, 62.87269927561283, 66.31718024611473, 59.94886636734009, 66.80290818214417, 62.738114297389984, 63.59918609261513, 61.07509173452854, 58.886158391833305, 56.325848177075386, 65.77939510345459, 60.64112842082977, 62.35269337892532, 59.46371600031853, 60.190392807126045, 58.145160153508186, 57.22564369440079, 50.04197716712952, 46.31500035524368, 45.61933368444443, 45.77971547842026, 45.9110364317894, 46.345436722040176, 49.38277713954449, 48.85555922985077, 49.00128901004791, 46.939842626452446, 48.106307834386826, 43.7768467515707, 45.38888745009899, 43.10966335237026, 48.27154956758022, 56.39526665210724, 60.16726724803448, 57.30850584805012, 61.19704619050026, 52.447426691651344, 55.268372520804405, 58.4137487411499, 48.73798593878746, 62.075733840465546, 58.887495920062065, 59.75398242473602, 59.05649945139885, 59.32595059275627, 58.876666501164436, 61.4406169205904, 58.010571375489235, 57.44525671005249, 54.94676537811756, 52.8439924120903, 52.54195421934128, 51.9412786513567, 54.52298931777477, 56.888062208890915, 56.59346781671047, 59.178434908390045, 58.24457801878452, 59.17401194572449, 56.71420633792877, 54.910975098609924, 45.99126912653446, 40.9949666261673, 41.1584110558033, 42.246152088046074, 42.436719462275505, 42.27212369441986, 42.13972359895706, 42.22792446613312, 42.515097856521606, 41.787577494978905, 43.20827566087246, 44.84173581004143, 50.96595078706741, 49.95354451239109, 50.8833584189415, 52.43498615920544, 52.53378465771675, 48.874353021383286, 45.84635250270367, 44.50757034122944, 42.44045466184616, 39.6051000058651, 41.557993814349174, 39.544960632920265, 41.55139356851578, 41.90705828368664, 48.67514491081238, 50.930897668004036, 54.749221578240395, 54.66229744255543, 56.808631271123886, 54.356588646769524, 57.23084181547165, 56.168251633644104, 56.33648760616779, 56.84822514653206, 28.328334912657738, 0.7812635495793074, 2.3505374835804105, 5.652100760489702, 9.74982937797904, 8.740729875862598, 0.8497655019164085, 0.5957790557295084, 3.3117643045261502, 29.440704323351383, 51.59097544848919, 30.88594537228346, 39.98094163835049, 38.473695516586304, 1.846744129434228, 0.10712165501900017, 0.09084039702429436, 0.0645292729313951, 0.04617288839654066, 0.027203495446883608, 0.038023323941160925, 0.03091102775215404, 0.026982495000993367, 0.025193444125761744, 0.023389220041281078, 0.022599378244194668, 0.034116127935703844, 0.049700843228492886, 0.07649915758520365, 0.03625299003033433, 0.051299826372996904, 0.03052329455385916, 0.04100328063941561, 0.023265839845407754, 0.014673318055429263, 0.17111909750383347, 0.15052231756271794, 0.151424620707985, 0.19723062840057537, 0.1331531527102925, 0.10309894001693465, 0.07955869848956354, 0.1430379066732712, 0.1684132419177331, 0.12625797739019617, 0.14395971345948055, 0.14314621570520103, 0.09345856786239892, 0.14791660738410428, 0.14080459135584533, 0.20386902062455192, 0.1710303663276136, 0.08732406422495842, 0.07867164647905156, 0.08335724778589793, 0.15609289286658168, 0.13753875566180795, 0.1539228975889273, 0.19728228187886998, 0.26851573842577636, 0.20163177192443982, 0.5345209990628064, 37.6054573059082, 52.95818388462067, 34.947716519236565, 56.03269770741463, 46.7093013972044, 35.1363991945982, 0.20748366572661325, 3.7869017338380218, 5.145394625142217, 16.86513092368841, 7.904191464185715, 4.21572701074183, 1.9338802224956453, 0.6014039414003491, 36.976313665509224, 74.25025016069412, 65.70764735341072, 71.22547566890717, 67.26603493094444, 69.31180715560913, 64.24406468868256, 70.01731529831886, 66.63851380348206, 63.470247611403465, 63.336817771196365, 62.43353024125099, 58.93581032752991, 66.57062664628029, 65.1667919754982, 63.97022858262062, 62.23584204912186, 61.83270648121834, 63.965448439121246, 60.371259301900864, 53.31825636327267, 48.34632955491543, 48.99554751813412, 47.6536001265049, 48.403121307492256, 49.89615999162197, 52.21955671906471, 51.35198347270489, 53.08166965842247, 47.92914614081383, 51.545841470360756, 45.222908556461334, 47.376708984375, 43.99169482290745, 50.729405879974365, 56.326532140374184, 61.43644854426384, 58.68153937160969, 65.44275596737862, 54.62770029902458, 57.363557294011116, 57.04161956906319, 45.90191312134266, 67.0433060824871, 61.6094608604908, 65.40811702609062, 60.966618955135345, 62.86456771194935, 60.89515618979931, 63.750775158405304, 61.24637894332409, 59.97947372496128, 57.58043445646763, 55.82749351859093, 55.453639179468155, 55.38094907999039, 56.96856468915939, 60.46418331563473, 59.52393516898155, 61.401809602975845, 61.07501193881035, 60.94392657279968, 59.29970160126686, 56.862576976418495, 48.56776647269726, 42.671113684773445, 43.60679067671299, 46.38872019946575, 43.63345764577389, 43.73690329492092, 42.33165130019188, 44.18988838791847, 43.71281638741493, 43.81040275096893, 46.434211358428, 48.492705300450325, 52.85018227994442, 52.79608458280563, 51.632758006453514, 55.521340146660805, 54.23321306705475, 52.33383558690548, 49.11936767399311, 49.18310545384884, 43.84965844452381, 40.92082880437374, 42.92791910469532, 41.45333983004093, 44.55523498356342, 43.32627072930336, 51.29154771566391, 53.91406059265137, 56.020492762327194, 57.26268410682678, 59.20681178569794, 56.84086874127388, 59.483505338430405, 56.90586805343628, 59.38790246844292, 56.036717891693115, 27.872287184000015, 1.6984339314512908, 2.7672843961045146, 6.818776857107878, 11.46638821810484, 12.898442074656487, 4.853658629581332, 0.6105619843583554, 3.467369517311454, 39.09836299717426, 51.78653955459595, 38.169886618852615, 48.216961696743965, 48.44091787934303, 1.3927479344420135, 0.16393782425438985, 0.17435909161577, 0.2065632987068966, 0.09891080029774457, 0.11784692833316512, 0.08657128899358213, 0.0625060150923673, 0.2307798742549494, 0.16501267673447728, 0.11666713617159985, 0.1400001923320815, 0.15585441113216802, 0.07352439963142388, 0.1518996397498995, 0.11779521548305638, 0.16791368747362867, 0.21643914689775556, 0.1147587776358705, 0.1733534221420996, 0.10052019206341356], [0.034589206261443906, 0.04610825846611988, 0.059692355134757236, 0.04249088226060849, 0.08083525186521001, 0.03058087964745937, 0.044844061849289574, 0.027121701496071182, 0.051782682494376786, 0.015389661257358966, 0.026673935972212348, 0.00883406117281993, 0.011260870160185732, 0.028307599677646067, 0.07987323551787995, 0.04655703145544976, 0.06279352310230024, 0.019569521391531453, 0.02006116083066445, 0.027151699105161242, 0.004478376513361582, 0.14382134744664654, 0.03512750823574606, 0.020341030285635497, 0.07437087842845358, 0.0019763086493185256, 0.09122951989411376, 2.409930909052491, 50.00647947192192, 28.65981962531805, 34.00163568556309, 35.558708533644676, 32.6534566283226, 3.7092386512085795, 1.110167191363871, 1.0821562819182873, 1.4031028538011014, 7.573100030422211, 3.6961362417787313, 2.902052002027631, 0.21126211766386405, 1.0754786152392626, 53.581160455942154, 67.11569219827652, 63.10133680701256, 61.536234989762306, 61.04117475450039, 61.34342573583126, 61.412494629621506, 62.43378862738609, 61.392469704151154, 57.22964107990265, 59.105220437049866, 60.578807964921, 61.10708601772785, 60.03834396600723, 60.09007439017296, 59.056286662817, 58.83362241089344, 59.41231235861778, 58.93853098154068, 46.21558628976345, 41.76800474524498, 44.827266186475754, 42.911887764930725, 45.35566583275795, 48.71913895010948, 54.218245670199394, 50.66738560795784, 51.63661479949951, 48.37735868990421, 42.23731376230717, 43.111954629421234, 40.88291823863983, 41.82983882725239, 42.41170920431614, 48.93741063773632, 54.92993988096714, 57.69492231309414, 57.311522886157036, 58.68502378463745, 56.01725913584232, 58.36902894079685, 54.29914712905884, 55.72529800236225, 56.10319912433624, 56.01065129041672, 58.19220542907715, 57.788328900933266, 55.40572375059128, 56.46098792552948, 57.745923176407814, 55.73377534747124, 52.609165012836456, 51.84490442276001, 54.86306346952915, 56.543048322200775, 56.13599896430969, 55.41003651916981, 57.65789330005646, 57.04672649502754, 57.18701496720314, 58.0289775878191, 56.60829842090607, 54.67712044715881, 41.8764129281044, 38.694490268826485, 39.40911032259464, 39.55249562859535, 40.24653218686581, 40.714591071009636, 39.58898887038231, 41.13049775362015, 39.532045125961304, 39.161382615566254, 41.53115965425968, 49.43263426423073, 52.57589019834995, 53.82623590528965, 53.10915358364582, 51.26847915351391, 51.0589811950922, 52.1481167525053, 52.28305511176586, 50.17259135842323, 47.90663614869118, 43.47743421792984, 40.31220406293869, 37.42293410003185, 39.021667912602425, 37.80006006360054, 40.00394560396671, 44.12053070962429, 49.65043857693672, 49.644799679517746, 49.73004810512066, 53.45542900264263, 53.54122459888458, 51.148158609867096, 56.40568569302559, 33.68300378322601, 3.437491958029568, 0.4362374619813636, 1.334213619120419, 4.28122409619391, 8.225728310644627, 2.526491554453969, 0.46114082098938525, 0.03486623885692097, 1.928032930009067, 34.228798896074295, 37.125334069132805, 21.740901991724968, 45.645552277565, 10.24105941876769, 0.2111101258196868, 0.03965298747061752, 0.06355153047479689, 0.04545909818261862, 0.01729035247990396, 0.015251074455591151, 0.014240452073863707, 0.06695159099763259, 0.06563029353856109, 0.054571484215557575, 0.034066162843373604, 0.010286571268807165, 0.04528289377049077, 0.057054287317441776, 0.047148842277238145, 0.061869901765021496, 0.026885900770139415, 0.0422586716740625, 0.07222122541861609, 0.12259406110388227, 0.011057743413402932, 0.022639057169726584, 0.06482524884631857, 0.03580133008654229, 0.02601001993753016, 0.05653245360008441, 0.018819673932739533, 0.03068552618060494, 0.041704402392497286, 0.020966465963283554, 0.03311414322524797, 0.06788494560169056, 0.035215196694480255, 0.013448843037622282, 0.028718174326058943, 0.07751768847811036, 0.035967214935226366, 0.06686882668873295, 0.04002983892860357, 0.08147038926836103, 0.026869100402109325, 0.03203011779987719, 0.04940047379932366, 0.03151599499688018, 0.009188491421809886, 0.032229677599389106, 0.14119331346591935, 0.22965829615714028, 5.036689108237624, 64.48602810502052, 22.37254209816456, 49.17015954852104, 42.57953479886055, 38.427235409617424, 3.4366113552823663, 0.770973761100322, 0.7982152712065727, 1.9489955739118159, 4.344447003677487, 5.775900492444634, 6.698479112237692, 1.0242017917335033, 1.6208358015865088, 57.60875813663006, 65.04062354564667, 64.69448491930962, 62.014215141534805, 63.37731599807739, 64.14821103215218, 62.89816550910473, 63.03528495132923, 63.19828100502491, 58.733064606785774, 61.57243564724922, 61.22518748044968, 60.53559668362141, 60.87963402271271, 61.75242818892002, 62.96704821288586, 61.192893013358116, 61.359825655817986, 59.70696374773979, 48.132591024041176, 44.722786992788315, 45.11149853467941, 45.36050297319889, 47.79207229614258, 50.45318350195885, 55.47002010047436, 52.935122922062874, 52.20870070159435, 47.90095545351505, 44.46462124586105, 45.033104941248894, 43.00075739622116, 44.4164702296257, 43.27367775142193, 51.84007868170738, 57.39930957555771, 59.99567985534668, 58.90805661678314, 60.303892716765404, 57.48323567211628, 59.955048635602, 58.17391321063042, 59.42658819258213, 55.96395939588547, 57.62459188699722, 60.25486394762993, 59.164216071367264, 56.645418629050255, 57.33177959918976, 58.57544906437397, 58.79589043557644, 55.98703555762768, 53.19173455238342, 55.4850634932518, 54.93440844118595, 57.73797020316124, 56.604369431734085, 58.67313802242279, 58.861376121640205, 56.22841380536556, 57.142219170928, 58.87800022959709, 55.332798063755035, 44.706786051392555, 41.30841560661793, 42.87259787321091, 41.78498603403568, 41.9919191300869, 42.63873182237148, 42.03414246439934, 42.50714108347893, 41.689348965883255, 40.90252138674259, 43.47117595374584, 50.60480676591396, 53.682322427630424, 56.10249996185303, 55.4907213896513, 53.18799935281277, 53.1442105025053, 53.76872979104519, 52.03827224671841, 52.121047005057335, 50.78693099319935, 44.44284841418266, 42.54597879946232, 39.08871911466122, 41.11625611782074, 39.74053993821144, 42.50627093017101, 47.974481508135796, 53.08610402047634, 51.33377104997635, 51.950040981173515, 55.899214670062065, 56.71042174100876, 51.83913253247738, 56.69078439474106, 34.89013820886612, 3.9786745933815837, 1.7763315327465534, 6.116452943533659, 7.943773465231061, 12.670844737440348, 2.9594773706048727, 0.399081808864139, 0.09881726742605679, 2.828915426507592, 37.46078386902809, 48.07101532816887, 21.064025312662125, 50.98646968603134, 13.740462642163038, 0.45822462590876967, 0.2165669298847206, 0.03801955383096356, 0.035878884518751875, 0.06839498659246601, 0.016355543266399764, 0.06459224416175857, 0.09331991241197102, 0.052012173109687865, 0.057276961306342855, 0.024450506061839405, 0.027669675509969238, 0.013165771215426503, 0.03399537308723666, 0.11787224299041554, 0.009552022256684722, 0.08209319217712618, 0.06633338198298588, 0.029769214997941162, 0.029505969650927, 0.019654888783406932, 0.07253991105244495, 0.19248293159762397, 0.20203457999741659, 0.2227225253591314, 0.15173700550803915, 0.10917378982412629, 0.10558831112575717, 0.1557384876650758, 0.1390342871309258, 0.1606619992526248, 0.21482303127413616, 0.14544764533638954, 0.08308726930408739, 0.07990352998604067, 0.1796558589558117, 0.127737493312452, 0.1741359129664488, 0.18673879763809964, 0.16593286563875154, 0.08304153816425242, 0.1673840612056665, 0.19162377691827714, 0.0973439410154242, 0.09566774111590348, 0.23150915309088305, 0.2925151615636423, 0.26117245433852077, 6.891079852357507, 74.96639773249626, 35.82882843911648, 46.37056477367878, 48.10487151145935, 43.81477251648903, 5.22431924007833, 1.9063065270893276, 6.027776151895523, 4.099941048771143, 18.972986117005348, 11.104506086558104, 6.6081152111291885, 0.6740767043083906, 1.9542097253724933, 57.151973247528076, 68.10655742883682, 65.81414803862572, 62.338596135377884, 63.74772772192955, 64.57582488656044, 66.63448601961136, 62.79303275048733, 65.94376668334007, 60.30677296221256, 63.06350603699684, 63.06971490383148, 64.48314785957336, 62.82639116048813, 64.70274567604065, 66.49561107158661, 63.56247626245022, 64.34988141059875, 62.837475165724754, 51.68297991156578, 46.938778683543205, 49.088311940431595, 47.379251047968864, 51.19908347725868, 54.24378789961338, 59.31418642401695, 55.700416937470436, 54.87197779119015, 52.663110718131065, 45.26471771299839, 48.78068804740906, 44.6020332723856, 47.770880833268166, 45.73549345135689, 53.1118818372488, 59.61188144981861, 62.139635011553764, 59.708989039063454, 64.72350016236305, 58.72746370732784, 60.160841792821884, 56.729842498898506, 58.90626311302185, 59.828021451830864, 58.364461585879326, 63.14171344041824, 61.10836274921894, 56.59827075898647, 57.053896710276604, 60.41998788714409, 60.87914764881134, 59.219681695103645, 54.96141739189625, 58.92823353409767, 59.466493651270866, 59.279228299856186, 58.73307980597019, 59.9965538084507, 60.15358418226242, 58.44093628227711, 59.824643433094025, 60.94656743109226, 57.36744828522205, 47.295746728777885, 42.68174931406975, 43.85723143815994, 43.25938291847706, 44.74461682140827, 44.51764740049839, 43.827786818146706, 45.599874928593636, 44.27700251340866, 42.13342733681202, 45.40794722735882, 54.851481691002846, 56.906893998384476, 58.5929699242115, 57.82659664750099, 54.20359745621681, 53.78207087516785, 56.44497558474541, 55.742682069540024, 54.71713609993458, 55.10837450623512, 47.40688696503639, 45.92215843498707, 42.04752914607525, 44.433941692113876, 43.58518123626709, 44.531809240579605, 49.24569569528103, 56.90019875764847, 52.784244418144226, 55.07023595273495, 58.45290184020996, 56.66868098080158, 52.97515757381916, 56.10394388437271, 35.48143208026886, 4.88122615031898, 1.600738917477429, 4.09392312169075, 11.576266922056675, 17.739357613027096, 8.470444679260254, 2.4469159869477153, 0.30654861009679735, 4.331893902271986, 46.65349379181862, 49.165721386671066, 30.36634035408497, 61.33123219013214, 17.321623228490353, 0.4919371590949595, 0.3058471321128309, 0.129333377990406, 0.21002866822527722, 0.16169646405614913, 0.12409881746862084, 0.10948627110337839, 0.3074035048484802, 0.1374189433408901, 0.10470446519320831, 0.08043573150644079, 0.23850202473113313, 0.10237075955956243, 0.11725374453817494, 0.28515620331745595, 0.18046053999569267, 0.15701610973337665, 0.14312264509499073, 0.19468213780783117, 0.2937468298478052, 0.08342217086465098], [0.010960104609694099, 0.03292482877441216, 0.0681266408355441, 0.05419931942014955, 0.024990589190565515, 0.05764836540038232, 0.02277882769703865, 0.09702558934804983, 0.02751361855189316, 0.048705712251830846, 0.01881790391053073, 0.05169600706722122, 0.02181613970606122, 0.07177119448897429, 0.0438601818314055, 0.027159461969858967, 0.04224006232107058, 0.01905480672576232, 0.04865046306804288, 0.03578872470825445, 0.0986431966884993, 0.07790240299073048, 0.12305596639635041, 0.035129623356624506, 0.14528692583553493, 0.1014830989879556, 0.21562778652878478, 0.4146807437064126, 16.919283717870712, 34.73331682384014, 35.143326222896576, 59.85264793038368, 30.447872579097748, 9.846198856830597, 0.12550037819892168, 0.8523187867831439, 1.4696020167320967, 2.235928983427584, 7.250911043956876, 3.6492496076971292, 0.42915600759442896, 0.10738274999312125, 8.809241149574518, 68.17543253302574, 61.557681038975716, 63.586319983005524, 58.25933262705803, 63.30347076058388, 62.07872427999973, 60.881397128105164, 57.51894235610962, 60.42704030871391, 61.15881644189358, 61.45483955740929, 60.642142966389656, 61.25520206987858, 60.65935604274273, 59.653200432658195, 61.406346559524536, 63.49836990237236, 57.427595257759094, 48.072402253746986, 45.337894186377525, 45.32768413424492, 43.8458776473999, 47.110480070114136, 55.23429214954376, 60.74740871787071, 60.20928919315338, 55.72083704173565, 46.12179212272167, 42.481431663036346, 41.8182722479105, 41.04246407747269, 42.31378085911274, 44.67641808092594, 43.63202132284641, 50.343753173947334, 55.38815349340439, 58.83675344288349, 56.69651448726654, 58.29006537795067, 59.08066235482693, 57.34665960073471, 57.081312239170074, 59.55139249563217, 56.94874495267868, 55.006323382258415, 55.54147906601429, 52.85279653966427, 56.609822139143944, 59.68526691198349, 56.93328358232975, 58.64250786602497, 58.37535560131073, 57.65329174697399, 58.86170670390129, 56.49143189191818, 57.092400044202805, 57.69885890185833, 57.245938405394554, 56.70568719506264, 54.45177733898163, 55.33307924866676, 50.84149606525898, 39.267921298742294, 39.70753870904446, 38.322497829794884, 39.44224074482918, 39.653380215168, 40.51899656653404, 40.21487608551979, 41.140441820025444, 41.556124314665794, 41.36212572455406, 44.82812114059925, 53.3445243537426, 54.460288882255554, 56.800853088498116, 52.46025860309601, 54.07903254032135, 51.826327219605446, 52.065129205584526, 52.180456817150116, 52.49313443899155, 54.6789975464344, 51.57226525247097, 50.45701749622822, 42.70780451595783, 38.496395498514175, 38.314446061849594, 38.342154175043106, 41.28154344856739, 43.7546331435442, 48.31094965338707, 51.998739168047905, 51.855851635336876, 55.37584215402603, 57.121521681547165, 50.2915857732296, 12.71644989028573, 0.5373147991485894, 1.570436730980873, 1.3826422579586506, 6.275192275643349, 9.434102419763803, 7.6197814755141735, 0.09231756775989197, 0.08640936721349135, 9.053242206573486, 45.63432388007641, 31.38534877449274, 35.451269298791885, 35.13326436281204, 0.9755651140585542, 0.04922709325910546, 0.01628948655707063, 0.08755885748541914, 0.014702647731610341, 0.03052283813303802, 0.07254907657625154, 0.03870008098601829, 0.01724656391161261, 0.01497687779192347, 0.03708416574227158, 0.02158815008442616, 0.06291117577347904, 0.04629913884855341, 0.0394269144453574, 0.10211045868345536, 0.06283961789449677, 0.06149851622467395, 0.05764101442764513, 0.0782723116572015, 0.011625776751316153, 0.012336305226199329, 0.039491692805313505, 0.09620944212656468, 0.04160257230978459, 0.013283061161928345, 0.04460997362912167, 0.019408247135288548, 0.07197328130132519, 0.04992039277567528, 0.04019456602691207, 0.0964331699651666, 0.040920720421127044, 0.040065020439215004, 0.0809115001175087, 0.025783067467273213, 0.01420131769918953, 0.05221945495577529, 0.04258921311702579, 0.010680106206564233, 0.05642597025143914, 0.04158951422141399, 0.035493494651746005, 0.09144026756985113, 0.09414994521648623, 0.07366839112364687, 0.1046527894504834, 0.17889169917907566, 0.2160931724938564, 0.4596540320198983, 29.045365937054157, 35.36295063793659, 29.680135175585747, 55.678343921899796, 35.26859790086746, 13.097520992159843, 0.20635200926335528, 1.0511944745667279, 0.4246016254182905, 3.667196282185614, 6.523888930678368, 5.725350854918361, 3.7393213994801044, 0.3784629871370271, 11.417773626744747, 69.16774168610573, 60.42262114584446, 64.80567455291748, 58.588444367051125, 64.55412045121193, 64.19862672686577, 63.6420401930809, 59.721706956624985, 64.64530795812607, 60.91791696846485, 62.51188963651657, 62.548808455467224, 64.3944226205349, 61.91752552986145, 62.5490440428257, 61.91627159714699, 64.09121409058571, 58.15049886703491, 50.21070711314678, 46.44756384193897, 47.83838041126728, 45.920011550188065, 49.35974657535553, 57.34946385025978, 62.33659364283085, 61.25212423503399, 57.35009841620922, 49.64178264141083, 47.02859826385975, 44.97787870466709, 43.94819475710392, 44.553281888365746, 45.96765339374542, 45.62465339899063, 53.49300518631935, 58.27197454869747, 59.0841543674469, 59.10332053899765, 58.83784398436546, 60.26017986238003, 60.84487348794937, 57.13528074324131, 61.75080567598343, 59.239490032196045, 55.89270941913128, 56.986746713519096, 53.30306097865105, 58.82894106209278, 60.225293934345245, 58.97377789020538, 59.31560754776001, 59.825038611888885, 58.25975060462952, 59.63650032877922, 59.44492980837822, 58.837733790278435, 60.71508765220642, 57.79232248663902, 59.61697697639465, 57.920728996396065, 58.24885278940201, 52.54180982708931, 42.58694440126419, 40.92965193092823, 39.53576512634754, 40.85940130054951, 42.0081252604723, 41.6630619764328, 41.90559156239033, 42.17692360281944, 43.25692065060139, 45.14203369617462, 45.80897010862827, 55.01421935856342, 57.23443642258644, 57.68078327178955, 54.219275414943695, 55.76163165271282, 56.06522776186466, 54.09528806805611, 53.76692868769169, 54.77330468595028, 57.33508162200451, 53.481886982917786, 50.03248907625675, 44.54374819993973, 40.192601680755615, 40.519015565514565, 39.36529107391834, 43.92242833971977, 46.54417745769024, 51.65299192070961, 53.99762190878391, 53.59437234699726, 56.79566256701946, 57.148515433073044, 52.16932341456413, 16.896619834005833, 0.8918294822797179, 3.0725018307566643, 5.501392297446728, 10.719148814678192, 5.070117339491844, 1.2341361329890788, 0.06276247906498611, 0.04225269738526549, 10.32757792621851, 56.74546346068382, 35.49500875174999, 31.60499408841133, 45.85811287164688, 2.380968863144517, 0.14889208629028872, 0.04399128592922352, 0.08254294851212762, 0.06636293430346996, 0.04445200378540903, 0.07499201150494628, 0.09560546750435606, 0.044364181740093045, 0.06299063752521761, 0.0766878857393749, 0.027164105958945584, 0.08427724373177625, 0.019424891652306542, 0.05514898271940183, 0.060514005381264724, 0.015289664279407589, 0.025035713624674827, 0.06597434577997774, 0.017748125865182374, 0.0188949295625207, 0.03189437156834174, 0.1165771359228529, 0.2750239579472691, 0.17736640758812428, 0.10516084148548543, 0.16987534705549479, 0.19561185588827357, 0.14355689054355025, 0.20126037154113874, 0.14242328965337947, 0.24109320365823805, 0.13358727941522375, 0.12493429763708264, 0.17783989780582488, 0.08868692195392214, 0.13965067046228796, 0.12181426427559927, 0.14499641954898834, 0.14160906459437683, 0.10947370654321276, 0.17741841729730368, 0.13659677730174735, 0.21629215712891892, 0.14676279039122164, 0.23608096089446917, 0.19757611298700795, 0.2601665473775938, 0.3679459827253595, 0.5855817091651261, 38.261161521077156, 49.75291147828102, 44.88623522222042, 69.24902692437172, 43.38864058256149, 15.427058190107346, 0.16445134591776878, 3.5827550757676363, 6.578359957784414, 8.073510378599167, 16.454519256949425, 9.492529984563589, 3.1784432334825397, 0.24784262117464095, 12.247296664863825, 70.4061484336853, 61.55575834214687, 65.55428758263588, 60.57444579899311, 66.56697124242783, 64.62642297148705, 64.90084424614906, 63.120191395282745, 65.34051865339279, 65.1011011004448, 63.760593831539154, 64.00010257959366, 67.68512204289436, 64.25118550658226, 62.506748512387276, 64.4939012825489, 68.80347803235054, 60.98704665899277, 53.075027614831924, 49.87176910042763, 49.559509456157684, 48.71266409754753, 51.94667436182499, 59.47619453072548, 65.10680839419365, 66.01030111312866, 63.106865510344505, 51.41051173210144, 48.988555893301964, 46.28635749220848, 44.828288331627846, 45.843400061130524, 49.70258317887783, 47.24334754049778, 55.097434893250465, 59.81959730386734, 61.0643345117569, 61.06653459370136, 61.61060079932213, 62.435008361935616, 64.02383610606194, 59.29874785244465, 64.63026836514473, 61.185912787914276, 57.316762804985046, 57.730647996068, 53.80587659776211, 60.58076485991478, 64.65598538517952, 62.23173066973686, 62.843349650502205, 63.00013303756714, 61.77251771092415, 62.292428612709045, 61.11970894038677, 61.33467100560665, 62.13069029152393, 58.73035915195942, 62.511859238147736, 59.30661343038082, 62.05687165260315, 54.51591029763222, 44.903733283281326, 43.299048990011215, 41.60300239920616, 42.0117312669754, 44.981621503829956, 43.99910442531109, 43.88442277908325, 44.519855082035065, 46.29106163978577, 47.14770287275314, 49.11845192313194, 57.07493998110294, 58.89506131410599, 60.77930800616741, 56.93845510482788, 57.95871935784817, 56.901224702596664, 54.33028645813465, 57.72516489028931, 58.13967704772949, 60.44483095407486, 54.79231886565685, 54.02140103280544, 47.487651631236076, 42.413970082998276, 42.619584649801254, 44.46514181792736, 47.079127952456474, 49.04831908643246, 53.2062915712595, 56.46072193980217, 55.78135259449482, 61.42332784831524, 58.23112294077873, 54.323180839419365, 15.92816960066557, 1.2853314983658493, 3.3994419872760773, 8.342810478061438, 12.226235345005989, 16.615089140832424, 16.03468358516693, 0.4428551037563011, 0.21609269751934335, 17.30976976454258, 61.13780736923218, 42.561557963490486, 43.90657939016819, 54.4348568469286, 2.2678420459851623, 0.2434221372823231, 0.2587936632335186, 0.2132038728450425, 0.20995193015551195, 0.12312161677982658, 0.1825905335135758, 0.16689673735527322, 0.10392068303190172, 0.13656352908583358, 0.20484461827436462, 0.10501301308977418, 0.13131791056366637, 0.12706635432550684, 0.12116294063162059, 0.1586552319349721, 0.06995272487984039, 0.17353389761410654, 0.16790485591627657, 0.1213360539986752, 0.08300790403154679, 0.11268040791037492], [0.04548314005660359, 0.028215443489898462, 0.013142443658580305, 0.04462611163035035, 0.05649446677125525, 0.01902189433167223, 0.016618456502328627, 0.031056564766913652, 0.06829204328823835, 0.02251207384688314, 0.011750811008823803, 0.07373277985607274, 0.06291253390372731, 0.03770922477997374, 0.05973247563815676, 0.054535289673367515, 0.03290398184617516, 0.054961293571977876, 0.013320818852662342, 0.016082470028777607, 0.07942752388771623, 0.018350039172219113, 0.08312077727168798, 0.01717169605399249, 0.07516451631090604, 0.0503238539386075, 0.026028475294879172, 0.23415710631525144, 4.7664647083729506, 46.01537123322487, 41.07117533683777, 52.06938497722149, 45.06694972515106, 15.010770577937365, 0.2607357152737677, 0.4682608076836914, 0.8703714399598539, 1.4464569836854935, 2.3080429388210177, 7.127398671582341, 3.7661926075816154, 1.4291916601359844, 0.1577402529073879, 24.642916470766068, 71.64923653006554, 58.88757951557636, 62.941912561655045, 64.5739933848381, 62.66927719116211, 57.866061329841614, 62.53756105899811, 59.03633773326874, 64.01294589042664, 60.99566459655762, 61.23933032155037, 62.67025373876095, 63.71508367359638, 58.39645206928253, 60.663760006427765, 61.414645314216614, 55.21131858229637, 44.776098132133484, 46.74876607954502, 47.40782931447029, 46.05937287211418, 53.15506651997566, 61.46513320505619, 61.04622468352318, 59.81447897851467, 56.9067458063364, 49.29537422955036, 43.62934626638889, 43.1939922273159, 42.52270884811878, 43.38240131735802, 42.16176241636276, 43.54344807565212, 44.262540489435196, 52.49791458249092, 52.59084239602089, 58.5281416028738, 54.40008111298084, 56.31742402911186, 56.19801543653011, 56.972022503614426, 57.06107832491398, 60.60495436191559, 55.82739472389221, 56.71480290591717, 53.53433936834335, 53.932846784591675, 56.34073577821255, 56.5718849748373, 56.565653309226036, 56.61559782922268, 60.387552827596664, 57.61411964893341, 57.05556482076645, 56.91250629723072, 58.10314200818539, 56.67011730372906, 56.827580854296684, 56.092628091573715, 52.51734293997288, 41.85837149620056, 39.78500135242939, 41.42430558800697, 39.27892930805683, 40.234285444021225, 39.718839302659035, 39.41781185567379, 39.76541340351105, 42.12488919496536, 41.30400784313679, 41.0176932066679, 47.50381216406822, 54.14153918623924, 54.46561239659786, 54.64884236454964, 55.286406353116035, 51.06186144053936, 53.93392592668533, 54.55428063869476, 53.882252499461174, 51.09243839979172, 52.321501448750496, 56.90147928893566, 53.860574662685394, 50.14895282685757, 43.64421866834164, 41.85985341668129, 39.53499376773834, 40.56180886924267, 43.58419328927994, 47.11272194981575, 50.28525911271572, 53.47684845328331, 52.17940807342529, 58.928879499435425, 31.376212164759636, 1.5870267595164478, 0.6022279034368694, 3.0161149939522147, 12.1848907135427, 8.322717156261206, 8.29122444614768, 0.7374678121414036, 0.061834256412112154, 0.33468565496150404, 26.948672644793987, 43.38927894830704, 24.42751742899418, 49.15173813700676, 14.256555698812008, 0.1972999153076671, 0.21377491095336154, 0.04207049641991034, 0.011817907652584836, 0.028855900236521848, 0.026293841328879353, 0.040949111280497164, 0.045854009804315865, 0.09090206207474694, 0.025370266375830397, 0.04485626646783203, 0.06968252375372685, 0.12387529743136838, 0.07028233492746949, 0.021368817615439184, 0.021834680410393048, 0.03511778610118199, 0.04902428285276983, 0.033609875608817674, 0.03838764052488841, 0.03354722350195516, 0.018613436659506988, 0.07037258008494973, 0.052184722444508225, 0.01794016770872986, 0.06068325586966239, 0.029287882134667598, 0.012204647300677607, 0.04450066640856676, 0.11774993705330417, 0.029247186466818675, 0.014594822023354936, 0.03301285862107761, 0.031538537732558325, 0.05521669998415746, 0.057404065228183754, 0.00650468504318269, 0.02755682453425834, 0.024970920421765186, 0.11001005666912533, 0.031696455625933595, 0.0358594031422399, 0.07155459868954495, 0.009297974902438, 0.03220512364350725, 0.032561324842390604, 0.14087582268984988, 0.022302656470856164, 0.05122702168591786, 0.3935071814339608, 8.763255067169666, 55.25475025177002, 37.40529544651508, 67.54584431648254, 53.582326993346214, 17.841163650155067, 0.2834511041874066, 0.4643307498190552, 0.7632919389288872, 3.2018882129341364, 2.243558499030769, 8.039932530373335, 7.153059644624591, 3.2064942782744765, 0.22878351184772328, 30.294364616274834, 70.69431737065315, 60.23015767335892, 62.56052702665329, 66.57163739204407, 64.32791098952293, 61.1540324985981, 64.355239123106, 58.68324168026447, 65.51067352294922, 62.09339149296284, 62.40033522248268, 64.23350885510445, 67.13644668459892, 61.41325458884239, 61.865726709365845, 64.07279267907143, 57.605178728699684, 47.225526496768, 47.35213950276375, 49.06788803637028, 47.340930104255676, 55.62564454972744, 64.08894941210747, 64.83310908079147, 63.56184929609299, 57.464829459786415, 51.09781891107559, 46.239764392375946, 45.69855183362961, 43.33437189459801, 46.05154529213905, 44.681847989559174, 45.12642413377762, 47.393933460116386, 54.94462609291077, 55.534871220588684, 59.977281242609024, 57.65532083809376, 59.14628483355045, 57.98723302781582, 59.24643985927105, 59.32684354484081, 61.77567534148693, 57.36681371927261, 57.538412511348724, 53.036345690488815, 52.94751025736332, 56.365001276135445, 60.65255060791969, 60.49382172524929, 55.91328911483288, 59.33063194155693, 60.982756689190865, 56.78169831633568, 58.432375341653824, 59.62013840675354, 58.029669150710106, 56.904602721333504, 57.41219088435173, 55.1946222782135, 44.98976066708565, 41.31726533174515, 43.338331282138824, 41.93903736770153, 42.993875965476036, 42.886866107583046, 41.810627058148384, 41.15708492696285, 43.899268582463264, 42.701812237501144, 42.46521033346653, 49.14427153766155, 55.38969241082668, 57.09148429334164, 58.04300643503666, 56.05700120329857, 54.5586846023798, 53.975704684853554, 54.82037656009197, 56.054580733180046, 54.24379549920559, 56.35376147925854, 58.20692963898182, 56.53316505253315, 49.885839745402336, 46.30970723927021, 44.48946811258793, 40.77533081173897, 42.576734349131584, 44.3250585347414, 49.31027702987194, 53.12600947916508, 56.30529887974262, 55.629721730947495, 58.111828342080116, 33.99450346827507, 2.374373604543507, 1.1759366746991873, 5.762336645275354, 13.254373725503683, 7.571183508262038, 4.609053879976273, 0.7058892503846437, 0.0945029106514994, 0.6903021305333823, 30.741931200027466, 57.89275489747524, 24.118668101727962, 49.518950432538986, 21.123452223837376, 0.29835770430509, 0.168173884449061, 0.031566160469083115, 0.045605145423905924, 0.03925688099116087, 0.03777195110160392, 0.06102585721237119, 0.048457478696946055, 0.04097543525858782, 0.017115123991970904, 0.05412153863289859, 0.08597987893153913, 0.07809156159055419, 0.0498323926149169, 0.06367612964822911, 0.06815956992795691, 0.054945296578807756, 0.037866634302190505, 0.02577437877334887, 0.005422405984063516, 0.042366999259684235, 0.011301935046503786, 0.11649388921796344, 0.13974544272059575, 0.12397326092468575, 0.2018312315340154, 0.18603276286739856, 0.08803298595012166, 0.10905866787652485, 0.2494843112071976, 0.1272373303072527, 0.06548081757500768, 0.11021943879313767, 0.17229595076059923, 0.10758099248050712, 0.1650104799773544, 0.0709141994593665, 0.12677485356107354, 0.09332830610219389, 0.25220389652531594, 0.10593712053378113, 0.19569812313420698, 0.18253053829539567, 0.12917553802253678, 0.20957665576133877, 0.12767816602718085, 0.20708335126983002, 0.16797001648228616, 0.1374217783450149, 0.40827660297509283, 11.222885884344578, 70.20109623670578, 49.89267937839031, 64.063171595335, 55.05332686007023, 28.54131728410721, 0.591002058936283, 1.4345746650360525, 3.84050355758518, 8.101088348776102, 7.558338772505522, 18.210365138947964, 11.243603322654963, 3.8618370378389955, 0.49391919805202633, 28.77415169030428, 71.97396710515022, 61.301513984799385, 64.36975434422493, 68.50672915577888, 68.42388600111008, 64.63694080710411, 65.4780712723732, 61.51838734745979, 67.44416937232018, 65.29798373579979, 64.6344481408596, 66.7713774740696, 68.77273008227348, 64.38186049461365, 64.83473539352417, 65.75100302696228, 59.56809259951115, 48.71662348508835, 49.30932328104973, 52.26759374141693, 51.37932300567627, 59.60524320602417, 64.9847361445427, 67.72766456007957, 66.17868527770042, 60.22428318858147, 53.85071039199829, 48.84505659341812, 48.026086539030075, 46.53577230870724, 50.2040346711874, 47.36433684825897, 47.66024596989155, 50.2000030875206, 57.89008744060993, 57.56774693727493, 64.70349043607712, 59.931387305259705, 60.39884202182293, 61.64455197751522, 61.83171473443508, 59.003750681877136, 64.41222846508026, 58.306860476732254, 59.46771718561649, 53.6523762345314, 53.59885610640049, 56.86833366751671, 60.71270138025284, 60.69166570901871, 58.75914640724659, 58.37548479437828, 63.581296652555466, 57.542675882577896, 57.080567479133606, 60.906430184841156, 58.930680602788925, 59.467907175421715, 59.961880668997765, 55.85320293903351, 45.10847769677639, 43.729695081710815, 46.33247181773186, 43.76015804708004, 44.47967603802681, 43.47590669989586, 44.2423065751791, 44.313982129096985, 47.89760023355484, 44.97537463903427, 45.15371806919575, 51.88813850283623, 59.00251194834709, 59.14569206535816, 59.6777319163084, 59.823879674077034, 55.63103266060352, 57.24664896726608, 58.47185142338276, 56.75285026431084, 56.575772166252136, 57.642918303608894, 62.915355786681175, 59.7545599937439, 52.20176987349987, 48.48279923200607, 47.87257857620716, 43.75385798513889, 46.53802938759327, 48.148367777466774, 53.2418804615736, 56.25508077442646, 59.847985580563545, 55.884311869740486, 59.78602610528469, 34.271991178393364, 2.085377024486661, 2.4462902080267668, 10.950241014361382, 27.555526681244373, 19.772995188832283, 18.453027717769146, 1.6898517357185483, 0.3239889023825526, 1.0542077128775418, 38.771014362573624, 56.15004301071167, 33.34908150136471, 62.008967623114586, 24.91588432341814, 0.3271175891859457, 0.26664650591555983, 0.11397173002478667, 0.11956536385696381, 0.06215001798409503, 0.15021797764347866, 0.13026319997152314, 0.17520413064630702, 0.19347347610164434, 0.24885550432372838, 0.16286139842122793, 0.2094662093441002, 0.20232484879670665, 0.1410960327484645, 0.15852747863391414, 0.1189299370162189, 0.07919748037238605, 0.1221972495841328, 0.12381926528178155, 0.10342950001358986, 0.15790601901244372, 0.12423651554854587], [0.046209357533371076, 0.0858498620800674, 0.03520082129398361, 0.03854842310829554, 0.024155283426807728, 0.022457687409769278, 0.03922098330804147, 0.034423243487253785, 0.02740455438470235, 0.049137486348627135, 0.015950393717503175, 0.08096656005363911, 0.05191589429159649, 0.0306978180014994, 0.059316590923117474, 0.045666769656236283, 0.042502059004618786, 0.038220041315071285, 0.13765702431555837, 0.07643926626769826, 0.033944268798222765, 0.03827722008281853, 0.057951688577304594, 0.0605420511419652, 0.03486095476546325, 0.09683887241408229, 0.04205129705951549, 0.045547398913186044, 0.36496115382760763, 19.449765533208847, 47.95806638896465, 20.665924474596977, 40.92404343187809, 40.154622718691826, 2.908151149749756, 0.11137674388010055, 0.43551368988119066, 1.462047309614718, 2.3366328421980143, 3.757214401848614, 4.7460707277059555, 2.5567939784377813, 0.4392841859953478, 1.2427405337803066, 37.70214691758156, 68.04724261164665, 62.05394200980663, 65.99990487098694, 62.096784710884094, 64.62459146976471, 62.51983501017094, 64.62302595376968, 62.52536751329899, 62.55203828215599, 60.13411782681942, 61.663828343153, 61.547664776444435, 62.539042979478836, 63.67297813296318, 58.74634109437466, 52.441502809524536, 47.476381435990334, 47.75595523416996, 44.940579906105995, 49.08004358410835, 59.098718985915184, 59.04160425066948, 61.98839172720909, 63.16372945904732, 61.12759351730347, 54.63591545820236, 46.288701966404915, 42.509838938713074, 42.65308365225792, 42.642489820718765, 43.34387518465519, 43.81631523370743, 42.00259655714035, 46.91958591341972, 48.499514535069466, 53.06134074926376, 53.40244084596634, 56.465262696146965, 56.6685251891613, 54.954364970326424, 58.11305187642574, 57.54669986665249, 57.661449909210205, 59.00368228554726, 57.63008639216423, 51.018775552511215, 51.75167262554169, 51.72883965075016, 59.45390112698078, 62.08706483244896, 58.075373098254204, 56.77890546619892, 56.21288023889065, 57.76948191225529, 59.954729452729225, 57.11114063858986, 56.63698688149452, 51.82106450200081, 43.530680760741234, 39.65919390320778, 41.35403975844383, 39.42069590091705, 40.303316339850426, 41.1231679469347, 41.459123119711876, 42.03698091208935, 41.17713265120983, 42.111650705337524, 41.97376370429993, 48.38261000812054, 51.115100383758545, 50.988692566752434, 53.4838704764843, 56.01152144372463, 53.039928898215294, 54.17727626860142, 55.999510288238525, 54.853085204958916, 54.482456892728806, 55.428454130887985, 53.374842926859856, 53.926630318164825, 56.68812833726406, 55.07617503404617, 48.10181267559528, 42.70145885646343, 43.11917044222355, 42.02791839838028, 44.99448001384735, 49.49579827487469, 51.153767108917236, 54.00493271648884, 57.222983837127686, 55.37181057035923, 10.238683596253395, 0.8786058356054127, 1.3599611562676728, 2.0627720374614, 4.033612282946706, 5.80025433562696, 1.4332890277728438, 0.17659868550254032, 0.05506811088707764, 4.583304086700082, 48.23932729661465, 31.326336041092873, 29.178273305296898, 44.49823044240475, 3.3155676629394293, 0.05898617935599759, 0.06151042027340736, 0.035926968266721815, 0.02129589789547026, 0.01891839627205627, 0.014333884755615145, 0.014452821342274547, 0.09348486215458252, 0.05525631953787524, 0.030151552782626823, 0.03935010216082446, 0.02145370075595565, 0.04199180650175549, 0.009294269730162341, 0.02233221250207862, 0.026671089835872408, 0.0448460916231852, 0.08219784242101014, 0.04019022817374207, 0.019589000912674237, 0.047459961715503596, 0.014948786574677797, 0.02958907905849628, 0.056128387586795725, 0.07022504854830913, 0.03565117505786475, 0.034122521537938155, 0.013433615094982088, 0.0365231614705408, 0.05057779089838732, 0.08188952459022403, 0.02216704382590251, 0.012858387563028373, 0.042546079494059086, 0.0071558458785148105, 0.010051115641545039, 0.02324819713976467, 0.057064039137912914, 0.10711231137975119, 0.05331233420292847, 0.11514027864905074, 0.09837324047111906, 0.03854068250802811, 0.02705450930079678, 0.03695082035847008, 0.06434121271013282, 0.030642169913335238, 0.02509441565052839, 0.044347290458972566, 0.0331887661741348, 0.4752475640270859, 31.96480058133602, 51.96574553847313, 25.452689118683338, 54.18192721903324, 42.81682826578617, 3.149508023634553, 0.053277052502380684, 1.27579175401479, 1.542259342968464, 2.4629473267123103, 3.7491417350247502, 6.9081927090883255, 4.341552034020424, 1.752860548440367, 2.8840884659439325, 43.28333303332329, 67.1601802110672, 63.895395398139954, 67.65126585960388, 64.02879104018211, 64.95097115635872, 64.1267953813076, 65.89751556515694, 64.38443675637245, 62.340028658509254, 63.00941973924637, 63.31224448978901, 64.03588905930519, 66.14811211824417, 64.33588296175003, 62.34527237713337, 55.51243342459202, 50.41496895253658, 49.461812898516655, 46.1945354193449, 51.17409981787205, 61.3062409311533, 61.126461178064346, 63.844690918922424, 63.653808161616325, 63.147948905825615, 56.08951985836029, 47.64669969677925, 45.27783080935478, 44.43766549229622, 44.36436742544174, 45.37101700901985, 44.499738961458206, 45.84380283951759, 49.78750862181187, 51.87165878713131, 55.72444684803486, 56.61631979048252, 59.31612052023411, 57.91930787265301, 59.107458516955376, 61.31656117737293, 61.34210340678692, 59.6209591627121, 60.28626926243305, 57.518398985266685, 50.73190614581108, 51.80473677814007, 51.44384354352951, 55.80306462943554, 62.09092542529106, 61.829678043723106, 57.590883895754814, 59.066777899861336, 59.36763055622578, 61.167757362127304, 60.01177579164505, 59.47901017963886, 55.28475344181061, 45.861221104860306, 42.26274959743023, 42.081115543842316, 41.020527854561806, 43.00957292318344, 42.90402218699455, 42.17211306095123, 42.43295766413212, 43.6152870208025, 44.02172081172466, 43.41582432389259, 48.519649654626846, 52.50050224363804, 53.93265679478645, 56.52787193655968, 59.05346341431141, 55.1203628629446, 55.292664617300034, 57.12199665606022, 56.46384157240391, 55.54055571556091, 56.09100937843323, 55.17633765935898, 56.70161001384258, 56.842631846666336, 56.44631691277027, 50.8078982681036, 45.56426703929901, 44.58935335278511, 44.40217159688473, 46.5878751128912, 51.41566805541515, 52.35615558922291, 56.23841866850853, 55.391254127025604, 56.701370626688, 10.977261364459991, 1.6573786782100797, 5.475612580776215, 2.8652858873829246, 11.734128501266241, 2.362501616589725, 0.5729812884237617, 0.16573998145759106, 0.044871617792523466, 4.578261757269502, 56.692608296871185, 38.30522395670414, 27.248503156006336, 52.799352407455444, 4.814261393621564, 0.11605923558818176, 0.05341598254744895, 0.008778230330790393, 0.00746374532354821, 0.02162532982765697, 0.008710679121577414, 0.03291770044597797, 0.030146999706630595, 0.04402269361889921, 0.020537549135042354, 0.044592915364773944, 0.02972777161630802, 0.0988290378882084, 0.03659844493085984, 0.032394790614489466, 0.013760568253928795, 0.038066910274210386, 0.029920902561570983, 0.020439450199774, 0.020045529345225077, 0.05545482177694794, 0.020395142128109, 0.1515764492796734, 0.21115511481184512, 0.11618173448368907, 0.11804004258010536, 0.08089736220426857, 0.13204509654315189, 0.20246076572220773, 0.16455413337098435, 0.10989319067448378, 0.13144840981112793, 0.14191242487868294, 0.35348924284335226, 0.1489687798311934, 0.10676681937184185, 0.10707595356507227, 0.14529743464663625, 0.2724596002371982, 0.1360989297972992, 0.282131684361957, 0.28905093495268375, 0.0854061394056771, 0.12891345599200577, 0.16642606729874387, 0.14189905137754977, 0.2567794150672853, 0.11203462810954079, 0.0908688287017867, 0.12294946078327484, 0.7208602095488459, 36.97015419602394, 63.96256059408188, 33.03224690258503, 49.97896894812584, 56.172119826078415, 5.724889179691672, 0.4918500903295353, 2.917244774289429, 7.080062236636877, 9.584785234183073, 12.100235056132078, 11.988017577677965, 6.641855500638485, 2.688184753060341, 3.055512229911983, 42.00372129678726, 69.51176762580872, 63.51060904562473, 68.58418419957161, 67.7504101395607, 69.11683201789856, 66.9656990468502, 68.45773458480835, 67.17667132616043, 64.4232326745987, 64.78069469332695, 65.07808953523636, 66.5517720580101, 68.06746512651443, 67.61471942067146, 65.38540184497833, 58.347267508506775, 53.04381988942623, 52.91497640311718, 48.49580593407154, 53.63918334245682, 62.79938980937004, 63.67486283183098, 65.16793191432953, 67.52261996269226, 66.11408114433289, 58.95156808197498, 50.745167434215546, 47.700539007782936, 46.847127601504326, 45.861889868974686, 47.69608564674854, 48.7461668998003, 46.657399982213974, 50.332691967487335, 53.98383244872093, 56.85379184782505, 59.053885191679, 63.77128645777702, 59.623341634869576, 60.528304874897, 64.21651616692543, 63.58654037117958, 61.59227058291435, 62.92282998561859, 58.39885354042053, 52.141277119517326, 52.762935161590576, 50.840249732136726, 57.371848449110985, 60.911616906523705, 62.38389350473881, 60.04856541752815, 58.76864589750767, 62.153983041644096, 63.624325543642044, 62.41802327334881, 62.7059718221426, 58.299443274736404, 46.31414920091629, 45.412351191043854, 45.61287023127079, 43.99123504757881, 44.67644467949867, 46.51825524866581, 45.02388283610344, 45.66883362829685, 44.81134124100208, 45.47256276011467, 46.186058074235916, 53.492503613233566, 55.619329288601875, 56.35766766965389, 58.08234952390194, 61.96263290941715, 56.21408097445965, 57.5007489323616, 60.26505120098591, 58.87374825775623, 59.27591107785702, 59.97016802430153, 58.34021508693695, 56.80458448827267, 59.06943015754223, 60.71415290236473, 52.06381067633629, 48.745604529976845, 46.64840966463089, 47.6933041960001, 47.41833195090294, 54.32042598724365, 54.590941071510315, 61.60666041076183, 58.63047771155834, 57.792075499892235, 11.38205649331212, 2.7467358112335205, 6.479281699284911, 6.560767851769924, 9.654635936021805, 17.666314132511616, 3.923419858328998, 1.6489635547623038, 0.1489498995942995, 8.282263576984406, 64.07083198428154, 43.20967398583889, 38.1898507475853, 59.12579633295536, 5.909455725923181, 0.19885737157892436, 0.2706046763341874, 0.12955631915247068, 0.17464380915043876, 0.12541059317300096, 0.12831397878471762, 0.11339684759150259, 0.18031004728982225, 0.17635701253311709, 0.17563552624778822, 0.08762787721934728, 0.15027213958092034, 0.1799547515111044, 0.09057908682734706, 0.1644393231254071, 0.1065628178184852, 0.13714243395952508, 0.16778260935097933, 0.11074729874962941, 0.1679319591494277, 0.12457324279239401, 0.09755654406035319], [0.04292409241315909, 0.056985282426467165, 0.06066916248528287, 0.018056651497317944, 0.03663344090455212, 0.07936058958875947, 0.028316568532318342, 0.030425232725974638, 0.04186769343505148, 0.06333963247016072, 0.04860768938669935, 0.0612227860983694, 0.041496207704767585, 0.03142704488709569, 0.10177822143305093, 0.03488924172415864, 0.02663115672476124, 0.028821904306823853, 0.03837117226794362, 0.05270821857266128, 0.04354082455392927, 0.016739498933020514, 0.02302444332599407, 0.06117754106526263, 0.012002464009128744, 0.024265696447400842, 0.06728795458911918, 0.07926068909000605, 0.14051292731892318, 0.48610120662488043, 35.23942306637764, 40.749963372945786, 33.817831948399544, 59.080685153603554, 16.47991519421339, 0.13961046090116724, 0.5219045479316264, 0.8011073316447437, 1.5582358231768012, 2.420152835547924, 7.964005954563618, 2.5016629742458463, 0.6093798321671784, 0.5432976374868304, 3.7794417841359973, 46.31696864962578, 62.89632260799408, 68.9316375553608, 62.55124792456627, 64.35872733592987, 63.95515099167824, 65.35799011588097, 62.340568229556084, 63.60374964773655, 62.65498995780945, 63.173304945230484, 63.50762240588665, 63.970737755298615, 59.094269424676895, 60.24010553956032, 52.43845157325268, 46.827988028526306, 47.027522921562195, 47.4631467461586, 54.3858926743269, 60.63659906387329, 61.61498576402664, 62.84740023314953, 59.873102232813835, 60.10294809937477, 58.01583789288998, 47.54716783761978, 43.648067861795425, 43.117460533976555, 43.68820510804653, 43.83176140487194, 43.47800798714161, 43.24541486799717, 45.12786045670509, 47.63688862323761, 49.010655507445335, 51.0181637853384, 51.70841574668884, 53.11279758810997, 53.02336558699608, 54.57924149930477, 54.36196155846119, 53.89715149998665, 58.50646756589413, 57.681448236107826, 51.67657345533371, 61.26483455300331, 65.57584002614021, 60.821310952305794, 54.197004809975624, 52.453069388866425, 60.07517918944359, 57.83023685216904, 58.970202282071114, 56.426690965890884, 55.67262902855873, 52.24390961229801, 43.6188056319952, 40.74483744800091, 39.239590018987656, 41.732643842697144, 40.702815502882004, 42.78993330895901, 42.728729993104935, 39.07562881708145, 40.07412403821945, 41.34219579398632, 43.54254752397537, 50.10926395654678, 52.890600711107254, 55.56718468666077, 53.16225193440914, 51.94679595530033, 54.7320768982172, 57.75490589439869, 53.818883299827576, 51.64160393178463, 53.45538720488548, 53.66353243589401, 52.54765011370182, 54.062872007489204, 54.86908994615078, 59.73556101322174, 53.43236044049263, 50.927527248859406, 45.85453346371651, 43.931126073002815, 43.32438603043556, 45.4421453922987, 52.51725174486637, 55.14955669641495, 52.81324066221714, 60.32459020614624, 32.62864775955677, 1.1005351832136512, 1.2342938245274127, 1.360446223989129, 4.026798298582435, 16.61603718996048, 2.0480226539075375, 0.7141536881681532, 0.22667702956823632, 0.09581922087818384, 17.1683394536376, 52.46206730604172, 22.697607055306435, 42.01135888695717, 19.73939549177885, 0.18831954250345007, 0.08652044445625506, 0.017865053087007254, 0.017083035381801892, 0.004421375397214433, 0.029525003883463796, 0.06270745623623952, 0.061990062895347364, 0.06480059470050037, 0.058461039370740764, 0.04521573682723101, 0.05626343248877674, 0.016354775143554434, 0.052694934129249305, 0.013748243036388885, 0.03982175556302536, 0.04969306923158001, 0.05085047450847924, 0.027836376721097622, 0.019829143202514388, 0.0804849952692166, 0.04461391443328466, 0.06235937413293868, 0.01737823389703408, 0.07518531871028244, 0.011844241835206049, 0.012363132009340916, 0.08559381371014751, 0.04341238476627041, 0.04481758202018682, 0.04273832913895603, 0.05647375714033842, 0.023366540008282755, 0.05578814627369866, 0.016475394550070632, 0.09868580338661559, 0.0726109197421465, 0.025607351017242763, 0.055480592855019495, 0.00016450088821784448, 0.016308526355715003, 0.013574955264630262, 0.1005866662308108, 0.03612796041124966, 0.05818798468681052, 0.041684561074362136, 0.020231144189892802, 0.05160781765880529, 0.015323613824875792, 0.060408316130633466, 0.05870904657058418, 0.06432622132706456, 2.3993052542209625, 50.077398866415024, 35.25890462100506, 34.83177714049816, 66.84197008609772, 18.323612362146378, 0.32599406666122377, 0.8715966960880905, 1.1253364523872733, 1.651736693456769, 2.494188300333917, 4.6997664123773575, 5.636100294068456, 2.4592225765809417, 0.9976388420909643, 5.7001525070518255, 54.570327177643776, 63.11214342713356, 69.97020542621613, 63.84714558720589, 66.94240629673004, 63.69102716445923, 65.86240544915199, 62.28310391306877, 65.46744704246521, 62.97293409705162, 64.53455150127411, 64.99631032347679, 66.43768697977066, 63.990838676691055, 62.923570945858955, 51.89205229282379, 49.224777817726135, 47.790818363428116, 47.61429883539677, 55.03657355904579, 63.98651450872421, 62.70375654101372, 62.29826509952545, 61.434636041522026, 62.35521264374256, 58.38220663368702, 49.381815791130066, 44.84013609588146, 44.99355286359787, 45.42495131492615, 45.17853833734989, 45.749811083078384, 45.36921590566635, 46.11804932355881, 50.02418652176857, 52.65210270881653, 53.11248600482941, 53.65503989160061, 56.62231966853142, 57.23008185625076, 57.017042487859726, 56.247530579566956, 56.333341374993324, 59.56008642911911, 57.161860316991806, 52.65060938894749, 57.950614392757416, 58.875043988227844, 61.74595333635807, 57.68008030951023, 52.601968199014664, 59.16026048362255, 60.10232113301754, 58.35596144199371, 58.93329866230488, 56.364640295505524, 53.01860824227333, 46.41815721988678, 42.91110500693321, 41.41777753829956, 43.818104937672615, 42.03604616224766, 44.43494863808155, 44.22586105763912, 42.90575869381428, 42.73134045302868, 43.02015535533428, 44.96538497507572, 49.79193538427353, 55.31163699924946, 57.18870587646961, 55.09851783514023, 56.22367165982723, 55.54055571556091, 57.25510351359844, 55.3626112639904, 53.459152802824974, 55.26664741337299, 55.84424301981926, 54.89510715007782, 55.25986857712269, 56.68130770325661, 62.415447011590004, 55.00834107398987, 53.28195311129093, 49.14193846285343, 46.37618087232113, 45.63778929412365, 47.316497415304184, 53.798884972929955, 57.803034111857414, 54.42673668265343, 61.09950542449951, 32.97687627375126, 1.0495615121908486, 3.1316710682585835, 3.9454142656177282, 4.8854676727205515, 6.323183225467801, 2.5951032852753997, 0.5835877661593258, 0.4777690552873537, 0.05755855068855453, 18.704821206629276, 67.39069864153862, 25.04012245684862, 41.70093074440956, 27.805467769503593, 0.4750147374579683, 0.22978306602453813, 0.06610677461139858, 0.018994763267983217, 0.029366501548793167, 0.03778244135901332, 0.06940787716303021, 0.08019853368750773, 0.006323109337245114, 0.0265146413948969, 0.02541425717936363, 0.016704623558325693, 0.02967232390801655, 0.04968135443050414, 0.019852845543937292, 0.021450207095767837, 0.009377355017932132, 0.06102292572904844, 0.04508212427026592, 0.04313917423132807, 0.02033976121310843, 0.03017077255208278, 0.038982008045422845, 0.14926566858775914, 0.19684097118442878, 0.2919746999396011, 0.13517562387278304, 0.20028242870466784, 0.1579531008610502, 0.09181626926874742, 0.1280866441084072, 0.15402681310661137, 0.2170084632234648, 0.2628054760862142, 0.1818556885700673, 0.2419326320523396, 0.12356182909570634, 0.15301154024200514, 0.2809165808139369, 0.10056461702333763, 0.09677110690972768, 0.1007839290832635, 0.14563246979378164, 0.07127440825570375, 0.2205246253288351, 0.11352384390193038, 0.12130711766076274, 0.1087209906836506, 0.1807312309392728, 0.21101576916407794, 0.2737309585791081, 0.19406392879318446, 3.5990234278142452, 60.95914475619793, 52.020116820931435, 43.41330125927925, 73.47542613744736, 30.714937448501587, 0.45406456163618714, 2.284253602847457, 2.9302963614463806, 4.2287056893110275, 9.715976044535637, 18.456054255366325, 9.569955579936504, 7.2454968094825745, 1.3062771619297564, 6.320386100560427, 52.771294713020325, 64.21986758708954, 72.44109123945236, 69.53506797552109, 70.43777033686638, 68.21247294545174, 69.28716167807579, 64.82554748654366, 67.6753793656826, 65.68573012948036, 66.7307348549366, 69.18004542589188, 69.01629701256752, 63.22639189660549, 65.04547208547592, 55.15612654387951, 52.968542128801346, 49.50972072780132, 50.423203110694885, 57.29758523404598, 69.03472602367401, 65.23688301444054, 67.05079928040504, 62.33497492969036, 64.4535930454731, 61.7496657371521, 52.6236118376255, 48.01314823329449, 47.710528671741486, 49.350687861442566, 49.014660492539406, 46.89986877143383, 49.00681011378765, 49.18044559657574, 51.86014160513878, 57.672134935855865, 55.22394150495529, 57.21558943390846, 59.17581304907799, 58.756072372198105, 59.67843487858772, 58.30785222351551, 58.52743484079838, 62.55383558571339, 60.55884003639221, 50.803213119506836, 57.36502781510353, 59.28346887230873, 59.980283081531525, 58.59904199838638, 54.77783404290676, 60.368044674396515, 62.09478601813316, 61.575878262519836, 60.812092646956444, 58.10433894395828, 55.29179826378822, 46.774965673685074, 43.994643464684486, 42.849039137363434, 45.90952031314373, 44.81100305914879, 48.03539603948593, 47.45512917637825, 45.61606585979462, 44.84876923263073, 47.25834533572197, 49.235409647226334, 54.7933866083622, 56.87952406704426, 59.88100200891495, 58.23303043842316, 57.18790411949158, 58.72223138809204, 63.38708907365799, 56.16385526955128, 54.640300422906876, 57.75608763098717, 59.13128323853016, 55.38954421877861, 57.35378801822662, 58.753458112478256, 62.311636582016945, 55.93785099685192, 56.32692351937294, 52.033340111374855, 47.94118769466877, 46.798368617892265, 49.8215775936842, 55.98087228834629, 59.95009370148182, 56.49567246437073, 62.544959262013435, 32.382466569542885, 1.5139700984582305, 4.087454443797469, 5.44063925743103, 10.59231637045741, 35.58202788233757, 9.647916946560144, 2.0714464969933033, 0.7247042970266193, 0.17024472879711539, 24.800207130610943, 69.0215939283371, 29.698915667831898, 55.49791060388088, 33.98856818675995, 0.4027283366303891, 0.31492472626268864, 0.20272921537980437, 0.07849229165003635, 0.11021213605999947, 0.07192860401119106, 0.17094031412852928, 0.18674136546906084, 0.11727472505299374, 0.1331106128054671, 0.11883057086379267, 0.14996082347352058, 0.09073687484487891, 0.14738168218173087, 0.07873399430536665, 0.17918143363203853, 0.13416490779491141, 0.09470699384110048, 0.16298462462145835, 0.12485451676184312, 0.17879524966701865, 0.22107623401097953, 0.13499746390152723], [0.03033226945262868, 0.0432482773612719, 0.05293776484904811, 0.0531723428866826, 0.008725913558009779, 0.03291937398898881, 0.03819110497715883, 0.010956259357044473, 0.051761646318482235, 0.03162080480251461, 0.060887313084094785, 0.05531175425858237, 0.029567649544333108, 0.041808956157183275, 0.040672331015230156, 0.04128549342567567, 0.010431367991259322, 0.06844420582638122, 0.04218589296215214, 0.09611622095690109, 0.049564017172087915, 0.05121539223182481, 0.021519161891774274, 0.03334644658025354, 0.08565700758481398, 0.0032765859350547544, 0.06045873393304646, 0.05856066527485382, 0.0806161921354942, 0.013808528619847493, 13.683835230767727, 51.35261803865433, 30.431858338415623, 53.5617358982563, 42.98794448375702, 3.007423197850585, 0.2612854092149064, 0.4741371626732871, 0.7949527900200337, 1.0476915375329554, 4.211215702816844, 5.72167550213635, 1.6297162813134491, 0.48804925521835685, 0.12247095364728011, 14.8740054666996, 64.30561378598213, 65.93733742833138, 64.40404370427132, 62.771499305963516, 61.819669380784035, 66.27383217215538, 62.91564077138901, 63.24618883430958, 65.25781989097595, 64.80528697371483, 62.61367857456207, 63.60657289624214, 62.820265889167786, 59.230872094631195, 52.34855979681015, 49.4153717905283, 48.245121985673904, 46.80749572813511, 58.048884719610214, 60.22028960287571, 62.03078605234623, 63.34091015160084, 62.61154308915138, 59.64470028877258, 57.93573059141636, 51.95854112505913, 46.808050498366356, 43.21685940027237, 42.91747726500034, 43.400526344776154, 43.68813671171665, 43.915303722023964, 43.48456263542175, 44.818906635046005, 46.41684629023075, 47.39438943564892, 50.81356756389141, 51.36316627264023, 51.448650285601616, 51.48214928805828, 51.81389808654785, 58.59566777944565, 59.16473664343357, 57.891633957624435, 41.67801037430763, 41.327809765934944, 49.290548488497734, 46.961820647120476, 53.887731805443764, 57.61019065976143, 58.86403977870941, 59.44304130971432, 57.7463373541832, 54.49736729264259, 52.373946234583855, 44.973337948322296, 41.44432671368122, 42.69031025469303, 39.61714915931225, 42.27547891438007, 41.48039057850838, 40.711767822504044, 41.799273267388344, 41.41597643494606, 40.08487366139889, 46.97345182299614, 52.625834718346596, 56.359111592173576, 55.53778566420078, 57.25914269685745, 56.17727994918823, 53.297897055745125, 54.71229135990143, 55.4393595457077, 57.295331954956055, 53.77379111945629, 52.87625268101692, 55.015515089035034, 56.900745928287506, 58.06538723409176, 56.16419345140457, 57.16057598590851, 56.55563324689865, 52.78822660446167, 47.83271111547947, 46.679678186774254, 49.037941843271255, 50.7836289703846, 53.901943042874336, 54.69059832394123, 54.17831741273403, 56.53471916913986, 8.9636867120862, 0.4309251985978335, 2.34258356038481, 3.7267666356638074, 1.4085053326562047, 5.465951124206185, 0.2454787027090788, 0.1380350298131816, 0.3321851516375318, 0.8806512539740652, 38.19138206541538, 38.787060901522636, 22.523221112787724, 48.02656151354313, 7.926359474658966, 0.11094022745965049, 0.10794327929033898, 0.06792079875594936, 0.1170580624602735, 0.02456949088809779, 0.04659041696868371, 0.061984507919987664, 0.1137174479663372, 0.04491064362809993, 0.021814722203998826, 0.027098492682853248, 0.025103978223341983, 0.028978139380342327, 0.07330521373660304, 0.053027089743409306, 0.05188985975109972, 0.014062083373573842, 0.05005406099371612, 0.01877661452454049, 0.03857458010315895, 0.08862906412105076, 0.06696274547721259, 0.02938237423222745, 0.02872250846849056, 0.028677727277681697, 0.050083316455129534, 0.025354553254146595, 0.017010662995744497, 0.049214064856641926, 0.03137080122542102, 0.03656561973912176, 0.07610478773131035, 0.0299720235489076, 0.049646402985672466, 0.019729717678274028, 0.0212012536576367, 0.05101448914501816, 0.10652260083588772, 0.07972337363753468, 0.06832516533904709, 0.057152955851051956, 0.04371371898741927, 0.0400557695684256, 0.051028619636781514, 0.027655454105115496, 0.02385214207606623, 0.07009679800830781, 0.13287642068462446, 0.038883684610482305, 0.15699507726822048, 0.02791918370348867, 0.07111764440196566, 0.10690115552279167, 21.293969973921776, 58.67285683751106, 29.428579173982143, 70.15935927629471, 49.95462365448475, 3.4904254926368594, 0.5128678609617054, 0.7316519867163152, 0.9434845636133105, 1.8283141683787107, 4.929977059364319, 8.471772707998753, 4.586652657017112, 3.3282238338142633, 0.25684546621050686, 17.87047527730465, 68.41624841094017, 63.49505268037319, 69.21989768743515, 65.5965793132782, 64.9038764834404, 65.44018730521202, 64.40288096666336, 63.41906815767288, 67.30306774377823, 65.28372690081596, 65.16586482524872, 65.16021832823753, 63.76825422048569, 60.14596939086914, 54.477653950452805, 50.9027411788702, 50.12486971914768, 49.30349059402943, 59.614628702402115, 63.05417753756046, 65.09436786174774, 64.05825465917587, 64.85856011509895, 63.22160415351391, 60.46970821917057, 53.67188058793545, 48.64371299743652, 46.57380826771259, 45.081221759319305, 45.11100456118584, 45.4343444108963, 46.20762571692467, 45.32307118177414, 47.80383266508579, 49.10763390362263, 50.71941241621971, 52.70105168223381, 55.38058429956436, 52.47573897242546, 52.65591770410538, 55.08757442235947, 60.306525975465775, 61.38377957046032, 60.25248907506466, 43.24085511267185, 43.17149743437767, 55.24515576660633, 53.0487672239542, 53.92467342317104, 60.56726038455963, 60.899997130036354, 60.548166409134865, 59.65759679675102, 56.1081350594759, 54.65220518410206, 49.105821400880814, 43.151468709111214, 45.585089921951294, 41.72472886741161, 43.88090416789055, 42.25728929042816, 43.336461782455444, 42.65657186508179, 42.98114284873009, 41.73558108508587, 47.19420097768307, 54.39683608710766, 57.89750084280968, 57.652102410793304, 59.51912462711334, 57.59968422353268, 54.64185453951359, 55.56957095861435, 56.56981788575649, 58.23600947856903, 57.332873940467834, 55.90043440461159, 56.97665065526962, 57.86744825541973, 58.425360918045044, 56.16012766957283, 58.281204253435135, 58.23672764003277, 54.094094932079315, 49.466828629374504, 48.05387444794178, 49.55757535994053, 52.471430003643036, 55.94798885285854, 56.54483042657375, 55.82609139382839, 55.73868088424206, 9.878695663064718, 1.1433711159043014, 3.2005276484414935, 6.4579738676548, 5.1625611539930105, 4.532725950703025, 0.08230347229982726, 0.4484682634938508, 0.08077567967120558, 0.5667361454106867, 42.00518041849136, 50.10208234190941, 21.355984546244144, 56.12149514257908, 10.527509897947311, 0.11867425229866058, 0.13135748187778518, 0.0792489928426221, 0.07039307078230195, 0.023831755279388744, 0.01186408500871039, 0.04172283734078519, 0.014227629617380444, 0.039350436127278954, 0.04461627817363478, 0.03171246746205725, 0.019721947392099537, 0.02757176767772762, 0.025550869868311565, 0.09140564638073556, 0.02383133596595144, 0.043566881358856335, 0.050184315332444385, 0.053674194277846254, 0.03494420518109109, 0.06964747211895883, 0.06534584317705594, 0.026865597465075552, 0.12422031446476467, 0.1072099557495676, 0.20293887209845707, 0.13623496546642855, 0.06810363425756805, 0.10078984400024638, 0.13220173423178494, 0.06642900028964505, 0.17871604766696692, 0.1276936917565763, 0.15730023354990408, 0.10440429614391178, 0.1459113392047584, 0.1224502625700552, 0.20425774273462594, 0.2078536115004681, 0.09035622730152681, 0.1675627109943889, 0.17317204124992713, 0.11085887323133647, 0.20213295909343287, 0.11234279751079157, 0.11284121646895073, 0.11718495487002656, 0.294973956188187, 0.20425613969564438, 0.2839687076630071, 0.24754074518568814, 0.13597401150036603, 0.17009166826028377, 26.80319555103779, 71.18347272276878, 43.513881862163544, 66.38173118233681, 62.36406996846199, 5.740482592955232, 1.4828945347107947, 2.489109872840345, 3.2770089944824576, 8.009722251445055, 13.793825078755617, 14.705711547285318, 5.9922893811017275, 3.120891759172082, 0.21859274071175605, 19.643779322504997, 68.16401794552803, 68.83516073226929, 70.03476396203041, 68.16191285848618, 65.66576600074768, 69.06757146120071, 65.88412508368492, 65.87969452142715, 68.29872071743011, 69.64023113250732, 68.25623139739037, 66.27529889345169, 67.23822042346, 64.53093409538269, 55.79459868371487, 54.91363115608692, 52.68032379448414, 52.01716057956219, 61.974974647164345, 65.6740115582943, 65.42418256402016, 66.48538202047348, 66.96678578853607, 66.04611039161682, 64.89300146698952, 58.23222108185291, 51.21314652264118, 47.58752167224884, 45.81172116100788, 48.26404117047787, 47.51843757927418, 47.66588866710663, 47.18953102827072, 48.981936648488045, 51.163920164108276, 52.956432178616524, 56.55746094882488, 56.78604148328304, 54.80343706905842, 56.22662790119648, 59.17293660342693, 65.74028000235558, 63.00194554030895, 61.53890624642372, 43.63625429570675, 43.662936463952065, 55.30820578336716, 55.389145240187645, 57.27014310657978, 61.69522985816002, 63.24829012155533, 63.92336189746857, 63.31033319234848, 58.99186111986637, 55.847514644265175, 49.62808437645435, 46.067728623747826, 49.07154344022274, 44.39506217837334, 47.17720448970795, 45.951637253165245, 46.082323640584946, 45.01194007694721, 44.830431416630745, 44.55059923231602, 51.34267397224903, 56.99322536587715, 61.773114278912544, 59.48013111948967, 63.47325325012207, 60.16604371368885, 56.257820427417755, 58.095876798033714, 59.35892142355442, 62.54082888364792, 58.44992280006409, 57.03496232628822, 59.29641857743263, 61.561427637934685, 60.01613795757294, 57.14150480926037, 59.92716193199158, 60.793606638908386, 56.572435945272446, 51.88295938074589, 52.052977457642555, 52.90071576833725, 56.11725836992264, 58.42497333884239, 57.65138424932957, 57.400069534778595, 56.891295835375786, 9.881763998419046, 0.9611726144794375, 6.641973294317722, 8.401678819209337, 9.154515322297812, 16.976121068000793, 4.488467825576663, 0.8629254426341504, 0.7130233675707132, 1.765953458379954, 50.42732208967209, 50.76833479106426, 30.594050735235214, 66.24033316969872, 12.662938311696053, 0.30222622328437865, 0.32495057734195143, 0.12047436117427424, 0.18547155079431832, 0.13154925283743069, 0.1459256181260571, 0.10418850186397322, 0.2467325612087734, 0.1544149563414976, 0.16474041243782267, 0.20324736804468557, 0.10007883684011176, 0.1387393576442264, 0.10447584660141729, 0.20039668976096436, 0.16983194625936449, 0.1587972344714217, 0.16201785852899775, 0.20897878159303218, 0.11935710979741998, 0.22488965594675392, 0.19103949889540672, 0.07802023377735168], [0.05315739232173655, 0.06552129430929199, 0.06235461696633138, 0.031155029209912755, 0.011394487355573801, 0.0413654041767586, 0.04390329690068029, 0.0760040114982985, 0.023766129015712067, 0.02715684775466798, 0.03646656157798134, 0.043859948054887354, 0.06302266119746491, 0.02627141362609109, 0.020539051984087564, 0.06460608521592803, 0.06768568637198769, 0.07654376066057011, 0.08349783282028511, 0.016069076118583325, 0.026803895307239145, 0.0343564687500475, 0.02917333535151556, 0.04396013799123466, 0.045064086370985024, 0.05951781684416346, 0.04374472591734957, 0.04025155183626339, 0.08418604120379314, 0.09809216688154265, 1.5580676821991801, 44.05164800584316, 38.029940128326416, 26.560736261308193, 56.227361261844635, 16.995526626706123, 0.09341406126623042, 0.3135076694888994, 0.5183048942126334, 0.873631308786571, 2.096703741699457, 3.855560962110758, 2.1920242393389344, 2.2877470403909683, 0.5771648045629263, 0.19927540852222592, 27.306845225393772, 69.60113883018494, 62.857112511992455, 66.88436061143875, 65.11986449360847, 67.02021092176437, 66.50281548500061, 70.18300920724869, 64.24081206321716, 64.47387635707855, 66.0701858997345, 62.89918005466461, 59.73486565053463, 58.394327983260155, 51.78137183189392, 47.69695959985256, 49.15947072207928, 52.990459352731705, 60.836593732237816, 62.0886417478323, 61.885698437690735, 60.15933707356453, 61.436076164245605, 60.81062212586403, 58.83462555706501, 53.83357331156731, 47.500855922698975, 43.44977930188179, 45.28561279177666, 43.08615781366825, 44.71329890191555, 45.67858770489693, 46.061451360583305, 42.71057836711407, 43.9275086671114, 44.39718246459961, 47.72044613957405, 48.17176692187786, 48.98734375834465, 49.89103026688099, 55.667932480573654, 56.63947954773903, 60.28234027326107, 54.69839930534363, 51.7815276235342, 54.1350719332695, 55.210334435105324, 58.94606977701187, 58.613561019301414, 56.450694277882576, 55.860464349389076, 56.367668733000755, 56.58454589545727, 51.65467523038387, 45.165771022439, 40.55900081992149, 43.26553478837013, 39.715381488204, 41.74483358860016, 41.1474334448576, 41.29442095756531, 41.76648862659931, 42.07511566579342, 40.73899336159229, 40.17539620399475, 55.15010766685009, 58.39766800403595, 57.98328123986721, 56.16952456533909, 56.703798696398735, 54.974731877446175, 54.49244275689125, 54.050214886665344, 57.01823182404041, 56.340450793504715, 53.71630020439625, 55.27317926287651, 53.47242549061775, 53.44656027853489, 56.32244735956192, 56.640710681676865, 56.282644495368004, 54.53135646879673, 53.287804797291756, 50.76542414724827, 48.60978841781616, 49.672086015343666, 54.89665366709232, 58.798082917928696, 56.66760943830013, 61.42044760286808, 30.09697660803795, 0.2530729811405763, 1.4259313163347542, 1.4066781057044864, 3.822069796733558, 4.131922982633114, 1.5971516724675894, 0.2618668373906985, 0.46031899633817375, 0.3227452706778422, 7.420038068667054, 52.23582744598389, 23.71250219643116, 38.22540543973446, 33.79234291613102, 0.6392955675255507, 0.07440270172082819, 0.07347821578150615, 0.007774056748530711, 0.029308287485037, 0.05156120707397349, 0.049616104806773365, 0.027424868821981363, 0.1713043820927851, 0.006049146450095577, 0.03522353472362738, 0.059262369613861665, 0.06821121598477475, 0.05857653610291891, 0.038997166411718354, 0.052957005027565174, 0.04764094926940743, 0.04118005279451609, 0.0625557018793188, 0.042057267637574114, 0.04562160625937395, 0.03705388240632601, 0.015310950002458412, 0.02016093145357445, 0.03912523141480051, 0.009177705233014422, 0.02830381657986436, 0.02973945487610763, 0.014421441483136732, 0.015151206425798591, 0.034163959353463724, 0.06815541390096769, 0.014225882787286537, 0.030542857566615567, 0.04475537520193029, 0.03036127072846284, 0.03160110820317641, 0.06291822617640719, 0.10108625778229907, 0.005544487885345006, 0.10161295256693847, 0.04008113617601339, 0.0437509822222637, 0.011579374895518413, 0.03458643805061001, 0.025417184951948002, 0.028824429464293644, 0.028506758717412595, 0.04625527421012521, 0.06310534387012012, 0.06993336966843344, 0.03834537521470338, 0.0011408662840040051, 0.06521443850942887, 3.191524031572044, 57.011646777391434, 36.91546753048897, 33.94884131848812, 71.42225190997124, 17.74007197469473, 0.07752616380457766, 0.19444925186689943, 0.6138975522480905, 0.5766140716150403, 2.626330959610641, 3.438201332464814, 6.18147267960012, 3.7336703902110457, 2.2566927317529917, 0.1989093516021967, 31.22816640883684, 71.16336420178413, 65.9849488735199, 69.17924746870995, 68.58658567070961, 68.25850367546082, 68.14710885286331, 70.62767654657364, 65.77713042497635, 66.8729916214943, 67.62320816516876, 66.81515112519264, 62.729686349630356, 61.647196635603905, 53.53243187069893, 49.82384607195854, 49.766955524683, 54.60161089897156, 64.2606545984745, 62.65896834433079, 63.64047847688198, 62.98011191189289, 62.274124994874, 63.690354600548744, 60.80592937767506, 54.795803278684616, 50.024653896689415, 45.07090151309967, 47.45556615293026, 44.93870660662651, 45.98411791026592, 47.50277481973171, 46.99216961860657, 47.02917203307152, 46.85292989015579, 48.79480428993702, 50.62014654278755, 50.07086701691151, 52.11418837308884, 51.01177252829075, 57.42122679948807, 61.24935798346996, 61.940529495477676, 56.56680844724178, 50.21169126033783, 52.26188264787197, 56.35807424783707, 58.11266049742699, 61.41155607998371, 58.98232363164425, 57.76838757097721, 57.33294993638992, 58.57142128050327, 52.36204147338867, 48.477544113993645, 42.42374695837498, 43.7445142865181, 42.13343493640423, 43.495266661047935, 42.01988942921162, 43.46957623958588, 43.61766569316387, 45.26323579251766, 42.08723321557045, 42.94758304953575, 57.20459662377834, 60.921959951519966, 57.54856176674366, 58.06372672319412, 58.83644945919514, 57.733334451913834, 58.054063841700554, 56.553938537836075, 59.22115981578827, 58.547455966472626, 55.28161101043224, 56.24301262199879, 55.181873962283134, 58.28899383544922, 58.527586832642555, 57.768125385046005, 58.0707411468029, 55.90397581458092, 54.527974650263786, 54.46165680885315, 50.73774643242359, 52.15232692658901, 56.855467557907104, 60.3984734416008, 57.31184206902981, 63.15929889678955, 33.41204412281513, 0.32854384859092534, 2.4938486935570836, 3.5947626689448953, 10.90121889486909, 2.2973327385261655, 1.7381656682118773, 0.14199558994732797, 0.09311010726378299, 0.119256051548291, 7.45594329200685, 67.42869660258293, 27.91385505348444, 35.897118374705315, 44.453218057751656, 0.9055346937384456, 0.05615599548036698, 0.02716560324188322, 0.011012493741873186, 0.0450066367193358, 0.025068889481190126, 0.046404431050177664, 0.03380460031621624, 0.027479715390654746, 0.0110895982470538, 0.0071463083531853044, 0.019507425895426422, 0.016001525837054942, 0.06826053169788793, 0.013165191412554123, 0.040185240941355005, 0.032254224133794196, 0.04849953991652001, 0.026634568748704623, 0.036673995564342476, 0.020317917951615527, 0.03645719196356367, 0.023300256943912245, 0.02935335440270137, 0.1358713724766858, 0.16727716225432232, 0.21234511892544106, 0.1907120633404702, 0.14237046358175576, 0.09149788791546598, 0.15459405141882598, 0.164259456214495, 0.09570821042871103, 0.0727586071297992, 0.1281861957977526, 0.1470659428741783, 0.1739517564419657, 0.1859536350821145, 0.1737413724185899, 0.08128068890073337, 0.18728832830674946, 0.1828286293311976, 0.1964100802433677, 0.05925685916736256, 0.28238989238161594, 0.195665008504875, 0.15143131488002837, 0.1423564666765742, 0.15566734538879246, 0.12927339761517942, 0.19724014273378998, 0.08855662308633327, 0.19471217994578183, 0.3049706853926182, 4.055156176909804, 62.72102661430836, 51.15994557738304, 36.12696424126625, 70.4085423052311, 28.46975762397051, 0.2596260857535526, 2.8465030202642083, 1.2927430006675422, 5.10324633680284, 7.277697706595063, 10.576037093997002, 8.76836959272623, 6.02323729544878, 2.459472413174808, 0.7539469934999943, 30.08684255182743, 73.63108858466148, 68.25756892561913, 71.26019820570946, 70.221698731184, 72.41911321878433, 70.32061502337456, 73.42544361948967, 68.33179414272308, 68.50238978862762, 69.73429888486862, 68.80681425333023, 66.43637225031853, 64.49699431657791, 55.67039094865322, 51.83225870132446, 53.3831112831831, 57.43649438023567, 67.47348859906197, 66.52550786733627, 65.40797263383865, 63.06663326919079, 64.12000134587288, 64.56731334328651, 62.90900632739067, 56.97103075683117, 53.885075747966766, 49.143614172935486, 51.19825892150402, 47.79624827206135, 48.95446792244911, 50.12633644044399, 50.99924840033054, 47.948376908898354, 50.02716936171055, 50.642572939395905, 51.5382494777441, 51.71545296907425, 53.25572691857815, 54.044735580682755, 58.97916980087757, 60.340689942240715, 64.32787299156189, 58.91218699514866, 54.00685541331768, 57.93263755738735, 60.12148730456829, 60.862987115979195, 62.363936975598335, 60.912749245762825, 58.81564557552338, 58.698019087314606, 60.456644520163536, 55.6322105973959, 49.341442957520485, 44.2411932349205, 47.336966916918755, 43.56368958950043, 46.06514856219292, 45.41936941444874, 45.06680153310299, 47.66283743083477, 47.57725842297077, 46.66015483438969, 45.5096335709095, 60.53746998310089, 62.63678513467312, 60.997541695833206, 61.92522011697292, 61.232046112418175, 59.02201630175114, 60.01944378018379, 59.463867992162704, 61.90654791891575, 59.4157587736845, 56.51346690952778, 58.93530115485191, 57.35959030687809, 58.32554027438164, 61.053022518754005, 61.01740702986717, 59.17744696140289, 56.202442198991776, 58.29164609313011, 54.76864613592625, 54.2681597918272, 55.200036987662315, 60.445837900042534, 64.23041582107544, 60.40968284010887, 63.01159702241421, 32.40998089313507, 0.42245206888765097, 3.625203547999263, 4.208533996716142, 10.17253864556551, 11.302424166351557, 6.271773409098387, 0.9776959684677422, 1.4437759900465608, 0.502997653093189, 11.11290268599987, 68.46699848771095, 32.201839461922646, 48.711862340569496, 52.096093744039536, 1.3057003053836524, 0.16614519408904016, 0.20719851774629205, 0.11076062030042522, 0.2288609475363046, 0.13357311923755333, 0.1158146905072499, 0.105134732730221, 0.1786864359746687, 0.11724812648026273, 0.21215601969743147, 0.1959200104465708, 0.11360834483639337, 0.10311248421203345, 0.10627381067024544, 0.13181238871766254, 0.240924172103405, 0.11983897144091316, 0.09172991296509281, 0.14052944752620533, 0.184357765247114, 0.13800109882140532, 0.08440474470262416, 0.16204494691919535], [0.04099634526937734, 0.04185620869975537, 0.05544049090531189, 0.03361725255672354, 0.06263473318540491, 0.07961490875459276, 0.06461211887653917, 0.026448894532222766, 0.009915446407831041, 0.021231763348623645, 0.0627320732746739, 0.03859762378851883, 0.030119597759039607, 0.043359020637581125, 0.03385110328963492, 0.02147749957657652, 0.05914965222473256, 0.024133833503583446, 0.015950863125908654, 0.07674592910916544, 0.07544300722656772, 0.034474470230634324, 0.05885122351173777, 0.07500767824240029, 0.08319177853991278, 0.02091962902341038, 0.03683103401272092, 0.03783123385801446, 0.05375682871090248, 0.06806583667639643, 0.19052943564020097, 12.276082020252943, 55.51074631512165, 32.18406401574612, 40.64732328057289, 51.84261694550514, 3.4062623837962747, 0.08049879921600223, 0.2717408153694123, 0.13670342392288148, 1.1823290004394948, 2.34090072568506, 6.478316551074386, 4.906990667805076, 1.7480249516665936, 0.5268834088928998, 3.04066167678684, 44.77235533297062, 66.66708067059517, 69.05492573976517, 65.26655942201614, 65.7050558924675, 67.18006834387779, 64.2478796839714, 66.4945775270462, 66.67365431785583, 63.55784051120281, 63.344576954841614, 60.93035750091076, 57.794271782040596, 51.2422339618206, 51.11048363149166, 51.08011186122894, 54.072785675525665, 60.315778478980064, 63.05354677140713, 61.70040138065815, 62.7698539942503, 65.77925071120262, 64.63147670030594, 61.288222298026085, 52.856394946575165, 49.0640464425087, 44.796104058623314, 45.60262218117714, 45.44705852866173, 44.07585270702839, 44.63246203958988, 46.065995916724205, 46.89601577818394, 44.509025663137436, 44.098358899354935, 47.55661033093929, 47.966395542025566, 48.17556291818619, 52.97027103602886, 58.38537946343422, 59.478394612669945, 62.949390560388565, 55.53212396800518, 62.06293612718582, 64.85547468066216, 59.70523104071617, 58.29825393855572, 61.76985785365105, 58.726403564214706, 55.23913688957691, 59.01596702635288, 54.09050032496452, 50.06281904876232, 44.443767964839935, 43.40951286256313, 41.57819353044033, 42.092419937253, 40.07175296545029, 41.134989112615585, 41.56916901469231, 41.259930208325386, 42.33510911464691, 40.19225209951401, 44.1353765130043, 53.4961324185133, 58.423757404088974, 60.01488022506237, 56.90768055617809, 59.34101678431034, 57.211972028017044, 57.18162305653095, 55.85968539118767, 56.52041293680668, 58.29662382602692, 56.33248642086983, 54.07326065003872, 54.35083955526352, 56.26312114298344, 59.06068302690983, 56.39618620276451, 57.28515990078449, 56.03300929069519, 50.46934403479099, 48.32996383309364, 48.571030497550964, 58.33693966269493, 53.95991653203964, 57.49133683741093, 54.60808955132961, 59.66624513268471, 7.715832721441984, 0.38130648143123835, 1.420004228129983, 3.572884392924607, 15.223175380378962, 1.3818247080780566, 0.574635862139985, 0.08857440494466573, 0.15591779054375365, 0.1383922848617658, 29.686566330492496, 39.084626734256744, 21.16435132920742, 47.59452849626541, 9.875564631074667, 0.021087764434923884, 0.19609385111834854, 0.04322288106777705, 0.014875787073833635, 0.04316170212405268, 0.0456314211623976, 0.027727197521016933, 0.060478950035758317, 0.01137882061811979, 0.04949654852680396, 0.015017358236946166, 0.051406287457211874, 0.014534430683852406, 0.06635014709900133, 0.03885643294779584, 0.0337352688802639, 0.043663839242071845, 0.037319701150408946, 0.026433481980348006, 0.026742350855784025, 0.03735362472070847, 0.013957952633063542, 0.02722329223615816, 0.09993025145377032, 0.07460728957084939, 0.024763872352195904, 0.024202183449233416, 0.01316237681749044, 0.08920235835830681, 0.058597728129825555, 0.03456928701780271, 0.040329755647690035, 0.018212875438621268, 0.03711814868438523, 0.011197224503121106, 0.013837109654559754, 0.07659255687030964, 0.019217413137084804, 0.03558707205229439, 0.08187595070921816, 0.08500728697981685, 0.09454725397517905, 0.028589177927642595, 0.023656016564927995, 0.03007075887580868, 0.028699802460323554, 0.04570412194880191, 0.0805616813886445, 0.043516994192032143, 0.0954501137312036, 0.04925926907162648, 0.015098505591595313, 0.09086656515137292, 0.05582454119576141, 0.22572491347091272, 19.889800921082497, 62.637708485126495, 24.01975940912962, 53.39093126356602, 58.090184703469276, 2.420662483200431, 0.03028332666872302, 0.28396152367349714, 0.12505228427471593, 0.3793449851218611, 1.6369313816539943, 6.98638966307044, 3.483231528662145, 4.501757612451911, 1.1878905957564712, 3.819453399628401, 52.19854764640331, 69.50312688946724, 71.39069080352783, 68.89241605997086, 68.21074023842812, 66.80047631263733, 67.65397131443024, 68.02259713411331, 68.1286570429802, 64.58498239517212, 67.12110310792923, 61.85633361339569, 59.45204682648182, 52.266457602381706, 51.64050579071045, 52.19317473471165, 56.14083610475063, 61.10892131924629, 64.67787981033325, 64.96646672487259, 65.41276037693024, 65.85035249590874, 66.09746843576431, 62.60196000337601, 54.783754125237465, 51.72702714800835, 46.70236676931381, 48.299215883016586, 46.643732115626335, 46.92098043859005, 46.070342883467674, 48.350725919008255, 47.72066652774811, 46.68062053620815, 47.66289822757244, 48.559342324733734, 50.28821915388107, 50.270975679159164, 54.900780245661736, 61.2710852175951, 60.29474280774593, 64.7861436009407, 58.64670664072037, 61.91326215863228, 67.82798677682877, 62.92987860739231, 61.87861181795597, 63.641485422849655, 59.12435241043568, 59.26158584654331, 61.5900819003582, 56.326790526509285, 51.624276861548424, 46.17205202579498, 45.305626317858696, 44.74006466567516, 42.95842386782169, 41.99120096862316, 43.29285152256489, 43.210114762187004, 43.212121054530144, 43.8623421639204, 42.13892184197903, 45.40907196700573, 55.855566412210464, 60.22845156490803, 61.71430863440037, 59.99178886413574, 59.90514971315861, 59.26746793091297, 57.86166496574879, 57.71843925118446, 58.66129785776138, 59.78507235646248, 57.36236035823822, 56.431904286146164, 55.943402498960495, 57.55866162478924, 60.378456115722656, 58.70064474642277, 57.609157115221024, 59.47788543999195, 51.607143580913544, 50.70724166929722, 48.96471597254276, 58.42438817024231, 57.96161100268364, 58.956097438931465, 55.907737612724304, 60.55125184357166, 9.60155563428998, 1.140532549470663, 2.7045632991939783, 5.866277692839503, 10.536953341215849, 1.330046548973769, 0.2571817778516561, 0.05130655023094732, 0.1789550785906613, 0.05923480253841262, 32.64180265367031, 47.14842863380909, 17.717147804796696, 53.267342895269394, 14.57636933773756, 0.19017041428014636, 0.15073877235408872, 0.010642768756952137, 0.04609500370861497, 0.05483989305503201, 0.041970477177528664, 0.027821839903481305, 0.025176038907375187, 0.049819078485597856, 0.06911054311785847, 0.038884326568222605, 0.010341056040488183, 0.0929389605880715, 0.08060712309088558, 0.0035718011486096657, 0.015843889959796797, 0.04647853449569084, 0.023657677120354492, 0.03801910854235757, 0.03640744951553643, 0.032271104282699525, 0.020611663712770678, 0.006085870236347546, 0.014497974534606328, 0.10643681598594412, 0.11103304786956869, 0.1860521626076661, 0.18621908646309748, 0.17724598670611158, 0.2687180775683373, 0.15359581826487556, 0.10986848457832821, 0.10810079271323048, 0.1291883474914357, 0.1903720706468448, 0.15035368676763028, 0.13355311093619093, 0.08902079192921519, 0.1776365196565166, 0.12963672343175858, 0.1610606216127053, 0.22112928272690624, 0.14965832408051938, 0.14924597198842093, 0.19793676707195118, 0.08948204413172789, 0.21911426272708923, 0.2121753600658849, 0.26391923194751143, 0.14387145725777373, 0.17751247709384188, 0.1347397456993349, 0.1550471325754188, 0.19036288285860792, 0.33045529446098953, 22.646475099027157, 75.8120347559452, 39.322699159383774, 54.700652584433556, 68.09891983866692, 5.633714022114873, 0.15577897924231365, 1.5735885431058705, 0.7058253663126379, 5.773626314476132, 10.355070400983095, 15.863121841102839, 12.36991323530674, 4.484164556488395, 1.3135815574787557, 4.731434863060713, 48.890688344836235, 70.11753112077713, 73.69099617004395, 72.11936250329018, 68.50976899266243, 71.83025121688843, 68.38922426104546, 70.81761315464973, 71.31350174546242, 68.62665072083473, 69.43969309329987, 65.40701508522034, 64.40732672810555, 54.469028413295746, 55.58475114405155, 56.50241710245609, 58.867524191737175, 65.24701327085495, 66.82262152433395, 65.59790924191475, 66.227026283741, 69.99984383583069, 70.02972543239594, 66.71080112457275, 56.48008570075035, 54.940621107816696, 50.47431416809559, 50.91044716536999, 48.74435819685459, 49.316797479987144, 47.30085365474224, 50.38588531315327, 51.07582189142704, 48.508132472634315, 49.28276650607586, 53.50828416645527, 52.39015996456146, 53.29044945538044, 59.43384200334549, 62.9917810857296, 63.07570718228817, 69.7434563934803, 59.828013852238655, 65.31657233834267, 70.72055876255035, 66.08652502298355, 64.68785807490349, 68.24248373508453, 63.57243172824383, 61.36672608554363, 64.68725010752678, 59.360357746481895, 55.052019730210304, 49.78490576148033, 48.36413159966469, 46.80339954793453, 45.80447494983673, 44.137094020843506, 46.37127913534641, 45.84864757955074, 45.76087988913059, 45.78332908451557, 43.89413885772228, 48.83501373231411, 56.25740244984627, 62.50782385468483, 64.70702424645424, 61.66337236762047, 63.70261274278164, 61.59486964344978, 60.66733941435814, 58.9968578517437, 60.904173105955124, 63.78238946199417, 59.47997532784939, 58.497823029756546, 57.11098104715347, 62.535201385617256, 63.91567870974541, 61.12818628549576, 58.82756933569908, 60.59533707797527, 53.61771449446678, 52.97798082232475, 52.29271799325943, 63.50570350885391, 59.01914365589619, 63.4989170730114, 56.743981540203094, 62.02174253761768, 9.53976335003972, 1.598582889419049, 4.501058924943209, 11.358347665518522, 29.16968386620283, 8.686338644474745, 4.456442669034004, 0.3006747190374881, 0.49158852780237794, 0.5079665395896882, 41.5197716653347, 52.42785394191742, 29.198704808950424, 64.17152658104897, 16.969889402389526, 0.2830829395679757, 0.3883811377454549, 0.09407798657775857, 0.14320367277832702, 0.11930361579288729, 0.159351262554992, 0.12363724614260718, 0.1420168302138336, 0.21007664065109566, 0.12509898020653054, 0.10043321235571057, 0.1112275647756178, 0.28677758818957955, 0.24824856111081317, 0.15634517854778096, 0.1106978791358415, 0.1363257152843289, 0.13261104351840913, 0.10347206960432231, 0.1466902974061668, 0.10264980708598159, 0.07518036858527921, 0.14361169072799385, 0.10347232935600914], [0.029981213192513678, 0.11150830439873971, 0.05117527914990205, 0.018089712320943363, 0.023048774637572933, 0.023449623440683354, 0.12173055001767352, 0.041502130043227226, 0.04966814420185983, 0.016047192038968205, 0.024368203739868477, 0.025659167768026236, 0.029289540834724903, 0.014299653194029815, 0.06994543698965572, 0.039770818257238716, 0.08246307115769014, 0.029398495535133407, 0.028980926144868135, 0.0481522036716342, 0.06669774680631235, 0.04106073029106483, 0.03711231540364679, 0.062070968124317005, 0.03129743621684611, 0.026327584928367287, 0.08424444080446847, 0.03036469945072895, 0.06623172259423882, 0.07679773843847215, 0.03452974167885259, 0.9849027567543089, 37.16553971171379, 50.69860093295574, 24.098075106739998, 57.72442393004894, 27.881746776401997, 0.4221340437652543, 0.25571725331246853, 0.12805878388462588, 0.2503794600488618, 2.5392021099105477, 3.040443188510835, 1.695444204378873, 2.1120848413556814, 1.129318519961089, 0.44862156151793897, 10.466000698506832, 57.29291148483753, 63.523148372769356, 68.19750934839249, 69.54025089740753, 65.70903807878494, 66.46047055721283, 63.37118312716484, 65.90086698532104, 62.30665884912014, 59.94492217898369, 57.13970370590687, 54.96522858738899, 53.508614748716354, 51.32823474705219, 48.35602663457394, 59.549807980656624, 60.74086546897888, 65.67662581801414, 64.03344199061394, 63.946229070425034, 59.76135402917862, 61.46987535059452, 62.563840448856354, 56.18332162499428, 49.7745893150568, 46.68436713516712, 44.2984751611948, 45.48022694885731, 45.14500513672829, 45.87721444666386, 44.58111919462681, 47.76789799332619, 43.57329547405243, 45.88926360011101, 49.38037946820259, 50.23140840232372, 50.14689713716507, 55.84202393889427, 56.7686802148819, 60.70518158376217, 60.889836475253105, 58.981875255703926, 58.18301372230053, 58.78360949456692, 59.816865250468254, 60.04094682633877, 55.09665213525295, 59.69012685120106, 56.05287842452526, 50.07777884602547, 46.88270129263401, 42.46346242725849, 43.374638333916664, 42.68472835421562, 43.43483850359917, 40.71932561695576, 43.12460035085678, 43.46051372587681, 44.682148173451424, 45.942589938640594, 42.704848274588585, 42.53240592777729, 44.15570542216301, 55.94404846429825, 57.922788485884666, 58.35522808134556, 55.642739832401276, 57.656133994460106, 56.458077281713486, 58.00722375512123, 54.05852884054184, 57.119978964328766, 58.17576751112938, 56.338478699326515, 53.94340641796589, 56.79714448750019, 56.00983053445816, 59.60616275668144, 56.29518382251263, 58.07936668395996, 52.474918216466904, 54.8742500692606, 48.57148267328739, 52.61832632124424, 54.30920138955116, 56.119458451867104, 54.7079785913229, 63.828184604644775, 20.13849377632141, 0.13178193097701296, 1.6592213418334723, 0.8556002075783908, 4.743944266811013, 9.095492139458656, 0.5540833587292582, 0.03134539379971102, 0.1650230519589968, 0.10775412069051526, 9.344614371657372, 55.96199110150337, 26.202210299670696, 40.089357420802116, 32.67900265753269, 0.24268183013191447, 0.050992117103305645, 0.10115034965565428, 0.022966887918300927, 0.03626753241405822, 0.015256571914505912, 0.056571052700746804, 0.005868352782272268, 0.07842010294552892, 0.05519067657587584, 0.043013142712879926, 0.044729318397003226, 0.07076135414536111, 0.06247747951420024, 0.0460740157723194, 0.04124643048271537, 0.0724810958490707, 0.08017897067475133, 0.05226592824328691, 0.07761637185467407, 0.039976074040168896, 0.05042177661380265, 0.030587417968490627, 0.018192132411058992, 0.04133959599130321, 0.07989213059772737, 0.10539204275119118, 0.01146896836871747, 0.028205841954331845, 0.03614915985963307, 0.04591693650581874, 0.07308969405130483, 0.056822796614142135, 0.07139949724660255, 0.04184069039183669, 0.03709491946210619, 0.015147257272474235, 0.035801241028821096, 0.028108756050642114, 0.040786020617815666, 0.017796222600736655, 0.029337279484025203, 0.04452096043678466, 0.10726419190177694, 0.02377862863795599, 0.039113071325118653, 0.08905058915843256, 0.054740705018048175, 0.05396530912548769, 0.032747715231380425, 0.031608047283953056, 0.05323893579770811, 0.061095760102034546, 0.03490802177111618, 0.0578746239625616, 0.036538991480483674, 1.21077949879691, 51.10698401927948, 47.526470348238945, 25.82027569413185, 75.66015690565109, 27.650069408118725, 0.19221366557758301, 0.13806965842377394, 0.061792967026121914, 0.43892632238566875, 1.2670630286447704, 3.4664775151759386, 3.269812655635178, 10.211453307420015, 3.5593426320701838, 0.9833828383125365, 13.395965527743101, 62.75278151035309, 66.29027768969536, 70.0269515812397, 71.36314988136292, 68.92472192645073, 69.89922523498535, 66.99952483177185, 68.0247250199318, 65.68477258086205, 63.414242416620255, 59.680615961551666, 58.6433932185173, 55.12366108596325, 51.048360764980316, 52.44652234017849, 62.38967299461365, 63.287063241004944, 66.71660721302032, 65.80990746617317, 64.00254964828491, 62.6090694218874, 64.2925500869751, 63.024877309799194, 57.619158178567886, 50.905119851231575, 49.0526432543993, 46.80039390921593, 48.077752366662025, 45.00031270086765, 48.142272904515266, 45.91988615691662, 48.19274179637432, 46.89754709601402, 48.814840614795685, 50.96814326941967, 50.860058069229126, 51.05295851826668, 58.33098918199539, 58.099205419421196, 63.46622362732887, 61.67665645480156, 58.29280503094196, 59.15817439556122, 62.089196518063545, 59.19835723936558, 60.36198779940605, 57.61792704463005, 61.35493151843548, 56.481898203492165, 54.860510006546974, 51.711436584591866, 44.06115509569645, 45.84563434123993, 44.66314159333706, 45.22051468491554, 43.403030410408974, 44.58482399582863, 46.332323625683784, 45.845193564891815, 48.010393381118774, 45.81378445029259, 44.482442289590836, 47.10389122366905, 58.150844648480415, 59.3748539686203, 60.89194916188717, 55.75073763728142, 59.011475667357445, 59.16953958570957, 58.61364081501961, 56.91366523504257, 61.13298162817955, 60.7389959692955, 57.28140950202942, 56.713822558522224, 58.71199853718281, 57.85572208464146, 59.13113884627819, 58.710642009973526, 60.51118679344654, 55.133468359708786, 56.616133600473404, 49.90082234144211, 55.324883088469505, 56.19327329099178, 59.327394515275955, 56.17319516837597, 64.36548337340355, 22.799952663481236, 0.21242795744910836, 2.6956812757998705, 3.487051036208868, 5.271872263401747, 3.7545937299728394, 0.3910218772944063, 0.09713146413560025, 0.2395570618682541, 0.04756158770760521, 10.858971811830997, 65.51910147070885, 33.07577736675739, 36.76857501268387, 41.65836922824383, 0.3941705427132547, 0.06999334262218326, 0.05019070151320193, 0.02274174999911338, 0.06566347496118397, 0.016257475872407667, 0.036737857371917926, 0.032331938127754256, 0.04468091923627071, 0.042478395625948906, 0.08839338770485483, 0.10693037387682125, 0.034238701045978814, 0.015484244268009206, 0.07429868230246939, 0.03188905779097695, 0.020878918512607925, 0.058481481828494, 0.018513938775868155, 0.04687770975579042, 0.059249816185911186, 0.026028994798252825, 0.05240936312475242, 0.04197699323412962, 0.00977961204625899, 0.13561576197389513, 0.22271314461249858, 0.18457668396877125, 0.11872436210978776, 0.14854249020572752, 0.11422149982536212, 0.33057427557650954, 0.10774635040434077, 0.13928795320680365, 0.21386742708273232, 0.18204541120212525, 0.09485149741522036, 0.1740182380308397, 0.06845335650723428, 0.18453215510817245, 0.08399939106311649, 0.12285041375434957, 0.18416606850223616, 0.13053527130978182, 0.10961855892674066, 0.2500584366498515, 0.1511578928329982, 0.11907054431503639, 0.2446493972092867, 0.10433835632284172, 0.15199651970760897, 0.1591319133876823, 0.1527683829772286, 0.14958474755985662, 0.2508597186533734, 0.19683215447003022, 1.877854485064745, 57.035057321190834, 64.6844382584095, 33.064974546432495, 74.26170274615288, 38.20816196501255, 1.1390363797545433, 0.5311210127547383, 0.5755067279096693, 2.2475613467395306, 8.506893273442984, 11.992887016385794, 8.815410118550062, 5.387814491987228, 1.9494527368806303, 0.8180153556168079, 13.739857524633408, 67.66871452331543, 67.5765922665596, 72.88011208176613, 75.03020390868187, 69.57007169723511, 73.43080893158913, 69.96419414877892, 68.66923123598099, 67.55031287670135, 65.2662706375122, 62.76616059243679, 59.68026638031006, 59.15581092238426, 56.8337707221508, 52.879007533192635, 67.31063693761826, 65.75987935066223, 70.3896801173687, 67.87863805890083, 65.63606679439545, 62.76546522974968, 65.11255368590355, 64.98219788074493, 59.72863398492336, 54.59871165454388, 53.00758883357048, 48.97717550396919, 50.26482380926609, 48.528145998716354, 50.550914257764816, 50.20808145403862, 51.28383792936802, 47.86788962781429, 52.04648740589619, 53.58705773949623, 55.41007451713085, 53.02429273724556, 60.45435704290867, 60.01672312617302, 66.96069851517677, 62.55886271595955, 61.711226999759674, 59.9418443441391, 64.99748066067696, 62.316713109612465, 63.34892772138119, 59.493966177105904, 63.256657272577286, 59.234774485230446, 55.15300691127777, 53.43059353530407, 46.32169559597969, 49.07933682203293, 47.28354178369045, 47.43263818323612, 45.22619917988777, 47.38748520612717, 48.33333045244217, 48.647847175598145, 50.706097930669785, 48.56224536895752, 47.90543921291828, 50.37792094051838, 62.29857288300991, 61.50228001177311, 60.62274880707264, 58.55642728507519, 61.07140213251114, 61.02466844022274, 61.82483710348606, 58.95799733698368, 62.283286303281784, 62.377863228321075, 58.34323212504387, 58.59756387770176, 59.51602019369602, 59.88930456340313, 62.78176635503769, 60.149472802877426, 60.66031739115715, 57.694850116968155, 59.845910891890526, 54.072151109576225, 56.81700982153416, 60.46044431626797, 61.087562665343285, 57.75595843791962, 65.14128014445305, 22.278749831020832, 0.2952907048165798, 4.252228327095509, 4.131230469793081, 10.158307459205389, 19.51826635748148, 4.593677055090666, 0.16014944238122553, 0.8029433456249535, 0.2300589668448083, 16.809327118098736, 70.07661491632462, 38.585215732455254, 50.04672311246395, 50.57546094059944, 0.7593022717628628, 0.17047034169081599, 0.2477071198518388, 0.11298672194243409, 0.24809514434309676, 0.07197155951871537, 0.16768667934229597, 0.15379532240331173, 0.24781815998721868, 0.13358944648643956, 0.13538551807869226, 0.25817625573836267, 0.18312850152142346, 0.1318482492933981, 0.15379204211058095, 0.15024015301605687, 0.13788802520139143, 0.15258985193213448, 0.1247807769686915, 0.10496464732568711, 0.19721633463632315, 0.10786136845126748, 0.10613096950692125, 0.17189330596011132, 0.10721414146246389], [0.05078002985101193, 0.12609374010935426, 0.046661511005368084, 0.07478199113393202, 0.029235950350994244, 0.03388117882423103, 0.03998688713181764, 0.0345236523571657, 0.10538665475905873, 0.052764235879294574, 0.07153133235988207, 0.04462014476303011, 0.06735483693773858, 0.10871776976273395, 0.10646570779499598, 0.042913290453725494, 0.014273422912083333, 0.024832153649185784, 0.07398364061373286, 0.04389412024465855, 0.023222889903991017, 0.07262423387146555, 0.0057403717346460326, 0.03827069289400242, 0.04554476799967233, 0.02795141703245463, 0.06352211174089462, 0.0828720761637669, 0.060350695785018615, 0.029031737285549752, 0.05406339136243332, 0.13457020948408172, 6.485919468104839, 51.10814295709133, 34.94260959327221, 39.813363030552864, 65.87639629840851, 13.931030966341496, 0.0716602211468853, 0.11436828921432607, 0.0778818826074712, 0.48642709851264954, 3.19852776825428, 1.6191181750036776, 12.831308227032423, 4.218639554455876, 0.13369687978411093, 0.03205192580935545, 25.790720880031586, 60.66617287695408, 67.01249733567238, 69.25137519836426, 66.1376702785492, 60.618800818920135, 64.0063114464283, 61.30116060376167, 59.09164376556873, 57.359499111771584, 59.316812083125114, 56.435001119971275, 51.830837577581406, 53.04763488471508, 56.357979252934456, 61.326098665595055, 61.94983899593353, 64.65916961431503, 64.74775046110153, 62.331323325634, 68.04284244775772, 65.47387629747391, 62.03524321317673, 56.48965738713741, 48.75743329524994, 45.29449291527271, 46.41228273510933, 47.43063189089298, 46.66644349694252, 45.92674478888512, 46.51261255145073, 45.984429493546486, 45.73457770049572, 47.9894033074379, 48.826236203312874, 49.567656219005585, 56.81140512228012, 59.530790001153946, 59.380663856863976, 62.58859612047672, 61.48570530116558, 58.908846974372864, 64.51272547245026, 61.22731536626816, 59.05101254582405, 53.37409056723118, 47.92598471045494, 49.973649233579636, 49.3199323117733, 45.19499145448208, 45.2928552031517, 43.88504594564438, 44.65424247086048, 43.70800204575062, 42.19607837498188, 43.45001868903637, 43.52004513144493, 47.110024094581604, 48.42210128903389, 47.13832877576351, 44.87943358719349, 43.71932543814182, 44.83331926167011, 52.77647763490677, 59.87296164035797, 61.211629807949066, 57.74596877396107, 56.30240723490715, 58.72696213424206, 58.07213947176933, 57.785190269351006, 56.76757827401161, 58.29754717648029, 59.666583314538, 54.759203642606735, 55.639171823859215, 58.738578110933304, 58.42179670929909, 59.83480788767338, 55.351310670375824, 57.191821709275246, 50.20238555967808, 50.98245330154896, 54.18797269463539, 56.01082608103752, 54.56457048654556, 63.90050992369652, 31.973068937659264, 0.8863220340572298, 0.31879363115876913, 0.8839845657348633, 1.7150163603946567, 3.4630838222801685, 2.696438147686422, 0.108700893324567, 0.19891600124537945, 0.04228079880704172, 3.3968690503388643, 45.11424958705902, 31.86795137822628, 23.00806749612093, 47.43627458810806, 6.403876645490527, 0.11412319494411349, 0.11373581612133421, 0.03730242395249661, 0.02137521492841188, 0.041457441620877944, 0.03272403329901863, 0.009811100444494514, 0.03763845357752871, 0.012407747144607129, 0.014857028363621794, 0.025158069656754378, 0.006547572829731507, 0.10296390624716878, 0.05084253352833912, 0.04016215643787291, 0.039090168647817336, 0.010227892435068497, 0.07095285051036626, 0.015647549225832336, 0.054576382390223444, 0.053185144934104756, 0.04190136838587932, 0.048547794358455576, 0.0028731574730045395, 0.03386249525647145, 0.04736495939141605, 0.030763164104428142, 0.05954659362032544, 0.01557856103318045, 0.014800625140196644, 0.023802702053217217, 0.024852165661286563, 0.02639592745254049, 0.038750509920646437, 0.05033296751207672, 0.08517625174135901, 0.010838195721589727, 0.016065619565779343, 0.05091709710541181, 0.02976547086291248, 0.027443372418929357, 0.026920783566311002, 0.03562928541214205, 0.07147653959691525, 0.08062811844865791, 0.0634146190714091, 0.06660151251708157, 0.018878090231737588, 0.04703072576376144, 0.037009728330303915, 0.06724349252181128, 0.010655306414264487, 0.030449578880507033, 0.06490712257800624, 0.03425997470912989, 0.030049986162339337, 0.1640749434591271, 11.025660317391157, 62.380796670913696, 28.089048452675343, 46.444410011172295, 76.91688627004623, 12.18654552474618, 0.05012611982238013, 0.13606629014248028, 0.08217635724577121, 0.6300258461851627, 1.2507799523882568, 2.5965562323108315, 20.748492144048214, 8.359428886324167, 0.48369973548687994, 0.1037069370795507, 34.320571571588516, 67.47254624962807, 68.63241121172905, 74.00809675455093, 65.97673371434212, 64.86195713281631, 65.86666882038116, 65.54912745952606, 61.6300443559885, 60.16259729862213, 61.09941802918911, 59.1381760686636, 54.63905788958073, 56.43269844353199, 58.934427201747894, 63.966535180807114, 63.693124651908875, 67.15619802474976, 65.59351667761803, 63.76161217689514, 67.75316119194031, 66.75573751330376, 61.75675995647907, 55.89882329106331, 49.688687324523926, 48.620165660977364, 48.037801310420036, 49.24752339720726, 49.132723957300186, 48.31366270780563, 48.65850940346718, 46.61666616797447, 47.27761410176754, 50.25855794548988, 51.150343492627144, 50.87758652865887, 57.176702320575714, 62.89716236293316, 63.55383552610874, 63.224507197737694, 62.271966710686684, 58.97427946329117, 65.4933388531208, 64.31473329663277, 61.42574831843376, 58.11913155019283, 51.17950692772865, 53.18959526717663, 52.56262131035328, 48.284286484122276, 46.89030088484287, 45.62821760773659, 46.3738401979208, 46.40519231557846, 46.35424844920635, 44.96894158422947, 46.35892599821091, 48.81787285208702, 51.43793486058712, 48.050173446536064, 46.541061624884605, 43.8884961605072, 47.078983560204506, 54.494221061468124, 60.70797823369503, 62.247066646814346, 59.18134555220604, 59.21339303255081, 61.84710770845413, 59.80989262461662, 59.564087614417076, 58.10088872909546, 60.28354860842228, 60.7160110026598, 57.28535369038582, 56.227068677544594, 60.19519194960594, 60.130906999111176, 59.68833714723587, 55.42489372193813, 59.25063483417034, 54.516867846250534, 54.934191852808, 57.11275555193424, 59.223865270614624, 55.84238111972809, 65.75620114803314, 36.166406124830246, 1.6633324837312102, 1.7288163886405528, 2.7243873104453087, 5.731568271294236, 2.9662790056318045, 0.8833548682741821, 0.1496087189298123, 0.15923392900731415, 0.07216942351078615, 4.178222548216581, 47.951466143131256, 48.91696013510227, 21.1966609954834, 55.37801183760166, 10.671582967042923, 0.2047558277263306, 0.045235028956085443, 0.02971896046801703, 0.04381098857265897, 0.049515577193233185, 0.016979435276880395, 0.02326903479115572, 0.03360319999046624, 0.08146569147356786, 0.052300389870652, 0.03894745736033656, 0.035004144738195464, 0.07550118418294005, 0.024882981488190126, 0.041000041164807044, 0.026258821235387586, 0.020406977528182324, 0.04963378276443109, 0.015101014050742378, 0.0484180966304848, 0.03312198772619013, 0.06376489051035605, 0.016489005538460333, 0.014349512530316133, 0.047975142078939825, 0.13219800865044817, 0.19977616524556652, 0.14068069722270593, 0.30763832037337124, 0.12245479709235951, 0.17631552647799253, 0.21166574209928513, 0.19897721358574927, 0.12015896325465292, 0.15012042975286022, 0.18416980892652646, 0.1398210972547531, 0.20401118643349037, 0.24483502318616956, 0.2328941342420876, 0.23682503815507516, 0.10607854419504292, 0.11781054083257914, 0.21632236253935844, 0.14510894397972152, 0.12173602706752717, 0.17276725906413049, 0.07061350348521955, 0.19138064933940768, 0.25486793951131403, 0.09542214960674755, 0.225613264774438, 0.19594717305153608, 0.1805087795946747, 0.1645826466847211, 0.23594419792061672, 0.469822701998055, 12.677528578788042, 73.48826944828033, 44.93758946657181, 51.11053682863712, 82.71260127425194, 21.531312838196754, 0.249727854388766, 0.46070351789239794, 0.16174134914763272, 2.225746954791248, 9.960792157799006, 9.5991076156497, 25.458998680114746, 11.592948976904154, 0.25748475221917033, 0.22699567809468135, 33.526440784335136, 66.52091771364212, 70.18044054508209, 73.48941698670387, 70.6589412689209, 65.67664861679077, 69.42449390888214, 69.22670692205429, 63.720547780394554, 61.284456700086594, 64.40943941473961, 62.0874448120594, 57.449197098612785, 57.30216018855572, 62.77626045048237, 67.6386733353138, 66.92833185195923, 69.33877810835838, 67.54985690116882, 63.193432465195656, 72.18407303094864, 70.31172350049019, 67.77102783322334, 59.43701483309269, 52.22922720015049, 50.51209554076195, 50.6266175955534, 51.922161877155304, 51.83386221528053, 51.312587186694145, 50.7160571962595, 50.3545255959034, 49.9587008357048, 53.27907666563988, 54.24008309841156, 54.96144399046898, 61.446639597415924, 67.81718775629997, 65.47341272234917, 66.85735926032066, 63.46677839756012, 61.01231150329113, 70.66851675510406, 67.26962193846703, 63.49203184247017, 60.213081389665604, 53.326118141412735, 54.718899205327034, 56.30686819553375, 50.51527217030525, 50.74519023299217, 48.87585014104843, 50.10705627501011, 48.80155272781849, 49.562716484069824, 47.69208826124668, 48.41115787625313, 51.69383592903614, 54.40312094986439, 51.759910583496094, 49.295815005898476, 47.06625044345856, 49.70791809260845, 55.61821214854717, 64.53388273715973, 64.75105628371239, 59.55620303750038, 60.81592284142971, 62.99594946205616, 63.02472151815891, 62.81517796218395, 60.76110318303108, 62.70949423313141, 63.62005077302456, 59.42130267620087, 57.646296322345734, 62.984428480267525, 62.817005664110184, 62.65158534049988, 59.36334818601608, 61.912547796964645, 54.87710751593113, 56.20243459939957, 61.417305171489716, 61.25495508313179, 57.019983530044556, 66.81252166628838, 34.359914660453796, 1.5117600420489907, 0.8431887673214078, 2.2461808333173394, 8.789770994335413, 13.622794356197119, 6.887254407629371, 0.7977863098494709, 0.5022864381317049, 0.23986652260646224, 7.90973536670208, 56.84819854795933, 45.205494090914726, 31.35814793407917, 65.88708132505417, 13.306400533765554, 0.35042850708123296, 0.21248433098662645, 0.16098523425171152, 0.11742230853997171, 0.11864674088428728, 0.1132453529862687, 0.08682238723849878, 0.08586150637711398, 0.1478289152146317, 0.3229454130632803, 0.14792196569032967, 0.18328289792407304, 0.20783998566912487, 0.15592067007673904, 0.13145780540071428, 0.11872634364408441, 0.10318416825612076, 0.2161576205980964, 0.11340329685481265, 0.16814351576613262, 0.181784130691085, 0.27938716288190335, 0.12542090902570635, 0.11947944542043842, 0.10992168172379024], [0.00702962093782844, 0.037598915660055354, 0.04579220374580473, 0.016197658769669943, 0.04856983614445198, 0.015635990275768563, 0.049977512171608396, 0.058814023359445855, 0.03092787450441392, 0.11561028819414787, 0.022388161160051823, 0.03587572668038774, 0.046359746338566765, 0.05041842952778097, 0.03846478677587584, 0.04118817931157537, 0.009627871604607208, 0.020042254618601874, 0.06925523222889751, 0.017892271353048272, 0.07815286298864521, 0.07905843158368953, 0.05332988228474278, 0.03209231719665695, 0.061427236651070416, 0.052718976003234275, 0.043094378197565675, 0.024534222175134346, 0.039696406820439734, 0.0243233149376465, 0.04644208020181395, 0.06169969761685934, 0.3138292272342369, 20.993197113275528, 55.87491877377033, 31.628727614879608, 47.378779873251915, 54.647881016135216, 7.434960342943668, 0.03399132467166055, 0.04223593226925004, 0.15093036519829184, 0.31060512992553413, 0.922875894466415, 33.15441034734249, 6.257956400513649, 1.400502605829388, 0.31273313448764384, 1.3699176907539368, 33.85966010391712, 70.47009140253067, 70.66024839878082, 66.90814733505249, 66.70554220676422, 61.480700969696045, 60.974609926342964, 59.27832014858723, 60.21326757967472, 58.235789090394974, 57.86987632513046, 57.34704717993736, 54.40744511783123, 58.75419147312641, 62.04181686043739, 66.51730790734291, 67.5456315279007, 65.67338839173317, 65.41979759931564, 65.84360405802727, 63.573210686445236, 61.27464182674885, 53.77438388764858, 48.86283963918686, 46.35975815355778, 46.5483458340168, 48.04821275174618, 46.44060641527176, 46.582718789577484, 46.60873979330063, 48.435457572340965, 47.767347022891045, 50.43036952614784, 47.06922568380833, 52.12897717952728, 55.46230271458626, 61.364412009716034, 62.098080441355705, 62.71490514278412, 59.82835963368416, 57.17057324945927, 59.51858885586262, 61.13665983080864, 58.366570472717285, 54.18877825140953, 48.82023252546787, 47.82780557870865, 44.83018063008785, 44.28337477147579, 44.33647312223911, 44.635843858122826, 45.00803388655186, 44.01249870657921, 45.59044763445854, 45.06824165582657, 46.69031381607056, 52.76843726634979, 54.45176213979721, 50.259758681058884, 46.14967882633209, 44.93648372590542, 43.83117623627186, 50.602458491921425, 57.18896046280861, 60.52459627389908, 60.107891634106636, 58.36399421095848, 55.73534846305847, 58.78234416246414, 58.45767438411713, 62.77209587395191, 59.58660140633583, 56.52042433619499, 57.74909220635891, 57.75380775332451, 58.11365224421024, 57.76686765253544, 58.40275973081589, 57.038427740335464, 53.37404876947403, 54.6281448751688, 55.223094150424004, 54.99457821249962, 54.338117837905884, 62.90874034166336, 36.659239679574966, 2.726217624731362, 0.2355593943502754, 1.1882293713279068, 2.621013382449746, 2.958575156517327, 2.2752328868955374, 0.3315490123350173, 0.0709388090763241, 0.04545547650195658, 2.3956137523055077, 31.136817410588264, 50.658642277121544, 21.773675233125687, 45.01374498009682, 30.40673788636923, 0.14598892332287505, 0.06765349942725152, 0.0710740358044859, 0.01800386995455483, 0.06330821735900827, 0.017731948901200667, 0.13455223466735333, 0.050838251336244866, 0.013667368421010906, 0.024453411569993477, 0.04027769398817327, 0.06670630376902409, 0.08991530252387747, 0.06329059135168791, 0.05471982469316572, 0.06922919768840075, 0.04814686020836234, 0.022332997323246673, 0.0725393915490713, 0.04547676500806119, 0.046466619314742275, 0.016726659778214525, 0.04836439111386426, 0.008427214888797607, 0.01753851738612866, 0.0207360402418999, 0.04203238713671453, 0.03442236404225696, 0.05487039532454219, 0.05712841673812363, 0.09293677867390215, 0.050024044830934145, 0.03710055607371032, 0.042351551455794834, 0.0167328400129918, 0.03512014613079373, 0.04316568374633789, 0.019946122374676634, 0.04354405289632268, 0.051834172700182535, 0.06123087179730646, 0.03167772010783665, 0.012110140360164223, 0.058491129748290405, 0.1018873616703786, 0.012389684197842143, 0.03529038367560133, 0.023587586838402785, 0.05436815430584829, 0.04028320443467237, 0.07219768449431285, 0.007912772034615045, 0.03419764543650672, 0.044725255138473585, 0.06648020847933367, 0.05298349598888308, 0.04865203271037899, 0.08576170235755853, 0.5772075522691011, 33.774149492383, 58.79473529756069, 30.473504103720188, 67.97703757882118, 61.08399085700512, 5.829701330512762, 0.210217188578099, 0.024203487773775123, 0.26632521534338593, 0.5959794949740171, 2.79465242754668, 6.824675090610981, 12.432471178472042, 2.700782264582813, 0.8636183117050678, 1.8843159195967019, 38.76921705901623, 78.63759353756905, 72.07811951637268, 72.24316745996475, 68.51559787988663, 65.45211866497993, 62.67324037849903, 62.36316181719303, 60.996777936816216, 62.846127301454544, 61.093266159296036, 59.98812586069107, 55.370769426226616, 61.88692957162857, 64.77444782853127, 67.73733884096146, 69.65631186962128, 66.35134041309357, 62.989660799503326, 66.09502136707306, 65.17423197627068, 64.32800218462944, 55.76366454362869, 49.97277148067951, 48.901741951704025, 49.64989900588989, 49.14462871849537, 48.93393002450466, 48.81967395544052, 49.4620256870985, 51.420660987496376, 49.09093759953976, 52.14081734418869, 47.97850549221039, 54.879505187273026, 57.81634479761124, 63.13209615647793, 64.23933014273643, 63.70973356068134, 60.10096460580826, 59.06184956431389, 62.397534772753716, 62.18978472054005, 60.36576099693775, 54.907460287213326, 51.16837352514267, 48.52026902139187, 46.02112412452698, 44.51135873794556, 45.48783794045448, 45.93381240963936, 47.368592619895935, 45.905082151293755, 45.65519995987415, 46.038736179471016, 47.21601560711861, 54.63456653058529, 55.5763041973114, 52.94742666184902, 49.65341381728649, 48.26205387711525, 45.72176858782768, 53.336844965815544, 59.37158614397049, 62.224237471818924, 61.35741278529167, 56.976171880960464, 57.40023672580719, 61.51918150484562, 58.78427445888519, 62.61358357965946, 62.516772374510765, 58.93075279891491, 59.21939291059971, 59.837539941072464, 60.11981159448624, 59.23820570111275, 61.248769015073776, 59.11346219480038, 54.11802604794502, 55.1643531024456, 56.66035182774067, 56.964749693870544, 55.76054111123085, 61.87521480023861, 42.21126616001129, 3.024218534119427, 0.7250216393731534, 3.317492022179067, 6.0178648587316275, 3.9551415061578155, 0.45678563124965876, 0.3102166304597631, 0.04272673679224681, 0.09879417921183631, 3.798807682469487, 33.25021840631962, 65.01932188868523, 21.235960386693478, 41.60638801753521, 39.72853638231754, 0.4867692879633978, 0.17523924907436594, 0.02941781178378733, 0.03291978588094935, 0.03244036219257396, 0.028489394317148253, 0.09848637346294709, 0.041355366629431956, 0.01818447530240519, 0.046580000926041976, 0.012663898487517145, 0.029485744271369185, 0.014354641698446358, 0.013795224695059005, 0.049177569744642824, 0.0396678192919353, 0.13123308308422565, 0.07638690032763407, 0.005196293068365776, 0.015662065634387545, 0.029873323474021163, 0.041509610891807824, 0.013703837557841325, 0.029403419684967957, 0.0594223321240861, 0.009188086023641517, 0.18356809043325484, 0.12347176947514527, 0.10703492764150724, 0.14714349730638787, 0.14048275159439072, 0.14019644586369395, 0.2096638284274377, 0.12466078653233126, 0.14770040492294356, 0.28052315348759294, 0.25571069272700697, 0.11926214458071627, 0.1714574426296167, 0.20053021697094664, 0.16220035264268517, 0.10776897106552497, 0.09863331128144637, 0.11422980445786379, 0.15875267592491582, 0.14365550712682307, 0.13545860478188843, 0.14586385659640655, 0.2133066751412116, 0.14843464130535722, 0.16060075722634792, 0.1678433021879755, 0.1971365834469907, 0.07965561555465683, 0.12003109120996669, 0.14730179740581661, 0.09961851974367164, 0.2551581192528829, 0.6921049556694925, 39.54622596502304, 72.89515167474747, 44.010154232382774, 60.95659129321575, 70.93595400452614, 12.480393256992102, 0.39723077381495386, 0.19812527258181944, 0.49892700277268887, 1.713038447778672, 6.798151088878512, 53.70914898812771, 19.88141857087612, 2.268310133367777, 1.0281263873912394, 1.942468355409801, 37.038493528962135, 78.33238631486893, 73.99892404675484, 73.9419575035572, 72.33340501785278, 66.72951892018318, 66.7301344871521, 63.94572749733925, 64.86670687794685, 64.3005296587944, 64.23757463693619, 64.68896761536598, 58.52984011173248, 65.65910875797272, 66.37656345963478, 72.58747458457947, 72.88584977388382, 67.84459948539734, 65.81105500459671, 65.8826507627964, 68.01162332296371, 66.13320171833038, 56.07414968311787, 53.035718724131584, 51.63027673959732, 51.652053371071815, 53.92404265701771, 51.51544310152531, 52.668187245726585, 52.0807159692049, 54.72619481384754, 52.462709471583366, 56.846188455820084, 50.42075604200363, 58.89536149799824, 59.66560296714306, 66.84527590870857, 66.67597979307175, 67.22417637705803, 60.21883428096771, 58.52115757763386, 63.07732209563255, 65.31480923295021, 63.77754092216492, 56.730921640992165, 52.56510637700558, 52.55328521132469, 49.32068467140198, 46.528814882040024, 48.0712129175663, 47.77177378535271, 49.99568425118923, 47.563685551285744, 48.8132219016552, 48.322812616825104, 50.322649106383324, 57.4275154620409, 59.562415704131126, 54.767753183841705, 53.30849848687649, 50.322143733501434, 48.947540894150734, 55.47884322702885, 62.0870154350996, 64.6459311246872, 62.87288926541805, 57.97416552901268, 57.76662066578865, 62.62667387723923, 61.763451397418976, 67.22246646881104, 63.63355524837971, 60.22643007338047, 61.43549479544163, 61.82893328368664, 60.289582684636116, 62.37249791622162, 63.36990639567375, 60.39177820086479, 56.230800077319145, 58.65255832672119, 60.32672569155693, 59.85390946269035, 56.59129433333874, 65.04180148243904, 39.24204848706722, 3.3878039242699742, 0.46528880309779197, 2.3474544240161777, 4.819038212299347, 12.269947249442339, 8.430226687341928, 1.1799277667887509, 0.2887942112283781, 0.18036079534795135, 6.123735252767801, 43.343236818909645, 62.58199207484722, 32.23514847457409, 56.071721613407135, 45.89840970933437, 0.5944380245637149, 0.2298415917903185, 0.22308791434625164, 0.0804280948068481, 0.15813185455044731, 0.06310039374511689, 0.19825669209240004, 0.17964489001315087, 0.09412798506673425, 0.13224715366959572, 0.1036844945338089, 0.09536160519928671, 0.12865765253081918, 0.12121757012209855, 0.2150483918376267, 0.1270304195350036, 0.20045273675350472, 0.19950915535446256, 0.11464091716334224, 0.20265494124032557, 0.17412875866284594, 0.14506101608276367, 0.1135266714845784, 0.07169208896812052, 0.1755585803766735, 0.04279296234017238], [0.04901340296783019, 0.027064673013228457, 0.015387270614155568, 0.05741533845139202, 0.06238072572159581, 0.013380209220485995, 0.0146643241532729, 0.049223289752262644, 0.018626982709974982, 0.0532195063715335, 0.04090113514394034, 0.03159231746394653, 0.015913690804154612, 0.06330540461931378, 0.03890660584147554, 0.030256566678872332, 0.06086167930334341, 0.12009941332507879, 0.017537673193146475, 0.03881924392771907, 0.0613372957741376, 0.025652937438280787, 0.04628738322935533, 0.024691935977898538, 0.00569660867768107, 0.05220034836384002, 0.06582975314813666, 0.06314230282441713, 0.05401589020038955, 0.03261398022004869, 0.09506945134489797, 0.04920474348182324, 0.01016847887512995, 1.894601492676884, 36.223061084747314, 46.033557057380676, 27.05841075628996, 53.004822582006454, 48.77382941544056, 10.077713783830404, 0.33453603798989207, 0.050959354994120076, 0.14490872737951577, 1.5409554191865027, 6.925339289009571, 6.969374176114798, 0.5449713882990181, 1.105597699061036, 0.07350144500378519, 2.611111351288855, 38.186864107847214, 71.12847447395325, 71.67173892259598, 65.20141571760178, 64.99944895505905, 60.00842437148094, 58.94014209508896, 59.97050620615482, 61.416275426745415, 60.0361742824316, 57.41558410227299, 58.476050198078156, 65.36543771624565, 63.579427152872086, 65.72467803955078, 64.44600105285645, 65.64277723431587, 70.55743351578712, 68.58584091067314, 65.42877271771431, 63.0309721827507, 52.752884700894356, 48.1401564180851, 47.08007790148258, 46.292064785957336, 47.00236827135086, 46.62745758891106, 47.308316454291344, 53.24879229068756, 53.081168085336685, 52.57502004504204, 51.04479655623436, 53.38265910744667, 53.37460353970528, 54.743734672665596, 59.46264445781708, 63.69250148534775, 61.569806188344955, 67.73803040385246, 41.374699249863625, 52.605357617139816, 67.13408321142197, 60.061078146100044, 63.919774889945984, 60.57537294924259, 61.78256057202816, 60.25399759411812, 55.60167923569679, 45.89939385652542, 45.688087195158005, 45.40656790137291, 45.75393006205559, 44.519855082035065, 47.16673605144024, 49.887492656707764, 54.33831162750721, 58.10477592051029, 53.63512896001339, 49.31353725492954, 44.35194589197636, 43.508026376366615, 46.71242482960224, 56.05284422636032, 59.91392344236374, 64.98155191540718, 61.29502393305302, 59.6622097492218, 57.947312369942665, 59.65165011584759, 57.12167747318745, 61.59353971481323, 58.6825805157423, 59.46227587759495, 56.86836026608944, 60.02635180950165, 60.37624463438988, 60.1797191798687, 54.89781640470028, 58.90046842396259, 56.75434358417988, 56.66798561811447, 57.38058798015118, 63.8478447496891, 41.255564242601395, 5.646629054099321, 0.10787512044771574, 2.087169815786183, 2.4016110179945827, 4.2023545783013105, 2.298067999072373, 0.36845622409600765, 0.07478498198906891, 0.1599323790287599, 5.1070470828562975, 32.768993228673935, 50.581088438630104, 30.77018268406391, 36.70436605811119, 45.505100414156914, 3.2738853245973587, 0.11891277856193483, 0.09276905329898, 0.040254175328300335, 0.028852284121967386, 0.05179289815714583, 0.06038904255547095, 0.05236760989646427, 0.02906224883190589, 0.06728767257300206, 0.09519894869299605, 0.0569134128454607, 0.07871938141761348, 0.03709927586896811, 0.060618113857344724, 0.0244289949114318, 0.022937665853532963, 0.051014229393331334, 0.05057179063442163, 0.0516081033856608, 0.0332260145660257, 0.031040981521073263, 0.040123408907675184, 0.04475297435419634, 0.02340672359423479, 0.057918110105674714, 0.011639747681329027, 0.060529130350914784, 0.04619966137397569, 0.004298517951610847, 0.02848120842827484, 0.08951698444434442, 0.07835290147340856, 0.05848178610904142, 0.07205383401014842, 0.0078076393947412726, 0.04964968698914163, 0.11250186202232726, 0.05366503246477805, 0.020170581228740048, 0.056535982512286864, 0.04532998304057401, 0.004441111423147959, 0.024991459358716384, 0.12530615815194324, 0.045641135875484906, 0.023139654331316706, 0.034720028343144804, 0.08828374280710705, 0.046678405997226946, 0.03920477851352189, 0.04077443569258321, 0.029526061443903018, 0.04960693928296678, 0.017348894944007043, 0.035684211761690676, 0.044581772017409094, 0.0880388414952904, 0.0051696629543585, 0.09786233116756193, 4.397129751741886, 48.20607528090477, 45.92912346124649, 30.228774435818195, 75.49490377306938, 52.63527721166611, 8.698621485382318, 0.19337392441229895, 0.12205256047309376, 0.10034676699433476, 0.4070509015582502, 2.423901096917689, 6.834308048710227, 4.90307355299592, 2.7961661713197827, 0.03362777250004001, 4.138605399057269, 44.19670142233372, 77.37474650144577, 73.353011906147, 69.52923908829689, 67.87660896778107, 62.135204449296, 61.18492104113102, 62.34491139650345, 63.918490558862686, 60.92770144343376, 61.091525852680206, 61.28990940749645, 66.96700617671013, 64.56488147377968, 68.78274634480476, 66.8176057934761, 65.26187047362328, 68.97583678364754, 71.71455502510071, 67.59316697716713, 64.80045363306999, 56.45739711821079, 50.420699045062065, 48.056374713778496, 48.44713054597378, 48.35228383541107, 47.45359405875206, 49.21234108507633, 54.79375898838043, 51.87335729598999, 55.567697659134865, 53.94689463078976, 52.85447224974632, 53.95715408027172, 58.93428660929203, 63.02523449063301, 65.31896620988846, 63.545639365911484, 65.20547389984131, 46.222004145383835, 56.71710938215256, 68.56732070446014, 61.19189366698265, 64.97503906488419, 60.45279532670975, 62.55163550376892, 61.63966163992882, 55.62002085149288, 47.53967083990574, 49.219271913170815, 47.93473944067955, 46.79147958755493, 47.49739810824394, 47.934538051486015, 52.75748625397682, 55.99683903157711, 59.60833624005318, 54.43908601999283, 50.15375196933746, 46.2313212454319, 44.91723395884037, 48.063886910676956, 59.092297330498695, 61.291121542453766, 64.62207600474358, 63.09399180114269, 58.62619914114475, 58.22104208171368, 61.742655113339424, 59.70846846699715, 61.46118901669979, 60.76160095632076, 61.0025118291378, 57.32542634010315, 59.10340033471584, 61.303691267967224, 61.545297503471375, 57.76353143155575, 61.45471416413784, 57.627407535910606, 57.79622867703438, 58.12471725046635, 62.42099091410637, 46.19791343808174, 7.519413186237216, 0.24002810299862176, 2.2935072937980294, 4.513066280633211, 3.7829283345490694, 0.5955828912556171, 0.18905463977716863, 0.14459076162893325, 0.10153927956707776, 6.507131829857826, 32.42422632873058, 57.73529514670372, 33.446553871035576, 30.05090408027172, 54.83493737876415, 6.319743460044265, 0.13404417521087453, 0.10945867805276066, 0.03904956203768961, 0.035396076636970975, 0.08194013164029457, 0.055313516859314404, 0.06018215404765215, 0.052771935661439784, 0.05998108026687987, 0.049018943100236356, 0.03398485314392019, 0.1514212365145795, 0.009190786513499916, 0.03393192317162175, 0.040539475448895246, 0.03214993383153342, 0.028292333699937444, 0.046156201206031255, 0.008133996980177471, 0.032145729564945213, 0.03631245832366403, 0.051108849511365406, 0.03379748683073558, 0.005098228921269765, 0.009622746147215366, 0.058669315694714896, 0.1107762054016348, 0.14005623932462186, 0.10883221635594964, 0.09697136061731726, 0.22650241706287488, 0.14814900350756943, 0.15713575878180563, 0.16517992713488638, 0.07959608046803623, 0.12127455222071148, 0.1549700679606758, 0.14258832845371217, 0.1692436309531331, 0.20380996051244438, 0.10402891784906387, 0.11623692058492452, 0.10132447234354913, 0.3494921838864684, 0.1375857336097397, 0.14194231858709827, 0.31044889299664646, 0.2520109381293878, 0.19171247840858996, 0.16568239079788327, 0.09856179050984792, 0.21182595693971962, 0.16767815948696807, 0.13404171128058806, 0.08627451898064464, 0.13337404554476961, 0.16361467831302434, 0.09162267262581736, 0.22420143272029236, 5.202672751620412, 59.31906156241894, 61.472975984215736, 38.298015743494034, 67.1119911968708, 65.58449596166611, 15.657450277358294, 0.47023349558003247, 0.3039058519061655, 0.24171230325009674, 3.52983555290848, 18.348700515925884, 23.47153812646866, 7.147458270192146, 2.2551424149423838, 0.2774611709173769, 4.26279840990901, 43.31688903272152, 76.46890550851822, 77.5303253531456, 69.90060076117516, 69.11373138427734, 65.93742862343788, 65.11975809931755, 65.7280370593071, 67.08597019314766, 65.84855899214745, 61.76606945693493, 61.986765414476395, 71.1671108007431, 68.35914507508278, 71.19190067052841, 68.90946194529533, 64.11019027233124, 69.71831694245338, 73.31983208656311, 70.36946520209312, 67.35617369413376, 59.851158410310745, 54.1192913800478, 51.587027460336685, 50.21864868700504, 51.90831542015076, 50.593867152929306, 52.67472289502621, 60.61033487319946, 56.23002491891384, 57.32745923101902, 55.94922378659248, 58.42713922262192, 57.770158275961876, 61.25674858689308, 64.39997792243958, 69.2879368364811, 67.10151135921478, 69.99843791127205, 44.56011012196541, 57.47109912335873, 72.90404319763184, 64.06015455722809, 69.42549705505371, 66.26965999603271, 66.88163995742798, 67.1414016187191, 61.896349266171455, 52.185936123132706, 51.92365139722824, 51.94227419793606, 50.196252688765526, 49.76773448288441, 51.84577837586403, 57.82863713800907, 60.017756670713425, 62.843984216451645, 57.29912795126438, 52.89836369454861, 49.1767255961895, 45.71866035461426, 50.42312331497669, 61.59000590443611, 64.57457855343819, 69.08311262726784, 66.72423720359802, 61.002918407320976, 60.81407994031906, 62.95198202133179, 61.26158192753792, 64.91803452372551, 61.67232468724251, 63.31241928040981, 60.32811261713505, 63.19399103522301, 62.495402321219444, 62.835837453603745, 59.8108995705843, 66.00939676165581, 61.3041016459465, 59.905157312750816, 60.755635276436806, 67.4724018573761, 42.38012909889221, 7.67941452562809, 0.3406973776873201, 4.472356690093875, 7.223242353647947, 11.609466690570116, 8.535442091524601, 1.6287988680414855, 0.2603102568536997, 0.22789755079429597, 8.935123644769192, 47.49098405241966, 59.75556693971157, 43.14581461250782, 42.403953820466995, 65.00226840376854, 6.298865480348468, 0.19031210511457175, 0.28113118023611605, 0.15911963826511055, 0.2310213097371161, 0.2582107804482803, 0.08618532025138848, 0.23339554405538365, 0.15147419617278501, 0.14788203814532608, 0.2866854431340471, 0.15339889680035412, 0.27474217931739986, 0.12067739793565124, 0.14208837324986234, 0.12114241282688454, 0.1139803537807893, 0.10280288246576674, 0.1340158993843943, 0.10895279308897443, 0.17787635209970176, 0.09859677535132505, 0.1870013991720043, 0.097239966125926, 0.11878796416567639, 0.12723869585897774, 0.17231276782695204], [0.02534270486648893, 0.031223689002217725, 0.019097769654763397, 0.027765445956902113, 0.0453493271197658, 0.07296246025362052, 0.035248567364760675, 0.04531059072178323, 0.02732386623392813, 0.03385403106221929, 0.008880986242729705, 0.03941213457437698, 0.061511937965406105, 0.05111803729960229, 0.044155081632197835, 0.03151333068672102, 0.06004344664688688, 0.01929027905134717, 0.036217741726431996, 0.12934217986185104, 0.049892476890818216, 0.04332041411544196, 0.073160301981261, 0.03795656404690817, 0.019950643909396604, 0.02131920318788616, 0.0921974511584267, 0.04967520944774151, 0.0397199403232662, 0.06442635189159773, 0.05222830135608092, 0.023818877161829732, 0.04065263441589195, 0.35939929133746773, 11.356657706201077, 49.29737292230129, 40.09164109826088, 29.650867246091366, 54.15850527584553, 54.79481153190136, 13.831325266510248, 0.5978374765254557, 0.05112439379445277, 0.22932004008907825, 0.9586423065047711, 9.784158635884523, 3.507805997505784, 2.5939557468518615, 1.1356469616293907, 0.03141160821542144, 10.894382111728191, 56.865210235118866, 72.37992212176323, 70.20354330539703, 66.78641706705093, 62.336924225091934, 64.64526236057281, 61.77911415696144, 60.317135006189346, 63.49908046424389, 65.53856402635574, 62.0316182076931, 62.7373581379652, 66.24355539679527, 71.25506088137627, 66.33068472146988, 66.55381634831429, 67.03433856368065, 66.73135802149773, 62.92402692139149, 59.28510658442974, 49.11313220858574, 47.08925820887089, 45.30611649155617, 50.48811122775078, 49.67557042837143, 49.5439188927412, 52.520299181342125, 57.26348206400871, 58.23733940720558, 57.344432920217514, 53.30047331750393, 53.25337864458561, 52.289575561881065, 56.63342647254467, 54.43901002407074, 59.484808668494225, 59.07153144478798, 67.46503785252571, 31.073814891278744, 45.01420855522156, 65.57456329464912, 62.34580434858799, 66.32502302527428, 61.170630007982254, 62.770598754286766, 60.098346546292305, 60.60818038880825, 53.828899562358856, 46.99994020164013, 45.67866750061512, 44.25679139792919, 45.73417492210865, 48.14650967717171, 53.757269605994225, 58.855399042367935, 63.32859121263027, 60.86182437837124, 56.298896223306656, 48.593266904354095, 44.576958417892456, 45.1382414996624, 52.8041135519743, 60.135820135474205, 60.98366864025593, 62.06436485052109, 61.28984861075878, 58.4952961653471, 57.70893216133118, 61.592145189642906, 59.576786532998085, 61.889608427882195, 59.8494902998209, 59.955990985035896, 56.89553260803223, 60.594884902238846, 61.31109707057476, 62.65349663794041, 57.2998271137476, 60.63393160700798, 59.39271681010723, 60.13339966535568, 42.300082594156265, 6.72860199585557, 0.3595469787251204, 0.23226130491821095, 1.1885388172231615, 5.460581537336111, 4.927776977419853, 0.4589532664977014, 0.04302328045014292, 0.08324933209223673, 6.631843987852335, 40.0486122071743, 46.83358892798424, 33.46174545586109, 32.26126827299595, 48.99668365716934, 13.378019090741873, 0.14390360709512606, 0.1819814826012589, 0.026231079755234532, 0.013970766740385443, 0.13965887861559168, 0.08285384901682846, 0.023890880329417996, 0.09248970149201341, 0.03258726661442779, 0.024629873878438957, 0.059517750050872564, 0.06317273087915964, 0.0328825708857039, 0.030152070430631284, 0.01919788908708142, 0.06212768304976635, 0.010348067480663303, 0.015127765691431705, 0.02544462215155363, 0.061308634030865505, 0.06812578736571595, 0.060914108325960115, 0.020473375625442713, 0.019396599127503578, 0.01668724431510782, 0.027404181455494836, 0.028399716902640648, 0.04606458307534922, 0.058779112732736394, 0.016229083157668356, 0.053261838475009426, 0.01200867300212849, 0.10799366369610652, 0.0278908707696246, 0.024728141652303748, 0.04984561768651474, 0.028346308245090768, 0.00781863060183241, 0.036061760838492773, 0.06672757372143678, 0.04110447989660315, 0.023538148670922965, 0.038960823439992964, 0.06627392111113295, 0.044982999315834604, 0.06685854052193463, 0.012277103178348625, 0.01570021573570557, 0.06309588890871964, 0.1623287590336986, 0.04048582188261207, 0.0414164194080513, 0.019224997886340134, 0.02769194179563783, 0.12392732198350132, 0.04559560511552263, 0.06457947180024348, 0.07038078081677668, 0.05165966409549583, 0.05684477531758603, 0.44242252071853727, 18.061717115342617, 61.061150282621384, 33.557241931557655, 32.211768329143524, 75.35117268562317, 58.87959234416485, 12.480183318257332, 0.8848149399273098, 0.08993932584417053, 0.07347816383116879, 0.3150210570311174, 2.8852894390001893, 5.111013595014811, 4.954962618649006, 2.6724602468311787, 0.0890812992292922, 12.803924046456814, 61.78948760032654, 76.19204476475716, 74.84941720962524, 70.24777293205261, 64.58449602127075, 66.24179989099503, 64.53347235918045, 63.67756448686123, 66.29072606563568, 67.15834110975266, 62.81635969877243, 66.45412489771843, 69.30038496851921, 73.0854606628418, 66.8774601817131, 66.09461098909378, 68.32591965794563, 68.47521364688873, 65.48499450087547, 61.45359322428703, 52.199459597468376, 49.775391072034836, 48.032132014632225, 52.48211123049259, 51.829731836915016, 51.010328605771065, 53.99624638259411, 56.996299400925636, 60.18650941550732, 58.434545025229454, 55.13364315032959, 55.440013110637665, 54.985656291246414, 58.79620961844921, 56.13285653293133, 62.37921595573425, 61.471155881881714, 68.97262215614319, 31.8252644687891, 47.17109441757202, 67.80030146241188, 63.54661591351032, 67.24048510193825, 63.385481759905815, 64.55498680472374, 62.21392102539539, 61.715969145298004, 53.55150684714317, 47.590363919734955, 46.75781339406967, 44.937167689204216, 46.182121485471725, 50.0120347738266, 55.518733486533165, 59.78080898523331, 65.12116402387619, 62.577466517686844, 58.343323320150375, 50.30027590692043, 47.569757625460625, 48.10910448431969, 56.2913004308939, 61.69420771300793, 62.26808711886406, 62.1494422852993, 61.437018513679504, 59.428229704499245, 60.14579080045223, 62.14439235627651, 63.05521868169308, 62.15213254094124, 61.17972292006016, 61.15439347922802, 58.49316067993641, 59.817818999290466, 63.888046592473984, 62.724188044667244, 60.00646747648716, 60.55980898439884, 61.5935093164444, 60.90499386191368, 47.75457590818405, 8.018732517957687, 0.8444601553492248, 1.9767522532492876, 3.1440199306234717, 4.08612783998251, 1.1874292767606676, 0.2684630756266415, 0.03950460988562554, 0.06831941369455308, 7.67521527595818, 40.815392062067986, 58.108868300914764, 44.65238817036152, 28.305807821452618, 57.6520112156868, 20.717312917113304, 0.16748263326007873, 0.15660395059967414, 0.05654419808706734, 0.030616001786256675, 0.04134889881242998, 0.046347029638127424, 0.023829400815884583, 0.055368806861224584, 0.02133586625859607, 0.05597326759016141, 0.04762884484080132, 0.07485935260774568, 0.019171720960002858, 0.03169214745867066, 0.09625874299672432, 0.053349649388110265, 0.029010946018388495, 0.01417747063896968, 0.04316540544095915, 0.03901735653926153, 0.06687188433716074, 0.005066942758276127, 0.019124193822790403, 0.05180958905839361, 0.06899861982674338, 0.06033216435753275, 0.01215728436363861, 0.12462102225981653, 0.1959008036646992, 0.17710478568915278, 0.16401019849581644, 0.07362346150330268, 0.13065303530311212, 0.12289581092773005, 0.10152959453989752, 0.13408011000137776, 0.0884601438883692, 0.08091877316473983, 0.09498204861301929, 0.23058053338900208, 0.14447528345044702, 0.1319134098594077, 0.1966359157813713, 0.14095964084845036, 0.10579221619991586, 0.2403273814707063, 0.23630237323231995, 0.11740066009224392, 0.15300662722438574, 0.2270640744245611, 0.12091982789570466, 0.09752811980433762, 0.1309079333441332, 0.1686684219748713, 0.1955978144542314, 0.10945288930088282, 0.09931699256412685, 0.14645024231867865, 0.14621070673456416, 0.15961741155479103, 0.7879993412643671, 20.87227050215006, 74.12685558199883, 52.4382995814085, 37.949684634804726, 69.34846758842468, 71.66594803333282, 21.986782997846603, 0.8944870834238827, 0.23565283074276522, 0.2698874945053831, 1.9438288011588156, 30.812121033668518, 14.624494705349207, 8.59329303726554, 3.5232013463974, 0.09166438874672167, 14.265693258494139, 61.99422061443329, 76.22505739331245, 77.1247199177742, 73.04006069898605, 66.26671895384789, 69.08782437443733, 67.36282333731651, 65.7156041264534, 69.28805842995644, 72.16545403003693, 67.66784816980362, 67.05618739128113, 72.3855610191822, 75.69693893194199, 69.24325123429298, 68.62318530678749, 70.46189144253731, 68.69168803095818, 67.47232586145401, 62.90293425321579, 53.69692124426365, 51.245425790548325, 49.981708601117134, 56.53463177382946, 55.405951738357544, 54.8504975438118, 58.40355008840561, 62.87119075655937, 64.63373377919197, 62.52355121076107, 58.22084069252014, 58.57134908437729, 59.832824394106865, 61.178905963897705, 57.76182912290096, 63.467082381248474, 63.107275888323784, 68.73145669698715, 34.594289883971214, 47.651677429676056, 68.80454957485199, 66.90122410655022, 71.15187361836433, 65.28171300888062, 66.39109387993813, 64.716257750988, 65.20620346069336, 57.21271298825741, 50.53250804543495, 49.37387801706791, 47.151673659682274, 50.733418464660645, 51.69364973902702, 57.78516747057438, 63.4364940226078, 66.95106983184814, 65.92427372932434, 64.36533898115158, 54.67755742371082, 49.523475989699364, 50.265127792954445, 58.45290184020996, 64.15236800909042, 63.359464555978775, 63.92800524830818, 62.82918021082878, 59.34562973678112, 62.02349044382572, 63.82876217365265, 62.656213492155075, 63.65150548517704, 63.53352181613445, 62.58589066565037, 57.64082461595535, 62.143408209085464, 65.26162728667259, 65.90995609760284, 61.196202635765076, 65.62115639448166, 63.88474836945534, 62.44404047727585, 45.433660447597504, 8.420768994838, 0.6400700728408992, 1.567084479611367, 5.752560244873166, 10.428318120539188, 13.413132056593895, 2.0456539560109377, 0.15783400100190192, 0.2665337885264307, 11.565125919878483, 54.66650761663914, 56.042694970965385, 47.65402190387249, 39.39627841114998, 68.14931273460388, 22.048909664154053, 0.30326626903843135, 0.41012793488334864, 0.12742130871629342, 0.08546415308956057, 0.25002144800964743, 0.15752646984765306, 0.09219504659995437, 0.18237805663375184, 0.16548733954550698, 0.16122266213642433, 0.18674028193345293, 0.11778539686929435, 0.16947500291280448, 0.09928857572958805, 0.2084086340619251, 0.1495357509702444, 0.11793014535214752, 0.13265275221783668, 0.1197679627512116, 0.09329623047960922, 0.14161503146169707, 0.12464312341762707, 0.053714040186605416, 0.15430663246661425, 0.12002038201899268, 0.10768995460239239, 0.10200202348642051], [0.011879958619829267, 0.0037841574294361635, 0.09747898962814361, 0.03322791446407791, 0.049328088425681926, 0.006696806203763117, 0.03430628472415265, 0.009573073275532806, 0.06708534085191786, 0.06558101493283175, 0.02300339787325356, 0.014380909087776672, 0.022939530499570537, 0.06616558981477283, 0.05478795756062027, 0.028462344889703672, 0.04781329451361671, 0.024306393970618956, 0.02098956345434999, 0.04996320356440265, 0.0345342762011569, 0.05123833572724834, 0.03779305407078937, 0.005562529959206586, 0.01788651785318507, 0.07471516073564999, 0.0208594037394505, 0.021656776480085682, 0.025158950957120396, 0.04999797689379193, 0.030004479522176553, 0.03717874875292182, 0.0038589763516938547, 0.20196409081108868, 0.29022308299317956, 20.178473331034184, 54.07944291830063, 40.90873405337334, 25.92616841197014, 56.43394477665424, 59.80692498385906, 18.23095243424177, 0.7419426657725126, 0.05495381272339728, 0.2716559136752039, 0.9131317923311144, 4.941979190334678, 3.7765705632045865, 2.1271099476143718, 0.08469759617582895, 0.1416052647982724, 27.92732533067465, 68.73048394918442, 69.00205537676811, 71.67789459228516, 70.64666032791138, 64.36596974730492, 63.42307694256306, 70.4408709704876, 65.90122416615486, 62.7599973231554, 67.38895073533058, 69.6788826584816, 69.61308538913727, 69.06568676233292, 64.64223772287369, 66.90674141049385, 66.22334808111191, 70.08112907409668, 67.17305392026901, 58.97776007652283, 51.138537526130676, 47.30850264430046, 45.835040509700775, 47.40846388041973, 47.45083160698414, 52.42199465632439, 56.14965543150902, 58.02432283759117, 58.021290600299835, 60.17158381640911, 57.84077748656273, 56.31163313984871, 55.7748169451952, 56.71164147555828, 58.4849189221859, 64.99206215143204, 64.05801147222519, 72.3288756608963, 40.03089755773544, 50.12478992342949, 59.23861227929592, 66.58749014139175, 66.33998662233353, 65.71690365672112, 66.64797529578209, 65.60126826167107, 61.82083211839199, 57.0972865819931, 50.13736344873905, 47.49777428805828, 47.21744813024998, 46.327779069542885, 51.765982657670975, 55.96392139792442, 59.05720241367817, 63.96436929702759, 61.676223278045654, 60.544366613030434, 53.810101971030235, 45.82427568733692, 43.7923651188612, 48.18349689245224, 57.09358178079128, 62.67454370856285, 63.73628653585911, 65.07772475481033, 65.0114943087101, 64.68028128147125, 60.21180085837841, 62.761319652199745, 60.74430048465729, 62.497401013970375, 56.529524847865105, 63.74941103160381, 60.220544189214706, 61.84634394943714, 61.40863783657551, 62.032058984041214, 60.26746407151222, 60.03974609076977, 40.08504465222359, 7.63797964900732, 0.04797611058165785, 0.3596035303780809, 0.9143161412794143, 1.1843273369595408, 2.6617707079276443, 1.1800142121501267, 0.13435240398393944, 0.047347188665298745, 8.881575968116522, 40.288421139121056, 42.932296469807625, 25.311648286879063, 28.01959577947855, 46.91238529980183, 17.05487374216318, 0.16736889170715585, 0.10971729425364174, 0.02948402991023613, 0.02246919997560326, 0.03701401794387493, 0.021454095949593466, 0.02185083882068284, 0.033954940881812945, 0.015893242780293804, 0.07799258877639659, 0.10117268087924458, 0.05387154989875853, 0.04842054200707935, 0.029670871153939515, 0.0211726587076555, 0.03528627217747271, 0.05302503770508338, 0.03455804719123989, 0.030959794275986496, 0.04963843974110205, 0.033762101229513064, 0.06237651774426922, 0.07667926940484904, 0.04673067174735479, 0.01850713884778088, 0.02020561802055454, 0.06017088824592065, 0.05714704093406908, 0.016094509519462008, 0.027583912924455944, 0.0353666133742081, 0.022053921966289636, 0.04595373960910365, 0.05414216662757099, 0.06729745407938026, 0.02758611153694801, 0.04157932082307525, 0.030118137583485804, 0.046061629327596165, 0.0686790955660399, 0.039573789181304164, 0.06550343823619187, 0.031273802524083294, 0.04078780177223962, 0.04914672979793977, 0.030046002684684936, 0.018801799305947497, 0.05334811685315799, 0.028140098802396096, 0.028433304651116487, 0.044870192868984304, 0.04099643432709854, 0.02085528296447592, 0.028121723225922324, 0.051691001281142235, 0.040430880690109916, 0.00952268237597309, 0.08384625631151721, 0.018479393656889442, 0.05397215543780476, 0.016883293756109197, 0.1844401436392218, 1.0712398239411414, 32.60280914604664, 59.153291657567024, 32.65418238937855, 32.2254703938961, 74.9619671702385, 66.06446340680122, 18.269499465823174, 1.1846652813255787, 0.023780194569553714, 0.0939441476657521, 0.7942091580480337, 1.0319135966710746, 3.9409547299146652, 3.7483972124755383, 0.38291795121040195, 0.41688002413138747, 31.51032406836748, 73.73277112841606, 71.31654158234596, 73.62212866544724, 73.1281627714634, 65.26193127036095, 66.14026933908463, 70.69858834147453, 66.90965205430984, 66.132532954216, 69.81850236654282, 70.06543591618538, 71.2749794125557, 70.50903171300888, 64.33909758925438, 67.40940883755684, 68.84308710694313, 72.1928733587265, 69.05168071389198, 60.27341455221176, 53.0687465518713, 49.01141546666622, 47.71017529070377, 48.77387121319771, 49.22225095331669, 53.97331461310387, 56.934849098324776, 59.4601745903492, 59.003636687994, 63.00100699067116, 58.444861471652985, 57.40787051618099, 57.39992894232273, 58.93824599683285, 61.40875943005085, 66.5593184530735, 65.06396189332008, 70.26725068688393, 41.06998600065708, 49.030429646372795, 63.077907264232635, 66.91285148262978, 68.20776119828224, 64.82487112283707, 68.1491607427597, 65.98785191774368, 63.841681480407715, 58.81082743406296, 51.51608146727085, 49.42743234336376, 50.785718858242035, 49.45110887289047, 53.650320544838905, 57.748214453458786, 59.93928328156471, 65.36619007587433, 63.98605853319168, 60.647261291742325, 54.26985450088978, 46.820981204509735, 46.131295412778854, 50.15600524842739, 58.81414085626602, 64.12887766957283, 66.13746508955956, 65.62279790639877, 63.83367910981178, 64.3544639647007, 62.99677021801472, 63.29715549945831, 63.35498459637165, 62.79049448668957, 57.86611832678318, 63.59452374279499, 61.53670236468315, 61.50812789797783, 62.00353391468525, 63.44898395240307, 61.43420286476612, 61.561264246702194, 42.10675656795502, 10.072131883352995, 0.16446664900286123, 1.0868091322481632, 2.1675271913409233, 1.9447986991144717, 1.1284111998975277, 0.1581517737940885, 0.21068883826956153, 0.0909024034626782, 9.296156521886587, 41.66688457131386, 51.42348423600197, 32.71518811583519, 27.441492900252342, 51.28619000315666, 30.319190584123135, 0.5636744596995413, 0.06880103785078973, 0.043828518100781366, 0.034064945721183904, 0.04237450237269513, 0.05991402351355646, 0.021168421044421848, 0.028438087792892475, 0.040637557685840875, 0.07285743151442148, 0.01794603067537537, 0.05192125630856026, 0.07407066485029645, 0.03367495082784444, 0.062113014500937425, 0.016204146995733026, 0.018423144429107197, 0.015051899645186495, 0.046472218818962574, 0.06104036248871125, 0.012393992365105078, 0.03713393416546751, 0.08086824032943696, 0.02434726404317189, 0.04141292389249429, 0.021092187635076698, 0.08469474632875063, 0.04232217725075316, 0.15139236696995795, 0.11700688395649195, 0.1816100673750043, 0.125704676611349, 0.14960021391743794, 0.11484652175568044, 0.20315382775152102, 0.10470160050317645, 0.1626939995912835, 0.1011061696044635, 0.1857781468424946, 0.1807559741428122, 0.08895370177924633, 0.17354584619170055, 0.1390630379319191, 0.10508935039979406, 0.1393656263826415, 0.13371905515668914, 0.07082657408318482, 0.17446177516831085, 0.10991054950864054, 0.11742920309188776, 0.08135428768582642, 0.1271623288630508, 0.14346070820465684, 0.13038881588727236, 0.13482117414241657, 0.1250605666427873, 0.07639481162186712, 0.17700548633001745, 0.1384287391556427, 0.18282551231095567, 0.20789960981346667, 0.22573813854251057, 0.7819385477341712, 35.406378507614136, 76.94691985845566, 52.24077858030796, 37.76479795575142, 67.56522327661514, 74.63364958763123, 26.460803523659706, 1.66718844557181, 0.1090702750661876, 0.8978369005490094, 2.165365582332015, 14.294994436204433, 12.58920231834054, 7.84632389433682, 0.8085057127755135, 0.4295068950159475, 30.764781273901463, 75.28289794921875, 71.64776980876923, 75.80447316169739, 76.21657624840736, 69.2238038778305, 69.08372059464455, 76.41633152961731, 71.36181995272636, 68.0095486342907, 72.18490898609161, 74.26306307315826, 75.28659895062447, 70.41045740246773, 63.04566979408264, 67.69205287098885, 69.71985206007957, 76.52109950780869, 72.03859403729439, 63.851500153541565, 55.70675119757652, 51.46556697785854, 50.663418620824814, 51.078029572963715, 53.33246000111103, 56.71610623598099, 60.881913900375366, 62.32311196625233, 61.4184945076704, 66.43501192331314, 62.88794405758381, 62.43059299886227, 62.011486887931824, 62.50185817480087, 65.40320008993149, 70.74610099196434, 70.65492868423462, 74.74372208118439, 46.93201884627342, 55.58722481131554, 64.40896064043045, 67.46181562542915, 69.10711213946342, 69.50984492897987, 72.63004750013351, 70.45747607946396, 67.56198585033417, 62.64651261270046, 56.203050166368484, 53.43772195279598, 53.67538399994373, 52.32671096920967, 58.65979313850403, 61.21447205543518, 62.836829200387, 67.24791750311852, 66.42124146223068, 63.179282024502754, 57.324822172522545, 49.89289976656437, 47.81754992902279, 53.65070432424545, 62.09418945014477, 69.70665156841278, 68.86383399367332, 67.42997333407402, 67.82237827777863, 66.61956042051315, 62.92384833097458, 66.39651998877525, 63.90491008758545, 63.1289879232645, 58.493947237730026, 64.55439403653145, 61.41475550830364, 61.05445884168148, 62.739505022764206, 63.917966187000275, 60.85629187524319, 62.03449845314026, 42.80284121632576, 9.393072221428156, 0.20445297210244462, 1.0319031472317874, 3.0097814463078976, 4.743335824459791, 10.173154212534428, 2.9452946316450834, 0.2923785470193252, 0.22446151095209643, 14.956388846039772, 52.48754873871803, 54.83146816492081, 38.07778716087341, 38.69478665292263, 62.769542410969734, 36.87697559595108, 0.5734700965695083, 0.29073320562019944, 0.12716473342152312, 0.15730539889773354, 0.13949422573205084, 0.1251757182762958, 0.10134660318726674, 0.15000993880676106, 0.13102514814818278, 0.13415055465884507, 0.17979351250687614, 0.2062205452239141, 0.16668282070895657, 0.13312527764355764, 0.11019808720448054, 0.1222620539192576, 0.1775479517527856, 0.1582753859111108, 0.13631069421535358, 0.2027862865361385, 0.11567457302589901, 0.1406869906350039, 0.19063980784267187, 0.13226837909314781, 0.08081555526587181, 0.1476558463764377, 0.2051667548948899, 0.1639809727203101], [0.13852691045030951, 0.07346324666286819, 0.022718966065440327, 0.03985397961514536, 0.021833663668076042, 0.041855021263472736, 0.03597090711991768, 0.07629229134181514, 0.051858741499017924, 0.03210568698705174, 0.030939019707147963, 0.07849119327147491, 0.07712154489126988, 0.0344251656497363, 0.04840414425416384, 0.06153173104394227, 0.03989019271102734, 0.024954669243015815, 0.05600161763140932, 0.04721305289422162, 0.04614240468072239, 0.0170885662373621, 0.0697651544760447, 0.014085487928241491, 0.06592561636352912, 0.03987916439655237, 0.05305698716256302, 0.04618002785719, 0.01231950671353843, 0.009497317623754498, 0.05547682274482213, 0.03774054341192823, 0.0475737403758103, 0.0290051683987258, 0.23049201001413167, 0.8458009490277618, 20.94112280756235, 49.76181820034981, 40.277606919407845, 26.265554800629616, 45.558130368590355, 64.03811573982239, 28.62203825265169, 2.1931371046230197, 0.06722560676280409, 0.254946785280481, 0.9389460040256381, 4.382945112884045, 1.7740559298545122, 0.09926838931278326, 0.18973443220602348, 2.0754567068070173, 45.592902302742004, 79.23792332410812, 70.94289243221283, 72.39565327763557, 73.76655891537666, 69.01798412203789, 66.65676042437553, 69.00157660245895, 72.71982908248901, 68.47676396369934, 69.34478178620338, 72.80847072601318, 67.98218250274658, 68.94334092736244, 73.47901314496994, 68.1563575565815, 64.91247162222862, 61.20447099208832, 56.50077559053898, 52.035904973745346, 48.406225740909576, 46.58038571476936, 50.81568405032158, 51.32671482861042, 59.200241938233376, 59.91317108273506, 63.08027073740959, 62.15718246996403, 67.04117819666862, 55.78737527132034, 59.01551865041256, 54.942703396081924, 57.87386231124401, 58.45309183001518, 66.11116290092468, 59.857135489583015, 75.97183898091316, 35.69244235754013, 43.25682185590267, 64.52569797635078, 60.92291370034218, 66.95575878024101, 64.44593265652657, 64.30021807551384, 58.77726383507252, 58.07873211801052, 54.9703773111105, 52.504530027508736, 45.15991173684597, 45.822588577866554, 48.53353410959244, 52.92093068361282, 57.68150523304939, 62.0052894204855, 62.16091766953468, 62.996926009655, 62.233140394091606, 63.69179092347622, 57.504370138049126, 49.739786982536316, 46.448414996266365, 50.947198793292046, 56.19093641638756, 58.67636784911156, 62.07764893770218, 62.838702499866486, 65.25120824575424, 64.11498561501503, 62.935901284217834, 60.57948812842369, 63.4534677118063, 64.02947500348091, 57.55242615938187, 61.479321643710136, 56.03286489844322, 61.99820280075073, 60.00970870256424, 54.40117545425892, 32.31038063764572, 3.6183069180697203, 0.26031064277049154, 0.12494841328589246, 1.9989884225651622, 3.609129935503006, 4.27767033688724, 0.7589081022888422, 0.04503703137743287, 0.08414799129241146, 9.002388585358858, 45.98223701119423, 46.16301991045475, 60.21858349442482, 36.22392363846302, 35.925742238759995, 30.61627384275198, 1.1311045428737998, 0.07195636775577441, 0.061859953275416046, 0.05480071507918183, 0.03236929413105827, 0.03079623420489952, 0.04223339412419591, 0.09766533548827283, 0.07009293884038925, 0.06675213880953379, 0.040310259428224526, 0.028746260904881638, 0.029533113702200353, 0.07469140458852053, 0.06782114316592924, 0.025107126784860156, 0.07042060446110554, 0.0457918549363967, 0.04213135995087214, 0.05781397194368765, 0.05331760345143266, 0.010484713566256687, 0.017300655345025007, 0.03434809361351654, 0.056074452004395425, 0.07474648678908125, 0.03130751087155659, 0.02571715918747941, 0.032739659218350425, 0.09778895502677187, 0.04592441735439934, 0.008398274840146769, 0.04318611878261436, 0.012064251513947966, 0.03649186510301661, 0.02276085473567946, 0.043909490123041905, 0.01503288489402621, 0.04128330780076794, 0.0601789553911658, 0.04704356120782904, 0.0080732828064356, 0.04816312066395767, 0.035971909019281156, 0.02642665793246124, 0.05026708335208241, 0.0016231292670454422, 0.04278350366803352, 0.06496636822703294, 0.05972956270852592, 0.01109075135900639, 0.01577099992573494, 0.04155278162215836, 0.04694810988439713, 0.040256850770674646, 0.05336908623576164, 0.015493321661779191, 0.009364203233417356, 0.03127098607365042, 0.16850854852236807, 0.03482447820715606, 0.07868953223805875, 0.024014585214899853, 0.2803007763577625, 2.4186022812500596, 34.62104804813862, 54.520667642354965, 32.12433502078056, 29.23050720244646, 66.67365431785583, 70.3978268802166, 25.344396829605103, 2.1040724962949753, 0.030227786191971973, 0.1250550599070266, 0.8647182339336723, 1.408775474410504, 3.562570558860898, 1.4333949470892549, 0.14466890977928415, 2.9412742098793387, 50.379399061203, 81.19582906365395, 74.4448909163475, 75.42459234595299, 76.78845316171646, 70.79317286610603, 71.50858327746391, 73.5939721763134, 73.90903607010841, 70.24177685379982, 73.21020796895027, 74.59526404738426, 69.48203042149544, 67.91063234210014, 72.4075998365879, 69.2020234465599, 67.84458428621292, 63.76049503684044, 58.933655843138695, 54.54289264976978, 51.264284178614616, 49.53273609280586, 53.79827320575714, 53.39874744415283, 61.26618728041649, 62.14418716728687, 66.00693449378014, 64.72896426916122, 67.03601807355881, 59.14197586476803, 61.839375123381615, 57.575680911540985, 60.0690159201622, 60.62269560992718, 66.82733327150345, 65.75199097394943, 75.66877484321594, 37.250985726714134, 48.1302085518837, 63.04453745484352, 63.07552859187126, 67.84717574715614, 66.79375067353249, 66.97069957852364, 62.22133822739124, 61.46421745419502, 57.9500026255846, 50.62378294765949, 47.61331468820572, 47.8692689538002, 49.95968498289585, 54.62108485400677, 58.46214674413204, 65.41824728250504, 67.12464451789856, 65.17281845211983, 65.08597031235695, 65.21457821130753, 56.81771658360958, 51.02584697306156, 48.73596824705601, 54.80838820338249, 59.763493314385414, 61.52623392641544, 64.79421436786652, 66.07720792293549, 67.7948297560215, 66.0875053703785, 66.30648761987686, 61.62927679717541, 64.12176445126534, 65.9875175356865, 60.466163009405136, 61.421944722533226, 56.842134073376656, 64.16680723428726, 58.61002340912819, 56.88303507864475, 36.22151456773281, 5.909677064046264, 0.45639573654625565, 0.3441381821176037, 0.9900416841264814, 1.2144062854349613, 0.9291841497179121, 0.19308962248032913, 0.09122045827098191, 0.08688537331181578, 8.847621940076351, 48.528848960995674, 53.511548191308975, 58.08433301746845, 31.664515994489193, 37.5694390386343, 44.65439826250076, 3.517212155275047, 0.11059958167606965, 0.1386165025178343, 0.0273552553699119, 0.009421474769624183, 0.029055870072625112, 0.01586243808560539, 0.035221690486650914, 0.056114331309800036, 0.017818106680351775, 0.0383453492395347, 0.04062811014591716, 0.030201449226296972, 0.005727395746362163, 0.04993262336938642, 0.023407475018757395, 0.08008940087165684, 0.028610089793801308, 0.03727820767380763, 0.006075713481550338, 0.06876442770590074, 0.04570114964735694, 0.044690541180898435, 0.0386935723508941, 0.03603916244173888, 0.07016206247499213, 0.008040607899602037, 0.03799444326432422, 0.03218689278583042, 0.3253021772252396, 0.16986991453450173, 0.07008084925473668, 0.11597656775848009, 0.10905122413532808, 0.13436813751468435, 0.1843343727523461, 0.12124391636461951, 0.16702279855962843, 0.13613663089927286, 0.10453591603436507, 0.18355379666900262, 0.17243023496121168, 0.14523378806188703, 0.18998860294232145, 0.144540399487596, 0.12223516590893269, 0.07356046058703214, 0.1184553855273407, 0.1472504111006856, 0.14646956784417853, 0.11514793019159697, 0.1477942123892717, 0.15902859158813953, 0.11788742733187973, 0.13321865466423333, 0.12731562688713893, 0.05661932569637429, 0.10211082975729369, 0.16315859887981787, 0.2448074598214589, 0.12312388033024035, 0.3095383965410292, 0.12430944640072994, 0.24137893051374704, 1.7351056449115276, 36.7938968539238, 68.63259360194206, 51.58610790967941, 37.05283775925636, 58.55171553790569, 76.64834707975388, 41.82334117591381, 3.77331817522645, 0.13562267879024148, 0.6687787198461592, 2.6890750927850604, 15.791324693709612, 9.01827173307538, 2.110037226229906, 0.33581787545699626, 3.549472186714411, 49.75264169275761, 85.99242568016052, 76.98393747210503, 75.65397843718529, 80.73971673846245, 72.91163519024849, 74.11353349685669, 74.90179359912872, 80.17061367630959, 74.17727127671242, 75.1458241045475, 75.5932728946209, 68.34915921092033, 70.09082615375519, 75.43203234672546, 72.37427562475204, 69.62112575769424, 64.98006239533424, 61.33731946349144, 57.84533344209194, 52.77765177190304, 53.045290410518646, 58.03376533091068, 56.32134921848774, 63.79954934120178, 66.44299909472466, 70.39201319217682, 67.15961024165154, 74.48823139071465, 61.360004246234894, 64.68927159905434, 62.70606301724911, 61.9789682328701, 63.02087612450123, 70.25034159421921, 67.77521520853043, 78.93799781799316, 41.95996284484863, 48.492705300450325, 68.98031294345856, 66.05025216937065, 69.8681429028511, 68.7555094063282, 68.6075833439827, 62.49063357710838, 62.6897618919611, 61.08562856912613, 55.97900278866291, 49.52408775687218, 50.214894488453865, 52.552388459444046, 56.67312674224377, 62.31642432510853, 66.439518481493, 68.98227363824844, 66.67461946606636, 67.78790652751923, 69.87135753035545, 60.521051064133644, 56.04905962944031, 52.28177838027477, 55.873968824744225, 60.235325396060944, 61.95227086544037, 67.51736864447594, 67.10328966379166, 70.52331894636154, 66.97772920131683, 68.3401308953762, 63.43615964055061, 66.44144877791405, 66.5538315474987, 58.80285166203976, 63.55095908045769, 60.145999789237976, 62.25965917110443, 59.554276540875435, 55.92878468334675, 35.331207141280174, 4.871315807104111, 0.39000142423901707, 0.43419584340881556, 4.802022250369191, 13.302127663046122, 12.034775968641043, 1.5890537132509053, 0.24266391468700022, 0.12676468613790348, 15.4168357886374, 59.93887670338154, 57.728824093937874, 73.84647622704506, 44.96367506682873, 47.23843440413475, 51.98602885007858, 3.3691082149744034, 0.37506151653360575, 0.238348058774136, 0.1390991359949112, 0.07951647770823911, 0.11611416935920715, 0.07835670869098976, 0.12993181619094685, 0.1828778485651128, 0.11283673389698379, 0.1368049645680003, 0.09507506940281019, 0.1356463533011265, 0.1728517303126864, 0.1024424287606962, 0.12028639001073316, 0.21892629156354815, 0.10319396460545249, 0.11697711641318165, 0.1868915613158606, 0.10134074022062123, 0.15093943424290046, 0.07795824218192138, 0.12237929098773748, 0.15824979665922, 0.1890529625234194, 0.0626538138021715, 0.11033990420401096, 0.13551662588724867], [0.04245474709023256, 0.02691754409170244, 0.0623080249351915, 0.0027935927482758416, 0.016624343588773627, 0.06148575870611239, 0.011878423301823204, 0.06813311978476122, 0.008232201671489747, 0.06313854013569653, 0.02962172613479197, 0.04019050647912081, 0.02475086435879348, 0.038378875760827214, 0.04536216256383341, 0.017904206943057943, 0.04920482140732929, 0.047245135938283056, 0.015076208692335058, 0.11088402461609803, 0.04625386412953958, 0.057224172342102975, 0.028237995502422564, 0.05616681599349249, 0.055704138867440633, 0.025442427249799948, 0.016414252713730093, 0.10435410469654016, 0.05602971163170878, 0.053544875045190565, 0.07061121024889871, 0.04091224880539812, 0.06404300293070264, 0.0501986313611269, 0.05309027990733739, 0.07141255162423477, 1.3126026350073516, 22.38480594009161, 56.885721534490585, 39.038132429122925, 28.054183423519135, 41.48979887366295, 61.69852428138256, 39.59895193576813, 3.4789712447673082, 0.043823282248922624, 0.03899504015862476, 0.5185723048634827, 2.962279007770121, 0.5647984868846834, 0.19753520580707118, 0.11729674457455985, 3.4271890483796597, 44.26178812980652, 79.59650248289108, 73.05607303977013, 71.90813183784485, 70.5263739824295, 75.3395377099514, 68.1111703813076, 70.86643293499947, 73.34649905562401, 74.02139604091644, 67.15524047613144, 66.79905518889427, 68.41909065842628, 70.69548010826111, 70.85646227002144, 68.71536836028099, 65.25826826691628, 58.956507816910744, 53.1660745292902, 48.6221681535244, 48.53740230202675, 52.361418306827545, 57.19447776675224, 61.45208850502968, 60.91224767267704, 63.8825748860836, 62.683294638991356, 68.02792444825172, 63.96430850028992, 64.52224776148796, 59.49332021176815, 60.96456326544285, 65.00367432832718, 70.21690338850021, 67.2461012005806, 75.34175679087639, 35.87793320417404, 55.871191173791885, 74.37716335058212, 62.783537060022354, 70.37567406892776, 64.13752600550652, 64.40115585923195, 60.977338179945946, 59.87057536840439, 56.93065792322159, 53.98195914924145, 47.97607742249966, 50.27299337089062, 48.195918425917625, 52.85528160631657, 54.959502294659615, 61.66231982409954, 62.207370176911354, 64.97401311993599, 62.34319008886814, 64.71976116299629, 58.82856108248234, 53.845098093152046, 46.60471200942993, 49.63859461247921, 55.40639631450176, 59.77259382605553, 56.987183690071106, 65.52100896835327, 64.58695828914642, 64.92704004049301, 63.9401113986969, 67.99297392368317, 58.6597665399313, 67.79730722308159, 58.97849343717098, 55.85496984422207, 61.4552803337574, 52.82151281833649, 52.87881374359131, 15.323679987341166, 1.916937525384128, 0.026518643426243216, 1.430196943692863, 0.23621588334208354, 0.44959855440538377, 0.48390691343229264, 0.33420198247767985, 0.2509102737531066, 0.1312701459391974, 11.676315553486347, 57.11156241595745, 45.00121705234051, 30.942129157483578, 57.177561074495316, 40.40410213172436, 35.25025628507137, 5.392924742773175, 0.08108117734082043, 0.06337875107419677, 0.025165225815726444, 0.037385399773484096, 0.02748005306784762, 0.05638765316689387, 0.033434227807447314, 0.07833461495465599, 0.03259455079387408, 0.04716030103736557, 0.03076075212447904, 0.02842948815668933, 0.01717231574730249, 0.0566014622017974, 0.013615569296234753, 0.03198491729563102, 0.02008631592616439, 0.0844079878879711, 0.017709075909806415, 0.029138972058717627, 0.03338420334330294, 0.06955066637601703, 0.0990760097920429, 0.02455256435496267, 0.021858397594769485, 0.011479969780339161, 0.036156169444439, 0.049354160073562525, 0.036805700801778585, 0.019252527854405344, 0.047234564044629224, 0.059894453079323284, 0.01839541037043091, 0.012756589021591935, 0.06936473611858673, 0.02875076388590969, 0.009901420744427014, 0.05227789166383445, 0.04726583072624635, 0.009592704009264708, 0.009255430359189631, 0.0270165929759969, 0.08526441888534464, 0.03139726250083186, 0.007387362093140837, 0.03427491414186079, 0.030152602921589278, 0.035607896716101095, 0.05463708635943476, 0.07383910735370591, 0.032922216414590366, 0.025454839669691864, 0.04883303139649797, 0.12774166418239474, 0.022437795996665955, 0.0347338619758375, 0.053807220538146794, 0.03295110451290384, 0.09964416094589978, 0.03548860018781852, 0.059285550596541725, 0.012317488071857952, 0.052527067746268585, 0.0638212937337812, 0.10747791558969766, 2.83976883161813, 33.50721761584282, 62.057502418756485, 31.723868809640408, 27.777206785976887, 58.311158046126366, 73.01509603857994, 36.578281223773956, 3.3624930074438453, 0.0604205689887749, 0.043834715033881366, 0.28116300352849066, 0.988057596841827, 0.10475231887539849, 0.23958599078468978, 0.1775536366039887, 5.071943616494536, 51.48287884891033, 82.77932569384575, 72.55856573581696, 74.38147991895676, 76.16366028785706, 76.17610082030296, 70.07311910390854, 72.71130234003067, 77.14886382222176, 75.32122269272804, 68.67964267730713, 66.93676739931107, 68.35815712809563, 72.85450145602226, 72.45362296700478, 70.64997375011444, 66.30093231797218, 59.19114522635937, 53.635090962052345, 51.05114221572876, 50.5698524415493, 53.34040157496929, 57.615631967782974, 62.54541903734207, 63.32641012966633, 65.81805422902107, 63.51719789206982, 69.29318055510521, 64.89494696259499, 65.46936213970184, 61.778122410178185, 62.10203602910042, 65.12567818164825, 70.74962720274925, 66.58185884356499, 73.06663647294044, 38.05224873125553, 56.091685742139816, 73.33924904465675, 64.71368908882141, 70.758495926857, 67.01413124799728, 65.73839530348778, 62.20342218875885, 61.78006790578365, 58.583702221512794, 56.3083653151989, 50.57515695691109, 52.950447499752045, 52.50966355204582, 56.81228667497635, 56.70721851289272, 63.94951969385147, 63.03859457373619, 66.41760885715485, 63.79596993327141, 66.64368152618408, 60.833094120025635, 54.64974291622639, 48.415048867464066, 52.35273577272892, 57.87693254649639, 63.37443955242634, 60.71632258594036, 66.7653737962246, 65.68570733070374, 64.69479650259018, 64.54383820295334, 68.05259272456169, 61.70615427196026, 66.78600668907166, 57.40339435636997, 59.89432789385319, 60.2887961268425, 55.045761466026306, 56.04228459298611, 19.609261974692345, 3.0385292787104845, 0.19444873236352578, 1.8218380096368492, 1.2891944660805166, 0.9646475873887539, 0.6875103490892798, 0.2426921162987128, 0.2969371742801741, 0.3177988267270848, 11.251890677958727, 56.26501344144344, 53.824841380119324, 37.7457419782877, 63.96981060504913, 45.947837457060814, 44.33176897466183, 10.7888712733984, 0.06993283532210626, 0.037516292359214276, 0.06848503879155032, 0.0712725825724192, 0.05525404485524632, 0.032551732583669946, 0.037043674165033735, 0.02333460910449503, 0.041829465408227406, 0.07526659130235203, 0.04638405909645371, 0.010557483001321089, 0.013889018246118212, 0.051019235179410316, 0.03437829531321768, 0.04133052323595621, 0.04957525699865073, 0.04737047725939192, 0.061969349553692155, 0.031571002982673235, 0.03382881659490522, 0.03459465362539049, 0.06376448975061066, 0.043799277482321486, 0.08723385617486201, 0.018031570616585668, 0.07453079640981741, 0.049850404539029114, 0.02002997021918418, 0.1629097864497453, 0.0763606654072646, 0.22000666562234983, 0.09892373593174852, 0.11374758658348583, 0.21430189517559484, 0.09012410577270202, 0.1602530461968854, 0.1161210416466929, 0.22091391147114336, 0.10509027808438987, 0.12911635916680098, 0.27754129318054765, 0.14143581764074042, 0.12930827855598181, 0.1328283888869919, 0.16484938940266147, 0.14472875656792894, 0.13038740580668673, 0.2371132289408706, 0.18038868525763974, 0.0874658886459656, 0.10972600706736557, 0.11045073653804138, 0.22080591414123774, 0.17267846851609647, 0.07630035106558353, 0.1479804766131565, 0.09770866949111223, 0.20685138559201732, 0.10138053417904302, 0.16931567864958197, 0.16605175769655034, 0.2220706970547326, 0.22215179895283654, 0.1751027681166306, 2.047234196215868, 34.94415611028671, 75.77487275004387, 49.54976677894592, 39.53101918101311, 54.01455760002136, 71.8256838619709, 51.72516904771328, 5.316285705193877, 0.14184046623995528, 0.2979164232965559, 2.8888667095452547, 16.69645417481661, 4.591484097763896, 0.4278800479369238, 0.33057703636586666, 4.76402903907001, 48.56423266232014, 85.0141453742981, 75.64941108226776, 77.86465421319008, 77.55260735750198, 80.27822390198708, 74.77608114480972, 74.87421467900276, 80.78145369887352, 76.98407426476479, 69.14955586194992, 66.97917312383652, 66.86314254999161, 73.53434577584267, 76.98984235525131, 74.62877824902534, 72.70041212439537, 63.733026310801506, 58.23011599481106, 53.464487716555595, 55.21067261695862, 57.80991934239864, 59.829985946416855, 66.8792536854744, 66.76396027207375, 67.87594020366669, 67.93962478637695, 72.00982958078384, 69.16455745697021, 69.27238047122955, 66.59201189875603, 66.23677656054497, 71.7668554186821, 73.8706049323082, 72.57013991475105, 75.50372689962387, 41.39942832291126, 59.52441394329071, 73.29971596598625, 69.37999829649925, 75.51925286650658, 71.23002022504807, 70.4961884021759, 66.97756201028824, 66.39238581061363, 61.848920211195946, 59.18017901480198, 54.382932633161545, 55.97022905945778, 56.15688644349575, 59.39427092671394, 60.59802733361721, 66.57471522688866, 66.69753223657608, 69.34301868081093, 67.1554684638977, 67.23287031054497, 62.59855158627033, 56.11753195524216, 52.173020616173744, 53.619629591703415, 62.06919439136982, 65.60243099927902, 62.358704656362534, 69.29084748029709, 69.54350352287292, 65.66872984170914, 69.08416137099266, 69.49756398797035, 63.808942437171936, 67.34106570482254, 62.747530192136765, 60.24696797132492, 64.72076430916786, 55.383175760507584, 56.49260602891445, 17.81886074692011, 2.594353538006544, 0.10012534723500721, 3.273565429262817, 0.8610610489267856, 3.481597378849983, 4.6743495762348175, 0.8956878783646971, 1.0776138631626964, 0.26330874126870185, 20.527887381613255, 70.33395990729332, 56.19101241230965, 44.23165574669838, 62.70280659198761, 52.944709807634354, 54.28181625902653, 9.976273477077484, 0.15414662542752922, 0.09479566564550623, 0.23311530909268185, 0.11768324024160393, 0.23421398451318964, 0.11218777028261684, 0.1456569755100645, 0.18615929904626682, 0.0857987800554838, 0.16059683868661523, 0.15365551662398502, 0.14199274010024965, 0.10440504571306519, 0.19332083116751164, 0.10393649819889106, 0.11343209218466654, 0.14115059544565156, 0.26659063703846186, 0.1557676392258145, 0.12717343139229342, 0.11319617085973732, 0.1937773558893241, 0.2613301755627617, 0.07891365341492929, 0.11018884004442953, 0.07811336588929407, 0.19690172339323908, 0.08245043980423361, 0.10235528578050435], [0.03298588897450827, 0.06157185525808018, 0.01960592930117855, 0.05699200999515597, 0.04672207767725922, 0.05462527878989931, 0.03644667573098559, 0.007438293368977611, 0.05843579892825801, 0.013883604278817074, 0.039294997695833445, 0.0503833444963675, 0.042709437329904176, 0.033017040623235516, 0.026044208825624082, 0.037211277085589245, 0.025052990822587162, 0.010140611229871865, 0.02320469058759045, 0.046409377464442514, 0.04589317293721251, 0.03220799575501587, 0.11283462619758211, 0.02849435000825906, 0.03145551367197186, 0.095637439226266, 0.027200259683013428, 0.05767220318375621, 0.01964699047675822, 0.04996256531740073, 0.016258193900284823, 0.0630516123783309, 0.06427564396290109, 0.06640368563239463, 0.10331331679481082, 0.027377594014978968, 0.13083147729048505, 0.9722391644027084, 13.719590362161398, 57.33338311314583, 46.79694749414921, 31.474585086107254, 42.36816734075546, 61.2596820294857, 56.536444276571274, 8.950324729084969, 0.10846759178093635, 0.11690489802276716, 0.5449327372480184, 1.075776305515319, 6.203342406079173, 0.5094761867076159, 0.11461715359473601, 1.8485363270156085, 29.853204488754272, 81.74575835466385, 82.10702776908875, 72.6554149389267, 72.37784743309021, 77.05681756138802, 79.01326417922974, 70.73875218629837, 65.90359523892403, 68.24684590101242, 72.22672194242477, 72.29087769985199, 72.30824276804924, 69.52151790261269, 65.70795893669128, 57.59547404944897, 58.32564286887646, 50.84636740386486, 52.88404606282711, 50.536824613809586, 56.39910824596882, 61.70467995107174, 63.97190049290657, 64.6770666539669, 66.39367774128914, 61.89410358667374, 67.72129610180855, 62.32277378439903, 66.32664173841476, 63.62275242805481, 60.793177261948586, 65.01576527953148, 64.09509748220444, 64.47945445775986, 70.7696445286274, 35.25353170931339, 44.52490881085396, 72.0102247595787, 65.99620386958122, 65.16914024949074, 61.30361147224903, 61.254050731658936, 57.18427911400795, 56.04641117155552, 57.086286172270775, 51.96690447628498, 50.14368250966072, 50.59646621346474, 49.92030009627342, 51.71126939356327, 56.02377198636532, 57.67871618270874, 61.382240653038025, 65.28471484780312, 67.32191473245621, 66.70133203268051, 64.26358804106712, 62.825581803917885, 53.69387000799179, 48.20505313575268, 52.72353507578373, 58.80769640207291, 61.7417773604393, 62.87519954144955, 62.89319157600403, 66.62008479237556, 63.459923565387726, 59.29084047675133, 65.6069603562355, 65.0465740263462, 58.29190067946911, 63.39500404894352, 59.10553961992264, 27.833305075764656, 6.483261985704303, 0.4230252740671858, 0.2162775516626425, 3.388768834993243, 1.275671347975731, 1.5106146410107613, 0.24016859155381098, 0.026807351860043127, 0.3837465145625174, 0.10112031493918039, 22.527131102979183, 56.23595640063286, 39.76870782673359, 28.190392814576626, 24.916568286716938, 36.71948164701462, 32.81446538865566, 5.316484244540334, 0.18080264038871974, 0.12789519969373941, 0.06280006884480827, 0.017524281138321385, 0.012594362033269135, 0.044754402988473885, 0.061104535998310894, 0.015058629069244489, 0.01694140020845225, 0.07037323317490518, 0.048997572957887314, 0.0925841397838667, 0.01622556352231186, 0.03214083881175611, 0.05460384185425937, 0.06662825209787115, 0.05906986763875466, 0.03205149907444138, 0.10238908318569884, 0.0514896974345902, 0.013676192556886235, 0.06151714413135778, 0.015830967313377187, 0.026496679565752856, 0.030075597678660415, 0.020423328896868043, 0.026832907715288457, 0.030260644780355506, 0.08812272644718178, 0.07208398004877381, 0.016638757952023298, 0.013850173309037928, 0.01733079581754282, 0.0409007232519798, 0.0453295414627064, 0.02192854353779694, 0.046858666246407665, 0.004020183814645861, 0.03641949828306679, 0.03311508575279731, 0.014948102871130686, 0.05789854338217992, 0.07007669322774746, 0.04159917327342555, 0.03691330479341559, 0.027336178463883698, 0.014620914080296643, 0.035579413088271394, 0.08097348429146223, 0.007858261287765345, 0.09752215293701738, 0.01418379837559769, 0.016970314281934407, 0.03071413597353967, 0.03836530930129811, 0.03746375201444607, 0.02958584143925691, 0.042873262718785554, 0.04293388134101406, 0.04472997519769706, 0.0419530960789416, 0.044428997207432985, 0.12455550546292216, 0.04557713677058928, 0.08221834053983912, 0.047368269370053895, 0.2695054962532595, 3.0601247074082494, 27.655892595648766, 66.45832747220993, 40.008664950728416, 26.956224739551544, 48.95281121134758, 76.60245314240456, 54.77914497256279, 5.057697705924511, 0.07716453008470125, 0.13538719533244148, 0.2646485553123057, 0.43171273602638394, 4.640028867870569, 0.24900510645238683, 0.13864307140465826, 3.4702153271064162, 36.19909577071667, 84.77834522724152, 83.23741391301155, 76.03290170431137, 76.52037754654884, 78.17739263176918, 80.90836688876152, 70.075573772192, 68.81749927997589, 69.33214366436005, 71.81198939681053, 72.5373400747776, 74.61933955550194, 70.76194614171982, 67.24475607275963, 60.190434604883194, 60.420706048607826, 54.207021072506905, 55.40577694773674, 51.780919656157494, 57.4432048201561, 62.08369441330433, 66.16675391793251, 66.3872940838337, 66.92210018634796, 64.5219361782074, 69.99022275209427, 65.06231278181076, 68.86935129761696, 66.08106091618538, 61.99412181973457, 66.2931427359581, 69.03949856758118, 65.97304791212082, 69.65900972485542, 36.77259139716625, 50.699239298701286, 72.41348952054977, 66.69387683272362, 66.65942028164864, 61.887199357151985, 63.417339250445366, 60.43125048279762, 58.02308790385723, 60.3489089012146, 55.34980595111847, 51.05613134801388, 52.080282792449, 51.82072252035141, 53.02877649664879, 58.02000626921654, 59.82300192117691, 64.06726017594337, 66.76354989409447, 69.98633176088333, 67.89316087961197, 66.07029229402542, 63.42816486954689, 54.86305586993694, 50.60317665338516, 54.7439930588007, 59.56784941256046, 63.735511377453804, 64.48045760393143, 64.5585586130619, 68.40073004364967, 66.5545991063118, 59.69346307218075, 65.56393906474113, 66.06929674744606, 60.634398981928825, 61.664288118481636, 63.322918117046356, 32.01938085258007, 9.31380657479167, 1.2131679081358016, 0.5767453426960856, 3.094972399994731, 2.1542112808674574, 0.76750258798711, 0.12951591663295403, 0.0330447969463421, 0.5304937495384365, 0.31682563363574445, 17.60142121464014, 61.76294982433319, 58.03791090846062, 35.11682264506817, 26.40410676598549, 40.95002643764019, 43.48642073571682, 12.173356432467699, 0.18683701346162707, 0.117178394284565, 0.01780427304765908, 0.07441406400175765, 0.03804322092037182, 0.017610266368137673, 0.11810693235020153, 0.021116728603374213, 0.08406172404647805, 0.012972478853043867, 0.10181215984630398, 0.008406547003687592, 0.038784325879532844, 0.04478900562389754, 0.01887088583316654, 0.01916310462547699, 0.00442806214778102, 0.06287590891588479, 0.049249558069277555, 0.08601861161878332, 0.03833617258351296, 0.07649503866559826, 0.02378989629505668, 0.0031598180430592038, 0.03382257142220624, 0.05399724002927542, 0.08858446104568429, 0.05796293211460579, 0.03122987851384096, 0.06819324858952314, 0.16127968876389787, 0.10086100111948326, 0.11721533839590847, 0.16250754240900278, 0.21969665569486097, 0.12958410516148433, 0.13457645836751908, 0.06712414033245295, 0.16648143151542172, 0.10362107801483944, 0.16082170943263918, 0.19068742403760552, 0.20829729706747457, 0.1759451799443923, 0.12404458873788826, 0.1334796828450635, 0.14365179638843983, 0.12193803966511041, 0.15648124390281737, 0.09309433662565425, 0.1807695851312019, 0.13542878528824076, 0.26209283620119095, 0.20708863536128774, 0.12919106375193223, 0.26764338836073875, 0.11766604467993602, 0.14005778299178928, 0.09055068483576179, 0.11527274458785541, 0.10674123011995107, 0.15456973866093904, 0.1979483594186604, 0.17301443876931444, 0.24765666865278035, 0.1600261271232739, 0.27838668844196945, 1.9092881795950234, 28.378300331532955, 76.483633518219, 59.26632799208164, 44.551556780934334, 53.81918728351593, 73.84938687086105, 70.81413254141808, 15.186965223401785, 0.19196630775695667, 0.22676978318486363, 2.6281717233359814, 2.34916718211025, 9.307290874421597, 0.7681072899140418, 0.14432669064262882, 3.3823543041944504, 33.17934840917587, 83.82433041930199, 83.55498567223549, 79.2994724214077, 77.44056656956673, 80.64652293920517, 85.00164404511452, 71.88084170222282, 67.9597257077694, 67.9973816871643, 72.7833616733551, 75.35941824316978, 74.80825021862984, 75.13260081410408, 71.80694326758385, 61.994311809539795, 61.75321854650974, 56.30629822611809, 58.28131064772606, 55.29484190046787, 63.27654540538788, 69.21172052621841, 70.01210957765579, 69.66794684529305, 69.69648331403732, 67.23068162798882, 75.47160342335701, 68.16229283809662, 72.30107635259628, 68.81995394825935, 66.00931316614151, 70.05361095070839, 70.71345314383507, 66.17680057883263, 70.12323841452599, 41.01754881441593, 48.40806484222412, 72.76035770773888, 69.11757677793503, 67.84982800483704, 64.78904664516449, 64.67159494757652, 62.95778810977936, 59.642720595002174, 64.38778817653656, 58.413589149713516, 54.603039622306824, 54.08777207136154, 54.136413261294365, 55.88093385100365, 60.76727785170078, 61.70779198408127, 66.7244727909565, 69.54098805785179, 72.96954408288002, 72.72258013486862, 69.70508605241776, 68.07289883494377, 59.17287960648537, 52.599361538887024, 58.23215648531914, 61.48998387157917, 68.28792169690132, 68.50764110684395, 69.29122745990753, 70.94101533293724, 66.6523602604866, 61.560656279325485, 66.85810402035713, 65.555929094553, 58.05166617035866, 65.44169202446938, 60.57544134557247, 32.86095589399338, 7.456363644450903, 0.8069738605991006, 0.4547405691118911, 4.597661616280675, 2.895733416080475, 3.1474986439570785, 1.5534971212036908, 0.21547401353018358, 0.8194794051814824, 0.3769494214793667, 31.695832014083862, 66.2854215502739, 52.745406702160835, 41.05268932878971, 34.64963011443615, 49.52978365123272, 51.962975487113, 11.527446191757917, 0.20795237651327625, 0.1841520715970546, 0.16875712346518412, 0.19176998001057655, 0.13849332084646448, 0.0932710716733709, 0.1576916125486605, 0.08953308904892765, 0.14827395149040967, 0.16679346008459106, 0.20354643871542066, 0.1346855837618932, 0.14038181951036677, 0.17920586513355374, 0.08741611280129291, 0.12812974804546684, 0.1047492389625404, 0.09036755247507244, 0.1882001754711382, 0.21596745267743245, 0.20450553100090474, 0.13855312310624868, 0.1009885614621453, 0.149015698407311, 0.1358911581337452, 0.07815258097252809, 0.21832132246345282, 0.2545577514683828, 0.1319505914580077, 0.25620950502343476], [0.09469914934015833, 0.026916241622529924, 0.05748865150962956, 0.029599582303490024, 0.03885140489728656, 0.04825561823963653, 0.022411746613215655, 0.033843258788692765, 0.012027697030134732, 0.037262147598084994, 0.035506025815266185, 0.02396772601059638, 0.06530701401061378, 0.026250698429066688, 0.03641840361524373, 0.04603876746841706, 0.032712979009374976, 0.03152428107568994, 0.0634134242136497, 0.01642494335101219, 0.02710884749831166, 0.02819859673763858, 0.035814299117191695, 0.048158511926885694, 0.04247170145390555, 0.018348942649026867, 0.017662322461546864, 0.008224218945542816, 0.014913285012880806, 0.01210263817483792, 0.025774690475373063, 0.041907684062607586, 0.059789483711938374, 0.08506979065714404, 0.04052984979352914, 0.0767056824406609, 0.07820229002390988, 0.02049874408839969, 0.14996684971265495, 6.5224070101976395, 52.669988349080086, 57.436650171875954, 47.22967207431793, 31.408179849386215, 56.65742598474026, 67.23034724593163, 19.946645870804787, 0.8384978596586734, 0.2664035267662257, 0.04354355936811771, 1.7411379399709404, 0.73944833711721, 0.015362797366833547, 0.2491128514520824, 0.10524865239858627, 14.535596575587988, 54.92131434381008, 76.10097125172615, 77.38884374499321, 68.88509765267372, 67.69832253456116, 72.41981238126755, 73.97360980510712, 69.32517483830452, 71.4447695016861, 71.06495708227158, 69.17160227894783, 71.20628669857979, 67.38676205277443, 65.36820396780968, 58.45179609954357, 54.96646732091904, 54.30296592414379, 53.22407081723213, 57.50579886138439, 61.821272894740105, 62.85769008100033, 62.93726921081543, 65.74564531445503, 66.63285970687866, 70.72860673069954, 69.85060304403305, 68.16464871168137, 64.71549779176712, 68.219213783741, 65.3793753683567, 67.73784041404724, 68.95291641354561, 72.87841737270355, 29.576879516243935, 33.02434712648392, 73.69068458676338, 74.0344749391079, 69.98834565281868, 67.07234412431717, 63.26366789638996, 59.040889889001846, 59.25527438521385, 58.92579026520252, 56.53403900563717, 51.30108140408993, 51.39780141413212, 50.492739379405975, 52.468770146369934, 53.83285515010357, 53.00899475812912, 55.831084325909615, 58.42723801732063, 60.76397582888603, 61.92916810512543, 60.73190554976463, 58.98093670606613, 58.759708777070045, 57.249567210674286, 57.620966881513596, 58.86757358908653, 64.35451716184616, 66.67312234640121, 67.05690935254097, 63.3040027320385, 67.87359952926636, 69.87512692809105, 65.95102429389954, 70.32719627022743, 62.1833136677742, 41.58158674836159, 11.477658413350582, 0.5922939302399755, 0.25554335326887667, 0.13385526894126087, 5.670959148555994, 5.326896160840988, 0.14405214053113014, 1.7932470375671983, 0.5755713838152587, 0.06434479728341103, 0.7268707151524723, 32.45733395218849, 57.089364007115364, 25.772455260157585, 22.438987232744694, 30.298952870070934, 45.101501271128654, 36.8831692636013, 3.851790614426136, 0.038585096335737035, 0.10433704272145405, 0.03606115969887469, 0.023205916986626107, 0.02924070751760155, 0.019191154096915852, 0.034637460703379475, 0.03950021637137979, 0.015488615517824655, 0.019220353897253517, 0.03628767059126403, 0.026996254418918397, 0.026618310148478486, 0.038078372745076194, 0.08005706549738534, 0.04550901874608826, 0.017317053097940516, 0.008459986274829134, 0.049626765758148395, 0.07416100648697466, 0.052253957401262596, 0.10594778519589454, 0.027830309663841035, 0.015246605798893142, 0.0386949230596656, 0.030187552511051763, 0.049819924533949234, 0.04239670372044202, 0.05038350405811798, 0.04336616751970723, 0.025865534917102195, 0.020609594976122025, 0.026101363473571837, 0.03257723648857791, 0.0769073016999755, 0.025987397420976777, 0.02331328720174497, 0.03509920643409714, 0.03989813369116746, 0.03759588398679625, 0.058989374301745556, 0.023399754827551078, 0.07919314622995444, 0.05194855621084571, 0.06255364613025449, 0.021734388428740203, 0.06130110123194754, 0.012957082071807235, 0.022227758927328978, 0.0475906279461924, 0.029789744658046402, 0.028523707514978014, 0.003146730732623837, 0.01912639243528247, 0.023519559726992156, 0.04216268971504178, 0.04197659247438423, 0.032141829578904435, 0.029896452506363858, 0.03683478927996475, 0.030013372306711972, 0.1009301321755629, 0.08117448014672846, 0.020012216191389598, 0.054024847922846675, 0.0300866445468273, 0.009133929652307415, 0.038173382490640506, 0.050313129904679954, 0.7269555574748665, 16.421656720340252, 65.55149853229523, 53.15983906388283, 41.12322874367237, 36.894884034991264, 81.08185037970543, 76.1390832066536, 13.38860247284174, 0.7035717309918255, 0.6986773561220616, 0.029878112181904726, 3.4533287957310677, 1.4960661716759205, 0.015802387206349522, 0.4049755894811824, 0.2913867705501616, 22.056742943823338, 65.09699732065201, 78.64814937114716, 76.2383034825325, 68.45311403274536, 71.42200872302055, 75.38084149360657, 71.46392807364464, 65.63382491469383, 70.80971717834473, 72.20386996865273, 72.56756365299225, 74.46224078536034, 71.0960166156292, 65.47554820775986, 60.97375497221947, 55.87835758924484, 54.918342903256416, 55.23502551019192, 59.07794930040836, 62.76251278817654, 66.1741255223751, 65.92195585370064, 69.31131318211555, 68.77136215567589, 72.99906089901924, 70.07229074835777, 68.28383311629295, 67.04171016812325, 69.98996436595917, 68.283871114254, 71.11319929361343, 67.49064087867737, 71.86175152659416, 35.83658382296562, 36.437080800533295, 72.71023079752922, 73.37236806750298, 72.0806197822094, 68.38592603802681, 63.981217592954636, 60.89807443320751, 61.84917099773884, 62.266848385334015, 59.15106877684593, 53.95677410066128, 52.28419505059719, 54.793580397963524, 53.8787566870451, 56.31930872797966, 56.207758113741875, 59.304576739668846, 60.97373217344284, 63.12249407172203, 64.2614221572876, 63.00338566303253, 61.86661206185818, 59.75622050464153, 58.400932028889656, 59.192387759685516, 61.08706869184971, 67.53287181258202, 66.94131955504417, 69.72728446125984, 64.76729661226273, 68.2579717040062, 69.43653926253319, 68.07556629180908, 68.62349689006805, 64.08387288451195, 45.181627571582794, 16.90826240926981, 1.7809867579489946, 1.2132359482347965, 0.737893448676914, 6.354489745572209, 9.043241143226624, 0.6763656658586115, 0.27387027454096824, 0.17729437473462895, 0.19862648943671957, 0.4672253632452339, 27.56062600761652, 69.0790468454361, 39.87233206629753, 23.289459496736526, 32.96518050134182, 47.969370782375336, 45.78907057642937, 8.468811716884375, 0.045778763451380655, 0.02222528386482736, 0.022784377106290776, 0.01988272440939909, 0.024551191381760873, 0.029031798512733076, 0.021780485076305922, 0.01658264602156123, 0.012887886077805888, 0.03923960750398692, 0.047772042235010304, 0.06724991952069104, 0.07886806328315288, 0.008962237498053582, 0.02771099087112816, 0.018350823993387166, 0.05269311215670314, 0.04797696405148599, 0.02139995998732047, 0.056646080120117404, 0.0337824546295451, 0.10073706987896003, 0.052158053367747925, 0.014510517758026253, 0.05624967307085171, 0.04154132286203094, 0.004704058519564569, 0.07990525919012725, 0.03992469886725303, 0.03477377467788756, 0.0600637592287967, 0.16325083299307153, 0.09739163884660229, 0.10544461649260484, 0.2621377806644887, 0.05924063952988945, 0.13578644109657034, 0.16895719163585454, 0.08860308153089136, 0.057344864108017646, 0.15278776787454262, 0.08352115110028535, 0.14186133543262258, 0.10432195485918783, 0.11797114158980548, 0.11497498751850799, 0.13454156258376315, 0.13145756791345775, 0.09942052958649583, 0.19082892191363499, 0.1620703432126902, 0.22568002837942913, 0.11055445909732953, 0.12991799740120769, 0.1344956087996252, 0.11736853251932189, 0.14995712757809088, 0.09113166030147113, 0.07949299615575, 0.11019193480024114, 0.11778477346524596, 0.14518431649776176, 0.29074205202050507, 0.13460753951221704, 0.17199236783199012, 0.11208516094484366, 0.19118087802780792, 0.15652679692720994, 0.15400889766169712, 0.8007133996579796, 15.267337560653687, 75.03122225403786, 72.32661098241806, 60.567503571510315, 42.907643392682076, 70.73185175657272, 83.25626090168953, 28.0441215634346, 1.1063392530195415, 0.9500748349819332, 0.11341863704728894, 2.9781621554866433, 2.3929626820608974, 0.10476361436303705, 0.45420936949085444, 0.25674676056951284, 18.56138840317726, 62.237529158592224, 76.35533720254898, 77.75355577468872, 71.34421929717064, 68.52206513285637, 73.9432418346405, 72.89280340075493, 67.66477033495903, 70.78704759478569, 73.09204190969467, 73.33592042326927, 77.22323343157768, 74.63067814707756, 73.29264834523201, 63.67048166692257, 59.54771429300308, 58.2393267005682, 59.854604825377464, 61.77377164363861, 65.01708760857582, 68.40026646852493, 68.16502869129181, 70.96523523330688, 71.83615610003471, 75.57251840829849, 74.71001029014587, 71.3977812230587, 69.50590074062347, 76.05243265628815, 70.92037484049797, 74.92190212011337, 72.92798951268196, 74.27893102169037, 37.41133712232113, 37.77706749737263, 72.42446333169937, 79.88984674215317, 77.41222009062767, 74.94427531957626, 67.45821341872215, 65.27994990348816, 66.63273051381111, 66.764697432518, 62.57104866206646, 57.413653805851936, 56.414771005511284, 57.15514227747917, 57.36931398510933, 60.56292861700058, 58.49115438759327, 60.86724288761616, 63.96971940994263, 65.51536247134209, 65.97597375512123, 64.50283080339432, 64.28952544927597, 64.05684873461723, 64.37274858355522, 65.53548619151115, 64.3804469704628, 69.10437628626823, 71.15084007382393, 71.3420458137989, 66.72237530350685, 70.8136385679245, 71.03783413767815, 67.04986453056335, 70.78519329428673, 66.0899068415165, 42.916664108633995, 14.572464097291231, 1.3119753124192357, 0.8831409516278654, 0.2722174226073548, 8.272021226584911, 12.904702238738537, 1.8815462244674563, 5.518682794645429, 1.7283674189820886, 0.27313611237332225, 1.8409058614633977, 46.17872826755047, 68.58957231044769, 37.62773551046848, 32.88103021681309, 44.537649527192116, 60.426261350512505, 51.50595881044865, 7.1637375466525555, 0.14537674054736272, 0.2452722075395286, 0.19396832532947883, 0.09494775396888144, 0.0915877619991079, 0.056583873301860876, 0.09919951800839044, 0.10184459169977345, 0.1054843065503519, 0.10186241066548973, 0.11995923647191375, 0.15699034236604348, 0.1272049726685509, 0.0988466787384823, 0.2627367532113567, 0.10040011256933212, 0.11055019174818881, 0.08307630036142655, 0.12134490039898083, 0.1348809021874331, 0.21902811422478408, 0.1773329812567681, 0.22773178468924016, 0.08557914887205698, 0.13713502732571214, 0.15038098295917735, 0.14827326871454716, 0.2081502479268238, 0.16595085529843345, 0.17616159020690247, 0.14727315050549805], [0.020849796637776308, 0.042372220268589444, 0.024931467851274647, 0.06422033911803737, 0.005051965290476801, 0.10689829825423658, 0.030823424640402663, 0.04290908618713729, 0.011541492895048577, 0.02533422397391405, 0.08870307850884274, 0.070089673390612, 0.03914159948180895, 0.06925469046109356, 0.09117244873777963, 0.0393667374009965, 0.04210138831695076, 0.07506829686462879, 0.04686657011916395, 0.048609567020321265, 0.04957170953275636, 0.01228436138262623, 0.06522070223581977, 0.04235731794324238, 0.0774243485648185, 0.05090964594273828, 0.05388453748309985, 0.012990474078833358, 0.08451297951978631, 0.011382134307496017, 0.010023367667599814, 0.021993982409185264, 0.06489172301371582, 0.041701749214553274, 0.006211887375684455, 0.04506200464675203, 0.02898340862884652, 0.0767179649847094, 0.03882286560838111, 0.10489280743058771, 5.547890877351165, 41.85530886054039, 58.64807836711407, 36.59599207341671, 24.110984914004803, 44.39085200428963, 71.99080020189285, 37.36757107079029, 2.0301092276349664, 0.19809466641163453, 0.15792703663464636, 0.49922534613870084, 0.34258599509485066, 0.3097806335426867, 0.2733641298254952, 0.4630296165123582, 1.0970784374512732, 25.964907333254814, 61.79316580295563, 81.37118205428123, 78.75341892242432, 68.50147783756256, 66.12954631447792, 73.79682809114456, 73.1339080631733, 73.63146856427193, 74.1463865339756, 70.94156250357628, 66.27791315317154, 58.6790619045496, 59.35134842991829, 58.12920480966568, 58.170318603515625, 58.984960690140724, 63.83858844637871, 68.4997147321701, 67.98063978552818, 73.17263558506966, 72.21641689538956, 70.20159021019936, 73.74299257993698, 70.75870111584663, 68.88498365879059, 68.47386091947556, 69.13817167282104, 68.09660956263542, 64.10739362239838, 70.63833117485046, 54.12094809114933, 28.475387021899223, 33.95773284137249, 68.43989074230194, 71.48703843355179, 66.66409403085709, 62.09312930703163, 63.00658129155636, 58.11707206070423, 56.79179057478905, 57.14884601533413, 53.37267704308033, 52.92549043893814, 51.67860634624958, 54.66898128390312, 51.98238104581833, 53.77482086420059, 52.03238256275654, 54.6788265556097, 58.29619064927101, 61.83276727795601, 63.062119111418724, 63.461105301976204, 63.38485859334469, 61.2912355363369, 59.10061128437519, 57.45181895792484, 61.30330368876457, 67.68414169549942, 63.82768303155899, 66.54575318098068, 73.69534313678741, 67.90549501776695, 66.03585854172707, 71.79651662707329, 48.91672074794769, 15.206449627876282, 1.3799588894471526, 0.3516404936090112, 0.8587025629822165, 0.4254983179271221, 6.053913999348879, 6.054928069934249, 1.0663753724657, 0.7539871882181615, 0.5268800246994942, 0.1021015529113356, 4.651941228657961, 49.720354825258255, 50.8841297775507, 16.094851456582546, 22.222300060093403, 35.22750310599804, 43.92223834991455, 22.290937677025795, 0.49627507163677365, 0.27585139323491603, 0.08677578778588213, 0.022085285127104726, 0.046628359268652275, 0.03234181982406881, 0.038200682392925955, 0.046557658570236526, 0.10418380406918004, 0.03776088196900673, 0.020143025285506155, 0.030189181525202002, 0.023971484988578595, 0.007795538676873548, 0.024035016540437937, 0.042240444527124055, 0.028590213223651517, 0.054375787294702604, 0.04454729183635209, 0.021736822673119605, 0.05581592115049716, 0.038583341156481765, 0.014329170262499247, 0.044364894201862626, 0.031183453465928324, 0.04674784133385401, 0.03544904742739163, 0.007368188244072371, 0.010125066019099904, 0.035948130607721396, 0.06855042942333966, 0.13050899928202853, 0.01795250405848492, 0.06286447242018767, 0.035229011773481034, 0.020259941375115886, 0.041543052066117525, 0.08423493389273062, 0.07182624700362794, 0.02927762379840715, 0.03041391868464416, 0.04831218102481216, 0.0288409274071455, 0.03818546094407793, 0.01719034251436824, 0.027237884714850225, 0.07032555018668063, 0.07409498502966017, 0.03601356205763295, 0.013971627631690353, 0.08026534924283624, 0.036149883453617804, 0.08706134394742548, 0.0077629676707147155, 0.024744134934735484, 0.04966848558979109, 0.06522013078210875, 0.018356224973103963, 0.0139165528526064, 0.04560042165394407, 0.036532371523207985, 0.04797003981366288, 0.132238722871989, 0.03667597709863912, 0.04065931003424339, 0.09778581574209966, 0.037097839813213795, 0.03155268306727521, 0.0742487728712149, 0.03362048460985534, 0.03558962504030205, 0.10730836453149095, 0.11503303088829853, 13.185158539563417, 56.86544582247734, 64.77109640836716, 30.955686829984188, 26.773486845195293, 65.96056938171387, 90.2524682879448, 29.131311625242233, 1.011223706882447, 0.16241649573203176, 0.17480590904597193, 0.6266409403178841, 0.30449609679635614, 1.1103463754989207, 0.5231301602907479, 0.6174837879370898, 3.378189252689481, 34.89280566573143, 72.85207718610764, 83.23542281985283, 74.01492118835449, 66.82345747947693, 68.68457481265068, 73.0379556119442, 72.88192838430405, 74.22314241528511, 76.53576672077179, 71.68085843324661, 68.75263676047325, 62.75929816067219, 61.648104786872864, 59.99038673937321, 60.08668877184391, 61.342897564172745, 65.45650362968445, 69.43295985460281, 70.40324538946152, 73.54118540883064, 72.15734526515007, 72.72088542580605, 73.82275030016899, 72.59619131684303, 70.3395228087902, 68.63688737154007, 70.02106189727783, 68.73310580849648, 67.57369682192802, 73.18921029567719, 61.18213579058647, 25.60268796980381, 36.591341122984886, 70.2910678088665, 72.17433035373688, 70.11860266327858, 64.53161805868149, 65.73727056384087, 60.77374130487442, 60.69559469819069, 60.12752138078213, 55.59887118637562, 52.71736800670624, 52.24370442330837, 56.020545959472656, 53.65488789975643, 55.62027923762798, 53.90967182815075, 57.20029145479202, 60.825152546167374, 65.72423726320267, 65.47098845243454, 65.82199081778526, 64.38626065850258, 63.575026988983154, 59.57098804414272, 60.26698909699917, 62.668304443359375, 67.9896529018879, 69.38268855214119, 69.55666601657867, 73.94078716635704, 71.21051967144012, 65.73383554816246, 71.31972581148148, 55.19372932612896, 21.125348322093487, 2.8767363354563713, 0.7098149741068482, 2.722717300057411, 1.5713774180039763, 4.82658508233726, 6.809533378109336, 2.0522955246269703, 0.7432869030162692, 0.32886736560612917, 0.25181067700032145, 3.0022956104949117, 49.66960854828358, 75.22523984313011, 31.16222284734249, 17.970552407205105, 33.805003836750984, 52.51495286822319, 32.16667614877224, 2.5675925239920616, 0.1920612432877533, 0.11611067384365015, 0.0180127516068751, 0.0592734276142437, 0.01573676836414961, 0.06003037742630113, 0.05414422608737368, 0.11738249231711961, 0.056621258991071954, 0.026419468376843724, 0.04239239926391747, 0.010344387355871731, 0.026472290737729054, 0.01340125096248812, 0.022475459991255775, 0.03894678571668919, 0.015380208151327679, 0.007605059518027701, 0.02365065269259503, 0.015144882399908965, 0.03231644208426587, 0.010650577078195056, 0.049774378931033425, 0.03120976260106545, 0.035387527095736004, 0.044592596241272986, 0.03568425257981289, 0.09581089398125187, 0.02224385239969706, 0.07832956092897803, 0.07246661654789932, 0.03478305152384564, 0.15709516330389306, 0.15496062784222886, 0.133776675502304, 0.17093701899284497, 0.1946437094011344, 0.17739058675942943, 0.18069704761728644, 0.14869700535200536, 0.14978083781898022, 0.1045832947420422, 0.2018692740239203, 0.11978590046055615, 0.15144825069000944, 0.18879040551837534, 0.3795610985253006, 0.11874197327415459, 0.15392095316201448, 0.13244419387774542, 0.16684220434399322, 0.21418240939965472, 0.14794908376643434, 0.11370032661943696, 0.14982420892920345, 0.14046437601791695, 0.12499352102167904, 0.2726541319862008, 0.24645940633490682, 0.09266254026442766, 0.11709051657817326, 0.24444968526950106, 0.11903855775017291, 0.2460778979002498, 0.16369739809306338, 0.219330494874157, 0.10340367327444255, 0.17488695157226175, 0.13272324140416458, 0.09459790555411018, 0.1462389825610444, 0.17636744712945074, 12.23078465089202, 64.41578507423401, 79.17524188756943, 46.603059098124504, 37.97272279858589, 58.01179111003876, 89.85097423195839, 48.91589619219303, 3.584121814928949, 0.41931115149054676, 0.5807961628306657, 0.6310597469564527, 0.7339110248722136, 1.132491349708289, 0.5022451747208834, 1.0842155339196324, 2.2762146592140198, 30.794892758131027, 67.68181622028351, 80.98211333155632, 77.53553867340088, 67.76839837431908, 67.1768157184124, 72.2146537899971, 73.8918685913086, 78.78858983516693, 81.44603043794632, 77.10776522755623, 72.05835297703743, 63.562027886509895, 63.18334400653839, 63.28784219920635, 63.428537249565125, 66.00529298186302, 70.6152892112732, 75.50784587860107, 74.07676666975021, 79.85320910811424, 75.81590294837952, 76.33344277739525, 80.13706907629967, 77.45622172951698, 72.59845599532127, 71.76228046417236, 72.66217857599258, 72.76703014969826, 67.76170313358307, 71.1613655090332, 57.46136024594307, 35.75694389641285, 41.917002350091934, 70.72829514741898, 75.46093359589577, 70.63395380973816, 67.4145233631134, 67.3502080142498, 62.207335978746414, 61.084028854966164, 62.579089030623436, 57.45228633284569, 58.6701437830925, 55.77493853867054, 59.76220518350601, 55.73951303958893, 57.35302805900574, 55.67765615880489, 61.14444561302662, 63.54551777243614, 68.52893516421318, 69.15524035692215, 69.51395630836487, 69.69309389591217, 66.20767772197723, 62.43167594075203, 61.92061856389046, 64.99414443969727, 71.92572489380836, 69.6584701538086, 72.76477307081223, 75.71387842297554, 68.60683098435402, 64.37282457947731, 72.47333630919456, 51.565254628658295, 17.450996786355972, 1.855394602753222, 0.6155712436884642, 1.116018402390182, 0.8812487125396729, 12.044467348605394, 14.86305920407176, 4.010751284658909, 3.913963590748608, 1.2954489304684103, 0.3299871477065608, 8.408071026206017, 66.17097929120064, 60.76207593083382, 29.742807112634182, 32.87932030856609, 45.99023178219795, 63.57050143182278, 32.61016935110092, 1.773143622558564, 0.32174500403925776, 0.2531055168947205, 0.16592249041423202, 0.1539530881564133, 0.0945761903130915, 0.1443458825815469, 0.08912244389648549, 0.3283273195847869, 0.23585712915519252, 0.10821440810104832, 0.1655547265545465, 0.12862669012974948, 0.12778767733834684, 0.10916163344518282, 0.11559298131032847, 0.159905839827843, 0.12223436438944191, 0.09280006765038706, 0.06395687669282779, 0.10738993398263119, 0.12591667851665989, 0.11404096498154104, 0.11742272414267063, 0.15662188088754192, 0.24515794648323208, 0.11416153429308906, 0.12587041303049773, 0.15223516471451148, 0.07186880917288363, 0.16478565376019105, 0.16618179681245238, 0.1111454312922433], [0.05378989138989709, 0.06448248794185929, 0.03695608589623589, 0.054683808266418055, 0.08312350837513804, 0.09588643719325773, 0.021247086842777207, 0.026698903675423935, 0.02729751813603798, 0.018190952396253124, 0.01270109863980906, 0.03786631888942793, 0.05395837746618781, 0.04553676764771808, 0.00736876387236407, 0.023237025961861946, 0.07851555797969922, 0.04278250919014681, 0.04768129983858671, 0.010530305553402286, 0.024310802327818237, 0.009974453641916625, 0.04328722156060394, 0.10082229069666937, 0.06653505319263786, 0.04605245638231281, 0.020945298056176398, 0.0385776229086332, 0.05232473231444601, 0.09536510071484372, 0.03451364078500774, 0.03680864341731649, 0.05359871043765452, 0.035897568086511455, 0.023454393594875, 0.07711113255936652, 0.05068894606665708, 0.030985496705397964, 0.07750059681711718, 0.03151259967125952, 0.010660142434062436, 2.141650104895234, 22.60374829173088, 60.42693391442299, 50.09525030851364, 32.38870583474636, 32.70664617419243, 59.0316753834486, 57.23908357322216, 8.408109974116087, 0.2583384298486635, 0.29628280783072114, 0.4101020784582943, 2.38064659293741, 12.91656045243144, 4.320376245304942, 0.23350711853709072, 0.5252404126804322, 2.693757154047489, 24.58693217486143, 56.94374822080135, 81.09199583530426, 79.9595957994461, 71.28048151731491, 69.83301758766174, 73.33595082163811, 72.59340986609459, 70.23595556616783, 71.23671546578407, 71.6024762392044, 69.38285574316978, 66.68918028473854, 63.30377474427223, 63.53968508541584, 65.2028900384903, 68.52890476584435, 70.23449644446373, 70.17129063606262, 71.73480033874512, 72.5007252395153, 71.72585561871529, 73.14485147595406, 71.46284893155098, 73.86884182691574, 73.78205448389053, 72.28588476777077, 58.18672992289066, 71.42362743616104, 34.174526408314705, 64.65191960334778, 46.98859021067619, 60.29193475842476, 76.79773226380348, 71.06185644865036, 71.86844676733017, 67.45483919978142, 66.84244126081467, 60.80914780497551, 59.17139768600464, 57.77996934950352, 57.11465924978256, 59.85802084207535, 59.021894708275795, 59.1621033847332, 59.920968264341354, 56.691749542951584, 53.05886708199978, 55.237742364406586, 55.86146369576454, 58.82516026496887, 60.28844654560089, 60.30865006148815, 61.740341037511826, 62.30231948196888, 68.39199811220169, 65.77206909656525, 69.96749237179756, 73.24231624603271, 72.99399957060814, 67.53879189491272, 75.313980281353, 64.1796125471592, 25.07106989622116, 2.9429511073976755, 0.0704905296151992, 0.309551369282417, 0.19692700094310567, 2.105332841165364, 4.851724058389664, 0.22390187223209068, 2.3514335229992867, 0.30751123500522226, 0.10190042346948758, 0.06450411412515678, 13.677674811333418, 58.219172582030296, 38.29274162650108, 14.205493088811636, 23.264529034495354, 39.637504667043686, 38.25576201081276, 8.136081621050835, 0.03196172518073581, 0.07953891283250414, 0.06399030302418396, 0.052558271345333196, 0.0847516319481656, 0.02558050753577845, 0.03979851520853117, 0.03356837100000121, 0.08947660418925807, 0.037554609443759546, 0.06364420987665653, 0.039701034111203626, 0.01733792043523863, 0.009811667259782553, 0.04144544480368495, 0.023626317670277786, 0.06343918415950611, 0.03369117417605594, 0.014449783175223274, 0.04407496307976544, 0.045684455035370775, 0.00785803864346235, 0.05921679432503879, 0.03829778128420003, 0.014002536227053497, 0.03182764135999605, 0.012438057383405976, 0.08104103457299061, 0.03542276426742319, 0.024902887744246982, 0.02224262228992302, 0.018025047138507944, 0.038748635997762904, 0.015735972410766408, 0.030877696044626646, 0.038053974640206434, 0.018493397983547766, 0.03634402928582858, 0.08316578852827661, 0.03278993601270486, 0.05406185511674266, 0.03820077887212392, 0.04329049072111957, 0.03654343694506679, 0.028090415726182982, 0.01771727293089498, 0.09180955283227377, 0.04193252003460657, 0.029868080200685654, 0.012303807507123565, 0.06321898152236827, 0.023716778050584253, 0.010073693629237823, 0.028063152931281365, 0.010082568787765922, 0.033693285586196, 0.09353716130135581, 0.06142527738120407, 0.07486113376216963, 0.029222916382423136, 0.04389544126752298, 0.06465787228080444, 0.05207265814533457, 0.02718563195230672, 0.01786154829460429, 0.03941284703614656, 0.05401593843998853, 0.042981456717825495, 0.044465674145612866, 0.05921748081163969, 0.02889561070333002, 0.014374265938386088, 0.04501463336055167, 0.030569858754461166, 0.0761688499187585, 5.522756176069379, 36.90107770264149, 67.69159689545631, 40.30647777020931, 26.07968207448721, 47.98642806708813, 88.26674044132233, 55.61481133103371, 3.9534149738028646, 0.05358144066121895, 0.20586673374054953, 0.2901088516227901, 3.648345968686044, 14.819388147443533, 6.134508149698377, 0.2931954141240567, 0.44304604351054877, 5.642069773748517, 34.21164281666279, 67.79853075742722, 80.77630877494812, 76.60479381680489, 70.35741984844208, 71.55045703053474, 74.87847045063972, 75.2260833978653, 74.43232879042625, 73.29042926430702, 70.91177210211754, 68.44704955816269, 66.21156871318817, 62.79211699962616, 63.44020262360573, 65.91426506638527, 68.66833448410034, 70.85627987980843, 71.07340782880783, 74.08502742648125, 72.3063276708126, 74.82392057776451, 77.55384609103203, 73.59939068555832, 75.59562116861343, 75.4689359664917, 73.8089570403099, 60.32790742814541, 68.52253630757332, 42.763638719916344, 59.16122563183308, 45.710562989115715, 64.57385659217834, 76.6619123518467, 72.62655168771744, 72.73758172988892, 68.18927139043808, 68.53135943412781, 61.1783891916275, 61.708080768585205, 59.45135906338692, 58.374751433730125, 59.79580298066139, 61.12348593771458, 59.497465789318085, 61.6476222127676, 58.940343484282494, 54.75928343832493, 57.74971157312393, 57.802999913692474, 61.31588861346245, 63.49998101592064, 63.145042061805725, 63.405324295163155, 62.592620104551315, 69.48743373155594, 67.8112904727459, 72.19028949737549, 72.93633386492729, 73.55000093579292, 68.35408374667168, 72.05924212932587, 69.32851105928421, 33.21862310171127, 4.292309051379561, 0.4148452926892787, 1.339444275945425, 2.79790457803756, 8.39865418151021, 7.42857763543725, 5.232244189828634, 0.5696560512296855, 0.5606300511863083, 0.38388989749364555, 0.12512538582086563, 10.54538318887353, 61.32183149456978, 59.99594584107399, 20.96164170652628, 15.546913258731365, 39.973763823509216, 47.93612636625767, 15.737177599221468, 0.38136196439154446, 0.1625370205147192, 0.05252812530670781, 0.0556110587058356, 0.07284390216227621, 0.06695757270790637, 0.03584732097806409, 0.03518492820148822, 0.03752724645892158, 0.01007105622193194, 0.05763463195762597, 0.010122838648385368, 0.03645675038569607, 0.030151909013511613, 0.06473690358689055, 0.03198846105078701, 0.050556450441945344, 0.0004892661320354819, 0.036322147061582655, 0.03270616980444174, 0.010530057861615205, 0.0036656002657764475, 0.06769195751985535, 0.04805288575880695, 0.061007051190244965, 0.02776198754872894, 0.02169901767047122, 0.02245557785499841, 0.08104311258648522, 0.08209295468986966, 0.0201623804969131, 0.003365288121131016, 0.025749813685251866, 0.060659162045340054, 0.16388562158681452, 0.18267243693117052, 0.14092539815464988, 0.15145114506594837, 0.167395549651701, 0.18141859327442944, 0.12301401278818958, 0.14976844395278022, 0.139919298235327, 0.15518552827415988, 0.16283251403365284, 0.09790946496650577, 0.16913020110223442, 0.09594094794010743, 0.13095267000608146, 0.16165208362508565, 0.18822713027475402, 0.1449794985819608, 0.11788218776928261, 0.057293396166642196, 0.15608659945428371, 0.09951792162610218, 0.13919104356318712, 0.18345745105762035, 0.27153135160915554, 0.19736151356482878, 0.11234682737267576, 0.1330515230074525, 0.09783848596271127, 0.2090916919405572, 0.12946828559506685, 0.1087546099734027, 0.10335934479371645, 0.15904972795397043, 0.20716308761620894, 0.2562593179754913, 0.16763029096182436, 0.07530324597610161, 0.1373826077906415, 0.11633343689027242, 0.16620225040242076, 4.449709905311465, 43.07258114218712, 84.41702261567116, 61.92622326314449, 46.694094613194466, 47.945162281394005, 75.95735415816307, 69.3030296266079, 11.63059925660491, 0.581005389103666, 0.7606509618926793, 1.5831490675918758, 4.123109830543399, 17.781598046422005, 7.306674476712942, 0.2382453010068275, 0.6922346237115562, 4.384407559409738, 31.096949949860573, 61.072599068284035, 80.3775429725647, 79.18804720044136, 70.25296345353127, 69.64761793613434, 74.32173952460289, 77.11066827178001, 76.44068822264671, 78.02541598677635, 77.07422822713852, 76.9325490295887, 73.42385530471802, 68.71896296739578, 69.43999707698822, 70.52472487092018, 70.84481969475746, 73.51137980818748, 73.95125940442085, 75.48918128013611, 74.53690677881241, 75.94784706830978, 80.45886620879173, 77.76813939213753, 78.38411673903465, 79.39370736479759, 75.53306132555008, 64.8550795018673, 73.62798035144806, 49.081837087869644, 71.19876310229301, 58.36123175919056, 65.87202653288841, 77.8532700240612, 77.64145419001579, 78.03957402706146, 73.5159319639206, 74.73663166165352, 66.57350689172745, 65.03552421927452, 64.0077705681324, 62.8984846919775, 66.88229352235794, 65.80159351229668, 63.51825423538685, 65.28261736035347, 63.389623537659645, 57.221448719501495, 59.87296164035797, 59.37697425484657, 62.032917737960815, 65.64534589648247, 64.12421151995659, 68.33346605300903, 68.51621344685555, 74.79956388473511, 71.01663887500763, 73.32379147410393, 76.3288602232933, 74.82674762606621, 67.46151924133301, 72.50378787517548, 68.9560854434967, 27.64603592455387, 3.7998250778764486, 0.22247901186347008, 0.5693156726192683, 1.3405584474094212, 4.424204248934984, 12.635216899216175, 13.37837627157569, 5.322006298229098, 3.1939179031178355, 0.7718942617066205, 0.35832391935400665, 19.571100622415543, 68.87471660971642, 48.87209974229336, 27.29596070945263, 33.16710166633129, 52.97729305922985, 58.56135942041874, 14.848653227090836, 0.2716785640222952, 0.3424804616952315, 0.18386803683824837, 0.10647822782630101, 0.19715026865014806, 0.13250562886241823, 0.1485947225592099, 0.13293717289343476, 0.14704673609230667, 0.13225933973444626, 0.23961067461641505, 0.07448033036780544, 0.09289817215176299, 0.15574439516058192, 0.1762266765581444, 0.1487474565510638, 0.18017056805547327, 0.09450443205423653, 0.13718044676352292, 0.1590191514696926, 0.1511003912310116, 0.08212906017433852, 0.19378099241293967, 0.08549346050131135, 0.14858848851872608, 0.10830499464645982, 0.2780198003165424, 0.21046983049018309, 0.1366623683134094, 0.15349730558227748, 0.13363258010940626, 0.13752861792454496, 0.15411069063702598, 0.09416109969606623], [0.010210926011495758, 0.03865142207359895, 0.036965180916013196, 0.06538315094076097, 0.05036033420765307, 0.018506218584661838, 0.05457866078359075, 0.10439473728183657, 0.08559057794627734, 0.05913046399655286, 0.034956224262714386, 0.045036994270049036, 0.02102120120980544, 0.022783432723372243, 0.02608892878924962, 0.038703880782122724, 0.03905845296685584, 0.038621955100097694, 0.016527914485777728, 0.05206173002079595, 0.02048171365458984, 0.029291173559613526, 0.04026590126159135, 0.03450486117799301, 0.04161960088822525, 0.05839485093019903, 0.042893805366475135, 0.018003200166276656, 0.037810208814335056, 0.053606822111760266, 0.061757128714816645, 0.015557593505945988, 0.05695510299119633, 0.02719091047765687, 0.05405202537076548, 0.13470664591295645, 0.05574196242378093, 0.04036881116917357, 0.16337100154487416, 0.0727175737847574, 0.10276630200678483, 0.07627384897205047, 0.08267732177046128, 21.177004650235176, 58.481761291623116, 57.928476780653, 37.240851670503616, 27.871291637420654, 43.88701803982258, 64.72367495298386, 25.28866332024336, 1.0498544527217746, 0.30833828437607735, 1.5594926057383418, 2.032688814215362, 12.573112081736326, 8.405319973826408, 1.1181142274290323, 0.36800864967517555, 0.165898147970438, 1.9769287062808871, 17.108705453574657, 56.21799856424332, 77.51304388046265, 73.75756099820137, 77.37166866660118, 75.66901803016663, 75.04407316446304, 65.6951992213726, 69.51650977134705, 70.7302026450634, 71.13140031695366, 72.22701832652092, 71.3269454240799, 70.94896450638771, 76.64617359638214, 77.06231966614723, 77.01671451330185, 77.31075793504715, 73.61074447631836, 71.90450683236122, 70.70060983300209, 70.16185194253922, 67.30602398514748, 70.98283588886261, 60.59782974421978, 66.06849879026413, 66.3908126950264, 33.30083169043064, 42.457223162055016, 59.59844917058945, 51.67436957359314, 71.43761828541756, 70.18157288432121, 68.09366852045059, 66.23490706086159, 59.363374784588814, 57.952252104878426, 53.748419880867004, 58.477395325899124, 61.725445836782455, 63.88131335377693, 61.37935280799866, 68.99897754192352, 70.66901072859764, 71.82762935757637, 65.24925515055656, 64.38881412148476, 66.16205736994743, 66.314497590065, 71.08758106827736, 69.89212721586227, 68.39043259620667, 67.18328297138214, 66.93888768553734, 71.23660147190094, 72.21368104219437, 64.73495274782181, 76.81091755628586, 83.99231940507889, 39.857843443751335, 5.464263064786792, 0.1536574462079443, 0.2607788488967344, 0.6108333135489374, 1.6084392042830586, 4.159827260300517, 17.925173342227936, 3.811522275209427, 3.673681584186852, 0.39563052530866116, 0.19208717392757535, 0.6607246364001185, 27.535898834466934, 59.6412006765604, 36.208800449967384, 21.00561674684286, 39.97695565223694, 48.77584330737591, 36.2323933839798, 5.883073741570115, 0.09218234845320694, 0.058357105299364775, 0.03172415999870282, 0.0626919898786582, 0.061870647623436525, 0.03489772447210271, 0.028612473943212535, 0.04476167603570502, 0.04595885671733413, 0.1068480548565276, 0.059322661691112444, 0.09185054906993173, 0.07372797073912807, 0.024117894026858266, 0.03303819183201995, 0.08931920950999483, 0.018985454880748875, 0.013685009271284798, 0.05409056138887536, 0.04666400091082323, 0.06338182356557809, 0.02543790942581836, 0.08617215455160476, 0.01638602883758722, 0.08505044286721386, 0.0505103370960569, 0.10757023133919574, 0.042567457057884894, 0.02744710727711208, 0.06338063612929545, 0.05224924476351589, 0.09211987446178682, 0.04052818738273345, 0.052869457576889545, 0.03518792276736349, 0.05815777556563262, 0.07752406352665275, 0.11756943931686692, 0.07236140227178112, 0.03710136501467787, 0.016356728847313207, 0.022466403934231494, 0.034354939925833605, 0.018878374103223905, 0.031666699214838445, 0.03491489034786355, 0.07920318748801947, 0.06712880844133906, 0.027514384819369297, 0.02242865644802805, 0.024253571609733626, 0.12250579748069867, 0.013130675979482476, 0.030637036106782034, 0.01569167732668575, 0.05200826570217032, 0.024163760608644225, 0.04613028169842437, 0.017408574749424588, 0.08861033973516896, 0.01608862614375539, 0.045331667715799995, 0.026621234210324474, 0.0350399459421169, 0.06498365284642205, 0.03194058510416653, 0.032107564620673656, 0.09618509968277067, 0.03416186649701558, 0.07450626842910424, 0.037055567081552, 0.05845259744091891, 0.03406471194466576, 0.1636234950274229, 0.061439663913915865, 0.07390664279228076, 0.06870889279525727, 1.3558533391915262, 32.143630385398865, 67.44312062859535, 54.76747579872608, 30.2572900056839, 34.49794985353947, 72.08340883255005, 78.2337436079979, 16.446687877178192, 0.5779481562785804, 0.2276546458597295, 1.5973327565006912, 2.629176056943834, 14.867322575300932, 11.585701815783978, 3.380094850435853, 0.34241892280988395, 0.04047954331326764, 4.289107248187065, 26.314775459468365, 66.85450941324234, 79.49346721172333, 71.25084310770035, 77.33020529150963, 78.66196542978287, 74.21931222081184, 67.6168093085289, 72.41067007184029, 73.75881493091583, 76.30075693130493, 73.99122565984726, 75.59497520327568, 74.30549919605255, 78.97848084568977, 76.69627770781517, 78.50733652710915, 77.2030945122242, 76.75420179963112, 72.06987395882607, 73.01442727446556, 70.57691887021065, 68.52116838097572, 67.7865917980671, 65.06828606128693, 63.159903064370155, 73.51128101348877, 39.17099229991436, 52.9790523648262, 57.421268597245216, 55.640448555350304, 76.38192057609558, 71.40020549297333, 72.47459784150124, 68.9863470196724, 64.00926768779755, 61.05053745210171, 57.333113327622414, 58.34550820291042, 62.92813450098038, 63.071356415748596, 62.47022107243538, 69.69549536705017, 70.44106096029282, 71.61778181791306, 65.36494374275208, 64.79993686079979, 66.28000304102898, 66.9536004960537, 70.27827009558678, 68.95399555563927, 69.17613923549652, 69.96094912290573, 69.54712852835655, 72.03910320997238, 72.37787023186684, 69.42906126379967, 74.21210020780563, 81.31284758448601, 50.03805197775364, 10.176253896206617, 1.0118583915755153, 1.77467149682343, 3.450329569168389, 5.929038925096393, 5.886181499809027, 4.396433439105749, 3.6006540153175592, 0.5388912989292294, 0.47809497686102986, 0.04838634755287785, 0.2526943967677653, 22.353930696845055, 68.50856825709343, 52.03328691422939, 19.678547456860542, 27.76804357767105, 49.24389459192753, 44.84897442162037, 10.46415874734521, 0.05810839676996693, 0.1217126939445734, 0.06760322634363547, 0.04966015869285911, 0.03950433529098518, 0.031759961202624254, 0.08752628462389112, 0.06418928023776971, 0.028628873551497236, 0.0973752596473787, 0.1154123128799256, 0.07322299119550735, 0.07254503187141381, 0.01118842819778365, 0.033233220819965936, 0.08237618050770834, 0.058739522864925675, 0.017630946313147433, 0.04140330936934333, 0.09654029898229055, 0.07378885653452016, 0.013010211496293778, 0.03292860259534791, 0.02633326792420121, 0.032471298618474975, 0.024750791999395005, 0.03176324149535503, 0.048117441474460065, 0.07814510012394749, 0.10413333802716807, 0.055348279056488536, 0.009262713610951323, 0.0879718923533801, 0.03692499361932278, 0.13046479696640745, 0.1718319155042991, 0.12336674815742299, 0.16369984718039632, 0.1350203962647356, 0.12489509739680216, 0.17773694708012044, 0.15859854669542983, 0.15667163446778432, 0.14511642482830212, 0.1400773014756851, 0.09194497994030826, 0.2030457858927548, 0.15932856767904013, 0.15036625874927267, 0.08834417589241639, 0.10163485334487632, 0.1949962740764022, 0.10847882047528401, 0.14221833815099671, 0.1982833945658058, 0.177564590703696, 0.1294187398161739, 0.10967454654746689, 0.15252525539835915, 0.20551056222757325, 0.1360969408415258, 0.12385905181872658, 0.09267578017897904, 0.2323342877207324, 0.10619200373184867, 0.11247548609389924, 0.16071547841420397, 0.20901896146824583, 0.08782968943705782, 0.20141392189543694, 0.2703647845191881, 0.1494587754132226, 0.15364710066933185, 0.2596034057205543, 0.1815646479371935, 0.13561323867179453, 0.2747738244943321, 1.0922738327644765, 33.49680237472057, 80.20190119743347, 75.2642485499382, 49.142652824521065, 42.22024127840996, 61.37108065187931, 81.2635338306427, 33.09961348772049, 2.0228433050215244, 0.6482854101341218, 3.722851420752704, 7.789975767955184, 18.28876443207264, 12.945262212306261, 2.2905778884887695, 0.6970939098391682, 0.3904461191268638, 3.5797337628901005, 21.603385470807552, 61.852332428097725, 79.01170626282692, 74.97156545519829, 79.57719191908836, 81.93692609667778, 78.1708873808384, 71.50181964039803, 73.70904520154, 76.0607086122036, 76.44622072577477, 75.97693830728531, 77.64091461896896, 78.69978860020638, 84.22614365816116, 80.08027732372284, 83.00561115145683, 81.71909138560295, 77.35795140266418, 72.03857123851776, 73.20630177855492, 71.67160972952843, 69.85489681363106, 69.70981299877167, 65.16870707273483, 71.42269268631935, 69.9209600687027, 46.2142563611269, 50.24196423590183, 64.81604039669037, 60.55700473487377, 73.78191009163857, 73.99424269795418, 71.45515814423561, 70.18128409981728, 64.71969276666641, 62.53668710589409, 59.63692970573902, 62.533871456980705, 65.53294032812119, 67.59678438305855, 66.85251072049141, 73.95328089594841, 75.97534239292145, 77.53740057349205, 71.09900325536728, 70.50850734114647, 72.83092752099037, 72.4778200685978, 77.75734797120094, 75.18579035997391, 71.88985481858253, 71.82936206459999, 71.89759880304337, 77.10270389914513, 78.35955485701561, 68.72160002589226, 75.95859289169312, 83.4586152434349, 42.98849165439606, 7.098144041374326, 0.4479915671981871, 0.5293265590444207, 1.5849508834071457, 4.799753772094846, 12.21895208582282, 35.634324476122856, 16.713188476860523, 5.416620746254921, 2.672127764672041, 0.5363453167956322, 1.6178351501002908, 37.98906572163105, 70.63937991857529, 48.40553417801857, 34.81049068272114, 49.51103165745735, 63.82573753595352, 51.10205188393593, 9.966717939823866, 0.19090272107860073, 0.221787627087906, 0.14595430955523625, 0.1487679101410322, 0.11022147969924845, 0.1766441939980723, 0.186288729601074, 0.2614993852330372, 0.1783442316809669, 0.252134965849109, 0.30659566225949675, 0.157587741559837, 0.16300135263008997, 0.09291429902077653, 0.14204348815837875, 0.23674873053096235, 0.16863616823684424, 0.08080278290435672, 0.16016983659937978, 0.22842652397230268, 0.16777446056948975, 0.10469689528690651, 0.22721949499100447, 0.20016941445646808, 0.15062458551255986, 0.16153170727193356, 0.1449555717408657, 0.12857853958848864, 0.16514654533239082, 0.21669107634807006, 0.12127145746489987, 0.2303381628007628, 0.2008458078489639, 0.16381162946345285, 0.32294716453179717], [0.018568147097539622, 0.018893140986619983, 0.029563053794845473, 0.07595422823214903, 0.03670576319564134, 0.07841829952667467, 0.04935367025609594, 0.07728313270490617, 0.060502839769469574, 0.02347236284549581, 0.04668662528274581, 0.04511640036071185, 0.001691304923951975, 0.05503079570189584, 0.036127370403846726, 0.05428544194728602, 0.08458700132905506, 0.01900434810522711, 0.025010313620441593, 0.052602978321374394, 0.054763392472523265, 0.03244796178478282, 0.10205338752712123, 0.021559282395173796, 0.033757559285731986, 0.08055104641243815, 0.08042252127779648, 0.037190563743934035, 0.09890169414575212, 0.041032769877347164, 0.04856805499002803, 0.015018639369372977, 0.006449215070460923, 0.07104126998456195, 0.03713523663464002, 0.055073695548344404, 0.03450116157182492, 0.047921941222739406, 0.06273634062381461, 0.08101141545921564, 0.04750646839966066, 0.14514585840515792, 0.12022227587294765, 0.18282368662767112, 14.231862723827362, 49.936012253165245, 59.12872217595577, 43.83749529719353, 38.56815464794636, 37.76602528989315, 63.24371136724949, 55.405085384845734, 10.621629897505045, 0.7001185475382954, 0.09968467478756793, 2.9734290344640613, 4.770391322672367, 1.4725479274056852, 0.7520526763983071, 0.2937335008755326, 0.48117955040652305, 0.1710841423482634, 3.123449021950364, 30.482893399894238, 64.73230808973312, 80.53651124238968, 73.83393689990044, 71.02653354406357, 77.9728876054287, 81.71230494976044, 82.41028189659119, 75.42890891432762, 74.87986877560616, 72.53704369068146, 69.76785108447075, 71.52264252305031, 75.72932079434395, 71.29983767867088, 73.43802094459534, 66.90250843763351, 74.37944322824478, 72.65194192528725, 75.38081869482994, 69.66708809137344, 79.95756670832634, 53.00606891512871, 87.16114416718483, 51.64481095969677, 41.12313374876976, 33.19430820643902, 63.80268037319183, 64.2898066341877, 62.26618342101574, 82.19579860568047, 72.31621474027634, 77.31455013155937, 67.84751012921333, 69.40443858504295, 63.45206178724766, 70.31091034412384, 71.30676850676537, 74.09537047147751, 72.35157564282417, 76.18668705224991, 75.28221398591995, 74.49258595705032, 69.9093022942543, 69.08897951245308, 70.21631062030792, 70.20482003688812, 66.39530405402184, 68.68692308664322, 71.34954661130905, 76.11737117171288, 78.39481696486473, 70.07750406861305, 72.44427546858788, 90.18615424633026, 76.55749395489693, 28.837802074849606, 0.9460787556599826, 0.155796033795923, 0.5400855035986751, 0.976780989440158, 2.1496743243187666, 9.631039202213287, 5.623175287619233, 8.804986327886581, 4.4041835982352495, 0.12345520473900251, 0.06026589428074658, 7.140745930373669, 50.92912316322327, 51.097898706793785, 30.890640020370483, 27.180975079536438, 39.45156164467335, 43.98130998015404, 21.428237669169903, 2.1182492980733514, 0.09906084029353224, 0.06649206799920648, 0.017769405094441026, 0.012125514876970556, 0.02681774192751618, 0.03391483893210534, 0.032166891905944794, 0.04944929969497025, 0.07152155827498063, 0.045508347102440894, 0.047404508441104554, 0.010775929531519068, 0.013255010762804886, 0.042129530556849204, 0.09304108010837808, 0.05116033229569439, 0.07070584149914794, 0.08653467142721638, 0.07545583153842017, 0.037456627396750264, 0.011906640684173908, 0.06467572835390456, 0.049271143434452824, 0.03533474555297289, 0.02076938864775002, 0.005828940102219349, 0.010104335051437374, 0.02428801653877599, 0.040158813062589616, 0.025249043974326923, 0.013924352824687958, 0.06214439621544443, 0.03168824747262988, 0.056132254176191054, 0.02462022595864255, 0.11218238229048438, 0.024808868765830994, 0.03371968006831594, 0.07103153300704435, 0.038242821538005956, 0.022639700982836075, 0.03113439008302521, 0.012682382603088627, 0.03179750645358581, 0.01138450175858452, 0.05188470553548541, 0.07007156498730183, 0.02994498525367817, 0.07817854871973395, 0.044928926436114125, 0.06941341358469799, 0.12812940665753558, 0.07553826188086532, 0.025433463961235248, 0.02990304277773248, 0.027440476187621243, 0.07278677163412794, 0.045744598683086224, 0.021806298827868886, 0.06142772275779862, 0.017486548495071474, 0.04162211676884908, 0.09362585537019186, 0.06482923417934217, 0.043259019948891364, 0.05738052059314214, 0.03847784115350805, 0.03277672207332216, 0.015992851986084133, 0.04803845840797294, 0.018038960552075878, 0.025150390283670276, 0.008401470713579329, 0.01167227879705024, 0.03025175570655847, 0.021725723854615353, 0.10378626524470747, 0.04101472826732788, 0.10104885353939608, 0.4363824479514733, 21.626609824597836, 64.57190349698067, 60.59040114283562, 35.689341723918915, 31.153447218239307, 56.8671253323555, 87.71314054727554, 58.25225740671158, 5.038111656904221, 0.6211901328060776, 0.23648513451917097, 2.5210818322375417, 4.797983067110181, 4.859404871240258, 2.444657958112657, 1.1223616870120168, 0.7657965982798487, 0.12802375451428816, 6.349983187392354, 39.39027093350887, 70.83924919366837, 80.12342780828476, 78.04623126983643, 75.0989194214344, 80.26167199015617, 82.52179071307182, 80.48620954155922, 76.85915976762772, 75.46076640486717, 71.24348670244217, 72.17515870928764, 72.82682374119759, 77.35285967588425, 75.43749645352364, 73.931325674057, 69.24790978431702, 72.5335630774498, 71.82637542486191, 73.43405395746231, 69.89919483661652, 78.42361181974411, 57.608454152941704, 79.07527685165405, 56.288579776883125, 39.77450251579285, 43.18729318678379, 66.63636311888695, 64.58587914705276, 69.44790825247765, 83.3537408709526, 75.67116111516953, 75.60096368193626, 69.46700602769852, 67.0160311460495, 62.256018966436386, 72.06097483634949, 74.28672060370445, 76.89028009772301, 73.44678327441216, 78.36628049612045, 76.80197283625603, 75.57486668229103, 71.24288633465767, 71.2827917933464, 69.12798821926117, 70.85638627409935, 67.80376687645912, 72.67591863870621, 71.044742166996, 75.96780359745026, 77.26034224033356, 73.20076167583466, 72.73575782775879, 82.19275876879692, 80.26394426822662, 39.180651381611824, 1.6358273033984005, 1.7329886835068464, 3.7381636491045356, 6.140671418979764, 10.52152806892991, 7.735421620309353, 1.8510046508163214, 0.9785681404173374, 1.0117143555544317, 0.14608595171011984, 0.1918819107231684, 4.774322686716914, 50.939489006996155, 71.66161626577377, 40.91743938624859, 24.729641117155552, 35.20918428897858, 51.60160347819328, 32.251780182123184, 4.564004922285676, 0.1721911595086567, 0.06579651977517642, 0.03878301598888356, 0.0554771826864453, 0.0573336539673619, 0.0486858264048351, 0.043620000578812324, 0.052878649075864814, 0.08335013801115565, 0.08100607941742055, 0.19236230291426182, 0.02511764301743824, 0.05125994335685391, 0.023938385202200152, 0.0766841453150846, 0.05436207240563817, 0.03852417714369949, 0.14691878983285278, 0.0912197309662588, 0.0556106616568286, 0.03615830311900936, 0.03943188683479093, 0.06021059314662125, 0.06934283534064889, 0.018881084797612857, 0.031454077616217546, 0.03466725422185846, 0.014120169416855788, 0.051190029334975407, 0.04468257422558963, 0.01974054004676873, 0.04419693876116071, 0.030806887734797783, 0.0404178708413383, 0.008179308806575136, 0.0549052057613153, 0.18877143622376025, 0.1620480342535302, 0.15975757356500253, 0.14292453619418666, 0.06817384142777883, 0.17530484008602798, 0.10829316481249407, 0.1679571921704337, 0.07772602417389862, 0.18247981992317364, 0.18350756086874753, 0.14114802761469036, 0.1873291315860115, 0.10242385280434974, 0.16075116087449715, 0.28156604908872396, 0.13772222941042855, 0.10379641782492399, 0.12569112499477342, 0.07060538438963704, 0.1311136269941926, 0.07201026994152926, 0.09095112545765005, 0.21118208445841447, 0.13216909457696602, 0.29806526843458414, 0.29535818088334054, 0.12493486166931689, 0.2786937594646588, 0.19670587062137201, 0.12008138655801304, 0.12885806208942086, 0.11496614853967912, 0.12645515118492767, 0.07306789717404172, 0.10519576695514843, 0.17137533141067252, 0.07120123249478638, 0.13326996675459668, 0.1622478649369441, 0.19017667800653726, 0.2616458258125931, 0.17562694702064618, 0.42580069857649505, 20.51646899431944, 72.31979414820671, 80.33851906657219, 57.29134976863861, 50.43986141681671, 55.67012116312981, 80.85377141833305, 69.30615305900574, 14.273961614817381, 0.7468990841880441, 0.2302587529993616, 7.434860598295927, 11.852874029427767, 4.224557736888528, 2.7329088281840086, 0.6879595562350005, 0.4293408617377281, 0.2779215993359685, 5.525070251896977, 35.29525347054005, 66.75586670637131, 79.76798728108406, 78.86703282594681, 76.05389177799225, 82.00643196702003, 88.78874123096466, 88.47221821546555, 85.23447275161743, 81.81730091571808, 77.10695207118988, 72.74216428399086, 74.80566635727882, 80.42905300855637, 78.03048491477966, 73.06244149804115, 68.05881679058075, 71.65691211819649, 75.73597803711891, 72.04560846090317, 71.70758619904518, 78.32892090082169, 61.17759883403778, 78.42693284153938, 61.13094113767147, 52.589672058820724, 47.52778507769108, 75.01277044415474, 67.45237693190575, 69.1673693060875, 87.45286971330643, 80.80726951360703, 80.74429929256439, 76.74879848957062, 76.65251925587654, 70.69242507219315, 76.59635066986084, 79.65451776981354, 80.27545765042305, 78.41628581285477, 81.89712703227997, 83.02635043859482, 81.30141779780388, 74.06790554523468, 75.50226777791977, 72.58217766880989, 72.43960931897163, 70.76582953333855, 75.40778204798698, 77.86606013774872, 81.65166780352592, 81.18860185146332, 73.1309974193573, 73.03122237324715, 89.05427098274231, 76.36854529380798, 33.473813608288765, 1.5349640906788409, 0.6547295674681664, 2.2709310427308083, 5.735135804861784, 8.73295359313488, 20.557504892349243, 17.02251847833395, 22.26127076894045, 12.3191137611866, 0.56510163936764, 0.31372134864795953, 11.109756454825401, 61.72704555094242, 61.96042902767658, 40.79914413392544, 38.06377351284027, 48.88319134712219, 63.455660194158554, 36.81617505848408, 3.8215012522414327, 0.2233487495686859, 0.1699206922785379, 0.24160495901014656, 0.07443660302669741, 0.188746307103429, 0.12596019805641845, 0.1320379867684096, 0.23481227428419515, 0.16946479096077383, 0.14356995234265924, 0.23158154217526317, 0.1363150728866458, 0.17175235727336258, 0.1327618330833502, 0.17067515960661694, 0.1587289568851702, 0.18141666369047016, 0.23662848776439205, 0.22464951180154458, 0.1439088466577232, 0.10243052471196279, 0.17915048607392237, 0.06864152805064805, 0.19601844891440123, 0.13066629006061703, 0.10900360794039443, 0.12845694611314684, 0.13244560395833105, 0.43942920165136456, 0.14847252052277327, 0.11944354773731902, 0.12527103972388431, 0.21487458085175604, 0.12092108212527819, 0.12845344317611307, 0.15277393424184993], [0.09048542779055424, 0.11477779888082296, 0.05692000311682932, 0.07532431554864161, 0.08265352851594798, 0.05295315328112338, 0.04787398735061288, 0.08087397713097744, 0.04913272918201983, 0.016518843585799914, 0.008304785569634987, 0.02791848237393424, 0.03810125315794721, 0.032642311707604676, 0.021619472427119035, 0.07290403838851489, 0.03666901946417056, 0.04405980842420831, 0.09817677171668038, 0.03418788248382043, 0.11635842500254512, 0.08238592490670271, 0.09165770199615508, 0.049860620201798156, 0.0516421419888502, 0.0756478845141828, 0.03913826723874081, 0.05427648051409051, 0.0431900261901319, 0.08609034019173123, 0.03470083269348834, 0.03314834881166462, 0.03239370336814318, 0.035426315444055945, 0.0827829293848481, 0.015263547174981795, 0.020240411759004928, 0.003393407864678011, 0.07439775159582496, 0.10312366837752052, 0.013299274305609288, 0.039411500038113445, 0.053464095981325954, 0.014322682036436163, 0.18344637821428478, 4.56201477907598, 42.18771122395992, 60.54166495800018, 54.114066660404205, 42.12631031870842, 25.09766846895218, 37.252976819872856, 66.98282092809677, 44.1148766130209, 3.6386842746287584, 1.2124729016795754, 0.9290363732725382, 6.524679763242602, 1.6097515588626266, 2.738289814442396, 2.0835388731211424, 0.05034905727370642, 0.1780616515316069, 0.12303123803576455, 10.336316507309675, 48.0184755474329, 76.07958599925041, 80.31473994255066, 74.37109127640724, 69.3047547340393, 72.29112848639488, 76.46385177969933, 77.85109654068947, 79.25737828016281, 79.34679508209229, 78.46400365233421, 79.56949353218079, 75.73436692357063, 72.8407233953476, 71.31010472774506, 72.51689717173576, 71.57549768686295, 73.7688235938549, 70.14423608779907, 62.35337354242802, 75.9498305618763, 79.00527700781822, 42.359192222356796, 53.82306307554245, 47.943015396595, 33.37662622332573, 73.74290138483047, 49.143382385373116, 76.54815405607224, 69.25120040774345, 74.13573950529099, 69.16059046983719, 66.89627677202225, 67.55434066057205, 72.70356595516205, 71.60490810871124, 71.7457589507103, 75.90256869792938, 73.76651331782341, 79.11293283104897, 77.84905225038528, 78.28089147806168, 78.53771209716797, 77.2437447309494, 80.87101489305496, 79.92313295602798, 78.29277724027634, 76.75055399537086, 73.71943384408951, 73.19883897900581, 80.70120960474014, 85.71327745914459, 50.80172739923, 7.510038614273071, 0.13620385463582352, 0.29047784744761884, 1.606834502890706, 5.727964639663696, 12.176893092691898, 18.149781189858913, 8.659873064607382, 2.3219297686591744, 0.90637581422925, 0.6071183597669005, 0.9828218340408057, 28.386200107634068, 56.988563016057014, 35.02164535224438, 21.240672133862972, 26.933545656502247, 41.84038706123829, 38.91593858599663, 14.178815670311451, 0.32776489038951695, 0.0650337478145957, 0.10235198322334327, 0.03889912499289494, 0.014688684223074233, 0.07444679271429777, 0.020413103957253043, 0.05623446646495722, 0.03000129941938212, 0.06481204603915103, 0.037768470429000445, 0.0630788343551103, 0.06192783752339892, 0.008178434000001289, 0.03332667576614767, 0.03164448673487641, 0.04247584263794124, 0.03436714454437606, 0.05847243875905406, 0.026331648186896928, 0.02462300159095321, 0.05416130290541332, 0.02411488090729108, 0.03159794294333551, 0.04719468102848623, 0.05193428100028541, 0.036319185892352834, 0.022147089330246672, 0.068298759724712, 0.03897791510098614, 0.06453736234107055, 0.0675164395943284, 0.015362453195848502, 0.05187097951420583, 0.09352910899906419, 0.08295144885778427, 0.07889924832852557, 0.06265778429224156, 0.09232673328369856, 0.12044035596773028, 0.06172069668537006, 0.03562237601727247, 0.015636060779797845, 0.04395220814330969, 0.03392519189219456, 0.016134073412104044, 0.13303944084327668, 0.01929664853378199, 0.02244273498945404, 0.03649854814284481, 0.02091720962198451, 0.02152036046027206, 0.0516254325339105, 0.031139121274463832, 0.060345382007653825, 0.03237225901102647, 0.028773228696081787, 0.055537111111334525, 0.04447781939234119, 0.07289074652362615, 0.09690214050351642, 0.05704941140720621, 0.025852638245851267, 0.051033224663115107, 0.021481293806573376, 0.07813942269422114, 0.03635420413047541, 0.01577653078129515, 0.043993467843392864, 0.02279380238178419, 0.020009709587611724, 0.028412982792360708, 0.037934180872980505, 0.07831405746401288, 0.09196049082675017, 0.04239157547999639, 0.016172015712072607, 0.10823460193932988, 0.013263006476336159, 0.04077241705090273, 0.05800185404950753, 0.003181893457622209, 0.13361830118810758, 9.230240508913994, 55.4494784027338, 68.39707463979721, 51.271648183465004, 34.000792130827904, 32.24859595298767, 64.06020775437355, 90.25646567344666, 32.451942041516304, 1.779149437788874, 0.4999223118647933, 1.1183157353661954, 1.1747767869383097, 0.8333492546807975, 5.791240269318223, 5.4320398438721895, 0.5537133535835892, 0.45803181594237685, 0.6365398841444403, 17.780258618295193, 58.63926284015179, 76.79375007748604, 79.86121907830238, 74.944738894701, 72.11718142032623, 78.48377779126167, 78.19068431854248, 81.07912972569466, 82.4093547463417, 81.98841333389282, 81.26031160354614, 81.37790769338608, 76.2255209684372, 72.15543776750565, 71.90793424844742, 68.9974196255207, 71.54464334249496, 73.29946517944336, 68.81530299782753, 62.23863109946251, 68.39787259697914, 82.71082296967506, 53.01980137825012, 58.275717347860336, 50.428845807909966, 47.236131727695465, 74.34375554323196, 57.960132881999016, 78.97814646363258, 72.88527220487595, 77.64721468091011, 72.8768290579319, 71.79017096757889, 70.99639356136322, 71.83812439441681, 74.05465185642242, 73.35008606314659, 75.07317200303078, 76.93848431110382, 78.43333169817924, 77.14194819331169, 80.88452696800232, 80.88542371988297, 77.92314067482948, 81.27829983830452, 81.26118555665016, 75.40018245577812, 77.31831192970276, 75.84454581141472, 74.79224547743797, 76.03228613734245, 85.20206049084663, 66.58419191837311, 14.377037733793259, 0.9826819540467113, 1.5590325929224491, 4.90629767999053, 6.825018497183919, 14.699967205524445, 5.958265531808138, 1.827819007448852, 0.7360947201959789, 0.364205974037759, 0.15931271540466696, 0.4028503753943369, 24.699440337717533, 74.38164710998535, 57.31452852487564, 26.407627277076244, 24.45937491953373, 44.535711631178856, 49.66747306287289, 20.612402446568012, 0.8788055030163378, 0.1492783147841692, 0.16261482727713883, 0.049081817851401865, 0.02872768309316598, 0.029194328853918705, 0.10731724803918041, 0.06765015976270661, 0.060792544536525384, 0.02137723542546155, 0.06593919766601175, 0.08085911933449097, 0.05654118867823854, 0.01585175486980006, 0.03167993541865144, 0.06846447387943044, 0.04368486057501286, 0.029906694144301582, 0.03233477684261743, 0.04520765854977071, 0.022042975288059097, 0.09406209719600156, 0.03520817968819756, 0.051726449964917265, 0.05640571333060507, 0.09609375614672899, 0.012211842422402697, 0.022841585559945088, 0.035727909416891634, 0.039824200939619914, 0.052403782174224034, 0.04374769079731777, 0.026345793521613814, 0.04020195781777147, 0.08699970858287998, 0.0299959040057729, 0.1176605379441753, 0.042262898205081, 0.17399270815076306, 0.24203301494708285, 0.12748931912938133, 0.09445290474104695, 0.14462288178037852, 0.16859186202054843, 0.10489216176210903, 0.07074775057844818, 0.18816354306181893, 0.11297322227619588, 0.10977906320476905, 0.17608117108466104, 0.17148625280242413, 0.08494401146890596, 0.17745666758855805, 0.09948911145329475, 0.18196361168520525, 0.1049713340762537, 0.21145307226106524, 0.0994923991675023, 0.20824095321586356, 0.24296378687722608, 0.17155414447188377, 0.1833323694881983, 0.08038019659579732, 0.2459777079639025, 0.13653701957082376, 0.16070253535872325, 0.180165269121062, 0.20105458883335814, 0.099093071767129, 0.14456264907494187, 0.12454634736059234, 0.1474824658362195, 0.20651373808505014, 0.2064608526416123, 0.17298245220445096, 0.11549468385055661, 0.2232117491075769, 0.2246795836254023, 0.07921792654087767, 0.19984914804808795, 0.17002573586069047, 0.10560794835328124, 0.35872079024557024, 7.154252305626869, 60.78446052968502, 84.90908861160278, 67.79030039906502, 56.68014116585255, 41.57437093555927, 50.29976673424244, 81.38437494635582, 55.41300415992737, 5.554113043472171, 1.3732257694937289, 2.3895352659747005, 19.68950416892767, 9.127964247018099, 5.685563664883375, 4.764517787843943, 0.2738363138632849, 0.21353712683776394, 0.3797632298665121, 14.223226737231016, 54.722364619374275, 79.13693994283676, 84.95453417301178, 78.41881647706032, 71.22159227728844, 76.10488504171371, 77.38946691155434, 81.36267051100731, 83.31895753741264, 87.10105419158936, 86.40005260705948, 81.89783379435539, 75.37012606859207, 72.92015433311462, 73.66632029414177, 71.97538822889328, 72.14469194412231, 73.39565321803093, 71.08579516410828, 64.48078438639641, 76.07850685715675, 82.89661020040512, 55.107150971889496, 68.55264589190483, 55.494277998805046, 50.396912321448326, 79.65569570660591, 58.684864193201065, 76.420176923275, 71.38943687081337, 78.60287100076675, 72.21123397350311, 70.70817142724991, 74.2054733633995, 75.89436873793602, 76.49954706430435, 75.91969817876816, 78.41212123632431, 77.70904496312141, 80.77978178858757, 77.26392164826393, 83.52852389216423, 83.01725372672081, 82.58510291576385, 86.89443647861481, 87.61777326464653, 77.56898447871208, 80.02336397767067, 76.60087242722511, 81.42822459340096, 82.37850040197372, 88.21581557393074, 55.63711613416672, 10.579338166862726, 0.5521036055870354, 0.5144817056134343, 3.9190595922991633, 12.181140314787626, 30.149472691118717, 34.08669412136078, 20.18152266740799, 9.152576476335526, 2.261794195510447, 0.9348796284757555, 2.183652576059103, 36.585379242897034, 70.407774746418, 45.69820985198021, 30.45549686998129, 38.47350932657719, 56.87515430152416, 58.209190517663956, 24.711698479950428, 0.7317061338108033, 0.4919488256564364, 0.4629580437904224, 0.10176282186876051, 0.12680225365329534, 0.2127165044657886, 0.11341319710481912, 0.1783208837150596, 0.16687758994521573, 0.10824146680533886, 0.13375837414059788, 0.22219764883629978, 0.14089234289713204, 0.1349911853321828, 0.0874848579405807, 0.15232536534313112, 0.14744941057870165, 0.15750984573969617, 0.19517927285050973, 0.14740232873009518, 0.1534619348240085, 0.2540809364290908, 0.0923438768950291, 0.12639059918001294, 0.14419230254134163, 0.15998769871657714, 0.11528576927958056, 0.11425327858887613, 0.11452228485723026, 0.17318980826530606, 0.17669874185230583, 0.22824321349617094, 0.14883785013807938, 0.2421862684423104, 0.1733480638358742, 0.17755366628989577, 0.16915856598643586, 0.0840063820942305], [0.0669614170328714, 0.0275610826065531, 0.08364162393263541, 0.042623229455784895, 0.07927965838462114, 0.07043954406981356, 0.019787978126259986, 0.004925662888126681, 0.05377600580686703, 0.030355294584296644, 0.04820179026864935, 0.053196974768070504, 0.018910069375124294, 0.035739524028031155, 0.07469072923413478, 0.05124745672219433, 0.005567239813899505, 0.07064699660986662, 0.13449822115944698, 0.08366394773474894, 0.22993765538558364, 0.04031678290630225, 0.11977742513408884, 0.029574842810689006, 0.0303571852055029, 0.07177693129051477, 0.05809909765957855, 0.08777862225542776, 0.05007684121665079, 0.08249148057075217, 0.09177196305245161, 0.09766707953531295, 0.05877673414943274, 0.03621648378612008, 0.060642523094429635, 0.013197427524573868, 0.10205150989349931, 0.03850429129670374, 0.10678226346499287, 0.03515209558827337, 0.055013173405313864, 0.034307809837628156, 0.07482467946829274, 0.02179882169002667, 0.06647144371527247, 0.06990378024056554, 1.045084996148944, 24.786094687879086, 55.89162267744541, 60.27631759643555, 42.356669157743454, 31.697935201227665, 22.59289227426052, 46.31135635077953, 63.53996627032757, 23.06938860565424, 0.6961709749884903, 0.03480331586615648, 1.7530811741016805, 6.344911884516478, 8.721100129187107, 0.2413959553814493, 0.48510447260923684, 0.044589371609617956, 0.1688682081294246, 0.9645540174096823, 18.46583303064108, 51.49985633790493, 76.80734574794769, 85.86639404296875, 82.40573734045029, 79.03490781784058, 78.48566249012947, 76.18055418133736, 76.74293920397758, 75.87999790906906, 71.85985162854195, 71.74290910363197, 73.79544496536255, 77.93615877628326, 75.74100136756897, 72.47873201966286, 80.77934101223946, 71.08354568481445, 76.76280453801155, 49.24622766673565, 11.520356722176075, 0.8199810376390815, 16.971014142036438, 46.741360276937485, 26.43959116190672, 74.42964613437653, 48.69213379919529, 78.17324325442314, 87.37485229969025, 79.82286393642426, 77.78368815779686, 81.75479426980019, 77.97269001603127, 78.65153878927231, 77.403244972229, 84.1544035077095, 81.59514963626862, 79.40231010317802, 75.00371173024178, 75.18592715263367, 76.46255984902382, 77.38375201821327, 73.46981763839722, 74.14268553256989, 67.5936533510685, 69.95105445384979, 71.19251623749733, 95.36381721496582, 84.6578460931778, 64.37848627567291, 19.531561844050884, 0.8353269891813397, 0.396077980985865, 0.32625361054670066, 1.377021528314799, 8.15900769084692, 3.000782816670835, 9.638668242841959, 8.397241607308388, 1.9795909384265542, 0.3994532092474401, 0.05011481320252642, 11.558714713901281, 50.551727414131165, 49.76739630103111, 27.321425043046474, 27.295852415263653, 43.8354130089283, 50.372772216796875, 29.663400873541832, 3.9484719140455127, 0.12277681496925652, 0.04079176113009453, 0.03438006533542648, 0.09289751906180754, 0.019253125283285044, 0.014314029522211058, 0.013060549517831532, 0.08963370200945064, 0.06408770248526707, 0.0038006822751412983, 0.06540969756315462, 0.03614029861637391, 0.007638076740477118, 0.06802757154218853, 0.009111839626712026, 0.01821300531446468, 0.07042764744255692, 0.06887335272040218, 0.051578870188677683, 0.06544388830661774, 0.10066571980132721, 0.032032006565714255, 0.033986775306402706, 0.039975120380404405, 0.05103206691273954, 0.02914543616498122, 0.044673557131318375, 0.030389674575417303, 0.02596409212856088, 0.03471247327979654, 0.018373199745838065, 0.0295859323523473, 0.09704137482913211, 0.07911353604868054, 0.11725398202543147, 0.05301614306517877, 0.055515284548164345, 0.11764979906729423, 0.04311207099817693, 0.02352690698899096, 0.07115624350262806, 0.01813641381886555, 0.028781475812138524, 0.07370009567239322, 0.040848001081030816, 0.042011848199763335, 0.03944954623875674, 0.05539080040762201, 0.037096381493029185, 0.08354304445674643, 0.09105488512432203, 0.06267311706324108, 0.05848681787028909, 0.07458923311787657, 0.08365418107132427, 0.16232007590588182, 0.05324269848642871, 0.07341816861298867, 0.05129448662046343, 0.04828271034057252, 0.05695071318768896, 0.11925385479116812, 0.018697078558034264, 0.032538039959035814, 0.030664751611766405, 0.04290838856832124, 0.05675944688846357, 0.03437199447944295, 0.05327345679688733, 0.1094684076088015, 0.05122014568769373, 0.018711194206844084, 0.03757773847610224, 0.06856936903204769, 0.048709923939895816, 0.09231574949808419, 0.0116317640276975, 0.053526098708971404, 0.03298177747637965, 0.04884366637270432, 0.05048874802014325, 0.08028891985304654, 0.012213734898978146, 0.13359305332414806, 0.03137723935651593, 3.0941903544589877, 38.027675449848175, 68.03436890244484, 62.48690977692604, 37.45824560523033, 21.160821318626404, 40.44914871454239, 89.6598368883133, 74.39392805099487, 14.112343937158585, 0.9898745524697006, 0.056031945496215485, 2.648576865904033, 3.302599908784032, 3.32499994430691, 0.990702195558697, 1.5265476610511541, 0.40008658776059747, 0.053381435573101044, 2.072484316304326, 28.25531993061304, 62.906300872564316, 81.51249647140503, 84.5400296151638, 77.9673171043396, 76.07105925679207, 77.54492416977882, 75.764180123806, 75.88970258831978, 72.60309934616089, 70.83144441246986, 68.40845122933388, 73.32019686698914, 73.60450521111488, 76.99723675847054, 72.11540311574936, 79.5868282020092, 72.3251822590828, 77.72027716040611, 67.44138032197952, 24.29902732372284, 4.255703715607524, 29.081249311566353, 63.49474489688873, 38.467171266674995, 76.51623576879501, 53.285410925745964, 81.18311494588852, 85.63973620533943, 78.66236060857773, 77.31548488140106, 78.55357244610786, 77.58256494998932, 80.46747654676437, 79.4786024093628, 85.79755693674088, 83.9943028986454, 80.19499316811562, 76.0138875246048, 76.85807302594185, 74.8101045191288, 77.50826373696327, 72.80413135886192, 75.02176076173782, 72.97074481844902, 73.0250059068203, 67.7853986620903, 88.01464676856995, 88.25452789664268, 71.829544454813, 31.2772673740983, 2.217517071403563, 0.3555797244189307, 1.4332076883874834, 3.5124108754098415, 7.905257781967521, 4.614677578210831, 6.043785642832518, 2.770105507224798, 1.7755807167850435, 0.3179584181634709, 0.11458072898676619, 8.106363415718079, 58.67412596940994, 72.86266341805458, 37.3209285736084, 18.144330382347107, 31.554456800222397, 53.62432613968849, 40.578022599220276, 7.867057481780648, 0.1257698965491727, 0.11161919610458426, 0.019197443798475433, 0.10970057366648689, 0.050310688238823786, 0.03527623834088445, 0.06359251186950132, 0.08641839172923937, 0.030815390891802963, 0.014913643099134788, 0.05456719460198656, 0.0362416648567887, 0.1079290671623312, 0.0403049530723365, 0.0023859737029852113, 0.02911061830673134, 0.056318106508115306, 0.04365622851764783, 0.028906089828524273, 0.042296981337131, 0.035450338764349, 0.04078986123204231, 0.07335264439461753, 0.062004716601222754, 0.0825449003605172, 0.030394489258469548, 0.033752475574146956, 0.04412109869008418, 0.04373903735540807, 0.058581627235980704, 0.04660725258872844, 0.0721688149496913, 0.04379643876745831, 0.04181795098702423, 0.07496971738873981, 0.013703793028980726, 0.008044843707466498, 0.05947294288489502, 0.02413886526483111, 0.1838483996107243, 0.2782073855632916, 0.2692321187350899, 0.09360898635350168, 0.13310832699062303, 0.31462133629247546, 0.11135678752907552, 0.07813163014361635, 0.11126577053801157, 0.12050855933921412, 0.13528780691558495, 0.2890474913874641, 0.13341927202418447, 0.18590904684970155, 0.21272278303513303, 0.2179682085989043, 0.1576753001427278, 0.1543943988508545, 0.22045186517061666, 0.30314981122501194, 0.29807280865497887, 0.1673246151767671, 0.35184689972084016, 0.2704198518767953, 0.12384498812025413, 0.1431291166227311, 0.08858472821884789, 0.20610861451132223, 0.10180058976402506, 0.21624657441861928, 0.16944438189966604, 0.210487374861259, 0.1061141598620452, 0.21501935902051628, 0.24859937431756407, 0.12574044812936336, 0.3801728953840211, 0.199569521646481, 0.27721278893295676, 0.162068443314638, 0.14189602341502905, 0.13521329528884962, 0.12168806948466226, 0.0662670042947866, 0.225912973692175, 0.2053143532248214, 2.0251616556197405, 38.28437827527523, 84.66380417346954, 79.90758419036865, 57.241891622543335, 47.018802389502525, 34.24779787659645, 64.40462127327919, 82.07909166812897, 32.28773005306721, 1.4531906973570585, 0.24007313651964068, 6.1663575656712055, 19.56920262426138, 19.173206873238087, 1.8244977481663227, 1.1876436090096831, 0.21743979945313185, 0.2748030354268849, 1.060541260521859, 23.60207062214613, 53.36867965757847, 78.39663326740265, 87.71226659417152, 85.98324537277222, 83.3178023993969, 82.46051520109177, 79.62227270007133, 76.01239040493965, 72.56178796291351, 74.46179240942001, 71.91072329878807, 75.76386094093323, 79.22438085079193, 78.46131339669228, 75.90021282434464, 81.99155956506729, 76.46475613117218, 79.29283797740936, 56.97785519063473, 16.02405935525894, 1.7522148205898702, 23.85755181312561, 67.93653175234795, 46.965696439146996, 82.9521632194519, 58.43767985701561, 89.06516879796982, 91.33143559098244, 84.99618753790855, 84.86693367362022, 89.65097576379776, 83.21280643343925, 83.81303742527962, 81.40145123004913, 91.22698679566383, 89.65261727571487, 85.59446543455124, 77.87675276398659, 77.79099896550179, 77.50892490148544, 80.40370836853981, 77.1031902730465, 78.37891861796379, 73.7863102555275, 79.37975451350212, 65.93867495656013, 89.94508758187294, 86.91343545913696, 63.35097201168537, 21.2358520925045, 1.8679107748903334, 0.8890040963888168, 1.3010486424900591, 3.899008543230593, 18.830250576138496, 12.333089411258698, 19.943875819444656, 20.393864773213863, 6.504661487415433, 1.2069386173970997, 0.3051953186513856, 16.03450119495392, 60.93898683786392, 60.25630407035351, 37.77915358543396, 35.99421836435795, 52.060789838433266, 64.71191838383675, 46.50590971112251, 6.770085319876671, 0.2629489777609706, 0.18828060943633318, 0.1168934689485468, 0.38963605009485036, 0.13683799013961107, 0.08911781289498322, 0.13832672353601083, 0.23251011734828353, 0.08615720027592033, 0.07752946636173874, 0.22232940973481163, 0.10604272072669119, 0.2278219407889992, 0.125329936563503, 0.12814107321901247, 0.11816697209724225, 0.20234827097738162, 0.11491042067063972, 0.13886062457459047, 0.18681884568650275, 0.1784867834066972, 0.13513161451555789, 0.14387671166332439, 0.14723497442901134, 0.12378375351545401, 0.1577553481911309, 0.10539514492847957, 0.11689391423715279, 0.1813998763100244, 0.15511229314142838, 0.1009850214177277, 0.1819544832687825, 0.1461447891779244, 0.1489757708623074, 0.3372912760823965, 0.11304997518891469, 0.12353279627859592, 0.17466691962908953, 0.11262783416896127], [0.14932472869986668, 0.14630053628934547, 0.06548050587298349, 0.02493833457265282, 0.07461125263944268, 0.15575252909911796, 0.014549477727996418, 0.0291133048813208, 0.10467348794918507, 0.08454994589556009, 0.09329890221124515, 0.06576137166121043, 0.11983673015492968, 0.03521969782013912, 0.11258758007897995, 0.11327322805300355, 0.12506156112067401, 0.039012339620967396, 0.052236650517443195, 0.044282519520493224, 0.10852484105271287, 0.028509866460808553, 0.023425941508321557, 0.12948364805197343, 0.02155390739062568, 0.160580734082032, 0.10058977582957596, 0.04522447561612353, 0.017140752206614707, 0.04796750166860875, 0.09479314234340563, 0.010909201628237497, 0.029738955781795084, 0.11970398962148465, 0.03288713880465366, 0.027914528582186904, 0.05428911557828542, 0.07458161126123741, 0.07363838609308004, 0.03945866723370273, 0.09109597041970119, 0.023427809865097515, 0.09895307302940637, 0.04716780415037647, 0.08527234502253123, 0.1188480484415777, 0.03530877780576702, 0.09999298519687727, 6.587380198761821, 44.01213392615318, 56.526849791407585, 54.37964580953121, 39.64459128677845, 23.614554852247238, 34.89281706511974, 58.95254082977772, 54.5711213350296, 10.114512909203768, 1.2815499887801707, 2.6430341508239508, 1.8945678882300854, 4.63292894884944, 2.47988301794976, 1.0247421939857304, 0.6182605493813753, 0.3317326493561268, 0.12498850410338491, 1.0597982816398144, 8.666803892701864, 27.259269878268242, 47.065931260585785, 61.61899834871292, 66.14734455943108, 78.42173472046852, 75.34555658698082, 78.54626923799515, 74.65733751654625, 67.03230187296867, 58.861752301454544, 59.48862366378307, 59.264367297291756, 48.9403934776783, 39.549866169691086, 31.82357545942068, 8.361702114343643, 0.07563027334981598, 0.4829979012720287, 0.6372358999215066, 0.10608131982735358, 4.4707669503986835, 6.196583993732929, 39.30070213973522, 67.39382967352867, 56.03401243686676, 77.10132077336311, 75.72209358215332, 83.261299431324, 75.23283183574677, 71.5916620194912, 71.22380375862122, 74.86131817102432, 68.97987216711044, 77.94653221964836, 79.70354273915291, 77.06037417054176, 81.16670742630959, 86.78165093064308, 84.13890793919563, 100.67734569311142, 84.02789309620857, 87.98096537590027, 83.50185692310333, 61.047053039073944, 37.511199563741684, 9.173480104655027, 0.5159144662320614, 0.02101717134792125, 0.14485300693195313, 0.3460098785581067, 2.089652270078659, 9.223547168076038, 7.318138461560011, 3.743661241605878, 6.580365300178528, 1.0435318294912577, 0.2735983516322449, 4.758843267336488, 32.98604518175125, 57.57465876638889, 30.38175232708454, 26.058093532919884, 44.82253164052963, 61.77887476980686, 49.31420221924782, 18.001712635159492, 0.8815933659207076, 0.19531385391019285, 0.02583650766609935, 0.041251773945987225, 0.07870582237956114, 0.11124154683784582, 0.04348546775872819, 0.013734089352510637, 0.09207775758113712, 0.02330340736079961, 0.06985625310335308, 0.06140771816717461, 0.033605908829486, 0.05473064891702961, 0.07946480938699096, 0.03946789584006183, 0.0905450593563728, 0.049844667737488635, 0.016749853748478927, 0.17362258426146582, 0.05967969038465526, 0.12167934924946167, 0.07960047398228198, 0.049786509334808215, 0.11556792640476488, 0.22924144665012136, 0.025726601161295548, 0.11022398815839551, 0.023626865004189312, 0.18375846615526825, 0.028116190514992923, 0.07232833217130974, 0.10964263419737108, 0.06975579599384218, 0.1391561032505706, 0.037995048114680685, 0.2152779677999206, 0.0996921185287647, 0.10839820839464664, 0.011243934350204654, 0.02301571010320913, 0.11335161369061098, 0.09102765572606586, 0.056839402168407105, 0.03985896684753243, 0.02571474720753031, 0.11480333618237637, 0.04611480049788952, 0.07061333279125392, 0.07616425602464005, 0.10131973001989536, 0.03654938525869511, 0.13497151841875166, 0.0380571695859544, 0.040949296817416325, 0.0576570893463213, 0.0969696017273236, 0.0975436381122563, 0.10372525328421034, 0.16886880184756592, 0.1425149745773524, 0.1481238892301917, 0.014964086876716465, 0.09500442436547019, 0.08735315641388297, 0.03528393070155289, 0.0390010292903753, 0.023133603972382843, 0.07050010332022794, 0.03590694512240589, 0.0646211656567175, 0.09212359262164682, 0.04703895247075707, 0.01830579789384501, 0.05802503503218759, 0.061133067865739577, 0.0617469353164779, 0.03649612874141894, 0.04770757557707839, 0.06653925374848768, 0.055050963565008715, 0.08209180436097085, 0.056425896036671475, 0.06603440036997199, 0.054037412483012304, 0.1452170600532554, 0.06920069179614075, 0.07106511518941261, 0.45575027586892247, 14.58962682634592, 59.754765182733536, 66.4867651462555, 52.56750024855137, 19.416528716683388, 18.22004321962595, 62.193599715828896, 89.71516191959381, 53.72626706957817, 3.7591145373880863, 1.4854882517829537, 0.7810382929164916, 2.5254285614937544, 1.4550426229834557, 3.269173577427864, 1.6105838329531252, 1.2905594240874052, 0.4177079047076404, 0.15828546427655965, 3.2430623285472393, 16.26571498811245, 38.75176839530468, 60.65676458179951, 71.20339125394821, 74.75823730230331, 85.07457733154297, 78.75687673687935, 74.66005057096481, 78.36102917790413, 76.13678812980652, 69.62453037500381, 72.14346081018448, 67.83370926976204, 64.18008372187614, 53.2665791362524, 40.27063429355621, 15.502839423716068, 0.6934610079042614, 0.8733164600562304, 0.9180765738710761, 0.7663528528064489, 9.450451992452145, 12.601531706750393, 62.166089192032814, 74.08649414777756, 60.82339324057102, 83.68541747331619, 80.39526522159576, 83.67113783955574, 83.43773156404495, 74.22462433576584, 71.35235086083412, 71.96476399898529, 69.52829673886299, 75.32116189599037, 80.5347329378128, 79.1452918946743, 80.7362513244152, 88.73086273670197, 83.79058822989464, 96.43349021673203, 86.77407413721085, 86.05614066123962, 85.53964957594872, 66.23325794935226, 56.75631567835808, 17.56633199751377, 2.971132770180702, 0.7106169092003256, 1.208963671233505, 1.9183833478018641, 1.1601989879272878, 6.77261408418417, 7.156348843127489, 3.735871659591794, 2.6520995143800974, 0.6378317554481328, 0.13635583163704723, 2.325233453884721, 35.387649312615395, 76.25913396477699, 47.93017588555813, 22.52090323716402, 32.24294565618038, 59.330198764801025, 58.67796376347542, 26.93023983389139, 1.342014956753701, 0.45462129113730043, 0.1346674605156295, 0.020210310249240138, 0.1465491854469292, 0.146458969975356, 0.005706673591703293, 0.029019942703598645, 0.09325842547696084, 0.055420126373064704, 0.037230558082228526, 0.06527335761347786, 0.017575624769960996, 0.041773967604967766, 0.11396853878977709, 0.03590726795664523, 0.07041586955892853, 0.05157729312486481, 0.05350079147319775, 0.07664746837690473, 0.02719211275689304, 0.05466128408443183, 0.012950041873409646, 0.04928437963826582, 0.1253362002898939, 0.07118642664863728, 0.037928533129161224, 0.15953250986058265, 0.0876494514523074, 0.08405143787967972, 0.05191652511712164, 0.01619397400645539, 0.10184004975599237, 0.06364997636410408, 0.07148855496780016, 0.05113090242957696, 0.14313193678390235, 0.0704616006987635, 0.025779993120522704, 0.10140089128981344, 0.05242319675744511, 0.2600540971616283, 0.2700365474447608, 0.19189721380826086, 0.1083178338012658, 0.22232541698031127, 0.27739256678614765, 0.10505826183361933, 0.12272159176063724, 0.2499830344459042, 0.21462183503899723, 0.1426340447505936, 0.23421488993335515, 0.1518461902742274, 0.18876158050261438, 0.2850172435864806, 0.2634458604734391, 0.21873794932616875, 0.16258166811894625, 0.24976374465040863, 0.23273126251297072, 0.17480130773037672, 0.2495554683264345, 0.127263602335006, 0.21711898385547101, 0.13743418705416843, 0.21755207155365497, 0.16036344808526337, 0.14945717237424105, 0.10613329242914915, 0.13593858137028292, 0.1790961905498989, 0.15200434194412082, 0.13676178641617298, 0.189470331533812, 0.06656617144471966, 0.1890884223394096, 0.16777771117631346, 0.16099678206956014, 0.1377795380540192, 0.22952939994866028, 0.1161173902801238, 0.15835898142540827, 0.30996827816125005, 0.22681116533931345, 0.40530537022277713, 0.2564422128489241, 0.14073785743676126, 0.48191020963713527, 12.247803937643766, 68.93439620733261, 86.23541504144669, 71.99731305241585, 50.38244649767876, 36.92311272025108, 53.86909760534763, 75.58030039072037, 67.87353113293648, 12.692725863307714, 2.096444168128073, 6.056595230475068, 10.833916906267405, 18.88363391160965, 10.07965262979269, 4.295814363285899, 1.9154121447354555, 0.3756039374275133, 0.4393561149481684, 2.5088037410750985, 10.561680514365435, 28.49695086479187, 46.45180441439152, 63.493418768048286, 67.20107361674309, 85.3139340877533, 75.1791787147522, 67.54039540886879, 70.48145279288292, 72.83305540680885, 64.26378563046455, 67.62959942221642, 68.44796150922775, 66.58094689249992, 44.59098346531391, 29.955715388059616, 7.038057390600443, 0.24874183698557317, 1.4226520922966301, 0.8051712135784328, 0.471778676728718, 5.569441895931959, 8.415400832891464, 64.59402590990067, 82.52265706658363, 57.59934984147549, 83.62482592463493, 77.71444827318192, 81.4346082508564, 81.05237156152725, 71.31375253200531, 74.36617434024811, 70.77600538730621, 66.34204611182213, 74.16030898690224, 79.39795553684235, 77.91920408606529, 82.89480149745941, 89.54832807183266, 80.26319950819016, 97.97402635216713, 89.34383824467659, 92.74920031428337, 96.50922015309334, 66.05464473366737, 41.377161517739296, 8.58419917523861, 1.1591802863404155, 0.5552193790208548, 0.4235594719648361, 0.534365326166153, 6.53471264988184, 17.232016436755657, 19.772797599434853, 14.919939301908016, 17.127337753772736, 2.7415609639137983, 0.38807243399787694, 6.916386969387531, 44.540993347764015, 69.62868735194206, 45.69144241511822, 35.564168840646744, 57.64416083693504, 75.02241432666779, 65.13798952102661, 27.0734104514122, 0.9648578823544085, 0.6740844226442277, 0.32152028172276914, 0.13376546907238662, 0.30650310160126537, 0.2540054451674223, 0.09938400849932805, 0.17089918430428952, 0.18308045488083735, 0.18565085367299616, 0.14180576341459528, 0.22903566394234076, 0.21919377642916515, 0.14116037695202976, 0.23384776432067156, 0.14459656522376463, 0.22142556292237714, 0.11699287962983362, 0.08887864096323028, 0.32863029395230114, 0.14656827348517254, 0.18336880893912166, 0.17721352516673505, 0.302699594758451, 0.3675375343300402, 0.42304088885430247, 0.1426563537097536, 0.2625828020973131, 0.21952044015051797, 0.37502019375097007, 0.08669936141814105, 0.19224021962145343, 0.20438629755517468, 0.21577682462520897, 0.21267412783345208, 0.17480648792115971, 0.3213696554303169, 0.2834779105614871, 0.17380593926645815, 0.5449493613559753, 0.17557293351273984], [0.04426641120517161, 0.11378032271750271, 0.07148019838496111, 0.01015531688608462, 0.09471578829106875, 0.055384276929544285, 0.021274924802128226, 0.1815901481313631, 0.04385252657812089, 0.17326458706520498, 0.05424615264928434, 0.20653046609368175, 0.012522388551587937, 0.04093481009476818, 0.05111744729219936, 0.09314903290942311, 0.0427065763506107, 0.052059774461667985, 0.05341594172932673, 0.08187356099369936, 0.2018910486367531, 0.025888381933327764, 0.10892108111875132, 0.03558778822480235, 0.08231251165852882, 0.06698049022816122, 0.05190365627640858, 0.02151038970623631, 0.09275138276279904, 0.016857658119988628, 0.03804488333116751, 0.10151576090720482, 0.0344331548694754, 0.10035073748440482, 0.03481382838799618, 0.04325163929024711, 0.02067952198558487, 0.07362775853835046, 0.029823117183696013, 0.027285461947030853, 0.040157250841730274, 0.026024079925264232, 0.05254272335150745, 0.018780746431730222, 0.05767802162154112, 0.04230230253597256, 0.03320298943435773, 0.025690334259707015, 0.24508356844307855, 0.056021570271695964, 25.9769868850708, 51.20903894305229, 71.01416140794754, 62.68269807100296, 30.780303440988064, 28.290834724903107, 41.849400177598, 57.50072993338108, 38.87544795870781, 4.452440058812499, 0.3819910087622702, 2.825647364370525, 1.078447443433106, 2.467168662697077, 0.4671780439093709, 0.9881908271927387, 0.19186926452675834, 0.04236289518303238, 0.08758681418839842, 0.05524768836039584, 1.3690955098718405, 4.363816939294338, 8.117116838693619, 10.754911545664072, 8.652784544974566, 9.933688212186098, 7.161286203190684, 2.902720528654754, 2.3128940910100937, 4.599868822842836, 5.307744238525629, 2.0608103927224874, 1.3681741780601442, 0.19463247328530997, 0.13024265732383355, 0.41494928242173046, 0.29576009837910533, 0.279431632370688, 0.43373446504119784, 0.26283682440407574, 0.10899778208113275, 4.181056721135974, 20.41588269174099, 61.25300198793411, 76.67583480477333, 84.64254051446915, 86.68498411774635, 89.9956476688385, 91.5492095053196, 91.00454673171043, 95.00264659523964, 86.3930381834507, 71.85127928853035, 46.55773513019085, 28.128830417990685, 20.231132805347443, 20.94102781265974, 20.22773578763008, 22.20082551240921, 20.933920294046402, 13.495334945619106, 5.930304732173681, 2.1250518830493093, 0.06995722971623763, 0.1578399381833151, 0.2626842982135713, 0.5373575468547642, 1.2188496720045805, 7.352495267987251, 2.607793416827917, 8.008128236979246, 6.873921398073435, 1.7331810481846333, 0.49030381080228835, 1.4374375739134848, 25.688574761152267, 51.61828078329563, 44.04777981340885, 27.849948182702065, 40.23530378937721, 56.2067511677742, 51.36845178902149, 28.253551125526428, 5.124427350237966, 0.05775246274424717, 0.05178416678973008, 0.07521294144680724, 0.0741917165578343, 0.022728257754351944, 0.025310681194241624, 0.05639130453346297, 0.0841005532129202, 0.01551106734041241, 0.02472861291607842, 0.02501985578419408, 0.10867217220948078, 0.1268372088088654, 0.014036739030416356, 0.06362246494973078, 0.003468927652647835, 0.0390691955544753, 0.06794050277676433, 0.07960683418787085, 0.11950077474466525, 0.023188023806142155, 0.11618849544902332, 0.1188690957496874, 0.023549976649519522, 0.058409801495145075, 0.0882992685365025, 0.10918026135186665, 0.13217535830335692, 0.08081939959083684, 0.02835298942954978, 0.12047380456351675, 0.05781977182778064, 0.05521845516341273, 0.016377486717829015, 0.09804610919672996, 0.24682917399331927, 0.018008237493631896, 0.04396729600557592, 0.07240236140205525, 0.04551368685497437, 0.03739990133908577, 0.0383856293046847, 0.0289578063893714, 0.0684584402188193, 0.048437143850605935, 0.02711317050852813, 0.07831417620764114, 0.09833310512476601, 0.03300043135823216, 0.03887422593834344, 0.04441218014108017, 0.08007249474758282, 0.07915935624623671, 0.0406842721713474, 0.06907469738507643, 0.03894446650519967, 0.049167999750352465, 0.05002024132409133, 0.05643552169203758, 0.05323895064066164, 0.10549495636951178, 0.10889722849242389, 0.2441545479814522, 0.016951202123891562, 0.02852707686542999, 0.0034773106744978577, 0.05264191138849128, 0.035595617882790975, 0.1010878905071877, 0.030863097999827005, 0.01593009783391608, 0.017070096037059557, 0.03448989205935504, 0.04470436368137598, 0.007838765995984431, 0.06059984960302245, 0.04280923763872124, 0.009677007346908795, 0.07693865001783706, 0.07705499650910497, 0.10454299612320028, 0.06791195235564373, 0.06283658993197605, 0.007127505114112864, 0.06006643838190939, 0.06875509148812853, 0.049330967958667316, 0.007285338124347618, 0.09448466124013066, 0.014940488435968291, 0.220397035300266, 2.2657402837648988, 37.38809376955032, 64.9997453391552, 72.43894815444946, 44.2898154258728, 19.589725323021412, 32.36036315560341, 69.6394331753254, 78.31655636429787, 30.338504947721958, 1.0033419798128307, 0.5485301348380744, 0.9722565009724349, 2.8635835787281394, 2.1203071251511574, 0.3477171447593719, 1.9381591491401196, 0.5501746153458953, 0.09731982121593319, 0.04750045329274144, 0.5455407046247274, 3.304809727706015, 7.982218377292156, 14.465524535626173, 18.548484295606613, 16.656660810112953, 18.219461850821972, 14.992846939712763, 7.773515051230788, 6.541136680170894, 13.107828889042139, 17.716566435992718, 10.207635462284088, 4.384616073220968, 1.3601549458689988, 0.6086614332161844, 1.5938951284624636, 1.389322062022984, 1.107507215347141, 0.9604720864444971, 0.21767317521153018, 0.09202482760883868, 9.743895996361971, 38.72102424502373, 66.03878438472748, 78.40577557682991, 81.70308664441109, 86.35363429784775, 77.0017509162426, 83.32971855998039, 86.26860246062279, 93.16482201218605, 84.40684676170349, 75.53833544254303, 60.89218094944954, 45.92872828245163, 32.77178607881069, 32.829637974500656, 35.29919005930424, 39.33936886489391, 34.02071826159954, 23.179860077798367, 12.365404777228832, 6.154412906616926, 0.7894277083687484, 0.8854236791376024, 0.39180252759251744, 1.9873402663506567, 5.202174028381705, 7.877603815868497, 3.409439963288605, 4.872857099398971, 3.4227933967486024, 0.48484317725524306, 0.4990769166033715, 0.44531671854201704, 26.509002037346363, 65.22377371788025, 64.96044784784317, 31.054614521563053, 27.46138673275709, 50.27852587401867, 62.63393148779869, 41.205665320158005, 7.832052810117602, 0.14149330439977348, 0.13005734304897487, 0.06338845836580731, 0.00983696892944863, 0.047730203659739345, 0.0961147143971175, 0.05538540870475117, 0.029959533203509636, 0.05219728329393547, 0.06011151272105053, 0.05554098141146824, 0.010247985155729111, 0.06060053980036173, 0.04577359068207443, 0.046860076326993294, 0.026945632525894325, 0.05572568712523207, 0.05627264254144393, 0.02411346711596707, 0.05655970897350926, 0.05232887720922008, 0.14737006014911458, 0.10017504144343548, 0.04892537312116474, 0.07340239797485992, 0.14321634866064414, 0.34334954631049186, 0.0926932725997176, 0.18073739076498896, 0.06683482890366577, 0.19329675589688122, 0.0352016636315966, 0.22258766228333116, 0.11262943720794283, 0.21997319476213306, 0.2668942348100245, 0.06645000306889415, 0.22086712648160756, 0.09324330050731078, 0.051519279440981336, 0.17644725769059733, 0.0419889492332004, 0.08225820129155181, 0.20325047022197396, 0.15676256240112707, 0.07557507982710376, 0.15363354905275628, 0.12944107846124098, 0.15177458786638454, 0.2390562160871923, 0.15196585416560993, 0.43489886505994946, 0.1624877715948969, 0.22666861361358315, 0.13584360131062567, 0.1299697399372235, 0.21700988814700395, 0.10873432707739994, 0.2576846274314448, 0.15597971534589306, 0.17313168325927109, 0.30005924112629145, 0.4014408291550353, 0.08977078410680406, 0.21690097055397928, 0.11729831050615758, 0.21922706917393953, 0.08390086353756487, 0.17151703708805144, 0.04695514915511012, 0.16555036272620782, 0.10354383528465405, 0.1472275232663378, 0.13438657246297225, 0.13589599693659693, 0.23594124417286366, 0.16646559408400208, 0.15027080371510237, 0.1502948789857328, 0.16197726305108517, 0.1628813028219156, 0.18652387167094275, 0.21100839221617207, 0.11972913358476944, 0.2596016542520374, 0.40779257426038384, 0.20446831971639767, 0.13569594360888004, 0.26699908543378115, 0.09235710196662694, 0.3423757298151031, 1.5632804087363183, 37.64447741210461, 76.18784219026566, 95.93609690666199, 79.26146686077118, 44.37151864171028, 39.1790896654129, 60.32973513007164, 71.34317055344582, 47.870215103030205, 6.037315065041184, 0.43540316924918443, 6.4199816063046455, 10.302887801080942, 14.893783405423164, 6.37157030403614, 2.943339399062097, 0.6666381878312677, 0.14037815330084413, 0.19931275339331478, 0.4669489577645436, 1.9513462227769196, 5.0247677229344845, 11.222278866916895, 12.75480693206191, 11.700691245496273, 11.097133532166481, 8.32970593124628, 3.8503013318404555, 2.233493314124644, 6.819363925606012, 9.933986496180296, 5.440736152231693, 2.6443602796643972, 0.5182678462006152, 0.20691011915914714, 0.8306116203311831, 0.5033646302763373, 1.3166146259754896, 1.5792844374664128, 0.3445929998997599, 0.16115200967760757, 6.685378365218639, 35.588483735919, 70.67820623517036, 82.15778544545174, 84.47329759597778, 86.35532140731812, 88.78022208809853, 89.38940539956093, 90.59701099991798, 100.36490365862846, 92.29787573218346, 79.83887627720833, 56.89092345535755, 41.36909835040569, 24.20711785554886, 24.212764352560043, 27.311762161552906, 25.623128972947598, 25.408497489988804, 14.17975327000022, 5.147699676454067, 3.1196022033691406, 0.5531968781724572, 0.49027884495444596, 0.5670875671785325, 0.8740203722845763, 3.6627671448513865, 19.163998067378998, 11.584023255854845, 25.077016577124596, 20.466877855360508, 5.1389862690120935, 0.6373795797117054, 2.1977111091837287, 34.86823618412018, 61.26117914915085, 57.506376430392265, 41.49785444140434, 53.841298297047615, 70.1854258775711, 72.79046729207039, 45.89783973991871, 7.676429310813546, 0.2501664636656642, 0.14961707551265135, 0.16411133838118985, 0.2226761559722945, 0.19832964520901442, 0.1444998782244511, 0.256621100124903, 0.23446922394214198, 0.15235957835102454, 0.12924619048135355, 0.13183584058424458, 0.2278281154576689, 0.2264460435253568, 0.1258629618678242, 0.1003860637138132, 0.1272533310111612, 0.10763294281787239, 0.20441323751583695, 0.11148138670250773, 0.3212642704602331, 0.10031733341747895, 0.2265609279857017, 0.3388258593622595, 0.14335146406665444, 0.17944784980500117, 0.20089422556338832, 0.4180223378352821, 0.2072801094618626, 0.2567293943138793, 0.17355396528728306, 0.3210092388326302, 0.15646849380573258, 0.2986718702595681, 0.16457760008051991, 0.2987332013435662, 0.38529018172994256, 0.20046501187607646, 0.3538462158758193, 0.24245189793873578, 0.2374319516820833, 0.1747538399649784, 0.1619618115364574], [0.19675280404044315, 0.018095777522830758, 0.06947340880287811, 0.3041672956896946, 0.14416233461815864, 1.1252335016615689, 0.20247532665962353, 0.13195112580433488, 0.1297050603898242, 0.02678573309822241, 0.11924068909138441, 0.051721032286877744, 0.03455544967437163, 0.10199469848885201, 0.1202102679235395, 0.1115022410522215, 0.47416301909834146, 0.08445598257821985, 0.03436443941609468, 0.1276381642674096, 0.05725916460505687, 0.014364329508680385, 0.030958035385992844, 0.02594981691800058, 0.08275152911664918, 0.049657223498797975, 0.07283216138603166, 0.07030727108940482, 0.06579520617378876, 0.02590766664070543, 0.04055054087075405, 0.012051848370902007, 0.03262060759880114, 0.037816016119904816, 0.03671830549137667, 0.05481190295540728, 0.05454713806102518, 0.08514746383298188, 0.11655408481601626, 0.03580324111680966, 0.06131869013188407, 0.0480685228103539, 0.03638779744505882, 0.026517181395320222, 0.05059260416601319, 0.05380663424148224, 0.048353770980611444, 0.08931070449762046, 0.05060725045041181, 0.17034819902619347, 0.2225529743009247, 5.3453892935067415, 33.7288711220026, 58.74583952128887, 71.50012493133545, 50.30336894094944, 33.62963564693928, 33.253034055233, 45.202131271362305, 60.52688755095005, 27.41032127290964, 3.3840160025283694, 1.522465255111456, 1.0671629989519715, 0.7664758712053299, 2.9048942495137453, 0.9970796783454716, 0.2001365224714391, 0.14974255784181878, 0.05959732683550101, 0.29690413386560977, 0.34820770437363535, 0.04571352124912664, 0.024722709131310694, 0.04957919409207534, 0.09348828345537186, 0.03445899274083786, 0.1423195522511378, 0.2132269536377862, 0.13240922387922183, 0.022129756471258588, 0.04030178410175722, 0.14078715088544413, 0.24030902073718607, 0.497026065713726, 1.1096660932525992, 0.8404142630752176, 0.4249701462686062, 0.03648723410151433, 0.13054398412350565, 0.20659040194004774, 0.14670001954073086, 0.20152022712863982, 5.0957312900573015, 25.354905165731907, 45.810524225234985, 54.221916273236275, 57.992161363363266, 51.905587166547775, 36.3147159665823, 29.277759566903114, 13.290286548435688, 4.246530057862401, 0.24553952913265675, 0.5899996845982969, 0.09607663479982875, 0.1041904091835022, 0.05076255969470367, 0.03187631140463054, 0.12876890046754852, 0.059434184222482145, 0.11468854077975266, 0.1269817049615085, 0.14706160873174667, 0.17066655069356784, 0.6229088874533772, 1.7281745793297887, 15.527444053441286, 16.499695032835007, 2.0572518836706877, 1.8195060035213828, 0.9620484674815089, 0.9072448394726962, 20.563124790787697, 45.83839952945709, 40.83386667072773, 27.32090637087822, 29.22827672213316, 53.50558631122112, 59.20145407319069, 35.30068337917328, 10.951782781630754, 0.044439049597713165, 0.14875703025609255, 0.04124604456592351, 0.036819081724388525, 0.027162098449480254, 0.0993075969745405, 0.06318007814115845, 0.026831495779333636, 0.009335451504739467, 0.0057810400357993785, 0.01977923933736747, 0.014294629781943513, 0.0912060977134388, 0.014657484334748005, 0.02465931302140234, 0.04549234639853239, 0.052476434721029364, 0.01574259793414967, 0.03727457486093044, 0.09197721883538179, 0.03859880751406308, 0.07499558123527095, 0.033711186188156717, 0.027161499165231362, 0.019445564175839536, 0.04262860260496382, 0.03784612134040799, 0.0212963097874308, 0.016493942675879225, 0.01385483585181646, 0.05152507561433595, 0.013868958922103047, 0.1411500759422779, 0.019434927344263997, 0.06044199850293808, 0.022348927523125894, 0.03321819232951384, 0.05881884731934406, 0.11757928761653602, 0.11309870460536331, 0.13053791335551068, 0.07321018914808519, 0.03208220914530102, 0.057054068383877166, 0.09861430487944745, 0.07197145561804064, 0.1344018755480647, 0.12718457845039666, 0.004582707169902278, 0.3724352933932096, 0.1579725302872248, 0.04734642796393018, 0.0957713820389472, 0.033018094472936355, 0.1280122363823466, 0.08205331658245996, 0.10662862405297346, 0.10062838235171512, 0.03322021097119432, 0.08780934716924094, 0.3175138123333454, 0.10039364846306853, 0.023660068691242486, 0.139795136929024, 0.04472433116461616, 0.019017504528164864, 0.028725747943099122, 0.03838168478978332, 0.07751010372885503, 0.09669659528299235, 0.016880276925803628, 0.02272461751999799, 0.029611326790472958, 0.058191487623844296, 0.026763602254504804, 0.026664223114494234, 0.03624462231528014, 0.023281111389223952, 0.03527587468852289, 0.07194832287495956, 0.10312744590919465, 0.03778461214096751, 0.06959929189179093, 0.03711624136485625, 0.025917646671587136, 0.1401377865113318, 0.015143248747335747, 0.052808052278123796, 0.07757797313388437, 0.017458719812566414, 0.08200391181162558, 0.15652373927878216, 0.1211535301990807, 0.06286712930887006, 0.21954472322249785, 10.347650349140167, 47.58378267288208, 72.10415571928024, 66.22295290231705, 37.15724095702171, 27.115542590618134, 43.443171456456184, 72.41971358656883, 77.12552547454834, 20.99101223051548, 1.9454959616996348, 0.8990537258796394, 0.4309892904711887, 2.4262845190241933, 0.9935737727209926, 0.8569295424968004, 0.5879363359417766, 0.34094095055479556, 0.055392403446603566, 0.3057022945722565, 0.11477832580567338, 0.3023658657912165, 0.2106241972069256, 0.2894694171845913, 0.24522536317817867, 0.13400034396909177, 0.8381831890437752, 0.5581017024815083, 0.9465349093079567, 0.3416634164750576, 0.3706473408965394, 0.5587390589062124, 0.7260146923363209, 2.4795118253678083, 3.1622247537598014, 2.173288632184267, 1.5976096666418016, 0.9971883287653327, 0.35841992357745767, 0.1623247069073841, 0.4131160886026919, 0.8288687013555318, 19.43130422383547, 38.80883753299713, 64.81685355305672, 66.57873541116714, 71.3471907377243, 73.44823479652405, 51.33828900754452, 56.16497240960598, 29.076415970921516, 11.616063136607409, 3.6335353134199977, 1.5381147153675556, 0.3296591778052971, 1.0980879957787693, 0.17193640989717096, 0.39111212245188653, 0.6064027512911707, 0.29566563782282174, 0.7448460068553686, 0.40471880638506263, 0.23479067778680474, 1.2834390811622143, 1.4660017099231482, 1.5322333434596658, 7.060061534866691, 9.721055421978235, 4.36551877297461, 2.0080098509788513, 0.9920103347394615, 0.6258115754462779, 14.017981700599194, 52.72614173591137, 57.733387649059296, 36.30812332034111, 23.16017523407936, 47.855844274163246, 71.07691124081612, 49.44995753467083, 16.057404465973377, 0.4093403974547982, 0.27193098329007626, 0.04781281953910366, 0.034336096796323545, 0.05745205620769411, 0.037710861215600744, 0.019600311243266333, 0.033610829268582165, 0.05001928766432684, 0.06717886630212888, 0.06649404953350313, 0.03440330568992067, 0.09280680635129102, 0.05413696788309608, 0.03728772571776062, 0.04534575367870275, 0.030293174968392123, 0.010094252047565533, 0.07316710747545585, 0.09766739865881391, 0.1022035165806301, 0.030930308748793323, 0.07509689923608676, 0.04254575294908136, 0.045927500977995805, 0.046515760623151436, 0.14656389481388032, 0.062311030633281916, 0.07097009060089476, 0.023367527064692695, 0.07624335412401706, 0.06777041737223044, 0.053469547056010924, 0.004842744583584135, 0.017443075339542702, 0.01652957875194261, 0.01892919452075148, 0.15634905255865306, 0.13407657737843692, 0.046315621948451735, 0.015239186177495867, 0.11429925463744439, 0.0392601946805371, 0.04978358527296223, 0.357086492003873, 0.1759572175797075, 0.17310443159658462, 0.2805684244958684, 0.34018185222521424, 1.2866039550863206, 0.3442718577571213, 0.19782350049354136, 0.25029435055330396, 0.07162931811762974, 0.1774743603891693, 0.19202777242753655, 0.263008646434173, 0.2703210571780801, 0.16283183125779033, 0.3015831077937037, 0.6588992499746382, 0.20604474528227001, 0.06613886507693678, 0.29414652090054005, 0.09675431952928193, 0.11579218858969398, 0.09648411098169163, 0.10446122629218735, 0.23699659301200882, 0.215850297245197, 0.13334042625501752, 0.23844519106205553, 0.16884523123735562, 0.2183909952873364, 0.12259536728379317, 0.13785701827146113, 0.10594464591122232, 0.08975725475465879, 0.10729816742241383, 0.26033082918729633, 0.13739439309574664, 0.1424219092587009, 0.24403901043115184, 0.11066877210396342, 0.1358795361011289, 0.24553897994337603, 0.14458434947300702, 0.1516272863955237, 0.2003409544704482, 0.20717392297228798, 0.10270858518197201, 0.3013175376690924, 0.5188745073974133, 0.21946152846794575, 0.4818525299197063, 8.261042665690184, 52.634255066514015, 84.37824189662933, 90.9082219004631, 66.29080206155777, 47.35486775636673, 51.374911442399025, 61.91620700061321, 79.48199182748795, 37.24720112979412, 4.59309758618474, 1.907442903611809, 1.8115612235851586, 4.603246366605163, 8.42618465423584, 5.646340744569898, 0.37328635866288096, 0.26130381447728723, 0.19963474158430472, 0.6728268088772893, 0.3690825670491904, 0.3153329074848443, 0.2490737847983837, 0.24705667194211856, 0.14105031645158306, 0.27883705333806574, 0.5928803456481546, 0.3190088539849967, 0.3084665274946019, 0.21006338589359075, 0.20537544682156295, 0.2865426242351532, 0.43443564616609365, 1.563777825795114, 2.1201845817267895, 1.5720891673117876, 1.0843259654939175, 0.38107383297756314, 0.3196270629996434, 0.29732475348282605, 0.3827510273549706, 0.5883442203048617, 12.26844822987914, 27.704068310558796, 59.24985587596893, 55.73241502046585, 52.39195726811886, 65.22384211421013, 38.853929713368416, 46.717436760663986, 18.040312863886356, 5.451924176886678, 1.5440526092424989, 1.0525377024896443, 0.21770992636447772, 0.3633863164577633, 0.09744060575030744, 0.18295056419447064, 0.4625443113036454, 0.21299532934790477, 0.5097935884259641, 0.24852545640897006, 0.3075514594092965, 0.9290379763115197, 1.3036107737571, 6.185562685132027, 33.98903176188469, 34.174192026257515, 7.630492625758052, 5.628389557823539, 1.272442233748734, 2.126261880621314, 25.329596623778343, 58.4598820656538, 55.22154003381729, 42.622894272208214, 40.13815060257912, 67.63067856431007, 80.61433106660843, 54.79873672127724, 17.951916307210922, 0.25107529771048576, 0.4496516031213105, 0.3463902440853417, 0.170475076592993, 0.1824894530000165, 0.16434379387646914, 0.15407094120746478, 0.20503560255747288, 0.20035829104017466, 0.13663945079315454, 0.13571022253017873, 0.10099046878167428, 0.2032013252028264, 0.18149399547837675, 0.20030365412821993, 0.14339913963340223, 0.2143953018821776, 0.06991926144110039, 0.21417273179395124, 0.18967991403769702, 0.21713783440645784, 0.1480859803268686, 0.16178952937480062, 0.1323778458754532, 0.1573424765956588, 0.18705337919527665, 0.23183133424026892, 0.17779749148758128, 0.14999275066656992, 0.10098194150486961, 0.13805545371724293, 0.13649902160977945, 0.35367112839594483, 0.10538915579672903, 0.21480714931385592, 0.24361141462577507, 0.16618696216028184, 0.24963986536022276, 0.21986767620546743, 0.20373739331262186, 0.1795718478388153, 0.26863706472795457, 0.1574631646508351, 0.13420885778032243], [0.09657644899562001, 0.1008845197793562, 0.009380821775266668, 0.03516023694828618, 0.04388274312077556, 0.07442705900757574, 0.06552913881023414, 0.06643455897574313, 0.08657698126626201, 0.049875652402988635, 0.03347459321958013, 0.020327753263700288, 0.06043092937034089, 0.0923166326538194, 0.01725294267089339, 0.03612665423133876, 0.037384401584859006, 0.05920980700466316, 0.002714461716095684, 0.03281712830357719, 0.07917862239992246, 0.03230835638532881, 0.01859209620306501, 0.059583645343082026, 0.016616538050584495, 0.05013396803406067, 0.07854338851757348, 0.019640051395981573, 0.033338932335027494, 0.14657137566246092, 0.01853377638326492, 0.02962290614959784, 0.038703732352587394, 0.052947089934605174, 0.029300537607923616, 0.0070233544283837546, 0.03156170387228485, 0.049953422058024444, 0.012631504669116111, 0.03849500331853051, 0.06038573628757149, 0.01872624496172648, 0.05934333421464544, 0.012378026913211215, 0.05260074816760607, 0.028145778087491635, 0.01782641873433022, 0.026708427285484504, 0.07122009788872674, 0.013600432266684948, 0.05186828180740122, 0.4894208925543353, 0.29276057495735586, 10.352603383362293, 42.55284123122692, 69.09237653017044, 61.947878301143646, 52.65337944030762, 33.165577948093414, 29.59530282765627, 49.65605467557907, 63.49321737885475, 35.94417504966259, 6.599640240892768, 0.6650876335334033, 0.8067501476034522, 1.535009688232094, 0.9317790542263538, 1.2745008920319378, 0.9719233063515276, 0.9522607864346355, 0.24847132415743545, 0.36956879252102226, 0.11756697538658045, 0.30232754128519446, 0.02345395572774578, 0.9967273660004139, 0.5004101106896996, 0.2511377271730453, 1.2625206098891795, 0.5115560407284647, 0.5446871754247695, 1.255234619602561, 0.8801406563725322, 3.64858559332788, 6.902409894391894, 5.475780721753836, 2.5805094558745623, 1.892556727398187, 0.3754850453697145, 0.3402294684201479, 0.25587734940927476, 0.1440559551701881, 0.02563498117524432, 0.031031014477775898, 0.42979918245691806, 2.427439894527197, 1.7904638056643307, 0.39355583663564175, 0.26434991508722305, 0.15506144118262455, 0.061427039981936105, 0.06285121766268276, 0.18146867339964956, 0.3130102524301037, 0.7517556985840201, 1.1593841691501439, 1.133934441022575, 0.083161009097239, 0.04763491560879629, 0.12313155413721688, 0.23641491250600666, 0.3132410900434479, 0.18602828029543161, 1.3884254288859665, 3.0796718085184693, 7.230933615937829, 2.294571711681783, 0.35925071337260306, 1.368380554486066, 2.3632981488481164, 22.12827790528536, 52.2356678545475, 49.56538014113903, 20.813098177313805, 28.226468078792095, 43.60489457845688, 64.83554095029831, 46.254940778017044, 12.881827466189861, 0.7584499893710017, 0.25164280319586396, 0.020569177613651846, 0.09829984948737547, 0.05009635227906983, 0.018983389854838606, 0.05515987373655662, 0.07707749100518413, 0.09088120772503316, 0.10006302909459919, 0.05105986776470672, 0.005350919536795118, 0.052363479844643734, 0.06976243821554817, 0.024923567689256743, 0.038776054643676616, 0.07449178912793286, 0.030439862312050536, 0.03645693221187685, 0.033632448030402884, 0.0875444152916316, 0.069626142794732, 0.06440764977014624, 0.053604224594892, 0.03289184773166198, 0.021241504036879633, 0.03138470165140461, 0.03341886906127911, 0.058096756183658727, 0.04241385846398771, 0.01508954044766142, 0.041420412162551656, 0.04971850634319708, 0.009246261124644661, 0.0066882636201626156, 0.03599457420932595, 0.06135120362159796, 0.07910181753686629, 0.01187402885989286, 0.13305110740475357, 0.07484961563022807, 0.011985748988081468, 0.04499496273638215, 0.0849608879070729, 0.06623552981182002, 0.09742079782881774, 0.08111743125482462, 0.06116178527008742, 0.03680542991787661, 0.1543793480959721, 0.02109533619659487, 0.35001183568965644, 0.07693079809541814, 0.0650971569120884, 0.01735239231493324, 0.034778554108925164, 0.10611254198011011, 0.03208855450793635, 0.030188704695319757, 0.14363376219989732, 0.07619612384587526, 0.06459422569605522, 0.05336302288924344, 0.023620736719749402, 0.028202812136441935, 0.06519310918520205, 0.017861947198980488, 0.05185245179745834, 0.02197164747485658, 0.028848538131569512, 0.09901758792693727, 0.05425119183200877, 0.03250198271416593, 0.06237595371203497, 0.08113047821098007, 0.06494315384770744, 0.03297044488135725, 0.06786190933780745, 0.03171687581925653, 0.027754291477322113, 0.03130462391709443, 0.052596944660763256, 0.05185164656722918, 0.07173654361395165, 0.054531170753762126, 0.02138539533916628, 0.03302671822893899, 0.0407765842101071, 0.057687769731273875, 0.05598818104772363, 0.049126584199257195, 0.12189011176815256, 0.08159432793036103, 0.049171087084687315, 0.03868091131153051, 0.06808367048506625, 0.03322700162243564, 0.4879536962835118, 1.0117242112755775, 16.63664348423481, 57.90951579809189, 78.37810546159744, 60.06152272224426, 42.736876755952835, 32.86169685423374, 40.630357190966606, 78.11684668064117, 74.10383641719818, 22.949727326631546, 0.9399949258659035, 0.7953760516829789, 0.6509848090354353, 0.9489189845044166, 1.14588076248765, 0.5960385699290782, 0.901098313042894, 0.5655763763934374, 0.6069368601310998, 0.9101829724386334, 0.2882089832564816, 0.4554171406198293, 1.0829359525814652, 1.274019624106586, 2.037640423513949, 2.1966875391080976, 5.13718469068408, 2.956396685913205, 2.207841365598142, 4.348005037754774, 3.878539754077792, 8.121959678828716, 7.893584333360195, 6.60812946036458, 6.236816709861159, 6.063980609178543, 1.6038542753085494, 1.7794612585566938, 0.8647768932860345, 0.5477839498780668, 0.13532123324694112, 0.09039508615387604, 1.662685687188059, 7.799460534006357, 6.58896186389029, 3.687565801665187, 1.260266499593854, 0.6397299317177385, 0.11678858121740632, 0.038531528116436675, 1.1338241281919181, 2.0676652248948812, 2.7846299903467298, 2.9379398887977004, 3.248425265774131, 0.6421561015304178, 1.1814846144989133, 0.7550448970869184, 0.7102042157202959, 1.469996958039701, 1.8138446635566652, 1.7333811311982572, 0.6410417519509792, 2.5595922907814384, 1.5382348839193583, 0.10405382432509214, 1.5100719826295972, 1.4770872588269413, 15.007488504052162, 55.27424320578575, 70.45337989926338, 36.011667028069496, 27.317079976201057, 36.029784455895424, 65.36469295620918, 59.80876788496971, 20.213239565491676, 1.9910555169917643, 0.2246216218918562, 0.022675233158224728, 0.07397262714221142, 0.04136629475397058, 0.08193941175704822, 0.07696713364566676, 0.030374794514500536, 0.033467724642832763, 0.02620828654471552, 0.05535189702641219, 0.09299756799009629, 0.013588454930868465, 0.025551274338795338, 0.06165955484902952, 0.06883332127472386, 0.05332121771061793, 0.02499256701412378, 0.0462028674519388, 0.015055556577863172, 0.0592957365734037, 0.09042106874403544, 0.05418623906734865, 0.02650736649229657, 0.03705856535816565, 0.03568375905160792, 0.008291411140817218, 0.024553545845265035, 0.03016826038219733, 0.08543741350877099, 0.0037610490380757255, 0.043955622022622265, 0.03467338807240594, 0.02565908984252019, 0.05211896444961894, 0.06293507292866707, 0.02949791549326619, 0.060459438973339275, 0.011426248493080493, 0.02417211904685246, 0.009848459230852313, 0.0199541635447531, 0.0697206478798762, 0.044984424239373766, 0.04338375641964376, 0.026315714276279323, 0.18402400659397244, 0.2129778146627359, 0.15411169995786622, 0.14675761020043865, 0.12315012267208658, 0.2483425912214443, 0.09524952605715953, 0.16927166929235682, 0.15629582572728395, 0.14914506959030405, 0.14958201645640656, 0.11594713418162428, 0.09977161738788709, 0.1795902382582426, 0.09283452556701377, 0.12481997720897198, 0.1436988337081857, 0.12973816017620265, 0.15035520074889064, 0.12231888016685843, 0.13365171267651021, 0.11044191240216605, 0.2125032409094274, 0.1479035901138559, 0.12418498081387952, 0.10520154086407274, 0.1293235074263066, 0.14349095814395696, 0.14353600650792941, 0.32762233866378665, 0.10887613665545359, 0.1889257732545957, 0.07201680084108375, 0.10168803564738482, 0.12968748633284122, 0.16341921145794913, 0.1385233481414616, 0.24926997895818204, 0.09262604886316694, 0.16144836408784613, 0.1269003507331945, 0.10673411292373203, 0.08166332539985888, 0.200911428546533, 0.1410678162937984, 0.20683894719695672, 0.14101855253102258, 0.19277964223874733, 0.14069035998545587, 0.11196242456207983, 0.38018215738702565, 0.6591541925445199, 0.7668075221590698, 17.90360949933529, 67.5967387855053, 93.74918505549431, 79.8025730252266, 70.15619784593582, 51.27040944993496, 46.15357741713524, 69.28140118718147, 80.98500117659569, 46.158745139837265, 9.5725023932755, 0.6521584116853774, 1.2666417262516916, 3.559107519686222, 4.166670693084598, 4.406146667897701, 3.2614635536447167, 1.975046619772911, 1.5111177577637136, 0.8809066121466458, 0.42109996487852186, 0.8553351124282926, 1.1359989177435637, 3.2644613552838564, 2.537142620421946, 3.1065508536994457, 3.4975296864286065, 4.331785133108497, 3.4488001512363553, 6.498755179345608, 4.993483051657677, 13.600180819630623, 16.514723226428032, 16.252531595528126, 8.936874400824308, 5.748702501878142, 1.3199395663104951, 0.9253683825954795, 0.943172505358234, 0.4683186952024698, 0.11056408475269563, 0.15735785389551893, 1.3227651896886528, 3.787918179295957, 3.144594649784267, 1.4021875779144466, 0.6494827021379024, 0.3252065589185804, 0.16225095227127895, 0.12585332879098132, 0.5541966995224357, 0.8640398515854031, 1.434481570031494, 2.729134443216026, 2.822912223637104, 0.6858613563235849, 0.3097660280764103, 0.242714514315594, 0.8303531748242676, 1.1203201278112829, 2.9945668252184987, 12.412225864827633, 12.12393058463931, 19.718542210757732, 11.48168619722128, 0.9768470108974725, 2.2943140380084515, 3.6020119674503803, 28.103164695203304, 65.45587286353111, 65.70723697543144, 35.750001668930054, 41.42060838639736, 57.23077341914177, 80.42484283447266, 66.87388077378273, 23.940784446895123, 1.5659561776556075, 0.5330542183946818, 0.08003752474905923, 0.21035795914940536, 0.1763457467313856, 0.12355505328741856, 0.21163060882827267, 0.15618319739587605, 0.31039795198012143, 0.2567231602733955, 0.12362265551928431, 0.11594449955737218, 0.1328741348697804, 0.15600705606630072, 0.12741590588120744, 0.17005825677188113, 0.16071065445430577, 0.11829009439679794, 0.1777920886524953, 0.11497095023514703, 0.20357386849354953, 0.0793133964180015, 0.12416080164257437, 0.14177871955325827, 0.12923528091050684, 0.10853514206246473, 0.08610202159616165, 0.09093400411074981, 0.15131882013520226, 0.1338023241260089, 0.23539230722235516, 0.21501014154637232, 0.14110382529906929, 0.08911222452297807, 0.15181834489339963, 0.16164641361683607, 0.16339255351340398, 0.1537470828043297, 0.0959561397030484, 0.17693789151962847, 0.141518997552339, 0.07239290644065477, 0.19301804975839332, 0.1574740296928212, 0.28666911588516086, 0.09820230901823379], [0.057794126914814115, 0.041444591333856806, 0.04059228296682704, 0.016338776295015123, 0.019249995275458787, 0.048805642436491325, 0.04362161846074741, 0.010734845163824502, 0.111113184975693, 0.05504714521521237, 0.11383038057829253, 0.055080181919038296, 0.02929361151473131, 0.023263691327883862, 0.05379673028073739, 0.0771316752070561, 0.013557105685322313, 0.023214832035591826, 0.027729474059015047, 0.023791284111212008, 0.04085211257915944, 0.022958776244195178, 0.02629331997013651, 0.029049125805613585, 0.04818837966013234, 0.0635438715107739, 0.05813637573737651, 0.033348205470247194, 0.04151636443566531, 0.00601928984906408, 0.0521299519459717, 0.052174143129377626, 0.015623950785084162, 0.06552351333084516, 0.05066570571216289, 0.05740251413953956, 0.034925480795209296, 0.048753554801805876, 0.06165233746287413, 0.10227766455500387, 0.027128265792271122, 0.037160862993914634, 0.05884179823624436, 0.025321305038232822, 0.03295440707006492, 0.04150119493715465, 0.05009356922528241, 0.05311405831889715, 0.09398860231158324, 0.022384066360245924, 0.07088970858603716, 0.15955740149365738, 0.03418898457312025, 0.3900624584639445, 0.7611169118899852, 27.49562479555607, 62.1737115830183, 62.69348569214344, 59.97078359127045, 44.03351537883282, 27.286765202879906, 28.25655296444893, 46.38710908591747, 63.943219631910324, 51.13762557506561, 20.25027047842741, 4.583039050921798, 0.11387515434762463, 1.2933369562961161, 1.2552564684301615, 1.1056277411989868, 0.9952559543307871, 1.6529745957814157, 0.6574647675734013, 1.2917195493355393, 1.944402689114213, 1.9320123852230608, 3.626694018021226, 2.7268821140751243, 13.793234210461378, 2.886430802755058, 2.870361227542162, 4.066315703094006, 4.0226527210325, 5.721649853512645, 4.0136828273534775, 3.295767637901008, 3.8857653038576245, 4.398096324875951, 1.8171699601225555, 2.00443163048476, 0.5539587372913957, 0.3200123267015442, 0.059258491892251186, 0.08106585941277444, 0.06643375745625235, 0.2513162582181394, 0.08725120758754201, 0.022989608769421466, 0.08071745076449588, 0.43283409147989005, 0.1556908863130957, 1.108397317584604, 2.4822859140112996, 3.399571180343628, 2.9216739116236567, 4.802082572132349, 3.295701378956437, 1.9787353905849159, 9.680834580212831, 3.195787165313959, 2.1657362999394536, 2.749040862545371, 1.873608569148928, 1.3422613497823477, 1.84620242100209, 0.7675942580681294, 0.1943979991483502, 3.6992060020565987, 31.590136885643005, 45.28226897120476, 42.31546796858311, 34.95321102440357, 25.81065461039543, 47.948240116238594, 61.116676703095436, 52.23478630185127, 18.782732225954533, 3.3997782692313194, 0.225377558672335, 0.08619304600870237, 0.1306112523889169, 0.06156684576126281, 0.011461302910902305, 0.05094093117804732, 0.08517758760717697, 0.03238276782212779, 0.03075979846471455, 0.05476180427649524, 0.016761744809628, 0.0559633339435095, 0.029099897983542178, 0.03738992687431164, 0.051009661474381573, 0.05900426549487747, 0.015767684380989522, 0.04275712031812873, 0.05331699489033781, 0.07224415778182447, 0.041594842841732316, 0.042648406815715134, 0.026828235895663965, 0.04726186023617629, 0.05040923431806732, 0.04874631515122019, 0.02930249316705158, 0.04047400318086147, 0.025331615324830636, 0.002618968878778105, 0.08227511483710259, 0.043102193012600765, 0.027877391512447502, 0.03251133377489168, 0.05755010133725591, 0.008660554467496695, 0.10793331966851838, 0.058922974349115975, 0.041212217474821955, 0.046430205838987604, 0.01683742717432324, 0.04963890358339995, 0.0392246717819944, 0.06862128226202913, 0.04725450555270072, 0.06019439948431682, 0.08926881768275052, 0.02450218737067189, 0.049563007851247676, 0.04829805424378719, 0.00022973417600269386, 0.026890939952863846, 0.05811105736938771, 0.0029624338958456065, 0.03750210991711356, 0.09885740277240984, 0.03591757638787385, 0.0150523412230541, 0.04973408031219151, 0.03237822216760833, 0.03757359358132817, 0.06381706349202432, 0.07330806358368136, 0.029703280742978677, 0.04520794056588784, 0.00737546546588419, 0.0026262866867909906, 0.041604906364227645, 0.07244789216201752, 0.046226374979596585, 0.020922276635246817, 0.022618640687142033, 0.03426061295613181, 0.02386529293289641, 0.0287519568882999, 0.036123329409747384, 0.005931175119258114, 0.10313959486666135, 0.05606772072496824, 0.05800291160994675, 0.04947068096953444, 0.061380344050121494, 0.0619075249414891, 0.0033271990150751662, 0.05797179706860334, 0.03122486530628521, 0.08671188887092285, 0.018197961981059052, 0.025925160916813184, 0.02379251607635524, 0.03644463111413643, 0.015857855323702097, 0.02609767128888052, 0.06883083508000709, 0.047777574945939705, 0.06913769830134697, 0.045937876202515326, 0.08094074815744534, 0.05535396019695327, 0.07436012470861897, 0.3142008651047945, 2.163863950408995, 37.47803874313831, 72.66103103756905, 72.57833987474442, 55.0762814283371, 36.49785093963146, 29.024970531463623, 48.08028303086758, 74.13174971938133, 78.3247259259224, 40.40856309235096, 7.527811210602522, 2.1082126116380095, 0.19463783159153536, 0.786593179218471, 0.45622005534823984, 0.19531444762833416, 0.8940035593695939, 1.6503957216627896, 1.0221013356931508, 0.8264446689281613, 0.17547688476042822, 0.46954944322351366, 0.9113736147992313, 0.9763099334668368, 2.36322405282408, 2.7903679199516773, 3.2512779626995325, 3.9849368948489428, 4.665656592696905, 6.550561599433422, 2.956657209433615, 3.583986684679985, 3.467337219044566, 4.4258813839405775, 3.0034949211403728, 1.8703604559414089, 0.7013781205751002, 1.2208493147045374, 1.3152573863044381, 0.47001058410387486, 0.35185167915187776, 0.5916540801990777, 0.17025734530761838, 0.7507382438052446, 0.5692723311949521, 1.6782761318609118, 1.7097954405471683, 2.5712222792208195, 1.6562254400923848, 2.7863812213763595, 3.5507641173899174, 3.852765499614179, 4.984963433817029, 1.725082613993436, 2.746936962939799, 2.367856716737151, 0.6942922133021057, 0.587544422596693, 1.984735862351954, 1.3987656240351498, 0.3909715299960226, 1.0929588647559285, 0.09295483512687497, 1.3764704391360283, 21.207285225391388, 63.16974833607674, 71.77314788103104, 49.9612694978714, 25.261990651488304, 37.670072838664055, 66.16201177239418, 64.78774711489677, 31.351834572851658, 5.977999772876501, 0.3747508832020685, 0.11658770410576835, 0.06274932820815593, 0.10449944689753465, 0.09548104644636624, 0.04334813333116472, 0.04890936499577947, 0.024265034080599435, 0.06522010109620169, 0.05349384868168272, 0.015273363005690044, 0.013470315225276863, 0.03285102589870803, 0.0367207545787096, 0.03861999211949296, 0.041360517134307884, 0.014074144201003946, 0.03421772795263678, 0.042101644357899204, 0.05352115229470655, 0.041551245376467705, 0.02580322790890932, 0.0029085233609293937, 0.013103693345328793, 0.04436223360244185, 0.08445727391517721, 0.06784186392906122, 0.03396614360099193, 0.019746518046304118, 0.03563999831385445, 0.04387361099361442, 0.04075515469594393, 0.05330505744495895, 0.02549768385506468, 0.0075515803564485395, 0.037141218344913796, 0.0779227378370706, 0.008156488693202846, 0.05432066798675805, 0.02721792465308681, 0.04179230236331932, 0.03447873757977504, 0.01241192079760367, 0.025110564783972222, 0.05734919453971088, 0.014889322919771075, 0.05153160651389044, 0.15119538613362238, 0.16511307447217405, 0.1291462974040769, 0.14061773341381922, 0.15697438619099557, 0.1279890665318817, 0.15319961530622095, 0.17285455047385767, 0.3011145751224831, 0.18837406067177653, 0.1655477800522931, 0.17643790662987158, 0.1224443550745491, 0.10002073409850709, 0.19593474949942902, 0.1674085223930888, 0.08138358767610043, 0.11927289830055088, 0.1144487973942887, 0.13672576256794855, 0.1203529755002819, 0.16101701301522553, 0.09594687770004384, 0.07186087561422028, 0.129444922786206, 0.15808408992597833, 0.13446126220514998, 0.14472100854618475, 0.07807036585290916, 0.15733158186776564, 0.39973350358195603, 0.1724993289099075, 0.1624784799059853, 0.15218187851132825, 0.10021226757089607, 0.17115158872911707, 0.14893193962052464, 0.1351151239941828, 0.11324092978611588, 0.22954868094529957, 0.10458702774485573, 0.17774144449504092, 0.2065462589962408, 0.12409314746037126, 0.13861990155419335, 0.18943849339848384, 0.17690348555333912, 0.15148445265367627, 0.19921896076994017, 0.13405995327048004, 0.29333888611290604, 0.2305399379110895, 0.14406897244043648, 0.6737552059348673, 1.9890916161239147, 39.80946063995361, 87.52058207988739, 87.58582457900047, 73.00805881619453, 59.70746532082558, 43.220628798007965, 45.65014623105526, 65.6363707780838, 79.97194513678551, 62.7988388389349, 26.021013222634792, 5.8332916628569365, 0.1069906511111185, 1.5642491192556918, 2.001880304887891, 2.79025012627244, 3.2952919509261847, 3.929618988186121, 3.1509514711797237, 5.448692450299859, 10.31626308336854, 9.263258837163448, 18.005761317908764, 12.780902981758118, 29.60844822227955, 15.2487413585186, 12.787722665816545, 19.346897453069687, 17.156560085713863, 19.40176460891962, 11.789366137236357, 7.975046262145042, 13.322714008390903, 12.055140025913715, 5.043428521603346, 6.6159233171492815, 1.544669244904071, 1.1710698483511806, 0.9208279231097549, 0.37949255376588553, 0.3211008198559284, 0.5407268379349262, 0.125914481759537, 0.4528738895896822, 0.31757502467371523, 1.052045391406864, 1.804473891388625, 3.2194874435663223, 8.506296705454588, 13.430006951093674, 15.483758747577667, 19.348044991493225, 18.201802298426628, 10.10163065046072, 22.533351369202137, 13.893667571246624, 10.865374468266964, 10.82658614963293, 8.805583845824003, 4.509171489626169, 3.931936863809824, 1.0365664470009506, 0.25457309908233583, 6.878422731533647, 41.67551390826702, 57.131872326135635, 57.049507945775986, 53.45361270010471, 38.44643957912922, 64.78275418281555, 80.40394395589828, 71.55057102441788, 34.81467425823212, 7.0398779679089785, 0.4628777434118092, 0.2118332448299043, 0.19367642380530015, 0.21734113834099844, 0.24892732937587425, 0.1962338201701641, 0.17289032199187204, 0.10853349449462257, 0.12749101122608408, 0.2141145771020092, 0.07614087095134892, 0.08497804636135697, 0.1133456319803372, 0.11433517458499409, 0.13811546377837658, 0.09999651781981811, 0.1447020095656626, 0.11384344237740152, 0.1303582839318551, 0.24724712187889963, 0.10933275043498725, 0.07745954120764509, 0.09759020045748912, 0.0919606837851461, 0.09983295589336194, 0.2393930175458081, 0.1142405359132681, 0.0999768880137708, 0.10138530618860386, 0.09379098322824575, 0.15431772015290335, 0.15783956710947677, 0.20784665015526116, 0.12923627538839355, 0.19079781108302996, 0.12507928360719234, 0.1802485529333353, 0.1090294643654488, 0.12435069496859796, 0.18099233333487064, 0.08273745057522319, 0.12418296217219904, 0.1868383790133521, 0.14804106554947793, 0.1657331536989659, 0.14370512712048367, 0.1285538705997169], [0.009560053222230636, 0.07082027324941009, 0.08014163322513923, 0.03957694330892991, 0.037478650629054755, 0.08220894495025277, 0.037154424862819724, 0.08829195838188753, 0.04743549681734294, 0.05199080296733882, 0.01053832538673305, 0.017135169400717132, 0.040754405126790516, 0.03526590393448714, 0.0612227193050785, 0.008335876918863505, 0.053947293490637094, 0.016329438221873716, 0.010449329820403364, 0.03214294651115779, 0.04636499703337904, 0.050106497437809594, 0.09690749138826504, 0.05223725536779966, 0.07178902829764411, 0.04900889070995618, 0.01706654114968842, 0.04296401995816268, 0.08761488963500597, 0.06760856238543056, 0.00636248073533352, 0.02293689216458006, 0.09314681388786994, 0.025229558887076564, 0.0076063374035584275, 0.09959828137652948, 0.002432230144222558, 0.12010858627036214, 0.03460996042122133, 0.027502182056196034, 0.018834930633602198, 0.041490448638796806, 0.06371400144416839, 0.03787992616707925, 0.03145312024571467, 0.03654713284049649, 0.045536474499385804, 0.05440788147097919, 0.028157043889223132, 0.02621615887619555, 0.0073597866685304325, 0.007149463408495649, 0.06712773974868469, 0.15450526087079197, 0.07450053904904053, 0.3561474080197513, 3.304270156659186, 32.88573056459427, 70.818350315094, 68.20865035057068, 61.22357256710529, 44.39775623381138, 22.785553336143494, 26.265663094818592, 36.720944568514824, 56.358313634991646, 55.99693402647972, 45.80685742199421, 35.09102202951908, 18.312009684741497, 7.584975343197584, 1.8999752355739474, 0.47576709708664566, 0.19000770582351834, 0.6008066015783697, 1.9542867899872363, 1.0228957305662334, 1.7254422884434462, 1.8294125469401479, 0.9710019745398313, 1.5854127961210907, 0.4748105281032622, 1.2674928805790842, 0.9727445966564119, 2.262076330371201, 4.434117916971445, 6.979805091395974, 3.8343205768615007, 3.5087818326428533, 4.0141236037015915, 2.915688520297408, 1.0158924688585103, 2.856582929380238, 2.2662259452044964, 0.7852494763210416, 0.5791184934787452, 1.312267065513879, 1.8463835050351918, 0.39438018458895385, 2.5886220205575228, 2.565475325100124, 3.3796253381296992, 2.4742217967286706, 0.6464849004987627, 2.2214301489293575, 2.254878329113126, 0.09764665563125163, 1.5300402673892677, 1.4097668649628758, 1.2841407372616231, 2.1131637459620833, 1.1155720450915396, 0.5621633876580745, 0.09257202793378383, 2.233866169117391, 12.268954552710056, 22.305346503853798, 52.31709748506546, 76.29082426428795, 33.021026104688644, 12.621941361576319, 22.77531858533621, 37.281847670674324, 63.27181085944176, 55.73158286511898, 29.913121573626995, 5.202000187709928, 0.08868001255905256, 0.10882788963499479, 0.08381816602195613, 0.0778869514761027, 0.042555682884994894, 0.05850521571119316, 0.04277835687389597, 0.045710125923505984, 0.06577619235031307, 0.09516259087831713, 0.04012256657006219, 0.03380275236850139, 0.02097432345181005, 0.05111665690492373, 0.06790907282265835, 0.02625991590321064, 0.059777342175948434, 0.08340993284946308, 0.018894267195719294, 0.08835613931296393, 0.027921898108616006, 0.06576184663572349, 0.016543414240004495, 0.03933492895157542, 0.002914883566518256, 0.01661242284171749, 0.03305735779576935, 0.027010368212359026, 0.010809869800141314, 0.026785933478095103, 0.11228530333028175, 0.06663033753284253, 0.05828199253301136, 0.049841098007163964, 0.0776648786268197, 0.023794633052602876, 0.028990139908273704, 0.011006830227415776, 0.02578589876065962, 0.017432382846891414, 0.0759817915968597, 0.030354058908415027, 0.014956252580304863, 0.06257888657273725, 0.006885945786052616, 0.012701158939307788, 0.018501615413697436, 0.09431243102881126, 0.08311407567816786, 0.04827875840419438, 0.043840923099196516, 0.0263874706797651, 0.017569900956004858, 0.05333102148142643, 0.026073443877976388, 0.07185654147178866, 0.025026473886100575, 0.014491521560557885, 0.058687550263130106, 0.030132882202451583, 0.03463458859187085, 0.012531113425211515, 0.07697101507801563, 0.02254387116408907, 0.004184469798929058, 0.059552842503762804, 0.02932638475613203, 0.03462779422989115, 0.03860849254124332, 0.011269862206972903, 0.02750314313743729, 0.05597130460955668, 0.06370300281560048, 0.04815171385416761, 0.025725487939780578, 0.026359773728472646, 0.05158493353519589, 0.012656782218982698, 0.06185449848999269, 0.02636066059494624, 0.028401178933563642, 0.039758494895068, 0.021901572035858408, 0.016430173636763357, 0.023197178197733592, 0.06181908320286311, 0.043141519417986274, 0.017700329699437134, 0.027482745208544657, 0.0480151846568333, 0.1048250641906634, 0.01297566081120749, 0.05315348862495739, 0.07159528322517872, 0.021257295084069483, 0.05369893005990889, 0.028865820895589422, 0.09253453463315964, 0.0434009000309743, 0.00785833086411003, 0.08696450109709986, 0.04543345326965209, 0.13052563823293895, 0.10943004599539563, 0.1504470341023989, 8.399337194859982, 47.45862118899822, 80.84898367524147, 70.97956046462059, 49.90439794957638, 32.665524780750275, 25.16886904835701, 43.849696442484856, 67.8042608499527, 86.47148117423058, 70.16854718327522, 39.24339361488819, 17.813113555312157, 5.292736943811178, 0.9296396502759308, 1.2064809794537723, 1.212369475979358, 0.3804722777567804, 0.8917854877654463, 0.5072052148170769, 0.32027964829467237, 0.456600509933196, 1.2114309263415635, 1.3614505575969815, 1.5476444852538407, 2.174712843261659, 1.2199238268658519, 2.334161549806595, 1.92186075495556, 2.02762131113559, 1.4144489262253046, 0.5097810016013682, 0.9512313979212195, 2.922918344847858, 3.5001156851649284, 0.8531789062544703, 1.7926165089011192, 1.4793446939438581, 1.540817676577717, 0.6736613984685391, 1.3299660407938063, 1.4113049511797726, 1.5796172758564353, 0.3983974299626425, 0.7364937581587583, 1.7636701371520758, 2.045732089318335, 1.5758599899709225, 1.250515510328114, 2.2686416655778885, 1.6473399731330574, 2.178152371197939, 1.1893564858473837, 0.511993314139545, 0.9028961509466171, 0.5862197780515999, 0.8247081027366221, 0.6684473063796759, 1.698085656389594, 3.3688315423205495, 20.71479745209217, 34.44417893886566, 65.09472504258156, 62.317442670464516, 25.278738252818584, 19.82752226293087, 35.8622058480978, 63.149442225694656, 72.45084151625633, 40.07361866533756, 8.153446689248085, 0.023066495268722065, 0.3670306771527976, 0.05330066764145158, 0.06527381774503738, 0.04766088335600216, 0.004193222039248212, 0.07270013331435621, 0.019176227651769295, 0.0663019742933102, 0.01184444499813253, 0.01437042996258242, 0.07905993072199635, 0.043668511061696336, 0.02996725896082353, 0.05402569026045967, 0.048153751049540006, 0.03694221886689775, 0.0507756103615975, 0.029651053955603857, 0.0466950820555212, 0.023360870000033174, 0.026751221375889145, 0.04101728496607393, 0.08874443839886226, 0.04621450061677024, 0.04153553782089148, 0.006376402961905114, 0.06812793959397823, 0.03785399552725721, 0.05716331994335633, 0.04679513098380994, 0.07411514918203466, 0.03827462627668865, 0.035108906304230914, 0.06728903812472709, 0.06703411781927571, 0.009274268850276712, 0.075460826192284, 0.050560558229335584, 0.03872097615385428, 0.05781797954114154, 0.017587729198567104, 0.008524677432433236, 0.020819383425987326, 0.03966178934206255, 0.08012102378415875, 0.02058537498669466, 0.12486190855270252, 0.03349900245666504, 0.08737807773286477, 0.10232115440885536, 0.12021503993310034, 0.04222859985020477, 0.20538144337479025, 0.11992091938736849, 0.2035577193601057, 0.34445074503310025, 0.11120413517346606, 0.13296579010784626, 0.1604357481119223, 0.11055345719796605, 0.22402692411560565, 0.1777025856426917, 0.18310812214622274, 0.10239614843158051, 0.21758635877631605, 0.1012921221263241, 0.07778812709148042, 0.1741223019780591, 0.13713976222788915, 0.10576952874544077, 0.2674541110172868, 0.17316212615696713, 0.17999415955273435, 0.11452670063590631, 0.11471189616713673, 0.22799588536145166, 0.11777504390920512, 0.1598849706351757, 0.12920290842885152, 0.11546690526301973, 0.1946612834581174, 0.11109567029052414, 0.1614450095803477, 0.10563236501184292, 0.19335189746925607, 0.2263738919282332, 0.07569613895611838, 0.11295275384327397, 0.15557852515485138, 0.1619450538419187, 0.1201063375629019, 0.120267391030211, 0.10774631329695694, 0.1509802375221625, 0.16979172185529023, 0.13100481330184266, 0.11151777420309372, 0.11221410910366103, 0.15029137604869902, 0.16968822194030508, 0.17300781881203875, 0.27455441595520824, 0.26743134192656726, 0.4645149508723989, 7.53486885689199, 53.87189045548439, 95.31331792473793, 86.08164489269257, 74.41731199622154, 59.42788392305374, 39.63885739445686, 41.040096804499626, 55.59894718229771, 77.42678090929985, 70.40827631950378, 60.527525916695595, 45.225549414753914, 23.021948151290417, 10.640361942350864, 2.914068619720638, 1.0405321279540658, 0.2858896827092394, 1.1485172272659838, 3.551310575567186, 1.968586491420865, 3.728759391233325, 4.20802054926753, 3.92762029543519, 6.691571557894349, 6.352354735136032, 6.870591826736927, 8.627616595476866, 10.373654253780842, 18.556908443570137, 22.194158770143986, 16.407219395041466, 17.948684580624104, 17.84026689827442, 15.65306056290865, 12.025432270020247, 15.293056480586529, 10.565524958074093, 5.7325405441224575, 5.322694536298513, 8.862273003906012, 8.459575362503529, 6.93800400942564, 9.789734836667776, 10.251925885677338, 16.709115095436573, 9.441116843372583, 10.031036138534546, 10.371660310775042, 11.491513419896364, 3.36487025488168, 6.776758236810565, 3.9719339925795794, 4.798401994630694, 5.044909492135048, 1.9576409412547946, 1.1758041568100452, 0.4635210370179266, 3.4720750898122787, 17.003109119832516, 29.625201523303986, 62.244399189949036, 86.8838806450367, 47.36361488699913, 21.90297469496727, 36.25939093530178, 51.941259652376175, 79.69953015446663, 80.55118605494499, 44.44173887372017, 9.12967225536704, 0.2872413117438555, 0.5557773553300649, 0.13729093770962209, 0.16089271812234074, 0.29881673748604953, 0.12127482681535184, 0.21107543783728033, 0.14074357197387144, 0.1424200538895093, 0.1597393909469247, 0.11782248941017315, 0.1071628590580076, 0.07225540874060243, 0.15925980027532205, 0.15816526603884995, 0.10553265005000867, 0.12448958048480563, 0.21253923507174477, 0.1252881981781684, 0.2684352599317208, 0.13790576253086329, 0.16866554244188592, 0.15633122617146, 0.18976750230649486, 0.14224463986465707, 0.1037057422217913, 0.1629169555963017, 0.16869732120539993, 0.10908801239565946, 0.12647006835322827, 0.24084050237433985, 0.16345428535714746, 0.11703563475748524, 0.2541123144328594, 0.1785033184569329, 0.17423558339942247, 0.14160104939946905, 0.27908920543268323, 0.14109429612290114, 0.11451772807049565, 0.11002279192325659, 0.07761634959024377, 0.07561532649560831, 0.12699395039817318, 0.07307676583877765, 0.12286918266909197, 0.11150223363074474, 0.21464726101839915, 0.10731796050095], [0.04123682709177956, 0.04713278962299228, 0.07739718595985323, 0.01874860216048546, 0.0594092517712852, 0.06353350370773114, 0.04298493739042897, 0.05732322679250501, 0.03131405661406461, 0.005043813725933433, 0.032966374201350845, 0.034779452107613906, 0.019400731034693308, 0.046988939138827845, 0.07827521345461719, 0.049448089994257316, 0.023033477118588053, 0.040839781795511954, 0.021217961257207207, 0.047251952564693056, 0.026431483747728635, 0.02188038928579772, 0.02336224111786578, 0.012565307879413012, 0.03470010167802684, 0.09021976118674502, 0.05246158063528128, 0.029397940779745113, 0.02671760208613705, 0.09108854152145796, 0.02771523595583858, 0.07606368017150089, 0.03014249487023335, 0.031247593578882515, 0.029170196066843346, 0.03278635143942665, 0.035692794699571095, 0.013631841811729828, 0.055757766458555125, 0.03236474105506204, 0.043586299652815796, 0.03622405740316026, 0.08470828310237266, 0.0282933615744696, 0.04033792298287153, 0.08267277240520343, 0.03338984366564546, 0.04285733251890633, 0.03758136757824104, 0.057630943483673036, 0.10818031383678317, 0.04029184674436692, 0.041637590547907166, 0.11066273102187552, 0.01141508566433913, 0.14079954475164413, 0.2838012791471556, 0.21567794086877257, 16.89196888357401, 59.847993180155754, 71.12084448337555, 71.61483317613602, 56.882248520851135, 50.4940465092659, 29.526074342429638, 20.22698912769556, 19.86780010163784, 26.222877390682697, 27.546129785478115, 38.947013318538666, 54.33516539633274, 55.68309746682644, 49.03784304857254, 43.11000533401966, 35.64012296497822, 26.12531952559948, 16.924960613250732, 11.785076167434454, 7.591077815741301, 4.263982521370053, 2.396966004744172, 0.30119365837890655, 0.1493332485551946, 0.3402216610265896, 0.41218861180823296, 0.7603833731263876, 1.344661395996809, 1.1855209479108453, 1.2985546700656414, 1.2742157885804772, 1.273886631242931, 0.5924347601830959, 0.9944359702058136, 0.8184668188914657, 1.0718403104692698, 1.3451474136672914, 1.0553538263775408, 1.6584128164686263, 3.7100228341296315, 2.1705321175977588, 2.2600655257701874, 2.107728375121951, 0.6900034903082997, 0.8559904585126787, 1.052858429029584, 0.3140719688963145, 0.1606116074253805, 0.4578274581581354, 2.5341799668967724, 4.001244669780135, 10.434109009802341, 27.383097633719444, 37.42978893220425, 47.817135751247406, 54.632925018668175, 40.10584853589535, 21.71917475759983, 77.14363530278206, 50.52856765687466, 15.760136917233467, 52.42554746568203, 61.04462876915932, 58.57897147536278, 27.812466993927956, 6.479215202853084, 0.1273766314261593, 0.1859222719212994, 0.0328024745977018, 0.08496816095430404, 0.1161308676819317, 0.04599076906742994, 0.07440440866048448, 0.06991422967985272, 0.07463237416232005, 0.09920192998833954, 0.06349892704747617, 0.017736320151016116, 0.005828682669744012, 0.027703868108801544, 0.04739344301924575, 0.024791446849121712, 0.03323674973216839, 0.03504078456899151, 0.020474778284551576, 0.012024356437905226, 0.042097525438293815, 0.02449104216793785, 0.005099607924421434, 0.024051186082942877, 0.02524343890399905, 0.07152816338930279, 0.04824657517019659, 0.10264824857586063, 0.024809291790006682, 0.06024018999596592, 0.014353906972246477, 0.024533736068406142, 0.04347486617916729, 0.056358924630330876, 0.03782770123507362, 0.033029226688086055, 0.015244120531860972, 0.046745295767323114, 0.03498559846775606, 0.052646679687313735, 0.029571516133728437, 0.052177560719428584, 0.027232734209974296, 0.04194760418613441, 0.052662342714029364, 0.02984046674100682, 0.06124143998022191, 0.04488747006689664, 0.02614763638121076, 0.0449527679302264, 0.04392441100208089, 0.029953918856335804, 0.06910533324116841, 0.056530141810071655, 0.02849431290087523, 0.02015169357036939, 0.06991558781010099, 0.0701781596580986, 0.06873290869407356, 0.017345879969070666, 0.05331697262590751, 0.009603479993529618, 0.09066571030416526, 0.023292887417483144, 0.049818206462077796, 0.03416138410102576, 0.061796054360456765, 0.026330069267714862, 0.015389511900139041, 0.03894930901878979, 0.011237549097131705, 0.027716397416952532, 0.01013028795568971, 0.011155591873830417, 0.04085150772880297, 0.06116503216617275, 0.03339607399539091, 0.0377528556418838, 0.029095992431393825, 0.038141959958011284, 0.07079268762026913, 0.02603270924737444, 0.07286808133358136, 0.019031870651815552, 0.030462134163826704, 0.02033028027653927, 0.0602868488203967, 0.07867839260143228, 0.00759298013690568, 0.019996078190160915, 0.012615267405635677, 0.02602617649245076, 0.04047278234793339, 0.03966317715821788, 0.05488224000146147, 0.029296246138983406, 0.060808062844444066, 0.06963915264350362, 0.026774402358569205, 0.02542724661907414, 0.04894922945823055, 0.1436451615882106, 0.012933714624523418, 0.10542142437770963, 0.12934458442032337, 0.09237524005584419, 0.10485475751920603, 0.7425464177504182, 0.6568860111292452, 27.55797564983368, 74.28567185997963, 81.44834071397781, 74.77108061313629, 49.5163019746542, 34.23944592475891, 20.86633712053299, 29.337486661970615, 40.70766784250736, 56.61260358989239, 63.8384972512722, 69.19338271021843, 66.68085113167763, 60.29648691415787, 52.23682679235935, 33.34063455462456, 21.16092201322317, 10.6409927085042, 6.250256113708019, 2.8836852125823498, 1.3813215913251042, 1.8307866482064128, 1.5944001451134682, 0.9277272841427475, 0.25771713349968195, 0.5379754886962473, 1.2159912753850222, 0.7863735628779978, 0.06267817108891904, 0.3135446581291035, 0.6695084588136524, 0.8070753864012659, 1.703382572159171, 0.8363256824668497, 1.0514580854214728, 1.214261893182993, 1.200135201215744, 1.100730278994888, 0.9294775652233511, 0.8634591358713806, 0.39098940091207623, 0.4694032995030284, 0.2765430451836437, 0.8073759858962148, 1.454143258742988, 1.1396321165375412, 1.043915490154177, 0.8086449990514666, 0.5728812469169497, 0.8927015354856849, 2.0197376841679215, 1.2750906916335225, 3.4579445980489254, 10.218484830111265, 24.968146719038486, 49.410644844174385, 67.13459998369217, 71.20576992630959, 48.3399610966444, 105.4860408604145, 73.79484459757805, 13.326264917850494, 22.561838440597057, 53.01716811954975, 71.88768893480301, 42.31102220714092, 10.367490984499454, 0.30398867558687925, 0.298439726466313, 0.05203069711569697, 0.08130490517942235, 0.05180204883799888, 0.13780527573544532, 0.04951018920110073, 0.029046498602838255, 0.07309863693080842, 0.06582888483535498, 0.05920401083130855, 0.029022718335909303, 0.06422617239877582, 0.07615091220941395, 0.025115552016359288, 0.04391090391436592, 0.04373362709884532, 0.011964430796069792, 0.07968748337589204, 0.021149748608877417, 0.050401081825839356, 0.03325525889522396, 0.049366335006197914, 0.04755960988404695, 0.04216594032186549, 0.06885538532515056, 0.04619527157046832, 0.05215925564698409, 0.03979545013862662, 0.08285152609460056, 0.02870099175197538, 0.04126029751205351, 0.053570868767565116, 0.009150665082415799, 0.027526878875505645, 0.07628615378052928, 0.04216930967231747, 0.02350314156501554, 0.056088315322995186, 0.008865860345395049, 0.045560345679405145, 0.03689833938551601, 0.03689798315463122, 0.02515500644221902, 0.05558552511502057, 0.0727787712821737, 0.01484974325649091, 0.02761792184173828, 0.005567015778069617, 0.08282365844934247, 0.02526074393244926, 0.11712464052834548, 0.13292807416291907, 0.23333189747063443, 0.08344416070031002, 0.10531880761845969, 0.11854808719363064, 0.1652520045172423, 0.19831493584206328, 0.12224318110384047, 0.14430350594921038, 0.14191864407621324, 0.193233554600738, 0.14161948434775695, 0.11749998171580955, 0.17484129464719445, 0.1307935535442084, 0.089438376162434, 0.18421353626763448, 0.10225835387245752, 0.1556146825896576, 0.1477027204236947, 0.0736489320115652, 0.1379594049649313, 0.06430447640013881, 0.12748271401505917, 0.13832997414283454, 0.19448503822786734, 0.09635594207793474, 0.20082284579984844, 0.22436357714468613, 0.07517765232478268, 0.1604846556438133, 0.12818040704587474, 0.12305066004046239, 0.158197965065483, 0.14679655811050907, 0.09595163486665115, 0.11708571488270536, 0.13966594386147335, 0.13507495896192268, 0.18213504779851064, 0.1962300797458738, 0.19172724714735523, 0.26824675442185253, 0.19026303431019187, 0.2155615869560279, 0.12518183357315138, 0.15465245844097808, 0.2003372585750185, 0.18392874451819807, 0.26023417187388986, 0.28767419164068997, 0.15344704734161496, 0.29810519597958773, 0.11359581738361157, 0.4636505269445479, 0.7433860539458692, 0.6303059624042362, 26.17711264640093, 85.35222083330154, 98.37045148015022, 89.93279904127121, 69.74061414599419, 65.00534623861313, 44.477270767092705, 35.46614930033684, 32.86475948989391, 40.203518494963646, 46.75530552864075, 56.88331626355648, 71.08514919877052, 72.89053872227669, 65.18364027142525, 56.04563981294632, 47.49741330742836, 34.73126493394375, 21.894265562295914, 15.495468769222498, 11.001191530376673, 7.146600941196084, 3.6534740310162306, 0.5438034259714186, 0.2138280338840559, 0.456983576877974, 1.0701610380783677, 0.9056119958404452, 1.9948342954739928, 2.580041131004691, 2.6915178867056966, 2.7525331126526, 3.668097071349621, 2.378598740324378, 3.4608637914061546, 3.577301655896008, 5.530016636475921, 4.264140212908387, 6.135492771863937, 5.130706513300538, 9.206425286829472, 5.6134839076548815, 4.366418374702334, 3.90305342618376, 2.9194405814632773, 2.096832934767008, 1.2313894741237164, 0.7623929309193045, 0.38929139671381563, 0.6718266312964261, 3.5639292234554887, 6.328344773501158, 16.62186037749052, 35.28223156929016, 49.34686906635761, 60.664033591747284, 67.2743108868599, 52.27977968752384, 31.736128851771355, 86.97145834565163, 65.20588427782059, 28.680427819490433, 72.82705932855606, 82.68922492861748, 84.71807286143303, 47.76786379516125, 13.015764579176903, 0.4266685066977516, 0.46050494886003435, 0.18621849274495617, 0.26324886479415, 0.20366406912216917, 0.236308251041919, 0.22304561192868277, 0.13023658655583858, 0.20245775260264054, 0.1483821269357577, 0.1279676629928872, 0.15218481741612777, 0.1732423820067197, 0.10537881767959334, 0.1699194751563482, 0.14762166305445135, 0.1304372336016968, 0.09696235094452277, 0.19961969082942232, 0.09005112297018059, 0.28344662161543965, 0.12558830785565078, 0.1421596936415881, 0.09638728297431953, 0.11952400396694429, 0.1882052666042, 0.14263723598560318, 0.13784406037302688, 0.1509541881387122, 0.18846705177566037, 0.07726981857558712, 0.08498163093463518, 0.13587107561761513, 0.20125479059061036, 0.1429447968257591, 0.2439000507001765, 0.13000690669286996, 0.14666513859992847, 0.0764327724755276, 0.05631738662486896, 0.13872779498342425, 0.2332230837782845, 0.16723583947168663, 0.1367087970720604, 0.16078712535090744, 0.14132789452560246, 0.1410616416251287, 0.1474534923909232, 0.11105034733191133, 0.21715022827265784, 0.14436016150284559], [0.027594071070780046, 0.025192317916662432, 0.06816635315772146, 0.05979619643767364, 0.03663462834083475, 0.03285467355453875, 0.020388318080222234, 0.06968204135773703, 0.03421093730139546, 0.01503746394519112, 0.005947136860413593, 0.005884645706828451, 0.01541569858090952, 0.02904440389102092, 0.004419174929353176, 0.060091686245868914, 0.02561888213676866, 0.015146071691560792, 0.00732698559659184, 0.07319736483623274, 0.021515998487302568, 0.10131485410965979, 0.052025416734977625, 0.02249305631266907, 0.05801035164040513, 0.04172842571279034, 0.005382832814575522, 0.010500240223336732, 0.05973074272333179, 0.011938486240978818, 0.059152754402020946, 0.08953366792411543, 0.1114144004532136, 0.039980307992664166, 0.030734971769561525, 0.06450262240832672, 0.037233229813864455, 0.03642103823949583, 0.05121960391988978, 0.033068349002860487, 0.0235870970209362, 0.021418476571852807, 0.07484783447580412, 0.021217384237388615, 0.03414422564674169, 0.020801397477043793, 0.036649964822572656, 0.04195695524686016, 0.01830977766076103, 0.0275201160548022, 0.037912283805781044, 0.012210788572701858, 0.0262718978774501, 0.13686455902643502, 0.07525248307501897, 0.2250713633839041, 0.2059077299782075, 0.1483395425020717, 0.870974063873291, 0.5025621014647186, 17.997935637831688, 48.57041113078594, 72.52727061510086, 68.9660333096981, 69.18969690799713, 65.08928373456001, 49.36689779162407, 34.63425613939762, 21.125344522297382, 25.643410384655, 30.408449694514275, 22.378956153988838, 19.63295940309763, 23.098899722099304, 42.53743685781956, 51.40424966812134, 50.737579241395, 47.630649358034134, 47.98996947705746, 49.51233118772507, 41.68268032371998, 52.79672294855118, 40.49832947552204, 30.0958214700222, 26.72143343836069, 26.645897291600704, 19.770303033292294, 13.451112918555737, 9.415457770228386, 5.845475709065795, 4.9246687442064285, 4.046010542660952, 3.11935949139297, 2.5083066802471876, 2.242384124547243, 3.483286388218403, 3.7799241207540035, 6.517056422308087, 7.391570946201682, 7.2368693724274635, 9.91362813860178, 15.578211229294538, 16.11428741365671, 24.080791734158993, 33.572034537792206, 36.235239431262016, 41.527758836746216, 45.57493306696415, 43.922534734010696, 54.06971924006939, 56.11552186310291, 41.2180108577013, 33.141662031412125, 25.907574109733105, 28.48955076187849, 31.87831722199917, 37.30736330151558, 26.129940077662468, 38.787212893366814, 71.71440303325653, 62.97973953187466, 43.67153160274029, 9.281849339604378, 0.25863905902951956, 0.16681521985447034, 0.03984696631960105, 0.15559577266685665, 0.02793619187286822, 0.07836545119062066, 0.06416945747332647, 0.08487615690683015, 0.059938603444607, 0.05190985320950858, 0.12837694259360433, 0.017754486070771236, 0.02641556282469537, 0.035371185003896244, 0.03369321137142833, 0.06258836379856803, 0.04221012779453304, 0.024562677972426172, 0.0719122841837816, 0.03573848873202223, 0.03616508263803553, 0.02802915700158337, 0.017777175380615517, 0.04430322544067167, 0.03573016183509026, 0.010552362182352226, 0.05019547352276277, 0.08337141538504511, 0.06529938473249786, 0.10453212365973741, 0.010875333719013724, 0.09280535916332155, 0.07282376769580878, 0.039699186163488775, 0.03932121406251099, 0.058141281333519146, 0.03254056326113641, 0.05798123718705028, 0.041795645738602616, 0.021972927679598797, 0.046170751011231914, 0.0075339283739594975, 0.06642196472967044, 0.017680889141047373, 0.04894551129837055, 0.0628766807494685, 0.09017262738780119, 0.02927847355749691, 0.07694404543144628, 0.038900438594282605, 0.07583060869364999, 0.04871874436503276, 0.05425589333754033, 0.06302185225649737, 0.0675773253897205, 0.05096533670439385, 0.013571828967542388, 0.04441700039023999, 0.06046382135536987, 0.014144453416520264, 0.05079929600469768, 0.06157480900583323, 0.017686134269752074, 0.023427674423146527, 0.01206694829306798, 0.051405782796791755, 0.043204579706070945, 0.045843968546250835, 0.0939636884140782, 0.05376760469516739, 0.025415019736101385, 0.04815139473066665, 0.05488794711709488, 0.024424395451205783, 0.08349625946721062, 0.030396561705856584, 0.07419327506795526, 0.07952582134748809, 0.023350706287601497, 0.035441510917735286, 0.08083238717517816, 0.07791042560711503, 0.006670617203781148, 0.014743300725967856, 0.04555501334834844, 0.08948368427809328, 0.06850472796941176, 0.03600353935325984, 0.07993657782208174, 0.01959336474101292, 0.07531074166763574, 0.04248072968039196, 0.013056284024060005, 0.0390803945629159, 0.02518622302886797, 0.018138076229661237, 0.04527044795395341, 0.033532577217556536, 0.04493095249927137, 0.06537290930282325, 0.0541155606333632, 0.018819640536094084, 0.04017957835458219, 0.03362456271133851, 0.028138469788245857, 0.017633391689741984, 0.08315094557474367, 0.051239682725281455, 0.10440468206070364, 0.14813629793934524, 0.046730400863452815, 0.8472183917183429, 3.6813146620988846, 29.995432756841183, 65.7120855152607, 80.5049729347229, 74.95210289955139, 63.62052194774151, 43.94280664622784, 22.4166539311409, 20.2279219776392, 11.217815056443214, 25.726088248193264, 44.10447657108307, 43.51006306707859, 45.76511666178703, 55.453570783138275, 69.84792798757553, 79.00650814175606, 75.74624508619308, 70.22412300109863, 72.52473995089531, 64.64903175830841, 57.6179688423872, 55.9586700797081, 35.07793553173542, 29.461815990507603, 24.37863875180483, 14.77153541520238, 3.40875172521919, 1.7213339963927865, 0.8853462582919747, 2.1940699545666575, 2.8385526593774557, 2.1432695304974914, 1.9035101146437228, 1.433107943739742, 0.9296658332459629, 1.7582554277032614, 1.4421952748671174, 1.7465734295547009, 2.4572844430804253, 3.46580115146935, 3.6732446076348424, 5.781424921005964, 11.61513028666377, 11.676777228713036, 21.432700529694557, 30.485215075314045, 39.110248759388924, 49.88587774336338, 63.86797606945038, 66.52059853076935, 76.54631495475769, 82.55562409758568, 66.26581460237503, 52.375120371580124, 43.57905596494675, 34.45171773433685, 14.231489393860102, 34.80992071330547, 36.21291562914848, 59.71287243068218, 79.66727748513222, 57.89360225200653, 17.118271440267563, 0.918867050204426, 0.20762661821208894, 0.02171877920773113, 0.2119863498955965, 0.026627881998138037, 0.023333534845733084, 0.03336158268211875, 0.0612840689427685, 0.017117790157499257, 0.0376740877982229, 0.040252590843010694, 0.1194804695842322, 0.01944596864632331, 0.07328173218411393, 0.029106404763297178, 0.01943127041158732, 0.022690664263791405, 0.03208164882380515, 0.007996381464181468, 0.05491688716574572, 0.03741151223948691, 0.038121439574752, 0.06602904948522337, 0.05356859779567458, 0.044093457399867475, 0.05300457669363823, 0.020319708382885437, 0.04618665152520407, 0.013352928799577057, 0.04316687489335891, 0.07696871442021802, 0.066898252844112, 0.01010569039863185, 0.042622505861800164, 0.008478182808175916, 0.017253111509489827, 0.01327790323557565, 0.05403241411841009, 0.0333652897097636, 0.06844849543995224, 0.04018024628749117, 0.0442016773740761, 0.026221444823022466, 0.041789426541072316, 0.009186503393721068, 0.04154682217631489, 0.06823812625952996, 0.026808201619132888, 0.03290865737653803, 0.07282965292688459, 0.036867440066998824, 0.029263971991895232, 0.02447951104841195, 0.110454053938156, 0.15556791244307533, 0.12638464715564623, 0.13486496085533872, 0.14281677635153756, 0.21655711869243532, 0.07928610022645444, 0.20476832549320534, 0.1358620956307277, 0.13303101004566997, 0.14543979341397062, 0.174773269391153, 0.2017778265872039, 0.1295100833522156, 0.11260536193731241, 0.1756860813475214, 0.156748105364386, 0.08998524994240142, 0.15559143852442503, 0.20629248901968822, 0.164353426953312, 0.17133059474872425, 0.17380669625708833, 0.10311883699614555, 0.2671196102164686, 0.13467473356286064, 0.16867462632944807, 0.12674151628743857, 0.21132592752110213, 0.05119441913848277, 0.1549186371266842, 0.23871858342317864, 0.1435091852908954, 0.15367381798569113, 0.19842011301079765, 0.1894413580885157, 0.16539624833967537, 0.23721389385173097, 0.13970279891509563, 0.15824679838260636, 0.12177027718280442, 0.13139540562406182, 0.13002884457819164, 0.17058029829058796, 0.18202825274784118, 0.18057898676488549, 0.12848692887928337, 0.13704142766073346, 0.11765609247959219, 0.12983999768039212, 0.20144461712334305, 0.12306687596719712, 0.06027575371263083, 0.2934004249982536, 0.19282282039057463, 0.40902899228967726, 0.29840030358172953, 0.4317407892085612, 1.14414116833359, 2.6513644913211465, 31.31922472268343, 75.36156892776489, 96.37989789247513, 86.09034642577171, 87.47661083936691, 80.51358327269554, 62.03113563358784, 49.28561635315418, 31.95471592247486, 40.42277052998543, 46.75670765340328, 34.63160768151283, 30.277430824935436, 36.833992302417755, 59.76309433579445, 70.22792279720306, 69.1891573369503, 67.5006115436554, 65.8509148657322, 63.01813267171383, 57.587566673755646, 67.96791046857834, 57.63585828244686, 43.644028678536415, 40.231652185320854, 36.24627023935318, 26.650666035711765, 19.93158347904682, 14.34447443112731, 9.171241074800491, 7.770209703594446, 6.823604973033071, 4.770985990762711, 3.968234653584659, 4.357651770114899, 6.451177457347512, 6.73780795186758, 9.85917991027236, 11.635116264224052, 10.332927089184523, 13.862393349409103, 19.43512871861458, 23.054943680763245, 32.04535245895386, 43.65973323583603, 47.69927367568016, 54.36240613460541, 61.1882496625185, 60.909318029880524, 69.57390189170837, 70.06721422076225, 56.76882840692997, 43.870112746953964, 36.19832061231136, 40.176061168313026, 49.31817300617695, 51.40681453049183, 43.648770824074745, 53.00745204091072, 89.85311731696129, 90.58996617794037, 64.22573447227478, 22.12230272591114, 1.1144120385870337, 0.4673193785129115, 0.14831246895482764, 0.3994426113786176, 0.1345340965781361, 0.14752500574104488, 0.14852358028292656, 0.20184784079901874, 0.19437528942944482, 0.14198941527865827, 0.25378099002409726, 0.24655509885633364, 0.17145304911537096, 0.14055708510568365, 0.16123505600262433, 0.12619333632756025, 0.18670540099265054, 0.16952586971456185, 0.16653752303682268, 0.126780018908903, 0.09956863257684745, 0.11272862524492666, 0.12335649167653173, 0.21203052252531052, 0.15685228805523366, 0.16539127595024183, 0.13563505781348795, 0.1603823431651108, 0.12429956841515377, 0.20433782046893612, 0.11724387397407554, 0.17559168016305193, 0.14130396768450737, 0.1261296748998575, 0.12794719455996528, 0.23247807141160592, 0.17149459454230964, 0.21031120384577662, 0.10087058224598877, 0.12977461447007954, 0.17157214897451922, 0.21925340057350695, 0.18115568003850058, 0.1319105748552829, 0.15706103935372084, 0.09672403990407474, 0.2054699815926142, 0.08380556435440667, 0.1623800117522478, 0.1477233224431984, 0.18013760185567662, 0.12030669517116621, 0.0607256362127373], [0.019717971335921902, 0.0646904154564254, 0.016932950857153628, 0.01830912642617477, 0.04133376271056477, 0.022143883252283558, 0.05682172421074938, 0.011617567670327844, 0.03739348547242116, 0.09451589823584072, 0.04906552770989947, 0.08131902082823217, 0.023910903473733924, 0.033162505278596655, 0.014975395351939369, 0.05650088263791986, 0.011903897520824103, 0.03328128230350558, 0.04628190989024006, 0.05184879672015086, 0.05338904258678667, 0.026961534895235673, 0.021789967868244275, 0.024288365348184016, 0.06699911071336828, 0.06573627222678624, 0.026013333626906388, 0.039525145111838356, 0.03278731252066791, 0.08110181646770798, 0.02481739047652809, 0.05020402677473612, 0.08881860863766633, 0.03549842251231894, 0.014370359458553139, 0.0915143042220734, 0.08262520816060714, 0.07536372359027155, 0.0269289286370622, 0.014516140454361448, 0.0441099182353355, 0.03717112689628266, 0.03644814518338535, 0.060399744324968196, 0.042501379939494655, 0.03303575016616378, 0.03255640440329444, 0.10129046713700518, 0.046938376617617905, 0.07290763780474663, 0.05989238619804382, 0.046751377667533234, 0.02315325789822964, 0.07195696889539249, 0.046784829974058084, 0.11727582343155518, 0.04336176658398472, 0.04939267753798049, 0.28236507496330887, 0.061884993338026106, 0.34382033511064947, 0.24248821864603087, 12.125277612358332, 39.203453958034515, 55.86153969168663, 69.71137091517448, 76.59662425518036, 71.00957125425339, 75.97137540578842, 66.7674408853054, 55.98702795803547, 46.91572532057762, 45.70756494998932, 34.80702906847, 33.646328151226044, 28.52094277739525, 37.45687007904053, 42.25995674729347, 33.55651617050171, 35.75712628662586, 25.98309885710478, 16.28188882023096, 41.417823135852814, 45.21136477589607, 29.325912483036518, 29.325352013111115, 34.66035693883896, 36.08629882335663, 37.173431888222694, 41.151332035660744, 34.98589687049389, 30.04388775676489, 35.26153028011322, 48.84502239525318, 58.429829478263855, 51.11126258969307, 52.58887030184269, 41.77832879126072, 42.89701536297798, 59.0747232735157, 64.58969414234161, 49.83157865703106, 58.65739926695824, 55.794743075966835, 34.3792974203825, 35.83113111555576, 41.8752995878458, 39.690747410058975, 25.641217902302742, 37.85282403230667, 39.01938423514366, 34.30231735110283, 35.097371488809586, 57.88099452853203, 55.30646547675133, 70.38632109761238, 81.50314137339592, 83.4708733856678, 73.564812541008, 41.034435108304024, 15.860867612063885, 1.55825779074803, 0.39302086690440774, 0.029278573747433256, 0.06251208586036228, 0.053282574081094936, 0.04778090718900785, 0.07122614639229141, 0.05708613287424669, 0.03060852464841446, 0.04619575396645814, 0.08755470145842992, 0.03309480285679456, 0.022752897057216614, 0.027618522981356364, 0.03481631458271295, 0.05169113115698565, 0.012386129310471006, 0.010823091161000775, 0.029794073234370444, 0.11464476890978403, 0.07927188067696989, 0.058549084060359746, 0.06428631604649127, 0.045372945969575085, 0.02170589181332616, 0.01610986641026102, 0.048296061577275395, 0.04674180396250449, 0.01842188463342609, 0.032306185603374615, 0.02690154895390151, 0.016449280228698626, 0.0062280216661747545, 0.030830853538645897, 0.05390036378230434, 0.08188024032278918, 0.10636015213094652, 0.029556851295637898, 0.04996805721020792, 0.057217196153942496, 0.041333206099807285, 0.05229815600614529, 0.05520119651919231, 0.05278829259623308, 0.05767098977230489, 0.03627654950832948, 0.06567109681782313, 0.06644194334512576, 0.06328755596769042, 0.030152510153129697, 0.008579688201280078, 0.03064671742322389, 0.031429252776433714, 0.041007202889886685, 0.02856740145944059, 0.01447802003895049, 0.04813199870113749, 0.018953646431327797, 0.006559480125361006, 0.03434811587794684, 0.02384587649430614, 0.06902987908688374, 0.03201977597200312, 0.03289019274234306, 0.037814613460795954, 0.09244164000847377, 0.05582607744145207, 0.03831445734249428, 0.049097184019046836, 0.05772719632659573, 0.04393100127344951, 0.01680797133303713, 0.00988198111372185, 0.030231654636736494, 0.05816019867779687, 0.05121545531437732, 0.019563261375878938, 0.05364434880902991, 0.03887494582158979, 0.017753248539520428, 0.07437998458044603, 0.024585428509453777, 0.03377472145075444, 0.0492099533585133, 0.033890503909788094, 0.060210518931853585, 0.03398052642296534, 0.026983528441633098, 0.05507066016434692, 0.07226283763884567, 0.019085910134890582, 0.020183717242616694, 0.06918834988027811, 0.013296945817273809, 0.04397906275698915, 0.08968277281383052, 0.047328542204922996, 0.056740470172371715, 0.024029745436564554, 0.028326659885351546, 0.040947909001260996, 0.046175203897291794, 0.032926231433521025, 0.23231156315887347, 0.035834244336001575, 0.05225605396844912, 0.018956114072352648, 0.06315922379144467, 0.04893227880529594, 0.03467296133749187, 0.05895923197385855, 0.11677625414449722, 0.028987820696784183, 0.29214094101917, 0.25011682882905006, 0.34413527289871126, 2.8912679431959987, 25.867649652063847, 58.36666166782379, 68.71941894292831, 83.50299686193466, 78.3108338713646, 58.052118346095085, 58.19240301847458, 47.07205653190613, 38.69494244456291, 23.831086233258247, 14.455946199595928, 14.39506396651268, 26.595173813402653, 33.89253593981266, 36.70426346361637, 42.74863712489605, 41.60412333905697, 50.16906514763832, 41.02365508675575, 43.01078125834465, 62.1881166100502, 56.03998951613903, 55.85514463484287, 67.24064469337463, 72.67547026276588, 65.6782977283001, 63.62539328634739, 61.1343951523304, 62.336358055472374, 53.48087623715401, 55.26893109083176, 61.85989782214165, 60.0540067255497, 67.61847361922264, 64.25570726394653, 69.22029286623001, 65.11488676071167, 60.07588595151901, 66.31371483206749, 75.11762201786041, 68.28839287161827, 78.33933994174004, 64.45321306586266, 61.881761848926544, 63.09446297585964, 59.337813556194305, 35.397023409605026, 47.767320424318314, 44.26137775182724, 23.6851379647851, 19.5929304510355, 24.644966460764408, 33.712273612618446, 47.28600025177002, 60.965357422828674, 69.56102818250656, 82.4248731136322, 59.09642770886421, 24.229608848690987, 3.585721766576171, 0.5107310693711042, 0.048202910911641084, 0.09494500060100108, 0.08364130480913445, 0.07881729296059348, 0.06990367633989081, 0.033850843537948094, 0.051127566475770436, 0.05205876143008936, 0.09617652045562863, 0.02534884428314399, 0.05166096285392996, 0.08350850490387529, 0.012829939187213313, 0.035498474462656304, 0.030879024488967843, 0.053249110642354935, 0.03787361420108937, 0.052477893041213974, 0.02363380408496596, 0.02849958029401023, 0.09404854557942599, 0.029023766619502567, 0.031013260449981317, 0.002998384456986969, 0.013989054186822614, 0.03209524125850294, 0.01702138517430285, 0.0441042074089637, 0.03637180787336547, 0.07964434233144857, 0.03794526855926961, 0.04371929993794765, 0.04011623976111878, 0.016553923051105812, 0.1606244465801865, 0.029802645040035713, 0.05358331458410248, 0.012974738692719257, 0.0373146434139926, 0.06622322500334121, 0.03288528343546204, 0.03183685883414, 0.053600439641741104, 0.03449366588029079, 0.022469099785666913, 0.026860135258175433, 0.09000686128274538, 0.0481823905283818, 0.014735607437614817, 0.07331100248848088, 0.02458361952449195, 0.0406551243213471, 0.0548735346092144, 0.1531126504414715, 0.39105818315874785, 0.15605293563567102, 0.06027952753356658, 0.13732241961406544, 0.11993011459708214, 0.15536638966295868, 0.12706715584499761, 0.1279926288407296, 0.11964255463681184, 0.14809605869231746, 0.1770493175718002, 0.08234043125412427, 0.1803069599554874, 0.1452321553369984, 0.12932367069879547, 0.13439976784866303, 0.16161175532033667, 0.1939817878883332, 0.11297178250970319, 0.11750675752409734, 0.1497777207987383, 0.13601015409221873, 0.13327798194950446, 0.1864253738312982, 0.26878065546043217, 0.05743098663515411, 0.12667332775890827, 0.12174434654298238, 0.11492208723211661, 0.16977499384665862, 0.11465091389254667, 0.15720332390628755, 0.14103084249654785, 0.2533492381917313, 0.19001959502929822, 0.22964872245211154, 0.20260296121705323, 0.10710235175793059, 0.20832085283473134, 0.16826512408442795, 0.09287156615755521, 0.19207049044780433, 0.16653593484079465, 0.14403244393179193, 0.1233661247533746, 0.11832779549877159, 0.2749697811668739, 0.2546320256078616, 0.16390519944252446, 0.24804113083519042, 0.23119889083318412, 0.1372173018171452, 0.19447544967988506, 0.2001223326078616, 0.2880886662751436, 0.239382597792428, 0.20791595190530643, 0.47949196596164256, 0.4220805794466287, 0.49912880756892264, 1.8249424430541694, 23.653884641826153, 64.12474349141121, 82.60002091526985, 94.68075826764107, 99.5310840010643, 84.29326325654984, 93.76103281974792, 78.84228855371475, 70.63042759895325, 62.55450055003166, 63.25333625078201, 48.5880421847105, 50.24914585053921, 45.318663418293, 47.70961292088032, 55.95099829137325, 47.5061946362257, 47.42647111415863, 34.2731387168169, 25.856466852128506, 52.78148956596851, 56.37032859027386, 40.03741420805454, 45.6770183891058, 52.895540446043015, 54.67445679008961, 56.85644410550594, 61.783282533288, 53.95975314080715, 49.02534171938896, 55.701188296079636, 70.46424731612206, 78.51766437292099, 70.80435946583748, 71.2655483186245, 60.40479250252247, 58.192965388298035, 74.8589015007019, 82.76408851146698, 67.19848215579987, 72.01072633266449, 74.21935021877289, 50.8197346329689, 53.19642350077629, 57.38194450736046, 54.35835175216198, 32.10978180170059, 50.773757100105286, 53.87168146669865, 44.59395110607147, 53.43882769346237, 73.79791483283043, 76.56969889998436, 90.48655092716217, 100.55654257535934, 110.7873871922493, 102.63797968626022, 63.81056874990463, 29.72346805036068, 5.0306550320237875, 0.6754265225026757, 0.09522898340946995, 0.22772307187551633, 0.15917890617856756, 0.2916279388591647, 0.1533833859139122, 0.20097118627745658, 0.13459055917337537, 0.19164380006259307, 0.21659530961187556, 0.10837680485565215, 0.11202723631868139, 0.12773516296874732, 0.19337036210345104, 0.08609976546722464, 0.1425239397212863, 0.09869574816548266, 0.15031491697300225, 0.1739872311009094, 0.13653170579345897, 0.24051119660725817, 0.14195922471117228, 0.2373840831569396, 0.1729237037943676, 0.11261420091614127, 0.0854083732701838, 0.0941648698062636, 0.12873854662757367, 0.0656846261699684, 0.08628131705336273, 0.1707268724567257, 0.13614031195174903, 0.17361027945298702, 0.19099136319709942, 0.1168338670686353, 0.22680718742776662, 0.12005109208985232, 0.20594670757418498, 0.1569718332029879, 0.1517410427914001, 0.14837182592600584, 0.11095029840362258, 0.08067932663834654, 0.14805676939431578, 0.18245049024699256, 0.13916356925619766, 0.14662117377156392, 0.23992967937374488, 0.14073196478420869, 0.13888508576201275, 0.25678092904854566, 0.1297001473722048, 0.202703136310447, 0.20159577776212245], [0.05006186096579768, 0.0320582451968221, 0.041102119866991416, 0.07152992970077321, 0.05641362462483812, 0.03799159712798428, 0.03175570869643707, 0.11337451636791229, 0.022152119236125145, 0.027076135484094266, 0.03754925855901092, 0.0540610721509438, 0.06177956012834329, 0.01528657230664976, 0.014500102643069113, 0.03845709812594578, 0.028565926440933254, 0.016647060729155783, 0.06404425716027617, 0.03212786607036833, 0.03621142604970373, 0.026781922169902828, 0.04204916338494513, 0.024376786677748896, 0.07556985510746017, 0.04116802629141603, 0.023447274543286767, 0.020027766040584538, 0.018804732644639444, 0.05345947611203883, 0.05601866476354189, 0.021390646033978555, 0.06807894300436601, 0.04947087763866875, 0.00902718840734451, 0.034275838115718216, 0.02983601199957775, 0.03923844975361135, 0.03291309913038276, 0.01639734473428689, 0.03161014385113958, 0.08391233714064583, 0.038066669076215476, 0.03021142925717868, 0.011580626342038158, 0.0544645370246144, 0.023340384868788533, 0.02507917564798845, 0.08844494470395148, 0.022492922726087272, 0.017574591329321265, 0.03951633952965494, 0.009158271168416832, 0.06431563830119558, 0.044776530121453106, 0.061995421201572753, 0.057088188623311, 0.09135615255217999, 0.18344870855798945, 0.008660120311105857, 0.09871085829217918, 0.03374306143086869, 0.516537573421374, 0.2102371523506008, 5.097581315785646, 17.715492993593216, 37.322091311216354, 46.44114978611469, 55.0924913585186, 57.57044479250908, 69.6219465136528, 74.30739909410477, 75.04810854792595, 69.90361019968987, 68.1037075817585, 59.910138845443726, 65.39319902658463, 58.560994639992714, 60.69193169474602, 50.63146993517876, 69.78381782770157, 48.10687780380249, 44.51132453978062, 71.4330205321312, 34.56248939037323, 48.244958594441414, 24.685645177960396, 20.397818461060524, 21.391166858375072, 23.33313625305891, 21.284641474485397, 23.1490608304739, 20.874221697449684, 29.77263741195202, 31.526870280504227, 26.22184194624424, 36.33218742907047, 28.23239006102085, 24.44079391658306, 84.05556321144104, 59.27892431616783, 29.57982435822487, 61.8083193898201, 39.596626460552216, 33.381098583340645, 42.660694643855095, 50.524767860770226, 59.65145632624626, 71.09209522604942, 68.3042760193348, 76.86527743935585, 86.62486374378204, 79.89911824464798, 77.07993552088737, 68.17406460642815, 67.72263363003731, 59.744612127542496, 34.455414935946465, 8.559630643576384, 0.7757774752099067, 0.25941071449778974, 0.2537526696687564, 0.05458157742395997, 0.10564056574366987, 0.06115757358202245, 0.019137142444378696, 0.03396378357138019, 0.012784465016011382, 0.06924349145265296, 0.08033437639824115, 0.053321061859605834, 0.023329714640567545, 0.031504718062933534, 0.09882424361421727, 0.03148344068904407, 0.10511162225157022, 0.06689742906019092, 0.04461373631784227, 0.056745702313492075, 0.07592474270495586, 0.037120456763659604, 0.028798413477488793, 0.03281154735304881, 0.027057474180764984, 0.03414316437556408, 0.08369012328330427, 0.024745606242504437, 0.008886611722118687, 0.10410935923573561, 0.02897008707805071, 0.06220731549547054, 0.03174309589667246, 0.05116887070471421, 0.021769607046735473, 0.018547376239439473, 0.017421894444851205, 0.010177489475609036, 0.035397705651121214, 0.0070452190266223624, 0.06524229131173342, 0.07529255162808113, 0.07694197483942844, 0.04202862073725555, 0.06201444615726359, 0.012453438394004479, 0.04414807946886867, 0.03062899679207476, 0.021690737157769036, 0.047509236610494554, 0.02946889195300173, 0.04119232420634944, 0.08341687935171649, 0.12088388568372466, 0.065804668556666, 0.041866505998768844, 0.0635401533509139, 0.07342587952734903, 0.057507312812958844, 0.04453718749573454, 0.02461794385453686, 0.03501951461657882, 0.023665326807531528, 0.039684736548224464, 0.045003586492384784, 0.018465085049683694, 0.02541182293498423, 0.03695539940963499, 0.050885726523119956, 0.038290927550406195, 0.05747665840317495, 0.016697638093319256, 0.05861259334778879, 0.06230544968275353, 0.0677731930045411, 0.04950658978486899, 0.024442978829029016, 0.01474505497753853, 0.02363211755437078, 0.05577294708928093, 0.051181913950131275, 0.01346589388049324, 0.020280081407690886, 0.037520043915719725, 0.054726711823605, 0.06573764519998804, 0.011375362209946616, 0.048119415587279946, 0.017290717987634707, 0.05087072400783654, 0.02245779131044401, 0.016523758458788507, 0.009372798231197521, 0.08724104016437195, 0.03381816677574534, 0.03494220880384091, 0.014489556724583963, 0.03293925241450779, 0.06602827765163966, 0.043578622135100886, 0.030753456812817603, 0.027294870524201542, 0.022632587497355416, 0.012907412910863059, 0.04478133181692101, 0.047432120045414194, 0.01178605652967235, 0.11367966522811912, 0.04079327511135489, 0.033008684040396474, 0.047444113151868805, 0.08648862858535722, 0.09670420229667798, 0.07779211984598078, 0.048938301333691925, 0.16637070308206603, 0.05191121876123361, 0.08535526518244296, 0.22412490245187655, 0.6159079412464052, 0.8508188172709197, 12.452256716787815, 30.294469110667706, 55.703563168644905, 65.80992266535759, 71.60072073340416, 71.8084479868412, 78.61601069569588, 73.53348702192307, 71.02778747677803, 59.631264209747314, 63.47476176917553, 43.309331238269806, 46.99042551219463, 44.03402455151081, 38.561292216181755, 34.16651263833046, 35.11258587241173, 11.472941916435957, 42.95924462378025, 64.01156276464462, 21.017042733728886, 31.156078577041626, 23.41668426990509, 32.221184223890305, 32.42089010775089, 40.200843438506126, 32.439535707235336, 32.50923916697502, 33.564617335796356, 47.52448685467243, 57.5209866464138, 42.210042625665665, 53.264626041054726, 35.890138149261475, 28.656487204134464, 91.02620556950569, 64.95439857244492, 29.340686090290546, 58.26922729611397, 39.40477095544338, 20.64487360417843, 28.067013435065746, 34.430161491036415, 38.51675860583782, 31.254449598491192, 44.585120379924774, 54.31016653776169, 56.05119131505489, 68.68525117635727, 81.76506131887436, 77.61877700686455, 84.83258351683617, 75.24044662714005, 57.46579460799694, 18.17188460379839, 2.4022220727056265, 0.469563573715277, 0.16463300882605836, 0.1102281293424312, 0.08880639288690872, 0.08873695012880489, 0.030146836434141733, 0.07321820434299298, 0.1296914048725739, 0.05474308360135183, 0.009339780081063509, 0.06573897364432923, 0.03714928177942056, 0.019339045575179625, 0.027449855078884866, 0.03429397249419708, 0.05362393974792212, 0.025046771625056863, 0.006828733157817624, 0.03776557605306152, 0.024559859666624106, 0.0382454005011823, 0.02995984676090302, 0.0923596994834952, 0.07677392291952856, 0.037704322894569486, 0.013841352883900981, 0.046855545515427366, 0.012355495309748221, 0.07402286311844364, 0.05878171024960466, 0.020317240741860587, 0.05166628034203313, 0.04461784410523251, 0.03377408691449091, 0.03841856581857428, 0.07238885431434028, 0.054757481266278774, 0.03164772249874659, 0.03626038182119373, 0.06302686175331473, 0.016088754164229613, 0.02375637719524093, 0.02007842133025406, 0.08248235957580619, 0.027692643125192262, 0.02542517973779468, 0.10897672735154629, 0.021121955178386997, 0.057086967790382914, 0.05551596732402686, 0.07477949751773849, 0.04867418952926528, 0.004388818306324538, 0.04492585765547119, 0.02133515379682649, 0.04378515812277328, 0.2254739191266708, 0.19523747207131237, 0.15976949245668948, 0.09483745598117821, 0.14235729788197204, 0.2111452294047922, 0.16664477821905166, 0.17312586482148618, 0.1609941993956454, 0.08225696190493181, 0.13416664442047477, 0.16131595009937882, 0.18530710571212694, 0.16131764219608158, 0.15104113816050813, 0.12971553951501846, 0.1823784425505437, 0.13020311569562182, 0.12044007395161316, 0.08682894040248357, 0.30132029845844954, 0.13957516435766593, 0.1563615057966672, 0.14109904586803168, 0.1690803436213173, 0.11293843039311469, 0.15741100651212037, 0.10438237310154364, 0.2093416769639589, 0.08201620177715085, 0.12962934648385271, 0.09808933929889463, 0.18363749608397484, 0.13199274544604123, 0.16509244276676327, 0.20528358378214762, 0.2351054671453312, 0.1385694058262743, 0.2372451827977784, 0.19241523288656026, 0.11499255415401421, 0.2121870859991759, 0.08045026275794953, 0.1845932932337746, 0.19582434761105105, 0.2255158356274478, 0.15525221766438335, 0.13896535645471886, 0.4119481856469065, 0.12721318082185462, 0.20041825657244772, 0.17047657573129982, 0.08569009994971566, 0.2054053108440712, 0.269310133298859, 0.39639164227992296, 0.09885518375085667, 0.2297491647186689, 0.4769802116788924, 0.09636939721531235, 0.2577784942695871, 0.25235158391296864, 1.1856824392452836, 0.3042711963644251, 9.109680578112602, 29.775238372385502, 56.50237150490284, 71.2952247262001, 79.71233546733856, 84.10489216446877, 92.81017944216728, 95.29760196805, 95.56799545884132, 85.16071870923042, 88.62746268510818, 72.08040699362755, 80.37834092974663, 72.67640501260757, 75.56079223752022, 68.51255804300308, 91.5407207608223, 66.87084093689919, 58.49541015923023, 85.14278367161751, 41.80125676095486, 58.7161099165678, 34.63951125741005, 34.039029479026794, 31.74630280584097, 36.06100358068943, 29.892745167016983, 37.31088571250439, 33.78584526479244, 42.539655938744545, 53.25009562075138, 38.054559007287025, 53.80352072417736, 42.162339985370636, 33.98697227239609, 105.09201720356941, 73.78784537315369, 43.83077725768089, 77.91876330971718, 52.12130919098854, 44.807492047548294, 60.08065089583397, 65.6676734983921, 81.84370189905167, 83.10957357287407, 84.71440225839615, 93.89911741018295, 101.90421625971794, 99.7700759768486, 102.55781158804893, 90.61341091990471, 93.90611663460732, 79.93804335594177, 52.88588896393776, 17.954156287014484, 3.490527612157166, 0.48069258278701454, 0.3013189329067245, 0.21870386990485713, 0.20464686560444534, 0.4444858100032434, 0.13418825576081872, 0.15503548085689545, 0.18423277273541316, 0.2271892747376114, 0.11290278504020534, 0.27579935383982956, 0.1923663550405763, 0.15654316870495677, 0.2590949455043301, 0.14402536384295672, 0.20630387356504798, 0.15440505609149113, 0.19923456071410328, 0.11518581683048978, 0.24992173304781318, 0.11823788430774584, 0.12425108390743844, 0.1980913119041361, 0.1506543456343934, 0.12398909093462862, 0.15582414634991437, 0.20998572756070644, 0.12405894929543138, 0.17820841865614057, 0.20360019989311695, 0.13213502999860793, 0.11524798654136248, 0.17295009456574917, 0.19718396215466782, 0.1002943936327938, 0.15442855248693377, 0.2105823697638698, 0.06950287206564099, 0.15042536339024082, 0.2481658710166812, 0.2567822055425495, 0.203209251340013, 0.227320916892495, 0.1819250496919267, 0.10837555804755539, 0.14061711000977084, 0.23022354551358148, 0.03840620905975811, 0.11069247630075552, 0.0796878692926839, 0.14596327469917014, 0.1411530000041239, 0.24307334271725267, 0.15008059126557782, 0.11706667879479937, 0.15331731992773712], [0.016319658570864704, 0.051312624709680676, 0.035514152332325466, 0.056549615765106864, 0.048267997262883, 0.07241647705086507, 0.07117179891793057, 0.06419277575332671, 0.08368811206310056, 0.023475593043258414, 0.06558340464835055, 0.023053114346112125, 0.07047749750199728, 0.08005590774700977, 0.03438141975493636, 0.10715160809922963, 0.06888346077175811, 0.07736344792647287, 0.016271025633614045, 0.030785009221290238, 0.029973943856020924, 0.014160736136545893, 0.10120389561052434, 0.012891233163827565, 0.056359199224971235, 0.046256142522906885, 0.07577379728900269, 0.013186050400690874, 0.02697830928809708, 0.07208071459899656, 0.11526250294991769, 0.07080920040607452, 0.06890448581543751, 0.06737189149134792, 0.03353397245518863, 0.052198355697328225, 0.0959048127697315, 0.034707634476944804, 0.01715506452455884, 0.014009959559189156, 0.02154134097509086, 0.0907003166503273, 0.0573793554212898, 0.06286174131673761, 0.03604272846132517, 0.09551817609462887, 0.043545822918531485, 0.062397372093982995, 0.029850546961824875, 0.015443720221810509, 0.06498726710560732, 0.054707230447093025, 0.0301421070980723, 0.08984263884485699, 0.10484507249202579, 0.028150793150416575, 0.0871067559637595, 0.11565811961190775, 0.05762955937825609, 0.06837186869233847, 0.26804224820807576, 0.04198383212496992, 0.21382411534432322, 0.1010727061657235, 0.4011642752448097, 0.2532100706594065, 0.15781800029799342, 0.530299247475341, 6.5864084009081125, 14.30549992248416, 21.21894869953394, 35.79988159239292, 36.24956086277962, 43.321163803339005, 54.47776414453983, 64.60292503237724, 68.0375075340271, 69.81879115104675, 66.05015337467194, 69.31026443839073, 67.0890936255455, 71.48351222276688, 69.8547600209713, 54.25020195543766, 57.54955731332302, 74.19738739728928, 85.00593781471252, 79.04774352908134, 79.15619730949402, 67.64607533812523, 89.94729146361351, 78.86403098702431, 75.69149762392044, 77.16171473264694, 65.04241704940796, 77.48870998620987, 75.32917186617851, 83.30100730061531, 72.96787217259407, 62.704508900642395, 67.20867320895195, 78.04864034056664, 72.76796489953995, 84.60182949900627, 94.76191431283951, 84.06659781932831, 85.1685918867588, 83.95257353782654, 79.114680737257, 66.87268763780594, 56.392443403601646, 46.90967984497547, 34.93309110403061, 30.736400596797466, 19.268465861678123, 7.376700444146991, 1.5619434742257, 0.028274006363062654, 0.2608164312550798, 0.13265805115224794, 0.0521056057914393, 0.16547763225389645, 0.025971584109356627, 0.0134749991048011, 0.03145407390547916, 0.07355668305535801, 0.03792288538534194, 0.04416424344526604, 0.052967799565522, 0.0537951791920932, 0.02708850151975639, 0.004940138942401973, 0.03326200872834306, 0.03229470086807851, 0.04278197113308124, 0.043115700100315735, 0.06436528055928648, 0.01796641376131447, 0.007979793535923818, 0.04084466512722429, 0.06429206769098528, 0.03709379510837607, 0.007093698895914713, 0.04921918567561079, 0.039524696112493984, 0.019337115991220344, 0.027842920608236454, 0.06265727963182144, 0.07049320876831189, 0.08400565478950739, 0.08284086143248715, 0.07313538808375597, 0.0449720452161273, 0.04321892170992214, 0.06954025404411368, 0.029580360678664874, 0.029098458217049483, 0.09301902347942814, 0.10486047205631621, 0.0229567130736541, 0.05509327711479273, 0.047828538226895034, 0.046905462368158624, 0.02314295132237021, 0.04092382630915381, 0.05405696436355356, 0.036474958978942595, 0.05774786142865196, 0.027857062232214957, 0.07403239971608855, 0.04331213545810897, 0.04197774651402142, 0.03597452880057972, 0.03124991650111042, 0.08300704314024188, 0.041878098345478065, 0.03770309835090302, 0.053808393131475896, 0.058511958122835495, 0.02179606832214631, 0.051238996238680556, 0.04755026624479797, 0.03536189331498463, 0.015982204022293445, 0.0330875557847321, 0.02516427030059276, 0.030720613067387603, 0.032783405113150366, 0.036130457738181576, 0.034871771567850374, 0.07403065566904843, 0.03923595242667943, 0.02181387801101664, 0.02986081271956209, 0.013095136382617056, 0.025720064695633482, 0.06529940699692816, 0.035877930858987384, 0.08194977956009097, 0.045204285488580354, 0.028764421258529183, 0.025783967321331147, 0.020184730274195317, 0.031151129223871976, 0.04563754016999155, 0.0682216505811084, 0.006982946806601831, 0.028046797851857264, 0.05660932896716986, 0.05504465530975722, 0.032302467443514615, 0.06570111669134349, 0.03311222106276546, 0.04567516705719754, 0.036647805172833614, 0.006610585342059494, 0.02744535024248762, 0.058401838250574656, 0.0926013798743952, 0.031206738349283114, 0.0059123593564436305, 0.059935467870673165, 0.05856997551745735, 0.04497277994232718, 0.0245114586505224, 0.060162353547639214, 0.05509854636329692, 0.049389883351977915, 0.03867113351589069, 0.07909784704679623, 0.01595642552274512, 0.020361203714855947, 0.0689036917174235, 0.021319288534868974, 0.02456406207784312, 0.052436028490774333, 0.14015010616276413, 0.053967917774571106, 0.1094572976580821, 0.23267056967597455, 0.39270922425203025, 0.23926706024212763, 0.17740663199219853, 3.316616644151509, 13.241809699684381, 25.198011584579945, 38.77856455743313, 51.84594176709652, 56.64587460458279, 63.064083606004715, 75.19634619355202, 77.57250308990479, 77.47636064887047, 72.95113027095795, 71.1621406674385, 64.37157824635506, 68.81771966814995, 59.52942967414856, 55.046164244413376, 54.803752452135086, 40.02845048904419, 55.09688772261143, 43.74133765697479, 37.28710658848286, 36.25162035226822, 32.35242918133736, 37.0133388787508, 38.68225872516632, 37.077563032507896, 41.3318907469511, 38.090565875172615, 35.783618465065956, 46.108245849609375, 42.21226170659065, 38.16973462700844, 69.11117792129517, 63.255996108055115, 60.30223600566387, 73.97998586297035, 72.64304280281067, 76.59173011779785, 78.72409969568253, 83.07335391640663, 87.92612671852112, 87.32905715703964, 84.13662806153297, 79.55403596162796, 72.26576864719391, 56.67809307575226, 45.59137478470802, 32.80932806432247, 15.738270040601492, 4.921258427202702, 0.08189999629394151, 0.40090526570566, 0.13624725543195382, 0.15379345219116658, 0.0881577558175195, 0.08043400972383097, 0.03225572327210102, 0.07011063164100051, 0.07513701973948628, 0.06905255911988206, 0.0784753929474391, 0.024707747434149496, 0.06591082536033355, 0.021181019001232926, 0.028162520939076785, 0.08214165442041121, 0.0667294958839193, 0.01941975042427657, 0.01485915832745377, 0.019319146740599535, 0.06608543044421822, 0.046851010993123055, 0.017620138787606265, 0.08982706116512418, 0.07520893384935334, 0.038636003955616616, 0.10514387598959729, 0.07202018503448926, 0.04209310965961777, 0.027973855867458042, 0.03777745041588787, 0.04693300346843898, 0.06545834534335881, 0.04028377959912177, 0.014844948054815177, 0.04156873779720627, 0.03633655214798637, 0.034922723716590554, 0.0428976645343937, 0.049470718076918274, 0.08486839404213242, 0.07296748459339142, 0.006881368590256898, 0.028075728623662144, 0.0659027804795187, 0.08279673333163373, 0.011835564273496857, 0.046419845457421616, 0.011245781370234909, 0.014918531069270102, 0.07265624270075932, 0.030827521295577753, 0.006581682400792488, 0.06749213425791822, 0.08544531738152727, 0.018234149101772346, 0.022856870091345627, 0.07445246272254735, 0.03542923579516355, 0.11389744104235433, 0.15809005679329857, 0.12219293770613149, 0.13483456248650327, 0.15294335171347484, 0.1629121316364035, 0.22735890001058578, 0.11844345179270022, 0.1954324045800604, 0.10221648190054111, 0.17174992302898318, 0.09101567004108801, 0.2063525139237754, 0.1512554258806631, 0.2173452646820806, 0.2123140377807431, 0.11238594597671181, 0.1769327707006596, 0.14463817002251744, 0.0896859863132704, 0.11448532590293325, 0.09856167918769643, 0.161778426845558, 0.10759659242467023, 0.16354729130398482, 0.11875961412442848, 0.18272296234499663, 0.14301141200121492, 0.12347454510745592, 0.15434917237143964, 0.27102122898213565, 0.12720874277874827, 0.16873898537596688, 0.15807824180228636, 0.1888711066567339, 0.16695818718289956, 0.18281017953995615, 0.17703518708003685, 0.09833036659983918, 0.05173422767256852, 0.1635820238152519, 0.11226948816329241, 0.1308664769749157, 0.14742327213753015, 0.1735725931939669, 0.14161023718770593, 0.13067396386759356, 0.11335522052831948, 0.1078580881585367, 0.21418364136479795, 0.15380289230961353, 0.15086149389389902, 0.11003917854395695, 0.2263050206238404, 0.13881670427508652, 0.12894453713670373, 0.1660730128060095, 0.17972847068449482, 0.14385698537807912, 0.15052846254548058, 0.5347184103447944, 0.12172564442153089, 0.31383403635118157, 0.18996619008248672, 0.5425078142434359, 0.4140298505080864, 0.1596357426024042, 2.0048686070367694, 9.813717249780893, 24.505772329866886, 36.94844216108322, 50.7444416731596, 60.18625482916832, 71.83186993002892, 84.36916798353195, 91.65044367313385, 98.13827633857727, 97.13950753211975, 89.87424418330193, 86.03789404034615, 87.75488510727882, 87.19328284263611, 88.53300735354424, 67.13928133249283, 74.04212012887001, 92.96353921294212, 102.76544004678726, 103.19683849811554, 95.81106081604958, 90.09988367557526, 110.13300150632858, 94.69188407063484, 93.92103463411331, 93.31998288631439, 82.02300667762756, 93.87861371040344, 93.20491746068001, 103.85434001684189, 86.04433849453926, 87.7826464176178, 78.39871555566788, 98.08833181858063, 95.9605523943901, 104.7461749613285, 114.32533174753189, 107.36497923731804, 109.10491347312927, 108.0061948299408, 101.1600261926651, 97.07010045647621, 85.10154068470001, 75.56424245238304, 58.351975455880165, 44.459863901138306, 31.031796745955944, 12.225004211068153, 2.745175282470882, 0.17899742553709075, 0.4587933188304305, 0.27015472704079, 0.2716344507643953, 0.31018397596199065, 0.23247970413649455, 0.11838359758257866, 0.20493893040111288, 0.11254159660893492, 0.10198230462265201, 0.13843901047948748, 0.14117755024926737, 0.13122741307597607, 0.09838714089710265, 0.1350280997576192, 0.20258632226614282, 0.14134597324300557, 0.15888028079643846, 0.1508049719268456, 0.1508697317331098, 0.24499123042915016, 0.2072097093332559, 0.15141644224058837, 0.14814229449257255, 0.15824317670194432, 0.16585180826950818, 0.22206735739018768, 0.16863253171322867, 0.18110024160705507, 0.10024024653830566, 0.14378891559317708, 0.2137613296508789, 0.18986862734891474, 0.1262158530880697, 0.10838620786671527, 0.2893585403217003, 0.18182695261202753, 0.14860106050036848, 0.11888214270584285, 0.14873035746859387, 0.20713426260044798, 0.2505501243285835, 0.15097869385499507, 0.15425938734551892, 0.12590850004926324, 0.16887016739929095, 0.12803291261661798, 0.14833649969659746, 0.16074673767434433, 0.08488538180245087, 0.17703334655379876, 0.11596669719438069, 0.19326448731590062, 0.20377907232614234, 0.3099053737241775, 0.09832382827880792, 0.09276445198338479, 0.23230884689837694, 0.1173418374673929], [0.0617859759950079, 0.03286617684352677, 0.06393203701009043, 0.061459275166271254, 0.10012441212893464, 0.002695499147193914, 0.028335357856121846, 0.06564386741956696, 0.05909417297516484, 0.0368583710223902, 0.004430878598213894, 0.037288211824488826, 0.004390098511066753, 0.047666293612564914, 0.07815323406248353, 0.0062540395083487965, 0.04350987328507472, 0.0697702456091065, 0.027660925588861573, 0.02102713282511104, 0.008381563529837877, 0.053728463826701045, 0.0422051776695298, 0.01379556237225188, 0.013116770915075904, 0.013474088118528016, 0.042629623058019206, 0.07827789260772988, 0.029177033102314454, 0.03974019724410027, 0.060492568445624784, 0.05010814500565175, 0.09587540887878276, 0.01290256112042698, 0.05328425133484416, 0.08802053271210752, 0.02577809507783968, 0.0689791384502314, 0.05901470380194951, 0.020434182806639, 0.0365238034282811, 0.01989323693123879, 0.027661673302645795, 0.020088731616851874, 0.03662546652776655, 0.025388866451976355, 0.0549243494606344, 0.00478956274491793, 0.03942951196222566, 0.05119538393046241, 0.05690010242688004, 0.033168724476126954, 0.0201804406606243, 0.0394392192538362, 0.07592480207676999, 0.008748690997890662, 0.03620539609983098, 0.0652443990111351, 0.0752775750879664, 0.02966136238683248, 0.09786786016775295, 0.038908127244212665, 0.17127119324868545, 0.05502400505065452, 0.19884438399458304, 0.18601192336063832, 0.02339734655834036, 0.1084021566202864, 0.43348397535737604, 0.6872685870621353, 0.35922488663345575, 0.161391515575815, 0.2897577563999221, 1.2459898344241083, 5.183770665898919, 8.4404500387609, 16.43714088946581, 27.560038939118385, 34.64446999132633, 37.219557613134384, 52.97546535730362, 65.30282467603683, 69.06836941838264, 72.5686351954937, 74.09474730491638, 72.58461713790894, 71.83411940932274, 75.56941777467728, 79.84575390815735, 81.65482923388481, 80.4914228618145, 76.2405301630497, 82.48516827821732, 79.05906692147255, 79.97455939650536, 78.11419442296028, 72.25745469331741, 71.08637273311615, 68.71175855398178, 71.92708522081375, 75.21429643034935, 59.19264614582062, 49.18990708887577, 44.97506305575371, 32.196375355124474, 33.13036523759365, 31.00658129900694, 18.02803762257099, 14.313914570957422, 7.4385307263582945, 2.7887717681005597, 2.0797013165429235, 0.13722331321332604, 0.05960221016721334, 0.4673442553030327, 0.2536921401042491, 0.044226565296412446, 0.04820622460101731, 0.11333297836245038, 0.21758549788501114, 0.09420429269084707, 0.0789095790241845, 0.08494574809446931, 0.04809782651136629, 0.08091147043160163, 0.07972645355039276, 0.08481805416522548, 0.058809340407606214, 0.03925985329260584, 0.08646384827443399, 0.04234082742186729, 0.00634201972388837, 0.07019850192591548, 0.039146122871898115, 0.012270224397070706, 0.05710311321308836, 0.01218112493006629, 0.043839947175001726, 0.04840129069634713, 0.030017860444786493, 0.00801793528808048, 0.020275686038075946, 0.04178935974778142, 0.06109994210419245, 0.046047684372751974, 0.029755477844446432, 0.03069616672291886, 0.0325682527909521, 0.047804221758269705, 0.0800599301874172, 0.013875972217647359, 0.04197561283945106, 0.021847829411854036, 0.04897303384495899, 0.048921213383437134, 0.009154369327006862, 0.009657749542384408, 0.04715285358543042, 0.009048976935446262, 0.045067118044244125, 0.046729862806387246, 0.019530050267348997, 0.036450527477427386, 0.03023500172275817, 0.042470257976674475, 0.04690510242653545, 0.012575050423038192, 0.03312733861093875, 0.029460292316798586, 0.04184627876384184, 0.04649945563869551, 0.017769598052836955, 0.06268718076171353, 0.06033085817762185, 0.02407254694844596, 0.024897833718569018, 0.05977152002742514, 0.036628045490942895, 0.03944618430978153, 0.03464264460490085, 0.051766960095847026, 0.03812119466601871, 0.050700081992545165, 0.09338600808405317, 0.07091022896929644, 0.02386119627772132, 0.03587333696486894, 0.029877433116780594, 0.02048585669399472, 0.04979025718057528, 0.01652977542107692, 0.019841203102259897, 0.13567826565122232, 0.02550668054027483, 0.057116460739052854, 0.027817069749289658, 0.039228393652592786, 0.019651608490676153, 0.05714005732443184, 0.034891212126240134, 0.039736620092298836, 0.017349457120872103, 0.07245777014759369, 0.05388087869505398, 0.01786377473763423, 0.012400393388816155, 0.03938015172025189, 0.027324318944010884, 0.06125334031821694, 0.016920276830205694, 0.06202264688909054, 0.030303505664051045, 0.06730045235599391, 0.012830866871809121, 0.08615864004241303, 0.03901834359567147, 0.09547656387439929, 0.05762147739005741, 0.025866085961752106, 0.0017540100247970258, 0.03778586265980266, 0.0539885457692435, 0.029642285480804276, 0.027504688659973908, 0.051195706764701754, 0.014759775476704817, 0.04577220657665748, 0.030547110072802752, 0.03407964395591989, 0.05024913822126109, 0.03987573196354788, 0.13468216988258064, 0.014680849926662631, 0.02325394692888949, 0.08782223827438429, 0.04230405029375106, 0.08568339835619554, 0.023351127456407994, 0.17362823942676187, 0.05371729079342913, 0.12204127240693197, 0.14596603548852727, 0.06824732146924362, 0.1972222124459222, 0.33322588016744703, 0.2670745470095426, 0.35135565733071417, 0.4863301740260795, 1.7985552339814603, 5.283097336068749, 12.19905350357294, 19.506637081503868, 32.32107326388359, 47.90443606674671, 55.23846432566643, 60.8761952072382, 71.55844420194626, 82.08673685789108, 85.09749010205269, 83.44221532344818, 79.69626232981682, 82.12196096777916, 89.23301339149475, 91.90164059400558, 90.97917169332504, 91.7428471148014, 94.2244103550911, 92.82405629754066, 96.70750111341476, 94.7054873406887, 95.25016531348228, 95.71929574012756, 92.57535204291344, 91.5721982717514, 90.52538484334946, 84.15699496865273, 90.00907614827156, 80.05190044641495, 70.67751467227936, 67.7934618294239, 56.68468952178955, 53.24972324073315, 50.72885870933533, 36.47902674973011, 27.920079119503498, 18.115071952342987, 11.148458328098059, 6.705133030191064, 1.1177127552218735, 0.38954797200858593, 0.5336250190157443, 0.3649070067331195, 0.12267409430933185, 0.04485542784095742, 0.09143045637756586, 0.0372105126734823, 0.16276030306471512, 0.13855076307663694, 0.042498340844758786, 0.06325790716800839, 0.004112151218578219, 0.04975061907316558, 0.05262620012217667, 0.03151442535454407, 0.05254096075077541, 0.04238853267452214, 0.057410826193518005, 0.03156095801386982, 0.1293224238906987, 0.011937624421989312, 0.0007710599527399609, 0.04101252037798986, 0.03698996122693643, 0.0965123125934042, 0.06393719493644312, 0.05926044745137915, 0.05733958743803669, 0.023695550771662965, 0.060376262772479095, 0.0667096656979993, 0.02761302181170322, 0.03195786972355563, 0.020929089550918434, 0.06604139882256277, 0.04570750243146904, 0.03934532272978686, 0.01143567284088931, 0.015013500924396794, 0.02230240970675368, 0.038620155391981825, 0.012834336412197445, 0.006353806420520414, 0.02407757314358605, 0.019898244572686963, 0.041672200604807585, 0.046766881132498384, 0.05007888212276157, 0.022122468581073917, 0.05559968529269099, 0.005821079366796766, 0.07136333981179632, 0.020810099158552475, 0.026341720986238215, 0.06018446212692652, 0.013567810237873346, 0.06244617572519928, 0.05134306018589996, 0.0070737977421231335, 0.06675558237475343, 0.031743103318149224, 0.03136929837637581, 0.09797041755518876, 0.24213080032495782, 0.1511368009960279, 0.09624419690226205, 0.1125437488371972, 0.2283056132728234, 0.07861380348913372, 0.11896394222276285, 0.21628945571137592, 0.15468346537090838, 0.0989196689624805, 0.11411556566599756, 0.1633505182689987, 0.07580412144307047, 0.09500587897491641, 0.14891206490574405, 0.09486283001024276, 0.20884406694676727, 0.13883353618439287, 0.10116406454471871, 0.1589568259078078, 0.06869209799333476, 0.24414663668721914, 0.11189140845090151, 0.13385866797761992, 0.2038348966743797, 0.17295275145443156, 0.12494749302277341, 0.21281046036165208, 0.08335745558724739, 0.0981397385476157, 0.15860914456425235, 0.14341574889840558, 0.20312556676799431, 0.07703705137828365, 0.09361948032164946, 0.16055561980465427, 0.14243998797610402, 0.10307686854503118, 0.21526808239286765, 0.11675501387799159, 0.2348209425690584, 0.15191056416369975, 0.1720602743444033, 0.193067254149355, 0.15575018391245976, 0.15215104969684035, 0.09540409315377474, 0.11263874373980798, 0.2075375456479378, 0.09296419360907748, 0.15032768191304058, 0.1194751780712977, 0.09783330577192828, 0.1399762209621258, 0.13799930282402784, 0.3587381268152967, 0.3121585043845698, 0.13626647705677897, 0.36415025359019637, 0.09471886078245007, 0.27929896605201066, 0.1795234449673444, 0.4050168232060969, 0.11201147310202941, 0.27332779427524656, 0.3437938849674538, 0.19061105704167858, 0.25018145504873246, 0.750976384151727, 1.1662999168038368, 0.4885728849330917, 0.1903522404609248, 0.6980239099357277, 2.9514500638470054, 7.680715955793858, 15.171208418905735, 28.562442250549793, 47.465320229530334, 60.568096339702606, 64.57952588796616, 82.46601730585098, 94.75936084985733, 101.29279866814613, 106.26930043101311, 102.62721866369247, 98.60806792974472, 98.74219313263893, 101.84917241334915, 106.11309081315994, 109.46913152933121, 105.3793653845787, 104.28557127714157, 106.64942443370819, 108.43117162585258, 107.31108292937279, 109.18089419603348, 98.35089772939682, 100.13262212276459, 98.32752138376236, 97.23648592829704, 99.58409115672112, 83.17516565322876, 72.26228043437004, 66.29270195960999, 50.1735033094883, 46.52148887515068, 43.43105390667915, 29.431976191699505, 21.67553599923849, 12.737416215240955, 7.043470675125718, 3.8139878679066896, 0.3820183197967708, 0.19892980519216508, 0.9700335015077144, 0.6367992796003819, 0.19641653692815453, 0.166382176685147, 0.2704040886601433, 0.33257103874348104, 0.3287528670625761, 0.284863292472437, 0.31152747105807066, 0.12155468328273855, 0.17607334884814918, 0.23036697297357023, 0.18846390506951138, 0.15281216969015077, 0.24052682623732835, 0.13440009439364076, 0.20141680142842233, 0.08113451549434103, 0.2536238031461835, 0.10484921367606148, 0.061611983182956465, 0.10403527063317597, 0.1231248896510806, 0.21225560107268393, 0.24495091696735471, 0.1231357546930667, 0.09027010848512873, 0.08799051283858716, 0.1336655908380635, 0.14099556079600006, 0.11683790435199626, 0.0960501772351563, 0.32197322929278016, 0.10225499194348231, 0.12081736698746681, 0.13628301210701466, 0.09669531136751175, 0.15274027042323723, 0.08278589055407792, 0.11934597016079351, 0.1409289159346372, 0.05092014733236283, 0.08780168078374118, 0.1328624683083035, 0.10881758862524293, 0.13068401254713535, 0.10343781948904507, 0.13952097273431718, 0.13351621135370806, 0.22389925987226889, 0.1452917349524796, 0.18425854010274634, 0.11462907248642296, 0.20198729034746066, 0.21300628344761208, 0.18068419361952692, 0.2246284793363884, 0.09331840585218742, 0.14758578763576224, 0.10712437870097347, 0.16450055030873045, 0.1303287167684175], [0.02555370858317474, 0.03153245954308659, 0.024359672752325423, 0.06738990341546014, 0.020261062018107623, 0.035007473270525225, 0.004713347425422398, 0.01385021041642176, 0.024840326550474856, 0.06626667032833211, 0.015085014274518471, 0.023810366583347786, 0.06448683692724444, 0.03489078539132606, 0.028181814923300408, 0.054171128940652125, 0.03767742746276781, 0.05009249311115127, 0.020300314208725467, 0.010690043563954532, 0.080155051255133, 0.006836611055405228, 0.07682641502469778, 0.040247221404570155, 0.047976863861549646, 0.06367156544001773, 0.04238058427290525, 0.01430129890650278, 0.02290285541675985, 0.05210399533098098, 0.04566586794680916, 0.044068907154724, 0.029635248065460473, 0.010649407267919742, 0.011806555576185929, 0.015703562821727246, 0.04900323554466013, 0.023626326947123744, 0.02555635990574956, 0.027087505186500493, 0.04678018784034066, 0.054290982079692185, 0.04045492627483327, 0.0418651441577822, 0.031943379290169105, 0.017549994699948, 0.026350461630499922, 0.041380807451787405, 0.10485426028026268, 0.05134818842634559, 0.010388620285084471, 0.06770118983695284, 0.010344111833546776, 0.01771943258063402, 0.031732639035908505, 0.03909897794073913, 0.10257240108330734, 0.03151168682961725, 0.20364689582493156, 0.04394838608277496, 0.10535914334468544, 0.03666786171379499, 0.09369993655127473, 0.030533230055880267, 0.07793080498231575, 0.11411503131967038, 0.03387615077372175, 0.044382082342053764, 0.09146328899078071, 0.14031343802344054, 0.13866018533008173, 0.027757130192185286, 0.056723552916082554, 0.14757358672795817, 0.44323725043796003, 0.5326505494304001, 0.2561880717985332, 0.22249857487622648, 0.040729294560151175, 0.1910951451282017, 0.22172089316882193, 2.2192177176475525, 3.6131885927170515, 4.363295417279005, 8.344348445534706, 13.958254605531693, 17.675790823996067, 15.76505670323968, 17.781624644994736, 17.100273706018925, 23.25410809367895, 16.845446079969406, 16.287541016936302, 15.34464631229639, 12.07170333713293, 12.788017150014639, 8.675494026392698, 13.442100752145052, 5.8090736623853445, 4.082457711920142, 4.751407066360116, 3.016226375475526, 0.23971896880539134, 0.4829308408079669, 0.06897527186083607, 0.06282608112087473, 0.057584017486078665, 0.21196062705712393, 0.457029560348019, 0.4835531464777887, 0.4198644374264404, 0.29923922731541097, 0.04145002385484986, 0.08637280159746297, 0.2152438141638413, 0.2073534336523153, 0.03864608603180386, 0.023874467733548954, 0.09199186140904203, 0.06816144014010206, 0.05911897183977999, 0.028748368604283314, 0.010398932427051477, 0.028782937843061518, 0.005729503909606137, 0.08858482469804585, 0.031249029634636827, 0.035816124800476246, 0.05225773493293673, 0.029398736733128317, 0.008343545159732457, 0.0532833793113241, 0.021545085110119544, 0.03652149905974511, 0.04921274012303911, 0.03970321602537297, 0.019857832776324358, 0.030592006296501495, 0.046414531680056825, 0.037910517494310625, 0.05214688033447601, 0.02814665567711927, 0.003642566321104823, 0.030931919209251646, 0.015949304615787696, 0.019312606564199086, 0.07559191173641011, 0.04853507023653947, 0.031779160563019104, 0.022350526851369068, 0.02109566645231098, 0.05179741412575822, 0.0573250005254522, 0.07557003322290257, 0.03890244981448632, 0.002979821720145992, 0.053493841260205954, 0.005014880634917063, 0.05834042181959376, 0.04511447448749095, 0.07745334427454509, 0.042917650571325794, 0.016717917278583627, 0.04054835895658471, 0.03466817819571588, 0.03398312022909522, 0.03875106653140392, 0.03827429231023416, 0.0033875555664053536, 0.05129524361109361, 0.014926395979273366, 0.05166264010767918, 0.04057774800457992, 0.04361385559604969, 0.038273164245765656, 0.03021308239112841, 0.04471437154279556, 0.08223309443565086, 0.0771726194943767, 0.0408585395780392, 0.009216898051818134, 0.01395893783410429, 0.036814343111473136, 0.024270533394883387, 0.02205689797847299, 0.011924993068532785, 0.007612813105879468, 0.012657000224862713, 0.08516106739989482, 0.00844043810502626, 0.03899253912095446, 0.027311388876114506, 0.021354770615289453, 0.014901662980264518, 0.02431039229122689, 0.061466332990676165, 0.032152123167179525, 0.04198036629531998, 0.0619620802171994, 0.0371125566016417, 0.0068674217800435144, 0.045033138812868856, 0.10118768710526638, 0.021166441365494393, 0.02231187951110769, 0.040793891093926504, 0.049921899335458875, 0.0712193557410501, 0.030234970181481913, 0.05161062297702301, 0.049792843565228395, 0.023189265048131347, 0.09547209614538588, 0.005490414541782229, 0.016176052995433565, 0.026264628540957347, 0.05675467858964112, 0.037331312050810084, 0.07365290250163525, 0.039534095412818715, 0.032681166849215515, 0.04078611338627525, 0.01926147630001651, 0.058126924486714415, 0.03142289257084485, 0.035794365030596964, 0.013658517382282298, 0.04162046920100693, 0.03626474193879403, 0.08773413050221279, 0.1040775136789307, 0.030303680068755057, 0.0789280139724724, 0.011954504570894642, 0.04903101042145863, 0.03735893849807326, 0.03532265225658193, 0.03577698764274828, 0.030286542023532093, 0.025218948030669708, 0.14981577813159674, 0.03681693320686463, 0.1602348784217611, 0.019968780143244658, 0.13832903903676197, 0.1687554462114349, 0.23524503543740138, 0.10827466307091527, 0.21844681963557377, 0.2749200869584456, 0.4576113150687888, 0.3915663465159014, 0.1895565542508848, 0.3445503709372133, 0.4548803303623572, 0.5806714820209891, 3.5341302724555135, 9.850413780659437, 12.42435671389103, 16.110747903585434, 21.716294512152672, 29.738173261284828, 30.52432257682085, 28.831310123205185, 32.94248431921005, 32.387011125683784, 35.65726764500141, 30.345283783972263, 29.392376616597176, 29.169017001986504, 23.18487960845232, 23.60346894711256, 19.187526404857635, 23.667085133492947, 14.311492200940847, 13.903990667313337, 12.562257964164019, 9.149075914174318, 2.691531660966575, 1.867096668574959, 0.9835636848583817, 0.07763882182189263, 0.17021406325511634, 0.2037326287245378, 0.2717841271078214, 0.17604303953703493, 0.45419621863402426, 0.23301223962334916, 0.11338498065015301, 0.17457818845286965, 0.17313917895080522, 0.13579168065916747, 0.0679603849130217, 0.0630973806255497, 0.06433844449929893, 0.018121758257620968, 0.06350338735501282, 0.043265606509521604, 0.1265772938495502, 0.12589650694280863, 0.012394504447001964, 0.012200793698866619, 0.039193505290313624, 0.017115402297349647, 0.020210768525430467, 0.01644493680942105, 0.014392562661669217, 0.07343522316659801, 0.04249125333444681, 0.04161295866651926, 0.04526978744252119, 0.055872031225590035, 0.047856851160759106, 0.019597374193836004, 0.008047114679357037, 0.031419775550602935, 0.0240850428599515, 0.028246973633940797, 0.03229491980164312, 0.05948326244833879, 0.012756103842548328, 0.01079459732864052, 0.04060515551827848, 0.058338377202744596, 0.023474140289181378, 0.028882179685751908, 0.035818269607261755, 0.020254429073247593, 0.06399693782441318, 0.06490894083981402, 0.032709591105231084, 0.03501297258480918, 0.0380397513799835, 0.033548585342941806, 0.06934001517947763, 0.015297108020604355, 0.03507314220769331, 0.0518349334015511, 0.03891131476848386, 0.026154835213674232, 0.019468982645776123, 0.027225639278185554, 0.0429569769767113, 0.034652518879738636, 0.10157216413062997, 0.02798953930323478, 0.003380461562301207, 0.008886021714715753, 0.028357553637761157, 0.0067743643467110815, 0.031092276913113892, 0.05298288000631146, 0.1296398849808611, 0.18003428005613387, 0.16623766568955034, 0.1505748022464104, 0.12682282598689198, 0.16726485744584352, 0.08347938302904367, 0.07486682603484951, 0.17704986676108092, 0.15375658229459077, 0.08230504565290175, 0.09178639782476239, 0.15248523879563436, 0.1458158841705881, 0.15396827249787748, 0.09327450781711377, 0.21502060582861304, 0.15820470376638696, 0.15756111330119893, 0.0930316028825473, 0.1192433682444971, 0.12497789139160886, 0.11815147605375387, 0.09121715571382083, 0.1532331752241589, 0.1145694186561741, 0.2184661600040272, 0.13240201020380482, 0.11695328605128452, 0.1767541209119372, 0.15706697653513402, 0.18522714672144502, 0.1081296028860379, 0.12953205092344433, 0.10831447929376736, 0.0648529977479484, 0.1532635884359479, 0.1169836547342129, 0.14334818377392367, 0.14675973274279386, 0.17735955014359206, 0.16432987118605524, 0.1396878223749809, 0.2020133991027251, 0.0804391602287069, 0.09954917346476577, 0.07110043399734423, 0.1606162532698363, 0.14818817406194285, 0.10609893841319717, 0.09981656927266158, 0.22513370378874242, 0.11823415130493231, 0.15857436752412468, 0.31811599095817655, 0.24221406929427758, 0.14808865205850452, 0.11330185268889181, 0.3395587153499946, 0.1213471416849643, 0.2862837631255388, 0.10325986731913872, 0.22358559857821092, 0.09330615299404599, 0.2964545111171901, 0.27279472444206476, 0.3001303685596213, 0.20497154037002474, 0.2311081558582373, 0.381204925943166, 0.3836967016104609, 0.12946317961905152, 0.328858281718567, 0.22339862189255655, 0.667983137536794, 0.8697088505141437, 0.6218367512337863, 0.2847715333336964, 0.339364658575505, 0.42290599609259516, 1.6401037364266813, 6.4407185185700655, 9.696306400001049, 12.262157667428255, 18.919604681432247, 26.455153226852417, 28.156073056161404, 25.58245025575161, 28.774647563695908, 28.687582835555077, 33.25415879487991, 26.7271863296628, 25.10114148259163, 24.68446534126997, 18.635153844952583, 19.265013746917248, 16.19683988392353, 21.30547385662794, 11.616576109081507, 10.129537303000689, 8.426667228341103, 6.504282457754016, 1.3906977069564164, 0.9786052478011698, 0.4530881030950695, 0.12518187810201198, 0.12279094546101987, 0.3275116696022451, 0.6521852477453649, 0.6462542410008609, 0.765339732170105, 0.4058395087486133, 0.13744564581429586, 0.3208674886263907, 0.4191131464904174, 0.3169781301403418, 0.17587613052455708, 0.09756345345522277, 0.16639114182908088, 0.27250902727246284, 0.2137946372386068, 0.14691849297378212, 0.23512085928814486, 0.15074334398377687, 0.1529435595148243, 0.17178434383822605, 0.14455127937253565, 0.13696350215468556, 0.17762402188964188, 0.13454614905640483, 0.18775977019686252, 0.176744339405559, 0.12903672672109678, 0.20596264890627936, 0.17339634796371683, 0.08843531904858537, 0.19501905801007524, 0.11096385002019815, 0.09281125181587413, 0.10275458349497057, 0.0813858512265142, 0.11199721644516103, 0.11126008568680845, 0.09725027455715463, 0.0632907249382697, 0.1335830640164204, 0.18903770396718755, 0.10774860653327778, 0.18859164352761582, 0.07008059692452662, 0.07747439900413156, 0.19752135733142495, 0.15493747283471748, 0.24717897787922993, 0.09215136378770694, 0.13448875135509297, 0.12161328326328658, 0.11174876766745001, 0.1664672268088907, 0.22883572935825214, 0.11829374576336704, 0.10931994096608832, 0.06475607326137833, 0.10525856749154627, 0.0961418918450363, 0.1390085939783603, 0.12117568330722861, 0.09953628235962242, 0.15398719726363197, 0.2013956947484985, 0.0766645600378979, 0.13251239724922925, 0.1902688675909303, 0.10951744872727431, 0.13609137473395094, 0.26735490071587265], [0.08661756190122105, 0.01657861801504623, 0.026987782803189475, 0.047879111880320124, 0.02039746133959852, 0.11147583543788642, 0.023072152289387304, 0.016651966325298417, 0.08957761048804969, 0.0300256270202226, 0.06652046999079175, 0.04936964498483576, 0.07933751621749252, 0.043095124055980705, 0.026482473003852647, 0.05345049241441302, 0.07794027478666976, 0.054358194684027694, 0.09525609406409785, 0.029876470180170145, 0.017375821917084977, 0.052852796361548826, 0.010548067002673633, 0.10775216884212568, 0.04904741930658929, 0.04818872475880198, 0.0611061501695076, 0.02973597976961173, 0.031056798543431796, 0.08998411445645615, 0.05632731656078249, 0.029437593730108347, 0.03791210940107703, 0.016481263082823716, 0.026496106256672647, 0.10325393755920231, 0.047740233785589226, 0.021363444466260262, 0.07500557796447538, 0.04451725340913981, 0.021412142341432627, 0.04119734854612034, 0.031691542608314194, 0.04299761698348448, 0.01825882551202085, 0.049344003782607615, 0.0074220231726940256, 0.026405662574688904, 0.028133291452832054, 0.03892335240379907, 0.10751054782303981, 0.04479039715079125, 0.040339073311770335, 0.039198533340822905, 0.03480707855487708, 0.01851304819865618, 0.052983859641244635, 0.04534539002634119, 0.04642216837964952, 0.029838923073839396, 0.08328010895638727, 0.03699863693327643, 0.12355163940810598, 0.1460776396561414, 0.0755625672172755, 0.1128472872369457, 0.04005995157058351, 0.06122099010099191, 0.1334676897386089, 0.24314487091032788, 0.12679581181146204, 0.037296241862350143, 0.0327554001705721, 0.04730241489596665, 0.12728301691822708, 0.10467389613040723, 0.10513829503906891, 0.11200063774595037, 0.11308021770673804, 0.0582662478700513, 0.10349239702918567, 0.09611297777155414, 0.1662365673109889, 0.22752049524569884, 0.04679996978666168, 0.4079739551525563, 0.7581459463108331, 0.7408885192126036, 0.6172028998844326, 0.34923522267490625, 0.6964256206993014, 0.6641979468986392, 0.6126150616910309, 0.5019600118976086, 0.19778661575401202, 0.7551232085097581, 0.47451616264879704, 0.6357092724647373, 0.2877599245402962, 0.16409250267315656, 0.19285893329652026, 0.32763163035269827, 0.0075405951793072745, 0.0596199920255458, 0.020227913992130198, 0.08233271291828714, 0.07670038350624964, 0.09790625146706589, 0.15925588173558936, 0.19621954124886543, 0.10953336037346162, 0.14996866055298597, 0.07020661360002123, 0.06399385049007833, 0.18808293098118156, 0.07247807530802675, 0.13150102808140218, 0.008383635977224912, 0.11836983074317686, 0.11322654696414247, 0.04510578393819742, 0.07168353200540878, 0.027973356773145497, 0.0034608952955750283, 0.01984591017389903, 0.036365985724842176, 0.06596052699023858, 0.08599917477113195, 0.023804089869372547, 0.026298270095139742, 0.027571943937800825, 0.02863275683921529, 0.029761977202724665, 0.07118048204574734, 0.069689574156655, 0.052781093763769604, 0.02103034817992011, 0.03299324365798384, 0.023674535004829522, 0.018189173097198363, 0.11147720841108821, 0.02156761856895173, 0.03328683727886528, 0.05148702570295427, 0.006609942456634599, 0.027969130242126994, 0.05403846262197476, 0.015033719810162438, 0.027098010286863428, 0.007586436249766848, 0.040963961655506864, 0.013220604796515545, 0.054334969172487035, 0.008824895649013342, 0.010738565179053694, 0.01727552622469375, 0.013537055638153106, 0.027903797126782592, 0.04136955649300944, 0.004541812513707555, 0.033783757098717615, 0.07095673194271512, 0.015939855220494792, 0.0242135846929159, 0.015524978898611153, 0.013448563804558944, 0.05423640825028997, 0.0070058239725767635, 0.06644322726060636, 0.07090803221217357, 0.027976798482995946, 0.043521528714336455, 0.08136289659887552, 0.07536477743997239, 0.0700178112310823, 0.041802210034802556, 0.07951873383717611, 0.02958468368888134, 0.04209131366224028, 0.010209733009105548, 0.0338368763186736, 0.043932348271482624, 0.04657624194805976, 0.04944816420902498, 0.04209584818454459, 0.05073311869637109, 0.03693207741889637, 0.03130002260149922, 0.021696896983485203, 0.08477309485897422, 0.10720841950387694, 0.010792135253723245, 0.022195462515810505, 0.07100712376995943, 0.0884591271460522, 0.0416591833345592, 0.04799852715223096, 0.045416714128805324, 0.10211123793851584, 0.031769256602274254, 0.03425459784921259, 0.041866977262543514, 0.03404939030588139, 0.03414393991988618, 0.10356928352848627, 0.04080183578480501, 0.04218077585392166, 0.03686462361656595, 0.06915868623764254, 0.048573888270766474, 0.02144032911019167, 0.03232144415960647, 0.03192888885678258, 0.042570796722429805, 0.015172758394328412, 0.02636367000377504, 0.05472081546031404, 0.012268908012629254, 0.044131692848168314, 0.0321740610525012, 0.00974139886238845, 0.04542413189483341, 0.09924088531988673, 0.023560151494166348, 0.021982436446705833, 0.039418568994733505, 0.06619023653911427, 0.09737504442455247, 0.05043606666731648, 0.011694803906721063, 0.015155137025431031, 0.11913617985555902, 0.020914088891004212, 0.048105782334459946, 0.024571034555265214, 0.03748409428226296, 0.07667292404221371, 0.04063332002260722, 0.11248025810346007, 0.05427669944765512, 0.05751525750383735, 0.08822943244013004, 0.060971498605795205, 0.0971533203846775, 0.08406020264374092, 0.16964799753623083, 0.09612698951968923, 0.06640172636252828, 0.07040773562039249, 0.12572254752740264, 0.13820793537888676, 0.047860762279015034, 0.07607764739077538, 0.1370797521667555, 0.15030510578071699, 0.03550510555214714, 0.04121885969652794, 0.25793395936489105, 0.19389688619412482, 0.1403599261539057, 0.26898079784587026, 0.34147906699217856, 0.23840579786337912, 0.4884065844817087, 0.3672643646132201, 0.3141062264330685, 0.5866078322287649, 0.26600217330269516, 0.25468955689575523, 0.2522343839518726, 0.23648339789360762, 0.3243596793618053, 0.46571150072850287, 0.32032037735916674, 0.24824900639941916, 0.2026165128336288, 0.20846092578722164, 0.3922350809443742, 0.2395233980496414, 0.18633579660672694, 0.07161506146076135, 0.0776910615968518, 0.11701700685080141, 0.08224068660638295, 0.06506727062514983, 0.05884933103516232, 0.03777103454922326, 0.08084650282398798, 0.06191503918671515, 0.0816796526487451, 0.07418592038447969, 0.0607939137989888, 0.02566703082266031, 0.020194749267830048, 0.07429131277604029, 0.11982719355728477, 0.06512873529572971, 0.06813850035541691, 0.05951170525804628, 0.012041766294714762, 0.05166419861780014, 0.05910189502174035, 0.01259880285942927, 0.05360777948226314, 0.005054016864960431, 0.044340518361423165, 0.04286380404664669, 0.05729348151362501, 0.04666924418415874, 0.03098816843703389, 0.048444980930071324, 0.059074821474496275, 0.07974923748406582, 0.01605302531970665, 0.03328290389617905, 0.03767721966141835, 0.0514915787789505, 0.018434458470437676, 0.06454954840592109, 0.04509279264311772, 0.02113279053446604, 0.138811063952744, 0.09042700592544861, 0.04605305381119251, 0.053401391924126074, 0.02161626449378673, 0.030236773600336164, 0.04229467696859501, 0.00986053953965893, 0.0050960289172508055, 0.016842872682900634, 0.022389608348021284, 0.03977755695814267, 0.03592728367948439, 0.03161162443575449, 0.008994145209726412, 0.05346945057681296, 0.09299810233642347, 0.05317350063705817, 0.003918838910976774, 0.02419121636194177, 0.007016201980150072, 0.023415634932462126, 0.029843784141121432, 0.19601988868089393, 0.014615783056797227, 0.042196732028969564, 0.05354370987333823, 0.07510694049415179, 0.029871809492760804, 0.011586370565055404, 0.03634254870121367, 0.3765081107849255, 0.10882687289267778, 0.11940560172661208, 0.15601861872710288, 0.09395337256137282, 0.19516067462973297, 0.13389524101512507, 0.09297442040406168, 0.21592611505184323, 0.12328508222708479, 0.19825326337013394, 0.169140606012661, 0.2730330725898966, 0.22990589146502316, 0.1798868301557377, 0.08921004700823687, 0.12974783778190613, 0.21864813461434096, 0.1618919605971314, 0.08467534658848308, 0.2347259476664476, 0.1915462373290211, 0.1946149140712805, 0.18468833266524598, 0.14189836860168725, 0.1748004913679324, 0.1763735178974457, 0.12095718760974705, 0.17114559217588976, 0.1035988877993077, 0.0859337618749123, 0.06083122156269383, 0.15988029510481283, 0.12757064367178828, 0.19381769903702661, 0.20907968399114907, 0.20813804701901972, 0.11061904820962809, 0.16504651866853237, 0.07627871746080928, 0.0906742227380164, 0.12502650206442922, 0.08666240988532081, 0.15608719317242503, 0.06470598571468145, 0.23286906449357048, 0.15861870342632756, 0.11476945714093745, 0.16864833945874125, 0.12395121171721257, 0.1590046944329515, 0.22287818341283128, 0.12161035177996382, 0.11772164638387039, 0.13627490785438567, 0.16043212643126026, 0.09121869938098826, 0.21913918404607102, 0.1738555295742117, 0.15872339077759534, 0.24420162983005866, 0.10871836348087527, 0.40397959761321545, 0.2129096706630662, 0.23045386362355202, 0.3259831719333306, 0.19806809752481058, 0.16382072819396853, 0.18278227478731424, 0.435816693934612, 0.2718480408657342, 0.1288615947123617, 0.14544340025167912, 0.1591887470567599, 0.32062572659924626, 0.23491616011597216, 0.19570282835047692, 0.33380312263034284, 0.22190049290657043, 0.14324419404147193, 0.13749168865615502, 0.3074109856970608, 0.4583910451037809, 0.2787126100156456, 0.4359648562967777, 0.946168169612065, 0.8725388674065471, 1.1390572786331177, 0.894118562573567, 0.4925664112670347, 1.0220496822148561, 0.8210659387987107, 0.7031345169525594, 0.6758655770681798, 0.5135484400670975, 0.7909789751283824, 1.0965367290191352, 1.0358386673033237, 0.547106220619753, 0.42313579469919205, 0.3425604058429599, 0.7363266265019774, 0.20273438072763383, 0.33864507218822837, 0.13888462563045323, 0.22148002171888947, 0.2185115942847915, 0.19686160288983956, 0.6361588952131569, 0.42379740450996906, 0.20207205845508724, 0.22667680692393333, 0.11214108919375576, 0.25676127697806805, 0.41675676824525, 0.24081590760033578, 0.250907750451006, 0.09797309670830145, 0.23037242033751681, 0.2782956714509055, 0.21026609610999003, 0.2111736239749007, 0.18490837945137173, 0.11960276809986681, 0.20893915090709925, 0.09638322342652828, 0.16884543903870508, 0.21009998861700296, 0.10046926588984206, 0.11605035950196907, 0.2289155696053058, 0.20904394215904176, 0.09760268338141032, 0.08170522705768235, 0.15391994384117424, 0.2106291992822662, 0.21721299912314862, 0.08549322301405482, 0.11324712671921588, 0.12682530476013198, 0.16637503722449765, 0.08877234315150417, 0.16599277179921046, 0.14406662725377828, 0.18585491459816694, 0.11839792103273794, 0.14496556104859337, 0.12814693618565798, 0.10997674165992066, 0.08586332463892177, 0.11529250798048452, 0.11316927542793564, 0.15355353069026023, 0.14719985600095242, 0.10272929110215046, 0.08263550174888223, 0.15328548179240897, 0.09107524223509245, 0.14019274996826425, 0.07758698280667886, 0.14791451452765614, 0.176324981439393, 0.11439945941674523, 0.15062596590723842, 0.19266604911535978, 0.2038836557767354, 0.14295809611212462, 0.13955543807242066, 0.2062866260530427, 0.15800073189893737, 0.0864631358126644, 0.10365891270339489, 0.25100458587985486, 0.16799904929939657, 0.1353310444392264, 0.19949362962506711], [0.020536285628622863, 0.028319770899543073, 0.015980703028617427, 0.013453439714794513, 0.062276750832097605, 0.017604542554181535, 0.058031803418998607, 0.03144119764328934, 0.042430196845089085, 0.060053024062654004, 0.002702106116885261, 0.04273823265975807, 0.02458789800584782, 0.004505669458012562, 0.046994056247058325, 0.06803115611546673, 0.04556396736006718, 0.020695108942163642, 0.04197628819383681, 0.03404586510441732, 0.04643431362637784, 0.013814213471050607, 0.06824931042501703, 0.018282446217199322, 0.08861321184667759, 0.04746928309032228, 0.022577043309865985, 0.044566821452463046, 0.0660784171486739, 0.010562427560216747, 0.0341866727831075, 0.05321206263033673, 0.011223503952351166, 0.04685255466029048, 0.03447598792263307, 0.010633997499098768, 0.027558358924579807, 0.012836997939302819, 0.0015091255272636772, 0.021523017348954454, 0.02153795492631616, 0.03356987384904642, 0.003405079992262472, 0.03436407947447151, 0.0164211120136315, 0.015243890466081211, 0.06554430088726804, 0.012418375627021305, 0.021920483814028557, 0.043061155956820585, 0.07302601778064854, 0.008065229576459387, 0.010056394166895188, 0.015947304527799133, 0.047532421303913, 0.030806537070020568, 0.013838909362675622, 0.05172743331058882, 0.03665802454634104, 0.023222311028803233, 0.19270285964012146, 0.02543815990065923, 0.06601097076782025, 0.025855987187242135, 0.059461083365022205, 0.033063666051020846, 0.02759440689260373, 0.03282994519395288, 0.10943644330836833, 0.21219412155915052, 0.14966071379603818, 0.06356099285767414, 0.00957695006945869, 0.09118600777583197, 0.06119770521763712, 0.06940917592146434, 0.08857994136633351, 0.0495811941800639, 0.09001014899695292, 0.007518681877627387, 0.023485740057367366, 0.033334215986542404, 0.05579724871495273, 0.01683033780864207, 0.033888474135892466, 0.19547881849575788, 0.22040868701878935, 0.27271662082057446, 0.20566605700878426, 0.09466174509725533, 0.33094487444031984, 0.16913705854676664, 0.28240927727892995, 0.12692570249782875, 0.07365449069766328, 0.2330378140322864, 0.22291107539786026, 0.3213486378081143, 0.18394306796835735, 0.06939584694919176, 0.127305964124389, 0.03356146531587001, 0.06915488644153811, 0.018889766070060432, 0.03060037772229407, 0.0961739377817139, 0.05271138383250218, 0.030857303681841586, 0.13595094555057585, 0.11259702761890367, 0.047757859792909585, 0.08536973706213757, 0.06340437001199462, 0.03329025857965462, 0.13723526179092005, 0.08488219056744128, 0.02035717014223337, 0.03641302675532643, 0.10097133621457033, 0.04919520688417833, 0.12301257302169688, 0.02610288116557058, 0.046146126551320776, 0.006060724881535862, 0.02742577053140849, 0.04741359603940509, 0.12454136012820527, 0.029698694270337, 0.08760125638218597, 0.0772895448608324, 0.030080184151302092, 0.04557919251965359, 0.08010681907762773, 0.03342244992381893, 0.0037519762827287195, 0.06580111366929486, 0.038013924640836194, 0.1011556782759726, 0.0796678832557518, 0.07692876461078413, 0.04299563544918783, 0.05556735733989626, 0.12231808606884442, 0.03774201286432799, 0.030649110849481076, 0.04261866524757352, 0.025326642935397103, 0.02255016086564865, 0.033050422425731085, 0.018823876343958545, 0.017242309550056234, 0.0622745614964515, 0.03805933294643182, 0.051492458223947324, 0.011391675543563906, 0.0590975015074946, 0.04442218800249975, 0.046486278806696646, 0.020776897326868493, 0.024091948544082697, 0.03972782564233057, 0.033918701810762286, 0.046503400153596886, 0.02125423929101089, 0.03329559833218809, 0.03651668252132367, 0.03307862774818204, 0.02807636872603325, 0.007740150340396212, 0.07074219931382686, 0.044969425434828736, 0.03163084606057964, 0.03089488975092536, 0.03497350146062672, 0.05919028109929059, 0.03201569415978156, 0.044854507577838376, 0.008680194478074554, 0.036216468943166547, 0.022808417124906555, 0.03553739268681966, 0.038379807156161405, 0.08627774732303806, 0.017992362954828423, 0.03298316900327336, 0.017137627764896024, 0.05322400378645398, 0.005257822213025065, 0.043824914973811246, 0.055807456956245005, 0.010520436844672076, 0.030955790389270987, 0.018324475895497017, 0.0281421341423993, 0.048550454957876354, 0.03182159285643138, 0.0657140597468242, 0.02609554874652531, 0.04876754057477228, 0.04690788919106126, 0.03444841713644564, 0.049244533729506657, 0.009228174058080185, 0.0421562441624701, 0.021042701227997895, 0.0015263825480360538, 0.02096262905979529, 0.08580377470934764, 0.027346011920599267, 0.06280270346906036, 0.08287506701890379, 0.0399454864236759, 0.06902766006533056, 0.04913580167340115, 0.02745229303400265, 0.02970666864712257, 0.008695626511325827, 0.01618444668565644, 0.018354438252572436, 0.03419281405513175, 0.03600340576667804, 0.005315200896802708, 0.03879271214827895, 0.0280519019725034, 0.02282019871927332, 0.049302655024803244, 0.03209523012628779, 0.06560955051099882, 0.018763756816042587, 0.0146147709529032, 0.09619046541047283, 0.02656918924913043, 0.03919448863598518, 0.020212293638905976, 0.08137747980072163, 0.010921432221948635, 0.041744381887838244, 0.06370761155267246, 0.03095398140430916, 0.04148844484006986, 0.05203670480113942, 0.06350395880872384, 0.061126640866859816, 0.030979832263255958, 0.11480946632218547, 0.19001177279278636, 0.051802649977616966, 0.09513133903965354, 0.025166359446302522, 0.09424672869499773, 0.10699911159463227, 0.09223363827914, 0.12779831973602995, 0.13887218723539263, 0.035767536392086186, 0.040965650041471235, 0.07374609398539178, 0.0612290052958997, 0.09880137062282301, 0.019241555201006122, 0.11875028532813303, 0.20180213934509084, 0.06674675081740133, 0.1188841019757092, 0.05216868834395427, 0.06926058311364613, 0.25818341004196554, 0.02687303192942636, 0.050164255080744624, 0.04678263692767359, 0.12327112242928706, 0.09778512554476038, 0.16840105585288256, 0.2152171265333891, 0.1386496765189804, 0.1352863819920458, 0.10383785935118794, 0.05915385278058238, 0.04868577445449773, 0.060190655349288136, 0.02695316532481229, 0.03682213937281631, 0.04771128260472324, 0.0720919729792513, 0.09429692014236934, 0.052853460583719425, 0.12344983901130036, 0.11755902698496357, 0.04359955069958232, 0.14835631503956392, 0.055388729815604165, 0.10224479483440518, 0.04030904972751159, 0.06488547413027845, 0.0464240534347482, 0.10504829479032196, 0.09218067862093449, 0.018389129945717286, 0.0743202787998598, 0.06396601253072731, 0.12138128047809005, 0.06255426953430288, 0.06047555471013766, 0.05642289404931944, 0.013461298131005606, 0.06773299086489715, 0.07798080347129144, 0.017441208838135935, 0.02389337580098072, 0.05333085820893757, 0.02971501224237727, 0.045482138157240115, 0.0326712332025636, 0.07653778637177311, 0.04159429736318998, 0.019309059098304715, 0.022387426433851942, 0.020669588338932954, 0.12486279912991449, 0.058017776827909984, 0.052089360178797506, 0.029033075006736908, 0.019899942235497292, 0.03707849944476038, 0.09944542864104733, 0.040400445213890634, 0.06388482157490216, 0.14668553281808272, 0.022382034730981104, 0.053008280010544695, 0.08636077880510129, 0.05151036995812319, 0.06509480430395342, 0.05924224627960939, 0.012975842637388268, 0.020713655212603044, 0.03724570902704727, 0.08245113742304966, 0.04373066964035388, 0.08033577905735001, 0.06765191865270026, 0.0235532792066806, 0.020011548258480616, 0.07077854228555225, 0.02134269401722122, 0.048991101430146955, 0.039541921360068955, 0.04386087202874478, 0.04514177067903802, 0.0498157054244075, 0.037476149591384456, 0.06935634242836386, 0.13203377136960626, 0.16991612064884976, 0.18638195819221437, 0.08972791765700094, 0.10160724545130506, 0.1323558040894568, 0.17944453982636333, 0.13306258100783452, 0.10984155946061946, 0.10154053379665129, 0.09641157346777618, 0.11595961710554548, 0.13341533864149824, 0.09010774141643196, 0.12965793401235715, 0.16552667337236926, 0.18674476450541988, 0.09786930735572241, 0.12927914183819667, 0.16754930780734867, 0.137316141044721, 0.16155373421497643, 0.20083565526874736, 0.12200067692901939, 0.22977580782026052, 0.11826264235423878, 0.10664438726962544, 0.13850455696228892, 0.21860084496438503, 0.0662421497690957, 0.09135554399108514, 0.17357430013362318, 0.15964346093824133, 0.09455549181438982, 0.14966758608352393, 0.1722614557365887, 0.15792014950420707, 0.1400830753846094, 0.12211835928610526, 0.11706100136507303, 0.0964130503416527, 0.09997040164307691, 0.18472693918738514, 0.1640672844951041, 0.13446887664031237, 0.15632539289072156, 0.25566966680344194, 0.16801721707452089, 0.11130675935419276, 0.2144099964061752, 0.15834492514841259, 0.15863146836636588, 0.11784898408222944, 0.07752579273073934, 0.16527919680811465, 0.26128911995328963, 0.11516703307279386, 0.2381946420064196, 0.18243912054458633, 0.12159516001702286, 0.36396519164554775, 0.19386725965887308, 0.11106303805718198, 0.09986043762182817, 0.3393311135005206, 0.19626994791906327, 0.08708275490789674, 0.12130695438827388, 0.2749560959637165, 0.3685144678456709, 0.45093623106367886, 0.24412029044469818, 0.18763589090667665, 0.11179765293491073, 0.21959183475701138, 0.3093136742245406, 0.1922108602593653, 0.3076816024258733, 0.1716258210944943, 0.2586932061240077, 0.14197034208336845, 0.12738449819153175, 0.20866184000624344, 0.22559953504242003, 0.191817284503486, 0.4403873736737296, 0.4649103671545163, 0.35788296489045024, 0.34872536722104996, 0.3436898358631879, 0.5800043209455907, 0.3687168366741389, 0.5660929705481976, 0.4649523727130145, 0.43463213718496263, 0.38254542276263237, 0.3675743448548019, 0.8223247993737459, 0.457051646662876, 0.3665790654486045, 0.3029959788545966, 0.1525074290111661, 0.345111790811643, 0.09287926222896203, 0.11846155277453363, 0.20241159101715311, 0.17716994625516236, 0.29054098937194794, 0.5768833227921277, 0.3995747136650607, 0.313314592349343, 0.27140765043441206, 0.10398130165413022, 0.27493988745845854, 0.3205406171036884, 0.19141492171911523, 0.22448144503869116, 0.15472069149836898, 0.22195070661837235, 0.2501765568740666, 0.21919125312706456, 0.18486301938537508, 0.18875463400036097, 0.18390673241810873, 0.28187846357468516, 0.20634657674236223, 0.22378701745765284, 0.1854262946289964, 0.2036167646292597, 0.22673576313536614, 0.12077126477379352, 0.13881818857043982, 0.19546510360669345, 0.12827204744098708, 0.10544285760261118, 0.15372710418887436, 0.14928008109563962, 0.15166314697125927, 0.27927851246204227, 0.16711933712940663, 0.11074228183133528, 0.12375892125419341, 0.26295990217477083, 0.11188387565198354, 0.28509496129117906, 0.1448889120365493, 0.06514185646665283, 0.16362870490411296, 0.13347474014153704, 0.1427254031295888, 0.10834826185600832, 0.31914647785015404, 0.07336195092648268, 0.11822267770185135, 0.1682517208973877, 0.1340237958356738, 0.16532439360162243, 0.16103635338367894, 0.08244657321483828, 0.11366642531356774, 0.18386776966508478, 0.15122717974008992, 0.16371170670026913, 0.2008366645895876, 0.15032642026199028, 0.12714077689452097, 0.11638799958745949, 0.08335006379638799, 0.10488361964235082, 0.12281471645110287, 0.1648944229236804, 0.14794762915698811, 0.12752290873322636, 0.09178880980471149, 0.1299349480541423, 0.14122798660537228], [0.05099095193145331, 0.03870861568429973, 0.01918459907756187, 0.03512639130349271, 0.027181880395801272, 0.04049976312671788, 0.045251096453284845, 0.0064377335820609005, 0.09149330886430107, 0.022048524697311223, 0.07994306419277564, 0.010613608847052092, 0.025404141706530936, 0.012446208020264748, 0.019344921529409476, 0.043877173302462325, 0.12301855473197065, 0.10802064076415263, 0.029200711323937867, 0.07399672467727214, 0.02514738644094905, 0.018704609501583036, 0.023810342463548295, 0.04879816900938749, 0.03062932148168329, 0.038137852170621045, 0.0259431505764951, 0.018567853949207347, 0.024892434594221413, 0.07762768960674293, 0.013265999186842237, 0.033155874189105816, 0.05887908744625747, 0.0637953334080521, 0.034914003481389955, 0.04220584931317717, 0.018066570301016327, 0.021404012113634963, 0.05086703553388361, 0.06045460017048754, 0.0044238625196157955, 0.08229252562159672, 0.05265770058031194, 0.02605047255201498, 0.03171302036207635, 0.07665525350603275, 0.03362152732734103, 0.009768516010808526, 0.044092782045481727, 0.07982399401953444, 0.03757410195248667, 0.06645162095082924, 0.022146274823171552, 0.06987996472162195, 0.05727440831833519, 0.029581453491118737, 0.03566373961803038, 0.03259935248934198, 0.029763697129965294, 0.017102975034504198, 0.06276064596022479, 0.07125543896108866, 0.04546335811028257, 0.03915206376404967, 0.06758751507732086, 0.03725211005075835, 0.015146337937039789, 0.03481939078483265, 0.073310267762281, 0.1392652138019912, 0.0606865510053467, 0.051222654146840796, 0.016512982474523596, 0.024873971815395635, 0.019421685574343428, 0.05774995057436172, 0.06188659637700766, 0.021712389316235203, 0.061886195617262274, 0.037277962765074335, 0.053535327315330505, 0.02828062260959996, 0.05366642399167176, 0.03452175988059025, 0.03597201291995589, 0.11246614987612702, 0.2060139164677821, 0.1607297721784562, 0.1431016720016487, 0.036727400511153974, 0.15975497604813427, 0.12846827128669247, 0.11332862937706523, 0.07467914430890232, 0.12031260266667232, 0.18927734345197678, 0.115398635098245, 0.15040600817883387, 0.07908360523288138, 0.02685440773348091, 0.04968532120983582, 0.18079367524478585, 0.014851681189611554, 0.02245225117803784, 0.0552740791317774, 0.0407362818805268, 0.060393131789169274, 0.10609000295517035, 0.11009443885996006, 0.09649595565861091, 0.1152185232785996, 0.18270872795255855, 0.008036892522795824, 0.061452035515685566, 0.06748832704033703, 0.02172822303691646, 0.010906800780503545, 0.0787371261685621, 0.07432434576912783, 0.06519386617583223, 0.012352129670034628, 0.03582396559068002, 0.022390036938304547, 0.01630900318559725, 0.04365505221358035, 0.010369928368163528, 0.04671758026233874, 0.022359612594300415, 0.034383972742944025, 0.021265109899104573, 0.036067293549422175, 0.03171402968291659, 0.015244509231706616, 0.03208653215551749, 0.03378744557267055, 0.026885858096648008, 0.013049781882727984, 0.015347207627200987, 0.013793772868666565, 0.03713545927894302, 0.0054080602694739355, 0.034489287208998576, 0.04948041794705205, 0.03444347814365756, 0.06506654332042672, 0.09578042881912552, 0.038053963507991284, 0.15777016145875677, 0.05775513818662148, 0.06327764829620719, 0.035688215648406185, 0.01655704007134773, 0.01395309063809691, 0.08273180283140391, 0.048347403353545815, 0.04184748846455477, 0.05617730254016351, 0.02058573121757945, 0.02038483740761876, 0.0694401680084411, 0.03153222947730683, 0.07937587783089839, 0.02486194160155719, 0.030994951666798443, 0.05394306695961859, 0.04845847317483276, 0.019943695551774, 0.05580704877502285, 0.034120536292903125, 0.05070593011623714, 0.0290978348130011, 0.030408081693167333, 0.02954448154923739, 0.0855621685332153, 0.041619504409027286, 0.006781657339161029, 0.032518235748284496, 0.06149316905066371, 0.0757420778973028, 0.05458586703753099, 0.022155013612064067, 0.030738335553905927, 0.010693515887396643, 0.021980762903694995, 0.06018941225192975, 0.0161443298929953, 0.02200281211116817, 0.025409101108380128, 0.03229086025385186, 0.045199847445474006, 0.011595985088206362, 0.021455079295265023, 0.006558838631463004, 0.07516768528148532, 0.08654625635244884, 0.04581471308483742, 0.08552589235478081, 0.01674111495958641, 0.011688688609865494, 0.07477119288523681, 0.039265460218302906, 0.09619415388442576, 0.02672764334420208, 0.04132721325731836, 0.023786302444932517, 0.07814048396539874, 0.04090709458978381, 0.03387387980183121, 0.048876562068471685, 0.05391256469010841, 0.07370261897449382, 0.01797146222088486, 0.05320492316968739, 0.020662098213506397, 0.053397020674310625, 0.02468344766384689, 0.037795428943354636, 0.05120423033076804, 0.11597834149142727, 0.039111984078772366, 0.059257341563352384, 0.0777230852690991, 0.06325769194518216, 0.038415782764786854, 0.0523969507048605, 0.0010620086868584622, 0.03681183465232607, 0.0181856460403651, 0.01686896473984234, 0.055197266847244464, 0.027518158640305046, 0.0576850423385622, 0.06864058552309871, 0.050388906893203966, 0.01686561394308228, 0.018900629256677348, 0.022127184929559007, 0.05249029432889074, 0.07851120157283731, 0.024178848470910452, 0.06801845054724254, 0.01194477130411542, 0.008749150201765588, 0.06255743850488216, 0.03477204547380097, 0.04698713943071198, 0.047757985958014615, 0.013786250274279155, 0.05007733103411738, 0.0742772787634749, 0.11903541104402393, 0.023303138332266826, 0.04767775237269234, 0.05753327684942633, 0.09153337741736323, 0.047980385352275334, 0.06380682185408659, 0.04251936959917657, 0.1050631822727155, 0.07690066689974628, 0.08288388373330235, 0.16480134276207536, 0.08016720763407648, 0.01845794373366516, 0.11002023893524893, 0.01443914541596314, 0.03792716015595943, 0.03970180594478734, 0.13765481271548197, 0.08531521147233434, 0.11693107357132249, 0.0824816693784669, 0.07956549656228162, 0.25337473838590086, 0.08279846253572032, 0.0923860605689697, 0.05723723414121196, 0.2282201623893343, 0.07555615506134927, 0.07014621762209572, 0.0306754645134788, 0.06925046764081344, 0.07027380022918805, 0.027765861559601035, 0.1284892889088951, 0.044886019168188795, 0.0666054904286284, 0.0651602988364175, 0.03430075572396163, 0.034710343315964565, 0.06416736461687833, 0.018312490210519172, 0.0242886789055774, 0.03366385572007857, 0.04858572923694737, 0.05464999230753165, 0.02666661839612061, 0.016931030550040305, 0.029241907941468526, 0.04256556829204783, 0.051799035718431696, 0.0346394904772751, 0.009400342114531668, 0.05002237870940007, 0.06124188155808952, 0.02936441796919098, 0.08456774259684607, 0.0311676123237703, 0.02894797293265583, 0.032908776120166294, 0.014673510086140595, 0.015515616705670254, 0.031334187369793653, 0.024777251419436652, 0.013107120212225709, 0.015318148834921885, 0.07009211505646817, 0.009112208845181158, 0.04359750608273316, 0.03819645586190745, 0.02725692822423298, 0.016723368353268597, 0.02543224869441474, 0.0700366469391156, 0.03438010244281031, 0.05741263332311064, 0.05185897527553607, 0.05262097911327146, 0.017520288383821025, 0.02495035922038369, 0.022440575339714997, 0.04368600719317328, 0.01379689916575444, 0.030256123245635536, 0.04797776557097677, 0.05398535453423392, 0.015841739586903714, 0.05703287635697052, 0.052336948065203615, 0.07201835935120471, 0.018189482943853363, 0.015104480808076914, 0.052770284382859245, 0.07182701883721165, 0.021872227516723797, 0.014769184981560102, 0.0429520416946616, 0.08013228216441348, 0.027812435037049, 0.027106485613330733, 0.041166118971887045, 0.039613163826288655, 0.16384722286602482, 0.2120981173356995, 0.10526726546231657, 0.14802957710344344, 0.13743788294959813, 0.1474346566828899, 0.12358408610452898, 0.11167061209562235, 0.1505739413551055, 0.10045643415651284, 0.1348122683702968, 0.12000447037280537, 0.17131270898971707, 0.1892550048069097, 0.09959243325283751, 0.16062132955994457, 0.2004778807167895, 0.19823064270894974, 0.15129695646464825, 0.15421371557749808, 0.3429612546460703, 0.11883765095262788, 0.12060781416948885, 0.10975749639328569, 0.25594607228413224, 0.20759936654940248, 0.11328824170050211, 0.1144426672544796, 0.12254640038008802, 0.1932809778372757, 0.1710501074558124, 0.10404809494502842, 0.18476248806109652, 0.1514484139624983, 0.20658805675338954, 0.15035477030323818, 0.08308687596581876, 0.10896389561821707, 0.14186281972797588, 0.1784791095997207, 0.1134004766936414, 0.1102308084955439, 0.18468333058990538, 0.17541072971653193, 0.14828012615907937, 0.15145682991715148, 0.16662646201439202, 0.19711114262463525, 0.2343269987613894, 0.1646901690401137, 0.19829627824947238, 0.13626019848743454, 0.11477264837594703, 0.1690962997963652, 0.23905422713141888, 0.1896540872985497, 0.14508317661238834, 0.11841176950838417, 0.2768111682962626, 0.07933891887660138, 0.24715359642868862, 0.16771244670962915, 0.17053110874257982, 0.11592556737014093, 0.27215849608182907, 0.14012511062901467, 0.16534284339286387, 0.17107887309975922, 0.22324927209410816, 0.2783148782327771, 0.21095708012580872, 0.157102792582009, 0.10753392547485419, 0.10691045463318005, 0.2789945073891431, 0.22336023801472038, 0.16690653370460495, 0.2189872515737079, 0.365879813907668, 0.1634996899520047, 0.13058355543762445, 0.12683235516306013, 0.13452336512273178, 0.16711930744349957, 0.1967444474576041, 0.3292733203852549, 0.5520819348748773, 0.60140251647681, 0.4473789094481617, 0.23238519905135036, 0.3166082437383011, 0.2939979429356754, 0.3710967261577025, 0.2974528184859082, 0.2985268842894584, 0.32416206027846783, 0.29203270620200783, 0.5369517998769879, 0.20008688763482496, 0.1888267113827169, 0.19680629804497585, 0.43048281921073794, 0.16790714173112065, 0.12651210359763354, 0.10098657250637189, 0.2742744778515771, 0.1554231342743151, 0.1758733845781535, 0.4111018998082727, 0.26049796084407717, 0.2414208767004311, 0.1942605830845423, 0.11157126820762642, 0.12600729474797845, 0.23125054431147873, 0.17219774978002533, 0.17369298439007252, 0.22570799250388518, 0.26436425338033587, 0.18034106906270608, 0.17097023752285168, 0.13250107207568362, 0.14377002051332965, 0.15874740667641163, 0.13280885556014255, 0.17634004703722894, 0.08534769527614117, 0.1516025877208449, 0.12861229246482253, 0.11963842087425292, 0.14597770205000415, 0.17594219651073217, 0.10020586283644661, 0.09606090869056061, 0.14222800091374665, 0.10103674911078997, 0.08055781479924917, 0.2033281879266724, 0.10439797304570675, 0.08471981607726775, 0.0938558617781382, 0.08332523153512739, 0.11172400962095708, 0.09677781592472456, 0.13599786412669346, 0.24264176900032908, 0.08978288853541017, 0.192774981551338, 0.1541375563829206, 0.14918183558620512, 0.09442096270504408, 0.13516502600396052, 0.09237424557795748, 0.12183660292066634, 0.11616318821324967, 0.1857922031194903, 0.13087366096442565, 0.11627818399574608, 0.08920710068196058, 0.14759309036890045, 0.07570956440758891, 0.23052193340845406, 0.07623749857884832, 0.13503961788956076, 0.13046568754361942, 0.12835288216592744, 0.08444481325568631, 0.2611029299441725, 0.10959014209220186, 0.1437148344120942, 0.10505346013815142, 0.1435802088235505, 0.0907038344303146, 0.13185267249355093, 0.20062994677573442, 0.08980717160739005], [0.05562146361626219, 0.06802066214731894, 0.02759588747721864, 0.08949308728915639, 0.03203376545570791, 0.05496154219144955, 0.009532510266581085, 0.038019950879970565, 0.007726960056970711, 0.04385613341582939, 0.06463580080890097, 0.03253300819778815, 0.05038272851379588, 0.032957468429231085, 0.03930544713512063, 0.024283764032588806, 0.018112275465682615, 0.019167140053468756, 0.021435972703329753, 0.05285727522277739, 0.04057375525007956, 0.024766826099948958, 0.02905590161390137, 0.07173784237238578, 0.05502413121575955, 0.018436742429912556, 0.005617252218144131, 0.07192873017629609, 0.06557701475685462, 0.059875873412238434, 0.02767563310044352, 0.08967899528215639, 0.07443403519573621, 0.015857586295169313, 0.004363718408058048, 0.019155354748363607, 0.0970107909233775, 0.053363809565780684, 0.034259106396348216, 0.07015298600890674, 0.01699275311693782, 0.021809178360854276, 0.08872647842508741, 0.021256517684378196, 0.012170742284070002, 0.08164123908500187, 0.05933327440288849, 0.07159768036217429, 0.01945784857525723, 0.055821205241954885, 0.033132106909761205, 0.04421305078722071, 0.06722478297888301, 0.05301989091094583, 0.020936724395141937, 0.03484869819658343, 0.05854446048033424, 0.038314431367325597, 0.049243832399952225, 0.03714954153110739, 0.043888902946491726, 0.017094592476496473, 0.06175370370328892, 0.021575943610514514, 0.03767139380215667, 0.012873471714556217, 0.025343613997392822, 0.061056934646330774, 0.028157869528513402, 0.12640321569051594, 0.06535356893436983, 0.01074908326700097, 0.031969762640073895, 0.07773377961711958, 0.041509714792482555, 0.04560191708151251, 0.025905653565132525, 0.04753181645355653, 0.08871770623954944, 0.06327466486254707, 0.07497593658627011, 0.05878798139747232, 0.04086129294591956, 0.037371903817984276, 0.02705795286601642, 0.1568543363828212, 0.08409882400883362, 0.04626926369383, 0.2272830079891719, 0.05625409998174291, 0.14615739084547386, 0.1340766961220652, 0.06431440633605234, 0.04964547530107666, 0.12941612745635211, 0.17172911320813, 0.04523098425124772, 0.1250278379302472, 0.03189318042132072, 0.12241361531778239, 0.05996309802867472, 0.07889949323725887, 0.08845736825605854, 0.012054333637934178, 0.03293852510978468, 0.045805640329490416, 0.023264624578587245, 0.02591812164610019, 0.05787425659946166, 0.06133853145001922, 0.025010384124470875, 0.1384730008430779, 0.06964332351344638, 0.03988097894762177, 0.06902580469613895, 0.07980378533829935, 0.05982482849503867, 0.03546927466231864, 0.022067310310376342, 0.042680033438955434, 0.04541148940916173, 0.06370124392560683, 0.03547038788383361, 0.0455521672120085, 0.024193401986849494, 0.021006239512644242, 0.019778851565206423, 0.03916036839655135, 0.04137203155551106, 0.056097221095114946, 0.02652697774465196, 0.042751379805849865, 0.02431273376714671, 0.08580918496591039, 0.05011335859308019, 0.012676423157245154, 0.010459128025104292, 0.056367989964201115, 0.033191437905770727, 0.014170688336889725, 0.02454594254231779, 0.03539129720593337, 0.02108035780111095, 0.02953172217530664, 0.010755271850939607, 0.04267375115887262, 0.015533464429609012, 0.026925587117148098, 0.0171208348183427, 0.02328892620425904, 0.02873391713364981, 0.060793498196289875, 0.026669343933463097, 0.025888391210173722, 0.05976458465738688, 0.04089425172423944, 0.02215669272118248, 0.04261434223735705, 0.05441689856525045, 0.023696081407251768, 0.05513588010217063, 0.07005810242844746, 0.06699364850646816, 0.05420985420641955, 0.07227390306070447, 0.0750792954931967, 0.012633116984943626, 0.03144187299767509, 0.07860978104872629, 0.028888307970191818, 0.01616040666704066, 0.031062453708727844, 0.06385585555108264, 0.025651338110037614, 0.029231144944787957, 0.034312882416998036, 0.005649722570524318, 0.03891751170158386, 0.012012439401587471, 0.023860023684392218, 0.05552849477680866, 0.03911300824256614, 0.05193368728214409, 0.04652120056562126, 0.0015597590163451969, 0.07275350857526064, 0.07276052929228172, 0.024812483025016263, 0.0781828309118282, 0.05327443272108212, 0.04216676781652495, 0.011516218128235778, 0.04066351059009321, 0.03801888960879296, 0.06220538591151126, 0.015004482902440941, 0.07758310879580677, 0.027690947317751125, 0.004420827599460608, 0.057615061523392797, 0.03579421289032325, 0.04254071747709531, 0.05195235971768852, 0.03899046852893662, 0.05649187296512537, 0.01710796783299884, 0.01074052908734302, 0.0112778746188269, 0.048523121658945456, 0.005017000394218485, 0.01945529929798795, 0.04386024491395801, 0.02203988053224748, 0.017703131306916475, 0.06400697166100144, 0.008264191947091604, 0.008002203612704761, 0.024482789485773537, 0.12056190491421148, 0.02167109621950658, 0.010928282245004084, 0.055280765882343985, 0.05944091179117095, 0.026528198577580042, 0.06213574277353473, 0.04608267292496748, 0.051261728222016245, 0.022249021458264906, 0.050223493308294564, 0.056076552282320336, 0.044011038189637475, 0.020694101476692595, 0.02010360982239945, 0.043757067833212204, 0.056115110564860515, 0.020853190108027775, 0.05096980443340726, 0.018790585454553366, 0.02074948795780074, 0.02503627951227827, 0.03862238554575015, 0.049493646729388274, 0.037836833362234756, 0.0649717339547351, 0.06941749539691955, 0.031092443896341138, 0.014600344529753784, 0.018848847757908516, 0.034550659111118875, 0.04527500474068802, 0.08811730134766549, 0.15732637199107558, 0.041864865852403454, 0.012834482058678987, 0.054303112483466975, 0.04014149133581668, 0.09995120228268206, 0.06718962744344026, 0.056955882246256806, 0.017816407162172254, 0.050914896637550555, 0.1237727103580255, 0.05392373030190356, 0.03618720977101475, 0.026279222875018604, 0.03420514854951762, 0.05004453923902474, 0.025464975551585667, 0.03840333694824949, 0.017326313245575875, 0.027947073613177054, 0.11125542499939911, 0.04038463746837806, 0.12389659706968814, 0.07015075214440003, 0.014177735029079486, 0.04980582743883133, 0.09137279150309041, 0.07963369251228869, 0.050735218974296004, 0.039150393931777216, 0.03673953462566715, 0.023089743044693023, 0.11276515375357121, 0.02618236147100106, 0.044063251989427954, 0.02728699633735232, 0.010960792023979593, 0.006928824295755476, 0.08948911679908633, 0.0774196804559324, 0.022461561420641374, 0.05951300772721879, 0.05360156028473284, 0.03872273133310955, 0.06524846598040313, 0.009438699089514557, 0.06841255322797224, 0.04384723135444801, 0.025026831972354557, 0.025757687872101087, 0.02980459317768691, 0.027329395234119147, 0.06513888787594624, 0.04164737205428537, 0.052550363761838526, 0.04249147226801142, 0.018749114242382348, 0.02841450976120541, 0.0663587634335272, 0.07833650743123144, 0.0344431812845869, 0.07970674952957779, 0.03694364379043691, 0.05993951628624927, 0.06367553593008779, 0.01890189461846603, 0.01855393868027022, 0.06272490412811749, 0.0429539007745916, 0.01639750615140656, 0.01950392481376184, 0.06007047566527035, 0.05758849634730723, 0.040255540880025364, 0.026764869471662678, 0.041372076084371656, 0.054652159378747456, 0.06982132021221332, 0.021642133906425443, 0.026182376313954592, 0.039469899638788775, 0.04245950054610148, 0.022049155522836372, 0.08325451970449649, 0.06901383385411464, 0.048167866698349826, 0.01723786408547312, 0.027628506722976454, 0.020604463024938013, 0.031267308731912635, 0.04663507941586431, 0.015621522106812336, 0.025253049716411624, 0.0551408005412668, 0.05881342221982777, 0.07894576614489779, 0.011114411026937887, 0.04259418179572094, 0.05013300324208103, 0.04184390760201495, 0.06491157546406612, 0.14271802618168294, 0.12438309713616036, 0.08378712940611877, 0.1622478204080835, 0.14037384884431958, 0.155849898874294, 0.1514737805700861, 0.1915352832293138, 0.10677347643650137, 0.12358662424958311, 0.1558958675013855, 0.0695867495960556, 0.15555801219306886, 0.14429224014747888, 0.21937135752523318, 0.07568416811409406, 0.10590963138383813, 0.20842797443037853, 0.10533450404182076, 0.09713567953440361, 0.18623449344886467, 0.15726591664133593, 0.10430739392177202, 0.12551032297778875, 0.12021038666716777, 0.11360834483639337, 0.19684328668517992, 0.16257012030109763, 0.1577641352196224, 0.11831116396933794, 0.08269289202871732, 0.17890473129227757, 0.15809336677193642, 0.09847670327872038, 0.14617772569181398, 0.21651183284120634, 0.16605244047241285, 0.15209874312859029, 0.1845769808278419, 0.11453525017714128, 0.12314640451222658, 0.08608668140368536, 0.23830562276998535, 0.10164355131564662, 0.07010721776168793, 0.09381747790030204, 0.13485583243891597, 0.16543289559194818, 0.13953833898995072, 0.11497806743136607, 0.1321917152381502, 0.06171789136715233, 0.1343528344295919, 0.0819003525248263, 0.135836536064744, 0.11902538462891243, 0.10968948598019779, 0.12621190486242995, 0.1539113200851716, 0.11284462292678654, 0.15335407108068466, 0.09699027796159498, 0.24877253221347928, 0.12206852406961843, 0.14543453900841996, 0.1916605280712247, 0.17416482703993097, 0.20441527100047097, 0.1572098844917491, 0.24395703279878944, 0.2680388046428561, 0.1202349888626486, 0.09446992218727246, 0.19257702108006924, 0.3661523899063468, 0.2457648006384261, 0.10246165780699812, 0.2493399486411363, 0.18912652420112863, 0.08723467253730632, 0.14618529559811577, 0.11335390692693181, 0.15144353063078597, 0.1787387573858723, 0.12936141632962972, 0.7303255016449839, 0.37438138271681964, 0.15453266096301377, 0.34683523583225906, 0.23935421806527302, 0.2574461605399847, 0.30000515340361744, 0.1622885643155314, 0.2296763748745434, 0.25514425593428314, 0.3216118924319744, 0.28370040643494576, 0.43102013412863016, 0.37853049288969487, 0.19574890087824315, 0.11238927079830319, 0.24359958479180932, 0.24636230373289436, 0.14191187568940222, 0.10714558186009526, 0.0812198179482948, 0.12074312995537184, 0.1890218665357679, 0.18589179933769628, 0.21040170133346692, 0.15708483260823414, 0.27741239697206765, 0.10041640271083452, 0.19765939679928124, 0.1459949792479165, 0.2112092322204262, 0.17918964178534225, 0.18818071635905653, 0.10286398348398507, 0.12651185126742348, 0.13494204031303525, 0.15275545476470143, 0.11357120776665397, 0.13561170984758064, 0.19811832607956603, 0.14776664902456105, 0.16554117493797094, 0.1392535472405143, 0.18398844287730753, 0.17982953635510057, 0.1964708769810386, 0.20156698243226856, 0.17281938751693815, 0.2469760153326206, 0.18667350348550826, 0.0834847784426529, 0.13425150158582255, 0.15873461205046624, 0.08305008770548739, 0.139869500126224, 0.09905378246912733, 0.13147190620657057, 0.12056658044457436, 0.1693107359460555, 0.09451349367736839, 0.2405053484835662, 0.05609411520708818, 0.07687546356464736, 0.11692665037116967, 0.09725807452923618, 0.15279619867214933, 0.239328064781148, 0.12541672331281006, 0.12121325824409723, 0.20282467041397467, 0.082756969059119, 0.16697516752174124, 0.11476828454760835, 0.13199181033996865, 0.13908401102526113, 0.14769396308111027, 0.20403597416589037, 0.1538804467418231, 0.08619338739663363, 0.20210785965900868, 0.21077820769278333, 0.0649963435716927, 0.07827548804925755, 0.11131314182421193, 0.10792102970299311, 0.15397910785395652, 0.15254621364874765, 0.160362156748306, 0.1346355926943943, 0.14498159143840894, 0.16085179609945044], [0.0751004763878882, 0.02763762400718406, 0.08006968200788833, 0.02494983229553327, 0.08465056627755985, 0.020141375862294808, 0.028651548018387984, 0.04516536355367862, 0.08195305243134499, 0.059542652816162445, 0.020337358510005288, 0.03292436864285264, 0.010527531776460819, 0.015256083952408517, 0.04195958244963549, 0.042221003968734294, 0.03378844747203402, 0.032381639757659286, 0.05034621113736648, 0.052136030135443434, 0.05649808845191728, 0.017725234320096206, 0.021936696030024905, 0.0174295311444439, 0.05511244678928051, 0.06083888052671682, 0.03759791376069188, 0.026659438117349055, 0.17051101138349622, 0.021411270317912567, 0.03490258182864636, 0.04934479788062163, 0.054268936582957394, 0.04894997531664558, 0.0810276017000433, 0.07303256352315657, 0.01584430741786491, 0.025919973304553423, 0.0453073438256979, 0.02094705694617005, 0.022143428686831612, 0.03478493286820594, 0.03586924030969385, 0.03518949983117636, 0.05670729988196399, 0.02910095739935059, 0.021203830765443854, 0.05892595407203771, 0.04877307699644007, 0.037711837139795534, 0.10985149681800976, 0.068219216336729, 0.09570022491971031, 0.05340757401427254, 0.018557916591817047, 0.030267389047367033, 0.033784617990022525, 0.06316447819699533, 0.028655520363827236, 0.07978135021403432, 0.05146381874510553, 0.009422113944310695, 0.05339356226613745, 0.038191524290596135, 0.02537969165132381, 0.0789304259524215, 0.03917396083124913, 0.025165114493574947, 0.06935559285921045, 0.12131641677115113, 0.027447431966720615, 0.015343893010140164, 0.06531724822707474, 0.02996756880747853, 0.026886991727224085, 0.08972681185696274, 0.05310065513185691, 0.048737405668362044, 0.07461419896571897, 0.05924867327848915, 0.09108975122217089, 0.020289235799282324, 0.0628052193496842, 0.028259476966923103, 0.012608402539626695, 0.0818272732431069, 0.08346995775355026, 0.07940304785734043, 0.07749598065856844, 0.1352634496288374, 0.04813276682398282, 0.0682751668500714, 0.0766747200395912, 0.0478280818060739, 0.03208142989024054, 0.034495287472964264, 0.024364231394429225, 0.046689775699633174, 0.05044989287853241, 0.03484547727566678, 0.06832358456449583, 0.04114433322683908, 0.07188800111180171, 0.1057011992088519, 0.020671989186666906, 0.039870266045909375, 0.1350261553307064, 0.10769898653961718, 0.026682611678552348, 0.037728958486695774, 0.039343300377367996, 0.08475429625832476, 0.05374588574341033, 0.061798566530342214, 0.03837157302768901, 0.1393180398736149, 0.046455294141196646, 0.05126726464368403, 0.034600453509483486, 0.03590835149225313, 0.0805703125661239, 0.04634153032384347, 0.047578538360539824, 0.033973565077758394, 0.044004588926327415, 0.008776713566476246, 0.027946745212830137, 0.022433588019339368, 0.02928089666966116, 0.034669788656174205, 0.05454821417515632, 0.09158613669569604, 0.02373349307163153, 0.028157218293927144, 0.06412850576452911, 0.07047278486425057, 0.03875457317917608, 0.04073897216585465, 0.02957510070700664, 0.048054841317934915, 0.0636068130552303, 0.03802316066867206, 0.009162794558505993, 0.02734082801907789, 0.0307161212185747, 0.06965566542930901, 0.06859204164356925, 0.047139168382273056, 0.06787709367927164, 0.005418046330305515, 0.02450726922688773, 0.007451423352904385, 0.022244028659770265, 0.05469155999890063, 0.028190557422931306, 0.05153186997631565, 0.04199269707896747, 0.011976693858741783, 0.02330573770450428, 0.02193092954257736, 0.01749999435560312, 0.050012656574836, 0.0750173929554876, 0.016571194682910573, 0.03755104342417326, 0.03450719523243606, 0.006944317556190072, 0.026809641385625582, 0.025530095299473032, 0.0637903090682812, 0.026664785291359294, 0.04529797050054185, 0.0070764652991783805, 0.06871441437397152, 0.09153540348052047, 0.11251238567638211, 0.05089731144835241, 0.03273679823905695, 0.07982730399817228, 0.039771493611624464, 0.07226178378914483, 0.035870049250661395, 0.039374422340188175, 0.02872019111237023, 0.11771065517677926, 0.04689431159931701, 0.029979007158544846, 0.04327099450165406, 0.041626239399192855, 0.07675174012547359, 0.08475702736177482, 0.0763238623039797, 0.030018712059245445, 0.08621724002296105, 0.025138146702374797, 0.030594368181482423, 0.03712257559527643, 0.0331739157991251, 0.011456865795480553, 0.007745211787550943, 0.004946942581227631, 0.02420978489681147, 0.04607715134625323, 0.01586431015311973, 0.03885327882017009, 0.036487709076027386, 0.027314248000038788, 0.03303697470983025, 0.009488028717896668, 0.03891246138664428, 0.027479416676214896, 0.09766903138370253, 0.06870898927445523, 0.0391194352414459, 0.047390155305038206, 0.025081363128265366, 0.023514142048952635, 0.061312463512877, 0.06371950075845234, 0.030525392976414878, 0.014393785349966493, 0.03797153687628452, 0.018639686422829982, 0.030676815222250298, 0.03154715035634581, 0.09249577226000838, 0.0585874048556434, 0.017877949758258183, 0.06402111699571833, 0.05583720594586339, 0.011325623472657753, 0.017381508623657282, 0.02979725704790326, 0.013330304427654482, 0.015555921818304341, 0.046109724207781255, 0.008072679811448324, 0.05371699764509685, 0.026819662234629504, 0.010066042086691596, 0.03482767686364241, 0.01578894505655626, 0.03444157453486696, 0.021807820230606012, 0.06650547860772349, 0.055888109855004586, 0.04414013477799017, 0.038033929231460206, 0.0628312019398436, 0.05258269542537164, 0.0701372598996386, 0.14465379965258762, 0.1193688579951413, 0.08891333636711352, 0.03550645997165702, 0.047310237132478505, 0.07844497231417336, 0.05140331886650529, 0.043094263164675795, 0.028523894907266367, 0.04070085546118207, 0.05759904226579238, 0.022527044820890296, 0.17316686105914414, 0.040968013781821355, 0.055054566691978835, 0.03878146490023937, 0.06307956165983342, 0.08882372945663519, 0.05385771255532745, 0.08064395588007756, 0.03195204757503234, 0.070033900992712, 0.058419727720320225, 0.009825719826039858, 0.03326437989016995, 0.023031528980936855, 0.02444002322590677, 0.06677682264125906, 0.05469217227073386, 0.005798836273243069, 0.019106901781924535, 0.02365038551943144, 0.04223286348860711, 0.06231373205082491, 0.047444777374039404, 0.028160361289337743, 0.06296557519817725, 0.03978952780016698, 0.10112986637977883, 0.04776693996973336, 0.06817981571657583, 0.036526805415633135, 0.03961595430155285, 0.03452866556472145, 0.047594513089279644, 0.019209769016015343, 0.05433277241536416, 0.08619281594292261, 0.03215341079339851, 0.022115267893241253, 0.041160953624057584, 0.05608728744846303, 0.05781923377071507, 0.03553834634658415, 0.02330265037016943, 0.0880947252153419, 0.04322971995861735, 0.06770927924662828, 0.023387463006656617, 0.04378202625957783, 0.0655507278861478, 0.007379064418273629, 0.049385846068616956, 0.01695581086096354, 0.03137578103633132, 0.016563953176955692, 0.014335087962535908, 0.04146066254179459, 0.04063984350068495, 0.022930505983822513, 0.036134049732936546, 0.038303896581055596, 0.004738337393064285, 0.062224926659837365, 0.08777978000580333, 0.01330682287516538, 0.040208822683780454, 0.06138610311609227, 0.020255774215911515, 0.023183548655651975, 0.010276186767441686, 0.023840330795792397, 0.010493539557501208, 0.016243217360170092, 0.03771770010644104, 0.02393202685198048, 0.07303393649635836, 0.10533241860684939, 0.012612449099833611, 0.016168227048183326, 0.046317217565956526, 0.007801050978741841, 0.026926525933959056, 0.06852892940514721, 0.023230493206938263, 0.019102315309282858, 0.02595939989987528, 0.015595198128721677, 0.03679448695038445, 0.08114263458992355, 0.01453119399229763, 0.160523722297512, 0.09606070088921115, 0.2023205443401821, 0.07439935463480651, 0.14872309926431626, 0.07786015252349898, 0.11196327803190798, 0.16568847640883178, 0.2874065435025841, 0.14586382691049948, 0.1443109571118839, 0.11110176332294941, 0.16389112832257524, 0.10048646887298673, 0.1711764803621918, 0.11412635649321601, 0.12335349339991808, 0.1982033168314956, 0.1386175860534422, 0.10903972084634006, 0.19308013783302158, 0.11824855639133602, 0.09755978724570014, 0.06730716879246756, 0.2061280736234039, 0.1368011350859888, 0.1095702599559445, 0.06831798877101392, 0.1993439978105016, 0.08869407625752501, 0.1092851565044839, 0.12518327333964407, 0.0895534610026516, 0.16468004614580423, 0.1821327768266201, 0.17683455487713218, 0.07301095218281262, 0.13922544952947646, 0.12783688172930852, 0.12082701490726322, 0.0845803516858723, 0.21577148116193712, 0.14596725261071697, 0.12082933782949112, 0.1174836173595395, 0.11117807094706222, 0.11652342669549398, 0.17073414550395682, 0.08801699266768992, 0.2779602207010612, 0.2282198061584495, 0.14207805739715695, 0.12840827606851235, 0.16374100669054314, 0.20800180354854092, 0.22706643445417285, 0.21203552460065112, 0.19320873718243092, 0.1284515581210144, 0.18542031291872263, 0.11648747706203721, 0.10230437444988638, 0.12928334239404649, 0.04881201377429534, 0.13114169501932338, 0.14352785772643983, 0.2393747607129626, 0.11843692831462249, 0.2562769810901955, 0.15205887495540082, 0.16453044401714578, 0.22468430368462577, 0.1655463402858004, 0.19659708661492914, 0.17064781888620928, 0.25128211942501366, 0.22101481386926025, 0.13195477717090398, 0.18758551392238587, 0.10657718579750508, 0.43962150695733726, 0.14317799446871504, 0.17294724471867085, 0.18078359687933698, 0.1910388161195442, 0.2728611318161711, 0.159749677113723, 0.27484602062031627, 0.18730372044956312, 0.45510339026805013, 0.2686661569168791, 0.17675836599664763, 0.169004496128764, 0.15871019539190456, 0.22448914853157476, 0.22929679602384567, 0.28621076548006386, 0.26379363087471575, 0.18460510822478682, 0.1303636867669411, 0.17569149902556092, 0.19753207394387573, 0.20995584869524464, 0.16207494452828541, 0.0704892679641489, 0.09370258601848036, 0.19653038238175213, 0.15332377661252394, 0.1679229346336797, 0.2481326079578139, 0.09939606097759679, 0.1650772732682526, 0.14732263691257685, 0.29647033370565623, 0.2812871499918401, 0.24154388025635853, 0.1910749141825363, 0.11610916728386655, 0.08620097214588895, 0.11265018765698187, 0.16188522189622745, 0.1985311828320846, 0.11661100012133829, 0.1425397623097524, 0.09608274267520756, 0.14685031928820536, 0.08749593078391626, 0.11615803028689697, 0.10649626201484352, 0.06686259264824912, 0.15307952096918598, 0.2434147900203243, 0.15336591575760394, 0.11437026332714595, 0.14788111788220704, 0.21793632593471557, 0.10724517807830125, 0.10965735840727575, 0.089526372612454, 0.09987890225602314, 0.12065572722349316, 0.06812730134697631, 0.13447586767142639, 0.10137352830497548, 0.11213938225409947, 0.11614200731855817, 0.16345204407116398, 0.08173215217539109, 0.3077461099019274, 0.17343654268188402, 0.0469763782894006, 0.14910947618773207, 0.17317484656814486, 0.17858856153907254, 0.132482533226721, 0.09275329750380479, 0.11105773170129396, 0.06199622272106353, 0.11532827207702212, 0.16479147219797596, 0.10845188051462173, 0.1703478576382622, 0.17706668382743374, 0.06683147439616732, 0.07375410918029957, 0.11092145112343132, 0.12358522901195101, 0.11140244445414282, 0.09212840173859149, 0.1354584118234925, 0.06962157858652063, 0.10837136491318233, 0.09899057375150733, 0.15533946454524994, 0.16903182200621814, 0.17457535344874486], [0.03400433452043217, 0.04760514435474761, 0.03788545887800865, 0.046248706203186885, 0.027939520405197982, 0.024426738782494795, 0.020010457301395945, 0.04201381860184483, 0.04136472140089609, 0.029583256909972988, 0.02142833785910625, 0.033097107225330546, 0.058173987781628966, 0.04902910681266803, 0.06976471660891548, 0.038378211538656615, 0.03830525471130386, 0.023262626345967874, 0.024052733460848685, 0.019372175047465134, 0.009885570325423032, 0.045129580903449096, 0.04046153881063219, 0.04561883062706329, 0.017265813366975635, 0.015426137815666152, 0.06804743883549236, 0.0457790640211897, 0.01059234260537778, 0.0056932838560896926, 0.029452507187670562, 0.0439041132631246, 0.018209188820037525, 0.051007423899136484, 0.0321629065729212, 0.029937372673884965, 0.05822401595651172, 0.03532929076754954, 0.0209613878178061, 0.034146162652177736, 0.0669342173205223, 0.06485420744866133, 0.06546813427121378, 0.01000609696347965, 0.07007353167864494, 0.037911827384959906, 0.06667567533440888, 0.02485794699168764, 0.07246180000947788, 0.052003738601342775, 0.028130174432590138, 0.045253300631884485, 0.027005477459169924, 0.033187189110321924, 0.023142006939451676, 0.05957714041869622, 0.05336565009201877, 0.06702039550873451, 0.04501497845922131, 0.02691424153454136, 0.022644287455477752, 0.0404047014308162, 0.06082902480557095, 0.03213700561900623, 0.06617871098569594, 0.014972703211242333, 0.042492808133829385, 0.047752879981999286, 0.08375415578484535, 0.07648194718058221, 0.0679207690700423, 0.03391459773411043, 0.008688373873155797, 0.03967969365476165, 0.05181094347790349, 0.050350701130810194, 0.03192938238498755, 0.02105331208440475, 0.06549272904521786, 0.02021711945417337, 0.07655550143681467, 0.07693591149291024, 0.0031213202919389005, 0.020048668629897293, 0.037328113394323736, 0.04175451962510124, 0.06870445475215092, 0.06836524131358601, 0.11091199616203085, 0.054668271404807456, 0.06758617179002613, 0.13084498437820002, 0.009542345578665845, 0.08547281395294704, 0.14727034518728033, 0.07621070704772137, 0.012082601115253055, 0.03990699122368824, 0.03979212160629686, 0.02622189567773603, 0.07882320045609958, 0.07370626291958615, 0.0837708763720002, 0.03474397373793181, 0.02501338611182291, 0.03818511213466991, 0.03194510478351731, 0.033473223957116716, 0.046148983819875866, 0.03713586746016517, 0.024306705672643147, 0.12307938115554862, 0.05200944942771457, 0.05269700843200553, 0.05117291169881355, 0.0638869366957806, 0.02294703732331982, 0.08916497637983412, 0.027031699391955044, 0.010046793559013167, 0.03925096236343961, 0.04266214767994825, 0.061575146683026105, 0.02348603135033045, 0.06160112556244712, 0.009443121361982776, 0.04068804599228315, 0.04010703712992836, 0.057882661421899684, 0.044801384647144005, 0.009055746249941876, 0.06101232043874916, 0.025171771558234468, 0.011849159491248429, 0.010490366876183543, 0.03224948552087881, 0.047734266918268986, 0.03582504541554954, 0.009304259965574602, 0.010695220043999143, 0.016565828955208417, 0.0137358899883111, 0.031776143732713535, 0.019845565075229388, 0.044581935289897956, 0.04415275499923155, 0.060802162770414725, 0.02658727353264112, 0.021827238524565473, 0.024708940436539706, 0.040260557798319496, 0.06141663507150952, 0.01832486923376564, 0.030490753233607393, 0.0328299414832145, 0.05313875328283757, 0.043379804483265616, 0.03781263192649931, 0.037150558273424394, 0.06031465709384065, 0.026478441286599264, 0.016030000188038684, 0.03250617955927737, 0.0636975999805145, 0.03619289091147948, 0.0626365069183521, 0.05376397188229021, 0.029943751433165744, 0.030274046112026554, 0.07707504933932796, 0.04576827690470964, 0.043911037500947714, 0.027893967380805407, 0.012654760794248432, 0.08754668626352213, 0.05506051500560716, 0.016767683846410364, 0.026620716562320013, 0.02176542689994676, 0.04234605214151088, 0.042885348593699746, 0.06098826001107227, 0.029227139202703256, 0.013339077540877042, 0.031938640677253716, 0.052101245673839, 0.044533391410368495, 0.022968403754930478, 0.04536736130830832, 0.008986266384454211, 0.0481136713642627, 0.025187970786646474, 0.06488855404313654, 0.0040490037281415425, 0.052270021187723614, 0.03863373298372608, 0.030306555891002063, 0.00794675219367491, 0.09090208433917724, 0.05462569068185985, 0.02070582555461442, 0.05194184348511044, 0.026663818644010462, 0.09667247548350133, 0.02453155229886761, 0.07968883408466354, 0.07528895221184939, 0.07685461663641036, 0.010736639305832796, 0.041865611710818484, 0.02376225314947078, 0.040705059727770276, 0.09614517213776708, 0.05408536264440045, 0.040398218770860694, 0.06364994667819701, 0.07944451164803468, 0.04668004243285395, 0.01518202967417892, 0.02060728133074008, 0.07575798212201335, 0.039536551921628416, 0.008791194723016815, 0.050719029022729956, 0.03728395560756326, 0.01552414491015952, 0.05394485924625769, 0.03827797707344871, 0.022189645933394786, 0.04022825582069345, 0.09364515120978467, 0.0638895713200327, 0.06688975525321439, 0.07826362110790797, 0.09133597355685197, 0.01886940710392082, 0.007771086302454933, 0.004935058477713028, 0.11674966299324296, 0.006764348136130138, 0.06207368067407515, 0.023317369013966527, 0.041061839801841415, 0.08051374607020989, 0.068226652656449, 0.04405863583087921, 0.04501541632635053, 0.05002504673029762, 0.03280041513789911, 0.0559390991111286, 0.09719494002638385, 0.03884946047037374, 0.029344396680244245, 0.04835784908209462, 0.015966425962687936, 0.029692870266444515, 0.048131130388355814, 0.013556319008785067, 0.013953445013612509, 0.09738772772834636, 0.06004045208101161, 0.07244550986797549, 0.013910953348386101, 0.05500888008100446, 0.0371627517597517, 0.07142890113755129, 0.017210773839906324, 0.04556994535960257, 0.03175838784954976, 0.06431029483792372, 0.046710893511772156, 0.04153371955908369, 0.049802472931332886, 0.07978705732966773, 0.007651874193470576, 0.038884545501787215, 0.08862251095706597, 0.06687397719360888, 0.06137504140497185, 0.030990717714303173, 0.0306414481747197, 0.0658433567150496, 0.030036258285690565, 0.03404660725209396, 0.01177536032628268, 0.019378553806745913, 0.01639778074604692, 0.06815790751716122, 0.009708391844469588, 0.0758523833064828, 0.0766531383851543, 0.024135497769748326, 0.04020923457574099, 0.04674844989494886, 0.026898194446403068, 0.03799482547037769, 0.02565710645285435, 0.09117014807998203, 0.06896479273564182, 0.043930604224442504, 0.01246405945494189, 0.049578177349758334, 0.06278619068325497, 0.024460738422931172, 0.04416073679749388, 0.0723109659156762, 0.027420690530561842, 0.08188801060896367, 0.05261475620500278, 0.0025286072968810913, 0.02428388277621707, 0.03592336885049008, 0.06038989231456071, 0.054617181958747096, 0.01990556400414789, 0.029664227076864336, 0.028093183937016875, 0.01999337491724873, 0.07429874167428352, 0.008930616440920858, 0.058817110693780705, 0.009252984054910485, 0.04261145157215651, 0.09166634059511125, 0.06444529892178252, 0.026316005569242407, 0.028539201703097206, 0.01150161266195937, 0.0542260441579856, 0.06988332665059716, 0.095665945118526, 0.023108213244995568, 0.022220035025384277, 0.008610715540271485, 0.08205736128729768, 0.02876436003134586, 0.040770454070298, 0.08095263736322522, 0.016140778716362547, 0.03273453839938156, 0.021878799234400503, 0.07054941161186434, 0.04586136077705305, 0.07304333950742148, 0.001484892202370247, 0.04849692384595983, 0.031480872858082876, 0.04994135844754055, 0.04692550406616647, 0.009383885917486623, 0.060196518315933645, 0.029430645372485742, 0.12682775384746492, 0.1460871094604954, 0.08651159063447267, 0.14040356443729252, 0.06494089771877043, 0.09886332511086948, 0.12372674173093401, 0.0707085503381677, 0.26762949535623193, 0.08083114778855816, 0.09375239897053689, 0.09340130374766886, 0.12712891737464815, 0.19685749139171094, 0.1763619255507365, 0.10338768741348758, 0.15856988495215774, 0.17194488522363827, 0.1510741192032583, 0.25105902983341366, 0.17369280627463013, 0.16423590044723824, 0.21086745837237686, 0.10176740091992542, 0.10113507625646889, 0.08054116100538522, 0.13345053128432482, 0.23299410153413191, 0.1146582982619293, 0.16052033810410649, 0.19334211596287787, 0.12681243591941893, 0.14762175211217254, 0.16509941895492375, 0.15646415966330096, 0.1063994191645179, 0.159241528599523, 0.2481681716744788, 0.0979306607041508, 0.11259007369517349, 0.14956371509470046, 0.15698434581281617, 0.1508607220603153, 0.1461729165748693, 0.2157667017308995, 0.1943956984905526, 0.14133953140117228, 0.14241380500607193, 0.13288672169437632, 0.12614754581591114, 0.09363269055029377, 0.08802967597148381, 0.19603311375249177, 0.09705815478810109, 0.1395349993254058, 0.23239971545990556, 0.21891526324907318, 0.11241169107961468, 0.15713022236013785, 0.16970279772067443, 0.09788561976165511, 0.07848729699617252, 0.20468147937208414, 0.06418824865249917, 0.20018480659928173, 0.07666022589546628, 0.09707075645565055, 0.08334218960953876, 0.24812888237647712, 0.1966693124268204, 0.16877205547643825, 0.18853126239264384, 0.14359940076246858, 0.1212344242958352, 0.23329523537540808, 0.1686483691446483, 0.1107870481791906, 0.1569259981624782, 0.1991580007597804, 0.11946234633796848, 0.1809830268030055, 0.11796671838965267, 0.10573181280051358, 0.13817556289723143, 0.11072579130996019, 0.10209804255282506, 0.2012729286798276, 0.1152200521028135, 0.24694579507922754, 0.17458657472161576, 0.2258396940305829, 0.2913553034886718, 0.08878855165676214, 0.2715787600027397, 0.2548502467107028, 0.133389096299652, 0.2049923947197385, 0.230281462718267, 0.16957651387201622, 0.08349904994247481, 0.1861216573161073, 0.39476714038755745, 0.18842053395928815, 0.15396794595289975, 0.18975338665768504, 0.1683044875971973, 0.1276898177457042, 0.09689836297184229, 0.12862902047345415, 0.1719853768008761, 0.118887953722151, 0.2046887672622688, 0.2168245887150988, 0.18410301563562825, 0.26971549435984343, 0.2002052156603895, 0.07586592008010484, 0.1457046065479517, 0.07469680000212975, 0.1502284567686729, 0.24075303284917027, 0.14962353219743818, 0.16275639936793596, 0.14043529867194593, 0.1086117910745088, 0.0683730783930514, 0.15684630634495988, 0.1313787221442908, 0.15041032747831196, 0.1695030412520282, 0.1167025143513456, 0.24274705006973818, 0.11828030546894297, 0.07875731258536689, 0.15244268404785544, 0.117560125363525, 0.1367576452321373, 0.10237704555038363, 0.08848107245285064, 0.08256861197878607, 0.17695853806799278, 0.08179274111171253, 0.17411118460586295, 0.14092438883380964, 0.19090376008534804, 0.17868376424303278, 0.13851625320967287, 0.1816014139330946, 0.16059262328781188, 0.10542520190938376, 0.08319551896420307, 0.21715040638810024, 0.13658929645316675, 0.18049978476483375, 0.15303674357710406, 0.10923317648121156, 0.09986990000470541, 0.09281341888708994, 0.16187959641683847, 0.13895723735913634, 0.08228653648984618, 0.15481706679565832, 0.1615267645684071, 0.1977453226572834, 0.13661993230925873, 0.1893944395123981, 0.11715566230122931, 0.16387014038627967, 0.09990314079914242, 0.21237446344457567, 0.13079825876047835, 0.12384265777654946, 0.08710590991540812, 0.11279708836809732, 0.1640257687540725, 0.24993010447360575], [0.021387362030509394, 0.014997337875684025, 0.03904851560946554, 0.013303691011969931, 0.043979296533507295, 0.02574337926489534, 0.04007607472885866, 0.030100535695964936, 0.02403376787697198, 0.03301619457488414, 0.02046595785941463, 0.03133117425022647, 0.0300937932843226, 0.03488809510599822, 0.05844169529154897, 0.013598749446828151, 0.06266340977163054, 0.058776622827281244, 0.042031552220578305, 0.04587228519085329, 0.03861291945213452, 0.03784794331295416, 0.020297829869377892, 0.03550178444129415, 0.07118428184185177, 0.028376764130371157, 0.01862239067122573, 0.05389775142248254, 0.014162477400532225, 0.016602218311163597, 0.028231225260242354, 0.02663468007085612, 0.04466985381441191, 0.04261572263203561, 0.038656646793242544, 0.04194129222014453, 0.046577292087022215, 0.03946926139178686, 0.04109012304979842, 0.008012746748136124, 0.04207661171676591, 0.046588951227022335, 0.07513324962928891, 0.032295717610395513, 0.08055894286371768, 0.041001317658810876, 0.03663465060526505, 0.02593686273030471, 0.03945352786104195, 0.03907929618435446, 0.034944565122714266, 0.04866901675995905, 0.03150612443278078, 0.046761051562498324, 0.06923505323356949, 0.048141231018234976, 0.05462754976178985, 0.021037218612036668, 0.02495698103302857, 0.017762000315997284, 0.10016995773185045, 0.04253634993801825, 0.05191028365516104, 0.048822040189406835, 0.10186636631260626, 0.09047176485182717, 0.05493441298312973, 0.08811760562821291, 0.062407643417827785, 0.07907824692665599, 0.04111767528229393, 0.0212559851934202, 0.05101663766254205, 0.04527070028416347, 0.0683323567500338, 0.0115982783245272, 0.02212948373198742, 0.03828933935437817, 0.027075914695160463, 0.03365990378370043, 0.0354222744499566, 0.06671213704976253, 0.010969440827466315, 0.040478482042090036, 0.07238354053697549, 0.025127938461082522, 0.044934789402759634, 0.052435134202823974, 0.028498758365458343, 0.04955120399245061, 0.03910947933036368, 0.00575330180254241, 0.029078698535158765, 0.05290378932841122, 0.10849669139133766, 0.07805804620147683, 0.03163855326420162, 0.10599597284453921, 0.024800386017886922, 0.04064899047079962, 0.04211760053294711, 0.06007755575410556, 0.08071296819252893, 0.028084461846447084, 0.0228761752077844, 0.03821231555775739, 0.030893565017322544, 0.026291162175766658, 0.03501482795400079, 0.045735741150565445, 0.04028135648695752, 0.10137813704204746, 0.019729279811144806, 0.06043675522960257, 0.035102757610729896, 0.02008947376452852, 0.05019344374886714, 0.04631088704627473, 0.009281625389121473, 0.024903741214075126, 0.0713245922815986, 0.058785172368516214, 0.004658345005736919, 0.06974674921366386, 0.032524866837775335, 0.039983714450499974, 0.07175657417974435, 0.026893891845247708, 0.043722057016566396, 0.07058478979161009, 0.0385988038033247, 0.032656894909450784, 0.016352032907889225, 0.11534938617842272, 0.02926906498032622, 0.07120226408005692, 0.019597468817664776, 0.02696218798519112, 0.05284399077936541, 0.01677543557889294, 0.04625722605851479, 0.04118902907066513, 0.08257399254944175, 0.04232014747685753, 0.029198911615822, 0.026596505849738605, 0.06764780715457164, 0.03600343545258511, 0.03839070188405458, 0.015951013410813175, 0.023941960498632398, 0.02830372566677397, 0.088773619645508, 0.020846774241363164, 0.015574349345115479, 0.059413678682176396, 0.01819075201638043, 0.017611425973882433, 0.07392380124656484, 0.054828701468068175, 0.027570327911234926, 0.06448158252169378, 0.02282641606143443, 0.029925296075816732, 0.00607329176091298, 0.03552320282324217, 0.03084618816501461, 0.028447782096918672, 0.050187013039248995, 0.03363753916346468, 0.030956133632571436, 0.03950391968828626, 0.06297068117419258, 0.02741818578215316, 0.06298267428064719, 0.15539399755652994, 0.006722656598867616, 0.03264134320488665, 0.03150728218315635, 0.024126107746269554, 0.031678555023972876, 0.05667147270287387, 0.013390564963629004, 0.040704083803575486, 0.04136982366617303, 0.05280888348352164, 0.026636913935362827, 0.005732617682951968, 0.11118501744931564, 0.011420331720728427, 0.04477676018723287, 0.016675010010658298, 0.03747365226445254, 0.02884765312046511, 0.03253947230405174, 0.04406632448080927, 0.00711261345713865, 0.013510694552678615, 0.06603590692975558, 0.03638418318587355, 0.06148892396595329, 0.08488609426422045, 0.033750338188838214, 0.038246584226726554, 0.031472768605453894, 0.04353036027168855, 0.03611933294450864, 0.0835626816842705, 0.05718824497307651, 0.03971889389504213, 0.024053234410530422, 0.03723391630046535, 0.01888110149593558, 0.029098643753968645, 0.04690627501986455, 0.06852679201983847, 0.04622391104931012, 0.007580597866763128, 0.014059099012229126, 0.08263573923613876, 0.04431208668393083, 0.028872388902527746, 0.08799862451269291, 0.02151318945834646, 0.031691909971414134, 0.03424554735829588, 0.01674993909546174, 0.024373033265874255, 0.007307906835194444, 0.02121166227880167, 0.02171137628465658, 0.027066084949183278, 0.029599294721265323, 0.013947713778179605, 0.037259486998664215, 0.024041415708779823, 0.04780970994033851, 0.02556744759203866, 0.07124517505872063, 0.019207661316613667, 0.03904841541952919, 0.03476789686828852, 0.08853672610712238, 0.06106613727752119, 0.0427383365604328, 0.014048491866560653, 0.012183190883661155, 0.042677383971749805, 0.02657872213603696, 0.04508809855906293, 0.021780262432002928, 0.025491908090771176, 0.0660947072901763, 0.024869539338396862, 0.045677753441850655, 0.06744713042280637, 0.03223030100343749, 0.03771745519770775, 0.03592570290493313, 0.05657965048158076, 0.036409946842468344, 0.013076743180135963, 0.07967271463712677, 0.04839612534851767, 0.01183275709990994, 0.10207534767687321, 0.05083703050331678, 0.020366443277453072, 0.049050877714762464, 0.021093248906254303, 0.046655176774947904, 0.045343831516220234, 0.029709282862313557, 0.05121505084389355, 0.044980899037909694, 0.04991621077351738, 0.07827691297279671, 0.03764852081076242, 0.017062108672689646, 0.01898338428873103, 0.02477650370565243, 0.15678656345698982, 0.02311662919964874, 0.018095144841936417, 0.020256705611245707, 0.06323956869891845, 0.07575665367767215, 0.036936790056643076, 0.04086684049980249, 0.05578380842052866, 0.018623902797116898, 0.007322485398617573, 0.03325057594338432, 0.03771875395614188, 0.039445238071493804, 0.05337971750122961, 0.05543902145291213, 0.05076167653896846, 0.06663575521088205, 0.055402400175808, 0.025795042020035908, 0.016664772083458956, 0.06388868816429749, 0.04078524136275519, 0.054831465968163684, 0.037503861385630444, 0.0412836937175598, 0.06062835920602083, 0.047107126156333834, 0.08547040197299793, 0.01661139125644695, 0.002876170824492874, 0.04327322465542238, 0.02770591643638909, 0.026827156070794445, 0.03487978676275816, 0.01289347816054942, 0.04317098268074915, 0.08711474147276022, 0.038562753979931585, 0.0164806693646824, 0.031193246104521677, 0.09422493923921138, 0.048559316201135516, 0.0385399106744444, 0.0012684877378887904, 0.025941985404642764, 0.11143559619085863, 0.006644708828389412, 0.04022356173663866, 0.03707295560161583, 0.03594335859816056, 0.011075505790358875, 0.03754746256163344, 0.13861399405868724, 0.040211980522144586, 0.043092404084745795, 0.017555000486026984, 0.08671931034768932, 0.022383309369615745, 0.02695452159969136, 0.0667829453595914, 0.06186029837408569, 0.024882237485144287, 0.009174120659736218, 0.030609979257860687, 0.0385274500149535, 0.01876962349342648, 0.05277241063595284, 0.1391123462235555, 0.034494118590373546, 0.08058201623498462, 0.13424105214653537, 0.11248123031691648, 0.11147146418807097, 0.16876077483175322, 0.0836504777544178, 0.16755625430960208, 0.14445079257711768, 0.11625077648204751, 0.06733324786182493, 0.1503711866098456, 0.033268209372181445, 0.11357028750353493, 0.17510054167360067, 0.14578572328900918, 0.15337620192440227, 0.09720842484966852, 0.1047665903752204, 0.11415239103371277, 0.12847728095948696, 0.1660941046429798, 0.14878469752147794, 0.15882715786574408, 0.10827642938238569, 0.09614500886527821, 0.14466479828115553, 0.18969542492413893, 0.09381525887874886, 0.10437961973366328, 0.08930717929615639, 0.1604574781958945, 0.14306812692666426, 0.25161400786601007, 0.14734107186086476, 0.1941021642414853, 0.13056115742074326, 0.09067117251106538, 0.141843271558173, 0.12662456865655258, 0.11932973939110525, 0.0951526386779733, 0.12511349661508575, 0.08841606031637639, 0.10773488422273658, 0.19330745766637847, 0.15185840602498502, 0.1285534253111109, 0.1355127667193301, 0.15661937242839485, 0.1230453907919582, 0.0991999484540429, 0.08097916172118858, 0.15738437825348228, 0.20755753910634667, 0.1890840585110709, 0.1419503486249596, 0.08874046048731543, 0.08237708592787385, 0.1539029783452861, 0.10310522600775585, 0.1280125480843708, 0.16705903020920232, 0.1105553942034021, 0.24165535083739087, 0.11873429946717806, 0.20521212980384007, 0.11252903947024606, 0.1574770428123884, 0.15584163134917617, 0.1285363410715945, 0.2442521700868383, 0.17470739636337385, 0.12877372442744672, 0.1023570224060677, 0.10180632656556554, 0.18456411198712885, 0.22279185679508373, 0.24436283914837986, 0.08469101332593709, 0.18449850613251328, 0.17161802854388952, 0.150845033058431, 0.1385534496512264, 0.11175904641277157, 0.19286118942545727, 0.15837686718441546, 0.30109979154076427, 0.14951243269024417, 0.22251571848755702, 0.13908601482398808, 0.2613927534548566, 0.18112857680534944, 0.1051546297094319, 0.16659275366691872, 0.20498271711403504, 0.23800586932338774, 0.15943948907079175, 0.14033233310328797, 0.19123456499073654, 0.15768566052429378, 0.18260047829244286, 0.17184929660288617, 0.14493730006506667, 0.10609294185996987, 0.13125954807037488, 0.10170046662096865, 0.2172897817217745, 0.1408927288139239, 0.13845223555108532, 0.2373368083499372, 0.17185285891173407, 0.2542266942327842, 0.32446601428091526, 0.10738329918240197, 0.10595478364848532, 0.13920196797698736, 0.14905727352015674, 0.14309143036371097, 0.125984777987469, 0.10707509267376736, 0.23167675972217694, 0.22733602701919153, 0.1770533251692541, 0.1970371208153665, 0.13095154194161296, 0.12015379048534669, 0.09300908612203784, 0.1394754642387852, 0.14715841447468847, 0.15588935144478455, 0.1464572481927462, 0.12985970912268385, 0.15613485389621928, 0.21432629699120298, 0.24105303862597793, 0.09000329897389747, 0.10842541552847251, 0.10088907656609081, 0.10425152504467405, 0.10665974230505526, 0.11613024427788332, 0.17406797676812857, 0.15391595108667389, 0.20448780851438642, 0.1945221159257926, 0.14975060272263363, 0.16253835638053715, 0.2722383214859292, 0.10011097183451056, 0.12640128610655665, 0.1327738113468513, 0.09047597282915376, 0.14354445214848965, 0.13062723824987188, 0.13346834282856435, 0.13812009477987885, 0.1597252010833472, 0.09315326315118, 0.12712306925095618, 0.2232500587706454, 0.12315211162786, 0.08491618835250847, 0.16229904344072565, 0.13610035472083837, 0.07709795201662928, 0.15249822637997568, 0.1726270079961978, 0.1643352146493271, 0.1037418180203531, 0.15135622437810525, 0.15524996153544635, 0.1230676329578273, 0.16253335430519655, 0.17043777625076473, 0.24977713299449533, 0.3037163073895499, 0.24489111470757052], [0.01556142855406506, 0.04301141350879334, 0.028196455641591456, 0.05217475911194924, 0.05907055041461717, 0.038516711138072424, 0.03797449804551434, 0.03740871063200757, 0.046019523579161614, 0.04216505716613028, 0.03760418119782116, 0.0736772152595222, 0.020139101179665886, 0.042477018942008726, 0.036928400077158585, 0.05249576395726763, 0.004533754181466065, 0.08653638578834943, 0.029639062704518437, 0.062184739363146946, 0.027492829140101094, 0.04542113732895814, 0.035596534435171634, 0.0402585428673774, 0.007914714606158668, 0.013109814208291937, 0.019676455594890285, 0.04233657120494172, 0.0832999317208305, 0.06015368897351436, 0.05509618633368518, 0.03875956041156314, 0.0381197363458341, 0.04144771577557549, 0.0961506788735278, 0.01106887191781425, 0.02690837671252666, 0.0464385290251812, 0.015207004798867274, 0.044230042258277535, 0.048195671261055395, 0.04688629640440922, 0.07288998953299597, 0.05333887711458374, 0.02250119581731269, 0.03481763931631576, 0.038777212394052185, 0.016864003482623957, 0.022387313256331254, 0.026670054539863486, 0.03690025783726014, 0.041420994748477824, 0.02272884961712407, 0.11180709305335768, 0.044824383803643286, 0.0075958021534461295, 0.07462303052307107, 0.02171131876821164, 0.02467967198754195, 0.0260163189159357, 0.06762036253348924, 0.06001059547998011, 0.03411605372093618, 0.059446155064506456, 0.10066214264952578, 0.06737832591170445, 0.059087879562866874, 0.02101999707520008, 0.033274302404606715, 0.04237972338160034, 0.022539295823662542, 0.07244804059155285, 0.01528404900454916, 0.02002554330829298, 0.022515738201036584, 0.03459713982010726, 0.03416262348764576, 0.04338312930485699, 0.03635042659880128, 0.034879953745985404, 0.05656094093865249, 0.05726597009925172, 0.05985986157611478, 0.09900107514113188, 0.03175309262587689, 0.03885330479533877, 0.031040191133797634, 0.06113256691605784, 0.056945414253277704, 0.06538536254083738, 0.03752974749659188, 0.08643727196613327, 0.07110746955731884, 0.049483308612252586, 0.049747973316698335, 0.06105434455093928, 0.09085601181141101, 0.026294485141988844, 0.04715616727480665, 0.05765334521129262, 0.024325290905835573, 0.07872019778005779, 0.020404135102580767, 0.06268090961384587, 0.06413573428289965, 0.043310202163411304, 0.02817231543303933, 0.06520631941384636, 0.009991679817176191, 0.056676986860111356, 0.0533458570134826, 0.01416532260918757, 0.06228374928468838, 0.029336982624954544, 0.06844290706794709, 0.021305887203197926, 0.07513795484555885, 0.03064343341975473, 0.058412703292560764, 0.060489711177069694, 0.0251767884765286, 0.05666725730407052, 0.06324049638351426, 0.01864348250819603, 0.019573172758100554, 0.05870899090950843, 0.05087139936222229, 0.026865944419114385, 0.02785086715448415, 0.04189304519968573, 0.005862534808329656, 0.036546405535773374, 0.0369482265523402, 0.0020776294331881218, 0.08966573310317472, 0.05929160652158316, 0.015332863767980598, 0.050193933566333726, 0.036154187910142355, 0.08459268618025817, 0.02065681041131029, 0.024793689990474377, 0.048297657194780186, 0.04089170244697016, 0.04696361706010066, 0.03576233393687289, 0.03014342626556754, 0.008479966745653655, 0.029440699618135113, 0.013407990591076668, 0.032634760354994796, 0.04923038468405139, 0.021760549134342, 0.035863830053131096, 0.03233284725865815, 0.04414360060764011, 0.06206034799106419, 0.03187620379321743, 0.023028957439237274, 0.037809474088135175, 0.04254377883626148, 0.0588335121574346, 0.07183045498095453, 0.033913432562258095, 0.047303409373853356, 0.028331444882496726, 0.04256426582287531, 0.019392040485399775, 0.04165051876043435, 0.00911338793230243, 0.031845078119658865, 0.04428000363986939, 0.051557102997321635, 0.015506664549320703, 0.04132717614993453, 0.0129435452981852, 0.062289293127832934, 0.038506291384692304, 0.017479948946856894, 0.018199262594862375, 0.0558857386931777, 0.06693527117022313, 0.025857352738967165, 0.03572655870812014, 0.013647478863276774, 0.06297528248978779, 0.07714104853221215, 0.02577921015472384, 0.05049380946729798, 0.07357884358498268, 0.05344520090147853, 0.02615371828142088, 0.01722398963465821, 0.008189098662114702, 0.04207574711472262, 0.07539791433373466, 0.006547968023369322, 0.030747365635761525, 0.03657018765807152, 0.028394033906806726, 0.034354824892943725, 0.030756406849832274, 0.02802936294756364, 0.06705686464556493, 0.014111658838373842, 0.08085174980806187, 0.023885900518507697, 0.003968847140640719, 0.032610154448775575, 0.05286115665512625, 0.04714646369393449, 0.03388926081242971, 0.029606122479890473, 0.021959244331810623, 0.04646018860512413, 0.03517071236274205, 0.07373942207777873, 0.053451245694304816, 0.056816050491761416, 0.005323936902641435, 0.009450238558201818, 0.007171719953475986, 0.06958128738915548, 0.05016701958084013, 0.015004344677436166, 0.02143019508366706, 0.044493285749922507, 0.034190376100013964, 0.031182514649117365, 0.042290190685889684, 0.03888483865011949, 0.01814913051930489, 0.11597101649385877, 0.009156439919024706, 0.06930187621037476, 0.019006865841220133, 0.06280419518589042, 0.004559934832286672, 0.05159517517313361, 0.05127663796884008, 0.036054933079867624, 0.056035789821180515, 0.013734888088947628, 0.024754832993494347, 0.0980160225299187, 0.08580770809203386, 0.018448227165208664, 0.03932952611648943, 0.06313511141343042, 0.03345670003909618, 0.03503729647491127, 0.06432876689359546, 0.021557063373620622, 0.055017511258483864, 0.028899456883664243, 0.018808439672284294, 0.054040915420046076, 0.0748845559428446, 0.022516977587656584, 0.058441992150619626, 0.025618577856221236, 0.14708369504660368, 0.022248368368309457, 0.04092467606824357, 0.01483644860854838, 0.12598080007592216, 0.10371592448791489, 0.057095665761153214, 0.039173344848677516, 0.02575439830252435, 0.05117374661494978, 0.059145926643395796, 0.07405377356917597, 0.007086082605383126, 0.03143134934362024, 0.010497720631974516, 0.03170839307131246, 0.05768861577962525, 0.014791570938541554, 0.03923207099433057, 0.038855212114867754, 0.009670007038948825, 0.029906755371484905, 0.027805284444184508, 0.04646326480724383, 0.04564238268358167, 0.02988097501656739, 0.030133603941067122, 0.03678945889987517, 0.11153059851494618, 0.057981444988399744, 0.04792086510860827, 0.04325048896134831, 0.07366701815044507, 0.0814716138120275, 0.04266668220225256, 0.03696348881931044, 0.09452980608330108, 0.032016651530284435, 0.021028990049671847, 0.007954757184052141, 0.03162057102599647, 0.05174379766685888, 0.04500244358496275, 0.02420035219984129, 0.045905169754405506, 0.021252617698337417, 0.06588562944671139, 0.028443698429327924, 0.028212764336785767, 0.00200706000214268, 0.04711736037279479, 0.03571743029169738, 0.09409927879460156, 0.04220902199449483, 0.04911760050163139, 0.10207728468230926, 0.03189174065482803, 0.017931085676536895, 0.06537417837535031, 0.04797248890099581, 0.0227113367873244, 0.04693205723015126, 0.04519452624663245, 0.01784081268851878, 0.03722697350895032, 0.022860582685098052, 0.04831612925045192, 0.024393106505158357, 0.04719387950899545, 0.04335241552325897, 0.04162516328506172, 0.04386729531688616, 0.020688698641606607, 0.03899544091837015, 0.054675065766787156, 0.02433956426102668, 0.033303817617706954, 0.02126736788341077, 0.006581768675459898, 0.0050085055863746675, 0.06275052306591533, 0.03473208453215193, 0.10993305142619647, 0.09446261945413426, 0.010446120031701867, 0.021774993183498736, 0.04550852892862167, 0.016917855573410634, 0.039253730574273504, 0.011290569054835942, 0.004223661690048175, 0.08114500946248882, 0.21761568845249712, 0.05962948780506849, 0.16907183860894293, 0.09291619891882874, 0.17618550220504403, 0.16941284062340856, 0.14899910398526117, 0.14089422795223072, 0.165908063063398, 0.1714537912630476, 0.1052275754045695, 0.11158111650729552, 0.138390340434853, 0.11014821488060988, 0.14878037822199985, 0.21256694686599076, 0.18680622917599976, 0.14339375164126977, 0.22052334883483127, 0.11024135441402905, 0.1027547541889362, 0.12227649611304514, 0.14967362716561183, 0.115937768277945, 0.07161545479902998, 0.12436937482561916, 0.14986363181378692, 0.16003898112103343, 0.16033304971642792, 0.16125565802212805, 0.17235566396266222, 0.0931198442413006, 0.140274430741556, 0.24507190188160166, 0.20318444876465946, 0.17811060359235853, 0.24773092794930562, 0.10909463235293515, 0.13085969374515116, 0.11047543521272019, 0.2292598073836416, 0.14504019141895697, 0.1009414870350156, 0.06297161628026515, 0.09592151851393282, 0.21496360888704658, 0.07330866472329944, 0.08960961189586669, 0.10054601880256087, 0.1246047395397909, 0.12423051899531856, 0.1329478301340714, 0.22173573612235487, 0.23471450374927372, 0.17099536664318293, 0.29163895233068615, 0.08736604751902632, 0.1605442797881551, 0.11553405478480272, 0.14721842453582212, 0.14745622349437326, 0.19352884031832218, 0.09567524422891438, 0.11103894052212127, 0.2185175908380188, 0.14070049772271886, 0.1268825985607691, 0.2884751174133271, 0.26269783498719335, 0.11012399118044414, 0.09067284234333783, 0.17026734945829958, 0.1205324861803092, 0.11832562100607902, 0.18570989894215018, 0.17160507064545527, 0.10281476425006986, 0.20346806792076677, 0.13253501791041344, 0.0791362531890627, 0.162350355531089, 0.21347589965444058, 0.23047378286719322, 0.19569215626688674, 0.37455480778589845, 0.21475380373885855, 0.17416638555005193, 0.17833919991971925, 0.13972647342598066, 0.2327581134159118, 0.22926909907255322, 0.20546705753076822, 0.13904075865866616, 0.1820461533498019, 0.20115296792937443, 0.21031648793723434, 0.28484770737122744, 0.27845870645251125, 0.14028206001967192, 0.15036082622827962, 0.14270257466705516, 0.10863862713449635, 0.11343967693392187, 0.11524050569278188, 0.16108864510897547, 0.21439591044327244, 0.11846887777210213, 0.1357160706538707, 0.08675540841068141, 0.15247887116856873, 0.1352649784530513, 0.16156839905306697, 0.21915249817539006, 0.13375579146668315, 0.12266202698810957, 0.1713582917000167, 0.11687606558552943, 0.19305741327116266, 0.18143658293411136, 0.15771634090924636, 0.18656802945770323, 0.14289556274889037, 0.1302138768369332, 0.09158100845525041, 0.11659401236101985, 0.2059577507316135, 0.131579814478755, 0.12054232705850154, 0.18071805039653555, 0.12905651237815619, 0.22722200345015153, 0.1246516581159085, 0.1698327180929482, 0.25669204944279045, 0.12306915436056443, 0.11690096464008093, 0.2513884543441236, 0.14785955107072368, 0.27623677568044513, 0.16974915226455778, 0.10841050578164868, 0.1504423882579431, 0.26236253266688436, 0.13147911988198757, 0.09861722151981667, 0.12724239175440744, 0.08610691234935075, 0.08993653536890633, 0.11093921071733348, 0.13847086345776916, 0.06953273608814925, 0.09074891990167089, 0.24166704708477482, 0.14465598156675696, 0.09252050062059425, 0.17718747578328475, 0.089532346901251, 0.09854273215751164, 0.14079708082135767, 0.09166044052108191, 0.13358889729715884, 0.18016213725786656, 0.08007638360140845, 0.14931338868336752, 0.18375935673248023, 0.15013766242191195, 0.1582007555407472, 0.15249488671543077, 0.0896331157127861, 0.13776591222267598, 0.0964231658144854, 0.12986429559532553, 0.1705027587013319, 0.14306082419352606, 0.10566591750830412], [0.02583064284408465, 0.05690160527592525, 0.036748585116583854, 0.04269975230272394, 0.03148086914734449, 0.03628397098509595, 0.03825877400231548, 0.047156760992947966, 0.04159320640610531, 0.03430626617046073, 0.04036900783830788, 0.02618490889290115, 0.06164471560623497, 0.04780121977091767, 0.02366076074395096, 0.08733654714887962, 0.018802303966367617, 0.01619265112822177, 0.01820434074033983, 0.08541364994016476, 0.03735640406375751, 0.07776776998071, 0.0336292790598236, 0.01863299410615582, 0.032789108518045396, 0.023319200263358653, 0.04593170524458401, 0.04015341022750363, 0.055800432528485544, 0.024462237561238, 0.03599281903007068, 0.007920011685200734, 0.04276817831851076, 0.0008624458723716089, 0.029969238639750984, 0.01069576273948769, 0.01876983129477594, 0.03622133001044858, 0.04062904525198974, 0.007521479310526047, 0.03834545685094781, 0.07276411386555992, 0.023960441831150092, 0.04322460285038687, 0.027934460813412443, 0.10305047777364962, 0.045599534787470475, 0.03704773000208661, 0.09796002006623894, 0.06612099416088313, 0.035095172861474566, 0.06410532107111067, 0.04305470298277214, 0.06717508134897798, 0.10272521671140566, 0.06786695594200864, 0.09077032344066538, 0.039016677474137396, 0.03393425351532642, 0.006309136551863048, 0.01921739458339289, 0.027333423240634147, 0.058652101579355076, 0.01551634586576256, 0.0445884105283767, 0.10508310151635669, 0.03954190651711542, 0.04603271525411401, 0.052824954691459425, 0.09833628893829882, 0.024636701637064107, 0.054866283826413564, 0.08743247715756297, 0.05193247758143116, 0.08263864845503122, 0.042022130655823275, 0.04998031377908774, 0.02241663922177395, 0.07997276494279504, 0.04948109701217618, 0.04274932776752394, 0.01835585389926564, 0.02678604294487741, 0.04171463289821986, 0.019462010168354027, 0.06000818350003101, 0.039294504167628475, 0.005991677780912141, 0.036263461734051816, 0.054063762436271645, 0.04614533987478353, 0.030505397662636824, 0.08702215855009854, 0.031323871517088264, 0.00849008221848635, 0.050571371320984326, 0.014025822038092883, 0.09628010200685821, 0.10163734696106985, 0.00915554934181273, 0.05509294685907662, 0.06123958090029191, 0.019437573100731242, 0.03917071764590219, 0.07379852671874687, 0.009735868934512837, 0.0356176782224793, 0.03611972257203888, 0.013302344941621413, 0.02512030547222821, 0.04654780655982904, 0.05648540514812339, 0.0730684315203689, 0.01561227680213051, 0.03507517198158894, 0.036049025584361516, 0.07401104070595466, 0.022253561546676792, 0.02732043565629283, 0.04198320129944477, 0.02363287454500096, 0.09579994730302133, 0.10088955154060386, 0.03428986470680684, 0.006165574577607913, 0.04698922115494497, 0.06918673941981979, 0.03944228432374075, 0.02523042719985824, 0.02083582014165586, 0.03740499618288595, 0.054433890036307275, 0.0421184873994207, 0.00926800141314743, 0.08839738045935519, 0.043018155920435674, 0.014100941298238467, 0.03481848165392876, 0.11844495835248381, 0.05365426761272829, 0.06653793272562325, 0.022514706615766045, 0.027916053695662413, 0.04079641068528872, 0.059874166472582147, 0.03104747345787473, 0.06178331910632551, 0.039620002717128955, 0.033815109127317555, 0.07147898868424818, 0.030271778850874398, 0.02585664584330516, 0.04086409826413728, 0.07013507798546925, 0.02973524504341185, 0.04320690633903723, 0.029027597956883255, 0.06560440742759965, 0.02009602507314412, 0.04488108017540071, 0.05766714173660148, 0.10332164369174279, 0.059663333449861966, 0.011263451906415867, 0.010353613179177046, 0.05163928843103349, 0.033530614236951806, 0.05574293834797572, 0.005206170590099646, 0.03660775888420176, 0.047383565033669583, 0.01876728201750666, 0.03651602200989146, 0.012713052783510648, 0.034190732330898754, 0.02791544327919837, 0.033410842734156176, 0.01482196095821564, 0.0749017292400822, 0.045311882058740593, 0.030984685909061227, 0.050053860613843426, 0.034968146865139715, 0.02262810492538847, 0.021249849487503525, 0.03219236612494569, 0.041735453851288185, 0.024024654303502757, 0.02961316360597266, 0.010722891020122916, 0.022682858725602273, 0.08493618181091733, 0.022850385576020926, 0.02095311472658068, 0.03111771588010015, 0.0229251532437047, 0.024514469914720394, 0.035040443181060255, 0.05273496557492763, 0.018472003721399233, 0.10604447961668484, 0.005106721873744391, 0.05012943351175636, 0.02875886442780029, 0.04526688193436712, 0.007480645881514647, 0.08632148208562285, 0.04193786720861681, 0.04070599112310447, 0.019593889810494147, 0.028070737680536695, 0.07095682100043632, 0.07907909297500737, 0.03934200532967225, 0.025464341015322134, 0.07144569593947381, 0.06340097839711234, 0.025730708948685788, 0.027618934873316903, 0.047160260219243355, 0.042958138437825255, 0.05197065736865625, 0.02564020403951872, 0.028170194746053312, 0.0832116903620772, 0.025730141205713153, 0.012468761888158042, 0.06865505740279332, 0.049377055329387076, 0.04332354226789903, 0.042407197688589804, 0.020992964346078224, 0.013349826622288674, 0.10333794867619872, 0.028661385185841937, 0.005928361915721325, 0.008024109029065585, 0.04127620915824082, 0.08928216149797663, 0.020010193838970736, 0.08943497712607495, 0.055316500292974524, 0.04449259184184484, 0.04706049701781012, 0.04663643012463581, 0.11615790412179194, 0.044947572896489874, 0.04546866817690898, 0.02678753837244585, 0.027268147641734686, 0.08017228392418474, 0.019613078038673848, 0.009193277346639661, 0.04725017512100749, 0.0306553244809038, 0.030669811203551944, 0.03901615797076374, 0.02195086362917209, 0.0677758276287932, 0.050716479745460674, 0.0773499408387579, 0.02735035348450765, 0.06833902865764685, 0.0018516715567784559, 0.028883278064313345, 0.026366814854554832, 0.03309628344140947, 0.019917607205570675, 0.055132833585958, 0.03813595598330721, 0.0038786479035479715, 0.09168931748718023, 0.03352937113959342, 0.06573494378244504, 0.048706135276006535, 0.0227304582222132, 0.0741928668867331, 0.02729765543335816, 0.01176479678179021, 0.08460778146400116, 0.020003974641440436, 0.023614896017534193, 0.04473678069189191, 0.038934614494792186, 0.04349134185758885, 0.01728201259538764, 0.012611231049959315, 0.049269481023657136, 0.03497245874314103, 0.010238644299533917, 0.03695604136737529, 0.022477248567156494, 0.041075139088206924, 0.012096475566067966, 0.03779299098823685, 0.0896588533942122, 0.04867312454734929, 0.0375892566080438, 0.029402213694993407, 0.04145984617935028, 0.0233183931777603, 0.06847255586762913, 0.0261287932517007, 0.0034266036664121202, 0.053045209278934635, 0.03430782468058169, 0.05584649021329824, 0.03612849846831523, 0.0410971215023892, 0.04744124846183695, 0.04660435821278952, 0.031844940822338685, 0.024157656444003806, 0.06865014438517392, 0.12012607126962394, 0.04893446443020366, 0.055386755702784285, 0.07022622114163823, 0.005508503927558195, 0.02650806596648181, 0.00035482196381053654, 0.022732927718607243, 0.02416893152258126, 0.021196236739342567, 0.024784416855254676, 0.08420384532655589, 0.03486073954263702, 0.060083229473093525, 0.017779995541786775, 0.016171980460057966, 0.024175056096282788, 0.06424633655115031, 0.030309312969620805, 0.08859361914801411, 0.03617958791437559, 0.042019978427561, 0.002670966528057761, 0.01108827907955856, 0.031288274403777905, 0.030454593943431973, 0.0069375208749988815, 0.010536984882492106, 0.03463460714556277, 0.05258249875623733, 0.08160574958310463, 0.04458481111214496, 0.02506027685740264, 0.03309315157821402, 0.0318481691647321, 0.011881517129950225, 0.049834708115668036, 0.014325316660688259, 0.14275632100179791, 0.10864167736144736, 0.2372909733094275, 0.2864868741016835, 0.1390354597242549, 0.2731534786289558, 0.10071658660308458, 0.09049635220435448, 0.0800174125470221, 0.10837216643267311, 0.11500007210997865, 0.09127311364863999, 0.12169768029707484, 0.14892638835590333, 0.12665705988183618, 0.17089234170271084, 0.1521753624547273, 0.10621575245750137, 0.15772674581967294, 0.15919603494694456, 0.11789535346906632, 0.35437542654108256, 0.17487342964159325, 0.13731928775087, 0.1921059947926551, 0.057421887904638425, 0.15126206068089232, 0.11420926181017421, 0.12708780239336193, 0.0854506682662759, 0.14868085621856153, 0.06459508658736013, 0.1668633852386847, 0.09587688575265929, 0.12598994333529845, 0.13245109585113823, 0.11838151214760728, 0.13192969257943332, 0.12404071472701617, 0.11700560746248811, 0.115010261797579, 0.13658701063832268, 0.09720797213958576, 0.1878165890229866, 0.13585504522779956, 0.2227110369130969, 0.1507087450590916, 0.09029613560414873, 0.16888097306946293, 0.1751706301001832, 0.15139598865061998, 0.15400873438920826, 0.15762821829412133, 0.21798891451908275, 0.19752762105781585, 0.1285784356878139, 0.16517259471584111, 0.15061631798744202, 0.10538020549574867, 0.09184115348034538, 0.06867499148938805, 0.09589578083250672, 0.18337759596761316, 0.08175627939635888, 0.19333335862029344, 0.17011253745295107, 0.16739773156587034, 0.13620968791656196, 0.142835448787082, 0.23044494300847873, 0.0915379861544352, 0.15348574292147532, 0.18792748072883114, 0.11699438618961722, 0.2315088117029518, 0.2041498789913021, 0.1356913274503313, 0.10672024960513227, 0.23590576951391995, 0.16742630425142124, 0.11128094745799899, 0.08560153204598464, 0.11868237139424309, 0.17793131555663422, 0.1290837343549356, 0.1879121776437387, 0.15138867107452825, 0.26927189785055816, 0.12864370015449822, 0.1126069798192475, 0.240716177795548, 0.10704209678806365, 0.21245305688353255, 0.21249586396152154, 0.15329327434301376, 0.2022654324537143, 0.1116637175437063, 0.23258287750650197, 0.20205628039548174, 0.14310849976027384, 0.1489697743090801, 0.2373666426865384, 0.09859586993115954, 0.18484027998056263, 0.22236028307816014, 0.054838019132148474, 0.23808303783880547, 0.13778995780739933, 0.14204133593011647, 0.1746015067328699, 0.16321486851666123, 0.1894838089356199, 0.10932263496215455, 0.14341208268888295, 0.11967868980718777, 0.18633763713296503, 0.248517990403343, 0.08121299018966965, 0.15600723418174312, 0.17534524260554463, 0.12512783490819857, 0.17183031246531755, 0.25417014257982373, 0.14189513283781707, 0.11916524978005327, 0.1402663710177876, 0.149154732353054, 0.09861826794804074, 0.15535896818619221, 0.16984667046926916, 0.1426337330485694, 0.1281246865983121, 0.12365725444396958, 0.11033292059437372, 0.19825326337013394, 0.12700978782959282, 0.0965828908374533, 0.15309181093471125, 0.1677026058314368, 0.13675599766429514, 0.1804806076688692, 0.12287408084375784, 0.18393797683529556, 0.08831377010210417, 0.05429928671219386, 0.10923616733634844, 0.16246578918071464, 0.08679328762809746, 0.1280180548201315, 0.14008936879690737, 0.08360376697964966, 0.09477598388912156, 0.24747941410169005, 0.24716407555388287, 0.09562661129166372, 0.15078413242008537, 0.15028880821773782, 0.16769945912528783, 0.12516308692283928, 0.1370882720220834, 0.11246414607740007, 0.13460742076858878, 0.16428210656158626, 0.20787976478459314, 0.1151383193791844, 0.08398585428949445, 0.1645978310261853, 0.1743444861494936, 0.15706575941294432, 0.10175180097576231, 0.09829044647631235, 0.10698630212573335, 0.17864535067928955, 0.09007930973893963, 0.19837530213408172, 0.13082837511319667], [0.029604812589241192, 0.027121925995743368, 0.04007158102467656, 0.0849809852661565, 0.024840356236381922, 0.0703119020909071, 0.04016222323116381, 0.0661081846919842, 0.018788987981679384, 0.06755083813914098, 0.050691647484200075, 0.024834608302626293, 0.01629229558602674, 0.0372266246995423, 0.03260578690969851, 0.04130619934585411, 0.04975669726263732, 0.04709861743322108, 0.055281957029365, 0.049795036611612886, 0.014391448512469651, 0.0342790293507278, 0.07498719496652484, 0.07109388083335944, 0.0156720567974844, 0.08989490088424645, 0.010160124147660099, 0.020413257952895947, 0.01760195616952842, 0.061698647477896884, 0.04271122961654328, 0.010018065022450173, 0.03046654623176437, 0.07703586394200101, 0.06011091158143245, 0.02172626933315769, 0.009775380876817508, 0.06654850833001547, 0.061073287870385684, 0.0665396693511866, 0.10388131951913238, 0.03284508129581809, 0.03592854904127307, 0.038293784818961285, 0.07754424994345754, 0.025004454364534467, 0.01496303209933103, 0.06216648624103982, 0.09089495230000466, 0.052499400480883196, 0.03284004211309366, 0.03567458610632457, 0.04266693453246262, 0.01908201571495738, 0.03012832170497859, 0.028868039917142596, 0.04484661483729724, 0.053894196535111405, 0.03200947125151288, 0.036252466816222295, 0.05963140996755101, 0.0377241716341814, 0.08049401978496462, 0.029518840347009245, 0.06942879088455811, 0.0665412649686914, 0.05254544703348074, 0.0071302923424809705, 0.03151710821839515, 0.0098614755734161, 0.01704742528090719, 0.018463880915078335, 0.014344695991894696, 0.017750489605532493, 0.05117269276524894, 0.03657963148725685, 0.02275733324495377, 0.047434784355573356, 0.09612828827812336, 0.019816313324554358, 0.06455901078879833, 0.0637369041214697, 0.03219199505110737, 0.029588637480628677, 0.03875533759128302, 0.04342180262028705, 0.11945388585445471, 0.05628757455269806, 0.04312364850193262, 0.05134409919264726, 0.049156904642586596, 0.047662553188274615, 0.027289274730719626, 0.036894431977998465, 0.026038392243208364, 0.06806248959037475, 0.03397250751731917, 0.05365279073885176, 0.08757000454352237, 0.05745144764659926, 0.050957069179276004, 0.010786863222165266, 0.05228990332398098, 0.04377328747068532, 0.08801015006611124, 0.03897955524735153, 0.07131293314159848, 0.020899366536468733, 0.020737730483233463, 0.03702789981616661, 0.04030097887152806, 0.12853001797338948, 0.06026917457347736, 0.010288645571563393, 0.015517012870986946, 0.05631448482745327, 0.05581474113569129, 0.03556466290319804, 0.04403575541800819, 0.055080801612348296, 0.04723969228507485, 0.0649893302761484, 0.053800808382220566, 0.043010537774534896, 0.031190132795018144, 0.011914059377886588, 0.0240400705661159, 0.04069345253810752, 0.05726310540921986, 0.02269857741339365, 0.07399909954983741, 0.03742598040844314, 0.03517429322528187, 0.03147758514387533, 0.05737986008170992, 0.024166857219825033, 0.04483153439650778, 0.01681890873442171, 0.01800709458620986, 0.06024621623510029, 0.0453352522890782, 0.022869104395795148, 0.01755880584823899, 0.03608860803069547, 0.01660464513406623, 0.008239278049586574, 0.015058227381814504, 0.04587856004945934, 0.05207669913943391, 0.03818508987023961, 0.03284322221588809, 0.009727071701490786, 0.07000810393947177, 0.0507297530566575, 0.021629788279824425, 0.04986894338799175, 0.031185646512312815, 0.02860522872651927, 0.021181009724386968, 0.006417914992198348, 0.027251690517005045, 0.021867041759833228, 0.04698145829024725, 0.10562074297922663, 0.029810109190293588, 0.029224408099253196, 0.05764412402641028, 0.05235343487584032, 0.08025768285733648, 0.022571295376110356, 0.01404187283696956, 0.040168108462239616, 0.03335463989060372, 0.012952867600688478, 0.01487242421717383, 0.11057184761739336, 0.04257622182194609, 0.025522894611640368, 0.0512645261187572, 0.027503662640810944, 0.04399148630909622, 0.05147547046362888, 0.046539661489077844, 0.015804719405423384, 0.014435609082283918, 0.07896355542470701, 0.020008229002996814, 0.03635344713984523, 0.0446713826386258, 0.018780564605549444, 0.04184730663837399, 0.01622653016966069, 0.02472169609973207, 0.005978627577860607, 0.021381371043389663, 0.020383432893140707, 0.04083267573150806, 0.051572135198512115, 0.03537787175446283, 0.029892263082729187, 0.08202040975447744, 0.0687699047557544, 0.008505321293341694, 0.051146750993211754, 0.010290396112395683, 0.03763204884307925, 0.04539595254755113, 0.027999224330415018, 0.04051968237035908, 0.027644861802400555, 0.038437598195741884, 0.03705187489686068, 0.04747170991322491, 0.014527310704579577, 0.013418384369288106, 0.051188604411436245, 0.02521158407034818, 0.038895755642442964, 0.07673254076507874, 0.030838777820463292, 0.14919951354386285, 0.03241969709051773, 0.039659733592998236, 0.032605300802970305, 0.04042024571390357, 0.013425032157101668, 0.04042121421662159, 0.07218581755296327, 0.018358451416133903, 0.03692195823532529, 0.04775313973368611, 0.060310564149403945, 0.00920736887564999, 0.0349370768526569, 0.06322459215880372, 0.029676897393073887, 0.06865263057989068, 0.017488507764937822, 0.11509062896948308, 0.023400120335281827, 0.03715163438755553, 0.054252034169621766, 0.07625457539688796, 0.07095918103004806, 0.025735505078046117, 0.019794219588220585, 0.025369116046931595, 0.09555553580867127, 0.03962968403357081, 0.026531597613939084, 0.07317812836845405, 0.020615140674635768, 0.028038821619702503, 0.08816731467959471, 0.008758371386647923, 0.02912728137744125, 0.13088307139696553, 0.029951495744171552, 0.08485455298796296, 0.013902952068747254, 0.052143214124953374, 0.06084885128075257, 0.03061743042053422, 0.028213769946887624, 0.023967241759237368, 0.022234286116145086, 0.027163992781424895, 0.04652349751268048, 0.019714861737156752, 0.07548646739451215, 0.019979324206360616, 0.07489253403036855, 0.03532428869220894, 0.034725008154055104, 0.013243863704701653, 0.03523683400999289, 0.02148209161532577, 0.017287385744566564, 0.043212327727815136, 0.011041982052120147, 0.06184672449307982, 0.03692255195346661, 0.01867755450803088, 0.046291810140246525, 0.06325959926471114, 0.02534075487346854, 0.064839186379686, 0.06459592521423474, 0.008604126196587458, 0.06764569945516996, 0.08401475352002308, 0.03236071490391623, 0.03949098776502069, 0.08446810184977949, 0.03627435275120661, 0.04174074165348429, 0.028674465538642835, 0.015808183379704133, 0.009313326227129437, 0.029579490510514006, 0.060037602233933285, 0.08118429876049049, 0.05837301694555208, 0.06204430646903347, 0.02403677728580078, 0.011406752273614984, 0.03635622648289427, 0.020398210908751935, 0.031160524813458323, 0.05397388835262973, 0.01615020213648677, 0.053731721855001524, 0.02432191227853764, 0.01052371157129528, 0.026586828244035132, 0.06299780667177401, 0.03416503546759486, 0.050033032239298336, 0.03490557268378325, 0.058092485123779625, 0.003948012272303458, 0.06051690346794203, 0.030681423959322274, 0.08297840366140008, 0.03914271270332392, 0.033602543189772405, 0.05014810223656241, 0.06338865874568, 0.05415974068455398, 0.03954120147682261, 0.017396741204720456, 0.011959398107137531, 0.0020817265522055095, 0.03594991176214535, 0.08983304287539795, 0.04360696846561041, 0.03142560883134138, 0.021193895263422746, 0.054779790225438774, 0.09727420139824972, 0.07857592427171767, 0.015072619480633875, 0.05155836093763355, 0.020442826971702743, 0.07130350786610506, 0.02071662380330963, 0.02991369259689236, 0.029869657264498528, 0.02811723323247861, 0.04799631184141617, 0.009435985612071818, 0.053430176121764816, 0.13918687269324437, 0.12004496937151998, 0.11324906372465193, 0.20661777234636247, 0.13589933660114184, 0.11490331831737421, 0.1896200524060987, 0.1756973916781135, 0.1365635439287871, 0.18151449359720573, 0.15145727520575747, 0.1509641922893934, 0.2129115557181649, 0.13082457531709224, 0.1300713696400635, 0.1131351143703796, 0.1320564662455581, 0.147322473640088, 0.1088017066649627, 0.16591821564361453, 0.10217188624665141, 0.17081260535633191, 0.21689537476049736, 0.1279280471499078, 0.30757969070691615, 0.2372373902471736, 0.1546060890541412, 0.14611516264267266, 0.08724886240088381, 0.13945079525001347, 0.14489176188362762, 0.07998026805580594, 0.06941876446944661, 0.11554894968867302, 0.1487473674933426, 0.12477184151066467, 0.10842318908544257, 0.1145864361023996, 0.14862209296552464, 0.14851808839011937, 0.12249225328559987, 0.07957485504448414, 0.17802098183892667, 0.14575351407984272, 0.16708512412151322, 0.14629649900598451, 0.13477677886839956, 0.10202848105109297, 0.18476538243703544, 0.15986142971087247, 0.12261199881322682, 0.208182115748059, 0.16414990037446842, 0.15745244803838432, 0.12040022062137723, 0.17128223640611395, 0.19126178696751595, 0.1619775895960629, 0.1566965112579055, 0.08631494376459159, 0.22565754130482674, 0.09812687712837942, 0.2068818433326669, 0.15084561193361878, 0.15645550622139126, 0.18876241170801222, 0.17216932552400976, 0.1365594769595191, 0.23597654071636498, 0.10105013745487668, 0.10516258553252555, 0.10675171666662209, 0.144664115505293, 0.15528825635556132, 0.16186470893444493, 0.20636640692828223, 0.16209971741773188, 0.18215159769169986, 0.18602587573695928, 0.10730558147770353, 0.2653727727010846, 0.24404865835094824, 0.14981338841607794, 0.14411860727705061, 0.15613614523317665, 0.165431915957015, 0.25340632419101894, 0.15444927325006574, 0.23289303586352617, 0.14525044185575098, 0.15077829913934693, 0.14922379661584273, 0.18252100911922753, 0.22275376977631822, 0.18542889214586467, 0.2815653366269544, 0.19867078081006184, 0.18615555862197652, 0.1608205516822636, 0.15444597811438143, 0.13263710774481297, 0.0798851098807063, 0.15947181702358648, 0.13967636361485347, 0.17280175408814102, 0.15928095148410648, 0.16069098754087463, 0.10099317762069404, 0.1992946895188652, 0.14763757470063865, 0.12567789992317557, 0.25329072726890445, 0.12458667566534132, 0.099784649501089, 0.16462425148347393, 0.176295236160513, 0.14568560756742954, 0.2781565336044878, 0.08802084441413172, 0.08723899183678441, 0.205856803804636, 0.20075476117199287, 0.20587509032338858, 0.13180855923565105, 0.12048895921907388, 0.1582248753402382, 0.20488475362071767, 0.10446083295391873, 0.17015832796460018, 0.12425101711414754, 0.17728598846588284, 0.1434945352957584, 0.09874260736978613, 0.09895079463603906, 0.12645580427488312, 0.2648131042951718, 0.1718175326823257, 0.0546560890506953, 0.10135388365597464, 0.23253776977071539, 0.09324118538643233, 0.12785914615960792, 0.13364369748160243, 0.21916974568739533, 0.08397428420721553, 0.12135948360082693, 0.09486694150837138, 0.17246171686565503, 0.08639825726277195, 0.10612984886392951, 0.10644822279573418, 0.1695961956284009, 0.12710736540611833, 0.1317710807779804, 0.11494190999655984, 0.13721097871894017, 0.07906192709924653, 0.12551321735372767, 0.17238343512872234, 0.11204469905351289, 0.1986576447961852, 0.08432577276835218, 0.10331956567824818, 0.25865131930913776, 0.11156780979945324, 0.07694054991588928, 0.13868328096577898, 0.1955695979995653, 0.22991601435933262, 0.12017899382044561, 0.07303143545868807, 0.08300253088236786, 0.1170074479887262, 0.11396099856938235, 0.12335570499999449, 0.4153224342735484], [0.031142386724241078, 0.01770583457982866, 0.07903917285148054, 0.08293221239000559, 0.06570989629835822, 0.04839461878873408, 0.022411724348785356, 0.04844974922889378, 0.02316434372914955, 0.030505458889820147, 0.06932344302185811, 0.03714045764354523, 0.053009233670309186, 0.07678017922444269, 0.04589360709360335, 0.05268567954772152, 0.05437141233414877, 0.026782684726640582, 0.044961046587559395, 0.06113628507591784, 0.055089176748879254, 0.03845132050628308, 0.015462588398804655, 0.03382164373761043, 0.032629205379635096, 0.005978984272587695, 0.036293700541136786, 0.01882771324744681, 0.03639779046352487, 0.02224884334282251, 0.05734570644563064, 0.0686531352403108, 0.06467599552706815, 0.010306031308573438, 0.01448361954317079, 0.05471848140587099, 0.04649460570362862, 0.02648681456776103, 0.049242626409977674, 0.01341365596090327, 0.0051008027821808355, 0.051343126979190856, 0.04298948304494843, 0.013132223357388284, 0.040531200502300635, 0.05959625443210825, 0.05664468859322369, 0.09022166108479723, 0.023761800439388026, 0.048864398268051445, 0.03159215048071928, 0.016512052934558596, 0.017176225010189228, 0.04569549819279928, 0.013833095563313691, 0.03350018618220929, 0.009881353998935083, 0.03549841509084217, 0.013268787806737237, 0.07817197329131886, 0.08367006303160451, 0.01553567139126244, 0.0292685603199061, 0.0367023196304217, 0.04731757326226216, 0.05491037110914476, 0.013672364002559334, 0.03778711317863781, 0.037457421494764276, 0.07843375846277922, 0.07529329377575777, 0.014492883401544532, 0.041896173352142796, 0.06836861808551475, 0.05781314815976657, 0.022173131292220205, 0.03462968299572822, 0.052909808146068826, 0.02234231313195778, 0.056071168000926264, 0.09763015768839978, 0.08429397174040787, 0.06178211682708934, 0.03612621265347116, 0.06156372503028251, 0.041712354504852556, 0.08581483270972967, 0.035070704252575524, 0.04605517635354772, 0.05306793384079356, 0.02315437111974461, 0.024889313863241114, 0.048914337385213, 0.027217240021855105, 0.008088116483122576, 0.09225210291333497, 0.06327279465040192, 0.08351476120878942, 0.017243812399101444, 0.04764675657497719, 0.015107388171600178, 0.05535604192118626, 0.08765669481363147, 0.020573216752381995, 0.02003113168029813, 0.04393326482386328, 0.024043714511208236, 0.06615575635805726, 0.029517244729504455, 0.08718727898667566, 0.027078501079813577, 0.01836736646509962, 0.032152100902749225, 0.08107579677016474, 0.012473550596041605, 0.04298613595892675, 0.015750442435091827, 0.04184790777799208, 0.014714469216414727, 0.035830329507007264, 0.0267315563178272, 0.08371082178200595, 0.05896500217204448, 0.0188315000559669, 0.011270511586189969, 0.02231790203950368, 0.04198141643428244, 0.025840003181656357, 0.026336832088418305, 0.025411058522877283, 0.03503696250845678, 0.02559348398790462, 0.03351020517584402, 0.0530664421239635, 0.10086778434924781, 0.0752191903302446, 0.039480445557273924, 0.01399680128088221, 0.01559743941470515, 0.0530049366352614, 0.03389048906683456, 0.05892337139812298, 0.02721935699810274, 0.0199330717077828, 0.01338373813268845, 0.06459925003582612, 0.042662314663175493, 0.0047297595574491424, 0.09887285428703763, 0.05316881026374176, 0.04158502422797028, 0.029955191639601253, 0.022532629482157063, 0.0002648685341455348, 0.0627268485550303, 0.06658486614469439, 0.05087348479719367, 0.0342868627194548, 0.08909352982300334, 0.05140941189893056, 0.05893333473068196, 0.05160015127330553, 0.07744326590909623, 0.005418060245574452, 0.034264776404597796, 0.038409140543080866, 0.02725496524362825, 0.036379581870278344, 0.032716006971895695, 0.034548098701634444, 0.010636527294991538, 0.0320798899338115, 0.04984558800060768, 0.046312638514791615, 0.004729073070848244, 0.049880817750818096, 0.09117624853388406, 0.024623868048365694, 0.057112594149657525, 0.053180910981609486, 0.010698681235226104, 0.031164346873993054, 0.014175319338392, 0.034569858471513726, 0.034545011367299594, 0.05157678846444469, 0.013895522242819425, 0.041791226249188185, 0.028781921100744512, 0.05643988180963788, 0.004762833832501201, 0.04587521296343766, 0.04175466805463657, 0.12272293504793197, 0.04044713743496686, 0.06654784039710648, 0.033547598286531866, 0.019053587748203427, 0.06005566981912125, 0.0717037332651671, 0.04452256347576622, 0.030842521955491975, 0.01831600056902971, 0.030671750064357184, 0.01857881732576061, 0.018814028044289444, 0.014916261952748755, 0.04966035165125504, 0.057764507801039144, 0.0635499571217224, 0.0938992625742685, 0.008320355827891035, 0.02654659270774573, 0.02202922143624164, 0.07833632931578904, 0.011899819419340929, 0.010823282264027512, 0.04859161446802318, 0.031139262282522395, 0.04827714423299767, 0.013389434116106713, 0.07850409179809503, 0.09795564881642349, 0.08660988809424452, 0.021402767160907388, 0.059952648589387536, 0.02191574705648236, 0.031227488798322156, 0.038244702882366255, 0.014523033150908304, 0.02125901315594092, 0.08319534827023745, 0.027854388645209838, 0.013875895219825907, 0.023117080054362305, 0.0328782552969642, 0.05885174672584981, 0.11119298811536282, 0.12345057373750024, 0.0551356871437747, 0.058473674434935674, 0.024186665141314734, 0.07015275594312698, 0.048586682896711864, 0.08900115470169112, 0.007334015126616578, 0.05804463515232783, 0.039423515408998355, 0.05722043562855106, 0.06289458877290599, 0.01902943455206696, 0.06161936013086233, 0.06388427980709821, 0.02898125268984586, 0.04484406927076634, 0.028554488089866936, 0.030903053375368472, 0.06072265648981556, 0.029305606476555113, 0.0796100105799269, 0.058354132997919805, 0.07513529795687646, 0.0005505931574134593, 0.04797727946424857, 0.054636277418467216, 0.08906720584491268, 0.05751418138970621, 0.08703827057615854, 0.002291904861522198, 0.010704384640121134, 0.027862014212587383, 0.03712951467605308, 0.06989118599449284, 0.032959475938696414, 0.06142459089460317, 0.04172978755377699, 0.022755078971385956, 0.04098947669262998, 0.0254433456575498, 0.011414793443691451, 0.05372707229980733, 0.030846197441860568, 0.022197642574610654, 0.04452281580597628, 0.04974422918166965, 0.02628556267154636, 0.018983477057190612, 0.06144538216176443, 0.009208571154886158, 0.03219825877749827, 0.0030017076551303035, 0.05784828885225579, 0.055661921796854585, 0.041336349095217884, 0.06385644926922396, 0.04026355978567153, 0.019718318289960735, 0.020440372318262234, 0.016027695819502696, 0.040145305974874645, 0.012116721354686888, 0.04745644022477791, 0.035267525527160615, 0.024555792697356082, 0.0635325389157515, 0.012238953077030601, 0.03691090394568164, 0.024656940004206263, 0.0224897519001388, 0.03374134706973564, 0.1001420604006853, 0.025821972703852225, 0.04928773414576426, 0.01456559160942561, 0.050804246129700914, 0.032689003928680904, 0.045553128293249756, 0.09063624704140238, 0.003046716360586288, 0.06179435113153886, 0.04591987541061826, 0.03069032416533446, 0.0307235352738644, 0.05481330932525452, 0.035490808077156544, 0.028611982270376757, 0.027642807908705436, 0.02275766721140826, 0.06919933366589248, 0.031006419703771826, 0.12981776293599978, 0.06310171476798132, 0.02135335496859625, 0.010000128240790218, 0.09196326645906083, 0.03878604395140428, 0.04062955362314824, 0.04894575249636546, 0.06013185498886742, 0.022209876879060175, 0.007878523774706991, 0.026142625029024202, 0.029439794197969604, 0.023680713384237606, 0.03420535635086708, 0.013735506854573032, 0.044665924142464064, 0.005684815951099154, 0.017707754886941984, 0.060407833734643646, 0.08647272436064668, 0.03838766278931871, 0.16724827786674723, 0.08704551393748261, 0.1085612211318221, 0.14243603975046426, 0.09300269623054191, 0.1204372983193025, 0.08316325038322248, 0.16156645462615415, 0.1202115295745898, 0.15445256838575006, 0.12659673811867833, 0.1375023607397452, 0.19007381633855402, 0.22921781666809693, 0.153432872320991, 0.08297682288684882, 0.1429927395656705, 0.1926306783570908, 0.11985188481048681, 0.16333306295564398, 0.1407748312340118, 0.12169920912128873, 0.09910479770042002, 0.14987586240749806, 0.11230408708797768, 0.1655750465579331, 0.11999174996162765, 0.15559691557427868, 0.0919372244970873, 0.04937462850648444, 0.10651641132426448, 0.18697330146096647, 0.16720665822504088, 0.20966188400052488, 0.12396716047078371, 0.12681292573688552, 0.12623191316379234, 0.16716316837118939, 0.16060342895798385, 0.10953300414257683, 0.08634551282739267, 0.1145037089008838, 0.14095076476223767, 0.06490646948805079, 0.10622399771818891, 0.16812604560982436, 0.21102022205013782, 0.14116502279648557, 0.1460912061156705, 0.10309428675100207, 0.13022665661992505, 0.09980877672205679, 0.13503213704098016, 0.15322101884521544, 0.09876381795038469, 0.14292107778601348, 0.08673934833495878, 0.08969059505034238, 0.11452764316345565, 0.20196646568365395, 0.15055942494655028, 0.21841811336344108, 0.2185049743275158, 0.14440746599575505, 0.1761263085063547, 0.1812759376480244, 0.14893869316438213, 0.1744413809501566, 0.1452470279764384, 0.1592228710069321, 0.13519582513254136, 0.10566355005721562, 0.1566652668407187, 0.14894293824909255, 0.10222348035313189, 0.1777289912570268, 0.11208903495571576, 0.26153046637773514, 0.16765524196671322, 0.2298575479653664, 0.1619358957395889, 0.16962457535555586, 0.17340730206342414, 0.158503299462609, 0.18409701908240095, 0.2731185086304322, 0.15406034333864227, 0.17937231401447207, 0.288614789606072, 0.17583177977940068, 0.19520970090525225, 0.1720594134530984, 0.1538522748160176, 0.14897235698299482, 0.11673813743982464, 0.17588696588063613, 0.14382716588443145, 0.20782451931154355, 0.15864113112911582, 0.16091585828689858, 0.1173953537363559, 0.14842576521914452, 0.1381278724875301, 0.11834793738671578, 0.11402455609641038, 0.08491256667184643, 0.12112109834561124, 0.22439453954575583, 0.214417121023871, 0.14620070258388296, 0.08509278239216655, 0.13080201402772218, 0.13869687711121514, 0.1443322715931572, 0.16574669047258794, 0.16592746280366555, 0.09885851599392481, 0.10701702703954652, 0.174813152407296, 0.19123719219351187, 0.15226539981085807, 0.11786314425989985, 0.18542636884376407, 0.12219687108881772, 0.14800076693063602, 0.1116151588212233, 0.19725206162547693, 0.09509751194855198, 0.16497846372658387, 0.1213321131945122, 0.17497029475634918, 0.11530031537404284, 0.13240607717307284, 0.1319651969242841, 0.24803068139590323, 0.14422647102037445, 0.09128004530793987, 0.11455192623543553, 0.1428674947237596, 0.15323390252888203, 0.15472993865842, 0.22288573847617954, 0.10078352832351811, 0.11782346904510632, 0.2437969812308438, 0.15904100029729307, 0.19633362418971956, 0.13614369614515454, 0.20698556589195505, 0.2294596380670555, 0.10888306831475347, 0.13439924834528938, 0.07870295026805252, 0.10750202054623514, 0.2254232601262629, 0.15310827177017927, 0.15060880745295435, 0.0704802805557847, 0.19166692538419738, 0.13823555811541155, 0.15595074190059677, 0.13948085223091766, 0.19863864581566304, 0.13583373074652627, 0.11283291925792582, 0.0937914804671891, 0.14122693275567144, 0.08145903440890834, 0.11715372529579327, 0.09773661135113798, 0.11264258806477301, 0.11166422962560318, 0.12890741490991786, 0.15278436883818358, 0.1605113729601726, 0.16089190175989643], [0.008508998635079479, 0.016585848388785962, 0.00997279030343634, 0.003743748648048495, 0.04429492080816999, 0.022068863254389726, 0.02848054420610424, 0.04842250869842246, 0.06795757959480397, 0.011224805493839085, 0.11264198692515492, 0.046910594319342636, 0.022624347802775446, 0.03171496849972755, 0.08105284956400283, 0.021690013563784305, 0.018392410238448065, 0.026802750544447917, 0.011257010064582573, 0.0009088615274777112, 0.07764425434288569, 0.036331442461232655, 0.0760905236529652, 0.027654365003400017, 0.044652520955423824, 0.0361270883877296, 0.03268626540375408, 0.01887828875624109, 0.026413796513224952, 0.04028400595416315, 0.08992714720079675, 0.04241050024575088, 0.014082787438383093, 0.03075991535297362, 0.047995866552810185, 0.03825311141554266, 0.017992298016906716, 0.01190120909086545, 0.024264829989988357, 0.0656386798073072, 0.05405044459621422, 0.03441242668486666, 0.03529462876031175, 0.04433776870428119, 0.03199411621608306, 0.052023476018803194, 0.049721400719136, 0.03741816930414643, 0.04743182689708192, 0.06209121391293593, 0.0856131169712171, 0.04391370923258364, 0.020686542702605948, 0.06077197591366712, 0.010670333977031987, 0.02354049756831955, 0.021969623267068528, 0.06740433818777092, 0.0630800960061606, 0.03385214600712061, 0.06793861030018888, 0.054872573527973145, 0.053768294892506674, 0.031907782176858746, 0.02589436735433992, 0.02770779963611858, 0.0021458031187648885, 0.034175136097474024, 0.05863065722223837, 0.07886539155151695, 0.11400439194403589, 0.01191003322674078, 0.038322691470966674, 0.03356025932589546, 0.08520368894096464, 0.031568706035614014, 0.04917573292914312, 0.06459904223447666, 0.05112420083605684, 0.037050431419629604, 0.019109206150460523, 0.04773664550157264, 0.02594630841485923, 0.029163585386413615, 0.01727343893435318, 0.027041512439609505, 0.038433802110375836, 0.05707553129468579, 0.03704965587530751, 0.05004826853109989, 0.08337619481608272, 0.06501347976154648, 0.03452052791544702, 0.052930829479009844, 0.07181878841947764, 0.029127318484825082, 0.022541156758961733, 0.08662852342240512, 0.024906553953769617, 0.017378987176925875, 0.03506348315568175, 0.0070697117553208955, 0.09410715298145078, 0.01588020139024593, 0.027879886984010227, 0.007838621277187485, 0.03701745408761781, 0.03165167443512473, 0.07168523894506507, 0.05669366291840561, 0.10367892842623405, 0.03840833902359009, 0.03143124544294551, 0.05189173738472164, 0.0695558317238465, 0.018984799935424235, 0.07459137050318532, 0.02620041606860468, 0.06708424989483319, 0.06765798199921846, 0.05216877369093709, 0.045822223619325086, 0.025686699591460638, 0.019389836306800134, 0.07850418085581623, 0.03801888960879296, 0.028797645354643464, 0.06064952154702041, 0.01363341052638134, 0.013435328528430546, 0.013896327473048586, 0.03806230524787679, 0.03558749507647008, 0.018151731746911537, 0.06972762406803668, 0.057812706581898965, 0.04920609419059474, 0.05095351429190487, 0.029320185967662837, 0.041555560965207405, 0.08744709004531614, 0.05235294134763535, 0.06702459606458433, 0.014708468952449039, 0.0115136679232819, 0.06918634608155116, 0.01805137853807537, 0.023042395878292155, 0.05955351414741017, 0.03330994033603929, 0.02008363120694412, 0.026309072054573335, 0.01482200084865326, 0.011199220880371286, 0.012739497360598762, 0.012579312206071336, 0.037369792407844216, 0.03583306432119571, 0.024304319667862728, 0.005742917301176931, 0.0954552271286957, 0.021545259514823556, 0.0073236018670286285, 0.080617565108696, 0.04459169824258424, 0.013388800507527776, 0.034012182732112706, 0.06410171423340216, 0.06061668522306718, 0.010321083918825025, 0.03675207692140248, 0.08565504831494763, 0.05215624623815529, 0.008580864505347563, 0.05730593104090076, 0.04012619567220099, 0.029650029791810084, 0.04751963038870599, 0.016912187420530245, 0.01882466302049579, 0.07570822854177095, 0.039494687371188775, 0.009597690313967178, 0.0023610635162185645, 0.0773774967819918, 0.014094610778556671, 0.039006313381833024, 0.032603063227725215, 0.014576039193343604, 0.042743553858599626, 0.033404998321202584, 0.023990038680494763, 0.07702173345023766, 0.024613941823190544, 0.014158313952066237, 0.03979619970778003, 0.01945800813700771, 0.03416502062464133, 0.05598473748250399, 0.020787856992683373, 0.0423131156276213, 0.01870940006483579, 0.036262196372263134, 0.059001022309530526, 0.06660310813458636, 0.022061436211515684, 0.044814316570409574, 0.04957265577104408, 0.04299916807212867, 0.04156186550972052, 0.035146926529705524, 0.02575328322564019, 0.03327583122882061, 0.03769693852518685, 0.05124133029312361, 0.06952972296858206, 0.025080327832256444, 0.039235781732713804, 0.06128980945504736, 0.012901789286843268, 0.10303008355549537, 0.037799180499860086, 0.05525288710487075, 0.03498535355902277, 0.018125407768820878, 0.010974097804137273, 0.0061201639528007945, 0.01648053392273141, 0.03775601348024793, 0.009992623272410128, 0.050526957493275404, 0.04772259664605372, 0.049798109102994204, 0.06056601880118251, 0.02656249693245627, 0.03867867373628542, 0.06677793586277403, 0.061896147817606106, 0.011311284251860343, 0.06960690632695332, 0.00642119667645602, 0.06430420180549845, 0.02541990306781372, 0.040038800361799076, 0.052143937718938105, 0.04539718822343275, 0.022677537526760716, 0.04447833518497646, 0.02625689907290507, 0.03818949822743889, 0.04906694150122348, 0.07544538209913298, 0.09544602449750528, 0.02362524526688503, 0.06722614853060804, 0.009985141496144934, 0.009855400166998152, 0.07511272182455286, 0.007533769739893614, 0.010548183890932705, 0.04918122482195031, 0.015640929268556647, 0.04662323473894503, 0.05757826584158465, 0.12374536221614107, 0.012089969713997561, 0.07507709131459706, 0.03611762971559074, 0.028826344205299392, 0.04329199728090316, 0.06165428931126371, 0.021977857395540923, 0.017707845800032374, 0.05759136474807747, 0.016003340388124343, 0.037124301088624634, 0.10043565402156673, 0.04274471531971358, 0.06853409475297667, 0.05231165938312188, 0.011627651601884281, 0.03809701920545194, 0.03467307637038175, 0.0018179983453592286, 0.04782596297445707, 0.05807495930639561, 0.03890028274327051, 0.06315721257124096, 0.04309661206207238, 0.04990025459846947, 0.05404328287113458, 0.014933513175492408, 0.029977070153108798, 0.026781263513839804, 0.027728598324756604, 0.04158766256296076, 0.016189318885153625, 0.0926687965693418, 0.026452620113559533, 0.018152130651287735, 0.03656302964373026, 0.03683416587591637, 0.04029032905236818, 0.028991642757318914, 0.06698641998809762, 0.0878368214762304, 0.045288600886124186, 0.05284665880026296, 0.01732545792037854, 0.007639537379873218, 0.08742611695197411, 0.007630628360857372, 0.0358575663267402, 0.07160300898249261, 0.04917437479889486, 0.06109918511356227, 0.09092172898817807, 0.011408998198021436, 0.04955043586960528, 0.008355911195394583, 0.027012594655388966, 0.019333076852490194, 0.06669164635241032, 0.029689935072383378, 0.010608503798721358, 0.07988179990206845, 0.01204843078085105, 0.045320457575144246, 0.059867208838113584, 0.0710603802872356, 0.022782193336752243, 0.0037192821264397935, 0.05879835662199184, 0.01221808945047087, 0.04654971016861964, 0.05794587385025807, 0.10302563066943549, 0.030526213049597573, 0.015833399702387396, 0.017654114308243152, 0.039618121372768655, 0.01975906219740864, 0.03531235866830684, 0.037489771711989306, 0.015642061043763533, 0.031582283627358265, 0.03510182250465732, 0.03522283339407295, 0.0627775966131594, 0.020105693402001634, 0.051095902745146304, 0.04780471899721306, 0.2169256840716116, 0.10365460082539357, 0.09149175777565688, 0.04689457135100383, 0.24737867497606203, 0.13987757469294593, 0.09739989895024337, 0.10067787618027069, 0.2096836140844971, 0.11053139314753935, 0.1803135353839025, 0.19043537584366277, 0.1367843328625895, 0.1060148976102937, 0.2046771749155596, 0.09778329986147583, 0.16651565936626866, 0.2178872996591963, 0.10012726939748973, 0.08232224863604642, 0.16875149798579514, 0.08032504018046893, 0.16577806847635657, 0.14879507274599746, 0.15669746120693162, 0.272334681940265, 0.19598146027419716, 0.16041666007367894, 0.14317769760964438, 0.14028084289748222, 0.19264261209173128, 0.1251015777233988, 0.07320208489545621, 0.13150595594197512, 0.12844766926718876, 0.1305674805189483, 0.15913219540379941, 0.2321181001025252, 0.0819588708691299, 0.08767233186517842, 0.1386993410415016, 0.1475383050274104, 0.2155066086561419, 0.11093403794802725, 0.1391412306111306, 0.11595920150284655, 0.22030190681107342, 0.12253378386958502, 0.1427659986075014, 0.13292336894664913, 0.20691856479970738, 0.15466742013813928, 0.12324811585131101, 0.21731522254412994, 0.13023734354646876, 0.1315119821811095, 0.0948836249881424, 0.19182271702447906, 0.13786081806756556, 0.11137409441289492, 0.19540010631317273, 0.1325386989628896, 0.1491767741390504, 0.09295310592278838, 0.1322283921763301, 0.16663138987496495, 0.18122823239536956, 0.12819997005863115, 0.15833642013603821, 0.2316207275725901, 0.1868398187798448, 0.18193548428826034, 0.16031458508223295, 0.11964662902755663, 0.20526967593468726, 0.1612966097309254, 0.22333527216687799, 0.15370573033578694, 0.11067372222896665, 0.1270982073037885, 0.07436835512635298, 0.17808960081310943, 0.1371177946566604, 0.15802851790795103, 0.15838510502362624, 0.08124506581225432, 0.17366806307109073, 0.13613995572086424, 0.13878764177206904, 0.12321503832936287, 0.14108460367424414, 0.27107864152640104, 0.13297294441144913, 0.22162526001920924, 0.13920759345637634, 0.17059485922800377, 0.16730819887015969, 0.15085831750184298, 0.08731151450774632, 0.14627322525484487, 0.16861887619597837, 0.12105956688174047, 0.22363535215845332, 0.12971599964657798, 0.10306531330570579, 0.08947100839577615, 0.09956489957403392, 0.08473444380797446, 0.164358829788398, 0.17176280671264976, 0.19727270817384124, 0.09421636001206934, 0.09941723445081152, 0.15439122245879844, 0.21655858814483508, 0.08507061444106512, 0.11325989908073097, 0.13581759645603597, 0.23328782874159515, 0.10444716259371489, 0.13203390495618805, 0.17308063834207132, 0.15009069931693375, 0.12706478097243235, 0.2857906208373606, 0.2148883996414952, 0.1226351538207382, 0.19055365934036672, 0.17155815206933767, 0.29642639856319875, 0.15366560983238742, 0.15905630338238552, 0.15803730493644252, 0.0887960399268195, 0.1667873893165961, 0.2254655328579247, 0.10914887592662126, 0.1372065703617409, 0.09898529708152637, 0.1475292508257553, 0.3165479813469574, 0.12601633410668, 0.1606039039324969, 0.18262364814290777, 0.06583116322872229, 0.1578977663302794, 0.10144868560018949, 0.1925094856414944, 0.13916477153543383, 0.22519032965647057, 0.08999135039630346, 0.14497552067041397, 0.1502981295925565, 0.2544618066167459, 0.07723728282144293, 0.12121665728045627, 0.14299885486252606, 0.10162410704651847, 0.09938010480254889, 0.17441941337892786, 0.2740619861287996, 0.07549849760835059, 0.17827555333497003, 0.2016353193903342, 0.1003575578215532, 0.142374174320139, 0.16988606366794556, 0.17498368310043588, 0.11600121448282152, 0.17997924238443375, 0.1297186713782139, 0.1108106855826918, 0.10920477448962629, 0.06346199777908623, 0.11814199140644632, 0.137911269266624], [0.037754195218440145, 0.07325419108383358, 0.01271821349291713, 0.029401775827864185, 0.038977829754003324, 0.08550995102268644, 0.05739849540987052, 0.02336454919714015, 0.017551755445310846, 0.027989038353553042, 0.024171783225028776, 0.03355871936946642, 0.050191406553494744, 0.04508410951530095, 0.0033367446576448856, 0.023300247667066287, 0.04428626736626029, 0.04301133187254891, 0.026043271864182316, 0.019928299698221963, 0.052477032149909064, 0.044877209875267, 0.015001684078015387, 0.03711345460033044, 0.08962469975813292, 0.024763851943134796, 0.05002770361898001, 0.03827094522421248, 0.03562625002814457, 0.006952339708732325, 0.05717515348806046, 0.0320668763743015, 0.06866034149425104, 0.0650706845044624, 0.009167545231321128, 0.033026896344381385, 0.06660229177214205, 0.05637139271129854, 0.04729852604214102, 0.07637135233380832, 0.08253154912381433, 0.07611583088873886, 0.010576439308351837, 0.038544229973922484, 0.034881790561485104, 0.06258694629650563, 0.013836516864103032, 0.0662372367514763, 0.01576021280925488, 0.022175712110765744, 0.014306299126474187, 0.02731360789766768, 0.02496954744856339, 0.059017145467805676, 0.12284709635423496, 0.08382392508792691, 0.06269281366257928, 0.029129455870133825, 0.06754168745828792, 0.03486208282993175, 0.06263970557483844, 0.040858981155906804, 0.043702156326617114, 0.007011307052380289, 0.04493726075452287, 0.06293697282671928, 0.007018928445177153, 0.03150566801195964, 0.03892684791935608, 0.05511374554771464, 0.022134949649625923, 0.013527022729249438, 0.0480888168385718, 0.04613011100445874, 0.02856920487829484, 0.09854187126620673, 0.0387004780350253, 0.03222699844627641, 0.016027552956074942, 0.056635890432517044, 0.028977031724934932, 0.04756014051963575, 0.04922652180539444, 0.07852646755054593, 0.05112825667310972, 0.044731129237334244, 0.028929100117238704, 0.051973418158013374, 0.051726910096476786, 0.04224897551466711, 0.05268189088383224, 0.08926375623559579, 0.0686161317571532, 0.019091953072347678, 0.07744751099380665, 0.08317951826029457, 0.0330641632899642, 0.019786551347351633, 0.013032888746238314, 0.04097955417819321, 0.026384730299469084, 0.02842997055267915, 0.0273075389850419, 0.027492758636071812, 0.03495830598694738, 0.039225295186042786, 0.03325919598864857, 0.060759392799809575, 0.03573233261704445, 0.03686387775815092, 0.04452537992619909, 0.03284496626292821, 0.023919966952234972, 0.061904753019916825, 0.024457669642288238, 0.16121578984893858, 0.034686635408434086, 0.0437133145169355, 0.04483648452151101, 0.010567740409896942, 0.058699105502455495, 0.06339288156596012, 0.034971141431014985, 0.014360866462084232, 0.03323977769468911, 0.011099510556960013, 0.013039625591773074, 0.049840856809169054, 0.03499562117212918, 0.026852441042137798, 0.02591388769360492, 0.052129970499663614, 0.022868358537380118, 0.08482908990117721, 0.022200303174031433, 0.0325770175550133, 0.038095471827546135, 0.026010001383838244, 0.03716428800544236, 0.08053051118622534, 0.046203950987546705, 0.0495744666113751, 0.047962781609385274, 0.040339577972190455, 0.033856628579087555, 0.052572409258573316, 0.029008734418312088, 0.007847413871786557, 0.015766161122883204, 0.037676262290915474, 0.022974034800427034, 0.010240607280138647, 0.018338316949666478, 0.1250339680700563, 0.020773811847902834, 0.0319020824827021, 0.03976504063757602, 0.01905036682728678, 0.0191363446356263, 0.039015586517052725, 0.02564838621765375, 0.04580632310535293, 0.010071583146782359, 0.04610584277543239, 0.03564787250070367, 0.05278348347928841, 0.021620539264404215, 0.03971961006755009, 0.07189586787717417, 0.03702507594425697, 0.06614682090003043, 0.03940834219974931, 0.016707551330910064, 0.06379160040523857, 0.014948357056709938, 0.05097565626783762, 0.0428139391442528, 0.05275194962450769, 0.016487100074300542, 0.02258224576507928, 0.016952239275269676, 0.03504592023091391, 0.02542798134527402, 0.048320125715690665, 0.03177051083184779, 0.014662106987088919, 0.019241492118453607, 0.03462013897660654, 0.10093528268043883, 0.030108348655630834, 0.07220374041935429, 0.010898158470808994, 0.054779344936832786, 0.028400438641256187, 0.05621223172056489, 0.03504358617647085, 0.034289334071218036, 0.007905415495770285, 0.05343654003809206, 0.06280098168645054, 0.08709187590284273, 0.01033798262142227, 0.02308616032678401, 0.05693367347703315, 0.03656604647403583, 0.015299679562303936, 0.08182915087672882, 0.00813463708254858, 0.03192830627085641, 0.05171356999198906, 0.037811941729160026, 0.05070852392236702, 0.09468530828598887, 0.023040777996357065, 0.03752113858354278, 0.04187530415947549, 0.04068675836606417, 0.025277015520259738, 0.0057162180746672675, 0.04575188286253251, 0.017445398261770606, 0.014149144717521267, 0.04001267305284273, 0.009947694579750532, 0.034395565089653246, 0.06917048638570122, 0.0762098832638003, 0.028346718281682115, 0.03787141373322811, 0.05236492332187481, 0.03784843684115913, 0.04943297986756079, 0.06177470277179964, 0.03835088566120248, 0.07011938156210817, 0.05660628987243399, 0.04942119456245564, 0.038375424774130806, 0.10438171259011142, 0.07476655446225777, 0.046053940677666105, 0.047375980284414254, 0.034987977051059715, 0.04088795460120309, 0.02610456769616576, 0.053777074499521405, 0.033668022879282944, 0.0028714203835988883, 0.019789848338405136, 0.0344276889518369, 0.03463875204033684, 0.00977734107436845, 0.03906870202627033, 0.027497454575495794, 0.04437660529220011, 0.07724661903921515, 0.03464718654868193, 0.0532659833697835, 0.028805590045521967, 0.028124894051870797, 0.047268097987398505, 0.026708931945904624, 0.030038104378036223, 0.035615321903605945, 0.12002801871858537, 0.038754892302677035, 0.07584050152217969, 0.05277861870126799, 0.029147163513698615, 0.016384611335524824, 0.09558776728226803, 0.07971884653670713, 0.06059984960302245, 0.08466670798952691, 0.02085226798953954, 0.02338199337827973, 0.023895231170172337, 0.018022527547145728, 0.01765442044415977, 0.040566430252511054, 0.022301680546661373, 0.05299111042404547, 0.042693507130024955, 0.06611879740376025, 0.026050212800328154, 0.02472358672093833, 0.02257593750982778, 0.03322414806461893, 0.017144466655736323, 0.06621737687964924, 0.04644754240871407, 0.04764434459502809, 0.02902537893533008, 0.046956600053817965, 0.011293360457784729, 0.008388874612137442, 0.06187102982949, 0.09427685246919282, 0.020502115294220857, 0.026788321338244714, 0.027144426057930104, 0.04185207864793483, 0.03270922745286953, 0.04467128244868945, 0.03408109856536612, 0.02550173598137917, 0.035424868256086484, 0.028211604731041007, 0.04191133542917669, 0.03912456348189153, 0.010346179642510833, 0.06236556364456192, 0.039240717014763504, 0.010727903299994068, 0.05719900982512627, 0.05544248728256207, 0.023697433971392456, 0.027754028014896903, 0.014521098000841448, 0.012394273453537608, 0.02301140750205377, 0.029557135167124216, 0.09506415983196348, 0.06741759294527583, 0.02870939286367502, 0.029892528400523588, 0.015092903304321226, 0.0992519804276526, 0.09062762328539975, 0.10047876538010314, 0.04416598749230616, 0.059833782506757416, 0.06533694482641295, 0.054756471945438534, 0.03848479507723823, 0.02145871581888059, 0.027762178651755676, 0.017948021486517973, 0.043774534278782085, 0.040361085411859676, 0.005735614104196429, 0.03900556381267961, 0.01214499903653632, 0.01795823158317944, 0.06226071302080527, 0.04259845656633843, 0.06162140845844988, 0.020540777477435768, 0.016135661608132068, 0.04339573468314484, 0.06243183743208647, 0.0282091278131702, 0.12365643808152527, 0.10140049795154482, 0.09013405797304586, 0.14347602613270283, 0.0570274141500704, 0.14495202427497134, 0.12638518150197342, 0.1406211918219924, 0.14356008177855983, 0.08991112423245795, 0.07025324273854494, 0.1104710936488118, 0.10620364802889526, 0.10000858514104038, 0.1929059557733126, 0.10008816563640721, 0.14953422214603052, 0.16228902444709092, 0.09552338597131893, 0.12522156815975904, 0.14515713904984295, 0.10162225167732686, 0.15495556639507413, 0.13367418490815908, 0.17229029559530318, 0.21306206326698884, 0.13525806163670495, 0.15478323970455676, 0.13941288634669036, 0.06835430205683224, 0.14569656166713685, 0.08254145679529756, 0.12729820125969127, 0.1403660117648542, 0.16759477177402005, 0.12304851523367688, 0.09909866756061092, 0.08810390558210202, 0.15370884735602885, 0.12435713681043126, 0.1677715068217367, 0.13139948743628338, 0.1216642910731025, 0.10272407380398363, 0.10676143880118616, 0.09079985349671915, 0.10297253000317141, 0.15554165525827557, 0.1353339833440259, 0.1593083664192818, 0.19954733143094927, 0.08686702742124908, 0.10212194712948985, 0.1708179191336967, 0.1708151286584325, 0.19711366592673585, 0.1607926914584823, 0.17097866832045838, 0.1847357559017837, 0.1760019245557487, 0.17521783069241792, 0.14902567287208512, 0.272294576279819, 0.17759565700544044, 0.1521860048524104, 0.11675919216941111, 0.13666616810951382, 0.20999298576498404, 0.12273187792743556, 0.13606547378003597, 0.10106962625286542, 0.11725964461220428, 0.12999985628994182, 0.177954648679588, 0.1094744264264591, 0.1837444247212261, 0.12343843962298706, 0.12040818386594765, 0.18616697285324335, 0.23695561161730438, 0.09001619750051759, 0.18189153430284932, 0.14507412241073325, 0.2059440952143632, 0.11171509642736055, 0.12807784223696217, 0.15405081416247413, 0.13466251781210303, 0.16448581125587225, 0.12609607045305893, 0.2116714566363953, 0.23340734420344234, 0.11627858475549147, 0.15744881151476875, 0.1444311998784542, 0.23285650735488161, 0.09320332101196982, 0.1457106476300396, 0.1513642247300595, 0.10745852327090688, 0.1056404915289022, 0.15670510532800108, 0.07385126373264939, 0.10249825310893357, 0.12147756671765819, 0.14446293411310762, 0.1962002454092726, 0.21946035587461665, 0.11554631506442092, 0.2081187066505663, 0.0777875779021997, 0.10562131443293765, 0.133699610887561, 0.31720451486762613, 0.11656169182970189, 0.3037700685672462, 0.11206515264348127, 0.16076882398920134, 0.12664997979300097, 0.09956226494978182, 0.11037419884814881, 0.21944955020444468, 0.14357770036440343, 0.10833320367964916, 0.08965365836047567, 0.1371058460790664, 0.09392760519403964, 0.13873293064534664, 0.19878569495631382, 0.10693409945815802, 0.10390480849309824, 0.06516426932648756, 0.0798293374828063, 0.2248399765812792, 0.11294295007246546, 0.16719062783522531, 0.10905407398240641, 0.14330273465020582, 0.10965646040858701, 0.1488733247970231, 0.10801045849802904, 0.17781307658879086, 0.12440057471394539, 0.08986001252196729, 0.13061901525361463, 0.18164791690651327, 0.12792233261279762, 0.11699482405674644, 0.07866536790970713, 0.14763586776098236, 0.06980673701036721, 0.1852743176277727, 0.11728949379175901, 0.23507178848376498, 0.14471213245997205, 0.13344588543986902, 0.11416725625167601, 0.16067468997789547, 0.16780807985924184, 0.0807687257474754, 0.1686888310359791, 0.16064959054347128, 0.22198324237251654, 0.1672056340612471, 0.16031535691581666, 0.13761792797595263, 0.08464106678729877, 0.06794845859985799, 0.19015257304999977, 0.14740226935828105, 0.12915788975078613, 0.10216445734840818, 0.12228218096424825, 0.24977496592327952, 0.1504344621207565, 0.10837607755092904], [0.048651361066731624, 0.023951435869093984, 0.039698314139968716, 0.040378767080255784, 0.06823085321229883, 0.025732115318533033, 0.005220659631959279, 0.08013985949219204, 0.025209454106516205, 0.03001189172209706, 0.04938662161293905, 0.03014103655004874, 0.0396345339686377, 0.07999362671398558, 0.03722034613019787, 0.05238162906607613, 0.0538658910227241, 0.012281569979677442, 0.05445368311484344, 0.007680187591176946, 0.03325364101328887, 0.03208199021173641, 0.03323060103866737, 0.01703163423371734, 0.01654903229791671, 0.01764690434356453, 0.028288810353842564, 0.0806186486443039, 0.010637767609296134, 0.02462177704728674, 0.03500336919387337, 0.021846591880603228, 0.056377860528300516, 0.04532982718956191, 0.006824406900705071, 0.03951543039875105, 0.03493349599011708, 0.04435978080437053, 0.07503563494537957, 0.017683555306575727, 0.018726868365774862, 0.048202417383436114, 0.029858834896003827, 0.03949696576455608, 0.041318771327496506, 0.03765850269701332, 0.04706106847152114, 0.038191327621461824, 0.03932885818358045, 0.060012287576682866, 0.04674157018598635, 0.06391459653968923, 0.027422586717875674, 0.017067411317839287, 0.038448730410891585, 0.04129727130930405, 0.022164169859024696, 0.06521034927573055, 0.08310584526043385, 0.07576940377475694, 0.05119556204590481, 0.06014312821207568, 0.023533923995273653, 0.019912829629902262, 0.02224871532234829, 0.0570701061951695, 0.05285195031319745, 0.05352541964384727, 0.04642041320039425, 0.11552292256965302, 0.037159475177759305, 0.019099641722277738, 0.060570501373149455, 0.045262399362400174, 0.040411232330370694, 0.04487735088332556, 0.012556777819554554, 0.03247986300266348, 0.07508365190005861, 0.021961882666801102, 0.03929215527023189, 0.04600416112225503, 0.007659073953618645, 0.045381001982605085, 0.0322740320552839, 0.035892450978280976, 0.04432088113389909, 0.056094096653396264, 0.027618456188065466, 0.016014322318369523, 0.03507558016281109, 0.10277635068632662, 0.051838603321812116, 0.04292599973268807, 0.05911290107178502, 0.07816343859303743, 0.023283374939637724, 0.05930320628976915, 0.06332577657303773, 0.04869191943726037, 0.041610587504692376, 0.055998344760155305, 0.044870126075693406, 0.07709973317105323, 0.01787746550689917, 0.040658697762410156, 0.02494563359505264, 0.03785664499446284, 0.028838049729529303, 0.08584994371631183, 0.05544411629671231, 0.052416109247133136, 0.03339754715852905, 0.06104393964051269, 0.0583654433285119, 0.02752363754552789, 0.05581468918535393, 0.0278248511676793, 0.04217125409923028, 0.0725679419701919, 0.057487208032398485, 0.029641860601259395, 0.05288893895340152, 0.09866394713753834, 0.05644159246003255, 0.04309172130888328, 0.03634619635704439, 0.09530484574497677, 0.06902547072968446, 0.07973771193064749, 0.05470911921293009, 0.05136015184689313, 0.043273870323901065, 0.03514089657983277, 0.04727671803266276, 0.07696521890466101, 0.02752593078184873, 0.015474070351046976, 0.046062352921580896, 0.03603707329602912, 0.01608474471140653, 0.03575501265004277, 0.05654388267430477, 0.030106385675026104, 0.045609141889144666, 0.03508502399199642, 0.0650523163494654, 0.03560851269867271, 0.03303518984466791, 0.04693456197855994, 0.06483471865067258, 0.07724058537860401, 0.03562303652870469, 0.041957923749578185, 0.08542170224245638, 0.011451312675490044, 0.06468009960372001, 0.011084859634138411, 0.036331134469946846, 0.04492553853197023, 0.018889515595219564, 0.01086248714273097, 0.047525649206363596, 0.005407358476077206, 0.031541279968223535, 0.0356590863520978, 0.03271742818469647, 0.017516223269922193, 0.02392135291302111, 0.011370123575034086, 0.017684985796222463, 0.030926536783226766, 0.011688440918078413, 0.007870612480473937, 0.019070894632022828, 0.04725068349216599, 0.03259460274421144, 0.04691745918535162, 0.029672086420760024, 0.009791267475520726, 0.049866275367094204, 0.028308950386417564, 0.032296578501700424, 0.14963936962885782, 0.052471547678578645, 0.057397274576942436, 0.016634336607239675, 0.04475149748031981, 0.03274066482845228, 0.03136372113658581, 0.025827757744991686, 0.05314339912729338, 0.04468265957257245, 0.04535248124739155, 0.054286714730551466, 0.0153478468018875, 0.04970132191374432, 0.05592811903625261, 0.043762359346146695, 0.04483259566768538, 0.03228618843422737, 0.06061388361558784, 0.03435233869822696, 0.07097175301169045, 0.01813275503081968, 0.04343302018241957, 0.050955911428900436, 0.025070865449379198, 0.015598784557369072, 0.008550534785172204, 0.017154288980236743, 0.030366614191734698, 0.018934467479994055, 0.08013985207071528, 0.047520220396108925, 0.03643852694949601, 0.010315396284568124, 0.05508642709173728, 0.02022162985667819, 0.049813786972663365, 0.02738343657256337, 0.029460511250363197, 0.028973521366424393, 0.05744142494222615, 0.02282840316183865, 0.023276057363545988, 0.03242099213821348, 0.006215916773726349, 0.06922080399817787, 0.024821422193781473, 0.045088658880558796, 0.022623486911470536, 0.005195667808948201, 0.05655350090819411, 0.09785678732441738, 0.030390455685846973, 0.0659446301870048, 0.006401539503713138, 0.01110774190237862, 0.018519976147217676, 0.027913198282476515, 0.02472357558872318, 0.022345153702190146, 0.01314213937803288, 0.005302149302224279, 0.02950031263026176, 0.0297643594967667, 0.04314971643907484, 0.028778564737876877, 0.06108297660830431, 0.01670689267484704, 0.05511495524842758, 0.012274679138499778, 0.0205752298279549, 0.05354462642571889, 0.03581452176149469, 0.008970156213763403, 0.05160894201253541, 0.027120399026898667, 0.057451529282843694, 0.020189034730719868, 0.06525973178213462, 0.02292285815201467, 0.05490120187459979, 0.016649602584948298, 0.10104290151502937, 0.030092327542661224, 0.04556615669571329, 0.04274155377061106, 0.06922127155121416, 0.05323198558471631, 0.019635991848190315, 0.04835432759136893, 0.08040886576054618, 0.052010150757269, 0.034074460054398514, 0.05210431445448194, 0.05409468401921913, 0.03653661289718002, 0.025033943602466024, 0.0280131934050587, 0.016401387583755422, 0.04780996227054857, 0.0398873688391177, 0.07510805371566676, 0.05384678814152721, 0.05716077437682543, 0.009940213731169933, 0.02505703738279408, 0.028435429048840888, 0.030202863017620984, 0.023360205777862575, 0.01253111249752692, 0.018042901356238872, 0.011250594197917962, 0.07948328886413947, 0.054935804510023445, 0.04897685590549372, 0.05982066875731107, 0.16630251455353573, 0.030840774197713472, 0.040220633964054286, 0.03599537201807834, 0.02611405976495007, 0.08333049336215481, 0.013972159194963751, 0.08094213597360067, 0.05169580297661014, 0.057380060461582616, 0.01118994681746699, 0.02503380259440746, 0.05010657165257726, 0.0198947175158537, 0.00959636836341815, 0.005751711287302896, 0.025903015230142046, 0.06551140890223905, 0.06910251307999715, 0.042460287222638726, 0.011205254540982423, 0.02987652213050751, 0.07233796524815261, 0.0338368763186736, 0.01560002208861988, 0.02624685595947085, 0.011192709462193307, 0.06857033382402733, 0.06090353643230628, 0.02698438005609205, 0.034809598146239296, 0.04708646847575437, 0.027840972470585257, 0.034761262068059295, 0.020516409058473073, 0.008108236106636468, 0.08772826011409052, 0.02895112891565077, 0.036262278008507565, 0.05726585506636184, 0.05013527792470995, 0.016751816729083657, 0.035142863271175884, 0.01565978909638943, 0.02350224542169599, 0.06751559354597703, 0.024231108654930722, 0.0675498362397775, 0.0683667256089393, 0.018703518544498365, 0.03643502030172385, 0.10079079394927248, 0.033751199080143124, 0.13002502993913367, 0.10483938021934591, 0.1497516268864274, 0.09255325159756467, 0.1278335420647636, 0.08581994610722177, 0.10068157949717715, 0.24254012445453554, 0.14795227500144392, 0.08262186107458547, 0.13800561107927933, 0.2606601646402851, 0.1405264640925452, 0.15716042777057737, 0.11572593706659973, 0.18287657207110897, 0.08287111137178726, 0.11165419578901492, 0.13518841849872842, 0.1269787215278484, 0.340951073449105, 0.10127405825187452, 0.07812518088030629, 0.13879248057492077, 0.09806021742406301, 0.13288217975059524, 0.12376096958178096, 0.18535295559559017, 0.08921647400711663, 0.12664531910559162, 0.11444378789747134, 0.11398478440241888, 0.13407758669927716, 0.17175807181047276, 0.056208535825135186, 0.14130837604170665, 0.11380514013580978, 0.1788377747288905, 0.12337477077380754, 0.04887355265964288, 0.08278943059849553, 0.12058511187206022, 0.14618054585298523, 0.09128476536716335, 0.07565106090623885, 0.23559047549497336, 0.13503676804248244, 0.13179200934246182, 0.14688754541566595, 0.14424950728425756, 0.21689026878448203, 0.1349622564157471, 0.16982594970613718, 0.06960198588785715, 0.11846412060549483, 0.11962629418121651, 0.10984536667820066, 0.17217441665707156, 0.2750596997793764, 0.1640868475078605, 0.14953920937841758, 0.09500599029706791, 0.14658811851404607, 0.11843599320854992, 0.1184724029735662, 0.10916400831774808, 0.12246437079738826, 0.08257634515757672, 0.1271033874945715, 0.22678728302707896, 0.14320607733679935, 0.144297702354379, 0.10632413570419885, 0.10787578838062473, 0.1556666032411158, 0.11310736546874978, 0.06495523601188324, 0.1787665137089789, 0.21734501235187054, 0.12580100737977773, 0.050865666271420196, 0.1952904020436108, 0.20975980296498165, 0.1670205275877379, 0.10737077172962017, 0.1261395454639569, 0.10271623672451824, 0.1813633181154728, 0.19124966027447954, 0.18746314861346036, 0.19664649880724028, 0.24765926616964862, 0.19966657971963286, 0.2094395662425086, 0.18867504608351737, 0.16276334587018937, 0.17074852832593024, 0.15462108043720946, 0.1482667971868068, 0.11648336556390859, 0.20021320116939023, 0.28227776871062815, 0.16637174208881333, 0.15583714877720922, 0.20674729195889086, 0.127905827248469, 0.08514468077919446, 0.1449918479193002, 0.16639661887893453, 0.3309608157724142, 0.15891835297225043, 0.12481472280342132, 0.14696965663461015, 0.17775757878553122, 0.10964549146592617, 0.09732995895319618, 0.12475256051402539, 0.1455199156771414, 0.1588217550306581, 0.1493636320810765, 0.1523556449683383, 0.09584101775544696, 0.1302653076709248, 0.26149573386646807, 0.16611078812275082, 0.20174140197923407, 0.14437862613704056, 0.16338366258423775, 0.18029265134828165, 0.18138898158213124, 0.1516423816792667, 0.12876743101514876, 0.13903372309869155, 0.13950555090559646, 0.177220709156245, 0.1481171208433807, 0.19011444150237367, 0.1576602048589848, 0.14904444920830429, 0.14494250994175673, 0.10302519280230626, 0.14373071637237445, 0.22653029212960973, 0.10262061099638231, 0.08283411531010643, 0.2105259516974911, 0.15842383028939366, 0.11490319215226918, 0.09632182554923929, 0.12148564870585687, 0.1197602369938977, 0.20508391637122259, 0.17614458018215373, 0.09218961407896131, 0.14382706198375672, 0.0907585232926067, 0.1371962990378961, 0.09037751209689304, 0.09706861164886504, 0.12798320356523618, 0.1762514197616838, 0.06880951317725703, 0.24290082306833938, 0.09658726208726875, 0.15545194444712251, 0.16063154151197523, 0.1774675029446371, 0.1313889934681356, 0.12514960952103138, 0.08426643806160428, 0.1090058714908082, 0.14977625134633854, 0.13451022910885513, 0.09723834824399091, 0.1614126964705065, 0.10835774650331587], [0.009943955083144829, 0.007243137288241996, 0.025778629424166866, 0.059733551752287894, 0.026523224332777318, 0.11334555776556954, 0.013496775573003106, 0.03664181233034469, 0.052302809272077866, 0.044013988226652145, 0.04761530064570252, 0.08640757863759063, 0.055769321697880514, 0.053914668678771704, 0.0503071222192375, 0.04598701751092449, 0.05182378263270948, 0.020594282614183612, 0.04521975184616167, 0.026086676371051, 0.05047813159762882, 0.025581889785826206, 0.04982102291251067, 0.02516908869438339, 0.048759521669126116, 0.036419153184397146, 0.03200606479367707, 0.04183079756330699, 0.026784258079715073, 0.06402748462278396, 0.0709328570519574, 0.042896903833025135, 0.06465487400419079, 0.034573840093798935, 0.05182129272725433, 0.05118308654346038, 0.05122361522808205, 0.07535699973232113, 0.03512258408591151, 0.023122941165638622, 0.00930194075408508, 0.05408020100730937, 0.01606664929568069, 0.03838001866824925, 0.003244328486289305, 0.030534367397194728, 0.029965164249006193, 0.07557214092230424, 0.018598838614707347, 0.025087502544920426, 0.08713400762644596, 0.011454415780463023, 0.03663062445411924, 0.06900220440002158, 0.021121261270309333, 0.0328050201642327, 0.050771977548720315, 0.09391849162057042, 0.011080844615207752, 0.12141332641476765, 0.02185451430705143, 0.06065361449145712, 0.019026144982490223, 0.07823388325050473, 0.06562330992892385, 0.06671337643638253, 0.05965315860521514, 0.04893440876912791, 0.04157285671681166, 0.06729447064572014, 0.05083185402327217, 0.05017509785830043, 0.04588645650073886, 0.03597279959649313, 0.037775687815155834, 0.021155986360099632, 0.07856845084461384, 0.0661057727120351, 0.055432316148653626, 0.050954096877831034, 0.043952248961431906, 0.046909410593798384, 0.027907047733606305, 0.03272374015068635, 0.03623094453359954, 0.09948786464519799, 0.06440830286010168, 0.024498799466528, 0.0181462732507498, 0.04180326017376501, 0.016461870764032938, 0.06548545599798672, 0.028726393611577805, 0.08351829383173026, 0.04196891124593094, 0.0375011043070117, 0.021794394779135473, 0.04406354884849861, 0.042341625230619684, 0.028753671249432955, 0.011195710521860747, 0.007833294512238353, 0.02378357319685165, 0.04197509704681579, 0.029025942967564333, 0.06463410129072145, 0.05695567815564573, 0.0688119103142526, 0.021272620433592238, 0.0626452939468436, 0.06910355950822122, 0.08310640187119134, 0.003875013467222743, 0.03996555409685243, 0.019302229484310374, 0.011415029075578786, 0.0659237832587678, 0.025417845463380218, 0.04450557200470939, 0.05881795674213208, 0.029958959894429427, 0.022018176423443947, 0.03316059795906767, 0.030595602001994848, 0.06388220921508037, 0.03758286671654787, 0.0653187844727654, 0.06609546428080648, 0.05884056256036274, 0.03283342957729474, 0.05173347810341511, 0.0633242774347309, 0.01613344815268647, 0.011184081067767693, 0.038780481554567814, 0.05297021896694787, 0.04915629979223013, 0.018824726103048306, 0.06176747796416748, 0.015070114732225193, 0.032947438303381205, 0.052477514545898885, 0.0506641991523793, 0.022350981416821014, 0.04900477550108917, 0.06501167634269223, 0.07902438184828497, 0.02295188169227913, 0.03421418419748079, 0.0409223679889692, 0.022573219393962063, 0.026251460985804442, 0.04047336864459794, 0.030273151824076194, 0.04258012180798687, 0.029154909680073615, 0.06599459156859666, 0.04127184161916375, 0.03334274697408546, 0.02679901197552681, 0.021432278663269244, 0.009135614327533403, 0.04838930872210767, 0.03655257278296631, 0.03387482604011893, 0.03366345496033318, 0.05832408343849238, 0.02560400764195947, 0.06846447387943044, 0.02380811045441078, 0.015330486112361541, 0.035536505820346065, 0.005594224303422379, 0.06782434924389236, 0.06061042891815305, 0.015224921171466121, 0.05449390380817931, 0.01496345512350672, 0.014864824624964967, 0.07821794191841036, 0.02706316274270648, 0.0533905194606632, 0.05060561772552319, 0.05430932425952051, 0.002813076675920456, 0.029162720784370322, 0.047976956630009227, 0.07618281713803299, 0.03251083653594833, 0.025454106798861176, 0.029389201990852598, 0.04023659756057896, 0.040894392732298, 0.03595006390241906, 0.019130850887449924, 0.042054915029439144, 0.04461585143872071, 0.033772372553357854, 0.04075889512023423, 0.027705398788384628, 0.14273718843469396, 0.0723957117588725, 0.0633615926199127, 0.030096611590124667, 0.05348361075448338, 0.06752210218110122, 0.04339985731348861, 0.07001969628618099, 0.07533968542702496, 0.013701631523872493, 0.04534342333499808, 0.08050082527915947, 0.03320867057482246, 0.046064004200161435, 0.020759159997396637, 0.041795460201683454, 0.10036038540420122, 0.07191039912868291, 0.03243246203055605, 0.07657801819732413, 0.03792436225921847, 0.039446054433938116, 0.028501287233666517, 0.05163065725355409, 0.051236101862741634, 0.04515606073255185, 0.058003193626063876, 0.03889078325300943, 0.05973849074507598, 0.03408331758691929, 0.13208290154580027, 0.011875791460624896, 0.02903483389673056, 0.042929910850944, 0.0318016699020518, 0.050568844308145344, 0.05494560085935518, 0.057557797408662736, 0.04712299327366054, 0.0838068853772711, 0.022874182541272603, 0.02255703686387278, 0.027381618310755584, 0.036485619930317625, 0.06050541873264592, 0.0678313996468205, 0.07201552434707992, 0.01599354774953099, 0.06280300032813102, 0.026186278155364562, 0.02294436559168389, 0.025213493245246354, 0.014434444838116178, 0.020895765264867805, 0.04872582074312959, 0.020432323726709, 0.042201563410344534, 0.06667403518804349, 0.04970378955476917, 0.03487130772555247, 0.047799115782254376, 0.06889887517900206, 0.06076124445826281, 0.061523021940956824, 0.029229521496745292, 0.022783605272707064, 0.0536718602234032, 0.04625905174179934, 0.025650647912698332, 0.09013572038384154, 0.04108555142011028, 0.008267132707260316, 0.04682731792854611, 0.00042944334722960775, 0.03315540663606953, 0.022356306326400954, 0.053021753701614216, 0.03639627277152613, 0.011971889380220091, 0.039706874813418835, 0.013221513927419437, 0.03126588751911186, 0.0245830109633971, 0.036119024953222834, 0.05180652027775068, 0.013562103122239932, 0.04787321180629078, 0.08582292211940512, 0.027088516362709925, 0.012433890224201605, 0.07236796285724267, 0.010842735810001614, 0.06631446463870816, 0.03559161770681385, 0.02971424226416275, 0.041722050664247945, 0.020024097975692712, 0.041409840268897824, 0.029836639114364516, 0.0901335162052419, 0.010110567236552015, 0.04411336180055514, 0.07431437872583047, 0.041538105651852675, 0.032580019542365335, 0.020679536828538403, 0.03625953206210397, 0.028361340446281247, 0.05418488464783877, 0.019904500877601095, 0.014701881464134203, 0.05586236104136333, 0.012976402031199541, 0.027367788388801273, 0.02118549971783068, 0.07125053336494602, 0.0180523451854242, 0.017460476847190876, 0.10312510072253644, 0.15366029605502263, 0.020370241218188312, 0.08522788295522332, 0.012440325572242728, 0.02188982383813709, 0.05739474014262669, 0.01679782802966656, 0.012308020122873131, 0.017571735916135367, 0.026287707478331868, 0.015349653003795538, 0.031082057539606467, 0.02511209917429369, 0.0905256076657679, 0.02827657233865466, 0.030245174712035805, 0.008250948321801843, 0.039650976250413805, 0.054548017506022006, 0.032338316887035035, 0.059215514120296575, 0.024627231832710095, 0.057034776255022734, 0.0274528793306672, 0.03439126805460546, 0.10911470002611168, 0.01681288063991815, 0.0767193379579112, 0.015538259631284745, 0.04982534592272714, 0.09335960989119485, 0.008720556179468986, 0.029848081176169217, 0.15011190989753231, 0.13507129275240004, 0.19139813433866948, 0.243231687345542, 0.14164369320496917, 0.2669321733992547, 0.13317311648279428, 0.19205500924726948, 0.09743665010319091, 0.07752315810648724, 0.14038324443390593, 0.18578530114609748, 0.1922072534216568, 0.11867010369314812, 0.09262390405638143, 0.12083951267413795, 0.1891180785605684, 0.13230778713477775, 0.12763604172505438, 0.13598299148725346, 0.16757241828599945, 0.14191968308296055, 0.13259366241982207, 0.07582052290672436, 0.2646954293595627, 0.2145562440273352, 0.10257588917738758, 0.19653792260214686, 0.1679460154264234, 0.13765666808467358, 0.10994456213666126, 0.12340278684860095, 0.20192751777358353, 0.06112504896009341, 0.13615033094538376, 0.15594527969369665, 0.14103823428740725, 0.16929224162595347, 0.1300046208780259, 0.24791149247903377, 0.10940099091385491, 0.12189523258712143, 0.10485788938240148, 0.13560964667703956, 0.11165809206431732, 0.09267099332646467, 0.1417432597372681, 0.20164241432212293, 0.11193272381206043, 0.10781573379063047, 0.22101021255366504, 0.09196295475703664, 0.19565685972338542, 0.20475247321883217, 0.1497335481690243, 0.1985171710839495, 0.07291258792974986, 0.1468755374662578, 0.06271266611292958, 0.20303714729379863, 0.09556086442898959, 0.15862302272580564, 0.13861647283192724, 0.17270901531446725, 0.2096837476710789, 0.14151767652947456, 0.08078034778009169, 0.10539294074987993, 0.19080276862950996, 0.20207093039061874, 0.17559159110533074, 0.1620236918097362, 0.340224570245482, 0.10267138874041848, 0.12127761729061604, 0.15732229017885402, 0.1919032252044417, 0.11552707117516547, 0.12787571089575067, 0.12858291825978085, 0.1175699736631941, 0.11494674879941158, 0.13457763096084818, 0.08415394331677817, 0.1305492385290563, 0.2476912527345121, 0.16434328921604902, 0.12907717376947403, 0.08543561008991674, 0.09976034416467883, 0.14456290140515193, 0.19560253451345488, 0.2501905686222017, 0.25919804465956986, 0.1219732768367976, 0.16278817813144997, 0.14895568834617734, 0.1776625245111063, 0.1751665334450081, 0.0891831293120049, 0.07663799857255071, 0.1890605324297212, 0.11551932315342128, 0.19437528942944482, 0.084107900474919, 0.1525894066435285, 0.1834931632038206, 0.19066043954808265, 0.18387768475804478, 0.13108886894769967, 0.16697052167728543, 0.2557961584534496, 0.08022383350180462, 0.10009924590121955, 0.13962091034045443, 0.08111898976494558, 0.1116737216943875, 0.08911484430427663, 0.24846200278261676, 0.12340654953732155, 0.07633465313119814, 0.07348237922997214, 0.1295068030594848, 0.1606163868564181, 0.17001261468976736, 0.1295670060790144, 0.19751680054469034, 0.1969666316290386, 0.10645201517036185, 0.14315325126517564, 0.16598365822574124, 0.10112222968018614, 0.11649604144622572, 0.14981340325903147, 0.17633369425311685, 0.11272881078184582, 0.1672162616159767, 0.17447790945880115, 0.08883656118996441, 0.11715726534021087, 0.0985786372621078, 0.19580671418225393, 0.17820598441176116, 0.25404287909623235, 0.1231619376630988, 0.11704294491210021, 0.1828257943270728, 0.19038136233575642, 0.16085486859083176, 0.10195141643634997, 0.19698579388204962, 0.10654061275999993, 0.16385730123147368, 0.09238395286956802, 0.2014313475228846, 0.11921697005163878, 0.1755573187256232, 0.08576832231483422, 0.09956588663044386, 0.185342060867697, 0.11329493587254547, 0.12253877110197209, 0.20588761777617037, 0.11944088342715986, 0.058943951153196394, 0.14168333873385563, 0.14044939947780222, 0.07788594215526246, 0.2698062441777438, 0.15718107431894168, 0.20670524187153205, 0.12232256864081137, 0.19554573053028435, 0.17831217090133578, 0.09404827098478563, 0.15036017313832417], [0.00904780434211716, 0.03297577721241396, 0.020454007426451426, 0.016610148159088567, 0.07477370134438388, 0.06554835301358253, 0.13219168555224314, 0.04573726997477934, 0.0393450481351465, 0.03235655516618863, 0.0690546297118999, 0.010108349142683437, 0.05305004808178637, 0.03247002212447114, 0.03763091706787236, 0.018584745230327826, 0.029574649852293078, 0.03042799908143934, 0.021721419398090802, 0.04078626923728734, 0.07462378009222448, 0.04273734208254609, 0.01844246253313031, 0.1316959160612896, 0.028057221315975767, 0.023761670563544612, 0.022265751322265714, 0.026394302149128634, 0.060370307037374005, 0.03278390235209372, 0.02895316982176155, 0.04734086185635533, 0.02649986337928567, 0.045752187143079937, 0.03985341558291111, 0.024601121222076472, 0.11353905792930163, 0.05975379754090682, 0.03992775651568081, 0.03539564619131852, 0.09315478455391712, 0.00903783173271222, 0.03211497867596336, 0.024231147617683746, 0.009795448549994035, 0.06772487176931463, 0.04982478560123127, 0.018510723421059083, 0.008306621457450092, 0.06923692344571464, 0.037610070139635354, 0.018821410558302887, 0.03596885137085337, 0.03419825770833995, 0.009356214013678255, 0.01842388472141465, 0.014274801451392705, 0.027673846379911993, 0.05308540028636344, 0.04465512960450724, 0.03396244028408546, 0.0801450916333124, 0.0541818455531029, 0.016077718428277876, 0.07185340960859321, 0.04395257179567125, 0.04175918402324896, 0.06564661336597055, 0.039664817304583266, 0.06936147809028625, 0.019512374165060464, 0.03892109256412368, 0.021726427039538976, 0.033795393974287435, 0.03799573460128158, 0.03370940132299438, 0.04557305124762934, 0.02571611646999372, 0.03886667087499518, 0.053370247696875595, 0.01874921999842627, 0.059942388397757895, 0.04540510322840419, 0.05124616167449858, 0.048521811768296175, 0.035199463163735345, 0.05179565152502619, 0.03333348497108091, 0.02049407412414439, 0.040808500270941295, 0.024362418698729016, 0.06650849914876744, 0.05783082982816268, 0.08578866458265111, 0.023296317995118443, 0.010892766767938156, 0.011533246706676437, 0.04822128277737647, 0.025170261287712492, 0.029614915074489545, 0.04507049481617287, 0.012978383565496188, 0.05576490962994285, 0.03318329283501953, 0.027818784110422712, 0.019440172472968698, 0.08834124440909363, 0.02922939162090188, 0.024886432474886533, 0.03775229903112631, 0.05325907397491392, 0.03297253402706701, 0.054495261938427575, 0.04992879017663654, 0.047741024172864854, 0.13276846788357943, 0.06645732806646265, 0.05532286420930177, 0.07655404682736844, 0.0900069651834201, 0.03246482337999623, 0.07770287658786401, 0.02923031188402092, 0.006363920037983917, 0.13538627506932244, 0.034453137195669115, 0.04406816871778574, 0.06567169795744121, 0.04687307504354976, 0.046235247355070896, 0.015392157656606287, 0.027235014458710793, 0.01178618733320036, 0.021341256106097717, 0.011256795769440942, 0.0661718386982102, 0.024517664860468358, 0.03916145193215925, 0.056291389191756025, 0.045197402068879455, 0.0032479821720698965, 0.054658608642057516, 0.06064931374567095, 0.0344839919853257, 0.0358271568256896, 0.03500325416098349, 0.037191517403698526, 0.03604485471441876, 0.03219377249479294, 0.07811430099536665, 0.03988947282778099, 0.09035535156726837, 0.004349896835265099, 0.04582759676850401, 0.020137655847065616, 0.011452162434579805, 0.017835599101090338, 0.07295917996088974, 0.04534017643891275, 0.0233065744760097, 0.0749889093276579, 0.010364891040808288, 0.06723669444909319, 0.020320656476542354, 0.04597258644935209, 0.04068992362590507, 0.07144608185626566, 0.024827309280226473, 0.0449669763474958, 0.06280072193476371, 0.014555639409081778, 0.004056819470861228, 0.013363986799959093, 0.07139809458749369, 0.10235349720460363, 0.0034800336607077043, 0.022838197655801196, 0.01630506794754183, 0.035406451861490496, 0.017151459542219527, 0.08357271552085876, 0.06353203425533138, 0.08842011244269088, 0.025819111724558752, 0.020530192596197594, 0.08712281603948213, 0.0570323494321201, 0.021733034009230323, 0.011755636824091198, 0.08468142477795482, 0.007848935274523683, 0.030506868970405776, 0.017108160791394766, 0.026892106980085373, 0.0761303621402476, 0.021874637641303707, 0.0745844907942228, 0.06317033374216408, 0.013423303880699677, 0.026051628447021358, 0.06910583048011176, 0.023972091694304254, 0.022064135773689486, 0.07929406347102486, 0.06147945787233766, 0.06179090014484245, 0.03825594270892907, 0.05097200490126852, 0.04826588214200456, 0.0427024611417437, 0.022617687027377542, 0.042746745093609206, 0.07598529453389347, 0.02101226204104023, 0.021232358922134154, 0.028166582342237234, 0.04189116385532543, 0.0059331195461709285, 0.05429603981610853, 0.022075611232139636, 0.013249245203041937, 0.032094929556478746, 0.006252865523492801, 0.03558638556569349, 0.024557965334679466, 0.04317370265198406, 0.11816389960586093, 0.06228202750207856, 0.017714480600261595, 0.018870149251597468, 0.03351241677592043, 0.05808833651826717, 0.058606485472409986, 0.024863388789526653, 0.047113794353208505, 0.009457667456445051, 0.04133190363063477, 0.07659174050786532, 0.04397617209178861, 0.044292976381257176, 0.02223867591965245, 0.007873585709603503, 0.02384414357948117, 0.07278088640305214, 0.051313700823811814, 0.018809833054547198, 0.08304616174427792, 0.056365615091635846, 0.012869617185060633, 0.025733517977641895, 0.04633180447854102, 0.07612354180309922, 0.009472369401919423, 0.035041177907260135, 0.056895530797191896, 0.07006964282481931, 0.004421749717948842, 0.0595902244822355, 0.02335124805540545, 0.04516830245847814, 0.011598695782595314, 0.01655542218941264, 0.0751731771742925, 0.024178308558475692, 0.04517764609772712, 0.004874272408414981, 0.015294016047846526, 0.05696245396393351, 0.03650662642030511, 0.00837865245557623, 0.09463604452321306, 0.032679125943104737, 0.06710214307531714, 0.023505028475483414, 0.016906576784094796, 0.025044550748134498, 0.04349594688392244, 0.021873442783544306, 0.028531201351142954, 0.06254797612200491, 0.02662411188794067, 0.025191187996824738, 0.014656957409897586, 0.013074755152047146, 0.005575537952609011, 0.023327235867327545, 0.06800386734539643, 0.031759560442878865, 0.027458135591587052, 0.04170469554082956, 0.03646040917374194, 0.08061372078373097, 0.11689945065882057, 0.044689817586913705, 0.01621208055439638, 0.07851857109926641, 0.09353613713756204, 0.0222055557242129, 0.09251173585653305, 0.02590071271697525, 0.008155304967658594, 0.033361886962666176, 0.055406470855814405, 0.06369661292410456, 0.06489811290521175, 0.046515975845977664, 0.03648377569334116, 0.031020301576063503, 0.07423188901157118, 0.005693780631190748, 0.054325328674167395, 0.02974259972688742, 0.029360317603277508, 0.07701095746597275, 0.012910940895380918, 0.015972277797118295, 0.1070266823808197, 0.0447216445900267, 0.036054636220796965, 0.07592779293190688, 0.058740350359585136, 0.038700771183357574, 0.012909297038277145, 0.020097893429920077, 0.020114897888561245, 0.0530718857771717, 0.052007720223627985, 0.049126424637506716, 0.041441010471316986, 0.06796657442464493, 0.05031987231632229, 0.039797268400434405, 0.00296374332265259, 0.07244902022648603, 0.028165298426756635, 0.010630472297634697, 0.029146714514354244, 0.02054978715023026, 0.0460975418536691, 0.008797691298241261, 0.04452965469681658, 0.02956130418169778, 0.0363353276043199, 0.0730274204397574, 0.04299983600503765, 0.07941711155581288, 0.04187596096016932, 0.02256240444694413, 0.01056603903634823, 0.008793959223112324, 0.019867111477651633, 0.008217003414756618, 0.2208394295303151, 0.09853119918261655, 0.13088090432574973, 0.16944996285019442, 0.23247672070283443, 0.18874448142014444, 0.30311475216876715, 0.11362007819116116, 0.09601125901099294, 0.12334034996456467, 0.12320444788201712, 0.12415090881404467, 0.11634590497124009, 0.21559400396654382, 0.12320071487920359, 0.15337069518864155, 0.07243827392812818, 0.18356823886279017, 0.12029458332108334, 0.1347230770625174, 0.16925716772675514, 0.12115125922719017, 0.11725407108315267, 0.2652716328157112, 0.2278048120206222, 0.10613770078634843, 0.09683263837359846, 0.18030176492175087, 0.15703117533121258, 0.12331607431406155, 0.08034693353693001, 0.19318914448376745, 0.10419846890727058, 0.12757851043716073, 0.20588105719070882, 0.10693070784327574, 0.2716332336422056, 0.1590034773107618, 0.0921454414492473, 0.12797121045878157, 0.17112061148509383, 0.1056875882204622, 0.19955868629040197, 0.09809967741603032, 0.08835577566060238, 0.12101564658223651, 0.0683023665624205, 0.119532212120248, 0.09476425053435378, 0.1775064508547075, 0.19357403711182997, 0.15820681146578863, 0.058418039334355853, 0.13361120625631884, 0.15712400316260755, 0.14031827682629228, 0.15381791337858886, 0.1290049628005363, 0.13522966706659645, 0.17796811123844236, 0.16974584228591993, 0.2014053426682949, 0.12977424339624122, 0.27113020594697446, 0.15826211631065235, 0.10860210604732856, 0.04809448684682138, 0.1851044548675418, 0.09768908421392553, 0.11956118556554429, 0.17116226081270725, 0.18092623766278848, 0.19361820974154398, 0.14812192996032536, 0.07327594343223609, 0.1735761109739542, 0.1770732444128953, 0.09712076236610301, 0.0758553296327591, 0.2199927280889824, 0.0754264128045179, 0.12675042205955833, 0.06922147193108685, 0.1593190830317326, 0.08278149703983217, 0.20543017279123887, 0.2271149115404114, 0.1987230873783119, 0.17255083395866677, 0.12424660875694826, 0.12228378400322981, 0.25870291341561824, 0.1591514318715781, 0.19200736336642876, 0.22994013415882364, 0.08934667639550753, 0.1618362995213829, 0.32240073604043573, 0.10087946575367823, 0.09264999054721557, 0.15437105088494718, 0.13551278156228364, 0.0932127759733703, 0.16256142233032733, 0.12043193259160034, 0.23535166721558198, 0.17323545034741983, 0.16411148681072518, 0.07475722566596232, 0.12270978419110179, 0.16932482190895826, 0.17743511562002823, 0.13911311805713922, 0.1290223142132163, 0.14872557803755626, 0.19143179815728217, 0.16152516152942553, 0.1436545720207505, 0.2010213109315373, 0.22581354074645787, 0.10602070862660185, 0.24652427004184574, 0.2389530575601384, 0.1127272225858178, 0.2415504853706807, 0.15136051399167627, 0.17011256713885814, 0.17186792450957, 0.1865051843924448, 0.12846488709328696, 0.14159766520606354, 0.1341700434568338, 0.19512750062858686, 0.1423353748396039, 0.12972999655175954, 0.25802527321502566, 0.06977339231525548, 0.14188639033818617, 0.09343509373138659, 0.13796335319057107, 0.12327764590736479, 0.2006044762674719, 0.08756407478358597, 0.1883068517781794, 0.12627663498278707, 0.0908861133211758, 0.07498581457184628, 0.08568103090510704, 0.09455095729208551, 0.17231199599336833, 0.2203985641244799, 0.14162678708089516, 0.1338441960979253, 0.1380429114215076, 0.10098010097863153, 0.2036908606532961, 0.0777866056887433, 0.22575918585062027, 0.16283643257338554, 0.19294828787678853, 0.18822195008397102, 0.11300137935904786, 0.27289987192489207, 0.11758708758861758, 0.13345326238777488, 0.16469564608996734, 0.11571219249162823, 0.19169506762409583, 0.1035297047928907, 0.1654587223310955, 0.11627601692453027, 0.06743810590705834, 0.11846221328596584, 0.16964100650511682, 0.17619041522266343, 0.0542258660425432], [0.07208302267827094, 0.02056762281426927, 0.04138139745919034, 0.010586199477984337, 0.02625934259413043, 0.05890612017537933, 0.022929541191842873, 0.028367147751851007, 0.017111921624746174, 0.054486059307237156, 0.009588388420525007, 0.06049183743016329, 0.06921226187841967, 0.06275870895478874, 0.005705643861801946, 0.056781243765726686, 0.05892672219488304, 0.017635575459280517, 0.04557103260594886, 0.025663023225206416, 0.02072136427159421, 0.030055006791371852, 0.02999796903168317, 0.0367518060375005, 0.009354455123684602, 0.04799750298843719, 0.046680951563757844, 0.04296174898627214, 0.012312916442169808, 0.04117390781175345, 0.046783705620327964, 0.015406638813146856, 0.06952534429728985, 0.05483084998559207, 0.06231339808437042, 0.03341834213642869, 0.03629215687396936, 0.05132307043822948, 0.05130914774781559, 0.07928998908028007, 0.03684662653540727, 0.07762237582937814, 0.02981180870847311, 0.05830910689837765, 0.07459853222826496, 0.13484069262631238, 0.016995927653624676, 0.029788967258355115, 0.02991979861690197, 0.03090651734964922, 0.041236340985051356, 0.03586898797948379, 0.03356359899044037, 0.07588282620417885, 0.030087694685789756, 0.018180185688834172, 0.048044948489405215, 0.012297081793803954, 0.0625027422211133, 0.050798635493265465, 0.05278037759126164, 0.07912998204119503, 0.029810817941324785, 0.02249303404823877, 0.07423461269354448, 0.027604936112766154, 0.029727270666626282, 0.036291277428972535, 0.09894623042782769, 0.045092603395460173, 0.028792674820579123, 0.026694417392718606, 0.012827475256926846, 0.024862700447556563, 0.01572363977174973, 0.03671737409604248, 0.08370625015231781, 0.05401261732913554, 0.055501718088635243, 0.038414843947975896, 0.050439525075489655, 0.03788774098211434, 0.036641574843088165, 0.035784208739642054, 0.030856682133162394, 0.00654065369417367, 0.039040511546772905, 0.012186374697193969, 0.0390195087675238, 0.034400979056954384, 0.004011311903013848, 0.015982664153852966, 0.03825010571745224, 0.015952989379002247, 0.055392485082848, 0.02142945108062122, 0.027712673690984957, 0.044457295298343524, 0.015446485649590613, 0.04688185465056449, 0.017325326189165935, 0.05150648481503595, 0.0054877650745766005, 0.018884789969888516, 0.06599109605303966, 0.03097423646977404, 0.06568631826667115, 0.01170460674984497, 0.020559021322696935, 0.053736634872620925, 0.05502043532032985, 0.08039701366215013, 0.029088995834172238, 0.03131344434223138, 0.015877086225373205, 0.019710572123585735, 0.05235450356849469, 0.0223785169509938, 0.00636791418401117, 0.06888997682835907, 0.017707892184262164, 0.027953550707024988, 0.08449404733255506, 0.059902360662817955, 0.03657924557046499, 0.011536765414348338, 0.026924895064439625, 0.04631977797544096, 0.03237789191189222, 0.018695464386837557, 0.058966824144590646, 0.09634941117838025, 0.029783276841044426, 0.07780203493894078, 0.08457062955130823, 0.061135086507420056, 0.10286879260092974, 0.0510086595750181, 0.05448991847515572, 0.0246564668850624, 0.10736417403677478, 0.02562306970503414, 0.11712898951373063, 0.07290534456842579, 0.048182668833760545, 0.07107139375875704, 0.0475844532775227, 0.016163993095688056, 0.09165382798528299, 0.010089515290019335, 0.035174950025975704, 0.013460375084832776, 0.01652009039389668, 0.03390021491213702, 0.07217167221824639, 0.11952109474805184, 0.015355733976321062, 0.026977040215570014, 0.03036451576917898, 0.013129661092534661, 0.010750843084679218, 0.012221678662172053, 0.037727125381934457, 0.05201617328566499, 0.05503130036231596, 0.049167220495291986, 0.014182893883116776, 0.04591931137838401, 0.07369172424660064, 0.004134484761380008, 0.03672150043712463, 0.023686173735768534, 0.08326296534505673, 0.09485781309194863, 0.014049523451831192, 0.022805018088547513, 0.03526001499267295, 0.0412910632439889, 0.08776728966040537, 0.06198241506353952, 0.0771914106735494, 0.08586781463236548, 0.04079934587934986, 0.04578177657094784, 0.045755697501590475, 0.03850333021546248, 0.12676712038228288, 0.03813719536992721, 0.0492008138098754, 0.07419088535243645, 0.039342543386737816, 0.051827174247591756, 0.0033147986550829955, 0.04999192096875049, 0.042956680117640644, 0.07695303283981048, 0.005137202806508867, 0.017589024246262852, 0.07074173176079057, 0.04055859688378405, 0.0370257104805205, 0.055572708224644884, 0.015346292002504924, 0.0875134083617013, 0.01832278194342507, 0.011657973900582874, 0.012624328101082938, 0.02524536663258914, 0.03080960399529431, 0.030781469176872633, 0.022573586757062003, 0.031803870369913056, 0.04955403528583702, 0.02535823245125357, 0.0031220710206980584, 0.034290458424948156, 0.0524491385294823, 0.06422465841751546, 0.03701891240780242, 0.04887717434030492, 0.04324776527937502, 0.033521133300382644, 0.09064658515853807, 0.0051442453241179464, 0.05573314570938237, 0.011599498229770688, 0.06402214858098887, 0.04502187301113736, 0.007943029395391932, 0.006858771121187601, 0.06927255395567045, 0.06110907794209197, 0.0326680456782924, 0.04115940253541339, 0.07269105684827082, 0.01606709643965587, 0.07662538948352449, 0.04097902354260441, 0.04603341658366844, 0.015982491604518145, 0.03529221678036265, 0.01792698345525423, 0.016514633753104135, 0.05567603002418764, 0.08742938982322812, 0.046791416534688324, 0.005264952396828448, 0.009988194506149739, 0.04257766900991555, 0.07651492822333239, 0.03178697908879258, 0.08199154763133265, 0.052720994644914754, 0.041556147261871956, 0.050125926863984205, 0.019111673791485373, 0.02647649871505564, 0.018165491164836567, 0.003679380556604883, 0.02667115106305573, 0.024024459489737637, 0.08778493793215603, 0.0845295590988826, 0.027523910284799058, 0.01980105291295331, 0.06862120804726146, 0.05430206976598129, 0.021573377634922508, 0.02717510644288268, 0.008133836490742397, 0.046465665654977784, 0.03415319079067558, 0.013703178901778301, 0.07792520918883383, 0.017648216089583002, 0.08042316694627516, 0.03227122673706617, 0.02310442829184467, 0.0308796534591238, 0.034198536013718694, 0.07554198746220209, 0.014256333106459351, 0.09035610855789855, 0.08461459437967278, 0.019860517495544627, 0.012388815885060467, 0.03202150146535132, 0.03395021711185109, 0.07582137637655251, 0.03531140129780397, 0.033363170878146775, 0.10977741563692689, 0.02418596195639111, 0.037920224785921164, 0.020669085533882026, 0.014231867280614097, 0.021512220955628436, 0.026192296973022167, 0.039484634980908595, 0.02543964048527414, 0.0404259491187986, 0.025238444250135217, 0.026754069367598277, 0.00708758220753225, 0.0671769144537393, 0.12274945940589532, 0.08563225695979781, 0.07012427973677404, 0.014690845728182467, 0.04454143258044496, 0.045630025924765505, 0.024872201793186832, 0.08203282588510774, 0.014141465344437165, 0.08002821079571731, 0.028290437512623612, 0.08425265637924895, 0.010125858261744725, 0.061101541432435624, 0.0414336594985798, 0.05557256350584794, 0.04695072966569569, 0.026759611355373636, 0.037466805952135473, 0.05196224512474146, 0.06619644089369103, 0.030226376111386344, 0.053359230514615774, 0.016476361197419465, 0.021205895791354124, 0.027725351428671274, 0.05087718440336175, 0.014158382600726327, 0.05152263765921816, 0.01734554229187779, 0.007255586815517745, 0.05293644753692206, 0.07231452822452411, 0.02003630444960436, 0.013799537500744918, 0.02105708404997131, 0.029274877852003556, 0.027007987773686182, 0.03792418785451446, 0.018415090271446388, 0.030929748427297454, 0.0062961067578726215, 0.036007665694341995, 0.02580171021691058, 0.028436319626052864, 0.04317495317081921, 0.02438903396978276, 0.18163313332479447, 0.11521510939928703, 0.1586678929743357, 0.08470030501484871, 0.1463533178321086, 0.1560923139913939, 0.09537761332467198, 0.08029969583731145, 0.23483305441914126, 0.18820980854798108, 0.1857967153773643, 0.16267375380266458, 0.1646367640933022, 0.17403471370926127, 0.10162920560105704, 0.15174880565609783, 0.09549568159854971, 0.12707338988548145, 0.11968479768256657, 0.14493608294287696, 0.07962120958836749, 0.10458361386554316, 0.1179160964966286, 0.09893771057249978, 0.13979734852910042, 0.1563953625736758, 0.14299763774033636, 0.18453585100360215, 0.1153389664250426, 0.0874423180357553, 0.08800065057585016, 0.07646128578926437, 0.16602561925537884, 0.1467359988600947, 0.12253583961864933, 0.15226531075313687, 0.07992506711161695, 0.11063775775255635, 0.08051764234551229, 0.19638401601696387, 0.15043713385239244, 0.2425890023005195, 0.20742889522807673, 0.16745063185226172, 0.17616381664993241, 0.23360643273917958, 0.11708014877513051, 0.07578318545711227, 0.09203990804962814, 0.08855330568621866, 0.26343267993070185, 0.18827747757313773, 0.10331607016269118, 0.21064665459562093, 0.14738855446921661, 0.18404250091407448, 0.14004694763571024, 0.0625186538673006, 0.2024215951678343, 0.1122910252888687, 0.19554907019482926, 0.20518214703770354, 0.11360359509126283, 0.14500799705274403, 0.10561093920841813, 0.17477429355494678, 0.08397872967179865, 0.1823729506577365, 0.2571025461656973, 0.11412802632548846, 0.13313176401425153, 0.07703938172198832, 0.13956193928606808, 0.22073088301112875, 0.12045531024341471, 0.18869701365474612, 0.2326263376744464, 0.1866594620514661, 0.16139184212079272, 0.13610191323095933, 0.13722148753004149, 0.10592658945824951, 0.11462022608611733, 0.11522011147462763, 0.10097553677042015, 0.219023794925306, 0.21236346481600776, 0.21959006844554096, 0.09349614279926755, 0.2609650982776657, 0.08126151180476882, 0.11989590158918872, 0.10426750348415226, 0.1115410182683263, 0.26052919041831046, 0.08401957747992128, 0.069765176740475, 0.2103457582416013, 0.12380798463709652, 0.1307508206809871, 0.1479641642072238, 0.1646455065929331, 0.12922450492624193, 0.13906437379773706, 0.1055055542383343, 0.09208819217747077, 0.21463856304762885, 0.12147275017923675, 0.17730716936057433, 0.25460881122853607, 0.11846366789541207, 0.10172846785280854, 0.10051147182821296, 0.07896209339378402, 0.13783922157017514, 0.1512083291891031, 0.09696433247881941, 0.13778829539660364, 0.09475832819589414, 0.1171549572609365, 0.12403704109601676, 0.12785414408426732, 0.1682859635911882, 0.12637870997423306, 0.11744337069103494, 0.11877780416398309, 0.10732500348240137, 0.1667328117764555, 0.13674905116204172, 0.1809269649675116, 0.21648784662829712, 0.19718758383532986, 0.10340623368392698, 0.1752869988558814, 0.17065406776964664, 0.14686391543364152, 0.2803046948974952, 0.13147986202966422, 0.13295612734509632, 0.11234672347200103, 0.23888690251624212, 0.2034450910286978, 0.25159966957289726, 0.17894369404530153, 0.17811358702601865, 0.13053072936600074, 0.21840425004484132, 0.15583327476633713, 0.24661577685037628, 0.21649822185281664, 0.07834115327568725, 0.18735163350356743, 0.10497761264559813, 0.22097542067058384, 0.10677148005925119, 0.16066133131971583, 0.13805027352645993, 0.1875666930573061, 0.08323363566887565, 0.08164827464497648, 0.1225185178918764, 0.10692169817048125, 0.11842772568343207, 0.11054382412112318, 0.1634993337211199, 0.08152383874403313, 0.10916873579844832, 0.10744233703007922, 0.13816043792758137, 0.09311790723586455, 0.08993816067231819, 0.10299906178261153, 0.19524876755895093, 0.15281090803910047, 0.1714691982488148, 0.1328319957247004], [0.057877659346559085, 0.0561498393653892, 0.05552200469537638, 0.06844533389084972, 0.029484790611604694, 0.04206361300020944, 0.025946505083993543, 0.02476972047588788, 0.03590710839489475, 0.038893737000762485, 0.03473431468592025, 0.010297776771039935, 0.029342225898290053, 0.031173586612567306, 0.04522750728938263, 0.07205550384242088, 0.00908676338440273, 0.05882210905838292, 0.031601056252839044, 0.09013359784148633, 0.04886127382633276, 0.06587131341802888, 0.02266925515868934, 0.02199908281909302, 0.04178026101726573, 0.049500292661832646, 0.11045610226574354, 0.04042722190206405, 0.03255313524277881, 0.024756335842539556, 0.025118336925515905, 0.02758151949819876, 0.013828330975229619, 0.03750700067030266, 0.029279980117280502, 0.02542600908782333, 0.03153913145069964, 0.013286046450957656, 0.014232528719730908, 0.0098630470711214, 0.04075883945915848, 0.018358772395004053, 0.021918218408245593, 0.03430628843489103, 0.03525016669300385, 0.07486672213417478, 0.06902584180352278, 0.042417320582899265, 0.011682507447403623, 0.0292090474977158, 0.08149511020747013, 0.028886055551993195, 0.015642532307538204, 0.04729531254270114, 0.03365279400895815, 0.03289402593509294, 0.00781282979005482, 0.05021505508921109, 0.04795983528310899, 0.04391539019707125, 0.03646412733360194, 0.048005714852479286, 0.024947266319941264, 0.005074688460808829, 0.015269014020304894, 0.0316950158594409, 0.06916622645803727, 0.03871770699333865, 0.09176033359835856, 0.0787197970203124, 0.020017665410705376, 0.018055644031846896, 0.026266543281963095, 0.03188654191035312, 0.059113517054356635, 0.04320750376791693, 0.04671647446230054, 0.027071408003394026, 0.06494981833384372, 0.018917941706604324, 0.033790896559366956, 0.02965703566587763, 0.016881377159734257, 0.07100860064383596, 0.04942407409544103, 0.03613313689129427, 0.06827674020314589, 0.025958728256227914, 0.08775471767876297, 0.02751986001385376, 0.011358059036865598, 0.0022390354206436314, 0.008007701999304118, 0.026631195687514264, 0.03659627043816727, 0.09923359742970206, 0.0639477111690212, 0.023358458020084072, 0.058508147194515914, 0.03411497760680504, 0.043855610201717354, 0.036843479829258285, 0.025321293906017672, 0.04333120865339879, 0.019894450342690106, 0.04850576282478869, 0.05091327504487708, 0.05648703045153525, 0.022513522890221793, 0.04870010903687216, 0.038569915705011226, 0.03967301432567183, 0.03767617694393266, 0.06775975271011703, 0.03482281208562199, 0.02819698998791864, 0.04368493850051891, 0.0332449801499024, 0.04265850002411753, 0.02953897295810748, 0.013501126413757447, 0.025662025036581326, 0.03146196293528192, 0.04276235988072585, 0.061760813478031196, 0.028888560300401878, 0.038494543186970986, 0.03944868534745183, 0.031124218949116766, 0.03037983740796335, 0.047957182105164975, 0.03750919371668715, 0.04500530456425622, 0.10389193223090842, 0.017808798293117434, 0.02701256311411271, 0.05850046596606262, 0.038921278101042844, 0.009410260918230051, 0.031891061589703895, 0.02086481956212083, 0.05502846164745279, 0.0970828311983496, 0.0527584322844632, 0.015871792857069522, 0.047792540353839286, 0.0438563078205334, 0.03879216295899823, 0.018788368288369384, 0.04608679184457287, 0.014116248094069306, 0.04042863569338806, 0.03221748040232342, 0.00791793645475991, 0.04909505405521486, 0.050439398910384625, 0.058095720887649804, 0.06792119951569475, 0.03242197177314665, 0.01726693215459818, 0.04358212878287304, 0.03576813753170427, 0.05882509249204304, 0.012920946901431307, 0.027743587852455676, 0.02723586978390813, 0.02984178590850206, 0.02451031017699279, 0.05724009883124381, 0.1032199471956119, 0.02593533390609082, 0.0027517680882738205, 0.03684298259031493, 0.05716766150726471, 0.025109549897024408, 0.01960349691216834, 0.04752760105475318, 0.05419695567979943, 0.03872036388202105, 0.012841685529565439, 0.04360166582046077, 0.03762404106964823, 0.04775655732373707, 0.052212653172318824, 0.07986712764250115, 0.01984030139283277, 0.07463103087502532, 0.029340509681787807, 0.02357990189921111, 0.02785600838251412, 0.057896305806934834, 0.026732250225904863, 0.0022856153918837663, 0.03630791266914457, 0.052044961194042116, 0.028868199478893075, 0.05502265805262141, 0.05340467963833362, 0.054702733032172546, 0.03474113873380702, 0.09534382334095426, 0.03451392651186325, 0.03262181729951408, 0.027456890638859477, 0.03321188036352396, 0.034749465630738996, 0.0039712985471851425, 0.015535957118117949, 0.029753186463494785, 0.04686500789830461, 0.02694681996217696, 0.05630979074339848, 0.07084004406351596, 0.027685151144396514, 0.05513268515642267, 0.033347760181641206, 0.03841481055133045, 0.018593179738672916, 0.03254838920838665, 0.031606462798663415, 0.003779336948355194, 0.0439207781892037, 0.026141125890717376, 0.02927109660959104, 0.04982059988833498, 0.018218291261291597, 0.12147175570135005, 0.01574342357343994, 0.03717407693329733, 0.023789285878592636, 0.08981341306935064, 0.03971824451582506, 0.04140602934057824, 0.04422840582265053, 0.017877862555906177, 0.024865333216439467, 0.04188686310953926, 0.0195475556756719, 0.02927828059910098, 0.05803650863526855, 0.02666474632860627, 0.051608455905807205, 0.017566937931405846, 0.062221817061072215, 0.03858926720567979, 0.038110711830086075, 0.06019638472935185, 0.02562106219556881, 0.013946787948952988, 0.04988620203221217, 0.04549602745100856, 0.048155895856325515, 0.04212120737065561, 0.028846621535194572, 0.03324720288219396, 0.06696434109471738, 0.07300819139345549, 0.012754719737131381, 0.054529931367142126, 0.024134900340868626, 0.10554842068813741, 0.03470923380518798, 0.02894849985750625, 0.051620745871332474, 0.12495451373979449, 0.01451602727684076, 0.028650779895542655, 0.04038633698655758, 0.011105726043751929, 0.08030717668589205, 0.03707237672642805, 0.01265986027647159, 0.03796439370489679, 0.09869631961919367, 0.03375858344952576, 0.04680982921854593, 0.04851825688092504, 0.053773081745021045, 0.013898604938731296, 0.007806926005287096, 0.03147272036585491, 0.0593019112420734, 0.025139015015156474, 0.027036783103540074, 0.06822515351814218, 0.06507718571810983, 0.025873704107652884, 0.03896509821061045, 0.10185553095652722, 0.04923402491840534, 0.0229371927343891, 0.023228374375321437, 0.05068571772426367, 0.058333671986474656, 0.028739794943248853, 0.04536320899205748, 0.07740981731330976, 0.024131364007189404, 0.012974318451597355, 0.02961159210826736, 0.11711442115483806, 0.023063797561917454, 0.05631923828332219, 0.015253452111210208, 0.04704671533545479, 0.028900545985379722, 0.10274832719005644, 0.05068758793640882, 0.019861677101289388, 0.047502798479399644, 0.019492427090881392, 0.009388546604895964, 0.0422480700945016, 0.047122366158873774, 0.0835082154662814, 0.012842250489484286, 0.042117470657103695, 0.052104288479313254, 0.05719669432437513, 0.04381014623504598, 0.039837240474298596, 0.05012770059693139, 0.04871221346547827, 0.026551027040113695, 0.056721764340181835, 0.011233020140934968, 0.02215685413830215, 0.012972495551366592, 0.004876028515354847, 0.04195907407847699, 0.019936162752856035, 0.01980210861802334, 0.03473969154583756, 0.018245843493787106, 0.0775583581707906, 0.0035774920297626522, 0.021774512642878108, 0.03881463890138548, 0.11496289793285541, 0.009957644924725173, 0.02289056730660377, 0.009889690172713017, 0.04674194125982467, 0.018313985638087615, 0.0007596206160087604, 0.015177830973698292, 0.017225258707185276, 0.04910357019980438, 0.060702896807924844, 0.07233616182929836, 0.011714423508237815, 0.0114055537051172, 0.1588939956855029, 0.31186179374344647, 0.1560624351259321, 0.14080580847803503, 0.125875044032, 0.14501624973490834, 0.13994230481330305, 0.1156538596842438, 0.1812183766742237, 0.12867865531006828, 0.1460334224975668, 0.12632119352929294, 0.09716162501717918, 0.13000229053432122, 0.25370202551130205, 0.11822244021459483, 0.09340793854789808, 0.15048734756419435, 0.13892346963984892, 0.14018169196788222, 0.19389712368138134, 0.13743362302193418, 0.06034910387825221, 0.20459798775846139, 0.14595778280636296, 0.22205057000974193, 0.15630597830750048, 0.08092148200375959, 0.13619655190268531, 0.14453281473834068, 0.06699856152408756, 0.09985307551687583, 0.12295603621168993, 0.14191056950949132, 0.10080251246108674, 0.1656122726853937, 0.13777052838122472, 0.10111250754562207, 0.09519663319224492, 0.1068666679202579, 0.10927089242613874, 0.07146037562051788, 0.10082021268317476, 0.06794923785491847, 0.16041004011640325, 0.1527971783070825, 0.10824298820807599, 0.1681867681327276, 0.10483109042979777, 0.12342514033662155, 0.19915031210985035, 0.11027763059246354, 0.12805548874894157, 0.1827454345766455, 0.17197019245941192, 0.12593100196681917, 0.10656492551788688, 0.15807126561412588, 0.0851096365659032, 0.15781345835421234, 0.107629840640584, 0.12193849979666993, 0.09641648648539558, 0.2864866069285199, 0.12018323148367926, 0.12480081495596096, 0.13542207627324387, 0.13042172271525487, 0.17969363427255303, 0.1736976153915748, 0.22733482473995537, 0.1323776232311502, 0.08673138509038836, 0.12736634525936097, 0.1352298748679459, 0.0925742914841976, 0.13079632917651907, 0.15423079981701449, 0.15013107215054333, 0.08937639940995723, 0.1125188052537851, 0.15794780192663893, 0.1046314081759192, 0.15134230168769136, 0.18823624384822324, 0.12363958390778862, 0.16779933735961094, 0.21763603814179078, 0.3511244634864852, 0.14984837325755507, 0.16286779573420063, 0.09174382823402993, 0.1883344299858436, 0.12414370256010443, 0.1268743013497442, 0.19990682776551694, 0.15235580824082717, 0.27606186631601304, 0.11597826727665961, 0.14710720628499985, 0.15649966400815174, 0.16541661287192255, 0.11942268596612848, 0.10128429988981225, 0.08966099820099771, 0.15979499265085906, 0.17899450147524476, 0.25667613779660314, 0.14139019040158018, 0.1385472749825567, 0.09741512039909139, 0.19822794129140675, 0.15200138819636777, 0.11459660352556966, 0.16513857466634363, 0.13890599948354065, 0.18879261711845174, 0.18355079839238897, 0.12251654377905652, 0.1330544173833914, 0.1516655960585922, 0.10202859979472123, 0.1407760038273409, 0.215354542597197, 0.14716133853653446, 0.1176407300226856, 0.09787528906599618, 0.14169469359330833, 0.13170424295822158, 0.18880320014432073, 0.2499298966722563, 0.16258760530035943, 0.13315082236658782, 0.18675358121981844, 0.1359541664714925, 0.14781839156057686, 0.10162561360630207, 0.10129267873708159, 0.13827008282532915, 0.1558389447745867, 0.1732047848054208, 0.13557682890677825, 0.20027135586133227, 0.1692661180277355, 0.11208709795027971, 0.18461787316482514, 0.11841848594485782, 0.10898825290496461, 0.16266976104816422, 0.13248625880805776, 0.09398777110618539, 0.1663044886663556, 0.11925028506084345, 0.1631605433067307, 0.13323018763912842, 0.1841083145700395, 0.24179334577638656, 0.1706239811028354, 0.12457805190933868, 0.0794587831478566, 0.12952966120792553, 0.09715510896057822, 0.24200959276640788, 0.1453644802677445, 0.11265802473644726, 0.1098477489722427, 0.15986546699423343, 0.12724639935186133, 0.1168053166475147, 0.1933860214194283, 0.11178773042047396, 0.09454733561142348, 0.1712361490353942, 0.19502365932567045, 0.09511230295174755, 0.0918986031319946], [0.09370338753797114, 0.005015106526116142, 0.03518112098390702, 0.03673222447105218, 0.032971205582725815, 0.04123054110095836, 0.01460808049159823, 0.028238247832632624, 0.024644295663165394, 0.07363310942309909, 0.015171814939094475, 0.04896230238955468, 0.0045777718878525775, 0.04246770869940519, 0.043569415793172084, 0.020224626277922653, 0.006436654684875975, 0.03929960272216704, 0.03203037384082563, 0.04346213463577442, 0.040626803966006264, 0.06388327790773474, 0.0489782548538642, 0.09497884253505617, 0.021134770213393494, 0.012184162169432966, 0.03896552123478614, 0.07690063721383922, 0.024922816264734138, 0.01446378935725079, 0.08434540257439949, 0.03154654179525096, 0.06814291613409296, 0.052380716224433854, 0.025484195321041625, 0.04835744832234923, 0.025678665842860937, 0.0066125293051300105, 0.05029963023844175, 0.05043910947279073, 0.043374019442126155, 0.0690030207624659, 0.07104105476173572, 0.07052810455206782, 0.032991217594826594, 0.06279672175878659, 0.0031115547881199745, 0.009922929111780832, 0.07396767701720819, 0.037883477343712, 0.04197543101327028, 0.007972742205311079, 0.04174768073426094, 0.0797636945208069, 0.03303393932583276, 0.024987216129375156, 0.033252602006541565, 0.015020276732684579, 0.07530656337621622, 0.026328980165999383, 0.06294633873039857, 0.022257455966609996, 0.05162108354852535, 0.031051163787196856, 0.03427175630349666, 0.0857382504909765, 0.042242956697009504, 0.05918990631471388, 0.0212244476279011, 0.007178727682912722, 0.07085903562256135, 0.1607568160397932, 0.039091901562642306, 0.050410102630848996, 0.028930257867614273, 0.04366539404145442, 0.031797673436813056, 0.03109724373643985, 0.01129555999796139, 0.03280320932390168, 0.04856218831264414, 0.026137441127502825, 0.037121874265722, 0.019621312167146243, 0.05252875613223296, 0.039903466022224165, 0.034532561840023845, 0.08006445728824474, 0.03482773623545654, 0.06579096108907834, 0.07738538581179455, 0.022069939368520863, 0.023870048244134523, 0.016540178476134315, 0.01590236006450141, 0.03545354484231211, 0.053488160119741224, 0.05472866367199458, 0.03393040176888462, 0.006535102429552353, 0.017095547991630156, 0.015224180879158666, 0.01086477759599802, 0.03347041492816061, 0.03855220435070805, 0.006199362242114148, 0.028488077005022205, 0.027243096446909476, 0.044520663577714004, 0.015239089698297903, 0.04971056907379534, 0.016276593596558087, 0.027052095465478487, 0.07056837348500267, 0.01693776182946749, 0.07941585732623935, 0.04374315256427508, 0.03139592663501389, 0.04556855754344724, 0.025921591186488513, 0.10408949194243178, 0.037833549358765595, 0.05334210174623877, 0.02063858697511023, 0.03940649425203446, 0.010839513033715775, 0.03499185106193181, 0.03169602889101952, 0.029206297840573825, 0.04776896232215222, 0.11557234218344092, 0.05164984177099541, 0.02611691703350516, 0.04372230563603807, 0.011445015552453697, 0.022840928759251256, 0.03570019020116888, 0.07280237157829106, 0.02132521829480538, 0.043119533293065615, 0.09714532003272325, 0.08219455470680259, 0.061526235440396704, 0.012569996397360228, 0.03583486031857319, 0.02769815913779894, 0.06598765990929678, 0.07486683345632628, 0.02604272638563998, 0.08053796234889887, 0.015097811683517648, 0.04090828944754321, 0.04094579016964417, 0.050473044175305404, 0.027695609860529657, 0.031885150383459404, 0.013067701966065215, 0.008428099899902008, 0.04709087312221527, 0.05004802733310498, 0.019204136115149595, 0.051234164857305586, 0.01691017434495734, 0.01144360732723726, 0.044637280952883884, 0.060801071813330054, 0.060012940666638315, 0.032193494189414196, 0.02348198107938515, 0.055433451634598896, 0.07252483061165549, 0.010907556843449129, 0.04164876358117908, 0.04724761842226144, 0.03281983714259695, 0.09417868859600276, 0.02808376793836942, 0.00961486639425857, 0.014484999937849352, 0.10832636849954724, 0.020538810786092654, 0.043084874996566214, 0.03582467063097283, 0.017815629762480967, 0.02896421297919005, 0.045445186624419875, 0.029219131429272238, 0.004251172176736873, 0.018020863280980848, 0.03059725699131377, 0.03223077226721216, 0.014624447630922077, 0.015185527972789714, 0.0936590887431521, 0.09016462703584693, 0.008752765388635453, 0.06011793600919191, 0.08599858105299063, 0.0673342274967581, 0.06598481748369522, 0.00706227218870481, 0.052587693789973855, 0.06156689771160018, 0.01342261924946797, 0.06368479793309234, 0.04071417701197788, 0.019427166334935464, 0.06432489288272336, 0.01941628459462663, 0.003543800844454381, 0.03974513252614997, 0.048486559753655456, 0.06102852523326874, 0.06107172193878796, 0.02801829938107403, 0.011557809011719655, 0.007885490686021512, 0.03570666172890924, 0.0761416502064094, 0.026795425546879414, 0.051675074792001396, 0.0059823907304235036, 0.06279155641095713, 0.06322690023807809, 0.11066938808653504, 0.021914457574894186, 0.021441961835080292, 0.02743014549196232, 0.06816902488935739, 0.008008805016288534, 0.04104002808162477, 0.022704501607222483, 0.006828342602602788, 0.02572040608356474, 0.025648250775702763, 0.03559205557394307, 0.0003214039236354438, 0.06820634007453918, 0.06257500514038838, 0.01969192009710241, 0.08935941164963879, 0.053441352865775116, 0.03705122180690523, 0.02017194863583427, 0.025553187224431895, 0.02532661696022842, 0.02835739778674906, 0.022278727774391882, 0.02123256115737604, 0.01524404353403952, 0.034850004376494326, 0.0117998781024653, 0.043687261422746815, 0.053150672174524516, 0.030761820817133412, 0.015658015363442246, 0.02099457666190574, 0.004377578943604021, 0.08841535527608357, 0.01770766768458998, 0.07875216208049096, 0.054604454126092605, 0.03098712200880982, 0.03139945925795473, 0.06060110383259598, 0.03273041205829941, 0.012647728017327609, 0.06110346730565652, 0.006883452633701381, 0.027276053369860165, 0.028131556682637893, 0.037994933081790805, 0.10424008112750016, 0.07384606869891286, 0.012140884755353909, 0.02741130050708307, 0.036776415654458106, 0.020710044664156158, 0.052152947391732596, 0.06044078880222514, 0.06562877955730073, 0.025156025039905217, 0.034443979093339294, 0.05242971652478445, 0.010003249899455113, 0.023836820437281858, 0.03905636382114608, 0.055688980501145124, 0.02216824796050787, 0.06375229626428336, 0.020079311907466035, 0.031559662966174074, 0.012004710861219792, 0.053129313164390624, 0.11742063870769925, 0.0162203313811915, 0.06563457573065534, 0.024135458806995302, 0.11893325441633351, 0.011941191369260196, 0.0391050709731644, 0.07503035827539861, 0.010923665158770746, 0.028296226264501456, 0.025481336197117344, 0.02375750340434024, 0.02382333746936638, 0.07077241214574315, 0.05467184484587051, 0.07312525034649298, 0.019756924812099896, 0.055734414781909436, 0.013603292318293825, 0.01879903666122118, 0.07678492896957323, 0.029082062319503166, 0.051701996198971756, 0.02084617124637589, 0.025445750216022134, 0.02766745277767768, 0.05579229116847273, 0.04429598950082436, 0.027582992661336903, 0.028475100552896038, 0.07069422688800842, 0.0208185039809905, 0.01784871841664426, 0.019577857565309387, 0.026741352667158935, 0.04956149015924893, 0.019931323950004298, 0.022487037495011464, 0.05134599166922271, 0.023080011633282993, 0.005594914036919363, 0.025074717195820995, 0.01927054163388675, 0.05683864888851531, 0.027265210592304356, 0.0441434039385058, 0.04424845123139676, 0.04374549775093328, 0.08847324279486202, 0.08080435625743121, 0.06737103060004301, 0.006257585582716274, 0.010523666114750085, 0.04881504915829282, 0.07110974795068614, 0.029296335196704604, 0.01793816205463372, 0.05831748203490861, 0.271449537249282, 0.06780658222851343, 0.17619963269680738, 0.17151920415926725, 0.11592935232329182, 0.14227391016902402, 0.099851799022872, 0.09203417124808766, 0.09629838110413402, 0.26639598654583097, 0.13494250044459477, 0.15973222180036828, 0.10522628406761214, 0.08108574154903181, 0.1956797030288726, 0.10699278849642724, 0.1220807695062831, 0.18093607854098082, 0.13902652426622808, 0.12724809144856408, 0.09736371182953008, 0.2173653175123036, 0.14392702927580103, 0.2741824515396729, 0.2021415828494355, 0.20035446155816317, 0.12929536518640816, 0.13571519491961226, 0.15481218346394598, 0.07846979715395719, 0.17228303739102557, 0.12284781623748131, 0.12206998610054143, 0.10836432935320772, 0.12343824666459113, 0.11139561669551767, 0.1272969544515945, 0.22132010373752564, 0.09533548902254552, 0.2083235394093208, 0.1694025841425173, 0.2295686595607549, 0.21044352877652273, 0.20348892227048054, 0.11296528129605576, 0.14105117734288797, 0.15756342880195007, 0.09987566649215296, 0.1771372472285293, 0.14390086114872247, 0.1985703088575974, 0.10154319068533368, 0.13755699765169993, 0.23109740955987945, 0.11508060997584835, 0.12400212304783054, 0.07086126206559129, 0.11092505053966306, 0.11503959889523685, 0.1315876070293598, 0.2508028701413423, 0.11371394502930343, 0.21944080770481378, 0.2440631450735964, 0.14030058402568102, 0.2914945303928107, 0.09767905779881403, 0.1542559140943922, 0.17043690051650628, 0.0937484136375133, 0.12629698467208073, 0.2280103275552392, 0.11326838182867505, 0.1222198925097473, 0.18019391602138057, 0.13291464128997177, 0.1613146290765144, 0.13981516007333994, 0.10336002756957896, 0.17905602551763877, 0.13703433272894472, 0.09097437694435939, 0.25790682644583285, 0.08250604150816798, 0.23034797399304807, 0.08806558849755675, 0.15673583024181426, 0.16157973906956613, 0.18333870742935687, 0.1136617423617281, 0.13156134984456003, 0.14366580813657492, 0.11295414908090606, 0.12627877236809582, 0.10514028399484232, 0.128530700749252, 0.10958224564092234, 0.12114834258682095, 0.16063091810792685, 0.13027281820541248, 0.10884841743973084, 0.07767947667161934, 0.09111775245401077, 0.13199353212257847, 0.1460729938116856, 0.07725890158326365, 0.12632322701392695, 0.20128570846281946, 0.13161859911633655, 0.13804288173560053, 0.13213692989666015, 0.11179001623531803, 0.11199239990673959, 0.13221264380263165, 0.134519639541395, 0.17917413089890033, 0.16105578280985355, 0.11467103351606056, 0.11683534394251183, 0.08405318192671984, 0.20113762031542137, 0.17806580755859613, 0.24693850718904287, 0.12946317961905152, 0.16092209232738242, 0.11298405021079816, 0.09377971000503749, 0.14773776463698596, 0.12287621822906658, 0.1491824144613929, 0.2191623390535824, 0.13628207700094208, 0.174267599650193, 0.2851162164006382, 0.05234728247160092, 0.11065300888731144, 0.13701622432563454, 0.1586725388187915, 0.15576925710774958, 0.0847215081739705, 0.19808292563538998, 0.15563105436740443, 0.3046585974516347, 0.10806928854435682, 0.09937654991517775, 0.11368385836249217, 0.16545260703423992, 0.12893319712020457, 0.1683655069791712, 0.19128759886370972, 0.10284163741744123, 0.08108468769933097, 0.138074645656161, 0.16618871362879872, 0.12014143372653052, 0.15343529172241688, 0.18144108034903184, 0.07530179878813215, 0.11463178874691948, 0.186712822469417, 0.09955783432815224, 0.0868152774637565, 0.09266184264561161, 0.11878352612257004, 0.18356377113377675, 0.16739384271204472, 0.23377311910735443, 0.23176657443400472, 0.15789096825756133, 0.14998838683823124, 0.11209158794372343, 0.11571378068765625, 0.14551777829183266, 0.09695336353615858, 0.1065319222107064, 0.20410938741406426], [0.017052546099876054, 0.03521500744682271, 0.043281087710056454, 0.006782632799513522, 0.040451456734444946, 0.016335280779458117, 0.05009840060665738, 0.05295247050526086, 0.03125456234556623, 0.006648518365182099, 0.041467794580967166, 0.07387609599390998, 0.010807184153236449, 0.0215240693432861, 0.028842150095442776, 0.035554053902160376, 0.018450720781402197, 0.034780736023094505, 0.04052207208587788, 0.07426153781125322, 0.029839596572855953, 0.030052841575525235, 0.015521830337092979, 0.06825503238360398, 0.03688306598633062, 0.04377782570372801, 0.05556394717132207, 0.0253987277392298, 0.04538535467872862, 0.014328178567666328, 0.033763010360416956, 0.04315489662985783, 0.03813466464634985, 0.04925338384055067, 0.05544764891965315, 0.012252528813405661, 0.056633560088812374, 0.025482473538431805, 0.027080091131210793, 0.04093091753020417, 0.03088341429247521, 0.026350123953307047, 0.07691766950301826, 0.02491296239895746, 0.029466897431120742, 0.07318379837670363, 0.029877017514081672, 0.02757768630544888, 0.03718527965247631, 0.061362053820630535, 0.0701170066895429, 0.03451742202742025, 0.06348660739604384, 0.04958059304044582, 0.139847859099973, 0.03461656924628187, 0.040637008496560156, 0.04514141444815323, 0.04939180922519881, 0.06186220940435305, 0.05270525740343146, 0.022925537305127364, 0.038672072332701646, 0.014548969356837915, 0.020119295113545377, 0.0531474438321311, 0.04271787925972603, 0.03542393686075229, 0.049789092008722946, 0.022646690158580896, 0.03285341190348845, 0.07542655381257646, 0.012065011287631933, 0.05066756850283127, 0.012176409509265795, 0.06479634961578995, 0.13038313103606924, 0.04900388121313881, 0.01143140827480238, 0.019889494651579298, 0.04503044481680263, 0.015263284640241181, 0.08445247964118607, 0.02635558987094555, 0.043936066431342624, 0.030370432541531045, 0.007620129754286609, 0.02430490781989647, 0.10474961745785549, 0.04425993225595448, 0.049321360856993124, 0.07134252999094315, 0.058771861949935555, 0.066696010180749, 0.04180154581263196, 0.11101109514129348, 0.060867564534419216, 0.06657022357103415, 0.018907863341155462, 0.012095260299247457, 0.03899641684256494, 0.06429330707760528, 0.023451393462892156, 0.03296896429674234, 0.044429513000068255, 0.06092945593991317, 0.029983298627485055, 0.0874365663912613, 0.007456185157934669, 0.03735490492545068, 0.06691056507406756, 0.026291041576769203, 0.03034931101865368, 0.033849110623123124, 0.05822025326779112, 0.03466655660304241, 0.028752936523233075, 0.03636618610471487, 0.01738821763865417, 0.017779344307200518, 0.022977790067670867, 0.0434747325925855, 0.02100642133882502, 0.006215222401806386, 0.02539552722737426, 0.030805637215962633, 0.04521738810581155, 0.02635880151501624, 0.02241811980638886, 0.047504876492894255, 0.01639850619540084, 0.009236108544428134, 0.024298427015310153, 0.027970254595857114, 0.0565110537718283, 0.011344193862896645, 0.05509219357918482, 0.06507052123197354, 0.06870713390526362, 0.07187533265096135, 0.035965482020401396, 0.0569022138370201, 0.06639412677031942, 0.007887400788604282, 0.013947115421615308, 0.05474699843034614, 0.06230061830137856, 0.05852322021382861, 0.045977959598531015, 0.02022537028096849, 0.06257432236452587, 0.027610695178736933, 0.07379776972811669, 0.04960586316883564, 0.02199411599576706, 0.05001762525353115, 0.04200524308544118, 0.04699167395301629, 0.057677119912113994, 0.04513090934779029, 0.0396623979031574, 0.0032921492356763338, 0.04791691688296851, 0.019325150715303607, 0.023261006608663592, 0.031049948520376347, 0.052751326220459305, 0.01864534344349522, 0.10956058235024102, 0.041864246159093454, 0.04080034777871333, 0.03758824728720356, 0.03206410074199084, 0.024207300557463896, 0.04866770686930977, 0.030029651315999217, 0.10537556707276963, 0.07520244005718268, 0.05540486039535608, 0.10249630868202075, 0.04503176955040544, 0.057692556583788246, 0.005452992209029617, 0.05198874721827451, 0.016338019304384943, 0.024078426613414194, 0.015157291109062498, 0.07818958445568569, 0.02016600588831352, 0.03301087337604258, 0.04594468540744856, 0.042794851106009446, 0.04238498891936615, 0.016976524202618748, 0.006209034745552344, 0.035691254743142053, 0.0329972364124842, 0.019337290395924356, 0.02393868206127081, 0.015989373168849852, 0.0157790874800412, 0.055480054797953926, 0.026865610452659894, 0.04640755178115796, 0.01388337514072191, 0.037888416336500086, 0.04634348959370982, 0.04789678983797785, 0.016769793401181232, 0.061932557582622394, 0.01517182050520205, 0.04344264212704729, 0.04161218683293555, 0.021379582467488945, 0.03521493694279343, 0.01757045571139315, 0.008126928023557412, 0.011342903453623876, 0.07715488958638161, 0.04651872550311964, 0.03964520605222788, 0.024656303612573538, 0.005965404361631954, 0.005392781768023269, 0.05077550275018439, 0.022078318215790205, 0.02638568024849519, 0.0516180407430511, 0.033554333276697434, 0.04525648073467892, 0.07665553552214988, 0.0446694790298352, 0.07013838054263033, 0.012417568541422952, 0.06642385720624588, 0.02706602001126157, 0.049424931276007555, 0.04969076857378241, 0.047272391311707906, 0.04994183713279199, 0.041900177238858305, 0.05721774163248483, 0.00972088033449836, 0.06061183157726191, 0.05141446592460852, 0.05676868662703782, 0.040732897687121294, 0.09810846444452181, 0.026906554739980493, 0.03471792064374313, 0.06018097403284628, 0.015322368872148218, 0.036168763690511696, 0.07070755586028099, 0.044446085157687776, 0.03596492169890553, 0.07152805948862806, 0.02535655705287354, 0.04661740516894497, 0.04062074061948806, 0.0772535358555615, 0.04873604753811378, 0.02332552150619449, 0.04582617184496485, 0.04624581924872473, 0.032358596072299406, 0.033793831753428094, 0.033464833977632225, 0.06833687642938457, 0.07738613538094796, 0.04695419549534563, 0.04607040151313413, 0.04445798920642119, 0.06661697145318612, 0.007612198514834745, 0.009279590976802865, 0.04329717376094777, 0.049438827991252765, 0.01268239280761918, 0.04010492943052668, 0.0550967132585356, 0.05016869312385097, 0.05473426317621488, 0.025017833431775216, 0.011614099985308712, 0.00844668142235605, 0.11090778076322749, 0.09725255295052193, 0.027490971915540285, 0.02751407682808349, 0.05266218686301727, 0.03878660427290015, 0.036840689353994094, 0.028193828438816126, 0.0192111290016328, 0.014758465586055536, 0.042828529767575674, 0.04170197556959465, 0.009106241050176322, 0.040569506454630755, 0.011927766845474252, 0.07127459379262291, 0.07091414750902914, 0.029014408137300052, 0.12811897206120193, 0.11082221113611013, 0.0321326083940221, 0.015290280261979206, 0.02726133658143226, 0.031243255725712515, 0.024962647330539767, 0.06898092702613212, 0.07359796873060986, 0.0608174621447688, 0.02831991747370921, 0.04346732595877256, 0.06648854279774241, 0.06292756981565617, 0.030033100447326433, 0.061495770278270356, 0.015737256326247007, 0.009858275989245158, 0.058248109780834056, 0.06634253266383894, 0.021401468402473256, 0.04050351839396171, 0.05825932734296657, 0.003013561376974394, 0.0274517067373381, 0.021193672619119752, 0.03267630578193348, 0.05427156007499434, 0.030089915562712122, 0.05939198570558801, 0.06850299134384841, 0.036485998425632715, 0.038907919442863204, 0.021580049542535562, 0.048589265570626594, 0.03857545954815578, 0.055889701761770993, 0.018716626727837138, 0.01263636295334436, 0.04873309750109911, 0.07978037800057791, 0.024660543131176382, 0.052814946830039844, 0.045518607294070534, 0.03094435203820467, 0.07104886957677081, 0.044153348717372864, 0.039035279405652545, 0.14804823469603434, 0.21746363723650575, 0.15480302536161616, 0.1768325807643123, 0.11996308079687878, 0.07466753711923957, 0.14886202930938452, 0.14426497364183888, 0.11791899087256752, 0.07673806234379299, 0.08972331634140573, 0.20415692939423025, 0.10967093228828162, 0.12838213762734085, 0.12146306515205652, 0.1619410907733254, 0.10525605161092244, 0.13521967775886878, 0.08104201420792378, 0.1726591875194572, 0.10544802295044065, 0.14314278698293492, 0.10766136707388796, 0.0917849580582697, 0.12278353140573017, 0.14420799154322594, 0.19211573177017272, 0.14465678308624774, 0.14236749499104917, 0.06188334577018395, 0.19020970357814804, 0.11453554703621194, 0.1521492685424164, 0.1441437067114748, 0.13221337110735476, 0.2217042542179115, 0.11688593614962883, 0.137735276366584, 0.13300432241521776, 0.1121121083269827, 0.13191790727432817, 0.07913825698778965, 0.1127274007012602, 0.10981148763676174, 0.10321457404643297, 0.18148305622162297, 0.1003896037582308, 0.07522874177084304, 0.10445010149851441, 0.0869816669728607, 0.1726197052630596, 0.12091867756680585, 0.18536787276389077, 0.13363833917537704, 0.25867595861200243, 0.1689202623674646, 0.11219729945878498, 0.10720790742198005, 0.16409921168815345, 0.26703951763920486, 0.09063885197974741, 0.19252624333603308, 0.18081274844007567, 0.12262236661626957, 0.12383926616166718, 0.0843959502526559, 0.15304907807148993, 0.20601655851351097, 0.15942948492011055, 0.13774712104350328, 0.13705411838600412, 0.21653152944054455, 0.09501373089733534, 0.15405997226480395, 0.11261810461292043, 0.18753515178104863, 0.18218207027530298, 0.12954751728102565, 0.14308069890830666, 0.09153516599326394, 0.1182953488023486, 0.09706993267172948, 0.20269473519874737, 0.19495153741445392, 0.20914224704029039, 0.10570601574727334, 0.0796233989240136, 0.16718797094654292, 0.18806448118994012, 0.1136555899574887, 0.14268877072026953, 0.12235740505275317, 0.2126631885766983, 0.3350648033665493, 0.367076393449679, 0.2049108623759821, 0.12045404117088765, 0.2432457881513983, 0.10605231669615023, 0.09654867040808313, 0.11665830461424775, 0.14867481513647363, 0.18081953166984022, 0.12621407193364576, 0.16537266288651153, 0.10222548415185884, 0.14969396201195195, 0.2120146999368444, 0.13351039291592315, 0.18167035945225507, 0.1631547842407599, 0.11708914360497147, 0.1425099725020118, 0.09383807249832898, 0.24024630925850943, 0.23256991960806772, 0.14276944217272103, 0.11775936975027435, 0.22272423229878768, 0.13221813569543883, 0.14950855867937207, 0.09972813495551236, 0.11135897686472163, 0.13540576386731118, 0.10062962173833512, 0.1714225616888143, 0.1743051374796778, 0.19081057602306828, 0.24573980510467663, 0.19545686576748267, 0.05322768112819176, 0.12105833491659723, 0.12953953177202493, 0.06355771256494336, 0.144357638200745, 0.13923824415542185, 0.2122138478443958, 0.13014879048569128, 0.11713111205608584, 0.21751361346105114, 0.23925209854496643, 0.15906560991425067, 0.16939133318373933, 0.12540860421722755, 0.1917717166361399, 0.14472335373284295, 0.1680883445078507, 0.18506670923670754, 0.20471523224841803, 0.15935819421429187, 0.09615142102120444, 0.061622529101441614, 0.1818940427619964, 0.0931343829142861, 0.15590119612170383, 0.15008780494099483, 0.19308169634314254, 0.13275295699713752, 0.16669704025844112, 0.13838535320246592, 0.11923731231945567, 0.09065057049156167, 0.17967286898056045, 0.1466109321336262, 0.16411150165367872, 0.11709704005625099, 0.1165498471527826, 0.09404481257661246, 0.14926077041309327, 0.1591093817842193, 0.08969609436462633, 0.13293739553773776, 0.2818473824299872, 0.12674691912252456, 0.1904928477597423, 0.10287541255820543], [0.035271807719254866, 0.02332151576410979, 0.012637237759918207, 0.04700771918578539, 0.038741040116292424, 0.04195731147774495, 0.03009296578966314, 0.02976848769321805, 0.053788722507306375, 0.08058985331445001, 0.02718979540077271, 0.060986141179455444, 0.059467751561896876, 0.023358025719062425, 0.03036392019566847, 0.0258011517507839, 0.07212026364868507, 0.04345132525486406, 0.05341751879313961, 0.07022013553068973, 0.04672557319281623, 0.043693721818272024, 0.0818957066803705, 0.04695768730016425, 0.011959777530137217, 0.039096640175557695, 0.019936038443120196, 0.003478447320048872, 0.048034309802460484, 0.05264158855425194, 0.006712373678965378, 0.059099620339111425, 0.003624653195402061, 0.035914414838771336, 0.028097020840505138, 0.04080842976691201, 0.023908771654532757, 0.03210250688425731, 0.05720593406294938, 0.06561444868566468, 0.04528791439952329, 0.056957730193971656, 0.028924042380822357, 0.10334859107388183, 0.036975804760004394, 0.07014031012658961, 0.05518178193597123, 0.01524640727438964, 0.03226256216294132, 0.034077959280693904, 0.04251602622389328, 0.029210693210188765, 0.02677366392163094, 0.04996089177438989, 0.00705612395904609, 0.03934755288355518, 0.04889541261945851, 0.020450038791750558, 0.03547131556842942, 0.02209319827670697, 0.04301597400626633, 0.04192673499346711, 0.015677142364438623, 0.02884236160753062, 0.07315259106690064, 0.02482377294654725, 0.020657812310673762, 0.025143575512629468, 0.0404817660455592, 0.04869096206675749, 0.04560297464195173, 0.016691511664248537, 0.04404174454975873, 0.04110171168576926, 0.04314177545893472, 0.040185252073570155, 0.053808244701940566, 0.006565473431692226, 0.0196640802823822, 0.021201812123763375, 0.016654200189805124, 0.01623700558411656, 0.005163411287867348, 0.05171803401026409, 0.08868498494848609, 0.03582868564990349, 0.07450513294315897, 0.044352511467877775, 0.01076823160474305, 0.03838525452010799, 0.027431709568190854, 0.01535683884867467, 0.023290532953978982, 0.020983052963856608, 0.09350659223855473, 0.004825654777960153, 0.008739893764868611, 0.03095337098784512, 0.038257786945905536, 0.034291731208213605, 0.038367572851711884, 0.004677651513702585, 0.06502313510281965, 0.05705244679120369, 0.009316056402894901, 0.02278258110891329, 0.031669934978708625, 0.025337892038805876, 0.07411796192172915, 0.024128278528223746, 0.06226676152436994, 0.03875050249916967, 0.05308773063006811, 0.04017902545456309, 0.034949852924910374, 0.09055178321432322, 0.06252495470107533, 0.014431307408813154, 0.029933908699604217, 0.03831624962913338, 0.06380070655723102, 0.04156422182859387, 0.041412148348172195, 0.038472794549306855, 0.028820536899729632, 0.05658124609908555, 0.024334289446414914, 0.014073317634029081, 0.013774947365163825, 0.029651111472048797, 0.05436624698631931, 0.08100517399725504, 0.02092386297590565, 0.06301144734607078, 0.07730721539701335, 0.056801738173817284, 0.04469824838452041, 0.07035794493276626, 0.03889071645971853, 0.04176680959062651, 0.050254674642928876, 0.05683126080839429, 0.034642395985429175, 0.007785588331898907, 0.02870025888114469, 0.045647941369679756, 0.05298731062794104, 0.018377231463091448, 0.02919120070146164, 0.08083447261014953, 0.08213584340410307, 0.045155452171457, 0.027534042455954477, 0.02415465445665177, 0.0494320262077963, 0.024901906253944617, 0.047551171664963476, 0.03340005190693773, 0.11610447691055015, 0.006293069054663647, 0.12110615891288035, 0.08797504648100585, 0.005541597683986765, 0.044904094174853526, 0.014772721315239323, 0.04545691626844928, 0.04618950879375916, 0.04264081464498304, 0.026051658132928424, 0.006642277367063798, 0.00943714707318577, 0.05858438802533783, 0.03657432884210721, 0.019025067012989894, 0.036393894188222475, 0.05216057295911014, 0.04393737261125352, 0.026152694117627107, 0.030902439248166047, 0.05180926622415427, 0.029021699738223106, 0.01377409203996649, 0.014176848162605893, 0.051145949473720975, 0.014288669408415444, 0.019041833984374534, 0.08351025637239218, 0.07665722761885263, 0.0018398227052784932, 0.05877436669834424, 0.04599578969646245, 0.021664329688064754, 0.020947168268321548, 0.07597963194712065, 0.08472955305478536, 0.017484160634921864, 0.07411123806377873, 0.005721454390368308, 0.06174272362841293, 0.013946391827630578, 0.060775723759434186, 0.10172075693844818, 0.003480267669146997, 0.03584261576179415, 0.06071459676604718, 0.03806085434916895, 0.06942250489373691, 0.049517117149662226, 0.01701112498267321, 0.06520782597362995, 0.04650874361686874, 0.030973613065725658, 0.025034470527316444, 0.045384857439785264, 0.0018881307209994702, 0.08297300082631409, 0.01826572377467528, 0.03436016835621558, 0.031219878073898144, 0.06451669352827594, 0.005817396922793705, 0.02024940102273831, 0.016390841665270273, 0.011016993939847453, 0.03926851786673069, 0.027242120522714686, 0.02253702114103362, 0.05756075857789256, 0.043039477823185734, 0.01473993786930805, 0.024587560328654945, 0.0038558108599318075, 0.02421147142740665, 0.041457100232946686, 0.0377390442736214, 0.03542175494658295, 0.03732939359906595, 0.07236527628265321, 0.058212004296365194, 0.031221707467921078, 0.048679295505280606, 0.11895921474206261, 0.009111740364460275, 0.060928053280804306, 0.05357264992198907, 0.09814349381485954, 0.040430628359899856, 0.06651213567238301, 0.05419878878456075, 0.027000380760000553, 0.04588224852341227, 0.03691697471367661, 0.048139969367184676, 0.0556773881544359, 0.09072080734767951, 0.0061311737135838484, 0.038975076386122964, 0.04674760755733587, 0.024169163443730213, 0.014169428541208617, 0.03669309473480098, 0.0227208529759082, 0.028084419172955677, 0.0412681345915189, 0.014935371327737812, 0.04851138459343929, 0.03894509733072482, 0.023900461455923505, 0.05840068421093747, 0.010023568975157104, 0.039944985473994166, 0.036936730684828945, 0.040426817431580275, 0.016061775240814313, 0.03651915758382529, 0.03674229170428589, 0.018554654852778185, 0.004782801315741381, 0.09417062145075761, 0.04755582122015767, 0.0566436236113077, 0.04146642531850375, 0.0500740730058169, 0.011128997939522378, 0.06816547000198625, 0.06684923399006948, 0.03451048665738199, 0.004430721355674905, 0.001986657434827066, 0.023374926277028862, 0.016109719836094882, 0.03634903136116918, 0.032360510813305154, 0.031816446062293835, 0.068515875027515, 0.02505903561541345, 0.08655053854454309, 0.02685465635295259, 0.0426961306220619, 0.07794663499225862, 0.03077450041018892, 0.04207533522276208, 0.029901398920628708, 0.06365390232531354, 0.060083344505983405, 0.036445866790018044, 0.032137814559973776, 0.060453023106674664, 0.024571563335484825, 0.02763304681138834, 0.007847592914913548, 0.011202298937860178, 0.014905500811437378, 0.052093605263507925, 0.052373394937603734, 0.03619745883042924, 0.005919518762311782, 0.1195908863155637, 0.02814050327287987, 0.011093010270997183, 0.060453713304013945, 0.03887837825459428, 0.04127517757297028, 0.02854336144082481, 0.016418722298112698, 0.12506159080658108, 0.08222659322200343, 0.008342190740222577, 0.0030699390890731593, 0.07349829087615944, 0.004126641651964746, 0.01835522492910968, 0.04753331930260174, 0.029740343597950414, 0.01835320257669082, 0.020197135272610467, 0.055511406826553866, 0.016810223751235753, 0.02001027733058436, 0.03650638151157182, 0.07230835355585441, 0.048657387305865996, 0.03150802804157138, 0.06692263239528984, 0.04177491013251711, 0.04237718523654621, 0.019059010992350522, 0.024944080651039258, 0.06184120662510395, 0.040508720849175006, 0.03599684889195487, 0.023828402627259493, 0.22386436408851296, 0.10600195455481298, 0.07474108395399526, 0.19865780806867406, 0.1291133015183732, 0.17664103244896978, 0.07549567002570257, 0.15929683344438672, 0.13078540476271883, 0.1880918219103478, 0.22531679162057117, 0.1641575148096308, 0.1874839881202206, 0.1211228127067443, 0.13947862578788772, 0.14893977669999003, 0.16122992034070194, 0.16923805000260472, 0.14795622322708368, 0.23648102302104235, 0.11172392798471265, 0.15030699083581567, 0.213088053278625, 0.1151828482397832, 0.10335006794775836, 0.22098285699030384, 0.12527047569165006, 0.1621289728791453, 0.09981564158806577, 0.17510581092210487, 0.131344331020955, 0.1115134177962318, 0.12639938620850444, 0.13364055077545345, 0.0830634092562832, 0.11403910219087265, 0.19041135994484648, 0.12826870777644217, 0.12503408681368455, 0.17032381205353886, 0.11192784790182486, 0.15467003249796107, 0.12983551510842517, 0.289982627145946, 0.1613141837879084, 0.18031711253570393, 0.21214331412920728, 0.11403588126995601, 0.09847757159150206, 0.10700871498556808, 0.15219876979244873, 0.11908015512744896, 0.20677117427112535, 0.15281301573850214, 0.11218278305022977, 0.12339913548203185, 0.11468627722933888, 0.09464089074754156, 0.1414756412850693, 0.1429015741450712, 0.15167742589255795, 0.10898407461354509, 0.15038608893519267, 0.0834377708088141, 0.1486084671341814, 0.23163377452874556, 0.174741267983336, 0.13977463881019503, 0.18116094928700477, 0.20826771506108344, 0.1040751239634119, 0.10611849400447682, 0.19815849111182615, 0.13567096291808411, 0.11759627537685446, 0.15933169954223558, 0.1291201144340448, 0.115014202601742, 0.08553488718462177, 0.13136309251422063, 0.17150920000858605, 0.12161274149548262, 0.09649554005591199, 0.10551113518886268, 0.15667071420466527, 0.12557474139612168, 0.1345564055372961, 0.11041022269637324, 0.17312156036496162, 0.11532809396157973, 0.1250980154145509, 0.1008337271923665, 0.11691474632243626, 0.15813672303920612, 0.16113455436425284, 0.1185210062249098, 0.057909471506718546, 0.11754622493754141, 0.09722092261654325, 0.12086755843483843, 0.19895819976227358, 0.2669953746953979, 0.1887665083631873, 0.1899197167949751, 0.1980550357257016, 0.08627474162494764, 0.10160770558286458, 0.12995029566809535, 0.12484069797210395, 0.10803740588016808, 0.15023342915810645, 0.14772030932363123, 0.13982480799313635, 0.13604828563984483, 0.11127137375297025, 0.1329808111768216, 0.20263650629203767, 0.0775915099075064, 0.08833014930132776, 0.0821161616477184, 0.2044823908363469, 0.1748617779230699, 0.18784799671266228, 0.1404428982641548, 0.1563817961141467, 0.11468367971247062, 0.12634890532353893, 0.13723158073844388, 0.18569582782220095, 0.15013166586868465, 0.10074788297060877, 0.1921547538950108, 0.0894543100730516, 0.11982039548456669, 0.14840632095001638, 0.14932646532543004, 0.10925163369392976, 0.2711086836643517, 0.16800357640022412, 0.2041979701607488, 0.1587663165992126, 0.2176263160072267, 0.09115019915043376, 0.10822781870956533, 0.11987950012553483, 0.28406684927176684, 0.16146955982549116, 0.11808308714535087, 0.1767323462991044, 0.1975501378183253, 0.2516460983315483, 0.15894300711806864, 0.08625911941635422, 0.11646275612292811, 0.10682334133889526, 0.11057461582822725, 0.24688139150384814, 0.14774586888961494, 0.21227799908956513, 0.16947335534496233, 0.23024318274110556, 0.16557902446947992, 0.1029038590786513, 0.12052073798258789, 0.1276444279938005, 0.16141961328685284, 0.2190803168923594, 0.11687659251037985, 0.14534562971675768, 0.13732111343415454, 0.08239330927608535, 0.1254219628754072, 0.18513106828322634, 0.06829084843047895, 0.09866615131613798, 0.15360628254711628], [0.04309657495468855, 0.018684526985452976, 0.05398987792432308, 0.05697391643479932, 0.026538096972217318, 0.03185519359249156, 0.04377929144538939, 0.024611049302620813, 0.03541450045304373, 0.0320551912591327, 0.03378533416253049, 0.025503643300908152, 0.10137631878023967, 0.011376598813512828, 0.021800400609208737, 0.056198895326815546, 0.04654780655982904, 0.016359651053790003, 0.03808089604717679, 0.08982451559859328, 0.03546471787558403, 0.006715076951877563, 0.033792592366808094, 0.03985651033872273, 0.09273344505345449, 0.04686576488893479, 0.030619218996434938, 0.01246594729309436, 0.05398386281740386, 0.027754864786402322, 0.04074784454132896, 0.06587512805708684, 0.037504874417209066, 0.05158879641385283, 0.014468167100858409, 0.09173420257866383, 0.040579503183835186, 0.03639417249360122, 0.026631520377122797, 0.04870335222221911, 0.033532840679981746, 0.029208284940978047, 0.02379370722337626, 0.0380540933838347, 0.028913578098581638, 0.027916706785617862, 0.026064924022648484, 0.021576565159193706, 0.07898575306171551, 0.024679471607669257, 0.01744796238199342, 0.027014908300770912, 0.0312922152079409, 0.015690740365243983, 0.027721128608391155, 0.014926391340850387, 0.02974320828798227, 0.016355823427147698, 0.03992156700405758, 0.06894566759001464, 0.04218463502184022, 0.017508994751551654, 0.02465631660015788, 0.033075199025915936, 0.02260479592223419, 0.08039875770919025, 0.0679564218444284, 0.036119600117672235, 0.04770869250933174, 0.0148852893471485, 0.0716321605432313, 0.04043760083732195, 0.07479841486201622, 0.04365706714452244, 0.05208183851209469, 0.025093962940445635, 0.06188755374751054, 0.11906087413080968, 0.06563171104062349, 0.040923154665506445, 0.03163626002788078, 0.030118415888864547, 0.028422563918866217, 0.06762269287719391, 0.02212729068560293, 0.05416512125520967, 0.03251809845096432, 0.05084376178274397, 0.013143922387826024, 0.05181895867281128, 0.05627360362268519, 0.01659816989558749, 0.05419190536485985, 0.08216862406698056, 0.11150912818266079, 0.029758494674752, 0.062226488880696706, 0.06547341094119474, 0.054370577418012545, 0.05479908977576997, 0.006086481116653886, 0.06581200839718804, 0.04024133246275596, 0.021683113445760682, 0.06255540502024814, 0.03257636817579623, 0.03930951781512704, 0.02527375934732845, 0.03293867725005839, 0.03806202694249805, 0.03341530304169282, 0.06282510890741833, 0.006580331692020991, 0.04583712594467215, 0.036654005816672, 0.03360843955306336, 0.017900685452332254, 0.04651569754059892, 0.07371902785962448, 0.05920295698160771, 0.007285532010428142, 0.021821538830408826, 0.14185153908329085, 0.012321868598519359, 0.06716008254443295, 0.027570823294809088, 0.049312859555357136, 0.027207866696699057, 0.04264840310497675, 0.002032602637882519, 0.07877815209212713, 0.11362846445990726, 0.03342019750562031, 0.057925282962969504, 0.03463380933681037, 0.03385171185072977, 0.060920809919480234, 0.11184226343175396, 0.018952325408463366, 0.022876225302752573, 0.03935367560188752, 0.01417023562680697, 0.05923247219470795, 0.06086556815716904, 0.021784090058645234, 0.07360045492532663, 0.026762069719552528, 0.08886091847671196, 0.06427214102586731, 0.0454090625862591, 0.021969675217405893, 0.07481869775801897, 0.058502569954725914, 0.03852700101560913, 0.07767498667817563, 0.027926994807785377, 0.0416463478904916, 0.08759149714023806, 0.05455270045786165, 0.0704359298106283, 0.0908811112458352, 0.045426870419760235, 0.04003289657703135, 0.05603828343737405, 0.032683582539903, 0.0380930004757829, 0.09400577560882084, 0.007455533459506114, 0.02498818463209318, 0.03640917500888463, 0.040209293947555125, 0.008168598687916528, 0.08801941949059255, 0.023958938982104883, 0.06770058127585799, 0.0524019973090617, 0.03452465796726756, 0.03859242504404392, 0.025343376510136295, 0.05276279611280188, 0.015625937885488383, 0.019830436394840945, 0.05237538760411553, 0.02344098855246557, 0.0636662590841297, 0.017002180247800425, 0.05534872063435614, 0.03555625065928325, 0.05152068581082858, 0.05707484109734651, 0.0449137272516964, 0.047428620819118805, 0.044425497981137596, 0.020143105066381395, 0.018520905687182676, 0.01964690141903702, 0.04557858766929712, 0.04698424876551144, 0.0055355700533255, 0.03470161937002558, 0.07605547201819718, 0.054471494659082964, 0.028572791306942236, 0.010861727369047003, 0.021419038748717867, 0.09590115398168564, 0.04654544281947892, 0.03515313088428229, 0.029593272192869335, 0.09418902671313845, 0.015251509539666586, 0.012975486406503478, 0.06422269914764911, 0.0656225455168169, 0.04965541265846696, 0.01021612197291688, 0.02170452626160113, 0.019611723619163968, 0.05614396526652854, 0.03301014607131947, 0.011810407322627725, 0.03165991227433551, 0.038473106251331046, 0.021718324642279185, 0.10700692640966736, 0.03548912711266894, 0.03565014347259421, 0.011456181164248846, 0.06586827803403139, 0.09531044153845869, 0.02666767410119064, 0.06754844100214541, 0.024056256806943566, 0.010571652455837466, 0.05611444263195153, 0.05959507812804077, 0.028628049767576158, 0.02978415443067206, 0.033454254662501626, 0.025682072300696746, 0.042901412380160764, 0.047175889849313535, 0.012937563587911427, 0.09141797345364466, 0.022235167416511104, 0.04612045937392395, 0.010838216130650835, 0.048544762685196474, 0.07980638285516761, 0.025919433392118663, 0.021908477719989605, 0.04146136016061064, 0.016209753921430092, 0.06843849128927104, 0.04965924956195522, 0.07323752986849286, 0.004373677102194051, 0.020150929158262443, 0.03726471171830781, 0.04282404719560873, 0.012686165700870333, 0.04004306400020141, 0.06419825280318037, 0.0678908902045805, 0.026348524625063874, 0.023817190631234553, 0.042953110387315974, 0.0020606219595720177, 0.049442212184658274, 0.07967970566824079, 0.060955972876399755, 0.025823774267337285, 0.016103213056339882, 0.047790900207473896, 0.02472539013979258, 0.061020109278615564, 0.029883631905249786, 0.01715798302029725, 0.07397771827527322, 0.03579744865419343, 0.013814307167194784, 0.10926561575615779, 0.01834108330513118, 0.021127953586983494, 0.051121276774210855, 0.07779324791044928, 0.05759031460911501, 0.022018831368768588, 0.034686015715124086, 0.06594495673198253, 0.07818468628101982, 0.03755914396606386, 0.002790583571368188, 0.05214456483372487, 0.05895397756830789, 0.05143533511727583, 0.0650648660666775, 0.04062341606186237, 0.025819080183282495, 0.029598814180644695, 0.06553506114869379, 0.06403552950359881, 0.004148859234192059, 0.021142445875739213, 0.07573660826892592, 0.05347693142539356, 0.04420480923727155, 0.009048476913449122, 0.02007185703405412, 0.009811963191168616, 0.009506539736321429, 0.10558543159277178, 0.06231307896086946, 0.043846155240316875, 0.018365661380812526, 0.05572172405663878, 0.02616295801999513, 0.026344828729634173, 0.14033939834916964, 0.03388980258023366, 0.0023446938257620786, 0.04076470613654237, 0.0391874456545338, 0.03347613317600917, 0.06457052149926312, 0.026565018379187677, 0.019959967139584478, 0.025454713504586834, 0.06835796826635487, 0.03681918191432487, 0.05534872063435614, 0.032770217148936354, 0.025048194693226833, 0.05373499843699392, 0.057476936708553694, 0.035202654398744926, 0.03929838931071572, 0.08100861014099792, 0.04378698009531945, 0.03064915166760329, 0.04518691923294682, 0.053242820940795355, 0.07428211014484987, 0.045372496970230713, 0.03898028997355141, 0.037511160408030264, 0.06853394632344134, 0.029862289593438618, 0.054289698164211586, 0.04024783738714177, 0.014289246428234037, 0.01743519002047833, 0.11065789964050055, 0.1410318518173881, 0.1446237723575905, 0.09363922887132503, 0.1295485711307265, 0.17299787403317168, 0.1424786983989179, 0.15528954769251868, 0.20647229655878618, 0.07067850077874027, 0.11312921429635026, 0.12321004367549904, 0.20152686192886904, 0.12215580805786885, 0.08567820332245901, 0.13733616418903694, 0.144976886222139, 0.11092286120401695, 0.14001778123201802, 0.18367878918070346, 0.08786285601672716, 0.20565433107549325, 0.15217399690300226, 0.1317701902007684, 0.24732152960496023, 0.15832231933018193, 0.1171882203198038, 0.14341794565552846, 0.09727917378768325, 0.2110294988960959, 0.06035483325831592, 0.18752100644633174, 0.13322484417585656, 0.22048597427783534, 0.10298215565853752, 0.18693619407713413, 0.1517348235938698, 0.10724145991844125, 0.14382154040504247, 0.12059052955009975, 0.056663342475076206, 0.10363801382482052, 0.12353640311630443, 0.14668100571725518, 0.2054871103609912, 0.17037553974660113, 0.14531175809679553, 0.09696300403447822, 0.1605012797517702, 0.1944490143796429, 0.1269656151998788, 0.0908871968567837, 0.10838819682248868, 0.1260788377840072, 0.10305848554708064, 0.12473335373215377, 0.1131907309172675, 0.08752594323595986, 0.16105780145153403, 0.15258633415214717, 0.14621652517234907, 0.20106037758523598, 0.11914846982108429, 0.0968049859511666, 0.19862386223394424, 0.22135033883387223, 0.12921181420097128, 0.12378695959341712, 0.11870541507960297, 0.07925407655420713, 0.18588979553896934, 0.1526035222923383, 0.16981287306407467, 0.06541704482515343, 0.18068575212964788, 0.14778940327232704, 0.11949718274991028, 0.32472867518663406, 0.16058444482041523, 0.10050946060800925, 0.1771772193023935, 0.1500871666939929, 0.0976603853632696, 0.15620902413502336, 0.11865065942401998, 0.23571674450067803, 0.1572385907638818, 0.19061157654505223, 0.11778556014178321, 0.1150748880172614, 0.19631461036624387, 0.1239588409953285, 0.1111481327097863, 0.19731199747184291, 0.21938419668003917, 0.1283979305298999, 0.12462471815524623, 0.15116926253540441, 0.27210328029468656, 0.1789501210441813, 0.1291690961807035, 0.19913741358323023, 0.1925788022344932, 0.08247683799709193, 0.10462842474225909, 0.1844227031688206, 0.09436922759050503, 0.09688707490568049, 0.11481043853564188, 0.11109748113085516, 0.19103428901871666, 0.1952475355938077, 0.2009493819787167, 0.13038091943599284, 0.2287452170276083, 0.16232779424171895, 0.09969406295567751, 0.1896648039110005, 0.14264473167713732, 0.13520716514904052, 0.11084098747232929, 0.18727918504737318, 0.22976066800765693, 0.13904366787755862, 0.21350183029426262, 0.20198110083583742, 0.13624569692183286, 0.09175830753520131, 0.18037903733784333, 0.14758186909602955, 0.17711726861307397, 0.21604303299682215, 0.05031886670622043, 0.1399754491285421, 0.16410136391641572, 0.20237636868841946, 0.19804172159638256, 0.19100026896921918, 0.11875864933244884, 0.12220042597618885, 0.17968309577554464, 0.09500789761659689, 0.20470702409511432, 0.12251694453880191, 0.09750464567332529, 0.1510428451001644, 0.08134556002914906, 0.2325836048112251, 0.2078169642481953, 0.15459310146979988, 0.07264061307068914, 0.14207967527909204, 0.20010532258311287, 0.0702573022863362, 0.16367327829357237, 0.13504249742254615, 0.11267281573964283, 0.10486088765901513, 0.14505205093882978, 0.147692033497151, 0.15134651708649471, 0.24559382465668023, 0.13471013400703669, 0.12295425505726598, 0.11531823081895709, 0.10623259178828448, 0.21351680683437735, 0.146250975667499, 0.09695166401797906, 0.1556797095690854, 0.14543243130901828, 0.11054933827836066, 0.17648644308792427, 0.07584836086607538, 0.12007060315227136, 0.08288107841508463], [0.029199351338320412, 0.022570768451259937, 0.006569318220499554, 0.011790992739406647, 0.022294142181635834, 0.058437435363885015, 0.08949425246100873, 0.03570358552678954, 0.05238502439169679, 0.04191970685496926, 0.033906649332493544, 0.11964099612669088, 0.03409778575587552, 0.09849804002442397, 0.020114070393901784, 0.015459998303413158, 0.07890094042522833, 0.04939147525874432, 0.021409967848740052, 0.060447471842053346, 0.027845545955642592, 0.061433099617715925, 0.029300695314304903, 0.03737061248102691, 0.0544374041055562, 0.008244635428127367, 0.05704959694412537, 0.02775150100205792, 0.01724570116493851, 0.03434893966186792, 0.009205162841681158, 0.013437083707685815, 0.02626149853313109, 0.011164936440763995, 0.01635354132304201, 0.030195127983461134, 0.08951066876761615, 0.033295487010036595, 0.016363499089493416, 0.05925576449953951, 0.029916271560068708, 0.03365451208082959, 0.04436114264535718, 0.08726218395167962, 0.04612679360434413, 0.07056352726067416, 0.013913010952819604, 0.03454241385043133, 0.016859179522725753, 0.07545031738118269, 0.030984795375843532, 0.021739704061474185, 0.026839112069865223, 0.05881945588043891, 0.07025920960586518, 0.10592474151053466, 0.020732578122988343, 0.02832327754731523, 0.05917915259487927, 0.07098913411027752, 0.008404910568060586, 0.034939240213134326, 0.04675940399465617, 0.05290546658216044, 0.006592692161575542, 0.03168092247506138, 0.016314380045514554, 0.08680086495587602, 0.04187953811197076, 0.02426671690045623, 0.08936465121223591, 0.04050121773616411, 0.03129733602690976, 0.03696951505844481, 0.07274593866895884, 0.05239871701633092, 0.0326569579920033, 0.05878315743757412, 0.026979717513313517, 0.08701523431227542, 0.06408649278455414, 0.0645354698644951, 0.030420338262047153, 0.009797183320188196, 0.045990787621121854, 0.041246003747801296, 0.02923834563262062, 0.012764680286636576, 0.054237792355706915, 0.030485328134091105, 0.08001210619113408, 0.03306078280729707, 0.02954206029244233, 0.04326227797719184, 0.05438183950900566, 0.04524793490418233, 0.02174228116928134, 0.06775179688702337, 0.035433636730886064, 0.023313854944717605, 0.04302558481867891, 0.07115776490536518, 0.005891866803722223, 0.022976203727012035, 0.040914890851126984, 0.027055303398810793, 0.054009344457881525, 0.1080739640747197, 0.04126980071305297, 0.016649830795358866, 0.06342324282741174, 0.029255791669129394, 0.07951660387334414, 0.03164870955515653, 0.0521211426530499, 0.021958557845209725, 0.003682048809423577, 0.05502356347278692, 0.052895083936164156, 0.029579121292044874, 0.044590321558644064, 0.0836793176131323, 0.08170963541488163, 0.01139061891080928, 0.008066915179369971, 0.011652392950054491, 0.04775480956595857, 0.026289369889127556, 0.06041540364094544, 0.04564103939628694, 0.03099188288615551, 0.06531697363243438, 0.02634522763401037, 0.047110317391343415, 0.04638554710254539, 0.10079243409563787, 0.07357830923865549, 0.0072573804936837405, 0.019796189990302082, 0.02772198393358849, 0.018409088152111508, 0.0077506749221356586, 0.04925882378302049, 0.04615010075212922, 0.01325405153693282, 0.016212820846703835, 0.033629464596742764, 0.07007727210293524, 0.08648966759210452, 0.03683602495584637, 0.019626594403234776, 0.03382982591574546, 0.051493263454176486, 0.03636515080870595, 0.006121412152424455, 0.013109004339639796, 0.017635460426390637, 0.01666353826294653, 0.0340259495715145, 0.03974729959736578, 0.06840718750027008, 0.03607357582950499, 0.015313889834942529, 0.07606220329762436, 0.0341766686324263, 0.02780733091640286, 0.03386377546121366, 0.03746618254808709, 0.04278612344933208, 0.029149263791623525, 0.03628691360063385, 0.030156007524055894, 0.04849910576012917, 0.03366813049069606, 0.0716864041169174, 0.0348262185434578, 0.03963727991504129, 0.032756999498815276, 0.04566285111650359, 0.024601445911685005, 0.013683435918210307, 0.046627212650491856, 0.0652925347094424, 0.03656015753222164, 0.036563263420248404, 0.041929544022423215, 0.028188444157422055, 0.10420180857181549, 0.017906494613271207, 0.018349597594351508, 0.006576922914973693, 0.011050068678741809, 0.03286616571131162, 0.02463626748067327, 0.012868369449279271, 0.052187201217748225, 0.026654378525563516, 0.058832395225181244, 0.023245829688676167, 0.027820290670206305, 0.03542046732036397, 0.06908513940288685, 0.084167613676982, 0.009809792409214424, 0.043832670417032205, 0.025428790286241565, 0.03524594758346211, 0.049380209457012825, 0.042707414977485314, 0.032410579806310125, 0.020065910575794987, 0.0561738292890368, 0.03433293153648265, 0.0156454990428756, 0.06603952861041762, 0.019656844342534896, 0.04757738432090264, 0.0596566207241267, 0.09626520710298792, 0.02096098705806071, 0.03641610295744613, 0.039692254504188895, 0.011400785406294744, 0.04751437227241695, 0.00437148637502105, 0.03170872703776695, 0.056072685692925006, 0.029494327209249604, 0.020062018011230975, 0.06885468770633452, 0.022414739323721733, 0.06858378153992817, 0.042160344528383575, 0.03617883463448379, 0.06181964352435898, 0.034197526692878455, 0.0663887536211405, 0.07612218367285095, 0.07105416851118207, 0.03914067921868991, 0.021039157472841907, 0.05990344790916424, 0.04634439501387533, 0.006323394136416027, 0.04884436399152037, 0.027669686642184388, 0.08825171171338297, 0.04811445433006156, 0.039415299834217876, 0.02695859599043615, 0.024214365803345572, 0.03941351125831716, 0.07221294305054471, 0.014259805429901462, 0.03971602549427189, 0.05258692195639014, 0.0477610436064424, 0.014824507452431135, 0.045750405988655984, 0.07246574823511764, 0.022692812781315297, 0.022910371517355088, 0.009438486649742117, 0.06768636172637343, 0.02554881040850887, 0.0500758875568863, 0.048822177486727014, 0.0067451510949467774, 0.09338678733911365, 0.05741855566157028, 0.030097598646534607, 0.0545030470675556, 0.045813098913640715, 0.02670039168151561, 0.05192541233554948, 0.030008130888745654, 0.05119262685184367, 0.013446343855321174, 0.049014557007467374, 0.04417502314026933, 0.03246651547669899, 0.026960093273373786, 0.062469048716593534, 0.07081368297804147, 0.05264287246973254, 0.02854368056432577, 0.0234284332691459, 0.01744300483551342, 0.03672371574793942, 0.054542161960853264, 0.008090694518614328, 0.028099681439925916, 0.036814272607443854, 0.02190453691582661, 0.051855286801583134, 0.027713937197404448, 0.04159237891144585, 0.003782340559155273, 0.029128346359357238, 0.03198089856596198, 0.04286079463781789, 0.0728751540009398, 0.0386440414149547, 0.07007951338891871, 0.03686558840854559, 0.0026298422699255752, 0.04389510730106849, 0.05831473237776663, 0.03312001732410863, 0.06355053599691018, 0.08560148751712404, 0.03720575921761338, 0.007559958276033285, 0.05423562899522949, 0.05463429588417057, 0.021641516068484634, 0.022796930534241255, 0.02556751438532956, 0.0038405984560085926, 0.05194248915358912, 0.03160330496029928, 0.03963476403441746, 0.025361416264786385, 0.005681579259544378, 0.05231515860941727, 0.045845356362406164, 0.018791398106259294, 0.041700832662172616, 0.06685766478767619, 0.010811137944983784, 0.054034028289606795, 0.052647744669229724, 0.029234158064355142, 0.09998110341257416, 0.06832840852439404, 0.03889698018610943, 0.02036302197666373, 0.006183186669659335, 0.024027717518038116, 0.044180362892802805, 0.058709514123620465, 0.03858774951368105, 0.015340849276981317, 0.03456700491369702, 0.051408042636467144, 0.03776084857236128, 0.07882340083597228, 0.1267921010730788, 0.035559100506361574, 0.03643115371232852, 0.0643467491318006, 0.04247742712323088, 0.17771030397852883, 0.12985656241653487, 0.09251307914382778, 0.10703544714488089, 0.19727123872144148, 0.17448107100790367, 0.20864984689978883, 0.20755964680574834, 0.11167207412654534, 0.16437628510175273, 0.14718170306878164, 0.1967760332627222, 0.1068976971146185, 0.2438309122226201, 0.13385709462454543, 0.12137026700656861, 0.16683323920005932, 0.18719670275459066, 0.07295725779840723, 0.08955617726314813, 0.12085821479558945, 0.19905849359929562, 0.14018464571563527, 0.09262823819881305, 0.14790908200666308, 0.19200420181732625, 0.13883374398574233, 0.07407479861285537, 0.09500660627963953, 0.13820766820572317, 0.16448618232971057, 0.14226029918063432, 0.1821591379120946, 0.11868862769915722, 0.09275208780309185, 0.13808815274387598, 0.23819965892471373, 0.20510270755039528, 0.1276314107235521, 0.09911709508742206, 0.0890267884824425, 0.15575974277453497, 0.2265598889789544, 0.13968270155601203, 0.13482124835718423, 0.1777737427619286, 0.11990575731033459, 0.09215842161211185, 0.09379361043102108, 0.19686966261360794, 0.2320845698704943, 0.12246608515852131, 0.12127048525144346, 0.21240401576505974, 0.19335928926011547, 0.2176552003948018, 0.13630126893986017, 0.21673713403288275, 0.21112015965627506, 0.1467802605475299, 0.0945540372049436, 0.1231506050680764, 0.16488237044541165, 0.12979402905330062, 0.09385791752720252, 0.15744110802188516, 0.07746863251668401, 0.21019799663918093, 0.16238832380622625, 0.08984961503301747, 0.2724979247432202, 0.10559388465480879, 0.1305645119282417, 0.1423325843643397, 0.15361707337433472, 0.12676765472861007, 0.11693114036461338, 0.10484509475645609, 0.179704439942725, 0.16983317822450772, 0.22486298315925524, 0.12419640246662311, 0.15167948906309903, 0.177131695963908, 0.17058700730558485, 0.16973853955278173, 0.11406063189497218, 0.09952544700354338, 0.1284285812289454, 0.13484667433658615, 0.2152393909636885, 0.09450248020584695, 0.19626078981673345, 0.19234876614063978, 0.09975646273232996, 0.1958262178231962, 0.1848724891897291, 0.10939398503978737, 0.15843652101466432, 0.13120491115842015, 0.14227284147636965, 0.21681198704754934, 0.1439069170737639, 0.16659352550050244, 0.1305047096684575, 0.09329263106337748, 0.17982440069317818, 0.1394425128819421, 0.20750440133269876, 0.09531456045806408, 0.2195599372498691, 0.0882794828794431, 0.1785404109978117, 0.1656605864991434, 0.07333466215641238, 0.08244773096521385, 0.1388816421967931, 0.09046062521520071, 0.16075932449894026, 0.12226622478920035, 0.11381670279661193, 0.18899191345553845, 0.13870179012883455, 0.15863703447394073, 0.08026292984141037, 0.1461248254054226, 0.1712533223326318, 0.2577751694479957, 0.14932705904357135, 0.13002068095374852, 0.13948811043519527, 0.2044822127209045, 0.10251659899950027, 0.14494964940240607, 0.2831998426700011, 0.12284326687222347, 0.15002831438323483, 0.10874531828449108, 0.13423794996924698, 0.15772778482642025, 0.09242356129107065, 0.13325876032467932, 0.09107090067118406, 0.1667693699710071, 0.09864364197710529, 0.13373429886996746, 0.06871782083180733, 0.09268240013625473, 0.19703416706761345, 0.12245970268850215, 0.0794611060700845, 0.12247893173480406, 0.12854567728936672, 0.12816725618904456, 0.19102665974060073, 0.20978003391064703, 0.16444355336716399, 0.18644422438228503, 0.15890334674622864, 0.16411893797339872, 0.10303355680662207, 0.13360261218622327, 0.16643167793517932, 0.15996145637473091, 0.1345884960028343, 0.10284339630743489, 0.07187347728176974, 0.12924331094836816, 0.1951317160273902, 0.10517514267121442, 0.20498673955444247, 0.18266528262756765, 0.10419409023597836, 0.12015103711746633, 0.23063646163791418, 0.25181613920722157], [0.045519538689404726, 0.04240572081471328, 0.07350542291533202, 0.036538568456307985, 0.05490791460033506, 0.015711741289123893, 0.029812541579303797, 0.036605792192858644, 0.05677843844750896, 0.007219377430374152, 0.05450627169921063, 0.061105066633899696, 0.018699664942687377, 0.017238405853277072, 0.0161241898604203, 0.021515467851713765, 0.04090244503458962, 0.05807951238239184, 0.028435562635422684, 0.027569249941734597, 0.057902009211829863, 0.024345722231373657, 0.008013801525521558, 0.04350393981439993, 0.03644246404292062, 0.026489640295039862, 0.010006451338995248, 0.01679993758443743, 0.05009670479921624, 0.0254873438825598, 0.008227609632740496, 0.04972101480234414, 0.021002638241043314, 0.040990953566506505, 0.04181018812232651, 0.010216680439043557, 0.03462061024038121, 0.036347784553072415, 0.013709561371797463, 0.014023705989529844, 0.009730582060001325, 0.019669280882226303, 0.03191931144101545, 0.013389840441959677, 0.05429700089734979, 0.037568687985185534, 0.04772707921802066, 0.04576071813062299, 0.015873071206442546, 0.010432099934405414, 0.018253487614856567, 0.03086133725446416, 0.034432227184879594, 0.028553658739838284, 0.07600614888360724, 0.08053511250182055, 0.01922759725857759, 0.02516878812457435, 0.048104761881404556, 0.03144280439300928, 0.014158303747535683, 0.05255254567600787, 0.03177087077347096, 0.011464657418400748, 0.06476204012869857, 0.08927899994887412, 0.07151987359975465, 0.05555145311518572, 0.07377431044005789, 0.03418184140173253, 0.04585942006087862, 0.027873209510289598, 0.05653182277455926, 0.016737137048039585, 0.01576865659444593, 0.026093168307852466, 0.05352050291548949, 0.02480117640516255, 0.034482767441659234, 0.03304411788121797, 0.06838399538537487, 0.044196567687322386, 0.03475546960544307, 0.03686556243337691, 0.060434684637584724, 0.05271589609037619, 0.033966336559387855, 0.014529486124956748, 0.007719290424574865, 0.038239986533881165, 0.035145928341080435, 0.0033435921295676962, 0.04828553050174378, 0.0572107320476789, 0.03942809074942488, 0.03452079508861061, 0.0720792674110271, 0.01954845924046822, 0.003544736414369254, 0.03493861309834756, 0.03491087903967127, 0.03101923102803994, 0.024650101113365963, 0.0210115607114858, 0.052183071165927686, 0.020422874331416097, 0.009159174733213149, 0.025048300449270755, 0.10198539195698686, 0.05376065077143721, 0.01927751967741642, 0.029416455508908257, 0.039009756947052665, 0.017794064806366805, 0.07332419787417166, 0.03156159626087174, 0.0053570557065540925, 0.00630458579507831, 0.043041166209150106, 0.03884831014147494, 0.06942318766959943, 0.051351238653296605, 0.05364038202969823, 0.05222637177212164, 0.04889772069873288, 0.057810802973108366, 0.0578385704284301, 0.019299019695608877, 0.03869083753670566, 0.032941230238066055, 0.13867836794815958, 0.07134228508220986, 0.03904014789441135, 0.11968821898335591, 0.002600823600005242, 0.014017801277077524, 0.042952824660460465, 0.12345916038611904, 0.028153809980722144, 0.04173933899437543, 0.05706766452931333, 0.020406734474818222, 0.07167460396885872, 0.02894122495490592, 0.02306939335539937, 0.025086585992539767, 0.005968370633127051, 0.04295942977478262, 0.05264847197395284, 0.04924887529341504, 0.03980523906648159, 0.052960426328354515, 0.04681717276980635, 0.009202981855196413, 0.056143879919545725, 0.035305727578816004, 0.01664083967625629, 0.02007887032959843, 0.06551851125550456, 0.04565931478282437, 0.006907950000822893, 0.06761705997632816, 0.07219024817459285, 0.03392295060621109, 0.022827236134617124, 0.012769163786288118, 0.02621441297378624, 0.03535902491421439, 0.02957611002784688, 0.08993044233648106, 0.0013277529842525837, 0.01953136015799828, 0.028546129651658703, 0.07043028948828578, 0.09384149379911833, 0.034752115097944625, 0.05603820180112962, 0.04319911378843244, 0.037772385257994756, 0.03476904719718732, 0.06084793472837191, 0.04252099490258843, 0.03939837886719033, 0.06643435859587044, 0.05285688559524715, 0.011258570430072723, 0.03446663686190732, 0.07398360350634903, 0.048273314750986174, 0.035996719016111456, 0.0733970916189719, 0.008985391577880364, 0.0726024444156792, 0.035836838142131455, 0.03444819449214265, 0.04343138003605418, 0.04190024032141082, 0.02611853306007106, 0.043233786927885376, 0.04419050434080418, 0.05547933491470758, 0.025986801847466268, 0.0508518771675881, 0.026070534659083933, 0.013433218973659677, 0.07501452826545574, 0.046165771200321615, 0.08631732605863363, 0.030192406156857032, 0.00539576056326041, 0.03102391397987958, 0.05296817806083709, 0.04193426408164669, 0.016511492613062728, 0.02337545134651009, 0.05152901270776056, 0.01665946387220174, 0.028604406797967386, 0.024871058885764796, 0.032857319311005995, 0.05000691606255714, 0.07442507747327909, 0.057538560940884054, 0.02391909307334572, 0.03142236193525605, 0.036641908809542656, 0.025075290504901204, 0.03924249445844907, 0.03780207858653739, 0.06096034041547682, 0.027512147244124208, 0.07435477382387035, 0.03577267205400858, 0.02686918760446133, 0.008012428552319761, 0.05686688018613495, 0.025040715700015426, 0.01611125422641635, 0.041693121747812256, 0.027127685061714146, 0.037917334120720625, 0.09378322036354803, 0.032557413724134676, 0.046683831096743234, 0.16987442679237574, 0.04537375862128101, 0.059963387466268614, 0.06234726228285581, 0.018858145012927707, 0.03170487158058677, 0.08396931923925877, 0.03447863367910031, 0.00840428994706599, 0.02938976787845604, 0.036088775013922714, 0.04494086759223137, 0.027604717179201543, 0.006582559990420123, 0.023705105922999792, 0.0537003883800935, 0.01548132206153241, 0.019342179293744266, 0.043967500096186996, 0.04076845398230944, 0.025542056864651386, 0.03241794191126246, 0.007728333030172507, 0.027498421222844627, 0.012168322882644134, 0.02516092878067866, 0.037034297129139304, 0.03710457109264098, 0.02692234207643196, 0.0518812768132193, 0.03764934830542188, 0.018633433828654233, 0.05997773689159658, 0.06722151752910577, 0.0211810913606314, 0.0165228085097624, 0.047179986504488625, 0.020408467389643192, 0.028700104885501787, 0.009162523674604017, 0.004996389097868814, 0.029110325158399064, 0.06204711920872796, 0.024284062747028656, 0.04503746924456209, 0.019855318751069717, 0.10076957594719715, 0.0518013586406596, 0.05951661827566568, 0.024190440817619674, 0.038652676303172484, 0.04387560366012622, 0.053939022254780866, 0.011075153270212468, 0.09314361523138359, 0.03670642741781194, 0.02689971213840181, 0.04952345880155917, 0.054456391953863204, 0.016079529268608894, 0.029877160377509426, 0.012972505755897146, 0.053186198783805594, 0.10196757299127057, 0.06604377369512804, 0.07733335383818485, 0.028957032700418495, 0.03294722308055498, 0.037744153960375115, 0.0884525517176371, 0.02585848451417405, 0.03192806878359988, 0.07068578866892494, 0.011465998850326287, 0.04100953694432974, 0.0645057468500454, 0.06395648335455917, 0.02286452719999943, 0.0008251824056060286, 0.017804694216465577, 0.009913111425703391, 0.024518468235328328, 0.04885694710537791, 0.026607305953803007, 0.04539657224086113, 0.028233776392880827, 0.03900054689438548, 0.002891117678700539, 0.04291806246328633, 0.03430869670410175, 0.04005612208857201, 0.017642054408497643, 0.06733259477186948, 0.017868450267997105, 0.020968026328773703, 0.012870535592810484, 0.018117578110832255, 0.05771591197117232, 0.0259140695197857, 0.000762055440191034, 0.022050652805774007, 0.07230971168610267, 0.09113226886256598, 0.00333138333644456, 0.03893294095178135, 0.03257450538512785, 0.06953379735932685, 0.027032638208766002, 0.18717673898208886, 0.08530675841029733, 0.14818519062828273, 0.12092979493900202, 0.14600416703615338, 0.06604813010198995, 0.1920578145654872, 0.1398316357517615, 0.10972314237733372, 0.08897137231542729, 0.18747626978438348, 0.18990324111655354, 0.18159642670070753, 0.15967636776622385, 0.11177465377841145, 0.14147642796160653, 0.2281668019713834, 0.12036605214234442, 0.14719676866661757, 0.07933327855425887, 0.08993822004413232, 0.17178036592667922, 0.18102543312124908, 0.1779991775401868, 0.16030351223889738, 0.12064250957337208, 0.09601481389836408, 0.11015547308488749, 0.17838764732005075, 0.18515034927986562, 0.12058262567734346, 0.19334386743139476, 0.09688521953648888, 0.16505984764080495, 0.1571092937956564, 0.10611612655338831, 0.1664192692260258, 0.12961206928594038, 0.1429105392890051, 0.16931523336097598, 0.08071008865954354, 0.06529635676997714, 0.10298152483301237, 0.07905852064141072, 0.10599635876133107, 0.2008560940157622, 0.12718258949462324, 0.1496083033271134, 0.07648573955520988, 0.12854619679274037, 0.13133673142874613, 0.1453960660728626, 0.08336312559549697, 0.13836823927704245, 0.1682208475540392, 0.3085867257323116, 0.16832586145028472, 0.14914484694600105, 0.11821927866549231, 0.23481740994611755, 0.11019480691174977, 0.11724232288543135, 0.08399297890719026, 0.08555784181226045, 0.1232201665698085, 0.1781074865721166, 0.12950726319104433, 0.09032291971379891, 0.23424016748322174, 0.15442015137523413, 0.1607740338658914, 0.13573633128544316, 0.14685938833281398, 0.08036078201257624, 0.1395076882909052, 0.12614102975931019, 0.118264096963685, 0.1391051770769991, 0.1819133831304498, 0.11623728423728608, 0.11395826004445553, 0.12024878538795747, 0.08156780357239768, 0.09062257668119855, 0.13927970052463934, 0.16289619030430913, 0.13218283915193751, 0.15991357300663367, 0.09038999502081424, 0.11321188212605193, 0.09914770867908373, 0.18052201950922608, 0.14278774353442714, 0.19644702435471117, 0.14915948209818453, 0.18293388071469963, 0.19181906565790996, 0.15664312115404755, 0.18682653433643281, 0.16542437573662028, 0.14985399873694405, 0.10517541726585478, 0.11991385414148681, 0.13344906183192506, 0.1552823043311946, 0.14090099633904174, 0.14495267736492679, 0.09826765512116253, 0.22435177699662745, 0.1903805905021727, 0.08794002453214489, 0.13724728458328173, 0.13926191866630688, 0.1703137782169506, 0.20471474243095145, 0.12289127640542574, 0.14781644713366404, 0.14073892612941563, 0.17557735671289265, 0.10654833109583706, 0.2911120868520811, 0.08215813752030954, 0.321384112467058, 0.1943259366089478, 0.16123189445352182, 0.17850995325716212, 0.1553742861142382, 0.08899096501409076, 0.09075127250980586, 0.15953630965668708, 0.268995551741682, 0.2657782525056973, 0.1632739880005829, 0.1495656743645668, 0.10219536037766375, 0.06831893872004002, 0.19015594240045175, 0.2945830224780366, 0.11296669879811816, 0.16974481812212616, 0.15730418177554384, 0.1356761431088671, 0.20228659850545228, 0.1382445974741131, 0.13226342154666781, 0.13834964105626568, 0.10067510054796003, 0.12458908022381365, 0.10094478959217668, 0.18707096809521317, 0.17474190623033792, 0.16782943886937574, 0.08077945720287971, 0.10440664875204675, 0.09937965209246613, 0.03318858063721564, 0.11580159902223386, 0.1301599375437945, 0.11486345014418475, 0.15648762637283653, 0.14359114808030427, 0.2045672183157876, 0.07231837997096591, 0.12450318405171856, 0.0941508803225588, 0.13271957519464195, 0.1573280937736854, 0.1470687927212566, 0.07275813215528615, 0.14954752143239602, 0.11538330974872224, 0.1045645035628695, 0.15387499937787652, 0.13091823435388505, 0.18765771004837006, 0.12160981743363664], [0.12314425970544107, 0.009766026105353376, 0.06937738973647356, 0.03397783984837588, 0.07590793306007981, 0.03499190672300756, 0.05072510721220169, 0.048512356806895696, 0.052085664283367805, 0.01400825447490206, 0.04317381026339717, 0.03116560481430497, 0.01788523393770447, 0.013719679627683945, 0.07248386405990459, 0.017734540851961356, 0.01994331705645891, 0.10958467988530174, 0.08257397770648822, 0.006766168717149412, 0.029431394941639155, 0.05687975644832477, 0.0815398246049881, 0.033864662327687256, 0.05909649589739274, 0.020607926999218762, 0.029905903757025953, 0.023299874737858772, 0.029249346116557717, 0.027893149162991904, 0.05049149396654684, 0.1345382971339859, 0.10585820054984652, 0.015484560608456377, 0.05470406518725213, 0.013284045435284497, 0.03163588153256569, 0.041236122051486745, 0.02155054360628128, 0.03651323524536565, 0.050791084140655585, 0.02218770150648197, 0.05536557480809279, 0.06273009916185401, 0.05541947699384764, 0.04884930298430845, 0.02465780831698794, 0.05410869205661584, 0.01723785295325797, 0.02340970517252572, 0.0998417058144696, 0.02702611844142666, 0.10466988111147657, 0.05011920671677217, 0.007170458766267984, 0.018115394341293722, 0.035211385766160674, 0.08330399869009852, 0.04646172856155317, 0.008250354603660526, 0.01188109781651292, 0.06361594147165306, 0.005724481425204431, 0.07491545897210017, 0.02035670815530466, 0.03225337808544282, 0.01754020206135465, 0.004824280413231463, 0.01026419273330248, 0.021024902671342716, 0.024581600882811472, 0.013583842483058106, 0.039054330336512066, 0.03324241974041797, 0.03489696748147253, 0.04702703357907012, 0.01375464684315375, 0.04551769445242826, 0.056921672949101776, 0.02037003156146966, 0.02308851293491898, 0.034494311548769474, 0.07201150190667249, 0.01678935826930683, 0.02879904059227556, 0.0166659131355118, 0.010329586148145609, 0.05469821706356015, 0.025151475674647372, 0.06793273249058984, 0.06304961600108072, 0.05245666019618511, 0.03090158021223033, 0.050677739636739716, 0.02784584281471325, 0.009858959692792268, 0.04740365126053803, 0.05359046517696697, 0.05651595565723255, 0.030684871235280298, 0.031911878832033835, 0.020977184431103524, 0.015347869066317799, 0.0707317424530629, 0.06662294574198313, 0.01713702476990875, 0.07792709424393252, 0.050592162588145584, 0.012345404884399613, 0.07829835361917503, 0.012252305241418071, 0.06486858284915797, 0.025202290526067372, 0.009773073725227732, 0.018208042201877106, 0.013353879676287761, 0.039588353829458356, 0.06296181250945665, 0.008308858105010586, 0.04883364737906959, 0.025835136548266746, 0.1263528535491787, 0.03556375748303253, 0.053036912067909725, 0.041692019658512436, 0.029080706044624094, 0.059582795583992265, 0.04921983876556624, 0.014803671656409279, 0.04811758619325701, 0.021072769341117237, 0.0324220942275133, 0.04627446243830491, 0.01786131822882453, 0.03744006637134589, 0.024237621000793297, 0.04551440302748233, 0.038682915110257454, 0.03769691626075655, 0.03602828255679924, 0.052487062275758944, 0.06120245496276766, 0.07490998934372328, 0.04095059928658884, 0.07584083548863418, 0.02993838756083278, 0.07159868226153776, 0.0347505491663469, 0.03563474761904217, 0.006145697079773527, 0.010401164436188992, 0.04416557560034562, 0.027302651942591183, 0.0687485234811902, 0.033560990341356955, 0.07735408202279359, 0.007548642843175912, 0.09032720190589316, 0.08515703011653386, 0.01652921138884267, 0.00927181697988999, 0.04768917031469755, 0.04589163669152185, 0.10393223084975034, 0.029566417579189874, 0.032761151815066114, 0.032366191953769885, 0.05674530526448507, 0.03434395985095762, 0.06526218829094432, 0.06437750373152085, 0.04560582077829167, 0.027433490722614806, 0.0506188502185978, 0.028227080365468282, 0.03902437354554422, 0.06377646801411174, 0.05682204333425034, 0.039523286031908356, 0.05227922752965242, 0.06959132864722051, 0.07234319738927297, 0.018624418589752167, 0.062053501678747125, 0.026204505302303005, 0.03454424695519265, 0.023613454395672306, 0.0456512736127479, 0.0033570799678273033, 0.052692421959363855, 0.015603307947458234, 0.0035737147300096694, 0.047307079294114374, 0.06369506925693713, 0.02550366370996926, 0.028383129902067594, 0.061175733935669996, 0.023612823570147157, 0.059045536327175796, 0.048006850338424556, 0.07639651114004664, 0.11896542651811615, 0.02017714738030918, 0.06005634888424538, 0.03532491951773409, 0.03137946951028425, 0.04005985138064716, 0.032351972404285334, 0.07027552201179788, 0.05354955428629182, 0.12161167280282825, 0.025423708430025727, 0.04763227356306743, 0.04063389518705662, 0.023939878774399403, 0.0413370096066501, 0.08922704219003208, 0.009047942567121936, 0.06513209722470492, 0.02902520453062607, 0.036972398302168585, 0.03320157193229534, 0.024095941298583057, 0.060201130763744004, 0.018040595132333692, 0.036242837450117804, 0.061584612776641734, 0.02912831296271179, 0.0460206776187988, 0.029810446867486462, 0.01630926850339165, 0.03919486713130027, 0.03321375057566911, 0.052104563073953614, 0.04675443531596102, 0.05679216446878854, 0.02680174307897687, 0.017017995414789766, 0.0835839516366832, 0.07043000747216865, 0.05963935465842951, 0.08000079586054198, 0.040150193017325364, 0.027500668074935675, 0.06230127881281078, 0.13424495584331453, 0.1476147017092444, 0.04555319879727904, 0.02509035239199875, 0.03526531392708421, 0.02041128755081445, 0.06221501898835413, 0.03914696520951111, 0.04520838585449383, 0.03282338831922971, 0.03892534878104925, 0.05192596523556858, 0.005923620055909851, 0.034632284223334864, 0.05076329442090355, 0.050321059752604924, 0.05021840217523277, 0.04667199384130072, 0.017428037572244648, 0.03760553190659266, 0.02146647311747074, 0.01644657695578644, 0.05655130786180962, 0.042430415778653696, 0.04355533354100771, 0.05967818753561005, 0.007644924908163375, 0.10839377777301706, 0.033202362319570966, 0.0661255361046642, 0.04157319439400453, 0.06363251362927258, 0.046727795925107785, 0.05095545871881768, 0.01988303425605409, 0.03474502758763265, 0.03180760337272659, 0.09879986406303942, 0.032610417911200784, 0.02840721444954397, 0.015585602159262635, 0.04495902423514053, 0.031519787371507846, 0.044991853137617, 0.010519859824853484, 0.012317212549532996, 0.02067340483336011, 0.016460740844195243, 0.06847562835901044, 0.012433918982424075, 0.06501396957901306, 0.05327669256075751, 0.031770369823789224, 0.014048046577954665, 0.006066469568395405, 0.015772641927469522, 0.06297157175140455, 0.023553631726827007, 0.047253960074158385, 0.030137704306980595, 0.016711590469640214, 0.037913408159511164, 0.06208211518242024, 0.007557565777460695, 0.02150319458451122, 0.14114201621850953, 0.03203713851689827, 0.02624774097057525, 0.04518866327998694, 0.018892788466473576, 0.03317682130727917, 0.02991275192471221, 0.11750749967177399, 0.028461053552746307, 0.030091936059761792, 0.021253009181236848, 0.03252654038078617, 0.05574673072260339, 0.037915727371000685, 0.017485344360466115, 0.0149627955397591, 0.031503133577643894, 0.02809532317769481, 0.019110582834400702, 0.10713213414419442, 0.05701665300875902, 0.011112485153716989, 0.05313968096743338, 0.013086795570416143, 0.03812233386270236, 0.012258468777872622, 0.015841010426811408, 0.08334475744049996, 0.045212664335849695, 0.09218643768690526, 0.04539256093266886, 0.02574826816271525, 0.07198309249361046, 0.038073036703281105, 0.03145848597341683, 0.022992232261458412, 0.06487383725470863, 0.03951442849938758, 0.06724586739437655, 0.04782982214237563, 0.05247028231678996, 0.03670649050036445, 0.2409025459201075, 0.10020792600698769, 0.0904115395678673, 0.1795537245925516, 0.14401605731109157, 0.13059675082331523, 0.14132492593489587, 0.15451517596375197, 0.14852530206553638, 0.22619043302256614, 0.12311236961977556, 0.2229331765556708, 0.07058417380903848, 0.10697858378989622, 0.19879715371644124, 0.07639398041646928, 0.248299413069617, 0.2228597187786363, 0.2008474851027131, 0.09147387943812646, 0.16864787932718173, 0.10532484870054759, 0.1515085724531673, 0.1237879837572109, 0.1500211303937249, 0.17387660656822845, 0.08251485080108978, 0.11053250636905432, 0.14373582234838977, 0.13076098810415715, 0.15994870627764612, 0.2042425880790688, 0.15431092208018526, 0.11374191657523625, 0.21910752402618527, 0.11796751990914345, 0.11185925861354917, 0.09667265359894373, 0.056702119691181, 0.08478191899484955, 0.2174806917901151, 0.05803715801448561, 0.1487536312197335, 0.10250915525830351, 0.13767127355095, 0.2010427144705318, 0.15236579754855484, 0.13291242968989536, 0.10855591477593407, 0.09937929586158134, 0.2534429862862453, 0.15356249583419412, 0.26121787377633154, 0.18847154919058084, 0.10671698415535502, 0.11561117134988308, 0.12275588640477508, 0.16533071669982746, 0.10495510330656543, 0.17652583628660068, 0.10541245181229897, 0.1448154097306542, 0.12026914992020465, 0.20687419921159744, 0.12539013958303258, 0.12428287751390599, 0.1476073544472456, 0.05650607025017962, 0.10373221462941729, 0.2285748496069573, 0.16758412937633693, 0.11632513225777075, 0.12877201748779044, 0.10558225520071574, 0.10466698673553765, 0.12266144069144502, 0.11001600127201527, 0.3123864030931145, 0.10194139744271524, 0.15231932426104322, 0.16582201846176758, 0.2335802052402869, 0.14375789382029325, 0.1025119457335677, 0.22615028283325955, 0.11280705541139469, 0.11441230599302799, 0.17591357929632068, 0.15076121489983052, 0.2112700734869577, 0.10623634705552831, 0.2308888066909276, 0.14234782807761803, 0.15220914501696825, 0.1342259271768853, 0.14761385566089302, 0.21869868971407413, 0.17557956831296906, 0.2329925578669645, 0.16441382293123752, 0.16604044736595824, 0.17430304462322965, 0.18796822463627905, 0.16072539350716397, 0.10659590276191011, 0.09485019123530947, 0.20205724518746138, 0.19912668212782592, 0.21891033538850024, 0.16112504003103822, 0.14044585201190785, 0.21552182268351316, 0.04773205531819258, 0.06214194341737311, 0.12358384861727245, 0.1524827303364873, 0.12404447741573676, 0.21840574918314815, 0.0870097721053753, 0.1495554475695826, 0.1834520630654879, 0.23991660273168236, 0.12982582265976816, 0.13631961483042687, 0.12639570515602827, 0.16250871500233188, 0.11153748564538546, 0.14783403603360057, 0.2118277974659577, 0.21605602058116347, 0.10329394674045034, 0.1670623550307937, 0.13369201129535213, 0.17962136393180117, 0.22677068860502914, 0.07459109590854496, 0.12288974015973508, 0.11326214036671445, 0.06826298078522086, 0.19219344947487116, 0.13097613671561703, 0.24393093888647854, 0.15991900552762672, 0.12911865982459858, 0.13374115631449968, 0.115550857008202, 0.19407565472647548, 0.21332174073904753, 0.08592429949203506, 0.12169094159617089, 0.07814902608515695, 0.20951698708813637, 0.10409029346192256, 0.23299191961996257, 0.1444609006284736, 0.18053646170301363, 0.15807392250280827, 0.2745317359222099, 0.17550551681779325, 0.11608489163336344, 0.17075545998523012, 0.1424670615233481, 0.12287123099667951, 0.1933450103388168, 0.09033244146849029, 0.11366794671630487, 0.15980621392372996, 0.20306640275521204, 0.10196358023677021, 0.13425497483694926, 0.12843877833802253, 0.15463629446458071, 0.12709005852229893, 0.1167495442496147, 0.1252613472752273, 0.12033264065394178], [0.04697427058999892, 0.027579884917940944, 0.01202464309244533, 0.07898657684563659, 0.026518008889979683, 0.01138865129178157, 0.04380814243631903, 0.041519652149872854, 0.03241563754272647, 0.06308914278633893, 0.006403499237421784, 0.022834113988210447, 0.038647592591587454, 0.023372299074253533, 0.08420410507824272, 0.02625204171636142, 0.06998425873462111, 0.05745118789491244, 0.06226295430678874, 0.03844601415039506, 0.054031608888180926, 0.026379628034192137, 0.017746591474860907, 0.038871635842951946, 0.023844516508688685, 0.033280614370596595, 0.09376210626214743, 0.029220057258498855, 0.0060982274590060115, 0.026157761130889412, 0.04804346048331354, 0.02220967649918748, 0.05507155816303566, 0.033261645075981505, 0.07977979170391336, 0.04177738890575711, 0.036852348493994214, 0.0882361266121734, 0.013316740751179168, 0.015666737454012036, 0.050621989503270015, 0.046070431199041195, 0.07027633837424219, 0.006216952069735271, 0.029394944358500652, 0.09340154123492539, 0.05435814644442871, 0.06682161867502145, 0.049733939304132946, 0.03950681406422518, 0.07357174123171717, 0.045397299545584247, 0.044321664099697955, 0.038884018576936796, 0.04127075066207908, 0.12980768457055092, 0.015702022865298204, 0.06298814390902407, 0.06040970765752718, 0.03947620789404027, 0.07326059581828304, 0.026299249730072916, 0.029872726045141462, 0.09735111016198061, 0.05055338537204079, 0.02493015239451779, 0.023330538424488623, 0.020032740285387263, 0.03887978462444153, 0.045576101474580355, 0.036826900250162, 0.0818324979627505, 0.0448696844978258, 0.03495583834592253, 0.03289151005446911, 0.027377304577385075, 0.015472511840926018, 0.009417906894668704, 0.011527270562510239, 0.03338867849379312, 0.027689355410984717, 0.023732676709187217, 0.00857266099046683, 0.023644401953788474, 0.10366402610088699, 0.07239150378154591, 0.014641393645433709, 0.07613473339006305, 0.008260490485554328, 0.03811432237853296, 0.029604727242258377, 0.010117570327565772, 0.007122375018298044, 0.09626784172724001, 0.02281472352478886, 0.059591389654087834, 0.03709389529831242, 0.01746784822898917, 0.04600947489961982, 0.07614949470735155, 0.04163639940088615, 0.03360261740454007, 0.012969890613021562, 0.037069931349833496, 0.08525102311978117, 0.007780625219311332, 0.04721967285149731, 0.037688485463149846, 0.009106893212447176, 0.018683287598832976, 0.030740701149625238, 0.029118115853634663, 0.09829081012867391, 0.013199499971960904, 0.011235023011977319, 0.03704559261677787, 0.028696139961539302, 0.03935717853892129, 0.07426999829476699, 0.013818935385643272, 0.03826857777312398, 0.011565505083126482, 0.06940770646906458, 0.10827124919160269, 0.017021264575305395, 0.028394297369231936, 0.02043637214228511, 0.05062638672825415, 0.02648076791956555, 0.017335491756966803, 0.02857424406101927, 0.01467878304538317, 0.037704493588535115, 0.03466057860350702, 0.023656153862248175, 0.028354518253763672, 0.027735544827010017, 0.04119457291380968, 0.06479929594206624, 0.0011602347149164416, 0.01731755219225306, 0.03230509093555156, 0.05944434793491382, 0.02689999972062651, 0.014356677038449561, 0.01817749725887552, 0.03314400353701785, 0.028613655813387595, 0.026950556675728876, 0.06835064326878637, 0.04142194098676555, 0.043564424850046635, 0.008401467930525541, 0.05397440785600338, 0.08725753810722381, 0.04235184831486549, 0.014510490855172975, 0.040879304870031774, 0.0028688186921499437, 0.05301226534356829, 0.05919661532971077, 0.02180709478125209, 0.013504077378456714, 0.013327400774869602, 0.01281766313695698, 0.009010163539642235, 0.08361690299352631, 0.034621441445779055, 0.021698416530853137, 0.06754883434041403, 0.07725095318164676, 0.040038202932919376, 0.05062416028522421, 0.09079588300664909, 0.1551318116253242, 0.01842399789893534, 0.02195606051827781, 0.02159179774025688, 0.010525410161790205, 0.0579465751798125, 0.02441805936541641, 0.011594917323236587, 0.04199332790449262, 0.03788388552493416, 0.02659387122548651, 0.06414790550479665, 0.030849301474518143, 0.012767894713761052, 0.025420114579901565, 0.043188259878661484, 0.06910387121024542, 0.011692566331475973, 0.023075093049556017, 0.037767219910165295, 0.06559035857208073, 0.018850877531804144, 0.0715598308306653, 0.060474816273199394, 0.037681242101825774, 0.026742760892375372, 0.06310126947937533, 0.03245777297706809, 0.01965214469237253, 0.03541546524502337, 0.022791913615947124, 0.0819685410533566, 0.05121776710439008, 0.026972470441251062, 0.007830990143702365, 0.02937150919024134, 0.06459076728788204, 0.03708933851157781, 0.007104338046701741, 0.033046934331650846, 0.02711048578930786, 0.046570568229071796, 0.10008884099079296, 0.0738086347701028, 0.07916222093626857, 0.027208161700400524, 0.00713075943167496, 0.03783381653192919, 0.07015882671112195, 0.05289451248245314, 0.05083785428723786, 0.032325177162420005, 0.05356949579436332, 0.043860705045517534, 0.0535540962300729, 0.060043491175747477, 0.03482912405161187, 0.12240822732564993, 0.026249227121297736, 0.02326657086086925, 0.03673763472761493, 0.010190138455072884, 0.02098136828863062, 0.04273082973668352, 0.04648395217373036, 0.027690949173120316, 0.038783605996286497, 0.02325166111404542, 0.06698612312902696, 0.0259344303412945, 0.03378190544026438, 0.08324363239808008, 0.04888838819169905, 0.056008879546425305, 0.07425832431181334, 0.02158053008315619, 0.036837178995483555, 0.06140086072264239, 0.04377658260636963, 0.029066284259897657, 0.04025394155178219, 0.006140075774965226, 0.027481986362545285, 0.021415940282167867, 0.02624295411806088, 0.026064100238727406, 0.06906125709065236, 0.04871934921538923, 0.025780163814488333, 0.06059682535124011, 0.009269661968573928, 0.02084953688608948, 0.055102145779528655, 0.09426120057469234, 0.06395784148480743, 0.0421421915962128, 0.01759834191034315, 0.029596287167805713, 0.06865893883514218, 0.02428323896310758, 0.0924082582059782, 0.04990507113689091, 0.009308829739893554, 0.033497711119707674, 0.014915902938810177, 0.04353747375716921, 0.022805396583862603, 0.047276602999772877, 0.05121635702380445, 0.0816737006243784, 0.06366035901010036, 0.010802725701068994, 0.02297926323080901, 0.007156299980124459, 0.025370561379531864, 0.08418809695285745, 0.03361793533258606, 0.026387006837467197, 0.09168771444819868, 0.039351575323962606, 0.012905766270705499, 0.03584401471016463, 0.09159597757388838, 0.03224850588594563, 0.035879734277841635, 0.05143986963958014, 0.01465944638766814, 0.01103873701140401, 0.04622428212314844, 0.04868420110142324, 0.10014960062108003, 0.04467970582481939, 0.07503486311179586, 0.07057180962874554, 0.05055486224591732, 0.035567753948271275, 0.030158679255691823, 0.02003658089961391, 0.02367194862017641, 0.04081748025782872, 0.02337870009796461, 0.005905895714022336, 0.005468329618452117, 0.05460107364342548, 0.0596652519016061, 0.03338960617838893, 0.04809702128113713, 0.03905165118339937, 0.02057539124507457, 0.039771586380084045, 0.053895172459306195, 0.04803810217708815, 0.03582046636438463, 0.0923676033562515, 0.03172736236592755, 0.10312311176676303, 0.028900082143081818, 0.024546868371544406, 0.06594307909836061, 0.029649701391463168, 0.018895090979640372, 0.04184988560155034, 0.018068757781293243, 0.04329761162807699, 0.05070970764791127, 0.03481294523226097, 0.049869384965859354, 0.06330913762212731, 0.05354992907086853, 0.019469452054181602, 0.05328849270881619, 0.05310826214554254, 0.018939818364742678, 0.03144044807413593, 0.06260022331844084, 0.03726961360371206, 0.05743070832977537, 0.04740231168398168, 0.1320931877125986, 0.3056954964995384, 0.17941899510333315, 0.20174242614302784, 0.13637692347401753, 0.09945981146302074, 0.11733228602679446, 0.09919335818267427, 0.09487854869803414, 0.212803217000328, 0.12557334615848958, 0.09880262485239655, 0.14533946989104152, 0.0697393277368974, 0.1857791413203813, 0.09352415145258419, 0.10735503819887526, 0.10587295444565825, 0.20965786156011745, 0.1614346046699211, 0.16953104990534484, 0.21798989415401593, 0.1333487976808101, 0.1100905128987506, 0.10648080307873897, 0.18074153194902465, 0.15406107064336538, 0.16744757420383394, 0.19404463295359164, 0.18784005573252216, 0.1316961832344532, 0.08411138114752248, 0.09336162111139856, 0.15218389715300873, 0.17556920793140307, 0.10970138260745443, 0.09640294229029678, 0.14667983312392607, 0.11257595804636367, 0.09219450483215041, 0.12631674064323306, 0.13872807699954137, 0.29855953878723085, 0.12174252085969783, 0.07504043664084747, 0.13363391597522423, 0.19989888678537682, 0.16658123553497717, 0.17447767197154462, 0.09034462753334083, 0.2450689481338486, 0.1032593626587186, 0.161909801827278, 0.14519295509671792, 0.14801449666265398, 0.32808983232825994, 0.1084259276103694, 0.17072338436264545, 0.13989359023980796, 0.14318701898446307, 0.16487123823026195, 0.22050433501135558, 0.15396696631796658, 0.08278099980088882, 0.0862563363625668, 0.05973087630991358, 0.11744066185201518, 0.2073559569544159, 0.1326458205585368, 0.30172340339049697, 0.1538658412755467, 0.2888002968393266, 0.13270272844238207, 0.13577756501035765, 0.07811581497662701, 0.1565008662873879, 0.14737901045009494, 0.2691783872433007, 0.20203358551952988, 0.09080749761778861, 0.09477367580984719, 0.10104543223860674, 0.11505570349982008, 0.14711305440869182, 0.2614324731985107, 0.12466992979170755, 0.13291205861605704, 0.11625053899479099, 0.08792757871560752, 0.14277474110713229, 0.19575327954953536, 0.1992005851934664, 0.1845953712472692, 0.14597013214370236, 0.12433122101356275, 0.18980627210112289, 0.07907466235337779, 0.17440701951272786, 0.1259234914323315, 0.11101093929028139, 0.12112863114452921, 0.1935223539476283, 0.10438656623591669, 0.165679793281015, 0.1276084635173902, 0.06874805592815392, 0.15298256679670885, 0.16426321148173884, 0.16508456115843728, 0.09838867714279331, 0.11075952192186378, 0.0719407232827507, 0.14409861381864175, 0.15261916676536202, 0.12807980150682852, 0.09291180540458299, 0.2112493824097328, 0.10324556613340974, 0.10196131668635644, 0.20092736987862736, 0.15785878873430192, 0.10495600130525418, 0.18268681975314394, 0.20304563746321946, 0.09568132983986288, 0.0980370921024587, 0.08884370065061375, 0.13329085079021752, 0.14552620908943936, 0.20088077784748748, 0.1532780603156425, 0.15740937378723174, 0.08724585670279339, 0.11537566562765278, 0.118591517675668, 0.18832105648471043, 0.08836310807964765, 0.10410227172542363, 0.1845377212157473, 0.1590290665626526, 0.07175706399721093, 0.15533144935034215, 0.27639948413707316, 0.2352955608512275, 0.13292495714267716, 0.06101421662606299, 0.07950893006636761, 0.12739129626424983, 0.1124780613463372, 0.1885057325125672, 0.1955558979534544, 0.10479325574124232, 0.08823437514365651, 0.16152234136825427, 0.15512706188019365, 0.12750290043186396, 0.2377261983929202, 0.09699838221422397, 0.1275860209716484, 0.18467337096808478, 0.178080398181919, 0.1252198315341957, 0.16274991299724206, 0.11096390939201228, 0.12338514599832706, 0.11422846859204583, 0.12203107529785484, 0.11723387724487111, 0.18063040275592357, 0.11409152008127421, 0.12842295574955642, 0.11682081269100308, 0.10591167971142568, 0.2037387588643469, 0.24414957559201866, 0.1293884453480132], [0.04691010450187605, 0.0021914825401836424, 0.02736131315032253, 0.030637735580967274, 0.01647735567530617, 0.024836472948663868, 0.05593854250037111, 0.04524144853348844, 0.010910775908996584, 0.024307139829033986, 0.04224607000651304, 0.05866187566425651, 0.04361393352155574, 0.09092883876292035, 0.024776333011686802, 0.06720382472849451, 0.06561460453667678, 0.008768542520556366, 0.01560130785946967, 0.03729745156306308, 0.013828849550918676, 0.0193784239309025, 0.04389745990920346, 0.09104108859901316, 0.052386709066922776, 0.06313594261882827, 0.01655696029047249, 0.047615731091354974, 0.025995280884671956, 0.008531851217412623, 0.045396943314699456, 0.04791126171767246, 0.015632752656529192, 0.034154801251133904, 0.029507264698622748, 0.030442578572547063, 0.06522812371258624, 0.036710004569613375, 0.061521589595940895, 0.024583248450653628, 0.03239541772927623, 0.053925719257676974, 0.05030948595958762, 0.027740671212086454, 0.06879348278744146, 0.008629836047475692, 0.04745291873405222, 0.02335000866878545, 0.05333658758900128, 0.06349676739773713, 0.01253795324373641, 0.06497513299109414, 0.03368576763023157, 0.053976018316461705, 0.09222732260241173, 0.02121492401784053, 0.0739141162193846, 0.022478146565845236, 0.06767606813809834, 0.10725142696173862, 0.04302354762330651, 0.010026968939200742, 0.003056898162867583, 0.06496080954093486, 0.1063211819564458, 0.04510998449404724, 0.05211483810853679, 0.009405746804986848, 0.013145592220098479, 0.10087153219501488, 0.009735102667036699, 0.04508569400059059, 0.0443231817916967, 0.02190659080952173, 0.07798383885528892, 0.023416031981469132, 0.07109451165888458, 0.017235342638741713, 0.029228345192677807, 0.048028469100245275, 0.05924520373810083, 0.05975063228106592, 0.02656832835782552, 0.03145410730212461, 0.10279418449499644, 0.07941441755974665, 0.010130765713256551, 0.04983249651559163, 0.034555089732748456, 0.032523330592084676, 0.042554777464829385, 0.033493158043711446, 0.03550995919795241, 0.09949668135959655, 0.04554687940981239, 0.03651828184956685, 0.08911123746656813, 0.062208150411606766, 0.06581652807653882, 0.012646810537262354, 0.04503517229750287, 0.03667373581265565, 0.024868591244739946, 0.023026250455586705, 0.038627120447927155, 0.00527131724084029, 0.013534289282688405, 0.0611761087202467, 0.02759291517577367, 0.010175208299187943, 0.05176564278372098, 0.06644002118264325, 0.0388652273977641, 0.05042888267780654, 0.04994220820663031, 0.051105324309901334, 0.048546473335591145, 0.03423881978960708, 0.03703709131514188, 0.008429429271927802, 0.04139082273468375, 0.054682398185832426, 0.01422594865289284, 0.016398415282310452, 0.08220632516895421, 0.07039707095827907, 0.017204129762831144, 0.025831288512563333, 0.061165518272900954, 0.03128989970718976, 0.020252672038623132, 0.01784552718163468, 0.018630569138622377, 0.03296123853942845, 0.04516060267633293, 0.007911428747320315, 0.044453532609622926, 0.0640580833714921, 0.06208203354617581, 0.034974536756635644, 0.04924081928038504, 0.05329206986061763, 0.040922364278230816, 0.00389929955417756, 0.038280633962131105, 0.09866775435511954, 0.024227104768215213, 0.06851630547316745, 0.0454907507810276, 0.07302773956325836, 0.07305914725293405, 0.02022565415245481, 0.03779164399020374, 0.058829756890190765, 0.0381836538144853, 0.04512018531386275, 0.04865999595494941, 0.09578108190908097, 0.03622872922278475, 0.043147957549081184, 0.04021615881356411, 0.01570517328218557, 0.030269743510871194, 0.051663081685546786, 0.022479623439721763, 0.033059925626730546, 0.024190062322304584, 0.049056892821681686, 0.04181448144663591, 0.021076969896967057, 0.011191700141353067, 0.03078962352446979, 0.002652447624313936, 0.06770914566004649, 0.06095934222685173, 0.020569478183460888, 0.02203243122494314, 0.037647207209374756, 0.0114632074473775, 0.016983505956886802, 0.012677757167693926, 0.0550578061665874, 0.05839150384417735, 0.012352996127447113, 0.08421559352427721, 0.016507312466274016, 0.016099934618978295, 0.025758858610060997, 0.03144451133266557, 0.06477282353444025, 0.05112107268359978, 0.027552503379411064, 0.04634363802324515, 0.020418523490661755, 0.03811589202086907, 0.012830105242755963, 0.011198709726158995, 0.018243451922899112, 0.018477872254152317, 0.03015011672687251, 0.005898066056033713, 0.09794286161195487, 0.033730370705598034, 0.02324325072549982, 0.03375318803591654, 0.03664201642095577, 0.09310932058724575, 0.04302308378100861, 0.07398058296530508, 0.021161955082789063, 0.0471479442785494, 0.04549194192804862, 0.04251419682987034, 0.020367712349980138, 0.039564196922583506, 0.06168687701574527, 0.014158553294691956, 0.05893530142202508, 0.05495449178852141, 0.08290092344395816, 0.01353460469545098, 0.05817052566271741, 0.037397300111479126, 0.026930142048513517, 0.04510002487222664, 0.03165357804391533, 0.01656915934290737, 0.030569062801077962, 0.005271122890917468, 0.07636399022885598, 0.009118902089539915, 0.019103495324088726, 0.045170228331699036, 0.004901422953480505, 0.07087835372658446, 0.0660871151194442, 0.026901955279754475, 0.025343343113490846, 0.015735430642962456, 0.012642150777537609, 0.06303715534158982, 0.022336661677400116, 0.06198805909662042, 0.01816523141314974, 0.06306777635472827, 0.05962965478829574, 0.02287236613483401, 0.1530324836494401, 0.006979151185078081, 0.06843849128927104, 0.03248412293032743, 0.03653423431387637, 0.030569951522920746, 0.014637875865446404, 0.0339362498925766, 0.03613688102632295, 0.004347587828306132, 0.05745013775594998, 0.030062747391639277, 0.021000413653382566, 0.03648228768724948, 0.04774139524670318, 0.028367555933073163, 0.01498711386375362, 0.01599984858330572, 0.013054913833911996, 0.010348681607865728, 0.026210874784737825, 0.0344709116325248, 0.03116802421573084, 0.04962396043993067, 0.0371670228196308, 0.07409003490465693, 0.05987071919662412, 0.036668013854068704, 0.12364678274025209, 0.02848718828317942, 0.1141503723920323, 0.02025255515036406, 0.05548428132897243, 0.03601415206503589, 0.022190508680068888, 0.08544542870367877, 0.054859248266438954, 0.008766926493990468, 0.055959704841370694, 0.044937624406884424, 0.06128813591203652, 0.058753527191584, 0.033013437496265396, 0.048115433964994736, 0.011678679820761317, 0.08722743659745902, 0.018112462857970968, 0.07236154327983968, 0.025521939096506685, 0.011637658535619266, 0.033002409181790426, 0.07608264204463921, 0.04554901308438275, 0.04471465726965107, 0.05412890444858931, 0.05360425799153745, 0.009125051710725529, 0.09293199924286455, 0.036756722765858285, 0.03287903455202468, 0.023060782586981077, 0.05905930316657759, 0.021403694845503196, 0.049089610402006656, 0.057207522258977406, 0.03836559131741524, 0.03320648494991474, 0.041158337553497404, 0.02850935994501924, 0.04332452932430897, 0.03260817291447893, 0.016466093584313057, 0.06949645248823799, 0.014694494311697781, 0.06426437816116959, 0.036657182208728045, 0.040779040718916804, 0.05476842423377093, 0.042527466430328786, 0.07318318981560878, 0.06782295400626026, 0.04011836601421237, 0.030890292146068532, 0.021951474045636132, 0.03170951000356581, 0.032201572466874495, 0.0629748594656121, 0.08830525766825303, 0.04100308025954291, 0.028098380826122593, 0.16696790931746364, 0.006594404203497106, 0.0007812748037849815, 0.014704278601129772, 0.034509369725128636, 0.04347025002061855, 0.06443719466915354, 0.03972844162490219, 0.018039771348412614, 0.021872296165383887, 0.05542250495636836, 0.06655132106970996, 0.042704628212959506, 0.07457522879121825, 0.015365375402325299, 0.16087064665043727, 0.08402541076065972, 0.13557344471337274, 0.14685970003483817, 0.06727283704094589, 0.23061079817125574, 0.2005018520867452, 0.11710530758136883, 0.13113222521496937, 0.07095351102179848, 0.07617102441145107, 0.22424808412324637, 0.13268181472085416, 0.1127470973005984, 0.12826266669435427, 0.14941700734198093, 0.13620891608297825, 0.13427812984446064, 0.153658663330134, 0.14337067084852606, 0.10626270071952604, 0.0861646885459777, 0.09367838458274491, 0.15131326887058094, 0.08546217155526392, 0.1516370233730413, 0.11443434777902439, 0.2417679049540311, 0.14581897150492296, 0.08838432608172297, 0.2539329818682745, 0.14524644910125062, 0.13643703743582591, 0.13696299749426544, 0.18883376178564504, 0.11064969148719683, 0.1533615667722188, 0.0930071491166018, 0.14514811453409493, 0.18881313008023426, 0.15296928235329688, 0.2538681775331497, 0.22146405070088804, 0.16314014908857644, 0.13061984645901248, 0.21615494886646047, 0.1281828264473006, 0.11677009431878105, 0.13013850431889296, 0.11506446084240451, 0.14458587829722092, 0.1656600076239556, 0.11418062975280918, 0.14132310025161132, 0.19414871174376458, 0.08899356253095903, 0.13572770752944052, 0.09975005057640374, 0.13887423556298018, 0.21815266198245808, 0.18338231602683663, 0.12250120358658023, 0.15275646408554167, 0.1701822696486488, 0.1846030302112922, 0.11105309327831492, 0.1672245588270016, 0.1204395767126698, 0.231010222050827, 0.14890829479554668, 0.09395336513989605, 0.2746920695062727, 0.1287839957512915, 0.10397655933047645, 0.13896332297008485, 0.08009639932424761, 0.19526179967215285, 0.10288238132488914, 0.1464342267718166, 0.1904191673384048, 0.18025690951617435, 0.23285318253329024, 0.17830455646617338, 0.148335846606642, 0.18740018480457366, 0.1054854568792507, 0.0997725005436223, 0.11449180485215038, 0.08281432965304703, 0.16385796916438267, 0.16503375372849405, 0.12003081661532633, 0.12270818115212023, 0.20146606519119814, 0.1767145495978184, 0.1731606715475209, 0.13271023897686973, 0.2699012984521687, 0.1418870285851881, 0.19256299448898062, 0.24619595875265077, 0.2971035341033712, 0.1090069995552767, 0.16436038829851896, 0.1894228340825066, 0.07881816869485192, 0.15602599567500874, 0.20540226803859696, 0.10637776329531334, 0.1775064953835681, 0.14399149222299457, 0.16417614271631464, 0.10525420366320759, 0.10511103595490567, 0.12419407954439521, 0.1598992495564744, 0.21142991725355387, 0.17582501139258966, 0.1414304890204221, 0.11573118405067362, 0.09396115769050084, 0.14428285940084606, 0.13809241267153993, 0.15496062784222886, 0.18749143928289413, 0.15040300990222022, 0.16571664833463728, 0.15164192154770717, 0.1831246868823655, 0.06498458795249462, 0.09481729925028048, 0.06073965167161077, 0.1478404036606662, 0.11383754972484894, 0.095721717516426, 0.15412795299198478, 0.10544137330725789, 0.13465960859321058, 0.18672113452339545, 0.1371638968703337, 0.18886460544308648, 0.11383567209122702, 0.12411347488523461, 0.1899272421724163, 0.10960909654386342, 0.19657062162877992, 0.14339096116600558, 0.07913465015008114, 0.1768710240139626, 0.14209742745151743, 0.21340558858355507, 0.1891433709533885, 0.202098092995584, 0.14023474068380892, 0.1508354741963558, 0.21371464856201783, 0.1348178493208252, 0.2152030257275328, 0.16010334016755223, 0.10550342427450232, 0.12694719509454444, 0.3467580524738878, 0.156978408631403, 0.18760605657007545, 0.0451627994334558, 0.0861349877959583, 0.1397721897228621, 0.13506994204362854, 0.11927615632885136, 0.0835020853264723, 0.13187915232265368, 0.12942276225658134, 0.11138211702927947, 0.1466981938574463, 0.16713551594875753, 0.12034879720886238], [0.11086945625720546, 0.06837127497419715, 0.022033772656868678, 0.1261499206884764, 0.04354821634478867, 0.013533731744246325, 0.023741165023238864, 0.024618541283416562, 0.060141217181808315, 0.05215761921135709, 0.006402481567420182, 0.03051942610909464, 0.013514955408027163, 0.055142381315818056, 0.046264384072856046, 0.03863218931655865, 0.019663280618260615, 0.017594642304175068, 0.05870279768714681, 0.04403179606015328, 0.06613900608499534, 0.049986725935013965, 0.012797130693797953, 0.04184607838396914, 0.02416615217953222, 0.047013222210807726, 0.023153914698923472, 0.011839515282190405, 0.01748888440488372, 0.04514644249866251, 0.010231909309368348, 0.020516908152785618, 0.07585938175907359, 0.018252678673889022, 0.11550645431270823, 0.016396212959080003, 0.05857988689967897, 0.02711110548261786, 0.02293885514518479, 0.07741878987872042, 0.026435684303578455, 0.006520967299366021, 0.019138858660880942, 0.06437340707634576, 0.0022595864174945746, 0.027334623664501123, 0.035544365164241754, 0.04018918545625638, 0.13806775852572173, 0.07212440483272076, 0.061477053313865326, 0.055595499579794705, 0.013848309590684948, 0.006043488501745742, 0.09914914102409966, 0.07439336550305597, 0.006341730750136776, 0.07310251836315729, 0.027882788781425916, 0.012686243626376381, 0.04960602273058612, 0.09279781894292682, 0.006744848205926246, 0.08598267682828009, 0.027465451312309597, 0.0832652734243311, 0.057266749354312196, 0.04854382015764713, 0.03393324419448618, 0.07101243012584746, 0.048995806646416895, 0.07397889086860232, 0.015931765810819343, 0.04779393559147138, 0.016816465213196352, 0.017365904968755785, 0.04675673226302024, 0.021597631020995323, 0.07834921299945563, 0.03843553873593919, 0.040614272802486084, 0.03236196542275138, 0.0340856405091472, 0.025830362683336716, 0.021931131777819246, 0.05852121641510166, 0.05946541379671544, 0.029851472791051492, 0.04815569176571444, 0.025879821259877644, 0.009638727369747357, 0.08757541480008513, 0.038664877210976556, 0.03828154680377338, 0.021629137045238167, 0.04929422793793492, 0.04294827529520262, 0.014977005812397692, 0.03937132758437656, 0.03256161056924611, 0.013518862815544708, 0.023843195485824253, 0.036718954870593734, 0.05413570623204578, 0.029900836743763648, 0.060550211055669934, 0.021137057883606758, 0.0076853302107338095, 0.0380019500880735, 0.04466604659683071, 0.02220561509602703, 0.016616204084130004, 0.10386457666754723, 0.0691091627231799, 0.04382846243970562, 0.04250890160619747, 0.05206207511946559, 0.014850758143438725, 0.040093307397910394, 0.017825275826908182, 0.028534541015687864, 0.04289479984436184, 0.029548884340329096, 0.012410087692842353, 0.04916628538921941, 0.036487007746472955, 0.01224735697178403, 0.07590299777803011, 0.04780660405231174, 0.03123797163425479, 0.03173060926201288, 0.04052242460602429, 0.06494170665973797, 0.040357686375500634, 0.059624233399517834, 0.021151171677047387, 0.032790830300655216, 0.04486469355470035, 0.06286827963776886, 0.009299547327827895, 0.013593768708233256, 0.03132861013000365, 0.07919592928374186, 0.037504607244045474, 0.02123540543834679, 0.008727998992981156, 0.03426232360652648, 0.1041954335232731, 0.11472328071249649, 0.027021817695640493, 0.06847543540061451, 0.037954927611281164, 0.045315993556869216, 0.04020971697173081, 0.019022747801500373, 0.07637437287485227, 0.039020347394398414, 0.049795415106927976, 0.05389336161897518, 0.031491177578573115, 0.02501294824469369, 0.055892892996780574, 0.012550537285278551, 0.02139998225175077, 0.039750791402184404, 0.006032302017047186, 0.039738293635309674, 0.03990305041952524, 0.08041250970563851, 0.059148757936782204, 0.02917403297033161, 0.006845734833405004, 0.010004234172811266, 0.020130056254856754, 0.056637118686921895, 0.025960309030779172, 0.02609489380120067, 0.042454249851289205, 0.020064493073732592, 0.058836079988395795, 0.06562192211276852, 0.05243846644589212, 0.015862130094319582, 0.054132663426571526, 0.106006466812687, 0.05182100328966044, 0.023242122661031317, 0.05111365862831008, 0.04528909812506754, 0.05763019020378124, 0.05139627588505391, 0.04076316246937495, 0.030328519751492422, 0.007030822289380012, 0.04816394444787875, 0.1691189204575494, 0.027336419661878608, 0.0278638473173487, 0.039899677358334884, 0.036941287471563555, 0.009196742248605005, 0.023717869007668924, 0.03335111839987803, 0.04498900700127706, 0.015223389564198442, 0.02497393354133237, 0.0054760386774432845, 0.023255178894032724, 0.03830385576293338, 0.0374774891679408, 0.05272989299555775, 0.021529260666284245, 0.02322981414181413, 0.09276186930947006, 0.06583439899259247, 0.06066379304684233, 0.024536897617508657, 0.049299215170321986, 0.02475496472470695, 0.10125626155058853, 0.0751645237323828, 0.018678396845643874, 0.05189290997805074, 0.029439389727485832, 0.08225098761613481, 0.03373208506673109, 0.019871336153300945, 0.11109717685030773, 0.06549064361024648, 0.008843330597301247, 0.018780553473334294, 0.05349788596504368, 0.04502497518842574, 0.01923583880852675, 0.023479366864194162, 0.025331956712761894, 0.048526138489251025, 0.016930041638261173, 0.008633457728137728, 0.059179111776757054, 0.017592378753761295, 0.016836367758514825, 0.0257531477836892, 0.014857269561616704, 0.05078905807749834, 0.028503971952886786, 0.06146489693492185, 0.013743317958869739, 0.027785094316641334, 0.039467239039367996, 0.013828467344865203, 0.0120008581870934, 0.045499545230995864, 0.02517978489777306, 0.054067513992777094, 0.02248887059977278, 0.01904661341541214, 0.03722066896443721, 0.015844231347728055, 0.07488083036150783, 0.035863885714206845, 0.06809331840486266, 0.13385822268901393, 0.012384106958052143, 0.05761910251749214, 0.03329865226987749, 0.04919287282973528, 0.06704248924506828, 0.03507206609356217, 0.06220384224434383, 0.02509117988665821, 0.06596294639166445, 0.017228813594556414, 0.07000582554610446, 0.04847075200814288, 0.021836778832948767, 0.03365243406733498, 0.020253134025551844, 0.018701191911532078, 0.03691787271236535, 0.040113208087859675, 0.05004626844311133, 0.030922506921342574, 0.02995080554683227, 0.04102349674212746, 0.04103167892026249, 0.01526211854070425, 0.043092760315630585, 0.03596326299884822, 0.010754870163509622, 0.05954304615443107, 0.025447349544265307, 0.0637272562016733, 0.030861862323945388, 0.034920638281619176, 0.019599693405325525, 0.0290557179323514, 0.042688861285569146, 0.009730877063702792, 0.028712407838611398, 0.11035156334401108, 0.06165419654280413, 0.06433550559449941, 0.060419630171963945, 0.016641797046759166, 0.027514473877090495, 0.03807848406722769, 0.0357737073500175, 0.028457502376113553, 0.0202097870351281, 0.05608120554825291, 0.014073648817429785, 0.051634542396641336, 0.02596627589809941, 0.1548548272694461, 0.02881456632167101, 0.02562877125455998, 0.02879911109630484, 0.01820968976971926, 0.09129481404670514, 0.04832299782719929, 0.10363231413066387, 0.057540798516129144, 0.06467490456998348, 0.026243503307341598, 0.01839748652855633, 0.02334414384677075, 0.0156894972678856, 0.06344957422697917, 0.01997253541048849, 0.06901870234287344, 0.03282413788838312, 0.010283545161655638, 0.04392400282085873, 0.02109543638653122, 0.025440692479605787, 0.037723748610005714, 0.07856515570892952, 0.06589342199731618, 0.052020448056282476, 0.07045555219519883, 0.019807372300419956, 0.08909429423511028, 0.05665761309501249, 0.021934541946393438, 0.03219982470909599, 0.022139871944091283, 0.05621432086627465, 0.047182569178403355, 0.031858596339588985, 0.08861599490046501, 0.051354737879591994, 0.17504735937109217, 0.17129611456766725, 0.09394376174896024, 0.2122690191026777, 0.17380200588377193, 0.06652079653576948, 0.14366635732585564, 0.18638899375218898, 0.16995667159790173, 0.1277226652018726, 0.09272889568819664, 0.17388138599926606, 0.1676895291893743, 0.19804816343821585, 0.1624289934989065, 0.1257119793444872, 0.1478355351719074, 0.08466009545372799, 0.14431898714974523, 0.2167513535823673, 0.1439435049542226, 0.1866696443175897, 0.0885596065199934, 0.15860151528613642, 0.09376351634273306, 0.1571194315329194, 0.1322697743307799, 0.09108742087846622, 0.07352005064603873, 0.14614746090956032, 0.07025593673461117, 0.1907003077212721, 0.1187451793521177, 0.06394259035005234, 0.2266806215629913, 0.11485988041386008, 0.1618939940817654, 0.14926557953003794, 0.2068853611126542, 0.22219046484678984, 0.12436915218131617, 0.26212691562250257, 0.12328292257734574, 0.2961979655083269, 0.1858325907960534, 0.1621843222528696, 0.0515355547395302, 0.1550903107272461, 0.25939619808923453, 0.15868717397097498, 0.18990073265740648, 0.1950539686367847, 0.12069918739143759, 0.12901719339424744, 0.1561086263973266, 0.15179765381617472, 0.16218895325437188, 0.11121725634438917, 0.10012240090873092, 0.09031114183017053, 0.1701409468660131, 0.19196060806280002, 0.06771817759727128, 0.22238585748709738, 0.15101299592060968, 0.11352265646564774, 0.11696594709064811, 0.1278140681097284, 0.23240483627887443, 0.1311994786374271, 0.14095784485107288, 0.18039018439594656, 0.09126444536377676, 0.11398575661587529, 0.18282576464116573, 0.12774476635968313, 0.10797503578942269, 0.18573637877125293, 0.14225911174435169, 0.09520832943962887, 0.20575910748448223, 0.13611684524221346, 0.07144989649532363, 0.19017212121980265, 0.07528147136326879, 0.14706168294651434, 0.2883749868487939, 0.1837979187257588, 0.10540848132222891, 0.20509408379439265, 0.09160713205346838, 0.19129963649902493, 0.14991524076322094, 0.141209150897339, 0.13045051804510877, 0.12135710872826166, 0.137960844731424, 0.13303564104717225, 0.12641005829209462, 0.08161602090694942, 0.11742540329578333, 0.1426618010737002, 0.12838822323828936, 0.12457183271180838, 0.06809278405853547, 0.09586705971742049, 0.10475494607817382, 0.17009575007250533, 0.10794929068651982, 0.11456875072326511, 0.101107297668932, 0.18290469946805388, 0.19262548332335427, 0.15983094228431582, 0.2066684016608633, 0.1589490778860636, 0.2680987404892221, 0.1134970597922802, 0.07469547897926532, 0.07734808546956629, 0.08940529121900909, 0.19068341644015163, 0.1306968368589878, 0.049507131552672945, 0.23225247336085886, 0.11211743694730103, 0.18876539514167234, 0.23048829927574843, 0.15672411915147677, 0.13222431036410853, 0.12438291902071796, 0.10604758921544999, 0.1607625454198569, 0.18559541524155065, 0.1148615131387487, 0.16166091518243775, 0.12443400104530156, 0.14283754164353013, 0.20656893902923912, 0.08398347941692919, 0.1321185691631399, 0.12773620197549462, 0.15359550656285137, 0.1350068298052065, 0.15605827909894288, 0.16537312301807106, 0.16731493757106364, 0.1471427403157577, 0.2010185204562731, 0.14249033527448773, 0.10936190199572593, 0.13290171307744458, 0.1150998316006735, 0.11884664578246884, 0.12888785189716145, 0.18332950479816645, 0.12025905671180226, 0.1309559799847193, 0.10782656172523275, 0.0800558335322421, 0.13598489138530567, 0.1892761857016012, 0.12243285920703784, 0.1747205769061111, 0.14863129559671506, 0.14427028741920367, 0.12270239982171915, 0.18697328661801293, 0.15018799487734213, 0.14327307842904702, 0.15454974520253018, 0.15176155575318262, 0.12288881247513928, 0.17506799107650295, 0.20596162474248558, 0.14013514446560293]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0353114606696181, 0.03447654082265217, 0.04213248801534064, 0.051816568957292475, 0.07722197231487371, 0.03294409121735953, 0.04919326245726552, 0.029298348272277508, 0.020799896483367775, 0.025839912268565968, 0.028960945674043614, 0.021427655083243735, 0.01747472237184411, 0.04613652316038497, 0.0454635510686785, 0.04616295103915036, 0.07249531539855525, 0.017209066900250036, 0.011562338895600988, 0.01225044430611888, 0.02481330680893734, 0.037502314007724635, 0.04943325817293953, 0.07326282226131298, 0.08270589445601217, 0.023241927847266197, 0.07552363415015861, 0.004700617273556418, 0.07225324166938663, 0.027278452362224925, 0.020897668873658404, 0.03647904821264092, 0.024110877020575572, 0.014480009922408499, 0.041315843554912135, 0.006756958664482227, 0.06398846991942264, 0.14524967002216727, 0.019639695165096782, 0.021848927790415473, 0.050908447374240495, 0.05140515568200499, 0.030467253127426375, 0.08710323076229542, 0.05929847880906891, 0.07817330173566006, 0.049440182410762645, 0.03807280292676296, 0.030173930390446912, 0.04927798974676989, 0.027770234664785676, 0.02488034686393803, 0.04654488249798305, 0.05194096404011361, 0.010902358098974219, 0.04434355374542065, 0.03056706456845859, 0.03076926826906856, 0.022422956753871404, 0.023126835585571826, 0.06077892241592053, 0.05720543682400603, 0.03773704418563284, 0.03433933627093211, 0.04156827024416998, 0.03960689267842099, 0.024956680463219527, 0.06020667089615017, 0.13924452272476628, 0.08616010207333602, 0.06108473549829796, 0.05216994628426619, 0.0647707752068527, 0.03590350526792463, 0.04572817124426365, 0.08605984534369782, 0.0240288938221056, 0.017390516441082582, 0.07095728113199584, 0.02317336453415919, 0.05100572438095696, 0.056261655045091175, 0.017536318773636594, 0.028325179300736636, 0.008298934662889224, 0.06648642767686397, 0.0302398423809791, 0.017970725639315788, 0.07826105327694677, 0.05142316389537882, 0.01544480004668003, 0.045078903349349275, 0.008673288793943357, 0.020225320186000317, 0.058162339773843996, 0.042721645659185015, 0.07437706051860005, 0.01705513619526755, 0.03885765378072392, 0.038448593113571405, 0.013910875422880054, 0.02234575484180823, 0.04199491610052064, 0.008797623577265767, 0.05282945581711829, 0.0548873905063374, 0.01074375835742103, 0.025096363788179588, 0.06304847309365869, 0.009925599915732164, 0.08434062314336188, 0.07817147605237551, 0.044439335324568674, 0.02531270725739887, 0.010458653978275834, 0.008932261225709226, 0.030567632311431225, 0.030742152048333082, 0.031954808364389464, 0.05700904228433501, 0.0395364888390759, 0.046633613674202934, 0.09681832976639271, 0.04643595377274323, 0.0453724784165388, 0.022625995370617602, 0.012082220764568774, 0.02575140373664908, 0.017681043136690278, 0.04650114773539826, 0.04532498467597179, 0.0401774743659189, 0.0745485931111034, 0.05984763469314203, 0.047451215505134314, 0.02650014910614118, 0.07584997874801047, 0.023191307809611317, 0.010232099484710488, 0.014142502495815279, 0.057127592954202555, 0.015776263608131558, 0.01883466902654618, 0.026610886816342827, 0.05064446173491888, 0.03066851986659458, 0.0077582179255841766, 0.05883489997358993, 0.03849379361781757, 0.020705348724732175, 0.01534575951154693, 0.0179005425889045, 0.022019575371814426, 0.07138759319786914, 0.022409713128581643, 0.04227808996802196, 0.009967993246391416, 0.04759720708534587, 0.05115710024256259, 0.08466160943498835, 0.011181314712302992, 0.021217903740762267, 0.02252680733363377, 0.029007053453824483, 0.06842721806606278, 0.01499711337601184, 0.04193968175968621, 0.03777455975068733, 0.04040821178932674, 0.039413255217368715, 0.023303056696022395, 0.020986413037462626, 0.01809956804208923, 0.05838259807205759, 0.022108434568508528, 0.028349289823381696, 0.031515779774053954, 0.02392387621512171, 0.0419220446201507, 0.034598468264448456, 0.030626868683611974, 0.02502041053958237, 0.006080680304876296, 0.05259549376205541, 0.008765332731854869, 0.025386582492501475, 0.04766819722135551, 0.006894685038787429, 0.04374853684566915, 0.06653830379946157, 0.043131927159265615, 0.03764953384234104, 0.07197745217126794, 0.03692941681947559, 0.008360614556295332, 0.049994232758763246, 0.015878019476076588, 0.014690216758026509, 0.07235283046611585, 0.025881140427372884, 0.04655863449443132, 0.039751733929733746, 0.07912655331892893, 0.018551897774159443, 0.02509849931811914, 0.01829490873205941, 0.058713610778795555, 0.064081698510563, 0.08988860005047172, 0.014371862307598349, 0.011607167398324236, 0.02282708399434341, 0.023876421437307727, 0.08426023370702751, 0.028725577249133494, 0.038069548609200865, 0.020576036913553253, 0.019741638425330166, 0.05761202242865693, 0.06455216076574288, 0.020833740272792056, 0.024603479396319017, 0.032276544225169346, 0.013954368059785338, 0.050437001773389056, 0.04943942913087085, 0.047791827892069705, 0.03913435612048488, 0.034369916465948336, 0.035595985245890915, 0.042517584734014235, 0.08701411366928369, 0.02464473909640219, 0.07550634953076951, 0.029013192870479543, 0.032198577900999226, 0.02648004247021163, 0.02168367191188736, 0.021858442123630084, 0.05412584308942314, 0.03892603526765015, 0.03946440032450482, 0.01861246259068139, 0.016734543241909705, 0.033721869403962046, 0.11106839636340737, 0.02194078711909242, 0.06528071229695342, 0.04010287368146237, 0.06317135048448108, 0.02603628639917588, 0.026072130276588723, 0.02308169630850898, 0.02590361822512932, 0.03488479625957552, 0.010896320727624698, 0.01624510798137635, 0.03890423467964865, 0.034658255681279115, 0.028194644801260438, 0.016117569903144613, 0.005866722376595135, 0.08451284593320452, 0.02474841156072216, 0.013064886443316936, 0.030885518281138502, 0.035810042900266126, 0.01604584504093509, 0.037446678907144815, 0.02413921036350075, 0.029956308571854606, 0.05320393982401583, 0.10219402451184578, 0.11505907285027206, 0.05538557568797842, 0.06142904378066305, 0.04438801210199017, 0.009033935457409825, 0.027720969046640676, 0.027925098620471545, 0.09463686088565737, 0.04910227515210863, 0.0703007253468968, 0.06641089188633487, 0.03156545171805192, 0.04489471342822071, 0.013909570170653751, 0.04525504838966299, 0.016563155368203297, 0.08838867506710812, 0.017507736811239738, 0.028308536639087833, 0.0473482165398309, 0.055015733814798295, 0.0469876218267018, 0.08332747282111086, 0.049954698552028276, 0.07024250386166386, 0.03525552870996762, 0.007487862803827738, 0.07457750718458556, 0.013520605007215636, 0.10038175925728865, 0.07875711962697096, 0.07400957867503166, 0.026415512729727197, 0.041613296343712136, 0.05620409036055207, 0.045535821409430355, 0.02533449856855441, 0.02869602121791104, 0.014607627781515475, 0.03401084686629474, 0.028267317757126875, 0.019116584953735583, 0.02778970119834412, 0.09403418502188288, 0.014330865142255789, 0.03701127199747134, 0.02178946877393173, 0.037826606567250565, 0.010893700018641539, 0.0030988796015662956, 0.04512024839641526, 0.020296304755902383, 0.027052537043346092, 0.03713653168233577, 0.09778248349903151, 0.015710676307207905, 0.012718859161395812, 0.02398935776000144, 0.05493899203429464, 0.021038754857727326, 0.01574064608576009, 0.03403423193958588, 0.08579743676818907, 0.03380616253707558, 0.02209317415690748, 0.007874996717873728, 0.010950583782687318, 0.040103107457980514, 0.012222255681990646, 0.06247726429137401, 0.07303013670025393, 0.05452225013868883, 0.011326072472002124, 0.0470904909161618, 0.021524041512748227, 0.0914152646146249, 0.014262843596952735, 0.02768204711173894, 0.04269982280675322, 0.11264865141129121, 0.1339028257643804, 0.13642970501678064, 0.18260702403495088, 0.17330378730548546, 0.16401736764237285, 0.13790101278573275, 0.1425300698610954, 0.1037812780123204, 0.14312067098217085, 0.17732634645653889, 0.1677668164484203, 0.11330744106089696, 0.16324741911375895, 0.11716165143297985, 0.18593031680211425, 0.16777370357885957, 0.10052497149445117, 0.15349527209764346, 0.11415325934649445, 0.19704587815795094, 0.18467623565811664, 0.1364125168765895, 0.16048811405198649, 0.22011061082594097, 0.14182811690261588, 0.20031052641570568, 0.08539952686987817, 0.07643214165000245, 0.1062864791310858, 0.11950249652727507, 0.17525970266433433, 0.133875381143298, 0.14658329455414787, 0.10119709753780626, 0.06910853931913152, 0.11431179693317972, 0.1879189460305497, 0.12900891102617607, 0.07907243591034785, 0.09035220486111939, 0.1484255722607486, 0.13691091357031837, 0.19898153288522735, 0.1121473009698093, 0.213765648950357, 0.1835804249276407, 0.18975420302012935, 0.08453462054603733, 0.1218032359611243, 0.151737614069134, 0.0786886565038003, 0.12965790432645008, 0.12579588656080887, 0.20866816310444847, 0.1616572935017757, 0.10045555100077763, 0.14027373312273994, 0.19208040554076433, 0.11980438735918142, 0.07645185309229419, 0.09924501166096888, 0.09297102136770263, 0.17944320396054536, 0.15951322886394337, 0.13717027934035286, 0.16387352457968518, 0.11446535470895469, 0.25994639669079334, 0.3131146577652544, 0.15784627612447366, 0.16180833539692685, 0.09937906579580158, 0.1354588125832379, 0.22423379035899416, 0.20467813970753923, 0.1091434656700585, 0.18908582482254133, 0.2765127952443436, 0.11472593760117888, 0.1168115803739056, 0.09774022561032325, 0.08547215344151482, 0.10679990431526676, 0.06746406623278745, 0.12802617391571403, 0.1647179847350344, 0.0951190639170818, 0.12431280832970515, 0.18535608745878562, 0.10669702038285322, 0.1249964747694321, 0.1114493259228766, 0.09469953525695018, 0.12864747026469558, 0.12227955376147293, 0.17540866654599085, 0.21837245643837377, 0.12197856092825532, 0.12776541290804744, 0.12223317695315927, 0.1116226841986645, 0.1721582081518136, 0.1428639324149117, 0.21327727125026286, 0.19357516517629847, 0.12894603627501056, 0.21064334461698309, 0.1126852170273196, 0.06679479745798744, 0.10917183055425994, 0.1776261444319971, 0.12536872120108455, 0.22334428183967248, 0.12849377148086205, 0.10308356271707453, 0.14795883558690548, 0.15819989464944229, 0.13437468325719237, 0.21696500305552036, 0.13091088709188625, 0.19917708879802376, 0.17572467302670702, 0.16903890209505334, 0.13776157808024436, 0.07624071949976496, 0.14436526747886091, 0.14006447716383263, 0.17536712111905217, 0.13801736669847742, 0.09378514252603054, 0.17537242005346343, 0.1302039172151126, 0.12626048584934324, 0.09322252779384144, 0.09008730266941711, 0.1634485411341302, 0.09064752026461065, 0.10666195390513167, 0.09941521580913104, 0.18043155170744285, 0.13826988986693323, 0.1267102570272982, 0.13728105230256915, 0.17335786018520594, 0.1393894196371548, 0.06728765773004852, 0.12931378529174253, 0.17141067248303443, 0.09631011445890181, 0.09144483177806251, 0.20354925887659192, 0.16742097563110292, 0.0978101952932775, 0.16950176475802436, 0.17296266654739156, 0.11910486122360453, 0.11599687291891314, 0.1925677145482041, 0.1604466131539084, 0.08816305475193076, 0.0815482776670251, 0.10937740546069108, 0.06271818027016707, 0.16012425388908014, 0.07406303557218052, 0.11579693091334775, 0.2146166400052607, 0.2248298388440162, 0.10095394027302973, 0.12630881450604647, 0.11251959935179912, 0.18816548748873174, 0.0674200123467017, 0.14764247287530452, 0.13244267989648506], [0.09608824198949151, 0.1290054971468635, 0.047741588205099106, 0.040672260511200875, 0.03765249872230925, 0.01956662516022334, 0.06813760977820493, 0.018846680686692707, 0.08807309903204441, 0.02764270771876909, 0.01422618985088775, 0.09387445999891497, 0.011245651494391495, 0.03536356314725708, 0.06044452551577706, 0.011472526039142394, 0.08219658076995984, 0.023218275600811467, 0.051293540382175706, 0.11667434984701686, 0.062470288103213534, 0.05795691700768657, 0.04623928092769347, 0.019934088450099807, 0.026726092255557887, 0.01062535704477341, 0.005738310419474146, 0.02118835698638577, 0.015475694726774236, 0.006549415675181081, 0.018308692269783933, 0.09273816511267796, 0.07782065542414784, 0.022578791067644488, 0.005794269281977904, 0.03243420236685779, 0.029010714097239543, 0.03027761213161284, 0.03447464092459995, 0.012174069888715167, 0.014027329525561072, 0.02959639848995721, 0.018434124503983185, 0.021167339364183135, 0.04366630317235831, 0.018520857447583694, 0.042793003158294596, 0.012666637940128567, 0.02691321737074759, 0.012300762846280122, 0.016233719725278206, 0.03657013570773415, 0.0475590013229521, 0.028478035746957175, 0.03495444681902882, 0.051634011761052534, 0.04726007166027557, 0.05482100910739973, 0.05369990598410368, 0.04801180046342779, 0.011641975052043563, 0.0388348846900044, 0.05528249137569219, 0.07008090862655081, 0.042433684939169325, 0.05239178164629266, 0.023445677070412785, 0.021691551664844155, 0.0020226086917318753, 0.021571282923105173, 0.07630473715835251, 0.0496184871008154, 0.05642741372867022, 0.02980889577884227, 0.03510880982503295, 0.018284847064933274, 0.052017475754837506, 0.040543193608755246, 0.024430356752418447, 0.04746637016069144, 0.0025883847411023453, 0.030723243980901316, 0.04337289137765765, 0.062223917338997126, 0.0448746420443058, 0.025419910489290487, 0.03901118929206859, 0.06290332385106012, 0.0314725236967206, 0.05471832555485889, 0.012551284999062773, 0.023908767943794373, 0.04081297913216986, 0.035989431125926785, 0.042271165730198845, 0.03195276003680192, 0.05214447948674206, 0.0361871095810784, 0.014711222320329398, 0.011924451300728833, 0.02827313990565017, 0.0769211130682379, 0.035512590111466125, 0.08944615387008525, 0.04452233712072484, 0.007052010141705978, 0.020869292857241817, 0.03453226869169157, 0.05201779116760008, 0.07297345888218842, 0.04696259660704527, 0.03176591322699096, 0.058077419525943696, 0.04001750814495608, 0.06644835550105199, 0.11264088112511672, 0.029549366736318916, 0.0010466228059158311, 0.011495215348986676, 0.014131706102489261, 0.02420952143438626, 0.0447073471150361, 0.061322404581005685, 0.046810044441372156, 0.1340846816310659, 0.035661487199831754, 0.06205677455000114, 0.022738074512744788, 0.03177721613610629, 0.06792431653593667, 0.09648586245020851, 0.06215028144652024, 0.028597438031283673, 0.022084537413320504, 0.01932559043780202, 0.06318390762316994, 0.028303324907028582, 0.03600771764467936, 0.055087443834054284, 0.022701959751429968, 0.026571246853563935, 0.05211083422182128, 0.019518918052199297, 0.03884273661242332, 0.05400826092227362, 0.02932422696176218, 0.03868982079438865, 0.03404578717891127, 0.045779438805766404, 0.009038178686751053, 0.04109596004127525, 0.022869913336762693, 0.028269071081012953, 0.04862779787799809, 0.041330716194352135, 0.03266696585342288, 0.006747022698618821, 0.04769859187945258, 0.07636175636434928, 0.05400486559665296, 0.0315071597287897, 0.013205442719481653, 0.05125524927279912, 0.03611634951084852, 0.05613877023279201, 0.06968151443288662, 0.034883041080320254, 0.035774879943346605, 0.03881180389726069, 0.024588890628365334, 0.04370538466901053, 0.05382859439123422, 0.15041807550005615, 0.08678430764121003, 0.00464616775389004, 0.03186881571309641, 0.07588328633573838, 0.06491155319963582, 0.023976186494110152, 0.039668706158408895, 0.03889214509399608, 0.05020174467063043, 0.0407159433234483, 0.010624929382174741, 0.04402009610203095, 0.07264399726409465, 0.040474726774846204, 0.057216034692828543, 0.010495081369299442, 0.02703417259908747, 0.015412101020046975, 0.033288648119196296, 0.03610391111578792, 0.03576168826839421, 0.037808405395480804, 0.07183438094216399, 0.05506307541509159, 0.00898801506991731, 0.01612174262845656, 0.02413531779893674, 0.03962661896366626, 0.06578475673450157, 0.05442054993181955, 0.012055428305757232, 0.047110339655773714, 0.01732384189381264, 0.03325175595819019, 0.042016174920718186, 0.05142416950548068, 0.04188328966847621, 0.033202247286681086, 0.05026778468163684, 0.032877546545933, 0.03496322642604355, 0.040135242452379316, 0.028299105797486845, 0.07642349562956952, 0.06417271550162695, 0.053834498176001944, 0.0011576998167583952, 0.03161524611641653, 0.015766331816848833, 0.08750180117203854, 0.04152990492002573, 0.041411309721297584, 0.07840439167921431, 0.019267083225713577, 0.01193876918478054, 0.0626672689395491, 0.06362734828144312, 0.0677273356996011, 0.024643813267175574, 0.057516367014613934, 0.08737725394894369, 0.06945449145860039, 0.06333385856123641, 0.03274406757554971, 0.041516312485327944, 0.04487722100748215, 0.02457498834701255, 0.024672115068824496, 0.04340208746725693, 0.010526572550588753, 0.038487552155856974, 0.019561535882530734, 0.044905663817189634, 0.038188058460946195, 0.003119506900475244, 0.042390098606119864, 0.02924909564171685, 0.03131338868115563, 0.05390440477640368, 0.02649477966770064, 0.03162401459121611, 0.055390611159964465, 0.02523282433685381, 0.02570032542280387, 0.018727452807070222, 0.009185919880110305, 0.010102230135089485, 0.01787454886652995, 0.015398282230307814, 0.04853838763665408, 0.04669864065363072, 0.0693435403809417, 0.029074613012198824, 0.06692291441140696, 0.0261234813297051, 0.034126651589758694, 0.006463049166995916, 0.015583963868266437, 0.04569799923046958, 0.03051528678042814, 0.0403787856339477, 0.041475323669146746, 0.019627984074759297, 0.014977885257394519, 0.014534152378473664, 0.05345142009900883, 0.04849762888625264, 0.06833503590314649, 0.01682031695963815, 0.05270933921565302, 0.055710692031425424, 0.0656364014139399, 0.06155592876893934, 0.04341103776823729, 0.05132104066433385, 0.024291519475809764, 0.06230511571629904, 0.03285996135673486, 0.016855953035701532, 0.04547876880678814, 0.025919698709913064, 0.031265405123122036, 0.02730847965722205, 0.036236848318367265, 0.026012791859102435, 0.030225346381484997, 0.04212671410641633, 0.07389595586573705, 0.05389727644796949, 0.06630059389863163, 0.018205882552138064, 0.048713972355471924, 0.04433671856531873, 0.03493287629680708, 0.008062686792982277, 0.09540131009998731, 0.07801514264428988, 0.035677094565471634, 0.051803473761538044, 0.042651126786950044, 0.010125417611561716, 0.012302574614295736, 0.05936841138463933, 0.016404682719439734, 0.07063286611810327, 0.043590956629486755, 0.05084285636257846, 0.08758803873206489, 0.0007248189922393067, 0.04580589637043886, 0.07955148481414653, 0.02720003147260286, 0.016305131030094344, 0.04733619003673084, 0.029822716423950624, 0.010039512162620667, 0.02170704956370173, 0.01595611567609012, 0.042264430740033276, 0.020950736143277027, 0.06902328881551512, 0.038236646869336255, 0.0074152793695247965, 0.025004196468216833, 0.101578709873138, 0.03463425091467798, 0.02544067392591387, 0.05432613019365817, 0.052635755273513496, 0.06962476240005344, 0.012975653389730724, 0.01809587214665953, 0.03940363327274099, 0.0319542257784633, 0.03928979152988177, 0.027688973204931244, 0.02776232151518343, 0.021664364940079395, 0.07582548045320436, 0.12237913513672538, 0.27346286515239626, 0.18028549704467878, 0.13960339565528557, 0.10413949043140747, 0.0861844964674674, 0.14888444216921926, 0.15696246729930863, 0.1346797653241083, 0.12629104749066755, 0.15735935303382576, 0.23740272590657696, 0.09776966660865583, 0.10484825630555861, 0.15233850135700777, 0.13985945144668221, 0.21788740355987102, 0.14225684077246115, 0.22624668781645596, 0.23319648520555347, 0.14958735991967842, 0.219445409020409, 0.11418215115554631, 0.07633687957422808, 0.11167599266627803, 0.09141640752204694, 0.10533105305512436, 0.1135107598383911, 0.1076996025221888, 0.13500914530595765, 0.10629701762809418, 0.12768689368385822, 0.18194663134636357, 0.12930370692629367, 0.0997182124410756, 0.15599418722558767, 0.12123588632675819, 0.15485660842387006, 0.1389862404903397, 0.12946381786605343, 0.15612151008099318, 0.11719077330781147, 0.17106906190747395, 0.15134883258724585, 0.13556087273173034, 0.12588825426064432, 0.18359350156970322, 0.15259320643963292, 0.12096877253497951, 0.33403897716198117, 0.09135817861533724, 0.10208881765720434, 0.13901282422011718, 0.11936877635889687, 0.1313800283242017, 0.11838386475574225, 0.12476056086597964, 0.19877579470630735, 0.19990561064332724, 0.10295767962816171, 0.12455308606149629, 0.1234743076201994, 0.15846038848394528, 0.24297500815009698, 0.1652571847080253, 0.19926378648960963, 0.1414452726021409, 0.15290266717784107, 0.06606214185012504, 0.10380740903201513, 0.2019678460783325, 0.14803098718402907, 0.25775504240300506, 0.13389766041655093, 0.12449400368495844, 0.16974225029116496, 0.12966108071850613, 0.09492378259892575, 0.18950929428683594, 0.13206590636400506, 0.08168683663825504, 0.11371231972589158, 0.15962797973770648, 0.1407409892999567, 0.11697347988956608, 0.111851065303199, 0.1258568762568757, 0.1700914159300737, 0.09194789658067748, 0.15745485259685665, 0.11607641630689614, 0.15247355739120394, 0.13472335907863453, 0.18305885838344693, 0.24757289502304047, 0.1053593066171743, 0.18307212798390538, 0.1463975349906832, 0.09088684062589891, 0.08214598114136606, 0.1400616718456149, 0.1971441533532925, 0.14147013454930857, 0.18541206023655832, 0.19763624179176986, 0.0753666550735943, 0.1583889641915448, 0.2048210328212008, 0.15831607044674456, 0.18863369361497462, 0.19512257276801392, 0.17840113956481218, 0.2357783427578397, 0.15358997014118358, 0.1680227238102816, 0.15995011635823175, 0.12865858763689175, 0.09239636157872155, 0.1189014311239589, 0.09257131547201425, 0.1389344534254633, 0.193755907821469, 0.1570981615805067, 0.1431623796815984, 0.18336677545448765, 0.12064893657225184, 0.10918043946730904, 0.10266649056575261, 0.12481513840612024, 0.1744546357076615, 0.16248449130216613, 0.13515105878468603, 0.1980685131275095, 0.10609372111503035, 0.11246396054048091, 0.1079162502719555, 0.09175735016469844, 0.1301110745407641, 0.11389967490686104, 0.16928213357459754, 0.0497429786628345, 0.1526463293703273, 0.06433634422137402, 0.19134701520670205, 0.13110540399793535, 0.08664430148201063, 0.10394436496426351, 0.13785072485916317, 0.1812628164771013, 0.1299108876264654, 0.11928897321922705, 0.23891881486633793, 0.1287899329327047, 0.20068100653588772, 0.10824222379596904, 0.15475448890356347, 0.12370803960948251, 0.14866148616420105, 0.12026903859805316, 0.10657451406586915, 0.1555892120813951, 0.13616487703984603, 0.1212665370258037, 0.12967164890142158, 0.1301215833518654, 0.15483275579754263, 0.1490472990553826, 0.11482046495075338, 0.1028242488973774, 0.13586675631813705, 0.13575452874647453, 0.12824387551518157, 0.2393885943456553, 0.10276287328451872, 0.09906006845994852, 0.2891627617646009], [0.0218210137609276, 0.0398717874486465, 0.034505569929024205, 0.07123603179934435, 0.03085750406171428, 0.02655977881659055, 0.04009006421256345, 0.03539364610332996, 0.05964981151919346, 0.044075163459638134, 0.05476262806041632, 0.022917622300155926, 0.03202284104190767, 0.07493318145861849, 0.03347333156852983, 0.01599083891051123, 0.03173257224261761, 0.04149034844886046, 0.022831792921351735, 0.07983908930327743, 0.04291455952625256, 0.027927230439672712, 0.05865319995791651, 0.043650528823491186, 0.024614691392343957, 0.035794665600406006, 0.07021173441899009, 0.08715462448890321, 0.036125982587691396, 0.06630484640481882, 0.02147620267351158, 0.03644562930276152, 0.02884044501115568, 0.023819190719223116, 0.04289609860279597, 0.030440940281550866, 0.03852778398140799, 0.03744550631381571, 0.01528016942756949, 0.010813651970238425, 0.036608308073482476, 0.06411774462321773, 0.08564623902202584, 0.038598384489887394, 0.04715871655207593, 0.04782355099450797, 0.0017162926883429463, 0.015853285549383145, 0.008890306689863792, 0.07410537509713322, 0.07120377063984051, 0.02983890266477829, 0.06857522457721643, 0.011301760641799774, 0.029508374209399335, 0.03570417553419247, 0.024731440498726442, 0.07002601938438602, 0.027259137968940195, 0.05706754207494669, 0.013838131035299739, 0.009298133536503883, 0.06435347298975103, 0.05575280520133674, 0.03828148001048248, 0.06039601503289305, 0.035994125209981576, 0.053278373525245115, 0.11786845061578788, 0.016892932399059646, 0.07653102540643886, 0.024883278347260784, 0.035189284608350135, 0.03944513788155746, 0.02781027909804834, 0.01024518354824977, 0.0758688960922882, 0.04824679039302282, 0.059178803785471246, 0.053727109407191165, 0.05502774176420644, 0.009892266352835577, 0.02483187534380704, 0.04594796941091772, 0.03640944960352499, 0.07830835034837946, 0.06306337541900575, 0.022345992329064757, 0.058890097207040526, 0.029144400868972298, 0.02102739628753625, 0.043843528037541546, 0.0955468081519939, 0.04433382418937981, 0.007487614184356062, 0.027367035108909477, 0.05096104709082283, 0.04206759462249465, 0.029693434298678767, 0.07008162108832039, 0.026979140493494924, 0.05424081289675087, 0.016093761805677786, 0.027297410524624866, 0.04289258082280867, 0.0480157152924221, 0.01740366729791276, 0.08820712348097004, 0.0405914072325686, 0.06346862515783869, 0.0533352554339217, 0.03656395732832607, 0.014092505862208782, 0.043337194074410945, 0.020250725756341126, 0.055415996321244165, 0.0935781946463976, 0.045021776531939395, 0.05312006971507799, 0.08629306525108404, 0.02440284162730677, 0.04511466744588688, 0.029800017837260384, 0.016345976982847787, 0.10169412125833333, 0.01372389688185649, 0.02195442037191242, 0.08375398509087972, 0.03403445458388887, 0.03556872616172768, 0.01131914823417901, 0.02398383803665638, 0.005807494353575748, 0.015878073281783145, 0.03581203185603954, 0.04277782252756879, 0.028232605654920917, 0.02576720406068489, 0.027443804719951004, 0.0164145607050159, 0.02864313020836562, 0.04322181979659945, 0.017652822971285786, 0.017467393663537223, 0.09702256880700588, 0.04826849821256474, 0.11401826268411241, 0.028241541112947743, 0.09281639489927329, 0.054150875730556436, 0.028188086071168073, 0.056216109442175366, 0.01938860248628771, 0.017188835954584647, 0.04860844637732953, 0.02079758469335502, 0.02257357376947766, 0.014209925684554037, 0.015353199542005314, 0.053605430584866554, 0.014041280974197434, 0.06404732965165749, 0.01697527553915279, 0.005509250249815523, 0.0198243377963081, 0.0023605704518558923, 0.027489354033605196, 0.02204365435318323, 0.009855774951574858, 0.05536507385841105, 0.06430869922041893, 0.036745590550708584, 0.0543598311196547, 0.0165174743233365, 0.014809131080255611, 0.03156705846777186, 0.025835262713371776, 0.09811580428504385, 0.005114563591632759, 0.05897798233490903, 0.08505648394930176, 0.04655651566281449, 0.04263232818630058, 0.08504343699314632, 0.03525518361129798, 0.040820218782755546, 0.032361442208639346, 0.04089496418600902, 0.09956368987332098, 0.02901594438299071, 0.05776568410510663, 0.1109176067984663, 0.04827450589800719, 0.005995073570375098, 0.027244118755334057, 0.049088174346252345, 0.0356939227640396, 0.08402585604926571, 0.11308122702757828, 0.0513650945504196, 0.007507749114665785, 0.06935674318810925, 0.020281684446672443, 0.028926921913807746, 0.052957179432269186, 0.014854962410026928, 0.02252433969260892, 0.0425617684959434, 0.027554696425795555, 0.018354620078753214, 0.04527453347691335, 0.01662384263909189, 0.026243416104989592, 0.016874859247764107, 0.018241264442622196, 0.037640090013155714, 0.04990159046428744, 0.048159476718865335, 0.026766348200908396, 0.027713644049072172, 0.06577134612598456, 0.053492624138016254, 0.029940927561256103, 0.04245788266416639, 0.028854829688498285, 0.07382910320302472, 0.056373775005340576, 0.036891114577883855, 0.027159998171555344, 0.04442972822289448, 0.016293429216602817, 0.003499919739624602, 0.04013585843495093, 0.0583971144806128, 0.024107446442940272, 0.09153449806035496, 0.05534349962545093, 0.025531932114972733, 0.06905744987307116, 0.02753452670731349, 0.021258636515995022, 0.08342272747540846, 0.019212963961763307, 0.05368894817365799, 0.07655415814951994, 0.04312958939408418, 0.04788152757100761, 0.02110888595780125, 0.014561438365490176, 0.0185413722647354, 0.038739949159207754, 0.04857157277001534, 0.05935644054261502, 0.09089541985304095, 0.038030084906495176, 0.047660775744589046, 0.07582473830552772, 0.02734610654442804, 0.10852564999368042, 0.05461001652292907, 0.052882690069964156, 0.05988812627037987, 0.04282674490241334, 0.012089087485946948, 0.029439888821798377, 0.04177330338279717, 0.03512620576657355, 0.029790800363116432, 0.08506435071467422, 0.029128413152648136, 0.03911841478839051, 0.03636327317508403, 0.02853437403246062, 0.04835561521758791, 0.026683248070185073, 0.07940445051644929, 0.051303488871781155, 0.030383319935936015, 0.04704417719040066, 0.047726852862979285, 0.020337909554655198, 0.09898664779029787, 0.032207105177803896, 0.02131835528416559, 0.06346420937916264, 0.037463881890289485, 0.03966383766965009, 0.026042171630251687, 0.032744672425906174, 0.10463477010489441, 0.008782271324889734, 0.015477360848308308, 0.06068207214411814, 0.0820712765562348, 0.038082265309640206, 0.09219023006153293, 0.02319697967323009, 0.05889741107239388, 0.030660942538816016, 0.022837999131297693, 0.002708851543502533, 0.011714193442458054, 0.029209795211500023, 0.04986239022400696, 0.09038204661919735, 0.04856257794017438, 0.018900373215728905, 0.018831802481145132, 0.06741668752511032, 0.025387090863659978, 0.04423327431140933, 0.04492422493058257, 0.04704517537902575, 0.0346799931867281, 0.03689833567477763, 0.058743504487210885, 0.03533733564836439, 0.06269941877690144, 0.01802130300347926, 0.033032280625775456, 0.05671808699844405, 0.02381210320891114, 0.07548821144155227, 0.03578319199732505, 0.06640890293056145, 0.026856784461415373, 0.014252344990381971, 0.007718073302385164, 0.02780971506581409, 0.0739351857919246, 0.07425122195854783, 0.031663886475143954, 0.044593282727873884, 0.06916984071722254, 0.03755923673452344, 0.1324360747821629, 0.0819538020004984, 0.05634722096147016, 0.04619777260813862, 0.07858808807213791, 0.010971090250677662, 0.027892609250557143, 0.05173422396183014, 0.04720836994238198, 0.021279596621752717, 0.009836851113504963, 0.03175114077748731, 0.0597251617728034, 0.044386984227458015, 0.01705639599094866, 0.011984977154497756, 0.019121199256915133, 0.1985945474007167, 0.12483876838814467, 0.12383780413074419, 0.22997264022706077, 0.14498944336082786, 0.1486514523276128, 0.116630808042828, 0.16149795439559966, 0.1549464973504655, 0.101209150016075, 0.1085710249026306, 0.1115423021838069, 0.19688294705701992, 0.27539345843251795, 0.10263396965456195, 0.1782045149593614, 0.24614433496026322, 0.11084594501880929, 0.17005022673401982, 0.10847328405361623, 0.0808504139422439, 0.1606537465704605, 0.19116517418297008, 0.14092136087128893, 0.17720179923344404, 0.15311284339986742, 0.21224574535153806, 0.09160151399555616, 0.1340938248904422, 0.1334922548267059, 0.09857969111180864, 0.113830588379642, 0.08673447984619997, 0.2065111108822748, 0.0720670961891301, 0.10714207150158472, 0.11405679499148391, 0.05268197252007667, 0.08359788917005062, 0.07631719781784341, 0.1331387847312726, 0.13405851350398734, 0.11939556789002381, 0.07235812197905034, 0.11590201160288416, 0.10813844186486676, 0.10946246300591156, 0.17770791426301003, 0.08298730201204307, 0.13983300130348653, 0.14261984004406258, 0.150882214657031, 0.16815356444567442, 0.1863216661149636, 0.10348455252824351, 0.07261225560796447, 0.18149858195101842, 0.13933671230915934, 0.11705688244546764, 0.13764029630692676, 0.14285423996625468, 0.1507853643852286, 0.18219657184090465, 0.1681345803081058, 0.15525733848335221, 0.20968030410585925, 0.1597279915586114, 0.17227433942025527, 0.151685337186791, 0.10078393650474027, 0.22040741052478552, 0.12955623009474948, 0.22182942484505475, 0.1397186066606082, 0.1400956473662518, 0.10017120453994721, 0.14931482844986022, 0.15493125363718718, 0.13906257780035958, 0.15008839865913615, 0.1480870193336159, 0.1291821282939054, 0.2282482897862792, 0.15435657900525257, 0.12261706768185832, 0.2678010205272585, 0.11843620100989938, 0.07274849165696651, 0.12511656910646707, 0.11163847710122354, 0.15649503300664946, 0.1390068425098434, 0.15397014271002263, 0.09192703480948694, 0.11678328228299506, 0.1983689790358767, 0.12560398201458156, 0.16164213884621859, 0.07629577201441862, 0.17422949778847396, 0.22393474937416613, 0.1254948863061145, 0.08927656570449471, 0.18056460394291207, 0.14832204265985638, 0.24479139974573627, 0.15140844188863412, 0.11477793988888152, 0.1023792868363671, 0.17913847812451422, 0.23270007746759802, 0.18764432170428336, 0.11980650248005986, 0.30332115828059614, 0.14743551757419482, 0.09810125076910481, 0.307009958778508, 0.20733952580485493, 0.10739876553998329, 0.27868998935446143, 0.14113233861280605, 0.14756595744984224, 0.17897250421810895, 0.10373033699579537, 0.17335582670057192, 0.09445542804314755, 0.11915192822925746, 0.16883239208254963, 0.24889501626603305, 0.10855705026187934, 0.1227082776313182, 0.09730384277645499, 0.1135913644975517, 0.08532428793841973, 0.11271397524978966, 0.1432696497067809, 0.16325305943610147, 0.07745220878859982, 0.14876687113428488, 0.10421032100566663, 0.11263121094089001, 0.11562299376237206, 0.10244571647490375, 0.09450099591049366, 0.1815951056778431, 0.15460484224604443, 0.23790015780832618, 0.2303681752528064, 0.19046146975597367, 0.08909317359211855, 0.09907733081490733, 0.21219179121544585, 0.09416716304258443, 0.17228339362191036, 0.13847470778273419, 0.1523377888952382, 0.12103182540158741, 0.12276879977434874, 0.12021080226986669, 0.29335556959267706, 0.20390593504998833, 0.11033387796487659, 0.2501548267900944, 0.11855884091346525, 0.14691328309709206, 0.09349180865683593, 0.14067241485463455, 0.16341754904715344, 0.1582189233158715, 0.12420957558788359, 0.10091074727824889, 0.16793405200587586, 0.19004404137376696, 0.18896017922088504, 0.14613436942454427, 0.145924222888425], [0.03905354365997482, 0.08252331870608032, 0.06662941726972349, 0.04743764533486683, 0.024556601638323627, 0.024397876659350004, 0.12856385990744457, 0.06540084374137223, 0.03446010596235283, 0.025603705216781236, 0.02547251762734959, 0.08011308280401863, 0.03614221706811804, 0.03827169108262751, 0.009643445573601639, 0.03749250652617775, 0.03277178308053408, 0.02007738788961433, 0.042257461973349564, 0.05503809101355728, 0.060099434267613105, 0.048301453280146234, 0.08348499366547912, 0.04442427714820951, 0.033657306266832165, 0.016287915059365332, 0.033049984558601864, 0.0313486072991509, 0.03329366503749043, 0.04887584218522534, 0.04038996608869638, 0.05260923833702691, 0.027674764787661843, 0.013754052197327837, 0.035527726213331334, 0.03477699188806582, 0.05627050886687357, 0.0629127342836, 0.014727554207638605, 0.013899348014092539, 0.052014262255397625, 0.02915405621024547, 0.04081103099451866, 0.010986327470163815, 0.02485371303919237, 0.029913614671386313, 0.07322074990952387, 0.07242504143505357, 0.007224703731480986, 0.03354330867296085, 0.016688832511135843, 0.020405305840540677, 0.020576007227646187, 0.009993855237553362, 0.03596888476749882, 0.02875491620216053, 0.030986739802756347, 0.014086247701925458, 0.01311805761361029, 0.038544267081306316, 0.027547868667170405, 0.018986716531799175, 0.06701926002278924, 0.0356448111415375, 0.03197341771738138, 0.03076072800467955, 0.00739282801077934, 0.022814031472080387, 0.03478178245131858, 0.0228461423466797, 0.057131782377837226, 0.003750744317585486, 0.07785227833664976, 0.039928160986164585, 0.025885385512083303, 0.028854517986474093, 0.047339960146928206, 0.02259622597193811, 0.03332190746732522, 0.043503546476131305, 0.029270504746818915, 0.021828650460520294, 0.007085371071298141, 0.02129457687260583, 0.05490964380442165, 0.019205510943720583, 0.016254130641755182, 0.04913427655992564, 0.030485250208585057, 0.02459413019096246, 0.018573368106444832, 0.041272613452747464, 0.046228189530665986, 0.051325979657121934, 0.07122229464584962, 0.0357774255098775, 0.03171141361235641, 0.030814522579021286, 0.05955374792392831, 0.025555265237926506, 0.01837363204685971, 0.02735973052040208, 0.019190630882803816, 0.14747366396477446, 0.023414781462633982, 0.05434817940113135, 0.015698892857471947, 0.008959668739407789, 0.012363441855995916, 0.014508904514514143, 0.030592358816647902, 0.07367474390775897, 0.02794473028188804, 0.005384056894399691, 0.061005570605630055, 0.03011101853189757, 0.047398266979143955, 0.07890039865742438, 0.03126291521766689, 0.07653104767086916, 0.04489348146307748, 0.03958439076086506, 0.029102760818204843, 0.07013978320173919, 0.0020004184762001387, 0.004659979122152436, 0.06653720542090014, 0.032260031439363956, 0.023003423848422244, 0.018939220935862977, 0.042910377524094656, 0.005854408755112672, 0.04906551286694594, 0.09728628356242552, 0.03572963862097822, 0.027583443516050465, 0.04143777841818519, 0.02670140100235585, 0.014351550653373124, 0.00600780789682176, 0.05105811629618984, 0.04041914733534213, 0.035668901255121455, 0.07163264293922111, 0.021859395783394575, 0.007072782391333021, 0.0712465999822598, 0.015494009076064685, 0.058006956314784475, 0.020374848099891096, 0.010490762069821358, 0.028837352110713255, 0.029412607473204844, 0.051881592225981876, 0.030280649370979518, 0.011151376475027064, 0.017527101299492642, 0.01447667675165576, 0.018789565001497976, 0.01760832379659405, 0.009680664279585471, 0.02659093417605618, 0.03398917986487504, 0.022768504422856495, 0.006282607091634418, 0.05085120181320235, 0.12391590033075772, 0.06940398088772781, 0.008184674534277292, 0.021482189949892927, 0.04732274232083, 0.06675469179754145, 0.07451422425219789, 0.01704116897599306, 0.047894411254674196, 0.012889021563751157, 0.021322848988347687, 0.08061694912612438, 0.05108425844809972, 0.03446805065323133, 0.07380116876447573, 0.04528932448010892, 0.05562926358834375, 0.09909360611345619, 0.04433664806128945, 0.003855087034025928, 0.023590373602928594, 0.03973668317485135, 0.05442552603199147, 0.041321661992697045, 0.0292620312757208, 0.03452957469562534, 0.027110047922178637, 0.06046798109309748, 0.02289577718329383, 0.044974371849093586, 0.05236150202108547, 0.01649513196753105, 0.07796486956067383, 0.06445425664423965, 0.03430418815696612, 0.04521155853581149, 0.05066513054771349, 0.06064216315280646, 0.006589949925910332, 0.0633303853101097, 0.03143265923426952, 0.03618578484747559, 0.03568477950466331, 0.04757207425427623, 0.05983478811685927, 0.005087972440378508, 0.03354904547450133, 0.08295767547679134, 0.042554146639304236, 0.03740322616067715, 0.008165926028596004, 0.010725781685323454, 0.04664758831495419, 0.04014748788904399, 0.017880281957332045, 0.03336707828566432, 0.04156588052865118, 0.020598650153260678, 0.08511918800650164, 0.009587602671672357, 0.012527012131613446, 0.018087226126226597, 0.025459279568167403, 0.006804124932386912, 0.026971811785188038, 0.004725195349237765, 0.01022475593345007, 0.01461591942643281, 0.0019368134053365793, 0.06338443592539988, 0.017992426037380937, 0.03398611479497049, 0.07508138092816807, 0.01163298578831018, 0.04702150086814072, 0.02552304489654489, 0.028194860024086665, 0.0472274208732415, 0.04985834180843085, 0.05603940779110417, 0.01187199259220506, 0.05674913845723495, 0.01178252205136232, 0.0095505221906933, 0.020877964852843434, 0.02014755053096451, 0.04356273275334388, 0.028145275282440707, 0.04882788831309881, 0.0354142629657872, 0.07350025014602579, 0.04981100762961432, 0.009622538345865905, 0.015901449078228325, 0.06741047574905679, 0.02038709539192496, 0.023918011393107008, 0.06698858705931343, 0.049845458124764264, 0.010611959423840744, 0.02346079832932446, 0.029204919301264454, 0.03341353301948402, 0.016150276351254433, 0.032836134705576114, 0.03741530832485296, 0.06521159608382732, 0.06805091208661906, 0.04818818670173641, 0.024666777171660215, 0.059437913514557295, 0.039930491329869255, 0.019155640475219116, 0.06399314544978552, 0.05889513638976496, 0.06599239481147379, 0.06507959027658217, 0.007296766270883381, 0.047325098639703356, 0.03809130095760338, 0.03548184293322265, 0.13028412853600457, 0.04419043012603652, 0.02320192794286413, 0.08009484081412666, 0.028064653924957383, 0.04352872012532316, 0.07290567111340351, 0.0313287993776612, 0.0030559405604435597, 0.055360821352223866, 0.031793172311154194, 0.016600721028225962, 0.030733953171875328, 0.06243421230465174, 0.03606674807087984, 0.030223418652894907, 0.026820775456144474, 0.03647263605671469, 0.01645695032493677, 0.020794454685528763, 0.030866244705975987, 0.03437746039708145, 0.045025060535408556, 0.04958597732183989, 0.03629884362453595, 0.021697759730159305, 0.01957483145815786, 0.02754834549705265, 0.05572190959355794, 0.0511635161092272, 0.05807526729768142, 0.026520246465224773, 0.012830795440095244, 0.03999814922281075, 0.057826718330034055, 0.09477447732933797, 0.04479453091335017, 0.08753109374083579, 0.004111292182642501, 0.008053305118664866, 0.027318893844494596, 0.03227847380912863, 0.040158067204174586, 0.02799012559989933, 0.009724038172862493, 0.04978033095540013, 0.04713206231826916, 0.0321746584813809, 0.05045789323048666, 0.024117441316775512, 0.029257513451739214, 0.04539802313956898, 0.055749435850884765, 0.011855197790282546, 0.05740435837651603, 0.06550663689267822, 0.054799828212708235, 0.02389662084169686, 0.051271598786115646, 0.03726973976881709, 0.017280626634601504, 0.021014091435063165, 0.03263602571678348, 0.057831445810734294, 0.018633563704497647, 0.10951871037832461, 0.1502206493751146, 0.14559272036422044, 0.2119361807126552, 0.15055565483635291, 0.1017022477753926, 0.1497652378748171, 0.14672557910671458, 0.12977758306078613, 0.09002254286315292, 0.14370849647093564, 0.12656248058192432, 0.11790094926254824, 0.15362789388746023, 0.13750135141890496, 0.11159961824887432, 0.13162153802113608, 0.15403053868794814, 0.11408480364480056, 0.24404597177635878, 0.24632720014778897, 0.15255347185302526, 0.20456962287425995, 0.11595187650527805, 0.08905304566724226, 0.08796562120551243, 0.14618707675253972, 0.1832525886129588, 0.11843317304737866, 0.12653473910177127, 0.11393918684916571, 0.17966623418033123, 0.12719591846689582, 0.10452303235069849, 0.09802260537981056, 0.13370274275075644, 0.21218373149167746, 0.15830596239538863, 0.14292281441157684, 0.1811984574305825, 0.11781779903685674, 0.18473630509106442, 0.1600459573091939, 0.09249540118617006, 0.12350354823865928, 0.13221923407400027, 0.1791109296027571, 0.17487103992607445, 0.19122847937978804, 0.14383893634658307, 0.14161676808726043, 0.07246027118526399, 0.12001048176898621, 0.0931584210775327, 0.14043359173228964, 0.1102816678758245, 0.1367334957467392, 0.11365472164470702, 0.07435548628563993, 0.17115996015490964, 0.11197784639080055, 0.11459830304374918, 0.16501846548635513, 0.23290640936465934, 0.08561572190956213, 0.09615277172997594, 0.10405282984720543, 0.23022776091238484, 0.08214768065954559, 0.10450830071931705, 0.09068935512914322, 0.23600502434419468, 0.16642480564769357, 0.1638689826359041, 0.09569111134624109, 0.13381526718148962, 0.09524887296720408, 0.17024648026563227, 0.15603567328071222, 0.08952502932515927, 0.1673914529965259, 0.15803390590008348, 0.08292403392260894, 0.11305027946946211, 0.1681093918159604, 0.08741966026718728, 0.1614440744742751, 0.26297563570551574, 0.20018529641674832, 0.16164467699127272, 0.11520149098942056, 0.12639528955332935, 0.1196052691375371, 0.14184382074745372, 0.12563427648274228, 0.17252649151487276, 0.15845636604353786, 0.22921931580640376, 0.2430922377971001, 0.08032486206502654, 0.09677728157839738, 0.12664389418205246, 0.1401820927276276, 0.19912303076125681, 0.11669049898046069, 0.24476831895299256, 0.13194147788453847, 0.16175479686353356, 0.13035577547270805, 0.15504337730817497, 0.15541706350632012, 0.2768632076913491, 0.2333735319552943, 0.12275982720893808, 0.16865213925484568, 0.13212443212978542, 0.12320798792643473, 0.17766429082257673, 0.1358954922761768, 0.18369021825492382, 0.1576916125486605, 0.12227355720824562, 0.10541493800701573, 0.1056655464344658, 0.166215653589461, 0.20022335374960676, 0.19827331620035693, 0.1658536636386998, 0.11877948141773231, 0.11334004360833205, 0.17541632551001385, 0.1528253947617486, 0.09581133184838109, 0.17862645559944212, 0.12623287795577198, 0.0996286871668417, 0.12616969150258228, 0.1432629703776911, 0.12597422464750707, 0.25133145740255713, 0.15058378223329782, 0.2136450054240413, 0.10898576671024784, 0.10104659741045907, 0.13512805220670998, 0.090366454096511, 0.20366708224173635, 0.10156210060813464, 0.11796658480307087, 0.06855721265310422, 0.06075524419429712, 0.10434191121021286, 0.1646007105591707, 0.21034366538515314, 0.11614182920311578, 0.08345029084011912, 0.18105848837876692, 0.1869178778724745, 0.06885226088343188, 0.1343503556563519, 0.09588827771949582, 0.14486575702903792, 0.1535138554754667, 0.15119131916435435, 0.11637819581665099, 0.1747214823262766, 0.28812802978791296, 0.23479959840187803, 0.1956961935502477, 0.09890636225463822, 0.2529721678001806, 0.2266244261409156, 0.1708452746970579, 0.07264783416758291, 0.13266738737002015, 0.17376151430653408], [0.04373892974399496, 0.07686191194807179, 0.022341320509440266, 0.02549680255469866, 0.020860305448877625, 0.15270610194420442, 0.01591797856235644, 0.04925345434457995, 0.018560963108029682, 0.03348038197145797, 0.021141907818673644, 0.08220971678383648, 0.025122878869296983, 0.052116073784418404, 0.009258976897399407, 0.03430472621403169, 0.038399039913201705, 0.08534818509360775, 0.059939794591628015, 0.06691435744869523, 0.00914919748538523, 0.0298489476335817, 0.033356354251736775, 0.047985309502109885, 0.02915288361691637, 0.054944157382124104, 0.058077957583009265, 0.04010973483673297, 0.04369231544842478, 0.033860884796013124, 0.051688819366972893, 0.01432436021786998, 0.0766780374397058, 0.03284175276348833, 0.014870878694637213, 0.03754694676899817, 0.018609052422107197, 0.06037892337189987, 0.040346543028135784, 0.016897771201911382, 0.02002868444833439, 0.040495581124559976, 0.0620835623703897, 0.03488967216981109, 0.019142120399919804, 0.05015979848394636, 0.02996381910634227, 0.0539854918315541, 0.11537987360497937, 0.03483174383291043, 0.008797733044048073, 0.06878862914163619, 0.034996378162759356, 0.045134401152608916, 0.060494201170513406, 0.06793345979531296, 0.06281036985456012, 0.03388271878066007, 0.02485025834175758, 0.0341122650570469, 0.04767129568790551, 0.01166495751022012, 0.04534651066933293, 0.03230984810215887, 0.0773153493355494, 0.03350455743202474, 0.022635956847807392, 0.01088363185772323, 0.04822060000151396, 0.02670853675226681, 0.050297763737034984, 0.03550025932781864, 0.040338854378205724, 0.018541331446613185, 0.02889682411478134, 0.03351487699546851, 0.03609808525652625, 0.040670045200386085, 0.06074383738450706, 0.07431210033246316, 0.0362059007602511, 0.024190342483052518, 0.09386952471686527, 0.01750653453200357, 0.05777734324510675, 0.07656513451365754, 0.023744667960272636, 0.02994761616719188, 0.027767650135501754, 0.032223766393144615, 0.06466968727181666, 0.03279720534919761, 0.04658544457925018, 0.03998078296717722, 0.03341669085784815, 0.018427975810482167, 0.01928228055476211, 0.08865826021065004, 0.03518299119605217, 0.0604789092176361, 0.03232374852814246, 0.008246827546827262, 0.028251964577066246, 0.039318924536928535, 0.02868796706025023, 0.05234247335465625, 0.08314183942275122, 0.060033561239833944, 0.0007150563294544554, 0.019499074878694955, 0.03686489078972954, 0.008597518299211515, 0.08062152075581253, 0.03897476468409877, 0.08621286135166883, 0.03546849540725816, 0.04118403070606291, 0.12091271069948561, 0.06662143918219954, 0.023889533331384882, 0.04535641834081616, 0.07515681281802244, 0.04110363755899016, 0.03354032523930073, 0.0748869011295028, 0.0622954974824097, 0.022060515948396642, 0.01935621701704804, 0.03464254070422612, 0.06994301016675308, 0.056860987533582374, 0.0687287600885611, 0.11325131985358894, 0.055521941612823866, 0.005744645113736624, 0.030731743427168112, 0.05141468485817313, 0.04706240062660072, 0.047298655917984433, 0.055322467160294764, 0.048045627554529347, 0.01998959924094379, 0.011309567107673502, 0.0665648355789017, 0.007284617313416675, 0.023685348096478265, 0.05828008521348238, 0.06989943125518039, 0.05328706778527703, 0.018207504144811537, 0.0465295126195997, 0.031055188082973473, 0.023550768892164342, 0.06906188049470074, 0.09775797036127187, 0.0465462220745394, 0.0761725458141882, 0.035044424803345464, 0.04288951575290412, 0.022578132411581464, 0.0728191812231671, 0.013602428643935127, 0.03913397391443141, 0.040277838706970215, 0.07097160458215512, 0.02910124498157529, 0.03280666773207486, 0.03872413028148003, 0.022773922100896016, 0.04027525974379387, 0.02884599998651538, 0.05380430018703919, 0.04820047666726168, 0.005228755999269197, 0.029081002903694753, 0.07025344311841764, 0.06171130109578371, 0.052535628419718705, 0.007264596024469938, 0.011154465664731106, 0.08111224364256486, 0.06503235999844037, 0.05867326763109304, 0.032901503072935157, 0.04248701938195154, 0.021358125122787897, 0.02821197580487933, 0.04106553198653273, 0.04591939301462844, 0.10136589160538279, 0.046289468664326705, 0.01718991763482336, 0.009455227645958075, 0.1262320764362812, 0.0383105573564535, 0.050295296096010134, 0.039446247392334044, 0.03281887235061731, 0.018825870865839534, 0.06326277565676719, 0.036295823083491996, 0.03725368340383284, 0.06623017892707139, 0.02348117770452518, 0.02464904169755755, 0.03932132538466249, 0.09237054226105101, 0.029177077631175052, 0.005179934278203291, 0.014813142388447886, 0.05909662206249777, 0.04258665270754136, 0.00718938909813005, 0.024542014725739136, 0.013705670662602643, 0.024740934422879945, 0.04684595325670671, 0.041498998180031776, 0.036782382521778345, 0.018593073982628994, 0.08315860453876667, 0.0291192142321961, 0.05157884050277062, 0.05865931525477208, 0.026771897610160522, 0.05798791280540172, 0.03441234875936061, 0.025543902956997044, 0.03622376796556637, 0.03252786882512737, 0.08557763489079662, 0.03823918872512877, 0.07884420323534869, 0.02361180497246096, 0.03179276784067042, 0.01029858571200748, 0.036193859414197505, 0.030613638045906555, 0.01570737560541602, 0.07818252663128078, 0.011606430816755164, 0.0435905484482646, 0.037795484604430385, 0.02078386052744463, 0.06893873593071476, 0.0785087895928882, 0.11064948368584737, 0.04414155970152933, 0.02115338884323137, 0.030464605515589938, 0.06868608659715392, 0.019069319423579145, 0.039867364248493686, 0.0148431502020685, 0.05775281155365519, 0.047070519722183235, 0.01811894922866486, 0.045056215894874185, 0.06805848941439763, 0.053734085595351644, 0.045511686766985804, 0.026701775786932558, 0.018328396290598903, 0.05052333952335175, 0.04602854067343287, 0.06521904724650085, 0.03960539725085255, 0.02414330516330665, 0.05830591937410645, 0.04745415812067222, 0.03692239610245451, 0.05697055450582411, 0.06117437209468335, 0.027675030105456244, 0.021456496797327418, 0.06960332175367512, 0.08039549968088977, 0.031428681322722696, 0.03996727959020063, 0.03142465517157689, 0.03381607763003558, 0.06790340281440876, 0.03321789547044318, 0.015183706000243546, 0.038947316352277994, 0.05865651364729274, 0.042356924604973756, 0.02707043578993762, 0.05558690179896075, 0.02866650786017999, 0.05877527211850975, 0.06926474656211212, 0.06091760013077874, 0.06272875587455928, 0.024000721896300092, 0.03446497816185001, 0.07428588025504723, 0.08365234796656296, 0.04793913307366893, 0.04807303877896629, 0.055171941057778895, 0.03392640530364588, 0.029345532166189514, 0.04523442039499059, 0.04139078562729992, 0.035805037114187144, 0.025078661710722372, 0.05688861769158393, 0.07633919507497922, 0.024181685330404434, 0.014852154308755416, 0.10633862984832376, 0.08802778349490836, 0.0554970351367956, 0.041577721494832076, 0.0588738367514452, 0.07162369263824075, 0.06121351667388808, 0.017699422423902433, 0.025613618454372045, 0.011510841268318472, 0.022654736894764937, 0.07313431196962483, 0.03004549060278805, 0.017641709309828002, 0.023258854380401317, 0.04112749760679435, 0.05699365756299812, 0.01313699815000291, 0.0646630598930642, 0.09779511485248804, 0.033255941671086475, 0.029339120010263287, 0.050465652384446, 0.02507769691874273, 0.026498570186959114, 0.03181422704074066, 0.02385272837273078, 0.03492503550660331, 0.04930509669065941, 0.016175648524949793, 0.02648530058650067, 0.05474309844430536, 0.10339248910895549, 0.044394880678737536, 0.039319911593338475, 0.0848703904193826, 0.0899565288273152, 0.04052931173646357, 0.03075811193411937, 0.011799112762673758, 0.11637714938842691, 0.15330002788687125, 0.12831930740503594, 0.23515501292422414, 0.09612238820409402, 0.14164068008540198, 0.1670093953725882, 0.1051385622122325, 0.16749559115851298, 0.1490575258503668, 0.09716293119709007, 0.1301691253320314, 0.20033246430102736, 0.10235806883429177, 0.15703870070865378, 0.11858098660013638, 0.11912827598280273, 0.10646206384990364, 0.15762225142680109, 0.13523696979973465, 0.1576197281247005, 0.14820738084381446, 0.13247503753518686, 0.06547347031300887, 0.11692399348248728, 0.1281040400499478, 0.15579759230604395, 0.11379719173419289, 0.20829033572226763, 0.13823189190588892, 0.17546409013448283, 0.1463836123002693, 0.10283699899446219, 0.150652134034317, 0.16029147460358217, 0.14476564130745828, 0.15887800982454792, 0.16580845200223848, 0.1297510735457763, 0.12280660477699712, 0.17288113420363516, 0.13331204652786255, 0.1283911769860424, 0.15880388411460444, 0.17026806192006916, 0.1659724666387774, 0.12765340798068792, 0.16152081254404038, 0.1434164762031287, 0.17477040470112115, 0.12617954722372815, 0.11980512950685807, 0.16357532964320853, 0.1266312034567818, 0.1427502353908494, 0.09518823950202204, 0.24015306582441553, 0.22469086427008733, 0.12055849103489891, 0.16253555106231943, 0.1261838516802527, 0.10134910422493704, 0.16353350220015272, 0.1685772862401791, 0.17448963539209217, 0.11156760941958055, 0.17698213836411014, 0.1241768839827273, 0.07007833337411284, 0.1265421902644448, 0.11482269139378332, 0.132628335559275, 0.12087329523637891, 0.10201294790022075, 0.10889364391914569, 0.16667226736899465, 0.07697317472775467, 0.1840356137836352, 0.18953966296976432, 0.17118332296377048, 0.15724218275863677, 0.12672833574470133, 0.1411686444771476, 0.18797349388478324, 0.13123127224389464, 0.16446845984319225, 0.1887953036930412, 0.07662294039619155, 0.12280974406166933, 0.1503231399692595, 0.17060314159607515, 0.13802645058603957, 0.15918430901365355, 0.1764050591737032, 0.1879099808866158, 0.15372282941825688, 0.18757573241600767, 0.12211491572088562, 0.1826607109978795, 0.15138611808652058, 0.19981411867775023, 0.16824755002744496, 0.12823517754441127, 0.1007667112571653, 0.18118512845830992, 0.09458654327318072, 0.21348701702663675, 0.10171658606850542, 0.2078517561312765, 0.07877173251472414, 0.16011019761208445, 0.12326080657658167, 0.13123726879712194, 0.16686921851942316, 0.14104589325143024, 0.23354909440968186, 0.1274299918441102, 0.17232087207958102, 0.17363984661642462, 0.1518615082022734, 0.1443258297513239, 0.20988613134250045, 0.1831988274352625, 0.14690299693029374, 0.11545376182766631, 0.14270784391555935, 0.14009527629241347, 0.1475662097800523, 0.10794983987580054, 0.15461011149454862, 0.1846020357334055, 0.13329341862117872, 0.15456568653462455, 0.23301602457650006, 0.12675686390139163, 0.15165248973062262, 0.19977419113274664, 0.21641155384713784, 0.13149753998732194, 0.2794237359194085, 0.16714078519726172, 0.19346574292285368, 0.10216255745035596, 0.11216632963623852, 0.18202057894086465, 0.0818596308818087, 0.07820700266165659, 0.19193907093722373, 0.17012666794471443, 0.08263740164693445, 0.09548721369355917, 0.2501877484610304, 0.1200221038016025, 0.0642079378303606, 0.10421206505270675, 0.17349640431348234, 0.18060086527839303, 0.12160146827227436, 0.1786169412662275, 0.16849082603584975, 0.1332833105698228, 0.105084140523104, 0.07054928544675931, 0.12299660942517221, 0.14422129082959145, 0.2974361943779513, 0.11942857861868106, 0.13559615443227813, 0.25033819663804024, 0.2007835713448003, 0.13685275887837633, 0.1765949302352965, 0.21104511368321255, 0.14400382671738043, 0.0971347741142381, 0.1221763581270352, 0.13797965075355023], [0.02317965238034958, 0.029415316312224604, 0.04816351400222629, 0.02839760920323897, 0.05378684487368446, 0.041940308874472976, 0.03535048650519457, 0.03216225348296575, 0.04892962933809031, 0.05801712744869292, 0.06632389733567834, 0.047275671604438685, 0.013919205102865817, 0.003712346988322679, 0.05280320234305691, 0.0990223599364981, 0.018725634545262437, 0.029747445951215923, 0.014356521187437465, 0.020284187339711934, 0.007345066169364145, 0.006301837529463228, 0.057159060015692376, 0.059434173090266995, 0.00791365611803485, 0.03390728015801869, 0.029911314013588708, 0.02721870390814729, 0.023711262037977576, 0.010433771622047061, 0.07015012131887488, 0.04384922773169819, 0.010334988983231597, 0.03326491052575875, 0.03509009286062792, 0.007661656163691077, 0.05022986835683696, 0.01892599215352675, 0.050119421939598396, 0.010476076822669711, 0.05235560194705613, 0.0247838361246977, 0.01318421451287577, 0.06097307566960808, 0.03176954975060653, 0.04711061425041407, 0.010520237392483978, 0.02980023306008661, 0.034609748909133486, 0.08244137818110175, 0.024476800354023, 0.017993372275668662, 0.045468044772860594, 0.031137525656959042, 0.053849073956371285, 0.02596097139758058, 0.028863208535767626, 0.021557616273639724, 0.022198067454155535, 0.03267226849857252, 0.0277188168183784, 0.04793367457750719, 0.034309691181988455, 0.04425028062541969, 0.041777307269512676, 0.04133419686695561, 0.006190026952026528, 0.030328530883707572, 0.0544602214358747, 0.004620126719601103, 0.019004572604899295, 0.027543464020709507, 0.011694912445818773, 0.014734982178197242, 0.025926873422577046, 0.03502660954836756, 0.024509914983354975, 0.047161603506538086, 0.04882918336079456, 0.05024702681112103, 0.051942700665676966, 0.012147038087277906, 0.036147278515272774, 0.046576980384998024, 0.009888084350677673, 0.04185327350569423, 0.07466291353921406, 0.052106114162597805, 0.12666390248341486, 0.07231111434521154, 0.040876117345760576, 0.011359881937096361, 0.06547042750753462, 0.04690872781793587, 0.03074691292567877, 0.041143869384541176, 0.017920766113093123, 0.07997998603968881, 0.03166917427734006, 0.023101140577637125, 0.05287532796501182, 0.004232704759488115, 0.037329545739339665, 0.05695762258255854, 0.0517970207874896, 0.031829481886234134, 0.08947765803895891, 0.007568476275991998, 0.03417702486331109, 0.014822393259237288, 0.007933662564028054, 0.08697754063177854, 0.016921033820835873, 0.03233064679079689, 0.09316531562944874, 0.007722708942310419, 0.0334508519154042, 0.026930750609608367, 0.10513881454244256, 0.016007683807401918, 0.07104348900611512, 0.12189396351459436, 0.06430190856917761, 0.10593304614303634, 0.052000031573697925, 0.02315860507223988, 0.05947988938714843, 0.0252964560786495, 0.04257992513885256, 0.020174124983896036, 0.06663119100267068, 0.03592307199141942, 0.05342602751625236, 0.0056741072239674395, 0.06506963065476157, 0.022082600407884456, 0.03352549341798294, 0.05692089740477968, 0.05317823924997356, 0.0568700120493304, 0.03144436290313024, 0.022451351323979907, 0.011596059302974027, 0.07789972383761778, 0.038560779867111705, 0.01270775384909939, 0.051662220794241875, 0.05716140891308896, 0.024149453856807668, 0.04048199982207734, 0.02069532602035906, 0.04694634357292671, 0.04949782131006941, 0.034701404147199355, 0.01291521844905219, 0.02094936131470604, 0.0520461597625399, 0.008094434015220031, 0.06485939506092109, 0.012822957432945259, 0.030876475211698562, 0.1129653406678699, 0.042210654719383456, 0.04316775804909412, 0.047539442020934075, 0.03822959646640811, 0.043168247866560705, 0.047872013237793, 0.05728317679313477, 0.03686060859763529, 0.11405805664253421, 0.043035381168010645, 0.012370144377200631, 0.04330728552304208, 0.059977239652653225, 0.08118375699268654, 0.008443061597063206, 0.041648099359008484, 0.11911014531506225, 0.051885251014027745, 0.03763840904866811, 0.04397315526148304, 0.060491547992569394, 0.04049730661790818, 0.035016390174860135, 0.0549635014613159, 0.08099557060631923, 0.061309160955715925, 0.027997639845125377, 0.041798974270932376, 0.018822486672434025, 0.011877111555804731, 0.028688629427051637, 0.034683180710999295, 0.02953459057607688, 0.011049657714465866, 0.04347441346908454, 0.044913905367138796, 0.08668226975714788, 0.04379518453788478, 0.06707092834403738, 0.028910019500472117, 0.012292858045839239, 0.01113980453737895, 0.04676819473388605, 0.028019438577757683, 0.021255063074931968, 0.02574566322437022, 0.03225717417080887, 0.0059750174932560185, 0.07478470739442855, 0.0394793657324044, 0.05391084290749859, 0.0414999221538892, 0.006628869541600579, 0.045465944494935684, 0.012317970467847772, 0.04776396024681162, 0.03713577469170559, 0.005388139170463546, 0.032641506477375515, 0.03822249040240422, 0.029557608286268078, 0.03529347843141295, 0.0654799047333654, 0.04827186385227833, 0.07601740726386197, 0.0578523150034016, 0.06552798848133534, 0.09532257565297186, 0.05254313895420637, 0.023014979087747633, 0.02406369869277114, 0.03916401976312045, 0.035624480005935766, 0.09081696000066586, 0.031633076214347966, 0.10338283376768231, 0.01505442387497169, 0.018681981418922078, 0.02189559589169221, 0.01783060815796489, 0.013768551907560322, 0.0996114025474526, 0.026465668925084174, 0.03735796257387847, 0.023586072857142426, 0.06795893772505224, 0.014834343692200491, 0.008836883189360378, 0.02914546028478071, 0.03716563129273709, 0.01508818602815154, 0.01998483650822891, 0.049575687444303185, 0.01879389543319121, 0.03187317583069671, 0.06373285941663198, 0.12540490832179785, 0.015583134518237785, 0.0527799879637314, 0.013226598566689063, 0.0026941298847305006, 0.01707357670966303, 0.0694067936274223, 0.09899537544697523, 0.04396322532556951, 0.029946436152386013, 0.03458457525994163, 0.045521282736444846, 0.014184256651788019, 0.05953898289590143, 0.09943046694388613, 0.06789607781684026, 0.03249938519729767, 0.052226483094273135, 0.0029708094962188625, 0.026758036146929953, 0.026874252762354445, 0.014483933100564172, 0.03267971223976929, 0.04053907097841147, 0.03950982718379237, 0.04203522214083932, 0.026269719674019143, 0.031154327880358323, 0.03420861808990594, 0.05365631222957745, 0.01347853358311113, 0.013680666779691819, 0.025679361606307793, 0.005414956212916877, 0.08264571370091289, 0.017590315583220217, 0.020230576446920168, 0.03832823902484961, 0.0379982541926438, 0.02528579698264366, 0.0715959066292271, 0.07121686212485656, 0.07837142547941767, 0.039766721602063626, 0.025772616172616836, 0.038634363809251226, 0.07381699135294184, 0.017104221842600964, 0.006957602463444346, 0.03768042202864308, 0.03511554481519852, 0.04677792800066527, 0.04409388784551993, 0.03564527869457379, 0.05383029390941374, 0.07041072647552937, 0.02765359873592388, 0.026998039284080733, 0.029897892272856552, 0.029589843470603228, 0.04162937868386507, 0.13273097458295524, 0.04297507424780633, 0.02253223614388844, 0.01516737411293434, 0.012357170708128251, 0.03293659923656378, 0.08620218184660189, 0.05553469170990866, 0.03622516320319846, 0.02357692959776614, 0.03953448132961057, 0.0413258996559307, 0.05686391901690513, 0.003183056078341906, 0.03633522741438355, 0.00784097945143003, 0.08784240984823555, 0.03755614197871182, 0.11915179464267567, 0.0031770875875736238, 0.054420624146587215, 0.06031805241946131, 0.026778168758028187, 0.029052153768134303, 0.017609396199986804, 0.037910161263425834, 0.036516545224003494, 0.08507946084137075, 0.012754450708598597, 0.01743684315442806, 0.03844212529656943, 0.012950555810675723, 0.09988711040932685, 0.12953173922142014, 0.15093104797415435, 0.22716891020536423, 0.23373325093416497, 0.10728333931183442, 0.08684281856403686, 0.13982963195303455, 0.1550557860173285, 0.13509944983525202, 0.1614024251466617, 0.13057901349384338, 0.14793012931477278, 0.1378262191428803, 0.09155962718068622, 0.07762947818264365, 0.24926312151364982, 0.09084553268621676, 0.1909372754744254, 0.12158937126514502, 0.1373001403408125, 0.15069835499161854, 0.21235528634861112, 0.11982634008745663, 0.20271508488804102, 0.13680831907549873, 0.08831797807943076, 0.06365822162479162, 0.08994002346298657, 0.1432819990441203, 0.11513971461681649, 0.19592024793382734, 0.09446429670788348, 0.1975467981537804, 0.148606478178408, 0.10383249362348579, 0.12155546253779903, 0.09257655503461137, 0.14785256003960967, 0.2552842546720058, 0.21167113009141758, 0.18839025433408096, 0.10645715825376101, 0.09218833016348071, 0.0914610773907043, 0.10861139773624018, 0.1709481215220876, 0.1308817949029617, 0.1884905036422424, 0.18687787611270323, 0.1559455765527673, 0.14555307483533397, 0.16731285955756903, 0.23196803784230724, 0.14775367628317326, 0.2284141894779168, 0.1482823971309699, 0.10530280691455118, 0.12004592674202286, 0.13094027613988146, 0.11781160952523351, 0.15154728287598118, 0.1751776656601578, 0.0985464132099878, 0.1598711815313436, 0.19298069004435092, 0.12294063664739951, 0.10771780740469694, 0.24418782588327304, 0.08766903672949411, 0.07071836895192973, 0.10212110850261524, 0.13894536299631, 0.1192297795205377, 0.09940556046785787, 0.17006704380037263, 0.08830063408822753, 0.11542788313818164, 0.1339064326020889, 0.17485030431998894, 0.14791911584325135, 0.11528827773872763, 0.1919454979361035, 0.24139844899764284, 0.09390573410200886, 0.10537951529840939, 0.09423978219274431, 0.16386801784392446, 0.15621686121448874, 0.2706965839024633, 0.25023940193932503, 0.18279990821611136, 0.07170495780883357, 0.10605339281028137, 0.1377674113609828, 0.11737764609279111, 0.0913409904751461, 0.2518371568294242, 0.21038933715317398, 0.10609055214445107, 0.1555495962384157, 0.16911525424802676, 0.09131663318839855, 0.10888542834436521, 0.14083608810324222, 0.11703392039635219, 0.14126769150607288, 0.12127844849601388, 0.11992794010438956, 0.138300214021001, 0.1176529680378735, 0.08287759032100439, 0.14193973591318354, 0.10671747397282161, 0.08056522885453887, 0.19605675857746974, 0.06995637624640949, 0.1701340894214809, 0.13851499155862257, 0.2568274171790108, 0.15464956406503916, 0.28065228718332946, 0.17455681459978223, 0.23432250134646893, 0.15291933581465855, 0.20826912514166906, 0.09222577151376754, 0.138843065360561, 0.10496879593119957, 0.18748320144368336, 0.08812582120299339, 0.19533678627340123, 0.1062939599796664, 0.1472516727517359, 0.14474003721261397, 0.12357397805317305, 0.15536625607637689, 0.16270140622509643, 0.14621904847444966, 0.10956549536786042, 0.18394631857518107, 0.1541822188301012, 0.10221196222119033, 0.122409273753874, 0.2277637118822895, 0.15506084746448323, 0.06291015160968527, 0.11875560652697459, 0.14021627604961395, 0.05757084807555657, 0.19083990569924936, 0.10907860196311958, 0.162925430922769, 0.18307034682948142, 0.13357493007788435, 0.2512255677720532, 0.19899685081327334, 0.2266200474696234, 0.0913916049466934, 0.11415485496399924, 0.19236178341088817, 0.14509393775369972, 0.34068508772179484, 0.12121267936890945, 0.17245524533791468, 0.08595774808782153, 0.11204958238522522, 0.11672078602714464, 0.22402106114896014, 0.13377864961512387, 0.1604216027772054, 0.22298534953733906, 0.13520612614229321, 0.10140728860278614, 0.14337516826344654, 0.1367651260807179, 0.1330588257405907], [0.022075555571063887, 0.015320256534323562, 0.011010924099537078, 0.06565128147485666, 0.01347595276456559, 0.04901317661278881, 0.031485529834753834, 0.051769104902632535, 0.03059387094253907, 0.026953161614073906, 0.045853275078115985, 0.04544834817352239, 0.028591220689122565, 0.04459746473003179, 0.03576881288609002, 0.07377507485216483, 0.025369767281517852, 0.022182105713000055, 0.07417112938128412, 0.012218676674820017, 0.01190639670312521, 0.04146515995671507, 0.02992982688738266, 0.00987459117823164, 0.04015811915451195, 0.05721428693505004, 0.044612997880904004, 0.02970016186736757, 0.05738011241191998, 0.15264900110196322, 0.04450941261893604, 0.06293284648563713, 0.04138370553846471, 0.016486285567225423, 0.03301603130239528, 0.017826277726271655, 0.06990139052504674, 0.024181154694815632, 0.07869984066928737, 0.025532924737490248, 0.007616229304403532, 0.004489061120693805, 0.022493041469715536, 0.0070760251128376694, 0.03198469465132803, 0.025250973558286205, 0.026189669770246837, 0.056708097690716386, 0.007816012675903039, 0.0639901397516951, 0.01900710332847666, 0.07601285047712736, 0.03576683877327014, 0.046072850600467063, 0.02225156145868823, 0.06084489192289766, 0.08685450738994405, 0.03395813582756091, 0.04110502537514549, 0.04313602010370232, 0.0725590213551186, 0.14046556345419958, 0.03628904356446583, 0.026336728187743574, 0.01637931611185195, 0.009279475016228389, 0.03768796595977619, 0.03621369331085589, 0.0322936395969009, 0.04892717654001899, 0.02733930290560238, 0.006584680677406141, 0.07632378066773526, 0.07130071739084087, 0.05630161227600183, 0.0280175757870893, 0.03858441355987452, 0.0560244609368965, 0.020046557219757233, 0.029763470774923917, 0.027146526335855015, 0.04186300306173507, 0.06308139476459473, 0.05406827469414566, 0.05717617394111585, 0.07141581707401201, 0.02029586503340397, 0.05483039727550931, 0.020331250634626485, 0.02371978189330548, 0.046081125547061674, 0.03244595427531749, 0.03169728683133144, 0.056245071755256504, 0.01638399906369159, 0.03480634011793882, 0.0493626428215066, 0.037596585316350684, 0.0049524998757988214, 0.03469500312348828, 0.06869971984997392, 0.026270035086781718, 0.048733527946751565, 0.0062747268748353235, 0.018057423330901656, 0.04372568982944358, 0.03805668718996458, 0.014338439686980564, 0.004932072260999121, 0.03433863865211606, 0.0373096190742217, 0.0034556664013507543, 0.02276528535730904, 0.02159986674087122, 0.03331616324430797, 0.028166547090222593, 0.052162495121592656, 0.04148822590650525, 0.03674822517496068, 0.043225100089330226, 0.060461034590844065, 0.02780730679660337, 0.046967661764938384, 0.024977597895485815, 0.021904976638325024, 0.13336794509086758, 0.0676033747731708, 0.06939111204701476, 0.05299102507706266, 0.04702917838585563, 0.029672926903003827, 0.0237757268405403, 0.038114741691970266, 0.04061397965415381, 0.011090950811194489, 0.07613511188537814, 0.023507290170527995, 0.051181375893065706, 0.019255251536378637, 0.016537180199520662, 0.024609112297184765, 0.0371769824414514, 0.017586701324034948, 0.08824463162454776, 0.06502956952317618, 0.03959653971833177, 0.07076244510244578, 0.02026424954237882, 0.04766952566569671, 0.02475209261319833, 0.020579356169037055, 0.04052278083690908, 0.007227960368254571, 0.10993587158736773, 0.027580450805544388, 0.0067777239564748015, 0.02861924975150032, 0.07525687658926472, 0.017834140780905727, 0.04723319478216581, 0.048068726900964975, 0.0017683926148492901, 0.022366017328749876, 0.022750774514861405, 0.03442483539402019, 0.004738361976706074, 0.005419603912741877, 0.0688476521463599, 0.028339588097878732, 0.06361909559927881, 0.011658421044558054, 0.02226185504696332, 0.024735828446864616, 0.04974699368176516, 0.050258025439688936, 0.04492654414207209, 0.010798235707625281, 0.012348518193903146, 0.05569202701735776, 0.037319137118174694, 0.01193859663544572, 0.018241331235913094, 0.01915573880978627, 0.02734239023993723, 0.09150160607532598, 0.03064948377868859, 0.08209641309804283, 0.008564024246879853, 0.020036540081491694, 0.007220911820695619, 0.022130370598461013, 0.010785172053147107, 0.0342058387468569, 0.03064146301767323, 0.042173955516773276, 0.029612952093884815, 0.05041777643782552, 0.04107649721845519, 0.07572020680527203, 0.04697028525697533, 0.03965804891777225, 0.04806966571777593, 0.05042857097578235, 0.023442352248821408, 0.0291883545651217, 0.03144009184325114, 0.039905265730340034, 0.06779139788704924, 0.06174660877150018, 0.03966544441937003, 0.07195328042143956, 0.06322560890112072, 0.03503411266137846, 0.0368467749649426, 0.09099331655306742, 0.03207000823749695, 0.030044885752431583, 0.01898402624647133, 0.04598269450070802, 0.02877962415368529, 0.036484484444372356, 0.027377404767321423, 0.028991679864702746, 0.044033955709892325, 0.04513868705544155, 0.04162743054621387, 0.055276005004998296, 0.04381348589959089, 0.049553916542208754, 0.00733251181372907, 0.0516507063730387, 0.01227141647177632, 0.064544212364126, 0.010146129097847734, 0.07081242132699117, 0.03370441037986893, 0.04150732136622537, 0.06878465123008937, 0.02118219344993122, 0.04070714145200327, 0.0412626018805895, 0.06471581174992025, 0.012705759327218402, 0.0034405757560307393, 0.01017365999359754, 0.1389491479494609, 0.04608458395523485, 0.013104806566843763, 0.026435628642502706, 0.04089930203917902, 0.017493517261755187, 0.09851904280367307, 0.024557035794714466, 0.012886965814686846, 0.05582814061199315, 0.012948877629241906, 0.03237954690121114, 0.039559744036523625, 0.05247297631285619, 0.07019683209364302, 0.034124414014513604, 0.05460854707052931, 0.055430995125789195, 0.013168982859497191, 0.006193785002324148, 0.04939213577017654, 0.008677455025463132, 0.03368444289662875, 0.05159861873835325, 0.0420663886325201, 0.03495124445180409, 0.09607371073798276, 0.05395743493863847, 0.07101613344275393, 0.04067056470375974, 0.0075068455498694675, 0.020989060649299063, 0.037511631671804935, 0.03540247766068205, 0.01390432504194905, 0.070215074083535, 0.014264390047173947, 0.0583668163017137, 0.0634222112421412, 0.09240879255230539, 0.0463101189234294, 0.00616426051237795, 0.08221275216783397, 0.05571394634898752, 0.016861162912391592, 0.07403970987070352, 0.03515068550768774, 0.021867976865905803, 0.09289368957979605, 0.03829889821645338, 0.056166359572671354, 0.07437711989041418, 0.03922926196537446, 0.0362956894969102, 0.06820965005317703, 0.05438228850835003, 0.1071538493852131, 0.03606896709243301, 0.03627479061833583, 0.026263743529852945, 0.05797316633106675, 0.020545469706121366, 0.08925645350245759, 0.041976009888458066, 0.04594833306327928, 0.015419990977534326, 0.06039747335307766, 0.011317476546537364, 0.03800102982495446, 0.018358388333581388, 0.050906922260764986, 0.026509976996749174, 0.07152331716497429, 0.019659163554024417, 0.12662305467529222, 0.023042971042741556, 0.021140486605872866, 0.15263230277923867, 0.028220577296451665, 0.02590277774288552, 0.029709809787163977, 0.0729285812121816, 0.047539853912894614, 0.06117065393482335, 0.05449867581774015, 0.040431934539810754, 0.05868856700544711, 0.03137723193503916, 0.041710988953127526, 0.03990510987932794, 0.06361766325426288, 0.00924318492252496, 0.01648610003030626, 0.0014633650494033645, 0.034334824013058096, 0.031532270295429043, 0.05138249420269858, 0.02837377327523427, 0.08505804988089949, 0.04691850561357569, 0.04714205533673521, 0.0373194896383211, 0.04644587628718, 0.02519956684409408, 0.05238785939582158, 0.024255076314148027, 0.015849025621719193, 0.11781402892665938, 0.08236656969529577, 0.08371451025595888, 0.13702686672331765, 0.09918160256347619, 0.09145165953668766, 0.1032989117084071, 0.1403654328896664, 0.1817358614061959, 0.18578993214759976, 0.19365037442184985, 0.09173314872896299, 0.1380576504743658, 0.12882099923444912, 0.1518151833442971, 0.15225137321976945, 0.21767780621303245, 0.1809108752058819, 0.2683129539946094, 0.09986371049308218, 0.12081554130418226, 0.1350518484832719, 0.11382964585209265, 0.14970154676120728, 0.11665429701679386, 0.12929870485095307, 0.1457908292650245, 0.13002663297811523, 0.15434124623425305, 0.20045202429173514, 0.10874882122152485, 0.21341210464015603, 0.12245541307493113, 0.12053652346367016, 0.1259311058674939, 0.1802961394423619, 0.11266223271377385, 0.1402433347539045, 0.15542117500444874, 0.11482564514153637, 0.1025687348737847, 0.12444634296116419, 0.09388988924911246, 0.11965351615799591, 0.18757463403744623, 0.08349876050488092, 0.11498118445160799, 0.14939573738956824, 0.10110365372383967, 0.11992462270427495, 0.20532244263449684, 0.20619223971152678, 0.24248051515314728, 0.08900032349629328, 0.10772706198622473, 0.15828680014237761, 0.18798300821799785, 0.07506106092478149, 0.2710732980631292, 0.11768502139602788, 0.14824919344391674, 0.17613650561543182, 0.1301814301405102, 0.0910186831606552, 0.06961535938899033, 0.17672502872301266, 0.07661593452212401, 0.14748357905773446, 0.05108531600853894, 0.23462537181330845, 0.23025701637379825, 0.12062071269610897, 0.13333934271940961, 0.18476110766641796, 0.21857069892575964, 0.34360021410975605, 0.2017435393645428, 0.18502788007026538, 0.15983730991138145, 0.14956692117266357, 0.11030130510334857, 0.13190267840400338, 0.1518111163750291, 0.1928787783253938, 0.1493175298674032, 0.1460923787089996, 0.1738425568328239, 0.10766188657726161, 0.11733598934370093, 0.10612897312967107, 0.09010581925394945, 0.08828831443679519, 0.10307591859600507, 0.12231676504597999, 0.08174866496119648, 0.13943970756372437, 0.12124554908950813, 0.12088941468391567, 0.12863230076618493, 0.1488774362951517, 0.17973304231418297, 0.11780071479734033, 0.18411315337289125, 0.10704689106205478, 0.23226068151416257, 0.12296986242290586, 0.1646362742758356, 0.18642948532942683, 0.19767697085626423, 0.12104032299248502, 0.07365023819147609, 0.21785152814118192, 0.11412439722334966, 0.121894928306574, 0.1945752536994405, 0.09083887562155724, 0.12898036802653223, 0.2485809096833691, 0.10058141924673691, 0.18192948773503304, 0.10414744625450112, 0.11062920821132138, 0.15923717961413786, 0.19903995475033298, 0.15353248338215053, 0.18368135701166466, 0.12135751690948382, 0.11990013183094561, 0.2550682600121945, 0.16521893441677094, 0.11139947586343624, 0.19476954796118662, 0.1093330027651973, 0.1342858184943907, 0.08078437022049911, 0.20410172845004126, 0.1019614131655544, 0.14233583497116342, 0.1994952920358628, 0.12242789423908107, 0.12332354031968862, 0.13074751070234925, 0.11921777899260633, 0.18959311244543642, 0.18104474380379543, 0.05740479624364525, 0.20088465185835958, 0.1916711704689078, 0.12940619752043858, 0.16975203179754317, 0.15050334826810285, 0.16909622558159754, 0.12275610904907808, 0.1557758028502576, 0.14624171366449445, 0.08510022613336332, 0.14527157822158188, 0.11343041493091732, 0.17860261781606823, 0.09176178078632802, 0.08711993650649674, 0.11591657254029997, 0.10324407441657968, 0.1820539459004067, 0.11607752210693434, 0.23134665243560448, 0.18566789338365197, 0.108829789533047, 0.10230206637061201, 0.21078371442854404, 0.11014699775842018, 0.17970632499782369, 0.14440518018091097, 0.16968152776826173, 0.14982757827965543, 0.13886543369153515], [0.06708014581818134, 0.08052423261688091, 0.017624016509216744, 0.009134066021943, 0.004131500400035293, 0.042197214424959384, 0.07148868855438195, 0.06384916137903929, 0.021912377706030384, 0.0495541057898663, 0.06435474948375486, 0.02265667761093937, 0.012029595072817756, 0.015170956830843352, 0.047632451678509824, 0.005455101299958187, 0.05538205419725273, 0.07512003197916783, 0.03735114594746847, 0.031189683795673773, 0.016769157009548508, 0.022386350319720805, 0.032367535241064616, 0.037835226612514816, 0.012176743475720286, 0.09430170699488372, 0.1097386161563918, 0.002185351240768796, 0.020252172944310587, 0.10161520127439871, 0.049620431527728215, 0.015766183387313504, 0.04170735614025034, 0.04697864183981437, 0.04647204070352018, 0.07509586765081622, 0.014491879646811867, 0.03131246099655982, 0.03637760404672008, 0.073498877172824, 0.03266927393269725, 0.014809247968514683, 0.0371534118312411, 0.08100296239717864, 0.025220187417289708, 0.042531689250608906, 0.04533448416623287, 0.01262066931303707, 0.03762790023756679, 0.023590303098899312, 0.027072068514826242, 0.05003334765206091, 0.003943359934055479, 0.04553440390736796, 0.018591446823847946, 0.13635620271088555, 0.016252813329629134, 0.05292059897328727, 0.06637527621933259, 0.03219110818463378, 0.04026875481940806, 0.01521383348517702, 0.0025494532974335016, 0.030673206529172603, 0.07796136662364006, 0.0717768348113168, 0.052758647507289425, 0.06526065946673043, 0.026258270190737676, 0.05956535882432945, 0.03306446385977324, 0.024948871214292012, 0.029247991697047837, 0.05512203533726279, 0.008765523834881606, 0.01276843091545743, 0.06022165856848005, 0.05857441727130208, 0.04167899867752567, 0.05836526150233112, 0.011178256136190612, 0.053055985263199545, 0.04741938850202132, 0.03847378902719356, 0.045700782284257, 0.0341647386085242, 0.017633152347116265, 0.013724444215768017, 0.06099178150179796, 0.07708664910751395, 0.04402117592690047, 0.030132793144730385, 0.02799800906359451, 0.02355714579607593, 0.10802942037116736, 0.08546992699848488, 0.035213063019909896, 0.030822827211522963, 0.04853392361837905, 0.10692129741073586, 0.02565603776019998, 0.061622139473911375, 0.03641370953118894, 0.015284104665624909, 0.030063476551731583, 0.06096782868553419, 0.03658237743366044, 0.025121971593762282, 0.03797639794356655, 0.0825823268678505, 0.07790005038259551, 0.02883128690882586, 0.01945518612046726, 0.03170090109051671, 0.01450786272471305, 0.03516048185701948, 0.059559165601967834, 0.02425998933176743, 0.11059603421017528, 0.022825651649327483, 0.0013817957142236992, 0.04656014105421491, 0.012475318762881216, 0.04036373858980369, 0.019174528133589774, 0.031456062861252576, 0.027670818417391274, 0.0082647680392256, 0.004490787077884306, 0.02952600578282727, 0.04435410337464418, 0.05734895705245435, 0.05668316895025782, 0.07401017981464975, 0.0646430293272715, 0.06326379982056096, 0.009992640898417449, 0.011093487100879429, 0.02016605041717412, 0.008085390945780091, 0.11331522619002499, 0.02222119648649823, 0.028538038386614062, 0.0636837886122521, 0.0660689473443199, 0.017260581225855276, 0.02242546706838766, 0.060695404827129096, 0.027254132182861213, 0.007316479104702012, 0.04004211034043692, 0.03451357770245522, 0.04223137548251543, 0.03943606141547207, 0.0014013032978255069, 0.051791001969831996, 0.029209774802438915, 0.0293862797843758, 0.007305948493012693, 0.03299644602520857, 0.0739065685775131, 0.036320310246082954, 0.009851419472397538, 0.04360283841378987, 0.04839936111238785, 0.04763374672620557, 0.05819229656481184, 0.08960973806097172, 0.06536332817631774, 0.016613144580333028, 0.028577233060786966, 0.025646998401498422, 0.03826856293017045, 0.03407492389669642, 0.05319444404449314, 0.055035987024893984, 0.09763452151673846, 0.0029863797544749104, 0.05762081316788681, 0.025787820923142135, 0.008988117115222849, 0.018349033562117256, 0.06930159419425763, 0.0423075606522616, 0.02478760994563345, 0.028603352948266547, 0.028190716984681785, 0.04508403901127167, 0.017810061799536925, 0.03088028428464895, 0.03483107590000145, 0.045286775202839635, 0.011169727931701345, 0.03791139693930745, 0.01770234648574842, 0.03274279479228426, 0.017610027025511954, 0.039759489372954704, 0.010022598617069889, 0.0813885749084875, 0.04978017881512642, 0.041568229426047765, 0.027055628088419326, 0.06726483668899164, 0.07013289607129991, 0.029527089318435173, 0.039095159590942785, 0.03849302920571063, 0.07695359687204473, 0.017252365651074797, 0.025785047146200668, 0.028071312844986096, 0.024244203850685153, 0.023450000080629252, 0.06055863814253826, 0.035491520538926125, 0.041301876335637644, 0.045271809794940054, 0.04077062476426363, 0.03718409592693206, 0.032487662974745035, 0.01818206703319447, 0.015574401295452844, 0.011289926169411046, 0.04293681282433681, 0.018849148327717558, 0.01926771590660792, 0.03444872883846983, 0.04223252952215262, 0.03952390943595674, 0.04515753760642838, 0.025947128488041926, 0.0122377804837015, 0.05084049633296672, 0.07121928152628243, 0.030124406875984278, 0.031127393485803623, 0.07588513428345323, 0.054223814004217274, 0.017312694835709408, 0.024699565256014466, 0.010852769646589877, 0.03863080892188009, 0.02761922060017241, 0.04740488322568126, 0.008738825999898836, 0.011946282502321992, 0.0035796658266917802, 0.014118239832896506, 0.04396684329549316, 0.02574685993749881, 0.015945387931424193, 0.07002639787970111, 0.028810772091674153, 0.01897309070045594, 0.08059354178840294, 0.00978273463260848, 0.062299646087922156, 0.02735448353632819, 0.03736185884918086, 0.036536653715302236, 0.03467241214821115, 0.03597566799726337, 0.07014723436441272, 0.03928590638679452, 0.016573259708820842, 0.03171969598042779, 0.06808011559769511, 0.027192248198844027, 0.011990075709036319, 0.026354318943049293, 0.06577189531526528, 0.048544213495915756, 0.05160516077012289, 0.018366277363384143, 0.04689614841481671, 0.006596901530429022, 0.04825714335311204, 0.0481879232393112, 0.02348703139432473, 0.00861368227560888, 0.06510086765047163, 0.0590484121494228, 0.05121694703120738, 0.012281186845939374, 0.03671735554235056, 0.04753183129651006, 0.03644680189609062, 0.011802229782915674, 0.061233124215505086, 0.054820530422148295, 0.018621752424223814, 0.039530640715383925, 0.023998395263333805, 0.11810269468696788, 0.040944717766251415, 0.03876867769577075, 0.034118721741833724, 0.035250426444690675, 0.04045898582262453, 0.006333944229481858, 0.06424218052416109, 0.037307192251319066, 0.03817493729002308, 0.010177726035180967, 0.09082726843189448, 0.018687432493607048, 0.020204590146022383, 0.03449513533269055, 0.07238021571538411, 0.022776317382522393, 0.010393319935246836, 0.03882695484207943, 0.0028862396811746294, 0.045805328627466224, 0.031222872639773414, 0.08444396720733494, 0.03003424521011766, 0.11682504293275997, 0.031629814475309104, 0.015778306369611528, 0.023265407544386107, 0.023622710832569283, 0.04940988052112516, 0.006729029792040819, 0.004919146367683425, 0.013758383556705667, 0.027089052564406302, 0.09199255160638131, 0.03732695935468655, 0.03445558999374043, 0.02748229064309271, 0.030907179716450628, 0.029623568516399246, 0.03761678657610901, 0.037301429474609904, 0.01748784168739803, 0.04681826372689102, 0.03311844397103414, 0.04071401373948902, 0.012880180729553103, 0.020742830893141218, 0.07333292553084902, 0.06745698614395224, 0.07507653470383957, 0.01268670654098969, 0.0074644536107371096, 0.05467141811095644, 0.0911985723359976, 0.053182677293079905, 0.02350986727833515, 0.028324674640316516, 0.18121456203516573, 0.23285457777092233, 0.12790980516001582, 0.0694120628759265, 0.15092614979948848, 0.09979376307455823, 0.16353730199625716, 0.14684055262478068, 0.08195969465305097, 0.11345899503794499, 0.21123453945619985, 0.15071065980009735, 0.1148580176231917, 0.07530111601226963, 0.08486609338433482, 0.06799099108320661, 0.12783530837623402, 0.1624982210341841, 0.14689630275825039, 0.18927958473796025, 0.18163252476369962, 0.11003635096130893, 0.12828622246161103, 0.20317447429988533, 0.2117461315356195, 0.18970309873111546, 0.14644764480181038, 0.09604829218005762, 0.159350817266386, 0.14375280268723145, 0.20696083753136918, 0.10997900521033444, 0.1401772687677294, 0.10521256175707094, 0.11692995292833075, 0.14704939298098907, 0.10690691458876245, 0.16444557200884447, 0.10877641427214257, 0.2545582561288029, 0.11518416926264763, 0.06246423959964886, 0.11042796744732186, 0.12954253004863858, 0.08004725430510007, 0.13740508002229035, 0.10893421713262796, 0.09274838448618539, 0.11832949501695111, 0.16284814366372302, 0.17487675446318462, 0.1255098925321363, 0.1536347810178995, 0.10698977537686005, 0.13722669740673155, 0.19062750303419307, 0.09464259768719785, 0.1328723834012635, 0.24391741695581004, 0.21156760049052536, 0.1114369988499675, 0.18852468696422875, 0.13234569603810087, 0.10482095269253477, 0.22429958917200565, 0.11730858183000237, 0.1369334600167349, 0.19412468100199476, 0.12397111611790024, 0.11897621734533459, 0.14012788626132533, 0.11168276847456582, 0.15222829242702574, 0.27644733781926334, 0.0984063847863581, 0.09915471455315128, 0.17038368852809072, 0.14432323223445565, 0.11881811762577854, 0.17770463397027925, 0.15094220987521112, 0.1834704534849152, 0.09291357171605341, 0.10596124775474891, 0.13619184668641537, 0.1157527879695408, 0.13503421505447477, 0.1225468901975546, 0.15735454391688108, 0.1415627694223076, 0.07529972077463754, 0.13435428903903812, 0.16235844494076446, 0.1150303368922323, 0.13976554007967934, 0.2549543551867828, 0.152250942774117, 0.13014418917009607, 0.11073985500843264, 0.2564526622882113, 0.10596138134133071, 0.14327638840768486, 0.13976172544062138, 0.0718597846571356, 0.12659365078434348, 0.1371085029677488, 0.22399222129024565, 0.16248354135314003, 0.14163080952130258, 0.24767433176748455, 0.17614324431633577, 0.10096995581989177, 0.12670316209550947, 0.12393639102810994, 0.11191592901013792, 0.14030635793460533, 0.20093839819310233, 0.12275961940758862, 0.29084123263601214, 0.07968235513544641, 0.1508761735749431, 0.1371704277698882, 0.14810987748205662, 0.11615555893513374, 0.08393060881644487, 0.18014526081969962, 0.24424948351224884, 0.1476082153385505, 0.06886256189318374, 0.1724292107974179, 0.14232407935196534, 0.1681184460176155, 0.11488657546578906, 0.12897281296318397, 0.13317431876203045, 0.1273147956817411, 0.11747504555387422, 0.16252041124971583, 0.164165485475678, 0.11693353008013219, 0.2049605268985033, 0.13090913562336937, 0.12571404251502827, 0.1046983573178295, 0.11633630158030428, 0.07877140596974641, 0.13767280237516388, 0.215515440213494, 0.18451382406055927, 0.08142355974996462, 0.12086565111530945, 0.12939228967297822, 0.1349261138238944, 0.19574657053453848, 0.11815159479738213, 0.3266726271249354, 0.11710000864695758, 0.1478518921067007, 0.07176040366175584, 0.16619448753772303, 0.09610856941435486, 0.1033534447196871, 0.1460883711115457, 0.13329239445738494, 0.10478116615558974, 0.21617553604301065, 0.14970883465139195, 0.122525998740457, 0.22157382918521762, 0.14546097430866212, 0.11821014282759279, 0.09453964696149342, 0.13221492961747572, 0.10434339550556615, 0.12075647377059795, 0.14575667562894523], [0.05827415545354597, 0.04050991570693441, 0.009033890928549226, 0.053567551367450505, 0.008059318370214896, 0.02781069284537807, 0.022840557685412932, 0.06969482856220566, 0.06318187413853593, 0.06815331362304278, 0.05545446554606315, 0.04498585287365131, 0.021578249834419694, 0.019337481498951092, 0.0452862519887276, 0.024904746824176982, 0.029328781893127598, 0.09309749817475677, 0.015948193249641918, 0.03219471502234228, 0.035642451111925766, 0.020731205149786547, 0.044610326149268076, 0.04665940330596641, 0.07595125221996568, 0.012389469902700512, 0.07400185291771777, 0.0541658225847641, 0.004159271102253115, 0.002531261866351997, 0.0631360242550727, 0.06295336686889641, 0.031146594701567665, 0.06855113446363248, 0.027318981046846602, 0.08200431257137097, 0.02733218570938334, 0.021893831435590982, 0.005255033129287767, 0.05283687358314637, 0.03281318007793743, 0.016569053586863447, 0.024422467722615693, 0.023018309475446586, 0.021368231318774633, 0.06818934489274397, 0.05032776505686343, 0.014913297072780551, 0.008308565884362906, 0.060840617152280174, 0.033228411703021266, 0.05114461360790301, 0.029406252833723556, 0.11078962343162857, 0.014641361176472856, 0.035526694628060795, 0.051578918428276666, 0.02569741063780384, 0.03353795407747384, 0.06906847818754613, 0.034162489901063964, 0.10108276226674207, 0.01675433260970749, 0.0203678533580387, 0.027010620542569086, 0.012092303768440615, 0.032252157252514735, 0.023840130415919703, 0.019722819415619597, 0.03291299151896965, 0.029834410815965384, 0.03840808669338003, 0.03997381791123189, 0.05310986147378571, 0.08801777934422716, 0.040793293665046804, 0.021943969077256043, 0.043958397654932924, 0.023890887750894763, 0.057289021206088364, 0.01961975736776367, 0.032340554462280124, 0.03814738134678919, 0.07609598585986532, 0.058893618697766215, 0.03277482588600833, 0.05145851609995589, 0.029168635701353196, 0.025560465837770607, 0.02831925139616942, 0.0386478041036753, 0.06352651267661713, 0.06278844681219198, 0.01574543108290527, 0.05412734222772997, 0.03164500252751168, 0.031153081072261557, 0.06709844717988744, 0.06950624141609296, 0.09189973861793987, 0.009612446992832702, 0.013267185695440276, 0.06114848227298353, 0.039135922052082606, 0.023900472588138655, 0.03634408123616595, 0.0509722089918796, 0.039843185077188537, 0.02479480692272773, 0.030009082693140954, 0.05108467405079864, 0.020920578972436488, 0.02710683813347714, 0.02064886015432421, 0.019802346105279867, 0.016547152808925603, 0.016529842214367818, 0.0054993356206978206, 0.06374221047735773, 0.04943526197166648, 0.0574773782864213, 0.05517925492313225, 0.0010030641874436697, 0.0190427709458163, 0.02535564977733884, 0.007198787470770185, 0.04595285274263006, 0.017741793490131386, 0.05335536021448206, 0.021826565025548916, 0.03513658099109307, 0.030543889151886106, 0.04552482278086245, 0.06836087748524733, 0.06809373400756158, 0.022746757640561555, 0.029034744839009363, 0.06621351029025391, 0.057983972001238726, 0.06554404855705798, 0.014240943746699486, 0.02360113474423997, 0.023717653784842696, 0.02460363153659273, 0.03355417000420857, 0.0268582390708616, 0.04044608729600441, 0.020779168298759032, 0.03322143922559917, 0.013370760752877686, 0.03861737975967117, 0.03202257015800569, 0.08797396294539794, 0.005173192794245551, 0.019260231347288936, 0.1033385943446774, 0.10387311878730543, 0.0046812963864795165, 0.04646050030714832, 0.03851172390568536, 0.018422569264657795, 0.09262874285923317, 0.02387212254689075, 0.011549966366146691, 0.04370895811007358, 0.08019745015189983, 0.11561398408957757, 0.014737820893060416, 0.07120490612578578, 0.03992123674834147, 0.05289836051815655, 0.006771772395950393, 0.009216877642757026, 0.028672357839241158, 0.03216632416297216, 0.028775186110578943, 0.022572211928491015, 0.03966158896218985, 0.02872434528399026, 0.00887410653376719, 0.04324540524976328, 0.019862098270095885, 0.038159712130436674, 0.061879794593551196, 0.06260129201109521, 0.05203298293054104, 0.05198138882406056, 0.043022597674280405, 0.03526724722178187, 0.04709797547548078, 0.027149617380928248, 0.022180588021001313, 0.03320640702440869, 0.05783291155239567, 0.035810547560686246, 0.08015099912881851, 0.046734178395126946, 0.09886802290566266, 0.1014086244686041, 0.03409225304494612, 0.05071551124274265, 0.03564633254427463, 0.019015658435819205, 0.029416774632409215, 0.002542120414545934, 0.08786811042227782, 0.023473578112316318, 0.033100973814725876, 0.019294808007543907, 0.08365578411030583, 0.0561577172629768, 0.08332789584528655, 0.056029396218946204, 0.014748120975127677, 0.039517066834378056, 0.03762934371479787, 0.0497512573201675, 0.018989768614119384, 0.06062957261747215, 0.03687632728542667, 0.024534120129828807, 0.03783927131735254, 0.06113418479799293, 0.03359892521984875, 0.030480890090984758, 0.03650091188319493, 0.06253128522075713, 0.05647973885061219, 0.006412821539925062, 0.03250285102694761, 0.07045417180052027, 0.03673176805023104, 0.01659647223277716, 0.06586056711967103, 0.04932157236908097, 0.015278434657375328, 0.059321871303836815, 0.05412226964836009, 0.029914258484495804, 0.048188442742684856, 0.037631655504810624, 0.04861994595557917, 0.014845685564068845, 0.04299484135117382, 0.0388529448537156, 0.03312064814963378, 0.036839943495579064, 0.014726542103744578, 0.10932141783996485, 0.02286926766828401, 0.07498620048863813, 0.03556225092324894, 0.031195030969684012, 0.03700978028064128, 0.02385734082054114, 0.02396351432253141, 0.07168493466451764, 0.02453831140883267, 0.044124271371401846, 0.05069975544756744, 0.043615069007501006, 0.01160211151727708, 0.045071593194734305, 0.018881877040257677, 0.02714096579438774, 0.05062467236712109, 0.024624951583973598, 0.04332383170549292, 0.015546913073194446, 0.07074795837979764, 0.1646560154040344, 0.022540056525031105, 0.03667009928904008, 0.04970561152731534, 0.0606512284866767, 0.09266789114917628, 0.04084602325747255, 0.03101908259850461, 0.10884909279411659, 0.05582145386142656, 0.09123493757215329, 0.03994648461230099, 0.041604698562878184, 0.08975139178801328, 0.01968146323633846, 0.015737586581963114, 0.03869811800541356, 0.06847902739536949, 0.010515882840991253, 0.025840988382697105, 0.045656249712919816, 0.03456666352576576, 0.023473364744859282, 0.09312941794632934, 0.04434986571141053, 0.0049390016010875115, 0.039026971062412485, 0.030708866725035477, 0.02100506506394595, 0.025634444973547943, 0.020801310274691787, 0.012465786803659284, 0.03677258988318499, 0.05956073524430394, 0.04739907963084988, 0.04478813360037748, 0.04993470138288103, 0.014340967627504142, 0.01625730703381123, 0.01241691823452129, 0.02748600694758352, 0.006062611792003736, 0.04555482781142928, 0.03304058154753875, 0.04730464133899659, 0.018156446240027435, 0.05771894364443142, 0.07297650168766268, 0.03321657073684037, 0.0409099963871995, 0.032280306913889945, 0.05084566910227295, 0.0352586754161166, 0.018621993622218724, 0.06292633785051294, 0.04100077960174531, 0.04043706278025638, 0.03591824061004445, 0.09777390427188948, 0.07751586279482581, 0.021635747725667898, 0.05445219139801338, 0.0515044364874484, 0.061572552876896225, 0.09082139062229544, 0.016737721489334945, 0.023071111427270807, 0.02927828987594694, 0.05269816247164272, 0.013012707895541098, 0.030753206337976735, 0.06369696173351258, 0.06204810255439952, 0.01583957622642629, 0.035084612100035883, 0.03160590989864431, 0.03068939648073865, 0.029349330106924754, 0.022311055727186613, 0.012340515986579703, 0.027784806734416634, 0.045541925574070774, 0.12070818222127855, 0.1251570161548443, 0.11743610506528057, 0.19762721727602184, 0.18572598870377988, 0.23434679926140234, 0.11348511121468619, 0.1905929041095078, 0.1991131601971574, 0.15909678011666983, 0.20565995655488223, 0.10088768132845871, 0.10245919387671165, 0.13115484587615356, 0.08595929175498895, 0.08100878083496355, 0.20374598738271743, 0.1572085783118382, 0.14654366386821494, 0.12235802845680155, 0.09094616791117005, 0.17011397721944377, 0.18484722648281604, 0.11563383653992787, 0.18921920360298827, 0.1760962960543111, 0.1809704548213631, 0.16162449057446793, 0.07538969875895418, 0.14431858638999984, 0.146454012428876, 0.1198050107632298, 0.1271258300403133, 0.14795516937738284, 0.10996574303135276, 0.1569809764623642, 0.13755221822066233, 0.10650500451447442, 0.16405054164351895, 0.09845193781075068, 0.23210428131278604, 0.08845765769365244, 0.1578786040772684, 0.1192003236792516, 0.19069356902036816, 0.15800514025613666, 0.13934633054304868, 0.15116739232325926, 0.09872317052213475, 0.11154026127769612, 0.19070747686782852, 0.1722199993673712, 0.07922114004031755, 0.17854750592960045, 0.14635606377851218, 0.08452523237792775, 0.14902776572853327, 0.06912334516528063, 0.21159446623641998, 0.1757412971346639, 0.15865048218984157, 0.1578023558249697, 0.08464632119284943, 0.129638712387532, 0.11472934405901469, 0.09410724946064875, 0.12317658023675904, 0.11630364708253182, 0.16035338456276804, 0.1023806820739992, 0.10638045729137957, 0.08571022699470632, 0.14818633353570476, 0.14275795372668654, 0.2081305958563462, 0.16701858316082507, 0.1360872038640082, 0.1903315939125605, 0.13053659233264625, 0.10408532849396579, 0.13935683935415, 0.07868026281357743, 0.10915291320998222, 0.10848830512259156, 0.16459941922221333, 0.15106056758668274, 0.18997485836734995, 0.10712025235989131, 0.13487615244230255, 0.11279781567282043, 0.1380241202423349, 0.10711610375437886, 0.14807492232648656, 0.11937961171497591, 0.285223827813752, 0.12326430209213868, 0.11326078965794295, 0.156167404493317, 0.2065162020153366, 0.23616489779669791, 0.13815699436236173, 0.10921247056103311, 0.18840459262719378, 0.1394050641101785, 0.16663125628838316, 0.14868176163872704, 0.14060651214094833, 0.17262420267798007, 0.11094574903836474, 0.11280137056019157, 0.25548119097948074, 0.15931883070152253, 0.1616698209545575, 0.10122437888639979, 0.16426900023361668, 0.1567688854993321, 0.15994409011909738, 0.16874461085535586, 0.2648878830950707, 0.11243872751947492, 0.18137142236810178, 0.09419596579391509, 0.04451543514733203, 0.10511712898733094, 0.1730212665279396, 0.15528567368164659, 0.14854372217087075, 0.07727304691798054, 0.2336417738115415, 0.25893235579133034, 0.1248776272404939, 0.12957303231814876, 0.1841956505086273, 0.15010402828920633, 0.1540714013390243, 0.12308301767916419, 0.10146294967853464, 0.16059954010415822, 0.12612047226866707, 0.14740609884029254, 0.09177536951028742, 0.20077227585716173, 0.11469395103631541, 0.159425625752192, 0.10310083991498686, 0.09328936561360024, 0.12341600449872203, 0.13153752690413967, 0.09935362497344613, 0.131933833763469, 0.136473803431727, 0.10192663612542674, 0.15016001590993255, 0.10939586267340928, 0.13109495455864817, 0.1825869712047279, 0.21162118355277926, 0.18277115741511807, 0.24756219325354323, 0.1362715385039337, 0.14935350918676704, 0.1352762887836434, 0.11488847536384128, 0.10744592160335742, 0.09826702429563738, 0.20975949126295745, 0.17465393204474822, 0.12879235233413056, 0.2060435281600803, 0.13853320386260748, 0.11670218038489111, 0.08377270205528475, 0.10920508619165048, 0.10085553149110638, 0.1330822627642192, 0.08263484865892678], [0.08146373962517828, 0.017183785639645066, 0.033916037500603124, 0.016415354803029913, 0.047391910484293476, 0.05264218969387002, 0.03835371695458889, 0.02769025340967346, 0.062466607050737366, 0.028616869312827475, 0.06418349148589186, 0.046233477332862094, 0.05363866024708841, 0.03578569303499535, 0.040823027811711654, 0.006732085585099412, 0.056954160463646986, 0.04593352721713018, 0.026654174434952438, 0.0034315510083615663, 0.04292500154406298, 0.024650874802318867, 0.05486974223458674, 0.03887670100084506, 0.0704368574952241, 0.019817309657810256, 0.03747234608454164, 0.07086134370183572, 0.022755028876417782, 0.014814218502579024, 0.010766782561404398, 0.05231357041338924, 0.030113027896732092, 0.051127518236171454, 0.05148137053765822, 0.05811756229377352, 0.01603419332241174, 0.05189141826122068, 0.024695145766600035, 0.04325556154071819, 0.040784206066746265, 0.052728913360624574, 0.02440443724481156, 0.002366774342590361, 0.06436021911213174, 0.030213282771001104, 0.038799476824351586, 0.03904963996319566, 0.03996086372353602, 0.061766149519826286, 0.08074229044723324, 0.04590954842569772, 0.01082821569070802, 0.02351049624849111, 0.03869352411129512, 0.022494360637210775, 0.02409050506685162, 0.008347040675289463, 0.08305091891088523, 0.02612820881040534, 0.018171407937188633, 0.022574360446014907, 0.04815736159798689, 0.01941351638379274, 0.03568326552340295, 0.02979039589263266, 0.00729506675270386, 0.07194300909759477, 0.05752473101892974, 0.024550217312935274, 0.010260398503305623, 0.020398761953401845, 0.03826461841526907, 0.04288113319489639, 0.027446294625406154, 0.048809716827236116, 0.059885261580348015, 0.00415372818679316, 0.036020838815602474, 0.0785550253931433, 0.048882495539146475, 0.019491798120725434, 0.04194391571218148, 0.02166291218600236, 0.028726968776027206, 0.027560798735066783, 0.040634551987750456, 0.008560666028643027, 0.04308133866288699, 0.0689778990636114, 0.07520592815126292, 0.0304031538325944, 0.033989550938713364, 0.056584032863611355, 0.06576070372830145, 0.06360132858389989, 0.06125652784248814, 0.03770781469938811, 0.042015725921373814, 0.0634237400663551, 0.04782516145496629, 0.039250160843948834, 0.011476657946332125, 0.05263250466668978, 0.0526714525767602, 0.016361216985387728, 0.042321427681599744, 0.03570568951545283, 0.09071274762391113, 0.0019432066596891673, 0.006780844223612803, 0.004476275307752076, 0.07848979803384282, 0.06610876356717199, 0.018043797499558423, 0.03667698641947936, 0.04722825578937773, 0.019279241460026242, 0.04007026371255051, 0.06411669819499366, 0.039736126564093865, 0.006778030556233716, 0.03931171457224991, 0.0663004899979569, 0.03626059704401996, 0.02199218826717697, 0.030669801926705986, 0.026858268756768666, 0.031910272082313895, 0.034480874965083785, 0.009322816440544557, 0.01240829355083406, 0.04355803124781232, 0.03739593827049248, 0.039878848983789794, 0.01542627975140931, 0.03532267081027385, 0.09178614549455233, 0.01061372666299576, 0.020326165067672264, 0.022006172184774186, 0.039989636788959615, 0.007614931473653996, 0.0221944012446329, 0.051006529611186124, 0.03930905026209075, 0.05081162307760678, 0.02742824930464849, 0.07302307145437226, 0.10886555362958461, 0.09795041667530313, 0.020061980903847143, 0.0234237855693209, 0.029316028085304424, 0.024233600415755063, 0.06980557925999165, 0.02971389716549311, 0.02464094115566695, 0.03900757132214494, 0.02450035241054138, 0.06169061744003557, 0.06635404337430373, 0.009127371849899646, 0.07878739925217815, 0.07012695888988674, 0.048512735302210785, 0.03602112454245798, 0.03637334411905613, 0.03153589568682946, 0.03520147809467744, 0.045935545858810656, 0.04123017373785842, 0.019339255231898278, 0.008293760038213804, 0.030791963145020418, 0.04219075031869579, 0.05438723863335326, 0.03968849552620668, 0.04329978983150795, 0.04293944002711214, 0.03760240746487398, 0.03560769262549002, 0.014806489034526749, 0.030975030567788053, 0.013940539065515622, 0.04567242111079395, 0.058342566626379266, 0.0064063708850881085, 0.04241595874191262, 0.03381596630788408, 0.05747178249293938, 0.04720159784483258, 0.043198568309890106, 0.03201635838195216, 0.06769512649043463, 0.01935535612574313, 0.04548579694528598, 0.026914705376839265, 0.03533897579472978, 0.09339121796074323, 0.02771391678834334, 0.03388713455933612, 0.009749938199092867, 0.02483979034877848, 0.07957073612487875, 0.05000228506105486, 0.07776029655360617, 0.00776622662669979, 0.07415914369630627, 0.013713256339542568, 0.036649712492362596, 0.025057432576431893, 0.03338299364259001, 0.02386308875429677, 0.04162312608968932, 0.03871628949127626, 0.039235885633388534, 0.037263765480020083, 0.05168901974684559, 0.017830405922723003, 0.04560699708235916, 0.052149399925838225, 0.05480821077071596, 0.03350569291797001, 0.06181038523209281, 0.08426942891674116, 0.05871173685591202, 0.05475470192322973, 0.04531664293608628, 0.05511060626304243, 0.03748961215023883, 0.03610738807765301, 0.02150027979951119, 0.044290037476457655, 0.05310549393470865, 0.043318362077116035, 0.05098941568576265, 0.02761114974418888, 0.043803693260997534, 0.050058725391863845, 0.026772931050800253, 0.06841939582955092, 0.0862738436262589, 0.024106164382828865, 0.04067052017489914, 0.039719175911159255, 0.037710356555180624, 0.029522497279685922, 0.016293182452500332, 0.10507814396987669, 0.03246863059757743, 0.023455568043573294, 0.07320667136809789, 0.02907387457526056, 0.050897578621516004, 0.09380512114148587, 0.058885507023660466, 0.07824985426850617, 0.0017425650639779633, 0.06827363060438074, 0.021618381470034365, 0.03531299691530876, 0.07597693795105442, 0.02568549916759366, 0.03365446755196899, 0.06023477602866478, 0.06627999930060469, 0.04204886281513609, 0.03553841685061343, 0.028434356645448133, 0.044481233271653764, 0.07866220636060461, 0.0461224186437903, 0.026693144609453157, 0.02709585620323196, 0.039104889146983624, 0.023360265149676707, 0.02329559069039533, 0.015677313058404252, 0.036580971063813195, 0.06023846450261772, 0.012109126400901005, 0.0456957802089164, 0.032256884733214974, 0.04712348680186551, 0.0714495476859156, 0.04607415306963958, 0.03581888187909499, 0.038160584153956734, 0.061783007404301316, 0.050004318545688875, 0.025966236935346387, 0.11048675296478905, 0.05320958385709673, 0.037771787829115056, 0.06608159354072995, 0.03712621582963038, 0.027685338536684867, 0.026751139739644714, 0.09306911102612503, 0.04037175007397309, 0.09470804769080132, 0.01993238336581271, 0.007367651578533696, 0.09589179549948312, 0.033258810071856715, 0.0382684850046644, 0.010874348517972976, 0.02199738515628269, 0.07732897516689263, 0.022329820931190625, 0.07848992419894785, 0.02158253573725233, 0.0984996504848823, 0.008842551342240768, 0.037092641068738885, 0.021331984826247208, 0.08381752035347745, 0.011578311768971616, 0.030193434031389188, 0.06613292047404684, 0.06183704317663796, 0.03175604637362994, 0.02345749020605581, 0.09314306604210287, 0.03667458557174541, 0.004952996187057579, 0.05411419508163817, 0.04694261799158994, 0.04436720599187538, 0.02858136682334589, 0.03486658395559061, 0.01956571974005783, 0.05361794319469482, 0.049313583149341866, 0.06386924389516935, 0.05870002576557454, 0.035422333821770735, 0.06861825429950841, 0.033247162064071745, 0.024063138371275272, 0.062042462232057005, 0.0493861021095654, 0.0253614570829086, 0.038665070169372484, 0.04901676860754378, 0.09302407008362934, 0.07116521606803872, 0.0019626503490144387, 0.05180632360861637, 0.0343849301134469, 0.07689959078561515, 0.15600251412251964, 0.07616926552145742, 0.08424958388786763, 0.24099215283058584, 0.15709038387285545, 0.09726538468385115, 0.17128759471233934, 0.12215140712214634, 0.09432608654606156, 0.15570081624900922, 0.16154157783603296, 0.13334703136933967, 0.14019076101249084, 0.0783430012234021, 0.14005515578901395, 0.17361192702082917, 0.13017356337513775, 0.14488753164187074, 0.09632515037083067, 0.10294406121829525, 0.15862585772993043, 0.10265741409966722, 0.1644430635496974, 0.15149589657085016, 0.16554878937313333, 0.14351426158100367, 0.13364311860641465, 0.10244476652587764, 0.16394367237808183, 0.27735979354474694, 0.1625283225439489, 0.0779934274032712, 0.200717193656601, 0.13313311472302303, 0.11780770582845435, 0.13374943868257105, 0.08630750744487159, 0.19234898878494278, 0.1305420693824999, 0.15562777407467365, 0.11292855982901528, 0.1112100575119257, 0.16415942955063656, 0.11470294586615637, 0.16025004792027175, 0.22027833620086312, 0.13771636644378304, 0.1609587692655623, 0.18284504563780501, 0.15393049718113616, 0.15650643239496276, 0.12751832226058468, 0.11659290656098165, 0.19580122228944674, 0.13442366500385106, 0.11040122044505551, 0.12251998734427616, 0.12418541125953197, 0.2290227951016277, 0.09733680897625163, 0.13658563024364412, 0.0942142448911909, 0.14570558618288487, 0.14506943203741685, 0.0802714645396918, 0.16892519022803754, 0.1692031987477094, 0.17431181680876762, 0.11081294913310558, 0.11668021281366237, 0.0688219367293641, 0.14004488446516916, 0.1750231653568335, 0.15944818704156205, 0.11500029475428164, 0.12474926537834108, 0.19281226705061272, 0.1774464556365274, 0.1057783751457464, 0.27905379014555365, 0.12422220694134012, 0.2966702979756519, 0.23154486523708329, 0.1302387536270544, 0.10898003733018413, 0.08617162020527758, 0.12652467557927594, 0.07990541504113935, 0.1365129739861004, 0.17905811837408692, 0.12659943953622133, 0.10511608255910687, 0.18169440503697842, 0.15568733884720132, 0.12682989123277366, 0.15929932706058025, 0.21424428967293352, 0.11991229563136585, 0.06440640296204947, 0.1678833187907003, 0.13457432098221034, 0.1472315308637917, 0.08000585730769671, 0.10539326729485765, 0.1560854713898152, 0.17300560721196234, 0.1446957903681323, 0.10238137969281524, 0.227908386150375, 0.14851035521132872, 0.11001663951901719, 0.1367018950986676, 0.11535104116774164, 0.13280953833600506, 0.1386931218439713, 0.1033587139681913, 0.18715376209001988, 0.15951012668665498, 0.125660058693029, 0.1516370679019019, 0.130478571227286, 0.10201533019426279, 0.15023617510451004, 0.18622183240950108, 0.11255285498918965, 0.15743392403237522, 0.11377699789591134, 0.08439677403657697, 0.23317610583035275, 0.13812180171953514, 0.11339972712448798, 0.09612063673557714, 0.08722882441361435, 0.08834298103465699, 0.12572602077852935, 0.14171303948387504, 0.13175665342714638, 0.257746463175863, 0.09621521603548899, 0.19220600661356002, 0.10385666537331417, 0.14104394882451743, 0.07707215496338904, 0.15458461130037904, 0.15468968456843868, 0.14471447764663026, 0.10633236612193286, 0.09361119053210132, 0.17578693921677768, 0.25483148521743715, 0.15501596237299964, 0.17743787640938535, 0.10608670039800927, 0.22078425827203318, 0.12148529247497208, 0.13361981516936794, 0.10095616671605967, 0.1045881187019404, 0.14349245728226379, 0.1424371826578863, 0.0949914738885127, 0.12628073163796216, 0.1283954072277993, 0.16267433267785236, 0.15896341617917642, 0.1711966667789966, 0.23070942959748209, 0.15287118527339771, 0.14353584323544055, 0.1663113757967949, 0.1570088812150061, 0.1396683038910851, 0.10326348157832399, 0.10171888672630303, 0.10327564537874423, 0.1276680431328714], [0.042221360199619085, 0.019153955799993128, 0.026499983978283126, 0.009918556934280787, 0.019145469341310672, 0.025882817681122106, 0.06515798333566636, 0.03944627707824111, 0.015838503823033534, 0.00747848066566803, 0.04932806987199001, 0.047654968439019285, 0.035584693468990736, 0.008685608445375692, 0.03139616041153204, 0.0683582280180417, 0.05949823527771514, 0.02060221060673939, 0.023568168544443324, 0.031505738515988924, 0.02670672591193579, 0.04924931316054426, 0.05231500275840517, 0.03970299338106997, 0.10688259440939873, 0.06505924058728851, 0.052753300333279185, 0.037248228618409485, 0.05511193099664524, 0.03518026009260211, 0.038286419003270566, 0.02852539033483481, 0.06639482438913547, 0.03691716767207254, 0.07390167040284723, 0.057190961233573034, 0.05468729264975991, 0.08610553937614895, 0.013494204031303525, 0.03335630601213779, 0.06282894581090659, 0.01740208281262312, 0.014312339280877495, 0.05559673525567632, 0.07403956886264496, 0.016273840228677727, 0.035351343685761094, 0.014520319673465565, 0.09406766330357641, 0.09506795962806791, 0.022847248146717902, 0.026458028514753096, 0.01839067361288471, 0.03506637382088229, 0.016504213999724016, 0.03249261309974827, 0.039282143698073924, 0.03535787829605397, 0.0293900647375267, 0.02785529963148292, 0.018327568795939442, 0.03123098060314078, 0.029615178536914755, 0.0319144540844718, 0.036204349671606906, 0.03901892247085925, 0.034655409544939175, 0.03346238489029929, 0.05389916892454494, 0.02629355189128546, 0.008758152453083312, 0.08910176766221412, 0.015659631390008144, 0.01156892267317744, 0.010357569753978169, 0.047976485366234556, 0.024371836552745663, 0.02403499613137683, 0.06819725618697703, 0.06370004164637066, 0.01810097997804405, 0.05562374943110626, 0.051756288012256846, 0.028384061297401786, 0.023049028823152184, 0.03991252393461764, 0.04372154493466951, 0.016722756081435364, 0.0408790785149904, 0.049085569407907315, 0.03141818735457491, 0.03501626772049349, 0.08294047249364667, 0.019238302738813218, 0.042608093353919685, 0.024439846965833567, 0.09214877369231544, 0.039630893734283745, 0.05072146326710936, 0.05058948714577127, 0.037891778265475295, 0.019716702263394836, 0.10617689360515215, 0.007333641269724467, 0.07941331175970845, 0.020081748007214628, 0.01244904487975873, 0.02442090364638716, 0.033410920659662224, 0.03620793795562349, 0.0620425735542085, 0.053684625163441524, 0.06560794747201726, 0.03750611751456745, 0.014199298129824456, 0.04888838819169905, 0.049039552541216835, 0.025838761939667165, 0.0768232905829791, 0.059167096405872144, 0.0197589601521031, 0.0529797073249938, 0.012118873582949163, 0.060799212733400054, 0.04020197637146339, 0.022897972085047513, 0.007535887179983547, 0.07321750672417693, 0.003910360801455681, 0.0628283892001491, 0.026725446587079205, 0.04274711987818591, 0.04756712784001138, 0.009332117406302132, 0.08420927042607218, 0.03201472936780192, 0.06219312934263144, 0.039673147912253626, 0.06401905382517725, 0.12646349292481318, 0.03450880940363277, 0.004929952037855401, 0.0340434790996369, 0.05165991642570589, 0.07176691229688004, 0.0270574704700266, 0.024010228808037937, 0.038304994959617034, 0.01734473891701782, 0.0678634233190678, 0.047577577279298566, 0.026611794091877528, 0.04741754426504485, 0.0021650722874255734, 0.02281817636685446, 0.05306734383339062, 0.007608735468238592, 0.022583507416129578, 0.10334683218388818, 0.06324613670585677, 0.035190995258744806, 0.040095077420119196, 0.12463642924558371, 0.014366116229211912, 0.04701046513218898, 0.104124855279224, 0.0054321513107424835, 0.06263399845920503, 0.060858176366309635, 0.04242005539708771, 0.08629017829662189, 0.06031520999385975, 0.011527419919730164, 0.07486535658244975, 0.06395804186468013, 0.09068743296666071, 0.037515832227654755, 0.035031296210945584, 0.03377669185283594, 0.03622490716225002, 0.06690733673167415, 0.023361537932942156, 0.0627539146807976, 0.006597822257390362, 0.03159438805596437, 0.02289349136844976, 0.059833344639628194, 0.0884986094024498, 0.022849018168926705, 0.02584190122433938, 0.031139870843617246, 0.052310223327367567, 0.03762830841878895, 0.013559121543949004, 0.025114939744526055, 0.040426138366456144, 0.0312858846882591, 0.028645072779909242, 0.04332124903157819, 0.022729944284947123, 0.08916744031012058, 0.044401237173588015, 0.13280524872243404, 0.07588319727801718, 0.01570300621096976, 0.04286023060558364, 0.02818698027112987, 0.028299619734752923, 0.017281962500419468, 0.03348987775098067, 0.032191393911489286, 0.06147388063254766, 0.022731393328285776, 0.05469865121995099, 0.07746361559838988, 0.02855603175703436, 0.059332702949177474, 0.017075328178179916, 0.014674760604975745, 0.011274924581812229, 0.050508585627540015, 0.027893355108972173, 0.027312079073453788, 0.01612949065020075, 0.010472198173374636, 0.0612289385026088, 0.05619655756163411, 0.045704274089075625, 0.03690773497510236, 0.09078239818336442, 0.018707533563429024, 0.09766684946953319, 0.05510567840246949, 0.03261491532612126, 0.055489888254669495, 0.060047539591323584, 0.03282038262113929, 0.031699038299848326, 0.017776104832591955, 0.015491993217437994, 0.08542778043192811, 0.08667118207085878, 0.04136645431572106, 0.03739101783139631, 0.03226456967240665, 0.028349046770017594, 0.048782598751131445, 0.10634614038281143, 0.07762914421618916, 0.028211040698806755, 0.007828121742932126, 0.01924540880281711, 0.07203022629255429, 0.020284988859202713, 0.025439119126531295, 0.026335340371588245, 0.006203922275744844, 0.01804038547561504, 0.03100962763710413, 0.011904552466148743, 0.023216266235976946, 0.04257007683918346, 0.1247248487197794, 0.011402573054510867, 0.03682192414999008, 0.05074362750747241, 0.13562619657022879, 0.030708597696502693, 0.03176983547746204, 0.05080391216324642, 0.039485874367528595, 0.012119682523916708, 0.06498218339402229, 0.0375327086658217, 0.024459239284624346, 0.025740106393641327, 0.03863165868096985, 0.044426459062378854, 0.04482243937673047, 0.023751746193738654, 0.0033711580454109935, 0.031174228570307605, 0.03392476515728049, 0.04143956699408591, 0.017344388252240606, 0.0410300610383274, 0.09463801121455617, 0.04939959435432684, 0.03680763780721463, 0.055951648828340694, 0.034687759762164205, 0.023963772218849044, 0.07322789679164998, 0.009863932082225801, 0.05828874607686885, 0.08156892421538942, 0.0175550635685795, 0.0394690758548677, 0.04167438994045369, 0.04232612547639292, 0.03252575741498731, 0.02517347293178318, 0.010711707782320445, 0.08577851942391135, 0.018558083575044293, 0.055262130554183386, 0.0576180041389307, 0.037616415502270684, 0.06405353400623426, 0.045024507635389455, 0.08502480166498572, 0.05718028172850609, 0.060105159936938435, 0.024013026704778895, 0.023915009405754972, 0.06815243046730757, 0.04516825792961754, 0.05218093378061894, 0.05805668763059657, 0.03252660346333869, 0.012163420997239882, 0.03218969810404815, 0.03256879826949444, 0.07522422951296903, 0.045671441475860775, 0.03415084931475576, 0.04667016815801617, 0.014662715548183769, 0.006073720351196243, 0.05312599576427601, 0.015699260220571887, 0.03611627900681924, 0.023242478891916107, 0.06451353940065019, 0.021246268624963704, 0.0676046586886514, 0.045182907924754545, 0.025417804645258002, 0.0596485424466664, 0.013529897623811848, 0.020494988821155857, 0.02927507637650706, 0.011273528416495537, 0.041473060118732974, 0.027924445530516095, 0.020454176265047863, 0.025004075869219378, 0.06809881029766984, 0.030633091591880657, 0.05425974879472051, 0.11703760887030512, 0.06868109194329008, 0.13517468876671046, 0.1036359803401865, 0.12858545640483499, 0.17087948770495132, 0.16628982382826507, 0.08883670961949974, 0.2152907772688195, 0.1725114556029439, 0.10674488890799694, 0.17095989198423922, 0.1800463770632632, 0.2205678034806624, 0.10229034785879776, 0.08619842657935806, 0.13469204044668004, 0.09676905116066337, 0.13973864464787766, 0.0944768390036188, 0.18850827065762132, 0.09883239981718361, 0.11792123958002776, 0.1230306294746697, 0.20800440106540918, 0.09971322520868853, 0.22689697245368734, 0.2067739944322966, 0.1877823908580467, 0.21281991532305256, 0.11766506504500285, 0.19807399017736316, 0.0793505780166015, 0.11145089185447432, 0.1624766393797472, 0.07751990007818677, 0.21329000650439411, 0.12923689879244193, 0.133501309028361, 0.22361289476975799, 0.17350357346003875, 0.08779943207628094, 0.08010482270037755, 0.058130149118369445, 0.1424197867163457, 0.15999923169147223, 0.13961400836706161, 0.07230282455566339, 0.1049367203086149, 0.08909607538953424, 0.12162647122750059, 0.22691141464747488, 0.08851792750647292, 0.16273124056169763, 0.12240703246789053, 0.19801779475528747, 0.04878058753092773, 0.16358330030925572, 0.08421499238465913, 0.10420428734505549, 0.16539700533030555, 0.13988792023155838, 0.13017945602769032, 0.13226466835476458, 0.13188028038712218, 0.11259442268055864, 0.15819943451788276, 0.21650405513355508, 0.15549028379609808, 0.09122994291828945, 0.1970153907313943, 0.24330841057235375, 0.15328137029428035, 0.26043962803669274, 0.16516189294634387, 0.10664930028724484, 0.0716928459587507, 0.13584930100478232, 0.17035989527357742, 0.10510143998544663, 0.13405072095338255, 0.17055145843187347, 0.14743526524398476, 0.11459934205049649, 0.12401468760799617, 0.11339829477947205, 0.11087471808423288, 0.15458839625352994, 0.20940582820912823, 0.06734730413882062, 0.13595743192126974, 0.1268281100783497, 0.14315725886262953, 0.14813196379691362, 0.15801276953425258, 0.1432919586659409, 0.14614342362619936, 0.11149254118208773, 0.2574176323832944, 0.11668762686895207, 0.07573154682177119, 0.08829467464238405, 0.15852231328608468, 0.14293060696218163, 0.2409772208193317, 0.13118809409206733, 0.24608791689388454, 0.15544437454082072, 0.10691561255953275, 0.2192009158898145, 0.08165450126398355, 0.11117825648398139, 0.28223733650520444, 0.13714470493141562, 0.2387871578685008, 0.14719378523295745, 0.09636529313866049, 0.09007430024212226, 0.15921301528578624, 0.09264866210287437, 0.24364890792639926, 0.21651915041729808, 0.08017704851226881, 0.07034470501821488, 0.1367950494750403, 0.09375366804306395, 0.07518174155848101, 0.10531834748690017, 0.09579008416039869, 0.2129938153666444, 0.13469456374878064, 0.1323958206921816, 0.2525646990397945, 0.16728059097658843, 0.21624255197821185, 0.2600392245221883, 0.25375736004207283, 0.1647195135592483, 0.12132905554608442, 0.12518428266048431, 0.2249608575948514, 0.2513139130314812, 0.18480707629350945, 0.13206504547270015, 0.25742012599948794, 0.21741625852882862, 0.1856581712490879, 0.10242724441923201, 0.13455832027830184, 0.17353597562760115, 0.07647336053196341, 0.15302494342904538, 0.1535118219908327, 0.1125983041129075, 0.09882696729619056, 0.10918464002315886, 0.1746144497883506, 0.15801135945366696, 0.08027349060284905, 0.13417978043435141, 0.1769356057047844, 0.375087758875452, 0.1527726132189855, 0.15373788017313927, 0.20536444819299504, 0.1915611099684611, 0.18571831489680335, 0.15609364985721186, 0.18199813639512286, 0.17310210125287995, 0.24653645610669628, 0.11037260323064402, 0.15348868182627484, 0.24694854102563113, 0.11182839269167744, 0.14314081287011504, 0.2013401672593318, 0.24334044166607782], [0.05306469065544661, 0.060074613138567656, 0.042818926376639865, 0.033018049944075756, 0.04168728104559705, 0.04783385942573659, 0.05295310133078601, 0.06215846733539365, 0.058340050745755434, 0.03280101627751719, 0.04232325707562268, 0.0032488191754964646, 0.05161752866115421, 0.03837308700894937, 0.03485077621007804, 0.0277125976208481, 0.03395868501684163, 0.04082905776158441, 0.07820860570063815, 0.04012232908280566, 0.07753615311230533, 0.010772687273856718, 0.1007268950343132, 0.052006688638357446, 0.06867301737656817, 0.04704932769527659, 0.02203253698098706, 0.012509310981840827, 0.009216192083840724, 0.011564333417481976, 0.06153135997010395, 0.03328371654788498, 0.0037268360301823122, 0.013369891512411414, 0.0052564552697731415, 0.014030500351509545, 0.025937001882994082, 0.08281676389742643, 0.018485319706087466, 0.01512914330305648, 0.09667941456427798, 0.07622391727636568, 0.04743908881209791, 0.015106445644050837, 0.060790963761974126, 0.07401599083095789, 0.04976293130312115, 0.014241801854950609, 0.02579224412329495, 0.034854123296099715, 0.07804145920090377, 0.015580965591652784, 0.08001074806088582, 0.03493315460218582, 0.0031194071743811946, 0.06992271984927356, 0.08846714234095998, 0.03343484379001893, 0.007849185749364551, 0.06953997202799655, 0.05672726736520417, 0.024163224406947847, 0.06441732737584971, 0.0724771327804774, 0.06867761127068661, 0.033126863636425696, 0.053971520901541226, 0.05889377454877831, 0.020085382675461005, 0.04143279860727489, 0.00971899713476887, 0.0429868558421731, 0.019557574669306632, 0.003949801312046475, 0.03249035326007288, 0.022152627607283648, 0.027277374392724596, 0.026715889580373187, 0.019647365261334926, 0.06761841068509966, 0.008024332601053175, 0.021795693537569605, 0.0510699646838475, 0.02677879030670738, 0.017415088950656354, 0.013479824920068495, 0.04303551104385406, 0.06144455837784335, 0.032214125894824974, 0.02023675297095906, 0.020990338998672087, 0.015144754379434744, 0.04083420084498357, 0.0578598626452731, 0.03111083060503006, 0.029364939327933826, 0.04119399774936028, 0.03331366962811444, 0.040305034708580934, 0.09359381685499102, 0.008842119968903717, 0.00686643565131817, 0.037878018847550265, 0.031237800940289162, 0.03531557216774672, 0.013151645362086128, 0.09519395403913222, 0.020372187500470318, 0.03004442376550287, 0.07546147928223945, 0.015669078929931857, 0.02826409869157942, 0.06017299965606071, 0.024579519158578478, 0.0814507223549299, 0.03186011774232611, 0.048940976776066236, 0.041022305595106445, 0.038797743909526616, 0.04414180089952424, 0.05679749679984525, 0.07222938162158243, 0.0720348944014404, 0.013032253282290185, 0.0810128403827548, 0.05845200743351597, 0.005851318173881737, 0.019571489938243758, 0.06912077733431943, 0.06919557097717188, 0.009619974225643091, 0.02123695838236017, 0.021481201038113795, 0.059151236710022204, 0.027279528476356063, 0.004574361255436088, 0.04170063228229992, 0.0650487985694781, 0.005956320474069798, 0.01027669513860019, 0.1420994015643373, 0.035499762088875286, 0.06209409344592132, 0.030504718597512692, 0.025435618044866715, 0.06696155061945319, 0.01905308679852169, 0.018841917953977827, 0.016970531360129826, 0.030648778738395777, 0.036724031160702, 0.01600476160092512, 0.0414856914721895, 0.03666081131086685, 0.04853572332649492, 0.027684511042025406, 0.04775995636009611, 0.06459203636040911, 0.044623729336308315, 0.011652158245851751, 0.02115296581905568, 0.03226066968636587, 0.05110971782414708, 0.03213097566913348, 0.09416187895112671, 0.07028223102679476, 0.046803502409602515, 0.04127402353333309, 0.07888741107308306, 0.022977159242145717, 0.02209544512879802, 0.06572991202119738, 0.044256700202822685, 0.011152963743370492, 0.06941779225599021, 0.0297756252984982, 0.03514896372507792, 0.026339333126088604, 0.05885363549168687, 0.036114586910116486, 0.035198854602640495, 0.02296769314853009, 0.05147822383150924, 0.05528086236154195, 0.01730774099996779, 0.029837256952305324, 0.046314338032971136, 0.06710691508487798, 0.028035530194756575, 0.0926150353916455, 0.05263490180368535, 0.01343656234894297, 0.02907642199716065, 0.08301393769215792, 0.017810288154578302, 0.056209726972156204, 0.1065132423536852, 0.030981593008618802, 0.03091521532041952, 0.04007642353826668, 0.0369037644850323, 0.026879590659518726, 0.02193291478761239, 0.020716490216727834, 0.022136051738925744, 0.04489588602154981, 0.03913142834790051, 0.03230553622415755, 0.03174817960825749, 0.02571273969806498, 0.024860214252839796, 0.04275406266970094, 0.010149171903321985, 0.051050609472440556, 0.02777407342364313, 0.021452251712617, 0.008996166634460678, 0.031149693168117665, 0.0358289491123287, 0.0034697924866122776, 0.009274312451452715, 0.05390690581407398, 0.03347871213918552, 0.05087169251055457, 0.04360141349025071, 0.0459010768099688, 0.03624057018896565, 0.025121448379650246, 0.03751202501007356, 0.0418103885021992, 0.017125315534940455, 0.06025640221196227, 0.05144126116647385, 0.014535956725012511, 0.041688060300657526, 0.056218506579170935, 0.04808535100892186, 0.03637038666056469, 0.09165745708742179, 0.04307385410356801, 0.03690199817356188, 0.025942009524442255, 0.06916724320035428, 0.029260704686748795, 0.02700107652344741, 0.04080837781657465, 0.013133225256751757, 0.08365399553440511, 0.02333585962333018, 0.020237882890796755, 0.04152829817030579, 0.012883555646112654, 0.03962334609241225, 0.03913336906407494, 0.06797202921006829, 0.04464958947210107, 0.02262832200358389, 0.03684030714794062, 0.008578042488807114, 0.017961048033612315, 0.07581311627291143, 0.1190897288324777, 0.060299031174508855, 0.0346750356402481, 0.021910817340540234, 0.049749257232178934, 0.009726495609356789, 0.03323130978969857, 0.0445833193953149, 0.06736826238920912, 0.03833395727269817, 0.08720663419808261, 0.013866916160623077, 0.05798529673484154, 0.020513681665761396, 0.04128194224904291, 0.022200995226739906, 0.00803068538516527, 0.0416982017486589, 0.07848107037716545, 0.056219011239591055, 0.03051940384466434, 0.019777593624894507, 0.028061742850695737, 0.022515513701364398, 0.05385063246649224, 0.041329580708406866, 0.038487025231006555, 0.10379161612945609, 0.013639025801239768, 0.020931371655024122, 0.02950267637061188, 0.024147294207068626, 0.030553056531061884, 0.027698578451236244, 0.03237083779822569, 0.06568666707607917, 0.029038628126727417, 0.060990089405095205, 0.01768992849974893, 0.037185053297434933, 0.06422268430469558, 0.04591572309436742, 0.023946363289724104, 0.02526672378735384, 0.04031392563774716, 0.09247055408195592, 0.021913871278229635, 0.0579991600534413, 0.010195303802902345, 0.035656221662065946, 0.0459518916613888, 0.02440964526613243, 0.0435774235666031, 0.0222474295514985, 0.07684689830057323, 0.05318631010595709, 0.006553362973136245, 0.02664706280484097, 0.019950599380536005, 0.07241170504130423, 0.06533912674058229, 0.029653658893948887, 0.00997543513221899, 0.06112703420512844, 0.04272493708413094, 0.020665645679400768, 0.02908430546085583, 0.08036740196985193, 0.0429459115548525, 0.04174771784164477, 0.02098029959597625, 0.07837979690521024, 0.056172122349380516, 0.030923163722036406, 0.029198668562457897, 0.009385146640852327, 0.02709287276957184, 0.021202903080848046, 0.02927107248979155, 0.04092536255484447, 0.012669467378145782, 0.004125204204683541, 0.006307606336122262, 0.12323989285505377, 0.023893487123132218, 0.027815262619697023, 0.03364427786436863, 0.01295587051572511, 0.04794664360815659, 0.019049108886974864, 0.07912389643024653, 0.1122996787307784, 0.1912846599589102, 0.17477306158980355, 0.13885418273275718, 0.11071574263041839, 0.128857230884023, 0.19313527940539643, 0.17786832206184044, 0.1413341730949469, 0.12820676813134924, 0.0863530753122177, 0.14670401229523122, 0.15212014666758478, 0.17571371892699972, 0.2844542503589764, 0.1236252901435364, 0.09086164471227676, 0.18913301057182252, 0.15319085796363652, 0.2051424272940494, 0.19036524288821965, 0.10665252862963825, 0.20867546583758667, 0.08218715549446642, 0.14913064223947003, 0.07479686377337202, 0.1188082322187256, 0.057309690018882975, 0.12536962662125006, 0.14585642027668655, 0.16038336732890457, 0.14198548189597204, 0.07680052891373634, 0.09110583356232382, 0.08241273870225996, 0.11363482466549613, 0.10786338709294796, 0.15921323793008924, 0.11745625437470153, 0.16068206692580134, 0.22176604543346912, 0.13020359067013487, 0.17446845449740067, 0.1293314780923538, 0.08916875391150825, 0.16243818128714338, 0.10342840905650519, 0.14159505284624174, 0.18312422675080597, 0.129926250083372, 0.16522021091077477, 0.1141450140858069, 0.2315818687202409, 0.1201656500052195, 0.08104107910185121, 0.20088969846256077, 0.16106709314044565, 0.0745338763226755, 0.07212740310933441, 0.13301109080202878, 0.15748137695482, 0.10323318711016327, 0.21939592261333019, 0.19282319146441296, 0.13381405005929992, 0.10040248002042063, 0.20297811686759815, 0.25027784518897533, 0.11888800567248836, 0.20361382572446018, 0.16055967193096876, 0.18173042888520285, 0.10358770363382064, 0.0856350251706317, 0.143249403918162, 0.2776471828110516, 0.135655585618224, 0.17975242721149698, 0.1343380953767337, 0.15696761780418456, 0.11111249477835372, 0.1642928528599441, 0.13597245299024507, 0.08218636881792918, 0.140643545310013, 0.3178123338147998, 0.18886151810875162, 0.11786200877395459, 0.10947846370982006, 0.13991238141898066, 0.08794537541689351, 0.13148624449968338, 0.1877096010139212, 0.17611164366826415, 0.16910430014831945, 0.11730509373592213, 0.12411841016728431, 0.10120519436895847, 0.08166259809513576, 0.11502621797262691, 0.11521704640472308, 0.1127901863947045, 0.12445225787814707, 0.1330016358406283, 0.1694275499903597, 0.1669294957537204, 0.12819740222766995, 0.11262134779826738, 0.18127236049622297, 0.1855096674989909, 0.19592078228015453, 0.08685147200594656, 0.25897462852299213, 0.0860293727600947, 0.2076185733312741, 0.1204523268097546, 0.1525174331618473, 0.13009315909584984, 0.17145221790997311, 0.13516634702682495, 0.14305825636256486, 0.13595667493063956, 0.10984545573592186, 0.12356260092929006, 0.15380744909634814, 0.27831425482872874, 0.10561984498053789, 0.11116212961496785, 0.11091434877016582, 0.12050757970428094, 0.18241486715851352, 0.09564142455928959, 0.13685836951481178, 0.13711105595575646, 0.09367760532768443, 0.11390095140086487, 0.11915712326299399, 0.10116540041053668, 0.0643358840898145, 0.1444464732776396, 0.1943256991216913, 0.08822799267363735, 0.1924371559289284, 0.18406475050142035, 0.17892690666485578, 0.16917330503929406, 0.12550368817755952, 0.08293919599964283, 0.20341745344921947, 0.17128471517935395, 0.1461610125261359, 0.1763205137103796, 0.11936864277231507, 0.11174358747666702, 0.13707832724321634, 0.07883468148065731, 0.12818815506761894, 0.08202020195312798, 0.14816592447459698, 0.1285119986278005, 0.08033868827624246, 0.08298457833006978, 0.09147955686785281, 0.17602122039534152, 0.238533966767136, 0.16642082773614675, 0.08471193446894176, 0.08635425532702357, 0.18018710310570896, 0.07885547645855695, 0.14376187173184007, 0.1141665066825226, 0.12123412001528777, 0.19713164074346423, 0.1949996137409471, 0.14801137964241207], [0.04287810894311406, 0.03614103334257379, 0.015419003921124386, 0.13133886881405488, 0.05763197135820519, 0.08556475120713003, 0.01648069348448189, 0.05227632944297511, 0.08343855748535134, 0.0672947007114999, 0.05451649478345644, 0.05681518217897974, 0.13640374469105154, 0.012411083098413656, 0.04890293057542294, 0.030408712518692482, 0.09598615215509199, 0.038279602376860566, 0.036637307493947446, 0.013480144043569453, 0.03346028461237438, 0.04410591805935837, 0.0304402909023338, 0.03854049697110895, 0.049777740860008635, 0.006092348721722374, 0.03718857107742224, 0.03585407081118319, 0.06015224920702167, 0.07611730776261538, 0.044228973565623164, 0.0558075682783965, 0.03228631831007078, 0.1318838426959701, 0.08463063219096512, 0.026327482883061748, 0.03150642129185144, 0.02321293028217042, 0.0781841593561694, 0.03564328602806199, 0.03738597864867188, 0.06889926109579392, 0.07067306083627045, 0.03338277841976378, 0.06366309753502719, 0.04996819079678971, 0.05563395767239854, 0.025162899182760157, 0.02826071264280472, 0.05489781025971752, 0.04544363924651407, 0.03316907328553498, 0.006222334959602449, 0.031658012376283295, 0.03247530621592887, 0.12151508970418945, 0.017667072206677403, 0.020390639147080947, 0.018241219913761597, 0.07935180256026797, 0.06290185439866036, 0.07236938035930507, 0.03752638556761667, 0.07843559156754054, 0.008495759648212697, 0.09041070094099268, 0.07520914907217957, 0.05902399178012274, 0.015373287624242948, 0.028285802800382953, 0.12051558747771196, 0.06308234471362084, 0.07710679841693491, 0.02634412368934136, 0.020457027967495378, 0.040134288792614825, 0.041385557196917944, 0.02813263279676903, 0.08360899169929326, 0.09661577540100552, 0.008029946020542411, 0.0023810977927496424, 0.036764455944648944, 0.051489441393641755, 0.0666191014170181, 0.015305705801438307, 0.01985512764804298, 0.09037651761900634, 0.013557176189351594, 0.05440659384476021, 0.03833251750620548, 0.04113084840355441, 0.0775434632669203, 0.07223777531180531, 0.07859591773012653, 0.027379679449950345, 0.056365143827861175, 0.06534707514219917, 0.0391238398879068, 0.02297427043231437, 0.017459051923651714, 0.02582655732112471, 0.03440175831201486, 0.029964867389935534, 0.03910738647391554, 0.05851097848790232, 0.02611913048895076, 0.005943476680840831, 0.03865725164359901, 0.038711985034751706, 0.03126702671579551, 0.08239239643444307, 0.032743481278885156, 0.00528479557033279, 0.06589181895833462, 0.05948089870798867, 0.031014282758405898, 0.009469190226809587, 0.03845119434117805, 0.03932529216399416, 0.05912696105951909, 0.0365064742800314, 0.012165434072812786, 0.08780465679592453, 0.0324808315053815, 0.05558316508540884, 0.003783370984820067, 0.033852691485662945, 0.038105167986941524, 0.1005100914335344, 0.030270533898146823, 0.03717687483003829, 0.01490915217800648, 0.023341056512435898, 0.028767851836164482, 0.0301127161947079, 0.03152868572215084, 0.027550655431696214, 0.01259639273484936, 0.059570286684902385, 0.042306417744839564, 0.01858647072367603, 0.021152835943212267, 0.04038945771753788, 0.04561829999147449, 0.05227655950875487, 0.06632303644437343, 0.037927798402961344, 0.08941692067310214, 0.049296814322588034, 0.06524589072796516, 0.041464696114417166, 0.09441959715331905, 0.05851685629750136, 0.03702034846355673, 0.010836889541678829, 0.04243137314915657, 0.02105445684719598, 0.08531511499313638, 0.06510743565740995, 0.0060023860442015575, 0.05917199086979963, 0.08715791962458752, 0.03650390273833182, 0.005015780952817295, 0.012172425103926798, 0.09145024945610203, 0.04359035177913029, 0.017982275312533602, 0.027188721142010763, 0.006023087325957022, 0.01572494595166063, 0.042436497678863816, 0.025281704038206954, 0.10471009809407406, 0.12998621561564505, 0.015351051952166017, 0.06995417206780985, 0.031211948225973174, 0.04477479349588975, 0.06228846192243509, 0.0508201837510569, 0.0349353290948784, 0.015515664945269236, 0.03150380893202964, 0.03543334729329217, 0.004169535004621139, 0.03555561612301972, 0.0737431253946852, 0.028717489694827236, 0.013064274171483703, 0.058299978481954895, 0.025997616794484202, 0.04769658436998725, 0.06933847893378697, 0.04578168009174988, 0.026161790992773604, 0.04022273795271758, 0.013335318562894827, 0.07125430347514339, 0.09581262318533845, 0.031937802050379105, 0.036009903269587085, 0.04914437347906642, 0.03700615117850248, 0.022546210784639698, 0.03724970549228601, 0.06805770273786038, 0.01332877560344059, 0.05935157947533298, 0.06936882535228506, 0.049738047091523185, 0.05204945118748583, 0.041314659829367884, 0.08905093796784058, 0.028147846824140288, 0.0415953771880595, 0.026055988564621657, 0.010853436651814263, 0.01560660864925012, 0.04938447680615354, 0.01622704596229596, 0.026098346643266268, 0.037004551850259304, 0.014984992249083007, 0.06074503966374323, 0.059448596730362624, 0.03725894152012188, 0.0091058477119077, 0.04997729694878217, 0.04220721857564058, 0.05374313237552997, 0.04860898814513348, 0.010756244064396014, 0.030834959470666945, 0.04798065623617731, 0.022569011416635476, 0.033737361736712046, 0.03090443748078542, 0.028283509564062115, 0.09695173823274672, 0.061199156116344966, 0.012952747001691023, 0.05003438294806983, 0.021789837992400862, 0.022335229332384188, 0.03424491282203235, 0.06603368790820241, 0.01083148021280067, 0.043680685994331725, 0.024770612908469047, 0.07052954431856051, 0.07643882840056904, 0.04703293365309946, 0.04075293196365237, 0.03192535994458012, 0.042576463019941, 0.0275173942281981, 0.0675637589301914, 0.009494425103184767, 0.007997479842742905, 0.043765090449596755, 0.034090835542883724, 0.04802151146577671, 0.021960815829515923, 0.033646140655037016, 0.04304848378524184, 0.022049283543310594, 0.01230429546922096, 0.1307681275648065, 0.02992569498019293, 0.055937006254680455, 0.06892740333569236, 0.04405147410579957, 0.03378952729690354, 0.037879120936850086, 0.06376751029165462, 0.030302257000585087, 0.02588425559224561, 0.009420644491910934, 0.0657614236115478, 0.04494445587624796, 0.03823551880486775, 0.023361986932286527, 0.02182914955483284, 0.02810841837344924, 0.030734866013517603, 0.010495623137103394, 0.02832721464073984, 0.013844941167917568, 0.026041110359074082, 0.010178316970268497, 0.056007821985986084, 0.06564995303051546, 0.04084605294337962, 0.026118321547983214, 0.014727722118550446, 0.030581818464270327, 0.02131988225301029, 0.003377299781277543, 0.045789940195390955, 0.05941263967542909, 0.013390949025051668, 0.059280340719851665, 0.032360603581764735, 0.03031754524272401, 0.041073328247875907, 0.06457982803112827, 0.06961159670026973, 0.060442915055318736, 0.05159144217032008, 0.01972025344002759, 0.033468173642177135, 0.043813393131131306, 0.00626527284111944, 0.06308871234068647, 0.06903753062942997, 0.03390468264115043, 0.07070846870192327, 0.021459764102473855, 0.02646051099873148, 0.043791874559246935, 0.05447152434499003, 0.03619059767515864, 0.04636623641999904, 0.06660430299234577, 0.01428281200787751, 0.04939994316373486, 0.011243659755564295, 0.04963409446645528, 0.01802312497602543, 0.009995425807574065, 0.007053701310724136, 0.03398020729946438, 0.021879084961256012, 0.08432572823949158, 0.03135642582492437, 0.059759096475318074, 0.07076044130371884, 0.04305671791371424, 0.03187251160852611, 0.053901955689070746, 0.07186351023847237, 0.008891025645425543, 0.03537388642143924, 0.09650414154748432, 0.020145552298345137, 0.08730668312637135, 0.06695115313050337, 0.036430686159292236, 0.021529223558900412, 0.020049874619871844, 0.16294815548462793, 0.16935268213273957, 0.08222205869969912, 0.23939042002893984, 0.1623734214808792, 0.08978330413810909, 0.1008038037980441, 0.1791303145000711, 0.19319843617267907, 0.20186317357001826, 0.12686923990258947, 0.13260356266982853, 0.28920313459821045, 0.15025762317236513, 0.10404445842141286, 0.10936117469100282, 0.1379252810147591, 0.11381069882190786, 0.13393125002039596, 0.14846811216557398, 0.11496962179080583, 0.0879133962735068, 0.10026303047197871, 0.15379407559521496, 0.22059820184949785, 0.16112747427541763, 0.15726841025752947, 0.12736227829009295, 0.12640006898436695, 0.1324713119538501, 0.14913911756593734, 0.15659191296435893, 0.10818632523296401, 0.23583933245390654, 0.19152363151079044, 0.17376696167048067, 0.10148844245122746, 0.12911030324175954, 0.3282803267939016, 0.0722006605064962, 0.07892165376688354, 0.12781204946804792, 0.1079090143321082, 0.13040762190939859, 0.185845029191114, 0.1285467459820211, 0.11715851214830764, 0.13000582315726206, 0.12152524228440598, 0.16884649288840592, 0.1631897097104229, 0.163315043610055, 0.07968959849677049, 0.12457671604352072, 0.2410614100517705, 0.2203780214767903, 0.14998843136709183, 0.11351889377692714, 0.17113486072048545, 0.12372602184768766, 0.2844406838994473, 0.16342479240847751, 0.13546495756600052, 0.13619065925013274, 0.17476912820711732, 0.18071858474286273, 0.15410861262353137, 0.14161454164423048, 0.11197077372344211, 0.1534184894990176, 0.13877656892873347, 0.3036578855244443, 0.10961751991999336, 0.1606350889778696, 0.07274983494426124, 0.12954926874954253, 0.1393379145883955, 0.1151876054063905, 0.2138499717693776, 0.20471394091146067, 0.10715722615714185, 0.11818979313829914, 0.16386809205869213, 0.10029017081251368, 0.13589400798082352, 0.0928419322008267, 0.11902726968401112, 0.22021485288860276, 0.1626054910593666, 0.19141348195262253, 0.13804576126858592, 0.1460841260268353, 0.13875860895495862, 0.1642609405098483, 0.16754213866079226, 0.19215788575820625, 0.17002159467665479, 0.10918295534793288, 0.13909321365645155, 0.1235413680842612, 0.1278536839527078, 0.11729430290870368, 0.15263454406522214, 0.11249853720073588, 0.15998143499018624, 0.18089362769387662, 0.1534458005335182, 0.08754883107030764, 0.14735166972968727, 0.18303093878785148, 0.11662008400890045, 0.18547120940638706, 0.16297533293254673, 0.10524016222916543, 0.13367191393626854, 0.08274179213913158, 0.06530750382808037, 0.17144632525742054, 0.1103644841350615, 0.10309401957783848, 0.1052414758305531, 0.13659888500114903, 0.11041798556107096, 0.1338944840244949, 0.16247278021182865, 0.2083442304865457, 0.10485562583198771, 0.14736376673681661, 0.11605265273828991, 0.1661553466692567, 0.21335261408239603, 0.1879809598904103, 0.17664607905317098, 0.21250987570965663, 0.1946943684015423, 0.1675167423672974, 0.09595196883310564, 0.15508520475123078, 0.11391494088456966, 0.13722499046707526, 0.09591003006789833, 0.09134043386438861, 0.15272422519046813, 0.14181336300680414, 0.1929954587831162, 0.09142613707808778, 0.22820534912170842, 0.17203759431140497, 0.12988495698664337, 0.16701122105587274, 0.18232352362247184, 0.19154319452354684, 0.15872922405833378, 0.18047066289000213, 0.09066557671758346, 0.09280003054300323, 0.10879131659748964, 0.13092742214212194, 0.14949678821722046, 0.13403604127233848, 0.13891474198317155, 0.1992794606485404, 0.1650779857300222, 0.1418206063681282, 0.1429831955465488, 0.15032713272375986, 0.19242495502112433, 0.10010481943027116, 0.09321296151028946, 0.23548448196379468, 0.07669353348319419, 0.1552283501951024, 0.17909613117808476, 0.1413920012419112, 0.21011981880292296, 0.21096576325362548], [0.043697347209672444, 0.013153785530448658, 0.0006827643244378123, 0.08833165586111136, 0.0032514289841856225, 0.014057666667213198, 0.010955849320453126, 0.03608381004596595, 0.011807658593170345, 0.0811370462179184, 0.04548629418422934, 0.06094816548284143, 0.0052406623672140995, 0.06949774382519536, 0.08614678794401698, 0.0485990248125745, 0.0573510053800419, 0.05398432294896338, 0.01187911906527006, 0.08342131739482284, 0.02926902972831158, 0.05008638894651085, 0.03959622059483081, 0.01706647435639752, 0.02152834968001116, 0.025659765196905937, 0.05778254198958166, 0.034060656107612886, 0.029457433192874305, 0.06307069299509749, 0.09290376052376814, 0.05632039232295938, 0.053213327992125414, 0.07007395470282063, 0.03703470902109984, 0.042175068738288246, 0.0360284458292881, 0.07066324222250842, 0.023558426000818145, 0.012297752509766724, 0.07972803432494402, 0.020906240679323673, 0.06748232306563295, 0.038030875293770805, 0.017037801480910275, 0.05366095807403326, 0.007826720939192455, 0.06676306322333403, 0.020767247551702894, 0.006700250696667354, 0.04194830180495046, 0.058241382212145254, 0.03790989409026224, 0.039844754719524644, 0.054965549788903445, 0.049920177552849054, 0.05622720826067962, 0.01268775760763674, 0.040106506494339556, 0.021615088189719245, 0.03270767265348695, 0.0394516131200362, 0.08299073073430918, 0.03718656356795691, 0.05302811390720308, 0.06260838694288395, 0.022716264647897333, 0.014255896167014726, 0.032166583914658986, 0.0925274842302315, 0.03571344495867379, 0.019702094941749237, 0.029226187398307957, 0.061735899580526166, 0.06193492874444928, 0.07484984569600783, 0.05607956169114914, 0.040675199416000396, 0.044276530388742685, 0.03413664089748636, 0.03493239761155564, 0.04387402288557496, 0.032899502984946594, 0.04777573070896324, 0.06620805550483055, 0.030166737124091014, 0.02306776434124913, 0.029880409128963947, 0.028643265650316607, 0.016117482700792607, 0.037062758492538705, 0.03800767575739883, 0.06254969790461473, 0.032003971937228926, 0.014359566775965504, 0.010916839255514788, 0.006049441917639342, 0.0678348951623775, 0.09301703452365473, 0.05950664010015316, 0.03159485189826228, 0.03353582040290348, 0.03765564542845823, 0.03523106381180696, 0.027352628167136572, 0.03667349461466074, 0.03956719519919716, 0.03558763979526702, 0.05234909702267032, 0.01791114787920378, 0.12414313110639341, 0.04826210089959204, 0.03679344052216038, 0.021615787663904484, 0.03750810647034086, 0.008757742416491965, 0.04602538283506874, 0.05628388607874513, 0.02163924880733248, 0.03229001791623887, 0.05614049201540183, 0.1435708874487318, 0.038858266052557155, 0.02702819459955208, 0.08815344393951818, 0.02141270637366688, 0.03167433220369276, 0.04263173075742088, 0.019912428870156873, 0.028248567396076396, 0.02739181541983271, 0.037584102392429486, 0.12041893758578226, 0.07465989299817011, 0.040559914195910096, 0.04704050727013964, 0.017455430242989678, 0.009249189824913628, 0.055560956316185184, 0.03960248803196009, 0.07075672314385884, 0.024766751885181293, 0.07891463304986246, 0.019088605986326, 0.05941614261246286, 0.06517923102364875, 0.046707253277418204, 0.0541732366400538, 0.016113142992253415, 0.01922648403706262, 0.028562577499542385, 0.006392033055817592, 0.05400680631282739, 0.0687732444202993, 0.03859541589918081, 0.09446089025004767, 0.014006003912072629, 0.03925364151655231, 0.03392520302440971, 0.04337061669502873, 0.049733271371223964, 0.010639758420438739, 0.03627919155405834, 0.025159650431305636, 0.005390853111748584, 0.03251725240261294, 0.05327199476596434, 0.07339793766732328, 0.02583019570010947, 0.047629401451558806, 0.02593324661575025, 0.04055543162394315, 0.031912383492453955, 0.016973590863926802, 0.023894789592304733, 0.06425668951123953, 0.008056451824813848, 0.03965284275182057, 0.029300582136784215, 0.04227935532981064, 0.08834571955958381, 0.014695701229356928, 0.011376114562153816, 0.04801891765964683, 0.023537308188679162, 0.0420070761902025, 0.023505210301664192, 0.06186459169839509, 0.011867813373100944, 0.03239106874389108, 0.06658245416474529, 0.02283784699102398, 0.05032843298977241, 0.02487695153831737, 0.030471032514469698, 0.017713597444526386, 0.06316991071798839, 0.06035162718035281, 0.016665451148583088, 0.021520714835787658, 0.060205835980013944, 0.05725956907554064, 0.007280841637111735, 0.017999081246671267, 0.030866263259667903, 0.02640545106260106, 0.10854552470846102, 0.056507465487811714, 0.06549322628416121, 0.023834603271097876, 0.04751473963551689, 0.06508450329420157, 0.059567280986811966, 0.07681158691411838, 0.036369117588037625, 0.015416644819197245, 0.10161295998841524, 0.06266649710596539, 0.0663202979194466, 0.04027607981697656, 0.04245838732458651, 0.01976343715796247, 0.0095406293621636, 0.03648067722679116, 0.10529347069677897, 0.0019001823875441914, 0.03125750125036575, 0.07447658994351514, 0.03999822343757842, 0.0731254655693192, 0.0899800326442346, 0.037447528666234575, 0.029848789927200414, 0.0960254340316169, 0.0489875279890839, 0.016392645084124524, 0.017800321111280937, 0.03353291489474941, 0.021227599900157657, 0.05846597094205208, 0.023837185945012607, 0.012652299647015752, 0.009887041633191984, 0.030203382520994637, 0.05385828029830009, 0.02256095911434386, 0.03865522186970338, 0.03763839049497619, 0.03365119468071498, 0.04523086921835784, 0.015011985087767243, 0.09433787185116671, 0.00929080204514321, 0.006431491192415706, 0.028590448855538853, 0.053286117836250924, 0.07804490276612341, 0.05234653661318589, 0.02053084383078385, 0.036636502263718285, 0.05361032504879404, 0.01781003396899905, 0.02780421946226852, 0.06227693636901677, 0.02533240014599869, 0.03389287507161498, 0.018566096914582886, 0.03678509878227487, 0.03453899254964199, 0.04056752492033411, 0.029312669867067598, 0.004176098373136483, 0.03806765242188703, 0.06416526433895342, 0.06904710433445871, 0.031070123804965988, 0.04634606484614778, 0.040297691157320514, 0.08339975800481625, 0.01646321590669686, 0.011126183344458696, 0.01853067420597654, 0.04178178984147962, 0.013654720369231654, 0.0322570554271806, 0.06159069838759024, 0.04533032813924365, 0.05890767126402352, 0.04950882736011408, 0.03473825920082163, 0.03830267574812751, 0.030022226128494367, 0.03494508462608792, 0.07577464333735406, 0.013956116745248437, 0.033748538480722345, 0.024162185400200542, 0.03360350056027528, 0.03107049302343512, 0.024305393926624674, 0.023264739611477125, 0.0918369677674491, 0.05311441454978194, 0.08497890725266188, 0.04625624271284323, 0.025320514650957193, 0.06293603772064671, 0.030447803292190656, 0.034269630050403066, 0.032350781257264316, 0.0339739843911957, 0.029082099426886998, 0.06008948206726927, 0.07755360842566006, 0.013684367313544499, 0.03827097862085793, 0.0421147024462698, 0.04220951181196142, 0.08257612251327373, 0.03388996214198414, 0.04415461778989993, 0.06323653331492096, 0.03447175768087618, 0.024281953192257788, 0.02972812784719281, 0.03164564448525198, 0.09378866772749461, 0.11676743743009865, 0.015866803769313265, 0.06958991114515811, 0.08109233182040043, 0.05697200169379357, 0.03407268632145133, 0.012014224266749807, 0.032644066886859946, 0.03443549634539522, 0.08226970458053984, 0.05683091570972465, 0.026845552056329325, 0.09893205540720373, 0.03721550732734613, 0.10476728799403645, 0.020099409266549628, 0.01896945046610199, 0.027336313905834686, 0.00831375071356888, 0.03688128483190667, 0.06714066053973511, 0.0655715080210939, 0.061428464905475266, 0.018862536671804264, 0.02884272897063056, 0.09443938281037845, 0.12498200288973749, 0.12769213324645534, 0.15066406776895747, 0.22835425363155082, 0.10371502648922615, 0.18040023307548836, 0.1438888828852214, 0.0728850913583301, 0.19822510628728196, 0.10362237677327357, 0.18565692444099113, 0.09816051868256181, 0.11792521007009782, 0.17294724471867085, 0.10916440907749347, 0.1757554869982414, 0.15953200520016253, 0.08238312700996175, 0.14122861000942066, 0.15106882026884705, 0.1152060626191087, 0.10825578283402137, 0.12663810543017462, 0.1258902283734642, 0.11588164707063697, 0.16072573489509523, 0.18351262231590226, 0.07141706388210878, 0.09667387814261019, 0.28020411904435605, 0.17922100494615734, 0.13069155276753008, 0.13982399163069203, 0.1237433213100303, 0.15040565194794908, 0.19952416158048436, 0.15561564738163725, 0.11292256327578798, 0.09127588185947388, 0.22455892525613308, 0.1020187811809592, 0.13384159858105704, 0.1824985072016716, 0.048116087054950185, 0.0934530833910685, 0.06259424160816707, 0.14086719893384725, 0.18413935118587688, 0.15447391255293041, 0.07961840427014977, 0.17524628463434055, 0.14267076621763408, 0.11877522149006836, 0.18666271265828982, 0.16928510216530412, 0.24844919331371784, 0.13282012136187404, 0.09824925728025846, 0.10928149029496126, 0.12485079118050635, 0.20831050729611889, 0.11876158823724836, 0.12066758674336597, 0.1586233195848763, 0.13368341722525656, 0.06992686845478602, 0.15257879393175244, 0.17624555679503828, 0.11244266832363792, 0.08865302806952968, 0.09978554749977775, 0.10406920162495226, 0.19103623344562948, 0.19073170056799427, 0.13483690767316148, 0.1506530394544825, 0.174079658172559, 0.10899254251853563, 0.13221985747804865, 0.134294739109464, 0.10807100290548988, 0.1226003174087964, 0.20696070394478738, 0.1810767303686589, 0.09002488804981112, 0.06763954705093056, 0.061356086953310296, 0.1004990705405362, 0.14835573616437614, 0.10008879646193236, 0.12340142129687592, 0.18931256578071043, 0.10393214921350591, 0.15012234449386597, 0.1326156745199114, 0.1575298688840121, 0.1139011443592608, 0.19821765512460843, 0.18281918921275064, 0.10824487326317467, 0.2196094681858085, 0.18662386864889413, 0.0868212962814141, 0.09221530723152682, 0.11822562402812764, 0.12719873862806708, 0.10280055954353884, 0.10236557194730267, 0.1626745256362483, 0.2851924201240763, 0.1418419208494015, 0.08387054680497386, 0.08443105383776128, 0.1263550651492551, 0.16053875820944086, 0.1828298019245267, 0.11472471305751242, 0.2133847787627019, 0.17466138320742175, 0.10448056666064076, 0.28720313566736877, 0.07615739858010784, 0.12647064722841606, 0.10474629263626412, 0.1513990166131407, 0.14115956058958545, 0.16333836189005524, 0.16606811463134363, 0.09969821898266673, 0.21153666777536273, 0.1869798472034745, 0.19499180634738877, 0.20560236589517444, 0.09922184923198074, 0.13816848280839622, 0.08821269701002166, 0.09071678490727209, 0.09292561677284539, 0.15771574719110504, 0.16387561743613333, 0.11501075903652236, 0.12907303258543834, 0.13433310814434662, 0.08704288673470728, 0.12113588934880681, 0.16595251770922914, 0.13712529034819454, 0.07632511653355323, 0.10010532409069128, 0.11248964627156965, 0.1795657176990062, 0.1600228765164502, 0.14845763304037973, 0.19691681867698207, 0.2497313276398927, 0.10941950749838725, 0.13486421870766208, 0.17523862567031756, 0.17592339048860595, 0.13385273079620674, 0.23706501902779564, 0.07056943475618027, 0.15287261019693688, 0.12411556032020599, 0.1452784801949747, 0.12604029063368216, 0.17595375917153433, 0.09392163090524264, 0.12411775707732886, 0.06721604047925211, 0.11259114980930462, 0.22512092400575057, 0.17520142922876403, 0.16991062875604257, 0.15428421960677952], [0.022908612627361435, 0.07569508510641754, 0.03184412817063276, 0.014072543945076177, 0.07443856971804053, 0.01988651121791918, 0.008802120992186246, 0.0301133358880179, 0.04520571783359628, 0.04897619910479989, 0.06828516357927583, 0.07094626023899764, 0.037220249650999904, 0.019949334018747322, 0.046081941909505986, 0.02361939157708548, 0.05775236255431082, 0.028786433358618524, 0.029020033616689034, 0.036758719143108465, 0.014193930546753109, 0.03149867327010725, 0.05571336376306135, 0.02931328213890083, 0.10520842057303526, 0.038231195794651285, 0.03688778233481571, 0.031964426598278806, 0.024182156594179105, 0.024211085510614794, 0.044934355246368796, 0.01877117272670148, 0.06808013786212541, 0.05421381727501284, 0.025574485007382464, 0.04155577618803363, 0.09521110507193953, 0.06811038037994877, 0.08965742104919627, 0.05327841063262895, 0.018699342108448036, 0.04795121894858312, 0.009201347274938598, 0.008194739912141813, 0.01589614086697111, 0.04315222118748352, 0.029509567211789545, 0.06693363102385774, 0.04286310271709226, 0.054731925411033444, 0.023254006300703622, 0.009535336921544513, 0.05200888168474194, 0.05903065997699741, 0.06415577969164588, 0.0505531404633075, 0.03372118662809953, 0.053773998297401704, 0.05034040012105834, 0.03908038714143913, 0.01628863494261168, 0.052226702027837746, 0.01688485968770692, 0.044916428669239394, 0.06019724933139514, 0.04539616405963898, 0.06594114951440133, 0.08941441221395507, 0.03342528492794372, 0.032709832303225994, 0.04708904743893072, 0.06406477754353546, 0.06745476712239906, 0.05415487590653356, 0.07192311953986064, 0.11107048921985552, 0.022869275089760777, 0.04291722012567334, 0.02806626995152328, 0.06832316896179691, 0.042514727465459146, 0.05452190504001919, 0.013365393169806339, 0.04021274493425153, 0.05069424871180672, 0.005335594651114661, 0.06327044946374372, 0.03026222369953757, 0.03664923751784954, 0.04986161467968486, 0.01624289452593075, 0.03888165483658668, 0.08471640219795518, 0.015011194700491615, 0.06703515682602301, 0.023781873678672127, 0.06241136899916455, 0.09737779037095606, 0.04276153980754316, 0.036238499596947804, 0.03196043755451683, 0.032742171388235874, 0.03298772579000797, 0.06054979174223263, 0.02555252671299968, 0.0022476178946817527, 0.02879379546357086, 0.029477925745595712, 0.07639081886736676, 0.04618533421307802, 0.023307797164306976, 0.014418163045775145, 0.02062876465060981, 0.04461764001462143, 0.03767873364267871, 0.023135323899623472, 0.04548918856016826, 0.022948222904233262, 0.02928434951172676, 0.034768627883750014, 0.029339689608605113, 0.015414851604873547, 0.04354555203462951, 0.04123818522202782, 0.018772395414998755, 0.05648555357765872, 0.04619873368937988, 0.06424627717933618, 0.036759201539098285, 0.05037269467720762, 0.04196407615381759, 0.01861690619989531, 0.012275136487005511, 0.09556736564263701, 0.04611623284290545, 0.06006814903230406, 0.026149044606427196, 0.03634867513028439, 0.015168676582106855, 0.03920183589798398, 0.04270901801646687, 0.021025249625381548, 0.03492418945825193, 0.031138768754317425, 0.03131603814836126, 0.06278449858655222, 0.00989659678452881, 0.032987362137646414, 0.04622591113729868, 0.027677703692461364, 0.020946830591128673, 0.03602590768423397, 0.023286061514227185, 0.016070506608230062, 0.06313477744697593, 0.05513039563084021, 0.060473784687928855, 0.03088759258389473, 0.0724312754755374, 0.01939385874720756, 0.0051121121850883355, 0.012247800405020826, 0.09538565820548683, 0.02721854249102762, 0.03172389653627761, 0.021594595636997838, 0.054752490323153324, 0.028735906089423224, 0.02177695987484185, 0.035525499770301394, 0.03268214648414869, 0.053850302210776135, 0.04972736758645624, 0.04402397382364143, 0.04972164191713091, 0.03987583586422261, 0.04817492081201635, 0.053684706799685955, 0.03581413213396445, 0.03166400521877222, 0.018705205075093545, 0.02048208101768978, 0.01598441191163147, 0.03698941203765571, 0.04279014217900112, 0.031125434215937275, 0.0069702440214314265, 0.03117903026577551, 0.043990176418446936, 0.01294611683988478, 0.028102516444050707, 0.04852823505643755, 0.12137669400544837, 0.06529533260618336, 0.03705296214320697, 0.011261404506512918, 0.02351185252337018, 0.006095122962506139, 0.05572379464865662, 0.042965827087755315, 0.008920289456000319, 0.05298840158502571, 0.02507645753212273, 0.04712079280579928, 0.03258747441577725, 0.02505246018699836, 0.029345554430619814, 0.011552930318430299, 0.03552686903276481, 0.009739443303260487, 0.048967887050821446, 0.05727758471039124, 0.07517719219322316, 0.058435038226889446, 0.021056046898593195, 0.009391636722284602, 0.03278750918980222, 0.03658644069219008, 0.021805215292260982, 0.028666914186032955, 0.0219738126907032, 0.03421582434384618, 0.041897286573657766, 0.01008891229503206, 0.05357970774639398, 0.03011846412846353, 0.004049852095704409, 0.013629013301397208, 0.03470320385531522, 0.022542693004652392, 0.02307058821315877, 0.02456885078572668, 0.06357028454658575, 0.03930197017325554, 0.0075574776474240934, 0.07652122905710712, 0.0072807887590897735, 0.010332198507967405, 0.025775013309612405, 0.02431542961858213, 0.03143379472021479, 0.009106876514124451, 0.06682049803202972, 0.05816732700623106, 0.05854974086105358, 0.0390746837365441, 0.02229497524240287, 0.018493700408726, 0.02559268061304465, 0.035877852933481336, 0.027939217980019748, 0.03105729763774434, 0.0614427549589891, 0.019006325928785373, 0.02691560708626639, 0.031491303743678145, 0.042616743085091, 0.0498551654163748, 0.03521807251672726, 0.05613689630990848, 0.02855317077774089, 0.01355789421722875, 0.013143185806256952, 0.014017086959938752, 0.0150224410208466, 0.03265004117565695, 0.011703203163051512, 0.025947783433366567, 0.001986952670449682, 0.02258263724797871, 0.03333845736051444, 0.00777861167989613, 0.06500253308331594, 0.08230972118326463, 0.014090298900555354, 0.030827191039861646, 0.026902279969363008, 0.047701374933240004, 0.04985079787729774, 0.03519308811519295, 0.09308448832598515, 0.06584905640920624, 0.06459143522079103, 0.067923225578852, 0.038410895722336136, 0.016539729476789944, 0.060076928639318794, 0.018951867132273037, 0.026410540340293664, 0.03946699041989632, 0.011925324251933489, 0.032302972103934735, 0.12356629682471976, 0.009451604109926848, 0.056065627868520096, 0.03341128431202378, 0.049486232674098574, 0.047774053455214016, 0.09041009237989783, 0.05667432626069058, 0.04715580362244509, 0.02980746157845715, 0.032727254219935276, 0.059701947393477894, 0.03338049631565809, 0.01741813546686899, 0.011760928337025689, 0.026604584127198905, 0.0287718538675108, 0.05489003255206626, 0.04937255049298983, 0.04075881719472818, 0.047643275902373716, 0.01993600690184394, 0.035252022062195465, 0.07212588170659728, 0.05734160979045555, 0.004288538384571439, 0.05689492594683543, 0.024025876991800033, 0.06076504054362886, 0.027716926197172143, 0.025935478624887764, 0.0719741867214907, 0.08909850963391364, 0.05439182139525656, 0.05249359688605182, 0.0549902150669368, 0.061942750980961137, 0.041922946329577826, 0.02069282312731957, 0.07413817060296424, 0.04794510365172755, 0.037604355602525175, 0.042837906803470105, 0.018767063083942048, 0.03007340092153754, 0.05010891683923546, 0.03139703614579048, 0.05810545786516741, 0.00949548451899318, 0.058227797198924236, 0.07166386509197764, 0.013172931085136952, 0.036655081930803135, 0.03403802060347516, 0.031637688662158325, 0.04217480898660142, 0.08355012454558164, 0.028864151063316967, 0.022283562866505235, 0.008167092128132936, 0.1341303830849938, 0.16544662532396615, 0.09148811383056454, 0.08315068582305685, 0.13864347216440365, 0.09115307868341915, 0.11161352609633468, 0.090216488315491, 0.13494604791048914, 0.1512407758855261, 0.10279522350174375, 0.13149185513611883, 0.14466962224105373, 0.07565714651718736, 0.19328510417835787, 0.06313390171271749, 0.22701402398524806, 0.13756600732449442, 0.11747214375645854, 0.14078364794841036, 0.183668220997788, 0.10814492081408389, 0.07128452372853644, 0.1366562381736003, 0.13684046891285107, 0.16842011420521885, 0.12403091837768443, 0.11858698315336369, 0.12064715541782789, 0.1882859825855121, 0.12727943976642564, 0.11833377720904537, 0.10115147029864602, 0.11946035738219507, 0.09699473826913163, 0.17812655976740643, 0.20917917630868033, 0.1162896872847341, 0.2529138943646103, 0.14035243046237156, 0.09542484360281378, 0.13987564510898665, 0.1551700322306715, 0.08398737569223158, 0.10799134077387862, 0.15940612211124972, 0.17771315382560715, 0.08959482089267112, 0.1747968400013633, 0.2248679703916423, 0.10897895379457623, 0.08966746972873807, 0.13661041797604412, 0.1675721659557894, 0.16521286364877596, 0.13510077085811645, 0.12315013751504011, 0.1257106731645763, 0.14959331194404513, 0.20821601705392823, 0.11956440648646094, 0.13958539115265012, 0.09526895548333414, 0.13808503572363406, 0.14400982327060774, 0.13424504490103573, 0.1589941410929896, 0.16105263610370457, 0.08614518490503542, 0.13549952680477872, 0.2515263750683516, 0.07899900781922042, 0.16054168227128685, 0.12979955063201487, 0.17057627585018054, 0.12890662823338062, 0.11422398602007888, 0.11668833190924488, 0.12088379662600346, 0.09956749709090218, 0.13582889194367453, 0.1210126186197158, 0.15758008259581402, 0.20103318529436365, 0.21871549193747342, 0.08568461547838524, 0.23279032262507826, 0.11360618518665433, 0.11939512260141782, 0.11409008031478152, 0.12089799391105771, 0.172322207945399, 0.11444252624642104, 0.14241024269722402, 0.12907561525935307, 0.12220106422319077, 0.15925696527119726, 0.2797686861595139, 0.11699797818437219, 0.14668631949461997, 0.15766820521093905, 0.09225143498042598, 0.13080582866678014, 0.1296320924302563, 0.18245173705508932, 0.13919886579969898, 0.13157175475498661, 0.10065123307867907, 0.14614472980611026, 0.10911537538049743, 0.15639622346498072, 0.18885739176766947, 0.1491202670149505, 0.1592479259124957, 0.1389461793587543, 0.0836321763927117, 0.16125309019116685, 0.12976523372344673, 0.111382354516536, 0.10116996461874805, 0.2515069011133164, 0.1551586773712188, 0.12174689953099005, 0.12678901373874396, 0.11151226004585624, 0.13555074983742088, 0.11868277957546525, 0.17160790564958006, 0.09999972389778122, 0.13859889877494425, 0.1777258890797384, 0.09214896665071137, 0.1182976271957159, 0.22425578761612996, 0.21418968244688585, 0.15377402276499197, 0.11094369328930043, 0.1558260462479666, 0.19167972001014277, 0.10964023706037551, 0.15015186712844297, 0.08640092157293111, 0.17987170518608764, 0.14123787201242521, 0.2727639104705304, 0.12817540497053415, 0.08962875188444741, 0.13571811898145825, 0.2167317460407503, 0.16207907086936757, 0.16789572749985382, 0.11673068627715111, 0.1515963685233146, 0.06907518720254302, 0.20903540746076033, 0.10210032836766914, 0.15095322334673256, 0.11137612789752893, 0.1087778688815888, 0.16655582439852878, 0.13694291497813538, 0.09742670532432385, 0.1344713257276453, 0.24767468799836934, 0.10499511990929022, 0.12664004985708743, 0.16664811788359657, 0.14851552055915818, 0.16410958691267297, 0.07997876149602234, 0.08041175271500833, 0.06548440214828588, 0.161237608990632, 0.10752911635790952, 0.21283950802171603, 0.2161629789043218], [0.0414832572278101, 0.0212810827724752, 0.02089249981509056, 0.022424435483117122, 0.04398487748403568, 0.03615379086113535, 0.03877089300658554, 0.02737321348831756, 0.11127963385661133, 0.030656075905426405, 0.03932298037398141, 0.09298842473072, 0.06038390318281017, 0.004987293150406913, 0.019916239798476454, 0.037176574260229245, 0.07611698863911442, 0.029118889542587567, 0.03246666019549593, 0.05764439491031226, 0.025443538615945727, 0.013636479307024274, 0.03956562184612267, 0.007889173593866872, 0.07768160663545132, 0.0705508142709732, 0.025051578886632342, 0.011236325481149834, 0.049824529560282826, 0.026153634789807256, 0.03775268865865655, 0.040451961394865066, 0.030847559282847214, 0.03515788062941283, 0.003243487308282056, 0.06477076036389917, 0.04695383184298407, 0.01799655979993986, 0.02721877255680738, 0.030739163048565388, 0.011450808015069924, 0.024646416350151412, 0.042741854340420105, 0.031077727107913233, 0.016216872973018326, 0.041343718621646985, 0.06573965642019175, 0.035995880389236845, 0.017988743129535578, 0.04601584623742383, 0.049728373196558096, 0.09428686404135078, 0.024639371513330843, 0.026319282151234802, 0.0872465617430862, 0.06208472012076527, 0.054762531581218354, 0.026883310674747918, 0.04109729590709321, 0.05834367613715585, 0.02614084201923106, 0.04902569664409384, 0.0848642380151432, 0.026872748057940044, 0.0227044533676235, 0.04337741105700843, 0.06953781979973428, 0.07112236446118914, 0.024260555219370872, 0.03734841484401841, 0.016016329827834852, 0.011289509639027528, 0.02898546437791083, 0.07020377859589644, 0.025866438481898513, 0.05873619062185753, 0.023706614338152576, 0.05760112027928699, 0.03952557555749081, 0.015838733888813294, 0.04795020220626611, 0.04137562726100441, 0.01997794010094367, 0.004604423338605557, 0.017398464842699468, 0.019978728632850107, 0.033855986621347256, 0.08025507049751468, 0.09008271619677544, 0.03709774333401583, 0.025268391764257103, 0.0033621395596128423, 0.02615437508211471, 0.01730300053168321, 0.007917457769508474, 0.06239736467250623, 0.012923021204187535, 0.04938111116643995, 0.021019149171479512, 0.045936243477626704, 0.04573098769469652, 0.03174188619595952, 0.019139003379677888, 0.029586685632239096, 0.05543056468013674, 0.031143255037022755, 0.053897387770120986, 0.008113001622405136, 0.05694705068890471, 0.03130911019979976, 0.05401164882641751, 0.03906424914021045, 0.04674430500017479, 0.04465016463655047, 0.04884872781985905, 0.04130833302042447, 0.01610994619113626, 0.008743038615648402, 0.06352704702294432, 0.02211849066952709, 0.05510553739441093, 0.011052437057514908, 0.04234626736433711, 0.016155078046722338, 0.014184970041242195, 0.03409393029869534, 0.06907790346303955, 0.07726581839961, 0.06006515075569041, 0.00793071994849015, 0.06933007040061057, 0.015587331363349222, 0.08940506857470609, 0.04341683023085352, 0.05209542352531571, 0.024119554582284763, 0.04062522319145501, 0.03714521852089092, 0.03688499185955152, 0.04702839542005677, 0.010824622768268455, 0.0918429197918158, 0.04570204022456892, 0.041963408220908605, 0.027839250687975436, 0.021433464244182687, 0.03036358808458317, 0.03121345849649515, 0.01783609634003369, 0.046450414520222694, 0.009074539284483762, 0.05281863901473116, 0.048973831653711386, 0.06110321126470808, 0.055463965036324225, 0.061362328415270895, 0.038426914979936555, 0.0323816805757815, 0.045749122073175386, 0.04197172027488705, 0.028557616242324002, 0.012952107827004511, 0.036103488091612235, 0.04243201881763525, 0.01366463638987625, 0.03416309475142043, 0.05124464398249984, 0.03129874981823377, 0.05593512119958177, 0.04648245303542353, 0.0035562257880883408, 0.036676574527518824, 0.025189291809510905, 0.02838711709046038, 0.05632953187159728, 0.030538172759406734, 0.018136580802092794, 0.029927949253760744, 0.07188225688878447, 0.03225077314709779, 0.0076080461985839065, 0.030549247458111495, 0.03099831174040446, 0.012264779816177906, 0.08284823095891625, 0.08325366623466834, 0.018879863964684773, 0.033911963109858334, 0.0900292964070104, 0.033543579556862824, 0.03351319603098091, 0.10954552417388186, 0.041160497203236446, 0.013112310607539257, 0.016209117529797368, 0.06849767014500685, 0.09219667932484299, 0.031692106640548445, 0.10480939003173262, 0.04105054431420285, 0.05004087302950211, 0.018483505155018065, 0.030507327246596105, 0.03849267297482584, 0.07969080819748342, 0.037624093019985594, 0.09162937421933748, 0.024040052012423985, 0.00970819239228149, 0.038990924949757755, 0.046415117976721376, 0.04825967407668941, 0.013840085666743107, 0.038194715525605716, 0.050115046979044564, 0.03767856665945146, 0.024551701608288568, 0.031608666977263056, 0.007108112331479788, 0.06015947772539221, 0.03673472921946086, 0.08819171649520285, 0.009021579626278253, 0.0414703549904516, 0.04519778798567131, 0.0972190524043981, 0.025866167597996537, 0.039045250159688294, 0.0226964641478844, 0.08191990811610594, 0.0491908319236245, 0.04221107403282076, 0.07629730826010928, 0.006933374588697916, 0.0027119337755721062, 0.02217356173787266, 0.0398680247599259, 0.058407909018569626, 0.02093120838253526, 0.011076254431827692, 0.02798634064674843, 0.028946531310793944, 0.05400249072408769, 0.01129385584135889, 0.034132414366467856, 0.0384065430262126, 0.026196286016784143, 0.09961538045899943, 0.0329693056846736, 0.041610828702687286, 0.0076384603380574845, 0.03229617403121665, 0.025934320874512196, 0.062428208329947665, 0.04737052178825252, 0.031086072558537126, 0.11269329159404151, 0.0507980529073393, 0.030053600421524607, 0.010062107776320772, 0.055858030609670095, 0.019723600526049268, 0.06345751520711929, 0.0459408039750997, 0.03912749496521428, 0.03253771712479647, 0.04506216791924089, 0.07428521232213825, 0.027131995084346272, 0.0473568031884497, 0.020625129982363433, 0.01889592775114579, 0.021190967490838375, 0.03507433335471433, 0.015830492338864133, 0.040379583442700095, 0.006638030890826485, 0.01266778363060439, 0.055545018694829196, 0.028150735633971635, 0.04657369638152886, 0.019506442549754865, 0.006267351782298647, 0.031949312760843895, 0.04159541058470495, 0.029115136130712926, 0.04096406184544321, 0.045414246487780474, 0.0053641770773538155, 0.019352933013578877, 0.008766971022851067, 0.08762883458985016, 0.012537243565020617, 0.04662562445446383, 0.05233180127106607, 0.07229413400636986, 0.07840626931283623, 0.01574289293785114, 0.03662055351014715, 0.06623565597692505, 0.026436508087499533, 0.06404475439921953, 0.00622060621935816, 0.07332785666221753, 0.07116607695934363, 0.017971881534322165, 0.05852381764270831, 0.018541238678153604, 0.05534827534575015, 0.023989662040548865, 0.07327194325625896, 0.0318839555257, 0.02647097713634139, 0.015950495762808714, 0.07046088081551716, 0.0019906434636141057, 0.020391232865222264, 0.02079128385958029, 0.042174356276518665, 0.058826083259191364, 0.006614625872316537, 0.041019218260771595, 0.04081887178472243, 0.05532643393962644, 0.0162747975991806, 0.04020819927973207, 0.03735058933671098, 0.03639874041255098, 0.03602894677896984, 0.09812970471102744, 0.005659334774463787, 0.07553634713985957, 0.035835149756167084, 0.0566450188489398, 0.050014567605103366, 0.0242619207710959, 0.0659586196707096, 0.037353082952904515, 0.04882890134467743, 0.012904956402053358, 0.04083586325577926, 0.03212233707017731, 0.018771903742162976, 0.020539302458928432, 0.060539780170074664, 0.05074917877209373, 0.03467346970865037, 0.05025604390539229, 0.02140496020729188, 0.018517827629693784, 0.028971537976758555, 0.0606506978510879, 0.11818590428447351, 0.08601052220910788, 0.19770628568949178, 0.14606952056055889, 0.09973738211556338, 0.18397469830233604, 0.10242673975881189, 0.07968220670591109, 0.2680262178182602, 0.16927965480135754, 0.08730210407520644, 0.19874484714819118, 0.19137291616061702, 0.1460878664511256, 0.2486927216523327, 0.15557770879240707, 0.2210661259596236, 0.08181433018762618, 0.0755194335943088, 0.22386314696632326, 0.16597473761066794, 0.10029837896581739, 0.20269115804694593, 0.1563991920556873, 0.09868092747638002, 0.1515027688583359, 0.1446980910259299, 0.11968543592956848, 0.18130718206521124, 0.12036249725497328, 0.17294947116170079, 0.14444727479713038, 0.11795206839451566, 0.08615557497250848, 0.14821311022387818, 0.20140658947639167, 0.20671011036029086, 0.10050826575024985, 0.21819477144163102, 0.150500928866677, 0.08435851632384583, 0.11759688393794931, 0.09783665285794996, 0.10420123711810447, 0.11550770854228176, 0.20242828933987767, 0.17164400371257216, 0.12437946803402156, 0.11526771282660775, 0.21404767991043627, 0.1028690226667095, 0.20369235979160294, 0.19351083581568673, 0.13071700843283907, 0.11497110608615912, 0.16323168558301404, 0.19947403692640364, 0.15328634268371388, 0.10775705217383802, 0.11678103357553482, 0.13147745747119188, 0.12510466505773365, 0.12877050350653008, 0.1633226135163568, 0.09099422197323292, 0.16321366623742506, 0.15124215628020465, 0.22795986151322722, 0.18722226232057437, 0.12287209930946119, 0.11725660180673003, 0.2912301477044821, 0.1374722592299804, 0.20237743738107383, 0.06596402992727235, 0.21679901430616155, 0.16785719519248232, 0.1916798239108175, 0.21091933449497446, 0.08989225141704082, 0.21075015451060608, 0.2134146130993031, 0.1287309915642254, 0.10218266965239309, 0.08840282782330178, 0.11627523766946979, 0.17070806643459946, 0.1922806815127842, 0.1336976367747411, 0.1055798506422434, 0.09928274987032637, 0.17295125231612474, 0.10906320239882916, 0.14333460247144103, 0.10657683698809706, 0.14752883522305638, 0.15897848177701235, 0.20012227323604748, 0.08266345845186152, 0.08601575435022824, 0.08147741740685888, 0.13524819107260555, 0.15037865261547267, 0.08070123483776115, 0.1783777619129978, 0.08437986049102619, 0.13423968659481034, 0.1385679660597816, 0.15774737752508372, 0.1719216411584057, 0.09049664164194837, 0.1700607652310282, 0.11932949448237196, 0.18642038659891114, 0.08640101805212907, 0.15578957711113617, 0.09589725770638324, 0.09603033220628276, 0.17169012076919898, 0.14348883560160175, 0.19252472935477272, 0.09658673516241834, 0.08810746789094992, 0.12928969517815858, 0.11851592993480153, 0.13289709691889584, 0.10435066113132052, 0.1447217506938614, 0.16463916865177453, 0.23309858108405024, 0.15616538585163653, 0.11023762141121551, 0.2249694665079005, 0.11783773312345147, 0.13688756560441107, 0.1327778783161193, 0.15653743932489306, 0.16705105954315513, 0.07054837260511704, 0.1985703088575974, 0.13697200716705993, 0.12712936266325414, 0.24336678790859878, 0.1602878826088272, 0.09520366875221953, 0.1442940064589493, 0.12374374433420599, 0.17913712741574273, 0.16757596575189382, 0.13820561987813562, 0.20693906291853637, 0.1401956146582961, 0.12683732755249366, 0.19137986266287044, 0.10251556741422974, 0.09125136872171424, 0.13112418033415452, 0.14129601186141372, 0.20523280603811145, 0.1894368013017811, 0.26279757963493466, 0.08865654584951699, 0.11649080188362859, 0.08550041442504153, 0.25350912648718804, 0.10432494571432471, 0.14945172501029447, 0.13580903207184747, 0.10189339533098973, 0.23785776633303612, 0.10184421320445836, 0.1809773567947559, 0.09507420851150528, 0.0866006631986238, 0.10312461832654662, 0.11410313469241373], [0.008360645169886993, 0.008988952031359076, 0.058161408378509805, 0.0037639399351974134, 0.021156633883947507, 0.01648253029998159, 0.009654695604695007, 0.017810696335800458, 0.06107942543167155, 0.009934864701790502, 0.03529707042616792, 0.017342241590085905, 0.014223895686882315, 0.02639969014126109, 0.027948691495112143, 0.03932068713766057, 0.0477121768926736, 0.002743882769209449, 0.015427841044584056, 0.010867114433494862, 0.02625296197948046, 0.03752582153538242, 0.07798020233167335, 0.055362609928124584, 0.035259848009445705, 0.038971027970546857, 0.02065825759927975, 0.023513082633144222, 0.005612091972579947, 0.019655903670354746, 0.013267883314256324, 0.043755839578807354, 0.0205235077010002, 0.03551481284375768, 0.02215534757851856, 0.08510253421263769, 0.08263461117167026, 0.042186382779618725, 0.01228907773111132, 0.013900780359108467, 0.06487656093668193, 0.03462417997070588, 0.030753733262827154, 0.04178654700808693, 0.03400743669772055, 0.06236196422833018, 0.05950136714091059, 0.0268238460921566, 0.09756420302437618, 0.021565891220234334, 0.032051584421424195, 0.047509247742709704, 0.010873919000005117, 0.03860147924569901, 0.07136961095966399, 0.03903044431353919, 0.05183291475987062, 0.07923795710667036, 0.015822280474822037, 0.06998247758019716, 0.030608303859480657, 0.08263642943347804, 0.01451087027817266, 0.013904793522669934, 0.03443580062594265, 0.03151650707877707, 0.07430180674418807, 0.02857761712220963, 0.038744988341932185, 0.08342721746885218, 0.03370055492268875, 0.08571254991693422, 0.04299447769881226, 0.028873489136458375, 0.08356360936886631, 0.07456111314240843, 0.02743831468251301, 0.07611417589941993, 0.07180614222306758, 0.026032139649032615, 0.014256989907153184, 0.07201444823294878, 0.05584825652476866, 0.04786821344168857, 0.08273194383946247, 0.022761225809517782, 0.027014386942028068, 0.01056408904332784, 0.03342790841998067, 0.04345325483882334, 0.04141511693887878, 0.023288720258278772, 0.02773887707007816, 0.031511018896708265, 0.03377205714059528, 0.02372459101025015, 0.05537792414543219, 0.09435621032025665, 0.026645263096725103, 0.02659060206497088, 0.057655556811369024, 0.03606471829698421, 0.01074409232387552, 0.01793939773051534, 0.00733265560484142, 0.015416523292515194, 0.06790055296733044, 0.049695815177983604, 0.030929624117561616, 0.036563987014233135, 0.032011475050239824, 0.030418596070376225, 0.11865443695569411, 0.022833781877125148, 0.0983421815908514, 0.10638037565513514, 0.04264626571966801, 0.03642540206783451, 0.04228383048030082, 0.04583613517752383, 0.03921224451914895, 0.012734848733089166, 0.031303536670748144, 0.033451683120802045, 0.007637983972017537, 0.04230164944601711, 0.012282105253689224, 0.0076656642249872675, 0.056470962954335846, 0.02566610499343369, 0.05400283211201895, 0.0273227882644278, 0.038450496722362004, 0.055319335297099315, 0.037748925969935954, 0.027085024557891302, 0.08919799452996813, 0.03256706535466947, 0.05626983351248782, 0.025788589045987464, 0.0026851000347960507, 0.029602717877423856, 0.04838493376155384, 0.004052940821566153, 0.03373186613316648, 0.05256223812466487, 0.05967921912088059, 0.04292806661396753, 0.02982367750519188, 0.004930494269501651, 0.04267619282472879, 0.017259412343264557, 0.0615269441914279, 0.01688987289526267, 0.05713076192478184, 0.06022106856107712, 0.035081721434835345, 0.009059431013156427, 0.07045069854939356, 0.008078767277766019, 0.01629872444027569, 0.06038745435944293, 0.09412480125320144, 0.008535879223927623, 0.05489181370649021, 0.01576620008563623, 0.03724816924659535, 0.015947811043588445, 0.03013528676092392, 0.03315550311526749, 0.0522896992333699, 0.04248155346431304, 0.037943120041745715, 0.03347563593706582, 0.04912320742732845, 0.057452883702353574, 0.026814467200892977, 0.010514776113268454, 0.12272201478481293, 0.04960920654411893, 0.04294203012250364, 0.08759511139942333, 0.02728922092501307, 0.04664170308387838, 0.06244090647669509, 0.011379738098185044, 0.0341996195493266, 0.020170095122011844, 0.031004697921162006, 0.029384765803115442, 0.08320133740198798, 0.03417585226998199, 0.02750852185272379, 0.07511444360716268, 0.07760136562865227, 0.014832823217147961, 0.11984029246377759, 0.040818897759891115, 0.014313760493678274, 0.05403273695264943, 0.0669564372219611, 0.05288769956678152, 0.03242379374569282, 0.027929724055866245, 0.020356047643872444, 0.04516473643889185, 0.02385487317951629, 0.04521659400779754, 0.019836473766190466, 0.017079207755159587, 0.06166005208797287, 0.02530468649638351, 0.03669022633403074, 0.035552124318201095, 0.005212013147684047, 0.029675552250409964, 0.08127582041197456, 0.025690096772450488, 0.01388732336636167, 0.021998390766384546, 0.03139764470688533, 0.036756756162503734, 0.03205886860087048, 0.05049669271102175, 0.1146211834566202, 0.016768682035035454, 0.05347917271137703, 0.029515281748899724, 0.01838439504354028, 0.04996849878807552, 0.01608910482900683, 0.07221611944260076, 0.0421179344994016, 0.07800765437423252, 0.042567698255879804, 0.007011600200712564, 0.005649485547110089, 0.04524658419541083, 0.027324975744704716, 0.028763508416886907, 0.03646470249805134, 0.028872112452518195, 0.06751092543709092, 0.06781839721952565, 0.04252123610058334, 0.025605712726246566, 0.040338865510420874, 0.07892155728768557, 0.011227505056012888, 0.08651118245325051, 0.10806387828779407, 0.05735689803259447, 0.039145080154412426, 0.024503790409653448, 0.07628463237779215, 0.06856154679553583, 0.03895766560162883, 0.025002064649015665, 0.05167117480596062, 0.06655705787125044, 0.07664443299290724, 0.04706755113147665, 0.06366977686411701, 0.025671711919130757, 0.010901399800786749, 0.019215208958485164, 0.003207698860023811, 0.02051468542049406, 0.02113905611622613, 0.0741396623197943, 0.01553936079289997, 0.03531523820129223, 0.08054081961745396, 0.03340728784678504, 0.03753586650418583, 0.05899816133023705, 0.08022349953535013, 0.04640972998458892, 0.06585837778402492, 0.03573873735149391, 0.029174129449529573, 0.012476050706027308, 0.06217915470188018, 0.04473716289794538, 0.06455517388531007, 0.03040047096874332, 0.031243608245858923, 0.024088206264423206, 0.07241225423058495, 0.025593881036911625, 0.04124829327338375, 0.051434507622616366, 0.06876951141748577, 0.046887172138667665, 0.0727907198597677, 0.09238296581315808, 0.052750431932508945, 0.01905152457766235, 0.020444930960366037, 0.06189439263835084, 0.03444227957515977, 0.018756179488264024, 0.01922366202052217, 0.014922019163350342, 0.039156761558842845, 0.027767147330450825, 0.008496681766700931, 0.0040588413594377926, 0.004437628431332996, 0.02265619892568793, 0.06635322701185942, 0.023996653071662877, 0.03395495943550486, 0.008987765522761038, 0.03024903759069275, 0.06650241353781894, 0.04920626859529875, 0.06210176354215946, 0.073586650978541, 0.009183929996652296, 0.06641037238296121, 0.013819954911014065, 0.04132376598136034, 0.004863938002017676, 0.05800192084279843, 0.028665064382948913, 0.045010243557044305, 0.020623513955797534, 0.026175251696258783, 0.04272551595931873, 0.0506770345964469, 0.05306882070726715, 0.04964597254002001, 0.014781781083001988, 0.04504002594330814, 0.04418097516463604, 0.040807721015880816, 0.04002344903710764, 0.0595009441167349, 0.04955281445290893, 0.0530013520619832, 0.03655777152744122, 0.059644545981427655, 0.017493936575192492, 0.037214386684354395, 0.07959650349221192, 0.009401295774296159, 0.053828338350285776, 0.07506952140829526, 0.024146800678863656, 0.018332819490751717, 0.024109364894684404, 0.1327478510211222, 0.10031295474618673, 0.2686351945158094, 0.17680727352853864, 0.1389536156784743, 0.1330253400374204, 0.10725943473516963, 0.12750996567774564, 0.1782237068982795, 0.1514860408497043, 0.0881356027093716, 0.10966563335387036, 0.14175747928675264, 0.1267110140179284, 0.12789625354344025, 0.12602240487467498, 0.11943346937187016, 0.15564517001621425, 0.2551336877513677, 0.14928564720321447, 0.23087417153874412, 0.15081122081028298, 0.2289731751079671, 0.17872652679216117, 0.19135817710775882, 0.1349326001945883, 0.12015140076982789, 0.11259044476901181, 0.1175429075374268, 0.11127427555038594, 0.0740815224708058, 0.15779768029460683, 0.13056421506917104, 0.14582030737074092, 0.1653438527137041, 0.17131152155343443, 0.17640088830376044, 0.08861500784405507, 0.11277740661171265, 0.055811713173170574, 0.13648373336764053, 0.21646074339514598, 0.2725320041645318, 0.1902555237757042, 0.2042546108714305, 0.2710326877422631, 0.08698329969774932, 0.1765227786381729, 0.19096813397482038, 0.12201756821013987, 0.16039533074945211, 0.13068865839159116, 0.13207044830778614, 0.16352363163605332, 0.15925611922284588, 0.177161441242788, 0.1483028061920777, 0.196052142418921, 0.14540663425577804, 0.13455023086862639, 0.14069509488763288, 0.22983228525845334, 0.1196613977663219, 0.10117700017872266, 0.270165977999568, 0.10547546757152304, 0.23672927141888067, 0.14556040725437924, 0.14446196932112798, 0.13624145183712244, 0.0806151976576075, 0.190478524309583, 0.08692489267559722, 0.14102371787885204, 0.3108037880156189, 0.10577491673757322, 0.13984843797516078, 0.2002556371735409, 0.11768854659749195, 0.16753991221776232, 0.1429749428643845, 0.167400284553878, 0.16961378452833742, 0.19158497743774205, 0.20447060553124174, 0.12876042514108121, 0.11606114290771075, 0.1398682830040343, 0.09785165166249499, 0.16449404909508303, 0.19551162142306566, 0.13514341466361657, 0.09675578156020492, 0.1496071752626449, 0.09762254325323738, 0.09606313513359055, 0.2623579907231033, 0.17322891944786534, 0.11689061167999171, 0.19832790858345106, 0.12081870285328478, 0.10307693533832207, 0.1097437072894536, 0.21870948054129258, 0.13641478784848005, 0.1666789170121774, 0.23672138981055468, 0.12076198792783543, 0.11825010747998022, 0.10904749113251455, 0.14845616358797997, 0.11134415617561899, 0.14660456450656056, 0.08527705766027793, 0.11190086341230199, 0.16907108161831275, 0.2643170824740082, 0.13224467489635572, 0.22907409234903753, 0.1744478673208505, 0.12864395248470828, 0.18347560398979113, 0.12215207505505532, 0.10343809408368543, 0.14035489439265803, 0.0843462634657044, 0.1317807732266374, 0.08712263050256297, 0.14841585012618452, 0.09015829651616514, 0.14001797419041395, 0.1481218557455577, 0.130684532050509, 0.12349702476058155, 0.17327968234894797, 0.19796311331447214, 0.2000318351201713, 0.12831071333494037, 0.09383104435983114, 0.14735256030689925, 0.09990025384468026, 0.1494220836320892, 0.24562275357311592, 0.11535918994923122, 0.0885062683664728, 0.1866373312077485, 0.13967575505375862, 0.0604844641929958, 0.13855555735062808, 0.06328529983875342, 0.12900699628517032, 0.13974002504255623, 0.17580877320142463, 0.15961972705554217, 0.21823026094352826, 0.16949747514445335, 0.13722738018259406, 0.09236126541509293, 0.09800281972275116, 0.12818759103538468, 0.11805935326265171, 0.19892699987394735, 0.16770547052146867, 0.10802417338709347, 0.09394579523359425, 0.1331318382290192, 0.10052656711195596, 0.1116936409380287, 0.14795557013712823, 0.12720335478661582, 0.1795763600966893, 0.14343155664391816, 0.20367828867165372, 0.10581768670817837, 0.15149914717767388, 0.09637125258450396], [0.057173357490682974, 0.015469409663637634, 0.030621681071352214, 0.03701311623444781, 0.04199034818157088, 0.002592912769614486, 0.06094574237067718, 0.023508655722253025, 0.032442666561109945, 0.0436810904648155, 0.07929856088594534, 0.037439654479385354, 0.04540989379165694, 0.06436513212975115, 0.09438315770239569, 0.05128197772137355, 0.0343197732581757, 0.04415695555508137, 0.03211411036318168, 0.016300160496030003, 0.010177025633311132, 0.03230159913073294, 0.02293271758389892, 0.04871287397691049, 0.02771489085716894, 0.08199954056181014, 0.04305430964450352, 0.08031081320950761, 0.0422970258659916, 0.040932887932285666, 0.031562876465613954, 0.02264030212245416, 0.05276540105114691, 0.00889294966327725, 0.04659812417230569, 0.040118510733009316, 0.03998341016995255, 0.015756542888993863, 0.041322018223581836, 0.046200243959901854, 0.09079730793018825, 0.0027803384546132293, 0.01780374612280866, 0.010084913974424126, 0.06454065747675486, 0.031671218894189224, 0.05087479097710457, 0.006076037243474275, 0.024742893692746293, 0.02796161043079337, 0.04735485876153689, 0.006659965065409779, 0.002164377915505611, 0.017997472641582135, 0.02611653668282088, 0.07817241115844809, 0.035722057582461275, 0.03209483307728078, 0.0495323719951557, 0.046226204285630956, 0.04411585541674867, 0.017240459746972192, 0.03891884385666344, 0.027459248813102022, 0.018311725798412226, 0.05621265845547896, 0.053396022485685535, 0.03174284727720078, 0.04158312804065645, 0.04291088960599154, 0.05040198353526648, 0.07476947852410376, 0.014908133580320282, 0.02594656074506929, 0.006352764630719321, 0.0393300196446944, 0.04071243296493776, 0.01305587120441487, 0.013007363504584646, 0.06689656074740924, 0.07897603092715144, 0.10221828531939536, 0.014011141429364216, 0.03591469685488846, 0.023601928842253983, 0.06644775436143391, 0.011606802818278084, 0.01328167891188059, 0.009230201048922027, 0.03223579660698306, 0.025570037687430158, 0.021729145155404694, 0.06373025447828695, 0.008056119713728549, 0.038232001024880446, 0.031097696446522605, 0.030205514340195805, 0.02210786125942832, 0.06849526558653452, 0.004199141130811768, 0.017577619291841984, 0.04608094001014251, 0.036647552842623554, 0.04030503099784255, 0.03212227769836318, 0.015356308213085867, 0.007393283503915882, 0.028481134213507175, 0.02018497518292861, 0.0340292038890766, 0.029685894078284036, 0.0384035336173838, 0.027895191924471874, 0.013945524442533497, 0.06556415333761834, 0.02448949479003204, 0.036973500391468406, 0.02223617302661296, 0.09778579347766936, 0.05430343531770632, 0.04795390923391096, 0.01256045701666153, 0.012264047873031814, 0.06928514820174314, 0.03188166600011755, 0.08694715710589662, 0.09821554893278517, 0.030228387331590056, 0.009231689982698299, 0.05654482891259249, 0.07727626041742042, 0.0869626976782456, 0.02612922926346073, 0.04888799856416881, 0.01475542370826588, 0.07271909518749453, 0.04104086670849938, 0.02060184324363945, 0.03984650618804153, 0.06853831015178002, 0.06944411623408087, 0.010756578030850505, 0.021012069082644302, 0.04020621032395866, 0.045430083919200115, 0.08233482803916559, 0.027366587964934297, 0.06885600872919895, 0.03057161949982401, 0.0838911636674311, 0.09886983374599367, 0.026389700833533425, 0.09823514163144864, 0.06208045277162455, 0.02713961323024705, 0.0042263120849383995, 0.03736364742508158, 0.03019585899892263, 0.04859257926000282, 0.047572686526109464, 0.017113051544583868, 0.06353895107167773, 0.026809607988980133, 0.024195964251703117, 0.022198158367245924, 0.050765287087415345, 0.023289859454962425, 0.03741813590750098, 0.03920191382349003, 0.015267401704477379, 0.03538894830853678, 0.027492465487739537, 0.050432663920219056, 0.05032527515140828, 0.017791916288842913, 0.017340818521915935, 0.04223824777000118, 0.047918831623974256, 0.03113114318693988, 0.028973615990253165, 0.05058176880993415, 0.0111100481262838, 0.067377895466052, 0.024652613283251412, 0.08727427353733219, 0.04642558596970048, 0.024416951710009016, 0.060186981718288735, 0.04653776159102563, 0.04331859956437256, 0.056788301590131596, 0.01843849204306025, 0.06955203934921883, 0.04473170069104526, 0.011359540549165104, 0.02603541437565582, 0.0587031761824619, 0.04091333605174441, 0.040500034010619856, 0.037256318028084934, 0.0332222073484445, 0.04847972828429192, 0.04329338138632011, 0.023409402747347485, 0.01457385356843588, 0.05966432792774867, 0.021101442216604482, 0.045670168692595325, 0.012998148813494481, 0.051389440704951994, 0.05188675015233457, 0.05598268544417806, 0.009420703863725066, 0.03825884821708314, 0.008081635678536259, 0.02846945651981514, 0.07080749346641824, 0.053176435831119306, 0.03766763111343607, 0.033399135354557075, 0.016479906807944644, 0.0826108995534014, 0.00973346252067131, 0.04493512707995251, 0.02301694948982913, 0.010758451953734038, 0.04221317060000729, 0.0288421222649049, 0.03312770597403869, 0.003929905260520172, 0.02109393353748601, 0.029869540376239456, 0.0341301248408854, 0.003541593650879804, 0.05409667297499254, 0.06325309805106372, 0.06920065468875691, 0.04549652097921353, 0.04798146888788324, 0.020676499589171726, 0.07049355757771991, 0.07719567060121335, 0.0632923205557745, 0.006084032957005547, 0.0796346869901754, 0.019163256765750702, 0.04082402228959836, 0.040509166137780994, 0.037636431225109845, 0.02586854803666938, 0.04672392562497407, 0.01108872622353374, 0.09392250663950108, 0.015239612912409939, 0.03239551791921258, 0.04775708795932587, 0.08896876737708226, 0.02439769854390761, 0.011507484905450838, 0.052672361707664095, 0.024581476573075633, 0.05844866405823268, 0.03407060088647995, 0.02767464604403358, 0.0350206909206463, 0.03455022495472804, 0.03835428840829991, 0.01600889165274566, 0.04651560106140096, 0.013015837903367355, 0.032679960859240964, 0.1019663261831738, 0.02691722311283229, 0.006961709323149989, 0.09434390551177785, 0.018077884342346806, 0.0066669083207671065, 0.04208851947623771, 0.009992164996219799, 0.043836815311806276, 0.029762838094029576, 0.02221751357865287, 0.0422287260153098, 0.04070794668223243, 0.05214848708419595, 0.0175277747985092, 0.02281615772517398, 0.03551920635800343, 0.043140521229361184, 0.047605359577573836, 0.03314497575047426, 0.0561697140801698, 0.010671704167179996, 0.03158173814881593, 0.044441962527344, 0.045527019537985325, 0.06609275544178672, 0.025253923595300876, 0.04827137403481174, 0.016455590339319315, 0.03153555058815982, 0.05084054086182732, 0.1349522522650659, 0.0057471308446110925, 0.0429497633012943, 0.02865700651454972, 0.04789767299371306, 0.034934408831759356, 0.00890009840077255, 0.039280677956412546, 0.03698380140122026, 0.02831546458764933, 0.04065110188093968, 0.05290059809340164, 0.032197394175454974, 0.014782183698116569, 0.04778901144163683, 0.04433953872648999, 0.04401223675813526, 0.060943760836380534, 0.01430910258932272, 0.04142506171774585, 0.07648821832844988, 0.0786529592005536, 0.044654287266894244, 0.03084995085373521, 0.12278630703804083, 0.05061052332166582, 0.025721799465827644, 0.05331718784873374, 0.04304849120671861, 0.006958010180824203, 0.022254518917179666, 0.03451525124546606, 0.06300007022218779, 0.03347039637446869, 0.031403043831232935, 0.012613241342478432, 0.020110040532017592, 0.026485098351258785, 0.07789843250066042, 0.06469957355875522, 0.08284344410640188, 0.06441337172873318, 0.021710138753405772, 0.027523253484105226, 0.024783221997495275, 0.02207465386163676, 0.016799188015284017, 0.0256942769192392, 0.03570662462152541, 0.006835491803940386, 0.13113369466736913, 0.0922419577545952, 0.1386895150062628, 0.13378672418184578, 0.11735794207197614, 0.1176604711508844, 0.15698284667450935, 0.0918405078118667, 0.17838864179793745, 0.10227437684079632, 0.1303165900753811, 0.2154118215548806, 0.1653298261226155, 0.12301832466619089, 0.31438809412065893, 0.11469958393718116, 0.15560635569272563, 0.14409702562261373, 0.11236468344577588, 0.08582189053413458, 0.18491609778720886, 0.12401422005495988, 0.0978712369396817, 0.1361641348921694, 0.11251451564021409, 0.09448909186176024, 0.16831276996526867, 0.15326774446293712, 0.10966816407744773, 0.17313350894255564, 0.127283209876623, 0.12934920057887211, 0.23044765926897526, 0.328742447309196, 0.13186453201342374, 0.12834541616030037, 0.11018775650882162, 0.1744749557110481, 0.10754648261354305, 0.14583181065972894, 0.2148570364806801, 0.1764207036467269, 0.1496689219493419, 0.16273526300210506, 0.1327669687452726, 0.1261579358833842, 0.13202587491832674, 0.10711796654504724, 0.11322303660563193, 0.17633336770813912, 0.2266558338305913, 0.09199382810038514, 0.11915274459170178, 0.05820880563987885, 0.15235205297358334, 0.18342392082558945, 0.1641562976874411, 0.14354599581565708, 0.10253581320284866, 0.23759804433211684, 0.16070149635197595, 0.17980528296902776, 0.1368033021572046, 0.11184517265064642, 0.12496479990659282, 0.1279015524778515, 0.17924202256835997, 0.14643379632616416, 0.09152844955679029, 0.061993231865926646, 0.12413351287250407, 0.17873451230116189, 0.11256186466198415, 0.11186475792783312, 0.12200236160424538, 0.10504433914320543, 0.1351844405871816, 0.14700299390824512, 0.197380987519864, 0.12920571374706924, 0.19476344750728458, 0.19185516372090206, 0.14803831960307434, 0.15467038872884586, 0.08602247078670189, 0.1509413935127668, 0.08921616230509244, 0.07851502363337204, 0.12845574383391067, 0.1721486047608778, 0.18885460129240528, 0.13231163145974278, 0.14562985743395984, 0.10202998761087656, 0.14266690704971552, 0.20767931069713086, 0.16110595199279487, 0.17243355978280306, 0.2178211891441606, 0.11826009678770788, 0.10165685060201213, 0.1211820138269104, 0.11506942581036128, 0.11004814368789084, 0.095104280335363, 0.07138219778425992, 0.13295321812620386, 0.07399906986393034, 0.18345308722928166, 0.14011958905030042, 0.12588204990606755, 0.11244883557083085, 0.1361676972010173, 0.1448293324210681, 0.12311182785197161, 0.11782840432715602, 0.18424510722979903, 0.0997305172495544, 0.1781454251613468, 0.10924782647634856, 0.1321991960867308, 0.11276000324869528, 0.1473620894830674, 0.16936408152105287, 0.13495113904355094, 0.14448841946432367, 0.2596741769229993, 0.13855721976142377, 0.08242773008532822, 0.1499317164416425, 0.18555155431386083, 0.23014550126390532, 0.14962424465920776, 0.21878371015191078, 0.10059610634925775, 0.23334390542004257, 0.07745866547338665, 0.10723702929681167, 0.10586079064523801, 0.11094660250819288, 0.24734897422604263, 0.09946370031684637, 0.1279158759280108, 0.17421115189790726, 0.125977341667749, 0.15396478440379724, 0.10326893636374734, 0.1897821226157248, 0.1374886606936343, 0.1286538378917612, 0.23851775826187804, 0.13323710445547476, 0.1498945793719031, 0.09959552058717236, 0.13728780584642664, 0.11285258617135696, 0.09849497495451942, 0.04917053418466821, 0.21030388626968488, 0.11708313220879063, 0.12285612086998299, 0.19356713513843715, 0.14336088934214786, 0.09695708911749534, 0.19023797940462828, 0.24503151420503855, 0.2071335501386784, 0.12374574813293293, 0.1081233836885076, 0.16831195360282436, 0.0933229255315382, 0.12757395365042612, 0.09492276585660875, 0.12037058666464873, 0.07713568280451, 0.10060516055091284], [0.02544469080021372, 0.014229036914912285, 0.006723826872985228, 0.05700105677533429, 0.035898852001992054, 0.023394565359922126, 0.043596890100161545, 0.04263353788701352, 0.011049799650209025, 0.02355928132601548, 0.004914317769362242, 0.04694964984082617, 0.03391776670468971, 0.020370211532281246, 0.06963286665268242, 0.020552008027152624, 0.039860937249613926, 0.06707305830786936, 0.016398144398408476, 0.022868445739732124, 0.0024591568853793433, 0.03982928094046656, 0.010919546239165356, 0.02779215956252301, 0.03884305573592428, 0.03736561782716308, 0.035973192934761755, 0.03305434467620216, 0.025916702288668603, 0.07910059299319983, 0.1648059143917635, 0.044060339059797116, 0.07142251866753213, 0.026473660000192467, 0.05058896022092085, 0.03305626683868468, 0.03758097423997242, 0.06382637002388947, 0.034719386385404505, 0.04482071759412065, 0.03283984544395935, 0.06122585487901233, 0.03218913778255228, 0.003191131804669567, 0.01900642611872172, 0.04488194848818239, 0.0684179412201047, 0.02840084311173996, 0.017035118617059197, 0.02200214974436676, 0.0055072371742426185, 0.05794588498247322, 0.020254829832992982, 0.09509346724371426, 0.06579093882464804, 0.018098378750437405, 0.00878008106155903, 0.007696440625295509, 0.019865200447384268, 0.012686625832429854, 0.015583019485347904, 0.05631340871332213, 0.013213522852311144, 0.06469945481512696, 0.06223573233000934, 0.0168757015853771, 0.09086160760489292, 0.035094311970169656, 0.05240755599515978, 0.022649007514701225, 0.04760747840919066, 0.060908531086170115, 0.049795975428423844, 0.013896941600251012, 0.04469264516956173, 0.0627134824753739, 0.03309758962132037, 0.03168341238051653, 0.042253617648384534, 0.0375848074327223, 0.07726195181021467, 0.07167298608692363, 0.10337544939829968, 0.04433776128280442, 0.0047401046322193, 0.03450298354437109, 0.03748944516701158, 0.04382449194963556, 0.0656572483421769, 0.027527875208761543, 0.034272131088073365, 0.02322576201549964, 0.04097418102901429, 0.02424773647362599, 0.02001999946514843, 0.027988917754555587, 0.036601903339033015, 0.08476191069348715, 0.08127477398375049, 0.06612976634642109, 0.03725363145349547, 0.02514515072107315, 0.03989241915405728, 0.04295751132303849, 0.038578005114686675, 0.02629280417750124, 0.013333769329619827, 0.06266200711252168, 0.09001468351925723, 0.04323822497099172, 0.039918798793223687, 0.061600943736266345, 0.10628233052557334, 0.05530753143830225, 0.008930686017265543, 0.04472959670238197, 0.02809364963468397, 0.04047448557685129, 0.07882327467086725, 0.017407444829586893, 0.06480872121755965, 0.0186279085392016, 0.025313365913461894, 0.04918685030133929, 0.05562050253502093, 0.027309780271025375, 0.026780222651723307, 0.00870403133376385, 0.01165834682979039, 0.015469686113647185, 0.09597087133442983, 0.04022707951662596, 0.062197073857532814, 0.06656798970652744, 0.0532207902870141, 0.016349724828614853, 0.057661560786073096, 0.011120320377813186, 0.042243542993674055, 0.03244153478590306, 0.008215074758481933, 0.06292130608926527, 0.045631116881850176, 0.030778088694205508, 0.026423394338053185, 0.08108847265248187, 0.052171642091707326, 0.03927899328118656, 0.038644987653242424, 0.018084367002302315, 0.04777487352839671, 0.04999684140784666, 0.0212318839476211, 0.01617578396690078, 0.03077421097259503, 0.041517370045767166, 0.016566042322665453, 0.0418967039877316, 0.0038219260204641614, 0.07316433184314519, 0.06788195474655367, 0.02652278089954052, 0.041746678834897466, 0.05564651852182578, 0.026128112331207376, 0.016739248458179645, 0.029745622123300564, 0.01042742440404254, 0.0459506745391991, 0.08673069489304908, 0.030308003078971524, 0.07706390228122473, 0.03322779943118803, 0.025378697173437104, 0.05717648564314004, 0.04582493245834485, 0.0308923794364091, 0.008106211898848414, 0.04410459703649394, 0.043441658781375736, 0.05567733620409854, 0.03773957861994859, 0.021534134721150622, 0.09870161113212816, 0.06157222262118012, 0.04672493494581431, 0.03396625863388181, 0.03878954317769967, 0.03726971379364841, 0.02616618265165016, 0.028616067793336697, 0.11479992972454056, 0.015204795981844654, 0.036765454133274034, 0.07605802500620484, 0.07940062103443779, 0.03516313503496349, 0.024189342439058237, 0.030009451911610086, 0.08126791653921828, 0.06321214634226635, 0.025816016968747135, 0.04858454180066474, 0.014182935628923588, 0.04090104979695752, 0.011975775450991932, 0.05640728668367956, 0.019405705279496033, 0.026319502940168604, 0.0519006208924111, 0.0235250163677847, 0.05933304433710873, 0.04945240558299702, 0.0491549342405051, 0.04884247151494492, 0.007531045594078023, 0.03651172868558206, 0.11438455709139816, 0.03725955379195511, 0.033386960421921685, 0.0814081601856742, 0.06206769154232461, 0.034345358799328096, 0.04670346461352892, 0.04291531651688274, 0.01946279498952208, 0.0633951896452345, 0.045391755702439696, 0.03203971005859785, 0.06446990853874013, 0.0854185555363074, 0.008285725361929508, 0.04511945429840125, 0.026188970296061598, 0.03809314890531823, 0.03954924635763746, 0.05965185984678101, 0.04268495016731322, 0.04189001352642663, 0.039254179573617876, 0.10720707621658221, 0.07906764905783348, 0.027268125377304386, 0.07649672334082425, 0.06868119584396482, 0.012868089288531337, 0.057166425831383094, 0.07871863926993683, 0.05275331517623272, 0.02146042275853688, 0.04815294953004923, 0.021322947322914843, 0.028997967710893136, 0.030517173690896016, 0.030453002036665566, 0.022282171339611523, 0.01652485127124237, 0.057235683052567765, 0.056494808159186505, 0.021642443753080443, 0.04704491191660054, 0.009924552559823496, 0.017817878469941206, 0.09102539959712885, 0.059311303120921366, 0.04421664278197568, 0.05158206884516403, 0.04952924013196025, 0.07169340256950818, 0.015045717555040028, 0.008359587609447772, 0.009741396079334663, 0.06201130316185299, 0.01898450864246115, 0.0829119369154796, 0.024176430924853776, 0.057990740388049744, 0.06131851201644167, 0.013330958445294527, 0.043775543599622324, 0.01082291953935055, 0.011531961863511242, 0.01606860114407027, 0.018343098236073274, 0.019734164998226333, 0.061010724821244366, 0.0345874807680957, 0.0395606568781659, 0.07133222898119129, 0.023117083765100688, 0.019180691670044325, 0.02038335682300385, 0.021984551567584276, 0.04726054292405024, 0.11158988127135672, 0.05694333995052148, 0.049305170905427076, 0.0839655046002008, 0.038267345807980746, 0.0571507108543301, 0.06289127137279138, 0.004512697596510407, 0.017018485232256353, 0.018068564822897315, 0.04313297358748969, 0.04373494070023298, 0.055433956295019016, 0.03089416986767901, 0.022084114389144816, 0.029345958901103586, 0.042957726545864716, 0.006599541720788693, 0.0389433087548241, 0.025502266616967972, 0.018372875056229532, 0.06481484393589199, 0.042448294116184115, 0.029624460948980413, 0.0173262631506077, 0.01784485182724893, 0.04298596897569951, 0.02962084297905676, 0.056941158036352135, 0.026514030978432857, 0.018211148089903872, 0.04068456903041806, 0.013893589875806356, 0.029392868200375233, 0.1159663854923565, 0.055355336880893447, 0.04560342735203449, 0.02401298588665668, 0.018857853719964623, 0.05229227077506948, 0.004257716527718003, 0.09611982037313282, 0.01974210412299726, 0.03566145751392469, 0.03583724261261523, 0.028383322860463522, 0.035686104238266125, 0.012733861676679226, 0.01594136920175515, 0.060197449711267836, 0.038718994619557634, 0.07539551719673909, 0.042076708195963874, 0.03345663324580528, 0.054136667313287035, 0.012861016621172894, 0.021282563357090112, 0.02699331922485726, 0.1267878559883684, 0.1350001504761167, 0.09666161044151522, 0.1268552875262685, 0.12149003479862586, 0.09714857806102373, 0.11172638449352235, 0.23639183171326295, 0.15401369193568826, 0.12956307269632816, 0.10790997912408784, 0.10873990802792832, 0.07659220806090161, 0.09811481722863391, 0.15025135944597423, 0.19941928127082065, 0.1012152578914538, 0.1548793923575431, 0.1548431013361551, 0.21347690897528082, 0.17982569203013554, 0.10501567739993334, 0.1542538806097582, 0.12918154941871762, 0.2723718190100044, 0.10981613348121755, 0.10718862642534077, 0.07653460997971706, 0.1584548520622775, 0.14189352979883552, 0.20724954782053828, 0.15194951207377017, 0.10001080416259356, 0.14553689601598307, 0.16079845052445307, 0.16978830797597766, 0.16160252300323918, 0.12295288208406419, 0.12107944159652106, 0.10187625914113596, 0.11841522791655734, 0.19453309971140698, 0.21273121383273974, 0.10050705604953691, 0.18868165119783953, 0.17392843816196546, 0.2787251374684274, 0.10620444212690927, 0.14571444742614403, 0.06855049621663056, 0.10780184820760041, 0.13577379490016028, 0.12161831502453424, 0.1307526760501787, 0.13712318264879286, 0.11945670601562597, 0.11372254652087577, 0.17951737419934943, 0.0997663258749526, 0.14003299525938928, 0.3263999323826283, 0.11373818357242271, 0.13934487593360245, 0.20799194782739505, 0.1732270492357202, 0.12573883024742827, 0.27619405766017735, 0.21929733571596444, 0.13559346785768867, 0.17004650115268305, 0.15806476440047845, 0.21197928464971483, 0.11367314917151816, 0.11561722727492452, 0.13769055454758927, 0.15001691499492154, 0.09355368893011473, 0.2020379641908221, 0.1428292295895517, 0.1276032833266072, 0.21995421062456444, 0.20905670709908009, 0.2239631291013211, 0.09185837130644359, 0.1836218812968582, 0.12203562466311269, 0.1297020324273035, 0.20648846053518355, 0.16726368485251442, 0.11849149101180956, 0.11167944365297444, 0.13839657447533682, 0.1843884604750201, 0.0912766536930576, 0.13239009131211787, 0.19002452288987115, 0.21452400513226166, 0.13652988011017442, 0.2760595508152619, 0.13243435299955308, 0.1739873201586306, 0.11834945136797614, 0.1827533755567856, 0.1328714334522374, 0.07099271126207896, 0.15951079461956397, 0.08133170413202606, 0.18438792612869292, 0.21770804130937904, 0.1307367644039914, 0.18774780677631497, 0.16077091684564948, 0.13662160956300795, 0.11594414332648739, 0.08278132634586655, 0.12659630767302588, 0.11650541477138177, 0.15649917419068515, 0.18260577722685412, 0.13362788973608986, 0.13665478356415406, 0.16148982045706362, 0.12988341331947595, 0.1680315553676337, 0.17614034994039685, 0.1841284119291231, 0.17214009974850342, 0.0854999097646214, 0.19242235750425607, 0.14752352144569159, 0.22010342683643103, 0.20532113645458594, 0.12604658404598013, 0.18265103339217603, 0.0915133988019079, 0.07869880908401683, 0.09661589414463378, 0.18622275267262012, 0.12324425668339245, 0.12607490440132096, 0.09827705071074888, 0.1983107056003064, 0.1114861735550221, 0.16444490407593548, 0.11224330519326031, 0.18773760966723785, 0.1504222908988595, 0.22262683283770457, 0.09520153878838755, 0.10936530103208497, 0.1657565907225944, 0.10256004432449117, 0.15902024984825402, 0.14372531353728846, 0.2363145592971705, 0.1912706036819145, 0.169591742742341, 0.14237102761399, 0.08620957363746129, 0.2789458225015551, 0.10613125152303837, 0.16858807706739753, 0.13443234813166782, 0.11297136690700427, 0.09413890205905773, 0.1023770307074301, 0.11217493112781085, 0.08974273834610358, 0.1703869688208215, 0.12866425764514133, 0.14086210780078545, 0.14042560622328892, 0.10986939741997048, 0.14807774248765782, 0.18572578090243042, 0.15195323765510693], [0.027124501248181332, 0.014790910427109338, 0.02041014093265403, 0.07839613157557324, 0.03685888681502547, 0.0045208802384877345, 0.025807395068113692, 0.03946565084333997, 0.05866588697244879, 0.06456639515818097, 0.027580771784414537, 0.021609553623420652, 0.06630113566643558, 0.03916265421139542, 0.11032777751097456, 0.028768683041562326, 0.0368515989248408, 0.06486728409072384, 0.035824663209496066, 0.028533023323689122, 0.030715165703441016, 0.028426339595171157, 0.008751732875680318, 0.020976588857593015, 0.01776983368472429, 0.07440535860951059, 0.03063944066525437, 0.032111557375174016, 0.03437898551055696, 0.045621602548635565, 0.021581660002993885, 0.022687178025080357, 0.042202402037219144, 0.023353665601462126, 0.05212267147726379, 0.02572864577814471, 0.037667530923499726, 0.011345827515469864, 0.06830065220128745, 0.0475962719792733, 0.04895710364507977, 0.03483378102828283, 0.03521036902384367, 0.061540109891211614, 0.019011324293387588, 0.04799528396688402, 0.026463422072993126, 0.029514539601223078, 0.019205755852453876, 0.0472330203774618, 0.1007308358384762, 0.05803797066619154, 0.026080093521159142, 0.03436919658270199, 0.026046242310258094, 0.019929290465370286, 0.026823556654562708, 0.054125869064591825, 0.022794724500272423, 0.03762466076295823, 0.02178738148359116, 0.06120366837421898, 0.023029191215755418, 0.04067739246238489, 0.028149830213806126, 0.011279226255282992, 0.0487787358724745, 0.05126302698045038, 0.06318389278021641, 0.03725448121258523, 0.03380074856977444, 0.012196011484775227, 0.04835517735045869, 0.07144421906559728, 0.03376666543772444, 0.0725072342902422, 0.04391641436086502, 0.038062902676756494, 0.03062623229197925, 0.04218555899569765, 0.057957024619099684, 0.023189446874312125, 0.05652740699588321, 0.019244562754465733, 0.06521775590954348, 0.03181514359312132, 0.015044231404317543, 0.04603509383741766, 0.01599712675670162, 0.09192419238388538, 0.020946222030033823, 0.04099199999473058, 0.05775547957455274, 0.006115095548011595, 0.02225607186119305, 0.004222275265419739, 0.06857220403617248, 0.042968695488525555, 0.047850676492089406, 0.021622838066832628, 0.020012926797789987, 0.02410898083326174, 0.05090067337732762, 0.018347033474128693, 0.011970765954174567, 0.03387119693798013, 0.024794775381451473, 0.030362419201992452, 0.051396925264270976, 0.01626937806577189, 0.02232903425465338, 0.04585139744449407, 0.029492941248463467, 0.06849151031929068, 0.09044675447512418, 0.05197778569709044, 0.0567559216869995, 0.04607602699252311, 0.04067892499733716, 0.007668370280953241, 0.05677467204804998, 0.025266866650781594, 0.024846599553711712, 0.038219388225115836, 0.04081871593371034, 0.055641976578044705, 0.03476697289443109, 0.07759357307804748, 0.028209138945385348, 0.004104589661437785, 0.08279138986836188, 0.022710783887305297, 0.034967159808729775, 0.1050381273671519, 0.002269829446959193, 0.018964518894790672, 0.017443724718759768, 0.021701991827285383, 0.029117236408637837, 0.09116304572671652, 0.1045953991706483, 0.03384024937986396, 0.042372565367259085, 0.05567030806560069, 0.050225044396938756, 0.04941942454024684, 0.03218396501324605, 0.018193648247688543, 0.07483577457605861, 0.025170715853164438, 0.02178074853873113, 0.012665479262068402, 0.028050883374817204, 0.008890173103281995, 0.054559880736633204, 0.023007887866697274, 0.06325637092231773, 0.00924713129279553, 0.010518427479837555, 0.03567671235941816, 0.03848380431008991, 0.040875300983316265, 0.023469822845072486, 0.05827761757245753, 0.023513822925451677, 0.03664688119897619, 0.06623060195124708, 0.046280458991532214, 0.025221048308594618, 0.010699741578719113, 0.008446308493148535, 0.013355686805880396, 0.0365404238254996, 0.008549350131943356, 0.020763464453921188, 0.04733605273941066, 0.04010379023384303, 0.021281474255374633, 0.039853523194324225, 0.09696664055809379, 0.036206082586431876, 0.030997877584013622, 0.038103346014395356, 0.0010942649760181666, 0.07167890842538327, 0.020044737102580257, 0.0060759569987567374, 0.030433309148065746, 0.029926403731224127, 0.08606819450506009, 0.04455221969692502, 0.04020373526145704, 0.06994010094786063, 0.05650500155752525, 0.029840938004781492, 0.01267332561837975, 0.02516756358090788, 0.04895084734016564, 0.02857634248357499, 0.02649282781931106, 0.10275673572323285, 0.06242853487492539, 0.02139738844562089, 0.04012695266283117, 0.0401667837286368, 0.043007023705285974, 0.035771195180132054, 0.04347729300206993, 0.01645250857109204, 0.027663647415465675, 0.02022870809014421, 0.0712812805431895, 0.02752119216893334, 0.04602449967933353, 0.015300919876608532, 0.028775601713277865, 0.018747459253063425, 0.020942934315826278, 0.07358566392213106, 0.014164882886689156, 0.03420452885620762, 0.0582997558376519, 0.0982752769778017, 0.023357879144896287, 0.0358867141767405, 0.010741163623606553, 0.09624375161365606, 0.025871676189126447, 0.02892152278946014, 0.024907459373935126, 0.04830721234611701, 0.015830343909328803, 0.050651345154619776, 0.03467480928520672, 0.02321131425560452, 0.006592821573576657, 0.07514114608056843, 0.05210293777054176, 0.03909670325811021, 0.04318198873079382, 0.03794664524320979, 0.00694592245054082, 0.054242289770627394, 0.04626721907698084, 0.033949111311812885, 0.049258348808507435, 0.03516565833706409, 0.047616603114875033, 0.06593707512365654, 0.07934389126603492, 0.031533602450508624, 0.10486892511835322, 0.043801674619317055, 0.023003919231996406, 0.0407588134839898, 0.056661297858227044, 0.08170678556780331, 0.01918699621455744, 0.02745144327491289, 0.01793081664800411, 0.12129232665756717, 0.023439240794687066, 0.01726102280372288, 0.050790787281584926, 0.03138237872917671, 0.03664007941551972, 0.10457419601152651, 0.03805897671554703, 0.058394160732859746, 0.07879928845795803, 0.02441551194351632, 0.05993531573039945, 0.09019714794703759, 0.046543587450287305, 0.07525911045377143, 0.021893284101679455, 0.008119866488414118, 0.03579520736820996, 0.012465014042390976, 0.02828186385158915, 0.005707468153559603, 0.07015196184511296, 0.041162055713357404, 0.019610387753346004, 0.05451963406812865, 0.02770861599856289, 0.06415687807020731, 0.005987882159388391, 0.07276114527485333, 0.007940067298477516, 0.02531222486140905, 0.05469025010825135, 0.013915641866333317, 0.014971067703299923, 0.05437501546111889, 0.023324604953813832, 0.0883572080056183, 0.11773805526900105, 0.019637153309304267, 0.057732985078473575, 0.011001353177562123, 0.039162464963737875, 0.04486861951590981, 0.07227649315609597, 0.06636945036007091, 0.02298522824276006, 0.03994977232650854, 0.02117490741511574, 0.06848100150818937, 0.059326379850972444, 0.018208533874712884, 0.015369879311037948, 0.07270211484865285, 0.044995189091423526, 0.009432857459614752, 0.06827966426499188, 0.04453262699826155, 0.02774429289274849, 0.06629252675338648, 0.06059446903236676, 0.010132540373888332, 0.05318233590514865, 0.05122162627230864, 0.03425518414587714, 0.04974035517079756, 0.0018468237090019102, 0.11056321643991396, 0.0266366987125366, 0.015268827555701137, 0.02182662810810143, 0.03811126473010518, 0.04235791908286046, 0.05441353663627524, 0.011056234998250147, 0.05011498389649205, 0.041678661000332795, 0.02979025859531248, 0.03076309360039886, 0.03775693003262859, 0.01748174679960357, 0.039402033944497816, 0.02668626304512145, 0.07085438977810554, 0.03870237051160075, 0.04203353375487495, 0.02180028001021128, 0.015194648967735702, 0.013413906435744138, 0.05462225453811698, 0.05345557241525967, 0.009719458194012986, 0.03624946853960864, 0.2111237368080765, 0.07750108663458377, 0.06834736297605559, 0.13183699833462015, 0.11200448949239217, 0.15308335045119748, 0.17029657523380592, 0.10545283206738532, 0.13683380442671478, 0.12925108865601942, 0.08175551498425193, 0.12940596003318205, 0.11158318709931336, 0.16812001937069, 0.30509785981848836, 0.13671175081981346, 0.1419253382482566, 0.15359797049313784, 0.1157393328321632, 0.09719374516862445, 0.1267047057626769, 0.11345128412358463, 0.12565435899887234, 0.10452207498019561, 0.20503490493865684, 0.22665997501462698, 0.27810942206997424, 0.22176628292072564, 0.23143992555560544, 0.13267580332467332, 0.12205397797515616, 0.14676992985187098, 0.10483089747140184, 0.07231655428768136, 0.14222930709365755, 0.15818753046914935, 0.15366338338935748, 0.10971985466312617, 0.1328616519458592, 0.1250707489089109, 0.17814261984312907, 0.12108942348277196, 0.2762921992689371, 0.12273066822672263, 0.11981776828179136, 0.12944079644512385, 0.17205945798195899, 0.16938950750045478, 0.1737151003908366, 0.1421274695894681, 0.17919053236255422, 0.14584136952180415, 0.08422132290434092, 0.16432222706498578, 0.10303495204425417, 0.1474955870071426, 0.12098232415155508, 0.13633082126034424, 0.13987987535074353, 0.2655513631179929, 0.1496574335033074, 0.15887373505393043, 0.08967999718151987, 0.13749102072324604, 0.0989469132036902, 0.10679853134206496, 0.1356092162313871, 0.20306104444898665, 0.12034496030537412, 0.2321752009447664, 0.13456017564749345, 0.08324591079144739, 0.17870760202640668, 0.15947125299135223, 0.09567010114551522, 0.24894552683690563, 0.13641072087921202, 0.083289905305719, 0.1797384154633619, 0.212304983579088, 0.1372113497927785, 0.1130021883000154, 0.1840815824107267, 0.11113818793091923, 0.3110664489213377, 0.11613433351158164, 0.08419793783104979, 0.13305196829605848, 0.13934968505054712, 0.10126557550393045, 0.22320627205772325, 0.16229754430241883, 0.1552561213611625, 0.09513241515378468, 0.12196575888083316, 0.13600084756035358, 0.19124056154396385, 0.16677420877385885, 0.20305611658841372, 0.10269857360981405, 0.07756283332128078, 0.13398852897807956, 0.13485491217579693, 0.11128070997074246, 0.13062471494777128, 0.11230670686927624, 0.13703209144296125, 0.13782038586214185, 0.09639820738811977, 0.12040310015436262, 0.12268075137399137, 0.2255384117597714, 0.16793172166217119, 0.14476951531833038, 0.1961365097668022, 0.1692995592020452, 0.09427700089872815, 0.14569384540664032, 0.10777225877973251, 0.1412521954625845, 0.3660901088733226, 0.2669398026773706, 0.14105211244896054, 0.11914532311493531, 0.17186955723445863, 0.23071616829838604, 0.10027412557974458, 0.19980249664513394, 0.1479840389220044, 0.10907814183156006, 0.1900337848928757, 0.10710472663049586, 0.16543043166166171, 0.32185157644562423, 0.08342399654793553, 0.13745646632742137, 0.13937460636952892, 0.17803655209718272, 0.16197715915041044, 0.17724607576383278, 0.23889785661594942, 0.2546252275351435, 0.13563807093305513, 0.16905462078284472, 0.22835129988379776, 0.1114751526620239, 0.11752345584682189, 0.09071944921743125, 0.21150779823074117, 0.1670685296994634, 0.22885493614012375, 0.12330823723459616, 0.11742345144739375, 0.08082418644335121, 0.21186944679357111, 0.11178516258951277, 0.19024703360628337, 0.10500205899006687, 0.11440652466262691, 0.11453006256488152, 0.13397647649981081, 0.08674868455273099, 0.14011062390636653, 0.16878197056939825, 0.11500520035042427, 0.10316235653590411, 0.16380673128878698, 0.22513411939144135, 0.1510182800120674, 0.14436274417676032, 0.11529140218044631, 0.16071092162746936, 0.0678722548764199, 0.1415817832457833, 0.1783536866423674, 0.17128156847320497], [0.022637923539150506, 0.02548764445236884, 0.015856623358558863, 0.03236151642340701, 0.02898488921346143, 0.022247169799811672, 0.03456750215264037, 0.030368538209586404, 0.013850766099494649, 0.019845960268867202, 0.013732659790548496, 0.07198813167633489, 0.010666330090316478, 0.03842928614176344, 0.03522076651279349, 0.028996830369578674, 0.02124713693774538, 0.029215240720077418, 0.08777660361374728, 0.016664506765664555, 0.07789205745211802, 0.011527571132319281, 0.07895082759205252, 0.058741563771036454, 0.0659857525897678, 0.014262106087699067, 0.02246588257548865, 0.05169174342881888, 0.03891816479153931, 0.05788495465822052, 0.014174570696923183, 0.035764586355071515, 0.018695700018724892, 0.049190516510861926, 0.02227837154350709, 0.06316186583717354, 0.04881432556430809, 0.0421357497543795, 0.05641080075292848, 0.07199302985100076, 0.04492832158575766, 0.0403768597607268, 0.029739074525423348, 0.036962613085052, 0.02375316555117024, 0.035207381879445165, 0.06401890539564192, 0.010620694501994876, 0.06636413658270612, 0.06170846609165892, 0.03519532569043804, 0.02077098426525481, 0.0316279999242397, 0.04288381605874747, 0.009819415281526744, 0.01834153415984474, 0.09140066656982526, 0.008193128523998894, 0.04656307624827605, 0.026544930296950042, 0.0497171519236872, 0.048831335589056835, 0.02660792008100543, 0.05095399668789469, 0.07648628132301383, 0.02960885172797134, 0.0062550177517550765, 0.11406645775423385, 0.029380535561358556, 0.010998382731486345, 0.029325149080250412, 0.010884346174862003, 0.013008547230128897, 0.059847953816642985, 0.01473901296776603, 0.04997821721190121, 0.014858984850434354, 0.017721885378705338, 0.04754944246087689, 0.021574785860138945, 0.01956966796569759, 0.03836585849057883, 0.04533556399110239, 0.049203667367692105, 0.07605392835102975, 0.04344518398283981, 0.024662244504725095, 0.030935461109038442, 0.03252010967116803, 0.06126640953880269, 0.06073351782106329, 0.06109626105171628, 0.036162507385597564, 0.029877960041631013, 0.038092406757641584, 0.032071195673779584, 0.06663739535724744, 0.025936400743375998, 0.056103061797330156, 0.07570315967313945, 0.026647569320630282, 0.04125780389585998, 0.021021171523898374, 0.02512277125788387, 0.034101255296263844, 0.09409475169377401, 0.02244028219138272, 0.0345750423730351, 0.03366511737112887, 0.02919154394476209, 0.062146763666532934, 0.10625566515955143, 0.060942465788684785, 0.01618510163098108, 0.033754471951397136, 0.044381752086337656, 0.016696905222488567, 0.01999414304009406, 0.07217966514872387, 0.013143016039975919, 0.026309608256269712, 0.03771453113586176, 0.02834499278833391, 0.12229221480083652, 0.024170462202164344, 0.06431792411603965, 0.06276667219935916, 0.07826139466487803, 0.05806934495922178, 0.004575955481413985, 0.023207061749417335, 0.042563085808069445, 0.058277324424125254, 0.023298859850910958, 0.025878837914206088, 0.029182074140408076, 0.05738050946092699, 0.014464283813140355, 0.046475881317746826, 0.041817609599092975, 0.05343246193660889, 0.067243819066789, 0.029485790655598976, 0.032687300699763, 0.013960050127934664, 0.0030060886456340086, 0.038524986084667034, 0.05749034360633232, 0.0461533142515691, 0.09499925159616396, 0.028693538733932655, 0.00704712078004377, 0.03248190390877426, 0.04175434893113561, 0.03408820462937001, 0.0880660634720698, 0.04802417948667426, 0.050083995520253666, 0.011547920821612934, 0.06388486610376276, 0.02018915347434813, 0.03166134833008982, 0.004124874876652029, 0.05453445475723129, 0.018969194425153546, 0.03539029159583151, 0.0436505919060437, 0.0582959486200707, 0.03818818091531284, 0.011722484159690794, 0.06118433542724233, 0.021376092518039513, 0.04167486491496675, 0.035600137562141754, 0.06502210351754911, 0.021843419199285563, 0.04671619986766018, 0.00983150486717932, 0.04950044480210636, 0.01178391636130982, 0.007123645946194301, 0.019405167222430464, 0.038591489937971346, 0.06122342063463293, 0.031005235978227574, 0.0492136715183733, 0.03294174231996294, 0.024416229971393477, 0.0720782506687101, 0.06681378159555607, 0.024418669781880453, 0.015479656867682934, 0.04558677726890892, 0.02324034892808413, 0.10892258767853491, 0.032640508288750425, 0.07768772193230689, 0.06389045447576791, 0.008103036434476962, 0.02919153466791613, 0.024656199711898807, 0.04425575396453496, 0.014530075204675086, 0.03797553705226164, 0.07788591246935539, 0.09431893224245869, 0.0675079642678611, 0.07980158858117647, 0.02586332517239498, 0.07150373188778758, 0.05939660557487514, 0.028961199859622866, 0.009736797546793241, 0.060640330048045143, 0.023563995819131378, 0.060472259574453346, 0.06397309261956252, 0.0831806834321469, 0.02823122154950397, 0.01699388860288309, 0.041303679754491895, 0.07071309970342554, 0.049861262159538455, 0.01491971108407597, 0.04554592946078628, 0.031229986125254072, 0.05412276688730344, 0.053228868564474396, 0.060153529411763884, 0.04274745013390202, 0.045819351507816464, 0.030741606569790747, 0.05202853375521954, 0.010321591362298932, 0.013782706519123167, 0.031209172593662515, 0.012727173998428043, 0.0494022141356254, 0.015565566027362365, 0.025191785425704438, 0.04063254818902351, 0.00858146286191186, 0.007027379188002669, 0.03644126918516122, 0.03314651199616492, 0.022324713099806104, 0.06902691049617715, 0.016906038727029227, 0.03209756046999246, 0.030931425681046676, 0.05824544918141328, 0.05581503799476195, 0.04157245595706627, 0.029031132435193285, 0.04181204720225651, 0.05870438959391322, 0.004645929338948918, 0.046212144297896884, 0.03496483317576349, 0.008237881884269882, 0.03644123949925415, 0.01830528024584055, 0.05500802661117632, 0.04142786332522519, 0.06044839210517239, 0.02324001310626045, 0.08056427890551277, 0.025763300363905728, 0.059186113940086216, 0.020727956398332026, 0.024685345706529915, 0.013695176694454858, 0.024928148595790844, 0.027749461951316334, 0.0476381884800503, 0.019412789079069626, 0.0628915979177691, 0.06354275828925893, 0.0886931931017898, 0.02580178072093986, 0.025449596396356355, 0.04682190025050659, 0.01231822558111162, 0.013742490464210277, 0.0072331396313529694, 0.041825873413472436, 0.03437514489633031, 0.03857896619592793, 0.013288967729749857, 0.049690182277117856, 0.022739093110430986, 0.05592476823949255, 0.034501703339628875, 0.10870540558244102, 0.05032304128690157, 0.04525160482444335, 0.03425014867389109, 0.029575065454992, 0.020911053507006727, 0.09455598163185641, 0.04174268979113549, 0.03367662437085528, 0.019809561636066064, 0.03388075951079372, 0.07367317797616124, 0.016590176965110004, 0.014600651593354996, 0.039282466532313265, 0.038244072056841105, 0.06256287844735198, 0.05562628386542201, 0.01968482702068286, 0.01772653493389953, 0.0554648110846756, 0.03933944120944943, 0.005165859447515686, 0.06919756735442206, 0.0582372113422025, 0.05251075534033589, 0.05227000634477008, 0.026652610358723905, 0.06025563779985532, 0.024556345597375184, 0.056122925379895605, 0.04028595409181435, 0.052818906187894754, 0.06548872886924073, 0.025349000134156086, 0.057031176838791, 0.030655962727905717, 0.1330771271022968, 0.04083210056705866, 0.03961795810027979, 0.024118808723869734, 0.05026728002121672, 0.043798060360131785, 0.07739476655842736, 0.04036656246171333, 0.03400321758817881, 0.01192387891933322, 0.021234383129922207, 0.010895920895563904, 0.04626338959496934, 0.04694631017628126, 0.0403539311082568, 0.053783089606440626, 0.04941434825013857, 0.07017640076810494, 0.03145577713439707, 0.02650291546160588, 0.015505901992582949, 0.020076456494280137, 0.14309307793155313, 0.06056117628759239, 0.07531363604357466, 0.15954867383698002, 0.12731973838526756, 0.12420527113135904, 0.14616942848078907, 0.11010641712346114, 0.08317485757288523, 0.12394230594509281, 0.14075419952860102, 0.23226324934512377, 0.18544244376244023, 0.18221407168311998, 0.12586410477524623, 0.10101498191943392, 0.19620085397036746, 0.13997300004120916, 0.31415125995408744, 0.11630329085164703, 0.17694593640044332, 0.1703020671266131, 0.14482823404250666, 0.1557660213438794, 0.15811411722097546, 0.07943321616039611, 0.15122404787689447, 0.15208205964881927, 0.1873425199300982, 0.14766902691917494, 0.10907251635217108, 0.19433447130722925, 0.12341201174422167, 0.17662385915173218, 0.13365387974772602, 0.18764994718367234, 0.12003590032691136, 0.18800135410856456, 0.17649098503170535, 0.10620657951221801, 0.25211198895704, 0.17685156490188092, 0.12374824917060323, 0.08891994148143567, 0.11728789817425422, 0.11436526125180535, 0.13790818193228915, 0.11583793457248248, 0.12839295814046636, 0.1942230452550575, 0.08533614745829254, 0.14166131179081276, 0.1425283629214391, 0.13880827347747982, 0.09589602574124001, 0.12647487747017294, 0.20941540191415697, 0.11498872467200272, 0.08456740120891482, 0.12240302487043664, 0.1305984874488786, 0.18991578341228887, 0.14629151177359745, 0.07806339708622545, 0.17637032666243613, 0.09294016286730766, 0.11214450307306834, 0.19621888815890998, 0.12313488638028502, 0.09680157207185403, 0.13188198732677847, 0.11546346169780008, 0.10544622695306316, 0.19222730625187978, 0.15595020755426958, 0.11644240643363446, 0.09963478762074374, 0.05404150171671063, 0.2019074055715464, 0.17142808326752856, 0.08145118990796618, 0.08606771210907027, 0.2166493676486425, 0.13451250008074567, 0.13689543236978352, 0.11806427370174788, 0.11331665111356415, 0.33040423470083624, 0.19753664557356387, 0.17513850994873792, 0.1924110174877569, 0.10517855655052699, 0.15339297446189448, 0.10061632245196961, 0.18046076263999566, 0.11910935121704824, 0.1946674135979265, 0.1286039804108441, 0.18015275651123375, 0.1382259398815222, 0.13980119285406545, 0.151968362624757, 0.2230239412165247, 0.08632988319732249, 0.1353418649523519, 0.20295891008572653, 0.165456481045112, 0.08737546537304297, 0.09985374344978482, 0.15614234958775342, 0.14430665265535936, 0.16971988196019083, 0.1525917073013261, 0.10990171052981168, 0.08441028854576871, 0.11144855408929288, 0.09802498025237583, 0.1950848865089938, 0.190754113427829, 0.14622730115661398, 0.1715133263496682, 0.09524135501123965, 0.12938807427417487, 0.25500378222204745, 0.12774384609656408, 0.20010662876302376, 0.19168368307873607, 0.22100611589848995, 0.12722965650027618, 0.0890005164546892, 0.24997219908982515, 0.12410686234943569, 0.21997981471940875, 0.12666998809436336, 0.10720660124206915, 0.13331807276699692, 0.12722667306661606, 0.14289348473539576, 0.22597506176680326, 0.18564430793048814, 0.23047543043503538, 0.11218866828130558, 0.18302466021850705, 0.14579856244381517, 0.14930221193935722, 0.14025765820406377, 0.14549505372997373, 0.12360288470517844, 0.11989430597168393, 0.19451542175374925, 0.09989741141907871, 0.05926144935074262, 0.09074548375792801, 0.12686192232649773, 0.23943196545587853, 0.09049363594385795, 0.14696509984787554, 0.13759631663560867, 0.11885376297868788, 0.15611693845130503, 0.12115059871575795, 0.09106122306548059, 0.17497492575785145, 0.09580032579833642, 0.06418446369934827, 0.13998603215441108, 0.12517727678641677, 0.1381912815850228, 0.22235354437725618, 0.13992548774695024, 0.15306463348679245, 0.17694271547952667, 0.1497999407001771, 0.08472670320770703, 0.26790560397785157, 0.09685731478384696], [0.031289135295082815, 0.006419876581276185, 0.07570571266114712, 0.03796099466853775, 0.04491938241699245, 0.056046461904770695, 0.0599422770756064, 0.03242603132093791, 0.02495102715329267, 0.030875352713337634, 0.02817767559463391, 0.029341891931835562, 0.0667468918254599, 0.010195627564826282, 0.04254433915775735, 0.07522975851316005, 0.047756460844539106, 0.0028472054964368, 0.04940703067404684, 0.06654013690422289, 0.03691392448672559, 0.011671744450723054, 0.014986278019932797, 0.035394321457715705, 0.04493730157264508, 0.04838229171582498, 0.06628402174101211, 0.03892315202392638, 0.04311631237214897, 0.03148977491946425, 0.016667911368131172, 0.03368707752088085, 0.032232612793450244, 0.040070152390399016, 0.04881254812062252, 0.10150002737645991, 0.10314758037566207, 0.03688547425554134, 0.054621530944132246, 0.06658783473540097, 0.068561509688152, 0.02423709593131207, 0.018752429787127767, 0.026130374026251957, 0.02294869045726955, 0.018610256556712557, 0.05991719619487412, 0.022823874205641914, 0.0863705825759098, 0.028032235059072264, 0.01413668591339956, 0.07589691216708161, 0.09177555504720658, 0.021185965415497776, 0.026850626491068397, 0.08414270720095374, 0.033924735471373424, 0.046812612272333354, 0.017620491307752673, 0.06183551435242407, 0.04390653266455047, 0.06196576126967557, 0.026348537612648215, 0.04500350114540197, 0.05332453139999416, 0.01929051839397289, 0.031439824670087546, 0.0664420472458005, 0.06259490954107605, 0.08799759292742237, 0.04333177268563304, 0.07521383202401921, 0.09528924580081366, 0.019839505439449567, 0.03172540680679958, 0.031637113497708924, 0.04686545689764898, 0.03818061471974943, 0.05239702863036655, 0.04027158240205608, 0.09129301804932766, 0.031404294350068085, 0.1551753014791757, 0.03602987446356565, 0.10836304543772712, 0.04366854816908017, 0.05399354413384572, 0.05321932454535272, 0.02681652294995729, 0.03113430844678078, 0.019052942079724744, 0.11872505972860381, 0.058317170332884416, 0.034917562079499476, 0.09123835145146586, 0.011568379050004296, 0.07437452237354591, 0.0608755129360361, 0.06122280094132293, 0.01942738155776169, 0.037665649579139426, 0.030684876801387873, 0.06650881085079163, 0.058604867590474896, 0.031059379361977335, 0.017517167652840726, 0.034588122725836, 0.03828988112218212, 0.07739832886727527, 0.08419478370342404, 0.03136810722935479, 0.04085244654561393, 0.044202957578818314, 0.11944718426093459, 0.050474639792810194, 0.04228101402986795, 0.006942250211068313, 0.05150690041773487, 0.03571732639102265, 0.015638634176866617, 0.057440181844867766, 0.030378525661944877, 0.009979687638406176, 0.07056093716528267, 0.0285248392901849, 0.043156599858775735, 0.008180451713997172, 0.05029645013564732, 0.013545145975513151, 0.04240711234160699, 0.047661302669439465, 0.05367082863813266, 0.04254201252479106, 0.0034810112083505373, 0.01163294589787256, 0.02429918215057114, 0.05688221295713447, 0.024205923873523716, 0.0156771256661159, 0.019999143260065466, 0.05537823584745638, 0.038993611524347216, 0.03636044930317439, 0.047818990497034974, 0.03582935358281247, 0.002702929436964041, 0.04351318326371256, 0.024564791237935424, 0.05773288859927561, 0.019004631976713426, 0.03158300351060461, 0.016596364621364046, 0.047924063765094616, 0.04802667681360617, 0.030239411935326643, 0.011034867638954893, 0.006821356209911755, 0.015827397583052516, 0.02749505001702346, 0.004309625119276461, 0.0200037835384137, 0.07344471523538232, 0.02762471620371798, 0.0525991488393629, 0.045641673932550475, 0.048455400683451444, 0.03368724079336971, 0.006506688378067338, 0.03765219444176182, 0.026991558479494415, 0.034447927318979055, 0.06139376579085365, 0.0342825693951454, 0.035562336270231754, 0.03696735169796739, 0.036134335459792055, 0.06545809301314875, 0.049944816855713725, 0.06834774889284745, 0.05490214069141075, 0.04951296483341139, 0.06044964262400754, 0.04814634070498869, 0.08542186551494524, 0.0679244872299023, 0.04741248281789012, 0.01154891993792262, 0.012269937742530601, 0.041394626241526566, 0.013333972492546309, 0.05549408138904255, 0.04484946468437556, 0.08034056590986438, 0.028709532016364392, 0.03235836229578126, 0.04954381591232959, 0.029243813405628316, 0.0714635594340507, 0.03685018884425517, 0.05065184610430151, 0.008573768645874225, 0.015706175181549042, 0.015130479168874444, 0.03205383683962282, 0.053017564277979545, 0.024367055266338866, 0.03464176144916564, 0.016653513703204226, 0.027432802380644716, 0.016163568216143176, 0.019433053421380464, 0.0414678094239207, 0.03702676804095972, 0.021774822489533108, 0.03972516133217141, 0.018407778261462227, 0.06402658662409522, 0.0636243203189224, 0.0874782602477353, 0.0479685963364318, 0.022209730304894038, 0.008218166731239762, 0.018129268792108633, 0.06847028489573859, 0.06326539543806575, 0.01700639935734216, 0.03978418062615674, 0.053208578246994875, 0.04850740297115408, 0.044158925957162865, 0.005823154133395292, 0.013011511182412505, 0.06221399482456036, 0.07497494952986017, 0.015810415388841648, 0.07509586022933945, 0.04964320432918612, 0.03569583008356858, 0.033320285874651745, 0.12468034954508767, 0.014925497980584623, 0.044555355270858854, 0.05040526011725888, 0.04014422243926674, 0.02114692844770616, 0.046224219040595926, 0.021208029465924483, 0.023703573388047516, 0.011272961601207498, 0.02111235178745119, 0.0619904747873079, 0.014977810114942258, 0.05072322215710301, 0.018190633272752166, 0.03794571755861398, 0.04017014194687363, 0.02664364335942082, 0.006856131858512526, 0.0340440542640863, 0.04401317557494622, 0.024561373647884466, 0.02382696471613599, 0.0721003592479974, 0.05222052364842966, 0.022027277009328827, 0.032091200264403597, 0.03761873100302182, 0.028692503437923733, 0.10728106833994389, 0.07012370086158626, 0.08355912679689936, 0.01830951605370501, 0.04805416967428755, 0.006865541363367811, 0.008432570411969209, 0.02851385735993972, 0.0343316142243566, 0.03442374443693552, 0.019249511024099775, 0.057821864684228785, 0.019833750084217172, 0.043564309817156754, 0.025523694275761954, 0.12292838378925808, 0.042998978824471124, 0.025843524672382046, 0.018871234642574564, 0.019550487158994656, 0.027722624035959598, 0.10120650797034614, 0.06841766662546434, 0.06350209601805545, 0.04300941713154316, 0.06938963517313823, 0.019327972731844056, 0.03859180163999554, 0.03897731025062967, 0.024618131246825214, 0.006967164108573343, 0.02727154853346292, 0.02250818128231913, 0.05585133272688836, 0.018967346477438696, 0.07436400614096783, 0.00523876107763499, 0.03850590917863883, 0.06535057807923295, 0.021904290151724126, 0.0639910229074303, 0.04830496363865677, 0.05510417926416267, 0.006256820242924732, 0.023383858024317306, 0.03464991023065522, 0.0372638953558635, 0.044333942933008075, 0.1275146857369691, 0.033262287033721805, 0.05298174452036619, 0.0532188198849326, 0.0096660949930083, 0.020691682075266726, 0.030742808849026915, 0.008075213318079477, 0.038465094767161645, 0.025790127147047315, 0.06534216212457977, 0.036374776464072056, 0.022623850563832093, 0.05455051483295392, 0.012278700651222607, 0.02874346300814068, 0.0328992803406436, 0.02191679348470643, 0.035986069196951576, 0.041170775948558, 0.05087279831059277, 0.044720961814164184, 0.025085220440814737, 0.041280981167801656, 0.014482973874692107, 0.03221262675651815, 0.04141906516451854, 0.01327952111751074, 0.05599558397079818, 0.01578809900820488, 0.024856388481566682, 0.09712414655950852, 0.061607463503605686, 0.07663511161808856, 0.019713303227035794, 0.0478433514945209, 0.19558497529942542, 0.2015527183539234, 0.17371557536534965, 0.12265830882824957, 0.14794031158089638, 0.21121099853189662, 0.13251612283056602, 0.1699066805304028, 0.1796483335783705, 0.16362625581678003, 0.1394907376379706, 0.08195924936444499, 0.09880791636533104, 0.13873914984287694, 0.12107037997338921, 0.17694323498290032, 0.1709089509677142, 0.11180072542629205, 0.15261964173987508, 0.21345998800825328, 0.09238146667485125, 0.1414792926516384, 0.15010539384093136, 0.17730657564243302, 0.10063597452244721, 0.10638030886184424, 0.1903087060782127, 0.1695648769964464, 0.11616282456088811, 0.13864270033081993, 0.14278778806328773, 0.26334795635193586, 0.1722420856822282, 0.07560891433968209, 0.20873439236311242, 0.1617992960382253, 0.17162975447718054, 0.13593693380244076, 0.13001158222323284, 0.18368695280514657, 0.16271709522698075, 0.07939585644635372, 0.17328982008621097, 0.0976515092770569, 0.09010837224195711, 0.12348257514531724, 0.1068119122646749, 0.08036529427045025, 0.2203589482815005, 0.12891422782558948, 0.07425274336128496, 0.15007345180492848, 0.15387603838462383, 0.13808085001073778, 0.10125256565515883, 0.15434621862368658, 0.14515091985231265, 0.21016060723923147, 0.18073163169901818, 0.17916231590788811, 0.25704709289129823, 0.15384688682388514, 0.18723226647125557, 0.14503012789646164, 0.19641757593490183, 0.11764038863475434, 0.12103506858693436, 0.13137918227585033, 0.11966643694904633, 0.13607682863948867, 0.11422046824009158, 0.13419778493698686, 0.17898610036354512, 0.15987904829671606, 0.2382081194082275, 0.09833797361352481, 0.11481093577458523, 0.07626256832736544, 0.11483711132314056, 0.1260697390534915, 0.10948254552204162, 0.0997154219658114, 0.25179598247632384, 0.17424196586944163, 0.16692887234967202, 0.11088078143075109, 0.16800664889160544, 0.14045861695194617, 0.10660956570063718, 0.1609670219477266, 0.17736618494382128, 0.22572388930711895, 0.2938333939528093, 0.1870113587938249, 0.18287056067492813, 0.1625379259348847, 0.18155681085772812, 0.17656723328400403, 0.13489503267919645, 0.14671150798676535, 0.09498622690443881, 0.11738206929294392, 0.08299205175717361, 0.1723903074162081, 0.11815612931968644, 0.08258255693363026, 0.13553853408666328, 0.235348075220827, 0.1872298470698297, 0.10306918731657788, 0.09618723706807941, 0.10780788186821155, 0.19868839939590544, 0.2809151558903977, 0.16695692553184927, 0.14736942190211266, 0.1673672441393137, 0.18732297176029533, 0.10683246233384125, 0.07430903526255861, 0.10513593500945717, 0.17833179328590631, 0.10081915141199715, 0.13609858840936795, 0.10360734086134471, 0.11170686600962654, 0.1319002590025775, 0.15082092810189351, 0.09971390798455104, 0.12336329717072658, 0.24933139909990132, 0.12512310000602156, 0.1699219984584488, 0.1368915435159579, 0.07351038046181202, 0.09611714122002013, 0.18873992463340983, 0.11559544524061494, 0.1575956676970236, 0.12364682726911269, 0.1979371826746501, 0.10449311637785286, 0.1110549560689833, 0.11603409162489697, 0.102737536362838, 0.06645136119914241, 0.12612744845682755, 0.13698054186534137, 0.08770600310526788, 0.10351691016694531, 0.17239170265384018, 0.10407539113657549, 0.05975057661999017, 0.13256333826575428, 0.10229434803477488, 0.10695041186409071, 0.0910271362226922, 0.13595464144600555, 0.15894367505097762, 0.12007144177914597, 0.08787101964117028, 0.1583526880131103, 0.26131622318644077, 0.10738988203229383, 0.08266850505606271, 0.13616839481983334, 0.16483842046000063, 0.08060052539804019, 0.16738024656660855, 0.06411313588614576, 0.15565257665002719, 0.2343552597449161, 0.17655859468504786, 0.16220029327087104, 0.1193179763504304, 0.08480491815134883], [0.043309148313710466, 0.03519788609992247, 0.023959067002579104, 0.012456771564757219, 0.11474209415609948, 0.05614619542029686, 0.017688395964796655, 0.06674907373962924, 0.0173892733437242, 0.020241200290911365, 0.02488933056156384, 0.07042179931886494, 0.039477669924963266, 0.028461396796046756, 0.009265231346944347, 0.039830961904954165, 0.06851293612271547, 0.08183102108887397, 0.007152328098527505, 0.04008499163319357, 0.015259335486916825, 0.04077284749655519, 0.012766468862537295, 0.017336846176476683, 0.038509185760631226, 0.032585526278126054, 0.02052043335424969, 0.018300695628568064, 0.04576304476358928, 0.04105122709006537, 0.016896420493139885, 0.07217703052447177, 0.027882775793841574, 0.028154500178061426, 0.06119904479419347, 0.016074035520432517, 0.032117821101564914, 0.16799622913822532, 0.06875357750686817, 0.07527039109845646, 0.0286262036752305, 0.038470968866022304, 0.05881135533854831, 0.03082891653320985, 0.022097083419794217, 0.031398750506923534, 0.02839292625139933, 0.06132733244157862, 0.01322679616350797, 0.06142180413007736, 0.02197475521825254, 0.04340791703725699, 0.05256101729173679, 0.050318799912929535, 0.07217536811367609, 0.01791509424947435, 0.028887601074529812, 0.08870099307387136, 0.061013396552880295, 0.02313328855962027, 0.06745048493030481, 0.04104294101125561, 0.036895600860589184, 0.019341513216204476, 0.026808166367118247, 0.028058937532478012, 0.03863984456984326, 0.008300546051032143, 0.03390427817066666, 0.04533700746833347, 0.02123351481714053, 0.017777227330952883, 0.020910372586513404, 0.04754730878630653, 0.06220699637196958, 0.06252652805414982, 0.0579899091826519, 0.03392258324311115, 0.058226212713634595, 0.04693964569014497, 0.044012897269567475, 0.056983642280101776, 0.11939919699216262, 0.05101996619487181, 0.022117254993645474, 0.0279133782532881, 0.021504912656382658, 0.045456949665094726, 0.06344773370074108, 0.010002412200265098, 0.06961683626286685, 0.026287173132004682, 0.031078647371032275, 0.03694231163535733, 0.05397674562118482, 0.12231494678417221, 0.046951917101978324, 0.01066297001671046, 0.024694123458175454, 0.00999870702798944, 0.09210727279423736, 0.04023103145300411, 0.04457367889699526, 0.040822445225785486, 0.08464885191642679, 0.07610292494064197, 0.09843831940088421, 0.007968832942424342, 0.030636828305432573, 0.05334941561159212, 0.06762748715118505, 0.005823018227602006, 0.030619872086390387, 0.06666472123470157, 0.03822358507022727, 0.05731820987421088, 0.028164782634121366, 0.06652665950241499, 0.05078891335870139, 0.03917499983799644, 0.028236184662091546, 0.014419512826862046, 0.02236897107650293, 0.053306200352380984, 0.012492092228058027, 0.10501562544959597, 0.017719404750096146, 0.046993161959107965, 0.04270134792022873, 0.05458546998852398, 0.07160408509662375, 0.06499978713691235, 0.006346164154820144, 0.05597737166681327, 0.07001614139880985, 0.08082194515736774, 0.02754953664407367, 0.07731439938652329, 0.046499863819917664, 0.06691267277346924, 0.03245958752813749, 0.021003513975301757, 0.05110873076773714, 0.05428860349638853, 0.06973426628974266, 0.04788813639606815, 0.0060637904152827105, 0.03812286820902955, 0.0694563690922223, 0.04088674861122854, 0.0421940231899498, 0.08675280347233638, 0.06545864962390624, 0.015314271113311406, 0.01715446895104833, 0.07873507784097455, 0.10007995006162673, 0.020192424490232952, 0.06976440490689129, 0.04617247650458012, 0.029100684660079423, 0.011579604961298173, 0.04112288515898399, 0.08337276609381661, 0.02565520098869456, 0.01904839456983609, 0.031893596024019644, 0.018157182821596507, 0.059932885196758434, 0.04113451090233866, 0.018193444157077465, 0.01964119430340361, 0.014143225162115414, 0.050795618662959896, 0.032697980204829946, 0.035856427130056545, 0.050421887935954146, 0.10166089530684985, 0.024025630227697548, 0.04409819230204448, 0.0502983129263157, 0.03995524195488542, 0.022640608258370776, 0.08241135088610463, 0.016314393033098895, 0.023216700392367784, 0.03665087395347655, 0.010345365135435713, 0.026311367146263365, 0.018770642091112677, 0.01701554447208764, 0.043491427204571664, 0.028875474381493405, 0.11884064180776477, 0.028351892906357534, 0.0683187457616441, 0.041242779116146266, 0.019014383797184564, 0.027261523973720614, 0.06318456813460216, 0.06973894182010554, 0.0483980660646921, 0.03435119208006654, 0.05391964477894362, 0.011204005877516465, 0.05504238804860506, 0.015820406551938504, 0.02902536409237655, 0.04073762145708315, 0.040505574143026024, 0.06763589568436146, 0.04344398541434202, 0.013524081969080726, 0.053207798991934396, 0.027579252237046603, 0.023167772451415658, 0.023653270618524402, 0.06420850928407162, 0.040917692458606325, 0.01826030795200495, 0.01015018215184682, 0.041488804781693034, 0.007524761922468315, 0.020879712610621937, 0.013080273020023014, 0.03213797783246264, 0.03149073228996713, 0.06644906796282157, 0.0194847681268584, 0.06430899607948959, 0.05377896326535847, 0.035014657260035165, 0.046474653063341975, 0.044697528501274064, 0.09823428074014373, 0.023417562661052216, 0.08765636826865375, 0.03953107487177476, 0.005048081538916449, 0.005011707953599398, 0.02993099576997338, 0.028693937638308853, 0.08275886895717122, 0.04663736523070838, 0.0028576069280461525, 0.02084533633023966, 0.056695714956731535, 0.05245906846539583, 0.03733778357855044, 0.054574363748542964, 0.057129370397888124, 0.04220610164338723, 0.01628613390494138, 0.05624348355922848, 0.041433399746892974, 0.07146582298446447, 0.02761380292213289, 0.0005626561301141919, 0.009101165687752655, 0.09260462305974215, 0.01605414967343677, 0.011862631326948758, 0.04169405685388483, 0.03132898862531874, 0.06049331059330143, 0.03908528160536662, 0.05443415720947087, 0.02861311033484526, 0.03686489078972954, 0.07850389141822234, 0.031621784437447786, 0.13471544778440148, 0.030422980307776015, 0.024307240018970333, 0.03598561277613044, 0.04536227017524652, 0.019241354821133427, 0.049736796572688036, 0.029569805483333766, 0.08090576331596822, 0.06051503696653526, 0.02986542516737245, 0.02900272487750044, 0.03848747794108931, 0.0501662737224251, 0.06810456936364062, 0.06595518352696672, 0.049729612583178096, 0.018968335389217827, 0.03513025789288804, 0.021228872683423106, 0.04537951397651341, 0.03863843077851925, 0.07358095870586112, 0.07442497357260436, 0.026465811788511928, 0.041608086467022076, 0.04112283691938501, 0.0503412721445784, 0.04593350866343826, 0.012214159778523026, 0.04729185784526635, 0.04033290235383902, 0.022216624856810085, 0.035160444749635644, 0.054477279700222425, 0.0165801078765071, 0.03378200934093911, 0.012608064862433821, 0.07634093912201934, 0.07720135545241646, 0.05690858517482411, 0.02847328043571906, 0.07026425621006638, 0.0052591905478038825, 0.033367289797752164, 0.01980339253350394, 0.0328231248568045, 0.08882806359906681, 0.05650489765685052, 0.04035263606056105, 0.006042668892405345, 0.03081433333136374, 0.0395328820013674, 0.052209302375558764, 0.020698005173471756, 0.045477811436285265, 0.0852459690941032, 0.04824884614208713, 0.05763125518569723, 0.02712381105084205, 0.008977441320894286, 0.04605362526490353, 0.03422781745030079, 0.0498348268592963, 0.02977164553158218, 0.01588643357536057, 0.04463226032385137, 0.017050228743755724, 0.03926988341845572, 0.06474934198195115, 0.04030411073472351, 0.009780325435713166, 0.06557056549354456, 0.09518806880805641, 0.03972102014813572, 0.053401462428155355, 0.07037353003397584, 0.03131984165520407, 0.058662714291131124, 0.07766027731122449, 0.05454667050798889, 0.08287671458674595, 0.21953531278995797, 0.1163105342129711, 0.11112520776805468, 0.20371521794004366, 0.14017358771525323, 0.08808008264168166, 0.23923271364765242, 0.12403574233758263, 0.11518444385728799, 0.11433712643338367, 0.09905112558044493, 0.1243965225876309, 0.08610056698671542, 0.13025407155510038, 0.10070694610476494, 0.11249095987295732, 0.21098042809171602, 0.23059444123646244, 0.1711810371489264, 0.09961276809917763, 0.1345388760091737, 0.12153417032095604, 0.2208828303264454, 0.0852856517303735, 0.11004603598848917, 0.11973134518484585, 0.1656765872030519, 0.1274746542912908, 0.1427423389395699, 0.06596351784537546, 0.12479815806727856, 0.08315864906762727, 0.06317257502814755, 0.09457628679228947, 0.18812800903106108, 0.09866636653896421, 0.2941828564507887, 0.13420281669823453, 0.12557036272482947, 0.15080013312399387, 0.11613725015195087, 0.14672854769742116, 0.14794087561313063, 0.059795958950417116, 0.07892580979387276, 0.08568540957639925, 0.0918368787097279, 0.14103899127803743, 0.23808352765627205, 0.09951907937647775, 0.1886502731940709, 0.12026978816720657, 0.140561300504487, 0.18133306817617267, 0.181633370812051, 0.12416549201589078, 0.22407869633752853, 0.2353359930566512, 0.09170122895739041, 0.20319608564022928, 0.21907264308538288, 0.12384950037812814, 0.09372364074806683, 0.10191252047661692, 0.09154254294116981, 0.3006900963373482, 0.1854514831211418, 0.12105170011636801, 0.12341340698185377, 0.2122776725445874, 0.10568189594778232, 0.1522249379195273, 0.13988190883537754, 0.1385735024814494, 0.23096888442523777, 0.19557250721845776, 0.11118092821561731, 0.09929780804668553, 0.16967616946203634, 0.07105226119165309, 0.17646535125095397, 0.1672157272696495, 0.24303823913214728, 0.1057507746736519, 0.1304727082606405, 0.10917269886704162, 0.10019195498898625, 0.16494705603690818, 0.2311316374107264, 0.15811263292562217, 0.15008185291662812, 0.19006437622010708, 0.15880127175478265, 0.1657324709231034, 0.22202046849997714, 0.13000704027945176, 0.1645457322592847, 0.07167647418100387, 0.12987887137569487, 0.24014996364712715, 0.11676892172545195, 0.10818658498465084, 0.1251379429595545, 0.19293625024147332, 0.1587039019796066, 0.1931088589481078, 0.1452630286803469, 0.07819699851097539, 0.2101329993456602, 0.25613766512833536, 0.12480522331316024, 0.0863132813537959, 0.070385092694778, 0.16800961748231202, 0.10710972870583646, 0.11032975162379444, 0.14520724886097014, 0.19890479481546208, 0.09839375343290158, 0.11757220752770081, 0.15624026855221018, 0.18025024503003806, 0.10442140264785849, 0.12042825896060094, 0.30544114764779806, 0.1890631893184036, 0.10851643251953647, 0.14751186972716823, 0.16861958865774795, 0.16267670755041763, 0.16456652723718435, 0.05209822513279505, 0.16741922416258603, 0.17225075396709144, 0.16453736083349213, 0.09291815818869509, 0.1932340592611581, 0.12336515996139497, 0.19702627061633393, 0.1650167437037453, 0.09596962452633306, 0.17599607643205673, 0.11689699415001087, 0.2539580367738381, 0.09252594798454084, 0.16477662924444303, 0.13244691013824195, 0.16627949313260615, 0.12001083057839423, 0.14806996478000656, 0.19148113613482565, 0.2150002116104588, 0.13985419704113156, 0.16266732680378482, 0.2537893020780757, 0.16207248059799895, 0.14567043806891888, 0.15614294330589473, 0.12061020388500765, 0.1622142011183314, 0.11050104672904126, 0.10540170551394112, 0.13957991410279647, 0.14988522831117734, 0.15107070532394573, 0.12154479045420885, 0.13634909293614328, 0.1678828289732337, 0.18657447129953653, 0.1680466506513767, 0.07678449110244401, 0.12132866962929256, 0.14678808278404176, 0.17639224970480427, 0.14262484211940318], [0.0196266778948484, 0.006438443724618992, 0.013747172488365322, 0.03723020556208212, 0.011248288901697379, 0.02114580409397604, 0.023999046497920062, 0.027356346326996572, 0.0292356720456155, 0.018129740055883303, 0.011258062986598816, 0.03519517726090271, 0.02473700289556291, 0.033404586429242045, 0.026636509464879055, 0.06966699060285464, 0.06395137737854384, 0.021630821720464155, 0.039451653938158415, 0.04238862544298172, 0.04057170692249201, 0.053169819584582, 0.01041333751345519, 0.013399312101682881, 0.013495700386556564, 0.030106779013294727, 0.03705382303451188, 0.017585105706530157, 0.04422824626090005, 0.030591099020966794, 0.0273165690668975, 0.037850166045245714, 0.049530152973602526, 0.01956172698555747, 0.024597362244094256, 0.00748638175537053, 0.040527493474655785, 0.044556769062182866, 0.04707310981757473, 0.025184061523759738, 0.02779485541395843, 0.03288076746684965, 0.01777786743332399, 0.027225437042943668, 0.008630984521005303, 0.017382122750859708, 0.014767102329642512, 0.03630800172686577, 0.026887975072895642, 0.023942531952343415, 0.04163729739957489, 0.024047386286838446, 0.03661131006083451, 0.030484929229714908, 0.02452109914884204, 0.0705175957409665, 0.07505328321713023, 0.055833884835010394, 0.04029860028822441, 0.039358069116133265, 0.08418345110840164, 0.06267969249165617, 0.0941646694263909, 0.038192340653040446, 0.024145626230165362, 0.010037425799964694, 0.06489401625003666, 0.03687408228870481, 0.029651716322405264, 0.023646457702852786, 0.021947908026049845, 0.0344132801546948, 0.09367997277877294, 0.04281720088329166, 0.06059754152374808, 0.018091129823005758, 0.045847330475226045, 0.028719291258312296, 0.08379333376069553, 0.019323621891089715, 0.10895314931985922, 0.010958500643027946, 0.07533736992627382, 0.0828933238517493, 0.0451572221936658, 0.011387714330339804, 0.019133637651975732, 0.007948659513203893, 0.013687038117495831, 0.0861151576100383, 0.029671132760995533, 0.0786652640090324, 0.03289781459898222, 0.04974002491508145, 0.03543842729413882, 0.01780529535608366, 0.059966085173073225, 0.019425663485890254, 0.04150167362240609, 0.08165557737811469, 0.015081600395205896, 0.013173634270060575, 0.0175689844036242, 0.03369527083123103, 0.038017483238945715, 0.01982555306312861, 0.08895935694454238, 0.029089372474118136, 0.04163829558819998, 0.019746156249311753, 0.04392667826323304, 0.02252089798275847, 0.018629511578183156, 0.07010901375906542, 0.08133246854413301, 0.05456996281282045, 0.05998402659315616, 0.026665937475627288, 0.03271870096796192, 0.010052312354673631, 0.0475279721285915, 0.0275220196635928, 0.047877998658805154, 0.03024976118467748, 0.12174071001936682, 0.07396515371510759, 0.03689333359943703, 0.05373295382014476, 0.007893235924711917, 0.041131141551886685, 0.04324993977206759, 0.025170895823976025, 0.06729057437041774, 0.014493530925392406, 0.03324103934573941, 0.027158554694324266, 0.03343017568113282, 0.035017136033275165, 0.0769221966038458, 0.015811836601642426, 0.008687683675816515, 0.017430970910936594, 0.0463374076934997, 0.01198853946334566, 0.04730664142698515, 0.05789513321360573, 0.11751840182114393, 0.03190984534739982, 0.0662385206669569, 0.035944917108281516, 0.04412273883644957, 0.05355002183932811, 0.04865702736424282, 0.03508014066028409, 0.05347941019863356, 0.10046375173260458, 0.037084069263073616, 0.06320708489511162, 0.03135029197437689, 0.05240097685600631, 0.09631633365643211, 0.05053277222032193, 0.03579826501663774, 0.06458786549046636, 0.04389113310026005, 0.018720595362538006, 0.07958105197758414, 0.026480736378289293, 0.03765686255064793, 0.016256726303254254, 0.11977637870586477, 0.01306799975282047, 0.05769680908997543, 0.09062959739821963, 0.02793307856336469, 0.0639662129106, 0.01268377598535153, 0.10592034057481214, 0.03435531471041031, 0.0581236516154604, 0.0535881348332623, 0.04631707284715958, 0.07263941079145297, 0.05448980715300422, 0.03628305814345367, 0.04387024906463921, 0.031108171860978473, 0.0036272799343350925, 0.015129493967833696, 0.014167278168315534, 0.042452435300219804, 0.04786285884620156, 0.006555686823048745, 0.07609345513628796, 0.023203319469757844, 0.0289056408291799, 0.06721496436512098, 0.027332365680194926, 0.025740141645655967, 0.042623630215530284, 0.06040665371983778, 0.01622803116333671, 0.04544466712104622, 0.01866597329353681, 0.0076434229868027614, 0.03758021724934224, 0.0485847941308748, 0.046458529905066825, 0.013193459817557596, 0.0306996993458597, 0.062467052339343354, 0.02114557588356547, 0.033880028495332226, 0.015711236628703773, 0.035284958576085046, 0.030816279613645747, 0.05321519449353218, 0.11963476208620705, 0.0610275381768588, 0.04907385089609306, 0.033448606918682344, 0.028831431627622806, 0.03185676694556605, 0.010687484082154697, 0.02591515120002441, 0.02779367354378337, 0.03263628917920869, 0.053565473353955895, 0.0674423658347223, 0.04327532122260891, 0.053858643950661644, 0.01705867995042354, 0.04607303984812461, 0.058154120488325134, 0.1307043177075684, 0.03809303016168997, 0.07148586097173393, 0.061224585806485265, 0.054219498415477574, 0.037593716915580444, 0.037753998549305834, 0.02180539526307257, 0.02722409561101813, 0.05184459987503942, 0.06753611392923631, 0.012903217921120813, 0.030747844321012963, 0.0740108774334658, 0.03372532039065845, 0.04143969686992932, 0.06666793473414145, 0.052198218400008045, 0.014697455480927601, 0.04595807746227365, 0.09679780938313343, 0.0211243671583361, 0.04566520743537694, 0.0201546565949684, 0.0748076917079743, 0.05742595858464483, 0.06216694637259934, 0.010112440231750952, 0.043212487289565615, 0.051757275068666786, 0.020257909745851066, 0.04114073752134573, 0.03198500635335222, 0.057392899616388604, 0.04787418030900881, 0.01702754685538821, 0.04023570698336698, 0.041647138277767226, 0.056042803116724826, 0.01800786270905519, 0.043790152776637115, 0.0356883455242496, 0.05224268046731595, 0.01855283473560121, 0.048754805320641026, 0.07868075263104402, 0.05473640427226201, 0.056470228228135966, 0.06651973526459187, 0.017117200150096323, 0.02093553324812092, 0.012922369969601277, 0.11216057057026774, 0.03264164006395731, 0.03819461533566937, 0.05130905869009439, 0.08098377787973732, 0.06331356082228012, 0.023084859712980688, 0.012897242704639211, 0.06273971739574336, 0.009277403496525949, 0.08664729233714752, 0.002777115214485093, 0.02249540892080404, 0.011750236772058997, 0.05049452192906756, 0.058915159534080885, 0.018729807270574383, 0.030914128074073233, 0.030807807997916825, 0.04364396081655286, 0.029809853149345145, 0.02982570542371832, 0.0425579167495016, 0.060526692395797, 0.05998525855829939, 0.0423886736825807, 0.08713741408428177, 0.027877669817826245, 0.021918240672675893, 0.04054022501804866, 0.04034925557789393, 0.12313720930251293, 0.039453316348954104, 0.006804915319662541, 0.0829331623390317, 0.06879239183035679, 0.034469141610316, 0.06796603265684098, 0.05583245991147123, 0.0635872945713345, 0.030072040935920086, 0.06684879612294026, 0.03955793319619261, 0.009280144804506563, 0.061885360701126046, 0.021333092481654603, 0.022013896086718887, 0.03418227184738498, 0.041613340872572735, 0.04019203159259632, 0.028090185660403222, 0.030595392345276196, 0.04461217780772131, 0.0015793318857504346, 0.036172537511447445, 0.05472675264172722, 0.0051039253685303265, 0.01857792303781025, 0.05201449974265415, 0.017207033415616024, 0.017636159900575876, 0.044199847980053164, 0.08124908825266175, 0.03471629162959289, 0.05912248590902891, 0.03580620228603948, 0.07932437278213911, 0.13547727721743286, 0.26161308225709945, 0.13719031732762232, 0.08988392452010885, 0.11797215091064572, 0.12493639049353078, 0.14524728030664846, 0.253441501990892, 0.18135242338757962, 0.11958106770180166, 0.08247113830293529, 0.11292207345832139, 0.14046722586499527, 0.1350031784386374, 0.1268768691807054, 0.2060189630719833, 0.14815216505667195, 0.13371975277550519, 0.11448677309090272, 0.1166691844991874, 0.11386891288566403, 0.05952467799943406, 0.19368479523109272, 0.11174132392625324, 0.09396179593750276, 0.1955414260737598, 0.07369218437816016, 0.22661002847598866, 0.09746811716468073, 0.11470727258711122, 0.12444810185115784, 0.12258004935574718, 0.11972505177254789, 0.12072336656274274, 0.10534041153732687, 0.12862490897532552, 0.1502426466322504, 0.10099141130922362, 0.09427945740753785, 0.2261191126308404, 0.19421581673668697, 0.14646909286966547, 0.09868315391940996, 0.21034972131019458, 0.10352795332437381, 0.11428854544647038, 0.17305199144175276, 0.1346397487213835, 0.110891557415016, 0.0697751808911562, 0.12317927423282526, 0.1918074139393866, 0.20347275829408318, 0.12253393229912035, 0.19674121169373393, 0.20181480038445443, 0.09871701069641858, 0.24421150039415807, 0.18761619430733845, 0.239022953028325, 0.17096480500185862, 0.24073982262052596, 0.13057228963589296, 0.11730565034667961, 0.09570674839778803, 0.16565174009883776, 0.20180654770229012, 0.17763467913027853, 0.07132476297556423, 0.0805541560112033, 0.16227493848418817, 0.1583676942391321, 0.08633577584987506, 0.13886402361094952, 0.1648739248048514, 0.12035224077408202, 0.12528281018603593, 0.232165107736364, 0.08958615260780789, 0.20074153610039502, 0.16493087721755728, 0.20842263096710667, 0.14368581643793732, 0.1469530473696068, 0.14682569482829422, 0.11309206980513409, 0.0934496546688024, 0.11297848410322331, 0.2044868140364997, 0.10507346101803705, 0.18847214290872216, 0.09487002142122947, 0.16707016242435202, 0.10934154488495551, 0.10134513373486698, 0.12968834722414613, 0.1387451315531507, 0.13823067478369921, 0.21020644227974117, 0.062230388866737485, 0.09862776001682505, 0.12602711009094492, 0.13145976467058063, 0.17317156627541408, 0.13445004093227908, 0.16121858032420278, 0.1026468830241356, 0.14371907949680462, 0.25999908917583525, 0.18391764198895544, 0.10975569297443144, 0.17430728970794007, 0.19563475856557488, 0.13071617722744122, 0.20751591946464032, 0.09487432587775402, 0.10297332410118543, 0.19044968445086852, 0.1286644209176302, 0.22362062794854864, 0.23587859206600115, 0.12548385799163952, 0.12514661124441773, 0.23039214662276208, 0.1574030506890267, 0.07448019678122364, 0.12698730075499043, 0.17218897759448737, 0.11267858964856714, 0.08824985634419136, 0.13323661463800818, 0.16424410860054195, 0.18189949012594298, 0.13127836893545464, 0.10669046721886843, 0.30027024855371565, 0.09664725730544887, 0.10903788032010198, 0.14497388794552535, 0.11522549946676008, 0.20851036766543984, 0.1072880593710579, 0.1985765725839883, 0.26008345652371645, 0.1894189600716345, 0.16652521822834387, 0.1272776586120017, 0.14363373251399025, 0.1498829128104262, 0.10569877980742604, 0.2269469783641398, 0.1905145333148539, 0.08379478094866499, 0.21693484217394143, 0.13858340273145586, 0.12158916346379556, 0.14445189095567912, 0.1964445158955641, 0.12649680051254109, 0.2114437657292001, 0.13107163627864793, 0.10153887880733237, 0.19070128735620528, 0.11590506182983518, 0.16541877994313836, 0.10149568581255153, 0.15743478492368013, 0.25513920933008194, 0.10545775992795825, 0.2164302411256358, 0.10231216700049117, 0.1552697768784128, 0.14214553346391767, 0.11172028403962031, 0.17073019727831706], [0.028477527375798672, 0.014654578826593934, 0.023595021302753594, 0.06085947512474377, 0.045015705763944425, 0.026132700659218244, 0.006798940567023237, 0.032904761101235636, 0.03712502839334775, 0.08397098165005445, 0.025665349858172704, 0.06129397661425173, 0.031046369513205718, 0.03125773131614551, 0.04066171088197734, 0.06605241971556097, 0.008986043740151217, 0.0639567208418157, 0.028106360769015737, 0.08521447976818308, 0.01512531474872958, 0.003995332535851048, 0.032724797711125575, 0.0756741788063664, 0.027872090722667053, 0.026754741011245642, 0.029751110305369366, 0.06492546104709618, 0.052522625992423855, 0.06369923270540312, 0.02767660716926912, 0.04620869702193886, 0.0580506168626016, 0.07380685361567885, 0.07778442377457395, 0.029730602909694426, 0.0310894419089891, 0.009364031611767132, 0.017009605435305275, 0.013655520961037837, 0.06413491049897857, 0.011037287040380761, 0.025719435725477524, 0.07030947526800446, 0.018558708834461868, 0.08786089674686082, 0.06354652839945629, 0.03215968936274294, 0.07184084504842758, 0.06645660076173954, 0.02095686628308613, 0.01962539583473699, 0.07383278425550088, 0.053488575722440146, 0.06445787832490169, 0.01806791729904944, 0.08859746347297914, 0.047036941250553355, 0.008043959624046693, 0.08169586857547984, 0.0334893619583454, 0.0658545111946296, 0.0032825245079948218, 0.037419367872644216, 0.09859745812718756, 0.03213463816791773, 0.034076456431648694, 0.005052749647802557, 0.0298441014092532, 0.016728151495044585, 0.014745044773007976, 0.06092142590205185, 0.05508932517841458, 0.09635792361223139, 0.03913836371793877, 0.03960725633078255, 0.032999997201841325, 0.04913642136671115, 0.02085329957481008, 0.017346959793940187, 0.09237446822226048, 0.015512708414462395, 0.07428342374623753, 0.028434803789423313, 0.02607689115393441, 0.0330299465713324, 0.06207890168298036, 0.043382246149121784, 0.023256509193743113, 0.027287773737043608, 0.03424080503464211, 0.03812591472524218, 0.055542402624269016, 0.1172281033359468, 0.02656273813045118, 0.03321484895423055, 0.10177160147577524, 0.061823710493627004, 0.04560467416013125, 0.08911048047593795, 0.023987439308257308, 0.02694840259209741, 0.09803259468753822, 0.03119748376775533, 0.04277473519323394, 0.12818503804737702, 0.040390782451140694, 0.06949132424779236, 0.055275337072089314, 0.0395998088788474, 0.0726149941328913, 0.03983052774856333, 0.058705302435555495, 0.013540627223846968, 0.02682860696950229, 0.0511096695845481, 0.01587389127962524, 0.027707150256901514, 0.03736071223102044, 0.028378107417665888, 0.04039738385472447, 0.02956404827273218, 0.08848151774145663, 0.01622923529794207, 0.044980476013734005, 0.022919479524716735, 0.04790700179000851, 0.07117998480680399, 0.05090803177154157, 0.043779146726592444, 0.050316666238359176, 0.045958541304571554, 0.014627717719122302, 0.024351570355065633, 0.03150763099256437, 0.0762334316095803, 0.018494475953048095, 0.03472859643807169, 0.011826220634247875, 0.09429123529116623, 0.06911639124155045, 0.03625440382165834, 0.024509536488039885, 0.0207796840913943, 0.04678440323914401, 0.014646561776316958, 0.04924943932564929, 0.07695045758737251, 0.07936122041428462, 0.05769242299720645, 0.03476452751783654, 0.025083587715926114, 0.05786319117760286, 0.049643319362076, 0.0726965264766477, 0.08676134559209459, 0.029412169606075622, 0.07452508187270723, 0.07333844710956328, 0.028200262859172653, 0.018955063933390193, 0.04736173104902264, 0.07978671594173647, 0.06179843294376042, 0.025276232554460876, 0.0635745222098194, 0.02054491123999469, 0.021025381356594153, 0.03913615953933913, 0.0287581760858302, 0.04806091950740665, 0.033644452269072644, 0.058262062157155015, 0.043907631043111905, 0.025303547299699858, 0.019076124917773996, 0.04008527364931069, 0.02655044630955672, 0.00445716129434004, 0.021081625018268824, 0.07907914492534474, 0.07005006496910937, 0.1148469744657632, 0.032751741382526234, 0.058687134660431184, 0.02627155277878046, 0.018910026701632887, 0.04956784665409941, 0.002666885875441949, 0.018128892152162734, 0.027515587098605465, 0.032753155173850246, 0.030742497147002723, 0.013603798834083136, 0.029411520226858556, 0.016507989676028956, 0.02817181077261921, 0.03920513845514506, 0.047168178934953175, 0.044773899207939394, 0.0011014173082912748, 0.038664899475406855, 0.042406544598634355, 0.022599406074732542, 0.04079678918060381, 0.03584441546991002, 0.01927358258399181, 0.024437987885903567, 0.02793232157273451, 0.018202759965788573, 0.051385403421591036, 0.024832255694491323, 0.04303051267925184, 0.13772119040368125, 0.07746467686956748, 0.01798223820514977, 0.044330970631563105, 0.027240890412940644, 0.015340754653152544, 0.013108619350532535, 0.06168173764308449, 0.0772027655330021, 0.04239294103172142, 0.038843070578877814, 0.024561086065659765, 0.03849551911116578, 0.10335118116927333, 0.04737204319098964, 0.09529382485197857, 0.08857384091243148, 0.045582194507005624, 0.027078658786194865, 0.03154746947984677, 0.10005013056797907, 0.0032509894936083583, 0.03311175350972917, 0.022129778735688888, 0.10776591341709718, 0.022498045400425326, 0.058899964060401544, 0.032232842859230004, 0.04924989945720881, 0.030767494536121376, 0.03346468183735851, 0.049763636343413964, 0.04130645167606417, 0.05539344245335087, 0.07534714401117526, 0.06932879390660673, 0.03679074281535577, 0.01948172717675334, 0.08162528290995397, 0.022728393196302932, 0.04194620894850232, 0.014655879440397257, 0.05516392215213273, 0.04381798702524975, 0.04482191245188005, 0.027896475839952473, 0.042078726837644354, 0.01938668774528196, 0.022955640670261346, 0.005230999604464159, 0.040427125422866084, 0.07475632024579681, 0.0359585763362702, 0.0064403241412946954, 0.046664965702802874, 0.0419308093842119, 0.03714955266332254, 0.03764567838516086, 0.05982730355754029, 0.03143978385196533, 0.03768377653614152, 0.023254215957422275, 0.09112438725423999, 0.057278360254713334, 0.014562264004780445, 0.026746250841824804, 0.050683854933595285, 0.06607577510294504, 0.020926165489072446, 0.0787000781565439, 0.019363269275345374, 0.05676923581631854, 0.048008342055254616, 0.024301707308040932, 0.03377613524207845, 0.035529255037545227, 0.06707150721922517, 0.03627254562161397, 0.06182049328344874, 0.025180491793435067, 0.03711675715749152, 0.04231811028148513, 0.011367193947080523, 0.042871485275099985, 0.02033149554335978, 0.04944405271089636, 0.01919164391438244, 0.03376356326043606, 0.06607757110032253, 0.02353725994908018, 0.04033475401229225, 0.004012266026620637, 0.057281172994407825, 0.030186556177795865, 0.044909485877724364, 0.0216319182436564, 0.0037171774420130532, 0.020793347030121367, 0.06009948621795047, 0.025918093815562315, 0.018949501536553726, 0.020111858793825377, 0.08668375405250117, 0.03310907064587809, 0.04374664065835532, 0.035395824306760915, 0.04183128367003519, 0.03465659327048343, 0.04295704005926382, 0.08606443923781626, 0.03403897055250127, 0.027592280639510136, 0.03000626809807727, 0.009212757795467041, 0.0483022139815148, 0.036277736944612116, 0.021941870654700324, 0.06107348825025838, 0.031027222103148233, 0.008340175809280481, 0.010372148317401297, 0.03842564590740949, 0.03243564584408887, 0.06550899692228995, 0.048561976800556295, 0.0460175346233882, 0.04576793922751676, 0.05630627667414956, 0.05805896973470226, 0.04331500385887921, 0.058797614474315196, 0.04414601258758921, 0.0767251341312658, 0.055493984909844585, 0.008062135748332366, 0.03179525403538719, 0.03682861090055667, 0.039963735835044645, 0.06507226527901366, 0.08002291186130606, 0.10877258479013108, 0.10681024243240245, 0.135960252082441, 0.1995334235834889, 0.06577534630196169, 0.14973114361055195, 0.16043451614677906, 0.09320256402133964, 0.13911394926253706, 0.14449031936237589, 0.14509191911201924, 0.09649187384638935, 0.11936572613194585, 0.1257449307013303, 0.23172839835751802, 0.1243689443799667, 0.09464607835980132, 0.12424620799720287, 0.20709466160042211, 0.08857440494466573, 0.15606914414092898, 0.142718723800499, 0.18827470194082707, 0.13637748750625178, 0.12481199169997126, 0.11419306072639301, 0.13387775601586327, 0.2715912280837074, 0.1353517800453119, 0.14692926895804703, 0.1229536984465085, 0.15748234174679965, 0.14535597525537014, 0.18255577131640166, 0.08825313663692214, 0.13209020427893847, 0.24613850167952478, 0.12931014876812696, 0.06285472059971653, 0.14318758301669732, 0.18154498102376238, 0.17723348893923685, 0.09407660618308, 0.1596258720383048, 0.18348174897255376, 0.17951664689462632, 0.10295261818100698, 0.162082870665472, 0.12868935707956553, 0.29913488135207444, 0.09685444267233834, 0.19003311695996672, 0.17068831046344712, 0.21758511196821928, 0.16822305915411562, 0.11769400880439207, 0.1974452575086616, 0.09392103718710132, 0.23274625389603898, 0.0795827218098566, 0.23374494718154892, 0.09286416694521904, 0.132541133207269, 0.2091201310395263, 0.15530387114267796, 0.1030598436773289, 0.16521056299097836, 0.14318657369585708, 0.1898710467503406, 0.1616749566164799, 0.2498715341789648, 0.14708522387081757, 0.13211833167588338, 0.11360483447788283, 0.1072531784302555, 0.13140679016942158, 0.08650569056044333, 0.13652735680807382, 0.13332280766917393, 0.23121273930883035, 0.2712802682071924, 0.1959057166823186, 0.17205697920871899, 0.16397456056438386, 0.1581871000234969, 0.16364966315450147, 0.1857152720913291, 0.19360755250090733, 0.1057556208979804, 0.2063165939762257, 0.21575651946477592, 0.13004787324462086, 0.16645827650791034, 0.2917572803562507, 0.25599965534638613, 0.2570063341408968, 0.11533138167578727, 0.17538491782033816, 0.2233248672564514, 0.10081273925607093, 0.14634723222116008, 0.1631509547587484, 0.1310590939829126, 0.194688594492618, 0.21142972429515794, 0.21523717936361209, 0.21224221272859722, 0.14887037104927003, 0.12184728984721005, 0.12360655833617784, 0.15194747858913615, 0.11164755356730893, 0.09375857363920659, 0.13240791769931093, 0.1606693910434842, 0.15621451602783054, 0.10398294180049561, 0.14272583357524127, 0.17400073818862438, 0.14586200122721493, 0.18079112225677818, 0.19938894227379933, 0.11456099528004415, 0.16706216207239777, 0.1505835002171807, 0.1878667582059279, 0.09820812003454193, 0.12609816330950707, 0.14738601632416248, 0.19367652770597488, 0.10435921809403226, 0.11029285946278833, 0.09301552054239437, 0.1565688767004758, 0.17661499790847301, 0.10753887559985742, 0.1339854861726053, 0.1246604896732606, 0.16227701649768278, 0.2220441578538157, 0.18640880909515545, 0.12157724457210861, 0.08379915219848044, 0.13597272016340867, 0.06788898288505152, 0.18162068008678034, 0.17633324896451086, 0.11807932445663027, 0.15775050938827917, 0.11309653011267073, 0.11337191885104403, 0.15031850896775723, 0.12203325721202418, 0.1877416469505988, 0.17999570321990177, 0.10598851426038891, 0.12389845986035652, 0.13150637154467404, 0.07991809834493324, 0.16620137466816232, 0.11971613857895136, 0.19932017487008125, 0.15366788080427796, 0.13683830184163526, 0.15316658973461017, 0.14389099058462307, 0.2326628364971839, 0.15332496404880658, 0.12050022502080537, 0.15146104531595483, 0.13241078238934278, 0.16820670221932232, 0.10547993530053645, 0.09455974432057701, 0.10782472862047143], [0.03802289349550847, 0.015966492755978834, 0.011394988305255538, 0.09151671620202251, 0.008674451182741905, 0.024063179189397488, 0.02070955299132038, 0.008991614486149047, 0.02980743931402685, 0.08724727420485578, 0.07573217022581957, 0.07656201749341562, 0.03819645586190745, 0.036192356565152295, 0.002647045484991395, 0.05379549831559416, 0.05139414963196032, 0.03445785725489259, 0.04074959229910746, 0.04860490262217354, 0.010324762188247405, 0.03410247983993031, 0.01631822993658716, 0.027623666064755525, 0.03143294125038665, 0.03048481605219422, 0.008370852483494673, 0.031771620342624374, 0.035310158200445585, 0.01881182015495142, 0.0414273512433283, 0.09991082944907248, 0.04368304602394346, 0.03224626088922378, 0.01572638200741494, 0.015583064014208503, 0.038245530377025716, 0.052553313798853196, 0.034822014276869595, 0.029331921177799813, 0.005716222249247949, 0.00045203516322089854, 0.050036071334034204, 0.015502807236771332, 0.03140711080050096, 0.06833839041064493, 0.010233296197839081, 0.03238922079617623, 0.0729199500347022, 0.012736261596728582, 0.053048905174364336, 0.031900345857138745, 0.01761215698934393, 0.05614616944512818, 0.0405729054909898, 0.03032455853826832, 0.10065861002658494, 0.060762250068364665, 0.021696713301935233, 0.006903177991262055, 0.08225594516261481, 0.07773757199174725, 0.026599455886753276, 0.053924413077766076, 0.03763129927392583, 0.0653608790889848, 0.049015269469236955, 0.02204265616455814, 0.03812467533862218, 0.06738182884873822, 0.09424214222235605, 0.015819055843167007, 0.06027143441315275, 0.0553012343152659, 0.05716140520235058, 0.070784175186418, 0.011061238928959938, 0.09648070452385582, 0.031004076372482814, 0.03713594538567122, 0.04354113625595346, 0.025137272823485546, 0.0866630110249389, 0.037827834821655415, 0.030011895432835445, 0.01754814489686396, 0.04254902582033537, 0.05892937166208867, 0.0423843135649804, 0.08834252090309747, 0.0573088217061013, 0.019396558309381362, 0.02821569210937014, 0.05760867534263525, 0.0483325121604139, 0.030684544690302573, 0.06256183944060467, 0.024650711529830005, 0.0045827006761101075, 0.08005764437257312, 0.04433264046383556, 0.011805092617578339, 0.019408028201723937, 0.023328154275077395, 0.02070615581033053, 0.024659459595568478, 0.07051666805637069, 0.008236633220803924, 0.030014882577233948, 0.02286072925926419, 0.03409668737731408, 0.007806113353581168, 0.022297745308605954, 0.024933586682891473, 0.07307894033147022, 0.014154356449580519, 0.02832447054970544, 0.04276043029676657, 0.037621347073582, 0.04226730656228028, 0.04577729770971928, 0.015113846711756196, 0.06797337249736302, 0.04096975411812309, 0.02917637444625143, 0.02630516464705579, 0.012445236734492937, 0.035564310383051634, 0.005915415613344521, 0.019540959838195704, 0.024725084003875963, 0.04908221490040887, 0.019309257622808218, 0.038516963468282484, 0.08766345577896573, 0.023089410933607724, 0.06348843307932839, 0.016125766924233176, 0.025135870164376684, 0.011197757921763696, 0.044510280931717716, 0.01849927950388519, 0.024215516132244375, 0.026113916901522316, 0.019516125721565913, 0.05941873270785436, 0.08105747314402834, 0.023068365480867215, 0.022528801855514757, 0.04298472958907951, 0.018319445989618544, 0.03314139488793444, 0.05560983787290752, 0.034952045971294865, 0.04072437412105501, 0.050859421098721214, 0.055895086043165065, 0.07518157828599215, 0.024143897026078776, 0.029622052679769695, 0.018436846330587287, 0.01926607576024253, 0.04271776051609777, 0.02423559493763605, 0.0102604921994498, 0.023680848826188594, 0.0633019907400012, 0.035934278421336785, 0.013706913759961026, 0.0363588759500999, 0.030484372618957423, 0.033839533207356, 0.0458403023367282, 0.056314592438866384, 0.010120573242602404, 0.03752964359591715, 0.021812434533785563, 0.04333812918048352, 0.04177675065875519, 0.019062443425355013, 0.048938690961222164, 0.06627188762649894, 0.08348573581315577, 0.0434146000770852, 0.012425584664015332, 0.054965401359368116, 0.017874684308480937, 0.027730607689591125, 0.05694361083442345, 0.031871264800429344, 0.0413109156943392, 0.022172693425090984, 0.03102192873484455, 0.028420784619811457, 0.04308720905100927, 0.09729303710628301, 0.04609656592947431, 0.07364067190792412, 0.026901532255578786, 0.035695811529876664, 0.056365396158071235, 0.03501479826809373, 0.017556755665282253, 0.04178403854893986, 0.03305016638478264, 0.03852301939332392, 0.023962349150679074, 0.05847021231602412, 0.047621401099604554, 0.03698941945913248, 0.08588947050157003, 0.07369707513134927, 0.01666079231654294, 0.07281095822690986, 0.05935633664194029, 0.05125400988617912, 0.02875014419259969, 0.04539820867648814, 0.02273719135700958, 0.022182894244906493, 0.043219441213295795, 0.018762044310278725, 0.0435463721078122, 0.08355957950698212, 0.04423277707246598, 0.09699377347715199, 0.027313786013110075, 0.05154515813046601, 0.015743646217742935, 0.030174952698871493, 0.04024476118502207, 0.03875382732076105, 0.024536157325201202, 0.061262398230610415, 0.03553362257662229, 0.04948320100083947, 0.026859116660489235, 0.03595415684685577, 0.03849485488899518, 0.05691834070603363, 0.05170460855879355, 0.023979136531124823, 0.027599236418609507, 0.039888363317004405, 0.02616286710690474, 0.006924389499545214, 0.04864267793891486, 0.032820620108395815, 0.05238112811639439, 0.024525902699679136, 0.03450740303378552, 0.03062137864617398, 0.024379933383897878, 0.02747328282566741, 0.01846451730671106, 0.03260546407545917, 0.00421886231379176, 0.006338850289466791, 0.06082829750084784, 0.03776147939788643, 0.03713658363267314, 0.05041455180617049, 0.07643184479093179, 0.03590156826248858, 0.03251695554354228, 0.04632224932720419, 0.08730482775717974, 0.03132392346742563, 0.04768210506881587, 0.0660424972011242, 0.05688305158400908, 0.05304202546540182, 0.07351145657594316, 0.005717703297705157, 0.027356082864571363, 0.08890572193195112, 0.01622802188649075, 0.03585070888220798, 0.10047947042039596, 0.022614928093389608, 0.05712961530662142, 0.06521410454297438, 0.028889064960821997, 0.08149551096721552, 0.07203798173577525, 0.016442509986518417, 0.00480120193969924, 0.06088461166655179, 0.024809354872559197, 0.014036752018000698, 0.046310961261042394, 0.0108453945540532, 0.024250990791188087, 0.02431958379020216, 0.01696981147688348, 0.01437868542780052, 0.020287219012971036, 0.026533410309639294, 0.022498251346405596, 0.028484028589446098, 0.045935534726595506, 0.049456283304607496, 0.045474772341549397, 0.03475540281215217, 0.06495408568298444, 0.03707648822455667, 0.022591281413042452, 0.04589133241097443, 0.03229447080229875, 0.014435045977734262, 0.05637548565573525, 0.05589221022091806, 0.06619954307097942, 0.040735435832175426, 0.025040645195986144, 0.013339771448954707, 0.015526737788604805, 0.04854282196902204, 0.0388163161551347, 0.06111038783274125, 0.07010637171333656, 0.004245002610332449, 0.0736141178640537, 0.0780790564022027, 0.039634370696148835, 0.03469948940619361, 0.015247705105139175, 0.02340022794669494, 0.07441459834808484, 0.01879572111647576, 0.07831657334463671, 0.05124004266690463, 0.041132956102956086, 0.10305897536454722, 0.020875983318546787, 0.0306842070131097, 0.04062721214722842, 0.0392371324414853, 0.04501526047533844, 0.01673209229920758, 0.01816497908293968, 0.040555943705840036, 0.03438010986428708, 0.023523778836533893, 0.04245784926752094, 0.07437281543388963, 0.06621629334404133, 0.007188436829892453, 0.05504818422195967, 0.0316435367858503, 0.03471543073828798, 0.052068828663323075, 0.17894347140099853, 0.07850573936593719, 0.15737110865302384, 0.13065444538369775, 0.22442271147156134, 0.11253355172812007, 0.13014870142797008, 0.09260591439669952, 0.0973712743143551, 0.2750114008085802, 0.28385358571540564, 0.15738639689516276, 0.15822486049728468, 0.06648558162851259, 0.17624687781790271, 0.13275852310471237, 0.12818837771192193, 0.16732308635255322, 0.10758882213849574, 0.2247456050827168, 0.12231126573169604, 0.17575098958332092, 0.08432734612142667, 0.1482332669547759, 0.11810010459157638, 0.0946442229906097, 0.11108936945674941, 0.1711379925836809, 0.0819386621878948, 0.1835997504531406, 0.1745022222166881, 0.20739950618008152, 0.11850857525132596, 0.14991528529208153, 0.16197269142139703, 0.10463989092386328, 0.16637500753859058, 0.11871012771734968, 0.3364322253037244, 0.14536177885020152, 0.14481110527412966, 0.15981062228092924, 0.14009769569383934, 0.16306078381603584, 0.08656817939481698, 0.0804292896646075, 0.09829521848587319, 0.20031879394082353, 0.20818949269596487, 0.1560301220160909, 0.10782863973872736, 0.13868803071090952, 0.11245580433751456, 0.10230160623905249, 0.11312696558889002, 0.1250685373088345, 0.15028428111691028, 0.25516346271615475, 0.14610557409469038, 0.1495778010576032, 0.15770755388075486, 0.2103278279537335, 0.10761648198240437, 0.13726816861890256, 0.2119134264648892, 0.13574922981206328, 0.1558053700136952, 0.15210263198241591, 0.16862142918398604, 0.24819407262839377, 0.2053687526495196, 0.12286683748243377, 0.15660162025596946, 0.15556440950604156, 0.1512178880511783, 0.1490551806637086, 0.11099892391939647, 0.24265634478069842, 0.08947465234086849, 0.1315823377808556, 0.13463286159094423, 0.1474296991364099, 0.10690027236705646, 0.12617919099284336, 0.1179123115434777, 0.1588056207401678, 0.17321392806479707, 0.13141940667992458, 0.1379428550717421, 0.21520642476389185, 0.20493838121183217, 0.18568410188890994, 0.1250429925858043, 0.17687685729470104, 0.24941006675362587, 0.1276796800084412, 0.23191766085801646, 0.12580485170474276, 0.22080536495195702, 0.17005843488732353, 0.1248797052539885, 0.0857393340265844, 0.18442920438246801, 0.1332391082542017, 0.2052198481396772, 0.11632167384959757, 0.1447777680004947, 0.16554292640648782, 0.12529520405223593, 0.14650189579697326, 0.11606633794144727, 0.07605006176163442, 0.1313935502548702, 0.10919974272837862, 0.13768589386017993, 0.08014992301468737, 0.1264690887182951, 0.07016028132056817, 0.09917905699694529, 0.19357169192517176, 0.10746290936367586, 0.15509755408857018, 0.1626828673761338, 0.12496481474954635, 0.12166115178843029, 0.21395937917986885, 0.1777495487476699, 0.12122692860430107, 0.15656155912438408, 0.0778630468994379, 0.1385173961170949, 0.14717273792484775, 0.12159161997260526, 0.11593445829930715, 0.15893858391791582, 0.10498720861505717, 0.16222683247178793, 0.14415365149034187, 0.057763476215768605, 0.12783676298568025, 0.09114427681197412, 0.2017437620088458, 0.14800823293626308, 0.15017962345154956, 0.14353376522194594, 0.1304654055275023, 0.24247036257293075, 0.13747476768912748, 0.10374985547969118, 0.04765476434840821, 0.20252215617801994, 0.0684799105511047, 0.15390239947009832, 0.12997897225432098, 0.12668720592046157, 0.16773716022726148, 0.13079506752546877, 0.19847102434141561, 0.10560664217337035, 0.16822515201056376, 0.12401192681863904, 0.1319188720663078, 0.1395118294749409, 0.13150355138350278, 0.07514589582569897, 0.19495389744406566, 0.19962745369412005, 0.15053462237119675, 0.1123702792392578, 0.1653713863925077, 0.1336657689535059, 0.06727386120473966, 0.11364736696123146, 0.21750924963271245, 0.10820450042956509, 0.11094377492554486], [0.019467205202090554, 0.13764304225333035, 0.07648042577784508, 0.008881409266905393, 0.05125455907545984, 0.017217260210600216, 0.0557742606906686, 0.0023508283720730105, 0.035532353504095227, 0.03667159842734691, 0.018927365126728546, 0.03151688557409216, 0.030292119263322093, 0.07080730050802231, 0.04393690876895562, 0.051048108434770256, 0.023013810205156915, 0.02325103028852027, 0.023985298212210182, 0.07305186678422615, 0.04106300497369375, 0.0564831675728783, 0.04526988021098077, 0.02992298799654236, 0.06679097539745271, 0.02467554008035222, 0.02612004889670061, 0.038038860802771524, 0.024062661541393027, 0.025709496512718033, 0.07125958014512435, 0.019268821706646122, 0.03841112949885428, 0.0716937068500556, 0.04629215894965455, 0.0378526485292241, 0.08227671787608415, 0.048427733418066055, 0.05580855533480644, 0.062446294468827546, 0.05963582945696544, 0.030525546972057782, 0.020221358972776216, 0.0069941365381964715, 0.014395167600014247, 0.07129670237191021, 0.010274265532643767, 0.05227493049460463, 0.023633316122868564, 0.09784050460439175, 0.03972702041210141, 0.05411453646956943, 0.028897762931592297, 0.03354448126628995, 0.0429640162474243, 0.0076515467208082555, 0.170484991685953, 0.04770520070451312, 0.0772705087729264, 0.09685468758107163, 0.056629867904121056, 0.008015971379791154, 0.01299660421864246, 0.027219672410865314, 0.04562328722386155, 0.007401866441796301, 0.01470813220294076, 0.04302936606109142, 0.0482141062093433, 0.017910086608026177, 0.037332299107220024, 0.05309984248015098, 0.08442486432613805, 0.0817246490623802, 0.07356092071859166, 0.058768017624970526, 0.016606324243184645, 0.07782864835462533, 0.06188692292198539, 0.0059398879329819465, 0.058004559177788906, 0.04182221833616495, 0.008688613215781515, 0.10117101104697213, 0.0645517154771369, 0.06407663706340827, 0.0464227917836979, 0.09439040848519653, 0.08933317672926933, 0.006827552679169457, 0.03061038558371365, 0.0446255698625464, 0.044815006767748855, 0.06986892898567021, 0.03178989943990018, 0.05692425933375489, 0.07277116426848806, 0.04063625150592998, 0.059945817120024, 0.09115944631048478, 0.0702847469074186, 0.011028074204659788, 0.09429295707377605, 0.053329407310229726, 0.01901627441839082, 0.018231393878522795, 0.024701561633264646, 0.08184028309187852, 0.036725474637933075, 0.020287330335122533, 0.031416962810908444, 0.07124382434994914, 0.02203560019552242, 0.028482982161222026, 0.020393772865645587, 0.07440772606059909, 0.0895610531733837, 0.032208181291935034, 0.026122466442757286, 0.021406147643574513, 0.08850548911141232, 0.04173041837930214, 0.03131066128844395, 0.07981075410498306, 0.07296134703210555, 0.10098588973050937, 0.02610549909149995, 0.009833505882852478, 0.018819573742803186, 0.07230711416923441, 0.06919901454239152, 0.06741930730640888, 0.05266149666567799, 0.03472459255135618, 0.06395024189259857, 0.08085249195573851, 0.033174268319271505, 0.035975040882476605, 0.03826582440524362, 0.018837518873624504, 0.055623545340495184, 0.02774578460957855, 0.036464390796027146, 0.038588907264056616, 0.021781141876999754, 0.034646986168809235, 0.018648516124812886, 0.05813267984194681, 0.02152358694729628, 0.038335864592227153, 0.03131396013486665, 0.05062996759079397, 0.05572780966758728, 0.08715688803931698, 0.022914271503395867, 0.04339442850323394, 0.026705213786044624, 0.02845810722647002, 0.033379694796167314, 0.10518746974412352, 0.01067552993845311, 0.010161397858610144, 0.04725049053377006, 0.02608321239677025, 0.044047989722457714, 0.04676635791838635, 0.03011315220646793, 0.01531798834548681, 0.06941407409613021, 0.019783326715696603, 0.06683266183244996, 0.0864618296327535, 0.05366964120185003, 0.03042091899260413, 0.02263648191728862, 0.011722546314558713, 0.01794783223886043, 0.042669728718465194, 0.0403237442515092, 0.030175910069374368, 0.05000417753763031, 0.04073191434144974, 0.030377286275324877, 0.03824222039838787, 0.0835675056441687, 0.033524209502502345, 0.019906896159227472, 0.037881929965806194, 0.017898700207297225, 0.08477529903757386, 0.03302935656392947, 0.02829804267094005, 0.08661609244882129, 0.05475332152855117, 0.02975903273181757, 0.046309332246892154, 0.01716631177259842, 0.038718044670531526, 0.06683804982458241, 0.023371202551061288, 0.03529053210513666, 0.00757553363655461, 0.0645985449955333, 0.042442026679054834, 0.017662140635366086, 0.05159221029316541, 0.011331563437124714, 0.013785133342025802, 0.0485494938766351, 0.04236341097566765, 0.01769685830367962, 0.051377907730056904, 0.04958631870977115, 0.04048125025292393, 0.03851418412523344, 0.057990283967228606, 0.03268867738370318, 0.01795684376702411, 0.02493761283403728, 0.01495825174060883, 0.012885082614957355, 0.10611858306219801, 0.026523838459979743, 0.052051306556677446, 0.022017682895238977, 0.06626471847994253, 0.050499980425229296, 0.037220847079879604, 0.042950998977175914, 0.035872505759471096, 0.03804101674177218, 0.03993259902927093, 0.0774766031827312, 0.11220925545785576, 0.04056145786307752, 0.08743482234422117, 0.027709987116395496, 0.05350453189748805, 0.020602281110768672, 0.030494874008581974, 0.09808501257793978, 0.014440376453421777, 0.04666824599553365, 0.04235218228131998, 0.04368993315438274, 0.07200344218290411, 0.05265073923510499, 0.028271332776057534, 0.04564253853459377, 0.05493295466294512, 0.049279752347501926, 0.018851063068723306, 0.03778520585910883, 0.07575911018648185, 0.05443381211080123, 0.005444373091449961, 0.10053306090412661, 0.01868658644525567, 0.04366169072454795, 0.040008491050684825, 0.10165398591198027, 0.06298221414908767, 0.04500533425016329, 0.04404347375384532, 0.0586549736908637, 0.005457684437715216, 0.048256675800075755, 0.10584913892671466, 0.012266910707694478, 0.05805263550428208, 0.04324553883634508, 0.043014838520321064, 0.03463976507191546, 0.059325633992557414, 0.003581268865673337, 0.058147912423009984, 0.006519358694276889, 0.10120962499058805, 0.02674806168215582, 0.08097088677459396, 0.039290478016482666, 0.006330657442958909, 0.02088435288897017, 0.10273576262989081, 0.02307273116457509, 0.08527857906301506, 0.01914056745590642, 0.031309136174968444, 0.044378479215083644, 0.02839183343894547, 0.03687001903017517, 0.041772542681428604, 0.06750896616722457, 0.016317469235218596, 0.012356217976048356, 0.019948306144215167, 0.04039352097606752, 0.02358518042456126, 0.027658743674692232, 0.014283857508416986, 0.017030574817908928, 0.07683770309085958, 0.04918063110380899, 0.05214455370150972, 0.024951741470431443, 0.03353987623995636, 0.035367871314520016, 0.025885240793286357, 0.0432731541513931, 0.012690008170466172, 0.07199878149549477, 0.02175558045564685, 0.02536333657189971, 0.03367112876730971, 0.0019155215363753086, 0.03592648958147038, 0.023020363369141705, 0.03458533225057181, 0.014596990949939936, 0.06011021767335478, 0.013878204226784874, 0.00947312917560339, 0.010828356698766584, 0.0627490461920388, 0.03792472220084164, 0.04675190088164527, 0.042354571996838786, 0.014494586630462436, 0.06074825687392149, 0.005615388499791152, 0.0691860492224805, 0.03616616246290505, 0.028122548865212593, 0.02420091437670635, 0.039201587278512307, 0.06514696986414492, 0.06548417950398289, 0.018342296716582496, 0.04415440998855047, 0.055915250195539556, 0.054098086766316555, 0.021527550015889574, 0.0418025106046116, 0.02536476335080806, 0.024353744847758207, 0.07414904306642711, 0.028666676698776428, 0.014436660148930969, 0.01837430925661465, 0.004338999324318138, 0.032124582066899166, 0.03426749637583271, 0.07326614708290435, 0.20446389651624486, 0.13609024666948244, 0.1300046654068865, 0.26146278250962496, 0.1837592528318055, 0.14683112734928727, 0.12159100399003364, 0.18660350411664695, 0.15236557490425184, 0.2690255345078185, 0.14122905529802665, 0.10000306356232613, 0.22340632538544014, 0.09729576820973307, 0.1615714715444483, 0.16699021827662364, 0.14564970246283337, 0.13396360765909776, 0.125914481759537, 0.12954126839758828, 0.0975684481090866, 0.12100583538995124, 0.07355040448601358, 0.1658379746368155, 0.10096632671775296, 0.11205997245269828, 0.1933927898062393, 0.09935552487149835, 0.18746576097328216, 0.13320658734301105, 0.055319910461548716, 0.09207837356370874, 0.08617795072495937, 0.09278754761908203, 0.168012764188461, 0.2277281481656246, 0.18399417225737125, 0.1601222055614926, 0.1385767085594125, 0.1998859882587567, 0.15964441088726744, 0.10616278537781909, 0.11681781441438943, 0.08778451490798034, 0.1705132526694797, 0.08787674902123399, 0.1519941448350437, 0.13337875076103956, 0.3330220270436257, 0.09972501793527044, 0.27383782784454525, 0.11333698595990427, 0.09891082256217487, 0.10077979532070458, 0.114987158740405, 0.21778102411190048, 0.21841024659806862, 0.2744499809341505, 0.23978197714313865, 0.12869465601397678, 0.14764852880034596, 0.11071693748817779, 0.12811331689590588, 0.12250149302417412, 0.12673795397859067, 0.12055421626428142, 0.14459165220614523, 0.12995175027754158, 0.12755863572238013, 0.10768019536044449, 0.16638738656183705, 0.09806644404307008, 0.14434424985665828, 0.13344811188289896, 0.22227417910471559, 0.1645369452307932, 0.22471655742265284, 0.22167970397276804, 0.12754309515003115, 0.1695251275668852, 0.1091140988864936, 0.16710767056792974, 0.1476150579401292, 0.16728029411751777, 0.16161684645339847, 0.16708288283552974, 0.2621606091270223, 0.15568616625387222, 0.07280745528987609, 0.14106572343735024, 0.29693607590161264, 0.1366188784595579, 0.13188905257266015, 0.143506528402213, 0.1902659732149914, 0.11440850619692355, 0.167676096316427, 0.2599040645873174, 0.16415794525528327, 0.16368258482543752, 0.15916146570816636, 0.1311497250571847, 0.17378401622409, 0.14612740807933733, 0.15722613752586767, 0.09427158322068863, 0.29647538030985743, 0.09857769473455846, 0.20428714662557468, 0.15769651072332636, 0.20280721510061994, 0.06168670632177964, 0.22695186169585213, 0.19009355746675283, 0.14504621765809134, 0.22451533150160685, 0.11761333735194057, 0.07231825380586088, 0.09799427760299295, 0.1336856881971471, 0.13707639765925705, 0.09825869739870541, 0.20064032200025395, 0.2481053859810345, 0.2759456163039431, 0.14007072604727, 0.14050088968360797, 0.05480129024363123, 0.11769498843932524, 0.13616564887342975, 0.16063835442764685, 0.11698199974489398, 0.13844214234268293, 0.1906061588670127, 0.19213464169297367, 0.14717824466060847, 0.09789220261154696, 0.14859896764392033, 0.11552331590792164, 0.13993054919410497, 0.11150250080390833, 0.1295117606059648, 0.11927226005354896, 0.12143133833887987, 0.1192124058434274, 0.10910454744589515, 0.16150840383488685, 0.09354297231766395, 0.0932013988494873, 0.1178132274071686, 0.10747606764198281, 0.18383420974714682, 0.11894929964910261, 0.10574719752185047, 0.15667151572415605, 0.10178283759159967, 0.12750714551657438, 0.12451418268028647, 0.164403447706718, 0.18251741712447256, 0.15238890802720562, 0.14663128182291985, 0.12808278494048864, 0.14408387476578355, 0.11867381443153135, 0.16429252631496638, 0.13457010558340698, 0.1436426828149706, 0.14873868436552584, 0.15399962081573904, 0.2188278827816248, 0.12872560357209295, 0.07514904253184795, 0.11229083975194953, 0.14701814856380224], [0.04360145430837292, 0.0075082157400174765, 0.028176532687211875, 0.0439982843818143, 0.08986652857856825, 0.01956989803147735, 0.008959999922808493, 0.06789764374843799, 0.03756827980396338, 0.02502829400327755, 0.005144175747773261, 0.051687342493096367, 0.037116567909833975, 0.03156345534080174, 0.024584114908066113, 0.019650643698696513, 0.016954406346485484, 0.06461656434112228, 0.016578874055994675, 0.016295815221383236, 0.0405108693666989, 0.021658015866705682, 0.02071347709716065, 0.028589419125637505, 0.037859932708670385, 0.036813619517488405, 0.05565631487115752, 0.03268923028372228, 0.04101004160474986, 0.07718288339674473, 0.008167055020749103, 0.03948425277485512, 0.023687021639489103, 0.052943486807635054, 0.08194376816391014, 0.04814855601580348, 0.09632236731704324, 0.025169114669552073, 0.09279896927182563, 0.061967650035512634, 0.07046586062642746, 0.026004424144048244, 0.08631457269075327, 0.01814636416384019, 0.03353387597599067, 0.06567750155227259, 0.09526482914225198, 0.0534258642437635, 0.03355126078531612, 0.02719025553233223, 0.010648852512531448, 0.00421519517658453, 0.03721265005879104, 0.012562641713884659, 0.0022748563378627296, 0.031158803030848503, 0.05116885215102229, 0.006435900013457285, 0.047576096694683656, 0.0745275458029937, 0.03448500130616594, 0.07965346332639456, 0.06697908756905235, 0.04777143367391545, 0.03307212653453462, 0.03725455913809128, 0.0666836608434096, 0.14263374789152294, 0.06900342152221128, 0.042230184335494414, 0.04487556230742484, 0.06078835140215233, 0.010586654043436283, 0.05432118006865494, 0.008939567669585813, 0.035933384133386426, 0.09232626573066227, 0.029727179753535893, 0.012269272592675406, 0.02766756781056756, 0.04906318994471803, 0.07100566173903644, 0.033790540328482166, 0.008176889405149268, 0.04372813520603813, 0.021722181954828557, 0.038374196519725956, 0.019429231360845733, 0.050592748884810135, 0.05878574382222723, 0.033497117401566356, 0.06683241692371666, 0.10974795979564078, 0.02365673459280515, 0.03509733251121361, 0.010879328328883275, 0.08133438328513876, 0.06474615074694157, 0.1657198098837398, 0.11012042887159623, 0.03458897990640253, 0.0330627903167624, 0.05188980409002397, 0.09217999584507197, 0.08090450166491792, 0.020856299706792925, 0.10597974949632771, 0.04044841763970908, 0.014752108163520461, 0.022848808512208052, 0.033026265518856235, 0.044210393898538314, 0.047065929538803175, 0.040292529520229436, 0.06644593609962612, 0.05179110958124511, 0.017694544658297673, 0.01724426881992258, 0.028031845431542024, 0.021989733613736462, 0.048880417525651865, 0.025953013719117735, 0.024134425366355572, 0.024040248681558296, 0.05552325521421153, 0.029183343212935142, 0.02304739238752518, 0.053055168900755234, 0.03925608689314686, 0.05453350480820518, 0.024097234490909614, 0.05267327454930637, 0.06766991573385894, 0.048199686279986054, 0.06748611544026062, 0.024454472841171082, 0.03518903969961684, 0.04653561678424012, 0.039103753661038354, 0.03255137264204677, 0.005950493223281228, 0.013291664508869871, 0.027154482158948667, 0.012738103050651262, 0.10580921138171107, 0.02624811946589034, 0.05522043298697099, 0.038537828950211406, 0.029823430741089396, 0.028578116216522176, 0.021386710795923136, 0.013420692448562477, 0.00667196698486805, 0.08284008959890343, 0.02596751528471941, 0.04829526005778462, 0.052513868649839424, 0.08526027027983218, 0.015951252753438894, 0.023473587389162276, 0.018390426848782226, 0.015920559380901977, 0.016175201380974613, 0.023386064058286138, 0.032716545028961264, 0.06311997160082683, 0.04792978201294318, 0.030918139382265508, 0.0640185565862339, 0.0010145900887437165, 0.04543966133496724, 0.09733588871313259, 0.06138767275842838, 0.01266549317733734, 0.03504263251670636, 0.037416714694700204, 0.020208529094816186, 0.026667182428354863, 0.03230514288588893, 0.08397978352149948, 0.08653744705952704, 0.016299013877869584, 0.010072892109747045, 0.00781415545134223, 0.04650939670682419, 0.03514404328598175, 0.03340326169563923, 0.06665312888799235, 0.02613706634292612, 0.0928138048038818, 0.013625879582832567, 0.01869156625616597, 0.04907183596515097, 0.020937481385772116, 0.030955109468777664, 0.02337293917662464, 0.007311616645893082, 0.049418767739553005, 0.034432746688253246, 0.05475338832184207, 0.05702669426682405, 0.002024971736318548, 0.021269852222758345, 0.03916829082299955, 0.03954634456022177, 0.027440956728241872, 0.02387318752880674, 0.010327455256629037, 0.04770153449499048, 0.08975954799097963, 0.012150171805842547, 0.03751190255570691, 0.07616094604600221, 0.022967780350882094, 0.05170784432266373, 0.039678161119809374, 0.06465269951149821, 0.04263842864020262, 0.13480728113790974, 0.04887979412160348, 0.07208139737485908, 0.04622333588486072, 0.07258109282702208, 0.03270385801442899, 0.007580256942674168, 0.0012867221903434256, 0.01889500934339594, 0.01736772508593276, 0.029450631409417838, 0.03730935190105811, 0.050936815969180316, 0.04182415905233938, 0.01908916630782187, 0.029268326543387957, 0.031602147209923714, 0.04908628929115366, 0.039829447923693806, 0.05839318851940334, 0.016571482265135273, 0.012683961522270693, 0.05220273436862044, 0.045095289970049635, 0.08837234039674513, 0.09026216008351184, 0.006541062339238124, 0.03695040104503278, 0.014518698080792092, 0.08036635554162785, 0.04936621255183127, 0.02227421366114868, 0.039421886394848116, 0.06835883657913655, 0.1902577353757806, 0.03711166231369134, 0.044687179251923226, 0.006606692777495482, 0.03537256910931319, 0.0223669635670376, 0.04273870392353274, 0.043988662437186576, 0.046565276716137305, 0.08871084137354046, 0.04592502962623257, 0.024125642048602458, 0.01854850987001555, 0.05723108544771094, 0.10066329297842458, 0.08772863860940561, 0.0999284406134393, 0.014896921584295342, 0.08162186160916463, 0.01221685006385087, 0.10366375892772339, 0.07330683161853813, 0.12606913049239665, 0.12462397600756958, 0.0397695380524965, 0.06751118518877774, 0.04795940112671815, 0.03763308413908817, 0.03176291866111569, 0.03723872170667164, 0.09051011904375628, 0.04158707626629621, 0.04197402835416142, 0.017089462380681653, 0.031034613894007634, 0.020481119936448522, 0.010865341628232272, 0.10657380902557634, 0.0393060297210468, 0.02126834380760556, 0.01939096808200702, 0.03650731290690601, 0.03890793799655512, 0.020659827241615858, 0.027642256864055526, 0.04065149892994668, 0.06016989005729556, 0.015829230687813833, 0.10011318343458697, 0.03565867446013726, 0.0147973151615588, 0.028353570160106756, 0.04855406179558486, 0.1020047471683938, 0.029271476960275322, 0.01817615582694998, 0.05786668669315986, 0.053334810145315714, 0.02113374419423053, 0.02388071661698632, 0.08116880271700211, 0.018922140407084953, 0.0374974529404426, 0.06334378849714994, 0.04052944903378375, 0.00753215278564312, 0.04542941227555275, 0.02433332279906608, 0.03308422725240234, 0.024770388408796862, 0.03405444062082097, 0.02929230347945122, 0.0422109107603319, 0.04792288746102713, 0.020448701070563402, 0.023665608823648654, 0.038815347652416676, 0.020210890979797114, 0.026833442061615642, 0.09479478991124779, 0.050762923347065225, 0.030919068922230508, 0.06783220858778805, 0.03286004670371767, 0.04509931612119544, 0.007418320319629856, 0.02890869105613092, 0.02581415046734037, 0.017436006382922642, 0.00833841877465602, 0.02636622670252109, 0.056126621275325306, 0.034033987030852586, 0.01120864801123389, 0.03659235189843457, 0.034431781896273606, 0.026021860903711058, 0.0037188843816693407, 0.06968942572711967, 0.055351284754578955, 0.16461510822409764, 0.12858616886660457, 0.10792534158099443, 0.36091264919377863, 0.16671356046572328, 0.08266091288533062, 0.1660294784232974, 0.14920564368367195, 0.09461700843530707, 0.11229205687413923, 0.08352970064152032, 0.13301180326379836, 0.13575038756243885, 0.22248106019105762, 0.083263878186699, 0.05764190500485711, 0.1531069804332219, 0.17483264120528474, 0.14511915593175218, 0.14624803676269948, 0.1177088962867856, 0.13978583039715886, 0.10422537176054902, 0.22428096126532182, 0.12271911298739724, 0.0835478090448305, 0.17448840342694893, 0.21668864210369065, 0.17971906025195494, 0.20125726936385036, 0.15465202799532562, 0.08509010323905386, 0.15190038189757615, 0.13810489559546113, 0.1223724483861588, 0.1584618430933915, 0.2607165975496173, 0.16347436787327752, 0.1513852275093086, 0.12299404901568778, 0.13678271498065442, 0.1832362762070261, 0.2705942268949002, 0.07663905984372832, 0.10390228519099765, 0.15910687332507223, 0.18236888368846849, 0.2636957267532125, 0.1058437509345822, 0.12799630989320576, 0.1275798017741181, 0.14768142078537494, 0.10912910511251539, 0.10976211255183443, 0.11448686214862391, 0.1642359746620059, 0.1453140439116396, 0.22148226300487295, 0.1676822709850967, 0.1653859918587841, 0.15880755032412708, 0.11930296270293184, 0.17113342095399275, 0.15498626162298024, 0.187890239758417, 0.21053417469374835, 0.19518754037562758, 0.19852822908433154, 0.14595285494579002, 0.20739532046718523, 0.1208165506250225, 0.13898787321522832, 0.09506154005066492, 0.1450575131457299, 0.14868743164697662, 0.1349485118407756, 0.28831190429627895, 0.2228918537730351, 0.114357327693142, 0.09789238072698936, 0.08537315836292692, 0.182828139513731, 0.1772423947113566, 0.0708226852293592, 0.1325339640607126, 0.17369320703437552, 0.20728787232656032, 0.10073042023577727, 0.11891142785316333, 0.10813269764184952, 0.191661567077972, 0.1626665549702011, 0.22844831342808902, 0.3647745482157916, 0.13713389926124364, 0.10254751687170938, 0.20472680975217372, 0.16548137267818674, 0.4166865017032251, 0.2958905085688457, 0.09363771489006467, 0.1860351228970103, 0.12941306980792433, 0.2039074045023881, 0.1372408278984949, 0.17154120141640306, 0.2368413208751008, 0.20541077305097133, 0.08357084530871361, 0.1288938187644817, 0.09598096454283223, 0.09907769446726888, 0.12126615853048861, 0.16940325207542628, 0.11726927768904716, 0.19883532979292795, 0.11958105285884812, 0.10931929529760964, 0.1466982829151675, 0.11914990958757699, 0.14760962541913614, 0.1548033964354545, 0.11969287224928848, 0.1179310136649292, 0.1519093767274171, 0.0990186640410684, 0.12165033127530478, 0.15433618478709832, 0.21579805004876107, 0.16005796525860205, 0.15835798694752157, 0.12436604258255102, 0.11309276000247337, 0.11899818491656333, 0.20159978535957634, 0.07560026831924915, 0.11402146876207553, 0.12631280726054683, 0.11202596724615432, 0.1609742356231436, 0.1287666443386115, 0.09281821316108108, 0.1321800338337198, 0.15538745181402192, 0.2128005601116456, 0.07339032323216088, 0.10931038210401312, 0.11437548804678954, 0.19115632778266445, 0.22118255408713594, 0.0986236559401732, 0.1641788738197647, 0.1033015018037986, 0.14092657074797899, 0.10169277054956183, 0.1508509405539371, 0.17637388897128403, 0.16689991374732926, 0.1592185813933611, 0.0988294163835235, 0.11068218271248043, 0.08334112833836116, 0.10152320464840159, 0.10429165296955034, 0.20187997579341754, 0.12481849291361868, 0.12255022986209951, 0.19173495064023882, 0.13373159745242447, 0.10193632857408375, 0.10703115753130987, 0.15155737608438358, 0.162456942780409, 0.0914837203163188, 0.18817048956407234, 0.19477872090646997], [0.04472854285268113, 0.05011711757106241, 0.021141996876394842, 0.0343159660405945, 0.07659155497094616, 0.04670026966778096, 0.06783430886571296, 0.06835630585555919, 0.009423940555279842, 0.0767040200298652, 0.0035503456592778093, 0.030378132323676255, 0.023624586610822007, 0.04376550976303406, 0.0747000877163373, 0.025648035552876536, 0.024991643040266354, 0.05166197588550858, 0.03418487307499163, 0.02196399222157197, 0.037755824232590385, 0.0426062973565422, 0.056608761224197224, 0.05089140024210792, 0.02398240569164045, 0.019716607639566064, 0.016797798343759496, 0.04255110754456837, 0.010529085648158798, 0.047975969573599286, 0.028551228206197266, 0.03676765089039691, 0.03996362451289315, 0.03118738684861455, 0.07574224859126844, 0.06839359135483392, 0.03792514522501733, 0.06334078279905953, 0.03680282497953158, 0.05800022503535729, 0.0083191906560387, 0.0766904758347664, 0.01992054054426262, 0.0630962302966509, 0.014492939990304876, 0.03563255457265768, 0.051895121578127146, 0.07494248799048364, 0.05112388542329427, 0.0722370034782216, 0.06338121500448324, 0.009004918410937535, 0.028664162673521787, 0.04809237172594294, 0.024766022725088987, 0.06468079722253606, 0.024477499828208238, 0.020364083247841336, 0.03866416103846859, 0.061455534741980955, 0.005586159477388719, 0.05224914457357954, 0.043977530222036876, 0.04287432770070154, 0.04920978637528606, 0.08314889724715613, 0.05195540994463954, 0.01732722608721815, 0.03638982350821607, 0.015840767373447306, 0.13855787285137922, 0.05216555648075882, 0.0320415134774521, 0.07760499473079108, 0.16149477800354362, 0.05110924284963403, 0.07931658765301108, 0.05813571151520591, 0.11295984135358594, 0.06733265414368361, 0.15636815543984994, 0.18788629153277725, 0.24419658322585747, 0.13661470758961514, 0.03252394286391791, 0.049434812972322106, 0.059168335792492144, 0.057181665833923034, 0.06454257221776061, 0.06041046835889574, 0.029260042319947388, 0.03852758731227368, 0.04295860599086154, 0.0733947241678834, 0.01396007981384173, 0.03363664487551432, 0.06667231340543367, 0.016749033675296232, 0.09519774641375989, 0.03950622776756063, 0.03767621405131649, 0.03394590152311139, 0.06429256492992863, 0.07558288722066209, 0.07265938198543154, 0.05980231915600598, 0.03574111593479756, 0.0785063553485088, 0.0567584449891001, 0.07922632023110054, 0.07605498962220736, 0.08622242021374404, 0.03714425372891128, 0.013738380821450846, 0.024361342584597878, 0.053289420393412, 0.02588100869616028, 0.053775285923620686, 0.016945146198850125, 0.06515605375170708, 0.018651349273568485, 0.035347636658116244, 0.05097835397464223, 0.04788359074154869, 0.030346743187692482, 0.05713119979191106, 0.020744305911648553, 0.018351445542066358, 0.024907296101446263, 0.03499474172713235, 0.04172684493823908, 0.058070257800864056, 0.010005172989622224, 0.04755445937917102, 0.03752107179025188, 0.01865106725745136, 0.03676338725199457, 0.032086791907204315, 0.1113423379138112, 0.03108419492491521, 0.05835428513819352, 0.08345127789652906, 0.10341312081436627, 0.051910439506173134, 0.08668456299346872, 0.031578220368828624, 0.03168135663145222, 0.011710873259289656, 0.04458914525457658, 0.07215979043394327, 0.029032347702013794, 0.014224006081349216, 0.010403522610431537, 0.04369753645732999, 0.04712587280664593, 0.03022914988832781, 0.04495457877055742, 0.03502539242617786, 0.04891664175374899, 0.02901009254856035, 0.018537639261921868, 0.060866781568620354, 0.007998960427357815, 0.09592997157596983, 0.05025960621424019, 0.036426886363187805, 0.027692613439285196, 0.010831614727067063, 0.0640009602648206, 0.03674251805932727, 0.029709924820053857, 0.07878308737417683, 0.03215509175788611, 0.0169919831387233, 0.014759471196157392, 0.01759402446623426, 0.011193708578502992, 0.022492226962640416, 0.02128943564457586, 0.08674748227349482, 0.02021942382270936, 0.019341153274581302, 0.07022521924227476, 0.034803479138645343, 0.017816639083321206, 0.027219618605158757, 0.028232397853571456, 0.0532058508542832, 0.03774787954171188, 0.04738480813102797, 0.06776857684599236, 0.014178111669025384, 0.06769134153728373, 0.038787160883657634, 0.036006185109727085, 0.0688240592717193, 0.05169468975509517, 0.038636081881122664, 0.09772444755071774, 0.05739070657000411, 0.07006442552665249, 0.02353943815251114, 0.022634754568571225, 0.08855594773194753, 0.02298622643138515, 0.0626675361127127, 0.046431630762526765, 0.02707678300794214, 0.0795056571951136, 0.026130761798413005, 0.12561552983243018, 0.018268219246238004, 0.03646474331617355, 0.01784877407772001, 0.011748434280889342, 0.0534561846870929, 0.019221671209379565, 0.08827885205391794, 0.06710750138154253, 0.04415813185914885, 0.027978130638075527, 0.008722760358068626, 0.052232795060263015, 0.06240008835447952, 0.028582038466993254, 0.017725271427480038, 0.021901328982494306, 0.03816340060438961, 0.022894654684932902, 0.09984245538362302, 0.02219697278633248, 0.031753938674228266, 0.04406928565003909, 0.05953088606474921, 0.04528507197392173, 0.023658803329453804, 0.042368331414763816, 0.05332169639586937, 0.007251664565046667, 0.023629596107639372, 0.013720573915634304, 0.10048834650660865, 0.09345595550257713, 0.018906623954535462, 0.017897624093166087, 0.0717296490620356, 0.11589919886318967, 0.02544871880672872, 0.03719139494933188, 0.05671047627402004, 0.12592562881764024, 0.026962418050970882, 0.06608358991798013, 0.023614591736986768, 0.08808149272226728, 0.10803929835674353, 0.09756659273989499, 0.21038458740804344, 0.18654626968782395, 0.14493911090539768, 0.03437426916207187, 0.07567399326944724, 0.06190090127347503, 0.08126899265334941, 0.04274759485269897, 0.06996431722654961, 0.03517398894473445, 0.0628163070359733, 0.01435090962331742, 0.016554143840039615, 0.030699272610945627, 0.07797255821060389, 0.045361631928244606, 0.034164430617238395, 0.08110149734420702, 0.08177459560101852, 0.022171676682773978, 0.05850344939972274, 0.09499572639469989, 0.1286506318137981, 0.033687107206787914, 0.05090116319479421, 0.018563673802418634, 0.08145634783431888, 0.02214759027992841, 0.1525559654692188, 0.04296874743886292, 0.05813904004753567, 0.0202656930196099, 0.028497461462393403, 0.017496981236035936, 0.048554243621765636, 0.026824228298210073, 0.027050015596614685, 0.03019317242433317, 0.038838205800857395, 0.022054664113966282, 0.013819721134495921, 0.03806384149356745, 0.007092611185726128, 0.009582899310771609, 0.0822425345540978, 0.02343459866096964, 0.0831200870743487, 0.007490317921110545, 0.02871354703529505, 0.03557294527126942, 0.028970977655262686, 0.08418714700383134, 0.03242983111704234, 0.020589430823747534, 0.025839097761490848, 0.05678346278727986, 0.07650836763787083, 0.04449098138138652, 0.05579163807851728, 0.032294318662025034, 0.05008694926800672, 0.015198944147414295, 0.024707990487513598, 0.04612458942574449, 0.02361479953833623, 0.05916533380514011, 0.02311589447344886, 0.07691587350564077, 0.03796033786784392, 0.050312591847614385, 0.01712988901999779, 0.016750907598179765, 0.07620163800311275, 0.053818916785530746, 0.009950562980520772, 0.01758081609295914, 0.04780961346114054, 0.07169331351178698, 0.06731480549206026, 0.04587171002640389, 0.053285865506040864, 0.03873680987453554, 0.075190639909124, 0.07897850227891468, 0.10371672600740567, 0.0549393111577956, 0.07598866388434544, 0.030362066681846045, 0.012576272183650872, 0.015235748178383801, 0.05103183684695978, 0.054148326453287154, 0.017986179009312764, 0.06613905803533271, 0.004560022034638678, 0.10524713099584915, 0.14913812308805063, 0.1698546708212234, 0.1549866030109115, 0.13899176206905395, 0.12657880783081055, 0.16094365913886577, 0.246145359124057, 0.10242827600450255, 0.12488199106883258, 0.10400456056231633, 0.13518832944100723, 0.10165004510781728, 0.15496101375902072, 0.19773313659243286, 0.11037606906029396, 0.1410275770467706, 0.10479577904334292, 0.09620932338293642, 0.19954204733949155, 0.15421781223267317, 0.11296933342237025, 0.14973249431932345, 0.11830155315692537, 0.2201449722633697, 0.13214151636930183, 0.12080578206223436, 0.13512330246157944, 0.1417333891731687, 0.13492406549630687, 0.11215389124117792, 0.10710046670283191, 0.14024161297129467, 0.08916610444430262, 0.2498983108671382, 0.21499578841030598, 0.10583916446194053, 0.15421212738147005, 0.13617232820251957, 0.16522576217539608, 0.12724280735710636, 0.21406831161584705, 0.1407141235540621, 0.1421361675602384, 0.09980553353670985, 0.08785895974142477, 0.1656883576652035, 0.1540256553562358, 0.13369851250899956, 0.2127438600291498, 0.13354095455724746, 0.13668865518411621, 0.14842862990917638, 0.20164081128314137, 0.09672260013758205, 0.11908113476238213, 0.10327258773031645, 0.22193198965396732, 0.1603312388760969, 0.10893195358221419, 0.28046591905876994, 0.12206665385747328, 0.14422844513319433, 0.10816777896252461, 0.15014474251074716, 0.23002398200333118, 0.2268877104506828, 0.11631984816631302, 0.07513221804401837, 0.19595932943047956, 0.17784723022487015, 0.30512813944369555, 0.1151507132453844, 0.1781806326471269, 0.5243636691011488, 0.1627125235972926, 0.30173578241374344, 0.19446056219749153, 0.2961361297639087, 0.2303295538877137, 0.3319447848480195, 0.5669719108846039, 0.49184902163688093, 0.27669162314850837, 0.16392633580835536, 0.17129612941062078, 0.12266289530089125, 0.18833189184078947, 0.2915722184116021, 0.13241297914646566, 0.1453205748111941, 0.1158816841780208, 0.14098086627200246, 0.11144230520585552, 0.07495482990634628, 0.1189078729657922, 0.16957694431766868, 0.2307162425131537, 0.19637236429844052, 0.1431061842595227, 0.12350725155556574, 0.15715432731667534, 0.12385352281853557, 0.1778807010850869, 0.18663804366951808, 0.2188957596081309, 0.19404582038987428, 0.22033626824850217, 0.09902815610985272, 0.17902767547639087, 0.14801219600485638, 0.19215706939576194, 0.10391470132162794, 0.10691870731534436, 0.20233819261193275, 0.15521939989412203, 0.16384898917749524, 0.16318160545779392, 0.09502815824816935, 0.18174804747104645, 0.12328676690231077, 0.06994704745011404, 0.1827302502351813, 0.12933141872053966, 0.09765734997927211, 0.19545414950698614, 0.150815287779551, 0.19947227061493322, 0.08907137671485543, 0.12385061359964311, 0.09348905528895557, 0.3059327759547159, 0.11528612551046535, 0.1841683840029873, 0.14800367614952847, 0.10504073230549693, 0.11532184507814236, 0.19652609276818112, 0.1556883630109951, 0.16906003846088424, 0.17498877423349768, 0.28595139971002936, 0.18127144023310393, 0.05896765163925011, 0.2415225064032711, 0.15365863364422694, 0.21732424705987796, 0.1048235576308798, 0.1734310804749839, 0.11421548100770451, 0.08545864635379985, 0.10215439382591285, 0.0687339848082047, 0.1065850599843543, 0.1099529187195003, 0.16661452827975154, 0.11013041075784713, 0.2657250553602353, 0.19306064903503284, 0.1692458425532095, 0.1087987826031167, 0.1650458507356234, 0.1250505179632455, 0.16683488676790148, 0.22291143162874505, 0.14952099707443267, 0.1020283623074647, 0.1472878598724492, 0.08875257975887507, 0.1338108885101974, 0.11657689843559638, 0.1492108980892226, 0.09184018126688898, 0.13995211600558832, 0.11681941745337099, 0.1092601461277809], [0.005265195914034848, 0.016727131041989196, 0.005364469761843793, 0.038634983502561226, 0.047451582868234254, 0.05011915847717319, 0.026112961386388633, 0.05082134150143247, 0.06589602693566121, 0.031268696548067965, 0.06590424993191846, 0.048911632256931625, 0.04865386581514031, 0.007419939129249542, 0.037946426309645176, 0.06704422587063164, 0.06193067994900048, 0.04251125421433244, 0.017882864631246775, 0.028610663102881517, 0.023284994676942006, 0.029703332693316042, 0.03995266670244746, 0.058885161924990825, 0.011693424439727096, 0.005719150949516916, 0.030514381360262632, 0.02658517139934702, 0.041666129836812615, 0.06540743401274085, 0.05288100539473817, 0.03844833707262296, 0.02192854168242775, 0.01902867941680597, 0.07072993161273189, 0.0605007320700679, 0.03988587712228764, 0.01527388621980208, 0.024538213074265514, 0.028484425638453104, 0.04472067979804706, 0.02696093561098678, 0.009010144985950319, 0.03622052106948104, 0.07780538944643922, 0.07126988857635297, 0.012896799271402415, 0.030267517067841254, 0.008456482410110766, 0.12272341744392179, 0.01813087183109019, 0.06676717472146265, 0.019859884814650286, 0.047624740764149465, 0.05690845900971908, 0.07410397243802436, 0.05831868060340639, 0.05591152832494117, 0.06668153087957762, 0.046253493055701256, 0.025838782348728273, 0.04448018313269131, 0.011908050764759537, 0.022530454989464488, 0.04513472398684826, 0.015318689675041242, 0.1500700379256159, 0.17146351339761168, 0.01788696499716025, 0.31494037073571235, 1.1319356295280159, 1.0985482460819185, 1.0053590778261423, 1.2859842320904136, 5.086145829409361, 4.579991614446044, 10.589267034083605, 7.884037820622325, 9.587935265153646, 9.666854180395603, 10.435489285737276, 9.752375241369009, 13.229530658572912, 25.017787255346775, 39.21974368393421, 42.68315143883228, 30.3155579790473, 15.341018456965685, 9.96119113638997, 3.709433153271675, 0.8856399112846702, 0.9912645653821528, 0.19090821297140792, 0.30950452492106706, 0.23585252783959731, 0.2417179584153928, 0.22133965190732852, 0.19581239903345704, 0.5381924333050847, 0.6348400691058487, 0.1882501516956836, 0.03374997453647666, 0.11785936672822572, 0.060547402026713826, 0.16005802463041618, 0.05524839711142704, 0.02259952852909919, 0.06330066229566, 0.05917015405429993, 0.0587012948381016, 0.05505853347131051, 0.03733802477654535, 0.029423899250105023, 0.052164376465952955, 0.04669591326091904, 0.019553661695681512, 0.013526414168154588, 0.034011908137472346, 0.04131173205678351, 0.053263178051565774, 0.02153501602151664, 0.04279307366232388, 0.024269143723358866, 0.043840533471666276, 0.010801737716974458, 0.05306169608957134, 0.03696956700878218, 0.03049671639018925, 0.04305864749767352, 0.019251384946983308, 0.015799197826709133, 0.047306897467933595, 0.06952267998713069, 0.01587036793353036, 0.05959559763141442, 0.005280700770526892, 0.013069995202386053, 0.028449101264413912, 0.02414190435956698, 0.01989166728890268, 0.03053023734537419, 0.002056592097687826, 0.03001010129082715, 0.0359696640225593, 0.013607307337224483, 0.06312389014055952, 0.07521165753132664, 0.016268567269435152, 0.012521741027740063, 0.0738856771204155, 0.04399391313199885, 0.0420373521046713, 0.00994921319943387, 0.01776184632035438, 0.03978453685704153, 0.015732929605292156, 0.04567662537738215, 0.06294453531154431, 0.015443612610397395, 0.01826074396376498, 0.040306218434125185, 0.015116084287001286, 0.029709735572396312, 0.0051661623365362175, 0.0445963552192552, 0.018918561399914324, 0.03980422974564135, 0.051876070647267625, 0.015889758396951947, 0.049485475683468394, 0.02546647097915411, 0.029114744647813495, 0.016627931872790214, 0.049251680611632764, 0.06762195815099403, 0.012062031564710196, 0.053374529888969846, 0.009328165469923988, 0.05651805593515746, 0.01554851240143762, 0.08090840536169708, 0.04617397193214856, 0.05323520650563296, 0.03850490727927536, 0.04935656463203486, 0.03244595798605587, 0.036149861189187504, 0.05554759765800554, 0.09461924972129054, 0.049519191452418454, 0.03101931266428437, 0.09562285602441989, 0.056999869339051656, 0.05178431521926541, 0.02737830647674855, 0.0561032065161271, 0.023055854726408143, 0.034229372249683365, 0.03669013356557116, 0.08424104918958619, 0.042796502384589985, 0.025003142618515994, 0.013591370643553091, 0.01580987733177608, 0.0885087026108522, 0.004630380417438573, 0.024173564379452728, 0.05113537758006714, 0.02780945345875807, 0.0905624330334831, 0.04290788390790112, 0.06879924185341224, 0.07804455395671539, 0.008487989362038206, 0.0581070757471025, 0.0918639670999255, 0.025942297106666956, 0.04289039890863933, 0.01570711214299081, 0.028993960113439243, 0.1077951466140803, 0.0749676839041058, 0.05165727066923864, 0.025754817615961656, 0.02368787882005563, 0.027526695193955675, 0.031768614644533955, 0.10981882747728378, 0.05846686523000244, 0.02898773720517056, 0.038182596254046075, 0.036103235761402175, 0.06098998921515886, 0.07207943810499273, 0.03780452025239356, 0.03705160772369709, 0.05641793650283944, 0.1181440768414177, 0.04366802124422975, 0.02759040300588822, 0.06346899623167701, 0.06008551899867598, 0.12558716494822875, 0.19100191653706133, 0.07797104422934353, 0.14883350115269423, 0.676096414681524, 0.72057273122482, 0.4345743980957195, 0.8077467628754675, 3.9090162562206388, 3.225547643378377, 8.586691841483116, 6.142150964587927, 7.002136493101716, 7.682586880400777, 8.76592157408595, 8.486288879066706, 13.00741832703352, 25.469748303294182, 44.303597286343575, 48.666447177529335, 34.13106054067612, 16.197434552013874, 9.684584978967905, 3.4605586202815175, 0.7962237624451518, 0.7553188980091363, 0.18169504328398034, 0.23199865885544568, 0.2561229409184307, 0.16594074724707752, 0.3172921476652846, 0.21836806292412803, 0.3696074732579291, 0.6167598674073815, 0.07353438893915154, 0.10264148761052638, 0.013800142351101385, 0.07857921198592521, 0.05628819424600806, 0.015554886522295419, 0.06345669142319821, 0.029351189186854754, 0.026754035970952827, 0.0327498674596427, 0.055921502789715305, 0.0407140397146577, 0.018840539414668456, 0.03955681997467764, 0.07344974699662998, 0.012142103732912801, 0.061440250210580416, 0.07097097375662997, 0.08111372051644139, 0.04654270058381371, 0.04654911273973994, 0.016529148306290153, 0.03191178977431264, 0.04064797372848261, 0.06921267005964182, 0.09941222495399415, 0.12317827233346179, 0.08326993411174044, 0.007685986083743046, 0.056195704091805965, 0.029219142561487388, 0.07389792997855693, 0.017758582725946326, 0.014430072660616133, 0.057497995148878545, 0.039074090018402785, 0.023355302037089132, 0.04044426532345824, 0.009165776136796921, 0.042260998307028785, 0.03541225545632187, 0.07463133515557274, 0.05937223344517406, 0.029144669897505082, 0.0018125297606275126, 0.044942789754713885, 0.0027696816778188804, 0.008898308897187235, 0.017468749938416295, 0.08350244897883385, 0.06171711582283024, 0.052228446074877866, 0.03522753861034289, 0.035916971537517384, 0.01011291891700239, 0.050231697750859894, 0.006017357482051011, 0.024299063406942878, 0.050272334046894684, 0.01988804931897903, 0.09069627936696634, 0.002625030369927117, 0.03904471952409949, 0.007326854793063831, 0.004127868514842703, 0.005790527930003009, 0.025262849776481744, 0.06414483301341534, 0.026534837088547647, 0.053298159182304516, 0.03372363200469408, 0.008007748383533908, 0.017259824235225096, 0.021127955442352686, 0.06662379179033451, 0.00990956395980902, 0.09971718827728182, 0.06674246862530708, 0.10021164416684769, 0.14344742376124486, 0.09223412067512982, 0.20978370012016967, 0.08450715366052464, 0.07799241066095419, 0.13891880895243958, 0.18894710257882252, 0.12753249728120863, 0.12864214164437726, 0.10914025959209539, 0.09882629194180481, 0.1561283675255254, 0.17432395834475756, 0.12800450320355594, 0.23585993447341025, 0.12148386755143292, 0.1012079328938853, 0.1838209104607813, 0.12448805166059174, 0.1267363064107485, 0.18195681361248717, 0.12511557462858036, 0.10100490355398506, 0.11312378919683397, 0.16022276657167822, 0.17725354176945984, 0.1585665304446593, 0.15497851360123605, 0.12923790811328217, 0.14069102791836485, 0.13515380473108962, 0.14754548901692033, 0.18647497898200527, 0.08630263153463602, 0.07568207525764592, 0.14812096516834572, 0.2322442948934622, 0.14676158811198547, 0.2070989808999002, 0.18344073789194226, 0.08577437823987566, 0.1359551609493792, 0.18654244020581245, 0.10970636241836473, 0.12242805751156993, 0.12549043342005461, 0.14659730630228296, 0.11377454138710164, 0.31920397945214063, 0.19286015041870996, 0.1442281185882166, 0.20775514334673062, 0.2144556088023819, 0.21384013089118525, 0.23109917587134987, 0.16651064244797453, 0.1657273797900416, 0.14991690317401662, 0.24896161659853533, 0.13874124269932508, 0.15636198077118024, 0.3053976281080395, 0.2617258590180427, 0.34393061825539917, 0.26066102553159, 0.26515173143707216, 0.7175393064972013, 1.662609453778714, 2.3828431125730276, 1.9767846702598035, 3.1883839750662446, 9.223064593970776, 9.88297138363123, 18.694092482328415, 14.273912217468023, 13.993411269038916, 14.636662602424622, 15.231893062591553, 16.213044114410877, 20.60315564274788, 38.35867188870907, 63.15146751701832, 63.84109631180763, 48.891915678977966, 25.888126753270626, 16.124373972415924, 5.913739996030927, 1.5666009555570781, 1.411713904235512, 0.41304680169560015, 0.44861304166261107, 0.38267224095761776, 0.3610734280664474, 0.37084270385093987, 0.32350650639273226, 0.7175944629125297, 1.0297658806666732, 0.41674976237118244, 0.21452900720760226, 0.17594939534319565, 0.15417160611832514, 0.21937027398962528, 0.14236347255064175, 0.14900658483384177, 0.2808693505357951, 0.1772634865483269, 0.22496254969155416, 0.18763218016829342, 0.21346199180698022, 0.1726971409516409, 0.10742778351414017, 0.14985871879616752, 0.11745189054636285, 0.17153066291939467, 0.18020115938270465, 0.3004917944781482, 0.17743502656230703, 0.1444613459170796, 0.16909757629036903, 0.08518238188116811, 0.12996644480153918, 0.19579880288802087, 0.26107695477548987, 0.13867519155610353, 0.3016509994631633, 0.0851566219353117, 0.1398748584324494, 0.09426236574654467, 0.13346884748898447, 0.15069246233906597, 0.11980575291090645, 0.24477848637616262, 0.08851603502989747, 0.09722836635774001, 0.14159551297780126, 0.15031082031782717, 0.10200668417382985, 0.08879955770680681, 0.15497800894081593, 0.0987100122438278, 0.11886200823937543, 0.08961703337263316, 0.23780513321980834, 0.18104227987350896, 0.1486593042500317, 0.21142577606951818, 0.14958731539081782, 0.2235654863761738, 0.1359240204328671, 0.09086266887607053, 0.09714159445138648, 0.11764985843910836, 0.11794378602644429, 0.08434412608039565, 0.12125367560656741, 0.1610552633064799, 0.12891488091554493, 0.1914473981014453, 0.08784101461060345, 0.16100332781206816, 0.16595495195360854, 0.09092981097637676, 0.1089801338093821, 0.1350888074375689, 0.1359346925164573, 0.14779666147660464, 0.1148094143718481, 0.10045463815913536, 0.07553686664323322, 0.10334945938666351, 0.11871397946379147, 0.16545293357921764, 0.05712783044145908], [0.018997754123120103, 0.03440003652940504, 0.010117985002580099, 0.036948527122149244, 0.011045482206100132, 0.05055105502833612, 0.04469160616281442, 0.04754124543978833, 0.06126273590780329, 0.04394087183754891, 0.03534130984917283, 0.0859600339026656, 0.027096088124380913, 0.08437417563982308, 0.01831771864090115, 0.01574896741658449, 0.038373439529095776, 0.09852320625213906, 0.013927404907008167, 0.08722761471290141, 0.07137082066037692, 0.008114854208542965, 0.09652322958572768, 0.019291705830255523, 0.026000808029493783, 0.03400524736207444, 0.02558854870585492, 0.017279546809731983, 0.06267669421504252, 0.030421256669797003, 0.05851346468261909, 0.0429861916200025, 0.00994568335954682, 0.0784989412932191, 0.028238637460162863, 0.026642175762390252, 0.049180645946762525, 0.030577675424865447, 0.055348126916214824, 0.07972716601216234, 0.03578201198251918, 0.02969185352412751, 0.0379125806648517, 0.057649293084978126, 0.017421057673345786, 0.038734212357667275, 0.04346930007159244, 0.06004856746585574, 0.020094976789550856, 0.04383590989164077, 0.052800797784584574, 0.01943255618243711, 0.011808217986981617, 0.05573488975642249, 0.07012666945229284, 0.05753202633059118, 0.02350690796447452, 0.04535913831205107, 0.061392452189465985, 0.03886928694555536, 0.09737286251038313, 0.022520940656249877, 0.023157840660132933, 0.24596114322775975, 0.09765340175363235, 0.5528282979503274, 5.813433453440666, 12.543321680277586, 25.351568944752216, 40.58321692049503, 59.70248758792877, 56.788401156663895, 67.23534017801285, 74.83559355139732, 77.90411129593849, 78.07062596082687, 86.26572221517563, 76.21193289756775, 92.94111281633377, 91.24991476535797, 96.15002542734146, 100.84962844848633, 105.85757732391357, 120.8094710111618, 109.09899339079857, 118.70215728878975, 104.74726170301437, 104.72732797265053, 106.6932512819767, 94.94081631302834, 77.06710740923882, 64.18940842151642, 52.41996556520462, 49.64572682976723, 33.16538795828819, 14.965996630489826, 17.08690032362938, 31.589186936616898, 30.806316845119, 22.170809023082256, 10.984638668596745, 2.3576205410063267, 0.3791693929815665, 0.128096247499343, 0.4762907268013805, 0.30990463157650083, 0.12837980728363618, 0.13815215555951, 0.06036068509274628, 0.03549488617863972, 0.01547912437672494, 0.09602433565305546, 0.047650652850279585, 0.0630489332252182, 0.02890941279474646, 0.036577620267053135, 0.056334077526116744, 0.08168207205017097, 0.020762681488122325, 0.03121988549537491, 0.02293979581736494, 0.03780161845497787, 0.022446000439231284, 0.02698044296266744, 0.01691692046733806, 0.03856855386402458, 0.04250915393640753, 0.012173131071904209, 0.012918513584736502, 0.04803896677913144, 0.05444861795695033, 0.06980019126785919, 0.017710775427985936, 0.05073799460660666, 0.014577292495232541, 0.02914154731115559, 0.039958915585884824, 0.05687345561455004, 0.07019473181571811, 0.025643603075877763, 0.022953905900067184, 0.04458085917576682, 0.02637002464325633, 0.01890602467028657, 0.04908631897706073, 0.03793201751250308, 0.011095217232650612, 0.010528566144785145, 0.06340911975712515, 0.012825860158045543, 0.032490223384229466, 0.00930431562665035, 0.03897892813256476, 0.027737737873394508, 0.04006782946817111, 0.07901755408965982, 0.05168835552467499, 0.028153320163255557, 0.05377022818720434, 0.018592250198707916, 0.09267604735214263, 0.07227872702060267, 0.024227945250459015, 0.0030168031707944465, 0.03633328298747074, 0.039451494376407936, 0.04590070202539209, 0.03592198103433475, 0.039318419876508415, 0.043803073567687534, 0.027664920198731124, 0.04667292523663491, 0.02699668300920166, 0.010706831872084877, 0.021548586191784125, 0.1101280284638051, 0.0385410387389129, 0.038170558618730865, 0.032692035601940006, 0.01843272926635109, 0.04078728597960435, 0.04885722912149504, 0.03637206391431391, 0.012269602848391514, 0.015326151042245328, 0.035151494448655285, 0.07379463044344448, 0.01336215276751318, 0.04855202460021246, 0.05032582805142738, 0.035169855182175525, 0.022282564677880146, 0.04359314596513286, 0.019457533162494656, 0.02778945072350325, 0.02709233285713708, 0.04122762074985076, 0.0625820852292236, 0.10024818751844577, 0.03952105587814003, 0.024366374345845543, 0.04863177578954492, 0.009362930450151907, 0.013277296529849991, 0.07991923383087851, 0.039493195654358715, 0.02991893772559706, 0.013759096018475248, 0.01786520708265016, 0.013238257706689183, 0.019064220869040582, 0.06927599009941332, 0.06915965102962218, 0.04727599814941641, 0.02598169772682013, 0.04331744181399699, 0.007816204706614371, 0.040712596237426624, 0.04401917954965029, 0.050545641061034985, 0.021712378184020054, 0.03160529762681108, 0.04854656981478911, 0.010325052553525893, 0.016900151640584227, 0.04944404528941959, 0.051379755677771755, 0.00981104385573417, 0.03480217666947283, 0.05391115460952278, 0.029197234362072777, 0.035125318900099955, 0.050225742015754804, 0.05607479339232668, 0.05695321422535926, 0.043338318428141065, 0.08510132451192476, 0.1207347956369631, 0.023346654161287006, 0.10283322888426483, 0.015560306983388728, 0.5460108700208366, 5.109994299709797, 10.943780411034822, 25.111222341656685, 40.24548724293709, 59.436342269182205, 57.70498797297478, 67.85907670855522, 76.48652896285057, 84.48312386870384, 85.53480863571167, 95.50087586045265, 83.08099910616875, 102.45713219046593, 102.59797543287277, 105.68445101380348, 116.82052865624428, 122.20363900065422, 136.9869813323021, 129.96413737535477, 139.59057122468948, 122.8782320022583, 118.36866438388824, 121.58340588212013, 102.77172490954399, 85.89857831597328, 76.15604549646378, 60.41578151285648, 57.32059299945831, 42.286327332258224, 17.1876348182559, 23.24761424213648, 36.4664988219738, 32.656606659293175, 23.114858865737915, 11.769876033067703, 2.2968378150835633, 0.1542227400932461, 0.2504532888997346, 0.29995851684361696, 0.23275481828022748, 0.06378233840223402, 0.1499517247430049, 0.05816007251269184, 0.05404459276178386, 0.005815495169372298, 0.09174604725558311, 0.04557438340270892, 0.028784728274331428, 0.10645468690199777, 0.04436883500602562, 0.05381079768994823, 0.02148114908777643, 0.0349830677441787, 0.014696084363094997, 0.047054693422978744, 0.0410010245104786, 0.04522256458585616, 0.035116183062200435, 0.04247038043104112, 0.018244019665871747, 0.023077028199622873, 0.04676525582908653, 0.03499672697216738, 0.013299262245709542, 0.043663405085681006, 0.09247568232240155, 0.10520288415136747, 0.021334376397135202, 0.04304358189983759, 0.011245044788665837, 0.11257055521127768, 0.004449574225873221, 0.06078733094909694, 0.07220598912681453, 0.05716742773074657, 0.023604229500051588, 0.03861270051856991, 0.07902723911684006, 0.023575020422867965, 0.024224305016105063, 0.006897552975715371, 0.010743527363956673, 0.062448795506497845, 0.10750219124020077, 0.04127184904064052, 0.07251680799527094, 0.03878918694681488, 0.022759808307455387, 0.03300597149063833, 0.009725113359309034, 0.02153093235392589, 0.0318791760946624, 0.02162455057259649, 0.029222688172012568, 0.029092237164149992, 0.05548182853090111, 0.06073133219615556, 0.004386981026982539, 0.0734344068041537, 0.004034333323943429, 0.01813873303035507, 0.016103079469758086, 0.06467233673902228, 0.017900271705002524, 0.019727478247659747, 0.017721536569297314, 0.05596624316240195, 0.018600645744299982, 0.014277775608206866, 0.04067083558766171, 0.11890664100064896, 0.09314933718997054, 0.09522618551272899, 0.13872234761947766, 0.11195852086530067, 0.1538854042883031, 0.07625618585734628, 0.12788598221959546, 0.13605012616608292, 0.21325635752873495, 0.15884314372669905, 0.17804358765715733, 0.14262902783229947, 0.15164181764703244, 0.13226146227680147, 0.2049758002976887, 0.08853749051922932, 0.14766221400350332, 0.10207145882304758, 0.1649982642265968, 0.18889703729655594, 0.20316996204201132, 0.13982675242004916, 0.23741422919556499, 0.20145138551015407, 0.12447970249922946, 0.1731930737150833, 0.07942086682305671, 0.279046279611066, 0.14198426477378234, 0.1811053475830704, 0.09530612966045737, 0.06975490541663021, 0.18494239950086921, 0.18319250433705747, 0.08254854430560954, 0.17454326298320666, 0.17204271513037384, 0.11139683381770737, 0.273631302989088, 0.08730188885238022, 0.09531570336548612, 0.091921090206597, 0.2413645328488201, 0.1440828654449433, 0.1458756864303723, 0.20817335840547457, 0.14899748610332608, 0.20586327533237636, 0.11263951557339169, 0.12400043837260455, 0.09753955630003475, 0.09015675284899771, 0.14707364636706188, 0.1686334965052083, 0.11432862884248607, 0.1501818944234401, 0.22032065346138552, 0.12392860589898191, 0.08870097080944106, 0.1575835855328478, 0.1581785356393084, 0.2100031977170147, 0.35691449185833335, 0.21473289001733065, 1.6778636164963245, 9.06119043007493, 20.353822521865368, 39.25800763070583, 61.22007675468922, 79.96042415499687, 82.42320120334625, 93.33746194839478, 104.68890443444252, 113.24527010321617, 115.34975677728653, 123.81649285554886, 109.29079949855804, 127.57500797510147, 128.62975537776947, 130.92420905828476, 138.18221479654312, 145.4445978999138, 159.60201501846313, 149.2266109585762, 159.07209545373917, 147.03826278448105, 146.42676919698715, 145.60841470956802, 128.86143654584885, 106.87292844057083, 94.74616035819054, 76.04111686348915, 75.54674059152603, 57.002318277955055, 29.53715644776821, 34.045040756464005, 48.68012644350529, 48.5767187923193, 33.65939185023308, 20.327594429254532, 4.310018001124263, 0.6250753055792302, 0.288265505223535, 0.44651460426393896, 0.6670130614656955, 0.4595647961832583, 0.2407972648506984, 0.2486938497168012, 0.12527532933745533, 0.1258744057849981, 0.21004495094530284, 0.14738004945684224, 0.1486647516139783, 0.2504826185759157, 0.17091896996134892, 0.11946686601731926, 0.11177075008163229, 0.13333245558897033, 0.11659658019198105, 0.12251830266905017, 0.13610801368486136, 0.15526443341514096, 0.09119751106481999, 0.1493809834937565, 0.11984014403424226, 0.146878105297219, 0.08819579830742441, 0.09693493600934744, 0.09291987254982814, 0.169317044201307, 0.20041133975610137, 0.19316336227348074, 0.17527720250654966, 0.19246074138209224, 0.10076871505589224, 0.3117650473723188, 0.13769062876235694, 0.23696465097600594, 0.13158181827748194, 0.1558927950100042, 0.11278059784672223, 0.15257019986165687, 0.16440499137388542, 0.12237857110449113, 0.13771253696177155, 0.08753616260946728, 0.07127601871616207, 0.17836205806815997, 0.14847121434286237, 0.11215832928428426, 0.17356334603391588, 0.12606772041181102, 0.1719664371921681, 0.13008682115469128, 0.15033262461656705, 0.15279039507731795, 0.08117876976029947, 0.16399620159063488, 0.09745610179379582, 0.14708832604810596, 0.1588710187934339, 0.09077592665562406, 0.0807636123499833, 0.12042705668136477, 0.12693972908891737, 0.16816809569718316, 0.1571629213867709, 0.22664645308395848, 0.11420400740462355, 0.13208978867623955, 0.2322843560250476, 0.15680207434343174, 0.1260999296209775, 0.09266221371944994, 0.18296105816261843], [0.06827044679084793, 0.03552225658495445, 0.012100827334506903, 0.020708757037937175, 0.025831620623648632, 0.04141376994084567, 0.05847764863574412, 0.06497840586234815, 0.05707718628400471, 0.06535112726851366, 0.08739605997106992, 0.0069744612756039714, 0.01955524432560196, 0.056197036246885546, 0.05737482832046226, 0.046505489299306646, 0.07583234531921335, 0.030910331988707185, 0.03505747918097768, 0.021621446539938916, 0.04409971741551999, 0.04351911302364897, 0.015120928655960597, 0.019221695329179056, 0.021695967443520203, 0.03781859508308116, 0.024985169657156803, 0.03609331695770379, 0.04044226523546968, 0.01212277635204373, 0.0059656103076122236, 0.024776659556664526, 0.04821866299607791, 0.018647126453288365, 0.04143040147027932, 0.006920024743521935, 0.0346180461201584, 0.03313123859697953, 0.013768655808235053, 0.011950962671107845, 0.056174486089730635, 0.01627905196073698, 0.0277748767985031, 0.02723100500588771, 0.03607754631957505, 0.09395538378157653, 0.07142432208638638, 0.028211363533046097, 0.05187713562918361, 0.023816999528207816, 0.052406457616598345, 0.06843906274298206, 0.08054750636802055, 0.05812854607938789, 0.02194285214500269, 0.05053539571235888, 0.06276371103012934, 0.014786474239372183, 0.016393760161008686, 0.026485066809982527, 0.22269818291533738, 0.23910536110633984, 1.050422047264874, 13.005203995853662, 29.502316117286682, 55.779350101947784, 75.60083448886871, 90.4435296356678, 102.99107953906059, 106.9366966187954, 103.29383969306946, 93.49425673484802, 88.93164396286011, 88.77472758293152, 87.26246953010559, 90.63135355710983, 96.5018181502819, 98.91217321157455, 93.55539545416832, 100.05814611911774, 100.39647236466408, 103.47833499312401, 93.60724747180939, 86.20795771479607, 87.6210866868496, 88.75719532370567, 86.14771574735641, 104.32107657194138, 91.2618613243103, 103.56642946600914, 105.98335817456245, 103.69282588362694, 107.21738755702972, 114.06230226159096, 115.77091097831726, 96.32258176803589, 110.9392574429512, 136.45405232906342, 107.76493057608604, 110.90045392513275, 93.5198749601841, 80.37405475974083, 50.14450706541538, 35.90309165418148, 22.380833253264427, 8.642037771642208, 2.01604594476521, 0.12700969877187163, 0.08233892469434068, 0.2712184324627742, 0.020638206624425948, 0.055425499522243626, 0.05303335718053859, 0.03083590570895467, 0.05390726204495877, 0.06255504136788659, 0.009238509392162086, 0.015614659096172545, 0.04301755478081759, 0.10396960540674627, 0.102368199150078, 0.053527018972090445, 0.02763788932497846, 0.010818215250765206, 0.03099053217738401, 0.07350037631113082, 0.02476099838531809, 0.016129262439790182, 0.008108987531159073, 0.08062549866735935, 0.011295764088572469, 0.033912100407178514, 0.04535215470241383, 0.08892835001461208, 0.05870660119398963, 0.005684154511982342, 0.1426810523844324, 0.037987370596965775, 0.06052909324353095, 0.01775855304003926, 0.046972804848337546, 0.03913532833394129, 0.030059246309974696, 0.014873339841869893, 0.03876677779771853, 0.07439199252985418, 0.04594605466991197, 0.032609890986350365, 0.02759395047178259, 0.023139318509493023, 0.05674313448253088, 0.07511199451982975, 0.020104073664697353, 0.015133349425013876, 0.01731990480038803, 0.04398059900267981, 0.021643137661158107, 0.04183426710369531, 0.046607898257207125, 0.06422748600016348, 0.0427135710924631, 0.011077581948484294, 0.09442880720598623, 0.03969914534536656, 0.0514238540927181, 0.032686343329260126, 0.07024609585641883, 0.054173262615222484, 0.011023798506357707, 0.06928355258423835, 0.07741361710941419, 0.0654613139340654, 0.042457945746718906, 0.07949411679874174, 0.04314971643907484, 0.007014145767243463, 0.05731058059609495, 0.02848277992598014, 0.05272269787383266, 0.06209906954609323, 0.033901187125593424, 0.03184959408827126, 0.003385578670531686, 0.019466687554086093, 0.008848375346133253, 0.11355370792443864, 0.0679924976429902, 0.04180238815024495, 0.03507366171106696, 0.052512414040393196, 0.07059613722958602, 0.021876541250094306, 0.02067582609015517, 0.010858742080017691, 0.05379477843234781, 0.004448883564691641, 0.056490871065761894, 0.06960562983294949, 0.02830396500939969, 0.03487762340228073, 0.027373538177926093, 0.0059169152154936455, 0.05584934748185333, 0.023985838124644943, 0.07638991344720125, 0.05494644690770656, 0.02851119304978056, 0.03631986124673858, 0.010948331364488695, 0.020037274807691574, 0.06298307504039258, 0.033589841332286596, 0.016261132805084344, 0.05774396886408795, 0.018961145833600312, 0.004956606735504465, 0.033520788201713, 0.03176559039275162, 0.02870544278266607, 0.061171132620074786, 0.0509992973820772, 0.03831024565442931, 0.09231109623215161, 0.014711049770994578, 0.05706489260774106, 0.03872129527735524, 0.0834089977433905, 0.06223571006557904, 0.03828321292530745, 0.02102220125379972, 0.033251373752136715, 0.06563090952113271, 0.018567538536444772, 0.07887967047281563, 0.035768694142461754, 0.022389207588275895, 0.23683532432187349, 0.15428359620273113, 1.1342403246089816, 12.120295129716396, 29.533231258392334, 60.80341011285782, 80.04253014922142, 102.16275438666344, 115.96042200922966, 120.8712100982666, 122.17525452375412, 111.01683408021927, 107.41409540176392, 108.21161180734634, 103.96303698420525, 105.05167856812477, 115.19496068358421, 117.48751446604729, 112.75277093052864, 122.8726615011692, 120.04012629389763, 118.72096627950668, 115.34505262970924, 110.99348813295364, 107.4560983479023, 108.04116815328598, 109.61547687649727, 121.45957052707672, 107.87523865699768, 122.3539437353611, 122.04993724822998, 121.85474932193756, 127.21623882651329, 134.8669534921646, 136.33197247982025, 116.65763899683952, 126.72031983733177, 154.4314956665039, 127.14912682771683, 130.41517317295074, 114.33778747916222, 89.82492282986641, 60.36986097693443, 40.08567541837692, 21.54280912131071, 9.499912038445473, 1.9726059632375836, 0.12350716249784455, 0.12610294274054468, 0.3020904102595523, 0.04619737184839323, 0.01646974495088216, 0.04757742884976324, 0.0515392951638205, 0.04321160784456879, 0.08525003606337123, 0.01849770429544151, 0.04838265165744815, 0.021500628608919214, 0.010838529688044218, 0.019418386727920733, 0.028662832373811398, 0.024041625365498476, 0.00745216596442333, 0.006699737687085872, 0.021806413860758767, 0.018463033011357766, 0.02042597836407367, 0.007106371531335753, 0.03155084625177551, 0.04651530791306868, 0.0180552228630404, 0.06547050914377905, 0.09852676856098697, 0.07449922544765286, 0.026605179700709414, 0.08900229018763639, 0.06256325694266707, 0.058801469931495376, 0.03499632621242199, 0.024526750603399705, 0.05734095298976172, 0.045522626023739576, 0.07475994192645885, 0.027753948234021664, 0.06878658081404865, 0.016420694555563387, 0.053848777097300626, 0.02211370567238191, 0.042193841363769025, 0.03892197571985889, 0.02415915372694144, 0.026761724620882887, 0.008173927308234852, 0.01977389030798804, 0.015944280276016798, 0.005374362126531196, 0.052354047147673555, 0.0284293619915843, 0.029759622739220504, 0.019020879444724414, 0.04457206843653694, 0.04471869826375041, 0.019421167926338967, 0.040455378984916024, 0.00642621173938096, 0.05753668701800052, 0.03577217852580361, 0.030892934191797394, 0.08214504603529349, 0.02513299619749887, 0.09169927710900083, 0.030553024989785627, 0.04226213750371244, 0.08724266546778381, 0.042546650947770104, 0.17701792472507805, 0.10703364372602664, 0.13229192001745105, 0.1277347028371878, 0.13661798788234591, 0.09657002199674025, 0.14797896263189614, 0.09590135436155833, 0.1998781957081519, 0.16217268537729979, 0.23695397889241576, 0.1338829510495998, 0.14004852098878473, 0.13708960788790137, 0.1951035441015847, 0.11348987580277026, 0.16652930004056543, 0.11879576413775794, 0.279985066736117, 0.13181307149352506, 0.1843505961005576, 0.19488363090204075, 0.10170406603720039, 0.19784854055615142, 0.10913880498264916, 0.11426371318520978, 0.16829325148137286, 0.12730148155242205, 0.14458495803410187, 0.07122795723262243, 0.14868573955027387, 0.09715297899674624, 0.1314719210495241, 0.15153101499890909, 0.11695788736687973, 0.1169700437458232, 0.06954605763894506, 0.09283891908125952, 0.07832092975149862, 0.06791154417442158, 0.15964702324708924, 0.23997356998734176, 0.1484134900965728, 0.1357752495096065, 0.13436985929729417, 0.24725993134779856, 0.1628448485280387, 0.1364194040070288, 0.10495204565813765, 0.1248861470958218, 0.12641416979022324, 0.3573274228256196, 0.1597876157029532, 0.10876612068386748, 0.0762755039613694, 0.20805085950996727, 0.14284159376984462, 0.15443707234226167, 0.13270299561554566, 0.11000060170772485, 0.3871776710730046, 0.5953873204998672, 3.3646821649745107, 20.18059741705656, 48.99237848818302, 82.70548045635223, 105.57786673307419, 121.67303547263145, 135.66190123558044, 137.28012800216675, 133.26497465372086, 125.4033637046814, 120.59196308255196, 119.94233474135399, 115.62827423214912, 117.80645415186882, 125.25751993060112, 127.3026005923748, 120.3615814447403, 129.86146688461304, 128.11138719320297, 133.1259173154831, 123.19126680493355, 113.16887140274048, 116.27011299133301, 115.52949473261833, 115.33777222037315, 132.12173759937286, 118.60420614480972, 132.6038557291031, 135.506991147995, 136.67345255613327, 143.33352237939835, 149.30022060871124, 152.93695986270905, 137.33785450458527, 151.31684839725494, 172.4458122253418, 142.77539312839508, 150.37668764591217, 135.33028542995453, 110.61649516224861, 80.85798159241676, 56.97416938841343, 33.74740272760391, 17.15861577540636, 4.4489271473139524, 0.418157497770153, 0.2825990889687091, 0.5007584451232105, 0.28715661785099655, 0.14310345315607265, 0.19607124530011788, 0.1643312070518732, 0.1315912583959289, 0.24218833161285147, 0.18817040050635114, 0.07390031969407573, 0.17026634013745934, 0.1895453775068745, 0.10711978480685502, 0.10293580853613093, 0.08538961919839494, 0.1478990333271213, 0.0705463020130992, 0.18554282665718347, 0.09340367862023413, 0.14228100510081276, 0.06808916237787344, 0.23606034403201193, 0.11178588989423588, 0.13964373880298808, 0.2115967817371711, 0.16842170240124688, 0.11400059956940822, 0.10545027907937765, 0.18336310924496502, 0.1268740341765806, 0.15149736602324992, 0.15355758281657472, 0.11025403029634617, 0.17504937801277265, 0.18367197626503184, 0.15612747694831342, 0.14824407262494788, 0.18600052397232503, 0.10831780411535874, 0.16253051930107176, 0.13405195291852579, 0.17538077663630247, 0.07340573763940483, 0.18232579459436238, 0.09850530565017834, 0.06846785807283595, 0.08399228870985098, 0.20276062306948006, 0.07650300933164544, 0.10238508300972171, 0.15606868400936946, 0.21932426083367318, 0.2802299754694104, 0.11870652087964118, 0.15871736453846097, 0.14048854034626856, 0.10084878536872566, 0.11101511016022414, 0.2891671552788466, 0.13221818022429943, 0.11494521997519769, 0.16046512231696397, 0.2608558541396633, 0.18292626627953723, 0.16196455748286098, 0.14549650833941996, 0.17257875355426222, 0.14599037793232128], [0.04338013844972011, 0.08426151762250811, 0.07671399449463934, 0.04376963239337783, 0.06146644431282766, 0.018967279684147798, 0.04269889883289579, 0.02683029721083585, 0.037382898735813797, 0.01371795227896655, 0.015609857400704641, 0.04149092361330986, 0.02610709470900474, 0.02648635443620151, 0.029432782757794484, 0.058438055057195015, 0.02823960967361927, 0.012603900486283237, 0.03106053154624533, 0.05994927552819718, 0.04021398432087153, 0.06111799484642688, 0.026036375456897076, 0.06425958388717845, 0.06943004511413164, 0.011087840284744743, 0.006379736596500152, 0.03668843404739164, 0.0386986189550953, 0.015434234646818368, 0.029095810605213046, 0.028807402741222177, 0.027970844603260048, 0.019666265907289926, 0.028643710938922595, 0.022752494442102034, 0.07614820337039419, 0.04247597622452304, 0.08410015245317481, 0.029416364595817868, 0.09169217475573532, 0.003476961633168685, 0.043774627047241665, 0.025543821320752613, 0.003291169368822011, 0.06686151653411798, 0.039251930866157636, 0.1418607120285742, 0.06309604475973174, 0.10495496971998364, 0.010593832466838649, 0.0684634422941599, 0.07473793724784628, 0.0874994634068571, 0.05649328675644938, 0.06574053215445019, 0.017792285507312045, 0.04675175987358671, 0.10888082702877, 0.27738570934161544, 15.814593695104122, 35.227894484996796, 59.14597325026989, 78.7145546078682, 91.28446251153946, 95.1992480456829, 82.35668197274208, 80.57227492332458, 79.31154817342758, 78.45382779836655, 81.75354793667793, 56.003393679857254, 78.38248282670975, 54.090063348412514, 63.90882387757301, 59.36177887022495, 32.77183547616005, 45.61790496110916, 49.766370356082916, 49.99329797923565, 42.68723241984844, 52.605065032839775, 53.54974754154682, 47.1946607530117, 44.62207719683647, 50.39000429213047, 47.984144389629364, 76.71359717845917, 83.24056014418602, 83.27711418271065, 77.88547709584236, 64.65582579374313, 78.98576125502586, 88.67012679576874, 75.20761638879776, 85.59471622109413, 83.41622471809387, 69.76894542574883, 104.00359600782394, 97.80392467975616, 96.53263449668884, 101.99471220374107, 98.00903007388115, 106.21339023113251, 104.69870790839195, 95.58656126260757, 71.44552186131477, 46.22261971235275, 17.945013977587223, 6.045242864638567, 0.8460805309005082, 0.5666722019668669, 0.012161569338786649, 0.009014049610414077, 0.1412996038561687, 0.029972418742545415, 0.06248146484722383, 0.04273619175364729, 0.07613177222083323, 0.05641616276989225, 0.009893962160276715, 0.029144061336410232, 0.043887170031666756, 0.01526312136775232, 0.009435293559363345, 0.00421994677708426, 0.06372426534653641, 0.03431284159887582, 0.032662887751939707, 0.014452070845436538, 0.015891910625214223, 0.025672134943306446, 0.03923116557416506, 0.005929691287747119, 0.036407538573257625, 0.02638400485011516, 0.04487200370931532, 0.03403620976314414, 0.01053051706549013, 0.057232057661167346, 0.0597351436590543, 0.01875378606200684, 0.0579001427104231, 0.03042771335458383, 0.0346365923905978, 0.040647506175446324, 0.04588844174577389, 0.0578832106111804, 0.00805358991783578, 0.004129992448724806, 0.020354405642137863, 0.023537079978268594, 0.02349043785216054, 0.05944724973232951, 0.03266909210651647, 0.1141797837044578, 0.023495733075833414, 0.028836339079134632, 0.02042777992755873, 0.037923393756500445, 0.06356910453177989, 0.024608121530036442, 0.015858667975408025, 0.06247750177863054, 0.04994988201360684, 0.033967909912462346, 0.045712385763181373, 0.0564031826070277, 0.042063601867994294, 0.011428374746174086, 0.02800319853122346, 0.03900386800523847, 0.04269098753866274, 0.03207141089660581, 0.018320305025554262, 0.028326429819571786, 0.021833956816408318, 0.05894358007935807, 0.006772456099497504, 0.050008359539788216, 0.01892729091196088, 0.056864327198127285, 0.03982137335697189, 0.05259723780909553, 0.07893165049608797, 0.05233965319348499, 0.021714281792810652, 0.09329267559223808, 0.05500777428096626, 0.02925689004769083, 0.006885389175295131, 0.020045939381816424, 0.022377891691576224, 0.06620802581892349, 0.03267790139943827, 0.04297278843296226, 0.010580495145404711, 0.01125501461501699, 0.05240783801127691, 0.04351948038674891, 0.05273060545732733, 0.02380409358011093, 0.0633602641755715, 0.005697163896911661, 0.06941939529497176, 0.14941515197278932, 0.009863829109235667, 0.027933271521760616, 0.01529494466012693, 0.019356200318725314, 0.020494756900006905, 0.05824466250487603, 0.05490023708262015, 0.05442506961117033, 0.04212885891320184, 0.00716620811544999, 0.014778634376853006, 0.032404394005425274, 0.011952142685913714, 0.03719419284607284, 0.017651327543717343, 0.06736472234479152, 0.04593670731992461, 0.039543379680253565, 0.05211060415604152, 0.08892227924661711, 0.04059961538587231, 0.022708794931531884, 0.06495345485745929, 0.1629307892289944, 0.038466048426926136, 0.059331177835701965, 0.004079749514858122, 0.08803267424809746, 0.10000174996093847, 0.3673013235675171, 15.454461369663477, 39.481701627373695, 65.76877847313881, 90.76695308089256, 107.99588218331337, 107.27253019809723, 96.57817885279655, 98.08035224676132, 95.50051108002663, 96.26516684889793, 93.9322592318058, 78.8139420747757, 99.37090739607811, 77.37908586859703, 90.7760801911354, 79.67605501413345, 67.55054086446762, 70.50488233566284, 76.45845606923103, 81.43339991569519, 78.53564500808716, 98.05500000715256, 92.8853166103363, 87.25076615810394, 85.78706189990044, 87.25045457482338, 78.30923795700073, 112.2307625412941, 116.00725829601288, 105.1576016843319, 103.67458686232567, 93.36642399430275, 105.41184604167938, 111.47008895874023, 103.90419334173203, 120.13885259628296, 123.69590252637863, 100.85370182991028, 117.29318529367447, 117.00249329209328, 108.86763140559196, 125.3402490913868, 113.10953378677368, 123.535345941782, 123.10485944151878, 110.95677450299263, 82.65095338225365, 53.58277156949043, 21.07569258660078, 7.723988508805633, 0.5160768481437117, 0.4329953156411648, 0.04844335933739785, 0.005583528100032709, 0.11203819783986546, 0.020056587345607113, 0.06659852908342145, 0.016334052525053266, 0.06708062079269439, 0.11982331954641268, 0.07450596414855681, 0.05379994006943889, 0.026095012544828933, 0.02692016201763181, 0.01886706377263181, 0.01829114418796962, 0.024368363301618956, 0.05733729420171585, 0.09602984981029294, 0.05139603839779738, 0.08253846594016068, 0.012493765771068865, 0.059619286985252984, 0.047704877870273776, 0.037618894275510684, 0.06751257300493307, 0.03956122091040015, 0.04239181296725292, 0.03314373636385426, 0.04017427942017093, 0.05359407572541386, 0.021509640137082897, 0.03896749534760602, 0.07127241929993033, 0.02488326350430725, 0.08037364343181252, 0.04787266632774845, 0.1170481473673135, 0.05921476455114316, 0.017540207627462223, 0.036229274701327085, 0.010954596018564189, 0.035370235054870136, 0.04854777951550204, 0.012246156547917053, 0.022811903363617603, 0.021663930783688556, 0.04348410962847993, 0.03981210022175219, 0.005328885172275477, 0.04786058416357264, 0.05791190575109795, 0.031610273726982996, 0.03513790943543427, 0.037215418269624934, 0.033789219305617735, 0.05476243510202039, 0.04077377147041261, 0.005771466330770636, 0.017082373015000485, 0.05184274821658619, 0.03287819221441168, 0.01425504548024037, 0.01391218438584474, 0.036409579479368404, 0.065683208667906, 0.17795500491047278, 0.13739630783675238, 0.1529779506381601, 0.13089574727928266, 0.11275288605247624, 0.1203283658833243, 0.12954860081663355, 0.10348976982641034, 0.1502287239418365, 0.07952881962410174, 0.07512663709348999, 0.18619300739374012, 0.18232848116895184, 0.07990532598341815, 0.10016909684054554, 0.1049501086527016, 0.07550593392807059, 0.14845223020529374, 0.1355028070975095, 0.13706162892049178, 0.13146729004802182, 0.09995605592848733, 0.12604596064193174, 0.12988653033971786, 0.1752559473970905, 0.07466583760106005, 0.17210916703334078, 0.08939946535974741, 0.2961985592264682, 0.2697349089430645, 0.08448024338576943, 0.09847944922512397, 0.13000974169699475, 0.1121334896015469, 0.11108790000434965, 0.25431269430555403, 0.28253826254513115, 0.12093244440620765, 0.1411840069340542, 0.07499933650251478, 0.18292488588485867, 0.12338271917542443, 0.18462110892869532, 0.16033851192332804, 0.13024290965404361, 0.14905685791745782, 0.16511653288034722, 0.27606263814959675, 0.24133075028657913, 0.2574741840362549, 0.12437368670362048, 0.11015893891453743, 0.15598183788824826, 0.44225800142157823, 0.16064990224549547, 0.15342093858635053, 0.10751645531854592, 0.2475714255706407, 0.15070789901074022, 0.5704087077174336, 22.594835869967937, 54.64106038212776, 88.94394010305405, 111.27867802977562, 120.03802120685577, 118.77962753176689, 105.95405414700508, 104.15674299001694, 103.54814484715462, 102.44710832834244, 105.2123187482357, 76.84546530246735, 103.51599097251892, 78.32889050245285, 86.93774655461311, 83.80703374743462, 53.841340094804764, 67.1041864156723, 74.62730392813683, 73.14427390694618, 63.76654431223869, 76.18911892175674, 78.65557417273521, 68.26164990663528, 69.57491263747215, 72.52866134047508, 69.22042205929756, 107.06425577402115, 113.21027398109436, 112.09091484546661, 104.33050766587257, 91.9797720015049, 108.07858854532242, 116.2708729505539, 102.80705541372299, 114.56220343708992, 106.11601665616035, 91.7558728158474, 131.4234110713005, 124.4634461402893, 124.1502745449543, 131.2737599015236, 126.76314353942871, 138.19714039564133, 138.52445483207703, 131.7641767859459, 102.99294143915176, 72.93894812464714, 32.365401685237885, 12.04759743064642, 1.4020351110957563, 0.6061862816568464, 0.24265903135528788, 0.1504151217523031, 0.2642689022468403, 0.19031211995752528, 0.14795200782828033, 0.19633187272120267, 0.1696501942933537, 0.20885968173388392, 0.12251660315087065, 0.17200283211423084, 0.16188663197681308, 0.12647569383261725, 0.12648605421418324, 0.06898492720210925, 0.11178695858689025, 0.2508162287995219, 0.14086333976592869, 0.13156123110093176, 0.10673616125131957, 0.10277969035087153, 0.11760035718907602, 0.14347613003337756, 0.11799930609413423, 0.20926780358422548, 0.1482355676125735, 0.30244503810536116, 0.1174251658085268, 0.2031210545101203, 0.11731726495781913, 0.10065524067613296, 0.1259622018551454, 0.1569656585343182, 0.12275532237254083, 0.26008841407019645, 0.20018387149320915, 0.19546182331396267, 0.20045613578986377, 0.11255861405516043, 0.15259593754308298, 0.12981387408217415, 0.09744607537868433, 0.1316574728116393, 0.11569913811399601, 0.16347669821698219, 0.1711827886174433, 0.19397837400902063, 0.1493104052497074, 0.059870114346267655, 0.15464867348782718, 0.18382923735771328, 0.16262061602901667, 0.21110583620611578, 0.15290645213099197, 0.12471297435695305, 0.19866772316163406, 0.17395132599631324, 0.16890230239368975, 0.08310931109008379, 0.16481133206980303, 0.12091537500964478, 0.11508639872772619, 0.09799538340303116, 0.10619788154144771, 0.10652735058101825], [0.014747606110177003, 0.10298921348294243, 0.02706648941966705, 0.028412426181603223, 0.02787554170936346, 0.025247481753467582, 0.040088936148094945, 0.05509574475581758, 0.017641965350776445, 0.03063263702642871, 0.02526585361920297, 0.03814065748883877, 0.05351148582121823, 0.053430873740580864, 0.0448233410861576, 0.035425729147391394, 0.02319745093700476, 0.08101480707409792, 0.05980105750495568, 0.021277635496517178, 0.015130901265365537, 0.02639770675159525, 0.023039037660055328, 0.029408820664684754, 0.039397900181938894, 0.059390612732386217, 0.03662492104922421, 0.041580519391573034, 0.018232623988296837, 0.0447439312847564, 0.048434286582050845, 0.044034252568962984, 0.025042916167876683, 0.045494108999264427, 0.015493442260776646, 0.037707937153754756, 0.08851382342982106, 0.012649716973101022, 0.044356723155942746, 0.006663130789092975, 0.05110892372613307, 0.026270068483427167, 0.0533781255944632, 0.10466451538377441, 0.030921382567612454, 0.06538191155414097, 0.03598955358029343, 0.06900659791426733, 0.09546127563226037, 0.002797343840938993, 0.028166420925117563, 0.03173666147631593, 0.06324844478513114, 0.04139384698646609, 0.03283243509940803, 0.02699989650864154, 0.08182514327927493, 0.3532792447367683, 2.719457312487066, 35.300569385290146, 51.73339940607548, 81.51285365223885, 74.24305334687233, 74.97408092021942, 65.20834654569626, 61.599535793066025, 60.554382875561714, 56.053414195775986, 51.28688156604767, 37.803563475608826, 50.55526502430439, 35.55728740990162, 21.709977351129055, 23.863173611462116, 26.709353886544704, 31.442298218607903, 27.283497378230095, 26.925868168473244, 22.300163581967354, 26.641101948916912, 28.25803678482771, 24.729130044579506, 22.820492461323738, 22.771756276488304, 22.51705214381218, 17.06984493881464, 29.229912534356117, 19.357804767787457, 23.027279265224934, 32.349966913461685, 21.332233920693398, 18.204975128173828, 22.603972479701042, 38.789257183671, 52.382161393761635, 31.139169484376907, 24.62053757160902, 35.69531500339508, 43.501680716872215, 50.69855533540249, 66.80279418826103, 57.981483936309814, 82.27203771471977, 87.17915520071983, 98.82081851363182, 94.3932580947876, 98.59470024704933, 96.78301826119423, 91.12873926758766, 87.2631610929966, 45.00835306942463, 12.362629976123571, 1.025540626142174, 0.14334831736050546, 0.11791434502811171, 0.03856101735436823, 0.08574095190851949, 0.048173499599215575, 0.047207850439008325, 0.04062396154040471, 0.03186527195794042, 0.044702029626932926, 0.10400263097835705, 0.0677337107481435, 0.05435789040348027, 0.051973833760712296, 0.044514455512398854, 0.05034084169892594, 0.0633811333682388, 0.04440547483682167, 0.04723449354059994, 0.044107194553362206, 0.02806483204039978, 0.04797576548298821, 0.03556623625627253, 0.0389528045343468, 0.018609876206028275, 0.03922306503227446, 0.015111588727449998, 0.03337415837449953, 0.009412905747012701, 0.059265468080411665, 0.02768311394902412, 0.010007535802287748, 0.08055057885940187, 0.03959984227549285, 0.03636928086052649, 0.06034654717950616, 0.022933055261091795, 0.03673937506391667, 0.02345797445741482, 0.06772317225113511, 0.042882420821115375, 0.056840674951672554, 0.08389185386477038, 0.05006704115658067, 0.033991710588452406, 0.03184262903232593, 0.04911568576062564, 0.01106163690565154, 0.03229520552849863, 0.10669463808881119, 0.06352603770210408, 0.040281085603055544, 0.04429434935445897, 0.014387777664524037, 0.09960725394194014, 0.036463288706727326, 0.03317117727419827, 0.09864759020274505, 0.04764130550029222, 0.04554473460302688, 0.018203578183602076, 0.033711471915012226, 0.033631208643782884, 0.04901434178464115, 0.02905608529545134, 0.020082417795492802, 0.04289197226171382, 0.01209745520100114, 0.06339688916341402, 0.0319541367207421, 0.06244387506740168, 0.00936821732466342, 0.022503275686176494, 0.009676571335148765, 0.058241693914169446, 0.01905530025396729, 0.06105629639932886, 0.08149885063176043, 0.05621844349661842, 0.08594307582825422, 0.05166799841390457, 0.0523337197228102, 0.030084022910159547, 0.031143967498792335, 0.04991526082449127, 0.04409535358718131, 0.03727152092324104, 0.033299182905466296, 0.055698402065900154, 0.04343394786701538, 0.0686840753769502, 0.058117432417930104, 0.016213575981964823, 0.03931347717298195, 0.053952080343151465, 0.03576617455109954, 0.07557189601357095, 0.019800034315267112, 0.06064730252546724, 0.057931984556489624, 0.06552021819516085, 0.021683250743080862, 0.036822569818468764, 0.08605519949924201, 0.0036545188413583674, 0.040816177788656205, 0.001119424014177639, 0.024748016367084347, 0.02564305945270462, 0.025972485818783753, 0.003997464818894514, 0.017835001672210637, 0.02888499428081559, 0.02416541930870153, 0.04206210644042585, 0.04333669312472921, 0.03615382796851918, 0.1343413459835574, 0.030369386113306973, 0.0975919741904363, 0.0730424044013489, 0.42770840402226895, 3.2281172554939985, 41.91660717129707, 65.10626882314682, 94.08722251653671, 88.69420230388641, 88.02979275584221, 78.10857832431793, 82.88206458091736, 84.1898176074028, 75.8663110435009, 79.97617051005363, 69.51707974076271, 86.70918881893158, 57.37104669213295, 49.67344634234905, 40.277139544487, 36.44181154668331, 48.176710456609726, 30.48050332814455, 31.884837672114372, 35.24822719395161, 40.18977843225002, 42.22288213670254, 34.842481166124344, 35.571183264255524, 36.069359332323074, 38.05923655629158, 31.795707754790783, 45.78164577484131, 43.061174154281616, 52.91623793542385, 60.721041932702065, 45.55743880569935, 37.076499089598656, 57.62910604476929, 68.45243006944656, 68.9542843401432, 53.795943930745125, 40.39725869894028, 56.86654016375542, 81.77182495594025, 83.04823726415634, 90.99891543388367, 86.0213953256607, 113.08200046420097, 109.05541732907295, 108.43814805150032, 108.19043174386024, 107.56708279252052, 115.37371069192886, 107.37441033124924, 101.92117854952812, 53.18579167127609, 16.637642830610275, 0.8929444849491119, 0.09293878989410587, 0.0834062963258475, 0.049366219973308034, 0.01268281583179487, 0.05280464953102637, 0.025553074046911206, 0.024962378302006982, 0.035131252370774746, 0.13299120124429464, 0.0271365258959122, 0.0058888833700621035, 0.04126561871089507, 0.09538052254356444, 0.04479129514947999, 0.07073934946674854, 0.027558119581954088, 0.06803160882554948, 0.05679490299371537, 0.030458243454631884, 0.047959397415979765, 0.033284343662671745, 0.014553836917912122, 0.05558246004511602, 0.024714933279028628, 0.040722730263951235, 0.02095673084113514, 0.030634687209385447, 0.0329793320997851, 0.05755468038842082, 0.04047966576763429, 0.019461386764305644, 0.018904208263847977, 0.015258209277817514, 0.07156245803344063, 0.05371389175707009, 0.027451148271211423, 0.05230168862908613, 0.013481210880854633, 0.027358667393855285, 0.04320526619267184, 0.04205071447358932, 0.08587756645283662, 0.028360225369397085, 0.0372035624604905, 0.03264103892433923, 0.06258618188439868, 0.031871806568233296, 0.05011951470805798, 0.029141918384993915, 0.0755663076415658, 0.05909465908189304, 0.06892292818520218, 0.013678848517884035, 0.09672283020336181, 0.0335183539573336, 0.012662282460951246, 0.06964975051232614, 0.046835529792588204, 0.024515260301996022, 0.03779449383728206, 0.028056885494152084, 0.04403626749990508, 0.030410790532187093, 0.10313171325833537, 0.14259855524869636, 0.15936910378513858, 0.10953147531836294, 0.1709533907705918, 0.13456228334689513, 0.17071977752493694, 0.18923619878478348, 0.1378576862043701, 0.12663049099501222, 0.15548201627098024, 0.11430332160671242, 0.11342292666085996, 0.1853790643508546, 0.18536362767918035, 0.2230115473503247, 0.1562204977381043, 0.17557116720126942, 0.19539549015462399, 0.106635852571344, 0.14106330403592438, 0.10888735050684772, 0.1284451608080417, 0.17099784541642293, 0.12250053565367125, 0.2358682465273887, 0.1485857871011831, 0.16011799016268924, 0.11294249736238271, 0.12101891203201376, 0.20079005771549419, 0.1392647685133852, 0.10289641533745453, 0.1379867605282925, 0.056744737521512434, 0.15945033926982433, 0.15030206297524273, 0.09886961852316745, 0.14009386621182784, 0.1947427267441526, 0.21984097373206168, 0.16585054661845788, 0.12990253104362637, 0.19430184649536386, 0.09907238811138086, 0.21322968474123627, 0.1130868228210602, 0.19103093451121822, 0.1335131685482338, 0.14403057371964678, 0.23710286855930462, 0.1998905005166307, 0.09883038117550313, 0.1943039838806726, 0.13871154194930568, 0.23308127420023084, 0.228617983229924, 0.7223376771435142, 4.619934596121311, 55.08942112326622, 78.41934084892273, 105.68623691797256, 98.78962978720665, 99.44801285862923, 87.48816221952438, 86.49059414863586, 86.55538067221642, 76.95138841867447, 74.6930480003357, 59.268778860569, 69.90034237504005, 53.27142387628555, 34.89356182515621, 39.78714443743229, 39.770641922950745, 47.52954438328743, 42.98151522874832, 42.354286685585976, 36.14929564297199, 42.18619890511036, 40.31979985535145, 35.3175088763237, 36.62640184164047, 32.22897380590439, 32.3618146777153, 25.70725455880165, 42.48051591217518, 30.18213003873825, 33.9031183719635, 49.64220441877842, 35.74882373213768, 31.575549468398094, 40.01195177435875, 56.095766723155975, 73.4314700961113, 43.469120264053345, 36.20971240103245, 54.89188872277737, 64.52757507562637, 69.666016548872, 92.19139024615288, 80.60340285301208, 110.75805276632309, 112.63819947838783, 123.74245002865791, 118.66827830672264, 125.47408550977707, 126.73968359827995, 124.92936953902245, 120.2986492216587, 69.29648637771606, 22.573634907603264, 1.9253817410208285, 0.27463792241178453, 0.309450407512486, 0.26553165167570114, 0.24166594870621338, 0.12365498347207904, 0.11434640327934176, 0.15395262802485377, 0.16193825576920062, 0.1734857470728457, 0.16751122078858316, 0.09040087490575388, 0.1072134290006943, 0.20098401058930904, 0.1209776931500528, 0.1002261383109726, 0.1742825613473542, 0.16677291743690148, 0.15739963680971414, 0.11617058000410907, 0.18546507926657796, 0.09158694563666359, 0.09557271652738564, 0.12231603031978011, 0.2374070303631015, 0.1369557689758949, 0.12233733737957664, 0.1444111915770918, 0.0997178784746211, 0.20627506339224055, 0.15624571591615677, 0.12602135102497414, 0.12073202000465244, 0.09933698602253571, 0.12615443294635043, 0.19046825298573822, 0.10276274711941369, 0.14801724260905758, 0.12897330278065056, 0.12432230781996623, 0.14158798760036007, 0.1544234316679649, 0.2634429809404537, 0.08643823675811291, 0.11477467443910427, 0.06436926589231007, 0.14700833737151697, 0.13473590137436986, 0.13717801251914352, 0.15368450491223484, 0.1700028925552033, 0.12208132611704059, 0.25939643557649106, 0.17134717432782054, 0.1628940083901398, 0.16834220354212448, 0.16697044746251777, 0.12784581718733534, 0.14871177409077063, 0.2369998733047396, 0.09833421834628098, 0.18194955540820956, 0.20192112046061084, 0.15765705815283582], [0.07303396618226543, 0.052598146939999424, 0.020803319639526308, 0.01592434990016045, 0.0427532091998728, 0.03493115451419726, 0.015144234876061091, 0.016638269989925902, 0.018081797315971926, 0.021727480889239814, 0.02082883282128023, 0.013282018444442656, 0.02683878738025669, 0.019696872077474836, 0.07422762166243047, 0.01561567398312036, 0.029295858366822358, 0.02421351233351743, 0.01218728197272867, 0.03643118339823559, 0.0198664546769578, 0.05150741621037014, 0.008579953519074479, 0.03885145313688554, 0.03731976052222308, 0.03801467792072799, 0.04185060548479669, 0.06240981048904359, 0.022362534800777212, 0.04251532860507723, 0.0319645379204303, 0.015932903152133804, 0.0741618376923725, 0.010888825036090566, 0.040158972624340095, 0.02637282439536648, 0.03713030877406709, 0.023364638254861347, 0.12625376199139282, 0.017768564612197224, 0.020399964232638013, 0.025148137865471654, 0.058070888626389205, 0.02163777007808676, 0.042497754548094235, 0.04292808145692106, 0.013645292310684454, 0.03474107194051612, 0.010594744380796328, 0.05129804521857295, 0.06868463198770769, 0.032180573398363777, 0.0019259225041423633, 0.03670249403512571, 0.07772947516059503, 0.19187836325727403, 0.42781007825396955, 10.314482878893614, 61.32954888045788, 73.97740960121155, 30.817851126194, 63.334347903728485, 77.1833735704422, 53.03679406642914, 46.09711244702339, 24.51419647783041, 22.3972749710083, 28.23160160332918, 19.548389241099358, 26.25495906919241, 30.937746092677116, 47.4050934612751, 57.49879203736782, 63.3316158503294, 75.77021420001984, 73.31552311778069, 109.5465561747551, 84.28056433796883, 97.81757354736328, 103.91353324055672, 124.45355907082558, 139.9562332034111, 116.96918427944183, 124.54774081707001, 124.2241881787777, 121.67797520756721, 98.24922278523445, 102.71671146154404, 82.72042885422707, 67.42604434490204, 75.34686371684074, 82.3450393974781, 68.86892572045326, 71.27161279320717, 76.06443241238594, 83.59970927238464, 102.0730260014534, 70.87869107723236, 44.902847930788994, 50.55390849709511, 32.332799434661865, 34.00578126311302, 27.980349585413933, 40.51702447235584, 55.80978646874428, 67.15115949511528, 82.94994413852692, 72.76926442980766, 82.68516674637794, 85.42811796069145, 92.37408444285393, 82.19344273209572, 48.34421306848526, 6.400753688067198, 0.21984193852404132, 0.1301023765699938, 0.05649349455779884, 0.006990378024056554, 0.059904883964918554, 0.00682148794112436, 0.01215589005369111, 0.14025949873030186, 0.07405321695841849, 0.06159009353723377, 0.031264440331142396, 0.08562505812733434, 0.07320661199628375, 0.030946767728892155, 0.028866566754004452, 0.058863209196715616, 0.014173861945891986, 0.09117949914070778, 0.08012613718165085, 0.018101347341143992, 0.037978294130880386, 0.017328471039945725, 0.049777225067373365, 0.023124505241867155, 0.036574462428689, 0.07032471155980602, 0.036080262580071576, 0.018333608022658154, 0.04593827325152233, 0.020285140999476425, 0.02090612193569541, 0.05081454713945277, 0.06939293030882254, 0.04918050122796558, 0.04563923597743269, 0.017557312276039738, 0.029982784690218978, 0.0560424765717471, 0.03365923956152983, 0.047231146454578266, 0.027971599738521036, 0.05520582009921782, 0.03442358487518504, 0.048648103038431145, 0.036582395987352356, 0.06916144702699967, 0.029645558352058288, 0.05846381129231304, 0.04669911562814377, 0.04501994713791646, 0.05341143689292949, 0.06660660365014337, 0.048376139311585575, 0.08987406879896298, 0.03337436617584899, 0.034296655358048156, 0.019475778863125015, 0.06981799539062195, 0.035724822082556784, 0.061802284690202214, 0.02286339356942335, 0.011208698106202064, 0.025839632107818034, 0.031368396666948684, 0.02900086579757044, 0.02970716217532754, 0.04055025885463692, 0.05994021019432694, 0.05273890637909062, 0.012636034552997444, 0.04543306364212185, 0.04821860733500216, 0.015723506185167935, 0.04324223998992238, 0.03337619185913354, 0.030372430774150416, 0.03293711873993743, 0.017820435168687254, 0.060538908146554604, 0.04827886601560749, 0.0222578975444776, 0.05031434331613127, 0.032298715887009166, 0.0964915101940278, 0.0509095086454181, 0.04897047343547456, 0.09467525960644707, 0.061576605003210716, 0.03857470626826398, 0.03732390541699715, 0.05750105279730633, 0.018134883139282465, 0.037335720408009365, 0.03325226061861031, 0.05836270851432346, 0.048886120930546895, 0.011309860256005777, 0.041620009069447406, 0.09343353522126563, 0.06265379895921797, 0.08662381078465842, 0.02636061421071645, 0.06745287464582361, 0.03116931184194982, 0.04577024359605275, 0.022046598824090324, 0.026202520057267975, 0.021713537789764814, 0.028067134553566575, 0.03552747017238289, 0.05225680724834092, 0.00730263155674038, 0.06116697288234718, 0.1024436458828859, 0.03713405290909577, 0.11211926263058558, 0.06441386154619977, 0.24527327623218298, 0.5663666746113449, 14.599036071449518, 74.28207725286484, 87.73175194859505, 38.55808138847351, 81.16771057248116, 99.90339562296867, 77.25832834839821, 72.01546087861061, 52.05100156366825, 49.10175561904907, 42.900036200881004, 36.25021442770958, 36.91936232149601, 37.022302597761154, 44.10598888993263, 28.950821310281754, 37.395761758089066, 45.284693241119385, 54.209996312856674, 71.624765843153, 59.32935141026974, 68.49369585514069, 68.22943523526192, 77.16933712363243, 83.46757516264915, 68.07460114359856, 58.835719898343086, 63.957035690546036, 59.34915974736214, 66.69194653630257, 54.52921338379383, 47.370864897966385, 50.98314866423607, 49.59401920437813, 50.75624763965607, 50.550880059599876, 56.23776510357857, 75.1199322938919, 55.49493156373501, 60.8758532255888, 64.88013535737991, 36.84535749256611, 39.663624465465546, 41.5508121997118, 42.5725431740284, 46.78220048546791, 60.72062775492668, 93.5550306737423, 100.43342158198357, 115.45370399951935, 87.76260629296303, 95.54540187120438, 98.39425340294838, 108.33679229021072, 97.4960196018219, 62.60543301701546, 9.989676307886839, 0.15441069641383365, 0.0984375030384399, 0.12102097520255484, 0.035117147854180075, 0.05343564203940332, 0.08413146366365254, 0.052369138720678166, 0.05428608019428793, 0.004804862119272002, 0.1104637686512433, 0.011336391107761301, 0.054818051648908295, 0.014872514202579623, 0.06640258725383319, 0.07220782223157585, 0.06940994033357129, 0.0025272375705753802, 0.01864440091594588, 0.06077125231968239, 0.017166363722935785, 0.05242707447905559, 0.0037615031396853738, 0.029118555576133076, 0.05823255065479316, 0.04641897714463994, 0.05839029043272603, 0.044305759874987416, 0.04342966938565951, 0.05628451319353189, 0.053427845778060146, 0.04623608598194551, 0.06101398656028323, 0.015335338830482215, 0.05641429997922387, 0.048124269233085215, 0.043253283147350885, 0.03625743178417906, 0.056509209534851834, 0.028869635534647387, 0.06575094448635355, 0.08414341224124655, 0.07831581635400653, 0.021136449322511908, 0.03835727184196003, 0.06931455951416865, 0.028066112245141994, 0.06593749072635546, 0.015526210863754386, 0.05712115853384603, 0.05853003684023861, 0.007013093309069518, 0.0494264934968669, 0.05428527125332039, 0.02853616631909972, 0.02915185017627664, 0.029915147206338588, 0.03018499024619814, 0.02368094901612494, 0.01269490634513204, 0.009024551927723223, 0.041716748019098304, 0.01179033037260524, 0.24171252589439973, 0.13171003171009943, 0.22366805118508637, 0.11120210168883204, 0.11047302323277108, 0.13351494970265776, 0.11777679537772201, 0.12960755702806637, 0.09280226440750994, 0.08828608799376525, 0.24475880461977795, 0.1303293847013265, 0.10689532966352999, 0.14961962850065902, 0.1381180464522913, 0.08626015100162476, 0.08919774219975807, 0.15909531066427007, 0.12019967005471699, 0.10926829490927048, 0.14474916562903672, 0.22318044531857595, 0.12978200626093894, 0.15430802770424634, 0.12127232577768154, 0.09269492758903652, 0.15764184412546456, 0.1522681606002152, 0.17633370909607038, 0.14809000276727602, 0.09565916931023821, 0.11410574705223553, 0.2839918329846114, 0.050459974954719655, 0.19038188183913007, 0.11955788300838321, 0.2320756937842816, 0.13872648880351335, 0.269994720001705, 0.1639519547461532, 0.18362577015068382, 0.09467002746532671, 0.14717255980940536, 0.12538147129816934, 0.08775136317126453, 0.09988993057049811, 0.09693052023067139, 0.11439908834290691, 0.12149984599091113, 0.2962537156417966, 0.24994298815727234, 0.16065542382420972, 0.09161732174106874, 0.40340232546441257, 0.25390127731952816, 0.4803454951616004, 1.1256938707083464, 20.64448792487383, 89.82316732406616, 100.52138686180115, 49.7117330878973, 88.84509980678558, 102.88476884365082, 78.00209283828735, 69.48934882879257, 41.58497616648674, 32.07208402454853, 46.115834042429924, 31.142184622585773, 41.52902416884899, 46.28109857439995, 67.7551218867302, 85.149205327034, 96.45803689956665, 109.22793567180634, 107.47079595923424, 158.03700059652328, 115.55366143584251, 132.11480677127838, 138.81842225790024, 168.18947821855545, 184.46613281965256, 157.44745463132858, 166.25585317611694, 168.64568173885345, 161.862832903862, 140.6859764456749, 137.7150222659111, 117.97461792826653, 99.61686059832573, 105.57068511843681, 112.09380269050598, 91.79932728409767, 97.89473980665207, 103.3425834774971, 112.15028285980225, 139.88766968250275, 99.62271228432655, 63.62118311226368, 70.19102677702904, 49.887690246105194, 51.518786922097206, 42.290795892477036, 58.77329304814339, 82.86180406808853, 91.73549830913544, 110.09077057242393, 95.11499136686325, 106.51905342936516, 107.83933818340302, 122.87706166505814, 114.30630996823311, 78.44961002469063, 13.691803403198719, 0.2605786471394822, 0.3831969987368211, 0.188557029759977, 0.07154829785577022, 0.15025587170384824, 0.19487404235405847, 0.16103976726299152, 0.1579290849622339, 0.2632286783773452, 0.16375439503462985, 0.11506093564094044, 0.2709652413614094, 0.3018984611844644, 0.15624782361555845, 0.13917545846197754, 0.10387660688138567, 0.1267640627338551, 0.17496921122074127, 0.23925405781483278, 0.136406653909944, 0.0955135450931266, 0.18782093800837174, 0.15002760192146525, 0.13138062204234302, 0.1996232382953167, 0.16361640009563416, 0.14940830937121063, 0.11181369074620306, 0.11791516139055602, 0.12291733321035281, 0.1917211912223138, 0.16083241120213643, 0.12395553843816742, 0.18511765025323257, 0.12470642861444503, 0.08832846462610178, 0.16430990741355345, 0.17006187845254317, 0.12100398002075963, 0.17548055096995085, 0.1423690831870772, 0.11752554128179327, 0.11858839323394932, 0.17025491106323898, 0.10660453393938951, 0.08054775869823061, 0.15859255014220253, 0.18014180241152644, 0.17211479251272976, 0.08094862976577133, 0.19183560070814565, 0.1005482229811605, 0.10340381428250112, 0.1729248763876967, 0.17590820614714175, 0.11041138786822557, 0.07526060959207825, 0.15879423619480804, 0.10403591630165465, 0.14350163022754714, 0.22151668381411582, 0.12740725243929774], [0.02422309717076132, 0.02221218866907293, 0.028126107463322114, 0.006731692246830789, 0.042983683160855435, 0.061303168113227, 0.06739528398611583, 0.07984076655702665, 0.04322546374169178, 0.06726125211571343, 0.028870058558823075, 0.07874159389757551, 0.018302267126273364, 0.01716673850751249, 0.09861238271696493, 0.06938073682249524, 0.016059689805842936, 0.061125906140659936, 0.054716262384317815, 0.04965719381289091, 0.02205585340561811, 0.0712064943218138, 0.018025113931798842, 0.05188807859667577, 0.01535355206215172, 0.04372712588519789, 0.01738621012918884, 0.019413698209973518, 0.05811007031297777, 0.043485746064106934, 0.04554748797090724, 0.02534907434892375, 0.044147404114482924, 0.06558990586199798, 0.043492276963661425, 0.02812245424138382, 0.06470497639384121, 0.020601282922143582, 0.010808497754624113, 0.051318636105861515, 0.044397507881512865, 0.01865918264229549, 0.04894714402325917, 0.0400049992458662, 0.0689262010564562, 0.041187752576661296, 0.045185627895989455, 0.04428306499903556, 0.07334419133258052, 0.055113036796683446, 0.065111851436086, 0.02755212117335759, 0.12157938937889412, 0.23825664102332667, 0.4560721601592377, 12.356528453528881, 44.9853491038084, 84.23464000225067, 90.3528892993927, 78.36419060826302, 24.702466875314713, 26.697468124330044, 26.586762964725494, 21.20044369250536, 21.73473872244358, 32.319268360733986, 48.79070430994034, 47.91385196149349, 67.89529636502266, 90.9442363679409, 110.43525248765945, 92.3737120628357, 91.11509799957275, 55.821968615055084, 40.19724503159523, 36.61988519132137, 34.06919606029987, 23.472828157246113, 51.7851260304451, 46.264151483774185, 43.68008114397526, 36.44571013748646, 47.726229429244995, 60.396197363734245, 71.22796833515167, 69.8648750782013, 59.79173339903355, 71.49831622838974, 84.18907284736633, 69.10711973905563, 72.4583575129509, 63.89716610312462, 96.23671397566795, 65.32959803938866, 46.71168766915798, 57.22706861793995, 47.89407782256603, 70.22446498274803, 95.16283079981804, 96.1955925822258, 80.77152103185654, 93.82605493068695, 90.38921535015106, 63.91741901636124, 27.138763144612312, 26.98090821504593, 24.323737397789955, 46.671292036771774, 55.70070192217827, 64.32314604520798, 67.80960336327553, 80.63455358147621, 91.98881551623344, 77.11736351251602, 26.211685091257095, 1.0141068021766841, 0.11551188683370128, 0.15609810274327174, 0.06451734661823139, 0.017090106193791144, 0.0690190882596653, 0.07221780411782674, 0.04414780116348993, 0.04414958231791388, 0.02569680207670899, 0.03557110103429295, 0.040296600200235844, 0.00803605482360581, 0.043621540535241365, 0.05547277061850764, 0.0025748804364411626, 0.04747128317831084, 0.014136684058030369, 0.04229000514897052, 0.038426009559771046, 0.006391427277776529, 0.07785178851918317, 0.048401190506410785, 0.0637680446379818, 0.030394140449061524, 0.05048872946645133, 0.018288891769771, 0.04040071238705423, 0.03533999995852355, 0.007224953278637258, 0.024453203768644016, 0.0021064769453005283, 0.07468896292266436, 0.028726011405524332, 0.07032981753582135, 0.03167071794450749, 0.03165379326674156, 0.053747707715956494, 0.05347706130123697, 0.014435012581088813, 0.035831101340590976, 0.05512031726539135, 0.023097448392945807, 0.03285606137069408, 0.014976233051129384, 0.055850501521490514, 0.02267390285851434, 0.057603112945798784, 0.01786919241567375, 0.04719605029094964, 0.019451942935120314, 0.06739494259818457, 0.07661871757591143, 0.04258848952304106, 0.044647541144513525, 0.07736479863524437, 0.030686288737342693, 0.027145116255269386, 0.04081444116309285, 0.050793254922609776, 0.04688328699558042, 0.023770695079292636, 0.024152145997504704, 0.024465491878800094, 0.03926787219825201, 0.03092523245868506, 0.022621739153692033, 0.05598329029453453, 0.067486738844309, 0.0382008048472926, 0.027715061551134568, 0.022248939822020475, 0.13216609630035236, 0.022943295043660328, 0.04261289504938759, 0.028825483313994482, 0.0442914215818746, 0.10071504293591715, 0.04027950853924267, 0.05665428456268273, 0.05374230859160889, 0.09201677530654706, 0.019413727895880584, 0.036660625773947686, 0.037570042404695414, 0.019751969120989088, 0.022403967050195206, 0.06864230730570853, 0.050018400797853246, 0.07868068583775312, 0.022783339954912663, 0.01572753975779051, 0.05925085148192011, 0.0650437297008466, 0.06676820630673319, 0.08161254023434594, 0.050388238960294984, 0.08268894380307756, 0.02566730912803905, 0.038891466028871946, 0.012197481864859583, 0.07140583518776111, 0.05707139382138848, 0.09993250758270733, 0.0748434335400816, 0.036763825119123794, 0.015266728205460822, 0.011632085934252245, 0.008069447758316528, 0.03210157548892312, 0.11426715675042942, 0.018516705131332856, 0.051912220660597086, 0.03759699349757284, 0.3699798829620704, 0.9885379741899669, 17.312655709683895, 56.88020043075085, 99.61942166090012, 98.85933324694633, 89.9867333471775, 49.59732502698898, 41.44877627491951, 50.731035992503166, 33.39754410088062, 29.518543146550655, 27.69326739013195, 28.62431813031435, 31.929097697138786, 31.836331374943256, 49.560934379696846, 60.25102615356445, 67.25115492939949, 73.53496134281158, 52.66688011586666, 43.50065477192402, 37.720933109521866, 32.34710946679115, 25.50934787839651, 41.68231174349785, 38.53576518595219, 34.35143731534481, 36.56383439898491, 40.583209320902824, 46.81457094848156, 46.63984872400761, 49.98208858072758, 41.22274920344353, 54.5257593691349, 58.2443006336689, 52.54619099199772, 51.68986514210701, 50.84555424749851, 51.95507951080799, 45.19576281309128, 35.65325126051903, 38.559483513236046, 40.97038954496384, 46.06449879705906, 65.44748291373253, 75.26017516851425, 64.10301625728607, 71.51654005050659, 54.74667951464653, 49.05189469456673, 31.92810595035553, 38.374798223376274, 40.233042910695076, 76.36270880699158, 86.82277232408524, 81.02164641022682, 77.41817817091942, 90.61729431152344, 105.64912810921669, 91.75907984375954, 39.981857389211655, 3.075354052707553, 0.11349218388204463, 0.2211931222700514, 0.05983223883958999, 0.0038826865784358233, 0.15017043566331267, 0.048033311613835394, 0.03282842008047737, 0.021658377663698047, 0.06195192763698287, 0.032953854170045815, 0.04276038205716759, 0.027205239493923727, 0.062071598949842155, 0.039330654180957936, 0.10635378450388089, 0.03703602633322589, 0.03639669579570182, 0.013016091161262011, 0.04494372115004808, 0.03473635559203103, 0.06647739573963918, 0.027875293089891784, 0.05936011046287604, 0.04262323687726166, 0.014470725654973648, 0.04728192790935282, 0.08865046766004525, 0.04912806107313372, 0.08654249366372824, 0.06786409125197679, 0.014559079263563035, 0.028013070950692054, 0.028369283281790558, 0.026435511754243635, 0.04618871840648353, 0.07993112303665839, 0.025891190962283872, 0.07046865852316841, 0.03410388992051594, 0.06498248767456971, 0.004984639972462901, 0.059020574190071784, 0.0503821273741778, 0.030885334599588532, 0.021316212332749274, 0.0325256498035742, 0.043412648228695616, 0.03514075557177421, 0.018500303667678963, 0.026378865477454383, 0.07137748514651321, 0.019665356776386034, 0.0008300301374219998, 0.01982224865059834, 0.0803027831716463, 0.020125824157730676, 0.09816942445468158, 0.10400027837022208, 0.0029335386079765158, 0.025262988929171115, 0.15115107991732657, 0.08418116529355757, 0.10438153447466902, 0.11543098531547002, 0.10422040679259226, 0.1249518568511121, 0.12925951945362613, 0.28383550699800253, 0.24584947968833148, 0.08226422753068618, 0.11400183895602822, 0.30154546606354415, 0.19109671848127618, 0.21713528141845018, 0.20465911104111, 0.1338308077538386, 0.19782470277277753, 0.16078817920060828, 0.17378474352881312, 0.114319923450239, 0.1966628705849871, 0.15508363139815629, 0.10001799557358027, 0.14381413377122954, 0.08016928564757109, 0.1307394658215344, 0.18085132527630776, 0.19861160195432603, 0.10341370711103082, 0.1413761786534451, 0.1616445285617374, 0.10631696655764244, 0.164388797711581, 0.18101008550729603, 0.13411364023340866, 0.14823454344877973, 0.18872448796173558, 0.13607893633889034, 0.1768447519862093, 0.15923177677905187, 0.18362415226874873, 0.0993612023012247, 0.20869866537395865, 0.15446744102519006, 0.11416966823162511, 0.14539968775352463, 0.10466554696904495, 0.12934215017594397, 0.1452690252335742, 0.18266869650688022, 0.14425572648178786, 0.13894588249968365, 0.14796922565437853, 0.7597456604707986, 1.0759229538962245, 20.439823307096958, 67.70171195268631, 113.59897032380104, 108.43245595693588, 102.12923258543015, 46.90034754574299, 41.36569373309612, 40.613961070775986, 35.84575653076172, 31.999549716711044, 50.005445927381516, 72.38768130540848, 77.49097466468811, 99.59378063678741, 128.99376064538956, 157.33364313840866, 136.3906565308571, 132.69679874181747, 83.73694270849228, 58.972371965646744, 58.89162249863148, 50.51392704248428, 36.16059623658657, 72.97447621822357, 66.0311695933342, 64.56561103463173, 55.79386152327061, 70.1395471394062, 92.1858349442482, 106.2696424126625, 101.79910629987717, 87.06762358546257, 104.30610537528992, 122.87076160311699, 99.89499807357788, 104.79804217815399, 89.25572857260704, 136.05948150157928, 93.66382643580437, 63.77491906285286, 82.05045640468597, 65.20998045802116, 96.20723515748978, 136.13721013069153, 131.0703644156456, 118.06259840726852, 128.5135120153427, 133.01449209451675, 93.05056974291801, 43.18253964185715, 42.453784346580505, 37.27862164378166, 67.5202564895153, 79.60255175828934, 90.48484861850739, 89.66783165931702, 104.42358747124672, 114.6422727406025, 110.8301804959774, 48.27536456286907, 4.191438714042306, 0.19439550553215668, 0.368758782860823, 0.21509033802431077, 0.09693455009255558, 0.30731058795936406, 0.11879313693498261, 0.08337393126566894, 0.1988256225013174, 0.19763940334087238, 0.07673686748603359, 0.11969002240221016, 0.1382584756356664, 0.14279596653068438, 0.14218920143321157, 0.14524787402478978, 0.26689453166909516, 0.12268010570551269, 0.0884045496059116, 0.09808260801946744, 0.15479705849429592, 0.18698590312851593, 0.16624167328700423, 0.18699736188864335, 0.22243623447138816, 0.10125158602022566, 0.1440653804456815, 0.18442881846567616, 0.12207305859192275, 0.1066621691279579, 0.15250785945681855, 0.12268558275536634, 0.23540833761217073, 0.10332513178582303, 0.1667292494676076, 0.1858189352788031, 0.24291952518979087, 0.1436756638577208, 0.1909029734088108, 0.07847362663596869, 0.11917108306079172, 0.07449300625012256, 0.1481610708287917, 0.20615648303646594, 0.1498324764543213, 0.16741114959586412, 0.16006742022000253, 0.15719358692876995, 0.08039742926484905, 0.21410509245470166, 0.09019780103699304, 0.1841546394280158, 0.17282609653193504, 0.11671954664052464, 0.12054940714733675, 0.1477074553258717, 0.08769968000706285, 0.1499734993558377, 0.22737794351996854, 0.07949051738251, 0.14770577807212248], [0.01723843739455333, 0.00583299222853384, 0.030053980772208888, 0.022593095964111853, 0.06934197444934398, 0.035734796547330916, 0.03749858842638787, 0.049549125978956, 0.08591308564064093, 0.04096497468708549, 0.052711357857333496, 0.0436468514817534, 0.01516969332442386, 0.02279484881000826, 0.07373347747488879, 0.031204296683426946, 0.005032013114032452, 0.09192063007503748, 0.050964861729880795, 0.04069186805281788, 0.01702241675957339, 0.04628992508514784, 0.03994917118689045, 0.048252694177790545, 0.056208120222436264, 0.01211698203405831, 0.031191605958156288, 0.02261387424368877, 0.048205816419795156, 0.06553183280630037, 0.11168492812430486, 0.015145917695917888, 0.08055201862589456, 0.03300153344753198, 0.04944259439071175, 0.040774658336886205, 0.05300576412992086, 0.057591212607803755, 0.049285303612123244, 0.06160924836876802, 0.05820990772917867, 0.015254393711074954, 0.05691358725016471, 0.016957258048933, 0.05011800072679762, 0.06948218840989284, 0.07843446350307204, 0.07088368976837955, 0.07437910884618759, 0.011735110874724342, 0.1929308325634338, 0.10466217019711621, 0.48009236343204975, 11.929000094532967, 47.67613671720028, 75.26449173688889, 85.01682803034782, 79.15868237614632, 73.27153667807579, 45.40282890200615, 19.794718623161316, 36.77155405282974, 56.065512746572495, 57.852059081196785, 71.09531745314598, 78.83043318986893, 96.22995793819427, 64.03905808925629, 71.46888300776482, 52.182299718260765, 29.26959380507469, 17.013547159731388, 2.3374269995838404, 0.6972662662155926, 0.03971481950429734, 0.04629185095836874, 0.1156399147293996, 0.06687030356260948, 0.1522010110784322, 0.07462390625732951, 0.1356049266178161, 0.11195438710274175, 0.1241819528513588, 0.11796579812653363, 0.07457024898030795, 0.031024214549688622, 0.1811461805482395, 0.13024285028222948, 0.05651998922985513, 0.029559176073234994, 0.11697727968567051, 0.39357358880806714, 0.49649234279058874, 0.4028440226102248, 0.9087493212427944, 0.4319949302589521, 0.377356504322961, 1.2288892082870007, 0.313220844254829, 0.9587552316952497, 6.147090224549174, 18.673020713031292, 29.964382722973824, 57.91882909834385, 98.57385456562042, 94.0157787501812, 67.03212708234787, 28.552805967628956, 21.6200627759099, 30.456688106060028, 57.942399233579636, 70.9419196844101, 78.59543859958649, 76.74185246229172, 76.8812669813633, 59.11343179643154, 19.60289541631937, 2.532719657756388, 0.22741674300050363, 0.06460900185629725, 0.03359094342158642, 0.03299190408142749, 0.023411848123942036, 0.008519129878550302, 0.009270871669286862, 0.08832729945424944, 0.0849212943285238, 0.03166224261804018, 0.02036344685620861, 0.019131589324388187, 0.049997572423308156, 0.04593413577822503, 0.01829679007641971, 0.0872443946718704, 0.020149277879681904, 0.006176291653900989, 0.07061357769998722, 0.02086540771415457, 0.019997866766061634, 0.0628285227867309, 0.02421159944788087, 0.031476431104238145, 0.046441304657491855, 0.025829579717537854, 0.01854705340520013, 0.017460374801885337, 0.037211989547358826, 0.059206767909927294, 0.01729141004034318, 0.030223040157579817, 0.02532291920942953, 0.08949356226366945, 0.012946732822456397, 0.09208653718815185, 0.06483096338342875, 0.026004335086327046, 0.018831494489859324, 0.013279553586471593, 0.020309388819441665, 0.009247328889614437, 0.010014703093474964, 0.027914727106690407, 0.038499107395182364, 0.032089122250908986, 0.025808615901041776, 0.026722878756118007, 0.08722621947526932, 0.0509491912816884, 0.0700525140564423, 0.015570007781207096, 0.01112957310397178, 0.03396141983103007, 0.061972392359166406, 0.03004776343004778, 0.055989899119595066, 0.015608092944603413, 0.011620407312875614, 0.028961322313989513, 0.03904658602550626, 0.060356157991918735, 0.022313308145385236, 0.05560970057558734, 0.017961795747396536, 0.07884798076702282, 0.04555485378659796, 0.029327540651138406, 0.06607099567190744, 0.022220688115339726, 0.03979668952524662, 0.0395649947313359, 0.07012251342530362, 0.014318121538963169, 0.03786869747273158, 0.02992654659465188, 0.01874735164165031, 0.031212397225317545, 0.07909895284683444, 0.04547377044218592, 0.02702362853597151, 0.007179287076723995, 0.04403626749990508, 0.019342053128639236, 0.060741202760254964, 0.029194775997893885, 0.046031609454075806, 0.0321741278457921, 0.03404350507480558, 0.04605012603860814, 0.01564514466736, 0.04269291712262202, 0.023384216110571288, 0.017841690278146416, 0.04706735817308072, 0.038232353545026854, 0.015788288255862426, 0.03547547530615702, 0.05067488978966139, 0.014400645577552496, 0.019968483284174, 0.03204779204679653, 0.023662124440306798, 0.09436248146812432, 0.030677015602122992, 0.09016123542096466, 0.014221229521353962, 0.039340821604127996, 0.08114489071886055, 0.15077565709361807, 1.0631029168143868, 18.30733023583889, 61.89957149326801, 87.8639468550682, 96.53264209628105, 95.11205792427063, 93.66995170712471, 66.75589710474014, 33.063131645321846, 34.348139092326164, 31.79832011461258, 36.36010453104973, 41.8721267580986, 52.493586614727974, 68.9116658270359, 61.478721275925636, 63.7260726839304, 55.085815116763115, 34.616636484861374, 20.745285116136074, 4.600850120186806, 1.6449229465797544, 0.2513591246679425, 0.2698693861020729, 0.0952669294201769, 0.03335246168717276, 0.1360182138159871, 0.10183627222431824, 0.11759391534724273, 0.13463464274536818, 0.07160920591559261, 0.01215465066707111, 0.25339804182294756, 0.04983079699741211, 0.15629371802788228, 0.07711630532867275, 0.20707598916487768, 0.2619052509544417, 0.34145018260460347, 0.38354571908712387, 0.846774528035894, 0.5159934307448566, 0.6618463480845094, 0.05038797178713139, 0.2647330710897222, 1.4458772772923112, 1.0056025022640824, 2.7188267838209867, 8.898125030100346, 21.764627918601036, 39.148957282304764, 59.665591567754745, 72.66873702406883, 62.27016940712929, 44.754112511873245, 37.44406096637249, 36.11009694635868, 53.74357894062996, 87.58574098348618, 96.69687688350677, 95.7864761352539, 95.78250914812088, 89.29766312241554, 76.56555712223053, 31.33291158825159, 6.1623739544302225, 0.10657990205800161, 0.2994646324077621, 0.06274540224694647, 0.06263338989811018, 0.0038429707774412236, 0.00822328198410105, 0.04144892547628842, 0.04205775374430232, 0.13566073612309992, 0.04212505911709741, 0.03691048092150595, 0.05146855364728253, 0.09507648690487258, 0.05960584298009053, 0.03912257081537973, 0.11429243430029601, 0.03372836690687109, 0.07135136896977201, 0.02641053662955528, 0.034778602348524146, 0.06115411888458766, 0.04962772683938965, 0.00433715740655316, 0.05489312359713949, 0.054901665716897696, 0.022488963368232362, 0.0237838719112915, 0.055762104311725125, 0.027538011090655345, 0.08335217149578966, 0.05458191139041446, 0.03295789887488354, 0.013124467914167326, 0.07473644553101622, 0.008315470640809508, 0.08978976824437268, 0.06521019342471845, 0.03375844986294396, 0.029439499194268137, 0.0689062372839544, 0.03574269670934882, 0.04252477243426256, 0.009933184664987493, 0.057582091612857766, 0.035381756897550076, 0.04490788283874281, 0.03927086676412728, 0.037979774715495296, 0.048080627238960005, 0.043979136971756816, 0.05381221148127224, 0.04183339508017525, 0.011048105698137078, 0.02909392183937598, 0.09241522697266191, 0.053242947105900384, 0.045926317252451554, 0.029641318833455443, 0.10727855988079682, 0.09607856438378803, 0.07752137695206329, 0.16826378821861, 0.2691359363961965, 0.1768933775019832, 0.14896299107931554, 0.13253613113192841, 0.20374217274365947, 0.11210360331460834, 0.1589319936465472, 0.10656508879037574, 0.10703555846703239, 0.10692599520552903, 0.16831659944728017, 0.11188961987500079, 0.14431112038437277, 0.1381198869785294, 0.1306945362011902, 0.12857809429988265, 0.13469465280650184, 0.17457481910241768, 0.09864234321867116, 0.2171810867730528, 0.17214186605997384, 0.1070523532689549, 0.1365030143642798, 0.09533698816085234, 0.16150224400917068, 0.1718469662591815, 0.22014219663105905, 0.12223194498801604, 0.14772109600016847, 0.14199227996869013, 0.14351442485349253, 0.15265919821104035, 0.1514945161761716, 0.14984280714998022, 0.09822632491705008, 0.17824803449911997, 0.26908092841040343, 0.08469080552458763, 0.1507136135478504, 0.18511417700210586, 0.10102858548634686, 0.31518999952822924, 0.23757043643854558, 0.269732415326871, 0.12565134587930515, 0.13403287972323596, 0.20833654183661565, 0.11236826801905409, 1.1849636840634048, 21.421301141381264, 72.62339785695076, 102.81010285019875, 107.8836590051651, 97.93139263987541, 93.76990154385567, 63.53152312338352, 30.95516435801983, 56.67869724333286, 76.97617068886757, 85.7358406484127, 102.948377430439, 114.06949907541275, 144.1189706325531, 91.47327437996864, 102.59490519762039, 79.36570286750793, 44.61004704236984, 28.475293926894665, 4.719642670825124, 1.573582487180829, 0.49471724429167807, 0.7257332105655223, 0.4001317697111517, 0.28575808508321643, 0.43339758936781436, 0.20313045009970665, 0.5254320648964494, 0.8810566447209567, 0.7311248243786395, 0.26932114677038044, 0.4379160812823102, 0.20332829182734713, 0.7898482389282435, 0.4998608026653528, 0.6541443394962698, 0.4844445252092555, 0.8109834173228592, 0.9134154708590358, 1.3232709188014269, 0.9097478364128619, 2.89937908295542, 1.3897967990487814, 1.1247714702039957, 3.6134868767112494, 1.2911873403936625, 2.851694729179144, 11.35464571416378, 29.807183258235455, 47.172606736421585, 83.8851423561573, 143.19976955652237, 132.00426310300827, 96.87468454241753, 40.64409725368023, 34.988689720630646, 48.06873545050621, 79.35054168105125, 92.17996805906296, 100.99851965904236, 98.19749996066093, 100.51416724920273, 92.35141485929489, 39.17452231049538, 6.794870439916849, 0.15018582780612633, 0.4325859766686335, 0.20878767856629565, 0.11403963653719984, 0.18653144157724455, 0.09827274625422433, 0.14138692495180294, 0.16956110688624904, 0.2791976777371019, 0.17312761629000306, 0.13139936869265512, 0.08422397237154655, 0.21997549541993067, 0.1652494812151417, 0.1312847514054738, 0.2174445046694018, 0.07582573278341442, 0.22657174849882722, 0.1362083075218834, 0.1415084590553306, 0.07808480062521994, 0.17676553514320403, 0.1482503957231529, 0.13505579670891166, 0.1406418828992173, 0.08372672600671649, 0.10659284511348233, 0.1268678595079109, 0.11772693789680488, 0.174106924678199, 0.10251011262880638, 0.09033730253577232, 0.17040096572600305, 0.14773194619920105, 0.05751244105340447, 0.14506871957564726, 0.14163101732265204, 0.17806663876399398, 0.1146585209062323, 0.16526347812032327, 0.1452823096769862, 0.21799856243887916, 0.14528849918860942, 0.12021987873595208, 0.13683871744433418, 0.09613639253075235, 0.09855814656475559, 0.15165887220064178, 0.15161959774559364, 0.15540784603217617, 0.09927841572789475, 0.27021124900784343, 0.11197567931958474, 0.16531958448467776, 0.21132092544576153, 0.11626531515503302, 0.14562872936949134, 0.1188768215070013], [0.06455404582084157, 0.006217923355507082, 0.03602319513447583, 0.031411615636898205, 0.0502024385787081, 0.03874909241858404, 0.06271915248362347, 0.05430195102235302, 0.02213253581430763, 0.0698157244187314, 0.05459357053041458, 0.03450975193118211, 0.07471145741874352, 0.014236907391023124, 0.09640760297770612, 0.019071939204877708, 0.0800892524421215, 0.04400407684443053, 0.05140745633980259, 0.06180426251376048, 0.023834866733523086, 0.00442160175225581, 0.03614233581174631, 0.01646585609705653, 0.061088576112524606, 0.042874145874520764, 0.014882330033287872, 0.00542398536708788, 0.1938892569160089, 0.005567357166000875, 0.05692745056876447, 0.03862411846057512, 0.022983294948062394, 0.020680408852058463, 0.02875232239603065, 0.07997580032679252, 0.03966041636886075, 0.009366503891214961, 0.07367644342593849, 0.06570029290742241, 0.015679511670896318, 0.055450929212383926, 0.07898531519458629, 0.0780232840043027, 0.028467773699958343, 0.08587659423938021, 0.05574360257014632, 0.0247479384415783, 0.08455964576569386, 0.2234781059087254, 2.415974484756589, 20.890627317130566, 50.856129080057144, 74.90104123950005, 67.81926244497299, 75.66193521022797, 65.20121052861214, 32.00043886899948, 34.168644323945045, 37.19691462814808, 64.06302720308304, 38.621302396059036, 63.900730311870575, 52.66560338437557, 39.832992777228355, 37.5849612057209, 18.291904963552952, 6.031125672161579, 1.6170688974671066, 0.3609507955843583, 0.17997198418015614, 0.18499874335248023, 0.062127222918206826, 0.0044358403192745754, 0.12070200755260885, 0.15691154112573713, 0.0693724247685168, 0.11413446816732176, 0.14904376643244177, 0.08826892953948118, 0.09084378863917664, 0.14246498350985348, 0.18716885737376288, 0.36158034461550415, 0.13685042853467166, 0.40193777123931795, 0.07507492424338125, 0.1738082992960699, 0.1327692694030702, 0.19666330103063956, 0.10694145414163359, 0.24271607282571495, 0.10956302401609719, 0.13471089099766687, 0.041166178343701176, 0.2028930964297615, 0.09557244935422204, 0.015369537923106691, 0.17037616315064952, 0.18852685403544456, 0.10769404383609071, 0.36968014435842633, 0.3537010814761743, 0.1981438708025962, 3.7570780841633677, 26.629210487008095, 58.94716031849384, 105.32618343830109, 78.12716692686081, 29.720969684422016, 16.576200127601624, 22.5570297986269, 51.91919803619385, 47.68963359296322, 67.97356456518173, 71.15380391478539, 77.85562589764595, 60.62510848045349, 24.60266713052988, 1.8179294443689287, 0.34997834998648614, 0.10462225007358938, 0.035374272338231094, 0.05329308289219625, 0.09654672598117031, 0.06710415429552086, 0.041519114092807285, 0.08569425597670488, 0.0331582453509327, 0.025525230521452613, 0.08734088129131123, 0.01978821375814732, 0.04067607886099722, 0.0351025794952875, 0.05601320255664177, 0.03432145793340169, 0.023633559176232666, 0.00503309804116725, 0.06743022429873236, 0.004962794391758507, 0.050341980895609595, 0.05308691797836218, 0.017259160013054498, 0.02720198146562325, 0.030388166160264518, 0.0238950178027153, 0.07188752613728866, 0.06569350967765786, 0.06227441306691617, 0.04055653371324297, 0.021918314887443557, 0.015324624073400628, 0.022240047037485056, 0.030104311372269876, 0.02450002772093285, 0.01627576053579105, 0.04244213800120633, 0.02577492796262959, 0.036225441508577205, 0.021930979637545533, 0.02024257326411316, 0.052119046085863374, 0.03380141279194504, 0.036567912975442596, 0.10356185463024303, 0.04279294749721885, 0.04040413368784357, 0.01309898441832047, 0.024789339149720035, 0.020174503479211126, 0.07340063908486627, 0.007733128231848241, 0.024702227710804436, 0.07928569204523228, 0.03652282008260954, 0.043783966975752264, 0.008560707774449838, 0.037811195870744996, 0.019571488082874566, 0.0028247385989743634, 0.03533206268912181, 0.013532802204281325, 0.0477752520237118, 0.050368672236800194, 0.037535213414230384, 0.03815673240751494, 0.03707851057697553, 0.03096236952842446, 0.006236195031306124, 0.027703790183295496, 0.07546324559370987, 0.06567002070369199, 0.03547892258211505, 0.03119679728115443, 0.0303370674373582, 0.03113639759249054, 0.04426991785294376, 0.029696851888729725, 0.06738598487572744, 0.0031148895823207567, 0.07285798812517896, 0.08681759296450764, 0.010585745840216987, 0.012555043049360393, 0.10300334397470579, 0.03091656788456021, 0.10519143281271681, 0.01681261717749294, 0.03902239572198596, 0.02619067166961031, 0.018867089747800492, 0.12266881021787412, 0.042284108785679564, 0.04208771795674693, 0.03571244305931032, 0.06590211254660971, 0.053592684198520146, 0.03592240776924882, 0.06299857108388096, 0.16535862145246938, 0.030031749738554936, 0.03968848439399153, 0.12370795797323808, 0.04678561665059533, 0.05235053307842463, 0.12270185063243844, 4.083239044994116, 28.068102076649666, 64.38768938183784, 85.12968197464943, 84.41760778427124, 90.36941841244698, 84.74508181214333, 64.4686858355999, 51.68528638780117, 43.69634427130222, 42.32498645782471, 36.42866425216198, 51.56961679458618, 52.26244881749153, 51.13154590129852, 43.85250449180603, 26.41905516386032, 10.517753921449184, 4.312255131080747, 1.1144493240863085, 0.08147329848725349, 0.07466393770300783, 0.21215318469330668, 0.055837614127085544, 0.05043417048000265, 0.16225366853177547, 0.12635600025532767, 0.10442052691360004, 0.06760295917047188, 0.11814847777714022, 0.056258430413436145, 0.11236995269428007, 0.2035562350647524, 0.12688541872194037, 0.39840980898588896, 0.6991817196831107, 0.6281239888630807, 1.0198492440395057, 0.31927745207212865, 0.1346224418375641, 0.09043162950547412, 0.03694949562486727, 0.07754310703603551, 0.10623495923937298, 0.09659123257733881, 0.09087966405786574, 0.15876665798714384, 0.04323063651099801, 0.14706150483107194, 0.12170588102890179, 0.26865585590712726, 0.25994455616455525, 0.30610756657551974, 0.7975658623035997, 7.115636877715588, 31.568181663751602, 59.55756336450577, 69.2393146455288, 48.29621024429798, 35.00654116272926, 33.591542690992355, 45.429818853735924, 80.42967617511749, 63.59380558133125, 84.5965401828289, 86.23339354991913, 94.0534195303917, 81.87609136104584, 40.68399891257286, 5.781752178445458, 0.06215952860657126, 0.10441680133226328, 0.05393539686338045, 0.01565191305417102, 0.08090337360044941, 0.02477211946825264, 0.11507242408697493, 0.019115519971819595, 0.02144510483049089, 0.024007985666685272, 0.030768746910325717, 0.018282791315868963, 0.02869985441066092, 0.015118549144972349, 0.006120298467067187, 0.015576562800561078, 0.02720174212299753, 0.03606425074394792, 0.018160279432777315, 0.07584387087263167, 0.038471544030471705, 0.05075881927041337, 0.03805243097303901, 0.05707385404093657, 0.07115956090274267, 0.03610470150306355, 0.007682973891860456, 0.021135926108399872, 0.09305810497608036, 0.06457184252212755, 0.02873074816307053, 0.023573090838908684, 0.018525538544054143, 0.04299690081097651, 0.038282400273601525, 0.04640276121790521, 0.029798769173794426, 0.04856810322962701, 0.057484877688693814, 0.05693460116162896, 0.07711884347372688, 0.08258143629063852, 0.031470130270463414, 0.02523426966945408, 0.017361520731355995, 0.033704332454362884, 0.09370059706270695, 0.06918791201314889, 0.046342691784957424, 0.05867531966941897, 0.008329860884259688, 0.015086963339854265, 0.07502067324821837, 0.04296839491871651, 0.027769043517764658, 0.06158830125059467, 0.09360100826597773, 0.07810918759787455, 0.06999781777267344, 0.08098624923150055, 0.20297672162996605, 0.12859056238085032, 0.14759620738914236, 0.19985726714367047, 0.1451732436544262, 0.10417008918011561, 0.1957181908073835, 0.14441053848713636, 0.1524623212753795, 0.12031439124257304, 0.14856377500109375, 0.16855524445418268, 0.2844944450771436, 0.15719211747637019, 0.18100181798217818, 0.09227634887793101, 0.1888216647785157, 0.10064760397654027, 0.15152026870055124, 0.12869130150647834, 0.1670969687984325, 0.1177140987419989, 0.12667501985561103, 0.16362410358851776, 0.30122280993964523, 0.12622541195014492, 0.2146532278857194, 0.10360439453506842, 0.1014287218276877, 0.09829166359850205, 0.12140132588683628, 0.2185997911146842, 0.09170488032395951, 0.1384924302692525, 0.18201953993411735, 0.11526996895554475, 0.17284364090301096, 0.13949712010798976, 0.17748173733707517, 0.2376518797245808, 0.1953123399289325, 0.10289418889442459, 0.20705975097371265, 0.1063361881824676, 0.19405117869609967, 0.3203652921365574, 6.204029219225049, 32.79465325176716, 77.33425587415695, 102.18762025237083, 93.31207171082497, 94.09566566348076, 83.64262416958809, 44.706862047314644, 48.344346061348915, 53.82443480193615, 91.13959148526192, 62.438910752534866, 89.71174970269203, 75.6022860109806, 63.81958946585655, 59.981407821178436, 29.090745002031326, 12.145823109894991, 3.887040135450661, 1.0962252644822001, 0.30774756451137364, 0.6890093092806637, 0.2798149368027225, 0.39980314671993256, 0.2954665047582239, 0.4283617017790675, 0.26164986309595406, 0.4284943384118378, 0.37054839776828885, 0.42915897618513554, 0.2698391955345869, 0.472599373315461, 0.41200978390406817, 0.7606400968506932, 0.5095484422054142, 0.9244679496623576, 0.7842826656997204, 1.5533427544869483, 0.7145755842793733, 0.6764066917821765, 0.28900168603286147, 0.4378459037980065, 0.4005247220629826, 0.4365984722971916, 0.27987736626528203, 0.5187713785562664, 0.4062073171371594, 0.13041637925198302, 0.45658412331249565, 0.5390979128424078, 0.30865538923535496, 0.45839903061278164, 0.5368926061782986, 0.8778372674714774, 6.394737660884857, 42.81905114650726, 83.38420003652573, 152.69258737564087, 114.23976793885231, 46.98612794280052, 24.9440199136734, 35.813492462038994, 67.5079907476902, 66.9049023091793, 90.6864657998085, 92.33426257967949, 105.46895697712898, 94.95099976658821, 46.466190442442894, 5.41495026089251, 0.43105744931381196, 0.25179535907227546, 0.1545731525402516, 0.15860607207287103, 0.27855984633788466, 0.07040524200419895, 0.26399427792057395, 0.1999466959387064, 0.1261215261183679, 0.10279653710313141, 0.2227063910686411, 0.12575061555253342, 0.09639882337069139, 0.16183279658434913, 0.15200707304757088, 0.18434255121974275, 0.1387981208972633, 0.08388767557335086, 0.1805143160163425, 0.12126949077355675, 0.12326312949880958, 0.1836282340809703, 0.08548095531295985, 0.10470332228578627, 0.22199361759703606, 0.127928136207629, 0.1041371155588422, 0.16712730779545382, 0.19166253186995164, 0.17150339641375467, 0.10631422061123885, 0.2179113749298267, 0.10430039546918124, 0.18186440138379112, 0.10904531663982198, 0.14916421700036153, 0.13219547050539404, 0.11956754577113315, 0.1279485155828297, 0.1292825408745557, 0.2227120759198442, 0.13743951567448676, 0.10635802958859131, 0.18399350432446226, 0.20785660977708176, 0.11577197248698212, 0.16800042969407514, 0.21148265426745638, 0.13896103715524077, 0.11281614672043361, 0.1663825032301247, 0.09325628067017533, 0.22280395380221307, 0.1784027277608402, 0.12994821765460074, 0.13438968948321417], [0.08031025659875013, 0.03912267100531608, 0.026989319048880134, 0.03703100199345499, 0.02395221141341608, 0.034548777766758576, 0.04576976120006293, 0.027711801667464897, 0.048735490927356295, 0.052072914186283015, 0.06268381141126156, 0.06223805154149886, 0.017685295642877463, 0.06044330097211059, 0.024709088866075035, 0.021733577632403467, 0.039796073542675, 0.026299182936782017, 0.06042633547622245, 0.038125929568195716, 0.04586760594975203, 0.03207038673281204, 0.046653202662128024, 0.0050140002622356405, 0.07772889628540725, 0.02661590373463696, 0.0034617269648151705, 0.0901460881868843, 0.06654837474343367, 0.05953112726274412, 0.03330594387080055, 0.060901001997990534, 0.02788643272651825, 0.02098186181683559, 0.04344964800111484, 0.04654824442695826, 0.049912258837139234, 0.057412054447922856, 0.0036013601948070573, 0.03994923798018135, 0.04439597905729897, 0.026302329642931, 0.126220261445269, 0.048707638125051744, 0.01610872906894656, 0.017229377626790665, 0.10356147613492794, 0.40100913669448346, 1.178133194334805, 25.881710797548294, 66.9763232767582, 85.94462424516678, 81.36293649673462, 75.65250411629677, 44.04813699424267, 37.917887941002846, 29.09358724951744, 40.995137616992, 47.09757596254349, 55.192817375063896, 53.115229457616806, 31.163624972105026, 22.864028625190258, 11.833092290908098, 3.7255979608744383, 0.4878288373583928, 0.19271390279754996, 0.1582789036910981, 0.27000552567187697, 0.06647574817179702, 0.11882121238159016, 0.059190106694586575, 0.09287398555898108, 0.01998502204514807, 0.020172195399936754, 0.0792551007180009, 0.1270491216564551, 0.05854094270034693, 0.031151837974903174, 0.04839217341213953, 0.12341329565970227, 0.004277152911527082, 0.04765731362567749, 0.15027616202132776, 0.08041587905609049, 0.309806460281834, 0.14138898812234402, 0.8938663511071354, 0.17698911455227062, 0.09842881248914637, 0.1810573454713449, 0.08886975003406405, 0.04354171142040286, 0.06914342768141069, 0.1416347429039888, 0.15688115759985521, 0.026376804162282497, 0.07312493864446878, 0.03643742857093457, 0.08686033324920572, 0.008506954945914913, 0.20300645206589252, 0.3103670192649588, 0.08774111411185004, 0.05696963795344345, 0.1122300504357554, 1.8389749713242054, 19.40335862338543, 53.72344762086868, 97.43602842092514, 87.59320378303528, 44.90570917725563, 16.430962421000004, 29.81703232973814, 33.46633940935135, 62.249673306941986, 79.86832469701767, 67.98361882567406, 76.92443266510963, 57.47895710170269, 20.53263522684574, 1.0195990512147546, 0.1734615975874476, 0.10610497207380831, 0.026948940649162978, 0.02010649121075403, 0.013915883992012823, 0.03104559211351443, 0.08574156789109111, 0.050361020694253966, 0.03216342978703324, 0.025421867903787643, 0.04090810762136243, 0.04576936044031754, 0.04405063918966334, 0.03177808815962635, 0.03787790752539877, 0.036834240090684034, 0.019810825142485555, 0.03726644834387116, 0.10222137265373021, 0.006200749130584882, 0.03154169928166084, 0.025289440927735996, 0.016752456831454765, 0.09110781509662047, 0.019094459676125553, 0.05777135411335621, 0.024233737713075243, 0.03984792740084231, 0.028934387919434812, 0.04127609412535094, 0.03179097555403132, 0.0459413346106885, 0.04275472318113316, 0.013045123050687835, 0.08815367400529794, 0.05662727038725279, 0.04734613481559791, 0.037136501996428706, 0.022533720439241733, 0.022390083322534338, 0.10943163419142365, 0.017598440244910307, 0.07266538596013561, 0.05461645465402398, 0.009060741831490304, 0.04434175403730478, 0.029386446767603047, 0.023389377747662365, 0.0625398347619921, 0.013172197286621667, 0.02854846741684014, 0.030416401168622542, 0.008029157488635974, 0.00472420504593174, 0.04183198128885124, 0.032999689210555516, 0.06040608597686514, 0.01847407802415546, 0.028811775846406817, 0.021979428893246222, 0.08467149484204128, 0.012540737225208431, 0.027302518356009386, 0.007500128649553517, 0.03588647668948397, 0.07532466435804963, 0.022778950151405297, 0.0563772890745895, 0.02447897113597719, 0.020957632550562266, 0.06377158468239941, 0.03841259524051566, 0.016693873549229465, 0.041688553828862496, 0.03906379271938931, 0.014491323963738978, 0.050256533722858876, 0.06040676133125089, 0.014739310754521284, 0.02555628012487432, 0.026942749282170553, 0.04205193530651741, 0.038759701419621706, 0.03433060490351636, 0.04426190636877436, 0.021286320479703136, 0.07220920262625441, 0.07130407931981608, 0.04271435405826196, 0.06351564763463102, 0.05169852665858343, 0.05147583782672882, 0.032445019169244915, 0.0418973014166113, 0.014703675606142497, 0.07711527374340221, 0.08205008824006654, 0.08408424822846428, 0.07038539697532542, 0.054288870669552125, 0.09471981073147617, 0.4018813680158928, 2.005474674515426, 37.21042290329933, 86.49020656943321, 100.72421997785568, 89.96078833937645, 95.81252753734589, 61.77285589277744, 64.34219062328339, 39.83194403350353, 31.688545905053616, 35.964108780026436, 47.225404903292656, 45.23111991584301, 39.68171149492264, 31.852296218276024, 19.87934958189726, 6.098254770040512, 1.1307217134162784, 0.09871541507891379, 0.25968771369662136, 0.08229314902564511, 0.13486123527400196, 0.03592830784327816, 0.057767802936723456, 0.12837392947403714, 0.08554958170861937, 0.11555579971172847, 0.14554519322700799, 0.33263946475926787, 0.2235181225114502, 0.26606305909808725, 0.36818076856434345, 0.6334212608635426, 0.3047559969127178, 0.3981939033837989, 0.49855996621772647, 0.5558884399943054, 1.1640671803615987, 2.1232118317857385, 2.204567128792405, 0.9394877718295902, 0.5324960639700294, 0.5182786518707871, 0.29518152005039155, 0.117650600586785, 0.32904690597206354, 0.5524451716337353, 0.23888921801699325, 0.17597468773601577, 0.2237636991776526, 0.0479762107715942, 0.020623202253773343, 0.032960763564915396, 0.18491324794013053, 0.3093715914292261, 0.19087725057033822, 0.23209773557027802, 0.07357015303568915, 2.1955751487985253, 21.059866435825825, 54.43075306713581, 69.59465637803078, 47.699304074048996, 32.28571616113186, 23.644472546875477, 54.94545064866543, 54.942859187722206, 71.98255464434624, 91.86121836304665, 77.2162114083767, 94.70111757516861, 75.01596987247467, 34.39089819788933, 4.163732500746846, 0.032332580085494556, 0.020253031980246305, 0.05073473657830618, 0.03661725095298607, 0.08224821198382415, 0.017963469290407375, 0.014769760146009503, 0.061982467013876885, 0.05087394863949157, 0.028055742586730048, 0.07392850646283478, 0.04249363933922723, 0.03508708345179912, 0.06533760533784516, 0.0771469040773809, 0.018869273517339025, 0.004747396233142354, 0.08836019886075519, 0.09260082326363772, 0.03542186626873445, 0.025967665569623932, 0.032129320679814555, 0.02512363400455797, 0.02057478268397972, 0.0425363610702334, 0.05025941696658265, 0.02739766910963226, 0.0007436833425344958, 0.06237775713088922, 0.018350853679294232, 0.04573445723508485, 0.008699546906427713, 0.05393046529206913, 0.03306352504296228, 0.03381750255357474, 0.05936854126048274, 0.08117550431052223, 0.01627471410756698, 0.05639682240143884, 0.020223056635586545, 0.017820665234467015, 0.049864980319398455, 0.022193534787220415, 0.0324386700958712, 0.030786714305577334, 0.029258583999762777, 0.023976891534402966, 0.04766520265548024, 0.04758856477565132, 0.01919208178151166, 0.02920359642303083, 0.06422541540814564, 0.03445155642111786, 0.031983499793568626, 0.19025124900508672, 0.12128320566262119, 0.12361116707324982, 0.14916130778146908, 0.12527145532658324, 0.22753468510927632, 0.11932717156014405, 0.10875766762183048, 0.109415225306293, 0.12634368060389534, 0.195134551031515, 0.23320218489971012, 0.13439302914775908, 0.17579896200913936, 0.18594481836771592, 0.09831924180616625, 0.09292059243307449, 0.1726276907720603, 0.2926361613208428, 0.10367875773226842, 0.1783035768312402, 0.10048281750641763, 0.14378383930306882, 0.133399679325521, 0.11047441847040318, 0.15150630148127675, 0.08804529818007722, 0.1834508014144376, 0.18508753390051425, 0.13478191453032196, 0.08460718774585985, 0.17240932123968378, 0.14374265010701492, 0.14675165817607194, 0.2225738880224526, 0.1656185364117846, 0.2316341010737233, 0.14126601425232366, 0.10647158560459502, 0.14689349744003266, 0.11636206894763745, 0.21973405993776396, 0.2686995832482353, 0.20960313559044152, 0.16746560839237645, 0.11098420713096857, 0.19868885952746496, 0.3637844044715166, 2.0632522366940975, 46.335230469703674, 101.18598639965057, 115.16487389802933, 99.2108903825283, 94.18126747012138, 57.87355072796345, 52.24413760006428, 39.014524295926094, 57.61188916862011, 72.74418577551842, 82.963045835495, 79.48541924357414, 52.39640302956104, 39.8275400698185, 22.235036976635456, 7.57613274268806, 1.2626740266568959, 0.43904877675231546, 0.4538403736660257, 0.6564018339850008, 0.29198405100032687, 0.3679214621661231, 0.20744789420859888, 0.14628371922299266, 0.13324817729881033, 0.23539866000646725, 0.18433052842738107, 0.39783057756721973, 0.21453657711390406, 0.16387949144700542, 0.17691439512418583, 0.5946196429431438, 0.24000500736292452, 0.222498812363483, 0.34509068413171917, 0.26992489874828607, 0.7117002073209733, 2.172631029970944, 1.985998225864023, 0.6396459206007421, 0.3258073126198724, 0.38457858085166663, 0.29478447104338557, 0.1416272620554082, 0.3203834599116817, 0.5349250242579728, 0.44272905739489943, 0.3223004867322743, 0.3169806534424424, 0.23381791514111683, 0.12902473361464217, 0.2237073701689951, 0.35401613800786436, 0.8097826817538589, 0.30572764633689076, 0.29011864797212183, 0.3803213546052575, 3.6890489095821977, 32.14491091668606, 82.39762857556343, 138.442622423172, 121.4211393892765, 65.04616364836693, 27.846022993326187, 41.640187203884125, 46.61773771047592, 83.1663653254509, 100.8561185002327, 88.01466196775436, 104.69863191246986, 86.34667307138443, 38.25283996760845, 4.148157611489296, 0.1948684168746695, 0.2631770248990506, 0.09376885980600491, 0.08375705758226104, 0.16065911971963942, 0.23110687936423346, 0.21297193685313687, 0.12337419932009652, 0.16568914434174076, 0.1225571837858297, 0.22138614003779367, 0.12171068272436969, 0.15061642188811675, 0.11588776236749254, 0.16087162628537044, 0.1351185081875883, 0.09255216064048, 0.26340720942243934, 0.2283875018474646, 0.18369527970207855, 0.1447633109637536, 0.11096139351138845, 0.06950656053959392, 0.1890482276212424, 0.15322011342504993, 0.12494525173678994, 0.1407212481717579, 0.17413506691809744, 0.16001345124095678, 0.17141721822554246, 0.15025303669972345, 0.2917670173337683, 0.14991550793638453, 0.07390492100967094, 0.17927694803802297, 0.16074448154540733, 0.13124709483236074, 0.07406001503113657, 0.1556004778831266, 0.07406916571198963, 0.2306355265318416, 0.0945268374925945, 0.12472621427150443, 0.2041149535216391, 0.09871288435533643, 0.17568670475156978, 0.15099313604878262, 0.15103110432391986, 0.13956606562715024, 0.21856537030544132, 0.15598810161463916, 0.16617909539490938, 0.15026140812551603, 0.10413465162855573], [0.07432954080286436, 0.02286343809828395, 0.03216381199308671, 0.018427879331284203, 0.06732973750331439, 0.04987740016076714, 0.05602827557595447, 0.06263420626055449, 0.06176704009703826, 0.0469292148045497, 0.09508789371466264, 0.049880806618602946, 0.05382418603403494, 0.03730810138222296, 0.06449978740420192, 0.07147722979425453, 0.02647974375577178, 0.06229520804481581, 0.01364540827125893, 0.047457356777158566, 0.05271771064144559, 0.08240812254371122, 0.031824743273318745, 0.031741967832203954, 0.02270571316330461, 0.018404336551611777, 0.012190356319479179, 0.004255262338119792, 0.03191373049048707, 0.09769018259248696, 0.028753307597071398, 0.1182706501276698, 0.04378790777991526, 0.07406626391457394, 0.05244914224022068, 0.02371054215473123, 0.06047891663911287, 0.0581560760474531, 0.0265586396199069, 0.0036530514762489474, 0.06526543147629127, 0.016524125821888447, 0.04824680523597635, 0.06652168711298145, 0.0364680087659508, 0.2744043536949903, 0.18328448612010106, 5.06904817186296, 56.62171170115471, 86.3216020166874, 65.52220970392227, 69.53003704547882, 58.34928140044212, 24.277438782155514, 27.040183134377003, 19.48653046041727, 35.78560955822468, 71.6947428882122, 56.32604956626892, 40.24255000054836, 23.69711682200432, 7.260484155267477, 1.1668591992929578, 0.089429700456094, 0.09806651825783774, 0.025183313809975516, 0.10059077772893943, 0.06210959320014808, 0.1407880414626561, 0.133193941146601, 0.07826141692930833, 0.0569102921144804, 0.1304419239750132, 0.11558668047655374, 0.04510013619437814, 0.061510446248576045, 0.1731133967405185, 0.16278618917567655, 0.19741322641493753, 0.25128446461167186, 0.06658545244135894, 0.027297317756165285, 0.08606013478129171, 0.2975460619200021, 1.1524446727707982, 1.0185039974749088, 1.1769247404299676, 1.6094082710333169, 0.22422668058425188, 0.34562906774226576, 0.3993036813335493, 0.17365382867865264, 0.18694604979828, 0.08703096784302033, 0.12474268994992599, 0.3491820552153513, 0.07338870535022579, 0.15142208256293088, 0.19337264791829512, 0.1420889372820966, 0.04740488322568126, 0.17342915089102462, 0.32558339182287455, 0.02679264249309199, 0.017887946487462614, 0.09930055399308912, 0.1716620082152076, 0.17489928606664762, 0.22345609380863607, 16.265941075980663, 59.99642841517925, 86.17885127663612, 69.87437456846237, 41.83557651937008, 25.21227791905403, 34.48635667562485, 54.671762734651566, 72.38031730055809, 71.32322922348976, 76.3252580165863, 76.27599745988846, 55.9859374165535, 16.61033559590578, 1.7976254713721573, 0.21532013663090765, 0.05124620620335918, 0.034417194983689114, 0.07317438794416375, 0.043041934331995435, 0.09134815962170251, 0.049700542658683844, 0.0379579518630635, 0.027625142938632052, 0.03866910745273344, 0.038984245620667934, 0.012947193881700514, 0.029402278632915113, 0.02155168094759574, 0.01850435208325507, 0.022500865561596584, 0.030486281793855596, 0.06657825360889547, 0.025159234828606714, 0.015803758324182127, 0.027608118070929777, 0.02194474833231652, 0.0593434529582737, 0.03263649698055815, 0.04429211920069065, 0.025158585449389648, 0.07419765373924747, 0.027807022925117053, 0.0389043793984456, 0.02024906520091463, 0.01638790090510156, 0.02415192335320171, 0.0075897666374658, 0.043421186637715437, 0.02514437146601267, 0.0314601075660903, 0.017141607531812042, 0.017016297751979437, 0.03218442514480557, 0.0627652695402503, 0.046990018963697366, 0.01524777931990684, 0.035098130319966, 0.041103140320046805, 0.032230467986664735, 0.07876046671299264, 0.05441145862278063, 0.0379517771943938, 0.08524826975190081, 0.01432994858987513, 0.016629425444989465, 0.05357749614631757, 0.017154270426544826, 0.021937382516625803, 0.047002917490317486, 0.009148696535703493, 0.05013837268052157, 0.06002593938319478, 0.047449597623199224, 0.05967382741800975, 0.06705840831273235, 0.046250910381786525, 0.04290573167963885, 0.03856498784443829, 0.021317557475413196, 0.07124845535145141, 0.05586639090324752, 0.05516555116628297, 0.04892389253654983, 0.029889461475249846, 0.03152333483740222, 0.051178596550016664, 0.018248667365696747, 0.0496062268211972, 0.02318574541277485, 0.035084270712104626, 0.031396928534377366, 0.010542978652665624, 0.033818059164332226, 0.022725586022716016, 0.041558188167982735, 0.12253484514076263, 0.030868619578541256, 0.0988624345336575, 0.07292569425771944, 0.03908814258466009, 0.03351734463649336, 0.03857361902191769, 0.05112586324685253, 0.07147440963308327, 0.02800630627461942, 0.031865457494859584, 0.09532525480608456, 0.026343370409449562, 0.114228431484662, 0.1070164333214052, 0.0612647916568676, 0.2700500248465687, 0.1402124168816954, 8.287899624556303, 72.9219326376915, 101.978190690279, 69.71535310149193, 83.5822682082653, 77.32448279857635, 42.60473884642124, 47.60148972272873, 31.003457866609097, 29.84152391552925, 49.18237589299679, 52.66206957399845, 47.575126737356186, 31.86433207243681, 13.030166756361723, 1.6904260986484587, 0.1346895023016259, 0.18800785532221198, 0.04909705414320342, 0.19670070527354255, 0.01823298392992001, 0.12657469633268192, 0.07939754854305647, 0.347563520190306, 0.38217179593630135, 0.9109551622532308, 0.44231122825294733, 0.8054621948394924, 0.5961484671570361, 0.9811822220217437, 0.9690190746914595, 1.5115968883037567, 1.4614711655303836, 0.5317077843938023, 1.4293257216922939, 1.768045958597213, 2.304080701433122, 3.871743818745017, 4.298886498436332, 4.729509316384792, 4.054220952093601, 1.945669089909643, 2.05314620397985, 1.7717590718530118, 1.4005311043001711, 2.0244603557512164, 0.8696625998709351, 0.9974882751703262, 1.5054635424166918, 0.7575661805458367, 0.6002752238418907, 0.7453718036413193, 0.6422779918648303, 0.16767913912190124, 0.5066699779126793, 0.25628125586081296, 0.012522947017714614, 0.12013370054773986, 0.1609051862033084, 0.03990891338617075, 0.2335696667432785, 0.7599425967782736, 19.660008251667023, 55.36514572799206, 61.31282597780228, 41.56088545918465, 30.22930260747671, 31.097117140889168, 59.6026973426342, 79.61797133088112, 88.10866132378578, 83.22822600603104, 87.9206170141697, 94.11871522665024, 73.93070250749588, 30.554458759725094, 5.338270850479603, 0.07184883797890507, 0.05098554909636732, 0.09569906716933474, 0.06028944262652658, 0.05572952773945872, 0.01631105893466156, 0.04812669234524947, 0.039117008418543264, 0.016210826324822847, 0.05767973227193579, 0.0808592009707354, 0.019185990604455583, 0.045972827647347, 0.07075532048474997, 0.03399345092475414, 0.018332667350478005, 0.02157381550205173, 0.019903205829905346, 0.038772907937527634, 0.07840923790354282, 0.030055069873924367, 0.01504396423115395, 0.02410272823908599, 0.013345362604013644, 0.031598269488313235, 0.012176780583104119, 0.04441203913302161, 0.05324163350451272, 0.07082503783749416, 0.022260357764025684, 0.015248976033035433, 0.03853953588986769, 0.016869315404619556, 0.038248365381150506, 0.01975506016606232, 0.09045389393577352, 0.024550185771659017, 0.042183421610388905, 0.02371268881688593, 0.058155166916549206, 0.08017205385840498, 0.01080086291040061, 0.02240096320747398, 0.05400792695581913, 0.01537848822408705, 0.08005715455510654, 0.06098948826547712, 0.0395892072992865, 0.011741471080313204, 0.03711536934133619, 0.044735971750924364, 0.03011324497492751, 0.16063078452134505, 0.08255411783466116, 0.258119169739075, 0.09380604882608168, 0.14321483467938378, 0.13242284971056506, 0.17645692045334727, 0.20069782360224053, 0.22198916471097618, 0.12550821527838707, 0.15293775591999292, 0.2020349510712549, 0.07475928141502663, 0.22228666202863678, 0.1140596299956087, 0.19257201900472865, 0.1372338368673809, 0.24842121434630826, 0.10838864953257143, 0.15570341376587749, 0.1517289160983637, 0.19196512032067403, 0.10400594837847166, 0.14161267143208534, 0.12475597439333797, 0.08989553913124837, 0.11324890045216307, 0.10860380556550808, 0.18781828111968935, 0.17225873947609216, 0.11260775907430798, 0.17621486156713217, 0.1885727039189078, 0.21539831446716562, 0.10358051222283393, 0.11716764798620716, 0.14374190795933828, 0.10021788562880829, 0.1062543664011173, 0.1675757727934979, 0.19150862528476864, 0.14517183357384056, 0.2358620273298584, 0.20952013379428536, 0.11769197531975806, 0.445597933139652, 0.2707197982817888, 8.629013020545244, 84.22184228897095, 112.71871715784073, 80.33387571573257, 88.20812478661537, 79.4014285504818, 39.24942389130592, 39.46235306560993, 31.581674739718437, 58.14274348318577, 109.14427936077118, 80.32105520367622, 63.033658638596535, 38.792411014437675, 14.395932219922543, 2.515241070650518, 0.6856141914613545, 0.5553929228335619, 0.17165378521895036, 0.1995311229256913, 0.2186717200675048, 0.4772937542293221, 0.20248696353519335, 0.273517279420048, 0.31538785609882325, 0.6203570275101811, 0.5891512020025402, 1.2395071447826922, 0.5230875313282013, 0.8031569654121995, 0.8795545971952379, 0.8239643520209938, 0.7486793480347842, 0.16403684159740806, 0.8580604568123817, 1.3929070509038866, 1.5797417191788554, 2.6816745148971677, 4.306228179484606, 3.4789137728512287, 3.1960871117189527, 0.9484935260843486, 1.1854944680817425, 1.4965264219790697, 0.7312008796725422, 1.0605847206898034, 0.5038630566559732, 0.4337522468995303, 1.2154501606710255, 0.6439165351912379, 0.3556470520561561, 0.6878763763234019, 0.6523064256180078, 0.15903292573057115, 0.3983148140832782, 0.4796300351154059, 0.180267121468205, 0.14617238222854212, 0.38913159747608006, 0.32632494578137994, 0.34197324828710407, 0.8393332804553211, 27.90329921990633, 94.78811770677567, 121.1505863070488, 98.0648946762085, 59.606637731194496, 38.432680517435074, 49.152745082974434, 72.42779955267906, 94.64684888720512, 89.66708689928055, 97.79822498559952, 105.72637796401978, 84.66107591986656, 33.7583689391613, 5.209779795259237, 0.1670286466833204, 0.2562167780706659, 0.1527090260060504, 0.2220054029021412, 0.130609946209006, 0.17811128636822104, 0.1531310853897594, 0.19819635548628867, 0.07612793531734496, 0.10012766273575835, 0.20544241822790354, 0.09184848589939065, 0.1249419417581521, 0.22033027169527486, 0.10014162253355607, 0.11900850819074549, 0.10293756742612459, 0.1849622742156498, 0.1529054724960588, 0.2001580744399689, 0.09350697815534659, 0.07470031036064029, 0.09189000906189904, 0.08914352831197903, 0.1692871653358452, 0.060246620705584064, 0.15496473934035748, 0.0988750510441605, 0.1276407766272314, 0.14300079928943887, 0.13126319943694398, 0.14070112112676725, 0.09750166223966517, 0.11817414124379866, 0.081157937675016, 0.23983033548574895, 0.0660303482436575, 0.08711131275049411, 0.1435030996799469, 0.13495272723957896, 0.1739422866376117, 0.148053266457282, 0.1220749065396376, 0.16203510604100302, 0.0947115506278351, 0.16577223519561812, 0.1889319033944048, 0.15135609079152346, 0.14835061534540728, 0.07649748033145443, 0.08826724486425519, 0.10928307106951252], [0.02824944498570403, 0.028831823110522237, 0.04391291884530801, 0.08744417340494692, 0.021996837822371162, 0.0347981764934957, 0.028379393188515678, 0.03670690239232499, 0.04985764047887642, 0.05475439022120554, 0.04244308795023244, 0.09781038825167343, 0.06229354563402012, 0.06234400425455533, 0.06747957711922936, 0.05170933603949379, 0.02691750141821103, 0.038977325093583204, 0.06885087306727655, 0.032637754920870066, 0.00654234022476885, 0.032570494076935574, 0.021362414736358915, 0.030398849376069847, 0.020046919016749598, 0.019162445969413966, 0.026881100930040702, 0.04453503897821065, 0.023384670676023234, 0.017314232936769258, 0.04282549809431657, 0.0022281597102846717, 0.037390220022643916, 0.05444111113320105, 0.015594548749504611, 0.015126053185667843, 0.15939185803290457, 0.05826921646075789, 0.03012500801560236, 0.03360284004884306, 0.03203054082405288, 0.016206035761570092, 0.021338808874133974, 0.22041548509150743, 0.11651768247247674, 2.682727533392608, 30.945687666535378, 67.49775409698486, 75.69690093398094, 75.78396186232567, 85.19938543438911, 47.8772409260273, 28.00692915916443, 35.119676291942596, 41.46604634821415, 64.50665339827538, 47.92994789779186, 29.438787326216698, 18.57763633131981, 6.770366029813886, 0.1621383981546387, 0.218312387005426, 0.06859911431092769, 0.10858271372853778, 0.048196164789260365, 0.029702197207370773, 0.07155905899708159, 0.09711050588521175, 0.17246006929781288, 0.20296204194892198, 0.09354137670015916, 0.11407658807002008, 0.5277023836970329, 0.22790902439737692, 0.8586060837842524, 0.6855035817716271, 0.6674749148078263, 1.5040596364997327, 2.705433452501893, 2.6053107250481844, 2.0814003003761172, 1.5646375296637416, 1.0550914029590786, 3.955317009240389, 7.905624937266111, 3.9415655471384525, 4.0005687810480595, 4.9388144351542, 2.14975886978209, 1.4614728279411793, 2.0638305181637406, 1.3599288580007851, 1.3427145942114294, 1.1660608858801425, 1.4767186786048114, 1.138347191736102, 0.4947439319221303, 0.16542219382245094, 0.4008715722011402, 0.19288173207314685, 0.09969977749278769, 0.10222025201073848, 0.20410469704074785, 0.05889201936952304, 0.06561853791936301, 0.051053214410785586, 0.0773613402270712, 0.16949070675764233, 0.039815194977563806, 0.11118984883069061, 0.16955497674643993, 15.00487519428134, 62.92992800474167, 97.37268581986427, 55.796285793185234, 18.443921506404877, 24.889477640390396, 27.473798766732216, 45.49151234328747, 62.71764099597931, 71.07802838087082, 73.17493826150894, 78.07460814714432, 56.45696774125099, 22.485054060816765, 1.7256997246295214, 0.320064514526166, 0.027928471681661904, 0.08286279189633206, 0.04668163433962036, 0.05388529447373003, 0.012023428753309418, 0.028412678511813283, 0.054416505226981826, 0.02724593701714184, 0.01377347884044866, 0.03503068022837397, 0.029968906528665684, 0.07623580648214556, 0.07827746216207743, 0.056156860082410276, 0.05572244022914674, 0.02775151213427307, 0.030980218180047814, 0.041659231574158184, 0.040296314473380335, 0.04551734193228185, 0.04983007711416576, 0.03521092934533954, 0.04665303938963916, 0.03154283847834449, 0.03672990897030104, 0.0525092710449826, 0.014076935603952734, 0.07577656549983658, 0.014646558065578574, 0.02907711033913074, 0.08819939030217938, 0.010670286665117601, 0.023012837991700508, 0.036334748729132116, 0.04034381934616249, 0.032182510403799824, 0.034537118626758456, 0.024867615320545156, 0.015864681226958055, 0.05355883113224991, 0.06363496271660551, 0.0012325655870881747, 0.048444201675010845, 0.061248649944900535, 0.025155037983495276, 0.02902938282204559, 0.038182618518476374, 0.059994854527758434, 0.0453445699531585, 0.031777590920682997, 0.022679122012050357, 0.02219665180746233, 0.048347035990445875, 0.08357731683645397, 0.03185406181728467, 0.09904057224048302, 0.022328240156639367, 0.03156265753204934, 0.011776262963394402, 0.0486250296671642, 0.03219873004127294, 0.02793606570776319, 0.03909959763404913, 0.02818549968651496, 0.02075414864521008, 0.005427530049928464, 0.02998021500388859, 0.027379117273085285, 0.05205654240853619, 0.03293716326879803, 0.03561987126886379, 0.009097237871174002, 0.013377120958466548, 0.04687327171268407, 0.036103131860727444, 0.02423382677079644, 0.08299879045807756, 0.048657732404535636, 0.015150368726608576, 0.02168266444641631, 0.06509525701403618, 0.04264726761903148, 0.05891998349397909, 0.04596068240061868, 0.06328186369501054, 0.00998958417767426, 0.044649997653323226, 0.028670367028098553, 0.03718592903169338, 0.008752775593166007, 0.01296162030484993, 0.05718274194805417, 0.3138953971210867, 0.07637678485480137, 4.798309849575162, 42.11099334061146, 81.65574878454208, 85.80231428146362, 84.24040049314499, 103.53948891162872, 68.27523037791252, 44.106676653027534, 28.607564829289913, 38.17675285041332, 43.30792151391506, 46.80400751531124, 39.76911440491676, 25.626024417579174, 9.786786194890738, 0.48517230490688235, 0.2167566228308715, 0.15752307081129402, 0.05556955038628075, 0.07429915727698244, 0.21955165488179773, 0.2865510550327599, 0.3451799199683592, 0.8722990052774549, 0.945335301803425, 0.67497868090868, 0.6529366574250162, 2.022478524595499, 1.0138580342754722, 4.374291552230716, 4.656391264870763, 4.216581964865327, 5.2983098197728395, 6.923050861805677, 5.812092125415802, 6.497488422319293, 5.498408982530236, 6.533360397443175, 7.902040304616094, 10.601300988346338, 11.927160993218422, 9.992912784218788, 8.38159404695034, 6.96827033534646, 6.057317666709423, 4.865503069013357, 4.104816187173128, 6.240803170949221, 4.511531637981534, 6.185104809701443, 4.636057605966926, 3.230564324185252, 2.162344981916249, 1.38289530063048, 0.9513225930277258, 0.6415226636454463, 0.7164049486164004, 0.5006826273165643, 0.29873774328734726, 0.36743704753462225, 0.17827951640356332, 0.14072340040002018, 0.3586520079988986, 0.06373936805175617, 0.24081995972665027, 0.399406750802882, 18.06819386780262, 58.77392381429672, 69.09543916583061, 44.8375104367733, 22.614110335707664, 41.9890920817852, 56.35210856795311, 70.59461072087288, 81.22650861740112, 78.12177121639252, 85.1285420358181, 92.32391953468323, 77.75316059589386, 39.425232857465744, 5.127262948080897, 0.40541033959016204, 0.07216463665827177, 0.010439131783641642, 0.0732409066404216, 0.04516387183684856, 0.03587010862247553, 0.020125647897657473, 0.043168581833015196, 0.044722935926984064, 0.04811712606169749, 0.052559210162144154, 0.054044826538302004, 0.007875457777117845, 0.03898607501469087, 0.011577553850656841, 0.014680269196105655, 0.032513114929315634, 0.07056889298837632, 0.01750636198266875, 0.02611332503875019, 0.01897883863421157, 0.033614465792197734, 0.05736774081015028, 0.05899790528928861, 0.052888564168824814, 0.028347983643470798, 0.06717827258398756, 0.01738203183776932, 0.012072355766576948, 0.03727015166077763, 0.0570863740722416, 0.04489832768740598, 0.07297751100850292, 0.03577155512175523, 0.09450210171053186, 0.06635514917434193, 0.030718308698851615, 0.03837151736661326, 0.0295106396151823, 0.02510949609131785, 0.04152992718445603, 0.056000307740760036, 0.011844985838251887, 0.04612776952853892, 0.027814359054900706, 0.0453477129485691, 0.029090127609379124, 0.024784609813650604, 0.027108682370453607, 0.05065642144472804, 0.1214090664871037, 0.18871878826757893, 0.16792413691291586, 0.20789834816241637, 0.2132757127401419, 0.18370182544458658, 0.1744027595850639, 0.23500267969211563, 0.13878290686989203, 0.24627964332466945, 0.1480030972743407, 0.19506570941302925, 0.2019175433088094, 0.1248313469113782, 0.16962221532594413, 0.11491070268675685, 0.07371421132120304, 0.17651405098149553, 0.16684726579114795, 0.12217384224641137, 0.16495245887199417, 0.10293280283804052, 0.07887892090366222, 0.1364992294111289, 0.1704959457856603, 0.15621844941051677, 0.06816902488935739, 0.13828734518028796, 0.0803074290161021, 0.047921963487169705, 0.1386315087438561, 0.1872373724472709, 0.19716347887879238, 0.1263016602024436, 0.16768512083217502, 0.20449910400202498, 0.21785105316666886, 0.1553305290872231, 0.11374742331099696, 0.11283889354672283, 0.14070358505705371, 0.0756405817810446, 0.12961309344973415, 0.4209061455912888, 0.19340028549777344, 5.316801052540541, 45.51394633948803, 98.6411489546299, 96.19460463523865, 91.67567431926727, 107.98713505268097, 64.72617521882057, 41.87136299908161, 50.17060026526451, 59.65642265975475, 90.6760011613369, 71.06380194425583, 47.40118347108364, 33.23834404349327, 13.32597328349948, 0.7204187207389623, 0.4441087692975998, 0.28429142315872014, 0.2841709874337539, 0.22802701103501022, 0.3058467758819461, 0.18094051658408716, 0.37773001240566373, 0.5920000991318375, 0.5638093524612486, 0.6661387521307915, 0.3439082350814715, 2.096375534310937, 0.6491411360912025, 1.8239793134853244, 2.892234278842807, 4.27492355927825, 7.24827541038394, 5.703026102855802, 6.318508526310325, 8.46149330958724, 6.099233217537403, 6.146784340962768, 8.451214861124754, 16.147659122943878, 14.486496560275555, 14.54995695501566, 12.290870826691389, 6.804768908768892, 6.342042563483119, 6.431701127439737, 3.555942289531231, 3.683618288487196, 2.4813533015549183, 4.710524110123515, 5.304427966475487, 2.2786631528288126, 1.98308271355927, 0.9921533614397049, 0.49240468244533986, 0.4072989569976926, 0.41799410653766245, 0.3155989228980616, 0.259715499705635, 0.3496806597104296, 0.2575051464373246, 0.26026828098110855, 0.5785981588996947, 0.21926827321294695, 0.5009102588519454, 0.5320332013070583, 24.14405833929777, 91.85031294822693, 136.74253284931183, 79.52477753162384, 28.407427668571472, 36.01576700806618, 41.270022466778755, 63.06841917335987, 81.31244480609894, 89.82175379991531, 97.53211006522179, 107.5387591123581, 89.35760110616684, 42.745992466807365, 4.786429787054658, 0.6725989992264658, 0.3476463141851127, 0.1640868029789999, 0.1748243291513063, 0.09631057459046133, 0.1289254639414139, 0.16272862820187584, 0.09435816216864623, 0.1737634142045863, 0.1963852925109677, 0.22663999639917165, 0.1311442331643775, 0.11244677982176654, 0.19899888429790735, 0.13790355093078688, 0.14163909188937396, 0.1401307064224966, 0.1914521330036223, 0.13526080758310854, 0.12889122124761343, 0.16630888218060136, 0.13626831758301705, 0.1983132734312676, 0.09568964931531809, 0.15929080720525235, 0.21828736178576946, 0.19383462000405416, 0.10251837273244746, 0.14172400842653587, 0.11811673612101004, 0.11538354723597877, 0.14769007422728464, 0.1010688544192817, 0.10417319877888076, 0.1814887410728261, 0.1888751142541878, 0.21922871674178168, 0.0952999475703109, 0.10083216126076877, 0.10845931683434173, 0.12515288981376216, 0.1782800507498905, 0.0662276110961102, 0.14007363526616246, 0.090903553791577, 0.11357497787685134, 0.15085061400895938, 0.11619272569078021, 0.11560858867596835, 0.10596724430797622], [0.04650792354368605, 0.04031157302961219, 0.02936018216132652, 0.03442074616032187, 0.0170929263549624, 0.049578637481317855, 0.008678374360897578, 0.03924947806808632, 0.08913684156141244, 0.02391935653577093, 0.02347954869037494, 0.0395656812179368, 0.027712682967830915, 0.016074575432867277, 0.037296761365723796, 0.030412170926865656, 0.039580171651323326, 0.007085071893015993, 0.07018718417384662, 0.024494966273778118, 0.03991326979303267, 0.042199017843813635, 0.03493347372568678, 0.04064857857883908, 0.03872682427754626, 0.06674598640529439, 0.028447759832488373, 0.045333964662859216, 0.009718405271996744, 0.02403344689810183, 0.031244587880792096, 0.021807653247378767, 0.03744469737284817, 0.07515584060456604, 0.009359690975543344, 0.017583356093382463, 0.08391897936235182, 0.02978682801767718, 0.04204942684737034, 0.008629997464595363, 0.04088815869181417, 0.20449950476177037, 0.12993362703127787, 3.590187239460647, 27.401904724538326, 60.5180948227644, 86.96451231837273, 75.86333960294724, 71.68044045567513, 67.65409290790558, 27.755774036049843, 26.855431348085403, 48.457162007689476, 38.30585852265358, 80.86020827293396, 66.2194874882698, 24.04443148523569, 7.642129501327872, 0.1543817378114909, 0.15911058406345546, 0.011785205842897994, 0.170625613827724, 0.07014444388914853, 0.10302191993105225, 0.17419926269212738, 0.0674321390397381, 0.13007098372327164, 0.4161795851541683, 0.11714090840541758, 0.49150240898597986, 0.5685352301225066, 0.9614672767929733, 2.2440049750730395, 1.7883904231712222, 1.1737207998521626, 2.400284414179623, 1.1257357872091234, 0.9154901001602411, 6.8238685838878155, 6.087474748492241, 6.773492312058806, 7.898688409477472, 4.849666943773627, 3.623743951320648, 6.931237997487187, 6.8813124764710665, 9.209055695682764, 6.442746659740806, 6.178326448425651, 4.72601255401969, 2.392021045088768, 4.77302173152566, 8.476398009806871, 6.759407892823219, 5.746764130890369, 3.7908820202574134, 2.5862775463610888, 4.372272910550237, 0.9588584792800248, 0.2236909538623877, 0.8483753108885139, 1.3763898122124374, 0.2214767414261587, 0.1995376092963852, 0.040618198763695545, 0.07916254748124629, 0.024308794818352908, 0.21589395037153736, 0.04184552548395004, 0.21151974680833519, 0.0710444909054786, 0.18169879855122417, 0.9292575332801789, 21.872475631535053, 63.85449439287186, 77.89577454328537, 48.88940401375294, 20.953206159174442, 22.033919468522072, 38.61542031168938, 67.07501918077469, 75.75593456625938, 69.690722823143, 61.60930506885052, 77.04425543546677, 55.91587297618389, 6.812389874830842, 0.2935627178521827, 0.028521295535028912, 0.0922634280868806, 0.04380154474347364, 0.07416434615151957, 0.024257011464214884, 0.07981355942320079, 0.036233579157851636, 0.06987439119257033, 0.026658968708943576, 0.08501752119627781, 0.07276776523212902, 0.01793667961464962, 0.02467272734065773, 0.04119418328627944, 0.01961659025255358, 0.0709217248368077, 0.023548249300802127, 0.05320570242474787, 0.019714529626071453, 0.11128697369713336, 0.056004081561695784, 0.03395518950128462, 0.014972156805015402, 0.0373642634076532, 0.0008914951558836037, 0.03180582592904102, 0.010348363412049366, 0.06237007590243593, 0.06244073578272946, 0.03682533802930266, 0.03446927890763618, 0.059208467428106815, 0.04542123009741772, 0.04962447994330432, 0.01402541571223992, 0.004686175079768873, 0.022951597820792813, 0.03636072389781475, 0.0030271547393567744, 0.023484086923417635, 0.04313130375521723, 0.042927049871650524, 0.03562045756552834, 0.028541507927002385, 0.03195843746652827, 0.0834561612282414, 0.031072361380211078, 0.020502709012362175, 0.03405497125640977, 0.021446646642289124, 0.07658281247131526, 0.035050933438469656, 0.015950117267493624, 0.03377095876203384, 0.027274077401671093, 0.04103112602024339, 0.12305581054533832, 0.015954570153553504, 0.030210816985345446, 0.055704038677504286, 0.08860748988809064, 0.028714341133309063, 0.017075649157050066, 0.041581922050681897, 0.010071944016090129, 0.03258548917074222, 0.0768445160065312, 0.055255024490179494, 0.008974820611911127, 0.010466179355717031, 0.014478814136964502, 0.014375736318470445, 0.0547844768880168, 0.06532402403536253, 0.028964535813429393, 0.04554719853331335, 0.09686373436124995, 0.008585414798290003, 0.014602140527131269, 0.06192018969159108, 0.07477205377654172, 0.0447506588534452, 0.03630344494013116, 0.09901575482217595, 0.011637293027888518, 0.07511321906349622, 0.027770370106736664, 0.0372830835840432, 0.04871016142715234, 0.2116701504564844, 0.04103719678823836, 8.56978464871645, 40.04508979618549, 80.48991814255714, 99.91414904594421, 84.00801256299019, 79.38148722052574, 88.07636305689812, 49.00359928607941, 29.98843353241682, 39.834596291184425, 36.989236772060394, 51.55247591435909, 48.998264372348785, 29.12723634392023, 8.849343247711658, 0.6880207092035562, 0.18564485711976886, 0.03526928812789265, 0.06628994407947175, 0.07168287149397656, 0.6907538906671107, 0.3701227018609643, 0.9495908953249454, 1.3852029643021524, 1.8675303203053772, 2.7425724221393466, 3.0194274662062526, 4.457992035895586, 4.866198431700468, 7.342396359890699, 3.7654295610263944, 6.108560292050242, 6.93024767562747, 7.2431072127074, 7.6929612737149, 11.23392904177308, 11.665314193814993, 14.36339171603322, 9.100504070520401, 11.046901177614927, 13.442665971815586, 15.494208186864853, 14.268881287425756, 16.443097069859505, 14.574661329388618, 12.508241012692451, 10.172883477061987, 6.883854065090418, 7.297453796491027, 6.255559204146266, 11.115743033587933, 9.286733027547598, 9.428326729685068, 4.671726291999221, 4.874557983130217, 4.5992356818169355, 3.360816822387278, 2.769618183374405, 3.3253898983821273, 1.41957568237558, 0.8542490238323808, 0.13965516787720844, 0.4039711965015158, 0.020170889220025856, 0.1764132227981463, 0.025551176004228182, 0.22479145496618003, 0.043316536393831484, 0.1332471679779701, 2.142489622347057, 28.032705076038837, 54.277723878622055, 55.18043003976345, 41.10030077397823, 27.594208605587482, 35.17035037279129, 61.170417219400406, 86.23017892241478, 86.93878769874573, 78.97613257169724, 70.6085179746151, 93.57512399554253, 79.02415439486504, 17.074332498013973, 0.28714480285998434, 0.060652490137727, 0.05911643740546424, 0.05104201540234499, 0.11973926390055567, 0.07109822239726782, 0.050413004428264685, 0.04430288405274041, 0.045914728616480716, 0.03666074451757595, 0.03549858207406942, 0.04350208073446993, 0.0361426475137705, 0.01200594189867843, 0.10664895147783682, 0.031974434459698386, 0.0475589567940915, 0.017767473655112553, 0.09753806458320469, 0.01665467701968737, 0.070170678809518, 0.025406344029761385, 0.09867960645351559, 0.023639700448256917, 0.07282923732418567, 0.04881976179603953, 0.02126864252204541, 0.10782702185679227, 0.020533938586595468, 0.04698996701336, 0.030109174294921104, 0.03025609355972847, 0.014965813297749264, 0.02749740262515843, 0.019799455440079328, 0.04332303018600214, 0.0460727763856994, 0.01578880775923608, 0.06329923737212084, 0.04109646841243375, 0.030966250960773323, 0.03029480027180398, 0.0197304542598431, 0.04453828958503436, 0.037011483509559184, 0.054892002954147756, 0.009297984179283958, 0.06888745352625847, 0.02525384938053321, 0.12398191436659545, 0.06131484580691904, 0.08483163546770811, 0.09641813405323774, 0.19662607490317896, 0.2175411768257618, 0.12606236210558563, 0.1169837660563644, 0.2309409945155494, 0.13319812685949728, 0.08270787599030882, 0.1993060889071785, 0.09880641722702421, 0.07102677584043704, 0.10989133530529216, 0.16438692749943584, 0.1484931373852305, 0.08216300600906834, 0.2289287353050895, 0.12417746285791509, 0.12060148364980705, 0.0981523105292581, 0.09580629266565666, 0.181881470780354, 0.1590140158077702, 0.22554166236659512, 0.09931297012371942, 0.26694716478232294, 0.09164795759716071, 0.10608760581817478, 0.11940290773054585, 0.2361981014837511, 0.14738153375219554, 0.14169496076647192, 0.12039335575536825, 0.23944490851135924, 0.1515729760285467, 0.15880311228102073, 0.11465933726867661, 0.1642784700379707, 0.17408028157660738, 0.2690564375370741, 0.20866906852461398, 8.3322099968791, 42.71485693752766, 89.6775971353054, 113.11299160122871, 91.72292858362198, 90.38635790348053, 84.79554310441017, 37.8675140440464, 39.28255811333656, 72.32881486415863, 57.49383330345154, 109.42340478301048, 88.93677368760109, 37.53274820744991, 13.754562735557556, 0.8698065765202045, 0.44928893039468676, 0.1733569844509475, 0.4155421396717429, 0.27861847600433975, 0.4392313747666776, 0.4357194429030642, 0.4269345517968759, 0.4976332018850371, 0.8631417341530323, 1.0740204434841871, 2.1640769764781, 3.9597546961158514, 4.443506263196468, 7.2295984625816345, 10.762516837567091, 6.61768214777112, 7.61231392621994, 10.199976973235607, 13.351527862250805, 18.722570054233074, 21.694210097193718, 21.11912425607443, 22.502194941043854, 18.306040205061436, 17.69625462591648, 21.912352591753006, 22.950791269540787, 24.796086251735687, 26.79187785834074, 23.782883919775486, 15.992281660437584, 11.696899998933077, 13.56105051934719, 18.848936073482037, 20.72626333683729, 16.526379100978374, 13.685889970511198, 9.28480938076973, 11.32161883637309, 6.662834174931049, 5.845647174865007, 3.498678649775684, 2.917693150229752, 0.953956920420751, 0.7098228705581278, 0.1811552347498946, 0.33251006389036775, 0.13661570206750184, 0.3393885854166001, 0.2519843098707497, 0.5188886378891766, 0.15864742454141378, 0.2824937039986253, 2.010560226626694, 35.09637214243412, 92.0276266336441, 104.6773910522461, 68.12190100550652, 29.675315134227276, 30.38075678050518, 52.61383876204491, 85.56790485978127, 93.65547448396683, 87.22293645143509, 78.98393735289574, 106.21708363294601, 85.97910359501839, 16.31910402327776, 0.5537735566031188, 0.16489512054249644, 0.15939748351229355, 0.19303685578051955, 0.15008970483904704, 0.20384491566801444, 0.19236452935729176, 0.16129987518070266, 0.21509140671696514, 0.1700572029221803, 0.17448164988309145, 0.12394022051012143, 0.17564843961736187, 0.16011920728487894, 0.20801091712201014, 0.09908249616273679, 0.26702657458372414, 0.119492774392711, 0.12716894882032648, 0.1332297275075689, 0.19698368618264794, 0.11337042713421397, 0.24456833984004334, 0.07676192239159718, 0.18789010617183521, 0.11789357973611914, 0.09710691389045678, 0.22825404885224998, 0.1367255547665991, 0.11650364845991135, 0.15100897348020226, 0.1364347813068889, 0.09811113617615774, 0.15789873112225905, 0.0829021554091014, 0.11653944966383278, 0.08550544618628919, 0.0744233927980531, 0.11074647496570833, 0.16926573211094365, 0.10762524674646556, 0.12119835591875017, 0.10837790323421359, 0.15060408739373088, 0.10382426320575178, 0.18325350887607783, 0.1999724336201325, 0.12696812365902588, 0.09945120254997164], [0.04905523412162438, 0.038214831438381225, 0.06561441899975762, 0.023527543380623683, 0.04952664261509199, 0.03695202634844463, 0.05289105778501835, 0.06981731261475943, 0.02219890979176853, 0.14752651972230524, 0.029091984833939932, 0.06372467352775857, 0.028605230581888463, 0.05118682325701229, 0.01644677176955156, 0.021379734607762657, 0.09387058598804288, 0.06825942589784972, 0.11678831404424272, 0.026779363615787588, 0.01016838146824739, 0.013390726380748674, 0.017521767113066744, 0.015450586015504086, 0.0359479302278487, 0.04359268583357334, 0.04203112919640262, 0.01859060077549657, 0.041130933750537224, 0.06083807900722604, 0.03365131342434324, 0.06552523511345498, 0.06402744751540013, 0.020644455507863313, 0.06998521610512398, 0.08360194129636511, 0.1031416654586792, 0.057387277847738005, 0.10844072603504173, 0.029048199976386968, 0.037604207172989845, 1.3926497334614396, 25.235074795782566, 71.32287204265594, 85.34511521458626, 77.28349059820175, 63.650779724121094, 62.352514788508415, 58.723606914281845, 30.94582635909319, 68.39879214763641, 64.09534066915512, 40.28771057724953, 37.859386280179024, 28.918779529631138, 8.960752319544554, 0.19046647183131427, 0.16906869190279394, 0.0882050528889522, 0.0765329178830143, 0.03165754482324701, 0.06098371806729119, 0.06657902544247918, 0.02595023066533031, 0.09990208694944158, 0.5884760257322341, 1.8463217583484948, 2.350405203178525, 3.762303991243243, 2.5551356049254537, 1.4807440876029432, 3.141636746004224, 5.933136530220509, 2.881440008059144, 20.77522750943899, 15.05707299336791, 5.6677378714084625, 6.264217039570212, 10.539256017655134, 7.545589506626129, 8.813400976359844, 5.4512786865234375, 9.81835775077343, 9.507634174078703, 13.083631787449121, 13.65870812907815, 11.492163185030222, 8.90553368255496, 9.215428903698921, 9.416508413851261, 4.284811103716493, 7.407396147027612, 11.415652390569448, 8.905921261757612, 10.224721245467663, 4.231380745768547, 5.858019310981035, 4.064417704939842, 2.7795109525322914, 4.525048937648535, 2.3427654756233096, 2.605790449306369, 2.3796512838453054, 0.7611680903937668, 0.4403125948738307, 0.2148925408255309, 0.03967740041844081, 0.017513699967821594, 0.05680443959136028, 0.08754515001783147, 0.0559477080241777, 0.29038163542281836, 0.04533728206297383, 0.4701674444368109, 12.013501860201359, 48.55066359043121, 82.28049606084824, 81.7960524559021, 48.20192590355873, 18.90741303563118, 20.63821256160736, 45.8085635304451, 63.677347898483276, 83.63550335168839, 70.46624600887299, 68.79970103502274, 66.3125216960907, 13.86987229809165, 0.425451384508051, 0.08920482228859328, 0.06440739001845941, 0.04253159277141094, 0.04380893653433304, 0.020725531430798583, 0.026911254390142858, 0.06175122121931054, 0.09204324771417305, 0.05133366459631361, 0.042634543497115374, 0.08861242517014034, 0.03533379560394678, 0.0630170208751224, 0.03077985871641431, 0.03993563441326842, 0.026210928590444382, 0.027463822298159357, 0.05557027398026548, 0.020666603049903642, 0.03572052875824738, 0.024413378268945962, 0.03975412364525255, 0.01117513169447193, 0.059479388437466696, 0.011354498583386885, 0.023508700251113623, 0.03835552037344314, 0.06104211395722814, 0.020348694815766066, 0.014646418912889203, 0.018397952226223424, 0.05210385061218403, 0.1130546432978008, 0.042301575231249444, 0.06931130890734494, 0.05175537145987619, 0.047493009551544674, 0.02921788462117547, 0.028965665733267087, 0.04706998537585605, 0.041632050415501, 0.07815842909622006, 0.06100496575527359, 0.05138975982845295, 0.07201698637800291, 0.03547542706655804, 0.030747410164622124, 0.028334276175883133, 0.020316697118687443, 0.046392475051106885, 0.03883017576299608, 0.026464455513632856, 0.029025833500782028, 0.03821308368060272, 0.05220827821176499, 0.03006509257829748, 0.06967244538827799, 0.06911541160661727, 0.06726447303663008, 0.05681732698576525, 0.04877859115367755, 0.05446916060463991, 0.02520251873647794, 0.07722655878751539, 0.01893443779408699, 0.015055116855364759, 0.04473867316846736, 0.08832605264615268, 0.08071774762356654, 0.03171500931784976, 0.018412323915981688, 0.035020015566260554, 0.03292066903668456, 0.07321672004763968, 0.07285592495463789, 0.07077120244503021, 0.049438783462392166, 0.0953409141220618, 0.014453526382567361, 0.05087827536044642, 0.01993928904994391, 0.03832327034615446, 0.032761830880190246, 0.14570531900972128, 0.06082813051762059, 0.0750828800664749, 0.09011920017655939, 0.1352715093526058, 3.712056912481785, 39.45878505706787, 86.45234540104866, 99.63152021169662, 82.9824247956276, 75.89791014790535, 87.95875176787376, 73.7453256547451, 41.00846730172634, 46.955835968256, 48.68302948772907, 41.473125368356705, 38.24665389955044, 34.79203887283802, 12.721112240105867, 0.7100829784758389, 0.11942333905608393, 0.13613017421448603, 0.09712696672067977, 0.06734375667292625, 0.4157650511479005, 0.2888599951984361, 0.9573792899027467, 1.1617757845669985, 3.8402541959658265, 6.766721550375223, 9.451419990509748, 8.74422948807478, 7.07306063733995, 9.741508774459362, 7.947868695482612, 9.358970001339912, 6.462052473798394, 12.541647870093584, 7.854212271049619, 9.312357902526855, 5.235230354592204, 14.973729215562344, 11.018237415701151, 12.799633126705885, 11.992513686418533, 15.293387062847614, 16.303579956293106, 11.03235175833106, 14.874809123575687, 14.537579119205475, 16.177445724606514, 9.664561953395605, 8.272592145949602, 7.016342505812645, 4.710038686171174, 8.856172431260347, 5.695810290053487, 3.1290525337681174, 4.2072187922894955, 6.4487740863114595, 5.00781730748713, 7.5976785365492105, 3.9347168896347284, 4.2127451207488775, 6.952640349045396, 4.590831957757473, 3.1091173784807324, 2.189531810581684, 0.9852015157230198, 0.2944997535087168, 0.24152283294824883, 0.1603057238389738, 0.31865541357547045, 0.0643519515870139, 0.2481790367164649, 0.1864749492960982, 0.1512878280482255, 12.62490140274167, 46.41621172428131, 54.87815245985985, 46.65363818407059, 45.487393364310265, 32.26635619997978, 36.27768315374851, 69.94183614850044, 86.01971581578255, 100.21073073148727, 80.26308551430702, 77.45354667305946, 86.18317544460297, 31.387643851339817, 0.22541147482115775, 0.0974195658636745, 0.05010826374928001, 0.03281330253230408, 0.04190873420157004, 0.01854483623901615, 0.015763142437208444, 0.03032027634617407, 0.0354212577076396, 0.03086488286498934, 0.04424989099788945, 0.05234341588220559, 0.0011654280092443514, 0.04707330277597066, 0.07425655057886615, 0.07191755343228579, 0.026500451531319413, 0.03591920169128571, 0.02205207772931317, 0.06600829903618433, 0.03272035224654246, 0.056449871117365547, 0.048722811334300786, 0.008095101948129013, 0.07220743631478399, 0.06198499773745425, 0.052812319627264515, 0.00422080766838917, 0.020301789227232803, 0.020553674148686696, 0.01097864438634133, 0.008877054715412669, 0.09846139277215116, 0.06045792128134053, 0.04988327797036618, 0.053905762906651944, 0.08752097084652632, 0.01441223514120793, 0.04402460093842819, 0.03489720867946744, 0.10358719155192375, 0.016733969932829496, 0.03301297365396749, 0.037286820297595114, 0.028032120026182383, 0.03363402509421576, 0.01956500913365744, 0.020191151706967503, 0.1341025673900731, 0.14521275559673086, 0.12994275544770062, 0.1132190809585154, 0.0854432764754165, 0.08219826544518583, 0.22755632613552734, 0.2718679007375613, 0.13842109503457323, 0.16200913087232038, 0.1737559778848663, 0.20196220575599, 0.16099359083455056, 0.1319304940989241, 0.150094187411014, 0.20950598845956847, 0.25210474559571594, 0.20236780430423096, 0.16828752210130915, 0.08936669953982346, 0.10806057573063299, 0.1791722755297087, 0.10890724006458186, 0.0658580067101866, 0.13213421363616362, 0.11509766452945769, 0.1596719742519781, 0.3205306426389143, 0.13008173002162948, 0.17922438913956285, 0.17846535018179566, 0.10239289040328003, 0.17005874658934772, 0.10723966392106377, 0.22844905557576567, 0.20807224820600823, 0.31318085733801126, 0.15158338093897328, 0.2072541936649941, 0.29996166354976594, 0.27924122696276754, 3.1915323436260223, 45.195588022470474, 99.94971513748169, 116.03910058736801, 93.35690170526505, 80.35646170377731, 81.28200843930244, 75.18455162644386, 43.56028117239475, 84.1700890660286, 85.59612974524498, 61.67564570903778, 54.9630931019783, 43.814023956656456, 15.3141481988132, 0.836050434736535, 0.7474340836051852, 0.2911214082268998, 0.47373129695188254, 0.24346997612155974, 0.25400295155122876, 0.19826354953693226, 0.30552029027603567, 0.5410008388571441, 3.8078856328502297, 5.604625158011913, 11.371334418654442, 11.764092743396759, 12.561232969164848, 9.540899489074945, 10.724148396402597, 15.59899041429162, 15.361863188445568, 39.83361974358559, 28.57276439666748, 17.99017645418644, 19.648633562028408, 30.281684696674347, 24.748818688094616, 23.006042204797268, 24.06269710510969, 27.18904584646225, 28.392446972429752, 29.520063064992428, 32.07984700798988, 27.533938139677048, 22.355275824666023, 23.153139911592007, 20.317984744906425, 19.738386645913124, 26.489501483738422, 25.5739938095212, 29.40549161285162, 27.405924908816814, 17.220877334475517, 17.80827261507511, 14.67863230034709, 12.342651598155499, 13.95249791443348, 9.27889309823513, 10.34099880605936, 5.146108511835337, 3.260479406453669, 2.457346427254379, 0.6375418428797275, 0.20260361430700868, 0.20358599518658593, 0.2596567809814587, 0.22184604895301163, 0.3071946348063648, 0.6957179680466652, 0.36932329006958753, 0.9722528199199587, 17.558910995721817, 73.5481770336628, 108.38530048727989, 108.25094729661942, 62.05269567668438, 26.91341243684292, 32.30693802237511, 63.07606056332588, 84.33365508913994, 105.10413855314255, 88.44614401459694, 90.89392706751823, 98.30739766359329, 31.761707179248333, 0.379670342663303, 0.18260598502820358, 0.1803812786238268, 0.16810902074212208, 0.1279857417102903, 0.14974322577472776, 0.10378208695328794, 0.17884239088743925, 0.14070983394049108, 0.10581926006125286, 0.0771950843045488, 0.15740616770926863, 0.10323752867407165, 0.1887243692181073, 0.20866611477686092, 0.17947208834812045, 0.14954387006582692, 0.08642792090540752, 0.15731215244159102, 0.14947718067560345, 0.11900440411409363, 0.10821858639246784, 0.2645580726675689, 0.16653445054544136, 0.17764775577234104, 0.14615734631661326, 0.15965885308105499, 0.05684916512109339, 0.12176208387245424, 0.12936322716996074, 0.17234956350876018, 0.1804716425249353, 0.2775803004624322, 0.16951929428614676, 0.20149361371295527, 0.16903954034205526, 0.17470301769208163, 0.19905076042050496, 0.1853051464422606, 0.0798376792226918, 0.17021587409544736, 0.0890254600381013, 0.1921686320565641, 0.21753111330326647, 0.1555368016124703, 0.07965882163261995, 0.16738907812396064, 0.14287812227848917], [0.022273347203736193, 0.07624625592143275, 0.004733614086944726, 0.03988226657384075, 0.011325033465254819, 0.05145264200109523, 0.027251510546193458, 0.059533669118536636, 0.042474124566069804, 0.02076803608360933, 0.03754031196876895, 0.034113341171178035, 0.09710260943393223, 0.02940867965662619, 0.020803579391213134, 0.018773888987198006, 0.0678906898247078, 0.0060516428493428975, 0.022293657930276822, 0.009597776588634588, 0.04735216105473228, 0.00829510425319313, 0.13412649423116818, 0.060090539627708495, 0.02545424966228893, 0.033112803648691624, 0.005183908015169436, 0.03633732769230846, 0.05673893763741944, 0.08083614244242199, 0.020795777563762385, 0.025913160388881806, 0.008163725560734747, 0.02501206508895848, 0.0496084606857039, 0.11392082611564547, 0.073755207558861, 0.04231967992382124, 0.08966056775534526, 0.3882368642371148, 17.845776602625847, 59.87678423523903, 77.74746090173721, 87.80685871839523, 69.42287519574165, 52.97841779887676, 34.80314187705517, 22.750492617487907, 20.863956548273563, 42.271234542131424, 77.96930819749832, 50.63612088561058, 26.41971442848444, 12.43204465135932, 1.1457282956689596, 0.0926475488813594, 0.07815911929355934, 0.13106458587571979, 0.09854416450252756, 0.03841319266939536, 0.2238222397863865, 0.14282262447522953, 0.4687365243444219, 2.586625227704644, 1.3245478877797723, 5.066931210458279, 11.156530994921923, 7.570032645016909, 10.24872075766325, 8.070086762309074, 8.331997208297253, 8.645943012088537, 7.427052017301321, 0.7578278915025294, 6.670942464843392, 5.477485405281186, 9.58722660318017, 5.027186293154955, 10.393878668546677, 5.677303858101368, 13.821972068399191, 5.173997115343809, 8.592956755310297, 16.555827520787716, 12.084008026868105, 11.548900790512562, 16.521492563188076, 13.696814384311438, 7.014698619022965, 7.940064389258623, 7.4053670559078455, 7.30247950181365, 9.591067247092724, 9.844117518514395, 11.76504174247384, 16.00947193801403, 9.043166097253561, 4.802820682525635, 4.534775465726852, 1.24412294710055, 2.876651552505791, 6.9159039203077555, 3.2061815075576305, 2.1743259765207767, 1.0196693474426866, 0.8582817355636507, 0.2017106770654209, 0.42015725921373814, 0.022413364495150745, 0.1132504886481911, 0.11640350305242464, 0.05133206526807044, 0.03625618868682068, 0.06944344087969512, 0.09522151740384288, 4.79421746917069, 35.8548304438591, 72.76011452078819, 81.44650161266327, 61.31041690707207, 30.88728290051222, 14.99692127108574, 16.272803507745266, 29.299131520092487, 63.31833556294441, 76.05158150196075, 65.92779234051704, 73.34218248724937, 30.283877179026604, 0.8757435798179358, 0.3766518796328455, 0.008727915501367534, 0.032961646720650606, 0.013504364032996818, 0.021051770272606518, 0.02991203760757344, 0.024924421159084886, 0.06012122372339945, 0.053893127842457034, 0.0814531120704487, 0.0632191522163339, 0.03777876772801392, 0.10978629914461635, 0.012514749996626051, 0.004217499545120518, 0.025638795814302284, 0.11144378950120881, 0.04099913203390315, 0.02540841647714842, 0.12434143296559341, 0.02670758309250232, 0.05551663154619746, 0.016818133190099616, 0.05962777344393544, 0.06303227200987749, 0.045155778716434725, 0.04027289600344375, 0.04402300161018502, 0.042956795150530525, 0.04983244085451588, 0.049699971204972826, 0.07451181969372556, 0.042576362830004655, 0.0868522809469141, 0.024980716771096922, 0.044414146832423285, 0.05414254512288608, 0.035333168489160016, 0.018335890126763843, 0.06270675119594671, 0.05673973173543345, 0.02884041161451023, 0.02626240580866579, 0.05295820359606296, 0.03513381649099756, 0.01850797747465549, 0.03468215654720552, 0.03350977101945318, 0.08634938683826476, 0.013468566539813764, 0.01314734925472294, 0.05048288505349774, 0.07290486959391274, 0.0790854828665033, 0.12446635126252659, 0.02643635409185663, 0.09244339147699066, 0.04267733573215082, 0.05194950615987182, 0.04714811497251503, 0.06186907798110042, 0.01538174161396455, 0.04809195612324402, 0.009907500789267942, 0.022255214680626523, 0.022507129287987482, 0.004599652256729314, 0.026577774042380042, 0.105924444651464, 0.0777208068757318, 0.03303778365079779, 0.023416399344569072, 0.024457576873828657, 0.061611686323885806, 0.030923434605938382, 0.04499634313106071, 0.003722566593751253, 0.013470733611029573, 0.020011466622236185, 0.019486946330289356, 0.019393964503251482, 0.08627135001006536, 0.21901333064306527, 0.07163993825088255, 0.09990433565690182, 0.8928244351409376, 26.846737414598465, 77.8530952334404, 94.39528718590736, 95.8777092397213, 87.20242515206337, 82.72827923297882, 52.84550093114376, 38.280643075704575, 37.50913247466087, 40.73234751820564, 72.61946886777878, 55.86244784295559, 31.0475791990757, 17.84574430435896, 1.4754104800522327, 0.095843177405186, 0.2133164121187292, 0.30015429540071636, 0.039273916991078295, 0.15023244952317327, 0.7208710152190179, 1.0719989519566298, 3.0761194741353393, 6.288952762261033, 7.934389868751168, 10.519620571285486, 11.804110296070576, 10.611775126308203, 7.905529942363501, 9.341734126210213, 10.336560644209385, 9.24561258405447, 6.174084451049566, 4.46672729216516, 5.777503056451678, 5.450306413695216, 5.212873304262757, 7.736318372189999, 7.8361879382282495, 10.010127760469913, 13.380966782569885, 11.075254306197166, 10.515061765909195, 9.207383785396814, 11.779762152582407, 7.615059278905392, 7.666265806183219, 6.2139390874654055, 2.4922337802127004, 3.5119028901681304, 4.08555549569428, 6.8615012895315886, 8.37689084932208, 11.837328113615513, 14.185380768030882, 12.542142793536186, 8.253192286938429, 5.676293112337589, 4.53217308036983, 2.902865158393979, 2.2104929108172655, 7.486883131787181, 6.693785889074206, 7.251109108328819, 5.961703397333622, 3.367246314883232, 1.7277617077343166, 1.7811855347827077, 0.23052941425703466, 0.11116620400571264, 0.22865258215460926, 0.11450076999608427, 0.06234367028810084, 0.02375225642026635, 0.18685682880459353, 4.013793021440506, 36.49483010172844, 60.685806423425674, 51.22297279536724, 36.22369185090065, 32.23205164074898, 33.77766810357571, 28.33831127732992, 42.574427872896194, 85.08956372737885, 87.89136618375778, 75.44695794582367, 88.53927701711655, 52.996041253209114, 3.509193635545671, 0.4205558815738186, 0.05543614191992674, 0.03680185276607517, 0.030092396191321313, 0.04089667112566531, 0.06430606459616683, 0.09638637013267726, 0.05597742732788902, 0.043587628097156994, 0.046401562649407424, 0.07183901194366626, 0.04729352396680042, 0.10417444558697753, 0.03680288064060733, 0.03212600699043833, 0.01052438878105022, 0.07355819703661837, 0.04756842659844551, 0.07453630314557813, 0.08623893299954943, 0.03587517006963026, 0.02410586010228144, 0.026485410053282976, 0.01731199907226255, 0.019687107269419357, 0.029344077556743287, 0.04529663463472389, 0.05556975447689183, 0.015892958908807486, 0.09679025431978516, 0.03846412626444362, 0.03634118314948864, 0.09066751372301951, 0.01343330895906547, 0.04725036065792665, 0.11214952741283923, 0.03763692104257643, 0.023042169523250777, 0.03956733249651734, 0.09031794732436538, 0.012567765315907309, 0.04219951879349537, 0.03535466850735247, 0.04603554283676203, 0.028054545873601455, 0.045028890017420053, 0.13905671483371407, 0.20614085340639576, 0.14513821428408846, 0.10747441265266389, 0.1072062821185682, 0.16126754722790793, 0.14592321356758475, 0.1935589121421799, 0.16411197662819177, 0.12143114538048394, 0.1338159796432592, 0.16560624644625932, 0.1747918824548833, 0.2298450205125846, 0.17756745539372787, 0.17058668076060712, 0.13961964868940413, 0.1372900471324101, 0.1708454973413609, 0.06765836791601032, 0.06428420834708959, 0.1554600932286121, 0.22599523334065452, 0.23786840873071924, 0.08816148139885627, 0.11166319804033265, 0.13384407735429704, 0.15428558515850455, 0.12880011519882828, 0.12888577388366684, 0.11500635067932308, 0.09024617422255687, 0.10743085600552149, 0.12788749620085582, 0.12854753265855834, 0.20298110030125827, 0.3795318875927478, 0.1593349056201987, 0.13819344865623862, 1.1720005609095097, 31.678394749760628, 93.48487883806229, 104.19067516922951, 106.4136166870594, 82.7270556986332, 72.0341482758522, 50.28735660016537, 33.17593239247799, 36.53339043259621, 61.62493363022804, 93.0324675142765, 66.77263140678406, 42.60918840765953, 20.72277892380953, 2.14311848860234, 0.2155376155860722, 0.35907188546843827, 0.6305870285723358, 0.38120934914331883, 0.15334550669649616, 0.41436883388087153, 0.44336866994854063, 2.236059126444161, 5.608131419867277, 9.973921403288841, 17.011151388287544, 27.69860040396452, 21.90946664661169, 21.058185026049614, 23.090648464858532, 23.494526892900467, 24.13656324148178, 17.964601926505566, 6.911688996478915, 17.313856445252895, 14.295704048126936, 24.08447753638029, 16.42085686326027, 26.931828148663044, 20.979842729866505, 28.645830675959587, 18.65591213107109, 24.59272876381874, 32.698488011956215, 33.11077728867531, 28.748979941010475, 40.26142358779907, 38.25250178575516, 20.898285806179047, 24.723453149199486, 16.282073110342026, 18.513167090713978, 18.632626980543137, 17.874656952917576, 21.26981656998396, 27.122437320649624, 16.69676385819912, 10.910589192062616, 13.622408676892519, 9.894040189683437, 13.124131914228201, 17.19100333750248, 14.729382377117872, 8.670574240386486, 6.5997423604130745, 3.9796696649864316, 1.5897412388585508, 1.5807741950266063, 0.15045396576169878, 0.38972997630480677, 0.26146052638068795, 0.24774508812697604, 0.24745238508330658, 0.12996139819733799, 0.4053314938209951, 6.612819358706474, 52.455163076519966, 103.35737988352776, 106.97120636701584, 77.9495720565319, 46.63629971444607, 24.196248538792133, 25.12714348733425, 40.576058104634285, 84.10579651594162, 97.83860921859741, 84.43886384367943, 102.9566153883934, 53.98573614656925, 2.6769639551639557, 0.8398069487884641, 0.2639683027518913, 0.22257694567088038, 0.1024438907916192, 0.11356113682268187, 0.1631389616522938, 0.13504620816092938, 0.11417240675655194, 0.12124298125854693, 0.25334475561976433, 0.15224006288917735, 0.15200763707980514, 0.20291442575398833, 0.2525870525278151, 0.11569527894607745, 0.09835154749453068, 0.16289718478219584, 0.16566526202950627, 0.12761060090269893, 0.36773162079043686, 0.10753023700090125, 0.16530150576727465, 0.10890724006458186, 0.15633468457963318, 0.15738425950985402, 0.17296256264671683, 0.17757236841134727, 0.16316073626512662, 0.13075588212814182, 0.15598624624544755, 0.09320541386841796, 0.2443552840850316, 0.12150829163147137, 0.11134644941193983, 0.16600187052972615, 0.1877601709566079, 0.1307823768001981, 0.14006891520693898, 0.19168240658473223, 0.22699986380757764, 0.19550108292605728, 0.13144606462446973, 0.1095996935328003, 0.1289109475328587, 0.08165758117684163, 0.12097644634195603], [0.05095141030324157, 0.04850539546168875, 0.06634963501710445, 0.0074612002208596095, 0.014904394083714578, 0.02183037966460688, 0.05896653841773514, 0.05226694127486553, 0.04533758263278287, 0.03344777942402288, 0.0345491265761666, 0.02800356403895421, 0.07493256547604688, 0.033970882213907316, 0.007721830888840486, 0.012608415527211037, 0.051612875395221636, 0.028514100413303822, 0.007233581209220574, 0.050711893272819, 0.0584930778859416, 0.0576224087853916, 0.06162916019093245, 0.025048769857676234, 0.040023319161264226, 0.03883066186972428, 0.03923159230907913, 0.04961910308338702, 0.08418489087489434, 0.10916812723735347, 0.053736657137051225, 0.03589515239582397, 0.09763377194758505, 0.07013300739345141, 0.02443496177875204, 0.05507538764504716, 0.024790392999420874, 0.22459232190158218, 1.2259771395474672, 34.2375498265028, 21.171627938747406, 66.3724672794342, 86.42066270112991, 57.28118151426315, 45.23381397128105, 21.19861599057913, 23.876970671117306, 46.95543318986893, 41.87757566571236, 47.89206013083458, 24.518598541617393, 16.662014722824097, 5.374254444614053, 0.03469128496362828, 0.08611414828919806, 0.05756635066063609, 0.09153075763606466, 0.07018540301942267, 0.1474980657803826, 0.07993706763954833, 0.540249488549307, 2.361004496924579, 2.9257214069366455, 9.329762868583202, 6.119124200195074, 5.997783886268735, 8.618138954043388, 8.00502760335803, 5.683021126314998, 3.6325347796082497, 10.546774864196777, 6.681182440370321, 6.956695206463337, 5.584895666688681, 10.099063888192177, 5.7829248905181885, 6.685640551149845, 3.0627059563994408, 9.561738520860672, 7.021761490032077, 8.507202956825495, 7.217317521572113, 10.131539795547724, 8.867201339453459, 4.93291050195694, 4.44370242767036, 6.670859819278121, 11.095539517700672, 7.383508728817105, 7.9550678841769695, 12.06394225358963, 19.49200216680765, 34.20038402080536, 35.36822855472565, 37.37146206200123, 38.40754106640816, 34.40919041633606, 26.339890211820602, 23.05776122957468, 10.174206756055355, 6.196765433996916, 5.2380099054425955, 5.8084305468946695, 4.125914555042982, 1.9968085270375013, 2.3013650346547365, 1.4440960041247308, 1.4260454289615154, 0.2871616941411048, 0.5548421898856759, 0.27182642952539027, 0.10520219395402819, 0.07421707574394532, 0.0897405193245504, 0.07836904318537563, 0.13277335121529177, 1.0181026440113783, 15.639783125370741, 64.37704995274544, 81.54362440109253, 57.00107954442501, 39.485748410224915, 83.89183759689331, 84.19592767953873, 31.03349145501852, 75.60344874858856, 67.31042414903641, 70.21018534898758, 79.2776007950306, 49.135809391736984, 5.5611250922083855, 0.1521865391987376, 0.11961086493101902, 0.020020222109451424, 0.03141963454254437, 0.05181453547265846, 0.04978221229976043, 0.0531989674345823, 0.04051647258165758, 0.06758445742889307, 0.06466855178587139, 0.012816138023481471, 0.05924893674091436, 0.06530475788167678, 0.027772208777605556, 0.09420854519703425, 0.02589948631793959, 0.032436944602523, 0.10169080385821871, 0.02339615355595015, 0.051456378714647144, 0.0409174995002104, 0.027443760191090405, 0.04651305920560844, 0.02047089128609514, 0.08443860147963278, 0.015237368843372678, 0.05300786069710739, 0.05604563812084962, 0.0741071265656501, 0.0499970974487951, 0.010630558572302107, 0.025277698296122253, 0.00825749128125608, 0.06394941068720073, 0.06467250743298791, 0.05584188147622626, 0.015550392818113323, 0.11450911173596978, 0.06097357290855143, 0.02622560456075007, 0.03856005998386536, 0.024438006439595483, 0.03311320069769863, 0.029608881413878407, 0.049975708752754144, 0.02492400184564758, 0.0626006537640933, 0.07919029638287611, 0.018017289839917794, 0.05343923403415829, 0.11402241871110164, 0.024820620674290694, 0.03887738748744596, 0.007985920892679133, 0.03298769239336252, 0.032618462792015634, 0.04849247467063833, 0.04310710974095855, 0.07492080243537202, 0.030513754245475866, 0.06418889432097785, 0.04811014616279863, 0.04457274750166107, 0.038329623130266555, 0.043835987817146815, 0.045469940960174426, 0.02654752224771073, 0.02935888525826158, 0.1076621537504252, 0.020394377716002055, 0.06002591711876448, 0.03322804805065971, 0.010776658691611374, 0.019363439969311003, 0.0817961327265948, 0.05622315984510351, 0.08699105514097027, 0.014332681548694381, 0.07167228846810758, 0.04374560165160801, 0.04109990826691501, 0.040678067816770636, 0.0601925441151252, 2.7611888106912374, 51.7826371639967, 29.20821949839592, 73.84811773896217, 99.0150336921215, 76.84785157442093, 67.53836631774902, 36.168009638786316, 33.7050312012434, 29.784116595983505, 36.93404093384743, 42.94631391763687, 33.99723932147026, 22.59252369403839, 7.747893976047635, 0.1473188222735189, 0.11227680573938414, 0.14806689228862524, 0.111034086876316, 0.1777732084156014, 0.5083676555659622, 1.6191718471236527, 2.222444457001984, 5.27258662506938, 7.439506324008107, 11.39305405318737, 10.741740502417088, 8.500963691622019, 8.003179002553225, 8.734811693429947, 5.59100478887558, 4.292670506983995, 4.303481876850128, 6.120197167620063, 5.7623993419110775, 6.240787021815777, 6.6350833140313625, 6.947724837809801, 6.461569424718618, 8.122365307062864, 8.245357107371092, 8.346721418201923, 9.354376997798681, 10.798534154891968, 7.263335902243853, 7.5783337745815516, 3.1242310674861073, 2.6806343207135797, 1.2791349808685482, 2.352127698250115, 4.588802391663194, 6.083509661257267, 13.678522165864706, 21.67891401797533, 35.83808474242687, 37.40476727485657, 41.029540970921516, 40.7944779843092, 37.11111903190613, 32.10442788898945, 25.48812221735716, 13.17803867161274, 7.383338212966919, 4.572827573865652, 6.545258983969688, 4.431297993287444, 5.658216057345271, 7.446693638339639, 3.416243498213589, 3.1105185532942414, 1.6618391638621688, 0.858621223596856, 0.7032643631100655, 0.35721028223633766, 0.2506341354455799, 0.06316323881037533, 0.12629698467208073, 0.10514757188502699, 1.2011499842628837, 18.11893444508314, 56.0134669393301, 58.521138578653336, 42.816763669252396, 28.571259677410126, 58.110506013035774, 79.48308616876602, 48.097499907016754, 88.003368973732, 83.62133011221886, 79.9402092397213, 94.82014238834381, 74.67143476009369, 16.890428066253662, 0.12930995580973104, 0.09018404161906801, 0.024187696726585273, 0.05253992545476649, 0.0448256417439552, 0.023244469703058712, 0.05428110409411602, 0.017526967712910846, 0.01123463338444708, 0.02916431269113673, 0.02155267728085164, 0.030017702738405205, 0.0055993265686993254, 0.04185752601188142, 0.04198383954644669, 0.045079730844008736, 0.03823962659225799, 0.043057712391600944, 0.03178847451636102, 0.03317832415632438, 0.04955693337251432, 0.010261132301820908, 0.04049387789564207, 0.02990985754877329, 0.017137742797785904, 0.040360406346735545, 0.0666873122099787, 0.043490944808581844, 0.058092863619094715, 0.01652080100029707, 0.022737966901331674, 0.02927951813035179, 0.016429847091785632, 0.09024087528814562, 0.04331929718318861, 0.050360950190224685, 0.012254545599716948, 0.06981943515711464, 0.04944891748891678, 0.006065452826078399, 0.022625685523962602, 0.010525456546019996, 0.020150704658590257, 0.01535774612420937, 0.0835923601698596, 0.07762941881082952, 0.1722432137466967, 0.1566125446697697, 0.10709703055908903, 0.1294394605793059, 0.269464707816951, 0.15091531444340944, 0.16698373190592974, 0.1248437407775782, 0.12356612613075413, 0.10674377568648197, 0.12718560261419043, 0.15712033695308492, 0.12914739578263834, 0.14191260299412534, 0.10754104267107323, 0.13006715424126014, 0.10891959682339802, 0.15100875083589926, 0.1032122882315889, 0.09924448473611847, 0.1075893416418694, 0.09847921915934421, 0.1910303407930769, 0.20217227807734162, 0.16344018455129117, 0.14395174279343337, 0.1348277198849246, 0.1453262151335366, 0.17613286909181625, 0.21128969587152824, 0.16520924196811393, 0.24660301191033795, 0.14065262919757515, 0.14872968953568488, 0.19515988795319572, 0.13400660769548267, 0.1703610084950924, 3.844300266355276, 63.00795301795006, 44.188391268253326, 83.30089330673218, 105.48357099294662, 75.14051958918571, 58.60755354166031, 26.882476396858692, 35.38526304066181, 67.38483935594559, 60.666993632912636, 65.99149972200394, 43.62507149577141, 30.027100257575512, 9.94592260569334, 0.3768491721712053, 0.30158972775097936, 0.4127975588198751, 0.27451128233224154, 0.2908235101494938, 0.35311101470142603, 1.180116687901318, 1.1672852514311671, 6.927668089047074, 9.338234513998032, 22.828076854348183, 16.852504201233387, 20.64487550407648, 26.7327169328928, 25.733385756611824, 19.03936855494976, 13.762701898813248, 27.746342942118645, 20.743510611355305, 15.507833305746317, 13.372616730630398, 18.122848235070705, 13.86328725144267, 16.084926389157772, 14.657406639307737, 23.090735860168934, 22.102386094629765, 23.937904201447964, 23.032162003219128, 25.946233235299587, 26.710613518953323, 20.410633273422718, 17.094021141529083, 16.625226996839046, 26.498165018856525, 13.95374994724989, 13.996238317340612, 19.067283757030964, 26.057295575737953, 42.01415553689003, 41.75345152616501, 44.491797387599945, 45.5380180478096, 40.63262186944485, 35.891338884830475, 32.834953889250755, 17.1162461489439, 15.581426806747913, 15.086076837033033, 17.584863603115082, 17.688594236969948, 11.91974189132452, 10.389773938804865, 7.775076292455196, 3.9156060526147485, 2.6468327594920993, 1.9874524790793657, 1.0661349166184664, 0.4267627000808716, 0.4036974924383685, 0.22456619830336422, 0.37522597645875067, 0.2780668227933347, 2.2529257088899612, 24.4580202922225, 92.24730804562569, 117.3293137550354, 77.86925956606865, 54.58077281713486, 99.26667898893356, 93.95463243126869, 40.00904493033886, 92.8281220793724, 88.91288816928864, 88.87004166841507, 107.17391029000282, 80.77787429094315, 13.954206872731447, 0.2875644725281745, 0.35292529966682196, 0.09976280067348853, 0.21303236251696944, 0.21725349070038646, 0.1393380036461167, 0.17270315234782174, 0.08586887590354308, 0.1684154535178095, 0.14809953194344416, 0.08974560303613544, 0.2346967812627554, 0.16222706995904446, 0.1606056999298744, 0.15826884016860276, 0.11741882044589147, 0.10335043902159669, 0.19543518021237105, 0.1104499350185506, 0.18276688264450058, 0.1304235780844465, 0.12264944758499041, 0.1809576601954177, 0.10156420830753632, 0.10518658658838831, 0.1361671183258295, 0.19557102292310447, 0.13395013025728986, 0.12541192903881893, 0.21820424124598503, 0.12367892515612766, 0.15420231618918478, 0.10859060275834054, 0.17657892953138798, 0.16289570048684254, 0.17082581558497623, 0.09855950469500385, 0.19307087583001703, 0.24287343781907111, 0.1717415516031906, 0.07766475246171467, 0.13409688253886998, 0.08836995068122633, 0.15216154366498813, 0.16580664116190746], [0.06238366462639533, 0.003164780227962183, 0.04439584547071718, 0.06736134557286277, 0.08484201069222763, 0.0693287790636532, 0.028960392774024513, 0.014279296083259396, 0.06952063165954314, 0.029765728759230115, 0.10093250704812817, 0.02801759990688879, 0.06500257019069977, 0.058272229580325074, 0.02949247369542718, 0.07154802326112986, 0.03301383083453402, 0.04617359343683347, 0.02360211994528072, 0.015619445948686916, 0.07271457550814375, 0.03446585760684684, 0.035681328517966904, 0.10126584267709404, 0.03373532454133965, 0.039119887951528654, 0.03715818755154032, 0.033508167980471626, 0.05413719794887584, 0.043782464126707055, 0.015700803887739312, 0.1405204230104573, 0.029336257175600622, 0.039403807677445, 0.028780262400687207, 0.05218274091021158, 0.22534621035447344, 7.08483905531466, 50.927964225411415, 90.42144522070885, 27.42109179496765, 24.448839984834194, 47.596546187996864, 36.034253016114235, 21.998911947011948, 72.23662421107292, 61.853825747966766, 63.67696791887283, 51.27911098301411, 34.712011367082596, 14.693958777934313, 2.834092886187136, 0.07881709258072078, 0.05829395595355891, 0.03176759048074018, 0.10741594625869766, 0.1605124119669199, 0.2754302986431867, 1.6294102789834142, 0.9913478046655655, 2.2301003336906433, 5.900999279692769, 6.800635680556297, 10.512818936258554, 10.884556788951159, 9.322486259043217, 7.832259424030781, 9.501637145876884, 2.9543191473931074, 7.2833931259810925, 9.260381441563368, 15.458231717348099, 16.17551352828741, 23.80723301321268, 20.399068593978882, 27.88259983062744, 18.50674543529749, 21.49052582681179, 12.1787815913558, 12.66759306192398, 8.593622669577599, 7.45112182572484, 3.5740870283916593, 5.301387179642916, 11.335659082978964, 13.311607204377651, 29.707109928131104, 36.632363721728325, 54.10671405494213, 41.972536370158195, 44.91683878004551, 59.201818853616714, 55.1744719594717, 66.44692808389664, 77.25347980856895, 71.56660616397858, 76.2675467133522, 71.97485625743866, 63.64413768053055, 49.14123550057411, 26.702046878635883, 19.282982982695103, 11.3613086566329, 7.800743915140629, 9.67659305781126, 3.392993970774114, 1.9064239645376801, 2.349752113223076, 1.4047194295562804, 1.0660544084385037, 1.2768097431398928, 0.458511866745539, 0.04008715128293261, 0.14676329505164176, 0.06176090624649078, 0.07182793167885393, 0.10080861291498877, 0.5298533057793975, 6.964086759835482, 30.22791188210249, 64.01133477687836, 89.31919276714325, 117.65299558639526, 111.01839199662209, 28.00797790288925, 26.754812747240067, 47.641026601195335, 71.44499748945236, 69.87131953239441, 74.72434312105179, 73.66808339953423, 18.070751130580902, 0.9675272984895855, 0.26039141812361777, 0.07111247163265944, 0.12178120901808143, 0.06327071663690731, 0.09950016945367679, 0.06343738816212863, 0.06720141274854541, 0.010021795242209919, 0.039725762471789494, 0.06073179974919185, 0.049122086784336716, 0.07016727235168219, 0.0686322437832132, 0.08304330447572283, 0.08720745056052692, 0.0504689289664384, 0.03623395394242834, 0.038269950746325776, 0.020457543760130648, 0.010757526124507422, 0.10412399438791908, 0.077999312634347, 0.045110645005479455, 0.016536716357222758, 0.023545746407762635, 0.056338289214181714, 0.039098959387047216, 0.05773145625425968, 0.04011341217847075, 0.06675783108221367, 0.11146517819724977, 0.038771197287132964, 0.018956950843858067, 0.019748657286982052, 0.01298334946113755, 0.0623326122877188, 0.03323383309179917, 0.019571026095945854, 0.04384537227451801, 0.03512863258947618, 0.07032505294773728, 0.03449077150435187, 0.06763792916899547, 0.013742996979999589, 0.02460471136146225, 0.0106828799835057, 0.06756827860954218, 0.061432628353941254, 0.08212757587898523, 0.016865747529664077, 0.05048193139373325, 0.06010100390994921, 0.023422188096446916, 0.025503934593871236, 0.016364714356313925, 0.018762407962640282, 0.026859049867198337, 0.04517794295679778, 0.08301322523038834, 0.03506006185489241, 0.045844747801311314, 0.040173247834900394, 0.01109108347009169, 0.0771765157696791, 0.049567690803087316, 0.06071327574318275, 0.02892081032769056, 0.018985616297868546, 0.06107427121605724, 0.042810926024685614, 0.021914763710810803, 0.05374340697017033, 0.043769049807451665, 0.060188785137142986, 0.05439405154902488, 0.008231651554524433, 0.051453154082992114, 0.057808253695839085, 0.05354621462174691, 0.1283010802580975, 12.337316684424877, 70.83051726222038, 104.00557190179825, 33.71987320482731, 33.80691513419151, 78.46758306026459, 57.63922110199928, 37.29416660964489, 50.14497444033623, 49.08865012228489, 54.185814410448074, 45.49508035182953, 36.239833384752274, 18.57597392052412, 3.8252860866487026, 0.02718509018450277, 0.32910422945860773, 0.030730817597941495, 0.17213258921401575, 0.8348780788946897, 2.5174955371767282, 5.946323722600937, 5.002135187387466, 5.521725006401539, 6.7202614434063435, 8.27382517978549, 11.721347887068987, 8.695745039731264, 5.787382051348686, 3.7051928183063865, 1.1176464962773025, 1.0803821333684027, 4.936838066205382, 8.17452510818839, 12.487257588654757, 13.523963559418917, 20.921284072101116, 22.43912972509861, 28.59693869948387, 19.090918488800526, 18.77971898764372, 10.755053088068962, 8.709506001323462, 9.005075991153717, 4.834164250642061, 2.792837074957788, 3.119230060838163, 7.2790665831416845, 14.40231777727604, 27.942940592765808, 39.71844032406807, 54.41946767270565, 43.943619802594185, 48.526276499032974, 64.44455713033676, 60.935886204242706, 72.14809656143188, 82.42467552423477, 77.61694550514221, 80.84569305181503, 74.70062479376793, 70.69394499063492, 54.78818088769913, 32.667857855558395, 18.370819129049778, 9.71544312313199, 6.193206449970603, 3.1426204182207584, 4.482843177393079, 3.4915685188025236, 3.051014933735132, 1.5605907468125224, 3.716992372646928, 2.2497647535055876, 0.9726479987148196, 0.0935100506467279, 0.2221802677377127, 0.06260285052121617, 0.05873399757547304, 0.042317319894209504, 0.39738665451295674, 8.223151098936796, 31.905546560883522, 61.517779380083084, 57.20615454018116, 111.25512689352036, 114.67807441949844, 35.327623933553696, 49.85200256109238, 63.49631801247597, 88.24740707874298, 80.18943026661873, 84.28569406270981, 89.93763998150826, 39.676254987716675, 1.5489023365080357, 0.32130378240253776, 0.09920604890794493, 0.09579054429195821, 0.02709276701352792, 0.03595918489736505, 0.06830450394772924, 0.04765893521835096, 0.018691792611207347, 0.06024863563652616, 0.029918685395387, 0.013423258424154483, 0.05423470873211045, 0.08004450093721971, 0.02965949403005652, 0.07107073324732482, 0.052917838183930144, 0.039142920504673384, 0.02742544955253834, 0.07387882709736004, 0.03372965453309007, 0.06260732567170635, 0.11498934065457433, 0.030475229359581135, 0.05195955483941361, 0.05015864815504756, 0.04250614081684034, 0.0795826327521354, 0.04590790827933233, 0.02898406357417116, 0.06448593150707893, 0.09577247299603187, 0.03355174689204432, 0.016463702013425063, 0.051145340912626125, 0.09131690778303891, 0.04667324436013587, 0.07646053622011095, 0.02253765382192796, 0.02315310761332512, 0.010177177773584845, 0.05229006659646984, 0.03848625339742284, 0.09315723364125006, 0.15619809972122312, 0.09575584888807498, 0.09741066751303151, 0.1590405698516406, 0.1527577851084061, 0.1385816215770319, 0.11434322688728571, 0.156690870935563, 0.07897828705608845, 0.14823645818978548, 0.14284002041677013, 0.1107846584636718, 0.13885390071664006, 0.1648139741155319, 0.16748481517424807, 0.1790941719082184, 0.09703822812298313, 0.17535189224872738, 0.19272899808129296, 0.26612810092046857, 0.165444087178912, 0.2193418052047491, 0.13044306688243523, 0.17646876513026655, 0.07573165072244592, 0.10572650644462556, 0.1173036836553365, 0.15158958529355004, 0.2198937998036854, 0.1016157801495865, 0.1499441548367031, 0.19366025982890278, 0.1480452809482813, 0.15499549394007772, 0.1343906542751938, 0.165161507029552, 0.2619885792955756, 15.609371457248926, 87.91254624724388, 119.67815011739731, 42.090178057551384, 42.778826504945755, 68.2537691295147, 44.286585599184036, 29.763517901301384, 90.19162595272064, 80.3802940249443, 85.06614178419113, 69.45220962166786, 53.11194643378258, 24.604384638369083, 5.187832172960043, 0.19517810025718063, 0.54508579778485, 0.18639708316186443, 0.19318869919516146, 0.7584114570636302, 2.5391054525971413, 8.071684576570988, 5.906443437561393, 10.326080806553364, 17.670807391405106, 22.375388145446777, 26.73393476754427, 25.29649470001459, 25.879415720701218, 23.772869557142258, 23.055150769650936, 14.014692027121782, 19.486484862864017, 21.37138321995735, 24.362062141299248, 24.00371477007866, 32.13554061949253, 26.69809129089117, 37.810919880867004, 25.433785133063793, 35.000309497117996, 21.4281065762043, 24.165293499827385, 25.951746739447117, 21.573152393102646, 15.781212486326694, 16.79016664624214, 19.78895053267479, 17.99286860972643, 31.09345033764839, 40.316041857004166, 59.342931881546974, 53.60768303275108, 53.49555104970932, 70.31403377652168, 65.44046849012375, 76.11429333686829, 88.18175420165062, 81.50699436664581, 82.35371813178062, 80.69715142250061, 75.5134391784668, 60.12057535350323, 34.35265704989433, 27.369393669068813, 20.07427342236042, 20.06971936672926, 23.407796546816826, 16.382404826581478, 8.831009231507778, 8.177558295428753, 5.292015932500362, 6.264516748487949, 4.276820132508874, 1.547953337430954, 0.20292088243877515, 0.2853540302021429, 0.17014988232403994, 0.3337262955028564, 0.13809880998451263, 1.5197259583510458, 11.489926055073738, 44.52199436724186, 85.85277557373047, 123.11366736888885, 128.76300662755966, 113.12718003988266, 41.20473437011242, 41.14986531436443, 60.36377750337124, 90.99567040801048, 84.06250923871994, 93.98215055465698, 102.36333802342415, 40.90723313391209, 1.4820074010640383, 0.38503693125676364, 0.13650659151608124, 0.2984841068973765, 0.18654748681001365, 0.10704727697884664, 0.30526971153449267, 0.11301344668027014, 0.08937351245549507, 0.17349635978462175, 0.1246667533996515, 0.10208281368250027, 0.1191171734535601, 0.1892257493454963, 0.17672848713118583, 0.1683765946654603, 0.1509340907796286, 0.10834287386387587, 0.20799577730940655, 0.2662881970172748, 0.12391850526910275, 0.20581387798301876, 0.30430396960582584, 0.09982233576010913, 0.06636577672907151, 0.09743794144014828, 0.1440550942788832, 0.14142008410999551, 0.16593007516348734, 0.13948229199741036, 0.13800319167785347, 0.31681901367846876, 0.32764896692242473, 0.16613288928056136, 0.20332515996415168, 0.15375201066490263, 0.12340249741100706, 0.11120202747406438, 0.0893514409835916, 0.13664991507539526, 0.12419255814165808, 0.1427639354369603, 0.20138401334406808, 0.21727088664192706], [0.10639146334142424, 0.04905338246317115, 0.047754119368619286, 0.06725199753418565, 0.10772002642625012, 0.008742361405893462, 0.08271705635706894, 0.09694839856820181, 0.1737646758556366, 0.22855310468003154, 0.2147999801672995, 0.08865157346008345, 0.057381941805942915, 0.03855963695968967, 0.12271243365830742, 0.07304552884306759, 0.017157778929686174, 0.0664233005954884, 0.1594555046176538, 0.20199631486320868, 0.052336788503453135, 0.14666230359580368, 0.15326338063459843, 0.12432304254616611, 0.1775267263292335, 0.12022994967992418, 0.34550738520920277, 0.281523242010735, 0.4008656943915412, 0.19293988676508889, 0.10506482241908088, 0.08698352234205231, 0.06495629728306085, 0.20297888870118186, 0.20562069694278762, 0.2958844229578972, 17.49383568763733, 86.73327192664146, 82.72000327706337, 98.09566542506218, 78.20611909031868, 31.182958334684372, 24.377240426838398, 20.985390432178974, 43.25451157987118, 56.34154133498669, 62.67028793692589, 30.845791026949883, 19.008468613028526, 4.170278124511242, 0.7334868132602423, 0.027770347842306364, 0.030970145380706526, 0.016882720447028987, 0.186204451310914, 0.21657061093719676, 1.4863498555496335, 1.4968241122551262, 2.736282334662974, 4.6320027485489845, 7.2969564981758595, 6.765919793397188, 7.863726010546088, 8.136962223798037, 10.81073435023427, 7.509447745978832, 11.43521374091506, 23.196676075458527, 32.82758988440037, 43.186559826135635, 48.67338180541992, 56.876605823636055, 50.60704484581947, 58.79964843392372, 50.868520215153694, 49.93231885135174, 43.911161944270134, 49.53907795250416, 39.98017027974129, 26.81625545024872, 15.945154689252377, 12.429558634757996, 11.734953057020903, 32.6068065315485, 63.83161962032318, 103.53613749146461, 122.42497712373734, 124.53020855784416, 135.70383578538895, 100.59726879000664, 52.17901289463043, 68.02736967802048, 84.88207966089249, 83.08528527617455, 94.46071207523346, 92.71440178155899, 99.59311947226524, 93.81012618541718, 95.77136814594269, 82.76403531432152, 71.55524477362633, 45.018665716052055, 37.428998574614525, 19.62579868733883, 10.483555756509304, 12.484653778374195, 5.82017001695931, 5.457631945610046, 1.8696692492812872, 1.496992134489119, 2.903643879108131, 1.2476409645751119, 0.7331650773994625, 0.4617992544081062, 0.2035637604421936, 0.011244115248700837, 0.13885430147638544, 0.1050940110872034, 0.3919233789201826, 4.086696384474635, 18.689572624862194, 50.019603967666626, 20.703899636864662, 14.95802465826273, 36.75795458257198, 20.97682949155569, 16.944863945245743, 40.291137993335724, 75.05202233791351, 63.95902678370476, 64.85262483358383, 72.94147118926048, 30.56632362306118, 2.3531279945746064, 0.2674900903366506, 0.09818874998018146, 0.019103549129795283, 0.5582842708099633, 0.2702415583189577, 0.22995892533799633, 0.12149530404713005, 0.06523238364025019, 0.06909571500727907, 0.021356368088163435, 0.2597259491449222, 0.2767149859573692, 0.20654443331295624, 0.4514649964403361, 0.3852023114450276, 0.2858997165458277, 0.10617168372846209, 0.11576110744499601, 0.05142621783306822, 0.02577473314886447, 0.06423484068363905, 0.02629592861921992, 0.06689199653919786, 0.04203925942420028, 0.17294288089033216, 0.06912718949024566, 0.10540327144553885, 0.0333139887516154, 0.09031275971210562, 0.10648251001839526, 0.18885449739173055, 0.12200871438835748, 0.16088957141619176, 0.04901430096651893, 0.056283080848515965, 0.04400448873639107, 0.061561053298646584, 0.09559418685967103, 0.014498470845865086, 0.05991704034386203, 0.0611663717427291, 0.04775283545313869, 0.05811843431729358, 0.14688592753373086, 0.02579334806796396, 0.0625014360412024, 0.11830069226562046, 0.09842654151725583, 0.021568590782408137, 0.09803361142985523, 0.15807696530828252, 0.14522667828714475, 0.06377476107445545, 0.12381332810036838, 0.027242742071393877, 0.024851516282069497, 0.0432582815119531, 0.03495340781228151, 0.043669702208717354, 0.08236425419454463, 0.11823026987258345, 0.1212281605694443, 0.055712885077809915, 0.027222407225053757, 0.08424595478572883, 0.11284655251074582, 0.11270524017163552, 0.053938332057441585, 0.17801709298510104, 0.26071950676850975, 0.20079262554645538, 0.046731332258787006, 0.05043384022428654, 0.10348563606385142, 0.010136624041479081, 0.1920844873529859, 0.10236684101982974, 0.11943126519327052, 31.833567023277283, 113.57556357979774, 95.51232844591141, 108.5259385406971, 91.510801166296, 34.7403958439827, 21.217204593122005, 18.392493166029453, 18.014301359653473, 42.63461284339428, 56.234934255480766, 37.1174418926239, 24.362478218972683, 5.749359391629696, 0.6252750323619694, 0.02500476606655866, 0.07543689935118891, 0.04857231491769198, 0.418662276933901, 0.6708564364816993, 2.0540928281843662, 3.9903739280998707, 4.057702040299773, 3.6564390594139695, 4.438428310677409, 4.779834765940905, 5.939161106944084, 4.435777952894568, 2.2186961956322193, 5.2577693201601505, 14.116201680153608, 25.53034745156765, 36.21282823383808, 48.01639325916767, 53.47069278359413, 59.12405602633953, 56.7855779081583, 62.82322973012924, 56.027909964323044, 53.36324594914913, 50.23360088467598, 48.15827764570713, 39.01152245700359, 28.45741778612137, 13.757184594869614, 8.236166350543499, 10.21606246009469, 28.83242156356573, 66.84496432542801, 104.88741338253021, 132.1868661046028, 133.92746150493622, 144.3083068728447, 106.88232153654099, 57.52999596297741, 71.9172665476799, 87.62587442994118, 88.55675607919693, 98.40174660086632, 97.57970631122589, 102.73264020681381, 100.4387640953064, 101.07814818620682, 93.30516368150711, 81.17027923464775, 52.57276676595211, 39.16629195213318, 21.17828518152237, 12.42300683632493, 8.139713276177645, 3.5139550175517797, 3.3175088837742805, 4.966480750590563, 3.525970922783017, 4.033193830400705, 2.2874316573143005, 1.1293464247137308, 0.618124766042456, 0.28048845066223294, 0.11764445560402237, 0.12904293107567355, 0.1554682568530552, 0.36660895915701985, 4.208991397172213, 19.701961800456047, 49.89364072680473, 36.61554582417011, 29.508640877902508, 23.28608337789774, 16.85689676553011, 28.966911546885967, 63.28273147344589, 95.21174177527428, 78.64419758319855, 75.98273679614067, 91.32670104503632, 59.536938071250916, 7.987373750656843, 0.4888166952878237, 0.021161212935112417, 0.05726357667299453, 0.32825402508024126, 0.2357175014913082, 0.290002902620472, 0.055333094715024345, 0.08111706760246307, 0.05446346462122165, 0.037721971166320145, 0.2440585586009547, 0.1733248494565487, 0.2194363102898933, 0.3094605007208884, 0.23827946948586032, 0.13501089677447453, 0.09257694837288, 0.07326622871914878, 0.04834730316360947, 0.0690434752323199, 0.13186188996769488, 0.019492119099595584, 0.021875253623875324, 0.023322612287302036, 0.17479167465353385, 0.044384987850207835, 0.06678376914351247, 0.04522502851614263, 0.027822964257211424, 0.10519006726099178, 0.08454972325125709, 0.09999334142776206, 0.07522405139752664, 0.07974358974024653, 0.03218861827917863, 0.027659541483444627, 0.04198807720968034, 0.05005669561796822, 0.05482915417815093, 0.10550766935921274, 0.04670879694458563, 0.03096692445978988, 0.18451241397997364, 0.25385849992744625, 0.11848022521007806, 0.17741466203005984, 0.231702245073393, 0.17171425541164353, 0.1657255392638035, 0.16243758756900206, 0.25019050925038755, 0.2706679963739589, 0.46261496376246214, 0.40238169429358095, 0.1582686768961139, 0.1454983785515651, 0.2721009054221213, 0.14913105784216896, 0.13781335030216724, 0.3067209664732218, 0.20162282162345946, 0.2996743336552754, 0.12228350940858945, 0.11343928359565325, 0.293223496992141, 0.24456667742924765, 0.2734325855271891, 0.2454806471359916, 0.3557018225546926, 0.39314741792622954, 0.4722646647132933, 0.2863624901510775, 0.2132413661456667, 0.18804417602950707, 0.09496868995483965, 0.258399939048104, 0.37286437349393964, 0.39205491717439145, 35.970899015665054, 133.62068116664886, 107.53935188055038, 118.83549973368645, 100.75674623250961, 51.09607480466366, 36.788037568330765, 36.61637797951698, 65.08591711521149, 78.8934414088726, 84.78212982416153, 49.90585707128048, 33.37269723415375, 7.662949059158564, 1.5383603959344327, 0.2641891362145543, 0.47964879660867155, 0.14378504158230498, 0.5466644943226129, 0.7562855305150151, 5.027278438210487, 6.138565381988883, 6.494791517034173, 13.596526365727186, 17.23895486444235, 19.893184639513493, 21.00731335580349, 23.924629613757133, 28.813793063163757, 18.914387561380863, 23.154971413314342, 31.090689785778522, 41.355662271380424, 48.98643180727959, 58.98861229419708, 63.82405802607536, 54.818389266729355, 65.40611073374748, 58.752796947956085, 55.51689438521862, 53.12747620046139, 55.96469655632973, 50.102336928248405, 36.003999039530754, 26.82653959840536, 21.108623519539833, 21.694565378129482, 38.47774989902973, 65.01983106136322, 101.00428014993668, 123.89758810400963, 127.60108977556229, 133.41906398534775, 106.37070178985596, 70.78249543905258, 73.780906945467, 91.46806105971336, 93.32242235541344, 98.99193093180656, 98.67188930511475, 105.02502679824829, 103.82353127002716, 105.12640535831451, 95.01922890543938, 79.98604997992516, 52.07429051399231, 43.55819508433342, 29.66202724725008, 21.48420676589012, 21.668677367269993, 15.302758309990168, 17.110973931849003, 9.649604056030512, 7.394902892410755, 9.115103837102652, 6.092881383374333, 1.9961832230910659, 1.1170388851314783, 0.5820391117595136, 0.20864824386080727, 0.22027180530130863, 0.31094586476683617, 0.7932294043712318, 9.20837553218007, 30.536282435059547, 71.02116823196411, 34.36687208712101, 28.38075689971447, 51.186969727277756, 30.31840592622757, 26.682092249393463, 55.01872591674328, 96.63230314850807, 83.12371641397476, 88.52947354316711, 103.53730782866478, 66.83625519275665, 6.059371456503868, 0.5237935215700418, 0.15081092395121232, 0.28792669996619225, 0.6361920246854424, 0.35281344316899776, 0.4124650766607374, 0.21077532815979794, 0.19438238436123356, 0.1743282182724215, 0.12930961442179978, 0.37009179883170873, 0.3316847956739366, 0.4174758796580136, 0.5179714621044695, 0.4809302184730768, 0.22823263047030196, 0.3056226175976917, 0.3377272729994729, 0.12349856842774898, 0.17920645885169506, 0.26588607172016054, 0.11417930130846798, 0.10991511371685192, 0.15482601709663868, 0.2771237608976662, 0.18611894105561078, 0.24062768410658464, 0.11431312537752092, 0.21333189331926405, 0.21118251490406692, 0.31094224308617413, 0.21277719730278477, 0.2091887648566626, 0.14162451610900462, 0.13832317607011646, 0.11694685905240476, 0.16932379774516448, 0.19937323842896149, 0.1881071101524867, 0.2499579795403406, 0.14679384185001254, 0.1314887826447375], [0.19880144333001226, 0.038941086022532545, 0.10417546232929453, 0.0322733233042527, 0.050135567362303846, 0.12755396019201726, 0.021445531565404963, 0.00574631912058976, 0.1869118367903866, 0.2561606717063114, 0.05789886250568088, 0.03557097486918792, 0.025403165782336146, 0.11883605533512309, 0.050650654957280494, 0.17217913671629503, 0.030232921853894368, 0.05097065419249702, 0.03421136032557115, 0.01221832415467361, 0.033493466034997255, 0.148172692861408, 0.06898935040226206, 0.2961648954078555, 0.43192068580538034, 0.40499797265511006, 0.26900490280240774, 0.361057932022959, 0.20968529133824632, 0.14303449279395863, 0.09450835059396923, 0.3359066660050303, 0.10665756039088592, 0.2851991291390732, 0.5135067610535771, 41.83536373078823, 106.9733190536499, 82.09449604153633, 77.25737079977989, 71.06991201639175, 69.70713794231415, 33.634453788399696, 76.34493336081505, 107.95326367020607, 90.26185378432274, 49.73864324390888, 35.93160532414913, 14.773887488991022, 2.077731122262776, 0.3388078400166705, 0.05865246152097825, 0.06023469439242035, 0.18463445274392143, 0.36909844900947064, 0.5062761052977294, 2.0529429148882627, 3.1793905701488256, 4.850322883576155, 3.1401861738413572, 4.891916401684284, 4.036696292459965, 4.170746449381113, 5.829423945397139, 14.74039513617754, 25.91140240430832, 48.22342894971371, 58.89045216143131, 89.65131014585495, 82.37532377243042, 87.14396148920059, 80.46956643462181, 81.78808808326721, 82.9504457116127, 86.50033682584763, 79.41345870494843, 79.57310333848, 77.62437790632248, 79.15503457188606, 60.604901164770126, 54.81660336256027, 54.33062084019184, 38.69601018726826, 49.21473115682602, 88.98066133260727, 110.35601153969765, 96.5884231030941, 81.72651618719101, 88.17420780658722, 87.643733471632, 89.07934203743935, 40.37494249641895, 83.76765266060829, 95.95707178115845, 95.53846344351768, 92.07473650574684, 91.04062959551811, 97.55015909671783, 92.75167778134346, 84.58973094820976, 84.62967440485954, 88.77542674541473, 85.20396798849106, 61.53745472431183, 43.9261407405138, 32.17240244150162, 31.156283766031265, 17.899197936058044, 3.9390911674126983, 0.7705901004374027, 3.0683583905920386, 1.5128731448203325, 1.2948819296434522, 0.7713133678771555, 1.2916284729726613, 0.9041582175996155, 0.19915124721592292, 0.05200405401410535, 0.0222625452443026, 0.07775216261507012, 0.06381911181961186, 2.3583662509918213, 17.421293780207634, 47.1699620783329, 56.138761416077614, 95.23194149136543, 138.28445971012115, 43.59091512858868, 13.666183277964592, 17.60966867208481, 48.39160792529583, 71.97757691144943, 62.694279849529266, 76.64804309606552, 59.735040441155434, 5.0938537158071995, 0.6713785522151738, 0.011487475676403847, 0.09914605368976481, 0.45423294010106474, 0.241762220102828, 0.15668567590182647, 0.003385398235877801, 0.03471515614364762, 0.1845781979500316, 0.21413704933365807, 0.38175518391653895, 0.19178863760316744, 0.31879526388365775, 0.5335872585419565, 0.6950985419098288, 0.3382543462794274, 0.03622044314397499, 0.07673550935578533, 0.06205711222719401, 0.06788452999899164, 0.06627584327361546, 0.01630720533285057, 0.054695248472853564, 0.2950261440128088, 0.1739874092163518, 0.027900848945137113, 0.06862764988909476, 0.02469080049195327, 0.023084034073690418, 0.18364470975939184, 0.14612911501899362, 0.0660973419144284, 0.1309944232343696, 0.06490885920356959, 0.02326853198610479, 0.08122418919811025, 0.07015720882918686, 0.04817315078980755, 0.10756163726910017, 0.1183310461055953, 0.09926347629516385, 0.14288607810158283, 0.018421155473333783, 0.012791602621291531, 0.05833198731124867, 0.02766961984889349, 0.04972590926627163, 0.01225512725795852, 0.04761704840348102, 0.14229460124624893, 0.21288452669978142, 0.16946787829510868, 0.03182220512826461, 0.04564578914141748, 0.09209530937368982, 0.1354648536653258, 0.1828733363072388, 0.03126045128738042, 0.017259787127841264, 0.04145733029872645, 0.043514782591955736, 0.010755439761851449, 0.07981202317751013, 0.06592134159291163, 0.20175807061605155, 0.305955812218599, 0.24527009984012693, 0.18059384456137195, 0.15520813409239054, 0.2847246889723465, 0.13131149840774015, 0.14171403396176174, 0.20611906395060942, 0.032052385940914974, 0.22987176751485094, 2.5455513317137957, 60.48072002828121, 119.18542295694351, 86.61645859479904, 88.73356059193611, 83.30713257193565, 90.23939698934555, 61.31679676473141, 62.67635241150856, 70.25199070572853, 64.94541585445404, 47.66006737947464, 37.641912549734116, 15.832397639751434, 2.920843418687582, 0.45135753345675766, 0.1911287198890932, 0.14461278857197613, 0.03200551560439635, 0.3578042081790045, 0.5117408651858568, 2.0610022824257612, 3.3908264245837927, 8.422362059354782, 4.005724154412746, 1.4726152550429106, 3.0270453449338675, 1.9373148819431663, 2.6329350052401423, 12.546948585659266, 28.07144019752741, 53.941628113389015, 67.00694963335991, 99.61144968867302, 90.18725618720055, 92.4726739525795, 87.14601337909698, 84.35589149594307, 84.02445048093796, 89.03538599610329, 83.28575491905212, 81.33139058947563, 77.64903098344803, 79.75494638085365, 69.58729237318039, 61.87652572989464, 56.2307620793581, 43.25910173356533, 54.16581228375435, 98.76486271619797, 122.63776570558548, 111.55288651585579, 92.79340714216232, 101.36348247528076, 100.35804122686386, 99.84272047877312, 48.37950177490711, 82.17309102416039, 99.03728529810905, 100.15274584293365, 92.08911493420601, 93.39068189263344, 103.90556126832962, 96.64670437574387, 90.40919467806816, 88.52722406387329, 94.55482542514801, 91.261086165905, 69.38156381249428, 53.736895099282265, 39.80058431625366, 32.72369205951691, 18.284730948507786, 5.429462632164359, 0.933920358074829, 4.368736250326037, 1.4625621819868684, 2.1013810532167554, 1.248240026179701, 1.5021576010622084, 1.5831295936368406, 0.5072670802474022, 0.07709790748776868, 0.02175171386625152, 0.1346766037750058, 0.10940627500531264, 1.8431980884633958, 12.946183662861586, 35.222027599811554, 43.45554739236832, 70.56668221950531, 108.2153432071209, 47.91352137923241, 24.91960432380438, 36.85591332614422, 70.174360871315, 90.15414476394653, 74.61100280284882, 89.24870654940605, 83.00507918000221, 15.370127744972706, 0.3864644671557471, 0.049023473911802284, 0.14852794411126524, 0.191190822806675, 0.1697909797076136, 0.11540601946762763, 0.04654104559449479, 0.043482235705596395, 0.07015389142907225, 0.16154292854480445, 0.2700046944664791, 0.19955372874392197, 0.29290965758264065, 0.4979392635868862, 0.4794812196632847, 0.16972071316558868, 0.0908662163419649, 0.13891943235648796, 0.0378265546169132, 0.033256798851653, 0.013872764284315053, 0.015586305344186258, 0.05390693178924266, 0.2154324681032449, 0.09785790054593235, 0.04705185099737719, 0.02914696313382592, 0.009879091376205906, 0.0813538052898366, 0.12001644863630645, 0.17030683171469718, 0.10448228844325058, 0.061576731168315746, 0.034992211003554985, 0.042634406199795194, 0.06679231126327068, 0.05318093695677817, 0.1298240415053442, 0.04704999191744719, 0.07140920453821309, 0.030710551400261465, 0.29835853551048785, 0.10679853876354173, 0.18404595932224765, 0.1199351463583298, 0.20498207886703312, 0.3055068722460419, 0.10986055101966485, 0.08164293118170463, 0.3985651850234717, 0.38098729855846614, 0.33898690540809184, 0.18334770225919783, 0.13187897420721129, 0.17261937871808186, 0.19202651077648625, 0.37475649383850396, 0.1409153049462475, 0.13887932669604197, 0.21604444307740778, 0.3866970562376082, 0.12409207134624012, 0.2352927258471027, 0.24631339620100334, 0.5080517381429672, 0.574621019186452, 0.5345942045096308, 0.5604448111262172, 0.8142965426668525, 0.42035366117488593, 0.23266427626367658, 0.3488573507638648, 0.3649791731731966, 0.13979659153847024, 0.5939772399142385, 3.6480165738612413, 67.51755103468895, 135.27877539396286, 92.61970326304436, 96.72001764178276, 90.73351487517357, 88.46062123775482, 53.82855378091335, 102.57852047681808, 132.6288279891014, 124.38727542757988, 71.74692168831825, 56.136207953095436, 24.748605899512768, 4.420701311901212, 0.8704498701263219, 0.2012987999478355, 0.1596432679798454, 0.26952274376526475, 0.7021777995396405, 1.2570749083533883, 5.12138893827796, 8.89395285397768, 12.033643629401922, 9.612796381115913, 15.045661255717278, 12.479435708373785, 13.906832914799452, 14.470707457512617, 23.70240993797779, 31.583713330328465, 55.12146480381489, 66.84320122003555, 102.62677788734436, 93.33154946565628, 97.02933624386787, 86.23207122087479, 84.8833791911602, 82.72139400243759, 86.68111592531204, 81.64533734321594, 82.2180426120758, 78.70339080691338, 81.85524567961693, 74.53930824995041, 70.89018166065216, 67.83973574638367, 54.2361731082201, 62.47714810073376, 102.83585026860237, 123.56832057237625, 111.28670319914818, 98.47414791584015, 108.86735022068024, 107.5797513127327, 101.11230835318565, 55.86610704660416, 86.15865916013718, 99.85152080655098, 103.55435371398926, 96.28436341881752, 95.29225945472717, 108.75946640968323, 101.31916165351868, 92.86651521921158, 89.71972927451134, 97.08086147904396, 93.06253150105476, 69.51557502150536, 51.50148645043373, 34.81399029493332, 36.00567854940891, 24.205922819674015, 8.949169591069221, 7.738114250823855, 12.667486667633057, 6.815326167270541, 6.212381171062589, 3.40663880109787, 2.805197574198246, 2.7790953498333693, 0.7329799560829997, 0.2642609761096537, 0.11439947425969876, 0.3047831595176831, 0.31400897540152073, 4.7149784211069345, 26.15810416638851, 66.93261802196503, 74.60517391562462, 120.40302962064743, 165.87762147188187, 55.1002087444067, 22.339918948709965, 28.243086487054825, 68.48963007330894, 94.5030190050602, 82.00007110834122, 101.1090937256813, 90.98500818014145, 11.964476890861988, 1.1093511851504445, 0.16457265737699345, 0.26764626789372414, 0.7145561103243381, 0.37652808940038085, 0.2764819219009951, 0.14782507088966668, 0.2874625311233103, 0.30232344463001937, 0.4017350164940581, 0.6831313809379935, 0.6277598021551967, 0.6293469888623804, 0.7537544507067651, 0.9291451424360275, 0.680874539539218, 0.16488303837832063, 0.26206282374914736, 0.14871002262225375, 0.19729727326193824, 0.18290683685336262, 0.14899644709657878, 0.182057686324697, 0.5470301059540361, 0.2352205297211185, 0.1904118646052666, 0.17560665670316666, 0.17975230846786872, 0.1370027320808731, 0.3965147794224322, 0.25483103992883116, 0.2586257003713399, 0.31067824631463736, 0.11794610894867219, 0.18459865154, 0.17064113955711946, 0.32201576919760555, 0.27331030927598476, 0.2231160714291036, 0.20253704366041347, 0.21252549049677327], [0.02012613957049325, 0.06151729256089311, 0.0661939695419278, 0.037449799638125114, 0.01073206582077546, 0.03498937971016858, 0.03261834033764899, 0.0774256102158688, 0.08526051518856548, 0.13921200181357563, 0.018080936424667016, 0.06805864526540972, 0.04930576462356839, 0.017664190818322822, 0.016518004958925303, 0.010319718367099995, 0.0628038241120521, 0.07238714737468399, 0.09904457983793691, 0.02536791747843381, 0.02434023033856647, 0.042772575543494895, 0.13425487093627453, 0.18718381907092407, 0.3005773789482191, 0.26536300603765994, 0.25190433603711426, 0.2469406891032122, 0.3377739986171946, 0.13736044726101682, 0.27433010924141854, 0.16183398402063176, 0.200999773805961, 8.087621871381998, 76.62682503461838, 105.79389274120331, 76.39206603169441, 86.12267509102821, 58.63219141960144, 43.603450655937195, 29.844204671680927, 23.20811916142702, 30.24473737925291, 41.62688031792641, 31.25457689166069, 20.80735858529806, 7.6383862271904945, 0.48680333769880235, 0.09439452740480192, 0.05948074656771496, 0.20684887713287026, 0.3179930616170168, 0.8331600960809737, 0.2386930980719626, 1.327013955451548, 1.1828898265957832, 0.6345659494400024, 9.600197207182646, 7.206520875915885, 1.8188324896618724, 0.45122002833522856, 5.81282121129334, 29.455840811133385, 63.696719259023666, 89.12314608693123, 95.94961658120155, 109.15064021945, 99.28212136030197, 92.86152228713036, 85.6632873415947, 86.12002283334732, 89.94878858327866, 97.1599580347538, 93.22634071111679, 91.4025753736496, 90.11531084775925, 98.53389590978622, 91.56434789299965, 76.3825361430645, 71.29964008927345, 70.80705732107162, 60.32333247363567, 55.818890780210495, 78.5699799656868, 62.20725618302822, 64.91471350193024, 65.14066457748413, 71.46847262978554, 74.20154437422752, 56.89463585615158, 33.50695922970772, 93.72623428702354, 102.70962864160538, 94.70741003751755, 89.99936386942863, 95.631512850523, 100.98755344748497, 89.83526587486267, 79.21427339315414, 80.00896275043488, 88.32908749580383, 92.89141908288002, 83.26430886983871, 81.94159984588623, 79.92326214909554, 71.34469047188759, 60.01187838613987, 28.250249102711678, 5.835209134966135, 1.3046388560906053, 2.969190124422312, 4.634899143129587, 3.6686428170651197, 1.3543685688637197, 0.860671866685152, 0.4490667610662058, 0.35180611128453165, 0.11184152128407732, 0.03738473926205188, 0.17177365691168234, 0.07333364541409537, 0.6167421152349561, 13.374530877918005, 39.383336305618286, 74.28397715091705, 54.65811766684055, 50.35517916083336, 58.6105477809906, 24.975879304111004, 18.324098736047745, 44.08036306500435, 60.2405159175396, 60.64579837024212, 76.55453771352768, 71.32705941796303, 12.014034781605005, 0.17368113971315324, 0.07284304869244806, 0.10208558931481093, 0.05660502822138369, 0.26329238433390856, 0.08710789144970477, 0.05163844980415888, 0.14925962750567123, 0.08409109825151972, 0.20386954012792557, 0.12997993704630062, 0.14750222180737182, 0.21334271383238956, 0.2863421553047374, 0.285137738683261, 0.09269467525882646, 0.10093985431012698, 0.08564241696149111, 0.0734431270393543, 0.13725415687076747, 0.01774247441062471, 0.08405925269471481, 0.040652051829965785, 0.13077979412628338, 0.10278340851073153, 0.04069630980666261, 0.026433340972289443, 0.048807189814397134, 0.026540839207882527, 0.09518992417724803, 0.06962916333577596, 0.06319605658063665, 0.01568386251165066, 0.10030923658632673, 0.0173798666219227, 0.020690554010798223, 0.032809925760375336, 0.08471376757370308, 0.027817980735562742, 0.09793190751224756, 0.038613624492427334, 0.08936772370361723, 0.058656621258705854, 0.029440207945299335, 0.022965086354815867, 0.04276545463653747, 0.10547216501436196, 0.03683516777527984, 0.011974801382166333, 0.03099306661169976, 0.016894550280994736, 0.13541642110794783, 0.014724919583386509, 0.02486088218574878, 0.11628956111962907, 0.03233866569644306, 0.0030592927487305133, 0.009617302494007163, 0.12496877781813964, 0.1298791979206726, 0.024974985535664018, 0.026849190435314085, 0.04699047167378012, 0.20719234307762235, 0.22760486259358004, 0.25539195514284074, 0.2197386315674521, 0.11388432729290798, 0.06902916662511416, 0.02977145071781706, 0.39342756383121014, 0.18895692861406133, 0.15279024664778262, 13.584804944694042, 99.30482894182205, 117.35582873225212, 88.66150885820389, 111.9607338309288, 82.38600879907608, 68.55683326721191, 54.201781153678894, 37.45039522647858, 45.013596788048744, 55.010465160012245, 41.01086877286434, 27.976242005825043, 9.251905996352434, 0.9027977718506008, 0.06889298252644949, 0.059169025989831425, 0.12815526308258995, 0.3464807564159855, 1.0690909205004573, 0.091776081972057, 0.6571006402373314, 0.36535425460897386, 0.24100726295728236, 6.9434011448174715, 5.873282616958022, 0.5738148686941713, 1.2239207373932004, 7.092287605628371, 34.0486391633749, 69.98466745018959, 93.93581584095955, 99.78494077920914, 109.1479803621769, 100.28826177120209, 97.38156974315643, 90.65653860569, 91.41468912363052, 93.5631014406681, 98.06492507457733, 94.96454983949661, 91.3922019302845, 90.84598883986473, 101.44654601812363, 94.44528490304947, 83.46027195453644, 74.04792621731758, 74.15548324584961, 67.67822921276093, 62.3294348269701, 86.46260485053062, 76.12688586115837, 72.57365092635155, 72.51192703843117, 78.34426447749138, 84.28398415446281, 65.97813203930855, 38.87994311749935, 95.48757657408714, 105.46570435166359, 96.38945057988167, 93.51724550127983, 98.98974984884262, 104.25619125366211, 95.00093668699265, 82.39381358027458, 84.95131194591522, 93.30696478486061, 96.3449777662754, 88.6923936009407, 85.10180667042732, 81.6163221001625, 77.40197584033012, 65.89509129524231, 33.64744529128075, 9.77202968671918, 1.4541149977594614, 4.523595990613103, 3.8571224408224225, 3.6604281328618526, 1.943382800091058, 0.8086151350289583, 0.6403238873463124, 0.03911576532118488, 0.044830603001173586, 0.20785315136890858, 0.03997064894065261, 0.04801685819984414, 0.35301429801620543, 9.542390909045935, 25.532171353697777, 70.97407355904579, 62.305659502744675, 36.98087342083454, 43.11246000230312, 30.64415104687214, 33.885259330272675, 66.65752798318863, 79.89684596657753, 70.16870677471161, 83.81417736411095, 89.4794225692749, 33.82503256201744, 0.4617412481456995, 0.34279275743756443, 0.01981947116291849, 0.06715536248520948, 0.13881835184292868, 0.020784198204637505, 0.04906130488961935, 0.08809668448520824, 0.0452211619267473, 0.16724145010812208, 0.16739934944780543, 0.12086832284694538, 0.18693472462473437, 0.19536736275767908, 0.24341360258404166, 0.14589444792363793, 0.05150478158611804, 0.13322321145096794, 0.04871800963883288, 0.1397990109398961, 0.0396376101707574, 0.03154595920932479, 0.08121290855342522, 0.047992790350690484, 0.04455185975530185, 0.039033260763972066, 0.09919265314238146, 0.051528756666812114, 0.03350642764416989, 0.11707841214956716, 0.03088379649852868, 0.027882590256922413, 0.01828118085541064, 0.11312082060612738, 0.06560015492141247, 0.02602819884486962, 0.07239943734020926, 0.0353690253541572, 0.030420158291235566, 0.03219975049432833, 0.20056771027157083, 0.13820832129567862, 0.14343690010719, 0.0881627578928601, 0.14090307435253635, 0.110453831293853, 0.12068164302036166, 0.15158854628680274, 0.28856960765551776, 0.3152975515695289, 0.13651920802658424, 0.33897915738634765, 0.10676246296497993, 0.13260581879876554, 0.2630315936403349, 0.06421820173272863, 0.244283355132211, 0.21459957060869783, 0.33546642400324345, 0.34082179132383317, 0.18217254109913483, 0.1432331360410899, 0.24012522044358775, 0.4397161159431562, 0.38192513573449105, 0.35101213201414794, 0.3295774228172377, 0.3451226558536291, 0.65732263145037, 0.2966827660566196, 0.44286020973231643, 0.4377764090895653, 0.4136960027972236, 18.674806617200375, 112.84779623150826, 132.5910884141922, 94.15748834609985, 114.0836039185524, 78.80128875374794, 61.20576672255993, 43.18136930465698, 33.39182920753956, 47.951834723353386, 61.55891977250576, 49.53531615436077, 35.93282125890255, 14.543256964534521, 1.338623519986868, 0.30413704575039446, 0.3545998519985005, 0.3550495341187343, 0.6717198807746172, 2.241916749626398, 0.6328943360131234, 3.365146927535534, 4.000239148736, 4.233227921649814, 17.125967927277088, 20.16304235905409, 7.468015244230628, 6.095950668677688, 10.219702664762735, 34.63480331003666, 70.89580535888672, 94.59634959697723, 104.32842537760735, 115.07589027285576, 105.77093437314034, 101.01158335804939, 90.20186260342598, 91.83316826820374, 92.48152747750282, 97.99402847886086, 96.76572158932686, 95.00684157013893, 92.9517750442028, 104.57636967301369, 97.12567627429962, 86.7138321697712, 77.11593478918076, 76.3429194688797, 74.86030742526054, 74.41368699073792, 93.61496105790138, 86.69041022658348, 79.0850955247879, 78.73858451843262, 88.74116018414497, 93.45965579152107, 70.94868332147598, 46.05370357632637, 98.90369206666946, 115.59482842683792, 101.50655999779701, 98.55680868029594, 101.12335816025734, 109.20076712965965, 100.14254719018936, 85.66709473729134, 86.24287024140358, 95.28629377484322, 98.77819240093231, 89.23192664980888, 81.42228171229362, 82.1604984998703, 74.92213010787964, 64.99756425619125, 32.574303075671196, 12.126467898488045, 6.921329079195857, 9.68307550996542, 11.235252320766449, 7.839707974344492, 3.711489555425942, 2.874609399586916, 1.6527063539251685, 0.7511946943122894, 0.1600834951386787, 0.5327463755384088, 0.25472381443250924, 0.15260312153259292, 1.550851275678724, 20.827942080795765, 57.31283001601696, 88.42558711767197, 64.08030867576599, 70.00631108880043, 78.29337000846863, 37.405751422047615, 27.579161413013935, 57.790430188179016, 79.81139615178108, 78.49524557590485, 94.55312311649323, 101.2179046869278, 28.50993286818266, 0.269993829424493, 0.5568492540623993, 0.2845208061626181, 0.5291331256739795, 0.3790678078075871, 0.2567937830463052, 0.16471425915369764, 0.2324246516218409, 0.44156548858154565, 0.416169076343067, 0.39884601370431483, 0.2680588426301256, 0.5623804510105401, 0.5453267879784107, 0.42325085727497935, 0.3819680615561083, 0.20343573996797204, 0.30924412014428526, 0.24317271629115567, 0.29321625363081694, 0.18404750298941508, 0.20426474860869348, 0.2508612029487267, 0.22464412380941212, 0.12498935015173629, 0.16142727225087583, 0.24863333499524742, 0.09439729561563581, 0.15933744376525283, 0.2789768442744389, 0.1748320326441899, 0.16408686235081404, 0.19017779122805223, 0.21755272464361042, 0.1827189844334498, 0.12063765592756681, 0.19148702878737822, 0.13408306374913082, 0.10205858998233452, 0.20285824517486617], [0.06818192341597751, 0.07052343644318171, 0.04894270598015282, 0.0237305337577709, 0.0352091222157469, 0.042122131344513036, 0.05308512940246146, 0.0427041643706616, 0.03750093361304607, 0.027839786889671814, 0.021430766537378076, 0.01871134078101022, 0.03002336532517802, 0.09463332826271653, 0.03849179352982901, 0.02191477298765676, 0.036769346697838046, 0.03749005001736805, 0.0751870108069852, 0.027865537558682263, 0.06876361134345643, 0.11604329425608739, 0.06094023192417808, 0.17816006031353027, 0.02896251346101053, 0.18361946189543232, 0.08939158375142142, 0.2700059412745759, 0.058323330158600584, 0.11266134213656187, 0.1063619926571846, 0.7569754309952259, 12.562176268547773, 82.4743540585041, 96.05174750089645, 78.69582921266556, 68.69861125946045, 21.874438226222992, 15.243321899324656, 15.160369500517845, 38.99508833885193, 73.61696094274521, 45.714807361364365, 32.963668182492256, 21.267215609550476, 4.29524059407413, 0.06503691678517498, 0.05626871658023447, 0.06480731113697402, 0.1846914496854879, 0.2102295379154384, 0.6507054646499455, 0.8611184020992368, 0.0802742995438166, 0.3874546999577433, 0.36646465596277267, 0.10681476953322999, 0.6303530442528427, 0.27698266378138214, 0.6717339518945664, 12.179138772189617, 49.541441425681114, 88.84731128811836, 100.83402648568153, 94.78249400854111, 90.39039328694344, 86.64526104927063, 89.09422963857651, 84.56910565495491, 94.28883209824562, 91.95489093661308, 92.5042274594307, 93.49632382392883, 83.92802685499191, 81.1237545311451, 88.86806577444077, 89.97910335659981, 91.10234588384628, 87.68233940005302, 82.31182917952538, 83.70086744427681, 67.68094226717949, 45.021682754158974, 46.67584039270878, 65.48832312226295, 69.70893904566765, 68.38286340236664, 71.34966060519218, 75.94946578145027, 47.78545685112476, 47.38170571625233, 97.81771034002304, 83.47810059785843, 81.57726779580116, 82.50082343816757, 86.0241311788559, 87.62505367398262, 79.0862126648426, 76.80110648274422, 83.20795029401779, 91.69912666082382, 91.61217212677002, 85.88791608810425, 84.73010301589966, 95.36110416054726, 98.12255278229713, 93.10913220047951, 77.86205515265465, 45.68886615335941, 13.209974057972431, 1.0192660940811038, 1.1867359327152371, 2.7430891944095492, 0.7500600989442319, 0.3936752036679536, 0.6604736123699695, 0.3411433193832636, 0.7056495663709939, 0.015613475370628294, 0.08614953389042057, 0.06080799605115317, 0.04654426280467305, 0.04083699874172453, 5.535853123292327, 15.263969991356134, 41.3437233120203, 69.26896065473557, 52.95166723430157, 56.7955257743597, 35.97587674856186, 12.385229263454676, 25.60352772474289, 51.59151501953602, 62.67894007265568, 75.3881599009037, 87.7184222638607, 37.94336937367916, 1.4969480806030333, 0.18129637639503926, 0.054841622259118594, 0.037117428801138885, 0.09571814778610133, 0.03547340842487756, 0.04128996857616585, 0.06107313573011197, 0.1135898134089075, 0.19116204231977463, 0.11261129911872558, 0.1029359050153289, 0.18195969314547256, 0.09855377531494014, 0.028219868545420468, 0.0834523762750905, 0.040194617977249436, 0.02983328275149688, 0.07532939926022664, 0.06049665767932311, 0.09191314180498011, 0.020770025039382745, 0.025945234156097285, 0.010874098970816704, 0.03371580605744384, 0.01446589612896787, 0.049100052419817075, 0.05744613015849609, 0.08113142816000618, 0.06729124972480349, 0.048549642306170426, 0.051017097794101574, 0.04218273883452639, 0.04516169734415598, 0.01991310051380424, 0.07311200301046483, 0.08518186237779446, 0.0163058267935412, 0.09279165911721066, 0.025136942567769438, 0.07497825208702125, 0.013600318161479663, 0.03596306261897553, 0.04737263319839258, 0.045001578982919455, 0.13957044429844245, 0.0471784428373212, 0.023431793342751916, 0.05986330143059604, 0.12715637683868408, 0.03037265341845341, 0.07535829849075526, 0.07798343067406677, 0.03152583216433413, 0.028392655367497355, 0.03539085933880415, 0.009161404886981472, 0.02626187702844618, 0.020251712812751066, 0.06434297902160324, 0.09099039249122143, 0.04432862173416652, 0.17440175026422366, 0.13963223551400006, 0.14688272145576775, 0.10229077830445021, 0.2562625240534544, 0.09931796477758326, 0.10473774309502915, 0.1910274612600915, 0.69050571648404, 17.217752002179623, 107.5740896165371, 104.12709698081017, 93.16353768110275, 80.30526325106621, 39.61865767836571, 35.08028380572796, 26.823275573551655, 32.536973878741264, 48.74141715466976, 45.137945115566254, 35.256096571683884, 25.399588868021965, 4.755544094368815, 0.03357070505444426, 0.0660713147954084, 0.1039904894423671, 0.48666304210200906, 0.14395322708878666, 1.1359289777465165, 1.4563567587174475, 0.2409364769118838, 0.16046872915467247, 0.32942801364697516, 0.3438404918415472, 0.40819021698553115, 1.884196107275784, 1.357303080148995, 13.62453181296587, 54.16643165051937, 96.24136492609978, 101.92866414785385, 94.96594816446304, 93.54787945747375, 90.54847240447998, 92.885233014822, 88.25801610946655, 95.07367238402367, 95.38534685969353, 94.50480490922928, 95.45581787824631, 87.8811827301979, 84.45103079080582, 90.77449187636375, 93.91549453139305, 95.58798998594284, 89.47336569428444, 85.38928404450417, 85.0715982913971, 71.06991201639175, 53.2756682485342, 57.08898402750492, 74.9587981402874, 77.86694929003716, 76.66393384337425, 77.23639592528343, 88.25803890824318, 53.59977185726166, 52.45188385248184, 101.38459414243698, 89.86980602145195, 84.7999356687069, 85.04512131214142, 90.09578749537468, 91.20330646634102, 83.06538954377174, 82.17187508940697, 88.27180936932564, 95.43595254421234, 95.68866178393364, 85.80239787697792, 83.9325638115406, 97.21965283155441, 100.54965734481812, 94.82116833329201, 83.28356623649597, 52.26562924683094, 16.158864721655846, 1.9587077340111136, 0.46158394252415746, 1.6389556042850018, 0.4743927880190313, 0.8402442221995443, 1.2413169164210558, 0.30241122585721314, 1.1228568479418755, 0.09513859724393114, 0.4096699407091364, 0.1571131678065285, 0.047009581976453774, 0.0327250351983821, 4.194354582577944, 18.416958153247833, 37.92240969836712, 48.700113371014595, 44.169893860816956, 44.260139018297195, 37.303742095828056, 23.261265009641647, 45.25264196097851, 77.31503650546074, 72.28263214230537, 84.70241770148277, 101.17054402828217, 66.98772266507149, 8.577939011156559, 0.18234281946206465, 0.028343814628897235, 0.071525105740875, 0.014233162328309845, 0.0729447822959628, 0.12797186354873702, 0.09201193650369532, 0.10692543117329478, 0.1687728421529755, 0.16459653968922794, 0.03134232872980647, 0.10592411068500951, 0.0374919647583738, 0.08462361147394404, 0.09799464867683128, 0.05502619438630063, 0.03359453541634139, 0.07860538753448054, 0.04888207622570917, 0.06026414281222969, 0.053089879147592, 0.05730674740334507, 0.047313795730588026, 0.02180510768084787, 0.06471156666520983, 0.054112729339976795, 0.02603210996312555, 0.041454469319432974, 0.04663215535401832, 0.06472886612755246, 0.07287406304385513, 0.07202932087238878, 0.03381120171980001, 0.03679323272081092, 0.02162999979191227, 0.03238981451431755, 0.09709783742437139, 0.08513504028087482, 0.17099137388868257, 0.15148848993703723, 0.1383072792668827, 0.07712239836109802, 0.10376485428423621, 0.13042973791016266, 0.2149350065155886, 0.16608960722805932, 0.1382593810558319, 0.20851937733823434, 0.2099822394666262, 0.13673472771188244, 0.18316774629056454, 0.24103746836772189, 0.0968101438775193, 0.16144980385433882, 0.23173584952019155, 0.09032258574734442, 0.13875734730390832, 0.11678939757985063, 0.2109370569814928, 0.280702545423992, 0.20220925187459216, 0.3113148605916649, 0.2711788611486554, 0.3299823682755232, 0.3461431385949254, 0.5152759223710746, 0.2921457798220217, 0.2454725725692697, 0.27196031296625733, 1.44108870299533, 26.080637723207474, 122.54730015993118, 115.5755178630352, 96.41845062375069, 93.34027379751205, 32.88611814379692, 23.590420447289944, 22.52314131706953, 52.50035785138607, 101.79820954799652, 67.84916684031487, 54.84797827899456, 36.64330713450909, 8.80803756415844, 0.3441182628739625, 0.36479868285823613, 0.4597569233737886, 0.5456810002215207, 0.4833074955968186, 3.680088990367949, 2.0426423801109195, 0.5299430759623647, 1.2880105921067297, 0.6555579823907465, 0.4394340404542163, 2.9629154736176133, 4.458078006282449, 2.3396558174863458, 15.396020505577326, 56.72921933233738, 100.02951845526695, 108.24425965547562, 99.3104450404644, 97.51198634505272, 95.99139153957367, 96.47461920976639, 89.5745238661766, 98.634894490242, 94.14076924324036, 96.63339748978615, 99.58092972636223, 89.32566002011299, 85.05417242646217, 93.15317943692207, 99.02891054749489, 98.64950850605965, 91.76065295934677, 88.22841569781303, 90.81292301416397, 77.95834958553314, 59.61454890668392, 64.42047402262688, 84.83496978878975, 86.03428423404694, 85.02696588635445, 85.91028168797493, 97.77902081608772, 62.030653059482574, 60.0991141051054, 107.31296002864838, 95.89180648326874, 90.72039797902107, 91.38857692480087, 94.60089415311813, 98.93490359187126, 87.04270452260971, 86.63274452090263, 89.6534912288189, 99.29313316941261, 96.84412658214569, 83.90113949775696, 84.03489992022514, 100.19842699170113, 105.25663956999779, 99.0934082865715, 84.24320474267006, 51.217041313648224, 18.16266629844904, 3.374248626641929, 2.894243421033025, 5.241242107003927, 4.6787079423666, 2.680981052108109, 4.172574151307344, 0.6301785504911095, 1.3899531844072044, 0.1359712061821483, 0.4967555677285418, 0.25513389555271715, 0.18044664699118584, 0.14314266823930666, 8.707274571061134, 28.08279398828745, 61.63119949400425, 91.94026932120323, 74.88508209586143, 76.22926756739616, 49.504723995923996, 20.189435742795467, 34.79028716683388, 73.20813328027725, 79.59323465824127, 93.69270488619804, 116.29107266664505, 67.7338582277298, 5.501044141128659, 0.7181476894766092, 0.2696600410854444, 0.19531183526851237, 0.2628314809408039, 0.2063221749267541, 0.24054413312114775, 0.26348932064138353, 0.2962790377205238, 0.3082870168145746, 0.3480132616823539, 0.2439859468722716, 0.23629232455277815, 0.2518817747477442, 0.1334162737475708, 0.26699647307395935, 0.1433936774265021, 0.11125651595648378, 0.25065120484214276, 0.1068666901846882, 0.15834256511880085, 0.17346662934869528, 0.13272290001623333, 0.11452252976596355, 0.21844526112545282, 0.14807486295467243, 0.21307372982846573, 0.2012374985497445, 0.18651002319529653, 0.2430178300710395, 0.2633397333556786, 0.1576542083057575, 0.16382286557927728, 0.15919867699267343, 0.12348037838819437, 0.11257877078605816, 0.25233234744518995, 0.21417954470962286, 0.23035692429402843], [0.029903217182436492, 0.006951489485800266, 0.0016031613199629646, 0.058355060682515614, 0.15321493323426694, 0.05841170881467406, 0.03302187571534887, 0.07929348459583707, 0.03054724551475374, 0.04084904008777812, 0.05306397448293865, 0.04038762461277656, 0.05570047636865638, 0.02520810710848309, 0.061359103783615865, 0.007091474772096262, 0.043871952293557115, 0.032985929792630486, 0.059079686252516694, 0.04148764332057908, 0.07280530306161381, 0.08057354832999408, 0.025947662834369112, 0.04302542896766681, 0.12338838176219724, 0.09848369430983439, 0.25563861534465104, 0.23413466376950964, 0.22852105874335393, 0.07652141459402628, 0.45625511440448463, 14.184123035520315, 89.44080144166946, 93.27999383211136, 85.18120720982552, 63.309558033943176, 46.051134914159775, 36.81001178920269, 39.56304766237736, 52.71426357328892, 70.61424806714058, 54.716987907886505, 37.750704512000084, 25.06592497229576, 2.6739875273779035, 0.04539551096968353, 0.10764319929876365, 0.04420560333528556, 0.031008176738396287, 0.05281043457216583, 0.1675258856266737, 0.15330994297983125, 0.22852016816614196, 0.12228913488797843, 0.1192524892394431, 0.029023248971498106, 0.11340692595695145, 0.4836228786734864, 1.6568134585395455, 20.187057070434093, 62.999984845519066, 89.28252473473549, 90.57578533887863, 90.3808481991291, 84.39718768000603, 82.13693216443062, 79.11329761147499, 78.83513733744621, 89.23498928546906, 93.29823285341263, 91.69300138950348, 91.19552448391914, 83.62965926527977, 76.60436064004898, 75.46863198280334, 81.67664006352425, 86.00586175918579, 83.6816556751728, 82.16674536466599, 86.14592224359512, 87.04418644309044, 87.42777585983276, 68.06243419647217, 29.46617055684328, 55.64770236611366, 64.9480377137661, 72.1839514374733, 79.26990240812302, 72.2857403755188, 29.877610579133034, 68.7103146314621, 91.77535817027092, 79.14144650101662, 74.78013932704926, 73.48310172557831, 77.12264522910118, 77.33924880623817, 81.94049030542374, 86.25016584992409, 90.80820366740227, 87.9542376101017, 87.58829444646835, 80.16777142882347, 92.54478648304939, 96.94855257868767, 88.49918156862259, 87.16862216591835, 90.66240549087524, 91.36635571718216, 70.62782853841782, 29.849311597645283, 10.629447028040886, 0.6906595488544554, 1.0495001217350364, 0.8135829528328031, 1.0021304385736585, 0.24044995458098128, 0.5914851673878729, 0.46882635389920324, 0.06495421926956624, 0.21993135247612372, 0.10668579910998233, 0.04473699962545652, 0.08908205621992238, 4.154239660128951, 20.936572551727295, 43.447879403829575, 55.65821260213852, 56.167309284210205, 51.866278275847435, 61.21945358812809, 28.006763868033886, 14.690421167761087, 49.206033423542976, 68.39781939983368, 68.94558280706406, 85.43838500976562, 60.84132827818394, 10.344027243554592, 0.3319284279132262, 0.12711634539300576, 0.095291427714983, 0.04579665663186461, 0.012757595559378387, 0.17699968273518607, 0.11378674229490571, 0.14569945604307577, 0.08226250574807636, 0.10013682083808817, 0.14445811015320942, 0.007973527954163728, 0.12289176622289233, 0.07702925882767886, 0.015456993533007335, 0.0544305206858553, 0.06724201564793475, 0.016740771716285963, 0.12105115834856406, 0.030433377796725836, 0.07196737380581908, 0.07626328078913502, 0.03666931632324122, 0.049755936561268754, 0.04955261778377462, 0.05978959132335149, 0.04841737674723845, 0.038440125208580866, 0.06635563157033175, 0.05648401733196806, 0.0568023318919586, 0.018438243423588574, 0.01944890755112283, 0.010933415123872692, 0.041329432278871536, 0.03880752541590482, 0.05489454480994027, 0.09698597350507043, 0.05078877606138121, 0.0371923857164802, 0.06230839600902982, 0.028457825210352894, 0.09141192495007999, 0.06910232754307799, 0.038459183560917154, 0.069782305508852, 0.03456678598013241, 0.02368846326135099, 0.03611904721765313, 0.027817260852316394, 0.019370892987353727, 0.035384061266086064, 0.02245853716885904, 0.003346812122799747, 0.03565099694242235, 0.03029359613719862, 0.01401932267981465, 0.06402437502401881, 0.08439290002570488, 0.025781970944080967, 0.05936619607382454, 0.033207238229806535, 0.1451814518077299, 0.18318833346711472, 0.12459507677704096, 0.16652187856379896, 0.067139933235012, 0.47532338183373213, 24.512380175292492, 114.70088839530945, 104.58165138959885, 102.46244430541992, 76.69257670640945, 69.34283629059792, 49.58800412714481, 25.778571031987667, 36.142524406313896, 46.24630764126778, 47.87118025124073, 40.098058953881264, 30.17753418534994, 5.155637925490737, 0.28799574938602746, 0.09628099258407019, 0.08558180576073937, 0.06642796128289774, 0.018603952012199443, 0.19380156474653631, 0.17730672407196835, 0.26938826660625637, 0.10049188655102625, 0.22028326406143606, 0.0893529475433752, 0.051322398794582114, 0.23710473877144977, 2.061126488260925, 23.171633519232273, 67.41855874657631, 91.82440593838692, 91.68215677142143, 93.83873865008354, 87.67123639583588, 84.49127063155174, 82.62439280748367, 81.65449485182762, 92.47921720147133, 97.10938274860382, 94.60131973028183, 95.10299161076546, 86.6247421503067, 78.23305204510689, 76.25968113541603, 85.71607410907745, 88.74060541391373, 87.93450146913528, 86.46189048886299, 89.2451423406601, 87.56800353527069, 89.72413703799248, 70.18563866615295, 37.493853494524956, 64.26517635583878, 72.83639922738075, 78.8906067609787, 86.86016991734505, 78.8253566622734, 38.852223604917526, 72.33289584517479, 97.7832841873169, 82.7738843858242, 78.53450506925583, 75.32364696264267, 80.7871001958847, 82.4258990585804, 87.42625594139099, 90.04629135131836, 95.47748431563377, 90.96040070056915, 88.24410125613213, 81.1413323879242, 93.5570065677166, 98.40398848056793, 91.31055191159248, 90.26537999510765, 95.66318035125732, 92.86270022392273, 77.05732673406601, 34.30730648338795, 14.23165088519454, 1.5849787881597877, 0.35902744566556066, 0.5540975485928357, 0.33024200121872127, 0.3881414537318051, 0.5770858994219452, 0.48966036876663566, 0.08451713554677553, 0.21959095902275294, 0.24839992955094203, 0.15015082812169567, 0.19427417922997847, 4.134738631546497, 23.148998133838177, 37.09305100142956, 48.69554981589317, 31.473266556859016, 37.496555149555206, 40.70774003863335, 29.902618937194347, 26.313042752444744, 66.10395088791847, 84.29899334907532, 74.61525097489357, 93.38935196399689, 82.69952237606049, 26.39931332319975, 0.21742351673310623, 0.09660637238994241, 0.05570076209551189, 0.054720726402592845, 0.016344954674423207, 0.12674601370235905, 0.15504823095398024, 0.1185669971164316, 0.07466413066140376, 0.05633502747514285, 0.0540722711593844, 0.07219608887680806, 0.06780872703529894, 0.08635812933789566, 0.005827031855005771, 0.043159549895790406, 0.030324378567456733, 0.09531275703920983, 0.04350793627963867, 0.056534594696131535, 0.053496583495871164, 0.08583418049965985, 0.013486683292285306, 0.041528628426021896, 0.05505054425157141, 0.07558310986496508, 0.06082767780753784, 0.05856033130839933, 0.018063813222397584, 0.008480820215481799, 0.022094140804256313, 0.028715845837723464, 0.054483268831972964, 0.07671730447327718, 0.04062109685037285, 0.04797978421265725, 0.05501037179783452, 0.21589294105069712, 0.1824250939534977, 0.1513070348300971, 0.18690257478738204, 0.26538725942373276, 0.18069921468850225, 0.1497539720730856, 0.21302550507243723, 0.1327216235222295, 0.17430197593057528, 0.13683500670595095, 0.08301176319946535, 0.0901558919576928, 0.06812820676714182, 0.13056305731879547, 0.07118935071048327, 0.19197620800696313, 0.09976737230317667, 0.12105019355658442, 0.12129300943342969, 0.23997523239813745, 0.19728817453142256, 0.19956926931627095, 0.21752277156338096, 0.14654952683486044, 0.22632603824604303, 0.5023858265485615, 0.38339613180141896, 0.450780795654282, 0.1791574028902687, 0.6895669887308031, 36.24133050441742, 132.6797452569008, 118.94823208451271, 110.25571972131729, 86.2833684682846, 60.53425915539265, 52.505574971437454, 49.76896561682224, 72.84557193517685, 99.80188027024269, 77.97101810574532, 58.21856461465359, 41.85484528541565, 7.583201788365841, 0.5980619613546878, 0.32247771159745753, 0.29156737960875034, 0.15389120788313448, 0.18734266835963354, 0.21240998263237998, 0.24507055117283016, 0.621677516028285, 0.44303206144832075, 0.5846201232634485, 0.2939530281582847, 0.3279559488873929, 0.4971565055893734, 2.3882490349933505, 26.416613794863224, 71.61994010210037, 95.46199634671211, 95.09034588932991, 99.72995772957802, 91.24923080205917, 88.16429793834686, 86.0688927769661, 86.5711422264576, 95.00943303108215, 98.56142163276672, 97.7364630997181, 97.82800018787384, 89.76790308952332, 83.00235092639923, 79.53210353851318, 87.3412013053894, 91.43124103546143, 90.71817129850388, 91.17476239800453, 95.05647450685501, 90.3127558529377, 92.63434767723083, 76.88606232404709, 45.32589443027973, 73.21033716201782, 82.74304524064064, 86.42738834023476, 95.09142503142357, 89.22206997871399, 46.77408032119274, 75.86067974567413, 100.7388111948967, 87.43995800614357, 84.3345594406128, 79.99903008341789, 84.00558829307556, 85.52654027938843, 91.18635937571526, 92.9672934114933, 98.63619402050972, 91.32976368069649, 90.96463367342949, 81.95659384131432, 95.94589278101921, 104.89667728543282, 96.00098982453346, 98.43349009752274, 101.94823309779167, 96.39461070299149, 77.84560203552246, 33.527348935604095, 13.927972130477428, 1.8195605068467557, 3.0188736459240317, 2.6042674435302615, 2.561972150579095, 0.8296005777083337, 1.3359693624079227, 0.9641372866462916, 0.2746982144890353, 0.5796657828614116, 0.4648794938111678, 0.4901255766162649, 0.23692334303632379, 6.5058916714042425, 34.93072383105755, 63.522642999887466, 76.5452966094017, 79.78179574012756, 71.28448650240898, 77.76395961642265, 39.32951979339123, 20.355927608907223, 65.98873347043991, 86.85531377792358, 85.0258107483387, 106.58096730709076, 90.48939317464828, 22.77646042406559, 0.5448272929061204, 0.22092296567279845, 0.142599742684979, 0.23580773180583492, 0.11180957182659768, 0.4462575836805627, 0.2886353025678545, 0.3163177374517545, 0.15614809381077066, 0.15650751593057066, 0.23232621315401047, 0.22478058992419392, 0.133141441619955, 0.32719014154281467, 0.1224753397400491, 0.113721077068476, 0.11121710049337707, 0.29620574321597815, 0.16902907605981454, 0.13770355697488412, 0.31662350229453295, 0.18359406560193747, 0.0883040924964007, 0.12410056151566096, 0.18419244443066418, 0.23351210576947778, 0.17063293140381575, 0.35066961601842195, 0.21594992314931005, 0.19317661703098565, 0.1250407809857279, 0.27269949205219746, 0.1642661207006313, 0.24702670401893556, 0.08988529007183388, 0.26486680610105395, 0.2906863612588495], [0.02621768398967106, 0.031273297863663174, 0.017329719703411683, 0.03846269020868931, 0.07204662033473141, 0.046674940167577006, 0.0237661661230959, 0.022246774606173858, 0.15139030379941687, 0.05768903509306256, 0.0692170561524108, 0.06229531194549054, 0.014736388548044488, 0.0271917008649325, 0.03848306216241326, 0.05573934635322075, 0.004009591975773219, 0.038894575627637096, 0.010645301335898694, 0.0646777544170618, 0.08351490963832475, 0.020130766861257143, 0.060866918865940534, 0.04162284778431058, 0.06599858432309702, 0.09504417379503138, 0.07435707448166795, 0.13156630739104003, 0.07927673432277516, 0.7635082304477692, 26.66824959218502, 111.12651899456978, 89.82205778360367, 89.67806831002235, 66.72727704048157, 36.18563689291477, 17.653940096497536, 21.20071727782488, 69.23575043678284, 62.36572287976742, 44.94970701634884, 34.83866237103939, 20.73884066194296, 2.1595457196235657, 0.03504006839648355, 0.05745208960433956, 0.11043578968383372, 0.168873343791347, 0.10028174001490697, 0.35480186459608376, 0.09784916546777822, 0.06727792075253092, 0.06011327161104418, 0.05828510213177651, 0.07578757154988125, 0.41614701971411705, 0.8057068660855293, 11.944039687514305, 40.75681820511818, 72.19428688287735, 86.19586676359177, 90.71534425020218, 87.14656814932823, 80.47866314649582, 75.02606973052025, 74.16661664843559, 67.30832666158676, 78.5117594897747, 94.04025703668594, 90.84539607167244, 89.3045711517334, 79.74002078175545, 68.11257630586624, 67.56315618753433, 71.9984681904316, 77.98327624797821, 81.61396622657776, 82.55750879645348, 82.20248624682426, 83.23680594563484, 84.40345734357834, 85.26595026254654, 87.67139598727226, 71.00700259208679, 35.631869807839394, 59.51707273721695, 67.65816628932953, 76.66782483458519, 45.34449063241482, 48.64088214933872, 87.60005101561546, 83.05440813302994, 75.4552187025547, 64.76000100374222, 68.57532307505608, 72.92729794979095, 81.61680847406387, 88.97661834955215, 88.14393103122711, 86.4883902668953, 89.22124922275543, 83.43330100178719, 84.1552622616291, 87.81278640031815, 90.95739886164665, 81.6362102329731, 76.71064093708992, 80.20687133073807, 84.72687318921089, 89.32387411594391, 92.2397692501545, 80.16343966126442, 49.59978349506855, 17.59725473821163, 3.156838067807257, 0.659210120793432, 0.5884656950365752, 0.071965310635278, 0.10972581410896964, 0.0165454050511471, 0.11505341026349925, 0.0789713702397421, 0.017420358199160546, 0.11591035334276967, 0.024842998282110784, 0.6883107405155897, 6.6130677703768015, 25.72865691035986, 57.54968270659447, 66.8453823029995, 67.16283246874809, 70.98598971962929, 41.157894283533096, 20.83203636109829, 34.71682570874691, 56.264158487319946, 67.233926653862, 72.30470135807991, 79.00515541434288, 15.835521072149277, 0.5099519330542535, 0.02721095774177229, 0.035838582189171575, 0.0560145458439365, 0.04013811827462632, 0.053997317954781465, 0.11092242333688773, 0.04861616842390504, 0.03312392102088779, 0.03421587258344516, 0.07510674011427909, 0.07103669093339704, 0.02694024453376187, 0.0781881892180536, 0.011034570779884234, 0.09093461267184466, 0.02319578667083988, 0.030519401989295147, 0.08251432387623936, 0.021331200005079154, 0.09667949620052241, 0.03347088990267366, 0.04291596218536142, 0.053252839934430085, 0.044878972475999035, 0.04089391775778495, 0.07998168555786833, 0.04485200654016808, 0.09638412142521702, 0.07663764976314269, 0.04467404323804658, 0.04362482824944891, 0.035971909019281156, 0.06872929443488829, 0.07239724058308639, 0.003909682200173847, 0.028083860706829, 0.06936929290532134, 0.043644814286381006, 0.06532590909046121, 0.03092907678365009, 0.05747982737375423, 0.019231461992603727, 0.0038165718888194533, 0.04572573699988425, 0.06114273062848952, 0.02854650443623541, 0.050701573709375225, 0.028872592993138824, 0.01981381414225325, 0.03285448801761959, 0.016334323408955242, 0.04779064416652545, 0.0113937572677969, 0.033910300699062645, 0.05190935968130361, 0.039490015551564284, 0.03918500027793925, 0.03299945172329899, 0.03521379032463301, 0.17065826832549646, 0.09754910031915642, 0.012695798777713208, 0.1337217417312786, 0.05256923286651727, 0.5494125781115144, 43.9564973115921, 138.5270994901657, 102.46352344751358, 107.3974446952343, 80.05268320441246, 64.34338375926018, 29.771896451711655, 25.05022421479225, 57.98708863556385, 57.405282855033875, 49.291114658117294, 38.75896520912647, 25.944703817367554, 3.484008824452758, 0.059132337919436395, 0.1113014604197815, 0.06822652649134398, 0.1344552359660156, 0.4597996413940564, 0.7165871607139707, 0.27118283906020224, 0.12322853799560107, 0.05969729412754532, 0.0966166659782175, 0.18124265974620357, 0.3795263363281265, 0.6420044659171253, 12.034001760184765, 41.34919501841068, 72.99141570925713, 85.74937552213669, 93.3050648868084, 91.85499429702759, 82.60052248835564, 77.23027065396309, 77.1998342871666, 70.66084116697311, 82.09596276283264, 95.69045528769493, 92.47328951954842, 90.63003122806549, 81.55520617961884, 70.22712484002113, 68.95797774195671, 75.14510214328766, 82.50372648239136, 85.54787993431091, 86.79331630468369, 88.54734018445015, 88.72996598482132, 88.00556525588036, 86.82886719703674, 89.40023481845856, 74.72076371312141, 46.75133474171162, 67.32017442584038, 77.36479863524437, 86.8280540406704, 55.08981630206108, 57.09426574409008, 91.57266184687614, 87.63497114181519, 79.72213134169579, 68.43603014945984, 69.61398214101791, 76.09514236450195, 85.489302277565, 93.3422040939331, 92.87906974554062, 89.02306705713272, 91.11378327012062, 85.31749829649925, 84.2450362443924, 88.95605385303497, 93.67675334215164, 85.69860264658928, 79.0880137681961, 83.73045265674591, 87.49790489673615, 92.04740837216377, 95.09031549096107, 83.42728972434998, 55.790909081697464, 22.849570401012897, 5.028930874541402, 1.920113442465663, 1.8057247367687523, 0.4596713389037177, 0.1269491543644108, 0.06331083714030683, 0.03642379160737619, 0.016847121478349436, 0.028749233206326608, 0.041979141751653515, 0.09574233437888324, 0.8002051175571978, 7.590184863656759, 27.197112813591957, 49.44751426577568, 45.50476983189583, 59.037063494324684, 52.447297498583794, 30.140571668744087, 37.1575715392828, 50.078196823596954, 77.11138263344765, 76.78838476538658, 79.11509871482849, 94.14436385035515, 35.671076104044914, 1.2582797999493778, 0.10801348646054976, 0.05694623803719878, 0.03695129162224475, 0.05877013274584897, 0.0783566790050827, 0.12354059625067748, 0.06508262566057965, 0.046610788922407664, 0.019771749211940914, 0.00947132297369535, 0.04347837282693945, 0.05774765733804088, 0.07009518012637272, 0.06859894361696206, 0.02976119238155661, 0.02514098356186878, 0.0115967513556825, 0.05920002920902334, 0.061463026722776704, 0.09276727214455605, 0.07068784441798925, 0.049391282300348394, 0.11791752884164453, 0.04322069915360771, 0.046736438234802336, 0.0321709180570906, 0.08040719592827372, 0.07828890607925132, 0.057256214568042196, 0.01685712191829225, 0.0541527644963935, 0.08360879874089733, 0.05944621443632059, 0.02398184351477539, 0.02252723406854784, 0.15876043878961354, 0.10572037630481645, 0.10945037342025898, 0.20885677251499146, 0.13805306400172412, 0.16978612606180832, 0.08370079536689445, 0.1194615448184777, 0.1902322648675181, 0.19042382802581415, 0.1575688464799896, 0.10674891134840436, 0.14958495536120608, 0.09657966991653666, 0.20518328994512558, 0.12213948080898263, 0.12782951962435618, 0.11232578006456606, 0.10906238603638485, 0.20332009851699695, 0.24438117019599304, 0.32118349510710686, 0.15399525698740035, 0.13420124334516004, 0.23124846629798412, 0.23806622077245265, 0.21277127496432513, 0.32626682077534497, 0.2679671428631991, 1.8281695386394858, 58.24768625199795, 157.8147429227829, 115.14763042330742, 114.45487439632416, 86.38483062386513, 53.42951439321041, 28.788153938949108, 30.06356120109558, 96.52240544557571, 86.62088915705681, 64.58829581737518, 54.497918263077736, 37.11717210710049, 4.803795330226421, 0.4608448228100315, 0.4149927129037678, 0.16486513777635992, 0.48263905802741647, 1.182478736154735, 1.099745538085699, 0.6529788707848638, 0.3909047070192173, 0.0950622970412951, 0.34487169119529426, 0.5320719711016864, 0.5846520652994514, 1.3393048709258437, 16.64472945034504, 47.498807832598686, 77.31726318597794, 88.41984942555428, 96.36355116963387, 96.79531440138817, 87.49352753162384, 82.10293918848038, 83.44787701964378, 74.9292129278183, 84.94907006621361, 100.8129908144474, 97.42423385381699, 93.95457163453102, 85.85427269339561, 75.05971312522888, 73.44663128256798, 78.804602175951, 86.82727128267288, 90.04789486527443, 90.67481562495232, 92.3318763077259, 93.38271751999855, 92.86942586302757, 90.78009277582169, 92.72143140435219, 79.04050871729851, 54.07432459294796, 76.3644415140152, 87.55974277853966, 96.04942962527275, 61.757911294698715, 63.495356664061546, 93.43402996659279, 92.05750823020935, 84.8555114865303, 72.10890546441078, 74.06074672937393, 82.00248777866364, 90.5511474609375, 97.26358607411385, 96.56412720680237, 93.43075454235077, 94.569743424654, 88.00914466381073, 85.13859629631042, 91.19962066411972, 98.37827906012535, 90.20788908004761, 85.20956128835678, 87.69378438591957, 93.86184900999069, 98.5945862531662, 98.70470434427261, 87.65557363629341, 57.66226686537266, 22.582862712442875, 4.414383675903082, 2.778463871218264, 4.130025934427977, 0.47256033634766936, 0.174441781709902, 0.15319428668590263, 0.27034658705815673, 0.2544085797853768, 0.31077297404408455, 0.4412039142334834, 0.301818517036736, 1.765822246670723, 13.472551368176937, 43.06032679975033, 82.65189573168755, 84.94279280304909, 90.03331124782562, 94.53334897756577, 56.788940727710724, 32.14063614606857, 46.213617995381355, 78.2757693529129, 83.85042741894722, 90.51894038915634, 110.74257999658585, 34.20012183487415, 0.8755714015569538, 0.30451530357822776, 0.18044740398181602, 0.15237532672472298, 0.15385807841084898, 0.2826594701036811, 0.2708228083793074, 0.2159179068985395, 0.16623589937807992, 0.10351714023272507, 0.11532751508639194, 0.21175016881898046, 0.1930109251406975, 0.1882468120311387, 0.12974819401279092, 0.16706513066310436, 0.07784795161569491, 0.23378390993457288, 0.18537239986471832, 0.18398897722363472, 0.17438882205169648, 0.11576241362490691, 0.20908995531499386, 0.148656276287511, 0.13108877988997847, 0.15678016614401713, 0.1495347119634971, 0.18370092002442107, 0.17564838024554774, 0.1290898199658841, 0.11038288939744234, 0.24825593805871904, 0.16374470258597285, 0.16225236235186458, 0.1654003153089434, 0.08538924070307985], [0.046726857108296826, 0.0984423715271987, 0.04076105105923489, 0.056661219932720996, 0.025176074159389827, 0.04548396012978628, 0.03403933049412444, 0.031250220781657845, 0.03971343539888039, 0.009089816394407535, 0.04578741318255197, 0.022624882149102632, 0.018447895054123364, 0.0450221290520858, 0.0416913851222489, 0.0841875329206232, 0.033989999938057736, 0.05057939393736888, 0.004701968446170213, 0.04879616892139893, 0.03394264349481091, 0.014957342609704938, 0.08609272990725003, 0.028214207814016845, 0.018929624966403935, 0.09844045678619295, 0.03088790428591892, 0.17862448148662224, 2.025201553478837, 26.922068372368813, 105.6716077029705, 80.40765255689621, 75.87701886892319, 43.87589983642101, 37.13831037282944, 17.953365929424763, 65.73353916406631, 104.17589396238327, 48.02422843873501, 58.27303469181061, 39.78514954447746, 14.622996635735035, 1.1832902301102877, 0.19040430954191834, 0.01724122786981752, 0.28598550881724805, 0.37682423600926995, 0.029516350441554096, 0.2178906393237412, 0.17396471434039995, 0.18406169285299256, 0.05119076777191367, 0.09938905510352924, 0.7587568822782487, 0.2543748269090429, 11.296215299516916, 50.18548406660557, 81.53860867023468, 89.44037586450577, 75.01724660396576, 83.15476834774017, 88.83348762989044, 84.14117261767387, 82.80562788248062, 73.25648188591003, 70.52467167377472, 70.0824286043644, 66.09461098909378, 78.27382385730743, 78.19934025406837, 72.49263167381287, 67.13713064789772, 63.508785143494606, 66.15942791104317, 72.92724475264549, 77.03251406550407, 78.83466616272926, 80.0596672296524, 83.8678228855133, 84.73941251635551, 82.0985010266304, 83.17857787013054, 78.99921253323555, 86.12639889121056, 67.24662557244301, 29.52231254428625, 59.54213239252567, 60.37665881216526, 44.568690061569214, 79.61780413985252, 81.31030172109604, 82.12026625871658, 73.94231468439102, 69.45262759923935, 64.57634925842285, 73.06873396039009, 78.01572650671005, 87.61510580778122, 82.56632432341576, 85.76746255159378, 83.60797762870789, 85.27104958891869, 87.69756898283958, 87.03483134508133, 87.20048725605011, 75.81394225358963, 69.3060390651226, 77.01799124479294, 83.94556671380997, 83.32721069455147, 84.15171325206757, 81.89363121986389, 88.13776016235352, 85.22195622324944, 56.884828582406044, 10.078203957527876, 1.1914439988322556, 1.1197496834211051, 0.13244601956102997, 0.09553190582664683, 0.14728135865880176, 0.14101659326115623, 0.00990501366686658, 0.17928585381014273, 0.05806160064821597, 0.10870555401197635, 0.42317616753280163, 2.6579139148816466, 10.093307197093964, 33.45558598637581, 45.03829546272755, 48.88352192938328, 65.48303380608559, 46.644872054457664, 17.95872174203396, 26.694253496825695, 43.75881291925907, 54.85914967954159, 66.23057529330254, 72.82575219869614, 40.50382398068905, 2.042605569586158, 0.19169634411809966, 0.015483266488445224, 0.06722916165017523, 0.13938024669187143, 0.0672995692002587, 0.08627659699413925, 0.048410634335596114, 0.11892172886291519, 0.04009436124761123, 0.009362499076814856, 0.06928445058292709, 0.04972643990186043, 0.02581897257186938, 0.07926728678285144, 0.03838880198600236, 0.032887754787225276, 0.03277635471022222, 0.03046153116883943, 0.022618794682784937, 0.08598632077337243, 0.04444480124220718, 0.047551386887789704, 0.03769487164390739, 0.07327722734771669, 0.030005924854776822, 0.056472154101356864, 0.05244434425549116, 0.028690288127108943, 0.002516679592190485, 0.1419736075331457, 0.01151868762462982, 0.026446794254297856, 0.03182109561748803, 0.0366006231342908, 0.05177771752642002, 0.026548574242042378, 0.09260118691599928, 0.07828002257156186, 0.09034413029439747, 0.05211969917581882, 0.043588878615992144, 0.03295377995527815, 0.020289328567741904, 0.05318203162460122, 0.04884901354671456, 0.05236002885794733, 0.012810185071430169, 0.05838170378410723, 0.07230209725094028, 0.02144489888451062, 0.010973638600262348, 0.023796946697984822, 0.03054986158531392, 0.06690234207781032, 0.05038191957282834, 0.04259858644218184, 0.03426013427088037, 0.03296683804364875, 0.04727868472400587, 0.06898141684359871, 0.04844707749725785, 0.06703249251586385, 2.1419711876660585, 40.1221838593483, 125.40501281619072, 90.44595390558243, 87.82718762755394, 64.19459134340286, 65.70776134729385, 31.574272736907005, 60.189389660954475, 63.830798864364624, 42.418241053819656, 54.52316410839558, 42.61869169771671, 21.816067658364773, 1.973831041250378, 0.22854721202747896, 0.045974608801770955, 0.5387624620925635, 0.7008504832629114, 0.03905669778760057, 0.3768767206929624, 0.0812012716778554, 0.21955831936793402, 0.05371991057472769, 0.22244095453061163, 1.08604418579489, 0.33720043720677495, 11.729289460927248, 50.80080404877663, 84.66984584927559, 91.05671033263206, 77.36912280321121, 83.91288086771965, 91.02571159601212, 87.14961558580399, 86.8122772872448, 75.96461936831474, 73.3644948899746, 71.00463911890984, 69.0873683989048, 81.47215783596039, 81.03449732065201, 74.90709811449051, 69.7768186032772, 66.75773620605469, 67.53670960664749, 75.88942900300026, 78.71959313750267, 83.29496562480927, 82.62826859951019, 87.50461533665657, 86.4655838906765, 85.08972331881523, 85.87211653590202, 81.03948265314102, 88.93273830413818, 72.51368254423141, 37.286650612950325, 66.89647436141968, 66.34112656116486, 53.13523158431053, 82.75273472070694, 84.11728709936142, 83.79207774996758, 76.51479184627533, 71.15460187196732, 68.09168502688408, 74.84386190772057, 82.49693244695663, 90.3484283387661, 85.87253451347351, 88.66176724433899, 88.0589447915554, 88.22995081543922, 91.19370818138123, 89.47017386555672, 91.66172906756401, 79.56098958849907, 72.54666477441788, 79.08924490213394, 86.6058723628521, 86.25255972146988, 85.17102375626564, 85.53524181246758, 91.72350615262985, 90.7813011109829, 64.34839949011803, 12.544595561921597, 1.0786616569384933, 2.002710085362196, 0.4525985528016463, 0.2563459117664024, 0.5031650816090405, 0.07066586942528374, 0.180053946969565, 0.2566349634435028, 0.04848080439842306, 0.07108576173777692, 0.23550223413622007, 3.231742260977626, 13.288010470569134, 33.80758389830589, 40.21316237747669, 44.94781851768494, 56.8996249884367, 44.45284567773342, 31.1433644592762, 43.41489717364311, 60.30073508620262, 69.44284692406654, 73.13876420259476, 86.69423282146454, 66.50496616959572, 7.579656103625894, 0.038058360732975416, 0.04962434264598414, 0.03269157918111887, 0.041549742527422495, 0.07954390748636797, 0.025957410944101866, 0.04742719218484126, 0.044677078622044064, 0.05848532986419741, 0.03055243127164431, 0.03862874575133901, 0.004595867767420714, 0.05435360821138602, 0.021226286298769992, 0.0652851874474436, 0.058263449973310344, 0.049530564865563065, 0.028709222169709392, 0.019768585807469208, 0.029430567446979694, 0.06591993893380277, 0.023676878336118534, 0.007666334477107739, 0.09070134081412107, 0.027278647175990045, 0.03839255354250781, 0.0377918517915532, 0.01624391312361695, 0.04876981154666282, 0.07539455240475945, 0.03811421476711985, 0.04061779058247339, 0.05308222389430739, 0.008400911319768056, 0.12113621589378454, 0.1317772109177895, 0.19318418693728745, 0.29555517656262964, 0.21184188342886046, 0.07558281300589442, 0.14734715747181326, 0.13992008491186425, 0.13335664960322902, 0.14339719520648941, 0.1413782566669397, 0.07680015041842125, 0.13597084995126352, 0.13205110793933272, 0.1531557395355776, 0.15188392106210813, 0.16292275919113308, 0.14396714977920055, 0.12452749680960551, 0.19391879439353943, 0.1315089690615423, 0.189797306957189, 0.1749574556015432, 0.11237701794016175, 0.13161897019017488, 0.19149502913933247, 0.22006971848895773, 0.26993603096343577, 3.778059370815754, 60.44609248638153, 143.9718273282051, 100.02726897597313, 99.82873722910881, 67.82198309898376, 55.2186293900013, 26.290076784789562, 86.27011477947235, 126.95718392729759, 62.84170813858509, 79.92904543876648, 60.72769917547703, 29.520080164074898, 3.020097417756915, 0.856520589441061, 0.20185337722068653, 1.423560124821961, 1.2014463683590293, 0.16006124555133283, 0.9502610249910504, 0.31741653161589056, 0.39511007198598236, 0.20702397945569828, 0.8094496058765799, 1.8869546405039728, 0.8365976647473872, 16.73569656908512, 61.78181201219559, 92.89755195379257, 94.22041296958923, 80.8385418355465, 84.49998736381531, 95.64794316887856, 91.62370830774307, 92.56405904889107, 80.38657888770103, 78.37785467505455, 76.86802089214325, 71.98224306106567, 85.68294748663902, 84.04822200536728, 80.06019920110703, 74.30064305663109, 69.3135778605938, 71.93984493613243, 78.88412430882454, 84.04347985982895, 88.63867968320847, 87.27848947048187, 90.80261036753654, 91.9832906126976, 89.16109845042229, 91.70052498579025, 84.23942014575005, 93.69344964623451, 76.65753498673439, 44.34563063085079, 73.69770660996437, 75.22894084453583, 58.62304911017418, 86.53837278485298, 90.78719839453697, 88.60173046588898, 80.84285840392113, 75.65659269690514, 72.29538425803185, 80.3029453754425, 87.2832316160202, 94.03058275580406, 87.71345973014832, 91.65096044540405, 91.61565274000168, 92.84171015024185, 96.21217489242554, 90.6546539068222, 97.23286852240562, 84.91481110453606, 77.1055993437767, 84.52520281076431, 92.55595788359642, 90.48895239830017, 91.65518581867218, 89.91608753800392, 95.1537036895752, 96.10045328736305, 69.39280360937119, 13.888441901654005, 1.7367520253174007, 3.6666142009198666, 0.8221381343901157, 0.4629539174493402, 0.6327754142694175, 0.5722435936331749, 0.2609635249245912, 0.490839522681199, 0.379091200302355, 0.38110173773020506, 0.7337750040460378, 5.813755486160517, 21.0257575660944, 52.31931656599045, 63.45291294157505, 69.6406415104866, 82.83225685358047, 56.87388516962528, 28.13251242041588, 33.88173691928387, 59.966657012701035, 74.607043415308, 82.99896150827408, 97.77023568749428, 66.43723100423813, 5.544744171202183, 0.4156769730616361, 0.14218258147593588, 0.16484808322275057, 0.2597964828601107, 0.1378347389982082, 0.2268874432775192, 0.16301860014209524, 0.19750949781155214, 0.14854119886877015, 0.10094966550241224, 0.19025442539714277, 0.14250630629248917, 0.13654957670951262, 0.18359081499511376, 0.11867917273775674, 0.18060660950141028, 0.13017828343436122, 0.18750929535599425, 0.1000154871144332, 0.17078015865990892, 0.15662099031032994, 0.12177553158835508, 0.16144484630785882, 0.1815076806815341, 0.1146830414654687, 0.14098091080086306, 0.17968475818634033, 0.13186047988710925, 0.11080134936491959, 0.1963827246800065, 0.1797392763546668, 0.2508023357950151, 0.14862954412819818, 0.09918292358634062], [0.04746460384922102, 0.07353289722232148, 0.01821991285396507, 0.017582196487637702, 0.026465008413651958, 0.043036976785515435, 0.07465219692676328, 0.07726717652985826, 0.06354045763146132, 0.02619637321913615, 0.06358841521432623, 0.0659151298168581, 0.03240716221625917, 0.029761609839624725, 0.021307811221049633, 0.07263017847435549, 0.0019625508548415382, 0.032581407358520664, 0.03343006806971971, 0.03662383751361631, 0.07522570638684556, 0.05228095302300062, 0.03785179134865757, 0.03960876289056614, 0.07690750950132497, 0.07809089365764521, 0.28750373516231775, 2.425017049536109, 27.581013813614845, 90.07888600230217, 83.0017277598381, 89.02987629175186, 73.85735124349594, 35.35456448793411, 18.55981908738613, 47.17440403997898, 55.05799300968647, 90.2299202978611, 65.62737286090851, 40.887010619044304, 19.154230691492558, 0.43404207041021436, 0.031665838323533535, 0.05895697213418316, 0.040267786316690035, 0.33416155027225614, 1.7741715861484408, 0.10367844603024423, 0.28470913355704397, 0.13161653594579548, 0.18564133933978155, 0.10921627035713755, 0.08316966996062547, 1.7414727970026433, 22.553742974996567, 74.1626800596714, 86.22185736894608, 81.60898849368095, 79.5428417623043, 81.53534084558487, 82.02637329697609, 85.49233451485634, 87.4890285730362, 83.74385833740234, 78.68357867002487, 66.11417233943939, 64.22131910920143, 63.590644150972366, 62.603305131196976, 63.74978341162205, 64.01925355195999, 62.88389727473259, 61.20225191116333, 57.669475078582764, 64.39400464296341, 69.07561182975769, 75.13401433825493, 77.27725133299828, 83.3464452624321, 81.1945903301239, 85.6466594338417, 82.87021681666374, 82.12763026356697, 74.15211662650108, 85.943613499403, 60.24468049407005, 26.036596186459064, 32.949612736701965, 68.08929115533829, 81.12215101718903, 73.8075815141201, 70.98244071006775, 64.2034524679184, 64.45302307605743, 66.12869516015053, 71.06418952345848, 77.30584859848022, 84.60452735424042, 86.74508929252625, 88.42862695455551, 78.96187573671341, 72.9839301109314, 80.1732811331749, 86.57359689474106, 82.50528439879417, 71.53627619147301, 64.6238163113594, 65.84934175014496, 69.8040023446083, 76.5808779001236, 78.1311871111393, 75.24626791477203, 73.68893668055534, 75.12109503149986, 76.8403659760952, 47.0477644354105, 12.207905128598213, 0.4175881517585367, 1.0705565731041133, 0.410067256889306, 0.1639551014523022, 0.26542561361566186, 0.2106414150330238, 0.03731146331119817, 0.09231070289388299, 0.051828101932187565, 0.045840743914595805, 0.019430392821959686, 2.364647788926959, 10.067764017730951, 33.310464173555374, 50.237343683838844, 40.351250767707825, 64.79615986347198, 42.68038518726826, 24.315159358084202, 20.152794308960438, 52.9326606541872, 67.43628859519958, 71.20214492082596, 85.97363948822021, 55.19140385091305, 6.303714970126748, 0.061790822219336405, 0.08299852328491397, 0.0642654394323472, 0.06071992167562712, 0.029861137409170624, 0.035181788916816004, 0.061661031722906046, 0.07115543456166051, 0.05372225205064751, 0.03615958703448996, 0.019065104024775792, 0.08870814737747423, 0.06778698952984996, 0.016457942947454285, 0.045929979751235805, 0.02109409680997487, 0.04490801271458622, 0.00567618755667354, 0.027852870953211095, 0.025217087095370516, 0.02721738288528286, 0.05975918182230089, 0.02532842780055944, 0.07692947707255371, 0.07624065270647407, 0.058212245494360104, 0.05874943424714729, 0.019183517397323158, 0.017914281597768422, 0.06281529029365629, 0.022715613413311075, 0.008496906266373117, 0.022186890710145235, 0.04360041530162562, 0.05333521832653787, 0.02705279679503292, 0.03026632035471266, 0.07031300046946853, 0.014148622431093827, 0.027814884124381933, 0.05207360067288391, 0.04670269649068359, 0.014813686939305626, 0.039299636118812487, 0.0693484979274217, 0.01565507089253515, 0.03037012826098362, 0.029628811789734755, 0.031936941159074195, 0.026696103923313785, 0.015941140991344582, 0.03620534043875523, 0.05050818857853301, 0.06840429312433116, 0.029734287672908977, 0.03799430596700404, 0.01793783736502519, 0.018446898720867466, 0.055196142493514344, 0.153735282656271, 1.747312133666128, 40.51744244992733, 113.5848730802536, 97.00181812047958, 105.2591398358345, 91.7837405204773, 54.018049612641335, 27.69690379500389, 38.38527426123619, 66.76789686083794, 103.57779085636139, 57.246040999889374, 44.624558463692665, 24.36197094619274, 0.8238257188349962, 0.19384751853067428, 0.032047279964899644, 0.12572133040521294, 0.50104841706343, 2.3270792048424482, 0.5363922799006104, 0.2772658970206976, 0.6873703503515571, 0.6362238479778171, 0.49284801178146154, 0.1014399431005586, 2.6692251954227686, 21.65415834635496, 75.94229936599731, 92.9167865216732, 84.99598994851112, 83.7926933169365, 83.71441751718521, 79.80243623256683, 88.40076684951782, 92.6339752972126, 88.08632612228394, 80.40009096264839, 68.73214066028595, 68.98583024740219, 67.78826370835304, 65.23611545562744, 66.17679297924042, 67.38142713904381, 64.72236022353172, 65.21402344107628, 60.31520090997219, 68.96991670131683, 73.85773122310638, 78.09862285852432, 81.66469350457191, 85.27709126472473, 85.22811949253082, 87.96662494540215, 85.33784240484238, 84.78548884391785, 78.84449243545532, 88.4961949288845, 65.75057744979858, 33.9399041980505, 40.85771419107914, 71.91747933626175, 85.6746943295002, 76.31430700421333, 75.94595476984978, 67.91506290435791, 68.83453756570816, 70.66063597798347, 73.6581203341484, 80.37425994873047, 87.63144493103027, 87.99887761473656, 89.98468905687332, 82.70753994584084, 77.37001955509186, 82.97221094369888, 88.55807840824127, 86.47154957056046, 74.17097881436348, 67.51160055398941, 67.86368206143379, 73.97893711924553, 80.65287619829178, 82.3394612967968, 80.30419930815697, 77.43132546544075, 80.13875618577003, 79.60083425045013, 53.17295216023922, 14.581752698868513, 0.9458093263674527, 0.858995741000399, 0.5586536228656769, 0.5608694977127016, 0.4391808493528515, 0.3029896557563916, 0.025756377981451806, 0.11878643534146249, 0.0046602699512732215, 0.07653673252207227, 0.020489853159233462, 2.51723762601614, 13.29720787703991, 35.37447541952133, 39.13249656558037, 34.41819593310356, 47.61172257363796, 28.6744412407279, 25.434041619300842, 39.198643416166306, 76.13190919160843, 79.00308832526207, 80.81388875842094, 92.9867559671402, 80.95953494310379, 16.99704274535179, 0.1762599396170117, 0.025550984901201446, 0.07486567570595071, 0.032668680214555934, 0.03242415368731599, 0.03564881502825301, 0.03908394573954865, 0.07791499723680317, 0.009095260047615739, 0.021530503763642628, 0.04119901837839279, 0.051466293807607144, 0.03602293167205062, 0.06483167584519833, 0.042555742256809026, 0.04585089649481233, 0.04218473521177657, 0.037744313522125594, 0.05179846426472068, 0.013824187008140143, 0.04411907633766532, 0.020443381727091037, 0.015670604043407366, 0.037268723026500084, 0.07209117888123728, 0.047980396484490484, 0.06448844738770276, 0.03054610817343928, 0.07403545736451633, 0.011454334144218592, 0.07332132576266304, 0.04810573780559935, 0.028584860483533703, 0.15636383614037186, 0.22091833467129618, 0.09762366389622912, 0.17020193656207994, 0.24650908570038155, 0.06519339120131917, 0.23509706603363156, 0.1673846400808543, 0.1883533992804587, 0.08684809523401782, 0.13908567343605682, 0.14936821855371818, 0.0820592611853499, 0.13408284110482782, 0.1395489220158197, 0.16010083170840517, 0.17070800706278533, 0.10885077746934257, 0.10546824647462927, 0.22297218383755535, 0.2938164136139676, 0.19288406241685152, 0.15083851700183004, 0.19073699950240552, 0.17666878877207637, 0.17366433748975396, 0.5619974434375763, 5.1165128499269485, 60.5066042393446, 130.9769806265831, 104.86963033676147, 121.54712542891502, 95.65114259719849, 54.95755299925804, 26.07831034809351, 67.53169387578964, 71.20861977338791, 104.02735993266106, 91.62275835871696, 62.61571526527405, 33.059271052479744, 1.519448454491794, 0.44114748132415116, 0.10170923138502985, 0.3235246741678566, 1.0493614291772246, 3.4381801960989833, 0.7484279677737504, 0.6619626574683934, 0.43664878990966827, 0.38225580705329776, 0.911873762961477, 0.5252085893880576, 3.8032299326732755, 28.956678695976734, 82.33664944767952, 96.24088615179062, 88.24531719088554, 88.8206747174263, 86.222472935915, 81.93516299128532, 89.31044563651085, 96.2056316435337, 91.65030688047409, 86.57551199197769, 71.92812636494637, 72.53558456897736, 71.20515435934067, 67.49127924442291, 69.21751901507378, 71.71955555677414, 69.06274572014809, 67.03345701098442, 63.34498733282089, 72.21510976552963, 76.06376364827156, 83.04681614041328, 86.14801213145256, 88.36735144257545, 87.37571865320206, 93.24798434972763, 90.83900481462479, 88.50850626826286, 83.85196253657341, 93.24365258216858, 69.6667917072773, 41.09283797442913, 48.878160417079926, 75.96464976668358, 89.80014055967331, 81.85988903045654, 80.02074971795082, 71.62208318710327, 70.97414955496788, 73.22625070810318, 78.55396002531052, 85.39841115474701, 92.23267123103142, 89.71817135810852, 95.0790224969387, 89.1515001654625, 80.0731261074543, 86.76296353340149, 93.54126781225204, 92.3733700811863, 78.74125957489014, 71.18297874927521, 71.48714482784271, 76.47726505994797, 85.23568108677864, 86.51376530528069, 84.10120636224747, 83.45489144325256, 82.92139247059822, 84.35293525457382, 57.45613552629948, 16.680700220167637, 1.676012403331697, 1.5568975824862719, 1.4143731677904725, 0.8649276976939291, 0.5041188898030668, 0.5311851936858147, 0.24330682237632573, 0.297974162385799, 0.17059511155821383, 0.18463382933987305, 0.2357782091712579, 4.5349611807614565, 20.610886327922344, 55.26240684092045, 73.24634402990341, 61.17832079529762, 85.88557541370392, 55.650388821959496, 36.90637841820717, 29.448408409953117, 68.61167192459106, 87.33020469546318, 88.33644390106201, 110.29854342341423, 86.47752285003662, 15.01089597120881, 0.12428969785105437, 0.24638121365569532, 0.2796586701879278, 0.1516272418666631, 0.18140781729016453, 0.1466291444376111, 0.20067882462171838, 0.22217428602743894, 0.14065482595469803, 0.11495036305859685, 0.09544730841298588, 0.19854148384183645, 0.1501100990572013, 0.10297978078597225, 0.20651860657380894, 0.09417753084562719, 0.11214125988772139, 0.13500460336217657, 0.150525716599077, 0.08604553673649207, 0.21989733242662624, 0.11400591334677301, 0.09246512898243964, 0.22726267314283177, 0.2392845749272965, 0.1889065813156776, 0.14185186562826857, 0.15718537877546623, 0.18602810217998922, 0.2375131129520014, 0.23260521615156904, 0.09300651086959988, 0.11837443205877207], [0.057737757088034414, 0.021110455600137357, 0.011524819619808113, 0.04024264606414363, 0.05800131599244196, 0.023125340158003382, 0.008235092336690286, 0.05159830332559068, 0.021934146752755623, 0.07477763472707011, 0.08375057863304392, 0.09744565235450864, 0.019701104174600914, 0.01572639313963009, 0.01606937854376156, 0.054311843850882724, 0.015186272903520148, 0.01025216159177944, 0.02367012479226105, 0.08513578242855147, 0.034512457059463486, 0.014435078446695115, 0.05819138743390795, 0.10373474535299465, 0.0425971132790437, 0.07032352412352338, 2.450756630860269, 52.37208813428879, 102.16986000537872, 92.60232299566269, 77.03549310564995, 56.675201430916786, 38.84504958987236, 27.17518039047718, 57.3809489607811, 58.645274117589, 52.033100724220276, 34.79814134538174, 32.01689578592777, 17.234045527875423, 1.4911132561974227, 0.0891293903987389, 0.10511339598451741, 0.09090917927096598, 0.05116237320180517, 0.05871230459888466, 0.3979495883686468, 0.44141162652522326, 0.030704413838975597, 0.3792864741990343, 1.3223989843390882, 0.14219261531252414, 0.23499968141550198, 24.938764795660973, 78.86881873011589, 80.74909463524818, 77.48199954628944, 77.91008457541466, 82.24382042884827, 87.3457458615303, 84.64570954442024, 77.55557119846344, 83.69731083512306, 84.14929658174515, 78.07444095611572, 71.52485400438309, 67.7964636683464, 68.8862831890583, 71.24081164598465, 70.25094956159592, 69.78638648986816, 67.34277561306953, 62.72608794271946, 62.50970095396042, 59.81025740504265, 65.2796459197998, 67.0709154009819, 72.08084776997566, 75.76000794768333, 85.59206396341324, 80.45670792460442, 83.56010779738426, 74.78458508849144, 76.95373669266701, 69.4371472299099, 88.07645425200462, 37.57463715970516, 36.090695187449455, 85.73562785983086, 73.15476134419441, 73.64903882145882, 60.832125172019005, 67.3654679954052, 64.2998380959034, 71.87654793262482, 73.56491133570671, 81.7336294054985, 81.53930023312569, 80.56622564792633, 80.38188993930817, 79.88783285021782, 65.22315055131912, 66.24683082103729, 70.0362154841423, 71.00099891424179, 61.48720622062683, 63.87148708105087, 64.67089578509331, 62.49306544661522, 63.84256303310394, 64.06946405768394, 67.33975857496262, 74.56619560718536, 78.23799178004265, 82.1766248345375, 75.46797841787338, 62.462534084916115, 55.59603653848171, 23.12045406550169, 0.8986336109228432, 1.0159303480759263, 0.22427113523008302, 0.2256422975915484, 0.14891156024532393, 0.05744678695918992, 0.04855653314734809, 0.027029129705624655, 0.08881558067514561, 0.10189051579800434, 2.7494151424616575, 11.571156196296215, 32.99385756254196, 46.43675722181797, 43.26523080468178, 74.08759608864784, 71.51866033673286, 25.908364467322826, 13.3274913020432, 34.47894707322121, 53.747211545705795, 64.17493879795074, 81.67607009410858, 70.02247542142868, 16.92048255354166, 0.6697148352395743, 0.10891363737755455, 0.016554993599129375, 0.061767043807776645, 0.02291258682816988, 0.07235360972117633, 0.009880171201075427, 0.0389000860741362, 0.04006287192169111, 0.059145774503122084, 0.09927978127961978, 0.05580549026490189, 0.03688249082188122, 0.02923332871432649, 0.06562099442817271, 0.03704780050611589, 0.057469489256618544, 0.042182390025118366, 0.0901620443619322, 0.02185802466556197, 0.010353520410717465, 0.041450695498497225, 0.033326954071526416, 0.023735932882118504, 0.04101732949493453, 0.052186811590217985, 0.04148192507273052, 0.052835775204584934, 0.024436811581836082, 0.026523125998210162, 0.03573681889974978, 0.0575567212945316, 0.05038243536546361, 0.021488106722244993, 0.038208267142181285, 0.04799512440513354, 0.07335648871958256, 0.017849581163318362, 0.004644403297788813, 0.03196034849679563, 0.046464726838166825, 0.02065534095891053, 0.1016021691611968, 0.030798603511357214, 0.04839536464714911, 0.03760378043807577, 0.04417254065629095, 0.017716144866426475, 0.04665089458285365, 0.04266127565642819, 0.03531372422003187, 0.05759922780271154, 0.05304918719048146, 0.062182431283872575, 0.015369613993243547, 0.07685904725803994, 0.040635906407260336, 0.03159612839226611, 3.5016610147431493, 70.52771151065826, 124.83207195997238, 102.73127987980843, 85.26041775941849, 65.11375442147255, 59.296927750110626, 47.216999754309654, 46.90244123339653, 38.527067452669144, 37.17958755791187, 33.80721151828766, 41.26792497932911, 23.0983392521739, 2.1445134887471795, 0.13053754228167236, 0.19173147738911211, 0.2720704476814717, 0.3447607549605891, 0.21446334198117256, 0.66278857877478, 0.21746356302173808, 0.23641960287932307, 0.5913189856801182, 0.9587807615753263, 0.2305770304519683, 0.5510514182969928, 22.795106023550034, 85.26165649294853, 87.0193661749363, 82.04727217555046, 82.10318997502327, 86.86582401394844, 91.41550987958908, 84.1477158665657, 78.87617513537407, 86.72055780887604, 87.59223103523254, 82.21475198864937, 73.19031983613968, 71.64053499698639, 71.63130149245262, 74.1531653702259, 73.8558541238308, 73.30028593540192, 70.91162770986557, 65.02446681261063, 64.41342920064926, 61.583527252078056, 68.61488655209541, 68.2523176074028, 76.51473104953766, 78.20882454514503, 86.52425274252892, 83.93523886799812, 86.35227397084236, 79.00387108325958, 81.92791298031807, 72.61566147208214, 89.85095143318176, 42.125801146030426, 41.68029025197029, 89.30507272481918, 77.95714125037193, 77.05645278096199, 63.9093254506588, 69.33338239789009, 66.34938731789589, 74.27754029631615, 77.51449540257454, 85.25816068053246, 82.95475468039513, 80.79492017626762, 84.1785778105259, 82.93836995959282, 68.3663722872734, 70.3907972574234, 75.02086400985718, 74.12165746092796, 64.39989432692528, 68.96700605750084, 67.53724917769432, 65.52850976586342, 67.40348875522614, 67.23565936088562, 70.64619675278664, 79.52346280217171, 81.1048011481762, 87.17399507761002, 80.16160055994987, 66.66720226407051, 58.853666335344315, 26.282216906547546, 0.775814107619226, 0.3267394797876477, 0.8327132638078183, 0.5497764085885137, 0.08002757997019216, 0.06576386527740397, 0.07619622774655, 0.09563673418597318, 0.08254639207734726, 0.20109687640797347, 2.6691741356626153, 14.567102584987879, 38.41732554137707, 49.38797526061535, 43.297909051179886, 51.495254784822464, 48.83532531559467, 18.567120395600796, 23.78679011017084, 53.88446778059006, 65.61788856983185, 74.58052083849907, 88.94686594605446, 91.96560636162758, 33.18610064685345, 0.7830954669043422, 0.04583096982969437, 0.04880575004790444, 0.03512209797918331, 0.05401784204877913, 0.013385209440457402, 0.03568341395293828, 0.05509720678674057, 0.004488209506234853, 0.034299453254789114, 0.0605825315869879, 0.056728109702817164, 0.03265801184170414, 0.04180648480542004, 0.015311869337892858, 0.014242782417568378, 0.08003607756108977, 0.04314333025831729, 0.027260559181740973, 0.0562501183594577, 0.03435331833316013, 0.08956916484748945, 0.035640016867546365, 0.016346240445272997, 0.06278437242144719, 0.025118541016126983, 0.025567416050762404, 0.011973441396548878, 0.028401902527548373, 0.05927788792178035, 0.07620845834026113, 0.04083597086719237, 0.14597449597204104, 0.12097519953385927, 0.08440196164883673, 0.09916990631609224, 0.15869180497247726, 0.16330533631844446, 0.11512513141497038, 0.11329530694638379, 0.12573327898280695, 0.2124161721440032, 0.22410709090763703, 0.1506243777112104, 0.11165148694999516, 0.08905516820959747, 0.06669899361440912, 0.1481325426721014, 0.1385124830994755, 0.16133190627442673, 0.13950765860499814, 0.19151711545418948, 0.14041073358384892, 0.15774250903632492, 0.1400624288362451, 0.13609679241199046, 0.2485584671376273, 0.12527564103947952, 6.759046437218785, 91.69543325901031, 137.39862084388733, 115.09681195020676, 104.51371863484383, 78.97717371582985, 56.94726303219795, 41.98201306164265, 83.59316602349281, 83.7404765188694, 67.69984245300293, 57.564661502838135, 51.92586287856102, 30.597196966409683, 3.6362885031849146, 0.30243651825003326, 0.498455649940297, 0.6175746268127114, 0.49993139575235546, 0.49063997401390225, 1.563465055078268, 0.9846682380884886, 0.15992173663107678, 0.7952678168658167, 2.0490291249006987, 0.40608925628475845, 1.3067102199420333, 29.69775103032589, 89.83241602778435, 89.37919154763222, 84.11695271730423, 86.06116399168968, 90.7112480700016, 95.34772127866745, 87.74258896708488, 79.63137701153755, 89.28053364157677, 91.11388206481934, 87.40951403975487, 76.56735062599182, 73.37134212255478, 74.16049897670746, 78.70190128684044, 77.89412543177605, 79.26733374595642, 74.67670127749443, 69.11421775817871, 69.17137429118156, 65.39971947669983, 72.98959940671921, 73.68845790624619, 82.09667712450027, 84.15982961654663, 92.00251758098602, 86.69378444552422, 88.52956473827362, 81.73023238778114, 84.90879982709885, 77.68282637000084, 93.14627900719643, 50.13069860637188, 48.45404617488384, 90.50700902938843, 81.31476268172264, 81.19804814457893, 68.53368490934372, 73.01290735602379, 70.37286221981049, 77.79253408312798, 80.7666040956974, 88.44820350408554, 85.68330466747284, 82.01814293861389, 86.59306704998016, 87.02951923012733, 72.79973119497299, 74.36223775148392, 78.73215526342392, 78.7714147567749, 68.3926060795784, 72.41063967347145, 70.47025099396706, 69.97432440519333, 71.66362255811691, 71.22417613863945, 74.6832825243473, 82.26816192269325, 86.43580108880997, 92.69682392477989, 80.18413335084915, 69.11354899406433, 63.60901616513729, 28.246686793863773, 0.7530279771890491, 2.6656624116003513, 1.2823971058242023, 0.48486912273801863, 0.40219948219601065, 0.2156665117945522, 0.4421595926396549, 0.35632715618703514, 0.15607368608471006, 0.3684365126537159, 5.264846915379167, 21.64131883531809, 52.76054888963699, 69.15390282869339, 65.65751284360886, 102.93777599930763, 93.59077915549278, 34.0481223911047, 21.114106625318527, 50.50305962562561, 73.60857859253883, 81.762865036726, 100.59528529644012, 102.71705344319344, 31.778576374053955, 0.7872701960150152, 0.22929553437279537, 0.14878554356982931, 0.13503871246939525, 0.10389071510871872, 0.12240645359270275, 0.18704301881371066, 0.15235279512126, 0.07715960964560509, 0.1572426874190569, 0.18519195407861844, 0.1787848595995456, 0.10605490679154173, 0.11885728818015195, 0.11492901146993972, 0.12432734700269066, 0.10813899847562425, 0.1262104354100302, 0.19819430715870112, 0.12029081321088597, 0.22911434643901885, 0.18553435133071616, 0.17404045793227851, 0.10115943354321644, 0.19822325091809034, 0.12529787578387186, 0.10496176037122495, 0.17699335963698104, 0.13322718936251476, 0.10838661604793742, 0.1359332972788252, 0.1427299005445093], [0.05049816216342151, 0.013768570461252239, 0.033881668641697615, 0.04848147233133204, 0.015738276779302396, 0.06803763506468385, 0.0579515327262925, 0.03694986669870559, 0.12375774123938754, 0.022584574253414758, 0.014269130515458528, 0.08120913844322786, 0.06000745248456951, 0.08690357077284716, 0.040474084817105904, 0.0750829023309052, 0.04153628367930651, 0.049921561658266, 0.07499532148358412, 0.04221436916850507, 0.013424957942334004, 0.02812843224091921, 0.00169470662740423, 0.05017519804823678, 0.10448052213178016, 3.6777262296527624, 76.5841457247734, 113.13279613852501, 91.48868635296822, 96.21475115418434, 80.31667783856392, 52.16708153486252, 24.201121777296066, 31.0021735355258, 46.93167306482792, 62.18310847878456, 68.05640012025833, 57.35701024532318, 22.893809527158737, 2.2814659774303436, 0.12104767025448382, 0.04698110948083922, 0.03429887437960133, 0.1013714206055738, 0.023778081304044463, 0.3238391666673124, 0.20063612144440413, 0.05731161589210387, 0.031965216985554434, 2.967378096655011, 1.580995295662433, 0.5202150042168796, 20.600186102092266, 85.28716072440147, 81.44017115235329, 80.22153854370117, 77.85399198532104, 73.04483324289322, 77.28862032294273, 78.70001658797264, 83.17891225218773, 80.3828626871109, 79.66508880257607, 84.26952213048935, 77.88192808628082, 75.6962701678276, 70.48902958631516, 73.50336223840714, 73.82313787937164, 80.65665319561958, 79.97892916202545, 75.30183613300323, 69.89646658301353, 65.81881418824196, 59.2704963684082, 58.17854896187782, 58.85594621300697, 63.15243646502495, 68.99059519171715, 77.38999888300896, 79.55665782094002, 80.57493478059769, 75.30228450894356, 74.68966618180275, 68.25036451220512, 85.20063936710358, 53.85058119893074, 24.32154681533575, 86.18290185928345, 71.81622236967087, 78.61860975623131, 60.75058914721012, 61.73313282430172, 62.7431870251894, 72.8340357542038, 73.38118359446526, 78.49257051944733, 76.56387761235237, 80.51981493830681, 79.91196915507317, 81.94929823279381, 64.52065944671631, 58.90440881252289, 59.12684507668018, 60.6283725053072, 57.80792064964771, 62.517201751470566, 60.00276267528534, 59.48713034391403, 60.350611209869385, 64.1322822868824, 72.10147306323051, 78.90847340226173, 78.50623458623886, 75.92587664723396, 68.96629929542542, 76.17925465106964, 82.91404366493225, 90.86181119084358, 57.65569321811199, 4.006100334227085, 1.5308828721754253, 0.41126965486910194, 0.047416583183803596, 0.04692335925938096, 0.15073544753249735, 0.012660310203500558, 0.05373489824705757, 0.10943518907879479, 0.1738046034006402, 1.5271975449286401, 6.1518152710050344, 21.08183305710554, 30.10454010218382, 38.01470294594765, 42.275300323963165, 81.13238766789436, 39.803570955991745, 8.521458841860294, 24.908041544258595, 48.8488107919693, 60.067689791321754, 69.60626095533371, 74.09713357686996, 20.09047195315361, 1.0537389130331576, 0.22125206363853067, 0.04662187289795838, 0.021199286966293585, 0.014064671613596147, 0.03716151608387008, 0.03575579190510325, 0.06251840153709054, 0.030402268821489997, 0.015764187010063324, 0.10275746302795596, 0.07225721958093345, 0.049401509095332585, 0.042952731892000884, 0.007061426140353433, 0.06286157804424874, 0.06415043622837402, 0.047169852477964014, 0.040090554030030034, 0.04852474696235731, 0.033331978411297314, 0.049191065700142644, 0.06198830400535371, 0.07812630894477479, 0.05692889404599555, 0.03977658474468626, 0.03828494584013242, 0.006299924179984373, 0.054064096402726136, 0.06661579143838026, 0.003971817586716497, 0.0299404637189582, 0.056670867852517404, 0.06145113380625844, 0.0431771239527734, 0.020719672174891457, 0.04442670768185053, 0.03675555388326757, 0.04367450761492364, 0.046306738440762274, 0.02849021810106933, 0.019425030804995913, 0.0369068629515823, 0.024674031665199436, 0.053119019576115534, 0.029129583890608046, 0.07086587822414003, 0.0515677342627896, 0.06839751731604338, 0.04040328763949219, 0.07987761418917216, 0.01705810849671252, 0.05117532367876265, 0.09863629471510649, 0.023918464103189763, 0.05175520076591056, 5.207631960511208, 91.97209641337395, 128.62853944301605, 100.18952026963234, 112.0349970459938, 102.00206100940704, 78.51377338171005, 37.367479875683784, 30.158613100647926, 42.88723848760128, 50.384160205721855, 58.9794509857893, 57.152322828769684, 29.01323676109314, 2.8904611989855766, 0.0564424014010001, 0.06090830473112874, 0.09366329672047868, 0.16573258966673166, 0.04418596981849987, 0.18913743377197534, 0.3680874063866213, 0.3103641397319734, 0.06121555757999886, 2.70520047750324, 1.4552962593734264, 0.30053412658162415, 20.489239655435085, 89.67916265130043, 86.21154472231865, 87.4602185189724, 82.06226617097855, 78.44523265957832, 80.44806718826294, 82.02717885375023, 85.67414715886116, 82.94703349471092, 79.9844616651535, 88.59055906534195, 80.5628590285778, 78.53393509984016, 73.85181114077568, 76.85993492603302, 77.97732576727867, 83.63145276904106, 82.67342537641525, 78.62050965428352, 72.40161895751953, 69.81806918978691, 62.48451970517635, 60.9335645288229, 61.05768106877804, 66.59198150038719, 69.78591531515121, 79.6974478662014, 81.79869711399078, 83.14488127827644, 80.89407965540886, 76.73996776342392, 72.78204694390297, 87.10104659199715, 57.606603652238846, 26.993597634136677, 89.04120728373528, 77.66293823719025, 82.0235538482666, 64.50919926166534, 63.387419655919075, 66.1717240512371, 77.21833169460297, 77.19386860728264, 80.32809242606163, 79.42673519253731, 81.54588907957077, 82.43271589279175, 86.94469258189201, 67.12936386466026, 60.33902183175087, 62.503815069794655, 64.46361690759659, 60.55749870836735, 64.48238790035248, 62.885504588484764, 62.50753507018089, 61.921595111489296, 66.86324134469032, 75.67933067679405, 82.22780048847198, 82.94042184948921, 78.76951485872269, 69.08852353692055, 80.29725328087807, 87.10695147514343, 95.81715568900108, 63.88451278209686, 5.461956588551402, 0.9500881342682987, 0.5624533595982939, 0.2689268288668245, 0.3903563192579895, 0.22663518728222698, 0.17404131882358342, 0.07802309104590677, 0.08296238069306128, 0.1361199325765483, 1.096274780575186, 5.115674044936895, 23.48772905766964, 36.729855090379715, 39.920673072338104, 42.20445312559605, 63.69342103600502, 31.03523176163435, 11.623184904456139, 41.47521145641804, 70.04661932587624, 70.71213841438293, 75.23939028382301, 91.93605914711952, 39.265641421079636, 1.2668396718800068, 0.11456226435257122, 0.019160377232765313, 0.05444890739454422, 0.03024728241143748, 0.0420961116469698, 0.0241172223832109, 0.043073390261270106, 0.037213596297078766, 0.027472015608509537, 0.045494565420085564, 0.06813106403569691, 0.06565415358636528, 0.03795263066422194, 0.014886058397678426, 0.054005752463126555, 0.032998126989696175, 0.01827830317779444, 0.009617555751901818, 0.017267210459976923, 0.04523970448644832, 0.0757014230475761, 0.00925038004425005, 0.026997616259905044, 0.0920314401446376, 0.02993506088387221, 0.009756244598975172, 0.0234742015163647, 0.03428105170314666, 0.03666685239295475, 0.012436618544597877, 0.13902913662604988, 0.17558424384333193, 0.11765155795728788, 0.09732236678246409, 0.13448104786220938, 0.23109029978513718, 0.0950955601001624, 0.14940323308110237, 0.19624588749138638, 0.1453948489506729, 0.13049047527601942, 0.16128397837746888, 0.1426175987580791, 0.10229920168058015, 0.18912584142526612, 0.1478290933300741, 0.10515170564758591, 0.17334951844532043, 0.15070303052198142, 0.19604176719440147, 0.1832952324184589, 0.1374666189076379, 0.14258534502005205, 0.2097636621329002, 0.20136305509367958, 7.524784198030829, 111.95612847805023, 139.87625509500504, 114.41781878471375, 124.00232568383217, 103.60569655895233, 76.38793185353279, 37.58958175778389, 43.40315580368042, 66.36488288640976, 85.17874494194984, 102.89549186825752, 83.70923459529877, 39.93396855890751, 5.063345152884722, 0.19260594999650493, 0.160419391177129, 0.30484475777484477, 0.5648645083419979, 0.31606983044184744, 0.8159528975374997, 0.4104969010222703, 0.3394772869069129, 0.13956150884041563, 5.862336829304695, 3.06862223893404, 1.277832007035613, 25.296217314898968, 94.56169545650482, 87.68341094255447, 90.27539625763893, 85.31421527266502, 82.16469347476959, 85.24860799312592, 87.08114326000214, 89.97992411255836, 85.17966449260712, 81.21310293674469, 91.41756936907768, 84.51324105262756, 81.93902358412743, 75.97747027873993, 80.19656628370285, 80.55948480963707, 87.32873037457466, 86.33573725819588, 81.3193528354168, 76.38689830899239, 72.45845630764961, 64.8039798438549, 64.24971878528595, 64.13217589259148, 70.7524162530899, 73.85656848549843, 83.75220268964767, 89.03127461671829, 88.02685171365738, 85.46873018145561, 81.16679862141609, 76.72688886523247, 90.96837267279625, 60.767999812960625, 32.33562268316746, 92.64934167265892, 80.50654605031013, 86.22732147574425, 68.69541183114052, 67.38757520914078, 71.27048805356026, 78.67660224437714, 82.40474179387093, 84.6858885884285, 83.70775267481804, 85.35242602229118, 87.26604893803596, 90.25106996297836, 71.41350477933884, 64.69148308038712, 66.45571321249008, 67.06280663609505, 63.64337392151356, 67.84068569540977, 67.49646976590157, 64.80135038495064, 65.92580884695053, 70.08557483553886, 79.01508048176765, 87.92000144720078, 87.3423944413662, 81.00248023867607, 70.96582040190697, 81.60852491855621, 89.31597054004669, 99.2825773358345, 65.60654237866402, 5.3668486420065165, 4.960963921621442, 2.571641206741333, 0.33634886727668345, 0.2675490762339905, 0.2321470290189609, 0.1395120075903833, 0.31769112625624985, 0.3715334355365485, 0.26133154111448675, 3.122891401872039, 12.541097849607468, 35.77028498053551, 50.360305085778236, 53.71793411672115, 63.83457586169243, 109.3879982829094, 54.516867846250534, 16.737047396600246, 36.64825066924095, 68.61937791109085, 81.53687596321106, 85.44165283441544, 108.33182975649834, 40.56096151471138, 1.484322901815176, 0.35063909890595824, 0.10648409079294652, 0.1549186816555448, 0.12454618408810347, 0.1217637091758661, 0.09372401182190515, 0.19245575414970517, 0.06941130588529631, 0.1210894828545861, 0.22948904195800424, 0.13359922799281776, 0.18103496229741722, 0.09068760366062634, 0.08482294491841458, 0.16974993894109502, 0.20965426956536248, 0.11296318101813085, 0.15478016721317545, 0.1858690005610697, 0.09994026302592829, 0.13501059991540387, 0.15770658908877522, 0.15996720059774816, 0.13718752685235813, 0.08897919455193914, 0.1598340444616042, 0.15518745785811916, 0.16140591324074194, 0.09802767424844205, 0.06013060818077065], [0.03512242823489942, 0.04217678681015968, 0.026476940292923246, 0.025476953815086745, 0.04598948515194934, 0.01619864397071069, 0.0409880554798292, 0.07334767942666076, 0.020573825313476846, 0.03742219916603062, 0.017210066944244318, 0.056825219726306386, 0.03809487068792805, 0.014400838535948424, 0.08418460143730044, 0.08977537057944573, 0.07378628870355897, 0.073743036336964, 0.09529349830700085, 0.04559658103971742, 0.031872871550149284, 0.08257437846623361, 0.036390257664606906, 0.0655962512246333, 0.2084418377489783, 64.52280253171921, 111.95930510759354, 81.40009850263596, 92.62199074029922, 79.11711260676384, 34.774730801582336, 13.45189567655325, 33.757635578513145, 56.5693961083889, 59.24782678484917, 40.061409920454025, 28.65146577358246, 19.84131172299385, 2.3660879116505384, 0.041300911543658, 0.05559535486099776, 0.06084398279199377, 0.09034935501404107, 0.0521256140928017, 0.12128953618230298, 0.05846428626682609, 0.010268954538332764, 0.03972198494011536, 0.5458620842546225, 0.739791743690148, 1.574715063907206, 11.853393651545048, 76.32571399211884, 83.42775329947472, 80.83436965942383, 76.27992644906044, 69.16046887636185, 64.8629678785801, 71.56964600086212, 80.22829458117485, 81.38696640729904, 82.7414645254612, 74.81067448854446, 80.83971217274666, 80.03021121025085, 75.31122162938118, 75.52774921059608, 76.68156489729881, 79.83758434653282, 82.52372100949287, 81.16564348340034, 78.56633216142654, 75.1530209183693, 69.68434676527977, 66.17170885205269, 59.994045943021774, 58.63784931600094, 57.400377318263054, 58.35729517042637, 69.2774797976017, 77.18935444951057, 82.74041578173637, 78.34927260875702, 72.84498676657677, 71.54410377144814, 81.4743921160698, 60.7680644094944, 14.017922803759575, 77.07932755351067, 77.2456294298172, 74.43156883120537, 62.21557013690472, 59.76032808423042, 65.33044159412384, 74.15936663746834, 76.314876973629, 73.94068837165833, 76.55826911330223, 79.42926585674286, 78.54389056563377, 82.44533881545067, 69.78908434510231, 56.251132786273956, 58.7086471170187, 59.63915258646011, 62.39077113568783, 66.24471053481102, 63.399715796113014, 61.65231876075268, 60.13901576399803, 61.91046930849552, 72.57279217243195, 75.87948873639107, 79.691611379385, 73.14210802316666, 74.59242179989815, 80.98957613110542, 74.64397743344307, 77.68560782074928, 89.25573617219925, 70.89744687080383, 4.278948018327355, 1.2162950215861201, 0.08764842728851363, 0.08232501684688032, 0.19231864978792146, 0.08961768646258861, 0.1399653113912791, 0.04028783914691303, 0.04156172821240034, 0.0655718197231181, 0.12223624202306382, 1.7765801819041371, 11.07573688030243, 28.53485193103552, 33.892361149191856, 25.8573180064559, 49.843392223119736, 77.1862082183361, 23.426843024790287, 18.507326804101467, 54.0136456489563, 64.05723631381989, 72.46301606297493, 66.75485596060753, 18.0301883071661, 0.8749793458264321, 0.06854091509012505, 0.11101706200861372, 0.04111491078219842, 0.051690645050257444, 0.027957365346082952, 0.02290566815645434, 0.06929118186235428, 0.06249617421417497, 0.07073917135130614, 0.014628389362769667, 0.015338745288318023, 0.024229668888438027, 0.0198281004850287, 0.012523546301963506, 0.0767874819575809, 0.10698299956857227, 0.04833703183976468, 0.042124862447963096, 0.08050596836255863, 0.03168751274643, 0.03276768642535899, 0.033160772363771684, 0.06737661897204816, 0.017435633453715127, 0.03482862681266852, 0.005954957705398556, 0.057461834003333934, 0.04470391839276999, 0.054987020121188834, 0.009618622589186998, 0.041615107184043154, 0.07047469960525632, 0.06722341000568122, 0.03552719186700415, 0.01808844695915468, 0.05955599292065017, 0.024103362775349524, 0.032801480119815096, 0.015144230237638112, 0.03730102500412613, 0.021533058607019484, 0.03663664698251523, 0.012338729266048176, 0.044579066889127716, 0.010192554145760369, 0.1050689561816398, 0.09968776954337955, 0.0704083070741035, 0.003239851712351083, 0.06539501046063378, 0.039605760903214104, 0.06574131140951067, 0.05242227278358769, 0.8858864824287593, 80.6783576309681, 126.82242035865784, 93.73629614710808, 106.7195762693882, 86.24733120203018, 50.97109571099281, 27.106198891997337, 34.7315689176321, 37.48536095023155, 44.24957938492298, 49.14099991321564, 37.26143516600132, 27.201786562800407, 3.8799946010112762, 0.05464418871270027, 0.019112356567347888, 0.17643176164710894, 0.12387853319523856, 0.16185388842131943, 0.21783485950436443, 0.2546508761588484, 0.24443313537631184, 0.3637060633627698, 0.21654007898177952, 0.9396958106663078, 1.1685289721935987, 11.410376373678446, 80.60698986053467, 86.37790739536285, 87.94321820139885, 80.10394245386124, 73.9943414926529, 68.56533721089363, 74.56966862082481, 82.31248274445534, 85.03597140312195, 84.29865136742592, 74.56889346241951, 81.49719089269638, 83.62989485263824, 77.67820581793785, 78.08567315340042, 79.25902739167213, 82.4963016808033, 84.05771389603615, 84.37853068113327, 81.74526438117027, 79.09489139914513, 73.08883488178253, 67.56722956895828, 63.09789039194584, 60.87635099887848, 59.20541726052761, 62.09339529275894, 72.67492309212685, 79.2225569486618, 83.1277745962143, 81.30869820713997, 75.511554479599, 75.5515207350254, 81.81675374507904, 63.20507124066353, 17.789547219872475, 79.86457049846649, 81.13806456327438, 77.72435814142227, 65.50352230668068, 63.28285686671734, 69.17537167668343, 77.04731807112694, 79.3388383090496, 77.3635371029377, 79.2984464764595, 79.19720470905304, 79.80666920542717, 84.64770823717117, 73.01861464977264, 60.4618464410305, 60.8204597979784, 62.682975456118584, 65.17466515302658, 70.69623246788979, 66.77237302064896, 65.88605538010597, 61.72860726714134, 64.80503618717194, 76.06618791818619, 80.07992014288902, 82.10037052631378, 75.19963681697845, 77.5970421731472, 85.90109378099442, 79.95754390954971, 83.68029534816742, 93.36802750825882, 78.07680442929268, 5.393037786707282, 0.6676119449548423, 0.5508258054032922, 0.5115676776040345, 0.7823873986490071, 0.35604561504442245, 0.18711337441345677, 0.14757397264475003, 0.047097841888898984, 0.07584564460557885, 0.16010982653824612, 1.3353556953370571, 11.364621128886938, 34.85617943108082, 35.40501818060875, 38.31816986203194, 43.991075456142426, 54.205341562628746, 26.117529943585396, 29.549473486840725, 67.20760926604271, 74.20981273055077, 83.07612016797066, 81.41732677817345, 32.368745505809784, 1.3100826577283442, 0.08360035310033709, 0.038264878166955896, 0.07085444172844291, 0.03505707842123229, 0.07307540028705262, 0.017488131124991924, 0.025594959006411955, 0.053029635309940204, 0.07410342324874364, 0.020635939363273792, 0.027389397873776034, 0.018697664854698814, 0.020480776693148073, 0.01831766483519459, 0.05973738123429939, 0.04176525108050555, 0.09091388448723592, 0.016898116300581023, 0.03099926354479976, 0.044653415243374184, 0.01988937219721265, 0.021836730593349785, 0.04022671957500279, 0.036807170254178345, 0.06068774215236772, 0.007271753574968898, 0.06497043519630097, 0.051942800855613314, 0.04971001988451462, 0.2449853377765976, 0.1479279325576499, 0.20546261948766187, 0.1301502896239981, 0.2208759283530526, 0.06876367071527056, 0.1577447503223084, 0.15863437758525833, 0.3347040305379778, 0.14740903774509206, 0.17009862960549071, 0.14111056399997324, 0.14600100548705086, 0.07179642008850351, 0.40167902887333184, 0.16543129255296662, 0.2524570282548666, 0.18785397842293605, 0.1321995523176156, 0.1408427971182391, 0.12434790449333377, 0.1623598104924895, 0.16388410760555416, 0.1278115002787672, 1.9195125997066498, 99.59438100457191, 139.1914862394333, 105.26150330901146, 120.48204258084297, 98.18372189998627, 53.69057938456535, 21.645519509911537, 47.44121812283993, 79.63170379400253, 81.07045859098434, 66.45523443818092, 47.864496409893036, 36.580458506941795, 5.336532918736339, 0.17827341594966128, 0.1597857751767151, 0.41528170520905405, 0.36882349813822657, 0.2971073635853827, 0.40485550998710096, 0.2570870204363018, 0.2517322468338534, 0.32392032793723047, 1.019359426572919, 2.4391359044238925, 6.6928886622190475, 14.022572804242373, 83.38859260082245, 88.07462275028229, 89.0890771150589, 84.20153617858887, 76.7150031030178, 70.14612078666687, 77.92247951030731, 87.5275357067585, 88.24385046958923, 87.41832956671715, 75.51125809550285, 83.77903684973717, 86.8723900616169, 81.08488261699677, 82.87660047411919, 81.47398173809052, 87.61764407157898, 86.4650747179985, 87.68521964550018, 84.53673139214516, 82.1719054877758, 76.18474915623665, 71.42985910177231, 65.5839791893959, 65.9208995103836, 62.78637930750847, 64.14842382073402, 76.03157937526703, 83.68254482746124, 86.0888721048832, 85.94220757484436, 77.99402967095375, 79.95251297950745, 86.95300653576851, 74.79342341423035, 25.18865078687668, 81.72403872013092, 85.46655669808388, 80.55238679051399, 70.1015567779541, 65.63342973589897, 71.6765570640564, 82.09527119994164, 82.29060351848602, 79.3119053542614, 84.34392973780632, 81.59688234329224, 83.23314294219017, 88.87265592813492, 76.61351054906845, 62.44688652455807, 63.91553431749344, 65.24040162563324, 68.33348885178566, 72.62424901127815, 69.53802421689034, 68.76787394285202, 66.54380768537521, 66.89587399363518, 80.38078039884567, 84.67011943459511, 89.05713602900505, 76.50314927101135, 76.90694600343704, 88.95492911338806, 81.48844376206398, 85.8671236038208, 94.83803942799568, 79.55456793308258, 4.592667259275913, 3.3734867675229907, 0.8128697786014527, 0.5809346179012209, 0.5213108297903091, 0.215029600658454, 0.26536760735325515, 0.23287743591936305, 0.25756917893886566, 0.19504481053445488, 0.5768754263408482, 3.6379938991740346, 19.16430775076151, 49.16581258177757, 50.3280296176672, 38.74649427831173, 72.42278382182121, 97.75771155953407, 31.72518163919449, 28.11099037528038, 72.61560067534447, 86.00216075778008, 92.08340004086494, 99.97522696852684, 34.72404532134533, 1.2365114805288613, 0.14370037737535313, 0.1856677746400237, 0.11464233466540463, 0.12449034489691257, 0.18268358398927376, 0.211621064809151, 0.12614034698344767, 0.17806582240154967, 0.21249478042591363, 0.14276918984251097, 0.1028291841794271, 0.07144534713006578, 0.14949678821722046, 0.10661308348062448, 0.14498767704935744, 0.24533172778319567, 0.22507056186441332, 0.12918530468596146, 0.1750718502444215, 0.10821123913046904, 0.2110503235599026, 0.14666344650322571, 0.16850284882821143, 0.10883881404879503, 0.11809262374299578, 0.07907547129434533, 0.11043635371606797, 0.12785396596882492, 0.21270986966555938], [0.043676645000232384, 0.06911791264428757, 0.030747844321012963, 0.050867926111095585, 0.020372365615912713, 0.04080432940099854, 0.04417522723088041, 0.014679388823424233, 0.02003074205276789, 0.04213685926515609, 0.10811560598085634, 0.0649334242916666, 0.021284663635015022, 0.026611656794557348, 0.03603381155699026, 0.033006390804075636, 0.0210481448812061, 0.01894778717542067, 0.02639574377099052, 0.03383924748050049, 0.07122472889022902, 0.02316014317329973, 0.023894090118119493, 0.16373885446228087, 45.05352504551411, 115.80373361706734, 100.65232783555984, 91.38906329870224, 64.00967806577682, 60.723443403840065, 44.93605434894562, 62.264576107263565, 54.18806008994579, 60.87773032486439, 44.11266893148422, 31.484242267906666, 25.69051455706358, 4.240591451525688, 0.053392167028505355, 0.03688546312332619, 0.00989451413261122, 0.046277234359877184, 0.07826771776308306, 0.013182573438825784, 0.09495802529272623, 0.1557675501680933, 0.28734568739309907, 0.7406836864538491, 0.8891007537022233, 0.23005877388641238, 6.217745533213019, 64.72361415624619, 89.90899711847305, 80.97619324922562, 77.9357559978962, 68.38306859135628, 60.919668674468994, 62.36331760883331, 66.70339152216911, 74.56893146038055, 79.37558993697166, 80.50685003399849, 76.24182969331741, 75.25993958115578, 79.9072878062725, 75.04785776138306, 79.05912011861801, 77.46287137269974, 78.81246775388718, 72.88244515657425, 71.59521862864494, 79.22506481409073, 78.27364146709442, 74.77114140987396, 70.44260367751122, 62.82198719680309, 58.655134588479996, 59.00674872100353, 56.084944903850555, 60.41424259543419, 74.47471931576729, 77.41331443190575, 82.21763223409653, 70.39655774831772, 72.05362603068352, 73.20646896958351, 53.51391926407814, 23.065292425453663, 67.44605407118797, 83.18321362137794, 68.92293602228165, 61.97675295174122, 55.52466116845608, 63.78769397735596, 70.66411659121513, 74.92788299918175, 75.43538376688957, 78.37982296943665, 77.17381328344345, 78.47319915890694, 76.02285504341125, 64.28544446825981, 56.30545847117901, 58.83948169648647, 62.77175009250641, 72.66539320349693, 75.382239818573, 70.75513690710068, 66.2720462679863, 61.75711713731289, 63.13892059028149, 73.88221710920334, 74.98189330101013, 73.25915694236755, 71.49021506309509, 77.90541842579842, 78.35949406027794, 75.70945546030998, 75.9008739888668, 75.51156967878342, 85.55645987391472, 69.9978831410408, 2.5397830037400126, 0.8863190654665232, 0.9999640798196197, 1.2541129672899842, 0.5462385015562177, 0.13414294022368267, 0.0494374030677136, 0.06453852751292288, 0.054413417892646976, 0.09496698301518336, 0.09111470222705975, 0.11657707655103877, 3.787356996908784, 28.080267123878002, 47.60467775166035, 50.31371958553791, 105.71287348866463, 127.41262748837471, 46.29849784076214, 36.161405593156815, 66.0461787879467, 69.36678260564804, 73.06859716773033, 72.23736897110939, 19.49215415865183, 0.6817962869536132, 0.02482202889950713, 0.09237872072844766, 0.04829713026992977, 0.057351391296833754, 0.1006312618847005, 0.05636097295791842, 0.06849677956779487, 0.016665766561345663, 0.027244784832873847, 0.042092063231393695, 0.08619957690825686, 0.048334575330954976, 0.06885580834932625, 0.0035782170152742765, 0.06032787845470011, 0.03610112064052373, 0.04867165509494953, 0.05703751106921118, 0.031427519861608744, 0.018743900654953904, 0.03225466200092342, 0.04860842411289923, 0.01396178397044423, 0.01683813035924686, 0.021930565890215803, 0.03634682718256954, 0.016535476970602758, 0.018568507039162796, 0.023061090578266885, 0.06642854015808553, 0.04006937313533854, 0.009370610750920605, 0.028743466718879063, 0.047368406667374074, 0.07300368655705824, 0.04393116454593837, 0.026737137268355582, 0.026632542685547378, 0.039861809273133986, 0.016166447749128565, 0.07471897537470795, 0.10048091018688865, 0.02650688409630675, 0.03986647367128171, 0.02349203532503452, 0.021711808585678227, 0.06213015440152958, 0.08060584659688175, 0.04457193113921676, 0.015607152272423264, 0.013727832119911909, 0.3586765582440421, 59.105091243982315, 128.79563927650452, 110.86163520812988, 105.06691575050354, 75.25887563824654, 89.20285061001778, 51.18146002292633, 36.50500975549221, 42.10428290069103, 56.42937362194061, 46.983259096741676, 39.534104615449905, 31.893140226602554, 4.946633465588093, 0.09586270331055857, 0.01339336100500077, 0.013309641180967446, 0.07110272723366506, 0.29065275681205094, 0.3558036155300215, 0.5242050276137888, 0.40285319555550814, 0.4436332901241258, 0.3777666745008901, 1.143451149109751, 0.33366101619321853, 7.556191887706518, 69.62459117174149, 95.31887322664261, 87.67456501722336, 84.30010288953781, 72.19278216362, 63.86333271861076, 65.75421765446663, 67.94524848461151, 78.4933152794838, 81.89901933073997, 83.83458226919174, 75.40507659316063, 76.70591399073601, 84.23975452780724, 80.83693072199821, 82.62828379869461, 80.53705081343651, 81.1473360657692, 74.53685358166695, 76.07776209712029, 81.12370893359184, 79.04378414154053, 78.58596190810204, 73.11671018600464, 65.00406950712204, 61.221353486180305, 62.23714917898178, 60.76581113040447, 64.98897671699524, 75.7375967502594, 79.29671376943588, 84.93827864527702, 74.53533366322517, 75.20543530583382, 76.80592462420464, 62.464069202542305, 27.977881617844105, 67.76763841509819, 85.1930245757103, 72.38640457391739, 66.25848099589348, 55.914007276296616, 66.84064015746117, 73.3464914560318, 79.08927530050278, 79.1679234802723, 81.84057086706161, 79.76196080446243, 82.70612642168999, 78.42235028743744, 67.67059922218323, 58.318670243024826, 59.11864131689072, 64.96345728635788, 75.52165433764458, 77.58439645171165, 73.93221482634544, 70.30447348952293, 65.68337425589561, 67.11690813302994, 75.99741920828819, 78.52673068642616, 76.1788746714592, 72.12013766169548, 80.54817661643028, 81.95071935653687, 79.21382501721382, 79.3071936070919, 80.7849571108818, 88.39909493923187, 76.76577597856522, 3.6853956431150436, 0.6434776587411761, 1.2353969528339803, 1.4009361388161778, 0.9610440151300281, 0.3911761846393347, 0.09014724593725987, 0.1976953019038774, 0.21103479783050716, 0.03994970553321764, 0.07606791041325778, 0.057335223609698005, 3.098466075025499, 32.39370256662369, 32.92261518537998, 39.350578263401985, 107.50851273536682, 102.48759135603905, 54.25223104655743, 51.01631708443165, 72.01475411653519, 79.36192587018013, 80.9434162080288, 87.35281348228455, 31.15507163107395, 0.7570343872066587, 0.08475181748508476, 0.09709041594760492, 0.06316256345598958, 0.011399572922528023, 0.02833451180777047, 0.04941686042002402, 0.02103919643559493, 0.0224736398740788, 0.04111067682970315, 0.04715093513368629, 0.035984013447887264, 0.04089362089871429, 0.06119491103163455, 0.019274480582680553, 0.01069344352799817, 0.0863254748401232, 0.01662630842474755, 0.05042282304202672, 0.04967086417309474, 0.04337309917900711, 0.07440069792210124, 0.053058682970004156, 0.01918107758683618, 0.012738040895783342, 0.030804067573626526, 0.044648331531789154, 0.03724789836269338, 0.025654469973233063, 0.22843344078864902, 0.16896462795557454, 0.12153606279753149, 0.22346470272168517, 0.15611248556524515, 0.12592789978953078, 0.21006497408961877, 0.11693418317008764, 0.06680414851871319, 0.1344377954956144, 0.16192047391086817, 0.1463517444790341, 0.14608194411266595, 0.1725600811187178, 0.12507632985943928, 0.11817230813903734, 0.10894674458540976, 0.12030141107970849, 0.09806945716263726, 0.25102869083639234, 0.1499710205825977, 0.12485177081543952, 0.09835447155637667, 0.7395546126645058, 78.53294715285301, 143.99366855621338, 120.29539659619331, 118.23746502399445, 87.17353150248528, 84.28342938423157, 60.822773873806, 79.38907161355019, 74.58284631371498, 84.86048921942711, 67.30898782610893, 53.15371759235859, 46.851132586598396, 7.93039770796895, 0.5119038408156484, 0.23621646221727133, 0.267502884962596, 0.2580656757345423, 0.2466064554755576, 0.1678071595961228, 0.35773429786786437, 0.21641299361363053, 0.5215340084396303, 2.247589132748544, 3.0225525610148907, 1.7864431464113295, 9.43827174603939, 74.04121577739716, 95.25209560990334, 89.4976007938385, 85.19085109233856, 75.1893013715744, 66.79630413651466, 68.97472724318504, 72.30104595422745, 80.20542740821838, 85.80359861254692, 86.60323530435562, 77.19813197851181, 77.7881795167923, 85.19941583275795, 82.68784180283546, 85.60296937823296, 82.3531025648117, 82.75840401649475, 76.37487575411797, 77.42440983653069, 82.91490241885185, 81.68091863393784, 82.34146758913994, 75.41513085365295, 68.13266962766647, 64.12339076399803, 67.48160496354103, 64.6626578271389, 69.78055760264397, 80.34351199865341, 83.44340085983276, 89.28504019975662, 76.72566533088684, 81.05896040797234, 82.11155712604523, 66.13599076867104, 32.33458153903484, 70.91510832309723, 89.53448921442032, 74.98696982860565, 71.39858677983284, 59.727581441402435, 71.35238885879517, 79.51129585504532, 82.60445907711983, 82.62486398220062, 85.03866165876389, 83.4177978336811, 85.20886212587357, 82.8057798743248, 71.18227198719978, 59.467477798461914, 64.19545009732246, 68.7576524913311, 79.42203864455223, 79.56052601337433, 77.44717061519623, 74.02356952428818, 69.86673697829247, 70.1108966767788, 80.51007986068726, 82.57020011544228, 77.78623402118683, 71.11953735351562, 82.4847275018692, 85.92220544815063, 81.31815969944, 82.33058497309685, 81.59631997346878, 91.70779779553413, 82.68990129232407, 2.6597242802381516, 4.133240086957812, 3.2626424403861165, 2.6904705679044127, 0.9425222652498633, 0.32168910547625273, 0.2675516885938123, 0.18525707011576742, 0.40037317550741136, 0.28803463792428374, 0.17335048323730007, 0.19400994497118518, 7.017042618244886, 47.22622565925121, 69.60395827889442, 55.06246156990528, 110.86280554533005, 141.83998972177505, 62.79813587665558, 51.28816969692707, 83.33719655871391, 92.41580620408058, 92.28494122624397, 101.48105576634407, 35.175567492842674, 0.7542198663577437, 0.18710715521592647, 0.2027939455001615, 0.18597831891383976, 0.11724961077561602, 0.13058962620561942, 0.10699914128053933, 0.1289986990741454, 0.159105196071323, 0.11429313934058882, 0.13133538071997464, 0.1580231447587721, 0.09898722666548565, 0.15546448674285784, 0.12228213643538766, 0.12437509678420611, 0.12347912415862083, 0.05919130897382274, 0.10341921384679154, 0.14889106212649494, 0.10091614269185811, 0.21181982679991052, 0.08247763209510595, 0.10173773727728985, 0.15050239831907675, 0.20215620315866545, 0.09291814334574156, 0.12412678159307688, 0.10466410720255226], [0.026783304419950582, 0.013703291151614394, 0.039369141959468834, 0.010408457892481238, 0.015553732482658233, 0.010718884350353619, 0.014330020949273603, 0.04072825555340387, 0.051080892808386125, 0.028772054247383494, 0.015249345251504565, 0.017785409509087913, 0.012292959163460182, 0.08064477966399863, 0.10624408023431897, 0.0517827455769293, 0.0028354225105431397, 0.04865883449383546, 0.026867664346355014, 0.0503325964382384, 0.02945126594568137, 0.04308663759729825, 0.1631423458456993, 13.058655727654696, 100.94191029667854, 94.41123113036156, 80.75740098953247, 49.491610899567604, 35.21559454500675, 15.697589423507452, 32.707276940345764, 47.282531037926674, 52.555276304483414, 49.18682545423508, 35.41228339076042, 18.252822160720825, 0.4776122246403247, 0.4257824714295566, 0.05413423677964602, 0.05758465573308058, 0.10800502597703598, 0.10065184163977392, 0.13091021915897727, 0.3363898041425273, 0.33979688538238406, 0.7008883031085134, 0.3744751011254266, 0.8656315505504608, 0.7091290515381843, 13.747608158737421, 63.07525500655174, 87.64276072382927, 79.66445043683052, 77.59227722883224, 68.85855987668037, 62.05672726035118, 62.098209634423256, 65.9754341840744, 71.35428115725517, 73.83095026016235, 79.66173738241196, 78.5438221693039, 77.38831177353859, 73.0690835416317, 74.41267624497414, 74.80660110712051, 77.15068012475967, 72.94593214988708, 70.68607941269875, 71.02579638361931, 67.464939057827, 71.08237534761429, 76.3653914630413, 75.3448574244976, 78.20584550499916, 67.15478450059891, 62.31443703174591, 54.32104155421257, 56.07166841626167, 61.837334632873535, 69.91573914885521, 72.8914886713028, 80.97713559865952, 73.11962082982063, 72.04980343580246, 71.49317890405655, 80.52995279431343, 28.987970016896725, 54.486093297600746, 77.86571055650711, 72.57943421602249, 72.69044145941734, 57.46810108423233, 58.85844647884369, 70.19679486751556, 77.70458400249481, 73.13728988170624, 74.86133337020874, 70.96259817481041, 69.55140709877014, 60.022403821349144, 57.83456861972809, 58.09950940310955, 58.597594276070595, 66.6734491288662, 72.650186419487, 74.51517954468727, 75.27285128831863, 72.24107757210732, 67.7317151427269, 63.897933661937714, 69.09316688776016, 75.50850704312325, 78.95550727844238, 73.45217898488045, 80.6274251639843, 78.9208835363388, 72.99890890717506, 63.497165367007256, 77.01476901769638, 75.13968363404274, 86.4597550034523, 52.69703909754753, 0.5317157995887101, 0.6966702325735241, 1.9310239632613957, 1.6264560562558472, 0.11722860799636692, 0.01362692601105664, 0.028715150074276607, 0.05470255491673015, 0.08437084339675494, 0.1466140046250075, 0.06296454361290671, 0.0868391152471304, 1.5299993008375168, 34.391316175460815, 61.51624046266079, 84.68428507447243, 101.5255057811737, 51.27856381237507, 19.766434840857983, 44.86058659851551, 56.50557853281498, 73.18020477890968, 70.76598152518272, 75.66315114498138, 11.019311808049679, 0.1727241402841173, 0.027764644437411334, 0.1335154692060314, 0.07175219550845213, 0.13727523386478424, 0.030466355128737632, 0.07282952676177956, 0.06814373249653727, 0.028119533890276216, 0.020227025270287413, 0.038698088319506496, 0.1089863307424821, 0.045925916492706165, 0.05081216113467235, 0.022009127787896432, 0.019273745856480673, 0.04767840917338617, 0.04376881603093352, 0.019410180429986212, 0.03942251350963488, 0.056457099635736085, 0.03794602554989979, 0.027182570593140554, 0.046376203463296406, 0.1112744610873051, 0.045165007322793826, 0.04103290346392896, 0.07441010093316436, 0.024765642374404706, 0.031199795557768084, 0.013621852504002163, 0.04468634804652538, 0.02731460608629277, 0.008172888301487546, 0.05846848311193753, 0.05712834623409435, 0.05737233841500711, 0.01542937172416714, 0.03319524883409031, 0.03430759832554031, 0.033333837491227314, 0.05616988848487381, 0.10210772015852854, 0.05975832093099598, 0.05830130321555771, 0.0416089881764492, 0.03425147711823229, 0.09640885720727965, 0.04729578009573743, 0.08703543557203375, 0.14430902752792463, 19.319882802665234, 119.68445017933846, 105.81200256943703, 96.36103570461273, 64.87166941165924, 67.10278809070587, 31.053267493844032, 31.871829070150852, 52.48551964759827, 56.87722519040108, 40.693581998348236, 41.25894986093044, 24.378258772194386, 0.6715840380638838, 0.5356079188641161, 0.012221903161844239, 0.11433866267907433, 0.12402621316141449, 0.432848489144817, 0.3568981646094471, 1.9075054815039039, 0.4303545464063063, 1.324462154880166, 1.3744392106309533, 0.6304672756232321, 0.5592038808390498, 12.316288612782955, 68.35903108119965, 93.38477700948715, 84.08172100782394, 81.24893501400948, 72.33958348631859, 67.80127421021461, 64.32735621929169, 69.90583688020706, 76.13886281847954, 76.65021657943726, 81.64551973342896, 81.99999511241913, 77.03136652708054, 73.94372060894966, 76.46569088101387, 76.17553845047951, 78.57005596160889, 74.61342707276344, 73.74914824962616, 73.04490923881531, 70.816131234169, 72.85653814673424, 76.466314047575, 78.80141034722328, 80.65067991614342, 70.44305205345154, 64.96614754199982, 58.046365454792976, 57.0360566675663, 64.03848811984062, 72.98549562692642, 77.14489683508873, 82.8203634917736, 75.23609966039658, 76.90833672881126, 72.49080017209053, 83.01238998770714, 31.737871058285236, 57.26488798856735, 82.60318234562874, 76.37714803218842, 76.81648805737495, 58.496185317635536, 62.6225320994854, 72.6260045170784, 80.73256552219391, 76.92756369709969, 78.19741755723953, 75.23165389895439, 71.14702507853508, 62.23456531763077, 60.697486996650696, 60.246139615774155, 61.97491765022278, 69.3455645442009, 75.0845941901207, 79.29598420858383, 79.8193833231926, 76.51679813861847, 70.6646865606308, 67.36715510487556, 72.53239274024963, 78.64950209856033, 82.71061018109322, 76.31269589066505, 83.07356670498848, 81.09643399715424, 76.06044262647629, 66.08067333698273, 82.14873433113098, 78.99475917220116, 91.38845533132553, 57.172389551997185, 1.0936016240157187, 0.1510400843108073, 0.4855612793471664, 1.057805169839412, 1.1337909987196326, 0.7364170497749001, 0.07735279068583623, 0.13045740517554805, 0.027160389654454775, 0.11426912344177254, 0.11071092609199695, 0.07425347066600807, 1.3423360395245254, 34.55924056470394, 55.1643493026495, 88.84033486247063, 107.58587658405304, 49.660200253129005, 28.90994120389223, 65.62634691596031, 67.25577548146248, 84.68021929264069, 75.47986418008804, 92.69713550806046, 18.763406462967396, 0.248783219140023, 0.0353733632073272, 0.1242798866587691, 0.03896890542819165, 0.028808167153329123, 0.05954673091764562, 0.04184717676253058, 0.03541175821737852, 0.01840808068664046, 0.059449594918987714, 0.03448458570346702, 0.12259826165973209, 0.06614044585148804, 0.022811320777691435, 0.04806700140761677, 0.04379651669296436, 0.024032068358792458, 0.03490253358904738, 0.03204961773008108, 0.054285564401652664, 0.01851800574513618, 0.05708886026695836, 0.036730936844833195, 0.09036595685756765, 0.016465815278934315, 0.00241988011111971, 0.028996719047427177, 0.05946144330664538, 0.11681964009767398, 0.16978009982267395, 0.11542956039193086, 0.18816305324435234, 0.1193251677614171, 0.14597863715607673, 0.16008282720576972, 0.11364389371010475, 0.16254893940640613, 0.09341902623418719, 0.1254422086640261, 0.2899036923190579, 0.15029927249997854, 0.10578305067610927, 0.3331156267086044, 0.17488334473455325, 0.11577584649785422, 0.2155061039957218, 0.10863197749131359, 0.14098108891630545, 0.18263049074448645, 0.1822748832637444, 0.42585374729242176, 27.95867744833231, 138.8348525762558, 114.4104927778244, 108.37684214115143, 72.50928997993469, 59.175889045000076, 31.166110038757324, 51.7862393707037, 63.973397612571716, 73.98194655776024, 70.30515745282173, 56.51474744081497, 32.721666768193245, 1.2877301196567714, 0.6457378249615431, 0.09042946243425831, 0.396016234299168, 0.3850696748122573, 0.3488746576476842, 0.30493087659124285, 1.9816805887967348, 0.29839160561095923, 2.091966108419001, 2.0015186117962003, 3.432691628113389, 1.8368477979674935, 15.648015383630991, 76.53438359498978, 91.1905999481678, 85.42071595788002, 83.92168119549751, 74.5561945438385, 68.82465809583664, 68.86845454573631, 72.10993140935898, 77.71552741527557, 80.03364622592926, 86.00241914391518, 84.82966527342796, 76.21456995606422, 73.40726539492607, 78.46406444907188, 79.11178529262543, 82.28061765432358, 77.50452473759651, 76.97226449847221, 74.89437639713287, 75.23768797516823, 75.28505623340607, 80.5768270790577, 80.91494053602219, 84.53677698969841, 73.90144407749176, 67.72338598966599, 60.063145235180855, 59.12037022411823, 70.08579522371292, 78.84865701198578, 82.44624316692352, 85.53233876824379, 79.7320868074894, 80.3332981467247, 76.53982490301132, 84.67255890369415, 35.826081186532974, 63.91158252954483, 88.29831674695015, 79.15125757455826, 81.38192027807236, 63.277578949928284, 63.47626268863678, 79.16714832186699, 82.94971615076065, 80.09886592626572, 84.05686274170876, 79.62573811411858, 74.27496403455734, 66.29072606563568, 63.23633596301079, 64.12176445126534, 65.1312866806984, 73.28404560685158, 78.45654845237732, 81.46105483174324, 80.75263604521751, 79.90123093128204, 73.95662471652031, 71.01967111229897, 75.21959334611893, 81.89640507102013, 86.39431491494179, 76.68433874845505, 85.93351364135742, 85.66651716828346, 77.70908296108246, 70.37910148501396, 84.77216675877571, 84.00396957993507, 92.07279101014137, 62.27482795715332, 0.6038019096013159, 4.2848889995366335, 5.410913927480578, 5.621819235384464, 0.9592160757165402, 0.7981716329231858, 0.24887255887733772, 0.2614989102585241, 0.30098024639301, 0.3273616370279342, 0.22751175274606794, 0.2758730639470741, 2.963690157048404, 62.77250625193119, 81.64191752672195, 88.45478475093842, 105.99338963627815, 61.21511422097683, 31.311408542096615, 64.1777278482914, 74.8203943669796, 95.79794391989708, 87.74752870202065, 103.36155965924263, 21.975664794445038, 0.32291649898979813, 0.18242804770125076, 0.2335900758043863, 0.110220826609293, 0.21313656005077064, 0.12662482098676264, 0.10325281691621058, 0.21022882545366883, 0.13701892574317753, 0.1381581966415979, 0.07006390602327883, 0.23998554825084284, 0.201037400693167, 0.10205055994447321, 0.10086824448080733, 0.12176309319329448, 0.0821124657522887, 0.15232989244395867, 0.13111053965985775, 0.21672488859621808, 0.0966228183824569, 0.13017127756029367, 0.0937556718417909, 0.1647141107241623, 0.14953766571125016, 0.11764579146984033, 0.1565960986772552, 0.12087563300156035], [0.02234106075775344, 0.021330166564439423, 0.02526468102587387, 0.032897736673476174, 0.012162236344011035, 0.052143318025628105, 0.02831973193679005, 0.00611399902481935, 0.05031868116930127, 0.07263523250003345, 0.024297222880704794, 0.09363709148601629, 0.018488408895791508, 0.020000460572191514, 0.05884208767383825, 0.06341298634652048, 0.05233899639279116, 0.046528280654456466, 0.004362183090051985, 0.0607070454134373, 0.09882042155368254, 0.033849652390927076, 1.215987119358033, 55.24088479578495, 97.20699951052666, 99.34971213340759, 82.71340683102608, 68.60730975866318, 22.75819480419159, 81.83251529932022, 91.7472168803215, 41.00558325648308, 50.06808556616306, 46.17824949324131, 21.610532887279987, 0.26602915779221803, 0.04461965865630191, 0.31705480883829296, 0.02335383258468937, 0.041426000534556806, 0.3577365539968014, 0.04398613913508598, 0.6545502052176744, 1.9934955798089504, 1.5299145178869367, 1.149525004439056, 1.1235068505629897, 3.2385127851739526, 32.10209481418133, 72.1707433462143, 91.28219023346901, 80.77488765120506, 80.88868394494057, 73.77625599503517, 59.4149874150753, 61.74471080303192, 67.36989855766296, 74.32319104671478, 75.00747352838516, 74.34385433793068, 77.3653382062912, 74.66412395238876, 72.2985228896141, 76.00507959723473, 74.37335595488548, 69.6968024969101, 69.87771838903427, 69.45765852928162, 68.63504827022552, 71.02856263518333, 72.9339399933815, 67.29092359542847, 70.43162986636162, 72.06525340676308, 74.85631003975868, 66.83506205677986, 61.592050194740295, 57.009264305233955, 55.62779143452644, 57.88844212889671, 68.166563808918, 71.96711987257004, 76.0089173913002, 69.89097967743874, 74.23747524619102, 63.85881096124649, 80.44106036424637, 34.223046004772186, 29.6626029163599, 71.4341376721859, 71.24931558966637, 80.53228586912155, 61.42843097448349, 56.73140801489353, 68.16786333918571, 76.2619686126709, 74.39908817410469, 73.14226761460304, 60.513960644602776, 56.68571926653385, 54.12411332130432, 54.8805995285511, 56.5861190110445, 64.20781463384628, 68.62099662423134, 75.90449899435043, 72.59056761860847, 75.75533419847488, 75.73534727096558, 72.28466123342514, 69.62775260210037, 69.96472612023354, 72.87688225507736, 73.88958111405373, 71.37828066945076, 73.87428313493729, 77.18142807483673, 72.49997287988663, 64.5703911781311, 63.06701324880123, 78.37109863758087, 76.13568618893623, 85.30894875526428, 31.39235369861126, 2.4157909071072936, 1.2592106312513351, 1.3706606696359813, 0.8702688454650342, 0.16645342286210507, 0.4650973289972171, 0.4648868559161201, 0.08835031345370226, 0.07914255402283743, 0.05986852243950125, 0.06006644951412454, 0.13715208187932149, 1.3505246001295745, 18.27132146805525, 32.20586344599724, 48.05118799209595, 79.1777953505516, 33.75341020524502, 12.497680429369211, 45.2311997115612, 63.65467071533203, 67.1477472782135, 69.49651524424553, 57.023532539606094, 2.2820794070139527, 0.11235070880502462, 0.07463724265107885, 0.026419069472467527, 0.009588607354089618, 0.043088192396680824, 0.0385157426353544, 0.017241001514776144, 0.021404370199888945, 0.02489123788109282, 0.015535921866103308, 0.04690479072451126, 0.04448134088306688, 0.04724331396573689, 0.04884744019364007, 0.05126057789311744, 0.05860799203219358, 0.03389669342141133, 0.026834785348910373, 0.0710975396214053, 0.07178677959018387, 0.035348545789020136, 0.02610468458442483, 0.036324729735497385, 0.04038823317387141, 0.0658404549176339, 0.06914529789355583, 0.030019639743841253, 0.03546859930793289, 0.02972294394567143, 0.04423105528985616, 0.0519004205125384, 0.0877919141203165, 0.005588833064393839, 0.05976767199172173, 0.06820785405579954, 0.08559322741348296, 0.06214468194229994, 0.041279062716057524, 0.04776687317644246, 0.028832368589064572, 0.028533748773043044, 0.06076435405702796, 0.017301820516877342, 0.020136802377237473, 0.036070944915991277, 0.017891215647978242, 0.02536085779865971, 0.07352937202085741, 0.011013268358510686, 2.282487885095179, 71.41255483031273, 113.36812511086464, 106.91032603383064, 93.52769494056702, 79.88537818193436, 30.1229178160429, 55.83070054650307, 67.40790411829948, 35.823630318045616, 47.34696038067341, 50.41354402899742, 28.690024204552174, 0.2938167698448524, 0.1541047534556128, 0.15821395092643797, 0.19584723544539884, 0.10142457322217524, 0.9583351761102676, 0.7810996833723038, 1.7559871869161725, 4.042111476883292, 0.39440826745703816, 2.343479124829173, 1.1364648677408695, 2.992715137079358, 36.416200920939445, 82.02207192778587, 96.17788553237915, 85.30360624194145, 85.07695600390434, 78.73125851154327, 64.54022079706192, 65.13620361685753, 72.25566118955612, 76.19516059756279, 77.28995025157928, 78.46790224313736, 80.32715007662773, 78.13915148377419, 75.17877593636513, 76.11509129405022, 76.08390256762505, 73.17363873124123, 72.19279736280441, 71.84299573302269, 70.82492396235466, 73.4103736281395, 75.52222430706024, 70.75845792889595, 74.21232059597969, 74.06216785311699, 76.793894469738, 70.48051804304123, 63.65025535225868, 59.2812117934227, 57.44722880423069, 61.15459866821766, 70.0910997390747, 74.62652117013931, 79.2613072693348, 74.47809353470802, 76.17463409900665, 68.78088444471359, 85.47275796532631, 36.036464497447014, 35.8619474619627, 76.3387168943882, 73.16268011927605, 83.77364113926888, 63.76931056380272, 61.54188148677349, 71.29465475678444, 78.44717055559158, 77.31024876236916, 77.35738903284073, 63.08741055428982, 59.65235687792301, 55.927538350224495, 58.60866688191891, 59.37007002532482, 66.33397534489632, 70.5890554189682, 78.69532763957977, 74.40248519182205, 77.44436636567116, 77.58891820907593, 74.38548490405083, 73.78504112362862, 73.04861783981323, 73.89773547649384, 77.42315590381622, 72.94337868690491, 76.26781269907951, 81.24285534024239, 76.57824844121933, 68.16397994756699, 66.30509689450264, 81.66809052228928, 80.08535385131836, 87.98769861459732, 35.35550303757191, 2.5684144673869014, 1.2829690938815475, 1.9131600530818105, 1.7492093006148934, 0.7658860716037452, 1.1582634667865932, 0.7570019701961428, 0.04491353058256209, 0.3636771789751947, 0.01188058202387765, 0.07870943663874641, 0.23856613144744188, 0.6573251250665635, 24.437092915177345, 35.02054341137409, 56.01578861474991, 68.09429168701172, 32.28411644697189, 25.399539470672607, 51.55247211456299, 74.72921445965767, 74.96689930558205, 79.86658439040184, 71.11210495233536, 3.7273684283718467, 0.1400467101484537, 0.043633073510136455, 0.028837888312409632, 0.13803982408717275, 0.04592222430801485, 0.018948482938867528, 0.04280691842723172, 0.03335994995723013, 0.060524703440023586, 0.008534518310625572, 0.09970846804208122, 0.014122853208391462, 0.014630053628934547, 0.048390770753030665, 0.03886697144480422, 0.007322747469515889, 0.05902417360630352, 0.04909034883894492, 0.04856493054830935, 0.034264750429429114, 0.010205803337157704, 0.030985168305051047, 0.055870276046334766, 0.019282436405774206, 0.024771217758825514, 0.013747539851465262, 0.014333178787637735, 0.21494745975360274, 0.09980499176890589, 0.10820516836247407, 0.14042940601939335, 0.17751520819729194, 0.10484521350008436, 0.14099199848715216, 0.15347606531577185, 0.16882173484191298, 0.15422198310261592, 0.13344082399271429, 0.21896636753808707, 0.15936405718093738, 0.14972628996474668, 0.12816724134609103, 0.10983075379044749, 0.16330002254107967, 0.1377586688613519, 0.11267910915194079, 0.2375034205033444, 0.14151236275210977, 0.08813425942207687, 4.049959480762482, 98.91132205724716, 123.3153073489666, 122.28949919342995, 109.43848237395287, 91.32361561059952, 30.624392107129097, 97.22040519118309, 111.43196940422058, 56.83662436902523, 71.84700831770897, 75.06246417760849, 36.99472367763519, 0.8559344115201384, 0.20888059545541182, 0.7204558874946088, 0.4529136390192434, 0.3631403687177226, 1.0968299070373178, 0.7403482357040048, 3.150556292384863, 6.646879781037569, 5.339728072285652, 7.906971490010619, 4.868488283827901, 3.6116639245301485, 42.44035206735134, 88.1131298840046, 92.89010435342789, 86.36640921235085, 88.46132799983025, 81.5964263677597, 65.45507490634918, 68.42710822820663, 75.79352974891663, 79.96591106057167, 80.71700915694237, 80.16400963068008, 84.8933270573616, 78.24777245521545, 76.35673552751541, 77.87596240639687, 79.21419739723206, 74.88730877637863, 75.10774254798889, 75.24584233760834, 72.33615607023239, 74.9402703344822, 78.19291859865189, 75.59401765465736, 75.83896771073341, 76.9472162425518, 80.50173550844193, 75.33973529934883, 66.83947741985321, 63.02094832062721, 61.42443738877773, 64.09622222185135, 74.74269613623619, 79.40688505768776, 80.96570581197739, 74.89752262830734, 80.51232933998108, 72.24949032068253, 88.01886454224586, 39.833703339099884, 39.829382970929146, 80.09878993034363, 77.25590407848358, 87.93580859899521, 66.78643226623535, 65.00915363430977, 74.15575683116913, 81.41918107867241, 83.38182136416435, 80.76644450426102, 66.38199716806412, 63.4773950278759, 58.00845868885517, 61.72799929976463, 62.27581970393658, 70.16077280044556, 74.15751233696938, 81.5190777182579, 77.85478994250298, 77.74668574333191, 82.22501903772354, 79.9041111767292, 77.00505673885345, 77.55014508962631, 78.84681031107903, 80.27311697602272, 74.40971240401268, 78.0079597234726, 84.06666621565819, 78.64786818623543, 73.12059357762337, 68.53618517518044, 86.60615354776382, 81.85613483190536, 94.52964797616005, 35.97106620669365, 3.6819181172177196, 5.907977605238557, 4.90922162309289, 4.0148816630244255, 0.923811059910804, 1.6040085232816637, 1.0400104871951044, 0.20902636810205877, 0.6515488412696868, 0.3321253345347941, 0.3175219165859744, 0.38629632617812604, 2.204254358075559, 32.72846460342407, 51.77921734750271, 60.76624430716038, 93.59566569328308, 46.077520698308945, 20.96697472035885, 61.279140785336494, 82.11812317371368, 87.44663044810295, 90.2259761095047, 80.92994213104248, 4.190604658797383, 0.28055889531970024, 0.16552079556277022, 0.10579432389931753, 0.15731002989923581, 0.1341922633582726, 0.1099579207948409, 0.16428926086518914, 0.15390891552669927, 0.13786354917101562, 0.0546146809210768, 0.1809551368933171, 0.13553707947721705, 0.09357889226521365, 0.12375478007015772, 0.19243470684159547, 0.12381338747218251, 0.17032934847520664, 0.22405009396607056, 0.1590789240435697, 0.14641800342360511, 0.11463449016446248, 0.17728567676385865, 0.12014040956273675, 0.08070487136137672, 0.12444457664969377, 0.14838509552646428, 0.09645420985179953], [0.04148724256083369, 0.025289429795520846, 0.03409557044506073, 0.027094922952528577, 0.027762874415202532, 0.06059944142180029, 0.05491876108862925, 0.05909907486056909, 0.057428396539762616, 0.009697337554825936, 0.019872820448654238, 0.043383752708905376, 0.04287151125026867, 0.05294373171636835, 0.05023245845222846, 0.03510746653773822, 0.07750535398372449, 0.06174045265652239, 0.06915139834745787, 0.08051079232245684, 0.08250264247180894, 0.18080301146255806, 25.040878616273403, 106.88579455018044, 93.58159884810448, 87.60201171040535, 61.28416031599045, 24.66299269348383, 56.575912758708, 123.28923314809799, 111.69300779700279, 61.422157511115074, 43.65290880203247, 24.794410541653633, 0.7146308594383299, 0.04859789303736761, 0.06397595730959438, 0.10550343911745586, 0.15461886883713305, 0.18122526380466297, 0.7215247582644224, 1.21821581851691, 0.9024523466359824, 2.5426943600177765, 1.997440243139863, 0.32407888036686927, 9.864724762737751, 63.580532893538475, 84.8325227200985, 76.65533110499382, 82.12304010987282, 84.79761779308319, 77.24570542573929, 68.91711473464966, 57.50258423388004, 65.27227431535721, 75.45388117432594, 78.7914776802063, 74.72937405109406, 79.83191505074501, 77.84652158617973, 73.17658737301826, 71.19232624769211, 76.03896617889404, 73.26723530888557, 73.77735793590546, 72.94061243534088, 70.43003395199776, 69.76791948080063, 74.41652923822403, 72.78969213366508, 69.74578946828842, 73.4355054795742, 74.21951740980148, 73.60622271895409, 66.29977717995644, 57.279862985014915, 53.41470278799534, 54.66537907719612, 58.91464166343212, 70.23201137781143, 76.030013859272, 74.0409953892231, 70.32902777194977, 72.01524809002876, 66.80686756968498, 82.57046610116959, 38.78185138106346, 42.67520986497402, 79.36672881245613, 65.9856328368187, 73.24653401970863, 60.81879548728466, 58.62726308405399, 63.35424743592739, 75.6376089155674, 73.35908398032188, 73.79478380084038, 58.699124827980995, 53.53063456714153, 52.937645986676216, 54.32563550770283, 54.5308168977499, 66.55638501048088, 72.10701316595078, 74.99639332294464, 68.86856094002724, 68.86102974414825, 70.47604948282242, 76.43055036664009, 71.53711974620819, 73.61821487545967, 72.58874371647835, 74.76348102092743, 66.91798120737076, 68.10910329222679, 75.00701755285263, 78.36913794279099, 67.06084594130516, 60.891971960663795, 68.71667549014091, 78.03003653883934, 76.10070526599884, 61.72783970832825, 17.96680010855198, 1.672782814130187, 0.9688112139701843, 1.8439872586168349, 0.90990831842646, 0.19268506293883547, 0.09031000634422526, 0.21426175982924178, 0.031940121261868626, 0.1042053708806634, 0.02091712798574008, 0.08971832910901867, 0.030370903805305716, 5.982557628303766, 27.89645578712225, 34.243051931262016, 37.127511352300644, 41.958841904997826, 28.219409957528114, 31.589924097061157, 48.86291563510895, 65.39220348000526, 73.08748975396156, 74.62228819727898, 27.495151720941067, 0.3383382980246097, 0.09239348946721293, 0.05401148184319027, 0.05949659884208813, 0.06927073569386266, 0.039645488068345, 0.0226610303070629, 0.02494278560334351, 0.02982881687785266, 0.06637445243541151, 0.07811203002347611, 0.048768115739221685, 0.013435171749733854, 0.03496464021736756, 0.025462853009230457, 0.05610669461020734, 0.032944213671726175, 0.01932022099936148, 0.024629055660625454, 0.03413778751564678, 0.05508043795998674, 0.043744618305936456, 0.0377336006204132, 0.07278505727299489, 0.0059487139242264675, 0.0026205610174656613, 0.019280670094303787, 0.03078680150792934, 0.029040715417067986, 0.03899399373040069, 0.009106459056056337, 0.07982421666383743, 0.03421250694373157, 0.0813847899553366, 0.0379380994127132, 0.030106535959930625, 0.06647064961725846, 0.07582888691104017, 0.01648033910896629, 0.023349683979176916, 0.016132809905684553, 0.0011424236345192185, 0.054660857349517755, 0.058549254754325375, 0.05573295275098644, 0.03810927577433176, 0.08392617077333853, 0.10107101406902075, 0.2700879337498918, 30.959017351269722, 123.28718885779381, 102.8941847383976, 103.48290234804153, 76.52915507555008, 44.293531626462936, 60.30612699687481, 122.27999970316887, 125.18147841095924, 63.26113723218441, 43.53754319250584, 31.84436034411192, 0.6865644373465329, 0.024496033111063298, 0.029088812152622268, 0.17392609297530726, 0.22665979689918458, 0.7080129801761359, 3.024947619996965, 2.453106567263603, 2.9117830423638225, 1.459761494770646, 0.7375572854653001, 0.5061692954041064, 10.432678386569023, 69.45694416761398, 89.98079806566238, 79.10426169633865, 88.23738321661949, 86.8117681145668, 80.99583059549332, 71.34044229984283, 60.51748685538769, 68.6185647547245, 78.77272948622704, 81.20695486664772, 80.3099673986435, 81.57694101333618, 80.0813640654087, 71.9714668393135, 74.00501891970634, 77.74781048297882, 76.23172983527184, 76.15964770317078, 74.4691564142704, 72.59638890624046, 72.48398333787918, 75.52048400044441, 74.08793807029724, 73.24746876955032, 75.25302395224571, 75.59033945202827, 75.98026692867279, 70.60696765780449, 59.97977010905743, 55.521647930145264, 57.3453638702631, 61.064554899930954, 74.47252303361893, 77.28608965873718, 77.38199651241302, 72.68673285841942, 77.37872868776321, 68.8882514834404, 84.9806235730648, 41.30322128534317, 44.26847957074642, 81.36818021535873, 67.64099881052971, 77.30246677994728, 62.46365502476692, 61.99162915349007, 67.74224817752838, 78.20788219571114, 76.62269845604897, 75.33383041620255, 60.95580093562603, 54.666693806648254, 55.54055571556091, 55.453175604343414, 59.56340745091438, 70.82162573933601, 76.46775797009468, 77.9798412322998, 69.53732505440712, 69.61279660463333, 72.08678305149078, 77.60744601488113, 74.92096737027168, 77.79253408312798, 75.33500835299492, 77.77186319231987, 70.77555701136589, 70.15392556786537, 77.25920990109444, 81.02993756532669, 71.54933989048004, 64.35349881649017, 72.14153051376343, 80.79744324088097, 79.25030305981636, 67.31722578406334, 22.767794989049435, 2.0425694715231657, 0.83680807845667, 1.0140221379697323, 1.4158168528228998, 1.1842977697961032, 0.7570945902261883, 0.5543266050517559, 0.17040434991940856, 0.07524587796069682, 0.12482952122809365, 0.05206377092690673, 0.02671541275049094, 5.512065449729562, 32.800550535321236, 34.69199404120445, 38.94288673996925, 35.41070647537708, 32.573805302381516, 47.28807494044304, 61.01452678442001, 71.77709966897964, 83.99776831269264, 85.61292484402657, 38.43182176351547, 0.3796668694121763, 0.08878958324203268, 0.04674669100495521, 0.053007430251454934, 0.039189824237837456, 0.03026523867447395, 0.013361643468670081, 0.05126372088852804, 0.007188963754742872, 0.036697161704069, 0.035709422518266365, 0.01831031942856498, 0.04548119934042916, 0.06750138141796924, 0.05609051950159483, 0.020959142821084242, 0.03916421643225476, 0.026372681531938724, 0.01828509382903576, 0.04425066654221155, 0.07801558793289587, 0.046107612797641195, 0.02825315015797969, 0.029879778303438798, 0.052302772164694034, 0.09016135416459292, 0.03104246952716494, 0.09251045936252922, 0.17923080129548907, 0.11695977242197841, 0.091373058676254, 0.19421977980528027, 0.24417480861302465, 0.16258554212981835, 0.09620728247682564, 0.16825531289214268, 0.164207401976455, 0.15720268565928563, 0.16282927826978266, 0.12229152460349724, 0.0967243590275757, 0.16433947457699105, 0.2051689219661057, 0.19807525182841346, 0.1986597228096798, 0.11333081871271133, 0.17049358575604856, 0.2260781015502289, 0.811242931522429, 38.859580010175705, 137.61584758758545, 114.9761912226677, 113.17457869648933, 85.25180742144585, 44.5710763335228, 78.62959116697311, 128.91274899244308, 118.739243298769, 77.67080381512642, 70.4596495628357, 40.03278225660324, 1.417073872871697, 0.14865651377476752, 0.26934026449453086, 0.16072485916083679, 0.6137883081100881, 0.982852173037827, 3.438570387661457, 5.962811037898064, 6.408539470285177, 9.202492497861385, 12.206154372543097, 3.7586219888180494, 10.247066896408796, 75.49941793084145, 92.31502801179886, 76.06377124786377, 85.91038048267365, 90.98499298095703, 83.69208231568336, 76.40539571642876, 63.63652288913727, 74.50366616249084, 79.36299741268158, 85.08229091763496, 82.57460027933121, 85.58692663908005, 80.13891577720642, 73.2926407456398, 75.05798041820526, 81.33693069219589, 79.42794352769852, 81.1286410689354, 75.99455416202545, 74.15153905749321, 74.38612326979637, 80.46417832374573, 78.31636637449265, 77.76617109775543, 79.04817670583725, 78.63851308822632, 78.96776542067528, 74.78076249361038, 63.72875154018402, 57.562518417835236, 61.05937957763672, 64.66961905360222, 76.476611495018, 82.15651631355286, 79.38821285963058, 75.96399620175362, 78.97219598293304, 72.23607704043388, 87.30115905404091, 44.915592446923256, 50.24583242833614, 83.36770132184029, 72.60381370782852, 80.2591261267662, 66.56879514455795, 65.28257936239243, 71.04758441448212, 83.4659868478775, 79.95002031326294, 79.65512573719025, 66.28324046730995, 57.607245817780495, 57.95067898929119, 57.70982511341572, 60.99145442247391, 73.75237807631493, 80.28196290135384, 80.9225781261921, 71.37172982096672, 72.06770807504654, 74.71069425344467, 81.16639584302902, 76.994888484478, 80.5539371073246, 77.15049013495445, 80.5532455444336, 70.20063266158104, 71.26643747091293, 81.93064883351326, 84.82701301574707, 74.60245326161385, 68.09430688619614, 77.00936570763588, 83.10501381754875, 82.69544139504433, 69.93444934487343, 22.16053057461977, 2.7416975190863013, 5.58393289335072, 5.568226436153054, 3.640989325940609, 1.8206764594651759, 0.40923670458141714, 1.0974742099642754, 0.2991521288640797, 0.23495374247431755, 0.27455189265310764, 0.29240318632218987, 0.18672488979063928, 10.340794567018747, 50.41492335498333, 48.97879421710968, 49.956489354372025, 60.92858299612999, 38.14951591193676, 46.26161701977253, 66.53724163770676, 83.89475584030151, 93.3488917350769, 97.5744853913784, 42.929587215185165, 0.6110453302972019, 0.13683905883226544, 0.14211804431397468, 0.10394630939117633, 0.1857695824583061, 0.11899687873665243, 0.09307067695772275, 0.086575964523945, 0.10728224093327299, 0.16797538963146508, 0.13476285617798567, 0.16263314348179847, 0.15873965865466744, 0.1335742769879289, 0.11895257994183339, 0.12120391460484825, 0.24439687404083088, 0.11230848060222343, 0.10226896658423357, 0.13539998995838687, 0.2532338787568733, 0.07921698401332833, 0.1532458807923831, 0.13446142547763884, 0.09066060432814993, 0.22028464445611462, 0.12030254656565376], [0.05460926695377566, 0.05211661926296074, 0.008280497859232128, 0.010534009797993349, 0.029466697051248048, 0.030346054845722392, 0.024577175827289466, 0.04344031920481939, 0.034467356745153666, 0.05269563916954212, 0.026203436609648634, 0.06285507683060132, 0.08537652771337889, 0.03134282225801144, 0.06503937329398468, 0.023605476308148354, 0.029572672028734814, 0.0199424116362934, 0.12070738812326454, 0.04463033445063047, 0.048143041858565994, 0.6263455061707646, 69.2307499051094, 100.28907492756844, 97.53039255738258, 77.4342893064022, 70.4641105234623, 85.70739537477493, 42.72405244410038, 67.62250140309334, 52.78432421386242, 33.67710269987583, 32.087625190615654, 3.417673883959651, 0.005692731883755187, 0.016630455174890812, 0.07153588914661668, 0.12542515411041677, 0.1548690616618842, 0.6796566455159336, 2.023900835774839, 1.3751262612640858, 1.9866712647490203, 1.9162333756685257, 0.6724764558020979, 29.23532724380493, 84.1508013010025, 85.54292500019073, 79.41284313797951, 86.3499940931797, 77.23376646637917, 81.26093477010727, 78.21829363703728, 68.44552963972092, 55.17950288951397, 70.84792792797089, 77.63364180922508, 72.75991693139076, 75.21781504154205, 76.857351064682, 70.72239026427269, 73.13564077019691, 73.44213992357254, 70.40927946567535, 67.53256022930145, 68.39395120739937, 73.01036909222603, 71.88331916928291, 71.64266288280487, 70.17259016633034, 68.44876706600189, 67.31664061546326, 72.47837483882904, 73.34723621606827, 75.96128314733505, 63.59238065779209, 54.07522514462471, 54.34538684785366, 54.343262761831284, 63.085358664393425, 75.78998073935509, 72.9271687567234, 73.17294716835022, 66.38945236802101, 73.64230558276176, 67.6668906211853, 78.73174488544464, 39.879494681954384, 46.485254019498825, 78.92041996121407, 58.62682990729809, 65.15122801065445, 51.72632038593292, 56.26140743494034, 61.553573459386826, 71.93901658058167, 70.56909888982773, 68.33054780960083, 53.4261591732502, 54.259595051407814, 52.83105030655861, 53.982874900102615, 61.15684054791927, 69.69432502985, 70.82362443208694, 71.59648016095161, 62.41290494799614, 63.360159918665886, 64.46022748947144, 70.7027605175972, 71.66109949350357, 72.41776049137115, 72.93418318033218, 68.35944145917892, 66.85527697205544, 65.89249223470688, 71.96936175227165, 75.73652520775795, 69.27209168672562, 57.99971915781498, 67.99381747841835, 79.4539949297905, 73.13292011618614, 74.91715237498283, 67.98428758978844, 22.99863640218973, 0.22356226545525715, 1.303532759193331, 1.6268184618093073, 1.1785377538762987, 0.30798012390732765, 0.24419085384579375, 0.06753308596671559, 0.18385372823104262, 0.10363651468651369, 0.14134235156234354, 0.07216339727165177, 0.16159394377609715, 11.391747873276472, 39.08177308738232, 31.24251253902912, 46.84792935848236, 42.38617077469826, 11.66407261043787, 47.65504404902458, 70.00044420361519, 65.70310279726982, 67.65131905674934, 66.54333651065826, 14.78718962520361, 0.2521346986759454, 0.04886955248366576, 0.021458790033648256, 0.03390489044249989, 0.030493784906866495, 0.034760746275424026, 0.04927207111904863, 0.08524676319211721, 0.03614644730987493, 0.05952155355771538, 0.06795498207793571, 0.06550568694365211, 0.007577863980259281, 0.0343118285672972, 0.03811923168541398, 0.02475302400853252, 0.05183028755709529, 0.04229926715197507, 0.0271895764672081, 0.057606979535194114, 0.04683909210143611, 0.022007676889188588, 0.025018833475769497, 0.04339168626756873, 0.03011158998560859, 0.06808787104091607, 0.0232513995069894, 0.03544842773408163, 0.09334062575362623, 0.022855020288261585, 0.015803582064108923, 0.029721452228841372, 0.012740059537463821, 0.014304559717857046, 0.020021346463181544, 0.007728891032456886, 0.01989125354157295, 0.10110680042998865, 0.054626451383228414, 0.012172204314992996, 0.03514431788062211, 0.03607349419326056, 0.04817278342670761, 0.10213728732196614, 0.10475424845935777, 0.0443342917424161, 0.08984375948784873, 1.0988382180221379, 81.87996715307236, 112.1649120748043, 108.14712926745415, 86.55398234724998, 76.57140880823135, 73.4826685488224, 50.92374265193939, 87.20344349741936, 71.62474304437637, 40.128244534134865, 37.45436981320381, 4.126238487660885, 0.03722677312907763, 0.03977446962380782, 0.17907594476127997, 0.25708108325488865, 0.6341733830049634, 1.941754468716681, 2.670003203675151, 3.4886277141049504, 1.7650715494528413, 1.066056783311069, 0.2907556184800342, 31.37390948832035, 88.95386517047882, 92.2067642211914, 82.6976528763771, 88.50808069109917, 83.0972470343113, 84.93040546774864, 81.55365586280823, 72.04474210739136, 57.83478140830994, 73.4303529560566, 82.76450648903847, 78.50735932588577, 78.12232598662376, 77.20349729061127, 72.68056198954582, 76.18721142411232, 76.48609578609467, 72.70339876413345, 70.62699258327484, 71.46423205733299, 76.2714909017086, 74.90902081131935, 73.34788978099823, 73.76000806689262, 72.43869736790657, 70.81049993634224, 76.3968613743782, 74.48142975568771, 78.05619433522224, 65.25154262781143, 57.830723226070404, 57.02748812735081, 57.58327290415764, 67.10367724299431, 79.69077542424202, 75.83505392074585, 75.54056212306023, 69.63101282715797, 75.94099223613739, 70.13858959078789, 80.959542542696, 42.07049511373043, 51.147668436169624, 83.0294206738472, 61.06773532927036, 67.2960913181305, 53.875599056482315, 59.791209027171135, 64.81497645378113, 74.57662984728813, 73.34292724728584, 71.81768909096718, 57.05556482076645, 55.97858861088753, 56.16521939635277, 57.17187277972698, 64.05051067471504, 72.53569096326828, 73.4838616847992, 73.31110015511513, 64.5691904425621, 65.10442972183228, 66.61107167601585, 70.94248205423355, 75.55432498455048, 75.91529041528702, 73.78194808959961, 69.9663220345974, 68.1009641289711, 66.70894682407379, 74.4987416267395, 78.45702722668648, 75.29938146471977, 60.56897409260273, 68.90503898262978, 82.97610953450203, 78.05197656154633, 77.39384427666664, 73.21842312812805, 26.75553470849991, 0.9673921088688076, 0.4151096456917003, 0.5249120271764696, 1.9210604229010642, 1.499779641162604, 0.7518316351342946, 0.3367865562904626, 0.2302327926736325, 0.07248595691635273, 0.49496524035930634, 0.038755946152377874, 0.28801246255170554, 14.240241274237633, 35.92176765203476, 31.145146563649178, 42.36737318336964, 33.29523839056492, 20.724095553159714, 52.01969884335995, 79.61804732680321, 71.17949053645134, 77.93922141194344, 80.2141061425209, 21.449465230107307, 0.3610112360911444, 0.053934899624437094, 0.07624488294823095, 0.04304604583012406, 0.03966146279708482, 0.020542668098642025, 0.04617435042746365, 0.05507500914973207, 0.09239280669135042, 0.04393780676764436, 0.13794800557661802, 0.02227156604931224, 0.05741953158576507, 0.04727870698843617, 0.02871903150662547, 0.007334636675295769, 0.09660022740717977, 0.03908701823092997, 0.0167926626818371, 0.045582539605675265, 0.05377487774239853, 0.03413018050196115, 0.047593399867764674, 0.022985154027992394, 0.04089095658855513, 0.046764517392148264, 0.1341190727544017, 0.08696119853993878, 0.19060531281866133, 0.11179785331478342, 0.09025633422425017, 0.10314236307749525, 0.09602147838450037, 0.18924262578366324, 0.141446890484076, 0.14302957977633923, 0.10940760344965383, 0.16807428823085502, 0.13169787533115596, 0.12763056467520073, 0.16582660493440926, 0.10937053317320533, 0.14546639198670164, 0.19983135134680197, 0.27023766946513206, 0.09933541266946122, 0.24167675437638536, 1.621855334378779, 93.83898183703423, 123.18220809102058, 121.12386614084244, 98.77677127718925, 91.03885129094124, 97.36433386802673, 56.75428278744221, 77.9684342443943, 70.71349874138832, 55.20946428179741, 54.46861423552036, 6.308946814388037, 0.1686164122656919, 0.19958400836912915, 0.32079377851914614, 0.7979799807071686, 1.4044428756460547, 2.7991675352677703, 6.650490537285805, 6.467768792062998, 8.561465945094824, 8.89127779752016, 1.714149888139218, 36.271793469786644, 92.58602187037468, 94.48480278253555, 84.19403538107872, 92.5850947201252, 83.03110018372536, 87.0315483212471, 85.67210286855698, 76.84819355607033, 61.766289845108986, 77.82160252332687, 83.70032027363777, 80.42390808463097, 81.52930676937103, 80.39015829563141, 72.62461379170418, 76.67327374219894, 78.3591976761818, 76.52133509516716, 74.17036324739456, 75.68261370062828, 78.98438572883606, 77.559484988451, 74.19368639588356, 77.23715588450432, 75.91086745262146, 75.09369850158691, 79.09018725156784, 79.49340641498566, 82.72361308336258, 70.86274713277817, 60.332740768790245, 61.049412712454796, 61.422518491744995, 70.60538694262505, 83.13235715031624, 79.21941071748734, 78.88407871127129, 71.91420391201973, 77.41025939583778, 73.9064522087574, 82.5252029299736, 45.003531128168106, 56.51741109788418, 86.60832703113556, 64.19777557253838, 70.71243479847908, 56.213564202189445, 63.256657272577286, 68.60542505979538, 78.96408721804619, 75.42687222361565, 73.5092443227768, 60.67456662654877, 59.3880582600832, 58.800267800688744, 59.59781840443611, 66.32416427135468, 77.61262133717537, 77.67021864652634, 74.95758220553398, 66.015734821558, 65.59348627924919, 67.19984248280525, 73.72451797127724, 78.20500954985619, 79.55069974064827, 76.45241439342499, 71.59667775034904, 68.61379221081734, 69.28370386362076, 76.20945543050766, 82.91878581047058, 77.3346358537674, 63.970798552036285, 74.32267427444458, 86.5126633644104, 79.8222179710865, 80.42095184326172, 75.28588458895683, 26.43345259130001, 1.0242769564501941, 6.716752331703901, 5.137904277071357, 4.9721709452569485, 1.5244128881022334, 0.7266722351778299, 0.2354559686500579, 0.5974831455387175, 0.3596895304508507, 0.4626556334551424, 0.15047743247123435, 0.3853534423978999, 19.89993117749691, 60.105265974998474, 43.53898711502552, 66.26747891306877, 55.59435322880745, 18.60947672277689, 59.408447965979576, 86.91677168011665, 83.85808020830154, 88.2392755150795, 90.86641654372215, 22.147001400589943, 0.38188737526070327, 0.250237591098994, 0.16202263796003535, 0.20231077767675743, 0.1897953328443691, 0.09622129422496073, 0.15154624386923388, 0.22747556562535465, 0.15210043522529304, 0.1780133377178572, 0.2517151180654764, 0.13365646242164075, 0.07680314127355814, 0.12193672606372274, 0.12015923784929328, 0.15282717591617256, 0.14980762935010716, 0.16570061794482172, 0.12193231770652346, 0.13982544624013826, 0.11130940882139839, 0.12496472569182515, 0.18491388618713245, 0.12809424370061606, 0.1625833156867884, 0.1313432920142077], [0.03292163753940258, 0.06249921701964922, 0.05300154130964074, 0.04847354248340707, 0.04857987369177863, 0.02676797164895106, 0.02828122003847966, 0.014299386020866223, 0.03871779976179823, 0.04080413273186423, 0.039639246606384404, 0.1071689446689561, 0.05258190503809601, 0.018937597487820312, 0.007213905018943478, 0.04182173222943675, 0.10198544390732422, 0.132437470019795, 0.10079435625812039, 0.10402453175629489, 0.7327758951578289, 7.393940119072795, 97.1763351559639, 87.03119114041328, 83.09052139520645, 61.059463173151016, 48.96044120192528, 64.34181064367294, 57.236609905958176, 56.885816529393196, 43.43784034252167, 40.94099812209606, 11.436261534690857, 0.3166660125134513, 0.02078807036014041, 0.07370988460024819, 0.07070328851114027, 0.4727594990981743, 0.3141245129518211, 1.2599863833747804, 2.6205308083444834, 1.8163980077952147, 0.9694236936047673, 0.37311729742214084, 53.651616275310516, 92.6387782394886, 84.41049456596375, 75.61876952648163, 82.91630834341049, 77.57713124155998, 78.03947523236275, 80.34717500209808, 78.27864959836006, 62.82483324408531, 56.73426166176796, 68.35862070322037, 76.51869803667068, 71.13000959157944, 76.96214944124222, 72.1722936630249, 74.33187738060951, 73.80571961402893, 71.09503626823425, 64.52526479959488, 61.29565469920635, 62.19140723347664, 66.99808090925217, 70.32032623887062, 71.90945416688919, 64.63061034679413, 64.01992991566658, 63.38215313851833, 73.03167074918747, 72.10288658738136, 70.42785286903381, 55.75154319405556, 54.05813366174698, 50.35818099975586, 55.13355195522308, 67.84428790211678, 73.15816596150398, 70.54382264614105, 71.64973050355911, 68.25794890522957, 76.0163801908493, 63.68829511106014, 76.0943292081356, 42.93519951403141, 47.40136206150055, 74.71301212906837, 54.22574266791344, 56.785118132829666, 50.87677717208862, 56.983007714152336, 60.532963424921036, 68.50013270974159, 67.97641441226006, 68.81103202700615, 52.868512496352196, 54.68230336904526, 52.41306513547897, 57.847955301404, 61.81597977876663, 70.48765406012535, 71.70716062188148, 67.24846467375755, 64.467743486166, 69.55963745713234, 67.90755450725555, 70.40686279535294, 69.5650863647461, 68.6366517841816, 65.92380255460739, 65.91747969388962, 71.29154652357101, 74.76725801825523, 72.5001172721386, 73.74051511287689, 72.5778079032898, 62.45173506438732, 59.88937295973301, 74.75623860955238, 75.00155344605446, 75.83532750606537, 75.2686259150505, 81.27174139022827, 42.15320147573948, 1.3272830285131931, 1.158637865446508, 1.0067363851703703, 1.8100170814432204, 0.04803151561645791, 0.07392512226942927, 0.09484185691690072, 0.35822102800011635, 0.11400174247683026, 0.041368194652022794, 0.1405173950479366, 0.19456011388683692, 30.780468732118607, 44.30771626532078, 41.8989647179842, 60.18549866974354, 29.13662564009428, 36.180898547172546, 52.37996891140938, 64.07929793000221, 67.75948405265808, 68.6186483502388, 62.74977207183838, 5.157522624358535, 0.2257745186216198, 0.04044176428578794, 0.024998806620715186, 0.04052471413160674, 0.052223154561943375, 0.1034491223981604, 0.03693458216730505, 0.03395312262000516, 0.032747681834734976, 0.026352669519837946, 0.0719332869630307, 0.020800117272301577, 0.07200506748631597, 0.01730325286189327, 0.020089180616196245, 0.023200267387437634, 0.04013764330011327, 0.008349489762622397, 0.021716593582823407, 0.017223412614839617, 0.028685081961157266, 0.06675285127130337, 0.04534603198408149, 0.04157398107054178, 0.02120092340192059, 0.027996090611850377, 0.02040626321104355, 0.06866076451842673, 0.05138499524036888, 0.03503466556139756, 0.06195220223162323, 0.026414043277327437, 0.08903150854166597, 0.05560560763115063, 0.0400125246233074, 0.025123285195149947, 0.03399829343834426, 0.040472971595590934, 0.04772403270180803, 0.052200170248397626, 0.0867150875274092, 0.08191576693207026, 0.13290616596350446, 0.1148269661644008, 0.16413354343967512, 0.5566581361927092, 9.99753238633275, 119.12249833345413, 97.06104934215546, 95.20295664668083, 71.46776586771011, 71.53338074684143, 86.54506042599678, 57.731723338365555, 60.28216168284416, 47.42596574127674, 49.09814581274986, 14.021771047264338, 0.21813900646520779, 0.04589420081174467, 0.27289268793538213, 0.048045453149825335, 0.6523631257005036, 0.8376861875876784, 1.4748425292782485, 2.4491132190451026, 0.9938104287721217, 0.9705457021482289, 0.5890731874387711, 54.27298553287983, 95.57630181312561, 89.25640493631363, 80.80125823616982, 85.58042138814926, 80.49633979797363, 79.94474619626999, 83.9654016494751, 81.21658354997635, 65.54852709174156, 60.101021602749825, 74.10390481352806, 81.39680027961731, 75.16967162489891, 77.36998915672302, 72.14847654104233, 74.78694096207619, 75.423064827919, 74.54145893454552, 68.30407083034515, 66.11604183912277, 64.83805641531944, 69.81622248888016, 73.09916272759438, 75.30540034174919, 69.05937150120735, 66.68586686253548, 66.54160380363464, 73.35801243782043, 75.08491337299347, 72.6762530207634, 58.69970999658108, 56.81305803358555, 53.91990087926388, 57.941764667630196, 70.59596344828606, 75.94166100025177, 73.0002312362194, 73.72301325201988, 69.74714979529381, 76.08756557106972, 65.51119789481163, 77.30605378746986, 46.30061812698841, 49.81462016701698, 76.72470018267632, 56.85154236853123, 59.68521751463413, 52.090922221541405, 59.807213768363, 63.422928750514984, 70.59395715594292, 70.78083872795105, 72.110805362463, 54.944462701678276, 55.74215769767761, 54.74606774747372, 59.047379940748215, 65.95936864614487, 74.84212160110474, 73.54876980185509, 66.9503402709961, 65.79351514577866, 71.74869239330292, 70.46749234199524, 72.21076279878616, 71.29422158002853, 70.70630192756653, 65.73565185070038, 67.35194072127342, 73.76124680042267, 76.7162798345089, 73.93351435661316, 76.32912620902061, 74.83585193753242, 64.13976788520813, 62.258032858371735, 79.30705681443214, 77.45972514152527, 77.16921553015709, 79.32100966572762, 84.74430665373802, 49.1676364839077, 2.2482586093246937, 0.9956257219891995, 0.8734184608329087, 1.6031299391761422, 1.879848309326917, 0.9350773366168141, 0.1396831765305251, 0.48945241898763925, 0.38765703910030425, 0.0487347821763251, 0.11143983385409229, 0.16726542147807777, 32.66226455569267, 34.3576879799366, 38.16854149103165, 42.91806623339653, 30.247159749269485, 49.86552223563194, 58.4783148765564, 72.62195393443108, 75.71254849433899, 76.68576747179031, 77.55078345537186, 8.485925998538733, 0.15842095075640827, 0.14181759324856102, 0.03982000780524686, 0.0871614225616213, 0.010121688319486566, 0.07793870885507204, 0.03200679209840018, 0.03342377094668336, 0.09465614188229665, 0.036901627099723555, 0.06732496549375355, 0.027219637158850674, 0.05025057056627702, 0.04966514592524618, 0.014504015616694232, 0.03349247155711055, 0.06757772614946589, 0.015771144644531887, 0.028738421970047057, 0.017296341611654498, 0.04624947061529383, 0.03480117848084774, 0.07944771030452102, 0.07265640597324818, 0.03330866384203546, 0.15790493547683582, 0.16230702894972637, 0.19553171878214926, 0.17868933035060763, 0.11458002394647337, 0.13993653090437874, 0.13929202017607167, 0.16071619087597355, 0.16496345750056207, 0.07813544478267431, 0.11716921391780488, 0.1224529862520285, 0.2510216849623248, 0.2853640343528241, 0.11441056194598787, 0.13019222096772864, 0.25648338720202446, 0.3364265849813819, 0.21101695660036057, 0.28076414368115366, 1.0469719511456788, 13.629406001418829, 133.87260764837265, 110.1650869846344, 107.8030577301979, 82.65387162566185, 68.64290624856949, 74.09805312752724, 72.93635666370392, 70.75550928711891, 62.43617869913578, 69.18629989027977, 19.420790188014507, 0.45855402073357254, 0.22248101566219702, 0.25306817202363163, 0.2225695241941139, 0.859864647500217, 0.851458489196375, 3.888120702467859, 7.637688014656305, 5.8098397962749, 6.233192654326558, 1.696719154715538, 62.550567761063576, 99.13873985409737, 91.29704743623734, 84.63621005415916, 88.46776485443115, 83.10502901673317, 82.15109780430794, 86.78422719240189, 84.8218984901905, 69.4405822455883, 65.30424579977989, 75.99405258893967, 83.75535652041435, 76.44559755921364, 81.01055100560188, 71.71450182795525, 76.31023362278938, 78.15104484558105, 78.29485952854156, 72.90149733424187, 69.13866564631462, 68.86155411601067, 72.25558519363403, 78.35009336471558, 79.85585376620293, 74.3408752977848, 70.67379847168922, 71.11626952886581, 76.07035249471664, 78.34083706140518, 76.05503171682358, 61.43242076039314, 60.28009079396725, 56.85858339071274, 61.39137156307697, 74.31310638785362, 79.47782725095749, 76.9873420894146, 77.31375977396965, 73.77200022339821, 79.32385951280594, 68.02736207842827, 78.24306070804596, 48.38853769004345, 53.8403407484293, 79.31347087025642, 61.75528563559055, 63.21359418332577, 55.12527979910374, 61.78908862173557, 67.04386085271835, 74.3354719877243, 75.17765879631042, 76.48557901382446, 57.9399673640728, 59.66445542871952, 57.96120062470436, 62.72579535841942, 68.4774099290371, 77.8362013399601, 79.27621006965637, 68.47610279917717, 66.86591640114784, 74.08100724220276, 72.79531583189964, 75.698322057724, 75.5669479072094, 72.74801596999168, 67.10998490452766, 67.20703929662704, 75.50414487719536, 81.40498504042625, 77.93762549757957, 78.72959420084953, 79.0018267929554, 67.21691116690636, 65.67670181393623, 81.11419424414635, 80.25737822055817, 80.15910029411316, 81.8382377922535, 88.26116234064102, 49.890847876667976, 1.8779818969778717, 4.429868320003152, 5.50763251259923, 4.423601981252432, 2.9309321148321033, 0.8920520078390837, 0.298971994780004, 0.7769500091671944, 0.5112593004014343, 0.13407865539193153, 0.4536838101921603, 0.45612348709255457, 51.08996093273163, 61.04311265051365, 60.75954906642437, 83.00236612558365, 41.912457793951035, 54.00457173585892, 68.15028548240662, 82.99680322408676, 86.1805459856987, 87.78938725590706, 86.03496059775352, 8.313055224716663, 0.27649908035527915, 0.1957332415622659, 0.08060511929215863, 0.15519015927566215, 0.12319151966948994, 0.18121922272257507, 0.10472361260326579, 0.10783908175653778, 0.13645855971844867, 0.11228493967792019, 0.1647096429951489, 0.10799505151226185, 0.183199955499731, 0.07343851830228232, 0.10980388804455288, 0.09460422865231521, 0.18456947029335424, 0.20635166787542403, 0.1544209528947249, 0.09451241014176048, 0.19501276459777728, 0.18342544964980334, 0.134083820739761, 0.16630012483801693, 0.1239587964664679], [0.018620722694322467, 0.029583217947219964, 0.027088356800959446, 0.008182860910892487, 0.04338198639743496, 0.045036671435809694, 0.017507024349470157, 0.06306173527264036, 0.0280671735163196, 0.08696087941643782, 0.04539185589237604, 0.019485979682940524, 0.02095434298098553, 0.07289416040293872, 0.034303642678423785, 0.006391039969457779, 0.024743138601479586, 0.05043194774771109, 0.01910792965645669, 0.0897854489448946, 0.09134913183515891, 36.95311211049557, 99.43934172391891, 85.46548515558243, 71.18413388729095, 45.2775002270937, 28.70198216289282, 20.28302662074566, 40.362228378653526, 52.59052701294422, 50.16126036643982, 21.98418203741312, 0.21234940853901207, 0.08515727502526715, 0.11934790716622956, 0.1683550130110234, 0.28294338611885905, 0.1706891119829379, 0.7780917885247618, 1.076703811995685, 1.0570762027055025, 2.496475540101528, 0.7812603435013443, 66.83462888002396, 100.31513392925262, 78.96661788225174, 81.23028561472893, 75.27833059430122, 74.02132764458656, 81.77304089069366, 84.53832730650902, 77.71797448396683, 76.68834373354912, 63.205926194787025, 55.794211104512215, 68.75273555517197, 74.23125877976418, 74.6407400071621, 79.71200868487358, 68.87496739625931, 73.61671015620232, 67.82728001475334, 68.60882207751274, 61.69944003224373, 57.07272469997406, 55.17874293029308, 58.40728908777237, 62.36275903880596, 60.52730552852154, 59.66759406030178, 53.93480367958546, 54.3347854167223, 59.64763753116131, 60.93784309923649, 54.71560098230839, 52.107713520526886, 53.74354474246502, 49.312758296728134, 54.20756444334984, 61.91863887012005, 70.51182836294174, 68.49286749958992, 73.61385270953178, 68.5697753727436, 72.81267330050468, 66.3645789027214, 74.79993626475334, 41.621477007865906, 48.298349529504776, 74.07185733318329, 57.69693240523338, 58.67405377328396, 49.45975340902805, 56.67507603764534, 58.16091030836105, 64.60395097732544, 64.07343864440918, 66.19867980480194, 52.59716905653477, 53.61937880516052, 52.530288845300674, 58.755798786878586, 61.71972334384918, 65.8844518661499, 62.252458557486534, 68.0959104001522, 64.42382544279099, 66.71897068619728, 64.02508243918419, 68.7590280175209, 68.27766224741936, 73.35340708494186, 68.68940055370331, 66.63333088159561, 69.76209819316864, 69.98963758349419, 70.72054356336594, 71.10019639134407, 65.03684654831886, 61.43369749188423, 55.42716979980469, 68.35810393095016, 70.30517265200615, 75.53480163216591, 74.02312874794006, 71.93298250436783, 78.63344416022301, 66.4982557296753, 5.144372479990125, 1.9231162313371897, 2.634517620317638, 0.6698027055244893, 0.4721699666697532, 0.028115633904235438, 0.44776138267479837, 0.9435810428112745, 0.03478037237073295, 0.10208255393081345, 0.035103329064440913, 3.527530264109373, 34.44403454661369, 39.1313262283802, 45.07623262703419, 35.67850850522518, 12.231556009501219, 25.844554491341114, 48.53927560150623, 61.03514067828655, 66.28520876169205, 75.28836205601692, 47.278655245900154, 1.3427763408981264, 0.03411466590478085, 0.011098965078417677, 0.016135728401422966, 0.09185946968500502, 0.02734158500970807, 0.009730715646583121, 0.021454878915392328, 0.08433059672825038, 0.030442020106420387, 0.024061685617198236, 0.02191910898545757, 0.05086519129690714, 0.01957280168426223, 0.016510833956999704, 0.03498096004477702, 0.0448207064619055, 0.011613292899710359, 0.04597929917508736, 0.020272153415135108, 0.062076556496322155, 0.044880222994834185, 0.03505644759570714, 0.009158715529338224, 0.02950494734250242, 0.0336411645548651, 0.005193117140152026, 0.053898946280241944, 0.015401401105918922, 0.05279923185298685, 0.03579478805477265, 0.046348361793207005, 0.06366693443851545, 0.028319221710262354, 0.01822460693801986, 0.06407734210370108, 0.05624738354526926, 0.0794893447891809, 0.0869778152264189, 0.07080609080730937, 0.06384528736816719, 0.04392169103084598, 0.021737203023803886, 0.03681807982502505, 0.04892411147011444, 0.17172287916764617, 46.77770532667637, 112.8161059319973, 92.13209822773933, 82.65948012471199, 53.03430140018463, 35.884119272232056, 25.269390754401684, 40.248717069625854, 42.356368973851204, 46.23131364583969, 28.4116093441844, 0.24456681101582944, 0.062147004864527844, 0.021692488626285922, 0.5505937803536654, 0.7059245766140521, 1.0463724145665765, 2.345292577520013, 1.4169609476812184, 1.0687001352198422, 0.6236237240955234, 1.2363127036951482, 72.12570816278458, 106.00399106740952, 82.87341624498367, 87.44021639227867, 78.875080794096, 78.09125125408173, 86.631338596344, 86.42075389623642, 79.97866317629814, 78.85938763618469, 67.13510155677795, 58.00276659429073, 70.52949741482735, 78.58166053891182, 78.64431157708168, 79.4742326438427, 69.54509943723679, 75.85021510720253, 72.43521675467491, 70.95005884766579, 66.20401471853256, 58.60393613576889, 58.61103415489197, 60.882590264081955, 63.64829085767269, 64.27836164832115, 62.365247905254364, 57.65499785542488, 56.85438461601734, 63.021001517772675, 63.54929856956005, 58.337749019265175, 54.042360708117485, 54.56774331629276, 53.052510023117065, 56.8783575296402, 65.13801231980324, 74.28412154316902, 72.60663315653801, 75.07031455636024, 71.37280136346817, 75.89948326349258, 70.40652841329575, 78.41491028666496, 45.60517944395542, 50.225442722439766, 78.97668734192848, 61.117292270064354, 60.823636427521706, 51.748085618019104, 59.11489851772785, 60.22540792822838, 67.84595221281052, 68.58127355575562, 70.37143349647522, 55.854536667466164, 56.336077228188515, 54.49990935623646, 60.381868332624435, 65.72912380099297, 69.70122545957565, 66.729876101017, 71.39370784163475, 66.37206450104713, 69.62253928184509, 65.44393390417099, 69.80087891221046, 72.22534641623497, 75.88177621364594, 68.01055178046227, 69.58726957440376, 72.82368510961533, 71.29891812801361, 74.22215446829796, 72.63447046279907, 67.76217430830002, 63.00305888056755, 57.8415222465992, 73.08920726180077, 71.83975830674171, 78.24226275086403, 78.23302924633026, 75.70275261998177, 82.00607478618622, 74.4460080564022, 6.9199226796627045, 0.9754008322488517, 0.5616253009065986, 1.4125898759812117, 1.5677159582264721, 0.28822275751736015, 0.9633868862874806, 0.6735786341596395, 0.6580448895692825, 0.13147797697456554, 0.11503064117277972, 3.790871570818126, 34.34454068541527, 41.77344225347042, 43.829580321908, 29.38728678971529, 20.628790967166424, 37.37267039716244, 56.26618377864361, 67.9641942679882, 75.97680151462555, 82.90034160017967, 61.185681000351906, 1.8427336821332574, 0.13300218502990901, 0.015845274065213744, 0.0494456594606163, 0.03715437662322074, 0.01709706939436728, 0.021961921629554126, 0.09001042359159328, 0.03413700083910953, 0.10117959769559093, 0.003122199505014578, 0.0586990387091646, 0.05693158062058501, 0.044987775036133826, 0.04457816146896221, 0.026856880940613337, 0.021813356652273796, 0.04468268183700275, 0.01927915796841262, 0.036270783020881936, 0.03469039067567792, 0.08308847900480032, 0.030129499864415266, 0.02354593380005099, 0.05256926626316272, 0.18214711511973292, 0.11397864684113301, 0.1868781729717739, 0.12578551133628935, 0.2624419127823785, 0.17879510123748332, 0.22510116803459823, 0.18457644648151472, 0.10378369741374627, 0.1280752447200939, 0.2544927393319085, 0.1675266129313968, 0.21772148902527988, 0.26295013551134616, 0.13558760489104316, 0.17695206654025242, 0.11585993925109506, 0.22662651899736375, 0.13758671324467286, 0.1517792633967474, 0.3170231042895466, 61.863678619265556, 126.43115535378456, 105.86399897933006, 95.36053419113159, 63.76153618097305, 41.36508956551552, 30.842844285070896, 54.72295358777046, 74.15009513497353, 72.69681751728058, 36.287118047475815, 0.5919371056370437, 0.1668936648638919, 0.3699167410377413, 0.985486856661737, 1.1592892929911613, 1.4275155938230455, 5.094307316467166, 5.409042052924633, 4.71028994768858, 5.577648505568504, 1.6110991802997887, 79.34282049536705, 107.40589544177055, 84.9757370352745, 89.15963172912598, 83.57284471392632, 81.50384053587914, 92.07563325762749, 86.97268187999725, 82.91049465537071, 83.68578225374222, 70.28605207800865, 60.83078384399414, 73.41874077916145, 81.92649185657501, 81.12593561410904, 82.21860498189926, 71.13650724291801, 78.8350385427475, 74.86599192023277, 76.20072349905968, 68.5786896944046, 62.47330650687218, 61.800332218408585, 64.88387435674667, 68.50824147462845, 67.03374579548836, 66.25507637858391, 60.31992405653, 59.20029893517494, 67.09040075540543, 65.9665198624134, 59.08092074096203, 55.95672458410263, 57.072257325053215, 54.47268381714821, 60.024197325110435, 69.65073376893997, 79.59932953119278, 76.85285970568657, 82.03233137726784, 74.15852308273315, 79.1281396150589, 73.83530482649803, 80.45751348137856, 48.15440185368061, 56.17859087884426, 81.80881217122078, 64.15253520011902, 63.33473168313503, 55.14165312051773, 62.293929532170296, 63.43874350190163, 69.97699186205864, 72.55888491868973, 72.60107025504112, 58.09444047510624, 59.08811755478382, 57.222014889121056, 64.8021787405014, 66.42740473151207, 71.59656375646591, 69.41128581762314, 74.2597496509552, 68.5099133849144, 73.2042270898819, 69.53294768929482, 74.23757404088974, 75.55778279900551, 78.49145337939262, 70.80195799469948, 70.54275870323181, 77.34901428222656, 74.01159256696701, 78.05465161800385, 76.29194900393486, 71.57374978065491, 67.07505717873573, 62.447331100702286, 75.67043915390968, 76.2323834002018, 80.84878608584404, 79.5605032145977, 77.430170327425, 83.75971108675003, 75.86372718214989, 5.67545335739851, 4.554107403382659, 8.460789397358894, 4.052072167396545, 3.078202474862337, 0.11924288584850729, 1.725613041780889, 2.3339148005470634, 0.6310877110809088, 0.27053607220295817, 0.36082940991036594, 5.973635707050562, 55.967310816049576, 55.72402127087116, 63.07623915374279, 48.715719133615494, 21.160866916179657, 41.704947128891945, 66.50273948907852, 78.22622001171112, 84.08096864819527, 95.78987315297127, 65.75322970747948, 1.9061570288613439, 0.18561456265160814, 0.11511779899592511, 0.16419773921370506, 0.19610943621955812, 0.10095997393364087, 0.09438107968890108, 0.14021808688994497, 0.14318241766886786, 0.14248447230784222, 0.07726804484263994, 0.09812405696720816, 0.13986662059323862, 0.19442893186351284, 0.07333236149861477, 0.11459335291874595, 0.2083668956765905, 0.13253371173050255, 0.1815395336598158, 0.14550674997735769, 0.23715947958407924, 0.2100258629070595, 0.148095850890968, 0.08352015662239864, 0.16988814168144017], [0.0993696108344011, 0.05992849910398945, 0.0471894859947497, 0.010956786281894892, 0.0193994267101516, 0.0328904710477218, 0.06375913144438528, 0.029671950978809036, 0.05526571512746159, 0.04502014009631239, 0.03178259670676198, 0.07446971765602939, 0.06759380106814206, 0.07789878873154521, 0.10714529242250137, 0.0398636869067559, 0.06826747077866457, 0.027425284424680285, 0.0835888423898723, 0.14864705881336704, 2.9967968305572867, 74.63496431708336, 91.12864047288895, 83.97674024105072, 61.7486397922039, 29.220718927681446, 94.52084764838219, 98.16656202077866, 57.43800289928913, 61.44329957664013, 41.37732870876789, 6.132750269025564, 0.17567011032951996, 0.18746353453025222, 0.2543986350065097, 0.2511097927344963, 0.46299399342387915, 1.5127786248922348, 1.959608404431492, 0.42887675226666033, 0.9091332193929702, 2.2404531156644225, 71.88277199864388, 94.31750535964966, 76.69061601161957, 83.7591715157032, 75.24310648441315, 70.84478169679642, 70.38536354899406, 78.28919783234596, 77.03078895807266, 79.269028455019, 76.33610263466835, 59.59635928273201, 52.660933434963226, 61.89823396503925, 70.28132513165474, 73.68336617946625, 73.09458777308464, 70.77504023909569, 72.34746426343918, 68.3568499982357, 62.616836205124855, 56.89862564206123, 54.08894240856171, 52.958997040987015, 53.323914259672165, 52.54579961299896, 52.54450008273125, 52.148101553320885, 53.039149940013885, 51.72030530869961, 51.17136016488075, 51.20408780872822, 51.00443512201309, 48.82277078926563, 51.823496371507645, 50.15161268413067, 51.334565207362175, 52.20935046672821, 62.51855827867985, 61.718902587890625, 64.51790079474449, 61.22558645904064, 66.5042670071125, 62.475464791059494, 74.98003900051117, 48.77529613673687, 40.799391120672226, 75.97837463021278, 62.15049862861633, 65.24985551834106, 51.780817061662674, 56.697084456682205, 57.82549470663071, 64.74042445421219, 60.11722393333912, 61.84473663568497, 52.95180782675743, 52.913916260004044, 50.189204066991806, 54.65208739042282, 63.412809893488884, 71.11050143837929, 65.6230790913105, 61.00178986787796, 65.60921743512154, 66.87594026327133, 64.90043386816978, 61.72302156686783, 63.52046951651573, 67.1229650080204, 70.92704728245735, 70.77152162790298, 71.11175537109375, 70.40782034397125, 65.78133299946785, 60.638445764780045, 61.371650621294975, 56.43044896423817, 54.674361795187, 55.73366895318031, 65.9346091747284, 67.75629222393036, 71.19991064071655, 75.12699991464615, 71.44676059484482, 77.17868462204933, 76.8867538869381, 8.247807025909424, 1.2488756608217955, 0.6619057792704552, 0.5892387160565704, 0.04279921864508651, 0.1040240864676889, 0.7799169374629855, 0.9199306962545961, 0.1973840154823847, 0.05178126499231439, 0.09125307566137053, 15.546083003282547, 27.055070735514164, 36.36502526700497, 48.249100372195244, 31.868914626538754, 19.79804914444685, 44.95146632194519, 65.50745889544487, 63.79334807395935, 63.180714547634125, 76.07373431324959, 15.286100953817368, 0.46578247973229736, 0.13755622581811622, 0.14854790788376704, 0.035087792202830315, 0.12126847403123975, 0.01635353204619605, 0.08430340443737805, 0.05493474323884584, 0.06704860454192385, 0.03778949918341823, 0.05708138312911615, 0.026397938672744203, 0.04993496113456786, 0.05380667877034284, 0.03988187323557213, 0.05021344462875277, 0.03922338044503704, 0.07280867241206579, 0.05970917220111005, 0.05178619656362571, 0.04309208125050645, 0.07689153848332353, 0.003880920035044255, 0.05670240912877489, 0.032592001516604796, 0.0374867845675908, 0.08177276991773397, 0.04200478295388166, 0.031350666758953594, 0.042026490773423575, 0.06353645003400743, 0.07360665185842663, 0.05419504093879368, 0.057212836036342196, 0.03360650996910408, 0.05421284135081805, 0.0638402184995357, 0.018060143302136566, 0.0795306007785257, 0.09624735845136456, 0.023782916396157816, 0.04450204309250694, 0.10790957094286568, 0.1535413891542703, 4.546721074730158, 91.07427299022675, 101.53581842780113, 93.89367610216141, 68.2101322710514, 43.57205294072628, 75.42282164096832, 80.70826962590218, 47.53717057406902, 44.865324944257736, 51.806784868240356, 6.85555555857718, 0.15899065299890935, 0.13358065945794806, 0.5659104022197425, 1.0749525809660554, 1.132297560106963, 2.739969086833298, 1.97045361623168, 0.33835423935670406, 0.8449610753450543, 2.3416986828669906, 77.74613857269287, 98.70110213756561, 81.24739989638329, 88.47455129027367, 78.92727479338646, 75.62573075294495, 75.84595933556557, 81.1333680152893, 79.64318677783012, 82.01474592089653, 80.61518222093582, 62.400251626968384, 54.96805563569069, 64.72410053014755, 73.01739111542702, 75.78283712267876, 74.35753360390663, 72.59602412581444, 76.0725411772728, 72.79632657766342, 65.78244253993034, 61.35408416390419, 57.82381899654865, 55.38328975439072, 56.7491340637207, 55.64272083342075, 55.58293864130974, 55.64557068049908, 54.93629693984985, 54.48206551373005, 53.81031095981598, 51.872984915971756, 52.577212527394295, 53.48325490951538, 53.51189397275448, 52.63263635337353, 52.717356607317924, 55.41615039110184, 62.80649922788143, 64.44582626223564, 67.01112180948257, 64.78046670556068, 69.67559203505516, 64.82349559664726, 75.6863223016262, 52.51929223537445, 43.26051525771618, 79.2296701669693, 66.33302539587021, 68.68055462837219, 54.639460667967796, 59.15484197437763, 60.90177543461323, 66.36862948536873, 63.960455507040024, 64.52454283833504, 54.53400872647762, 54.908573627471924, 52.42052413523197, 57.32166454195976, 66.20871126651764, 72.2995488345623, 70.33015251159668, 66.27383217215538, 70.30179843306541, 70.91955408453941, 66.25348046422005, 64.97606500983238, 66.15386500954628, 70.19134595990181, 71.6041861474514, 72.55161210894585, 75.79815790057182, 71.77868038415909, 67.53282621502876, 63.0131321400404, 64.25183147192001, 61.43481843173504, 58.32952246069908, 59.032279551029205, 68.30397963523865, 69.80515748262405, 75.13165086507797, 77.44266405701637, 74.82312262058258, 79.53899636864662, 83.92799645662308, 12.677252143621445, 1.3362365355715156, 1.0112032829783857, 2.4107599770650268, 1.4808966731652617, 0.484848105115816, 1.1930196080356836, 0.972446728264913, 0.6575855892151594, 0.025471506451140158, 0.07217137535917573, 19.16698470711708, 32.99522928893566, 40.786202028393745, 36.0446834564209, 35.582092478871346, 32.9145672172308, 59.03229475021362, 77.2090145945549, 73.35239633917809, 70.84522247314453, 89.22544419765472, 21.465393975377083, 0.41970413352828473, 0.11060719611123204, 0.08364287816220894, 0.05692280101357028, 0.05097711087728385, 0.0688937988888938, 0.038575318540097214, 0.04765842684719246, 0.03253342380048707, 0.039328093771473505, 0.01291090286031249, 0.07513018455938436, 0.05836843789438717, 0.014709650822624099, 0.01989732245419873, 0.024786088542896323, 0.05515667508007027, 0.0448170773597667, 0.038925753251533024, 0.05351433195755817, 0.03611203392210882, 0.0911267101764679, 0.009785897109395592, 0.03288099753262941, 0.1275787627673708, 0.2627253538230434, 0.1593077727011405, 0.18254238297231495, 0.08109809830784798, 0.18867706472519785, 0.18194156989920884, 0.273779584094882, 0.1742024242412299, 0.14059028879273683, 0.14444706699578092, 0.19141005323035643, 0.25034653837792575, 0.1831293327268213, 0.2944208780536428, 0.2611868816893548, 0.19751893792999908, 0.16555888258153573, 0.18739950202871114, 0.42477804876398295, 7.495619812980294, 109.82249736785889, 113.1749814748764, 107.56074473261833, 84.31422293186188, 46.8545676022768, 108.60796093940735, 114.08295035362244, 77.90475726127625, 86.41461342573166, 63.37219387292862, 11.033720634877682, 0.3884633380221203, 0.36737930844537914, 1.0482410830445588, 1.9053766457363963, 1.8489946774207056, 3.361033648252487, 6.085297940298915, 3.4886462381109595, 4.223155612125993, 2.718853857368231, 83.46156388521194, 101.56260699033737, 83.22077840566635, 93.61989319324493, 81.51517152786255, 79.52756658196449, 77.71336153149605, 82.35001713037491, 78.77494856715202, 85.47186121344566, 84.15264800190926, 65.64566507935524, 58.87390784919262, 68.55763882398605, 76.47142857313156, 80.06933391094208, 75.43182715773582, 73.71344536542892, 79.81657147407532, 76.05832993984222, 67.09391936659813, 66.12031280994415, 59.05817896127701, 59.98396888375282, 61.25775933265686, 59.57979217171669, 59.31528456509113, 58.12159761786461, 58.24706308543682, 57.663380205631256, 55.9470921009779, 55.79988420009613, 55.605034455657005, 55.90600110590458, 55.93462876975536, 54.7565171867609, 56.068788170814514, 57.6392363011837, 67.39503800868988, 68.12922701239586, 69.93384137749672, 68.0563697218895, 73.05994123220444, 69.50432002544403, 79.65732961893082, 57.5430216640234, 47.92756922543049, 81.11382186412811, 68.08661609888077, 71.18416428565979, 56.92601077258587, 62.58956506848335, 65.15448063611984, 68.61870154738426, 65.79634219408035, 68.81285592913628, 57.264101430773735, 57.54084438085556, 54.69970263540745, 60.07226474583149, 69.66755166649818, 76.27232685685158, 73.76433223485947, 69.32663396000862, 72.98981979489326, 74.72954884171486, 70.84250181913376, 67.82843515276909, 68.996811658144, 73.47564652562141, 74.8125971853733, 75.81832721829414, 78.58578711748123, 75.85630238056183, 71.18561580777168, 65.79582542181015, 68.15087825059891, 63.804815858602524, 61.87613435089588, 62.086392268538475, 73.9757376909256, 73.8495160639286, 78.13779875636101, 82.0293827354908, 79.83132228255272, 82.46832758188248, 88.19170206785202, 11.330397315323353, 4.4473241083323956, 6.20350674726069, 5.080423336476088, 1.6736941714771092, 0.4302995384205133, 2.165088909678161, 3.6608047876507044, 1.1475107562728226, 0.2155467143165879, 0.19505313743138686, 25.93802947551012, 44.43346671760082, 53.57164956629276, 63.687352761626244, 46.764831617474556, 32.192818745970726, 63.58507364988327, 79.93976846337318, 83.66408541798592, 81.46360069513321, 98.46233054995537, 23.644615039229393, 0.7772917533293366, 0.20525374944554642, 0.24080818926449865, 0.129311069031246, 0.25562816590536386, 0.1671705601620488, 0.12769780325470492, 0.22261682868702337, 0.1410842326004058, 0.11522423039423302, 0.18827789317583665, 0.13252241624286398, 0.16507299849763513, 0.15206991811282933, 0.20081771013792604, 0.14842483011307195, 0.13355456554563716, 0.16156712255906314, 0.09835921388003044, 0.17945497442269698, 0.17858348524896428, 0.14817937219049782, 0.15012237417977303, 0.09619592019589618], [0.028586919943336397, 0.024922170596255455, 0.05585067221545614, 0.01146073052950669, 0.14612154511269182, 0.10986748267896473, 0.06125342937593814, 0.01814373510569567, 0.012278262784093386, 0.044550375459948555, 0.025510832856525667, 0.06223444841452874, 0.010462774753250415, 0.07825291191693395, 0.05490199968335219, 0.03490233691991307, 0.13282963569508865, 0.2087491611018777, 0.1272250254987739, 0.2576410782057792, 20.66549889743328, 87.47367739677429, 93.88497456908226, 76.68413355946541, 69.12099659442902, 46.26208059489727, 87.58751928806305, 61.36998251080513, 51.51763178408146, 49.41052705049515, 15.57364672422409, 0.21704125130781904, 0.11051925903302617, 0.11421602277550846, 0.17680222692433745, 0.5464579991530627, 0.9705684415530413, 0.3010436554905027, 1.0537526872940361, 0.5337113456334919, 1.5548946149647236, 83.4268869459629, 88.18702831864357, 76.87201827764511, 82.0352952182293, 76.1692763864994, 73.51481482386589, 68.39480236172676, 69.230917096138, 78.6266577243805, 79.04911905527115, 76.78564891219139, 73.28178092837334, 57.983817011117935, 50.39305932819843, 59.11098092794418, 65.71310386061668, 73.14655378460884, 69.14037555456161, 71.98712959885597, 70.14184981584549, 65.94322711229324, 61.421842128038406, 57.008561342954636, 52.34607473015785, 52.29583762586117, 51.32337860763073, 49.29944761097431, 50.91184549033642, 49.329576194286346, 50.77881082892418, 51.145852133631706, 50.62582723796368, 49.795412197709084, 51.02823704481125, 51.7383049428463, 50.066432654857635, 48.82495567202568, 52.960634753108025, 51.23463436961174, 52.08952009677887, 51.9212157279253, 54.876210764050484, 56.752736270427704, 59.48509365320206, 55.935229137539864, 68.41141507029533, 55.50545699894428, 34.82389636337757, 71.68757647275925, 64.38350960612297, 66.59812197089195, 55.9224846214056, 56.2472227960825, 55.469666719436646, 63.54388765990734, 57.41106614470482, 60.45614294707775, 50.25916211307049, 53.78948427736759, 50.95640949904919, 51.05857081711292, 53.29203017055988, 61.695963218808174, 64.87543880939484, 68.2444216310978, 62.58556008338928, 66.36435851454735, 59.97050620615482, 58.094102293252945, 58.39914232492447, 64.18788090348244, 68.01360681653023, 72.37240612506866, 69.47723507881165, 70.06938770413399, 62.91819043457508, 55.7268825173378, 53.876902386546135, 57.06065274775028, 55.292254239320755, 56.943706423044205, 56.55535206198692, 65.3567285835743, 64.4430524110794, 67.8615465760231, 71.22506529092789, 71.3612499833107, 74.8532322049141, 75.87229192256927, 5.633619977161288, 1.0526677267625928, 2.951588756404817, 1.3866745540872216, 0.35259489552117884, 0.5364636448211968, 0.8691012987401336, 1.124143316410482, 0.11048327971366234, 0.16579022485530004, 1.4828805229626596, 27.9919408634305, 31.21231935918331, 37.496547549963, 31.13026276230812, 33.72140072286129, 29.35621775686741, 27.953570522367954, 48.74012902379036, 60.34892790019512, 73.91663566231728, 53.45224857330322, 1.17732597514987, 0.09999236179282889, 0.05427758631412871, 0.0698901766736526, 0.05974918880383484, 0.026762155066535342, 0.02795315180264879, 0.08418733996222727, 0.09359334188047796, 0.03460650572378654, 0.0188184864964569, 0.052949490782339126, 0.030643464961030986, 0.007558769448223757, 0.029148399189580232, 0.031032775223138742, 0.030622677404608112, 0.11043489168514498, 0.11331303685437888, 0.01076572871170356, 0.028459995992307086, 0.03116562707873527, 0.06889978802064434, 0.02396538453467656, 0.02042425472609466, 0.024988921213662252, 0.13104159414069727, 0.01730351817968767, 0.045142891322029755, 0.01356726939775399, 0.024828403948049527, 0.09949020983185619, 0.07997824199264869, 0.0349042776360875, 0.05112178885610774, 0.027438071629148908, 0.06589524768060073, 0.047638236719649285, 0.054479840109706856, 0.044993786432314664, 0.051359123972360976, 0.16162309533683583, 0.16404959169449285, 0.40015985257923603, 29.112206250429153, 102.48512148857117, 102.86790534853935, 86.29163682460785, 75.72485983371735, 48.29653322696686, 85.22680476307869, 54.26712244749069, 38.424723744392395, 55.10759934782982, 20.07410053163767, 0.1256333859055303, 0.059975551266688854, 0.10363914931076579, 0.48696892568841577, 0.911269357893616, 1.490984063129872, 2.7999752294272184, 1.3241283665411174, 0.742828018264845, 1.9303211197257042, 89.57904562354088, 92.85604298114777, 79.68191429972649, 86.85398384928703, 78.62808644771576, 76.3094736635685, 71.77902236580849, 71.69354975223541, 81.00817233324051, 83.82765144109726, 80.18583565950394, 77.74466425180435, 63.29579137265682, 53.316660448908806, 62.5694565474987, 67.79948070645332, 74.164047986269, 73.63040462136269, 73.80084067583084, 72.41420388221741, 69.58141788840294, 64.62872564792633, 59.595196545124054, 54.094763696193695, 54.96183916926384, 53.83206099271774, 52.13549382984638, 52.92064189910889, 53.05010475218296, 53.29992614686489, 54.612413719296455, 52.10133746266365, 52.67852649092674, 52.97137297689915, 54.369245767593384, 51.26187890768051, 52.386173978447914, 54.335408583283424, 52.839767038822174, 55.41822887957096, 55.52514374256134, 57.553334310650826, 58.9761907607317, 59.65561330318451, 61.07752740383148, 71.6221971809864, 60.77949799597263, 37.19645865261555, 73.93121927976608, 68.13513949513435, 70.51028564572334, 58.10872010886669, 57.06516690552235, 58.620472848415375, 66.64773970842361, 61.134212762117386, 64.19472813606262, 53.466870188713074, 56.887701228260994, 52.94548116624355, 54.04162734746933, 57.66097493469715, 63.96715834736824, 67.5895343720913, 71.92869633436203, 65.50770968198776, 68.35892468690872, 63.93229141831398, 60.929187163710594, 61.42691485583782, 67.11183920502663, 70.38271129131317, 71.59730091691017, 72.27585330605507, 73.14277678728104, 64.89500015974045, 58.67300122976303, 56.75639167428017, 59.318544790148735, 58.27087640762329, 59.55634742975235, 58.42659205198288, 67.63348281383514, 67.27350533008575, 71.24104723334312, 74.74649593234062, 77.21019253134727, 76.37286186218262, 81.15644037723541, 8.034175839275122, 0.7890307484194636, 0.4962118109688163, 1.015108642168343, 1.815047417767346, 1.3225121470168233, 2.3520626267418265, 2.1684959018602967, 0.4718974500428885, 0.11117571833892725, 1.128355865366757, 31.071987189352512, 32.88411185145378, 30.968587137758732, 19.626526348292828, 31.580456905066967, 36.52223043143749, 42.98989377915859, 56.15028619766235, 67.60939970612526, 80.75761377811432, 67.1179948747158, 1.7964046681299806, 0.03629445382102858, 0.041326422870042734, 0.0543591891619144, 0.050257105176569894, 0.028217571598361246, 0.018471293114998844, 0.019899689905287232, 0.03865984544972889, 0.07789985742419958, 0.05533785559237003, 0.03189981522154994, 0.1142653459100984, 0.04755078574817162, 0.013668202409462538, 0.05259630641376134, 0.030740823603991885, 0.019101291145489085, 0.07090544953825884, 0.040107504682964645, 0.03578424955776427, 0.05795941804535687, 0.05401407564932015, 0.06535324981086887, 0.09922063210979104, 0.10251774190692231, 0.29233146517071873, 0.15545954403933138, 0.20511679351329803, 0.21531657432205975, 0.13171589467674494, 0.15864218497881666, 0.16834063018905, 0.2845955255907029, 0.22529519512318075, 0.17459847877034917, 0.12335686275037006, 0.24293414549902081, 0.17462243529735133, 0.3344692743849009, 0.2525469468673691, 0.3889668406918645, 0.3593834984349087, 0.6418708793353289, 38.47797028720379, 115.94162061810493, 114.85398218035698, 99.64938685297966, 88.6389608681202, 64.67356324195862, 99.63118582963943, 71.48167312145233, 74.41899910569191, 69.03465002775192, 27.91570745408535, 0.3745227470062673, 0.21065512992208824, 0.2670255652628839, 0.7072510023135692, 2.379794013686478, 2.4770790059119463, 4.640139061957598, 4.191779270768166, 2.6079796068370342, 2.0107675530016422, 96.33059933781624, 93.60945895314217, 82.81945914030075, 89.76233258843422, 82.08495855331421, 79.54980298876762, 73.70829284191132, 75.99474415183067, 85.9107680618763, 86.90987884998322, 84.13034319877625, 81.37021690607071, 65.1582196354866, 55.552623867988586, 64.73849415779114, 71.86605289578438, 81.01615950465202, 76.42512425780296, 77.01802164316177, 76.85583874583244, 73.73476222157478, 68.68588954210281, 62.0158414542675, 56.34631387889385, 59.39180865883827, 55.89496649801731, 55.2373243868351, 56.7763140052557, 55.11302165687084, 54.73821356892586, 56.96265980601311, 54.443516582250595, 55.16145385801792, 55.01417376101017, 58.42397779226303, 54.0733328461647, 53.99586260318756, 57.68057808279991, 56.31880335509777, 58.85555863380432, 59.856139943003654, 61.843019127845764, 63.791455775499344, 64.32671025395393, 63.69008481502533, 75.21821022033691, 64.69510048627853, 42.10337854921818, 76.88764303922653, 72.08795338869095, 73.12357261776924, 61.93588614463806, 60.34755617380142, 62.39998944103718, 68.3063431084156, 64.27140802145004, 68.68620872497559, 55.76038911938667, 60.426690727472305, 55.93780539929867, 57.156327813863754, 58.35436932742596, 68.39150413870811, 72.0423786342144, 75.84367945790291, 69.47297930717468, 72.24909514188766, 66.76395267248154, 64.11752387881279, 65.47107204794884, 70.15537708997726, 73.84203046560287, 74.31340277194977, 76.86584740877151, 76.64575561881065, 70.0651167333126, 61.27846822142601, 60.15674941241741, 63.45507122576237, 61.143043488264084, 63.25342744588852, 62.74420537054539, 69.46882992982864, 71.43625035881996, 74.32807758450508, 76.20745673775673, 78.88226240873337, 80.79278469085693, 82.97381445765495, 7.488820077851415, 3.2736915349960327, 9.262781962752342, 4.4247794430702925, 2.5877903401851654, 1.403239171486348, 3.2733091805130243, 3.962871953845024, 0.6739991647191346, 0.27694935619365424, 2.708772523328662, 44.47477430105209, 47.023578733205795, 54.630344957113266, 42.68913991749287, 47.831635773181915, 40.51673948764801, 44.03200685977936, 66.6768005490303, 77.88021817803383, 90.56355759501457, 73.75083535909653, 1.8628253415226936, 0.2781650237739086, 0.17709846259094775, 0.16659005224937573, 0.13753077015280724, 0.10756864314316772, 0.18023077107500285, 0.15016866935184225, 0.19702687917742878, 0.16897728899493814, 0.14704761182656512, 0.11472169251646847, 0.16435072553576902, 0.11082336146500893, 0.13543582084821537, 0.10395073259132914, 0.26231019641272724, 0.22672201856039464, 0.2716786530800164, 0.1818129705497995, 0.1235249220917467, 0.1727754226885736, 0.1103348724427633, 0.12476876901928335], [0.0023869855749580893, 0.03442152541538235, 0.0386160661582835, 0.013009189187869197, 0.03584235972084571, 0.031204229890136048, 0.04230711165291723, 0.0658541326993145, 0.04625519628461916, 0.06320925196632743, 0.047956792477634735, 0.05092175037134439, 0.058145986549789086, 0.01552698455270729, 0.01076209682651097, 0.03890263906214386, 0.04677352335420437, 0.028974888773518614, 0.02295447549840901, 0.09419860041816719, 55.46202912926674, 89.03910219669342, 73.37685942649841, 81.16745218634605, 54.516955241560936, 46.84211567044258, 23.3146483451128, 57.05551162362099, 66.54832184314728, 34.11217175424099, 7.885624710470438, 0.14404501591343433, 0.09811300638830289, 0.31594526837579906, 0.28230588126461953, 1.3151264120824635, 0.36937286553438753, 3.3397714141756296, 0.21210886363405734, 0.21932148520136252, 62.43197612464428, 92.88599297404289, 72.45666280388832, 83.19180116057396, 70.35105139017105, 72.72930577397346, 69.7312742471695, 67.60800138115883, 65.86061954498291, 76.47139817476273, 74.87128883600235, 77.72039875388145, 71.73638865351677, 52.7781343460083, 53.42303954064846, 55.228892639279366, 64.3011224269867, 70.49494966864586, 70.1597012579441, 72.708330899477, 67.58897200226784, 63.33320036530495, 57.58892700076103, 56.30480870604515, 51.91480167210102, 51.967816427350044, 50.523042753338814, 49.94960032403469, 50.17857223749161, 50.714639872312546, 50.1538697630167, 50.78652821481228, 50.74113205075264, 50.08203461766243, 50.00585250556469, 51.183367520570755, 52.44083784520626, 53.00745204091072, 53.377654775977135, 51.05836562812328, 50.40050692856312, 47.8763821721077, 49.51323173940182, 47.891421765089035, 51.743567660450935, 55.86005017161369, 68.97012948989868, 56.93619042634964, 38.57173025608063, 69.65150132775307, 60.77232018113136, 62.97549515962601, 54.70507174730301, 56.08374796807766, 57.560048550367355, 57.84652657806873, 57.758135721087456, 55.72125121951103, 48.97376708686352, 55.10941185057163, 51.27804324030876, 52.53985673189163, 48.62229734659195, 51.9243885576725, 53.271511271595955, 61.9625037163496, 60.574981570243835, 59.92297075688839, 57.5806700438261, 55.753754675388336, 52.56426282227039, 62.3736796528101, 64.87553760409355, 68.33306327462196, 66.66111499071121, 71.33442342281342, 63.032416105270386, 57.24079728126526, 51.10756158828735, 56.81506812572479, 51.09447509050369, 54.50098469853401, 57.34226703643799, 59.797615483403206, 54.82478432357311, 60.93299075961113, 61.94027490913868, 72.74617686867714, 68.75150442123413, 77.61772826313972, 57.080377489328384, 2.089990214444697, 2.360012037679553, 2.0796732930466533, 1.8583614123053849, 0.6894316209945828, 0.38705109036527574, 0.11696185785694979, 0.22596700204303488, 0.15867571521084756, 0.13565422006649897, 5.4688080959022045, 29.772812202572823, 41.23282626271248, 71.59426108002663, 150.47291368246078, 73.34924250841141, 21.095778308808804, 47.3754208534956, 54.33437883853912, 61.307361871004105, 70.58839425444603, 14.586966969072819, 0.8114807750098407, 0.039020625699777156, 0.08971217670477927, 0.11846991677884944, 0.04245746706146747, 0.04156097122177016, 0.038001957509550266, 0.07203924338682555, 0.02703380709135672, 0.0018719763693297864, 0.036284416273701936, 0.03675664484035224, 0.051947669344372116, 0.05578272859565914, 0.07628704435774125, 0.04007253468444105, 0.00382439180611982, 0.02074300715321442, 0.0074937304088962264, 0.02084796353301499, 0.057056339355767705, 0.0048291929670085665, 0.09740760244312696, 0.01930316644575214, 0.03266895109845791, 0.05124976851220708, 0.025598157662898302, 0.019292329234303907, 0.042241546616423875, 0.07395520893624052, 0.11656676811981015, 0.045626641731359996, 0.02140428299753694, 0.09722469272674061, 0.015684682584833354, 0.025030570541275665, 0.022814834846940357, 0.0360249057848705, 0.03727514260390308, 0.03388919401913881, 0.04174223337031435, 0.06503825265099294, 0.040910463940235786, 66.40343561768532, 99.8935541510582, 83.84231865406036, 89.14892390370369, 73.17942962050438, 52.82419167459011, 36.77326396107674, 59.31278809905052, 53.77951741218567, 42.665197402238846, 8.73647790402174, 0.03189336595823988, 0.01327346148173092, 0.7709073240403086, 1.004430977627635, 1.3335731159895658, 1.3605595054104924, 3.036581645719707, 0.4582281585317105, 0.44851555314380676, 65.94613015651703, 94.45150136947632, 78.30218553543091, 88.14228191971779, 73.13715308904648, 76.45556822419167, 72.62354224920273, 72.46460437774658, 70.62820851802826, 79.11952167749405, 78.34203779697418, 80.44435858726501, 73.5796469449997, 55.03500044345856, 57.44534410536289, 58.27196314930916, 67.88699761033058, 74.06529128551483, 73.27264621853828, 73.66302967071533, 71.70224368572235, 65.38984000682831, 62.53870479762554, 59.04041111469269, 54.657973274588585, 53.9905808866024, 53.676713928580284, 53.17622758448124, 52.431657537817955, 52.30029098689556, 50.39430946111679, 52.32962541282177, 52.02022321522236, 51.17068000137806, 52.2795706987381, 53.53704862296581, 56.10156521201134, 56.52757555246353, 55.62910616397858, 52.353769317269325, 53.56226406991482, 52.07894526422024, 51.95516310632229, 51.052475944161415, 54.052574560046196, 58.90104599297047, 72.72884219884872, 61.772548109292984, 40.95115877687931, 71.67693704366684, 63.4523543715477, 64.92712363600731, 57.06987105309963, 58.939340338110924, 59.26322355866432, 60.139593333005905, 62.629519924521446, 56.572204157710075, 51.786068379879, 57.69958086311817, 53.22203032672405, 53.55985879898071, 50.57822719216347, 53.76439042389393, 57.95216850936413, 64.11421805620193, 62.866433411836624, 64.92723762989044, 60.41753701865673, 57.097666561603546, 54.23382103443146, 66.48655235767365, 69.81306105852127, 70.72615966200829, 69.11271303892136, 74.58854600787163, 66.117432564497, 61.368853971362114, 53.85137155652046, 58.64744380116463, 55.09754128754139, 59.08444695174694, 59.406320080161095, 61.45246088504791, 58.84086862206459, 62.81960092484951, 65.30011922121048, 74.75353315472603, 72.37990692257881, 79.20940205454826, 60.614222064614296, 2.90272765327245, 1.2280078930780292, 0.2382804045919329, 2.0829078694805503, 1.8696846859529614, 1.113909634295851, 1.9490833254531026, 1.163960904814303, 0.35601055598817766, 0.13662998098880053, 5.35887666977942, 33.42966377735138, 37.58585415780544, 51.76920868456364, 115.67699521780014, 77.54142075777054, 29.55602813512087, 50.72292722761631, 65.17617747187614, 66.8295219540596, 86.41357988119125, 22.11707230657339, 0.6963234418071806, 0.09130086997174658, 0.0026806515552380006, 0.08138880497426726, 0.05277451462461613, 0.03956825647037476, 0.05507783302164171, 0.05299813114106655, 0.049742466580937617, 0.03311374988697935, 0.025115464814007282, 0.04102347818843555, 0.03681885908008553, 0.03777352445467841, 0.025457999363425188, 0.028810944641008973, 0.055073317053029314, 0.07554673720733263, 0.00040816603132043383, 0.015050366182549624, 0.026822795953194145, 0.037061990369693376, 0.06158706557471305, 0.09174937949865125, 0.19807615724857897, 0.13813461118843406, 0.13192204845836386, 0.09193925798172131, 0.13169055775506422, 0.1681352185551077, 0.19823960785288364, 0.16192986950045452, 0.2814590313937515, 0.23649221460800618, 0.2054437095648609, 0.2087835522252135, 0.08057694736635312, 0.14117707527475432, 0.11725866497727111, 0.09373258362757042, 0.12822768185287714, 0.15402672404889017, 0.188649412302766, 76.59761220216751, 113.22646111249924, 90.90463489294052, 99.96880531311035, 75.41812509298325, 66.53936192393303, 33.040853440761566, 79.00281473994255, 90.53893491625786, 55.45563027262688, 13.320285938680172, 0.2227666534599848, 0.5187717941589653, 1.3014383590780199, 2.0305704278871417, 2.7557171043008566, 3.9295866899192333, 6.9530160538852215, 3.2690296601504087, 0.9202594973612577, 71.08294531702995, 97.62034893035889, 79.70382392406464, 89.44619715213776, 76.75531134009361, 81.07146173715591, 76.45418509840965, 75.5185841023922, 74.19137611985207, 82.135891020298, 81.90087363123894, 83.1383228302002, 78.96037101745605, 59.27779957652092, 59.384368658065796, 62.231802865862846, 73.54240894317627, 78.06453868746758, 75.4070220887661, 77.21466109156609, 74.3169441819191, 69.13043528795242, 64.81458127498627, 63.19302208721638, 57.5909560918808, 58.08339066803455, 57.458749786019325, 55.96229508519173, 56.08736537396908, 56.29897601902485, 54.346257001161575, 54.94178384542465, 53.284168392419815, 53.90706516802311, 53.61869864165783, 56.157585605978966, 58.29975865781307, 58.68537336587906, 57.34945625066757, 55.994228571653366, 55.23569047451019, 53.919186517596245, 55.54520286619663, 52.12094061076641, 56.52586184442043, 62.40350045263767, 75.53909540176392, 66.01052150130272, 45.27279607951641, 74.07583951950073, 69.28994312882423, 68.03997740149498, 60.19288167357445, 62.81231291592121, 63.84091392159462, 62.92469188570976, 66.70718371868134, 59.56017382442951, 53.92054684460163, 60.87256260216236, 56.0217846930027, 58.080483824014664, 53.163464069366455, 56.97218969464302, 61.80955432355404, 66.89139783382416, 67.64634892344475, 68.7974363565445, 64.1202825307846, 61.4484179019928, 55.79147905111313, 69.48616459965706, 72.02551513910294, 72.46615469455719, 72.55478113889694, 76.85858219861984, 68.43998953700066, 64.02189821004868, 56.144533306360245, 62.65475057065487, 57.0424897223711, 61.891082748770714, 62.16092526912689, 66.16843342781067, 61.11833721399307, 67.74338811635971, 68.97377729415894, 78.13577726483345, 74.37300637364388, 84.11457404494286, 62.137450128793716, 2.9333988949656487, 8.098886366933584, 9.125759415328503, 5.366162778809667, 3.4257377637550235, 1.1540853534825146, 3.37877394631505, 1.0275219823233783, 0.6822229328099638, 0.37253560207318515, 9.819621182978153, 48.445481434464455, 59.484842866659164, 91.6050361096859, 156.84953391551971, 81.39205053448677, 31.14593882113695, 62.88636714220047, 74.05443146824837, 76.65083974599838, 94.73982229828835, 23.183458484709263, 0.8385331265162677, 0.31966630776878446, 0.23067630012519658, 0.21959805395454168, 0.1849913812475279, 0.18742221174761653, 0.22543275961652398, 0.132549237459898, 0.10635286424076185, 0.10783281803014688, 0.11081156131695025, 0.1850149963865988, 0.16102964436868206, 0.16833939822390676, 0.16139305924298242, 0.15273327939212322, 0.10917347070062533, 0.11743314389605075, 0.15267757378751412, 0.09361753589473665, 0.19916752993594855, 0.08993919225758873, 0.1802492208662443], [0.03919542003131937, 0.016900227710721083, 0.051543744339141995, 0.01667953525611665, 0.0670036229712423, 0.028670005231106188, 0.02874161506042583, 0.01759703387506306, 0.017334562217001803, 0.025178319156111684, 0.03870888285746332, 0.07536112607340328, 0.02693754682695726, 0.036391255853231996, 0.08139297584421001, 0.10304583192919381, 0.06336005637422204, 0.13282873027492315, 0.047952027889550664, 3.374662804417312, 73.94704163074493, 75.92459231615067, 77.97441512346268, 60.48658691346645, 34.43581938743591, 15.798531007021666, 26.33106328547001, 29.731643311679363, 43.60972411930561, 27.299068942666054, 0.05180744054086972, 0.028585916188603733, 0.05928500511799939, 0.1919565856223926, 0.2612817281624302, 0.4061640944564715, 1.6282193991355598, 1.356020886451006, 0.9668228519149125, 32.109800800681114, 103.19184556603432, 74.76631566882133, 87.39295452833176, 66.29012569785118, 71.42561852931976, 67.74136662483215, 69.52557608485222, 64.33798044919968, 65.54210543632507, 69.67306137084961, 78.21331590414047, 72.56701648235321, 63.57394404709339, 51.3405878841877, 54.42401222884655, 52.45995081961155, 64.79679062962532, 68.2619234919548, 68.54883089661598, 65.65535455942154, 69.47788864374161, 62.881750389933586, 59.05785217881203, 55.9611589461565, 55.69887802004814, 48.3776018768549, 49.550256952643394, 47.30354771018028, 49.13464665412903, 48.32885429263115, 51.29370220005512, 49.45915304124355, 50.42378827929497, 48.25758911669254, 50.341036319732666, 54.28738676011562, 62.620617002248764, 58.300172835588455, 56.71590104699135, 50.604122802615166, 51.783640310168266, 50.264185443520546, 51.25213623046875, 48.47103886306286, 50.99010989069939, 52.99336239695549, 68.60914126038551, 54.37058709561825, 40.7577795535326, 68.25445309281349, 55.593243688344955, 56.64191521704197, 51.49276211857796, 54.157851710915565, 53.83729711174965, 53.91145393252373, 54.950071200728416, 51.064232513308525, 49.99279260635376, 51.506961956620216, 54.34088408946991, 50.79831138253212, 51.31375752389431, 49.30665962398052, 48.47687914967537, 49.17004935443401, 52.86700397729874, 51.931714564561844, 51.04441277682781, 50.7336388528347, 51.05358548462391, 59.85987514257431, 65.65539255738258, 66.98548838496208, 66.28530755639076, 67.87194281816483, 67.3796184360981, 60.780451744794846, 53.7822000682354, 52.01074652373791, 53.12812976539135, 54.31941144168377, 54.953946992754936, 56.64656616747379, 60.460125133395195, 61.266020089387894, 67.63620346784592, 67.72155448794365, 70.44206410646439, 68.20401459932327, 73.93884167075157, 26.359898038208485, 0.048347507254220545, 0.508610486285761, 1.2854504794813693, 0.9382596064824611, 1.12326544476673, 0.7935703173279762, 0.4010518844006583, 0.21734685287810862, 0.13699544419068843, 0.13324756873771548, 12.742404397577047, 31.15331992506981, 49.85552117228508, 94.73672166466713, 70.25593489408493, 33.597519770264626, 36.92651353776455, 47.1164533495903, 58.353510573506355, 69.21998128294945, 51.801415756344795, 0.7731168461032212, 0.057182411692338064, 0.006969970354475663, 0.02411522229522234, 0.016566367012273986, 0.054212177128647454, 0.054482192717841826, 0.04279904795112088, 0.038115142451715656, 0.033917046821443364, 0.03724304471688811, 0.0868264096789062, 0.04066945148224477, 0.07787064649164677, 0.06258633773541078, 0.04296733735827729, 0.02956084590550745, 0.05672972387401387, 0.06177350049256347, 0.04767868376802653, 0.026401406357763335, 0.008365911635337397, 0.07303777339984663, 0.03378183864697348, 0.03330710904265288, 0.027286460135655943, 0.016282224642054643, 0.025644675479270518, 0.035892758969566785, 0.0034470869422875694, 0.05142520851222798, 0.0729866542678792, 0.07063225755700842, 0.03216369324945845, 0.01902749754663091, 0.026358575159974862, 0.0940818086382933, 0.0714459631126374, 0.17952386057004333, 0.021542982976825442, 0.18646105629159138, 0.14510495122522116, 5.107352016493678, 89.0871012210846, 85.49234211444855, 87.3989126086235, 69.924136698246, 43.82093958556652, 22.6077513769269, 31.259410232305527, 37.37583562731743, 47.67509937286377, 31.775616332888603, 0.03719666048709769, 0.0797584920655936, 0.3078825760167092, 0.29601527843624353, 0.7217482337728143, 1.4866404212079942, 3.045592149719596, 0.8421592600643635, 0.4588309011887759, 33.71978960931301, 104.16754201054573, 78.90340447425842, 90.34029677510262, 69.29580241441727, 76.44398644566536, 70.93277737498283, 72.84704625606537, 65.51454931497574, 68.33574593067169, 73.87125849723816, 80.0379627943039, 75.93673646450043, 66.13380968570709, 53.58416989445686, 56.41265071928501, 55.8970145881176, 67.05845206975937, 71.82676300406456, 69.89847287535667, 69.04415711760521, 71.59446626901627, 64.78975340723991, 61.393320858478546, 59.45118807256222, 59.15998689830303, 52.339242696762085, 52.3384827375412, 51.047372817993164, 52.61215165257454, 52.491272538900375, 52.57286176085472, 51.662757396698, 51.921477913856506, 51.099468022584915, 52.99025036394596, 57.66436815261841, 65.86555927991867, 61.88518166542053, 58.14951092004776, 52.82577618956566, 54.52790625393391, 51.1950708925724, 55.14527812600136, 49.61668498814106, 54.03890289366245, 57.381537929177284, 72.89648920297623, 57.74045906960964, 45.53952656686306, 71.41002416610718, 59.086628034710884, 59.89489026367664, 53.7057101726532, 55.96700683236122, 55.972592532634735, 57.15965263545513, 57.36537739634514, 52.75152437388897, 52.90377840399742, 53.57235632836819, 55.91656073927879, 53.31117354333401, 52.83233463764191, 50.896133333444595, 49.52421694993973, 52.570695877075195, 54.420930594205856, 54.7112388163805, 54.971353858709335, 53.56955587863922, 53.68006154894829, 62.42739737033844, 69.88628312945366, 69.26883906126022, 67.32649728655815, 70.60770481824875, 71.25116229057312, 62.24698305130005, 54.87169660627842, 54.6239423006773, 57.88470312952995, 55.77362760901451, 57.25052855908871, 58.66832748055458, 63.01693953573704, 63.89521300792694, 70.34597486257553, 71.86871275305748, 75.33804059028625, 73.42483565211296, 79.7574770450592, 32.81516835093498, 0.06986498076003045, 0.9662784123793244, 0.6238781323190778, 1.5609924565069377, 2.9240772826597095, 1.761155384592712, 1.095377909950912, 0.5422284104861319, 0.16256214963505045, 0.07415488376864232, 13.874105270951986, 35.72256714105606, 47.30032928287983, 101.3213275372982, 77.31178387999535, 31.441192477941513, 48.472064808011055, 52.751520574092865, 65.9009201824665, 76.02233827114105, 65.14795258641243, 1.4504726557061076, 0.07223635038826615, 0.08079541337792762, 0.0044121992050349945, 0.051960063210572116, 0.07002174461376853, 0.030025794003449846, 0.03676755070046056, 0.04415941206389107, 0.018222306280222256, 0.037057856607134454, 0.08591026547946967, 0.03225064698199276, 0.053548685973510146, 0.05420869645604398, 0.023778337344992906, 0.03611856111092493, 0.043807311230921187, 0.05053548105934169, 0.060694495696225204, 0.04027891111036297, 0.03499295315123163, 0.09952310181688517, 0.1077478495426476, 0.19901268824469298, 0.11805972433649004, 0.16876127949217334, 0.09062846933375113, 0.17228743090527132, 0.11674763693008572, 0.07408348916214891, 0.2063726558117196, 0.13318861252628267, 0.08407680448726751, 0.19866646151058376, 0.09316088500781916, 0.14704682515002787, 0.26291754038538784, 0.2747885190183297, 0.14201509358827025, 0.34636417985893786, 0.4319017461966723, 6.903138980269432, 104.14038866758347, 95.51358237862587, 99.80452492833138, 78.56550380587578, 51.86766900122166, 25.54984040558338, 40.29765084385872, 44.988863915205, 63.09784859418869, 43.55922482907772, 0.23862235655542463, 0.16153633827343583, 0.4034928377950564, 1.2367319874465466, 0.7724322890862823, 2.7782819559797645, 6.993464883416891, 7.045755302533507, 3.0458975583314896, 36.22689127922058, 107.91806995868683, 82.28958517313004, 94.10055220127106, 73.1206163764, 79.75937694311142, 73.06746482849121, 76.05297982692719, 70.10955914855003, 72.4064826965332, 77.70416602492332, 83.87406975030899, 79.54187661409378, 69.618861079216, 56.95873461663723, 60.093338415026665, 59.260670095682144, 71.55271410942078, 75.70795074105263, 73.30073431134224, 70.32317608594894, 74.58557456731796, 68.23412418365479, 65.22829547524452, 62.24348723888397, 62.27324724197388, 53.365278840065, 55.293926149606705, 51.91050410270691, 55.41316755115986, 54.98496472835541, 56.90093971788883, 55.59129819273949, 56.961508467793465, 52.91376046836376, 57.08413168787956, 58.82677897810936, 68.62599715590477, 63.85576352477074, 61.92381799221039, 56.82337448000908, 57.61982314288616, 56.616555377840996, 57.87204220890999, 54.60148170590401, 56.2898451089859, 59.86323796212673, 75.06406769156456, 62.18927934765816, 48.39243248105049, 72.65264868736267, 64.19446215033531, 65.27675807476044, 58.858932852745056, 59.67479467391968, 58.688755184412, 59.9114877730608, 61.036884784698486, 54.88602563738823, 54.66744236648083, 55.14399379491806, 62.6769033819437, 55.834352150559425, 54.356170669198036, 53.3149391412735, 54.040198624134064, 53.639559522271156, 60.18192306160927, 56.753370836377144, 57.064505741000175, 55.186908692121506, 56.2034909427166, 67.10280328989029, 73.89277294278145, 71.09426110982895, 69.74444434046745, 73.8120348751545, 73.23605418205261, 65.55630147457123, 58.311560824513435, 56.02764777839184, 59.81480576097965, 59.37909074127674, 59.306461438536644, 63.51864941418171, 66.7928159236908, 66.64334714412689, 72.8150063753128, 75.8586810529232, 77.13711485266685, 76.88651069998741, 81.6043147444725, 36.993173360824585, 0.09801838255953044, 5.520173264667392, 7.62665388174355, 6.454667570069432, 4.582342263311148, 2.024082038551569, 3.942449474707246, 0.9898699214681983, 0.255005830549635, 0.22128973505459726, 22.156840972602367, 50.407304763793945, 62.5276929885149, 100.71024432778358, 73.98567035794258, 47.67995931208134, 52.75809422135353, 62.402140125632286, 75.90117037296295, 84.4998049736023, 71.42218351364136, 1.391465028282255, 0.19551205186871812, 0.11365593876689672, 0.11329519562423229, 0.08424962841672823, 0.09730207646498457, 0.17441392148612067, 0.11610305198701099, 0.09299879995523952, 0.07268132729222998, 0.10981590341543779, 0.25612157536670566, 0.06964370200876147, 0.16597249632468447, 0.16837846487760544, 0.07730317069217563, 0.08313108570291661, 0.13223090063547716, 0.10248877588310279, 0.14859788410831243, 0.12618833425221965, 0.1375503183226101, 0.16742094594519585], [0.022264296712819487, 0.01612734213267686, 0.04347413887444418, 0.015438297905348008, 0.04922341220662929, 0.0375766846264014, 0.018408462892693933, 0.0049006961125996895, 0.05471467047755141, 0.027259928356215823, 0.05221612642344553, 0.03963722425396554, 0.04752180859213695, 0.023244733165483922, 0.03644122465630062, 0.03917315189028159, 0.021662594917870592, 0.08517714974004775, 0.09898848089505918, 21.835818998515606, 91.0639451444149, 76.32532641291618, 78.93788382411003, 48.17623168230057, 38.47567901015282, 26.941924206912518, 56.00996732711792, 54.00596246123314, 45.28265655040741, 5.414551757276058, 0.10011286431108601, 0.047514079124084674, 0.14964636065997183, 0.42691433569416404, 0.5607995577156544, 1.317807761952281, 0.5135446402709931, 1.9840302877128124, 7.0737730991095304, 95.10584145784378, 79.8400542140007, 81.94656237959862, 68.51429834961891, 68.53430807590485, 64.72633481025696, 68.95476311445236, 64.18886885046959, 61.78951419889927, 57.72960685193539, 62.44405947625637, 61.54464773833752, 59.02324363589287, 52.71123893558979, 52.43576131761074, 51.49596534669399, 53.42045567929745, 62.45043933391571, 69.94439721107483, 69.64753434062004, 65.53470343351364, 69.70929622650146, 67.81581223011017, 63.569008111953735, 60.02328537404537, 54.44196626543999, 49.14376616477966, 49.52965445816517, 48.9080648124218, 47.295910120010376, 49.5942509919405, 50.87293177843094, 47.433907315135, 47.848940044641495, 48.09197120368481, 54.16195549070835, 62.6808475703001, 68.20159032940865, 62.98632837831974, 57.64165677130222, 50.82617148756981, 48.566246554255486, 47.56160706281662, 49.48605179786682, 47.849206030368805, 51.15877144038677, 54.03710559010506, 67.14823365211487, 54.86551433801651, 43.54348987340927, 69.73553001880646, 54.81730252504349, 55.835921466350555, 49.92968559265137, 53.88531893491745, 51.58294267952442, 53.931501656770706, 50.35294108092785, 49.81916852295399, 48.95293280482292, 51.73594906926155, 51.57663121819496, 51.032538414001465, 47.32097737491131, 49.89783950150013, 48.81755366921425, 47.93251276016235, 49.487222135066986, 49.8915546387434, 49.15132015943527, 51.04754760861397, 50.71980759501457, 54.314004331827164, 63.6647629737854, 67.30540841817856, 66.00997433066368, 66.9663754105568, 67.27670475840569, 60.52361972630024, 51.12824387848377, 52.1332785487175, 52.53996692597866, 52.83366836607456, 54.79301802814007, 60.86147479712963, 66.68784275650978, 70.01261115074158, 69.23441290855408, 68.75086605548859, 77.89965033531189, 68.30920055508614, 64.3560142815113, 79.77922707796097, 24.14195515215397, 0.12291087652556598, 1.359417310450226, 1.528494581580162, 1.5206931252032518, 0.6694357877131552, 1.2897956650704145, 0.36950176174286753, 0.2645723515888676, 0.16234185051871464, 1.4441300835460424, 22.952983751893044, 29.662819504737854, 21.877715550363064, 27.31895137578249, 40.29341407120228, 21.20696224272251, 44.44065973162651, 51.48073196411133, 56.511525213718414, 66.73115283250809, 14.583493005484343, 0.7693896617274731, 0.21319992461940274, 0.08845586169627495, 0.11859853839268908, 0.05124590563355014, 0.01448242654078058, 0.08415484873694368, 0.051937683747382835, 0.009816554302233271, 0.01852962221164489, 0.03219688209355809, 0.0342001056560548, 0.022508233232656494, 0.012770193516189465, 0.025860304631351028, 0.049458509747637436, 0.020548347383737564, 0.020471310599532444, 0.028296096388658043, 0.06359591832733713, 0.06788640763261355, 0.03781567844271194, 0.00808300957942265, 0.042520360366324894, 0.054083614886621945, 0.013566009602072882, 0.0209671635820996, 0.04037503407744225, 0.015930634035612457, 0.011081450393248815, 0.010617971747706179, 0.03420308908971492, 0.09687683326774277, 0.010766216673800955, 0.07933250672067516, 0.03915508801583201, 0.044477997507783584, 0.05787601177871693, 0.04308699011744466, 0.05763273577031214, 0.2569149906048551, 28.424750939011574, 105.79333797097206, 85.30231431126595, 88.76386776566505, 57.91498750448227, 48.06249998509884, 35.081051364541054, 58.46515618264675, 42.837480157613754, 47.346280217170715, 6.296392288058996, 0.021459522904478945, 0.30063250567764044, 0.22739002568414435, 0.94513836549595, 1.127427527680993, 2.1862554363906384, 1.6164764855057001, 1.106548123061657, 8.240069691091776, 98.57095912098885, 82.11158752441406, 85.62226474285126, 71.16226986050606, 73.22128057479858, 68.39421719312668, 71.19795754551888, 67.95659467577934, 65.76790452003479, 59.18202191591263, 64.40791189670563, 65.00890284776688, 62.830426543951035, 54.34735134243965, 56.296167969703674, 54.73183371126652, 56.02575547993183, 64.94202643632889, 72.95394212007523, 73.46370756626129, 67.66350120306015, 72.91832283139229, 69.89110127091408, 67.40687817335129, 62.57345773279667, 56.80361174046993, 52.0681082457304, 50.71405850350857, 51.55541315674782, 52.35362112522125, 51.41364276409149, 53.294963613152504, 50.30852526426315, 49.97909054160118, 49.495471492409706, 56.58470168709755, 67.69445434212685, 71.26903653144836, 65.25832146406174, 59.848764538764954, 52.58018396794796, 52.782811895012856, 49.02719222009182, 50.752026066184044, 51.50428310036659, 52.58505530655384, 58.50364811718464, 70.69114834070206, 58.50974678993225, 46.51345610618591, 72.17120692133904, 58.79415012896061, 57.75476910173893, 50.83709590137005, 55.41687995195389, 55.4303540289402, 58.76179486513138, 52.44379408657551, 50.99772848188877, 52.25013367831707, 54.50063891708851, 53.567219004034996, 53.47139194607735, 49.83142286539078, 51.50075688958168, 52.43831478059292, 49.26297716796398, 51.554603800177574, 53.354578614234924, 52.91024945676327, 52.852116376161575, 52.97357685863972, 57.84980960190296, 65.97410425543785, 69.43690404295921, 66.40953809022903, 70.21514028310776, 69.57523941993713, 62.90014140307903, 53.88385221362114, 54.62925061583519, 54.51851315796375, 55.70078931748867, 57.800093069672585, 63.36395971477032, 70.3668661415577, 73.10560718178749, 74.35357421636581, 73.3717069029808, 79.92118746042252, 72.74283304810524, 68.71245011687279, 83.24546188116074, 30.344905704259872, 0.18588897917652503, 0.8920680382288992, 0.4779591935221106, 1.0725617967545986, 1.9839745969511569, 3.5418680822476745, 1.0764873423613608, 0.75654914136976, 0.21868935349630192, 1.2735434621572495, 28.208099864423275, 33.228065595030785, 29.311513155698776, 34.180701076984406, 47.76548132300377, 31.91158063709736, 48.050131648778915, 58.06930862367153, 63.45723330974579, 80.60649588704109, 22.40959770977497, 1.164834382943809, 0.3659178118687123, 0.11682456053677015, 0.049856957703013904, 0.11456878783064894, 0.05994022874801885, 0.05488452581630554, 0.03977122272772249, 0.030629863249487244, 0.04040888714371249, 0.08237802845542319, 0.07635931469849311, 0.020327634520072024, 0.044801269614254124, 0.0444904544565361, 0.04593128964188509, 0.017017492609738838, 0.07524036380345933, 0.008041436321946094, 0.005768744504166534, 0.05066259982413612, 0.04539393761660904, 0.13904484047088772, 0.05211442621657625, 0.17516052204882726, 0.13087662955513224, 0.1841345865977928, 0.11322250968078151, 0.15307622583350167, 0.10767071071313694, 0.1435256758122705, 0.13850089075276628, 0.20846920815529302, 0.13993247877806425, 0.16214507748372853, 0.11445385884144343, 0.18459578684996814, 0.2029652925557457, 0.16869439714355394, 0.2585264603840187, 0.2881504426477477, 34.56952661275864, 119.8848058283329, 95.54581224918365, 102.64054074883461, 65.99949449300766, 54.78621259331703, 39.49167609214783, 77.52306014299393, 75.03257498145103, 71.10252186655998, 9.162301104515791, 0.18849065207177773, 0.39800801023375243, 0.8655174972955137, 1.309409737586975, 1.791423016693443, 4.329064004123211, 5.549435494467616, 5.400045085698366, 8.53031711652875, 103.39668497443199, 85.77088236808777, 89.62378442287445, 74.28640902042389, 76.45764291286469, 71.72169864177704, 75.44723153114319, 70.85292086005211, 69.46242347359657, 63.378809317946434, 67.22726181149483, 67.36517921090126, 65.74363902211189, 57.13944531977177, 59.39872428774834, 57.90366791188717, 60.528787449002266, 68.02394226193428, 76.10763609409332, 72.82913401722908, 69.40119355916977, 75.44757351279259, 72.07348376512527, 70.39412587881088, 67.50937387347221, 60.10678969323635, 54.88809272646904, 56.18152812123299, 55.136443600058556, 54.803623259067535, 55.6196104735136, 56.30334958434105, 52.585659474134445, 53.21428634226322, 52.17680141329765, 58.96690025925636, 71.40637636184692, 74.20539736747742, 67.946867197752, 63.67411807179451, 55.904583781957626, 54.217911288142204, 53.03580231964588, 55.34275732934475, 54.878072664141655, 56.853316873312, 60.9394846111536, 73.67121443152428, 63.947414606809616, 50.02682738006115, 75.91934859752655, 62.22282774746418, 61.10077075660229, 56.69069319963455, 57.98573970794678, 59.18464757502079, 61.050355061888695, 55.194094106554985, 54.43465165793896, 53.54777544736862, 56.72282427549362, 57.20707789063454, 56.278563514351845, 52.58771136403084, 54.36440862715244, 54.22818213701248, 51.81690372526646, 54.08570118248463, 55.509849563241005, 55.43964833021164, 55.51512748003006, 56.66127897799015, 60.34060634672642, 70.09773418307304, 73.97345781326294, 69.3189887702465, 70.99110424518585, 72.32499226927757, 66.78916811943054, 56.042436584830284, 56.048440262675285, 58.712313920259476, 57.744638845324516, 60.4605583101511, 66.91952392458916, 71.93365126848221, 75.2856793999672, 77.9989618062973, 75.24819821119308, 82.27956131100655, 75.93558892607689, 70.50299003720284, 79.26490187644958, 31.568768732249737, 0.18359077046625316, 7.878634035587311, 7.886872468516231, 7.4666534923017025, 4.513647649437189, 4.110927684232593, 1.4740879135206342, 1.161106307990849, 0.45702020928729326, 2.6695880759507418, 40.03565490245819, 46.77969641983509, 32.353903502225876, 39.79265794157982, 52.67541825771332, 34.087556675076485, 55.96122734248638, 69.66219395399094, 72.34857380390167, 89.40414860844612, 22.84284856170416, 1.5515447384677827, 0.45686210214626044, 0.2258459577569738, 0.24190649361116812, 0.3144916979363188, 0.11334097871440463, 0.19905494613340124, 0.1675850644824095, 0.2625163353513926, 0.14537531562382355, 0.21390978887211531, 0.22441754612373188, 0.09129344849498011, 0.10322515707230195, 0.15264129760907963, 0.15378874697489664, 0.11624489867244847, 0.1186958710604813, 0.17354692972730845, 0.1250301831169054, 0.1750607180292718, 0.22928695514565334], [0.019509698722686153, 0.04061413179442752, 0.037972405189066194, 0.02185460336477263, 0.024086963167064823, 0.07829492489690892, 0.05474883895658422, 0.0044768713451048825, 0.04363178217317909, 0.011720986876753159, 0.045584157487610355, 0.01851159358920995, 0.057571887082303874, 0.0612301556247985, 0.08455876260995865, 0.0274662250012625, 0.017998031107708812, 0.021622504100378137, 0.19845472677843645, 55.243392661213875, 83.6621019244194, 76.13371789455414, 61.43163800239563, 40.29997631907463, 23.372534438967705, 26.289909593760967, 34.43866543471813, 43.43818612396717, 28.090695664286613, 0.38279229076579213, 0.053185293363640085, 0.1818816043669358, 0.49820896005257964, 0.1277630528784357, 0.5747483717277646, 1.5163187286816537, 1.1095878412015736, 0.7034449127968401, 65.80337941646576, 89.67711076140404, 77.01801404356956, 75.33659666776657, 68.2810440659523, 62.52159431576729, 65.39324462413788, 64.54932510852814, 62.721771374344826, 57.94375956058502, 54.00843232870102, 56.01215980947018, 58.62993434071541, 54.36053663492203, 54.77184556424618, 52.381716817617416, 50.93848966062069, 51.59134782850742, 59.915093779563904, 67.08939000964165, 68.53120744228363, 67.76229590177536, 67.6551416516304, 66.27954706549644, 66.04002311825752, 58.60126867890358, 52.69806884229183, 48.992150500416756, 51.04932211339474, 47.32350043952465, 53.385296165943146, 51.88458949327469, 54.033252596855164, 48.40254753828049, 49.0386638045311, 48.4358299523592, 60.35092659294605, 65.04696160554886, 71.07755720615387, 65.93585550785065, 57.85355620086193, 50.29574275016785, 49.89571541547775, 46.28690466284752, 48.6680468916893, 47.68399849534035, 49.03847001492977, 52.77899689972401, 69.63851362466812, 50.13752683997154, 43.30921344459057, 70.30343994498253, 55.93386881053448, 56.51131622493267, 48.87612372636795, 50.67091941833496, 47.448240146040916, 49.687581583857536, 47.2251009196043, 50.136139914393425, 49.3033841997385, 51.74941934645176, 50.85263326764107, 51.95189528167248, 46.83533303439617, 47.71218158304691, 47.24303215742111, 48.020307049155235, 46.99003793299198, 49.8297281563282, 48.75563219189644, 51.33891597390175, 47.44776897132397, 53.63979510962963, 61.19972124695778, 66.0249987244606, 67.33373209834099, 66.06945633888245, 66.56921312212944, 60.67289851605892, 52.235732451081276, 50.03014840185642, 49.88299749791622, 52.688561752438545, 56.49445652961731, 67.14104443788528, 70.46935424208641, 69.01301398873329, 68.36677506566048, 72.80031636357307, 67.2170327603817, 60.16856297850609, 63.27659860253334, 65.88411748409271, 67.5021542608738, 41.46208696067333, 2.767080394551158, 0.6985162803903222, 1.9508143700659275, 1.65799270151183, 0.3077921527437866, 0.1532777931424789, 0.21322074928320944, 0.10721790415118448, 0.23990248708287254, 9.452302493155003, 24.600151665508747, 37.68513523042202, 42.85343550145626, 51.25484548509121, 41.382135450839996, 33.322186544537544, 57.90541581809521, 56.6646645963192, 68.6024384200573, 40.88037237524986, 0.5419419414829463, 0.08538946334738284, 0.022078375732235145, 0.05596093680651393, 0.004466264199436409, 0.02789118247164879, 0.03688578595756553, 0.03814435709500685, 0.02752131833403837, 0.030952847773733083, 0.03240944803110324, 0.01225483503731084, 0.07936320194858126, 0.04930036920995917, 0.1023694608011283, 0.019792156417679507, 0.016414256424468476, 0.02462317599565722, 0.016869586288521532, 0.0365689519821899, 0.03244802857807372, 0.020159526939096395, 0.0037298609777280944, 0.05312174696882721, 0.04733792295155581, 0.07201203625299968, 0.14248276536818594, 0.02347066518268548, 0.07549909874796867, 0.010334065009374171, 0.03733457007911056, 0.0422752252779901, 0.04271220925147645, 0.04955940101353917, 0.016024217002268415, 0.06323164256173186, 0.03664076219138224, 0.025175511982524768, 0.01971470959688304, 0.031275628207367845, 0.3913841344183311, 66.89224138855934, 93.68904188275337, 83.29666033387184, 69.66707289218903, 49.32125464081764, 32.67955742776394, 29.658565632998943, 36.01022310554981, 49.55827072262764, 32.64615722000599, 0.8647523133549839, 0.13728581689065322, 0.3090325486846268, 0.9612173214554787, 0.9090031951200217, 2.6734840543940663, 2.8207361279055476, 0.7906441180966794, 1.0924563417211175, 70.16437500715256, 91.49155139923096, 81.32208108901978, 80.39851024746895, 71.88097089529037, 65.6366291642189, 69.52769637107849, 67.15799912810326, 65.28814986348152, 61.56147323548794, 58.126833736896515, 58.58317404985428, 60.17645135521889, 56.764553636312485, 57.400403916835785, 54.76731240749359, 54.589413553476334, 55.13375714421272, 62.74968467652798, 69.53438401222229, 70.45128241181374, 71.84589877724648, 68.79459410905838, 70.56828573346138, 70.41534394025803, 61.63719557225704, 55.856713950634, 51.880865693092346, 53.43565106391907, 50.00991068780422, 53.6614615470171, 54.064980894327164, 56.065676137804985, 51.75724312663078, 52.38245777785778, 50.497276335954666, 61.02350950241089, 69.23264220356941, 72.2863407433033, 67.73242950439453, 60.748818442225456, 53.3511283993721, 53.45315292477608, 49.3414581567049, 50.8337976783514, 50.20367369055748, 53.31261746585369, 57.15420372784138, 72.49689504504204, 53.99249218404293, 46.40468694269657, 73.23217079043388, 59.391348883509636, 58.648952320218086, 52.90070816874504, 52.75958754122257, 50.922313928604126, 52.15018764138222, 49.90404076874256, 51.173522248864174, 51.95866271853447, 54.20425862073898, 53.31792198121548, 54.24351431429386, 49.28201414644718, 49.893868714571, 50.018247440457344, 49.24313843250275, 49.523726776242256, 52.895111069083214, 50.13719625771046, 51.46309331059456, 50.348316729068756, 55.57805970311165, 63.088504895567894, 69.49124112725258, 69.74730178713799, 70.49863547086716, 69.34746444225311, 64.24817606806755, 53.91126774251461, 51.46110221743584, 54.153219759464264, 56.063069477677345, 60.17288334667683, 69.32599559426308, 73.4740962088108, 71.26528233289719, 71.51704162359238, 74.01129618287086, 70.6345845758915, 64.44964125752449, 66.58766493201256, 65.48282861709595, 70.02847909927368, 49.956523552536964, 4.635452963411808, 0.2961737714940682, 1.0643577994778752, 0.9133450558874756, 2.302532996982336, 0.8935553021728992, 0.8254642027895898, 0.2516721625579521, 0.18889684433816, 12.685108222067356, 39.95526261627674, 34.84322212636471, 42.11092494428158, 46.10533520579338, 40.20077504217625, 40.852907449007034, 62.248001396656036, 63.73126320540905, 74.74050745368004, 54.691381081938744, 1.5536799863912165, 0.11809026371338405, 0.03414415885345079, 0.012558073794934899, 0.034158244816353545, 0.09050369946635328, 0.04505820856138598, 0.058730194068630226, 0.017142945252999198, 0.03681207585032098, 0.012200597029732307, 0.022998670392553322, 0.006482034696091432, 0.04051352996611968, 0.06418345437850803, 0.012474924496927997, 0.06392184732249007, 0.0515207043645205, 0.03926000172214117, 0.005040640116931172, 0.031472345581278205, 0.036096500771236606, 0.1249308095430024, 0.12369661053526215, 0.09437897941097617, 0.19440208096057177, 0.19967355590779334, 0.15733095846371725, 0.24943933705799282, 0.12286209515878, 0.12775622511981055, 0.13943915837444365, 0.14348567405249923, 0.11867822278873064, 0.1291930378647521, 0.20533822069410235, 0.1800457833451219, 0.17935368610778823, 0.11552791722351685, 0.07816748329787515, 0.584794320166111, 79.58028495311737, 106.08308002352715, 96.67915463447571, 80.40999323129654, 59.01934504508972, 31.899170503020287, 37.11532160639763, 48.91977198421955, 65.99904611706734, 45.57288117706776, 1.2313578883185983, 0.27025574818253517, 0.380300396354869, 2.111575431190431, 0.677564264042303, 4.371150070801377, 6.192175755277276, 7.051720507442951, 0.9934609662741423, 74.44131150841713, 93.39651837944984, 83.14284458756447, 82.38809868693352, 75.32863229513168, 67.40699216723442, 72.31702789664268, 70.68170964717865, 68.7487305700779, 63.22615250945091, 60.66469095647335, 62.041930854320526, 63.884824365377426, 59.42625381052494, 61.01591370999813, 57.79509253799915, 57.58712589740753, 57.31295920908451, 64.69586044549942, 72.34557196497917, 75.24559155106544, 72.12927237153053, 70.84152147173882, 73.18105593323708, 74.02128964662552, 64.96372327208519, 56.828207820653915, 53.62353578209877, 57.74094544351101, 52.79232278466225, 56.252109333872795, 56.19698949158192, 58.45744639635086, 54.096633195877075, 55.51589123904705, 53.19267690181732, 65.36603808403015, 72.72994413971901, 75.89417114853859, 71.12608060240746, 63.09565231204033, 54.92213509976864, 57.386694252491, 51.07440076768398, 55.239748656749725, 52.697814255952835, 56.51752509176731, 59.32103745639324, 75.56839942932129, 57.68790028989315, 50.10727286338806, 75.06359651684761, 63.114856481552124, 62.87645727396011, 54.58167336881161, 54.962880313396454, 53.51107321679592, 54.657597094774246, 54.155853018164635, 54.77687269449234, 54.28104110062122, 56.07487544417381, 56.4191597700119, 56.64609879255295, 51.49052023887634, 53.28161492943764, 53.13826762139797, 52.54753991961479, 52.131036669015884, 56.309391260147095, 53.27598363161087, 55.65477378666401, 54.610114842653275, 58.801761120557785, 68.47967460751534, 71.98229625821114, 72.34844461083412, 72.68753841519356, 73.46358597278595, 66.11158847808838, 58.00144046545029, 55.34606695175171, 57.25082114338875, 57.90372110903263, 63.700002282857895, 73.19311648607254, 75.65843939781189, 75.4222896695137, 73.60465720295906, 78.81807625293732, 75.3795799612999, 67.63262405991554, 66.37783259153366, 64.65950399637222, 71.66179105639458, 49.84531491994858, 3.2669974816963077, 2.7107035322114825, 7.779234694316983, 5.914775915443897, 3.0380915896967053, 0.686590145342052, 0.9646284696646035, 0.46355627418961376, 0.6467134819831699, 20.398340933024883, 47.71929480135441, 54.59189862012863, 57.156061828136444, 58.11185114085674, 55.51364175975323, 46.83009311556816, 74.37600821256638, 72.56414383649826, 86.43764778971672, 62.036098167300224, 1.2586038513109088, 0.2558742620749399, 0.1397557882592082, 0.13896071061026305, 0.09237135120201856, 0.2141048846533522, 0.17428239807486534, 0.19722709577763453, 0.1757489115698263, 0.10485827529919334, 0.14489385474007577, 0.07577139273053035, 0.14411344192922115, 0.1935926204896532, 0.24524008738808334, 0.09744462819071487, 0.15712858963524923, 0.13584939006250352, 0.11898921235115267, 0.12721139966743067, 0.11328220061841421, 0.13366498227696866], [0.04266114949132316, 0.044128160225227475, 0.004296305423849844, 0.042017091473098844, 0.03715618004207499, 0.03429508571571205, 0.026561634185782168, 0.04445228951226454, 0.030366710670932662, 0.04658835008740425, 0.08973910182248801, 0.049021822633221745, 0.07830851362086833, 0.0318109653017018, 0.010613850972731598, 0.06133651651907712, 0.07057653710944578, 0.10750919711426832, 6.447588549926877, 88.40376108884811, 76.10312953591347, 76.10977917909622, 64.46990177035332, 50.355167761445045, 32.092804312705994, 64.79607626795769, 60.138392597436905, 44.9380986392498, 8.276845067739487, 0.08109276968752965, 0.13186714437324554, 0.11164206909597851, 0.17301282088737935, 1.1139775556512177, 1.9800500012934208, 1.2179685942828655, 1.3634834485128522, 26.972465068101883, 95.76613202691078, 76.02040037512779, 81.60922408103943, 69.5361015200615, 61.826144233345985, 63.11734154820442, 65.42244225740433, 61.45823657512665, 60.826372280716896, 56.07738330960274, 56.1830860376358, 51.84164419770241, 54.50825370848179, 54.773593470454216, 52.920459508895874, 50.25384619832039, 52.648378908634186, 51.506239995360374, 55.35160705447197, 63.19939814507961, 67.61215075850487, 67.21938863396645, 67.63240367174149, 65.75825303792953, 65.0515365600586, 59.143902361392975, 53.225111961364746, 48.873254880309105, 50.25789678096771, 47.0644873380661, 56.101189032197, 56.81452475488186, 54.713172912597656, 52.31367386877537, 50.57261109352112, 53.23305353522301, 64.37746033072472, 67.8593198955059, 70.66866874694824, 62.07717016339302, 59.78173993527889, 50.75991824269295, 48.576707392930984, 46.69810339808464, 47.035111114382744, 49.201067090034485, 53.65842550992966, 52.33038157224655, 68.39854896068573, 46.785076931118965, 40.72743818163872, 70.46844989061356, 56.42205901443958, 59.77939546108246, 54.11956116557121, 54.356117472052574, 48.24838601052761, 50.18195405602455, 47.45796762406826, 51.95339620113373, 51.44968003034592, 50.96489444375038, 47.77531519532204, 50.66439896821976, 46.95924438536167, 47.60441176593304, 44.83231231570244, 47.151270881295204, 46.768019646406174, 48.67212787270546, 49.10931721329689, 47.463716715574265, 47.96031206846237, 48.36127795279026, 58.24797883629799, 64.90981936454773, 65.90628549456596, 68.0314202606678, 63.3527959138155, 63.617474511265755, 56.13159120082855, 50.16568332910538, 48.7319328635931, 51.746406108140945, 57.83367566764355, 67.7366852760315, 66.43271684646606, 67.47646003961563, 63.35625372827053, 58.50207880139351, 58.791110292077065, 67.08457946777344, 61.195165291428566, 62.455048486590385, 69.1059798002243, 73.38903397321701, 59.999217465519905, 12.753039076924324, 0.19032644340768456, 1.4154393668286502, 3.4628121368587017, 1.0856425948441029, 0.10509433763218112, 0.29469247441738844, 0.04264516363036819, 0.8105627086479217, 14.339454900473356, 24.732939340174198, 42.63383008539677, 105.57082951068878, 70.44924572110176, 24.167240895330906, 34.881413877010345, 47.99799844622612, 54.54022899270058, 59.702540785074234, 14.914769679307938, 0.3791791299590841, 0.12105903253541328, 0.1629627906368114, 0.026225645378872287, 0.05223492502409499, 0.035685781404026784, 0.031991336873034015, 0.13559035083744675, 0.0322936395969009, 0.018012525251833722, 0.014861689051031135, 0.05140957517141942, 0.05973348124825861, 0.032542195986025035, 0.012437046207196545, 0.07010942194028758, 0.020459055886021815, 0.07387971025309525, 0.03859474054479506, 0.11885965563124046, 0.038709688087692484, 0.06830280442954972, 0.12748301087412983, 0.0729969033272937, 0.040444718033540994, 0.061453768430510536, 0.06166472019685898, 0.059686224994948134, 0.012235858321218984, 0.029181146455812268, 0.07615611466462724, 0.06416112315491773, 0.01897571604786208, 0.08158658733009361, 0.03732207231223583, 0.06824280178989284, 0.034442053220118396, 0.04723157690023072, 0.2622382971458137, 8.426690977066755, 101.03370577096939, 85.86536049842834, 87.32514336705208, 70.92704728245735, 56.290422677993774, 38.887964487075806, 38.30320246517658, 51.820118352770805, 50.824488177895546, 9.95304437354207, 0.08816092478809878, 0.13777265092357993, 0.4889699933119118, 0.8148942980915308, 1.7338384129106998, 2.5555623695254326, 0.6138506485149264, 0.42912175005767494, 29.992928691208363, 97.98690006136894, 78.47959041595459, 86.61338075995445, 72.93510273098946, 65.58755099773407, 67.46237799525261, 68.8523206114769, 64.63270023465157, 63.38415563106537, 59.92635637521744, 60.12613445520401, 54.912707805633545, 56.55504047870636, 58.11030462384224, 55.126168951392174, 53.822964280843735, 54.23996530473232, 55.128931403160095, 59.35634896159172, 64.73819777369499, 70.2391853928566, 71.06754094362259, 68.80372881889343, 68.53797107934952, 66.42999619245529, 62.11840935051441, 56.12771160900593, 50.99902421236038, 52.05939531326294, 51.441841050982475, 60.39403147995472, 59.113450795412064, 58.24582815170288, 55.18573455512524, 53.09778459370136, 55.43644890189171, 69.12388443946838, 70.29940456151962, 73.24378296732903, 64.37199622392654, 62.19469025731087, 52.4398422986269, 51.87607415020466, 49.27476793527603, 51.928233951330185, 52.47849002480507, 55.04966765642166, 55.744372978806496, 71.57692641019821, 50.43842889368534, 42.97210693359375, 72.25565358996391, 60.783168599009514, 61.58755883574486, 57.86900997161865, 55.40031284093857, 50.215187072753906, 52.384923845529556, 50.17490163445473, 53.23696352541447, 52.63881862163544, 53.458408042788506, 50.91445595026016, 52.36665062606335, 48.05351346731186, 49.19274553656578, 47.48137816786766, 50.04030525684357, 49.35092344880104, 50.4122406989336, 50.16933113336563, 50.515959933400154, 49.52468432486057, 51.14331007003784, 59.246006682515144, 67.14382588863373, 67.82892912626266, 70.33999398350716, 66.40026658773422, 67.6882378757, 57.95237749814987, 52.95873485505581, 52.51089088618755, 53.65905627608299, 62.43711344897747, 71.07725322246552, 69.66226994991302, 70.00900894403458, 65.64878091216087, 63.18740598857403, 64.72110629081726, 67.51361444592476, 62.53787264227867, 68.06422010064125, 73.3178561925888, 75.33750101923943, 68.73872190713882, 18.367351815104485, 0.7463709719013423, 0.9780698921531439, 1.3846422568894923, 1.8019282654859126, 0.9959626570343971, 1.0184525814838707, 0.030654849506390747, 0.5044391413684934, 25.358264185488224, 31.952899619936943, 30.656342692673206, 83.89943718910217, 63.9602655172348, 38.5269420593977, 44.706683456897736, 55.63628017902374, 60.126628428697586, 73.71375694870949, 25.458647198975086, 0.37280399235896766, 0.11585685933823697, 0.07297992298845202, 0.10077414015540853, 0.02768988790194271, 0.03743332395970356, 0.02874123656511074, 0.02817265867633978, 0.035982948465971276, 0.0647286805906333, 0.017264503476326354, 0.09243833745131269, 0.04480423449422233, 0.03733191690116655, 0.04193409709841944, 0.028015586831315886, 0.03612204920500517, 0.11018700693966821, 0.03915022694854997, 0.05931173356657382, 0.06269874342251569, 0.14913534745573997, 0.3270199819235131, 0.1621301009436138, 0.13714353233808652, 0.14002215990331024, 0.11366642531356774, 0.11794899590313435, 0.10101562016643584, 0.14627543685492128, 0.16465923632495105, 0.1732066401746124, 0.10128089343197644, 0.2269550084020011, 0.13661372795468196, 0.13931311201304197, 0.25514389970339835, 0.21559275715844706, 0.31389596115332097, 10.322373155504465, 114.6364438533783, 96.40188351273537, 99.7053350508213, 83.99679556488991, 67.78526946902275, 45.540525913238525, 87.73824959993362, 77.997677475214, 68.09214100241661, 14.727282989770174, 0.28508765855804086, 0.28902911581099033, 1.8929883604869246, 0.6238920846953988, 3.0891902977600694, 5.8741850685328245, 6.672737868502736, 5.037571610882878, 34.36895437538624, 102.37491980195045, 80.79467698931694, 90.71625620126724, 75.69203719496727, 67.55341351032257, 72.37274050712585, 72.79498144984245, 68.84359627962112, 67.36343890428543, 63.062043115496635, 63.118295297026634, 57.47646063566208, 59.55649942159653, 59.972934275865555, 59.4000618159771, 56.481134444475174, 58.5407455265522, 58.9875103533268, 61.013713628053665, 67.67514377832413, 74.45446640253067, 74.930839240551, 69.45189043879509, 71.01333305239677, 70.02195864915848, 65.87641909718513, 60.20748049020767, 52.78575673699379, 54.15562503039837, 52.716174870729446, 63.15576508641243, 63.66637408733368, 61.29536211490631, 58.96003022789955, 54.42976891994476, 57.762174904346466, 72.63621836900711, 74.19272884726524, 75.19567742943764, 67.64800563454628, 64.8662357032299, 55.88145822286606, 54.31780032813549, 53.23035567998886, 55.40285490453243, 54.36363346874714, 57.96119302511215, 58.69530223309994, 75.49596011638641, 55.12581557035446, 47.022370398044586, 74.2501513659954, 64.01432141661644, 65.74046239256859, 60.92094540596008, 58.61827276647091, 53.44448558986187, 55.110658183693886, 51.87008947134018, 57.47750177979469, 56.33621782064438, 55.841640159487724, 53.71845468878746, 55.928970873355865, 50.93863785266876, 52.837023586034775, 48.776268884539604, 52.90139593183994, 52.35265597701073, 53.50790038704872, 52.81953312456608, 51.82559385895729, 52.18002364039421, 53.21429394185543, 62.2051776945591, 71.10032558441162, 71.4315690100193, 72.70279079675674, 68.1364618241787, 71.24307632446289, 61.58244051039219, 55.29266841709614, 54.752326011657715, 56.50764562189579, 64.9008746445179, 74.28118050098419, 73.22706386446953, 71.125518232584, 69.8713119328022, 67.21447929739952, 64.79453355073929, 69.23359215259552, 63.14214661717415, 68.09771910309792, 74.98082175850868, 77.19377741217613, 67.68376931548119, 16.303460262715816, 1.2278243154287338, 5.212667165324092, 9.92253391072154, 4.064872255548835, 0.8770280296448618, 1.4547749748453498, 0.12778404081473127, 1.9549611350521445, 26.79540976881981, 43.116233199834824, 54.19116072356701, 113.27512130141258, 76.9154803454876, 38.759155198931694, 49.75609950721264, 66.91153675317764, 67.76656687259674, 84.10024881362915, 24.96066302061081, 0.5724186217412353, 0.19638000841950998, 0.28044546546880156, 0.2553592115873471, 0.1405625176266767, 0.10139139179955237, 0.05944678217929322, 0.2593398839235306, 0.12001627052086405, 0.19555416132789105, 0.10864936601137742, 0.18060168164083734, 0.14037888060556725, 0.062237962483777665, 0.1752540623419918, 0.15544146532192826, 0.10753133537946269, 0.3625256032682955, 0.177131695963908, 0.1108231462421827, 0.13268010778119788], [0.030222889872675296, 0.01619871261937078, 0.02346110632061027, 0.0143467090674676, 0.018144237910746597, 0.046056326682446525, 0.01924829946801765, 0.06273308259551413, 0.039647992816753685, 0.029123754320607986, 0.07896552211605012, 0.10231485357508063, 0.08494545123539865, 0.02626841906021582, 0.06553155079018325, 0.07098652917193249, 0.1267774510779418, 0.12339199602138251, 26.910853274166584, 85.69005310535431, 72.74342581629753, 64.04129236936569, 48.69061008095741, 28.873712047934532, 37.1871567517519, 104.37374174594879, 61.701605916023254, 36.71415813267231, 1.0569138801656663, 0.016876896443136502, 0.0434150193905225, 0.7814562111161649, 0.7475677889306098, 3.5844020498916507, 2.3885627556592226, 1.604753164574504, 3.6528299655765295, 81.7915990948677, 82.49678045511246, 78.08638751506805, 73.24971064925194, 66.88031002879143, 59.27245706319809, 57.76135414838791, 60.323271676898, 61.39406181871891, 58.598099648952484, 55.265575870871544, 53.17646697163582, 56.38173557817936, 52.54338674247265, 52.26849429309368, 51.86946630477905, 52.67713576555252, 50.0024288892746, 52.219978496432304, 50.881545916199684, 60.01165419816971, 64.60166350007057, 68.97355690598488, 64.8825292289257, 65.451829880476, 66.46614745259285, 58.67149271070957, 48.779673501849174, 48.93123596906662, 47.554288655519485, 50.16738943755627, 58.89666482806206, 59.42153446376324, 59.281671568751335, 55.40141098201275, 55.75538858771324, 60.97793094813824, 63.85480597615242, 68.37635055184364, 64.45129036903381, 63.34635145962238, 59.35486704111099, 49.63420584797859, 48.130162954330444, 45.84677428007126, 50.90534403920174, 51.07163451611996, 58.69554162025452, 52.804155349731445, 68.63013133406639, 45.042574033141136, 35.27894854545593, 69.42244961857796, 58.76513868570328, 66.88813000917435, 59.02022659778595, 60.88675484061241, 51.669528633356094, 48.036205396056175, 45.37990853190422, 48.799679428339005, 47.806355729699135, 47.48979091644287, 47.275550812482834, 46.936943382024765, 45.64141809940338, 47.0127759128809, 47.10465118288994, 47.84761391580105, 45.96292644739151, 46.8119490891695, 46.587118953466415, 49.61890026926994, 46.28370903432369, 48.969777300953865, 50.458275228738785, 60.395065024495125, 63.78539890050888, 68.23026359081268, 65.4072430729866, 64.59521904587746, 58.719506934285164, 48.41487407684326, 50.162723287940025, 51.2279087305069, 59.82587456703186, 67.58422985672951, 66.93385675549507, 63.76194655895233, 61.71895958483219, 67.56903827190399, 72.14351400732994, 69.60092604160309, 67.26132318377495, 70.63537493348122, 69.64105188846588, 69.03450563549995, 71.7255288362503, 70.05682557821274, 22.71445345133543, 0.20993980346247554, 2.0945468824356794, 3.291728929616511, 0.6633950618561357, 1.135937764775008, 0.0915812978928443, 0.14871238265186548, 10.240746885538101, 19.59568340331316, 56.316166296601295, 84.40835148096085, 72.6116792857647, 22.18773141503334, 28.243453167378902, 53.30082289874554, 55.729056000709534, 65.39252266287804, 52.28969715535641, 1.6899136011488736, 0.15303692169254646, 0.04673511350119952, 0.07664389864658006, 0.016939422384893987, 0.01339859314612113, 0.017562540706421714, 0.05832284405187238, 0.022889745378051884, 0.03036483674804913, 0.021036752914369572, 0.027505061589181423, 0.043346214879420586, 0.05935271496127825, 0.05310200584062841, 0.029827547805325594, 0.01594397228473099, 0.049530483229318634, 0.0660673294623848, 0.02639373626152519, 0.05716302308428567, 0.030883067338436376, 0.0368521072959993, 0.005464158748509362, 0.02478214959410252, 0.07952306055813096, 0.014756702057638904, 0.058820082995225675, 0.015070194513100432, 0.10745363251771778, 0.05945429271378089, 0.04492403197218664, 0.026458093452674802, 0.11199781016330235, 0.06945602028281428, 0.050333705949014984, 0.11573632713407278, 0.16794824186945334, 0.030417020861932542, 36.804741472005844, 98.3159852027893, 79.35665935277939, 72.61927887797356, 60.35089239478111, 42.713800594210625, 37.606908828020096, 90.08476808667183, 52.89194583892822, 41.31617099046707, 1.8333224183879793, 0.12165896245278418, 0.2591261750785634, 1.597450312692672, 1.2098574545234442, 3.046835158020258, 1.9175020325928926, 0.9884568129200488, 5.091688307002187, 85.64561828970909, 84.24160122871399, 83.27907487750053, 76.80823490023613, 70.69737240672112, 61.46526239812374, 61.187865883111954, 62.397774159908295, 64.64227572083473, 60.25647506117821, 57.499061822891235, 55.488145127892494, 58.3347699791193, 54.04421880841255, 54.46403928101063, 54.27105523645878, 56.68370917439461, 53.866775929927826, 54.29953470826149, 55.23572847247124, 62.922480404376984, 67.75648221373558, 70.72279304265976, 67.62676477432251, 67.84732013940811, 68.71533036231995, 62.2176144272089, 51.771651953458786, 50.67459002137184, 49.77074012160301, 53.059566244482994, 61.928119361400604, 63.9214164018631, 62.117983773350716, 59.00216616690159, 57.90456086397171, 64.24463465809822, 65.66305294632912, 70.60040161013603, 66.28443360328674, 67.50365898013115, 61.05695530772209, 53.05120289325714, 50.25739140808582, 48.40483121573925, 54.93069604039192, 55.184568017721176, 63.12953509390354, 55.935187339782715, 70.68608701229095, 48.86702321469784, 37.635737881064415, 72.42874950170517, 61.08471281826496, 68.93597692251205, 61.856132224202156, 64.11619395017624, 52.98307254910469, 50.116966143250465, 48.97703871130943, 49.68426056206226, 49.12687987089157, 49.89471226930618, 50.35417981445789, 48.266758024692535, 47.955410331487656, 49.09488558769226, 49.14570406079292, 50.86369447410107, 47.467660903930664, 48.49770963191986, 48.39661605656147, 49.920087307691574, 48.891391307115555, 50.47473594546318, 54.2301694303751, 64.44944366812706, 66.45921662449837, 70.93128025531769, 67.9747349023819, 68.395866304636, 63.04943539202213, 52.21840538084507, 52.68562451004982, 53.0781776458025, 62.76880905032158, 70.74784889817238, 69.43464696407318, 67.01981574296951, 65.25249257683754, 70.40370136499405, 73.34693223237991, 71.74472540616989, 68.45883652567863, 71.99561834335327, 72.16241419315338, 70.36911562085152, 73.97889912128448, 75.59109181165695, 28.114596381783485, 0.6356925889849663, 1.0508739855140448, 3.131975051946938, 2.0645254058763385, 2.1962182642892003, 0.23405069718137383, 0.15474982821615413, 8.50164670497179, 31.28405001014471, 42.149929851293564, 74.23549935221672, 62.90696583688259, 29.371565133333206, 37.94609762728214, 59.71050515770912, 64.62221279740334, 70.44603869318962, 67.1186712384224, 4.269322184845805, 0.31968717696145177, 0.017154622946691234, 0.07355234891292639, 0.07387946534436196, 0.01941634211107157, 0.029504539161280263, 0.05301727484038565, 0.02762916723440867, 0.022739757332601584, 0.11545281930011697, 0.047787686708034016, 0.05740298540331423, 0.07334723413805477, 0.03301344491774216, 0.013840821320627583, 0.02277821728057461, 0.05485951915034093, 0.03655668428109493, 0.06424252191209234, 0.016283985387417488, 0.0924985998426564, 0.16565506492042914, 0.08790409716311842, 0.15817963401786983, 0.19222709845053032, 0.11283423285931349, 0.13998502283357084, 0.2180111047346145, 0.15141008945647627, 0.1982622136711143, 0.14179786696331576, 0.2622124704066664, 0.22899346542544663, 0.1742291564005427, 0.15720229974249378, 0.29625689203385264, 0.23350352654233575, 0.1981740168412216, 43.816638216376305, 108.53201061487198, 92.77937069535255, 83.72510254383087, 67.63504073023796, 43.52234400808811, 50.15445873141289, 131.86933994293213, 81.3401985168457, 57.14492082595825, 2.4801121931523085, 0.34938718483317643, 0.46490472683217376, 2.0432819332927465, 2.704278789460659, 9.363901186734438, 9.666092321276665, 5.452255234122276, 4.942324971780181, 91.13345101475716, 86.53458818793297, 87.45043784379959, 78.56508582830429, 75.8306385576725, 63.16524177789688, 65.44753611087799, 66.80651798844337, 68.93102198839188, 63.995710015296936, 61.81275375187397, 58.59350569546223, 64.69217464327812, 58.30774962902069, 57.00009919703007, 57.87713013589382, 61.174361407756805, 55.19229680299759, 57.752922400832176, 56.7623383551836, 65.6021574139595, 71.32401958107948, 74.76007640361786, 68.28067928552628, 69.80698138475418, 71.19168788194656, 65.65691247582436, 54.58833061158657, 54.00826133787632, 53.19006264209747, 57.642610520124435, 63.66481237113476, 67.01806023716927, 64.52578157186508, 61.555940732359886, 60.17604477703571, 68.17920953035355, 70.3513553738594, 72.80182108283043, 68.45745339989662, 71.85841530561447, 65.4044996201992, 57.00461335480213, 52.38105945289135, 50.892892107367516, 57.34960824251175, 56.20428889989853, 64.7188188135624, 60.823431238532066, 73.25882256031036, 53.65458771586418, 43.23002949357033, 72.9386593401432, 64.4966371357441, 72.64655381441116, 63.8596773147583, 66.43779337406158, 56.99888326227665, 52.29076489806175, 52.111467719078064, 53.53124253451824, 53.2456498593092, 51.86791218817234, 52.90294624865055, 51.04760840535164, 49.59861695766449, 51.81014768779278, 52.88720369338989, 54.20232452452183, 50.83620674908161, 49.32111784815788, 50.52318334579468, 54.639278277754784, 52.69298851490021, 52.95356333255768, 56.41579695045948, 67.55332231521606, 69.39816132187843, 74.37660098075867, 70.04057765007019, 72.40232571959496, 65.48869550228119, 54.09587323665619, 56.387442871928215, 55.18263392150402, 64.57903951406479, 73.80378171801567, 71.5753684937954, 70.84180265665054, 69.69961434602737, 72.67917886376381, 77.68325194716454, 74.3557932972908, 71.04683965444565, 73.52698177099228, 73.97755399346352, 74.64464619755745, 76.13819405436516, 80.10482400655746, 26.35253593325615, 0.6846632924862206, 6.371051631867886, 9.514555502682924, 3.1907085003331304, 3.421757952310145, 0.6279725907370448, 0.6519362423568964, 16.919412910938263, 36.31049819290638, 75.37834122776985, 88.06395292282104, 75.61726480722427, 30.92594012618065, 43.0102226883173, 71.38434514403343, 73.5877177119255, 79.55185487866402, 73.60711947083473, 3.5392996575683355, 0.3250735660549253, 0.07803137341397814, 0.27367265545763075, 0.15069871122250333, 0.21251407626550645, 0.22438824613345787, 0.12245627396623604, 0.1690924703143537, 0.11431077276938595, 0.2055515584652312, 0.13324096362339333, 0.2469039973220788, 0.21655754913808778, 0.1974509868887253, 0.11589006302529015, 0.16659545508446172, 0.14412556862225756, 0.14777151751331985, 0.17989484535064548, 0.16758034442318603], [0.058145882649114355, 0.029207804400357418, 0.06478021532529965, 0.05173145575099625, 0.16736383026000112, 0.00865527037603897, 0.0592518274061149, 0.03921906856703572, 0.02325431243662024, 0.0238675527725718, 0.025302743924839888, 0.02843521382601466, 0.05696497726603411, 0.05207140762649942, 0.014255281112127705, 0.010965104829665506, 0.06770156833226793, 1.1832196963950992, 69.88524958491325, 75.5844497680664, 79.69721987843513, 65.59388905763626, 44.64291527867317, 20.68779230117798, 64.22356098890305, 73.90929445624352, 61.7917674779892, 13.50964592769742, 0.04994476490537636, 0.060132689905003645, 0.15643233637092635, 0.16343412862624973, 1.4759011287242174, 1.685169436968863, 0.40822126844432205, 0.5121540930122137, 35.74226148426533, 94.5954604446888, 72.67017334699631, 77.50469952821732, 65.41652217507362, 63.347544595599174, 56.38218395411968, 64.27395388484001, 59.96081292629242, 59.75788101553917, 56.945841908454895, 55.29543846845627, 54.10918012261391, 53.10360208153725, 51.16452053189278, 52.48965002596378, 51.14889957010746, 52.585461884737015, 50.79887755215168, 51.668362095952034, 51.5419352799654, 58.023699671030045, 65.76709896326065, 66.60531878471375, 69.98719811439514, 66.51443526148796, 66.82227954268456, 56.5129691362381, 48.51363077759743, 50.315919667482376, 49.30032916367054, 54.10676345229149, 61.52219474315643, 61.40287734568119, 62.33141832053661, 62.30901852250099, 61.7849962413311, 60.267517268657684, 69.99330058693886, 61.2929530441761, 59.01459150016308, 64.51340943574905, 57.30303034186363, 48.917469307780266, 47.78152026236057, 45.3064888715744, 50.66370740532875, 55.06348371505737, 62.73772671818733, 56.67439587414265, 66.40031218528748, 46.11226223409176, 35.82027889788151, 66.71072512865067, 56.42397791147232, 63.18975426256657, 60.45168578624725, 65.5731649696827, 50.20378388464451, 47.28270202875137, 46.460540145635605, 46.41753405332565, 45.28695411980152, 47.763452231884, 48.64981546998024, 46.87279522418976, 46.19893938302994, 49.10530462861061, 46.82691268622875, 48.95721897482872, 47.93448105454445, 46.811838895082474, 46.30323238670826, 48.51216025650501, 47.54341743886471, 48.55734743177891, 47.62431129813194, 56.85958653688431, 66.54609516263008, 63.028582111001015, 64.58821222186089, 65.95196664333344, 60.99243476986885, 49.58665519952774, 48.041042536497116, 49.66272331774235, 59.746884405612946, 67.15376615524292, 67.75818452239037, 64.60588127374649, 66.1639952659607, 69.76089745759964, 64.58375126123428, 71.6884808242321, 68.14943432807922, 66.71076312661171, 67.96156480908394, 66.53718084096909, 69.50723066926003, 70.83544179797173, 65.65707966685295, 17.504497915506363, 0.4791742376983166, 1.0774517781101167, 1.5002293232828379, 0.6977496121544391, 0.5655719828791916, 0.12439241108950227, 6.603697473183274, 20.249552316963673, 24.5692840218544, 47.64429062604904, 40.12459293007851, 28.402681723237038, 29.950262680649757, 43.01217578351498, 46.07313573360443, 56.11449591815472, 57.83331088721752, 26.49636961519718, 0.6255834095645696, 0.12713102507404983, 0.07025319820968434, 0.0993955266312696, 0.02783905772957951, 0.017802410256990697, 0.026613295085553546, 0.03453444689512253, 0.03501640872855205, 0.009149371890089242, 0.04818041641556192, 0.010509701678529382, 0.05673075174854603, 0.1047813962213695, 0.09740648922161199, 0.078950367460493, 0.07149187236791477, 0.03957134009397123, 0.042795674889930524, 0.07769869087496772, 0.0020582992692652624, 0.04955330427037552, 0.09945206344127655, 0.06166307633975521, 0.0765605406195391, 0.03752406264538877, 0.07417777902446687, 0.033167496221722104, 0.01472468487918377, 0.02847822499461472, 0.02855382757843472, 0.022860990866320208, 0.008173610967787681, 0.10421055849292316, 0.045098206610418856, 0.06291319441515952, 0.050706323454505764, 2.0787791535258293, 82.50494241714478, 85.82198962569237, 88.89036297798157, 73.37910890579224, 50.54564394056797, 26.26109004020691, 49.71752017736435, 74.18628439307213, 63.27178806066513, 15.381247848272324, 0.10384112480096519, 0.08967481699073687, 0.593702585902065, 1.8215857981704175, 3.506354237906635, 3.8102246448397636, 1.079096021130681, 0.19660340971313417, 39.293235540390015, 96.79483562707901, 77.629963606596, 79.92830067873001, 68.81783366203308, 67.05472826957703, 60.510221645236015, 68.09328094124794, 63.976817429065704, 62.53650091588497, 60.73147237300873, 59.176857993006706, 57.12375596165657, 57.43021331727505, 54.502333626151085, 55.75992934405804, 54.54323463141918, 54.78977680206299, 54.05084565281868, 55.13442970812321, 53.65017995238304, 61.53105206787586, 68.7109985947609, 69.89636018872261, 72.10116907954216, 67.99063324928284, 69.60080444812775, 59.55683380365372, 51.934606209397316, 52.7926267683506, 50.96365951001644, 58.618493154644966, 65.26826933026314, 64.37482327222824, 64.2597958445549, 64.23768103122711, 64.69502449035645, 63.93694996833801, 72.49221369624138, 65.55146053433418, 62.02174633741379, 66.88452780246735, 60.76877877116203, 51.95600666105747, 50.911663100123405, 48.44942942261696, 53.2735213637352, 56.35553598403931, 65.56538298726082, 60.17764829099178, 68.38250622153282, 48.944831639528275, 39.824770018458366, 68.39365482330322, 58.93087439239025, 66.37402519583702, 62.034460455179214, 67.00431257486343, 54.194466546177864, 48.17919932305813, 49.116791412234306, 47.342499420046806, 47.52721130847931, 47.333957478404045, 50.51772303879261, 48.834880739450455, 48.365389332175255, 51.49900898337364, 51.34365811944008, 50.965532809495926, 51.022727340459824, 48.00362594425678, 48.838258758187294, 49.56901274621487, 48.626701310276985, 51.05653032660484, 51.670600175857544, 58.92579406499863, 68.24260532855988, 66.38283312320709, 66.32605656981468, 69.32151943445206, 61.91666677594185, 54.13574069738388, 50.2483706921339, 52.44570158421993, 62.0001444965601, 69.20746475458145, 68.61998587846756, 67.77594476938248, 69.92817208170891, 71.94355353713036, 67.95703545212746, 71.83817759156227, 69.84642326831818, 70.49479767680168, 69.47843581438065, 71.18998557329178, 72.72425964474678, 71.62274435162544, 69.72576454281807, 23.772654868662357, 1.0426327027380466, 1.2452430557459593, 2.1351861767470837, 1.118601313792169, 0.8817452390212566, 0.09445348361623473, 1.0203205375000834, 23.4981556981802, 29.365126378834248, 45.561466589570045, 43.13819222152233, 23.369188718497753, 41.68141879141331, 49.409014731645584, 54.00183968245983, 61.24024227261543, 68.45873013138771, 40.55168241262436, 0.5334344354923815, 0.0746116014488507, 0.05452531891933177, 0.07295863077160902, 0.07122757873730734, 0.07080840630806051, 0.04066421191964764, 0.08179585071047768, 0.03555203897121828, 0.022279473632806912, 0.07010913992417045, 0.031081586275831796, 0.030979201437730808, 0.046887951393728144, 0.05429060729511548, 0.06597764833713882, 0.04424325619766023, 0.044670766656054184, 0.05739402025938034, 0.10489664433407597, 0.17367569234920666, 0.22677221742924303, 0.22169994976138696, 0.17908597859786823, 0.37834899325389415, 0.18493730836780742, 0.18992798432009295, 0.1510170628898777, 0.10209376778220758, 0.1270234730327502, 0.17138371767941862, 0.105209318571724, 0.08420941143413074, 0.200474719167687, 0.27153785282280296, 0.15823842695681378, 0.14328378019854426, 2.382241557352245, 97.36991956830025, 94.02346953749657, 100.0674556195736, 82.65834778547287, 65.41734293103218, 29.871204122900963, 85.92169627547264, 83.14349055290222, 86.10819026827812, 23.548976071178913, 0.34593349671922624, 0.2720374072669074, 0.9673110663425177, 2.945524281822145, 5.552456332370639, 5.7454959489405155, 4.113841177895665, 1.8473428348079324, 41.73879191279411, 102.00415849685669, 79.97083559632301, 83.64080026745796, 72.50815764069557, 70.36307394504547, 64.16287064552307, 72.83513009548187, 66.40099614858627, 64.92647007107735, 62.28110522031784, 62.69173018634319, 61.505456641316414, 59.50335167348385, 56.6231632232666, 60.586513951420784, 56.67446427047253, 59.512661173939705, 57.543679028749466, 59.02709662914276, 56.035878136754036, 64.8876665532589, 72.02164694666862, 72.55247086286545, 70.94978526234627, 69.49893191456795, 73.4348139166832, 63.11246261000633, 54.55861620604992, 56.873896569013596, 54.14794564247131, 60.24528466165066, 67.36596196889877, 67.686527967453, 67.30902582406998, 70.41713744401932, 66.16706550121307, 67.29317307472229, 76.04399710893631, 66.90775975584984, 64.46514442563057, 69.3652930855751, 64.02446687221527, 54.29565891623497, 53.52038651704788, 51.02420546114445, 56.26591399312019, 59.95695233345032, 68.0901575088501, 63.13740447163582, 70.44943571090698, 53.442053720355034, 43.6134023219347, 67.41710722446442, 61.84895060956478, 67.2404471039772, 66.70882523059845, 71.59777209162712, 56.11358776688576, 50.10389484465122, 50.960190296173096, 49.858519211411476, 50.34973785281181, 52.249537110328674, 54.85408075153828, 52.146300449967384, 53.25352303683758, 54.85965125262737, 53.219777047634125, 53.02086912095547, 53.22287768125534, 50.04768826067448, 52.49805897474289, 53.02728697657585, 52.074149921536446, 53.468697890639305, 52.35877364873886, 60.299469754099846, 73.70238795876503, 68.2711797952652, 67.70551934838295, 73.11905086040497, 64.66605484485626, 56.62983566522598, 53.088019117712975, 54.719970747828484, 63.93804430961609, 73.09855476021767, 71.81701272726059, 71.41953885555267, 74.68712791800499, 74.84109565615654, 71.42931193113327, 76.31309866905212, 72.42463052272797, 72.5070632994175, 76.25014364719391, 72.766292989254, 77.61827543377876, 73.09003561735153, 73.37191969156265, 21.206350475549698, 1.7032812838442624, 4.7712054289877415, 5.337238730862737, 1.5711788786575198, 1.840075368527323, 0.2903682173928246, 10.221024993807077, 32.5359745323658, 41.95417955517769, 57.95718044042587, 49.255012795329094, 35.549190044403076, 46.03342406451702, 55.697327703237534, 65.60157984495163, 69.78042840957642, 80.71734353899956, 44.39398683607578, 1.0640430101193488, 0.19658245146274567, 0.19790331105468795, 0.20252111717127264, 0.25623230380006135, 0.1576852152356878, 0.12696478399448097, 0.24118925241054967, 0.1255953434156254, 0.07493787925341167, 0.13204019836848602, 0.1077489108138252, 0.12508759566117078, 0.286317634745501, 0.21966357075143605, 0.22659266222035512, 0.17785995063604787, 0.14091876335442066, 0.15659247699659318, 0.2394357355660759], [0.04120194244023878, 0.05869868989975657, 0.10170723500777967, 0.021589769821730442, 0.023684828593104612, 0.028440317946660798, 0.016411065189458895, 0.027695815806509927, 0.021011729550082237, 0.01353688865492586, 0.04423426136781927, 0.009432177466806024, 0.041619318872108124, 0.01919724527397193, 0.05412088554294314, 0.07450768593116663, 0.45385147619526833, 13.41619374230504, 87.07398444414139, 71.97187721729279, 70.84635481238365, 50.219602435827255, 41.30120359361172, 23.623649664223194, 35.1435162127018, 30.618705712258816, 26.26368150115013, 1.4006386860273778, 0.00790901305663283, 0.14618529559811577, 0.40570648619905114, 1.7238171631470323, 0.7335810363292694, 0.464630369679071, 1.2797621847130358, 3.449153294786811, 82.61948347091675, 80.8299694955349, 76.86882644891739, 68.46792563796043, 66.05558708310127, 64.11999374628067, 66.78488194942474, 61.337520852684975, 66.56141594052315, 63.204930648207664, 62.88532219827175, 60.439648032188416, 57.46591240167618, 55.184233635663986, 55.47987677156925, 50.70934675633907, 50.43810211122036, 49.158782958984375, 51.093791127204895, 48.94342191517353, 53.96527424454689, 62.976008132100105, 67.25712060928345, 67.3586967587471, 70.95721006393433, 65.94402506947517, 64.5379789173603, 52.39291861653328, 46.81125372648239, 48.376511335372925, 47.47208006680012, 58.39872054755688, 63.78435775637627, 63.93321096897125, 64.61965173482895, 63.74439150094986, 63.476771861314774, 65.65825760364532, 63.41455020010471, 58.033757731318474, 66.17974922060966, 58.323343992233276, 56.307118982076645, 47.578265368938446, 48.83928470313549, 43.86746808886528, 52.79345892369747, 54.27137441933155, 65.12697011232376, 59.26237240433693, 65.53812325000763, 40.86176857352257, 41.71741425991058, 63.8686828315258, 57.446632236242294, 61.40948139131069, 60.60085438191891, 59.564524590969086, 48.040856346488, 43.626766204833984, 44.76845294237137, 45.471331626176834, 43.49492847919464, 44.738043174147606, 45.47008529305458, 45.32899126410484, 45.724762827157974, 50.88626146316528, 52.16317534446716, 51.337274461984634, 51.001349687576294, 47.49074466526508, 45.25896102190018, 46.477441638708115, 46.88815400004387, 47.443779185414314, 48.6735375970602, 51.86568930745125, 61.654674634337425, 63.041710406541824, 64.19315502047539, 64.74502980709076, 59.12776082754135, 48.99384520947933, 47.94797033071518, 49.33498330414295, 57.8121992200613, 66.08286201953888, 66.4240001142025, 63.05756315588951, 65.28380289673805, 66.72796100378036, 65.78434243798256, 65.28299733996391, 67.3478901386261, 68.28862845897675, 61.45018860697746, 63.15241366624832, 61.40237957239151, 70.90414971113205, 70.84130868315697, 49.17770974338055, 6.907119266688824, 1.0057996166869998, 1.787038764450699, 0.9161045390646905, 0.5458440945949405, 0.06989064422668889, 0.04801657618372701, 20.482688806951046, 39.53229211270809, 24.527328573167324, 14.019546266645193, 24.158117584884167, 16.662288308143616, 25.546764470636845, 55.52109315991402, 54.59146164357662, 57.4650764465332, 54.02559980750084, 5.5743631068617105, 0.3764015680644661, 0.013724141790589783, 0.127969830064103, 0.054225365092861466, 0.028222525434102863, 0.018064833675452974, 0.055350757829728536, 0.01729249914205866, 0.053538288484560326, 0.07297855743672699, 0.0522983972041402, 0.03202940904884599, 0.058231340954080224, 0.05232744857494254, 0.033535100519657135, 0.13382978359004483, 0.04621712781954557, 0.03964853829529602, 0.028489841461123433, 0.044446934916777536, 0.032294136835844256, 0.052437798512983136, 0.005705755183953443, 0.026940721363644116, 0.02349658840103075, 0.017214506842719857, 0.04353111726231873, 0.08244066571933217, 0.06890887932968326, 0.029777580857626162, 0.03407844538742211, 0.017751651066646446, 0.053905235981801525, 0.0707603151386138, 0.12596934131579474, 0.28888543602079153, 20.31348768621683, 101.51155292987823, 80.30264899134636, 79.17209565639496, 59.973192662000656, 54.026823341846466, 30.954698882997036, 37.08026088774204, 32.078904658555984, 35.82758970558643, 1.083060633391142, 0.026665121113182977, 0.25032341305632144, 0.7749770244117826, 2.3474017018452287, 5.455464161932468, 3.5175085393711925, 1.4956553187221289, 4.519365867599845, 85.74822798371315, 82.417151927948, 80.41505455970764, 71.38363838195801, 68.63919004797935, 66.8355256319046, 70.66496774554253, 64.37923863530159, 70.79457119107246, 67.4201774597168, 65.78332409262657, 62.97018304467201, 59.910670816898346, 56.89562380313873, 57.41729021072388, 52.9963718354702, 54.12510886788368, 52.43228830397129, 54.232076928019524, 53.9188027381897, 58.03657338023186, 65.2353934943676, 70.73368325829506, 68.63710016012192, 73.23559820652008, 67.67437621951103, 68.23152512311935, 54.30055305361748, 47.623429745435715, 48.910652473568916, 50.42888380587101, 60.38887515664101, 66.43553629517555, 66.00795283913612, 66.4619828760624, 65.70864289999008, 65.95473289489746, 67.57717743515968, 66.46924808621407, 61.281800642609596, 68.41380894184113, 60.20768187940121, 58.17731022834778, 49.14161168038845, 51.328477934002876, 46.325875371694565, 56.266198977828026, 56.183241829276085, 67.8198704123497, 63.684472516179085, 66.59902632236481, 41.547662168741226, 44.38815414905548, 65.43746665120125, 59.96713198721409, 64.36597734689713, 61.73567108809948, 61.83831498026848, 50.5036485940218, 46.618942245841026, 46.48623816668987, 47.7923496812582, 45.93481935560703, 47.25465193390846, 47.95455917716026, 48.608298897743225, 47.939048409461975, 52.51326575875282, 53.70007507503033, 55.89532367885113, 54.21206720173359, 51.44638940691948, 47.415311112999916, 49.29822027683258, 48.94546240568161, 49.857481867074966, 51.11157037317753, 54.45613570511341, 65.7420127093792, 66.87278643250465, 64.47198405861855, 67.44152471423149, 63.810219168663025, 52.52843074500561, 50.56922547519207, 51.523510068655014, 61.18913121521473, 69.043640345335, 67.40204483270645, 66.18785798549652, 67.3689030110836, 70.19348904490471, 67.53513649106026, 68.10374557971954, 69.99797433614731, 71.70003220438957, 64.88211125135422, 66.8754006922245, 64.44059774279594, 74.62931782007217, 73.44581052660942, 54.83575813472271, 9.802524950355291, 0.12367902163532563, 2.3419456696137786, 2.0697515504434705, 1.3573231478221714, 0.06553550643729977, 0.13253721466753632, 15.803446043282747, 50.511673763394356, 29.359282292425632, 17.858173437416553, 15.816692132502794, 23.93528614193201, 41.31546042859554, 66.08653262257576, 65.1968863606453, 61.603772565722466, 71.72641038894653, 14.5004921592772, 0.33593887521419674, 0.03480791347101331, 0.04136096242291387, 0.02366129137953976, 0.06872053709230386, 0.11507425719173625, 0.028253511954972055, 0.031502836718573235, 0.05927674501435831, 0.07929560713819228, 0.11245977482758462, 0.020109103570575826, 0.06666886241873726, 0.052301844480098225, 0.06864138704258949, 0.03907167803845368, 0.03581657379982062, 0.05761649015767034, 0.023966709268279374, 0.13531350006815046, 0.104083732876461, 0.15727213583886623, 0.11086233163950965, 0.1240417240478564, 0.11271628332906403, 0.09699248956167139, 0.1792550546815619, 0.15051001275423914, 0.14745401189429685, 0.15518155036261305, 0.14716935373144224, 0.12370241413009353, 0.10421721555758268, 0.15158476133365184, 0.17526749521493912, 0.5701328068971634, 25.50023976713419, 116.66874200105667, 90.97138971090317, 93.1524346768856, 68.3563332259655, 58.313859701156616, 35.667732283473015, 51.84873081743717, 46.474303007125854, 43.54855880141258, 3.074949849396944, 0.15900684666121379, 0.6496412248816341, 2.1889461670070887, 5.2588000148534775, 3.5567647079005837, 3.0334954988211393, 4.986825808882713, 4.125498477369547, 91.3534364104271, 85.56868001818657, 84.94500428438187, 73.45935299992561, 71.62893041968346, 69.52169269323349, 73.05625542998314, 65.83639964461327, 72.6687142252922, 67.80252054333687, 68.26553329825401, 66.3523131608963, 63.928058445453644, 60.08270278573036, 61.895817294716835, 55.13513647019863, 56.68022856116295, 55.20240046083927, 57.2266848385334, 56.13566838204861, 61.681789979338646, 68.35009396076202, 73.85854437947273, 70.79710945487022, 73.76120120286942, 73.14563423395157, 71.37199580669403, 57.676782086491585, 51.3595374673605, 52.586902007460594, 53.300108537077904, 64.96591955423355, 69.4785650074482, 68.55589851737022, 69.19805645942688, 69.54402029514313, 69.41421926021576, 70.01945078372955, 67.6102964580059, 62.98360012471676, 71.93898618221283, 64.60561528801918, 61.66842609643936, 52.24593110382557, 53.658896684646606, 47.45434641838074, 61.35989025235176, 60.73095180094242, 71.87283173203468, 64.31306898593903, 67.42672070860863, 45.13353355228901, 49.38285693526268, 66.18931710720062, 63.407288789749146, 63.80174562335014, 65.13579323887825, 67.1551264822483, 53.36828447878361, 48.82150545716286, 48.50662015378475, 50.8517175167799, 49.33385096490383, 49.10099945962429, 50.49642898142338, 50.41749581694603, 49.78834457695484, 57.067488580942154, 57.27447487413883, 56.6144160926342, 57.672245129942894, 53.666990250349045, 51.81896321475506, 51.8291162699461, 51.906616911292076, 53.09431537985802, 52.80266962945461, 56.67082026600838, 68.53505283594131, 70.0120335817337, 68.06620359420776, 70.81207305192947, 65.99337682127953, 54.662441834807396, 53.310580775141716, 53.5822319984436, 62.37598992884159, 74.29672166705132, 69.7102689743042, 69.22057405114174, 71.81298494338989, 73.67049247026443, 72.42684200406075, 71.23816698789597, 73.41082960367203, 73.64726811647415, 67.35815718770027, 70.40778234601021, 67.39742428064346, 78.25024232268333, 75.25439947843552, 56.866889744997025, 9.202828779816628, 3.3086230605840683, 6.540517313405871, 4.535672217607498, 1.8882084544748068, 0.2827647957019508, 0.17541466309921816, 28.98126147687435, 59.54663135111332, 38.355453461408615, 23.665910996496677, 36.088251918554306, 26.59296803176403, 38.85712534189224, 70.52391931414604, 74.07444879412651, 71.14440321922302, 83.10286313295364, 16.502778567373753, 0.7340900308918208, 0.14266971236793324, 0.22365979850292206, 0.14580748305888847, 0.3808104892959818, 0.17016910394886509, 0.11894884693901986, 0.21427995729027316, 0.20341838855529204, 0.1702765966183506, 0.16996023390674964, 0.12229275656864047, 0.21199592360062525, 0.18150301999412477, 0.13683122175280005, 0.19743495649890974, 0.10485443097422831, 0.1349580113310367, 0.16969285294180736], [0.051540152344387025, 0.06706763320835307, 0.03914119501132518, 0.027483348203531932, 0.03558649688784499, 0.005426339366749744, 0.024044684869295452, 0.04828982382605318, 0.03327733036712743, 0.03880663112795446, 0.06669785812846385, 0.0163780655930168, 0.04257254819094669, 0.03593743625970092, 0.014045886000531027, 0.043203548120800406, 0.2569621615111828, 40.15339158475399, 78.15696492791176, 67.90575340390205, 58.906506299972534, 37.555045410990715, 12.042155172675848, 32.081237733364105, 45.624562203884125, 46.03071101009846, 18.184384033083916, 0.02467083486408228, 0.03998269770818297, 0.08992744405986741, 0.22515071381349117, 0.6492009828798473, 1.8580704904161394, 4.655987061560154, 0.5254408519249409, 25.902489982545376, 91.62474185228348, 69.47266772389412, 78.79068732261658, 64.70528393983841, 69.79865223169327, 65.12998715043068, 71.48769199848175, 69.89564582705498, 72.38808408379555, 66.7582605779171, 69.72011804580688, 62.47288092970848, 64.5060758292675, 56.751854717731476, 54.36876319348812, 52.46335543692112, 51.03959463536739, 49.442905113101006, 50.763037875294685, 50.01608155667782, 59.95431907474995, 63.94698902964592, 68.04321482777596, 64.61193054914474, 66.25396683812141, 66.99104368686676, 60.787732154130936, 47.585089802742004, 47.99102962017059, 45.85913121700287, 49.119610860943794, 58.587836399674416, 65.81338807940483, 59.8599549382925, 66.31288647651672, 61.99398122727871, 65.90237930417061, 60.241826847195625, 61.713560074567795, 62.287523075938225, 60.823207050561905, 54.50653240084648, 51.318332478404045, 47.47812174260616, 47.984771355986595, 47.52782687544823, 51.317473724484444, 55.44259697198868, 63.556711971759796, 59.551396295428276, 63.31478275358677, 42.951162457466125, 43.281220346689224, 65.33533573150635, 59.26720954477787, 61.596355363726616, 58.29495191574097, 53.038256987929344, 40.82620248198509, 44.226370230317116, 45.94167038798332, 48.38482528924942, 44.61904115974903, 46.73830524086952, 46.63745865225792, 47.07139156758785, 44.14207935333252, 49.03104901313782, 50.11859245598316, 52.70343795418739, 53.590112775564194, 50.02416752278805, 46.1273018270731, 45.29592543840408, 45.29299959540367, 44.31137926876545, 48.809266313910484, 48.9828409999609, 58.22787031531334, 63.96295577287674, 61.971501633524895, 65.16029432415962, 60.787260979413986, 48.04366819560528, 47.553961873054504, 50.655454248189926, 54.74646292626858, 64.15619060397148, 65.21083161234856, 61.606139838695526, 65.55710703134537, 66.07345372438431, 61.89031898975372, 63.18004958331585, 63.39364752173424, 62.48079590499401, 62.92271979153156, 64.45401102304459, 63.467580154538155, 65.09294673800468, 71.13525331020355, 67.47627004981041, 23.58976498246193, 1.1096095712855458, 1.3633119827136397, 1.6647490952163935, 0.9071008034516126, 0.05267189786536619, 0.0596427425625734, 1.8256974150426686, 48.45617786049843, 39.62050437927246, 26.352496035397053, 23.631786927580833, 20.819084756076336, 18.64178068935871, 30.34478221088648, 49.417986050248146, 57.09441773593426, 57.54171073436737, 38.97125601768494, 0.7973696384578943, 0.047378080562339164, 0.024520952574675903, 0.049484110131743364, 0.015899556601652876, 0.022116958134574816, 0.058088125006179325, 0.011640551983873593, 0.056840355828171596, 0.022736853679816704, 0.029828375299985055, 0.04929140406602528, 0.009157593030977296, 0.08886584633728489, 0.043879722579731606, 0.015054290288389893, 0.033455839147791266, 0.03552183356077876, 0.04772532032802701, 0.04375219563371502, 0.03169828873069491, 0.02706847280933289, 0.04785198638273869, 0.04678356090153102, 0.04724633450678084, 0.05038491413870361, 0.05462528992211446, 0.02763215252343798, 0.10101131570991129, 0.028489017677202355, 0.07451447658240795, 0.04860316599661019, 0.025278518369304948, 0.048165135594899766, 0.08216797839850187, 0.35490318259689957, 54.442376643419266, 86.70312434434891, 74.94283139705658, 69.40947711467743, 47.3025331646204, 22.369625754654408, 31.712934896349907, 42.121024802327156, 53.50551411509514, 24.560920670628548, 0.04413096925418358, 0.08131462731398642, 0.6067631382029504, 1.560374633409083, 1.3669299823231995, 7.960107838734984, 4.929809868335724, 1.0177980666048825, 29.678107984364033, 93.96668538451195, 73.55437830090523, 80.57957053184509, 68.0872468650341, 72.08403199911118, 66.60430043935776, 74.6759869158268, 74.53553885221481, 74.93887960910797, 69.86360594630241, 72.09524899721146, 65.49044340848923, 66.91005483269691, 59.48139265179634, 58.20319443941116, 54.42137137055397, 54.39964413642883, 51.03929825127125, 53.805899396538734, 53.769550547003746, 62.7208898216486, 67.25909650325775, 70.82360163331032, 67.53696799278259, 69.07431229948997, 69.19272154569626, 63.062240704894066, 50.91292843222618, 50.864549428224564, 47.731674537062645, 52.465528920292854, 61.40937119722366, 67.11125403642654, 63.87549206614494, 67.72166088223457, 65.59659451246262, 67.61150479316711, 61.83750182390213, 63.854167610406876, 64.03087332844734, 62.961584106087685, 57.960098683834076, 54.24541041254997, 49.41146560013294, 50.23222155869007, 49.7985128313303, 55.32465510070324, 58.19959603250027, 66.91721364855766, 63.114309310913086, 64.89236310124397, 44.84332412481308, 45.537584871053696, 67.63978287577629, 61.243494898080826, 65.94563618302345, 61.3012707978487, 56.611718237400055, 44.932459741830826, 45.9391625225544, 47.3458394408226, 52.298725470900536, 47.29770362377167, 48.53984177112579, 47.39173337817192, 48.47894623875618, 49.041251465678215, 50.991284027695656, 52.498431354761124, 56.34190991520882, 57.09934987127781, 53.243548572063446, 48.15294273197651, 48.21558617055416, 47.65643857419491, 47.27343812584877, 51.333356872200966, 52.05265447497368, 60.4447777569294, 67.19755500555038, 67.06771597266197, 68.82249981164932, 61.88101328909397, 52.21964791417122, 50.654861479997635, 52.625439539551735, 58.331274166703224, 66.46123811602592, 68.39113935828209, 64.33725848793983, 68.08575734496117, 66.7959013581276, 64.87594798207283, 66.41742646694183, 66.3285644352436, 67.49938040971756, 65.68441540002823, 66.50138676166534, 67.72120490670204, 68.55789721012115, 71.40683993697166, 70.54744765162468, 27.261200174689293, 2.003853586502373, 1.0302517795935273, 3.1187106762081385, 1.9210508046671748, 0.5575785180553794, 0.1765771335340105, 0.5365787667687982, 50.546445697546005, 44.90203857421875, 23.12887441366911, 17.72022943943739, 14.33271311223507, 29.612610898911953, 41.02436564862728, 55.862014666199684, 66.95869222283363, 65.20450115203857, 57.298497185111046, 2.2231773426756263, 0.12454869254725054, 0.009107401583605679, 0.00921136812394252, 0.013498771950253285, 0.020219564830767922, 0.03826606560323853, 0.04057555124745704, 0.05238379613729194, 0.1274478033883497, 0.03487547117401846, 0.04782870892086066, 0.05661212686391082, 0.014926037893019384, 0.028474248938437086, 0.011351631110301241, 0.008736441850487608, 0.03993298865680117, 0.02079613936075475, 0.1410366757772863, 0.1045140894711949, 0.12957708444446325, 0.13462223403621465, 0.15478223038371652, 0.12162981831352226, 0.15904877800494432, 0.10014598636189476, 0.06496760019217618, 0.14582582894945517, 0.12902559450594708, 0.15529765194514766, 0.15268147748429328, 0.06383872678270563, 0.1825894945068285, 0.2828974917065352, 0.4422418522881344, 66.71551287174225, 96.02480694651604, 88.75922441482544, 77.66777917742729, 55.66969558596611, 20.252236872911453, 43.995551615953445, 64.74368467926979, 68.45929250121117, 32.23451770842075, 0.20624321041395888, 0.39213343639858067, 1.4801034657284617, 2.808317206799984, 4.859626684337854, 8.698106613010168, 13.709830585867167, 2.1597537584602833, 30.074884593486786, 98.09818848967552, 76.18671745061874, 86.06089040637016, 70.53058415651321, 76.66469380259514, 70.4786029458046, 77.35562592744827, 76.71132490038872, 78.0735670030117, 74.28433433175087, 77.89705127477646, 67.44413137435913, 72.40547195076942, 63.55253979563713, 59.40628208220005, 57.775181606411934, 56.62538230419159, 55.69409787654877, 57.118880823254585, 57.015017196536064, 64.37774911522865, 71.19231104850769, 74.77559477090836, 67.83715948462486, 72.32970401644707, 73.1417128443718, 65.62538176774979, 54.2971446365118, 53.74011732637882, 49.72684487700462, 55.536235347390175, 64.78443369269371, 72.142533659935, 65.10218784213066, 71.2438590824604, 65.66924661397934, 69.05377820134163, 65.410495698452, 67.14367389678955, 66.97257667779922, 67.01076462864876, 61.80585332214832, 57.19068557024002, 51.67394019663334, 52.056887447834015, 52.27795198559761, 57.551506608724594, 61.74500718712807, 69.55935627222061, 65.21983712911606, 64.30220916867256, 46.945363730192184, 52.14712120592594, 68.90369385480881, 65.10636761784554, 69.56347525119781, 65.30628249049187, 58.090834468603134, 44.8631476610899, 48.27245391905308, 50.148538649082184, 55.06171301007271, 50.302662178874016, 51.75802208483219, 50.27590021491051, 51.13638684153557, 51.12375631928444, 54.26452338695526, 55.050013437867165, 58.424950540065765, 59.20723356306553, 54.86683666706085, 50.67917637526989, 49.75670367479324, 50.48548176884651, 49.63349528610706, 54.0139914304018, 54.64720085263252, 63.742191419005394, 70.52993059158325, 70.82621589303017, 71.90162658691406, 65.72780907154083, 54.65012289583683, 51.80702045559883, 54.87930379807949, 60.93937061727047, 69.07685056328773, 70.87341696023941, 68.39265167713165, 72.13906824588776, 70.59625223279, 67.90246278047562, 69.13392350077629, 67.68666476011276, 69.28414463996887, 69.2718181014061, 69.66289311647415, 71.01531654596329, 71.36157676577568, 75.68452879786491, 74.11955997347832, 28.519094176590443, 2.55181600805372, 4.613322475925088, 6.741621997207403, 2.238283194601536, 0.6556506617926061, 0.2942511340370402, 2.1002458641305566, 61.61848537623882, 55.19958861172199, 41.36562913656235, 35.38478806614876, 31.557346545159817, 29.451579339802265, 45.484452322125435, 65.35523146390915, 77.72314220666885, 75.58189630508423, 68.6031223833561, 3.198596639558673, 0.38090370304416865, 0.11376231821486726, 0.13532748213037848, 0.13993347325595096, 0.13618890778161585, 0.14672709308797494, 0.14742643368663266, 0.09409108548425138, 0.12617013679118827, 0.1229472566046752, 0.16706986556528136, 0.1267653243849054, 0.10496638395125046, 0.12378719708067365, 0.15466051816474646, 0.07386684883385897, 0.07433722945279442, 0.21623857406666502], [0.02377502736635506, 0.005266383350317483, 0.046447546119452454, 0.025387087152921595, 0.02963066715892637, 0.02324647535715485, 0.12111942851333879, 0.11210247525013983, 0.04602148284902796, 0.05591436703980435, 0.06413376017007977, 0.011799430030805524, 0.04337111393397208, 0.06507038022391498, 0.028963995900994632, 0.2412959435605444, 9.11924846470356, 75.59034705162048, 72.88965716958046, 67.90035009384155, 54.69995342195034, 37.043535858392715, 27.313743755221367, 46.1825280636549, 49.47538577020168, 26.60346306860447, 6.22009570710361, 0.22315503418212757, 0.12838534370530397, 0.20271842455258593, 0.38038238883018494, 1.561283259652555, 15.010562539100647, 4.578880649060011, 0.620762180769816, 70.38903415203094, 78.12965199351311, 77.18066051602364, 72.77877151966095, 68.88350173830986, 67.39530399441719, 71.23128175735474, 69.7070999443531, 68.34846764802933, 69.83249321579933, 71.29739820957184, 69.62403640151024, 67.54389882087708, 64.52546238899231, 61.32321462035179, 56.6877331584692, 54.769801273941994, 50.251596719026566, 49.77584324777126, 48.012118488550186, 53.40914748609066, 64.74273473024368, 65.51590964198112, 68.26694682240486, 63.39365512132645, 64.61013704538345, 61.68796084821224, 55.48276461660862, 47.66830913722515, 49.46576468646526, 44.368957579135895, 52.03180119395256, 63.066184893250465, 63.99461567401886, 63.19142237305641, 63.4571573138237, 64.02974098920822, 62.59571313858032, 59.69261571764946, 61.90112181007862, 59.12314787507057, 58.80394980311394, 49.595679715275764, 47.76415139436722, 47.74502322077751, 49.92537282407284, 45.29071971774101, 53.193725645542145, 57.5475662201643, 59.88912217319012, 61.87964916229248, 63.53725701570511, 45.2628368139267, 45.99428616464138, 65.43874338269234, 56.197871044278145, 59.300039783120155, 49.449790343642235, 47.228148356080055, 45.338733941316605, 46.294686645269394, 50.91053456068039, 53.11986520886421, 55.209829062223434, 47.761001363396645, 45.24386443197727, 46.190473437309265, 43.817770555615425, 48.27472619712353, 52.12566755712032, 54.80699747800827, 54.70982529222965, 56.41917496919632, 47.7716825902462, 44.68964137136936, 45.91749608516693, 46.197704449296, 47.05253317952156, 47.52130262553692, 52.006217166781425, 61.90821222960949, 62.41549260914326, 62.083930000662804, 56.40615686774254, 47.878430262207985, 49.600851237773895, 48.82821209728718, 53.383305072784424, 64.49584677815437, 63.71865168213844, 60.236476734280586, 66.38974875211716, 61.25975802540779, 62.417540699243546, 61.44731976091862, 67.30787828564644, 64.14684310555458, 64.3605588376522, 63.57919916510582, 62.94055603444576, 66.4798191189766, 67.71060347557068, 72.74993866682053, 43.98969613015652, 2.7780549181625247, 0.21976987598463893, 1.2195418286137283, 1.317721197847277, 0.33751433598808944, 0.1458075424307026, 0.17196867847815156, 17.128272503614426, 59.852419942617416, 33.98591972887516, 32.12663769721985, 31.29338800907135, 17.295300140976906, 23.8242295011878, 49.027917981147766, 61.820569932460785, 59.249703884124756, 54.381253123283386, 13.371104411780834, 0.5582815397065133, 0.07372014108113945, 0.08170145694748498, 0.04068196409207303, 0.03046255347726401, 0.008367772570636589, 0.0950052852567751, 0.022188541988725774, 0.06841664246167056, 0.049100776013801806, 0.05207031666941475, 0.17927080305526033, 0.01715448193863267, 0.014031611717655323, 0.08655048659420572, 0.017176668443426024, 0.02324700413737446, 0.012680581039603567, 0.07917867435025983, 0.030612914451921824, 0.03677215572679415, 0.03373568077222444, 0.01781695264071459, 0.023308760100917425, 0.06985852407524362, 0.0835069760796614, 0.05563449944020249, 0.024220694467658177, 0.027470202912809327, 0.04868413430813234, 0.04271606470865663, 0.07842224775231443, 0.06725235376507044, 0.19877119339071214, 12.258197329938412, 88.07966887950897, 81.02565139532089, 78.92753317952156, 65.23363038897514, 50.16645468771458, 32.64643840491772, 47.925258949398994, 43.968573063611984, 40.782523825764656, 9.728004299104214, 0.2517523738788441, 0.24150760407792404, 0.9277460456360132, 1.9498768891207874, 2.87055145483464, 9.527688547968864, 1.3392154569737613, 1.4641139237210155, 72.32670977711678, 83.78911390900612, 79.22802105545998, 75.96688404679298, 72.21891716122627, 71.13579288125038, 72.88209557533264, 72.82523542642593, 70.76119378209114, 73.44509616494179, 73.7821912765503, 72.46320605278015, 68.15161541104317, 68.89547869563103, 64.35184210538864, 59.58893448114395, 56.877635568380356, 54.61555615067482, 53.222007527947426, 50.0254138559103, 54.602199867367744, 67.30104625225067, 68.6122190952301, 71.36367425322533, 63.727915585041046, 66.77616521716118, 64.68991756439209, 58.74359384179115, 49.4384441524744, 51.05466082692146, 47.924229204654694, 55.61867952346802, 63.60471099615097, 66.34032860398293, 64.08286973834038, 66.02714940905571, 67.4970169365406, 63.33543464541435, 60.7794675976038, 64.80231553316116, 61.781021654605865, 61.71241253614426, 51.73316761851311, 51.90634712576866, 50.491968020796776, 52.1562597155571, 47.6955346763134, 56.44259311258793, 60.14280416071415, 65.89708238840103, 63.791182190179825, 63.40242885053158, 47.32459478080273, 48.29690180718899, 69.61376175284386, 59.41431105136871, 62.08934850990772, 53.2888725399971, 47.137173637747765, 46.63826800882816, 49.255673959851265, 52.95932002365589, 55.116479471325874, 59.10538762807846, 50.965737998485565, 46.71396754682064, 47.73891694843769, 45.71456037461758, 49.893401339650154, 53.0798115581274, 58.78246195614338, 58.37259314954281, 58.089884519577026, 51.924160569906235, 45.620454624295235, 49.5421177893877, 47.53009915351868, 49.818651750683784, 49.45898585021496, 53.92421364784241, 62.95261658728123, 65.54224982857704, 64.71720770001411, 60.67714288830757, 50.200272873044014, 52.57628157734871, 51.71076022088528, 55.3253086656332, 66.62541210651398, 66.91033601760864, 64.00798335671425, 69.41621035337448, 65.43007984757423, 66.35213077068329, 63.90228822827339, 69.83850449323654, 66.0460115969181, 68.12179461121559, 64.21522423624992, 66.2107327580452, 67.94452652335167, 69.69742566347122, 72.5950513780117, 49.832938984036446, 4.371117297559977, 1.4271864364854991, 3.363580461591482, 3.6805029306560755, 1.2860498973168433, 0.17728882347000763, 0.212020369945094, 15.521155390888453, 71.05818584561348, 34.96252052485943, 32.97077760100365, 24.20356884598732, 17.45280548930168, 32.94836260378361, 57.986647859215736, 69.64932784438133, 65.76152086257935, 66.1866344511509, 25.201193913817406, 0.5478370876517147, 0.04736828421300743, 0.0022972687338551623, 0.09877033400698565, 0.024130909441737458, 0.089828782947734, 0.04836103289562743, 0.013950170286989305, 0.06766722915926948, 0.08325740665895864, 0.03270757988502737, 0.05404851872299332, 0.04294408587156795, 0.01583284309162991, 0.039867052546469495, 0.019074989431828726, 0.03373879779246636, 0.029567072524514515, 0.15202852111542597, 0.19312536431243643, 0.12340144356130622, 0.11963626122451387, 0.1472077376092784, 0.14391226053703576, 0.18551699991803616, 0.1937911004642956, 0.15532729332335293, 0.10552680934779346, 0.07965574171976186, 0.16872951557161286, 0.14488653716398403, 0.22575335256988183, 0.22163725312566385, 0.43773006938863546, 16.23062577098608, 103.48575219511986, 91.31119027733803, 88.42242568731308, 73.93841609358788, 53.14188502728939, 39.124528393149376, 64.12149846553802, 70.27513906359673, 46.771458461880684, 11.98488274589181, 0.359962314250879, 0.578836239874363, 0.9478075441438705, 3.4950144588947296, 5.229999460279942, 29.356523640453815, 14.13658568635583, 1.0407001501880586, 79.12861838936806, 83.86097565293312, 84.78193983435631, 78.67632105946541, 76.43912270665169, 73.35675090551376, 78.92974466085434, 76.13926559686661, 75.91508522629738, 76.44468560814857, 78.15774008631706, 74.93293672800064, 72.66147181391716, 71.0402812063694, 68.60629141330719, 63.3940427005291, 61.24782286584377, 56.85933195054531, 54.911773055791855, 53.57599273324013, 59.35500003397465, 71.18867844343185, 70.35235092043877, 74.60898891091347, 64.96088862419128, 70.03210410475731, 67.67422422766685, 62.06563398241997, 53.524307906627655, 53.82861077785492, 50.35265229642391, 58.22976641356945, 69.3966718018055, 69.06759425997734, 65.46217292547226, 67.50499650835991, 72.14048936963081, 67.28514790534973, 63.403618186712265, 67.4338947236538, 64.744383841753, 65.10149627923965, 55.67424014210701, 53.56527730822563, 54.726540595293045, 55.868462920188904, 50.1558418571949, 59.92192581295967, 62.262611612677574, 66.24639004468918, 67.32827559113503, 67.87198081612587, 49.70275416970253, 52.72019125521183, 70.61167180538177, 61.58817820250988, 65.20260885357857, 56.267802491784096, 51.93520277738571, 50.944736525416374, 52.59422801434994, 56.23271517455578, 57.97505468130112, 61.48071996867657, 52.3714953660965, 50.732141733169556, 49.38137501478195, 47.82646045088768, 51.695914417505264, 58.23611207306385, 62.174528539180756, 61.349003836512566, 61.65234535932541, 54.38564948737621, 49.26043130457401, 50.90466007590294, 49.83480088412762, 52.993400394916534, 53.100873827934265, 56.82918056845665, 67.77028307318687, 68.38123708963394, 68.14562693238258, 63.38410243391991, 52.32393331825733, 54.50268320739269, 53.85113976895809, 59.41321671009064, 71.74755245447159, 70.23141101002693, 67.45665550231934, 73.13766226172447, 68.16970244050026, 70.04430145025253, 66.92092224955559, 71.54632285237312, 67.80850142240524, 72.5846703350544, 68.24402645230293, 69.803736358881, 70.66253587603569, 73.8430792093277, 75.5554649233818, 51.76148749887943, 5.0048064440488815, 4.406333332881331, 7.372358702123165, 6.486271424219012, 0.865680769784376, 0.4915776033885777, 0.25729321874678135, 21.98466271162033, 79.29268598556519, 48.54168087244034, 47.06365518271923, 45.05684606730938, 26.282978765666485, 35.434246212244034, 65.05071580410004, 79.36266303062439, 73.521076887846, 79.48017552495003, 31.58618699759245, 1.0270383395254612, 0.14444587955949828, 0.23216635454446077, 0.21272592974128202, 0.12842179799918085, 0.3028876252938062, 0.17215408181073144, 0.06999000295763835, 0.2874783833976835, 0.3121116303373128, 0.12911379133583978, 0.18732735043158755, 0.13019753474509344, 0.12818517163395882, 0.17454777524108067, 0.11280476959655061, 0.12730415328405797, 0.08553284627851099], [0.06397431716322899, 0.06858332882984541, 0.028227943112142384, 0.036525840623653494, 0.059200860414421186, 0.11905480336281471, 0.03747818678675685, 0.069633579114452, 0.08612043428001925, 0.00713001589247142, 0.04584111498843413, 0.09904807535349391, 0.059382074323366396, 0.05704193055862561, 0.14473681629169732, 0.0340699923253851, 34.548437744379044, 79.64308798313141, 61.67700983583927, 66.09347864985466, 42.01417833566666, 19.85531587153673, 21.562835946679115, 43.10364447534084, 37.57486894726753, 32.93524190783501, 3.3455855771899223, 0.03905864592525177, 0.1330387283815071, 0.4881492076674476, 1.183020919561386, 1.6896062926389277, 8.101880606263876, 1.4344169734977186, 20.424265041947365, 89.46950510144234, 71.90984934568405, 75.14219909906387, 66.57384887337685, 70.64326331019402, 67.0496441423893, 69.81031000614166, 66.92083865404129, 68.55627849698067, 65.00267878174782, 66.17781892418861, 63.62100452184677, 67.69636183977127, 63.14419850707054, 62.40468218922615, 55.70041313767433, 54.43038068711758, 49.1294751316309, 50.74876584112644, 48.423108235001564, 56.17079369723797, 64.24611657857895, 66.35349869728088, 61.005103290081024, 64.33908998966217, 64.70361202955246, 58.17751541733742, 50.77573299407959, 46.23148463666439, 47.44752198457718, 45.79146824777126, 53.84273461997509, 63.3062332123518, 64.0113727748394, 64.58451122045517, 63.48644234240055, 61.050594449043274, 61.17467679083347, 60.75170248746872, 62.846564278006554, 59.95517022907734, 55.75167998671532, 50.706664100289345, 52.070908695459366, 58.591104224324226, 59.86824989318848, 51.00005015730858, 50.361711010336876, 58.730997517704964, 63.44594791531563, 59.85119640827179, 61.89342342317104, 45.67866750061512, 46.721114963293076, 66.12537413835526, 54.88432712852955, 56.34073577821255, 45.29488809406757, 45.260503739118576, 44.00169588625431, 47.493636310100555, 52.028126791119576, 58.44320856034756, 58.10951046645641, 56.22034303843975, 44.04187873005867, 45.231184512376785, 43.707215487957, 45.7271832972765, 52.25958377122879, 55.63224479556084, 55.95240041613579, 57.48958133161068, 55.42157270014286, 46.55385933816433, 44.735075533390045, 47.71198399364948, 46.50986149907112, 47.4847561866045, 48.813605681061745, 57.854631543159485, 60.61013728380203, 61.66847549378872, 52.85692311823368, 47.91958585381508, 46.92523241043091, 49.88262511789799, 50.77406108379364, 60.38062199950218, 61.74704007804394, 63.6651885509491, 64.30908679962158, 62.273099049925804, 63.463909551501274, 64.22749757766724, 65.87852418422699, 64.3414306640625, 64.37620639801025, 63.44823159277439, 65.05127817392349, 67.18296378850937, 67.89306968450546, 66.2661261856556, 62.792979553341866, 10.712956096976995, 1.1113977315835655, 1.9557913905009627, 1.60528679843992, 0.8635541307739913, 0.2520562388235703, 0.17572793847648427, 0.4157961322925985, 48.41239660978317, 45.8757097274065, 32.03255854547024, 39.612163826823235, 32.15830139815807, 22.965247593820095, 26.3579810410738, 43.609667122364044, 55.08559852838516, 55.17067216336727, 46.23925901949406, 4.366254983469844, 0.09847365305176936, 0.07311491965083405, 0.07671803919947706, 0.027689958405971993, 0.048093306832015514, 0.03332224514451809, 0.058741897737490945, 0.009123110994551098, 0.07674233711441047, 0.02118765565683134, 0.08422846978646703, 0.05574054492171854, 0.028237021433596965, 0.009836554254434304, 0.042312191653763875, 0.030726999248145148, 0.03717976178450044, 0.022495266057376284, 0.011117282210761914, 0.05769048228103202, 0.031402962194988504, 0.04024637535621878, 0.034607863854034804, 0.015334559575421736, 0.004572064308376866, 0.03309553758299444, 0.03158665116643533, 0.04758151808346156, 0.12576474604429677, 0.08481055847369134, 0.028892180125694722, 0.07674836335354485, 0.06921319698449224, 43.98365065455437, 90.44608309864998, 69.61985662579536, 74.4270470738411, 49.342738687992096, 26.30143627524376, 24.43578578531742, 34.73321042954922, 36.56715542078018, 38.521975725889206, 2.4471974093466997, 0.23009007767541334, 0.8021823177114129, 2.0337263960391283, 3.1693163607269526, 3.4314623940736055, 4.74795020185411, 0.19636417098809034, 24.47151906788349, 91.69202104210854, 75.7991686463356, 77.47383758425713, 70.01891881227493, 73.64235118031502, 70.34324660897255, 73.14595341682434, 69.71938848495483, 73.15870553255081, 68.63280639052391, 68.73648002743721, 68.80844816565514, 69.041748046875, 64.93045225739479, 64.34761673212051, 57.43045270442963, 55.845911130309105, 49.77320618927479, 53.07437784969807, 49.90720979869366, 58.31832446157932, 67.33891502022743, 69.35070186853409, 65.44183641672134, 66.84197008609772, 66.82175517082214, 60.94969466328621, 52.762232199311256, 48.93629729747772, 51.136109456419945, 47.75377795100212, 54.09648880362511, 65.90704545378685, 67.04608753323555, 65.97180917859077, 67.00247347354889, 63.69126655161381, 64.89201352000237, 62.39728778600693, 64.60385218262672, 62.012953609228134, 59.441452994942665, 52.51351274549961, 54.44824352860451, 64.04724285006523, 63.14835928380489, 53.20623077452183, 52.0281457901001, 60.761973336339, 65.70773854851723, 63.15390318632126, 63.034259006381035, 46.62085734307766, 48.692274391651154, 68.3679910004139, 59.497689977288246, 57.92434260249138, 45.705144479870796, 48.44673156738281, 47.25622124969959, 50.78087791800499, 55.37952035665512, 61.51886612176895, 61.92752659320831, 59.18685905635357, 46.645438224077225, 46.66004844009876, 45.23464232683182, 49.67007212340832, 53.7993523478508, 58.491279780864716, 58.893438801169395, 61.617436632514, 56.83393031358719, 48.22549223899841, 47.449782863259315, 49.600114077329636, 48.81758026778698, 50.66433057188988, 51.08308710157871, 60.28053916990757, 61.14353746175766, 63.52754853665829, 55.73388174176216, 50.995604395866394, 49.32870224118233, 51.91704735159874, 53.54696609079838, 62.19756670296192, 65.23451954126358, 66.78052738308907, 66.70210719108582, 66.66298449039459, 66.10233217477798, 66.63675829768181, 67.14292913675308, 67.05013811588287, 67.70268470048904, 65.56023806333542, 68.32815393805504, 69.50071781873703, 72.98360332846642, 67.11617097258568, 66.14539906382561, 13.766732532531023, 0.49855171353556216, 1.3954693009145558, 2.9981032479554415, 1.9895439106039703, 0.4404822498327121, 0.20826410822337493, 0.29028022836428136, 52.650651186704636, 53.514823615550995, 35.52085496485233, 40.68101607263088, 28.049484975636005, 33.846550807356834, 39.97911013662815, 51.76253244280815, 63.396010994911194, 62.22768768668175, 65.51952704787254, 10.766298584640026, 0.0769943482009694, 0.09436535357963294, 0.10479799064341933, 0.04404192266520113, 0.05955786313279532, 0.03748256916878745, 0.04144505146541633, 0.0965829576307442, 0.019162054486514535, 0.03325436089653522, 0.054407666248152964, 0.0643369230965618, 0.04073787378729321, 0.009101748273678822, 0.02757547285000328, 0.010934316833299818, 0.024463814625050873, 0.16697979852324352, 0.07729334465693682, 0.1329569733934477, 0.15462502866284922, 0.2501419134205207, 0.1701384680927731, 0.10780500975670293, 0.10970119707053527, 0.19863748806528747, 0.10559004032984376, 0.11852824958623387, 0.11845365632325411, 0.27649195573758334, 0.14198905904777348, 0.16402208770159632, 0.17411351494956762, 54.7830131649971, 102.38898664712906, 78.70884731411934, 86.16657793521881, 58.02004426717758, 30.375685952603817, 30.82414548844099, 59.49030317366123, 56.875378489494324, 49.92032289505005, 6.1750823725014925, 0.2525008743396029, 1.3591449125669897, 1.7302290815860033, 5.265285791829228, 3.3968992112204432, 21.763016805052757, 4.648186080157757, 24.53956961631775, 95.43007805943489, 79.10156384110451, 81.0978627204895, 71.2496043741703, 77.58761867880821, 74.02749851346016, 74.96354788541794, 74.28134769201279, 77.0408584177494, 71.01294547319412, 71.19526728987694, 70.6272965669632, 73.39910343289375, 70.14727592468262, 66.62788197398186, 59.48355473577976, 60.72678342461586, 53.19923534989357, 54.76591408252716, 52.443721890449524, 63.69891934096813, 70.56086853146553, 73.1832218170166, 68.10132130980492, 69.20894667506218, 70.66517293453217, 63.64865183830261, 56.50212071835995, 49.40772280097008, 54.58436742424965, 51.25040352344513, 57.56529226899147, 67.90766850113869, 68.86135652661324, 68.34507063031197, 69.2332273721695, 67.41532891988754, 65.89878469705582, 63.58959540724754, 68.4303380548954, 64.7129899263382, 62.978405803442, 55.215410962700844, 58.17651227116585, 66.38848721981049, 66.28685027360916, 57.653268948197365, 55.68444639444351, 64.64057341217995, 67.75810852646828, 65.88666334748268, 63.86036887764931, 49.88609053194523, 52.794363275170326, 71.73702701926231, 61.81100584566593, 59.762155786156654, 51.855498254299164, 50.834272652864456, 51.20726823806763, 51.86044558882713, 57.11730010807514, 65.02021864056587, 65.18554776906967, 62.2272165119648, 48.084063827991486, 49.495976865291595, 47.392576932907104, 52.84148074686527, 57.09087252616882, 62.84998029470444, 62.50810883939266, 63.699394315481186, 61.154184490442276, 50.91460034251213, 51.00185126066208, 52.810166627168655, 50.06921790540218, 53.11641499400139, 53.17433528602123, 65.86184307932854, 64.59307596087456, 67.0961232483387, 58.85905064642429, 53.5517006367445, 51.79847091436386, 54.949949607253075, 55.54773353040218, 65.81819862127304, 67.40484148263931, 70.76068460941315, 69.82788786292076, 68.24920937418938, 67.81608581542969, 70.2944116294384, 70.64925938844681, 69.90746319293976, 71.99619591236115, 69.62396800518036, 72.46355563402176, 73.86343091726303, 73.54535758495331, 68.45519632101059, 69.21656906604767, 17.75826159864664, 4.715085290372372, 8.796759769320488, 7.357514798641205, 3.632743055932224, 0.42681194900069386, 0.2986467262962833, 0.5019474844448268, 61.82769455015659, 60.763326063752174, 46.53665766119957, 53.089219853281975, 43.26836943626404, 33.93614239990711, 39.073899909853935, 61.52070142328739, 73.06175753474236, 71.93521678447723, 77.1159727871418, 11.233407519757748, 0.25029245065525174, 0.21241054666461423, 0.15806319104740396, 0.12681544903898612, 0.12162815590272658, 0.12406205889419653, 0.12098977531422861, 0.13924104947363958, 0.2402275922941044, 0.11781554290791973, 0.14384560083271936, 0.1502107788110152, 0.08984407861134969, 0.1938889452139847, 0.1689436993910931, 0.14042824826901779, 0.08215891677537002], [0.04689309076638892, 0.04285698742023669, 0.07178007057518698, 0.048109797353390604, 0.052564431171049364, 0.05836950287630316, 0.0182100793972495, 0.038876292819622904, 0.025813309985096566, 0.06488408631412312, 0.028744845258188434, 0.012522519355115946, 0.009932258835760877, 0.050098764259018935, 0.04873842612141743, 2.091377852484584, 70.39883762598038, 75.27189373970032, 69.35278415679932, 56.97227329015732, 48.11229631304741, 29.082805328071117, 44.99039523303509, 62.823685705661774, 43.35541516542435, 29.72982320934534, 0.37719554733484983, 0.1009205510490574, 0.2519967779517174, 0.7454615144524723, 2.013500793837011, 1.9058220530860126, 3.2609045086428523, 1.2305867671966553, 63.13373766839504, 78.97795647382736, 72.97769084572792, 69.83369395136833, 70.93792229890823, 68.11492457985878, 79.2486235499382, 72.01243624091148, 65.39974227547646, 63.32862161099911, 62.20208466053009, 61.161772683262825, 65.37269532680511, 60.97277842462063, 63.07441525161266, 60.24371914565563, 58.29661622643471, 53.557407930493355, 50.436726585030556, 48.98462310433388, 48.21699969470501, 52.624728977680206, 65.03294795751572, 64.12991881370544, 66.25469639897346, 63.85228291153908, 63.64587038755417, 54.84071306884289, 46.122343093156815, 45.798372477293015, 46.28283888101578, 45.19096367061138, 53.273775950074196, 62.11384579539299, 63.554439693689346, 64.15079489350319, 60.93148984014988, 59.32262197136879, 59.48222100734711, 61.69236101210117, 64.30874481797218, 60.90986140072346, 55.716630667448044, 51.2753339856863, 61.02510541677475, 61.540445163846016, 64.13307264447212, 54.55680750310421, 50.25072656571865, 51.63482129573822, 60.60330145061016, 57.742218375205994, 61.45500294864178, 48.17129194736481, 47.408072501420975, 62.918889597058296, 52.685062140226364, 48.54616843163967, 43.8868622481823, 44.93092082440853, 48.55597570538521, 50.16084238886833, 53.38860958814621, 59.51237998902798, 59.501197189092636, 58.623166903853416, 48.22593301534653, 46.24509550631046, 44.0479052066803, 45.65006643533707, 50.0790061801672, 55.432227328419685, 55.688865557312965, 58.50291095674038, 57.72316239774227, 49.229485765099525, 42.75770343840122, 45.813267678022385, 45.185735151171684, 46.14145986735821, 46.086302027106285, 51.94181442260742, 54.621039256453514, 54.44619923830032, 49.73322853446007, 46.92046366631985, 48.10603804886341, 48.967539221048355, 50.42968936264515, 59.47494439780712, 63.223196268081665, 61.95104733109474, 64.15151685476303, 63.36278937757015, 67.18000754714012, 63.0987985432148, 64.38307642936707, 67.97896787524223, 64.17998492717743, 63.74009393155575, 64.77786004543304, 68.5043352842331, 65.03289476037025, 60.149419605731964, 64.89047080278397, 22.312094941735268, 0.6344320659991354, 0.5797684367280453, 3.8251680554822087, 1.3734023412689567, 0.5907602969091386, 0.2770485368091613, 0.1164148653333541, 14.995192363858223, 66.1804711818695, 32.13826507329941, 25.798757448792458, 24.175224266946316, 14.523534122854471, 20.66295113414526, 29.44257192313671, 45.211718156933784, 53.002816289663315, 59.75894495844841, 42.99869030714035, 1.1342063639312983, 0.06232352097867988, 0.04651226139685605, 0.028047250561940018, 0.08275523985503241, 0.09620416545658372, 0.01618372309167171, 0.010401247000118019, 0.020364910742500797, 0.035811133857350796, 0.029314970524865203, 0.03840390840196051, 0.03836053729173727, 0.05212719857809134, 0.03439923129917588, 0.04238849556713831, 0.02678441578609636, 0.022780404760851525, 0.060073084314353764, 0.03439307889493648, 0.03367502133187372, 0.01676751686318312, 0.03950638732931111, 0.0543233137432253, 0.08662643798743375, 0.040516821391065605, 0.04914878554700408, 0.024297543859574944, 0.04037867060105782, 0.0324715138413012, 0.05427106283605099, 0.13082773686619475, 4.158056555315852, 89.78009283542633, 82.94486001133919, 80.1188376545906, 64.8964136838913, 59.31643210351467, 34.25258181989193, 27.501322589814663, 43.74204821884632, 51.52693748474121, 34.14469040930271, 0.31486861989833415, 0.09524129563942552, 0.6588687922339886, 3.2462586695328355, 2.9813881823793054, 3.7351192999631166, 3.145735301077366, 2.2340145986527205, 66.82035684585571, 84.84512284398079, 75.99098235368729, 74.76724281907082, 75.29452532529831, 72.31270372867584, 79.2091816663742, 76.87960267066956, 70.25613248348236, 64.97433990240097, 66.50071799755096, 64.07048240303993, 67.33297973871231, 64.50327917933464, 66.06020003557205, 63.822652101516724, 61.397443637251854, 54.518634751439095, 52.01187886297703, 51.88559263944626, 49.99150447547436, 56.85328647494316, 69.34364944696426, 67.23372146487236, 68.03580522537231, 66.50935873389244, 65.5289201438427, 55.65451920032501, 49.4768600910902, 47.71175980567932, 48.88141684234142, 47.77110122144222, 54.71600376069546, 66.24784916639328, 64.8979564011097, 65.4418896138668, 62.748594135046005, 59.91814501583576, 63.9509180188179, 64.56248000264168, 66.16123661398888, 63.05045373737812, 57.55792446434498, 55.111098960042, 63.94633546471596, 63.66425380110741, 67.61284992098808, 57.472717836499214, 53.57526317238808, 53.62265802919865, 61.9865146279335, 61.924346163868904, 64.49327051639557, 49.39266420900822, 51.66186064481735, 66.01175263524055, 56.486142575740814, 50.940416157245636, 46.504032611846924, 49.134034886956215, 50.68814769387245, 53.860206082463264, 55.44719472527504, 62.85033367574215, 61.27834662795067, 61.03018194437027, 51.13346479833126, 46.6575063765049, 46.7407751083374, 47.06200987100601, 51.157213523983955, 57.70245350897312, 58.72814007103443, 60.48369146883488, 59.85110901296139, 51.04245588183403, 46.40588767826557, 47.17378847301006, 46.857759431004524, 47.884680926799774, 48.40325050055981, 53.31217668950558, 57.588980197906494, 58.68072621524334, 52.62572452425957, 49.58748735487461, 51.07851214706898, 50.016841515898705, 53.86468604207039, 61.11138738691807, 65.04661962389946, 64.01237592101097, 65.97975075244904, 66.60301610827446, 68.14245030283928, 65.52751421928406, 67.52927720546722, 67.49441787600517, 66.99041292071342, 67.13574752211571, 67.95739263296127, 69.68056216835976, 66.42059549689293, 61.44530586898327, 65.36251947283745, 28.869066797196865, 0.9735830454155803, 0.48573399195447564, 2.2892595967277884, 2.8760388353839517, 1.2321012234315276, 0.4258199647301808, 0.21453063993249089, 13.6974679492414, 74.82798635959625, 37.14584916830063, 29.54099614173174, 22.160500176250935, 17.309716567397118, 28.420350775122643, 39.97866556048393, 52.79772609472275, 59.15682166814804, 66.16812944412231, 59.82672572135925, 2.0035491278395057, 0.11055968381697312, 0.04131335736019537, 0.06092991978221107, 0.05507742112968117, 0.060451497993199155, 0.00862740180309629, 0.06738408497767523, 0.05335486297553871, 0.059332602759241126, 0.0621715142915491, 0.029777168965665624, 0.03667917575512547, 0.06899639338371344, 0.012899185276182834, 0.008821402916510124, 0.04223874871968292, 0.16619913338217884, 0.21548789169173688, 0.335856526507996, 0.22337352245813236, 0.09776133971172385, 0.11813802091637626, 0.11675276517053135, 0.16025441174861044, 0.06721413315972313, 0.14731672941707075, 0.111907631799113, 0.10097313963342458, 0.16938290238613263, 0.1553161907941103, 0.23349698079982772, 5.09502500295639, 103.16606774926186, 90.29830142855644, 89.86010894179344, 73.2821837067604, 66.49332359433174, 39.626454859972, 63.85241970419884, 92.12944597005844, 66.24729439616203, 43.828326389193535, 0.7999554590787739, 0.11552938667591661, 2.1525735687464476, 4.006355395540595, 6.506284475326538, 6.0308292880654335, 11.450022496283054, 1.7013626242987812, 71.60733237862587, 86.13589838147163, 80.60679987072945, 76.76615595817566, 78.25816109776497, 74.16228488087654, 81.5669247508049, 79.3737356364727, 73.3563557267189, 70.45819044113159, 68.6190739274025, 66.51670753955841, 70.09198129177094, 68.43546018004417, 70.42274594306946, 66.91437900066376, 64.53781172633171, 57.11301773786545, 56.20314136147499, 54.90678392350674, 53.290677443146706, 58.155157417058945, 73.462423235178, 71.53113886713982, 69.97384563088417, 68.504768460989, 70.5560427904129, 58.96506875753403, 51.51219807565212, 49.72855478525162, 51.70547470450401, 51.83798499405384, 58.9652169495821, 68.29411536455154, 68.83591309189796, 69.21222969889641, 67.41111874580383, 63.01586039364338, 67.02864646911621, 67.41840675473213, 68.2888488471508, 65.37837982177734, 61.670983359217644, 59.33128170669079, 67.3516671359539, 67.67977192997932, 71.45056039094925, 59.49504911899567, 55.41433408856392, 58.60182724893093, 64.35773938894272, 63.17076288163662, 66.37444317340851, 52.74676702916622, 55.7871662825346, 68.44240620732307, 59.847043231129646, 53.80974479019642, 47.091572284698486, 49.7461212426424, 54.43104185163975, 56.21751978993416, 59.430425986647606, 64.16665524244308, 64.71797525882721, 64.82477992773056, 52.02860176563263, 49.127252250909805, 49.145533069968224, 50.12298882007599, 53.870617523789406, 59.63871940970421, 60.97511149942875, 63.73069703578949, 64.33535858988762, 53.04013788700104, 47.674556002020836, 50.28111733496189, 50.81198684871197, 49.344573989510536, 51.396794468164444, 55.68891115486622, 59.6116990596056, 61.967017874121666, 55.71644447743893, 51.621001437306404, 54.74179297685623, 53.163798451423645, 56.08264222741127, 65.30268028378487, 69.00456324219704, 66.43623545765877, 68.13026055693626, 68.91040429472923, 72.02850937843323, 68.87981593608856, 70.66935271024704, 70.37682920694351, 68.92763257026672, 70.19073039293289, 71.81212618947029, 73.26829925179482, 69.00333970785141, 66.36194184422493, 67.1730387210846, 31.911432445049286, 2.1908417902886868, 6.960775712504983, 9.899823479354382, 7.364089395850897, 2.3387566907331347, 0.6559966807253659, 0.3011356818024069, 19.07119184732437, 82.07889407873154, 44.4854973256588, 38.772902861237526, 32.09909677505493, 22.251066416502, 30.774586647748947, 44.26560692489147, 61.313502341508865, 69.84136193990707, 77.61737108230591, 69.01831090450287, 2.741442695260048, 0.18039266316918656, 0.09848646994214505, 0.18113249534508213, 0.17016720405081287, 0.18153907352825627, 0.06318234911304899, 0.12369868112728, 0.11769855816964991, 0.3247639717301354, 0.10154163217521273, 0.10243410928524099, 0.12642801826586947, 0.14576439396478236, 0.10723739294917323, 0.16018717316910625, 0.16866582445800304], [0.082398786325939, 0.06499870360130444, 0.049732929983292706, 0.009009169061755529, 0.0040147165054804645, 0.1023717169300653, 0.03959804627811536, 0.018745637280517258, 0.03944919371861033, 0.06240068207262084, 0.010208573403360788, 0.08508930914103985, 0.07227394758956507, 0.07302264843019657, 0.07860319819883443, 15.607550404965878, 82.65732184052467, 62.918604612350464, 60.888677537441254, 49.23695236444473, 18.801170736551285, 18.279377035796642, 51.913365349173546, 30.688462369143963, 49.46333281695843, 12.85164663568139, 0.10934035744867288, 0.0913470760860946, 0.5693406087812036, 2.285370505414903, 2.837450481019914, 3.31148121971637, 1.7102400166913867, 18.603467345237732, 78.11964333057404, 74.64988991618156, 73.2178683578968, 74.68271255493164, 74.0366180241108, 77.72302821278572, 83.92396867275238, 69.99947905540466, 70.45920118689537, 63.301092088222504, 61.702069491147995, 56.38773925602436, 58.325528874993324, 57.45042823255062, 59.191692396998405, 53.091765716671944, 53.126229867339134, 53.60599972307682, 50.04913978278637, 48.306564688682556, 48.17614808678627, 49.65914011001587, 62.39832893013954, 64.02941420674324, 65.20634785294533, 64.06475991010666, 62.210269421339035, 50.833774879574776, 47.628943249583244, 45.63915342092514, 45.873912423849106, 46.306709200143814, 50.523342937231064, 59.24355201423168, 60.192372500896454, 57.05258958041668, 54.88781154155731, 57.57604569196701, 62.65069618821144, 63.12960349023342, 59.9331846088171, 59.86224241554737, 56.39079049229622, 56.835119649767876, 62.339283898472786, 59.89590480923653, 64.02469485998154, 59.7438445687294, 54.77792903780937, 54.77005586028099, 60.485139191150665, 59.07593920826912, 60.86233735084534, 42.51784510910511, 49.80072431266308, 62.26670019328594, 52.47595176100731, 52.02782280743122, 48.6285176128149, 50.382195711135864, 52.081498727202415, 59.205052480101585, 57.40332216024399, 62.03000329434872, 62.599961310625076, 58.852389603853226, 51.651916578412056, 45.519714429974556, 41.39929533004761, 43.99346172809601, 44.37927782535553, 53.973724991083145, 54.305352196097374, 59.10811588168144, 59.218412563204765, 56.55303418636322, 46.0440368950367, 44.811462834477425, 45.280775651335716, 45.78042224049568, 46.19831621646881, 46.79869160056114, 51.10301323235035, 51.27963915467262, 50.18438592553139, 47.747299298644066, 46.87327779829502, 46.59548990428448, 49.472600519657135, 57.391212210059166, 60.37633962929249, 60.57626970112324, 61.73742659389973, 64.22796875238419, 63.40640343725681, 63.975669890642166, 61.22161187231541, 65.10837391018867, 64.11387607455254, 64.86663088202477, 66.73561379313469, 62.55463354289532, 67.68443807959557, 62.85165600478649, 72.16738432645798, 54.55716848373413, 1.8031751923263073, 0.857176766730845, 1.8854568083770573, 1.3902299758046865, 1.0590681270696223, 0.16821753757540137, 0.0052974621758039575, 0.6248412025161088, 45.50602376461029, 53.676903918385506, 31.21545609086752, 27.860488817095757, 37.224102169275284, 22.251695282757282, 21.290692649781704, 38.55171672999859, 50.35760723054409, 55.188246220350266, 58.94449286162853, 10.93003274872899, 0.24899189622374251, 0.06903586079715751, 0.02306448033777997, 0.015952735193422996, 0.024390200997004285, 0.035769462265307084, 0.0340420615975745, 0.04109232722839806, 0.09118396686972119, 0.12052366204443388, 0.02058996702544391, 0.07311053355806507, 0.05270517947792541, 0.06203258795721922, 0.0366532748012105, 0.030272086842160206, 0.059399793099146336, 0.01796655291400384, 0.015357734064309625, 0.04808357356523629, 0.0573590391286416, 0.03495499971904792, 0.046940016763983294, 0.02551951227360405, 0.027534268810995854, 0.09841817009146325, 0.04726740036858246, 0.008323400488734478, 0.07751828219625168, 0.08375997422263026, 0.17048514011548832, 21.398808248341084, 94.59977701306343, 68.71302008628845, 69.55434814095497, 55.930171608924866, 32.134336084127426, 21.94630566984415, 60.45804284512997, 36.255458146333694, 59.73905302584171, 14.130028188228607, 0.37832004949450493, 0.6798529881052673, 1.9221797003410757, 3.548155794851482, 5.671841651201248, 5.319428136572242, 1.7988067329861224, 20.850691460072994, 81.73918470740318, 78.94604578614235, 75.95790892839432, 75.1897269487381, 76.92425027489662, 78.23229968547821, 83.84240984916687, 73.59796956181526, 73.60873818397522, 66.3115793466568, 63.67489702999592, 58.79353456199169, 61.38944886624813, 59.47793483734131, 61.48331142961979, 56.634296625852585, 55.27403801679611, 56.41462281346321, 53.47826577723026, 51.354263350367546, 51.51520751416683, 51.71193055808544, 63.97007659077644, 67.38645806908607, 67.62224301695824, 65.07514849305153, 65.17081215977669, 54.36353087425232, 50.83016127347946, 49.09133277833462, 48.25925722718239, 48.20064917206764, 53.0244143307209, 60.596598610281944, 62.29597382247448, 60.97625523805618, 57.32593551278114, 60.267106890678406, 65.33425658941269, 65.34726709127426, 62.253412306308746, 61.9259724766016, 59.434772953391075, 59.118614718317986, 65.15696570277214, 61.66565224528313, 65.37097781896591, 62.79902882874012, 59.9615690857172, 58.5316564142704, 63.15979287028313, 61.20412901043892, 62.920637503266335, 44.921953305602074, 53.428161665797234, 64.71006408333778, 54.65611517429352, 53.031113371253014, 50.859499499201775, 52.22103103995323, 55.74290245771408, 60.45397326350212, 59.04734194278717, 63.133927658200264, 63.16526457667351, 60.80124042928219, 54.97698135674, 47.83386245369911, 45.29108829796314, 47.34840430319309, 46.61891184747219, 55.84784522652626, 57.73564092814922, 63.46092291176319, 62.7635083347559, 58.72415028512478, 49.0569294244051, 46.83592960238457, 47.25428335368633, 48.362079709768295, 47.829397693276405, 49.113987162709236, 52.02707804739475, 52.411446422338486, 52.22713731229305, 49.8255255818367, 49.561166167259216, 52.22793146967888, 50.83996094763279, 60.2881121635437, 65.53176999092102, 64.04598131775856, 64.11123141646385, 65.68522855639458, 66.3302743434906, 65.57542204856873, 63.313870802521706, 66.83683276176453, 67.29519456624985, 66.54566958546638, 69.88078862428665, 65.54687798023224, 69.74597185850143, 65.33947750926018, 74.92691025137901, 60.43099969625473, 5.021317033097148, 0.6458658305928111, 1.9185394956730306, 3.112993170507252, 1.8161568394862115, 0.6659950723405927, 0.13538672035792843, 0.40336260572075844, 47.509413063526154, 61.51515752077103, 29.95949238538742, 22.659637592732906, 20.41091065853834, 21.05542827397585, 30.803653188049793, 47.16622307896614, 59.31746944785118, 61.332341730594635, 68.08992192149162, 19.164262153208256, 0.2992905245628208, 0.068591477611335, 0.030749393554287963, 0.017879847800941207, 0.04140892000577878, 0.030486994255625177, 0.026275183736288454, 0.018535882227297407, 0.03433326921367552, 0.008082363910943968, 0.11564604486920871, 0.05273037910228595, 0.02532522914407309, 0.0776661180134397, 0.012058959073328879, 0.027120029808429535, 0.11549577480764128, 0.18076381122227758, 0.12296763597987592, 0.10486470971954986, 0.07777562932460569, 0.18221147416625172, 0.10231224121525884, 0.06411495414795354, 0.1262556470464915, 0.130880355136469, 0.15380569762783125, 0.2275828059646301, 0.16545122663956136, 0.18073464481858537, 0.3211267356527969, 26.430070772767067, 108.70894432067871, 79.06499460339546, 81.445582062006, 65.69660514593124, 32.254371643066406, 28.358218409121037, 73.73921558260918, 48.011586517095566, 71.03280320763588, 18.73334437608719, 0.2518997644074261, 1.1215011519379914, 2.7109821047633886, 6.387129994109273, 8.418570812791586, 13.075927700847387, 4.446792136877775, 23.08470368385315, 85.60976341366768, 80.11435389518738, 80.44636487960815, 79.90958288311958, 80.25471836328506, 80.23603096604347, 86.12839758396149, 78.76623943448067, 77.09027856588364, 68.85079309344292, 66.9949422776699, 62.13026471436024, 63.14749673008919, 62.07476109266281, 64.61272090673447, 58.3691581338644, 57.10286468267441, 59.291969016194344, 57.7597164362669, 55.12933798134327, 53.51048804819584, 55.477745085954666, 68.01137253642082, 71.27406746149063, 68.94071146845818, 68.23591008782387, 69.37646448612213, 56.78748540580273, 52.950550094246864, 51.404093876481056, 50.408247113227844, 51.347864493727684, 55.67215405404568, 63.66611950099468, 66.24363899230957, 62.57182762026787, 59.91984352469444, 62.95923963189125, 69.68477994203568, 69.16986957192421, 65.53648173809052, 63.989706337451935, 61.5584409981966, 61.25755414366722, 68.7990702688694, 63.55583041906357, 67.21813470125198, 66.4263179898262, 61.253286972641945, 60.95745384693146, 66.4800775051117, 63.61530862748623, 64.28014755249023, 48.72242197394371, 56.23575121164322, 67.02953562140465, 57.0121331512928, 58.59396547079086, 54.571337923407555, 54.21804428100586, 58.23796637356281, 63.350272849202156, 62.495162934064865, 65.50133362412453, 68.46970394253731, 62.92648158967495, 59.52514350414276, 51.03784292936325, 46.80051550269127, 48.6995168030262, 49.11259263753891, 58.90951193869114, 60.30756711959839, 64.96668711304665, 66.7790074646473, 61.36980392038822, 50.14823466539383, 49.46164570748806, 50.05781091749668, 49.20599162578583, 50.891888961195946, 51.67383000254631, 55.66834285855293, 56.11342817544937, 54.78865206241608, 52.10546404123306, 53.09230528771877, 52.35033430159092, 52.97814801335335, 62.74512492120266, 68.04593548178673, 67.28089973330498, 68.1849168241024, 67.12871789932251, 69.25351068377495, 69.77419674396515, 65.52312925457954, 69.9969331920147, 70.27566343545914, 69.4261734187603, 71.38555347919464, 69.0022149682045, 73.92665192484856, 68.76794993877411, 78.62413465976715, 62.08840236067772, 7.44047574698925, 3.803546028211713, 9.09152990207076, 6.038050325587392, 3.9246464800089598, 1.0502894106321037, 0.15879294485785067, 0.8503459207713604, 57.27773889899254, 67.29485258460045, 44.37957040965557, 37.370310723781586, 51.48958548903465, 33.003189861774445, 32.65171632170677, 52.21428640186787, 65.80724000930786, 70.42125642299652, 81.91567003726959, 23.793063573539257, 0.6176580442115664, 0.2035698015242815, 0.11808387382188812, 0.14830518106464297, 0.14735211501829326, 0.12761969963321462, 0.09362626355141401, 0.1258260919712484, 0.12318675508140586, 0.1872121839551255, 0.24183882458601147, 0.18935240426799282, 0.09423190058441833, 0.1614046812755987, 0.10755944793345407, 0.17034759046509862], [0.059459728945512325, 0.055860739448689856, 0.044750651431968436, 0.07920557720353827, 0.050548683866509236, 0.038841408168082125, 0.012043047427141573, 0.04043848028231878, 0.04098139099369291, 0.09273873656638898, 0.043259435551590286, 0.06553542480105534, 0.05170834527234547, 0.03692267811857164, 0.2665018761763349, 41.421330347657204, 73.88316705822945, 64.39534977078438, 48.21451462805271, 54.31668318808079, 44.14757005870342, 60.05470588803291, 45.72450064122677, 33.93677696585655, 52.24356763064861, 1.9326674938201904, 0.34527108538895845, 0.6183808366768062, 0.5892622272949666, 2.2027486888691783, 2.372223394922912, 3.9968497306108475, 1.0339286760427058, 42.07000873982906, 79.43965449929237, 74.69561666250229, 73.04291814565659, 75.24933815002441, 74.56687957048416, 79.40019741654396, 70.36477625370026, 68.7375059723854, 71.09656378626823, 66.63471400737762, 67.99459263682365, 63.20463426411152, 58.20795178413391, 54.558878391981125, 53.85004162788391, 49.80076611042023, 53.00474278628826, 50.469423830509186, 51.042186096310616, 48.92130710184574, 51.35654702782631, 46.68230764567852, 56.30145728588104, 63.123827800154686, 64.34450089931488, 63.18225346505642, 60.802121981978416, 50.218477696180344, 46.387994438409805, 47.16115415096283, 46.30385935306549, 47.008048966526985, 46.10501602292061, 49.36505489051342, 50.884137377142906, 50.36814786493778, 52.29567043483257, 56.248062551021576, 62.62782521545887, 59.75966311991215, 60.13969212770462, 58.98487329483032, 58.444029316306114, 60.92131018638611, 64.38803896307945, 54.41311061382294, 56.537303030490875, 57.95436479151249, 61.17832839488983, 58.65722067654133, 59.59253288805485, 58.88371892273426, 57.44170010089874, 42.090615034103394, 50.195994302630424, 63.05072732269764, 51.09222561120987, 50.489007979631424, 48.49914215505123, 56.53047479689121, 55.596853494644165, 59.33497130870819, 61.09868846833706, 54.908205047249794, 58.57519447803497, 57.60940410196781, 53.352074548602104, 50.51161676645279, 44.50086750090122, 44.37774270772934, 41.702382266521454, 50.92826060950756, 54.944375306367874, 53.73545877635479, 56.46381877362728, 57.549226731061935, 49.66854840517044, 44.436985328793526, 44.70640227198601, 44.947028160095215, 46.051024720072746, 46.54943257570267, 47.58898839354515, 46.10833704471588, 46.89861103892326, 46.55216462910175, 48.80017340183258, 47.19904951751232, 49.27689962089062, 58.30558754503727, 62.34811842441559, 60.58914341032505, 58.414736688137054, 64.28306579589844, 65.18758445978165, 63.858985751867294, 63.13400365412235, 61.494634822010994, 62.596530094742775, 64.28666040301323, 62.76611879467964, 63.7051510065794, 63.623048812150955, 64.31243062019348, 61.42657287418842, 68.96083518862724, 28.76725886017084, 0.08560645990655757, 0.7188849686644971, 1.9492585910484195, 0.7427998760249466, 0.9714837768115103, 0.3118764882674441, 0.1792842656141147, 10.993863623589277, 60.51130458712578, 44.339699149131775, 32.16147042810917, 63.091575130820274, 75.93187272548676, 30.184653103351593, 28.550009317696095, 45.808981508016586, 48.63792970776558, 54.78298656642437, 43.39729651808739, 1.4335011038929224, 0.03868201711156871, 0.09269275309634395, 0.024454018275719136, 0.06342596650938503, 0.08972865980467759, 0.039978471177164465, 0.06466872247983702, 0.04508722653554287, 0.02159217809094116, 0.03304924241092522, 0.03806304739555344, 0.011362054574419744, 0.02388102831901051, 0.05347017046005931, 0.04617599428456742, 0.02146163060388062, 0.029778686657664366, 0.0340638176567154, 0.036804862174903974, 0.07432948143105023, 0.08285807925858535, 0.01577723025548039, 0.05532434850465506, 0.031072828933247365, 0.008919796855479944, 0.04290234006475657, 0.12034700863296166, 0.10101494481205009, 0.12531372805824503, 0.281170810922049, 52.321946024894714, 84.3207585811615, 70.0477896630764, 54.74512159824371, 64.93230655789375, 46.93396434187889, 36.10601216554642, 37.1057765185833, 38.73908467590809, 62.672807201743126, 1.5635694307275116, 1.2114019528962672, 2.31593179050833, 1.6613075486384332, 4.684315491467714, 9.447377007454634, 3.318260768428445, 1.5708667016588151, 46.66614331305027, 82.96146512031555, 77.61572197079659, 77.242202013731, 77.91156649589539, 80.11194482445717, 79.9745973944664, 73.34073856472969, 72.66173779964447, 75.09257376194, 69.44162338972092, 71.12146764993668, 66.56473696231842, 60.60130275785923, 58.06633338332176, 54.95300844311714, 51.33070461452007, 55.19391551613808, 52.908163368701935, 53.84270042181015, 49.551921263337135, 53.86440105736256, 48.085237964987755, 58.39754641056061, 66.64040610194206, 68.33150535821915, 64.62212160229683, 65.02649590373039, 53.55244159698486, 48.70072513818741, 49.83420051634312, 48.1957246363163, 49.58388514816761, 47.41336941719055, 51.15006610751152, 54.07791160047054, 52.25756607949734, 54.73847575485706, 59.574145674705505, 65.0738337635994, 60.892880111932755, 62.99679681658745, 59.45327416062355, 61.85210824012756, 62.56632551550865, 65.06583139300346, 56.974370777606964, 56.89650535583496, 61.981080919504166, 65.54360255599022, 63.472288101911545, 62.938561141490936, 60.72490252554417, 57.86139518022537, 42.259443774819374, 52.898850068449974, 63.8835172355175, 52.429256066679955, 53.508614748716354, 50.62856689095497, 59.07391011714935, 59.330430552363396, 59.71300162374973, 61.37792028486729, 56.71580225229263, 58.40058624744415, 62.268486097455025, 56.277328580617905, 50.921789556741714, 48.49441900849342, 45.64321160316467, 44.24924500286579, 52.270033210515976, 55.718184784054756, 58.15337531268597, 59.72431741654873, 60.24487428367138, 51.82888828217983, 45.083938613533974, 47.28740997612476, 47.527234107255936, 48.26470993459225, 48.248355612158775, 49.510032311081886, 49.9019318819046, 49.82630833983421, 48.478676453232765, 49.59924392402172, 49.837149158120155, 53.10212396085262, 61.408455446362495, 65.95518127083778, 62.65757381916046, 60.327193066477776, 66.55833050608635, 66.59445896744728, 65.8474950492382, 66.32959797978401, 63.6372372508049, 66.83071509003639, 66.48092105984688, 64.99779224395752, 68.08527857065201, 65.14677464962006, 67.02170044183731, 64.81424689292908, 71.84326171875, 34.162359461188316, 0.19342581537785009, 0.38755978806875646, 1.7130918824113905, 2.4248565081506968, 1.242562299594283, 0.4942726087756455, 0.10476896524778567, 9.495020750910044, 68.33801060914993, 47.425566762685776, 27.039694860577583, 50.186244025826454, 66.7605784535408, 35.61699740588665, 36.926851719617844, 56.112197041511536, 55.67823752760887, 62.75232173502445, 59.25283491611481, 3.0407070368528366, 0.1018089240824338, 0.07647813254152425, 0.047138296358752996, 0.0209972855009255, 0.021730499574914575, 0.0911858445033431, 0.0288238413122599, 0.015614920703228563, 0.02339570641197497, 0.02314176017534919, 0.1059689957764931, 0.06318893196294084, 0.03927412108168937, 0.062179633387131616, 0.018606339872349054, 0.1128350046928972, 0.19405653700232506, 0.28561787854414433, 0.22867753315949813, 0.1368662214372307, 0.24900145508581772, 0.06404824991477653, 0.11639763266430236, 0.1396650681272149, 0.17618925747228786, 0.11728446945198812, 0.14840071031358093, 0.1928936064359732, 0.15979079209500924, 0.44995187607128173, 63.09662126004696, 96.41728028655052, 80.29105201363564, 67.10888296365738, 67.8893306851387, 55.364621356129646, 78.63398373126984, 61.10396258533001, 49.86118666827679, 76.1060705780983, 2.691157618537545, 1.1474228859879076, 2.2018965845927596, 2.3773564444854856, 8.090375773608685, 6.803273214027286, 10.536313075572252, 2.5433308258652687, 52.531850561499596, 86.84954568743706, 80.76527416706085, 78.18976476788521, 79.65484455227852, 82.91307851672173, 82.61211946606636, 75.71784541010857, 74.15343895554543, 77.14064866304398, 72.06041246652603, 75.24883657693863, 71.07859075069427, 63.539012521505356, 60.626947581768036, 58.001455664634705, 55.704858899116516, 58.40732328593731, 54.302076771855354, 55.694918632507324, 53.61003890633583, 57.345933839678764, 51.5029189735651, 61.27542458474636, 70.75140550732613, 71.42349824309349, 67.09739997982979, 67.82582849264145, 54.892135709524155, 51.75495944917202, 53.87238062918186, 51.623095124959946, 52.800819128751755, 50.70822201669216, 53.255407735705376, 56.69252470135689, 55.19494906067848, 56.89299054443836, 61.6368193924427, 67.44457215070724, 64.56479027867317, 64.71286073327065, 62.819870710372925, 62.64034554362297, 68.01460236310959, 68.86957168579102, 57.15894967317581, 57.22030498087406, 62.61100351810455, 65.35938084125519, 63.91420438885689, 64.88237723708153, 65.05845978856087, 60.116072595119476, 45.758147835731506, 57.31562286615372, 68.17028000950813, 56.516894325613976, 56.115575060248375, 53.28438878059387, 60.69731220602989, 61.25123508274555, 62.10135206580162, 62.55042336881161, 57.55675412714481, 62.19246357679367, 64.71224516630173, 59.592821672558784, 53.406647220253944, 51.01888194680214, 46.84251084923744, 47.497975677251816, 55.19758991897106, 59.66117240488529, 59.015773236751556, 61.237396225333214, 63.964194506406784, 54.1165517270565, 49.27145451307297, 48.68730425834656, 50.11788189411163, 50.16007483005524, 51.76435634493828, 53.1641860306263, 50.69448955357075, 52.667184099555016, 52.43206411600113, 53.37124451994896, 51.54212906956673, 55.58624446392059, 65.00355273485184, 70.74036329984665, 65.5558454990387, 61.12638138234615, 67.47416496276855, 68.31985518336296, 68.13429594039917, 69.88173857331276, 68.70521530508995, 69.16699692606926, 68.64849954843521, 66.41012325882912, 70.13201594352722, 69.18715104460716, 69.4685411453247, 67.27539002895355, 73.25630709528923, 37.56714776158333, 0.40814316482283175, 5.737079875543714, 6.5571746695786715, 3.327943361364305, 2.5031173462048173, 0.49396527057979256, 0.32956961542367935, 13.682036977261305, 76.34825438261032, 58.562058582901955, 44.53528605401516, 71.48633167147636, 86.31344005465508, 41.861829310655594, 42.10380792617798, 62.78848819434643, 64.09595623612404, 72.19138383865356, 70.7186208665371, 4.363693920895457, 0.21926995046669617, 0.22516635828651488, 0.20673961815191433, 0.1826250582234934, 0.13656265335157514, 0.26026175008155406, 0.11585140455281362, 0.15199746965663508, 0.08915284968679771, 0.0989233203290496, 0.2273543580668047, 0.1651977832079865, 0.09994702399126254, 0.167063839326147, 0.11497789673740044], [0.028143531235400587, 0.09272123672417365, 0.054451449250336736, 0.06721003650454804, 0.04207162819511723, 0.014170051017572405, 0.1393416104838252, 0.10267501784255728, 0.05746634255046956, 0.04505505443376023, 0.00456458067674248, 0.04898046645394061, 0.034879460217780434, 0.05291838737321086, 1.5442738286219537, 62.043602764606476, 65.6933905184269, 54.448395520448685, 37.80221834778786, 29.436522647738457, 46.881728544831276, 80.11879965662956, 52.54567801952362, 49.88439962267876, 34.45989489555359, 0.2319116791477427, 1.559793739579618, 1.3758121244609356, 1.0176191199570894, 2.847108612768352, 9.934535566717386, 2.971511324867606, 6.47054691798985, 67.18596562743187, 71.36971592903137, 73.31917092204094, 75.33959850668907, 72.32737094163895, 72.51388013362885, 65.07489010691643, 64.60393577814102, 70.5918824672699, 70.15739858150482, 72.02730104327202, 67.69839093089104, 66.9151921570301, 63.97130012512207, 64.51157033443451, 62.25183539092541, 51.61442779004574, 50.93092426657677, 51.6907162964344, 48.72012309730053, 49.682622849941254, 48.3138071000576, 48.66329714655876, 50.76839938759804, 63.13711188733578, 63.628733307123184, 64.82320681214333, 57.26979352533817, 50.39639934897423, 46.46011836826801, 47.35041819512844, 46.162620931863785, 47.36774146556854, 45.47894261777401, 47.047665640711784, 48.973884880542755, 49.383795484900475, 51.90999113023281, 58.07767957448959, 60.87014593183994, 62.626430690288544, 59.201682060956955, 60.92262111604214, 57.685555815696716, 59.69944775104523, 59.711717292666435, 58.54921527206898, 58.19127827882767, 54.59566421806812, 54.81562301516533, 55.590918213129044, 61.005962044000626, 60.93137584626675, 64.0249152481556, 47.03615605831146, 48.41774672269821, 63.79175215959549, 53.150008991360664, 53.06875415146351, 51.68657451868057, 56.627992764115334, 56.48615017533302, 54.256749004125595, 56.95492722094059, 54.34164024889469, 52.44486182928085, 60.13629510998726, 57.31900468468666, 55.76499067246914, 51.82100750505924, 46.77609421312809, 42.42564305663109, 44.648200795054436, 54.48758661746979, 53.631944730877876, 55.44140383601189, 60.23123301565647, 52.0005326718092, 45.56224934756756, 44.54443596303463, 45.43304868042469, 44.676129296422005, 45.980063527822495, 46.11003555357456, 45.72347089648247, 46.00088261067867, 46.26282915472984, 46.18416577577591, 48.4302594512701, 47.76054918766022, 57.67055802047253, 61.06060691177845, 63.513276502490044, 62.849231734871864, 65.62235713005066, 62.245033755898476, 67.23494499921799, 61.98929227888584, 58.59555758535862, 60.599220469594, 62.003701105713844, 60.97432114183903, 63.90976622700691, 60.19399881362915, 61.86653986573219, 59.19963777065277, 67.80036985874176, 58.567530289292336, 8.09698836877942, 0.45342085242737085, 1.6813054005615413, 0.0743873837927822, 0.5658075108658522, 0.22353566688252613, 0.22605684644076973, 0.08041309600230306, 37.28392235934734, 52.90380120277405, 48.50210599601269, 83.91896054148674, 107.50464454293251, 60.188017934560776, 21.964550390839577, 33.78465212881565, 47.02604480087757, 48.9472521096468, 49.905055314302444, 7.757793869823217, 0.2428858762141317, 0.0702919828472659, 0.05378162386477925, 0.060042055119993165, 0.048730325579526834, 0.07564993284177035, 0.05031749744375702, 0.07670829480048269, 0.04272625439625699, 0.06314851460047066, 0.09556821169098839, 0.05644688768370543, 0.03094197531027021, 0.03843313788820524, 0.03239424142520875, 0.01546926680020988, 0.03781735198572278, 0.03645717712061014, 0.03635000728536397, 0.048394455516245216, 0.09986335426219739, 0.07225828827358782, 0.04789385093317833, 0.04854871462157462, 0.01881766085716663, 0.01886416011984693, 0.10243632830679417, 0.053671151472372, 0.018012382388405968, 2.284335298463702, 76.47663429379463, 70.94039976596832, 65.2450829744339, 42.24936671555042, 40.141673013567924, 53.59867751598358, 73.4608881175518, 49.614082127809525, 57.7386237680912, 39.94968831539154, 0.203744666359853, 2.3872390016913414, 3.712870543822646, 3.147385362535715, 3.693405375815928, 10.472372956573963, 1.5348268230445683, 8.094298113137484, 70.23393407464027, 74.84724372625351, 74.49700132012367, 78.71360465884209, 73.176359385252, 74.10097137093544, 67.58400946855545, 65.90243250131607, 72.4976398050785, 73.36406171321869, 74.33750107884407, 70.70912137627602, 67.51158535480499, 68.86041417717934, 66.9772732257843, 64.95860874652863, 54.155191853642464, 52.901688516139984, 53.643503710627556, 51.48887872695923, 50.393078327178955, 51.683515682816505, 51.545488089323044, 52.623931020498276, 63.20339933037758, 67.34165847301483, 65.96440717577934, 61.45444057881832, 53.07915419340134, 50.55830106139183, 48.363820016384125, 47.365727573633194, 48.54541227221489, 49.238308891654015, 50.39750128984451, 50.978129133582115, 51.82247802615166, 54.13526572287083, 60.53171329200268, 63.38120698928833, 61.95956267416477, 60.29723547399044, 59.9417607486248, 61.01119436323643, 61.934259831905365, 59.43676024675369, 60.54770663380623, 59.67802830040455, 55.57560883462429, 55.35477988421917, 58.256687968969345, 63.46434272825718, 62.58904829621315, 63.84897708892822, 48.35975043475628, 51.029297187924385, 64.80986952781677, 56.34411379694939, 54.812704771757126, 53.534058183431625, 58.56561899185181, 57.27862425148487, 57.01605834066868, 59.09411743283272, 56.48015409708023, 52.13721513748169, 61.43416106700897, 58.34606297314167, 58.98287080228329, 53.54577675461769, 49.29296515882015, 44.47242982685566, 47.729778438806534, 56.35669492185116, 58.75472344458103, 58.6219509691, 63.01751710474491, 56.57995954155922, 47.23465360701084, 47.78258420526981, 47.68741071224213, 47.69783355295658, 49.5887640863657, 48.089440539479256, 48.593498691916466, 47.75988042354584, 47.877092733979225, 47.26604752242565, 48.294086158275604, 51.31629578769207, 59.39479909837246, 62.45372615754604, 67.14582458138466, 65.33274427056313, 66.46028056740761, 64.48554933071136, 67.99697130918503, 65.11784300208092, 60.3459944576025, 63.83084446191788, 63.96831348538399, 63.42220298945904, 63.216113448143005, 62.28413745760918, 65.14322564005852, 62.773049622774124, 70.52455008029938, 63.26866462826729, 13.544642999768257, 0.30252759461291134, 0.12125628054491244, 0.9253200539387763, 1.646254537627101, 0.6757707602810115, 0.23083376901922747, 0.185860124474857, 38.93136955797672, 60.87307557463646, 48.44318635761738, 79.7434101998806, 106.60035386681557, 62.917525470256805, 32.28651411831379, 43.072406351566315, 53.863166123628616, 54.72159706056118, 62.65022501349449, 15.809766054153442, 0.29783609323203564, 0.058624100347515196, 0.03352309257024899, 0.06019964646839071, 0.033622625705902465, 0.029053877406113315, 0.04639018552552443, 0.12928788433782756, 0.019032514464925043, 0.025112418297794648, 0.03733360528713092, 0.03874463582178578, 0.03106552620010916, 0.04787034711625893, 0.05419720429927111, 0.1018289101193659, 0.15644345374312252, 0.11319421901134774, 0.11049848631955683, 0.20908517588395625, 0.14704437606269494, 0.20978944434318691, 0.22317710565403104, 0.18897126690717414, 0.13049319153651595, 0.10612114347168244, 0.12430401387973689, 0.14495141571387649, 0.15315566532080993, 3.581490693613887, 87.44520172476768, 81.73128113150597, 74.56377133727074, 54.36389945447445, 42.00971357524395, 56.02371118962765, 90.9275096654892, 76.50678187608719, 71.61158055067062, 48.26429955661297, 0.2818332222523168, 5.002186484634876, 4.846536861732602, 4.518869044259191, 8.437562193721533, 20.041847862303257, 10.065467990934849, 7.618323778733611, 74.7216984629631, 74.86547514796257, 80.70684090256691, 82.68202051520348, 79.8441731929779, 74.1374722123146, 72.27640807628632, 69.20016154646873, 74.56465288996696, 74.2720153927803, 76.7276868224144, 73.45379009842873, 70.1564334332943, 73.00377264618874, 69.99638602137566, 66.62464454770088, 57.02110446989536, 54.349224641919136, 58.60665678977966, 54.47415433824062, 54.91907626390457, 53.60812000930309, 53.170383498072624, 55.72570078074932, 68.70198547840118, 69.86795291304588, 69.27718341350555, 62.026556879282, 57.32984930276871, 51.837662011384964, 51.22065491974354, 49.769216403365135, 53.37795875966549, 51.855456456542015, 52.75350786745548, 53.13795983791351, 53.521461859345436, 57.257789969444275, 63.03441859781742, 65.75715109705925, 66.1107449233532, 60.117254331707954, 61.59026809036732, 62.12392285466194, 64.34624880552292, 62.46729142963886, 61.725643426179886, 61.35577127337456, 57.6739664375782, 57.52915620803833, 60.013151317834854, 63.91029819846153, 67.70482778549194, 66.38096362352371, 51.70653484761715, 54.03402395546436, 67.7695383131504, 60.244399309158325, 57.92069099843502, 57.35701024532318, 60.7880437374115, 59.860110729932785, 56.92104823887348, 61.12694755196571, 59.48963060975075, 54.922731667757034, 64.85143169760704, 62.17344559729099, 60.889296904206276, 58.30510497093201, 51.28868646919727, 47.865807339549065, 51.29916250705719, 59.325129836797714, 60.78697219491005, 61.39065720140934, 66.23883605003357, 58.27137038111687, 50.922047942876816, 49.922625571489334, 49.04040031135082, 49.68994505703449, 51.930111050605774, 49.940986186265945, 50.46584442257881, 50.070000663399696, 50.84557704627514, 51.48858234286308, 51.683044508099556, 53.81791055202484, 61.98876790702343, 67.55741089582443, 68.62210616469383, 66.1346760392189, 70.39968878030777, 68.48861172795296, 70.47709062695503, 66.33332937955856, 64.0977269411087, 67.39752307534218, 68.81604015827179, 65.96337363123894, 69.00599956512451, 66.46427035331726, 67.45238453149796, 65.87385803461075, 74.45578873157501, 68.08703407645226, 18.580229692161083, 1.3847211026586592, 9.130475912243128, 4.281933233141899, 2.112353201955557, 0.7327473373152316, 0.44678738806396723, 0.20119065418839455, 45.45091912150383, 66.55842170119286, 61.20640508830547, 83.15807417035103, 107.79986590147018, 67.59514287114143, 32.17731937766075, 46.94628708064556, 64.80310589075089, 63.935924023389816, 75.61503052711487, 22.51772850751877, 0.578400450758636, 0.24971526756417006, 0.15484507544897497, 0.25136369629763067, 0.17306144640315324, 0.15527384384768084, 0.12887477525509894, 0.25751951441634446, 0.16394876351114362, 0.13823831890476868, 0.18935632280772552, 0.08008263990632258, 0.1673689065501094, 0.10394006792921573, 0.13882844505133107], [0.04796953515324276, 0.07350166764808819, 0.03388346092833672, 0.03549276734702289, 0.0625757992384024, 0.031036126019898802, 0.06752069952199236, 0.03404709706956055, 0.1220708544133231, 0.014973017696320312, 0.1044182336772792, 0.06901594897499308, 0.08927073242375627, 0.12181444981251843, 8.199474569410086, 74.23379704356194, 65.21546736359596, 57.830149456858635, 27.906466349959373, 16.9917344301939, 23.642530851066113, 41.46513059735298, 27.35112614929676, 65.1138000190258, 13.834600690752268, 0.2728231338551268, 1.6971678868867457, 2.91568495798856, 0.9862475283443928, 6.729352455586195, 18.984818682074547, 1.6784980637021363, 21.875283680856228, 75.65761104226112, 75.13511627912521, 67.52397269010544, 70.04747048020363, 66.03999271988869, 69.5947627723217, 62.89877347648144, 61.45126774907112, 69.93233665823936, 70.30695855617523, 71.40986457467079, 70.52301496267319, 70.26858821511269, 69.76320773363113, 67.41035118699074, 69.87377420067787, 59.353719502687454, 50.46429790556431, 48.280015513300896, 48.104445934295654, 48.28891843557358, 50.92677488923073, 49.88688088953495, 48.98030273616314, 58.52751083672047, 62.59452760219574, 60.44670045375824, 54.17601093649864, 50.62716856598854, 46.86411648988724, 44.872020184993744, 45.023141875863075, 46.04196220636368, 47.42915377020836, 48.580070212483406, 47.12634041905403, 46.1916171759367, 51.43050625920296, 55.779452696442604, 57.435673624277115, 59.89000752568245, 65.51757395267487, 51.11573114991188, 58.58472436666489, 61.94787450134754, 60.601564943790436, 59.22945857048035, 62.700306326150894, 59.20777313411236, 61.204957365989685, 64.20729786157608, 62.82426707446575, 55.65114118158817, 65.78014746308327, 46.36532485485077, 44.49127681553364, 63.476395681500435, 53.07308591902256, 57.52195939421654, 51.82197265326977, 56.51447385549545, 57.67084300518036, 55.18384225666523, 55.327147766947746, 56.19032844901085, 54.94790531694889, 55.186118334531784, 56.983247101306915, 57.881659492850304, 56.65828473865986, 52.82160401344299, 48.26093673706055, 47.97520346939564, 52.84526914358139, 57.24190682172775, 51.64473116397858, 59.61725056171417, 55.50004608929157, 48.445747420191765, 45.086704865098, 46.80295117199421, 45.51135487854481, 45.75103461742401, 46.54882840812206, 46.73881821334362, 44.192833229899406, 46.07292674481869, 46.56165651977062, 46.927193105220795, 48.83618026971817, 56.41862399876118, 58.665158450603485, 64.25961345434189, 63.29092763364315, 62.75705628097057, 62.29817770421505, 63.1765765696764, 58.84912557899952, 60.75527049601078, 59.11950007081032, 58.95108550786972, 56.47256590425968, 56.113276183605194, 53.61728131771088, 58.83022919297218, 61.7089319229126, 63.95281031727791, 49.74473811686039, 48.816102147102356, 4.920888422057033, 1.605597313027829, 2.43576358538121, 0.6217149796430022, 1.0370933124795556, 0.10312521204468794, 0.07044771511573344, 7.107975063845515, 64.14552077651024, 33.86706970632076, 32.9198033362627, 56.287010461091995, 56.02466493844986, 29.160547256469727, 18.55385910719633, 47.538295313715935, 48.5299851000309, 53.84228244423866, 29.707241021096706, 0.25590605568140745, 0.017658743454376236, 0.019654651296150405, 0.05201582447625697, 0.05148691067006439, 0.03306381076981779, 0.023266678472282365, 0.0228467620399897, 0.10284108080668375, 0.04769271406985354, 0.03991721059719566, 0.08868987570167519, 0.06868184893392026, 0.03867673673084937, 0.048077721730805933, 0.05093078230856918, 0.08738020027521998, 0.05148366006324068, 0.023586497736687306, 0.07117702363757417, 0.036887637616018765, 0.05761654952948447, 0.049806910974439234, 0.06907404429512098, 0.019278868530818727, 0.0580301447189413, 0.07637386821443215, 0.13006044522626325, 0.13300171005539596, 13.094231318682432, 89.96704280376434, 72.9712463915348, 67.22873613238335, 35.54205022752285, 28.473207838833332, 17.791697904467583, 41.249913945794106, 33.64640034735203, 72.39683881402016, 16.190327033400536, 0.4554043459938839, 1.4283787412568927, 4.197748750448227, 2.1212131390348077, 7.4162244983017445, 11.138518061488867, 1.1519607924856246, 22.895986810326576, 80.60711145401001, 77.38418519496918, 73.81014257669449, 71.73871412873268, 70.28900071978569, 70.77038168907166, 67.79750481247902, 64.25202906131744, 69.60569098591805, 71.70146092772484, 73.06391581892967, 72.43850737810135, 71.12173363566399, 71.02591797709465, 70.45002847909927, 70.87087869644165, 64.01138037443161, 52.29365274310112, 51.60086251795292, 49.85583275556564, 51.00139528512955, 52.644373923540115, 52.35528163611889, 52.86404013633728, 61.475255861878395, 63.661533147096634, 63.749471828341484, 57.44648024439812, 52.90377840399742, 50.62637820839882, 46.37929290533066, 46.96370154619217, 48.46795342862606, 48.80800478160381, 49.47720967233181, 49.32618297636509, 48.50531302392483, 54.48494955897331, 56.53086997568607, 59.51174162328243, 62.40169934928417, 65.52113056182861, 51.579720452427864, 62.22557879984379, 64.07286867499352, 62.71768279373646, 61.759712398052216, 65.7510182261467, 61.56200520694256, 64.79986846446991, 64.26935613155365, 64.64026182889938, 59.23184484243393, 67.90518343448639, 49.75550673902035, 46.54126301407814, 65.34561797976494, 56.96347676217556, 60.97578026354313, 53.91884833574295, 59.01704616844654, 58.87885898351669, 57.0916248857975, 55.30310645699501, 58.900092244148254, 55.80683022737503, 57.21792630851269, 57.644951194524765, 60.55761270225048, 57.57903233170509, 56.21223047375679, 50.126887410879135, 51.93145237863064, 54.67521294951439, 60.280174389481544, 54.66346397995949, 62.622855082154274, 59.999175667762756, 50.5514994263649, 47.45888337492943, 47.29500576853752, 46.903972551226616, 48.8388629257679, 48.729500994086266, 48.06980699300766, 47.11537420749664, 47.023947313427925, 47.88628824055195, 49.14775975048542, 50.82677185535431, 57.499403804540634, 60.630948767066, 65.93627348542213, 64.76421877741814, 64.24879923462868, 62.85564199090004, 64.63966146111488, 62.97047182917595, 62.552403062582016, 61.550811007618904, 62.36574187874794, 56.96777053177357, 58.26084114611149, 55.937159433960915, 59.302141070365906, 65.7110595703125, 65.60718834400177, 55.23711919784546, 56.16616174578667, 7.900572633370757, 0.8045826014131308, 0.5193764960858971, 2.4310050532221794, 1.0889288247562945, 0.5649879423435777, 0.11799673826317303, 5.693143308162689, 70.10154917836189, 39.87218387424946, 45.62988191843033, 73.85187193751335, 48.651988953351974, 34.84965518116951, 26.979745477437973, 54.70801658928394, 56.197236478328705, 60.94186328351498, 44.219602793455124, 0.5862426362000406, 0.03258329983509611, 0.02044713699433487, 0.031795458125998266, 0.038862384972162545, 0.05282376354443841, 0.05734856742492411, 0.018341823597438633, 0.09674497589003295, 0.033512802692712285, 0.04814429237740114, 0.03306049336970318, 0.02146542668924667, 0.045960975548950955, 0.030514450008922722, 0.14569060964277014, 0.14791893772780895, 0.1163316260499414, 0.10253705258946866, 0.13408281141892076, 0.23564483039081097, 0.17441583622712642, 0.15000728191807866, 0.26843766449019313, 0.182682337181177, 0.20481564482906833, 0.23163297300925478, 0.2061015195795335, 0.5351745639927685, 15.879190228879452, 104.67862978577614, 79.30105313658714, 77.7882707118988, 45.46816639602184, 30.838109739124775, 34.687666073441505, 56.29617556929588, 42.37903095781803, 82.10256680846214, 20.890226438641548, 0.5486560624558479, 3.9967775344848633, 11.141483802348375, 4.634105460718274, 19.441069699823856, 42.2532919049263, 4.19915372505784, 25.720016174018383, 81.31281718611717, 80.49985080957413, 77.69547209143639, 75.6161780655384, 73.61359432339668, 75.22400110960007, 70.61659634113312, 67.62732714414597, 72.22618997097015, 75.34731969237328, 76.09425321221352, 74.55527499318123, 73.39477926492691, 74.88106191158295, 73.06787520647049, 73.57599154114723, 65.60566842556, 56.16412505507469, 52.90708042681217, 52.40079939365387, 53.591913878917694, 57.87263497710228, 54.517624005675316, 55.23275323212147, 66.06159076094627, 66.77971422672272, 65.86375057697296, 60.56045114994049, 56.529464051127434, 53.04429866373539, 49.97776061296463, 50.13804741203785, 51.54746398329735, 51.01923152804375, 54.20994311571121, 51.95571407675743, 50.731138586997986, 57.11651735007763, 60.2731067687273, 61.79260343313217, 66.64283037185669, 67.19116374850273, 54.47098530828953, 63.216482028365135, 66.11944645643234, 66.69620990753174, 65.67593425512314, 69.269849807024, 63.76807942986488, 66.08319640159607, 68.88528764247894, 68.23200389742851, 60.39688892662525, 71.45975589752197, 53.29220876097679, 50.229565501213074, 66.1441071331501, 60.61999775469303, 64.24825966358185, 57.68564321100712, 62.121737971901894, 60.93520984053612, 57.57707163691521, 58.108199536800385, 61.297414004802704, 59.48352813720703, 57.94933766126633, 59.737742096185684, 63.122908249497414, 60.10179676115513, 57.495930790901184, 53.19945193827152, 56.049716994166374, 58.14032681286335, 64.42514777183533, 57.821523919701576, 64.73695904016495, 63.23250196874142, 53.56412976980209, 50.764451399445534, 50.532090067863464, 49.936004653573036, 51.22340217232704, 51.83019161224365, 51.68142959475517, 47.78469309210777, 48.838121965527534, 50.31273543834686, 52.10833288729191, 54.27178479731083, 61.04899473488331, 63.63630250096321, 70.36577939987183, 69.10011291503906, 67.57249608635902, 66.88368424773216, 67.02407911419868, 65.23628264665604, 66.29367470741272, 66.32831364870071, 64.1656368970871, 61.231308951973915, 61.8919263035059, 58.74221071600914, 63.36696155369282, 69.06067863106728, 69.53185334801674, 58.2559660077095, 55.58842554688454, 9.000526685267687, 3.2380881579592824, 12.131929155439138, 6.248268345370889, 2.5443059485405684, 0.6162468949332833, 0.2859579009236768, 9.426326137036085, 79.12270590662956, 46.8573984503746, 42.856140956282616, 65.67515149712563, 64.3397967517376, 35.44080466032028, 29.41303800791502, 62.72368647158146, 66.344333589077, 71.022619754076, 54.05492663383484, 1.206002205144614, 0.10776198003441095, 0.10601799236610532, 0.13219101761933416, 0.1453154836781323, 0.11343319798470475, 0.1079027728701476, 0.18486255925381556, 0.1451466153957881, 0.18538664910010993, 0.128699257329572, 0.11363126977812499, 0.16172390867723152, 0.12742687482386827, 0.16708332812413573], [0.07654920060303994, 0.08814966640784405, 0.028748040203936398, 0.056427135423291475, 0.0349303492839681, 0.026225634246657137, 0.05887782208446879, 0.037865591584704816, 0.031528945473837666, 0.04944654261635151, 0.05521549770492129, 0.07409445810480975, 0.08121570645016618, 0.1082536528701894, 35.83928167819977, 80.59859991073608, 62.17153809964657, 50.16502596437931, 28.486448228359222, 28.810052163898945, 51.318237483501434, 43.32011505961418, 46.20393991470337, 68.51692780852318, 2.260265965014696, 0.10244702265481465, 0.7282534253317863, 1.3133390829898417, 3.250351049937308, 3.0583874881267548, 3.871012357994914, 0.35715669917408377, 36.90354377031326, 76.74506708979607, 76.24075815081596, 74.72571864724159, 69.14292901754379, 69.9862177670002, 73.27496409416199, 68.52027162909508, 63.414234817028046, 69.71420556306839, 66.24111592769623, 67.38632127642632, 68.6903429031372, 67.52629056572914, 68.09288576245308, 66.48099705576897, 65.34937217831612, 60.47452636063099, 47.99447983503342, 48.02367366850376, 47.36785165965557, 48.29482711851597, 46.42018251121044, 47.089744582772255, 48.779844492673874, 54.29678365588188, 57.430030927062035, 56.421751230955124, 52.32076048851013, 48.15887801349163, 48.85338954627514, 43.63115876913071, 42.67598122358322, 44.40652996301651, 46.798478811979294, 47.93571978807449, 43.64609956741333, 50.788728296756744, 50.276378989219666, 56.98163598775864, 58.37168499827385, 59.710824340581894, 50.83610415458679, 49.9362288415432, 65.87568953633308, 57.54021741449833, 59.4095803052187, 58.2576797157526, 58.39835196733475, 57.884045764803886, 64.02917861938477, 57.73911394178867, 60.619074404239655, 53.65048013627529, 63.84624883532524, 45.31636454164982, 41.46372847259045, 61.779596731066704, 55.95572903752327, 58.425053134560585, 52.843962013721466, 57.60843515396118, 57.48792082071304, 52.96185828745365, 53.529126048088074, 55.490273013710976, 58.1006683409214, 58.30042362213135, 55.514283925294876, 55.30473276972771, 56.817454397678375, 56.19775705039501, 55.5038420855999, 52.26915545761585, 51.73244185745716, 54.3690025806427, 47.101014778018, 55.274247005581856, 57.593775540590286, 50.316862016916275, 44.14675310254097, 46.224337220191956, 43.52762572467327, 46.64013370871544, 45.46468198299408, 45.67675240337849, 44.373357743024826, 47.02847667038441, 46.18359200656414, 47.07063540816307, 47.854008972644806, 52.842426896095276, 54.536094814538956, 57.898785173892975, 57.27909542620182, 59.7977826744318, 57.377498745918274, 56.34794779121876, 54.666291028261185, 54.151335060596466, 55.15609614551067, 53.167510852217674, 50.20487442612648, 49.69444401562214, 58.46976913511753, 61.75306275486946, 65.92610523104668, 66.8561053276062, 64.72660079598427, 67.04610273241997, 54.6141654253006, 4.480621246621013, 0.14261219592299312, 2.3222480015829206, 0.7561189332045615, 0.14071968966163695, 0.18569392792414874, 0.25627205322962254, 35.812926292419434, 59.630166068673134, 21.997162140905857, 13.26853271573782, 70.45892000198364, 62.94618733227253, 21.879995428025723, 30.472447760403156, 47.654249891638756, 47.97308698296547, 49.20846149325371, 1.4350916747935116, 0.23716835567029193, 0.017569921365065966, 0.046946959555498324, 0.04937404963129666, 0.04840766945562791, 0.024608689273009077, 0.021767375037597958, 0.07287036714842543, 0.008082915883278474, 0.0679950654739514, 0.028137863082520198, 0.023150751294451766, 0.02867741000954993, 0.052156780584482476, 0.02806195250741439, 0.08467671214020811, 0.027899726446776185, 0.0200901862262981, 0.014108126215433003, 0.02400637706159614, 0.05769833420345094, 0.014623934621340595, 0.0354609403439099, 0.07598901269375347, 0.07760926950140856, 0.11158723922562785, 0.14737154444446787, 0.10753599606687203, 46.703457310795784, 88.43610495328903, 69.88784104585648, 60.034787356853485, 41.34058088064194, 34.36732046306133, 40.57134635746479, 47.52633735537529, 52.92807810008526, 78.3350233733654, 2.242613062262535, 0.14675251906737685, 1.3392490614205599, 2.6055816980078816, 3.537628697231412, 5.245246617123485, 4.600491989403963, 0.6067177187651396, 39.01717275381088, 76.83972761034966, 76.24261245131493, 77.48782083392143, 72.08437398076057, 72.45754435658455, 74.9682368338108, 70.76041862368584, 65.21240472793579, 72.87973210215569, 68.28786849975586, 70.80323472619057, 70.80901801586151, 70.19728124141693, 69.74526509642601, 68.94878223538399, 69.1233828663826, 64.93074864149094, 50.70124939084053, 51.096029207110405, 50.01175358891487, 50.604369789361954, 47.00749419629574, 49.946929067373276, 50.458214432001114, 56.4039795845747, 59.2329353839159, 59.34960812330246, 56.30808413028717, 51.757193729281425, 51.11940175294876, 46.64658956229687, 43.61681453883648, 47.62626439332962, 48.05014304816723, 48.88061888515949, 46.519820764660835, 53.3282346278429, 53.13139759004116, 59.347905814647675, 60.94554528594017, 63.600709810853004, 51.37209199368954, 50.87252140045166, 67.61315390467644, 59.42488968372345, 63.5104114562273, 61.779931113123894, 61.66947104036808, 60.259815081954, 66.85244992375374, 60.43702997267246, 61.83616429567337, 54.431220442056656, 68.44177544116974, 47.20672890543938, 42.6402897387743, 64.26874056458473, 57.36657813191414, 59.066109135746956, 55.64126931130886, 60.330571085214615, 60.30023351311684, 55.337000638246536, 55.69726690649986, 57.90739931166172, 59.220221266150475, 58.92393596470356, 57.783696949481964, 56.48015409708023, 58.54536607861519, 59.051495119929314, 58.10740917921066, 57.04762704670429, 55.25519482791424, 57.32036501169205, 51.19906447827816, 58.89204427599907, 61.185551807284355, 51.616491079330444, 47.14475043118, 47.80319429934025, 47.272533774375916, 49.0039374679327, 48.266226053237915, 47.92609490454197, 46.39603100717068, 49.38297092914581, 48.66822928190231, 49.9944569170475, 50.30585020780563, 55.376583114266396, 57.052790969610214, 60.29397524893284, 61.52840740978718, 61.43302492797375, 58.65349307656288, 57.03422136604786, 57.24024251103401, 55.78460521996021, 57.73003242909908, 56.321672201156616, 52.409489527344704, 51.70321002602577, 62.60120764374733, 62.87111096084118, 69.65809777379036, 68.65492880344391, 67.61651292443275, 65.84146857261658, 62.52242647111416, 7.283430173993111, 0.07985675983945839, 0.5948186572641134, 0.9244224114809185, 0.9230908798053861, 0.3076190542196855, 0.09863299215794541, 35.624555200338364, 68.91891583800316, 25.70317167788744, 14.477703832089901, 60.2960841357708, 55.197608917951584, 32.47369967401028, 38.334752172231674, 53.31955209374428, 55.59858240187168, 60.81217244267464, 3.796982355415821, 0.2806305867852643, 0.020604806268238463, 0.08615722254035063, 0.05058933871623594, 0.04814570987946354, 0.06964764281292446, 0.054661822141497396, 0.05734941718401387, 0.04094978292414453, 0.03201204279321246, 0.043999449553666636, 0.008385376313526649, 0.020145941925875377, 0.01649610603635665, 0.1766734494594857, 0.19469904393190518, 0.12242800556123257, 0.2011506524286233, 0.11990364218945615, 0.1508971318253316, 0.14882993884384632, 0.11044655824662186, 0.12273508400539868, 0.13102640979923308, 0.19378284778213128, 0.19197034504031762, 0.1774344773730263, 0.12726566550554708, 55.16351334750652, 99.44028407335281, 78.77797320485115, 67.7623338997364, 43.525269851088524, 44.519984275102615, 69.46608647704124, 62.69801504909992, 62.908873334527016, 83.51516380906105, 3.4858279768377542, 0.3663492965279147, 1.903009491506964, 6.043746694922447, 9.909580405801535, 13.079997282475233, 13.093370664864779, 1.2559246388264, 42.74247005581856, 81.57488912343979, 79.74033236503601, 80.49458429217339, 75.8438390493393, 75.1884426176548, 80.32607093453407, 74.56988140940666, 69.32081267237663, 73.23331072926521, 71.47935524582863, 71.22753515839577, 74.98050257563591, 72.10753753781319, 75.12340530753136, 71.81328892707825, 73.35051164031029, 67.0246870815754, 53.73837701976299, 52.42710538208485, 51.79823912680149, 53.62967625260353, 50.65753273665905, 52.131507843732834, 52.96415716409683, 59.906031265854836, 62.15116739273071, 61.92526191473007, 61.04339003562927, 53.34346421062946, 54.66639742255211, 49.84979867935181, 45.8127661049366, 49.49777036905289, 52.023323848843575, 52.23124489188194, 48.72703492641449, 56.293261125683784, 56.049640998244286, 64.10575211048126, 62.96538010239601, 66.14013254642487, 53.409554064273834, 52.96808235347271, 70.94853892922401, 62.918938994407654, 65.09709611535072, 64.85965445637703, 62.52723701298237, 63.32186937332153, 69.7265625, 65.05270689725876, 65.894133746624, 58.012372478842735, 70.98812520503998, 51.78894862532616, 44.36782144010067, 67.93631136417389, 59.56986330449581, 63.63793641328812, 57.84028351306915, 62.06618495285511, 61.593197733163834, 56.3877734541893, 57.98159413039684, 59.98117223381996, 63.67049306631088, 62.02863156795502, 58.6580528318882, 59.13924001157284, 62.37302988767624, 62.83016435801983, 62.1131656318903, 59.068613201379776, 57.15526007115841, 59.12467159330845, 52.25798785686493, 60.05213342607021, 63.607545644044876, 55.88032968342304, 50.78995183110237, 52.16167062520981, 50.805261209607124, 50.81649340689182, 51.80958151817322, 49.709909185767174, 50.5562149733305, 52.22483083605766, 51.84734009206295, 53.39173682034016, 53.00606891512871, 57.80662111938, 59.54677954316139, 61.05094403028488, 62.775580286979675, 64.49731349945068, 61.88971862196922, 60.06536811590195, 59.88367706537247, 59.51522223651409, 62.50193037092686, 60.605509132146835, 57.028096094727516, 55.13086549937725, 66.56839236617088, 67.08395630121231, 72.27869555354118, 71.04610249400139, 68.2619158923626, 68.70978266000748, 64.58713307976723, 6.579590141773224, 1.9182914402335882, 10.68655226379633, 3.4720565658062696, 1.5636231028474867, 0.30907802749425173, 0.27062512992415577, 44.654709845781326, 77.9975862801075, 33.028770089149475, 18.132039941847324, 87.98113256692886, 69.2430916428566, 32.36021876335144, 42.90884032845497, 63.53289104998112, 63.29972416162491, 75.59619873762131, 6.762462928891182, 0.49390978761948645, 0.1968245697207749, 0.33366846735589206, 0.12262465985259041, 0.17769096361007541, 0.13400239229667932, 0.11896541909663938, 0.24276190786622465, 0.10014801984652877, 0.21387740154750645, 0.18256964947795495, 0.11419277871027589, 0.13427875324850902, 0.09671241044998169], [0.02560699107561959, 0.02408303349511698, 0.010787736173369922, 0.053239262342685834, 0.018357952321821358, 0.06828320430940948, 0.02780411741696298, 0.056128179785446264, 0.019443335877440404, 0.037649225851055235, 0.004608404497048468, 0.05527045745111536, 0.037749248804175295, 0.539599604671821, 51.096268594264984, 68.85451689362526, 58.688242211937904, 52.70156845450401, 19.529870934784412, 29.01107467710972, 34.959739074110985, 26.28297496587038, 65.90332165360451, 42.52324841916561, 0.10140567814232782, 0.0036022213180331164, 0.6041780300438404, 1.129866640549153, 1.0244479472748935, 4.9508697632700205, 2.555603217333555, 2.2529036225751042, 48.74291427433491, 76.50039061903954, 69.40998628735542, 70.43167546391487, 69.71711620688438, 70.91253206133842, 70.0898990035057, 66.79654732346535, 64.77057203650475, 70.57144716382027, 67.9681384563446, 67.59149506688118, 66.33003115653992, 67.84412071108818, 66.4301709830761, 66.46843492984772, 63.230442479252815, 56.25750884413719, 49.93381977081299, 50.04998333752155, 49.000544250011444, 47.48669408261776, 46.387299075722694, 47.083638310432434, 45.75549177825451, 47.85903610289097, 52.2420971095562, 53.996637761592865, 50.773464515805244, 50.328147411346436, 47.40314416587353, 43.38243931531906, 43.76210354268551, 43.29199656844139, 46.578166633844376, 46.71208284795284, 47.90834605693817, 51.36708006262779, 52.922287210822105, 59.792409762740135, 54.64261069893837, 59.55806113779545, 53.945127725601196, 59.505612552165985, 59.98654894530773, 57.1022605150938, 58.407912254333496, 54.43089745938778, 54.438550248742104, 55.218446999788284, 55.18801063299179, 53.8284245878458, 57.5405365973711, 51.7047755420208, 64.28882628679276, 41.87768206000328, 36.31061978638172, 60.54857678711414, 53.45132902264595, 59.11696560680866, 55.22519923746586, 55.66543221473694, 55.354586094617844, 55.19697055220604, 54.96280811727047, 56.72866836190224, 56.396155804395676, 56.505437940359116, 54.532355815172195, 55.15803404152393, 56.975476518273354, 58.814486637711525, 57.74101763963699, 56.666032522916794, 55.15668511390686, 58.56460824608803, 43.985276967287064, 52.616916596889496, 58.811579793691635, 52.26513147354126, 44.25729677081108, 46.356832310557365, 44.39347766339779, 45.02472639083862, 45.476795732975006, 45.72087183594704, 46.880862191319466, 44.89972069859505, 47.1516128629446, 45.55513232946396, 46.724758967757225, 49.54279415309429, 52.95407250523567, 52.329253032803535, 55.188383013010025, 52.67093829810619, 53.53696122765541, 51.74526996910572, 52.29677997529507, 52.056990042328835, 51.630314737558365, 48.663479536771774, 51.240581050515175, 55.66615417599678, 62.77357019484043, 63.02491910755634, 65.30877515673637, 62.268125116825104, 67.98930332064629, 58.22604261338711, 70.32724186778069, 58.91448587179184, 4.076893860474229, 1.6569250775501132, 1.1418098746798933, 0.8374303544405848, 0.13839127554092556, 0.38733426423277706, 8.341176565736532, 62.4555766582489, 54.142048358917236, 61.58020243048668, 83.31822037696838, 90.35681828856468, 16.566689237952232, 28.070666939020157, 43.610069900751114, 52.54238739609718, 52.92232520878315, 5.543504012748599, 0.511119895381853, 0.20012316381325945, 0.07566236381535418, 0.11126154029625468, 0.05155750746780541, 0.08579598958021961, 0.08245722303399816, 0.08392012969125062, 0.04007303563412279, 0.010282723233103752, 0.06310901750111952, 0.08152858848916367, 0.08184924081433564, 0.03424142843869049, 0.030716911605850328, 0.05024431797210127, 0.04498201597016305, 0.11573796728043817, 0.05378952031605877, 0.08757799005252309, 0.03807184555626009, 0.06662944695563056, 0.010725947740866104, 0.10094994751852937, 0.05545761596295051, 0.09950309351552278, 0.027792287582997233, 0.8223828056361526, 65.91764688491821, 73.44383463263512, 68.1884354352951, 57.195860892534256, 32.64748714864254, 31.55051451176405, 32.319918125867844, 33.09334762394428, 73.29717010259628, 43.9849653840065, 0.16834831883898005, 0.03352681815158576, 1.000500088557601, 2.4204603815451264, 2.55774796474725, 6.026080967858434, 4.011498419567943, 3.9083774155005813, 50.18360696732998, 79.68125313520432, 70.22762641310692, 73.49124848842621, 71.26256167888641, 73.5892528295517, 72.75718867778778, 71.15229919552803, 66.89044028520584, 73.27376335859299, 71.1562205851078, 70.59595584869385, 70.02711117267609, 70.71764811873436, 68.65084782242775, 68.28057289123535, 65.38072809576988, 60.59363476932049, 51.03192664682865, 51.83496795594692, 49.55154128372669, 50.48952475190163, 47.71413467824459, 48.76508228480816, 48.669954389333725, 51.74183115363121, 56.35654293000698, 57.06457793712616, 54.204243421554565, 53.3868882805109, 50.51349766552448, 48.39690484106541, 47.29828879237175, 47.03697681427002, 48.56436185538769, 48.630147725343704, 49.77774314582348, 54.03292581439018, 56.304314732551575, 63.54278951883316, 56.96629621088505, 60.87063990533352, 55.00267557799816, 62.812719494104385, 63.42544041574001, 59.388681426644325, 60.16718365252018, 57.59330056607723, 57.4783681333065, 59.315208569169044, 58.03711675107479, 56.79148279130459, 59.966957196593285, 57.12091751396656, 65.75641393661499, 43.95717367529869, 39.81514513492584, 61.05360768735409, 54.6821665763855, 61.0878324508667, 56.7916651815176, 58.294822722673416, 54.73203890025616, 55.74625387787819, 56.228527799248695, 58.845306783914566, 56.52233563363552, 61.259290650486946, 56.51898041367531, 57.99293652176857, 60.0093325227499, 62.075578048825264, 60.38977190852165, 58.36149774491787, 57.64761105179787, 59.50406223535538, 46.60610653460026, 54.30475562810898, 61.173958629369736, 54.99266691505909, 45.012962222099304, 47.45396263897419, 44.58983212709427, 48.34104023873806, 48.10747057199478, 46.31073318421841, 47.87984378635883, 47.55859762430191, 48.58394220471382, 48.28875504434109, 49.04858127236366, 52.80516989529133, 53.95349107682705, 53.55025291442871, 56.53365142643452, 55.89441932737827, 55.362957045435905, 54.541452527046204, 54.97261539101601, 55.642405450344086, 54.57980006933212, 51.12162463366985, 54.51279826462269, 59.522411450743675, 64.94636580348015, 66.76901400089264, 65.58776378631592, 62.86649040877819, 69.20215263962746, 62.922943979501724, 70.33665776252747, 67.38927751779556, 5.963115021586418, 0.7948614761698991, 0.958740032510832, 1.4074917370453477, 0.6231562898028642, 0.47150553669780493, 7.405588869005442, 66.65943548083305, 54.08500961959362, 42.42605723440647, 85.312140583992, 69.52249065041542, 22.753327265381813, 40.034123584628105, 50.6737806648016, 57.48012363910675, 64.12333756685257, 11.971975788474083, 0.6131684069987386, 0.21737272414611652, 0.128049596096389, 0.0427556211798219, 0.07592057925648987, 0.061773103443556465, 0.06330583506496623, 0.0737427023705095, 0.08348621820914559, 0.019306131325720344, 0.028779457170458045, 0.0801127785234712, 0.14030430960701779, 0.003531911638674501, 0.09942395088728517, 0.17073831637389958, 0.10230092346318997, 0.12862400355516002, 0.09324025770183653, 0.14976464415667579, 0.1836646141600795, 0.27385148336179554, 0.16740124934585765, 0.2011699482682161, 0.12241928532603197, 0.2498142106924206, 0.2012270491104573, 1.9292684574611485, 81.19782775640488, 84.98665004968643, 76.72550573945045, 68.57406914234161, 32.0037142932415, 44.36415083706379, 50.45933537185192, 39.59663785994053, 82.01590865850449, 50.220202803611755, 0.5993863684125245, 0.1254311655065976, 2.537602395750582, 5.62150290235877, 6.335308374837041, 14.174926578998566, 8.953756894916296, 5.2128220070153475, 54.170809015631676, 80.117978900671, 71.9738607108593, 75.10721057653427, 76.2276716530323, 74.24134343862534, 78.12082126736641, 72.58164569735527, 72.05943211913109, 74.35188710689545, 74.96048524975777, 73.67994636297226, 73.26051726937294, 74.6123631298542, 71.98001638054848, 72.01395615935326, 68.75971958041191, 61.93734906613827, 55.227091535925865, 55.0641942769289, 52.23168946802616, 52.86729276180267, 50.98880656063557, 51.46963655948639, 50.22900693118572, 54.79102313518524, 60.184750109910965, 59.84335742890835, 57.803292497992516, 55.691464617848396, 53.96128445863724, 48.49323347210884, 48.80931191146374, 47.364211454987526, 51.464780420064926, 51.07422977685928, 53.47944751381874, 56.75772540271282, 59.149647653102875, 67.57629588246346, 61.30497559905052, 63.94296124577522, 56.90704599022865, 65.87477758526802, 67.28415235877037, 62.35629938542843, 65.2028900384903, 60.22972069680691, 59.34479758143425, 62.32212781906128, 59.99483250081539, 60.95958173274994, 62.06330470740795, 58.55961911380291, 68.28596860170364, 47.7732253074646, 41.340698674321175, 62.2799576818943, 58.55663247406483, 62.3771982640028, 59.985652193427086, 59.65165011584759, 58.45272324979305, 57.12116450071335, 58.160370737314224, 61.96692667901516, 59.80174586176872, 63.16607013344765, 59.510457292199135, 60.984120815992355, 62.86827631294727, 63.529159650206566, 63.58418069779873, 59.656031280756, 60.57238630950451, 60.76174154877663, 49.495437294244766, 56.52302339673042, 64.10488575696945, 57.53430113196373, 46.7024389654398, 51.132663041353226, 48.04084874689579, 50.77521242201328, 51.07324182987213, 50.04386566579342, 50.84873087704182, 50.1855980604887, 52.46639907360077, 50.10307028889656, 52.807936146855354, 55.08996069431305, 57.7083507925272, 56.73741169273853, 60.07727287709713, 58.44861947000027, 59.47762705385685, 57.503477185964584, 57.48497977852821, 58.945678398013115, 57.65975899994373, 53.615248426795006, 58.45088794827461, 61.88371494412422, 68.09822827577591, 69.71823334693909, 69.6746800839901, 65.16002833843231, 73.79071041941643, 64.84587639570236, 74.63786736130714, 67.80321970582008, 5.366294821724296, 4.518823446705937, 7.53080022521317, 2.16056359000504, 0.8642357785720378, 0.5961177125573158, 10.566344764083624, 75.42321681976318, 73.45546200871468, 77.25422456860542, 91.77209794521332, 96.91945374011993, 26.275160685181618, 40.501069128513336, 58.18603456020355, 66.63919776678085, 75.39718821644783, 17.320654280483723, 1.0025580343790352, 0.35720009997021407, 0.2300114545505494, 0.3457966446876526, 0.2137587172910571, 0.23361988045508042, 0.1557025231886655, 0.17153565015178174, 0.2260902282432653, 0.12323715433012694, 0.13125355151714757, 0.1514705448062159, 0.36295064608566463, 0.04252562219335232], [0.05439135384222027, 0.03331549531139899, 0.06937025769730099, 0.027461996614874806, 0.041666853430797346, 0.013704438697459409, 0.029672147647943348, 0.09390630555571988, 0.02445671783789294, 0.04056610741827171, 0.001759318352014816, 0.06472424254752696, 0.13269293209305033, 5.740829799324274, 65.904431194067, 59.94719825685024, 61.29584088921547, 28.353405967354774, 23.52236609905958, 32.89883226156235, 38.506343364715576, 40.07825821638107, 83.79944935441017, 16.856644079089165, 0.1440034556435421, 0.0933067021833267, 0.491210893378593, 1.0404234775342047, 2.1731798630207777, 8.346962705254555, 2.656889632344246, 6.229072725400329, 62.184928581118584, 70.7156266272068, 70.10810762643814, 66.62240266799927, 66.40875533223152, 67.04101100564003, 70.1299412548542, 69.51538503170013, 62.10377633571625, 66.85062602162361, 65.40842100977898, 65.89531168341637, 62.65853136777878, 62.280113473534584, 61.80469438433647, 60.428636223077774, 57.45260551571846, 51.82555206120014, 50.73289789259434, 44.97637778520584, 47.765340730547905, 47.39272512495518, 46.61092467606068, 47.50626303255558, 47.940420135855675, 47.737188041210175, 47.933808490633965, 46.909683644771576, 47.90352791547775, 46.96869067847729, 43.80202420055866, 44.685655385255814, 42.4822486191988, 45.13310797512531, 48.48181888461113, 46.940074414014816, 49.42568823695183, 51.676896438002586, 53.52283738553524, 58.9262842386961, 48.747747614979744, 49.94510896503925, 65.55162012577057, 57.42380306124687, 59.736738950014114, 55.968484953045845, 53.777944296598434, 50.669046118855476, 50.95006383955479, 46.09316445887089, 49.365917444229126, 48.29817853868008, 56.00735306739807, 54.56101767718792, 66.02624505758286, 39.232172816991806, 35.939258113503456, 59.90856572985649, 53.292288556694984, 59.80299599468708, 55.46848878264427, 55.841168984770775, 51.172511503100395, 55.560356453061104, 52.06832103431225, 59.24630306661129, 55.005498826503754, 57.5979895144701, 52.87749521434307, 57.16539032757282, 53.999081030488014, 57.405206859111786, 54.90283593535423, 56.808365285396576, 50.133035480976105, 54.76336821913719, 42.668480426073074, 52.34081581234932, 58.69109585881233, 56.832349598407745, 46.06918774545193, 43.6356995254755, 43.36275637149811, 43.169323951005936, 45.303730219602585, 44.38079014420509, 45.98274238407612, 46.17185063660145, 45.09927459061146, 45.33025659620762, 46.39320395886898, 47.25730039179325, 47.09296680986881, 52.50407785177231, 51.15222819149494, 51.894662752747536, 50.11464826762676, 50.14988757669926, 50.08260078728199, 49.321737214922905, 49.589736834168434, 52.12526097893715, 57.16933831572533, 61.01545013487339, 64.47601184248924, 66.40236407518387, 65.3037442266941, 66.09533295035362, 66.10110864043236, 66.8574732542038, 60.45984774827957, 69.49527651071548, 49.15479697287083, 0.388672326807864, 0.797226611757651, 0.9639270510524511, 0.4755345673765987, 0.036024820437887684, 0.13497877662302926, 39.516731947660446, 61.24322511255741, 44.23625349998474, 59.96526628732681, 51.605068892240524, 26.003993935883045, 15.759597346186638, 32.256678119301796, 43.02757255733013, 53.797745034098625, 22.827417589724064, 0.2045541416737251, 0.05629944891552441, 0.11538763646967709, 0.018619974980538245, 0.06365435503539629, 0.03921742470993195, 0.04399834375362843, 0.014886692933941958, 0.026335190086683724, 0.07575594121590257, 0.015516469247813802, 0.06451208479120396, 0.02734427158429753, 0.026016879237431567, 0.026269415393471718, 0.016905027550819796, 0.05601292425126303, 0.04333637400122825, 0.03026411432074383, 0.08218472867156379, 0.05400787129474338, 0.06810687002143823, 0.022222489678824786, 0.016730116331018507, 0.03733652563823853, 0.06658626138232648, 0.18912964122137055, 8.901312109082937, 82.70996421575546, 66.80676117539406, 66.62752479314804, 33.16636450588703, 24.49239894747734, 18.69351491332054, 42.02844277024269, 48.64989526569843, 93.36444810032845, 18.31090584397316, 0.1928034651791677, 0.22919461713172495, 3.79122756421566, 3.1761225080117583, 6.434212792664766, 12.965536024421453, 1.3738925149664283, 7.878936119377613, 64.74983274936676, 71.15095406770706, 72.44502782821655, 67.66498312354088, 68.95156368613243, 68.95497590303421, 74.82940748333931, 72.5980532169342, 65.93483716249466, 69.90136072039604, 69.14009436964989, 70.26516079902649, 65.70095971226692, 64.70713824033737, 64.57187309861183, 64.35577109456062, 60.17261356115341, 55.30470237135887, 52.038382440805435, 48.77687305212021, 50.05149185657501, 49.21414218842983, 48.82125087082386, 49.330982118844986, 51.084272637963295, 49.71443474292755, 50.361084043979645, 49.08182568848133, 49.65200789272785, 49.792634546756744, 46.59184589982033, 46.668282598257065, 45.5284121632576, 47.921778336167336, 50.68951942026615, 50.47734260559082, 51.16497650742531, 53.79098139703274, 56.682816222310066, 62.87255488336086, 53.10700669884682, 51.31412610411644, 66.2028519809246, 60.00798359513283, 63.17180782556534, 58.78237836062908, 57.223926186561584, 53.518262431025505, 53.43866050243378, 48.36790859699249, 52.76093266904354, 50.387906804680824, 58.36951531469822, 56.86083287000656, 66.25238612294197, 42.32408590614796, 37.98627287149429, 58.17887954413891, 57.150970101356506, 60.85878074169159, 56.4052677154541, 58.28921802341938, 52.08002820611, 55.99593847990036, 54.61681388318539, 59.88669030368328, 58.275063782930374, 60.046251341700554, 55.03530442714691, 58.67221087217331, 57.49326713383198, 59.02139313519001, 59.45563763380051, 59.07470427453518, 54.72241781651974, 56.44195854663849, 46.4853186160326, 52.30480894446373, 60.40794253349304, 58.37537080049515, 48.83212208747864, 45.48341877758503, 46.0521000623703, 44.71605375409126, 47.01555356383324, 46.26382850110531, 47.6885886490345, 46.61990359425545, 48.98124888539314, 47.143245711922646, 47.8064127266407, 51.19854390621185, 51.508899852633476, 54.33031305670738, 54.70076657831669, 52.288880199193954, 51.073124036192894, 52.20669060945511, 50.91585427522659, 52.16613158583641, 53.67090784013271, 54.60757277905941, 61.15873284637928, 64.69336777925491, 66.24221786856651, 67.74219498038292, 67.60121494531631, 68.71276929974556, 66.21026158332825, 67.38573610782623, 65.43775543570518, 68.94272536039352, 55.36898732185364, 0.652600375469774, 0.6220861722249538, 1.1739334696903825, 0.8737181103788316, 0.3828213829547167, 0.16333125211531296, 38.47881004214287, 70.06820976734161, 44.39341686666012, 63.938333094120026, 49.129653722047806, 29.50972381979227, 20.677247866988182, 35.3617575019598, 48.62211495637894, 62.22192719578743, 32.93027937412262, 0.3856542200082913, 0.04931839597702492, 0.09122702627792023, 0.0316410802770406, 0.006424479288398288, 0.0066973076172871515, 0.04622615975677036, 0.04984764374967199, 0.01752217714965809, 0.04674785988754593, 0.042119708232348785, 0.047295742988353595, 0.06823410381912254, 0.01725908208754845, 0.15185566007858142, 0.23963804502272978, 0.1612669535097666, 0.1142582658212632, 0.15562813030555844, 0.23569274344481528, 0.1264528653700836, 0.26540708960965276, 0.1560115534812212, 0.12878215522505343, 0.2227445226162672, 0.2078662725398317, 0.4327608266612515, 12.540806215256453, 97.5410395860672, 75.36211609840393, 80.82480937242508, 41.20284207165241, 32.71286264061928, 47.424795404076576, 58.94709572196007, 56.80059090256691, 101.96440503001213, 22.018608190119267, 0.24123078299453482, 0.257632439606823, 4.5516346860677, 6.595839494839311, 8.973419889807701, 18.813691064715385, 10.040645822882652, 10.049219112843275, 65.09938359260559, 72.137730717659, 73.03473338484764, 68.69547262787819, 70.5203703045845, 70.7140839099884, 75.53703591227531, 75.84323108196259, 67.99129441380501, 71.42989709973335, 70.67702069878578, 71.86021640896797, 67.72822692990303, 69.01588663458824, 67.19983488321304, 66.17802411317825, 63.1538537889719, 57.30390429496765, 55.77654965221882, 50.76492637395859, 53.95963914692402, 52.60709412395954, 51.88876546919346, 51.89433977007866, 52.9970595985651, 52.48493827879429, 52.7966545522213, 50.09766697883606, 54.182744175195694, 52.48780332505703, 48.89081373810768, 50.6963362544775, 47.13595770299435, 52.07650579512119, 53.575046584010124, 52.255875170230865, 55.00272877514362, 57.0527795702219, 59.897481724619865, 66.77525326609612, 55.20553149282932, 51.55787542462349, 71.69181704521179, 63.78855273127556, 67.02076569199562, 60.82699164748192, 59.764849841594696, 57.051837220788, 56.22146017849445, 49.729143753647804, 54.23819079995155, 53.641231432557106, 62.93347701430321, 60.9079235047102, 70.41757062077522, 45.082388296723366, 40.80497682094574, 60.61905540525913, 60.01159340143204, 60.88209629058838, 59.80943284928799, 59.527248591184616, 54.77802023291588, 57.30114944279194, 56.65585286915302, 62.98553042113781, 59.3200609087944, 64.14296731352806, 59.687767177820206, 60.53674802184105, 60.9995099902153, 63.845481276512146, 61.18393309414387, 61.40092045068741, 56.90140709280968, 59.766650944948196, 49.445621967315674, 55.79493306577206, 62.696799114346504, 62.690875232219696, 50.00501275062561, 49.698581993579865, 47.75086350739002, 46.632644310593605, 49.3440268188715, 49.22852821648121, 50.41282206773758, 49.147524163126945, 48.85413430631161, 51.017308831214905, 50.80474443733692, 53.5060840845108, 54.74840462207794, 57.706040516495705, 57.88729839026928, 56.14946164190769, 55.70001035928726, 55.171876698732376, 55.561625584959984, 55.356987565755844, 56.4247340708971, 58.00021693110466, 63.91347482800484, 68.23148712515831, 68.65343928337097, 71.01371303200722, 71.2389725446701, 70.95011964440346, 71.70377120375633, 71.29310443997383, 67.74743869900703, 72.6288391649723, 57.96621635556221, 0.4858474514912814, 4.277352578938007, 6.629312373697758, 1.357810590416193, 0.47054861148353666, 0.37378540844656527, 47.15499468147755, 77.467902302742, 58.85223001241684, 67.95022621750832, 63.464768305420876, 35.15609733760357, 23.777345716953278, 45.03071486949921, 57.8899772465229, 72.31043145060539, 39.705752804875374, 0.5825151549652219, 0.18248173466417938, 0.20817984477616847, 0.2274142493843101, 0.13736154563957825, 0.09678994261776097, 0.1580805127741769, 0.11826380010461435, 0.08493402216117829, 0.2295978704933077, 0.12607206939719617, 0.1956295783747919, 0.10729869434726425, 0.16814784990856424], [0.06965326087083668, 0.019448360217211302, 0.06785321878851391, 0.06494834888144396, 0.07351449195994064, 0.05656736422679387, 0.014868739453959279, 0.06556718130013905, 0.021176781337999273, 0.06675490702036768, 0.0419870233599795, 0.093468289996963, 0.10473593225469813, 23.776802346110344, 71.5938962996006, 62.99963906407356, 60.066618248820305, 39.32814806699753, 34.20254610478878, 47.07620970904827, 32.07348234951496, 54.29000481963158, 68.7682843208313, 3.134976178407669, 0.09856831398792565, 0.02208452257036697, 0.6753715442027897, 0.5081162753049284, 2.5752284517511725, 14.85913971439004, 1.7350041191093624, 17.654169984161854, 76.4507956802845, 72.78608232736588, 72.78638631105423, 66.53674766421318, 70.35054981708527, 66.34378641843796, 68.09885904192924, 67.48658269643784, 64.85870450735092, 67.60920971632004, 68.20124834775925, 61.612417101860046, 62.79059328138828, 59.40893813967705, 58.67539890110493, 57.15380474925041, 57.18795731663704, 53.058186918497086, 52.55621865391731, 49.41853702068329, 48.54794293642044, 44.482750073075294, 48.474542275071144, 46.109514981508255, 46.87032535672188, 46.98369227349758, 45.61762757599354, 47.23125658929348, 46.373973190784454, 44.66353677213192, 45.07185906171799, 45.24109438061714, 44.71194997429848, 45.85860684514046, 48.18494841456413, 48.41922864317894, 51.34293615818024, 52.95623458921909, 57.4769090116024, 59.37563292682171, 60.10458581149578, 54.087817668914795, 58.96413400769234, 54.36909377574921, 56.022027879953384, 52.50669591128826, 54.30466063320637, 46.53663866221905, 49.22751747071743, 43.56534630060196, 51.632594615221024, 47.21620939671993, 55.54574243724346, 55.74166752398014, 65.27637049555779, 37.39043824374676, 31.051128208637238, 62.823085337877274, 54.25225764513016, 60.0767333060503, 56.247899159789085, 59.83269900083542, 52.23177686333656, 52.623972818255424, 53.242211043834686, 54.476840794086456, 57.15368315577507, 55.3153607994318, 55.39775177836418, 52.42124989628792, 56.281538754701614, 56.68170288205147, 55.415892004966736, 54.49129141867161, 51.20083138346672, 52.38738991320133, 53.173514530062675, 45.82583360373974, 58.229838609695435, 57.475248500704765, 52.029840499162674, 43.59108991920948, 44.23901975154877, 43.27955983579159, 45.47084905207157, 45.316653326153755, 45.5766923725605, 44.12406072020531, 45.5310720205307, 46.608994379639626, 46.501691937446594, 45.584751740098, 48.103264197707176, 46.479174345731735, 47.73765541613102, 46.13473802804947, 51.29457235336304, 47.67389103770256, 51.17839738726616, 51.155815199017525, 53.49770173430443, 57.71329052746296, 60.458856001496315, 62.67479449510574, 64.57153111696243, 63.13726767897606, 67.5387690961361, 60.20197078585625, 61.56258277595043, 58.11424881219864, 65.59662491083145, 63.595530688762665, 74.14827883243561, 21.150618866086006, 0.5034805834293365, 1.2938518286682665, 0.9563459234777838, 0.016095516984933056, 0.12351747092907317, 10.73823044076562, 66.53787240386009, 43.00605051219463, 51.1045141518116, 28.59196286648512, 20.171460807323456, 29.090040139853954, 29.6171098574996, 46.19559556245804, 53.81799414753914, 37.72408314049244, 1.1702202376909554, 0.07852809285395779, 0.07029515181784518, 0.08418415614869446, 0.06799425653298385, 0.0736389055964537, 0.09252421878045425, 0.013744274401688017, 0.06306230672635138, 0.050983938635909, 0.037703495399910025, 0.036800639354623854, 0.01373720915580634, 0.06201210097060539, 0.020339605362096336, 0.04660042483010329, 0.020698873486253433, 0.06802553063607775, 0.0672837466117926, 0.0628642868832685, 0.013061127465334721, 0.03617571390350349, 0.0461197172262473, 0.02778365455014864, 0.050576647990965284, 0.0027034848881157814, 0.21188988554058596, 33.735991939902306, 82.44232937693596, 67.68224939703941, 67.54456758499146, 44.20013263821602, 45.01451633870602, 42.796757742762566, 39.92843985557556, 60.92727966606617, 73.79742085933685, 3.418682967312634, 0.059766454869532026, 0.3769967408152297, 2.820157608948648, 3.3736370969563723, 4.9858844093978405, 15.155749898403883, 1.1411175993271172, 19.473611153662205, 77.5156581401825, 74.01362925767899, 73.73994514346123, 70.02589523792267, 70.87202623486519, 67.43378832936287, 69.96920228004456, 71.5415807068348, 67.78455510735512, 69.68348041176796, 70.47675624489784, 63.18737559020519, 65.55649906396866, 61.9901130348444, 59.4533159583807, 58.83708022534847, 59.290213510394096, 56.341985911130905, 55.62743805348873, 52.775128707289696, 51.66169345378876, 47.87690654397011, 50.997363701462746, 48.45320641994476, 48.99009481072426, 48.17586310207844, 49.052783846855164, 47.362341955304146, 49.175118282437325, 47.02436909079552, 45.76535984873772, 46.30267761647701, 45.70460490882397, 49.72645349800587, 50.73416702449322, 52.22523361444473, 53.29714089632034, 56.864077895879745, 60.72439335286617, 62.801358103752136, 61.06366574764252, 55.77878013253212, 62.638054266572, 58.270716816186905, 58.25461708009243, 54.1610511392355, 56.7594201117754, 48.81915718317032, 51.73531450331211, 46.87178447842598, 54.263052865862846, 48.31086605787277, 57.68880844116211, 58.137647956609726, 67.93077126145363, 39.30661462247372, 31.392479091882706, 63.85393962264061, 57.97025553882122, 62.16683775186539, 58.372813537716866, 60.348536521196365, 53.44433359801769, 54.546624049544334, 55.40131978690624, 56.94923132658005, 59.65289644896984, 58.426956832408905, 57.64334388077259, 56.188223361968994, 58.44794310629368, 59.94489938020706, 58.10119271278381, 57.42372326552868, 54.47894588112831, 54.37040850520134, 54.7456269711256, 47.29973651468754, 58.9728469401598, 59.87559489905834, 54.11434404551983, 46.32593236863613, 45.207310393452644, 45.31897880136967, 46.904006749391556, 48.07741038501263, 48.81145499646664, 45.39816655218601, 48.309771716594696, 47.98749960958958, 47.349118664860725, 47.543911412358284, 51.679252311587334, 50.264466628432274, 49.843829199671745, 48.48160229623318, 51.40624836087227, 50.75825773179531, 53.170854672789574, 52.910743430256844, 55.780372247099876, 60.84073171019554, 64.1364012658596, 65.54647520184517, 65.63376411795616, 66.69852778315544, 68.11351865530014, 64.0220957994461, 64.96059983968735, 61.541748493909836, 66.52238443493843, 64.86295267939568, 76.67550802230835, 25.99622145295143, 0.395988745149225, 1.0939394496381283, 2.002326068468392, 0.35259664698969573, 0.0905576090735849, 9.49810428544879, 71.77922755479813, 50.559976771473885, 54.249476194381714, 32.38674893975258, 15.950913280248642, 27.566888071596622, 36.899025812745094, 52.71101854741573, 62.02122576534748, 48.04347820580006, 1.2963414075784385, 0.05899361196497921, 0.022653658925264608, 0.05641405135975219, 0.016526038707525004, 0.05276297051750589, 0.07739753476926126, 0.049567197274882346, 0.053806040523340926, 0.02219214140495751, 0.08012722813873552, 0.04619766870746389, 0.06039810417860281, 0.026498972802073695, 0.18780814338242635, 0.10717609897255898, 0.12299542198888958, 0.11422972282161936, 0.13848340575350448, 0.16148700029589236, 0.1300946285482496, 0.18174498982261866, 0.13614443829283118, 0.22161932283779606, 0.14426676963921636, 0.45654265210032463, 0.26160221721511334, 41.208211183547974, 95.46065121889114, 76.58567324280739, 79.42062512040138, 51.430392265319824, 49.51447807252407, 70.94508111476898, 49.4152007997036, 66.93913847208023, 79.9237485229969, 5.166442645713687, 0.16934834799030796, 0.4678383772261441, 4.615365341305733, 7.990044057369232, 7.806630274280906, 23.358592987060547, 5.405637910589576, 20.981280952692032, 81.91154345870018, 77.07673609256744, 78.48405137658119, 72.4988329410553, 74.98923450708389, 69.25234794616699, 70.60240030288696, 72.85338431596756, 71.82720378041267, 74.48299527168274, 74.81101647019386, 64.86451059579849, 68.65948095917702, 66.08242124319077, 61.92567989230156, 62.542420998215675, 64.04883116483688, 58.26118692755699, 58.03113207221031, 56.039419546723366, 53.858860954642296, 49.63986374437809, 54.11115221679211, 51.68074943125248, 52.50101521611214, 51.04332223534584, 51.37619197368622, 50.710498094558716, 51.684997603297234, 50.49422889947891, 49.727008268237114, 50.14506943523884, 47.899002358317375, 52.337270602583885, 54.60412256419659, 53.97621005773544, 56.78724221885204, 59.9659426510334, 63.29481862485409, 65.6459766626358, 62.337019219994545, 57.86175616085529, 66.115213483572, 58.96792620420456, 60.94507411122322, 56.04182481765747, 59.855607971549034, 52.05037459731102, 55.736260414123535, 49.07807148993015, 56.60723827779293, 51.51369519531727, 60.750532150268555, 62.905844897031784, 69.78729844093323, 43.7467485666275, 35.81948474049568, 66.55232682824135, 59.848722741007805, 64.29848536849022, 60.73234632611275, 63.477725610136986, 56.919551119208336, 56.624272763729095, 57.51492977142334, 58.21084722876549, 60.284308567643166, 60.235112607479095, 60.200675055384636, 57.94012315571308, 61.51184029877186, 64.33095082640648, 61.495922952890396, 60.21395154297352, 57.27619618177414, 57.05102026462555, 58.24831701815128, 50.61653293669224, 61.17458939552307, 62.71461255848408, 56.065858528018, 47.66050435602665, 48.063723519444466, 47.45169036090374, 49.97228890657425, 52.75348126888275, 52.082870453596115, 48.274714797735214, 52.237240970134735, 52.202571630477905, 49.873790591955185, 50.10479159653187, 52.981575429439545, 52.99859471619129, 53.839599788188934, 51.550230234861374, 56.46892569959164, 52.77351379394531, 57.00574569404125, 56.00155457854271, 57.868120819330215, 65.29614463448524, 66.18981868028641, 68.99907633662224, 67.43224561214447, 68.62193897366524, 72.11674064397812, 66.12854316830635, 68.33222731947899, 65.37540838122368, 71.5572814643383, 67.6946747303009, 79.70637738704681, 26.8553002551198, 1.391550642438233, 6.740754218772054, 3.470580819994211, 0.43043003766797483, 0.12919189495733008, 12.995755802839994, 78.06880965828896, 55.66493444144726, 62.304150983691216, 38.618513345718384, 27.620809078216553, 40.76314106583595, 44.232525900006294, 62.42952525615692, 68.89309242367744, 58.52319426834583, 2.386841685511172, 0.20209064183291048, 0.13274250755785033, 0.13437263492960483, 0.13911267276853323, 0.14014200191013515, 0.2196412766352296, 0.11992183222901076, 0.20332746062194929, 0.2114569314289838, 0.21968178305542096, 0.11039586213883013, 0.1573460389045067, 0.10696766679757275], [0.05024052188673522, 0.0999794781091623, 0.034535797603894025, 0.04885603797447402, 0.049077008734457195, 0.059646887457347475, 0.022532872535521165, 0.030714121130586136, 0.07480280837626196, 0.04898524588497821, 0.07709209647146054, 0.10538846559938975, 0.8407621819060296, 58.9000428467989, 66.72363683581352, 59.787033051252365, 54.55366887152195, 21.466047540307045, 13.627261016517878, 22.413560897111893, 37.3632887005806, 75.90107157826424, 42.94163636863232, 0.2529394836165011, 0.06527604418806732, 0.0905623217113316, 3.949086293578148, 2.6821509143337607, 10.629935301840305, 7.834843760356307, 0.2848523680586368, 34.294166788458824, 75.51238283514977, 69.34694766998291, 72.15744405984879, 69.76488724350929, 71.7941303551197, 69.51498985290527, 69.21420559287071, 67.47424095869064, 64.1103346645832, 65.72894141077995, 66.11253082752228, 64.66923907399178, 62.86219283938408, 59.91730906069279, 61.53546363115311, 59.597685411572456, 59.26302216947079, 54.772339537739754, 52.81504176557064, 49.78631928563118, 46.86241038143635, 45.43898016214371, 47.607162818312645, 48.613614812493324, 46.6798909753561, 46.46907448768616, 47.07185514271259, 47.9087146371603, 46.75708383321762, 45.4151326417923, 47.90903761982918, 42.18475878238678, 44.45955231785774, 45.52350662648678, 50.01445524394512, 52.89883866906166, 52.622498497366905, 55.286748334765434, 59.94733884930611, 56.512425765395164, 59.348608776926994, 58.88754531741142, 56.81842714548111, 55.17023518681526, 56.11396014690399, 50.68198822438717, 50.63835896551609, 44.81975398957729, 45.24985671043396, 43.1981910020113, 49.68298763036728, 47.23636731505394, 58.84349428117275, 53.96694615483284, 64.78966981172562, 33.57163555920124, 32.782113924622536, 65.99428877234459, 52.5103285163641, 58.542808815836906, 54.2810221016407, 58.72882783412933, 56.042428985238075, 52.10257239639759, 53.02580885589123, 54.74335469305515, 53.059053272008896, 57.39908158779144, 57.006699442863464, 56.620028391480446, 56.724902763962746, 56.45949460566044, 58.17752301692963, 57.11716331541538, 56.631047800183296, 56.47419981658459, 53.55775371193886, 47.3571552336216, 53.32022465765476, 59.927716702222824, 52.7651010453701, 45.21601192653179, 44.28538866341114, 45.055478140711784, 43.10939736664295, 43.70289131999016, 45.3184050321579, 45.82847446203232, 44.8161555826664, 46.57997153699398, 46.0458379983902, 45.37765525281429, 46.22709967195988, 44.97327335178852, 45.82341693341732, 46.67219638824463, 47.2475691139698, 51.843631491065025, 50.26292011141777, 55.57558983564377, 59.00177098810673, 63.769865334033966, 61.59470625221729, 62.9044845700264, 63.579658940434456, 65.51843270659447, 63.2472375780344, 63.19738045334816, 55.49936592578888, 54.52766306698322, 60.492461398243904, 64.11698430776596, 68.7629722058773, 56.095063760876656, 1.2036713864654303, 0.5444852518849075, 1.3161192275583744, 0.21454873349284753, 0.06682942606857978, 0.37687066476792097, 45.69016948342323, 62.66894280910492, 46.19653791189194, 35.59343867003918, 36.73879601061344, 20.15107110142708, 23.520080521702766, 43.3323048055172, 46.14551804959774, 51.433299109339714, 4.374872446060181, 0.39855708077084273, 0.008157357933669118, 0.040307721283170395, 0.05870096829312388, 0.10184181606746279, 0.0476543005061103, 0.0657031501759775, 0.0491381357278442, 0.01116341503802687, 0.07214523691800423, 0.0142775909989723, 0.02387952361459611, 0.04066671295731794, 0.05209972798184026, 0.020397709959070198, 0.0295434388317517, 0.04188200204225723, 0.04132832647883333, 0.03438190957240295, 0.055332590054604225, 0.032824865193106234, 0.05511423165444285, 0.03465833360678516, 0.09471636716625653, 0.026370443956693634, 2.201931495219469, 74.22007218003273, 72.21802040934563, 70.69962188601494, 64.57048997282982, 34.88664239645004, 20.676932483911514, 28.412034921348095, 44.34538744390011, 83.3848688006401, 44.93742227554321, 0.05229345821135212, 0.043968405516352504, 1.22266941703856, 2.5878107640892267, 5.137048847973347, 9.844002574682236, 9.844904076308012, 0.2302478879573755, 38.521975725889206, 75.80771058797836, 74.25394356250763, 72.56519258022308, 72.71820276975632, 72.91583776473999, 72.6248037815094, 68.88260498642921, 70.24906486272812, 67.02755212783813, 68.50033789873123, 67.82539531588554, 68.20167392492294, 66.12087517976761, 63.95840361714363, 63.575627356767654, 63.135420978069305, 60.84430351853371, 57.51079559326172, 56.76273733377457, 53.40487651526928, 49.12352465093136, 49.062868505716324, 49.38471883535385, 49.81185391545296, 50.29422663152218, 46.96064651012421, 49.03181657195091, 49.38327491283417, 48.6701063811779, 47.66815334558487, 48.05059902369976, 44.77274291217327, 47.29626730084419, 49.21750120818615, 51.56135983765125, 54.231864139437675, 54.43175621330738, 58.16968023777008, 62.208829298615456, 58.49191814661026, 61.16499871015549, 62.036535143852234, 61.17157235741615, 56.77060291171074, 58.2136020809412, 53.01959238946438, 52.53881178796291, 48.57726216316223, 48.03114026784897, 45.90753681957722, 50.33006630837917, 50.2552293241024, 63.23140002787113, 57.22337141633034, 69.33500111103058, 35.303913205862045, 34.625915586948395, 67.29590132832527, 56.11027434468269, 60.553740710020065, 56.32232956588268, 59.132875353097916, 58.97675313055515, 54.60022397339344, 53.2875844091177, 56.95504881441593, 56.134019270539284, 57.121126502752304, 57.3201560229063, 58.09221379458904, 58.33943992853165, 60.94096653163433, 59.22367908060551, 59.631822779774666, 57.714316472411156, 59.57063086330891, 55.19277177751064, 49.342248514294624, 54.3148934841156, 62.241431549191475, 56.23769290745258, 46.7749048769474, 45.362418070435524, 46.94766640663147, 45.925380662083626, 46.448388397693634, 46.860692873597145, 46.41779623925686, 46.69895075261593, 48.030802085995674, 47.37629100680351, 46.55054971575737, 48.038572669029236, 47.908821031451225, 49.01442490518093, 49.60638754069805, 48.73131349682808, 53.83773408830166, 52.73187182843685, 59.16085705161095, 61.410571932792664, 65.89468851685524, 64.95846435427666, 65.29798373579979, 66.54426366090775, 67.98269167542458, 64.64840859174728, 66.27421975135803, 57.798884734511375, 56.62092134356499, 61.86039939522743, 67.54148215055466, 70.21150767803192, 61.18239037692547, 1.9235239969566464, 0.5035755189601332, 1.1202320200391114, 0.8995694888290018, 0.21802072296850383, 0.21068615169497207, 47.41749219596386, 70.00522434711456, 53.3583328127861, 35.59684708714485, 24.004070051014423, 29.55834601074457, 28.63688785582781, 51.357211992144585, 49.824955612421036, 63.942018896341324, 9.509537871927023, 0.42687040055170655, 0.017874268705782015, 0.06780690135201439, 0.03844750586722512, 0.05092202496598475, 0.049974884968833067, 0.03706138551933691, 0.07563136430690065, 0.03388396929949522, 0.05775776538939681, 0.0284055928568705, 0.022153507052280474, 0.036410818865988404, 0.15423793927766383, 0.19748899969272316, 0.10790496220579371, 0.13654335751198232, 0.14999582315795124, 0.15098721371032298, 0.18203429382992908, 0.10101768333697692, 0.21081489947391674, 0.1355032969149761, 0.2689407515572384, 0.1967755879741162, 3.7831491976976395, 88.77206012606621, 81.85671240091324, 77.60076597332954, 72.86747395992279, 35.974269434809685, 19.404857642948627, 35.113535821437836, 53.53430137038231, 92.3609447479248, 53.485401794314384, 0.6136930163484067, 0.13763722381554544, 2.5809841929003596, 8.859054576605558, 9.644507579505444, 22.537635639309883, 15.663193669170141, 1.0312729747965932, 42.346174120903015, 78.9279055595398, 77.61734068393707, 76.02033957839012, 77.90641397237778, 76.52602404356003, 74.33404326438904, 69.72638010978699, 72.18933954834938, 69.13752570748329, 71.40005350112915, 70.30046090483665, 71.8968540430069, 68.26316982507706, 67.93659254908562, 67.55797326564789, 66.55367955565453, 65.40455281734467, 60.198805555701256, 58.82749333977699, 54.07258428633213, 51.344494074583054, 52.90670424699783, 51.784993037581444, 53.16870018839836, 51.653064116835594, 50.18976643681526, 51.52208514511585, 53.843467980623245, 51.856820583343506, 50.3559847176075, 51.768494322896004, 46.98892459273338, 50.28774417936802, 51.88361294567585, 53.86063925921917, 59.28743585944176, 57.50947706401348, 61.528456807136536, 64.53456670045853, 61.132540851831436, 62.14406557381153, 64.40006911754608, 63.83975878357887, 61.521339789032936, 61.628820821642876, 56.82438902556896, 56.397569328546524, 50.09319841861725, 48.85379992425442, 47.896635085344315, 53.76202695071697, 52.95868545770645, 64.16281744837761, 59.98453505337238, 69.67222541570663, 40.375554263591766, 36.28909774124622, 71.2425671517849, 58.346537947654724, 63.809550404548645, 57.83914737403393, 60.97291901707649, 60.13904616236687, 55.863781571388245, 55.96085496246815, 60.439184457063675, 57.604407370090485, 59.13957439363003, 60.17382189631462, 59.030676037073135, 62.7082858979702, 63.52903425693512, 63.28991308808327, 61.77118018269539, 60.12094393372536, 63.446365892887115, 58.76876749098301, 52.21634969115257, 56.76140360534191, 65.62101200222969, 59.16325092315674, 51.45706683397293, 48.85560482740402, 49.311086386442184, 47.28131130337715, 49.56085458397865, 50.592434629797935, 50.34500330686569, 48.399028927087784, 51.09710454940796, 50.742568373680115, 49.2978934943676, 51.63254141807556, 50.86678370833397, 51.550652012228966, 53.23315232992172, 52.06595376133919, 57.35776640474796, 55.01552268862724, 62.02258609235287, 64.50949564576149, 69.28233593702316, 67.68334373831749, 66.38734728097916, 68.76280501484871, 71.81002110242844, 67.42157578468323, 70.89088082313538, 60.390178486704826, 60.41518874466419, 65.4527798295021, 71.75215020775795, 73.44577252864838, 64.3185330927372, 1.5958541608415544, 2.816005856730044, 5.9575654193758965, 0.9244328015483916, 0.2746504498645663, 0.7398467813618481, 55.26444353163242, 76.90829873085022, 60.46922944486141, 49.93349298834801, 51.470259726047516, 32.81440079212189, 35.2537102997303, 61.38599865138531, 57.07496277987957, 76.00275412201881, 12.360085062682629, 0.752159011317417, 0.22391192091163248, 0.30398713191971183, 0.20585051039233804, 0.29293747327756137, 0.19037334714084864, 0.18491868046112359, 0.15234660560963675, 0.08242179290391505, 0.18923993920907378, 0.16040653717936948, 0.13824683876009658, 0.17025557899614796], [0.15513930731685832, 0.05512568670383189, 0.04644102264137473, 0.025444143466302194, 0.04526198375970125, 0.0687922137149144, 0.05384297721320763, 0.07713157130638137, 0.07690262616961263, 0.1886815027683042, 0.16742541367420927, 0.5046116758603603, 11.812270358204842, 73.11168685555458, 63.208677247166634, 42.563032284379005, 26.25689696520567, 22.690917514264584, 48.10763776302338, 46.1788384616375, 39.87966567277908, 78.69240939617157, 17.14258063584566, 0.10445073232403956, 0.043490198950166814, 0.32427911181002855, 1.526837395504117, 1.6553018521517515, 4.009301187470555, 1.4372526900842786, 0.7575310918036848, 55.01699700951576, 75.9725533425808, 70.8376456797123, 66.58964082598686, 68.34219038486481, 66.7163260281086, 70.48662811517715, 70.52886664867401, 70.72425216436386, 64.46582078933716, 67.14648574590683, 68.32993984222412, 66.62091314792633, 64.71461623907089, 63.92140120267868, 62.60308854281902, 60.58728910982609, 62.485405057668686, 59.349931105971336, 56.76359988749027, 53.7690793722868, 45.01667462289333, 45.7077207416296, 45.77544070780277, 47.39638052880764, 44.72633220255375, 47.17036485671997, 45.61071954667568, 46.20099127292633, 46.59806236624718, 46.140042543411255, 43.31185810267925, 42.935811281204224, 44.64932553470135, 45.239342674613, 48.5696017742157, 52.087251618504524, 53.98199334740639, 56.007185876369476, 56.411256194114685, 58.16310279071331, 59.11103032529354, 55.96506133675575, 55.25877043604851, 51.45966209471226, 48.89965586364269, 47.915235087275505, 45.36133132874966, 43.27406533062458, 46.658498123288155, 46.125405728816986, 48.65182176232338, 47.670361027121544, 58.08139197528362, 53.53188470005989, 60.86739107966423, 32.4275017529726, 40.20030006766319, 64.854486733675, 52.776508033275604, 55.200747549533844, 53.131427988409996, 57.57690444588661, 57.07410782575607, 55.529650300741196, 50.86488761007786, 56.556305810809135, 54.33932237327099, 52.51219421625137, 51.02191038429737, 53.489167392253876, 56.42338514328003, 58.14026981592178, 55.9541255235672, 56.404036581516266, 53.71218882501125, 54.027362912893295, 54.297000244259834, 47.6854994148016, 48.613443821668625, 59.10874664783478, 56.979500502347946, 47.3317763954401, 43.06091196835041, 43.94874952733517, 44.49154660105705, 45.39992965757847, 44.27887961268425, 45.903676226735115, 44.44108530879021, 46.1952193826437, 44.03151288628578, 44.65343691408634, 44.78920362889767, 44.09817650914192, 43.93969461321831, 50.44702783226967, 50.08857026696205, 54.38228286802769, 53.8911098241806, 61.89177431166172, 59.70423549413681, 63.05979743599892, 63.1190400570631, 65.240029245615, 61.5231104940176, 60.995379611849785, 60.32807841897011, 54.15238380432129, 46.78740240633488, 55.79543083906174, 61.228770688176155, 66.6727727651596, 62.46253788471222, 68.58453378081322, 17.46569249778986, 0.29781130549963564, 2.915100264362991, 1.7364327237010002, 0.2711943571921438, 0.033813146146712825, 15.241005923599005, 70.03749221563339, 49.63443003594875, 39.548080265522, 31.251014582812786, 21.039467230439186, 17.583351284265518, 37.57636986672878, 52.908402755856514, 53.99530403316021, 26.327768862247467, 1.3394139963202178, 0.13980882213218138, 0.052683367757708766, 0.03141756395052653, 0.04266181742423214, 0.051890794857172295, 0.03901118929206859, 0.015500656863878248, 0.035001610303879716, 0.03966943717387039, 0.04371154078398831, 0.06658148195128888, 0.0425585364428116, 0.0504049001756357, 0.07598110139952041, 0.09693639804027043, 0.061411662682075985, 0.067833767097909, 0.020485049608396366, 0.06595672719413415, 0.07121758942957968, 0.04312601966375951, 0.11683563338010572, 0.11927119878237136, 0.5866210721433163, 16.69736422598362, 87.08530783653259, 68.99479016661644, 52.91789084672928, 36.73688471317291, 27.005035020411015, 23.14045049250126, 44.28579904139042, 48.42986427247524, 85.20025938749313, 17.574877738952637, 0.14427272166358307, 0.1827653092914261, 1.68406393378973, 4.589910507202148, 5.200919145718217, 5.667445287108421, 2.0845709927380085, 1.2056905031204224, 57.86533556878567, 78.7088093161583, 72.96501472592354, 70.26712149381638, 71.46373048424721, 70.44467076659203, 72.77288183569908, 71.68338149785995, 73.81389677524567, 67.22692742943764, 68.46914157271385, 70.57333946228027, 67.92418241500854, 68.05339828133583, 66.408481746912, 65.41140764951706, 62.241902723908424, 65.1827435195446, 60.60604490339756, 60.14192260801792, 55.34180358052254, 47.86174915730953, 49.97621409595013, 46.53330624103546, 46.95534199476242, 47.21907824277878, 50.22842176258564, 47.697810754179955, 48.30170854926109, 48.72375190258026, 47.43985779583454, 45.56135259568691, 44.60046775639057, 45.935499519109726, 47.283765971660614, 52.35086627304554, 54.9002368748188, 56.7807749658823, 58.585298135876656, 60.13597592711449, 58.78911539912224, 61.975035443902016, 57.844573482871056, 57.324445992708206, 54.50927585363388, 51.12300395965576, 52.4930964410305, 49.16009768843651, 46.50283947587013, 49.458210691809654, 47.435419633984566, 50.321372374892235, 47.94881388545036, 59.208704084157944, 57.11434006690979, 64.12687137722969, 34.790275767445564, 41.92736819386482, 67.89351046085358, 54.17855679988861, 57.27369971573353, 56.76746428012848, 59.550100564956665, 58.318677842617035, 58.163680359721184, 51.325510293245316, 58.69600139558315, 56.256946474313736, 55.36633126437664, 53.02205465734005, 53.94745320081711, 56.62022218108177, 59.636975303292274, 57.69492231309414, 58.1239040941, 56.84590347111225, 57.343532368540764, 56.88085779547691, 49.6091727912426, 49.565760120749474, 62.363705188035965, 58.41178044676781, 50.07520258426666, 45.20272023975849, 46.820939406752586, 45.75872540473938, 47.98119194805622, 46.54981255531311, 47.32383482158184, 47.3146241158247, 47.6457155495882, 46.44868478178978, 48.14688965678215, 46.44512057304382, 47.296825870871544, 47.44440995156765, 53.592411652207375, 53.58976699411869, 56.48856304585934, 57.84385912120342, 62.67226383090019, 62.42620423436165, 65.65270990133286, 66.15780919790268, 66.6009110212326, 63.71478728950024, 62.59369544684887, 61.89479514956474, 57.032587453722954, 51.38070613145828, 57.961177825927734, 64.00182008743286, 70.1830168068409, 63.97859573364258, 72.36856073141098, 20.98513014614582, 0.026605207531247288, 2.518533356487751, 2.5043717538937926, 0.35438376828096807, 0.06199085328262299, 15.637872777879238, 72.85276874899864, 57.41471774876118, 47.21828408539295, 32.074584290385246, 24.097944013774395, 20.924937576055527, 44.29808758199215, 58.3171921223402, 59.292227402329445, 37.944110333919525, 1.9011632655747235, 0.0338791045214748, 0.08551366918254644, 0.023284755334316287, 0.03556065530574415, 0.08192616442102008, 0.013641003624798032, 0.01842080851929495, 0.027558503643376753, 0.035164660148439, 0.09132429957389832, 0.024163465604942758, 0.02596471182187088, 0.20322977914474905, 0.1700788439484313, 0.1696729485411197, 0.15099908807314932, 0.21844247065018862, 0.12883612420409918, 0.17481132672401145, 0.20309628162067384, 0.1704064427758567, 0.3368641255656257, 0.3676162613555789, 1.0368616436608136, 20.228227861225605, 97.79614269733429, 79.75113898515701, 59.87629786133766, 38.50067786872387, 34.748660400509834, 65.21711647510529, 68.6785863339901, 53.66167053580284, 93.7244787812233, 21.12646546214819, 0.43843641586136073, 0.21065861801616848, 4.542613970115781, 6.3642034493386745, 9.203393999487162, 10.571648329496384, 4.046736778691411, 1.2446311698295176, 67.47218146920204, 82.23406255245209, 78.87393325567245, 71.69145986437798, 74.57974568009377, 72.00856804847717, 76.29732951521873, 75.03427729010582, 77.24713414907455, 68.42230528593063, 72.83612564206123, 71.25732555985451, 71.69408932328224, 69.66429144144058, 69.95537862181664, 66.94489136338234, 65.14181971549988, 68.3190268278122, 64.29712504148483, 63.896915316581726, 59.39176686108112, 49.15078818798065, 51.553498059511185, 49.016742780804634, 50.2990447729826, 48.553566634655, 54.49380308389664, 50.95552034676075, 51.6960284113884, 50.46777851879597, 50.277389734983444, 46.421368047595024, 47.6017215102911, 49.75738763809204, 47.889244481921196, 54.60732959210873, 57.66562968492508, 58.73124450445175, 61.15149423480034, 61.093239560723305, 61.023593097925186, 65.57189583778381, 60.25206349790096, 60.08400611579418, 55.900020226836205, 53.01509343087673, 54.50508087873459, 51.93709887564182, 49.661469385027885, 51.34510964155197, 51.798535510897636, 52.87675425410271, 51.873231902718544, 62.70235441625118, 60.08636198937893, 65.84943294525146, 39.77423653006554, 45.01503311097622, 71.10354021191597, 57.38428898155689, 60.08463308215141, 59.86653618514538, 61.7777044326067, 61.46748527884483, 58.59370708465576, 53.69365721940994, 58.84948655962944, 58.38995061814785, 56.37143053114414, 54.8123399913311, 56.69538974761963, 59.59377162158489, 63.26543100178242, 61.004202738404274, 61.50234080851078, 59.186479076743126, 60.0562410056591, 59.05409798026085, 51.71511098742485, 52.34610132873058, 63.64374630153179, 61.14825300872326, 52.20183067023754, 47.59397752583027, 47.4402491748333, 50.644374042749405, 50.48009745776653, 48.601721450686455, 48.99660766124725, 48.56945738196373, 49.50228072702885, 48.14990669488907, 49.993928745388985, 49.90479312837124, 50.580651462078094, 49.837354347109795, 58.22366014122963, 56.18760019540787, 58.84067863225937, 61.811446622014046, 64.61805582046509, 65.24072840809822, 67.73384302854538, 69.25593495368958, 70.34584566950798, 66.75514474511147, 66.1336500942707, 67.14839324355125, 59.79299873113632, 53.04137662053108, 61.18641436100006, 66.71146988868713, 73.61356392502785, 67.85583168268204, 75.14334663748741, 22.690041661262512, 0.632821130566299, 9.917925707995892, 2.974935653619468, 0.6496545835398138, 0.19687803403940052, 19.219142608344555, 82.21305727958679, 59.844786152243614, 58.77355143427849, 43.99743631482124, 31.132162660360336, 28.50142702460289, 55.11355742812157, 67.09572046995163, 71.55696228146553, 45.41089586913586, 2.0256002945825458, 0.244256533915177, 0.11871391267050058, 0.10264007010846399, 0.15851070609642193, 0.13021886406932026, 0.14145346591249108, 0.09979289476177655, 0.16909272264456376, 0.08786396181676537, 0.25996880955062807, 0.2194423959008418, 0.12061504268785939], [0.024636547641421203, 0.041266991684096865, 0.04042080974613782, 0.02959845238365233, 0.09026553685544059, 0.022081268252804875, 0.03632261090388056, 0.024795940553303808, 0.12389100869768299, 0.07452281832229346, 0.08279345303890295, 0.04072875279234722, 33.356521502137184, 83.58797550201416, 55.006992146372795, 47.35344283282757, 41.31899043917656, 26.196062229573727, 53.429559990763664, 34.65269275009632, 61.95379078388214, 67.26772964000702, 4.957732195034623, 0.18464505061274394, 0.15565823181532323, 0.6711288343649358, 0.2150978337158449, 5.76132494956255, 0.8299297350458801, 0.7947898737620562, 6.297729816287756, 75.98288878798485, 68.92713099718094, 70.10262832045555, 63.551574647426605, 63.615627810359, 64.47944685816765, 67.06888630986214, 66.36614441871643, 68.46116960048676, 67.5504344701767, 69.45398032665253, 66.99735134840012, 68.15510362386703, 66.17623060941696, 64.6941277384758, 63.09226669371128, 64.95103195309639, 63.024672120809555, 62.15452641248703, 59.376959055662155, 58.852268010377884, 46.61726273596287, 46.22165456414223, 45.06242036819458, 46.563408225774765, 47.16296665370464, 45.70547506213188, 44.28704917430878, 46.50091677904129, 45.46577252447605, 45.7378189265728, 44.472965598106384, 42.25508540868759, 45.89904427528381, 48.26717220246792, 50.950466617941856, 54.61161196231842, 56.987833455204964, 57.50650942325592, 60.46281158924103, 57.626172602176666, 53.7730273604393, 56.760009080171585, 50.72041176259518, 45.07692039012909, 47.351132556796074, 45.43639250099659, 45.02569533884525, 43.479702696204185, 46.96421071887016, 49.153630435466766, 48.348795622587204, 47.20512539148331, 57.3360201716423, 56.734299659729004, 62.35092647373676, 30.742588564753532, 46.356395334005356, 62.05062858760357, 52.434093207120895, 55.99791057407856, 55.1357938349247, 55.39489433169365, 55.94904899597168, 55.52615828812122, 49.67958301305771, 58.675003722310066, 57.074753791093826, 58.4478747099638, 52.36945107579231, 49.38471883535385, 45.693190321326256, 47.360970228910446, 54.63647402822971, 56.25591292977333, 56.748510897159576, 58.07869412004948, 55.71838237345219, 51.39337845146656, 48.3550500869751, 54.38762158155441, 57.500296756625175, 48.196431398391724, 41.88894845545292, 45.97036264836788, 42.26352855563164, 43.8992153853178, 45.39602346718311, 45.74041798710823, 46.224629804492, 46.45989038050175, 44.63872030377388, 45.165121257305145, 43.75025577843189, 45.65207652747631, 45.95544844865799, 50.461045280098915, 51.76561027765274, 53.516769111156464, 58.23432616889477, 60.31756438314915, 61.77583493292332, 60.908531472086906, 63.25917273759842, 61.056769117712975, 60.5197249352932, 54.68462884426117, 48.23695242404938, 48.64355720579624, 53.64930979907513, 60.250771567225456, 62.75162257254124, 63.30561004579067, 66.4934603869915, 67.65880465507507, 51.508573070168495, 0.9029314771760255, 0.6131035136058927, 1.6207328508608043, 0.24818343023071066, 0.019673073256853968, 2.085043117403984, 47.7316365391016, 67.6317273080349, 42.62602150440216, 35.69906920194626, 31.553022377192974, 18.804379664361477, 29.20125637203455, 40.11450067162514, 49.37898114323616, 47.09395855665207, 5.363978371024132, 0.37515867850743234, 0.04090211106813513, 0.09284979896619916, 0.03998067164502572, 0.055386848471243866, 0.06363823558785953, 0.07192880439106375, 0.13312235358171165, 0.009885272538667778, 0.021960027297609486, 0.02251461941341404, 0.04258783643308561, 0.08263242183602415, 0.019028210008400492, 0.03469026451057289, 0.034198524881503545, 0.020088924575247802, 0.043562992505030707, 0.04843503615120426, 0.027358366824046243, 0.03281597055320162, 0.06561948044691235, 0.0392589330294868, 0.1039411366218701, 44.27423246204853, 89.57470625638962, 63.138248026371, 51.83239169418812, 43.223843425512314, 34.654771238565445, 43.13697248697281, 39.482396990060806, 68.71341526508331, 73.695327937603, 5.175447687506676, 0.17110290384152904, 0.34530394768808037, 1.7261654371395707, 2.709700148552656, 4.63496801443398, 1.3451227149926126, 0.55713981972076, 8.15652072429657, 77.95546174049377, 74.1847112774849, 71.5875506401062, 67.06347540020943, 65.91029807925224, 66.4528101682663, 70.11333614587784, 71.10436856746674, 70.11998578906059, 68.90107959508896, 69.31978672742844, 69.71586987376213, 69.19076085090637, 68.35666760802269, 66.3213600218296, 66.50558173656464, 66.19442403316498, 64.68775928020477, 64.68831405043602, 61.37499064207077, 61.690742298960686, 48.81960555911064, 48.077178597450256, 47.55645453929901, 48.59852582216263, 50.343206003308296, 48.20348002016544, 48.82335215806961, 49.85881179571152, 47.93336011469364, 47.98499174416065, 45.75671151280403, 45.45685060322285, 48.93705725669861, 51.85078650712967, 52.20041334629059, 57.081646621227264, 61.37127064168453, 59.81410279870033, 62.26412773132324, 58.659215569496155, 57.40986540913582, 57.80160918831825, 53.63641329109669, 48.98516267538071, 49.11968305706978, 48.35932485759258, 48.533359318971634, 46.02942667901516, 48.16320978105068, 52.13255658745766, 52.02700585126877, 50.10465860366821, 58.58909793198109, 59.65565890073776, 62.60124944150448, 34.17191594839096, 48.512369245290756, 62.84479737281799, 54.98883672058582, 58.720460683107376, 57.79446177184582, 59.81279566884041, 57.401604652404785, 58.594045266509056, 50.23748807609081, 60.53273543715477, 59.04694676399231, 59.67281877994537, 55.2520751953125, 49.90580007433891, 47.64225013554096, 48.987149968743324, 57.10123836994171, 60.26483081281185, 58.13178867101669, 58.345500603318214, 57.13521234691143, 53.084204122424126, 51.22991882264614, 58.01060177385807, 59.68689702451229, 50.54861918091774, 44.99277390539646, 47.95718863606453, 45.720279067754745, 47.11151361465454, 46.68485730886459, 46.97561390697956, 47.69998423755169, 48.666952550411224, 46.80235080420971, 47.70750783383846, 46.61112606525421, 47.250194773077965, 48.31612877547741, 51.38237804174423, 54.61084820330143, 55.81705927848816, 60.30649557709694, 62.6134467869997, 62.845629528164864, 64.03610944747925, 64.83206793665886, 62.428723499178886, 62.43774801492691, 56.844448149204254, 51.51008538901806, 51.93318888545036, 56.564684361219406, 62.87252448499203, 65.77266186475754, 66.35143920779228, 70.16625210642815, 67.68642157316208, 57.87272997200489, 2.3216806445270777, 0.8070955134462565, 2.5996727775782347, 0.45306417625397444, 0.01416449047610513, 1.6812062496319413, 51.67653165757656, 73.05487230420113, 50.39790786802769, 30.702673606574535, 26.403863579034805, 29.74828641861677, 38.053502663969994, 46.981860771775246, 58.02497640252113, 58.46361346542835, 7.521476000547409, 0.42056063131894916, 0.10916767452727072, 0.06960920698475093, 0.04541458416497335, 0.03958943736506626, 0.027403435597079806, 0.05364781463867985, 0.062214748104452156, 0.013134865403117146, 0.06537837150972337, 0.015208990043902304, 0.05882377146917861, 0.22195971629116684, 0.18252105364808813, 0.07756675186101347, 0.0958618795266375, 0.22610526415519416, 0.12656023929594085, 0.12275714063434862, 0.09223925633705221, 0.22670934267807752, 0.12851662962930277, 0.13778596505289897, 0.16908366844290867, 53.59700180590153, 99.60243657231331, 72.78046622872353, 63.224472999572754, 54.932474344968796, 38.460567221045494, 73.60045462846756, 51.985105499625206, 76.76569998264313, 80.96746891736984, 6.563294716179371, 0.34021385363303125, 0.7532294257543981, 3.840041644871235, 3.113633911125362, 15.566551554948092, 2.818463137373328, 2.975014499388635, 10.786038525402546, 84.16840195655823, 74.18204382061958, 77.63826236128807, 69.9257630109787, 67.87335634231567, 70.38485437631607, 71.84253975749016, 71.75812348723412, 73.51400926709175, 70.01527860760689, 72.99658343195915, 71.75582841038704, 71.4791576564312, 70.81498369574547, 67.88398057222366, 68.9950181543827, 71.13416656851768, 68.94524082541466, 67.38588809967041, 63.36791530251503, 64.96105581521988, 51.97239138185978, 50.66988207399845, 49.190408661961555, 50.747268721461296, 52.31252633035183, 50.410409197211266, 49.12033662199974, 52.45684638619423, 49.7420022636652, 51.405780985951424, 48.41083109378815, 48.800443187355995, 52.02289067208767, 53.92117381095886, 56.56246908009052, 61.40682153403759, 63.04645635187626, 60.66324703395367, 66.25881537795067, 62.25981496274471, 59.12070840597153, 63.4434362500906, 57.1110038459301, 50.615655183792114, 52.48130567371845, 50.93263037502766, 50.60293726623058, 49.037083089351654, 51.10234446823597, 54.843061342835426, 55.60335874557495, 52.4161771684885, 62.5320665538311, 64.49368089437485, 65.73929205536842, 38.73054273426533, 54.2119912058115, 68.62417325377464, 58.06306175887585, 60.798348784446716, 60.38670167326927, 61.46177418529987, 60.92452101409435, 60.69280564785004, 53.912213891744614, 63.022966012358665, 60.41309505701065, 62.93999366462231, 58.59865441918373, 51.71049803495407, 49.25773724913597, 48.93277868628502, 59.15334105491638, 62.42988623678684, 62.319061383605, 62.62367203831673, 61.01572372019291, 52.82429426908493, 52.34666749835014, 59.52089913189411, 63.68073731660843, 52.91748806834221, 45.969207510352135, 51.13366238772869, 46.5636096149683, 49.1808445751667, 49.21603448688984, 50.24175524711609, 49.4421299546957, 52.06492021679878, 48.5767187923193, 50.790829584002495, 48.82807910442352, 50.02705916762352, 51.59268155694008, 55.895715057849884, 58.07452194392681, 58.15070025622845, 62.757949233055115, 65.85930481553078, 67.65155464410782, 65.54663479328156, 69.31714206933975, 66.8603079020977, 66.01254299283028, 60.070923417806625, 55.526614263653755, 55.30883274972439, 59.01038512587547, 64.24303114414215, 70.05852028727531, 67.59342536330223, 72.72938936948776, 70.5391412973404, 60.27665197849274, 2.430895809084177, 3.077295273542404, 5.825627474114299, 1.272738736588508, 0.16221491358010098, 2.553045004606247, 57.719168812036514, 80.38023322820663, 57.9624355584383, 49.409178122878075, 44.709392711520195, 29.475128576159477, 46.33196644484997, 58.131249099969864, 65.61867132782936, 69.46324422955513, 9.487693794071674, 0.6591823941562325, 0.22059765266021714, 0.15108306950423867, 0.2016171219293028, 0.14234350877813995, 0.14305239339591935, 0.11978684298810549, 0.23494188295444474, 0.1285225074389018, 0.07074499721056782, 0.14976179430959746, 0.19527974480297416], [0.032899974248721264, 0.026285113672201987, 0.09539814112940803, 0.0463298823160585, 0.007782985248923069, 0.03334564135002438, 0.0515372357040178, 0.04272269950888585, 0.0513464146933984, 0.022200386665645055, 0.026454846556589473, 0.5845098104327917, 53.36835287511349, 70.21441832184792, 49.901111125946045, 58.249012380838394, 24.087526872754097, 16.57377775758505, 35.2491619437933, 36.778279691934586, 76.45271837711334, 41.25708416104317, 0.19971812929725274, 0.04864271133556031, 0.17984773381613195, 0.859571706969291, 3.6649805260822177, 3.771598292514682, 1.5309915225952864, 0.3732749295886606, 33.18431854248047, 81.39402642846107, 67.85581648349762, 69.5853240787983, 61.93424843251705, 59.72439341247082, 58.615552112460136, 63.03140535950661, 61.71012885868549, 65.14196410775185, 64.7388057410717, 65.04915788769722, 65.5639998614788, 65.5368161201477, 66.3543650507927, 66.39198303222656, 66.82604134082794, 64.7661566734314, 63.078978806734085, 62.92295537889004, 61.430665254592896, 59.61233362555504, 52.734345495700836, 44.319727420806885, 46.9905699044466, 45.97884379327297, 46.3425412774086, 46.84808515012264, 46.98215335607529, 44.760268181562424, 46.09998509287834, 45.41917942464352, 43.67751248180866, 43.370591551065445, 45.99933609366417, 46.100399270653725, 53.69271107017994, 54.84695613384247, 57.66751438379288, 59.322447180747986, 58.62640433013439, 55.609271228313446, 55.106296017766, 51.16708919405937, 46.77036792039871, 46.79030165076256, 47.420463636517525, 44.36275631189346, 46.313210651278496, 47.902802154421806, 49.818549156188965, 47.22382798790932, 50.4762976616621, 49.9241378903389, 55.491488948464394, 56.564615964889526, 61.08158178627491, 32.79971458017826, 45.00040389597416, 59.971972927451134, 52.48028352856636, 54.590614289045334, 56.47287368774414, 56.92148141562939, 55.78438863158226, 52.79736131429672, 48.864636942744255, 56.50755822658539, 55.79654797911644, 53.970962539315224, 56.29535861313343, 49.889449551701546, 55.27750343084335, 59.575517401099205, 50.686384588479996, 53.36657457053661, 53.197001069784164, 53.822322115302086, 52.20194086432457, 55.594049245119095, 47.30491563677788, 53.62319000065327, 57.52820245921612, 51.487658992409706, 45.74881173670292, 45.12099042534828, 44.601721689105034, 42.33223646879196, 44.66503009200096, 44.576221257448196, 47.54150614142418, 44.74307030439377, 45.604788064956665, 43.93949322402477, 45.80002918839455, 44.13670264184475, 46.71974703669548, 46.971038952469826, 53.06758761405945, 55.986055210232735, 59.17203985154629, 60.236054956912994, 61.756417974829674, 60.49045130610466, 59.442345947027206, 54.69873748719692, 49.6257247030735, 47.16851815581322, 49.70765970647335, 52.20606364309788, 60.73192834854126, 62.60082766413689, 66.09510496258736, 63.97799536585808, 69.32544082403183, 58.68874378502369, 74.28168207406998, 21.69596940279007, 0.5406649131327868, 1.9305086159147322, 0.35308836435433477, 0.21911509393248707, 0.028111555802752264, 19.418557807803154, 65.44527143239975, 53.64934399724007, 55.71978069841862, 31.882626190781593, 13.6671332269907, 26.620782539248466, 38.16716976463795, 47.698711305856705, 49.307818561792374, 17.039055190980434, 0.6094117148313671, 0.05611867287370842, 0.07277559489011765, 0.04182195116300136, 0.08747421554289758, 0.02553704736783402, 0.06585338313016109, 0.023488122351409402, 0.07199777217465453, 0.016188053523364943, 0.026621673932822887, 0.06276798580074683, 0.04813486339116935, 0.04189124178083148, 0.026134008694498334, 0.04046383575769141, 0.04441679258889053, 0.016190101850952487, 0.06401133548934013, 0.04571283105178736, 0.051202040995121934, 0.06545196287333965, 0.04727837673272006, 1.2619571713730693, 67.54399001598358, 78.02968695759773, 57.10930533707142, 64.86387982964516, 35.71815177798271, 22.28067632764578, 38.27180474996567, 43.29379007220268, 83.3177188038826, 44.37414430081844, 0.059925497116637416, 0.08399276368436404, 0.9723136760294437, 4.079932747408748, 5.387301994487643, 2.7766242949292064, 1.1712776497006416, 0.052262150711612776, 35.80723039805889, 85.69546401500702, 71.03567585349083, 72.60458126664162, 64.53870847821236, 61.63796313107014, 59.50427882373333, 65.94915479421616, 66.17325156927109, 68.10186088085175, 67.73078039288521, 65.2955974638462, 65.77778398990631, 66.38340309262276, 68.75706732273102, 67.41928830742836, 66.03544056415558, 66.92901581525803, 66.66158616542816, 64.84911382198334, 63.68883468210697, 61.03838570415974, 54.26559492945671, 48.66496905684471, 48.15765827894211, 47.6958766579628, 49.18508514761925, 49.80362355709076, 48.505389019846916, 48.72056387364864, 49.257946237921715, 47.31075592339039, 48.34851823747158, 45.16537584364414, 49.112554639577866, 48.819711953401566, 57.34481669962406, 58.04802976548672, 59.35085445642471, 61.37875624001026, 59.74786475300789, 57.8376654535532, 56.66480138897896, 53.6693499237299, 49.875359907746315, 47.41987846791744, 49.84146572649479, 48.086396902799606, 46.56564250588417, 49.073975309729576, 53.31273525953293, 47.73111216723919, 52.22713351249695, 51.34583160281181, 59.08053696155548, 58.12642715871334, 62.773752585053444, 35.87071359157562, 46.80797830224037, 62.22727730870247, 55.04933327436447, 57.066880613565445, 58.471205458045006, 59.27156791090965, 58.190822303295135, 53.54735367000103, 50.79228490591049, 58.7399460375309, 57.103651240468025, 57.37258940935135, 57.915755063295364, 52.71626226603985, 51.75321154296398, 60.12605845928192, 51.232099905610085, 53.15922349691391, 55.65370224416256, 55.12754067778587, 53.59616205096245, 56.64835587143898, 52.388507053256035, 56.12611949443817, 59.725951328873634, 53.22896495461464, 46.481446623802185, 47.1071058511734, 46.594270169734955, 44.503451362252235, 46.5552918612957, 45.12475982308388, 49.834208115935326, 47.54501335322857, 46.96576103568077, 46.47933393716812, 47.85933628678322, 46.863307133316994, 48.05731326341629, 51.24128021299839, 55.3531763702631, 57.367509081959724, 60.84883287549019, 60.59375636279583, 64.08431366086006, 61.74817621707916, 60.29665030539036, 55.61888091266155, 51.13869331777096, 48.39291885495186, 51.90583035349846, 54.80972193181515, 64.68904361128807, 65.06162881851196, 68.89337360858917, 66.37275606393814, 70.13596773147583, 61.38678140938282, 77.23454922437668, 27.75267720222473, 0.21326461021089926, 0.7242122234310955, 0.8535398275125772, 0.43961176997981966, 0.017887911235447973, 19.71545297652483, 71.8699286878109, 58.758603036403656, 51.65125921368599, 18.422239869832993, 17.09921546280384, 35.115507915616035, 45.54120987653732, 55.20756058394909, 58.22966381907463, 24.007474668323994, 0.53027538000606, 0.0596534109354252, 0.13568694877903908, 0.03603316217777319, 0.030939262760512065, 0.054108461990836076, 0.06300386259681545, 0.022991746154730208, 0.02653449755598558, 0.033242894714931026, 0.024371114814130124, 0.034917688244604506, 0.1391436203266494, 0.09673909065895714, 0.11640529162832536, 0.14592837891541421, 0.14216671435860917, 0.14045348129002377, 0.1342954664141871, 0.14178934710798785, 0.15762456692755222, 0.17515204672235996, 0.1463109560427256, 1.6778358304873109, 80.09678363800049, 87.38485336303711, 68.26390698552132, 72.03904241323471, 36.47948272526264, 26.791300289332867, 51.61283187568188, 52.1776981651783, 88.83680865168571, 50.998511239886284, 0.5138602608349174, 0.2291868839529343, 3.234956176020205, 4.571402175351977, 12.196348048746586, 11.377647779881954, 8.084547836333513, 0.932326759211719, 41.354700922966, 85.51859110593796, 74.00707840919495, 74.80448842048645, 68.32933187484741, 63.93037632107735, 64.57941949367523, 70.47602668404579, 68.06998059153557, 71.4212715625763, 69.90259945392609, 68.75484064221382, 69.29987579584122, 68.32005277276039, 72.90443077683449, 70.90669557452202, 69.13147643208504, 70.24892807006836, 69.8889809846878, 68.52651089429855, 68.63829329609871, 62.106861770153046, 58.435582369565964, 49.37494955956936, 51.528320610523224, 50.139305144548416, 51.24232515692711, 52.52202048897743, 50.72301842272282, 50.834519639611244, 51.04845955967903, 49.27300103008747, 50.781337693333626, 47.00509652495384, 52.468557357788086, 50.38405381143093, 59.940461218357086, 59.853259697556496, 62.86614462733269, 62.774482145905495, 62.92089208960533, 61.05454623699188, 59.93072994053364, 57.273087948560715, 54.16231267154217, 50.54708406329155, 53.40936027467251, 51.58685266971588, 50.82477316260338, 50.87591841816902, 56.469712257385254, 51.723098158836365, 55.00748611986637, 54.147896245121956, 60.184981897473335, 64.39258351922035, 64.4190376996994, 39.40758280456066, 48.983179181814194, 64.01313588023186, 57.36649073660374, 59.883882254362106, 60.007098242640495, 60.58162361383438, 61.69640399515629, 56.529319658875465, 52.707366943359375, 60.164880976080894, 59.1348322480917, 59.23915944993496, 59.78014022111893, 52.11177550256252, 50.57824619114399, 60.04444643855095, 54.49741668999195, 56.26988857984543, 56.79454542696476, 57.60520152747631, 56.68535068631172, 58.88085387647152, 51.966015323996544, 58.08791242539883, 61.23247928917408, 56.07607237994671, 49.655465707182884, 50.163889825344086, 49.36956524848938, 45.555318519473076, 49.06364746391773, 48.142690882086754, 52.24633388221264, 49.288766384124756, 48.32361817359924, 48.32796514034271, 50.74485585093498, 48.53614456951618, 50.856782644987106, 54.333702474832535, 58.683321475982666, 60.80836124718189, 63.9437972009182, 63.5115247964859, 67.16810658574104, 64.86792281270027, 64.27345991134644, 59.37149874866009, 55.73935724794865, 52.37812981009483, 55.12557618319988, 56.27637483179569, 67.29548335075378, 69.11465093493462, 72.0084236562252, 68.73668521642685, 73.34202289581299, 64.022346585989, 80.38834199309349, 29.401192143559456, 0.6514589523430914, 6.919886106625199, 1.3757966877892613, 0.46384529618080705, 0.1931660043192096, 24.745643958449364, 78.15900921821594, 66.45451247692108, 73.60362365841866, 40.62412932515144, 23.58733121305704, 37.09985263645649, 55.68422980606556, 63.27049233019352, 71.97978079319, 28.888840936124325, 1.057252655737102, 0.146404436964076, 0.21347307949326932, 0.1766799358301796, 0.24471920361975208, 0.10080485764774494, 0.12410764160449617, 0.11738389497622848, 0.2084675754304044, 0.12533590343082324, 0.11250852650846355, 0.15207119460683316], [0.035927105564041995, 0.16317071072990075, 0.024355186469620094, 0.0781581099727191, 0.033755410768208094, 0.11762137481127866, 0.07240413513500243, 0.031952077260939404, 0.05941707029705867, 0.06367614449118264, 0.04746908642118797, 6.524124043062329, 64.70235049724579, 62.36435495316982, 56.60171717405319, 39.74069572985172, 11.921993270516396, 38.41069869697094, 45.713374838232994, 46.831073462963104, 81.95513471961021, 20.520247891545296, 0.050968349823961034, 0.025021319670486264, 1.0262289829552174, 0.8885117853060365, 3.5804364876821637, 0.7592890912201256, 0.6257902015931904, 9.836440030485392, 70.914735943079, 71.15083247423172, 72.02600911259651, 64.35587748885155, 62.463073655962944, 56.78270526230335, 57.0122167468071, 55.131340473890305, 59.68259185552597, 60.58167681097984, 62.08438217639923, 62.71280765533447, 61.55606232583523, 63.53205129504204, 65.20355120301247, 63.12361501157284, 63.72994087636471, 63.65008816123009, 63.17231699824333, 62.22050987184048, 63.67613956332207, 60.14600358903408, 58.756277561187744, 47.18370594084263, 45.62990091741085, 45.49521714448929, 45.2299115806818, 46.35768346488476, 45.0826732814312, 47.12004795670509, 46.96404352784157, 47.17455983161926, 46.94433018565178, 42.612570226192474, 42.51314476132393, 48.17930571734905, 53.3063668012619, 55.072660222649574, 58.08815561234951, 56.43947347998619, 56.37743420898914, 55.45889429748058, 49.12276469171047, 47.37970322370529, 46.15968368947506, 45.259344801306725, 45.79170383512974, 43.3181581646204, 47.87336513400078, 47.427409663796425, 50.388928949832916, 47.40448169410229, 53.986579701304436, 49.37168553471565, 54.84402269124985, 54.118413627147675, 63.82889896631241, 35.02397462725639, 44.75469008088112, 62.307699993252754, 48.70648182928562, 53.197730630636215, 56.0596876591444, 57.644985392689705, 56.565592512488365, 56.53403900563717, 52.056123688817024, 53.14730353653431, 55.017821565270424, 54.52702470123768, 50.77558100223541, 54.970445707440376, 53.312682062387466, 47.103739231824875, 47.74397827684879, 50.97542367875576, 48.169464245438576, 51.216604337096214, 51.93207174539566, 56.42274297773838, 46.142383217811584, 53.79101179540157, 55.606679767370224, 54.583094492554665, 43.654508516192436, 43.85416500270367, 44.55791383981705, 45.16905024647713, 42.61211045086384, 43.7024999409914, 43.301347866654396, 45.44417828321457, 45.171037539839745, 46.009375154972076, 46.29700072109699, 46.60726547241211, 46.227620244026184, 46.08732037246227, 47.018904983997345, 52.021385952830315, 53.21425214409828, 53.24834391474724, 54.865183755755424, 51.252679601311684, 46.81164130568504, 47.294751182198524, 47.790920957922935, 51.18850104510784, 53.572971895337105, 61.99566453695297, 62.26698137819767, 66.25257611274719, 61.60352937877178, 66.48377850651741, 67.00841635465622, 64.11738708615303, 60.1901800185442, 63.85100618004799, 6.4056601747870445, 0.7106236182153225, 0.7051731075625867, 0.27357098122593015, 0.023473531728086527, 4.363240795210004, 54.07429799437523, 64.8302136361599, 44.63168688118458, 43.468117117881775, 26.415724642574787, 15.323550794273615, 31.11068621277809, 46.822010949254036, 56.558973267674446, 31.701505109667778, 2.498303479515016, 0.1628955520573072, 0.02391365127550671, 0.0716877102968283, 0.019557005070964806, 0.06618490049731918, 0.038915277837077156, 0.04013266719994135, 0.036034735530847684, 0.016007355407055, 0.03138921762001701, 0.07577860640594736, 0.06425188781577162, 0.05848290675203316, 0.04120497411349788, 0.04519861548033077, 0.02095334293699125, 0.03042827553144889, 0.15274721692549065, 0.013297127643454587, 0.050489972563809715, 0.08232624139054678, 0.12900068802991882, 9.833485689014196, 80.86805865168571, 65.9874415397644, 63.72579149901867, 42.52141311764717, 22.608674727380276, 39.24318842589855, 45.47431446611881, 54.7672364115715, 86.55410394072533, 22.297898903489113, 0.14920948800863698, 0.09223498898791149, 2.551490175537765, 3.578294590115547, 3.272702400572598, 0.6733483902644366, 0.5217636586166918, 12.151228319853544, 74.87834885716438, 72.93595388531685, 74.45502117276192, 67.44358420372009, 67.99859002232552, 58.891542702913284, 59.52453173696995, 59.549207612872124, 63.501280546188354, 64.5277650654316, 64.16540890932083, 64.90266814827919, 63.84151428937912, 65.64977645874023, 67.41757079958916, 67.00928270816803, 66.17136687040329, 64.7616197168827, 62.8476320207119, 64.22611445188522, 66.14729136228561, 63.265472799539566, 60.909842401742935, 50.13341546058655, 47.05540582537651, 47.5340623408556, 47.50154748558998, 48.47003571689129, 46.331020295619965, 48.351421281695366, 48.58557231724262, 50.054007321596146, 49.201359674334526, 45.923989936709404, 46.23436488211155, 50.23328550159931, 55.01237265765667, 58.07482972741127, 60.71828328073025, 60.8478981256485, 60.21593503654003, 57.143860682845116, 52.13039070367813, 49.34751883149147, 48.79511967301369, 48.04312102496624, 48.28649416565895, 46.22912496328354, 50.09500332176685, 49.933705776929855, 51.98865830898285, 51.7220114171505, 55.58627866208553, 52.51649558544159, 56.14539586007595, 56.41621112823486, 64.0910392999649, 39.597405418753624, 47.04273350536823, 62.50297911465168, 52.09799364209175, 55.068845227360725, 60.27998819947243, 58.351074904203415, 58.88608619570732, 59.14920687675476, 53.131572380661964, 55.55607408285141, 56.78674824535847, 54.04170334339142, 53.78715880215168, 51.37645795941353, 52.84212291240692, 50.787690952420235, 50.22355042397976, 52.80118390917778, 49.665071591734886, 52.020519599318504, 52.86685198545456, 59.302319660782814, 50.33731251955032, 56.919361129403114, 56.51176080107689, 56.683219000697136, 47.612866312265396, 46.563769206404686, 47.20017805695534, 46.99517525732517, 45.17656624317169, 46.347074434161186, 46.95078603923321, 47.031303718686104, 47.07266449928284, 48.1027702242136, 47.92496636509895, 48.425597101449966, 48.551727533340454, 48.73785674571991, 48.15900720655918, 54.178765788674355, 54.36581455171108, 57.69089832901955, 56.13339230418205, 54.532260820269585, 50.24241641163826, 48.5604252666235, 49.49099153280258, 55.32420292496681, 58.13493110239506, 64.60329741239548, 64.74075883626938, 69.49635565280914, 65.07335498929024, 67.88119912147522, 66.57729148864746, 66.4363494515419, 63.431349098682404, 69.69715967774391, 11.384634654968977, 1.00067179184407, 0.9629548375960439, 0.5291901819873601, 0.10276784567395225, 3.716543046757579, 55.812039747834206, 70.2367839217186, 49.42596562206745, 38.48642863333225, 25.99483262747526, 23.839516080915928, 38.12137842178345, 53.98805022239685, 64.52743828296661, 43.31386439502239, 3.5771703254431486, 0.13884057174436748, 0.027181869263586123, 0.03339512775710318, 0.05092084866191726, 0.05143713111465331, 0.041400993868592195, 0.07074347580783069, 0.021461231699504424, 0.029958787345094606, 0.022136031329864636, 0.04085586413566489, 0.25680764636490494, 0.2463463624008, 0.2063311103847809, 0.1549752036225982, 0.08763563266256824, 0.24384915421251208, 0.1795728868455626, 0.19658181321574375, 0.26030099485069513, 0.2847597183426842, 0.3674659912940115, 12.142998911440372, 93.86127904057503, 77.19145953655243, 72.21435740590096, 51.84291332960129, 20.388016887009144, 52.14257664978504, 65.25892183184624, 59.216953441500664, 95.08380264043808, 26.709918156266212, 0.32203951792325824, 0.22998510830802843, 3.6398902349174023, 6.3554159458726645, 11.26268494874239, 9.02711670845747, 2.4721976928412914, 16.88199631869793, 75.80683663487434, 76.08359858393669, 79.89718794822693, 68.62070024013519, 71.10375300049782, 61.61242850124836, 62.90422238409519, 62.38874964416027, 66.481544226408, 66.94688245654106, 68.27876418828964, 68.58612209558487, 68.36818099021912, 70.54651290178299, 72.83903628587723, 69.42675858736038, 68.71710106730461, 68.10575947165489, 66.08451873064041, 66.03121519088745, 69.6012756228447, 65.31852543354034, 64.1664956510067, 52.096428126096725, 49.58036653697491, 49.697107672691345, 49.92416448891163, 50.20922899246216, 48.58979009091854, 51.958366334438324, 52.93907471001148, 52.184735387563705, 51.65351629257202, 46.56648226082325, 48.24508398771286, 53.08429531753063, 57.320851385593414, 59.462025091052055, 64.89414140582085, 64.53499227762222, 61.82065352797508, 58.609453439712524, 54.01779122650623, 52.09377586841583, 52.507307678461075, 52.26236902177334, 50.6225024163723, 47.81345374882221, 53.40688280761242, 52.391250506043434, 57.304052487015724, 53.50991427898407, 60.185555666685104, 53.99423249065876, 57.76241809129715, 60.88915251195431, 66.36454850435257, 42.107980102300644, 50.850984156131744, 67.14126482605934, 57.27328933775425, 56.92207798361778, 64.06849130988121, 60.798466578125954, 62.21208952367306, 61.82802893221378, 55.6131736189127, 57.993438094854355, 60.608389377593994, 58.11304807662964, 55.76934523880482, 53.838030472397804, 56.016206592321396, 53.89237895607948, 49.36308279633522, 53.86796906590462, 51.824799701571465, 54.04568172991276, 54.770470038056374, 59.52739678323269, 50.38571812212467, 60.26039645075798, 58.738467916846275, 59.94983911514282, 49.934074357151985, 49.328219667077065, 48.833011239767075, 51.14895276725292, 47.93839104473591, 47.47882090508938, 47.470936328172684, 50.19045799970627, 48.85725013911724, 51.67022779583931, 50.64823463559151, 51.62955477833748, 51.86166912317276, 49.63136740028858, 52.32923023402691, 58.1633535772562, 56.32127322256565, 58.13423193991184, 59.805511459708214, 56.676854342222214, 52.14946947991848, 52.17957146465778, 53.207883685827255, 56.54727749526501, 58.973591700196266, 67.98316285014153, 66.48049548268318, 74.52097043395042, 65.87159335613251, 71.5282130241394, 70.53427755832672, 70.00563472509384, 64.71099883317947, 71.23014941811562, 11.351459585130215, 3.042240492068231, 3.5716615710407495, 1.1967164534144104, 0.14348708413308486, 5.292050605639815, 66.16938337683678, 74.35051918029785, 60.32674849033356, 58.41688737273216, 37.10554853081703, 25.567480958998203, 48.197126761078835, 64.14246574044228, 74.66360718011856, 52.2817175835371, 4.610928604379296, 0.2971273718867451, 0.11984467855654657, 0.1483966878731735, 0.15864239278016612, 0.15333832270698622, 0.16872063948540017, 0.15717831352958456, 0.11702781252097338, 0.12685027060797438, 0.1423356420127675, 0.1731067174114287], [0.040109241308528, 0.06997717122430913, 0.03358027133799624, 0.04781142430147156, 0.049661067823763005, 0.022410612982639577, 0.052369825207279064, 0.09949632512871176, 0.019691549023264088, 0.03921945819456596, 0.1380440840148367, 21.927682869136333, 78.58938932418823, 55.06120763719082, 57.95203171670437, 28.15366968512535, 26.201480738818645, 51.35149709880352, 42.1167728304863, 59.707016944885254, 68.9199797809124, 7.358456198126078, 0.12007318582618609, 0.17780123191187158, 1.1307230195961893, 5.325438939034939, 4.277325980365276, 0.5720176838804036, 8.394903782755136, 74.86177414655685, 74.29992109537125, 71.43009468913078, 69.41509321331978, 67.58527100086212, 64.43013310432434, 59.49634104967117, 53.12271125614643, 53.700546249747276, 51.61730423569679, 57.60191090404987, 56.90050274133682, 59.43825736641884, 58.11339385807514, 59.334538131952286, 59.445028603076935, 58.440522104501724, 62.14294083416462, 59.233471155166626, 61.69827349483967, 61.4108607172966, 62.02420100569725, 62.89834789931774, 61.86267927289009, 50.61559818685055, 46.1408556997776, 47.12736636400223, 46.08038954436779, 47.33480103313923, 46.19082301855087, 44.21644516289234, 46.24640263617039, 45.26384375989437, 49.96662341058254, 45.75857721269131, 42.50412404537201, 45.494981557130814, 52.13177002966404, 56.75669185817242, 57.72645682096481, 54.03833672404289, 52.260358929634094, 52.19222478568554, 47.24438488483429, 44.281653463840485, 45.59380665421486, 45.804246962070465, 44.39119778573513, 44.23023082315922, 44.71127361059189, 49.48519304394722, 53.399993777275085, 50.20165979862213, 53.797908425331116, 51.761730685830116, 57.16635547578335, 52.529281899333, 63.64217318594456, 38.532831743359566, 43.872008845210075, 60.43480709195137, 49.61027853190899, 46.66509456932545, 52.94899217784405, 58.39688144624233, 58.996048495173454, 57.13232830166817, 57.01019145548344, 55.24987891316414, 53.66334244608879, 55.61383858323097, 53.4654376655817, 42.142778635025024, 36.25651828944683, 48.69424268603325, 56.167206689715385, 56.302813813090324, 55.57187743484974, 51.61677226424217, 50.90021051466465, 47.34613582491875, 42.84680865705013, 54.52064484357834, 55.699360594153404, 54.67796020209789, 43.27655419707298, 44.16762538254261, 43.18354278802872, 45.00339433550835, 41.58286727964878, 44.33790564537048, 47.09017775952816, 43.97500991821289, 45.18561355769634, 46.043622717261314, 44.16883371770382, 45.38937762379646, 45.55718041956425, 46.19270011782646, 47.01444402337074, 45.34889459609985, 46.80564142763615, 45.44706992805004, 43.7434883415699, 44.952746853232384, 46.6870041936636, 51.95830173790455, 53.46998602151871, 56.78273186087608, 61.3997121155262, 59.969385266304016, 62.93164171278477, 63.40429835021496, 63.92309591174126, 62.27944850921631, 60.03727242350578, 62.15965233743191, 63.75755399465561, 64.86534655094147, 45.65623350441456, 0.6231380626559258, 1.1000058241188526, 0.2546807995531708, 0.1594988608849235, 0.1290124881779775, 32.414468452334404, 62.51618720591068, 58.15001629292965, 38.01577068865299, 16.718644984066486, 13.481761123985052, 21.266191564500332, 45.0541178137064, 47.45521277189255, 48.19513186812401, 6.933752037584782, 0.3303087648237124, 0.08384969987673685, 0.0888458825647831, 0.04439295851625502, 0.04733856119855773, 0.05111856051371433, 0.008491067419527099, 0.019572642122511752, 0.011787503717641812, 0.0015311772858694894, 0.07193119410658255, 0.005637040194415022, 0.07860360638005659, 0.027922892586502712, 0.00461013926724263, 0.05033899004047271, 0.06638216334977187, 0.11850321694510058, 0.031799554781173356, 0.011625637598626781, 0.0705560389906168, 0.07728437209152617, 31.251381263136864, 92.3660896718502, 61.59507483243942, 67.8857284784317, 37.653342336416245, 29.888510294258595, 40.765200555324554, 48.27943034470081, 65.72133421897888, 76.88455000519753, 7.399451248347759, 0.11668206818285398, 0.15106313541764393, 2.3812954081222415, 4.608713798224926, 0.5705662805121392, 0.5827420740388334, 11.190794706344604, 80.01384168863297, 74.12653639912605, 73.794115036726, 70.6654617190361, 72.3013499379158, 67.58818924427032, 63.360330909490585, 56.28759182989597, 57.59635180234909, 54.495087414979935, 59.923232942819595, 59.25745166838169, 60.30844487249851, 61.5457458794117, 61.36997491121292, 61.79666921496391, 62.226243764162064, 66.3128712773323, 60.99409528076649, 64.68851923942566, 63.57747785747051, 62.544092908501625, 63.66117976605892, 64.54443097114563, 52.9435470700264, 47.835838347673416, 48.903919234871864, 48.205315321683884, 50.10644070804119, 48.32321919500828, 47.68206439912319, 47.688619047403336, 47.47594825923443, 53.39119724929333, 47.50891149044037, 45.23538328707218, 48.041015937924385, 57.029912397265434, 59.18926812708378, 60.783331990242004, 58.00233721733093, 56.666051521897316, 54.54499013721943, 50.030535981059074, 48.553863018751144, 48.83885532617569, 48.44684176146984, 47.39757366478443, 46.278104335069656, 48.32258082926273, 53.001718148589134, 56.283811032772064, 53.79574254155159, 57.091704681515694, 53.88906553387642, 58.207852989435196, 55.545848831534386, 63.46051633358002, 41.173363253474236, 45.58548890054226, 62.818928360939026, 52.78085879981518, 47.94264681637287, 56.48367650806904, 60.10694928467274, 61.82584784924984, 57.73738883435726, 59.214639365673065, 59.717025607824326, 54.88100990653038, 56.93064272403717, 56.25933274626732, 45.0326831638813, 40.97896948456764, 51.17552474141121, 56.76723249256611, 57.1992427110672, 56.97747901082039, 53.62718738615513, 53.67064565420151, 50.55931940674782, 45.238267332315445, 55.27559593319893, 57.81363174319267, 56.27257123589516, 45.58639705181122, 45.32042272388935, 45.67015215754509, 47.84571401774883, 43.638249188661575, 45.459062084555626, 49.257380068302155, 45.90766221284866, 48.02767485380173, 49.191985577344894, 47.11794286966324, 47.97940984368324, 47.32025921344757, 48.347260504961014, 48.221513852477074, 47.595714032649994, 48.44145365059376, 46.90106190741062, 46.094912365078926, 48.967649415135384, 51.034278720617294, 54.207423850893974, 56.6285665333271, 59.839546233415604, 64.1817632317543, 62.38582380115986, 65.29132649302483, 64.7226034104824, 65.04220426082611, 64.89535734057426, 63.22872117161751, 64.3316575884819, 65.47083646059036, 65.05707666277885, 54.04060140252113, 1.6615575039759278, 0.4484948026947677, 0.9677225130144507, 0.2995129313785583, 0.13979308860143647, 32.77218125760555, 71.61049380898476, 62.2062948346138, 41.11533656716347, 18.050728105008602, 17.601890489459038, 28.89794334769249, 50.58546960353851, 54.33755546808243, 60.75190767645836, 11.739454865455627, 0.44683553860522807, 0.044450846035033464, 0.04343006272392813, 0.024459352462145034, 0.04015065685962327, 0.05749972064222675, 0.06346568625303917, 0.022404035698855296, 0.02179935047024628, 0.019970429566456005, 0.06825402306276374, 0.14346250420203432, 0.19760720897465944, 0.05151986573764589, 0.18829741165973246, 0.14391748525667936, 0.13127660262398422, 0.18924651463748887, 0.18612803978612646, 0.09516760779661126, 0.24160016473615542, 0.17079510551411659, 35.7892269641161, 105.24425983428955, 69.21482875943184, 77.35746502876282, 40.84569923579693, 37.83756025135517, 64.78748872876167, 60.17094165086746, 72.79653176665306, 84.38429117202759, 9.594508912414312, 0.17647735920036212, 0.4705612873658538, 4.235366256907582, 14.458200428634882, 14.535055104643106, 2.413207283243537, 14.694606643170118, 83.58090028166771, 72.69888460636139, 75.7310763001442, 74.01360645890236, 74.9465323984623, 69.70128625631332, 67.05048009753227, 60.15437074005604, 60.438010320067406, 57.4606154859066, 64.32034939527512, 61.3264824450016, 66.10356330871582, 63.945218324661255, 66.13648474216461, 65.0092676281929, 64.4309614598751, 69.21583950519562, 63.59285943210125, 67.50937387347221, 67.49376431107521, 66.00774765014648, 67.30282455682755, 69.0451830625534, 55.82071088254452, 51.14126577973366, 52.93749399483204, 50.43309397995472, 53.2597167044878, 51.45691864192486, 48.65014985203743, 48.641957491636276, 49.353526309132576, 56.87443234026432, 49.48627598583698, 46.12685725092888, 51.06959022581577, 60.79807139933109, 61.34605899453163, 64.91069331765175, 59.83982361853123, 57.8729123622179, 57.9313076287508, 53.318263962864876, 50.590675324201584, 50.81713557243347, 50.89826121926308, 50.1288291066885, 50.95249570906162, 50.71959860622883, 57.27767430245876, 60.774501264095306, 55.50939738750458, 59.8131338506937, 55.94568997621536, 62.679399847984314, 57.8567860275507, 65.8133652806282, 47.32707604765892, 51.075715497136116, 64.55704629421234, 56.365825831890106, 50.301598235964775, 58.25978480279446, 61.27661392092705, 65.25088906288147, 59.77134749293327, 61.14573374390602, 59.80854369699955, 54.68086324632168, 60.6579615175724, 57.285771667957306, 47.79178351163864, 46.409748271107674, 52.91108541190624, 58.518273532390594, 61.01202271878719, 59.388525635004044, 55.26755176484585, 54.386534839868546, 48.65451201796532, 46.70924440026283, 58.30644629895687, 61.196742206811905, 58.739539459347725, 48.83009299635887, 46.01609319448471, 47.23327048122883, 49.29424189031124, 46.170767694711685, 47.6522284001112, 51.68525218963623, 47.8116450458765, 51.11612252891064, 51.26233868300915, 48.47747191786766, 50.92711687088013, 50.52060708403587, 49.258151426911354, 50.49968160688877, 49.08450834453106, 51.435556188225746, 49.606535732746124, 49.16852943599224, 51.18088245391846, 54.27083484828472, 56.98808804154396, 57.82131493091583, 62.0582015812397, 67.36803665757179, 64.9019917845726, 70.04961356520653, 67.63032898306847, 66.9831857085228, 67.00082436203957, 66.27774596214294, 67.48688668012619, 69.63242635130882, 67.07654669880867, 57.58926518261433, 2.194125051610172, 4.487851308658719, 3.422938738949597, 0.37695123231969774, 0.35180611128453165, 39.81246627867222, 76.6616539657116, 71.312285810709, 53.369876593351364, 24.975660815835, 22.84770280122757, 34.996167719364166, 61.65141820907593, 63.15227307379246, 74.1514478623867, 15.556584689766169, 0.7206077012233436, 0.3672847885172814, 0.12915241270093247, 0.15643337537767366, 0.1388946149381809, 0.13222667039372027, 0.21919088205322623, 0.14299515896709636, 0.09539078644593246, 0.12630253593670204, 0.18312857573619112], [0.037937680099275894, 0.06748503190465271, 0.0018832261685020057, 0.028250663963262923, 0.057055352299357764, 0.06972138260607608, 0.06708879183861427, 0.016269359512079973, 0.062456187297357246, 0.04957801036653109, 0.6416270392946899, 45.51217183470726, 70.2482745051384, 51.45741641521454, 43.069773092865944, 20.412717461586, 32.72772364318371, 62.11544930934906, 45.80455854535103, 69.64828670024872, 54.573507606983185, 1.8665924831293523, 0.047124021148192696, 0.18991486314916983, 1.8578406027518213, 2.4534437991678715, 1.0508032143115997, 5.697454176843166, 78.85413631796837, 73.06914433836937, 74.00973826646805, 71.76589027047157, 69.16134282946587, 69.94388043880463, 67.00850754976273, 60.09797416627407, 55.2462425082922, 51.225617453455925, 51.99160315096378, 50.308441668748856, 53.14503125846386, 53.455535396933556, 54.67816539108753, 55.00797249376774, 55.876077711582184, 55.76301097869873, 57.46106006205082, 59.90801475942135, 59.909599274396896, 61.536842957139015, 61.707009226083755, 59.191453009843826, 61.21386408805847, 52.64824591577053, 45.34238554537296, 45.88775508105755, 45.70989042520523, 46.78415738046169, 45.65437160432339, 46.77096828818321, 44.04116816818714, 48.03438529372215, 49.50416922569275, 45.137192755937576, 45.63299395143986, 44.0435316413641, 46.69398441910744, 48.50305214524269, 50.63864015042782, 46.260017305612564, 47.36845962703228, 45.55073216557503, 43.23727570474148, 42.833406776189804, 44.96711768209934, 43.509641289711, 44.158308282494545, 44.5379763096571, 46.38885319232941, 47.570289596915245, 54.509690031409264, 52.3358266800642, 57.580286264419556, 52.507676258683205, 58.74977611005306, 53.439918234944344, 61.411172300577164, 36.65005937218666, 43.04926939308643, 60.26788964867592, 52.80667841434479, 46.827395260334015, 44.415151700377464, 54.96791884303093, 54.492309764027596, 57.73484297096729, 54.4449795037508, 55.288705229759216, 60.27386672794819, 54.961235001683235, 56.1977494508028, 49.98560719192028, 54.1975861787796, 57.75633841753006, 55.79155124723911, 54.453076869249344, 55.33803038299084, 56.08860790729523, 51.668894067406654, 45.1521335542202, 48.746634274721146, 54.720358327031136, 58.02205055952072, 51.01832337677479, 43.21917347609997, 45.992146879434586, 43.21641482412815, 44.576304852962494, 43.86401787400246, 43.479113727808, 45.1159442961216, 44.71733048558235, 45.465544536709785, 44.050363674759865, 47.66709320247173, 45.74274726212025, 46.98262073099613, 45.50248995423317, 46.769205182790756, 46.609131172299385, 46.65237285196781, 45.010116174817085, 47.51221351325512, 50.15847131609917, 54.02583919465542, 57.12073892354965, 58.45741219818592, 58.914113491773605, 60.97780555486679, 62.327173948287964, 63.45901921391487, 61.62199258804321, 62.87858135998249, 57.595979422330856, 58.62232334911823, 56.41354367136955, 64.81667876243591, 63.070968836545944, 75.12281253933907, 14.891341086477041, 0.39999747066758573, 1.4341530064120889, 0.12097588230972178, 0.06366142770275474, 10.00290434807539, 63.32721188664436, 58.293390199542046, 50.26208035647869, 35.105826035141945, 25.088446363806725, 14.958440735936165, 35.367164611816406, 49.62467595934868, 49.709232822060585, 19.625492803752422, 1.719238052610308, 0.1236641118885018, 0.06456520030042157, 0.011173665952810552, 0.04138862597756088, 0.046229829677031375, 0.012904146533401217, 0.0389787203312153, 0.05534404510399327, 0.025872674377751537, 0.04154376823862549, 0.051439520830172114, 0.020513336567091756, 0.0096969247351808, 0.024155845603672788, 0.025949456976377405, 0.02101154957927065, 0.08546639437554404, 0.06172088222228922, 0.08219214272685349, 0.02671035130333621, 0.6956713018007576, 58.3806487172842, 79.03849482536316, 59.203182980418205, 50.89207515120506, 28.20501632988453, 30.411255843937397, 52.55819454789162, 52.634589448571205, 77.2946847975254, 59.07392531633377, 1.678870206233114, 0.0783315350417979, 1.126431506127119, 3.9490549452602863, 0.7744051550980657, 0.30629509245045483, 7.2859404142946005, 84.77516859769821, 76.19286552071571, 77.61600315570831, 72.66287013888359, 70.9053048491478, 70.35064861178398, 70.51790043711662, 63.994380086660385, 56.83400250971317, 55.71373142302036, 54.97250139713287, 52.55014277994633, 55.983353555202484, 55.802297070622444, 58.17541413009167, 57.07801781594753, 59.13452826440334, 58.89187328517437, 61.326904222369194, 61.487149223685265, 62.39178568124771, 63.547037690877914, 64.37654837965965, 60.22878214716911, 64.77915957570076, 55.636401772499084, 47.55259394645691, 48.063396736979485, 48.167533949017525, 48.23901951313019, 47.76959270238876, 48.43613013625145, 46.52002975344658, 48.03616359829903, 52.052745670080185, 48.351565673947334, 48.32389175891876, 47.833049297332764, 48.268695920705795, 50.01848682761192, 51.90625973045826, 48.98935005068779, 49.85871680080891, 47.94152207672596, 45.34217655658722, 43.88278126716614, 47.8269050270319, 46.57671891152859, 46.28020942211151, 46.09527334570885, 49.298319071531296, 51.00363716483116, 57.16184891760349, 54.557301476597786, 59.95987817645073, 54.6227415651083, 60.66133193671703, 56.72599710524082, 64.54879313707352, 40.03863774240017, 46.33252501487732, 61.45410619676113, 55.19248679280281, 47.74584397673607, 47.89434000849724, 56.03022404015064, 57.12888948619366, 59.320087507367134, 56.916651874780655, 56.64910443127155, 60.223929807543755, 56.4223325997591, 58.03558923304081, 53.35612133145332, 55.55125214159489, 59.95879903435707, 57.76758201420307, 55.086510479450226, 56.948114186525345, 56.836293786764145, 54.48467597365379, 47.07459099590778, 51.84042826294899, 57.176394537091255, 58.34393508732319, 53.63962411880493, 45.277937203645706, 46.79566316306591, 46.37319043278694, 46.77951402962208, 44.654554054141045, 46.32608816027641, 46.90942145884037, 47.922884076833725, 48.799079060554504, 46.43400996923447, 48.878460600972176, 46.94043919444084, 49.473801255226135, 46.02652743458748, 47.94611983001232, 48.83780658245087, 48.73338058590889, 46.82757765054703, 50.73195934295654, 53.531991094350815, 56.50166854262352, 59.31406483054161, 62.10135966539383, 62.14951828122139, 62.23883628845215, 64.82098013162613, 65.39202868938446, 63.18619005382061, 65.25231018662453, 58.28148923814297, 59.508561193943024, 59.78932432830334, 68.57926726341248, 64.61531236767769, 78.40890660881996, 21.346956230700016, 0.27951632626354694, 1.3567826268263161, 0.20157974737230688, 0.031174688701867126, 9.323893133550882, 66.39920264482498, 63.81340339779854, 54.71302092075348, 31.99747122824192, 27.762353383004665, 20.91603085398674, 42.24329084157944, 56.69908694922924, 59.321246445178986, 29.19494491070509, 2.0136853214353323, 0.13780429610051215, 0.036654232171713375, 0.016262140270555392, 0.02250719422590919, 0.04127789754420519, 0.019077004362770822, 0.024859546319930814, 0.012316609554545721, 0.04631341405911371, 0.10924377435003407, 0.22516753087984398, 0.12030427576974034, 0.12151603223173879, 0.12374957761494443, 0.12007230267045088, 0.18750074581475928, 0.15936178620904684, 0.18408331903629005, 0.23148921900428832, 0.14212420413969085, 1.0564570734277368, 70.82164093852043, 88.60317438840866, 68.97804826498032, 60.075562968850136, 32.01265141367912, 47.43079148232937, 80.21260902285576, 62.68015220761299, 81.66883528232574, 67.31733217835426, 2.8917754534631968, 0.14152226300211623, 1.6867787693627179, 6.601966191083193, 12.983437813818455, 5.426286952570081, 8.440815769135952, 87.61392027139664, 76.6888453066349, 80.66878214478493, 74.28121849894524, 75.3318241238594, 74.21801269054413, 75.16864567995071, 66.07491284608841, 61.16838812828064, 57.773699685931206, 56.90446972846985, 55.354004725813866, 58.0409849435091, 57.78375394642353, 60.8488404750824, 59.725187569856644, 61.74313008785248, 62.03433506190777, 62.84670487046242, 65.94682171940804, 64.28023874759674, 64.44753617048264, 67.8381398320198, 64.07804399728775, 67.45355486869812, 58.41515086591244, 50.15006996691227, 50.94213746488094, 50.55968798696995, 53.109286576509476, 50.77470324933529, 51.77559234201908, 48.55775400996208, 53.183762580156326, 53.95603694021702, 50.804387256503105, 49.58480469882488, 49.89331774413586, 52.112463265657425, 53.29081803560257, 55.883787497878075, 50.431589260697365, 53.10449503362179, 50.6061214953661, 46.998025104403496, 46.47106558084488, 51.10638365149498, 47.0553108304739, 49.00847442448139, 49.893838316202164, 51.74373485147953, 53.97225446999073, 58.14313866198063, 55.86842492222786, 61.63422033190727, 58.67667943239212, 64.89585131406784, 59.43907432258129, 67.48820140957832, 44.20789182186127, 49.894301891326904, 63.45324732363224, 58.85962061583996, 50.074518620967865, 50.66941849887371, 59.11969766020775, 59.84967648983002, 62.69783265888691, 59.34446319937706, 59.007736667990685, 63.54215495288372, 59.98965337872505, 60.708050429821014, 57.17880740761757, 57.23635911941528, 63.28563071787357, 61.08166538178921, 57.96205177903175, 60.63315264880657, 59.15070779621601, 56.50241330265999, 48.691305443644524, 52.99476832151413, 58.09729032218456, 61.50766432285309, 56.41157917678356, 48.795442655682564, 49.681646302342415, 47.53796473145485, 48.97829644382, 47.576977238059044, 48.95755335688591, 50.10256491601467, 48.96402060985565, 52.158493995666504, 47.50029355287552, 52.18251630663872, 48.82758513092995, 51.86983488500118, 47.79905632138252, 51.4664713293314, 51.376419961452484, 50.8036120980978, 49.13897842168808, 54.13026139140129, 56.6759841889143, 59.15685586631298, 61.95063315331936, 65.61856493353844, 65.41130885481834, 66.33640721440315, 67.01435163617134, 67.73837998509407, 64.56146165728569, 67.60923251509666, 60.946339443325996, 62.117022424936295, 62.776393443346024, 71.86672925949097, 69.54350352287292, 81.73840954899788, 21.021535992622375, 0.5583460768684745, 5.735867265611887, 0.5660742684267461, 0.25440139579586685, 13.356198761612177, 73.6710624396801, 69.28438022732735, 69.34397622942924, 50.17017088830471, 34.67253528535366, 25.873970612883568, 53.474838361144066, 65.87770342826843, 69.62645307183266, 38.46344366669655, 2.8698062198236585, 0.22514648357173428, 0.10792257337016053, 0.13547938491683453, 0.1489260618109256, 0.06076312580262311, 0.053796767388121225, 0.12435681026545353, 0.19977181626018137, 0.10415792537969537, 0.22691350750392303], [0.05228828544204589, 0.035002723525394686, 0.04599266525474377, 0.06697848642943427, 0.03583073768822942, 0.05005403872928582, 0.006786880667277728, 0.017169874081446324, 0.052541057229973376, 0.04322541179135442, 3.5536351008340716, 58.51545788347721, 69.12953853607178, 53.56621205806732, 37.051895409822464, 31.39172673225403, 44.61623691022396, 52.10787311196327, 48.32909367978573, 79.56507816910744, 31.043230332434177, 0.02662729941221187, 0.0772311601031106, 0.05757813967647962, 2.0367861818522215, 1.2155876657925546, 0.23190011648694053, 54.04106117784977, 78.17966490983963, 69.20469090342522, 69.5592574775219, 70.82304686307907, 70.61459004878998, 67.28873491287231, 68.65396365523338, 62.355763614177704, 59.13719192147255, 50.84739714860916, 47.874261885881424, 49.989999756217, 49.94425021111965, 50.12614265084267, 48.622696325182915, 48.74654307961464, 49.131838604807854, 52.438964545726776, 52.516894564032555, 57.22081795334816, 57.977703139185905, 64.64640989899635, 59.826144352555275, 60.19116796553135, 62.67886407673359, 51.56419828534126, 45.2675561606884, 45.48893988132477, 45.995756685733795, 47.2319595515728, 46.48701712489128, 45.97619153559208, 47.42214314639568, 47.52175100147724, 46.43958806991577, 44.311375468969345, 45.376063138246536, 44.249822571873665, 46.74212023615837, 45.194037705659866, 42.2929921746254, 42.67992161214352, 42.903577610850334, 44.028625041246414, 44.678272381424904, 42.99780495464802, 44.481686130166054, 43.23015868663788, 46.514219865202904, 42.86895006895065, 43.29589135944843, 47.39158138632774, 52.765283435583115, 53.17092306911945, 55.77656865119934, 55.82712113857269, 58.20428878068924, 54.339120984077454, 59.02977928519249, 37.37818770110607, 47.124885097146034, 59.047569930553436, 52.45524287223816, 48.597579672932625, 44.19330820441246, 42.02726103365421, 46.489832773804665, 51.83132395148277, 53.962268605828285, 54.21840526163578, 53.829705119132996, 56.210220381617546, 55.429784059524536, 55.8095508813858, 54.396319314837456, 55.63721492886543, 51.80681146681309, 52.060953229665756, 51.95210047066212, 53.59519310295582, 57.126537412405014, 55.727273896336555, 56.97760060429573, 57.08586819469929, 55.430502220988274, 47.96852722764015, 44.455634728074074, 43.322090953588486, 44.330119863152504, 45.85710592567921, 43.142713978886604, 43.92533518373966, 44.497310891747475, 45.98997339606285, 45.548345893621445, 45.06768308579922, 47.0886692404747, 46.617707312107086, 45.24480298161507, 45.84786482155323, 46.42585940659046, 43.80561500787735, 45.7662869989872, 47.564776092767715, 48.56400087475777, 51.636584401130676, 55.56440323591232, 58.16860489547253, 58.51350478827953, 58.17884914577007, 61.90648712217808, 59.713123217225075, 59.213028252124786, 60.27427330613136, 58.637476935982704, 53.19538615643978, 57.028027698397636, 56.75960250198841, 66.44952714443207, 63.38266611099243, 69.71090734004974, 67.56171986460686, 3.5724125057458878, 1.445025885477662, 0.6791697966400534, 0.055660270518274046, 1.2566331820562482, 41.917697712779045, 67.74315252900124, 54.26068939268589, 41.674829944968224, 21.091087460517883, 11.474785767495632, 24.97808888554573, 38.26996564865112, 49.5759017765522, 36.470405012369156, 7.222985392436385, 0.17671066074399278, 0.054303524375427514, 0.07927969549200498, 0.025236234505428, 0.047752408718224615, 0.05405763600720093, 0.052759129903279245, 0.011006734675902408, 0.03113149941782467, 0.008871592508512549, 0.03684038878418505, 0.0355129723175196, 0.04060142993694171, 0.06140861616586335, 0.048634551421855576, 0.03262981022999156, 0.018192258576164022, 0.028280357291805558, 0.05452089200844057, 0.041444246235187165, 5.559519678354263, 71.88575103878975, 78.31427648663521, 63.27189825475216, 46.50983490049839, 39.39081430435181, 35.79899623990059, 46.89815506339073, 57.758872881531715, 83.94498154520988, 33.55964720249176, 0.012575893688335782, 0.10060911619802937, 1.394754583016038, 4.598855702206492, 1.1414277576841414, 0.0720608324627392, 60.323153883218765, 81.6363850235939, 73.72822657227516, 71.98035076260567, 73.63589152693748, 71.62418067455292, 71.56078487634659, 71.94768011569977, 64.84190940856934, 61.74961633980274, 54.279790967702866, 52.276052087545395, 53.109415769577026, 52.910599038004875, 52.90316663682461, 51.911127269268036, 52.56963953375816, 52.63026528060436, 53.540540635585785, 55.35105228424072, 59.02942970395088, 60.831559002399445, 65.98788231611252, 65.0692056119442, 62.5577911734581, 64.68509942293167, 53.03218491375446, 46.407031416893005, 48.35996322333813, 46.32654793560505, 48.83839555084705, 50.25517612695694, 48.489866852760315, 47.497151121497154, 49.150791987776756, 49.13443386554718, 47.40567862987518, 47.316797599196434, 44.80943374335766, 48.41355934739113, 46.130318865180016, 44.834702387452126, 46.12607829272747, 44.655883982777596, 44.638879895210266, 48.533556908369064, 46.298581436276436, 45.741751715540886, 46.22685268521309, 47.824560552835464, 43.4031368046999, 47.03432455658913, 50.690457969903946, 53.49606782197952, 56.166279539465904, 59.69922736287117, 57.60515972971916, 60.603100061416626, 57.28652022778988, 61.13229766488075, 40.02121947705746, 48.275151774287224, 61.931189596652985, 54.58645351231098, 50.40870688855648, 44.831195175647736, 44.11592535674572, 49.04851287603378, 54.764348566532135, 55.23075453937054, 57.573769614100456, 55.53752727806568, 59.02977928519249, 57.03091934323311, 57.29672268033028, 56.03656589984894, 57.57229529321194, 55.40350466966629, 56.24400816857815, 53.67478743195534, 56.26288175582886, 56.04564741253853, 59.27754119038582, 59.42720755934715, 60.509587079286575, 57.54076838493347, 50.277458131313324, 45.40864638984203, 45.24671047925949, 47.033363208174706, 47.72076152265072, 45.434948578476906, 44.65659834444523, 47.54347823560238, 48.19176904857159, 46.463652178645134, 45.93066617846489, 48.666215389966965, 47.96715170145035, 46.6770601272583, 48.31649735569954, 48.48863571882248, 47.36323870718479, 49.715939462184906, 50.710327103734016, 50.42182758450508, 53.7452432513237, 56.98079243302345, 60.54403603076935, 60.538647919893265, 61.45860135555267, 65.3033110499382, 61.44239142537117, 60.47139532864094, 61.63160227239132, 61.210470870137215, 58.14501196146011, 59.659785479307175, 61.8469063192606, 66.62905991077423, 67.64093801379204, 69.91617992520332, 74.9259527027607, 4.840688975527883, 0.8637250028550625, 1.1839053221046925, 0.040653280084370635, 0.9406485501676798, 44.61775302886963, 73.74559924006462, 59.49649304151535, 39.111270904541016, 23.974486738443375, 21.406198851764202, 34.34287637472153, 46.481575816869736, 58.41869227588177, 50.14050208032131, 9.529775585979223, 0.1768834178801626, 0.0855002437310759, 0.04703040664026048, 0.054218904697336257, 0.01981123146833852, 0.006814035850766231, 0.006031156326571363, 0.031258896487997845, 0.13063802907709032, 0.04177983428235166, 0.3207023162394762, 0.08073961871559732, 0.13354261696804315, 0.13709000864764675, 0.20970593788661063, 0.12567536177812144, 0.20695727522252128, 0.12517856812337413, 0.22716751496773213, 0.1944518048549071, 8.851682022213936, 86.27091273665428, 83.0359411239624, 73.65550607442856, 51.589463129639626, 44.66023474931717, 60.5603751540184, 68.9654253423214, 64.96743187308311, 92.47323632240295, 37.90659874677658, 0.2174608170753345, 0.17252039106097072, 1.889456093776971, 8.14543766900897, 8.138949517160654, 0.44729427492711693, 64.92336943745613, 82.87114396691322, 77.89821401238441, 74.18626919388771, 76.26224219799042, 73.29215437173843, 73.18311542272568, 74.89134415984154, 66.90483391284943, 64.66258943080902, 56.356151551008224, 54.869694113731384, 57.080677673220634, 55.68110257387161, 55.59717267751694, 54.82142150402069, 55.66487364470959, 54.168601334095, 57.67524316906929, 58.38211543858051, 61.18566580116749, 63.76190096139908, 70.82531154155731, 64.87543120980263, 65.47239437699318, 67.51334846019745, 54.9056401848793, 49.327113926410675, 50.989593118429184, 48.81016306579113, 51.88737854361534, 53.048178255558014, 52.15000905096531, 50.63938111066818, 52.5254213064909, 51.58090598881245, 49.989315792918205, 50.90236499905586, 46.9461502879858, 52.41046607494354, 49.314593598246574, 46.26311793923378, 49.178747087717056, 46.60759225487709, 48.065368831157684, 51.30775764584541, 47.71260716021061, 48.902342319488525, 49.705330431461334, 52.31725327670574, 46.59267045557499, 50.50962187349796, 53.35015945136547, 55.78009486198425, 59.98700492084026, 60.18757335841656, 59.20105889439583, 62.882099971175194, 59.45053070783615, 63.23915921151638, 43.63656967878342, 52.184913977980614, 65.23784816265106, 57.33329951763153, 51.53277017176151, 47.48091459274292, 45.22971399128437, 51.76123671233654, 56.69173814356327, 56.52431532740593, 58.62965315580368, 58.74837398529053, 60.75124651193619, 58.98452751338482, 58.77088777720928, 58.9193382114172, 60.398161858320236, 58.082687705755234, 59.01776432991028, 55.226517766714096, 59.66162458062172, 61.357731968164444, 61.56034469604492, 60.68143665790558, 63.36112126708031, 61.06181904673576, 52.02653467655182, 48.02768625319004, 47.87515863776207, 49.29116025567055, 50.472672656178474, 48.57926465570927, 48.16050052642822, 49.35201019048691, 50.49247719347477, 49.92570720613003, 48.393317833542824, 52.30767399072647, 51.13108612596989, 49.27418276667595, 50.74408449232578, 52.50445403158665, 49.49361339211464, 51.003751158714294, 52.61095091700554, 52.82629296183586, 56.96289159357548, 59.774839505553246, 64.19224306941032, 65.97584456205368, 64.1433472931385, 68.00460889935493, 64.50679019093513, 65.15348508954048, 64.69570085406303, 64.40981939435005, 59.51636217534542, 62.95795530080795, 63.231411427259445, 72.37258091568947, 68.9552266895771, 73.94636526703835, 75.37346228957176, 4.672981649637222, 3.182400483638048, 2.531851641833782, 0.17560612235683948, 1.5884673572145402, 51.967113465070724, 78.74487698078156, 67.88331180810928, 57.64219254255295, 30.305266231298447, 22.436861246824265, 40.68792410194874, 58.406814113259315, 68.28389391303062, 62.587475180625916, 11.908354852348566, 0.2848189417272806, 0.15779337583808228, 0.2633697458077222, 0.14937984058633447, 0.0855263153789565, 0.134753089514561, 0.12729359994409606, 0.11598807104746811, 0.3268559672869742, 0.11325428102281876], [0.03321226256957743, 0.04244445350195747, 0.04895670288533438, 0.0635559536749497, 0.07365035693510436, 0.0319194338953821, 0.029637006955454126, 0.08103566142381169, 0.06615170423174277, 0.0704657196183689, 8.19322295486927, 65.70450112223625, 58.75548720359802, 56.694948971271515, 24.987257793545723, 41.6820153594017, 44.748135432600975, 48.292543441057205, 62.61384956538677, 73.65127310156822, 16.877552457153797, 0.29747808119282126, 0.40037753933575004, 2.054232945665717, 2.5316371908411384, 1.6789466771297157, 13.952917791903019, 81.0484729707241, 71.25762194395065, 69.77405995130539, 63.74460808932781, 74.7150032222271, 70.53611665964127, 65.92380255460739, 65.8451771736145, 65.11110976338387, 59.82441924512386, 57.43921123445034, 49.97436739504337, 47.55194418132305, 46.70145481824875, 46.28605730831623, 45.117760598659515, 46.67361371219158, 47.029563412070274, 47.02112026512623, 46.501425951719284, 48.81844662129879, 50.98852537572384, 58.330400213599205, 60.1087161898613, 61.47253140807152, 53.18361058831215, 47.28995203971863, 46.43247865140438, 45.346880704164505, 44.26386661827564, 46.650856733322144, 49.63152699172497, 45.87727144360542, 46.63576774299145, 47.29174554347992, 46.491075307130814, 43.62954765558243, 45.2058170735836, 44.116753712296486, 45.37535257637501, 45.97241073846817, 45.52332043647766, 43.72844874858856, 44.336758106946945, 44.69180345535278, 43.98732505738735, 43.9513523876667, 44.71279352903366, 45.64333699643612, 43.228448778390884, 44.29050698876381, 42.25512720644474, 49.77626882493496, 53.5133720934391, 56.60463161766529, 58.40187817811966, 57.01745666563511, 56.396585181355476, 57.837498262524605, 55.649454072117805, 27.02212080359459, 42.92743653059006, 60.35745844244957, 53.42877343297005, 54.20232832431793, 52.298835664987564, 47.439124435186386, 42.02394001185894, 43.445101752877235, 48.33965711295605, 54.4012438505888, 54.57589767873287, 55.28583638370037, 57.48057201504707, 55.385003462433815, 55.673001408576965, 54.33192417025566, 48.67048256099224, 48.789328783750534, 52.59121857583523, 54.23027582466602, 54.21712473034859, 54.16812635958195, 54.0379985421896, 52.23851390182972, 48.750114887952805, 44.2683731764555, 42.942039147019386, 43.51179197430611, 46.165356785058975, 43.179055228829384, 43.30459289252758, 43.23744289577007, 44.875014424324036, 46.222045943140984, 44.68898020684719, 46.64880484342575, 44.13447596132755, 45.27464658021927, 45.14069236814976, 45.661093443632126, 44.811291843652725, 46.83291636407375, 48.2051557302475, 51.36928394436836, 52.041787058115005, 53.53899031877518, 52.85423286259174, 54.507014974951744, 55.89640662074089, 57.05951280891895, 54.19628664851189, 54.7870409488678, 53.13115440309048, 55.12069724500179, 51.20989389717579, 56.34947530925274, 53.36785510182381, 58.29237185418606, 56.679514199495316, 67.26259231567383, 60.73262371122837, 74.77089822292328, 29.98707700520754, 0.12206500628963113, 0.742573847528547, 0.15981503063812852, 0.027875936903001275, 16.204228587448597, 66.45695954561234, 57.535900846123695, 47.92290307581425, 33.01696792244911, 15.430514104664326, 11.631951034069061, 35.198180079460144, 44.727658331394196, 56.42623119056225, 17.20652550458908, 0.360171896754764, 0.024472527438774705, 0.01565166443469934, 0.04479319875827059, 0.025200880445481744, 0.02301972697750898, 0.006876681463836576, 0.06496584872365929, 0.05037136623286642, 0.058291636742069386, 0.026555320364423096, 0.10548233985900879, 0.07292746056918986, 0.05437121195427608, 0.08230517181800678, 0.03077371929975925, 0.02318660630407976, 0.0890811433782801, 0.12037481690640561, 0.09648727253079414, 12.37677851691842, 79.45568963885307, 63.87523368000984, 64.41023737192154, 36.687802746891975, 43.09289865195751, 30.25188099592924, 52.72180616855621, 68.37015688419342, 81.53806909918785, 17.21102826297283, 0.35883870266843587, 0.17192837985930964, 3.4844427136704326, 2.796093262732029, 2.114253337495029, 17.279563285410404, 88.87783125042915, 73.63956212997437, 74.50563445687294, 65.17388999462128, 77.21678137779236, 69.9658052623272, 70.00796020030975, 66.38508260250092, 68.35287541151047, 63.13236974179745, 59.7297777235508, 51.17754243314266, 49.542729556560516, 49.56144355237484, 49.74905468523502, 48.71723145246506, 50.01354329288006, 49.85547937452793, 48.51495310664177, 49.310356825590134, 52.3536591231823, 52.76881344616413, 60.79574212431908, 62.28594996035099, 62.456351816654205, 55.027974620461464, 49.769584983587265, 49.21494774520397, 48.55110056698322, 46.99897885322571, 48.47284376621246, 51.535122245550156, 46.42079047858715, 48.04743379354477, 50.456637516617775, 49.34907674789429, 45.94659112393856, 47.64866419136524, 46.18494853377342, 47.29526795446873, 48.196492195129395, 47.69877590239048, 46.60266771912575, 47.10790000855923, 46.94850616157055, 46.04890823364258, 46.42729572951794, 47.51573592424393, 49.295256435871124, 46.364576295018196, 44.92153912782669, 44.30935777723789, 51.12279877066612, 56.65809474885464, 58.1228781491518, 60.073469281196594, 60.16084939241409, 58.344223871827126, 61.2757133692503, 55.318613424897194, 28.515600264072418, 45.55220268666744, 60.70746146142483, 56.48027569055557, 55.977874249219894, 54.991033002734184, 50.139620527625084, 44.63253803551197, 45.545344054698944, 49.93856571614742, 57.262532114982605, 57.99454003572464, 58.9690775424242, 59.496291652321815, 58.72877463698387, 56.709004417061806, 56.67095325887203, 50.7071390748024, 50.914201363921165, 54.49035666882992, 55.84235452115536, 55.19274137914181, 57.160556986927986, 54.596944749355316, 53.74140925705433, 48.71584452688694, 46.342537477612495, 45.61660163104534, 45.81453301012516, 49.09536816179752, 45.894450321793556, 44.74493980407715, 45.13250380754471, 46.20467707514763, 48.033401146531105, 45.59962794184685, 48.960593193769455, 45.394799932837486, 47.02981039881706, 47.088072672486305, 48.42092715203762, 46.56731441617012, 50.2684336155653, 51.90344028174877, 54.33809123933315, 55.18965594470501, 55.817458257079124, 55.56795984506607, 55.692775547504425, 57.5532279163599, 59.28456701338291, 55.95879927277565, 57.797786593437195, 54.9182403087616, 56.875705271959305, 52.273950800299644, 56.49226404726505, 56.032378524541855, 62.078648284077644, 57.70544394850731, 69.2034749686718, 62.66064025461674, 78.18689212203026, 36.12060338258743, 0.19838799285935238, 1.0343328793533146, 0.33504372637253255, 0.08315596991451457, 15.643233340233564, 71.10003679990768, 64.22118231654167, 48.73268522322178, 33.3833746612072, 24.371236748993397, 18.14525183290243, 42.566778883337975, 51.47754393517971, 66.46906569600105, 24.070528484880924, 0.5514451721683145, 0.029672097552975174, 0.037059556125313975, 0.1285760459722951, 0.03392080951016396, 0.0429397591506131, 0.08037894978770055, 0.03504570500808768, 0.04467447739443742, 0.0745670503238216, 0.10353400182793848, 0.3648935887031257, 0.19178039976395667, 0.2002590213669464, 0.2537473855772987, 0.12771417503245175, 0.2384948407416232, 0.20351403654785827, 0.3217964497162029, 0.3657674230635166, 18.15929587930441, 93.43076214194298, 74.76107195019722, 75.97086623311043, 39.68619905412197, 53.801818415522575, 59.38903480768204, 68.23671564459801, 75.68470358848572, 89.04908806085587, 20.72190687060356, 0.37173040152993053, 0.7228613365441561, 5.038019511848688, 12.419181391596794, 5.8405891712754965, 22.876928932964802, 93.55225682258606, 76.599922478199, 75.98699256777763, 68.44487607479095, 79.88619893789291, 73.5664464533329, 72.51871347427368, 71.95109233260155, 70.75948387384415, 64.95762079954147, 63.14289517700672, 54.726267009973526, 52.141113728284836, 52.9293168336153, 52.56273910403252, 50.147820487618446, 51.10606826841831, 52.361494302749634, 52.91120320558548, 51.93861499428749, 55.13299338519573, 56.65135771036148, 64.06585425138474, 66.08557507395744, 67.14981436729431, 57.227330803871155, 53.321942165493965, 52.746341452002525, 52.17390216886997, 48.1930647790432, 50.450291857123375, 51.63270100951195, 49.14112530648708, 50.733152478933334, 51.919049844145775, 50.66974148154259, 48.75524081289768, 51.12429589033127, 49.92493584752083, 48.161283284425735, 50.597518756985664, 49.10960219800472, 48.33874136209488, 50.28518691658974, 49.167427495121956, 48.154432252049446, 48.9089235663414, 50.583189725875854, 52.73352473974228, 47.06489011645317, 48.89197647571564, 46.181255131959915, 55.05591072142124, 58.55869576334953, 61.70292444527149, 64.03590425848961, 63.42145822942257, 59.51086387038231, 63.761520981788635, 57.345823645591736, 32.42623642086983, 49.107614904642105, 62.70228981971741, 60.3805536031723, 59.74620804190636, 58.04562449455261, 52.3319660872221, 47.1756237745285, 48.64744059741497, 54.47943605482578, 60.43342776596546, 58.925965055823326, 60.814520716667175, 62.759909927845, 60.69132752716541, 58.39834436774254, 60.967990681529045, 50.957462042570114, 52.94581554830074, 58.12171161174774, 59.71713960170746, 59.4552044570446, 60.08056350052357, 57.220411375164986, 55.82761511206627, 52.77554288506508, 48.54543127119541, 47.441643700003624, 47.69185647368431, 52.207784950733185, 47.44014658033848, 47.80861660838127, 47.60102614760399, 49.95277315378189, 48.944368064403534, 47.67835199832916, 50.64031206071377, 47.843992710113525, 50.023548156023026, 49.944637790322304, 51.05628713965416, 49.072413593530655, 53.42185020446777, 56.244821324944496, 56.665895730257034, 57.85400837659836, 58.59181858599186, 58.89273203909397, 60.37536308169365, 59.95788708329201, 63.48392687737942, 58.869298696517944, 61.26749061048031, 58.769869431853294, 60.574225410819054, 55.73224022984505, 60.62976323068142, 59.37534414231777, 63.86228397488594, 62.538279220461845, 73.72327163815498, 66.23678416013718, 81.6841408610344, 36.82803802192211, 0.27047373179811984, 4.5292211137712, 0.7242806197609752, 0.1684457331430167, 21.208894439041615, 77.80546098947525, 68.99309545755386, 64.00653943419456, 46.02528490126133, 23.08636799454689, 21.73870000988245, 53.331658244132996, 61.29091635346413, 78.31494525074959, 30.431981831789017, 1.123318641912192, 0.16158661135705188, 0.11317047028569505, 0.21711326931836084, 0.15534715319518, 0.17245549766812474, 0.1656016896595247, 0.1425903767812997, 0.1516875042580068, 0.12449130968889222], [0.03525830805301666, 0.09040237404406071, 0.051387618732405826, 0.07649928375030868, 0.01942956161656184, 0.03695155137393158, 0.0381389023095835, 0.03496574230666738, 0.04245409400027711, 0.03823471728537697, 13.589877672493458, 67.56485089659691, 51.337935626506805, 43.7687873840332, 18.375430181622505, 62.29348875582218, 61.092228814959526, 40.844555497169495, 70.47061577439308, 63.126537054777145, 4.053519414737821, 0.39484402688685805, 0.35906562174204737, 2.0280473632737994, 3.199258279055357, 1.54905658448115, 40.37002936005592, 76.64380252361298, 69.13700893521309, 61.693546548485756, 62.949648946523666, 66.25398203730583, 70.56982845067978, 68.46563816070557, 65.07913067936897, 68.61112475395203, 65.84257811307907, 62.82849624752998, 61.97942800819874, 58.73852111399174, 53.918859735131264, 47.78392173349857, 45.32963342964649, 44.72896546125412, 46.97111114859581, 47.46834106743336, 47.5062820315361, 46.06490917503834, 46.397273540496826, 46.87941446900368, 48.96929852664471, 47.379475235939026, 43.52148525416851, 44.8225886374712, 47.461915612220764, 45.17594687640667, 45.447031930089, 43.133214488625526, 49.0543607622385, 45.65262369811535, 44.32344742119312, 45.35177864134312, 47.16013960540295, 45.169407427310944, 46.38568416237831, 42.83050373196602, 43.26776906847954, 42.902376875281334, 43.79207253456116, 44.86562132835388, 46.41728326678276, 45.88896341621876, 43.74241299927235, 43.837252110242844, 45.39405897259712, 45.19863925874233, 43.618543446063995, 42.34851859509945, 44.011012986302376, 45.44482424855232, 53.58453847467899, 55.001220256090164, 59.08049896359444, 56.207628920674324, 57.011509984731674, 55.36538131535053, 54.84825186431408, 26.24086182564497, 35.02514876425266, 54.69529487192631, 57.351397946476936, 53.929632157087326, 52.76900723576546, 54.10810858011246, 49.862163215875626, 40.90652637183666, 42.755845338106155, 45.063256323337555, 46.31011001765728, 52.970746010541916, 52.56762184202671, 55.15847861766815, 52.14494772255421, 50.52486665546894, 45.553680807352066, 43.640829250216484, 44.90588776767254, 44.430818259716034, 46.85111738741398, 45.60810528695583, 44.84527342021465, 42.63028867542744, 42.54375971853733, 41.84160679578781, 43.63636828958988, 43.937540128827095, 44.02347631752491, 44.27261374890804, 42.013893350958824, 42.9579146951437, 45.358105301856995, 43.40658321976662, 47.423799857497215, 45.41102506220341, 44.61399123072624, 44.09442991018295, 44.346979558467865, 44.45314586162567, 46.008387207984924, 48.251938819885254, 50.87863527238369, 53.66012021899223, 51.687786653637886, 54.076300486922264, 55.81166356801987, 60.70064462721348, 57.239919528365135, 54.626586958765984, 54.135641902685165, 50.06424397230148, 50.169334933161736, 49.715475887060165, 53.11783991754055, 53.15522991120815, 56.34707383811474, 54.22586426138878, 58.894517943263054, 61.26228109002113, 64.0436178445816, 70.2117432653904, 63.98337587714195, 3.9938360173255205, 0.7123398792464286, 0.8026274875737727, 0.01451386948247091, 1.8764762277714908, 48.88549402356148, 62.24370762705803, 52.4316081404686, 43.680027946829796, 22.80484490096569, 17.52347979694605, 35.141988694667816, 38.20912331342697, 55.87808400392532, 37.72401474416256, 2.819742481224239, 0.1280675857560709, 0.057318410254083574, 0.10197433395660482, 0.010572428000159562, 0.05568010441493243, 0.06428125459933653, 0.06822873066994362, 0.049778349421103485, 0.039956496184458956, 0.09282625062041916, 0.09136116204899736, 0.04466128571948502, 0.04272500387742184, 0.03411436904571019, 0.07233346041175537, 0.04950542832375504, 0.05802747298730537, 0.20490835391683504, 0.11055253693484701, 21.662590093910694, 80.22244289517403, 57.045571357011795, 52.74154610931873, 23.25343932956457, 59.81743901968002, 54.08007748425007, 49.14601184427738, 75.47723472118378, 71.212297976017, 4.168175887316465, 0.382592118694447, 0.08679217440658249, 2.5890468852594495, 2.020720881409943, 2.373203979805112, 51.027359291911125, 78.59169960021973, 71.80586412549019, 63.45085725188255, 65.04133030772209, 69.33638423681259, 70.6868925690651, 70.14099106192589, 69.64549764990807, 70.16988471150398, 69.07875806093216, 67.62909024953842, 63.053554370999336, 59.24403078854084, 54.12217542529106, 49.980393871665, 48.485253900289536, 48.30816440284252, 48.739353865385056, 48.56296733021736, 49.301989674568176, 47.138974741101265, 50.10095000267029, 48.64027038216591, 51.60288020968437, 50.574776977300644, 46.98101721704006, 48.36921572685242, 48.78930598497391, 45.90165473520756, 47.68070787191391, 47.18270279467106, 50.38859076797962, 49.55640882253647, 46.78602308034897, 48.471456840634346, 47.4696633964777, 48.04164670407772, 47.92581371963024, 45.46191193163395, 44.555888548493385, 44.96434383094311, 46.488700434565544, 46.529871225357056, 48.353822752833366, 48.65842580795288, 45.340303257107735, 45.32040372490883, 46.98713108897209, 47.57851995527744, 46.09664127230644, 44.77667950093746, 45.711455941200256, 46.68703079223633, 57.618865594267845, 59.11273643374443, 60.37887789309025, 59.321820214390755, 60.02798572182655, 60.551365837454796, 57.20069043338299, 29.40142013132572, 37.86105819046497, 56.821740567684174, 60.13984031975269, 55.96121594309807, 54.146790504455566, 55.837927758693695, 50.75573846697807, 43.0248861014843, 44.06012915074825, 47.10321485996246, 48.68343226611614, 53.49941924214363, 55.4174917191267, 55.20773537456989, 53.921363800764084, 51.72455348074436, 47.26871497929096, 46.52514047920704, 48.86525630950928, 47.083338126540184, 47.10498936474323, 46.44872657954693, 47.187562733888626, 45.68415440618992, 44.56586681306362, 43.29710349440575, 46.50123976171017, 45.993955582380295, 46.20023511350155, 46.093985214829445, 45.74096895754337, 44.60893750190735, 45.16617000102997, 45.882933139801025, 48.82789671421051, 47.101466953754425, 47.713401317596436, 46.61910943686962, 45.75950816273689, 46.471327766776085, 49.57492522895336, 49.62425038218498, 53.48676212131977, 55.88044747710228, 56.12927332520485, 56.037078872323036, 57.80418545007706, 62.10189163684845, 58.35864409804344, 55.496128499507904, 57.331775799393654, 52.37239591777325, 54.11138400435448, 53.29139560461044, 56.138480231165886, 55.72188578546047, 58.7924250215292, 56.01445488631725, 60.94280943274498, 62.73253619670868, 66.99877247214317, 72.8771710395813, 69.60658773779869, 5.312044182792306, 1.6916542639955878, 1.7390156351029873, 0.0811591102683451, 1.8087867787107825, 52.60785408318043, 69.41884741187096, 56.66176155209541, 37.486067712306976, 24.920808859169483, 25.80290112644434, 42.860126942396164, 48.972083777189255, 62.172032073140144, 48.504195883870125, 4.160796208307147, 0.112899363739416, 0.03398501641640905, 0.055794833024265245, 0.008552306662750198, 0.01851604276453145, 0.07815156423021108, 0.06151996800326742, 0.1557835954008624, 0.028200171946082264, 0.1608262662193738, 0.13980273652123287, 0.21191304054809734, 0.16029977181460708, 0.06545176991494372, 0.24006887659197673, 0.24517893441952765, 0.13722528732614592, 0.20411606674315408, 0.23662520747166127, 32.86292798817158, 92.2674697637558, 65.78181177377701, 62.1920607984066, 30.116387866437435, 72.56137758493423, 75.82307696342468, 60.07682830095291, 81.75546303391457, 79.85314071178436, 5.155886337161064, 0.3179821075173095, 0.6429158826358616, 4.385539423674345, 12.278693430125713, 5.171791333705187, 61.89324863255024, 79.85648453235626, 76.2285304069519, 67.43039131164551, 69.96518209576607, 71.05984255671501, 73.73513460159302, 70.6886100769043, 73.34310963749886, 71.57710120081902, 72.93632626533508, 68.56782227754593, 67.71495804190636, 63.34498733282089, 56.730389669537544, 53.52651558816433, 51.11739166080952, 48.92517909407616, 53.11543084681034, 51.84134021401405, 51.745744943618774, 48.893724381923676, 51.7172122746706, 51.207146644592285, 54.651585817337036, 53.226251900196075, 49.03681330382824, 49.461083337664604, 51.41958944499493, 49.96394455432892, 49.72200773656368, 48.74373883008957, 53.7320351600647, 51.29689782857895, 49.28664229810238, 48.91464985907078, 50.88393598794937, 50.14447286725044, 51.93192355334759, 48.72510842978954, 47.268794775009155, 46.875629872083664, 47.87620358169079, 48.895130306482315, 50.832786932587624, 50.8687824010849, 47.213348150253296, 47.42415323853493, 48.95870469510555, 50.110046714544296, 49.59027260541916, 46.852777898311615, 50.58654114603996, 49.28562395274639, 60.16490377485752, 62.18409262597561, 62.644817903637886, 60.58450385928154, 61.83060519397259, 62.81126417219639, 58.967861607670784, 34.3002350628376, 40.70791482925415, 59.25182417035103, 63.28639067709446, 57.1519086509943, 56.264842450618744, 58.25809769332409, 54.16830115020275, 47.11966797709465, 46.21710240840912, 50.119143426418304, 50.06182350218296, 58.83899912238121, 57.292466908693314, 60.00000022351742, 54.154842272400856, 55.60159184038639, 50.16118437051773, 47.91569486260414, 51.19302660226822, 49.677599519491196, 50.246261805295944, 50.30475206673145, 50.60253828763962, 48.601250275969505, 47.70204372704029, 46.35339729487896, 48.5402787476778, 49.09544415771961, 47.66490451991558, 48.87883298099041, 46.8181237578392, 45.88107883930206, 47.6253904402256, 48.22617620229721, 51.974986642599106, 50.096245855093, 50.12123331427574, 47.607455402612686, 47.75739535689354, 47.91336178779602, 53.03877755999565, 53.1109356880188, 55.92534586787224, 58.64058516919613, 58.4095423668623, 60.237711668014526, 61.400240287184715, 65.1372067630291, 63.16452741622925, 60.43796472251415, 60.51556035876274, 55.21921455860138, 58.18478062748909, 55.90090937912464, 58.64744380116463, 58.65152858197689, 62.97558635473251, 57.70048901438713, 66.7167592048645, 66.18370860815048, 70.18890649080276, 74.01188895106316, 70.45748367905617, 5.604373421519995, 5.1193593721836805, 2.6647917833179235, 0.19095177704002708, 2.845784858800471, 59.524657130241394, 73.83095026016235, 67.95515075325966, 55.43972432613373, 34.193802773952484, 29.765406399965286, 53.67380328476429, 59.611592665314674, 73.47382262349129, 58.31043228507042, 5.922425854951143, 0.3142238419968635, 0.13858749938663095, 0.21616173209622502, 0.09754484781296924, 0.29088635521475226, 0.20145389396930113, 0.15701504104072228, 0.2368830147315748, 0.14204106875695288], [0.02454129484249279, 0.062177670406526886, 0.08593563950853422, 0.029175810414017178, 0.02420744342089165, 0.03130543285806198, 0.041379215545021, 0.04435566930624191, 0.06076987563574221, 0.6417941115796566, 36.96380473673344, 61.3056443631649, 49.51583459973335, 33.931480050086975, 23.59733037650585, 19.917946010828018, 36.66614770889282, 59.58812892436981, 73.71283739805222, 50.952438712120056, 0.49486790027003735, 0.01303766353885294, 0.25051779637578875, 2.219222942367196, 1.349154773633927, 2.4889172706753016, 84.0664990246296, 78.47813129425049, 70.27979001402855, 59.19190138578415, 57.12363816797733, 67.64669850468636, 69.57363590598106, 63.574392423033714, 58.62645372748375, 67.2648037970066, 66.28822579979897, 66.13089144229889, 60.533126816153526, 61.81244596838951, 60.412088111042976, 56.5229170024395, 49.37259368598461, 45.41673995554447, 45.32171465456486, 43.379167690873146, 45.23106671869755, 46.29302613437176, 47.39666171371937, 45.36850154399872, 46.431186720728874, 45.77150411903858, 46.16430424153805, 44.71413865685463, 43.59983704984188, 45.84227912127972, 46.949323117733, 46.38463921844959, 46.31035700440407, 45.25948539376259, 43.88587050139904, 45.94911798834801, 46.12688384950161, 45.165995210409164, 45.836970806121826, 44.04549613595009, 43.28467056155205, 45.04098191857338, 43.01036708056927, 43.57833780348301, 41.639860421419144, 43.75204548239708, 43.864504247903824, 44.520413652062416, 44.836271703243256, 44.2887856811285, 43.96663896739483, 42.90211468935013, 44.806789085268974, 43.514182046055794, 52.03201398253441, 57.49076686799526, 56.583668142557144, 57.340059354901314, 56.597852781414986, 55.176884829998016, 56.87179908156395, 38.25984679162502, 32.11939908564091, 47.93613016605377, 58.664558082818985, 55.553041845560074, 54.701252952218056, 54.293861612677574, 54.64843578636646, 46.36203043162823, 43.14251258969307, 44.562344402074814, 43.41897055506706, 44.148721396923065, 43.76406043767929, 44.7549294680357, 42.121134996414185, 41.88468888401985, 40.61601296067238, 40.97021475434303, 44.39789682626724, 41.88374653458595, 42.71621346473694, 41.59515582025051, 40.09557008743286, 40.417006239295006, 41.93660169839859, 41.431973576545715, 44.67773661017418, 42.66435764729977, 44.57516111433506, 43.88365142047405, 44.69225563108921, 43.3548603951931, 43.224538788199425, 44.413969963788986, 44.80813421308994, 44.39197674393654, 44.66028034687042, 43.93763892352581, 45.12228615581989, 44.520926624536514, 48.036744967103004, 50.999810770154, 53.246121034026146, 52.66100563108921, 59.362595826387405, 54.822557643055916, 58.521780744194984, 59.04000073671341, 59.76166941225529, 56.672765761613846, 57.16041259467602, 54.63204346597195, 54.906886518001556, 52.71816596388817, 52.9857362061739, 56.71025834977627, 59.25595074892044, 59.31725285947323, 61.53732933104038, 61.13435335457325, 64.67070579528809, 62.14705981314182, 75.6594729423523, 17.458983957767487, 0.6677615025546402, 0.39014516340103, 0.13899148005293682, 0.09084278673981316, 19.31403111666441, 68.84256273508072, 56.13538719713688, 63.30396093428135, 44.92673724889755, 15.156467109918594, 12.920864671468735, 31.183311715722084, 45.36105014383793, 53.239277601242065, 10.722426138818264, 0.4154171916889027, 0.04018500716483686, 0.023544911491626408, 0.07725701652816497, 0.019418872834648937, 0.031170703368843533, 0.07025314625934698, 0.03857662100926973, 0.05304196980432607, 0.05939937378570903, 0.026277729302819353, 0.0615436313819373, 0.03501859806419816, 0.03422008427151013, 0.06721961763105355, 0.05682111936039291, 0.035170508272130974, 0.044908728887094185, 0.8475998556241393, 50.19021101295948, 71.17329686880112, 58.29314701259136, 39.72628690302372, 25.89645590633154, 33.61447066068649, 44.53820049762726, 63.96655037999153, 79.02925372123718, 53.48476342856884, 0.4141577077098191, 0.1134546980028972, 0.2952302643097937, 1.430524557363242, 2.1666705748066306, 8.926448710262775, 86.83386012911797, 76.8483379483223, 73.71502608060837, 62.143279016017914, 62.57960580289364, 71.47682458162308, 72.92103588581085, 64.48304146528244, 62.352856770157814, 68.70267704129219, 68.09927701950073, 67.45466440916061, 65.5880905687809, 64.6069984138012, 63.25210891664028, 58.400981426239014, 51.78483724594116, 48.502789959311485, 49.22270692884922, 46.0400927066803, 49.57328371703625, 49.92496244609356, 48.79596322774887, 48.02325189113617, 47.908885627985, 47.09010936319828, 48.66381011903286, 48.18630114197731, 46.40912890434265, 47.997170090675354, 48.922648429870605, 47.84920983016491, 47.199756279587746, 48.80866214632988, 47.07456059753895, 48.73198606073856, 48.92371617257595, 48.30347925424576, 46.97270326316357, 45.76692536473274, 46.06338545680046, 46.172705590724945, 46.20506465435028, 45.643633380532265, 43.75387318432331, 46.04543901979923, 46.87850631773472, 45.99667623639107, 47.019239366054535, 46.453928500413895, 45.445067435503006, 47.17676751315594, 47.91427753865719, 45.84512136876583, 54.51403319835663, 58.830179795622826, 58.56153801083565, 60.05357354879379, 59.30185988545418, 56.92718870937824, 60.81217244267464, 41.83693304657936, 34.16288763284683, 49.155534133315086, 61.675341725349426, 57.173495292663574, 57.60715462267399, 57.31501869857311, 55.95761373639107, 48.6248280107975, 45.011427104473114, 45.16022332012653, 45.72252094745636, 43.979892656207085, 45.8531541377306, 46.87555767595768, 43.0145126581192, 43.759261295199394, 43.99325653910637, 44.38814654946327, 45.36639645695686, 44.65790167450905, 43.55968080461025, 43.465073481202126, 42.698639407753944, 41.92824214696884, 43.793451860547066, 43.62941846251488, 45.491098165512085, 45.64612224698067, 47.75503188371658, 44.940477311611176, 47.485550343990326, 45.37876859307289, 47.29696646332741, 45.12259013950825, 46.26838065683842, 46.318465769290924, 47.927189245820045, 45.612710639834404, 46.58936843276024, 47.265082374215126, 49.43090155720711, 51.209487318992615, 55.45612424612045, 55.202427059412, 60.34808434545994, 57.68433228135109, 62.77421995997429, 60.47500893473625, 63.488855212926865, 59.41419705748558, 61.17824859917164, 59.30493392050266, 57.07589752972126, 55.69632835686207, 57.321444153785706, 59.196100160479546, 62.964449152350426, 61.47538885474205, 65.08530914783478, 63.646090775728226, 67.03387498855591, 64.67614710330963, 79.53125238418579, 20.937946178019047, 0.6922876427415758, 3.3012611931189895, 0.6226195686031133, 0.11735174513887614, 22.920873574912548, 74.15296778082848, 61.981327906250954, 53.40635843575001, 38.24849680066109, 21.05391025543213, 17.824210859835148, 40.952724292874336, 52.48414792120457, 62.876354679465294, 14.354097414761782, 0.5017210403457284, 0.06393236355506815, 0.012454503375920467, 0.028318806107563432, 0.03634892374975607, 0.05510871749720536, 0.03772635725908913, 0.004700564395534457, 0.1042235831846483, 0.12439250014722347, 0.2043989734374918, 0.14074054401135072, 0.09840704529779032, 0.1462421441101469, 0.12145662331022322, 0.10621993074892089, 0.19723021279787645, 0.22449211712228134, 1.5448699216358364, 64.725172072649, 81.47693797945976, 72.2715899348259, 50.11881284415722, 36.48844264447689, 29.422269612550735, 49.13399688899517, 76.6385968029499, 84.18440669775009, 61.651604399085045, 0.971671569859609, 0.19127220672089607, 1.5080231800675392, 8.183304537087679, 6.937332395464182, 14.464224055409431, 86.1226598918438, 80.18764436244965, 76.29673674702644, 65.8308519423008, 65.51953464746475, 75.07681980729103, 76.2255285680294, 65.86628884077072, 62.97908216714859, 72.43447199463844, 71.05169579386711, 72.0295125246048, 67.64767125248909, 68.03393572568893, 66.78787618875504, 60.74109725654125, 53.781272917985916, 49.09897416830063, 50.86716748774052, 47.12881028652191, 53.201264441013336, 52.032439559698105, 51.96428261697292, 48.99400860071182, 51.6510084271431, 49.664915800094604, 51.72048009932041, 50.60665726661682, 49.63974975049496, 51.63988642394543, 50.646741315722466, 52.303543612360954, 52.11367920041084, 50.28828755021095, 48.39342802762985, 50.794294998049736, 50.77738210558891, 49.51019570231438, 51.88550144433975, 49.08759757876396, 47.7886638790369, 51.18867963552475, 47.280893325805664, 46.98505640029907, 46.108185052871704, 48.22182163596153, 49.29846726357937, 48.58095556497574, 48.605433851480484, 51.25943563878536, 48.38285319507122, 49.99954104423523, 49.74478371441364, 48.56064185500145, 55.58502472937107, 62.51940943300724, 61.50823809206486, 62.85819165408611, 61.50271698832512, 60.910499766469, 62.29896046221256, 45.73590002954006, 37.70662307739258, 51.390802189707756, 65.20691022276878, 58.51338319480419, 57.856064066290855, 60.28837434947491, 58.72549541294575, 51.40132762491703, 47.77577497065067, 47.51366883516312, 47.997059896588326, 47.70740523934364, 48.116966262459755, 49.19434905052185, 45.8403754234314, 45.52115075290203, 46.6185736656189, 45.5452224612236, 50.23098662495613, 46.85371644794941, 47.084075286984444, 45.28144061565399, 45.013855174183846, 43.15235786139965, 46.65126711130142, 46.13348789513111, 49.047828912734985, 47.34053112566471, 50.61071924865246, 47.71699972450733, 50.14821566641331, 46.460110768675804, 50.09754158556461, 48.31984117627144, 48.58248308300972, 49.09075140953064, 48.002565801143646, 47.65564061701298, 49.91043582558632, 49.20884147286415, 50.92050142586231, 54.996763095259666, 57.679156959056854, 57.77091063559055, 64.27318632602692, 60.606272891163826, 65.26036575436592, 64.47913527488708, 63.72364081442356, 63.57520937919617, 62.48649939894676, 60.94701960682869, 60.68403571844101, 57.05803468823433, 57.79429838061333, 60.32252311706543, 65.46183854341507, 65.18731087446213, 68.24252933263779, 65.75440764427185, 70.64011707901955, 65.84649950265884, 82.17526450753212, 22.336058355867863, 1.5478155948221684, 3.3561015129089355, 0.5030971008818597, 0.1511392797692679, 27.303649596869946, 81.36605992913246, 69.42343756556511, 80.12275904417038, 53.88607509434223, 26.590940840542316, 27.124831192195415, 52.10428990423679, 61.89736761152744, 72.88384348154068, 19.754780866205692, 0.6344304035883397, 0.20627273304853588, 0.16445799556095153, 0.13706793717574328, 0.09347749262815341, 0.17021124309394509, 0.13853076961822808, 0.09608916967408732, 0.20627740857889876], [0.03066325247345958, 0.05467233095259871, 0.06101291786762886, 0.08215563648263924, 0.014507148407574277, 0.07641480508027598, 0.032854417513590306, 0.11095414272858761, 0.09802644970477559, 3.3174136513844132, 50.4460284858942, 58.13782274723053, 45.97098581492901, 43.93100827932358, 26.911945715546608, 19.653147719800472, 39.47320908308029, 58.0399551987648, 74.45708826184273, 30.14835935086012, 0.14126856724033132, 0.017551183991599828, 0.434950043563731, 0.612846789881587, 3.512128028087318, 29.309066087007523, 91.23951092362404, 64.83427181839943, 71.10148072242737, 59.21364761888981, 52.60056987404823, 61.74636371433735, 68.61435458064079, 68.21680471301079, 65.76866447925568, 56.36191964149475, 60.759176686406136, 60.22091656923294, 60.18230304121971, 60.7592298835516, 61.13953247666359, 61.8660306930542, 58.788127452135086, 50.62539406120777, 47.716083973646164, 44.44851391017437, 46.03298708796501, 48.5224387049675, 44.62197080254555, 46.742553412914276, 47.47315540909767, 47.09787614643574, 46.70133322477341, 44.958142563700676, 45.452826619148254, 44.419525265693665, 43.677599877119064, 45.4127311706543, 43.88122335076332, 44.99694228172302, 45.03562040627003, 46.04800768196583, 45.17539210617542, 45.1072845607996, 44.364823400974274, 42.17386856675148, 42.079075053334236, 42.510458305478096, 44.11504380404949, 40.71017190814018, 41.92479573190212, 43.63366283476353, 45.2178206294775, 44.74210135638714, 45.18357306718826, 43.19730564951897, 42.585713267326355, 42.4585834890604, 43.1487138569355, 43.77210080623627, 46.59405738115311, 52.75040723383427, 55.04625543951988, 53.34357060492039, 53.95718067884445, 51.35250024497509, 55.23680001497269, 47.47568227350712, 37.901054844260216, 54.7927862405777, 55.56093022227287, 55.01569747924805, 53.89622434973717, 52.517821714282036, 55.561876371502876, 49.60974656045437, 42.174533531069756, 41.70572988688946, 42.26291298866272, 42.85065025091171, 42.866423204541206, 43.08313697576523, 43.02144728600979, 43.89199577271938, 43.62805433571339, 42.34605252742767, 42.74861812591553, 43.47600929439068, 42.06250034272671, 42.36773036420345, 42.58822873234749, 42.74452954530716, 42.63513721525669, 43.05641680955887, 43.17412309348583, 42.90035918354988, 43.866092562675476, 43.093647211790085, 43.563746586441994, 41.43142640590668, 44.42273989319801, 45.96005380153656, 43.877822533249855, 45.685951709747314, 44.81518283486366, 45.159220173954964, 46.22512757778168, 45.800602957606316, 45.78182056546211, 48.85152764618397, 55.53693450987339, 54.33300331234932, 55.73927365243435, 55.33148713409901, 58.05805362761021, 59.22677971422672, 59.38732109963894, 60.39326772093773, 58.84117640554905, 56.61011852324009, 57.310964316129684, 56.61250859498978, 58.992662876844406, 61.031386479735374, 62.977672442793846, 63.62263083457947, 64.68443065881729, 67.18268260359764, 68.86668384075165, 65.86825713515282, 76.04360952973366, 39.43290464580059, 0.1836211688350886, 2.3641735268756747, 1.8467709654942155, 0.309129087254405, 17.238403894007206, 65.44273316860199, 58.4820918738842, 57.39875480532646, 58.23605127632618, 32.94631831347942, 19.704625457525253, 39.552309438586235, 47.45169036090374, 53.94319362938404, 20.76215621083975, 0.8153800189029425, 0.04736819515528623, 0.05606710103165824, 0.01568245243106503, 0.025395913144166116, 0.08701270358869806, 0.035538042066036724, 0.03956397427828051, 0.05274449475109577, 0.024996971660584677, 0.022382990246114787, 0.007931874915811932, 0.025985046668210998, 0.02978648291900754, 0.009992573177441955, 0.03178720915457234, 0.06815344720962457, 0.0946541158191394, 4.827003534883261, 63.87359976768494, 62.84784860908985, 57.01594814658165, 50.15356957912445, 39.35743689537048, 20.509220883250237, 41.90369166433811, 66.62387698888779, 80.29690369963646, 32.18195132911205, 0.28010609617922455, 0.0428268859104719, 1.327460550237447, 0.3935460699722171, 2.7423475217074156, 34.302100762724876, 87.72062614560127, 70.18443033099174, 73.76054763793945, 62.258359640836716, 54.374675676226616, 65.28431966900826, 71.42004802823067, 70.6899856030941, 65.03433108329773, 59.09672789275646, 64.11626994609833, 63.05734656751156, 59.49547469615936, 61.82843551039696, 63.86861443519592, 64.95612367987633, 61.862546280026436, 52.82201439142227, 48.960600793361664, 46.27041354775429, 46.93265721201897, 49.55001376569271, 46.566641852259636, 49.60607975721359, 49.02781538665295, 50.96748970448971, 49.62979048490524, 46.84005618095398, 47.414452359080315, 46.12102456390858, 45.09771287441254, 46.59696042537689, 46.20603360235691, 46.13443024456501, 46.397778913378716, 48.17001901566982, 46.00950814783573, 48.4165345877409, 46.762772127985954, 45.4076736420393, 44.9948637932539, 44.47430692613125, 46.04203440248966, 44.017769023776054, 45.71836777031422, 44.73496913909912, 46.821874156594276, 45.666443556547165, 45.65554954111576, 45.948730409145355, 44.97839167714119, 44.68944378197193, 44.69982102513313, 45.99564649164677, 49.05767038464546, 56.210117787122726, 57.197703793644905, 57.48231992125511, 55.40579974651337, 53.808335065841675, 57.18365974724293, 50.18342837691307, 40.765424743294716, 55.2446161955595, 56.56305804848671, 56.653736382722855, 54.80678848922253, 55.57225361466408, 57.34293960034847, 52.442779541015625, 44.00559827685356, 44.63638722896576, 43.88067238032818, 45.47783687710762, 44.268183186650276, 44.06335137784481, 44.20040242373943, 45.06643295288086, 44.35440815985203, 43.52032631635666, 43.890289664268494, 45.58753699064255, 44.843517914414406, 46.446108520030975, 45.84173575043678, 44.146863296628, 44.412032067775726, 44.91225242614746, 46.01665936410427, 45.89931786060333, 46.09578251838684, 46.085462272167206, 45.717072039842606, 42.87433438003063, 46.40344440937042, 46.200455501675606, 44.833843633532524, 46.55384413897991, 47.10536174476147, 48.082072734832764, 47.79364161193371, 47.14331790804863, 48.677861765027046, 52.301202937960625, 58.64322982728481, 59.149070084095, 58.39919172227383, 58.54366756975651, 60.192991867661476, 61.47049471735954, 60.872266218066216, 61.3367684930563, 59.855763763189316, 57.60322563350201, 60.076360926032066, 58.38368095457554, 62.5535885989666, 62.86472350358963, 64.18224200606346, 65.11205971240997, 67.29997470974922, 67.89107099175453, 71.07169032096863, 66.75777420401573, 76.68510630726814, 43.365309834480286, 0.39468894770834595, 2.931281221099198, 2.525466321967542, 0.2806519309524447, 16.401895880699158, 70.15118211507797, 64.3029235303402, 60.06349861621857, 43.370127975940704, 29.535247050225735, 27.412775941193104, 49.23112727701664, 55.385098457336426, 62.63174660503864, 27.486368492245674, 0.6263500778004527, 0.11018586403224617, 0.1280040282290429, 0.08933310251450166, 0.1130422716960311, 0.0060407884757296415, 0.07621631768415682, 0.050281458752579056, 0.036220747424522415, 0.12284734126296826, 0.17141024203738198, 0.2017030181013979, 0.19058322650380433, 0.13525500398827717, 0.15191543265245855, 0.12748384207952768, 0.24547154840547591, 0.4214620735729113, 8.186741452664137, 77.04026564955711, 72.95344054698944, 65.5580721795559, 58.233752399683, 38.825742825865746, 26.88316985964775, 58.593881875276566, 71.0436250269413, 88.61577451229095, 36.59075975418091, 0.2172211479046382, 0.14108454430243, 2.451447006314993, 4.758052909746766, 6.738317124545574, 37.42747105658054, 91.39918595552444, 74.61592733860016, 74.37717095017433, 66.10376089811325, 57.903090342879295, 69.12854298949242, 74.02128204703331, 73.30695077776909, 67.8885555267334, 61.62478543817997, 65.78589275479317, 67.8402753174305, 65.49122616648674, 63.57988692820072, 66.58158525824547, 67.61584416031837, 64.70078498125076, 55.9654451161623, 51.50871366262436, 49.35597337782383, 49.601322412490845, 54.55759786069393, 48.96596610546112, 50.69064795970917, 51.40439786016941, 52.38219179213047, 52.03878901898861, 49.76680353283882, 49.69455420970917, 48.75658594071865, 45.74444957077503, 49.88788403570652, 47.52580538392067, 49.54894982278347, 49.49130691587925, 50.40209524333477, 48.17923352122307, 50.59819132089615, 48.99579830467701, 48.036915957927704, 46.02898210287094, 46.543231308460236, 47.56443791091442, 45.94262033700943, 47.410481572151184, 47.57871374487877, 50.26310630142689, 50.17057366669178, 48.67934748530388, 47.27076306939125, 46.41141638159752, 46.31550192832947, 47.74625055491924, 49.35870923101902, 51.74413003027439, 60.25287285447121, 59.50951874256134, 58.931041583418846, 59.02556151151657, 57.50439293682575, 58.553501442074776, 51.71953774988651, 42.72917456924915, 57.774539440870285, 59.714863523840904, 60.12627884745598, 57.25495532155037, 57.592916786670685, 60.761551558971405, 54.38436135649681, 46.2206020206213, 45.971916764974594, 47.628103494644165, 48.0322840064764, 46.62087634205818, 46.5666114538908, 47.15606242418289, 49.075020253658295, 47.323709428310394, 46.917674615979195, 46.61743372678757, 48.30205053091049, 45.88471904397011, 48.26858572661877, 49.752193316817284, 47.41573289036751, 46.779099851846695, 48.24954114854336, 47.755461260676384, 46.73646233975887, 47.96621315181255, 48.69923561811447, 48.36377061903477, 45.756962299346924, 48.23370359838009, 50.393678694963455, 48.23111593723297, 50.12760937213898, 48.31292174756527, 50.101196989417076, 51.37226298451424, 49.0750278532505, 49.23662178218365, 54.01933774352074, 59.292398393154144, 60.32400123775005, 60.06159111857414, 61.81562639772892, 63.638285994529724, 65.0669713318348, 63.2758804410696, 62.88178078830242, 64.44508150219917, 59.83591742813587, 62.92666777968407, 61.506554782390594, 64.79715541005135, 67.2089771926403, 66.1404137313366, 68.31381350755692, 68.88719514012337, 72.74224787950516, 73.20557221770287, 70.30670017004013, 77.82023459672928, 47.78871327638626, 0.5286640883423388, 5.454544611275196, 4.056560676544905, 0.5398750898893923, 22.24487654864788, 74.99899238348007, 72.03974917531013, 74.56848308444023, 69.88669350743294, 46.70714311301708, 33.80945719778538, 57.28863291442394, 65.26345118880272, 73.06348264217377, 37.051785215735435, 1.50054850615561, 0.2554004156263545, 0.28429949772544205, 0.14507633401080966, 0.23496272246120498, 0.1671343730413355, 0.15860221290495247, 0.13096121954731643, 0.14299808302894235], [0.05898895498830825, 0.012673398905462818, 0.03769177317735739, 0.03511112903652247, 0.03909224666131195, 0.046871186277712695, 0.026159707413171418, 0.10375159210525453, 0.07345641890424304, 9.476491995155811, 59.292029812932014, 49.79092463850975, 47.73194432258606, 39.5321249216795, 16.390036717057228, 39.97027941048145, 51.61219350993633, 66.31241530179977, 68.83288845419884, 11.50516988709569, 0.2512871066574007, 0.21642261184751987, 0.17597611265955493, 0.07430054509313777, 1.769035211764276, 53.46430152654648, 55.37266932427883, 71.40672594308853, 69.5685213804245, 68.50229859352112, 51.75968259572983, 58.69242958724499, 66.06517016887665, 69.5553968846798, 65.95740795135498, 66.95505201816559, 61.6370739787817, 59.51794669032097, 57.13108956813812, 58.35520148277283, 57.10574492812157, 58.72412368655205, 59.49299342930317, 58.33507016301155, 51.645776107907295, 45.60674875974655, 43.84066812694073, 45.975226387381554, 44.72236141562462, 45.335390120744705, 44.524065256118774, 46.25047221779823, 44.82354998588562, 44.663567170500755, 45.462535098195076, 46.77904285490513, 44.9838899821043, 44.34654638171196, 42.94259771704674, 43.6162331700325, 44.06234063208103, 47.416321858763695, 44.1917122900486, 45.596975684165955, 42.54581540822983, 42.47817903757095, 43.723554611206055, 42.589323073625565, 41.57804913818836, 43.24924126267433, 41.917370930314064, 42.61765815317631, 43.32120940089226, 43.63512195646763, 43.3799010515213, 43.53895291686058, 44.62939940392971, 44.06991362571716, 42.836879789829254, 44.42500837147236, 43.16825620830059, 44.44524608552456, 47.911496087908745, 47.988320365548134, 48.4480918943882, 49.84809257090092, 54.05226297676563, 54.38639044761658, 45.80983646214008, 58.53616677224636, 52.92066849768162, 52.67251521348953, 54.121046885848045, 54.96681310236454, 52.52338841557503, 46.92629635334015, 43.11304897069931, 44.55076262354851, 43.57226572930813, 42.21166893839836, 42.30507552623749, 44.53347735106945, 41.64192371070385, 43.65406014025211, 41.65248714387417, 42.262719199061394, 40.153995752334595, 43.43665100634098, 40.985189750790596, 41.76841512322426, 39.680962935090065, 40.051823034882545, 39.46652144193649, 43.610894456505775, 42.21833378076553, 44.711965173482895, 44.16069835424423, 44.88579824566841, 42.50832661986351, 43.99725392460823, 42.54352793097496, 44.26788680255413, 46.05148449540138, 47.60748580098152, 44.80391263961792, 44.91203583776951, 44.547114819288254, 45.94704329967499, 45.1418437063694, 50.33552661538124, 53.97653304040432, 58.16084571182728, 54.37446288764477, 56.14030413329601, 58.49203214049339, 59.3817999958992, 54.99425522983074, 57.939868569374084, 57.42891378700733, 60.000718384981155, 56.966148018836975, 59.08443935215473, 57.97888867557049, 64.69785913825035, 63.51561337709427, 65.68014442920685, 63.96921783685684, 68.90331387519836, 64.99995052814484, 67.46643617749214, 67.74478644132614, 60.09095974266529, 1.238624642137438, 4.393787831068039, 3.5195077070966363, 0.5883636942598969, 3.9121791115030646, 45.77892892062664, 68.18199098110199, 53.182698637247086, 69.76190820336342, 38.81254993379116, 9.028551131486893, 28.482884019613266, 43.82590971887112, 53.79722446203232, 37.67973572015762, 2.656234879978001, 0.2306593643152155, 0.04006966257293243, 0.02988060765346745, 0.05553714079724159, 0.08939244464272633, 0.027025431954825763, 0.05402390168455895, 0.0856489478610456, 0.03031886441021925, 0.03831148875178769, 0.04953890289471019, 0.11076082068029791, 0.054627290010103025, 0.04626280700904317, 0.06880590633954853, 0.08474833681248128, 0.09953145839972422, 13.341792784631252, 74.01617512106895, 57.29527875781059, 55.85488244891167, 47.397851049900055, 24.370668679475784, 29.837220646440983, 57.223489210009575, 73.22289928793907, 76.8070949614048, 12.372996769845486, 0.22218952974071726, 0.15241424494888633, 0.9638027264736593, 0.7351719634607434, 4.296263689175248, 56.04389950633049, 58.98336477577686, 73.2718938589096, 72.87635788321495, 70.3252811729908, 53.439937233924866, 62.408964559435844, 69.00656193494797, 71.63980543613434, 69.00514841079712, 69.04522106051445, 65.14759540557861, 63.22370544075966, 59.92076687514782, 61.73565208911896, 60.8524426817894, 63.228109404444695, 62.43098057806492, 60.26609614491463, 55.12174978852272, 49.25751306116581, 45.673028603196144, 48.564677238464355, 46.86788968741894, 46.963731944561005, 47.04617612063885, 47.75255061686039, 47.095926851034164, 46.71962544322014, 47.327980399131775, 48.254537880420685, 46.32042646408081, 46.53583310544491, 46.952739134430885, 46.28688186407089, 47.01541677117348, 50.41542872786522, 47.53831051290035, 47.38080516457558, 45.17128832638264, 44.421892538666725, 44.03554067015648, 44.61477018892765, 44.38938148319721, 46.224834993481636, 43.41100238263607, 45.486929789185524, 44.759462624788284, 45.796168595552444, 44.9909234046936, 45.04552647471428, 46.30809232592583, 46.29309833049774, 45.63542582094669, 46.87751077115536, 44.15833108127117, 47.446549236774445, 49.722463712096214, 51.21437385678291, 50.35201393067837, 51.511084735393524, 55.47265715897083, 55.872433707118034, 47.618208825588226, 61.65386527776718, 54.377590119838715, 54.86680246889591, 57.28699520230293, 57.31688819825649, 55.556077882647514, 50.32236412167549, 44.57818195223808, 47.47770756483078, 45.828033685684204, 43.80898542702198, 45.27382202446461, 46.471859738230705, 44.561987221241, 44.411496296525, 43.08423891663551, 43.781832084059715, 41.58081538975239, 43.31703342497349, 42.60305933654308, 43.68143767118454, 42.56160356104374, 41.702245473861694, 41.58426560461521, 45.07439732551575, 44.04399521648884, 46.32903300225735, 44.54620286822319, 46.84715420007706, 43.44727523624897, 45.266815200448036, 44.55213814973831, 46.936867386102676, 46.26813367009163, 49.47501718997955, 45.95791071653366, 46.99594661593437, 46.489498391747475, 48.30181114375591, 46.54325410723686, 53.65465231239796, 57.47282803058624, 61.221779063344, 57.12485030293465, 58.51667381823063, 59.42105948925018, 62.79307074844837, 57.70461179316044, 60.41700504720211, 59.614431113004684, 62.40231491625309, 57.648390009999275, 62.259909957647324, 61.277039498090744, 66.20551943778992, 67.51444280147552, 67.86058142781258, 66.24337300658226, 70.81071272492409, 66.99984401464462, 69.64574083685875, 70.32864019274712, 63.1075494736433, 1.827896547038108, 4.481802033260465, 7.954011065885425, 0.3047077276278287, 3.0671391310170293, 50.662407875061035, 73.11867088079453, 59.42737855017185, 60.82846216857433, 44.884145334362984, 19.629328697919846, 35.55754579603672, 51.117106676101685, 62.13759832084179, 47.23317548632622, 3.454901436343789, 0.16417492559412494, 0.09167514246655628, 0.011966834426857531, 0.03153673802444246, 0.08862962073180825, 0.057125860039377585, 0.04583700720104389, 0.035640647693071514, 0.16586852143518627, 0.07387553196167573, 0.22398720437195152, 0.15759357484057546, 0.143469569447916, 0.09148026932962239, 0.16989808646030724, 0.2080730051966384, 0.2208755275933072, 20.89388184249401, 89.70836788415909, 66.6340984404087, 64.72539246082306, 53.358283415436745, 26.187723577022552, 55.08743762969971, 70.02882108092308, 75.8447813987732, 84.4557273387909, 14.404823742806911, 0.30735746200662106, 0.3562776104081422, 2.037082565948367, 5.289837224408984, 4.624772686511278, 61.045818105340004, 64.44530189037323, 75.2103142440319, 77.7910977602005, 72.8618274629116, 56.56985588371754, 65.26225045323372, 71.7196923494339, 76.322590559721, 72.77511611580849, 70.96561521291733, 67.30995297431946, 63.8690248131752, 62.70925484597683, 62.90747120976448, 61.84554599225521, 64.85941126942635, 63.81802394986153, 62.80234605073929, 57.88359358906746, 50.23938797414303, 48.46124678850174, 50.43666958808899, 48.673830181360245, 49.10875864326954, 51.871730983257294, 51.00953444838524, 50.47917790710926, 48.45001079142094, 49.28775563836098, 49.281064197421074, 47.35430158674717, 48.87351706624031, 48.97390007972717, 47.647269666194916, 49.60405446588993, 53.943170830607414, 49.989460185170174, 49.81578290462494, 48.617456406354904, 46.103598698973656, 48.2394602894783, 45.91448284685612, 46.19820982217789, 48.93642649054527, 45.291339084506035, 47.46356092393398, 49.405765905976295, 49.858853593468666, 47.31996662914753, 46.6549339145422, 48.87396924197674, 48.724124282598495, 47.04026743769646, 49.04656358063221, 46.570859625935555, 50.41364662349224, 53.48131321370602, 52.180901393294334, 52.73493446409702, 53.30454669892788, 57.57117435336113, 58.87492619454861, 50.42409606277943, 66.05128571391106, 56.75291106104851, 56.286755874753, 60.1356453448534, 59.50384944677353, 57.02754132449627, 51.79605044424534, 45.69922439754009, 50.19459217786789, 48.63987140357494, 46.89280115067959, 47.00572349131107, 48.96274767816067, 44.52283792197704, 48.70026156306267, 45.16519345343113, 45.87086498737335, 44.117293283343315, 47.484949976205826, 45.9979909658432, 45.41943401098251, 45.027420446276665, 44.81433168053627, 43.429647982120514, 48.04273344576359, 46.78723521530628, 49.54188600182533, 47.0975037664175, 48.719184547662735, 47.133734822273254, 49.45183843374252, 47.90136583149433, 49.05666723847389, 48.41693356633186, 52.90326543152332, 47.78535805642605, 48.02263252437115, 48.34452085196972, 50.45169398188591, 49.16684612631798, 56.914345398545265, 58.81531499326229, 65.3572529554367, 59.772780016064644, 63.74953642487526, 62.62738063931465, 64.41845253109932, 60.12237265706062, 61.37095145881176, 60.55552661418915, 66.92794427275658, 59.759549126029015, 65.23695901036263, 62.50000387430191, 70.08103787899017, 69.26107227802277, 69.87271785736084, 67.30027869343758, 74.34106528759003, 68.63566383719444, 75.44343933463097, 72.31377527117729, 69.76123943924904, 1.9558628741651773, 9.953848030418158, 8.436129670590162, 0.8722075133118778, 5.522002391517162, 58.68196114897728, 79.98559400439262, 67.74121463298798, 84.2182856798172, 50.425414592027664, 19.23753362149, 43.461402878165245, 62.88430765271187, 68.68281930685043, 57.800108268857, 4.774609096348286, 0.33128163137007505, 0.20052858424605802, 0.0886224812711589, 0.10761126468423754, 0.2499613637337461, 0.11800299456808716, 0.11483691836474463, 0.1590513755218126], [0.11704288554028608, 0.019976394578407053, 0.08295351202832535, 0.08763943245867267, 0.04384509025840089, 0.021141540455573704, 0.07380544353509322, 0.1342683334951289, 0.0735955715936143, 23.981461264193058, 60.49887925386429, 43.70949536561966, 36.95083223283291, 14.155350029468536, 23.537658378481865, 37.19208888709545, 53.11560183763504, 68.25978800654411, 59.746360033750534, 3.4265912929549813, 0.27665953268297017, 0.05585881728620734, 0.534724110038951, 0.20702861045720056, 21.044471561908722, 63.93926024436951, 62.88985535502434, 70.33956080675125, 65.78956335783005, 70.49942582845688, 56.48295074701309, 48.10849271714687, 60.64540319144726, 65.61483353376389, 63.16386245191097, 64.13387060165405, 64.13086116313934, 64.65907081961632, 63.06831657886505, 60.341856479644775, 56.85701407492161, 57.46427468955517, 57.47117131948471, 59.28564615547657, 52.5955655425787, 50.175346210598946, 46.22445121407509, 47.204779610037804, 45.15669710934162, 45.81034563481808, 44.87633295357227, 44.37638618052006, 45.61215206980705, 44.40991938114166, 44.16939228773117, 44.516347870230675, 44.52852621674538, 43.08106608688831, 44.7945499420166, 44.01315987110138, 42.17810533940792, 44.361677169799805, 44.2657171189785, 42.96079494059086, 43.4487571567297, 41.9818876683712, 41.73138611018658, 39.501502364873886, 41.90391965210438, 41.997729018330574, 42.28383846580982, 41.884324103593826, 40.13310067355633, 40.597462356090546, 42.71634265780449, 45.56856460869312, 43.7121020257473, 42.395506873726845, 45.504887625575066, 42.8298881649971, 44.86751362681389, 46.11270301043987, 44.09387893974781, 46.229174360632896, 48.191655054688454, 52.466756254434586, 55.236602425575256, 54.15997579693794, 44.96938996016979, 57.669440880417824, 52.811238169670105, 46.74259901046753, 49.14023235440254, 49.707587510347366, 45.9318783134222, 45.34651592373848, 42.89218582212925, 43.41115817427635, 44.18628618121147, 44.06194165349007, 43.00239510834217, 41.209962889552116, 40.522078201174736, 41.691484451293945, 43.149017840623856, 39.61834989488125, 40.33798947930336, 40.35978130996227, 40.46358034014702, 40.52249617874622, 38.85872505605221, 41.79637402296066, 41.55193313956261, 41.47444009780884, 41.44416332244873, 42.94521577656269, 43.133085295557976, 43.134669810533524, 42.171265706419945, 43.55885624885559, 43.54014225304127, 45.53567737340927, 45.351125076413155, 45.86858510971069, 45.49261048436165, 44.402050003409386, 42.67223462462425, 45.27005262672901, 47.53462851047516, 46.66378743946552, 52.41676613688469, 56.70421287417412, 54.99492019414902, 56.398564875125885, 55.975575372576714, 60.07388725876808, 57.34654180705547, 56.98033645749092, 57.202616930007935, 59.604844227433205, 56.987715661525726, 61.82570345699787, 59.28250752389431, 62.4585746973753, 65.34212976694107, 68.33706825971603, 70.2413360774517, 66.9834440946579, 63.807088136672974, 69.59803059697151, 65.60865506529808, 74.88841071724892, 8.014796879142523, 1.7364170495420694, 2.6358748599886894, 0.0808393930492457, 0.10310889221727848, 23.87084160000086, 72.00077086687088, 52.80957765877247, 59.28188815712929, 34.414700120687485, 14.227081630378962, 22.387587390840054, 39.30817633867264, 50.55511303246021, 52.35401630401611, 6.301998412236571, 0.28966175217647105, 0.09949595405487344, 0.01534126673504943, 0.049341053745592944, 0.06364092216244899, 0.0030347309075295925, 0.02264877373818308, 0.03812563641986344, 0.04714299415354617, 0.02928428086306667, 0.0422835039353231, 0.04830034748010803, 0.0711137407051865, 0.05294360555126332, 0.04720654796983581, 0.03544882849382702, 0.06802180505474098, 31.41356036067009, 71.89607128500938, 52.5559488683939, 45.60285396873951, 25.462665483355522, 27.18653228133917, 31.393018662929535, 62.537173479795456, 72.2721979022026, 67.84335315227509, 3.536474509164691, 0.29035756015218794, 0.1411879700026475, 0.8932618272956461, 1.16564872674644, 23.97264763712883, 65.17233207821846, 63.71102549135685, 71.95771917700768, 69.65631946921349, 71.71794444322586, 58.03673677146435, 50.98585791885853, 61.28968141973019, 68.85585442185402, 67.14309632778168, 66.86789989471436, 67.08378911018372, 67.45538637042046, 64.74260553717613, 61.93805582821369, 59.63218756020069, 59.82445724308491, 60.06705902516842, 61.521586775779724, 55.90875215828419, 53.19635510444641, 49.7189337015152, 49.05446335673332, 47.28785075247288, 47.18869507312775, 46.94964610040188, 45.68713344633579, 47.379277646541595, 47.79644966125488, 46.846903413534164, 47.02800549566746, 48.207443207502365, 45.67300580441952, 45.728973001241684, 46.54018387198448, 44.231549352407455, 46.600642427802086, 47.0014563202858, 45.75199976563454, 46.91044360399246, 44.776717498898506, 42.77610965073109, 43.46040353178978, 42.517746314406395, 44.148782193660736, 44.32637706398964, 44.50403273105621, 43.780532553792, 43.58265437185764, 45.2721007168293, 46.60292610526085, 45.13356015086174, 44.086526334285736, 46.34859435260296, 45.85980758070946, 47.534753903746605, 46.51863902807236, 45.565042197704315, 48.747610822319984, 51.03465110063553, 55.175057128071785, 57.55618795752525, 56.187178418040276, 46.1191588640213, 58.538176864385605, 55.8869831264019, 49.72784802317619, 50.05804270505905, 52.26059451699257, 48.53232577443123, 48.594748824834824, 44.18878644704819, 44.7112850099802, 45.15372186899185, 46.35856121778488, 45.25207199156284, 44.155409038066864, 41.69588841497898, 43.81220765411854, 46.44510917365551, 42.75936394929886, 42.336450442671776, 42.36971765756607, 42.28911258280277, 42.92778231203556, 41.136155650019646, 43.67399387061596, 43.77097986638546, 43.068332970142365, 46.68480411171913, 45.83705060184002, 45.31065344810486, 45.890677124261856, 44.16665643453598, 44.63467352092266, 46.02803975343704, 47.522035986185074, 46.92915000021458, 48.75905580818653, 46.21970146894455, 46.49714358150959, 45.511962845921516, 47.43059389293194, 48.487252593040466, 48.21563936769962, 55.951344072818756, 57.36175239086151, 58.47152844071388, 59.876609444618225, 56.10226437449455, 62.71577149629593, 57.992203161120415, 60.46640619635582, 57.36884281039238, 59.89474207162857, 60.889365300536156, 65.44129684567451, 60.99570259451866, 64.36936676502228, 66.83772951364517, 67.84239560365677, 66.34194731712341, 69.36541467905045, 64.6440464258194, 71.50678217411041, 65.99468395113945, 77.59263440966606, 9.142888896167278, 0.8684806257952005, 3.774393992498517, 0.17261679604416713, 0.1483869063667953, 25.658774860203266, 77.67368406057358, 60.53948387503624, 62.21820339560509, 36.61217160522938, 20.956405587494373, 28.53182729333639, 48.125652596354485, 57.91942946612835, 62.79818147420883, 9.104292467236519, 0.35804193292278796, 0.089128529507434, 0.08568928358727135, 0.06666547822533175, 0.11612816626438871, 0.07524556625867262, 0.0583821527834516, 0.0054544509930565255, 0.17261492583202198, 0.14467380795395002, 0.17399022937752306, 0.17415951326256618, 0.16358420572942123, 0.10890715842833742, 0.14229164749849588, 0.3300994198070839, 0.1433097998960875, 39.825780764222145, 84.29612070322037, 61.37541621923447, 54.57906670868397, 25.40263630449772, 33.93694795668125, 50.74199840426445, 71.18753090500832, 77.90114745497704, 75.90578332543373, 4.697741596028209, 0.4470569657860324, 0.5354775977320969, 3.447342454455793, 2.636305899359286, 26.93950943648815, 67.4594597518444, 63.43066893517971, 75.00084668397903, 72.7138178050518, 74.51770260930061, 59.90026697516441, 53.3448701351881, 65.51696598529816, 72.94331029057503, 70.30891925096512, 69.70405250787735, 71.01014122366905, 71.37809067964554, 69.11241665482521, 64.10710483789444, 61.22955344617367, 63.99535283446312, 63.26495222747326, 65.75604155659676, 57.527780681848526, 56.03185035288334, 53.005483746528625, 51.10379599034786, 49.32416528463364, 49.92595799267292, 50.18619082868099, 47.31644041836262, 49.577535688877106, 49.68817055225372, 49.44592595100403, 48.7275554984808, 50.56409575045109, 48.23007479310036, 49.03877779841423, 49.51368771493435, 47.86906756460667, 49.31019723415375, 49.42858748137951, 47.6438270509243, 48.21872100234032, 46.63863658905029, 45.9252704679966, 45.113292038440704, 46.21932528913021, 47.575502917170525, 45.734676495194435, 46.53208650648594, 46.146217212080956, 45.05736283957958, 47.363284304738045, 50.84537945687771, 48.117927610874176, 47.199866473674774, 49.80183385312557, 47.22721740603447, 50.705231577157974, 49.24485594034195, 49.923894703388214, 51.960072442889214, 53.58254738152027, 58.03903564810753, 60.23422725498676, 58.86730760335922, 50.49354113638401, 62.20757536590099, 58.65396045148373, 50.987423434853554, 54.4362323731184, 54.69265781342983, 51.70459695160389, 50.21688558161259, 45.87075479328632, 48.55852536857128, 50.02574823796749, 48.63206282258034, 48.464989587664604, 44.45971570909023, 45.49095757305622, 45.88689632713795, 50.56380696594715, 44.49878141283989, 44.99405823647976, 45.25041148066521, 45.133324563503265, 46.08823612332344, 43.402490839362144, 46.117566749453545, 45.6618420034647, 46.05786435306072, 47.04535536468029, 46.862064599990845, 47.720894515514374, 46.85780122876167, 46.91161394119263, 48.27259451150894, 49.549660384655, 51.09701715409756, 48.80888253450394, 51.071908101439476, 50.2363595366478, 47.5298597663641, 47.91487030684948, 48.91942240297794, 50.763269662857056, 51.283020973205566, 59.826471135020256, 59.82964016497135, 61.70556150376797, 64.55579236149788, 60.55121764540672, 64.777130484581, 61.422484293580055, 64.73463356494904, 60.915063321590424, 63.085434660315514, 64.36434343457222, 68.4091579914093, 63.24572145938873, 66.75510674715042, 69.28786844015121, 70.00787660479546, 69.31453540921211, 69.91456881165504, 67.5126264989376, 75.02986952662468, 69.57547500729561, 80.99712252616882, 11.044822689145803, 4.717195127159357, 6.551011400297284, 0.24348619946977124, 0.38221590919420123, 32.30999305844307, 83.55660438537598, 67.37185165286064, 75.5319593846798, 42.7338445186615, 23.639092035591602, 36.21383138000965, 59.707917496562004, 66.95675432682037, 75.40394425392151, 13.096495997160673, 0.47519792919047177, 0.21417365205707029, 0.17796733940485865, 0.2027637549326755, 0.29819449118804187, 0.15573881421005353, 0.1866066359798424, 0.20178236853098497], [0.06610895652556792, 0.0357893332693493, 0.07131935271900147, 0.026071825996041298, 0.05851156478456687, 0.11088255516369827, 0.0861845632607583, 0.051706471349461935, 0.3195790312020108, 38.320879116654396, 64.32885333895683, 50.018547624349594, 35.513034984469414, 24.58363965153694, 36.69496536254883, 42.34927475452423, 61.821580678224564, 70.4780937731266, 46.08404494822025, 0.17709503386868164, 0.046234946785261855, 0.036031718700542115, 0.6357558793388307, 4.522239463403821, 49.00695450603962, 72.64026895165443, 68.99915993213654, 69.11587446928024, 71.8605887889862, 67.38471776247025, 62.998362332582474, 51.535266637802124, 49.75661627948284, 52.65241429209709, 57.01752886176109, 59.04965601861477, 58.50153923034668, 58.34187559783459, 57.764181196689606, 60.998252257704735, 61.39284208416939, 57.71604537963867, 57.12766595184803, 58.482593446969986, 55.43322667479515, 48.98164786398411, 46.17006093263626, 45.49306645989418, 43.202089592814445, 45.80789856612682, 46.236872747540474, 43.58900763094425, 44.08605515956879, 46.03378124535084, 44.67291846871376, 42.989939376711845, 45.052366107702255, 41.99017882347107, 44.238039404153824, 41.772803887724876, 44.18850526213646, 43.46606142818928, 43.875652849674225, 43.38259890675545, 43.39054808020592, 43.42702992260456, 42.37592652440071, 43.30900065600872, 41.924548745155334, 41.95514850318432, 41.62606716156006, 40.46546123921871, 39.185515120625496, 41.46258473396301, 42.05508694052696, 40.560657531023026, 42.37349845468998, 43.286030888557434, 41.90552316606045, 44.128491282463074, 42.792752757668495, 44.11866880953312, 45.650606006383896, 47.61871799826622, 54.67234030365944, 54.389149099588394, 56.324552446603775, 52.55904570221901, 40.93887783586979, 56.12032100558281, 54.78761851787567, 48.042585253715515, 43.15940648317337, 43.75031277537346, 41.313317343592644, 42.65108495950699, 42.697628661990166, 41.20528534054756, 42.228350043296814, 43.209814578294754, 41.89815156161785, 42.64081031084061, 42.35226899385452, 41.53027430176735, 40.76366923749447, 39.895985797047615, 39.19243834912777, 40.3435979783535, 42.15015023946762, 40.56991383433342, 41.11083000898361, 41.1389485001564, 40.347074791789055, 42.92145565152168, 44.748272225260735, 46.09252609312534, 45.009842589497566, 44.91293638944626, 42.535050585865974, 42.61685259640217, 43.913829401135445, 45.82366771996021, 45.59668309986591, 45.05850277841091, 44.038968086242676, 45.031452029943466, 43.71572703123093, 46.46035775542259, 45.635042041540146, 46.6393281519413, 50.116502568125725, 56.39101468026638, 52.511088475584984, 54.70546692609787, 53.965004459023476, 57.79720142483711, 57.66023397445679, 57.369781360030174, 58.15930299460888, 59.896273389458656, 57.306043580174446, 61.684943810105324, 60.85795618593693, 61.36006124317646, 61.78389050066471, 65.24678528308868, 50.782907009124756, 66.57973855733871, 66.33848950266838, 68.99797439575195, 63.247644156217575, 79.96590346097946, 25.508074946701527, 1.815443190280348, 8.790774140506983, 0.09102190408157185, 0.03667963217594661, 10.762503538280725, 69.2138560116291, 57.77906119823456, 54.31808531284332, 58.48388157784939, 21.84593215584755, 15.1184406504035, 42.78956472873688, 40.580971240997314, 59.79219697415829, 13.94397972151637, 0.35366815980523825, 0.0872218185395468, 0.05857536722032819, 0.031692644697614014, 0.04089182119059842, 0.06777245827834122, 0.03139937391097192, 0.06563761111465283, 0.031490097753703594, 0.09956219815649092, 0.05447224793897476, 0.07644524797797203, 0.05060760297055822, 0.018802723279804923, 0.041087165591306984, 0.16030731203500181, 0.5308828130364418, 49.58933025598526, 74.06358137726784, 59.83616441488266, 41.504219099879265, 32.30109013617039, 34.657548889517784, 43.73505279421806, 70.51160797476768, 75.6214065849781, 50.974595323204994, 0.21163739205803722, 0.08384846049011685, 0.410873080836609, 0.5223276908509433, 5.736509906128049, 52.2283798456192, 72.53052324056625, 71.3001036643982, 71.29428997635841, 73.09065878391266, 70.08853107690811, 65.542903393507, 53.26575458049774, 52.689298912882805, 55.25281995534897, 60.58255076408386, 63.292637541890144, 62.25961357355118, 60.60610570013523, 61.91871486604214, 62.55663603544235, 64.5589005947113, 60.41398420929909, 59.3438134342432, 60.64044825732708, 55.12521140277386, 50.88208928704262, 49.296688959002495, 47.530885711312294, 46.45064927637577, 46.249598264694214, 46.86825446784496, 45.26924706995487, 46.78095415234566, 47.585948556661606, 47.757186368107796, 45.88692672550678, 47.57024399936199, 44.065429866313934, 47.09800913929939, 43.89931797981262, 46.68131209909916, 46.120131611824036, 45.54649539291859, 46.140513718128204, 45.91187998652458, 45.51045432686806, 45.86203046143055, 46.111977249383926, 45.73726415634155, 46.91855996847153, 44.309581965208054, 41.49378105998039, 42.939003109931946, 44.37438748776913, 44.57233026623726, 43.3914752304554, 44.3526678532362, 46.60114400088787, 44.03664641082287, 46.20970040559769, 45.51271140575409, 46.492105051875114, 46.24485991895199, 50.26140779256821, 56.65667362511158, 56.11912027001381, 59.93928328156471, 55.7539826631546, 42.41037927567959, 57.568066120147705, 56.774687692523, 49.27358999848366, 45.70211224257946, 44.016233906149864, 46.31833657622337, 45.41932761669159, 43.84430833160877, 45.47848664224148, 43.32936756312847, 44.17542636394501, 44.74938176572323, 45.23502230644226, 44.19778436422348, 43.76213014125824, 42.70167924463749, 41.21693551540375, 42.17771776020527, 42.35564701259136, 43.01892042160034, 42.66056165099144, 43.92349608242512, 44.018498584628105, 42.77049735188484, 44.27155360579491, 47.55671292543411, 48.074108362197876, 46.77762173116207, 46.23843066394329, 44.262274503707886, 44.18815568089485, 44.024870842695236, 47.21540004014969, 47.156237214803696, 47.04837240278721, 45.01228965818882, 47.34302759170532, 45.76152965426445, 47.328170388937, 46.7530370503664, 48.645232915878296, 52.18983091413975, 57.510962784290314, 54.92657706141472, 59.022194892168045, 57.33375929296017, 59.75166454911232, 59.95909161865711, 58.88039410114288, 60.327740237116814, 63.145281448960304, 58.35469231009483, 64.05898422002792, 62.14651644229889, 62.80125550925732, 62.851496413350105, 65.78868940472603, 49.5143336802721, 68.16269561648369, 68.48817855119705, 70.58361411094666, 65.84485799074173, 82.35299617052078, 27.877679094672203, 1.358446937520057, 6.353767784312367, 0.20883257850073278, 0.09795432037208229, 10.553172770887613, 77.3154316842556, 63.328739404678345, 62.26235702633858, 49.0909717977047, 23.319272696971893, 22.702212408185005, 50.279354229569435, 48.20474535226822, 68.57770934700966, 19.131828993558884, 0.3443326544947922, 0.09663234013714828, 0.024719232169445604, 0.1070460450137034, 0.049110494437627494, 0.028623750877159182, 0.05073864769656211, 0.010481245881237555, 0.16239196032984182, 0.13942073826910928, 0.18399758613668382, 0.13826891023200005, 0.15224926552036777, 0.18754711520159617, 0.12956190010299906, 0.16853283159434795, 1.101671322248876, 64.18736413121223, 83.7729723751545, 68.28729093074799, 50.68830728530884, 36.17383852601051, 45.50944738090038, 60.838497430086136, 76.0760597884655, 80.35461500287056, 57.069050297141075, 0.4711857601068914, 0.3132994525367394, 1.0128323268145323, 3.339072489179671, 6.537496475502849, 55.151680782437325, 73.49040493369102, 74.26978871226311, 73.70316311717033, 77.30277076363564, 72.5519996881485, 69.76670354604721, 56.40694722533226, 56.20873086154461, 57.471938878297806, 62.00315773487091, 64.68859523534775, 64.67085778713226, 63.969058245420456, 63.863591104745865, 66.43439635634422, 68.16214084625244, 64.61619392037392, 62.608355060219765, 64.75658118724823, 59.880648627877235, 55.50753928720951, 51.865651309490204, 49.76054146885872, 47.555721178650856, 48.35164546966553, 49.08044256269932, 48.60952243208885, 49.09635990858078, 50.96573419868946, 49.8021986335516, 49.08233866095543, 49.19032506644726, 45.30748061835766, 50.387865006923676, 44.61197353899479, 48.66258658468723, 49.029624089598656, 48.286277577281, 48.28152783215046, 49.102264791727066, 47.53574185073376, 47.2568292170763, 50.0627164542675, 47.852002680301666, 49.123479053378105, 46.09470337629318, 45.004937052726746, 45.334018394351006, 46.85214713215828, 47.01374866068363, 46.49528548121452, 46.41887538135052, 49.05222527682781, 46.0077640414238, 49.116567224264145, 47.2497083991766, 49.78583671152592, 49.22227755188942, 51.93440102040768, 60.38591131567955, 59.60033766925335, 61.2257194519043, 57.69409395754337, 46.76242634654045, 59.82378087937832, 60.60507595539093, 51.76183708012104, 47.728570103645325, 47.3110219091177, 46.4192021638155, 46.5891632437706, 46.02514050900936, 47.527876272797585, 46.400822550058365, 48.989224657416344, 47.127879336476326, 47.017499059438705, 45.8039353787899, 47.83878318965435, 47.57210209965706, 43.594874516129494, 44.28897187113762, 45.60256138443947, 46.891855001449585, 44.916071221232414, 46.35441944003105, 46.37749180197716, 44.39769543707371, 46.7279089987278, 49.51805368065834, 51.05262413620949, 48.57153207063675, 49.85356047749519, 46.69570952653885, 47.67174035310745, 48.097123727202415, 50.12952446937561, 48.51783335208893, 48.7351056933403, 48.72411288321018, 50.774125680327415, 47.339763566851616, 50.61142221093178, 48.28564681112766, 50.44171191751957, 53.88907693326473, 62.67996221780777, 58.37089464068413, 62.106534987688065, 59.35010589659214, 63.78422096371651, 63.660119622945786, 61.746147125959396, 63.43268662691116, 65.33472016453743, 60.86270593106747, 67.4200938642025, 64.54621687531471, 63.43359097838402, 64.27140802145004, 68.77187892794609, 54.536326602101326, 72.79599219560623, 69.67520445585251, 73.95119860768318, 67.90895283222198, 86.63093581795692, 30.48847910016775, 4.038433274254203, 16.232884749770164, 0.6854114367160946, 0.19898012280464172, 13.940755594521761, 84.0834005177021, 69.50166016817093, 70.96234738826752, 71.23087137937546, 32.780681401491165, 26.677538193762302, 61.01053699851036, 57.0517498254776, 78.03990080952644, 27.211120761930943, 0.6572884332854301, 0.268234345712699, 0.13017086195759475, 0.14076822611968964, 0.11200407388969325, 0.1566325974999927, 0.21448547282489017, 0.14835456357104704], [0.03147549228742719, 0.036044891821802594, 0.04623169617843814, 0.07031124900095165, 0.07652993444935419, 0.007416810976792476, 0.04125355881114956, 0.08634693032945506, 1.9091179012320936, 53.49036432802677, 56.77732095122337, 44.92650926113129, 26.358279325067997, 29.383749179542065, 40.51676608622074, 49.15388502180576, 60.99059946835041, 71.64032980799675, 26.149628721177578, 0.10761715733679011, 0.08239019225584343, 0.20440134831005707, 0.9018228866625577, 24.494906812906265, 75.4741644859314, 69.08448055386543, 71.38331919908524, 70.30192762613297, 67.78063371777534, 66.02262005209923, 58.21374647319317, 50.92168316245079, 53.660283610224724, 47.767039239406586, 49.017240554094315, 45.972543731331825, 49.19915199279785, 47.55540959537029, 49.20154206454754, 49.407764598727226, 52.41439886391163, 54.10083197057247, 55.13162545859814, 51.68984234333038, 50.30300036072731, 47.631352320313454, 45.22576600313187, 44.75461408495903, 47.860860005021095, 42.68825076520443, 44.60472732782364, 45.1496446877718, 46.03467419743538, 45.69204278290272, 43.69835816323757, 45.06606437265873, 45.336522459983826, 42.81054340302944, 43.29831562936306, 43.688414096832275, 43.10730367898941, 44.13504213094711, 44.72747214138508, 44.2745516449213, 43.09295564889908, 42.63014808297157, 40.91337360441685, 42.52898991107941, 42.969067096710205, 41.264303773641586, 40.274133905768394, 40.17789267003536, 40.97324699163437, 40.893546268343925, 41.79420813918114, 41.36088699102402, 43.44354383647442, 44.20451760292053, 43.27299378812313, 44.80452820658684, 44.51497994363308, 44.31164525449276, 45.04450432956219, 45.70880368351936, 53.41948673129082, 55.03523223102093, 58.14090438187122, 49.12800461053848, 35.59121958911419, 53.842335641384125, 52.95286037027836, 50.94043515622616, 45.848932564258575, 46.26877963542938, 44.20638330280781, 43.89996014535427, 44.16296303272247, 41.41188025474548, 41.68164677917957, 42.06812784075737, 41.794550120830536, 39.875748082995415, 40.01152239739895, 41.011385545134544, 39.7530260682106, 40.80130621790886, 40.226233676075935, 39.406093284487724, 40.82763880491257, 40.05545563995838, 41.92095793783665, 42.457196563482285, 41.32791616022587, 42.806454822421074, 43.63134875893593, 42.406518682837486, 44.44102071225643, 42.84070998430252, 42.4092735350132, 42.53511518239975, 42.126040533185005, 42.8967759758234, 45.08198171854019, 43.42951878905296, 42.79955819249153, 42.75500178337097, 43.967262133955956, 45.8295726031065, 43.699562698602676, 44.99413803219795, 47.438736855983734, 54.085537791252136, 54.93594355881214, 54.71618615090847, 53.84266622364521, 60.694819539785385, 59.70094867050648, 59.28024284541607, 58.36588650941849, 59.694747403264046, 56.170843094587326, 62.298987060785294, 59.26293097436428, 59.7489894926548, 54.73040498793125, 59.759473130106926, 52.26110368967056, 62.67564944922924, 65.96981048583984, 67.71552041172981, 61.36644870042801, 73.9329443871975, 48.17783519625664, 0.24348124192329124, 4.337545624002814, 0.11382612065062858, 0.21862325782421976, 3.945635366253555, 55.460995584726334, 65.7427042722702, 53.835328817367554, 60.180015563964844, 31.847126595675945, 13.27619880437851, 35.49902893602848, 46.34737081825733, 59.186916053295135, 29.03361886739731, 0.8612659410573542, 0.04074775548360776, 0.04744440630020108, 0.01385611512887408, 0.015960787495714612, 0.06473380883107893, 0.03968944547523279, 0.014660528067906853, 0.036836362633039244, 0.017196235166920815, 0.040368232293985784, 0.053723057280876674, 0.03812576629570685, 0.07334915630053729, 0.03248473891289905, 0.09965111486962996, 2.5041779642924666, 65.31326651573181, 64.99661430716515, 52.42870509624481, 36.92213997244835, 38.712292313575745, 34.14932616055012, 51.42641007900238, 67.58688971400261, 77.7027752995491, 31.72320194542408, 0.09797727499972098, 0.17806641611969098, 0.47990979510359466, 1.7100334027782083, 26.35101031512022, 76.86007931828499, 71.08849301934242, 72.97420263290405, 71.09784051775932, 72.2803370654583, 69.0220195055008, 62.687634006142616, 52.47135400772095, 54.49593856930733, 50.00201091170311, 51.697981506586075, 48.49974252283573, 51.84961996972561, 49.507098868489265, 49.84831675887108, 52.061071023344994, 56.2159238755703, 54.47060152888298, 55.67370817065239, 53.05406413972378, 53.02075892686844, 48.92450653016567, 46.360613107681274, 45.75534738600254, 49.23136666417122, 46.70444905757904, 46.82750545442104, 46.47798880934715, 47.510545402765274, 46.49464711546898, 45.26016555726528, 46.06370083987713, 46.25641129910946, 45.58794356882572, 45.488286316394806, 45.45109011232853, 45.73623441159725, 45.34072123467922, 46.491060107946396, 45.888644233345985, 45.156419724226, 45.166329592466354, 44.40810687839985, 43.77834387123585, 44.487594813108444, 42.808214128017426, 42.60226517915726, 42.616548612713814, 43.8895221054554, 43.620181158185005, 43.34533430635929, 43.135931342840195, 44.54584188759327, 47.490490078926086, 45.028723776340485, 47.88526989519596, 46.93079151213169, 45.61680682003498, 48.82560543715954, 47.15196244418621, 56.52890928089619, 57.677853628993034, 58.967177644371986, 52.64508068561554, 36.64103485643864, 55.96403159201145, 56.15588329732418, 53.33258919417858, 48.54605823755264, 48.219157978892326, 45.83501771092415, 46.23764030635357, 44.65767748653889, 42.70024672150612, 44.544173777103424, 44.58163596689701, 43.06650526821613, 42.098423615098, 43.25288146734238, 42.964564338326454, 41.85232222080231, 42.341055795550346, 42.08153732120991, 41.222825199365616, 44.915265664458275, 41.974250078201294, 44.237731620669365, 43.555653020739555, 42.77392476797104, 44.777333065867424, 45.85169121623039, 44.937604665756226, 45.400913804769516, 45.432315319776535, 43.784807324409485, 45.53180918097496, 44.33735087513924, 44.912564009428024, 46.82467080652714, 44.74057003855705, 45.896532610058784, 45.13237841427326, 45.483817756175995, 47.60342761874199, 47.11967557668686, 45.719222724437714, 48.8882564753294, 55.539168789982796, 56.983342096209526, 57.690012976527214, 57.26913996040821, 62.3052529245615, 61.05855122208595, 62.585579082369804, 59.32692714035511, 62.130956277251244, 61.80533654987812, 64.49251055717468, 62.05377861857414, 60.26730827987194, 54.444656521081924, 60.4571308940649, 56.9769736379385, 65.87540075182915, 67.68629997968674, 70.64475283026695, 63.65340918302536, 76.00593835115433, 52.74287983775139, 0.6805797584820539, 2.162078758701682, 0.524571054847911, 0.22660830669337884, 4.252234501764178, 62.16790929436684, 71.07636407017708, 60.94155550003052, 59.716269448399544, 35.03548040986061, 25.306117683649063, 46.23396210372448, 54.887822940945625, 67.90092766284943, 37.45764143764973, 1.1368151614442468, 0.048203831174760126, 0.038829600598546676, 0.010430699130665744, 0.040371709255850874, 0.024980536800285336, 0.015228975153149804, 0.06831472332123667, 0.21685961808543652, 0.1397866170736961, 0.1635493544745259, 0.1359859897638671, 0.22161861037602648, 0.17192251689266413, 0.16929806006373838, 0.3014724387321621, 3.837950569577515, 78.5126106441021, 72.0092748105526, 62.38175041973591, 41.457888185977936, 37.71628215909004, 52.64780513942242, 68.33025142550468, 71.2182104587555, 86.1582563817501, 33.87810431420803, 0.13510676741134375, 0.3798877028748393, 1.3644896820187569, 2.004096773453057, 27.532074339687824, 80.5336993932724, 73.88431459665298, 75.56764706969261, 75.54692298173904, 74.14001807570457, 73.7437753379345, 63.733197301626205, 56.42246939241886, 58.79229582846165, 53.375355899333954, 54.675767719745636, 51.38523168861866, 54.999540746212006, 53.70655372738838, 52.101614847779274, 56.72168433666229, 56.57906658947468, 56.8623261898756, 60.032507479190826, 57.63454735279083, 54.59232419729233, 52.00095824897289, 48.92246603965759, 49.13360930979252, 50.93896463513374, 47.043660655617714, 50.377882942557335, 49.87227067351341, 51.58494897186756, 48.91854465007782, 47.31037214398384, 49.6483638882637, 48.43852020800114, 48.24320688843727, 49.778434708714485, 50.21070331335068, 47.96077944338322, 48.69048468768597, 49.4784028083086, 49.41587716341019, 47.22051076591015, 47.57621727883816, 47.49843165278435, 46.91591531038284, 48.1968379765749, 45.72736568748951, 45.52822597324848, 44.863770827651024, 46.17717795073986, 45.14331042766571, 48.12112703919411, 46.36833429336548, 48.76908726990223, 50.812002047896385, 48.179282918572426, 50.524011701345444, 47.99751967191696, 49.05386298894882, 50.62412112951279, 50.5340051651001, 58.03462028503418, 60.407817140221596, 62.96094574034214, 55.74911132454872, 41.163122802972794, 57.557989060878754, 58.113173469901085, 55.24460479617119, 52.60500803589821, 51.150343492627144, 48.85836347937584, 47.06902049481869, 48.44267338514328, 46.95295952260494, 45.96631206572056, 47.88963586091995, 45.43719805777073, 45.0603798776865, 45.49680545926094, 46.24125771224499, 43.63385282456875, 46.192916706204414, 45.20314201712608, 43.114561289548874, 45.763805732131004, 44.645396545529366, 46.99929043650627, 47.72256642580032, 45.09666793048382, 46.81321822106838, 47.22976706922054, 46.583372354507446, 49.10877764225006, 47.356243282556534, 47.34847649931908, 48.8736766576767, 47.23097540438175, 49.22046884894371, 51.66212663054466, 47.840888276696205, 46.81839354336262, 47.36216716468334, 47.991117015480995, 51.06542564928532, 49.8727760463953, 48.104480132460594, 52.22313992679119, 59.341286569833755, 61.62896901369095, 61.597863882780075, 59.07797209918499, 63.96093428134918, 64.44872930645943, 65.49756422638893, 62.54107587039471, 65.05455359816551, 62.22277075052261, 66.44559055566788, 63.974347561597824, 60.266985297203064, 55.23953966796398, 62.630925849080086, 57.75026634335518, 68.88338774442673, 70.78650042414665, 73.853460252285, 66.5319675207138, 77.62929484248161, 55.514025539159775, 0.5266457435209304, 8.878115303814411, 1.2476453580893576, 0.40274255617987365, 5.776110431179404, 69.37770321965218, 76.14659920334816, 69.34165075421333, 76.19028925895691, 41.787585094571114, 24.051747992634773, 53.573177084326744, 65.24841919541359, 77.29775503277779, 48.11310566961765, 1.9262773054651916, 0.11505296497489326, 0.10676290083210915, 0.11580732840229757, 0.14863322518067434, 0.11662987293675542, 0.1424152299296111, 0.12329588789725676], [0.08901279157726094, 0.0438736369687831, 0.009292008962802356, 0.023793414075043984, 0.022027766826795414, 0.03719675325555727, 0.028914284994243644, 0.12643049703910947, 5.931310728192329, 64.68914240598679, 57.9654335975647, 39.0092995762825, 15.63600992783904, 14.800630453974009, 34.54459235072136, 51.57507710158825, 64.48054879903793, 68.15926820039749, 12.236580289900303, 0.327548123896122, 0.09921208256855607, 0.28655256901402026, 18.809942565858364, 61.424129605293274, 72.88018047809601, 66.43419116735458, 68.43151599168777, 63.55293117463589, 66.47738724946976, 61.124291494488716, 52.63804346323013, 49.50681008398533, 48.507900685071945, 46.941556334495544, 46.89448066055775, 46.31230629980564, 45.22338353097439, 44.632617831230164, 45.33103175461292, 45.69037087261677, 45.28295673429966, 43.79933774471283, 46.362577602267265, 44.92288425564766, 45.84435760974884, 43.59443373978138, 43.884468376636505, 43.60051341354847, 45.6421210616827, 44.53019432723522, 42.59794861078262, 42.308502942323685, 43.24498549103737, 43.31767939031124, 44.61105398833752, 43.34517851471901, 44.264314994215965, 42.260773703455925, 41.06602281332016, 43.55985939502716, 44.112919718027115, 42.41151161491871, 45.28030447661877, 46.247094199061394, 43.48491221666336, 42.25033186376095, 42.40229710936546, 41.5947150439024, 41.054828613996506, 41.014961153268814, 41.623688489198685, 40.05650818347931, 38.548334911465645, 42.55594566464424, 41.571251302957535, 41.37335792183876, 43.08293558657169, 40.78837551176548, 42.57856585085392, 47.628779858350754, 49.503014087677, 47.15612322092056, 47.09985204041004, 47.165694907307625, 51.83285526931286, 55.78931696712971, 53.759431689977646, 50.54495997726917, 35.159422159194946, 49.267438128590584, 57.13508315384388, 51.78901322185993, 53.89739848673344, 48.59422445297241, 48.67514111101627, 48.60198363661766, 46.11381255090237, 42.40573592483997, 41.62368468940258, 40.12498050928116, 40.881789699196815, 40.788215920329094, 41.51070915162563, 41.025380194187164, 39.57344390451908, 38.953925147652626, 41.12627997994423, 41.490026861429214, 40.92784322798252, 40.02838969230652, 43.78818914294243, 41.23214989900589, 42.84933552145958, 41.04629047214985, 42.33808055520058, 43.339068442583084, 43.367487117648125, 41.4738929271698, 42.81511835753918, 41.03126987814903, 42.151586562395096, 43.58288235962391, 45.31562738120556, 44.235322549939156, 45.203400403261185, 42.44819484651089, 45.07095091044903, 42.941944152116776, 44.14098121225834, 44.31746654212475, 50.426007360219955, 56.658451929688454, 58.68745185434818, 60.07691189646721, 56.81749999523163, 59.07665736973286, 58.405655175447464, 57.75344677269459, 59.36461351811886, 61.47861868143082, 61.23376362025738, 59.12902615964413, 62.68273986876011, 60.989660918712616, 64.3273714184761, 64.38320562243462, 66.18979588150978, 66.51048347353935, 66.38046205043793, 60.94730079174042, 67.79650166630745, 66.16334930062294, 74.00203227996826, 4.160440927371383, 1.558405151590705, 0.21490095678018406, 0.10439823279739358, 1.1782775865867734, 44.323793202638626, 66.09267309308052, 56.150571182370186, 53.7966962903738, 27.74618335068226, 9.940747283399105, 22.1124479547143, 40.80326311290264, 49.05836194753647, 49.06600333750248, 3.14758675172925, 0.09138283276115544, 0.0698878314869944, 0.0898966820386704, 0.07872830203268677, 0.12171658279839903, 0.032251916054519825, 0.10034056263975799, 0.042064440494868904, 0.03590699707274325, 0.06910104362759739, 0.0433462556975428, 0.041324381963931955, 0.04200697600026615, 0.053454032458830625, 0.09596293035428971, 7.6909293327480555, 76.1451704800129, 63.860794454813, 48.5196952521801, 19.83182553201914, 22.98577219247818, 34.59611378610134, 56.24783456325531, 71.34815588593483, 74.27623316645622, 14.972252044826746, 0.5061950627714396, 0.03083979827351868, 0.3209523012628779, 22.60349940508604, 63.28395500779152, 74.59477007389069, 70.08340135216713, 72.12544977664948, 67.79044479131699, 69.40835997462273, 62.457981929183006, 56.909303069114685, 51.66881047189236, 50.877164751291275, 49.88845020532608, 48.372506350278854, 47.237533852458, 47.32204131782055, 47.706318497657776, 48.34783427417278, 44.65184099972248, 48.99897113442421, 46.26572459936142, 48.44733573496342, 48.968515768647194, 48.45835894346237, 44.916500598192215, 46.068173199892044, 45.39930649101734, 47.45871238410473, 46.23553141951561, 46.06419861316681, 43.45941938459873, 44.40802328288555, 45.00522203743458, 45.3416445851326, 45.73242701590061, 46.47632069885731, 43.883431032299995, 43.239931762218475, 45.47423467040062, 46.229782328009605, 45.09857542812824, 46.54452703893185, 47.687862887978554, 44.77773204445839, 46.16033345460892, 44.30265873670578, 42.458355501294136, 44.51932691037655, 43.12333881855011, 44.24125023186207, 43.4896619617939, 42.275805696845055, 43.70598055422306, 42.94035203754902, 43.75569708645344, 44.42802540957928, 42.41311512887478, 45.19325114786625, 49.82219696044922, 52.75878958404064, 50.6450580060482, 49.105882197618484, 48.8533591479063, 54.70170132815838, 57.54424899816513, 56.35272413492203, 55.6391604244709, 37.556306943297386, 50.373277589678764, 57.92057320475578, 55.51648400723934, 53.847970739006996, 48.84008266031742, 50.402802005410194, 52.19440586864948, 48.000008538365364, 44.181445240974426, 42.257429882884026, 41.03559024631977, 43.5466855019331, 43.510959818959236, 42.93470174074173, 42.95844666659832, 42.25933738052845, 43.99299815297127, 43.09463515877724, 43.03270988166332, 44.068055525422096, 41.86982408165932, 46.099593713879585, 42.923009768128395, 44.769786670804024, 43.41605991125107, 45.527526810765266, 44.5062518119812, 44.79216746985912, 44.090272933244705, 44.55937296152115, 43.764235228300095, 45.60868285596371, 45.19661396741867, 48.0977088958025, 44.636273235082626, 46.376367062330246, 45.470982044935226, 46.05182267725468, 45.524456575512886, 46.08771935105324, 46.28562793135643, 53.38036023080349, 59.45690296590328, 60.36846645176411, 60.54357245564461, 59.90756258368492, 60.2084456384182, 62.21490517258644, 60.3002905100584, 61.59026809036732, 65.07051274180412, 63.76062422990799, 61.61785461008549, 63.17427009344101, 62.98882484436035, 66.1907610297203, 65.13718396425247, 68.72777849435806, 69.80245962738991, 69.22947317361832, 63.360304310917854, 70.43628081679344, 67.36292973160744, 77.77425706386566, 5.039645824581385, 1.4565682411193848, 0.6870864343363792, 0.12832457665354013, 1.382865495979786, 48.964058607816696, 74.02966439723969, 64.13445577025414, 57.50452592968941, 27.85519950091839, 14.43555649369955, 29.238186590373516, 48.968850150704384, 55.76142266392708, 59.600668251514435, 4.823222262784839, 0.2073758316691965, 0.08986052460386418, 0.027420811129559297, 0.07609588195919059, 0.034277192535228096, 0.015089641565282363, 0.06866603376693092, 0.16997388942399994, 0.13430976017843932, 0.24041603843215853, 0.21957623481284827, 0.15171957988059148, 0.24851325550116599, 0.23500355542637408, 0.19224183750338852, 11.405019611120224, 88.8800199329853, 74.01554435491562, 59.41211476922035, 28.647475987672806, 24.804170317947865, 49.23130586743355, 66.8662279844284, 74.97084349393845, 82.73195743560791, 16.39286756515503, 0.597866924945265, 0.17711861932184547, 1.7517157411202788, 23.828941248357296, 67.8376154601574, 77.27246358990669, 73.0136901140213, 76.5541273355484, 70.36716252565384, 73.4381577372551, 65.93292966485023, 59.50850419700146, 54.28837090730667, 53.70753027498722, 53.3133128285408, 50.92639870941639, 50.91648504137993, 49.9797935038805, 49.295944198966026, 50.58833844959736, 50.450660437345505, 51.30476340651512, 49.27806615829468, 51.00557126104832, 50.60531973838806, 52.04173386096954, 48.13815772533417, 48.67601126432419, 46.87596045434475, 50.4923328012228, 49.09857518970966, 47.83379405736923, 45.621647760272026, 46.23148463666439, 49.01589162647724, 49.388735219836235, 48.14122036099434, 47.16208890080452, 45.761765241622925, 44.34847667813301, 49.51645016670227, 46.93247862160206, 45.6914272159338, 50.23564137518406, 51.828170120716095, 46.97720602154732, 47.51546233892441, 45.08511655032635, 45.223337933421135, 46.91068299114704, 44.927254021167755, 46.54185578227043, 47.09105171263218, 42.53161557018757, 48.182189762592316, 46.1395675688982, 46.953981667757034, 48.569487780332565, 45.4617827385664, 48.73694859445095, 51.92109413444996, 55.21343506872654, 50.96190020442009, 49.87724460661411, 51.839968487620354, 58.908976167440414, 60.76558314263821, 58.532963544130325, 57.21165284514427, 42.93329581618309, 54.29898373782635, 61.15031249821186, 58.031040877103806, 58.74537594616413, 52.4539053440094, 52.88119621574879, 55.14382280409336, 51.699592620134354, 46.3617492467165, 45.35280838608742, 47.314285933971405, 44.92259167134762, 46.012692376971245, 45.049854442477226, 47.010416239500046, 44.45973850786686, 45.94917878508568, 47.93565519154072, 45.72969876229763, 45.88449485599995, 43.96277457475662, 48.099396005272865, 45.14726221561432, 46.58510126173496, 45.42189247906208, 46.399724408984184, 47.415782287716866, 47.21494026482105, 45.79199641942978, 46.679963171482086, 46.044986844062805, 48.94998796284199, 48.28551761806011, 49.90803435444832, 47.38541431725025, 49.21549491584301, 46.33558005094528, 48.87130178511143, 46.93782493472099, 48.514785915613174, 47.9339224845171, 55.46477638185024, 62.923297360539436, 62.707423344254494, 64.85376477241516, 63.52581962943077, 63.41789782047272, 64.53799411654472, 63.98947075009346, 62.74565689265728, 65.63176542520523, 64.86182793974876, 63.225031569600105, 65.48489570617676, 64.81196701526642, 67.8565688431263, 68.16603943705559, 69.08318862318993, 71.61305487155914, 74.70192432403564, 67.24981740117073, 74.4556975364685, 71.83995589613914, 82.02965632081032, 5.579230645671487, 6.605424480512738, 2.553641335107386, 0.2654063474619761, 1.8701490922831, 54.08991135656834, 80.1354655623436, 67.91503250598907, 71.35805055499077, 34.690280333161354, 16.08870528638363, 35.2686282992363, 58.67516331374645, 65.35697937011719, 72.45019555091858, 6.616208301857114, 0.34523498732596636, 0.19459750328678638, 0.18397570762317628, 0.19038737373193726, 0.2358738423208706, 0.08195385395083576, 0.13339439523406327], [0.0183278433905798, 0.07572671544039622, 0.02804081614158349, 0.047767544820089824, 0.04304915913962759, 0.04609961615642533, 0.070945295447018, 0.21747160790255293, 16.459320299327374, 72.47719690203667, 51.78063087165356, 38.87034483253956, 20.21417811512947, 25.78713957220316, 34.40197080373764, 52.72928036749363, 67.99860522150993, 66.7464280128479, 11.138630155473948, 0.3680924529908225, 0.5283168226014823, 1.2989283562637866, 17.537206560373306, 72.25217297673225, 69.35093745589256, 66.05579987168312, 60.650373324751854, 61.654374450445175, 58.617961183190346, 53.444044813513756, 53.15826214849949, 52.94420823454857, 52.82107204198837, 48.245714753866196, 48.04640404880047, 45.32163105905056, 46.53818517923355, 45.871537551283836, 44.45264048874378, 44.99831400811672, 45.395183712244034, 45.41038289666176, 43.43086011707783, 44.65319372713566, 43.55210781097412, 45.17814315855503, 45.17411917448044, 44.108348563313484, 43.007038459181786, 43.07191997766495, 42.9739536345005, 41.992432102561, 43.613140136003494, 44.55811142921448, 42.2450615465641, 45.145088732242584, 44.33403745293617, 41.820035353302956, 42.921147868037224, 42.093138098716736, 41.23195230960846, 43.04947078227997, 44.663437977433205, 43.78858432173729, 43.46869848668575, 42.62273848056793, 45.58277204632759, 45.009808391332626, 43.699175119400024, 41.61937192082405, 39.722202122211456, 40.36516562104225, 39.967665150761604, 39.85343188047409, 40.76795540750027, 39.76881422102451, 38.45897890627384, 41.514972522854805, 40.71809448301792, 46.53480336070061, 52.01866149902344, 53.18401716649532, 52.54109166562557, 52.63019308447838, 49.40140374004841, 54.33589495718479, 55.24327486753464, 58.56193698942661, 31.371137537062168, 38.5151968896389, 58.0240036547184, 54.14475381374359, 55.43716326355934, 51.11820861697197, 52.65474356710911, 50.41650027036667, 44.4131226092577, 39.566174894571304, 39.284249022603035, 40.18549606204033, 40.641847774386406, 39.40190590918064, 41.23131774365902, 40.36612316966057, 41.67535051703453, 39.89339433610439, 40.429644361138344, 40.9307386726141, 41.725758612155914, 39.7474479675293, 43.21596644818783, 42.15635150671005, 42.83936865627766, 42.48903125524521, 43.27025793492794, 42.52196408808231, 45.16269698739052, 42.992941215634346, 42.182547301054, 39.982020780444145, 41.6170996427536, 41.40597157180309, 45.35877786576748, 44.020668268203735, 45.941457599401474, 44.892379492521286, 43.358439803123474, 42.65148013830185, 43.52998919785023, 45.04841431975365, 55.72192758321762, 58.11916574835777, 58.723375126719475, 42.69530698657036, 50.330385491251945, 62.224666848778725, 60.295825749635696, 62.44893841445446, 61.32170230150223, 59.0225862711668, 59.81423199176788, 57.09984004497528, 59.835225865244865, 58.34195539355278, 61.75468906760216, 64.46025788784027, 66.55996441841125, 60.92064522206783, 62.65630468726158, 57.86339767277241, 65.32753854990005, 61.837710812687874, 80.12016758322716, 20.550463870167732, 1.1985386931337416, 0.3875270445132628, 0.036536802144837566, 0.14188529195962474, 28.86977545917034, 67.69817054271698, 57.031971886754036, 52.46124655008316, 56.01275257766247, 35.24574972689152, 19.300887621939182, 37.19843074679375, 49.1350494325161, 57.56116569042206, 9.965421259403229, 0.17627022578381002, 0.05334515568392817, 0.08337922277860343, 0.0634146190714091, 0.05253150207863655, 0.0374194606411038, 0.014379450767592061, 0.025213617554982193, 0.0480474087089533, 0.0521701652178308, 0.060526146917254664, 0.052121513726888224, 0.017398206946381833, 0.1372100436128676, 0.2626278653042391, 21.407129801809788, 83.91779780387878, 59.20771613717079, 45.81087000668049, 26.34081546217203, 29.24630295485258, 34.81563940644264, 60.427454486489296, 72.82347992062569, 72.19548761844635, 11.089346799999475, 0.31311928876675665, 0.4469903209246695, 0.8862273360136896, 19.4225836917758, 74.601731300354, 72.14976847171783, 68.53271216154099, 63.92734408378601, 63.50460536777973, 61.02342590689659, 57.30361171066761, 54.0187069773674, 53.97696241736412, 55.61770297586918, 51.841925382614136, 51.248872205615044, 48.849665746092796, 48.6135084182024, 47.93147921562195, 47.49474585056305, 48.22924643754959, 46.3180173933506, 46.66943393647671, 45.909695103764534, 46.06337785720825, 44.99530076980591, 47.40385852754116, 47.18471668660641, 45.58345600962639, 44.10709463059902, 46.90157487988472, 46.17414191365242, 45.486682802438736, 44.2561112344265, 46.55604802072048, 43.57833780348301, 46.906374022364616, 46.281429156661034, 43.85134555399418, 43.53186249732971, 44.1982327401638, 43.974550142884254, 46.482776552438736, 45.460072830319405, 46.069373935461044, 44.02349531650543, 44.71394866704941, 46.176528185606, 45.68727403879166, 45.161811634898186, 43.80264736711979, 41.34121924638748, 42.75035083293915, 41.697674319148064, 42.70925223827362, 42.533481270074844, 43.2916621863842, 42.55319461226463, 41.58966891467571, 42.73645877838135, 47.62477107346058, 53.282899260520935, 55.624200627207756, 54.987730979919434, 52.944694608449936, 51.54121331870556, 55.54484188556671, 56.90124370157719, 59.800890907645226, 34.49851602315903, 41.461007818579674, 60.38388982415199, 54.582315534353256, 58.39020140469074, 54.80940654873848, 55.34119941294193, 52.164607867598534, 46.96392573416233, 43.521462455391884, 43.777184933423996, 43.13013665378094, 42.68875613808632, 41.130642145872116, 44.124805480241776, 43.50673444569111, 45.20802855491638, 41.92089334130287, 42.36675761640072, 42.11363799870014, 44.44106251001358, 44.812165796756744, 44.841785207390785, 44.822714030742645, 43.72524552047253, 46.05711579322815, 44.94736634194851, 45.81795662641525, 47.19681143760681, 43.978889510035515, 42.51298896968365, 43.40369537472725, 43.140529096126556, 45.08463777601719, 46.7404293268919, 43.55974920094013, 48.25919263064861, 46.05409495532513, 46.449649930000305, 43.770672082901, 45.2660096436739, 47.039819061756134, 58.953961953520775, 60.80491863191128, 59.82626214623451, 45.68814419209957, 53.34835074841976, 65.46487838029861, 63.80960360169411, 64.18062329292297, 61.26293085515499, 61.470513716340065, 62.391428500413895, 60.666366666555405, 61.81891322135925, 60.56341879069805, 64.08666953444481, 64.57470014691353, 67.82451376318932, 62.574354484677315, 63.61063867807388, 58.983144387602806, 69.27346721291542, 63.71757633984089, 83.41370925307274, 23.81267622113228, 1.312329643405974, 1.757298472803086, 0.08282464550575241, 0.13450573169393465, 30.389479212462902, 74.07399281859398, 61.69842168688774, 62.41479344666004, 35.707633942365646, 26.756062880158424, 27.095964141190052, 45.89607663452625, 55.92748515307903, 65.30771881341934, 13.5769004188478, 0.2630756772123277, 0.09158945409581065, 0.03997103856818285, 0.11502425870276056, 0.02627990750625031, 0.06019267028023023, 0.022393144681700505, 0.14231290260795504, 0.13849474577000365, 0.19219462206820026, 0.17517569154733792, 0.17344157444313169, 0.1029160303005483, 0.17482453695265576, 0.3760750824585557, 30.104158222675323, 95.6967705488205, 65.13308018445969, 55.73315978050232, 32.90929690003395, 36.053985357284546, 49.14810933172703, 70.0849212706089, 78.5557459294796, 79.72067221999168, 13.767112512141466, 0.3562014957424253, 1.041676460299641, 3.443876327946782, 22.78275478631258, 76.11866310238838, 75.92551946640015, 70.58925300836563, 65.89874669909477, 67.74797067046165, 63.89128401875496, 59.68977726995945, 59.73377510905266, 57.92346864938736, 58.5933955013752, 53.20341132581234, 53.72690163552761, 51.09325535595417, 50.66343002021313, 52.116536647081375, 50.1567842066288, 51.119268760085106, 48.911002054810524, 50.881811901926994, 48.465023785829544, 48.94619196653366, 47.79962629079819, 50.825970098376274, 51.240881234407425, 47.50664681196213, 46.003698259592056, 49.55658741295338, 47.92115896940231, 48.808099776506424, 46.14312797784805, 49.6231522411108, 46.67562000453472, 48.724956437945366, 50.19281007349491, 47.20414124429226, 46.816512644290924, 47.9155732691288, 45.84548994898796, 47.61222414672375, 49.24492433667183, 49.1413988918066, 46.55533745884895, 46.92530080676079, 48.94411727786064, 47.54717543721199, 48.57394494116306, 45.370857417583466, 44.08338010311127, 47.62728653848171, 45.887135714292526, 47.105848118662834, 45.06324112415314, 44.862991869449615, 45.03676034510136, 44.50466349720955, 44.485751911997795, 50.97036994993687, 58.073564395308495, 57.29807920753956, 57.78067611157894, 56.01405970752239, 54.63261343538761, 57.90143743157387, 59.10336993634701, 60.96521683037281, 39.075013250112534, 44.69221003353596, 61.771837547421455, 59.108503460884094, 60.05885906517506, 57.2724761813879, 58.34723711013794, 55.159751549363136, 48.67592006921768, 45.239262878894806, 45.15835762023926, 46.13401986658573, 44.975515231490135, 43.3618938177824, 46.93203404545784, 44.77864779531956, 47.76488095521927, 45.85530862212181, 44.790617153048515, 44.55821022391319, 47.21202202141285, 45.537455677986145, 47.64698088169098, 47.497956678271294, 44.93704229593277, 47.22425356507301, 45.70292539894581, 46.918670162558556, 50.30686475336552, 45.28801426291466, 46.306762397289276, 46.257471442222595, 45.718375369906425, 45.85494764149189, 49.34859797358513, 45.7785527408123, 50.3645608574152, 50.95021203160286, 47.33661733567715, 48.399724289774895, 46.150624975562096, 49.56958271563053, 62.74019278585911, 64.45172354578972, 63.648199662566185, 51.28833308815956, 58.04497852921486, 66.31002143025398, 67.05927282571793, 66.34471356868744, 63.78935068845749, 63.36080588400364, 64.54393699765205, 61.39563113451004, 64.96506839990616, 63.3383908867836, 67.60461196303368, 69.13825526833534, 72.77089074254036, 66.6913689672947, 67.3235334455967, 62.46455937623978, 72.42635563015938, 66.3365288078785, 84.85441714525223, 25.46468887478113, 1.9013112201355398, 4.828683519735932, 0.24172371748136356, 0.2334591609542258, 35.908601358532906, 80.78679621219635, 67.1406264603138, 72.25669473409653, 73.83475005626678, 47.09285281598568, 33.63713264465332, 57.69867651164532, 65.41051849722862, 78.57960104942322, 19.759988486766815, 0.31834587862249464, 0.2718417771393433, 0.1999961823457852, 0.23780289193382487, 0.11751781552447937, 0.22237683297134936, 0.12281878342037089], [0.009175783998216502, 0.02757239664788358, 0.016950255885603838, 0.005928467671765247, 0.02833723177900538, 0.051895878568757325, 0.10769469692604616, 0.0722640250751283, 25.137915909290314, 70.18291801214218, 49.182733073830605, 39.922200590372086, 13.722903784364462, 29.921557120978832, 40.22241488099098, 56.148211508989334, 67.72619783878326, 57.65790469944477, 8.010112680494785, 0.6063040159642696, 0.41593877307605, 0.1310730612021871, 28.17182321101427, 78.03022652864456, 65.50874322652817, 63.253153860569, 56.811218932271004, 56.77423931658268, 57.04449221491814, 54.86874416470528, 56.72249749302864, 60.44226609170437, 61.1596903949976, 60.901619642972946, 59.513200744986534, 51.347693502902985, 50.694804936647415, 48.18885080516338, 45.018794909119606, 46.581046879291534, 44.92818497121334, 44.10100355744362, 42.53145977854729, 43.99859145283699, 43.50812517106533, 40.75346298515797, 42.99323379993439, 43.14302176237106, 45.35812810063362, 44.779460951685905, 42.127910032868385, 43.749511018395424, 42.371324971318245, 43.88913452625275, 43.56984905898571, 42.24002681672573, 43.793596252799034, 42.939671874046326, 42.46288485825062, 43.25507774949074, 43.88509914278984, 43.792448714375496, 43.78031596541405, 45.03801807761192, 42.65293926000595, 42.50385046005249, 41.722790971398354, 46.053665578365326, 46.10384188592434, 46.208309680223465, 44.164824932813644, 42.35283516347408, 39.13096144795418, 40.92044122517109, 39.89999458193779, 40.256537050008774, 37.667697966098785, 41.15169681608677, 39.326928332448006, 42.219500318169594, 46.173701137304306, 50.6357067078352, 53.42870883643627, 53.294895216822624, 53.33211801946163, 51.970776468515396, 54.88326698541641, 55.45997343957424, 35.4946743696928, 42.48933523893356, 53.42768669128418, 52.25900240242481, 55.10754615068436, 52.19168521463871, 50.501589104533195, 47.85659663379192, 43.09135973453522, 40.35227671265602, 40.40222503244877, 40.804004073143005, 40.00707283616066, 40.414399579167366, 41.2370440363884, 40.02067610621452, 41.34133704006672, 40.693752989172935, 41.81768327951431, 39.51821006834507, 41.30682349205017, 44.59996238350868, 45.340105667710304, 43.17364051938057, 44.5978344976902, 43.35137598216534, 43.35224233567715, 42.265645042061806, 44.323903396725655, 41.226795986294746, 42.124881595373154, 41.9557298719883, 41.12293615937233, 42.13802129030228, 44.83181834220886, 43.19111958146095, 43.36431048810482, 42.02319525182247, 42.81606450676918, 42.35370151698589, 44.035734459757805, 44.09281499683857, 54.426649287343025, 58.10991704463959, 53.14323015511036, 40.09205147624016, 58.1231365352869, 56.95144280791283, 62.77836933732033, 59.711588099598885, 59.41882900893688, 58.49278450012207, 61.80966071784496, 59.27264325320721, 60.24879947304726, 54.38227906823158, 57.96486362814903, 56.15060918033123, 61.10786497592926, 54.058825224637985, 55.02968072891235, 52.8046303242445, 63.71758013963699, 60.47343961894512, 78.99226650595665, 42.0800743997097, 0.11163238406879827, 0.5817734228912741, 0.042949013732140884, 0.08517832233337685, 17.125012278556824, 64.9113316833973, 62.076444402337074, 56.51937559247017, 61.45091436803341, 33.34666483104229, 15.184824988245964, 34.55915316939354, 45.06987936794758, 59.51027870178223, 21.624801121652126, 0.37923081312328577, 0.06549761979840696, 0.04468897524930071, 0.07536466611782089, 0.034056856311508454, 0.07121357441064902, 0.03884622470650356, 0.09646903796237893, 0.03941123286494985, 0.036347944114822894, 0.02900856372434646, 0.023751733206154313, 0.02680596589925699, 0.1160577438713517, 0.11590314708882943, 32.501096203923225, 79.29883405566216, 56.923537105321884, 47.08871103823185, 18.4481430798769, 26.49105940014124, 38.302244916558266, 65.92493489384651, 72.60157942771912, 64.13162112236023, 7.777787921950221, 0.6160541146527976, 0.38455501024145633, 0.6072422687429935, 29.711046516895294, 79.18449819087982, 68.14973831176758, 63.96297097206116, 57.38124534487724, 61.00912347435951, 58.46148177981377, 57.3874694108963, 59.692722111940384, 62.76888884603977, 63.922168761491776, 63.941540122032166, 60.62195464968681, 55.31635634601116, 53.17398190498352, 51.57339759171009, 48.4180773049593, 48.497918620705605, 47.81637579202652, 46.55918285250664, 45.388454273343086, 45.50107643008232, 46.064392402768135, 44.03979264199734, 45.63756890594959, 45.09942278265953, 46.761958971619606, 47.20007166266441, 44.55928556621075, 44.54392299056053, 44.651947394013405, 45.25488764047623, 46.480648666620255, 45.20420975983143, 46.20170943439007, 44.68518801033497, 45.6989736109972, 45.188265815377235, 45.46439699828625, 45.43623670935631, 45.581985488533974, 46.061793342232704, 45.44613137841225, 44.762840643525124, 43.93385052680969, 48.71940113604069, 49.62939530611038, 47.2167831659317, 45.95965102314949, 44.016260504722595, 42.115518897771835, 42.611962258815765, 40.974633917212486, 42.28082902729511, 41.18822805583477, 42.187604829669, 41.29032477736473, 43.205725997686386, 48.43862660229206, 54.85686220228672, 55.91593757271767, 56.56153813004494, 54.15520705282688, 53.674365654587746, 58.19795832037926, 55.66303074359894, 40.25387719273567, 44.68192018568516, 55.00917322933674, 52.88735568523407, 56.981430798769, 54.276754930615425, 50.60447998344898, 49.43225048482418, 46.865761801600456, 42.423891350626945, 42.1570810675621, 41.722912564873695, 42.502106353640556, 42.1951512247324, 43.16042102873325, 43.1465669721365, 42.223934680223465, 42.444170862436295, 43.996915742754936, 43.283021450042725, 44.68605436384678, 45.7705769687891, 46.25689387321472, 46.31504975259304, 45.795724019408226, 45.41434608399868, 43.5189013928175, 43.59600305557251, 45.64815893769264, 44.185670614242554, 43.406742811203, 43.20060767233372, 43.400492146611214, 43.61747570335865, 46.892755553126335, 44.4523137062788, 44.796088859438896, 44.31436590850353, 44.93742607533932, 44.63197946548462, 46.05629503726959, 45.901867523789406, 55.870290622115135, 61.5011552721262, 55.4074564576149, 45.01016557216644, 60.05567103624344, 60.348863303661346, 64.5549488067627, 60.5585740506649, 60.88667884469032, 60.75675241649151, 65.26800334453583, 61.747560650110245, 62.25874722003937, 58.31559240818024, 60.919729471206665, 58.49139377474785, 62.68557831645012, 55.07428653538227, 58.12043868005276, 55.203080624341965, 67.34176486730576, 64.10296306014061, 80.14347553253174, 46.89337871968746, 0.15272852964699268, 2.452855068258941, 0.5362176080234349, 0.13207274896558374, 18.60053200274706, 71.64678946137428, 65.80170750617981, 64.99817982316017, 59.20577444136143, 30.193751715123653, 19.062279425561428, 42.22980536520481, 52.53247752785683, 69.2932641506195, 28.14446847885847, 0.36636586126405746, 0.07336178765399382, 0.041949329679482616, 0.0372514792252332, 0.056717942279647104, 0.02934578078566119, 0.06611153919948265, 0.2399760636035353, 0.12388166505843401, 0.16721792402677238, 0.1148405326239299, 0.10198118397966027, 0.13232881959993392, 0.1504057558486238, 0.14202505321009085, 43.320650830864906, 88.24985414743423, 65.81303089857101, 55.902987867593765, 23.949936255812645, 40.50915889441967, 52.610373347997665, 74.53197464346886, 76.54332831501961, 75.22499665617943, 11.058027930557728, 0.7367416354827583, 1.0008661751635373, 1.0184529377147555, 33.719671815633774, 82.94372767210007, 70.89045524597168, 66.51878982782364, 60.82066498696804, 63.32362487912178, 62.733261957764626, 59.15798060595989, 64.21658456325531, 65.41494145989418, 67.60136693716049, 66.28641709685326, 64.54085916280746, 55.7759340852499, 56.20241180062294, 55.35406932234764, 50.03577210009098, 51.62542060017586, 50.68927243351936, 48.63425150513649, 48.231495916843414, 49.97438259422779, 48.48687261343002, 46.31260648369789, 49.113531187176704, 48.422371074557304, 50.05257859826088, 49.69174236059189, 46.92914620041847, 47.266796082258224, 47.49645575881004, 48.292380049824715, 47.417351603507996, 47.14643374085426, 48.81392106413841, 47.71380789577961, 48.24444182217121, 48.50769929587841, 49.366088435053825, 48.11093218624592, 47.73979090154171, 47.86876358091831, 47.56623521447182, 47.24407710134983, 46.07821226119995, 50.5175406485796, 54.3163488060236, 49.962895810604095, 48.715969920158386, 46.63870118558407, 43.54545816779137, 45.50130821764469, 42.40176513791084, 44.44561466574669, 41.58223271369934, 45.11992268264294, 44.574024975299835, 49.12229351699352, 51.53511084616184, 57.729150876402855, 57.79332183301449, 57.513425052165985, 56.86459846794605, 56.720836982131004, 59.381298422813416, 58.572074845433235, 44.3685358017683, 46.515876576304436, 56.52213804423809, 57.12593324482441, 58.90895336866379, 56.6363675147295, 55.25582939386368, 52.54450008273125, 48.8494947552681, 46.32180958986282, 45.85079066455364, 43.50713722407818, 44.39218193292618, 45.47407127916813, 44.50076870620251, 45.300264805555344, 44.443501979112625, 45.823610723018646, 47.10031941533089, 44.992424324154854, 46.86405949294567, 49.298250675201416, 49.480557292699814, 46.82611092925072, 47.92416840791702, 48.01996126770973, 47.271743416786194, 46.838380470871925, 47.43460647761822, 46.04701213538647, 46.446579694747925, 47.861547768116, 45.97969874739647, 46.445036977529526, 50.249822214245796, 45.92137947678566, 47.76144213974476, 44.9224016815424, 47.422701716423035, 47.226381450891495, 48.275676146149635, 47.52147361636162, 59.10843126475811, 63.089671432971954, 57.90130823850632, 46.47435620427132, 62.13928923010826, 63.07389087975025, 67.08865284919739, 64.01660889387131, 64.38537150621414, 63.86796846985817, 67.32997789978981, 65.81786423921585, 65.10895907878876, 61.6903243213892, 63.721877709031105, 61.2800907343626, 65.93532353639603, 57.557776272296906, 60.401771664619446, 60.42499981820583, 68.90364825725555, 66.86018630862236, 83.234191685915, 50.15913248062134, 0.27679846272803843, 3.745989566668868, 1.0190910659730434, 0.22390081838238984, 23.201038241386414, 78.69942381978035, 71.71867400407791, 74.07987490296364, 80.6236481666565, 44.52916458249092, 24.19044055044651, 52.858940809965134, 64.88892808556557, 78.24758246541023, 35.47419346868992, 0.5789263069164008, 0.18025276833213866, 0.16354280873201787, 0.11329395623761229, 0.10527150312555023, 0.11773878257372417, 0.16057414381066337], [0.025482840901531745, 0.08896388404536992, 0.01823039197915932, 0.08019261877052486, 0.03487038746243343, 0.0459482180303894, 0.026506251415412407, 0.07450335178873502, 36.642258390784264, 64.9521566927433, 46.818906515836716, 28.250528387725353, 20.313309095799923, 44.803848043084145, 39.73471865057945, 54.92881894111633, 70.1930482685566, 54.07608389854431, 2.450939496047795, 0.16807093372335657, 0.3616417944431305, 0.4027218947885558, 39.232283011078835, 77.54509896039963, 67.35836997628212, 62.56191395223141, 53.05117629468441, 55.752097964286804, 53.996740356087685, 59.69992272555828, 60.18607623875141, 63.172354996204376, 64.00441914796829, 63.8761380314827, 62.6486898958683, 58.054614812135696, 57.79800698161125, 54.79431375861168, 52.53846600651741, 50.75363717973232, 48.55516254901886, 46.756779849529266, 45.02115458250046, 43.29698570072651, 41.81653954088688, 45.51402233541012, 44.26156014204025, 44.58819821476936, 43.75622905790806, 44.08097863197327, 44.13407318294048, 42.19896242022514, 44.200900197029114, 44.98407617211342, 43.5986553132534, 44.96597774326801, 43.57708387076855, 42.29411691427231, 44.12198223173618, 43.261575400829315, 43.02180826663971, 42.69013166427612, 44.262772276997566, 44.19863931834698, 43.7984561920166, 40.49356833100319, 41.72267697751522, 44.09330137073994, 43.48808504641056, 45.90399160981178, 44.5142237842083, 43.58402989804745, 42.303897589445114, 41.13584406673908, 41.98782294988632, 39.56660807132721, 40.38389101624489, 40.19155293703079, 39.46722820401192, 39.4049571454525, 43.56865972280502, 47.92099937796593, 49.31368164718151, 52.33892351388931, 55.510358735919, 53.25733803212643, 52.33584187924862, 51.020078882575035, 38.934124410152435, 40.79364962875843, 48.66094507277012, 50.55540941655636, 50.819343253970146, 48.41998100280762, 47.45826780796051, 45.38647837936878, 40.477871373295784, 38.31241317093372, 39.640111327171326, 39.8427202552557, 39.60051745176315, 40.26675470173359, 40.39712190628052, 42.5095159560442, 42.1104271709919, 42.266914173960686, 41.43807224929333, 43.755978271365166, 44.2972706258297, 45.36526031792164, 48.63268978893757, 45.173275619745255, 46.106000170111656, 43.8768345862627, 44.55606333911419, 44.19709660112858, 42.88841262459755, 42.777249589562416, 41.49907797574997, 39.8389508575201, 41.69777691364288, 41.65912538766861, 43.000897988677025, 43.357239067554474, 43.05951364338398, 43.225541934370995, 42.57301814854145, 42.45593123137951, 43.57242912054062, 41.72262378036976, 48.487602174282074, 56.74131028354168, 57.478592321276665, 60.12153670191765, 59.85088862478733, 55.617691576480865, 57.38399639725685, 55.8278127014637, 58.233835995197296, 56.42476066946983, 54.02572900056839, 51.869717091321945, 50.53516410291195, 47.17623934149742, 48.364222794771194, 46.874858513474464, 47.82349281013012, 47.671915143728256, 52.7789930999279, 51.89400918781757, 59.60815005004406, 64.32434678077698, 72.09336429834366, 65.40373206138611, 1.489630623254925, 2.3333464935421944, 0.3437438642140478, 0.25394470780156553, 8.89257637783885, 62.80629403889179, 65.43980732560158, 58.19957323372364, 41.8690375238657, 33.63902874290943, 16.58544883131981, 27.275094129145145, 43.80656875669956, 55.47163501381874, 30.969379395246506, 0.8439659443683922, 0.1331784896319732, 0.022280670345935505, 0.03742576147487853, 0.0647611940803472, 0.02512839673727285, 0.047002709688968025, 0.017835745675256476, 0.0404872319631977, 0.0406769249093486, 0.03595537396904547, 0.014625292751588859, 0.10652230397681706, 0.041226700486731716, 0.253495589713566, 45.89535467326641, 73.24851751327515, 54.169976860284805, 35.02680167555809, 25.340940915048122, 36.18997246026993, 40.0760543346405, 63.84345218539238, 71.96140497922897, 60.67353308200836, 3.278136821463704, 0.23130129236960784, 0.13336893956875429, 0.580881480127573, 41.00390374660492, 79.76255357265472, 70.24780333042145, 66.95816785097122, 56.383840665221214, 58.25814709067345, 56.581164076924324, 61.95828974246979, 60.63952870666981, 66.7559427022934, 66.00216954946518, 66.59025639295578, 65.10515928268433, 60.29875539243221, 58.50251577794552, 57.35311545431614, 55.366308465600014, 52.846200093626976, 50.16523115336895, 48.241477981209755, 48.71873997151852, 46.62083454430103, 43.8579647988081, 47.08011969923973, 46.666413098573685, 46.195352375507355, 45.913426503539085, 44.906484335660934, 45.35766452550888, 44.594372883439064, 45.786220729351044, 45.8007587492466, 45.15982434153557, 45.2179916203022, 45.63590459525585, 44.648413583636284, 45.37653811275959, 45.92487528920174, 45.199866592884064, 45.26363097131252, 44.7948045283556, 44.94282938539982, 45.282113179564476, 43.02870489656925, 45.90682625770569, 45.73542885482311, 46.35758087038994, 46.66996210813522, 46.504427790641785, 46.87828212976456, 45.413878709077835, 43.25575411319733, 42.65132814645767, 42.46429458260536, 40.35992190241814, 43.74315395951271, 41.46679110825062, 41.44107028841972, 44.60513390600681, 50.05187563598156, 50.98876856267452, 53.78580987453461, 56.65644943714142, 57.06729099154472, 55.22709533572197, 54.44987364113331, 40.56465871632099, 47.31270521879196, 53.676679730415344, 52.80738517642021, 53.19759763777256, 50.31246945261955, 49.16387088596821, 46.33797772228718, 43.684633299708366, 42.25407466292381, 41.969158351421356, 41.97460725903511, 40.543463453650475, 41.780528873205185, 42.032029777765274, 43.04946318268776, 43.52289877831936, 43.88444557785988, 44.44414034485817, 45.982370004057884, 46.55390113592148, 48.376708924770355, 49.90737698972225, 46.39943942427635, 46.5293924510479, 45.40287829935551, 44.91096429526806, 45.11290065944195, 45.10257661342621, 44.19166289269924, 43.88178952038288, 42.37441800534725, 43.10500480234623, 44.21493664383888, 45.927626341581345, 44.595744609832764, 44.842187985777855, 45.067595690488815, 44.35723140835762, 45.93083716928959, 45.579834803938866, 44.99145917594433, 50.4279338568449, 58.997754603624344, 59.62280586361885, 62.30514273047447, 62.71115854382515, 58.137955740094185, 58.75912360846996, 59.11128491163254, 61.42487056553364, 58.85402351617813, 56.50166094303131, 54.4719884544611, 50.98811499774456, 48.47580000758171, 49.693041890859604, 49.747751355171204, 50.87908744812012, 49.68055576086044, 52.64484889805317, 56.66787922382355, 61.34334973990917, 66.48877143859863, 73.11476469039917, 70.07811963558197, 1.7357271490618587, 2.1468814741820097, 0.9176065865904093, 0.33110419870354235, 9.691961333155632, 68.25513705611229, 69.13637816905975, 64.92357462644577, 47.42796443402767, 36.318082585930824, 21.594613641500473, 34.89068157970905, 50.54687887430191, 64.01590213179588, 39.117460772395134, 0.8459598280023783, 0.1331523066619411, 0.07427151969750412, 0.045736947140539996, 0.09047642553923652, 0.0314509012241615, 0.006414410663637682, 0.14075406594201922, 0.12680357467615977, 0.11990228405920789, 0.11496246006572619, 0.1262260353541933, 0.2645799214951694, 0.1937550914590247, 0.6917985971085727, 58.976308554410934, 82.97923296689987, 63.04375849664211, 42.58179947733879, 31.820001751184464, 59.934020563960075, 54.42058861255646, 69.91896137595177, 78.94674494862556, 68.28343033790588, 4.412513226270676, 0.38157513889018446, 0.6068358686752617, 1.064513591118157, 44.815125837922096, 84.54150393605232, 74.37927603721619, 68.83102655410767, 58.392948657274246, 61.3827308267355, 59.99435752630234, 66.0868290066719, 63.22704926133156, 68.89557749032974, 69.36620503664017, 67.8166937828064, 68.36212411522865, 61.58585272729397, 61.55069701373577, 61.190662533044815, 59.31998871266842, 56.18027798831463, 53.24844650924206, 52.37306088209152, 52.39120110869408, 50.21594323217869, 45.552548468112946, 49.52431574463844, 48.89174088835716, 49.68222387135029, 47.17631533741951, 47.21786990761757, 49.05662164092064, 46.875527277588844, 49.08625245094299, 49.68530170619488, 47.837878838181496, 48.12791347503662, 48.847579658031464, 46.219990253448486, 48.04120592772961, 47.527397498488426, 47.88929767906666, 47.7053115516901, 48.2951994985342, 47.77517460286617, 46.09336204826832, 43.938277289271355, 46.25278249382973, 47.73941472172737, 48.5489346832037, 48.324115946888924, 49.378589764237404, 47.866913080215454, 48.36145654320717, 45.55573649704456, 46.47516556084156, 45.29707297682762, 43.8451024889946, 46.35083623230457, 44.8809839040041, 43.68491068482399, 48.337058052420616, 53.62687200307846, 54.205656945705414, 56.96613661944866, 60.075870752334595, 59.112808629870415, 58.5274538397789, 57.28281922638416, 45.20256444811821, 49.96649421751499, 54.2017013579607, 54.58122119307518, 57.25574567914009, 53.70947577059269, 51.48017719388008, 51.71322628855705, 46.03058561682701, 45.41632577776909, 45.06413787603378, 45.92303618788719, 42.13545262813568, 45.2522923797369, 44.43016089498997, 47.60985687375069, 47.9251791536808, 46.49527408182621, 47.26397283375263, 48.92871670424938, 48.97271454334259, 50.11798068881035, 52.113929986953735, 48.01722541451454, 49.2364089936018, 46.28350764513016, 47.208005636930466, 48.84331628680229, 46.70864783227444, 45.96927210688591, 46.51855543255806, 43.25456477701664, 44.883468970656395, 46.693494245409966, 48.45746599137783, 48.02746206521988, 46.79289311170578, 48.6217387765646, 46.469887644052505, 46.594672948122025, 48.45987506210804, 47.132089510560036, 52.99510270357132, 62.57705993950367, 62.07608722150326, 65.36403939127922, 66.29822686314583, 60.41992709040642, 61.01879395544529, 61.84822104871273, 62.72538498044014, 62.24813058972359, 59.64380353689194, 57.5818707793951, 54.43825766444206, 50.9061723947525, 53.76726306974888, 53.66589970886707, 54.23478998243809, 53.68879348039627, 56.53208591043949, 59.46757659316063, 62.374622002243996, 70.3210861980915, 76.37621328234673, 74.50796753168106, 1.7117395112290978, 5.188150405883789, 1.6682785120792687, 0.387757882126607, 11.758241057395935, 75.39458155632019, 76.41966015100479, 71.5869502723217, 57.66618065536022, 47.26535975933075, 29.673451334238052, 46.50728903710842, 62.09869220852852, 74.14881840348244, 50.14003850519657, 1.4960968075320125, 0.2975094591965899, 0.14180441270582378, 0.10973866810672916, 0.12818618095479906, 0.15875840530497953, 0.15407539409352466], [0.007845430482120719, 0.03131337754894048, 0.08082734799245372, 0.00474341553854174, 0.054295193767757155, 0.04241619251843076, 0.0352686573023675, 0.20506763365119696, 45.44331572949886, 58.37865002453327, 43.23661834001541, 25.86496889591217, 6.928864549845457, 36.41852639615536, 45.623551458120346, 61.79275922477245, 70.78578606247902, 50.458370223641396, 1.476449843030423, 0.07584314356790856, 0.23687998676905409, 0.2349533565575257, 42.70729534327984, 74.13034379482269, 64.21112805604935, 62.03629195690155, 57.08826586604118, 59.07169483602047, 60.97778655588627, 64.09722536802292, 62.892253026366234, 61.58926114439964, 59.84938770532608, 60.23155219852924, 62.012550830841064, 62.36696541309357, 60.18425613641739, 55.648792907595634, 51.557461246848106, 51.93654790520668, 51.05065584182739, 47.55556158721447, 44.60092753171921, 45.08059859275818, 45.50724729895592, 42.74632304906845, 43.00421141088009, 44.8759301751852, 44.0575946867466, 43.547848239541054, 43.26384387910366, 43.71927984058857, 41.217456087470055, 44.78345073759556, 43.79314407706261, 44.13661904633045, 43.0069662630558, 43.61468285322189, 43.32762725651264, 42.52701781690121, 41.274859607219696, 43.99896763265133, 45.0013842433691, 44.758451879024506, 44.188828244805336, 42.02671006321907, 42.983928099274635, 44.51760560274124, 43.91751900315285, 42.08811476826668, 42.86697797477245, 44.60353039205074, 40.73869697749615, 42.24182412028313, 40.46771451830864, 40.21663159132004, 38.363744616508484, 40.90529903769493, 39.50573153793812, 38.78166139125824, 40.84211602807045, 42.90973708033562, 45.95224142074585, 48.77919852733612, 49.24109414219856, 52.20269702374935, 48.62107761204243, 46.558673679828644, 41.63243182003498, 41.00561745464802, 47.181258872151375, 51.20890595018864, 47.50495210289955, 47.481708750128746, 43.47918212413788, 43.45156900584698, 39.73018929362297, 38.01257885992527, 40.976321026682854, 39.69984792172909, 40.324967578053474, 40.39862662553787, 39.82452683150768, 41.63712836802006, 41.166987195611, 41.27428583800793, 44.0342715382576, 43.4890615940094, 42.222125977277756, 43.42030428349972, 43.15992325544357, 43.08463789522648, 43.7134775519371, 43.22718724608421, 42.45214283466339, 41.07383519411087, 42.55135551095009, 43.126815631985664, 39.92642976343632, 40.32454580068588, 42.56416082382202, 42.4569495767355, 43.57049122452736, 44.13499653339386, 43.19596812129021, 41.00307159125805, 43.88031139969826, 43.029426857829094, 41.57469391822815, 44.1766194999218, 44.61340606212616, 47.816603779792786, 49.50094699859619, 51.08794704079628, 50.52091106772423, 52.09978714585304, 50.5692482739687, 50.628346502780914, 48.394670560956, 46.71954944729805, 45.5344158411026, 44.681240022182465, 43.23760248720646, 48.44994239509106, 48.998872339725494, 50.811694264411926, 54.35010999441147, 54.94732014834881, 54.60415296256542, 58.27005185186863, 58.88721473515034, 66.97071477770805, 68.32903549075127, 72.65502735972404, 7.1051921881735325, 2.7112245792523026, 0.9202005411498249, 0.3055349551141262, 3.8039727928116918, 57.361702993512154, 68.15320372581482, 62.983364537358284, 55.33369101583958, 32.33704000711441, 11.00906565785408, 29.951263926923275, 37.91302800178528, 53.390475288033485, 36.137558072805405, 1.7401118762791157, 0.11127523292088881, 0.026830556962522678, 0.09555765092954971, 0.08523489625076763, 0.04397760072606616, 0.028411852872523014, 0.04791669052792713, 0.0196409308409784, 0.051223871269030496, 0.01517712778877467, 0.03922736577806063, 0.02741626918577822, 0.019719375850399956, 0.45913639885839075, 55.847488045692444, 65.73276400566101, 50.92843919992447, 30.202063769102097, 14.914750680327415, 30.295362062752247, 47.86020644009113, 71.44493669271469, 76.39131367206573, 56.36852368712425, 1.4256573747843504, 0.11039874167181551, 0.28446012816857547, 0.16270758089376613, 45.21483398973942, 77.12076812982559, 66.70084565877914, 64.13018479943275, 58.71302828192711, 60.62249042093754, 63.071998581290245, 66.13712310791016, 65.9113772213459, 64.91386994719505, 62.300453782081604, 60.56995823979378, 63.48353549838066, 62.8154743462801, 61.361334174871445, 59.363067001104355, 56.46831013262272, 54.674867168068886, 54.12250980734825, 49.52285282313824, 47.184629291296005, 47.070004642009735, 47.556690126657486, 45.42852692306042, 44.92507293820381, 46.63720026612282, 47.115298211574554, 45.124870017170906, 44.04599390923977, 45.66418267786503, 43.674290254712105, 46.5252810716629, 45.009891986846924, 44.53384593129158, 45.247785821557045, 45.26383236050606, 45.78816242516041, 44.52198676764965, 44.83659848570824, 47.722087651491165, 46.10618636012077, 45.82504704594612, 46.590086594223976, 43.454415053129196, 45.01197807490826, 45.38534224033356, 45.60196861624718, 43.64661253988743, 43.97109992802143, 45.828824043273926, 42.84152694046497, 45.15823222696781, 42.90721021592617, 42.53110259771347, 40.61617635190487, 41.987199783325195, 41.855939626693726, 41.33790582418442, 42.8743951767683, 45.60838647186756, 49.32091645896435, 50.88128753006458, 50.62792852520943, 53.489801958203316, 51.29210628569126, 49.68787796795368, 44.53328736126423, 43.889981880784035, 49.97757822275162, 53.15146431326866, 49.18451517820358, 48.083224073052406, 45.699543580412865, 45.31877741217613, 41.93753644824028, 40.20885720849037, 41.78875543177128, 42.02900514006615, 42.724193036556244, 40.704377219080925, 41.50276757776737, 43.56322981417179, 44.02987517416477, 43.69292825460434, 45.59505298733711, 44.48842316865921, 44.317721128463745, 44.4851553440094, 44.139107912778854, 45.59755705296993, 44.8723241686821, 43.12070935964584, 43.77742812037468, 42.89777532219887, 44.25798453390598, 44.87762488424778, 41.6128134727478, 44.48311485350132, 44.61682587862015, 44.66094151139259, 45.27044400572777, 45.671280696988106, 43.31836715340614, 43.329010382294655, 45.971753373742104, 45.21423362195492, 43.4823739528656, 46.830944269895554, 45.31897120177746, 49.068708792328835, 52.20689959824085, 52.04280540347099, 54.48858976364136, 54.40308675169945, 51.548626720905304, 51.60071052610874, 50.16395442187786, 48.24877738952637, 46.38785004615784, 48.675536289811134, 46.52004115283489, 50.21214343607426, 51.68574996292591, 54.41808454692364, 56.743673756718636, 57.55200818181038, 58.49160276353359, 60.4888591915369, 61.28714695572853, 70.08907064795494, 70.454421043396, 76.71355918049812, 8.07697294279933, 1.6928610554896295, 0.8459139929618686, 0.36151643085759133, 4.467899054288864, 62.63255596160889, 73.00561174750328, 69.47973534464836, 58.11278209090233, 43.064244389534, 22.075221352279186, 37.603838592767715, 46.174772679805756, 60.99646635353565, 47.97744154930115, 2.426761630922556, 0.26592493057250977, 0.04332007643824909, 0.03146852723148186, 0.05759596606367268, 0.008908529198379256, 0.017545625305501744, 0.12397473779856227, 0.1431736900121905, 0.19126197992591187, 0.1792768292943947, 0.15101317403605208, 0.13793277670629323, 0.12010244870907627, 1.8637281493283808, 69.42945644259453, 75.67666321992874, 59.675246849656105, 40.56957185268402, 14.038710538297892, 49.587388560175896, 64.08570438623428, 76.23518005013466, 81.59842506051064, 60.81901587545872, 2.0589237939566374, 0.19225950061809272, 0.5018084950279444, 0.5317166307941079, 49.46788117289543, 80.92277571558952, 69.96085792779922, 65.5483826994896, 61.77020363509655, 63.155331909656525, 66.23810648918152, 69.50957894325256, 69.52883630990982, 67.80787825584412, 65.7769176363945, 64.37630519270897, 66.03342667222023, 67.98312485218048, 66.66889697313309, 60.79795740544796, 58.0456966906786, 57.955124750733376, 58.62931877374649, 53.45924399793148, 50.53849272429943, 50.21288439631462, 52.74151191115379, 48.22683736681938, 47.13553972542286, 49.61579963564873, 50.02555064857006, 46.78471975028515, 46.610373705625534, 46.75163492560387, 45.34243494272232, 48.91764409840107, 49.21415738761425, 48.056819289922714, 48.376982510089874, 47.556690126657486, 48.591424003243446, 45.935875698924065, 46.180096194148064, 51.19494549930096, 50.121286511421204, 48.08645769953728, 48.26794736087322, 45.066052973270416, 46.79748326539993, 48.25261898338795, 48.66172403097153, 46.775292456150055, 46.412750110030174, 48.98167826235294, 45.41793689131737, 46.84109352529049, 46.633810847997665, 43.93572002649307, 43.249963223934174, 46.468223333358765, 45.72567097842693, 43.42765308916569, 47.31792613863945, 47.464214488863945, 52.74008698761463, 53.989589139819145, 54.83298048377037, 56.26130864024162, 52.822686955332756, 50.62942184507847, 46.867114529013634, 47.14541159570217, 51.989984437823296, 55.53801745176315, 51.15063227713108, 51.04353882372379, 47.00848214328289, 48.92637223005295, 44.63082812726498, 42.60534681379795, 46.48066386580467, 44.91761773824692, 44.30611275136471, 44.92199890315533, 44.23839658498764, 46.597177013754845, 47.41491973400116, 45.82839846611023, 48.477441519498825, 48.67959067225456, 45.03587119281292, 45.29049552977085, 44.47338357567787, 47.56620481610298, 47.480352222919464, 45.02512536942959, 45.86999483406544, 45.063127130270004, 45.92900946736336, 49.21564690768719, 42.768574655056, 46.50162734091282, 46.92587837576866, 47.409068048000336, 48.544671311974525, 47.32206791639328, 45.530448853969574, 44.870982840657234, 49.01697836816311, 48.43106500804424, 46.19862399995327, 49.04588721692562, 48.38391333818436, 52.38643616437912, 56.22503958642483, 56.463408395648, 57.43091627955437, 58.41588422656059, 54.299709498882294, 54.871590211987495, 54.143059104681015, 50.941024124622345, 49.615206867456436, 51.665523648262024, 48.74587431550026, 54.48766641318798, 54.00261104106903, 57.34685719013214, 59.71915729343891, 60.09815275669098, 60.126062259078026, 63.87242943048477, 64.07647088170052, 72.64351397752762, 75.40268272161484, 79.62148994207382, 8.60401226207614, 4.5759424567222595, 3.4865527879446745, 0.5571643996518105, 5.419221706688404, 67.10894376039505, 80.55981159210205, 77.01874360442162, 72.56163597106934, 42.16363951563835, 23.81674960255623, 45.10307438671589, 57.88772776722908, 72.06431105732918, 63.03350284695625, 3.5275259893387556, 0.34556646016426384, 0.22449792071711272, 0.15926716238027439, 0.21652024879585952, 0.10432119786855765, 0.14490051922621205], [0.04761610587593168, 0.029823473414580803, 0.08870796184055507, 0.028746066091116518, 0.024808790840324946, 0.09678543778136373, 0.07351515989284962, 2.0854259468615055, 55.35880006849766, 56.3117129355669, 40.000423192977905, 20.140144787728786, 15.715244226157665, 54.83942113816738, 53.96658897399902, 61.52828961610794, 68.04072976112366, 42.51799710094929, 0.7136774668470025, 0.017122020399256144, 0.1639313081977889, 0.17948719847481698, 37.842553183436394, 73.60732465982437, 62.92222961783409, 64.40907463431358, 58.55197012424469, 61.331133395433426, 62.25333251059055, 64.53198283910751, 62.23266541957855, 59.241420328617096, 59.972702488303185, 64.14042145013809, 60.949956849217415, 60.08372113108635, 56.61206781864166, 57.048041224479675, 53.652087450027466, 51.94279856979847, 50.44309884309769, 49.59635227918625, 46.88276968896389, 43.022214844822884, 39.36175346374512, 42.757790833711624, 42.278739139437675, 41.933827847242355, 43.30657638609409, 43.41975711286068, 43.454183265566826, 43.94943729043007, 42.95643277466297, 42.59555093944073, 43.32951195538044, 44.61031682789326, 41.54942147433758, 42.97511637210846, 41.733400002121925, 40.53896829485893, 42.56449520587921, 44.53967481851578, 43.68050292134285, 41.93594053387642, 43.754416555166245, 42.99704499542713, 40.94756416976452, 44.22736197710037, 44.008755907416344, 42.59894795715809, 41.63903966546059, 42.50489920377731, 39.46757398545742, 38.11197392642498, 41.217817068099976, 40.10717086493969, 38.835629895329475, 39.02555510401726, 39.44483980536461, 36.99134945869446, 41.35534688830376, 42.08597168326378, 42.03521400690079, 45.67286901175976, 45.805250108242035, 47.966083958745, 45.65634369850159, 41.84047445654869, 45.66001430153847, 40.14587178826332, 43.76768924295902, 45.47681473195553, 45.11182151734829, 42.78608411550522, 40.24652078747749, 40.20960196852684, 40.34243144094944, 37.97629840672016, 39.44590374827385, 40.29595993459225, 39.52104851603508, 38.10411214828491, 39.72210332751274, 40.51207333803177, 43.69260147213936, 44.01790201663971, 42.181745544075966, 40.56445352733135, 42.03356869518757, 42.18119077384472, 44.010044038295746, 45.18912456929684, 44.625151231884956, 41.254690289497375, 42.65474796295166, 42.21586011350155, 42.034218460321426, 42.09249973297119, 40.512662306427956, 41.624813228845596, 39.366913586854935, 42.71422617137432, 44.125679433345795, 42.70302057266235, 42.71769538521767, 43.33887845277786, 43.31417217850685, 43.92663091421127, 43.21793854236603, 42.866088822484016, 42.07966022193432, 42.41074785590172, 42.10947722196579, 43.32799203693867, 43.68755914270878, 42.788740172982216, 43.39155502617359, 43.547798842191696, 44.89253148436546, 45.30029900372028, 44.70821477472782, 47.98158712685108, 49.15446259081364, 52.77286022901535, 53.482958525419235, 59.87109214067459, 58.928879499435425, 60.84448590874672, 61.38624183833599, 63.88092577457428, 61.42967350780964, 67.38032519817352, 66.28520876169205, 76.3252580165863, 12.14003887027502, 1.0094717633910477, 0.5729339097160846, 0.08357517945114523, 0.8758034859783947, 48.995057344436646, 68.1553316116333, 63.63594152033329, 50.90165823698044, 37.50605084002018, 17.09046833217144, 19.177717231214046, 35.81002704799175, 46.823485270142555, 50.66528432071209, 3.2713988330215216, 0.0705461684265174, 0.10471505564055406, 0.009762286608747672, 0.008203754223359283, 0.030015416923561133, 0.04946864006342366, 0.0280628356631496, 0.009498755534878, 0.08016962703550234, 0.005736112734666676, 0.11125319855636917, 0.05512260308023542, 0.11478936896310188, 3.4904209803789854, 62.901231944561005, 64.05778348445892, 45.235136300325394, 27.254453636705875, 20.05768731236458, 50.61288133263588, 59.278798922896385, 67.54583671689034, 74.52979356050491, 47.41513252258301, 0.8859856927301735, 0.12765843974193558, 0.24180720909498632, 0.40414616523776203, 40.27795650064945, 77.33091965317726, 66.19640752673149, 67.04675629734993, 61.85464650392532, 63.89627695083618, 67.80453443527222, 66.23442828655243, 65.53820684552193, 62.58836053311825, 61.587144657969475, 65.99075496196747, 64.14064943790436, 62.687770798802376, 59.2376509308815, 59.60150420665741, 56.925809383392334, 54.18604239821434, 52.49148532748222, 52.06555098295212, 47.19935730099678, 44.985710084438324, 42.134951055049896, 44.91470709443092, 46.70886442065239, 43.72111514210701, 45.12665592133999, 45.53923398256302, 44.93963375687599, 44.978927448391914, 45.17750099301338, 45.27989789843559, 44.76518891751766, 46.03205993771553, 43.17722752690315, 44.192909225821495, 43.69698263704777, 43.61300714313984, 44.28305558860302, 44.70576770603657, 44.21095445752144, 43.46477709710598, 46.7792784422636, 44.804843589663506, 42.39593245089054, 45.82525983452797, 45.78386105597019, 43.986599296331406, 43.06459777057171, 42.53022864460945, 40.09136751294136, 39.64678376913071, 41.78423747420311, 42.625063955783844, 41.04519993066788, 41.53703413903713, 40.66075176000595, 38.98660719394684, 43.06844316422939, 42.80006356537342, 45.410569086670876, 47.49284215271473, 47.14802585542202, 49.817504212260246, 49.289647936820984, 46.667370647192, 47.327106446027756, 43.526170402765274, 46.46074913442135, 47.4173554033041, 47.52101004123688, 44.12603281438351, 43.623046204447746, 41.489247903227806, 40.87427370250225, 40.2569892257452, 42.28813983500004, 42.735983803868294, 41.53953820466995, 41.87883339822292, 42.039876356720924, 43.27345736324787, 45.040738731622696, 43.99685114622116, 42.569909915328026, 41.664395704865456, 43.4623072296381, 42.494791746139526, 44.162313267588615, 45.40125958621502, 45.77599547803402, 43.16667929291725, 43.239665776491165, 44.282022044062614, 43.82797680795193, 44.63115110993385, 43.19109298288822, 42.907677590847015, 43.71195763349533, 43.851881325244904, 43.721187338232994, 44.558119028806686, 44.59236279129982, 44.49762247502804, 43.72768118977547, 44.61724005639553, 43.950524032115936, 44.982932433485985, 44.977992698550224, 44.447670355439186, 44.86728183925152, 44.76929649710655, 45.096690729260445, 46.28579892218113, 44.84329752624035, 46.78774058818817, 46.218162551522255, 47.66132891178131, 47.70793721079826, 52.23646581172943, 52.32760392129421, 56.64042189717293, 57.613849863409996, 61.9447510689497, 62.511600852012634, 64.4383254647255, 62.157532051205635, 68.52847918868065, 64.00160729885101, 71.46531119942665, 68.80955770611763, 80.71793630719185, 13.569207731634378, 1.6401336598210037, 2.1128946729004383, 0.02550521479861345, 0.9593527496326715, 50.9496458619833, 74.38441336154938, 69.7648112475872, 58.58218230307102, 32.90348321199417, 20.03483723849058, 27.155487947165966, 44.66221444308758, 53.93888846039772, 61.53164863586426, 4.081678753718734, 0.2176720619900152, 0.01411411813023733, 0.03383127310371492, 0.019353278112248518, 0.04951080147293396, 0.038625892193522304, 0.1821653125807643, 0.17364988045301288, 0.17114397429395467, 0.08111111557809636, 0.25963335880078375, 0.23434486967744306, 0.2939458144828677, 4.434123141691089, 76.78512454032898, 72.51208662986755, 55.9295978397131, 35.218007415533066, 25.92148706316948, 67.00875073671341, 69.9447163939476, 73.57633352279663, 80.14663696289062, 55.93484155833721, 1.3908102759160101, 0.4157111415406689, 1.054388559423387, 0.6278046872466803, 43.69107395410538, 80.62086671590805, 69.28248792886734, 71.00437313318253, 64.9893718957901, 67.00176671147346, 70.59632062911987, 70.17164021730423, 66.94320425391197, 63.34458075463772, 63.4886272251606, 67.39234015345573, 64.91608142852783, 65.57623520493507, 58.761722669005394, 63.804147094488144, 59.87443596124649, 55.73877587914467, 56.40230007469654, 56.5898884087801, 51.34937301278114, 48.10452573001385, 43.18196587264538, 47.55529560148716, 48.05151477456093, 47.28060834109783, 47.048927173018456, 48.97019147872925, 47.429176568984985, 48.10526289045811, 48.87340687215328, 47.496250569820404, 48.06607939302921, 49.28808622062206, 45.02466939389706, 47.47245244681835, 46.40420816838741, 44.947655126452446, 46.329116597771645, 48.36145654320717, 47.63175129890442, 45.67774794995785, 50.151608884334564, 46.329348385334015, 43.780338764190674, 48.84253352880478, 48.222011625766754, 47.12680019438267, 45.75948916375637, 45.81081300973892, 43.59310381114483, 41.22477829456329, 45.24026222527027, 44.77580934762955, 43.75833414494991, 44.07237969338894, 43.59446033835411, 42.221062034368515, 46.732100173830986, 46.333189979195595, 48.625808358192444, 49.61202643811703, 50.6285060942173, 52.85862162709236, 50.75196906924248, 47.959115132689476, 49.55100931227207, 45.16887165606022, 48.70948366820812, 50.78139089047909, 48.66856746375561, 46.7493512481451, 45.68266108632088, 45.65932273864746, 45.70647820830345, 42.658388167619705, 45.36380119621754, 45.6407455354929, 43.93826588988304, 42.57284715771675, 44.003629982471466, 44.83298107981682, 46.798668801784515, 46.9429736584425, 44.53947722911835, 42.688307762145996, 45.68097397685051, 44.37821388244629, 45.53126960992813, 47.01832361519337, 49.59413319826126, 45.996820628643036, 45.456265434622765, 47.28072613477707, 46.61898024380207, 47.11029767990112, 45.66901981830597, 45.18856219947338, 44.806652292609215, 47.153140380978584, 47.26994231343269, 45.57451888918877, 47.31660760939121, 46.90943665802479, 46.28918074071407, 48.39496694505215, 46.58823609352112, 48.33337604999542, 47.125914841890335, 46.99862167239189, 47.440708950161934, 47.18005433678627, 47.77970016002655, 48.705155700445175, 46.76956616342068, 47.423929050564766, 49.65931870043278, 49.485033452510834, 50.47433316707611, 53.82532775402069, 53.913509622216225, 58.45246106386185, 60.18854230642319, 65.14507234096527, 65.27044281363487, 67.66436755657196, 65.66666275262833, 72.04703718423843, 67.02208802103996, 74.38161671161652, 72.28949457406998, 82.04382196068764, 15.277464017271996, 2.440316928550601, 3.7563031632453203, 0.24244269530754536, 1.1316033848561347, 58.40857341885567, 81.30067303776741, 73.70602056384087, 69.40666526556015, 46.28027021884918, 28.0940280854702, 35.08767440915108, 57.563916742801666, 63.75873953104019, 77.25205108523369, 6.866276683285832, 0.6028092128690332, 0.24420249072136357, 0.0923286702891346, 0.1022911122709047, 0.1351637940388173, 0.15797882369952276], [0.01785773736628471, 0.07560668047517538, 0.0449683715851279, 0.03955403692089021, 0.08928397975978442, 0.05506826673808973, 0.1303926602122374, 5.513002574443817, 67.97607243061066, 53.21055494248867, 39.9458809196949, 12.647662181407213, 26.958550214767456, 35.68330004811287, 49.26075428724289, 69.416993111372, 60.034221187233925, 43.94013158977032, 0.4631244926713407, 0.05989418219542131, 0.1880035360227339, 0.3991928044706583, 36.84047855436802, 68.41737315058708, 64.15094688534737, 65.44012650847435, 61.846993714571, 65.75330570340157, 66.58483788371086, 64.5788799226284, 57.31522008776665, 60.345105305314064, 62.559364289045334, 62.958342880010605, 60.211667865514755, 59.81140874326229, 54.44337598979473, 53.46399374306202, 51.774539798498154, 50.55169701576233, 47.146562933921814, 45.88470384478569, 43.8280414044857, 43.31316143274307, 43.43209505081177, 42.2949680685997, 42.75857359170914, 42.31777064502239, 43.026839196681976, 43.988974168896675, 42.72709608078003, 41.01011261343956, 41.90215274691582, 41.21445044875145, 40.186503008008, 41.17095038294792, 43.70946876704693, 43.444372192025185, 41.77949532866478, 42.39972084760666, 39.2491465061903, 42.53308609127998, 42.41418667137623, 41.8008653819561, 42.152623906731606, 42.50964134931564, 44.99206714332104, 44.73068296909332, 44.9787450581789, 40.46391472220421, 45.54572023451328, 43.810326755046844, 39.62908811867237, 40.14294974505901, 40.10136477649212, 40.13500437140465, 37.1077486127615, 40.65335735678673, 39.73311893641949, 38.466038927435875, 38.41412231326103, 38.66593100130558, 40.678831189870834, 42.03506961464882, 43.50076116621494, 45.034161284565926, 42.71231107413769, 39.748124331235886, 45.064027681946754, 39.47126738727093, 40.20443804562092, 44.23758342862129, 42.629771903157234, 41.03479988873005, 41.15023389458656, 39.97277207672596, 40.28467074036598, 39.998090118169785, 40.03453016281128, 38.973706886172295, 39.649903401732445, 41.431639194488525, 40.862513333559036, 42.71381959319115, 43.67303632199764, 41.111202389001846, 40.25785557925701, 42.37657628953457, 39.257768243551254, 41.22606262564659, 39.934926107525826, 44.59799408912659, 42.67159625887871, 42.669673562049866, 43.010587468743324, 41.935362964868546, 41.259044855833054, 40.13370864093304, 41.22086450457573, 42.85069204866886, 41.309175565838814, 43.39874044060707, 42.07819350063801, 42.562458515167236, 40.588757023215294, 45.189603343605995, 42.985375821590424, 42.222331166267395, 42.74843193590641, 42.54681475460529, 39.79950897395611, 43.10284651815891, 41.95686221122742, 41.1459781229496, 42.60473124682903, 41.63320317864418, 43.308943659067154, 43.32651011645794, 41.64627827703953, 46.055766865611076, 49.552563428878784, 53.472949862480164, 55.54066210985184, 60.251318737864494, 61.111565977334976, 63.42467285692692, 59.94442440569401, 67.6382477581501, 62.568582594394684, 67.17112362384796, 63.10980275273323, 72.32137486338615, 64.17759865522385, 77.2815603017807, 13.40953839942813, 0.6277332035824656, 0.4465271614026278, 0.07691634105867706, 0.049247468923567794, 37.31742896139622, 68.1111703813076, 70.27152925729752, 52.845364138484, 95.42213648557663, 58.3314261585474, 13.56011101976037, 39.40683424472809, 44.877860471606255, 62.194234281778336, 10.809868946671486, 0.13552774325944483, 0.024524555701646022, 0.047659202391514555, 0.06363124455674551, 0.012007837158307666, 0.006752329054506845, 0.011641636447166093, 0.08042202403885312, 0.07436621774104424, 0.031883866467978805, 0.04769968283653725, 0.16107420291518793, 0.16997813450871035, 8.217900730669498, 78.3361329138279, 61.1490623652935, 46.95645913481712, 23.338929042220116, 23.871523663401604, 40.74346572160721, 58.01532872021198, 74.55625534057617, 68.2999138534069, 51.18355371057987, 0.5376589181832969, 0.0860916537931189, 0.0863640962052159, 0.658975780243054, 39.49421815574169, 72.780701816082, 67.6616545021534, 67.81939923763275, 65.41130885481834, 67.54610270261765, 68.04569229483604, 65.71241229772568, 60.97166508436203, 62.89416432380676, 65.78915297985077, 64.75180104374886, 62.28667952120304, 61.77368424832821, 58.77288267016411, 56.74420952796936, 52.85607196390629, 51.681877970695496, 50.81325598061085, 48.69468346238136, 48.38742054998875, 45.81069141626358, 45.892622619867325, 44.146578311920166, 44.65607397258282, 44.418693110346794, 45.656613484025, 45.63351832330227, 44.85408514738083, 43.19403022527695, 44.13500413298607, 43.226032108068466, 44.175810143351555, 44.68068905174732, 45.8330912142992, 45.62995411455631, 44.79819014668465, 45.12656852602959, 41.24850422143936, 43.97088333964348, 43.349358290433884, 42.51545883715153, 43.80123384296894, 44.45284187793732, 46.35998994112015, 47.63955608010292, 46.281987726688385, 43.144746869802475, 46.76507480442524, 46.07823126018047, 42.51168943941593, 42.59636789560318, 42.09914177656174, 40.93963019549847, 41.28012992441654, 42.40830458700657, 42.134753465652466, 40.493864715099335, 40.57559832930565, 40.94485491514206, 42.55268543958664, 43.87691058218479, 44.63670641183853, 47.68500544130802, 44.69268500804901, 43.193737640976906, 47.12252542376518, 41.806580275297165, 44.140411242842674, 45.98846487700939, 44.2267882078886, 44.22788254916668, 43.649868965148926, 41.820669919252396, 42.232545018196106, 42.10033871233463, 43.1749552488327, 40.26840381324291, 41.379031017422676, 42.0596656948328, 43.879589438438416, 43.749005645513535, 44.63265582919121, 42.07656338810921, 42.51376412808895, 42.532907500863075, 40.01476742327213, 42.8107675909996, 41.48534931242466, 45.938706547021866, 45.18957294523716, 43.48588116466999, 43.69434177875519, 43.193874433636665, 43.64227317273617, 42.966870814561844, 44.7799701243639, 42.811109572649, 44.74187336862087, 44.210437685251236, 44.11221295595169, 44.58884418010712, 43.39390330016613, 45.47568999230862, 45.41935421526432, 45.07463291287422, 43.717174753546715, 44.856612011790276, 43.479246720671654, 44.24075625836849, 43.34604486823082, 43.8640520721674, 43.19993890821934, 43.62501449882984, 45.613140016794205, 45.779267102479935, 44.86169993877411, 48.85799489915371, 50.35880036652088, 55.367630794644356, 57.63798236846924, 62.297634333372116, 63.00935514271259, 64.30553019046783, 63.88953611254692, 69.32304695248604, 64.94100049138069, 69.1216653585434, 66.93197965621948, 74.1631056368351, 66.26460626721382, 79.61814612150192, 15.755195282399654, 0.7444886479061097, 1.611028052866459, 0.1948620195616968, 0.10524252225877717, 38.2097502797842, 74.5510496199131, 72.91076123714447, 62.00061187148094, 76.78735122084618, 47.81468108296394, 18.949146196246147, 47.56856448948383, 51.426938250660896, 73.10880661010742, 13.702704068273306, 0.15018168662209064, 0.055837317268014885, 0.04073666037584189, 0.047466099276789464, 0.01837186202465091, 0.060389562058844604, 0.13251910626422614, 0.17913800315000117, 0.2329600221128203, 0.1821871762513183, 0.16889532620552927, 0.34397924377117306, 0.4709303128765896, 12.95471040531993, 91.32332682609558, 66.62073075771332, 56.76213316619396, 27.44092483073473, 38.52151595056057, 48.71519096195698, 64.38803896307945, 80.88286265730858, 74.03209626674652, 57.46897503733635, 0.7156396459322423, 0.31245776801370084, 0.9485046879854053, 0.9882154071237892, 39.271447509527206, 75.53569838404655, 70.43175905942917, 69.79461684823036, 67.97288060188293, 71.53954401612282, 70.29365167021751, 68.40199157595634, 62.10169404745102, 64.96774345636368, 69.57150042057037, 67.83756226301193, 65.56456223130226, 64.30236116051674, 60.59702418744564, 59.524854719638824, 56.71691179275513, 57.01063223183155, 52.40815579891205, 52.40559473633766, 51.66938044130802, 49.5108188688755, 49.376180693507195, 47.39176757633686, 49.06622372567654, 46.29295393824577, 48.804926946759224, 47.67941974103451, 46.21577247977257, 45.786520913243294, 46.86181381344795, 44.29755561053753, 45.435761734843254, 46.131591796875, 48.28809008002281, 49.140270352363586, 47.68980458378792, 47.6732412725687, 42.68646106123924, 46.294515654444695, 45.830172970891, 45.49862936139107, 46.14237181842327, 44.88354116678238, 49.646315798163414, 48.38525086641312, 47.34068691730499, 44.16927069425583, 48.142041116952896, 47.97583043575287, 45.538724809885025, 45.0681808590889, 43.494974076747894, 43.92055884003639, 42.47557997703552, 44.03936326503754, 44.856285229325294, 43.317778185009956, 44.50689397752285, 43.45074824988842, 47.89180554449558, 46.22816741466522, 48.11216711997986, 51.160230562090874, 46.51003248989582, 45.70833630859852, 49.792471155524254, 44.077908396720886, 45.571353659033775, 50.6083557754755, 48.430844619870186, 46.304368525743484, 46.15893512964249, 43.931699842214584, 45.22029049694538, 44.22117590904236, 46.702146381139755, 41.723212748765945, 44.845619201660156, 45.159520357847214, 46.526561602950096, 47.145586386322975, 47.74945378303528, 43.222635090351105, 43.46011474728584, 45.292068645358086, 40.64429484307766, 44.14313569664955, 41.92236386239529, 48.5889845341444, 45.934435576200485, 45.48891328275204, 46.657802760601044, 45.053095668554306, 46.091378554701805, 46.40126712620258, 46.61288917064667, 45.259105414152145, 45.610221773386, 47.31386795639992, 44.95488993823528, 46.600289046764374, 44.207067266106606, 49.480215311050415, 47.922120317816734, 46.15642346441746, 46.67169861495495, 48.58715683221817, 45.36152891814709, 48.11644569039345, 46.988651007413864, 45.28341270983219, 46.57497860491276, 45.87154895067215, 48.75150941312313, 49.24857974052429, 46.78024739027023, 51.436874717473984, 53.763337880373, 59.020830765366554, 60.66702023148537, 65.79857647418976, 65.84639310836792, 68.9649161696434, 65.12536659836769, 72.84601271152496, 66.67947560548782, 73.72930571436882, 70.58484524488449, 77.9617466032505, 67.30745270848274, 84.75379854440689, 17.95367371290922, 1.186865244526416, 2.414010940119624, 0.23150140506913885, 0.19648833229439333, 43.91491234302521, 80.4395480453968, 78.78542840480804, 72.52729341387749, 110.72143793106079, 69.63469102978706, 25.84069959819317, 60.57939313352108, 61.38128690421581, 86.15008682012558, 20.24418320506811, 0.4420202469918877, 0.206647755112499, 0.18246782681671903, 0.14387742412509397, 0.11588182518607937, 0.20333807333372533], [0.13901101337978616, 0.025629997653595638, 0.0909800172667019, 0.05475719925016165, 0.06454853908508085, 0.12719998543616384, 0.3150027111405507, 14.228564500808716, 69.1299869120121, 51.490907818078995, 40.01678891479969, 19.405458010733128, 48.59937697649002, 50.302061811089516, 51.48441016674042, 63.402151465415955, 62.99506410956383, 42.890981286764145, 0.07867566149798222, 0.11473050923086703, 0.24657086207298562, 1.0468885931186378, 28.843518868088722, 72.37872898578644, 58.856102004647255, 67.43932083249092, 62.03797906637192, 65.79767972230911, 60.71126885712147, 61.05255514383316, 61.3504059612751, 65.7565127313137, 59.33574266731739, 61.307327672839165, 56.362368017435074, 54.92267847061157, 53.05195905268192, 52.58325420320034, 49.02055397629738, 50.196020901203156, 47.099399864673615, 43.718333691358566, 43.915459513664246, 42.83766254782677, 42.663669884204865, 47.038242146372795, 46.316296085715294, 47.04350106418133, 46.399526819586754, 48.79402533173561, 50.51570154726505, 47.52393588423729, 41.7786555737257, 43.105840757489204, 42.52592347562313, 42.46285445988178, 41.133883371949196, 44.11795824766159, 43.11404071748257, 41.24428264796734, 40.42902499437332, 40.4255785793066, 40.691488310694695, 41.77246190607548, 41.08627192676067, 45.526504665613174, 46.288204193115234, 48.331396356225014, 45.840022042393684, 41.56433567404747, 41.37762889266014, 42.61416994035244, 43.851968720555305, 40.663062036037445, 39.22738507390022, 40.36371409893036, 40.22029459476471, 39.21035818755627, 39.65819455683231, 39.42797631025314, 37.159368842840195, 37.88735277950764, 39.105438217520714, 41.12729452550411, 41.09275437891483, 42.53115959465504, 43.675361797213554, 38.81776325404644, 42.24132254719734, 38.07659022510052, 40.51923215389252, 42.2231937199831, 43.98246891796589, 41.93828120827675, 41.16696819663048, 39.03006166219711, 39.55328218638897, 39.46890391409397, 39.517940282821655, 40.78517608344555, 39.71826173365116, 39.92934800684452, 41.71410843729973, 42.331544905900955, 41.27510279417038, 42.32665836811066, 42.680700570344925, 42.91250333189964, 38.119052946567535, 40.81259921193123, 40.85403598845005, 44.466407150030136, 42.24182792007923, 43.63636068999767, 42.05321364104748, 40.49858406186104, 40.9196812659502, 39.264611676335335, 40.13069160282612, 41.33340306580067, 42.832422628998756, 43.03978130221367, 42.817364037036896, 42.7257015556097, 43.87206584215164, 43.50554130971432, 42.299516424536705, 43.755575492978096, 41.785943582654, 42.81131096184254, 43.29633593559265, 43.77892903983593, 39.02655445039272, 44.44979444146156, 41.36178754270077, 45.70887207984924, 43.29086422920227, 46.348085179924965, 46.44289009273052, 49.745471477508545, 50.68001993000507, 54.782826974987984, 58.72806787490845, 61.541455909609795, 58.55478197336197, 63.87637361884117, 62.78420962393284, 64.37784031033516, 61.34746491909027, 68.66732373833656, 62.72230714559555, 68.902827501297, 66.83147504925728, 77.32785701751709, 13.353616800159216, 0.4383997537661344, 2.45338988956064, 0.09357515926240012, 0.17210627265740186, 21.650069765746593, 72.74730160832405, 65.88323593139648, 59.35452125966549, 56.97958029806614, 40.505150109529495, 14.554646853357553, 37.311398684978485, 40.27791850268841, 63.83668854832649, 20.357132144272327, 0.46848027559462935, 0.09461400273721665, 0.07581460798974149, 0.048503028010600246, 0.04251316153386142, 0.016127316157508176, 0.13639347336720675, 0.009943701825250173, 0.03684447059640661, 0.0825349852675572, 0.1438344834605232, 0.1274469870259054, 0.34694177855271846, 16.402750834822655, 80.89512079954147, 56.57181277871132, 49.00829963386059, 28.0159954726696, 51.811405420303345, 54.722303822636604, 58.683397471904755, 69.09050703048706, 69.38594117760658, 47.45998911559582, 0.12597728229593486, 0.16867155383806676, 0.3676425036974251, 0.9690275648608804, 32.93640464544296, 73.47313866019249, 61.13207347691059, 70.20330771803856, 66.21832475066185, 68.2140764594078, 63.60906556248665, 64.88028734922409, 63.236495554447174, 67.38097876310349, 62.12328068912029, 63.33343595266342, 60.8258593082428, 58.732464239001274, 55.141185745596886, 56.385341584682465, 52.62263908982277, 53.26567478477955, 50.92954494059086, 48.987921327352524, 46.94030240178108, 45.551723912358284, 43.78050975501537, 49.56204392015934, 48.17538432776928, 49.45140905678272, 49.66058023273945, 52.09127560257912, 53.29627834260464, 49.37814898788929, 43.86261194944382, 44.96935576200485, 44.07211750745773, 44.3127927929163, 44.01611611247063, 44.75203402340412, 45.299254059791565, 43.43860790133476, 42.57089406251907, 42.606714740395546, 44.93221275508404, 43.724420964717865, 44.47575084865093, 47.88065694272518, 49.68253165483475, 51.54706500470638, 48.25680635869503, 44.38329420983791, 43.749442622065544, 43.7779600918293, 45.724884420633316, 42.44175039231777, 40.67758485674858, 42.15795122087002, 41.70183889567852, 40.40586903691292, 41.65513180196285, 40.40248341858387, 41.096280589699745, 40.80042086541653, 41.42723523080349, 42.13410750031471, 44.58298869431019, 45.2630989998579, 45.905956104397774, 43.448000997304916, 43.95044803619385, 39.690876603126526, 43.4198597073555, 44.57370199263096, 44.15082648396492, 42.754105031490326, 41.49978093802929, 39.967665150761604, 40.80581657588482, 40.107596442103386, 42.47923918068409, 41.416170224547386, 41.58689126372337, 41.493800058960915, 44.094878286123276, 43.94433796405792, 41.566611751914024, 43.26570197939873, 41.99563913047314, 43.86850543320179, 39.91959013044834, 43.275406658649445, 40.95332086086273, 44.90709610283375, 43.05653840303421, 45.169973596930504, 44.08491902053356, 44.104936346411705, 43.00732724368572, 42.695569172501564, 42.863162979483604, 44.68806065618992, 44.94541324675083, 44.56189222633839, 44.44835811853409, 44.457333236932755, 45.402619913220406, 44.625227227807045, 44.6940453350544, 44.89237569272518, 42.147547379136086, 43.8602826744318, 43.67327570915222, 45.41156463325024, 42.25711070001125, 47.0322422683239, 42.68415078520775, 48.50950799882412, 45.58462634682655, 46.19480140507221, 48.93176034092903, 52.54962220788002, 52.37811081111431, 56.401152536273, 61.95062555372715, 63.198079615831375, 61.01624809205532, 65.07676720619202, 64.99267011880875, 65.16018033027649, 64.86919954419136, 71.07936590909958, 65.64868211746216, 72.67464950680733, 69.44550678133965, 79.90263685584068, 14.861363545060158, 0.47544328321237117, 3.091911901719868, 0.3006487141828984, 0.19452876556897536, 23.94237656146288, 79.44677531719208, 70.79680547118187, 64.96486321091652, 58.93816240131855, 47.59195603430271, 22.33732558786869, 44.582471922039986, 47.84358233213425, 76.45331114530563, 25.50630994141102, 0.3846519347280264, 0.025086127716349438, 0.02186412883020239, 0.023298383021028712, 0.06698708049952984, 0.03258544093114324, 0.30939860560465604, 0.1416413628612645, 0.1413080346537754, 0.18081620684824884, 0.1611579765449278, 0.2665221516508609, 0.6245810352265835, 23.187672458589077, 89.65425118803978, 64.02480125427246, 58.20744641125202, 31.91794529557228, 60.952837094664574, 65.31968057155609, 68.3799147605896, 75.21800503134727, 75.4793094098568, 53.02447892725468, 0.24019959848374128, 0.40322771295905113, 1.2339691794477403, 2.1954642422497272, 35.55670604109764, 70.94795376062393, 65.71713924407959, 71.62161201238632, 69.98868763446808, 69.49900031089783, 68.93422141671181, 65.47323793172836, 65.86379617452621, 69.28152278065681, 64.47360277175903, 66.0316027700901, 65.80467134714127, 60.73671609163284, 58.36430199444294, 58.51872190833092, 55.266168639063835, 55.882947742938995, 54.15456108748913, 48.52695666253567, 50.54148316383362, 46.6870041936636, 48.563271313905716, 51.4157060533762, 49.84429657459259, 51.96401283144951, 51.412609219551086, 54.4382044672966, 55.66458486020565, 50.246398597955704, 46.876260638237, 47.83252872526646, 47.28189267218113, 47.38692283630371, 46.74511067569256, 47.87717252969742, 48.085230365395546, 45.5953835695982, 44.43660154938698, 43.16206254065037, 47.330955639481544, 47.20579035580158, 46.14622861146927, 50.97885109484196, 52.220100089907646, 52.433971613645554, 50.294086039066315, 46.10575318336487, 45.20301662385464, 46.23939201235771, 50.56488610804081, 45.73305018246174, 44.02506463229656, 44.63609844446182, 45.32911665737629, 42.81454838812351, 44.440739527344704, 46.084630116820335, 42.17058554291725, 42.445766776800156, 44.83471758663654, 45.466521084308624, 47.88179308176041, 47.80363887548447, 48.38932044804096, 43.58783729374409, 46.6934410482645, 42.59478338062763, 46.302525624632835, 46.898174062371254, 47.0427905023098, 45.29031693935394, 45.718204379081726, 41.64715602993965, 45.78617513179779, 42.740057185292244, 44.450953379273415, 43.94176930189133, 43.84384095668793, 42.972942888736725, 46.33140407502651, 46.42982259392738, 44.473790153861046, 45.93471676111221, 42.78531655669212, 45.62955513596535, 40.57844437658787, 43.94977547228336, 42.894522696733475, 46.887044459581375, 45.22669695317745, 47.37649619579315, 46.10368609428406, 45.201762691140175, 45.40595233440399, 44.086507335305214, 44.356574043631554, 45.27508355677128, 48.15676152706146, 46.66567973792553, 46.804421693086624, 45.433877035975456, 48.18324990570545, 46.64778269827366, 45.74872054159641, 47.40683376789093, 44.2002884298563, 46.53013341128826, 45.76909124851227, 48.01527611911297, 43.33808049559593, 50.641885176301, 45.93719802796841, 51.59062586724758, 49.152463898062706, 48.875416964292526, 52.01536327600479, 54.42794121801853, 55.751995369791985, 61.8553114682436, 64.98312503099442, 67.60118454694748, 62.52092555165291, 67.92634069919586, 67.50495091080666, 67.40536585450172, 66.40235647559166, 73.63670468330383, 67.04603433609009, 75.75916439294815, 71.03747695684433, 81.02939799427986, 16.22458789497614, 1.6738681308925152, 8.593044150620699, 0.3754721616860479, 0.2857730764662847, 26.4248251542449, 85.98997101187706, 76.57285273075104, 73.74854028224945, 69.9346849322319, 52.77692601084709, 26.35693419724703, 56.57667651772499, 58.344223871827126, 88.92241805791855, 32.490779757499695, 0.6341011868789792, 0.15405238751554862, 0.20965475938282907, 0.10778481591842137, 0.1385934217250906, 0.16294018481858075], [0.07394121203105897, 0.04981949408829678, 0.04756815942528192, 0.03944743853935506, 0.1343083946267143, 0.08053025885601528, 0.20376112719532102, 17.73679845035076, 71.74479380249977, 50.2325065433979, 40.10166876018047, 17.664134949445724, 28.620712123811245, 40.882929638028145, 57.7935916185379, 65.73277920484543, 62.41186000406742, 42.037474885582924, 0.1735152697074227, 0.01878851300716633, 0.11369268991984427, 1.25219110166654, 14.245111662894487, 57.54603110253811, 62.465296536684036, 62.00343132019043, 64.20032903552055, 62.13418610394001, 60.19926533102989, 61.80536314845085, 63.82668748497963, 60.81811912357807, 56.961010694503784, 56.901312097907066, 53.60651269555092, 52.880432456731796, 51.81727610528469, 51.56901262700558, 50.26297710835934, 50.92265971004963, 48.57270620763302, 47.96621695160866, 45.07151708006859, 49.3569765239954, 55.393150225281715, 52.76211440563202, 54.11021746695042, 51.786657348275185, 52.8223829716444, 53.740402311086655, 52.44287073612213, 52.379417940974236, 46.41164056956768, 39.76721830666065, 41.39171093702316, 41.57034695148468, 43.803715109825134, 43.570316433906555, 42.117456793785095, 42.70846568048, 39.53904815018177, 40.47083415091038, 42.11295023560524, 39.62492734193802, 41.223235577344894, 39.85929876565933, 48.595368191599846, 49.59105536341667, 44.715043008327484, 40.64293451607227, 40.69839634001255, 42.189763113856316, 38.10882769525051, 40.394427850842476, 40.12277662754059, 39.451542645692825, 37.93297313153744, 38.975732177495956, 38.94902341067791, 39.3317236751318, 38.33857096731663, 38.31146702170372, 36.561592519283295, 38.11814099550247, 40.931825414299965, 40.82776039838791, 40.94610504806042, 39.74931746721268, 39.39548045396805, 38.54834631085396, 43.05030293762684, 40.347933545708656, 42.080978751182556, 41.72449707984924, 40.319058895111084, 40.18193565309048, 38.932520896196365, 39.020964950323105, 38.970731645822525, 41.39729663729668, 39.4344587624073, 41.88795670866966, 41.142706498503685, 42.96673782169819, 42.24279686808586, 42.02716983854771, 41.084626615047455, 40.260044261813164, 40.7505751401186, 40.64645692706108, 41.15698613226414, 42.33734339475632, 42.34345346689224, 42.58185267448425, 42.60140262544155, 40.28778277337551, 41.91503405570984, 41.52076341211796, 41.53970919549465, 42.0955091714859, 42.02422879636288, 43.14126245677471, 43.44448618590832, 43.37408736348152, 42.175380885601044, 40.97485430538654, 41.890213787555695, 41.54178388416767, 40.98864756524563, 42.65175752341747, 43.010340481996536, 42.24465876817703, 41.89136892557144, 42.02766381204128, 41.8069526553154, 43.770717680454254, 42.479603961110115, 44.673180654644966, 45.133685544133186, 50.08041970431805, 49.92415688931942, 55.5233958363533, 56.83326534926891, 60.178077667951584, 60.765488147735596, 62.42896668612957, 64.27405267953873, 67.19478875398636, 62.21352204680443, 67.64620453119278, 64.43717032670975, 69.1147269308567, 59.99726437032223, 75.44755831360817, 15.702755246311426, 0.35621381539385766, 0.5610955262091011, 0.23387593624647707, 0.22580168122658506, 15.394696276634932, 73.46463471651077, 63.71848829090595, 65.23654103279114, 49.20773193240166, 29.59866374731064, 9.194060750305653, 29.218691736459732, 42.65205390751362, 64.261764138937, 24.953762590885162, 0.581960859708488, 0.04744951969769318, 0.03182578228006605, 0.014870362902001943, 0.06220275128725916, 0.026209138159174472, 0.01938372657605214, 0.04180299300060142, 0.019098637967545073, 0.03042051823285874, 0.10485313963727094, 0.14124659966910258, 0.32116603979375213, 23.79823699593544, 78.96259009838104, 57.64599993824959, 50.50598546862602, 26.324637830257416, 41.26952849328518, 47.31957145035267, 63.449538722634315, 72.63273015618324, 69.43424418568611, 46.931969448924065, 0.15855483419727534, 0.22866654937388375, 0.09812824268010445, 1.548573060426861, 15.83026310428977, 65.25037989020348, 64.15322676301003, 63.91356602311134, 65.86389496922493, 64.92409139871597, 62.83020995557308, 63.16279470920563, 65.8958512544632, 63.81494611501694, 58.7459497153759, 58.87695528566837, 55.43613351881504, 56.800484508275986, 54.79326121509075, 54.831414967775345, 54.54257346689701, 52.7462350577116, 51.47996820509434, 50.159155279397964, 47.5494135171175, 52.53046363592148, 58.24151158332825, 53.395130038261414, 56.65781356394291, 54.28695358335972, 55.57494007050991, 56.62272244691849, 54.65341351926327, 51.97569340467453, 47.9460172355175, 42.09239713847637, 44.069803431630135, 43.08611981570721, 45.033929497003555, 45.798440873622894, 44.25444312393665, 44.121093079447746, 41.076001077890396, 42.4325966835022, 45.55920571088791, 42.00257755815983, 42.75426462292671, 42.514565885066986, 51.34159483015537, 52.41882562637329, 45.47985456883907, 44.26882915198803, 41.630300134420395, 43.617034927010536, 41.87326669692993, 43.5569753497839, 42.542289197444916, 41.342948153615, 40.028043910861015, 41.86787858605385, 40.79594470560551, 41.836636662483215, 39.546187967062, 39.42949242889881, 39.41358648240566, 42.32544623315334, 44.04090218245983, 42.06387586891651, 43.893181309103966, 42.873084247112274, 41.41616262495518, 42.336484640836716, 44.96597774326801, 43.13825301826, 42.29422710835934, 43.55354033410549, 41.94114625453949, 41.11775703728199, 41.60318098962307, 39.73949879407883, 41.38299040496349, 43.37668262422085, 40.2129951864481, 43.84317219257355, 43.71144086122513, 44.515352323651314, 43.88261787593365, 41.96588672697544, 41.4857292920351, 40.15934966504574, 42.309908866882324, 40.44317163527012, 40.90377151966095, 43.459001407027245, 44.11200016736984, 44.51047718524933, 44.302518144249916, 41.859883815050125, 43.56617085635662, 41.95660762488842, 43.3554607629776, 45.4423163831234, 44.57711040973663, 44.13047097623348, 43.8200656324625, 44.79352779686451, 43.627305775880814, 43.54426883161068, 43.49305897951126, 43.72283644974232, 44.36874859035015, 45.90333044528961, 44.110381454229355, 43.54714147746563, 44.29784819483757, 43.94586928188801, 44.90206137299538, 45.59441842138767, 45.255229622125626, 48.18947397172451, 47.508341521024704, 52.335435301065445, 52.134638875722885, 57.917719557881355, 58.843239694833755, 62.839344665408134, 63.83872523903847, 65.71884915232658, 66.97397500276566, 68.81119161844254, 65.76620981097221, 68.96018922328949, 66.93973883986473, 71.64630308747292, 61.08122080564499, 76.83806329965591, 17.33790535479784, 0.2683420164976269, 2.27235050406307, 0.6210372503846884, 0.2527251513674855, 15.99231205880642, 80.68175464868546, 69.3359662592411, 72.68357902765274, 52.013634368777275, 35.79653017222881, 15.296984519809484, 38.85067708790302, 52.16206580400467, 73.97400498390198, 31.661291867494583, 0.625359577825293, 0.07900352007709444, 0.021943475549051072, 0.08256027766037732, 0.04201257921522483, 0.020964378672942985, 0.2258674948825501, 0.09074321278603747, 0.18126514682080597, 0.19282670924440026, 0.1906089048134163, 0.25816295645199716, 0.37881969299633056, 29.588102214038372, 89.30871292948723, 64.37965661287308, 58.20300444960594, 29.904547333717346, 40.17315812408924, 53.4483727812767, 73.58782410621643, 77.74550020694733, 75.12630835175514, 51.79199606180191, 0.4745778499636799, 0.3084680117899552, 0.6158290954772383, 2.9934256989508867, 20.47530960291624, 63.30048032104969, 63.58066588640213, 66.58663138747215, 68.23629766702652, 66.21343821287155, 62.832125052809715, 64.389878064394, 68.31987798213959, 66.43618986010551, 62.47484162449837, 61.98254004120827, 59.71945367753506, 58.963670432567596, 57.378836274147034, 57.683522924780846, 57.4934571236372, 56.60437323153019, 53.63265909254551, 52.98238478600979, 49.95690353214741, 56.3408687710762, 62.41085305809975, 57.63729080557823, 59.08402517437935, 57.04285830259323, 59.904967322945595, 58.30286309123039, 57.844353094697, 55.78310430049896, 50.97350478172302, 44.11131240427494, 45.687958002090454, 45.8447489887476, 48.298030346632004, 48.08152936398983, 45.17907030880451, 47.615985944867134, 42.507730051875114, 44.212538972496986, 48.54240283370018, 44.505480453372, 44.39736105501652, 44.041882529854774, 53.12009319663048, 55.298102125525475, 46.68553747236729, 43.4921470284462, 42.1557891368866, 47.368189841508865, 42.860446125268936, 46.07212118804455, 44.09194864332676, 43.64636555314064, 42.838414907455444, 43.79150256514549, 43.52915324270725, 45.583976581692696, 42.56692707538605, 41.646722853183746, 41.96009583771229, 44.06827591359615, 46.383286491036415, 45.28097704052925, 46.94012761116028, 44.595927000045776, 44.22031715512276, 45.05790241062641, 49.302073270082474, 45.93268766999245, 45.949938744306564, 47.86221653223038, 43.90017293393612, 44.38721939921379, 42.34485559165478, 42.04365335404873, 43.3226153254509, 47.45574474334717, 42.52424016594887, 46.82870998978615, 45.41567221283913, 46.45146243274212, 45.75980454683304, 43.829698115587234, 43.86468283832073, 43.446978852152824, 42.86019913852215, 43.15712280571461, 43.94602507352829, 44.84130263328552, 47.13915333151817, 47.53520607948303, 47.491732612252235, 42.925145253539085, 46.794971600174904, 44.398884773254395, 47.09137849509716, 47.46011830866337, 47.09259822964668, 48.03574942052364, 46.09594210982323, 46.37721821665764, 45.89518368244171, 44.838319793343544, 45.61696261167526, 44.7984903305769, 46.50894574820995, 47.11392268538475, 46.16270452737808, 46.398808658123016, 47.18421511352062, 47.049295753240585, 46.08397275209427, 48.21539618074894, 48.88867825269699, 50.05048111081123, 50.426873713731766, 55.55807277560234, 56.034145429730415, 60.78000336885452, 62.38688014447689, 65.99916011095047, 66.30218625068665, 67.7819636464119, 69.39712777733803, 70.43940424919128, 65.79828009009361, 70.6746344268322, 67.79220029711723, 74.0366180241108, 63.79290729761124, 78.45326542854309, 19.933428280055523, 0.5674428481142968, 6.235311990603805, 1.3760859472677112, 0.4301243321970105, 18.845761343836784, 87.0020467042923, 73.72802898287773, 78.37774068117142, 65.64517110586166, 42.93754778802395, 17.23741214722395, 47.99411125481129, 61.00946165621281, 86.1731667816639, 42.64151707291603, 0.902728425571695, 0.1891166833229363, 0.07515201112255454, 0.2118208954925649, 0.10545876182732172, 0.15682874713093042], [0.027326022172928788, 0.021537867723964155, 0.045613579932251014, 0.06725475090206601, 0.12903058173833415, 0.08801169373327866, 0.1893505934276618, 19.130991138517857, 71.56483545899391, 51.02474883198738, 36.043000146746635, 20.303689911961555, 28.504622653126717, 40.406252816319466, 60.97222365438938, 62.29061610996723, 67.02878326177597, 36.34982988238335, 0.08007990138139576, 0.1276625512400642, 0.08377947044209577, 0.2156532570370473, 18.63463707268238, 40.573314651846886, 55.19183702766895, 60.73575474321842, 58.44112627208233, 62.242434695363045, 59.02094855904579, 63.48522260785103, 59.849794283509254, 61.20281048119068, 57.2458928078413, 55.85647456347942, 52.27419398725033, 54.3169529736042, 54.09988962113857, 52.845307141542435, 50.70691108703613, 52.69258193671703, 49.2845144122839, 50.77354811131954, 52.54583761096001, 55.4307796061039, 54.7736656665802, 63.31598348915577, 55.47749809920788, 56.56230188906193, 53.39577220380306, 56.69086039066315, 53.88743922114372, 55.40969453752041, 49.906727224588394, 43.92515279352665, 44.31932844221592, 41.28598541021347, 40.70863679051399, 40.23858681321144, 41.84405006468296, 41.14427961409092, 41.81778207421303, 38.53695072233677, 41.07966028153896, 38.913844898343086, 41.756244376301765, 40.00019520521164, 45.267696753144264, 45.385289043188095, 44.12424311041832, 42.554079964756966, 41.69507905840874, 39.84655424952507, 40.120397955179214, 39.44906137883663, 40.83931937813759, 40.96013389527798, 39.58045072853565, 37.92329125106335, 40.17007268965244, 39.489711597561836, 39.709776788949966, 39.23614740371704, 37.62121506035328, 40.083182752132416, 38.40453542768955, 41.85230702161789, 40.360058695077896, 39.97916713356972, 38.45776677131653, 37.5137834250927, 41.10170289874077, 39.90412496030331, 40.2301474660635, 39.69127178192139, 38.82779851555824, 38.15831243991852, 36.49628542363644, 39.34944212436676, 40.67720487713814, 39.3385861068964, 41.47746853530407, 40.10660469532013, 41.910846680402756, 41.36585332453251, 41.088494807481766, 42.486113011837006, 40.22953189909458, 40.963819697499275, 40.079656541347504, 40.641118213534355, 40.18905647099018, 45.252185985445976, 43.73805843293667, 43.08957003057003, 39.17894907295704, 39.83254060149193, 39.704981446266174, 41.204335391521454, 39.97008942067623, 40.82195430994034, 43.43303360044956, 42.17301361262798, 42.436814457178116, 43.10495160520077, 41.83767020702362, 41.51923209428787, 40.000696778297424, 42.2195915132761, 41.33838839828968, 42.46533952653408, 41.205665320158005, 40.427896454930305, 39.95990216732025, 40.804543644189835, 41.13209746778011, 41.655409187078476, 42.07314737141132, 43.6709426343441, 43.43701958656311, 46.032268926501274, 44.14872519671917, 48.6549261957407, 48.24656970798969, 54.84344132244587, 52.9372052103281, 62.11048677563667, 62.51493327319622, 66.30882069468498, 63.02879869937897, 68.58653247356415, 63.91463756561279, 73.74624520540237, 55.543739944696426, 73.65581005811691, 18.32335587590933, 0.2849239407805726, 1.7848214646801353, 0.36638857098296285, 0.1594278373522684, 8.806709535419941, 69.74580466747284, 65.58676064014435, 65.16618400812149, 53.18831853568554, 51.94709613919258, 20.448285453021526, 25.412882454693317, 35.566399320960045, 63.60155336558819, 33.814590722322464, 0.6672132632229477, 0.017675328599580098, 0.045991685619810596, 0.04784510296303779, 0.09286409273045138, 0.10421835104352795, 0.01750584619003348, 0.047059881035238504, 0.009347049417556264, 0.1261282796622254, 0.22687844844767824, 0.2544469339773059, 0.21026413684012368, 22.978202998638153, 79.9276015162468, 56.9563103467226, 43.27420212328434, 20.139369629323483, 24.622408971190453, 44.40572440624237, 66.94007322192192, 66.96788772940636, 73.35087642073631, 40.345668867230415, 0.12547490769065917, 0.035694720572791994, 0.3682204883079976, 0.4466011980548501, 20.776105262339115, 43.92417624592781, 60.292155146598816, 61.807802617549896, 60.463674142956734, 64.43808227777481, 62.400407418608665, 64.979507625103, 60.736476704478264, 61.696126610040665, 59.142572432756424, 56.23986259102821, 54.8559008538723, 55.27667887508869, 56.36758893728256, 56.70152261853218, 54.393078088760376, 54.11381207406521, 51.497090086340904, 53.58751751482487, 55.94615735113621, 56.620909944176674, 57.987597808241844, 65.12654453516006, 57.278172075748444, 58.57100710272789, 55.75568117201328, 58.876742497086525, 57.01192416250706, 57.92074799537659, 50.360054299235344, 45.18408603966236, 46.43159709870815, 44.02893282473087, 44.488297775387764, 41.99701085686684, 43.816794008016586, 42.224234864115715, 43.77713933587074, 39.79788266122341, 43.102762922644615, 42.523689195513725, 45.087609216570854, 42.15732425451279, 46.65336839854717, 49.2046806961298, 44.43506263196468, 43.25765401124954, 41.393667832016945, 40.16832858324051, 42.56162256002426, 41.76257103681564, 43.60221192240715, 42.801146507263184, 41.69610120356083, 40.59163726866245, 42.5424487888813, 40.66059596836567, 42.638416439294815, 40.61000168323517, 38.5795084387064, 41.87259793281555, 40.59470370411873, 44.090907499194145, 44.17668029665947, 41.54062494635582, 40.91784976422787, 38.57581503689289, 44.21353071928024, 43.92347328364849, 42.95120805501938, 42.09157258272171, 39.901936277747154, 41.03941284120083, 38.99722762405872, 41.96651369333267, 41.62314131855965, 40.80253355205059, 43.96992579102516, 42.42296040058136, 42.858576625585556, 42.99111731350422, 42.90271505713463, 43.00094358623028, 39.87107053399086, 42.54334554076195, 41.740224435925484, 42.27681644260883, 41.0413621366024, 45.987077951431274, 44.47694018483162, 45.60223840177059, 40.68530224263668, 42.219629511237144, 41.72246038913727, 44.00258123874664, 42.64055572450161, 42.833828553557396, 45.35190403461456, 44.12897385656834, 43.7496630102396, 43.53552170097828, 42.903680205345154, 43.75850513577461, 42.16861344873905, 43.800774067640305, 43.469257056713104, 44.360913410782814, 40.761548951268196, 42.56583273410797, 42.56583273410797, 43.23769748210907, 42.30681963264942, 45.67640662193298, 43.81846211850643, 45.35951882600784, 46.690321415662766, 46.57635413110256, 46.371864303946495, 51.35503090918064, 49.48631778359413, 56.13955557346344, 55.629421547055244, 63.5944477468729, 64.59743812680244, 68.21734428405762, 64.43325653672218, 70.45297712087631, 64.98772278428078, 73.93245801329613, 61.04732662439346, 75.64954787492752, 18.876171112060547, 0.23748750885715708, 2.89820637088269, 1.1205102363601327, 0.15369522152468562, 9.389450065791607, 74.64650049805641, 71.11645951867104, 71.26729622483253, 59.451598450541496, 46.89533181488514, 20.354859866201878, 36.89548060297966, 45.295412465929985, 71.72625079751015, 42.10582561790943, 0.7294567732606083, 0.10260190887493081, 0.02450231353577692, 0.042523254742263816, 0.045591753369080834, 0.04350710878497921, 0.12750923837302253, 0.16006172052584589, 0.139014546002727, 0.2899225428700447, 0.34034179989248514, 0.37072390085086226, 0.3914506605360657, 30.337591096758842, 91.4698089659214, 65.2687557041645, 52.744840532541275, 29.78222619742155, 36.9786087423563, 55.69161280989647, 74.30492922663689, 72.65530854463577, 80.7740668952465, 44.272959530353546, 0.21256460167933255, 0.2784544910537079, 0.32345224055461586, 0.7934868999291211, 23.586804941296577, 47.645198777318, 57.94549226760864, 60.548124611377716, 62.01019875705242, 66.99077770113945, 65.14365881681442, 68.3860856294632, 66.08606904745102, 66.38623014092445, 62.71512933075428, 59.74635623395443, 58.812590539455414, 58.9891404658556, 61.3238225877285, 58.99135574698448, 55.89017115533352, 57.90076486766338, 55.77065236866474, 55.65095119178295, 59.77344498038292, 60.645399391651154, 60.703703463077545, 70.51878958940506, 60.90212121605873, 61.87843702733517, 58.15424546599388, 61.108442544937134, 59.485872611403465, 60.60465797781944, 54.658246859908104, 47.92230650782585, 51.582224518060684, 47.668252140283585, 45.326316207647324, 44.34602200984955, 46.97212189435959, 44.74590875208378, 46.356437131762505, 43.232556357979774, 45.41880324482918, 44.143755063414574, 47.17370107769966, 43.25579971075058, 48.98057632148266, 49.57969397306442, 47.11949698626995, 44.91358235478401, 41.07261925935745, 41.905640959739685, 43.597766160964966, 41.878791600465775, 45.71678325533867, 45.13166405260563, 44.75277878344059, 42.008653432130814, 44.54362280666828, 43.481537997722626, 45.6970889121294, 44.2789214104414, 42.199194207787514, 44.38664563000202, 43.44638608396053, 47.20119260251522, 47.68081046640873, 44.83131676912308, 44.0851242095232, 41.98772795498371, 46.147528141736984, 44.190876334905624, 46.22477039694786, 41.9636220484972, 43.88194911181927, 43.093115240335464, 40.893109291791916, 44.12720315158367, 42.47555337846279, 42.317858040332794, 45.14402098953724, 43.17191161215305, 44.612501710653305, 45.0699857622385, 43.305299654603004, 43.867445290088654, 41.7386095225811, 42.423188388347626, 43.4649670869112, 42.51107007265091, 41.49184696376324, 47.74348430335522, 46.75049878656864, 47.73168593645096, 42.31481820344925, 44.312712997198105, 43.40913288295269, 45.94855181872845, 46.38188436627388, 44.75169964134693, 47.806663513183594, 45.62501057982445, 45.34062623977661, 47.8413100540638, 45.94691790640354, 45.509929955005646, 43.7283119559288, 46.69685326516628, 46.53388760983944, 46.208549067378044, 44.911785051226616, 45.62063321471214, 45.16789510846138, 45.44722571969032, 45.535320192575455, 46.890243887901306, 46.8206088244915, 47.352891862392426, 49.669186770915985, 49.580237343907356, 49.049576818943024, 54.54471655189991, 53.42325232923031, 59.71097633242607, 58.44827748835087, 67.2105199098587, 69.86541464924812, 73.28716143965721, 69.31960433721542, 73.9012160897255, 68.12640756368637, 79.39712718129158, 61.36020943522453, 78.39904993772507, 21.336491592228413, 0.5214742210227996, 7.862875806167722, 2.1940077329054475, 0.24202676606364548, 10.595046523958445, 84.83196035027504, 75.44856905937195, 78.37625116109848, 70.08074149489403, 67.72326439619064, 30.89375015348196, 43.19234311580658, 53.692467883229256, 85.04233986139297, 56.23566001653671, 1.2884766608476639, 0.36185621574986726, 0.16433696611784399, 0.16477189434226602, 0.22489287686767057, 0.16817538358736783], [0.0513507525465684, 0.027588905722950585, 0.04248785429808777, 0.09579830715665594, 0.07135878302506171, 0.20702014997368678, 0.19223609328037128, 27.631712593138218, 68.43941196799278, 45.10321117937565, 38.38375434279442, 34.85063172876835, 62.62650288641453, 40.42337089776993, 61.2281247228384, 66.21131792664528, 67.55757048726082, 37.87873484194279, 0.12659121653996408, 0.09770027580088936, 1.0071759740822017, 0.4480650695040822, 11.425743699073792, 56.7902060598135, 48.08371804654598, 61.707556396722794, 59.53207053244114, 61.29031218588352, 64.41250205039978, 64.79552909731865, 56.97203390300274, 59.11813594400883, 57.83901438117027, 58.22907865047455, 60.6777698546648, 55.11846676468849, 55.61791576445103, 54.672663286328316, 53.20502623915672, 52.42475710809231, 53.28397460281849, 54.281223490834236, 54.17572595179081, 54.75495547056198, 59.65773358941078, 37.131113559007645, 43.71107988059521, 53.55321295559406, 52.89834849536419, 57.54087097942829, 55.07111370563507, 55.29754355549812, 46.570730432868004, 39.91216152906418, 40.75553007423878, 40.32907135784626, 39.99988742172718, 40.573983415961266, 41.47122547030449, 40.9810745716095, 42.42394834756851, 41.19045853614807, 39.46657843887806, 39.4341129809618, 40.405086278915405, 38.74720484018326, 42.658517360687256, 44.028556644916534, 41.68353907763958, 39.89332973957062, 41.528769582509995, 41.97181820869446, 39.47040103375912, 42.76053808629513, 40.871670842170715, 42.23664499819279, 37.421178594231606, 38.032615184783936, 38.24455261230469, 40.038592144846916, 39.451774433255196, 39.6912831813097, 37.222430258989334, 38.76398853957653, 37.845254838466644, 40.91975726187229, 40.2679668366909, 40.55898182094097, 38.972411155700684, 39.572075977921486, 39.79211837053299, 40.889111906290054, 41.79535947740078, 39.945386946201324, 38.340421468019485, 38.88578720390797, 38.89118671417236, 39.9568585306406, 39.84249606728554, 39.6127337962389, 40.43198883533478, 41.46844781935215, 40.99647134542465, 41.12263597548008, 40.88818095624447, 39.41042885184288, 38.29244144260883, 38.88783149421215, 39.58624541759491, 40.7032410800457, 40.5203340947628, 42.97065541148186, 41.27698749303818, 41.97542421519756, 38.83547030389309, 39.91881877183914, 38.645560294389725, 41.12380251288414, 39.53339025378227, 41.24325670301914, 42.42615602910519, 43.106775507330894, 41.75800748169422, 39.764193668961525, 39.856034740805626, 40.32245971262455, 40.638743340969086, 42.74099953472614, 45.8301767706871, 48.84114280343056, 46.34917572140694, 46.43092833459377, 44.05224457383156, 43.32643412053585, 42.61669680476189, 43.269851356744766, 42.682475075125694, 43.029814437031746, 41.72352813184261, 43.84049333631992, 43.72586868703365, 43.092317283153534, 43.8339576870203, 46.16075903177261, 45.08871115744114, 50.78704118728638, 52.58224345743656, 63.72656285762787, 59.49620045721531, 65.64569547772408, 61.044138595461845, 71.01134195923805, 62.35620059072971, 75.72174400091171, 26.68788693845272, 0.33782719576265663, 1.7611389979720116, 0.3704701754031703, 0.17454611283028498, 4.433991573750973, 65.46331286430359, 65.76814770698547, 69.79090824723244, 49.849984869360924, 46.39102667570114, 20.954323299229145, 14.872215762734413, 32.69153818488121, 57.21471928060055, 47.829500287771225, 0.5526893679052591, 0.13147736841347069, 0.008232413183577592, 0.042645675712265074, 0.04082068262505345, 0.04102153376152273, 0.05491132476890925, 0.10238195114652626, 0.05481830026837997, 0.04703301900008228, 0.06380264356266707, 0.12048156742821448, 0.08674259894178249, 33.90244200825691, 78.54641363024712, 52.56909616291523, 47.68536642193794, 34.14703108370304, 39.32919681072235, 42.31523618102074, 69.5553968846798, 70.89050084352493, 73.73435944318771, 40.70103719830513, 0.446641719317995, 0.09716699074488133, 0.34412630775477737, 0.6039284309372306, 13.853031601756811, 58.90114478766918, 51.376575753092766, 62.7449045330286, 60.25413818657398, 62.889406979084015, 65.62491059303284, 63.71119648218155, 59.07130725681782, 62.29684017598629, 59.773482978343964, 59.96984884142876, 61.49066783487797, 55.887055322527885, 58.579157665371895, 56.44270710647106, 56.273145005106926, 53.44483517110348, 57.03628845512867, 56.769151389598846, 57.563050389289856, 57.1196635812521, 63.4596461802721, 38.61668944358826, 47.71007649600506, 54.020143300294876, 55.62117598950863, 58.7018758803606, 56.731248423457146, 57.51374043524265, 49.061094000935555, 42.881052419543266, 44.218823835253716, 43.312245681881905, 42.68089056015015, 42.60717071592808, 44.247618690133095, 43.309236243367195, 43.355988934636116, 44.133621007204056, 43.40102031826973, 41.48286424577236, 42.397300377488136, 41.430514454841614, 44.18585680425167, 46.66570633649826, 42.255864366889, 41.854111924767494, 44.493374302983284, 43.49623180925846, 41.958781108260155, 43.38827960193157, 43.57954993844032, 43.025817051529884, 40.34225285053253, 41.014182195067406, 40.04458822309971, 42.27047838270664, 41.857087165117264, 41.985630467534065, 39.270588755607605, 41.1799369007349, 40.742458775639534, 42.25190117955208, 42.59916074573994, 41.7365538328886, 41.02719649672508, 41.75065487623215, 41.82851269841194, 42.610434740781784, 42.604545056819916, 42.93782137334347, 40.23112401366234, 40.39909020066261, 44.112988114356995, 42.562173530459404, 43.60460199415684, 41.49923376739025, 42.408422380685806, 42.49602288007736, 41.962083131074905, 42.51957781612873, 39.861814230680466, 39.5819516479969, 39.44904997944832, 39.01730194687843, 40.77452905476093, 40.72635143995285, 41.47289738059044, 43.086503595113754, 43.35881598293781, 43.64239476621151, 42.074906677007675, 42.129950523376465, 39.77042153477669, 42.69419364631176, 41.99926033616066, 42.72227793931961, 44.11119841039181, 44.0788621455431, 43.04433725774288, 42.80719958245754, 42.98695273697376, 41.87622673809528, 42.49525152146816, 45.79643078148365, 48.42957928776741, 50.011662393808365, 48.07820834219456, 50.22078417241573, 45.480283945798874, 44.023248329758644, 43.72043877840042, 44.5282868295908, 44.57668103277683, 46.25466339290142, 43.95118899643421, 45.60135304927826, 46.598214358091354, 46.23021550476551, 45.942848324775696, 48.6128244549036, 47.231518775224686, 52.47335650026798, 54.51252467930317, 65.59654891490936, 63.4551016241312, 69.27887812256813, 63.66386242210865, 74.04268249869347, 64.46976497769356, 78.42057198286057, 28.0654726177454, 0.2845961193088442, 3.696739934384823, 1.828268808312714, 0.22991265985183418, 5.063226409256458, 71.8257674574852, 70.85615828633308, 74.48389202356339, 57.032921835780144, 48.236272260546684, 24.61171444505453, 21.81549198925495, 36.99689716100693, 66.87473952770233, 54.91854049265385, 0.9856358799152076, 0.0595181842072634, 0.05223626831138972, 0.04727514839032665, 0.022656584842479788, 0.045955557870911434, 0.1459608256118372, 0.22031309839803725, 0.12190443521831185, 0.17052527546184137, 0.21839816443389282, 0.3390813065925613, 0.27857151289936155, 46.19667090475559, 90.58814987540245, 59.52171228826046, 53.85226830840111, 48.11183653771877, 76.74301519989967, 54.27154541015625, 76.44356086850166, 76.98873281478882, 79.8920202255249, 45.66478304564953, 0.6002465472556651, 0.3744105639634654, 2.2169034043326974, 1.1014658957719803, 15.80982020124793, 63.01163502037525, 55.58187089860439, 65.67711219191551, 60.85482135415077, 65.03438428044319, 68.05384665727615, 67.990602850914, 61.84400327503681, 63.63816440105438, 62.73206502199173, 63.184514343738556, 65.58958008885384, 58.27610872685909, 61.587042063474655, 59.1992349922657, 58.8237239420414, 54.59724113345146, 59.75861057639122, 59.576254561543465, 61.328526735305786, 59.50158856809139, 66.07402369379997, 41.83000601828098, 49.363147392868996, 57.18402452766895, 58.04555989801884, 62.91998013854027, 61.05896160006523, 59.31490458548069, 53.48817564547062, 44.52840842306614, 46.667382046580315, 46.162879317998886, 44.23368863761425, 44.834538996219635, 46.76177278161049, 44.139100313186646, 45.808381140232086, 47.06710159778595, 43.39614897966385, 44.02496963739395, 43.94432656466961, 45.849342942237854, 46.87949426472187, 48.93582612276077, 44.78977359831333, 42.508262023329735, 43.79590652883053, 43.40924307703972, 41.14619851112366, 44.44239243865013, 43.5895662009716, 45.41860185563564, 41.81408867239952, 43.51309530436993, 40.864021852612495, 45.1418437063694, 44.334090650081635, 45.63369691371918, 40.491550639271736, 43.44917893409729, 42.51630999147892, 45.98295897245407, 44.68903720378876, 45.574895069003105, 45.28874762356281, 45.84373824298382, 44.86782521009445, 45.419316217303276, 46.45460106432438, 45.79435609281063, 42.37391263246536, 40.87146945297718, 46.28987990319729, 43.689322248101234, 44.21577259898186, 42.93814815580845, 45.32077610492706, 44.405652210116386, 44.478308111429214, 43.69444437325001, 41.20147414505482, 40.14601618051529, 39.0249927341938, 39.433835595846176, 39.58384394645691, 42.33049236238003, 41.83174252510071, 44.31527025997639, 44.15202721953392, 46.82458721101284, 42.95837827026844, 45.0273672491312, 42.64811351895332, 44.65456545352936, 43.98017004132271, 44.74807843565941, 46.415520161390305, 47.46432468295097, 45.38899764418602, 44.997827634215355, 46.14456050097942, 43.9719320833683, 44.49297532439232, 47.29299947619438, 51.931843757629395, 52.55936108529568, 49.96745176613331, 52.181596755981445, 48.75493302941322, 47.469864785671234, 46.36114127933979, 46.62755258381367, 47.744597643613815, 48.6808256059885, 45.547848120331764, 48.60821910202503, 48.53540740907192, 47.49490164220333, 49.841952100396156, 52.659774497151375, 49.413749277591705, 56.31522014737129, 56.53290666639805, 69.6621635556221, 67.64138638973236, 74.56702396273613, 67.27973699569702, 78.47022771835327, 67.21116587519646, 82.7076843380928, 29.007987342774868, 0.4876262607285753, 7.452478827908635, 2.7422256907448173, 0.5431765783578157, 6.195570398122072, 77.91819334030151, 77.33205959200859, 81.38669282197952, 65.78047424554825, 65.32705217599869, 28.856377378106117, 27.255249693989754, 49.24014799296856, 74.92002502083778, 66.59793198108673, 2.2434623166918755, 0.33143914479296654, 0.19907474663341418, 0.1857709331670776, 0.11588049674173817, 0.14828823041170835], [0.055238467175513506, 0.09546900881105103, 0.011154397016071016, 0.044585664581973106, 0.051527769610402174, 0.051120196949341334, 0.06780860829167068, 31.368175595998764, 71.721843034029, 44.89004261791706, 39.676118195056915, 14.95888626202941, 55.81025384366512, 52.65172652900219, 59.11290742456913, 64.99041303992271, 64.6621410548687, 38.98154966533184, 0.08224570352467708, 0.06987554152146913, 0.6989039189647883, 0.2201837272150442, 5.713444193825126, 48.48965026438236, 60.67564196884632, 56.761680990457535, 58.47210220992565, 61.02228216826916, 58.061671033501625, 60.43967463076115, 61.72635778784752, 61.443903744220734, 60.23884400725365, 62.03697592020035, 60.46414531767368, 57.78631500899792, 60.62543146312237, 57.48944453895092, 56.91379442811012, 54.11048345267773, 54.017836824059486, 53.89231815934181, 57.11088985204697, 53.55545103549957, 60.92568755149841, 36.347462609410286, 47.33545459806919, 57.13905394077301, 54.42712806165218, 56.50821939110756, 56.18593208491802, 52.033013328909874, 43.94182249903679, 42.16570280492306, 46.94817557930946, 45.86491450667381, 42.54007011651993, 40.69484733045101, 40.52076727151871, 39.14820112287998, 39.094472005963326, 42.07421511411667, 41.2535085529089, 39.19110842049122, 39.293801710009575, 38.03988419473171, 42.15084560215473, 42.96328380703926, 40.89331828057766, 41.47327356040478, 41.87289051711559, 43.53386119008064, 43.42207118868828, 40.66461995244026, 42.33469493687153, 43.150492161512375, 37.69568346440792, 38.24446141719818, 37.692282646894455, 38.83100174367428, 38.03527504205704, 37.021025866270065, 39.512392580509186, 38.94749969244003, 39.49103392660618, 38.47821347415447, 38.8907041400671, 38.97195138037205, 38.68622191250324, 39.244734942913055, 40.40664419531822, 40.66976107656956, 39.417070895433426, 39.384407848119736, 38.65663670003414, 38.9175420999527, 39.212216287851334, 38.53442765772343, 40.424362644553185, 41.25701196491718, 41.53472386300564, 41.24404326081276, 41.006472408771515, 41.09162583947182, 38.862650245428085, 38.12784567475319, 37.43636637926102, 36.75268046557903, 39.76467624306679, 39.124706983566284, 38.730060160160065, 40.90533323585987, 42.7239840477705, 39.50069680809975, 40.21622881293297, 39.945489540696144, 40.364215672016144, 40.555489808321, 40.91053515672684, 41.54676541686058, 40.636942237615585, 41.15864284336567, 41.864052191376686, 41.54059074819088, 40.23441843688488, 41.737344190478325, 44.728798270225525, 50.6160731613636, 54.65922340750694, 55.10117769241333, 55.30808798968792, 55.60628458857536, 52.05005921423435, 52.22590997815132, 52.494908943772316, 49.90731239318848, 49.728433191776276, 47.07161955535412, 47.29733884334564, 46.64081387221813, 44.11103121936321, 46.08604744076729, 46.52038313448429, 46.90432593226433, 43.95893298089504, 45.016393437981606, 44.259477853775024, 46.78674504160881, 51.1460155248642, 61.22196525335312, 63.87216344475746, 67.00884193181992, 59.65392239391804, 73.23043048381805, 38.816053345799446, 0.19734799163416028, 1.85929307481274, 0.8080801949836314, 0.03645062395662535, 1.8332016561180353, 60.071865767240524, 67.48437881469727, 68.00251141190529, 56.58229261636734, 50.55481664836407, 23.92922356724739, 24.50545694679022, 38.56252335011959, 51.457773596048355, 56.719921231269836, 2.7563587948679924, 0.17503207112895325, 0.05552517366595566, 0.015134315144678112, 0.07317264389712363, 0.10808217222802341, 0.049406225443817675, 0.08422319311648607, 0.026842622428375762, 0.03590263324440457, 0.07389734368189238, 0.09000174788525328, 0.11022094535292126, 37.12050832808018, 80.11381432414055, 50.51860839128494, 47.88557007908821, 18.257530108094215, 48.085101172327995, 52.74767518043518, 66.65147110819817, 70.33165723085403, 72.03985556960106, 43.114724680781364, 0.035866238322341815, 0.06373986529069953, 0.9690703719388694, 0.7116544316522777, 6.2418685387820005, 51.0185057669878, 63.11318077147007, 58.520948588848114, 60.11812448501587, 62.11657024919987, 61.034088134765625, 62.027035653591156, 63.2760514318943, 62.659523114562035, 61.99600271880627, 64.33038085699081, 63.40005777776241, 60.21300919353962, 60.44736161828041, 61.05283632874489, 57.856964617967606, 56.51635095477104, 56.298808827996254, 56.588942259550095, 59.5678836107254, 55.08019141852856, 59.37544293701649, 38.02071802318096, 49.711976274847984, 58.30057941377163, 59.03440743684769, 57.68647536635399, 58.48084934055805, 55.34513600170612, 45.03090485930443, 44.450721591711044, 48.539233803749084, 47.252356857061386, 46.22733525931835, 42.320293709635735, 43.26458103954792, 41.35819673538208, 42.897756323218346, 44.096128419041634, 41.631329879164696, 38.53722810745239, 41.91831327974796, 41.141737550497055, 43.802309185266495, 43.902939185500145, 41.984969303011894, 41.77624270319939, 41.043235436081886, 44.83499877154827, 43.37613545358181, 41.27101041376591, 43.28938990831375, 44.735083132982254, 41.716627702116966, 40.96741430461407, 39.70202900469303, 41.1571229249239, 39.70289535820484, 41.211950182914734, 41.296708434820175, 39.988203048706055, 41.37923240661621, 40.2453276515007, 41.31282716989517, 41.3183368742466, 40.180005356669426, 40.10942034423351, 41.99438899755478, 40.84199823439121, 40.8380426466465, 42.04032853245735, 40.45760706067085, 39.14139188826084, 42.874980345368385, 41.29771538078785, 41.72672376036644, 42.741653099656105, 42.79338352382183, 40.90186782181263, 41.78507722914219, 41.349206417798996, 38.9633372426033, 38.28556001186371, 36.81468553841114, 37.61632852256298, 41.16968125104904, 37.791635915637016, 40.38808599114418, 41.758653447031975, 44.50610361993313, 40.44484734535217, 43.22648048400879, 40.69480173289776, 41.53229579329491, 42.06667251884937, 42.835808247327805, 43.26496481895447, 44.28808271884918, 41.22001715004444, 44.466148763895035, 42.32896104454994, 41.78999036550522, 44.325997084379196, 45.66626116633415, 53.48903439939022, 56.56812697649002, 57.97765374183655, 56.65678381919861, 57.92569912970066, 55.35199083387852, 55.65863437950611, 53.0890716612339, 52.92110547423363, 52.0802865922451, 50.13351805508137, 49.04580362141132, 52.032466158270836, 46.660341024398804, 48.079553470015526, 47.95050859451294, 49.03336688876152, 46.05809614062309, 47.291475757956505, 46.374873742461205, 49.872160479426384, 53.18626284599304, 66.24612405896187, 65.75306251645088, 70.84976702928543, 63.38436082005501, 78.45706522464752, 40.31224586069584, 0.16253448236966506, 3.09687752276659, 1.8376642791554332, 0.06649469520198181, 2.1801767125725746, 65.75961336493492, 73.48447725176811, 74.31480869650841, 63.834659457206726, 51.53238259255886, 26.368234790861607, 26.68441392481327, 43.736219331622124, 60.82883454859257, 67.14480623602867, 3.716472275555134, 0.3646565764211118, 0.0918393797473982, 0.05028017483709846, 0.008192961540771648, 0.0637767203443218, 0.15726596117019653, 0.19117768679279834, 0.14407392998691648, 0.12202815865748562, 0.14569578983355314, 0.16486438078572974, 0.2873762045055628, 47.19627566635609, 89.8200286924839, 61.42830178141594, 55.088558569550514, 24.33519758284092, 68.72015610337257, 66.1947052180767, 70.89786484837532, 77.33239397406578, 78.54306221008301, 48.866601437330246, 0.29408052912913263, 0.30776398081798106, 2.3961967835202813, 1.7132200067862868, 8.265955802053213, 54.720434322953224, 64.28239703178406, 60.45205056667328, 61.79145589470863, 63.71918365359306, 61.830259412527084, 64.28776994347572, 65.24163275957108, 66.83692395687103, 65.75971975922585, 65.94399467110634, 66.06919795274734, 61.837539821863174, 65.21600693464279, 63.65810193121433, 60.18573045730591, 59.563992619514465, 59.70031030476093, 58.643283024430275, 62.874701768159866, 57.801157012581825, 61.977368518710136, 36.0512039065361, 49.11571986973286, 61.13299302756786, 58.631750643253326, 59.79660093784332, 62.739170640707016, 58.0944062769413, 48.83391559123993, 47.730344608426094, 51.89576469361782, 49.02282625436783, 48.27562674880028, 45.191841423511505, 44.99452941119671, 42.302001491189, 44.237397238612175, 46.39059729874134, 45.3721721470356, 41.148159205913544, 44.11887399852276, 43.25198091566563, 46.104472652077675, 46.41709707677364, 41.02656573057175, 43.06521713733673, 42.970875799655914, 44.857546761631966, 43.060588985681534, 41.22876048088074, 46.40654504299164, 45.78663110733032, 43.0657909065485, 42.44991235435009, 42.0691803842783, 43.01050767302513, 42.097545862197876, 43.99275116622448, 44.73527692258358, 43.68871808052063, 44.597367122769356, 41.709750071167946, 42.71342061460018, 45.07035054266453, 44.10494014620781, 44.4053216278553, 43.935412243008614, 45.038398057222366, 42.786141112446785, 45.95482148230076, 43.462208434939384, 40.83328150212765, 44.4099497795105, 42.785042971372604, 44.65296573936939, 45.242709293961525, 45.524866953492165, 44.45360563695431, 43.40304180979729, 44.238305389881134, 39.382770135998726, 38.701402097940445, 37.59675197303295, 36.20329834520817, 41.91124565899372, 39.17138747870922, 40.94640143215656, 43.64134222269058, 46.10770247876644, 42.58904568850994, 43.524050116539, 42.51415550708771, 45.78355707228184, 43.83056066930294, 46.51539400219917, 45.49018241465092, 46.803410947322845, 44.31523606181145, 47.562674805521965, 44.917572140693665, 44.28506188094616, 46.285460740327835, 48.927090391516685, 56.0560854524374, 59.1368043422699, 60.84469109773636, 60.45619234442711, 60.16425780951977, 57.412418872117996, 57.81156465411186, 56.06647029519081, 55.8220674097538, 54.144104048609734, 51.50591321289539, 52.99117751419544, 52.95791029930115, 49.566026106476784, 50.33278316259384, 51.956565231084824, 52.03367069363594, 49.239741414785385, 51.681080013513565, 49.68243665993214, 53.33713375031948, 55.87331525981426, 67.73610010743141, 70.79995930194855, 73.89235496520996, 65.55950850248337, 81.26374661922455, 44.58664409816265, 0.15630225272616372, 8.226858749985695, 4.178974907845259, 0.21895915386267006, 2.94087000656873, 71.3126277923584, 79.84490275382996, 80.99326953291893, 74.68539521098137, 63.905730843544006, 38.38438130915165, 38.548600897192955, 56.44313648343086, 68.63138526678085, 79.5888040959835, 6.00684117525816, 0.5801973980851471, 0.372758187004365, 0.23984462925000116, 0.16256494011031464, 0.2089988047373481], [0.038902791202417575, 0.05934034335950855, 0.0381506542180432, 0.02778793674224289, 0.1254042107029818, 0.02689005123102106, 0.14867144578602165, 32.43157513439655, 67.15885028243065, 48.43687489628792, 44.47594843804836, 23.13486099243164, 27.13195960968733, 42.15038202702999, 63.20655316114426, 66.23876765370369, 64.21644017100334, 44.53441970050335, 0.14405384747078642, 0.037261379475239664, 0.16623028874164447, 0.1699891034513712, 3.8427067268639803, 36.78967908024788, 63.357963636517525, 62.610019370913506, 58.21640633046627, 60.529927387833595, 63.61598499119282, 58.303011283278465, 58.93936313688755, 57.653835117816925, 60.30447028577328, 61.53752692043781, 60.82750841975212, 61.45069018006325, 57.210892885923386, 57.733053267002106, 55.5138735473156, 55.43181695044041, 56.3934313505888, 56.218503937125206, 54.31440331041813, 51.87629833817482, 53.142831176519394, 61.173202469944954, 57.87863105535507, 55.54994501173496, 55.168848261237144, 53.964799270033836, 50.588102862238884, 44.51250247657299, 42.02214650809765, 46.23515523970127, 45.044055953621864, 48.4569226205349, 49.3609207123518, 44.36446242034435, 40.56220784783363, 41.47264279425144, 39.621416330337524, 41.70678623020649, 42.40700125694275, 40.18390014767647, 41.671778708696365, 38.92382696270943, 39.946895465254784, 44.38692681491375, 42.48786851763725, 40.714127495884895, 39.366905987262726, 41.20982229709625, 45.14255806803703, 43.13755385577679, 40.517807230353355, 39.68993045389652, 40.31901329755783, 38.90028342604637, 39.23290237784386, 38.62432703375816, 39.09009464085102, 39.143230989575386, 37.865131571888924, 37.7886226773262, 38.87639030814171, 40.45629993081093, 40.02276599407196, 39.590512588620186, 38.931012377142906, 40.618308037519455, 41.22413992881775, 40.25088295340538, 39.37107056379318, 39.23328995704651, 39.00668151676655, 39.42799910902977, 38.40048864483833, 38.17877434194088, 40.1309347897768, 39.087799564003944, 42.44873821735382, 43.390597477555275, 40.1401074975729, 40.881694704294205, 40.5479472130537, 37.71940939128399, 38.431567177176476, 38.595668971538544, 37.3050644248724, 39.04682256281376, 39.58766274154186, 40.558419451117516, 41.64645306766033, 37.99134559929371, 40.306162387132645, 38.76978702843189, 39.86011952161789, 40.6743398308754, 41.763661578297615, 41.55652329325676, 41.803380846977234, 39.82244834303856, 40.9831340610981, 41.37617737054825, 40.01711569726467, 43.34495052695274, 44.95724581182003, 50.62191344797611, 55.80051876604557, 55.97979694604874, 49.588030725717545, 53.79321187734604, 56.319715306162834, 56.61921143531799, 57.46367432177067, 57.83970594406128, 58.22320036590099, 58.17329004406929, 57.19202309846878, 56.049982979893684, 53.566550239920616, 54.622000604867935, 53.70692990720272, 54.285080283880234, 55.307286232709885, 56.42735593020916, 55.09401127696037, 52.740269377827644, 46.0536427795887, 49.38883401453495, 56.96808971464634, 64.80989992618561, 64.96404245495796, 70.969278216362, 44.49509181082249, 0.05760619656939525, 2.208508704788983, 2.0185564225539565, 0.0622218875651015, 0.753953168168664, 50.997200310230255, 67.3071563243866, 72.64260202646255, 56.555200070142746, 58.32671441137791, 33.53591367602348, 20.515804030001163, 45.84270089864731, 47.71530121564865, 64.75917264819145, 6.423069890588522, 0.3412376611959189, 0.03399622284632642, 0.025425780877412762, 0.07708469725912437, 0.14333006052765995, 0.019189508384442888, 0.016913233848754317, 0.00777703368839866, 0.07274274743394926, 0.04809651662071701, 0.03240321770135779, 0.0242158426772221, 40.06530471146107, 76.91940173506737, 53.260750249028206, 50.35669527947903, 22.39351887255907, 38.072258457541466, 49.977422431111336, 68.2008607685566, 69.98475104570389, 68.88238459825516, 48.982195034623146, 0.18861212680349126, 0.08233881337218918, 1.5697875595651567, 0.9797492832876742, 4.449022617191076, 39.73769389092922, 62.379337549209595, 62.41864264011383, 60.77918641269207, 62.85987116396427, 63.7255597114563, 57.51751363277435, 59.95418608188629, 61.70109674334526, 61.4561352878809, 63.47117856144905, 62.2814130038023, 63.645490407943726, 60.07373906672001, 59.15839858353138, 59.87046517431736, 59.653569012880325, 59.28766004741192, 58.64186190068722, 58.027438670396805, 50.192616283893585, 53.8670989125967, 62.052254900336266, 58.896113857626915, 57.50317320227623, 55.34325510263443, 56.74764074385166, 52.21603810787201, 47.237940430641174, 44.16942648589611, 47.938508838415146, 46.9901367276907, 51.851177886128426, 50.83128981292248, 45.60547962784767, 42.838946878910065, 42.342237532138824, 41.94400370121002, 43.96525964140892, 44.469614177942276, 42.181281968951225, 44.25204165279865, 41.65982834994793, 41.38829492032528, 48.35187345743179, 42.87175431847572, 41.31289176642895, 40.62326677143574, 42.718801125884056, 45.2861637622118, 44.732271283864975, 41.76771976053715, 41.6995058208704, 42.431008368730545, 42.54465267062187, 41.73799015581608, 42.17842072248459, 41.08871139585972, 41.296415850520134, 42.47665911912918, 40.27137145400047, 41.4608596265316, 42.6235668361187, 42.53952294588089, 43.50246347486973, 40.34834012389183, 43.334121108055115, 42.439497113227844, 42.12197855114937, 40.54550014436245, 40.76888635754585, 40.250757560133934, 40.85795737802982, 40.356798470020294, 41.00993402302265, 42.268080711364746, 40.04191696643829, 44.28688198328018, 43.52326735854149, 41.428542360663414, 41.13266363739967, 39.96820472180843, 37.96540819108486, 38.39870274066925, 39.188695549964905, 37.649998515844345, 40.18519587814808, 40.333175137639046, 41.90015405416489, 41.680525839328766, 40.061307325959206, 42.42755435407162, 41.056397929787636, 42.491626515984535, 40.92551775276661, 43.79851318895817, 43.539986461400986, 45.03442347049713, 42.613075599074364, 43.32645691931248, 41.73011317849159, 42.02211230993271, 45.299630239605904, 47.14670352637768, 54.27439145743847, 57.487571239471436, 57.86115579307079, 53.17424789071083, 56.44466020166874, 58.91326993703842, 59.34318266808987, 61.29078336060047, 59.49181169271469, 60.70539057254791, 60.02706617116928, 59.56859037280083, 57.85373859107494, 55.337445214390755, 56.97161592543125, 56.48771949112415, 55.84325887262821, 59.413995668292046, 57.28772476315498, 56.7883213609457, 55.12171559035778, 49.3442016094923, 51.409770771861076, 59.24224108457565, 67.14884921908379, 67.85604447126389, 75.53656473755836, 50.37634402513504, 0.1348452048841864, 1.9362873933278024, 1.311385987792164, 0.13229245436377823, 0.7160911685787141, 55.90551473200321, 73.57773184776306, 74.77865740656853, 66.29128843545914, 58.27353246510029, 31.2827979773283, 27.021784521639347, 52.41781108081341, 55.23050755262375, 75.10651141405106, 9.043938405811787, 0.4845855035819113, 0.12221945464261808, 0.04620473395334557, 0.0481775443040533, 0.07671600571484305, 0.23512241779826581, 0.10628102434566244, 0.09512188407825306, 0.1265794163919054, 0.24559703073464334, 0.22703182068653405, 0.254934614058584, 51.17869757115841, 84.9095369875431, 63.57176676392555, 60.37747196853161, 34.882185235619545, 41.48252986371517, 55.40481559932232, 75.97742468118668, 75.9551502764225, 75.71086138486862, 53.97106893360615, 0.4006341740023345, 0.41907191276550293, 2.2554387990385294, 1.0467417072504759, 5.8919695392251015, 42.73638658225536, 66.7650394141674, 64.8991647362709, 63.654811307787895, 63.98985832929611, 63.65432873368263, 57.90484964847565, 61.13556168973446, 62.56899677217007, 64.0029676258564, 65.53894400596619, 62.743122428655624, 64.72523286938667, 60.93770630657673, 61.35161429643631, 62.53498859703541, 61.11308969557285, 63.180216774344444, 60.061541721224785, 59.523517191410065, 52.444778233766556, 55.87781801819801, 64.43615198135376, 63.44706505537033, 59.88774284720421, 59.22537378966808, 57.604981139302254, 55.62855139374733, 48.16060312092304, 48.82101908326149, 49.7369409352541, 50.48510178923607, 55.07215104997158, 52.26334176957607, 47.38101415336132, 46.130326464772224, 45.432220324873924, 44.347408935427666, 46.75838716328144, 46.92924119532108, 45.714077800512314, 47.67832159996033, 43.293672278523445, 45.29238782823086, 47.7118244022131, 45.65099738538265, 42.88975015282631, 41.51872292160988, 41.23150393366814, 47.20871239900589, 44.94019232690334, 42.89458729326725, 43.785590082407, 44.413274601101875, 43.72415877878666, 44.153573736548424, 43.553749322891235, 43.93149085342884, 42.994818314909935, 45.55822156369686, 42.978688180446625, 43.405929654836655, 45.30039019882679, 45.505222007632256, 46.16045884788036, 43.36817488074303, 46.3230749219656, 45.13073310256004, 45.32146006822586, 43.11340235173702, 42.585610672831535, 41.672276481986046, 44.14810203015804, 42.87008620798588, 43.17755050957203, 43.987062871456146, 42.112980633974075, 45.80897770822048, 45.842621102929115, 43.08091789484024, 40.75017996132374, 41.12000271677971, 37.4281208217144, 39.53207552433014, 38.87124918401241, 37.58572116494179, 40.714693665504456, 41.085451170802116, 41.660717502236366, 45.644302144646645, 40.52919901907444, 45.33836916089058, 42.2878510504961, 45.706987380981445, 43.715966418385506, 45.59802062809467, 46.57477341592312, 45.63008330762386, 43.244339525699615, 45.5944450199604, 44.18698534369469, 44.86187852919102, 48.83665904402733, 49.73893582820892, 54.35612887144089, 60.559512600302696, 61.14488258957863, 55.989467427134514, 58.97214397788048, 61.865016147494316, 61.41035534441471, 64.38977167010307, 62.66625255346298, 64.46155741810799, 61.71721167862415, 63.17385971546173, 60.56461572647095, 57.511392161250114, 60.53132951259613, 58.17036420106888, 59.75726544857025, 61.41988143324852, 62.47322291135788, 60.8189132809639, 56.85998551547527, 52.53104120492935, 54.52394686639309, 62.85091504454613, 70.4526275396347, 71.91333755850792, 77.24437549710274, 57.05656796693802, 0.14865152654238045, 10.466725509613752, 5.890796827152371, 0.3411312372190878, 1.142918465193361, 60.67891739308834, 80.14017730951309, 82.77294963598251, 73.61467346549034, 73.5439744591713, 48.28492484986782, 34.149139970541, 62.377289459109306, 64.72030073404312, 88.19176286458969, 13.129255939275026, 0.9084380348213017, 0.21372313873143867, 0.156673074234277, 0.19470426865154877, 0.32847340393345803], [0.06760726362699643, 0.02178694361646194, 0.017003514258249197, 0.06686374297714792, 0.0728228993830271, 0.09145094707491808, 0.13329045003047213, 30.694732032716274, 64.73024860024452, 38.37243475019932, 28.735918141901493, 11.615686006844044, 21.587855704128742, 45.66122263669968, 63.9422544836998, 63.874002546072006, 64.58416163921356, 45.758299827575684, 0.2593277127016336, 0.07114865875337273, 0.6223162380047143, 0.19157316244672984, 1.496966842096299, 27.41691581904888, 60.099718272686005, 61.327591985464096, 60.98469838500023, 54.311526864767075, 56.24017037451267, 60.04438944160938, 63.14202882349491, 59.97332565486431, 57.7745508402586, 56.22393384575844, 54.67351824045181, 53.648948818445206, 57.60588929057121, 56.13188378512859, 55.435932129621506, 55.693702697753906, 54.68091644346714, 53.08279439806938, 55.12761667370796, 58.14111717045307, 57.25394457578659, 50.963431522250175, 52.006593346595764, 51.66667878627777, 54.1324120759964, 51.53851546347141, 43.759519681334496, 43.35406243801117, 46.71622082591057, 49.4879212975502, 57.16350182890892, 56.806298196315765, 50.087749511003494, 52.15627111494541, 44.54144552350044, 42.332479655742645, 41.75888143479824, 41.35397516191006, 41.60194605588913, 41.976841539144516, 43.211520686745644, 40.603815615177155, 37.66878090798855, 45.58596767485142, 44.615210965275764, 40.20173259079456, 40.24027772247791, 41.69136665761471, 42.41418667137623, 44.14164237678051, 42.76698634028435, 42.84962810575962, 40.11931121349335, 40.474364161491394, 39.739069417119026, 39.234315901994705, 39.3349839001894, 36.77334375679493, 38.789143189787865, 39.37933512032032, 39.97756741940975, 40.23303151130676, 40.507749170064926, 39.94515895843506, 38.76724876463413, 39.50594812631607, 37.791841104626656, 38.97999934852123, 39.57427605986595, 39.4349717348814, 40.53375117480755, 39.69930075109005, 39.53342825174332, 38.0517091602087, 39.194543436169624, 43.696234077215195, 43.342362865805626, 41.365207359194756, 40.64601615071297, 37.89706125855446, 37.66881890594959, 38.03626298904419, 37.43646897375584, 39.57636594772339, 37.198685333132744, 37.76010900735855, 41.672740057110786, 42.58192107081413, 41.64996027946472, 40.61418145895004, 39.29037429392338, 39.160311073064804, 38.81310850381851, 39.94004063308239, 40.825613513588905, 40.59614382684231, 41.73781916499138, 39.87219147384167, 41.029274985194206, 40.97545087337494, 42.148516327142715, 44.00917388498783, 45.14445036649704, 48.43668110668659, 55.19988499581814, 53.336597979068756, 56.8060702085495, 56.6202487796545, 57.52521201968193, 56.39902085065842, 55.29279761016369, 55.04054054617882, 57.51033201813698, 57.21414931118488, 57.63398878276348, 58.7866797298193, 57.81054250895977, 59.677123948931694, 57.7838109433651, 61.300115659832954, 60.313335210084915, 60.09529151022434, 59.83170725405216, 58.89235205948353, 59.074898064136505, 53.162031546235085, 53.66646587848663, 62.34211094677448, 65.31482443213463, 68.9361897110939, 51.43648333847523, 0.5356523289810866, 1.3710193941369653, 1.6463685315102339, 0.04228358557156753, 0.25796694040764123, 44.85716678202152, 68.97371649742126, 66.85412183403969, 62.30361521244049, 65.12383908033371, 37.796077877283096, 23.33885494619608, 40.89373625814915, 45.91557338833809, 73.1743834912777, 10.769426766782999, 0.33823822683189064, 0.13437395595246926, 0.05239283178525511, 0.09514467543340288, 0.025821573799476027, 0.028273683528823312, 0.030863867978041526, 0.046622025038232096, 0.03634868255176116, 0.06590865086764097, 0.16417681064922363, 0.29874739120714366, 39.52042154967785, 74.17481660842896, 46.412639915943146, 33.03109176456928, 19.48191750794649, 30.138202495872974, 50.04426844418049, 71.54869392514229, 68.99757921695709, 69.65691983699799, 49.693368673324585, 0.1822827648720704, 0.03848329964966979, 1.1083600320853293, 1.1177347227931023, 2.0934183429926634, 28.936919756233692, 61.29728101193905, 64.15965601801872, 62.020560801029205, 56.102119982242584, 58.98046933114529, 60.46007193624973, 63.023368790745735, 59.19007368385792, 58.17077457904816, 57.330894246697426, 57.9033525288105, 55.67025035619736, 58.41407172381878, 56.98523439466953, 56.56773179769516, 57.16524973511696, 56.02466493844986, 54.45980630815029, 55.13518966734409, 58.24341528117657, 59.17053513228893, 52.40086019039154, 56.016772761940956, 55.10690778493881, 56.247769966721535, 52.999369874596596, 45.559768080711365, 45.259766578674316, 49.596280083060265, 53.002379313111305, 58.96208971738815, 56.53254948556423, 52.57384970784187, 53.738688603043556, 47.75721676647663, 44.147744849324226, 44.153839722275734, 43.82598951458931, 44.4180965423584, 43.98203194141388, 44.878118857741356, 40.386828258633614, 40.238985791802406, 46.6239769756794, 44.54949349164963, 40.593457370996475, 40.018730610609055, 42.432448491454124, 42.92326055467129, 43.505890890955925, 43.47321264445782, 42.82240256667137, 42.81699165701866, 40.89876338839531, 42.21364103257656, 41.094943061470985, 40.515774339437485, 39.34610590338707, 43.44124875962734, 40.889070108532906, 41.668168902397156, 40.99562019109726, 42.400207221508026, 43.2104567438364, 40.22995747625828, 40.339186415076256, 41.293243020772934, 39.70643296837807, 41.781824603676796, 42.026140093803406, 41.325906068086624, 42.06850402057171, 39.963557571172714, 40.70920296013355, 40.811428874731064, 45.571954026818275, 44.33006666600704, 39.625394716858864, 40.16179293394089, 39.062014147639275, 36.6696435213089, 37.37831309437752, 37.51713864505291, 39.273598194122314, 35.42373597621918, 37.61505179107189, 41.14808700978756, 41.79016135632992, 42.751266583800316, 41.71008825302124, 40.597040578722954, 41.40972577035427, 40.912093073129654, 42.940135449171066, 43.192536905407906, 42.16199040412903, 42.995316088199615, 41.9636220484972, 43.07458743453026, 43.5370834171772, 44.57119792699814, 46.84468813240528, 47.75832250714302, 50.17504222691059, 54.739763885736465, 55.15675351023674, 58.37443605065346, 58.13510209321976, 57.67587013542652, 57.490512281656265, 56.85497738420963, 56.17958262562752, 59.25002686679363, 59.41766247153282, 58.98346357047558, 60.45617714524269, 60.324483811855316, 64.39962834119797, 62.540490701794624, 64.96869340538979, 62.41526462137699, 64.66878309845924, 64.79855373501778, 63.26185159385204, 62.38339193165302, 55.82531623542309, 56.59860514104366, 64.70138534903526, 67.6000066101551, 73.04828345775604, 59.51114125549793, 0.4734967486001551, 1.8337470456026495, 2.305641705170274, 0.09747566480655223, 0.22277072042925283, 49.287839233875275, 76.56914412975311, 72.97556295990944, 68.51723179221153, 67.1131919324398, 41.468409821391106, 29.595555514097214, 49.10750091075897, 53.175881803035736, 83.41169536113739, 14.66064976528287, 0.6424868619069457, 0.1206184046168346, 0.08788346545770764, 0.07054148547467776, 0.07285883417353034, 0.17122886114520952, 0.17744788056006655, 0.1843989989720285, 0.1703529042424634, 0.23924299981445074, 0.2807009423850104, 0.36088471475522965, 48.15530240535736, 83.88143375515938, 54.2643865942955, 46.03793062269688, 24.038699492812157, 33.29537898302078, 60.125933066010475, 77.98685565590858, 74.99710768461227, 76.43303543329239, 54.005658477544785, 0.40447273990139365, 0.3330669121351093, 3.001633733510971, 1.1523338849656284, 2.3190982080996037, 33.62011335790157, 63.197616040706635, 66.33922666311264, 64.47162687778473, 59.589246064424515, 62.69764646887779, 63.324837014079094, 63.467040583491325, 61.396425291895866, 59.58372116088867, 59.19679932296276, 56.95984035730362, 57.802228555083275, 59.96266342699528, 57.39582896232605, 58.67927469313145, 59.11812074482441, 58.01771879196167, 53.09992387890816, 56.40670403838158, 60.078667402267456, 61.080350652337074, 54.48221370577812, 54.95215728878975, 57.564258724451065, 59.57235977053642, 56.973299235105515, 48.32931026816368, 48.67581367492676, 53.35754245519638, 54.507334157824516, 59.89652417600155, 58.69172282516956, 58.84152218699455, 56.49944566190243, 50.424506440758705, 47.40027152001858, 45.83997264504433, 45.87697125971317, 46.367817521095276, 46.0103365033865, 47.552829533815384, 43.95641751587391, 43.01095984876156, 49.34700965881348, 45.172762647271156, 39.94543634355068, 41.02336250245571, 42.20768675208092, 42.69947536289692, 44.8634098470211, 43.865636587142944, 44.95033398270607, 43.995027244091034, 43.74728053808212, 44.165151715278625, 42.71516852080822, 42.884840816259384, 40.47515071928501, 44.71592076122761, 43.526299595832825, 44.97424989938736, 43.93108807504177, 45.82247078418732, 44.60239425301552, 43.56514871120453, 43.59261363744736, 42.32740692794323, 43.31941969692707, 44.23600271344185, 45.031493827700615, 45.1479309797287, 45.823850110173225, 43.14176023006439, 43.79746824502945, 41.877161487936974, 48.489061295986176, 47.29822039604187, 41.13183908164501, 40.541115179657936, 38.00812549889088, 38.08594152331352, 37.86624111235142, 38.28155502676964, 42.268354296684265, 35.9570449590683, 39.816391468048096, 43.5338269919157, 42.53379285335541, 45.98908804357052, 43.482807129621506, 42.683444023132324, 44.495775774121284, 43.84294420480728, 44.767704382538795, 45.24822659790516, 45.40742665529251, 45.48358976840973, 43.258668556809425, 44.64126996695995, 45.52134074270725, 47.83229313790798, 48.189048394560814, 50.1847393065691, 54.39795322716236, 57.9598630964756, 59.16023388504982, 59.48851726949215, 60.770093500614166, 59.88537177443504, 60.7747520506382, 58.88113506138325, 57.43146724998951, 61.90569296479225, 62.056772857904434, 60.54761543869972, 62.73050330579281, 63.560131788253784, 65.28496563434601, 63.959581553936005, 69.69343587756157, 64.91266161203384, 66.10255256295204, 69.14966985583305, 66.31716504693031, 64.92629528045654, 59.46003779768944, 59.00614455342293, 67.28746578097343, 70.7109908759594, 74.5770326256752, 64.44376677274704, 0.47031893162056804, 7.3930196184664965, 4.971265168860555, 0.2823521022219211, 0.4028540861327201, 55.56654252111912, 81.77608072757721, 79.55494791269302, 77.80324950814247, 79.69473481178284, 51.333467066287994, 35.64714498817921, 59.76744890213013, 62.17917189002037, 96.38153180480003, 19.30141769349575, 0.794685676228255, 0.3835836873622611, 0.19814609724562615, 0.23560972680570558, 0.23846039024647325], [0.04839058892684989, 0.030982064272393472, 0.010339062446291791, 0.1300255345995538, 0.050532078312244266, 0.08558628833270632, 0.04315013575251214, 27.491568513214588, 70.06509393453598, 46.624702736735344, 41.83348663151264, 22.476109340786934, 34.44631442427635, 46.92919559776783, 63.826041519641876, 64.00971606373787, 62.8979679197073, 46.25997930765152, 0.2862046204973012, 0.10427001936477609, 2.270245417021215, 1.1601506592705846, 0.3639052854850888, 14.847436342388391, 56.690130829811096, 60.832151770591736, 55.80780677497387, 56.35277733206749, 55.139076858758926, 47.13357903063297, 50.86866080760956, 53.93931023776531, 52.31488220393658, 48.775402531027794, 49.030224457383156, 50.035270527005196, 52.4850332736969, 50.677147284150124, 50.20696051418781, 51.7618902772665, 55.58646485209465, 57.42558516561985, 59.45961982011795, 58.66852506995201, 51.24284952878952, 56.034077033400536, 52.48321317136288, 49.56894814968109, 42.83047333359718, 41.769011691212654, 41.085834950208664, 46.185187920928, 48.03186222910881, 51.562708765268326, 52.32281997799873, 57.93742150068283, 61.95601366460323, 52.10679776966572, 51.09314136207104, 44.94611240923405, 41.30077041685581, 39.79233115911484, 41.45405799150467, 41.12214580178261, 39.28373984992504, 40.62826730310917, 40.479243099689484, 42.13892564177513, 45.21153576672077, 39.78927992284298, 39.712117463350296, 37.92956091463566, 41.142809092998505, 41.76360458135605, 41.47571682929993, 39.72754083573818, 38.675909265875816, 39.61462989449501, 39.726351499557495, 39.95561219751835, 39.743518978357315, 38.940314278006554, 39.114546328783035, 38.04928109049797, 37.43055649101734, 39.20180104672909, 40.75188226997852, 39.513490721583366, 40.106061324477196, 41.93775683641434, 39.90142710506916, 39.182847663760185, 37.020923271775246, 37.94456250965595, 39.79288972914219, 38.34039106965065, 39.04002472758293, 40.28725080192089, 42.08637446165085, 42.573888301849365, 40.05465008318424, 37.02052429318428, 37.60967127978802, 38.700991719961166, 37.91266702115536, 36.4969427883625, 37.7176158875227, 38.61898072063923, 37.56241701543331, 37.61374846100807, 38.936636075377464, 43.22397641837597, 38.385141268372536, 40.61880201101303, 39.41809304058552, 39.80389393866062, 41.91819168627262, 42.45759554207325, 42.26957403123379, 40.08142724633217, 40.723106414079666, 40.12723758816719, 42.941883355379105, 41.19376055896282, 45.24178594350815, 51.47696256637573, 50.37663660943508, 48.491075187921524, 49.619219452142715, 54.83906775712967, 53.545009195804596, 53.90380874276161, 57.69375577569008, 58.16106989979744, 57.77848742902279, 55.55810697376728, 57.150814309716225, 54.09654960036278, 57.844117507338524, 57.79586009681225, 57.221327126026154, 57.008090168237686, 59.526082053780556, 58.68445761501789, 64.49238896369934, 61.66879087686539, 69.53157216310501, 71.51443496346474, 60.21979562938213, 58.921838477253914, 56.60854920744896, 60.50379998981953, 66.13979056477547, 72.17505991458893, 55.263056606054306, 0.3107979992637411, 0.44135920121334493, 0.6564914854243398, 0.14415034151170403, 0.08331968769198284, 41.11954294145107, 69.29616719484329, 70.8719502389431, 57.984690964221954, 63.562841042876244, 37.689368203282356, 10.707406494766474, 35.815517753362656, 41.23389020562172, 67.98470556735992, 11.181305665522814, 0.3009880241006613, 0.09867822605883703, 0.0636898519587703, 0.06718376447679475, 0.0693151903396938, 0.02407641353784129, 0.06096136086853221, 0.04060950450366363, 0.07774515674100257, 0.08025015005841851, 0.2246289246249944, 0.06030632277543191, 34.80295188724995, 78.64331603050232, 53.79709146916866, 48.13843131065369, 25.152444429695606, 36.3314388692379, 52.026462480425835, 69.58847790956497, 69.14923667907715, 69.25959035754204, 49.53507676720619, 0.25871184887364507, 0.17719198804115877, 1.5636620507575572, 2.779250666499138, 0.8777064713649452, 16.711516566574574, 58.127107322216034, 61.6947852820158, 59.726988673210144, 56.55002474784851, 57.55773447453976, 51.64103776216507, 55.38333535194397, 54.64062340557575, 52.991865277290344, 48.60813170671463, 50.76368384063244, 50.869454964995384, 52.0795152336359, 53.07721249759197, 50.33164702355862, 52.0931489020586, 55.17630726099014, 58.05958114564419, 61.77018083631992, 60.656642988324165, 52.81340405344963, 57.920428812503815, 53.92718128859997, 50.7069680839777, 46.15544691681862, 43.43755155801773, 43.20487484335899, 48.86121712625027, 50.42392887175083, 55.12177258729935, 56.28545634448528, 60.71547523140907, 59.464536756277084, 52.946400716900826, 53.03175553679466, 47.78641439974308, 44.318424090743065, 41.85185864567757, 41.9829174131155, 42.76700533926487, 41.67740240693092, 41.41029953956604, 39.77219983935356, 43.79551135003567, 48.170611783862114, 41.09762951731682, 39.28402103483677, 38.016682639718056, 41.703282818198204, 39.869197234511375, 41.877153888344765, 40.2816841006279, 38.70981864631176, 40.96577659249306, 41.04641206562519, 40.975637063384056, 41.51206187903881, 41.81435465812683, 40.03230728209019, 41.33667089045048, 40.44642046093941, 42.57097385823727, 43.20957139134407, 42.86466769874096, 42.06701070070267, 43.677668273448944, 41.46963335573673, 40.824473574757576, 40.42587496340275, 40.780722722411156, 41.00603923201561, 39.54489603638649, 39.556880593299866, 42.01419733464718, 43.028511106967926, 43.78475792706013, 40.269023180007935, 36.024426743388176, 38.6894441395998, 38.26496511697769, 39.1165754199028, 36.57932996749878, 36.798866987228394, 37.833285480737686, 36.69797480106354, 35.14064736664295, 39.03571955859661, 44.737442806363106, 40.887181609869, 42.447499483823776, 42.8841682523489, 41.256035417318344, 42.06050164997578, 43.5986553132534, 43.802172392606735, 41.66949883103371, 43.05899307131767, 43.53499352931976, 44.84857924282551, 42.77480252087116, 48.59531879425049, 53.262669146060944, 53.39294895529747, 49.81923691928387, 52.57599279284477, 56.381807774305344, 56.049375012516975, 55.07828012108803, 59.57794547080994, 58.80244128406048, 59.97004263103008, 55.06876923143864, 59.20933485031128, 57.160222604870796, 58.55183333158493, 58.44443589448929, 58.582623079419136, 59.65418457984924, 61.780455484986305, 61.80728204548359, 66.48800387978554, 65.22248178720474, 69.45211842656136, 74.64154556393623, 65.6111553311348, 60.14963239431381, 60.32375805079937, 63.78359779715538, 68.33989530801773, 73.01743671298027, 61.65463283658028, 0.2574047486996278, 1.108124682214111, 2.31981850694865, 0.11964014265686274, 0.0830258936912287, 45.02555854618549, 75.99895432591438, 76.29128023982048, 65.59301510453224, 66.43470034003258, 43.93398351967335, 21.05442512780428, 45.47718331217766, 49.02333542704582, 75.57742774486542, 14.209062997251749, 0.48084938374813646, 0.09671007268480025, 0.05275229472317733, 0.10158072109334171, 0.08578556240536273, 0.22899524657987058, 0.09026115818414837, 0.1056391853489913, 0.27824467106256634, 0.1315127094858326, 0.34697093011345714, 0.10570352213107981, 46.24045215547085, 86.83741673827171, 60.150278359651566, 59.903990775346756, 34.09392513334751, 46.69534094631672, 63.95809963345528, 76.3543264567852, 75.88490724563599, 75.02138078212738, 55.920428931713104, 0.4032817709958181, 0.4841598076745868, 4.825736302882433, 3.436625129543245, 1.1909770988859236, 19.457988291978836, 59.0529428422451, 64.53105568885803, 59.83744874596596, 58.16782973706722, 58.88330854475498, 53.8656359910965, 58.863811790943146, 57.64640271663666, 54.767282009124756, 51.5348144620657, 52.363021820783615, 53.927762657403946, 54.09782633185387, 53.392884358763695, 51.25635400414467, 54.49142061173916, 56.02360099554062, 59.11745198071003, 63.896117359399796, 62.93879672884941, 55.84351345896721, 61.93635731935501, 55.47730430960655, 53.996698558330536, 47.3604154586792, 45.03390669822693, 45.36502853035927, 51.609613448381424, 53.44986990094185, 58.7672171741724, 57.147607281804085, 58.68305169045925, 57.60488614439964, 54.47540447115898, 55.888788029551506, 49.63630333542824, 46.6921529173851, 42.47420445084572, 45.33766619861126, 45.25059387087822, 44.05584678053856, 43.22405241429806, 41.78103804588318, 45.66009409725666, 47.60694243013859, 39.94756042957306, 40.1649771630764, 39.89089027047157, 42.10698455572128, 39.957455098629, 42.12212294340134, 41.14618331193924, 40.61557978391647, 42.63387568295002, 44.03048314154148, 43.45547139644623, 44.844684451818466, 45.36001659929752, 43.47364962100983, 44.65154081583023, 43.56866732239723, 44.21293415129185, 44.9615927785635, 45.67912347614765, 44.39924195408821, 45.29563285410404, 44.97070088982582, 43.55384811758995, 42.62643948197365, 43.115283250808716, 43.26075844466686, 41.397733613848686, 41.33239611983299, 42.62338824570179, 44.86926533281803, 45.080894976854324, 42.78732284903526, 37.98282265663147, 38.19905765354633, 40.51547795534134, 39.4727037101984, 35.519749224185944, 36.69129855930805, 38.08980591595173, 37.81266778707504, 35.27905113995075, 39.34846177697182, 46.62153750658035, 42.250628247857094, 44.474603310227394, 44.142368137836456, 44.43540081381798, 46.11544646322727, 46.28861077129841, 46.6293802857399, 43.80932740867138, 43.631496950984, 44.98204328119755, 46.61896884441376, 46.03444240987301, 51.29863053560257, 56.468074545264244, 56.0085766017437, 51.89801037311554, 54.64513376355171, 60.09339541196823, 58.51006597280502, 56.43332540988922, 61.40210218727589, 61.740109249949455, 62.17797115445137, 55.908227786421776, 60.28119653463364, 59.94868777692318, 61.53579041361809, 61.150985062122345, 59.76041927933693, 61.63641281425953, 64.43778589367867, 61.86970129609108, 70.10088801383972, 67.31145769357681, 71.52636632323265, 74.94435891509056, 69.40980389714241, 62.57650516927242, 63.37868392467499, 64.50539946556091, 73.60953614115715, 76.11218824982643, 68.38298499584198, 0.3101681830594316, 3.33812752738595, 4.891292285174131, 0.4636225331341848, 0.15594621479976922, 49.93903689086437, 81.94820389151573, 84.43773910403252, 72.5113570690155, 78.98680999875069, 48.20473775267601, 18.675139099359512, 54.97127026319504, 58.04246686398983, 89.55787315964699, 22.18658197671175, 0.6288361537735909, 0.2329359616851434, 0.14913413033355027, 0.1987812272273004, 0.18992844445165247], [0.003737231431841792, 0.06527287521748804, 0.03506257402477786, 0.02867528746719472, 0.12521413184003904, 0.07749946875264868, 0.12898968940135092, 31.205607019364834, 64.43132624030113, 43.33764351904392, 31.611795723438263, 22.044127620756626, 48.94587278366089, 47.34105929732323, 62.78942294418812, 62.6461174339056, 63.20359691977501, 46.6880339384079, 0.12334855069639161, 0.07308566418942064, 0.7490150956436992, 1.8245933367870748, 0.26681286573875695, 6.094615990296006, 48.50404009222984, 51.93889617919922, 56.131705194711685, 55.04750557243824, 61.01590231060982, 59.469381496310234, 56.14270180463791, 50.89153937995434, 56.24888330698013, 52.31776624917984, 54.013231471180916, 51.094725877046585, 52.09084242582321, 49.87493433058262, 55.258158668875694, 56.9859753549099, 58.9104200899601, 55.90412400662899, 56.32898300886154, 51.47991880774498, 52.05211490392685, 48.56295593082905, 45.657525435090065, 44.17304389178753, 41.851265877485275, 38.97380568087101, 41.60515308380127, 45.32575763761997, 49.54980477690697, 51.681338399648666, 48.861361518502235, 40.97752936184406, 51.37357771396637, 60.35993590950966, 55.15883959829807, 48.51885549724102, 44.27189938724041, 40.53263783454895, 39.16865922510624, 37.515360340476036, 40.60277447104454, 39.48981039226055, 40.2854572981596, 36.65118791162968, 49.84162151813507, 43.81189227104187, 38.06766830384731, 40.11684514582157, 38.64551469683647, 41.877583265304565, 40.33385910093784, 42.54266917705536, 41.16507589817047, 37.713489308953285, 38.18918198347092, 39.658118560910225, 40.26706628501415, 38.77555891871452, 39.159231930971146, 39.0949659794569, 39.06243972480297, 39.932995811104774, 41.93818621337414, 40.681232661008835, 40.990368872880936, 39.842655658721924, 40.49956060945988, 39.1231756657362, 35.77540710568428, 40.38437359035015, 41.09183482825756, 40.083463937044144, 41.124877855181694, 41.896483451128006, 40.879354029893875, 38.74890334904194, 39.00714889168739, 39.9642301350832, 38.160375729203224, 38.30271229147911, 35.469132140278816, 36.82563275098801, 36.79746866226196, 35.40616191923618, 37.19850294291973, 33.57499457895756, 39.22882899641991, 44.40928861498833, 38.0903834849596, 39.35866042971611, 39.04786750674248, 41.801769733428955, 37.77540698647499, 41.23305045068264, 40.25867633521557, 40.11182941496372, 40.37098690867424, 39.94740463793278, 40.28371699154377, 41.40832744538784, 50.74674814939499, 52.321003675460815, 51.705322712659836, 53.99268977344036, 50.83249814808369, 48.30959692597389, 50.490379706025124, 53.73588055372238, 55.02617731690407, 53.30280639231205, 56.73132061958313, 56.87060974538326, 56.65728159248829, 57.31254883110523, 58.09047348797321, 59.55917067825794, 58.51361118257046, 57.710680067539215, 56.50920353829861, 57.4279448390007, 53.59052695333958, 62.72099241614342, 54.19223606586456, 61.63862809538841, 70.88192090392113, 64.17978733778, 64.23134297132492, 61.37961499392986, 61.79187387228012, 68.98037374019623, 58.50074127316475, 0.961230086395517, 0.6732672883663327, 1.6979325958527625, 0.18764766136882827, 0.06124466461187694, 37.93881721794605, 73.27499449253082, 63.7394517660141, 61.0215450078249, 59.54407408833504, 51.22994922101498, 15.565500911325216, 26.52374904602766, 37.65094466507435, 69.78735163807869, 26.249346770346165, 0.5359112494625151, 0.06319711043033749, 0.01776955909008393, 0.04331772383011412, 0.09728702571010217, 0.0201438342264737, 0.08456069219391793, 0.054870117019163445, 0.06140425233752467, 0.06994022711296566, 0.08998469333164394, 0.08989009176730178, 38.173257037997246, 74.01102259755135, 49.06779304146767, 46.3283072412014, 25.77227856963873, 45.636250376701355, 54.2287141084671, 68.34272235631943, 68.95656421780586, 68.58964070677757, 50.81633381545544, 0.12399859784636647, 0.25643146655056626, 1.8161575519479811, 4.397301692515612, 0.7056268269661814, 6.562210824340582, 51.06096088886261, 56.048637852072716, 55.09219117462635, 56.15946650505066, 63.12220148742199, 59.08686362206936, 57.95260548591614, 55.18219314515591, 56.67102165520191, 53.54961454868317, 53.79205293953419, 51.702860444784164, 52.91067883372307, 51.86635047197342, 56.684966906905174, 60.340621545910835, 59.39870148897171, 57.428822591900826, 58.56711611151695, 54.438516050577164, 54.911001697182655, 48.027758449316025, 48.186209946870804, 46.016636565327644, 42.32890024781227, 40.65563723444939, 44.126006215810776, 48.74859496951103, 52.75260351598263, 56.321087032556534, 49.966642409563065, 46.82042643427849, 54.63343419134617, 61.66187904775143, 55.764147117733955, 50.42199857532978, 48.9738392829895, 41.386748403310776, 41.572657227516174, 40.991269424557686, 43.4027986228466, 42.73506425321102, 42.22943678498268, 38.85027430951595, 51.19707338511944, 45.606433376669884, 36.90855570137501, 40.39720930159092, 38.62986333668232, 42.95528523623943, 40.39587937295437, 43.38880777359009, 40.77894061803818, 36.8478349596262, 39.581636264920235, 41.5096490085125, 41.926049664616585, 39.95780847966671, 39.52773995697498, 42.57353112101555, 41.03026673197746, 43.01915220916271, 44.55143138766289, 42.19097524881363, 43.7223082780838, 43.09300884604454, 42.41533420979977, 41.735303699970245, 38.24085161089897, 41.6827867180109, 43.89200337231159, 39.91697587072849, 43.446139097213745, 44.24294114112854, 42.568469792604446, 39.21617187559605, 38.48889470100403, 39.93397615849972, 37.652734369039536, 38.371188417077065, 37.678683176636696, 36.55238941311836, 36.14875987172127, 35.33151112496853, 38.60478088259697, 33.88671085238457, 40.54069720208645, 45.12325130403042, 39.93552267551422, 41.54874891042709, 41.84667192399502, 43.469618037343025, 41.379673182964325, 43.09893652796745, 42.70482927560806, 41.30988612771034, 40.46752832829952, 42.692981511354446, 43.21501649916172, 43.03795740008354, 51.526238322257996, 55.76559104025364, 56.02377198636532, 55.34685730934143, 52.481495663523674, 49.01359274983406, 54.12873387336731, 55.44761650264263, 56.675045639276505, 56.29240617156029, 58.722630366683006, 58.91873024404049, 59.84476715326309, 60.78987143933773, 59.960045367479324, 60.915956273674965, 55.821695029735565, 59.576588943600655, 57.1612523496151, 57.98503294587135, 54.42209713160992, 65.51147907972336, 53.399872183799744, 60.50168350338936, 73.50413739681244, 65.30087158083916, 66.71261742711067, 62.01410114765167, 66.34302645921707, 69.65046778321266, 62.59884417057037, 0.9518655482679605, 1.063988150563091, 3.258299035951495, 0.02370916547079105, 0.011003822673956165, 40.62871187925339, 79.99490350484848, 72.06354349851608, 65.9653191268444, 69.35852944850922, 49.98719930648804, 15.574817061424255, 33.4825075417757, 44.349422827363014, 79.88004326820374, 30.298384800553322, 0.4743139125639573, 0.034241788380313665, 0.03482447449641768, 0.0059768812116089975, 0.04839048131543677, 0.1820806335308589, 0.17199919559061527, 0.1492439236608334, 0.16584959666943178, 0.26609871187247336, 0.2279730123700574, 0.1662134865182452, 52.331525310873985, 83.08723837137222, 59.13684234023094, 50.10801762342453, 32.65769340097904, 60.87896905839443, 62.44184039533138, 74.87501263618469, 73.81565988063812, 74.09533247351646, 55.279665514826775, 0.27312714722938836, 0.3054854687070474, 3.8059574738144875, 4.894781922921538, 1.510896657127887, 7.99999762326479, 57.22670003771782, 60.682831183075905, 56.373558416962624, 59.35344971716404, 64.06101331114769, 62.150019854307175, 61.10585108399391, 58.53376530110836, 59.64887626469135, 54.97258119285107, 55.01013457775116, 51.94495305418968, 54.31701757013798, 53.930213525891304, 57.29100398719311, 59.174369126558304, 63.49026873707771, 60.87081469595432, 61.660317331552505, 55.45238524675369, 56.809702813625336, 51.39489457011223, 51.23976789414883, 49.13364350795746, 44.64605771005154, 42.36411675810814, 46.82812862098217, 50.53142890334129, 55.54333336651325, 57.085309624671936, 54.64467018842697, 50.34994304180145, 58.90463300049305, 60.132776498794556, 55.61133071780205, 54.95675504207611, 50.96200279891491, 45.16243480145931, 43.55409890413284, 42.07101188600063, 45.434777587652206, 44.78056289255619, 45.10995201766491, 40.75840272009373, 52.06512160599232, 45.608603060245514, 38.839547485113144, 39.695333763957024, 38.77556651830673, 42.02702544629574, 41.28214381635189, 42.29961521923542, 42.05395460128784, 37.384039387106895, 38.83862413465977, 43.857189640402794, 46.45458586513996, 42.639427185058594, 42.11928829550743, 46.22181035578251, 43.656378015875816, 46.06911934912205, 48.14391441643238, 43.77660356462002, 46.873125806450844, 47.12756395339966, 44.37612019479275, 45.46095438301563, 39.21734221279621, 44.92864474654198, 45.305934101343155, 42.18212932348251, 45.18399104475975, 45.64245164394379, 42.73605599999428, 38.71381603181362, 39.8835414648056, 41.5640164911747, 38.76134008169174, 38.93238790333271, 36.641555428504944, 36.75510473549366, 36.34610988199711, 35.29222883284092, 37.72857829928398, 33.45810145139694, 38.669837191700935, 46.49831011891365, 41.264543160796165, 43.086230009794235, 44.984201565384865, 45.80699801445007, 42.590782195329666, 44.85216245055199, 44.6238137036562, 43.97711880505085, 41.6863015294075, 44.84605237841606, 45.54171524941921, 45.50670772790909, 53.684560507535934, 57.63682343065739, 56.0764105618, 57.66484312713146, 54.66020755469799, 51.72213301062584, 56.81226007640362, 57.81337335705757, 59.35635656118393, 58.01663964986801, 61.894274577498436, 60.02234302461147, 61.78150802850723, 60.00927172601223, 62.513542547822, 64.46925580501556, 58.71058501303196, 60.606607273221016, 59.049044251441956, 57.97215163707733, 56.56703643500805, 65.51713317632675, 55.28271295130253, 64.79410797357559, 77.0390573143959, 69.29198741912842, 71.30420744419098, 66.7456528544426, 69.0355695784092, 74.05894562602043, 68.5532994568348, 1.3380254083313048, 3.4804234793409705, 6.62446953356266, 0.33091242774389684, 0.12766041385475546, 46.350384056568146, 86.47737085819244, 77.90311574935913, 74.76589769124985, 76.61717355251312, 64.45490777492523, 26.18056856095791, 42.944319024682045, 52.747371196746826, 89.9466834962368, 39.75024461746216, 0.7133560278452933, 0.11654721995000727, 0.16371862351661548, 0.1682616805192083, 0.13618218392366543], [0.025241897092200816, 0.028920654476678465, 0.09500224245130084, 0.014154024338495219, 0.007617791061420576, 0.07991570862941444, 0.0958159776928369, 32.82073125243187, 60.43220803141594, 41.151761412620544, 33.77210520207882, 19.93758335709572, 37.23713167011738, 47.1824786067009, 65.31622275710106, 63.55306796729565, 62.683792412281036, 48.860460966825485, 0.1966947384062223, 0.21666866348823532, 0.47763923881575465, 3.181859962642193, 0.11808399998699315, 1.5289465198293328, 35.790469497442245, 52.286805510520935, 58.677978962659836, 61.97731912136078, 59.455147460103035, 57.2949405759573, 61.06516666710377, 60.59952825307846, 57.108856961131096, 54.0048149228096, 51.74553595483303, 54.51861195266247, 55.410427898168564, 59.11512270569801, 57.95014701783657, 55.69812186062336, 55.58632805943489, 52.12626792490482, 51.334572806954384, 48.47916282713413, 44.21448826789856, 41.74767963588238, 42.27926731109619, 41.222061440348625, 41.33693687617779, 40.940941125154495, 43.200793862342834, 44.59522023797035, 49.319225549697876, 46.28614850342274, 50.39139501750469, 51.18972837924957, 40.961821004748344, 43.138735592365265, 56.426288187503815, 51.4022433757782, 46.82527497410774, 42.13174022734165, 39.82121340930462, 41.622616946697235, 39.78238329291344, 38.701702281832695, 40.30419409275055, 38.70206706225872, 43.648212254047394, 50.46039551496506, 39.42513786256313, 41.08806923031807, 39.07836467027664, 39.367050379514694, 40.06026238203049, 41.39462538063526, 40.95633789896965, 40.03706842660904, 40.386212691664696, 40.38134515285492, 41.8281327188015, 39.78549912571907, 37.94018134474754, 37.8783168643713, 38.14725883305073, 38.45523230731487, 38.79034012556076, 39.6377744525671, 39.08146150410175, 40.077042281627655, 40.02929784357548, 38.69449786841869, 38.49313147366047, 39.49517950415611, 38.93320485949516, 39.28783603012562, 40.65017692744732, 42.20256082713604, 41.60818912088871, 38.19185324013233, 40.07916256785393, 37.791708111763, 38.866267651319504, 37.87958599627018, 36.56917691230774, 36.89308673143387, 38.428667932748795, 37.35503174364567, 37.99402065575123, 34.02956798672676, 43.43051813542843, 41.05153039097786, 36.39735393226147, 40.38779340684414, 40.38156934082508, 39.23241600394249, 38.54863129556179, 39.62718062102795, 39.71570447087288, 40.64968675374985, 40.03988787531853, 43.296537324786186, 45.097017511725426, 47.50810593366623, 48.25399070978165, 53.13356727361679, 53.49901266396046, 52.47849382460117, 52.75646410882473, 52.506467923521996, 48.74964751303196, 48.653448075056076, 49.662799313664436, 53.348825722932816, 54.76953148841858, 55.27829758822918, 54.718754813075066, 57.04361066222191, 57.110004499554634, 62.69201137125492, 56.88893996179104, 60.94382777810097, 59.349999502301216, 64.5747609436512, 57.75023974478245, 60.78760676085949, 42.17243604362011, 47.25939407944679, 68.30519556999207, 62.69790105521679, 66.2019020318985, 62.76648357510567, 64.03234764933586, 69.93927508592606, 54.2242531478405, 0.602163722505793, 0.4770127177471295, 0.9458283253479749, 0.17509138357127085, 0.08176773073500954, 32.91553616523743, 74.23192754387856, 63.46393994987011, 61.786098182201385, 49.529042690992355, 38.73042494058609, 22.153785936534405, 33.9714615046978, 47.620161920785904, 68.96649688482285, 31.041180342435837, 0.49913278548046947, 0.2021222424809821, 0.10431106755277142, 0.07805027591530234, 0.08472566420095973, 0.0944227735453751, 0.07474411191651598, 0.06596249368158169, 0.06424664083169773, 0.021880695421714336, 0.1064215500082355, 0.10284701798809692, 42.475435584783554, 68.74861657619476, 48.19490768015385, 33.63556332886219, 23.983551152050495, 46.818872317671776, 54.0531787276268, 72.9792183637619, 68.32831352949142, 69.41910579800606, 53.32433983683586, 0.22523515537614003, 0.21976114832796156, 2.766415192745626, 7.388390991836786, 1.3984393165446818, 1.4235215331427753, 42.12382525205612, 54.62616518139839, 61.02416306734085, 61.36811301112175, 62.69574277102947, 60.39266735315323, 64.80005085468292, 62.143871784210205, 59.27684582769871, 54.67175893485546, 53.55450488626957, 55.504206866025925, 56.39396332204342, 60.25030419230461, 60.68372793495655, 57.55844883620739, 57.69279062747955, 55.1030395925045, 55.79204902052879, 51.49510279297829, 46.61385431885719, 44.41607505083084, 45.662936344742775, 44.4293325394392, 45.15468321740627, 42.29348234832287, 44.17819641530514, 46.65176868438721, 50.49582481384277, 49.36282441020012, 52.29934863746166, 53.388142213225365, 45.13298638164997, 47.30820246040821, 57.91557267308235, 53.86338651180267, 49.184097200632095, 43.573265075683594, 41.800466403365135, 42.77754597365856, 40.789751037955284, 41.32585667073727, 43.44236969947815, 39.87544409930706, 43.945823684334755, 51.77588492631912, 40.474048778414726, 40.034150183200836, 39.361658468842506, 40.55348351597786, 39.078402668237686, 41.04475535452366, 40.81967443227768, 40.422717332839966, 39.65025678277016, 41.866993233561516, 42.30927050113678, 41.03391453623772, 39.72670868039131, 39.12296287715435, 41.97903402149677, 40.36755949258804, 40.36041207611561, 42.63875462114811, 39.33636322617531, 41.74747444689274, 43.22028301656246, 41.844019666314125, 40.351756140589714, 41.326027661561966, 40.824310183525085, 42.37872317433357, 42.17067293822765, 42.55457013845444, 41.533382534980774, 37.975367456674576, 40.186495408415794, 38.42662364244461, 37.396643310785294, 37.630566358566284, 35.35194642841816, 36.77625060081482, 38.322832211852074, 37.081780806183815, 37.98938870429993, 34.8280381411314, 44.969940930604935, 44.00222405791283, 39.05400037765503, 41.578558310866356, 41.27164117991924, 40.92640310525894, 39.731530621647835, 43.50524492561817, 42.34392464160919, 43.422755151987076, 41.84792585670948, 46.37555770576, 47.956223487854004, 48.91360491514206, 50.38275808095932, 55.14850415289402, 55.10275840759277, 56.07584059238434, 53.04537780582905, 54.81973059475422, 49.355506002902985, 50.810242742300034, 52.61618323624134, 54.99219574034214, 56.45219899713993, 57.64572635293007, 57.77376428246498, 59.09694828093052, 57.18234121799469, 63.04984577000141, 59.32848125696182, 63.88148054480553, 61.561127454042435, 65.58973208069801, 59.40397560596466, 61.114317029714584, 46.11760854721069, 48.15157100558281, 69.93561208248138, 65.04791155457497, 69.42820250988007, 66.04020550847054, 66.1392129957676, 73.53601768612862, 56.99891746044159, 0.6473772588651627, 0.9944608469959348, 2.169962148182094, 0.028607275198737625, 0.06970541158807464, 36.109200194478035, 79.44476902484894, 69.17506009340286, 68.48398357629776, 57.49896302819252, 49.58360776305199, 26.83655586093664, 43.18238005042076, 51.69872246682644, 78.23930650949478, 37.3566010594368, 0.4300350073026493, 0.20586845552315935, 0.04035418343846686, 0.056425688235322013, 0.03461691063421313, 0.14123775326879695, 0.1538090076064691, 0.22570509812794626, 0.10673363794921897, 0.13843256863765419, 0.27147705608513206, 0.3487906762165949, 53.09625707566738, 80.27590602636337, 56.73094443976879, 46.392409801483154, 30.77619396150112, 51.753530725836754, 63.95706608891487, 78.22855308651924, 74.74183738231659, 76.68581306934357, 58.16915586590767, 0.3545384021708742, 0.5894891463685781, 2.8928154101595283, 9.24965176731348, 1.5188613859936595, 2.3288446851074696, 42.6290575414896, 59.097408056259155, 62.22742170095444, 65.2077765762806, 65.24313747882843, 64.36311230063438, 65.37580356001854, 64.77178037166595, 61.37078046798706, 58.21568436920643, 55.31620815396309, 55.825494825839996, 57.07688167691231, 62.06104762852192, 63.00279289484024, 59.34794761240482, 57.661510705947876, 57.14259535074234, 57.35871635377407, 53.645073026418686, 48.88034150004387, 46.2476147711277, 47.79434077441692, 45.83768516778946, 46.24033436179161, 45.42914628982544, 47.350722178816795, 49.28267151117325, 53.17006051540375, 52.326577976346016, 54.17232133448124, 55.73865808546543, 47.26470619440079, 52.45250701904297, 61.1147616058588, 55.55111154913902, 53.80137383937836, 45.17864853143692, 43.047992661595345, 46.21638044714928, 44.72837269306183, 42.99389876425266, 45.91499201953411, 42.6926851272583, 47.45149277150631, 51.87015026807785, 40.226929038763046, 41.37979097664356, 38.84006045758724, 40.27212381362915, 41.470484510064125, 40.86940236389637, 41.40567518770695, 42.292999774217606, 41.50358073413372, 43.123730197548866, 46.48389369249344, 44.87451285123825, 42.75730445981026, 42.519091442227364, 43.83047707378864, 43.06626968085766, 40.94381757080555, 45.343571081757545, 44.17283110320568, 44.342830181121826, 45.75070783495903, 42.767396718263626, 42.2679553180933, 43.53437416255474, 43.404291942715645, 42.63258375227451, 43.939546421170235, 44.885631054639816, 43.06310825049877, 38.706246837973595, 40.66541410982609, 39.19574037194252, 39.373354241251945, 36.59731440246105, 35.31419165432453, 37.60696962475777, 38.942217975854874, 37.399937734007835, 39.32839885354042, 34.20630030333996, 44.46214757859707, 45.64328379929066, 40.7724429666996, 45.03407008945942, 45.18904857337475, 41.506886556744576, 43.574929386377335, 46.071441024541855, 43.470320999622345, 46.707899272441864, 43.303027376532555, 48.59787605702877, 50.16842298209667, 52.60812386870384, 53.17210100591183, 56.33797712624073, 58.440590500831604, 56.39680556952953, 56.4266187697649, 57.93163441121578, 53.683747351169586, 54.01177614927292, 54.98366139829159, 57.65077248215675, 58.89512211084366, 61.446202620863914, 61.653705686330795, 61.49227134883404, 59.69967193901539, 67.50619724392891, 60.572082325816154, 66.74431532621384, 63.49529966711998, 68.9035114645958, 61.63823291659355, 63.95459622144699, 48.87623392045498, 49.21367861330509, 72.39961266517639, 68.94008830189705, 72.3206377029419, 68.57727617025375, 70.26910498738289, 77.05779790878296, 64.67420160770416, 1.0623532882891595, 2.5247448356822133, 5.853239642456174, 0.5681615439243615, 0.15735451423097402, 39.64877486228943, 85.8704674243927, 76.22118920087814, 76.43658444285393, 64.87200379371643, 52.37302288413048, 34.72123347222805, 53.55705074965954, 64.1050073504448, 87.62394413352013, 49.23387452960014, 0.8911220671143383, 0.4205413948511705, 0.2793113450752571, 0.12260211340617388, 0.20715345453936607], [0.026357554706919473, 0.08823806361760944, 0.10450353613123298, 0.028250059112906456, 0.07512070733355358, 0.20203032006975263, 0.24389108555624261, 32.973870635032654, 65.17547070980072, 51.13655403256416, 38.813385888934135, 10.69598525762558, 35.85044547915459, 47.80746906995773, 67.53670200705528, 61.53772450983524, 62.000984251499176, 47.22451955080032, 0.4038548277458176, 0.2528131700819358, 1.720825892407447, 6.803059000521898, 0.46712466864846647, 0.2686094865202904, 37.24124684929848, 57.89519816637039, 60.916727632284164, 60.40983863174915, 60.66641226410866, 60.5660330504179, 57.85471893846989, 57.34902307391167, 59.2957878112793, 58.16268481314182, 59.084982722997665, 59.10615898668766, 58.757881075143814, 56.14001914858818, 56.222208738327026, 56.43323801457882, 52.784381210803986, 48.41051571071148, 44.24277015030384, 41.75641916692257, 41.52759924530983, 41.467482671141624, 42.36311361193657, 41.83849096298218, 40.765998512506485, 41.991873532533646, 41.910622492432594, 43.483278304338455, 44.512145295739174, 46.15673124790192, 47.6197325438261, 47.700417414307594, 54.73865054547787, 46.57875560224056, 42.47280992567539, 50.110981464385986, 46.20698735117912, 41.46382726728916, 40.28359539806843, 38.920524939894676, 39.695789739489555, 38.84733706712723, 40.18459551036358, 39.733734503388405, 39.86658297479153, 53.31264786422253, 44.08817544579506, 39.53131936490536, 38.710962384939194, 39.30610544979572, 37.142193764448166, 39.49643723666668, 40.17307832837105, 38.53754349052906, 35.778781324625015, 39.43987347185612, 38.65734726190567, 40.19276887178421, 39.059107303619385, 38.50945919752121, 38.90390083193779, 37.544299587607384, 39.15932312607765, 39.95002269744873, 38.44985939562321, 38.52409601211548, 39.53288488090038, 38.635631427168846, 39.04486946761608, 38.890331760048866, 40.094141364097595, 40.262977704405785, 39.15049619972706, 41.129373013973236, 38.29271122813225, 38.90439860522747, 40.004367381334305, 37.910470739006996, 37.60057456791401, 38.16476829349995, 38.009831607341766, 38.701899871230125, 35.91075584292412, 36.919753700494766, 35.479395389556885, 39.3287218362093, 48.114154413342476, 39.31909695267677, 38.41835528612137, 37.610948011279106, 40.10487958788872, 39.943673238158226, 41.62270814180374, 39.87015478312969, 38.8102662563324, 38.61935310065746, 44.948973655700684, 50.21478809416294, 52.64047533273697, 53.4634617716074, 51.57856911420822, 52.257649675011635, 50.28522491455078, 54.02635596692562, 52.701097279787064, 50.651456862688065, 50.95400042831898, 48.566846922039986, 46.370895355939865, 48.35890308022499, 48.96915413439274, 51.03058911859989, 55.59316009283066, 52.07652099430561, 56.095671728253365, 55.94641953706741, 57.22602367401123, 56.64946161210537, 58.711489364504814, 58.37725929915905, 59.84426558017731, 61.030238941311836, 57.03979566693306, 58.10822993516922, 55.17113953828812, 73.52813690900803, 70.14300495386124, 63.03563833236694, 63.375389501452446, 73.13953936100006, 48.89680601656437, 0.5063791153952479, 0.5689319525845349, 2.132612527348101, 0.360046592541039, 0.05470167918247171, 31.961380764842033, 72.74573609232903, 61.687216088175774, 66.26351192593575, 52.84310705959797, 40.20767167210579, 10.380814969539642, 16.721198447048664, 38.69671694934368, 65.07523968815804, 39.34276208281517, 0.8008089289069176, 0.08932801880291663, 0.027761590499721933, 0.05127427422848996, 0.07618559277034365, 0.0600704422686249, 0.05692225924576633, 0.044913478632224724, 0.057703881757333875, 0.039088892153813504, 0.2241478199721314, 0.22715013386914507, 43.28384980559349, 73.87236043810844, 52.62976750731468, 43.10938596725464, 18.651386573910713, 39.23313796520233, 53.29848222434521, 72.47417986392975, 66.93034574389458, 67.26004645228386, 52.26925045251846, 0.25909343152306974, 0.17705960373859853, 2.4622989865019917, 15.492120198905468, 1.905532912351191, 0.1382539633777924, 40.17347350716591, 57.01911337673664, 63.14517505466938, 63.30030933022499, 63.05187106132507, 62.21312306821346, 61.371787413954735, 59.74627643823624, 59.99141648411751, 59.27253305912018, 60.40964864194393, 60.91868072748184, 60.59684559702873, 58.581532537937164, 58.114906176924706, 57.577447816729546, 54.53079789876938, 50.455873757600784, 45.986865162849426, 42.02764481306076, 45.34306190907955, 43.00367183983326, 45.710958167910576, 44.39112178981304, 43.449786901474, 43.731708973646164, 45.45727618038654, 45.555060133337975, 47.14882381260395, 48.671599701046944, 48.627446070313454, 50.64423345029354, 54.91255961358547, 47.27841965854168, 46.00607693195343, 52.056914046406746, 48.631150871515274, 42.06834442913532, 41.664969474077225, 41.50389991700649, 40.740710869431496, 40.79828158020973, 41.552411913871765, 41.2320701032877, 41.846831515431404, 53.08292359113693, 44.27455924451351, 39.71852011978626, 39.376971647143364, 39.590117409825325, 38.83894331753254, 39.88365925848484, 39.96814012527466, 40.942312851548195, 37.64442801475525, 41.75515003502369, 41.07030898332596, 43.056678995490074, 40.93552641570568, 39.69678148627281, 41.10169529914856, 40.471423119306564, 42.049934417009354, 41.40624135732651, 40.961425825953484, 41.88452549278736, 41.33567154407501, 41.41216903924942, 41.972331181168556, 40.93275636434555, 42.27581709623337, 40.88023938238621, 40.7543521374464, 42.8769638389349, 39.31682847440243, 38.79499487578869, 39.46761958301067, 37.565867230296135, 38.01987446844578, 37.84523203969002, 39.01647359132767, 38.99450697004795, 34.968459606170654, 37.97919765114784, 35.886596739292145, 41.06293737888336, 50.35077899694443, 40.23052364587784, 40.78334838151932, 39.277132004499435, 42.092571929097176, 41.96072660386562, 43.27789552509785, 42.33346380293369, 40.83368808031082, 40.96991457045078, 46.78799517452717, 51.99962452054024, 56.46968185901642, 55.858860835433006, 55.26884749531746, 54.3697739392519, 53.888324573636055, 55.56004486978054, 55.29001235961914, 53.033499643206596, 52.673237174749374, 51.57418414950371, 50.28008759021759, 49.86031271517277, 52.127658650279045, 52.94257812201977, 57.95143894851208, 55.23623384535313, 58.23721781373024, 58.27597953379154, 58.81126441061497, 59.468549340963364, 60.25782398879528, 59.40927252173424, 62.56381385028362, 63.7993061542511, 57.13333144783974, 57.546730265021324, 55.78799083828926, 70.16557574272156, 73.04108664393425, 66.49722218513489, 64.53895926475525, 73.79301309585571, 51.05249494314194, 0.4213529184926301, 0.9309996210504323, 3.400817275978625, 0.12378283325233497, 0.011476650524855359, 33.7116352468729, 79.64760214090347, 67.78998121619225, 72.10547044873238, 57.92215012013912, 42.04029433429241, 18.073500283062458, 28.445530124008656, 45.86545407772064, 74.09353137016296, 46.28730744123459, 0.6593996949959546, 0.11310381058137864, 0.021982219368510414, 0.030196346961020026, 0.03755766338144895, 0.1076637271034997, 0.15528592601185665, 0.1610165974125266, 0.16829624975798652, 0.15441580238984898, 0.37338482681661844, 0.39605010591913015, 53.67148540914059, 82.98280477523804, 66.64194121956825, 53.729204311966896, 18.399948365986347, 44.873950481414795, 63.71311537921429, 78.55047941207886, 72.46243849396706, 71.83389142155647, 56.22594773769379, 0.42307039664592594, 0.8829833788331598, 5.118330577388406, 24.37585160136223, 1.4322991808876395, 0.3333561716135591, 43.588753044605255, 59.43323403596878, 64.23446640372276, 67.06255584955215, 66.48566320538521, 65.2658298611641, 63.57462041079998, 61.92770138382912, 65.04119351506233, 60.57954132556915, 60.88752619922161, 63.12337562441826, 63.326398730278015, 61.64354883134365, 61.375765800476074, 61.71995893120766, 55.74831336736679, 53.994699865579605, 48.04791256785393, 45.08637808263302, 48.32888849079609, 46.01057589054108, 48.37578557431698, 47.17392526566982, 44.77368526160717, 47.29960352182388, 48.62441383302212, 48.92256863415241, 48.700250163674355, 50.34522369503975, 53.811431899666786, 53.25219690799713, 58.66529904305935, 51.06405772268772, 51.816208362579346, 53.28943870961666, 51.99591971933842, 45.42338579893112, 43.94027978181839, 42.373589649796486, 43.66040959954262, 43.21840591728687, 44.39667709171772, 42.594999969005585, 43.034856766462326, 55.339656695723534, 45.392398461699486, 41.29048436880112, 39.554049745202065, 39.549736976623535, 38.5691311955452, 39.23435389995575, 41.4296481013298, 40.882500261068344, 37.53091290593147, 41.14993371069431, 42.49146692454815, 46.3000101596117, 42.309601083397865, 41.66628420352936, 45.4173631221056, 42.8390646725893, 45.19699014723301, 44.54142652451992, 43.10027785599232, 43.698301166296005, 44.84267435967922, 44.248089864850044, 45.294948890805244, 42.94681169092655, 45.558688938617706, 44.19139690697193, 41.99863716959953, 44.27052766084671, 39.88533116877079, 39.16148900985718, 41.38209365308285, 38.80224108695984, 37.669472470879555, 37.61465661227703, 39.50027123093605, 38.15751448273659, 35.97494579851627, 38.1163626909256, 35.408324003219604, 41.92146711051464, 52.83599004149437, 43.361768424510956, 42.0691841840744, 41.629331186413765, 44.38052415847778, 45.49856476485729, 46.04210279881954, 44.99621272087097, 43.913419023156166, 42.97499857842922, 49.73321333527565, 54.60373118519783, 58.83316643536091, 58.695610016584396, 56.66746124625206, 56.39207102358341, 55.66946379840374, 57.49297834932804, 56.54733829200268, 55.10503828525543, 54.49796766042709, 54.356136471033096, 52.165193036198616, 53.36612619459629, 54.740493446588516, 55.23215286433697, 58.36391441524029, 57.98931151628494, 62.14376159012318, 60.42945317924023, 63.050894513726234, 61.99292488396168, 64.4472473859787, 63.26315872371197, 65.38642778992653, 63.88535633683205, 58.89283463358879, 57.619063183665276, 59.425528049468994, 68.02771925926208, 72.70864248275757, 68.74166294932365, 69.10207360982895, 78.49201574921608, 55.41746512055397, 0.7011449674610049, 2.664132993668318, 6.597820613533258, 0.5958666291553527, 0.11069270636653528, 37.441484704613686, 87.64018446207047, 73.44744443893433, 79.47503060102463, 70.53962767124176, 52.620192021131516, 18.321408480405807, 31.801935620605946, 56.32357969880104, 81.84028208255768, 59.59195151925087, 1.2303217314183712, 0.17474724969360977, 0.1868143185856752, 0.14884418807923794, 0.18262691359268501], [0.04071264076628722, 0.07606953571666963, 0.027472687252156902, 0.024247990659205243, 0.07419962043059058, 0.31821356853470206, 0.2861388662131503, 27.790606766939163, 64.47398275136948, 52.27180391550064, 33.672862127423286, 21.794099137187004, 44.95897851884365, 43.865207210183144, 68.92236605286598, 61.351583898067474, 62.235188484191895, 50.22339843213558, 0.45059974130708724, 0.15722883894341066, 4.101471891626716, 5.555854300037026, 3.7166416039690375, 0.09635553389671259, 31.6067248955369, 61.49284511804581, 58.51448133587837, 60.90034291148186, 56.79614134132862, 53.60491678118706, 57.89702586829662, 58.87996852397919, 61.51682563126087, 59.789510518312454, 58.76754015684128, 56.65408596396446, 58.37444365024567, 57.19210669398308, 54.90627095103264, 50.870450511574745, 44.4186133146286, 43.91424737870693, 44.33009706437588, 41.81581377983093, 42.79397249221802, 45.91672092676163, 49.10264477133751, 45.201652497053146, 43.937977105379105, 44.05068285763264, 43.68000514805317, 46.16727568209171, 47.419365495443344, 49.154075011610985, 49.93883550167084, 48.18318150937557, 48.17359082400799, 49.99167926609516, 46.04898422956467, 46.53473496437073, 45.92469669878483, 41.3593290746212, 38.19926284253597, 38.02114740014076, 39.669077172875404, 39.83083449304104, 40.633195638656616, 39.54220578074455, 38.207531198859215, 50.07957994937897, 53.713484555482864, 42.849658504128456, 38.91387529671192, 38.115975111722946, 39.16612856090069, 38.35079111158848, 39.55323278903961, 38.36769640445709, 40.22838056087494, 38.23764078319073, 38.107759952545166, 40.0883998721838, 39.36764694750309, 38.438623398542404, 38.46281670033932, 39.23941142857075, 38.86356599628925, 41.13155409693718, 38.96296106278896, 39.89483825862408, 37.66281522810459, 38.245646953582764, 38.75249795615673, 39.46835294365883, 39.9691204726696, 39.46239486336708, 37.91728377342224, 41.16346478462219, 40.64714469015598, 38.5544715821743, 36.96301817893982, 34.79390077292919, 38.15792106091976, 37.01273091137409, 38.57531726360321, 38.10811333358288, 35.073333978652954, 39.402449280023575, 39.429066851735115, 50.093031227588654, 45.601451843976974, 36.63462460041046, 39.33767415583134, 37.86654509603977, 40.74075646698475, 37.52253815531731, 40.14509283006191, 40.07773384451866, 40.04631333053112, 39.34452138841152, 51.174681186676025, 51.270010471343994, 46.07522942125797, 50.59075891971588, 53.20862464606762, 49.70382571220398, 49.869572818279266, 49.18945111334324, 54.22609984874725, 52.613477781414986, 50.3679920732975, 48.2843054831028, 50.135539546608925, 48.21766845881939, 50.556743144989014, 48.975180611014366, 51.979101821780205, 48.127548694610596, 51.474948674440384, 53.55201222002506, 53.72571989893913, 54.75525185465813, 56.666788682341576, 59.81126815080643, 59.429859817028046, 59.218439161777496, 58.671690300107, 57.261202186346054, 59.51660916209221, 55.97112961113453, 63.336388394236565, 69.93286103010178, 64.1678635776043, 72.11333602666855, 41.76191367208958, 0.07234032527776435, 0.2023314539110288, 1.7563747661188245, 0.31966336886398494, 0.17670169560005888, 32.20494769513607, 73.60046222805977, 67.82516732811928, 66.41245633363724, 56.65753997862339, 52.382351383566856, 25.37035323679447, 24.278916902840137, 36.8242534250021, 59.51149083673954, 40.63819617033005, 0.5178250512108207, 0.08988469635369256, 0.050925179093610495, 0.044654402299784124, 0.03528570814523846, 0.04853954909776803, 0.06342540989862755, 0.02386985157500021, 0.055219108253368177, 0.0747013271029573, 0.33660490822512656, 0.42099205660633743, 38.238195553421974, 73.94951909780502, 56.79085962474346, 39.42334055900574, 19.13141291588545, 48.45621965825558, 51.322535052895546, 74.50769394636154, 66.59237667918205, 67.78692618012428, 53.80350172519684, 0.5356314301025122, 0.2707748953253031, 2.12131145875901, 10.398199986666441, 4.788678316399455, 0.028625185077544302, 34.27615575492382, 61.50736793875694, 61.693861931562424, 64.42223712801933, 59.23434130847454, 55.443193539977074, 60.13443700969219, 60.57408481836319, 61.7291734367609, 62.142104879021645, 61.61294527351856, 59.36346597969532, 58.949014618992805, 58.33593271672726, 56.20662957429886, 52.225552797317505, 47.43599720299244, 44.72608141601086, 46.24142110347748, 43.0161389708519, 46.19765505194664, 48.03668037056923, 49.40196990966797, 46.25108778476715, 45.38463547825813, 46.345288529992104, 46.85129977762699, 49.02824856340885, 49.232829585671425, 50.98685346543789, 51.57084792852402, 50.36312073469162, 49.82657052576542, 52.93777897953987, 48.37785266339779, 46.643629521131516, 47.486458495259285, 42.02222250401974, 40.77848084270954, 41.323762983083725, 40.87924383580685, 40.246649980545044, 42.78231471776962, 41.92723520100117, 39.856015741825104, 51.70751519501209, 54.254708513617516, 44.01606671512127, 38.85018311440945, 37.371914237737656, 38.55709724128246, 38.48932407796383, 39.862319603562355, 39.7116044908762, 40.60712143778801, 38.529434725642204, 38.93944792449474, 39.85578395426273, 41.41158767044544, 41.969226747751236, 40.51010504364967, 39.59886074066162, 40.899359956383705, 42.09256432950497, 42.282109558582306, 41.480629965662956, 41.78642235696316, 41.08691029250622, 41.104898527264595, 39.88989092409611, 42.51293957233429, 40.74881203472614, 39.797122702002525, 41.049562096595764, 42.15558394789696, 39.123130068182945, 35.76748453080654, 34.68038946390152, 38.635304644703865, 37.542061507701874, 37.29054540395737, 38.00429530441761, 35.66652774810791, 38.55467677116394, 39.36846010386944, 50.11902943253517, 48.86391498148441, 38.65916736423969, 40.49847386777401, 39.57171879708767, 41.257323548197746, 40.6592508405447, 42.58282162249088, 40.026372000575066, 41.571122109889984, 42.46969789266586, 52.34724126756191, 53.06612089276314, 49.5214468985796, 51.143716648221016, 53.27563025057316, 51.90965294837952, 51.379790380597115, 51.74254171550274, 56.58143766224384, 57.20144659280777, 53.553501740098, 48.69158662855625, 52.09740847349167, 51.41928166151047, 51.38588145375252, 52.59434960782528, 54.288006126880646, 51.08624093234539, 53.794948384165764, 55.09544759988785, 56.75965189933777, 59.34013903141022, 58.330126628279686, 61.93456381559372, 61.15700773894787, 60.48048444092274, 60.37801913917065, 60.60296706855297, 60.302315801382065, 52.3979077488184, 67.28312641382217, 72.41936400532722, 66.98890820145607, 73.96439909934998, 43.96210581064224, 0.04771500447532162, 1.074803676456213, 2.713299742899835, 0.25255751505028456, 0.2757395664229989, 35.50228916108608, 78.79818812012672, 72.8668811917305, 72.45593324303627, 66.9789907336235, 48.05831640958786, 21.170913577079773, 26.95519309490919, 42.924742475152016, 69.44340169429779, 49.80121448636055, 0.8332667872309685, 0.10536824949667789, 0.04613874218193814, 0.05442792687972542, 0.037923738855170086, 0.17339847050607204, 0.15605226770276204, 0.12168458881205879, 0.17543502763146535, 0.19332569965627044, 0.41515402612276375, 0.48879149195272475, 48.43443542718887, 81.5232726931572, 66.13415166735649, 49.398861676454544, 33.26290212571621, 59.60731029510498, 59.87491473555565, 77.8309728205204, 73.30076470971107, 73.39466527104378, 62.087763994932175, 0.5961053038481623, 0.5910795391537249, 9.868335518985987, 14.188623894006014, 10.072023589164019, 0.1379761181306094, 38.30483257770538, 62.375324964523315, 64.97103407979012, 67.13444799184799, 64.7645303606987, 58.7736464291811, 62.12044224143028, 62.49105155467987, 64.30494502186775, 63.75325262546539, 64.96420964598656, 62.443352714180946, 63.515096604824066, 61.630724519491196, 59.762224182486534, 54.28194925189018, 50.04120200872421, 47.59385973215103, 50.06637945771217, 46.413179486989975, 47.660568952560425, 49.04992640018463, 53.268045857548714, 48.717573434114456, 48.28915782272816, 48.56358289718628, 48.70055414736271, 51.66878767311573, 52.482988983392715, 53.67853403091431, 55.77014319598675, 52.34206594526768, 53.48292052745819, 54.909071400761604, 51.12971059978008, 49.11250904202461, 50.01970276236534, 43.48952516913414, 42.58128270506859, 42.765876799821854, 43.05294759571552, 41.36751763522625, 46.06622390449047, 43.59472252428532, 43.54386605322361, 55.2346683293581, 56.73865422606468, 43.66521254181862, 38.16633000969887, 39.195348992943764, 40.35281628370285, 38.16980682313442, 40.50989605486393, 37.23410703241825, 40.181145295500755, 39.946158304810524, 40.79597510397434, 42.44300052523613, 43.862653747200966, 42.5728053599596, 42.35804848372936, 42.38676734268665, 41.37621536850929, 45.72988115251064, 43.6465897411108, 44.47087951004505, 43.06104876101017, 43.888473361730576, 44.40937981009483, 42.80376836657524, 46.79500959813595, 43.9256277680397, 39.70762990415096, 41.56180880963802, 41.07774518430233, 38.55037920176983, 35.75402945280075, 34.38464753329754, 39.51836206018925, 37.517837807536125, 37.21281297504902, 38.33313345909119, 35.401875749230385, 39.55060712993145, 40.25790497660637, 52.46554411947727, 49.22146059572697, 40.092032477259636, 42.38962858915329, 40.03722041845322, 44.090101942420006, 42.921516448259354, 45.050891786813736, 43.653942346572876, 42.588620111346245, 44.22946706414223, 57.03604906797409, 55.74956730008125, 51.58924274146557, 54.4680480659008, 56.46710939705372, 53.55428449809551, 52.42253042757511, 54.6988058835268, 58.930578008294106, 58.69500584900379, 53.915781900286674, 51.82350397109985, 55.09442165493965, 53.98840360343456, 56.847047209739685, 51.99457459151745, 56.11188545823097, 53.799409344792366, 56.44457660615444, 58.43956455588341, 58.927412778139114, 61.156285777688026, 60.33557541668415, 65.39344981312752, 65.74332743883133, 64.75405052304268, 62.35913023352623, 61.008568704128265, 61.1990562826395, 56.182934045791626, 72.69870981574059, 73.68154987692833, 72.0417782664299, 77.01407745480537, 49.22045364975929, 0.21745385573012754, 2.551525323651731, 5.455179177224636, 0.5775130796246231, 0.2655696199508384, 39.547274708747864, 87.4321836233139, 81.22788414359093, 78.82033333182335, 77.57394701242447, 70.18841251730919, 34.80799421668053, 38.029681742191315, 56.53197951614857, 79.22268614172935, 61.070121601223946, 1.4374698721803725, 0.2372142203967087, 0.13252615666715428, 0.17781459057005122, 0.23245708347531036], [0.0540159013326047, 0.10443007835419849, 0.022348506354319397, 0.023421637051797006, 0.08964772860053927, 0.16075277875643224, 0.1166853187896777, 24.60139039903879, 66.87423795461655, 39.3777734041214, 39.71766896545887, 28.509526289999485, 22.89047710597515, 39.53457958996296, 70.95410943031311, 61.569684594869614, 61.743821650743484, 50.23280672729015, 0.9732411231379956, 0.3736738784937188, 0.5438661226071417, 9.92130657657981, 5.529902167618275, 0.5072018899954855, 19.632653519511223, 62.182116732001305, 58.87978993356228, 60.86889199912548, 54.038716703653336, 53.21036495268345, 51.90006606280804, 53.82090859115124, 57.831787168979645, 56.63093380630016, 55.351766645908356, 56.070494279265404, 55.2231777459383, 52.75273650884628, 47.40267299115658, 46.20882645249367, 41.790279150009155, 40.76638989150524, 41.68939836323261, 43.28722782433033, 44.29120235145092, 47.85652443766594, 48.383730947971344, 47.11788587272167, 48.90483878552914, 49.82750907540321, 50.658068507909775, 52.426957190036774, 51.39496676623821, 53.77392031252384, 50.25483034551144, 49.77497689425945, 48.58471356332302, 45.802419260144234, 47.36479662358761, 44.81835186481476, 44.10997487604618, 39.611118882894516, 39.828026443719864, 41.29030957818031, 38.96209850907326, 38.37162919342518, 38.91985237598419, 38.73588904738426, 39.464746937155724, 48.16203944385052, 51.53896763920784, 50.803349912166595, 41.59453645348549, 37.92630448937416, 36.580226719379425, 37.88213945925236, 38.0498206615448, 39.823937863111496, 42.24913872778416, 38.621385991573334, 39.679522812366486, 36.71760454773903, 38.630725890398026, 40.45424044132233, 39.12388242781162, 39.05402697622776, 38.41561943292618, 38.94936919212341, 40.99611036479473, 38.15749928355217, 39.890274703502655, 39.92957979440689, 39.98349130153656, 39.35000069439411, 40.07475860416889, 37.72466070950031, 37.70780861377716, 40.66177770495415, 39.13211278617382, 38.25685255229473, 37.549873888492584, 37.08143122494221, 36.94475255906582, 36.23380310833454, 37.948457300662994, 35.38285776972771, 36.84297502040863, 38.72377149760723, 46.88602991402149, 50.411138758063316, 45.25026708841324, 37.86504037678242, 37.2489832341671, 40.06313502788544, 39.16292913258076, 39.65636305510998, 38.94371509552002, 39.314810782670975, 41.32484212517738, 39.27303582429886, 46.052411645650864, 53.59601005911827, 51.97159342467785, 50.82331024110317, 52.48722195625305, 52.160553485155106, 50.49288757145405, 51.836256086826324, 53.44321645796299, 52.75953434407711, 52.61352717876434, 52.87701644003391, 49.59086537361145, 48.670022785663605, 49.533116072416306, 50.39830304682255, 49.09121498465538, 48.53414207696915, 48.67006078362465, 47.4806410074234, 49.15619909763336, 48.98324377834797, 53.843441382050514, 52.85641774535179, 58.142234310507774, 60.000254809856415, 61.52574375271797, 62.61215105652809, 54.81571801006794, 30.551948994398117, 56.152816861867905, 73.69152054190636, 69.6642154455185, 74.23168435692787, 33.264843821525574, 0.16572542052017525, 0.5667036690283567, 3.2752423267811537, 0.22108010802185163, 0.1266834358102642, 31.562567465007305, 74.56428050994873, 69.17940706014633, 67.57545992732048, 56.30309879779816, 54.12766233086586, 29.379915185272694, 28.26907329261303, 41.111673563718796, 64.77073162794113, 41.35986104607582, 0.8305390679743141, 0.0777133928204421, 0.12797647970728576, 0.03311616186692845, 0.03510836082568858, 0.0388610231311759, 0.05793684933451004, 0.04120698904443998, 0.07244681604788639, 0.039175901547423564, 0.2173582967952825, 0.17259432381251827, 32.306052669882774, 74.93715450167656, 46.595102325081825, 49.60382267832756, 28.745942004024982, 30.17670013010502, 49.27431955933571, 75.20966067910194, 66.32247716188431, 65.88302314281464, 57.05643117427826, 0.8478482672944665, 0.38923285610508174, 1.8604308762587607, 5.936804283410311, 3.3174886973574758, 0.8090297877788544, 23.83775107562542, 63.86872082948685, 60.50935909152031, 63.02271522581577, 57.95643948018551, 54.51729342341423, 55.578724667429924, 54.87826645374298, 59.59710784256458, 57.954661175608635, 57.44811795651913, 57.529091611504555, 57.25076034665108, 54.54102694988251, 48.88377271592617, 48.10251943767071, 43.98078940808773, 43.77582460641861, 43.55330854654312, 44.39011104404926, 47.378145307302475, 49.9691578745842, 49.775930643081665, 51.5248703956604, 50.91566048562527, 51.205337941646576, 52.44339890778065, 53.51953536272049, 53.612478375434875, 54.35505352914333, 52.15035103261471, 52.049504444003105, 50.408718287944794, 47.502733021974564, 47.76028700172901, 47.60066896677017, 46.20273157954216, 40.88084734976292, 41.05015866458416, 40.45551337301731, 40.29303789138794, 39.56595830619335, 40.64764246344566, 39.93090592324734, 40.88731460273266, 50.142690762877464, 52.78295248746872, 51.78142882883549, 42.890019938349724, 38.006426990032196, 36.22206553816795, 38.84672150015831, 37.59569562971592, 38.483111411333084, 41.02530799806118, 39.66979153454304, 39.15170453488827, 36.77594281733036, 42.021268755197525, 42.702036425471306, 41.13138310611248, 41.20571851730347, 41.67178250849247, 42.595292553305626, 43.57290409505367, 40.969865173101425, 40.5850750207901, 41.73541769385338, 40.260576233267784, 42.10198402404785, 41.98058433830738, 39.290260300040245, 37.03576147556305, 40.6197177618742, 38.729862570762634, 37.38826476037502, 37.85483032464981, 37.45413802564144, 39.1043970733881, 38.04603226482868, 38.388614282011986, 36.23817287385464, 37.249348014593124, 37.44553528726101, 48.133267387747765, 54.262585490942, 46.58060610294342, 39.27517130970955, 39.411340802907944, 42.260712906718254, 40.78725837171078, 41.15233138203621, 40.81740215420723, 40.26143878698349, 42.5354989618063, 41.33573614060879, 47.74738669395447, 56.37407138943672, 54.87599417567253, 52.9987733066082, 57.967215701937675, 53.6658389121294, 53.41691806912422, 53.21821913123131, 54.87792067229748, 54.656996726989746, 55.74939250946045, 54.35652405023575, 50.54211013019085, 50.62678098678589, 53.467922732234, 52.389031425118446, 52.411890998482704, 50.972744822502136, 49.62182231247425, 47.921690940856934, 52.94073522090912, 51.6986920684576, 55.74289485812187, 56.695917919278145, 61.432679146528244, 60.37761256098747, 63.80325794219971, 64.50861409306526, 59.335370287299156, 34.10439357161522, 59.718423932790756, 73.56263145804405, 69.9669300019741, 76.68049335479736, 36.86346732079983, 0.24568415887188166, 0.8304265583865345, 3.8007512781769037, 0.20256033225450665, 0.15371966786915436, 34.715465381741524, 78.63644599914551, 74.76123914122581, 71.62301033735275, 65.41982039809227, 37.99507699906826, 17.24357731640339, 32.68731661140919, 45.735113471746445, 71.87264934182167, 51.994133815169334, 0.6951524515170604, 0.08864623741828837, 0.0636702889460139, 0.06262259907089174, 0.05815780896227807, 0.2006298428750597, 0.17324339132755995, 0.1473251305287704, 0.1995454463758506, 0.20938369736541063, 0.3180307033471763, 0.24808991962345317, 41.18300713598728, 85.00159084796906, 55.34558817744255, 56.462226659059525, 39.868570268154144, 32.42975503206253, 53.46348077058792, 83.33828330039978, 71.54507651925087, 72.70353555679321, 61.736472845077515, 1.2986426590941846, 0.921467951266095, 4.705384410917759, 22.771119810640812, 10.572744570672512, 0.6538832816295326, 27.770287357270718, 65.54317697882652, 62.72911638021469, 67.62345895171165, 60.45649632811546, 59.303444400429726, 58.192528411746025, 58.6932123452425, 63.950887620449066, 61.64338544011116, 59.612014442682266, 60.76014183461666, 59.97312046587467, 57.14750088751316, 52.19328872859478, 51.79340958595276, 44.19257864356041, 46.14991441369057, 46.36224702000618, 47.942897602915764, 50.46537704765797, 53.740436509251595, 53.247656151652336, 52.63718470931053, 51.78329072892666, 53.37286703288555, 55.104757100343704, 56.91752202808857, 56.56335063278675, 56.77805811166763, 53.120081797242165, 54.656464755535126, 52.30168171226978, 48.80356281995773, 54.0814758092165, 50.83883620798588, 48.74468497931957, 42.89907105267048, 44.252292439341545, 43.633746430277824, 43.582338988780975, 41.12987458705902, 41.28904804587364, 41.289830803871155, 42.88478001952171, 52.524399161338806, 54.89428259432316, 53.965338841080666, 43.35942395031452, 37.75559864938259, 36.72991208732128, 39.056671634316444, 37.887238785624504, 39.30839292705059, 42.58673541247845, 39.55397754907608, 42.96379677951336, 38.34606036543846, 43.07184778153896, 45.64421854913235, 44.25951965153217, 42.69838482141495, 41.747634038329124, 44.042885676026344, 45.18829621374607, 42.726415917277336, 43.057537749409676, 45.757847651839256, 43.202252984046936, 43.386094719171524, 43.87901186943054, 41.31665736436844, 38.33998829126358, 42.24562391638756, 39.16711650788784, 38.985053077340126, 38.56509581208229, 37.618167623877525, 38.952602818608284, 37.782930582761765, 38.57517667114735, 35.45630402863026, 37.730193212628365, 38.55416759848595, 49.47037763893604, 56.20738573372364, 47.696997597813606, 41.292308270931244, 41.18380129337311, 45.011453703045845, 42.99153909087181, 43.89022506773472, 42.93434076011181, 43.19189473986626, 43.48478302359581, 45.53533919155598, 50.28578348457813, 59.6096433699131, 55.70461191236973, 53.950105458498, 57.43723914027214, 55.508485436439514, 55.97245194017887, 53.536767438054085, 56.07950359582901, 58.896440640091896, 58.12648415565491, 56.90206065773964, 53.724640756845474, 54.084207862615585, 54.970023930072784, 53.94810676574707, 54.98347520828247, 53.63191433250904, 52.163665518164635, 52.355277836322784, 55.31217657029629, 55.20281843841076, 58.05831201374531, 59.699367955327034, 63.36817368865013, 64.83737245202065, 65.4315085709095, 68.46445262432098, 59.8116709291935, 40.09896710515022, 59.677123948931694, 78.00615102052689, 71.56000971794128, 81.08860641717911, 39.43314403295517, 0.29007512843236327, 2.837312975898385, 7.702294997870922, 0.5467027297709137, 0.1794722516206093, 38.34513321518898, 85.89652642607689, 80.42353570461273, 79.69794183969498, 73.81734699010849, 70.9977462887764, 42.338730320334435, 45.62216833233833, 58.49647410213947, 82.56928816437721, 64.5109623670578, 1.5178539650514722, 0.334721248364076, 0.18391839897958562, 0.2563329093391076, 0.17978368647163734], [0.018459223938407376, 0.014733374500792706, 0.00437276333286718, 0.030051589201320894, 0.028089899933547713, 0.17963166494155303, 0.10471817266079597, 33.62444132566452, 61.46183878183365, 46.50040380656719, 26.35354857891798, 16.354799307882786, 34.234107211232185, 39.03471261262894, 68.78648534417152, 62.054964154958725, 60.63198611140251, 51.270911023020744, 0.9059520775917917, 0.11059050520998426, 0.8850953530054539, 7.749346448108554, 4.258289951831102, 0.6794342980720103, 6.753331068903208, 64.71498101949692, 57.69393816590309, 60.254388973116875, 52.977270260453224, 48.861361518502235, 47.18331836163998, 47.99117401242256, 45.97897678613663, 46.54177598655224, 47.478372529149055, 48.11393402516842, 45.33613868057728, 43.23390148580074, 43.49577583372593, 39.168526232242584, 42.01374515891075, 42.491060346364975, 45.312655940651894, 48.08331526815891, 50.35663828253746, 52.7890245616436, 51.40057146549225, 53.20667155086994, 52.787390649318695, 52.37654149532318, 51.753291338682175, 53.798850774765015, 54.43632736802101, 52.73424290120602, 52.78706006705761, 50.00035040080547, 46.19095601141453, 47.809167578816414, 46.27329379320145, 47.84384451806545, 43.30455109477043, 38.27429361641407, 37.84560441970825, 34.72639359533787, 38.487956151366234, 40.46726234257221, 39.754640981554985, 41.90118759870529, 43.33695575594902, 49.083330407738686, 52.54654437303543, 54.354532957077026, 42.26755253970623, 38.820434510707855, 39.5082052052021, 39.27813895046711, 40.6842041015625, 38.84035684168339, 41.43310971558094, 42.80739717185497, 36.54914438724518, 36.519334986805916, 37.161367535591125, 39.38415326178074, 41.16932027041912, 41.07443556189537, 41.19058012962341, 40.27065709233284, 42.332145273685455, 38.563891276717186, 39.604248851537704, 38.444395288825035, 40.84938883781433, 40.71004271507263, 39.72119517624378, 37.25845992565155, 38.094339072704315, 39.866366386413574, 40.56110590696335, 38.142110109329224, 38.56226496398449, 36.45502343773842, 38.00100088119507, 38.72259356081486, 36.832320392131805, 35.54512046277523, 35.870595797896385, 40.83182618021965, 50.224739760160446, 49.2135114222765, 46.46907828748226, 37.799455896019936, 38.24155457317829, 36.88060440123081, 40.90198561549187, 39.54299993813038, 38.73624622821808, 39.61346335709095, 40.26002146303654, 39.942746087908745, 40.765671730041504, 49.06772844493389, 54.839664325118065, 54.67304706573486, 54.93851602077484, 53.3897153288126, 55.47736510634422, 53.42366650700569, 52.659371718764305, 53.59994284808636, 53.87804612517357, 52.80591085553169, 53.86634275317192, 53.462086245417595, 51.472478806972504, 47.80930817127228, 48.452393263578415, 51.69269219040871, 49.590527191758156, 50.27089208364487, 48.20947989821434, 52.01535187661648, 52.052453085780144, 54.38825614750385, 54.96088542044163, 58.84279131889343, 60.45091822743416, 61.05475902557373, 60.947126001119614, 57.94255502521992, 60.197012051939964, 64.11537319421768, 76.82614713907242, 68.9544515311718, 26.94757640361786, 0.20496085344348103, 0.29885856492910534, 1.9688205351121724, 0.12180946258013137, 0.2371866867179051, 30.25807276368141, 75.48578426241875, 62.47237555682659, 76.68714299798012, 55.2452127635479, 87.08868205547333, 42.67386473715305, 23.547201566398144, 41.86193190515041, 63.47880095243454, 40.880854949355125, 0.631814303342253, 0.08882193345925771, 0.035484670515870675, 0.03403902621357702, 0.07968283010995947, 0.027556184431887232, 0.03986055133282207, 0.04008042742498219, 0.04570991812215652, 0.04061419858771842, 0.2217282701167278, 0.09459131528274156, 38.76135528087616, 69.60978716611862, 52.221942991018295, 37.809521555900574, 20.466191992163658, 32.33509451150894, 47.57313944399357, 73.66517275571823, 67.15213984251022, 66.31130576133728, 55.35960182547569, 1.0699539491906762, 0.2874682901892811, 0.47743859176989645, 3.5106608318164945, 7.5702867563813925, 1.0568888252601027, 8.103553466498852, 67.77232736349106, 59.20214183628559, 63.43965545296669, 54.58648391067982, 51.98323979973793, 50.27679316699505, 50.36222018301487, 47.99508400261402, 50.76122157275677, 50.74846565723419, 49.557993337512016, 48.64623226225376, 44.945116862654686, 44.15513165295124, 41.76990084350109, 43.45077104866505, 46.00990332663059, 44.348419681191444, 50.04514999687672, 52.467922791838646, 53.72218608856201, 52.247333228588104, 55.07908187806606, 56.02357819676399, 54.793831184506416, 55.61377018690109, 56.32976956665516, 55.132446214556694, 54.9424222111702, 54.702358692884445, 51.18883162736893, 46.899769976735115, 50.818252712488174, 49.46229547262192, 49.01163965463638, 46.12879514694214, 42.011244893074036, 39.26101326942444, 38.02154257893562, 40.358394384384155, 41.27216175198555, 40.78910507261753, 42.032949328422546, 45.731195881962776, 51.30540557205677, 52.26476289331913, 55.9238525480032, 43.422325775027275, 36.14133507013321, 39.34662647545338, 39.67043749988079, 38.80044758319855, 39.54884022474289, 43.22204232215881, 43.33543203771114, 38.89621764421463, 37.562360018491745, 39.2744455486536, 41.32868751883507, 42.88402386009693, 42.225503996014595, 40.84631100296974, 42.60476164519787, 43.55122245848179, 41.41389414668083, 42.39020235836506, 41.90455421805382, 43.22690226137638, 41.80737063288689, 41.9348119944334, 39.00676131248474, 38.98942284286022, 39.775410667061806, 39.99419912695885, 38.210669830441475, 38.87686908245087, 37.57693603634834, 37.81901344656944, 38.23911890387535, 37.48894415795803, 36.05854891240597, 35.64042314887047, 40.93386970460415, 52.112995237112045, 51.24890260398388, 49.710460156202316, 39.59853395819664, 40.468371883034706, 39.862346202135086, 43.232256174087524, 41.1844814568758, 41.34795628488064, 40.49320735037327, 41.60816632211208, 42.69553877413273, 42.88145139813423, 49.63098742067814, 56.73552319407463, 56.96349956095219, 56.92631095647812, 55.59581235051155, 57.156533002853394, 56.412532925605774, 55.03939300775528, 55.63506044447422, 55.7244810461998, 54.06548626720905, 55.91183379292488, 55.36195009946823, 53.552897572517395, 51.653493493795395, 52.18058221042156, 53.242860808968544, 50.35729944705963, 51.95564188063145, 49.98893201351166, 53.927796855568886, 54.48113076388836, 56.84043176472187, 56.63708567619324, 61.32447615265846, 61.731989085674286, 64.0621380507946, 62.15343967080116, 59.07963640987873, 61.4332415163517, 67.85491973161697, 74.55807164311409, 74.80835661292076, 28.011515513062477, 0.08526450794306584, 1.8297953763976693, 2.3771552927792072, 0.14710045274114236, 0.16293212509481236, 34.819663390517235, 82.24409401416779, 66.23909443616867, 81.93409904837608, 63.342004492878914, 78.89869272708893, 31.218241341412067, 24.506475292146206, 49.275011122226715, 69.77786734700203, 51.793166399002075, 1.0334786376915872, 0.13068521482637152, 0.07015647410298698, 0.045772648154525086, 0.02505611155356746, 0.23234959080582485, 0.14403073699213564, 0.11768668380682357, 0.20722979184938595, 0.20161324791843072, 0.30798490333836526, 0.2137580345151946, 50.82457177340984, 79.32608619332314, 60.49382172524929, 40.40972962975502, 25.782796405255795, 45.81498138606548, 54.18275557458401, 79.86776232719421, 74.77214455604553, 72.31098622083664, 62.18300208449364, 1.176405712030828, 0.3335091727785766, 3.4852993302047253, 18.513680063188076, 10.105211958289146, 1.0591248865239322, 10.5174888856709, 70.9857389330864, 63.029448464512825, 65.79558983445168, 58.270477429032326, 54.93097722530365, 52.30322822928429, 52.709263041615486, 50.013300105929375, 54.00280483067036, 51.71091981232166, 52.81332425773144, 50.670030266046524, 46.4439844340086, 46.76989294588566, 42.325260043144226, 45.650484412908554, 46.01171962916851, 49.01995740830898, 54.171257391572, 54.02411788702011, 55.915523394942284, 54.791239723563194, 58.707837760448456, 57.81772792339325, 57.18816250562668, 58.99575211107731, 58.03614400327206, 57.409192845225334, 56.561108753085136, 55.97327269613743, 54.01670068502426, 50.536592826247215, 54.40741091966629, 49.802780002355576, 51.6056502610445, 48.16974923014641, 44.30051565170288, 42.889746353030205, 38.475086241960526, 43.27938124537468, 44.15447048842907, 42.4247957020998, 46.16260193288326, 48.36163893342018, 53.723569214344025, 56.09300807118416, 57.3661183565855, 42.94297009706497, 37.94901207089424, 40.59218443930149, 40.54512396454811, 40.21804131567478, 39.54381309449673, 42.79227018356323, 43.9864207059145, 38.87015104293823, 38.47182221710682, 40.71354992687702, 43.27482528984547, 45.93816697597504, 45.08742682635784, 44.95052017271519, 45.541426464915276, 46.169635355472565, 43.85165333747864, 46.03217773139477, 44.12479028105736, 43.61492604017258, 45.15832722187042, 43.11955042183399, 39.34523954987526, 38.95822271704674, 41.82283200323582, 40.05789510905743, 38.33703204989433, 38.676422238349915, 38.91761049628258, 38.02893318235874, 39.08371098339558, 37.51482456922531, 37.115454599261284, 35.71279026567936, 43.42775568366051, 53.65221664309502, 53.0347041785717, 51.444618701934814, 42.07985781133175, 42.01349437236786, 41.187931671738625, 45.95028452575207, 42.98832066357136, 41.18922360241413, 41.395864114165306, 44.21887703239918, 44.65476304292679, 45.57408191263676, 54.16637845337391, 59.99925546348095, 60.829913690686226, 59.36488710343838, 59.52647723257542, 58.3278239518404, 58.55005122721195, 56.33288159966469, 58.965642526745796, 58.37276414036751, 58.99933151900768, 59.01800751686096, 57.18202963471413, 54.66222524642944, 54.03658501803875, 54.159360229969025, 55.72792366147041, 53.60868997871876, 55.00336714088917, 52.168400064110756, 57.23629832267761, 57.098711505532265, 59.637807458639145, 59.25459802150726, 62.96290263533592, 66.63871139287949, 68.60341876745224, 63.927458077669144, 59.459684416651726, 61.7341435700655, 68.57213884592056, 74.16066616773605, 74.48788940906525, 32.10276737809181, 0.4100907384417951, 3.1533443927764893, 8.136833980679512, 0.3746545227477327, 0.2700960380025208, 38.08074340224266, 86.27438575029373, 73.40781256556511, 88.21429565548897, 73.49686458706856, 97.61477082967758, 55.303744822740555, 38.719333335757256, 60.78463152050972, 79.3672987818718, 64.39462780952454, 1.577084711752832, 0.313255547080189, 0.1445195748237893, 0.13921595003921539, 0.26088346203323454], [0.0814701963099651, 0.043041188473580405, 0.04319181476603262, 0.0370821693650214, 0.08564151896280237, 0.15098644187673926, 0.09781917528016493, 45.68730063736439, 62.03103303909302, 40.466380789875984, 30.852102488279343, 22.494943030178547, 35.53241394460201, 40.86784064769745, 67.22463235259056, 64.16221708059311, 59.64181624352932, 54.62790548801422, 1.312306725885719, 0.05128300930664409, 0.7089476706460118, 1.027063513174653, 3.0871329456567764, 1.5518838702701032, 2.3782721953466535, 57.066040858626366, 63.57961714267731, 58.58169972896576, 55.748446360230446, 53.3302067220211, 50.59623822569847, 46.24552868306637, 45.51850609481335, 42.27512553334236, 44.98936928808689, 43.5414569824934, 44.82418455183506, 41.97962298989296, 41.99606470763683, 44.983327612280846, 46.56342342495918, 46.97276785969734, 50.6224150210619, 50.88375359773636, 49.85077902674675, 49.67570722103119, 50.36244437098503, 50.45354828238487, 53.17159183323383, 53.3222271502018, 53.235280215740204, 53.36662016808987, 53.32081362605095, 53.4139808267355, 49.38893660902977, 45.57430610060692, 46.053809970617294, 49.410508051514626, 50.09314902126789, 46.458207070827484, 40.61917819082737, 36.936723589897156, 37.473847568035126, 36.15484334528446, 38.260542154312134, 37.65847586095333, 36.509060338139534, 38.70191127061844, 40.254051983356476, 42.58233144879341, 47.46180921792984, 54.460820853710175, 47.26135857403278, 36.17989160120487, 38.31053227186203, 37.57695123553276, 38.355016484856606, 37.05615118145943, 39.75014582276344, 44.70213510096073, 43.3191879093647, 38.672907426953316, 37.041210383176804, 37.84801349043846, 43.670038282871246, 39.527903348207474, 39.99834090471268, 41.864299178123474, 41.60102270543575, 41.810467466712, 39.571851789951324, 39.743948355317116, 40.020231530070305, 38.11278708279133, 35.63611038029194, 36.58955901861191, 38.601836040616035, 39.39040772616863, 41.54619164764881, 36.534169390797615, 39.14051033556461, 37.117780074477196, 38.42320382595062, 37.199981063604355, 37.00003959238529, 39.12187233567238, 37.03159689903259, 47.88046695291996, 51.515887677669525, 48.941085040569305, 43.538846522569656, 38.14849756658077, 38.574359714984894, 36.89786307513714, 38.704814314842224, 38.04464913904667, 39.73254136741161, 39.36194345355034, 40.91799035668373, 38.99860315024853, 39.99584823846817, 40.743515118956566, 43.823352456092834, 48.17647486925125, 50.01564837992191, 50.17406567931175, 50.922997891902924, 52.277921587228775, 51.442544013261795, 35.17441615462303, 45.38253799080849, 56.49474151432514, 52.64664240181446, 52.14506931602955, 53.453707695007324, 49.02824476361275, 53.718697875738144, 55.97320809960365, 53.17632257938385, 53.7451558560133, 51.940583288669586, 52.622293308377266, 54.40415449440479, 51.064901277422905, 51.52589254081249, 54.97097387909889, 62.22363330423832, 62.92924024164677, 66.59094795584679, 59.390353336930275, 49.35802906751633, 60.577253848314285, 74.88781034946442, 68.53113904595375, 18.034214191138744, 0.535974302329123, 0.6418359093368053, 2.233415418304503, 0.1874793422757648, 0.08602376954513602, 34.92248207330704, 77.75212705135345, 62.3295184224844, 79.87491354346275, 55.032237991690636, 56.55331917107105, 53.676132559776306, 29.190423153340816, 39.52525869011879, 65.98347455263138, 40.03951169550419, 0.9530880732927471, 0.095631019648863, 0.05536026474146638, 0.019380292287678458, 0.06440047320211306, 0.04985112442227546, 0.007522005771534168, 0.04407481465023011, 0.022386227865354158, 0.037150213174754754, 0.05007323437894229, 0.18234204762848094, 53.10761846601963, 70.35868138074875, 47.30338051915169, 38.62990513443947, 23.593241795897484, 24.5363112911582, 47.16956689953804, 72.09407866001129, 69.48159724473953, 64.79844734072685, 58.294066563248634, 1.7625301983207464, 0.1315013546263799, 0.18566919956356287, 1.5886508161202073, 5.142474481835961, 0.8389946236275136, 2.5832645455375314, 61.01532094180584, 64.72763434052467, 61.89276985824108, 57.31990523636341, 55.41100926697254, 50.34529969096184, 48.636029809713364, 47.485850527882576, 44.83861617743969, 45.83936087787151, 44.9834606051445, 46.97703503072262, 44.319651424884796, 43.94135892391205, 45.67175567150116, 48.614644557237625, 49.953643307089806, 52.39506170153618, 53.88211950659752, 53.39193440973759, 53.340036794543266, 52.68414258956909, 52.53117419779301, 53.368976041674614, 57.72151328623295, 56.03837840259075, 54.585469365119934, 54.807130470871925, 56.33251681923866, 51.68852761387825, 46.12783379852772, 49.75399062037468, 51.87915958464146, 51.67003020644188, 50.01631334424019, 43.45272034406662, 39.454878866672516, 38.213242292404175, 38.771333545446396, 39.81352262198925, 40.839581564068794, 39.859823137521744, 39.9534273147583, 42.01341837644577, 43.83865423500538, 49.68535490334034, 56.24762937426567, 48.08137357234955, 37.173929661512375, 37.269524931907654, 37.852501049637794, 37.849062234163284, 35.482473224401474, 39.73922900855541, 44.6652352809906, 42.64009974896908, 38.67517590522766, 38.09230998158455, 39.953089132905006, 44.55267772078514, 40.51133617758751, 41.40971437096596, 43.917568400502205, 43.768069222569466, 43.74360233545303, 41.221932247281075, 41.160983517766, 41.85417652130127, 40.508383736014366, 35.61641603708267, 36.727392822504044, 38.78616414964199, 40.16989789903164, 40.20388327538967, 36.67975477874279, 38.76607842743397, 37.53128908574581, 38.47083427011967, 36.67771428823471, 37.40198202431202, 38.518175929784775, 37.96809084713459, 48.33843357861042, 56.142166033387184, 52.438998743891716, 45.30704364180565, 40.6646541506052, 39.50420022010803, 39.06885378062725, 40.24334415793419, 39.72295828163624, 41.58146895468235, 39.80913385748863, 42.6041042804718, 41.93381264805794, 41.51870772242546, 41.9248603284359, 45.90924672782421, 51.39981530606747, 52.833242788910866, 52.80374497175217, 54.439545795321465, 54.43294174969196, 54.68818545341492, 38.24687048792839, 46.29739969968796, 60.054990872740746, 53.673560097813606, 54.16127912700176, 54.33605834841728, 53.37777636945248, 57.29741804301739, 57.656209990382195, 55.33644586801529, 56.56695283949375, 55.14279305934906, 55.55613487958908, 57.386948838829994, 54.32942010462284, 52.235740050673485, 57.607109025120735, 62.700667306780815, 64.3765939772129, 68.1079937517643, 59.652007296681404, 51.27334289252758, 64.4099409878254, 73.32414105534554, 72.03424707055092, 19.748171120882034, 0.17348893830785528, 2.3283485742285848, 3.8716713851317763, 0.2829208842013031, 0.04205671473755501, 37.83442921936512, 83.45150962471962, 65.95546245574951, 83.91518354415894, 61.12215980887413, 71.84954658150673, 52.91028365492821, 40.11605478823185, 50.04970595240593, 74.08127322793007, 49.847910180687904, 1.2396699422970414, 0.13779574655927718, 0.0038296631419143523, 0.09363758872495964, 0.04454807480215095, 0.21798410540213808, 0.22811090340837836, 0.12934246187796816, 0.13938354182755575, 0.31402200751472265, 0.3629991825437173, 0.5742282152641565, 66.66791662573814, 77.36938118934631, 54.16023038327694, 41.06449529528618, 33.58130984008312, 48.042680248618126, 56.98190197348595, 78.42680364847183, 75.04982605576515, 68.2024946808815, 66.57488241791725, 1.9823636021465063, 0.31207496824208647, 3.34187270142138, 5.659048687666655, 11.206396669149399, 3.297182349488139, 5.15052150003612, 62.78099499642849, 68.22975441813469, 66.21811956167221, 60.512056946754456, 58.69102366268635, 54.16064456105232, 52.365662679076195, 52.27005980908871, 46.21650964021683, 48.673830181360245, 47.20004506409168, 49.31029602885246, 47.68216699361801, 46.80711194872856, 47.7336086332798, 52.13883765041828, 52.2401288151741, 55.26856251060963, 55.60019351541996, 54.465289413928986, 55.908372178673744, 55.26347458362579, 54.85609844326973, 56.385436579585075, 59.11543808877468, 58.19236122071743, 57.96112842857838, 56.97178691625595, 59.0062091499567, 54.922568276524544, 48.92708279192448, 52.579955980181694, 54.574339762330055, 56.73030987381935, 52.12034784257412, 45.78023225069046, 40.836777314543724, 39.80680078268051, 39.979653507471085, 42.40666687488556, 42.18762382864952, 41.37447506189346, 41.783564910292625, 45.203434601426125, 47.266993671655655, 50.79781360924244, 60.48321269452572, 51.04087136685848, 35.81980772316456, 38.4426511824131, 38.10134209692478, 38.20377700030804, 37.35828056931496, 39.21038098633289, 43.925783559679985, 44.887044578790665, 40.68235360085964, 39.29932661354542, 40.394101068377495, 47.86551475524902, 43.65964584052563, 44.43867623806, 46.640962064266205, 47.69941046833992, 46.38463921844959, 44.8253320902586, 44.568484872579575, 42.8008197247982, 42.09165997803211, 36.63492098450661, 38.807948380708694, 38.667325526475906, 39.41263273358345, 40.576126500964165, 34.69896286725998, 39.29377131164074, 38.0148359388113, 37.98304304480553, 37.45256491005421, 36.710852310061455, 39.318112805485725, 36.88730724155903, 50.16195572912693, 57.633221223950386, 54.32072997093201, 48.71250830590725, 43.23911480605602, 41.74359865486622, 39.88444201648235, 42.75481939315796, 41.367187052965164, 42.399553656578064, 43.73043604195118, 45.7575398683548, 44.52084302902222, 43.029616847634315, 45.479204803705215, 49.357348904013634, 53.58513884246349, 54.69420053064823, 55.30774600803852, 55.14624327421188, 56.88306167721748, 56.213735193014145, 38.2718313485384, 50.287098214030266, 59.81050819158554, 56.432557851076126, 57.61320769786835, 58.965049758553505, 56.677720695734024, 59.123869836330414, 59.3240012973547, 56.27994664013386, 58.624922409653664, 56.757607609033585, 59.244935140013695, 60.774501264095306, 58.35588924586773, 56.80480107665062, 61.068628281354904, 66.00486740469933, 66.60667151212692, 72.45848670601845, 63.468051329255104, 53.67852263152599, 68.57050493359566, 74.7255590558052, 73.60279530286789, 24.13067165762186, 0.9057204681448638, 4.236650113016367, 5.506233712658286, 1.4631165959872305, 0.12210443659569137, 40.335626006126404, 90.06748661398888, 72.63794347643852, 90.35785183310509, 69.21860575675964, 74.99616533517838, 66.3057504594326, 45.84918335080147, 59.053991585969925, 82.61841952800751, 64.91097450256348, 1.666717033367604, 0.2564337820513174, 0.14196096133673564, 0.1613923319382593, 0.11710913706338033], [0.07675837492570281, 0.00399332038796274, 0.08248850455856882, 0.05635266090393998, 0.05855140327184927, 0.22051681793527678, 0.18356488435529172, 37.518548369407654, 57.66197048127651, 41.370679065585136, 23.16972602158785, 43.07829223573208, 62.374963983893394, 40.95533475279808, 66.26023650169373, 63.936858773231506, 59.817218631505966, 61.09728254377842, 5.088543025776744, 0.26113638596143574, 0.3083263209555298, 1.017929872032255, 7.1247155405581, 0.6755025184247643, 0.6864051427692175, 52.6691447943449, 70.43342337012291, 54.893541634082794, 59.68478433787823, 56.41486220061779, 62.74794436991215, 54.28501948714256, 55.50302512943745, 44.93394546210766, 44.01259370148182, 43.72473634779453, 41.77109397947788, 41.21472403407097, 45.60249298810959, 49.669821336865425, 53.12771938741207, 54.785984605550766, 52.940765619277954, 52.63957858085632, 50.642907321453094, 53.008151203393936, 52.67584003508091, 51.69576242566109, 52.27636747062206, 55.450295358896255, 53.23496863245964, 52.888020649552345, 50.558031275868416, 50.16838498413563, 45.8914028853178, 47.58967615664005, 48.21975454688072, 50.53056254982948, 49.04608100652695, 47.34263241291046, 40.237089693546295, 37.52376928925514, 37.4832558631897, 36.204445883631706, 38.73161807656288, 36.91931672394276, 39.53325346112251, 37.55646653473377, 39.22672010958195, 39.69846099615097, 44.205437153577805, 51.43699251115322, 53.27148087322712, 42.8424084931612, 40.61013087630272, 39.34411101043224, 38.26200507581234, 39.024035185575485, 39.99178245663643, 42.59057700634003, 44.76236566901207, 42.761282846331596, 37.109162136912346, 35.47847203910351, 38.47431108355522, 39.60202217102051, 41.875018402934074, 41.56874343752861, 40.462607592344284, 39.81191910803318, 40.78191205859184, 41.035799235105515, 38.57062831521034, 34.287289157509804, 36.57523758709431, 39.20724995434284, 41.272028759121895, 38.92918847501278, 40.37700958549976, 41.00228503346443, 38.169130459427834, 36.498694494366646, 37.71190479397774, 38.50199639797211, 37.9068723320961, 36.877005994319916, 39.64706115424633, 52.54915103316307, 49.28284250199795, 44.55550856888294, 35.97859360277653, 37.133488431572914, 38.45066495239735, 38.27940434217453, 38.168290704488754, 37.837503254413605, 39.857604056596756, 37.771037220954895, 41.48652344942093, 38.72429966926575, 41.896817833185196, 39.86334554851055, 38.83945629000664, 40.49381911754608, 42.60506562888622, 45.76055310666561, 51.40024088323116, 51.67978808283806, 54.084044471383095, 47.27137863636017, 27.793213427066803, 41.31829887628555, 56.08827352523804, 57.188778072595596, 52.78981111943722, 49.66906517744064, 53.61102685332298, 57.967816069722176, 56.95327810943127, 58.70269663631916, 57.24352553486824, 57.17541038990021, 53.45061466097832, 54.13599908351898, 46.62776917219162, 51.817184910178185, 55.06156861782074, 60.75113631784916, 60.15267223119736, 68.67290943861008, 65.91101244091988, 53.75250466167927, 60.40400594472885, 60.645992159843445, 12.149946838617325, 0.32942445133812726, 1.5289274021051824, 1.9639052613638341, 0.24392580322455615, 0.23725232225842774, 38.97164359688759, 78.03010493516922, 64.14953336119652, 77.43864387273788, 58.21039505302906, 59.09593753516674, 34.712851122021675, 19.283839836716652, 38.35019074380398, 65.63076987862587, 37.394390031695366, 1.1381867690943182, 0.14794592221733183, 0.06542829578393139, 0.06091986739193089, 0.054956035455688834, 0.05413562088506296, 0.06329478448606096, 0.061734326227451675, 0.0407785768766189, 0.026167794967477676, 0.1752294972538948, 0.18360227375524119, 49.469735473394394, 65.59429943561554, 46.60818502306938, 25.617649666965008, 24.767468087375164, 46.448483392596245, 46.81439995765686, 70.4234679043293, 70.94841733574867, 64.46835145354271, 67.31366157531738, 5.215188805013895, 0.40140375145711005, 0.3526780160609633, 1.9207470584660769, 4.532688902691007, 0.5391356733161956, 1.134604630060494, 52.93756239116192, 71.37165382504463, 60.946913212537766, 60.40142208337784, 60.24731755256653, 63.33946242928505, 57.62820929288864, 58.77289406955242, 46.81550569832325, 47.21816249191761, 45.55363900959492, 42.70840868353844, 43.296210542321205, 49.303239807486534, 53.21702599525452, 54.07076798379421, 55.83015717566013, 54.96586315333843, 53.8867362588644, 55.25460585951805, 56.21107153594494, 53.78610625863075, 53.73980954289436, 53.38158376514912, 55.99248826503754, 54.854061752557755, 55.73241502046585, 51.37389689683914, 52.614583522081375, 48.566075563430786, 50.25378920137882, 52.54082947969437, 52.93760418891907, 53.313187435269356, 49.13563460111618, 40.864553824067116, 37.76969589293003, 38.79229322075844, 37.6966106146574, 38.49405862390995, 38.14616069197655, 40.201588198542595, 39.166075363755226, 40.72173088788986, 40.8140317350626, 46.622183471918106, 53.85862536728382, 54.18496325612068, 41.13186568021774, 40.887044817209244, 37.51615449786186, 39.412009567022324, 39.14908267557621, 39.48857165873051, 42.461399137973785, 46.728573963046074, 43.90144966542721, 37.24775590002537, 37.56558604538441, 41.11418142914772, 41.610062420368195, 42.15445160865784, 43.32128919661045, 42.35108345746994, 43.83535981178284, 42.94543616473675, 44.030897319316864, 40.184017941355705, 37.844312489032745, 37.41211228072643, 39.439520090818405, 41.913529336452484, 39.99050572514534, 40.07943995296955, 39.64961461722851, 38.71725484728813, 36.765090599656105, 37.217843905091286, 38.01824815571308, 38.388819471001625, 35.85248216986656, 38.883598521351814, 54.88476410508156, 52.47264973819256, 48.38228702545166, 38.51574406027794, 37.83888258039951, 40.95790721476078, 40.01626834273338, 40.55742010474205, 38.66142064332962, 42.625014558434486, 41.65226675570011, 42.80225224792957, 41.25679537653923, 42.86507047712803, 42.13293716311455, 41.2707482278347, 43.479668498039246, 44.970248714089394, 47.04798102378845, 51.88355214893818, 53.26033227145672, 56.7070247232914, 53.35604913532734, 31.67029358446598, 41.67259946465492, 59.49351780116558, 58.99132154881954, 54.949220046401024, 53.84949065744877, 55.96329443156719, 59.68790777027607, 60.20029507577419, 61.440415531396866, 59.30829294025898, 60.04642613232136, 54.38370779156685, 57.336373552680016, 50.67875079810619, 54.359324499964714, 56.86378911137581, 62.951989620923996, 61.795445680618286, 71.69892266392708, 65.91468304395676, 58.54941286146641, 62.83579185605049, 66.39127627015114, 13.300512749701738, 0.4495938046602532, 2.409982681274414, 0.861760686384514, 0.11570402886718512, 0.10831525112735108, 43.11627879738808, 85.22495806217194, 68.68083581328392, 83.73826503753662, 62.81972251832485, 63.91467556357384, 45.35490967333317, 23.959944918751717, 42.78145216405392, 75.37252753973007, 44.540734961628914, 1.2189979827962816, 0.09870628666249104, 0.08024601629585959, 0.03924040531273931, 0.043972765633952804, 0.19549461139831692, 0.19151512649841607, 0.151623367855791, 0.2398278418695554, 0.16123642155434936, 0.32730906328652054, 0.42601081542670727, 61.131450310349464, 73.14374193549156, 55.84158316254616, 34.6403282135725, 56.21939688920975, 75.72031527757645, 59.28103320300579, 77.15956404805183, 76.504737585783, 70.88167011737823, 73.96714255213737, 6.43244493752718, 0.5239750212058425, 1.75107084447518, 3.7670164508745074, 15.947797447443008, 1.7722671758383512, 2.030089753679931, 56.56941890716553, 73.32829043269157, 60.53767517209053, 64.31702077388763, 64.91535946726799, 68.32174748182297, 59.1427206248045, 61.279098987579346, 49.24124613404274, 49.34336945414543, 49.5433147251606, 45.722954124212265, 46.10721230506897, 50.44469095766544, 56.61732293665409, 56.98793224990368, 57.859039306640625, 57.46394030749798, 58.675987869501114, 58.13008636236191, 56.63186855614185, 54.849612191319466, 55.89241683483124, 55.89060813188553, 58.183386102318764, 58.18386107683182, 56.65249764919281, 54.13206249475479, 55.73197044432163, 51.70547090470791, 54.31100629270077, 54.013246670365334, 54.02525782585144, 55.89372016489506, 53.76510478556156, 44.509804621338844, 39.97476316988468, 40.81908166408539, 40.39992615580559, 40.56343138217926, 42.11572028696537, 42.96984605491161, 39.99766454100609, 43.63574892282486, 45.920414328575134, 46.929860562086105, 57.10151955485344, 58.0427860468626, 43.54106940329075, 41.17251209914684, 37.11064785718918, 39.21964108943939, 39.371081963181496, 39.78334464132786, 43.944657146930695, 46.759428307414055, 45.84057681262493, 38.63693855702877, 37.32500955462456, 42.50974394381046, 44.80090320110321, 45.85785448551178, 46.90702758729458, 44.93137300014496, 46.02116972208023, 45.20896330475807, 44.77912276983261, 41.98699839413166, 37.637075409293175, 38.9424991607666, 39.09827180206776, 43.4759446978569, 40.89252412319183, 41.05821043252945, 43.875181674957275, 38.33799719810486, 36.95552118122578, 38.059806525707245, 39.448548406362534, 38.15329670906067, 36.83206580579281, 39.15871515870094, 57.261297181248665, 54.22724738717079, 49.993088990449905, 40.17144061625004, 39.32136543095112, 42.59605631232262, 42.524950727820396, 42.04696297645569, 41.25821650028229, 45.36956548690796, 43.858880549669266, 46.421394646167755, 43.74741353094578, 45.2713293582201, 44.69227463006973, 43.5938523709774, 44.70465436577797, 46.17679797112942, 51.38382576406002, 55.01521110534668, 56.22931435704231, 58.14458258450031, 52.439169734716415, 28.642002381384373, 45.77670603990555, 61.85678578913212, 60.514397621154785, 57.69615724682808, 55.13209283351898, 57.61740267276764, 64.00773257017136, 61.46125741302967, 64.06551226973534, 61.695663034915924, 62.41018809378147, 56.31607510149479, 58.87455761432648, 51.08092501759529, 58.17189171910286, 60.510358437895775, 67.56412893533707, 65.57604521512985, 74.33035746216774, 68.25842767953873, 60.495394840836525, 68.44807550311089, 70.48544257879257, 15.893185827881098, 0.4725482244975865, 5.066213998943567, 5.393451964482665, 1.42792145954445, 0.32771184167359024, 46.803205758333206, 93.34651306271553, 75.33519074320793, 88.79827871918678, 72.09164679050446, 75.1157221198082, 51.48513972759247, 32.771729081869125, 56.592149287462234, 84.35284405946732, 57.38021560013294, 1.3844691286794841, 0.35260504810139537, 0.14664939022623003, 0.17123067198554054, 0.1031304887146689], [0.009553519539622357, 0.036602352338377386, 0.007906392347649671, 0.06758194896974601, 0.046601048234151676, 0.1657256728503853, 0.0612221218761988, 27.400795184075832, 64.94635820388794, 41.49624712765217, 22.939583770930767, 76.50546714663506, 90.47583550214767, 46.55319057404995, 57.17428185045719, 66.11544907093048, 58.83981987833977, 67.86102220416069, 8.75981530174613, 0.43304777063895017, 0.825376866851002, 0.2312331780558452, 2.6232709363102913, 0.20988567121094093, 0.6021883024368435, 46.620287373661995, 73.42937260866165, 54.43559020757675, 60.83445064723492, 57.4508386105299, 62.12025225162506, 57.01011925935745, 56.407482996582985, 49.250897616147995, 44.60720479488373, 43.33969920873642, 43.5191597789526, 49.92369331419468, 55.67690759897232, 56.18666544556618, 55.59106260538101, 49.675642624497414, 50.957693830132484, 52.512786984443665, 53.26003968715668, 52.141748294234276, 53.1765391677618, 53.02563786506653, 52.38390929996967, 52.258979603648186, 53.13598774373531, 51.134908720850945, 48.04500952363014, 46.71198405325413, 48.70160669088364, 50.976354628801346, 51.838828548789024, 51.709076911211014, 49.537489637732506, 47.36588716506958, 39.25689809024334, 36.4678705483675, 37.04572454094887, 36.52056612074375, 38.111042976379395, 38.03072288632393, 36.035358756780624, 38.33336904644966, 40.27026191353798, 41.98020435869694, 43.21322679519653, 49.009781554341316, 53.68225783109665, 45.34295551478863, 38.17902512848377, 39.46297623217106, 39.47196654975414, 40.363664701581, 41.669814214110374, 44.10026639699936, 45.19647337496281, 46.798395216464996, 42.51856327056885, 37.184056118130684, 39.93377856910229, 43.14566262066364, 39.269988387823105, 41.75285495817661, 42.90835775434971, 40.85003100335598, 42.854879423975945, 39.31606471538544, 37.126663997769356, 38.21904078125954, 37.06767976284027, 37.225356101989746, 38.725884184241295, 38.26811894774437, 38.64463314414024, 40.20944617688656, 38.60508106648922, 37.14197717607021, 38.28509643673897, 38.111970126628876, 37.77913838624954, 36.12471476197243, 47.087343111634254, 51.34647376835346, 49.62318643927574, 46.71354956924915, 43.47806118428707, 40.659896805882454, 37.23342686891556, 40.24536944925785, 37.81286917626858, 38.62002186477184, 39.296229779720306, 39.6235366165638, 38.35728116333485, 40.20428605377674, 41.02489002048969, 41.39715604484081, 43.31043317914009, 40.575982108712196, 41.10514931380749, 39.236629977822304, 44.565099254250526, 52.04199604690075, 50.75322300195694, 59.48923163115978, 55.9175068885088, 33.91465075314045, 34.188023284077644, 44.76602487266064, 52.250164076685905, 53.08114908635616, 53.34969587624073, 56.45468786358833, 57.8385242074728, 57.87758991122246, 57.08350472152233, 59.56438019871712, 57.01503999531269, 55.50468184053898, 52.297087758779526, 49.35889922082424, 49.63380306959152, 57.86086320877075, 59.638449624180794, 60.134653598070145, 61.38374537229538, 58.44394572079182, 50.041050016880035, 56.55942164361477, 6.371820140630007, 0.30805638700257987, 0.5217017338145524, 2.6280076196417212, 0.07176441125920974, 0.11670172767480835, 38.41786891222, 77.50507190823555, 65.80623686313629, 73.44228431582451, 63.200078308582306, 45.2364282310009, 24.612660594284534, 43.47784839570522, 45.12236975133419, 67.64495059847832, 30.266485512256622, 0.6818546494469047, 0.04186281010333914, 0.09633329173084348, 0.028818299324484542, 0.04681545098719653, 0.01883452987385681, 0.0534166356374044, 0.0326146629959112, 0.05116488166095223, 0.06574239494511858, 0.2762204484315589, 0.1126265428320039, 37.83417463302612, 70.8241868019104, 45.3823783993721, 24.642194509506226, 67.62936383485794, 86.30172908306122, 51.375409215688705, 63.83634656667709, 72.47325271368027, 63.395471423864365, 74.17490020394325, 9.404411762952805, 0.43612026202026755, 0.8933535567484796, 1.3580533023923635, 5.430577397346497, 0.48999035730957985, 1.2097561662085354, 49.66214954853058, 75.05430981516838, 57.70162895321846, 64.30075764656067, 59.55760516226292, 63.594603538513184, 58.8927586376667, 59.36445012688637, 50.389400124549866, 47.72626742720604, 42.63640254735947, 45.32275199890137, 52.63514041900635, 59.47886198759079, 58.340382277965546, 59.671146869659424, 52.08211049437523, 54.21665735542774, 53.720593973994255, 56.35497361421585, 53.01786348223686, 54.834553599357605, 55.65096639096737, 53.9308974891901, 53.991964012384415, 55.31389407813549, 51.0131024569273, 50.16941852867603, 47.630033791065216, 49.11068134009838, 52.65183672308922, 52.49236308038235, 52.53586694598198, 50.35504996776581, 48.178914338350296, 41.49107560515404, 37.3478539288044, 39.011685848236084, 37.76223689317703, 39.36856649816036, 39.35632735490799, 38.259523808956146, 38.90387423336506, 40.38817338645458, 41.641327142715454, 43.327931240200996, 51.651418805122375, 55.80304943025112, 46.28297187387943, 39.62416738271713, 40.24923004209995, 39.82312470674515, 38.259033635258675, 42.00605057179928, 44.49049785733223, 45.81266351044178, 48.764865696430206, 43.6175175011158, 39.16661113500595, 40.66032998263836, 42.58847951889038, 41.14991471171379, 42.478000447154045, 46.022039875388145, 44.289192259311676, 43.03855016827583, 40.465111657977104, 39.06123898923397, 37.96377047896385, 37.086522951722145, 37.51076638698578, 38.29809933900833, 38.81454102694988, 38.270326629281044, 39.0417118370533, 38.0401311814785, 37.4824009090662, 37.77354508638382, 37.73192211985588, 38.284621462225914, 35.9299486130476, 48.11410881578922, 52.61993743479252, 52.438261583447456, 49.561568945646286, 44.051598608493805, 42.27896332740784, 39.55118469893932, 42.40328125655651, 39.70336273312569, 40.45425184071064, 41.91110126674175, 41.99947312474251, 40.531938672065735, 43.76756764948368, 43.25781740248203, 43.972106873989105, 45.125888362526894, 43.92306290566921, 42.750263437628746, 42.873050048947334, 48.052977696061134, 53.86105723679066, 52.59903095662594, 59.22139920294285, 60.79734563827515, 36.97420857846737, 37.00287044048309, 45.79043470323086, 53.031535148620605, 53.63012842833996, 55.69212958216667, 56.30435653030872, 58.42526592314243, 55.70654980838299, 58.148169592022896, 61.07743240892887, 60.654112324118614, 58.69554162025452, 54.89574171602726, 53.56827154755592, 52.49951429665089, 59.31976072490215, 62.16894283890724, 61.08661271631718, 63.29504281282425, 61.01176053285599, 51.65196217596531, 59.25426363945007, 8.917269352823496, 0.46243212826084346, 1.750077079050243, 3.6299960408359766, 0.07281456506461836, 0.09695302956970409, 42.394100949168205, 82.35956221818924, 70.91606587171555, 78.22048991918564, 70.13693287968636, 54.6521557867527, 28.34030047059059, 44.390829205513, 52.69270732998848, 76.67534083127975, 39.737275913357735, 0.8457772003021091, 0.09418596906471066, 0.10670978532289155, 0.010260495910188183, 0.08397190933465026, 0.16175294149434194, 0.2450055835652165, 0.1626345090335235, 0.20777337049366906, 0.1265158291789703, 0.5276624264661223, 0.25183285237289965, 49.763497710227966, 84.9323433637619, 55.02347566187382, 37.58280672132969, 86.66429802775383, 90.45042246580124, 60.033320635557175, 70.6642609834671, 77.98750922083855, 68.5149747133255, 82.30263367295265, 11.074393652379513, 0.5205981305334717, 2.2276238165795803, 1.901502397377044, 12.053024489432573, 1.5618551289662719, 1.6116294893436134, 50.83627134561539, 74.08326432108879, 61.019990891218185, 66.41426503658295, 61.31251059472561, 67.08692774176598, 62.398347929120064, 62.66942158341408, 53.164991587400436, 50.1739364862442, 45.57885825634003, 46.8253243714571, 54.99912656843662, 61.3023841381073, 59.24838535487652, 60.101048201322556, 56.560113206505775, 56.114682108163834, 55.351603254675865, 55.341776981949806, 54.256790801882744, 58.491887748241425, 58.15152481198311, 56.09808839857578, 57.1136599034071, 58.098802641034126, 54.791361317038536, 52.485363855957985, 52.13049329817295, 53.52707415819168, 55.425307899713516, 53.90944004058838, 55.31016647815704, 52.62721784412861, 52.38468445837498, 44.28798012435436, 39.65713821351528, 41.21906340122223, 39.52764116227627, 42.010754719376564, 42.92993679642677, 39.96612623333931, 42.01163247227669, 42.91430063545704, 43.13981853425503, 46.99100308120251, 55.669589191675186, 59.080555960536, 49.07174862921238, 38.18307191133499, 39.26839627325535, 40.4867172986269, 40.87853707373142, 43.31549450755119, 44.97789770364761, 46.93135388195515, 49.05946388840675, 45.62963493168354, 39.54918600618839, 41.141513362526894, 45.553122237324715, 45.12523099780083, 44.85359877347946, 47.712166383862495, 46.639187559485435, 47.6336245983839, 42.745802477002144, 39.097910821437836, 38.58068637549877, 37.38085135817528, 37.112213373184204, 39.147783145308495, 38.89339059591293, 37.56048671901226, 38.71961072087288, 38.898562118411064, 36.47667087614536, 36.689345464110374, 38.20921450853348, 39.15494196116924, 35.45390635728836, 51.57694660127163, 55.42051635682583, 55.56217275559902, 52.72173397243023, 48.043022230267525, 44.56029251217842, 42.04661339521408, 45.05912974476814, 41.865724101662636, 43.71944323182106, 42.23998121917248, 43.30000653862953, 43.258197382092476, 46.338969469070435, 46.332281827926636, 46.73698291182518, 46.809995993971825, 46.462968215346336, 44.92582529783249, 43.519646152853966, 48.873631060123444, 57.28365138173103, 52.42051653563976, 63.807407319545746, 58.12358111143112, 33.65291319787502, 40.27521304786205, 49.52842332422733, 55.82565441727638, 54.626887142658234, 55.94391547143459, 58.783495500683784, 60.34938767552376, 59.7767698019743, 58.44197742640972, 61.24515920877457, 61.363477259874344, 60.85794858634472, 55.82959860563278, 55.81537976861, 56.07905521988869, 62.338117361068726, 65.90361043810844, 63.22132296860218, 66.31134375929832, 65.80434456467628, 56.38833202421665, 68.38866949081421, 10.620147977024317, 0.48758915334474295, 3.689989596605301, 3.5026525240391493, 0.6770287302788347, 0.16750184004195035, 47.400389313697815, 86.59156993031502, 79.23422992229462, 83.2269036769867, 78.72131824493408, 62.680832371115685, 37.32454977929592, 61.475666239857674, 61.552870497107506, 89.30924490094185, 51.308316215872765, 1.0839497856795788, 0.27901962166652083, 0.1908502512378618, 0.19417115428950638, 0.15735056600533426], [0.06261766378884204, 0.08384364395169541, 0.0673593491956126, 0.0442071210272843, 0.030094455651124008, 0.2043592240079306, 0.10759682991192676, 35.26539087295532, 64.0144582092762, 38.835390508174896, 33.47979448735714, 66.9240152835846, 81.27474322915077, 40.3485719114542, 58.88651557266712, 67.71412208676338, 58.44543904066086, 70.84612682461739, 14.794108103960752, 0.231538200750947, 0.27070213516708463, 1.360597622115165, 2.7730292128399014, 0.16007424797862768, 1.169042894616723, 37.057572305202484, 74.60883691906929, 55.844376012682915, 64.87997576594353, 57.8725665807724, 64.02724832296371, 57.492545172572136, 54.15340214967728, 49.257877841591835, 43.85070338845253, 44.035126492381096, 52.52995066344738, 51.01305305957794, 55.44838786125183, 51.146767884492874, 48.68269510567188, 52.57376231253147, 55.14721982181072, 54.72705356776714, 56.44931115210056, 52.39376597106457, 56.347867995500565, 50.395084619522095, 52.04973243176937, 49.888856783509254, 48.21382686495781, 45.821482837200165, 45.15441723167896, 44.54027898609638, 51.40958458185196, 51.55454680323601, 51.65233835577965, 48.9456257969141, 47.8689231723547, 39.98016647994518, 38.307321444153786, 37.51899294555187, 39.57043066620827, 36.07712231576443, 36.404341757297516, 35.98466947674751, 36.32307931780815, 44.77817662060261, 48.56522060930729, 47.815376445651054, 47.62401111423969, 46.389005184173584, 53.77935782074928, 44.925308525562286, 40.09719640016556, 38.31816606223583, 40.54150655865669, 39.587544947862625, 40.936833545565605, 44.307431280612946, 41.89405918121338, 45.417693704366684, 46.755123138427734, 38.92042614519596, 37.723000198602676, 40.95507636666298, 39.8111629486084, 40.626823380589485, 44.79160510003567, 41.35125830769539, 44.07527133822441, 37.350278198719025, 35.94325929880142, 39.355920776724815, 40.191476941108704, 38.131805062294006, 39.53956872224808, 38.26518550515175, 40.12156069278717, 39.78888854384422, 39.25770364701748, 37.962212562561035, 38.918267861008644, 38.745684921741486, 37.12246522307396, 37.16392859816551, 49.07840207219124, 50.88930889964104, 45.174176171422005, 39.03623253107071, 37.99418404698372, 37.637873366475105, 37.226735427975655, 38.19672457873821, 38.94539460539818, 36.81434355676174, 38.03276717662811, 38.05317968130112, 40.09982965886593, 40.98213851451874, 42.569617331027985, 44.37734752893448, 45.66919460892677, 44.462314769625664, 43.598510921001434, 42.52449855208397, 40.12826733291149, 42.8895677626133, 49.91648130118847, 51.282963976264, 56.37270726263523, 59.465102925896645, 51.37690253555775, 43.53131912648678, 43.001988530159, 42.82872922718525, 46.41855999827385, 48.1835462898016, 48.07392597198486, 52.43948891758919, 54.63408015668392, 58.09528023004532, 54.909227192401886, 60.28085455298424, 57.99077443778515, 54.69257041811943, 52.521260529756546, 54.244623854756355, 55.570140928030014, 64.33896079659462, 63.25548693537712, 57.61932156980038, 50.659577026963234, 50.92126898467541, 3.792429487220943, 0.24731513229198754, 2.563633373938501, 2.612677817232907, 0.04697517229942605, 0.04991436282580253, 44.80242311954498, 73.89852583408356, 65.22597000002861, 68.95706579089165, 60.120932534337044, 46.36801891028881, 26.178085394203663, 23.991553522646427, 36.837267726659775, 61.61875136196613, 22.05095775425434, 0.5238955817185342, 0.1751003784011118, 0.1190565548313316, 0.024802951993478928, 0.06258535067900084, 0.055716339775244705, 0.14001856790855527, 0.07567025284515694, 0.06290448160143569, 0.07241897808853537, 0.22441788751166314, 0.04549609795503784, 41.8964796513319, 72.40060821175575, 44.83448959887028, 36.20241679251194, 78.58033820986748, 91.98427855968475, 51.14390283823013, 63.22212852537632, 73.67098644375801, 63.415640741586685, 74.96588096022606, 17.128633484244347, 0.40844156756065786, 0.3564944659592584, 2.0942476484924555, 5.629628291353583, 0.297651921864599, 1.3204612070694566, 41.47993080317974, 73.50374221801758, 60.05131646990776, 67.09853991866112, 58.99646267294884, 66.30091711878777, 58.71240891516209, 56.77892446517944, 49.895802810788155, 45.94926618039608, 47.47542008757591, 54.807825833559036, 51.918654665350914, 57.44397237896919, 53.475636318325996, 51.136880815029144, 52.56766363978386, 57.97345116734505, 54.31101009249687, 57.41133973002434, 53.7903468310833, 57.49381810426712, 52.24227949976921, 55.82448028028011, 51.36196553707123, 51.7632620036602, 47.57575370371342, 45.639381408691406, 46.160751432180405, 52.944626212120056, 54.4164202362299, 53.02631422877312, 51.72258898615837, 48.89354959130287, 42.95716613531113, 40.171224027872086, 40.00678025186062, 39.70676735043526, 37.72843390703201, 37.157423347234726, 37.36493021249771, 38.89821253716946, 44.574967324733734, 50.46989120543003, 48.658668994903564, 50.36483444273472, 49.40855495631695, 55.81358626484871, 46.357569471001625, 39.81473855674267, 39.33271922171116, 40.840311124920845, 40.06694242358208, 41.04582689702511, 45.75770705938339, 42.725686356425285, 45.21768003702164, 47.01592594385147, 38.72652254998684, 37.493785098195076, 43.4334971755743, 42.37629510462284, 42.677322551608086, 45.53326450288296, 44.86912854015827, 46.56067617237568, 39.099556133151054, 36.13878920674324, 40.017222091555595, 40.18741115927696, 38.86708460748196, 38.265269100666046, 36.64831526577473, 40.35551033914089, 39.749359264969826, 38.67166109383106, 37.57875233888626, 39.33746516704559, 39.03547257184982, 36.11959643661976, 36.287357434630394, 50.22223189473152, 52.830970510840416, 47.168559953570366, 41.36631689965725, 39.68232326209545, 38.69175061583519, 39.75111477077007, 40.05245380103588, 40.25944769382477, 37.58425064384937, 40.25808356702328, 40.305296033620834, 41.1464910954237, 42.32538543641567, 45.77808536589146, 46.600813418626785, 47.555162608623505, 46.81874692440033, 44.67103376984596, 44.51299265027046, 42.31970474123955, 45.27114316821098, 53.16832400858402, 52.096933498978615, 56.95247255265713, 62.80426874756813, 52.04009234905243, 44.842951744794846, 42.93592527508736, 44.55035224556923, 47.10670307278633, 48.94423887133598, 47.65811808407307, 55.929115265607834, 56.46968185901642, 60.474685952067375, 57.98408679664135, 61.91160164773464, 60.503507405519485, 57.64271691441536, 54.99441862106323, 57.04749785363674, 58.885383233428, 65.44064328074455, 65.85697174072266, 62.14754618704319, 54.29177552461624, 54.03964005410671, 4.719773288816214, 0.34603540843818337, 5.4211558029055595, 9.004844203591347, 0.047197935346048325, 0.027277417066216003, 48.93269509077072, 78.99028301239014, 69.60979476571083, 75.43367385864258, 66.02208808064461, 49.20276179909706, 27.898855358362198, 31.41124438494444, 43.9047858864069, 73.88537093997002, 29.288400895893574, 0.7008307718206197, 0.16534897353267297, 0.08325483140652068, 0.019488985381030943, 0.032698529394110665, 0.14205439772922546, 0.18434477766277269, 0.22076686233049259, 0.23751416680170223, 0.11094992732978426, 0.34412143926601857, 0.19190910301404074, 53.508014380931854, 79.622333496809, 54.61760424077511, 49.18011501431465, 79.94979992508888, 84.3698899447918, 56.189587488770485, 70.43749675154686, 79.4201235473156, 67.12513089179993, 83.76405045390129, 18.488075137138367, 0.46901465160772204, 2.253428469412029, 3.658205489628017, 12.094150632619858, 1.9377802382223308, 2.1984546817839146, 46.994259506464005, 73.46994683146477, 61.412802413105965, 68.9618231356144, 61.52864299714565, 71.05726629495621, 61.965824738144875, 59.18000042438507, 53.68618302047253, 48.70378017425537, 48.14375102519989, 57.662076875567436, 54.554428830742836, 61.76826573908329, 55.42540669441223, 53.08631680905819, 53.07193078100681, 56.927181109786034, 55.50427906215191, 60.219180062413216, 55.39208248257637, 61.94889284670353, 55.41999578475952, 59.45737034082413, 54.26530994474888, 52.95736312866211, 49.82880860567093, 48.06859865784645, 48.59954796731472, 55.23373357951641, 56.935654655098915, 55.15649512410164, 51.855551451444626, 51.18862263858318, 44.4492244720459, 43.113242760300636, 43.23232837021351, 44.768399745225906, 38.02537277340889, 39.32523362338543, 38.926536217331886, 41.149728521704674, 48.47675755620003, 52.967151403427124, 52.29683697223663, 54.0782155841589, 50.54899916052818, 58.68148237466812, 46.753040850162506, 41.291392520070076, 38.87947574257851, 41.813233718276024, 40.43842189013958, 42.26076230406761, 47.60593928396702, 44.18581120669842, 44.95416797697544, 48.22369113564491, 41.32370978593826, 37.86426141858101, 44.362946301698685, 45.980595499277115, 45.00124745070934, 47.795226126909256, 47.240984067320824, 48.803152441978455, 39.230200722813606, 35.94803564250469, 39.75409761071205, 40.56345798075199, 37.134210392832756, 38.172269091010094, 37.75185205042362, 40.663764998316765, 39.556914791464806, 39.56835597753525, 37.82301843166351, 39.243663400411606, 38.82224701344967, 37.79881373047829, 37.790777161717415, 52.348624393343925, 54.99712027609348, 49.89420309662819, 43.17129984498024, 40.82135774195194, 39.039633348584175, 41.57667741179466, 41.239624097943306, 43.78229185938835, 40.2335786819458, 41.80600270628929, 42.79360771179199, 43.102865517139435, 43.8210079818964, 47.503549978137016, 49.6071171015501, 50.96883863210678, 49.42022033035755, 46.73860542476177, 46.834109500050545, 44.715164601802826, 47.73982509970665, 55.69851703941822, 55.4437331110239, 59.02057237923145, 61.400103494524956, 51.181102842092514, 45.437657833099365, 46.36943623423576, 45.000863671302795, 47.68022909760475, 49.56650108098984, 49.50801461935043, 57.60408818721771, 59.08223167061806, 60.86457163095474, 59.17519748210907, 67.01127380132675, 64.0461029112339, 60.295875146985054, 59.6554309129715, 60.17729490995407, 62.44808346033096, 71.60382896661758, 69.10005211830139, 66.35039806365967, 59.10134084522724, 62.165952399373055, 6.837092824280262, 0.451546068652533, 9.443144984543324, 15.753522422164679, 0.11978771130088717, 0.11064025879022665, 54.4165076315403, 87.25111573934555, 74.51088577508926, 81.58720046281815, 73.3741083741188, 62.71164111793041, 37.375619038939476, 39.03260752558708, 54.165310710668564, 83.3429342508316, 40.18969103693962, 0.964626925997436, 0.3812403412302956, 0.2861203718930483, 0.11876088319695555, 0.2755100646754727], [0.017748059071891475, 0.1385428517824039, 0.03624528653745074, 0.04038784725707956, 0.08156004070769995, 0.1961960893822834, 0.08609727927250788, 34.834231808781624, 62.23192825913429, 42.89400212466717, 19.654967822134495, 18.663975298404694, 32.95066148042679, 42.472289353609085, 57.83116780221462, 64.29802179336548, 58.260632157325745, 67.2499617934227, 24.022791646420956, 0.45116792956832796, 0.32045440922956914, 0.8924613171257079, 5.061222966760397, 0.257302985410206, 1.9476092420518398, 29.658556133508682, 63.8049678504467, 54.890129417181015, 60.92740885913372, 61.04413099586964, 61.15970179438591, 56.05223245918751, 51.62590317428112, 44.39261130988598, 44.77358266711235, 48.84157977998257, 54.31432731449604, 53.67364749312401, 55.88976077735424, 52.11239106953144, 56.590169593691826, 55.49959771335125, 53.73768165707588, 52.90648765861988, 53.08304898440838, 50.45064903795719, 50.10437361896038, 48.69563341140747, 47.610936015844345, 46.320635452866554, 44.74651291966438, 44.17767584323883, 46.04373671114445, 49.1586347669363, 51.96585953235626, 51.79952345788479, 52.01415874063969, 51.542668640613556, 44.770584627985954, 40.95351085066795, 36.86697453260422, 37.185781225562096, 36.6207667440176, 36.4658110588789, 36.62269704043865, 39.929454401135445, 39.32810626924038, 41.05258673429489, 38.429458290338516, 37.60964088141918, 39.16083164513111, 44.321133345365524, 51.002086848020554, 47.238909378647804, 40.019467771053314, 38.718440383672714, 40.83481281995773, 40.67549116909504, 38.832559660077095, 39.88888017833233, 42.32258878648281, 42.47391566634178, 48.31454426050186, 42.75987692177296, 38.79558004438877, 39.59656946361065, 40.98485916852951, 43.47017280757427, 43.855954706668854, 43.73919077217579, 42.64454931020737, 37.8098027408123, 40.35628169775009, 38.31627756357193, 40.310364961624146, 39.73679333925247, 38.750605657696724, 37.38329462707043, 40.10552175343037, 40.330978855490685, 41.22282899916172, 38.101182505488396, 37.46749810874462, 37.986265271902084, 35.71589469909668, 43.46682898700237, 50.84749974310398, 46.99908524751663, 42.89001613855362, 35.82893863320351, 37.473984360694885, 39.17571544647217, 35.95501206815243, 37.39147558808327, 38.091234639286995, 39.30796355009079, 38.36516194045544, 39.67940881848335, 37.88408875465393, 39.56808619201183, 42.00545780360699, 43.170927464962006, 46.19572475552559, 46.73265494406223, 44.19297382235527, 44.76141571998596, 40.198080986738205, 38.840216249227524, 44.375063851475716, 51.216167360544205, 52.432584688067436, 54.29948911070824, 57.617801651358604, 58.28268997371197, 51.98853671550751, 49.82033126056194, 49.09164056181908, 50.0341609865427, 55.67523568868637, 56.70714631676674, 57.07451060414314, 58.616521060466766, 57.36442744731903, 55.640931129455566, 55.94304911792278, 57.41743080317974, 54.10202130675316, 50.91442935168743, 51.69049210846424, 59.405993297696114, 59.40193131566048, 60.066025480628014, 54.51060198247433, 52.46003821492195, 2.4844608223065734, 0.15334500203607604, 1.1272722110152245, 5.258079953491688, 0.1807261843350716, 0.618986904155463, 52.21661567687988, 72.36687362194061, 61.63622662425041, 68.21247294545174, 60.353005081415176, 46.358314231038094, 16.324748620390892, 36.705399602651596, 48.63981060683727, 64.70174252986908, 15.579192526638508, 0.5756500514689833, 0.06711184294545092, 0.04297138948459178, 0.09067495004273951, 0.214962896425277, 0.014976567017583875, 0.0745388338691555, 0.028397714959282894, 0.05732239558710717, 0.05007816966099199, 0.20375759457238019, 0.13070623244857416, 41.71178676187992, 70.92327028512955, 49.90131251513958, 27.52541709691286, 38.91315333545208, 46.79658271372318, 44.87310312688351, 64.97573062777519, 69.61728036403656, 64.413892775774, 71.83650568127632, 26.74353875219822, 0.4019178223097697, 0.5090983444824815, 3.547765128314495, 4.285513116046786, 0.5885922163724899, 2.439125217497349, 36.37895531952381, 62.83385396003723, 56.60216175019741, 63.84529888629913, 61.42092637717724, 62.048515900969505, 58.7341133505106, 53.25638048350811, 46.70104444026947, 49.06481020152569, 51.00560925900936, 57.358891144394875, 55.65774902701378, 58.25907804071903, 51.860627979040146, 55.70602163672447, 56.38618513941765, 58.1192759424448, 54.50009174644947, 54.625439420342445, 51.099939197301865, 52.83963784575462, 52.5749858468771, 50.311846286058426, 49.62501034140587, 47.08999156951904, 45.663939490914345, 47.359845489263535, 49.789317324757576, 52.70259439945221, 54.79790076613426, 53.172648176550865, 53.983980640769005, 47.36378587782383, 42.49343141913414, 38.07942487299442, 37.87841185927391, 39.28046062588692, 38.96303325891495, 39.01878006756306, 41.76645442843437, 40.63641406595707, 44.30100962519646, 40.48803962767124, 39.17073771357536, 40.534039959311485, 48.2253972440958, 53.916579857468605, 48.911895006895065, 42.26921685039997, 38.55799779295921, 40.3610884398222, 40.695595890283585, 39.7631449252367, 39.62856374680996, 44.53080989420414, 43.59641343355179, 47.88305841386318, 43.204772248864174, 38.35538126528263, 41.41466550529003, 42.89236441254616, 46.18817076086998, 45.16644358634949, 46.36596322059631, 43.878783881664276, 37.9043834656477, 42.02816158533096, 36.797411665320396, 41.077038422226906, 40.38456358015537, 37.80295550823212, 37.06219665706158, 39.00017246603966, 41.058233231306076, 40.869330167770386, 39.06832940876484, 36.566239669919014, 37.90488883852959, 36.703666895627975, 42.25872181355953, 54.63111251592636, 48.52202832698822, 43.88903573155403, 38.72224397957325, 40.84853768348694, 41.92976586520672, 38.44426989555359, 39.83612760901451, 41.383377984166145, 40.151347294449806, 40.644325241446495, 40.57280167937279, 39.36420813202858, 40.99816985428333, 44.463713094592094, 46.20523564517498, 49.02507193386555, 47.6940793544054, 46.29071205854416, 44.94068630039692, 41.40715330839157, 41.670201793313026, 45.933801010251045, 55.124455243349075, 54.314562901854515, 54.7307925671339, 60.57914614677429, 57.9988794028759, 53.00927974283695, 52.18972451984882, 51.856357008218765, 53.143131360411644, 57.63236626982689, 58.796479403972626, 59.14537288248539, 60.32839760184288, 61.63503348827362, 58.81785325706005, 59.155590534210205, 59.902292266488075, 56.77279159426689, 54.90483082830906, 54.543519616127014, 63.54772925376892, 62.492624670267105, 64.95760560035706, 56.173088774085045, 55.9993164986372, 2.812196323648095, 0.19455279631074518, 4.051603367552161, 5.030406145378947, 0.23931807547342032, 0.6091348640620708, 56.94255888462067, 78.95925387740135, 67.51086339354515, 74.08902481198311, 67.45792463421822, 59.48691375553608, 23.25883314013481, 38.08314487338066, 56.943569630384445, 74.33525919914246, 22.476780004799366, 0.6827355490531772, 0.26435513980686665, 0.09484181980951689, 0.07815526754711755, 0.11857113087899052, 0.07750063392450102, 0.15378675801912323, 0.195771373109892, 0.20397004176629707, 0.15784918534336612, 0.26853411400225013, 0.2561610279371962, 48.99664185941219, 81.8565072119236, 57.26331487298012, 33.17017950117588, 30.438525080680847, 42.86930724978447, 54.60291422903538, 69.26618680357933, 77.52916261553764, 68.13459992408752, 80.22815778851509, 30.176956616342068, 0.5658580362796783, 1.4725770195946097, 6.591735240072012, 12.622441984713078, 1.1339523713104427, 3.3583075320348144, 43.21515329182148, 65.62461420893669, 57.94467531144619, 65.52486956119537, 63.74026492238045, 66.68335139751434, 61.42101377248764, 55.13822190463543, 49.54932600259781, 50.18421873450279, 54.590143114328384, 59.12776842713356, 57.29787401854992, 60.01860022544861, 54.517726600170135, 55.20072855055332, 57.906605154275894, 59.01396833360195, 57.332934737205505, 57.50720098614693, 53.52161005139351, 54.53989081084728, 53.36283937096596, 52.20214985311031, 52.829648181796074, 49.20695297420025, 48.932774886488914, 49.173936545848846, 51.22331477701664, 55.60635298490524, 55.5063309520483, 57.24311515688896, 56.821333989501, 50.06646305322647, 47.30428487062454, 41.36508196592331, 40.10591313242912, 41.70519411563873, 41.20037600398064, 40.69642424583435, 44.39285069704056, 43.093381226062775, 47.877719700336456, 42.81090818345547, 41.0663115978241, 42.332472056150436, 51.40759728848934, 56.84344120323658, 53.72068136930466, 43.34243506193161, 39.260941073298454, 41.46657072007656, 42.41875782608986, 40.13739824295044, 39.286623895168304, 44.71923418343067, 43.72844874858856, 48.070635348558426, 45.02018183469772, 39.26398850977421, 41.13598085939884, 43.61206479370594, 49.784787967801094, 47.06446073949337, 50.238715410232544, 45.03114804625511, 38.731621876358986, 41.18400268256664, 37.62317955493927, 41.05300471186638, 39.55521248281002, 37.6304941624403, 36.46943226456642, 41.104469150304794, 41.23353682458401, 41.34362451732159, 38.40399585664272, 37.97164365649223, 39.21017959713936, 36.2985098361969, 43.6582513153553, 56.31745062768459, 50.472003892064095, 46.482681557536125, 41.00511588156223, 42.0052146166563, 44.78006511926651, 39.7612564265728, 42.61887788772583, 43.080416321754456, 42.0714146643877, 43.48139360547066, 44.28373575210571, 41.90770424902439, 42.11760878562927, 46.24827213585377, 47.711729407310486, 50.60280427336693, 50.16611650586128, 47.213792726397514, 49.12554234266281, 43.32494080066681, 44.30438384413719, 50.06097994744778, 59.22611854970455, 55.982240214943886, 58.401813581585884, 62.33161970973015, 58.28770570456982, 54.488597363233566, 54.14612174034119, 55.02588473260403, 55.75997494161129, 61.58980831503868, 63.25398601591587, 61.97848565876484, 63.98471340537071, 64.98236507177353, 60.269645154476166, 60.78707858920097, 62.17764437198639, 59.788894951343536, 55.80588787794113, 56.736837923526764, 66.66748344898224, 66.6810791194439, 68.96265149116516, 59.5658203214407, 61.184058487415314, 3.895210884511471, 0.5029687390197068, 5.974656427279115, 16.387583948671818, 0.5189078743569553, 0.6570555770304054, 62.57128804922104, 85.63887745141983, 72.5169275701046, 79.58418354392052, 76.86835527420044, 61.5983160585165, 27.470584139227867, 54.648428186774254, 66.24030277132988, 85.84564715623856, 30.40077220648527, 0.7474412675946951, 0.3209957614308223, 0.16921398957492784, 0.1972010315512307, 0.23604643618455157], [0.02563065445428947, 0.08250800077803433, 0.10446291096741334, 0.051096143943141215, 0.1303126270067878, 0.3595036076148972, 0.3758092154748738, 19.451127760112286, 67.39078983664513, 49.760693460702896, 27.473971657454967, 21.391073763370514, 37.150792703032494, 44.44260522723198, 57.149408385157585, 65.28194859623909, 60.11546082794666, 65.75754627585411, 29.854975193738937, 0.39115944178774953, 0.37746438290923834, 1.9362351461313665, 3.025647019967437, 0.41323352605104446, 1.4393445965833962, 31.193928346037865, 52.629854902625084, 42.902867048978806, 61.84240736067295, 60.45449383556843, 61.30090981721878, 52.06782326102257, 46.75228849053383, 46.83839946985245, 51.71679429709911, 52.96862952411175, 54.085716381669044, 57.542090713977814, 48.826023414731026, 51.78519442677498, 55.68554073572159, 52.05479376018047, 51.2907649576664, 52.95333914458752, 50.76989270746708, 49.29852806031704, 48.25441248714924, 43.67647133767605, 40.48639811575413, 41.717098876833916, 44.028693437576294, 47.54166193306446, 50.707462057471275, 53.31856794655323, 56.19314789772034, 51.07751280069351, 51.52142398059368, 48.474876657128334, 41.72319374978542, 36.96981981396675, 37.17655912041664, 36.19110479950905, 36.47057980298996, 35.3777926415205, 38.49340885877609, 35.34514859318733, 35.4658605158329, 35.77068775892258, 37.41124972701073, 35.298072919249535, 38.348746821284294, 41.731367111206055, 47.02600680291653, 47.22807615995407, 42.72531017661095, 37.939326390624046, 40.34810833632946, 40.55065646767616, 40.106676891446114, 39.5722621679306, 41.43769606947899, 41.14828459918499, 46.4454435557127, 48.77140894532204, 39.72616910934448, 42.47660592198372, 40.94443313777447, 40.89324228465557, 45.3436204791069, 44.59719993174076, 43.085861429572105, 39.57977056503296, 38.81992533802986, 39.2845606058836, 41.43049165606499, 39.81040298938751, 39.892083406448364, 37.838662192225456, 39.806546196341515, 41.18629775941372, 38.4455656260252, 38.49091999232769, 38.41271638870239, 35.97129799425602, 41.68753646314144, 47.51414380967617, 48.33243370056152, 43.10058183968067, 39.0372546762228, 36.04995757341385, 36.301447078585625, 38.259960785508156, 39.31049421429634, 37.7304781973362, 38.252893164753914, 37.49284654855728, 37.691484689712524, 38.9196889847517, 37.65005551278591, 37.59308896958828, 39.608880802989006, 45.11891953647137, 47.95278087258339, 49.39051352441311, 49.14872109889984, 48.967489823699, 47.14677192270756, 42.08599828183651, 41.38244703412056, 41.76608964800835, 47.95637167990208, 50.72931468486786, 50.95853738486767, 55.31368128955364, 55.2376663684845, 55.286885127425194, 57.17967376112938, 57.93657034635544, 59.134288877248764, 55.904306396842, 55.216577500104904, 56.458753645420074, 57.876438573002815, 59.246462658047676, 57.47833773493767, 58.12611937522888, 53.503135442733765, 52.395890057086945, 48.24636451900005, 57.20916397869587, 61.20870776474476, 60.79620949923992, 65.3816856443882, 50.00896833837032, 0.6122943945229053, 0.3550899960100651, 5.533400354906917, 5.35517661832273, 0.4772992164362222, 2.155819069594145, 55.77318303287029, 69.41301092505455, 64.28565725684166, 66.84244886040688, 59.84721802175045, 39.02861014008522, 18.264400139451027, 39.37430039048195, 45.1790589094162, 67.41089835762978, 8.118993937969208, 0.48029170429799706, 0.08707873246748932, 0.0864508977974765, 0.04043749322590884, 0.037012322136433795, 0.035704695037566125, 0.10500192540348507, 0.14123613538686186, 0.10826098528923467, 0.06317261955700815, 0.335897077457048, 0.3777456865645945, 26.80062498897314, 75.17613127827644, 55.43137237429619, 31.837121732532978, 19.481030255556107, 36.74199923872948, 50.76717585325241, 61.551430374383926, 69.03075143694878, 65.06144642829895, 69.9790209531784, 32.40629509091377, 0.39276090741623193, 0.3666309267282486, 2.390664992853999, 5.818848637863994, 0.4973078443435952, 1.0555123491212726, 35.86651101708412, 51.95046275854111, 48.978771418333054, 60.72327621281147, 62.167153134942055, 62.846461683511734, 54.88867029547691, 49.83628660440445, 48.32925707101822, 54.39594313502312, 55.28418347239494, 58.06213840842247, 55.909299328923225, 51.512722447514534, 54.36518378555775, 57.07190774381161, 54.65197719633579, 53.903968334198, 56.30085691809654, 53.872931599617004, 51.47131606936455, 51.63975343108177, 47.06789955496788, 44.3916841596365, 44.22124430537224, 46.046898141503334, 48.79597082734108, 50.738092213869095, 53.0702018737793, 58.29121671617031, 51.6438952088356, 53.55312176048756, 50.40746055543423, 43.233646899461746, 40.693931579589844, 37.81536564230919, 37.6388119161129, 38.10235284268856, 37.50297300517559, 39.819693490862846, 37.82203048467636, 37.638207748532295, 36.66714325547218, 38.16313438117504, 38.23764458298683, 39.26662176847458, 43.968668058514595, 51.61976270377636, 51.32812835276127, 44.30316410958767, 38.8876149058342, 39.95709791779518, 41.7557580024004, 39.99676398932934, 39.518772438168526, 41.37180760502815, 41.557154059410095, 47.999066188931465, 50.28100334107876, 39.657115414738655, 42.930597960948944, 43.00837978720665, 43.11603561043739, 47.41891331970692, 46.383662670850754, 44.42288048565388, 38.81351888179779, 38.73706318438053, 38.90890136361122, 41.154721453785896, 39.45827208459377, 38.43706168234348, 37.21493326127529, 41.21839843690395, 39.32345911860466, 38.40901158750057, 37.74805225431919, 38.24182815849781, 36.50212191045284, 38.869193494319916, 48.48868891596794, 50.305337235331535, 45.07943965494633, 40.022306218743324, 38.713766634464264, 38.922462835907936, 39.33689519762993, 41.479668617248535, 40.004462376236916, 38.59350688755512, 38.862916231155396, 38.85937102138996, 39.355586394667625, 39.545500203967094, 39.45161484181881, 40.83754487335682, 46.800013929605484, 51.08589135110378, 52.35251918435097, 52.0199990272522, 50.052779987454414, 49.85283851623535, 44.70352202653885, 43.03318105638027, 44.23457399010658, 49.98777687549591, 53.94989266991615, 52.765823006629944, 55.75893759727478, 57.47594006359577, 57.90337532758713, 57.44854353368282, 59.78965111076832, 60.71381852030754, 59.75343905389309, 57.28238604962826, 60.30640818178654, 59.19861562550068, 62.33733460307121, 59.8674975335598, 62.482847794890404, 56.21776297688484, 54.68263395130634, 51.09532244503498, 61.70810356736183, 63.42503383755684, 66.64264038205147, 65.77483534812927, 53.402342051267624, 0.6601010542362928, 0.07367184953182004, 6.971366219222546, 5.307132946327329, 0.3954008751315996, 1.9874497479759157, 61.80541634559631, 75.30447319149971, 70.90878546237946, 70.66856995224953, 67.8255245089531, 48.990888968110085, 19.103127233684063, 44.97047670185566, 53.41220252215862, 78.40724229812622, 13.133654203265905, 0.49096049275249243, 0.09145004907622933, 0.04869050935667474, 0.09188108844682574, 0.13146123412298039, 0.17961328936507925, 0.16670646553393453, 0.16031195787945762, 0.25582361791748554, 0.2746576932258904, 0.5880549608264118, 0.6544324709102511, 34.63842451572418, 86.47133678197861, 64.53074410557747, 40.99411927163601, 30.311902575194836, 52.23985902965069, 60.14674834907055, 67.52372950315475, 76.14609763026237, 70.10543256998062, 78.1487649679184, 36.13122381269932, 0.38632693234831095, 1.4770960458554327, 6.798656461760402, 10.712217036634684, 0.8915801800321788, 2.1616116212680936, 41.719302758574486, 56.30325458943844, 52.597210854291916, 64.61126938462257, 66.07383370399475, 66.35001808404922, 56.498028337955475, 51.11009985208511, 51.01641207933426, 58.11185874044895, 57.00310483574867, 60.68027012050152, 59.37835358083248, 53.08629021048546, 52.70013213157654, 58.79733435809612, 56.98873020708561, 57.60292544960976, 58.81347209215164, 57.001820504665375, 54.158915653824806, 53.483988270163536, 48.80848355591297, 46.878529116511345, 47.16514013707638, 48.35805952548981, 51.26836135983467, 54.39851179718971, 56.12841077148914, 60.57721205055714, 54.827831760048866, 57.85913810133934, 54.03125010430813, 46.447928622365, 42.32881285250187, 40.791415348649025, 39.657586589455605, 39.37944531440735, 38.503888696432114, 41.66523925960064, 38.63505005836487, 39.87275004386902, 38.81340108811855, 43.13115879893303, 40.82902193069458, 41.74733005464077, 45.99895991384983, 53.19037802517414, 54.159850403666496, 47.00836434960365, 39.737310111522675, 40.81895247101784, 41.109975054860115, 41.17327965795994, 39.98357869684696, 42.14482672512531, 42.051762118935585, 49.77788373827934, 52.11602367460728, 39.8046500980854, 45.15512019395828, 46.25214032828808, 44.4648340344429, 49.37417820096016, 49.84102115035057, 45.392303466796875, 41.61644987761974, 38.25380511581898, 39.8607312887907, 43.40109631419182, 38.896213844418526, 39.605844765901566, 37.14352369308472, 40.81187345087528, 39.9494831264019, 38.34993235766888, 38.33956651389599, 38.29462632536888, 36.63566194474697, 41.378027871251106, 51.29320062696934, 52.41619996726513, 45.69651514291763, 42.3287520557642, 39.10042628645897, 40.73838159441948, 40.00021420419216, 43.523863926529884, 41.78832605481148, 41.66721515357494, 40.90970300137997, 40.991884991526604, 42.32496365904808, 40.543900430202484, 41.003573164343834, 43.865207210183144, 49.457104951143265, 54.151110872626305, 53.99789549410343, 53.7270650267601, 51.96123518049717, 53.245323076844215, 47.476829811930656, 46.12643927335739, 46.324340254068375, 53.30752193927765, 56.98676951229572, 55.17759159207344, 59.63498421013355, 61.73409417271614, 60.912141278386116, 60.32778203487396, 61.15899883210659, 63.95671650767326, 61.2569385766983, 61.03218823671341, 63.126400262117386, 60.87955042719841, 63.617003336548805, 62.22180940210819, 64.69930306077003, 58.173757418990135, 58.1728682667017, 54.26589511334896, 63.3085510879755, 68.36128816008568, 68.83342802524567, 70.01394867897034, 57.73273788392544, 1.6801696177572012, 0.3584198048338294, 10.635895282030106, 18.634074702858925, 0.6421644729562104, 2.1982806036248803, 67.62639239430428, 82.1594649553299, 78.12509983778, 76.54347270727158, 74.70511615276337, 54.270838648080826, 26.602319329977036, 57.17611715197563, 60.36088205873966, 91.98341980576515, 19.02901791036129, 1.009296616539359, 0.4014342388836667, 0.19554847647668794, 0.2805217285640538, 0.17083191603887826], [0.01735474306769902, 0.05138588952831924, 0.08233477608882822, 0.07435687410179526, 0.0600990594830364, 0.22900988173205405, 0.1558146468596533, 13.524657022207975, 66.73688292503357, 47.37678498029709, 31.099119633436203, 21.824645698070526, 33.894470036029816, 45.922705605626106, 60.64223416149616, 64.27046567201614, 60.572853684425354, 66.28683507442474, 33.9056072384119, 0.38377204444259405, 0.15867948532104492, 1.045898508746177, 2.082560663111508, 0.2598446630872786, 0.49049246474169195, 40.39511941373348, 53.81518989801407, 45.28365969657898, 64.60508331656456, 55.275481939315796, 56.89680173993111, 46.09534174203873, 48.00800330936909, 47.40175724029541, 55.96513353288174, 52.521097138524055, 56.814513355493546, 51.43059365451336, 50.49172103404999, 55.141124948859215, 52.849004343152046, 53.12019199132919, 49.71249684691429, 45.15852101147175, 42.20100291073322, 41.48971527814865, 41.30450561642647, 41.738940104842186, 44.88104090094566, 44.69616562128067, 46.383921056985855, 49.66252192854881, 51.87412105500698, 53.111532256007195, 50.445979088544846, 50.12295462191105, 53.04914340376854, 48.13337758183479, 42.44153380393982, 38.207436203956604, 36.117141768336296, 38.03208701312542, 35.23649722337723, 35.396491438150406, 36.74677558243275, 35.84799461066723, 37.16158412396908, 38.47342573106289, 39.03189696371555, 36.707611083984375, 38.00918944180012, 41.08567535877228, 46.52745075523853, 49.17474590241909, 43.92151638865471, 37.31289200484753, 42.97171175479889, 40.2760262042284, 39.06232953071594, 39.84406538307667, 42.37942233681679, 43.64217817783356, 45.63622757792473, 48.25759671628475, 46.05512470006943, 40.41389800608158, 44.1827105730772, 42.3870675265789, 47.96919599175453, 44.74484860897064, 40.879031047225, 38.35546486079693, 39.11169268190861, 37.70729944109917, 41.08193255960941, 38.9926602691412, 39.147509559988976, 38.32360357046127, 41.519756466150284, 39.21156272292137, 40.19645467400551, 37.471077516674995, 37.836492508649826, 39.23600301146507, 43.879984617233276, 47.15485408902168, 47.63374999165535, 41.17841698229313, 37.73672126233578, 36.93771153688431, 37.6211466640234, 35.71321964263916, 36.12545572221279, 36.140259727835655, 38.7751941382885, 38.56531240046024, 36.90569445490837, 37.16916471719742, 36.39881685376167, 37.59393252432346, 40.81712856888771, 44.14032004773617, 48.909656926989555, 52.771997675299644, 52.65939071774483, 52.12190955877304, 50.52869684994221, 46.760131269693375, 43.80441427230835, 43.938885256648064, 39.99031573534012, 44.22535188496113, 47.84025751054287, 52.10128426551819, 49.32967118918896, 52.2348091006279, 50.36369830369949, 49.85265992581844, 50.122814029455185, 50.18274441361427, 49.39143307507038, 49.701944813132286, 51.15309454500675, 51.26445136964321, 51.17341585457325, 50.423571690917015, 50.23665972054005, 51.3791786134243, 52.12447442114353, 55.1996836066246, 59.57269415259361, 60.76316647231579, 63.97203728556633, 47.946070432662964, 0.20023791468702257, 0.06371967887389474, 3.1733638560399413, 0.91122702579014, 0.2074227947741747, 3.6245129350572824, 60.27958162128925, 69.22188118100166, 64.44145649671555, 67.54484876990318, 63.244748711586, 49.0589053183794, 31.18677143007517, 36.36115327477455, 48.11108037829399, 64.24321353435516, 6.122849425300956, 0.44793638109695166, 0.09339942611404695, 0.15505157061852515, 0.05664480362611357, 0.07503011336666532, 0.058787628877325915, 0.0980347691802308, 0.037265119899529964, 0.08436914387857541, 0.10800660675158724, 0.27635617239866406, 0.22381772752851248, 17.088028863072395, 76.96777313947678, 55.00334434211254, 37.57841415703297, 30.984863564372063, 43.24400894343853, 50.77037528157234, 64.83257710933685, 70.05801871418953, 64.41596746444702, 70.97131490707397, 38.357630744576454, 0.20352430787170306, 0.37090222409460694, 2.559201861731708, 3.579241926781833, 0.35423723864369094, 0.5480111064389348, 44.65474784374237, 54.131009951233864, 47.56336636841297, 67.41467535495758, 58.473682925105095, 58.862060084939, 48.42797577381134, 49.65724401175976, 49.7405431419611, 58.03984120488167, 55.3638119995594, 59.03493940830231, 52.30505973100662, 53.91916751861572, 56.73229716718197, 53.56932409107685, 54.73660245537758, 52.38962419331074, 47.54570871591568, 45.66603697836399, 43.10047924518585, 42.46893413364887, 42.814593985676765, 45.349658355116844, 45.55632546544075, 48.06507244706154, 52.1908188611269, 55.12265793979168, 56.20327815413475, 52.697780057787895, 53.47883954644203, 54.50067691504955, 50.26365727186203, 42.208541706204414, 38.82036231458187, 37.71347790956497, 38.6545430123806, 37.049752324819565, 36.38708308339119, 37.53077611327171, 36.812990829348564, 38.80076676607132, 39.808776676654816, 39.72943313419819, 37.234908789396286, 39.585067480802536, 44.9705944955349, 49.671098068356514, 53.11098888516426, 46.436263248324394, 38.95625822246075, 43.84816512465477, 39.859515354037285, 40.00909432768822, 39.34378042817116, 40.878514274954796, 45.321627259254456, 46.798566207289696, 48.364397585392, 45.486682802438736, 39.988461434841156, 46.07849344611168, 45.414486676454544, 49.90663222968578, 46.60317309200764, 42.941583171486855, 40.45453682541847, 40.49025110900402, 38.44944901764393, 41.11435241997242, 38.24880078434944, 38.57212923467159, 38.038455471396446, 41.50350473821163, 39.44387085735798, 38.091808408498764, 37.868657782673836, 37.90998436510563, 40.386220291256905, 42.7497960627079, 47.69003637135029, 49.39962163567543, 42.93932609260082, 38.39144892990589, 37.95082837343216, 40.02258360385895, 37.3444265127182, 37.086849734187126, 39.859773740172386, 39.14435192942619, 39.42943163216114, 39.066961482167244, 39.59090016782284, 40.04310630261898, 39.913221672177315, 41.80674746632576, 46.536695659160614, 49.541000649333, 54.66683439910412, 53.67936998605728, 54.617087468504906, 53.7131691724062, 48.62751066684723, 45.86725898087025, 43.80495384335518, 42.88598075509071, 44.75500926375389, 49.762973338365555, 54.459912702441216, 53.169482946395874, 54.48412500321865, 51.78473085165024, 52.76248298585415, 53.302905187010765, 53.1633310765028, 50.397322699427605, 52.35205940902233, 52.837563157081604, 53.92462782561779, 52.510404512286186, 51.88563823699951, 50.2215289324522, 53.049515783786774, 52.973025888204575, 57.894069626927376, 61.38460412621498, 64.60119232535362, 65.34630194306374, 51.1232053488493, 0.14790218003327027, 0.05732071462261956, 6.861591534689069, 4.41957039758563, 0.33786430314648896, 3.9084090013056993, 65.80800756812096, 74.06696319580078, 68.45651105046272, 72.580726146698, 70.4985822737217, 55.088250786066055, 26.268283054232597, 42.504325434565544, 53.82883496582508, 75.18819943070412, 9.406107421964407, 0.5403894872870296, 0.1163618166174274, 0.20850469765719026, 0.0447612159041455, 0.11504477908601984, 0.16183097090106457, 0.16927140211919323, 0.18380005611106753, 0.19456152396742254, 0.18768680223729461, 0.4743373644305393, 0.30157547851558775, 23.47718272358179, 87.53886669874191, 63.016354367136955, 48.06825667619705, 33.30040231347084, 43.73355187475681, 59.56912614405155, 70.51569655537605, 77.99168139696121, 70.86383387446404, 78.50945681333542, 42.31097660958767, 0.4388844355707988, 1.8235853221267462, 4.367605336010456, 8.640389610081911, 0.8463263895828277, 0.9193384030368179, 45.972612127661705, 58.30189034342766, 52.78873957693577, 69.0493780374527, 62.26915866136551, 62.01804153621197, 52.10357554256916, 51.829731836915016, 52.3191873729229, 60.959482938051224, 57.44820535182953, 59.97318886220455, 56.661119386553764, 55.243727043271065, 58.685225173830986, 56.7716820538044, 56.93707197904587, 55.483197793364525, 51.16244584321976, 47.610404044389725, 44.88848850131035, 44.80181135237217, 45.05589611828327, 49.289066568017006, 48.72787848114967, 49.09739725291729, 54.85277742147446, 55.04625543951988, 57.453380674123764, 55.93955710530281, 55.96586309373379, 55.61096973717213, 52.45968483388424, 44.36937175691128, 40.199726298451424, 39.944376200437546, 40.89546516537666, 38.9423281699419, 38.46799582242966, 40.53205266594887, 39.42464008927345, 40.87509445846081, 41.715092584490776, 43.71321156620979, 39.082422852516174, 42.43229649960995, 46.30004055798054, 51.34610898792744, 57.12479330599308, 47.18836449086666, 40.40570944547653, 46.104404255747795, 42.09865540266037, 40.00074237585068, 40.01792125403881, 43.22083778679371, 44.120895490050316, 47.7749390155077, 48.205075934529305, 48.12154121696949, 40.7169621437788, 47.79254347085953, 47.56996661424637, 53.02968844771385, 50.354567393660545, 42.171968668699265, 39.90718759596348, 41.28543443977833, 37.59306237101555, 42.17250443994999, 37.78547644615173, 39.061903953552246, 37.707246243953705, 41.87944136559963, 38.45597706735134, 39.20349955558777, 38.520037829875946, 39.08054955303669, 40.39402887225151, 44.16340380907059, 49.603199511766434, 52.8321598470211, 46.163814067840576, 42.43828497827053, 41.031957641243935, 42.50988833606243, 38.896050453186035, 39.65334601700306, 41.56965918838978, 42.31157697737217, 40.987959802150726, 40.7338560372591, 40.66253386437893, 41.77588552236557, 42.36538968980312, 45.35887286067009, 48.99841636419296, 52.9663610458374, 56.87209166586399, 55.17820715904236, 55.58264225721359, 55.54444670677185, 50.28878152370453, 48.49768303334713, 48.451416715979576, 44.10959869623184, 47.7430435270071, 52.11795017123222, 57.42729127407074, 54.902178570628166, 56.64166443049908, 55.34540958702564, 54.407741501927376, 55.413919910788536, 55.563487485051155, 54.069415256381035, 54.98249866068363, 56.48743450641632, 55.39680942893028, 56.430300772190094, 54.66137409210205, 55.101139694452286, 56.45385190844536, 56.60388685762882, 60.491861030459404, 63.22012983262539, 68.3225530385971, 65.73088690638542, 55.28041407465935, 0.7082730287220329, 0.2071932633407414, 10.265076979994774, 12.324969246983528, 0.47835009754635394, 4.596273265779018, 71.53863966464996, 81.36681228876114, 75.45741498470306, 78.93285289406776, 78.20460677146912, 69.2994274199009, 41.830093413591385, 55.73882907629013, 61.818613037467, 88.7174342572689, 15.005603805184364, 1.2878761743195355, 0.2232862458913587, 0.3386707208119333, 0.16605423646979034, 0.24123876850353554], [0.035816158197121695, 0.0283494883478852, 0.03890833133482374, 0.02150722073565703, 0.05111873120767996, 0.23149392422055826, 0.11488234522403218, 7.677213018760085, 61.80784821510315, 54.33234974741936, 27.736132889986038, 11.755387410521507, 32.00614616274834, 45.9074342250824, 66.20903044939041, 60.98420441150665, 60.87701216340065, 63.21754977107048, 41.07076495885849, 0.15049013803945854, 0.1536538393702358, 1.723123462870717, 2.7165321819484234, 0.4900678968988359, 0.19428471772698686, 38.91674034297466, 62.681003361940384, 54.43424127995968, 64.02711153030396, 60.12120991945267, 57.452206537127495, 48.97708810865879, 52.98703193664551, 51.418362110853195, 56.457442715764046, 52.98592999577522, 54.251733273267746, 49.00877460837364, 58.49352926015854, 56.59140832722187, 53.40359978377819, 48.187513276934624, 45.005845203995705, 42.11680322885513, 41.512168273329735, 41.03077210485935, 42.554311752319336, 44.74290691316128, 45.51210343837738, 50.093821585178375, 51.10484093427658, 49.27018158137798, 50.913300812244415, 49.2485037446022, 50.94257444143295, 51.044397577643394, 50.48922456800938, 46.512076780200005, 40.607452020049095, 36.85858458280563, 36.734057664871216, 35.01238524913788, 39.41272772848606, 35.988203287124634, 37.26996950805187, 36.51244595646858, 35.92248201370239, 35.392186269164085, 37.68394589424133, 38.082487508654594, 38.949198201298714, 41.436757519841194, 44.564882665872574, 49.37375262379646, 46.11753635108471, 39.488081485033035, 41.23157612979412, 39.40695583820343, 40.40520407259464, 39.82216335833073, 40.07495999336243, 43.80485884845257, 42.67443090677261, 46.8061999976635, 45.692228972911835, 39.655819684267044, 42.42038033902645, 43.20945739746094, 46.10276274383068, 42.318295016884804, 38.44083487987518, 39.858519807457924, 39.15133975446224, 39.65239226818085, 39.860408306121826, 38.56624335050583, 40.50422675907612, 41.14890016615391, 41.82979702949524, 38.34105983376503, 39.98903140425682, 36.401434913277626, 40.22635906934738, 39.54510882496834, 44.46799546480179, 46.91655747592449, 43.34770917892456, 39.14565145969391, 36.28683686256409, 37.09636442363262, 37.09402374923229, 38.33823658525944, 37.765789702534676, 38.62995073199272, 35.32701976597309, 38.383872136473656, 36.212197467684746, 36.9487651437521, 38.22057589888573, 37.91387915611267, 37.75057531893253, 42.838646695017815, 47.412294074893, 51.89882352948189, 53.401038721203804, 51.902387738227844, 51.82424873113632, 51.85972362756729, 49.258451610803604, 45.28310872614384, 42.824473455548286, 40.0995484739542, 39.941845536231995, 44.79598246514797, 43.09965468943119, 48.317770287394524, 47.34446011483669, 43.130615428090096, 43.19252170622349, 45.31319551169872, 42.36849032342434, 44.43260416388512, 45.400123447179794, 47.116335555911064, 46.43576167523861, 48.67643304169178, 51.11970193684101, 55.282538160681725, 53.45513641834259, 62.134558483958244, 64.53575223684311, 60.44986568391323, 70.12995645403862, 43.52461248636246, 0.06747218532836996, 0.2308585270657204, 6.28409662283957, 1.9332796172238886, 0.5885365849826485, 4.85637690871954, 65.6519803404808, 66.06256350874901, 65.20736619830132, 66.67116165161133, 66.04089707136154, 44.127222150564194, 25.916114151477814, 35.037927478551865, 48.653497472405434, 62.83551067113876, 4.212887613102794, 0.23460386437363923, 0.06614880243432708, 0.08130782924126834, 0.0041801681254582945, 0.10602154725347646, 0.11097267415607348, 0.030615773575846106, 0.06278716289671138, 0.05420466659415979, 0.07336422189837322, 0.2531504613580182, 0.16921033820835873, 9.843154270201921, 73.05829972028732, 59.376890659332275, 35.273351445794106, 12.281183246523142, 37.764186188578606, 53.32664631307125, 70.8054918050766, 67.21365854144096, 64.79834094643593, 68.65610674023628, 44.63740557432175, 0.11807171744294465, 0.27644395362585783, 1.6061067231930792, 5.122308963909745, 0.24791382282273844, 0.2659107110230252, 42.38199859857559, 62.30086416006088, 56.805405244231224, 64.50318798422813, 61.061537861824036, 57.8528456389904, 51.528639793395996, 57.03890271484852, 54.57896791398525, 58.04773338139057, 55.33395700156689, 55.5426874011755, 52.08384320139885, 59.06544417142868, 56.9357268512249, 55.33179871737957, 51.93486079573631, 47.29251690208912, 42.74000018835068, 42.740418165922165, 42.94988572597504, 46.023385003209114, 45.91956317424774, 47.99409605562687, 52.11892671883106, 53.9170016348362, 51.12831987440586, 52.63340011239052, 50.85864834487438, 52.58417755365372, 51.90156698226929, 53.37825134396553, 47.38290645182133, 42.91884899139404, 39.28025543689728, 39.12839278578758, 37.37467668950558, 40.84758013486862, 38.062447383999825, 38.75185579061508, 38.328072130680084, 38.07007737457752, 37.43835747241974, 39.254226833581924, 37.900557070970535, 41.07038877904415, 42.99199886620045, 47.144454047083855, 52.12420083582401, 48.89881610870361, 40.2462700009346, 40.351653546094894, 40.53378537297249, 41.146574690937996, 39.514262080192566, 41.00775673985481, 43.70485961437225, 44.0084633231163, 47.20345348119736, 48.00303317606449, 39.724045023322105, 44.5134524255991, 44.25727777183056, 50.08033990859985, 44.62395429611206, 39.02913451194763, 37.897015661001205, 38.09039868414402, 38.187449276447296, 39.266386181116104, 39.156401082873344, 39.909919649362564, 40.0724521279335, 42.82243296504021, 39.123825430870056, 39.001601189374924, 37.351547330617905, 40.64231514930725, 41.321817487478256, 45.90062879025936, 48.66262078285217, 46.485759392380714, 39.28140677511692, 38.05131018161774, 38.815468177199364, 38.66377271711826, 40.778055265545845, 40.93130484223366, 38.98573324084282, 38.6420226842165, 38.682631105184555, 38.31185460090637, 39.53602731227875, 40.43375954031944, 38.98737095296383, 41.36143036186695, 44.864998161792755, 50.9277818351984, 52.923795729875565, 55.05179554224014, 52.94825881719589, 52.993571385741234, 55.99909611046314, 52.591902539134026, 48.37602116167545, 44.39055182039738, 42.864192724227905, 43.140065521001816, 43.70136000216007, 47.714883238077164, 52.17416435480118, 48.871780559420586, 45.427310988307, 45.394275560975075, 47.10914634168148, 44.88759554922581, 46.36795051395893, 47.64850080013275, 49.61042292416096, 48.97182539105415, 51.512080281972885, 52.98329293727875, 57.19860814511776, 56.826782897114754, 65.24100959300995, 67.19365641474724, 63.23621056973934, 71.61612510681152, 47.610609233379364, 0.0841616171237547, 0.1793859398458153, 7.739417580887675, 3.1597957341000438, 0.4514294327236712, 5.600514253601432, 70.9231486916542, 71.06906086206436, 69.9859593808651, 72.4498763680458, 72.20459192991257, 49.53590512275696, 29.49239294975996, 42.33332701027393, 56.696457490324974, 77.10424661636353, 6.8729757238179445, 0.2736276516225189, 0.04663331310439389, 0.0731616304256022, 0.018325665187148843, 0.0785412362893112, 0.24295936367707327, 0.18974681122926995, 0.13343548052944243, 0.16266328952042386, 0.2979078737553209, 0.4196165897883475, 0.37224702537059784, 12.260864786803722, 83.20947781205177, 68.80068138241768, 43.50436717271805, 19.737698882818222, 46.090519800782204, 61.330574825406075, 76.38244494795799, 73.15373539924622, 70.82069858908653, 75.31237676739693, 51.740136444568634, 0.1711904030526057, 0.9767700056545436, 5.873775640502572, 10.764674171805382, 1.2383021344430745, 0.30921220779418945, 45.65727844834328, 62.49672085046768, 57.44711861014366, 69.44166898727417, 64.2820930480957, 62.11387239396572, 53.262859135866165, 58.792242631316185, 56.15891173481941, 62.55891211330891, 59.55781415104866, 59.17083151638508, 55.2807142585516, 60.36449186503887, 59.30029436945915, 57.93964058160782, 55.054318606853485, 49.437870383262634, 46.26116864383221, 44.932759925723076, 45.816166922450066, 47.2437085211277, 50.63841976225376, 49.6550477296114, 53.35684709250927, 55.766385197639465, 51.81093044579029, 56.05053775012493, 55.158448219299316, 53.464297726750374, 52.503055706620216, 55.92898227274418, 51.33753664791584, 44.90202337503433, 41.81433945894241, 40.63181631267071, 38.39729301631451, 45.0195624679327, 40.362064987421036, 41.27226434648037, 39.65754099190235, 40.149382799863815, 39.20484848320484, 42.746687829494476, 41.29873372614384, 44.66759495437145, 46.230527088046074, 49.15415100753307, 55.51329217851162, 51.64907053112984, 40.950493812561035, 42.76939921081066, 41.20177052915096, 43.91218788921833, 41.50310955941677, 41.12861305475235, 46.18744879961014, 45.08168913424015, 48.95089991390705, 49.36500169336796, 39.84674043953419, 45.889081209897995, 45.69000609219074, 51.18475444614887, 46.32381588220596, 38.05030703544617, 39.030707627534866, 38.042441457509995, 40.576726868748665, 39.45010632276535, 40.1786944270134, 40.37070952355862, 41.27569176256657, 43.11603181064129, 39.79400306940079, 39.38048645853996, 38.32891188561916, 40.321665555238724, 42.18204952776432, 46.56188830733299, 51.03435851633549, 47.91565306484699, 41.81859143078327, 40.50336040556431, 40.66244266927242, 40.789804235100746, 44.02999296784401, 41.659497767686844, 42.101934626698494, 40.065585896372795, 42.5191256403923, 40.77395148575306, 42.53443501889706, 43.131892159581184, 41.06854967772961, 42.92954541742802, 47.482480108737946, 53.028601706027985, 56.74503408372402, 57.37800791859627, 55.745452120900154, 55.549219250679016, 57.1283271163702, 54.99566875398159, 52.34814941883087, 46.360578909516335, 43.87199364602566, 44.72998380661011, 48.67518670856953, 47.52784967422485, 54.98184509575367, 51.170714199543, 47.18993000686169, 46.98857121169567, 48.8236029446125, 47.712569162249565, 48.52761022746563, 49.98288653790951, 52.217440232634544, 52.20555067062378, 54.64585192501545, 56.17739014327526, 60.754939913749695, 58.214833214879036, 68.88303056359291, 70.78209266066551, 66.32322192192078, 74.82249945402145, 51.85240522027016, 0.1314491668017581, 0.644776001572609, 13.698199409991503, 4.855959406122565, 1.5626999898813665, 5.800922624766827, 78.42082276940346, 76.34722083806992, 78.19538846611977, 78.69934022426605, 81.17248311638832, 59.32376570999622, 36.684310734272, 54.92066837847233, 63.64806666970253, 91.03211805224419, 11.34421432390809, 0.45590615656692535, 0.20998995780246332, 0.1879406612715684, 0.1850826505688019, 0.185713654209394], [0.03043016986339353, 0.09759978158399463, 0.05331563304935116, 0.11869428286445327, 0.033749043141142465, 0.15013197757070884, 0.008560549140383955, 3.6845022160559893, 59.433606415987015, 58.319946974515915, 37.025099247694016, 39.88547936081886, 32.12628811597824, 40.86447402834892, 66.28359764814377, 62.770245373249054, 62.61321119964123, 58.896414041519165, 46.38659231364727, 0.27500997588504106, 0.20915584318572655, 0.9343482507392764, 2.0679019996896386, 0.32014938653446734, 0.03698308893945068, 29.93387036025524, 63.07894840836525, 56.16870380938053, 60.769759118556976, 53.26706551015377, 56.57858781516552, 55.12144960463047, 54.27673973143101, 54.67190332710743, 54.8790568113327, 51.55051901936531, 53.497758731245995, 55.68809799849987, 59.12022203207016, 53.85974630713463, 51.086590513587, 45.97868800163269, 39.304254949092865, 39.542087987065315, 41.80965431034565, 43.85494016110897, 48.95083911716938, 51.47028632462025, 55.54864168167114, 51.720157116651535, 53.386299312114716, 50.54092079401016, 50.16770102083683, 54.4851091504097, 52.55142331123352, 50.26407524943352, 48.6050196737051, 40.34453272819519, 39.768130257725716, 38.15455824136734, 36.54425784945488, 36.866799741983414, 37.48092278838158, 37.159239649772644, 35.88277414441109, 36.29297353327274, 38.73209685087204, 38.47366891801357, 39.62621547281742, 38.86683002114296, 37.42710627615452, 40.34740537405014, 43.421998992562294, 46.66288308799267, 47.58113041520119, 41.20875455439091, 39.74300980567932, 38.7729636579752, 39.662055149674416, 39.21798437833786, 39.49314281344414, 41.05518959462643, 43.39273676276207, 42.402494698762894, 43.899466171860695, 41.62728309631348, 44.52732168138027, 41.57106131315231, 45.34079723060131, 44.72833089530468, 39.59837056696415, 38.361772522330284, 38.14682185649872, 39.79471743106842, 39.76694852113724, 40.14866083860397, 40.0321476906538, 41.63649000227451, 41.021675392985344, 38.163438364863396, 41.21854282915592, 36.22743844985962, 39.532998874783516, 40.47969147562981, 47.447457388043404, 47.72079952061176, 44.519152119755745, 39.43058677017689, 36.12908832728863, 36.144108921289444, 36.153353825211525, 35.24000443518162, 35.131147876381874, 36.880023032426834, 35.909270122647285, 36.625410094857216, 36.10678352415562, 37.481074780225754, 37.79440216720104, 37.138249576091766, 39.11661721765995, 39.60057444870472, 44.15463387966156, 51.23315244913101, 52.534928396344185, 51.100129187107086, 52.079370841383934, 53.546019941568375, 53.189241886138916, 50.070521235466, 49.630238860845566, 43.432110249996185, 42.88038745522499, 40.369584783911705, 42.136193588376045, 42.8683876991272, 41.95865571498871, 40.27469627559185, 41.107539385557175, 39.94051180779934, 44.69480149447918, 49.61761213839054, 51.0057270526886, 53.65378595888615, 53.34347561001778, 60.10990932583809, 55.84713466465473, 62.13861666619778, 63.26767288148403, 64.15271759033203, 61.086095944046974, 62.079070061445236, 71.09724014997482, 41.17514155805111, 0.08922872686525807, 0.366869067074731, 7.1324253268539906, 2.59146545547992, 0.6528768700081855, 8.631056360900402, 67.71592319011688, 62.91076943278313, 65.77257826924324, 69.48794290423393, 65.63805028796196, 46.896323561668396, 27.187877409160137, 32.297974303364754, 50.894237235188484, 57.01806843280792, 2.9029371170327067, 0.3148034296464175, 0.07243290077894926, 0.0795217469567433, 0.037700819957535714, 0.0418172273930395, 0.039904497607494704, 0.05213270902459044, 0.13153945648809895, 0.08161514517269097, 0.02340376242500497, 0.2439193762256764, 0.15258375147823244, 4.894412392750382, 67.94913947582245, 64.1267877817154, 39.86058309674263, 32.89735794067383, 37.72504448890686, 49.563848823308945, 70.14621198177338, 65.95475569367409, 67.2751696407795, 64.53924044966698, 50.54495617747307, 0.2758027974050492, 0.32089099986478686, 2.9206710029393435, 3.920289776287973, 0.7897080620750785, 0.14570043567800894, 33.55092667043209, 63.5219856351614, 57.5588858127594, 61.75603799521923, 55.3134723007679, 58.72050628066063, 56.784730553627014, 57.1248959004879, 57.053949907422066, 57.421568781137466, 54.74025405943394, 57.27904602885246, 57.33917400240898, 60.345527082681656, 55.6464484333992, 52.83393815159798, 47.30403408408165, 41.28377012908459, 42.987401112914085, 43.90917465090752, 44.434249475598335, 51.825236678123474, 54.03103731572628, 56.4910177141428, 55.29912047088146, 56.04168422520161, 52.59517416357994, 52.71957568824291, 55.70747695863247, 54.091685861349106, 52.608477249741554, 51.163764372467995, 44.01979811489582, 42.223626896739006, 40.180373936891556, 38.34117002785206, 39.58403393626213, 38.60662758350372, 39.0196768194437, 38.240357637405396, 37.51210771501064, 40.781630873680115, 40.25701962411404, 40.87760612368584, 38.93472097814083, 39.832768589258194, 41.99438899755478, 45.62184534966946, 47.90215238928795, 50.37801593542099, 42.75766544044018, 39.84069116413593, 39.36639301478863, 39.625421315431595, 39.63663071393967, 39.06452961266041, 43.4507292509079, 43.38694587349892, 42.33496472239494, 43.80541741847992, 44.15461108088493, 43.68372514843941, 44.064529314637184, 49.34509076178074, 44.75757792592049, 41.029248386621475, 37.23300889134407, 38.43988113105297, 39.452006220817566, 40.056777969002724, 40.26361607015133, 39.323987290263176, 40.8578509837389, 41.42293766140938, 38.46171475946903, 40.25280185043812, 37.28600464761257, 38.11828538775444, 41.92296802997589, 49.75190833210945, 47.235238775610924, 46.26791708171368, 40.53359538316727, 36.81753158569336, 38.098184466362, 38.61707702279091, 36.01523503661156, 38.092708960175514, 37.63664983212948, 38.08380223810673, 38.11427280306816, 38.4359597414732, 37.16900512576103, 38.2598277926445, 39.09408062696457, 41.98003716766834, 42.855418995022774, 46.63824900984764, 53.791794553399086, 55.366171672940254, 53.46598483622074, 54.73025679588318, 55.37971414625645, 55.96273586153984, 54.06433492898941, 52.30501413345337, 45.893694162368774, 44.85019035637379, 42.78663128614426, 44.742287546396255, 45.945257395505905, 45.06538040935993, 42.839205265045166, 44.504161924123764, 41.67889952659607, 46.75793118774891, 50.92671409249306, 53.183906972408295, 56.57034605741501, 56.93673379719257, 61.846682131290436, 61.364738792181015, 65.47908961772919, 67.87189722061157, 65.64748898148537, 62.83187046647072, 65.21593853831291, 72.27885514497757, 44.04656767845154, 0.13027364941081032, 0.2766741975210607, 5.623295931145549, 3.475373312830925, 0.8776890754234046, 9.608251824975014, 74.72798332571983, 68.92374157905579, 71.66430652141571, 72.98904463648796, 72.08663865923882, 54.5504504442215, 23.934759870171547, 36.95808224380016, 58.205880895256996, 68.63301157951355, 5.5682202614843845, 0.5637339502573013, 0.0587912616902031, 0.07161434899899177, 0.03360352282470558, 0.08807446458376944, 0.2890345186460763, 0.1575469976523891, 0.22639161441475153, 0.22656769637251273, 0.22422332607675344, 0.4301693954039365, 0.200469538976904, 5.646643303334713, 81.40673294663429, 73.29740568995476, 53.837019726634026, 53.45686912536621, 45.51823250949383, 55.69535180926323, 77.35133975744247, 72.29201003909111, 70.98199993371964, 69.18731823563576, 57.14261054992676, 0.553096717922017, 0.7544150808826089, 5.950593268498778, 9.24988355487585, 2.5536909699440002, 0.1701026817318052, 37.22336120903492, 68.64726841449738, 58.193394765257835, 65.60692235827446, 58.71153876185417, 63.97811695933342, 59.96694579720497, 61.10415257513523, 59.460619166493416, 59.45564903318882, 56.24625004827976, 60.75945407152176, 58.40067744255066, 62.14598447084427, 58.516791611909866, 54.10201370716095, 49.79941338300705, 43.18811774253845, 45.24003803730011, 46.08173847198486, 48.129889369010925, 55.28751589357853, 56.51343271136284, 59.47994492948055, 57.19585709273815, 57.94740356504917, 53.954456225037575, 55.82691974937916, 57.441118732094765, 57.535935044288635, 54.025827795267105, 54.27980616688728, 45.82190461456776, 44.49080564081669, 42.927846908569336, 40.58826304972172, 41.808054596185684, 41.31000392138958, 41.69287897646427, 40.77717751264572, 40.09701021015644, 43.61475504934788, 43.9907106757164, 42.96274043619633, 40.96147522330284, 41.844688430428505, 45.696404948830605, 48.640703558921814, 51.306336522102356, 53.06219570338726, 43.54238033294678, 40.91159150004387, 40.231112614274025, 40.25609627366066, 39.99938204884529, 39.071019664406776, 43.8174931704998, 45.06692312657833, 42.70313456654549, 44.150393307209015, 44.273008927702904, 46.03286549448967, 47.28931367397308, 50.371966660022736, 47.67825320363045, 41.07269145548344, 39.99569244682789, 37.577699795365334, 40.51939934492111, 39.41463142633438, 39.726822674274445, 40.60233749449253, 42.173306196928024, 42.43986949324608, 39.481865018606186, 41.85701496899128, 35.97765125334263, 40.46850107610226, 42.41575978696346, 50.39319612085819, 50.16366943717003, 48.521826937794685, 44.02547501027584, 40.25354661047459, 40.855042934417725, 39.843480214476585, 37.64914736151695, 40.17525941133499, 40.58787927031517, 39.26244579255581, 40.32457999885082, 39.75425720214844, 39.77550566196442, 40.824773758649826, 41.21468223631382, 44.57464434206486, 44.409296214580536, 49.931140914559364, 54.573268219828606, 58.804333582520485, 55.2720583230257, 56.219351291656494, 60.2270532399416, 58.3270487934351, 56.34200491011143, 53.74815009534359, 47.919369265437126, 49.00984615087509, 44.579899460077286, 46.90871089696884, 47.81142085790634, 46.209046840667725, 45.7634599506855, 46.55590362846851, 45.068074464797974, 48.861034736037254, 54.855733662843704, 56.13499201834202, 60.554648861289024, 59.445328786969185, 68.67522731423378, 61.71440362930298, 68.32492411136627, 69.61966663599014, 69.44022506475449, 66.2687100470066, 67.7520440518856, 71.95467934012413, 48.35281580686569, 0.20037432142999023, 0.6090307852718979, 14.37138743698597, 10.079258400946856, 0.8489897497929633, 10.810424666851759, 82.1530432999134, 72.34548836946487, 79.77372497320175, 79.47788804769516, 81.03772714734077, 63.86914640665054, 37.26939953863621, 49.58018034696579, 66.71591565012932, 82.41434007883072, 8.71792919933796, 0.7276193343568593, 0.29136314056813717, 0.16635139239951968, 0.19560179236577824, 0.17113941750722006], [0.04894127734587528, 0.025693683201097883, 0.036235367733752355, 0.044683264422928914, 0.1071118883555755, 0.03237973985960707, 0.053759288930450566, 0.6773550971411169, 46.73286773264408, 61.50291457772255, 43.5508006811142, 25.947544164955616, 20.6049757450819, 42.4783918261528, 66.02267324924469, 65.26456072926521, 60.647116899490356, 59.59774240851402, 54.48812618851662, 1.8436297215521336, 0.7025357522070408, 0.37163490196689963, 4.212096780538559, 0.6679763097781688, 0.1705225888872519, 28.028071224689484, 58.37791666388512, 56.627779975533485, 61.56180761754513, 58.21622774004936, 58.71463179588318, 56.49174727499485, 58.57512228190899, 57.53567285835743, 57.55830444395542, 55.020713210105896, 53.275250270962715, 58.47630858421326, 54.073427841067314, 50.79524874687195, 46.56439237296581, 40.10679088532925, 40.547210052609444, 38.825484439730644, 45.187665447592735, 47.76469096541405, 52.66289412975311, 51.484125182032585, 50.625595450401306, 51.70090734958649, 48.29704239964485, 48.29146049916744, 53.75952668488026, 50.99926359951496, 51.12872265279293, 47.1037582308054, 40.693992376327515, 41.067630127072334, 40.37730596959591, 36.523792147636414, 35.83263963460922, 38.00319716334343, 37.01657250523567, 38.234285563230515, 37.14990735054016, 36.73716589808464, 37.30990916490555, 38.537444695830345, 38.1790479272604, 37.715761587023735, 39.16187658905983, 37.35383100807667, 42.17186227440834, 45.83125591278076, 45.36690182983875, 42.58048854768276, 38.07009257376194, 40.04657171666622, 39.284644201397896, 38.94733250141144, 38.32032814621925, 39.52289141714573, 43.90737734735012, 43.12174290418625, 45.16463488340378, 42.8553581982851, 44.14507359266281, 44.22152929008007, 42.63787306845188, 44.05229017138481, 39.31983411312103, 38.83123353123665, 39.286760687828064, 40.09379558265209, 39.426167607307434, 40.53160049021244, 41.17937833070755, 43.54782164096832, 39.49818134307861, 39.15903054177761, 40.731226578354836, 40.613942071795464, 40.35040341317654, 40.6583084911108, 49.73740831017494, 43.02860230207443, 43.774380683898926, 41.33340686559677, 40.99871322512627, 40.57950831949711, 38.34466964006424, 38.191974833607674, 39.443224892020226, 35.9603887796402, 36.36178024113178, 37.61741146445274, 37.028332874178886, 38.66249978542328, 38.471373841166496, 37.13495135307312, 40.09934328496456, 44.11954276263714, 43.44287887215614, 47.34707437455654, 53.37169669568539, 51.091518849134445, 52.31625773012638, 54.667955338954926, 52.01915547251701, 53.68750914931297, 52.894263714551926, 51.94725953042507, 48.962223306298256, 47.32367143034935, 43.86839143931866, 41.95893310010433, 42.00235716998577, 40.682801976799965, 41.4331629127264, 40.37931226193905, 42.90926590561867, 51.49536117911339, 57.90500544011593, 57.12881729006767, 60.47845155000687, 57.72847071290016, 58.37781026959419, 60.07916897535324, 59.57510702311993, 63.583698123693466, 65.40905937552452, 61.48470975458622, 71.28358975052834, 32.143364399671555, 0.03335643959871959, 0.4634471487952396, 3.9724590769037604, 2.7999084955081344, 0.5117305344901979, 13.181139305233955, 69.62747141718864, 62.902132496237755, 66.18419498205185, 67.11617857217789, 67.41147592663765, 42.48529225587845, 26.912604980170727, 32.263468354940414, 54.6789937466383, 55.02201274037361, 1.8695389875210822, 0.16082448506494984, 0.05641751347866375, 0.013740699105255771, 0.05034103094658349, 0.06299801447312348, 0.020677429129136726, 0.013592790928669274, 0.041282265083282255, 0.051811403609463014, 0.0952206045622006, 0.058944032789440826, 0.05129622695676517, 1.1530407657846808, 57.06901229918003, 68.79162266850471, 51.08394205570221, 34.39219392836094, 29.107344411313534, 50.8137271553278, 70.79796060919762, 71.73094734549522, 66.31410241127014, 65.1288928091526, 59.735162034630775, 1.6530681657604873, 0.6629184843041003, 0.8427170582581311, 5.239669941365719, 0.6901715719141066, 0.32211022975388914, 30.22120714187622, 58.896550834178925, 59.613241776824, 64.58802223205566, 61.06228642165661, 61.524220034480095, 59.00043725967407, 59.08596307039261, 59.971931129693985, 59.72555235028267, 54.78511065244675, 53.906650990247726, 59.460223987698555, 55.121590197086334, 52.52489313483238, 49.18326124548912, 42.41859443485737, 42.75687888264656, 40.44805437326431, 46.71413093805313, 50.67167937755585, 55.086844861507416, 54.323070645332336, 53.73138539493084, 52.302608862519264, 50.31759537756443, 49.05802756547928, 53.69729362428188, 51.92736379802227, 53.330499306321144, 48.964605778455734, 43.28483395278454, 43.277568742632866, 41.989643052220345, 37.75439791381359, 38.92980024218559, 40.40061391890049, 39.52858351171017, 41.50692455470562, 39.874334558844566, 38.445227444171906, 40.63401259481907, 40.7546941190958, 39.98985975980759, 38.54871489107609, 40.942981615662575, 39.22618053853512, 43.42022828757763, 49.21587109565735, 50.289112105965614, 43.20356771349907, 39.962744414806366, 42.33041636645794, 39.658152759075165, 38.94722990691662, 39.44870039820671, 39.96476210653782, 42.20023535192013, 43.616046980023384, 44.99243952333927, 42.82768428325653, 43.37300822138786, 45.59925556182861, 44.951033145189285, 46.67635716497898, 39.45962481200695, 39.315437749028206, 38.502247184515, 40.40486589074135, 39.03065823018551, 40.07559835910797, 42.29756332933903, 42.78611831367016, 41.209043338894844, 40.14201499521732, 39.00973655283451, 40.95341585576534, 39.932292848825455, 42.041548267006874, 50.69771558046341, 46.06017462909222, 47.058780044317245, 42.87847615778446, 42.34858699142933, 41.51803515851498, 40.719709396362305, 40.0946581363678, 42.492329478263855, 37.62627638876438, 37.6101690530777, 39.83391992747784, 39.78840596973896, 39.73248437047005, 39.68294642865658, 39.88772124052048, 41.352645233273506, 43.83986636996269, 44.93782885372639, 49.70270097255707, 55.096944719552994, 53.391907811164856, 54.34405691921711, 58.09672795236111, 55.19567862153053, 55.38598760962486, 54.884513318538666, 54.65003550052643, 51.992401108145714, 49.75089758634567, 44.98821794986725, 43.14800329506397, 44.57195408642292, 43.702279552817345, 43.0698224902153, 43.16509857773781, 45.359511226415634, 53.07999774813652, 60.151186510920525, 59.95138183236122, 60.78455172479153, 59.56017002463341, 60.39807826280594, 63.68522487580776, 60.00910073518753, 65.5525852739811, 67.25952208042145, 64.12944003939629, 73.3928793668747, 36.50860816240311, 0.061061881060595624, 0.6032701162621379, 4.865323528647423, 3.3573074731975794, 0.48673497105482966, 13.998166713863611, 76.57536059617996, 67.8666079044342, 72.55187049508095, 73.65165308117867, 74.19947728514671, 50.80002889037132, 25.850672163069248, 38.87965053319931, 61.61113657057285, 66.09593331813812, 2.9393716994673014, 0.27781039592809975, 0.04314765697927214, 0.12496101495344192, 0.033391940232831985, 0.00890981867996743, 0.21400893980171531, 0.09092891297768801, 0.17984702135436237, 0.1693446224089712, 0.27583640185184777, 0.11577621757169254, 0.23449153290130198, 1.587168420664966, 67.58925318717957, 78.44878166913986, 61.692775189876556, 34.10424157977104, 30.924146622419357, 58.16209204494953, 75.11318385601044, 79.31227773427963, 71.54000759124756, 69.5130367577076, 65.98212942481041, 2.456866465508938, 1.1630024062469602, 3.791040424257517, 9.04184091836214, 1.5134180593304336, 0.3064519527833909, 33.96449647843838, 62.03827925026417, 60.63452057540417, 65.79283878207207, 64.10899713635445, 62.52360060811043, 61.79092012345791, 62.26696237921715, 62.64775134623051, 61.95031777024269, 57.67916835844517, 57.67828680574894, 60.89761845767498, 58.22535865008831, 54.50859569013119, 51.14358365535736, 44.65052247047424, 46.344954147934914, 41.76675081253052, 50.28027758002281, 52.69700109958649, 58.38743135333061, 57.81894385814667, 56.532534286379814, 54.39573034644127, 51.61863796412945, 50.32466299831867, 57.08880163729191, 56.85968153178692, 55.911108031868935, 52.330358773469925, 43.86946298182011, 44.556789100170135, 43.536445051431656, 38.99976208806038, 40.353918224573135, 42.524734139442444, 40.20838603377342, 42.079219445586205, 41.629555374383926, 40.02989441156387, 41.692290008068085, 42.7840132266283, 42.95265957713127, 41.52204014360905, 43.519722148776054, 40.41932411491871, 45.95013253390789, 50.495148450136185, 55.33281326293945, 45.631113052368164, 40.08440628647804, 42.02537253499031, 40.01834683120251, 38.791871443390846, 40.23096442222595, 40.45043684542179, 44.062462225556374, 45.54120987653732, 46.742595210671425, 43.67023587226868, 45.11424958705902, 49.13301274180412, 47.30529561638832, 48.97976316511631, 39.516481161117554, 38.83469134569168, 39.011070281267166, 39.80466529726982, 39.74384196102619, 41.61819778382778, 43.202268183231354, 44.6265609562397, 40.24915784597397, 41.45987547934055, 40.902601182460785, 42.44896620512009, 41.80004082620144, 43.50290045142174, 53.68802972137928, 47.59129486978054, 49.2743119597435, 45.356099009513855, 43.42839404940605, 45.56094981729984, 42.59610950946808, 40.943676978349686, 45.03174841403961, 39.37941111624241, 39.40518133342266, 41.924111768603325, 41.701679304242134, 43.492960184812546, 42.316486313939095, 42.440226674079895, 43.06897133588791, 47.60494753718376, 47.04069301486015, 51.58327326178551, 56.93072251975536, 55.348267033696175, 57.116540148854256, 61.28694176673889, 58.101983070373535, 58.95414814352989, 57.36055925488472, 57.82492093741894, 55.08764661848545, 51.61974750459194, 47.22513131797314, 46.83575861155987, 47.02690355479717, 44.91206243634224, 44.13515232503414, 44.702180698513985, 47.8270798176527, 56.619101241230965, 63.17077048122883, 62.968522533774376, 63.34772318601608, 62.311773374676704, 61.08948156237602, 66.05694741010666, 62.46799819171429, 68.66415470838547, 70.05440130829811, 65.75974255800247, 75.63938722014427, 38.696488961577415, 0.17203631781740114, 1.0622616182081401, 11.47677781060338, 8.979591708630323, 0.6634442810900509, 15.756164230406284, 82.4713446199894, 75.41558682918549, 79.75184574723244, 78.32493111491203, 81.35032877326012, 59.27826315164566, 35.736360400915146, 48.096986934542656, 70.4226091504097, 80.51487520337105, 4.127921797335148, 0.45640119875315577, 0.15053690818604082, 0.33205085259396583, 0.15029345406219363, 0.1188135014672298], [0.05728858333895914, 0.06463812373112887, 0.04008853167761117, 0.06268208220717497, 0.08096269346424378, 0.05821791921334807, 0.13926941435784101, 0.1984154077945277, 37.39584155380726, 63.766924291849136, 47.03379638493061, 33.806797340512276, 30.787380561232567, 33.269939348101616, 54.34985540807247, 58.2805734872818, 61.30265012383461, 54.898036792874336, 62.641584277153015, 5.300915529951453, 0.6204622343648225, 0.5152279499452561, 2.724942793138325, 0.7761523488443345, 0.2368345228023827, 32.43083797395229, 61.39509156346321, 54.521241411566734, 64.05627116560936, 59.41582717001438, 60.09241506457329, 56.4383677393198, 57.907300516963005, 53.59192527830601, 53.20903122425079, 50.34373797476292, 58.28815408051014, 56.41915217041969, 52.55919009447098, 49.524908512830734, 41.97228938341141, 39.688748717308044, 38.614569157361984, 41.504416689276695, 49.61155526340008, 52.15442441403866, 50.13705186545849, 50.63241608440876, 53.13262492418289, 53.950485438108444, 54.032078459858894, 49.205235466361046, 52.382795959711075, 56.059725657105446, 47.7690265327692, 40.95495477318764, 41.236519664525986, 43.76291289925575, 39.99343916773796, 38.27186934649944, 37.16859854757786, 36.20722733438015, 36.05929747223854, 38.020961210131645, 37.81710974872112, 39.46916989982128, 37.74641454219818, 39.23941522836685, 39.18427638709545, 36.304954290390015, 37.76840776205063, 38.62202815711498, 41.24432444572449, 45.374604016542435, 45.09333550930023, 43.789952248334885, 39.44692209362984, 36.757434010505676, 40.189189463853836, 41.23073637485504, 38.3576725423336, 41.14657089114189, 42.667872458696365, 44.10702243447304, 43.5908467322588, 43.757513388991356, 42.85330630838871, 42.811850532889366, 43.57399843633175, 44.048965349793434, 40.41519373655319, 41.21640734374523, 40.52773989737034, 41.52787663042545, 39.123061671853065, 39.82198476791382, 41.52366645634174, 39.14485350251198, 38.378674015402794, 38.5182861238718, 39.49612185359001, 39.288314804434776, 38.73108610510826, 43.71795371174812, 46.21315822005272, 44.0127494931221, 42.03721649944782, 38.61928850412369, 36.87321379780769, 38.366773054003716, 38.1767338514328, 38.308385387063026, 39.156537875533104, 38.071829080581665, 37.24942021071911, 36.75330363214016, 35.738940462470055, 38.11457298696041, 38.155135810375214, 37.86834999918938, 38.029244765639305, 40.649230778217316, 40.50770737230778, 42.14032016694546, 47.05235078930855, 52.86038473248482, 50.302772372961044, 51.87257833778858, 53.403561785817146, 53.52749213576317, 56.16184517741203, 53.14390271902084, 54.42053161561489, 50.91176189482212, 49.42663438618183, 48.63226421177387, 46.26209579408169, 45.8053907006979, 41.00924625992775, 41.21560178697109, 44.50339436531067, 51.69252499938011, 57.6656448841095, 60.06992407143116, 59.1074775159359, 58.91889363527298, 62.52163611352444, 57.78069131076336, 52.793470323085785, 45.526675656437874, 51.67361341416836, 57.590526714921, 56.77838869392872, 32.02432058751583, 0.0726917470456101, 0.5344764108303934, 1.7790695233270526, 1.8243191577494144, 0.9212635934818536, 16.797095574438572, 68.5540746152401, 61.72095067799091, 67.3452378809452, 70.16652569174767, 66.37853935360909, 49.02440696954727, 22.030218467116356, 38.310596868395805, 59.359483793377876, 45.641668885946274, 0.8387422340456396, 0.09748506781761535, 0.055590278570889495, 0.05363539108657278, 0.025190139713231474, 0.03717947234690655, 0.02987634958117269, 0.0678312660602387, 0.03300302145362366, 0.0684637539961841, 0.10100920058903284, 0.05781732645118609, 0.2102138934424147, 0.3895034728338942, 45.14483414590359, 69.17930826544762, 54.11592476069927, 27.334958016872406, 34.90127541124821, 47.34329737722874, 62.50727668404579, 67.35897034406662, 65.72682872414589, 60.982954278588295, 66.93461671471596, 5.859446609392762, 0.9172412124462426, 1.1562764109112322, 4.884670665487647, 0.6905414583161473, 0.23937545833177865, 33.96110326051712, 61.35944187641144, 57.21016712486744, 66.39268979430199, 60.02637080848217, 61.34301535785198, 59.9157739430666, 57.3273566365242, 55.96854194998741, 55.33948950469494, 53.07982295751572, 60.65693557262421, 58.849345967173576, 52.987149730324745, 50.963534116744995, 45.43730065226555, 42.251965776085854, 42.05246888101101, 43.68509687483311, 51.673697009682655, 54.450306817889214, 51.171686947345734, 54.087791070342064, 53.75714421272278, 54.37694415450096, 53.9754007011652, 50.588102862238884, 53.69428038597107, 56.625112518668175, 49.66152638196945, 43.90603221952915, 44.74341608583927, 46.345349326729774, 41.73427015542984, 42.359576001763344, 38.41715835034847, 39.1302926838398, 39.62397739291191, 38.17531652748585, 39.18255887925625, 40.198681354522705, 40.0399486720562, 39.77781593799591, 40.15725217759609, 39.4101020693779, 40.01587696373463, 41.51655703783035, 43.81849251687527, 49.09058041870594, 49.17376935482025, 49.22993794083595, 41.44794411957264, 38.335386738181114, 39.95844304561615, 41.79174967110157, 38.20003040134907, 42.46091276407242, 43.08353215456009, 43.137227073311806, 44.71742548048496, 42.08527252078056, 43.78444254398346, 46.44860878586769, 46.3681785017252, 45.54850548505783, 40.0005903840065, 41.06156565248966, 40.65886326134205, 41.59306973218918, 37.72863149642944, 39.42797631025314, 41.850726306438446, 39.36848670244217, 38.9627368748188, 39.141695871949196, 39.30967725813389, 41.36435240507126, 39.71558667719364, 44.74721968173981, 47.29720585048199, 46.902247443795204, 44.19583886861801, 41.892873644828796, 38.90525355935097, 40.23884519934654, 38.71956892311573, 41.01796679198742, 41.93797342479229, 40.103017687797546, 38.178341165184975, 38.338491171598434, 38.31313893198967, 39.67637278139591, 40.852136090397835, 38.87890577316284, 40.674594417214394, 43.676862716674805, 43.09952549636364, 43.77003371715546, 49.40227769315243, 54.867292642593384, 53.88978749513626, 55.23234665393829, 54.056818932294846, 55.73861248791218, 56.02949447929859, 54.5088654756546, 56.32712110877037, 54.75598141551018, 50.9561663120985, 50.034609362483025, 50.74139043688774, 47.23344147205353, 44.49585936963558, 43.40188667178154, 45.67476511001587, 53.998370468616486, 60.98194733262062, 61.569684594869614, 62.316671311855316, 60.913342013955116, 65.0873838365078, 57.738171592354774, 54.93923418223858, 47.795131132006645, 53.658638298511505, 59.02649246156216, 61.67803958058357, 36.008091419935226, 0.11279362253844738, 0.2935342490673065, 4.423746848478913, 0.019289087904326152, 0.9096374048385769, 18.435926735401154, 75.73726236820221, 67.87615299224854, 74.24141943454742, 74.06081512570381, 74.2810133099556, 51.4838819950819, 19.65180069208145, 45.11112615466118, 66.85607492923737, 56.324381455779076, 1.4125112676993012, 0.04570369521388784, 0.04163166078797076, 0.07310908637009561, 0.03208184178220108, 0.02871188276913017, 0.15047863475047052, 0.16600479459157214, 0.1405127640464343, 0.14331116544781253, 0.25903394096530974, 0.25802702468354255, 0.22531273949425668, 0.5521452252287418, 55.53075224161148, 79.75715786218643, 63.38482439517975, 44.54309083521366, 43.041852191090584, 49.82144080102444, 68.00834029912949, 69.24932330846786, 72.13712275028229, 64.19020637869835, 73.35563376545906, 6.701220190152526, 1.0055907466448843, 4.724599979817867, 8.04874425753951, 1.7740546236746013, 0.38920091406907886, 37.125660851597786, 62.95368053019047, 61.08635053038597, 64.98527571558952, 62.24633328616619, 63.411825746297836, 61.97560541331768, 60.93601539731026, 57.7277335524559, 55.69759748876095, 54.422568306326866, 61.09105087816715, 59.885063990950584, 56.56897433102131, 54.26539734005928, 46.5821336209774, 45.263410583138466, 44.192970022559166, 45.84678567945957, 54.52920198440552, 56.57248914241791, 54.93544198572636, 57.56379134953022, 56.664121225476265, 55.8901559561491, 56.083839163184166, 53.35332088172436, 56.08803033828735, 60.6827399879694, 51.866715252399445, 47.66789875924587, 47.15813711285591, 47.940344139933586, 45.69480903446674, 44.23945292830467, 41.75135783851147, 41.11813321709633, 41.10469713807106, 42.35154703259468, 41.862798258662224, 42.97255150973797, 41.7826833575964, 43.75605046749115, 41.86091735959053, 40.8316133916378, 41.53885044157505, 41.71309769153595, 45.80957427620888, 50.85623547434807, 52.999533265829086, 50.59157967567444, 42.80108951032162, 37.6654788851738, 40.58088384568691, 42.99387976527214, 38.79279859364033, 42.21938632428646, 44.21065807342529, 45.33337242901325, 45.452226251363754, 42.231522873044014, 45.03393329679966, 48.75076845288277, 48.54043833911419, 45.01002877950668, 40.329246148467064, 43.98815341293812, 40.44688023626804, 41.78135722875595, 37.9849087446928, 39.87937688827515, 43.56973126530647, 39.329698383808136, 39.110541343688965, 39.63480681180954, 40.356961861252785, 41.82309798896313, 40.88189609348774, 45.64185127615929, 50.48314489424229, 50.252143889665604, 47.23626472055912, 45.219769924879074, 40.45004926621914, 42.96129651367664, 40.25596708059311, 43.47394220530987, 43.12688782811165, 42.52330161631107, 39.838977456092834, 40.088874846696854, 39.05867412686348, 43.794120624661446, 42.68836475908756, 41.67152412235737, 44.28259201347828, 44.746805503964424, 44.81244318187237, 46.05643942952156, 51.59995436668396, 56.60298250615597, 56.60729147493839, 56.507847011089325, 56.94165073335171, 57.2733311355114, 60.4233431071043, 58.14995549619198, 60.440578982234, 57.068544924259186, 55.50208278000355, 52.637929469347, 53.623273596167564, 50.01805365085602, 45.888617634773254, 46.91765181720257, 48.0561239272356, 55.249867513775826, 62.925045266747475, 65.92873468995094, 63.49053092300892, 65.13561084866524, 66.56578570604324, 59.60780426859856, 55.45715779066086, 48.032097816467285, 55.89769475162029, 62.37854339182377, 61.33729666471481, 41.77823379635811, 0.17213640385307372, 1.5922734467312694, 12.53160310909152, 6.698168953880668, 1.1301981727592647, 20.0253339484334, 80.70150598883629, 74.65312734246254, 79.86532285809517, 80.57172015309334, 79.7644154727459, 65.76377034187317, 33.03981229662895, 56.044906452298164, 73.8417112827301, 71.94772571325302, 2.8257133858278394, 0.2856238157255575, 0.1223447588563431, 0.15636463765986264, 0.07836090924683958, 0.09364572266349569], [0.05994990264298394, 0.022741258326277602, 0.08350914315087721, 0.10808662511408329, 0.027480583703436423, 0.030449764417426195, 0.18816057447111234, 0.17123337340308353, 31.56551230698824, 66.20732054114342, 42.935875877738, 35.650933384895325, 28.979447074234486, 31.124213486909866, 48.984938487410545, 57.2636454552412, 66.52679979801178, 54.19780656695366, 66.26018330454826, 11.509530153125525, 0.5709608062170446, 0.08642992470413446, 5.07003896869719, 0.28914450493175536, 0.452093209605664, 46.224850192666054, 67.05611899495125, 61.11114799976349, 56.68277442455292, 61.613359451293945, 56.16759426891804, 55.87947092950344, 52.750981003046036, 54.87582318484783, 53.491808250546455, 59.40891154110432, 53.084538504481316, 48.4721864014864, 46.38433523476124, 43.29444743692875, 42.5850673019886, 41.11633971333504, 42.16411828994751, 47.43363372981548, 48.760758116841316, 51.923096626996994, 51.40089064836502, 53.90437111258507, 50.093023627996445, 54.16428856551647, 55.043291598558426, 58.691175654530525, 53.87118749320507, 49.998910278081894, 47.54920072853565, 46.48757949471474, 41.64782099425793, 43.72956208884716, 40.97277581691742, 39.69721086323261, 38.80723021924496, 37.09959425032139, 36.031672954559326, 35.19721493124962, 36.915216743946075, 38.1522061675787, 34.27300192415714, 37.76077017188072, 38.95548686385155, 38.86762037873268, 41.07192389667034, 39.179450646042824, 41.72507464885712, 44.90915559232235, 46.92663073539734, 44.65623736381531, 42.57236458361149, 38.464864790439606, 39.19030286371708, 38.24186995625496, 39.68011178076267, 37.444725930690765, 40.41192211210728, 40.38671426475048, 44.11295011639595, 42.30822175741196, 43.40929627418518, 41.53164602816105, 42.951025664806366, 48.89671862125397, 38.95640641450882, 37.65653416514397, 38.735600262880325, 41.5608474612236, 39.91761803627014, 40.214306116104126, 39.113113805651665, 41.077946573495865, 42.114789336919785, 38.76825571060181, 38.55252228677273, 41.40936478972435, 43.101132810115814, 43.65366876125336, 45.41224479675293, 46.66703626513481, 39.754435792565346, 38.98334316909313, 37.59801730513573, 36.379996463656425, 37.72548906505108, 38.10563586652279, 36.061109974980354, 35.40803141891956, 36.5044017881155, 35.21060921251774, 37.65689134597778, 36.203552931547165, 37.866864278912544, 36.923808082938194, 37.13624708354473, 40.07765784859657, 43.43970984220505, 40.82750581204891, 43.700983822345734, 48.41571383178234, 54.00934427976608, 52.22934119403362, 51.575715467333794, 48.45969647169113, 52.75941275060177, 52.85818085074425, 54.2955981194973, 54.18271757662296, 55.16986280679703, 52.844535782933235, 53.70892859995365, 56.80434130132198, 53.00953812897205, 52.13628038764, 43.69282566010952, 43.67973156273365, 50.698973312973976, 55.80249845981598, 56.95882961153984, 58.97141441702843, 58.11269089579582, 58.47794249653816, 60.31124912202358, 65.05292728543282, 50.57342804968357, 60.61604976654053, 62.0141239464283, 46.57070383429527, 0.4483341722516343, 0.21809964295243844, 3.1505228066816926, 1.2341643939726055, 0.12382085347780958, 25.538509413599968, 73.05576145648956, 60.639585703611374, 68.43602254986763, 67.34095931053162, 64.23386603593826, 42.122130542993546, 32.74050235748291, 39.619907811284065, 60.84923565387726, 44.07370202243328, 1.2986151105724275, 0.16561289608944207, 0.04879742315097246, 0.026249544389429502, 0.019540547946235165, 0.01686556941422168, 0.03255534313211683, 0.025341354157717433, 0.06992316513787955, 0.07725001065409742, 0.07652183761820197, 0.03303637357021216, 0.22656122484477237, 0.2660317998379469, 40.257137417793274, 73.88027921319008, 53.61914701759815, 35.370037257671356, 33.29383246600628, 39.5583663135767, 58.340595066547394, 65.79694256186485, 70.25749281048775, 60.780417546629906, 72.83971264958382, 12.424057479947805, 0.691538667306304, 0.3567131026647985, 3.8652839278802276, 0.3104147838894278, 0.27338547399267554, 49.2064817994833, 69.88893538713455, 62.42639422416687, 59.0027741342783, 63.324487432837486, 56.56541012227535, 57.21753112971783, 54.245900586247444, 56.7942338436842, 54.246364161372185, 61.355049312114716, 54.90080304443836, 53.285832703113556, 47.89807140827179, 44.757748916745186, 43.15370298922062, 42.695629969239235, 44.04902994632721, 49.5764147490263, 49.68003138899803, 54.87286314368248, 53.71589742600918, 55.72082944214344, 52.87656806409359, 55.068013072013855, 58.271583169698715, 60.868922397494316, 52.54583761096001, 52.66680411994457, 50.23925118148327, 48.98513987660408, 40.62049672007561, 45.585211515426636, 42.788249999284744, 42.58257083594799, 39.88295629620552, 40.31748577952385, 37.90531441569328, 38.004572689533234, 39.737002328038216, 40.573117062449455, 37.36850582063198, 39.17138747870922, 39.49184708297253, 41.015192940831184, 41.51983246207237, 42.57818967103958, 44.139495491981506, 45.16943022608757, 50.327915623784065, 48.640000596642494, 46.07453405857086, 40.83018086850643, 38.943737894296646, 38.927683755755424, 39.70184661448002, 38.52680526673794, 40.631006956100464, 40.828930735588074, 45.71278966963291, 42.49769099056721, 44.60159249603748, 43.80944900214672, 45.34926697611809, 47.39292651414871, 38.771770521998405, 38.00758972764015, 38.26602526009083, 42.06090062856674, 39.424195513129234, 40.970309749245644, 39.94306907057762, 41.15531042218208, 39.23018932342529, 39.142262041568756, 38.57450030744076, 41.952462047338486, 43.722122088074684, 45.432049334049225, 49.00072284042835, 48.76132808625698, 41.90474420785904, 40.97587265074253, 39.487180933356285, 38.62670190632343, 38.13215844333172, 38.35983842611313, 37.70737923681736, 37.092063054442406, 38.055835738778114, 37.39554136991501, 38.65826301276684, 39.20796811580658, 38.98773953318596, 39.14088271558285, 40.217110365629196, 42.43156313896179, 45.139343440532684, 41.82329177856445, 45.68978190422058, 52.04722836613655, 56.29651375114918, 54.42045941948891, 52.82489463686943, 50.361391827464104, 53.60501937568188, 54.56148885190487, 54.07199911773205, 55.99469214677811, 57.187721729278564, 54.49100263416767, 57.146680131554604, 59.94015343487263, 55.79766511917114, 53.87708097696304, 45.488252118229866, 46.26123704016209, 51.57147869467735, 58.3826170116663, 58.7848786264658, 61.65803365409374, 60.19479677081108, 61.66350156068802, 61.41985483467579, 66.58536985516548, 55.87001323699951, 62.97174096107483, 63.56274604797363, 49.93231505155563, 0.2555996674345806, 0.466490785474889, 3.4494867268949747, 1.7368172155693173, 0.2044607201241888, 27.238887771964073, 78.69127705693245, 64.88544747233391, 74.37721654772758, 71.8086151778698, 74.58957955241203, 47.66463093459606, 32.34515257179737, 49.45376493036747, 69.62705343961716, 55.57569622993469, 1.4875090308487415, 0.23031935677863657, 0.08087560985586606, 0.06585238865227439, 0.04494823711866047, 0.050957963467226364, 0.1686599911772646, 0.12608075252501294, 0.14564734243322164, 0.2329886393272318, 0.19722635362995788, 0.18422676133923233, 0.44236080371774733, 0.3737333690514788, 46.99089668691158, 84.22027677297592, 60.91780297458172, 46.96552164852619, 42.76523843407631, 45.78655131161213, 70.19233390688896, 70.95790922641754, 78.63697797060013, 64.56158325076103, 81.03209584951401, 14.160179570317268, 1.041943752206862, 2.954543810337782, 10.932607110589743, 0.45961849798914045, 0.6273688387591392, 53.58554542064667, 71.03731736540794, 63.824787586927414, 62.0094083994627, 62.73693636059761, 56.0049743950367, 57.72454172372818, 54.770857617259026, 58.71871657669544, 56.802156418561935, 63.30604322254658, 54.5302165299654, 54.32429797947407, 50.90858146548271, 46.28193452954292, 44.2637450248003, 45.56203655898571, 46.77545964717865, 52.57281236350536, 52.148504331707954, 58.01204949617386, 56.39384552836418, 58.35418313741684, 55.10987922549248, 60.300206914544106, 59.853704273700714, 59.348232597112656, 54.75902125239372, 58.141067773103714, 51.919855400919914, 50.6426527351141, 42.306489050388336, 49.59415599703789, 44.717915654182434, 45.588281750679016, 42.519589215517044, 42.667914256453514, 41.37384809553623, 38.54535587131977, 41.19890168309212, 41.25755153596401, 37.030270770192146, 41.79556466639042, 43.394800052046776, 43.99100326001644, 45.401726961135864, 44.474835097789764, 46.371864303946495, 49.01942543685436, 53.8163336366415, 51.588235795497894, 48.28350372612476, 42.45774373412132, 38.70302461087704, 37.66585886478424, 40.028138905763626, 38.59356388449669, 38.939964696764946, 40.41879594326019, 45.60737572610378, 44.70383740961552, 45.26031754910946, 44.58301529288292, 48.5949844121933, 51.66137047111988, 40.36800406873226, 37.92161554098129, 39.546305760741234, 42.10307076573372, 40.28201088309288, 40.994081273674965, 39.67590540647507, 43.49208623170853, 41.98232464492321, 39.513198137283325, 38.33787940442562, 43.74710954725742, 44.466456547379494, 47.905853390693665, 52.179769054055214, 53.40916648507118, 42.938744723796844, 42.43569731712341, 43.35971653461456, 40.147574096918106, 40.015854164958, 41.09120026230812, 40.18524907529354, 38.83972227573395, 39.275194108486176, 38.56145940721035, 41.16753436625004, 39.45218101143837, 40.57068519294262, 40.09623125195503, 41.990106627345085, 43.60835239291191, 47.746345549821854, 43.910983353853226, 48.752618953585625, 54.33911718428135, 57.996550127863884, 55.65165415406227, 54.911301881074905, 52.38028049468994, 54.41598705947399, 56.70769728720188, 58.560420870780945, 58.14504995942116, 59.63812664151192, 58.23713041841984, 57.44538590312004, 62.34414003789425, 57.57808618247509, 58.57582904398441, 47.74322971701622, 49.352857545018196, 54.480131417512894, 60.642264559865, 61.73468694090843, 66.56424298882484, 62.43646748363972, 64.27923560142517, 62.16810308396816, 65.95374494791031, 53.20503003895283, 64.61047902703285, 64.68884602189064, 50.86120940744877, 0.6273564300499856, 2.4901788029819727, 8.65633450448513, 6.042106607928872, 0.24571467598434538, 30.335852690041065, 85.42014598846436, 68.21143940091133, 82.59287729859352, 78.42440977692604, 80.18860951066017, 58.23509752750397, 43.707614466547966, 59.95160982012749, 77.5569999217987, 69.30746018886566, 2.547255540266633, 0.4290770727675408, 0.20685383467935026, 0.16496976575581357, 0.16494635841809213, 0.15168855810770765], [0.03775600234803278, 0.04042417167511303, 0.02162123502785107, 0.0450661272770958, 0.1134136646578554, 0.018199971345893573, 0.3552828950341791, 0.4248156608082354, 21.914666667580605, 66.12931832671165, 42.31371246278286, 30.379449650645256, 16.88739202916622, 31.698003597557545, 49.141718074679375, 57.06563048064709, 66.00983753800392, 53.468507900834084, 67.27445527911186, 16.94973338395357, 0.602652708766982, 0.1894209935562685, 3.3401886792853475, 0.1445323249208741, 3.151406259275973, 64.9091961979866, 62.98904903233051, 65.06469145417213, 59.49767477810383, 59.17350277304649, 56.761244013905525, 59.355554804205894, 52.83924266695976, 57.405814826488495, 57.23308369517326, 56.531367748975754, 47.258615121245384, 49.367186576128006, 40.39638474583626, 42.78712145984173, 41.73134431242943, 43.392835557460785, 43.172736167907715, 45.98432309925556, 47.76864655315876, 50.807518288493156, 49.86669637262821, 49.820418655872345, 49.76161681115627, 51.48184910416603, 49.66895878314972, 50.49000732600689, 57.90431007742882, 58.631268069148064, 51.907190680503845, 53.53042557835579, 48.64674523472786, 42.3891232162714, 40.7048711925745, 39.127401039004326, 38.73042494058609, 38.695820197463036, 37.897718623280525, 36.52353376150131, 34.845141023397446, 37.91968144476414, 39.912020936608315, 42.84176252782345, 43.18577326834202, 42.29225881397724, 41.72693274915218, 39.90131691098213, 41.12749591469765, 46.784218177199364, 47.43591360747814, 45.0001835078001, 43.17131504416466, 40.29676169157028, 40.10671108961105, 39.26409110426903, 39.60237555205822, 38.220556899905205, 38.439687341451645, 40.888203755021095, 42.85742528736591, 40.81607602536678, 43.13244692981243, 44.11152899265289, 42.71408177912235, 43.38241271674633, 37.60320782661438, 39.34899754822254, 38.39113734662533, 39.45762611925602, 40.57697385549545, 42.43815578520298, 39.819203317165375, 40.91971166431904, 41.27867080271244, 38.88557441532612, 40.561668276786804, 41.64676085114479, 40.458097234368324, 43.787535578012466, 46.23130604624748, 48.940784856677055, 40.770147889852524, 36.647182926535606, 34.30175498127937, 37.44050435721874, 37.12754935026169, 35.48538386821747, 38.22136625647545, 36.70743629336357, 35.71463696658611, 37.3420250415802, 35.66878102719784, 38.500434681773186, 38.405283987522125, 39.640240520238876, 38.39319683611393, 40.51869638264179, 42.00257755815983, 42.84750021994114, 45.26160567998886, 49.81857195496559, 51.88307337462902, 50.860802829265594, 50.05733974277973, 50.838429629802704, 47.05328553915024, 48.624592423439026, 45.99633425474167, 47.95687325298786, 51.48310303688049, 56.737594082951546, 54.514090195298195, 55.97791224718094, 54.77720707654953, 56.58467508852482, 52.830712124705315, 45.21586373448372, 42.03669212758541, 46.52991682291031, 49.902148470282555, 56.2863264977932, 59.09329667687416, 62.94946275651455, 59.12075400352478, 65.61497032642365, 69.62510034441948, 63.14549803733826, 65.63222140073776, 56.722672283649445, 1.5935551654547453, 0.34503861505072564, 1.718617973383516, 0.39877527218777686, 0.163966738327872, 38.293832167983055, 70.59888169169426, 58.959912434220314, 62.44084104895592, 68.23132753372192, 60.919531881809235, 55.16070909798145, 36.18138872087002, 31.328824907541275, 60.85902392864227, 33.265805169939995, 0.9626891487278044, 0.1075356917863246, 0.030359253942151554, 0.10486484330613166, 0.05715587620215956, 0.03361069939273875, 0.042243658026563935, 0.06948327194550075, 0.07225313034723513, 0.05709417775506154, 0.20443153887754306, 0.09844557018368505, 0.37229553214274347, 0.49086419166997075, 27.450004443526268, 77.12382316589355, 49.81808178126812, 38.09489764273167, 24.081633388996124, 40.60194991528988, 59.096446707844734, 64.07261028885841, 72.40160375833511, 57.984561771154404, 73.26465144753456, 18.415873311460018, 0.5914867704268545, 0.4575692204525694, 4.0355924516916275, 0.054803672537673265, 3.054402689449489, 68.71872738003731, 65.29932886362076, 66.94465577602386, 59.43997107446194, 61.852932795882225, 57.41112694144249, 61.281181275844574, 55.817484855651855, 59.60590437054634, 58.73007416725159, 58.87289710342884, 50.24629220366478, 53.34751479327679, 42.8067360073328, 45.266446620225906, 44.153395146131516, 45.04701979458332, 44.500973895192146, 48.41229021549225, 49.59624968469143, 53.36808308959007, 52.997036799788475, 50.800211280584335, 51.412050649523735, 53.76489199697971, 52.4025435000658, 56.21444575488567, 59.60422106087208, 57.94632442295551, 53.254172801971436, 54.399834126234055, 48.220510706305504, 44.271166026592255, 43.82764242589474, 42.15950533747673, 39.17327597737312, 40.14796547591686, 39.819032326340675, 38.349202796816826, 37.516010105609894, 38.46171855926514, 40.399185195565224, 45.57928003370762, 44.56575281918049, 43.4894035756588, 42.29699335992336, 42.11246386170387, 42.814369797706604, 49.129190146923065, 48.37066724896431, 48.755081221461296, 46.17055110633373, 40.70557415485382, 40.17256535589695, 40.48537977039814, 39.98577117919922, 38.605309054255486, 38.80577489733696, 39.53001603484154, 43.51714588701725, 40.232176557183266, 42.40197792649269, 47.31381855905056, 43.933405950665474, 45.048053339123726, 38.58270026743412, 39.34204012155533, 39.87081214785576, 39.44247253239155, 40.9169340133667, 42.535282373428345, 40.915292501449585, 41.11160136759281, 40.38448378443718, 40.08667476475239, 38.84350307285786, 42.77613624930382, 40.54081119596958, 47.2232998162508, 50.612706542015076, 51.27408765256405, 42.760184705257416, 38.82444329559803, 37.42249712347984, 38.64396058022976, 39.3839480727911, 38.13303239643574, 40.594753101468086, 38.224896267056465, 38.62860180437565, 38.623540475964546, 38.72556500136852, 39.860750287771225, 40.698673725128174, 39.463265016674995, 40.2623051404953, 43.205801993608475, 46.08146108686924, 43.44926252961159, 46.95954456925392, 52.94660970568657, 53.00103038549423, 54.25492510199547, 53.11191223561764, 52.99566127359867, 49.34061460196972, 51.70557349920273, 50.31540289521217, 51.10611766576767, 53.04675713181496, 59.08717520534992, 55.792915374040604, 58.7541838735342, 57.82227247953415, 59.291585236787796, 54.50565844774246, 47.77589276432991, 44.00438234210014, 48.4402871131897, 52.025493532419205, 58.875104784965515, 60.68799130618572, 64.90630075335503, 61.35937348008156, 65.16604721546173, 71.09375193715096, 67.09670841693878, 67.98838376998901, 61.727246940135956, 1.3987659802660346, 0.4326257260981947, 2.2082785796374083, 0.27984117914456874, 0.14050115685677156, 40.681437849998474, 78.79656940698624, 64.95084196329117, 69.94112938642502, 74.51429039239883, 70.92612013220787, 50.06995886564255, 35.969200506806374, 39.31169115006924, 67.977394759655, 44.023350924253464, 1.0058588697575033, 0.01868307423137594, 0.07775329810101539, 0.09182617694023065, 0.03643910211394541, 0.06294467631960288, 0.2255922619951889, 0.1341197852161713, 0.17235070641618222, 0.28085035155527294, 0.31390546064358205, 0.23825524578569457, 0.47987509227823466, 0.7045197207480669, 31.31693534553051, 86.02695062756538, 55.90810239315033, 43.412765488028526, 25.01748327165842, 44.865552932024, 66.15314304828644, 68.44081789255142, 79.09362226724625, 62.80280202627182, 82.15365126729012, 21.58644787967205, 0.6796507083345205, 3.010797891765833, 8.057072460651398, 0.45357210212387145, 4.299374297261238, 70.03129854798317, 65.84411323070526, 70.1387719810009, 61.71428203582764, 64.59455028176308, 58.763850554823875, 61.921766102313995, 57.53391355276108, 61.87422305345535, 61.252515614032745, 60.033928602933884, 53.61191600561142, 56.210091188549995, 43.82031261920929, 47.83214494585991, 45.5722314119339, 47.71008409559727, 47.58319370448589, 52.66229376196861, 53.320346251130104, 57.54129275679588, 55.00138744711876, 54.10961329936981, 53.76711867749691, 55.88790647685528, 56.081445291638374, 60.017851665616035, 58.35625782608986, 56.859103962779045, 55.34812644124031, 56.93876288831234, 51.210053488612175, 45.275843515992165, 47.084101885557175, 43.91598008573055, 41.832339093089104, 42.98708952963352, 42.88552097976208, 40.21667338907719, 38.03036190569401, 41.95546768605709, 44.52849581837654, 47.36716389656067, 47.84428529441357, 47.500350549817085, 44.76031377911568, 44.07493315637112, 46.34586989879608, 51.97467885911465, 52.092989310622215, 51.4104775339365, 49.29810628294945, 41.944889053702354, 39.54317852854729, 40.64790464937687, 40.949885845184326, 39.19782266020775, 38.884442076087, 41.59116603434086, 44.45527374744415, 40.86129739880562, 44.15777251124382, 48.71845118701458, 48.10218885540962, 45.026022121310234, 36.55155725777149, 37.943817749619484, 38.678694516420364, 39.329029619693756, 41.60084791481495, 43.368064686656, 41.0427338629961, 42.62628749012947, 41.19466491043568, 39.57043446600437, 40.111213847994804, 44.889119267463684, 41.69732093811035, 50.48711188137531, 52.43403621017933, 54.28454831242561, 44.56788070499897, 41.590561866760254, 38.80106694996357, 41.66274279356003, 42.12691828608513, 41.32711820304394, 42.50268392264843, 40.91145470738411, 40.00047259032726, 40.648235231637955, 39.50960732996464, 43.39634656906128, 43.72861973941326, 42.941978350281715, 42.45498888194561, 45.063282921910286, 48.01695562899113, 47.04859659075737, 48.684241622686386, 53.717120960354805, 55.74282266199589, 55.55798918008804, 54.8467243462801, 56.37841455638409, 51.11747905611992, 54.6591854095459, 52.31357507407665, 57.52961978316307, 55.87018042802811, 60.57182013988495, 58.01718682050705, 60.98487317562103, 60.262809321284294, 61.52490019798279, 58.31686533987522, 50.601557940244675, 47.45076321065426, 52.76447407901287, 54.14357207715511, 61.594493463635445, 62.51435570418835, 68.18867862224579, 63.333036974072456, 67.84692496061325, 70.82667946815491, 66.16337209939957, 69.2874276638031, 64.41395357251167, 2.878107111901045, 0.9723993495572358, 6.071415385231376, 2.3969940282404423, 0.3302284941310063, 45.325332060456276, 83.91487196087837, 71.26920372247696, 75.530074685812, 80.30391812324524, 76.63551896810532, 69.43154633045197, 48.02620053291321, 49.7292273491621, 76.8687504529953, 57.875796407461166, 1.3681891397573054, 0.383334860089235, 0.09186462761135772, 0.23153934365836903, 0.24768685922026634, 0.17638790071941912], [0.044390427792677656, 0.017318726640951354, 0.07694845378864557, 0.07168303476646543, 0.04944811968016438, 0.05420674089691602, 0.30736963322851807, 0.12809310079319403, 15.147220306098461, 65.87299168109894, 50.609773099422455, 28.267424181103706, 21.73421435058117, 33.81407015025616, 47.85062335431576, 49.9713883548975, 64.51591730117798, 55.304747968912125, 66.72136455774307, 23.479975573718548, 0.21927691181190312, 0.22341843723552302, 1.8749589216895401, 0.029316870422917418, 8.730520773679018, 70.88072776794434, 58.24902758002281, 62.816963866353035, 56.208119094371796, 62.860859110951424, 57.83754006028175, 62.032625153660774, 55.67175127565861, 58.80172312259674, 52.20561906695366, 50.742439180612564, 46.3296789675951, 44.139161109924316, 38.57214443385601, 39.85813222825527, 39.921129047870636, 42.36983545124531, 42.953039556741714, 47.44986265897751, 47.2885575145483, 48.89106832444668, 46.430088579654694, 47.9602512717247, 46.56904712319374, 47.434492483735085, 52.21297927200794, 49.706618562340736, 39.75445099174976, 51.78251937031746, 53.485189005732536, 51.607960537075996, 47.02142804861069, 46.380885019898415, 40.26082322001457, 38.805014938116074, 38.73681239783764, 38.97181838750839, 36.662556901574135, 35.41598819196224, 36.1819738894701, 39.90494191646576, 42.52878472208977, 41.742960289120674, 39.97052639722824, 37.195299714803696, 37.940466329455376, 39.92590919137001, 40.929929316043854, 43.96611839532852, 47.77867801487446, 46.96572303771973, 43.33969160914421, 41.025433391332626, 39.575480595231056, 38.215335980057716, 38.586906641721725, 39.13490183651447, 39.758611768484116, 41.887470334768295, 42.81824938952923, 41.362129524350166, 42.12549336254597, 46.5660984814167, 43.63142855465412, 43.098123371601105, 36.110032349824905, 38.716263100504875, 39.78599309921265, 40.08099406957626, 38.21935996413231, 40.20810104906559, 39.36340257525444, 39.176475405693054, 39.25457261502743, 40.67078322172165, 39.45267118513584, 42.146722823381424, 41.73522390425205, 45.86184427142143, 48.51971045136452, 43.669228926301, 39.9866983294487, 41.61174193024635, 40.13076759874821, 37.88982644677162, 36.15938790142536, 39.46486473083496, 37.68310993909836, 36.17530144751072, 36.49897187948227, 37.99421824514866, 37.29060620069504, 37.38238647580147, 37.79559150338173, 40.014854818582535, 39.32221658527851, 43.240661323070526, 41.969108954072, 45.997933968901634, 49.56575632095337, 54.26879055798054, 51.28638759255409, 54.54769179224968, 48.280881866812706, 41.755412220954895, 43.876511603593826, 49.86442409455776, 53.334751278162, 49.66126039624214, 44.62577819824219, 46.025752276182175, 52.24049359560013, 56.76948197185993, 56.28911554813385, 54.7710096091032, 55.53911179304123, 50.621864050626755, 43.45195658504963, 42.30574809014797, 41.75592519342899, 49.523023813962936, 57.927082255482674, 59.51519563794136, 60.397474095225334, 61.01965270936489, 58.81673611700535, 62.954208701848984, 59.364472925662994, 68.0723212659359, 3.5571575118228793, 0.2921235153917223, 1.99127531144768, 0.6761538272257894, 0.11851797826238908, 37.57270306348801, 70.4564881324768, 61.082041561603546, 66.14254161715508, 68.05864199995995, 60.74506804347038, 58.08424562215805, 37.3416792601347, 34.087986052036285, 64.11439284682274, 31.565329916775227, 0.8367219299543649, 0.11233919809455983, 0.07358584945905022, 0.02472799322276842, 0.06719709344906732, 0.07201642976724543, 0.06596791878109798, 0.03851637346087955, 0.09407278412254527, 0.07157546788221225, 0.09479588828980923, 0.07333622066653334, 0.21593839017441496, 0.21975924842990935, 20.568319112062454, 73.55730414390564, 55.28282314538956, 34.24506202340126, 23.646351546049118, 43.30269679427147, 52.38462746143341, 54.3058917671442, 71.08861461281776, 58.49950633943081, 73.96276518702507, 24.308542013168335, 0.1660356976208277, 0.49161862931214273, 2.97325543127954, 0.03174581957864575, 8.836909364908934, 75.58492094278336, 60.681801438331604, 66.2003593146801, 58.14127296209335, 66.2379240989685, 60.66907972097397, 64.27238076925278, 59.17381435632706, 61.56784929335117, 54.414634332060814, 52.59341485798359, 47.68423788249493, 46.42311595380306, 39.42949242889881, 44.31701056659222, 41.41057692468166, 44.57600086927414, 44.75591741502285, 48.93235310912132, 51.26003980636597, 50.768046006560326, 48.7426482886076, 49.171405881643295, 47.69605904817581, 50.10356806218624, 52.90396839380264, 50.17903581261635, 44.69113849103451, 54.98308002948761, 54.34577442705631, 54.40468266606331, 49.88472640514374, 48.10672201216221, 43.26402246952057, 41.35146349668503, 39.52156908810139, 39.44107040762901, 38.14038500189781, 38.185845762491226, 37.834991589188576, 42.405796721577644, 44.38720420002937, 47.055185437202454, 41.796453818678856, 39.80392053723335, 40.044945403933525, 41.317417323589325, 41.511765494942665, 45.90672366321087, 49.66237373650074, 50.910530760884285, 49.43750560283661, 42.92028531432152, 40.50728939473629, 37.95028880238533, 39.53542694449425, 39.367008581757545, 40.130045637488365, 42.145522087812424, 43.72302643954754, 39.90304581820965, 42.12559595704079, 48.46114419400692, 44.87568698823452, 43.347652181982994, 36.86173841357231, 39.350707456469536, 39.42876286804676, 40.23086942732334, 39.982252568006516, 40.900336503982544, 38.55276547372341, 40.359165742993355, 40.914984717965126, 41.1690428853035, 39.440196454524994, 43.2837738096714, 44.11378227174282, 49.16898161172867, 49.51442487537861, 47.86668889224529, 42.90474034845829, 43.36456127464771, 42.09423243999481, 39.85503539443016, 37.47228965163231, 41.97239197790623, 38.71172234416008, 37.77211256325245, 37.97268100082874, 39.90254044532776, 38.72835025191307, 40.13968572020531, 39.36759755015373, 42.49261446297169, 39.9662022292614, 43.98938074707985, 42.7535654604435, 48.253595530986786, 52.018916085362434, 55.20142391324043, 53.79643030464649, 57.87021450698376, 48.46647150814533, 43.36705394089222, 45.3324718773365, 50.91624565422535, 52.52166710793972, 53.69673125445843, 48.68842899799347, 49.40898433327675, 53.483266308903694, 57.61407405138016, 58.45315642654896, 57.97564744949341, 59.46134492754936, 52.960266172885895, 45.9263002127409, 44.55527298152447, 43.62908788025379, 52.57484905421734, 59.59467597305775, 62.94345907866955, 62.475286200642586, 66.24300822615623, 59.82712849974632, 69.05130073428154, 61.716740503907204, 76.31712645292282, 6.752723101526499, 0.2777456509647891, 2.664640503935516, 0.9555249894037843, 0.09876567331957631, 39.680928736925125, 78.58330965042114, 65.6653556227684, 69.26006153225899, 73.11458230018616, 66.38620734214783, 66.06279149651527, 38.74411940574646, 41.08808442950249, 72.65328705310822, 40.22387020289898, 0.9649319190066308, 0.04421544792421628, 0.05177287130209152, 0.021474163622769993, 0.01527194086520467, 0.01027897445965209, 0.18904954864410684, 0.1133235456654802, 0.20037803216837347, 0.19070450827712193, 0.15292781114112586, 0.186026647570543, 0.5530616885516793, 0.5636217375285923, 24.706097580492496, 84.81929183006287, 64.89621609449387, 42.610392943024635, 30.624046325683594, 48.34696792066097, 59.93999384343624, 61.06697157025337, 76.70820906758308, 63.98722127079964, 81.0632161796093, 27.545364126563072, 0.2950138837331906, 2.025755373761058, 6.5485909301787615, 0.16747994668548927, 10.49394154921174, 77.56926566362381, 62.673320174217224, 68.20239588618279, 60.67940756678581, 69.05293464660645, 62.739539220929146, 66.45011231303215, 60.46611361205578, 63.30661699175835, 56.34751461446285, 55.91385908424854, 50.59966564178467, 49.74616304039955, 40.84971562027931, 45.08197411894798, 43.984034433960915, 48.48164789378643, 48.67962867021561, 51.72768451273441, 52.16913342475891, 53.05188685655594, 51.417127177119255, 51.90556816756725, 50.975454077124596, 50.89664250612259, 56.56648546457291, 53.36281657218933, 48.80137413740158, 57.43191942572594, 56.19398005306721, 55.01255124807358, 50.92877738177776, 52.53447622060776, 43.047958463430405, 43.05486649274826, 42.8765382617712, 43.184200152754784, 40.59534966945648, 40.86521118879318, 40.09545609354973, 45.004070699214935, 45.33921271562576, 48.696229979395866, 43.93190123140812, 42.07822009921074, 42.64155127108097, 42.64762334525585, 44.68466363847256, 48.27127978205681, 51.77428141236305, 53.744038715958595, 51.980310156941414, 44.25719417631626, 41.44066371023655, 37.90529541671276, 39.70858745276928, 40.936138182878494, 41.28928743302822, 42.43795059621334, 43.26711170375347, 40.5174158513546, 42.824918031692505, 51.164167150855064, 47.332353964447975, 45.01423515379429, 34.93186756968498, 40.19770100712776, 39.19037885963917, 40.11099345982075, 39.24959868192673, 40.546875670552254, 37.89690546691418, 41.02390967309475, 40.76777681708336, 41.055976152420044, 39.88365165889263, 44.1990876942873, 45.21113678812981, 52.672313824296, 53.73215675354004, 52.88297452032566, 46.40317462384701, 47.862505316734314, 46.20502285659313, 42.54434108734131, 38.99708703160286, 45.08796639740467, 41.42683245241642, 40.1557170599699, 40.50956167280674, 41.54407896101475, 39.51030269265175, 41.20035320520401, 41.26775398850441, 44.93506260216236, 42.59153455495834, 47.352428287267685, 43.46716716885567, 50.21318078041077, 55.201169326901436, 57.79102675616741, 54.23510916531086, 59.09445561468601, 51.477779522538185, 46.368854865431786, 49.406408071517944, 53.02832432091236, 54.161495715379715, 54.607215598225594, 52.58012317121029, 52.348734587430954, 55.961462929844856, 59.97266449034214, 60.67111261188984, 59.9041123688221, 62.43435859680176, 55.0481553375721, 48.624136447906494, 46.706717535853386, 46.46732658147812, 53.75561289489269, 63.22595871984959, 65.62040403485298, 65.33862635493279, 68.40614855289459, 62.36636124551296, 70.6349341571331, 63.78177389502525, 76.91269129514694, 10.804189201444387, 0.34489995217882097, 5.015307180583477, 4.025512067601085, 0.3542660636594519, 44.173203483223915, 84.78954702615738, 69.9579168856144, 78.48895311355591, 77.04317629337311, 75.78620374202728, 75.61583608388901, 48.99730682373047, 53.60734865069389, 80.83427086472511, 53.043994680047035, 1.7287824279628694, 0.2514189714565873, 0.2144330771989189, 0.1124084998446051, 0.17600547202164307, 0.3273983584949747], [0.05261929072730709, 0.04655712422390934, 0.03144548354612198, 0.02311331179953413, 0.04355619072157424, 0.08388133021071553, 0.15786646254127845, 0.04221058792609256, 7.844028817489743, 62.46905833482742, 48.057480454444885, 26.23607598245144, 22.421255484223366, 40.09978026151657, 49.51134704053402, 51.615590527653694, 60.34570187330246, 56.00053243339062, 60.45034445822239, 38.58809597790241, 0.07562452170532197, 0.18171937088482082, 2.644444825127721, 0.08349542826181278, 13.388540726155043, 71.1880324780941, 57.86101520061493, 57.80958876013756, 48.43179076910019, 55.79326115548611, 55.08232690393925, 57.372973188757896, 53.9476203918457, 53.5209184885025, 46.548771411180496, 47.06664562225342, 39.672508388757706, 41.3713326305151, 38.75695891678333, 40.444258376955986, 40.168548971414566, 41.865036338567734, 42.90670484304428, 46.608204022049904, 44.46948118507862, 47.55980595946312, 43.94906871020794, 40.97779154777527, 40.37057273089886, 45.791418850421906, 47.23738566040993, 51.57184727489948, 50.84522746503353, 44.000156968832016, 44.678496569395065, 47.12224803864956, 44.12300817668438, 45.97444362938404, 40.9788478910923, 40.17168380320072, 38.586237877607346, 38.51145029067993, 36.66186913847923, 38.455293104052544, 37.8996717184782, 38.06023210287094, 36.54560297727585, 36.85313567519188, 38.18751007318497, 38.51775035262108, 37.21702314913273, 37.56842069327831, 38.595919758081436, 41.30269691348076, 48.21536958217621, 49.36875209212303, 51.75667695701122, 39.61849048733711, 39.24836754798889, 40.05985200405121, 39.354856833815575, 38.875136375427246, 38.47468726336956, 39.98630315065384, 39.827650263905525, 43.01341071724892, 39.94921334087849, 44.91158366203308, 44.286627396941185, 43.141479045152664, 37.78889626264572, 39.74793814122677, 39.454859867691994, 40.80877281725407, 40.06309702992439, 38.28600078821182, 38.10741037130356, 40.37835091352463, 40.62582403421402, 41.66932784020901, 40.894310027360916, 40.854503363370895, 41.33105479180813, 45.824587270617485, 42.341405376791954, 43.83729390799999, 43.93852807581425, 40.439865812659264, 37.51230530440807, 37.67209053039551, 37.302719950675964, 36.3274110853672, 38.74937832355499, 36.52857229113579, 36.52374655008316, 38.11963431537151, 36.58032551407814, 36.71103850007057, 39.45766031742096, 41.52128018438816, 40.64462162554264, 42.042536213994026, 45.11815197765827, 49.46885012090206, 51.18013009428978, 51.9074110686779, 51.5166362375021, 49.73262056708336, 48.47889304161072, 49.335397481918335, 47.951568737626076, 49.92698013782501, 46.45036429166794, 53.76349367201328, 55.59371866285801, 51.891128942370415, 49.1628335416317, 55.46075239777565, 54.739368706941605, 57.35142074525356, 54.42801721394062, 51.230952367186546, 44.93815563619137, 44.570327773690224, 43.58572460711002, 49.61699657142162, 55.21857999265194, 60.5704902112484, 56.56453616917133, 63.00411522388458, 56.011445447802544, 59.94730845093727, 58.97766888141632, 69.86590102314949, 8.454467486590147, 0.2991889097029343, 1.0678797354921699, 0.5668918183073401, 0.0855335290543735, 42.638545632362366, 68.19551825523376, 63.33766892552376, 65.68993270397186, 67.9160812497139, 56.018357276916504, 32.53544636070728, 25.508354231715202, 34.26982909440994, 65.52511274814606, 28.598475717008114, 0.5060021043755114, 0.05027185907238163, 0.04798436326382216, 0.040745109727140516, 0.10317098771338351, 0.050690211428445764, 0.12248949991771951, 0.07685099495574832, 0.058860581993940286, 0.017398910131305456, 0.01426672874003998, 0.06815639353590086, 0.34006008063443005, 0.19492222258122638, 10.902676116675138, 72.59617611765862, 54.312427416443825, 34.55197915434837, 27.09289200603962, 45.87126016616821, 53.096131682395935, 52.7571214735508, 68.286272585392, 59.99212324619293, 67.15467810630798, 40.470112189650536, 0.1742875634226948, 0.36675231240224093, 2.472594534046948, 0.0991912950121332, 14.27969740703702, 74.98172610998154, 60.71123465895653, 60.0109626352787, 51.56333193182945, 59.67511385679245, 57.361702993512154, 61.386975198984146, 56.065942123532295, 56.121749728918076, 49.123042076826096, 48.03548723459244, 41.71767644584179, 44.087563678622246, 41.552746295928955, 44.390962198376656, 41.40459984540939, 43.798733577132225, 45.40504798293114, 47.524703443050385, 46.18857353925705, 49.94736984372139, 46.53303265571594, 43.40577386319637, 41.36342905461788, 47.27877303957939, 48.95913027226925, 52.90242187678814, 50.403436571359634, 47.598518282175064, 48.54912847280502, 48.68008464574814, 46.915744319558144, 47.13003382086754, 42.61509329080582, 41.585546135902405, 40.147254914045334, 39.86866906285286, 36.70758068561554, 38.66187661886215, 39.511465430259705, 42.444607838988304, 39.40344102680683, 36.8936301022768, 39.70411129295826, 40.08670516312122, 40.57659387588501, 40.1324737071991, 40.103428065776825, 42.252429351210594, 49.94688346982002, 51.03998601436615, 54.02905002236366, 41.39437459409237, 38.860773146152496, 39.800124540925026, 40.588920414447784, 38.66289496421814, 36.708922013640404, 39.19963136315346, 40.0777642428875, 41.124045699834824, 39.79751028120518, 48.32821972668171, 46.50610730051994, 42.46131174266338, 37.60445415973663, 40.41944570839405, 39.72715325653553, 41.076179668307304, 38.768065720796585, 38.30015882849693, 38.13905507326126, 39.87117312848568, 40.53755857050419, 41.33131317794323, 41.41814611852169, 41.80852957069874, 42.12036743760109, 50.17028868198395, 45.14259986579418, 47.22266525030136, 45.9533129632473, 40.44301964342594, 39.50260430574417, 39.09029223024845, 39.671205058693886, 39.30401936173439, 40.06450675427914, 38.84047083556652, 37.77990594506264, 40.02952203154564, 38.09566140174866, 38.67270603775978, 40.520489886403084, 42.349954918026924, 41.73501871526241, 43.74770991504192, 46.69279508292675, 52.008934020996094, 54.440719932317734, 56.51936039328575, 50.6307327747345, 52.78183534741402, 49.228551015257835, 52.08599008619785, 49.462850242853165, 51.648390367627144, 46.281360760331154, 53.182071670889854, 55.65672308206558, 54.9620595574379, 51.30020745098591, 55.54398313164711, 56.714483723044395, 59.44793164730072, 58.82726915180683, 53.662555888295174, 47.475739270448685, 47.598845064640045, 44.87322472035885, 52.40265749394894, 57.843346148729324, 63.81892830133438, 58.36727723479271, 65.37495240569115, 58.26185569167137, 64.89009842276573, 60.98440200090408, 76.61521285772324, 12.5784925930202, 0.23490041174227372, 1.6591335902921855, 0.29377785162068903, 0.11668059130897745, 45.14627426862717, 76.56481996178627, 69.1834956407547, 71.41153648495674, 73.54951456189156, 65.1485225558281, 41.866556257009506, 26.802646480500698, 41.04216769337654, 73.04651275277138, 36.60108380019665, 0.6260070868302137, 0.07424865412758663, 0.11566064291400835, 0.0720680461381562, 0.048170664595090784, 0.027338594154571183, 0.23181058379122987, 0.1686932987649925, 0.10906461247941479, 0.11348901491146535, 0.2729948965134099, 0.36311216710601, 0.6962789129465818, 0.4343335860176012, 14.184526763856411, 80.76765283942223, 61.87043845653534, 39.842374473810196, 31.109789460897446, 53.67928259074688, 64.06480550765991, 60.984060019254684, 73.48551839590073, 63.68340477347374, 73.11583623290062, 45.683637633919716, 0.38869230542331934, 1.473389700986445, 6.300455695018172, 0.12138143632910214, 15.821909252554178, 78.57973024249077, 61.84809945523739, 63.356565311551094, 53.69248688220978, 62.36225746572018, 59.81899693608284, 62.82351851463318, 58.33395682275295, 59.95825566351414, 51.012300699949265, 50.0961584597826, 43.57015684247017, 46.413745656609535, 44.133191630244255, 47.04105779528618, 43.966935351490974, 46.59923270344734, 48.52495796978474, 52.34857499599457, 47.953609228134155, 52.1589195728302, 47.56414532661438, 45.781307592988014, 43.74979220330715, 49.69144217669964, 52.28315390646458, 56.364556699991226, 52.68540792167187, 50.73477879166603, 51.85256481170654, 50.06289504468441, 49.39946964383125, 49.37827058136463, 43.99381510913372, 44.33284051716328, 42.11752139031887, 43.35867919027805, 39.06715527176857, 41.58759042620659, 43.00103858113289, 43.81904348731041, 40.3906774520874, 39.62121494114399, 43.57399843633175, 44.08293552696705, 42.8742241859436, 42.95153483748436, 41.519140899181366, 44.415022507309914, 51.934321224689484, 56.499700248241425, 57.760252207517624, 41.68686769902706, 38.332970067858696, 41.754306480288506, 39.44398105144501, 39.32257376611233, 37.21567042171955, 39.65944088995457, 39.74752016365528, 42.44437225162983, 41.77347645163536, 50.38721904158592, 50.025125071406364, 42.93016478419304, 38.7992924451828, 38.93024101853371, 39.83608581125736, 41.39160834252834, 38.97746868431568, 37.657107934355736, 37.00533650815487, 40.29434122145176, 40.823573023080826, 41.271789371967316, 42.70243160426617, 41.4347930252552, 45.97690969705582, 51.7387343198061, 49.940788596868515, 48.466912284493446, 49.18584130704403, 43.530046194791794, 42.432851269841194, 40.794930160045624, 40.99686272442341, 41.33439481258392, 43.08668978512287, 41.3588161021471, 39.08029496669769, 42.65172332525253, 40.01310311257839, 39.95132602751255, 43.45005288720131, 44.8760099709034, 44.6396778523922, 46.089877635240555, 49.66816842556, 55.2090273052454, 57.781683057546616, 59.63070183992386, 52.98127144575119, 54.12316717207432, 52.408015206456184, 55.0204586237669, 50.854954943060875, 53.3743679523468, 49.06448721885681, 53.56735199689865, 54.915804639458656, 57.37903766334057, 56.29570059478283, 57.98974849283695, 60.283905789256096, 61.674783155322075, 59.8938225209713, 57.11789667606354, 49.88239333033562, 48.60489048063755, 47.42107540369034, 55.607116743922234, 60.9788428992033, 66.58852368593216, 59.38039407134056, 68.10857132077217, 61.83177933096886, 68.02305310964584, 64.68446105718613, 77.41408959031105, 18.92019934952259, 0.3184912505093962, 4.16709104552865, 1.5559339779429138, 0.20441111497348174, 51.345447823405266, 81.4815129339695, 75.42944848537445, 75.81033244729042, 80.00703245401382, 71.97882324457169, 48.46569634974003, 37.56039172410965, 50.163468047976494, 83.28640848398209, 48.879307955503464, 0.7501916075125337, 0.2225336487754248, 0.2310364495497197, 0.15863482287386432, 0.19240188907133415, 0.16370955447200686], [0.09130058795562945, 0.05364546203054488, 0.0706488371361047, 0.07208113020169549, 0.07201080428785644, 0.06619483785470948, 0.160355388361495, 0.0540827614167938, 5.290356371551752, 61.51150971651077, 49.713177010416985, 35.766868963837624, 29.306750111281872, 37.02539563179016, 50.59842310845852, 58.934229612350464, 54.45820279419422, 57.84202381968498, 54.73638966679573, 48.73798593878746, 0.6155115156434476, 0.5558788811322302, 1.7229094868525863, 0.061020740104140714, 10.716575402766466, 67.52138122916222, 62.15323828160763, 58.468940779566765, 45.52581690251827, 47.69778415560722, 47.846709564328194, 50.70248432457447, 48.375542387366295, 46.38959415256977, 41.562728360295296, 40.075165182352066, 39.75732363760471, 40.27253799140453, 39.06852699816227, 41.43141880631447, 40.465548634529114, 40.83759427070618, 40.92351906001568, 43.126576244831085, 42.78250090777874, 43.781170919537544, 41.76434174180031, 38.19103628396988, 40.364337265491486, 42.959351018071175, 43.51696349680424, 46.56989447772503, 47.653144150972366, 49.10319574177265, 49.374079406261444, 48.882944360375404, 45.807222202420235, 42.971229180693626, 39.95021648705006, 40.95772102475166, 40.05348354578018, 38.00435610115528, 38.73776234686375, 37.62525424361229, 36.738009452819824, 35.170927941799164, 36.45397089421749, 38.92906308174133, 38.09231378138065, 39.774715304374695, 37.920236214995384, 37.65427328646183, 38.56846623122692, 42.63640634715557, 47.6253904402256, 47.592465206980705, 51.507835909724236, 44.31723475456238, 37.25470192730427, 39.866100400686264, 39.72423501312733, 37.254861518740654, 37.61079601943493, 38.00201162695885, 39.82312470674515, 39.341359958052635, 40.69499172270298, 45.7254695892334, 47.593768537044525, 42.71558649837971, 38.80008280277252, 37.555850967764854, 39.358998611569405, 39.24149751663208, 39.58584263920784, 38.79687577486038, 39.10607658326626, 39.11990404129028, 41.564913243055344, 40.54329626262188, 41.00507788360119, 43.60692746937275, 41.83641627430916, 41.85648299753666, 42.627731412649155, 44.10560891032219, 40.48513278365135, 42.716141268610954, 37.47186787426472, 36.398440673947334, 37.47844912111759, 35.465066358447075, 33.46220523118973, 37.74337090551853, 34.81155842542648, 38.175441920757294, 37.23095700144768, 38.480599746108055, 37.520315274596214, 39.50329206883907, 41.65282912552357, 43.3637785166502, 44.02048967778683, 50.54171495139599, 52.42229864001274, 51.7875275015831, 49.43290784955025, 49.995190277695656, 50.425277799367905, 50.779878571629524, 53.854153007268906, 54.47519548237324, 51.04277886450291, 50.07176756858826, 50.21232582628727, 60.596556812524796, 58.88653077185154, 53.92516739666462, 53.08330737054348, 53.372114673256874, 50.64730368554592, 49.35367830097675, 42.500286251306534, 44.01756763458252, 42.58399195969105, 46.833064556121826, 49.33310620486736, 55.04027456045151, 53.493787944316864, 53.319901674985886, 47.58352428674698, 62.27020360529423, 57.522438168525696, 70.65406993031502, 6.682018870487809, 0.39639078138861805, 1.2198174325749278, 0.8415286720264703, 0.5228851328138262, 45.28304032981396, 69.65425997972488, 60.652911588549614, 64.85636383295059, 66.3011147081852, 54.77630652487278, 35.88045246899128, 35.66001869738102, 37.708754763007164, 64.4631153345108, 21.996793560683727, 0.6507423345465213, 0.06149639368231874, 0.10595555548206903, 0.056794520787661895, 0.040917621954577044, 0.06172504567075521, 0.06833770763478242, 0.10709766880609095, 0.05264575571345631, 0.06145510800706688, 0.07430594792822376, 0.037485018256120384, 0.13268044916912913, 0.17372329370118678, 7.303217612206936, 72.52283245325089, 54.167970567941666, 35.55420197546482, 16.69649977236986, 43.54198895394802, 59.03115101158619, 61.58947013318539, 60.34808434545994, 64.87911701202393, 61.66690997779369, 53.375348299741745, 0.5593496980145574, 0.5910837545525283, 2.5484959362074733, 0.06086105218855664, 12.007418386638165, 70.29488280415535, 63.272228837013245, 59.970935583114624, 46.95990175008774, 49.344813376665115, 49.22279052436352, 55.42390577495098, 49.44797404110432, 47.82174110412598, 44.25366796553135, 42.28508099913597, 42.50841401517391, 42.76798948645592, 41.80388621985912, 43.577338457107544, 42.71190069615841, 43.64896081387997, 42.971263378858566, 46.28323405981064, 44.91189904510975, 47.67524376511574, 42.58112691342831, 40.98203971982002, 42.181745544075966, 45.67694619297981, 46.326209753751755, 48.24919156730175, 48.365320935845375, 52.46472716331482, 50.60113236308098, 50.42128041386604, 48.32875169813633, 45.11120215058327, 42.6636166870594, 42.246171087026596, 39.7835536301136, 40.58749169111252, 38.86040076613426, 39.42787751555443, 40.66579408943653, 36.40287883579731, 38.40793624520302, 40.57906374335289, 40.42435884475708, 41.4856380969286, 38.87876518070698, 39.22045424580574, 41.16493530571461, 43.01701672375202, 48.473976105451584, 51.34563401341438, 53.42346511781216, 46.91850297152996, 38.45198728144169, 41.25207602977753, 39.43422697484493, 38.79790551960468, 38.08519296348095, 39.05135191977024, 40.078938379883766, 42.129787132143974, 39.70201760530472, 49.04601640999317, 50.22907912731171, 42.88796424865723, 38.02233673632145, 38.06155823171139, 39.48649697005749, 39.360472932457924, 39.03714448213577, 39.72114197909832, 38.31364430487156, 39.112650230526924, 40.78195005655289, 41.96419581770897, 40.4276342689991, 41.892820447683334, 44.62263956665993, 44.31063070893288, 46.81204788386822, 45.47202318906784, 40.3213007748127, 43.78261864185333, 38.6789833009243, 36.91519774496555, 39.0874195843935, 37.127606347203255, 36.71417713165283, 40.67250452935696, 37.7753309905529, 38.98403853178024, 39.370413199067116, 39.444733411073685, 39.359967559576035, 41.490729823708534, 42.656070291996, 44.565741419792175, 47.61028245091438, 51.17117017507553, 54.86663527786732, 54.39810521900654, 52.64150507748127, 51.02188378572464, 52.61392995715141, 52.7679318934679, 55.22762730717659, 57.186984568834305, 53.249309062957764, 54.096306413412094, 49.67191122472286, 57.61116720736027, 61.66925445199013, 56.07956059277058, 55.415428429841995, 57.14425966143608, 53.33024092018604, 51.323006227612495, 45.40797762572765, 47.32236810028553, 45.19894324243069, 49.476134330034256, 53.192980885505676, 59.263371750712395, 55.42421355843544, 55.925228074193, 50.77423967421055, 67.67312228679657, 59.6346840262413, 77.0291094481945, 12.128240503370762, 0.31085271039046347, 1.9030091352760792, 0.7857955782674253, 0.5565817840397358, 49.418662413954735, 77.23065063357353, 64.58154737949371, 72.951350659132, 70.44183611869812, 64.7082781791687, 46.61750592291355, 38.8323924690485, 47.19763979315758, 74.22846972942352, 30.592680908739567, 0.5813153693452477, 0.04637831858417485, 0.10496599803445861, 0.06639854997047223, 0.11268874222878367, 0.03939805974368937, 0.27213703317102045, 0.21734358742833138, 0.16416098806075752, 0.22263213177211583, 0.1417006753035821, 0.19861819222569466, 0.3213641932234168, 0.325705727445893, 8.227357473224401, 81.71763226389885, 64.94568943977356, 48.95483650267124, 37.63064615428448, 49.661879763007164, 65.28451725840569, 68.85925143957138, 67.73328825831413, 68.29368218779564, 68.18695351481438, 57.5883874297142, 1.0884146648459136, 1.5306977508589625, 5.204168921336532, 0.1428880522144027, 12.640116736292839, 74.72097650170326, 64.42823320627213, 62.08372861146927, 48.229079246520996, 52.00643755495548, 50.585762187838554, 56.74925185739994, 51.97032809257507, 50.082604587078094, 46.040020510554314, 43.99250037968159, 45.18032804131508, 46.03882737457752, 42.99894489347935, 46.88673287630081, 45.91624595224857, 47.5978647172451, 45.628943368792534, 48.33538234233856, 47.58621834218502, 49.97304506599903, 45.28091624379158, 43.06552492082119, 44.28671099245548, 49.087342992424965, 48.75563979148865, 51.21641434729099, 49.666580110788345, 52.30920530855656, 54.198558926582336, 52.84472577273846, 49.84271965920925, 47.31273181736469, 44.55897778272629, 45.99510692059994, 43.935294449329376, 41.78140662610531, 41.76509790122509, 40.817630141973495, 42.67389513552189, 39.06439661979675, 41.730800941586494, 43.68806071579456, 42.829454988241196, 44.85259182751179, 40.76968431472778, 40.7891620695591, 42.62705884873867, 46.66105918586254, 51.979307010769844, 53.179560005664825, 55.26070453226566, 49.51416648924351, 38.94360490143299, 40.625561848282814, 41.088692396879196, 39.418906196951866, 38.173454627394676, 40.08372612297535, 41.53860725462437, 40.08547782897949, 41.61442078649998, 49.14880469441414, 52.26381674408913, 44.307172894477844, 39.90078493952751, 38.6308778822422, 39.910478219389915, 39.48134824633598, 40.07521837949753, 39.36657540500164, 40.10384984314442, 39.64961841702461, 41.18374049663544, 40.605943500995636, 41.09886445105076, 45.7081463187933, 46.42425589263439, 48.53029288351536, 48.64980787038803, 47.77935437858105, 43.62323999404907, 45.51687978208065, 43.36098946630955, 37.72333078086376, 41.944759860634804, 39.16506081819534, 37.34368935227394, 43.25823538005352, 40.99192678928375, 39.589612036943436, 41.49520218372345, 43.64668853580952, 41.67279705405235, 43.256130293011665, 45.157882645726204, 46.02702900767326, 48.70546728372574, 55.385603830218315, 57.24891744554043, 55.726399943232536, 55.40924996137619, 52.33513131737709, 53.92837442457676, 53.894712030887604, 60.20065985620022, 59.23078469932079, 55.86105711758137, 56.28645949065685, 51.97860024869442, 59.52530689537525, 62.69841022789478, 58.535106629133224, 58.948456048965454, 59.04060870409012, 54.250103160738945, 53.781956881284714, 47.98662945628166, 50.266868099570274, 47.224546149373055, 51.90944775938988, 54.669129475951195, 60.453642681241035, 56.81548610329628, 56.945499926805496, 53.875933438539505, 70.69167271256447, 62.40793101489544, 79.50637891888618, 19.08229675143957, 0.2627288567600772, 5.0125827267766, 2.093858406879008, 0.7231397903524339, 53.27161766588688, 82.57274597883224, 70.90783551335335, 78.50906163454056, 76.45907923579216, 71.2991689145565, 53.27213443815708, 47.83271111547947, 54.48295846581459, 84.90998536348343, 42.45923325419426, 1.051177375484258, 0.22612703876802698, 0.22391889709979296, 0.17174395616166294, 0.1658013867563568, 0.18646062584593892], [0.06269037941819988, 0.04497251647990197, 0.02180978135584155, 0.04858791857259348, 0.03892088476277422, 0.10159710771404207, 0.10106643501785584, 0.06843911469331942, 1.1796167772263288, 55.58502472937107, 58.557316437363625, 47.56173625588417, 43.81066873669624, 38.80005240440369, 48.865932673215866, 67.0222020149231, 54.604764729738235, 61.459460109472275, 52.42167167365551, 60.580434277653694, 2.9026148468255997, 0.5051119427662343, 0.48453423602040857, 0.1827410262194462, 4.96591268107295, 63.2941460609436, 62.954432889819145, 61.29817396402359, 50.71306295692921, 44.385061115026474, 43.428405448794365, 42.29012332856655, 42.31295630335808, 40.47911390662193, 40.090641751885414, 42.183029875159264, 39.24447275698185, 39.338753297924995, 39.514440670609474, 39.28350426256657, 38.09319153428078, 38.27614411711693, 40.15093691647053, 41.58766262233257, 40.69168969988823, 39.34657707810402, 37.81455248594284, 39.140400141477585, 37.83014304935932, 42.823854088783264, 42.0052108168602, 43.237454295158386, 44.50279399752617, 44.18533243238926, 43.385315760970116, 44.84450966119766, 42.04103909432888, 38.814989402890205, 40.45273572206497, 40.94102472066879, 41.79541267454624, 39.92232598364353, 37.464895248413086, 35.39283223450184, 36.58006712794304, 38.1715053319931, 38.32720197737217, 37.6153177767992, 36.88066519796848, 37.989662289619446, 38.587738797068596, 36.74804091453552, 36.77390232682228, 38.640141785144806, 46.89825765788555, 50.740288496017456, 51.367589235305786, 44.53744813799858, 35.67487969994545, 38.38495887815952, 36.96816310286522, 38.12777727842331, 36.51787966489792, 38.246866688132286, 39.06190015375614, 39.62096035480499, 38.4290175139904, 48.280889466404915, 48.003576546907425, 44.23989750444889, 38.021371588110924, 39.989377185702324, 37.40855187177658, 38.90933454036713, 39.28240232169628, 38.5451240837574, 37.60094314813614, 39.9857559800148, 39.01699036359787, 40.23797124624252, 40.58660253882408, 43.30564543604851, 41.84235155582428, 45.427599772810936, 43.61439406871796, 41.68980114161968, 38.14405560493469, 39.2673247307539, 39.80175085365772, 39.476769492030144, 40.105065777897835, 42.033386304974556, 36.82555295526981, 37.66176648437977, 35.20036116242409, 37.45158076286316, 35.926935374736786, 38.14866475760937, 37.852398455142975, 39.25221674144268, 40.39046846330166, 41.40339531004429, 42.92486786842346, 47.513220459222794, 50.52168242633343, 50.34433454275131, 52.70840808749199, 50.74487864971161, 51.7517714202404, 50.81575624644756, 47.401495054364204, 50.14894522726536, 53.35004925727844, 51.87707729637623, 51.21281214058399, 48.29380877315998, 51.2972018122673, 52.0834556221962, 47.792524471879005, 47.18457609415054, 44.61657889187336, 42.67007254064083, 42.80224084854126, 43.752634450793266, 42.5589133054018, 43.0759933590889, 45.41944921016693, 47.184139117598534, 46.90931886434555, 52.11802236735821, 50.66712722182274, 62.97911636531353, 55.66083446145058, 64.10060718655586, 2.1581224584951997, 0.7524274906609207, 0.635049354750663, 0.49429683247581124, 0.6955149164423347, 47.86527916789055, 67.38787159323692, 62.43621289730072, 64.74129840731621, 66.9618308544159, 50.04461422562599, 31.74463089555502, 32.07589901983738, 39.37313765287399, 61.99751503765583, 16.220178231596947, 0.6154216860886663, 0.019126500046695583, 0.04846642528718803, 0.06716577481711283, 0.08156793715897948, 0.061813071806682274, 0.046699026570422575, 0.07194766236352734, 0.08943648368585855, 0.03211564660887234, 0.03177663355018012, 0.019047285059059504, 0.08502014097757638, 0.04773517975991126, 2.2172261495143175, 64.05018389225006, 61.53035670518875, 52.2926913946867, 29.62887592613697, 38.35916206240654, 56.57372407615185, 70.55410489439964, 60.4918572306633, 65.08294567465782, 58.776317685842514, 65.4296238720417, 3.2227346068248153, 0.47072874556761235, 0.9214275784324855, 0.5356903269421309, 5.813626293092966, 65.30799999833107, 64.76234927773476, 62.86337837576866, 52.95911863446236, 46.515918374061584, 45.62631770968437, 45.25067746639252, 44.63536888360977, 43.03681746125221, 41.48829035460949, 43.96104946732521, 41.02254554629326, 41.648565754294395, 43.35028924047947, 42.061614990234375, 39.96825411915779, 40.18861189484596, 42.01503708958626, 44.6028958261013, 44.241907596588135, 41.86624087393284, 41.22460350394249, 40.98626509308815, 39.4509232789278, 42.8765344619751, 44.02008689939976, 46.38454042375088, 45.69262035191059, 46.90812572836876, 46.19581215083599, 46.74057751893997, 44.54246386885643, 41.476959362626076, 41.72851726412773, 43.732738718390465, 42.540032118558884, 40.574515387415886, 41.19533367455006, 38.26126791536808, 37.43584580719471, 38.65321688354015, 39.16378028690815, 38.67055915296078, 38.99468936026096, 40.536612421274185, 41.826327815651894, 38.303153067827225, 39.88484099507332, 41.91597640514374, 49.45182703435421, 52.984174489974976, 53.19213733077049, 46.65685661137104, 37.88712099194527, 38.8058926910162, 38.3626426756382, 38.03638078272343, 36.7681722342968, 38.44287157058716, 39.43095535039902, 40.43434850871563, 37.783052176237106, 49.62398439645767, 48.96671466529369, 44.808460995554924, 38.73785734176636, 39.526121243834496, 38.9001352339983, 38.59157659113407, 40.072402730584145, 39.670072719454765, 37.12414093315601, 39.88745905458927, 39.91000324487686, 40.60126215219498, 42.9193239659071, 43.665904104709625, 44.808460995554924, 48.42890292406082, 45.365644097328186, 44.47036653757095, 40.4192329198122, 41.7624494433403, 41.37261316180229, 41.71770304441452, 41.77247330546379, 43.26252914965153, 37.916892394423485, 39.6421480178833, 38.57974022626877, 38.48718859255314, 38.73584344983101, 40.60609549283981, 38.788679614663124, 40.97054533660412, 43.08595262467861, 43.88275846838951, 45.026288107037544, 47.97305278480053, 50.929225757718086, 52.584078758955, 54.92875434458256, 52.37790182232857, 52.949676141142845, 51.67718142271042, 50.531877279281616, 51.44716076552868, 54.02337312698364, 54.30909499526024, 54.271636605262756, 50.68769931793213, 51.39047160744667, 54.27058406174183, 51.52968093752861, 48.807997182011604, 45.381455048918724, 44.77635271847248, 43.824013620615005, 45.65474398434162, 44.822018668055534, 45.80600246787071, 46.786612048745155, 51.40134282410145, 49.10261057317257, 55.18759645521641, 52.941856160759926, 66.64476826786995, 58.22425290942192, 70.59186726808548, 6.6984577383846045, 0.884061036631465, 1.5657373331487179, 0.601889721583575, 0.7502644567284733, 52.19958499073982, 77.40104869008064, 68.17708924412727, 72.22241297364235, 72.16608479619026, 60.03207430243492, 34.58315648138523, 35.73835149407387, 45.79985439777374, 71.37446567416191, 24.59917701780796, 0.5642119527328759, 0.06623348890570924, 0.03511626840918325, 0.03659090471046511, 0.051297347599756904, 0.012188485179649433, 0.11222702989471145, 0.1610495339264162, 0.19150012027239427, 0.10455245108460076, 0.16116332000819966, 0.16905539261642843, 0.2682970423484221, 0.12908956763567403, 2.7231036918237805, 75.26668041944504, 71.689423173666, 65.13493448495865, 56.11090891063213, 54.11341309547424, 63.74950982630253, 75.95170766115189, 66.96344956755638, 69.82968136668205, 63.399673998355865, 71.47046372294426, 4.486566502600908, 1.1595004191622138, 3.614398827776313, 0.5046765692532063, 6.096234703436494, 69.03195977210999, 66.73352390527725, 65.84307968616486, 55.36686323583126, 49.402334690093994, 46.980162262916565, 45.86955785751343, 46.93742595613003, 45.38965500891209, 42.79537081718445, 46.75811357796192, 42.9568887501955, 44.41421315073967, 45.81229493021965, 44.22454632818699, 42.880288660526276, 42.95509144663811, 44.21447306871414, 48.00508126616478, 46.79875999689102, 43.5457469522953, 42.49856874346733, 44.951238334178925, 41.46893419325352, 47.48733624815941, 45.8487843722105, 47.866768687963486, 48.38846929371357, 50.783644169569016, 48.80911812186241, 49.34740863740444, 46.42788089811802, 43.60281988978386, 45.9207259118557, 44.65810686349869, 45.58591827750206, 43.205631002783775, 43.24838250875473, 39.04133565723896, 40.54848678410053, 41.27262532711029, 41.033397763967514, 40.86352027952671, 39.8717050999403, 42.77737118303776, 44.03512269258499, 41.534704864025116, 41.24338589608669, 43.39029349386692, 50.61437085270882, 55.59098660945892, 57.69234985113144, 48.82731534540653, 38.955999836325645, 38.62974934279919, 38.77066858112812, 37.72903807461262, 36.788869723677635, 38.29611584544182, 39.934960305690765, 39.77941185235977, 38.758171051740646, 50.73139697313309, 53.063966408371925, 44.601740688085556, 38.37667912244797, 40.877552926540375, 39.374828562140465, 38.316710740327835, 39.55703258514404, 39.444133043289185, 37.07606591284275, 40.65409071743488, 40.280916541814804, 39.695360362529755, 42.49017879366875, 45.18855080008507, 49.2211452126503, 53.84193666279316, 47.162746265530586, 46.35564677417278, 40.8923227339983, 43.03039960563183, 43.164110630750656, 44.408676847815514, 43.14137265086174, 45.66207759082317, 39.53828439116478, 42.41346850991249, 40.461505651474, 40.73778882622719, 40.21117888391018, 42.49423697590828, 40.64260013401508, 42.91541017591953, 45.33961169421673, 46.212820038199425, 49.21952649950981, 52.09715008735657, 55.02748064696789, 54.22193147242069, 58.70015077292919, 55.566299334168434, 53.75641845166683, 56.47785522043705, 51.456246078014374, 54.99720387160778, 57.527092918753624, 56.75274387001991, 56.797311678528786, 52.21670687198639, 53.59781116247177, 55.69346331059933, 54.82869811356068, 52.60701432824135, 49.89397510886192, 46.50489516556263, 46.80933102965355, 48.73237743973732, 46.57446563243866, 47.697210386395454, 49.580313339829445, 53.340036794543266, 51.493282690644264, 57.89612151682377, 56.22210994362831, 68.68971213698387, 61.093300357460976, 75.70864990353584, 14.264081194996834, 1.0172713198699057, 3.8355331867933273, 1.1785791954025626, 0.9318612841889262, 56.87762416899204, 83.77269878983498, 73.49838450551033, 77.78007075190544, 75.18928617238998, 67.85881832242012, 44.74828362464905, 44.84615497291088, 55.25363311171532, 82.87692725658417, 33.361598029732704, 0.6539184297434986, 0.21423719474114478, 0.19169223261997104, 0.16302213276503608, 0.12725465203402564, 0.23480452626245096], [0.07576049058116041, 0.0794335723912809, 0.060199524014024064, 0.03610643441788852, 0.05645569326588884, 0.04132230766117573, 0.026450017030583695, 0.14931237936252728, 0.8362940372899175, 49.59346443414688, 56.19144178926945, 40.580910444259644, 26.82284239679575, 32.16592758893967, 49.4550758600235, 70.68891406059265, 56.88622310757637, 58.2446464151144, 50.54900296032429, 62.869325056672096, 10.514864176511765, 0.5954051320441067, 0.7252606702968478, 0.49734388303477317, 1.059127973858267, 44.70739781856537, 70.85722222924232, 58.33899535238743, 58.15847463905811, 48.16684998571873, 45.844068825244904, 46.290776655077934, 44.199186488986015, 41.581738740205765, 41.23908832669258, 38.32004316151142, 39.704647064208984, 38.305280953645706, 39.04967620968819, 38.77873174846172, 38.0630249530077, 38.857881501317024, 39.04738113284111, 37.009079307317734, 39.52283062040806, 38.29002857208252, 39.67156983911991, 38.98045912384987, 40.26610113680363, 39.7978712618351, 41.25176824629307, 40.17411187291145, 38.31372410058975, 41.94721072912216, 40.69197088479996, 39.63672950863838, 41.449483036994934, 40.835603177547455, 41.44442930817604, 41.824416518211365, 38.88302095234394, 37.80064143240452, 38.649557679891586, 36.372191682457924, 39.23597641289234, 39.264509081840515, 38.92004616558552, 37.13970109820366, 35.886535942554474, 38.91331672668457, 37.139055132865906, 39.25991892814636, 37.71834924817085, 43.80520083010197, 50.670315250754356, 50.80148421227932, 51.03322237730026, 49.85228754580021, 38.07273343205452, 37.02821508049965, 38.570236936211586, 37.196131870150566, 39.55808512866497, 38.71217831969261, 38.56695771217346, 38.27058881521225, 37.33674332499504, 47.46514543890953, 48.86706881225109, 42.14111052453518, 37.2021659463644, 39.6624731272459, 38.591356202960014, 39.78916212916374, 39.938862696290016, 40.101790353655815, 40.05276918411255, 39.37595710158348, 39.836207404732704, 39.68254745006561, 41.77670247852802, 43.80536422133446, 49.5374820381403, 50.18976643681526, 46.61338694393635, 40.17769128084183, 39.63015966117382, 36.38062343001366, 38.41580182313919, 38.780791237950325, 38.28553341329098, 39.86677676439285, 40.867468267679214, 38.22833888232708, 36.98921017348766, 36.42408549785614, 38.244928792119026, 37.27262556552887, 39.69955913722515, 38.55101756751537, 38.96828457713127, 42.290803492069244, 41.380334347486496, 39.780692383646965, 43.23594957590103, 43.62787954509258, 44.29987348616123, 45.570118725299835, 47.040522024035454, 43.7837889790535, 44.69933085143566, 42.17428654432297, 46.0496111959219, 48.18999834358692, 49.83292758464813, 47.802951112389565, 49.061428382992744, 47.387287616729736, 44.10787358880043, 43.14548023045063, 42.47072383761406, 43.00485737621784, 43.042049780488014, 42.372130528092384, 42.05043599009514, 42.54508204758167, 44.22353558242321, 45.336419865489006, 46.65538989007473, 46.99347674846649, 54.53707896173, 61.749407351017, 58.98453131318092, 54.907760471105576, 1.2627229490317404, 0.30843473388813436, 1.3156250165775418, 0.6202882155776024, 1.2700564367696643, 49.74967025220394, 64.80759724974632, 58.28701414167881, 63.43547187745571, 62.28345349431038, 51.13211967051029, 39.776611402630806, 47.02902004122734, 45.27341164648533, 53.42153862118721, 8.081284761428833, 0.4603809805121273, 0.0709948263829574, 0.09426845877896994, 0.06519389586173929, 0.04029466690553818, 0.06823074189014733, 0.080041027686093, 0.044370022442308255, 0.026321818440919742, 0.026820434068213217, 0.04301506487536244, 0.10128358742804267, 0.04683868020947557, 0.13485402159858495, 1.099278994370252, 59.055902883410454, 63.74851047992706, 49.959191009402275, 38.967224434018135, 47.44308762252331, 55.04310540854931, 75.53704351186752, 62.27319784462452, 66.6847725212574, 56.15242548286915, 69.46608647704124, 11.348022669553757, 0.760592658771202, 0.9080651798285544, 0.9810555225703865, 1.1460231360979378, 48.08621071279049, 71.5229845046997, 60.25070697069168, 60.16812980175018, 50.52273117005825, 46.70412227511406, 46.50607690215111, 45.85647515952587, 43.88886094093323, 44.61646869778633, 41.17161154747009, 43.441320955753326, 40.40546625852585, 41.469789147377014, 41.24259553849697, 40.93143783509731, 41.21578797698021, 41.446200013160706, 39.70029629766941, 42.611969858407974, 40.97396895289421, 41.77662268280983, 40.29158256947994, 43.766834288835526, 41.910709887742996, 43.2852291315794, 43.88157673180103, 42.597409039735794, 42.42421433329582, 43.096117079257965, 42.33292043209076, 42.910858020186424, 41.56213939189911, 43.23102883994579, 41.892725452780724, 41.45816557109356, 39.611487463116646, 40.78692398965359, 38.58067877590656, 40.24074129760265, 42.718679532408714, 40.88879272341728, 40.714572072029114, 38.0030831694603, 39.92987237870693, 39.55560386180878, 39.460460767149925, 39.305995255708694, 46.06349565088749, 51.219366788864136, 55.08315905928612, 53.32196496427059, 50.73744624853134, 37.80576355755329, 36.824473813176155, 39.47606272995472, 37.59972341358662, 39.59600709378719, 39.23001453280449, 38.38222682476044, 37.93439045548439, 38.05343806743622, 50.740603879094124, 50.817378759384155, 42.659357115626335, 38.02114740014076, 39.891809821128845, 39.22168917953968, 39.59120415151119, 38.63809749484062, 41.07962608337402, 39.88164156675339, 41.21568538248539, 38.794880881905556, 39.22505579888821, 42.00090944766998, 44.695158675312996, 52.412696555256844, 51.27862460911274, 47.526059970259666, 43.446576073765755, 41.05318710207939, 39.3972397595644, 39.36802692711353, 40.660858154296875, 41.237496212124825, 42.00044967234135, 42.9961596429348, 41.58056080341339, 39.14258122444153, 39.11779895424843, 40.97355857491493, 38.80944550037384, 40.23427404463291, 40.05436509847641, 40.0510972738266, 44.43577319383621, 43.84110130369663, 41.19017355144024, 46.15385100245476, 46.032990887761116, 46.616175994277, 47.8665217012167, 49.1879577934742, 47.240189909935, 45.13587422668934, 46.273479983210564, 50.16106277704239, 50.773696303367615, 51.1171218752861, 50.789062678813934, 51.510210782289505, 50.065395310521126, 45.8317194879055, 46.34684644639492, 43.726153671741486, 45.17536170780659, 44.87122222781181, 46.009280160069466, 44.253766760230064, 44.48370762169361, 46.14846669137478, 46.62323981523514, 47.768581956624985, 51.09651178121567, 57.74626135826111, 65.43103739619255, 59.810648784041405, 61.808554977178574, 3.6006328789517283, 0.2347613629535772, 1.374012683518231, 0.4921278910478577, 1.337116069626063, 54.18513044714928, 72.56059482693672, 63.82139816880226, 70.247423350811, 66.18626207113266, 56.5746246278286, 43.945094123482704, 51.572459042072296, 52.66840383410454, 64.31485489010811, 12.666249834001064, 0.6573974399361759, 0.07214577868580818, 0.043312269044690765, 0.006146789892227389, 0.07614680071128532, 0.03507038141833618, 0.23367940069874749, 0.2448051591636613, 0.16770348156569526, 0.08768109662923962, 0.218715759110637, 0.25914944882970303, 0.17348360968753695, 0.2700408222153783, 1.285352990962565, 67.84440949559212, 71.52836501598358, 57.92251870036125, 37.8986381739378, 45.961566120386124, 64.97526705265045, 80.59507369995117, 68.94177541136742, 71.77824720740318, 61.79915048182011, 75.63925802707672, 13.43002500012517, 0.9686640906147659, 3.2717132661491632, 1.2012481852434576, 1.4415582153014839, 51.575270891189575, 73.89015108346939, 63.55849787592888, 61.69898025691509, 53.67883421480656, 49.16384428739548, 49.92107905447483, 47.673963233828545, 46.34629927575588, 46.33751034736633, 41.81601516902447, 45.633636116981506, 44.06176686286926, 43.23377229273319, 43.41280348598957, 44.36514638364315, 44.03141789138317, 43.83031748235226, 40.55487044155598, 44.34302397072315, 43.18127050995827, 43.7331148982048, 43.29001307487488, 45.594969391822815, 43.084326311945915, 45.85913881659508, 46.22821681201458, 44.89977769553661, 46.06946513056755, 44.537220150232315, 45.73963142931461, 45.31284973025322, 45.798741057515144, 45.27444899082184, 45.83404876291752, 42.96334080398083, 43.06677505373955, 44.014151617884636, 41.05331249535084, 43.660166412591934, 43.68109188973904, 41.82473950088024, 42.84054659307003, 40.98681606352329, 43.82767282426357, 40.92178635299206, 43.75903710722923, 42.390935719013214, 48.94860863685608, 55.74064917862415, 56.58434450626373, 57.47183248400688, 51.84528060257435, 39.75647248327732, 38.132774010300636, 41.290655359625816, 37.8714582324028, 39.997242763638496, 40.16956351697445, 39.4228807836771, 37.90516622364521, 36.680985912680626, 53.30328516662121, 54.145338982343674, 42.2286806255579, 38.16969282925129, 40.661219134926796, 38.4033764898777, 39.57426466047764, 40.012685135006905, 42.4238495528698, 40.695193111896515, 40.817569345235825, 39.29398030042648, 38.971958979964256, 42.619318664073944, 46.621856689453125, 54.38859432935715, 55.68598531186581, 50.46809010207653, 44.94153745472431, 43.82724344730377, 40.45740947127342, 42.55833953619003, 44.753838926553726, 43.83211478590965, 44.62194040417671, 44.01186414062977, 43.577467650175095, 41.126036792993546, 41.45527012646198, 42.12781883776188, 42.292494401335716, 43.18196967244148, 43.63971211016178, 43.54991912841797, 46.75028219819069, 46.05356678366661, 43.74185062944889, 48.77230569720268, 48.41501846909523, 47.11773008108139, 49.23688776791096, 53.661940321326256, 48.63887205719948, 48.04993025958538, 46.39699995517731, 52.46005721390247, 55.1350224763155, 55.00114805996418, 51.6753651201725, 55.944268852472305, 52.97174155712128, 48.58086057007313, 47.87353612482548, 46.987613663077354, 47.72043094038963, 47.43302956223488, 47.616989091038704, 45.750548243522644, 46.616430580616, 48.741960525512695, 49.60758447647095, 50.7103157043457, 53.22236470878124, 59.09652270376682, 68.16456511616707, 63.431736677885056, 68.9227232336998, 8.235690426081419, 0.3844055416993797, 4.446060201153159, 2.220050347968936, 1.7861497309058905, 57.3951032012701, 79.59736123681068, 67.00983747839928, 78.00355955958366, 72.60202780365944, 68.15555199980736, 55.54870627820492, 64.0985856950283, 60.70514738559723, 77.46495366096497, 18.88049717992544, 0.899690844817087, 0.23303309397306293, 0.16533525864360854, 0.20806059648748487, 0.12346933523076586, 0.11315377938444726], [0.06211507396074012, 0.05538969089684542, 0.025197190116159618, 0.0955146063643042, 0.1278952887514606, 0.021013996811234392, 0.032793962163850665, 0.08455131886876188, 0.3451760014286265, 39.499169290065765, 60.50220787525177, 41.64597049355507, 14.161272961646318, 23.269957043230534, 49.568248987197876, 66.7133317887783, 52.249202728271484, 52.37112678587437, 52.826159968972206, 62.902964651584625, 19.362915493547916, 0.4809252015547827, 0.28024933068081737, 1.7318608565256, 0.3729554498568177, 17.672564797103405, 74.40297156572342, 57.02644318342209, 61.99809640645981, 48.32515709102154, 44.41600285470486, 43.104803413152695, 45.65804980695248, 38.49515676498413, 41.757110729813576, 38.81333269178867, 39.43673864006996, 38.59694190323353, 40.87005592882633, 36.979539692401886, 37.90361970663071, 37.0622194558382, 37.69829012453556, 38.16008694469929, 38.34852643311024, 37.153262570500374, 39.929488599300385, 38.668036088347435, 37.99241714179516, 36.51608616113663, 38.004059717059135, 36.964952275156975, 37.98561930656433, 36.78400598466396, 39.354530051350594, 38.06267537176609, 39.747094586491585, 38.36415499448776, 40.89122459292412, 39.20745134353638, 41.141539961099625, 38.29090632498264, 36.80965840816498, 36.65468752384186, 37.944152131676674, 34.746893495321274, 36.13500460982323, 36.876234635710716, 39.31832179427147, 37.009064108133316, 37.70367443561554, 37.480124831199646, 39.84243907034397, 45.28353050351143, 49.01925824582577, 48.732886612415314, 52.09892079234123, 48.69510903954506, 39.37918692827225, 35.461224764585495, 39.44861300289631, 38.91851104795933, 37.528325244784355, 38.20059657096863, 38.223687931895256, 39.90967646241188, 40.09344220161438, 46.4941531419754, 51.06431610882282, 42.187703624367714, 38.98474909365177, 38.47312934696674, 39.2289961874485, 39.734300673007965, 40.47525331377983, 39.115712866187096, 38.4184692800045, 40.34603364765644, 38.88545662164688, 40.48015125095844, 42.15588793158531, 41.29602827131748, 44.658464044332504, 50.035080537199974, 49.21498194336891, 43.10538858175278, 37.10050620138645, 37.427224069833755, 36.33181504905224, 37.30243116617203, 36.748721078038216, 34.3653217703104, 36.867289915680885, 35.0897490978241, 37.491151839494705, 37.99058184027672, 36.438847705721855, 38.70832912623882, 40.07214434444904, 39.36349377036095, 39.36950504779816, 40.228232368826866, 39.921060651540756, 41.05512499809265, 40.95058500766754, 39.29087206721306, 39.714260548353195, 40.2304058521986, 40.42388767004013, 39.70042169094086, 40.53437054157257, 38.40767025947571, 40.20344629883766, 42.48689576983452, 44.8185570538044, 44.87243056297302, 44.589425548911095, 44.32636946439743, 42.016587406396866, 42.412932738661766, 40.63434697687626, 41.122373789548874, 39.88571874797344, 41.531771421432495, 40.21182104945183, 41.29421956837177, 41.96982331573963, 44.48021940886974, 44.37912203371525, 48.414053320884705, 54.12390433251858, 61.53946481645107, 57.396132946014404, 53.51690970361233, 2.5124244717881083, 0.28116920788306743, 1.1772892833687365, 0.5622850998770446, 1.5395490196533501, 53.686722591519356, 64.52210336923599, 59.05977487564087, 61.987890154123306, 65.00375032424927, 56.27649262547493, 18.34158919751644, 22.2449791431427, 41.803502440452576, 53.191924542188644, 4.891370180994272, 0.40398167562671006, 0.03355034794367384, 0.03579220167011954, 0.1275024699862115, 0.025242952797270846, 0.09263666899641976, 0.0044090037954447325, 0.10136658922419883, 0.06949292728677392, 0.050065838877344504, 0.06357867081533186, 0.08308047865284607, 0.043588025146164, 0.14736332144821063, 0.6428398273419589, 47.66933888196945, 65.7139702141285, 49.14753556251526, 18.806429654359818, 27.28194136172533, 58.319012224674225, 71.38065174221992, 59.56012062728405, 59.5886304974556, 56.598118767142296, 70.12426435947418, 20.822498872876167, 0.25607609655708075, 0.6480495259165764, 2.055223030038178, 0.15546724753221497, 19.246780425310135, 75.27772262692451, 60.59995763003826, 64.28259462118149, 50.36954239010811, 47.81014412641525, 44.847925677895546, 47.19116874039173, 39.84310403466225, 43.846136033535004, 41.5376079082489, 41.91093787550926, 40.329101756215096, 41.53515703976154, 39.641456454992294, 40.49124285578728, 40.317139998078346, 39.67798009514809, 40.910079181194305, 41.71899497509003, 40.77306613326073, 41.68858900666237, 40.72642743587494, 38.43563295900822, 39.69058781862259, 40.37295900285244, 38.55366602540016, 39.19479042291641, 39.12608250975609, 40.939569398760796, 41.203051060438156, 42.1565642952919, 40.415307730436325, 42.974546402692795, 42.218747958540916, 41.73070974647999, 40.68682596087456, 41.15556500852108, 39.414566829800606, 39.781285151839256, 36.65552727878094, 38.91827926039696, 37.79022619128227, 39.86033610999584, 38.203518614172935, 38.898049145936966, 39.187684804201126, 41.290457770228386, 48.92343498766422, 52.8202398866415, 51.81099124252796, 55.78714728355408, 50.913266614079475, 39.085553884506226, 37.14215196669102, 39.74318839609623, 37.718968614935875, 38.30264009535313, 38.43203455209732, 37.98903152346611, 38.550512194633484, 40.46191982924938, 47.75275580585003, 52.93743319809437, 43.25397580862045, 40.007513612508774, 37.78491407632828, 39.10818926990032, 39.65831235051155, 40.30683875083923, 38.97141560912132, 39.12696026265621, 38.93087558448315, 40.352580696344376, 40.12868531048298, 42.735710218548775, 44.825328290462494, 48.10295261442661, 53.530360981822014, 50.55772349238396, 43.61182160675526, 39.57724370062351, 40.435621440410614, 38.92704539000988, 38.64400997757912, 38.58683444559574, 36.36244520545006, 38.7307745218277, 38.271014392375946, 39.63922597467899, 37.96591356396675, 38.05860199034214, 40.788884684443474, 41.287934705615044, 42.560003846883774, 40.62893986701965, 41.86160132288933, 41.34210839867592, 41.654181852936745, 43.27929764986038, 41.547935754060745, 39.76647734642029, 43.549968525767326, 42.5660265237093, 42.624866366386414, 41.21399827301502, 41.667044162750244, 42.79326193034649, 44.12669397890568, 48.59579376876354, 48.984706699848175, 46.7980532348156, 47.662343457341194, 44.71671111881733, 44.248143061995506, 43.64052526652813, 42.75157056748867, 42.862760201096535, 44.48684625327587, 43.48469942808151, 44.04914774000645, 44.273540899157524, 46.63263291120529, 46.45389810204506, 50.1078200340271, 58.01501713693142, 63.508348166942596, 61.17498077452183, 60.4209378361702, 5.077885072678328, 0.41019324387889355, 1.783435964025557, 0.18587312690215185, 1.8378266016952693, 57.986663058400154, 71.92377179861069, 63.68524007499218, 66.55908286571503, 69.30628225207329, 64.42874997854233, 26.31250888109207, 29.07426718622446, 47.8982499986887, 67.01780945062637, 8.390467520803213, 0.6181784381624311, 0.03607806211221032, 0.16980444226646796, 0.038819477704237215, 0.014832486467639683, 0.0722169506479986, 0.09881584992399439, 0.2596677647670731, 0.2364454444614239, 0.19603027874836698, 0.3022135474020615, 0.12929440039442852, 0.08629903953988105, 0.23438487143721431, 0.7853441743645817, 57.19618007540703, 74.51585590839386, 59.90046836435795, 20.543128363788128, 32.070115730166435, 61.62887021899223, 77.17235416173935, 61.69919304549694, 65.45704320073128, 60.376920998096466, 78.3694039285183, 23.039377816021442, 0.4396674904273823, 2.383379121311009, 4.553700825199485, 0.6560071301646531, 20.408015213906765, 77.24063649773598, 63.29701490700245, 66.87682181596756, 53.30749914050102, 49.56003002822399, 47.08392709493637, 50.48815302550793, 42.26631760597229, 48.44529904425144, 42.302328273653984, 44.85279701650143, 42.06327170133591, 44.44586165249348, 43.1002626568079, 42.90985107421875, 42.0084672421217, 43.498515486717224, 43.024281933903694, 42.38079026341438, 42.36539348959923, 44.517651200294495, 44.18164283037186, 42.640095949172974, 40.19906513392925, 41.99090838432312, 40.75202666223049, 42.05111235380173, 42.68561750650406, 45.150286853313446, 44.546841233968735, 44.39268730580807, 42.14834913611412, 46.41262851655483, 44.6841012686491, 44.54652585089207, 43.804007694125175, 41.71278990805149, 40.839349776506424, 42.45835170149803, 39.043885320425034, 40.37211924791336, 40.87155684828758, 42.48486667871475, 40.21307498216629, 41.11549615859985, 42.91238933801651, 43.09172451496124, 50.13215772807598, 56.008265018463135, 55.850113704800606, 58.14875856041908, 54.250464141368866, 39.283451065421104, 36.37778498232365, 41.14567793905735, 38.35053272545338, 38.35106089711189, 39.24354560673237, 38.21211375296116, 39.35506582260132, 39.80982542037964, 49.91063341498375, 55.141649320721626, 43.35990272462368, 40.292870700359344, 39.1199192404747, 40.16796760261059, 40.90186022222042, 40.76010122895241, 39.422291815280914, 39.06278930604458, 40.07703848183155, 39.49223466217518, 41.5392342209816, 42.31824941933155, 49.529221281409264, 52.453293576836586, 56.44375205039978, 53.51031705737114, 47.19631366431713, 41.680791825056076, 41.524217426776886, 41.787611693143845, 40.995445400476456, 42.13816948235035, 38.68947073817253, 41.86735801398754, 39.40450116991997, 41.692761182785034, 40.92528596520424, 39.87205848097801, 43.08069750666618, 43.47290486097336, 43.141171261668205, 44.482613280415535, 44.009519666433334, 43.73201675713062, 43.23943018913269, 44.79784436523914, 43.57871398329735, 41.78865663707256, 46.09984450042248, 44.25150588154793, 45.533853471279144, 43.80643956363201, 43.862197771668434, 45.4370004683733, 47.359081730246544, 50.1386059820652, 50.84483228623867, 48.4042726457119, 50.231564193964005, 47.96637274324894, 48.20913791656494, 45.038971826434135, 45.11333003640175, 44.67082858085632, 47.43403650820255, 45.05933113396168, 46.680666133761406, 46.123346239328384, 49.44500260055065, 49.73048508167267, 53.93658198416233, 59.63715009391308, 67.24412530660629, 63.752507865428925, 66.0519240796566, 7.9874820448458195, 0.39034097164403647, 5.769076533615589, 1.1284160683862865, 2.132310918532312, 61.47113688290119, 77.74391949176788, 67.57272407412529, 75.20429536700249, 75.30400201678276, 71.25607922673225, 28.741367049515247, 37.9496656358242, 56.80147245526314, 78.99481996893883, 13.904195856302977, 0.8132689946796745, 0.19017348677152768, 0.26617144234478474, 0.27934699784964323, 0.1772844447987154, 0.1998476785956882], [0.08543230011127889, 0.027772904541052412, 0.03147420837194659, 0.020646589182433672, 0.034988745173905045, 0.02904236112954095, 0.017749793842085637, 0.11359161682776175, 0.02530950674554333, 27.590007930994034, 68.86800616979599, 43.14163103699684, 43.130984008312225, 48.276173919439316, 42.916356325149536, 67.49076247215271, 50.731035992503166, 54.50544945895672, 55.24270109832287, 56.6909895837307, 31.54028546065092, 0.03418190077354666, 0.35532965033780783, 0.8392937981989235, 0.07465404487447813, 2.474988643079996, 57.47988045215607, 63.34642745554447, 61.82579465210438, 51.58402182161808, 43.841557279229164, 41.90159037709236, 42.16103285551071, 41.051028817892075, 40.129411071538925, 39.216589853167534, 41.22679218649864, 37.73028440773487, 40.91983325779438, 39.33896228671074, 38.01252566277981, 38.517909944057465, 39.83097888529301, 37.468166872859, 40.46215541660786, 38.66300895810127, 39.23263639211655, 38.639841601252556, 41.70860253274441, 41.70978046953678, 39.215187728405, 38.57167325913906, 37.553012520074844, 37.56219282746315, 38.72007429599762, 38.85883904993534, 40.8295539021492, 40.16226410865784, 39.506894275546074, 39.030046463012695, 38.06840546429157, 35.90612769126892, 38.64325761795044, 36.23544842004776, 37.6750847697258, 36.15474075078964, 38.2228671759367, 35.71665085852146, 39.98110502958298, 38.44466507434845, 38.009805008769035, 39.37201291322708, 46.298110261559486, 48.56482923030853, 48.24105620384216, 51.216125562787056, 50.118577256798744, 53.39183561503887, 48.232499063014984, 35.35367913544178, 38.32171507179737, 37.40543983876705, 39.20574143528938, 38.754815831780434, 38.24513778090477, 38.910850659012794, 38.608079105615616, 45.7064364105463, 51.93815141916275, 41.99968211352825, 36.774635687470436, 38.97793985903263, 41.207371428608894, 40.22754840552807, 38.61263506114483, 40.953073874115944, 40.077684447169304, 39.22070503234863, 39.50610391795635, 37.82602407038212, 41.73365838825703, 44.75602000951767, 46.02196767926216, 52.77905769646168, 48.68547275662422, 43.81854951381683, 38.294139951467514, 37.47463792562485, 39.24224987626076, 37.188585475087166, 37.642642110586166, 37.039230689406395, 38.59719268977642, 35.15716128051281, 35.27413800358772, 38.19585062563419, 36.3165170699358, 36.835432425141335, 39.1342406719923, 39.10000830888748, 37.826886624097824, 38.462907895445824, 38.76258261501789, 38.632492795586586, 40.8208067715168, 39.438946321606636, 38.61575469374657, 40.204924419522285, 40.5548058450222, 39.844988733530045, 39.07285116612911, 38.82880926132202, 38.5181949287653, 39.42467428743839, 40.4573068767786, 41.99627369642258, 42.61712238192558, 42.89873667061329, 40.717205330729485, 41.460639238357544, 39.23352554440498, 41.66466549038887, 41.48990146815777, 41.336017325520515, 40.96420727670193, 41.967220455408096, 44.22509729862213, 41.64573110640049, 42.976681888103485, 44.08474043011665, 49.456333592534065, 62.66070105135441, 56.73277594149113, 61.087596863508224, 6.834967313334346, 0.44225138146430254, 0.27784441597759724, 0.36929577123373747, 3.565283138304949, 60.20869642496109, 61.15269497036934, 62.01534368097782, 67.48779863119125, 61.88281439244747, 51.25152826309204, 23.215169683098793, 33.36480885744095, 48.04701201617718, 55.02218373119831, 4.891937300562859, 0.3592956578359008, 0.1013032320770435, 0.12000449263723567, 0.046371279313461855, 0.0358809810859384, 0.03921649702533614, 0.022311909197014757, 0.0415265467017889, 0.07317072173464112, 0.02076654065604089, 0.0430605770816328, 0.06089662332669832, 0.03342440177220851, 0.2562383300391957, 0.08592640719143674, 34.72853668034077, 74.12377014756203, 51.394924968481064, 29.314271807670593, 42.49088175594807, 59.1104793548584, 69.51068848371506, 58.236176669597626, 55.16986660659313, 60.684263706207275, 60.23315191268921, 34.37357112765312, 0.14916487009031698, 0.27642922941595316, 2.3143092775717378, 0.07780449144775048, 3.7342170858755708, 60.74993938207626, 65.49683466553688, 64.4071139395237, 54.23039361834526, 46.99772112071514, 44.200216233730316, 44.27359789609909, 43.04079584777355, 42.79868423938751, 40.715035647153854, 43.021701872348785, 40.82496374845505, 43.743397146463394, 40.13186194002628, 40.37951745092869, 39.724455401301384, 41.24378867447376, 40.05875006318092, 42.139393016695976, 40.86268812417984, 41.309194564819336, 41.38837851583958, 44.82460632920265, 43.89337129890919, 40.058202892541885, 40.732906088232994, 40.93882083892822, 39.5080342143774, 40.74323393404484, 42.26073570549488, 40.88448375463486, 42.624596580863, 41.37480564415455, 41.27601094543934, 39.541590213775635, 39.401848912239075, 41.14279009401798, 37.42908217012882, 39.81607228517532, 37.58437983691692, 38.940941244363785, 36.745848432183266, 41.88504606485367, 40.341895669698715, 39.27728779613972, 40.93838766217232, 47.161416336894035, 50.82270987331867, 52.0302052795887, 53.96109826862812, 51.88589662313461, 55.99646285176277, 48.8416937738657, 36.46997943520546, 38.17305184900761, 38.00292357802391, 39.169719368219376, 37.920323610305786, 38.03540423512459, 39.487925693392754, 38.314833641052246, 46.32278613746166, 52.98806548118591, 42.761583030223846, 38.11186373233795, 39.71067354083061, 39.57841403782368, 40.17892621457577, 38.17150913178921, 40.02602621912956, 40.04447042942047, 40.19745782017708, 40.305820405483246, 38.793421760201454, 41.30128338932991, 46.49926766753197, 47.92990989983082, 54.7025790810585, 48.188577219843864, 44.15258198976517, 40.1091543585062, 40.31693480908871, 41.319826394319534, 38.20884592831135, 38.1739865988493, 38.57914745807648, 39.855312779545784, 35.63843585550785, 35.99916189908981, 38.691944405436516, 38.74988749623299, 39.07476246356964, 41.09541803598404, 39.71712939441204, 40.597762539982796, 40.42697690427303, 41.42120495438576, 41.80791400372982, 43.066968843340874, 42.43024080991745, 41.13737538456917, 41.35339759290218, 43.37097533047199, 42.16442607343197, 41.275380179286, 41.511362716555595, 41.16954445838928, 39.724755585193634, 42.36621044576168, 45.060022696852684, 46.231686025857925, 44.32617947459221, 43.82518395781517, 43.524490892887115, 42.78986491262913, 43.08238461613655, 44.0599961578846, 44.04259689152241, 42.88590855896473, 44.243408516049385, 45.65939873456955, 45.27841217815876, 44.58637431263924, 46.3763290643692, 52.207347974181175, 66.31268128752708, 59.49186488986015, 65.60414850711823, 8.311428911983967, 0.42397311539389193, 0.6662386155221611, 0.7838219404220581, 3.9534501219168305, 64.85946446657181, 67.79593169689178, 66.02102413773537, 70.7793340086937, 66.9408255815506, 58.375188410282135, 27.950749173760414, 36.235547214746475, 54.54293444752693, 66.28171294927597, 7.017186060547829, 0.4449571925215423, 0.03836356154351961, 0.11175676801940426, 0.042450164328329265, 0.09185093498672359, 0.023653673233638983, 0.26669676415622234, 0.11851304298033938, 0.2117361719137989, 0.10052227749838494, 0.15600460697896779, 0.281809443840757, 0.11438442350481637, 0.41085458651650697, 0.15384292375529185, 37.908848226070404, 84.58523958921432, 62.024163007736206, 53.31992827355862, 65.30183672904968, 58.245094791054726, 76.0595990717411, 63.18612165749073, 68.68773624300957, 66.68834432959557, 69.94873657822609, 36.541149616241455, 0.14092073746724054, 2.642949130386114, 3.224094221368432, 0.2315973796066828, 4.809227613732219, 62.233011201024055, 66.3097782433033, 68.16069692373276, 55.419801995158195, 49.698076620697975, 44.94563363492489, 46.746729388833046, 44.019167348742485, 46.86105765402317, 43.93898785114288, 45.94666711986065, 43.96019831299782, 46.53942011296749, 43.82760062813759, 42.46743321418762, 41.46295331418514, 44.23363924026489, 42.57139943540096, 44.6636925637722, 42.365252897143364, 43.07639233767986, 43.51345248520374, 46.022640243172646, 45.793254151940346, 43.43506269156933, 44.445637464523315, 44.2038032412529, 42.13539183139801, 42.52952568233013, 43.730937615036964, 45.26090271770954, 44.31938163936138, 43.30985181033611, 42.84912273287773, 41.16676300764084, 40.951857939362526, 43.2649914175272, 39.13865603506565, 41.87996953725815, 40.51693707704544, 42.06987574696541, 39.22354348003864, 44.46023628115654, 42.029415518045425, 41.88804030418396, 43.89810584485531, 50.77303893864155, 53.933295160532, 53.609518334269524, 56.05283282697201, 54.48495715856552, 58.236123472452164, 50.193722024559975, 37.77755007147789, 37.57884733378887, 38.60050991177559, 39.23109367489815, 38.36730882525444, 38.31275135278702, 40.062876641750336, 38.73093031346798, 46.88957892358303, 56.61222741007805, 43.15986625850201, 37.79550410807133, 39.01780731976032, 40.81795312464237, 40.821471735835075, 38.57730835676193, 40.85372440516949, 40.92097319662571, 39.96231883764267, 38.06372791528702, 38.97369168698788, 45.68600870668888, 53.75250846147537, 51.24616675078869, 55.88744670152664, 51.720183715224266, 47.6579774916172, 41.573325991630554, 41.98438413441181, 43.76548916101456, 40.765029564499855, 40.74845105409622, 40.85269846022129, 41.70729540288448, 38.23691122233868, 37.618141025304794, 40.93780629336834, 40.64076863229275, 39.722038730978966, 42.08081156015396, 42.89340175688267, 42.03017167747021, 42.68614187836647, 44.135026931762695, 43.455091416835785, 46.99554763734341, 44.848928824067116, 43.44496876001358, 44.31690037250519, 45.72524540126324, 43.54194715619087, 43.43534007668495, 43.12391638755798, 43.96509625017643, 42.376572489738464, 45.06751209497452, 47.781702652573586, 48.389597833156586, 47.35307805240154, 45.623517259955406, 46.934180930256844, 45.238833501935005, 47.373410761356354, 46.347682401537895, 46.64218179881573, 45.73111608624458, 47.61923857033253, 47.56659239530563, 47.50256583094597, 47.54943251609802, 48.72251696884632, 53.57010304927826, 70.06650745868683, 65.49244970083237, 70.34493371844292, 10.839503556489944, 0.44470581226050854, 4.326571812853217, 1.064830042887479, 4.656192725524306, 71.12695455551147, 75.00640958547592, 70.73464080691338, 79.87881973385811, 73.63507077097893, 66.45550042390823, 34.95200268924236, 47.587825655937195, 63.599528074264526, 78.2817654311657, 11.046333108097315, 0.6051421095617115, 0.2663294010562822, 0.293308220570907, 0.13418785500107333, 0.20999595435569063, 0.08638221945147961], [0.027957220627286006, 0.03873594898323063, 0.021320082632882986, 0.04255346386344172, 0.04729287829832174, 0.09555547643685713, 0.05202029220527038, 0.2933863241923973, 0.20476002828218043, 17.642481811344624, 62.52831235527992, 45.50433285534382, 33.77645216882229, 18.792269714176655, 44.81705993413925, 62.842946872115135, 55.93049079179764, 57.76294246315956, 58.33161994814873, 53.82080979645252, 47.486621886491776, 0.7406069186981767, 0.7976120535749942, 1.3626287318766117, 0.25477181654423475, 0.3079588687978685, 33.258859142661095, 67.35935032367706, 57.71790347993374, 53.083037585020065, 40.72627544403076, 42.99208626151085, 44.741892367601395, 44.10427138209343, 42.34097599983215, 41.09699495136738, 40.3119532763958, 41.51644304394722, 41.25146426260471, 39.7736057639122, 39.10314314067364, 39.13688912987709, 38.80617767572403, 40.947294384241104, 38.85879345238209, 38.45281943678856, 39.65576648712158, 42.51218721270561, 43.49925644695759, 41.43197737634182, 39.772872403264046, 38.10087852180004, 39.023769199848175, 35.936332270503044, 36.433805376291275, 39.30749237537384, 37.38890312612057, 39.264250695705414, 39.67084787786007, 37.530863508582115, 37.921771332621574, 36.6273707896471, 37.754401713609695, 38.95414933562279, 36.45364411175251, 36.05330139398575, 37.117848470807076, 37.36485801637173, 38.59661132097244, 37.22682282328606, 39.66236673295498, 42.73922502994537, 45.2942269295454, 48.099472001194954, 50.905781015753746, 50.09567588567734, 51.87388926744461, 41.21432885527611, 46.41339227557182, 40.16606770455837, 38.1829047203064, 39.32919301092625, 38.14355783164501, 39.93090592324734, 38.14101196825504, 38.40247593820095, 38.28546121716499, 45.506791323423386, 50.39804846048355, 40.05194842815399, 37.85384997725487, 39.595904499292374, 39.525650069117546, 39.817523807287216, 38.95634941756725, 39.21867214143276, 38.950725719332695, 39.307264387607574, 39.50260430574417, 39.35675673186779, 48.32386516034603, 58.41474048793316, 54.09870408475399, 52.545442432165146, 48.88989418745041, 46.11258141696453, 37.752942591905594, 38.049011304974556, 39.83503706753254, 37.307823076844215, 36.1049672216177, 36.13934777677059, 35.89754015207291, 36.59970447421074, 36.2856475263834, 37.53688998520374, 35.52300564944744, 39.75434459745884, 40.32049521803856, 38.381041288375854, 36.701626405119896, 38.9713092148304, 39.03490260243416, 38.056204319000244, 38.00276018679142, 38.03804509341717, 38.51226344704628, 39.377708807587624, 37.526079565286636, 39.29711513221264, 38.52490156888962, 39.54615376889706, 38.41557003557682, 39.77922186255455, 39.778686091303825, 40.14948159456253, 40.38410000503063, 41.72700874507427, 40.3873336315155, 41.31567321717739, 39.95740570127964, 40.71005031466484, 39.69542495906353, 41.34726092219353, 44.406260177493095, 49.207310155034065, 50.656499192118645, 52.48699016869068, 50.36601237952709, 49.78443078696728, 45.69401867687702, 55.3984547406435, 56.259499937295914, 67.26937115192413, 10.996299292892218, 0.7898978737648576, 1.4717603009194136, 0.6216240813955665, 7.83498102799058, 67.13955491781235, 59.57462064921856, 65.19947022199631, 61.34986259043217, 67.09583446383476, 48.281060457229614, 25.0667742267251, 39.666307121515274, 49.56950291991234, 45.45313440263271, 1.5714802499860525, 0.3150671592447907, 0.025760096141311806, 0.030344739388965536, 0.04498584916291293, 0.07912051965831779, 0.08220299292588606, 0.027111413473903667, 0.05342791628208943, 0.03396198015252594, 0.046026455238461494, 0.03730252785317134, 0.03709912743943278, 0.059513801825232804, 0.33620212983805686, 0.06503068274469115, 22.96773076057434, 73.84338319301605, 51.7171286791563, 44.23323266208172, 31.657820753753185, 51.13519370555878, 68.9445872604847, 59.17313039302826, 61.5051032602787, 63.70847202837467, 58.51074233651161, 53.02142009139061, 0.8471227437257767, 0.6542488932609558, 2.4005945725366473, 0.5630221415776759, 0.5134559387806803, 38.55460077524185, 70.13304948806763, 60.70896238088608, 54.8435515165329, 42.495433911681175, 45.02192594110966, 46.95274293422699, 44.964058846235275, 43.537767380476, 42.46271766722202, 43.86498682200909, 42.96400956809521, 43.57812121510506, 41.70411117374897, 39.99610662460327, 40.42179398238659, 40.51616571843624, 43.004260808229446, 41.068317890167236, 40.190697982907295, 41.418674290180206, 43.476864248514175, 46.33629821240902, 44.300492852926254, 41.863083243370056, 40.64704209566116, 41.746193915605545, 39.86043110489845, 39.96573865413666, 42.058046981692314, 39.16417546570301, 41.79022595286369, 41.42592050135136, 40.29712647199631, 40.12958586215973, 39.47769284248352, 37.52734109759331, 38.501247838139534, 36.94322504103184, 37.80788764357567, 38.906442895531654, 38.697165325284004, 39.63207855820656, 40.76428100466728, 39.809548035264015, 45.32452270388603, 48.121940195560455, 50.67193776369095, 53.64196099340916, 51.897672191262245, 53.73650752007961, 44.41768616437912, 51.273346692323685, 40.78460991382599, 38.15374128520489, 38.696283772587776, 38.26416715979576, 39.87383298575878, 37.33540199697018, 39.066429510712624, 37.67572693526745, 46.150058805942535, 54.27382528781891, 41.47115707397461, 36.96859247982502, 39.61795851588249, 39.302754029631615, 38.16828690469265, 39.19121101498604, 39.605483785271645, 39.55115430057049, 38.34810085594654, 39.852493330836296, 38.09405408799648, 48.42839375138283, 59.54904042184353, 55.61555229127407, 53.89769107103348, 50.837992653250694, 47.27940760552883, 39.91374224424362, 39.993921741843224, 40.61676152050495, 39.26443688571453, 39.31372784078121, 38.9015943557024, 36.28027081489563, 38.28190840780735, 38.80551651120186, 38.080181032419205, 36.28653287887573, 41.48211568593979, 40.108797177672386, 41.564666256308556, 39.45747792720795, 40.82325004041195, 41.54959626495838, 41.23243488371372, 39.47814501821995, 40.49910083413124, 40.416816249489784, 42.068602815270424, 40.23130640387535, 40.97185246646404, 40.62453210353851, 40.957508236169815, 40.61906419694424, 41.24195717275143, 41.956208646297455, 42.79583819210529, 42.229018807411194, 44.90211836993694, 42.26373374462128, 44.01360064744949, 42.076502591371536, 43.48572917282581, 41.975580006837845, 42.97258570790291, 47.35868275165558, 51.39454498887062, 53.08728575706482, 53.84108550846577, 54.586996883153915, 51.874485835433006, 48.86002019047737, 58.43475021421909, 60.975476279854774, 71.38489991426468, 12.588634248822927, 0.8744613267481327, 1.9001121469773352, 0.6839863944333047, 8.115955051034689, 73.07185739278793, 64.60034117102623, 70.28218388557434, 68.65524798631668, 73.14468428492546, 58.17300505936146, 25.713586919009686, 44.919715225696564, 57.5837554782629, 54.496185556054115, 2.9687419859692454, 0.41528241767082363, 0.060897551011294127, 0.1359682672773488, 0.06293719547102228, 0.12623102258658037, 0.04426943545695394, 0.24784839508356526, 0.1946897225570865, 0.06254845109651797, 0.189127592893783, 0.185344316996634, 0.15312897769035771, 0.2296399205806665, 0.39433461672160774, 0.3859471308533102, 24.118770696222782, 83.77711415290833, 59.9594222009182, 51.2719863653183, 28.60779471695423, 56.5808866918087, 75.60391992330551, 66.00235193967819, 69.66849401593208, 69.79944258928299, 64.67227891087532, 60.43642200529575, 1.4004790945909917, 1.8346511595882475, 5.54462400265038, 0.6813818123191595, 0.8262055786326528, 43.17566201090813, 70.13964593410492, 65.05734264850616, 57.059831991791725, 45.00307895243168, 46.00445441901684, 50.10602653026581, 47.05180361866951, 46.299128606915474, 44.53322656452656, 46.091173365712166, 45.5631422996521, 46.47939093410969, 43.539025112986565, 42.46560551226139, 44.346018210053444, 43.317253813147545, 46.330488324165344, 43.31980347633362, 42.348807379603386, 43.87189865112305, 45.89357636868954, 47.53866769373417, 45.839018896222115, 43.07863421738148, 42.02161453664303, 45.140665769577026, 40.48526957631111, 42.42408134043217, 44.44461151957512, 42.09793344140053, 45.165797621011734, 46.40103913843632, 42.37141236662865, 42.08540931344032, 41.531547233462334, 41.202063113451004, 41.33369944989681, 38.18252094089985, 38.60731154680252, 40.67001946270466, 40.9880205988884, 42.422819808125496, 41.64365641772747, 42.138792648911476, 46.93741075694561, 48.609739020466805, 54.535604640841484, 58.717135861516, 54.977365136146545, 58.24976094067097, 48.117806017398834, 53.93521785736084, 42.30934649705887, 38.57868768274784, 39.85107600688934, 39.36641201376915, 37.809874936938286, 38.61836135387421, 39.491391107439995, 37.91559286415577, 48.623023107647896, 56.24950647354126, 40.303985103964806, 38.68603192269802, 40.29129758477211, 40.48545576632023, 38.61805737018585, 39.458298683166504, 38.79045031964779, 39.924575462937355, 37.643291875720024, 39.148083329200745, 38.59377667307854, 51.53643697500229, 60.87864227592945, 60.2413784712553, 55.94218656420708, 54.905032217502594, 50.07998272776604, 40.28710640966892, 42.67489828169346, 43.59575226902962, 42.24970489740372, 40.67307069897652, 40.276459380984306, 39.78014141321182, 40.595361068844795, 40.97678080201149, 40.452275946736336, 38.35062012076378, 43.64111803472042, 43.46269480884075, 42.62841537594795, 41.43927298486233, 43.63275468349457, 43.49581763148308, 44.07285466790199, 42.252961322665215, 41.7962334305048, 43.2624189555645, 43.289401307702065, 42.41462744772434, 43.738757595419884, 42.23384454846382, 44.244309067726135, 40.90498365461826, 43.2117410749197, 44.87777307629585, 43.608519583940506, 44.325309321284294, 47.39508859813213, 44.72041592001915, 47.74440385401249, 45.316980108618736, 46.140384525060654, 43.058704286813736, 46.08852110803127, 49.87683802843094, 53.470875173807144, 56.360927894711494, 57.96626195311546, 57.10723824799061, 55.946867913007736, 51.41423553228378, 61.472444012761116, 64.10378381609917, 74.62962180376053, 14.003908205777407, 0.6285420258063823, 6.833546664565802, 1.0426885122433305, 9.39504336565733, 79.19731110334396, 71.23131215572357, 75.62559396028519, 73.33760753273964, 77.42935717105865, 65.15279352664948, 35.781429782509804, 54.32448036968708, 65.16605481505394, 68.01609948277473, 4.743702029809356, 0.5331379920244217, 0.15516418410697952, 0.2840791689231992, 0.16609389684163034, 0.2180815939209424, 0.27506608224939555], [0.01144732548709726, 0.05211875664826948, 0.004591548004100332, 0.09388447157107294, 0.05854489834746346, 0.09242050364264287, 0.05437516389065422, 0.29963342647533864, 0.053212489365250804, 11.550134774297476, 62.93816216289997, 47.354271188378334, 37.84813888370991, 34.98992845416069, 50.09501472115517, 60.683465749025345, 65.76736494898796, 54.47554886341095, 60.69603927433491, 48.36635448038578, 58.64031918346882, 4.353203633800149, 0.3410630190046504, 1.92529683932662, 1.3689489802345634, 0.11687693389831111, 22.3360488563776, 74.35789838433266, 55.71830257773399, 54.23165515065193, 39.90694060921669, 53.41532975435257, 49.832802191376686, 46.03402063250542, 40.12128330767155, 43.40234264731407, 40.27865186333656, 42.58542828261852, 41.30525417625904, 41.8093541264534, 40.26653051376343, 39.156534075737, 37.48087719082832, 38.998891934752464, 38.07728558778763, 40.08036710321903, 38.934853971004486, 39.08337660133839, 39.212850853800774, 39.771500676870346, 36.29728250205517, 38.06639917194843, 39.21315483748913, 37.6615346968174, 37.276934534311295, 37.72886708378792, 37.18629039824009, 38.83243806660175, 37.18689076602459, 40.111274644732475, 36.73090763390064, 37.93598636984825, 36.32234215736389, 36.13565057516098, 36.566900834441185, 39.98384848237038, 39.76872682571411, 41.58927373588085, 39.047943502664566, 40.51370345056057, 38.71531695127487, 43.24999362230301, 44.313689544796944, 49.42927144467831, 50.40257781744003, 49.383787885308266, 50.08923143148422, 43.183455392718315, 43.68326537311077, 41.27661131322384, 35.607904493808746, 39.864557683467865, 37.102447897195816, 38.29348638653755, 37.967965453863144, 41.28127746284008, 38.07372137904167, 44.088027253746986, 51.633726954460144, 40.13857617974281, 37.443642988801, 38.83225567638874, 39.65308763086796, 39.42672237753868, 38.640020191669464, 39.14541207253933, 40.00928811728954, 39.04750652611256, 41.063397154212, 41.58083438873291, 49.22182537615299, 51.44973322749138, 53.71867887675762, 51.75241358578205, 50.17469264566898, 47.95435018837452, 42.505655363202095, 37.093700766563416, 37.19290964305401, 37.43396110832691, 37.86963813006878, 37.39028625190258, 36.22096739709377, 36.5717151761055, 35.413837507367134, 38.59918758273125, 37.73257948458195, 37.01892077922821, 37.00809136033058, 41.36727824807167, 39.19743128120899, 39.56577591598034, 38.306265100836754, 38.49551394581795, 39.18661706149578, 38.9507295191288, 39.069552943110466, 39.104720056056976, 39.167249500751495, 37.3990485817194, 39.59753841161728, 39.34595011174679, 39.34238210320473, 40.4107441753149, 38.45450274646282, 40.043915659189224, 40.13718545436859, 40.05465388298035, 39.24774818122387, 40.81582523882389, 39.17264521121979, 40.74269816279411, 40.78074932098389, 42.224766835570335, 45.30481316149235, 52.13457427918911, 56.04936361312866, 56.70386329293251, 57.33633175492287, 55.723610892891884, 47.37664818763733, 54.470612928271294, 54.05706971883774, 66.50824159383774, 10.851071085780859, 0.7545515173114836, 0.28943067707587034, 0.7271191861946136, 14.540654104202986, 69.64909225702286, 58.71491298079491, 64.37344774603844, 59.39736396074295, 63.309341445565224, 42.744396552443504, 35.95619760453701, 40.091166123747826, 47.984797954559326, 41.31755031645298, 1.1877234047278762, 0.21453482564538717, 0.08365012894500978, 0.05698243257938884, 0.013621116850117687, 0.06434131661080755, 0.03290374806965701, 0.11442095201346092, 0.018763626940199174, 0.013405211248027626, 0.060782826112699695, 0.027803521843452472, 0.05918546827160753, 0.029683825341635384, 0.20485906046815217, 0.10018094151746482, 14.367373902350664, 74.06897708773613, 52.13237799704075, 41.512004882097244, 25.677794739603996, 54.602690041065216, 66.90143689513206, 69.21202450990677, 60.359958708286285, 66.2051622569561, 53.57522517442703, 66.48915901780128, 3.9728214824572206, 0.6480540975462645, 1.6046415455639362, 1.8811842938885093, 0.15818503685295582, 25.476415045559406, 76.05696961283684, 57.67790302634239, 56.507942005991936, 42.51053810119629, 53.14202941954136, 51.797083988785744, 49.81380321085453, 42.86828130483627, 45.57508885860443, 43.33255559206009, 45.22154442965984, 44.08981315791607, 44.69762474298477, 41.556964069604874, 41.03026293218136, 40.765895918011665, 41.29956588149071, 39.59725342690945, 41.67126193642616, 40.44456236064434, 40.806386545300484, 41.45687364041805, 40.78174486756325, 37.589338570833206, 40.10114058852196, 40.37914127111435, 39.88750085234642, 38.97358529269695, 40.26616953313351, 40.39317771792412, 39.98895160853863, 40.676714703440666, 40.86120620369911, 37.95704483985901, 39.9733230471611, 37.92085558176041, 39.60834123194218, 38.27056601643562, 39.00703489780426, 42.09300510585308, 43.045112416148186, 40.655739828944206, 41.157860085368156, 42.1783447265625, 44.51889753341675, 48.056940883398056, 51.86509653925896, 50.80452784895897, 53.13469581305981, 51.878171637654305, 46.4962962269783, 45.39229206740856, 40.40467210114002, 35.19664116203785, 39.629555493593216, 38.365640714764595, 38.27359065413475, 38.40453922748566, 40.818006321787834, 39.33159828186035, 45.91434605419636, 52.6477025449276, 41.93895377218723, 37.358466759324074, 38.374851420521736, 38.32234583795071, 39.13761869072914, 39.00906398892403, 38.72256696224213, 40.45625813305378, 37.68596738576889, 39.29330013692379, 40.324591398239136, 49.11589466035366, 55.007866099476814, 56.62977106869221, 54.47079911828041, 51.897406205534935, 50.35493217408657, 43.48981775343418, 40.86370266973972, 38.936772868037224, 40.301085859537125, 38.69018889963627, 39.76861663162708, 37.67446160316467, 39.28306728601456, 38.439987525343895, 39.474831596016884, 39.45897124707699, 40.37043213844299, 40.72329260408878, 41.76190987229347, 40.607691407203674, 40.34856051206589, 40.35588651895523, 40.15908367931843, 41.1303723603487, 41.831199154257774, 41.79489590227604, 40.87954021990299, 41.670604571700096, 40.85860334336758, 41.88448369503021, 40.877621322870255, 40.57209871709347, 42.19300054013729, 40.37979103624821, 41.18409767746925, 42.52220347523689, 43.63027721643448, 41.7241171002388, 43.27962443232536, 41.28670357167721, 44.2375872284174, 44.469629377126694, 44.884901493787766, 47.97095149755478, 54.71120081841946, 56.9023722410202, 59.12155196070671, 60.675645768642426, 60.269747748970985, 49.71988745033741, 57.16388940811157, 57.341947853565216, 69.99589204788208, 11.321868672966957, 0.36058874626178294, 1.0808170912787318, 0.971479145810008, 16.53774619102478, 76.07922121882439, 63.996621966362, 70.319285094738, 66.38091042637825, 72.12434783577919, 51.573693975806236, 29.144415222108364, 43.80324773490429, 53.76987732946873, 51.64085537195206, 1.3791976240463555, 0.12828586623072624, 0.0748720062256325, 0.08469522872474045, 0.04816605956875719, 0.0111399483284913, 0.03379385772859678, 0.15466749435290694, 0.12989328388357535, 0.12643864582059905, 0.16169707261724398, 0.20722379529615864, 0.28370675921905786, 0.10936530845356174, 0.4380431369645521, 0.2361481252592057, 14.974851105362177, 85.1994614303112, 60.00987209379673, 55.08709564805031, 46.286969259381294, 67.38607048988342, 71.53030291199684, 78.46141219139099, 63.38423162698746, 72.07335457205772, 58.88767071068287, 75.27086779475212, 5.21742451004684, 0.717963696224615, 5.800883201882243, 3.027219185605645, 0.3803097771015018, 31.179274432361126, 77.67057582736015, 61.11255392432213, 59.06837001442909, 45.497778207063675, 56.82661950588226, 54.44042734801769, 50.737396851181984, 45.87893955409527, 47.63993225991726, 46.78507313132286, 49.121282771229744, 47.26013883948326, 46.63590453565121, 45.45002616941929, 45.09549379348755, 42.16467685997486, 42.92672976851463, 42.540051117539406, 44.40510503947735, 44.05156821012497, 44.676927253603935, 45.28082884848118, 44.526371732354164, 40.667306408286095, 43.428705632686615, 45.35743273794651, 42.545762211084366, 42.94493459165096, 41.481066942214966, 42.178280130028725, 44.51564110815525, 42.54222460091114, 45.08353963494301, 41.296115666627884, 40.67843601107597, 39.89236079156399, 41.30990132689476, 39.78939771652222, 40.95133736729622, 44.40944820642471, 44.08034026622772, 42.31006845831871, 44.479501247406006, 44.15464147925377, 46.945603117346764, 49.33487690985203, 53.678754419088364, 53.930437713861465, 55.45825973153114, 56.3069099932909, 50.31176649034023, 47.73236230015755, 42.548847645521164, 36.25858537852764, 40.4418683052063, 38.26699420809746, 39.18983168900013, 38.62363927066326, 42.16072127223015, 39.18109215795994, 45.6839682161808, 54.59676995873451, 42.10047170519829, 37.698062136769295, 38.030384704470634, 39.456782564520836, 39.41663771867752, 38.87295909225941, 39.33080032467842, 40.96246317028999, 38.81928697228432, 42.15799681842327, 41.85632340610027, 49.906951412558556, 55.613002628088, 63.28922152519226, 56.663118079304695, 56.373250633478165, 52.72526018321514, 45.455767661333084, 41.52758024632931, 42.09035664796829, 42.311804965138435, 41.84747748076916, 41.3453534245491, 39.65364620089531, 40.6712543964386, 40.27286857366562, 42.50970594584942, 42.39453412592411, 41.543022617697716, 41.268411353230476, 46.85326807200909, 44.32009220123291, 43.877453953027725, 42.96677581965923, 41.66731394827366, 42.61163167655468, 44.68452304601669, 43.74266758561134, 42.204168140888214, 44.466148763895035, 42.37596072256565, 44.49804425239563, 44.02255676686764, 43.47269207239151, 45.8588994294405, 42.50366806983948, 44.657582491636276, 45.313883274793625, 46.48182660341263, 45.06756529211998, 45.95206283032894, 43.68986561894417, 46.15314424037933, 45.9901899844408, 48.4524654597044, 51.568188071250916, 57.29312427341938, 59.28433142602444, 60.80310232937336, 64.22980785369873, 61.843456104397774, 53.09466876089573, 61.248544827103615, 60.860551446676254, 74.11816164851189, 12.759384736418724, 0.6492019328288734, 1.8237313767895103, 1.4509555860422552, 18.168905563652515, 81.63582265377045, 71.48655965924263, 75.0353792309761, 71.22153148055077, 77.01793044805527, 61.55520357191563, 47.71958738565445, 54.847381711006165, 62.66130521893501, 64.27982077002525, 2.548553408123553, 0.5275350145529956, 0.23270215548109263, 0.1800207729684189, 0.12057654006639495, 0.17459070106269792, 0.12773459893651307], [0.008805262132227654, 0.1010777527699247, 0.03810783600783907, 0.09369977327878587, 0.06257372864638455, 0.0287743326407508, 0.04516017223068047, 0.17984601203352213, 0.17560190695803612, 6.0814515966922045, 54.305302798748016, 46.72431439161301, 43.887504413723946, 22.060960717499256, 35.37409543991089, 59.20132488012314, 62.48160906136036, 56.263995096087456, 60.420044884085655, 48.913977295160294, 58.32769475877285, 11.749621219933033, 0.57769107632339, 0.826860093511641, 0.9718601941131055, 0.22289289277978241, 15.11745935305953, 69.46771278977394, 54.76739600300789, 48.67922209203243, 43.10396745800972, 57.67051242291927, 53.50704163312912, 49.47056382894516, 41.38429373502731, 39.67791549861431, 39.72556114196777, 42.31154277920723, 41.65393866598606, 44.2850086838007, 41.87887139618397, 42.380174696445465, 37.1321015059948, 39.82812523841858, 37.98122674226761, 38.36674265563488, 38.395328521728516, 39.194262251257896, 37.8928928822279, 37.62990899384022, 36.87742777168751, 39.41365487873554, 36.348412558436394, 37.15785272419453, 34.89866495132446, 38.81456382572651, 39.31573033332825, 36.55186504125595, 38.309859707951546, 39.01302717626095, 37.689185813069344, 37.33403407037258, 38.88965539634228, 40.03460995852947, 37.46742591261864, 38.69054988026619, 38.434952795505524, 38.96433658897877, 39.09936994314194, 41.08535997569561, 40.262438133358955, 42.97822840511799, 47.815840020775795, 48.08841459453106, 48.66844967007637, 49.77096050977707, 47.83716827630997, 52.79481545090675, 50.26675030589104, 42.11507432162762, 37.89783261716366, 39.389955550432205, 40.531965270638466, 38.54705438017845, 38.25667016208172, 39.128301590681076, 37.69542507827282, 43.221039175987244, 51.976453363895416, 42.606551349163055, 39.27742458879948, 38.88611778616905, 37.559282183647156, 39.30420935153961, 41.220286935567856, 40.08998818695545, 39.00356948375702, 39.01898145675659, 40.91964326798916, 39.22271512448788, 46.7032977193594, 54.118018448352814, 52.53353387117386, 52.78569594025612, 48.48420515656471, 48.3336990326643, 46.78555190563202, 39.129646718502045, 38.769942820072174, 36.39806069433689, 37.66875430941582, 38.627887442708015, 38.496566489338875, 38.94004449248314, 35.961148738861084, 36.604450419545174, 37.1763501316309, 38.37597236037254, 39.68874491751194, 38.29236924648285, 39.48465786874294, 37.8689693659544, 37.99997113645077, 40.422246158123016, 38.298110738396645, 37.97932684421539, 37.219276428222656, 38.685511350631714, 39.47420462965965, 40.36421947181225, 41.32050275802612, 38.29113431274891, 40.177098512649536, 39.118053540587425, 38.7268341332674, 39.067691043019295, 40.10394103825092, 39.62371900677681, 38.916527554392815, 39.66745086014271, 37.067991346120834, 41.54183328151703, 39.96550686657429, 41.87249913811684, 49.07529003918171, 53.21577586233616, 54.57996346056461, 59.955474212765694, 59.493658393621445, 61.56535282731056, 54.66007836163044, 55.601964220404625, 54.139947071671486, 64.49839264154434, 6.041846796870232, 0.5253051279578358, 2.0822908775880933, 1.0406600148417056, 23.09163261204958, 65.90574592351913, 60.07062703371048, 67.50493571162224, 62.13436849415302, 65.16369894146919, 40.30447527766228, 29.27042406052351, 40.32848618924618, 57.901015654206276, 31.375765688717365, 0.9348278562538326, 0.005058137176092714, 0.043167683834326454, 0.03409995282709133, 0.13287066161865368, 0.07554527517640963, 0.06934647928574122, 0.019007381633855402, 0.01423186449756031, 0.03268394619226456, 0.15344103594543412, 0.016865205761860125, 0.07760687978588976, 0.11063887097407132, 0.15545678324997425, 0.16759067511884496, 7.660483941435814, 65.17968848347664, 53.84367696940899, 54.335606172680855, 29.38286192715168, 46.59982167184353, 64.34076189994812, 70.52691355347633, 59.19243335723877, 67.43243560194969, 52.7295957505703, 67.02693656086922, 12.096324115991592, 0.4447732289554551, 1.1222209758125246, 3.144216095097363, 0.07103610463673249, 18.207080215215683, 72.83474251627922, 56.56034119427204, 49.08301122486591, 44.41476412117481, 62.03006029129028, 54.34487007558346, 51.226920783519745, 42.97813341021538, 41.96512296795845, 41.530912667512894, 44.82451893389225, 43.55365052819252, 46.87571346759796, 43.01988936960697, 42.59127996861935, 38.115082159638405, 42.88550578057766, 40.567576959729195, 41.41272760927677, 40.67274011671543, 42.11312882602215, 40.18560245633125, 39.65668983757496, 38.871370777487755, 42.32008472084999, 38.585945293307304, 39.98377248644829, 37.39294610917568, 41.714123636484146, 41.24968595802784, 40.216578394174576, 39.17207904160023, 40.64793884754181, 40.32791621983051, 39.041829630732536, 40.79360403120518, 42.09145478904247, 40.08057989180088, 40.58265455067158, 39.91233251988888, 41.56046748161316, 41.35541148483753, 42.17090092599392, 41.83811858296394, 46.15401819348335, 49.48327414691448, 51.20618909597397, 52.52906531095505, 51.57527469098568, 50.54329186677933, 56.095534935593605, 51.321866288781166, 42.09946095943451, 37.667663767933846, 39.04026411473751, 38.37632194161415, 37.6615346968174, 37.95457497239113, 39.36974823474884, 37.444896921515465, 43.98100599646568, 55.353902131319046, 42.500271052122116, 39.000582844018936, 39.14611503481865, 38.624441027641296, 38.52136015892029, 40.34691900014877, 39.835101664066315, 36.951147615909576, 38.40587295591831, 40.20572617650032, 38.10219705104828, 47.13494315743446, 58.23344461619854, 54.43149782717228, 53.31455156207085, 51.344589069485664, 51.85566544532776, 47.06849992275238, 40.79846777021885, 40.103580057621, 38.914882242679596, 38.724812641739845, 41.61542773246765, 39.867396131157875, 41.07692442834377, 38.521477952599525, 39.65524971485138, 39.825780764222145, 39.81507293879986, 41.70660383999348, 41.03003114461899, 41.354332342743874, 41.41253001987934, 39.93415094912052, 42.244909554719925, 39.50660929083824, 41.62306532263756, 39.62373040616512, 40.3790120780468, 41.12592279911041, 42.68437497317791, 42.7991858124733, 40.267659053206444, 41.69363513588905, 41.39583371579647, 40.99019408226013, 41.61215230822563, 40.60790799558163, 43.64732690155506, 40.31061954796314, 41.36297307908535, 40.12607865035534, 43.38995151221752, 42.370861396193504, 44.37331214547157, 52.553589195013046, 56.96405813097954, 57.850463166832924, 61.29906691610813, 61.16632483899593, 64.64025422930717, 58.19424971938133, 60.079301968216896, 56.892462372779846, 67.9321999847889, 6.669594012200832, 0.8652977622114122, 0.5754404095932841, 1.1384076322428882, 25.381600633263588, 72.30723202228546, 65.91791287064552, 73.01452606916428, 67.51250490546227, 69.16529461741447, 50.23695230484009, 32.463330030441284, 46.08350917696953, 64.78549003601074, 40.47238826751709, 0.9832138661295176, 0.03945807722629979, 0.025876772888295818, 0.016247065395873506, 0.048777849006000906, 0.07961902025272138, 0.03414584352867678, 0.10856824184884317, 0.15546227514278144, 0.22473043558420613, 0.265145794255659, 0.23888682830147445, 0.21636941470205784, 0.19131605280563235, 0.2990459423745051, 0.21661107282852754, 7.819615127518773, 75.1750673353672, 60.23447044193745, 60.480028465390205, 31.18907030671835, 49.27075535058975, 70.69447696208954, 74.99949395656586, 64.41421195864677, 72.4713072180748, 55.521564334630966, 72.46447518467903, 14.055714625865221, 0.7085185311734676, 2.941798106767237, 3.556740959174931, 0.28703739924822, 22.80701458454132, 76.56262367963791, 59.083850383758545, 53.411811143159866, 47.571900710463524, 64.47410434484482, 58.04409697651863, 54.7373054176569, 45.275208950042725, 44.61622931063175, 45.06115883588791, 46.10945038497448, 46.902745217084885, 50.82765340805054, 47.07429081201553, 45.908083990216255, 41.03106468915939, 44.23032961785793, 42.21174493432045, 43.47792059183121, 43.36453467607498, 44.853849560022354, 43.09207409620285, 42.388218864798546, 41.11732766032219, 45.87115377187729, 40.36861963570118, 42.84901633858681, 40.7515174895525, 43.13110560178757, 44.49152000248432, 42.00790487229824, 41.87890939414501, 43.44150334596634, 41.439561769366264, 41.39762721955776, 42.360913529992104, 45.68342484533787, 41.634810492396355, 43.54508958756924, 42.575389221310616, 42.47179917991161, 42.889411970973015, 44.27284173667431, 44.20997031033039, 49.26280997693539, 52.08489574491978, 54.49192978441715, 54.24112804234028, 54.0436602383852, 54.46136422455311, 57.31544427573681, 51.639293655753136, 43.347815573215485, 38.098651841282845, 40.28970927000046, 40.259231105446815, 38.67565467953682, 38.52193392813206, 38.400009870529175, 37.44092993438244, 44.63417574763298, 56.932352632284164, 43.24194945394993, 40.056899562478065, 38.779092729091644, 37.75999501347542, 39.15900394320488, 41.10343940556049, 39.99425992369652, 37.02555902302265, 38.42136852443218, 39.35057446360588, 38.98471109569073, 49.8449881374836, 60.85348762571812, 56.37435257434845, 57.84444808959961, 53.168867379426956, 53.70495021343231, 49.63830962777138, 42.84368522465229, 41.08786404132843, 39.23792950809002, 41.222866997122765, 43.46202224493027, 41.29288583993912, 42.54255138337612, 41.125873401761055, 41.33843779563904, 42.09463141858578, 41.97676174342632, 43.23382169008255, 42.810315415263176, 42.84088857471943, 44.50149826705456, 42.3539637029171, 45.64028576016426, 40.766701474785805, 43.761066198349, 43.14697355031967, 42.74835214018822, 44.52644772827625, 46.64989158511162, 44.28223103284836, 43.227069452404976, 44.44678120315075, 45.27395501732826, 42.41951398551464, 43.278100714087486, 43.742720782756805, 45.60099586844444, 42.41282634437084, 44.199684262275696, 41.84347629547119, 46.281155571341515, 44.54465255141258, 47.41893991827965, 54.84524242579937, 58.66255559027195, 58.655107989907265, 63.7693789601326, 62.181713953614235, 67.56632521748543, 60.82030400633812, 63.20657595992088, 58.75119723379612, 72.42390096187592, 7.806635499000549, 1.0273031378164887, 5.172538943588734, 1.5253459755331278, 27.95315634459257, 79.12092760205269, 71.29672184586525, 77.71480545401573, 74.52442824840546, 75.44193461537361, 57.53944605588913, 41.5069055557251, 53.84055733680725, 73.7124802172184, 50.5262041836977, 1.3077247655019164, 0.2210739185102284, 0.12274718843400478, 0.17822649737354368, 0.1275074275326915, 0.23291473626159132, 0.18092325422912836], [0.03991901030531153, 0.06791295425500721, 0.030919939090381376, 0.050930619036080316, 0.06696407392155379, 0.0600989926897455, 0.01799791421944974, 0.09372945918585174, 0.10955761375953443, 2.3360564606264234, 43.66645127534866, 54.816819950938225, 39.51344892382622, 19.453365840017796, 31.675896383821964, 58.53569559752941, 62.96289883553982, 56.928803622722626, 58.93635369837284, 49.15682226419449, 61.147504448890686, 22.530999295413494, 0.3316341812023893, 0.584532015491277, 3.0838727205991745, 0.11308339409879409, 11.942751556634903, 66.16129741072655, 52.31354467570782, 47.24111706018448, 47.75053292512894, 58.65581475198269, 55.16327016055584, 50.49281917512417, 40.17719350755215, 40.70139437913895, 39.19818364083767, 43.36556822061539, 40.1654901355505, 43.109347969293594, 43.46722796559334, 43.03354203701019, 38.25529843568802, 39.61678437888622, 39.288820177316666, 40.836674720048904, 38.106266632676125, 38.742975667119026, 36.62669822573662, 36.87957465648651, 35.23796774446964, 38.979744762182236, 35.99233366549015, 37.07340985536575, 36.70622035861015, 38.81070703268051, 36.28020241856575, 38.26889790594578, 38.02001506090164, 37.16512553393841, 37.78057470917702, 39.831233471632004, 37.65846446156502, 38.66506464779377, 37.406393587589264, 38.433676064014435, 37.06248924136162, 38.39250907301903, 38.017419800162315, 37.22303442656994, 39.85185496509075, 45.72456903755665, 50.451287403702736, 48.11180233955383, 48.73358577489853, 48.99455577135086, 49.37245309352875, 52.10338555276394, 50.554695054888725, 43.4247500449419, 34.81549881398678, 39.628635942935944, 37.69373036921024, 40.12908048927784, 37.7858792245388, 39.9746947735548, 38.51098671555519, 44.28888067603111, 52.89184704422951, 40.06947688758373, 37.90134362876415, 40.55297814309597, 37.39482320845127, 38.30674007534981, 40.08888624608517, 38.80404978990555, 39.128267392516136, 40.19411399960518, 39.655777886509895, 38.984315916895866, 50.628483295440674, 53.855129554867744, 51.50695435702801, 48.61478894948959, 46.87622644007206, 49.513075947761536, 47.143587693572044, 44.22973684966564, 40.535753667354584, 38.15465323626995, 35.764281302690506, 35.9642493724823, 37.69179627299309, 38.67990285158157, 36.56535051763058, 37.910470739006996, 37.70513355731964, 38.98628421127796, 37.57070817053318, 39.37941491603851, 38.57005074620247, 39.93367597460747, 39.23403471708298, 37.6137750595808, 39.18104276061058, 40.10753184556961, 40.098777115345, 39.20908905565739, 37.69382916390896, 38.52718144655228, 38.97221356630325, 38.55316445231438, 39.22189436852932, 39.682558849453926, 39.90293562412262, 40.07726646959782, 39.279301688075066, 40.00862315297127, 39.38065744936466, 40.579094141721725, 39.58782993257046, 39.94132876396179, 41.516541838645935, 42.282535135746, 50.63404239714146, 56.1613854020834, 53.968545868992805, 52.39035375416279, 60.941407307982445, 62.368910908699036, 59.166480749845505, 56.49457812309265, 60.76657868921757, 53.882837668061256, 0.37294690031558275, 0.4957390035269782, 0.7255034416448325, 0.3986606252146885, 27.898382283747196, 66.75162613391876, 58.11422221362591, 64.66774955391884, 58.94567459821701, 63.6674228310585, 34.684861823916435, 29.41208615899086, 37.23665289580822, 51.649078130722046, 22.419351786375046, 0.692942573223263, 0.02583169854915468, 0.09522687571006827, 0.039014439898892306, 0.12804827507352456, 0.09056952796527185, 0.03495884775475133, 0.005464494106490747, 0.017156882786366623, 0.03357219677127432, 0.03538420598488301, 0.06955359785933979, 0.09191649631247856, 0.06234100597794168, 0.14803417841903865, 0.11245257599512115, 3.346787500195205, 53.29877480864525, 59.4774978607893, 40.001521334052086, 19.38703279942274, 43.7254773080349, 65.09271115064621, 71.06824770569801, 60.885968282818794, 65.00330954790115, 53.483121916651726, 68.41312497854233, 23.170579075813293, 0.3654612129321322, 0.562150088371709, 3.2509364560246468, 0.11798019579146057, 14.388891197741032, 70.55855065584183, 53.831137642264366, 48.72903361916542, 51.767912954092026, 60.882692858576775, 56.91966511309147, 51.97355791926384, 43.17430168390274, 43.46092030405998, 42.47808404266834, 44.135498106479645, 42.529210299253464, 46.17126926779747, 44.63189586997032, 42.551378309726715, 39.171957448124886, 42.912788316607475, 39.73903901875019, 43.08805771172047, 40.63642546534538, 41.219865158200264, 38.05270850658417, 39.40550811588764, 39.034059047698975, 40.27811609208584, 39.535647332668304, 38.92673380672932, 38.27135257422924, 38.85584481060505, 38.97861622273922, 39.80866268277168, 39.54030588269234, 39.79036286473274, 39.08136650919914, 41.81819245219231, 39.798999801278114, 39.744746312499046, 39.18864235281944, 39.2859323322773, 39.18428398668766, 41.81583657860756, 40.5895359814167, 40.707208067178726, 41.42581790685654, 46.17209002375603, 52.482833191752434, 49.86138045787811, 51.9351913779974, 51.197259575128555, 53.963271751999855, 52.22937539219856, 52.16735512018204, 43.73323269188404, 34.941036477684975, 38.438076227903366, 39.73828665912151, 41.31097286939621, 38.18947836756706, 40.12858271598816, 38.104621320962906, 45.22198520600796, 53.38092640042305, 41.329774260520935, 38.474588468670845, 39.63358327746391, 38.02875839173794, 39.24156591296196, 41.536581963300705, 39.331944063305855, 38.16791832447052, 40.620785504579544, 39.567812606692314, 37.48065300285816, 52.28251554071903, 56.57290332019329, 52.99063794314861, 52.20447152853012, 51.2735290825367, 51.33541256189346, 50.30445948243141, 44.44626443088055, 41.834276989102364, 39.51976798474789, 37.64350466430187, 39.870276376605034, 39.644047915935516, 38.2654020935297, 38.13341237604618, 39.65760178864002, 39.71557907760143, 40.052997171878815, 39.549505189061165, 39.714131355285645, 40.81087030470371, 41.56819246709347, 39.96570065617561, 40.51421642303467, 39.888044223189354, 42.19651535153389, 43.21407414972782, 41.43433324992657, 40.55522762238979, 40.74883483350277, 40.90323194861412, 41.03316217660904, 40.69864332675934, 40.699942857027054, 41.800637394189835, 41.01995408535004, 40.84646299481392, 42.53462880849838, 41.46075323224068, 42.49581769108772, 41.95439614355564, 43.107915446162224, 43.21329519152641, 44.5419242978096, 55.33785559237003, 58.775812312960625, 56.813346818089485, 56.48830845952034, 64.07318025827408, 61.053527891635895, 61.94577321410179, 60.95075860619545, 63.15362200140953, 56.300446540117264, 0.6690116948448122, 1.438470643479377, 0.9709918219596148, 0.42757585644721985, 30.27223650366068, 71.67765140533447, 62.634098678827286, 69.3707723915577, 65.03966599702835, 70.71410670876503, 44.261639937758446, 30.13615060597658, 41.17609530687332, 60.26586815714836, 28.2700764387846, 0.9339632245246321, 0.07217366859549657, 0.06448050640756264, 0.03955964384658728, 0.0681722087028902, 0.05033218825701624, 0.03424161026487127, 0.16471354669192806, 0.32281307328958064, 0.1692795509006828, 0.16414862388046458, 0.12777464522514492, 0.21684241510229185, 0.13542725646402687, 0.18982086272444576, 0.32798423955682665, 3.1857302924618125, 63.663805425167084, 68.65353047847748, 54.75189283490181, 29.762243069708347, 46.975712701678276, 69.65154692530632, 77.07907676696777, 65.9357263147831, 68.78954038023949, 55.49074038863182, 75.43273150920868, 26.490791514515877, 0.368218885269016, 2.309834542684257, 6.742202416062355, 0.30147727753501385, 17.13277716189623, 74.95282486081123, 55.965612307190895, 51.297357603907585, 53.27388994395733, 63.30255500972271, 58.26928809285164, 55.07604204118252, 45.48037514090538, 46.45815007388592, 43.641232028603554, 47.2329892963171, 44.2965030670166, 48.55551593005657, 48.600786700844765, 47.092412039637566, 41.05287551879883, 45.67320339381695, 43.21570806205273, 45.29463730752468, 42.343198880553246, 43.877780735492706, 40.174636244773865, 40.04589915275574, 41.140844598412514, 44.736515656113625, 42.08006300032139, 42.68362641334534, 41.279943734407425, 41.690758690238, 41.31042569875717, 41.97623737156391, 42.98151142895222, 43.175984993577, 41.93033963441849, 44.437524899840355, 42.184789180755615, 43.27804371714592, 42.70704835653305, 42.390019968152046, 43.12211528420448, 43.58740791678429, 43.9022134244442, 44.2131507396698, 43.09629566967487, 49.829663559794426, 55.348035246133804, 52.38558501005173, 53.185039311647415, 55.63175842165947, 56.43549509346485, 56.94148354232311, 55.42101792991161, 45.82383491098881, 35.6202158331871, 39.78575371205807, 38.47050368785858, 41.21187038719654, 38.15420486032963, 39.4114737957716, 38.270155638456345, 46.53372801840305, 55.06411828100681, 41.1825055629015, 37.057940885424614, 41.85848169028759, 37.17278592288494, 38.79945583641529, 40.64390726387501, 39.78985749185085, 38.108360320329666, 40.286490842700005, 38.78314331173897, 38.34075205028057, 53.27542506158352, 59.42987881600857, 56.03071041405201, 53.799751326441765, 52.85611756145954, 54.077003449201584, 52.6307288557291, 49.24878492951393, 45.26593364775181, 42.68525272607803, 38.94660294055939, 41.71354606747627, 40.93530982732773, 41.138393729925156, 39.85742926597595, 40.753048807382584, 40.92353045940399, 43.75227726995945, 41.93417362868786, 41.76084212958813, 43.50513473153114, 44.39501278102398, 44.630706533789635, 42.964967116713524, 43.24289180338383, 44.50844429433346, 44.63319920003414, 43.78153569996357, 41.34856805205345, 43.884700164198875, 44.14990313351154, 41.99082478880882, 42.50583775341511, 45.16715034842491, 44.990083649754524, 43.379612267017365, 43.19131717085838, 45.08594490587711, 43.57179835438728, 46.62664443254471, 44.11731228232384, 45.86254723370075, 45.48207364976406, 46.62349820137024, 55.14846235513687, 60.74803188443184, 58.956234231591225, 59.55268442630768, 66.36869788169861, 62.80034355819225, 63.730769231915474, 63.24447512626648, 64.9541249871254, 61.37489564716816, 0.9438672743272036, 1.8578470149077475, 5.101118925958872, 0.4941228433744982, 34.47233162820339, 78.64677384495735, 65.99431157112122, 77.07327827811241, 71.25127628445625, 78.3993311226368, 49.580054953694344, 38.530703857541084, 50.187334567308426, 70.39040207862854, 36.8531508743763, 1.1253808625042439, 0.11824437067843974, 0.238725277595222, 0.13185443880502135, 0.14974643185269088, 0.21711150300689042, 0.13763478957116604], [0.07625589641975239, 0.06004291972203646, 0.14470558671746403, 0.035271188025944866, 0.019898088721674867, 0.06193333312694449, 0.015925132865959313, 0.05161395522009116, 0.04319552921515424, 0.8365853154100478, 38.173754811286926, 55.82339733839035, 43.683998733758926, 26.40673242509365, 30.381457842886448, 49.71106432378292, 66.08058974146843, 59.00448024272919, 59.93156969547272, 50.461653247475624, 58.08481939136982, 32.44407266378403, 0.18573908018879592, 0.5840159556828439, 2.6645523961633444, 0.1663902067230083, 6.369034415110946, 61.26609988510609, 56.371886506676674, 52.073180973529816, 51.40019528567791, 58.034643083810806, 54.266335889697075, 49.50716346502304, 39.18418139219284, 40.78725077211857, 40.6521338224411, 43.78459453582764, 43.262278363108635, 46.51316352188587, 43.74000392854214, 44.42064620554447, 36.28551833331585, 39.89272177219391, 40.29114939272404, 41.24652452766895, 38.254413083195686, 39.022526666522026, 36.09986029565334, 37.74339370429516, 34.99503158032894, 37.27603778243065, 35.0684018433094, 37.8208639472723, 35.97271531820297, 37.889271676540375, 35.793744921684265, 37.6797167211771, 38.296336233615875, 38.601167276501656, 39.3287218362093, 38.04780676960945, 37.53825031220913, 38.96727383136749, 37.19059556722641, 37.05070987343788, 37.5082091242075, 36.53573490679264, 35.45405454933643, 37.23932795226574, 38.71161974966526, 47.89287708699703, 47.13172473013401, 49.98959697782993, 50.26378646492958, 47.708400785923004, 51.02647013962269, 50.0211276859045, 52.450565323233604, 44.842522367835045, 36.916991248726845, 38.4077462553978, 38.466673493385315, 38.920661732554436, 38.08379843831062, 40.29039703309536, 38.309867307543755, 45.25231897830963, 52.47579216957092, 42.21734583377838, 38.7256333976984, 37.66189947724342, 41.748055815696716, 40.97658321261406, 38.660010918974876, 40.367810279130936, 38.842670917510986, 40.38642928004265, 38.412590995430946, 40.954608991742134, 48.889077231287956, 54.71813164651394, 52.522666454315186, 49.52856011688709, 50.63367761671543, 47.018038630485535, 46.22035503387451, 45.70093430578709, 42.28413484990597, 40.390764847397804, 38.85785490274429, 35.860374346375465, 37.13250808417797, 36.472152918577194, 37.22061775624752, 38.96460637450218, 38.12189519405365, 39.05848413705826, 38.24274770915508, 40.049653351306915, 37.159471437335014, 38.46284709870815, 38.11592951416969, 38.51123750209808, 37.75033213198185, 39.3607085198164, 39.62821416556835, 39.67085547745228, 38.914145082235336, 37.52076365053654, 38.32240283489227, 37.23318748176098, 39.80203203856945, 40.32462939620018, 38.91892522573471, 39.89507004618645, 39.01651158928871, 39.39150206744671, 40.0144824385643, 39.089490473270416, 38.910440281033516, 40.32484218478203, 39.009337574243546, 40.643314495682716, 53.8639260828495, 53.969788402318954, 58.22507746517658, 54.00319240987301, 50.53894869983196, 55.50431326031685, 63.808212876319885, 53.109415769577026, 68.696848154068, 26.434769220650196, 0.08800883646472357, 0.8200661174487323, 0.79092922154814, 0.38047776964958757, 35.21184414625168, 67.51199573278427, 55.04440873861313, 66.31214171648026, 61.221258491277695, 66.23743772506714, 34.2860010266304, 39.059905260801315, 37.093666568398476, 53.4849838167429, 17.350083701312542, 0.7449085253756493, 0.05793952848762274, 0.051758662884822115, 0.053412179040606134, 0.12256662390427664, 0.06005026327329688, 0.016027330311771948, 0.04320908454246819, 0.028241286927368492, 0.19218487024772912, 0.02152015451429179, 0.047108250510063954, 0.08487337385304272, 0.03040177900402341, 0.07456007413566113, 0.3253265790408477, 1.0077585303224623, 45.325332060456276, 63.79353046417236, 54.90686371922493, 31.361822336912155, 35.2596265822649, 58.421306535601616, 70.5734458565712, 65.34593716263771, 64.64691907167435, 55.80455794930458, 63.00839379429817, 34.05586637556553, 0.1177510131674353, 0.2965967362979427, 3.4257071278989315, 0.38792186707723886, 7.210333496332169, 66.0393999516964, 59.11174848675728, 53.677572682499886, 52.99235165119171, 59.730188101530075, 56.30678839981556, 51.53574921190739, 41.177512630820274, 43.20470005273819, 42.32680656015873, 46.776090413331985, 45.58144211769104, 48.9327596873045, 46.006810292601585, 45.698266848921776, 39.29301895201206, 41.73180028796196, 42.91429303586483, 42.40921653807163, 39.33259002864361, 41.8732400983572, 38.373631685972214, 40.16644388437271, 37.58664831519127, 38.5915993899107, 38.74923013150692, 39.78113315999508, 38.85662756860256, 39.02433916926384, 38.43764305114746, 40.341561287641525, 41.34632237255573, 41.50790870189667, 40.540222227573395, 39.85386125743389, 39.725777730345726, 42.275041937828064, 39.162146374583244, 37.78834909200668, 39.851060807704926, 39.600829035043716, 37.54307225346565, 39.6998555213213, 41.10677182674408, 49.97480437159538, 50.17637215554714, 52.8838674724102, 50.94161309301853, 50.88405378162861, 54.332794323563576, 52.72124759852886, 54.439872577786446, 44.6473990380764, 35.97228594124317, 38.51508669555187, 39.21613767743111, 38.79931144416332, 37.2964920848608, 39.12171274423599, 37.62707054615021, 46.677991077303886, 55.73633261024952, 41.945557817816734, 38.32604303956032, 38.0023118108511, 40.69429636001587, 38.560965433716774, 38.47524583339691, 39.49100732803345, 38.595953956246376, 40.11136204004288, 38.71715225279331, 41.66723035275936, 50.605262741446495, 57.372551411390305, 53.319567292928696, 53.570992201566696, 52.274414375424385, 49.43276345729828, 48.14249709248543, 47.38422118127346, 42.198810428380966, 41.44420512020588, 39.692643508315086, 38.44150364398956, 38.53773348033428, 38.07772636413574, 36.96058250963688, 39.38460163772106, 40.43866507709026, 40.22841855883598, 40.10122798383236, 40.61294272542, 39.54444006085396, 42.133381739258766, 41.81303232908249, 41.41968883574009, 40.70683568716049, 40.24459429085255, 41.754580065608025, 41.360260024666786, 42.384084686636925, 38.972593545913696, 39.635266587138176, 39.59220349788666, 40.36535941064358, 41.09712414443493, 40.43597862124443, 41.29583828151226, 41.608493104577065, 40.438820868730545, 41.238704547286034, 41.22011214494705, 41.139731258153915, 42.487948313355446, 41.85028932988644, 44.76896971464157, 54.84487384557724, 57.50799514353275, 61.19955785572529, 54.42147396504879, 54.54744100570679, 59.31613191962242, 65.89917227625847, 57.022958770394325, 71.5523113310337, 30.134662985801697, 0.09352836685138755, 1.4258690946735442, 0.28505818045232445, 0.21867403556825593, 39.369683638215065, 74.45403322577477, 59.70646217465401, 72.83687800168991, 64.83522936701775, 73.61448347568512, 37.455779537558556, 39.494229555130005, 42.753538861870766, 62.043500170111656, 22.40551482886076, 0.5441299709491432, 0.055342263949569315, 0.1189611888548825, 0.0031701837588116177, 0.1832151843700558, 0.02059798778645927, 0.022015662398189306, 0.19384287268621847, 0.16500635363627225, 0.38138381321914494, 0.06812144580180757, 0.18117855302989483, 0.20493616961175576, 0.16946168878348544, 0.18055295222438872, 0.4391866084188223, 1.0218048328533769, 52.695952355861664, 71.26677945256233, 63.198372200131416, 36.69841557741165, 45.25459885597229, 63.76427203416824, 76.28980591893196, 71.57439574599266, 71.59565940499306, 60.67132540047169, 71.10564529895782, 38.61646145582199, 0.2821894531371072, 1.9866966758854687, 8.156352583318949, 0.3382032865192741, 8.533332254737616, 71.7702828347683, 61.11756965517998, 56.9599961489439, 57.62012332677841, 61.98906809091568, 58.95627602934837, 56.16804264485836, 44.87553119659424, 46.977863386273384, 46.68166548013687, 49.52665261924267, 49.586951583623886, 50.98379462957382, 48.53145182132721, 47.76084557175636, 41.26452036201954, 45.34182697534561, 45.283416509628296, 45.09765587747097, 42.32396051287651, 44.260936975479126, 39.562204107642174, 42.388329058885574, 38.82706515491009, 42.07798071205616, 40.80968476831913, 42.56987951695919, 42.39070013165474, 42.59811580181122, 41.94744631648064, 42.999663054943085, 43.98098699748516, 42.85023607313633, 44.483213648200035, 41.08041264116764, 40.13052821159363, 43.4500452876091, 41.66015513241291, 40.07942475378513, 42.04758234322071, 40.91657303273678, 41.168655306100845, 42.400207221508026, 43.46841350197792, 51.730283573269844, 51.51223607361317, 55.562320947647095, 53.327619060873985, 52.6844047755003, 58.154815435409546, 53.771838024258614, 55.12630574405193, 47.51140035688877, 37.288056537508965, 39.46073815226555, 38.54801572859287, 40.13266749680042, 37.36645393073559, 38.69469925761223, 37.083711102604866, 47.32164613902569, 55.92088110744953, 43.164160028100014, 37.94582784175873, 37.96854302287102, 42.01855190098286, 40.10883517563343, 39.396445602178574, 39.11981284618378, 37.95718163251877, 39.53002743422985, 38.23600687086582, 41.39070399105549, 51.820350140333176, 59.9687734991312, 55.96129573881626, 56.70974537730217, 55.40057122707367, 50.965969786047935, 50.75411215424538, 50.22550351917744, 44.812492579221725, 44.06144008040428, 43.246577605605125, 39.7721466422081, 40.915756076574326, 41.00404053926468, 39.26840767264366, 42.47201196849346, 41.81245096027851, 42.48498447239399, 42.27140173316002, 44.217767491936684, 41.2481964379549, 44.35972787439823, 45.635710805654526, 43.58339913189411, 42.865332663059235, 43.9029885828495, 44.8810712993145, 43.5641797631979, 45.49324505031109, 41.582141518592834, 43.0075628310442, 40.88911570608616, 43.76253291964531, 45.9283597022295, 43.46014514565468, 42.61290080845356, 43.77981819212437, 42.39993743598461, 45.71414239704609, 44.565912410616875, 43.2961231470108, 45.183421075344086, 44.03631962835789, 46.69140435755253, 60.07602274417877, 60.11894904077053, 63.80669295787811, 57.049986720085144, 57.06700220704079, 63.06049659848213, 67.80099302530289, 60.77870763838291, 75.35928905010223, 33.04987795650959, 0.13541412045015022, 2.78309416025877, 1.7204912728630006, 0.4034777276683599, 43.14086727797985, 80.75179249048233, 62.806940004229546, 78.37101504206657, 67.91960746049881, 78.71168196201324, 47.88415655493736, 50.62081530690193, 53.078432232141495, 75.15111342072487, 30.546106807887554, 0.8708827500231564, 0.17632193863391876, 0.27006748015992343, 0.05316862843756098, 0.2250511769670993, 0.1306491019204259, 0.17664183396846056], [0.052654895262094215, 0.08169965352863073, 0.06055133540940005, 0.021933415737294126, 0.03650466715043876, 0.03989625234680716, 0.024532396491849795, 0.06074063872802071, 0.16339163325028494, 0.08032569327042438, 27.18993689864874, 59.41148780286312, 30.132698491215706, 19.640843980014324, 25.34978114068508, 42.72814862430096, 67.1983453631401, 59.85387906432152, 57.10804380476475, 51.5826690942049, 55.77989727258682, 43.919369503855705, 0.7553344534244388, 0.6526470417156816, 0.7626362366136163, 0.5621168995276093, 1.6761445649899542, 49.63417544960976, 61.50756932795048, 54.99759905040264, 58.58723223209381, 57.60081276297569, 56.82967834174633, 45.59485539793968, 38.99702623486519, 40.30447907745838, 44.72434490919113, 43.94092574715614, 45.66259816288948, 48.943752497434616, 47.64101140201092, 43.44349063932896, 38.95470790565014, 38.911021649837494, 38.63880045711994, 39.37354803085327, 39.817128628492355, 38.449213430285454, 39.37756061553955, 37.238457798957825, 36.56718201935291, 36.04732811450958, 35.61067834496498, 38.83347541093826, 35.75482361018658, 37.29671247303486, 36.60326488316059, 37.053293734788895, 36.156553253531456, 37.83319428563118, 38.47619578242302, 37.69225224852562, 38.1810200214386, 37.52976916730404, 39.25682969391346, 37.61775724589825, 37.57135413587093, 36.23894423246384, 39.08035196363926, 37.083547711372375, 40.405789241194725, 48.71050961315632, 47.40252859890461, 49.19175758957863, 48.65215614438057, 49.49258364737034, 50.34087672829628, 49.4316691160202, 49.60705630481243, 44.07008841633797, 36.76564536988735, 38.42625506222248, 37.98638306558132, 38.39117914438248, 38.615230321884155, 39.019524827599525, 38.40703569352627, 44.10766460001469, 49.12211112678051, 42.156362906098366, 39.6508913487196, 39.238089099526405, 38.272522911429405, 38.93748342990875, 38.00661318004131, 41.14638850092888, 39.43250946700573, 41.889788210392, 37.63525910675526, 43.46932165324688, 52.49135613441467, 51.417256370186806, 50.80502562224865, 49.50689747929573, 50.46541504561901, 51.06723055243492, 45.81732206046581, 42.07483448088169, 43.34699481725693, 39.502710700035095, 40.62016233801842, 39.764022678136826, 37.484137415885925, 37.29467958211899, 37.478460520505905, 37.97155246138573, 37.513088062405586, 39.52119290828705, 39.84497353434563, 38.9651345461607, 37.12137468159199, 36.77733734250069, 37.378370091319084, 37.2452974319458, 37.65202380716801, 38.28014150261879, 39.5739720761776, 40.507190600037575, 39.65196669101715, 36.802571788430214, 38.50008890032768, 36.649094223976135, 37.98937730491161, 38.847523257136345, 39.06630411744118, 37.82822035253048, 39.630326852202415, 39.13476884365082, 41.18961498141289, 39.725245758891106, 40.922873094677925, 40.79246409237385, 39.498131945729256, 39.516241773962975, 51.431782990694046, 54.32131513953209, 57.154724299907684, 56.855357363820076, 54.240345284342766, 47.89815880358219, 60.01423425972462, 50.562154054641724, 63.9239926636219, 5.7042239885777235, 0.34313749987632036, 1.0157922492362559, 0.1491677199373953, 0.7873336644843221, 44.83097478747368, 64.44689020514488, 58.939496129751205, 61.252994388341904, 51.00963704288006, 55.2967493981123, 33.849157467484474, 44.32632006704807, 43.903737142682076, 48.41351754963398, 9.886117614805698, 0.5001437687315047, 0.03643165095127188, 0.12671229051193222, 0.03896367328707129, 0.10321665205992758, 0.0649447123578284, 0.037061611874378286, 0.016673317913955543, 0.051967532926937565, 0.03364314237842336, 0.06099869089666754, 0.019288221446913667, 0.014320039063022705, 0.04523030518612359, 0.07302239609998651, 0.30098363058641553, 0.22842867620056495, 32.8149251639843, 67.91416615247726, 38.288953229784966, 19.227904938161373, 32.76858665049076, 56.981240808963776, 69.37846317887306, 63.23141522705555, 62.71336242556572, 58.22744093835354, 60.067013427615166, 47.826525047421455, 0.8255179936531931, 0.22896741604199633, 2.2447585221379995, 1.3173720915801823, 2.0569854229688644, 53.29661272466183, 62.2888758033514, 58.56634855270386, 61.04608029127121, 59.214931949973106, 59.368246123194695, 47.037178203463554, 41.63340836763382, 43.30847628414631, 45.89470870792866, 46.48202419281006, 47.93028607964516, 50.05718395113945, 49.0306082367897, 46.04212939739227, 41.171664744615555, 41.528872177004814, 40.44071316719055, 40.234961807727814, 41.91614359617233, 40.59380695223808, 39.0044092386961, 38.258064687252045, 38.79361554980278, 39.189972281455994, 38.269391879439354, 39.8186219483614, 37.82221667468548, 38.58920931816101, 39.1227462887764, 40.01474842429161, 38.97125221788883, 40.64177557826042, 41.35119371116161, 41.46693170070648, 40.63139833509922, 40.034799948334694, 40.43195463716984, 38.51973384618759, 39.4814470410347, 37.822247073054314, 40.832696333527565, 39.661291390657425, 42.122335731983185, 50.576502084732056, 50.615039616823196, 51.41477890312672, 51.22295379638672, 50.84756053984165, 52.53333628177643, 52.08367221057415, 52.229033410549164, 44.87904220819473, 37.740182876586914, 37.866495698690414, 39.339387863874435, 38.89296501874924, 39.40493434667587, 40.58542840182781, 37.99417644739151, 45.12704350054264, 51.90378986299038, 43.92121620476246, 39.07260797917843, 40.08508265018463, 38.51237364113331, 39.65822875499725, 38.72893922030926, 39.423321560025215, 38.05795222520828, 40.449437499046326, 39.2855029553175, 42.302955240011215, 55.27327425777912, 54.948543682694435, 53.40011157095432, 51.10240526497364, 53.01788628101349, 54.11372847855091, 48.300568610429764, 45.1752895116806, 47.31325998902321, 41.56801387667656, 42.96674162149429, 39.994206726551056, 39.648934453725815, 39.03719387948513, 38.867202401161194, 38.885433822870255, 40.647334679961205, 41.20224930346012, 41.79173827171326, 40.05328595638275, 39.981393814086914, 38.29139269888401, 39.84600327908993, 40.35025142133236, 39.99886527657509, 39.94498796761036, 41.76748797297478, 42.85617895424366, 42.30978727340698, 38.93780641257763, 40.521743819117546, 40.11360391974449, 38.924400731921196, 40.26209995150566, 40.5085851252079, 40.68515785038471, 42.49086655676365, 42.9011495411396, 42.47991554439068, 43.35980772972107, 42.50868380069733, 42.60862983763218, 41.21743328869343, 43.17322254180908, 52.841020971536636, 57.593087777495384, 59.6649532020092, 59.040038734674454, 54.377529323101044, 52.687326818704605, 64.08397167921066, 55.457822754979134, 64.45850998163223, 7.493487652391195, 0.4168787773232907, 2.942137001082301, 0.47124973323661834, 0.8162993914447725, 50.16273468732834, 71.08517959713936, 64.90989536046982, 70.19664287567139, 59.03316870331764, 65.82620859146118, 39.2730700224638, 49.98409487307072, 49.780748784542084, 59.54674534499645, 13.683232963085175, 0.5232899298425764, 0.03407106101803947, 0.11819938168628141, 0.05463051093101967, 0.15166013385169208, 0.08762582147028297, 0.06006318777508568, 0.15809418313438073, 0.1473536586854607, 0.12301311478950083, 0.10292531456798315, 0.10383304281276651, 0.06131031870609149, 0.12592193292221054, 0.19700510456459597, 0.5835389031562954, 0.21492182597285137, 39.2817335575819, 77.67018064856529, 46.063552647829056, 30.17644554376602, 36.881995126605034, 57.9018098115921, 77.45231553912163, 70.10021924972534, 69.67422410845757, 63.404210954904556, 64.83731165528297, 54.13015119731426, 1.3750793575309217, 1.2978765252046287, 4.99004946090281, 0.9303274133708328, 2.087196889333427, 55.23084953427315, 66.03167876601219, 61.58842898905277, 62.262448221445084, 61.15528263151646, 61.701168939471245, 51.697004958987236, 43.423807695508, 46.633647456765175, 49.35064606368542, 48.17350722849369, 50.20919479429722, 53.75153951346874, 51.5735799819231, 48.08291248977184, 42.20884568989277, 43.11566703021526, 43.73974174261093, 41.482583060860634, 45.00338293612003, 43.5983931273222, 42.97434501349926, 40.94560347497463, 41.34804368019104, 40.790575593709946, 40.1241597533226, 45.36863453686237, 40.295880138874054, 41.85084030032158, 41.796598210930824, 42.744354754686356, 40.33703953027725, 43.49022813141346, 42.567147463560104, 42.980899661779404, 42.93842934072018, 42.19025328755379, 44.0690852701664, 40.93958079814911, 41.150921657681465, 40.069788470864296, 44.911663457751274, 41.66593462228775, 44.64783601462841, 52.195230424404144, 53.68334457278252, 55.680718794465065, 55.16801990568638, 52.68565110862255, 57.02107787132263, 53.76168496906757, 54.684317260980606, 47.16290965676308, 38.19891706109047, 38.932034522295, 39.27772477269173, 38.47339153289795, 40.21242141723633, 40.17103023827076, 38.46165016293526, 47.202560529112816, 53.1103391200304, 43.836670741438866, 38.89390356838703, 40.0607867538929, 38.45322981476784, 39.07062828540802, 37.52529680728912, 42.756118923425674, 38.01889032125473, 41.71647571027279, 38.34449104964733, 45.635813400149345, 57.47611865401268, 57.625082060694695, 58.24167497456074, 54.94431830942631, 54.85802873969078, 57.24184602499008, 50.437463745474815, 47.608029171824455, 48.791764453053474, 43.70420224964619, 44.002626836299896, 42.10162304341793, 41.20964750647545, 41.64379321038723, 40.54584592580795, 41.79174967110157, 44.34990160167217, 43.293501287698746, 44.40462626516819, 43.543201088905334, 42.5114880502224, 41.14728905260563, 41.05284132063389, 43.67653973400593, 43.01379069685936, 39.863254353404045, 44.56103727221489, 45.373464077711105, 45.28219297528267, 42.186727076768875, 43.69087636470795, 40.70939674973488, 41.22621461749077, 42.61486530303955, 43.007372841238976, 43.23351010680199, 45.25431387126446, 43.968067690730095, 46.69323205947876, 45.147645995020866, 44.57995265722275, 44.34037171304226, 42.21340924501419, 44.205129370093346, 55.381462052464485, 59.12999510765076, 62.963746190071106, 61.405385211110115, 54.8236595839262, 54.74104441702366, 64.73805338144302, 55.568427219986916, 68.37747529149055, 8.829770497977734, 0.32418177172075957, 5.498222317546606, 2.1131912944838405, 1.0945664159953594, 54.2113072425127, 76.72226831316948, 66.98030546307564, 72.55260765552521, 62.30839155614376, 71.56023010611534, 45.9560564160347, 58.33413541316986, 57.58124761283398, 71.48282065987587, 18.783376291394234, 0.8094301912933588, 0.13533615041524172, 0.197423126664944, 0.15376640832982957, 0.2444589472725056, 0.1767344688414596, 0.31616280670277774], [0.07620524484082125, 0.05863252001290675, 0.047320690282504074, 0.08469858323223889, 0.0720015200204216, 0.05925444718741346, 0.03446014306973666, 0.03471688905847259, 0.2141205291263759, 0.016666052288201172, 26.377800777554512, 60.78920267522335, 48.98494228720665, 51.430548056960106, 33.30116607248783, 31.812533251941204, 57.470548152923584, 63.49945284426212, 55.142652466893196, 54.584971591830254, 50.827205032110214, 52.93056316673756, 5.921571850776672, 0.40982344653457403, 0.9623303648550063, 1.7676518484950066, 0.1604330021655187, 19.625555500388145, 70.46065270900726, 53.38458940386772, 58.32671441137791, 53.82586732506752, 52.48039752244949, 40.33336132764816, 41.28703415393829, 39.35859203338623, 44.550177454948425, 46.40985086560249, 52.26149506866932, 50.204133465886116, 51.14521376788616, 43.97060215473175, 39.51190620660782, 37.90032908320427, 39.25579994916916, 37.72570565342903, 39.27025817334652, 38.18957716226578, 38.57523746788502, 36.40138551592827, 38.74770641326904, 38.169062063097954, 36.02543368935585, 35.69923639297485, 37.17063903808594, 34.40423548221588, 37.34190344810486, 35.02826079726219, 38.092830553650856, 37.31703758239746, 40.73694907128811, 37.56796091794968, 37.73968890309334, 38.53323832154274, 38.87453980743885, 38.404007256031036, 36.7655161768198, 36.819602474570274, 37.837674245238304, 36.42350792884827, 42.12631791830063, 49.450964480638504, 47.80553117394447, 47.24042169749737, 48.4603576362133, 48.773483633995056, 49.9659014493227, 51.31223380565643, 50.07966734468937, 43.72783698141575, 37.82625585794449, 37.47717618942261, 38.1148237735033, 38.55278067290783, 38.401776775717735, 39.912621304392815, 40.036559253931046, 42.834641709923744, 50.1888582855463, 41.51960447430611, 41.12048149108887, 39.37208890914917, 40.685408636927605, 40.17788887023926, 38.921372294425964, 40.52299775183201, 37.89809860289097, 39.52539548277855, 40.01670531928539, 43.55705514550209, 51.39717824757099, 50.578911155462265, 53.16213794052601, 50.65010033547878, 48.550880178809166, 48.05616192519665, 49.431292936205864, 42.402160316705704, 40.61361528933048, 39.613562151789665, 38.943813890218735, 37.83133618533611, 37.739738300442696, 35.64392276108265, 37.57209129631519, 37.93470583856106, 37.87783049046993, 39.94309946894646, 38.960947170853615, 37.27140583097935, 36.90097130835056, 36.452979147434235, 36.06152795255184, 36.689448058605194, 39.61254000663757, 38.270121440291405, 38.76650780439377, 38.213713467121124, 38.69073607027531, 37.89059400558472, 39.22094061970711, 37.937130108475685, 39.45492826402187, 39.15273427963257, 40.24535425007343, 38.890536949038506, 38.26649263501167, 38.68214853107929, 38.18692870438099, 38.551636934280396, 40.5266759544611, 40.31601905822754, 40.385980904102325, 39.41977635025978, 45.99043697118759, 53.891900181770325, 54.5264433324337, 57.69575446844101, 59.61150906980038, 50.07267192006111, 50.041289404034615, 58.34427706897259, 39.443403482437134, 0.49035374249797314, 0.2177549450425431, 1.4642500039190054, 0.24138758395565674, 1.2797286990098655, 49.891919419169426, 59.324195086956024, 55.92249982059002, 51.57059334218502, 46.70113563537598, 48.863470405340195, 26.75052087754011, 43.02338518202305, 44.76909130811691, 38.099123015999794, 3.986060209572315, 0.37989539152476937, 0.07786717324052006, 0.1001641689799726, 0.05264944789814763, 0.11776107668993063, 0.04508033198362682, 0.0689903819875326, 0.009381555573781952, 0.042448316380614415, 0.021914698772889096, 0.07638693001354113, 0.07308161206310615, 0.042762166922329925, 0.0047938212810549885, 0.046946076399763115, 0.35715254314709455, 0.04631673145922832, 30.133956223726273, 68.3565080165863, 51.28659278154373, 43.67386847734451, 32.72811122238636, 45.480549931526184, 64.01599332690239, 69.03246894478798, 59.01982381939888, 60.2918853610754, 55.600565895438194, 60.479523092508316, 6.264636442065239, 0.41874061804264784, 1.7742148088291287, 3.2321160659193993, 0.19718375435331836, 22.230412624776363, 73.22157695889473, 55.76652579009533, 59.308855310082436, 56.23061768710613, 54.52336549758911, 43.26759047806263, 42.755142375826836, 41.68850541114807, 46.62665583193302, 49.61052171885967, 52.97120578587055, 51.92891791462898, 53.3492399007082, 44.951040744781494, 42.144743129611015, 39.91884537041187, 41.593358516693115, 38.93434479832649, 39.982925131917, 39.84532691538334, 39.93481211364269, 37.585496976971626, 39.98051606118679, 40.046951696276665, 39.770934507250786, 37.83104360103607, 39.15398061275482, 37.886459827423096, 38.88474605977535, 38.070696741342545, 41.14316627383232, 39.707306921482086, 41.64373621344566, 37.60788157582283, 41.148117408156395, 40.95859877765179, 41.595201417803764, 39.88327547907829, 39.670209512114525, 36.77041031420231, 40.00428758561611, 39.442597925662994, 43.65438312292099, 50.42348429560661, 50.59436872601509, 50.16487397253513, 51.92393638193607, 50.71760751307011, 53.95003326237202, 52.422215044498444, 50.368923023343086, 42.44201637804508, 36.76651172339916, 38.76006714999676, 37.685173228383064, 37.48468078672886, 38.83100554347038, 40.419859886169434, 39.58591103553772, 43.774312287569046, 52.73072429001331, 42.53192335367203, 41.16392455995083, 38.832198679447174, 40.082650780677795, 38.91056567430496, 39.115583673119545, 39.20945763587952, 39.44241173565388, 39.51175041496754, 41.29455015063286, 43.927713856101036, 53.917651399970055, 54.06346097588539, 54.184476882219315, 51.65766566991806, 52.1603786945343, 50.585598796606064, 50.39570018649101, 43.80374550819397, 44.068192318081856, 41.9222878664732, 40.78577645123005, 40.33657595515251, 40.64383886754513, 37.103561237454414, 39.71304081380367, 39.26126025617123, 39.79010067880154, 41.0127192735672, 40.88498912751675, 38.77994008362293, 38.56615595519543, 39.32616837322712, 38.98202084004879, 37.33005568385124, 41.485208719968796, 41.66609801352024, 41.55962772667408, 41.09685815870762, 40.645704567432404, 40.75596325099468, 40.18574684858322, 39.89983879029751, 39.68415476381779, 41.639552637934685, 42.127343863248825, 40.98984830081463, 40.772051587700844, 39.91791822016239, 41.49086281657219, 41.762890219688416, 43.27481389045715, 40.28921149671078, 42.27270886301994, 41.00398734211922, 48.45560409128666, 57.4959421902895, 57.80654512345791, 61.00543387234211, 60.57356424629688, 52.17412255704403, 53.68357256054878, 59.03006426990032, 42.775988057255745, 0.8362230286002159, 0.356912087299861, 2.4426606902852654, 0.5132212419994175, 1.315008974634111, 54.57620166242123, 65.38066729903221, 62.219863906502724, 56.51530221104622, 48.77172812819481, 56.110259145498276, 37.09501549601555, 49.0089949965477, 51.85731075704098, 49.427075162529945, 5.316256256774068, 0.3661260288208723, 0.12491430417867377, 0.08142606078763492, 0.032421552459709346, 0.031082586319826078, 0.09204034591675736, 0.04806576944247354, 0.2007538705947809, 0.14671149314381182, 0.1413813588442281, 0.1298432779731229, 0.23528080695541576, 0.08804103825241327, 0.11067927349358797, 0.2083298476645723, 0.4177695623366162, 0.24152740457793698, 35.35357654094696, 77.93416008353233, 61.390224024653435, 63.134900406003, 42.73729473352432, 51.34366191923618, 65.13298138976097, 77.10843399167061, 63.496838584542274, 67.28702500462532, 60.26023305952549, 65.64737498760223, 7.456884691491723, 0.7004342274740338, 6.286279605701566, 3.061153977178037, 0.32746829849202186, 23.770371191203594, 74.50858309864998, 55.6145491451025, 61.32203288376331, 60.26446983218193, 57.010206654667854, 44.94903065264225, 44.16396617889404, 44.022347778081894, 49.02389399707317, 50.97469411790371, 56.21201008558273, 54.88540627062321, 56.85925975441933, 47.02710874378681, 42.89400972425938, 42.105810418725014, 44.00229625403881, 41.495164185762405, 42.84357503056526, 41.95102572441101, 42.2017552703619, 39.58449751138687, 42.303631603717804, 42.6391725987196, 42.48509846627712, 41.5463550388813, 42.8610160946846, 40.44624947011471, 41.091272458434105, 39.474497213959694, 43.45796786248684, 42.308571338653564, 45.6788194924593, 41.13842412829399, 42.29923903942108, 42.73253358900547, 43.921983763575554, 43.114314302802086, 40.400336533784866, 40.06643325090408, 44.3480359017849, 41.42942011356354, 46.59799017012119, 52.59517416357994, 53.30564484000206, 52.3355682939291, 53.98179195821285, 53.31858694553375, 56.045541018247604, 57.29454919695854, 53.45277674496174, 44.387789368629456, 37.28549167513847, 38.30617770552635, 38.042973428964615, 37.92269088327885, 38.48881870508194, 41.06361374258995, 41.00908286869526, 43.89410845935345, 54.19761277735233, 43.198643177747726, 44.11553397774696, 37.93939098715782, 41.315908804535866, 40.513775646686554, 38.02647091448307, 40.26441402733326, 38.59856441617012, 40.092845633625984, 41.27625793218613, 46.07639975845814, 56.633266881108284, 54.48596030473709, 58.350740522146225, 55.44808387756348, 54.4703583419323, 51.49645172059536, 52.32589781284332, 47.37569443881512, 45.36766178905964, 44.28274780511856, 41.88408091664314, 42.06455983221531, 42.31795683503151, 38.264976516366005, 41.40312932431698, 40.69844573736191, 41.34094946086407, 44.73566450178623, 42.91434623301029, 41.48120753467083, 40.87480187416077, 41.37869283556938, 39.36608903110027, 41.42543412744999, 45.71008041501045, 45.04247143864632, 44.05495382845402, 42.834729105234146, 44.17385324835777, 43.21248583495617, 42.05745421350002, 44.390369430184364, 43.839440792798996, 42.97860838472843, 44.56656977534294, 43.345277309417725, 42.028172984719276, 43.47892753779888, 44.1252576559782, 43.74774031341076, 46.44314847886562, 43.2926045358181, 45.079591646790504, 43.911051750183105, 50.17339691519737, 59.6900774538517, 57.97407813370228, 63.36165323853493, 63.011388033628464, 54.27203558385372, 57.69832693040371, 57.49974578619003, 48.09427008032799, 1.4042237936519086, 0.25218528346158564, 4.9863783828914165, 0.6317080871667713, 1.6818189667537808, 60.73028303682804, 71.1371760070324, 68.83497834205627, 62.52129413187504, 56.994361504912376, 64.13897752761841, 39.49830673635006, 53.39813567698002, 62.10791431367397, 62.991803884506226, 7.4174670316278934, 0.4815396701451391, 0.31730746559333056, 0.3328364307526499, 0.14289271290181205, 0.19248318392783403, 0.19560563669074327, 0.13557498838054016], [0.11358581323293038, 0.08132711765938438, 0.05393854728026781, 0.020164406560070347, 0.06386997862136923, 0.07214399010990746, 0.09299365687184036, 0.07226965797599405, 0.3536246996372938, 0.03744595902389847, 17.109655402600765, 59.93079073727131, 46.72474756836891, 47.90659435093403, 80.48304051160812, 46.11522987484932, 48.378776013851166, 61.39605291187763, 52.48262420296669, 59.39601503312588, 47.5235179066658, 56.39125406742096, 18.704496324062347, 0.4473793547367677, 1.1375134927220643, 1.6935432376340032, 0.23429047025274485, 1.9560332712717354, 57.29919634759426, 58.18025127053261, 59.74400416016579, 54.36605013906956, 48.30722585320473, 38.92900228500366, 42.180742397904396, 44.2096359282732, 50.47866873443127, 50.81162966787815, 54.17286090552807, 52.054675966501236, 53.232434168457985, 41.35661981999874, 39.88087020814419, 38.45690421760082, 38.40082302689552, 40.61187118291855, 45.3731144964695, 43.29542398452759, 41.88519045710564, 40.15915207564831, 39.32153262197971, 36.930214539170265, 36.3679663091898, 35.158768594264984, 37.73464277386665, 35.881812795996666, 37.38236367702484, 36.037296652793884, 38.240562826395035, 37.95166052877903, 39.28342826664448, 42.47057184576988, 41.49569235742092, 39.836739376187325, 38.95058512687683, 36.00388504564762, 38.00936423242092, 36.918860748410225, 37.502539828419685, 38.00877146422863, 44.79118712246418, 47.80111961066723, 50.52647016942501, 48.45367759466171, 50.02071350812912, 49.33831572532654, 48.216627314686775, 50.533754378557205, 48.35919566452503, 43.14595900475979, 38.222126215696335, 39.60144840180874, 37.525889575481415, 40.83925478160381, 40.02354875206947, 41.323694586753845, 38.473243340849876, 42.64014154672623, 50.09607866406441, 41.15154482424259, 39.5224354416132, 40.77590838074684, 38.60675297677517, 40.077540054917336, 39.33073952794075, 40.16430079936981, 38.9911213517189, 40.43583802878857, 40.82953490316868, 45.192415192723274, 52.540339305996895, 52.21483737230301, 52.39146709442139, 49.66187596321106, 49.46259185671806, 47.98317164182663, 49.182090908288956, 48.19954723119736, 39.29341033101082, 37.63057015836239, 34.93516579270363, 36.646555960178375, 36.71024814248085, 36.53975509107113, 38.309601321816444, 36.94986328482628, 38.56451444327831, 38.42163071036339, 36.9848708063364, 38.77906613051891, 35.678056329488754, 36.60839840769768, 35.431939736008644, 36.40805795788765, 37.441028729081154, 37.10916593670845, 37.657054737210274, 36.603029295802116, 37.318755090236664, 37.03039616346359, 37.378560081124306, 39.36155207455158, 38.0168916285038, 37.359188720583916, 39.67000812292099, 40.879031047225, 44.43011149764061, 45.02155736088753, 43.15357379615307, 41.44433431327343, 38.15125621855259, 41.034100726246834, 39.070932269096375, 41.17214351892471, 39.08838093280792, 52.64522507786751, 52.16623418033123, 58.03224541246891, 54.56850327551365, 60.829647704958916, 47.95393221080303, 59.60151560604572, 16.955505274236202, 0.061946075802552514, 0.7783103361725807, 2.116513978689909, 0.24663951073307544, 2.732506049796939, 59.64245080947876, 60.851830914616585, 58.4344120323658, 61.82953365147114, 61.264374777674675, 40.81273600459099, 22.648352198302746, 48.95999662578106, 58.7444031983614, 35.94648912549019, 1.34090042905882, 0.3098651790060103, 0.03418122912989929, 0.11589453075430356, 0.0605353458377067, 0.028538259175547864, 0.05535620519367512, 0.050583891352289356, 0.02131557779648574, 0.15130501618841663, 0.0376392959151417, 0.06952319206902757, 0.1145557186100632, 0.07498212609789334, 0.07888620137237012, 0.10642704932251945, 0.3195423394208774, 0.1155174158338923, 22.59959701448679, 69.47484120726585, 52.09564916789532, 52.61230744421482, 60.68096548318863, 45.08129395544529, 59.04081769287586, 67.8327365219593, 58.18125821650028, 65.40527477860451, 52.10753113031387, 63.73520739376545, 19.85231213271618, 0.3230535291368142, 1.9150251592509449, 2.2858682787045836, 0.6192182167433202, 2.927398541942239, 58.41671638190746, 58.441320061683655, 60.05026392638683, 56.747393757104874, 50.253329426050186, 41.943585723638535, 45.922952592372894, 46.89544960856438, 51.5701487660408, 52.716946229338646, 55.24923674762249, 54.750646501779556, 53.29139560461044, 44.55590754747391, 41.55720345675945, 39.62091475725174, 39.52759176492691, 43.182991817593575, 45.953198969364166, 46.07860743999481, 43.72481994330883, 41.279404163360596, 40.26454322040081, 38.18709969520569, 37.61722147464752, 37.370052337646484, 40.923507660627365, 38.285643607378006, 40.62644340097904, 37.04709246754646, 39.416846707463264, 38.68205353617668, 40.02395533025265, 43.272705003619194, 43.11969481408596, 41.84701010584831, 42.14041896164417, 39.05289463698864, 40.12233205139637, 39.03074562549591, 39.9791519343853, 40.86301490664482, 47.85308562219143, 49.54587198793888, 53.77908803522587, 52.163205742836, 51.907395869493484, 53.400430753827095, 51.185571402311325, 52.06027686595917, 50.59758335351944, 44.349346831440926, 40.107098668813705, 39.01977941393852, 38.65289390087128, 40.9827046841383, 39.47212994098663, 40.65932683646679, 38.12906160950661, 46.308502703905106, 51.19877569377422, 40.49908943474293, 41.053688675165176, 39.32526022195816, 40.22356241941452, 40.144101083278656, 38.29936847090721, 40.233058109879494, 38.05884137749672, 40.04963435232639, 40.983593836426735, 44.38102953135967, 54.21147063374519, 53.084006533026695, 53.27646240592003, 50.59165187180042, 52.4843493103981, 49.83411692082882, 53.47413919866085, 50.29317028820515, 40.9701843559742, 38.863782584667206, 38.670574352145195, 39.51208099722862, 39.68558728694916, 37.915220484137535, 39.43061716854572, 40.230702236294746, 40.39618715643883, 40.88912710547447, 39.740672931075096, 41.22197404503822, 38.853226751089096, 39.905470088124275, 37.14863821864128, 39.46201868355274, 40.70213533937931, 39.831286668777466, 40.063587203621864, 39.82232674956322, 39.480732679367065, 38.328877687454224, 39.04498726129532, 39.93975564837456, 39.89900663495064, 40.218455493450165, 41.835230737924576, 43.042855337262154, 45.57569682598114, 45.95455549657345, 45.130657106637955, 44.39340926706791, 40.19265867769718, 43.83240357041359, 41.20489776134491, 43.48051965236664, 43.37285242974758, 55.105897039175034, 55.19181042909622, 60.9466852247715, 57.88069434463978, 60.72451114654541, 49.550344347953796, 59.44658271968365, 21.582327000796795, 0.02625019747938495, 2.5753735564649105, 2.8252766467630863, 0.7945155759807676, 2.842594929970801, 62.75079421699047, 65.9752593934536, 60.25444217026234, 65.50042927265167, 63.27320918440819, 48.94317112863064, 26.800423599779606, 49.692126139998436, 65.99444076418877, 45.918047055602074, 2.101206025108695, 0.26296031777746975, 0.02179199393140152, 0.09870224937913008, 0.07725748408120126, 0.011948848477913998, 0.02787151370284846, 0.07486966846045107, 0.15943096921546385, 0.22452644887380302, 0.18075742875225842, 0.1822395421913825, 0.20351623330498114, 0.17018188373185694, 0.21386739739682525, 0.20370147336507216, 0.6144169962499291, 0.21348438982386142, 23.308386281132698, 81.88241422176361, 58.048911318182945, 64.87279415130615, 82.67027154564857, 63.804481476545334, 63.87430652976036, 71.73707261681557, 63.105896562337875, 72.78572514653206, 55.623144283890724, 72.24923953413963, 24.982082471251488, 0.5509668728336692, 4.793539205566049, 4.273248799145222, 0.3625698055839166, 2.9630779149010777, 58.215441182255745, 55.29972083866596, 63.12107674777508, 59.50907036662102, 53.68396773934364, 44.21251617372036, 46.84980645775795, 47.73492716252804, 53.52251820266247, 54.64530475437641, 57.68430948257446, 56.089926436543465, 56.56151533126831, 47.24478766322136, 43.668313175439835, 42.08893172442913, 41.62654593586922, 45.80653063952923, 48.65508198738098, 48.907760828733444, 46.75663165748119, 44.45568032562733, 42.88242794573307, 43.123274222016335, 39.6722462028265, 40.54938353598118, 42.2386284917593, 41.32155530154705, 43.377108201384544, 39.70365151762962, 42.37862817943096, 43.057940527796745, 43.788588121533394, 46.390198320150375, 44.11095142364502, 44.22347478568554, 42.99647122621536, 41.081856563687325, 42.24086657166481, 42.34389044344425, 42.774589732289314, 43.05705137550831, 49.97534394264221, 54.16605167090893, 56.85833640396595, 55.51237262785435, 56.33295379579067, 56.00826121866703, 52.68052138388157, 56.30580045282841, 52.56012484431267, 45.46049080789089, 39.785966500639915, 38.74300226569176, 38.43745306134224, 42.780661806464195, 38.963443636894226, 42.48425491154194, 38.30031082034111, 45.51227442920208, 55.16532205045223, 42.93026737868786, 42.112121880054474, 41.88720054924488, 39.550576731562614, 40.15445172786713, 39.18848656117916, 40.23772805929184, 39.08634424209595, 41.47298477590084, 40.79375222325325, 46.674293875694275, 56.33173406124115, 57.15023294091225, 56.473348662257195, 54.48444038629532, 53.683428168296814, 52.92357914149761, 55.576684176921844, 53.99287596344948, 43.64885821938515, 41.15036688745022, 40.309335216879845, 41.10737979412079, 40.55379889905453, 39.56749342381954, 42.24372781813145, 42.052225694060326, 42.513562738895416, 42.78225392103195, 39.91180434823036, 43.16832460463047, 41.3685055822134, 42.29519985616207, 40.22170051932335, 43.552214205265045, 43.61969478428364, 41.89551830291748, 43.410645201802254, 41.071171537041664, 42.62978330254555, 40.75763896107674, 41.58450499176979, 42.640681117773056, 41.64584890007973, 41.918024495244026, 43.7976848334074, 47.52699092030525, 48.47555302083492, 48.411085680127144, 48.25170323252678, 46.55043952167034, 42.72277191281319, 45.983829125761986, 43.86636234819889, 45.60313895344734, 44.33646932244301, 58.63359734416008, 57.49447546899319, 63.59430335462093, 60.284452959895134, 63.237483501434326, 51.98678120970726, 59.837703332304955, 26.40898760408163, 0.2852481108857319, 2.0726531697437167, 9.658673219382763, 1.2787384958937764, 3.214308558963239, 68.57856050133705, 70.94001218676567, 66.23778730630875, 73.4060950577259, 69.33207526803017, 52.77328580617905, 31.492351032793522, 57.88804695010185, 72.67383635044098, 59.23268459737301, 3.1810643803328276, 0.5292121495585889, 0.1549777269246988, 0.18480320228263736, 0.16007783997338265, 0.09841073377174325, 0.1522667653625831, 0.12986903049750254], [0.053561031600111164, 0.028529128903755918, 0.012296487147978041, 0.05906385253183544, 0.03337177236971911, 0.03919022870832123, 0.018511203961679712, 0.024775954516371712, 0.08791557076619938, 0.07675191081943922, 5.798511179164052, 58.71884196996689, 52.8655144572258, 51.46521359682083, 87.49727413058281, 56.63363166153431, 37.20557436347008, 59.346895068883896, 55.339375510811806, 58.60164485871792, 48.41692216694355, 53.92442263662815, 32.50512398779392, 0.04515391592576634, 1.0022653313353658, 2.354453173466027, 1.7904186830855906, 0.7218109897803515, 26.48172900080681, 58.2763747125864, 57.19796597957611, 53.32620553672314, 41.80774301290512, 43.19952853024006, 45.041449293494225, 48.795993626117706, 52.22342491149902, 52.23081931471825, 53.71081329882145, 53.3288311958313, 50.09179629385471, 40.363942086696625, 37.10496336221695, 38.98190304636955, 43.473486229777336, 50.17911180853844, 50.5169402807951, 49.5572903752327, 48.854681476950645, 44.673556834459305, 41.226803585886955, 39.419624358415604, 36.58075489103794, 37.71899901330471, 38.952602818608284, 36.49572305381298, 37.090132758021355, 35.99633865058422, 35.10418452322483, 37.77634933590889, 37.194494158029556, 36.39119826257229, 36.94980628788471, 38.59201356768608, 38.95452171564102, 38.639036044478416, 38.43983173370361, 37.02916122972965, 38.684458807110786, 40.465199053287506, 43.6937490105629, 47.2175545245409, 49.60741348564625, 51.205303743481636, 48.052635714411736, 46.76905319094658, 49.93454173207283, 50.35519436001778, 46.99083968997002, 42.22486563026905, 38.534313663840294, 38.84824521839619, 38.44386711716652, 38.76931965351105, 37.74149760603905, 40.306967943906784, 40.52975378930569, 42.49017499387264, 46.47238031029701, 42.27105975151062, 38.898520320653915, 41.72295816242695, 39.51556161046028, 40.01768946647644, 38.852968364953995, 38.78698490560055, 38.936430886387825, 41.08172357082367, 40.634514167904854, 43.52318376302719, 49.747675359249115, 51.77340365946293, 48.45465034246445, 49.98072825372219, 50.89621692895889, 49.54939819872379, 48.862091079354286, 50.342286452651024, 45.01186028122902, 37.5760392844677, 34.06087450683117, 36.316650062799454, 36.95869781076908, 35.16310416162014, 36.71599343419075, 38.103188797831535, 38.64814415574074, 38.93220171332359, 37.6686555147171, 37.05702893435955, 35.166178196668625, 35.19301615655422, 35.18088340759277, 35.75219415128231, 33.979011699557304, 35.880448669195175, 34.86160174012184, 37.98777759075165, 36.150883957743645, 37.739403918385506, 36.28957651555538, 38.291396498680115, 36.51751108467579, 39.44001026451588, 38.94877262413502, 42.99814313650131, 47.0623404532671, 52.11637705564499, 49.49877731502056, 50.02616621553898, 43.86061705648899, 41.99500076472759, 38.01651544868946, 39.22244533896446, 39.48704794049263, 45.07079131901264, 49.75206792354584, 55.62536336481571, 54.29852016270161, 56.09196312725544, 48.58028680086136, 48.86161990463734, 2.898080265149474, 0.21018278261180967, 2.2556532500311732, 0.11154193110996857, 0.8082691754680127, 6.859241835772991, 63.90107989311218, 58.106664419174194, 62.386625558137894, 60.70271171629429, 57.98708103597164, 39.35569278895855, 33.09349961578846, 45.33120274543762, 59.73199300467968, 25.38571771234274, 0.5737860139925033, 0.23346647853031754, 0.08930169482482597, 0.162382579583209, 0.06549299621838145, 0.07439321707352065, 0.02006617589358939, 0.12064541879226454, 0.02671784513950115, 0.009509623359917896, 0.011304374856990762, 0.08213496766984463, 0.09157727545243688, 0.02452952066960279, 0.020367330143926665, 0.013893201175960712, 0.13300561375217512, 0.1184377892059274, 8.812665715813637, 68.64596128463745, 56.47576533257961, 56.942935064435005, 80.3338073194027, 56.25574953854084, 45.64434014260769, 66.60165578126907, 60.18009535968304, 65.07191106677055, 52.81780041754246, 60.97389556467533, 34.85948145389557, 0.1275379743310623, 2.6003470038995147, 3.6853792564943433, 2.4609982687979937, 0.6376870069652796, 30.386173389852047, 57.90200740098953, 60.477395206689835, 54.75731894373894, 43.217353373765945, 42.802613228559494, 47.40058310329914, 50.90741492807865, 55.74339643120766, 53.60443040728569, 56.47307127714157, 54.88339617848396, 52.350896671414375, 41.718402206897736, 40.19365802407265, 40.495897606015205, 44.876781329512596, 52.52265505492687, 53.411670550704, 52.267038971185684, 50.155914053320885, 47.06187687814236, 44.79785956442356, 42.544063702225685, 39.71013396978378, 38.95892567932606, 40.329899713397026, 38.32291200757027, 39.077167734503746, 37.659482806921005, 37.65605919063091, 39.561698734760284, 40.08659116923809, 39.28372845053673, 39.24949608743191, 39.11381296813488, 39.70954120159149, 42.05609008669853, 39.964245334267616, 39.12027642130852, 41.621948182582855, 40.869227573275566, 45.28159260749817, 49.743609577417374, 52.762239798903465, 52.254176661372185, 50.074115842580795, 50.12010857462883, 52.38184601068497, 52.940157651901245, 50.50592087209225, 43.71099628508091, 38.71561333537102, 39.62829016149044, 38.57997581362724, 38.24163056910038, 38.239761069417, 39.66517858207226, 40.97803473472595, 41.71472780406475, 49.56402741372585, 43.02536487579346, 39.029514491558075, 41.29860073328018, 39.60171818733215, 39.833034574985504, 40.12575566768646, 37.907468900084496, 38.46598193049431, 40.86881719529629, 42.07983121275902, 42.6069351285696, 50.76397642493248, 55.786117538809776, 51.85056231915951, 51.89568109810352, 51.775459349155426, 52.50161178410053, 51.74932815134525, 52.36147530376911, 45.660303086042404, 39.02318023145199, 36.625923067331314, 36.961247473955154, 38.09519782662392, 38.00185203552246, 39.76421266794205, 39.80014353990555, 39.53622110188007, 40.907909497618675, 39.9083237349987, 39.595433324575424, 37.63714760541916, 38.81783165037632, 37.42730766534805, 37.621743232011795, 37.12156467139721, 38.88671055436134, 38.05799022316933, 39.43499073386192, 38.989897817373276, 40.933763310313225, 39.6515791118145, 40.231310203671455, 38.20806697010994, 40.62850669026375, 41.60592824220657, 46.6455902159214, 49.315752536058426, 53.120571970939636, 52.460083812475204, 52.87603609263897, 46.66926294565201, 43.5241337120533, 39.364736303687096, 42.04856649041176, 40.419947281479836, 49.299656599760056, 52.35298655927181, 59.44593295454979, 56.360756903886795, 60.70796303451061, 51.3522532582283, 52.870853170752525, 5.472369454801083, 0.13757304288446903, 4.939764384180307, 2.455350821837783, 0.7812219299376011, 6.7679940070956945, 68.46366226673126, 63.36375832557678, 67.51375123858452, 67.69001618027687, 62.83090151846409, 48.19887466728687, 34.487245827913284, 48.94430726766586, 66.70596018433571, 32.742531448602676, 0.6537591945379972, 0.18473749252734706, 0.06608796858927235, 0.10998106095939875, 0.02235143412690377, 0.07000908357440494, 0.006393301200660062, 0.09616612296667881, 0.18254744441946968, 0.10084044362884015, 0.1256839113193564, 0.15310752962250262, 0.12560067203594372, 0.11111315528978594, 0.18163212400395423, 0.0793868319306057, 0.3965423576300964, 0.25138091412372887, 9.147281460464, 77.5721687078476, 65.15894919633865, 64.10645127296448, 90.98849639296532, 65.4929056763649, 52.952556386590004, 69.67462688684464, 66.93164527416229, 69.96952146291733, 61.099687814712524, 65.48095911741257, 43.54724407196045, 0.13370136235607788, 3.1905945064499974, 7.759342761710286, 3.384448941797018, 0.7757463643793017, 31.081192195415497, 62.93215848505497, 61.32427476346493, 58.47332954406738, 44.6402820199728, 47.4483959376812, 47.03586347401142, 54.102336689829826, 57.860848009586334, 55.715920105576515, 56.95460043847561, 58.267543986439705, 54.22575406730175, 44.36447761952877, 40.92673748731613, 44.74124640226364, 46.986903101205826, 54.832915887236595, 53.73320549726486, 54.59600239992142, 54.016446098685265, 50.5006505548954, 45.78025884926319, 45.925756841897964, 41.278408616781235, 42.10883505642414, 43.80422808229923, 41.58602871000767, 42.5866936147213, 40.14858864247799, 40.15678860247135, 42.589015290141106, 42.09891378879547, 41.49338588118553, 40.88368579745293, 41.87473721802235, 43.92440043389797, 44.759933799505234, 44.010386019945145, 41.68605454266071, 44.48422819375992, 43.374596536159515, 49.52013596892357, 51.11630491912365, 56.30763195455074, 55.34274213016033, 52.08141513168812, 52.24903553724289, 54.8722779750824, 56.543880477547646, 51.7804978787899, 43.92527058720589, 38.94234336912632, 39.73637156188488, 37.61260852217674, 41.02564997971058, 38.46621751785278, 39.134818241000175, 41.40170060098171, 43.76494958996773, 49.50527496635914, 44.20811980962753, 40.05597621202469, 43.166227117180824, 39.89173382520676, 41.857706531882286, 40.30270077288151, 38.87960113584995, 37.77792625129223, 42.33211487531662, 41.05333909392357, 44.11651432514191, 52.63257935643196, 57.369617968797684, 54.0397122502327, 55.52178472280502, 56.66684567928314, 55.22424928843975, 54.495326802134514, 54.81236658990383, 49.384354054927826, 42.55210027098656, 38.14063958823681, 41.070031598210335, 40.65448209643364, 39.51251417398453, 41.478844061493874, 42.457796931266785, 41.92704901099205, 44.28520627319813, 40.761290565133095, 42.37792141735554, 39.83636699616909, 41.14399082958698, 40.00884734094143, 39.35310132801533, 38.502501770853996, 41.653786674141884, 40.65266579389572, 43.88578310608864, 40.88998205959797, 43.796202912926674, 40.89862659573555, 42.065095603466034, 39.92095805704594, 43.09740900993347, 42.54863865673542, 50.05507506430149, 51.10749699175358, 56.82735286653042, 54.30198557674885, 55.39297543466091, 48.38507227599621, 46.63591593503952, 41.3140507042408, 44.412605836987495, 42.91528478264809, 51.75657816231251, 55.08283227682114, 60.96183501183987, 59.3766550719738, 62.61356458067894, 53.10732588171959, 54.44039314985275, 7.868104325607419, 0.22744294081348926, 6.029280871152878, 9.140700213611126, 1.6934430180117488, 7.635038606822491, 73.42248737812042, 70.45117601752281, 73.37930649518967, 72.12944716215134, 68.87386545538902, 54.79352720081806, 45.165926814079285, 55.4975838214159, 72.88423106074333, 45.88538020849228, 1.1894553992897272, 0.4889761679805815, 0.22469267511041835, 0.2786422544158995, 0.16188327746931463, 0.3157680731965229, 0.09020984609378502, 0.18206774984719232], [0.09515338082564995, 0.03601548422011547, 0.07070838706567883, 0.04152863584749866, 0.054498865065397695, 0.04382478138722945, 0.013849883871444035, 0.04010511496744584, 0.10758791671833023, 0.06272499318583868, 1.2722985539585352, 52.39510349929333, 50.95394343137741, 41.38931706547737, 67.10921734571457, 57.181368470191956, 40.244567692279816, 56.09040521085262, 56.51670053601265, 56.097009256482124, 54.58298049867153, 49.371970519423485, 43.22578512132168, 1.2635408551432192, 2.155927838757634, 1.050898446701467, 2.5523603288456798, 0.07008853048318997, 4.140057396143675, 56.94671966135502, 61.33995272219181, 53.65411654114723, 45.34751147031784, 47.2867564111948, 49.994871094822884, 52.78624691069126, 52.32020951807499, 55.35362094640732, 51.75456427037716, 54.3223524838686, 48.52257549762726, 38.87261711061001, 37.03380838036537, 43.93278278410435, 51.13888330757618, 53.164843395352364, 52.88379147648811, 51.797752752900124, 50.57686686515808, 46.788755133748055, 44.207135662436485, 42.461965307593346, 38.265542685985565, 38.04095193743706, 39.07067008316517, 37.172968313097954, 37.02742852270603, 36.281543746590614, 36.8700485676527, 36.80452108383179, 39.53887335956097, 39.27929788827896, 39.90648463368416, 38.244773000478745, 37.82985046505928, 37.707014456391335, 37.957246229052544, 36.001426577568054, 37.5635189563036, 37.025065049529076, 41.53258077800274, 49.566919058561325, 49.29630137979984, 48.27442221343517, 46.62240765988827, 47.02806629240513, 47.6270205527544, 48.76125209033489, 45.438619181513786, 43.05274620652199, 39.67837527394295, 38.24240952730179, 38.88685494661331, 41.94213420152664, 37.549744695425034, 40.28738759458065, 41.49220794439316, 43.85596990585327, 47.21607640385628, 41.30968853831291, 36.73655793070793, 39.77327138185501, 38.17020200192928, 40.93662455677986, 40.28328761458397, 38.62763665616512, 39.9774344265461, 39.32295374572277, 40.957918614149094, 42.48729854822159, 49.50957253575325, 51.28410391509533, 52.32439309358597, 50.710710883140564, 49.98102083802223, 49.87093694508076, 47.49152362346649, 49.034339636564255, 47.11537040770054, 40.91185748577118, 36.3557917624712, 37.318318113684654, 34.29863914847374, 35.508251041173935, 34.9529754370451, 37.21812129020691, 39.30784195661545, 38.68902616202831, 38.7444993853569, 37.19582028687, 37.592321410775185, 37.044436410069466, 34.86364223062992, 37.17929497361183, 34.36498738825321, 35.77296003699303, 36.911280155181885, 35.701603665947914, 34.806903675198555, 36.52221143245697, 37.03560948371887, 38.08600232005119, 36.69737443327904, 38.275600746273994, 38.18015366792679, 49.19551558792591, 52.91941076517105, 53.27417492866516, 55.00020571053028, 54.11623254418373, 50.64586356282234, 48.81318010389805, 41.74840919673443, 39.21031638979912, 39.87863212823868, 41.93785183131695, 44.62353251874447, 53.29151339828968, 54.27338071167469, 56.603563874959946, 52.023494839668274, 37.22412496805191, 0.15103926794836298, 0.08112143885227852, 4.644264690577984, 0.21992709254845977, 0.8928682515397668, 9.25088195130229, 65.36045238375664, 53.487389087677, 61.70762099325657, 57.996987104415894, 63.28716203570366, 42.00415447354317, 28.25104136019945, 33.7164343893528, 60.68312756717205, 21.09160803258419, 0.6224992219358683, 0.06737368748872541, 0.13403237506281585, 0.043185024114791304, 0.04882833731244318, 0.11035694391466677, 0.026704343617893755, 0.0234673626255244, 0.0644314727105666, 0.012932212703162804, 0.005102623827042407, 0.025613137913751416, 0.06608064359170385, 0.050306829070905223, 0.020022853022965137, 0.07733462291071191, 0.051199770023231395, 0.021495888140634634, 2.396411234512925, 63.671952188014984, 55.653227269649506, 48.48001018166542, 74.55060884356499, 63.24599504470825, 43.76761704683304, 63.049480989575386, 62.92929723858833, 61.4779195189476, 60.4331161826849, 55.051890537142754, 47.973219975829124, 1.505665050353855, 1.553630589041859, 2.7756900200620294, 5.210550203919411, 0.10595116938930005, 4.929968509823084, 60.700694024562836, 63.429232612252235, 55.491754934191704, 45.984539687633514, 50.695534497499466, 49.488506466150284, 56.316208094358444, 54.52736288309097, 57.01864220201969, 54.485200345516205, 54.92709383368492, 51.012369096279144, 41.51243045926094, 38.50535921752453, 43.63129176199436, 54.43900242447853, 54.54957649111748, 53.46444971859455, 53.84567566215992, 52.66704350709915, 47.693566381931305, 45.16663737595081, 44.2340724170208, 40.938969030976295, 40.55596478283405, 41.3681598007679, 39.936290234327316, 38.44612419605255, 38.553677424788475, 37.751931846141815, 40.47457315027714, 41.560832262039185, 40.33637836575508, 40.48630312085152, 39.8556699603796, 40.23165598511696, 40.945117101073265, 39.20508787035942, 37.62135185301304, 39.79308731853962, 41.68515019118786, 42.847025245428085, 51.90859280526638, 51.25882387161255, 51.1407870054245, 48.649956062436104, 49.81225289404392, 52.361049726605415, 53.74780811369419, 48.522100523114204, 44.62576299905777, 39.21462915837765, 38.76057252287865, 39.047992900013924, 40.942039266228676, 37.675749734044075, 39.67741012573242, 39.084379747509956, 45.61803415417671, 48.206174075603485, 44.11804564297199, 39.01194043457508, 39.139860570430756, 39.590349197387695, 40.77360190451145, 40.52728392183781, 38.010918349027634, 38.91380310058594, 38.60907845199108, 39.98037166893482, 42.03877441585064, 51.58767342567444, 53.16277630627155, 53.18215146660805, 52.4863176047802, 50.630216002464294, 50.43218582868576, 51.00967884063721, 49.38188798725605, 50.325745940208435, 43.057682141661644, 38.400678634643555, 39.547764882445335, 37.84002631902695, 37.500035762786865, 37.626990750432014, 38.83527651429176, 41.2791495770216, 40.7257054746151, 40.553890094161034, 38.29244144260883, 37.96551838517189, 38.839935064315796, 37.86350525915623, 38.47668215632439, 37.22519651055336, 38.60416531562805, 39.198780208826065, 38.08908015489578, 36.757810190320015, 38.52476857602596, 38.096345365047455, 41.48305423557758, 38.73672880232334, 40.42134940624237, 39.91539515554905, 51.94512024521828, 54.35515232384205, 54.927568808197975, 56.41620732843876, 55.73526106774807, 53.15773017704487, 51.37018449604511, 42.82472424209118, 40.263407081365585, 42.34099119901657, 43.27970802783966, 49.3274787068367, 56.016540974378586, 56.8011798709631, 59.44899179041386, 53.260982036590576, 40.31943887472153, 0.6066709337756038, 0.0329959302325733, 7.098985696211457, 1.7807213659398258, 0.8063506346661597, 9.917937107384205, 70.64283013343811, 59.229002594947815, 65.85901603102684, 63.04883502423763, 66.65728479623795, 49.688763320446014, 29.723585844039917, 38.569104596972466, 66.9794999063015, 28.501909598708153, 0.604516746243462, 0.01059926127709332, 0.1614543903269805, 0.07990631303982809, 0.04996695883164648, 0.10570699538220651, 0.016849826606630813, 0.030872128081682604, 0.14468805718934163, 0.11608478031121194, 0.08795995119726285, 0.10252903739456087, 0.15484255214687437, 0.14038247260032222, 0.1264859948423691, 0.16763913736213, 0.28007765708025545, 0.18473464268026873, 2.458705329336226, 71.43646314740181, 64.18602660298347, 53.533184230327606, 72.43276968598366, 66.4326560497284, 55.16627199947834, 68.78617376089096, 66.1267040669918, 65.62130078673363, 65.20790576934814, 59.99863989651203, 54.6528397500515, 2.210099631920457, 4.953907700255513, 5.623555267229676, 7.262302357703447, 0.1631886707036756, 5.99670996889472, 61.38128690421581, 66.41256272792816, 60.286725237965584, 48.896904811263084, 54.17948395013809, 54.60055075585842, 60.177728086709976, 55.746979638934135, 59.0044042468071, 55.88298574090004, 57.078405395150185, 52.7898833155632, 42.5149230659008, 42.29766972362995, 48.597450479865074, 57.3794936388731, 58.28546762466431, 55.23010857403278, 57.35914193093777, 56.94895774126053, 51.13956347107887, 47.035130113363266, 47.13640607893467, 43.34676302969456, 43.32518398761749, 43.47100876271725, 42.08468735218048, 42.285882756114006, 41.349780187010765, 39.175035282969475, 40.337780490517616, 43.37184928357601, 42.81117416918278, 42.57961839437485, 41.78044907748699, 42.152992486953735, 42.19645455479622, 41.02735608816147, 39.40265826880932, 43.655861243605614, 42.76828587055206, 45.70844650268555, 56.53125375509262, 54.078625962138176, 54.364598616957664, 51.13657683134079, 53.794298619031906, 52.757695242762566, 55.550298392772675, 50.10937415063381, 44.81985278427601, 38.945991173386574, 38.15420866012573, 38.49151276051998, 42.88530819118023, 37.08144262433052, 42.74891451001167, 42.16137483716011, 46.267768889665604, 51.520990803837776, 45.55100195109844, 39.50868397951126, 40.38502335548401, 38.382276222109795, 41.97410948574543, 41.60139888525009, 37.77834802865982, 39.418203234672546, 39.26194041967392, 40.926741287112236, 44.20462019741535, 53.14299836754799, 56.227866634726524, 56.79582975804806, 56.250711008906364, 53.587806299328804, 54.16633665561676, 53.709145188331604, 52.844174802303314, 52.37883657217026, 45.3913801163435, 41.517449989914894, 43.00916254520416, 37.42840200662613, 38.95272061228752, 39.295678809285164, 41.33503697812557, 41.493792459368706, 41.714431419968605, 42.01817572116852, 41.29069335758686, 40.51811881363392, 42.21929132938385, 40.17308972775936, 42.765458822250366, 39.97649967670441, 40.311136320233345, 41.57453432679176, 40.69541350007057, 39.25824701786041, 40.86960755288601, 39.68035116791725, 43.04633595049381, 40.759858042001724, 42.725496366620064, 42.0324781537056, 54.00971665978432, 56.93302519619465, 56.237575113773346, 58.39474596083164, 59.092236533761024, 56.51724770665169, 53.880880773067474, 45.553217232227325, 42.85356089472771, 45.455201491713524, 47.137276232242584, 50.02529226243496, 59.17975343763828, 60.23413605988026, 63.93027752637863, 55.55878333747387, 45.59389404952526, 1.2405383144505322, 0.15441813273355365, 11.357710249722004, 6.630414789542556, 1.9741327688097954, 11.31219344213605, 77.3443253338337, 63.264845833182335, 72.83571526408195, 68.0543102324009, 73.800810277462, 57.02232040464878, 38.92441973090172, 46.31477236747742, 75.74030220508575, 38.76894347369671, 1.0510402265936136, 0.1752729871077463, 0.19668167660711333, 0.13586193235823885, 0.12708115275017917, 0.19467400386929512, 0.1402279277681373, 0.151058430201374], [0.06947948699234985, 0.05081530413008295, 0.07243033294798806, 0.041461412110948004, 0.04791725456016138, 0.08729165463591926, 0.045437794833560474, 0.01991768327570753, 0.07314442002098076, 0.10249275379464962, 0.12866664736066014, 39.78812098503113, 59.43618267774582, 39.07090947031975, 41.07019878923893, 38.65103580057621, 46.47283248603344, 52.82653994858265, 57.67418682575226, 57.074187621474266, 56.08904488384724, 47.44969166815281, 54.47563625872135, 5.609785756096244, 1.8916910863481462, 4.717149529606104, 1.8604583060368896, 0.45954760804306716, 1.2497567385435104, 49.738688841462135, 60.7184162735939, 54.178553000092506, 49.94110397994518, 50.01258574426174, 54.67278108000755, 57.5497131049633, 54.48035180568695, 54.114005863666534, 53.33092488348484, 49.993662759661674, 41.14415042102337, 38.42079855501652, 39.01409491896629, 49.65116433799267, 52.867912128567696, 53.302475810050964, 48.354670107364655, 50.80656833946705, 50.281531512737274, 50.45230194926262, 46.75713703036308, 42.82417707145214, 40.82372881472111, 38.77178192138672, 35.12873500585556, 36.5105764567852, 36.25054880976677, 37.16780059039593, 35.7825431227684, 37.14378207921982, 40.669270902872086, 38.8299036026001, 39.058480337262154, 38.3276541531086, 37.85264924168587, 38.01726020872593, 38.21041904389858, 35.59552475810051, 38.05405743420124, 35.12827903032303, 41.407654881477356, 49.39217023551464, 50.01763567328453, 48.6826229095459, 48.474903255701065, 49.99718517065048, 47.6527451723814, 49.631823375821114, 46.92709431052208, 43.84099490940571, 39.32374410331249, 39.17859189212322, 39.38164159655571, 39.66649331152439, 40.341629683971405, 38.48279982805252, 41.68503239750862, 43.52571442723274, 46.43021397292614, 42.28009186685085, 39.44789484143257, 38.50082226097584, 38.60432490706444, 39.22151438891888, 39.83116887509823, 39.816159680485725, 40.38856856524944, 39.79312151670456, 40.183375775814056, 42.275330722332, 50.70040583610535, 50.39675273001194, 50.39725810289383, 48.22373293340206, 50.624041333794594, 48.568013459444046, 50.17370089888573, 45.774961933493614, 47.63488993048668, 45.16545943915844, 37.85428315401077, 36.119763627648354, 36.12428158521652, 35.4948453605175, 37.196808233857155, 37.335219606757164, 38.22896204888821, 39.11640822887421, 37.47081533074379, 36.82018004357815, 36.572972908616066, 35.383241549134254, 36.060528606176376, 36.1231492459774, 35.209587067365646, 37.291453555226326, 35.196295380592346, 36.194995790719986, 36.689972430467606, 36.434576734900475, 36.050383150577545, 37.337218299508095, 37.82585687935352, 37.32524514198303, 43.89167279005051, 50.84020413458347, 52.04789713025093, 53.69545452296734, 56.45021930336952, 54.70596469938755, 51.975165233016014, 53.84518548846245, 46.242705434560776, 41.20039880275726, 37.69225984811783, 40.484980791807175, 42.71924950182438, 50.80166280269623, 52.53658130764961, 53.03994029760361, 54.9642938375473, 33.00123296678066, 0.35612980427686125, 0.1155074339476414, 4.273038385435939, 0.9038431313820183, 0.6795004976447672, 15.275281984359026, 66.22302889823914, 54.23432260751724, 63.09144973754883, 58.47863405942917, 58.09691794216633, 35.628484189510345, 35.16569942235947, 32.77332879602909, 54.53433930873871, 12.699344158172607, 0.7252628076821566, 0.03190300274582114, 0.06676391669316217, 0.06837868902948685, 0.1408430642914027, 0.061931733798701316, 0.022803210958954878, 0.029885470576118678, 0.13062578364042565, 0.013580550130427582, 0.04588276060530916, 0.0614190730266273, 0.06113197319791652, 0.04124128368857782, 0.06643849235842936, 0.12116032085032202, 0.037442055327119306, 0.1705752665293403, 0.2510965528199449, 48.21164198219776, 64.06142368912697, 42.84675545990467, 51.825134083628654, 49.476510509848595, 52.92366273701191, 61.142408922314644, 64.28100630640984, 61.855778843164444, 60.25935910642147, 53.4814690053463, 60.991237834095955, 5.847059274092317, 1.9210192188620567, 5.154150780290365, 4.915953436866403, 2.0037338929250836, 1.6900676116347313, 51.312689781188965, 62.55309462547302, 56.63635611534119, 51.1786025762558, 52.340006455779076, 57.056788355112076, 57.71506883203983, 56.277301982045174, 57.27625697851181, 55.08231170475483, 52.18782462179661, 43.95511798560619, 39.82021026313305, 40.74701093137264, 50.93320034444332, 54.80655290186405, 54.170011058449745, 51.044131591916084, 53.84961985051632, 52.500927820801735, 52.05189071595669, 48.559137135744095, 44.92061197757721, 42.52414897084236, 40.54274909198284, 38.87555055320263, 38.734502121806145, 38.60352694988251, 39.40346382558346, 38.37720349431038, 39.92321893572807, 41.02346129715443, 40.450045466423035, 40.411336943507195, 39.63442303240299, 38.42617526650429, 39.63547557592392, 39.00521859526634, 38.5711944848299, 38.82997579872608, 37.752342224121094, 43.19174274802208, 51.45366981625557, 53.32331009209156, 51.978433057665825, 51.189754977822304, 51.53076007962227, 49.77711237967014, 52.31218434870243, 47.98141613602638, 43.75485733151436, 39.2008662968874, 39.823835268616676, 40.80093763768673, 39.646061807870865, 40.42788505554199, 39.73411828279495, 40.54792441427708, 45.47110363841057, 48.144157603383064, 43.237169310450554, 39.77754235267639, 39.36806872487068, 39.123532846570015, 39.609454572200775, 41.31879664957523, 40.06843954324722, 39.82826203107834, 40.19889794290066, 39.57319311797619, 43.02268221974373, 53.21173667907715, 52.9860819876194, 53.06469216942787, 51.168875098228455, 52.68631227314472, 51.8818536400795, 52.102105021476746, 49.0092533826828, 49.187870398163795, 45.295370668172836, 40.46201102435589, 37.80296690762043, 38.69191400706768, 37.42081381380558, 38.470978662371635, 38.4820132702589, 39.19980235397816, 40.21758534014225, 39.62798997759819, 37.65471786260605, 38.12271974980831, 38.49149376153946, 38.19467268884182, 37.668332532048225, 37.21833027899265, 39.03066202998161, 36.69240429997444, 36.896050572395325, 38.492253720760345, 38.18516179919243, 37.04722926020622, 39.33834291994572, 40.58817185461521, 40.13957932591438, 45.01425415277481, 53.79696607589722, 54.28813152015209, 55.510826110839844, 57.349596843123436, 55.044499933719635, 55.38431189954281, 55.89903227984905, 50.5392374843359, 44.19779576361179, 38.934124410152435, 43.50617207586765, 44.268867149949074, 53.84413294494152, 56.2600889056921, 57.29036182165146, 56.708445847034454, 35.24771802127361, 0.3280000324593857, 0.6091208523139358, 9.755729511380196, 2.828536396846175, 0.6102518853731453, 17.012165933847427, 72.88816764950752, 58.595922365784645, 69.54292595386505, 62.32538044452667, 66.75978049635887, 39.5900946110487, 33.041624799370766, 39.27868612110615, 61.34447067975998, 18.476848639547825, 0.6929462542757392, 0.025257697416236624, 0.12653571873670444, 0.019914588519895915, 0.04841619673243258, 0.09030938294017687, 0.036934767704224214, 0.04779713795869611, 0.30421577277593315, 0.17313784308498725, 0.21870134660275653, 0.11980049850535579, 0.18343876377912238, 0.18566327722510323, 0.1602829250623472, 0.1913353634881787, 0.19034287455724552, 0.32130716659594327, 0.4064426076365635, 54.69552665948868, 75.7111045718193, 49.6411594748497, 53.027530163526535, 52.27787218987942, 60.44013060629368, 68.05158957839012, 67.80994534492493, 68.06681156158447, 67.16037780046463, 58.57464350759983, 67.32376903295517, 8.508338145911694, 3.7231611041352153, 11.943574212491512, 6.209793509915471, 1.3893024693243206, 2.101394827477634, 54.176459312438965, 64.41495671868324, 59.36946585774422, 54.13431957364082, 55.79810969531536, 60.733459666371346, 61.06028392910957, 57.625443041324615, 59.13482844829559, 57.09763616323471, 53.71414951980114, 45.95727615058422, 42.97170415520668, 43.94947528839111, 54.9164430052042, 57.05727852880955, 57.06060715019703, 51.72877885401249, 54.76659044623375, 54.87314432859421, 56.02768957614899, 51.03826090693474, 47.07019843161106, 45.342146158218384, 43.27608682215214, 41.553244069218636, 40.267043486237526, 42.10643358528614, 43.135555163025856, 41.87203176319599, 41.71600453555584, 45.02180054783821, 42.71529771387577, 42.45473809540272, 42.03840583562851, 40.32797321677208, 42.989905178546906, 41.36132396757603, 39.544789642095566, 41.33774243295193, 41.27271272242069, 45.335295125842094, 55.55816017091274, 55.24848438799381, 53.29931437969208, 54.35448735952377, 56.41277231276035, 51.36187054216862, 55.03684714436531, 48.43006186187267, 43.71661998331547, 39.5329836755991, 38.38255360722542, 39.87925909459591, 39.37818378210068, 41.27737507224083, 40.36633975803852, 42.43455357849598, 47.25248984992504, 50.87589181959629, 45.589626878499985, 41.578558310866356, 39.964013546705246, 40.088867247104645, 39.69069421291351, 39.650401175022125, 40.52166402339935, 40.095444694161415, 40.434071123600006, 40.623992532491684, 43.890008479356766, 54.70079317688942, 54.921926110982895, 55.46264849603176, 53.44006262719631, 56.307392567396164, 54.4159946590662, 56.85070261359215, 51.0502340644598, 50.824890956282616, 49.528434723615646, 43.36408630013466, 40.522583574056625, 41.418381705880165, 38.45974266529083, 40.28654783964157, 42.15056821703911, 40.65337635576725, 42.40317106246948, 41.88641779124737, 40.09767137467861, 40.90993858873844, 40.90742692351341, 41.18376709520817, 41.335443556308746, 41.28483027219772, 42.31439642608166, 39.7711168974638, 40.01089163124561, 40.83460383117199, 41.139096692204475, 39.96355377137661, 40.710817873477936, 42.90152192115784, 41.27065323293209, 48.377780467271805, 56.484565660357475, 55.737727135419846, 58.61342802643776, 58.57665739953518, 57.188227102160454, 56.86372071504593, 58.619667291641235, 52.049949020147324, 46.56953729689121, 41.18513502180576, 46.17429010570049, 46.98666371405125, 55.74716962873936, 60.15491031110287, 59.69492979347706, 59.48223240673542, 41.3680762052536, 0.7819259609095752, 0.8460927614942193, 14.10476429387927, 7.636668719351292, 1.3193439482711256, 19.41903468221426, 77.0221558213234, 64.10567611455917, 74.62441608309746, 68.6859655380249, 71.99615031480789, 49.386333748698235, 45.82367531955242, 47.559140995144844, 73.89602556824684, 24.37973689287901, 0.9894180425908417, 0.06627379494602792, 0.24265521671622992, 0.11352218149113469, 0.18113953090505674, 0.22223992156796157, 0.1754159841220826, 0.12019491288810968], [0.033375932107446715, 0.04763180229929276, 0.0295456522871973, 0.0539085830678232, 0.03128762873529922, 0.013679398634849349, 0.06643829940003343, 0.012037919186695945, 0.08350422271178104, 0.2407985710306093, 0.13200818211771548, 15.01379331573844, 63.45510542392731, 39.06822681427002, 44.30134400725365, 42.52247326076031, 32.41825304925442, 47.78493247926235, 61.74119219183922, 55.167176350951195, 58.73937226831913, 46.96228802204132, 57.81637899577618, 16.707264594733715, 0.7923328306060284, 1.6716573620215058, 3.657491127960384, 3.3437956357374787, 0.26830238581169397, 29.361607767641544, 62.50773645937443, 58.10170188546181, 56.05887830257416, 53.07427905499935, 56.23606659471989, 53.931885436177254, 56.721266359090805, 51.44656799733639, 52.78431661427021, 46.08265422284603, 38.768571093678474, 38.24585594236851, 44.026576951146126, 50.25860734283924, 53.20480965077877, 49.481408447027206, 45.74083976447582, 51.745110377669334, 51.689758747816086, 50.151403695344925, 43.82593251764774, 43.41636769473553, 41.466772109270096, 39.67303276062012, 37.571243941783905, 38.500674068927765, 36.73020467162132, 37.92906314134598, 36.744708493351936, 37.75853209197521, 39.29884023964405, 38.997041434049606, 39.250248447060585, 37.648368403315544, 37.90571719408035, 36.98322929441929, 37.50883989036083, 37.31267921626568, 36.87386356294155, 36.185990273952484, 43.1794124096632, 49.21462096273899, 51.18701912462711, 48.78606855869293, 48.08721765875816, 47.75579944252968, 49.03677150607109, 47.817777916789055, 47.58056804537773, 43.820179626345634, 41.38305500149727, 40.42940877377987, 39.11621443927288, 38.42521771788597, 38.83957788348198, 36.78937129676342, 38.787805661559105, 42.078816667199135, 45.06474584341049, 41.82833790779114, 40.57548053562641, 37.13242448866367, 38.453115820884705, 37.88802534341812, 38.71282048523426, 39.89166922867298, 40.30357472598553, 39.33358937501907, 40.95952972769737, 43.1480260938406, 50.22036239504814, 51.504507288336754, 51.15899182856083, 47.66777716577053, 50.54257370531559, 50.37474811077118, 48.77871215343475, 48.702017068862915, 45.60229539871216, 42.36179508268833, 38.61494533717632, 38.335781916975975, 37.01552376151085, 36.593860387802124, 35.13118967413902, 37.02768690884113, 35.59818461537361, 36.86610817909241, 38.08034062385559, 36.821635365486145, 35.378157421946526, 36.18827395141125, 34.01463098824024, 34.435880184173584, 36.7343844473362, 34.362597316503525, 35.52756920456886, 35.073060393333435, 35.08081957697868, 37.36978255212307, 35.65587691962719, 36.829481944441795, 37.394424229860306, 39.17524427175522, 45.71489475667477, 50.57991050183773, 51.82979643344879, 52.532595321536064, 53.46730716526508, 52.67738275229931, 52.57451467216015, 57.10306227207184, 53.165477961301804, 47.46774449944496, 38.95692698657513, 39.04880605638027, 40.09618565440178, 47.03465893864632, 53.41140076518059, 53.92511799931526, 57.32659287750721, 30.89747965335846, 0.11745766445528716, 0.04661891915020533, 5.4906911216676235, 1.1433671973645687, 0.3202000603778288, 26.390716284513474, 64.62409749627113, 53.3218889683485, 62.18072220683098, 56.72550693154335, 55.67557007074356, 34.932084158062935, 30.320303924381733, 33.54222513735294, 56.982688531279564, 8.42395892366767, 0.4492908006068319, 0.0030105041923889075, 0.06405863256077282, 0.07310366127057932, 0.02699190728890244, 0.036273903751862235, 0.04172765387920663, 0.011246467856835807, 0.03888819686835632, 0.03458347688138019, 0.007854354807932395, 0.09289617577451281, 0.07744839414954185, 0.01788935471267905, 0.01295004743951722, 0.039225892614922486, 0.06837249951786362, 0.27167571417521685, 0.011559515951375943, 21.761814169585705, 70.81661000847816, 40.6400390714407, 44.37217980623245, 49.337635561823845, 41.68526418507099, 56.46427474915981, 66.42033711075783, 61.78789548575878, 64.45909515023232, 51.42135255038738, 62.80872970819473, 17.19547189772129, 0.3858354821568355, 3.042365647852421, 5.4513138346374035, 5.473131788894534, 0.23947063134983182, 33.894899412989616, 65.28828665614128, 61.044704765081406, 59.11601185798645, 56.10818825662136, 57.639065310359, 57.69793935120106, 57.51929573714733, 55.78478381037712, 55.431729555130005, 49.10114765167236, 41.89213648438454, 39.055402502417564, 46.776018217206, 51.986906602978706, 55.02181135118008, 51.16814933717251, 46.019030436873436, 54.81636397540569, 52.94917456805706, 51.992986276745796, 47.27148503065109, 44.97974440455437, 43.85288827121258, 42.56455600261688, 41.08594514429569, 40.060782954096794, 39.098845571279526, 39.475355967879295, 39.243936985731125, 40.4976075142622, 40.287247002124786, 40.4474426060915, 41.19375295937061, 39.155869111418724, 39.08723719418049, 40.14477364718914, 39.21959549188614, 40.488222017884254, 39.69744265079498, 38.47485825419426, 43.678002655506134, 51.37244537472725, 53.09143513441086, 51.58081479370594, 50.56785374879837, 50.675543770194054, 50.53937427699566, 48.981765657663345, 49.00488741695881, 44.02794107794762, 40.737785026431084, 39.83592242002487, 40.05428530275822, 38.83426956832409, 39.651430919766426, 38.18155199289322, 41.60837151110172, 44.89952310919762, 47.40871086716652, 42.814157009124756, 40.09271264076233, 39.95403528213501, 38.84192995727062, 39.68540109694004, 40.56608363986015, 39.68374818563461, 39.51762109994888, 40.19553132355213, 40.01968055963516, 43.812735825777054, 51.58925034105778, 53.3164818584919, 52.03241676092148, 50.636717453598976, 51.39176353812218, 53.275558054447174, 49.17846970260143, 51.47739954292774, 48.70372697710991, 46.58266179263592, 41.37461185455322, 40.21416172385216, 37.69740477204323, 38.53573098778725, 37.04111158847809, 40.27639098465443, 37.77876600623131, 38.629532754421234, 38.38496267795563, 39.04835008084774, 37.379570826888084, 37.200889214873314, 37.409498021006584, 38.087263852357864, 37.55662992596626, 36.75421938300133, 38.410026133060455, 38.15696731209755, 37.82733120024204, 39.58110049366951, 37.34538406133652, 39.173268377780914, 39.2259069532156, 42.52731800079346, 47.45693027973175, 53.89481842517853, 54.72390353679657, 55.3745274245739, 55.69959618151188, 55.439234152436256, 54.690746515989304, 59.552612230181694, 56.10379569232464, 49.136075377464294, 40.43071590363979, 40.26930816471577, 41.93471319973469, 48.963002264499664, 55.049549862742424, 58.00990641117096, 58.71380344033241, 33.876546397805214, 0.27902354020625353, 0.641073634615168, 7.804144257679582, 1.5353567758575082, 0.2629321755375713, 28.371586091816425, 70.87286978960037, 58.63230921328068, 68.03102508187294, 59.526047855615616, 62.20513969659805, 45.28648294508457, 34.058864414691925, 38.40707369148731, 63.51727768778801, 11.176291834563017, 0.47650553402490914, 0.02782928364467807, 0.09952801483450457, 0.017618253732507583, 0.06461929544457234, 0.034340412385063246, 0.027186075385543518, 0.039400263922289014, 0.15480722591746598, 0.15919241326628253, 0.1156994052871596, 0.21340156614314765, 0.19864906556904316, 0.14209061453584582, 0.2561925840564072, 0.15575824363622814, 0.16622003226075321, 0.6241912592668086, 0.33472400915343314, 22.931300215423107, 82.06241816282272, 50.78178986907005, 56.40605807304382, 55.05233511328697, 47.552289962768555, 60.037291422486305, 72.69398286938667, 65.73632821440697, 70.04468902945518, 55.337506011128426, 69.63278353214264, 21.358118131756783, 1.022778411861509, 7.298765201121569, 11.606823932379484, 8.32033658400178, 0.7457016734406352, 35.510120540857315, 67.33341291546822, 62.540946677327156, 62.70179584622383, 56.57628893852234, 61.528593599796295, 58.4382726252079, 60.85871994495392, 56.22734986245632, 57.37599402666092, 50.96065767109394, 43.86570118367672, 42.140608951449394, 50.02165585756302, 55.1831278949976, 56.30714178085327, 51.72992259263992, 47.15137727558613, 55.521940514445305, 54.36964474618435, 54.63898569345474, 48.5897520929575, 47.38914951682091, 47.61834181845188, 45.64899869263172, 44.592693373560905, 43.3806724101305, 41.924951523542404, 41.93665489554405, 42.32353113591671, 42.40622229874134, 42.588217332959175, 42.68451936542988, 44.823314398527145, 41.19602143764496, 41.71963334083557, 41.41381815075874, 41.0073197633028, 43.39552961289883, 42.011210694909096, 39.76947918534279, 48.14730383455753, 56.20797850191593, 56.3567291200161, 54.32194970548153, 54.41233545541763, 54.78627718985081, 52.92000733315945, 50.736728087067604, 51.42365902662277, 45.44805787503719, 43.144309893250465, 40.0528147816658, 40.094851925969124, 40.578235387802124, 40.980044826865196, 38.06596599519253, 41.66689217090607, 46.74250781536102, 49.95670214295387, 44.548649936914444, 43.26408326625824, 40.42877420783043, 40.62617361545563, 39.86279837787151, 40.580104887485504, 40.2645318210125, 38.92795354127884, 39.99410793185234, 41.29065155982971, 44.495202004909515, 51.5650874376297, 56.36217802762985, 56.04654036462307, 52.313962653279305, 54.90861542522907, 57.05095186829567, 53.16093720495701, 54.12161685526371, 50.26364587247372, 46.638252809643745, 44.05292093753815, 42.11157090961933, 41.10217407345772, 40.92317707836628, 39.06171776354313, 42.45347656309605, 39.67439688742161, 39.89023670554161, 41.95013277232647, 41.45324483513832, 39.024472162127495, 41.11763924360275, 39.19314131140709, 39.62483614683151, 42.08089895546436, 38.10190066695213, 39.86268438398838, 38.54243382811546, 41.670577973127365, 43.31099934875965, 40.519376546144485, 41.38306260108948, 41.91967360675335, 44.47582684457302, 49.124189615249634, 55.11485315859318, 57.1460797637701, 56.618003100156784, 59.501634165644646, 56.488810032606125, 56.27489671111107, 61.58091299235821, 58.82927164435387, 50.90163163840771, 44.10073757171631, 43.0071372538805, 44.7455857694149, 52.18579553067684, 58.71307007968426, 59.94844079017639, 63.347468599677086, 37.92309746146202, 0.7007748435717076, 1.1231737746857107, 15.852611605077982, 4.979363959282637, 0.48773630638606846, 32.185409143567085, 75.74999928474426, 63.99615839123726, 73.14080849289894, 66.38404905796051, 66.02903410792351, 50.345888659358025, 40.72383597493172, 47.280061170458794, 73.24268862605095, 17.058133967220783, 0.6311819341499358, 0.14071758196223527, 0.23604916728800163, 0.17515859246486798, 0.17851479206001386, 0.09250243674614467, 0.16022528987377882, 0.12455617339583114], [0.038921393133932725, 0.030182036498445086, 0.05731532663048711, 0.016524790044059046, 0.03846758838335518, 0.02388479100773111, 0.02171259155147709, 0.030665471495012753, 0.04692245012847707, 0.15704370278399438, 0.08585689764004201, 2.35881011467427, 53.79822000861168, 51.37250617146492, 49.148888289928436, 34.73805896937847, 31.66106577962637, 54.627753496170044, 60.72741039097309, 55.75832203030586, 57.42471881210804, 49.146965593099594, 56.687170788645744, 23.350966796278954, 0.4850792099023238, 3.785674637183547, 4.5140832010656595, 7.046976462006569, 5.528302928432822, 6.352538550272584, 56.413904651999474, 59.799861162900925, 54.60183888673782, 54.922328889369965, 57.69851312041283, 57.38960489630699, 55.8423925191164, 51.2850234657526, 48.529783710837364, 40.684800669550896, 38.9658223092556, 41.87136299908161, 49.67187702655792, 52.44150660932064, 53.00670728087425, 45.369253903627396, 51.8398392945528, 56.27797834575176, 52.62805759906769, 49.91158336400986, 45.18951214849949, 42.385688200592995, 41.234110593795776, 39.33216065168381, 37.541016563773155, 35.181905552744865, 36.73059985041618, 36.07896141707897, 36.78222768008709, 38.1795608997345, 37.42581434547901, 38.338612765073776, 37.567729130387306, 38.04966486990452, 36.988233625888824, 38.42350400984287, 37.04817160964012, 38.05052362382412, 35.88481083512306, 34.932281747460365, 40.84884166717529, 49.22271452844143, 47.8211635351181, 47.667321190238, 49.214119389653206, 49.4236059486866, 47.250494956970215, 48.786250948905945, 47.37589582800865, 43.03905554115772, 40.776915326714516, 40.402316227555275, 38.41955982148647, 36.17940902709961, 38.322988003492355, 38.12033727765083, 39.91137497127056, 42.05564931035042, 41.46725468337536, 42.66347609460354, 38.957276567816734, 38.459735065698624, 37.091196700930595, 38.14546152949333, 37.61893518269062, 39.861255660653114, 39.393272772431374, 40.410865768790245, 38.505040034651756, 42.37672068178654, 47.540389001369476, 49.971221163868904, 49.92812007665634, 48.12796667218208, 49.371696934103966, 50.75351558625698, 49.073390141129494, 51.162563636898994, 43.36382791399956, 43.0193118005991, 40.08909523487091, 39.135828986763954, 37.11379408836365, 35.541111677885056, 37.24414609372616, 37.500670328736305, 39.32782508432865, 38.08834679424763, 37.647726237773895, 35.66162221133709, 36.30196765065193, 34.536700174212456, 35.0154060870409, 35.36087974905968, 34.30982194840908, 35.44197879731655, 34.68728609383106, 35.95767952501774, 36.66630730032921, 37.203043699264526, 35.72273813188076, 36.92598916590214, 37.91177786886692, 40.568306520581245, 47.09901988506317, 49.5893644541502, 51.01681865751743, 52.663540095090866, 51.72084867954254, 52.20418654382229, 52.30676583945751, 56.87040455639362, 53.737066090106964, 51.64848156273365, 44.424035623669624, 37.49636895954609, 40.33559940755367, 43.89118641614914, 53.800659477710724, 53.79409343004227, 59.39567305147648, 35.971054807305336, 1.2738248845562339, 0.3321843798039481, 9.006315674632788, 1.9680471578612924, 0.7425962900742888, 41.15250237286091, 61.31238900125027, 55.164140313863754, 60.9529472887516, 60.15817433595657, 45.46045280992985, 24.381456300616264, 26.693805120885372, 38.815665766596794, 45.76404511928558, 3.7809522030875087, 0.4006834526080638, 0.022919145558262244, 0.11118072783574462, 0.03546291816746816, 0.04813821789866779, 0.09876502022962086, 0.027779678493971005, 0.01761472853104351, 0.08847322795190848, 0.04510917926381808, 0.03229190668207593, 0.07740259621641599, 0.015759262860228773, 0.006652903530266485, 0.062389535014517605, 0.0562867247936083, 0.07841557584470138, 0.19611304305726662, 0.08171846697223373, 4.066351326182485, 66.05645343661308, 53.912377282977104, 50.78574165701866, 42.732043415308, 38.01552750170231, 56.59605547785759, 65.16486927866936, 61.31634458899498, 63.906468003988266, 53.39163042604923, 61.77579693496227, 25.801626294851303, 0.4838794836541638, 3.4548985864967108, 4.334271624684334, 11.190410926938057, 5.702350214123726, 8.633338138461113, 57.700861394405365, 62.074027732014656, 57.148507833480835, 56.45555801689625, 58.68117839097977, 59.53197933733463, 58.99006761610508, 53.534821942448616, 51.32799915969372, 43.36139224469662, 41.00093610584736, 42.33013138175011, 51.37337252497673, 54.42126117646694, 55.87706945836544, 47.9232906550169, 52.29398712515831, 56.53779320418835, 54.187239333987236, 52.14688181877136, 47.39605754613876, 44.16735179722309, 44.07395660877228, 42.40050360560417, 40.712789967656136, 39.312040731310844, 39.012620598077774, 40.22060997784138, 39.27596166729927, 40.64986154437065, 38.836025074124336, 40.567732751369476, 40.54312527179718, 39.258900582790375, 38.01597587764263, 39.864120706915855, 39.93048794567585, 38.85524824261665, 38.745092153549194, 37.17407025396824, 45.72788245975971, 51.084246039390564, 49.840219393372536, 49.99571844935417, 52.95516684651375, 53.50649446249008, 48.872681111097336, 50.11128544807434, 46.58841848373413, 42.6755328476429, 40.72641983628273, 41.44997701048851, 38.191522657871246, 38.55752281844616, 38.4163261950016, 38.00271838903427, 40.72901889681816, 44.49302852153778, 43.1370484828949, 43.43553386628628, 40.5200757086277, 40.03550671041012, 38.588475957512856, 39.47638191282749, 38.74900974333286, 39.64728154242039, 39.6797090023756, 39.757787212729454, 38.419578820466995, 42.282956913113594, 49.055941477417946, 50.72946287691593, 52.73773871362209, 50.57792700827122, 50.804885029792786, 50.526610761880875, 50.64603455364704, 51.22805692255497, 45.89842110872269, 44.47770394384861, 41.20922192931175, 40.83252914249897, 37.29604370892048, 38.36068958044052, 39.23494666814804, 39.55235503613949, 38.854305893182755, 38.569233790040016, 40.235778763890266, 38.24110619723797, 37.802241146564484, 39.03126619756222, 36.3041715323925, 37.73615509271622, 37.26668268442154, 37.959476709365845, 37.72968403995037, 39.71167668700218, 37.04508617520332, 38.173025250434875, 37.69202046096325, 38.96872155368328, 39.99754674732685, 42.63810485601425, 48.69486205279827, 52.53072202205658, 53.300564512610435, 55.90253569185734, 53.566652834415436, 54.9006662517786, 53.19114938378334, 57.24620059132576, 55.66215679049492, 53.380390629172325, 47.893720641732216, 41.2377317994833, 41.269061118364334, 45.811124593019485, 56.69908694922924, 56.32928319275379, 60.651710852980614, 40.52517123520374, 1.353348798584193, 0.24774654273642227, 8.317539934068918, 0.4642231680918485, 0.5922675097826868, 44.44993503391743, 66.84657543897629, 60.45263573527336, 67.06063315272331, 65.0837816298008, 55.13308838009834, 32.99488350749016, 29.919731318950653, 42.55126431584358, 54.6961460262537, 5.077599138021469, 0.4070811514975503, 0.0657094361667987, 0.17039824946550652, 0.0622782796563115, 0.056963774986797944, 0.07351033593295142, 0.06212260675965808, 0.026273634503013454, 0.12588371231686324, 0.1238091201230418, 0.15651318593882024, 0.19164952944265679, 0.24238562415121123, 0.10965749941533431, 0.10950010473607108, 0.21336177218472585, 0.21316955593647435, 0.2774893428431824, 0.1557636761572212, 4.472250295802951, 73.14371913671494, 65.22291496396065, 61.8400514870882, 47.50628583133221, 45.849061757326126, 66.66540116071701, 70.24729415774345, 66.5923310816288, 70.82914933562279, 57.85407297313213, 69.55863431096077, 29.916355200111866, 0.7943138899281621, 11.045740339905024, 10.130404606461525, 11.800879519432783, 8.146183378994465, 9.432798139750957, 62.21010223031044, 61.719236969947815, 60.83176799118519, 59.47717107832432, 62.05300725996494, 60.70376805961132, 62.19398729503155, 55.6251809746027, 54.7009451687336, 45.53717449307442, 43.72981287539005, 46.01889744400978, 53.12098614871502, 57.129778638482094, 58.272080942988396, 48.54303739964962, 54.69909466803074, 60.289548486471176, 58.07043336331844, 55.178305953741074, 50.5078549683094, 46.84715420007706, 45.44232778251171, 43.962424993515015, 42.044808492064476, 41.49203695356846, 41.93257011473179, 42.18882076442242, 40.83448983728886, 43.79376724362373, 41.01203911006451, 42.032314762473106, 42.33231246471405, 40.85695043206215, 41.40190578997135, 41.354624927043915, 41.49416483938694, 43.02759535610676, 41.076248064637184, 40.17752408981323, 46.437300592660904, 53.46531607210636, 53.43962945044041, 51.92180849611759, 56.67124964296818, 55.24620071053505, 50.473394617438316, 54.91820991039276, 47.05795928835869, 43.56706000864506, 41.49597354233265, 41.11364185810089, 38.16754214465618, 38.60125087201595, 40.57988829910755, 39.05412197113037, 43.47133934497833, 46.37144632637501, 47.18623660504818, 46.357371881604195, 41.62403807044029, 41.93827360868454, 40.57451158761978, 41.42562411725521, 39.020227789878845, 40.07078781723976, 40.24253860116005, 41.020364463329315, 38.977385088801384, 43.98624211549759, 48.467562049627304, 53.54303330183029, 54.607713371515274, 52.857261300086975, 53.544108644127846, 53.98364245891571, 53.49609822034836, 56.27520829439163, 47.62369953095913, 46.01017691195011, 44.84206639230251, 44.46376629173756, 39.72235031425953, 39.93245244026184, 40.96932180225849, 41.23832456767559, 41.91064529120922, 40.72155989706516, 41.24488681554794, 39.908703714609146, 40.35155475139618, 42.21518374979496, 39.556109234690666, 41.07316642999649, 38.382078632712364, 39.90979045629501, 40.36470964550972, 40.8161748200655, 40.8587097376585, 40.78371696174145, 39.822949916124344, 40.53955726325512, 43.34097974002361, 44.74965155124664, 52.29664698243141, 55.64463213086128, 55.13273499906063, 57.225556299090385, 54.370739087462425, 55.883076936006546, 54.937797859311104, 60.53246185183525, 56.67772829532623, 57.785026878118515, 49.489638805389404, 43.567280396819115, 44.05366949737072, 47.894286811351776, 60.47300644218922, 60.68634979426861, 63.24678920209408, 42.146285846829414, 2.46549176517874, 0.8633232931606472, 25.191128253936768, 5.59920902363956, 0.8474782027769834, 49.39139507710934, 72.10138946771622, 65.21171316504478, 72.47026607394218, 70.95537096261978, 61.22453771531582, 35.324185118079185, 38.72604377567768, 52.101443856954575, 64.05402168631554, 7.117334911599755, 0.7161478092893958, 0.12223630139487796, 0.27484987978823483, 0.1074183730816003, 0.14958035404561087, 0.1479223812930286, 0.23666044464334846, 0.13048585911747068], [0.022562411868420895, 0.014544303103320999, 0.01618933558347635, 0.0090156378064421, 0.015253997589752544, 0.020724984096887056, 0.06109039066359401, 0.0522023670055205, 0.027649552175716963, 0.08122555474983528, 0.2858889108756557, 0.12199958597193472, 25.7960918918252, 56.14480309188366, 41.009603440761566, 49.5331958681345, 24.955014623701572, 51.21858783066273, 62.83776015043259, 55.60489006340504, 58.40753227472305, 51.39039561152458, 53.67728769779205, 37.24249318242073, 0.23036130296532065, 0.8425992645788938, 3.505658875219524, 11.227182503789663, 13.329169861972332, 1.4389899093657732, 39.166785925626755, 60.79046040773392, 60.36601558327675, 56.44742265343666, 54.69813711941242, 56.85085080564022, 52.6314964145422, 50.76770022511482, 42.2485725581646, 41.60730756819248, 41.769707053899765, 46.25151716172695, 51.95171669125557, 54.29720923304558, 53.412814289331436, 53.3134838193655, 57.58741848170757, 52.38457426428795, 50.824203193187714, 45.07418833673, 44.169962257146835, 41.62168599665165, 41.162480637431145, 38.39274846017361, 37.85064294934273, 37.83624552190304, 37.22092553973198, 35.55085815489292, 36.38002306222916, 37.634495347738266, 36.3174632191658, 40.28405137360096, 37.55309611558914, 38.29859331250191, 38.10689739882946, 35.68963050842285, 39.82792004942894, 36.3607656955719, 35.72462663054466, 36.083277985453606, 40.01784525811672, 47.17507280409336, 47.94874548912048, 49.95974197983742, 47.89346605539322, 47.62972600758076, 47.440298572182655, 45.78004606068134, 44.28478829562664, 42.092115953564644, 40.44226348400116, 39.238362684845924, 38.22019971907139, 37.91053153574467, 39.39318157732487, 40.261108204722404, 39.50818620622158, 40.84974601864815, 40.17126202583313, 40.440690368413925, 38.6478515714407, 38.665421828627586, 37.58479781448841, 36.57293491065502, 36.61803849041462, 39.06600013375282, 38.06798368692398, 39.374459981918335, 40.77035687863827, 40.43162785470486, 48.3373848348856, 51.38392075896263, 49.830769300460815, 49.13443386554718, 50.20992815494537, 50.81196025013924, 46.92165680229664, 48.03025111556053, 45.85943520069122, 39.588076919317245, 36.12605608999729, 37.41338901221752, 37.42824621498585, 37.92413480579853, 36.70138321816921, 38.131922855973244, 36.818872913718224, 36.57036244869232, 37.12651960551739, 38.573246374726295, 35.795606821775436, 35.537380278110504, 35.0590543448925, 34.77565795183182, 36.106559336185455, 34.77558955550194, 35.26430793106556, 35.76982140541077, 33.68335336446762, 35.68403720855713, 35.839828848838806, 37.78953082859516, 35.154729411005974, 44.28184725344181, 46.26844525337219, 49.811124354600906, 51.68041504919529, 54.3503075838089, 52.467193230986595, 51.57859571278095, 50.55714212357998, 50.34487031400204, 56.90278261899948, 53.27089190483093, 52.24930912256241, 40.83861641585827, 38.80939230322838, 41.76271542906761, 52.73547403514385, 56.44629791378975, 56.88133276998997, 47.15871088206768, 11.251722536981106, 0.21703801554394886, 5.711110644042492, 0.2189653879031539, 2.9080183943733573, 56.99878826737404, 55.11759661138058, 57.48264670372009, 56.27360478043556, 60.6679929792881, 39.35793846845627, 31.19791243225336, 31.691143065690994, 43.142250403761864, 32.57116824388504, 0.7611173868644983, 0.2623756241519004, 0.023559114342788234, 0.038615208977716975, 0.013527350201911759, 0.05143735746969469, 0.020370244928926695, 0.1185582546168007, 0.07421007729135454, 0.019878896782756783, 0.02847396692231996, 0.04672669754654635, 0.004604983660101425, 0.02178129587264266, 0.07324094374780543, 0.024903015764721204, 0.07946659054141492, 0.02052225718216505, 0.0657177779066842, 0.2352293612784706, 0.17161231400677934, 36.70337811112404, 63.98098200559616, 45.136626586318016, 49.409083127975464, 37.97893926501274, 59.83494468033314, 67.25496232509613, 60.555747002363205, 64.36829522252083, 56.97324983775616, 60.23526459932327, 40.49204841256142, 0.15254297788487747, 1.798757929354906, 5.795653257519007, 10.59637550264597, 17.82693151384592, 1.9125921023078263, 42.285358384251595, 63.012888953089714, 61.803976222872734, 58.7263123691082, 56.945815309882164, 58.21812003850937, 55.2506198734045, 52.44094043970108, 43.95558916032314, 44.541293531656265, 42.382952347397804, 48.81152719259262, 52.90016859769821, 56.04621738195419, 56.35917618870735, 55.20275764167309, 56.508599370718, 53.506935238838196, 52.92455568909645, 46.99687376618385, 45.494529381394386, 45.19470266997814, 42.42761895060539, 40.90024910867214, 41.10693521797657, 39.01288278400898, 38.98802071809769, 37.86006644368172, 39.31881956756115, 39.30467292666435, 39.05618146061897, 41.56215079128742, 39.10854645073414, 38.975876569747925, 40.37965804338455, 39.24556329846382, 39.94784541428089, 39.03051383793354, 37.83771224319935, 38.367004841566086, 42.6766499876976, 50.37379056215286, 50.38709744811058, 52.52895511686802, 50.56842751801014, 48.90568234026432, 49.576813727617264, 47.8412264585495, 45.9889892488718, 43.78810554742813, 40.70383384823799, 39.7029447555542, 37.40579701960087, 38.56186978518963, 40.66049337387085, 41.00464850664139, 43.34721140563488, 42.08397679030895, 42.662605941295624, 42.510629296302795, 41.846592128276825, 39.29486185312271, 38.82367953658104, 38.06144803762436, 37.58235074579716, 38.45290683209896, 37.249743193387985, 40.21054431796074, 40.78962564468384, 42.64060892164707, 48.573732152581215, 51.94304175674915, 50.31599946320057, 51.48948669433594, 51.159983575344086, 52.177857756614685, 50.19892014563084, 50.89465521275997, 48.648850321769714, 42.16029189527035, 37.811847031116486, 40.09849213063717, 39.443422481417656, 37.990760430693626, 38.98796372115612, 39.143702164292336, 39.92840565741062, 38.36969129741192, 37.685678601264954, 38.99694263935089, 38.09308134019375, 37.34155386686325, 37.95059658586979, 37.247873693704605, 37.90745370090008, 37.23967753350735, 37.56868667900562, 39.186662659049034, 36.31872855126858, 36.91887214779854, 37.30147361755371, 39.71193127334118, 37.16360181570053, 45.09594976902008, 48.18613775074482, 51.58227011561394, 53.439371064305305, 57.37751394510269, 53.99652376770973, 53.30331176519394, 52.25263774394989, 52.14433595538139, 58.0978374928236, 56.78675964474678, 54.7134654968977, 43.51849481463432, 41.10661223530769, 44.85947325825691, 54.413555189967155, 58.8622272759676, 58.021332398056984, 49.13438826799393, 13.68630699813366, 0.14807505591306835, 7.333673927932978, 0.2881899249041453, 3.848698055371642, 60.629288256168365, 60.23746468126774, 61.921234130859375, 60.54193094372749, 63.55580762028694, 49.33515049517155, 32.36314460635185, 31.639374643564224, 48.79533626139164, 40.0924314558506, 0.8619681908749044, 0.20451728662010282, 0.03854550275718793, 0.0454430343961576, 0.04386505774164107, 0.06341377302305773, 0.02979204902658239, 0.06277561507886276, 0.008420311060035601, 0.14199909288436174, 0.08029470860492438, 0.061873538288637064, 0.12495236151153222, 0.08908101721317507, 0.12742267426801845, 0.14366623858222738, 0.226921834400855, 0.14622157177655026, 0.1275039542815648, 0.3568209515651688, 0.3299246885580942, 42.89907105267048, 72.39297062158585, 54.24490123987198, 59.956401363015175, 39.46408197283745, 65.11733382940292, 73.58425229787827, 66.2567786872387, 67.20714569091797, 62.719043120741844, 62.02727124094963, 49.218739941716194, 0.2566422364907339, 5.517029883340001, 13.998806979507208, 16.693022958934307, 19.11606553941965, 2.2149745328351855, 46.34752281010151, 61.24995835125446, 65.35380274057388, 58.179244324564934, 59.00349609553814, 60.86179777979851, 58.42655785381794, 53.54530178010464, 46.40617646276951, 45.70066072046757, 46.384958401322365, 50.73837719857693, 56.051012724637985, 58.39026600122452, 58.48918989300728, 56.83518424630165, 62.08523713052273, 57.4089914560318, 54.71639893949032, 48.353366777300835, 49.15842957794666, 46.76166258752346, 45.67131109535694, 42.77956746518612, 43.932087421417236, 41.732206866145134, 42.16731011867523, 40.0691045075655, 41.502478793263435, 41.33035182952881, 41.18226997554302, 44.83154475688934, 40.64826563000679, 41.43316671252251, 41.707253605127335, 40.85132293403149, 43.3744103461504, 40.272727981209755, 40.89008845388889, 40.95572993159294, 46.16387106478214, 54.194553941488266, 51.726297587156296, 54.87571679055691, 52.05623008310795, 53.219837844371796, 51.984402537345886, 48.71329866349697, 47.15369515120983, 43.375409692525864, 40.49754671752453, 41.64641126990318, 38.8483402132988, 39.949768111109734, 43.32052543759346, 42.804535925388336, 43.726624846458435, 45.22770769894123, 47.5133116543293, 44.064597710967064, 44.17537696659565, 42.56968952715397, 39.9866983294487, 39.89793509244919, 39.8987140506506, 39.80134427547455, 39.3565059453249, 38.985756039619446, 42.06180118024349, 42.37046621739864, 51.640467792749405, 56.323112323880196, 54.36761185526848, 53.818814903497696, 53.583786115050316, 54.92130294442177, 52.08722122013569, 53.73928137123585, 50.68714074790478, 44.966836497187614, 40.939447805285454, 43.09532672166824, 41.05822183191776, 41.71827681362629, 39.656017273664474, 42.79113784432411, 39.69618871808052, 38.972901329398155, 39.969758838415146, 42.596808671951294, 42.37392023205757, 41.2228973954916, 39.59922552108765, 38.678113147616386, 40.244567692279816, 38.876842483878136, 40.18447771668434, 40.24782031774521, 37.73712024092674, 39.82884339988232, 40.60319624841213, 42.75109179317951, 38.83714981377125, 48.52207012474537, 50.01593716442585, 53.88229429721832, 54.66513589024544, 58.3323685079813, 56.6289085149765, 54.575479701161385, 53.96643318235874, 53.42709772288799, 59.38736289739609, 59.806009232997894, 57.49404229223728, 46.294447258114815, 43.11275638639927, 47.30691812932491, 56.458685249090195, 62.700408920645714, 60.11237919330597, 53.04864563047886, 15.961507111787796, 0.3236416366416961, 19.35009118169546, 1.581324334256351, 4.210326550528407, 67.50720039010048, 65.86500450968742, 65.99929690361023, 65.89385256171227, 69.56441760063171, 54.155777022242546, 42.067858055233955, 42.640278339385986, 58.15299153327942, 49.125777930021286, 1.19265743996948, 0.40001736022531986, 0.11227687995415181, 0.28965670557226986, 0.1578287614393048, 0.15673330693971366, 0.15442844858625904, 0.15429486200446263, 0.12445863292668946], [0.08462108817184344, 0.03261062200181186, 0.046767686362727545, 0.04794322230736725, 0.012627870000869734, 0.02844091723090969, 0.02754000004642876, 0.044079616345698014, 0.02498268717317842, 0.015170246224442963, 0.40014521742705256, 0.04892709490377456, 7.299214052036405, 55.450663939118385, 49.22246374189854, 57.668027356266975, 25.676916986703873, 40.23526959121227, 59.148686304688454, 55.7088752835989, 52.455402463674545, 52.643746957182884, 48.383715748786926, 47.21598140895367, 0.8206615573726594, 2.2591412253677845, 3.147832313552499, 3.2927076146006584, 6.806003842502832, 0.7789071416482329, 26.437299884855747, 54.45105157792568, 37.07202672958374, 51.70342281460762, 56.25697687268257, 57.37197384238243, 50.569993034005165, 49.97764281928539, 43.93919304013252, 45.4827082157135, 46.06219232082367, 51.4220517128706, 51.56308874487877, 53.846101239323616, 55.30381701886654, 52.16555781662464, 54.129668623209, 51.38201706111431, 45.778495743870735, 42.79563680291176, 41.883799731731415, 41.61391921341419, 39.9053218960762, 38.80301244556904, 38.29872630536556, 38.92144829034805, 37.82261185348034, 36.35495200753212, 36.85491397976875, 37.57180631160736, 38.70017856359482, 37.82883211970329, 37.4311226606369, 38.75204958021641, 39.069362953305244, 37.6290350407362, 35.32654859125614, 36.33645839989185, 36.410660818219185, 35.47980956733227, 40.7967958599329, 46.31602630019188, 47.332217171788216, 48.71639929711819, 46.95870861411095, 46.41193315386772, 50.051564052700996, 49.08416636288166, 44.897368624806404, 42.49515652656555, 37.843411937355995, 36.80896304547787, 36.78397178649902, 38.73118869960308, 38.829079046845436, 37.29613870382309, 36.93820931017399, 39.59312304854393, 39.93351258337498, 39.70058888196945, 38.3687299489975, 38.6836152523756, 38.64781737327576, 39.87640544772148, 38.94744649529457, 38.65580454468727, 37.53676079213619, 39.05254125595093, 38.253922909498215, 40.813720151782036, 47.07112178206444, 49.739984571933746, 48.24005305767059, 49.66720327734947, 48.82824249565601, 48.625663965940475, 49.2360670119524, 46.48865103721619, 47.047091871500015, 37.89285108447075, 35.3615865111351, 36.44991651177406, 37.26485498249531, 36.625573486089706, 35.54447449743748, 35.83426594734192, 36.896780133247375, 37.36312910914421, 38.28802227973938, 37.72299639880657, 36.50437518954277, 35.10868348181248, 34.900295063853264, 36.5987279266119, 35.89398354291916, 35.51955923438072, 34.85891908407211, 38.1960292160511, 36.131580993533134, 37.397441267967224, 36.08840391039848, 36.41354486346245, 36.52775153517723, 40.93063227832317, 45.73015473783016, 49.28375445306301, 51.16285242140293, 53.48443664610386, 51.22766174376011, 51.123281344771385, 52.24720783531666, 48.10712859034538, 52.877274826169014, 53.57281610369682, 52.2670541703701, 47.562709003686905, 39.190154671669006, 43.97560268640518, 50.99071025848389, 58.11299487948418, 55.546114817261696, 54.933409094810486, 14.390755947679281, 0.3919370047515258, 6.000321200117469, 0.694117957027629, 10.513225514441729, 62.77082294225693, 52.335537895560265, 57.576076090335846, 59.628330767154694, 59.763595908880234, 34.15715754032135, 29.750640392303467, 30.476228557527065, 45.73226362466812, 18.800802156329155, 0.47858595207799226, 0.04673496136092581, 0.12282176685403101, 0.07402324161375873, 0.14285774290328845, 0.035883923701476306, 0.07592374080559239, 0.13612184731755406, 0.05653914406138938, 0.09071207969100215, 0.022080338712839875, 0.02067221368633909, 0.04593848476361018, 0.056329854705836624, 0.018875444475270342, 0.0051862592317775125, 0.05851052206708118, 0.02248777778731892, 0.073260469653178, 0.46105695830192417, 0.10015209423727356, 11.023713871836662, 64.36040684580803, 53.13678950071335, 63.541110008955, 35.00715292990208, 48.562043979763985, 63.835860192775726, 59.20905366539955, 60.270682498812675, 56.95460423827171, 54.78075988590717, 50.88078215718269, 1.0197301441803575, 0.5778120760805905, 2.0165634294971824, 7.341367090120912, 9.10523671656847, 1.2359185935929418, 28.934453688561916, 56.00948475301266, 39.92216259241104, 53.0704602599144, 57.639281898736954, 58.76804172992706, 52.66220636665821, 51.11093960702419, 46.26972198486328, 47.0536845177412, 46.79482340812683, 53.993730917572975, 51.77813820540905, 55.17703302204609, 56.50943532586098, 54.45683106780052, 55.17640605568886, 53.624139949679375, 47.706508487463, 45.00648356974125, 44.88072171807289, 42.96062394976616, 42.70982600748539, 41.382435634732246, 40.52811607718468, 40.155470073223114, 39.213109239935875, 39.213272631168365, 38.15152980387211, 39.4254532456398, 40.51126018166542, 39.391163885593414, 38.44463847577572, 40.390996634960175, 41.78309753537178, 39.215039536356926, 36.7653451859951, 38.46632391214371, 39.57135781645775, 38.1254556030035, 43.589395210146904, 48.36231529712677, 49.472026750445366, 51.400662660598755, 49.39079470932484, 49.76187139749527, 51.09016612172127, 50.095117315649986, 46.85761883854866, 43.977810367941856, 39.411272406578064, 36.72001741826534, 36.12233228981495, 39.60127741098404, 40.04570536315441, 39.85780544579029, 40.00929571688175, 41.91130645573139, 41.25692456960678, 42.597177252173424, 39.363303780555725, 39.97362703084946, 40.125637874007225, 42.52288743853569, 38.825777024030685, 39.53762702643871, 37.968128845095634, 40.43369494378567, 40.031817108392715, 40.25529831647873, 49.15011562407017, 52.120507434010506, 50.536866411566734, 50.45340768992901, 51.58838398754597, 50.81073671579361, 50.68965241312981, 49.3098134547472, 48.952438831329346, 39.84628826379776, 37.41493932902813, 37.80776605010033, 38.071433901786804, 38.66430088877678, 37.99930617213249, 37.33957417309284, 39.01894345879555, 39.673074558377266, 39.64902564883232, 39.28305208683014, 37.70690806210041, 37.27097265422344, 37.224687337875366, 38.664490878582, 38.24925296008587, 37.41504952311516, 37.97816410660744, 40.689945593476295, 39.39494088292122, 38.223026767373085, 38.5936588793993, 39.438988119363785, 37.462862357497215, 43.770641684532166, 48.56672152876854, 52.42359437048435, 53.02357077598572, 55.26482351124287, 52.791163846850395, 55.048839300870895, 54.70940351486206, 50.06853014230728, 54.06102530658245, 56.597628593444824, 56.04556001722813, 51.74761824309826, 40.98558872938156, 46.118828281760216, 54.60281543433666, 62.33440116047859, 58.8616307079792, 57.63959728181362, 14.747055228799582, 1.0088763828389347, 5.368853034451604, 1.3230601488612592, 11.232354026287794, 69.33760017156601, 58.603803142905235, 63.29612575471401, 62.598528787493706, 64.51921552419662, 43.37021917104721, 31.60095300525427, 33.540044054389, 53.44018802046776, 24.212226681411266, 0.41771404969040304, 0.05438243693788536, 0.020639889444282744, 0.14354183978866786, 0.09049997388501652, 0.03491669747745618, 0.003644697444542544, 0.08216319896746427, 0.0592698430409655, 0.24082456104224548, 0.18085797491949052, 0.14358889195136726, 0.07767536517349072, 0.10399865306681022, 0.1244037362630479, 0.2035310020437464, 0.09870966343441978, 0.10323915397748351, 0.1888710175990127, 0.687775919213891, 0.16205913678277284, 13.386029060930014, 75.74407920241356, 63.598471730947495, 67.39572957158089, 37.983160838484764, 54.04027841985226, 69.59117576479912, 66.27970665693283, 65.32759934663773, 63.26660893857479, 58.113439455628395, 59.36766475439072, 1.4889223175123334, 5.908279689028859, 10.401943735778332, 9.30747326463461, 12.086258456110954, 2.658795230090618, 31.47383652627468, 56.4566295593977, 41.30227133631706, 53.84492330253124, 58.47596660256386, 61.28323696553707, 53.51177617907524, 53.60136017203331, 48.150024488568306, 50.42397066950798, 48.20806257426739, 54.414995312690735, 53.73250633478165, 57.65094727277756, 60.82665726542473, 55.304721370339394, 58.61490994691849, 55.23171588778496, 49.88007925450802, 48.30919034779072, 47.42287650704384, 45.24109058082104, 45.023202672600746, 43.6081700026989, 42.65670105814934, 44.729372039437294, 42.62281447649002, 40.72597526013851, 40.1625756919384, 40.950235426425934, 43.198084607720375, 41.493070498108864, 42.1488431096077, 42.209803238511086, 43.38845819234848, 41.55942253768444, 39.11593325436115, 41.767571568489075, 41.288595870137215, 41.55948333442211, 46.5574349462986, 51.13036796450615, 52.20066413283348, 54.364256635308266, 49.991417080163956, 51.144632399082184, 55.14581009745598, 52.38118104636669, 48.50494064390659, 43.77282276749611, 40.403748750686646, 38.47984738647938, 38.02265211939812, 40.90979039669037, 42.20995523035526, 41.64936751127243, 40.30032970011234, 44.15823608636856, 45.18269531428814, 44.25655201077461, 40.77334351837635, 42.29029431939125, 42.55233585834503, 43.097678795456886, 41.171991527080536, 42.466243878006935, 39.53850477933884, 40.204726830124855, 39.33749556541443, 40.92837519943714, 50.28021678328514, 54.97875586152077, 52.108545675873756, 53.668354377150536, 53.44654507935047, 53.82427141070366, 52.15589873492718, 52.99634523689747, 51.77643209695816, 41.230079010128975, 41.17180533707142, 39.831191673874855, 41.61288186907768, 41.00889667868614, 39.78180952370167, 39.63858760893345, 39.071635231375694, 40.321391969919205, 41.944022700190544, 41.41440711915493, 40.90830087661743, 38.912180587649345, 38.93335685133934, 40.586306154727936, 41.37692593038082, 39.24714021384716, 39.5431063324213, 43.277705535292625, 39.80229802429676, 41.481838300824165, 38.9650509506464, 41.53032749891281, 40.101619362831116, 45.67794553935528, 50.08544683456421, 55.19669696688652, 55.65224692225456, 58.63376073539257, 54.29030500352383, 55.793447345495224, 55.15250913798809, 50.99047087132931, 56.232145205140114, 60.42083144187927, 58.05404104292393, 54.7994776815176, 43.05002175271511, 49.63864780962467, 56.65209487080574, 65.20682662725449, 58.67876932024956, 59.136526957154274, 16.895436197519302, 1.6995122423395514, 17.975552938878536, 2.2252375446259975, 13.351484164595604, 71.61562353372574, 62.861056700348854, 67.36447244882584, 69.02939110994339, 70.17002150416374, 47.56832890212536, 39.261294454336166, 40.97298860549927, 62.18431681394577, 30.356905460357666, 0.6900733709335327, 0.2000851510092616, 0.2015557314734906, 0.22205315268365666, 0.21261963935103267, 0.10665499255992472, 0.18805542698828503, 0.41890326712746173, 0.15263264416716993], [0.038386267551686615, 0.025817885325523093, 0.05441715460619889, 0.03500768849335145, 0.022259921752265655, 0.040578538391855545, 0.13200721732573584, 0.0705015505081974, 0.07631132000824437, 0.03671859121823218, 0.12042814021697268, 0.10531061430810951, 0.25738488882780075, 38.135088086128235, 41.934830993413925, 50.67465841770172, 35.71169972419739, 34.1781210154295, 61.12876005470753, 57.76583030819893, 54.93386507034302, 54.77147318422794, 46.789758279919624, 56.173491552472115, 10.809331275522709, 1.7784114461392164, 1.6097430093213916, 7.427409198135138, 4.417998231947422, 2.7714558597654104, 37.439375817775726, 67.82037198543549, 46.13795265555382, 50.81676319241524, 52.64252722263336, 56.085108295083046, 52.650856375694275, 53.78503851592541, 53.772962763905525, 52.990254163742065, 53.95389385521412, 50.55016949772835, 52.814942970871925, 53.60952593386173, 52.77450554072857, 50.47578848898411, 48.88702154159546, 46.06033802032471, 41.0555087774992, 40.64221255481243, 40.244499295949936, 40.80632194876671, 38.412435203790665, 38.52742463350296, 37.58905738592148, 37.31705278158188, 37.5911320745945, 36.56799517571926, 36.41425542533398, 37.7292774617672, 38.857900500297546, 38.10912407934666, 39.417542070150375, 36.74637280404568, 37.27554760873318, 37.5287926197052, 37.40098647773266, 38.46344366669655, 37.161967903375626, 36.05260223150253, 39.67165343463421, 46.92603416740894, 48.07341679930687, 48.82880486547947, 47.14991055428982, 47.774532437324524, 50.05305737257004, 47.44305722415447, 42.834109738469124, 39.212448075413704, 36.359363570809364, 36.82246372103691, 38.20172131061554, 40.29964953660965, 37.24182441830635, 37.08762489259243, 37.97516226768494, 37.45866358280182, 37.93146461248398, 38.65927755832672, 37.434648871421814, 38.927539363503456, 38.347933664917946, 39.437285810709, 37.54497595131397, 38.0689412355423, 36.72585770487785, 39.19059544801712, 38.19265499711037, 40.022959783673286, 47.59376473724842, 49.05543990433216, 49.79366049170494, 46.53687804937363, 48.593403697013855, 49.74399335682392, 47.87831246852875, 45.40596753358841, 47.3778261244297, 40.8181507140398, 35.15018865466118, 37.1491663902998, 35.24228811264038, 36.20797969400883, 36.437954753637314, 37.25083373486996, 36.034218817949295, 39.32223178446293, 38.14787060022354, 37.540184408426285, 36.62132151424885, 35.34262552857399, 34.74420323967934, 36.99107967317104, 36.51149220764637, 38.02027344703674, 36.00803442299366, 36.34565390646458, 35.76437629759312, 36.60316228866577, 37.62942261993885, 36.99776351451874, 36.12274266779423, 37.23717346787453, 41.680294051766396, 43.5971087962389, 45.3776628524065, 49.2848601937294, 51.00468970835209, 52.20589645206928, 54.16344881057739, 47.63063035905361, 47.4145245552063, 58.76343637704849, 51.0314554721117, 53.018406853079796, 39.60179038345814, 43.26880641281605, 51.54530189931393, 61.58528655767441, 54.598616659641266, 44.45547133684158, 1.961726553272456, 1.3034545071423054, 2.3814604617655277, 0.7562540634535253, 15.577916745096445, 58.128300458192825, 55.04503570497036, 58.890702947974205, 52.5664971023798, 50.11218219995499, 33.921703174710274, 29.79005567729473, 36.669673919677734, 44.12344515323639, 8.593515325337648, 0.7727891730610281, 0.032330294270650484, 0.1791551022324711, 0.04340022096585017, 0.0775543283089064, 0.039765641777194105, 0.020781647071999032, 0.008873472925188253, 0.05312871573551092, 0.02948031175037613, 0.0664170368690975, 0.01560427830554545, 0.07318153482628986, 0.036774233740288764, 0.020736997612402774, 0.04028979099530261, 0.09182406181935221, 0.07620238757226616, 0.15875034558121115, 0.10011658989242278, 0.06665752982371487, 1.0592183377593756, 48.929206877946854, 49.66589234769344, 54.48012001812458, 31.24044544994831, 43.97005498409271, 66.62369459867477, 63.13116140663624, 60.70843420922756, 58.76432552933693, 52.06498861312866, 61.12274497747421, 10.900580529123545, 0.9878316277172416, 2.3714365996420383, 6.167752090841532, 4.3652556370943785, 2.255611689761281, 39.96462531387806, 63.43660421669483, 48.16681958734989, 51.19861230254173, 53.153611198067665, 57.4560671299696, 55.72215177118778, 55.03747411072254, 56.65352739393711, 55.50695411860943, 55.865753665566444, 52.91352868080139, 55.617904365062714, 56.62652984261513, 55.47939419746399, 53.79067361354828, 51.26363441348076, 48.69376391172409, 44.264922961592674, 42.11994186043739, 41.92582927644253, 43.64366389811039, 41.008041724562645, 40.21712176501751, 40.82966409623623, 40.09052015841007, 38.59340809285641, 38.57052952051163, 38.49957212805748, 39.57726649940014, 41.949855387210846, 38.530130088329315, 41.69170863926411, 38.321616277098656, 38.832430467009544, 39.335109293460846, 39.200691506266594, 40.254530757665634, 37.421022802591324, 38.48069094121456, 42.645833641290665, 47.55838103592396, 49.511704221367836, 49.8907794803381, 48.91005590558052, 49.72070820629597, 53.26239176094532, 48.18074584007263, 43.961619436740875, 39.34252269566059, 36.89692072570324, 36.46631643176079, 39.37327444553375, 41.60041853785515, 40.23873120546341, 39.13249656558037, 39.47754465043545, 40.04944436252117, 40.078353211283684, 41.14822380244732, 39.28264170885086, 39.518411457538605, 40.44614687561989, 40.30947580933571, 39.54049967229366, 39.11706179380417, 38.836203664541245, 39.081883281469345, 38.880513086915016, 40.90585000813007, 48.25894184410572, 51.2558676302433, 50.899568349123, 50.26309870183468, 50.514759197831154, 50.78325279057026, 49.739384204149246, 48.68404783308506, 50.64815104007721, 40.77650494873524, 37.06554427742958, 37.128009125590324, 37.43710733950138, 37.35613368451595, 37.142630741000175, 38.51743496954441, 38.143713623285294, 39.409414306283, 38.55006381869316, 37.93280214071274, 38.74791540205479, 37.91502669453621, 38.03445428609848, 38.65296229720116, 37.02617458999157, 39.63415324687958, 36.82836100459099, 38.06815467774868, 38.765288069844246, 37.82742239534855, 38.898227736353874, 40.49097687005997, 37.86543935537338, 38.777660205960274, 42.793482318520546, 45.96695423126221, 46.97329603135586, 51.45290605723858, 53.387097269296646, 53.446461483836174, 56.860768273472786, 50.460273921489716, 49.522336050868034, 59.841632321476936, 54.627711698412895, 56.03372365236282, 41.76593765616417, 45.91732509434223, 53.02340738475323, 64.50455591082573, 56.30866929888725, 46.724888160824776, 2.8517958987504244, 2.4117787973955274, 7.00742200948298, 1.0168949025683105, 17.11678571999073, 65.14163732528687, 60.59824392199516, 63.49682718515396, 60.91556489467621, 56.62733919918537, 41.84093423187733, 30.56809052824974, 39.448343217372894, 53.33374813199043, 11.979122254997492, 0.6147459161002189, 0.069936212094035, 0.19717392831807956, 0.12347342446446419, 0.10380654814071022, 0.023159957636380568, 0.057141018405673094, 0.03451422708167229, 0.038302976317936555, 0.21131923334905878, 0.12838751077651978, 0.12390177726047114, 0.20364973082905635, 0.07007187668932602, 0.07980639769812115, 0.20969657198293135, 0.2009483429719694, 0.1473641229677014, 0.2577331045176834, 0.2699839440174401, 0.1868702023057267, 1.6126652900129557, 59.65228848159313, 56.365062072873116, 63.77286717295647, 48.57301019132137, 49.53548714518547, 72.25786507129669, 68.74987810850143, 66.5215028822422, 67.44417697191238, 57.015651762485504, 65.34629434347153, 15.602495726197958, 2.271145493723452, 9.98321570456028, 19.505793526768684, 6.843782365322113, 5.084615461528301, 41.46182857453823, 65.14545232057571, 46.65233105421066, 50.8826744556427, 53.514284044504166, 60.60492776334286, 58.424289375543594, 59.19534020125866, 58.56782287359238, 59.07766431570053, 60.919729471206665, 54.3021185696125, 58.42474915087223, 56.99389033019543, 57.1429867297411, 54.63023476302624, 52.53287650644779, 48.53203698992729, 47.301218435168266, 46.2233454734087, 43.88592749834061, 45.208416134119034, 43.922808319330215, 43.20821486413479, 43.707914650440216, 42.111650705337524, 43.24581004679203, 41.14062421023846, 40.71812868118286, 42.31793783605099, 43.9008416980505, 39.931179508566856, 43.41571792960167, 39.507297053933144, 41.01618088781834, 41.68238393962383, 42.57661275565624, 42.7271568775177, 40.53161948919296, 41.110146045684814, 45.22359251976013, 51.600011363625526, 54.337202087044716, 54.60356019437313, 51.279126182198524, 52.426212430000305, 55.254712253808975, 50.501015335321426, 44.489525109529495, 41.39822758734226, 37.378601878881454, 39.191465601325035, 41.40802726149559, 43.8246975839138, 43.173895105719566, 42.36467532813549, 42.86534406244755, 42.45466209948063, 42.77505710721016, 42.5156906247139, 41.91344194114208, 43.6906673759222, 44.50632780790329, 41.10327981412411, 40.45874319970608, 40.48476040363312, 38.380228132009506, 41.06416091322899, 39.481333047151566, 41.91374972462654, 49.219203516840935, 52.34932355582714, 52.696674317121506, 50.87030231952667, 52.96201787889004, 54.3117206543684, 52.48284079134464, 51.953187212347984, 53.240580931305885, 44.116297736763954, 40.170160084962845, 42.1489305049181, 39.804745092988014, 39.77918766438961, 38.256590366363525, 40.59043653309345, 39.08338040113449, 42.71054796874523, 41.13778576254845, 40.08702054619789, 40.89685969054699, 40.02527765929699, 40.87588481605053, 41.1673329770565, 39.416048750281334, 42.4735888838768, 38.97518880665302, 40.451717376708984, 40.366085171699524, 40.19922852516174, 41.789815574884415, 43.069723695516586, 40.6064260751009, 40.925711542367935, 45.201223120093346, 49.33005876839161, 49.05143491923809, 54.650590270757675, 54.85189966857433, 56.49834752082825, 57.44890071451664, 52.3813596367836, 49.24640245735645, 59.603882879018784, 55.913482904434204, 58.44098187983036, 44.60807494819164, 48.38616281747818, 56.829503551125526, 67.19394519925117, 56.5134859085083, 51.0299963504076, 3.815251775085926, 4.759144876152277, 8.633339088410139, 2.1486367424950004, 21.192849799990654, 71.93031504750252, 63.400281965732574, 67.29758083820343, 63.0601242184639, 61.83780200779438, 47.21881605684757, 38.70618984103203, 49.504097029566765, 64.2896318435669, 16.5217262506485, 0.9626427793409675, 0.1378717424813658, 0.27814465924166143, 0.21668092376785353, 0.17981883458560333, 0.10660452651791275, 0.1502337260171771, 0.1272200234234333, 0.3099576506065205], [0.04376584001875017, 0.06759037976735272, 0.05414685329014901, 0.024619224059279077, 0.03669201862066984, 0.0712562924309168, 0.02120799235854065, 0.1173508471401874, 0.0527371845964808, 0.1889174760435708, 0.10325660929083824, 0.19857700302964076, 0.07288828259333968, 23.407205678522587, 47.548885345458984, 48.17616328597069, 48.560071885585785, 27.366579920053482, 52.43926092982292, 57.39705249667168, 56.616870760917664, 58.7589830160141, 47.6513734459877, 48.83838415145874, 25.287261195480824, 0.20729162759380415, 1.0813952540047467, 5.383149767294526, 2.658553230576217, 1.532984753139317, 42.08154872059822, 53.15224327147007, 58.63599121570587, 52.061629593372345, 52.25864142179489, 54.47366036474705, 57.24093407392502, 55.60505725443363, 55.578758865594864, 54.893294647336006, 54.976069405674934, 53.81784975528717, 54.46782007813454, 54.39487539231777, 56.444648802280426, 50.6290190666914, 49.600353464484215, 41.49612173438072, 38.88942360877991, 38.190063536167145, 39.68628264963627, 38.72382089495659, 37.30750769376755, 36.52370475232601, 38.15931938588619, 36.52273580431938, 37.73285686969757, 36.51498042047024, 35.61545088887215, 38.141897320747375, 39.449304565787315, 36.48222237825394, 39.65623006224632, 38.861544504761696, 38.09883423149586, 37.13933251798153, 36.31133794784546, 38.94483603537083, 35.430191829800606, 34.677220433950424, 38.55134055018425, 44.26470257341862, 46.46494410932064, 48.3530779927969, 46.49081692099571, 47.61316269636154, 50.35349205136299, 43.92863340675831, 39.802165031433105, 35.870371609926224, 38.82901445031166, 36.15711182355881, 37.482944279909134, 38.28814387321472, 35.969477891922, 35.69579377770424, 36.68322779238224, 37.51461558043957, 38.42313542962074, 36.72792099416256, 37.61254772543907, 37.36675411462784, 37.40869626402855, 36.847986951470375, 37.40023411810398, 37.84756891429424, 38.71307887136936, 38.95584784448147, 37.83127158880234, 37.849749997258186, 43.47668945789337, 46.794861406087875, 47.96169899404049, 47.878612652421, 47.56513327360153, 48.96559752523899, 47.567656338214874, 46.50370582938194, 43.580530285835266, 37.21987299621105, 35.999249294400215, 36.774840876460075, 36.36037811636925, 34.91784632205963, 36.76333129405975, 37.05155722796917, 37.7828773856163, 36.99452988803387, 37.35714063048363, 35.60739912092686, 35.644777715206146, 34.11332309246063, 34.99261111021042, 34.501928240060806, 34.553711861371994, 34.627108722925186, 36.19205094873905, 35.93595989048481, 35.19238159060478, 36.478129997849464, 36.97889752686024, 35.98957881331444, 35.73416791856289, 35.43474778532982, 37.306690737605095, 38.77938911318779, 41.303988844156265, 45.56455582380295, 49.159254133701324, 51.12477466464043, 53.608215004205704, 54.448893293738365, 45.615533888339996, 50.94014257192612, 56.109058409929276, 52.959992587566376, 47.19056837260723, 41.50580361485481, 55.81319488584995, 54.92167912423611, 60.94027116894722, 32.04133227467537, 0.4525211319560185, 1.4745242963545024, 1.2300447025336325, 0.07671524872421287, 25.816470198333263, 59.89506505429745, 53.70337329804897, 53.73665191233158, 47.909447997808456, 48.94569419324398, 31.673643104732037, 31.777094453573227, 39.53873656690121, 39.03619833290577, 1.8498104461468756, 0.27554105676244944, 0.0984821209567599, 0.0012909339943689702, 0.043107978053740226, 0.06407737178960815, 0.04030717580462806, 0.04903918888885528, 0.057886264548869804, 0.02976589759782655, 0.02570986016507959, 0.06933937693247572, 0.03369916339579504, 0.0596261889586458, 0.0207161877915496, 0.10139894686290063, 0.014173965846566716, 0.03494682125165127, 0.021758524926553946, 0.12043509414070286, 0.06634812845732085, 0.23148117412347347, 0.052645967225544155, 31.000695414841175, 50.8472603559494, 52.886116951704025, 47.65761651098728, 35.51625721156597, 63.05419273674488, 62.398811504244804, 61.95956647396088, 62.48143047094345, 52.628407180309296, 56.74730636179447, 26.566931828856468, 0.33661387336906046, 1.5925756492652, 8.193253353238106, 2.280333638191223, 2.141086310148239, 45.705991834402084, 53.14735673367977, 57.032013684511185, 53.63921374082565, 52.92794890701771, 56.98918238282204, 59.74617764353752, 58.43236394226551, 58.25817368924618, 55.65018743276596, 54.83262710273266, 57.05497585237026, 58.181945979595184, 53.95325168967247, 57.75790013372898, 51.14750884473324, 51.13642483949661, 43.16841959953308, 42.44078144431114, 40.07137678563595, 41.96566253900528, 41.391756534576416, 42.082358077168465, 39.55276161432266, 39.53560933470726, 38.17543812096119, 41.40399947762489, 38.406990095973015, 40.38234069943428, 39.761860594153404, 42.219329327344894, 38.43898817896843, 41.1075583845377, 40.00619888305664, 39.31373544037342, 39.8745359480381, 38.16288359463215, 39.34877336025238, 38.25063228607178, 36.29977136850357, 41.26616567373276, 47.964130863547325, 48.18378947675228, 48.7311577051878, 47.98965409398079, 50.55996157228947, 51.402205377817154, 46.05631023645401, 39.157233238220215, 38.53275954723358, 38.93978990614414, 38.75945158302784, 40.613155514001846, 40.05916424095631, 38.553540632128716, 38.6246158182621, 39.30065654218197, 39.235721826553345, 39.16932798922062, 39.936427026987076, 40.9165046364069, 39.19375687837601, 39.14385035634041, 39.379141330718994, 38.04035156965256, 39.21146012842655, 39.46516111493111, 39.280802607536316, 38.10675300657749, 37.982518672943115, 44.19149950146675, 47.10347704589367, 50.509504079818726, 50.49206681549549, 49.51268456876278, 51.389479860663414, 49.95116204023361, 48.466387912631035, 45.57824268937111, 41.608363911509514, 37.91988283395767, 38.66681635379791, 38.31652835011482, 36.9077767431736, 37.74281233549118, 38.74623589217663, 37.309836968779564, 38.571137487888336, 39.95633415877819, 38.012145683169365, 37.7056997269392, 37.251912876963615, 37.25830793380737, 37.86070480942726, 38.18064384162426, 37.33683072030544, 39.01974141597748, 38.572585210204124, 38.34605276584625, 38.12275394797325, 38.61074656248093, 36.39121726155281, 37.32773780822754, 38.65448221564293, 39.68833073973656, 42.339425683021545, 44.16141651570797, 47.13061898946762, 51.58116437494755, 52.007117718458176, 54.86357644200325, 57.15750955045223, 46.72781780362129, 49.96859170496464, 57.129729241132736, 54.342157021164894, 50.52942641079426, 44.09810811281204, 57.067883759737015, 58.1163576990366, 61.234781965613365, 34.846220165491104, 0.8881731878500432, 3.6014324985444546, 0.9157232532743365, 0.2774597756797448, 27.146567925810814, 66.85785323381424, 57.5334195792675, 60.150320157408714, 51.66569083929062, 55.93436278402805, 41.46451883018017, 32.30935089290142, 44.346174001693726, 47.05272696912289, 3.2781432336196303, 0.3947666357271373, 0.04769253224367276, 0.12699760176474229, 0.049891775561263785, 0.07644321449333802, 0.041088865109486505, 0.10776516384794377, 0.11770273646106943, 0.021948457215330563, 0.09172566045890562, 0.15024570428067818, 0.14123292930889875, 0.1798457745462656, 0.07761416767607443, 0.15846286725718528, 0.1063719745434355, 0.19758832873776555, 0.16192320501431823, 0.44343291025143117, 0.18669897399377078, 0.3751582629047334, 0.16623618139419705, 37.409121841192245, 62.31255233287811, 59.21027719974518, 61.93400904536247, 42.197925075888634, 65.11421039700508, 68.38740035891533, 67.46850326657295, 66.75715863704681, 58.949725180864334, 63.30669678747654, 30.793141052126884, 0.44470685126725584, 4.919232185930014, 20.139542520046234, 4.814276592805982, 3.462091125547886, 48.684952184557915, 53.1478963047266, 57.91700519621372, 53.29760827124119, 53.00761163234711, 57.26542375981808, 60.140391290187836, 58.882958963513374, 59.86691236495972, 59.531268775463104, 58.49368505179882, 58.33520695567131, 58.22701916098595, 56.85730665922165, 61.27737767994404, 52.751193791627884, 55.11377401649952, 45.22962659597397, 44.56508785486221, 43.80696773529053, 43.671144023537636, 43.5539735108614, 43.57397563755512, 40.82499414682388, 42.81080558896065, 41.83123715221882, 43.52741293609142, 41.967957615852356, 41.77847698330879, 43.111973628401756, 42.98325173556805, 39.95598837733269, 43.10297191143036, 42.029594108462334, 42.16893643140793, 42.61393055319786, 38.81843961775303, 42.716912627220154, 42.081791907548904, 38.760587722063065, 43.74672196805477, 50.79241789877415, 51.6280310600996, 51.152703166007996, 50.813012793660164, 52.39209786057472, 53.169946521520615, 48.33837278187275, 42.145978063344955, 38.874148428440094, 42.112448662519455, 39.42370913922787, 42.11198128759861, 42.235364466905594, 41.19981363415718, 41.133564189076424, 41.56231038272381, 41.74188494682312, 41.868733540177345, 42.1382150799036, 42.19418607652187, 41.72608159482479, 42.757920026779175, 40.73026143014431, 41.474702283740044, 41.808586567640305, 41.760891526937485, 41.77482917904854, 39.179040268063545, 38.31188499927521, 46.322436556220055, 48.40198136866093, 52.47137300670147, 53.1469539552927, 51.18716351687908, 55.41858226060867, 50.47315903007984, 50.05824029445648, 48.86858493089676, 43.64849343895912, 42.09075562655926, 42.18118317425251, 41.16457812488079, 38.7881438434124, 40.6430447101593, 41.39190852642059, 38.8782674074173, 40.78685559332371, 40.753246396780014, 39.748302921652794, 39.90505591034889, 38.134092539548874, 39.86551143229008, 40.242310613393784, 40.02891406416893, 40.53930267691612, 42.937980964779854, 40.687783509492874, 40.42020186781883, 41.08527638018131, 41.2023138999939, 39.6591255068779, 39.16035287082195, 40.108367800712585, 40.166052505373955, 44.23097938299179, 44.32390719652176, 48.66819128394127, 52.89100728929043, 53.74029591679573, 58.017509803175926, 58.55114556849003, 47.82049857079983, 52.61616803705692, 59.09580074250698, 57.74950638413429, 52.38594979047775, 47.76416279375553, 62.13355153799057, 60.44211409986019, 62.89590083062649, 38.29564847052097, 2.154337386600673, 4.205965809524059, 4.455320779234171, 0.39916920417454094, 30.680634789168835, 71.4644068479538, 61.33710667490959, 64.58390325307846, 56.86752051115036, 60.46017073094845, 43.687589541077614, 41.385821253061295, 52.45171666145325, 57.526579946279526, 4.768219264224172, 0.6244147941470146, 0.15734640997834504, 0.27621433313470334, 0.2310204488458112, 0.21051100484328344, 0.10247094207443297, 0.18480689817806706, 0.21173945220652968, 0.10365578084019944], [0.06436091673094779, 0.019499891241139267, 0.059832413244294, 0.024843044666340575, 0.030200141191016883, 0.04817464992811438, 0.037186856716289185, 0.09372171116410755, 0.04918018952594139, 0.044944281471543945, 0.0912704567599576, 0.26741899258922786, 0.25132379843853414, 9.430692102760077, 55.49838937819004, 51.450432389974594, 53.18305961787701, 28.362004905939102, 46.15207649767399, 58.42379540205002, 59.4178182631731, 56.162171959877014, 50.39393708109856, 52.25075304508209, 41.48329362273216, 0.583908255212009, 1.9016739819198847, 2.3649080749601126, 4.935514312237501, 1.2633108487352729, 45.89625142514706, 61.133741587400436, 55.224321484565735, 55.49181953072548, 56.913239657878876, 54.90165799856186, 57.49254137277603, 56.54700011014938, 54.35585528612137, 54.212724566459656, 54.219651594758034, 49.20595362782478, 49.600353464484215, 53.44870336353779, 51.166405230760574, 50.25104574859142, 44.28665779531002, 38.19497287273407, 38.07299181818962, 36.89905621111393, 37.30293653905392, 36.542677134275436, 37.985151931643486, 36.303248181939125, 37.690774127840996, 36.76107421517372, 36.13606855273247, 35.77737160027027, 37.58789844810963, 37.96254314482212, 38.14840257167816, 37.125976234674454, 38.9888908714056, 37.16234788298607, 38.044747933745384, 37.64451161026955, 37.99989514052868, 38.42195749282837, 36.7781201004982, 36.05251483619213, 38.64756278693676, 44.18240658938885, 44.31240901350975, 45.85333272814751, 46.35460563004017, 48.24230253696442, 48.3246935158968, 39.66970793902874, 37.677756026387215, 37.12201684713364, 37.57992647588253, 38.464845791459084, 38.43400664627552, 37.13904373347759, 35.599799528717995, 35.823732912540436, 37.66298621892929, 37.35374741256237, 37.79743440449238, 37.279902175068855, 37.84658096730709, 37.1666606515646, 36.63874737918377, 37.27226838469505, 35.459028482437134, 37.912021055817604, 39.01313357055187, 38.16262520849705, 37.54170052707195, 38.36943671107292, 40.46191602945328, 45.38194142282009, 49.59602929651737, 47.18825429677963, 48.63583981990814, 46.54123641550541, 46.515488997101784, 45.09348750114441, 42.84676305949688, 38.47599819302559, 34.83324386179447, 34.809483736753464, 36.65632903575897, 34.91731055080891, 35.81445761024952, 37.59984880685806, 36.40905350446701, 37.26199373602867, 36.74286559224129, 36.498607099056244, 36.894884034991264, 35.07842190563679, 34.16676722466946, 36.15808457136154, 35.82211419939995, 36.09520934522152, 34.914821684360504, 37.23953694105148, 36.646248176693916, 35.81702247262001, 36.126333475112915, 35.843085274100304, 37.27449506521225, 36.42039969563484, 35.1863057166338, 36.59156531095505, 36.241497695446014, 38.71207192540169, 40.746114179492, 48.59389007091522, 49.89763431251049, 54.05722551047802, 51.315691620111465, 45.90214490890503, 54.18756991624832, 53.60655069351196, 50.41262827813625, 44.46779407560825, 52.361083924770355, 54.94809910655022, 56.44169256091118, 19.155857004225254, 0.4666887904750183, 0.9203563327901065, 2.721565724350512, 0.33434011100325733, 30.78028254210949, 53.60562354326248, 55.782146751880646, 52.56411463022232, 52.16664835810661, 38.52259889245033, 30.1335933431983, 28.95360466092825, 46.592898443341255, 23.88126064091921, 0.4950961552094668, 0.09167472686385736, 0.13455570791848004, 0.020487654546741396, 0.0482054305030033, 0.023120714722608682, 0.03076238299399847, 0.03608845960116014, 0.030864945947541855, 0.02030832754826406, 0.016649923563818447, 0.0343632631120272, 0.04864398040808737, 0.08652998105389997, 0.04354684708232526, 0.09669610546552576, 0.02782728726742789, 0.06755220369086601, 0.058911177911795676, 0.03727264156623278, 0.06797999987611547, 0.4014607780845836, 0.2996518911095336, 14.58403542637825, 61.95695601403713, 53.08643460273743, 57.47744478285313, 36.809149235486984, 53.81443373858929, 67.08828806877136, 66.70401468873024, 61.16379037499428, 54.44637402892113, 58.010913357138634, 43.82729284465313, 0.6626791565213352, 2.166391764767468, 4.623039029538631, 8.02756229415536, 1.4922368084080517, 48.444007113575935, 58.87917056679726, 55.804371759295464, 55.1235356926918, 60.21025814116001, 56.233699321746826, 60.0645549595356, 56.43316961824894, 58.11094678938389, 55.87281748652458, 56.829374358057976, 49.90967206656933, 51.28001533448696, 55.25739870965481, 55.051582753658295, 51.561344638466835, 47.47072733938694, 40.862118154764175, 39.92722012102604, 39.410957023501396, 40.3167562186718, 38.7886568158865, 41.37701332569122, 39.628191366791725, 41.05094522237778, 39.51138563454151, 38.884293884038925, 38.14545392990112, 39.476598501205444, 39.91799421608448, 41.27633012831211, 40.314609333872795, 39.413210302591324, 38.5973446816206, 40.755982249975204, 39.54748749732971, 41.29135072231293, 39.762194976210594, 39.81390260159969, 38.54815252125263, 39.26952101290226, 46.32733069360256, 45.51360435783863, 47.57660485804081, 48.93436700105667, 50.11117905378342, 51.14221192896366, 41.74202173948288, 39.2409161478281, 37.145332396030426, 38.33737403154373, 40.65646559000015, 39.243568405508995, 38.91292914748192, 38.03158164024353, 38.207128420472145, 38.68485018610954, 39.51171241700649, 38.91837805509567, 38.90692166984081, 40.062010288238525, 39.003805071115494, 38.250039517879486, 38.76889407634735, 38.94387848675251, 38.52318026125431, 40.49103006720543, 39.74584445357323, 39.01890926063061, 39.28000085055828, 40.469048246741295, 46.38317249715328, 50.442935451865196, 49.526067450642586, 49.58716817200184, 48.16012814640999, 49.88527737557888, 47.135296538472176, 45.581035539507866, 39.79352429509163, 36.410189643502235, 36.63955293595791, 38.98222602903843, 37.183911725878716, 36.96981601417065, 38.88049028813839, 38.35487209260464, 38.068185076117516, 38.9945487678051, 38.32610763609409, 38.66558521986008, 37.51289427280426, 37.39884339272976, 38.32831151783466, 37.28159688413143, 39.17612202465534, 37.37737454473972, 38.254660069942474, 38.91807407140732, 38.403809666633606, 38.88066507875919, 39.23230201005936, 39.52734097838402, 38.72573599219322, 37.55539879202843, 39.27522450685501, 39.73124943673611, 41.02979935705662, 44.31703336536884, 50.811736062169075, 51.254499703645706, 55.981552451848984, 53.11631619930267, 46.242378652095795, 56.45435728132725, 54.99446801841259, 53.71129207313061, 47.4668325483799, 55.8121233433485, 57.43041850626469, 57.858765721321106, 21.615227535367012, 0.31692315184045583, 0.8324073802214116, 1.4630459435284138, 0.3240844910033047, 34.69339236617088, 59.55415494740009, 60.949630066752434, 56.67083166539669, 51.875162199139595, 50.21233342587948, 39.76976417005062, 31.693099960684776, 51.82607263326645, 30.773501805961132, 0.38758988957852125, 0.13076861738227308, 0.08679069753270596, 0.027746068481064867, 0.004651902700061328, 0.04809624202607665, 0.07406004471704364, 0.032223469534073956, 0.0776440094341524, 0.007665067259949865, 0.3599135996773839, 0.07745122173218988, 0.20992607373045757, 0.11822349406429566, 0.1216398818360176, 0.19719484203960747, 0.1708751980913803, 0.188513079774566, 0.17571711796335876, 0.09137780842138454, 0.1545856799930334, 0.49783331458456814, 0.6541445176117122, 15.415313970297575, 73.41837599873543, 61.20004042983055, 64.2922081053257, 42.33603246510029, 60.32113619148731, 68.974180072546, 68.60830530524254, 65.88889762759209, 60.155028104782104, 63.718799874186516, 50.07284291088581, 0.9924192877952009, 5.168433738872409, 12.295945454388857, 9.724708925932646, 3.790411320514977, 51.28083609044552, 59.37284007668495, 56.975769102573395, 57.4916598200798, 61.601747274398804, 57.31379896402359, 61.675014942884445, 58.65953475236893, 58.629314973950386, 57.95133635401726, 58.68811681866646, 49.012832790613174, 50.652589201927185, 58.447760716080666, 56.424487084150314, 54.796787425875664, 49.424468502402306, 43.00378203392029, 42.57862664759159, 42.003698498010635, 42.97155976295471, 39.451071470975876, 43.814605325460434, 41.572957411408424, 43.425806388258934, 42.4473474919796, 41.414977088570595, 40.42820803821087, 41.713762655854225, 42.02582471072674, 44.24801766872406, 43.281581327319145, 41.381379291415215, 40.359405130147934, 41.6396514326334, 41.17402821779251, 41.777614429593086, 42.501555383205414, 43.035764917731285, 40.21492928266525, 40.81199124455452, 49.56296727061272, 49.1352242231369, 50.32595872879028, 51.304406225681305, 51.39913134276867, 52.16765150427818, 42.53525957465172, 41.334713995456696, 39.461634904146194, 40.815202072262764, 44.32187810540199, 41.365917921066284, 41.63712836802006, 40.55235117673874, 39.63729947805405, 42.032029777765274, 42.03225016593933, 41.99896015226841, 42.42425233125687, 43.871708661317825, 41.65108501911163, 40.53244024515152, 42.943958044052124, 39.399553835392, 43.347739577293396, 44.407126531004906, 42.426976785063744, 41.03790432214737, 41.46134980022907, 42.37583912909031, 47.40958862006664, 52.72491440176964, 51.24308131635189, 51.761377304792404, 51.829731836915016, 52.48272679746151, 48.76998022198677, 48.47688674926758, 42.75051802396774, 40.021439865231514, 39.18848656117916, 39.52855311334133, 39.12706285715103, 39.905272498726845, 41.522997692227364, 39.7531970590353, 40.33870004117489, 41.94380611181259, 39.768601432442665, 41.10333301126957, 39.568146988749504, 37.88195326924324, 42.113280817866325, 39.35463644564152, 41.4384750276804, 38.568238243460655, 42.32741832733154, 41.32231146097183, 39.98297452926636, 41.24835982918739, 40.82583390176296, 40.72113811969757, 41.40387788414955, 38.12636375427246, 41.983289793133736, 40.76801620423794, 42.05093756318092, 46.927029713988304, 53.17255698144436, 52.26702757179737, 58.31834726035595, 56.465023308992386, 48.06868985295296, 57.169209122657776, 58.06994318962097, 56.23244918882847, 51.06371194124222, 56.4141858369112, 61.99192553758621, 57.977737337350845, 27.9482489079237, 0.8470092841889709, 2.8187868325039744, 9.427246637642384, 0.5016165459528565, 36.2807609885931, 61.129136234521866, 66.36651679873466, 62.14411877095699, 59.83540825545788, 53.02998103201389, 39.91426281630993, 40.21624021232128, 60.351804345846176, 39.5195247977972, 0.5317456042394042, 0.23918928316561505, 0.14282054646173492, 0.12765122606651857, 0.11503375819302164, 0.17724142991937697, 0.22067232755944133, 0.1966377711505629, 0.1842279190896079, 0.11798755047493614], [0.034597043340909295, 0.03210360897355713, 0.02658036413777154, 0.0012904164623250836, 0.013252689695946174, 0.038170525222085416, 0.034778728513629176, 0.03302716722828336, 0.05130505480337888, 0.039888166647870094, 0.0753445910231676, 0.024482273693138268, 0.18573778885183856, 1.079700782429427, 37.41273544728756, 48.43508139252663, 45.430487617850304, 26.5075771138072, 34.641616344451904, 48.922724425792694, 46.52721516788006, 52.595139965415, 51.880546510219574, 55.561291202902794, 45.87058000266552, 3.4091105684638023, 1.9015238899737597, 5.3870488330721855, 6.678786193951964, 8.663438223302364, 43.19585032761097, 50.61237595975399, 64.52516600489616, 56.759940683841705, 56.528426706790924, 55.38095287978649, 56.65679521858692, 55.44920861721039, 55.98429970443249, 54.96974654495716, 53.83794687688351, 51.37792468070984, 53.51627893745899, 53.127096220850945, 52.22368709743023, 46.00559435784817, 41.53817027807236, 38.482796028256416, 38.70526649057865, 37.72590324282646, 37.83200114965439, 36.33539445698261, 38.61181430518627, 37.60308623313904, 37.22856692969799, 34.98402737081051, 35.31950756907463, 37.04164735972881, 37.03217826783657, 36.11562944948673, 37.563192173838615, 37.26465739309788, 38.56685131788254, 37.758779078722, 38.21613393723965, 37.40026071667671, 36.35003887116909, 37.75164686143398, 35.95015212893486, 34.68445524573326, 39.839133247733116, 43.05219903588295, 41.859051659703255, 44.30308811366558, 45.71989148855209, 46.565748900175095, 40.766709074378014, 37.844209894537926, 39.303878769278526, 39.19772006571293, 39.098321199417114, 38.45674082636833, 37.29732424020767, 36.561147943139076, 35.83628363907337, 36.8617308139801, 36.396700367331505, 38.1775926053524, 36.622218266129494, 36.858276799321175, 37.099917232990265, 38.45824554562569, 35.97631752490997, 35.97197435796261, 33.71984660625458, 35.672406032681465, 36.82762764394283, 36.70369729399681, 38.95251542329788, 37.68728591501713, 38.9226034283638, 44.691966846585274, 46.16721868515015, 49.22313630580902, 48.64993326365948, 45.37536397576332, 45.11569730937481, 43.92241694033146, 43.80528822541237, 36.91857196390629, 33.546249121427536, 36.87172807753086, 37.67232991755009, 36.04508623480797, 38.109139278531075, 35.487637147307396, 37.16088116168976, 37.29323945939541, 36.56256906688213, 36.45028509199619, 35.4203237593174, 35.97104340791702, 33.70582915842533, 35.002023205161095, 34.8121701925993, 36.15606687963009, 36.314301788806915, 37.981481328606606, 37.561014890670776, 37.746220752596855, 37.16218449175358, 36.535199135541916, 37.26842299103737, 40.512962490320206, 39.67343553900719, 40.55698312819004, 40.81194564700127, 41.295971274375916, 40.96574619412422, 46.422473788261414, 49.38523940742016, 51.697149351239204, 53.09160992503166, 51.894670352339745, 53.142891973257065, 55.58359980583191, 53.76920476555824, 52.517399936914444, 53.80383990705013, 56.45287536084652, 48.428169563412666, 15.421972163021564, 0.5663343763444573, 1.6341299819760025, 0.16383203852456063, 0.5227914440911263, 37.41190709173679, 59.57702971994877, 54.17891398072243, 57.01867260038853, 55.76119087636471, 35.91483302414417, 25.27364082634449, 21.628304533660412, 45.3900083899498, 7.782432697713375, 0.4884672921616584, 0.021614611359837, 0.17065172258298844, 0.04980011290172115, 0.030465414456557482, 0.042906154703814536, 0.06198097900778521, 0.06760829521226697, 0.0012196778448014811, 0.04418552452989388, 0.025325477763544768, 0.046436243210337125, 0.02537178592319833, 0.05202336840739008, 0.03354744243551977, 0.02531009118683869, 0.06833802675828338, 0.009401135284861084, 0.03904597746441141, 0.04408645152579993, 0.13239665189757943, 0.17794845916796476, 0.16953332087723538, 2.356925653293729, 48.51800434291363, 54.00090113282204, 50.53595446050167, 32.114003375172615, 43.85000802576542, 53.921929970383644, 53.206014186143875, 60.891379192471504, 54.286649599671364, 60.68486787378788, 49.77117709815502, 4.172026505693793, 2.335057114250958, 7.394936140626669, 7.551004691049457, 8.389483373612165, 45.370770022273064, 52.172617837786674, 65.1639649271965, 58.471984416246414, 60.195708721876144, 56.20433829724789, 58.836970031261444, 58.11745584011078, 59.134410470724106, 54.55849081277847, 56.376697048544884, 50.99289134144783, 55.66416308283806, 55.29599703848362, 55.275789722800255, 48.86943608522415, 44.560664892196655, 41.134783923625946, 40.637215822935104, 39.79644633829594, 40.31997464597225, 38.54046173393726, 39.727852419018745, 39.15468357503414, 39.31542254984379, 38.57826590538025, 38.62867400050163, 39.56956811249256, 37.71670013666153, 39.049357026815414, 39.81223449110985, 39.03341308236122, 41.671075746417046, 39.39768813550472, 40.90004771947861, 38.19046251475811, 38.63549463450909, 41.04052998125553, 37.66484811902046, 38.858850449323654, 42.16747730970383, 44.967607855796814, 44.264117404818535, 46.428504064679146, 49.92888003587723, 49.578014463186264, 43.744487687945366, 39.131086841225624, 40.01648113131523, 42.272933050990105, 39.982184171676636, 39.468212351202965, 39.327992275357246, 38.2051183283329, 37.610245048999786, 38.41576002538204, 39.222293347120285, 40.26207335293293, 37.77560077607632, 38.78933697938919, 38.17920371890068, 39.337715953588486, 38.62351007759571, 37.481032982468605, 39.57492582499981, 36.69173553586006, 39.280783608555794, 38.781999573111534, 40.290256440639496, 40.43999120593071, 41.55739724636078, 46.93201884627342, 48.03848147392273, 49.27558109164238, 49.96093891561031, 47.00842134654522, 47.41577088832855, 45.62618851661682, 44.41480591893196, 40.570107623934746, 36.66074059903622, 37.85790055990219, 38.321521282196045, 37.84436568617821, 38.98167885839939, 38.44887524843216, 38.41477207839489, 39.76500682532787, 37.82534770667553, 37.874349877238274, 38.03836427628994, 38.03313575685024, 36.00076161324978, 38.30181173980236, 36.968261897563934, 38.33686485886574, 38.189865946769714, 38.73447172343731, 38.89008857309818, 39.545792788267136, 38.27434681355953, 39.21375520527363, 39.24689322710037, 41.21713310480118, 41.618896946311, 41.83869995176792, 41.44051931798458, 42.126614302396774, 43.26638974249363, 47.99874700605869, 51.85894846916199, 52.454175129532814, 55.83262324333191, 53.63978751003742, 52.527647987008095, 57.62952022254467, 55.30780300498009, 53.95202815532684, 55.29951944947243, 58.96490916609764, 52.157688438892365, 19.379723891615868, 0.1378124300390482, 1.4617230207659304, 0.5388250399846584, 0.4079043120145798, 41.44364655017853, 63.442497700452805, 59.64820370078087, 61.30123279988766, 60.051981434226036, 47.760625183582306, 29.220789223909378, 25.054970160126686, 53.22588711977005, 11.16674104705453, 0.655784901464358, 0.05027909130149055, 0.05522496379853692, 0.03606289261369966, 0.019544338465493638, 0.034696376096690074, 0.05531465976673644, 0.029174511655583046, 0.024603950660093687, 0.04362041247077286, 0.06309335818514228, 0.16315059852786362, 0.16007537604309618, 0.12923094676807523, 0.1330326427705586, 0.08451004061498679, 0.12608471559360623, 0.149752116703894, 0.23571245488710701, 0.2801907900720835, 0.25036889186594635, 0.29694513010326773, 0.2339591903728433, 2.6943508721888065, 55.207522585988045, 62.71501533687115, 55.66930800676346, 41.0195779055357, 46.29412427544594, 58.63142006099224, 61.43141761422157, 63.39838586747646, 60.74872724711895, 65.6503464281559, 54.01191674172878, 4.756257981061935, 4.779668999835849, 15.87024550884962, 11.15881847217679, 12.61861464008689, 47.91624203324318, 49.61910545825958, 67.21430450677872, 60.23274913430214, 61.76241025328636, 59.42356735467911, 61.78898222744465, 58.12206879258156, 59.58258882164955, 56.82224594056606, 57.443983778357506, 52.47462943196297, 56.7485336959362, 56.7132867872715, 58.88513624668121, 49.689663872122765, 44.760423973202705, 43.43630142509937, 43.57570834457874, 43.43773014843464, 42.8242302685976, 41.03117108345032, 43.14012631773949, 42.5493074208498, 43.17198760807514, 40.20145520567894, 40.50560988485813, 41.461402997374535, 41.34920261800289, 41.23303145170212, 42.150393426418304, 40.524057894945145, 42.70405411720276, 41.82174526154995, 41.299942061305046, 40.51087640225887, 40.36262735724449, 42.08823636174202, 40.2677958458662, 40.90994618833065, 43.094015792012215, 47.46761530637741, 46.25454939901829, 47.98513613641262, 51.83480076491833, 51.033036187291145, 43.1029187142849, 40.78353837132454, 41.49695388972759, 43.1132959574461, 41.99536554515362, 41.96223892271519, 41.214686036109924, 39.8527517169714, 40.12857511639595, 41.60726197063923, 42.44926638901234, 42.646529003977776, 40.670015662908554, 41.65566377341747, 41.38527788221836, 42.932019084692, 40.31686261296272, 40.55081605911255, 40.78291900455952, 38.58228988945484, 40.98817639052868, 40.89163117110729, 43.015519604086876, 43.02592724561691, 44.076688662171364, 46.47461079061031, 49.82940137386322, 52.37503297626972, 52.608135268092155, 49.47836481034756, 49.46815475821495, 50.23571357131004, 48.28669935464859, 41.58427320420742, 39.094000831246376, 38.851972818374634, 41.92138731479645, 40.24444989860058, 41.71008825302124, 39.87405337393284, 40.48628032207489, 42.595231756567955, 40.22296965122223, 40.585705786943436, 40.64739927649498, 40.71402110159397, 38.18210296332836, 40.36024108529091, 38.22140045464039, 40.50953887403011, 41.06577582657337, 41.08957014977932, 41.20453678071499, 41.82472810149193, 39.431536719202995, 40.84254540503025, 41.278005838394165, 43.94387058913708, 43.00924614071846, 45.544675290584564, 45.06741710007191, 44.062359631061554, 44.4283863902092, 50.54234951734543, 55.562020763754845, 53.721939101815224, 57.032382264733315, 54.30205017328262, 54.34246100485325, 60.90719394385815, 60.17525061964989, 57.24090747535229, 57.377901524305344, 61.44630141556263, 53.48428465425968, 25.161548741161823, 0.555217657238245, 5.949436705559492, 4.15914804674685, 0.40410439716652036, 47.33444005250931, 69.55905988812447, 64.02096346020699, 66.10124543309212, 67.08364471793175, 50.89212454855442, 34.948575273156166, 33.29311430454254, 62.41129383444786, 16.204536370933056, 0.8482473052572459, 0.18753929296508431, 0.32427911181002855, 0.21664063999196514, 0.18616642366396263, 0.16886846045963466, 0.14996147656347603, 0.1560448165400885, 0.14383878791704774, 0.13860327744623646], [0.03278378731920384, 0.029031959929852746, 0.00842504967295099, 0.032730720049585216, 0.05385654738347512, 0.060851897796965204, 0.0568847733666189, 0.027857932400365826, 0.06625161957344972, 0.025988139568653423, 0.10894339749938808, 0.012133498530602083, 0.1903516022139229, 0.19264516507973894, 21.584369391202927, 46.93839110434055, 44.4918429851532, 45.645708069205284, 27.492543160915375, 50.091222524642944, 47.64011085033417, 49.944588392972946, 54.061165899038315, 51.12169682979584, 55.086457282304764, 7.032144432887435, 1.7305885185487568, 2.412157114595175, 14.27481846883893, 28.64770207554102, 34.86273027956486, 56.646379977464676, 58.27153757214546, 57.94553026556969, 52.63524301350117, 53.703863471746445, 53.12794357538223, 56.11523687839508, 54.69115309417248, 55.3866221755743, 55.2275475114584, 55.768288895487785, 53.81222225725651, 54.333136305212975, 52.09501840174198, 43.06821897625923, 37.395229786634445, 40.09359799325466, 37.70963631570339, 37.42130398750305, 36.476663276553154, 36.94325923919678, 37.18888185918331, 37.83745005726814, 35.631296038627625, 37.02436588704586, 36.008277609944344, 36.38545297086239, 36.830158308148384, 37.045078575611115, 38.858371675014496, 38.42976987361908, 37.83223673701286, 36.588115096092224, 37.37390153110027, 37.66414135694504, 36.79815262556076, 38.282049000263214, 36.07982017099857, 37.06356078386307, 41.64815537631512, 42.805573269724846, 40.98518215119839, 44.15527984499931, 45.882237777113914, 46.06389842927456, 40.95750443637371, 38.79306077957153, 38.072095066308975, 38.28646436333656, 38.46445061266422, 37.82329581677914, 36.41999311745167, 36.75742261111736, 36.301937252283096, 36.150739565491676, 36.58642798662186, 37.18399912118912, 36.40204668045044, 38.12532640993595, 37.08503723144531, 36.98120400309563, 35.65628729760647, 36.504781767725945, 36.92144460976124, 36.45964778959751, 37.955901101231575, 37.62426629662514, 37.850228771567345, 38.01456235349178, 38.464993983507156, 41.254390105605125, 45.15789024531841, 46.1628071218729, 45.36981247365475, 45.611304715275764, 45.13736754655838, 42.74841673672199, 42.93097034096718, 38.30460838973522, 33.99855025112629, 37.166041284799576, 38.84566895663738, 37.57493734359741, 35.904588773846626, 36.0891068726778, 36.66934333741665, 36.88618250191212, 37.83884838223457, 36.9324716180563, 36.383598670363426, 35.85999816656113, 36.2763000279665, 35.65241150557995, 36.14780232310295, 37.03750938177109, 36.35640352964401, 38.85323815047741, 37.47686080634594, 38.19826349616051, 41.516249254345894, 44.827782958745956, 46.910762786865234, 47.85093493759632, 49.74833272397518, 48.25929142534733, 47.53996342420578, 49.075844809412956, 48.35121989250183, 49.40865375101566, 47.48256370425224, 52.25414626300335, 53.3294353634119, 50.54295748472214, 47.9357235878706, 56.602036356925964, 52.97328047454357, 54.84428487718105, 49.95640575885773, 61.38591505587101, 32.29479007422924, 4.194491375237703, 1.2513464782387018, 0.8997536008246243, 0.6314361642580479, 1.6223323275335133, 51.978098675608635, 55.809030309319496, 51.738996505737305, 59.83177185058594, 40.67769505083561, 32.900287583470345, 28.256053291261196, 31.1538689956069, 41.69020012021065, 1.1152155767194927, 0.22094699641456828, 0.0276125171512831, 0.03276526331319474, 0.07726972951786593, 0.02641463328473037, 0.0352246813417878, 0.10744028870249167, 0.04723510952317156, 0.06841791153419763, 0.01089745992430835, 0.05488851486006752, 0.013223120677139377, 0.05685461619577836, 0.0530780604458414, 0.0166113578598015, 0.024350783678528387, 0.04182788834441453, 0.03261039935750887, 0.04035529665998183, 0.03981485358963255, 0.04595283418893814, 0.0547720384929562, 0.2722178085241467, 0.24639599723741412, 31.641341038048267, 54.20761004090309, 48.90378624200821, 45.97783304750919, 34.538098499178886, 54.11679871380329, 52.05595649778843, 53.67171339690685, 58.534095883369446, 56.356178149580956, 59.555750861763954, 6.952988030388951, 1.8605493823997676, 7.503631208091974, 17.089957259595394, 30.993939377367496, 36.91102936863899, 56.140383929014206, 60.64495861530304, 62.747967168688774, 55.02232812345028, 55.939321517944336, 54.48749542236328, 56.9685684889555, 57.360365465283394, 56.80113807320595, 55.48836551606655, 56.40641525387764, 54.73108895123005, 56.37104295194149, 54.03370097279549, 45.79553782939911, 39.288288205862045, 42.32004292309284, 39.32988457381725, 39.21562850475311, 38.495931923389435, 39.52230624854565, 38.484448939561844, 41.359298676252365, 38.5370609164238, 39.67206381261349, 38.85702654719353, 38.17558631300926, 39.27558548748493, 39.44367706775665, 39.32310193777084, 40.02163365483284, 39.22030985355377, 38.71317386627197, 39.41135600209236, 40.625390857458115, 41.16155728697777, 42.42084391415119, 35.617464780807495, 38.48069854080677, 43.809126019477844, 44.25440512597561, 44.189573004841805, 46.469560861587524, 47.71977737545967, 49.78730723261833, 42.75148697197437, 39.67477306723595, 39.45353373885155, 39.819142520427704, 41.28293037414551, 40.12800894677639, 37.18826249241829, 37.852337658405304, 38.59357908368111, 37.512556090950966, 39.82362248003483, 39.57313612103462, 39.93660181760788, 38.54157507419586, 37.71464444696903, 39.97425019741058, 39.66097220778465, 39.449904933571815, 37.93035127222538, 37.179743349552155, 39.30875390768051, 39.776911586523056, 40.162340104579926, 40.100597217679024, 41.50363393127918, 42.43887014687061, 47.88863651454449, 47.65678055584431, 48.86988066136837, 47.53006495535374, 46.134855821728706, 45.10124668478966, 45.13263680040836, 40.290898606181145, 36.240999922156334, 40.488814786076546, 39.895009249448776, 38.18600535392761, 39.13129583001137, 38.39568950235844, 38.75199258327484, 38.21033164858818, 39.66027304530144, 38.61434876918793, 37.89178714156151, 38.1043591350317, 38.17594729363918, 38.696059584617615, 38.150576055049896, 39.988339841365814, 39.36378635466099, 41.0993318259716, 39.67812068760395, 38.089536130428314, 42.268095910549164, 46.75075337290764, 48.16434971988201, 50.53981505334377, 50.40044613182545, 51.20200552046299, 50.21147467195988, 50.34280702471733, 47.968572825193405, 51.91569462418556, 50.44614627957344, 53.385930731892586, 53.62808033823967, 50.69048456847668, 49.10736411809921, 59.318039417266846, 57.47383497655392, 57.98469476401806, 52.135915607213974, 64.38560709357262, 35.16540303826332, 6.432846765965223, 2.7481604972854257, 0.21629407186992466, 0.44244775373954326, 1.528938920237124, 55.872528702020645, 61.9623289257288, 57.35353343188763, 61.97943180799484, 48.5216673463583, 41.13819994032383, 20.70523526519537, 34.81940500438213, 48.52982550859451, 2.297431295737624, 0.23638547892915085, 0.038350933900801465, 0.06173021472932305, 0.018450169736752287, 0.07978432622621767, 0.047397187154274434, 0.06097321667766664, 0.0516953688202193, 0.050765539417625405, 0.10882908449275419, 0.13847801776137203, 0.0730871113773901, 0.18388599681202322, 0.14953212928958237, 0.1124754044576548, 0.12191927075036801, 0.11329320666845888, 0.09745126299094409, 0.18476987985195592, 0.0809003456379287, 0.1274618151364848, 0.13498999789590016, 0.4889577627182007, 0.4169996583368629, 34.10461775958538, 64.50454071164131, 55.050074234604836, 58.45837354660034, 42.661302611231804, 60.253385826945305, 58.641113340854645, 60.16473278403282, 62.31455482542515, 60.84656819701195, 65.6341440975666, 10.505983103066683, 3.614467461593449, 8.444664012640715, 22.508930079638958, 35.48515968024731, 40.64709909260273, 55.93425638973713, 62.70515866577625, 62.58050635457039, 57.65467867255211, 59.29782070219517, 57.17746987938881, 59.622270092368126, 60.68062350153923, 58.54384995996952, 57.60541431605816, 58.679350689053535, 56.34597189724445, 58.221349865198135, 56.189811676740646, 46.48373410105705, 41.563575714826584, 43.45159560441971, 41.58930033445358, 39.97969910502434, 41.191207095980644, 42.42598883807659, 41.76180347800255, 44.82146769762039, 41.08433023095131, 40.2809127420187, 40.71597799658775, 41.125504821538925, 41.33680388331413, 42.149983048439026, 41.36089079082012, 41.661428064107895, 40.70412643253803, 40.58763988316059, 40.412400886416435, 42.866506800055504, 42.035932168364525, 43.6482160538435, 39.299254417419434, 40.202952325344086, 48.46012204885483, 47.26422742009163, 46.02776616811752, 47.24055089056492, 51.34516283869743, 50.51589913666248, 43.266024962067604, 42.00193539261818, 39.61405232548714, 41.271667778491974, 42.749473080039024, 41.365549340844154, 39.3493889272213, 40.80050066113472, 40.82991108298302, 40.62912605702877, 42.70378813147545, 42.90876813232899, 45.05899675190449, 41.958351731300354, 40.638880133628845, 43.1333626806736, 41.68293111026287, 41.79310239851475, 41.74630410969257, 39.27158050239086, 42.22389668226242, 41.840151473879814, 41.206102296710014, 42.33803875744343, 43.64520661532879, 43.71062010526657, 51.281432658433914, 49.70089606940746, 50.139346942305565, 49.22808364033699, 48.326741605997086, 47.39461362361908, 47.121548876166344, 43.03755082190037, 37.369383573532104, 42.668602019548416, 42.206132635474205, 40.513091683387756, 41.70058496296406, 39.382838532328606, 41.446200013160706, 40.36695532500744, 42.05711983144283, 39.35837544500828, 41.467106491327286, 41.22335337102413, 40.52137903869152, 39.99651700258255, 40.817261561751366, 42.197256311774254, 40.11517323553562, 44.05044727027416, 41.3276007771492, 41.48019678890705, 45.44773109257221, 49.20383334159851, 51.35155409574509, 52.56926715373993, 53.84060673415661, 53.814536333084106, 53.273209780454636, 53.248556703329086, 52.67384514212608, 53.369397819042206, 52.04748675227165, 55.91904580593109, 56.11359916627407, 51.66947543621063, 49.789222329854965, 58.26858513057232, 59.51189361512661, 59.08079534769058, 54.388506934046745, 65.80027118325233, 37.91864410042763, 8.704117890447378, 4.088196828961372, 3.563772006891668, 1.5101478598080575, 1.9782056752592325, 63.2203122228384, 67.15022474527359, 63.2630181312561, 68.29748198390007, 51.61983869969845, 46.704813838005066, 37.571046352386475, 44.09134067595005, 59.18726563453674, 3.6220354679971933, 0.422727910336107, 0.15443051175680012, 0.17288600269239396, 0.14904853102052584, 0.19649955356726423, 0.14262898330343887, 0.24064868688583374, 0.11104083299869671, 0.243239123665262, 0.15081809309776872], [0.028775408754881937, 0.08255943161202595, 0.02035122182860505, 0.04995695468096528, 0.04277311731129885, 0.0075780244696943555, 0.01850813889177516, 0.0538553117075935, 0.13590263173682615, 0.06223059295734856, 0.020524658029899, 0.06434362469008192, 0.18882696371292695, 0.06427128755603917, 3.636935893446207, 43.35679829120636, 44.41620424389839, 47.12030254304409, 25.733155868947506, 40.562990605831146, 64.79236006736755, 57.48852498829365, 51.728699058294296, 49.28129978477955, 55.46426720917225, 12.147655561566353, 0.4461194551549852, 4.246703423559666, 0.558965977979824, 10.93172650784254, 37.68193580210209, 69.47532758116722, 56.51339091360569, 58.12907561659813, 48.74155394732952, 49.57909360527992, 47.63192988932133, 52.54063569009304, 50.17401248216629, 55.202883034944534, 53.247887939214706, 57.100949585437775, 55.205284506082535, 52.5897366553545, 45.72338730096817, 38.23201708495617, 39.78892654180527, 39.18043099343777, 37.35744081437588, 39.11550387740135, 35.82624077796936, 36.61509744822979, 39.24879692494869, 38.378202840685844, 36.69829398393631, 36.526186019182205, 35.868228524923325, 38.784169256687164, 36.36885166168213, 37.61903017759323, 37.65909902751446, 38.65909516811371, 37.63244725763798, 38.14966790378094, 37.70459018647671, 39.01063330471516, 38.98212343454361, 38.80318343639374, 36.26661814749241, 37.40228220820427, 41.927182003855705, 42.43372522294521, 41.69120326638222, 42.16896302998066, 45.65093278884888, 46.715411469340324, 42.397649958729744, 38.00614960491657, 39.24016758799553, 39.93805713951588, 36.19781143963337, 37.38813556730747, 35.469671711325645, 35.91012507677078, 36.613026559352875, 36.27065733075142, 36.50312885642052, 37.88008376955986, 36.2581218034029, 35.824614465236664, 37.87276916205883, 37.60182090103626, 36.70234456658363, 34.869835898280144, 35.461866930127144, 35.57260438799858, 35.94201676547527, 35.85527502000332, 38.02768684923649, 37.062451243400574, 38.223896920681, 40.74835605919361, 42.5150066614151, 44.19300802052021, 46.76568657159805, 44.24418747425079, 43.52117747068405, 41.30457021296024, 41.80787220597267, 38.31646755337715, 34.711992368102074, 38.447450324893, 38.097314313054085, 36.03750944137573, 37.563602551817894, 35.86026035249233, 34.70872454345226, 37.28523328900337, 35.49059718847275, 37.13897153735161, 36.63478799164295, 36.81834474205971, 35.769870802760124, 35.250643864274025, 36.96861907839775, 37.4698805809021, 36.53245188295841, 37.82130852341652, 38.5864544659853, 42.73698315024376, 48.87400344014168, 52.66940318048, 50.847245156764984, 51.34747311472893, 51.69091008603573, 52.456303015351295, 49.06783863902092, 49.701910614967346, 48.788952603936195, 52.929772809147835, 49.895107448101044, 51.58306807279587, 54.53050531446934, 46.99659638106823, 42.37070560455322, 52.98991218209267, 54.186114594340324, 59.7693146020174, 56.00230313837528, 57.020694091916084, 11.28791369497776, 1.1767733423039317, 1.5040057268925011, 0.3216915694065392, 0.4091976972995326, 3.830278543755412, 55.75369767844677, 52.39798754453659, 49.9689906835556, 59.079974591732025, 37.246406972408295, 32.84489035606384, 28.338869847357273, 39.78325344622135, 23.12082264572382, 0.20332829182734713, 0.07082193566020578, 0.06914181722095236, 0.02876119477150496, 0.012967159509571502, 0.03238882003643084, 0.034775229287333786, 0.02121935278410092, 0.04401587699248921, 0.011647311093838653, 0.019282852008473128, 0.01741392563417321, 0.01768256082868902, 0.019767604317166843, 0.053802058901055716, 0.060537601966643706, 0.060105505035608076, 0.036101365549257025, 0.01252282178029418, 0.005895122048968915, 0.09705729389679618, 0.028291441267356277, 0.1099679472099524, 0.33003025164362043, 0.19110868190182373, 8.509606327861547, 52.72315889596939, 47.8914749622345, 53.33463728427887, 32.80761815607548, 47.2443050891161, 67.28931248188019, 62.44556799530983, 58.767999932169914, 54.26207631826401, 60.73358125984669, 12.249161414802074, 0.8639524562750012, 6.895338948816061, 1.003979870583862, 14.105778839439154, 39.86447788774967, 69.81386661529541, 58.458453342318535, 60.628995671868324, 52.323883920907974, 50.93612238764763, 50.18538907170296, 54.16407197713852, 53.46072591841221, 57.476681023836136, 55.18776744604111, 58.980055153369904, 55.89793033897877, 54.836217910051346, 48.90128597617149, 41.29726700484753, 42.011776864528656, 41.510701552033424, 40.169723108410835, 40.509060099720955, 37.705977112054825, 39.295010045170784, 40.19338823854923, 41.0602243244648, 38.368684351444244, 37.94526167213917, 40.085599422454834, 40.65045811235905, 38.35872508585453, 40.088833048939705, 40.47190569341183, 41.09206661581993, 39.27791476249695, 40.938102677464485, 39.349069744348526, 42.16589279472828, 41.76076613366604, 40.41865535080433, 37.978813871741295, 41.04610428214073, 44.04697425663471, 44.93890039622784, 44.68703851103783, 45.57690516114235, 47.775999158620834, 48.08442480862141, 43.02211605012417, 41.43762767314911, 40.65505966544151, 40.330139100551605, 38.333543837070465, 39.51190620660782, 37.90446326136589, 39.01355914771557, 39.03615653514862, 38.0289825797081, 39.185556918382645, 40.28905190527439, 38.25188621878624, 38.073835372924805, 38.25918562710285, 40.49618259072304, 39.00117941200733, 36.718064323067665, 37.69846871495247, 39.72768522799015, 38.84118139743805, 38.615066930651665, 37.853033021092415, 38.82049150764942, 40.72917468845844, 42.23018914461136, 43.18307161331177, 45.206204652786255, 46.60802163183689, 47.54611149430275, 43.655192479491234, 44.44100931286812, 44.703373834490776, 41.49259552359581, 37.1407650411129, 39.38952997326851, 39.81106035411358, 38.3797911554575, 39.74906288087368, 38.05004104971886, 36.776280999183655, 39.40099395811558, 36.88380002975464, 39.66712787747383, 39.180301800370216, 38.30129496753216, 38.27404282987118, 37.26605571806431, 38.30396622419357, 39.30464252829552, 38.94800886511803, 39.45490166544914, 41.3775946944952, 44.70811977982521, 50.45661471784115, 53.99281896650791, 52.6110915094614, 53.824894577264786, 54.070057421922684, 55.38372293114662, 51.80002123117447, 50.78557066619396, 51.35101452469826, 55.0039105117321, 51.55646950006485, 54.76795457303524, 54.85738657414913, 48.721114844083786, 44.12603281438351, 54.03348818421364, 56.52027614414692, 61.559824123978615, 56.71985663473606, 58.564330860972404, 13.323749452829361, 2.216914566233754, 2.840854385867715, 0.27323265094310045, 0.18255203089211136, 3.9510529255494475, 59.35549020767212, 56.344831958413124, 55.09846083819866, 62.273794412612915, 41.71531297266483, 38.654771000146866, 23.721456415951252, 45.027789026498795, 28.78639653325081, 0.5852514831349254, 0.08107867630315013, 0.100155448744772, 0.03301049488072749, 0.07958221714943647, 0.04899561368802097, 0.021520393856917508, 0.017501079746580217, 0.042583398389979266, 0.011849653019453399, 0.06379724814905785, 0.06385774802765809, 0.15461101691471413, 0.16769788577221334, 0.1242982770781964, 0.1484714963589795, 0.1348311931360513, 0.11715841566910967, 0.12296962493564934, 0.23338445636909455, 0.1144328857481014, 0.1780018344288692, 0.22653210296994075, 0.3161734342575073, 0.290264287032187, 9.548460133373737, 64.10965070128441, 55.59400364756584, 58.01370620727539, 39.29933801293373, 51.696051210165024, 72.70817130804062, 68.11638370156288, 62.63936139643192, 61.70397698879242, 64.64853778481483, 15.417966227978468, 1.9213917176239192, 12.251255102455616, 2.0103106275200844, 13.315953221172094, 43.457131907343864, 70.51087841391563, 62.05918572843075, 62.390527948737144, 54.18244779109955, 54.01640050113201, 53.51584196090698, 56.06830559670925, 55.76395332813263, 59.40190091729164, 56.55111908912659, 61.60121530294418, 57.74528481066227, 56.66667088866234, 49.736553356051445, 42.523765191435814, 44.90828923881054, 44.21987257897854, 42.074203714728355, 43.579527139663696, 38.5170853883028, 41.124452278018, 44.83633629977703, 44.75706875324249, 41.60971663892269, 40.39123222231865, 42.79294274747372, 43.8179225474596, 41.36795461177826, 41.67938590049744, 42.478000447154045, 42.76439867913723, 42.131280452013016, 43.26192498207092, 42.522325068712234, 44.08896580338478, 43.15027177333832, 44.443194195628166, 40.49015611410141, 43.73749606311321, 46.138963401317596, 46.842632442712784, 47.003941386938095, 46.49919927120209, 50.89729607105255, 48.98428112268448, 45.020945593714714, 42.80268542468548, 42.384392470121384, 43.21171447634697, 41.1244560778141, 41.79346717894077, 40.63152752816677, 40.24752773344517, 41.536220982670784, 41.05481341481209, 40.23206256330013, 43.97837653756142, 41.2882424890995, 40.13602651655674, 41.004002541303635, 43.46014514565468, 41.94075487554073, 38.36746461689472, 40.86964175105095, 41.68962635099888, 39.891946613788605, 41.80001802742481, 41.259869411587715, 41.03245921432972, 42.35275536775589, 45.53127720952034, 45.728289037942886, 47.909250408411026, 49.85397845506668, 49.446959495544434, 46.36984661221504, 46.60536177456379, 46.94380201399326, 42.97618791460991, 39.38882701098919, 42.161671221256256, 40.18744915723801, 40.29072381556034, 43.676049560308456, 38.862486854195595, 37.33145780861378, 41.065555438399315, 39.32928040623665, 41.130178570747375, 40.7404600828886, 40.9266272932291, 41.18928819894791, 38.16416032612324, 41.95560447871685, 42.338901311159134, 39.79582317173481, 41.26179590821266, 43.232487961649895, 47.67914995551109, 51.74355626106262, 57.034012377262115, 53.77168223261833, 55.1393086463213, 55.8857785910368, 57.252987027168274, 53.07468183338642, 53.655241280794144, 53.35109040141106, 58.263573199510574, 55.29655180871487, 56.50441959500313, 57.990797236561775, 49.29589480161667, 44.316459596157074, 55.00020571053028, 58.14375802874565, 64.74687650799751, 57.77561478316784, 62.11834095418453, 17.085583694279194, 3.6946581210941076, 4.038777630776167, 0.7234772597439587, 0.8840726141352206, 5.714372768998146, 68.05155918002129, 60.62493748962879, 60.99990516901016, 67.52334952354431, 46.988540813326836, 47.17980735003948, 36.660311222076416, 53.44830058515072, 36.46158568561077, 0.741152367554605, 0.18699709471547976, 0.17079491255572066, 0.1748574140947312, 0.16811428999062628, 0.14152597374049947, 0.12964770721737295, 0.08151352289132774, 0.11301081205601804, 0.10802275588503107, 0.140730525017716], [0.04453614848898724, 0.03135233659122605, 0.03775562756345607, 0.0802170873794239, 0.0790878948464524, 0.018152891352656297, 0.02087466786178993, 0.02116531515639508, 0.0453419130644761, 0.03646447243227158, 0.02748947277723346, 0.07325304817641154, 0.013538645689550322, 0.03637311405327637, 0.3313423984218389, 32.85079523921013, 43.24036493897438, 40.624121725559235, 34.85713317990303, 31.560494676232338, 57.56258301436901, 53.61142963171005, 56.59005559980869, 43.715673834085464, 59.462351873517036, 19.7087824344635, 0.5894494859967381, 4.687377652153373, 0.4570729611441493, 0.8400999486912042, 27.1222872287035, 66.9363722205162, 54.42121937870979, 55.599767938256264, 47.79662065207958, 47.7397795021534, 42.29709975421429, 45.684743374586105, 45.694125071167946, 49.26931142807007, 49.24359820783138, 52.15548075735569, 47.488654777407646, 44.450979977846146, 38.799459636211395, 39.920707270503044, 38.075172901153564, 40.60470096766949, 36.626413241028786, 37.77181997895241, 35.13486787676811, 38.947913870215416, 36.1220321059227, 38.97811844944954, 35.91364748775959, 37.86603592336178, 36.16807043552399, 38.23972687125206, 37.15744234621525, 38.370614647865295, 37.659490406513214, 38.72053787112236, 38.289466202259064, 38.17874774336815, 36.3311804831028, 37.6606759428978, 39.10987637937069, 39.1734279692173, 36.37163691222668, 39.753577038645744, 42.98258677124977, 42.56650909781456, 39.94222931563854, 43.359093368053436, 46.25335246324539, 44.8404248803854, 41.42774440348148, 39.798194244503975, 36.44955933094025, 36.25000923871994, 37.18540504574776, 37.521516010165215, 37.20832161605358, 37.07700826227665, 35.531988367438316, 35.746923834085464, 37.77425564825535, 37.11884781718254, 37.60104954242706, 37.299512922763824, 37.740836441516876, 36.209864392876625, 35.22520422935486, 35.38667656481266, 34.31866027414799, 36.21695101261139, 36.91851116716862, 36.263468116521835, 38.476321175694466, 37.41258725523949, 36.93567484617233, 39.2638973146677, 43.56712460517883, 44.3129675835371, 44.345839619636536, 42.97333426773548, 41.453256234526634, 40.650309920310974, 41.97047308087349, 39.495498687028885, 35.324458703398705, 38.257703706622124, 40.56472711265087, 38.499328941106796, 37.08602137863636, 36.066049709916115, 37.4785403162241, 37.86135837435722, 38.15178819000721, 37.365663573145866, 35.92195004224777, 36.90722577273846, 37.73786500096321, 38.272435516119, 37.32634328305721, 36.767294481396675, 38.073759377002716, 38.449901193380356, 39.40793618559837, 45.5209531635046, 47.316455617547035, 53.125614300370216, 51.05862781405449, 52.048638090491295, 48.10672201216221, 51.5872972458601, 51.033362969756126, 53.26493762433529, 50.966501757502556, 51.286930963397026, 51.1918068677187, 52.80133590102196, 50.729147493839264, 54.36985373497009, 41.396301090717316, 50.81725716590881, 49.04195822775364, 53.46158467233181, 54.81463886797428, 35.196207985281944, 1.0306517081335187, 15.990529954433441, 7.029006276279688, 0.13590386370196939, 0.09104456927161664, 12.486072052270174, 57.78871268033981, 47.71908201277256, 53.93864527344704, 47.68239498138428, 34.0786499530077, 26.942152194678783, 24.379037730395794, 44.59837406873703, 7.134338049218059, 0.5345071060582995, 0.038897926424397156, 0.13885940745240077, 0.04647118352295365, 0.01485062641222612, 0.08395152995944954, 0.013412447187874932, 0.036384769482538104, 0.002635827227095433, 0.029262120333442, 0.035051838858635165, 0.047142118419287726, 0.03354802502144594, 0.02371746268181596, 0.033201913320226595, 0.023670840964769013, 0.046500494645442814, 0.06086435474571772, 0.040196844420279376, 0.04354745935415849, 0.07946779282065108, 0.050428162794560194, 0.13446990080410615, 0.03580031705496367, 0.012419045415299479, 0.9480804763734341, 43.334079310297966, 47.047821432352066, 43.35806742310524, 37.49310493469238, 42.05539092421532, 63.396105989813805, 57.861972749233246, 62.735473439097404, 50.27597241103649, 65.02593353390694, 21.257429234683514, 0.4485716891940683, 6.7128057684749365, 2.1304768044501543, 0.9639829199295491, 29.959840066730976, 68.17689925432205, 57.32026621699333, 58.626149743795395, 50.79552233219147, 50.0951287150383, 45.54761253297329, 49.32822726666927, 47.81536124646664, 51.11691668629646, 50.69784477353096, 53.555162250995636, 49.04795430600643, 49.052939638495445, 40.775775387883186, 42.68175691366196, 40.69323241710663, 41.66311897337437, 38.01713101565838, 39.84494313597679, 37.584543228149414, 40.31976565718651, 39.28040362894535, 39.70833286643028, 38.130011558532715, 40.3842443972826, 39.829614758491516, 39.96434412896633, 38.33466477692127, 39.15785260498524, 38.96907113492489, 41.13374277949333, 38.83860133588314, 40.677417665719986, 38.73187266290188, 39.82306011021137, 40.994750037789345, 42.465506717562675, 37.73633748292923, 40.74394449591637, 45.15415884554386, 45.67582905292511, 42.489456832408905, 45.34677430987358, 47.15371035039425, 46.5191899985075, 43.90248320996761, 42.65722543001175, 40.013046115636826, 39.12990890443325, 38.62793684005737, 39.84788417816162, 39.60187017917633, 38.55099096894264, 38.714484795928, 38.955741450190544, 39.44024585187435, 40.804467648267746, 39.331883266568184, 39.304425939917564, 38.730265349149704, 38.770398795604706, 37.9733307659626, 37.74172559380531, 36.26105524599552, 38.373582288622856, 37.880817130208015, 37.47306481003761, 39.90748777985573, 38.30794081091881, 40.06652444601059, 41.00290060043335, 42.78602711856365, 45.34854881465435, 46.00308269262314, 44.05111983418465, 43.76001365482807, 42.46059738099575, 43.810087367892265, 42.465670108795166, 35.758038237690926, 39.243344217538834, 40.0086535513401, 39.63254973292351, 39.61649939417839, 37.371777445077896, 38.299516662955284, 39.755214750766754, 39.50624831020832, 39.376405477523804, 37.31462851166725, 38.43752905726433, 38.702868819236755, 40.80666393041611, 39.12110477685928, 38.78380447626114, 39.68173809349537, 40.143303126096725, 40.95554754137993, 47.899173349142075, 49.912062138319016, 55.59011645615101, 51.71836361289024, 52.16468766331673, 48.072976022958755, 53.27824451029301, 54.17701028287411, 54.77988973259926, 52.088684141635895, 53.51500600576401, 52.30625666677952, 54.54296104609966, 52.661609798669815, 56.76017627120018, 42.731826826930046, 50.56114710867405, 49.813001453876495, 56.672841757535934, 56.41020365059376, 39.275992065668106, 1.6378858429379761, 20.132624991238117, 9.560021962970495, 0.10515938687603921, 0.01723288427456282, 12.313631605356932, 65.82016691565514, 53.91284465789795, 60.12103132903576, 52.96930588781834, 43.41661088168621, 34.36560295522213, 26.429390609264374, 52.623604238033295, 10.276559963822365, 0.5040257354266942, 0.03928108242689632, 0.10222900193184614, 0.008685201191838132, 0.07174443264375441, 0.11598254204727709, 0.0561168842978077, 0.0386439746216638, 0.07622742021339945, 0.012160303976997966, 0.02924727366917068, 0.18712287390371785, 0.1382128187105991, 0.12562057643663138, 0.2193035400705412, 0.1533323706826195, 0.1509558505495079, 0.20829799468629062, 0.1335466097225435, 0.15847395494347438, 0.11539932529558428, 0.09659912160714157, 0.31724147382192314, 0.10956755111692473, 0.13589227135526016, 1.4973286539316177, 50.92756524682045, 55.5242545902729, 47.61618733406067, 47.35493615269661, 46.98178857564926, 66.29267156124115, 62.12541617453098, 66.74529567360878, 56.54061645269394, 70.36730691790581, 25.980370603501797, 0.670933322981, 15.397029351443052, 3.3460885751992464, 1.370006154756993, 32.772937417030334, 68.3717679977417, 60.4112483561039, 62.05508574843407, 53.85819599032402, 51.45656906068325, 47.63517111539841, 51.44993841648102, 49.625033140182495, 53.449702709913254, 53.46822291612625, 57.64780484139919, 51.53101086616516, 49.24723081290722, 43.69334243237972, 45.661598816514015, 42.56057381629944, 45.14426037669182, 40.55439926683903, 43.54160137474537, 40.025308057665825, 44.13595028221607, 42.36475132405758, 43.89204517006874, 40.10121278464794, 42.82549560070038, 42.886539325118065, 42.467117831110954, 39.879255294799805, 42.12056502699852, 41.50326535105705, 43.42428646981716, 42.261537462472916, 44.124683886766434, 40.52771329879761, 41.651001423597336, 44.225230291485786, 44.56665717065334, 39.73463125526905, 45.648409724235535, 49.10190001130104, 47.60504253208637, 44.90322411060333, 47.8341094404459, 50.91652303934097, 47.90534421801567, 45.69387808442116, 44.04959611594677, 41.068401485681534, 41.00272201001644, 41.10897570848465, 42.210927978158, 40.32298028469086, 40.641650184988976, 40.229045525193214, 41.00116789340973, 42.602888345718384, 42.823371514678, 42.146688625216484, 41.92729979753494, 42.21074178814888, 41.36426500976086, 38.981314077973366, 40.24673357605934, 37.01622672379017, 40.531596690416336, 40.17191559076309, 39.61063630878925, 42.56204053759575, 41.11194334924221, 39.71768036484718, 43.75997945666313, 47.884107157588005, 49.418586418032646, 47.17086263000965, 47.83364586532116, 44.9585947394371, 45.1076303422451, 46.30409114062786, 43.60515296459198, 38.07143770158291, 41.1671581864357, 43.833395317196846, 41.41465410590172, 41.330914199352264, 40.662153884768486, 41.38482950627804, 43.34876172244549, 42.14832253754139, 41.814419254660606, 39.334413930773735, 40.624980479478836, 41.49943135678768, 42.3718873411417, 41.38275481760502, 40.33078506588936, 41.49118199944496, 44.937836453318596, 42.74861432611942, 49.68448095023632, 52.62165114283562, 58.19158226251602, 52.68036939203739, 53.53041797876358, 49.26835007965565, 54.66529928147793, 55.02996951341629, 57.28475712239742, 52.67966262996197, 54.74283792078495, 54.36864160001278, 57.15507008135319, 53.38739365339279, 59.14215825498104, 40.40985122323036, 53.224021419882774, 49.006091952323914, 58.63564543426037, 55.43688207864761, 43.92880819737911, 3.407710581086576, 25.438504479825497, 12.742120362818241, 0.12323302056756802, 0.49084174912422895, 15.334280468523502, 74.29560452699661, 56.30062513053417, 65.87695106863976, 55.07591664791107, 47.686654552817345, 37.43910223245621, 33.59305500984192, 62.35570281744003, 15.024486891925335, 0.8100269373971969, 0.32115855894517154, 0.23964322521351278, 0.10874617917579599, 0.19495750428177416, 0.23370101203909144, 0.16019070579204708, 0.18922947492683306, 0.22080318303778768, 0.10353816527640447, 0.12490995519328862], [0.02239817458757898, 0.01634377837035572, 0.01708801519271219, 0.03135099330393132, 0.07516827157814987, 0.022730003656761255, 0.0447339939273661, 0.019149591971654445, 0.028583292696566787, 0.07298456141143106, 0.04962200859154109, 0.03349698752572294, 0.1171633880585432, 0.11018343720934354, 0.08350356962182559, 11.245525069534779, 44.398421198129654, 43.957409262657166, 39.50523376464844, 22.04123217612505, 52.59464979171753, 56.95663332939148, 55.952647402882576, 49.0493830293417, 58.02670530974865, 35.24698086082935, 0.0431033581844531, 4.780099326744676, 1.6222856612876058, 0.06331907497951761, 22.72026713937521, 68.42659905552864, 58.94562900066376, 58.862276673316956, 47.4164092540741, 48.38855288922787, 44.138028770685196, 44.384855926036835, 42.08387799561024, 42.40476317703724, 40.63813917338848, 41.03984981775284, 38.97325851023197, 40.53956866264343, 39.233191162347794, 39.11603584885597, 38.89474332332611, 38.95953744649887, 37.68408268690109, 35.982982367277145, 37.82493352890015, 37.85641863942146, 36.26469545066357, 38.285985589027405, 38.176703453063965, 36.93542405962944, 35.885198414325714, 37.36613094806671, 39.059434086084366, 39.18082617223263, 38.23570668697357, 37.62593060731888, 38.5182823240757, 38.86169269680977, 39.12748843431473, 38.51345658302307, 39.101657420396805, 38.7286352366209, 38.10296840965748, 40.248143300414085, 41.95755377411842, 40.53067333996296, 41.7882576584816, 44.46862243115902, 44.162818640470505, 42.81082458794117, 40.65145365893841, 38.78853142261505, 38.12113903462887, 36.39842167496681, 36.371944695711136, 34.79478232562542, 38.01420517265797, 36.254891976714134, 37.33880281448364, 36.83038629591465, 38.1327436119318, 39.37448278069496, 37.00474753975868, 37.42813602089882, 39.15007442235947, 36.88675247132778, 37.129107266664505, 36.64112225174904, 37.748724818229675, 36.19297809898853, 35.81502377986908, 36.013810113072395, 35.93192830681801, 36.146134212613106, 39.41621594130993, 39.07639637589455, 40.551405027508736, 44.210008308291435, 43.7272822111845, 44.54848654568195, 44.040115624666214, 39.59547512233257, 41.40746869146824, 44.22328099608421, 38.519445061683655, 37.6982407271862, 38.2393316924572, 36.70192278921604, 36.34444557130337, 36.830629482865334, 35.463455244898796, 39.367316365242004, 38.556926250457764, 37.16686584055424, 34.85327638685703, 36.99581801891327, 34.31058570742607, 36.75644986331463, 35.838001146912575, 38.56128081679344, 37.200022861361504, 38.5777073353529, 37.9194762557745, 42.91173957288265, 47.56263680756092, 52.1169014275074, 48.82199943065643, 50.2177557349205, 47.37578943371773, 51.18742190301418, 48.651244193315506, 50.753211602568626, 52.32632718980312, 50.81191845238209, 50.49641378223896, 52.05246828496456, 48.113785833120346, 55.84456980228424, 54.56130266189575, 51.944371685385704, 51.410549730062485, 48.35398234426975, 53.141828030347824, 11.809402462095022, 0.2133160558878444, 4.789716610684991, 1.5175118646584451, 0.2027642002212815, 0.24926715879701078, 24.13779627531767, 58.5025841742754, 45.09958237409592, 56.37661725282669, 45.74465475976467, 33.992903754115105, 21.86528831720352, 34.6284956485033, 33.09549830853939, 0.30124593526124954, 0.07118368070223369, 0.02737251401413232, 0.050660365959629416, 0.07171901408582926, 0.05874581627722364, 0.0433387971133925, 0.016981774897431023, 0.06630758492974564, 0.06679225189145654, 0.024014047157834284, 0.04807408891792875, 0.02946000844531227, 0.025151833760901354, 0.05332866516255308, 0.05511775685590692, 0.03136399944196455, 0.019302917826280463, 0.030733274106751196, 0.03659989954030607, 0.06050787524145562, 0.06523900359752588, 0.06887478506541811, 0.06522079129354097, 0.20983645197702572, 0.14043225586647168, 0.01417143976141233, 18.556613959372044, 53.896034359931946, 47.302305176854134, 43.31890672445297, 31.746849976480007, 60.752264857292175, 61.19391895830631, 62.74084635078907, 51.52668669819832, 62.53448702394962, 37.105533331632614, 0.047985595228965394, 5.307031776756048, 2.98583394382149, 0.17065268737496808, 26.167751848697662, 69.56152975559235, 61.17004103958607, 61.35993205010891, 48.66219140589237, 50.18068112432957, 45.98134025931358, 46.160675436258316, 44.56975780427456, 45.06493963301182, 43.04656773805618, 44.59057308733463, 41.97977118194103, 43.16814221441746, 41.00508168339729, 40.36459185183048, 41.40426926314831, 40.659596621990204, 40.351455956697464, 38.69097165763378, 40.406157821416855, 40.63855715095997, 40.296978279948235, 40.435587242245674, 38.84745866060257, 38.41499626636505, 38.89389216899872, 39.82649512588978, 40.51495358347893, 41.32198087871075, 40.17495542764664, 40.04699349403381, 42.160709872841835, 40.79350143671036, 41.262107491493225, 40.65954342484474, 39.04489986598492, 38.74032720923424, 38.47477465867996, 42.45053552091122, 45.52571050822735, 40.87175443768501, 42.59880356490612, 45.19354373216629, 46.51452764868736, 44.97410550713539, 42.262118831276894, 41.011241152882576, 41.30004085600376, 38.01008239388466, 40.47172710299492, 39.52105991542339, 39.45508785545826, 36.561018750071526, 40.64354248344898, 40.159098878502846, 40.313066616654396, 42.02859856188297, 39.69409883022308, 38.651810958981514, 41.08430743217468, 39.41793344914913, 39.278933107852936, 38.3863990008831, 38.38353395462036, 39.00968335568905, 37.7237943559885, 36.39314375817776, 38.13200265169144, 38.28392989933491, 42.006168365478516, 39.07233439385891, 41.06706015765667, 44.91532266139984, 45.76767012476921, 46.684747114777565, 45.24736404418945, 41.87920577824116, 42.927922904491425, 46.399921998381615, 40.51523096859455, 38.09325993061066, 39.65008199214935, 39.152833074331284, 37.71995276212692, 38.55954051017761, 37.265633940696716, 39.432273879647255, 39.19433444738388, 39.72936853766441, 37.896225303411484, 37.86748364567757, 36.81083254516125, 39.43367600440979, 37.44778096675873, 38.52742463350296, 38.351904451847076, 39.69830520451069, 40.32523736357689, 45.28954558074474, 50.0250680744648, 54.81612838804722, 51.2270537763834, 51.70351020991802, 48.54219004511833, 51.02106302976608, 49.60854582488537, 53.23290154337883, 52.49052777886391, 52.91252553462982, 53.35388705134392, 53.6906173825264, 50.85215449333191, 56.165063604712486, 56.52339577674866, 52.35158063471317, 52.244281992316246, 49.662472531199455, 54.12707336246967, 14.756667762994766, 0.06290444449405186, 6.239072363823652, 1.5285072871483862, 0.18132076336769387, 0.1481366838561371, 26.27006895840168, 66.04186981916428, 48.530684262514114, 61.98287442326546, 49.742503836750984, 45.99785037338734, 24.048565663397312, 35.75804203748703, 43.4370955824852, 1.370899819303304, 0.005069176158940536, 0.02523277980799321, 0.1205726141051855, 0.05289842731144745, 0.08323928341269493, 0.04186242418654729, 0.02120547833328601, 0.05238992998783942, 0.060374518725438975, 0.049827694820123725, 0.06824695039540529, 0.20936912158504128, 0.08590216864831746, 0.08004065661225468, 0.12611955200554803, 0.15157138783251867, 0.14009275299031287, 0.14091379096498713, 0.15110141539480537, 0.13058532174909487, 0.1921965813380666, 0.11206261449842714, 0.16046190139604732, 0.2974574198015034, 0.2546601975336671, 0.2195762941846624, 22.0522952824831, 63.438614308834076, 52.69956216216087, 50.19224010407925, 36.32443584501743, 63.96748512983322, 65.05884736776352, 67.03657284379005, 57.00536571443081, 67.26963713765144, 43.54682609438896, 0.1941166806500405, 13.815834447741508, 5.830443715676665, 0.2239544311305508, 29.030672125518322, 70.78976064920425, 64.90630835294724, 64.88727897405624, 51.808874756097794, 53.01332652568817, 48.760389536619186, 47.87900023162365, 46.558392494916916, 45.769577622413635, 45.36369480192661, 45.391171127557755, 45.358508080244064, 45.0012132525444, 44.65987376868725, 42.86912865936756, 43.740482702851295, 42.894891276955605, 43.145784214138985, 40.22789418697357, 44.21304054558277, 43.61874483525753, 42.122301533818245, 42.30775058269501, 41.56162641942501, 41.99000783264637, 40.28632365167141, 42.255868166685104, 44.42797601222992, 43.80904242396355, 42.40026041865349, 41.61860816180706, 44.59467686712742, 42.98814207315445, 44.3427237868309, 42.91754946112633, 40.60920372605324, 41.66972301900387, 41.70471914112568, 45.231826677918434, 47.56058111786842, 44.05454725027084, 43.83477844297886, 47.27906182408333, 48.0182209610939, 47.249791994690895, 45.33190570771694, 43.99326793849468, 43.31600368022919, 39.846318662166595, 41.19850650429726, 39.28548775613308, 42.955475226044655, 39.24562409520149, 42.6386634260416, 41.74036882817745, 41.76569066941738, 44.7043389827013, 42.33414016664028, 42.72413983941078, 43.41981031000614, 40.42500860989094, 41.46282412111759, 42.42180906236172, 41.69854447245598, 42.51326635479927, 39.56967070698738, 40.44583909213543, 40.233590081334114, 40.51264710724354, 43.74545283615589, 40.962550565600395, 44.077444821596146, 48.984330520033836, 48.10904748737812, 49.050975143909454, 46.517548486590385, 42.57023669779301, 45.368448346853256, 50.57986490428448, 43.45187298953533, 41.14953093230724, 41.63464330136776, 40.25771878659725, 39.51536402106285, 40.19951730966568, 39.072227999567986, 42.06003427505493, 42.02146254479885, 42.36644223332405, 38.655739948153496, 41.6691492497921, 38.5404921323061, 41.14763863384724, 39.08606305718422, 42.394933104515076, 40.94357818365097, 42.841751128435135, 41.8648387491703, 46.98894739151001, 50.6329632550478, 57.70005203783512, 52.516715973615646, 53.7255223095417, 49.12643149495125, 52.164429277181625, 49.953343123197556, 54.35517892241478, 55.07234483957291, 55.88120363652706, 53.876207023859024, 54.52909179031849, 51.725944206118584, 59.58380475640297, 57.23579294979572, 53.57767604291439, 53.695443123579025, 51.16758316755295, 53.24791833758354, 19.855198077857494, 0.4211581195704639, 8.436347208917141, 2.9979013837873936, 0.19712151784915477, 0.5853790731634945, 30.056670270860195, 70.79809740185738, 56.604130044579506, 66.13453164696693, 56.40422277152538, 46.54195457696915, 31.19173776358366, 44.57392618060112, 54.06713157892227, 3.7121663941070437, 0.3382563352352008, 0.16274459921987727, 0.2767350833164528, 0.22446865041274577, 0.19770472717937082, 0.07483820882043801, 0.13545649708248675, 0.11368241859599948, 0.2334636138402857, 0.10638270599883981, 0.142351642716676], [0.04694084054790437, 0.040470667227054946, 0.04545774747384712, 0.004373575984573108, 0.005678307315974962, 0.037277996161719784, 0.016290360435959883, 0.08605027906014584, 0.06087588772061281, 0.060547665489139035, 0.1273770915577188, 0.0535150778159732, 0.03521147111314349, 0.08595993000199087, 0.006848240509498282, 1.4072466501966119, 43.092617467045784, 37.434143498539925, 38.44392791390419, 33.74152064323425, 32.91005305945873, 55.71507275104523, 56.44012324512005, 51.32152050733566, 51.52987092733383, 43.069267719984055, 0.6187425891403109, 3.1258369563147426, 2.3217378789559007, 0.1485101622529328, 12.528379932045937, 67.6082293689251, 55.00050589442253, 58.29177908599377, 51.37325093150139, 49.80447471141815, 47.06625044345856, 45.05612790584564, 41.69387452304363, 41.19916766881943, 39.13948059082031, 39.29490365087986, 38.62830922007561, 39.84235927462578, 38.10869090259075, 39.48926702141762, 37.0173666626215, 37.28487990796566, 38.170950561761856, 38.13146688044071, 37.0647045224905, 37.14742988348007, 35.065677389502525, 38.553506433963776, 37.788778468966484, 37.617711648344994, 36.53240628540516, 37.67089359462261, 37.158939465880394, 39.06797222793102, 38.32707658410072, 39.24870193004608, 37.78627060353756, 37.277895882725716, 37.588001042604446, 39.64985400438309, 39.018031507730484, 38.611894100904465, 37.65588819980621, 41.05949856340885, 42.756848484277725, 40.5859299749136, 40.57390362024307, 43.50597068667412, 43.124277368187904, 42.16240458190441, 39.55806612968445, 40.413533225655556, 37.909972965717316, 38.17178651690483, 37.581765577197075, 37.00468674302101, 37.782425209879875, 36.93833090364933, 38.1790517270565, 39.159676507115364, 41.30310349166393, 41.46933317184448, 39.93791654706001, 39.125839322805405, 38.87763664126396, 38.42474654316902, 36.977411806583405, 37.12151147425175, 36.174970865249634, 37.017594650387764, 35.78255072236061, 36.86105065047741, 35.67367896437645, 35.68214491009712, 36.423378735780716, 36.746585592627525, 37.266576290130615, 39.51636716723442, 43.08584243059158, 43.27288739383221, 42.169191017746925, 40.62313757836819, 40.61895780265331, 43.30121487379074, 37.70845837891102, 36.98710888624191, 37.84176662564278, 37.933698892593384, 36.6438315063715, 37.13581770658493, 37.546169087290764, 37.09851510822773, 38.932965472340584, 37.24304415285587, 36.268639639019966, 36.08338437974453, 34.61231991648674, 35.83103232085705, 35.41645556688309, 37.89327286183834, 35.31343549489975, 37.508653700351715, 35.66233657300472, 38.35718996822834, 39.016317799687386, 46.100672855973244, 49.3611790984869, 51.425376534461975, 52.30288244783878, 52.01810672879219, 51.41574785113335, 50.58036267757416, 51.818822622299194, 51.75152063369751, 50.261400192976, 48.57571184635162, 49.375033155083656, 49.65542010962963, 52.322470396757126, 53.818324729800224, 50.94749137759209, 51.64601929485798, 39.95371989905834, 0.5984381411690265, 0.6085682788398117, 0.7169894641265273, 0.11420519484090619, 0.2307973592542112, 0.027118534380861092, 28.69641736149788, 52.73625299334526, 47.98583149909973, 54.87826265394688, 40.57544633746147, 22.33318191021681, 23.412572890520096, 42.051264345645905, 20.799713395535946, 0.5500111053697765, 0.025752348119567614, 0.009771010554686654, 0.06660820668912493, 0.07331681350478902, 0.024383811105508357, 0.07308794258278795, 0.09148572411504574, 0.055822789727244526, 0.01610738949239021, 0.00873687322382466, 0.03412456615478732, 0.005256748881947715, 0.017900138118420728, 0.07627372280694544, 0.040299813699675724, 0.0385096347599756, 0.05294851114740595, 0.03093315302976407, 0.07275097785168327, 0.009744020499056205, 0.1098179369000718, 0.021842597270733677, 0.030440402224485297, 0.03165824986353982, 0.016619293273834046, 0.02850880704500014, 3.374400855973363, 53.645149022340775, 41.490163654088974, 40.52804008126259, 34.70537692308426, 45.546407997608185, 60.006858855485916, 60.755935460329056, 56.26248277723789, 59.29424129426479, 46.29043847322464, 0.4809402523096651, 2.8773647267371416, 2.05102093052119, 0.1087729113351088, 14.774712044745684, 68.94448086619377, 57.31311500072479, 59.30846393108368, 52.34052322804928, 52.69345968961716, 49.41006347537041, 45.87547793984413, 43.77368152141571, 42.80935026705265, 41.615936905145645, 41.45833656191826, 40.09172849357128, 42.57148303091526, 39.821448996663094, 40.676783099770546, 39.19325530529022, 39.19921338558197, 39.203161373734474, 39.66835141181946, 39.51735891401768, 38.56565438210964, 37.94219143688679, 40.4044821113348, 40.6135468930006, 40.28229966759682, 39.23666797578335, 40.02713195979595, 41.05748847126961, 40.7933646440506, 41.04503273963928, 40.33050388097763, 40.81793412566185, 38.15353609621525, 39.65434916317463, 40.76767422258854, 41.805938109755516, 40.29409423470497, 40.62771253287792, 43.47083397209644, 46.71575725078583, 42.03506201505661, 43.15692901611328, 45.209601670503616, 45.0004418939352, 43.41036021709442, 41.70136012136936, 41.491083204746246, 40.528458058834076, 40.09284183382988, 40.84938883781433, 38.12308453023434, 39.835333451628685, 39.88383024930954, 39.38708670437336, 41.86825856566429, 42.52064175903797, 42.08858214318752, 42.57101185619831, 41.859059259295464, 41.01998068392277, 41.0188939422369, 39.03054803609848, 40.10886937379837, 40.69607086479664, 39.738081470131874, 37.72263541817665, 37.47750677168369, 38.36366482079029, 38.37764427065849, 39.35793846845627, 37.99641452729702, 40.4417809098959, 41.68763525784016, 44.74420264363289, 45.7502556592226, 44.35351140797138, 42.05371521413326, 42.35449567437172, 44.75375533103943, 39.858975782990456, 38.877613842487335, 40.92986471951008, 39.87575188279152, 37.42309749126434, 37.34723836183548, 39.18049558997154, 39.51534882187843, 40.435982421040535, 38.64511951804161, 38.10403235256672, 37.40446709096432, 37.37962402403355, 36.99572302401066, 37.96350069344044, 38.57286259531975, 38.042141273617744, 38.9611941576004, 38.71506616473198, 41.09271638095379, 42.469219118356705, 48.533788695931435, 51.399393528699875, 52.88227915763855, 54.8835975676775, 52.64847010374069, 51.88645139336586, 51.85440771281719, 53.28391380608082, 52.206842601299286, 52.5359695404768, 52.230424135923386, 51.016845256090164, 53.11124347150326, 54.19629044830799, 54.84094485640526, 50.99891781806946, 51.99841998517513, 43.71699616312981, 1.129757040180266, 0.8035215677227825, 1.5720620937645435, 0.355688018607907, 0.140171910461504, 0.05572980975557584, 34.31084789335728, 59.318039417266846, 55.249962508678436, 59.50292229652405, 46.32279373705387, 33.63816998898983, 22.28908147662878, 47.99638353288174, 29.44781184196472, 0.43081182811874896, 0.07454534250427969, 0.00851320568472147, 0.11107863057986833, 0.02244422856165329, 0.02630764527566498, 0.09015532050398178, 0.03110798446869012, 0.04166485334280878, 0.04730769527668599, 0.022983972157817334, 0.04837092572415713, 0.14456186239840463, 0.1788161337026395, 0.17421303695300594, 0.12245725360116921, 0.11568007976165973, 0.1347295634332113, 0.12422106403391808, 0.21568619355093688, 0.1681236707372591, 0.16528948297491297, 0.2717116934945807, 0.11681989242788404, 0.13060423167189583, 0.23306681716348976, 0.08396969773457386, 4.328268421813846, 64.67867016792297, 50.28574548661709, 45.91528840363026, 45.81468120217323, 49.08638544380665, 63.851226568222046, 67.48336046934128, 61.644247993826866, 63.61567720770836, 52.736427783966064, 0.5789888848084956, 7.781517896801233, 7.504871366545558, 0.1925053444574587, 17.674058116972446, 70.72923749685287, 61.390182226896286, 61.809618920087814, 56.64259918034077, 54.229025691747665, 51.407616287469864, 47.721016108989716, 46.14038072526455, 43.99263337254524, 44.21624757349491, 44.18272577226162, 43.999666795134544, 45.04945166409016, 43.089969009160995, 43.54001685976982, 40.970359146595, 42.25625194609165, 42.22887061536312, 43.14196161925793, 41.77883796393871, 41.69066749513149, 40.797890201210976, 44.32792358100414, 41.30652330815792, 41.80546313524246, 42.364173755049706, 42.77802474796772, 43.00935633480549, 42.849563509225845, 43.03129255771637, 43.259071335196495, 41.427068039774895, 40.586537942290306, 42.43559472262859, 44.35806356370449, 43.290963023900986, 43.26700150966644, 41.87938816845417, 45.426311641931534, 49.32915061712265, 43.52166384458542, 44.63129170238972, 47.09286041557789, 47.80276492238045, 45.90095177292824, 45.17849273979664, 44.54228527843952, 41.667104959487915, 42.08639346063137, 43.78223106265068, 39.6541553735733, 43.011385425925255, 41.610989570617676, 42.31820002198219, 45.110009014606476, 46.879403069615364, 44.817698299884796, 45.690659657120705, 45.4830501973629, 44.392326325178146, 43.86271834373474, 40.75344778597355, 41.73486292362213, 43.89901019632816, 42.37472578883171, 39.896293580532074, 39.709328413009644, 41.34102165699005, 40.445861890912056, 40.56639522314072, 40.405918434262276, 41.66781172156334, 42.575833797454834, 47.67385683953762, 48.273901641368866, 45.93083716928959, 44.28476929664612, 43.7618375569582, 45.9509114921093, 43.72654125094414, 40.66621966660023, 42.8004739433527, 41.473630741238594, 39.565076753497124, 40.390183478593826, 41.893747597932816, 41.793402582407, 42.90115714073181, 40.45845441520214, 39.284591004252434, 39.75839897990227, 39.315513744950294, 39.10582959651947, 40.781554877758026, 41.84138260781765, 39.57826964557171, 41.582981273531914, 40.63928671181202, 42.77692660689354, 44.83426161110401, 49.55657601356506, 52.588976696133614, 54.414402544498444, 57.59851388633251, 55.8140042424202, 54.01698186993599, 53.81004877388477, 55.106041431427, 54.34817589819431, 55.399203300476074, 55.10983742773533, 52.311785370111465, 56.064182817935944, 57.3089200258255, 56.81480213999748, 53.073724284768105, 52.04389214515686, 45.88675953447819, 3.258966375142336, 1.1614588578231633, 3.659257795661688, 0.665952384006232, 0.29596187348943204, 0.1639901308226399, 37.48699486255646, 63.86777088046074, 59.23854008316994, 63.27787533402443, 51.428986340761185, 32.77446113526821, 31.513362005352974, 55.8001995831728, 40.29098600149155, 0.8544511254876852, 0.2151061309268698, 0.20632054220186546, 0.2536413772031665, 0.14992034673923627, 0.1670448255026713, 0.25430738052818924, 0.0988901017990429, 0.19219000590965152, 0.10715088079450652, 0.148095850890968, 0.18093067570589483], [0.018939825786219444, 0.07804104359820485, 0.049725538192433305, 0.017911808390635997, 0.03807781984505709, 0.032971365144476295, 0.02826779273163993, 0.051451710605761036, 0.0466634999611415, 0.019361538215889595, 0.021234750493022148, 0.06429539993405342, 0.005167386416360387, 0.1785328856203705, 0.04151042354351375, 0.13161027221940458, 24.819111116230488, 45.04698559641838, 36.45824946463108, 25.611180514097214, 21.750821359455585, 51.846469938755035, 59.032176956534386, 53.786923214793205, 48.24405424296856, 46.59807376563549, 2.3048651218414307, 2.8804311621934175, 1.4735359931364655, 0.11068614578107372, 7.55237546749413, 60.6903737783432, 58.12407128512859, 53.95069822669029, 52.78193034231663, 51.06851868331432, 50.05844168365002, 46.14753574132919, 43.35448041558266, 41.37015089392662, 39.689812660217285, 39.36381675302982, 38.82879786193371, 38.75268034636974, 38.95865589380264, 39.186062291264534, 38.89188967645168, 39.48054648935795, 40.639659091830254, 38.188425824046135, 39.44411784410477, 38.10160428285599, 36.78715601563454, 37.93309472501278, 37.440147176384926, 39.24432456493378, 36.96507766842842, 40.086853355169296, 37.55596876144409, 38.890631943941116, 38.812648728489876, 38.23351040482521, 38.78921538591385, 37.91559286415577, 38.21793504059315, 39.054425954818726, 39.686571434140205, 37.15099409222603, 38.59535738825798, 43.255906105041504, 41.70974627137184, 40.35988010466099, 41.949760392308235, 43.334387093782425, 41.85567744076252, 39.3829221278429, 39.195873364806175, 37.95416459441185, 38.487006202340126, 39.55096051096916, 38.86346720159054, 36.10259234905243, 36.50423839688301, 38.4748088568449, 36.968888863921165, 40.51354005932808, 40.29953554272652, 41.74773283302784, 41.75823926925659, 41.06353774666786, 41.19107410311699, 40.272925570607185, 39.92248937487602, 38.36861975491047, 38.261883482337, 39.314639791846275, 35.72393126785755, 35.34851901233196, 36.35140299797058, 36.50041580200195, 36.49515688419342, 36.91063039004803, 36.81434355676174, 37.78314717113972, 41.62537559866905, 42.39782094955444, 41.16893649101257, 40.72029076516628, 40.54725185036659, 42.95528903603554, 38.67540009319782, 36.76416724920273, 37.56546065211296, 38.02902817726135, 35.81102639436722, 38.03126625716686, 36.412606313824654, 38.88379991054535, 37.78420351445675, 36.74850448966026, 35.23753076791763, 35.12962035834789, 36.34041778743267, 37.97137387096882, 36.735095009207726, 35.505309998989105, 36.142858788371086, 37.14708410203457, 36.903957948088646, 37.295773923397064, 36.6287425160408, 37.02970080077648, 39.25574295222759, 44.15245659649372, 44.38077874481678, 48.86307902634144, 48.62741947174072, 49.93643403053284, 47.50689759850502, 47.99048624932766, 46.65714159607887, 44.95708242058754, 45.52233628928661, 51.92791476845741, 51.62256695330143, 53.05740416049957, 50.4323910176754, 53.153903782367706, 27.37858347594738, 0.30068068590480834, 2.840589825063944, 1.3968423334881663, 0.1762935143779032, 0.1706631071283482, 0.7373918162193149, 33.44890594482422, 51.91491186618805, 45.59878818690777, 48.60981121659279, 31.171889528632164, 27.98994407057762, 31.02227445691824, 43.7864526361227, 5.849237032234669, 0.3209797013550997, 0.1899318434880115, 0.08248588477727026, 0.059743400051956996, 0.07893741698353551, 0.028999908427067567, 0.050110033771488816, 0.03002909099450335, 0.02253334936540341, 0.08399001773796044, 0.06820908602094278, 0.055414608505088836, 0.04444537640665658, 0.030814439087407663, 0.019470500337774865, 0.02374592404521536, 0.045761252476950176, 0.03759711966267787, 0.020581452736223582, 0.039550448636873625, 0.056449318217346445, 0.04523789735685568, 0.02978468321089167, 0.050712327429209836, 0.00458175722087617, 0.14005650649778545, 0.04257658918504603, 0.470037687337026, 36.19157217442989, 50.05409851670265, 40.30448667705059, 31.81034456938505, 31.156431958079338, 58.6210086196661, 62.514302507042885, 57.84732073545456, 54.04021382331848, 53.65808732807636, 2.8656972153112292, 2.0696145202964544, 1.4880052604712546, 0.32614157593343407, 9.360091891139746, 63.417688831686974, 60.27891665697098, 55.72231516242027, 53.812545239925385, 52.23432272672653, 51.13243505358696, 48.7226689606905, 45.87821379303932, 41.69050790369511, 42.78241351246834, 41.05140119791031, 40.47483533620834, 39.901723489165306, 41.557754427194595, 41.38362877070904, 39.88973893225193, 41.85612201690674, 41.311166658997536, 39.6115330606699, 41.21872141957283, 40.130285024642944, 38.802408277988434, 41.72704674303532, 40.23922897875309, 42.25420765578747, 40.25962248444557, 41.352215856313705, 39.22300010919571, 40.14723591506481, 40.57613790035248, 41.06961362063885, 40.33135123550892, 39.4807630777359, 40.79884774982929, 39.27351459860802, 41.1297719925642, 38.874251022934914, 42.35694654285908, 43.75241406261921, 45.34333549439907, 43.167728036642075, 42.65243388712406, 45.34928597509861, 44.82423394918442, 41.77794121205807, 41.69476367533207, 39.89465966820717, 39.63941216468811, 40.93414328992367, 39.98327851295471, 37.22029097378254, 38.80849935114384, 40.89306369423866, 40.942605435848236, 42.343704253435135, 43.44173513352871, 42.49659664928913, 44.53406631946564, 42.74540349841118, 44.27272394299507, 42.79262736439705, 41.93748325109482, 41.095790416002274, 41.06621280312538, 41.56176321208477, 36.37330122292042, 38.69884863495827, 36.91486716270447, 38.28914701938629, 38.60563203692436, 40.14573119580746, 38.80813077092171, 39.583395570516586, 41.84081643819809, 43.50046098232269, 42.88411885499954, 42.01289780437946, 41.834105998277664, 44.51324723660946, 40.81152766942978, 39.24980387091637, 38.503949493169785, 38.48953306674957, 38.11309486627579, 39.91353705525398, 37.921505346894264, 39.88241672515869, 39.84470374882221, 38.91113944351673, 38.88434328138828, 38.578322902321815, 37.56175585091114, 38.659076169133186, 38.54561805725098, 40.298976972699165, 37.63314262032509, 39.011355265975, 38.85147124528885, 38.22529524564743, 36.96438230574131, 38.99136073887348, 41.237085834145546, 46.42578341066837, 46.2836292386055, 49.861597046256065, 49.9711299687624, 52.63762928545475, 48.885319232940674, 49.09895896911621, 48.10503110289574, 47.86136157810688, 48.788223043084145, 53.592867627739906, 52.517829313874245, 55.12707330286503, 51.72893464565277, 53.358154222369194, 29.72953252494335, 0.42474833317101, 4.1858211904764175, 2.861122260801494, 0.07783373948768713, 0.14524646394420415, 0.5142699263524264, 39.53198432922363, 56.93541146814823, 52.59335786104202, 52.11772218346596, 45.2571789175272, 30.85762359201908, 27.841311246156693, 51.31046690046787, 9.87527584657073, 0.24911035783588886, 0.06911842472618446, 0.03319873692817055, 0.055149424297269434, 0.05007857413147576, 0.018120702552550938, 0.04156816634349525, 0.01021716005197959, 0.09965933786588721, 0.033836442162282765, 0.02025044559559319, 0.09065355392522179, 0.10332560676033609, 0.1500625570770353, 0.12933235382661223, 0.09598690914572217, 0.15697570721386, 0.15528534713666886, 0.11788981704739854, 0.1475435891188681, 0.18059261259622872, 0.15364318212959915, 0.07449476514011621, 0.18741798150585964, 0.07606683429912664, 0.26559740595985204, 0.14491659414488822, 0.6490603904239833, 43.05811531841755, 61.25968582928181, 43.205091431736946, 36.09206311404705, 36.654444336891174, 62.79445767402649, 68.93897116184235, 63.37849013507366, 58.92966605722904, 59.93317320942879, 3.284565364010632, 7.4188069347292185, 5.863092513754964, 0.6185904785525054, 11.592369507998228, 64.84251737594604, 61.915359646081924, 56.84688001871109, 55.84295868873596, 55.38452848792076, 53.65912847220898, 49.962622225284576, 48.798539489507675, 44.86080318689346, 45.959225445985794, 44.95968148112297, 43.57547275722027, 42.70113967359066, 43.59324440360069, 43.704251646995544, 44.071638733148575, 43.63821879029274, 46.81715860962868, 42.07452669739723, 44.38513711094856, 43.08149926364422, 41.66318356990814, 43.551108464598656, 43.26346009969711, 45.38865566253662, 41.83724842965603, 44.36579614877701, 41.711292788386345, 42.071692049503326, 43.038500770926476, 43.397877886891365, 43.07318910956383, 41.4258749037981, 41.880155727267265, 42.9963344335556, 43.81047874689102, 43.074902817606926, 44.831305369734764, 46.407475993037224, 45.73238901793957, 45.99110573530197, 46.17345795035362, 46.60805203020573, 46.46733418107033, 42.184720784425735, 43.82770702242851, 41.90966114401817, 42.43900693953037, 43.396342769265175, 43.0958054959774, 39.715324491262436, 42.72142678499222, 43.47635127604008, 43.218861892819405, 45.36216728389263, 45.68720564246178, 44.916371405124664, 46.767651066184044, 45.69460764527321, 45.273700430989265, 45.16256779432297, 44.1479766368866, 43.201694414019585, 44.57928009331226, 44.76774238049984, 39.1780599206686, 39.96814012527466, 39.93054114282131, 40.98524294793606, 40.681928023695946, 42.91517458856106, 41.076548248529434, 42.13140584528446, 45.2700450271368, 45.43230392038822, 44.55293230712414, 44.778499603271484, 45.01563347876072, 46.59932769834995, 42.544322088360786, 40.31056635081768, 40.14890782535076, 39.61922004818916, 39.848222360014915, 41.36513136327267, 40.919707864522934, 42.405352145433426, 42.52107873558998, 41.73498451709747, 39.73452486097813, 39.345174953341484, 39.280905202031136, 41.15254797041416, 41.242367550730705, 40.66361680626869, 40.16610190272331, 39.72580432891846, 40.73424741625786, 40.98248429596424, 39.95323732495308, 40.77620096504688, 44.80506017804146, 47.90181040763855, 48.24790343642235, 52.132169008255005, 53.19685287773609, 54.414797723293304, 52.58844092488289, 50.24824529886246, 51.89905911684036, 49.69254411756992, 51.714898198843, 55.09804666042328, 55.76606221497059, 55.97632393240929, 53.96188102662563, 52.7545528113842, 33.6235635727644, 1.0137888067401946, 6.676592286676168, 4.5148583594709635, 0.49371044675353914, 0.31626011710613966, 0.9234041254967451, 46.7147047072649, 63.86248156428337, 55.403979644179344, 59.66147638857365, 44.97450068593025, 37.50155568122864, 41.17152415215969, 61.21769808232784, 14.612151067703962, 0.5382325092796236, 0.2731610188493505, 0.17158353351987898, 0.1561637531267479, 0.22029032930731773, 0.07722606154857203, 0.14812166278716177, 0.13652596157044172, 0.18968119053170085, 0.13698218943318352, 0.13094198307953775, 0.21817887463839725], [0.02825111852871487, 0.041273622773587704, 0.02167860118788667, 0.025781071090023033, 0.01153415769294952, 0.027890204692084808, 0.020903784170513973, 0.08538218287867494, 0.0279977456011693, 0.0423107704409631, 0.03489639602776151, 0.007697730106883682, 0.01659852798184147, 0.11966896025114693, 0.11641645352938212, 0.16333769395714626, 3.8710980908945203, 41.56438887119293, 29.623812697827816, 37.88017876446247, 26.841866075992584, 41.47856667637825, 58.55920113623142, 49.55502949655056, 48.890570551157, 43.47404859960079, 2.833081902936101, 1.8095961352810264, 0.5291709455195814, 0.13343191822059453, 2.6204498251900077, 51.546449437737465, 62.92992800474167, 57.28910408914089, 52.250943034887314, 49.66938816010952, 51.95544049143791, 48.1837172806263, 44.177136272192, 41.43002048134804, 40.18491089344025, 38.3487506210804, 38.16232122480869, 39.836978763341904, 43.16611312329769, 44.93595935404301, 42.85606116056442, 43.82871396839619, 42.2989996522665, 40.96861124038696, 40.05622699856758, 38.84715087711811, 37.84093827009201, 38.03980439901352, 37.13258408010006, 37.971601858735085, 37.11711511015892, 36.945375725626945, 39.94051180779934, 39.36918206512928, 38.62971514463425, 37.90117263793945, 39.099685326218605, 38.97061385214329, 37.655280232429504, 39.945139959454536, 39.27539549767971, 37.83070161938667, 39.786027297377586, 42.210008427500725, 41.18906021118164, 41.1279670894146, 40.59569165110588, 42.261510863900185, 39.648402482271194, 37.59854167699814, 37.58131720125675, 38.69533762335777, 38.10775615274906, 38.604416102170944, 37.760876566171646, 36.76557317376137, 37.215047255158424, 40.108975768089294, 43.501673117280006, 43.846265226602554, 42.58315600454807, 44.900670647621155, 44.15780670940876, 43.00161994993687, 43.686005026102066, 41.731606498360634, 42.52271264791489, 39.910941794514656, 39.46261145174503, 37.93788626790047, 35.27661547064781, 36.86184100806713, 37.47741937637329, 38.15841883420944, 36.34810857474804, 36.89125522971153, 37.9818195104599, 37.748827412724495, 39.69838500022888, 38.902730494737625, 40.115013644099236, 39.51972618699074, 40.38121975958347, 41.487727984786034, 38.42109873890877, 37.71016448736191, 37.41040617227554, 37.52804785966873, 35.75037024915218, 37.903874292969704, 37.288246527314186, 38.38439270853996, 37.11638554930687, 37.66741678118706, 36.732659339904785, 36.56445376574993, 35.51498807966709, 36.57029785215855, 35.84438860416412, 36.73934318125248, 37.10134595632553, 36.9485979527235, 37.37995080649853, 36.86576619744301, 37.508551105856895, 37.473023012280464, 37.021436244249344, 37.607524394989014, 37.89486117660999, 39.21646445989609, 41.077353805303574, 43.319799676537514, 43.755111917853355, 43.7121894210577, 43.17204460501671, 44.195113107562065, 46.35970875620842, 48.54789353907108, 50.825369730591774, 55.507235303521156, 50.094395354390144, 55.4960411041975, 31.89721740782261, 0.44313314196188003, 0.5932590190786868, 0.4208049166481942, 0.21195924666244537, 0.09345484970253892, 1.5186031186021864, 46.81156150996685, 47.84725673496723, 49.88334707915783, 47.517491430044174, 32.64234222471714, 27.630525156855583, 37.54651866853237, 40.553152933716774, 0.7972036942373961, 0.18257505231304094, 0.015515667728323024, 0.06256131993723102, 0.023602273940923624, 0.06274065250181593, 0.028531537172966637, 0.06202374155691359, 0.024805401080811862, 0.029046439231024124, 0.09729287383379415, 0.0369668173516402, 0.028055968941771425, 0.038745493002352305, 0.013350597528187791, 0.05278747994452715, 0.05752556222432759, 0.027368788432795554, 0.056921843643067405, 0.017743548669386655, 0.020935162174282596, 0.03836463394691236, 0.03010157099197386, 0.027773180991061963, 0.019393155562283937, 0.020539567776722834, 0.12261462601600215, 0.08951590090873651, 0.07016188435954973, 10.788359250873327, 52.37323947250843, 32.38656274974346, 38.60780172049999, 31.09060049057007, 50.120017379522324, 65.46985611319542, 57.37243741750717, 53.90535905957222, 51.18388429284096, 3.042419319972396, 1.6168867447413504, 0.6261496979277581, 0.29322388290893286, 3.4978046966716647, 53.79640370607376, 66.18694603443146, 58.91463786363602, 54.33728568255901, 53.25321525335312, 52.86478489637375, 50.066979825496674, 45.68592131137848, 43.9462074637413, 41.328497529029846, 40.966753140091896, 41.550318226218224, 42.322866171598434, 44.42330226302147, 46.079785376787186, 44.54871453344822, 44.934732019901276, 45.01095972955227, 41.76300421357155, 42.20563866198063, 41.24775566160679, 39.91722285747528, 39.478897377848625, 39.14700038731098, 40.584041476249695, 39.628130570054054, 40.980360209941864, 41.72713793814182, 41.67759619653225, 39.89840626716614, 40.20354889333248, 40.41379161179066, 40.7615527510643, 39.18590269982815, 42.34986372292042, 40.48683509230614, 39.640248119831085, 42.74646744132042, 45.396179258823395, 42.55216486752033, 43.351562172174454, 43.79595972597599, 43.078356832265854, 40.95519036054611, 38.61030578613281, 39.998819679021835, 40.95401622354984, 40.332069396972656, 41.69903464615345, 40.15186406672001, 40.276698768138885, 38.30179654061794, 41.698103696107864, 44.150659292936325, 45.947271287441254, 46.0276597738266, 44.31484468281269, 45.872890278697014, 45.75584515929222, 44.03551027178764, 43.11364933848381, 42.598712369799614, 43.17603059113026, 41.349574998021126, 41.097120344638824, 37.843472734093666, 38.91388289630413, 39.19906899333, 38.97020347416401, 39.493936970829964, 38.405291587114334, 39.071832820773125, 39.83216442167759, 41.51418216526508, 41.11540876328945, 42.890141531825066, 42.72991552948952, 41.13554008305073, 44.27431985735893, 41.09025411307812, 39.937061592936516, 39.57186318933964, 40.16376502811909, 37.350236400961876, 37.54107356071472, 38.55877675116062, 38.891908675432205, 39.02715101838112, 39.79776866734028, 37.581765577197075, 37.64952354133129, 38.330678790807724, 38.203587010502815, 39.34240110218525, 38.50235737860203, 38.145480528473854, 38.80894012749195, 39.07355412840843, 38.941978588700294, 39.94831658899784, 38.80110114812851, 38.5139087587595, 40.01375287771225, 39.320145696401596, 42.046446204185486, 44.54651825129986, 46.35341629385948, 46.192453131079674, 46.24208986759186, 45.828668251633644, 46.74921825528145, 48.67459014058113, 52.74883031845093, 53.38859438896179, 56.338254511356354, 51.764911115169525, 56.98445923626423, 32.25371427834034, 0.684558026259765, 0.9707989823073149, 1.0964390030130744, 0.13854112999979407, 0.08294347819173709, 1.670824137981981, 51.43284313380718, 52.9755337536335, 54.91642780601978, 49.59689944982529, 45.7698930054903, 26.71953734010458, 37.68535181879997, 49.62114214897156, 1.8282797327265143, 0.08853196894051507, 0.06022502049745526, 0.08932188124163076, 0.0630866046412848, 0.019916963392461184, 0.027411608498368878, 0.010106819390784949, 0.009700969440018525, 0.022688139106321614, 0.05615330519503914, 0.014644519014836987, 0.008114504471450346, 0.1701228236197494, 0.1360530947567895, 0.11984516837401316, 0.11388461673050188, 0.10453330367454328, 0.18476170138455927, 0.10312458121916279, 0.2370984453591518, 0.08098477235762402, 0.19428629108006135, 0.31176308810245246, 0.11887574539287016, 0.1456852216506377, 0.20521711703622714, 0.35361606103833765, 0.3652337595121935, 14.255110826343298, 68.66106927394867, 39.801674857735634, 45.67874349653721, 39.69337306916714, 54.24576759338379, 67.6351623237133, 60.688466280698776, 59.90045316517353, 59.702894166111946, 4.13862582296133, 5.302575565874577, 4.498059460893273, 0.36261682806070894, 4.635975435376167, 56.348460763692856, 67.68170222640038, 60.984257608652115, 56.71987943351269, 54.861820936203, 57.29415401816368, 53.02571006119251, 48.80869634449482, 47.49939300119877, 43.86966437101364, 43.118988052010536, 44.887420758605, 44.384126365184784, 48.459878861904144, 49.21737961471081, 47.02376872301102, 47.17166058719158, 46.95109762251377, 43.96141044795513, 45.929993614554405, 42.68424578011036, 43.378069549798965, 42.11447395384312, 42.427029982209206, 43.28998647630215, 41.614428386092186, 42.81476877629757, 45.41654996573925, 44.67811278998852, 42.86171145737171, 41.1061904579401, 41.54451593756676, 43.844251334667206, 40.69252945482731, 44.61458399891853, 42.27526232600212, 41.92831814289093, 45.89991442859173, 48.4229676425457, 45.13886086642742, 46.562473475933075, 45.63954859972, 45.63948020339012, 42.78198033571243, 40.141502022743225, 41.67525552213192, 43.77433508634567, 42.6728729903698, 43.48574437201023, 42.45786912739277, 42.903038039803505, 40.1908765733242, 43.78405876457691, 47.27953299880028, 47.598320692777634, 47.71630436182022, 48.52017022669315, 48.55282947421074, 48.6993458122015, 45.95832869410515, 45.356649979949, 46.221274584531784, 45.66405728459358, 43.79155196249485, 43.82182493805885, 39.39268380403519, 40.76109677553177, 40.83044305443764, 41.90201215445995, 40.20721949636936, 41.219181194901466, 41.86905272305012, 39.731504023075104, 43.42608377337456, 42.09097221493721, 45.20551688969135, 43.421349227428436, 44.163350611925125, 46.04595199227333, 41.89854674041271, 42.92737193405628, 42.309460490942, 41.87944516539574, 40.30915282666683, 40.70558175444603, 41.269292905926704, 41.398968547582626, 40.48104040324688, 41.08476720750332, 39.621811509132385, 39.37792159616947, 39.084292352199554, 40.703476667404175, 41.631208285689354, 40.20148180425167, 40.47976367175579, 41.310676485300064, 40.97131669521332, 39.8540398478508, 41.383773162961006, 40.633701011538506, 42.19159081578255, 41.78608797490597, 41.17952652275562, 42.65013501048088, 46.92547179758549, 47.40871846675873, 49.65722121298313, 47.86515757441521, 47.78813950717449, 47.86209873855114, 50.939120426774025, 54.75732274353504, 56.502341106534004, 58.789362385869026, 55.014736130833626, 55.447696298360825, 37.63522870838642, 0.6401478499174118, 1.2978812749497592, 2.141038575209677, 0.5545535834971815, 0.4255708702839911, 2.433893848210573, 57.4179969727993, 59.54948499798775, 60.300419703125954, 58.05640451610088, 45.19933082163334, 34.987325593829155, 47.68941320478916, 58.83978568017483, 3.6858088709414005, 0.334528349339962, 0.2298237060313113, 0.18150088260881603, 0.22205575020052493, 0.12479544180678204, 0.11679246264975518, 0.16108950600028038, 0.08828329751850106, 0.12073112942744046, 0.19960621342761442, 0.10995668882969767, 0.1760130122420378], [0.1099913397047203, 0.08906305723940022, 0.01789228990674019, 0.07633316141436808, 0.044102363171987236, 0.0611916010529967, 0.02764874509011861, 0.03013326997461263, 0.049460045993328094, 0.07149643657612614, 0.042271807687939145, 0.037274211208568886, 0.05232849500316661, 0.07158634776715189, 0.1077962746785488, 0.13730218866840005, 0.2965374238556251, 23.5087476298213, 41.31294496357441, 50.611779391765594, 29.735484905540943, 31.3473679125309, 48.017442002892494, 48.2801029086113, 50.81842750310898, 47.45007924735546, 5.264520607888699, 1.0887697082944214, 0.5095392395742238, 0.23596849583555013, 1.805457326117903, 51.89287304878235, 62.68571510910988, 53.785027116537094, 52.478091046214104, 47.53767594695091, 48.86292703449726, 46.77049711346626, 44.3340602517128, 41.61725543439388, 41.74934774637222, 42.79662474989891, 44.13267105817795, 44.664862900972366, 46.22879058122635, 47.45876558125019, 48.49835179746151, 46.77382953464985, 44.87871162593365, 41.92608006298542, 40.43999880552292, 39.18437898159027, 39.15270388126373, 38.19882966578007, 37.18268059194088, 40.247447937726974, 38.82529824972153, 37.59617060422897, 38.87780003249645, 39.785229340195656, 40.98954811692238, 39.355525597929955, 39.79528360068798, 37.80626133084297, 40.75524888932705, 39.3770020455122, 39.56395581364632, 37.372514605522156, 40.75182527303696, 43.43979723751545, 40.74471965432167, 40.5291648209095, 40.480839014053345, 39.525118097662926, 39.25033584237099, 38.94187219440937, 40.79481616616249, 38.10286581516266, 37.29616530239582, 39.38028506934643, 37.51765161752701, 36.224698796868324, 37.024225294589996, 39.291221648454666, 43.696370869874954, 45.991056337952614, 45.3975585848093, 46.38857200741768, 45.99240146577358, 43.8533366471529, 43.72206509113312, 43.260982632637024, 45.54673857986927, 42.012985199689865, 41.81988336145878, 36.58909544348717, 36.30984082818031, 37.89407081902027, 36.632534712553024, 38.49420301616192, 35.86234264075756, 37.712622955441475, 37.59436950087547, 38.319480791687965, 39.0405149012804, 39.30727198719978, 40.27364373207092, 37.17517979443073, 38.66419069468975, 40.47765098512173, 39.89223159849644, 38.20176310837269, 36.25780642032623, 36.51428505778313, 37.333950474858284, 35.9193167835474, 36.99492886662483, 37.81944662332535, 37.754462510347366, 37.50225484371185, 35.08044719696045, 37.00796976685524, 35.57018771767616, 37.5377981364727, 36.6270288079977, 37.747516483068466, 38.47833126783371, 36.721529737114906, 37.38230288028717, 37.37824089825153, 38.28964479267597, 40.38153514266014, 38.859606608748436, 40.541354566812515, 38.07567447423935, 38.746129497885704, 38.05233612656593, 37.06642583012581, 37.60109893977642, 38.17728482186794, 38.96657846868038, 42.75535136461258, 44.18801508843899, 47.02485166490078, 49.145422875881195, 52.61825032532215, 50.77587738633156, 57.39083603024483, 38.110966980457306, 0.678362874314189, 0.4633712419308722, 0.41732881567440927, 0.09589641907950863, 0.2548384020337835, 1.1969985882751644, 46.535616517066956, 45.96457935869694, 57.829283103346825, 38.568641021847725, 32.75109998881817, 28.278825469315052, 45.022138729691505, 17.37007822841406, 0.2361035963986069, 0.07962994466652162, 0.016737112928240094, 0.03180084240739234, 0.06362322194036096, 0.0561672353069298, 0.039871171466074884, 0.07744092072243802, 0.04593984660459682, 0.02976322030008305, 0.04700796780525707, 0.038126582658151165, 0.050200345722259954, 0.1320263944217004, 0.017516802145109978, 0.02675999356142711, 0.06942699488718063, 0.04246326694556046, 0.018862855795305222, 0.0366638763807714, 0.0880722381407395, 0.01738197803206276, 0.06142051279312, 0.008636138736619614, 0.037469652088475414, 0.012409898445184808, 0.006856006157249794, 0.07607745443237945, 0.10029159573605284, 0.7631228480022401, 40.436875373125076, 41.044075191020966, 52.37712286412716, 36.500940173864365, 40.543892830610275, 55.53538419306278, 52.34666749835014, 55.58734640479088, 53.7737151235342, 5.281834378838539, 1.0908218356780708, 0.28008929395582527, 0.16185797023354098, 1.8842025194317102, 53.71967822313309, 64.49205458164215, 57.68020190298557, 55.34885600209236, 49.67826448380947, 51.67473055422306, 49.556131437420845, 47.09975324571133, 43.72225508093834, 44.354826137423515, 44.95586268603802, 45.90868055820465, 46.150127202272415, 47.72986203432083, 48.383863940835, 49.7458590567112, 49.531759545207024, 46.82611092925072, 45.95808170735836, 43.79387363791466, 41.74807481467724, 42.22277194261551, 40.91878071427345, 39.874368757009506, 40.361335426568985, 41.035233065485954, 39.46760058403015, 40.34829832613468, 41.04028299450874, 43.065733909606934, 41.246501728892326, 42.055998891592026, 40.45878119766712, 42.10595101118088, 41.92052476108074, 41.015827506780624, 40.209579169750214, 42.340770810842514, 44.96043004095554, 42.676991969347, 42.878016382455826, 41.40629455447197, 41.144044026732445, 40.67123539745808, 40.240228325128555, 41.33476339280605, 40.11391930282116, 39.92706052958965, 39.382169768214226, 40.19173912703991, 38.724854439496994, 40.53880490362644, 42.67957203090191, 46.60747066140175, 47.66588106751442, 48.583592623472214, 48.96227650344372, 48.24627332389355, 47.181232273578644, 44.39688988029957, 45.886170566082, 46.27192586660385, 43.70405025780201, 42.91028805077076, 41.206790059804916, 39.343959018588066, 38.63915003836155, 39.6358859539032, 39.10016030073166, 38.44541743397713, 39.54537481069565, 40.15649601817131, 41.07041537761688, 40.92178255319595, 40.66361680626869, 42.199110612273216, 40.04323549568653, 41.43480062484741, 42.17266783118248, 42.23567225039005, 39.91088479757309, 37.950619384646416, 39.002596735954285, 39.06701847910881, 37.92766861617565, 39.27979566156864, 39.071095660328865, 38.623548075556755, 39.490790739655495, 37.802738919854164, 38.792547807097435, 37.85029336810112, 39.77162227034569, 39.37906913459301, 40.08775770664215, 38.31380009651184, 37.70074099302292, 39.445599764585495, 41.01704724133015, 39.421581253409386, 42.2935925424099, 42.090900018811226, 42.555444091558456, 40.23393206298351, 39.58450511097908, 39.32768069207668, 39.22705069184303, 40.615435391664505, 40.7630118727684, 40.7063303142786, 45.636542961001396, 46.08683779835701, 48.223968520760536, 51.65606215596199, 53.197977617383, 54.45605590939522, 56.674376875162125, 41.07128173112869, 0.5510074237827212, 0.44035332393832505, 1.1887543369084597, 0.042534761741990224, 0.10763487240183167, 1.3005620311014354, 51.86913192272186, 50.79937532544136, 60.78146629035473, 49.973751828074455, 41.06467388570309, 20.325582437217236, 51.09104007482529, 22.574134580790997, 0.3667102474719286, 0.043500206811586395, 0.01609750594070647, 0.05113101004099008, 0.04947562367306091, 0.023252859682543203, 0.03740878855751362, 0.1237406421569176, 0.03429262178542558, 0.019883084351022262, 0.08330089651281014, 0.020283372832636815, 0.008978981277323328, 0.2986076596425846, 0.22247191693168133, 0.13584277010522783, 0.2130551464506425, 0.13264700799481943, 0.10247834128676914, 0.14496643678285182, 0.196505312633235, 0.09559820187860169, 0.1547931251116097, 0.14337430737214163, 0.12312056293012574, 0.08745917963096872, 0.23907335969852284, 0.165298062202055, 0.2260595775442198, 1.2105412990786135, 54.92829076945782, 54.55921657383442, 57.25613705813885, 39.11799654364586, 43.9602667093277, 59.802201837301254, 61.6924712061882, 60.145296826958656, 61.551574766635895, 7.039937814697623, 1.839430471882224, 1.84003250207752, 0.5905577202793211, 2.8741536615416408, 56.3259469717741, 66.09442859888077, 58.727475106716156, 54.96830262243748, 52.267810329794884, 54.19652223587036, 51.309687942266464, 49.51595239341259, 46.93588703870773, 46.652650237083435, 48.386193215847015, 47.990626841783524, 48.611969500780106, 50.15562906861305, 50.73913335800171, 52.867543548345566, 51.12627558410168, 48.758827820420265, 48.370568454265594, 45.61675362288952, 45.963257029652596, 44.843327924609184, 44.19680781662464, 41.03294558823109, 43.73991273343563, 43.27280379831791, 41.79008536040783, 42.94191375374794, 43.50393019616604, 46.58739633858204, 42.99074873328209, 44.0684849023819, 43.19969192147255, 46.481986194849014, 44.16139751672745, 44.219963774085045, 42.09757626056671, 46.01700894534588, 47.32916213572025, 44.73963908851147, 44.551173001527786, 45.93251667916775, 44.98567968606949, 43.82874816656113, 43.20428967475891, 43.961782827973366, 42.74807095527649, 41.65616154670715, 43.08471009135246, 41.900701224803925, 40.54285928606987, 42.385053634643555, 45.394378155469894, 49.15205352008343, 52.11789317429066, 49.664942398667336, 50.05863547325134, 50.65895386040211, 49.60096903145313, 47.5788277387619, 47.067595571279526, 49.723561853170395, 47.021572440862656, 45.96074916422367, 42.26714976131916, 41.954168155789375, 41.64118655025959, 42.68037758767605, 41.62691831588745, 41.00121729075909, 40.770664662122726, 42.465616911649704, 42.03015647828579, 43.31816956400871, 42.42210924625397, 45.83564467728138, 41.25407472252846, 42.53709867596626, 45.16167104244232, 45.04146449267864, 42.64918126165867, 39.846550449728966, 41.25567063689232, 41.80517055094242, 38.28788548707962, 40.31427875161171, 41.36626750230789, 40.89099660515785, 41.15192860364914, 39.533067271113396, 39.69280689954758, 39.381447806954384, 42.72139258682728, 41.24872460961342, 41.64117515087128, 42.52042897045612, 39.09414902329445, 40.78877069056034, 42.98671334981918, 40.67993313074112, 44.16582427918911, 44.806815683841705, 45.634046494960785, 41.64289265871048, 41.35188527405262, 41.47048071026802, 40.225443318486214, 41.564734652638435, 43.24061952531338, 43.4952362626791, 48.0407727509737, 48.18695090711117, 50.97063213586807, 54.44130130112171, 54.80134718120098, 57.51993030309677, 58.03045190870762, 44.6286166459322, 1.0759693826548755, 1.1340194614604115, 3.6815314879640937, 0.21832399419508874, 0.7630880561191589, 1.9812079891562462, 60.457450076937675, 57.75212064385414, 66.01992219686508, 49.97951611876488, 43.97294282913208, 34.96522217988968, 61.78755730390549, 29.264279790222645, 0.4757923894794658, 0.262669277144596, 0.10545982309849933, 0.13925617444328964, 0.12402351916534826, 0.12201603196444921, 0.06031761826307047, 0.13409142033196986, 0.25670137081760913, 0.08461045319563709, 0.1734722696710378, 0.11067105049733073, 0.1769425967358984], [0.03235866657632869, 0.028711487575492356, 0.07345314603298903, 0.04197587630187627, 0.014429786006076029, 0.03267999054514803, 0.009622901998227462, 0.03942408686270937, 0.03833319657132961, 0.044503980097942986, 0.03875528564094566, 0.04208781072520651, 0.10825914476299658, 0.02086973443510942, 0.16096380102680996, 0.10244649572996423, 0.045643900375580415, 8.747087884694338, 37.65514723956585, 48.72906781733036, 37.46241398155689, 21.629174686968327, 39.58465710282326, 55.59464581310749, 49.447122886776924, 50.903945714235306, 11.89980436116457, 0.7944378582760692, 0.4312234529061243, 0.5820084759034216, 0.867803015280515, 39.972072914242744, 67.91571646928787, 53.74104827642441, 54.15923483669758, 44.596842750906944, 46.20960921049118, 41.82028993964195, 43.971001133322716, 41.778188198804855, 44.64315086603165, 43.880900368094444, 47.55381368100643, 46.91054239869118, 50.395042821764946, 49.57851983606815, 50.52007131278515, 48.922424241900444, 48.05813021957874, 42.530764415860176, 41.6478855907917, 40.458165630698204, 41.68696649372578, 39.03786264359951, 38.87623451650143, 38.29628303647041, 37.66130670905113, 38.0882403999567, 39.30013217031956, 41.4042616635561, 40.26903077960014, 37.94919826090336, 39.81351502239704, 38.65238852798939, 39.00668151676655, 39.033314287662506, 40.585903376340866, 39.550736322999, 40.626652389764786, 41.841386407613754, 40.17245516180992, 39.43513132631779, 39.363208785653114, 37.415946274995804, 38.56895260512829, 39.29746091365814, 40.50072714686394, 39.61502127349377, 39.7531932592392, 37.64503978192806, 39.77124609053135, 37.86740384995937, 36.82780243456364, 41.27056583762169, 47.491930201649666, 47.75334857404232, 50.108082219958305, 48.79116788506508, 49.17039513587952, 49.2924901843071, 45.997892171144485, 44.25936006009579, 46.93187825381756, 45.084204599261284, 45.31142860651016, 38.924203142523766, 36.16745866835117, 36.285180151462555, 36.104199662804604, 37.01815702021122, 36.58385172486305, 35.729687958955765, 37.34300538897514, 37.896742075681686, 38.356749191880226, 37.825754284858704, 38.25556822121143, 39.001122415065765, 37.609310299158096, 36.9158361107111, 38.61154831945896, 37.83881418406963, 38.079470470547676, 39.529567658901215, 36.24993324279785, 36.44185334444046, 36.62607505917549, 37.641509771347046, 36.80866666138172, 37.18197003006935, 38.02802123129368, 36.51548959314823, 37.18600541353226, 37.81497806310654, 37.644192427396774, 36.960913091897964, 36.64327293634415, 39.85113300383091, 40.891015604138374, 40.70793382823467, 42.86323517560959, 42.82156281173229, 43.01557660102844, 42.885828763246536, 41.64520673453808, 40.95607191324234, 38.24639551341534, 38.27838979661465, 38.86383958160877, 37.578250765800476, 38.489681258797646, 43.591530695557594, 45.17162650823593, 44.424267411231995, 46.83138884603977, 49.37332324683666, 51.46334409713745, 57.02561102807522, 44.25529047846794, 1.4547494449652731, 0.6550152052659541, 1.8310444406233728, 0.250994730158709, 0.056805730928317644, 2.153188423253596, 43.26637454330921, 52.245653718709946, 48.776097893714905, 29.08385407179594, 25.346798300743103, 36.3393310457468, 42.69032925367355, 2.311049052514136, 0.1701190386665985, 0.13069735636236146, 0.040482025797246024, 0.018093181861331686, 0.0436845859803725, 0.054553398076677695, 0.07429402161506005, 0.05520253980648704, 0.06103121551859658, 0.1322433093446307, 0.055742686017765664, 0.014388363033503992, 0.017282281623920426, 0.019339687532919925, 0.03716395774972625, 0.010990477003360866, 0.038841649366077036, 0.03921239294868428, 0.01141946804636973, 0.061481446828111075, 0.05628253908071201, 0.03788703594182152, 0.059019646505475976, 0.09339707350591198, 0.06003862639772706, 0.1072334373020567, 0.09135696149314754, 0.156986067595426, 0.18729333038209006, 0.05890318498131819, 17.258109636604786, 45.57564362883568, 47.99516759812832, 39.572007581591606, 31.989601850509644, 46.00712187588215, 61.73209547996521, 52.651422545313835, 58.05283650755882, 11.99371537193656, 0.9136060543823987, 0.2006973189418204, 0.5729086766950786, 1.0684671602211893, 41.51011638343334, 69.58230704069138, 58.11364084482193, 56.82667650282383, 45.281581208109856, 49.293687120079994, 45.08024521172047, 44.70095336437225, 43.69056478142738, 45.89829571545124, 46.196252927184105, 50.08867286145687, 49.44632112979889, 51.36086739599705, 52.00865663588047, 53.69869954884052, 50.03636106848717, 50.01144200563431, 46.100030690431595, 43.186757415533066, 41.58430740237236, 42.75880917906761, 39.97013881802559, 41.92209407687187, 41.6391346603632, 41.99273608624935, 41.58265829086304, 41.20227970182896, 42.14178688824177, 42.150127440690994, 40.57551093399525, 41.438387632369995, 39.67045269906521, 41.13820753991604, 41.93754404783249, 43.59335079789162, 41.8788143992424, 41.404147669672966, 43.7675828486681, 40.94383276998997, 42.08548150956631, 41.9804323464632, 38.45519430935383, 42.517411932349205, 41.57327279448509, 43.09782698750496, 41.380478739738464, 42.681369334459305, 40.954259410500526, 41.9286335259676, 38.30934673547745, 37.98091895878315, 41.88237100839615, 49.13111284375191, 48.541661873459816, 52.04936005175114, 52.06070624291897, 49.99696098268032, 50.62566764652729, 47.60196849703789, 45.4998566955328, 47.16222569346428, 45.22059828042984, 46.02583967149258, 42.16589659452438, 38.59821103513241, 38.927341774106026, 38.23402337729931, 39.54156741499901, 38.20150852203369, 36.870436146855354, 38.77075597643852, 40.21172605454922, 40.11316694319248, 40.3411129117012, 40.4544760286808, 41.4775787293911, 40.15627183020115, 40.11524923145771, 40.31580626964569, 38.61143812537193, 39.53815519809723, 40.668773129582405, 37.33800865709782, 39.66588534414768, 39.031186401844025, 38.56888800859451, 40.12697160243988, 39.08898130059242, 38.07270683348179, 38.57752874493599, 38.731002509593964, 38.32515388727188, 40.377336367964745, 37.93063245713711, 39.18868415057659, 41.69738933444023, 42.32613019645214, 42.97296568751335, 44.81585919857025, 44.681145027279854, 43.82431760430336, 44.76452015340328, 42.46003121137619, 43.16900856792927, 41.73276163637638, 39.9114091694355, 41.34953700006008, 40.30836246907711, 41.16246543824673, 45.128324031829834, 47.48730204999447, 45.49672946333885, 48.65551136434078, 50.73179595172405, 53.02580885589123, 57.590036541223526, 46.722315698862076, 1.2375179515220225, 0.8279563940595835, 1.198424817994237, 0.3039472340606153, 0.15705336554674432, 2.1115542948246, 51.17715485394001, 57.46568061411381, 53.88349503278732, 39.38647113740444, 27.519443817436695, 33.39961498975754, 52.500498443841934, 3.8147183787077665, 0.17916801560204476, 0.05267299995466601, 0.04830515288631432, 0.031081573288247455, 0.02650484133482678, 0.019981094228569418, 0.10141467297216877, 0.013187488311814377, 0.12284068419830874, 0.0497741859726375, 0.01211162187246373, 0.06368510221363977, 0.03073745425353991, 0.11446902091847733, 0.13193303224397823, 0.16176190663827583, 0.17034949036315084, 0.12541332427645102, 0.09136966706137173, 0.12480436242185533, 0.1314275703043677, 0.12734791031107306, 0.12054469450959004, 0.1555587988696061, 0.19157955975970253, 0.24328492901986465, 0.1677388820098713, 0.35962054040282965, 0.2929824771126732, 0.2478562470059842, 23.639092035591602, 58.092137798666954, 54.06482130289078, 44.24412287771702, 35.84868237376213, 48.919004425406456, 68.5859777033329, 58.00035372376442, 67.3065559566021, 15.519838761538267, 1.4558114879764616, 2.11468200199306, 1.2613822147250175, 1.1189423454925418, 42.02079378068447, 72.28425845503807, 58.679118901491165, 59.374078810214996, 47.80081942677498, 51.25228822231293, 47.095497474074364, 48.48388597369194, 46.21229946613312, 49.75305587053299, 47.123703360557556, 52.169874384999275, 50.79518795013428, 54.481529742479324, 54.08013068139553, 55.04639983177185, 52.581928074359894, 52.353708520531654, 48.07769536972046, 45.26728257536888, 45.19362352788448, 47.51144975423813, 41.74021303653717, 43.839645981788635, 42.36635483801365, 43.53915050625801, 43.88423278927803, 44.72129367291927, 44.714305847883224, 45.357238948345184, 41.8852474540472, 43.33938002586365, 41.66369654238224, 43.45190718770027, 43.575202971696854, 45.846865475177765, 43.87624181807041, 43.77066448330879, 46.21638424694538, 43.8239224255085, 43.55103626847267, 44.41687300801277, 39.598359167575836, 43.32598954439163, 43.961722031235695, 44.552708119153976, 43.975416496396065, 44.704658165574074, 42.39756256341934, 44.09305818378925, 40.31001538038254, 40.65215662121773, 44.36662830412388, 50.66559970378876, 50.96514903008938, 54.5561957359314, 52.99735218286514, 51.937083676457405, 54.88885648548603, 50.165561735630035, 49.16184559464455, 51.12096346914768, 48.58024500310421, 49.62103575468063, 43.838779628276825, 40.328835770487785, 42.07024432718754, 41.31745532155037, 40.42200297117233, 40.74446886777878, 39.16343830525875, 41.72903023660183, 41.91701754927635, 42.13968180119991, 41.66715055704117, 41.962417513132095, 43.87012794613838, 41.52961313724518, 41.220784708857536, 42.46319264173508, 40.36264255642891, 41.64093196392059, 43.32341708242893, 38.83955128490925, 41.84997774660587, 40.55134803056717, 40.3378526866436, 41.2962980568409, 40.96576139330864, 40.452591329813, 40.65589942038059, 39.098416194319725, 40.772705152630806, 41.349719390273094, 38.74391421675682, 40.2441231161356, 43.67787726223469, 45.852534770965576, 45.780502036213875, 49.03715528547764, 46.43552228808403, 45.56110180914402, 47.20599554479122, 45.591591373085976, 45.096417143940926, 43.680696710944176, 41.212774738669395, 43.60576473176479, 42.57163502275944, 42.53223493695259, 48.50893422961235, 50.349190682172775, 48.49589332938194, 49.67334754765034, 53.75648684799671, 57.20844201743603, 59.75109077990055, 48.46858039498329, 1.9741638796404004, 2.1353433933109045, 4.74503243342042, 0.4522311600157991, 0.4904102050932124, 3.0941302701830864, 56.92841224372387, 61.11185856163502, 60.476262867450714, 38.839144706726074, 37.001080736517906, 43.841010108590126, 59.75881576538086, 6.036788318306208, 0.4329967999365181, 0.2008685324108228, 0.11775288337958045, 0.10025442898040637, 0.08184533711755648, 0.122152943367837, 0.17478260560892522, 0.10163537284824997, 0.299210847588256, 0.22865743580041453, 0.180285140813794, 0.12499700911575928, 0.11694387561874464], [0.02895180427003652, 0.046002676826901734, 0.090189444454154, 0.02620541628857609, 0.046688766378792934, 0.018343500851187855, 0.028364919453451876, 0.005953065228823107, 0.04399962766910903, 0.02587373379355995, 0.020829341192438733, 0.0313614872720791, 0.009927830997185083, 0.11221589025808498, 0.1248106113052927, 0.10656143000232987, 0.028886777290608734, 1.2879777001217008, 37.616925090551376, 55.83464473485947, 47.37873427569866, 23.495769426226616, 29.20872677117586, 55.05996510386467, 50.530376359820366, 53.69165852665901, 18.847011476755142, 0.582930757664144, 0.5767228407785296, 0.7723768358118832, 0.31668029143474996, 23.839506581425667, 70.62873288989067, 54.228786304593086, 61.0931483656168, 46.38332448899746, 45.806743428111076, 43.84039454162121, 42.92423330247402, 41.54714919626713, 46.41582414507866, 46.03719346225262, 48.09811167418957, 48.56216937303543, 53.040924444794655, 50.653060376644135, 53.159785866737366, 49.3872456997633, 46.988746002316475, 42.19336912035942, 41.175042763352394, 37.511423751711845, 40.746121779084206, 36.90759435296059, 37.66235165297985, 39.110446348786354, 39.735896587371826, 38.07635083794594, 39.820309057831764, 39.802909791469574, 39.33562986552715, 38.48142430186272, 40.524350479245186, 38.01787957549095, 40.27955621480942, 39.450034126639366, 40.15833891928196, 38.95598083734512, 40.254093781113625, 40.882971435785294, 39.481101259589195, 39.966266825795174, 39.63264852762222, 38.28954599797726, 40.71654796600342, 39.65772718191147, 39.68844473361969, 39.87832434475422, 40.55050067603588, 40.71354612708092, 39.207466542720795, 35.86457312107086, 36.20696134865284, 40.712584778666496, 50.60350343585014, 50.07066182792187, 52.27563410997391, 52.903018444776535, 53.62222105264664, 49.63273532688618, 47.22301483154297, 47.19092555344105, 48.545803651213646, 49.64908204972744, 46.35247014462948, 40.74182040989399, 37.800022065639496, 35.90607449412346, 36.89366430044174, 36.48572579026222, 36.74894906580448, 36.34802497923374, 38.45308542251587, 36.584873870015144, 37.1085199713707, 38.506856337189674, 39.11320500075817, 36.22441001236439, 37.08577819168568, 38.29757496714592, 38.89750957489014, 37.38643325865269, 36.56615987420082, 38.276869878172874, 38.275087773799896, 35.695421397686005, 38.28405149281025, 38.820730894804, 38.88945400714874, 37.395263984799385, 35.99250465631485, 37.00620286166668, 37.1712052077055, 37.46343232691288, 37.559821754693985, 37.32643447816372, 39.89138424396515, 40.713295340538025, 43.183592185378075, 44.40670855343342, 42.52464674413204, 43.731142804026604, 45.31710930168629, 45.02222992479801, 43.195211961865425, 43.556785359978676, 40.107364654541016, 39.424229711294174, 39.30720739066601, 38.54370675981045, 37.541616931557655, 38.36796998977661, 40.709290355443954, 41.94881424307823, 42.90619567036629, 49.76049967110157, 52.68039979040623, 54.59402270615101, 40.579128339886665, 1.0567073849961162, 0.5490681028459221, 0.5981968541163951, 0.20827415690291673, 0.47788773954380304, 3.1904674507677555, 45.99655084311962, 47.1150816231966, 43.72706562280655, 27.304704040288925, 28.46268430352211, 39.246817231178284, 24.61501646786928, 0.2628992241807282, 0.04945494372805115, 0.06251755548873916, 0.06121167985838838, 0.031041439797263592, 0.050160596292698756, 0.016535404611204285, 0.011372735007171286, 0.03071899147471413, 0.03547032109054271, 0.027860420450451784, 0.008298451339214807, 0.011135259810544085, 0.02174331275455188, 0.022425181341532152, 0.05797234996862244, 0.043287778171361424, 0.018825954357453156, 0.019183239091944415, 0.13115309440763667, 0.014406753452931298, 0.10293044280842878, 0.10394306620582938, 0.019005453905265313, 0.04915813660772983, 0.07962684248923324, 0.06435577364754863, 0.1676499578752555, 0.18139002058887854, 0.1452245854306966, 0.02632515625009546, 3.535052672959864, 45.44485464692116, 55.96849635243416, 44.45662647485733, 32.02828757464886, 38.535233214497566, 60.09344480931759, 55.41410990059376, 59.223952665925026, 20.866880491375923, 0.6716788548510522, 0.3179178078426048, 0.8427378383930773, 0.4112515761516988, 25.362335667014122, 73.21309581398964, 57.32177093625069, 61.80932633578777, 46.96988761425018, 47.33444765210152, 43.550686687231064, 46.58409431576729, 43.42664994299412, 49.192509949207306, 48.58988128602505, 51.165599673986435, 50.715445429086685, 53.703434094786644, 51.985774263739586, 55.9227392077446, 51.23964250087738, 50.27690716087818, 43.95231753587723, 42.26968802511692, 40.07451541721821, 41.3620725274086, 40.016416534781456, 40.94893589615822, 41.287018954753876, 41.938877776265144, 40.17474263906479, 42.03123562037945, 41.5490110963583, 41.84521660208702, 40.5326834321022, 42.17702619731426, 41.30233213305473, 41.276873499155045, 41.75426088273525, 41.77072539925575, 41.60470850765705, 41.626097559928894, 41.93720206618309, 41.78479604423046, 42.85195738077164, 42.30459675192833, 40.15410594642162, 41.21717110276222, 40.49970120191574, 42.01900027692318, 41.05213075876236, 42.75583013892174, 42.665375992655754, 39.64460268616676, 39.8083359003067, 38.04365359246731, 42.677200958132744, 50.193277448415756, 52.16503344476223, 53.41976411640644, 54.7965632379055, 54.179856330156326, 51.50788530707359, 48.99886853992939, 50.28445355594158, 48.75410467386246, 49.89458687603474, 49.61032032966614, 45.16046270728111, 38.96133095026016, 37.839099168777466, 39.07855086028576, 37.990133464336395, 38.32069672644138, 39.53887335956097, 39.719534665346146, 37.81861066818237, 39.80376094579697, 40.95889516174793, 40.741121247410774, 39.03030104935169, 39.39520686864853, 38.919631987810135, 40.65366894006729, 38.866191655397415, 39.650332778692245, 40.172690749168396, 40.201348811388016, 38.991474732756615, 39.90671642124653, 39.45879265666008, 39.744111746549606, 39.59507994353771, 37.614633813500404, 37.93619155883789, 39.154132604599, 38.132078647613525, 39.167910665273666, 39.03401345014572, 41.25306397676468, 42.148953303694725, 44.85413834452629, 45.49047499895096, 44.662332236766815, 45.66118083894253, 48.13476450741291, 48.52490097284317, 44.58957754075527, 44.11767326295376, 43.35522137582302, 40.46347014605999, 42.66739748418331, 39.37730982899666, 40.69189868867397, 41.871948167681694, 43.76310668885708, 43.13993252813816, 45.52482135593891, 51.46299451589584, 55.273422449827194, 54.954820945858955, 42.635141015052795, 1.2520444532856345, 1.1953392648138106, 0.5628411762882024, 0.37895936518907547, 0.6867781165055931, 3.23740656953305, 50.607725009322166, 51.22488409280777, 51.03518687188625, 36.576316729187965, 25.423867665231228, 41.31264477968216, 31.13178078085184, 0.3939476906089112, 0.06269771183724515, 0.1151085741003044, 0.01956610936758807, 0.0676730030681938, 0.05479112282046117, 0.041185422232956626, 0.034147149708587676, 0.024056356996879913, 0.06250097590964288, 0.037009865627624094, 0.02980157263664296, 0.04061818021000363, 0.12530183885246515, 0.08164435610524379, 0.1095193560468033, 0.213681370660197, 0.14467643515672535, 0.10510326566873118, 0.18384807306574658, 0.11593491843086667, 0.23623216606210917, 0.20474080665735528, 0.1689924139645882, 0.14801080076722428, 0.17550110846059397, 0.14504874096019194, 0.3049928607651964, 0.28718211804516613, 0.2548374223988503, 0.19264823757112026, 4.499817816540599, 59.22262653708458, 65.72507321834564, 51.89734920859337, 36.77556663751602, 40.098777115345, 66.34161293506622, 59.809619039297104, 67.20951676368713, 24.07571330666542, 0.6742402142845094, 1.873450877610594, 1.1870538094080985, 0.5351030209567398, 26.74347035586834, 75.60448989272118, 58.93813960254192, 65.0104683637619, 50.276557579636574, 52.0959797501564, 46.713842153549194, 48.56826804578304, 45.59081241488457, 52.0267778635025, 50.35566173493862, 53.01711492240429, 53.351158797740936, 55.25278955698013, 54.07738342881203, 57.56571784615517, 52.88066424429417, 51.99892535805702, 47.029855996370316, 44.372989162802696, 41.44769333302975, 45.296552404761314, 41.45861014723778, 44.3760821968317, 43.918332159519196, 43.90879087150097, 41.44805051386356, 44.07195791602135, 43.7245387583971, 44.00591365993023, 43.107246682047844, 46.05108931660652, 42.609287202358246, 43.32144498825073, 44.55533377826214, 44.55553136765957, 45.00181742012501, 45.05400761961937, 44.50860768556595, 44.04408261179924, 45.025414153933525, 44.33977894484997, 42.014364525675774, 44.851869866251945, 42.757209464907646, 44.40422348678112, 44.09957863390446, 47.019281163811684, 44.870606660842896, 43.08390833437443, 41.293938383460045, 40.03592848777771, 45.82085967063904, 52.3588914424181, 54.272286370396614, 57.44114153087139, 58.78242775797844, 58.45350980758667, 53.96216981112957, 51.248469427227974, 51.480291187763214, 51.0458604991436, 53.905165269970894, 50.9669691324234, 45.97814843058586, 41.08057223260403, 40.56550607085228, 41.645856499671936, 39.85405124723911, 40.69510571658611, 40.969272404909134, 42.3000255972147, 39.5398461073637, 41.427265629172325, 42.12914116680622, 44.471867457032204, 40.13665348291397, 39.5663420855999, 40.94762496650219, 42.95637957751751, 41.606555208563805, 41.65643513202667, 43.550139516592026, 42.64060132205486, 39.82116021215916, 42.350787073373795, 43.356562703847885, 42.164319679141045, 40.93052588403225, 40.694094970822334, 40.39904460310936, 41.322030276060104, 40.92267170548439, 41.41063392162323, 41.77033022046089, 43.88826057314873, 45.228490456938744, 46.17756552994251, 48.6420638859272, 47.57386900484562, 47.114526852965355, 51.401992589235306, 50.681220665574074, 47.013570070266724, 47.496603950858116, 44.778302013874054, 42.42090851068497, 44.6504844725132, 40.61174958944321, 42.95777790248394, 43.25775280594826, 45.02039462327957, 45.82660876214504, 47.10365563631058, 54.73552331328392, 58.12086425721645, 55.28519421815872, 43.16400043666363, 1.6220481740310788, 2.2753437934443355, 1.9845413602888584, 0.9236939786933362, 1.4863420184701681, 5.149442832916975, 58.04899111390114, 57.6266285777092, 59.11640323698521, 39.472354128956795, 37.41179309785366, 49.193923473358154, 41.11709587275982, 0.5350586702115834, 0.11944764439249411, 0.15868089540163055, 0.21268235082970932, 0.1926769586862065, 0.10532824773690663, 0.15623776009306312, 0.07519061022321694, 0.20468670409172773, 0.12340438988758251, 0.1260101149091497, 0.09665404795669019, 0.12399771469063126, 0.2336148190079257], [0.05501134401129093, 0.06312541896477342, 0.008412809802393895, 0.030926006147637963, 0.03256123578466941, 0.02735348720307229, 0.04498575639445335, 0.02949086694570724, 0.03791656970861368, 0.06683753774268553, 0.026430728612467647, 0.021050311952421907, 0.07702304705162533, 0.021213755135249812, 0.033925425668712705, 0.11560053637367673, 0.05973949264443945, 0.11845970482681878, 19.39456209540367, 55.53160339593887, 42.74255745112896, 26.11892256885767, 28.132594116032124, 47.45038703083992, 52.31718868017197, 50.896946489810944, 26.55507266521454, 0.2429250764544122, 0.21992817608406767, 0.510210853535682, 0.05708043318009004, 6.465327898040414, 70.05089029669762, 56.87924288213253, 60.44994927942753, 50.60892194509506, 48.44498746097088, 41.28638818860054, 42.83809572458267, 40.8010820299387, 45.9594040364027, 46.19214914739132, 49.77901607751846, 49.26003612577915, 52.401190772652626, 50.66248767077923, 50.93451127409935, 49.49140951037407, 46.99017472565174, 39.80904646217823, 40.1037510484457, 38.62140879034996, 40.48276171088219, 37.24702633917332, 38.10896448791027, 39.40939910709858, 39.24069955945015, 38.80106694996357, 39.09990951418877, 39.65213768184185, 41.388127729296684, 38.530164286494255, 40.07374785840511, 39.15511295199394, 40.49960620701313, 40.354784578084946, 41.263471618294716, 39.306417033076286, 40.00602029263973, 41.58187173306942, 39.233156964182854, 38.631873428821564, 39.121389761567116, 39.09055441617966, 39.960643127560616, 40.30504144728184, 39.162549152970314, 39.47654150426388, 39.5555354654789, 40.57035841047764, 39.072098806500435, 36.493249386548996, 37.959149926900864, 40.2510691434145, 48.00239861011505, 51.33963793516159, 52.33540490269661, 54.87355850636959, 54.7619204968214, 53.48319411277771, 49.87558029592037, 49.58288960158825, 51.48532211780548, 50.07880479097366, 49.02376100420952, 42.94463060796261, 35.68595990538597, 37.75774173438549, 37.22807675600052, 38.438042029738426, 37.51414820551872, 37.56544165313244, 37.32193171977997, 39.184390380978584, 37.163879200816154, 38.51626083254814, 36.69002182781696, 37.65472166240215, 38.561884984374046, 39.27720420062542, 39.094232618808746, 36.62557728588581, 37.31264501810074, 37.42971673607826, 37.65260897576809, 37.58505620062351, 38.08613531291485, 38.86776477098465, 38.53284694254398, 38.93852837383747, 37.10255429148674, 35.98264038562775, 35.409045964479446, 35.79877205193043, 36.85639210045338, 41.46122060716152, 43.662560284137726, 42.98886403441429, 43.43628242611885, 43.48814584314823, 44.384494945406914, 45.37471041083336, 43.52136366069317, 45.73596842586994, 42.969409078359604, 43.1033518910408, 43.05485509335995, 41.88174784183502, 40.05978360772133, 39.403049647808075, 38.459161296486855, 38.212170749902725, 39.82942096889019, 40.266306325793266, 47.37371854484081, 49.795165210962296, 51.93641871213913, 55.9903147816658, 26.11478839069605, 0.2691035490715876, 0.6875529186800122, 0.1911578862927854, 0.48955459787975997, 0.680773607455194, 9.533926863223314, 59.07461307942867, 47.991808578372, 42.057731598615646, 21.692992262542248, 24.91505216807127, 45.079291462898254, 6.079374058172107, 0.23464766592951491, 0.06720543518895283, 0.07807357193087228, 0.030827560258330777, 0.05025713115173858, 0.05641485287924297, 0.05116756081406493, 0.01972649675735738, 0.031083836838661227, 0.04934418560878839, 0.06159709570056293, 0.05324562625901308, 0.05563066995819099, 0.04364551932667382, 0.017078922028304078, 0.10467919506481849, 0.04703429549408611, 0.026145636293222196, 0.03060453374928329, 0.05635372959659435, 0.03845562125206925, 0.02127229203324532, 0.02882867269363487, 0.06597698040422983, 0.02114051443641074, 0.06812890438595787, 0.02356433164095506, 0.050110159936593845, 0.02428160994895734, 0.1288127910811454, 0.09062934506800957, 0.09476114093558863, 27.44306031614542, 62.03816145658493, 42.54105046391487, 31.186630837619305, 36.6954555362463, 52.63750769197941, 56.95334650576115, 55.20957067608833, 27.931182123720646, 0.2507961611263454, 0.1946040490292944, 0.6299336417578161, 0.026667872625694145, 8.171846251934767, 71.23483836650848, 58.255358040332794, 63.909675031900406, 51.36484198272228, 50.576570481061935, 42.42408134043217, 45.02126097679138, 43.735816553235054, 48.2343989610672, 48.50397549569607, 51.33491858839989, 50.68389572203159, 55.734622702002525, 51.757338121533394, 54.11896839737892, 51.280190125107765, 49.288713186979294, 41.47933803498745, 43.01718771457672, 40.190507993102074, 41.16917587816715, 40.02023532986641, 41.00822791457176, 42.48954802751541, 41.49016745388508, 40.87790630757809, 43.29259693622589, 41.220526322722435, 42.41272754967213, 39.93436373770237, 41.0213790088892, 40.41638687252998, 41.69053830206394, 42.80245743691921, 42.52266705036163, 41.17430940270424, 41.37799747288227, 42.13122345507145, 40.95683567225933, 40.47832354903221, 41.77452899515629, 41.02390967309475, 42.50633932650089, 42.327669113874435, 41.508368477225304, 40.62278799712658, 42.34759524464607, 43.64023648202419, 40.031551122665405, 37.96229615807533, 41.248910799622536, 42.6393473893404, 50.77249176800251, 52.03555919229984, 54.38293643295765, 55.41768930852413, 55.87854377925396, 54.918555691838264, 51.87801204621792, 51.3004544377327, 54.91616562008858, 52.022620886564255, 50.601865723729134, 44.605255499482155, 39.02360200881958, 39.699638932943344, 39.04241479933262, 39.38443444669247, 39.61331896483898, 38.54689098894596, 38.5440107434988, 39.89255078136921, 39.77735996246338, 41.03671498596668, 39.139936566352844, 40.46899504959583, 40.91348759829998, 39.71080653369427, 39.32644575834274, 38.348575830459595, 39.90467973053455, 40.35544194281101, 39.82347808778286, 38.818325623869896, 41.43192417919636, 40.75615704059601, 40.82450017333031, 41.302316933870316, 39.765660390257835, 38.12494643032551, 37.475397884845734, 38.317387104034424, 38.6078055202961, 43.20122703909874, 45.64605385065079, 44.77271631360054, 46.12534873187542, 45.78219294548035, 46.651054322719574, 45.27094177901745, 45.827262327075005, 47.25477732717991, 45.65083399415016, 44.104833751916885, 45.079500451684, 43.849806636571884, 42.34720766544342, 40.417116433382034, 40.46003893017769, 40.37895128130913, 42.44642414152622, 43.37987445294857, 49.85766425728798, 52.482232823967934, 54.386310651898384, 56.984687224030495, 29.101559221744537, 0.5760092509444803, 1.6973394714295864, 0.7136188074946404, 0.3521643904969096, 0.7575704553164542, 9.137634728103876, 66.69794261455536, 49.6803467720747, 51.84391267597675, 28.317330703139305, 22.660084068775177, 53.08048412203789, 9.139260090887547, 0.27630956552457064, 0.13626211322844028, 0.05722780515498016, 0.022864065213070717, 0.05186412949115038, 0.07575722513138317, 0.05123278817336541, 0.02788254201732343, 0.07818136145942844, 0.044941824962734245, 0.07828469810192473, 0.04213432483084034, 0.09881700767436996, 0.06420280958991498, 0.14821364457020536, 0.33682713692542166, 0.15304219094105065, 0.11920932593056932, 0.18183553183916956, 0.11402845237171277, 0.15738520945888013, 0.12521815428044647, 0.19445276964688674, 0.17764986347174272, 0.20004082995001227, 0.09642868739319965, 0.12885878939414397, 0.1643582954420708, 0.11037546049919911, 0.21557942818617448, 0.15469139150809497, 0.16163387132110074, 31.19740705937147, 70.42686492204666, 49.922557175159454, 37.58327029645443, 40.7659263163805, 57.48501017689705, 61.268550753593445, 63.500509187579155, 32.137413918972015, 0.23827045981306583, 1.1608112300746143, 1.2667598761618137, 0.12688510701991618, 8.999197706580162, 73.52870687842369, 60.60458958148956, 65.26047214865685, 53.80206160247326, 52.43885435163975, 44.729630425572395, 46.05722978711128, 45.90979389846325, 50.386440083384514, 50.073276087641716, 54.0211046487093, 52.90389619767666, 57.49544821679592, 54.570627361536026, 55.19898824393749, 52.89041832089424, 51.585800126194954, 44.095889031887054, 44.78956840932369, 41.08908377587795, 43.58332693576813, 42.50586815178394, 42.10752412676811, 44.93758946657181, 43.440633192658424, 43.39548401534557, 45.30542112886906, 44.42376583814621, 45.4137647151947, 42.91274651885033, 41.91970020532608, 42.74958327412605, 44.44647341966629, 45.97596354782581, 45.357736721634865, 41.86143033206463, 43.91575589776039, 45.57979680597782, 43.02405394613743, 42.78680607676506, 43.953130692243576, 42.99869030714035, 45.10378874838352, 44.8423969745636, 43.59254904091358, 42.507334873080254, 43.82502816617489, 46.246178448200226, 41.38125769793987, 39.881683364510536, 44.60153549909592, 44.218687042593956, 52.36774116754532, 54.69369515776634, 57.214795276522636, 59.10874664783478, 58.615027740597725, 57.25606866180897, 54.216729551553726, 54.083846881985664, 55.61367139220238, 55.16291677951813, 54.64224971830845, 46.232259795069695, 40.662625059485435, 41.64694704115391, 42.287554666399956, 42.326912954449654, 42.18540094792843, 40.05902364850044, 40.71155123412609, 42.360142171382904, 38.76474089920521, 41.95962466299534, 39.57013428211212, 41.976567953825, 43.814916908741, 43.07706490159035, 42.63173259794712, 40.922914892435074, 43.17548342049122, 42.932896837592125, 42.68880933523178, 41.4671216905117, 43.02616663277149, 41.82362236082554, 42.85953037440777, 42.63032287359238, 41.6214694082737, 38.67614105343819, 39.37157213687897, 40.158361718058586, 40.99007248878479, 46.06677107512951, 48.72140362858772, 47.07205653190613, 47.9563906788826, 47.08008170127869, 48.62383246421814, 47.43538923561573, 48.515918254852295, 49.31916855275631, 48.10478411614895, 47.324370592832565, 47.37225562334061, 45.486887991428375, 44.88919906318188, 42.21098117530346, 41.66561923921108, 42.489114850759506, 45.63539542257786, 45.48895888030529, 52.59692206978798, 55.0910360366106, 56.19339108467102, 56.8049568682909, 30.001160949468613, 0.7033422589302063, 3.3124917279928923, 1.0176300443708897, 1.3855415023863316, 1.388216083869338, 12.990528233349323, 71.94920003414154, 55.970954820513725, 52.21099577844143, 33.07330369949341, 32.007586285471916, 62.32038751244545, 12.824325151741505, 0.5449691321700811, 0.21944632928352803, 0.18472873518476263, 0.12873952626250684, 0.17174121021525934, 0.15806713927304372, 0.13323334918823093, 0.08995543787023053, 0.1645485672634095, 0.09838481797487475, 0.199237366032321, 0.16825368016725406, 0.22064065269660205, 0.10381394735304639], [0.09225447036442347, 0.020967419623048045, 0.005959495474598953, 0.03369275123986881, 0.035993928540847264, 0.09268580659409054, 0.03603678756917361, 0.05437590603833087, 0.06587855677935295, 0.02455585763527779, 0.07484788642614149, 0.06932814081665128, 0.03619000766775571, 0.04797099347342737, 0.045189895245130174, 0.009975822904380038, 0.07296050840523094, 0.12240012307302095, 2.454251255840063, 40.731963738799095, 49.813206642866135, 31.29537720233202, 28.632381297647953, 44.3734223395586, 50.84075130522251, 53.14886525273323, 29.338163025677204, 0.24399957270361483, 0.2126184816006571, 0.17949733621207997, 0.22074991167755798, 0.37714098463766277, 42.79453486204147, 63.87510448694229, 58.95760975778103, 56.987046897411346, 52.527211010456085, 46.75475835800171, 42.82666973769665, 44.05437245965004, 44.966407120227814, 47.52725310623646, 47.749244794249535, 48.873760253190994, 49.577972665429115, 49.87942948937416, 51.31337374448776, 48.275805339217186, 44.72508206963539, 40.62782272696495, 40.68152904510498, 40.37282221019268, 39.75442059338093, 39.16269734501839, 38.64890791475773, 39.344259202480316, 39.72580812871456, 39.54026788473129, 40.34700259566307, 41.42083257436752, 41.12480565905571, 40.370622128248215, 40.04177637398243, 39.526558220386505, 40.13186953961849, 40.265310779213905, 39.13527801632881, 39.25653710961342, 39.38603036105633, 40.37670940160751, 40.29587633907795, 40.85952669382095, 39.52624663710594, 39.924016892910004, 40.77507242560387, 41.86815597116947, 38.87478679418564, 39.64805290102959, 40.389051139354706, 39.212577268481255, 38.38594302535057, 36.18508592247963, 36.52767553925514, 39.36016894876957, 45.69262035191059, 49.47409763932228, 50.28396338224411, 50.857390612363815, 55.219484344124794, 52.6021695882082, 50.906559973955154, 49.69421602785587, 52.91615813970566, 51.10255725681782, 48.40969875454903, 44.54907551407814, 39.31915394961834, 38.370880633592606, 37.80762165784836, 38.06170642375946, 37.015641555190086, 38.10141049325466, 37.939599975943565, 37.54420839250088, 38.08458499610424, 37.92672246694565, 39.667241871356964, 36.97311043739319, 39.43203829228878, 38.208705335855484, 38.79112288355827, 38.8317047059536, 37.407347336411476, 37.866883277893066, 38.637500926852226, 35.83420895040035, 37.265614941716194, 37.75635860860348, 38.359800428152084, 38.48448693752289, 36.21831513941288, 37.25964926183224, 37.63411156833172, 36.452644765377045, 40.79683765769005, 44.52729508280754, 43.8718568533659, 43.60360264778137, 44.300321862101555, 42.67196863889694, 42.18771882355213, 43.44911053776741, 42.54815988242626, 42.687012031674385, 43.380239233374596, 41.8742660433054, 40.34839332103729, 41.15744970738888, 40.557150319218636, 39.40827436745167, 38.71950812637806, 39.9431336671114, 40.1636016368866, 44.64324586093426, 50.184108540415764, 52.22264215350151, 51.38493910431862, 52.384536266326904, 11.675287708640099, 0.4374410177115351, 0.8684237475972623, 0.3948232170660049, 0.2762880135560408, 0.12614686304004863, 15.242767129093409, 55.661784410476685, 47.1959412842989, 35.33111974596977, 23.78262933343649, 38.30156095325947, 32.72433042526245, 0.6853961187880486, 0.05067085621703882, 0.0982453535834793, 0.09830823575612158, 0.017707804981910158, 0.006197253151185578, 0.023516043802374043, 0.03508750276523642, 0.041953426334657706, 0.04370203758298885, 0.08280888228910044, 0.07388614467345178, 0.08667660717037506, 0.018447277216182556, 0.06252814593608491, 0.05191902986553032, 0.015843292530917097, 0.014522967285302002, 0.011422144416428637, 0.022346471014316194, 0.043132788050570525, 0.026691578677855432, 0.06687886052532122, 0.025139141180261504, 0.03302086639450863, 0.09059964431799017, 0.05653741114656441, 0.044103635955252685, 0.04861266177613288, 0.05015580201870762, 0.05024872261856217, 0.07225711568025872, 0.1681733797886409, 5.524563929066062, 50.617422088980675, 51.55200853943825, 30.23755196481943, 39.751209765672684, 52.40128956735134, 55.429799258708954, 58.638335689902306, 32.968957498669624, 0.11701786032062955, 0.6808168301358819, 0.5794851144310087, 0.19058122270507738, 0.6139473058283329, 46.982031762599945, 64.6440540254116, 60.604179203510284, 57.96027347445488, 54.501296281814575, 48.01678463816643, 44.872510358691216, 45.148960724473, 47.68317013978958, 48.508010879158974, 51.03766433894634, 51.549561470746994, 51.99915714561939, 51.183599308133125, 53.423902094364166, 50.81288740038872, 47.681939005851746, 43.308210298419, 43.12780357897282, 41.84919498860836, 41.799607649445534, 41.060273721814156, 41.60591684281826, 41.64358802139759, 42.31146298348904, 41.57784014940262, 41.69402651488781, 41.31135664880276, 43.097523003816605, 42.687217220664024, 42.79497183859348, 41.81789226830006, 41.921805292367935, 42.31294870376587, 40.713793113827705, 39.978008195757866, 41.671444326639175, 41.85050591826439, 42.68790878355503, 43.791023790836334, 41.49775184690952, 41.84357509016991, 42.73741252720356, 42.846398279070854, 39.789899289608, 42.33323961496353, 41.403957679867744, 43.05312618613243, 41.61327324807644, 39.199209585785866, 38.25335294008255, 41.84593476355076, 47.43035450577736, 51.65253594517708, 52.41172380745411, 52.663452699780464, 57.424259036779404, 54.55137759447098, 52.61052533984184, 52.427618354558945, 55.014477744698524, 53.894172459840775, 50.33188261091709, 47.270500883460045, 41.34077087044716, 39.552248641848564, 39.2955382168293, 39.6161650121212, 39.13203679025173, 40.134153217077255, 41.3932840526104, 40.43967202305794, 40.04119120538235, 40.91215007007122, 40.535753667354584, 38.9591346681118, 39.916531294584274, 41.01687625050545, 40.07376305758953, 39.28497478365898, 40.323288068175316, 40.41086956858635, 39.939075484871864, 37.149618566036224, 39.218656942248344, 39.577521085739136, 40.21089389920235, 39.57027107477188, 38.318743631243706, 39.31055121123791, 38.31861823797226, 38.64808335900307, 42.57894963026047, 45.223372131586075, 47.10286147892475, 45.491132363677025, 45.167169347405434, 45.422128066420555, 44.97947081923485, 45.02417542040348, 44.253664165735245, 44.56251159310341, 45.01732058823109, 44.552955105900764, 41.682505533099174, 44.99847359955311, 42.67813190817833, 42.18534775078297, 40.72637803852558, 42.51814529299736, 41.62480942904949, 47.27519743144512, 51.48444056510925, 54.05572459101677, 51.68277472257614, 54.11673791706562, 12.085269559174776, 0.44164724356960505, 1.2121312762610614, 0.7197644433472306, 0.269398923846893, 0.1592799273203127, 16.584624275565147, 62.628566175699234, 51.329712867736816, 46.54762767255306, 21.33386593312025, 37.592116221785545, 40.82316644489765, 1.2430352554656565, 0.11834441960672848, 0.04860959299548995, 0.04691411209932994, 0.012563186264742399, 0.029681344713026192, 0.07442809801432304, 0.05201613988901954, 0.09942576172761619, 0.008621254964964464, 0.06535252250614576, 0.04271096986485645, 0.05667184006597381, 0.020959513894922566, 0.04291140168788843, 0.18570598040241748, 0.12224139994941652, 0.12662528111832216, 0.10515265559661202, 0.1322957791853696, 0.15133535518543795, 0.17867393820779398, 0.18305200093891472, 0.192767545231618, 0.1224786126113031, 0.21922984480625018, 0.12474488670704886, 0.1505198239465244, 0.17038794845575467, 0.1819246044033207, 0.1545703917508945, 0.14778039359953254, 0.25126421882305294, 6.394651215523481, 59.90328401327133, 61.753811314702034, 39.33176167309284, 41.715871542692184, 56.55985862016678, 59.8690402507782, 63.57329048216343, 37.480140030384064, 0.15503049362450838, 1.3101128186099231, 1.339831380173564, 0.6489553023129702, 0.705582951195538, 46.76928497850895, 65.70613503456116, 63.658618703484535, 60.90731553733349, 56.295164823532104, 50.39305932819843, 47.47051455080509, 48.2123601436615, 49.68319661915302, 53.14371272921562, 52.897075563669205, 52.7976842969656, 53.38783822953701, 53.145137652754784, 55.93205250799656, 54.38176989555359, 49.445743560791016, 45.139480233192444, 46.11772634088993, 44.10625107586384, 44.032922610640526, 43.97018797695637, 43.56982246041298, 43.621184304356575, 44.74466621875763, 44.07907493412495, 45.26364617049694, 45.20169049501419, 46.64360672235489, 43.90137366950512, 45.32413512468338, 43.754245564341545, 46.01388931274414, 44.567489326000214, 42.96119771897793, 43.2142299413681, 43.2577034085989, 44.21536602079868, 46.75352722406387, 46.00811742246151, 43.96869085729122, 44.47393074631691, 45.127792060375214, 46.004678606987, 41.71616032719612, 43.68741475045681, 43.2786250859499, 44.93472062051296, 43.77780809998512, 40.509865656495094, 40.830929428339005, 43.808913230895996, 48.81174758076668, 53.07039566338062, 52.90417358279228, 54.99537996947765, 58.78035306930542, 56.15573510527611, 54.55719508230686, 53.50345082581043, 56.052274256944656, 54.589003175497055, 50.58310993015766, 47.63750419020653, 45.078622698783875, 41.74749344587326, 41.83289386332035, 43.03090877830982, 43.10807503759861, 42.09946855902672, 44.07826937735081, 43.05363915860653, 42.39086352288723, 42.402813881635666, 42.98514403402805, 39.05369259417057, 42.05969989299774, 43.122639656066895, 43.929264172911644, 43.31427477300167, 41.68467901647091, 41.380573734641075, 43.43510828912258, 38.64224687218666, 41.344411075115204, 41.156537756323814, 43.433379381895065, 42.17710219323635, 41.39084458351135, 41.48522771894932, 40.28540790081024, 39.855571165680885, 44.989783465862274, 46.99590481817722, 48.87782983481884, 46.21560148894787, 48.170896768569946, 47.620317712426186, 46.93711817264557, 46.50282047688961, 45.86013436317444, 46.190712824463844, 48.28998237848282, 45.53082883358002, 44.709016531705856, 46.44671268761158, 44.57981586456299, 44.02325592935085, 43.9727908372879, 45.062321573495865, 44.064958691596985, 49.1301628947258, 55.75109101831913, 56.031075194478035, 53.428085669875145, 53.51793184876442, 15.390639994293451, 0.5313219269737601, 3.383347950875759, 1.2304490245878696, 0.748787404736504, 0.2844769007060677, 20.17185978591442, 67.29178994894028, 55.79299136996269, 50.75398676097393, 32.14558728039265, 49.11571986973286, 49.73399989306927, 1.882056703325361, 0.2835772396065295, 0.2729028998874128, 0.19516162457875907, 0.08427875029155985, 0.14737780817085877, 0.1792375251534395, 0.10852950916159898, 0.11838641774374992, 0.11545723507879302, 0.23961005121236667, 0.21548762451857328, 0.17018976534018293, 0.15328960813349113, 0.329890341963619], [0.044034824022674, 0.037611825318890624, 0.05224158208875451, 0.06950868308194913, 0.04901937354588881, 0.07695036852965131, 0.03124346723780036, 0.023442866186087485, 0.03297506846138276, 0.01068372974259546, 0.013698062721232418, 0.0164425582261174, 0.04309861957153771, 0.08908089104807004, 0.10535837893257849, 0.06850396355730481, 0.11671890839352272, 0.05261668949970044, 0.3880089655285701, 18.088897056877613, 50.87550424039364, 31.071527414023876, 28.776574060320854, 34.75688315927982, 44.39077600836754, 52.72518418729305, 38.91902022063732, 0.8529710455331951, 0.6703539728187025, 0.08058380481088534, 0.4041905456688255, 0.2542901923879981, 9.586130362004042, 67.45195895433426, 56.776849776506424, 60.08507385849953, 54.091024696826935, 56.94294646382332, 48.245292976498604, 44.38804395496845, 45.07834531366825, 46.877955347299576, 47.949999421834946, 49.84978727996349, 49.526633620262146, 51.11365266144276, 49.11695100367069, 48.6412089318037, 43.291829377412796, 41.55039802193642, 38.994271382689476, 39.819796085357666, 39.095980525016785, 40.70422902703285, 40.85496313869953, 39.317873418331146, 37.87449046969414, 38.988773077726364, 38.90523076057434, 40.68095527589321, 40.15193246304989, 40.49985319375992, 39.43595588207245, 40.183314979076385, 38.187783658504486, 40.53142569959164, 39.4538339227438, 40.49893744289875, 41.50118686258793, 40.694687739014626, 39.12864737212658, 39.889871925115585, 40.07068522274494, 40.20169839262962, 41.89076475799084, 39.9887540191412, 39.01220262050629, 40.226233676075935, 38.59480641782284, 39.165285006165504, 37.25373677909374, 37.39603154361248, 37.48544454574585, 39.53561693429947, 41.127347722649574, 45.558335557579994, 49.01191703975201, 50.078728795051575, 54.679043143987656, 54.35858353972435, 55.051951333880424, 53.2330497354269, 56.73536740243435, 53.31195630133152, 48.47862705588341, 42.19241537153721, 40.48768624663353, 37.495893985033035, 37.699536457657814, 36.95289172232151, 36.93502888083458, 36.27144008874893, 39.63009126484394, 38.91935080289841, 39.60840962827206, 37.883492186665535, 39.559650644659996, 38.88609878718853, 37.33266994357109, 38.64380478858948, 37.04198554158211, 37.707470431923866, 38.96234169602394, 36.85164235532284, 36.695280745625496, 36.885289549827576, 37.189125046133995, 38.59908878803253, 38.31986837089062, 36.64102725684643, 35.77065356075764, 36.19885638356209, 37.13788099586964, 39.402046501636505, 46.076407358050346, 47.38796018064022, 47.487864419817924, 46.96193844079971, 45.90887434780598, 43.97316321730614, 45.69670893251896, 44.577402994036674, 44.52467322349548, 41.99610270559788, 41.19455851614475, 41.29331521689892, 41.7865439504385, 39.63147059082985, 40.528055280447006, 41.197621151804924, 40.49373172223568, 41.568705439567566, 42.687646597623825, 47.55350969731808, 52.75236412882805, 50.0437630712986, 54.863245859742165, 36.953332498669624, 2.7747944556176662, 0.672693281667307, 0.4838696279330179, 0.2292508867685683, 0.2562445937655866, 0.21601284242933616, 22.766696847975254, 58.58093976974487, 40.30857525765896, 30.835187695920467, 27.019288055598736, 46.14907465875149, 18.056836277246475, 0.13589029724244028, 0.05936668589129113, 0.036932485600118525, 0.03155972604872659, 0.05646571225952357, 0.05076250403362792, 0.01631064704270102, 0.07835505370167084, 0.058709985387395136, 0.02976449493871769, 0.046958666935097426, 0.028627485735341907, 0.02719902400713181, 0.025728595683176536, 0.014985440320742782, 0.014355155635712435, 0.08107982663204893, 0.036381960453581996, 0.054200287922867574, 0.043060076131951064, 0.024752740137046203, 0.0560847270389786, 0.0403695570275886, 0.011491138175188098, 0.02229015684861224, 0.018237455369671807, 0.051373421447351575, 0.045690492406720296, 0.054875007772352546, 0.011365309819666436, 0.014011279654368991, 0.027811833897430915, 0.015802572743268684, 0.5934066174086183, 26.526281610131264, 60.044400840997696, 30.32926194369793, 33.35360325872898, 44.94236961007118, 50.51212593913078, 57.85872772336006, 38.26727159321308, 0.6903615617193282, 0.8424222772009671, 0.3366340894717723, 0.5821918160654604, 0.3119149018311873, 12.014856487512589, 67.95649588108063, 58.57122749090195, 62.667498886585236, 55.168574675917625, 59.044834077358246, 49.73104365170002, 45.698411241173744, 47.12934225797653, 49.73498784005642, 50.194356590509415, 53.781383112072945, 51.240083277225494, 52.2954386472702, 52.29907505214214, 49.12604011595249, 46.387736052274704, 43.231484815478325, 41.237325221300125, 40.618779212236404, 40.87965041399002, 43.92900958657265, 41.52914196252823, 42.04432591795921, 40.34606784582138, 40.8484198898077, 42.55311481654644, 41.95318020880222, 43.076187148690224, 42.53254272043705, 42.475503981113434, 42.204399928450584, 41.56480684876442, 42.01283320784569, 41.3615595549345, 43.43738816678524, 42.837309166789055, 40.926851481199265, 41.996452286839485, 42.79896542429924, 41.69550463557243, 43.001764342188835, 42.22943298518658, 42.52457834780216, 41.1368890106678, 44.459031745791435, 40.64210616052151, 41.740577816963196, 39.4444864243269, 38.857102543115616, 39.551032707095146, 41.23693764209747, 42.09471881389618, 48.74749682843685, 50.5991792678833, 52.1981942653656, 56.26342132687569, 56.23645417392254, 55.94267673790455, 55.55088736116886, 57.9505155980587, 53.56572948396206, 49.79351609945297, 43.60369764268398, 41.03735335171223, 40.62189884483814, 38.88765290379524, 39.3848068267107, 39.1979556530714, 40.27245819568634, 41.017970591783524, 39.88880418241024, 40.892543122172356, 40.087769106030464, 40.438562482595444, 40.574359595775604, 40.209871754050255, 41.3613011687994, 39.55803193151951, 41.15089885890484, 39.46278624236584, 38.91662634909153, 38.893614783883095, 39.48289856314659, 39.40656825900078, 40.366909727454185, 38.87685388326645, 37.76429258286953, 37.73205891251564, 38.26382897794247, 39.64633159339428, 40.082411393523216, 47.93200358748436, 49.49003778398037, 48.897797763347626, 49.3146163970232, 47.68947780132294, 46.83734692633152, 47.13399700820446, 45.38905844092369, 44.081784188747406, 44.35937449336052, 42.68589109182358, 43.645727187395096, 43.900469318032265, 41.569879576563835, 41.775110363960266, 42.807279378175735, 42.31327548623085, 43.06633047759533, 44.27880361676216, 52.26918585598469, 53.722839653491974, 53.06881494820118, 55.55639706552029, 39.055368304252625, 2.9513612436130643, 0.9752015210688114, 2.098023220896721, 1.2398367770947516, 0.5279506172519177, 0.2316113468259573, 25.055792815983295, 64.22150909900665, 48.49633030593395, 43.05218763649464, 26.417843028903008, 49.0479277074337, 23.729143403470516, 0.3159074782161042, 0.04979907018423546, 0.06368470145389438, 0.05019369978981558, 0.07825065578799695, 0.005113623383294907, 0.032080951204989105, 0.107235938339727, 0.06327560739009641, 0.06900782987941056, 0.036704965386888944, 0.049448962017777376, 0.028444999043131247, 0.012602838287421037, 0.022853897789900657, 0.1370996268815361, 0.21315904712537304, 0.1155547755479347, 0.1232310984050855, 0.10511732936720364, 0.17464818782173097, 0.10962086700601503, 0.10276170069118962, 0.08904890448320657, 0.1530435713357292, 0.05711824931495357, 0.15177611669059843, 0.26192445773631334, 0.140563556633424, 0.1538272644393146, 0.09419562440598384, 0.15903562714811414, 0.15402255317894742, 0.7219157216604799, 32.2072047740221, 68.25865566730499, 40.228600949048996, 41.76892049610615, 46.88566893339157, 54.77248772978783, 63.34879472851753, 50.09691841900349, 0.8131835586391389, 1.3482913887128234, 1.051799354609102, 1.2442596210166812, 0.31508360523730516, 12.214043699204922, 69.73852425813675, 58.80474396049976, 64.58456441760063, 59.6043236553669, 62.91420824825764, 52.74562329053879, 48.27386364340782, 49.3147873878479, 52.909029722213745, 52.63028807938099, 56.524919494986534, 55.209331288933754, 56.224222630262375, 54.2996297031641, 53.2718076556921, 48.83443236351013, 45.36136172711849, 44.248656034469604, 43.18533629179001, 42.125903740525246, 46.44439861178398, 43.783272206783295, 44.39689368009567, 41.93121738731861, 44.44464951753616, 44.592237398028374, 44.82089772820473, 44.845395013689995, 43.44654567539692, 45.370625630021095, 45.832734033465385, 43.38022783398628, 44.389221891760826, 43.492641001939774, 43.9342837035656, 45.114621967077255, 44.32636946439743, 44.334159046411514, 45.30860535800457, 45.735637843608856, 45.34021586179733, 46.502748280763626, 45.06230637431145, 43.52966621518135, 45.90022221207619, 43.62517029047012, 43.442434296011925, 41.01398080587387, 41.69557683169842, 41.59457065165043, 44.398618787527084, 44.16371539235115, 49.671432450413704, 52.645377069711685, 54.058593437075615, 59.0343314409256, 57.97087870538235, 57.61053264141083, 57.58746787905693, 62.140501365065575, 57.05205000936985, 52.52750739455223, 46.94652646780014, 45.13905845582485, 42.534476816654205, 42.176608219742775, 42.01775014400482, 41.48588128387928, 42.405701726675034, 44.88303579390049, 42.738446071743965, 44.462949335575104, 41.75577700138092, 42.36157849431038, 41.25579223036766, 42.034457847476006, 44.3086776137352, 41.752402782440186, 42.3675973713398, 43.502752259373665, 41.51551589369774, 40.46849347651005, 41.428964138031006, 41.57123610377312, 40.828151777386665, 40.55484004318714, 38.81632313132286, 39.90338779985905, 40.14420747756958, 40.97966484725475, 42.47378647327423, 49.92476865649223, 51.33410923182964, 51.649693697690964, 51.92894071340561, 50.91067135334015, 50.845736637711525, 49.94945973157883, 46.921451613307, 47.10228770971298, 45.70551685988903, 45.78690089285374, 44.061675667762756, 46.38838581740856, 43.93203042447567, 45.407574847340584, 45.64834512770176, 43.605183362960815, 45.105548053979874, 47.11669273674488, 53.62271502614021, 56.40866853296757, 53.49360555410385, 56.805397644639015, 40.450835824012756, 3.618440148420632, 1.613947602454573, 2.3696478456258774, 1.258927071467042, 0.9496057976502925, 0.4651957971509546, 29.538839757442474, 68.4930270910263, 50.849973410367966, 44.59927462041378, 33.90681937336922, 58.512657433748245, 29.703361429274082, 0.39715997292660177, 0.15743773867143318, 0.12420599101460539, 0.09221560409059748, 0.23214849847136065, 0.1324862736510113, 0.17908168898429722, 0.2228822058532387, 0.12631579069420695, 0.11671432192088105, 0.13669477048097178, 0.13203313312260434, 0.1416266238084063, 0.1531284730299376, 0.2068673714529723], [0.01755693378072465, 0.030612949703936465, 0.013056569750915514, 0.05530886359338183, 0.03647678837296553, 0.05332977838406805, 0.01985279730433831, 0.06950169947231188, 0.09375296300277114, 0.05656077766616363, 0.09478290070546791, 0.06708951172186062, 0.01839218573877588, 0.06736217677826062, 0.044858982728328556, 0.027997636134386994, 0.06296144143561833, 0.04821750524570234, 0.11492518940940499, 2.2587811946868896, 37.215776816010475, 42.095839753746986, 31.07631705701351, 38.61112654209137, 40.36347471177578, 49.51744191348553, 55.09629875421524, 4.229147415608168, 0.7378749246709049, 0.8539000363089144, 0.17135097412392497, 0.1594539312645793, 0.2271722350269556, 33.045344799757004, 62.7375291287899, 59.719769060611725, 58.10015916824341, 54.3911287933588, 54.52255614101887, 44.563279151916504, 45.30174672603607, 48.2536905258894, 49.34058040380478, 47.90343292057514, 47.47850552201271, 49.23677757382393, 47.156184017658234, 44.789443016052246, 43.16249191761017, 41.92813955247402, 40.936164781451225, 39.42541904747486, 39.578334242105484, 39.69435341656208, 40.9545785933733, 39.009877145290375, 39.72860477864742, 40.34050114452839, 40.78969784080982, 41.498473808169365, 41.50843687355518, 40.94688020646572, 41.235246732831, 40.39104223251343, 39.689375683665276, 39.6681272238493, 41.34722292423248, 40.10620191693306, 40.364447459578514, 41.989130079746246, 38.88614438474178, 41.69827088713646, 41.030783504247665, 41.1571229249239, 40.9672699123621, 40.11952020227909, 37.77188457548618, 40.57837978005409, 39.945911318063736, 38.86773817241192, 38.28472785651684, 36.093567833304405, 38.46819341182709, 38.76197464764118, 39.359959959983826, 44.84636016190052, 48.73001776635647, 49.67812769114971, 52.11451895534992, 53.12818296253681, 55.87194733321667, 53.512311950325966, 52.93554849922657, 49.88283410668373, 44.80653069913387, 40.938060879707336, 40.39720170199871, 39.42196883261204, 38.997922986745834, 38.32087151706219, 38.63161884248257, 38.930111825466156, 38.88825327157974, 38.404117450118065, 38.830416575074196, 39.24090474843979, 37.4605368822813, 39.01960462331772, 37.54890874028206, 39.67305935919285, 38.88763390481472, 38.24599273502827, 36.95214316248894, 38.061847016215324, 36.61494545638561, 37.27268636226654, 37.658745646476746, 36.51181519031525, 36.48168660700321, 36.515725180506706, 36.099449917674065, 38.228274285793304, 35.43264649808407, 38.98287579417229, 47.29847118258476, 50.32529756426811, 51.3730875402689, 49.19123321771622, 50.78806333243847, 49.67671036720276, 47.131686732172966, 46.647007539868355, 47.32392981648445, 46.18777558207512, 45.37976033985615, 45.643135607242584, 42.80696399509907, 41.694296300411224, 41.65492661297321, 39.50773023068905, 40.23069083690643, 41.42234489321709, 44.51390840113163, 49.95452865958214, 50.291015803813934, 50.89173696935177, 53.54915477335453, 22.441576793789864, 0.18609649850986898, 0.5243576131761074, 0.2927321655442938, 0.3145154466619715, 0.2096135405008681, 0.4936091584386304, 43.0958890914917, 51.55619591474533, 39.467885568737984, 23.06101005524397, 27.102627083659172, 46.11540086567402, 4.259566683322191, 0.0699954577430617, 0.14068587741348892, 0.04983304941561073, 0.05576695053605363, 0.04403151775477454, 0.04660137106839102, 0.03457350241660606, 0.038516529311891645, 0.001595139747223584, 0.030083425481279846, 0.01826478310249513, 0.01698240386758698, 0.0046412380379479146, 0.04453834153537173, 0.02779604841634864, 0.06572622354724444, 0.05838151824718807, 0.048549100538366474, 0.08914399586501531, 0.054936116212047637, 0.0453402320999885, 0.058759089588420466, 0.0152920521395572, 0.030145890195854008, 0.0745880308386404, 0.051412001994322054, 0.05008034044294618, 0.07230177812743932, 0.02752520904323319, 0.04628052207408473, 0.04373890005808789, 0.02054628977930406, 0.024351616739295423, 0.06714859409839846, 4.716277476400137, 49.742435440421104, 41.505043655633926, 32.7959755808115, 48.286171182990074, 45.76742693781853, 55.52935391664505, 58.082687705755234, 4.087403621524572, 0.7830418541561812, 1.4052043785341084, 0.07940484385471791, 0.1483135821763426, 0.17781062750145793, 36.84438854455948, 63.32367807626724, 61.712154150009155, 61.513132229447365, 56.64049029350281, 54.72665458917618, 49.47635091841221, 46.7713862657547, 49.25229974091053, 51.72294236719608, 50.76138876378536, 51.79125130176544, 51.94971039891243, 48.18594016134739, 47.05559961497784, 48.055808544158936, 42.65811838209629, 42.44362369179726, 42.42063872516155, 41.42735302448273, 41.38103350996971, 41.560900658369064, 41.37900061905384, 40.85221588611603, 41.18938319385052, 42.03965596854687, 41.713827252388, 41.75026349723339, 43.3979918807745, 42.08182990550995, 42.7602569013834, 40.36362290382385, 42.63509161770344, 41.800766587257385, 41.83301545679569, 42.81031921505928, 42.948924377560616, 41.80452078580856, 44.01484698057175, 42.360263764858246, 42.72345207631588, 42.178143337368965, 41.730705946683884, 40.565304681658745, 41.8746992200613, 43.18070814013481, 41.53097726404667, 40.33081166446209, 38.68648409843445, 39.342670887708664, 40.14124743640423, 42.63834424316883, 46.56766399741173, 50.335564613342285, 52.98519663512707, 54.482852071523666, 54.34624560177326, 56.706678941845894, 55.45606344938278, 54.51502114534378, 51.815418004989624, 47.959723100066185, 44.05001789331436, 42.12708167731762, 41.0369011759758, 41.18279814720154, 40.49049809575081, 39.96063932776451, 41.39501675963402, 39.90687221288681, 41.23948730528355, 40.889602079987526, 40.8383010327816, 39.86166223883629, 40.82502454519272, 38.67297202348709, 41.25519186258316, 40.670969411730766, 39.287919625639915, 39.95194539427757, 39.33909147977829, 37.294763177633286, 39.41759146749973, 39.083494395017624, 39.55850690603256, 39.18770380318165, 37.44323641061783, 39.355149418115616, 40.135114565491676, 38.097443506121635, 40.56742496788502, 48.58714163303375, 51.69713035225868, 51.780448481440544, 50.504891127347946, 53.3705947548151, 50.81746235489845, 48.43142218887806, 49.447483867406845, 49.67288017272949, 47.62514345347881, 48.29932227730751, 45.98745413124561, 44.78870585560799, 42.0554631203413, 43.31786558032036, 40.81970863044262, 43.431954458355904, 44.270968437194824, 47.472129464149475, 52.026177495718, 52.63325572013855, 51.4402299374342, 54.71674092113972, 23.887123726308346, 0.2861536497948691, 1.947886033449322, 3.6068293964490294, 0.32257736718747765, 0.14287982921814546, 0.12325917385169305, 49.563943818211555, 55.098301246762276, 47.10932493209839, 27.87701603025198, 25.98471187055111, 54.288621693849564, 6.039954498410225, 0.2749267959734425, 0.07696546381339431, 0.11634819078608416, 0.08794439578196034, 0.0332091269956436, 0.03514984688081313, 0.04567233205307275, 0.019003231172973756, 0.02624654796818504, 0.05183166424103547, 0.02069384543574415, 0.018344845993851777, 0.08493248591548763, 0.07917199502117, 0.05121505084389355, 0.15190582926152274, 0.10565704142209142, 0.06842798247816972, 0.10675318611902185, 0.12343531518126838, 0.19398489006562158, 0.13686107093235478, 0.08810695580905303, 0.2024396590422839, 0.15376896131783724, 0.1704508380498737, 0.19278992840554565, 0.11298304831143469, 0.10098401951836422, 0.10022069094702601, 0.19957706186687574, 0.16001590032828972, 0.15281645930372179, 0.17267812712816522, 4.6746758837252855, 57.296437695622444, 54.539738819003105, 41.79129369556904, 50.96719332039356, 52.539241164922714, 58.859514221549034, 65.75656592845917, 5.017216578125954, 0.8780970785301179, 2.619207054376602, 0.3972545522265136, 0.5271564004942775, 0.40111066249664873, 37.537551149725914, 61.99733264744282, 63.78205507993698, 61.82414174079895, 57.63521231710911, 59.16081145405769, 49.984547048807144, 48.82529005408287, 51.431885585188866, 54.653489515185356, 52.7051592618227, 53.268596827983856, 54.09132108092308, 51.737856566905975, 48.15110743045807, 48.741401955485344, 45.8785405755043, 43.70993234217167, 42.21363343298435, 44.414148554205894, 42.61089451611042, 45.17499312758446, 44.59713913500309, 43.24815072119236, 44.14241373538971, 46.180818155407906, 45.90349763631821, 45.066558346152306, 46.652308255434036, 45.67052833735943, 44.23700965940952, 43.719036653637886, 44.58518497645855, 43.48135180771351, 43.44775401055813, 45.75710669159889, 46.6275829821825, 44.14425663650036, 46.58162824809551, 44.558400213718414, 44.49917659163475, 44.59315314888954, 44.74723868072033, 43.83710391819477, 44.39506217837334, 44.87974517047405, 43.301963433623314, 42.472958117723465, 39.93740737438202, 42.87291705608368, 42.60509982705116, 43.71104188263416, 49.1532314568758, 52.831236496567726, 53.902079835534096, 57.09677740931511, 54.89991009235382, 60.122330859303474, 57.55653373897076, 56.25806741416454, 53.72647985816002, 49.46526311337948, 45.658726170659065, 44.47230823338032, 42.9599741846323, 42.85946197807789, 42.42386855185032, 44.27504941821098, 45.15431843698025, 42.60219298303127, 42.4597842246294, 43.63291807472706, 43.86128582060337, 42.119086906313896, 44.15997639298439, 40.46942062675953, 45.86058273911476, 43.494141921401024, 41.44462689757347, 41.732370257377625, 42.429841831326485, 39.594498574733734, 41.13567687571049, 41.244503036141396, 41.014892756938934, 41.29946328699589, 39.44100961089134, 40.72768896818161, 43.804117888212204, 41.03492148220539, 43.04424986243248, 51.78940460085869, 53.796380907297134, 53.79357285797596, 53.15520331263542, 54.15430270135403, 53.16681928932667, 50.12491911649704, 52.19567880034447, 51.40762768685818, 50.042680129408836, 49.99972343444824, 48.54145668447018, 46.65289342403412, 43.857258036732674, 45.89581444859505, 43.771549835801125, 43.67030426859856, 47.033500000834465, 49.025592505931854, 56.049477607011795, 54.51263107359409, 54.07467037439346, 54.95664484798908, 26.51213876903057, 0.36747973586898297, 1.5444845985621214, 3.6389222368597984, 0.4394071747083217, 0.4656657250598073, 1.3299181871116161, 55.597548857331276, 59.91225913167, 50.65427251160145, 32.71925389766693, 34.595190435647964, 62.79046408832073, 8.643670734018087, 0.6235902977641672, 0.3250146098434925, 0.15894796466454864, 0.22586707927985117, 0.14176213997416198, 0.107519535231404, 0.1376709618489258, 0.09360177267808467, 0.05515931341506075, 0.11825278663309291, 0.12528592720627785, 0.11020374979125336, 0.1953276281710714, 0.14207994245225564, 0.1830591997713782], [0.0733461431809701, 0.046007968339836225, 0.013298113772179931, 0.05037720322434325, 0.015828590585442726, 0.050744447580655105, 0.020405923678481486, 0.04504862372414209, 0.025207459584635217, 0.014879484824632527, 0.08348034782102332, 0.018891706786234863, 0.029530030078603886, 0.04196090347249992, 0.05978250010230113, 0.023897776736703236, 0.047147317163762636, 0.07656332367332652, 0.04270155943231657, 0.11811332966317423, 13.439822774380445, 50.05931943655014, 30.638897828757763, 33.47665585577488, 43.56980346143246, 39.747934341430664, 55.550530180335045, 13.776167426258326, 0.1394148456165567, 1.4025448774918914, 0.14625375129980966, 0.03672802762594074, 0.08890587778296322, 3.5464938590303063, 50.657304748892784, 56.359411776065826, 57.88053475320339, 57.57563531398773, 56.86610698699951, 48.08454640209675, 44.05530720949173, 46.541456803679466, 46.1984758079052, 46.27692639827728, 47.51656427979469, 45.574423894286156, 46.967007368803024, 44.85730737447739, 44.392960891127586, 41.84099122881889, 42.0288797467947, 41.27273552119732, 39.043767526745796, 40.23279972374439, 40.210206136107445, 39.820027872920036, 39.42524045705795, 39.31741364300251, 41.20774760842323, 39.284849390387535, 41.37670934200287, 40.58040887117386, 39.639681950211525, 39.902836829423904, 40.1614585518837, 40.16165994107723, 42.15824380517006, 40.091166123747826, 41.01691424846649, 41.96903295814991, 40.603283643722534, 39.75037761032581, 40.68324655294418, 39.434785544872284, 42.50565156340599, 40.2851153165102, 39.85633112490177, 40.11991538107395, 40.591519474983215, 37.72138528525829, 38.70121970772743, 37.3458856344223, 38.54406014084816, 39.883020892739296, 41.87760226428509, 42.698666006326675, 47.32094317674637, 51.40697032213211, 56.402208879590034, 54.48626048862934, 55.75479581952095, 54.6525813639164, 53.16210754215717, 49.03151638805866, 44.7360634803772, 43.829580321908, 42.87960849702358, 42.98223719000816, 42.25210256874561, 41.13630384206772, 40.85365600883961, 37.30718091130257, 39.22611594200134, 38.730987310409546, 37.704768776893616, 38.07778716087341, 37.6910363137722, 37.52300173044205, 37.66546368598938, 38.90581592917442, 37.6586202532053, 37.31228023767471, 38.73173967003822, 38.50599378347397, 37.018282413482666, 37.38939709961414, 37.257118597626686, 38.43241833150387, 37.67028942704201, 37.66482152044773, 35.59050142765045, 35.83668641746044, 36.01787209510803, 36.75483874976635, 46.01045049726963, 48.584124594926834, 48.925091698765755, 52.497515603899956, 49.03133399784565, 53.572740107774734, 50.77293634414673, 50.9613074362278, 48.10660421848297, 49.1024623811245, 49.11500170826912, 47.54784420132637, 47.90556460618973, 47.174852415919304, 45.863288193941116, 46.923290714621544, 42.41783827543259, 44.8477166891098, 45.16857527196407, 51.11405923962593, 51.159827783703804, 53.763546869158745, 42.45700277388096, 6.939911982044578, 0.7382849464192986, 0.7425541360862553, 4.732354413717985, 1.1350483749993145, 0.17462046118453145, 6.490931399166584, 55.76903745532036, 46.22758224606514, 34.18916702270508, 24.375840201973915, 41.484813541173935, 20.173793882131577, 0.24842991231707856, 0.030636763367510866, 0.006015285034663975, 0.054898348316783085, 0.06679634854663163, 0.021242771254037507, 0.026830369570234325, 0.06598875086638145, 0.043509524475666694, 0.029913293692516163, 0.034473965570214204, 0.0031619120591130923, 0.07774845929816365, 0.0067082394525641575, 0.03860012111545075, 0.057319753541378304, 0.025862868751573842, 0.03386196833162103, 0.052013000604347326, 0.03526174790749792, 0.07496736478060484, 0.005205385768931592, 0.018643922230694443, 0.021427061365102418, 0.05017308663809672, 0.013237765106168808, 0.06407262204447761, 0.03739487328857649, 0.018798402124957647, 0.014560426261596149, 0.055521388712804765, 0.0413425868464401, 0.0897480892308522, 0.061586438459926285, 0.08419611214776523, 0.23811033403035253, 21.613960303366184, 55.40521077811718, 31.407072208821774, 44.29619908332825, 52.8897799551487, 46.69602870941162, 62.53482140600681, 13.469711020588875, 0.19809030258329585, 2.6283534010872245, 0.230015566048678, 0.032565840811003, 0.17089312837924808, 4.981661411002278, 53.842259645462036, 57.80386246740818, 59.12839159369469, 58.559588715434074, 58.196901977062225, 50.238939598202705, 45.632382184267044, 48.58523793518543, 48.669456616044044, 48.9843875169754, 49.716471433639526, 47.30665974318981, 49.40037779510021, 47.22465254366398, 46.50446958839893, 42.63424426317215, 43.97273004055023, 43.58931161463261, 40.99109463393688, 42.04827010631561, 43.227780014276505, 41.10640324652195, 41.21907100081444, 42.27447956800461, 42.57715992629528, 41.542825028300285, 42.48162545263767, 43.08455429971218, 40.32497897744179, 41.32570467889309, 42.012487426400185, 42.36323520541191, 43.37922848761082, 42.37667888402939, 43.785080909729004, 44.22432214021683, 42.12187975645065, 42.432570084929466, 41.20948791503906, 41.218151450157166, 44.07374382019043, 41.59073285758495, 42.400507405400276, 42.308160960674286, 44.22337979078293, 41.85731515288353, 40.332548171281815, 40.81991381943226, 39.69178855419159, 40.747056528925896, 41.954597532749176, 45.13231761753559, 49.52113911509514, 53.72533231973648, 56.88726045191288, 57.10572972893715, 58.408493623137474, 55.838398933410645, 55.27370743453503, 49.55705478787422, 46.30902327597141, 45.96123933792114, 43.81567686796188, 44.12256360054016, 43.94042417407036, 41.57043814659119, 42.12376065552235, 38.76898907124996, 41.58550053834915, 41.97264276444912, 39.67247799038887, 39.54368770122528, 40.66752679646015, 39.686244651675224, 40.40538266301155, 40.75021035969257, 39.84090395271778, 39.04598280787468, 41.157799288630486, 41.09283037483692, 37.3836138099432, 39.17718216776848, 40.1604326069355, 40.42067304253578, 39.199407175183296, 38.66221860051155, 38.426490649580956, 38.77428598701954, 38.6467382311821, 37.73842737078667, 49.356577545404434, 50.17733350396156, 50.50976246595383, 53.95803943276405, 49.901403710246086, 52.9663610458374, 53.534297570586205, 50.96014469861984, 51.49523578584194, 50.40231183171272, 50.154242143034935, 48.845375776290894, 49.531451761722565, 48.900712206959724, 48.228117898106575, 48.27743925154209, 44.87788327038288, 46.08308359980583, 46.96250461041927, 50.90660557150841, 54.0404038131237, 55.371669977903366, 44.80717286467552, 7.5123322661966085, 1.6068157413974404, 1.2104011815972626, 5.207800101488829, 0.9834192332345992, 0.1728852605447173, 6.812613112851977, 62.52439096570015, 51.5785501152277, 46.264227479696274, 21.99079178273678, 41.10681362450123, 27.420244440436363, 0.5770268244668841, 0.0818421904114075, 0.08883164075086825, 0.08816577843390405, 0.025686753397167195, 0.04599692518240772, 0.056626917867106386, 0.0934555844287388, 0.03337762791488785, 0.05019921765779145, 0.011528346676641377, 0.025538117915857583, 0.04620092673576437, 0.047196499290294014, 0.03835401752439793, 0.04680739497416653, 0.2589219360379502, 0.16587264777626842, 0.1319682100438513, 0.20475697063375264, 0.29587332042865455, 0.09716313157696277, 0.13828453986207023, 0.10412511503091082, 0.11613577327807434, 0.1677920197835192, 0.19166722224326804, 0.1567723587504588, 0.10857845380087383, 0.10223496879916638, 0.1619254908291623, 0.09328740634373389, 0.24026475904975086, 0.17457464098697528, 0.21260231762425974, 0.4843153024557978, 25.146233662962914, 64.99483600258827, 40.35557493567467, 43.347446992993355, 55.14667645096779, 51.508546471595764, 68.180972635746, 18.894014954566956, 0.16861301322933286, 3.8803339703008533, 0.3582419565645978, 0.14287496072938666, 0.49390126776415855, 5.518001206219196, 53.885280936956406, 56.24275803565979, 60.236279144883156, 62.13382512331009, 61.09508626163006, 53.20746190845966, 48.427876979112625, 52.65029780566692, 50.87181083858013, 50.67064583301544, 52.486606389284134, 49.861399456858635, 51.11475460231304, 50.987013056874275, 48.121776804327965, 44.21276316046715, 47.82461754977703, 45.10063111782074, 43.28463636338711, 44.558126628398895, 44.99066881835461, 43.21588285267353, 43.06479535996914, 42.27517493069172, 46.527940928936005, 43.6271195858717, 45.97332648932934, 45.831772685050964, 42.11978226900101, 43.53310503065586, 45.47638915479183, 45.09868562221527, 44.947962909936905, 44.043383449316025, 46.83198161423206, 46.79781384766102, 44.7489295899868, 43.68725895881653, 43.86819005012512, 44.86905634403229, 48.28655496239662, 43.456934317946434, 44.50831890106201, 44.69217963516712, 47.96294152736664, 43.24125409126282, 43.31953749060631, 43.02856430411339, 41.240832433104515, 43.60734164714813, 44.24823045730591, 47.30130963027477, 51.999115347862244, 56.1418392509222, 60.23607395589352, 58.042341470718384, 59.84533712267876, 59.693451672792435, 57.58793905377388, 51.46402806043625, 50.35854957997799, 48.006654381752014, 46.20844267308712, 47.312416434288025, 47.16365061700344, 44.00190107524395, 45.414881855249405, 41.043201237916946, 42.94494219124317, 43.655880242586136, 40.835029408335686, 41.38458251953125, 42.61162027716637, 41.23077817261219, 42.466114684939384, 42.077471539378166, 43.59151549637318, 40.541662350296974, 43.98934654891491, 44.05789107084274, 40.40613882243633, 41.39051400125027, 40.304593071341515, 43.0590158700943, 42.287820652127266, 41.23904652893543, 40.16867436468601, 39.98056925833225, 40.237553268671036, 39.45931322872639, 50.29029384255409, 51.634498313069344, 52.73980960249901, 54.41009737551212, 51.24704070389271, 53.979531079530716, 54.701492339372635, 53.86162720620632, 54.349574223160744, 53.86551059782505, 52.92704075574875, 52.30624906718731, 50.915006920695305, 51.021055430173874, 50.1961462944746, 51.367228254675865, 47.57830336689949, 50.05034051835537, 47.79600888490677, 55.80650344491005, 55.517635345458984, 55.689560920000076, 44.79047656059265, 9.599290005862713, 1.1483427928760648, 2.307397685945034, 6.363063035532832, 3.833700972609222, 0.22750507341697812, 9.88600742071867, 67.87874445319176, 54.12715695798397, 47.0186085999012, 32.09662690758705, 51.191024109721184, 34.79788675904274, 0.7613306504208595, 0.21761303156381473, 0.22747454146156088, 0.2553817431908101, 0.1540940220002085, 0.15417638554936275, 0.14878687943564728, 0.19006290676770732, 0.15128083701711148, 0.1764605421340093, 0.10165558152948506, 0.17786202864954248, 0.1616602175636217, 0.24714898027013987, 0.13798009604215622, 0.1008557689783629], [0.03560601908247918, 0.031191657908493653, 0.12104337321943603, 0.024934518078225665, 0.02511586371838348, 0.05336721602361649, 0.0051617126973724226, 0.02555636176111875, 0.0345236078283051, 0.047489280259469524, 0.03638378613686655, 0.033152167161460966, 0.03123813119600527, 0.0931406689051073, 0.1132838407647796, 0.022386177770385984, 0.021178536517254543, 0.1073266584717203, 0.1455620548222214, 0.16456228215247393, 1.600356800481677, 40.73444880545139, 43.352462723851204, 27.610390037298203, 31.787019520998, 36.42249338328838, 57.534468322992325, 31.69278457760811, 0.17602821142645553, 2.0152038149535656, 0.0922804010042455, 0.04476446280023083, 0.03249569301260635, 0.17933044204255566, 17.37590901553631, 61.17414481937885, 55.778981521725655, 59.10854525864124, 53.08202303946018, 53.64342011511326, 46.05485491454601, 45.73753014206886, 44.8956511169672, 46.578337624669075, 46.684370934963226, 45.3793765604496, 45.45865550637245, 46.43792375922203, 43.07152479887009, 40.63323363661766, 40.01472942531109, 42.464511170983315, 39.80308078229427, 40.73655389249325, 40.75439773499966, 41.2283007055521, 40.337180122733116, 39.41358268260956, 41.07339821755886, 42.18442440032959, 40.777781680226326, 42.44999215006828, 41.24963276088238, 41.764930710196495, 39.62747320532799, 40.428428426384926, 39.32341732084751, 40.92177875339985, 41.02587416768074, 42.06802524626255, 39.78193871676922, 41.005271673202515, 41.052168756723404, 39.944239407777786, 40.89198835194111, 41.54428794980049, 40.6448420137167, 40.78555226325989, 39.2602115124464, 38.49828019738197, 39.18100096285343, 39.35130402445793, 39.57624815404415, 39.83002133667469, 41.869770884513855, 46.75271786749363, 50.98260909318924, 54.54397939145565, 53.90228122472763, 55.518159717321396, 54.25703398883343, 56.85384124517441, 54.52986694872379, 46.38552077114582, 44.39866818487644, 46.18185169994831, 46.83933421969414, 44.67527814209461, 44.60696920752525, 43.9082171022892, 42.367243990302086, 38.049045503139496, 36.937392354011536, 37.91512168943882, 38.67824614048004, 38.313332721590996, 38.13172146677971, 38.221115469932556, 38.61783318221569, 38.12377609312534, 39.08464193344116, 37.08784528076649, 37.98815757036209, 38.64411257207394, 39.11352038383484, 37.9029281437397, 37.14163139462471, 36.277299374341965, 36.11761674284935, 35.03490284085274, 34.36795122921467, 35.86901128292084, 35.48745855689049, 36.420555487275124, 40.63585929572582, 49.867615923285484, 48.86351220309734, 50.172120183706284, 49.41656492650509, 46.12900413572788, 49.03004586696625, 49.373710826039314, 51.51716060936451, 51.70806236565113, 50.9032541513443, 50.26793584227562, 51.08057923614979, 48.72790887951851, 48.97237256169319, 49.20936584472656, 47.09903508424759, 47.109647914767265, 48.29465992748737, 50.45740507543087, 53.022495433688164, 54.400673881173134, 27.846853248775005, 1.0612886329181492, 0.7187294738832861, 2.574281352572143, 5.915405256673694, 0.6850895821116865, 0.04228860248986166, 27.282726019620895, 59.052087888121605, 35.638610646128654, 27.055500112473965, 26.250091530382633, 47.854309156537056, 10.021373257040977, 0.20912434643832967, 0.21915956342127174, 0.030644485414086375, 0.08618121617473662, 0.10264671975164674, 0.04569383578200359, 0.06038882362190634, 0.08439651428489015, 0.014870493705529952, 0.016915428750508, 0.025235932080249768, 0.04569359458400868, 0.03527773747919127, 0.024166732910089195, 0.07606727958773263, 0.06146188381535467, 0.026169516750087496, 0.029917933970864397, 0.10898193722823635, 0.04457433940842748, 0.05229618931480218, 0.036483174553723074, 0.034227190335514024, 0.028617969546758104, 0.09061275064595975, 0.057837023050524294, 0.027373272860131692, 0.06610523836570792, 0.04983621838619001, 0.0725318439071998, 0.04226127661240753, 0.018645783165993635, 0.07343114135437645, 0.06525712684378959, 0.13568022492108867, 0.10232594126136974, 3.871694658882916, 50.966269969940186, 41.37773148715496, 28.86603645980358, 48.009648621082306, 40.74380770325661, 62.932960242033005, 30.626987367868423, 0.40329441719222814, 2.8393368422985077, 0.3637323353905231, 0.08678623722516932, 0.17937393189640716, 0.17146812955616042, 19.241985082626343, 60.15749417245388, 55.094794034957886, 62.22431346774101, 57.31568746268749, 54.14867900311947, 47.95819938182831, 47.69466832280159, 47.141486406326294, 48.707401379942894, 48.160219341516495, 47.766112089157104, 49.47596333920956, 49.64329496026039, 46.84400036931038, 44.03745196759701, 42.03043386340141, 44.32740680873394, 42.740813344717026, 42.16653116047382, 43.563636392354965, 43.47373701632023, 43.801211044192314, 41.530639082193375, 41.77543334662914, 43.488362431526184, 41.95292182266712, 43.97069334983826, 42.576563358306885, 41.281171068549156, 42.59006783366203, 43.36942881345749, 41.66260980069637, 44.07331444323063, 42.22371429204941, 43.664627373218536, 41.34879224002361, 43.84554706513882, 41.55429281294346, 41.82609982788563, 42.33846813440323, 42.58505970239639, 41.54233105480671, 42.138697654008865, 39.620747566223145, 40.16199432313442, 41.10948108136654, 40.74141763150692, 41.68793924152851, 41.47434890270233, 43.56348060071468, 48.24298270046711, 52.704091519117355, 55.82133784890175, 57.20393165946007, 54.92001861333847, 55.27886375784874, 58.708514124155045, 55.12531779706478, 50.04931457340717, 45.71528233587742, 47.23755665123463, 48.65737706422806, 46.26970678567886, 47.31155388057232, 45.97673870623112, 44.471954852342606, 38.71206432580948, 40.83689130842686, 40.321418568491936, 40.96450746059418, 40.04610434174538, 40.44476754963398, 40.98988629877567, 38.83267745375633, 39.320445880293846, 41.78288854658604, 39.063138887286186, 40.66775098443031, 38.6867006868124, 41.79888568818569, 39.40911412239075, 39.275741279125214, 39.534568190574646, 36.758452355861664, 38.038094490766525, 38.28706093132496, 36.95231415331364, 38.16260240972042, 37.66018196940422, 43.62562246620655, 51.0485203564167, 50.002444088459015, 52.04114869236946, 50.69746479392052, 47.248857244849205, 49.301472902297974, 50.263395085930824, 50.83983555436134, 54.32424858212471, 52.990056574344635, 52.245421931147575, 52.936426252126694, 50.97218245267868, 52.368330135941505, 50.128532722592354, 49.62265446782112, 47.791384533047676, 50.800690054893494, 52.10362493991852, 53.46400894224644, 55.01936808228493, 29.459355622529984, 0.984946929384023, 2.808899525552988, 5.2961681596934795, 5.486597316339612, 0.3791712335078046, 0.09586567190126516, 29.923360124230385, 64.27922800183296, 43.497915118932724, 36.62441834807396, 24.106159172952175, 54.334903210401535, 12.747530322521925, 0.48254061955958605, 0.1550777387456037, 0.06448046930017881, 0.030135706074361224, 0.07500265390262939, 0.03541124242474325, 0.049076585710281506, 0.01415588991221739, 0.011675369842123473, 0.08854776184307411, 0.1291911379666999, 0.03972779224568512, 0.023423698366968893, 0.06626584654441103, 0.05771423842816148, 0.05907542632485274, 0.18970412289490923, 0.11397757072700188, 0.28353900415822864, 0.09332022411399521, 0.1406156999291852, 0.09528732363833115, 0.1457951930933632, 0.1205029190168716, 0.12262270800420083, 0.12310117061133496, 0.21135499002411962, 0.2954532648436725, 0.19547132280422375, 0.2120346637093462, 0.26221110485494137, 0.07930418636533432, 0.12423052641679533, 0.28802914603147656, 0.3341681702295318, 0.48825103032868356, 4.866894269362092, 58.84923577308655, 55.34951336681843, 35.65987050533295, 44.92914631962776, 46.62282183766365, 67.10132136940956, 37.75204584002495, 1.4072175580076873, 4.77571246214211, 0.7492762722540647, 0.2057716200943105, 0.20750986353959888, 0.18676227919058874, 19.81314953416586, 61.839606910943985, 57.293789237737656, 64.49732109904289, 58.46113979816437, 58.16979423165321, 50.03786578774452, 51.15404449403286, 49.48839247226715, 52.3708114027977, 52.38782688975334, 50.68078748881817, 51.250775903463364, 51.17933213710785, 48.39269086718559, 46.96404352784157, 43.5803896933794, 47.15596742928028, 44.23357084393501, 43.97440955042839, 47.29760862886906, 45.793698728084564, 46.350992023944855, 43.64733450114727, 44.65611957013607, 46.52007155120373, 43.46211723983288, 46.946537867188454, 46.0391503572464, 44.45708245038986, 44.45517875254154, 46.16183057427406, 43.64908240735531, 47.3570716381073, 45.91647394001484, 46.99409991502762, 43.63482557237148, 44.577763974666595, 44.34920623898506, 44.45602610707283, 44.30056504905224, 45.339737087488174, 44.56416830420494, 45.293284580111504, 42.16312654316425, 42.93743759393692, 43.17121624946594, 44.40423868596554, 44.23831678926945, 43.52330915629864, 46.459244415163994, 51.87200836837292, 57.10473418235779, 57.48501017689705, 59.567575827240944, 56.29890002310276, 55.483205392956734, 60.409188866615295, 57.6821132004261, 50.04826582968235, 48.30600991845131, 49.71446514129639, 51.8390679359436, 49.09280329942703, 49.93214026093483, 47.33789786696434, 47.05896623432636, 41.756973937153816, 42.13961720466614, 43.220157623291016, 42.96315461397171, 41.47467188537121, 42.349848523736, 43.66154193878174, 41.99539594352245, 41.98192186653614, 44.749172776937485, 40.45372746884823, 41.810714453458786, 41.14114858210087, 44.95002619922161, 41.66191443800926, 42.77764856815338, 40.28104193508625, 40.043300092220306, 39.115678668022156, 38.39124374091625, 39.060403034090996, 39.377230033278465, 41.20717763900757, 45.34150019288063, 53.64718571305275, 52.580959126353264, 52.92220741510391, 54.60528910160065, 48.36858116090298, 48.874429017305374, 50.52572540938854, 52.485724836587906, 54.28852289915085, 53.90130467712879, 53.79839479923248, 57.32527434825897, 51.85189224779606, 53.54021765291691, 53.39481085538864, 52.484995275735855, 50.097370594739914, 51.91173903644085, 53.529582023620605, 56.73251375555992, 56.72149054706097, 33.60723204910755, 1.7402515187859535, 2.5454349629580975, 7.5258068181574345, 14.842695146799088, 3.283547256141901, 0.134991497034207, 36.64410509169102, 68.91182541847229, 45.36044977605343, 39.11462612450123, 34.86075818538666, 62.81970351934433, 17.76998206973076, 0.6745006190612912, 0.36128707753960043, 0.14520435448503122, 0.1541806454770267, 0.19180827483069152, 0.10049679214716889, 0.15033456904347986, 0.16551660984987393, 0.13339973869733512, 0.14803362922975793, 0.2169818794936873, 0.14257605333114043, 0.11212646888452582, 0.2055981059675105, 0.15414686291478574, 0.17064477608073503], [0.07277016979060136, 0.09694526670500636, 0.06848184013506398, 0.035774386415141635, 0.030080987526162062, 0.052314386775833555, 0.06773892062483355, 0.056370457605225965, 0.08645500187412836, 0.05411353457020596, 0.037697216830565594, 0.043089546816190705, 0.033366373245371506, 0.019256863852206152, 0.059265742675052024, 0.07041541684884578, 0.014126375626801746, 0.01690931345365243, 0.06298341642832384, 0.0931124524504412, 0.2031982081825845, 18.869711458683014, 47.0319838821888, 29.594208486378193, 29.625957682728767, 37.03071914613247, 49.171576872467995, 50.809893161058426, 2.8393741277977824, 0.9015668160282075, 0.4118685086723417, 0.015160657676460687, 0.12481763202231377, 0.05853196271345951, 1.8526074523106217, 41.62369228899479, 64.89149674773216, 56.898720636963844, 57.5380515307188, 52.2636229544878, 47.92378842830658, 47.49857984483242, 46.259751319885254, 48.23846094310284, 48.144484385848045, 48.46353426575661, 48.05188715457916, 48.810398653149605, 42.62112356722355, 41.55881457030773, 42.37428121268749, 40.69608986377716, 40.733662247657776, 39.65813755989075, 38.84648971259594, 41.57033175230026, 39.929420202970505, 36.81418776512146, 40.17896041274071, 37.80854120850563, 44.13308143615723, 43.5044963657856, 41.62366949021816, 41.844661831855774, 39.459902197122574, 40.57475857436657, 39.37122255563736, 39.203993529081345, 41.36906415224075, 39.32515762746334, 41.69887125492096, 40.37120349705219, 40.94930447638035, 39.74681340157986, 41.5171118080616, 42.018369510769844, 39.33339938521385, 39.68341760337353, 39.52313080430031, 39.80211183428764, 38.21754366159439, 38.903175070881844, 40.34887969493866, 40.10699987411499, 43.583581522107124, 50.881101340055466, 53.57522137463093, 51.778354793787, 75.33008381724358, 93.29181879758835, 56.182770654559135, 57.685992792248726, 53.44215631484985, 48.06484825909138, 48.16881828010082, 52.75417663156986, 52.35509164631367, 50.07863759994507, 50.21683618426323, 48.36579591035843, 43.51498380303383, 38.197104558348656, 38.078885301947594, 37.97639340162277, 39.13710571825504, 38.080944791436195, 38.85312795639038, 36.9202970713377, 39.16009448468685, 37.22942568361759, 38.331115767359734, 37.451808750629425, 38.590679839253426, 37.950824573636055, 36.731697991490364, 36.23950280249119, 37.36536718904972, 36.352075561881065, 36.69833578169346, 35.13925664126873, 36.479965299367905, 35.067212507128716, 35.576115399599075, 35.85312433540821, 35.66014789044857, 41.860552579164505, 48.77146974205971, 47.634722739458084, 49.95811566710472, 50.129133090376854, 50.98559953272343, 48.87186415493488, 47.74879641830921, 48.428769931197166, 49.53008383512497, 49.14470851421356, 52.51983940601349, 52.779209688305855, 49.810136407613754, 47.940393537282944, 52.1881628036499, 48.169274255633354, 50.533590987324715, 50.42086623609066, 53.828135803341866, 43.24798732995987, 8.674366436898708, 0.0861882146273274, 3.9747216179966927, 2.9268584959208965, 2.548326370306313, 0.6152772344648838, 4.249912351369858, 48.423435017466545, 47.28916548192501, 30.4715434089303, 20.150552429258823, 35.57876765727997, 35.29829330742359, 1.19166593067348, 0.08022719543077983, 0.0974904780741781, 0.029047465250187088, 0.06318107261904515, 0.04762767224747222, 0.0903057464165613, 0.04355177494289819, 0.04575329294311814, 0.05683423310983926, 0.02305226087628398, 0.028691106344922446, 0.031560215866193175, 0.013256662969070021, 0.027326179879310075, 0.05243558691290673, 0.03281683515524492, 0.025003693663165905, 0.0534344063635217, 0.04102504040929489, 0.09491410499322228, 0.024189041869249195, 0.02327161746507045, 0.03863922116579488, 0.029885561489209067, 0.044191483975737356, 0.08246442186646163, 0.03174937817675527, 0.04868734409683384, 0.006511820793093648, 0.031042302543937694, 0.0577383136987919, 0.07176129423896782, 0.05179836036404595, 0.020496153993008193, 0.12744848616421223, 0.09104584576562047, 0.30151877843309194, 26.267699785530567, 54.87080365419388, 28.088320791721344, 33.982245326042175, 45.83765856921673, 54.59404930472374, 53.591169118881226, 2.1930233482271433, 1.6477248212322593, 0.7232152519281954, 0.08623315909062512, 0.24659346789121628, 0.20271262095775455, 2.437532152980566, 45.35807490348816, 65.28732150793076, 58.04390698671341, 59.98569779098034, 54.674635380506516, 49.511970207095146, 49.20087330043316, 48.01237307488918, 50.31624265015125, 50.4305899143219, 49.2606782913208, 50.37539407610893, 49.536152109503746, 45.28569258749485, 42.92382672429085, 43.95875059068203, 41.52547515928745, 41.14886216819286, 42.756567299366, 41.31417989730835, 43.71862627565861, 41.43738828599453, 40.81899046897888, 43.079318180680275, 39.335409477353096, 45.68716764450073, 45.600338503718376, 42.92345054447651, 43.414840176701546, 40.757756754755974, 40.90934582054615, 43.292137160897255, 42.39993743598461, 42.21343204379082, 43.595725670456886, 42.61609263718128, 43.19400742650032, 42.606612145900726, 41.46950416266918, 42.53537356853485, 43.922945111989975, 41.634681299328804, 41.25944383442402, 41.52576394379139, 42.69049644470215, 41.33011244237423, 43.104195445775986, 39.99523267149925, 41.69973000884056, 43.19010503590107, 52.78837859630585, 54.870047494769096, 54.402174800634384, 60.37402555346489, 68.42062577605247, 61.65871001780033, 56.87805354595184, 56.62334181368351, 48.669851794838905, 49.52366217970848, 52.17542968690395, 54.03446853160858, 51.82991802692413, 51.166295036673546, 48.35164926946163, 44.44274581968784, 40.28750538825989, 39.27000358700752, 38.167853727936745, 40.45759566128254, 40.4374947398901, 40.74437007308006, 39.15575511753559, 40.28090514242649, 38.750297874212265, 40.342435240745544, 40.07215574383736, 40.70199854671955, 39.316870272159576, 38.49720485508442, 37.698867693543434, 39.59322564303875, 37.40306496620178, 37.76009000837803, 34.9983374029398, 38.881789818406105, 37.456045523285866, 38.796662986278534, 38.32757815718651, 37.12528087198734, 43.810900524258614, 50.08791670203209, 49.3565471470356, 52.78106778860092, 51.4318285882473, 50.93711033463478, 50.19404120743275, 48.78956817090511, 48.84661830961704, 51.1184936016798, 50.04741467535496, 53.39827626943588, 52.41768188774586, 51.98306120932102, 50.398960411548615, 52.46891833841801, 49.163954481482506, 52.39342778921127, 50.163202062249184, 55.613059625029564, 44.5703087747097, 11.072309464216232, 0.47812674078159034, 4.594595180824399, 4.880236778408289, 1.4793514623306692, 1.070394606795162, 4.104705518111587, 56.308027133345604, 55.0581070035696, 40.04024885594845, 23.62617462873459, 36.38670310378075, 44.665204882621765, 2.4149525770917535, 0.10148485787794925, 0.06807680561905727, 0.04561943176668137, 0.003401294575269276, 0.04456367845705245, 0.022470778894785326, 0.07414775172946975, 0.06248065590625629, 0.019527122494764626, 0.046795297967037186, 0.0239653975222609, 0.043050817839684896, 0.03498953927191906, 0.05702216716599651, 0.03383908791875001, 0.024772394062893, 0.15619113837601617, 0.33150151488371193, 0.2102932141860947, 0.21862503897864372, 0.06319375592283905, 0.04975912037480157, 0.13235087622888386, 0.24616198323201388, 0.1253558968892321, 0.17396790557540953, 0.08489342668326572, 0.16836423048516735, 0.14969287847634405, 0.12637173378607258, 0.08517677866620943, 0.15283289045328274, 0.14872179308440536, 0.20072978048119694, 0.16393040277762339, 0.28959460265468806, 0.3596611210377887, 30.65325915813446, 65.18598094582558, 38.088969960808754, 39.00567077100277, 50.82930251955986, 57.276158183813095, 61.21670253574848, 5.252876607701182, 2.1391313150525093, 1.6116627375595272, 0.2576815994689241, 0.39882294775452465, 0.36387019674293697, 2.766818921081722, 45.460262820124626, 67.14846163988113, 59.84500654041767, 64.16523411870003, 57.23990432918072, 52.787485644221306, 51.70815356075764, 52.085013538599014, 52.951279655098915, 53.096808046102524, 53.35939295589924, 53.95770125091076, 53.52125287055969, 49.16570618748665, 47.33263894915581, 45.4244839400053, 44.593791514635086, 44.33110401034355, 43.20371590554714, 44.24572639167309, 46.19640491902828, 45.28052106499672, 42.23673619329929, 44.290039613842964, 41.66042871773243, 48.182797729969025, 48.23271945118904, 45.299751833081245, 45.65370284020901, 43.812830820679665, 43.12127932906151, 44.2440240830183, 43.4615358710289, 43.562640845775604, 44.12312597036362, 46.541893780231476, 44.303836673498154, 47.09863990545273, 44.01425041258335, 46.267761290073395, 48.80336903035641, 44.29665885865688, 43.274627700448036, 44.68098923563957, 44.75301817059517, 43.127510994672775, 43.12186449766159, 42.48506046831608, 44.263680428266525, 47.626207396388054, 54.67001102864742, 56.004355028271675, 56.33212924003601, 65.54932504892349, 77.3757192492485, 61.756478771567345, 61.19497910141945, 58.8690023124218, 50.63112035393715, 51.814004480838776, 56.70347571372986, 56.55632480978966, 53.704927414655685, 54.461094439029694, 51.413095593452454, 48.442000821232796, 42.209510654211044, 41.899766474962234, 42.22303792834282, 42.11607366800308, 42.00328812003136, 42.68334522843361, 40.05150765180588, 43.743191957473755, 42.56117798388004, 44.176402911543846, 41.96612611413002, 43.321798369288445, 42.25697010755539, 40.5893611907959, 40.37181906402111, 42.541267052292824, 39.023210629820824, 40.58180719614029, 37.90004789829254, 42.13773250579834, 40.13415701687336, 41.22319757938385, 40.59710517525673, 39.55680079758167, 45.24290308356285, 52.571733221411705, 52.51955062150955, 56.650856137275696, 54.239923506975174, 55.529528707265854, 52.50979654490948, 51.430057883262634, 50.818115919828415, 52.22488783299923, 50.94702400267124, 54.38476413488388, 53.45564939081669, 54.71465103328228, 51.2786740064621, 55.80111913383007, 51.99034921824932, 54.747857451438904, 54.43584479391575, 55.988825261592865, 47.15497948229313, 10.978235062211752, 0.3554308495949954, 9.77755269035697, 5.657834177836776, 12.32464911416173, 1.8823977350257337, 5.665695481002331, 61.330799013376236, 56.451644226908684, 42.75286249816418, 30.32843168824911, 43.840656727552414, 55.75009927153587, 3.348438274115324, 0.2635437942808494, 0.3709339286433533, 0.0976195746625308, 0.17024086962919682, 0.13959621166577563, 0.18513721326598898, 0.16050169535446912, 0.22333065600832924, 0.0985751194821205, 0.165137164585758, 0.06852490696473978, 0.19910740113118663, 0.11809840507339686, 0.08923646746552549, 0.14579593524103984, 0.06907843038788997], [0.05021634271543007, 0.12529377912869677, 0.09819848695769906, 0.026872241542150732, 0.08716395328519866, 0.034588597700349055, 0.03340925082738977, 0.0282348450855352, 0.07869435619795695, 0.05289442713547032, 0.07958102971315384, 0.02590708219941007, 0.04310654941946268, 0.05425771902082488, 0.022141803383419756, 0.08140693564200774, 0.06856506457552314, 0.143625954806339, 0.13119057286530733, 0.08346674425411038, 0.19306314265122637, 3.389621414244175, 35.36526471376419, 38.7964653968811, 33.28950069844723, 36.11254021525383, 36.95855721831322, 61.87307171523571, 20.173691287636757, 0.0871859431208577, 0.26063513942062855, 0.07320936536416411, 0.36099437449593097, 0.284577535931021, 0.17086626263335347, 13.06513438001275, 66.47066161036491, 56.22290790081024, 61.13533370196819, 54.04407061636448, 52.15000905096531, 45.197845101356506, 50.42431265115738, 50.70650830864906, 52.1086672693491, 50.553855299949646, 51.80287107825279, 48.0409399420023, 43.7751292437315, 38.448863849043846, 44.01096358895302, 39.59414519369602, 41.93595573306084, 40.762886479496956, 45.75141079723835, 43.6083447933197, 41.30301609635353, 43.596307039260864, 41.88930183649063, 41.02820724248886, 41.68362267315388, 41.26258246600628, 42.9068074375391, 42.46367521584034, 41.911154463887215, 40.82714483141899, 40.6084855645895, 43.075168803334236, 41.45133353769779, 38.85113686323166, 42.515432238578796, 41.78832985460758, 40.764197409152985, 39.670809879899025, 39.54483523964882, 41.50061309337616, 40.97450852394104, 39.10374350845814, 38.146571069955826, 40.51725625991821, 38.96215170621872, 41.64627827703953, 38.77619728446007, 40.70723846554756, 45.97414344549179, 55.00376231968403, 52.445728182792664, 56.77653059363365, 69.88730907440186, 61.08044944703579, 62.29628160595894, 55.3056675195694, 53.44480477273464, 51.47907145321369, 52.352200001478195, 52.26852469146252, 57.76577331125736, 54.14066523313522, 51.8280029296875, 49.266058802604675, 45.50935238599777, 39.042505994439125, 37.786559388041496, 36.307921931147575, 38.69212679564953, 39.93028275668621, 40.018920600414276, 38.37124161422253, 38.40455062687397, 37.94424332678318, 37.04371064901352, 39.23021212220192, 38.8530595600605, 38.44750352203846, 37.66214266419411, 36.56996347010136, 37.08487384021282, 34.86780680716038, 34.95995946228504, 36.811353117227554, 38.299243077635765, 36.2633541226387, 37.19722241163254, 36.242869421839714, 34.96959574520588, 36.437388584017754, 39.524886310100555, 44.85349617898464, 45.58281384408474, 47.23925516009331, 48.76814492046833, 46.54953896999359, 49.75305587053299, 49.655689895153046, 47.71541140973568, 47.92246609926224, 44.69783753156662, 47.334987223148346, 52.53080561757088, 51.39670327305794, 49.683489203453064, 52.745079919695854, 53.72789338231087, 49.52798634767532, 53.08852069079876, 25.94651822000742, 1.6358719510026276, 0.27540996379684657, 3.1609993195161223, 3.1073571229353547, 1.75354961771518, 0.6844700372312218, 19.12208441644907, 55.30810698866844, 36.32755167782307, 30.703076384961605, 29.998991265892982, 42.26532585918903, 12.746448330581188, 0.4026403179159388, 0.12159625097410753, 0.029544054814323317, 0.09585105901351199, 0.033112458550021984, 0.04802259129064623, 0.0059928192968072835, 0.05345050354662817, 0.043982072165817954, 0.03510000053211115, 0.05512153438758105, 0.0924604905594606, 0.009425936932530021, 0.06718944932799786, 0.050476476608309895, 0.058548152665025555, 0.0780692081025336, 0.054669406890752725, 0.0728395012265537, 0.04396558906591963, 0.06503659024019726, 0.036630958420573734, 0.11203088768525049, 0.08199415256967768, 0.06588575561181642, 0.15249294228851795, 0.025835678316070698, 0.0360980295954505, 0.036035722587257624, 0.08625446615042165, 0.007073600609146524, 0.042137701602769084, 0.07463390298653394, 0.08585625197156332, 0.06336617909255438, 0.05324959674908314, 0.1320868794573471, 0.30944218451622874, 6.065330011770129, 46.744506508111954, 36.894336864352226, 30.287198200821877, 49.366620406508446, 44.32230748236179, 69.64204743504524, 18.472665064036846, 0.059112151502631605, 0.8691096107941121, 0.12629220524104312, 0.6229297863319516, 1.7172829387709498, 0.11310450820019469, 15.065353699028492, 67.97133028507233, 59.68454495072365, 61.975772604346275, 55.67325979471207, 54.52817603945732, 46.32961057126522, 52.37850978970528, 52.63499602675438, 54.82585206627846, 53.02794434130192, 53.00046041607857, 50.633286237716675, 46.116453409194946, 41.67196489870548, 46.84005618095398, 40.117415115237236, 42.607459500432014, 43.26314851641655, 46.058612912893295, 45.806895419955254, 43.163510262966156, 44.63358677923679, 43.17372031509876, 43.48984435200691, 42.5443334877491, 44.40468706190586, 45.94375267624855, 44.92675244808197, 42.48583182692528, 41.52048982679844, 41.29659824073315, 45.68308666348457, 44.072402492165565, 41.86815217137337, 42.98866264522076, 44.05843824148178, 42.84080117940903, 41.226947978138924, 41.42340503633022, 42.36138850450516, 40.92731885612011, 42.19364270567894, 40.027006566524506, 43.071232214570045, 40.7951695472002, 43.859420120716095, 39.99719336628914, 43.38977672159672, 47.91229784488678, 59.01313237845898, 50.53621664643288, 63.194504007697105, 67.68966659903526, 62.40724325180054, 63.67469944059849, 54.977406933903694, 58.11536215245724, 51.229896023869514, 55.54900266230106, 53.71605321764946, 59.124720990657806, 55.07556326687336, 55.46872057020664, 49.62701663374901, 47.53810912370682, 40.776383355259895, 41.17145575582981, 37.63183929026127, 40.71103826165199, 42.09339648485184, 41.55600272119045, 40.29037803411484, 39.6548393368721, 38.67665022611618, 40.36723650991917, 39.46163110435009, 40.0911471247673, 39.54898841679096, 39.16713170707226, 38.55479456484318, 40.23523159325123, 38.20541091263294, 37.40914843976498, 38.44490826129913, 39.30726818740368, 38.564499244093895, 38.84733706712723, 37.82316282391548, 37.50279821455479, 38.064111694693565, 41.73974186182022, 45.6233386695385, 48.26946347951889, 48.33725944161415, 51.2025260925293, 49.87687982618809, 51.60811632871628, 51.906119138002396, 49.65618386864662, 49.471726566553116, 48.30657608807087, 48.909466937184334, 53.22480417788029, 51.5463924407959, 53.32978494465351, 54.35539551079273, 54.70382921397686, 51.448049917817116, 54.03271682560444, 26.3110326603055, 1.8342800857499242, 1.0651440010406077, 4.036220367997885, 5.554719110950828, 2.0386010594666004, 0.6200150458607823, 20.76961901038885, 62.06417106091976, 39.731393828988075, 33.600844591856, 26.12712822854519, 47.194926738739014, 20.026648677885532, 0.6410152127500623, 0.10256462337565608, 0.060058204253437, 0.10049604999949224, 0.06774206733098254, 0.04449058062164113, 0.042250797487213276, 0.039351055820588954, 0.025317176841781475, 0.10200312186498195, 0.047389569008373655, 0.035971793986391276, 0.011413411193643697, 0.017279253661399707, 0.13888373505324125, 0.14875360153382644, 0.048789266948006116, 0.16133699740748852, 0.13633888098411262, 0.33538876567035913, 0.2208775610779412, 0.22563785954844207, 0.17396029114024714, 0.14370655204402283, 0.1931868735118769, 0.17724411649396643, 0.13476892694598064, 0.11812963464763016, 0.14625464187702164, 0.30514319019857794, 0.1371999949333258, 0.10918872925685719, 0.20882322744000703, 0.27721486694645137, 0.27993893483653665, 0.32563216576818377, 0.21198096190346405, 0.5099153600167483, 6.476970948278904, 54.221152514219284, 52.339250296354294, 40.943050011992455, 51.39550633728504, 46.84133671224117, 73.50615128874779, 28.242588713765144, 0.1816244501969777, 1.016293466091156, 0.2379434250178747, 0.8573919895570725, 0.5552889627870172, 0.1324659091187641, 15.237572807818651, 69.60686132311821, 60.43481849133968, 66.06474459171295, 57.71767549216747, 58.77539433538914, 49.261419251561165, 55.74259087443352, 53.78818854689598, 58.19338716566563, 55.82093507051468, 55.64733758568764, 51.979572996497154, 48.81729148328304, 42.69484721124172, 48.5695181787014, 43.579139560461044, 45.07657080888748, 47.19941809773445, 50.274372696876526, 49.98103603720665, 46.518544033169746, 46.876215040683746, 47.18206062912941, 45.70794112980366, 46.661910340189934, 45.571387857198715, 46.61405190825462, 47.42580994963646, 45.33723682165146, 44.266321286559105, 44.62608218193054, 48.58619928359985, 45.873756632208824, 43.12107793986797, 46.611711233854294, 46.361171677708626, 45.05826339125633, 43.30270059406757, 45.74404299259186, 45.00386171042919, 43.588760644197464, 43.77269357442856, 42.01050013303757, 45.0880765914917, 43.17829146981239, 45.96803717315197, 42.64720916748047, 44.37412150204182, 51.02345310151577, 59.07945401966572, 55.31302772462368, 58.973538503050804, 79.01962503790855, 72.01020196080208, 61.93795323371887, 59.79370169341564, 59.28254932165146, 55.05814120173454, 58.42813856899738, 58.48001338541508, 59.73914422094822, 57.096507623791695, 56.61669597029686, 52.76987358927727, 49.72295768558979, 42.80884109437466, 42.749678269028664, 41.23305805027485, 44.40960019826889, 43.13458241522312, 43.28289985656738, 41.85980781912804, 41.656849309802055, 41.967501640319824, 40.89359946548939, 41.63809351623058, 42.39887349307537, 42.157468646764755, 41.32689781486988, 41.85332536697388, 41.52330547571182, 39.01236601173878, 40.42929098010063, 40.53202226758003, 42.171660885214806, 41.02284573018551, 40.5952812731266, 39.6585289388895, 39.49106052517891, 39.4973985850811, 43.298190236091614, 48.157278299331665, 49.9766206741333, 49.873858988285065, 51.28542624413967, 50.62460370361805, 53.33436369895935, 52.69484281539917, 51.15252457559109, 50.73082320392132, 49.620701372623444, 48.27923275530338, 52.02648527920246, 54.7431381046772, 53.95657651126385, 57.21485987305641, 57.640543431043625, 54.34811890125275, 54.893507435917854, 29.401651918888092, 2.162340944632888, 1.8840525462292135, 5.616452498361468, 7.839684225618839, 5.614723591133952, 1.011411203071475, 24.33065302670002, 69.00333970785141, 45.754785016179085, 43.338734060525894, 38.84360946714878, 54.52376827597618, 28.374302946031094, 0.8043971238657832, 0.208169721881859, 0.2829576056683436, 0.14400844287592918, 0.19917459518183023, 0.1196379384782631, 0.11931794666452333, 0.18904139986261725, 0.10915355145698413, 0.16472240793518722, 0.09860024860245176, 0.21654554118867964, 0.0737254845444113, 0.1413806018535979, 0.17317367397481576, 0.22149579977849498, 0.21974695846438408], [0.09396549183293246, 0.042851309990510345, 0.023355292760243174, 0.011555846031114925, 0.0061082251158950385, 0.03562246878573205, 0.071500540652778, 0.031043827657413203, 0.006990218926148373, 0.05151044417289086, 0.0265055667841807, 0.0788089883280918, 0.015587596681143623, 0.058114059356739745, 0.04919364466331899, 0.027607366646407172, 0.09844482061453164, 0.059696496318792924, 0.010977569199894788, 0.06789659732021391, 0.06249573634704575, 0.39340417133644223, 16.619126424193382, 47.76040479540825, 29.987183399498463, 36.991235464811325, 36.639207154512405, 46.241299510002136, 52.63746589422226, 2.889183755032718, 0.4701385006774217, 0.11041069767088629, 0.802847103914246, 2.3331942642107606, 0.20532066148007289, 1.2110925070010126, 43.03245909512043, 62.598494589328766, 58.266936019062996, 57.19170391559601, 54.0897061675787, 51.2404328584671, 51.474367305636406, 54.229470267891884, 52.540768682956696, 55.85820347070694, 51.63074791431427, 48.43824282288551, 40.99596217274666, 42.93117173016071, 40.59940405189991, 42.602417171001434, 46.314058005809784, 52.505008801817894, 54.35110554099083, 50.24873547255993, 48.087449446320534, 45.07518008351326, 41.979911774396896, 42.040013149380684, 39.4508320838213, 42.878213971853256, 41.86328463256359, 40.77451765537262, 41.93388104438782, 41.55873857438564, 41.89509652554989, 42.25918158888817, 39.649523422122, 41.6714671254158, 40.14041908085346, 40.40467210114002, 41.06146305799484, 41.07050657272339, 38.63819628953934, 43.04002448916435, 40.50500951707363, 42.950030118227005, 40.68155564367771, 40.91888330876827, 41.224804893136024, 42.97693267464638, 38.05155336856842, 44.72532145678997, 50.07237173616886, 57.04227693378925, 49.44753706455231, 63.615392223000526, 23.32418203353882, 30.686896853148937, 94.0978391468525, 56.266499161720276, 55.13570263981819, 53.73213395476341, 56.360954493284225, 54.96903598308563, 56.55732415616512, 55.0713074952364, 53.64236757159233, 50.773069337010384, 43.47150273621082, 37.339995950460434, 40.045553371310234, 38.12083125114441, 38.52080538868904, 40.08644677698612, 39.91853378713131, 36.74747094511986, 37.00554169714451, 36.855138167738914, 38.40623773634434, 36.89701572060585, 36.3633381575346, 37.365777567029, 37.882899418473244, 36.99456408619881, 36.0116708278656, 37.66612485051155, 36.13870561122894, 36.59120053052902, 39.4470626860857, 34.52605314552784, 36.30692258477211, 34.699000865221024, 36.83175802230835, 33.46514247357845, 36.84319920837879, 42.761419638991356, 43.67034986615181, 45.8933711796999, 45.55938430130482, 48.064992651343346, 47.5268579274416, 49.87548530101776, 51.973949298262596, 48.90279069542885, 48.76987762749195, 44.82590965926647, 50.123380199074745, 52.34199374914169, 52.01805353164673, 54.49690751731396, 52.53750465810299, 51.81470364332199, 46.388131231069565, 8.70882773771882, 0.44452288770116866, 1.8398309941403568, 2.623093295842409, 7.332996614277363, 0.43826391105540097, 0.09992711216909811, 35.83020396530628, 52.666161954402924, 37.29801580309868, 42.952336594462395, 37.030954733490944, 46.422063410282135, 6.073982622474432, 0.05587665851635393, 0.12620006018551067, 0.053621268016286194, 0.04613312783476431, 0.05490226685651578, 0.03891697364451829, 0.059935709068668075, 0.011995111181022367, 0.018445139830873813, 0.06874611892271787, 0.012150152324466035, 0.037570135173154995, 0.011950728894589702, 0.005138314636496943, 0.043587813634076156, 0.07581224796012975, 0.1031877008790616, 0.023082225088728592, 0.029510795466194395, 0.04490103281568736, 0.0543431884580059, 0.0446514633949846, 0.026548247697064653, 0.08912533827242441, 0.05926449586695526, 0.04418698656081688, 0.04961648701282684, 0.008961268067650963, 0.05671326303854585, 0.023552702186862007, 0.07886766994488426, 0.05104137715534307, 0.05337030335795134, 0.058866500621661544, 0.052310679748188704, 0.008775496444286546, 0.051056208976660855, 0.025946814930648543, 0.48218409181572497, 23.949645571410656, 50.97543887794018, 28.162994384765625, 43.899697959423065, 45.391744896769524, 55.137180760502815, 54.94162805378437, 2.2599087841808796, 0.7257644995115697, 0.2046490623615682, 1.6209712880663574, 5.3224314004182816, 0.7991344062611461, 1.8756219861097634, 46.87765896320343, 63.49834330379963, 61.512634456157684, 59.034722819924355, 56.68386496603489, 54.38261725008488, 52.83959224820137, 55.836221650242805, 56.85787282884121, 58.13804313540459, 53.70213836431503, 51.00296080112457, 44.41516689956188, 46.0841703414917, 42.84226030111313, 41.922113075852394, 47.48292848467827, 53.026937395334244, 56.331859454512596, 51.10161870718002, 50.56188426911831, 48.224542289972305, 42.904348969459534, 45.002372190356255, 40.874380096793175, 45.45635282993317, 45.90496815741062, 42.6378008723259, 44.43261556327343, 44.32741440832615, 42.18308687210083, 43.899732157588005, 42.04720996320248, 42.9889590293169, 42.23681218922138, 42.82052926719189, 44.65149141848087, 44.44218724966049, 39.89613398909569, 42.855582386255264, 42.94823661446571, 43.51713068783283, 42.38991357386112, 42.628924548625946, 42.67558604478836, 44.695740044116974, 41.4416478574276, 45.733544155955315, 49.139719381928444, 59.563855826854706, 52.57545702159405, 65.40804862976074, 30.03608677536249, 28.18920347839594, 78.35480511188507, 59.37849797308445, 58.51100832223892, 55.25719352066517, 56.562290489673615, 55.17237067222595, 58.32172907888889, 56.62206508219242, 54.589242562651634, 52.8048887103796, 46.46011836826801, 38.807211220264435, 41.06514886021614, 40.49687035381794, 38.655603155493736, 41.39054819941521, 41.633704751729965, 39.68852072954178, 38.52452538907528, 39.63457502424717, 39.32514242827892, 40.75806073844433, 38.2748331874609, 39.6203637868166, 37.705532535910606, 39.125907719135284, 37.050789669156075, 39.57788586616516, 38.26962746679783, 38.82883206009865, 40.19555792212486, 36.385209783911705, 38.7515290081501, 36.155428513884544, 38.259865790605545, 35.77995926141739, 39.991778656840324, 46.28852717578411, 46.34666405618191, 47.165284529328346, 48.18462163209915, 51.1710561811924, 50.05990080535412, 53.74546743929386, 54.96744766831398, 49.810223802924156, 50.036813244223595, 45.99029637873173, 51.19988523423672, 51.108712926506996, 51.82471610605717, 55.423206612467766, 53.78226466476917, 50.11070407927036, 46.95647053420544, 8.880427479743958, 1.0486189252696931, 4.299226580187678, 2.4504144117236137, 8.3656957000494, 1.606865138746798, 0.1404708475456573, 38.98287959396839, 58.22323456406593, 46.53958350419998, 54.60240125656128, 36.6697309166193, 51.862839460372925, 9.158158376812935, 0.06947218425921164, 0.10623284411849454, 0.02245553147076862, 0.13013872696319595, 0.03590989515942056, 0.041589551328797825, 0.051172952516935766, 0.02896720754506532, 0.017249630836886354, 0.04950370283040684, 0.07926380611024797, 0.11502879322506487, 0.04572191493934952, 0.026963405107380822, 0.051558776540332474, 0.04267227057425771, 0.1559511575032957, 0.21555455139605328, 0.148708330525551, 0.1498598320176825, 0.09091225918382406, 0.10301270987838507, 0.07016838557319716, 0.17202845105202869, 0.19414667825913057, 0.16970297583611682, 0.1341146050253883, 0.09536519719404168, 0.17060017300536856, 0.10423461892060004, 0.19318886246765032, 0.10686134672141634, 0.10497947543626651, 0.15584495617076755, 0.2508465974824503, 0.1152448398352135, 0.11423868054407649, 0.2967022400116548, 0.5675417615566403, 28.481050617992878, 64.0486791729927, 38.71939413249493, 48.53537701070309, 49.09709706902504, 56.75234869122505, 63.53468835353851, 4.36065835878253, 1.5082017704844475, 0.319272642955184, 3.611523569561541, 8.96177826449275, 0.5650645319838077, 2.125530894845724, 46.717520356178284, 65.22079467773438, 64.05764669179916, 62.701241075992584, 58.389449045062065, 57.018680199980736, 55.48719137907028, 59.87351641058922, 59.08694341778755, 60.69869913160801, 56.63484379649162, 54.41249504685402, 46.47796221077442, 48.23571369051933, 44.06683959066868, 44.916500598192215, 51.50612600147724, 57.768433168530464, 60.143598318099976, 53.95165957510471, 52.36622504889965, 51.52846120297909, 46.165698766708374, 46.564316377043724, 43.54122519493103, 48.397049233317375, 46.980188861489296, 45.05018502473831, 45.80517791211605, 46.65340639650822, 45.79626739025116, 46.27252243459225, 42.51235440373421, 45.3631666302681, 44.554961398243904, 43.357668444514275, 47.210673093795776, 46.519649773836136, 42.15764343738556, 48.25821228325367, 45.408475399017334, 46.43904469907284, 45.48947185277939, 44.26642768085003, 44.907856062054634, 47.60625086724758, 41.50663956999779, 47.394678220152855, 53.11266839504242, 60.63145413994789, 52.944497019052505, 66.11661180853844, 35.956201404333115, 34.7737580537796, 83.2780185341835, 60.765598341822624, 60.13591893017292, 58.0629363656044, 59.94058281183243, 57.39944636821747, 59.276260659098625, 57.30364590883255, 56.768000051379204, 55.135687440633774, 48.89804854989052, 39.346907660365105, 42.87137433886528, 42.78809800744057, 40.744723454117775, 45.568891391158104, 44.15933422744274, 40.19695244729519, 41.76786035299301, 42.084535360336304, 41.19676239788532, 40.9831378608942, 40.17482243478298, 42.02196791768074, 39.84960548579693, 40.64685210585594, 38.60152445733547, 43.23887921869755, 41.07584908604622, 41.03585243225098, 45.06628476083279, 38.94536800682545, 39.91262510418892, 38.92530508339405, 40.53301781415939, 37.50125169754028, 41.24238274991512, 49.314756989479065, 49.27009418606758, 49.858450815081596, 50.1836221665144, 52.85056605935097, 51.59129463136196, 54.72047232091427, 56.71607963740826, 50.86379326879978, 51.959703862667084, 47.23442181944847, 53.25863756239414, 51.092692986130714, 53.39196100831032, 56.908976286649704, 54.30519640445709, 51.524273827672005, 48.42311583459377, 10.259292740374804, 1.2240292690694332, 5.17902709543705, 6.469574170187116, 17.716085761785507, 3.210899904370308, 0.2889932255493477, 44.93332229554653, 62.21378803253174, 48.31023909151554, 51.818214654922485, 41.95090413093567, 63.05537447333336, 12.823382802307606, 0.4110003146342933, 0.26215980760753155, 0.1341024338034913, 0.1551532300072722, 0.13580564787844196, 0.14050227007828653, 0.13349606946576387, 0.22450409538578242, 0.2573529467917979, 0.14112261647824198, 0.16515791503479704, 0.20027374557685107, 0.19452573760645464, 0.2158673814847134, 0.11823652617749758, 0.13821298198308796, 0.2254493095097132], [0.019230473080824595, 0.026573818395263515, 0.13186404219595715, 0.04372301809780765, 0.07567282067611814, 0.007683470203119214, 0.018746175337582827, 0.09122790943365544, 0.12499959178967401, 0.056644061478436925, 0.04938323741953354, 0.060441033710958436, 0.07793585158651695, 0.04473980865441263, 0.05604717807727866, 0.04121984675293788, 0.04584059919579886, 0.006487983937404351, 0.08246154975495301, 0.04862315945501905, 0.08184252437786199, 0.08736433315789327, 3.669214923866093, 40.136167109012604, 40.895210579037666, 30.057225041091442, 40.864261239767075, 36.371678709983826, 65.0485423207283, 20.093082413077354, 0.05044065313995816, 0.46835615881718695, 2.0484800543636084, 4.8511403147131205, 0.33739030826836824, 0.20804532308829948, 14.694544896483421, 64.50983762741089, 57.821060344576836, 60.863526687026024, 57.77938798069954, 56.52664080262184, 53.69325064122677, 55.701788663864136, 55.97034305334091, 54.780642092227936, 51.20334304869175, 44.865674525499344, 43.34769777953625, 42.67666518688202, 42.274468168616295, 50.51047682762146, 53.22376683354378, 55.39196088910103, 56.47872917354107, 56.23451627790928, 51.74430102109909, 46.58173084259033, 45.78662350773811, 42.582703828811646, 41.77387923002243, 42.871267944574356, 42.240064814686775, 42.78689347207546, 42.041206285357475, 42.38908141851425, 41.82175286114216, 41.37728311121464, 42.34373465180397, 40.15398055315018, 41.84178538620472, 41.111038997769356, 39.87165570259094, 40.58435685932636, 41.06478027999401, 40.4774571955204, 42.44185298681259, 40.12704759836197, 41.7959750443697, 40.26027224957943, 40.46799190342426, 41.62828244268894, 43.33610840141773, 43.63722324371338, 50.933416932821274, 55.62241472303867, 56.41410984098911, 50.639460906386375, 46.079363599419594, 39.64407831430435, 42.53941275179386, 55.249145552515984, 52.4800593405962, 54.47168067097664, 54.984223768115044, 54.64204452931881, 52.347826436161995, 54.66359317302704, 53.31021599471569, 51.6239994764328, 39.049083441495895, 40.64333349466324, 38.50956179201603, 37.84095346927643, 37.89826579391956, 39.073865711688995, 38.29364597797394, 38.6148427426815, 38.782687336206436, 38.343765288591385, 37.459731325507164, 39.12664107978344, 37.469002828001976, 38.6631191521883, 37.11870722472668, 38.130836114287376, 37.48816139996052, 38.010276183485985, 38.49297568202019, 36.06182813644409, 35.69957077503204, 37.085588201880455, 37.3140699416399, 36.847086399793625, 37.14580737054348, 36.09361723065376, 36.5254108607769, 37.74226136505604, 40.37571385502815, 43.60672228038311, 45.46742543578148, 48.12589958310127, 49.98084604740143, 46.55273079872131, 47.84467287361622, 48.514451533555984, 54.070057421922684, 52.63520501554012, 46.08929246664047, 45.753979459404945, 49.8190089315176, 54.623433127999306, 49.38003748655319, 55.49200192093849, 26.26182720065117, 1.2290094955824316, 1.0379071813076735, 0.9161081607453525, 2.9859595745801926, 6.5210504829883575, 1.5493692364543676, 4.550614915788174, 52.61544227600098, 44.460935443639755, 26.89376939088106, 13.70972229167819, 27.01592903584242, 38.30935053527355, 2.001358070410788, 0.21884633257286623, 0.07934082619613037, 0.039859675598563626, 0.03965434560086578, 0.024983323564811144, 0.08502225609845482, 0.03161197324516252, 0.028502567438408732, 0.05235878947132733, 0.02236751275631832, 0.058493252290645614, 0.03127117161056958, 0.05368020196328871, 0.02570735912740929, 0.010274819360347465, 0.044004533265251666, 0.06437259071390145, 0.009077277809410589, 0.025715272277011536, 0.14687807561131194, 0.07152126883738674, 0.02725027301494265, 0.020375796193548013, 0.05845731750014238, 0.026588071341393515, 0.056433699719491415, 0.06689744390314445, 0.03730267257196829, 0.03265591527451761, 0.09407348916283809, 0.038825515075586736, 0.07352008775342256, 0.06852548583992757, 0.010075567552121356, 0.049288747177342884, 0.06605773349292576, 0.06973503812332638, 0.04254708139342256, 0.2306272738496773, 6.764540942385793, 49.700014516711235, 40.15964984893799, 31.807397827506065, 52.029403522610664, 40.529727190732956, 74.94160786271095, 18.319183699786663, 0.08864705378073268, 1.0701143718324602, 3.36515333969146, 9.646743759512901, 1.8368036253377795, 0.11788988384068944, 16.805802807211876, 68.26614886522293, 58.48596006631851, 62.83701919019222, 59.34565633535385, 59.67496566474438, 53.524174913764, 55.98149925470352, 56.00835241377354, 56.49070233106613, 52.994654327631, 47.968409433960915, 45.33565230667591, 45.35896025598049, 43.595174700021744, 52.838326916098595, 55.46003043651581, 59.0535432100296, 58.44768092036247, 57.274212688207626, 53.799622133374214, 48.64001579582691, 47.53202944993973, 44.24977317452431, 42.83118009567261, 45.028681978583336, 42.6362619549036, 44.868573769927025, 43.68871808052063, 43.56863312423229, 42.82909780740738, 43.41022342443466, 43.85302506387234, 42.57160842418671, 43.32079142332077, 43.357007279992104, 42.21115976572037, 41.793786361813545, 43.0308023840189, 42.525395303964615, 44.92810897529125, 42.660462856292725, 42.229679971933365, 41.561725214123726, 43.49175184965134, 43.63577552139759, 45.204874724149704, 46.36782892048359, 52.99796015024185, 57.68716312944889, 57.21037991344929, 51.593046337366104, 43.66520494222641, 40.627191960811615, 48.49396303296089, 60.56539088487625, 53.90874847769737, 58.452905640006065, 55.44289715588093, 57.55002088844776, 53.59511710703373, 57.68515683710575, 53.255210146307945, 52.40666247904301, 40.77007569372654, 41.85820810496807, 39.06753145158291, 41.04108475148678, 40.22442877292633, 39.95781987905502, 39.09199073910713, 39.74637262523174, 40.270394906401634, 39.2764138430357, 39.91819940507412, 40.77679753303528, 38.91914941370487, 40.92830680310726, 37.32237629592419, 39.5071754604578, 39.514862447977066, 40.342796221375465, 40.92503137886524, 38.80631826817989, 38.4172685444355, 39.01009373366833, 38.41108247637749, 38.12072865664959, 38.696386367082596, 38.93394201993942, 38.71389202773571, 38.50152142345905, 42.139092832803726, 46.88956372439861, 48.196328803896904, 50.42760707437992, 51.012395694851875, 49.214392974972725, 49.64470848441124, 49.96309719979763, 53.89879681169987, 53.2682054489851, 46.97356961667538, 49.144556522369385, 51.146862879395485, 54.43990297615528, 49.61166925728321, 53.12024138867855, 28.642133474349976, 1.8720046989619732, 2.8158795135095716, 3.8800523104146123, 7.756935115903616, 5.535689257085323, 1.443775158841163, 4.491639705374837, 60.632761269807816, 48.81908118724823, 35.76462708413601, 24.47438221424818, 30.041191801428795, 47.19470635056496, 3.6098466720432043, 0.1800564702716656, 0.06990089328610338, 0.06521870585856959, 0.013617124095617328, 0.00476662296023278, 0.05978840017633047, 0.0791794090764597, 0.037975251325406134, 0.05996734311338514, 0.09150664525805041, 0.007181334012784646, 0.018229250927106477, 0.006795172312195064, 0.05487487418577075, 0.025828043471847195, 0.018171821684518363, 0.02913938951678574, 0.20735727797728032, 0.14790695946430787, 0.22525476291775703, 0.12228224775753915, 0.21554205362917855, 0.11018394186976366, 0.14102395536610857, 0.09148898956482299, 0.21825743839144707, 0.23621668486157432, 0.11171633581398055, 0.1540085265878588, 0.2109349938109517, 0.16283165314234793, 0.12265372977708466, 0.12877816247055307, 0.09652503300458193, 0.23693882423685864, 0.16845043835928664, 0.14384068781509995, 0.13653148314915597, 0.31056291656568646, 6.679658247157931, 55.75001947581768, 53.89818884432316, 39.94852937757969, 55.14057397842407, 45.524927750229836, 79.04344215989113, 26.484248265624046, 0.14344580587930977, 1.3711167639121413, 6.1024886928498745, 16.432797722518444, 1.487280330620706, 0.3122381813591346, 18.361762315034866, 68.85118827223778, 61.52914457023144, 65.32433152198792, 62.337456196546555, 61.69659398496151, 57.376658990979195, 61.23355843126774, 58.61902512609959, 59.23935703933239, 55.71332484483719, 50.478778928518295, 48.25660116970539, 47.346948981285095, 46.1407683044672, 55.63433088362217, 58.41328516602516, 61.29505053162575, 59.92849566042423, 61.43386468291283, 55.437372252345085, 50.61302952468395, 50.239410772919655, 47.00537770986557, 46.09594590961933, 47.50941686332226, 46.393431946635246, 47.55159080028534, 45.07728897035122, 45.723554491996765, 45.55702082812786, 45.692871138453484, 46.13808184862137, 44.95253026485443, 46.25053681433201, 45.39217047393322, 43.425859585404396, 44.77674029767513, 45.01541689038277, 45.42695760726929, 49.74812753498554, 44.87598717212677, 46.24946527183056, 43.79925794899464, 45.60306675732136, 46.9955438375473, 47.68242157995701, 48.84823702275753, 54.26169253885746, 61.27902679145336, 59.15203012526035, 53.1550133228302, 47.15405613183975, 47.99951836466789, 53.76663230359554, 57.58004307746887, 54.91396173834801, 59.37961511313915, 58.17814998328686, 58.22388052940369, 54.89933632314205, 57.03550569713116, 54.46080185472965, 55.03826826810837, 42.931088134646416, 44.99391384422779, 41.829451248049736, 42.0026421546936, 42.91211195290089, 43.1087514013052, 41.26647725701332, 42.13010631501675, 43.74839007854462, 40.7066684961319, 41.766002252697945, 42.74184308946133, 40.99843584001064, 43.451078832149506, 40.1815290749073, 41.662355214357376, 43.2028229534626, 42.55318321287632, 43.472756668925285, 41.0555961728096, 39.82058264315128, 42.39224284887314, 41.91932402551174, 41.318481266498566, 41.15949019789696, 39.77001495659351, 40.52490144968033, 40.4449537396431, 44.29119475185871, 47.955205142498016, 48.78884620964527, 53.0928410589695, 53.61989937722683, 50.271036475896835, 53.027495965361595, 51.40435606241226, 55.47675333917141, 55.4448464512825, 50.838859006762505, 51.40068545937538, 52.340006455779076, 55.37648431956768, 49.32300254702568, 53.68948504328728, 29.86565452069044, 2.1549904765561223, 3.328109127469361, 4.038734883069992, 10.117627792060375, 17.408712655305862, 3.544466430321336, 5.48644152469933, 64.66733157634735, 54.02277655899525, 36.546587124466896, 25.82715332508087, 37.34915725886822, 54.86792340874672, 4.694076692685485, 0.3556077182292938, 0.2059649198781699, 0.19777293055085465, 0.09133969171671197, 0.1688525636564009, 0.12475322844693437, 0.13084697333397344, 0.12124983128160238, 0.21720125834690407, 0.1426072680624202, 0.0655655782611575, 0.13918768905568868, 0.11381046133465134, 0.09094795648707077, 0.11661510419799015, 0.10708887435612269, 0.15851787524297833], [0.011600374891713727, 0.05684594048943836, 0.021390343608800322, 0.03452642798947636, 0.03974294690124225, 0.037124338196008466, 0.0189265784501913, 0.03311908592877444, 0.05404982119216584, 0.04452686422155239, 0.039960511203389615, 0.04827975659281947, 0.05284936763928272, 0.023036197089822963, 0.01291244096137234, 0.029306908945727628, 0.05714033934054896, 0.06911656193551607, 0.013487126725522103, 0.04577663348754868, 0.13199900917243212, 0.027872474784089718, 0.11590287249418907, 19.34204701334238, 45.43649509549141, 30.145741291344166, 43.57354246079922, 30.833253599703312, 47.25421875715256, 50.29507778584957, 1.5604500356130302, 0.41405692405533046, 1.9296947470866144, 3.703224998898804, 3.9548368100076914, 0.3843600332038477, 1.5766217303462327, 46.67283475399017, 59.87739980220795, 62.49905772507191, 57.4542698264122, 60.12628264725208, 54.60457853972912, 59.134357273578644, 57.00867533683777, 54.57910470664501, 47.885573878884315, 42.08322063088417, 41.86895772814751, 47.70705945789814, 55.08539713919163, 55.814148634672165, 55.4630246758461, 56.94612689316273, 56.980416253209114, 56.30328878760338, 52.367703169584274, 52.28399746119976, 49.26994599401951, 46.63466960191727, 41.86487674713135, 40.08866585791111, 41.50094747543335, 41.32025197148323, 40.97211465239525, 43.30542504787445, 44.230090230703354, 40.714264288544655, 40.854476764798164, 40.62770873308182, 41.46903678774834, 40.15023775398731, 40.45686610043049, 40.097021609544754, 41.45106375217438, 39.50611151754856, 42.398637905716896, 42.99931727349758, 48.751505613327026, 46.746831983327866, 47.164691761136055, 43.46092790365219, 42.333843782544136, 41.6637459397316, 52.21728444099426, 52.69666291773319, 58.74384842813015, 51.96926034986973, 58.64317283034325, 35.02659268677235, 26.90457221120596, 51.3507067412138, 51.64068438112736, 56.76080323755741, 53.61499384045601, 54.44377116858959, 51.550952196121216, 52.05934211611748, 50.79051420092583, 42.572524175047874, 39.00275632739067, 38.72175380587578, 37.143994867801666, 39.44374166429043, 39.2286542057991, 39.236082807183266, 37.63793036341667, 39.45075608789921, 36.79196275770664, 38.236113265156746, 37.415509298443794, 37.047677636146545, 36.767955645918846, 39.24562409520149, 37.72711157798767, 36.54499500989914, 38.5345758497715, 38.690751269459724, 38.645054921507835, 40.52697233855724, 38.0025739967823, 37.663434594869614, 36.605343371629715, 37.41485953330994, 36.28529034554958, 36.34854935109615, 36.255416348576546, 35.286977514624596, 36.54798164963722, 39.84886072576046, 41.78394868969917, 44.4035205245018, 47.11247496306896, 48.507292717695236, 48.78131501376629, 50.97081832587719, 49.29639257490635, 49.11736898124218, 49.36552606523037, 50.28959088027477, 47.00199969112873, 47.49938540160656, 50.136645287275314, 45.98825588822365, 9.88403532654047, 0.3096036164788529, 1.9886925187893212, 4.603667194023728, 2.826094077900052, 5.4123075027018785, 0.919937405269593, 14.064067527651787, 46.93655580282211, 30.527231320738792, 28.15942257642746, 20.691485702991486, 42.11985446512699, 17.933415099978447, 0.10839995244168676, 0.08035290782572702, 0.07043581106700003, 0.0475949435349321, 0.05450154421851039, 0.038649588968837634, 0.03596781607484445, 0.05367501806176733, 0.011683218053804012, 0.08166413434082642, 0.07533724376116879, 0.01521657757621142, 0.009785402653506026, 0.019742386139114387, 0.009711464335850906, 0.0759107457997743, 0.02162833738111658, 0.07434092534822412, 0.028568685374921188, 0.02405462037131656, 0.005269515213512932, 0.035179577316739596, 0.02063432890281547, 0.028397212154231966, 0.05158784275408834, 0.016542347402719315, 0.10021414520451799, 0.02436360427964246, 0.03531946102157235, 0.061950643721502274, 0.05830591566336807, 0.00822571437311126, 0.05499734710610937, 0.009006068739836337, 0.015156213139562169, 0.016449957438453566, 0.008824579308566172, 0.11000322891050018, 0.049462079477962106, 0.05327102626324631, 0.19380359823117033, 28.39769449084997, 52.51008912920952, 27.895243652164936, 48.97257775068283, 38.15955497324467, 54.14443463087082, 52.32568122446537, 1.2945868517272174, 0.5456561234313995, 3.6571372719481587, 3.0616192147135735, 8.321132641285658, 0.5642180086579174, 2.4930787598714232, 49.18366402387619, 62.32698395848274, 64.62769970297813, 58.17148134112358, 61.32522091269493, 56.72259248793125, 62.41820186376572, 60.716660767793655, 57.1501075476408, 50.78230284154415, 45.27729503810406, 44.585823342204094, 49.19912539422512, 55.70223703980446, 58.055857345461845, 56.840006187558174, 59.08130832016468, 58.83839875459671, 59.48879465460777, 56.02080054581165, 53.85793000459671, 52.9593276232481, 49.10365171730518, 44.81506124138832, 42.32290416955948, 44.414277747273445, 42.598567977547646, 42.650138810276985, 43.89782465994358, 45.26072032749653, 42.32822768390179, 43.217053189873695, 41.61955051124096, 43.2614766061306, 42.63449124991894, 43.05949844419956, 43.27128387987614, 43.99797968566418, 42.52634525299072, 44.00950826704502, 44.40688334405422, 49.750882387161255, 48.177987188100815, 48.31337012350559, 44.35725040733814, 44.80677388608456, 44.34754952788353, 53.244080543518066, 54.21983398497105, 58.617934584617615, 52.288940995931625, 62.42567606270313, 37.30629175901413, 26.537506207823753, 53.28843176364899, 51.94221720099449, 59.04991440474987, 55.73756754398346, 58.11659328639507, 54.14807103574276, 55.449033826589584, 52.89078310132027, 45.73256380856037, 40.14132723212242, 39.56218510866165, 38.71855057775974, 40.92646010220051, 40.195474326610565, 40.0911471247673, 39.283238276839256, 41.19362756609917, 39.95424807071686, 39.55857150256634, 38.780662044882774, 39.3753757327795, 39.65321682393551, 40.414236187934875, 39.02150832116604, 38.847884237766266, 41.23319864273071, 40.19212670624256, 41.64861895143986, 42.61105790734291, 39.85899098217487, 39.99804072082043, 37.78838708996773, 38.84218454360962, 37.912245243787766, 37.39908277988434, 37.13612549006939, 37.6399290561676, 39.1045718640089, 41.978950425982475, 45.0319118052721, 47.20892898738384, 47.84451708197594, 51.160549744963646, 50.86879380047321, 53.02863210439682, 51.15834206342697, 51.688660606741905, 50.14015629887581, 52.00049467384815, 48.597838059067726, 50.59198625385761, 49.07938241958618, 47.91045494377613, 10.378379300236702, 1.1057329480536282, 5.49011972732842, 5.2438796404749155, 7.307906085625291, 3.930201306939125, 0.547669599764049, 15.419947821646929, 54.83559474349022, 37.493519112467766, 35.686803460121155, 18.729861862957478, 46.05103611946106, 23.484700620174408, 0.3059249685611576, 0.02384541636274662, 0.07159678978496231, 0.05400055000791326, 0.06895667364005931, 0.049257268983637914, 0.097950134659186, 0.08374781042221002, 0.033896333479788154, 0.07085706150974147, 0.06376494246069342, 0.03789362250245176, 0.01354308558802586, 0.039751147633069195, 0.03268682943598833, 0.06893300655065104, 0.067484260071069, 0.060313558715279214, 0.16378759872168303, 0.06788423313992098, 0.10586460528429598, 0.08839637855999172, 0.09789451069082133, 0.1101650096825324, 0.14123681816272438, 0.10870682308450341, 0.1785521220881492, 0.1410110419965349, 0.14093047444475815, 0.2344817662378773, 0.14303017349448055, 0.22192799689946696, 0.1127443958830554, 0.1494469158933498, 0.1752237233449705, 0.12291155187995173, 0.14575219305697829, 0.15215465653454885, 0.14401326683582738, 0.0842666310200002, 0.22337877686368302, 30.835957154631615, 62.41148382425308, 37.97406032681465, 53.75154331326485, 45.28106443583965, 55.8844068646431, 63.85453999042511, 1.888547942508012, 0.6735618913080543, 6.502541676163673, 16.927065700292587, 14.191546887159348, 0.5097505438607186, 2.690528752282262, 50.56533068418503, 61.97545722126961, 67.07780823111534, 62.097848653793335, 63.88401120901108, 59.03547137975693, 63.491188287734985, 64.75179344415665, 59.59599070250988, 51.527119874954224, 47.678029015660286, 46.91320985555649, 51.34889043867588, 59.94758203625679, 58.6326739937067, 59.81230169534683, 60.83004288375378, 62.76146784424782, 62.045008689165115, 58.09532582759857, 57.032203674316406, 54.834819585084915, 50.9134566038847, 45.86443953216076, 43.480078876018524, 45.332946851849556, 45.01914069056511, 44.762506261467934, 45.75868360698223, 46.83031350374222, 43.56045216321945, 44.1698444634676, 43.68559464812279, 45.792258605360985, 43.448016196489334, 47.604316771030426, 45.2531511336565, 45.82307495176792, 42.99174427986145, 46.40759378671646, 46.88905455172062, 54.165971875190735, 51.597207114100456, 52.135015055537224, 48.11829999089241, 47.81311936676502, 47.527146711945534, 56.846720427274704, 57.70668648183346, 60.65665818750858, 54.85682040452957, 62.00944259762764, 41.61712244153023, 32.98775129020214, 52.291882038116455, 54.735162332654, 60.48682250082493, 56.061063185334206, 58.68829920887947, 54.223151206970215, 57.98797398805618, 56.88701346516609, 47.7396997064352, 42.35097326338291, 40.48819161951542, 41.23594969511032, 42.2760146856308, 42.182387709617615, 42.08597928285599, 42.16707453131676, 42.93738439679146, 42.16069847345352, 40.683976113796234, 40.90405270457268, 40.44309563934803, 40.58849863708019, 42.19235457479954, 40.88000759482384, 40.464245304465294, 43.214393332600594, 42.260097339749336, 43.438824489712715, 46.672929748892784, 41.39601230621338, 40.67544937133789, 40.284457951784134, 41.15710012614727, 41.35061614215374, 40.72893530130386, 39.22523058950901, 39.740653932094574, 40.72717219591141, 44.02482144534588, 47.97874867916107, 48.84995833039284, 51.10623925924301, 53.20950999855995, 54.02700953185558, 55.185886546969414, 53.780672550201416, 53.40542748570442, 52.64201045036316, 54.560789689421654, 50.83561398088932, 52.803999558091164, 50.93522563576698, 47.89976231753826, 12.05179050564766, 1.2023927550762892, 6.1066746432334185, 10.604920294135809, 11.018256414681673, 14.288645926862955, 1.9357131491415203, 19.169304482638836, 57.115973979234695, 42.876918241381645, 40.412606075406075, 26.887801811099052, 57.41618447005749, 28.978316634893417, 0.4497860505944118, 0.15464757510926574, 0.1773059819242917, 0.09622317185858265, 0.0866841028619092, 0.09660698837251402, 0.17197902401676401, 0.12918359774630517, 0.09587507491232827, 0.2089903294108808, 0.15088659332832322, 0.09416440967470407, 0.12914343271404505, 0.12149875503382646, 0.18322251678910106, 0.17482321592979133, 0.10343974165152758, 0.1572218182263896], [0.011085103615187109, 0.04432462155818939, 0.0475305399595527, 0.03602499855333008, 0.10443333638249896, 0.05765649562817998, 0.023113434253900778, 0.018196015698777046, 0.04700314755609725, 0.024480700340063777, 0.06290239616646431, 0.011508928382681916, 0.030392648732231464, 0.04542361610219814, 0.01707409435766749, 0.06878073269035667, 0.035235279210610315, 0.07049746127449907, 0.029240423646115232, 0.059965064720017835, 0.04407281827297993, 0.05287546897307038, 0.041906752667273395, 1.4224463095888495, 34.51250687241554, 44.10880833864212, 34.80167895555496, 43.52614380419254, 31.77754282951355, 52.62303426861763, 9.444191828370094, 1.4544804906472564, 2.4989541945979, 3.5773505782708526, 2.437762040644884, 0.6443165824748576, 0.3546931251185015, 16.6050348803401, 58.41905705630779, 57.446556240320206, 60.78102931380272, 57.562279030680656, 61.05595976114273, 57.118056267499924, 57.602830454707146, 49.82260353863239, 43.72909851372242, 39.94246490299702, 49.57129642367363, 56.041733622550964, 58.61950770020485, 57.496542558074, 55.498051196336746, 57.94512368738651, 56.621107533574104, 54.57315042614937, 49.95576739311218, 51.85497768223286, 51.12911023199558, 49.25195015966892, 46.18250146508217, 40.75661301612854, 41.95952966809273, 40.1598284393549, 41.49991773068905, 41.96700006723404, 42.768897637724876, 41.935929134488106, 41.26880653202534, 41.49322248995304, 40.160333812236786, 40.87344154715538, 41.28708355128765, 39.979653507471085, 40.95880776643753, 43.397919684648514, 48.08097839355469, 53.47362622618675, 55.835499688982964, 54.49173219501972, 54.10924851894379, 52.32069209218025, 46.700208485126495, 43.793493658304214, 46.151840910315514, 52.14261844754219, 53.66059899330139, 55.21540716290474, 54.65836465358734, 57.548086792230606, 47.520630061626434, 52.49694183468819, 54.642675295472145, 56.61978140473366, 53.262129575014114, 53.147375732660294, 52.70918324589729, 49.580020755529404, 43.18765416741371, 40.12018136680126, 39.16781947016716, 40.39095103740692, 39.86507825553417, 40.12574806809425, 39.010048136115074, 40.331674218177795, 39.01235841214657, 38.11099737882614, 38.3225130289793, 38.27456720173359, 37.31488689780235, 37.99323029816151, 38.018191158771515, 38.449608609080315, 38.78357648849487, 37.453815042972565, 38.01854074001312, 39.550705924630165, 38.913749903440475, 38.86507071554661, 39.11045014858246, 37.022868767380714, 38.64394158124924, 37.47928127646446, 37.66323320567608, 36.91977269947529, 35.002125799655914, 36.243606582283974, 35.3396312892437, 36.0787296295166, 36.010937467217445, 36.875383481383324, 38.778545558452606, 40.82031659781933, 42.269418239593506, 44.8953927308321, 46.289173141121864, 47.223071828484535, 47.13808938860893, 48.17246228456497, 52.50875160098076, 50.818716287612915, 52.51146465539932, 41.5502954274416, 1.3482310669496655, 1.0643593431450427, 3.79237771499902, 4.243249408900738, 6.095516541972756, 2.3233169317245483, 0.5126350640784949, 28.579968810081482, 51.18983097374439, 29.746948890388012, 28.98610431700945, 23.236243352293968, 42.988765239715576, 4.545961590483785, 0.12009365425910801, 0.035789006724371575, 0.02147574254195206, 0.06860660258098505, 0.11832069314550608, 0.024160799439414404, 0.044219299670658074, 0.048643305053701624, 0.05535784534004051, 0.05785706474853214, 0.04727511870441958, 0.07096622401149943, 0.05014061396650504, 0.04223201372951735, 0.03473819240753073, 0.07972569655976258, 0.043567797911236994, 0.016709722112864256, 0.012249601968505885, 0.06672477582469583, 0.039563176469528116, 0.02107104013703065, 0.04414856928633526, 0.08514118526363745, 0.006179940237416304, 0.030715494103787933, 0.031246561993611977, 0.03425548471568618, 0.035183647996746004, 0.01946896780282259, 0.04484588011109736, 0.02704966493183747, 0.06974841162445955, 0.017243265065189917, 0.025072260687011294, 0.06658764177700505, 0.03768293790926691, 0.00532266551090288, 0.09043462778208777, 0.08358564373338595, 0.20109473902266473, 4.119989247992635, 43.742694184184074, 45.22432968020439, 36.71823151409626, 48.24961714446545, 37.81804829835892, 62.28768266737461, 8.530213572084904, 0.39705838775262237, 2.823568400926888, 3.702383106574416, 5.732256509363651, 3.133912472985685, 0.10696417128201574, 20.29541775584221, 61.15749791264534, 57.68837906420231, 63.36526304483414, 57.369773760437965, 61.4377024769783, 59.355847388505936, 57.769633904099464, 53.17428968846798, 45.28550639748573, 43.74056249856949, 51.03211663663387, 58.83244067430496, 60.92592693865299, 57.98082277178764, 58.396136686205864, 58.046536445617676, 58.55830818414688, 56.015135049819946, 53.47696244716644, 53.4927885979414, 54.33810643851757, 52.22282834351063, 47.60081335902214, 43.943790793418884, 44.33588035404682, 42.60463625192642, 43.5171040892601, 43.9925117790699, 44.14612613618374, 42.62249909341335, 44.03195746243, 44.43934880197048, 43.17961759865284, 43.959381356835365, 44.119994938373566, 41.32400617003441, 42.52982206642628, 44.13784638047218, 48.698080480098724, 56.154283583164215, 56.543724685907364, 55.73397293686867, 55.17236687242985, 52.23855569958687, 48.60199123620987, 45.77899731695652, 47.923252657055855, 54.23682287335396, 54.400392696261406, 57.69722118973732, 57.11041487753391, 56.59833915531635, 45.829432010650635, 52.128388211131096, 55.82658916711807, 58.05430322885513, 55.27012802660465, 55.297262370586395, 55.22212140262127, 51.681251004338264, 46.22492618858814, 43.04102383553982, 41.70656584203243, 41.92453734576702, 41.25572383403778, 42.77352198958397, 39.658794924616814, 41.696971356868744, 40.96322312951088, 39.651814699172974, 41.02489002048969, 39.79103922843933, 39.65748779475689, 39.33969184756279, 39.065718948841095, 39.90770436823368, 41.28638818860054, 40.994810834527016, 39.542019590735435, 42.18721725046635, 42.73128345608711, 41.86554931104183, 42.0533200353384, 39.14693959057331, 39.4778448343277, 39.72353585064411, 38.22985880076885, 38.337214440107346, 36.7597670853138, 38.53255055844784, 38.16503047943115, 38.036190792918205, 38.58469896018505, 37.86835379898548, 41.246269941329956, 43.70589315891266, 44.54845614731312, 47.464290484786034, 49.361578077077866, 49.450158923864365, 49.88547496497631, 50.39739489555359, 53.723869398236275, 51.229367852211, 53.319970071315765, 41.23663745820522, 1.82795864995569, 2.5079749105498195, 7.193762585520744, 6.278221663087606, 7.885438520461321, 1.825769254937768, 0.45485548325814307, 31.514623537659645, 54.756296798586845, 34.79284442961216, 30.70203334093094, 22.88099281489849, 51.42094597220421, 6.930133206769824, 0.14330657897517085, 0.04816140259208623, 0.02738623632467352, 0.01288419853153755, 0.023437140516762156, 0.018019388262473512, 0.06156943585665431, 0.03248277593229432, 0.052104852511547506, 0.04159516567597166, 0.02977654370624805, 0.011645618997135898, 0.04864878581429366, 0.03758423597901128, 0.01955976214958355, 0.05705664363631513, 0.05662532596033998, 0.03753741017135326, 0.08231453772168607, 0.1597995642805472, 0.1364947171532549, 0.08418283512583002, 0.19364347244845703, 0.2719100547255948, 0.08614775273599662, 0.19840083201415837, 0.11976544687058777, 0.1692343392642215, 0.26745782175567, 0.1511016528820619, 0.10450317247887142, 0.14826795493718237, 0.195201255264692, 0.17590396106243134, 0.10125405737198889, 0.21257831656839699, 0.12144978070864454, 0.16926214011618868, 0.22508369787828997, 0.1778760107117705, 0.2888091729255393, 3.8073389371857047, 52.879239320755005, 56.45206980407238, 43.56243185698986, 57.33922719955444, 42.82089024782181, 64.4573700428009, 11.896755024790764, 2.6107988180592656, 9.086217787116766, 7.7356211096048355, 9.18738640844822, 2.4576708348467946, 0.6526015035342425, 21.088668890297413, 62.96362079679966, 59.38800126314163, 65.14622747898102, 59.88995052874088, 63.662399500608444, 60.64637593924999, 60.79288847744465, 54.722406417131424, 47.522499561309814, 46.300260946154594, 54.88300859928131, 61.75889164209366, 63.65976624190807, 61.60693019628525, 60.21220363676548, 59.343232065439224, 61.403876692056656, 59.97737243771553, 55.06939999759197, 55.77565290033817, 58.197665736079216, 53.639772310853004, 50.78482210636139, 47.17001907527447, 48.25966000556946, 44.50186684727669, 44.77597653865814, 46.04287035763264, 45.6508681923151, 44.50478509068489, 47.4833844602108, 46.9097026437521, 44.85375836491585, 46.31360583007336, 44.54301863908768, 43.7051559984684, 43.81117030978203, 46.460471749305725, 51.1412999778986, 57.7104102820158, 61.28209322690964, 57.0741306245327, 59.34144236147404, 56.56911112368107, 50.63515953719616, 49.05162870883942, 50.706037133932114, 57.45515897870064, 57.124702110886574, 58.41009333729744, 57.02335014939308, 59.77703958749771, 47.66561508178711, 54.45710465312004, 58.585263937711716, 60.61262235045433, 58.08727405965328, 56.50994449853897, 56.18089355528355, 53.53278525173664, 48.60229901969433, 44.85889948904514, 44.028480648994446, 44.52177777886391, 43.87618102133274, 43.15655283629894, 42.28644132614136, 44.61062841117382, 44.44429233670235, 42.542254999279976, 44.18666996061802, 42.092469334602356, 41.73962026834488, 41.68642312288284, 40.81412672996521, 42.00355790555477, 42.87014700472355, 42.70239360630512, 43.159976452589035, 44.27814245223999, 44.26583111286163, 43.079720959067345, 44.68416966497898, 40.5046409368515, 41.802746281027794, 41.17430180311203, 41.15778788924217, 40.98247669637203, 39.20716255903244, 39.410295858979225, 40.08243419229984, 39.630722030997276, 40.40644660592079, 39.08367678523064, 43.144670873880386, 46.18176430463791, 46.9428026676178, 47.47231565415859, 50.48063322901726, 50.58911360800266, 51.78670294582844, 51.897174417972565, 56.410519033670425, 54.80516977608204, 55.65087519586086, 41.88399352133274, 2.284452854655683, 2.722425665706396, 8.508126307278872, 9.09217681735754, 18.96826297044754, 8.637589160352945, 0.8081528660841286, 36.34413778781891, 61.91471368074417, 40.21082170307636, 42.343172281980515, 31.47264339029789, 61.72161564230919, 9.280544109642506, 0.34630555019248277, 0.23971405578777194, 0.10016375337727368, 0.10831473904545419, 0.16619683272438124, 0.09300390593125485, 0.19107006053673103, 0.13250432268250734, 0.1308596640592441, 0.17507952405139804, 0.11064083024393767, 0.11774597398471087, 0.1315532307489775, 0.13370942207984626, 0.10373756551416591, 0.1917220075847581, 0.13055775838438421, 0.1176571314863395], [0.06846862990641966, 0.029037934218649752, 0.025133313465630636, 0.06189671556057874, 0.025038659950951114, 0.028906722509418614, 0.026331022927479353, 0.11065694226999767, 0.04400743877340574, 0.010456539785081986, 0.04593659228703473, 0.01922201074194163, 0.020865489350399002, 0.031249448948074132, 0.05028984873206355, 0.00717161280590517, 0.09338410076452419, 0.06848280492704362, 0.02761035750154406, 0.046325663206516765, 0.03959301822760608, 0.0230608215497341, 0.04097809214727022, 0.04681618571339641, 8.189865835011005, 44.212854355573654, 24.05895810574293, 43.454654440283775, 36.06431320309639, 45.19328534603119, 32.316840291023254, 0.10549016951699741, 2.553676008246839, 0.8401556988246739, 5.875723510980606, 2.720851837657392, 0.5342313833534718, 1.36300562415272, 33.87091130018234, 59.992510825395584, 57.74602957069874, 56.960805505514145, 60.36324933171272, 54.19362299144268, 55.22209860384464, 48.58467936515808, 42.47151039540768, 47.85058155655861, 54.004963114857674, 58.136078640818596, 61.35147750377655, 55.59479400515556, 55.73380954563618, 56.52830891311169, 58.517828956246376, 53.407642766833305, 53.05260881781578, 53.01382049918175, 54.812985956668854, 51.26766599714756, 47.40688316524029, 41.58756762742996, 42.66752667725086, 40.413913205266, 42.0466285943985, 41.51755638420582, 43.49513366818428, 41.07042297720909, 41.71625532209873, 42.31060042977333, 40.94944506883621, 41.33783362805843, 39.68185968697071, 41.01784899830818, 41.00866489112377, 41.661127880215645, 48.747835010290146, 55.94939477741718, 54.25386495888233, 55.338216572999954, 55.5065855383873, 53.3428980410099, 54.28074091672897, 50.41025720536709, 45.880155488848686, 44.4637168943882, 50.57488337159157, 53.35827961564064, 53.82882736623287, 53.35192635655403, 51.04969069361687, 53.050511330366135, 56.649518609046936, 55.893400982022285, 53.66870395839214, 50.94777636229992, 47.9412978887558, 43.42366710305214, 39.012046828866005, 39.35793086886406, 40.344091951847076, 40.602212101221085, 41.385460272431374, 40.30831687152386, 40.44534891843796, 38.45092333853245, 38.79496447741985, 38.37296672165394, 38.84610593318939, 38.957903534173965, 39.15515094995499, 38.49374324083328, 40.369121208786964, 38.602489605546, 39.17382314801216, 37.852801233530045, 38.50230798125267, 39.1523353010416, 40.516108721494675, 40.519786924123764, 39.293364733457565, 37.323850616812706, 37.39590995013714, 37.4237472563982, 38.351775258779526, 35.69227136671543, 36.6149340569973, 36.307097375392914, 37.15170845389366, 36.70790746808052, 35.92799171805382, 35.342363342642784, 35.01369997859001, 35.20310841500759, 36.993139162659645, 35.21979331970215, 38.482271656394005, 38.59773226082325, 41.52333587408066, 46.61271817982197, 51.779601126909256, 48.3857524394989, 59.068628400564194, 22.812642082571983, 0.06189257437654305, 2.1289841970428824, 6.547534111887217, 4.753067102283239, 5.077643310651183, 1.58674830570817, 0.5086568556725979, 46.43936388194561, 41.37230157852173, 32.97463059425354, 35.39739578962326, 31.199451349675655, 29.557620249688625, 0.39055661007296294, 0.08669537608511746, 0.04441861827217508, 0.05675029620761052, 0.010483479745744262, 0.044846473829238676, 0.06077786485548131, 0.02142334506061161, 0.08722616752493195, 0.029529933599405922, 0.07403025490930304, 0.047043587182997726, 0.013291329614730785, 0.052253909161663614, 0.10044430004199967, 0.05365832716051955, 0.02621359846671112, 0.06427956250263378, 0.06702741622575559, 0.051025098146055825, 0.05356151770683937, 0.05015611743147019, 0.0369514808699023, 0.07314404894714244, 0.07882038029492833, 0.03889226383762434, 0.049733215710148215, 0.09960568058886565, 0.06050907009921502, 0.07509663206292316, 0.07801758431014605, 0.02070303507935023, 0.009117363988480065, 0.028124684395152144, 0.06673504714854062, 0.04542237671557814, 0.06869973469292745, 0.04535595820925664, 0.030183045819285326, 0.04291491204639897, 0.05937314999755472, 0.052969124299124815, 0.061285738775040954, 14.833100661635399, 53.69209170341492, 24.998811073601246, 52.17022016644478, 38.23493532836437, 52.21694625914097, 28.221891224384308, 0.08188182109734043, 1.6166139906272292, 2.242353488691151, 3.2222971552982926, 6.439469810575247, 1.0833605797961354, 1.497565428726375, 39.699023365974426, 61.140661016106606, 60.265347585082054, 56.13979496061802, 61.7759945243597, 57.74515941739082, 59.30287443101406, 50.4001459479332, 45.68816319108009, 49.018809869885445, 55.408516600728035, 58.30700486898422, 60.9088696539402, 58.26319321990013, 55.53565017879009, 56.933355778455734, 60.488122031092644, 57.30730131268501, 54.77344147861004, 54.30519260466099, 56.843805983662605, 54.76012319326401, 49.93491791188717, 41.9551333039999, 45.56493200361729, 42.433512434363365, 44.53646019101143, 43.668278977274895, 45.4187386482954, 43.22846777737141, 43.618319258093834, 43.646703734993935, 43.611563220620155, 43.68617981672287, 41.81818105280399, 43.28616388142109, 42.59919114410877, 43.37665222585201, 51.23587690293789, 59.06336188316345, 57.37056791782379, 56.85367025434971, 56.32090084254742, 57.15383894741535, 56.308011934161186, 50.770892053842545, 46.65333420038223, 46.09457038342953, 53.02569106221199, 54.07952271401882, 55.94248674809933, 55.88049307465553, 50.93519143760204, 53.312381878495216, 58.41523826122284, 56.48813746869564, 56.332193836569786, 52.23672419786453, 50.07183596491814, 45.340785831213, 41.03804871439934, 41.13312341272831, 42.35672615468502, 42.020565792918205, 43.084231317043304, 43.01327392458916, 41.51511691510677, 40.99792666733265, 40.64772605895996, 40.18917806446552, 40.37811912596226, 39.808484092354774, 41.02693811058998, 41.344300881028175, 42.592735290527344, 40.150830522179604, 40.65036691725254, 38.56526680290699, 39.903292804956436, 41.795553267002106, 41.91036410629749, 41.91633738577366, 41.8339654058218, 39.40108135342598, 40.22254407405853, 39.695394560694695, 40.4086846858263, 37.98023119568825, 38.41782711446285, 37.14026726782322, 39.424522295594215, 39.05922889709473, 38.1555537879467, 36.96127027273178, 36.62710480391979, 37.028306275606155, 38.42446155846119, 37.524612843990326, 40.685667023062706, 40.76740063726902, 43.549083173274994, 49.46388378739357, 53.352325335145, 50.724139362573624, 59.593859016895294, 25.545668229460716, 0.06375156895956025, 2.7929693553596735, 11.84639822691679, 12.932525295764208, 2.399286017753184, 1.5949385287240148, 0.39642913558054715, 51.230162009596825, 46.061819940805435, 40.66094554960728, 35.04821352660656, 31.68232373893261, 39.64176803827286, 0.616420260630548, 0.12250984960701317, 0.052578721224563196, 0.05134271508723032, 0.0194590063256328, 0.0835166462638881, 0.041584489881643094, 0.02666755906830076, 0.0199055398843484, 0.04618637693056371, 0.08246875600889325, 0.04077163779584225, 0.0496990694955457, 0.036733530650963075, 0.03613916313042864, 0.058960797905456275, 0.012440342270565452, 0.048643809714121744, 0.05842108585056849, 0.2008251761435531, 0.14234100031899288, 0.10615963125019334, 0.11635071408818476, 0.1556063408497721, 0.21731971995905042, 0.1114654156845063, 0.3115583147155121, 0.09513175464235246, 0.13776203821180388, 0.1802749140188098, 0.1502578755025752, 0.09627080289646983, 0.17910505179315805, 0.15947278181556612, 0.20202347746817395, 0.15251105069182813, 0.16483408631756902, 0.20522087230347097, 0.09675262001110241, 0.17087638552766293, 0.1796515693422407, 0.11110315113910474, 0.18811902904417366, 15.55544475093484, 62.78305448591709, 35.691382214426994, 56.64759211242199, 45.820643082261086, 57.190696969628334, 40.085762813687325, 0.1876211370108649, 6.521062832325697, 4.699419206008315, 17.554672323167324, 7.58096038363874, 1.0521820653229952, 3.0809126794338226, 37.521584406495094, 62.20342218875885, 59.32345412671566, 58.82701836526394, 64.58362206816673, 58.98684538900852, 60.8822026848793, 53.21577966213226, 48.123577907681465, 53.18733058869839, 56.178370490670204, 61.52734726667404, 65.64644023776054, 58.38883347809315, 56.55274920165539, 58.83989967405796, 62.638753429055214, 58.681417778134346, 57.03400857746601, 58.725920990109444, 59.55225884914398, 57.07909695804119, 51.47497907280922, 44.494198858737946, 46.956922709941864, 44.46095444262028, 46.71184346079826, 46.527040377259254, 47.20131419599056, 44.071946516633034, 45.657552033662796, 46.62882171571255, 45.207200199365616, 46.45953319966793, 43.35147097706795, 46.66722245514393, 44.72848668694496, 45.18487259745598, 52.13161803781986, 59.61906686425209, 57.646315321326256, 57.3560830950737, 59.170793518424034, 57.82485634088516, 59.09258611500263, 52.82684773206711, 50.51400303840637, 47.66246885061264, 54.51884754002094, 56.13260954618454, 58.10159169137478, 58.37226636707783, 52.62074679136276, 56.797380074858665, 58.93029302358627, 60.2868278324604, 60.364032089710236, 55.33369101583958, 52.96588987112045, 48.049162700772285, 43.54622192680836, 43.70766006410122, 43.6732567101717, 44.35684762895107, 45.64075693488121, 44.770611226558685, 43.920748829841614, 42.38396689295769, 42.714032381772995, 42.00465604662895, 40.85877813398838, 42.489388436079025, 42.76715353131294, 44.06177446246147, 45.3196931630373, 42.937331199645996, 44.602907225489616, 41.23107835650444, 41.77319526672363, 43.061747923493385, 44.63827192783356, 44.69058372080326, 44.13103714585304, 41.50381252169609, 41.70306622982025, 42.45631121098995, 42.41301253437996, 39.11219425499439, 42.43627108633518, 39.992071241140366, 41.2979319691658, 41.36094018816948, 41.836963444948196, 39.00824323296547, 39.44231294095516, 38.800170198082924, 41.57614924013615, 39.97887074947357, 42.9349335283041, 42.5305250287056, 45.97505159676075, 50.36814406514168, 57.60194510221481, 52.31533817946911, 60.74032969772816, 26.107644774019718, 0.21170992957195267, 4.789832979440689, 14.045875053852797, 14.640063419938087, 18.095647394657135, 4.932254562154412, 0.6378042069263756, 58.678184151649475, 50.87465688586235, 46.989954337477684, 44.24345411360264, 40.168092995882034, 50.58238796889782, 0.8191775588784367, 0.2072871895506978, 0.09158434811979532, 0.15883242711424828, 0.10552994863246568, 0.10825742298038676, 0.18302114243851975, 0.09676972651504911, 0.16050070087658241, 0.1371136386296712, 0.09692967418232001, 0.1382532509160228, 0.16225837374804541, 0.26337841409258544, 0.2194938118918799, 0.11802161505329423, 0.09621018427424133, 0.13153445441275835, 0.2152230785577558], [0.009176391631626757, 0.03483574400888756, 0.0032274534396492527, 0.03004433285241248, 0.061685886248596944, 0.031801091026864015, 0.03545420906448271, 0.11861259466968477, 0.06816209323005751, 0.011589288133109221, 0.06968991554458626, 0.09751180739840493, 0.024324559890374076, 0.011977604845014866, 0.04496926958381664, 0.020517641023616306, 0.1551441609626636, 0.008769476698944345, 0.04429398199135903, 0.021979007724439725, 0.02332284606382018, 0.03159680374665186, 0.12099689251044765, 0.006881856088511995, 0.2261406200705096, 25.17267644405365, 36.48606777191162, 27.512619383633137, 47.4772097915411, 33.134320825338364, 52.39641822874546, 4.401396922767162, 1.8838584003970027, 2.878525326959789, 1.981252043042332, 5.748301148414612, 0.49835899262689054, 0.2240204525878653, 7.420830801129341, 47.29349344968796, 63.50854575634003, 59.02131333947182, 59.485735818743706, 55.938789546489716, 53.85025441646576, 43.15033636987209, 45.67077912390232, 52.59262450039387, 57.17216916382313, 57.95434579253197, 59.16504442691803, 55.707077980041504, 57.38373041152954, 58.29688221216202, 56.77803531289101, 53.12667444348335, 54.69746075570583, 51.3772939145565, 54.91425812244415, 51.59472584724426, 49.01879847049713, 41.60873629152775, 41.79624103009701, 40.937528908252716, 43.345645889639854, 41.45978048443794, 42.11472474038601, 43.27730655670166, 43.08344095945358, 44.47089470922947, 39.8580676317215, 40.77663414180279, 39.268977642059326, 40.97792834043503, 41.22274160385132, 42.42048293352127, 53.05357776582241, 53.00339765846729, 54.54199209809303, 54.158227890729904, 55.48715338110924, 55.57556323707104, 53.52561503648758, 53.47973629832268, 51.7401060461998, 46.744198724627495, 45.56576415896416, 50.79702325165272, 54.18155483901501, 57.4466360360384, 59.15624789893627, 54.55091781914234, 56.01907163858414, 51.4699899405241, 50.145153030753136, 45.53620934486389, 42.75578834116459, 41.36017642915249, 40.50597466528416, 41.965392753481865, 46.353325098752975, 47.502193450927734, 49.18866455554962, 46.773346960544586, 42.195250019431114, 39.71494451165199, 39.44327048957348, 38.61257426440716, 39.14762355387211, 39.44447502493858, 38.31525921821594, 37.873912900686264, 39.87449035048485, 37.94375695288181, 39.9848972260952, 37.49617896974087, 39.416478127241135, 39.03057083487511, 42.06027366220951, 39.16998155415058, 40.11616498231888, 36.75101235508919, 38.285890594124794, 36.44049681723118, 38.79046931862831, 38.65199714899063, 37.28698119521141, 35.22873803973198, 37.188798263669014, 35.88337831199169, 36.29150681197643, 37.06942766904831, 40.13237491250038, 40.883871987462044, 44.7876913100481, 43.29250954091549, 46.07278615236282, 44.79771517217159, 49.79893460869789, 47.72299200296402, 52.87017300724983, 48.500149101018906, 54.253405183553696, 7.455250779166818, 0.20296248723752797, 2.469343808479607, 12.018508091568947, 5.752498973160982, 3.9736633747816086, 0.9291509608738124, 4.127868600189686, 50.79194292426109, 31.452287882566452, 37.416109666228294, 45.67688539624214, 37.02120825648308, 14.48065247386694, 0.3220058244187385, 0.10075077734654769, 0.06623445369768888, 0.04383257022709586, 0.0719899425166659, 0.055606884125154465, 0.0619663290126482, 0.013783648118987912, 0.09389122511493042, 0.015401574582938338, 0.06687048167805187, 0.023073564225342125, 0.08703292711288668, 0.06882843794301152, 0.0912653878913261, 0.036664559156633914, 0.06210588617250323, 0.03692815145768691, 0.02287782648636494, 0.05091091872600373, 0.02845729457476409, 0.036238225002307445, 0.05680132999259513, 0.014748970734217437, 0.06106214823375922, 0.008082979893515585, 0.024239251870312728, 0.09732521662954241, 0.011310829686408397, 0.025411051101400517, 0.043437261556391604, 0.019152037348248996, 0.0752227303746622, 0.0472174167225603, 0.05249287700280547, 0.0567620518268086, 0.047231432181433775, 0.030275606477516703, 0.04942863088217564, 0.03771530668018386, 0.08473902285913937, 0.13416746078291908, 0.06736705268849619, 0.5575764400418848, 35.1480645686388, 38.53609196841717, 33.54097880423069, 52.94127859175205, 39.42864507436752, 57.01118320226669, 2.765766615048051, 0.7950540189631283, 1.8891420168802142, 4.950695922598243, 2.9505749233067036, 4.097594199702144, 0.49919880693778396, 9.0649370290339, 50.048740804195404, 65.22210940718651, 61.22578024864197, 60.845348462462425, 57.76138074696064, 55.513706356287, 46.62137031555176, 46.25319667160511, 55.61131551861763, 59.886872693896294, 59.51745271682739, 59.536611288785934, 55.65051041543484, 58.46989832818508, 58.43540757894516, 59.21188451349735, 55.59781864285469, 55.07100731134415, 55.08750222623348, 55.872004330158234, 54.59605559706688, 50.32429061830044, 43.01701292395592, 43.462843000888824, 43.36486145853996, 45.40529876947403, 44.63298261165619, 44.75509665906429, 46.08893148601055, 45.131789445877075, 45.23190647363663, 43.578041419386864, 42.10072249174118, 43.66080857813358, 41.82393014431, 41.789154410362244, 42.67410412430763, 54.990527629852295, 55.951188281178474, 56.6183602809906, 55.77111594378948, 57.97127768397331, 58.07044856250286, 56.601762771606445, 55.32009154558182, 53.79661649465561, 46.66707046329975, 46.86187840998173, 52.24762201309204, 56.58227741718292, 58.58081437647343, 59.31433081626892, 56.57790005207062, 58.52523475885391, 54.1290682554245, 51.96641430258751, 49.51173461973667, 45.741417333483696, 41.981454491615295, 43.29962655901909, 42.901529520750046, 47.75048352777958, 47.70189553499222, 51.431327015161514, 46.914167404174805, 43.92178237438202, 42.62457378208637, 41.78279735147953, 40.835869163274765, 41.00919686257839, 40.3273918479681, 40.59580944478512, 40.50527170300484, 40.43113388121128, 40.838643014431, 42.13604919612408, 39.155766516923904, 41.12717293202877, 42.47359648346901, 44.57627445459366, 41.06975041329861, 41.53251998126507, 39.188395366072655, 40.62153786420822, 39.15367662906647, 41.7934899777174, 39.95250776410103, 39.01102088391781, 37.04631730914116, 39.033416882157326, 36.755579710006714, 37.82781757414341, 38.53772968053818, 41.286194398999214, 41.627488285303116, 45.3988391160965, 43.971901684999466, 46.567876785993576, 46.893922090530396, 51.13458193838596, 49.29878644645214, 54.47005435824394, 50.08915163576603, 53.61797668039799, 8.40724267065525, 0.7758425467181951, 3.116450747475028, 14.17412482202053, 13.950470723211765, 2.637924375012517, 0.5790489097125828, 4.82214929535985, 57.940358743071556, 37.13315024971962, 43.32348547875881, 46.672519370913506, 43.21696199476719, 24.06810611486435, 0.2773011341923848, 0.05576606738031842, 0.0688526319572702, 0.05246659384283703, 0.025714834409882315, 0.025128072047664318, 0.01229055831572623, 0.01802747767214896, 0.09219856437994167, 0.0505085448094178, 0.031165942491497844, 0.03354955384565983, 0.02928397287178086, 0.12650450400542468, 0.045436844884534366, 0.016038065477914643, 0.014554245099134278, 0.03375368156412151, 0.01263442409253912, 0.1435031887376681, 0.23221230832859874, 0.12433347714249976, 0.1402530717314221, 0.11216287122806534, 0.16643388953525573, 0.17202312243171036, 0.12190640190965496, 0.27137912227772176, 0.14221538440324366, 0.1302666138508357, 0.2145323171862401, 0.07537939032772556, 0.16413594799814746, 0.10889490557019599, 0.13918768905568868, 0.3964070195797831, 0.1424701340147294, 0.11708249396178871, 0.11146475517307408, 0.14212487207259983, 0.22474422468803823, 0.2306255223811604, 0.10001453716540709, 0.4459488799329847, 38.36007781326771, 48.47261197865009, 39.239795207977295, 58.805268332362175, 43.86080704629421, 63.36232580244541, 6.216766135767102, 4.517244156450033, 9.936876241117716, 7.818151256069541, 14.285823628306389, 2.7470295829698443, 0.37237173586618155, 9.640509244054556, 51.07841715216637, 65.77950909733772, 64.57992106676102, 63.44736523926258, 61.822500228881836, 58.59403006732464, 47.943824753165245, 47.924460992217064, 59.34066340327263, 60.39501182734966, 63.791250586509705, 61.22487589716911, 58.29327240586281, 60.03794878721237, 62.88787566125393, 62.49504894018173, 58.79222743213177, 60.2562964707613, 56.77925884723663, 58.643522411584854, 57.44849033653736, 52.23734736442566, 46.45834766328335, 45.34843862056732, 44.91183444857597, 47.4836390465498, 46.550975292921066, 46.28137595951557, 48.810596242547035, 47.931562811136246, 47.9863216727972, 43.977954760193825, 45.33471375703812, 44.43363770842552, 44.70653906464577, 45.185564160346985, 47.225070521235466, 59.65533971786499, 58.651292994618416, 58.57256501913071, 57.10351824760437, 60.50684742629528, 61.21674433350563, 59.4454275816679, 59.21959429979324, 56.42219200730324, 49.66169737279415, 48.89240965247154, 55.19619919359684, 59.005566984415054, 60.39603777229786, 62.1731074154377, 58.16004015505314, 59.73384350538254, 55.09311072528362, 55.60290277004242, 51.10313482582569, 47.1926848590374, 44.212956950068474, 44.585952535271645, 44.76140812039375, 51.45980268716812, 52.40179494023323, 53.72092455625534, 49.93776395916939, 47.020911276340485, 44.316281005740166, 44.192232862114906, 41.619770899415016, 41.76163248717785, 44.133355021476746, 42.50848241150379, 41.66352555155754, 42.161241844296455, 42.26123347878456, 44.037242978811264, 42.33076214790344, 43.51580835878849, 43.433440178632736, 46.88165634870529, 42.00107663869858, 44.36419643461704, 41.644199788570404, 42.25106902420521, 41.87182657420635, 44.49110962450504, 43.01034428179264, 40.147471502423286, 38.08253690600395, 40.37988603115082, 38.6867006868124, 39.813157841563225, 41.95919908583164, 44.21406649053097, 45.14187790453434, 49.40695144236088, 47.68656335771084, 50.220339596271515, 49.702947959303856, 53.06418679654598, 53.20636756718159, 56.05513550341129, 52.36133091151714, 54.66391995549202, 8.696979023516178, 0.8652701543178409, 8.543708547949791, 23.480357453227043, 18.305808417499065, 10.195537861436605, 1.8533758423291147, 5.862133540213108, 62.82393269240856, 43.92139099538326, 49.80626441538334, 48.21101501584053, 53.23048487305641, 29.462648145854473, 0.4676189093152061, 0.12640737171750516, 0.1248155688517727, 0.19742305245017633, 0.10243576427455992, 0.11023234474123456, 0.10585474214167334, 0.0560004264843883, 0.13025093969190493, 0.15962419478455558, 0.0721696981054265, 0.18717642728006467, 0.1648091501556337, 0.2375844185007736, 0.16912646067794412, 0.12849878839915618, 0.16061396745499223, 0.17448197642806917, 0.10994574215146713], [0.11800868684076704, 0.02707054154598154, 0.01182778192742262, 0.0895957559987437, 0.009574203195370501, 0.05359679569664877, 0.1072769939491991, 0.014286302885011537, 0.05295752082020044, 0.04543091883533634, 0.08211277003283612, 0.04774913213623222, 0.03958552624681033, 0.02454435991239734, 0.05029568572354037, 0.0432532349077519, 0.03081918697716901, 0.01183359387141536, 0.032736560751800425, 0.06607046874705702, 0.08636345795821398, 0.055041070736479014, 0.05265766347292811, 0.017642813254497014, 0.1228941188310273, 2.840912095271051, 36.40266604721546, 25.51844649016857, 37.45353385806084, 32.472213953733444, 40.87187983095646, 23.51932816207409, 1.317464830353856, 0.7657882268540561, 2.3531640926375985, 4.988682959228754, 4.889828888699412, 0.7006379321683198, 0.3500459744827822, 24.26838956773281, 60.818662494421005, 64.1463415324688, 59.74419794976711, 57.37241081893444, 51.110529229044914, 45.62791362404823, 50.85567310452461, 57.43182063102722, 58.18506941199303, 60.608860552310944, 57.84619979560375, 58.236621245741844, 55.484938099980354, 54.9355635792017, 56.79812863469124, 56.66833519935608, 54.09027233719826, 55.85371971130371, 55.00808268785477, 51.40134282410145, 43.24558965861797, 41.034461706876755, 40.9839092195034, 42.054832354187965, 42.82728150486946, 42.896688580513, 42.54860445857048, 43.49873207509518, 41.71538896858692, 42.372130528092384, 41.85236021876335, 42.261013090610504, 40.54535195231438, 40.794493183493614, 39.8057596385479, 43.39745610952377, 48.191503062844276, 53.2556015253067, 55.83470173180103, 56.06128737330437, 55.41600599884987, 55.12508220970631, 56.245497688651085, 55.549055859446526, 55.18998272716999, 53.32494780421257, 48.60346935689449, 48.87771584093571, 54.73143853247166, 53.27983662486076, 56.174582093954086, 54.61543455719948, 57.578314170241356, 52.35313095152378, 46.18999466300011, 43.00999090075493, 40.08310295641422, 42.3616810888052, 45.44469125568867, 48.85675236582756, 53.18491771817207, 52.1922741830349, 55.43731905519962, 53.03670287132263, 43.35209034383297, 37.38873973488808, 38.515455275774, 38.95618222653866, 39.92943540215492, 38.04626025259495, 38.066186383366585, 39.38716270029545, 39.943319857120514, 39.88321468234062, 39.84600327908993, 38.18747207522392, 38.69303494691849, 40.92050962150097, 41.610723584890366, 40.124995708465576, 39.90595266222954, 37.992766723036766, 36.97892412543297, 37.80531898140907, 38.461262583732605, 37.013403475284576, 40.10484538972378, 38.408225029706955, 40.31629264354706, 43.51065583527088, 45.949304178357124, 48.70379917323589, 49.593244045972824, 49.44030225276947, 49.12567153573036, 50.84789492189884, 51.54713340103626, 50.833645686507225, 50.4759556800127, 50.03850415349007, 50.46957202255726, 55.413619726896286, 36.77095368504524, 1.0101432586088777, 0.41166815848555416, 0.24467929091770202, 14.276960603892803, 15.108366440981627, 1.2583603081293404, 0.7929530879482627, 11.003268118947744, 47.39185877144337, 27.298571169376373, 38.507490903139114, 42.62164033949375, 36.94886013865471, 3.668142193928361, 0.3427760145859793, 0.017500925750937313, 0.04071237359312363, 0.01581059164891485, 0.03491949537419714, 0.09491907738265581, 0.0821916529093869, 0.01729907457047375, 0.018132281911675818, 0.03682161986944266, 0.04854377933952492, 0.07535673255915754, 0.0597779024974443, 0.021570217941189185, 0.04378748475573957, 0.031034921885293443, 0.021914420467510354, 0.014373761277965968, 0.02350824754103087, 0.0106596192199504, 0.06904248817590997, 0.026041375676868483, 0.02627400743222097, 0.017250642013095785, 0.027628419520624448, 0.06916723577887751, 0.026160586858168244, 0.03893573142704554, 0.04805276701517869, 0.03612516993598547, 0.015796813677297905, 0.07833303418010473, 0.06988651788560674, 0.1126180675055366, 0.044355309364618734, 0.020367959114082623, 0.07089266975526698, 0.030285554967122152, 0.024263798404717818, 0.12628668366232887, 0.012933873258589301, 0.01970562014321331, 0.007852212784200674, 0.07408962672343478, 6.062678704038262, 46.12289786338806, 27.715507596731186, 50.90092867612839, 38.06614078581333, 51.197286173701286, 22.22399666905403, 0.8563025167677552, 1.2300353217869997, 2.3164238641038537, 4.876032778993249, 8.072151001542807, 3.0887518962845206, 0.6145268934778869, 27.24361851811409, 59.76453445851803, 64.76932570338249, 61.615031361579895, 57.46597699820995, 53.58458027243614, 47.754750698804855, 52.00629696249962, 60.883730202913284, 60.416769459843636, 61.501341462135315, 59.360220953822136, 59.660515040159225, 56.2144685536623, 57.409846410155296, 56.61230340600014, 59.64346535503864, 56.032515317201614, 58.34420867264271, 56.36628180742264, 54.32943530380726, 46.26154862344265, 42.473018914461136, 44.2160651832819, 44.24853824079037, 45.309844091534615, 45.394302159547806, 43.724018186330795, 45.25314353406429, 43.26900780200958, 42.332555651664734, 43.61643075942993, 43.369022235274315, 41.592929139733315, 43.966798558831215, 41.94684594869614, 44.6492837369442, 51.76074653863907, 55.415626019239426, 59.28341567516327, 58.56884881854057, 56.68285422027111, 56.85518637299538, 57.52754129469395, 56.54096603393555, 56.011764630675316, 53.94526071846485, 50.33185601234436, 51.09235480427742, 56.166298538446426, 54.97812129557133, 56.20024211704731, 57.69640803337097, 58.741211369633675, 54.71802905201912, 49.370503798127174, 44.1866509616375, 42.161678820848465, 42.63446845114231, 46.593369618058205, 49.16976056993008, 54.55158658325672, 54.04281668365002, 56.816295459866524, 53.8906804472208, 44.915299862623215, 40.65404511988163, 39.78916592895985, 40.99606856703758, 41.63830630481243, 40.423264503479004, 41.366047114133835, 41.53934821486473, 42.107269540429115, 40.784735307097435, 41.33343726396561, 40.05732513964176, 41.852964386343956, 41.37007109820843, 44.531303867697716, 41.47593341767788, 39.676460176706314, 39.14045713841915, 40.910953134298325, 39.42556343972683, 39.2987946420908, 38.222358003258705, 40.894249230623245, 38.61476294696331, 41.00782133638859, 43.69301185011864, 48.19326996803284, 48.68069261312485, 50.589896366000175, 49.70447167754173, 51.56270496547222, 51.126788556575775, 53.66870015859604, 52.81666427850723, 52.73065969347954, 51.584462597966194, 52.93174870312214, 55.632681772112846, 39.875447899103165, 0.7199261721689254, 1.8119933316484094, 4.153024675324559, 11.488088853657246, 7.397072575986385, 0.7632285892032087, 0.6019676174037158, 12.108927089720964, 51.39988750219345, 33.57873357832432, 47.17791885137558, 45.689724907279015, 44.37952481210232, 6.640919325873256, 0.6876673281658441, 0.060876882198499516, 0.03415051534830127, 0.032407596372650005, 0.04275596627849154, 0.03962075228628237, 0.1197755103930831, 0.025034769241756294, 0.013269952050904976, 0.03772259828110691, 0.020935642714903224, 0.01675786894338671, 0.020836495496041607, 0.024344343692064285, 0.06086755711294245, 0.009943798304448137, 0.019101550897175912, 0.06654762517428026, 0.007964585074660135, 0.17772100574802607, 0.15182772564003244, 0.11247795744566247, 0.29634639504365623, 0.13497472449671477, 0.17049649497494102, 0.2675399329746142, 0.10913707577856258, 0.1852329057874158, 0.14254906884161755, 0.16367467353120446, 0.09267173547414131, 0.14228085667127743, 0.25556398497428745, 0.13640862802276388, 0.174993880209513, 0.11506883209221996, 0.20516647287877277, 0.1359966618474573, 0.1354965433711186, 0.2373279322637245, 0.09371812659082934, 0.1736583557794802, 0.08713726565474644, 0.18795434647472575, 6.24475828371942, 54.78740192949772, 35.893166586756706, 50.059452429413795, 41.71574614942074, 52.07143306732178, 28.53665303438902, 1.344078246038407, 2.7236738987267017, 5.228796824812889, 17.075588330626488, 14.239427167922258, 2.431094110943377, 0.89307249058038, 27.704231701791286, 62.16892383992672, 67.85011678934097, 65.3969456255436, 61.38486631214619, 58.23070116341114, 51.01280987262726, 54.582554921507835, 63.35610553622246, 63.124333173036575, 62.30143412947655, 61.79256923496723, 60.553508922457695, 57.55078464746475, 58.542284443974495, 60.530200973153114, 60.375917851924896, 59.271928891539574, 60.74892483651638, 58.70034076273441, 56.61198802292347, 48.53356830775738, 43.623353987932205, 45.427599772810936, 46.39866806566715, 49.719712659716606, 48.381846249103546, 47.024855464696884, 47.78877027332783, 46.46088592708111, 44.71436284482479, 46.06443040072918, 46.47015742957592, 43.73192936182022, 45.17592787742615, 43.5126431286335, 47.6766686886549, 52.62903794646263, 56.88344165682793, 60.364860445261, 61.00372776389122, 58.16339537501335, 58.84265452623367, 60.34909889101982, 59.213643819093704, 59.36098851263523, 56.18413858115673, 51.776838675141335, 53.7378716468811, 59.06610533595085, 56.58100828528404, 58.24614353477955, 60.498035699129105, 61.00404694676399, 58.32530848681927, 51.02882981300354, 47.088141068816185, 43.46236042678356, 46.815406903624535, 50.83317071199417, 52.311219200491905, 56.00193075835705, 56.03878878057003, 59.35615137219429, 55.21866358816624, 46.06278508901596, 41.53343193233013, 40.68378992378712, 42.97473259270191, 43.1679218262434, 42.419115006923676, 42.7970465272665, 44.533420354127884, 43.50711062550545, 44.1815060377121, 43.336119800806046, 42.46738001704216, 43.54049563407898, 44.473463371396065, 46.89785107970238, 43.86472463607788, 43.559658005833626, 42.5615693628788, 42.33827814459801, 42.31139458715916, 41.45165652036667, 40.545899122953415, 44.48359362781048, 41.897691786289215, 42.82790087163448, 47.85852313041687, 50.9765750169754, 53.5089947283268, 52.87133954465389, 54.369086176157, 53.404279947280884, 53.724469766020775, 55.73096349835396, 55.316968113183975, 52.93560549616814, 52.89448790252209, 55.29105730354786, 57.287682965397835, 38.340284675359726, 1.1804755311459303, 1.626798512879759, 6.788174249231815, 31.08366586267948, 30.90228259563446, 6.756205139681697, 0.9319723094813526, 15.868391208350658, 59.88187216222286, 37.46502444148064, 50.78964784741402, 47.39305950701237, 54.73544351756573, 6.918320115655661, 0.8140075206756592, 0.11250567666138522, 0.19576166581828147, 0.12706323730526492, 0.1373349322238937, 0.2016017001005821, 0.28279388789087534, 0.19345107808476314, 0.1144215754175093, 0.1540764034143649, 0.24626266298582777, 0.12328980970778503, 0.16185767337447032, 0.09424931879038922, 0.1308742695255205, 0.14324011222925037, 0.09766283445060253, 0.14037116226973012, 0.0968731522152666], [0.023209507126011886, 0.01589672901900485, 0.07528206508141011, 0.023444070320692845, 0.023322404485952575, 0.03381065995199606, 0.0581976177636534, 0.033539219439262524, 0.053541880479315296, 0.06610670039663091, 0.03353251413500402, 0.0385492060740944, 0.0947945895313751, 0.028652306864387356, 0.07369763174210675, 0.026185009082837496, 0.03689235767524224, 0.0259283002014854, 0.0674595836608205, 0.035064254989265464, 0.09419816255103797, 0.05602382640063297, 0.05933891472523101, 0.020666378550231457, 0.06675109980278648, 0.15466221026144922, 15.921315718442202, 37.800200656056404, 24.490972124040127, 44.48091097176075, 29.411001317203045, 33.7841809540987, 0.5473606288433075, 1.1484362441115081, 3.126921560615301, 1.7961972230114043, 7.743106707930565, 5.447283675894141, 0.17268173396587372, 5.467395521700382, 51.16940326988697, 65.73231562972069, 59.03751567006111, 57.44614586234093, 53.73167797923088, 48.74228350818157, 54.05170440673828, 58.49586233496666, 57.904237881302834, 57.08643436431885, 58.554907366633415, 55.74512533843517, 56.43809415400028, 56.49076692759991, 59.22541178762913, 57.434096708893776, 56.5068818628788, 58.10700260102749, 55.55569030344486, 49.14957605302334, 41.88435070216656, 41.842579543590546, 42.55219906568527, 43.645100221037865, 42.49197609722614, 42.36522249877453, 45.216099321842194, 42.55092993378639, 42.29554183781147, 43.727798983454704, 42.70882286131382, 41.013315841555595, 42.120458632707596, 40.91724559664726, 42.96617165207863, 43.50591368973255, 50.15536688268185, 52.966182455420494, 55.84891676902771, 53.194857984781265, 57.202328145504, 56.502265110611916, 53.488601222634315, 55.68243250250816, 53.99231739342213, 55.97846321761608, 51.85195304453373, 52.767650708556175, 52.74942308664322, 55.82595840096474, 56.80170804262161, 56.04054428637028, 54.7721191495657, 50.24232141673565, 44.22439433634281, 44.95091535151005, 46.05491191148758, 52.506277933716774, 52.18262270092964, 52.75460220873356, 55.343585684895515, 56.740234941244125, 53.6883907020092, 53.30653019249439, 47.238738387823105, 36.3717395067215, 38.725017830729485, 40.28679862618446, 37.529586777091026, 38.1414907425642, 39.14785534143448, 38.31313893198967, 39.05651584267616, 37.71237596869469, 38.52442279458046, 39.37361262738705, 38.90853278338909, 39.58519667387009, 39.36004735529423, 41.822452023625374, 39.25991892814636, 37.890445813536644, 39.12642069160938, 38.655036985874176, 37.90057227015495, 37.150253131985664, 39.53273668885231, 37.77628853917122, 45.933158844709396, 50.271009877324104, 52.733410745859146, 51.51404857635498, 50.6050119549036, 51.00366376340389, 51.78833685815334, 51.96049802005291, 52.48701296746731, 50.344216749072075, 53.51608134806156, 50.490774884819984, 51.83758221566677, 47.83460721373558, 11.2502377666533, 0.10398317928775214, 0.5853182170540094, 2.2666923701763153, 6.595735475420952, 6.826122337952256, 0.6440966692753136, 0.2699540206231177, 21.095196940004826, 38.640757352113724, 35.242052525281906, 25.127909146249294, 38.36589150130749, 21.21281012892723, 0.43617167801130563, 0.10805296871694736, 0.06139300880022347, 0.05915608664508909, 0.073778978548944, 0.08395840966841206, 0.022866842700750567, 0.05491710609931033, 0.011830478706542635, 0.044780270545743406, 0.04358009529823903, 0.04015708385850303, 0.03514783566060942, 0.027277892040729057, 0.02663540366484085, 0.041356572619406506, 0.019630755996331573, 0.005779980619990965, 0.10113259748322889, 0.028044699429301545, 0.06712836315273307, 0.02380851121415617, 0.0805706242681481, 0.016219819299294613, 0.028524073022708762, 0.04216992936562747, 0.025599161417630967, 0.030593254959967453, 0.03437638428295031, 0.08071581803960726, 0.026432058912178036, 0.043913794579566456, 0.05434253907878883, 0.014830852815066464, 0.03472099684586283, 0.06635293015278876, 0.07354831162956543, 0.019104701314063277, 0.045221351174404845, 0.03050671311939368, 0.06241991854039952, 0.06629766983678564, 0.04416253650560975, 0.01816154850530438, 0.08123477222397923, 0.21027164737461135, 23.475292325019836, 41.29325442016125, 28.0812930688262, 52.008652836084366, 35.131767243146896, 36.72503314912319, 0.32427727128379047, 0.7033744978252798, 0.38138120085932314, 3.272509085945785, 8.518088422715664, 7.2578793950378895, 0.33023739990312606, 7.54666437394917, 53.64745169878006, 67.07463160157204, 61.23037800192833, 60.58799207210541, 54.27803926169872, 52.371236979961395, 55.65487638115883, 60.30327335000038, 60.44521853327751, 58.79687838256359, 58.284411281347275, 58.92094172537327, 57.69877530634403, 57.27922081947327, 59.959076419472694, 58.82315017282963, 58.76578465104103, 58.46770204603672, 56.773274168372154, 51.24775126576424, 44.65917460620403, 44.49241295456886, 46.49939306080341, 45.554151982069016, 43.85428659617901, 44.23200532793999, 45.36188989877701, 43.01484324038029, 43.55631798505783, 44.71396006643772, 44.25485350191593, 44.30030666291714, 43.8022255897522, 41.62226356565952, 41.349214017391205, 44.517009034752846, 50.88908091187477, 54.38047036528587, 56.60623513162136, 55.918217450380325, 58.65412004292011, 58.163064792752266, 56.60311169922352, 57.69173048436642, 57.306092977523804, 57.360433861613274, 52.96061955392361, 55.692270174622536, 55.38638278841972, 55.21932855248451, 58.61512653529644, 58.902702704072, 56.48782208561897, 51.84594176709652, 45.142713859677315, 46.89708732068539, 46.83360792696476, 52.36978925764561, 54.35722701251507, 56.524113938212395, 56.211702302098274, 55.74854515492916, 57.200283855199814, 54.83338326215744, 46.9320872426033, 38.287889286875725, 41.31587080657482, 40.661089941859245, 40.048247426748276, 40.57858116924763, 40.76254449784756, 39.08622644841671, 41.037942320108414, 38.346911519765854, 39.92171421647072, 39.38020147383213, 40.6499869376421, 41.535046845674515, 41.16979144513607, 43.17829146981239, 41.10191948711872, 40.299406349658966, 41.131189316511154, 39.55822952091694, 40.22730901837349, 38.969257324934006, 40.948761105537415, 40.052921175956726, 48.09563420712948, 51.62786766886711, 52.6064595580101, 53.654538318514824, 53.17296735942364, 51.609408259391785, 52.238304913043976, 54.17378045618534, 53.16328927874565, 52.24606029689312, 55.10894447565079, 52.09570996463299, 52.5220812857151, 51.58822439610958, 14.053324554115534, 0.11338881755364127, 2.7747892308980227, 5.0239569414407015, 8.812053948640823, 3.9840679289773107, 0.8009588427376002, 0.29984547290951014, 24.16845493018627, 45.381747633218765, 42.04341396689415, 28.568212240934372, 40.95998950302601, 29.87030927091837, 0.9885040728840977, 0.1591251153149642, 0.0402194131311262, 0.03440397362282965, 0.057585761533118784, 0.041144374044961296, 0.029056834864604753, 0.04804956835869234, 0.05738985681091435, 0.006309600394160952, 0.10284853196935728, 0.02189024686231278, 0.044438945697038434, 0.05684319825377315, 0.050348567456239834, 0.00918375651963288, 0.05706996889784932, 0.02679531608009711, 0.047512565142824315, 0.012023830440739403, 0.10923757741693407, 0.13056191441137344, 0.16607198864221573, 0.14378701569512486, 0.14674074860522524, 0.1671922011882998, 0.30824400193523616, 0.20017224946059287, 0.1618490050896071, 0.16580177267314866, 0.10030649063992314, 0.12248723636730574, 0.18536882271291688, 0.16648184711812064, 0.18891124200308695, 0.1437488989904523, 0.18641161441337317, 0.1431708550080657, 0.15056620817631483, 0.1480290576000698, 0.08877646207110956, 0.29756158764939755, 0.15240352833643556, 0.0861209315189626, 0.23978056706255302, 0.18925831478554755, 24.57062914967537, 55.53989835083485, 34.30333949625492, 55.476228967309, 41.38907007873058, 42.74985305964947, 0.7301616354379803, 2.843785691075027, 7.736142156645656, 5.9960530791431665, 15.78795712441206, 10.801900774240494, 0.266377967200242, 6.877911658957601, 55.64047135412693, 70.49405291676521, 63.69801118969917, 61.97370171546936, 59.03371587395668, 52.61424534022808, 59.45930063724518, 63.03636409342289, 63.36650937795639, 59.857701659202576, 61.547801569104195, 60.04720889031887, 59.096207320690155, 60.21109789609909, 62.786443904042244, 59.61435131728649, 62.412429973483086, 60.97242124378681, 59.474511221051216, 54.72033552825451, 47.066907808184624, 47.72690959274769, 49.600695446133614, 49.122639298439026, 45.81807442009449, 45.40722146630287, 49.06043283641338, 46.37128673493862, 46.71162307262421, 47.81144365668297, 47.50468231737614, 45.37887878715992, 45.57697735726833, 44.09056931734085, 44.89757761359215, 47.27231338620186, 54.50675278902054, 56.83087147772312, 60.11820428073406, 58.44949722290039, 60.477197617292404, 60.48504799604416, 59.56347204744816, 60.975297689437866, 59.18821558356285, 60.59660620987415, 57.1037158370018, 56.748491898179054, 56.87143050134182, 57.5697760283947, 59.78187292814255, 60.74579380452633, 58.06107446551323, 54.55681510269642, 47.28137210011482, 49.56278868019581, 49.42243941128254, 57.1656297147274, 56.123585030436516, 58.05874139070511, 57.886652424931526, 60.105034187436104, 58.58471676707268, 56.97107255458832, 50.29903717339039, 40.676927492022514, 42.81794920563698, 43.447852805256844, 41.03034272789955, 43.050652518868446, 43.96306335926056, 40.52550941705704, 42.893682941794395, 40.28831474483013, 42.594460397958755, 42.76530683040619, 44.26012381911278, 45.49792639911175, 43.39686334133148, 45.88221877813339, 43.91328223049641, 42.703012973070145, 43.98100219666958, 41.970340088009834, 42.17291481792927, 41.35076813399792, 44.37641277909279, 40.4545634239912, 51.061352267861366, 52.73247219622135, 54.76113773882389, 56.71065732836723, 56.28540314733982, 53.738525211811066, 55.19391551613808, 57.252876833081245, 56.634957790374756, 54.90376688539982, 57.707712426781654, 53.88721503317356, 53.889088332653046, 50.09594187140465, 14.502496551722288, 0.29462568112649024, 3.09541008900851, 5.909726461395621, 15.544556435197592, 17.05361220985651, 3.13490089494735, 0.4865056771086529, 27.98099935054779, 52.078686878085136, 48.05099420249462, 33.34126152098179, 49.172108843922615, 34.16772477328777, 1.0912673617713153, 0.3018835885450244, 0.17729504266753793, 0.08091708848951384, 0.2401101845316589, 0.17776019114535302, 0.11155534913996235, 0.14153611147776246, 0.16044348129071295, 0.15603136882418767, 0.22562680154806003, 0.17175427201436833, 0.13316048512933776, 0.20173310476820916, 0.11936884315218776, 0.16829296946525574, 0.1454744813963771, 0.12276963840122335, 0.1578817210975103, 0.13437459419947118], [0.045348848434514366, 0.033561587770236656, 0.036250411067157984, 0.029246861777210142, 0.027563735784497112, 0.017829144271672703, 0.029829271443304606, 0.04387759632663801, 0.03918027279723901, 0.012251540829311125, 0.016676382983860094, 0.020959693865734152, 0.024929708961280994, 0.07056275542709045, 0.02420748980512144, 0.0051326302491361275, 0.016363612267014105, 0.04167089442489669, 0.04489744453167077, 0.07284170540515333, 0.038175675726961344, 0.03724860340298619, 0.022146232149680145, 0.033919195338967256, 0.05553733375563752, 0.10645936985383742, 0.9885247936472297, 39.02991347014904, 26.439596861600876, 36.53582990169525, 36.47938013076782, 36.299870163202286, 7.944136820733547, 0.7284218037966639, 1.0093437577597797, 3.242515157908201, 7.18482973985374, 3.266433924436569, 0.5216169508639723, 0.11949934982112609, 24.795578978955746, 66.05418875813484, 61.823134794831276, 56.82717427611351, 56.124287992715836, 53.66744622588158, 54.91370715200901, 58.4896382689476, 62.01928406953812, 60.40923446416855, 59.86157365143299, 59.729219153523445, 54.78560082614422, 55.35329036414623, 57.70606331527233, 56.02869652211666, 59.75275129079819, 54.253937155008316, 51.03520967066288, 42.13865205645561, 41.33436441421509, 42.612296640872955, 42.986234575510025, 41.73784576356411, 44.674791768193245, 44.77540656924248, 47.206512317061424, 47.41329342126846, 47.11128182709217, 43.186894208192825, 42.921448051929474, 42.00018748641014, 41.250024139881134, 41.63703337311745, 41.012954860925674, 42.664391845464706, 46.70626915991306, 51.07203349471092, 56.141721457242966, 55.59730187058449, 52.7745321393013, 57.064349949359894, 54.2227940261364, 54.806503504514694, 53.30709636211395, 55.906495079398155, 55.05434900522232, 53.77445228397846, 54.937687665224075, 54.59456227719784, 55.16148045659065, 57.065535485744476, 55.3590926527977, 49.28346946835518, 46.87833912670612, 49.406871646642685, 52.07879327237606, 52.08806857466698, 56.38026885688305, 53.695777505636215, 54.95270065963268, 54.253868758678436, 53.97233806550503, 54.432599768042564, 44.32389199733734, 37.45726905763149, 38.74041460454464, 38.077274188399315, 39.25375185906887, 40.36685273051262, 39.27019737660885, 38.56534279882908, 38.43228153884411, 38.66900123655796, 38.51595684885979, 37.71634675562382, 39.55627262592316, 37.72030234336853, 40.21770313382149, 41.903239488601685, 39.30858291685581, 36.87426634132862, 36.047442108392715, 37.20745526254177, 36.68179526925087, 37.59813129901886, 36.854169219732285, 41.37963518500328, 51.40377089381218, 50.97555287182331, 53.41100178658962, 51.04329563677311, 52.1667243540287, 50.04898019134998, 51.66656859219074, 48.599046394228935, 52.92566902935505, 52.04561725258827, 54.711318612098694, 50.59049293398857, 55.52866995334625, 24.313001073896885, 1.0383538948372006, 0.14605837350245565, 1.7984907561913133, 4.885417800396681, 5.824921661987901, 1.9898152397945523, 0.26725304836872965, 0.08427211549133062, 18.91528431326151, 37.52753488719463, 30.661690905690193, 22.317017577588558, 42.66548238694668, 5.230269720777869, 0.4005905654048547, 0.03478831335087307, 0.05296793686284218, 0.06101187515014317, 0.0607275843503885, 0.05964693569694646, 0.027066428192483727, 0.013848525741195772, 0.04293064928788226, 0.06284254195634276, 0.05060212963144295, 0.03666734221042134, 0.07149189463234507, 0.06741893623257056, 0.15473286272026598, 0.03442924746195786, 0.06381566825439222, 0.01896896807011217, 0.0472807144979015, 0.10378657694673166, 0.04930225797579624, 0.05275771611195523, 0.009317743861174677, 0.014491873153019696, 0.02251048008474754, 0.02262807152874302, 0.07208357186755165, 0.03790964176005218, 0.03653355895949062, 0.009915397240547463, 0.04937492165481672, 0.04237820940033998, 0.013181145732232835, 0.03731645425432362, 0.03166557857184671, 0.009547411664243555, 0.01023251972583239, 0.07311133507755585, 0.05101261893287301, 0.035493390751071274, 0.0045501806926040445, 0.10192405345151201, 0.0365800841973396, 0.050113325196434744, 0.06458498595748097, 0.13771326426649466, 2.700162660330534, 49.13588918745518, 26.35155748575926, 45.19369952380657, 42.93744519352913, 42.90263906121254, 7.328616874292493, 0.5791110720019788, 1.022301537450403, 2.523314212448895, 6.784942522644997, 6.382270529866219, 2.443183637224138, 0.12477776384912431, 27.88066003471613, 67.19555631279945, 63.13841141760349, 58.99321764707565, 58.80430318415165, 54.533993527293205, 57.693478390574455, 60.5293308198452, 64.20298889279366, 61.54452994465828, 60.65716356039047, 60.483208894729614, 56.00982293486595, 56.93593204021454, 57.46422529220581, 57.8471839427948, 59.77923966944218, 57.80654512345791, 54.630618542432785, 43.96321915090084, 43.79464499652386, 43.531976491212845, 44.686909317970276, 44.945956617593765, 47.0392756909132, 46.7737003415823, 48.00840988755226, 47.36794285476208, 46.93037733435631, 43.99678274989128, 45.01667082309723, 43.17793428897858, 44.62727531790733, 42.804680317640305, 43.65848310291767, 43.61064366996288, 50.119375213980675, 53.11996400356293, 56.82940475642681, 57.43616379797459, 56.05762057006359, 58.49985212087631, 56.8712443113327, 57.925239354372025, 54.012870490550995, 58.67236666381359, 55.429396480321884, 55.43310508131981, 57.079735323786736, 54.910059347748756, 58.099676594138145, 57.016647309064865, 56.07508063316345, 51.39920733869076, 49.2441263794899, 51.00793853402138, 54.15108047425747, 55.435434356331825, 55.808376744389534, 55.491549745202065, 55.43883137404919, 55.96846975386143, 55.32530106604099, 55.60573361814022, 46.98802404105663, 39.39358815550804, 40.44919811189175, 39.83906105160713, 40.57046860456467, 43.074336647987366, 40.994647443294525, 41.49459421634674, 39.887812435626984, 38.83354380726814, 41.6287612169981, 40.596466809511185, 39.87570248544216, 40.09585127234459, 40.56470051407814, 43.63122336566448, 42.407890409231186, 39.28589813411236, 38.87376464903355, 39.80112008750439, 38.56528960168362, 41.19443692266941, 39.73662614822388, 43.03582191467285, 52.235766649246216, 52.17276223003864, 54.86058600246906, 53.60376924276352, 54.09491948783398, 53.760966807603836, 51.975362822413445, 51.14834479987621, 54.13497693836689, 53.60167555510998, 54.44661341607571, 53.046935722231865, 53.76193195581436, 27.79030278325081, 1.5862200153060257, 1.2986943125724792, 4.680132865905762, 7.22378714941442, 6.163136288523674, 2.0326764648780227, 0.4085081530502066, 0.12465677893487737, 22.348270900547504, 45.24048641324043, 39.47952814400196, 22.820224575698376, 48.064787462353706, 9.355538785457611, 0.4590874764835462, 0.030092602137301583, 0.0836393678036984, 0.09447877600905485, 0.02710168391786283, 0.0733659511024598, 0.05617175869701896, 0.03475007048109546, 0.0881282554473728, 0.04646823348593898, 0.01612183539691614, 0.016001837539079133, 0.023890136326372158, 0.07222247964818962, 0.02033795779425418, 0.023774227702233475, 0.09250838877051137, 0.03479396480543073, 0.016900034752325155, 0.06821808085078374, 0.20582333294441923, 0.11509682590258308, 0.16207064007176086, 0.06929705225047655, 0.13137973146513104, 0.056443685316480696, 0.17449103062972426, 0.15786055504577234, 0.16155587160028517, 0.08260079892352223, 0.1806642595329322, 0.0977235050231684, 0.12171016322099604, 0.13585635140771046, 0.159519596491009, 0.08304290371597745, 0.13351828936720267, 0.15889910166151822, 0.29902249050792307, 0.12906366668175906, 0.0949866276641842, 0.13129582424880937, 0.16459599049994722, 0.14381201122887433, 0.09958110807929188, 0.180482997384388, 2.52286939881742, 56.17032252252102, 36.604750603437424, 45.92566564679146, 46.78914651274681, 47.80404545366764, 10.333318468183279, 0.8258731558453292, 3.493938404135406, 8.769827764481306, 18.643849678337574, 10.159487295895815, 1.7355536646209657, 0.22199669008841738, 28.286204673349857, 68.43035325407982, 66.82950675487518, 62.22156621515751, 60.87976321578026, 58.66421230137348, 60.05631700158119, 62.583709582686424, 65.56406065821648, 64.41169649362564, 62.435171753168106, 62.290730103850365, 57.61447302997112, 59.37529094517231, 60.51073081791401, 59.391383081674576, 62.231639474630356, 59.173194989562035, 56.23005911707878, 46.86929181218147, 45.209601670503616, 46.34976848959923, 47.68680654466152, 46.72999128699303, 49.848597943782806, 50.95203593373299, 51.055880561470985, 49.66140478849411, 50.29560975730419, 46.24552868306637, 46.59617766737938, 45.14841355383396, 48.183888271450996, 46.416679099202156, 46.25547654926777, 46.31003402173519, 51.72696255147457, 54.318241104483604, 60.72931028902531, 59.35506083071232, 56.873091012239456, 60.36713272333145, 59.18626628816128, 57.335814982652664, 56.853803247213364, 60.61530500650406, 57.89244331419468, 56.642587780952454, 59.45275358855724, 57.08152122795582, 58.71155396103859, 61.57864071428776, 59.256152138113976, 54.51086796820164, 51.52781903743744, 53.66990849375725, 57.0415435731411, 58.178643956780434, 59.21707883477211, 58.24510619044304, 57.976905182003975, 57.41920530796051, 56.519235000014305, 56.37592948973179, 49.382123574614525, 41.1387775093317, 42.24652826786041, 40.84917604923248, 42.26627200841904, 44.12772752344608, 42.73095287382603, 43.767297863960266, 42.22483143210411, 42.33526110649109, 43.76177676022053, 41.11484259366989, 41.79273001849651, 42.08170831203461, 44.91898946464062, 47.3034755140543, 44.62419368326664, 41.32649123668671, 39.75114896893501, 41.63580223917961, 40.43189384043217, 42.783192470669746, 41.56687393784523, 44.58946734666824, 56.0809551179409, 53.72159332036972, 57.84714974462986, 54.98900771141052, 55.694705843925476, 54.16067495942116, 53.75874012708664, 52.59065620601177, 55.66290155053139, 53.705337792634964, 54.22516509890556, 53.19364205002785, 55.980283319950104, 27.309024408459663, 1.3951860973611474, 0.832780710188672, 5.690864380449057, 11.967911906540394, 15.510811395943165, 8.313191067427397, 1.2330543785355985, 0.25828279845882207, 26.52355145663023, 50.40422312915325, 43.10046784579754, 31.09074678272009, 59.44991514086723, 11.206045188009739, 0.5379001458641142, 0.256797315669246, 0.19825381255941465, 0.21573673380771652, 0.2190419181715697, 0.18410215474432334, 0.16856274014571682, 0.14619817928178236, 0.1806575950467959, 0.11017868004273623, 0.08645312424050644, 0.13408592843916267, 0.10074842473841272, 0.1673304633004591, 0.2376025269040838, 0.16143445624038577, 0.24932059342972934, 0.14566919126082212, 0.15100279881153256, 0.32231506251264364], [0.03568778520275373, 0.02577038416347932, 0.014322337865451118, 0.02786264132737415, 0.02810660382237984, 0.09045662503922358, 0.03580169373890385, 0.01690249682724243, 0.025162233105220366, 0.04949155016220175, 0.020794365627807565, 0.01276650318686734, 0.0064158355871768435, 0.03134917875286192, 0.06653877135249786, 0.03828257096756715, 0.019940372585551813, 0.058025250255013816, 0.0480777068878524, 0.03148125506413635, 0.011873348867084133, 0.07597445917781442, 0.027027027572330553, 0.0514630728866905, 0.010801909338624682, 0.05913355133088771, 0.18448982300469652, 11.799475494772196, 42.95017451047897, 19.99452520161867, 38.22155624628067, 33.58524642884731, 16.81384887546301, 0.03137627456453629, 0.34169209306128323, 0.9580063750036061, 6.029753470793366, 4.47195153683424, 3.31635398324579, 0.30360928969457746, 0.9069390746299177, 48.9012935757637, 64.41957727074623, 62.30592168867588, 60.95385544002056, 56.46505370736122, 60.02024933695793, 58.91564480960369, 61.83373622596264, 60.02830870449543, 56.27364657819271, 55.2481310069561, 54.94214482605457, 57.13386341929436, 58.22598561644554, 57.01557196676731, 57.021047472953796, 53.831118643283844, 43.22067819535732, 40.27056969702244, 41.36039301753044, 44.2673472315073, 43.037402629852295, 43.32435563206673, 46.56363621354103, 48.47394950687885, 53.01495283842087, 51.78072206676006, 53.56320641934872, 51.5335301309824, 46.42851546406746, 41.868330761790276, 42.57136143743992, 40.73615871369839, 41.321730092167854, 42.31032684445381, 46.03315807878971, 51.02044366300106, 50.668958723545074, 51.55679248273373, 53.45495022833347, 54.674076810479164, 52.67929024994373, 50.966638550162315, 54.88739736378193, 54.03634563088417, 56.10716991126537, 56.03346526622772, 56.729979291558266, 54.949539229273796, 56.87281362712383, 56.936255022883415, 54.193790182471275, 50.4575152695179, 52.14880831539631, 53.037375435233116, 62.08373621106148, 62.01743736863136, 55.06649315357208, 55.89098051190376, 53.35302449762821, 56.513523906469345, 54.52475242316723, 53.224211409687996, 42.777127996087074, 37.92870596051216, 38.74285027384758, 39.443300887942314, 38.42676803469658, 39.45968560874462, 38.17217789590359, 38.637918904423714, 40.198791548609734, 39.36244122684002, 38.51409874856472, 39.01027612388134, 38.50940980017185, 38.44480186700821, 38.13260681927204, 40.29365725815296, 39.855039194226265, 38.0448467284441, 39.311577156186104, 38.97909499704838, 37.005556896328926, 38.17444257438183, 38.12316432595253, 42.37884856760502, 45.05691446363926, 51.514154970645905, 51.66712336242199, 51.54736518859863, 51.768452525138855, 52.21564292907715, 48.738084733486176, 51.33476659655571, 48.52034501731396, 49.13285315036774, 49.48376812040806, 50.7612519711256, 31.182585954666138, 2.666110312566161, 0.6476384354755282, 0.3911032760515809, 3.7375362077727914, 6.357483034953475, 4.659100044518709, 0.6783330696634948, 0.21273203019518405, 0.4149241087725386, 22.9286365583539, 42.41144701838493, 20.133426748216152, 33.63301366567612, 26.192663311958313, 0.24983982963021845, 0.06907883856911212, 0.06527504228870384, 0.008557728051528102, 0.05448831172543578, 0.01329904795056791, 0.07513908291002735, 0.033982860477408394, 0.02764725337328855, 0.06505823868792504, 0.028264458633202594, 0.013358764863369288, 0.04644483356969431, 0.1005411874211859, 0.03264995582867414, 0.03867230981995817, 0.02802658545988379, 0.005343360298866173, 0.027632677592919208, 0.08231757310568355, 0.028603267601283733, 0.017707997940306086, 0.01374116201986908, 0.04533826911938377, 0.04540125890343916, 0.024715781182749197, 0.03844088962068781, 0.013050696579739451, 0.029259680522955023, 0.04587950257700868, 0.03500346567307133, 0.045039703109068796, 0.042973712406819686, 0.04701771220425144, 0.04342443724453915, 0.03275276183558162, 0.04015430822619237, 0.06135861767688766, 0.03890655018039979, 0.03208361922588665, 0.08193134461180307, 0.0573422183515504, 0.04052237265568692, 0.010353327452321537, 0.06604271242395043, 0.025966936409531627, 0.07008703134488314, 0.3252163255820051, 21.416199915111065, 44.94373753666878, 24.90285862237215, 48.78623574972153, 41.157043129205704, 19.79293841868639, 0.06274387342273258, 0.6992616935167462, 2.0359046291559935, 3.697813614271581, 2.7404112881049514, 5.0896943639963865, 1.2430762220174074, 1.7945259064435959, 51.25044532120228, 67.91815593838692, 61.85928225517273, 63.244368731975555, 58.60288739204407, 61.49845361709595, 61.2245187163353, 64.2430691421032, 60.59150688350201, 57.7640026062727, 58.71460139751434, 57.39702969789505, 56.29163481295109, 59.826151952147484, 59.099319353699684, 60.28238967061043, 55.17808936536312, 48.07863391935825, 43.28723542392254, 42.966802418231964, 45.64099632203579, 45.5743782967329, 44.471723064780235, 49.03473101556301, 50.226882845163345, 54.452092722058296, 53.98914836347103, 55.57049050927162, 51.43057465553284, 47.15557225048542, 43.42857263982296, 44.21012990176678, 41.58690646290779, 43.32168057560921, 42.957515716552734, 46.41653090715408, 53.62173467874527, 53.283556625247, 55.152178555727005, 55.07651701569557, 56.3303205370903, 53.37647683918476, 52.865681648254395, 57.800461649894714, 57.74187259376049, 56.67191080749035, 58.10381077229977, 58.137191981077194, 56.91734343767166, 55.92606782913208, 57.288610115647316, 56.659987047314644, 53.68514947593212, 52.343715056777, 56.11370176076889, 60.48995353281498, 58.59551578760147, 58.184381648898125, 55.44032469391823, 53.90329197049141, 59.47786644101143, 56.94881334900856, 56.42311155796051, 45.47251716256142, 40.29125578701496, 39.55376856029034, 40.476731434464455, 40.255834087729454, 41.34834386408329, 39.94206212460995, 39.11455012857914, 43.06365542113781, 41.84711270034313, 40.626899376511574, 41.3822266459465, 41.28867946565151, 41.65488861501217, 41.21606916189194, 43.39881643652916, 41.26079276204109, 39.83241140842438, 40.84039092063904, 39.90243025124073, 38.69303494691849, 40.156602412462234, 40.36498703062534, 42.580868527293205, 48.23554649949074, 53.29503960907459, 53.371267318725586, 54.14216995239258, 52.70675137639046, 52.853092923760414, 49.069746136665344, 50.803437307477, 49.7161902487278, 48.669551610946655, 50.63581310212612, 52.003542110323906, 34.710578843951225, 3.430982669815421, 1.7323729977943003, 2.5416757771745324, 5.026575475931168, 7.946994267404079, 4.7646218072623014, 0.632604839047417, 0.257481457083486, 0.6774164875969291, 24.307143688201904, 54.70608249306679, 25.131784938275814, 33.73343087732792, 35.93811057507992, 0.6534070603083819, 0.18090896046487615, 0.11066010381910019, 0.06349963208776899, 0.0566132363746874, 0.004450044098120998, 0.01717701910820324, 0.06273467821301892, 0.013676178641617298, 0.100818743230775, 0.04274803271982819, 0.025733091242727824, 0.07974706299137324, 0.04649303235055413, 0.02813100378261879, 0.06722956240992062, 0.008368599137611454, 0.07058747636619955, 0.023816203574824613, 0.04098345045349561, 0.06299899410805665, 0.17438971262890846, 0.09449865814531222, 0.09094771157833748, 0.1167608323157765, 0.07451564917573705, 0.18795758223859593, 0.08397954603424296, 0.06704372863168828, 0.11559112594113685, 0.15264704183209687, 0.17826351569965482, 0.12635346211027354, 0.13955796137452126, 0.13689938059542328, 0.13567458459874615, 0.24527983681764454, 0.15445233089849353, 0.13967716513434425, 0.09960047071217559, 0.21695376693969592, 0.2615259838057682, 0.09884986255201511, 0.11967781407292932, 0.13074813410639763, 0.11570759117603302, 0.16181057668291032, 0.3032544837333262, 23.22705164551735, 60.666822642087936, 28.367698900401592, 48.70537608861923, 47.037934362888336, 22.662086561322212, 0.16551386390347034, 1.3355849892832339, 5.807090168818831, 15.889064949005842, 9.815020579844713, 8.455210346728563, 1.3159196195192635, 1.4209922938607633, 52.865708246827126, 67.51609191298485, 66.10181540250778, 65.62269151210785, 60.60711644589901, 64.6063220500946, 63.11747454106808, 66.05301842093468, 62.6737267524004, 58.53090785443783, 61.050355061888695, 60.387142449617386, 58.86453755199909, 62.09734708070755, 61.81590378284454, 62.19879023730755, 58.34292434155941, 50.03625847399235, 44.38365899026394, 45.2391716837883, 49.51212219893932, 49.37234669923782, 48.70433494448662, 50.23249514400959, 52.552498653531075, 58.74494656920433, 56.59957408905029, 58.45021538436413, 56.87228545546532, 50.80519661307335, 46.04219399392605, 46.93584904074669, 43.60580272972584, 46.14670358598232, 44.91377234458923, 49.90024097263813, 55.544142723083496, 55.190419703722, 57.29418441653252, 58.2366668432951, 58.58809478580952, 55.704361125826836, 55.322154834866524, 61.60806633532047, 57.86859579384327, 59.433127641677856, 61.19109570980072, 59.90876331925392, 59.48585741221905, 59.36753176152706, 61.264701560139656, 56.5539613366127, 56.45927041769028, 55.35021252930164, 58.719465136528015, 64.69457611441612, 61.228968277573586, 59.22888480126858, 56.99072130024433, 57.443391010165215, 60.573419854044914, 60.106029734015465, 59.522582441568375, 48.53423327207565, 43.15764717757702, 41.61002442240715, 43.488218039274216, 43.25431399047375, 43.797164261341095, 42.04795092344284, 40.07429502904415, 44.529529362916946, 43.31447996199131, 42.22898080945015, 42.89510406553745, 42.830826714634895, 43.088209703564644, 43.54241453111172, 46.39394871890545, 42.87858635187149, 42.07499407231808, 43.65399554371834, 44.02634136378765, 41.408905014395714, 41.68437123298645, 43.001703545451164, 46.40610806643963, 50.47066256403923, 56.67005270719528, 55.26728577911854, 54.1768316924572, 54.268007799983025, 52.81122297048569, 50.478607937693596, 51.367973014712334, 49.77560006082058, 50.665778294205666, 51.87491521239281, 53.031774535775185, 33.3608228713274, 3.6869077244773507, 1.5340756508521736, 2.6137061370536685, 10.022109467536211, 15.178054701536894, 15.37204284220934, 3.0512075359001756, 0.5650168564170599, 1.0436740843579173, 33.028469905257225, 56.22352346777916, 29.221174903213978, 44.19807314872742, 41.06139846146107, 0.7025524356868118, 0.25330447184387594, 0.2278629073407501, 0.1900126485270448, 0.10762668651295826, 0.11360767690348439, 0.1518611519713886, 0.2186070493189618, 0.11842758467537351, 0.2612521906848997, 0.21151985070900992, 0.10724000530899502, 0.17143112607300282, 0.20986386691220105, 0.13974400295410305, 0.2383243100484833, 0.10905015544267371, 0.25196139235049486, 0.1529800583375618, 0.18083017406752333, 0.12819067836971954], [0.029832713153155055, 0.15303475462133065, 0.024589213462604675, 0.03239617100916803, 0.03316869850095827, 0.06699934077914804, 0.09527915259241126, 0.005948842872385285, 0.06785790916183032, 0.032729399026720785, 0.011138124500575941, 0.049322852573823184, 0.046073321864241734, 0.014380227239598753, 0.034225698618683964, 0.059120162986801006, 0.07777501334203407, 0.06974320174776949, 0.07620675140060484, 0.05613895205897279, 0.021874348203709815, 0.02269372191221919, 0.05073807253211271, 0.028576017793966457, 0.0462245344533585, 0.02882778582716128, 0.031007863181002904, 0.6984434311743826, 39.09677468240261, 29.689615666866302, 35.242333710193634, 44.070308804512024, 28.385483846068382, 2.310041394084692, 0.41357630921993405, 0.5964040034450591, 1.8261219235137105, 2.7289021806791425, 4.321004161611199, 1.5934918751008809, 0.17230659315828234, 8.205517195165157, 66.84554949402809, 62.81449019908905, 63.396679759025574, 60.36406248807907, 60.81390134990215, 61.412460431456566, 59.04900245368481, 58.55431839823723, 57.28425934910774, 55.413026958703995, 60.31275384128094, 60.260700434446335, 57.520903050899506, 57.52876862883568, 52.4863214045763, 44.60019417107105, 42.853636890649796, 45.81857219338417, 42.1707983314991, 42.48102128505707, 42.05729842185974, 45.17802156507969, 48.5186693072319, 50.1811370998621, 55.20306162536144, 56.09994649887085, 59.84633266925812, 62.153853848576546, 55.56765206158161, 42.80632942914963, 40.78338257968426, 40.959145948290825, 40.48720747232437, 41.70955628156662, 42.696735709905624, 49.24911171197891, 51.695545837283134, 54.5290157943964, 53.48131321370602, 56.745106279850006, 51.576308235526085, 36.96595162153244, 50.99855303764343, 53.22747923433781, 58.28740552067757, 55.690632462501526, 56.022252067923546, 48.75549919903278, 53.74218441545963, 53.275919035077095, 57.57759600877762, 52.98737771809101, 58.205561712384224, 51.02769747376442, 74.37350794672966, 69.81175392866135, 49.91769343614578, 57.221688106656075, 53.27450551092625, 55.53952597081661, 53.284365981817245, 49.7469761967659, 41.237264424562454, 40.24171784520149, 37.77650512754917, 39.05377238988876, 38.69988597929478, 39.52865190804005, 39.74921487271786, 40.43228901922703, 38.76605182886124, 39.94546294212341, 37.82827354967594, 39.4420051574707, 38.269410878419876, 39.002752527594566, 36.96587182581425, 38.98189924657345, 39.60053265094757, 38.52310426533222, 38.285145834088326, 38.004872873425484, 38.280145302414894, 38.50595958530903, 37.13850036263466, 40.71514584124088, 40.54436020553112, 44.803403466939926, 48.157810270786285, 50.751733481884, 51.38015516102314, 52.78146676719189, 52.99622364342213, 53.232760950922966, 52.503355890512466, 50.677724853158, 50.9084864705801, 39.50709566473961, 6.478036791086197, 0.13939733093138784, 2.2825805051252246, 3.2585830707103014, 3.927741413936019, 5.361791113391519, 2.4337929161265492, 0.22829459980130196, 0.12486947845900431, 1.2272094609215856, 33.55824887752533, 34.31562423706055, 20.13602200895548, 38.780183270573616, 5.057371873408556, 0.18930545600596815, 0.07333291068789549, 0.06673563344520517, 0.11446712844190188, 0.02623851421958534, 0.06783488031942397, 0.024888569860195275, 0.029038071515969932, 0.043313382266205736, 0.07318227697396651, 0.010626103830873035, 0.03683353505039122, 0.009691417071735486, 0.059923912631347775, 0.06127262502559461, 0.11288506255368702, 0.007244586331580649, 0.01985650247661397, 0.04177797891316004, 0.1045460018212907, 0.06495503563201055, 0.07533138821600005, 0.038933030009502545, 0.05276595024042763, 0.021793491214339156, 0.029189413980930112, 0.05280828605464194, 0.08068596886005253, 0.05549735426029656, 0.08471417575492524, 0.039654223146499135, 0.028688659112958703, 0.038314223565976135, 0.043976231463602744, 0.054430435338872485, 0.050721667357720435, 0.04449303341971245, 0.004280072334950091, 0.07625738071510568, 0.05301551223965362, 0.04560443296213634, 0.036584058398148045, 0.026532490046520252, 0.028833220203523524, 0.0604925869993167, 0.06671113515039906, 0.07571570196887478, 0.054685700742993504, 2.265639351680875, 52.70139366388321, 23.785239793360233, 38.188931196928024, 52.20398135483265, 28.65565124899149, 2.4297784315422177, 0.4192844044882804, 0.8626060816459358, 1.6400631261058152, 4.543119817972183, 6.23919015750289, 5.525856334716082, 0.3253705141833052, 11.170724183321, 70.222207903862, 63.56538310647011, 68.37328031659126, 62.26844049990177, 64.30124402046204, 61.7402346432209, 60.42133301496506, 58.43285791575909, 59.96138669550419, 57.40946263074875, 60.896809101104736, 61.15534342825413, 58.586267083883286, 59.988490641117096, 55.58400638401508, 47.524137273430824, 44.72436770796776, 47.286638617515564, 44.681069031357765, 44.57552969455719, 44.18277136981487, 49.30176928639412, 50.960722267627716, 54.67137895524502, 57.488752976059914, 58.50118584930897, 62.220585867762566, 62.34982833266258, 54.13477174937725, 44.260952174663544, 42.696530520915985, 43.679830357432365, 43.43521848320961, 45.82874044775963, 46.5798195451498, 50.65579243004322, 53.599023297429085, 56.199200972914696, 53.4816437959671, 58.91442887485027, 54.13596108555794, 43.19505237042904, 51.413277983665466, 55.76201543211937, 59.277161210775375, 56.656848415732384, 57.729956433176994, 50.363451316952705, 54.08614195883274, 54.97756652534008, 57.63136312365532, 55.46040661633015, 58.32373537123203, 53.03089678287506, 66.9910816848278, 67.7614751458168, 53.15182529389858, 58.549169674515724, 56.01937182247639, 57.04959914088249, 54.718918204307556, 52.294462099671364, 44.41155329346657, 40.93693234026432, 39.95952598750591, 41.58745363354683, 41.20978809893131, 40.87146945297718, 41.20122715830803, 41.8266773968935, 41.63900546729565, 39.67699974775314, 39.45791870355606, 40.904501080513, 39.88083600997925, 40.99363669753075, 39.767605885863304, 40.062789246439934, 41.68380506336689, 40.9093876183033, 41.09250359237194, 39.20203283429146, 40.0000736117363, 39.84647445380688, 40.657753720879555, 43.38152356445789, 45.00937141478062, 47.66504131257534, 50.26561416685581, 52.82952658832073, 52.00316973030567, 54.95336942374706, 55.96670664846897, 53.72163511812687, 53.609803318977356, 52.05767400562763, 50.949368476867676, 41.469884142279625, 7.142541809007525, 1.224961169064045, 3.9353811414912343, 5.06449886597693, 5.454483814537525, 4.959296761080623, 2.493286323733628, 0.16818184027215466, 0.07152604826842435, 1.5784700936637819, 39.9298419803381, 43.90114188194275, 19.537550322711468, 45.37935756146908, 8.710337206721306, 0.2728388970717788, 0.13128294056514278, 0.04052291071275249, 0.01857280221884139, 0.013259373663458973, 0.05198904407734517, 0.055232222002814524, 0.028661129144893494, 0.016303952870657668, 0.02369687736063497, 0.04202462427201681, 0.03722986417415086, 0.03210041031707078, 0.03226548622478731, 0.03278030293586198, 0.009646885428082896, 0.030673115616082214, 0.04288990166969597, 0.028776212129741907, 0.04791202984051779, 0.015208955719572259, 0.22092314378824085, 0.16758331301389262, 0.13079984695650637, 0.12010028163786046, 0.14952328288927674, 0.15792455786140636, 0.2232594246743247, 0.13204015383962542, 0.19981733959866688, 0.12609219644218683, 0.13519983272999525, 0.107452830998227, 0.17385214538080618, 0.1251828280510381, 0.14517521776724607, 0.11488830466987565, 0.15848476061364636, 0.3040038450853899, 0.14804648322751746, 0.12987922760657966, 0.11834688353701495, 0.09979470560210757, 0.10468194101122208, 0.16567376704188064, 0.1129340443003457, 0.13783240865450352, 0.10425579981529154, 2.642792626284063, 58.507854491472244, 39.29422728717327, 45.11013440787792, 56.13849923014641, 39.06161516904831, 4.168829927220941, 1.2336033303290606, 3.2381883775815368, 5.1377076376229525, 11.274399720132351, 10.256344098597765, 5.163337737321854, 0.34533713653218, 9.901887718588114, 71.13848313689232, 66.13919019699097, 69.75248470902443, 65.10629922151566, 64.87838745117188, 62.926941365003586, 61.2290670722723, 60.343923568725586, 61.02208837866783, 60.30244119465351, 64.25144389271736, 64.33674171566963, 59.87674243748188, 60.01606576144695, 58.53692673146725, 50.588634833693504, 47.12084971368313, 50.41901953518391, 48.05379845201969, 46.14802211523056, 45.652714893221855, 50.775565803050995, 54.497694075107574, 57.55492262542248, 60.865388587117195, 61.87953136861324, 63.850299417972565, 64.8188142478466, 57.76843696832657, 46.46286182105541, 45.53865261375904, 47.406468987464905, 45.40705047547817, 48.530581668019295, 47.10057780146599, 53.34622286260128, 55.749259516596794, 57.20074363052845, 55.83169989287853, 59.60879601538181, 57.6322902739048, 41.85518726706505, 57.65684075653553, 55.720054283738136, 59.33769956231117, 59.521279111504555, 59.547296315431595, 51.70835494995117, 55.37414364516735, 57.96317271888256, 62.43880435824394, 58.28455947339535, 60.916127264499664, 55.98584622144699, 69.6520408987999, 68.80897253751755, 52.07807131111622, 60.097445994615555, 57.01100841164589, 59.457944110035896, 56.42571821808815, 53.97727780044079, 44.437749087810516, 43.28757360577583, 41.43884360790253, 44.21567760407925, 41.878954991698265, 43.48807744681835, 43.70838202536106, 45.98091088235378, 43.14753212034702, 43.380512818694115, 41.60556726157665, 42.41468824446201, 42.0088966190815, 43.10147479176521, 40.58067865669727, 43.36028650403023, 42.46480755507946, 42.74854972958565, 42.46220089495182, 42.61878289282322, 42.103059366345406, 41.52727246284485, 41.95742458105087, 45.95702536404133, 46.93543866276741, 50.087312534451485, 51.94341413676739, 55.16008973121643, 54.946373999118805, 56.80953562259674, 57.735093757510185, 54.44018796086311, 54.03796814382076, 51.4927127212286, 51.23438358306885, 41.33286349475384, 7.683818489313126, 0.8758717041928321, 5.184361059218645, 7.872592359781265, 10.06432045251131, 13.169696219265461, 8.498051147907972, 1.443658908829093, 0.21468922204803675, 3.0918520549312234, 48.9948445558548, 44.934568628668785, 26.7207969725132, 55.18266052007675, 11.204089242964983, 0.40387819055467844, 0.22423330054152757, 0.24591242865426466, 0.18944190727779642, 0.1369335490744561, 0.18691323202801868, 0.17277724837185815, 0.08191490604076535, 0.15023592277429998, 0.12030185636831447, 0.14330987411085516, 0.1916708587668836, 0.08806439363979734, 0.19680620898725465, 0.09760674292920157, 0.24678798479726538, 0.0693427017540671, 0.12466756976209581, 0.20344363641925156, 0.17523023940157145, 0.1620093238307163], [0.0707243729266338, 0.04395131014462095, 0.07515182558563538, 0.0360454001929611, 0.04393818526295945, 0.03722256144101266, 0.06083551488700323, 0.04669069225201383, 0.026494827907299623, 0.01545294233437744, 0.027956151934631635, 0.015523258043685928, 0.041645127057563514, 0.04329586758103687, 0.07062071716063656, 0.05128431548655499, 0.024817499943310395, 0.05888047155167442, 0.03305526865005959, 0.020976913547201548, 0.036476127861533314, 0.062485034577548504, 0.04401380640047137, 0.04964614694472402, 0.01138144967626431, 0.035291912499815226, 0.042031251650769264, 0.05883117068151478, 8.546509947627783, 43.889012932777405, 23.905757926404476, 38.92446532845497, 35.91175898909569, 7.064232286065817, 0.04137370880926028, 0.5281336605548859, 1.393364688847214, 2.1420269971713424, 4.097817437723279, 3.0036718491464853, 0.4632070491788909, 0.2184398434474133, 16.075614988803864, 69.56091418862343, 59.71584767103195, 65.02546235918999, 61.66471749544144, 60.948987901210785, 60.549925714731216, 60.8316919952631, 56.30143828690052, 61.72584481537342, 57.3240964114666, 60.05624480545521, 56.682428643107414, 51.484356969594955, 45.86063593626022, 47.489897310733795, 44.51549671590328, 44.58723306655884, 45.27015142142773, 43.502581268548965, 44.45451378822327, 47.22781777381897, 48.98094870150089, 52.14012198150158, 52.79709912836552, 60.81834331154823, 58.403709679841995, 60.64313091337681, 61.55342526733875, 49.385030418634415, 39.66368906199932, 41.840143874287605, 43.3924213796854, 42.885460183024406, 43.80883723497391, 47.32406660914421, 52.027355432510376, 53.43961425125599, 54.83714126050472, 57.387009635567665, 59.58170346915722, 36.118718683719635, 47.00187049806118, 50.61443164944649, 50.385790318250656, 54.58817861974239, 48.51444773375988, 50.71366712450981, 51.915432438254356, 54.679309129714966, 56.086992993950844, 54.78182002902031, 55.63657656311989, 57.395327389240265, 65.92763274908066, 52.21678286790848, 54.3571662157774, 56.27670541405678, 56.250745207071304, 55.54305978119373, 52.185198962688446, 47.72070452570915, 42.16633357107639, 39.538656771183014, 38.38975042104721, 37.80265152454376, 39.15222130715847, 39.54578518867493, 38.54540906846523, 40.161378756165504, 40.22521533071995, 40.17277434468269, 39.50650289654732, 37.886972799897194, 40.32457999885082, 39.53773342072964, 39.803236573934555, 39.33921307325363, 38.30129876732826, 41.006335616111755, 39.93381656706333, 39.30404216051102, 39.285947531461716, 37.732868269085884, 38.76892447471619, 38.00457648932934, 38.576719388365746, 38.543619364500046, 41.58145375549793, 44.9323495477438, 50.78514888882637, 49.99468110501766, 50.54574653506279, 51.610103622078896, 54.765154123306274, 51.95147730410099, 52.61961445212364, 11.807287875562906, 0.37073259882163256, 0.9180345386266708, 3.1502627581357956, 3.312875982373953, 2.574078538455069, 4.831042243167758, 0.9799678903073072, 0.14114366378635168, 0.06075814970245119, 7.624500347301364, 45.819183960556984, 29.11823272705078, 29.80450250208378, 23.166534192860126, 0.24517992889741436, 0.18196506629465148, 0.04185902886092663, 0.07654007960809395, 0.023764555662637576, 0.03448593270150013, 0.005807560219182051, 0.04302104658563621, 0.02903608441556571, 0.008436214357061544, 0.03330500505398959, 0.020877907336398493, 0.032297038633259945, 0.04290304510504939, 0.007502773478336167, 0.06326147689833306, 0.05089425379992463, 0.04098181030713022, 0.052343167262733914, 0.040782495416351594, 0.03902995078533422, 0.035282168100820854, 0.07416558553813957, 0.09930849497322924, 0.05810906470287591, 0.042435440118424594, 0.05508649017428979, 0.03580613549274858, 0.052489633817458525, 0.019717240320460405, 0.037831174486200325, 0.04047763599373866, 0.013391217125899857, 0.05138422711752355, 0.05293987625918817, 0.07181267312262207, 0.06050757838238496, 0.10434549578349106, 0.04188802085991483, 0.02348247460759012, 0.06017161183990538, 0.06084905537136365, 0.029375401754805353, 0.07717048210906796, 0.028113073494751006, 0.01383720335070393, 0.03629541490226984, 0.03704843133164104, 0.0870270567247644, 0.06720075965858996, 18.05350385606289, 48.021473586559296, 24.1033948212862, 47.6880718767643, 43.468975871801376, 8.492126315832138, 0.08100128514342941, 0.5165831709746271, 1.6906633484177291, 2.742039975710213, 5.746301030740142, 6.615358097478747, 2.2266401443630457, 0.17787823715480044, 20.8093648776412, 71.86096876859665, 58.64746280014515, 66.2922839820385, 62.5037656724453, 63.84162828326225, 60.53801715373993, 62.64495089650154, 58.43478061258793, 62.03566499054432, 59.85201336443424, 61.70098654925823, 59.75495897233486, 54.85224165022373, 48.58376741409302, 48.78254994750023, 46.806120201945305, 46.20458967983723, 46.657734364271164, 45.67431293427944, 47.34601803123951, 48.67654323577881, 51.064703688025475, 55.05459979176521, 55.391751900315285, 62.59838439524174, 61.62067025899887, 61.80307187139988, 63.165648356080055, 50.93578800559044, 41.57195046544075, 43.10302130877972, 43.7330275028944, 44.01101678609848, 44.5877992361784, 49.03271332383156, 53.80728252232075, 55.63897043466568, 56.47018723189831, 58.62507060170174, 61.221163496375084, 40.56969724595547, 51.923628598451614, 53.58319714665413, 52.7637293189764, 55.62890477478504, 51.693444550037384, 50.933177545666695, 52.96392537653446, 57.792675867676735, 58.619135320186615, 57.353970408439636, 56.869188621640205, 58.31428147852421, 64.27546620368958, 59.92610938847065, 54.57709461450577, 57.773407101631165, 57.149081602692604, 57.34857089817524, 56.00459821522236, 49.43266846239567, 43.93038511276245, 42.899789214134216, 39.94877636432648, 40.87855227291584, 39.21374760568142, 40.237431675195694, 39.96904827654362, 41.52132198214531, 39.76898521184921, 41.28632739186287, 41.91583961248398, 39.60434004664421, 41.22113808989525, 40.37158727645874, 42.094209641218185, 40.873376950621605, 40.413662418723106, 41.882169619202614, 41.14385403692722, 40.92652469873428, 39.89881284534931, 39.46452274918556, 41.522423923015594, 39.708617851138115, 40.36275275051594, 40.821984708309174, 42.97675408422947, 47.521694004535675, 52.321303859353065, 52.83877529203892, 52.29477748274803, 53.904549703001976, 53.97450774908066, 50.8120172470808, 52.68655925989151, 14.083265047520399, 1.113700526766479, 3.092714846134186, 4.854429038241506, 10.002584215253592, 4.927947968244553, 4.58989673294127, 1.7608492635190487, 0.11504304246045649, 0.10705445354687981, 8.538341335952282, 55.21199494600296, 31.034492701292038, 27.04550474882126, 33.553966507315636, 0.7661591819487512, 0.14193979528499767, 0.05312478977430146, 0.015333569735958008, 0.04089181747986004, 0.024917430127970874, 0.020484773158386815, 0.08788442282821052, 0.027232775028096512, 0.027782535762526095, 0.040411462396150455, 0.029661059961654246, 0.024041649485297967, 0.06481879216153175, 0.02464363700710237, 0.047411785199074075, 0.08351900629349984, 0.011586581149458652, 0.061475457696360536, 0.02452098411595216, 0.02579946150945034, 0.031625728952349164, 0.28493311372585595, 0.29260202252771705, 0.21777713525807485, 0.2370290397084318, 0.09547353591187857, 0.25916675571352243, 0.16228534339461476, 0.10070723554235883, 0.12852838524850085, 0.120852381514851, 0.10509729880141094, 0.18388415628578514, 0.16487529035657644, 0.1492523099295795, 0.14784942817641422, 0.2761617593932897, 0.1417603885056451, 0.2219460014021024, 0.11144147400045767, 0.12572765350341797, 0.21305481990566477, 0.17513607570435852, 0.1355966442497447, 0.12977807287825271, 0.18448640912538394, 0.1618102501379326, 0.2030022960389033, 0.18887616810388863, 21.822595708072186, 60.666625052690506, 32.0226676762104, 47.95636028051376, 47.56232522428036, 10.857050064951181, 0.24642396136187017, 3.5844027623534203, 4.664965029805899, 7.548412280157208, 10.693726278841496, 9.306773152202368, 1.6449756687507033, 0.30306161439511925, 19.073500223457813, 70.07286831736565, 59.68871712684631, 68.22042971849442, 64.26224291324615, 63.386777490377426, 62.46962070465088, 64.92235109210014, 59.53111678361893, 66.2994047999382, 62.770442962646484, 64.2061199247837, 63.07284213602543, 56.98424644768238, 50.42969696223736, 53.50493274629116, 48.890524953603745, 49.14687059819698, 49.53859157860279, 47.35100336372852, 51.094323098659515, 51.06888346374035, 53.63126076757908, 56.877506375312805, 57.65367932617664, 63.612827360630035, 62.682557478547096, 64.5396888256073, 66.73232316970825, 53.67529280483723, 43.028811290860176, 45.8619848638773, 49.099965915083885, 47.058958634734154, 46.53343923389912, 50.04735767841339, 56.558722481131554, 56.22517257928848, 59.29369792342186, 60.911540910601616, 65.48763155937195, 39.0989975631237, 53.010199293494225, 58.40959936380386, 55.207495987415314, 55.9871381521225, 52.53496639430523, 52.33460694551468, 52.5409434735775, 58.43973554670811, 60.61875142157078, 59.61605742573738, 59.48552303016186, 57.229405492544174, 63.03428940474987, 60.486244931817055, 55.6861487030983, 61.526192128658295, 59.18636508285999, 60.143529921770096, 56.982756927609444, 52.73608960211277, 44.96151678264141, 43.308662474155426, 41.715024188160896, 42.835276275873184, 41.551450565457344, 43.933535143733025, 41.63134127855301, 44.33952435851097, 42.56131857633591, 44.086233749985695, 43.038439974188805, 42.18260429799557, 43.39657075703144, 43.75593647360802, 45.56692689657211, 44.01222512125969, 42.466646656394005, 44.62160602211952, 44.018266797065735, 43.631200566887856, 43.03744822740555, 41.93041183054447, 43.42172920703888, 40.26176556944847, 41.60804472863674, 43.603348061442375, 45.52020840346813, 49.95354451239109, 53.984676003456116, 54.82826493680477, 55.726141557097435, 55.07066152989864, 54.66537147760391, 52.822823747992516, 52.265667244791985, 14.715537820011377, 0.77355797868222, 2.3986828001216054, 7.77901953086257, 9.372720513492823, 10.821794606745243, 14.93845285847783, 5.003133108839393, 0.5762036936357617, 0.19686054904013872, 14.460678845643997, 59.40721683204174, 39.327072724699974, 40.02867467701435, 42.38819606602192, 1.2640740140341222, 0.2966528129763901, 0.16282957512885332, 0.1198338060930837, 0.22428903583204374, 0.1938921958208084, 0.12998631951631978, 0.15010428061941639, 0.10597928194329143, 0.0952321152726654, 0.11050016357330605, 0.13961513643153012, 0.10302859926014207, 0.14965024951379746, 0.20993331709178165, 0.16889504418941215, 0.18472321360604838, 0.09639189913286828, 0.20413938502315432, 0.14616738015320152, 0.11100728050223552, 0.1144402552745305], [0.045427720178849995, 0.03694941769936122, 0.02409168693702668, 0.07121177841327153, 0.06194049485202413, 0.06971524504479021, 0.03985895571531728, 0.06721360623487271, 0.01842746187321609, 0.04173392502707429, 0.04875399637967348, 0.010918646385107422, 0.031904717106954195, 0.05215802368184086, 0.06642531923716888, 0.01815567255107453, 0.028666493017226458, 0.03315682042739354, 0.036734506575157866, 0.03697951549838763, 0.003522717356645444, 0.02567127776273992, 0.04318335799325723, 0.04522424555034377, 0.09110833459999412, 0.05789928552985657, 0.12172232702141628, 0.274583597201854, 1.9380531110800803, 34.62724931538105, 32.8157839179039, 49.77816492319107, 48.666086196899414, 15.419873725622892, 0.504216318950057, 0.1392318171565421, 0.7562869554385543, 2.958747334778309, 6.73562116920948, 7.164163123816252, 0.8589084644336253, 0.17560738400788978, 0.08495659829350188, 21.60227783024311, 69.57937359809875, 60.12428395450115, 60.00400900840759, 61.60718858242035, 59.97961051762104, 61.19876749813557, 60.51019884645939, 56.09643928706646, 56.739927157759666, 58.19741874933243, 51.179833710193634, 48.768749088048935, 49.307810962200165, 47.69609324634075, 49.528107941150665, 48.04741479456425, 46.08141928911209, 43.80992017686367, 45.145449712872505, 48.99720422923565, 49.542410373687744, 52.32206001877785, 54.199064299464226, 59.343695640563965, 59.696932286024094, 59.25509199500084, 60.210440531373024, 51.00612223148346, 42.62643948197365, 42.95461647212505, 41.774886175990105, 43.67178238928318, 41.81172899901867, 45.14165751636028, 53.683428168296814, 55.30288606882095, 57.38676264882088, 55.82049809396267, 62.316215336322784, 41.88348054885864, 45.2807642519474, 56.61259979009628, 47.3063937574625, 47.74027727544308, 45.75845181941986, 50.229823887348175, 48.42418357729912, 55.55890493094921, 55.04854291677475, 57.93150521814823, 53.0854694545269, 59.60075184702873, 55.89618243277073, 45.585485100746155, 58.077242597937584, 54.39147837460041, 54.80654150247574, 52.99633003771305, 48.39082516729832, 47.2458516061306, 41.46475441753864, 38.063655719161034, 39.28741805255413, 39.05452474951744, 40.66431976854801, 39.46862652897835, 39.944607987999916, 39.148622900247574, 42.27887973189354, 40.43564423918724, 40.02259500324726, 39.88158077001572, 42.27708242833614, 41.165851056575775, 39.309589862823486, 41.557317450642586, 39.13151241838932, 40.09782336652279, 40.640457049012184, 40.49361392855644, 40.59726856648922, 40.71895703673363, 44.540993347764015, 47.661032527685165, 44.28884647786617, 41.71655930578709, 40.48804722726345, 39.816604256629944, 41.63789592683315, 47.071041986346245, 50.57995229959488, 52.58835352957249, 52.220605462789536, 54.733718410134315, 33.246038630604744, 3.113113814033568, 0.378905069665052, 4.3162368424236774, 3.177143703214824, 8.820379301905632, 3.6877432046458125, 2.645842912606895, 1.3413541484624147, 0.09179521453916095, 0.4568849899806082, 24.627753384411335, 40.3181279450655, 19.484887048602104, 39.658984914422035, 14.793307296931744, 0.054976852698018774, 0.05674895292031579, 0.015548808332823683, 0.02080330108583439, 0.09120751521550119, 0.021037411570432596, 0.030937839692342095, 0.13293410040205345, 0.0568421258503804, 0.06620061176363379, 0.01511246910013142, 0.03706511481141206, 0.028366446422296576, 0.031481548212468624, 0.06417294556740671, 0.06535874170367606, 0.02539266068197321, 0.06565257281181403, 0.05501293591805734, 0.05208371985645499, 0.06913086312124506, 0.027155864408996422, 0.0063968667564040516, 0.02021909356699325, 0.030237339487939607, 0.04865913877438288, 0.057659197045722976, 0.06901678760186769, 0.023097982739272993, 0.0520046848396305, 0.010834501681529218, 0.02536208790843375, 0.009062129647645634, 0.06623497320106253, 0.05243249215709511, 0.032917359058046713, 0.015621594466210809, 0.028079127660021186, 0.018284973230038304, 0.011115641136711929, 0.02663905132067157, 0.0419159367447719, 0.0304474396398291, 0.03509261616272852, 0.03589314488635864, 0.01743176871968899, 0.00889198023287463, 0.07571517504402436, 0.10483961770660244, 0.2824655914446339, 3.1623126240447164, 46.492595225572586, 28.64297702908516, 42.36367218196392, 48.0513209849596, 19.043840914964676, 0.5686625826638192, 0.16295970330247656, 0.8617869880981743, 1.7131918645463884, 2.6141770742833614, 6.686167772859335, 3.538796897046268, 1.3089798856526613, 0.09806228801608086, 28.30542404204607, 72.9307633638382, 57.4201400578022, 61.42321765422821, 60.571440160274506, 60.58199979364872, 62.13864706456661, 62.56442941725254, 58.90902176499367, 58.83403278887272, 58.40596295893192, 55.46956032514572, 51.16475231945515, 51.486002281308174, 49.14153568446636, 50.48149958252907, 48.7429940700531, 48.19311037659645, 46.530976966023445, 48.22106547653675, 50.87137386202812, 51.93336367607117, 54.003420397639275, 56.926975920796394, 61.40970557928085, 60.87198503315449, 58.77960830926895, 60.995303615927696, 51.61412760615349, 45.24520955979824, 45.11951230466366, 44.35981526970863, 44.69611242413521, 46.463617980480194, 47.34281100332737, 55.22456467151642, 55.97885459661484, 59.73014250397682, 57.154192328453064, 61.77596032619476, 47.60239027440548, 48.6777363717556, 56.34483955800533, 50.147820487618446, 50.59833951294422, 48.00452269613743, 51.2660738825798, 50.584382861852646, 55.988696068525314, 57.01181776821613, 57.44572028517723, 57.30716452002525, 57.25562408566475, 60.92148877680302, 50.266655310988426, 57.18600422143936, 56.512630954384804, 55.41322074830532, 55.57150885462761, 51.04170732200146, 47.553095519542694, 43.45921419560909, 40.830253064632416, 41.05701729655266, 42.63175919651985, 41.74261450767517, 40.96656695008278, 41.842286959290504, 42.52596527338028, 43.209309205412865, 43.46973963081837, 40.0817958265543, 41.17635369300842, 43.349685072898865, 42.846132293343544, 41.2776942551136, 42.90558770298958, 40.70068381726742, 43.44313345849514, 41.21891900897026, 42.17571146786213, 42.524931728839874, 42.8747371584177, 46.02352939546108, 46.30022294819355, 44.43162381649017, 42.379916310310364, 42.53029704093933, 41.35932147502899, 43.51748786866665, 50.35836338996887, 52.73357413709164, 55.88080085813999, 52.8505090624094, 56.57022446393967, 32.368745505809784, 3.766984627582133, 1.776265511289239, 6.863760268315673, 4.295324664562941, 11.192890293896198, 9.14906831458211, 0.8415039139799774, 0.569357470376417, 0.20108135067857802, 0.33046259719412774, 27.19401217997074, 53.14838267862797, 20.342679619789124, 43.714001923799515, 19.78152573108673, 0.04126290245039854, 0.1293603773228824, 0.05053373701230157, 0.0426439873263007, 0.023329774012381677, 0.041054277317016385, 0.010858858968276763, 0.025717259377415758, 0.02690017226996133, 0.012362669094727607, 0.016719921077310573, 0.05451952645671554, 0.09531418938422576, 0.014750423488294473, 0.012976958641957026, 0.09074463028809987, 0.03918373120541219, 0.023784647455613595, 0.04518983587331604, 0.06137428070360329, 0.06815910237492062, 0.04863219139224384, 0.1388997951289639, 0.2246001738240011, 0.13054509734502062, 0.11432126673753373, 0.11571227412787266, 0.13239322317531332, 0.20980798319214955, 0.15481427632039413, 0.12202133089886047, 0.14134753175312653, 0.14573159103747457, 0.1695244002621621, 0.16925033996813, 0.15792344463989139, 0.10210307431407273, 0.11623917671386153, 0.13992501277243719, 0.21317249484127387, 0.11490658376715146, 0.12913216691231355, 0.145844234211836, 0.11660027608741075, 0.1449868458439596, 0.1109000550059136, 0.2314803280751221, 0.20627760153729469, 0.3139746288070455, 0.4380143416346982, 5.014085071161389, 55.921929851174355, 45.02648189663887, 60.1464519649744, 61.09870366752148, 27.206733897328377, 1.2462286278605461, 0.547007960267365, 3.55075366795063, 8.901761434972286, 14.492038562893867, 14.743649661540985, 3.742164596915245, 0.5945351568516344, 0.15989586536306888, 27.152372114360332, 73.60763624310493, 59.77287121117115, 59.74308080971241, 62.76509664952755, 60.36044508218765, 64.42348346114159, 65.24836599826813, 61.493734270334244, 59.68325302004814, 63.94696623086929, 56.66334226727486, 53.24185386300087, 55.5712466686964, 52.06851862370968, 53.185339495539665, 51.44196644425392, 49.6125204116106, 49.4976107776165, 49.22975555062294, 53.11397932469845, 56.19698189198971, 57.0028730481863, 60.86763046681881, 65.02340286970139, 61.97673015296459, 62.502013966441154, 64.33420345187187, 54.69056412577629, 49.1389936208725, 47.47384317219257, 46.33051112294197, 47.04874478280544, 46.971278339624405, 48.1731728464365, 57.25449554622173, 58.57723496854305, 62.565797343850136, 57.81336575746536, 66.58416911959648, 44.11497160792351, 49.45504926145077, 59.83179844915867, 54.801214188337326, 51.66949063539505, 49.184868559241295, 50.47916650772095, 51.015541926026344, 55.90595930814743, 58.25910083949566, 57.78080150485039, 58.624006658792496, 54.59762491285801, 60.07471181452274, 52.1613210439682, 58.308353796601295, 58.50322633981705, 56.163631081581116, 58.13587345182896, 51.59944899380207, 50.73301188647747, 44.17611412703991, 42.914289236068726, 42.75241792201996, 44.68865342438221, 43.75852793455124, 44.17886517941952, 45.11199630796909, 45.38327895104885, 45.571490451693535, 45.93003921210766, 44.759052246809006, 44.42785441875458, 45.61948947608471, 44.1522666066885, 43.83638955652714, 46.799740344285965, 42.402023524045944, 45.59614732861519, 44.02738630771637, 46.055105701088905, 45.6014746427536, 45.71562811732292, 48.932603895664215, 51.520493030548096, 47.172599136829376, 46.393800526857376, 44.93488021194935, 43.27334716916084, 46.42582520842552, 50.972725823521614, 54.760104194283485, 57.381769716739655, 55.67868210375309, 53.407521173357964, 34.036183431744576, 3.450739234685898, 1.5350284497253597, 9.756802953779697, 8.433161079883575, 16.380028054118156, 6.749206865206361, 7.604398475959897, 4.376145377755165, 0.2995762514183298, 1.2197173316963017, 35.14475874602795, 54.205812737345695, 27.388415448367596, 55.84729805588722, 25.20634263753891, 0.12848605314502493, 0.27345974813215435, 0.18357310735154897, 0.1604918099474162, 0.19290647527668625, 0.1623366109561175, 0.17679024866083637, 0.27293407008983195, 0.08261296272394247, 0.11045191655284725, 0.0884228064387571, 0.19103161728708073, 0.15836301870876923, 0.05893138288229238, 0.1317667614785023, 0.19205658260034397, 0.13182838942157105, 0.13965782476589084, 0.14339715067762882, 0.11490954493638128, 0.21902542765019462, 0.11844461696455255], [0.08120180602418259, 0.05281040859699715, 0.05516345459909644, 0.061682205196120776, 0.027288903656881303, 0.020950335383531637, 0.023252494174812455, 0.06068215378036257, 0.0938724190928042, 0.00759158814616967, 0.019611315437941812, 0.007851876034692395, 0.00968773138083634, 0.09793916571652517, 0.012629527773242444, 0.031101325548661407, 0.031540983109152876, 0.06126499574747868, 0.04648952199204359, 0.0208794992431649, 0.06396116630639881, 0.027445077503216453, 0.06522784169646911, 0.049564176733838394, 0.08163987353327684, 0.11111045387224294, 0.017894948650791775, 0.09941723445081152, 0.2203892427496612, 14.557832982391119, 36.92191958427429, 39.0086118131876, 66.28038302063942, 47.11397588253021, 4.384141098707914, 0.17228990967851132, 0.7346338767092675, 0.4496055602794513, 1.8524635350331664, 5.134363817051053, 3.9261566614732146, 2.010002131573856, 0.07745222363155335, 0.04285933631763328, 24.606231339275837, 66.35301232337952, 61.85389034450054, 60.07609114050865, 62.5164607912302, 61.39098398387432, 59.63936537504196, 59.774436727166176, 56.57159239053726, 52.3018679022789, 53.68609182536602, 53.28953370451927, 52.541300654411316, 53.69847156107426, 53.99191841483116, 50.16179233789444, 47.410800755023956, 45.77507212758064, 46.34315304458141, 46.27903528511524, 49.241318330168724, 51.55279889702797, 58.30311007797718, 60.6356605142355, 58.644981533288956, 56.78750820457935, 59.31876517832279, 55.27980610728264, 46.05428494513035, 41.77506476640701, 42.294466495513916, 42.55816474556923, 41.790647730231285, 41.577152386307716, 53.457876071333885, 54.52269673347473, 57.93604217469692, 54.08916279673576, 62.02815279364586, 43.93392272293568, 49.23441030085087, 54.909534975886345, 50.34290961921215, 49.2095672339201, 55.277051255106926, 47.39877440035343, 50.717219933867455, 51.54954247176647, 51.48420877754688, 51.44589923322201, 53.91225188970566, 68.75528901815414, 42.52327501773834, 50.33767729997635, 56.03515237569809, 54.14328709244728, 55.715353935956955, 51.92629985511303, 48.5992705821991, 43.050120547413826, 38.46916235983372, 39.70953360199928, 40.895047187805176, 39.776858389377594, 40.382241904735565, 39.628791734576225, 41.111586168408394, 38.43796983361244, 40.26820622384548, 40.125337690114975, 39.406933039426804, 43.125409707427025, 43.84156487882137, 44.03378516435623, 43.83060626685619, 41.152164191007614, 40.30671335756779, 40.3329661488533, 41.96494817733765, 41.147558838129044, 40.573056265711784, 45.953206568956375, 49.03164938092232, 51.059824749827385, 51.89014099538326, 52.11336761713028, 50.333489924669266, 48.682087138295174, 43.085861429572105, 44.73796717822552, 48.172572478652, 50.292987897992134, 52.16236598789692, 54.88309219479561, 14.999399688094854, 0.6101897824555635, 3.183614993467927, 4.672764586284757, 3.1119026290252805, 18.345136307179928, 8.947244044393301, 1.075254783499986, 0.7284850941505283, 0.07369174651103094, 2.4088479671627283, 42.745597288012505, 29.705147333443165, 21.452784352004528, 35.457975938916206, 2.5946506345644593, 0.10226599799352698, 0.06085642489779275, 0.08053947633015923, 0.14940553373889998, 0.02569610074715456, 0.07865687031880952, 0.027071600961789954, 0.13190337602281943, 0.06960005630389787, 0.0492651283275336, 0.08193357105483301, 0.03453865116171073, 0.0677629884739872, 0.0793593427806627, 0.021152498266019393, 0.04050534778798465, 0.01763651984219905, 0.03783414307690691, 0.022455412727140356, 0.015028080415504519, 0.03438445142819546, 0.05099621004774235, 0.04227321776852477, 0.019342760024301242, 0.037365443422459066, 0.06431325600715354, 0.04094626143341884, 0.06513995656860061, 0.010595621970423963, 0.053185156066319905, 0.09099008078919724, 0.007729042708888301, 0.01964926330401795, 0.023325423171627335, 0.04457402028492652, 0.17699806485325098, 0.027468883745314088, 0.041274082905147225, 0.019189825652574655, 0.04012853343738243, 0.02856075738236541, 0.03208612397429533, 0.07126276395865716, 0.024458330153720453, 0.048823428005562164, 0.03982087982876692, 0.04963057297572959, 0.08395462471526116, 0.019691409870574716, 0.07328605890506878, 0.159445010649506, 25.922364816069603, 42.23105929791927, 45.58943308889866, 71.34548082947731, 48.13054673373699, 5.124231660738587, 0.07203505767392926, 0.7915887236595154, 1.3027681689709425, 3.0022661620751023, 6.057889061048627, 6.9085009675472975, 3.797855358570814, 1.7653870512731373, 0.27494641835801303, 28.578471690416336, 67.38740041851997, 60.78103691339493, 61.973260939121246, 62.7706291526556, 64.75815430283546, 62.608362659811974, 60.51412023603916, 58.23535591363907, 54.92799058556557, 55.502542555332184, 55.16661778092384, 55.6657399982214, 55.14959469437599, 54.55657571554184, 52.28856861591339, 47.75984242558479, 46.99939303100109, 48.89469712972641, 49.97103877365589, 51.116977483034134, 53.8893923163414, 60.86331769824028, 62.17926308512688, 59.8770996183157, 60.23384727537632, 61.642127707600594, 56.00351147353649, 46.51977896690369, 44.83653388917446, 43.46155107021332, 44.672192707657814, 43.97714540362358, 44.75857347249985, 56.188018172979355, 56.85155376791954, 59.68388378620148, 57.64579474925995, 59.712728038430214, 52.14735299348831, 52.68734201788902, 56.267080530524254, 53.65230783820152, 50.75857691466808, 54.22663561999798, 48.762574419379234, 50.14047548174858, 52.82959498465061, 52.223880887031555, 55.42918749153614, 51.830715984106064, 68.6838148534298, 51.86035059392452, 49.888480603694916, 58.9684771746397, 54.85323719680309, 58.064216896891594, 53.501368537545204, 51.2755923718214, 45.36970227956772, 41.71775244176388, 41.971472427248955, 42.507996037602425, 41.46934077143669, 42.014691308140755, 39.65469494462013, 43.477137833833694, 40.30151143670082, 41.62724889814854, 41.7864565551281, 40.17427146434784, 44.595102444291115, 45.2904537320137, 45.17672583460808, 45.38121946156025, 43.39011110365391, 42.81399741768837, 42.84444138407707, 43.89803744852543, 41.44007094204426, 42.9991614818573, 48.643678799271584, 49.340698197484016, 53.26447784900665, 53.90605442225933, 53.432432636618614, 51.14419922232628, 49.86037351191044, 45.80637104809284, 46.30404554307461, 51.21026627719402, 52.01852090656757, 53.106216341257095, 55.260233357548714, 15.824184380471706, 1.7599674733355641, 4.6313235349953175, 6.3822344318032265, 7.170438012108207, 16.420362889766693, 5.953102558851242, 0.8912217523902655, 0.8318833052180707, 0.09380123970913701, 2.928959308192134, 50.01827783882618, 36.12688064575195, 21.124035492539406, 44.09705936908722, 3.9503718120977283, 0.22133212652988732, 0.11515696955029853, 0.05133976505021565, 0.1343453090521507, 0.03169795105350204, 0.058752328623086214, 0.0757125329982955, 0.08173114285455085, 0.06809239814174362, 0.03267759340815246, 0.07063922632369213, 0.04632208605471533, 0.03703176640556194, 0.0397632965905359, 0.05427654359664302, 0.009420967326150276, 0.06997212462010793, 0.03658798064861912, 0.048514089721720666, 0.023870486111263745, 0.028283726642257534, 0.017585274545126595, 0.14189091743901372, 0.2359285979764536, 0.15337078424636275, 0.11888199427630752, 0.17224132869159803, 0.13944453152362257, 0.17435900255804881, 0.18484655854990706, 0.2249248485895805, 0.07029004584182985, 0.1300747983623296, 0.1149336647358723, 0.14760637481231242, 0.3466594952624291, 0.08242923664511181, 0.10972675663651899, 0.09937788578099571, 0.10278078872943297, 0.15722604846814647, 0.09759307256899774, 0.1372517819982022, 0.09082690477953292, 0.13167421566322446, 0.14421055937418714, 0.15505142218898982, 0.2093698043609038, 0.12605795374838635, 0.20947248791344464, 0.4288834612816572, 29.856609106063843, 54.547619596123695, 49.87270765006542, 70.57114318013191, 64.29904773831367, 7.934838719666004, 0.21333992335712537, 3.1452204287052155, 2.840765565633774, 7.153248684480786, 15.847912207245827, 11.240692678838968, 4.877314260229468, 0.7840293855406344, 0.23003027541562915, 28.617951571941376, 68.17662566900253, 61.354190558195114, 61.81176960468292, 67.13892415165901, 67.84817889332771, 64.37068909406662, 64.59750652313232, 61.0164874792099, 56.64384551346302, 59.002865329384804, 59.33020256459713, 57.78014414012432, 56.5536155551672, 58.18445764482021, 55.0537296384573, 50.52297055721283, 51.18425667285919, 52.64349617063999, 51.81909620761871, 53.7768879532814, 55.78859880566597, 65.55652186274529, 65.63488125801086, 61.70568309724331, 60.75715519487858, 64.0466196835041, 59.10437308251858, 49.692597314715385, 46.883529648184776, 46.148360297083855, 46.72563672065735, 46.45333953201771, 44.289576038718224, 58.26234206557274, 58.28782729804516, 63.377259001135826, 59.23790171742439, 67.37331837415695, 48.93469758331776, 54.22083333134651, 59.09192115068436, 56.200967878103256, 54.089645370841026, 55.421815887093544, 49.59214590489864, 51.773057878017426, 52.15294249355793, 51.85092709958553, 56.22207574546337, 51.9706928730011, 63.957316875457764, 57.37629421055317, 51.95720739662647, 59.330069571733475, 57.54974730312824, 60.86974695324898, 55.148602947592735, 53.7880327552557, 47.45053522288799, 43.14618319272995, 45.27848057448864, 44.11594055593014, 43.69103595614433, 44.99927915632725, 43.54383945465088, 45.34742407500744, 41.96985371410847, 44.592856764793396, 43.47047299146652, 42.404485791921616, 48.5394199937582, 48.83716821670532, 48.36930312216282, 47.62164384126663, 46.1459094285965, 45.04950866103172, 45.569921135902405, 46.68265342712402, 44.17281590402126, 46.09997749328613, 50.73387064039707, 52.49436937272549, 53.39139103889465, 56.069525331258774, 56.79514579474926, 56.539335921406746, 51.98416315019131, 48.42187710106373, 48.780976831912994, 52.69094802439213, 52.743844985961914, 54.83245611190796, 54.564597085118294, 17.56353534758091, 1.4637859538197517, 7.153676161542535, 11.686306167393923, 10.684335082769394, 30.372461825609207, 24.842666052281857, 2.799174184910953, 1.98957264656201, 0.4239372251322493, 4.708013869822025, 58.18886160850525, 41.351144313812256, 31.11205793917179, 51.27797104418278, 4.553955886512995, 0.32242792833130807, 0.3187479742337018, 0.23918687860714272, 0.2311010312405415, 0.12196952899103053, 0.15722526179160923, 0.17278973129577935, 0.24931821855716407, 0.17498074419563636, 0.2474676733254455, 0.1493748088250868, 0.17140544776339084, 0.1533494400791824, 0.1516603713389486, 0.12516569928266108, 0.09014023264171556, 0.13885912543628365, 0.11394530214602128, 0.17958664626348764, 0.13556047197198495, 0.12117896359995939, 0.15131052292417735], [0.05393558240029961, 0.01313683209446026, 0.07545148997451179, 0.005470620071719168, 0.05181469132367056, 0.020414976024767384, 0.03226446206099354, 0.0543041700439062, 0.023722919322608504, 0.02673702038009651, 0.0317421125510009, 0.08445236831903458, 0.030463980256172363, 0.030196781117410865, 0.0510024403774878, 0.06219724084076006, 0.013549057093769079, 0.067069065553369, 0.11831828858703375, 0.027335165432305075, 0.038387863169191405, 0.08529011203791015, 0.009528045320621459, 0.04971703689079732, 0.1291387720266357, 0.062400667229667306, 0.061596271916641854, 0.07421429269015789, 0.23478085175156593, 1.4418207574635744, 36.70325271785259, 29.041117765009403, 20.875732116401196, 52.26133927702904, 24.12855327129364, 0.24524010223103687, 0.18921767477877438, 1.1895336513407528, 0.7328333670739084, 3.0854862090200186, 4.778656829148531, 5.695861587300897, 1.8781646434217691, 0.25329515046905726, 0.29753629525657743, 23.900964483618736, 65.0186151266098, 60.6773366779089, 63.90301778912544, 60.81637121737003, 61.515636295080185, 56.07076406478882, 57.73464538156986, 53.9332989603281, 58.97964097559452, 57.46080927550793, 59.29055169224739, 57.384908348321915, 56.787356212735176, 53.03205192089081, 49.6913205832243, 44.38153110444546, 44.15825128555298, 44.43261556327343, 50.11471666395664, 55.07844731211662, 58.648032769560814, 59.678453877568245, 62.928518280386925, 58.42590808868408, 59.055340513587, 54.553235694766045, 45.61798095703125, 40.966186970472336, 44.143739864230156, 41.054938808083534, 45.82016430795193, 41.01646587252617, 48.69811087846756, 55.280239284038544, 58.7345465272665, 54.117383882403374, 61.95717640221119, 46.9812224060297, 47.94484689831734, 54.93793845176697, 54.50299099087715, 57.656544372439384, 59.24623467028141, 50.36210998892784, 54.58868019282818, 55.88297814130783, 55.71617469191551, 57.933481112122536, 66.14759534597397, 49.55561466515064, 41.7887744307518, 57.08020269870758, 53.820950388908386, 56.190761625766754, 54.36107240617275, 52.62208811938763, 46.26357011497021, 40.967395305633545, 39.511226043105125, 39.132150784134865, 39.79322411119938, 41.872214153409004, 39.0331356972456, 40.570707991719246, 39.91348385810852, 40.33491164445877, 42.491284534335136, 40.043170899152756, 39.4048735499382, 45.37638232111931, 45.649610459804535, 45.01417435705662, 44.95590068399906, 45.5085164308548, 41.47293917834759, 40.69727540016174, 40.52678234875202, 43.45924459397793, 43.87787953019142, 47.43046849966049, 50.7180330902338, 53.50373961031437, 51.93109139800072, 54.56317976117134, 54.16843794286251, 52.667320892214775, 47.389628291130066, 48.02977614104748, 52.574735060334206, 51.76635503768921, 55.20655743777752, 43.421296030282974, 2.7386225340887904, 1.6297909710556269, 3.5168238636106253, 4.670955408364534, 4.339397549629211, 4.463456617668271, 8.139811120927334, 0.21455426991451532, 0.32874692988116294, 0.016134809993673116, 12.062954306602478, 47.87697114050388, 19.451095461845398, 35.73577523231506, 21.39023020863533, 0.04595596976287197, 0.040985420855577104, 0.05383607523981482, 0.017601147228560876, 0.07562314873212017, 0.0732581022020895, 0.046920680106268264, 0.05316046481311787, 0.014415651803574292, 0.03376619417394977, 0.007990528702066513, 0.053550441152765416, 0.02772898609691765, 0.03062153820792446, 0.03505985776428133, 0.025073411015910096, 0.02786980490782298, 0.06796491201384924, 0.0381209534680238, 0.01771223745890893, 0.028974536253372207, 0.08526729099685326, 0.025434770141146146, 0.030288495727290865, 0.02667485623533139, 0.019498640722304117, 0.04325939102272969, 0.05595428345259279, 0.01572828747157473, 0.034171291772508994, 0.08120311220409349, 0.05892138244234957, 0.04241289367200807, 0.06981470025493763, 0.039488939437433146, 0.04035818732518237, 0.07725117582594976, 0.05770466472313274, 0.045606258645420894, 0.035742863692576066, 0.008483003057335736, 0.04250112389854621, 0.02961766287626233, 0.02190217317547649, 0.02336832487344509, 0.04748624487547204, 0.01733523386064917, 0.05003632737498265, 0.11870951173477806, 0.07553308169008233, 0.044114642005297355, 0.39953570638317615, 4.325013421475887, 48.46991032361984, 28.025945238769054, 34.749792739748955, 64.63919788599014, 24.210277386009693, 0.3275601763743907, 0.30920175835490227, 1.7745256796479225, 0.7132036203984171, 2.3116078600287437, 5.400454038754106, 5.030665006488562, 7.4760750867426395, 5.3895780723541975, 0.6329639791510999, 30.892302431166172, 64.29866015911102, 61.47743694484234, 64.28908467292786, 62.379611134529114, 63.02761696279049, 58.38468790054321, 59.74737077951431, 56.01817108690739, 61.16285562515259, 59.299344420433044, 60.584336668252945, 56.887351647019386, 58.315163031220436, 54.91441011428833, 50.840420722961426, 46.06956012547016, 46.53496295213699, 48.484216555953026, 52.5380290299654, 55.50929859280586, 61.753009557724, 60.33118665218353, 62.94769585132599, 60.11815868318081, 61.33620232343674, 56.784928143024445, 47.663346603512764, 44.13156911730766, 44.79157470166683, 44.43325772881508, 44.89298366010189, 44.12848748266697, 51.45204730331898, 56.24335080385208, 60.668809935450554, 56.566854044795036, 60.731297582387924, 52.53902077674866, 52.159497141838074, 55.58049537241459, 58.1710709631443, 58.585966899991035, 59.770104959607124, 50.67440763115883, 53.47974389791489, 54.15851667523384, 55.650734603405, 55.6808327883482, 66.45251378417015, 60.8460134267807, 42.78011463582516, 56.8819597363472, 56.351436004042625, 58.49250331521034, 55.7630679756403, 53.56691122055054, 48.41707415878773, 42.44170479476452, 41.20318025350571, 40.23568756878376, 40.50548069179058, 43.09989407658577, 41.682505533099174, 43.020972311496735, 41.77960552275181, 40.97249463200569, 43.182957619428635, 43.570118844509125, 40.9462646394968, 47.50275582075119, 48.42157691717148, 46.848396733403206, 46.94772720336914, 46.46247424185276, 44.02469985187054, 43.0319195240736, 43.185556679964066, 46.064487397670746, 45.95490127801895, 48.31132583320141, 52.16117665171623, 54.09851789474487, 52.922731786966324, 54.17954094707966, 55.64622804522514, 54.2715872079134, 49.26300376653671, 49.363523572683334, 53.487905859947205, 53.620359152555466, 56.739934757351875, 45.246182307600975, 4.085196414962411, 3.6841485975310206, 4.588155001401901, 4.781254939734936, 11.443676836788654, 9.81239777058363, 1.3666578219272196, 0.5665889626834542, 0.18404523201752454, 0.06747176230419427, 12.634649779647589, 60.14645576477051, 23.161765448749065, 38.64527530968189, 28.742624782025814, 0.04148306426941417, 0.051270162730361335, 0.08860034300596453, 0.010450307599967346, 0.03979530913056806, 0.004303864197936491, 0.06654607408563606, 0.04786805759067647, 0.04958338351571001, 0.01985646907996852, 0.018458502199791837, 0.026187992516497616, 0.018500394580769353, 0.027154263225384057, 0.008247872119682143, 0.03065176588279428, 0.018995885766344145, 0.004289015678295982, 0.006545908099724329, 0.03970520498114638, 0.016159536498889793, 0.03514809541229624, 0.004578035350277787, 0.16411074466304854, 0.141117213643156, 0.15839105704799294, 0.1460067051812075, 0.1330288578174077, 0.12188650493044406, 0.15188475226750597, 0.19097326963674277, 0.1297107303980738, 0.2098714219755493, 0.31675216101575643, 0.12830719555495307, 0.09970321363653056, 0.17193915584357455, 0.10926344868494198, 0.10416759556392208, 0.165259069763124, 0.09109757345868275, 0.34379382559563965, 0.13427772908471525, 0.1136703512747772, 0.1574620365863666, 0.14575226727174595, 0.14275909663410857, 0.28748975310008973, 0.3891475684940815, 0.20533655828330666, 0.20402178430231288, 0.45711998362094164, 4.116168553009629, 58.618903532624245, 42.320327907800674, 30.37713747471571, 62.938534542918205, 35.16018591821194, 0.8310386817902327, 1.227014483883977, 4.130320893600583, 5.011459412053227, 11.60453075543046, 11.320822779089212, 10.754402372986078, 6.604027580469847, 2.795873824506998, 0.7209655351471156, 28.324301429092884, 64.27130922675133, 62.682204097509384, 68.02769646048546, 64.87270295619965, 66.15847796201706, 60.86439684033394, 62.31260932981968, 59.85646292567253, 63.23904521763325, 61.176804676651955, 64.7234545648098, 58.49993571639061, 61.02105863392353, 58.399507105350494, 54.61326867341995, 48.669224828481674, 48.86425696313381, 50.60553252696991, 56.08209505677223, 58.61331023275852, 63.91285166144371, 63.1080586463213, 64.48602810502052, 62.83417694270611, 64.00555908679962, 59.31908056139946, 51.50283917784691, 46.53216630220413, 48.891965076327324, 47.12606303393841, 48.977665677666664, 45.30726782977581, 53.58295015990734, 59.46188449859619, 62.17767097055912, 56.69323906302452, 65.03982558846474, 50.324169024825096, 52.642546221613884, 60.318240746855736, 58.82376953959465, 61.987855955958366, 61.9251973181963, 53.85404661297798, 55.69456145167351, 57.36141420900822, 58.65921176970005, 58.916359171271324, 61.46808564662933, 63.354122042655945, 49.18645687401295, 57.3776925355196, 57.905772998929024, 58.99501495063305, 58.323351591825485, 56.14416092634201, 49.5187908411026, 43.82277108728886, 42.615264281630516, 42.48748853802681, 43.48415985703468, 46.095296144485474, 43.73143158853054, 44.58322808146477, 43.67622435092926, 44.85600784420967, 45.786384120583534, 44.8666662722826, 43.13103340566158, 50.48914477229118, 50.24333216249943, 48.76312159001827, 50.2264154702425, 50.457838252186775, 46.54111482203007, 45.8312901109457, 45.418662652373314, 49.413912668824196, 48.5659995675087, 49.933078810572624, 54.51813317835331, 57.47366018593311, 54.18049469590187, 57.13219150900841, 59.53101798892021, 57.1478770673275, 50.782907009124756, 51.619382724165916, 56.34470276534557, 56.099410727620125, 58.51662062108517, 45.512973591685295, 3.9676300110295415, 4.4205322209745646, 7.820992553606629, 10.180496368557215, 10.841578245162964, 13.623501118272543, 19.65311922132969, 1.561134948860854, 0.7462310325354338, 0.16842823330080137, 18.87349035590887, 65.89575245976448, 28.71728964149952, 50.47706142067909, 33.68448190391064, 0.14470604684902355, 0.1382552250288427, 0.18018294707871974, 0.10063895053463057, 0.1359440287342295, 0.12445472180843353, 0.11172565718879923, 0.1904085249407217, 0.1361304710735567, 0.08402692474192008, 0.08508015103871003, 0.13871004281099886, 0.12799432093743235, 0.09155052102869377, 0.0461575185181573, 0.12207559673697688, 0.12840575276641175, 0.09731159821967594, 0.11654821442789398, 0.11275011784164235, 0.19333046424435452, 0.1282940892269835, 0.08412476949160919], [0.029440747857734095, 0.08799501025350764, 0.03288954707386438, 0.04408886350574903, 0.009296267962781712, 0.07195005207904615, 0.04313665835070424, 0.016372399295505602, 0.0457162300881464, 0.05646334851917345, 0.061389917755150236, 0.02308450533746509, 0.09515926605672576, 0.03722730376466643, 0.02885478887037607, 0.018792375885823276, 0.022043177523300983, 0.007340563188336091, 0.0763583870138973, 0.015033701256470522, 0.07612936766236089, 0.02530830261093797, 0.05463199151563458, 0.04018257663119584, 0.14355268998770043, 0.132269358728081, 0.06531998675200157, 0.042860056200879626, 0.11462344700703397, 0.16171657625818625, 12.362404838204384, 52.68342062830925, 29.885164573788643, 41.718273013830185, 49.94041621685028, 4.10915270447731, 0.3242529882118106, 1.035246136598289, 1.0526481340639293, 1.2632683385163546, 7.706468123942614, 3.5586182959377766, 10.040369387716055, 8.54304738342762, 0.18674219667445868, 0.416762171080336, 34.839695915579796, 68.11429381370544, 59.94655229151249, 60.92639051377773, 58.946905732154846, 61.82783894240856, 56.60852260887623, 57.85461634397507, 59.954034090042114, 60.59181846678257, 60.631020963191986, 60.25166451931, 57.0123915374279, 54.77127179503441, 47.46165722608566, 42.973079681396484, 44.1599839925766, 46.86917781829834, 50.21105669438839, 57.30265416204929, 57.58061684668064, 64.11053225398064, 61.805674731731415, 59.050792157649994, 59.10039469599724, 55.32588243484497, 47.33841843903065, 42.44517020881176, 43.50497514009476, 40.46660877764225, 44.52437683939934, 40.87016612291336, 44.07112196087837, 52.10527405142784, 59.93852712213993, 53.91576670110226, 62.35901243984699, 45.333220437169075, 48.852116614580154, 62.59288229048252, 55.27236990630627, 58.248472809791565, 59.427902922034264, 56.22967913746834, 55.60792990028858, 55.46699546277523, 56.782158091664314, 60.07903218269348, 43.209138214588165, 44.79809135198593, 55.77622666954994, 55.06888322532177, 56.512760147452354, 55.869029089808464, 53.88916812837124, 49.23011273145676, 41.91205121576786, 39.934557527303696, 39.848590940237045, 38.86989265680313, 40.63259147107601, 41.92557089030743, 42.065414786338806, 39.38649393618107, 40.81792272627354, 40.14689013361931, 41.87956675887108, 40.66067196428776, 42.10563562810421, 45.066771134734154, 46.320601254701614, 47.75260381400585, 47.22983926534653, 44.53841708600521, 45.657852217555046, 41.073212027549744, 43.88912312686443, 44.51400339603424, 46.821820959448814, 50.248621478676796, 51.82076811790466, 55.85920661687851, 53.053444772958755, 53.56639824807644, 57.77959316968918, 55.02357065677643, 52.13226020336151, 49.063753858208656, 52.57378131151199, 51.12864285707474, 57.53066472709179, 21.865254119038582, 0.4049563530134037, 3.990253759548068, 3.6474898271262646, 2.792071416042745, 10.782148484140635, 9.643395189195871, 1.027927016839385, 0.3352636395720765, 0.28082790900953114, 0.25673761731013656, 31.22178465127945, 35.87836638092995, 16.77822768688202, 37.69426994025707, 3.252241685986519, 0.15784922987222672, 0.073444121517241, 0.08913290817872621, 0.02047255555226002, 0.04648421563615557, 0.04476947971852496, 0.04530554040684365, 0.05569547429331578, 0.03689043180202134, 0.05570986453676596, 0.014980904870753875, 0.05136367333761882, 0.03409126969927456, 0.005763432582170935, 0.08258983740233816, 0.040293616766575724, 0.06997824733844027, 0.02072137540380936, 0.003898601471519214, 0.08017212065169588, 0.05153001089638565, 0.02420230219286168, 0.03624601384217385, 0.04033119170344435, 0.04462186654563993, 0.04702232836280018, 0.06392313123797067, 0.057262582195107825, 0.07469996155123226, 0.0376108345517423, 0.07619346695719287, 0.025065030313271564, 0.06360163286444731, 0.047335989656858146, 0.023435157127096318, 0.09096407593460754, 0.021118554286658764, 0.02154113131837221, 0.0538998850970529, 0.04915748351777438, 0.0530742977571208, 0.0826018898806069, 0.006908658751854091, 0.05877113093447406, 0.03671003054478206, 0.0488445124210557, 0.05223718486377038, 0.07610288041178137, 0.05954656022367999, 0.07634928828338161, 0.036033785581821576, 0.13360549171920866, 0.2511390036670491, 20.414805449545383, 58.438139632344246, 22.227950356900692, 50.613287910819054, 55.87181434035301, 4.03246046975255, 0.06631484313402325, 1.0197113826870918, 0.20786435779882595, 1.8152203084900975, 2.228240570984781, 4.0173320565372705, 13.429221343249083, 8.663868550211191, 1.0117394104599953, 0.8179255260620266, 41.23826377093792, 67.80584916472435, 63.28674405813217, 63.23599398136139, 62.08891913294792, 62.98285536468029, 59.24303524196148, 60.56464992463589, 61.22346617281437, 60.833557695150375, 62.48005494475365, 62.62453459203243, 60.09429216384888, 56.046099588274956, 52.01775334775448, 46.52292139828205, 47.03485652804375, 47.81280018389225, 51.64984188973904, 60.310333371162415, 61.29237927496433, 63.65846671164036, 64.47131529450417, 60.782199651002884, 61.79093152284622, 57.89292208850384, 48.4475789219141, 44.47261601686478, 44.406628757715225, 44.23697166144848, 47.192878648638725, 46.037406250834465, 48.27529236674309, 56.619496420025826, 60.72803735733032, 57.39453323185444, 61.04593589901924, 53.37149530649185, 52.86949664354324, 60.192391499876976, 59.198767617344856, 58.42968508601189, 60.58014549314976, 56.66567914187908, 57.096146643161774, 55.01240685582161, 59.44989614188671, 62.54991039633751, 52.64115169644356, 43.287763595581055, 54.01760123670101, 57.11753569543362, 59.132214188575745, 58.30644249916077, 55.35134106874466, 50.37585385143757, 44.41807374358177, 41.97510503232479, 42.694968804717064, 43.158699721097946, 39.431175738573074, 42.965955063700676, 42.64075331389904, 42.79089845716953, 42.44942218065262, 41.17679826915264, 42.440424263477325, 42.42441572248936, 44.91784952580929, 47.06340819597244, 49.90940608084202, 49.210714772343636, 49.85167197883129, 46.386132538318634, 44.9706818908453, 42.50771105289459, 45.618782714009285, 44.6973929554224, 48.22905644774437, 51.69907204806805, 54.31442230939865, 54.85503450036049, 53.34790617227554, 56.01693995296955, 57.93777108192444, 55.663080140948296, 53.05145747959614, 50.06625026464462, 54.702753871679306, 51.98618844151497, 58.35221104323864, 24.07407559454441, 0.6115308136213571, 5.492500774562359, 4.998086029663682, 3.5276941303163767, 6.489941077306867, 2.8719212813302875, 0.5481565673835576, 0.34690202912315726, 0.12750806577969342, 0.43157965410500765, 35.49839437007904, 47.3719896376133, 17.91031613945961, 44.213678911328316, 6.535571403801441, 0.25099069287534803, 0.011303349765512394, 0.02179479182814248, 0.04334847842983436, 0.028509779258456547, 0.050608022283995524, 0.03690797617309727, 0.04716933297459036, 0.04680457852373365, 0.03336695583129767, 0.031178696299321018, 0.05173655430553481, 0.0273544148876681, 0.04369814501842484, 0.08669312737765722, 0.03361316332302522, 0.03383348470379133, 0.05162851986824535, 0.015384443031507544, 0.03360865477588959, 0.04812955703528132, 0.003220267130927823, 0.04101621998415794, 0.07884268183261156, 0.20204338186886162, 0.18018021597526968, 0.1542741560842842, 0.19655456155305728, 0.18313283566385508, 0.08568183242459781, 0.11591648348257877, 0.11151672035339288, 0.11490722201415338, 0.15028526075184345, 0.11016705801011994, 0.18450696661602706, 0.10891382291447371, 0.12775677430909127, 0.21474538778420538, 0.18160343257477507, 0.10807579717948101, 0.20472942211199552, 0.09720735615701415, 0.21179290168220177, 0.2101713090087287, 0.08962973894085735, 0.18298771610716358, 0.2837056608404964, 0.13984607794554904, 0.18714490084676072, 0.18430151045322418, 0.2091776771703735, 0.23491981148254126, 21.885142251849174, 71.44329518079758, 39.870002791285515, 53.77996578812599, 63.975935876369476, 7.751206923276186, 0.6981130864005536, 5.805441057309508, 3.923686081543565, 5.313480505719781, 20.030731558799744, 11.301543563604355, 21.83963779360056, 20.18602542579174, 0.4233451694017276, 1.004431927576661, 39.351247027516365, 69.4083371758461, 63.60152296721935, 66.46870851516724, 64.29794579744339, 65.67666381597519, 62.54462867975235, 63.799397349357605, 65.53120002150536, 63.41530255973339, 66.17234721779823, 64.66221705079079, 61.98473632335663, 58.19854348897934, 51.83418519794941, 48.40004347264767, 49.825487583875656, 51.53607219457626, 53.46194185316563, 62.24995829164982, 63.587786704301834, 66.62932589650154, 65.60379132628441, 63.0937410145998, 64.63087633252144, 60.58360330760479, 50.60768701136112, 45.31710170209408, 47.2576841711998, 44.57652144134045, 49.95376870036125, 45.59558875858784, 50.7579043507576, 57.213404551148415, 66.21678963303566, 59.17083151638508, 66.38651132583618, 49.66023065149784, 55.371001213788986, 63.982562720775604, 60.13606712222099, 63.100383058190346, 62.11352661252022, 60.03150433301926, 59.19767327606678, 56.39744773507118, 59.31912615895271, 62.91935697197914, 54.71905879676342, 51.46185837686062, 56.50275148451328, 58.38545925915241, 60.12148730456829, 61.12622559070587, 58.07066135108471, 52.70849168300629, 46.01401850581169, 44.92687024176121, 45.229546800255775, 43.51151838898659, 42.88250394165516, 46.07406288385391, 45.970039665699005, 44.00032036006451, 44.65246416628361, 43.0026762932539, 44.042612090706825, 44.621495828032494, 47.012361735105515, 49.47876378893852, 51.5659423917532, 52.21264109015465, 52.17973865568638, 48.9484566450119, 48.941993191838264, 43.336495980620384, 49.42518286406994, 47.30946399271488, 51.20431959629059, 56.84773117303848, 55.16646958887577, 56.575650572776794, 55.96243567764759, 57.29345105588436, 61.15724332630634, 59.0881859511137, 55.06283015012741, 53.43728497624397, 57.00867533683777, 55.31070984899998, 58.20577830076218, 24.32382669299841, 0.6675879587419331, 7.704454706981778, 8.449088875204325, 13.547687586396933, 21.312843561172485, 22.702708281576633, 2.905410071834922, 0.7298522489145398, 0.7269306806847453, 0.8791527687571943, 43.68556044995785, 49.92823787033558, 23.237183801829815, 55.24777762591839, 8.987049758434296, 0.34834235964808613, 0.1601614206447266, 0.11497317667817697, 0.08577751752454787, 0.13458159402944148, 0.09771592027391307, 0.12635739549295977, 0.09454366940190084, 0.13670348329469562, 0.10778558775200509, 0.17455446941312402, 0.213001518859528, 0.14493694383418187, 0.0833432434592396, 0.2173426968511194, 0.26638372626621276, 0.2526289690285921, 0.14139102160697803, 0.0519619927945314, 0.1592296245507896, 0.11908584740012884, 0.11186678399099037, 0.19606438785558566], [0.057780920396908186, 0.06537239722092636, 0.03422293040785007, 0.01952604823600268, 0.03983871734817512, 0.03773450604057871, 0.0587442985852249, 0.020098841523576993, 0.04360906132205855, 0.03340036731970031, 0.0699983150116168, 0.059836272412212566, 0.02532585996959824, 0.04797965433681384, 0.06655178120126948, 0.07238989332108758, 0.06033787889464293, 0.04573777463519946, 0.13994708424434066, 0.04867592615482863, 0.04638627069653012, 0.029764786231680773, 0.07205401954706758, 0.07324228703510016, 0.10811325337272137, 0.021924047978245653, 0.04834737366763875, 0.026154044826398604, 0.08082507702056319, 0.1353007648140192, 0.30492027872242033, 26.915002651512623, 49.824723824858665, 29.683076217770576, 57.468937039375305, 20.33080715686083, 0.3089450643165037, 0.4648443160112947, 0.04271008299838286, 0.8895421237684786, 0.5575402826070786, 4.449052065610886, 7.447682060301304, 8.25320653617382, 2.415296696126461, 0.19915825308999047, 6.597877610474825, 58.12084525823593, 61.47059351205826, 59.470076858997345, 65.89172467589378, 62.000820860266685, 60.657277554273605, 64.26586031913757, 63.831718415021896, 62.359958589076996, 61.28186523914337, 60.139369145035744, 61.36017523705959, 59.9811190366745, 51.30820982158184, 43.924119248986244, 43.2062541693449, 49.87073175609112, 55.98961181938648, 59.68325302004814, 60.54441221058369, 62.48869568109512, 57.145627588033676, 60.657072365283966, 58.836859837174416, 56.015313640236855, 47.012696117162704, 44.756779968738556, 44.82888489961624, 43.070039078593254, 44.74628113210201, 43.29600155353546, 44.04342904686928, 46.90004736185074, 56.12590670585632, 52.80457712709904, 62.397097796201706, 55.930285602808, 46.820646822452545, 56.04298375546932, 56.19314029812813, 58.6395288258791, 58.6035181581974, 56.96495108306408, 54.90842163562775, 59.44622553884983, 50.220047011971474, 47.87763610482216, 51.81432366371155, 59.758435785770416, 56.47054821252823, 58.517441377043724, 54.99612092971802, 54.23719145357609, 51.500992476940155, 44.64107997715473, 39.91253010928631, 39.5934384316206, 38.59708249568939, 41.0596239566803, 44.41575966775417, 46.16246894001961, 43.67324911057949, 42.35899083316326, 40.87690696120262, 42.79838405549526, 48.09562660753727, 48.162662610411644, 42.44695991277695, 45.67283481359482, 46.97454236447811, 51.54378958046436, 48.31370070576668, 49.1541738063097, 45.505317002534866, 44.699273854494095, 42.84330524504185, 47.48184934258461, 46.9518955796957, 51.58834978938103, 52.1566016972065, 55.30838057398796, 54.75371293723583, 53.420041501522064, 56.47382743656635, 55.047072395682335, 53.800222501158714, 52.8955252468586, 53.916108682751656, 56.762178763747215, 47.89178654551506, 4.6730628702789545, 1.0382732679136097, 3.476315187290311, 1.6175866196863353, 2.114862254820764, 7.331187911331654, 3.2327741431072354, 0.10100905958097428, 0.2998424449469894, 0.04564155518892221, 3.687529703602195, 47.107949405908585, 20.60337033122778, 29.105423614382744, 28.854840360581875, 0.383890105294995, 0.17156169953523204, 0.05721405686927028, 0.01982796318770852, 0.034343072984484024, 0.01558119009132497, 0.0438799897528952, 0.014854892833682243, 0.018110898781742435, 0.03713768943271134, 0.03481419575109612, 0.03346195815538522, 0.04020041786134243, 0.023788356338627636, 0.05324331817973871, 0.018442705586494412, 0.017037870129570365, 0.06907704257173464, 0.026580785306578036, 0.056367540964856744, 0.050328700162936, 0.038476924601127394, 0.03017913655639859, 0.0012876338723799563, 0.059741184741142206, 0.04399464785819873, 0.013191549714974826, 0.031608744902769104, 0.038311755924951285, 0.041435615057707764, 0.08961851766798645, 0.08733416485483758, 0.03955347288865596, 0.052805996529059485, 0.006064462058930076, 0.04194320696115028, 0.0061652767908526585, 0.011377673072274774, 0.04077790152223315, 0.05433630874904338, 0.02093154049362056, 0.03833650283922907, 0.07279995217686519, 0.01912920703034615, 0.06937257319805212, 0.02986091476486763, 0.039877620729384944, 0.16242966143181548, 0.0024226949381045415, 0.052885261611663736, 0.039425155555363744, 0.05104174080770463, 0.11619261436862871, 0.11183253387571312, 0.908099259249866, 40.88288404047489, 46.82435542345047, 31.278589703142643, 73.01873624324799, 19.97921012341976, 0.06112039940489922, 0.2181338262744248, 0.2197235808125697, 0.14418995735468343, 2.1904352121055126, 5.708532007411122, 9.369277898222208, 9.541590102016926, 8.157560918480158, 0.33218084718100727, 9.104532804340124, 59.58029754459858, 61.375663205981255, 62.26934105157852, 65.81023424863815, 64.96229454874992, 62.31870800256729, 64.09152567386627, 66.06670528650284, 64.15942803025246, 63.41652229428291, 61.87859661877155, 62.39335119724274, 61.57599225640297, 54.102541878819466, 45.82497105002403, 47.8105279058218, 50.70520497858524, 57.59680397808552, 61.94062829017639, 60.238817408680916, 62.79217019677162, 61.269287914037704, 61.774770990014076, 60.52403010427952, 56.95481322705746, 49.44606274366379, 47.40390032529831, 47.63415277004242, 45.637082532048225, 44.96284291148186, 45.10780893266201, 46.154227182269096, 49.440564438700676, 59.98154081404209, 54.237145856022835, 62.27645426988602, 57.8224016726017, 49.6270926296711, 59.86773692071438, 56.26940980553627, 60.77008590102196, 60.76211392879486, 57.746610939502716, 57.370142340660095, 61.50212801992893, 54.50087830424309, 50.97781375050545, 50.826958045363426, 60.43524406850338, 57.88972266018391, 59.14755776524544, 57.53047093749046, 56.77434951066971, 54.19390417635441, 46.59773178398609, 42.51239240169525, 41.565129831433296, 40.319822654128075, 42.86574304103851, 44.74141739308834, 47.36382007598877, 46.49375036358833, 44.071775525808334, 42.08955109119415, 44.42870557308197, 49.469100907444954, 47.22688302397728, 44.55295130610466, 48.20417158305645, 49.912293925881386, 52.950002923607826, 49.876404851675034, 51.02240435779095, 48.25205281376839, 46.004967391490936, 44.82571966946125, 48.53985697031021, 49.048068299889565, 53.91045838594437, 54.996041133999825, 58.648017570376396, 55.91713450849056, 54.30754467844963, 58.171895518898964, 55.59060662984848, 54.68781687319279, 54.25128869712353, 54.53951083123684, 54.397869631648064, 50.9700545668602, 5.287753036245704, 1.331786618102342, 6.671548532322049, 3.919720994308591, 5.477710068225861, 4.576838733628392, 1.2435876508243382, 0.25091855612117797, 0.3144704131409526, 0.05075462242530193, 3.9287538221105933, 58.7815348058939, 27.19781957566738, 28.715431541204453, 40.02435810863972, 0.9851023647934198, 0.1259885184117593, 0.08902084387955256, 0.03030190633580787, 0.02504991276509827, 0.057154699898092076, 0.015380854747490957, 0.10150079921004362, 0.031875064596533775, 0.009273723371734377, 0.04512781830271706, 0.08587987453211099, 0.043311820045346394, 0.056874494621297345, 0.09625144026358612, 0.037564569065580145, 0.04277644584362861, 0.009426310789422132, 0.01248932494490873, 0.05108830315293744, 0.03361997994943522, 0.0036522341861200402, 0.022576859628316015, 0.0055624390461161966, 0.14189413835993037, 0.20298340095905587, 0.09230950803612359, 0.1329419226385653, 0.1507028375635855, 0.1760488876607269, 0.31044987263157964, 0.1518547991872765, 0.1996177909313701, 0.13780223292997107, 0.17730699124513194, 0.13334842660697177, 0.15371462126495317, 0.14132109645288438, 0.17426537320716307, 0.12887130200397223, 0.2701363217784092, 0.11158584398799576, 0.21033750555943698, 0.11769572316552512, 0.21477467293152586, 0.14667523180833086, 0.1878246190608479, 0.27822047704830766, 0.21374883188400418, 0.1453753304667771, 0.217003372090403, 0.17754415195668116, 0.21301979053532705, 0.19272043369710445, 1.2910940079018474, 46.92521721124649, 63.17229799926281, 35.0800596177578, 75.29898628592491, 26.73235595226288, 0.6378021882846951, 1.1296396027319133, 0.4314265341963619, 5.082080997526646, 5.231878934428096, 16.501195952296257, 16.991016268730164, 18.322478123009205, 10.244197100400925, 0.40385607455391437, 9.605756308883429, 62.671340480446815, 62.62863837182522, 65.97531259059906, 69.99560326337814, 66.96151927113533, 65.5531096458435, 67.32855677604675, 68.45151051878929, 67.84725934267044, 67.80961856245995, 67.14005649089813, 64.93369728326797, 65.50862163305283, 59.2789851129055, 49.002432748675346, 49.49429355561733, 55.78558176755905, 62.557418793439865, 64.64787662029266, 63.74821409583092, 62.626062110066414, 60.25740601122379, 62.40572713315487, 64.77937996387482, 59.69161257147789, 52.823424115777016, 51.284632086753845, 50.657775923609734, 49.93669241666794, 48.58523413538933, 48.196663185954094, 48.92342358827591, 51.30608573555946, 62.25034587085247, 56.62516191601753, 68.22061970829964, 57.68403209745884, 49.74391736090183, 61.23826637864113, 59.296600967645645, 63.774341493844986, 61.39463558793068, 60.485104992985725, 58.01578849554062, 63.68243582546711, 56.18226148188114, 54.909561574459076, 56.645023450255394, 62.58242145180702, 58.51463332772255, 63.1239227950573, 59.005593582987785, 58.05681489408016, 55.295419469475746, 48.086035922169685, 43.88050138950348, 42.69683450460434, 42.073869332671165, 45.22535562515259, 48.599981144070625, 49.31450620293617, 48.390076607465744, 48.00722435116768, 45.478201657533646, 46.15554191172123, 52.78648629784584, 51.047403216362, 47.26694047451019, 50.50702281296253, 53.4394508600235, 56.35286472737789, 52.09721848368645, 55.66234678030014, 50.06154991686344, 47.88942687213421, 46.34732522070408, 51.054706424474716, 50.67452922463417, 57.193064242601395, 55.96803277730942, 61.36429041624069, 56.86358392238617, 58.357823342084885, 60.37496030330658, 57.927811816334724, 57.63428516685963, 57.743103727698326, 57.47772976756096, 59.41064044833183, 50.820688381791115, 5.859582927078009, 2.5546551682054996, 10.836051441729069, 6.377091407775879, 9.148817528039217, 19.2133916169405, 12.639080341905355, 1.0764893610030413, 1.313902996480465, 0.17635123862419277, 7.413477245718241, 64.767015427351, 30.139688216149807, 39.613793939352036, 46.15016520023346, 1.4899476687423885, 0.35192708135582507, 0.18318432586966082, 0.22352606349159032, 0.14181425358401611, 0.11979089511441998, 0.14963969617383555, 0.19544442737242207, 0.10611841978970915, 0.06799262380809523, 0.10824870274518616, 0.13573367439676076, 0.1702722327900119, 0.21626017056405544, 0.20625904784537852, 0.19544337352272123, 0.2339783526258543, 0.16778667632024735, 0.15015514742117375, 0.12111347648897208, 0.14594264299375936, 0.11018624252756126, 0.160860835458152, 0.10732874390669167], [0.026057337418023963, 0.050509286957094446, 0.09309535336797126, 0.05298863907228224, 0.07020580465905368, 0.07039921576506458, 0.02194144020904787, 0.031982969157979824, 0.04643448060960509, 0.09261211875127628, 0.09512206961517222, 0.02251327983685769, 0.016212408954743296, 0.0773153270711191, 0.044086848574806936, 0.06990088586462662, 0.032601664279354736, 0.05532667142688297, 0.0692346079449635, 0.046826727921143174, 0.028719784786517266, 0.0499289757135557, 0.05647806159686297, 0.09827958885580301, 0.03775523422518745, 0.17250588949536905, 0.01757092511979863, 0.04231406557664741, 0.04481080250116065, 0.0813253216620069, 0.2217525680316612, 6.951492810621858, 46.65709599852562, 38.096983730793, 47.13644027709961, 54.60652783513069, 2.8166997944936156, 0.1307720015756786, 0.29270108439959586, 0.5297239345964044, 0.3870978456689045, 2.0508330781012774, 9.263853505253792, 3.4366172924637794, 6.964488113299012, 0.40881071181502193, 0.09597573240171187, 16.312841959297657, 66.27244144678116, 58.13507929444313, 64.37096267938614, 65.04753917455673, 65.57203263044357, 62.844953164458275, 61.11538477241993, 61.866156086325645, 63.60226012766361, 61.517669185996056, 66.37465596199036, 60.01167319715023, 53.9551667869091, 46.02555088698864, 45.6434091925621, 52.15207614004612, 59.88403804600239, 59.618572890758514, 64.49702471494675, 58.83421137928963, 57.25422576069832, 59.89367812871933, 61.40364870429039, 55.253785103559494, 44.249590784311295, 43.757152408361435, 42.9063780605793, 44.18427988886833, 42.97640070319176, 45.006411373615265, 45.19596040248871, 44.50613781809807, 49.51769270002842, 53.13647411763668, 55.919220596551895, 62.295875027775764, 55.93127354979515, 52.00874783098698, 56.9013386964798, 57.18275159597397, 59.91880618035793, 56.67988657951355, 55.12050725519657, 59.5846027135849, 56.807601526379585, 58.24678190052509, 56.23955100774765, 57.07234472036362, 56.58585302531719, 59.27802376449108, 57.61989153921604, 54.798888713121414, 46.215529292821884, 40.992743745446205, 40.52147403359413, 41.09137885272503, 41.089798137545586, 45.38938142359257, 50.03129594027996, 50.38912653923035, 43.82922314107418, 41.25259280204773, 40.32269150018692, 52.026967853307724, 56.70181140303612, 54.58843320608139, 50.31071774661541, 45.56754246354103, 48.880911469459534, 50.8621783554554, 50.8830164372921, 49.87031377851963, 47.512080520391464, 46.91949091851711, 45.569286569952965, 46.600110456347466, 49.24098774790764, 53.27001415193081, 54.02482844889164, 52.58537828922272, 52.81064160168171, 53.59774276614189, 49.61633540689945, 56.27267763018608, 54.12208043038845, 54.016214311122894, 52.411153838038445, 58.53669494390488, 20.918272733688354, 0.43458888481836766, 1.0683961515314877, 4.6923463605344296, 5.460339775308967, 1.845716640818864, 2.5320126581937075, 0.3516019316157326, 0.1754551992053166, 0.2324147810577415, 0.15927039814414456, 21.713621355593204, 38.39495234191418, 17.490336075425148, 39.767495691776276, 11.625882759690285, 0.10338117877836339, 0.07048103754641488, 0.03427527037274558, 0.0432323657150846, 0.04163236211752519, 0.07319124953937717, 0.1111443032277748, 0.0463282013515709, 0.05932654683419969, 0.024303768623212818, 0.03594802299630828, 0.03869500469591003, 0.0749578356044367, 0.02108060085447505, 0.10814924753503874, 0.05505939065187704, 0.017850568219728302, 0.005608923002000665, 0.021702633785025682, 0.022030564723536372, 0.0634916168928612, 0.1281274770735763, 0.0757743464782834, 0.03329841107188258, 0.05317725219356362, 0.03662945928226691, 0.018690148754103575, 0.09549682450597174, 0.09145504373009317, 0.0329698140558321, 0.02032712429354433, 0.047042885853443295, 0.03031589581951266, 0.05685411153535824, 0.020582452780217864, 0.035132651319145225, 0.043475589773152024, 0.07486325630452484, 0.03688910335768014, 0.030464076735370327, 0.05218836267886218, 0.048294421430910006, 0.0865824063657783, 0.10351550008635968, 0.06543114563100971, 0.027762993158830795, 0.014898424433340551, 0.007539332600572379, 0.0480429372692015, 0.06297564614214934, 0.07773870747769251, 0.05305202219460625, 0.030404573190025985, 0.12148958951001987, 0.2727139787748456, 10.884208157658577, 56.104316264390945, 32.86339156329632, 53.74865546822548, 58.05948235094547, 2.068768828175962, 0.06661968029220589, 0.19300078740343451, 0.4550524492515251, 0.3701197629561648, 3.2731806999072433, 8.207345847040415, 3.3143567154183984, 7.37469082698226, 1.4075422030873597, 0.13927785999840125, 21.663224659860134, 68.18961337208748, 60.18405854701996, 67.98298805952072, 69.39734816551208, 65.28318732976913, 64.62950840592384, 64.2518998682499, 64.53632980585098, 64.94723975658417, 64.01172235608101, 67.56988942623138, 61.12675376236439, 56.62490352988243, 47.4008908867836, 47.41047777235508, 53.29583376646042, 62.668380439281464, 64.17933896183968, 64.78331655263901, 59.05243746936321, 58.22951942682266, 61.42419420182705, 60.78794874250889, 57.91487731039524, 47.77186878025532, 46.00050263106823, 44.77151557803154, 45.15201956033707, 45.32397173345089, 47.4682080745697, 46.60532757639885, 47.511472553014755, 51.675745099782944, 56.62413977086544, 57.09301181137562, 65.21442621946335, 58.07458274066448, 52.250008285045624, 59.01055231690407, 58.39615188539028, 62.27938011288643, 56.711721271276474, 56.59911051392555, 59.49707821011543, 57.95089937746525, 58.81581276655197, 59.4729533046484, 58.81945297122002, 58.87188255786896, 61.110863015055656, 60.89459002017975, 59.300735145807266, 48.35185445845127, 42.92617119848728, 42.83397674560547, 43.8839516043663, 42.22702011466026, 46.64585620164871, 49.624071791768074, 51.37158662080765, 46.06979951262474, 43.89004647731781, 43.5467728972435, 53.11009593307972, 57.27485865354538, 56.24787636101246, 50.9105421602726, 47.34559625387192, 50.741265043616295, 52.74401597678661, 52.10233300924301, 52.133540734648705, 48.47581900656223, 47.493206933140755, 46.10599637031555, 49.822983518242836, 50.86946256458759, 54.26042340695858, 56.166100949048996, 54.627875089645386, 54.29494455456734, 55.689165741205215, 52.79509663581848, 57.47577287256718, 56.09661787748337, 56.59851774573326, 53.61008830368519, 60.18055133521557, 23.620355241000652, 0.8162648964207619, 3.347614430822432, 5.891453241929412, 7.5086830370128155, 4.853868568316102, 1.1091414839029312, 0.42731022695079446, 0.22321220923913643, 0.16361726098693907, 0.09908548701787367, 23.871231079101562, 51.187448501586914, 16.924901716411114, 43.19329306483269, 17.242899052798748, 0.11388954459107481, 0.07700955480686389, 0.04598387822625227, 0.1099432707997039, 0.0476655440434115, 0.08909902913728729, 0.05934275533945765, 0.03779961836698931, 0.026625150894687977, 0.018529473782109562, 0.05779540711955633, 0.051043711209786125, 0.03925295874068979, 0.06311511795502156, 0.15860697749303654, 0.05430376928416081, 0.0623313729010988, 0.059011542252846994, 0.048415120618301444, 0.05436786115751602, 0.05633735781884752, 0.038672072332701646, 0.13885542954085395, 0.021638463986164425, 0.10017480395617895, 0.17083111451938748, 0.17101451405324042, 0.19890442374162376, 0.29486744315363467, 0.18007827457040548, 0.09554959120578133, 0.0797945233352948, 0.16196593787753955, 0.11348050247761421, 0.16766054090112448, 0.17439575371099636, 0.07280623074620962, 0.4041427810443565, 0.1618574804160744, 0.2356971666449681, 0.12864812335465103, 0.12449472356820479, 0.15939868579152972, 0.34718009701464325, 0.08674881813931279, 0.1424639148171991, 0.1755630926345475, 0.18659211957128718, 0.11931400586036034, 0.3178010234842077, 0.1508335000835359, 0.2338242085534148, 0.12112188502214849, 0.22800873935921118, 0.489012444159016, 15.299217849969864, 69.68184649944305, 46.90666280686855, 57.414064183831215, 69.91588354110718, 5.685661984607577, 0.2404223763733171, 0.6693625228945166, 1.1749368533492088, 3.8478794367983937, 7.304204134270549, 23.68886176496744, 12.982747200876474, 13.134833090007305, 1.378746754489839, 0.2812035841634497, 19.96904566884041, 71.01758882403374, 62.178267538547516, 69.63333830237389, 70.92843800783157, 69.58075672388077, 67.65079468488693, 67.10055381059647, 66.7752380669117, 66.58520266413689, 66.12308666110039, 70.20467564463615, 62.44538560509682, 58.062297999858856, 51.16870030760765, 49.96631182730198, 56.24258704483509, 64.35895532369614, 67.04112499952316, 68.34345951676369, 60.028947070240974, 59.31313768029213, 63.177370727062225, 66.0807417333126, 59.89142864942551, 48.97874861955643, 47.72842951118946, 46.07286974787712, 46.68524108827114, 48.33879455924034, 50.48757925629616, 49.85640652477741, 49.504002034664154, 52.73813009262085, 58.90535116195679, 59.606284350156784, 65.81589594483376, 57.55398787558079, 57.773407101631165, 62.50142499804497, 60.54848939180374, 64.03522789478302, 58.12988497316837, 56.89489424228668, 62.33219727873802, 61.071998700499535, 61.892910450696945, 60.58854304254055, 61.7976001650095, 60.02314478158951, 63.77613499760628, 62.22144082188606, 59.886454716324806, 49.897337928414345, 45.35199522972107, 44.77547116577625, 46.19926996529102, 44.43325012922287, 49.63179677724838, 54.41491171717644, 54.28603023290634, 48.520592004060745, 46.2708543241024, 45.39928749203682, 55.20379118621349, 59.54331412911415, 58.721410632133484, 53.84698659181595, 50.37132829427719, 54.73695583641529, 56.00310109555721, 55.1969363540411, 55.1872468739748, 50.53020536899567, 50.459912940859795, 50.08427269756794, 51.71911217272282, 52.841062769293785, 57.16542072594166, 58.39975789189339, 54.97308276593685, 57.04427942633629, 57.866559103131294, 52.00760409235954, 59.74910348653793, 57.38333523273468, 57.77487762272358, 56.13920219242573, 59.38748449087143, 22.76468675583601, 0.7913524238392711, 4.412222541868687, 10.504851713776588, 12.84437857568264, 8.11254283413291, 8.19070653989911, 2.0821260614320636, 0.23562399088405073, 0.6702709710225463, 0.20806139800697565, 30.243709534406662, 52.19928860664368, 24.56869885325432, 54.765541702508926, 20.1435437053442, 0.15953001624438912, 0.19211173901567236, 0.269908630871214, 0.17895651835715398, 0.1517446496291086, 0.21234350104350597, 0.1901771975099109, 0.2210308739449829, 0.18384494120255113, 0.1600509148556739, 0.11918490927200764, 0.1681081301649101, 0.23614880803506821, 0.0941820876323618, 0.3354054194642231, 0.25670187547802925, 0.07292182024684735, 0.08668820693856105, 0.08452686510281637, 0.09691736195236444, 0.21862633031560108, 0.22742149274563417, 0.2174086292507127, 0.1514734243392013], [0.0651975472283084, 0.014848040027573006, 0.028869182824564632, 0.05267534143058583, 0.026442148409842048, 0.04511504594120197, 0.05781773092166986, 0.07972378181875683, 0.022241178812691942, 0.05307905492372811, 0.050900079659186304, 0.09358122260891832, 0.025439508754061535, 0.018402382847853005, 0.0605370935954852, 0.04934551034239121, 0.015393064004456392, 0.043898840303882025, 0.07579477038234472, 0.01649744746828219, 0.03535941825248301, 0.027650555930449627, 0.023915829478937667, 0.018175356162828393, 0.018139551248168573, 0.06370783419697545, 0.026653033382899594, 0.06717969008604996, 0.019057231693295762, 0.0007284322077794059, 0.05698684835806489, 0.9255163965281099, 29.534597285091877, 52.18555234372616, 35.05607530474663, 60.56971125304699, 31.33589632809162, 0.31624500697944313, 0.0553980845870683, 0.03935163469577674, 0.2031350662582554, 3.300820654258132, 3.432656479999423, 6.005774382501841, 6.874048691242933, 1.0248855175450444, 0.39922631985973567, 0.5659677553921938, 24.822443537414074, 64.31971102952957, 63.09893153607845, 64.10323664546013, 60.82372762262821, 64.25930947065353, 61.48569010198116, 65.61262965202332, 64.835966527462, 62.17097572982311, 60.96360191702843, 64.47299480438232, 58.116072714328766, 46.110947504639626, 46.91740483045578, 56.236442774534225, 64.47383835911751, 62.30126313865185, 59.8760736733675, 58.770428001880646, 59.97776381671429, 60.25100335478783, 58.61187011003494, 52.20170147716999, 46.28536194562912, 44.02877703309059, 44.690921902656555, 44.41804714500904, 43.96802969276905, 44.861027374863625, 44.92873974144459, 45.327475145459175, 47.40861587226391, 53.55043150484562, 53.83386589586735, 59.14840891957283, 62.57958680391312, 55.88254116475582, 56.28346145153046, 56.49904288351536, 59.95380990207195, 56.66424661874771, 59.40045699477196, 58.339679315686226, 56.91421240568161, 54.84730191528797, 53.44385102391243, 56.48180700838566, 55.60488626360893, 58.166306018829346, 53.96907024085522, 48.10231424868107, 41.762787625193596, 40.6412436068058, 40.43917804956436, 40.1663488894701, 45.16582801938057, 50.38107857108116, 53.47715623676777, 51.905294582247734, 47.28080593049526, 42.628460973501205, 44.314609095454216, 53.68916966021061, 56.27889409661293, 56.56866654753685, 54.616050124168396, 50.22396840155125, 48.25747512280941, 50.860631838440895, 51.44453890621662, 53.05576644837856, 49.562477096915245, 48.41904245316982, 46.087578758597374, 50.26274152100086, 51.14060461521149, 53.07494021952152, 54.094892889261246, 58.32800634205341, 55.98300397396088, 50.96110224723816, 55.33462196588516, 55.636025592684746, 56.896311566233635, 54.96860280632973, 56.57997094094753, 39.09489378333092, 4.352285033091903, 0.06936004574527033, 2.1861578291282058, 3.9277000911533833, 3.779256781563163, 5.444244313985109, 1.0624701320193708, 0.19612782663898543, 0.13332647387869656, 0.012782140238414286, 4.495657989755273, 43.79527196288109, 30.67967154085636, 30.40944144129753, 35.99860332906246, 1.2158933118917048, 0.07795024925144389, 0.085611499089282, 0.05994374652800616, 0.07889412750955671, 0.019531263678800315, 0.013662044439115562, 0.04981713034794666, 0.03667745026177727, 0.0713640968024265, 0.04533443963737227, 0.017028743568516802, 0.028311473688518163, 0.01512116707090172, 0.06957397723454051, 0.02092739930958487, 0.08209683612221852, 0.07729954159003682, 0.015585537221340928, 0.11246606081840582, 0.06542713061207905, 0.025663581691333093, 0.023069282033247873, 0.05067998092272319, 0.0381352509430144, 0.0550854919856647, 0.010483994610694936, 0.06117966731835622, 0.13270461349748075, 0.06217147718416527, 0.029280015369295143, 0.04193422326352447, 0.07529305628850125, 0.0329446070099948, 0.034591454968904145, 0.04270809775334783, 0.010589202393020969, 0.03219103396986611, 0.062382373289437965, 0.023924770503072068, 0.014683053177577676, 0.0658668160031084, 0.04659252837882377, 0.02007561230129795, 0.04976729513145983, 0.023378076693916228, 0.021762243086413946, 0.056147241848520935, 0.024819969439704437, 0.02726892133068759, 0.05063379336206708, 0.037397986598080024, 0.0723420396388974, 0.03264058250351809, 0.04172877081145998, 0.0833952754328493, 1.2023785058408976, 41.103990375995636, 52.75408163666725, 36.70844703912735, 76.00613594055176, 29.57770027220249, 0.05804857595649082, 0.06142864302091766, 0.21478115930221975, 0.12739638739731163, 0.439670518389903, 4.586198106408119, 6.877859411761165, 5.965847074985504, 4.423402491956949, 0.7168745202943683, 0.804588122991845, 32.253117710351944, 65.19316256046295, 64.26711425185204, 68.50226819515228, 65.65263390541077, 66.34697064757347, 63.230450078845024, 66.26899883151054, 66.70776128768921, 62.53865160048008, 63.78562688827515, 65.6849017739296, 57.84267358481884, 48.59637513756752, 49.53894875943661, 58.43755066394806, 65.4145310819149, 63.193329870700836, 62.78607912361622, 57.988034784793854, 61.910986080765724, 61.71014025807381, 60.942505449056625, 54.84849125146866, 48.52331265807152, 46.189333498477936, 46.21225766837597, 46.783617809414864, 45.21808661520481, 46.15820936858654, 46.94695584475994, 47.57597029209137, 51.344144493341446, 55.1896483451128, 57.84485846757889, 59.25433963537216, 65.82292556762695, 58.409283980727196, 57.04549916088581, 57.80771166086197, 61.40264555811882, 57.21926383674145, 57.696161046624184, 60.94716019928455, 60.06930090487003, 58.24424743652344, 55.10779693722725, 58.06970380246639, 58.07446114718914, 60.00483736395836, 56.898952424526215, 51.094554886221886, 42.651879116892815, 43.15072014927864, 42.50711068511009, 41.766902804374695, 46.01015031337738, 52.12686449289322, 55.047836154699326, 53.76026764512062, 49.59265507757664, 44.61320087313652, 44.64401341974735, 56.14273980259895, 59.57270175218582, 57.63243846595287, 55.98930023610592, 50.59981383383274, 50.25424897670746, 52.42107890546322, 53.616027384996414, 53.695116341114044, 51.161226108670235, 50.587829276919365, 48.95913407206535, 52.25976996123791, 52.99417555332184, 55.56903138756752, 56.518832221627235, 57.6912897080183, 56.49336598813534, 53.47044959664345, 56.428328678011894, 56.823765859007835, 56.915124356746674, 55.71663826704025, 56.28171354532242, 41.993777230381966, 6.5804237220436335, 0.3326517844107002, 1.5399709157645702, 9.864989798516035, 7.664189217612147, 2.506688442081213, 0.2379380667116493, 0.15469148056581616, 0.06542589122545905, 0.11604349463596009, 5.441102832555771, 52.07049071788788, 34.52350728213787, 27.426497004926205, 44.72891226410866, 2.0356460055336356, 0.08589651348302141, 0.02321613264939515, 0.032068223372334614, 0.018606260091473814, 0.053959494398441166, 0.012500927496148506, 0.09108026657486334, 0.04058982274727896, 0.025351952026539948, 0.05402681461418979, 0.1355006400262937, 0.03588580133509822, 0.05971054888505023, 0.0387147532455856, 0.05077896115835756, 0.10879469336941838, 0.021889883209951222, 0.04436555471329484, 0.008714598588994704, 0.012219061663927278, 0.042590396842570044, 0.04797339061042294, 0.036617395671783015, 0.044216420137672685, 0.16037688095821068, 0.10228771323454566, 0.1148305952665396, 0.22675519256154075, 0.12003993761027232, 0.14870496117509902, 0.19449415180133656, 0.20381882175570354, 0.057790616556303576, 0.1937359885778278, 0.1509531046031043, 0.18377848929958418, 0.12898388580651954, 0.18039704184047878, 0.16594039101619273, 0.1944722287589684, 0.1549194980179891, 0.14676783699542284, 0.13396776368608698, 0.20676070998888463, 0.09534809811157174, 0.1573996664956212, 0.15099928103154525, 0.15608919697115198, 0.23210215877043083, 0.16532756999367848, 0.09436825537704863, 0.17303734144661576, 0.08370176758035086, 0.11208496798644774, 0.12874866952188313, 1.2830169475637376, 46.476601883769035, 67.89079740643501, 45.67677520215511, 75.20887032151222, 43.155036717653275, 0.9749675367493182, 0.3346998745109886, 0.35850289568770677, 1.635251515544951, 9.233855064958334, 11.961540598422289, 14.269468355923891, 18.808812126517296, 6.930158380419016, 0.5663336045108736, 1.0916499537415802, 29.646277092397213, 68.42246487736702, 66.13901540637016, 68.90033483505249, 68.82623881101608, 70.70349007844925, 65.05335286259651, 67.67965793609619, 69.0171405673027, 65.02537876367569, 64.19757798314095, 70.53315281867981, 63.06443318724632, 52.06735968589783, 53.078527227044106, 60.22151693701744, 69.98694732785225, 66.94983869791031, 62.85523161292076, 59.77081932127476, 61.19113750755787, 64.6260429918766, 62.90103815495968, 58.823670744895935, 52.11612246930599, 48.83583068847656, 49.01288598775864, 51.03316158056259, 48.21008026599884, 48.973618894815445, 50.54983131587505, 50.537329986691475, 53.166997879743576, 56.50572672486305, 60.22211730480194, 61.19689799845219, 64.42225232720375, 59.334914311766624, 60.445788502693176, 63.04840944707394, 63.37812155485153, 58.714080825448036, 61.59916341304779, 62.775777876377106, 62.952536791563034, 60.84714196622372, 57.086244374513626, 59.95494984090328, 60.84631361067295, 63.158736526966095, 57.09318280220032, 51.41213804483414, 44.59979899227619, 45.01848332583904, 44.716939106583595, 44.50154006481171, 49.040240719914436, 54.84367311000824, 58.050290644168854, 55.783651471138, 51.25896066427231, 46.78713642060757, 49.298250675201416, 58.564433455467224, 61.48902252316475, 60.78067593276501, 57.65623278915882, 53.41654188930988, 51.64258427917957, 55.49887955188751, 56.32941238582134, 57.46908903121948, 54.39023584127426, 53.276185020804405, 51.58827379345894, 55.031398236751556, 56.07309713959694, 57.70124897360802, 58.17618168890476, 62.673285976052284, 58.77992369234562, 56.80224381387234, 59.2395394295454, 58.920261561870575, 59.41362328827381, 58.132886812090874, 58.42015139758587, 41.26766659319401, 5.9804625157266855, 0.500805526971817, 5.0280901696532965, 8.525913152843714, 12.047792170196772, 13.001090716570616, 5.0025940127670765, 0.4487826075637713, 0.45999595429748297, 0.2280465592048131, 8.152519538998604, 58.32377716898918, 41.83213010430336, 42.250791639089584, 51.356911808252335, 2.3545723920688033, 0.24484989582560956, 0.27995561831630766, 0.13540209765778854, 0.12356391453067772, 0.14740338257979602, 0.10322949121473357, 0.09032303103595041, 0.10562381547060795, 0.1836757909040898, 0.20211875438690186, 0.18271313630975783, 0.21442161843879148, 0.13458199478918687, 0.16984350892016664, 0.12393550787237473, 0.1461246027611196, 0.17553322861203924, 0.07708610733971, 0.20530382957076654, 0.17019737977534533, 0.09207560535287485, 0.1154988472990226, 0.11694953820551746, 0.1590929803205654], [0.016563248136662878, 0.030641550220025238, 0.03390292746189516, 0.03885475198330823, 0.03614044704590924, 0.018446449721523095, 0.0834240039694123, 0.027134752162965015, 0.03108389806584455, 0.07389644568320364, 0.019187682701158337, 0.017993125511566177, 0.07400396061711945, 0.03517696124617942, 0.042883200076175854, 0.045479429318220355, 0.06507547877845354, 0.05879628974071238, 0.0397286605584668, 0.07189815369201824, 0.048514089721720666, 0.033212492635357194, 0.03252043992688414, 0.06545067895785905, 0.0343452474771766, 0.06396524811862037, 0.05696845051716082, 0.052729455128428526, 0.041417046522838064, 0.027674087577906903, 0.08985826847492717, 0.04795954955625348, 5.389515375718474, 52.73756392300129, 34.22595664858818, 31.81492332369089, 61.698725670576096, 19.277944453060627, 0.2369170347810723, 0.08209829815314151, 0.13238053245004267, 0.7049068249762058, 3.8424205547198653, 1.6851276392117143, 3.354452163912356, 1.9945037132129073, 0.49709256214555353, 0.10541944284341298, 1.8743611662648618, 40.14307513833046, 58.0417563021183, 59.534468203783035, 61.96511797606945, 61.425554528832436, 66.77878707647324, 65.07048234343529, 62.63586178421974, 63.670709654688835, 64.73774939775467, 63.16549636423588, 59.291121661663055, 49.84483614563942, 50.86128160357475, 60.87863467633724, 62.30291984975338, 64.96182337403297, 60.454748421907425, 61.855512857437134, 60.085457637906075, 61.61804459989071, 60.24985961616039, 51.40804186463356, 43.76144997775555, 45.41314534842968, 43.767529651522636, 44.032569229602814, 44.418924897909164, 45.08675046265125, 44.62406449019909, 48.79584163427353, 49.72391523420811, 53.082095235586166, 55.55033639073372, 55.8615130931139, 57.87574701011181, 57.352477088570595, 57.80197776854038, 58.802258893847466, 58.95769715309143, 56.93704538047314, 57.15452291071415, 57.567807734012604, 59.08803775906563, 56.79522179067135, 52.77104392647743, 53.2292765378952, 53.193083480000496, 51.84773147106171, 48.014158979058266, 42.79894642531872, 41.72938361763954, 42.26461909711361, 42.15474419295788, 43.55432689189911, 50.023050382733345, 57.38373041152954, 59.140189960598946, 55.60279257595539, 48.189006596803665, 40.78817792236805, 44.24292214214802, 56.656780019402504, 58.62076923251152, 58.47430609166622, 54.29478116333485, 54.361513182520866, 51.83539353311062, 49.88171696662903, 53.758196756243706, 51.16431534290314, 49.931038320064545, 51.48239627480507, 49.41077023744583, 51.140407025814056, 51.07580289244652, 53.68955723941326, 55.1995962113142, 55.73358155786991, 56.38823702931404, 51.759466007351875, 52.16330833733082, 56.673202738165855, 54.69726696610451, 57.222014889121056, 42.67374314367771, 6.885872706770897, 0.10256991488859057, 1.476787906140089, 0.6695531657896936, 10.230087507516146, 8.25554721057415, 3.2340848352760077, 0.23026356211630628, 0.1396744785597548, 0.07270181056810543, 1.19983050506562, 33.62332038581371, 40.585268810391426, 19.987185895442963, 40.96742570400238, 13.106458112597466, 0.18552406516391784, 0.0904969459224958, 0.01690067299932707, 0.02208878064266173, 0.05835846342961304, 0.002294704845553497, 0.054310489431372844, 0.02891299365728628, 0.008686586224939674, 0.043862564125447534, 0.01657255837926641, 0.035395846571191214, 0.013375805501709692, 0.027871062848134898, 0.03704724760609679, 0.05688985707820393, 0.04215880457195453, 0.01636825440073153, 0.04139380616834387, 0.027363248300389387, 0.06460191434598528, 0.03661048998765182, 0.0538119777047541, 0.04737186507554725, 0.019540154607966542, 0.11337211180943996, 0.03280221113527659, 0.021023672561568674, 0.04109847592189908, 0.0768305933161173, 0.05063275064458139, 0.021317564896889962, 0.041707474883878604, 0.0470451419823803, 0.03334230168547947, 0.05833373135828879, 0.012168792291049613, 0.03296890121418983, 0.04807880897715222, 0.044814798966399394, 0.016163440195668954, 0.028772111763828434, 0.04043397544592153, 0.016625807475065812, 0.016390522541769315, 0.008615450442448491, 0.09156251413514838, 0.013732340667047538, 0.04635915633116383, 0.08432640359387733, 0.021398210374172777, 0.021699529752368107, 0.02516605887649348, 0.05162611530977301, 0.029875852342229337, 0.1572519791079685, 0.08336386032169685, 8.969829082489014, 61.20521195232868, 34.44340378046036, 41.720013320446014, 68.22768732905388, 15.109589025378227, 0.16684923990396783, 0.06662263403995894, 0.03784040680329781, 0.5722428217995912, 0.24261885148007423, 2.460554405115545, 8.165015168488026, 4.014710672199726, 2.8010897571220994, 0.2998601080616936, 3.1374921184033155, 47.91040934622288, 60.75808994472027, 61.298675537109375, 63.418008014559746, 65.98702356219292, 68.55815559625626, 65.09033247828484, 64.0562255680561, 67.17751488089561, 64.27160561084747, 65.85691094398499, 61.32517911493778, 50.39249315857887, 52.09376446902752, 62.98797369003296, 64.47043374180794, 66.77236542105675, 60.30547343194485, 62.08120554685593, 62.6066717505455, 62.418543845415115, 62.80665501952171, 52.30957768857479, 45.01631364226341, 45.97152918577194, 45.65411701798439, 46.25879377126694, 45.48330098390579, 46.62804275751114, 47.40365333855152, 51.630485728383064, 52.91425444185734, 53.90055991709232, 57.56996601819992, 58.5236806422472, 58.975510597229004, 60.44900692999363, 61.070756167173386, 59.81749601662159, 61.22506208717823, 58.99186111986637, 59.709957987070084, 59.74242344498634, 61.23513914644718, 56.900479942560196, 55.34450523555279, 55.093464106321335, 55.654994174838066, 54.93726208806038, 50.12161709368229, 45.07795013487339, 42.402916476130486, 45.03124304115772, 44.91624981164932, 44.30733248591423, 50.7961492985487, 59.0151272714138, 59.92495805025101, 57.69710339605808, 49.54918920993805, 43.816330432891846, 46.34976848959923, 57.811420261859894, 59.94846358895302, 60.91224767267704, 57.31640562415123, 55.95667518675327, 52.63661094009876, 53.02224084734917, 54.65479664504528, 53.728474751114845, 51.15715652704239, 52.40373283624649, 52.17758797109127, 51.762372851371765, 52.421306893229485, 54.6817409992218, 57.46033810079098, 56.967819929122925, 56.96295239031315, 54.14561256766319, 55.77371120452881, 58.35112430155277, 55.82548342645168, 57.44041197001934, 45.80132491886616, 9.006229229271412, 0.1825902663404122, 2.602851069532335, 2.666099863126874, 15.144586097449064, 3.681569010950625, 1.0858881566673517, 0.11556773344636895, 0.1682192593580112, 0.1512626395560801, 2.2422558814287186, 32.85920038819313, 53.12258206307888, 20.687763802707195, 45.2960280328989, 18.903617039322853, 0.19827499345410615, 0.049640206052572466, 0.04665901367843617, 0.02417000949208159, 0.023620707033842336, 0.02669245997822145, 0.011348710759193636, 0.015723656470072456, 0.09186018956825137, 0.06493661552667618, 0.007914950238046004, 0.04382261431601364, 0.0182048120041145, 0.09904587859637104, 0.05292550828016829, 0.020071035105502233, 0.030646769373561256, 0.04491482563025784, 0.029178387521824334, 0.05214777462242637, 0.08336593091371469, 0.014039028555998811, 0.0619868456851691, 0.035199797130189836, 0.047307309359894134, 0.18546786974184215, 0.1415655153687112, 0.08897898675058968, 0.19243948627263308, 0.11705533135682344, 0.129338558181189, 0.2000406221486628, 0.18562897515948862, 0.1989961086655967, 0.10987090397975408, 0.14143108273856342, 0.13775806030025706, 0.1225087586499285, 0.16784472711151466, 0.16359845496481284, 0.13697346177650616, 0.11247619113419205, 0.24284050130518153, 0.08424867104622535, 0.1384960816358216, 0.09083190685487352, 0.1511202214169316, 0.10317781547200866, 0.14782884099986404, 0.2427102840738371, 0.1637985825072974, 0.16621451068203896, 0.12609044497366995, 0.24180101958336309, 0.1516418028040789, 0.3059663507156074, 0.23248463199706748, 10.787990670651197, 69.55940946936607, 46.38122700154781, 44.30787965655327, 74.92662146687508, 27.862409614026546, 0.3815228323219344, 0.2955349307740107, 0.227700837131124, 2.0270302053540945, 9.975074641406536, 8.13847929239273, 4.735251283273101, 5.71358478628099, 3.3781441301107407, 0.4162393428850919, 3.0283968849107623, 46.073207929730415, 65.16351655125618, 64.43675234913826, 67.56042793393135, 68.03460448980331, 70.62567785382271, 69.87815916538239, 65.62522977590561, 68.62280532717705, 68.29682841897011, 69.2165158689022, 62.79435507953167, 54.22217845916748, 56.74569524824619, 67.37908646464348, 67.27095186710358, 69.15346965193748, 59.343859031796455, 64.96451362967491, 65.41246399283409, 65.96251487731934, 64.78886425495148, 55.64924128353596, 46.36913985013962, 49.50096979737282, 47.46868684887886, 48.800074607133865, 48.48306901752949, 48.51876810193062, 49.999237060546875, 55.01755937933922, 57.50636503100395, 57.69235745072365, 61.543762385845184, 61.448303908109665, 62.11429797112942, 62.396239042282104, 64.51391100883484, 63.44886615872383, 64.02917101979256, 60.50080955028534, 61.960543021559715, 60.64292952418327, 63.28257568180561, 59.15627829730511, 57.314323335886, 57.44819775223732, 57.85284943878651, 57.84238860011101, 51.97157822549343, 48.347347900271416, 45.72871461510658, 47.061827480793, 46.92057766020298, 47.4777227640152, 54.373284950852394, 62.18120478093624, 62.97443501651287, 61.44915886223316, 52.455041483044624, 45.13778552412987, 49.02076296508312, 60.92531517148018, 61.85648560523987, 61.064657494425774, 60.22625148296356, 59.82283852994442, 55.7925695925951, 55.53868621587753, 56.90104991197586, 56.57389126718044, 54.355954080820084, 55.44863484799862, 54.767323806881905, 55.094357058405876, 55.10645940899849, 58.074457347393036, 59.59303446114063, 58.636268600821495, 59.199683368206024, 55.630314499139786, 56.209893599152565, 59.61985722184181, 57.16477856040001, 58.232547864317894, 44.24696892499924, 7.515473747625947, 0.17813660844694823, 3.371503036469221, 4.296682141721249, 21.579359360039234, 20.244977362453938, 6.3183308858424425, 0.3904160769889131, 0.3309283987618983, 0.19073520350502804, 3.6234926898032427, 43.88064578175545, 53.62105831503868, 27.838962972164154, 55.926577001810074, 21.830176301300526, 0.38814854866359383, 0.17052220297046006, 0.16366989410016686, 0.11989353413810022, 0.20956020976882428, 0.10299632325768471, 0.15942345868097618, 0.1393137057311833, 0.15217398206004873, 0.10455507828737609, 0.12334407554590143, 0.10459793731570244, 0.09763348993146792, 0.2281586977187544, 0.1318571699084714, 0.06748225627234206, 0.1803285416099243, 0.08494044173858128, 0.11166806652909145, 0.09958047725376673, 0.16397873143432662, 0.20429890224477276, 0.08230081541114487, 0.18911147344624624, 0.22444479778641835], [0.04133068650844507, 0.06688597772154026, 0.06388349313056096, 0.01123925881984178, 0.09871098445728421, 0.036110660948907025, 0.043034475747845136, 0.004833467273783754, 0.01448267887099064, 0.02974000777612673, 0.03830346613540314, 0.012155081112723565, 0.029253166321723256, 0.043146755269845016, 0.058616548994905315, 0.018068659446726087, 0.02785380791465286, 0.026569040819595102, 0.05827263776154723, 0.020478104961512145, 0.032065711202449165, 0.05636956702801399, 0.04682292070356198, 0.053072256851010025, 0.041069780781981535, 0.045213228368083946, 0.018322420146432705, 0.08760666663874872, 0.030262396248872392, 0.012227724382682936, 0.1542472161236219, 0.16636831336654723, 0.06044077395927161, 18.743117451667786, 50.06676323711872, 34.78760451078415, 49.12333466112614, 62.46697224676609, 14.940816331654787, 0.36906018387526274, 0.03760167644941248, 0.07699130539549515, 0.6337641924619675, 2.737451959401369, 10.812733992934227, 1.5440294542349875, 2.014761851169169, 0.47910242748912424, 0.1167510508093983, 4.332873299717903, 45.72265774011612, 59.642207622528076, 59.046479389071465, 60.669444501399994, 61.81282214820385, 62.38449767231941, 64.11858782172203, 61.866216883063316, 61.80649168789387, 66.31515115499496, 58.179776296019554, 47.35709823668003, 56.4423955231905, 64.13852915167809, 64.4921837747097, 61.8136391043663, 61.15139164030552, 62.89920285344124, 63.430304154753685, 63.17808508872986, 61.166727617383, 50.33143803477287, 42.39645682275295, 45.36746799945831, 44.55805063247681, 46.16557337343693, 45.33482775092125, 45.37254832684994, 44.47468690574169, 46.4078863710165, 52.438303381204605, 56.8841902166605, 56.71016335487366, 56.91976010799408, 56.63318328559399, 56.0253868997097, 57.0099862664938, 59.17534567415714, 60.755076706409454, 56.02404177188873, 59.60866302251816, 58.91451247036457, 58.71284209191799, 52.58891209959984, 48.518483117222786, 49.23411011695862, 45.78843221068382, 46.39248199760914, 42.76204660534859, 41.881561651825905, 43.191157579422, 42.40106597542763, 41.738886907696724, 46.283515244722366, 55.319840759038925, 58.01528312265873, 60.615722984075546, 58.044245168566704, 51.51522271335125, 40.377560555934906, 46.2344104796648, 56.468237936496735, 57.69242964684963, 58.891671895980835, 58.29006537795067, 55.61270244419575, 53.83549600839615, 53.64577978849411, 52.40054860711098, 53.944895938038826, 53.99104446172714, 51.26318223774433, 50.69782957434654, 49.32152062654495, 52.67487868666649, 52.91870400309563, 54.30642753839493, 59.14252683520317, 53.42029228806496, 54.88364316523075, 56.03990212082863, 56.461455300450325, 54.87327732145786, 39.738168865442276, 10.111833103001118, 0.1523947561508976, 0.67082425695844, 0.2831193938618526, 1.6161013743840158, 14.32757768779993, 2.1937111113220453, 1.0395660297945142, 0.09581041900673881, 0.06460547665483318, 3.1306128250434995, 28.422780744731426, 49.1704673320055, 20.35875465720892, 33.765128776431084, 29.7884426638484, 0.34083259699400514, 0.009945430101652164, 0.019161560958309565, 0.04438291725818999, 0.009225035701092565, 0.028199758198752534, 0.020128327050770167, 0.028625246304727625, 0.052375254017533734, 0.038439034251496196, 0.0356089579872787, 0.025251339066016953, 0.027924697860726155, 0.04263825794623699, 0.01636427092307713, 0.09754096638062038, 0.015985419377102517, 0.04827866934647318, 0.025624162517488003, 0.008769990636210423, 0.009060126776603283, 0.027253709158685524, 0.04278761516616214, 0.05972222286800388, 0.004019555772174499, 0.06268313605687581, 0.006731842067893012, 0.06676814693491906, 0.11424787575379014, 0.04074207434314303, 0.021199860275373794, 0.026850283247767948, 0.0439659712719731, 0.03857432406221051, 0.05494505909155123, 0.0028952064485565643, 0.014866033397993306, 0.023151072273321915, 0.018570423635537736, 0.04570539473206736, 0.023127488675527275, 0.06294433493167162, 0.016224390928982757, 0.014250589811126702, 0.012333913655311335, 0.026865634572459385, 0.015446314027940389, 0.03706340787175577, 0.08029235599678941, 0.07550502850790508, 0.02037476089753909, 0.03805846834438853, 0.009221206219081068, 0.05793424439616501, 0.0225677887283382, 0.03851559049508069, 0.0809771430795081, 0.0194378476953716, 0.1357630782877095, 27.68680013716221, 56.18818536400795, 31.618794947862625, 63.21883790194988, 67.33257696032524, 12.018044516444206, 0.09532190772006288, 0.16565087920753285, 0.11325532002956606, 0.5922666192054749, 0.7907951006200165, 5.384300155565143, 7.452449854463339, 6.910945661365986, 1.5869165654294193, 0.1723984710406512, 7.058197734877467, 53.54704588651657, 60.853905603289604, 59.62037019431591, 62.598065212368965, 65.06456986069679, 63.73807244002819, 64.61110979318619, 62.51278258860111, 63.28524313867092, 68.30630511045456, 59.54888842999935, 51.19714938104153, 57.69399136304855, 66.66696667671204, 66.12865716218948, 63.72379280626774, 59.27550449967384, 63.49298179149628, 63.58158923685551, 64.1629010438919, 63.040931448340416, 52.53923736512661, 46.35824203491211, 48.01748760044575, 46.98024585843086, 47.29132756590843, 44.84678953886032, 46.7253365367651, 46.47865757346153, 48.422139286994934, 55.495262145996094, 59.75800260901451, 58.48505191504955, 58.39036859571934, 58.377255499362946, 57.47864931821823, 56.66694067418575, 61.74845740199089, 61.851131692528725, 57.00472354888916, 62.3806294798851, 60.98041981458664, 61.36853098869324, 55.60922183096409, 51.34854085743427, 52.53181256353855, 49.9634163826704, 47.48908035457134, 43.47795478999615, 44.4379922747612, 43.9175646007061, 43.14446188509464, 43.79810281097889, 47.096158638596535, 58.17088097333908, 60.62675379216671, 62.52701282501221, 59.007839262485504, 53.15123252570629, 42.618102729320526, 48.77825237810612, 58.09582740068436, 60.25573790073395, 60.24630680680275, 60.031048357486725, 57.11814746260643, 56.29517622292042, 54.928005784749985, 52.856128960847855, 54.8597576469183, 54.88431952893734, 53.68092030286789, 51.74817681312561, 52.692661732435226, 54.99191075563431, 54.40265357494354, 56.47110678255558, 58.727155923843384, 56.34173892438412, 55.68001203238964, 58.11368644237518, 57.35122315585613, 56.88690707087517, 43.579937517642975, 13.16347785294056, 0.6990647572092712, 2.4338634498417377, 2.521947710774839, 4.756701607257128, 5.2794053591787815, 1.1581251304596663, 0.2815799124073237, 0.16669989010551944, 0.04498517751926556, 3.8004019344225526, 27.20207154750824, 58.49534176290035, 24.82065763324499, 30.537471771240234, 41.35443113744259, 1.0369137721136212, 0.2096937518217601, 0.00633507043858117, 0.04256085565430112, 0.04336640871770214, 0.045080680793034844, 0.04648528432880994, 0.00820105929960846, 0.04184811929007992, 0.03179538020049222, 0.06300738779827952, 0.036374624323798344, 0.02958820517960703, 0.04188752362097148, 0.004730653381557204, 0.06871409525047056, 0.01747109698044369, 0.07283035054570064, 0.02891107891628053, 0.03208693291526288, 0.022168583782331552, 0.048931770434137434, 0.01663100436417153, 0.020275008828321006, 0.005380289103413816, 0.018607727688504383, 0.18037642497802153, 0.25948044669348747, 0.20097464468562976, 0.14796992327319458, 0.13042323669651523, 0.12065433940733783, 0.14271058986196294, 0.06781552510801703, 0.23538368346635252, 0.09073024004464969, 0.16468063986394554, 0.167490188323427, 0.13850233051925898, 0.16063498507719487, 0.28980457107536495, 0.13386144360993057, 0.06844297386123799, 0.1123253496189136, 0.1796783015015535, 0.18109889089828357, 0.1080578965775203, 0.18733842327492312, 0.1730205985950306, 0.15596374432789162, 0.10172520982450806, 0.11096828064182773, 0.06249463796848431, 0.18780434358632192, 0.18470684182830155, 0.19338627374963835, 0.2205965097527951, 0.4175856284564361, 0.28943892975803465, 31.81901190429926, 66.8164886534214, 44.599578604102135, 63.963046967983246, 74.34744134545326, 22.75705486536026, 0.7109828176908195, 0.20853730762610212, 0.21608135750284418, 2.2136742901057005, 11.420877110213041, 28.4257160872221, 10.038802921772003, 8.53535184636712, 0.7308798562735319, 0.2506210142746568, 6.125283194705844, 55.85217699408531, 64.57283064723015, 63.93121987581253, 65.77316343784332, 68.15451085567474, 65.67311480641365, 68.26782837510109, 65.24987831711769, 64.82547149062157, 70.21745055913925, 64.0196867287159, 54.12713035941124, 61.53979539871216, 69.26791951060295, 69.47471961379051, 63.13167817890644, 60.12570507824421, 63.36962901055813, 64.90193098783493, 66.78425878286362, 65.60639798641205, 57.086628153920174, 47.72999882698059, 51.73642784357071, 50.303912311792374, 50.00503934919834, 50.20455524325371, 49.054816737771034, 49.4045689702034, 50.8839625865221, 57.39409625530243, 63.77146124839783, 61.212830543518066, 59.54828806221485, 60.67857161164284, 61.722633987665176, 61.35322920978069, 64.47396755218506, 64.87846344709396, 58.754408061504364, 65.28586238622665, 64.05019909143448, 64.50783893465996, 56.86032749712467, 54.344319105148315, 55.93838296830654, 49.94118757545948, 50.45943796634674, 46.43250524997711, 46.87990844249725, 46.69741563498974, 46.42276257276535, 44.718740209937096, 48.891725689172745, 60.65205283463001, 62.270621582865715, 63.18650923669338, 61.61919593811035, 56.71490550041199, 44.33125980198383, 52.057522013783455, 62.93023578822613, 60.35461239516735, 62.31081202626228, 61.91237300634384, 59.98319752514362, 57.610718831419945, 57.452335730195045, 55.23373357951641, 58.47412370145321, 57.92129136621952, 56.87479332089424, 54.50938604772091, 54.18437048792839, 57.865882739424706, 55.45102871954441, 58.6336999386549, 61.18408128619194, 57.21586301922798, 57.995771169662476, 59.08013038337231, 58.02428863942623, 57.15793512761593, 42.958819046616554, 11.756512150168419, 0.5106799502391368, 2.5257066590711474, 1.1175835621543229, 3.5919377580285072, 28.069243915379047, 8.385151606053114, 2.195245041511953, 0.22250293870456517, 0.24288905260618776, 6.266149710863829, 40.331750214099884, 61.42210811376572, 31.232501976191998, 44.306298941373825, 47.07584112882614, 1.1056874692440033, 0.3002246213145554, 0.042489765328355134, 0.10837042980710976, 0.16707811824744567, 0.11287086526863277, 0.18091733189066872, 0.09792213342734613, 0.19246278970967978, 0.17445537785533816, 0.18806215084623545, 0.11324580569635145, 0.1514760812278837, 0.1820658944780007, 0.09113911146414466, 0.20280292548704892, 0.10187927226070315, 0.19931597431423143, 0.13685090350918472, 0.10449733177665621, 0.11871445443830453, 0.13613496848847717, 0.1543650246458128, 0.1514991174917668, 0.10452954098582268, 0.24519435624824837], [0.026702048526203725, 0.0516166900342796, 0.07849510438973084, 0.059039075931650586, 0.05245466381893493, 0.017875589728646446, 0.03200483653927222, 0.01163354796517524, 0.05482997796207201, 0.023008540956652723, 0.04463276498427149, 0.056753632161417045, 0.06537718407344073, 0.02254183025797829, 0.035677302366821095, 0.047819495157455094, 0.019707429128175136, 0.07193333891336806, 0.05286957632051781, 0.0348769666015869, 0.1177125031244941, 0.05379680820624344, 0.02356295495701488, 0.07005225430475548, 0.07110925071174279, 0.014477638760581613, 0.036794627958443016, 0.0631907131173648, 0.020551494089886546, 0.04431678076798562, 0.012406403857312398, 0.1250592159340158, 0.041532676841598004, 0.3937083628261462, 30.88543239980936, 45.37634812295437, 27.303081527352333, 40.12656882405281, 60.759142488241196, 18.331122659146786, 0.9356302069500089, 0.08208349230699241, 0.08310918492497876, 0.22441284090746194, 8.569742850959301, 6.632916005328298, 5.888073798269033, 2.470298744738102, 0.07790074057993479, 0.3056662855669856, 8.220080863684416, 48.3621671050787, 61.84129782021046, 60.340929329395294, 66.37826576828957, 67.70263150334358, 63.22444640100002, 66.43786177039146, 65.39743199944496, 64.16284024715424, 55.07120490074158, 52.3661794513464, 62.73361913859844, 65.2942219376564, 64.59934562444687, 60.975271090865135, 59.708407670259476, 63.918574154376984, 64.6921518445015, 62.61639542877674, 56.405852884054184, 47.11603917181492, 44.99711327254772, 46.76291652023792, 46.092659085989, 45.20471513271332, 45.92486009001732, 45.47872602939606, 44.37339574098587, 45.0030941516161, 50.78369736671448, 58.02988953888416, 57.90896862745285, 59.44770745933056, 58.46640631556511, 56.25201813876629, 57.75566965341568, 60.27862787246704, 61.845591589808464, 54.94349755346775, 56.93514168262482, 60.27572102844715, 57.474955916404724, 53.40724378824234, 47.13647447526455, 42.778199538588524, 45.84897816181183, 44.22986604273319, 43.422067388892174, 45.10463610291481, 41.843951269984245, 43.67504261434078, 44.40364211797714, 53.06499235332012, 57.257326394319534, 61.81878782808781, 57.525079026818275, 60.27924343943596, 52.96148970723152, 41.13933987915516, 44.85329858958721, 55.42009457945824, 59.9108000099659, 60.5034314095974, 59.393989741802216, 58.300404623150826, 57.45990872383118, 55.528559759259224, 55.09160600602627, 52.76896923780441, 53.37275683879852, 53.26216757297516, 52.34526917338371, 53.468139320611954, 53.335705026984215, 53.57687808573246, 57.04761564731598, 57.40083709359169, 55.81032603979111, 56.667628437280655, 51.67798697948456, 56.352849528193474, 39.383275508880615, 9.602231997996569, 0.2228063138318248, 0.8899286936502904, 1.490846558008343, 4.149495614692569, 7.000540578737855, 3.548245090059936, 0.5588269885629416, 0.04851289115322288, 0.07446249655913562, 4.816398303955793, 29.82449132949114, 45.43413922190666, 21.56130462884903, 29.298466555774212, 40.25407858192921, 2.91884686332196, 0.19073398638283834, 0.031721495688543655, 0.015591468836646527, 0.039974767860258, 0.05427027615951374, 0.002975731558763073, 0.04319067556934897, 0.05828617082443088, 0.008534904227417428, 0.0668114735162817, 0.06231568389921449, 0.0285453336982755, 0.0206889658147702, 0.05924137796682771, 0.06950522467377596, 0.004535730149655137, 0.07856902971980162, 0.03301803510112222, 0.01344554604656878, 0.01834219652664615, 0.012876339187641861, 0.026725689640443306, 0.020654715699492954, 0.03579355608962942, 0.023041765052767005, 0.017580226085556205, 0.03546373452991247, 0.03911874504410662, 0.06119311132351868, 0.041795382276177406, 0.059618210871121846, 0.05180615291465074, 0.05112481310789008, 0.05318647337844595, 0.027148960580234416, 0.021893258126510773, 0.06116244949225802, 0.05405290852650069, 0.029000329595874064, 0.025034952923306264, 0.08931620381190442, 0.012802333149011247, 0.032840071799000725, 0.02086787535517942, 0.02099418517900631, 0.035366539159440435, 0.09462976595386863, 0.02217570840002736, 0.06291742465691641, 0.030666876009490807, 0.06865650459076278, 0.040275371065945365, 0.02894880042731529, 0.040238156070699915, 0.046109564646030776, 0.08546334414859302, 0.02129144500941038, 0.06222213989531156, 0.0691418543283362, 1.5030121989548206, 43.8123444467783, 46.224508211016655, 33.345768079161644, 58.9967742562294, 66.46199807524681, 17.19474993646145, 0.7310213393066078, 0.061879115528427064, 0.11843740328913555, 0.27328798547387123, 1.4259729953482747, 7.393990941345692, 5.811139801517129, 4.3342953734099865, 0.574129776796326, 0.13070216547930613, 11.884317342191935, 54.00790795683861, 62.210140228271484, 61.67405739426613, 68.46173197031021, 66.38271152973175, 65.3183126449585, 66.30985423922539, 66.96487829089165, 65.11557832360268, 60.80499842762947, 54.0026680380106, 65.02370685338974, 66.64720013737679, 66.67498424649239, 62.82050907611847, 60.00027380883694, 65.93463197350502, 65.92670559883118, 65.66068947315216, 58.268573731184006, 48.55564892292023, 46.63102179765701, 48.15073125064373, 48.380352929234505, 47.32522174715996, 48.149766102433205, 47.980363592505455, 45.64241744577885, 48.084835186600685, 54.44527588784695, 61.522882506251335, 60.76076880097389, 61.31245739758015, 60.40428712964058, 59.79375869035721, 59.52614285051823, 63.09720262885094, 61.21406547725201, 57.91643522679806, 59.446126744151115, 61.56979858875275, 60.46435810625553, 54.789670407772064, 48.43561716377735, 47.2554536908865, 46.5175636857748, 47.27230578660965, 45.735713839530945, 46.447541043162346, 44.6510886400938, 45.91656893491745, 46.65517710149288, 53.85960191488266, 58.85537624359131, 63.28638307750225, 59.89629998803139, 60.41588790714741, 52.28899419307709, 43.794196620583534, 46.13849602639675, 58.64525131881237, 60.87985821068287, 61.29234507679939, 59.99176986515522, 61.10613226890564, 59.42075930535793, 58.02884839475155, 56.234900057315826, 53.38944934308529, 55.288405045866966, 55.16803130507469, 54.530246928334236, 55.27727164328098, 55.03476865589619, 56.46349959075451, 58.43316949903965, 58.61570030450821, 56.533906012773514, 59.22749787569046, 54.38618145883083, 56.50823079049587, 44.16502632200718, 11.111027486622334, 0.8286186866462231, 1.935909076128155, 3.323911540210247, 5.724016651511192, 5.631536263972521, 1.2342895497567952, 0.2391774088027887, 0.14064848801353946, 0.008169101492967457, 5.3603186924010515, 29.549729973077774, 54.136018082499504, 30.883371010422707, 25.535161793231964, 49.50351946055889, 7.185819111764431, 0.3316533286124468, 0.03762048618227709, 0.025092294963542372, 0.01531452251583687, 0.03647695164545439, 0.050752228999044746, 0.030192458107194398, 0.018075092011713423, 0.035081780806649476, 0.040964674117276445, 0.050424114378984086, 0.07356732545304112, 0.03267339285230264, 0.06704696439555846, 0.028916338887938764, 0.015659301134292036, 0.022070401355449576, 0.026394782689749263, 0.0619993731379509, 0.03468221220828127, 0.01911953313538106, 0.02026224203291349, 0.06950991504709236, 0.013897583557991311, 0.046400323262787424, 0.020705396964331158, 0.1361931677092798, 0.13142348849214613, 0.14008178404765204, 0.22066842386266217, 0.11739753565052524, 0.24328280647750944, 0.14970746909966692, 0.13379934069234878, 0.1564215010148473, 0.0702685458236374, 0.17000151216052473, 0.12399260129313916, 0.12406586611177772, 0.16456011508125812, 0.1648486769408919, 0.1279451313894242, 0.10236778354737908, 0.17075801297323778, 0.08184893653378822, 0.12356817445834167, 0.32802826375700533, 0.1482865383150056, 0.1250012542004697, 0.2221358724636957, 0.15189935773378238, 0.20564852748066187, 0.1688327779993415, 0.18163138185627759, 0.09952509077265859, 0.16441756335552782, 0.094785757974023, 0.3234477579826489, 0.17018933489453048, 1.2646141787990928, 49.44582715630531, 57.07929074764252, 41.06687396764755, 53.38598012924194, 74.71763268113136, 27.519255727529526, 1.1588525539264083, 0.1586608128855005, 0.1850300916703418, 0.7343712158035487, 22.064122147858143, 18.27502626925707, 10.765210893005133, 7.041469607502222, 0.4870816133916378, 0.3902704082429409, 9.706714991480112, 54.575247913599014, 65.66579639911652, 63.99240419268608, 71.8412858247757, 70.54734885692596, 68.23541611433029, 68.90133798122406, 70.93279257416725, 68.32801714539528, 61.66146107017994, 58.87722127139568, 69.32322174310684, 70.2079738676548, 66.94941312074661, 63.22255030274391, 61.05939857661724, 66.93555146455765, 69.73494485020638, 69.21938091516495, 60.655803233385086, 50.78856110572815, 47.9142851382494, 49.681688100099564, 50.05548544228077, 49.54523742198944, 50.13295188546181, 51.12694434821606, 47.40545444190502, 51.009918227791786, 55.972919315099716, 65.17075896263123, 64.39959794282913, 63.63549694418907, 62.740454971790314, 61.335719749331474, 61.844520047307014, 66.20269998908043, 63.193706050515175, 58.42569150030613, 61.34776510298252, 66.83853507041931, 61.46837443113327, 58.098236471414566, 51.341005861759186, 47.99507260322571, 49.100205302238464, 48.40691350400448, 48.18598955869675, 49.206280410289764, 46.035597547888756, 49.42375034093857, 49.67892944812775, 57.130698189139366, 62.88137800991535, 65.43517917394638, 61.05170018970966, 63.85634109377861, 56.59645825624466, 46.91000662744045, 48.19064050912857, 58.255992606282234, 64.16768878698349, 63.72757740318775, 61.69746033847332, 62.56933495402336, 63.05621802806854, 61.38366177678108, 59.78253789246082, 54.715745374560356, 58.79144847393036, 56.84802755713463, 58.92848812043667, 57.02103987336159, 57.51939453184605, 57.90100425481796, 61.616661474108696, 60.364571660757065, 60.65174885094166, 59.74901229143143, 54.886485412716866, 56.61718614399433, 42.63371229171753, 10.467969942837954, 0.38568758696783334, 2.043632226996124, 3.987539280205965, 8.866672217845917, 15.455662105232477, 9.462660737335682, 2.1076986892148852, 0.22619193216087297, 0.22767875081626698, 9.751635231077671, 44.30066764354706, 54.552437737584114, 32.469128519296646, 37.258798107504845, 58.70622664690018, 8.534550089389086, 0.5261250527109951, 0.1385984238004312, 0.14607753575546667, 0.1013937963580247, 0.16984284098725766, 0.18859150994103402, 0.09098478927626275, 0.10798549265018664, 0.13094130030367523, 0.27672653377521783, 0.22313790541375056, 0.14536381233483553, 0.08722161815967411, 0.23505483783083037, 0.2610036008991301, 0.0748200187808834, 0.16135851969011128, 0.12644183705560863, 0.13405855803284794, 0.12780314369592816, 0.12075580583768897, 0.10485927719855681, 0.1418628345709294, 0.0817407610884402, 0.14001230418216437, 0.13146328245056793], [0.04560151261102874, 0.07807350513758138, 0.037729463147115894, 0.0979117582028266, 0.03175552687025629, 0.06331473341560923, 0.03941663570003584, 0.03807335582678206, 0.030222507666621823, 0.03048116654099431, 0.09250213988707401, 0.03295735710707959, 0.0573143989458913, 0.031733314390294254, 0.06342894252156839, 0.05440215209091548, 0.06549704092321917, 0.01581862168677617, 0.0835812056902796, 0.051223140253569, 0.0953260860114824, 0.022606100246775895, 0.020278359625081066, 0.11985270117293112, 0.047166906151687726, 0.04371681745396927, 0.03598315626732074, 0.014666607185063185, 0.018248400192533154, 0.006817649646109203, 0.04870597200351767, 0.06439110729843378, 0.023858045860833954, 0.10704082029405981, 4.949271474033594, 46.142820194363594, 44.32759299874306, 26.403040923178196, 41.578026339411736, 62.55020298063755, 24.539653211832047, 1.0631850874051452, 0.1359419952495955, 0.363026077975519, 0.15991569554898888, 6.327310279011726, 5.123656941577792, 4.080613860860467, 0.7540318951942027, 0.008082036438281648, 0.12275431305170059, 7.732349960133433, 45.852337181568146, 65.48548087477684, 63.772487193346024, 66.73381268978119, 65.45898869633675, 64.03220325708389, 64.41812574863434, 64.70675066113472, 55.57824209332466, 52.192110791802406, 62.762451991438866, 67.30859264731407, 66.22299090027809, 62.98033609986305, 61.84977896511555, 61.52807682752609, 62.25967817008495, 57.71835185587406, 53.7787726521492, 46.27695679664612, 46.07639595866203, 48.30424681305885, 49.36287380754948, 45.921702459454536, 44.71480742096901, 44.9585947394371, 45.879486724734306, 45.39770297706127, 48.228676468133926, 56.26538962125778, 59.296061396598816, 59.0415358543396, 58.79803352057934, 58.59994255006313, 60.99666774272919, 59.774847105145454, 65.25466606020927, 38.46024803817272, 46.08930006623268, 65.56589215993881, 59.39113229513168, 56.2214145809412, 50.67267492413521, 50.595314875245094, 49.60476502776146, 48.513980358839035, 44.20691907405853, 43.26838843524456, 43.44184912741184, 42.986302971839905, 45.512741804122925, 55.32353036105633, 57.351671531796455, 60.59685319662094, 59.67620059847832, 60.855098739266396, 53.03858757019043, 42.428641095757484, 45.24041421711445, 53.62319380044937, 57.76784420013428, 60.08469007909298, 59.64046351611614, 62.875112146139145, 59.626385271549225, 59.18222330510616, 54.82544168829918, 56.2854715436697, 54.34205822646618, 54.04519535601139, 53.512885719537735, 52.80935347080231, 57.17504180967808, 58.177864998579025, 55.26825852692127, 58.01378980278969, 56.675680205225945, 54.12183724343777, 56.60324089229107, 38.66428188979626, 12.427501995116472, 0.4154685779940337, 1.1000036867335439, 0.7475012924987823, 3.3622811688110232, 8.81573025137186, 5.536077786237001, 0.25519677030388266, 0.086180822836468, 0.06757653871318325, 4.523435924202204, 34.223585575819016, 50.57893015444279, 31.478905454277992, 24.4225187972188, 43.40398035943508, 10.540867131203413, 0.06949602204258554, 0.08864234114298597, 0.05864579703484196, 0.03478732629446313, 0.03234276235161815, 0.038783880590926856, 0.07006744606769644, 0.024677471519680694, 0.08224013741710223, 0.01519090483270702, 0.03795870885369368, 0.027182815501873847, 0.04907511996862013, 0.043235761040705256, 0.07476750441128388, 0.06843978262622841, 0.027832914602186065, 0.04996001604013145, 0.017296451078436803, 0.03770208160858601, 0.02225679359980859, 0.018763901534839533, 0.025632758442952763, 0.024776349710009526, 0.029507240578823257, 0.05930919542151969, 0.007116277811292093, 0.07367569385678507, 0.06998744996963069, 0.05078617112303618, 0.01823957234591944, 0.04158718016697094, 0.11169726261869073, 0.05886482336791232, 0.011488738255138742, 0.07704911869950593, 0.02850036325980909, 0.048505161685170606, 0.08917426806874573, 0.09466798655921593, 0.0517113917885581, 0.14116493373876438, 0.03216003446141258, 0.0363105398719199, 0.04435643000761047, 0.03404652561584953, 0.008940170664573088, 0.00961184307016083, 0.031758974146214314, 0.026750913384603336, 0.01778400684997905, 0.03307018952909857, 0.0276741766356281, 0.04365851804323029, 0.02739320323598804, 0.013151660205039661, 0.03862920588289853, 0.05125140865857247, 0.050667100949794985, 0.04323445857153274, 0.09099970644456334, 9.217768628150225, 58.58524493873119, 41.598742827773094, 28.835005424916744, 57.07862578332424, 68.28856766223907, 20.999481976032257, 1.1687628971412778, 0.08685957625857554, 0.007642615901204408, 0.06873008111142553, 2.0663272216916084, 4.6184835489839315, 6.692065531387925, 2.857912858016789, 0.13178748224163428, 0.14945867151254788, 11.831147745251656, 54.255445674061775, 66.29867523908615, 66.86500445008278, 70.70590674877167, 67.52448946237564, 68.00625041127205, 66.92517802119255, 67.43799090385437, 57.72048354148865, 54.195093512535095, 65.7060818374157, 70.8324171602726, 67.49972999095917, 63.94243687391281, 62.665439397096634, 62.52067856490612, 64.41315561532974, 60.65886966884136, 57.233668863773346, 48.557909801602364, 48.95282261073589, 49.44831982254982, 52.108492478728294, 48.287098333239555, 47.12002135813236, 47.6746129989624, 47.3855397105217, 46.85805581510067, 51.070277988910675, 58.24129119515419, 63.18106032907963, 60.59663660824299, 61.290597170591354, 59.965087696909904, 61.86645247042179, 60.84969162940979, 66.11038014292717, 41.73141270875931, 49.587396159768105, 65.72428286075592, 60.941262915730476, 58.65552216768265, 51.88006013631821, 51.50200702250004, 49.22618754208088, 49.95585858821869, 45.5725733935833, 45.11705003678799, 44.573295414447784, 45.43239511549473, 46.42967440187931, 57.28980325162411, 60.73495298624039, 61.562552377581596, 60.34520410001278, 62.934495359659195, 55.77101334929466, 44.423366859555244, 47.03650563955307, 56.00209794938564, 60.677522867918015, 60.9683782607317, 60.86537718772888, 62.52555750310421, 61.74297049641609, 59.05584588646889, 55.86062394082546, 56.70041307806969, 56.91537134349346, 56.05605885386467, 54.12474788725376, 54.79678362607956, 58.266282454133034, 59.22353468835354, 57.68073387444019, 59.94339466094971, 57.52377949655056, 54.242488369345665, 58.26578088104725, 41.68554536998272, 14.800952486693859, 0.8894438040442765, 2.326513035222888, 2.3856958094984293, 3.540840237401426, 6.637339917942882, 2.4839210137724876, 0.2577182021923363, 0.08992538088932633, 0.028343504782242235, 4.6490467339754105, 36.50694765150547, 56.20433069765568, 39.63715508580208, 19.517291709780693, 49.07903663814068, 17.80658360570669, 0.06369283539243042, 0.07013049893430434, 0.09598092001397163, 0.07835279015125707, 0.01463626540498808, 0.061930308875162154, 0.04443762838491239, 0.013221071421867236, 0.043426118209026754, 0.0284579569415655, 0.019410334425629117, 0.043033269757870585, 0.03819031087914482, 0.10520784911932424, 0.06416107120458037, 0.02205132259405218, 0.005866293786311871, 0.06827126315329224, 0.042513454682193696, 0.03087731012783479, 0.013884396521461895, 0.03567429295799229, 0.0058024148165714, 0.05281829391606152, 0.04100695798115339, 0.10378457314800471, 0.04448040206625592, 0.25547032593749464, 0.18139993568183854, 0.15594434458762407, 0.14231768203899264, 0.16257699258858338, 0.1547345845028758, 0.21074139716802165, 0.10734751282143407, 0.15855556150199845, 0.10340005901525728, 0.19090831687208265, 0.13626255851704627, 0.10565437711193226, 0.20320414536399767, 0.23151280445745215, 0.1825820581871085, 0.21152672299649566, 0.08714525858522393, 0.18234335380839184, 0.2051561718690209, 0.11336732495692559, 0.11555182180018164, 0.1390915660886094, 0.1790541849914007, 0.15821491571841761, 0.07669404556509107, 0.1600709231570363, 0.1308356036315672, 0.08118179030134343, 0.1710610170266591, 0.14252454828238115, 0.18699716893024743, 0.0877151389431674, 0.31300223723519593, 8.377840798348188, 66.50035321712494, 55.385535433888435, 39.44708548486233, 53.219435065984726, 76.10433027148247, 33.608854562044144, 2.0245107030496, 0.2322510929661803, 0.5721583357080817, 0.3405685111647472, 18.128663823008537, 13.808976765722036, 10.988835543394089, 3.5192089481279254, 0.09814557924983092, 0.32237817475106567, 10.54497281089425, 52.167043536901474, 69.96978744864464, 67.35268548130989, 71.78034469485283, 72.14243486523628, 69.46116954088211, 69.35136303305626, 72.59480059146881, 61.867527812719345, 57.63718441128731, 68.96716564893723, 74.46895122528076, 70.51425263285637, 63.21746617555618, 62.76223920285702, 65.86145550012589, 65.08226931095123, 62.15329147875309, 59.404484778642654, 51.31877325475216, 52.40939453244209, 53.526219204068184, 54.331661984324455, 51.31801329553127, 50.25939770042896, 51.989828646183014, 51.06023132801056, 50.45561917126179, 52.546608969569206, 60.966953337192535, 63.51482301950455, 64.87106904387474, 63.160647824406624, 63.56953248381615, 65.03879964351654, 63.271362483501434, 66.4849716424942, 42.587875351309776, 53.969951793551445, 68.68633791804314, 64.51011881232262, 61.56082347035408, 56.02680802345276, 54.35749299824238, 54.19146090745926, 53.10439623892307, 48.32312799990177, 45.915466994047165, 46.96601182222366, 47.21557103097439, 48.91291715204716, 59.51604299247265, 62.511103078722954, 62.48345576226711, 63.067222237586975, 65.58887332677841, 59.252584129571915, 47.07516096532345, 49.32798407971859, 57.97311678528786, 63.54879319667816, 62.49505653977394, 60.96581719815731, 65.25964379310608, 62.96899750828743, 62.14785397052765, 58.52152235805988, 60.16456179320812, 58.74289467930794, 58.623201102018356, 55.381659641861916, 57.698896899819374, 62.24377602338791, 61.81824825704098, 59.41629834473133, 60.86652472615242, 59.94019903242588, 55.50746709108353, 61.01095877587795, 40.729186087846756, 13.796388041228056, 0.6063071032986045, 2.12402475066483, 2.7657602028921247, 6.656307075172663, 16.84733457863331, 13.504467755556107, 2.406338439323008, 0.3165133675793186, 0.24184774520108476, 8.256751745939255, 45.388693660497665, 60.71645937860012, 44.88262161612511, 32.69963175058365, 58.75698812305927, 20.190127305686474, 0.16855451714945957, 0.24226944835390896, 0.17067112232325599, 0.15776707412442192, 0.08248267869930714, 0.1375938527053222, 0.2311732867383398, 0.07757168714306317, 0.18431469099596143, 0.13447870267555118, 0.14595895539969206, 0.12387871873215772, 0.27288520708680153, 0.3346882079495117, 0.20275633345590904, 0.10993967880494893, 0.0662485248176381, 0.17088221880840138, 0.0947844740585424, 0.22103593539213762, 0.11437259367085062, 0.09477899700868875, 0.10994064359692857, 0.10401757783256471, 0.146308210096322, 0.17753255960997194, 0.08810634724795818], [0.017939334647962824, 0.029529486455430742, 0.06569968434632756, 0.03249589710321743, 0.01999353447899921, 0.020537172495096456, 0.05754909943789244, 0.054793093222542666, 0.03779752179980278, 0.08657151905936189, 0.057737541865208186, 0.011022900507668965, 0.03024572019057814, 0.03728496863914188, 0.06975429685553536, 0.029609703342430294, 0.023102129489416257, 0.06274835599469952, 0.059989666915498674, 0.06037894192559179, 0.033269192717853, 0.02646884160640184, 0.12511965644080192, 0.0366104714339599, 0.06798638234613463, 0.11875207390403375, 0.01273976546144695, 0.046273059779196046, 0.0829468623851426, 0.050732844101730734, 0.02691269230126636, 0.021667110886482988, 0.07412706065224484, 0.025802682430366985, 0.023498879781982396, 4.065184313803911, 30.449918769299984, 40.71683295071125, 31.745645441114902, 44.05890181660652, 66.05918169021606, 28.141322247684002, 1.636232694145292, 0.00867925937200198, 0.2265992821776308, 1.6094467439688742, 2.7371299266815186, 5.721618980169296, 2.3597256280481815, 0.5088956491090357, 0.07092358020599931, 0.5464757513254881, 13.922825306653976, 46.9185371696949, 67.7210833132267, 64.97501626610756, 62.87502095103264, 65.69715231657028, 64.25075232982635, 58.60623501241207, 55.76867647469044, 61.2263198196888, 70.21699458360672, 66.74688398838043, 63.60018543899059, 65.26461392641068, 66.92327812314034, 64.92421299219131, 63.148807659745216, 57.09674321115017, 48.74471917748451, 48.47957320511341, 48.50046828389168, 52.60113224387169, 51.11923076212406, 49.277385994791985, 45.201926082372665, 46.07033148407936, 48.30979071557522, 44.71973955631256, 46.2502746284008, 51.3741172850132, 58.96514855325222, 59.37619149684906, 61.84152960777283, 58.33560213446617, 60.51014944911003, 58.36802579462528, 65.92427372932434, 40.79718343913555, 47.687323316931725, 64.83460620045662, 60.070452243089676, 61.213841289281845, 56.55158646404743, 57.06194847822189, 53.514162451028824, 54.81367751955986, 47.83960774540901, 45.342146158218384, 44.229824244976044, 45.16660317778587, 50.60063078999519, 57.656384781003, 61.45431138575077, 62.87072718143463, 62.39190727472305, 63.02675060927868, 55.116513669490814, 45.316018760204315, 44.41806614398956, 53.02445612847805, 58.46017844974995, 62.43886895477772, 61.15063548088074, 61.684499233961105, 60.969765186309814, 61.99344165623188, 59.444720819592476, 57.08823546767235, 56.34894713759422, 57.37032853066921, 55.32606102526188, 58.059037774801254, 56.43784336745739, 58.38974542915821, 60.781162306666374, 56.157198026776314, 55.762885585427284, 53.76313269138336, 34.29339163005352, 8.87480853125453, 0.5553039838559926, 0.38906836649402976, 0.9870698873419315, 2.411939101293683, 5.017542410641909, 5.563974939286709, 1.0977682191878557, 0.1546260082977824, 0.03453088087553624, 6.116612534970045, 41.88679397106171, 40.39695471525192, 32.18757502734661, 23.425047621130943, 43.91520872712135, 23.227752707898617, 0.07696259170188569, 0.03626983307185583, 0.05811290902784094, 0.07995682361070067, 0.0184682484541554, 0.028598265525943134, 0.036364939296618104, 0.041535534110153094, 0.04701817233581096, 0.08287318938528188, 0.06215837456693407, 0.02936508404673077, 0.07200074818683788, 0.06095152370107826, 0.038956233256612904, 0.051107161125401035, 0.06515895554912277, 0.023962601480889134, 0.07394229556666687, 0.03947909855924081, 0.03718723892234266, 0.03614750487031415, 0.06161200915812515, 0.012640942932193866, 0.01620591887331102, 0.06443073056288995, 0.07649138729902916, 0.051806561095872894, 0.016590583290962968, 0.03129328761133365, 0.04544973227893934, 0.08329489253810607, 0.06918249433510937, 0.005076288716736599, 0.05831028691318352, 0.03659871581476182, 0.035668637792696245, 0.06769093335606158, 0.08010437741177157, 0.020030172454426065, 0.018900219220086, 0.026070603307744022, 0.04541256923403125, 0.02973581835249206, 0.053688951884396374, 0.023559841647511348, 0.04103990562725812, 0.004492619254961028, 0.02458752136590192, 0.012237985501997173, 0.041713913014973514, 0.009836650733632268, 0.04037816222989932, 0.01578646628331626, 0.06522516996483319, 0.02007552880968433, 0.025632292745285667, 0.08588262047851458, 0.0312859069526894, 0.06942548090592027, 0.04941704966768157, 0.04596069724357221, 0.06405282896594144, 11.380495727062225, 45.84683507680893, 40.48421323299408, 31.61253098398447, 56.73838824033737, 75.54563105106354, 25.40178705006838, 1.040323139168322, 0.06475052941823378, 0.1165042570210062, 0.5694186233449727, 0.9622800175566226, 6.748920930549502, 5.461814571171999, 1.9398095668293536, 0.07282819831743836, 0.905450563877821, 17.922283597290516, 54.498499631881714, 72.31784865260124, 65.59967994689941, 66.02936089038849, 68.47479566931725, 67.05890044569969, 60.83047606050968, 59.41635154187679, 63.41262750327587, 73.68474170565605, 69.52441334724426, 66.12785920500755, 66.50986790657043, 68.17965790629387, 66.80786311626434, 66.8689714372158, 59.81970749795437, 52.25034646689892, 50.08388131856918, 50.041494593024254, 53.267996460199356, 52.223983481526375, 51.42405800521374, 48.523293659090996, 47.82285824418068, 50.60256488621235, 47.88775496184826, 47.06866331398487, 54.074860364198685, 61.27102442085743, 62.07036092877388, 63.84359657764435, 61.73491112887859, 64.03110131621361, 60.46401232481003, 65.60385212302208, 41.21267594397068, 48.60225722193718, 65.46631470322609, 60.285714492201805, 62.08234928548336, 59.82780106365681, 57.91488490998745, 55.791399255394936, 54.76643845438957, 49.451162070035934, 46.89108744263649, 46.85720466077328, 45.93502074480057, 51.91799730062485, 59.29324574768543, 62.13256359100342, 63.60893256962299, 62.46555492281914, 64.35847654938698, 57.29323446750641, 47.31518268585205, 45.56235574185848, 53.32243233919144, 61.11937835812569, 62.16570921242237, 61.83245949447155, 62.10017412900925, 63.00137177109718, 63.73649552464485, 61.61036141216755, 59.28428202867508, 57.390885427594185, 58.88852186501026, 57.19244487583637, 59.359901770949364, 59.841981902718544, 59.8388584703207, 59.91986632347107, 57.91416674852371, 55.35793371498585, 57.78009474277496, 40.29058322310448, 11.479992438107729, 1.1092078615911305, 1.1408463888801634, 3.5475991247221828, 1.6832583770155907, 3.8796260207891464, 5.901184994727373, 0.30911210691556334, 0.19511552236508578, 0.06018940854119137, 3.5534866712987423, 45.35657398402691, 49.11478891968727, 39.06761884689331, 25.164991356432438, 45.454783514142036, 34.337070286273956, 0.8274679421447217, 0.050177695375168696, 0.049240344305871986, 0.09960558410966769, 0.03404553855943959, 0.07178282394306734, 0.0338897061010357, 0.04925425586407073, 0.057261146139353514, 0.033213984352187254, 0.02326568584976485, 0.027891004356206395, 0.08954693010309711, 0.030262390682764817, 0.018626092132763006, 0.04091695031092968, 0.0860218696470838, 0.04635682598745916, 0.07190006101154722, 0.14340549241751432, 0.03837889802525751, 0.0363044319965411, 0.05207992006035056, 0.022342424454109278, 0.03337488196848426, 0.03536277275998145, 0.043850734291481785, 0.024395362634095363, 0.12383069435600191, 0.1412412413628772, 0.21734600682975724, 0.1347377270576544, 0.28942500706762075, 0.2092962575261481, 0.20399048051331192, 0.12565137556521222, 0.14826782135060057, 0.1624711326439865, 0.12712167401332408, 0.11418058522394858, 0.12867595389252529, 0.1354472796083428, 0.15246481489157304, 0.14223563019186258, 0.10094473022036254, 0.0932559986540582, 0.1910643608425744, 0.112086548760999, 0.1180286802991759, 0.10038417865871452, 0.18673597747692838, 0.20584994636010379, 0.16523061582120135, 0.18066954362438992, 0.1534310169517994, 0.18330602324567735, 0.1856058498378843, 0.1445148399216123, 0.15977632021531463, 0.1711358700413257, 0.212914984440431, 0.22373401327058673, 0.1622190696070902, 10.419854074716568, 54.16450895369053, 54.83439400792122, 45.357694923877716, 55.077668353915215, 81.23134195804596, 39.97964210808277, 3.229637173935771, 0.10838355097803287, 0.7615070440806448, 4.280067533254623, 10.191016104072332, 16.153307519853115, 8.43066556379199, 2.0577696058899164, 0.17077193566365167, 1.1780715663917363, 16.942677162587643, 53.08454230427742, 72.66825065016747, 69.52462613582611, 69.29693475365639, 70.55780589580536, 70.57887196540833, 62.0054642111063, 59.74952906370163, 67.0476758480072, 77.01794564723969, 72.54322975873947, 65.33392980694771, 66.3101202249527, 70.54647490382195, 70.9092566370964, 70.51523298025131, 61.674011796712875, 53.249240666627884, 53.73387426137924, 50.32939754426479, 57.73358903825283, 55.87364204227924, 55.249369740486145, 50.59681199491024, 51.99208952486515, 53.9487299323082, 50.21187745034695, 51.607565358281136, 57.36183978617191, 65.01885831356049, 66.48706153035164, 66.97310104966164, 63.95118400454521, 65.56920558214188, 63.42601798474789, 67.2089771926403, 46.66870437562466, 53.09594169259071, 68.57267081737518, 63.35629552602768, 65.4682981967926, 62.22975857555866, 61.87128581106663, 59.35609817504883, 57.81249940395355, 52.122848108410835, 50.681273862719536, 50.15644982457161, 48.39639186859131, 56.94286286830902, 63.14546003937721, 65.53071364760399, 65.04866391420364, 65.79154685139656, 67.43842408061028, 60.52319414913654, 48.82198803126812, 47.34527327120304, 55.83142250776291, 61.80707685649395, 66.54921099543571, 63.52505587041378, 62.902998849749565, 65.38384392857552, 66.99111968278885, 62.618644908070564, 61.4933542907238, 60.12746058404446, 60.92549756169319, 60.678750202059746, 61.43829524517059, 60.91730140149593, 63.8036835193634, 63.46312679350376, 56.857500448822975, 56.78487874567509, 58.06740492582321, 37.53185525536537, 10.575364530086517, 0.8622550161089748, 1.223958854097873, 3.497797097079456, 5.704430602490902, 17.62055318802595, 13.56894364580512, 2.268372355028987, 0.3710993385175243, 0.11273583892034367, 9.598643090575933, 54.223793372511864, 51.801218166947365, 46.66492737829685, 34.85201105475426, 56.35532699525356, 37.894845977425575, 0.6981076241936535, 0.1521270931698382, 0.10637864645104855, 0.20695356448413804, 0.10209704807493836, 0.10264220749377273, 0.18290864769369364, 0.1326964795589447, 0.11843445696285926, 0.10379289262345992, 0.08400244129006751, 0.10979161292198114, 0.22487692069262266, 0.1641503456630744, 0.1448227124637924, 0.17250578559469432, 0.20362431969260797, 0.1421976470737718, 0.197861646884121, 0.2696356689557433, 0.23023430665489286, 0.15920911158900708, 0.2257183677284047, 0.07950219878694043, 0.1573870945139788, 0.14168966183206066, 0.1598055608337745, 0.13190125348046422], [0.07760388150927611, 0.07944759156089276, 0.017721846415952314, 0.07025059327133931, 0.028160526417195797, 0.022705286428390536, 0.03039000297576422, 0.039463532011723146, 0.03812085327808745, 0.0780664844205603, 0.05040756077505648, 0.04800735870958306, 0.07244378808536567, 0.019286969072709326, 0.07349373408942483, 0.030620658762927633, 0.05256470205495134, 0.07500261679524556, 0.03639354166807607, 0.05169803313037846, 0.05264981526124757, 0.03516333541483618, 0.04827091390325222, 0.13070774642983451, 0.03763041982892901, 0.015061311005410971, 0.02397731826931704, 0.03721460190718062, 0.03837502401438542, 0.079638227034593, 0.04893896926660091, 0.06613640114665031, 0.06929933806532063, 0.051845727939507924, 0.017876446909212973, 0.15449412865564227, 4.549874430522323, 32.710115388035774, 44.25484590232372, 32.54179961979389, 36.54201216995716, 58.248104229569435, 39.11423094570637, 3.3453932125121355, 0.02994553629832808, 0.1251339798909612, 0.7435506326146424, 4.307055585086346, 4.280444663017988, 1.6656644898466766, 0.3721711481921375, 0.05746279137383681, 3.3862474327906966, 22.382049188017845, 47.907320111989975, 67.09255144000053, 65.99637106060982, 63.33923824131489, 62.40619830787182, 63.19364905357361, 59.95362751185894, 63.965927213430405, 65.73693618178368, 66.21016278862953, 65.34463763237, 68.08466300368309, 65.35131767392159, 63.65005776286125, 60.05524545907974, 51.665052473545074, 51.250965893268585, 54.006859213113785, 53.12770418822765, 56.28867857158184, 53.28885354101658, 52.313860058784485, 50.07981553673744, 47.746003568172455, 47.86853939294815, 45.567880645394325, 46.86996057629585, 45.59078961610794, 55.58308303356171, 58.84265072643757, 60.22451877593994, 60.28678223490715, 65.79537704586983, 61.23964950442314, 65.98059430718422, 40.2189114689827, 51.74518257379532, 65.64283043146133, 62.05290086567402, 61.0742823779583, 58.205390721559525, 61.91995359957218, 59.5596494525671, 59.099938720464706, 53.91392379999161, 46.676455959677696, 44.24360230565071, 46.14204503595829, 51.21876262128353, 60.42947977781296, 62.78538376092911, 64.85064893960953, 62.951028272509575, 62.11465895175934, 58.88381011784077, 52.66076624393463, 47.12420113384724, 50.58111123740673, 57.24922142922878, 59.69870679080486, 65.11991009116173, 62.71828696131706, 61.70990847051144, 60.759115889668465, 59.1975212842226, 60.204129070043564, 59.29885044693947, 59.967625960707664, 57.91316360235214, 57.792873457074165, 60.57224951684475, 59.108127281069756, 55.11441618204117, 59.66782584786415, 55.159151181578636, 28.10994353145361, 7.666064891964197, 0.2683380385860801, 0.2378437842708081, 1.098443039227277, 4.716214304789901, 2.6446853997185826, 5.218305112794042, 0.5566154478583485, 0.30718742113094777, 0.057100819976767525, 4.7675471752882, 48.03886145353317, 30.718708746135235, 39.25427243113518, 46.858496591448784, 30.610663443803787, 28.53373099118471, 0.3135416895383969, 0.01794831463485025, 0.019620813072833698, 0.0058300310593040194, 0.12477516633225605, 0.0860295731399674, 0.03654991218354553, 0.06706134721753187, 0.057221348470193334, 0.10077228478621691, 0.01609051862033084, 0.033277686598012224, 0.04103423190827016, 0.06525619173771702, 0.03380934263987001, 0.06943941101781093, 0.03836713498458266, 0.0600680080242455, 0.00919411411814508, 0.02139038813766092, 0.03100150297541404, 0.048550488354521804, 0.027260184397164267, 0.08276795284473337, 0.07045426827971824, 0.0233539810142247, 0.04533517065283377, 0.04258034074155148, 0.03151665921905078, 0.031262432821677066, 0.03906375561200548, 0.04991696034267079, 0.044795807407354005, 0.10403319261968136, 0.028647173057834152, 0.06360875006066635, 0.0653249368770048, 0.03592584020225331, 0.03961703412642237, 0.0588855663954746, 0.016975051039480604, 0.052272614993853495, 0.04245780473866034, 0.027623719870462082, 0.060304563885438256, 0.06092813862778712, 0.0177533654277795, 0.03921259332855698, 0.035026190234930255, 0.09070260988664813, 0.046924650596338324, 0.014811026339884847, 0.0781979484600015, 0.015452389434358338, 0.04815276028239168, 0.034894173295469955, 0.029903658760304097, 0.02047009904345032, 0.0709476183692459, 0.012498214018705767, 0.0362671613402199, 0.05613890381937381, 0.04225319091347046, 0.021436685165099334, 0.22707535506924614, 10.501428097486496, 43.3469720184803, 45.644963309168816, 32.350293695926666, 53.15644584596157, 68.64898592233658, 33.737827241420746, 2.1749477181583643, 0.08409370318986475, 0.14225272927433252, 0.19252489262726158, 2.0399761106818914, 2.473738035187125, 1.7942109983414412, 0.7223643944598734, 0.09004653649753891, 4.848885610699654, 26.580442003905773, 55.01129351556301, 70.79694986343384, 69.37593251466751, 66.82667210698128, 65.9482504427433, 65.13396933674812, 59.810648784041405, 65.62729686498642, 70.00718504190445, 68.39996248483658, 65.41613459587097, 68.02479341626167, 67.38212630152702, 66.40323802828789, 62.60629557073116, 56.52512848377228, 53.151817694306374, 56.20256379246712, 57.14706011116505, 57.352074310183525, 55.21982632577419, 53.757759779691696, 53.18058215081692, 48.71919974684715, 48.800374791026115, 48.10460552573204, 49.81142833828926, 48.52923274040222, 59.132651165127754, 59.623014852404594, 62.42764435708523, 62.457183972001076, 66.77518486976624, 64.03989404439926, 66.9319036602974, 43.67390267550945, 52.997268587350845, 68.52867677807808, 63.47595490515232, 63.49869288504124, 59.65571969747543, 61.77882917225361, 61.15431368350983, 60.57062700390816, 56.83981999754906, 48.09804327785969, 45.94995774328709, 48.45250345766544, 53.73953975737095, 62.08324983716011, 66.25441521406174, 64.21479105949402, 62.93891452252865, 65.02861618995667, 60.86540758609772, 52.17221885919571, 47.80901178717613, 51.8697664886713, 59.32693853974342, 63.110004141926765, 66.06294348835945, 62.990534752607346, 60.41572071611881, 63.50242428481579, 61.62877142429352, 61.60091891884804, 62.565994933247566, 61.33417323231697, 61.273551285266876, 59.44484241306782, 61.981859877705574, 60.38270428776741, 57.72838331758976, 59.36004236340523, 59.195704981684685, 32.284177243709564, 8.557260520756245, 0.345285750227049, 1.8284181877970695, 2.1494957339018583, 3.8221695413812995, 2.047988218255341, 2.6405215356498957, 0.6598467647563666, 0.19503663206705824, 0.1899642456555739, 3.0788254039362073, 49.67759571969509, 43.631371557712555, 41.04190930724144, 46.683804765343666, 32.48166024684906, 38.11917833983898, 2.0567785715684295, 0.019209928577765822, 0.06559746092534624, 0.030935477807361167, 0.16308236547047272, 0.13935090217273682, 0.0287923037467408, 0.035469430513330735, 0.03279071897850372, 0.049409694984206, 0.031350852295872755, 0.06623540364671499, 0.03704543676576577, 0.014915938190824818, 0.04316253704018891, 0.030422523886954878, 0.06649213479249738, 0.006993874467298156, 0.016881753799680155, 0.025600981534807943, 0.06329780502710491, 0.06836590182501823, 0.06223122378287371, 0.07473233403288759, 0.033235480659641325, 0.003725550027411373, 0.02078040583000984, 0.050073586899088696, 0.00808852280897554, 0.10427757442812435, 0.14403164241230115, 0.1051348217879422, 0.27224541641771793, 0.23354710545390844, 0.12231130283907987, 0.11811857664724812, 0.1264475070638582, 0.09902795572998002, 0.1301031929324381, 0.1567023148527369, 0.12276738969376311, 0.25920926593244076, 0.18028224643785506, 0.09146757118287496, 0.13911231653764844, 0.196654706960544, 0.19950068002799526, 0.15310825692722574, 0.16383951937314123, 0.20750588562805206, 0.2085567667381838, 0.07511322648497298, 0.2265478513436392, 0.1390282460488379, 0.20808284607483074, 0.08847626333590597, 0.08444142164080404, 0.1297815758152865, 0.16371702047763392, 0.16557783703319728, 0.1197742264776025, 0.1614706582040526, 0.21748846949776635, 0.10241473923088051, 0.24227703310316429, 10.783841293305159, 55.47217458486557, 57.5843558460474, 42.5080606341362, 52.055584117770195, 68.48745658993721, 50.147569701075554, 5.625439491122961, 0.2044907325762324, 0.34895160351879895, 1.750825282651931, 13.192810378968716, 12.10550157353282, 3.9936151541769505, 1.9690792774781585, 0.15316106815589592, 4.977205200120807, 26.525941528379917, 55.06592698395252, 72.01786994934082, 72.4353839457035, 70.00039100646973, 68.27000185847282, 70.88182210922241, 65.1192033290863, 69.59974810481071, 71.49200096726418, 70.09608507156372, 68.47156584262848, 69.95576620101929, 68.82705196738243, 69.46015119552612, 65.21492019295692, 58.42973068356514, 56.36930264532566, 57.86483019590378, 60.78603744506836, 61.8987051397562, 58.61705303192139, 59.46792237460613, 56.395468041300774, 52.4213220924139, 52.96925649046898, 51.220464929938316, 52.434161603450775, 49.53108698129654, 60.28316482901573, 62.39248104393482, 63.992312997579575, 66.35083884000778, 68.95698979496956, 65.7028216123581, 66.7327943444252, 43.82998310029507, 55.84274969995022, 69.26180943846703, 66.97302505373955, 65.00512585043907, 61.34982459247112, 66.2239408493042, 63.14002253115177, 64.12510827183723, 59.131769612431526, 50.78454092144966, 49.24900911748409, 50.04362627863884, 55.34006707370281, 63.94429877400398, 66.98852822184563, 66.34505555033684, 64.93308931589127, 66.80545404553413, 65.37651792168617, 57.10095338523388, 52.15973272919655, 55.49677826464176, 61.99628010392189, 65.88929280638695, 68.87781724333763, 63.36276277899742, 60.21989442408085, 62.606253772974014, 63.01179841160774, 63.17839287221432, 64.6712301671505, 62.952966168522835, 61.48238427937031, 62.39904709160328, 63.929593563079834, 62.02906094491482, 56.329552978277206, 62.335544899106026, 59.84316743910313, 30.88153760880232, 9.158043432980776, 0.42461263888981193, 1.323220927733928, 2.8912038216367364, 10.404633991420269, 9.777564089745283, 18.05612001568079, 3.5031980322673917, 0.6310448446311057, 0.22075187094742432, 7.846904788166285, 59.77695979177952, 43.30317556858063, 50.93260757625103, 52.92164884507656, 42.74141751229763, 43.46269480884075, 1.5367814619094133, 0.13559315615566447, 0.1306699265842326, 0.1080169077613391, 0.2786461729556322, 0.2462806081166491, 0.1477674357010983, 0.1430682753561996, 0.19115147413685918, 0.2186166972387582, 0.16712046519387513, 0.10465732397278771, 0.0787332966865506, 0.1945993141271174, 0.18737625796347857, 0.13778712280327454, 0.16555054084165022, 0.21196672751102597, 0.18160411535063758, 0.06967476088902913, 0.27056845952756703, 0.16623275267193094, 0.2017006729147397, 0.2424031833652407, 0.14504945342196152, 0.22348005033563823, 0.1092093312763609, 0.22424251801567152, 0.29419799626339227], [0.02101307654811535, 0.027111894014524296, 0.040616558617330156, 0.062025901206652634, 0.02932856481493218, 0.0210778901600861, 0.04644346801796928, 0.012657115257752594, 0.060087797392043285, 0.014549830248142825, 0.025122227634710725, 0.011816466958407545, 0.060169103380758315, 0.021012486540712416, 0.02739975639997283, 0.06474111156421714, 0.0402150530135259, 0.049469148434582166, 0.11469458928331733, 0.015674663591198623, 0.046721368926228024, 0.04094457304745447, 0.032668004860170186, 0.042440134202479385, 0.08679635269800201, 0.06401917256880552, 0.01473757227358874, 0.010865231233765371, 0.07222930740681477, 0.004745710166389472, 0.06535574342706241, 0.024272457412735093, 0.17377862823195755, 0.056063883821479976, 0.028277808014536276, 0.038773861597292125, 0.03506275585095864, 6.421774160116911, 35.12974955141544, 45.69842644035816, 34.50109988451004, 31.17108017206192, 54.451731741428375, 48.959856033325195, 6.478506540879607, 0.04851004501688294, 0.5206022865604609, 1.5543369948863983, 2.978362119756639, 2.445843731984496, 0.7731333514675498, 0.185066471749451, 0.23984065133845434, 5.317554837092757, 26.67978197336197, 56.94890074431896, 68.56589198112488, 65.53557738661766, 68.42629507184029, 63.717333152890205, 66.69456079602242, 69.58924546837807, 73.72343882918358, 66.25534996390343, 65.96583589911461, 69.43039119243622, 68.08284670114517, 64.22813594341278, 58.347069919109344, 54.6697336435318, 55.63576340675354, 55.016176253557205, 56.16977155208588, 52.240474596619606, 51.96628890931606, 50.431418269872665, 51.67518272995949, 48.30044701695442, 49.558000937104225, 47.13719643652439, 48.48121851682663, 45.10907806456089, 55.203646793961525, 57.28840872645378, 64.24261316657066, 63.63781102001667, 64.90630075335503, 58.708909302949905, 64.53721895813942, 39.1736863553524, 46.39332555234432, 61.059409976005554, 64.30074244737625, 67.2910375893116, 62.97175616025925, 61.75559721887112, 62.069661766290665, 62.4950185418129, 59.425862431526184, 53.38358625769615, 44.53152045607567, 47.479349076747894, 56.27249523997307, 63.69025960564613, 63.76810982823372, 66.78867414593697, 62.74221047759056, 65.18126919865608, 62.08694323897362, 57.19582289457321, 52.924019917845726, 47.98670545220375, 51.88052751123905, 58.8523668050766, 60.83447724580765, 62.2650358825922, 63.05341377854347, 63.032526299357414, 62.41446666419506, 62.022840678691864, 61.08696609735489, 62.61858031153679, 59.53155755996704, 64.19721320271492, 57.2629538923502, 57.605676501989365, 54.58657130599022, 47.98086516559124, 18.425775580108166, 3.036195016466081, 0.25846450589597225, 0.04173552806605585, 2.920779772102833, 0.18775797419948503, 0.6947527604643255, 2.4513781350106, 0.45714355423115194, 0.3514192742295563, 0.04256815467670094, 7.164453333243728, 42.838148921728134, 48.58581930398941, 46.179746612906456, 38.833999782800674, 39.35138002038002, 26.434590630233288, 2.583025158382952, 0.0959647040872369, 0.06663332838797942, 0.02842518184479559, 0.03467508759058546, 0.013684780133189633, 0.049022178864106536, 0.020352242281660438, 0.023360871855402365, 0.054661224712617695, 0.06996638781856745, 0.014248506231524516, 0.02103755257849116, 0.020075883185199928, 0.04224685668305028, 0.08504101017024368, 0.05300893681123853, 0.1322859086212702, 0.03189876508258749, 0.007441476718668127, 0.0347834819694981, 0.022997150845185388, 0.056229041365440935, 0.05954254520474933, 0.04684026098402683, 0.05857296637259424, 0.07938881346490234, 0.04350941686425358, 0.050886884273495525, 0.0411714624351589, 0.0213177559999167, 0.04503878655668814, 0.051125614627380855, 0.013860317540093092, 0.036906057721353136, 0.04993277550966013, 0.019770428189076483, 0.0638211824116297, 0.08650369418319315, 0.03556291885615792, 0.027925662652705796, 0.02694659175176639, 0.05345519763068296, 0.05032488552387804, 0.023843045200919732, 0.06648005262832157, 0.0242815524325124, 0.04280606495740358, 0.07006927175098099, 0.020489005255512893, 0.08817505527986214, 0.028528151124191936, 0.04188565340882633, 0.05784758381196298, 0.07769976698909886, 0.029481181918527, 0.052789506007684395, 0.03509508751449175, 0.03311465901788324, 0.05444520778837614, 0.08543129079043865, 0.025516534406051505, 0.12850324128521606, 0.032088146326714195, 0.038671875663567334, 0.04323660337831825, 0.1347097777761519, 12.27884067222476, 47.73289427161217, 46.50551073253155, 32.25399926304817, 42.51674696803093, 72.34412044286728, 47.46215499937534, 4.35665194876492, 0.16760798200266436, 0.27961494284681976, 0.29721542028710246, 0.9595869714394212, 1.8273237277753651, 0.9242289187386632, 0.25006728305015713, 0.5294754635542631, 7.021537302061915, 31.60953864455223, 63.04296053946018, 72.3407082259655, 68.09857025742531, 70.53053855895996, 65.60577481985092, 71.14546716213226, 72.45145708322525, 70.65024733543396, 65.56631773710251, 64.96178537607193, 71.55108779668808, 70.43206304311752, 66.5081200003624, 60.47486834228039, 56.89735271036625, 57.22995646297932, 56.63597233593464, 57.5955880433321, 55.09213797748089, 53.472615480422974, 53.557734712958336, 53.37390057742596, 51.0628379881382, 49.264155104756355, 49.360704123973846, 49.786421880126, 47.40801550447941, 56.916617676615715, 60.08825048804283, 65.20247206091881, 65.6122724711895, 67.29229912161827, 63.3600877225399, 64.85657662153244, 40.66130273044109, 47.87904962897301, 63.49347576498985, 64.7333188354969, 65.70442512631416, 64.35362040996552, 63.88512074947357, 63.56421656906605, 63.63758683204651, 61.36923395097256, 54.664755910634995, 46.10796086490154, 49.11604665219784, 56.765659376978874, 65.61311602592468, 64.39213514328003, 66.71682000160217, 64.31825950741768, 66.11972764134407, 63.085582852363586, 58.03263679146767, 53.39681714773178, 50.30848726630211, 54.2727879434824, 60.57527035474777, 63.87516528367996, 63.81702080368996, 63.72141793370247, 62.84974470734596, 64.74116921424866, 63.04663494229317, 61.739516481757164, 63.47424879670143, 61.262410283088684, 63.300347328186035, 59.06265892088413, 57.163566425442696, 55.254138484597206, 53.257945999503136, 23.86412926018238, 4.583727288991213, 0.7150608894880861, 1.3715797453187406, 2.8043806180357933, 2.067850702442229, 1.2652422138489783, 2.5363506004214287, 0.23461682227207348, 0.14511706307530403, 0.01270436780032469, 5.431851278990507, 44.30748447775841, 58.17030340433121, 38.79481628537178, 40.00260427594185, 47.2090619802475, 35.101889446377754, 5.466592814773321, 0.12310452511883341, 0.024351952561119106, 0.10749562323326245, 0.056841914338292554, 0.030648407664557453, 0.04468949846341275, 0.00631656359473709, 0.060726493393303826, 0.06211912608705461, 0.0710244158108253, 0.027213186040171422, 0.03681296271679457, 0.04638342827092856, 0.008468323376291664, 0.08369436094653793, 0.020227888016961515, 0.09843575899139978, 0.012647120383917354, 0.024023620862863027, 0.03666612879897002, 0.0068331248166941805, 0.061239525239216164, 0.04788678197655827, 0.03542562153597828, 0.039146015260485, 0.030623683014709968, 0.005824470517836744, 0.07475620150216855, 0.007158272237575147, 0.1583026078878902, 0.13491014280589297, 0.14059963985346258, 0.23994164279429242, 0.14068365097045898, 0.17114838265115395, 0.19837653409922495, 0.22613532113609836, 0.15823585912585258, 0.09827808971749619, 0.12393517390592024, 0.15054732793942094, 0.09929381529218517, 0.17762940988177434, 0.20724559959489852, 0.18618010886712, 0.11841245228424668, 0.1294740743469447, 0.20675774139817804, 0.13434519030852243, 0.1589347841218114, 0.08041367487749085, 0.13387481711106375, 0.10973004435072653, 0.26018530887085944, 0.14648405456682667, 0.11658292467473075, 0.11640982615062967, 0.18761592713417485, 0.1820771157508716, 0.1431511584087275, 0.19655129610328004, 0.22384922427590936, 0.2084174656192772, 0.1248663614387624, 0.12471459223888814, 0.20791897986782715, 11.565109770745039, 59.17391695082188, 58.931691348552704, 47.40242600440979, 43.02618183195591, 69.29905503988266, 62.160146310925484, 10.501455646008253, 0.18049677164526656, 1.0339216701686382, 3.917777636088431, 10.680034663528204, 12.051066644489765, 2.022769683972001, 1.0853155748918653, 0.5696558731142431, 6.692585628479719, 31.052895113825798, 63.27422372996807, 75.34916639328003, 73.14089208841324, 74.5855213701725, 70.51597774028778, 72.15140238404274, 75.35824030637741, 78.24006646871567, 67.18543365597725, 66.34953171014786, 73.63512396812439, 73.9971761405468, 69.38935339450836, 65.38145005702972, 60.035995692014694, 61.61059319972992, 59.98771168291569, 59.93639923632145, 56.06068700551987, 56.267768293619156, 54.53270919620991, 55.85167922079563, 52.807103991508484, 53.57330247759819, 52.981643825769424, 52.96120472252369, 51.463879868388176, 59.71264824271202, 64.10592690110207, 69.55504730343819, 69.11888390779495, 69.94296848773956, 63.473127856850624, 64.09483149647713, 45.917363092303276, 50.60120455920696, 65.49871936440468, 67.61979594826698, 69.93651643395424, 68.19530546665192, 65.83744078874588, 66.93256482481956, 66.80861547589302, 65.45301541686058, 57.46849626302719, 49.19509381055832, 52.41048127412796, 61.52358926832676, 68.96826758980751, 65.9907853603363, 68.30192014575005, 66.67211920022964, 69.00666072964668, 64.88915607333183, 62.20985524356365, 56.790304854512215, 51.125982999801636, 55.12069344520569, 61.89312323927879, 65.35960122942924, 65.04509970545769, 64.23994570970535, 64.8552542924881, 65.93661546707153, 64.96463522315025, 63.27577404677868, 67.6216958463192, 63.24162907898426, 65.8850522339344, 58.71710926294327, 62.22568139433861, 60.992309376597404, 52.189272344112396, 21.20427578687668, 3.2194596575573087, 0.3221059846691787, 0.8128804655279964, 3.9428598526865244, 3.42481417581439, 10.50337454304099, 8.725397698581219, 1.7097496055066586, 0.6310275674331933, 0.19662579288706183, 10.573522578924894, 56.14317677915096, 61.2252938747406, 55.57525545358658, 47.39333689212799, 52.0849147439003, 40.39364889264107, 4.627235904335976, 0.2471276361029595, 0.1144958495569881, 0.1431662536924705, 0.13021147227846086, 0.14646889991126955, 0.20823599566938356, 0.10705378561397083, 0.11964429868385196, 0.16706202848581597, 0.16411506396252662, 0.10220335330814123, 0.14428848488023505, 0.18764135311357677, 0.06900803025928326, 0.18806566862622276, 0.09013828821480274, 0.16243641497567296, 0.14308872894616798, 0.04416357922309544, 0.17608612863114104, 0.09104645432671532, 0.15202877344563603, 0.17010152398142964, 0.1001924967567902, 0.12930213357321918, 0.16414911369793117, 0.07978423716849647, 0.14890485123032704, 0.14320223301183432], [0.03586017497582361, 0.12329107135883532, 0.022039808172849007, 0.03014260990312323, 0.020571682362060528, 0.030526192640536465, 0.023818005138309672, 0.010081502878165338, 0.033990137235377915, 0.020329371145635378, 0.03165776746755, 0.012987922946194885, 0.027595859646680765, 0.026658874085114803, 0.030026840431673918, 0.023239000074681826, 0.028809055875171907, 0.059155118142371066, 0.00980436638201354, 0.027365138921595644, 0.03339119808515534, 0.00758928192226449, 0.03290584092610516, 0.046067755756666884, 0.042944308515870944, 0.03006299230037257, 0.015544328543910524, 0.0653586229600478, 0.02750179799477337, 0.12564566102810204, 0.06702127124299295, 0.07541841987404041, 0.07587536019855179, 0.09833496049395762, 0.0587547888426343, 0.040424004691885784, 0.022645636308880057, 0.12631769059225917, 6.045160694047809, 43.324534222483635, 53.837867081165314, 35.02736784517765, 33.38639549911022, 53.40546168386936, 59.623410031199455, 9.00937071070075, 0.17316408542683348, 0.31785282539203763, 0.2590879693161696, 1.4043311378918588, 2.163984118960798, 0.8872059022542089, 0.0625916440912988, 0.2052175474818796, 7.006363766267896, 33.899075388908386, 64.10455137491226, 69.92830887436867, 66.13719150424004, 71.90752387046814, 70.94375118613243, 68.68014425039291, 68.06121066212654, 67.71681994199753, 66.28922134637833, 67.57879614830017, 65.67456632852554, 59.858446419239044, 54.95547831058502, 53.724059388041496, 56.27443313598633, 56.231837421655655, 56.0295894742012, 54.816219583153725, 53.711341470479965, 51.889559626579285, 53.9054274559021, 51.62431485950947, 48.607193157076836, 47.40223601460457, 49.95339632034302, 47.23526157438755, 52.68244408071041, 56.214567348361015, 63.225400149822235, 58.991872519254684, 71.95083394646645, 57.80752547085285, 63.88599470257759, 36.15746520459652, 47.2289615124464, 68.27788263559341, 61.78724192082882, 66.30511209368706, 62.377673238515854, 66.97652086615562, 63.27955864369869, 64.33992594480515, 62.35855646431446, 56.63451701402664, 45.674863904714584, 46.63335867226124, 56.091016978025436, 61.20477117598057, 68.63213762640953, 63.82012903690338, 61.79169908165932, 65.8442272245884, 62.578659653663635, 64.3592669069767, 60.29862239956856, 54.20297808945179, 50.96759609878063, 52.40457259118557, 62.29234881699085, 63.499247655272484, 62.17220686376095, 62.72419564425945, 62.62358844280243, 63.571090400218964, 61.56334653496742, 60.84177665412426, 61.75840526819229, 59.774771109223366, 60.99717691540718, 61.784802451729774, 42.123699858784676, 8.497693967074156, 0.8965159370563924, 0.18374443956417963, 0.677310983883217, 1.028516460210085, 15.711147096008062, 12.57665254175663, 0.9659446240402758, 0.18610681436257437, 0.24224663473432884, 0.12729462410788983, 9.508556574583054, 52.37923555076122, 40.647197887301445, 28.364244885742664, 34.61788661777973, 35.87057299911976, 29.283065982162952, 2.9346003429964185, 0.1300908435950987, 0.06179515636176802, 0.019724047670024447, 0.0165549435041612, 0.030055574534344487, 0.035304718257975765, 0.02958870984002715, 0.03142098896205425, 0.046445356783806346, 0.01692494308372261, 0.04514429398113862, 0.045581816011690535, 0.03298675728728995, 0.006294588138189283, 0.038226067554205656, 0.011037987442250596, 0.03621294745244086, 0.048130685099749826, 0.04647234127332922, 0.021149761596461758, 0.05244888991001062, 0.04235310996591579, 0.04123483071452938, 0.05071647232398391, 0.02961336027510697, 0.04120154910197016, 0.10757514435681514, 0.03750077034055721, 0.0301650357505423, 0.029945621645310894, 0.033251418280997314, 0.030647572748421226, 0.05742701614508405, 0.018438727674947586, 0.051289647817611694, 0.05928404032601975, 0.013348987995414063, 0.03344823213410564, 0.07841887098038569, 0.010058974985440727, 0.013399753679550486, 0.026295370153093245, 0.019158865106874146, 0.021097959688631818, 0.04500620627368335, 0.037903986594756134, 0.01844356276706094, 0.011522523600433487, 0.010856563876586733, 0.03001150951604359, 0.029152594179322477, 0.013289931594044901, 0.06570015932084061, 0.028798368948628195, 0.02732153589022346, 0.046752045600442216, 0.14003888791194186, 0.10202359029790387, 0.11517541934153996, 0.03565667066141032, 0.042060878186021, 0.02846022976882523, 0.01914250446134247, 0.02541304191254312, 0.020879425028397236, 0.090129953896394, 0.08143229482811876, 0.11759671324398369, 11.701113022863865, 53.240767121315, 52.77216486632824, 29.749971628189087, 40.160614997148514, 69.21843856573105, 58.583770617842674, 6.451905593276024, 0.20717454637633637, 0.32548762508668005, 0.40667970897629857, 0.7168184139300138, 2.2379036899656057, 1.2136251898482442, 0.02340682749490952, 0.3795313829323277, 9.243883676826954, 39.92496684193611, 67.75841251015663, 70.7861964404583, 70.80361470580101, 72.93124973773956, 72.06194758415222, 67.48884737491608, 71.40187740325928, 68.39588150382042, 65.83804115653038, 71.34483486413956, 69.1756984591484, 61.72026291489601, 57.2505209594965, 55.918969810009, 59.26382392644882, 59.037021696567535, 60.15096612274647, 57.516563683748245, 56.164702624082565, 54.85243543982506, 54.948346093297005, 51.60484470427036, 51.00725457072258, 50.80938018858433, 51.6901995241642, 49.40044619143009, 55.020420625805855, 59.544484466314316, 66.97397500276566, 60.78464671969414, 71.88490748405457, 61.792322248220444, 65.54152026772499, 41.87867000699043, 48.92500810325146, 66.14418312907219, 63.05023334920406, 68.56452405452728, 65.57894825935364, 69.48424190282822, 66.14618942141533, 68.26931789517403, 63.085351064801216, 58.17993588745594, 46.91704764962196, 49.7095862030983, 57.4889999628067, 62.76219740509987, 69.2828831076622, 65.66537082195282, 61.6177824139595, 66.33715957403183, 64.61526677012444, 65.18734127283096, 62.582227662205696, 56.343882009387016, 53.352196142077446, 56.0262418538332, 65.94046846032143, 64.21944960951805, 63.968594670295715, 65.8847938477993, 62.684837356209755, 64.42254111170769, 63.09205390512943, 62.3663916438818, 61.641846522688866, 62.670679315924644, 58.8570823520422, 64.26285848021507, 48.54312479496002, 12.147401925176382, 1.7277824878692627, 0.4613104462623596, 2.1702430956065655, 1.1041043791919947, 12.538848370313644, 17.83577173948288, 1.1979065020568669, 0.33453719574026763, 0.14059002161957324, 0.18327973637497053, 6.467238245531917, 54.4416356831789, 51.80489256978035, 35.543520748615265, 43.07545758783817, 38.96283566951752, 37.115222811698914, 6.5671163611114025, 0.04959133562806528, 0.03379904534085654, 0.03933609783416614, 0.08322853711433709, 0.04733953712275252, 0.038003126392140985, 0.057562547153793275, 0.01456619367672829, 0.025309497468697373, 0.035503743711160496, 0.031378152198158205, 0.007709463461651467, 0.01682563073700294, 0.01788012796168914, 0.021404186518338975, 0.036949388013454154, 0.13355262111872435, 0.013282262425491353, 0.03239526558900252, 0.02636677960254019, 0.0888309208676219, 0.0012749346819873608, 0.07788390124915168, 0.02624495049531106, 0.10655350386514328, 0.017053913506970275, 0.05425378192740027, 0.031984657543944195, 0.07965390861500055, 0.06073831951653119, 0.13956993963802233, 0.1619985033175908, 0.1393592735985294, 0.09459397959290072, 0.09769803451490588, 0.2154756462550722, 0.08693653697264381, 0.08868298114975914, 0.1264362857909873, 0.12534019304439425, 0.10905372517299838, 0.1431374583626166, 0.09462010319111869, 0.10500098287593573, 0.16095338127342984, 0.1079201688116882, 0.133362052438315, 0.1574757366324775, 0.16277974733384326, 0.14084916474530473, 0.1071158291597385, 0.08604405244113877, 0.18702237226534635, 0.0718139050877653, 0.15490355668589473, 0.13956517504993826, 0.2097821416100487, 0.13110728905303404, 0.19597338570747524, 0.18561230652267113, 0.14615881576901302, 0.08323601796291769, 0.1401397754671052, 0.22570563247427344, 0.22721870831446722, 0.25204317702446133, 0.17365936510032043, 0.2530337363714352, 9.829266965389252, 60.42829044163227, 67.5143364071846, 44.90037426352501, 46.866970136761665, 67.2792886197567, 73.32189917564392, 13.966810796409845, 0.3844662196934223, 0.5273883661720902, 1.393409811425954, 4.526831042021513, 6.259848223999143, 1.4877069764770567, 0.15409973653731868, 0.4101079859538004, 9.299386348575354, 38.58222149312496, 67.89587393403053, 74.87456426024437, 71.40178620815277, 78.87274011969566, 78.64440277218819, 72.50701010227203, 70.38958132266998, 68.49776923656464, 67.8615465760231, 72.76528984308243, 70.02808392047882, 64.79948088526726, 59.734295681118965, 59.15686346590519, 61.80344805121422, 61.37513503432274, 63.92486661672592, 62.66537860035896, 60.409960225224495, 59.24325183033943, 58.57810892164707, 56.32052466273308, 53.37662883102894, 53.717394545674324, 54.996212124824524, 52.613014206290245, 57.07140617072582, 61.47065430879593, 67.61956036090851, 64.16242986917496, 74.36132580041885, 66.2380912899971, 66.00171357393265, 44.51041638851166, 52.98963099718094, 71.96864739060402, 65.46413362026215, 68.2022362947464, 68.04620146751404, 71.24830484390259, 68.98297280073166, 69.69763085246086, 65.74352502822876, 59.77805033326149, 50.492849573493004, 50.20281873643398, 59.75483737885952, 64.66330379247665, 71.58337086439133, 66.12124755978584, 63.18782016634941, 67.77444005012512, 68.03043991327286, 67.66941368579865, 66.96113929152489, 59.268509075045586, 56.04298375546932, 56.530296206474304, 69.54687014222145, 65.3875221312046, 66.2711039185524, 65.22264137864113, 63.816435635089874, 63.404948115348816, 64.57717761397362, 61.07341982424259, 65.22565081715584, 62.03878842294216, 62.04641081392765, 63.22047561407089, 46.348187774419785, 9.299415796995163, 1.3291680836118758, 0.5943858367390931, 2.428684327751398, 2.8648838214576244, 28.703889660537243, 31.025717072188854, 2.6915810583159328, 0.2871416264679283, 0.5508692061994225, 0.2988789591472596, 15.558594781905413, 65.84203854203224, 51.48114614188671, 41.394541785120964, 43.85237529873848, 48.10996703803539, 43.73757965862751, 6.612657392397523, 0.19621514773461968, 0.13173419603845105, 0.07891800240031444, 0.10644358437275514, 0.21385969390394166, 0.12476155534386635, 0.17263437010115013, 0.11891219968674704, 0.09043129553901963, 0.16949437296716496, 0.11176375905051827, 0.12597061780979857, 0.09437576591153629, 0.1300645715673454, 0.09287976688938215, 0.09127272773184814, 0.28043388796504587, 0.11375572794349864, 0.2000225879601203, 0.06332643708446994, 0.1600783594767563, 0.07978117952006869, 0.17050792404916137, 0.16659302084008232, 0.1113783246546518, 0.13162836577976122, 0.194866620877292, 0.11651693290332332, 0.14288569218479097, 0.1962181756971404], [0.05268184264423326, 0.031691601980128326, 0.030815591271675657, 0.07028070220258087, 0.021008345356676728, 0.0665933192067314, 0.021291355951689184, 0.040759303301456384, 0.022756876824132632, 0.026183641675743274, 0.02052338339126436, 0.0446229575027246, 0.02159681280318182, 0.06973958006710745, 0.04557859509077389, 0.04607143680914305, 0.029558500718849245, 0.04882240013103001, 0.04972347873263061, 0.04630394796549808, 0.10451059395563789, 0.030478077351290267, 0.034918456367449835, 0.01701165190752363, 0.014772110898775281, 0.014083340338402195, 0.05339752904546913, 0.07419078145176172, 0.02763813052297337, 0.011802904209616827, 0.014768384389753919, 0.05166277740499936, 0.056508107445552014, 0.016390990094805602, 0.016158664475369733, 0.04998512289603241, 0.06138653727248311, 0.058744851485244, 0.1677943204413168, 5.866176523268223, 39.00304511189461, 51.1064026504755, 47.207576259970665, 31.236309371888638, 51.12319394946098, 66.20047330856323, 22.116595432162285, 0.17301218264037743, 0.13259839732199907, 0.08983092033304274, 3.8049158547073603, 3.326224428601563, 0.43844728090334684, 0.10481120087206364, 0.4235354857519269, 5.897015668451786, 29.62769228965044, 64.73987728357315, 71.59176081418991, 66.33821591734886, 69.03783425688744, 74.59154784679413, 71.3189734518528, 66.96588143706322, 69.39197525382042, 72.28242695331573, 68.15976977348328, 62.82470025122166, 58.50242078304291, 58.18660832941532, 60.1172049343586, 59.67790670692921, 55.900054425001144, 51.3300434499979, 51.729238629341125, 61.02423906326294, 61.1221332103014, 62.09546998143196, 62.622744888067245, 56.71455591917038, 56.579286977648735, 53.01306813955307, 51.34995058178902, 57.4262273311615, 66.6673694550991, 64.88359317183495, 64.94277879595757, 57.54424139857292, 71.30280911922455, 32.58460432291031, 39.950987845659256, 68.8892014324665, 59.19170759618282, 70.30124366283417, 61.91250219941139, 69.75796401500702, 62.92203202843666, 64.75306257605553, 63.61357972025871, 61.57749317586422, 48.470161110162735, 48.457830771803856, 59.60309252142906, 64.58597794175148, 64.93251174688339, 66.27574726939201, 64.4697193801403, 66.24204307794571, 65.50121203064919, 67.41106554865837, 64.4413349032402, 64.65947359800339, 58.69071967899799, 55.34463822841644, 55.67469231784344, 63.885895907878876, 63.91770780086517, 69.09151017665863, 64.83601972460747, 64.17129099369049, 61.658181846141815, 62.31127940118313, 60.30458427965641, 66.41897678375244, 54.872600957751274, 24.32411927729845, 1.5527284936979413, 0.1117864168190863, 0.2814632171066478, 1.2210644781589508, 1.7682891455478966, 17.12307248264551, 41.54272623360157, 2.2837622417137027, 0.3535441914573312, 0.2715088496915996, 0.3931124182417989, 18.183052204549313, 53.16163256764412, 34.94818389415741, 29.669792130589485, 23.637646213173866, 32.70903244614601, 29.993806444108486, 4.7500809375196695, 0.018239681812701747, 0.033630659454502165, 0.026980999573424924, 0.032448462734464556, 0.07631422922713682, 0.03560167009709403, 0.029235471665742807, 0.08571209720685147, 0.11186418647412211, 0.04462530640012119, 0.023201131989480928, 0.06741912176948972, 0.026307407788408455, 0.005005265184081509, 0.018512847818783484, 0.030057398362259846, 0.025946889145416208, 0.05475667603604961, 0.039288503903662786, 0.030006557535671163, 0.10638109553838149, 0.04372260249510873, 0.0329970805614721, 0.07079014205373824, 0.04430196378962137, 0.034310919436393306, 0.07664981356356293, 0.09811442389036529, 0.039080457645468414, 0.026561812301224563, 0.08374953220481984, 0.03800626196607482, 0.12525636004284024, 0.04100276484678034, 0.06912889642990194, 0.04671643735491671, 0.0765169171791058, 0.033453612704761326, 0.08287546035717241, 0.08001314519788139, 0.06803905998822302, 0.043480606691446155, 0.06042965287633706, 0.04826460193726234, 0.039677255699643865, 0.051653303889906965, 0.053015786834293976, 0.07186805218225345, 0.06916172162164003, 0.0932785079930909, 0.042814380722120404, 0.01841889192292001, 0.018169712129747495, 0.07477111124899238, 0.007086200421326794, 0.02697611809708178, 0.04146062543441076, 0.02454944176861318, 0.030462618415185716, 0.10357625971664675, 0.04996730021957774, 0.0528848497197032, 0.01990980908885831, 0.011035504958272213, 0.032517809013370425, 0.05216618730628397, 0.05907922241021879, 0.056015915106399916, 0.029102475091349334, 0.1660471860668622, 10.664234161376953, 51.31163343787193, 51.107280403375626, 41.99304386973381, 36.58885605633259, 66.71454012393951, 69.47738707065582, 15.445702839642763, 0.15378825715743005, 0.3058701386908069, 0.08534262640750967, 5.14232343994081, 3.313017524778843, 0.6636046443600208, 0.07431595950038172, 0.5531322816386819, 8.390080891549587, 36.50579631328583, 70.75349539518356, 73.64410668611526, 68.99915233254433, 74.04626190662384, 76.16497501730919, 68.18623155355453, 65.82439228892326, 70.13780683279037, 74.16815936565399, 71.26402080059052, 67.0874597132206, 60.73323167860508, 60.475852489471436, 61.37103505432606, 60.95347546041012, 59.17523168027401, 53.9245518296957, 53.60789202153683, 62.386978939175606, 61.92924030125141, 61.5446325391531, 61.356052458286285, 56.654739528894424, 56.826980486512184, 55.25783188641071, 53.73542457818985, 60.16322046518326, 68.09379771351814, 66.95735469460487, 69.28637892007828, 60.347875356674194, 69.79028508067131, 36.17375113070011, 43.75361479818821, 69.36542987823486, 61.3675582408905, 69.76779788732529, 63.08775633573532, 70.23492202162743, 63.61164562404156, 66.12020641565323, 65.7486243546009, 63.31840395927429, 51.52971513569355, 50.95921374857426, 61.5229395031929, 67.38577410578728, 69.4191361963749, 66.10338851809502, 65.60474127531052, 67.78568744659424, 67.24184542894363, 68.86950328946114, 64.670120626688, 63.67777347564697, 58.452700451016426, 58.94519962370396, 60.397971868515015, 66.51736870408058, 64.75373893976212, 69.19247075915337, 65.14306604862213, 63.61994817852974, 61.08664691448212, 62.51364894211292, 60.27708515524864, 63.84233504533768, 60.26462182402611, 30.820049308240414, 3.421792150475085, 0.6176736589986831, 1.102662831544876, 4.329893309623003, 0.7458606117870659, 17.80370146036148, 51.701325327157974, 4.460606770589948, 0.508997174911201, 0.21983128128340468, 0.46668217051774263, 14.226090833544731, 60.50198368728161, 47.52188019454479, 33.05188424885273, 27.994515225291252, 35.5895970761776, 39.73001450300217, 9.078887980431318, 0.03765293658943847, 0.10056667277240194, 0.05712777106964495, 0.0364975981938187, 0.029952798213344067, 0.050701677610049956, 0.01994838963582879, 0.008951609015639406, 0.022120672583696432, 0.01844667236582609, 0.06373141222866252, 0.06467935745604336, 0.07178384068538435, 0.05313610381563194, 0.04362688399851322, 0.04800945898750797, 0.03574220689188223, 0.11215762424399145, 0.05957326640782412, 0.027890059973287862, 0.09872093665762804, 0.029538581475208048, 0.010206266251771012, 0.03304131627373863, 0.050428255563019775, 0.06361871710396372, 0.04560571687761694, 0.05665904172929004, 0.01787551365850959, 0.0024424330513284076, 0.004039396626467351, 0.13259309838758782, 0.22307209175778553, 0.08172225192538463, 0.19177642185240984, 0.05136588493769523, 0.21681396116036922, 0.06494883869891055, 0.13014622265473008, 0.11254963406827301, 0.11721713439328596, 0.1224748944514431, 0.17573779419763014, 0.13008725160034373, 0.12880087218945846, 0.11095349706010893, 0.21482191805262119, 0.1695278289844282, 0.1797105255536735, 0.21020460175350308, 0.14786015963181853, 0.1637653194484301, 0.10487832070793957, 0.1698708496405743, 0.04921974228636827, 0.13803891866700724, 0.1583667888189666, 0.23253693856531754, 0.13655955117428675, 0.21220872702542692, 0.10812438558787107, 0.1416664177668281, 0.11575206066481769, 0.11328947366564535, 0.1073649458703585, 0.15793095517437905, 0.17273509438382462, 0.0898388761561364, 0.2866447140695527, 0.2216640891856514, 8.302742578089237, 58.92648182809353, 67.1321377158165, 57.848225086927414, 45.37598714232445, 62.39996664226055, 81.6118611395359, 28.341750092804432, 0.7994558452628553, 0.35321761679369956, 0.144451163650956, 6.568422541022301, 5.364322727546096, 0.8612004539463669, 0.14233099616831169, 0.6975028035230935, 8.230426758527756, 33.24824631214142, 70.47636866569519, 75.71507915854454, 70.7892894744873, 73.27572405338287, 77.38987728953362, 70.84849789738655, 66.16182178258896, 70.21362036466599, 77.26159617304802, 74.02617618441582, 70.78944146633148, 64.69932585954666, 63.932534605264664, 64.71713170409203, 63.95339548587799, 60.09072035551071, 54.497086107730865, 55.57509206235409, 65.46656548976898, 65.1050528883934, 68.22577223181725, 66.58988401293755, 61.2999826669693, 60.332482382655144, 60.91079615056515, 56.23483166098595, 64.12928804755211, 71.20576232671738, 71.5880674123764, 70.31398817896843, 65.11565431952477, 72.47575297951698, 42.27671764791012, 44.784845262765884, 70.0477060675621, 64.0442182123661, 70.75955227017403, 64.84114184975624, 72.89718836545944, 68.5452438890934, 69.05335262417793, 70.50916850566864, 66.94687485694885, 54.97491806745529, 53.979367688298225, 64.60474893450737, 69.46770519018173, 71.26713663339615, 67.61072963476181, 67.70612731575966, 68.58870595693588, 68.92134770751, 69.15872097015381, 67.11211279034615, 68.12364131212234, 61.57743617892265, 61.114754006266594, 61.484010592103004, 69.18476477265358, 67.43674457073212, 71.6996218264103, 66.29160761833191, 64.15134206414223, 61.57866731286049, 62.90116734802723, 59.45142365992069, 64.9018169939518, 57.142865136265755, 27.61128108948469, 1.7813072470016778, 0.3238156851148233, 0.8234358835034072, 2.65673004090786, 3.5547847766429186, 27.544467374682426, 58.67319121956825, 6.2904033344239, 0.7665747846476734, 0.4856406297767535, 0.7883828831836581, 25.095006711781025, 65.11923372745514, 47.06566907465458, 42.21780940890312, 34.84984517097473, 48.69603618979454, 44.5657642185688, 7.836490022018552, 0.1404745879699476, 0.26192356715910137, 0.1340895501198247, 0.14257767121307552, 0.16067181044491008, 0.14828745857812464, 0.07619249474373646, 0.14606388023821637, 0.1803465757984668, 0.11602513390243985, 0.10719682715716772, 0.15855956909945235, 0.13645683793583885, 0.17086394713260233, 0.09781245884369127, 0.15369085769634694, 0.10862561728572473, 0.1446901648887433, 0.1796454392024316, 0.11456923311925493, 0.18167966598412022, 0.06588812306290492, 0.18656872707651928, 0.11742203394533135, 0.2135522072785534, 0.17515359038952738, 0.1051435865520034, 0.1534823141992092, 0.10719615922425874, 0.17129509040387347, 0.1691896768170409], [0.0158314293003059, 0.017907802648551296, 0.005518137004401069, 0.06724452410708182, 0.10551362880505621, 0.02371073696849635, 0.017092447669710964, 0.06533304855111055, 0.029353293175518047, 0.01648126864893129, 0.055418430565623567, 0.017696650502330158, 0.015661180623283144, 0.035229312343290076, 0.017717300761432853, 0.13706116878893226, 0.03399677203560714, 0.049483653710922226, 0.05060641924501397, 0.042451359186088666, 0.05558741388085764, 0.13013020710786805, 0.051340544305276126, 0.02717462590226205, 0.03025457772309892, 0.08247210309491493, 0.05938028574746568, 0.021735674199589994, 0.06485143181635067, 0.09240963860065676, 0.061134155112085864, 0.036368119399412535, 0.0786897623038385, 0.03629246486525517, 0.06242112081963569, 0.01885795205453178, 0.008448583175777458, 0.07831240247469395, 0.03850760869681835, 0.012091130247426918, 2.301621283404529, 31.2595147266984, 57.88331240415573, 39.888507798314095, 27.27646205574274, 37.65001371502876, 61.574856117367744, 33.412416502833366, 1.778381522744894, 0.032057918651844375, 0.052238520729588345, 0.24203274777391925, 0.09097364963963628, 0.3597434697439894, 0.06435286442865618, 0.08217498427256942, 1.8948635598644614, 16.963515244424343, 49.91295509040356, 76.9453239440918, 71.52797743678093, 66.27909868955612, 67.38436818122864, 70.12886211276054, 71.70501753687859, 69.80258122086525, 66.86211660504341, 62.71446816623211, 57.116034775972366, 56.15280546247959, 58.468545600771904, 55.86516469717026, 54.81460087001324, 54.87721011042595, 66.67146563529968, 69.62133094668388, 67.97590523958206, 68.29380378127098, 68.01871374249458, 63.654811307787895, 63.98472100496292, 55.42826034128666, 54.24624636769295, 58.689564540982246, 60.32610632479191, 65.94240635633469, 70.44720903038979, 67.26795002818108, 71.45558372139931, 25.40335636585951, 31.571371592581272, 65.32630741596222, 59.02017340064049, 63.16289350390434, 65.94652533531189, 66.95013508200645, 62.982661575078964, 64.41614225506783, 65.44555261731148, 59.93759237229824, 48.25941301882267, 45.52021220326424, 56.851618364453316, 61.20779201388359, 65.65603852272034, 66.88884437084198, 67.70923554897308, 66.7503722012043, 68.39366242289543, 67.51207172870636, 70.07018566131592, 67.17464223504066, 65.89258342981339, 62.14319922029972, 58.40315490961075, 62.11413457989693, 62.07571864128113, 65.17749980092049, 67.09524929523468, 66.03884518146515, 63.24124149978161, 66.60748466849327, 60.340826734900475, 39.97445538640022, 7.525506634265184, 0.0708746726741083, 0.2249842946184799, 2.3901140224188566, 0.9737828315701336, 3.5732921585440636, 1.5283522079698741, 8.405266776680946, 1.264961266424507, 0.6378433329518884, 0.13228841708041728, 0.4567221034085378, 30.349395163357258, 52.10827209055424, 28.4628476947546, 21.666655875742435, 30.813145078718662, 37.59614020586014, 25.513776540756226, 1.582917042542249, 0.13599565252661705, 0.04636404337361455, 0.03582377263228409, 0.05669441248755902, 0.12381976252072491, 0.0034826416140276706, 0.10333197438740171, 0.021964674997434486, 0.017088959575630724, 0.010491977336641867, 0.032919941731961444, 0.03893278510076925, 0.043406944823800586, 0.0234816378360847, 0.015820473345229402, 0.010401464078313438, 0.06074918826925568, 0.04959328747645486, 0.08286584954475984, 0.0317899402580224, 0.10640977212460712, 0.05963037838228047, 0.00958752474616631, 0.0801253505051136, 0.02930141519755125, 0.03899632778484374, 0.08851054313709028, 0.046464326078421436, 0.05549248577153776, 0.01042115232849028, 0.0459982573374873, 0.06890789227327332, 0.011746282980311662, 0.07414170322590508, 0.01381714309900417, 0.021180145122343674, 0.05060436720668804, 0.03277921197877731, 0.07270343587151729, 0.03075079064728925, 0.04152556706685573, 0.017516336447442882, 0.08233418979216367, 0.013404640722001204, 0.03334317370899953, 0.017324225955235306, 0.0525623642897699, 0.03359901798830833, 0.05595585680566728, 0.07253614836372435, 0.04338937076681759, 0.0643207220127806, 0.012019032456009882, 0.14438822952797636, 0.08035279650357552, 0.022056482375774067, 0.02449027404509252, 0.03841364166873973, 0.0248297379584983, 0.005845574414706789, 0.020404354036145378, 0.05057893751654774, 0.057589687494328246, 0.08474756497889757, 0.03695248276926577, 0.06068532275094185, 0.09944243778591044, 0.0654503153054975, 0.02812773276673397, 0.06811220606323332, 0.09610917797544971, 0.031038283814268652, 6.252032993361354, 41.34740151464939, 62.839808240532875, 39.313868433237076, 30.442725755274296, 57.15503208339214, 83.63685607910156, 27.202360332012177, 0.4447767318924889, 0.16134566569235176, 0.28487516683526337, 0.40199960698373616, 0.4176499875029549, 0.4288351919967681, 0.11254500306677073, 0.17383997415890917, 3.2795764692127705, 23.035545721650124, 59.21982988715172, 78.4245465695858, 72.04682439565659, 68.22929084300995, 68.95941406488419, 69.02487695217133, 73.0975592136383, 71.88838809728622, 69.37625169754028, 63.644023686647415, 59.6206171810627, 59.38233196735382, 62.27848716080189, 59.06822942197323, 58.56403827667236, 56.405415907502174, 68.29513370990753, 70.95973312854767, 70.24417832493782, 68.28577101230621, 69.45031732320786, 65.28299733996391, 65.13868108391762, 57.20144659280777, 55.66324733197689, 58.49347986280918, 64.40496325492859, 67.3576708137989, 72.16091707348824, 65.26854291558266, 74.55133840441704, 28.632168509066105, 35.34370847046375, 67.98737302422523, 58.23035538196564, 65.73997601866722, 68.18047866225243, 67.87834167480469, 66.26205280423164, 67.62231901288033, 67.18274340033531, 61.43027767539024, 51.21438525617123, 49.43008840084076, 57.37835370004177, 63.01820106804371, 67.47250065207481, 67.06612005829811, 69.37323465943336, 66.68437734246254, 70.34459173679352, 68.67661044001579, 71.57753437757492, 70.00099897384644, 67.63839974999428, 62.89347656071186, 60.6137964874506, 63.62871430814266, 65.26690140366554, 67.6653403043747, 66.55438631772995, 64.98842194676399, 65.13822510838509, 65.68354144692421, 63.65424893796444, 48.136535212397575, 11.499125361442566, 0.5682655039709061, 1.173076971899718, 3.552848305553198, 3.098696912638843, 7.068272894248366, 4.901240151375532, 13.051528260111809, 1.9829221721738577, 0.14033720159204677, 0.14137904334347695, 0.36959723161999136, 24.104420766234398, 68.19990321993828, 40.98626509308815, 23.62913466989994, 32.551371306180954, 42.52308502793312, 35.04019595682621, 3.8745117327198386, 0.07201830740086734, 0.026836117503989954, 0.06669435519143008, 0.032734389969846234, 0.07812293217284605, 0.04424006496265065, 0.04479077193536796, 0.008122004801407456, 0.036241427369532175, 0.04541139292996377, 0.11882625156431459, 0.03504004984279163, 0.04576489642204251, 0.0705028789525386, 0.07358497372479178, 0.029482393474609125, 0.04825922136660665, 0.04119603494473267, 0.0386001099832356, 0.058059515213244595, 0.05185975824133493, 0.05741831075283699, 0.07096329994965345, 0.05140430592291523, 0.00550333718820184, 0.028038196360284928, 0.051519772969186306, 0.010290712452842854, 0.08679834907525219, 0.043204360772506334, 0.0130793907919724, 0.012918013562739361, 0.08617885614512488, 0.12900172703666613, 0.10141158563783392, 0.11117793736048043, 0.17441243719076738, 0.08463455815217458, 0.19061393657466397, 0.21132914844201878, 0.15174206695519388, 0.20775303564732894, 0.16244575119344518, 0.11418005829909816, 0.10218165291007608, 0.09606220744899474, 0.13696029607672244, 0.23432858695741743, 0.1631262560840696, 0.22846183535875753, 0.18992495635757223, 0.13423366035567597, 0.12402159700286575, 0.2958098816452548, 0.23801952484063804, 0.13091274246107787, 0.14459481375524774, 0.1496724842581898, 0.21382353646913543, 0.12163451610831544, 0.1553318797959946, 0.3264769969973713, 0.1408057045773603, 0.14190662128385156, 0.11004585787304677, 0.10576978107565083, 0.17475220724008977, 0.2380908897612244, 0.07766953189275227, 0.1686058143968694, 0.16269867512164637, 0.23632879368960857, 4.955966714769602, 44.61863838136196, 76.33427873253822, 53.62686060369015, 38.276132717728615, 52.94531397521496, 78.78076985478401, 41.31683595478535, 3.6274226289242506, 0.18906213546870276, 0.21591198456007987, 0.8875868911854923, 0.8567965496331453, 0.9140323440078646, 0.1814444496994838, 0.17070530564524233, 2.6202567480504513, 19.268640652298927, 53.5322380810976, 82.14615046977997, 72.50222995877266, 67.45447441935539, 67.48212173581123, 71.27302631735802, 76.06735825538635, 76.639364361763, 72.49629467725754, 68.30027103424072, 61.17691867053509, 62.07640640437603, 65.03800928592682, 63.60170155763626, 62.48347096145153, 61.03752315044403, 74.31324318051338, 76.2584500014782, 74.74445924162865, 71.68101042509079, 74.1210874915123, 69.47888419032097, 69.1857299208641, 59.34178054332733, 59.56428520381451, 62.528160363435745, 66.17956683039665, 70.49287497997284, 74.41454574465752, 71.57483652234077, 71.44344717264175, 32.28295370936394, 39.55935426056385, 65.75935497879982, 63.7879903614521, 66.58429071307182, 70.03566071391106, 69.62209850549698, 67.9129122197628, 69.9703498184681, 71.18449866771698, 64.40108746290207, 53.32240954041481, 50.410504192113876, 60.01015707850456, 65.99545910954475, 69.98805686831474, 70.37046074867249, 71.73728540539742, 68.56757149100304, 73.44723924994469, 71.34754031896591, 74.46558460593224, 73.1937700510025, 71.1590476334095, 67.51799941062927, 64.06012415885925, 64.79419156908989, 65.81052303314209, 70.02264261245728, 67.88011997938156, 65.90183213353157, 64.2043188214302, 67.38182231783867, 63.44861537218094, 45.71777120232582, 9.15107935667038, 0.32827014452777803, 0.5945783201605082, 4.359401576220989, 2.7422055043280125, 8.671592585742474, 6.475739339366555, 14.659471828490496, 3.044668324291706, 1.2972629768773913, 0.40340294886846095, 0.8268581936135888, 39.79160539805889, 64.88505989313126, 38.968930542469025, 32.81385742127895, 42.05029159784317, 54.33714509010315, 36.36564463376999, 3.074144055135548, 0.16509305132785812, 0.17851718177553266, 0.29395474994089454, 0.16925311560044065, 0.20925958058796823, 0.14487927895970643, 0.14455255586653948, 0.1252345260581933, 0.1415195912704803, 0.11705563563737087, 0.1792504682089202, 0.09663571690907702, 0.11615331764915027, 0.1782298815669492, 0.10640477747074328, 0.14957141858758405, 0.1761745777912438, 0.1999666151823476, 0.1034887605055701, 0.1435214900993742, 0.23108826630050316, 0.1307257657754235, 0.19832149642752483, 0.20089873782126233, 0.15138087852392346, 0.08572818696848117, 0.1274951227242127, 0.16241792065557092, 0.10737746590166353, 0.1057027725619264, 0.10799413124914281, 0.16930904384935275], [0.06168155210616533, 0.06567641801666468, 0.02634138145367615, 0.01407339092111215, 0.03393342973140534, 0.03800202801357955, 0.024302557067130692, 0.02900448933360167, 0.02404921382549219, 0.044928581337444484, 0.015328730933106272, 0.022559016542800236, 0.06888213232741691, 0.059091735020047054, 0.05155543316504918, 0.04582452427712269, 0.03590713065932505, 0.02902846441429574, 0.05409576384408865, 0.03056722598557826, 0.05082207251689397, 0.030191465484676883, 0.06667077715974301, 0.026144599141844083, 0.050941498921019956, 0.024729308679525275, 0.008850502526911441, 0.04664417443564162, 0.020214163851051126, 0.002893653040700883, 0.03898979317455087, 0.03220696045900695, 0.09591716952854767, 0.007292077752936166, 0.020149654519627802, 0.02741775162576232, 0.051648758235387504, 0.0035820411630993476, 0.013432186460704543, 0.05529606896743644, 0.04006723946076818, 0.4336052719736472, 22.1492812782526, 52.12130159139633, 46.33197404444218, 29.370201006531715, 32.15938813984394, 59.81042839586735, 49.208571687340736, 7.560235345736146, 0.05502199383045081, 0.09676719579147175, 0.6082143040839583, 0.0837909737310838, 0.09600766701623797, 0.015789605567988474, 0.07822651372407563, 0.17724328528856859, 6.74069294705987, 23.956882283091545, 44.65533301234245, 67.88043156266212, 73.66744503378868, 67.6398740708828, 65.6332017481327, 71.05051025748253, 68.2041285932064, 69.24629867076874, 67.78079330921173, 66.8735159933567, 66.34953171014786, 64.98804956674576, 61.235089749097824, 62.07409992814064, 66.32945358753204, 69.03912618756294, 66.74896627664566, 69.02438297867775, 70.1177667081356, 67.60596469044685, 67.21260219812393, 65.6821659207344, 61.243665888905525, 64.39766004681587, 66.87131211161613, 75.95470190048218, 59.02176931500435, 69.90823835134506, 48.82160425186157, 52.98507884144783, 41.52158036828041, 56.44346706569195, 76.79258733987808, 61.97907842695713, 65.1520411670208, 65.37409365177155, 71.64589270949364, 67.33019068837166, 68.18563878536224, 66.1071503162384, 57.450036853551865, 51.78876243531704, 56.428792253136635, 58.79283159971237, 61.74357086420059, 61.32837854325771, 66.93603783845901, 66.60773545503616, 70.69206029176712, 69.30967167019844, 68.50627318024635, 65.51405534148216, 66.5997102856636, 64.18633058667183, 63.51802624762058, 62.7814319729805, 66.01211741566658, 68.82392853498459, 69.36590105295181, 62.6069263368845, 66.99574783444405, 47.44197428226471, 16.850651800632477, 0.7757274841424078, 0.17137941322289407, 0.3584898338885978, 1.4134448301047087, 2.0607742946594954, 2.780998572707176, 7.243825374171138, 1.7809957824647427, 2.556557203643024, 1.0012881900183856, 0.016745332213758957, 2.9379835864529014, 38.66851106286049, 49.590234607458115, 21.599864959716797, 24.794435240328312, 34.39860798418522, 38.83244566619396, 10.303476769477129, 0.06923914246726781, 0.04349919006926939, 0.09611242858227342, 0.07998381552170031, 0.022035639158275444, 0.013800943870592164, 0.06209577069967054, 0.05980451220239047, 0.04724476486444473, 0.054713093413738534, 0.027263234624115285, 0.04307028437324334, 0.03711849007231649, 0.06292784441029653, 0.03805052736424841, 0.10059480759082362, 0.05517633828276303, 0.013591002352768555, 0.07785017805872485, 0.04372441704617813, 0.02552208381530363, 0.07339947391301394, 0.013512745663319947, 0.024975454944069497, 0.04369976661109831, 0.08847785895341076, 0.08582543800002895, 0.0242558351601474, 0.01488150253862841, 0.02349515605601482, 0.015768138946441468, 0.040242182221845724, 0.02124441511114128, 0.031891944745439105, 0.04561761721561197, 0.01773835734638851, 0.0498446751589654, 0.05833809518662747, 0.04103210194443818, 0.060670902821584605, 0.028660867537837476, 0.04390477006381843, 0.06041828317393083, 0.04005230002803728, 0.05022301833378151, 0.013501564280886669, 0.07139083638321608, 0.04879485903074965, 0.04047298643854447, 0.015861801693972666, 0.04551328609522898, 0.022956256652832963, 0.039482293504988775, 0.08713230068678968, 0.08258303932962008, 0.0321859242831124, 0.028095937304897234, 0.04324391353293322, 0.01727670809486881, 0.04489621256652754, 0.04080192855326459, 0.01370790638247854, 0.010907481700996868, 0.025530809616611805, 0.023970831898623146, 0.03254050388932228, 0.052853861343464814, 0.06431105925003067, 0.023179414893093053, 0.023025953596516047, 0.03188377741025761, 0.03816520402324386, 0.04797385445272084, 0.023318361636484042, 0.024976677632366773, 2.0786319114267826, 34.53625939786434, 59.10527363419533, 44.85142149031162, 27.25606855005026, 42.19203919172287, 81.35155230760574, 45.36806456744671, 3.3029034174978733, 0.08223603334045038, 0.285541556077078, 0.1904256537090987, 0.17009257368044928, 0.24545142136048526, 0.16500399360666052, 0.08220665171393193, 0.42773865396156907, 11.686807740479708, 33.49995240569115, 51.5523961186409, 70.3329111635685, 70.34437894821167, 67.6370470225811, 66.42051190137863, 72.51301378011703, 70.38970291614532, 69.88647311925888, 70.63716843724251, 67.95773461461067, 68.44695076346397, 63.67501862347126, 61.35193347930908, 61.45364262163639, 70.73185175657272, 71.09004333615303, 69.8696780204773, 69.84356582164764, 72.0940862596035, 69.50947254896164, 69.32615518569946, 66.37226969003677, 61.829761639237404, 64.65752810239792, 66.98185577988625, 78.35552707314491, 64.48406741023064, 70.6646865606308, 57.02202022075653, 42.79390029609203, 40.711194053292274, 59.12014223635197, 74.48754742741585, 61.04743301868439, 67.09179148077965, 67.25591987371445, 70.95668569207191, 67.24840387701988, 68.52091759443283, 66.4399516582489, 57.49009430408478, 50.74258357286453, 59.152056723833084, 62.59073540568352, 65.618367344141, 64.17785704135895, 69.33772936463356, 69.45622220635414, 73.4892649948597, 69.76226538419724, 69.47480320930481, 67.57682025432587, 68.03025752305984, 65.2596665918827, 64.8785774409771, 61.65641114115715, 66.1616849899292, 69.04256880283356, 68.54375436902046, 63.39408069849014, 65.17993927001953, 54.865654930472374, 22.3770809546113, 1.6053326334804296, 0.7886172237340361, 1.653552995994687, 5.56413690559566, 5.1543027721345425, 6.114643290638924, 5.515058264136314, 1.8109468440525234, 0.9679957421030849, 0.41883332713041455, 0.017837157611211296, 1.5788130252622068, 37.44003318250179, 69.99203145503998, 32.37069860100746, 22.12917845696211, 35.19098326563835, 45.29767334461212, 17.64090869575739, 0.3174435457913205, 0.11689436694723554, 0.06595588856725954, 0.023946812289068475, 0.02413568701740587, 0.05862476085894741, 0.06910153344506398, 0.028329634042165708, 0.05935255539952777, 0.07279644923983142, 0.05091107086627744, 0.05252388022199739, 0.0258005988507648, 0.010604514754959382, 0.045491236887755804, 0.026471088458492886, 0.05282260579406284, 0.02967971198813757, 0.015775950050738174, 0.050889292542706244, 0.0173005458782427, 0.03810694543062709, 0.00303746479403344, 0.058815811935346574, 0.05208566799410619, 0.022001370489306282, 0.030350554116012063, 0.019531217294570524, 0.026369228689873125, 0.01650238460570108, 0.02560858854849357, 0.02709143671381753, 0.04009982345451135, 0.06365334571455605, 0.12357624902506359, 0.15680378128308803, 0.1398716523544863, 0.23729793465463445, 0.09654773530201055, 0.11625217171967961, 0.1231381666730158, 0.12112988537410274, 0.06955963151995093, 0.1610030309529975, 0.10707179753808305, 0.10350793760153465, 0.1484909703140147, 0.09863721497822553, 0.2600552252260968, 0.1152670152077917, 0.15702345699537545, 0.11540316219907254, 0.14382459805347025, 0.24366035184357315, 0.11600844300119206, 0.18092077545588836, 0.1479265818488784, 0.14763319602934644, 0.2256875389139168, 0.21750362415332347, 0.10319386070477776, 0.09408476980752312, 0.1385174406459555, 0.15878608741331846, 0.18273936380865052, 0.15849379997234792, 0.22796464094426483, 0.14916240616003051, 0.08540374226868153, 0.19884411682141945, 0.12066313385730609, 0.07378832218819298, 0.09518535996903665, 0.10869584672036581, 0.0801949120068457, 1.3248757389374077, 34.752460196614265, 74.05293434858322, 62.03217677772045, 39.54744189977646, 43.644268065690994, 72.85306513309479, 61.37926161289215, 10.953470841050148, 0.3709719859762117, 0.3627016703831032, 1.8612750247120857, 0.40283597772940993, 0.34956963441800326, 0.213671455567237, 0.17101160483434796, 0.669525854755193, 9.769274834543467, 28.272327817976475, 47.74589717388153, 69.0798220038414, 74.14406105875969, 67.3814195394516, 66.22843980789185, 73.68952184915543, 73.62361818552017, 75.18720388412476, 77.65896365046501, 73.41199994087219, 74.16473954916, 69.92935001850128, 68.45291644334793, 65.61756178736687, 71.12514585256577, 72.31431484222412, 71.592528373003, 70.63305705785751, 75.2851702272892, 71.53800889849663, 72.53823682665825, 72.64387115836143, 68.2490573823452, 70.21473750472069, 72.38053008913994, 80.24363055825233, 68.92133250832558, 71.50764092803001, 56.59559570252895, 57.10427060723305, 51.868721544742584, 60.88107794523239, 74.36397805809975, 65.41896164417267, 70.35634070634842, 69.08999785780907, 74.7445884346962, 72.68075957894325, 73.317681401968, 70.8916711807251, 62.950667291879654, 56.402037888765335, 60.375230088829994, 64.39380705356598, 66.35889440774918, 66.58268719911575, 71.85931965708733, 68.48172649741173, 75.66742211580276, 73.24576646089554, 69.48291197419167, 66.99548184871674, 69.84149873256683, 67.34395354986191, 67.26886197924614, 67.1035024523735, 69.52080354094505, 70.90159624814987, 68.74009743332863, 62.66019947826862, 64.56285998225212, 51.509002447128296, 19.490915425121784, 0.8570538670755923, 0.361628049868159, 0.763966521481052, 4.151717545464635, 5.173998065292835, 10.075576398521662, 22.269313037395477, 8.394146673381329, 9.07137768343091, 2.7318617468699813, 0.16190772381378338, 4.712426383048296, 50.20185358822346, 60.392253175377846, 31.988051533699036, 36.00327327847481, 46.91404961049557, 55.89030794799328, 16.7657358571887, 0.21806591976201162, 0.23174309288151562, 0.28737875749357045, 0.2776677254587412, 0.14813174115261063, 0.11209164731553756, 0.1445576618425548, 0.10967077643726952, 0.15461463859537616, 0.1494256014120765, 0.15406638442073017, 0.12934908183524385, 0.18594147870317101, 0.09704164942377247, 0.16895615262910724, 0.1494906283915043, 0.14413386583328247, 0.08540669601643458, 0.12987830734346062, 0.09252588119124994, 0.15847113478230312, 0.10170662644668482, 0.07266521526616998, 0.08274787032860331, 0.06166384075186215, 0.1492445619078353, 0.1912569926935248, 0.12276870329515077, 0.113451113429619, 0.11720609123585746, 0.1146534965664614, 0.06759539668564685, 0.09125746917561628, 0.16571939428104088], [0.03618822280259337, 0.038250558427535, 0.03590305997931864, 0.13023814506595954, 0.039539776553283446, 0.05178464176424313, 0.060560552883544005, 0.02823013986926526, 0.08316655294038355, 0.03743937246326823, 0.01619109076273162, 0.022145864786580205, 0.030910539790056646, 0.021140809440112207, 0.009173115049634362, 0.026579380792099983, 0.03174203462549485, 0.038063488973421045, 0.017428100654797163, 0.00892587968337466, 0.008342972778336843, 0.05415202977019362, 0.06644621069426648, 0.032119301686179824, 0.08428594912402332, 0.06916391095728613, 0.013747441516898107, 0.048358476196881384, 0.11586710839765146, 0.1474922473425977, 0.039947026380104944, 0.00994549503957387, 0.0967504974687472, 0.04897644401353318, 0.042864702045335434, 0.07872248359490186, 0.029128214628144633, 0.08167943742591888, 0.0642244951450266, 0.06719022858305834, 0.06974546529818326, 0.06686435153824277, 0.07036552968202159, 14.336314368993044, 52.101668044924736, 56.13409906625748, 36.765166595578194, 30.537652261555195, 46.5481748431921, 65.22797629237175, 21.73365008085966, 1.000845751259476, 0.16447730624349788, 0.8547044650185853, 0.25250612874515355, 0.08325962568051182, 0.0719382890383713, 0.13791615259833634, 0.13955583883216605, 0.19852444413118064, 3.5588778695091605, 16.63975741714239, 39.61817890405655, 65.28662994503975, 69.13784489035606, 70.21463871002197, 70.42323991656303, 67.66418516635895, 65.42291343212128, 69.91326168179512, 70.57069480419159, 71.44622102379799, 70.091183334589, 71.72933623194695, 70.69273665547371, 72.28421285748482, 68.61978068947792, 70.4647108912468, 63.721011355519295, 71.36548295617104, 69.16746810078621, 68.19123208522797, 61.90699249505997, 63.45457345247269, 64.13872674107552, 68.86987566947937, 72.84994930028915, 75.42775377631187, 36.121325343847275, 53.1852862983942, 49.8446499556303, 47.60269045829773, 76.1347134411335, 72.5901572406292, 68.33588272333145, 65.02294689416885, 67.39661872386932, 67.76091277599335, 66.62108793854713, 63.7385094165802, 57.485640943050385, 50.31004138290882, 55.33026359975338, 54.95517812669277, 59.81549732387066, 62.03910380601883, 62.02968031167984, 66.12608850002289, 71.2239557504654, 73.56672763824463, 69.43400099873543, 68.08568134903908, 69.300377368927, 69.08476173877716, 65.99495753645897, 65.78773185610771, 68.63840728998184, 68.69971320033073, 69.49561089277267, 65.53781166672707, 28.73108860105276, 2.815452511422336, 0.10273578489432111, 0.22783098014770076, 0.21990695066051558, 1.4514037244953215, 7.599857244640589, 4.811583962291479, 4.738629776984453, 4.901221627369523, 3.5482778633013368, 0.40522489172872156, 0.07422040798701346, 11.422789357602596, 48.04964527487755, 47.54382781684399, 21.176643669605255, 29.68326810747385, 38.87488938868046, 38.27366665005684, 8.102376479655504, 0.09644943042076193, 0.1435144545393996, 0.059136653508176096, 0.027047143485106062, 0.04230926017044112, 0.02238761753687868, 0.024336688438779674, 0.09620222102967091, 0.016932692960835993, 0.016218845230469014, 0.038262789021246135, 0.10572225393843837, 0.020741931039083283, 0.023961033693922218, 0.04864440343226306, 0.02452245171298273, 0.09468700038269162, 0.01446276241040323, 0.03640435104898643, 0.043011591624235734, 0.03200694052793551, 0.020110528494114988, 0.07219900551717728, 0.03522621016600169, 0.04813602856302168, 0.08386443892959505, 0.006682801877104794, 0.08726119689526968, 0.029856985092919786, 0.06862876311060973, 0.10507689716177993, 0.04842724731133785, 0.034026435678242706, 0.08356798804015853, 0.013268123584566638, 0.13734391221078113, 0.023147196407080628, 0.05285723069391679, 0.06010552358929999, 0.057079453545156866, 0.020694895574706607, 0.05721570072637405, 0.08112650029943325, 0.0075871315493714064, 0.050694664314505644, 0.0905787009105552, 0.07448421922163107, 0.01876342841569567, 0.00597402116000012, 0.029432389419525862, 0.020094793108000886, 0.044981726532569155, 0.05768471208284609, 0.06510773993795738, 0.027090154653706122, 0.030538747923856135, 0.06920779414940625, 0.044788359955418855, 0.052443731983657926, 0.022852586043882184, 0.047641691417084076, 0.059642746273311786, 0.0643855931411963, 0.026833892916329205, 0.0946132383251097, 0.04442920871952083, 0.05297765528666787, 0.05716210653190501, 0.02878457056795014, 0.06373144933604635, 0.032147477322723716, 0.06742479919921607, 0.035798346652882174, 0.06272391707170755, 0.020210775946907233, 0.03591174681787379, 0.11850804090499878, 0.7833241077605635, 23.328756988048553, 60.07631912827492, 52.85272814333439, 26.977250911295414, 35.95938943326473, 74.14555817842484, 78.0498106777668, 17.33280222862959, 0.34554523474071175, 0.2400431240675971, 0.4933500598417595, 0.25665621855296195, 0.32878442318178713, 0.47775439044926316, 0.029812192769895773, 0.04859689484874252, 0.42941807478200644, 6.584529876708984, 22.873881496489048, 49.3194193392992, 69.5741830766201, 68.07262524962425, 72.58508831262589, 72.77173429727554, 70.93929782509804, 67.89537236094475, 73.09426859021187, 74.31225523352623, 74.24065187573433, 72.46480196714401, 72.92105868458748, 71.72073349356651, 73.25647428631783, 68.41608881950378, 70.29367446899414, 66.18549451231956, 71.82061493396759, 68.41271460056305, 73.26319992542267, 65.10305419564247, 66.2418682873249, 65.2198675274849, 72.03773528337479, 68.63490387797356, 74.34142246842384, 44.44067873060703, 60.5555722117424, 52.06360548734665, 53.20786848664284, 76.1522077023983, 74.68477964401245, 68.23181390762329, 67.92918294668198, 72.60764390230179, 70.42223677039146, 69.94767263531685, 69.63520020246506, 59.37181033194065, 52.58338339626789, 55.093832686543465, 55.174046382308006, 59.848817735910416, 65.29858410358429, 63.800256103277206, 68.55488017201424, 72.144935131073, 73.51459443569183, 70.58084025979042, 71.02113783359528, 70.94180569052696, 71.27222076058388, 68.09488445520401, 67.90980398654938, 71.08208656311035, 70.64141660928726, 68.2637169957161, 68.03108587861061, 38.92144829034805, 5.7624349649995565, 0.5692058941349387, 1.32935652974993, 1.593596488237381, 4.364811535924673, 5.751283038407564, 5.867519276216626, 4.2836027685552835, 1.3877988187596202, 0.9677140228450298, 0.6174962560180575, 0.2824560028966516, 8.039086125791073, 51.02100983262062, 62.512391209602356, 24.50285218656063, 21.69004552066326, 39.277261197566986, 45.35775572061539, 12.7444220893085, 0.035065230913460255, 0.07522994405007921, 0.08090763352811337, 0.10679766302928329, 0.039838238662923686, 0.024179928295779973, 0.048893271523411386, 0.17248629679670557, 0.031520418197032996, 0.044601349873119034, 0.04674904732382856, 0.04150938453676645, 0.042248214813298546, 0.026903003563347738, 0.05151253331860062, 0.04573166304908227, 0.046664735637023114, 0.0426930989488028, 0.015879898965067696, 0.06913329736562446, 0.02574719204858411, 0.019719936171895824, 0.07018914344371296, 0.02143248089851113, 0.012391065520205302, 0.018094875813403632, 0.010843922318599652, 0.04066748479090165, 0.039806196436984465, 0.024565477724536322, 0.06600462540518492, 0.007904121375759132, 0.020246857311576605, 0.1848521246574819, 0.08642861852422357, 0.18309258157387376, 0.06407671127817594, 0.20030049257911742, 0.258800164447166, 0.15408222185214981, 0.13880913436878473, 0.09713821767945774, 0.12140698105213232, 0.1474487129598856, 0.16179318074136972, 0.1525620065513067, 0.15666949708247557, 0.13191253412514925, 0.10739513643784449, 0.12013925181236118, 0.18558981944806874, 0.1376451351097785, 0.17989855608902872, 0.12652837147470564, 0.1329206972150132, 0.15337007178459316, 0.19874734076438472, 0.21106678439537063, 0.1455931508098729, 0.16772098140791059, 0.22654062282526866, 0.1804494226234965, 0.19172603002516553, 0.24697776680113748, 0.14808915671892464, 0.15173571417108178, 0.19244146038545296, 0.22367087134625763, 0.1501064922194928, 0.1472994522191584, 0.15262894827174023, 0.1485208937083371, 0.24143395334249362, 0.14056005369639024, 0.12436774210073054, 0.28926559374667704, 0.28605752682778984, 0.8357221086043864, 21.20683114975691, 72.68370822072029, 72.24567532539368, 47.53273621201515, 44.81745511293411, 60.79394482076168, 79.07830148935318, 29.467340894043446, 1.6298751602880657, 0.29888136370573193, 2.37996619194746, 1.0409128200262785, 0.3263738681562245, 0.2341568688279949, 0.5939040938392282, 0.17654654220677912, 0.7592871913220733, 5.7056341879069805, 20.166186690330505, 43.782508447766304, 68.36923733353615, 70.09123653173447, 74.18799430131912, 78.21055725216866, 73.55275198817253, 68.63110408186913, 73.74138906598091, 76.66919276118279, 77.48516857624054, 77.04524338245392, 79.35368791222572, 77.16454938054085, 75.67781075835228, 71.14321008324623, 71.66195064783096, 67.02088728547096, 75.80832615494728, 73.32492381334305, 74.06052634119987, 67.95530274510384, 69.95768889784813, 68.64250347018242, 73.59663963317871, 73.98412004113197, 72.55168050527573, 52.45753034949303, 58.72448466718197, 56.37927711009979, 55.8934161812067, 74.25645142793655, 73.68262901902199, 70.77946320176125, 68.8746178150177, 73.22431281208992, 71.60790994763374, 71.36387184262276, 68.09162423014641, 60.57411901652813, 54.31531146168709, 57.86152817308903, 56.76578477025032, 63.40505450963974, 67.31748417019844, 67.245934009552, 71.15412309765816, 76.5766829252243, 75.72615936398506, 73.75234007835388, 74.06208425760269, 73.49268481135368, 73.3242018520832, 70.95091000199318, 70.65648660063744, 71.76304802298546, 70.17587319016457, 67.8767229616642, 69.01673778891563, 32.770167365670204, 3.825014876201749, 0.2004028792725876, 0.5753173911944032, 0.9407409920822829, 4.822336435317993, 14.994201567023993, 13.036980740725994, 14.96328642591834, 10.757393762469292, 12.996994536370039, 0.466391634545289, 0.24084473261609674, 15.950369909405708, 62.5074552744627, 59.91002105176449, 31.36186793446541, 40.069701075553894, 50.78080952167511, 53.746740370988846, 11.072499454021454, 0.13062906393315643, 0.24875589326256886, 0.1634138383087702, 0.2154957436141558, 0.14759041863726452, 0.25281610898673534, 0.14075443701585755, 0.24794475553790107, 0.17041953426087275, 0.11755055165849626, 0.15284415625501424, 0.25817732443101704, 0.20512896473519504, 0.23028913652524352, 0.1914220314938575, 0.09775428188731894, 0.28376322181429714, 0.17403073579771444, 0.08289883058751002, 0.18902680923929438, 0.10878129760385491, 0.1081991198589094, 0.12417403413564898, 0.0794623899855651, 0.13283324253279716, 0.2540329343173653, 0.07620525226229802, 0.22613337670918554, 0.12239515810506418, 0.19724422454601154, 0.1527153342613019, 0.08935048361308873, 0.11103788667242043, 0.3464665071805939, 0.23825361306080595], [0.031001705210655928, 0.05180500629649032, 0.06699493242194876, 0.017025004999595694, 0.0734415759507101, 0.011979373011854477, 0.057448683146503754, 0.03101434398558922, 0.022925225603103172, 0.03347015517647378, 0.007201096013886854, 0.01665306099312147, 0.047027497421368025, 0.024716985317354556, 0.012012313236482441, 0.010371287426096387, 0.045648698360309936, 0.062183670670492575, 0.026400055648991838, 0.041075907211052254, 0.023591457138536498, 0.003616162794060074, 0.008530241684638895, 0.052385881572263315, 0.10255250410409644, 0.06962485145777464, 0.05087992292828858, 0.08056793027208187, 0.04248283366905525, 0.16721019084798172, 0.027037426916649565, 0.07356057190918364, 0.06882875706651248, 0.07724477851297706, 0.004930488239551778, 0.08608490024926141, 0.02052902742434526, 0.08562175557017326, 0.02391976842773147, 0.014038928366062464, 0.06280029148911126, 0.05311014720064122, 0.04147357591136824, 0.28621266537811607, 9.436349049210548, 46.95556618273258, 58.549230471253395, 42.20419093966484, 29.0189041569829, 37.39231914281845, 60.923768654465675, 44.96105320751667, 8.764761686325073, 0.11882042570505291, 0.5026432033628225, 0.5638382071629167, 0.4350296314805746, 0.09170492485282011, 0.16761357779614627, 0.005578615082413307, 0.14049082616111264, 0.12369623203994706, 2.4781070882454515, 15.95381062477827, 45.3389847278595, 66.96683898568153, 74.01496678590775, 73.6351315677166, 75.16626700758934, 73.38668569922447, 74.09660160541534, 70.0621072947979, 70.7480388879776, 69.78314906358719, 69.66774925589561, 71.20769262313843, 71.60163268446922, 70.28731361031532, 73.5953477025032, 71.0360786318779, 72.66203418374062, 74.59866106510162, 72.23701938986778, 70.00169813632965, 76.3091392815113, 66.67878404259682, 63.083686754107475, 43.42129983007908, 32.322106808423996, 30.087779201567173, 54.66663680970669, 38.56437385082245, 71.07574850320816, 70.44179052114487, 77.94449552893639, 71.54043316841125, 69.01206403970718, 67.99428105354309, 68.68464320898056, 71.05136901140213, 67.14507982134819, 63.33338275551796, 66.26787409186363, 70.14008671045303, 68.83440837264061, 67.40288078784943, 66.06526896357536, 68.39592710137367, 70.33834487199783, 68.75039488077164, 72.10294738411903, 66.19509279727936, 72.29485228657722, 68.9061713218689, 71.62500143051147, 68.26117113232613, 74.57517832517624, 74.31089490652084, 63.74911844730377, 18.802071288228035, 0.5353052413556725, 0.08443009646725841, 0.9515242790803313, 2.0367705076932907, 3.55577414855361, 6.542270444333553, 4.812311148270965, 6.89548809081316, 2.8670841408893466, 0.6538964621722698, 0.6054069078527391, 1.074822556693107, 26.762581430375576, 53.55638198554516, 36.6265994310379, 23.918627835810184, 37.58724108338356, 47.709730714559555, 27.992966808378696, 3.328636586666107, 0.04024964822747279, 0.18731467454927042, 0.06900189269799739, 0.06190769563545473, 0.027730145702662412, 0.04104328982066363, 0.028825082554249093, 0.14378434396348894, 0.07369277067482471, 0.017148975202871952, 0.05657957626681309, 0.032870733630261384, 0.06516209483379498, 0.013848249291186221, 0.0633464528073091, 0.030921590368961915, 0.07822386425687, 0.050795514762285165, 0.09595049195922911, 0.07127316144760698, 0.02822041031322442, 0.04806337230547797, 0.0344710897479672, 0.053308738497435115, 0.09502490021986887, 0.14764128543902189, 0.013553541521105217, 0.0415836920728907, 0.03282905832747929, 0.0380143439542735, 0.012592867533385288, 0.013699896753678331, 0.02738713432336226, 0.023592384823132306, 0.016382544454245362, 0.019863651214109268, 0.06662744315690361, 0.014378035120898858, 0.04923264823446516, 0.024202202002925333, 0.05976156040560454, 0.021842190944880713, 0.0217465837704367, 0.04198798073048238, 0.05792769865365699, 0.041296792624052614, 0.057983682563644834, 0.03918806905858219, 0.04290648124879226, 0.06888127885758877, 0.03159672582114581, 0.03398004402697552, 0.03445687019848265, 0.03753424862225074, 0.07952384723466821, 0.048792788438731804, 0.013933403315604664, 0.012064171733072726, 0.03593866822484415, 0.10981455270666629, 0.05591321300016716, 0.15673510293709114, 0.08323313100845553, 0.0874203207786195, 0.03968465491198003, 0.13815010723192245, 0.025069722541957162, 0.01594050645508105, 0.04486827441724017, 0.11753121871151961, 0.03688929260533769, 0.02623707816383103, 0.042197477887384593, 0.05940020870184526, 0.08690555972862057, 0.02872348624805454, 0.043322206402081065, 0.05665972450515255, 0.07649284932995215, 0.3690407099202275, 16.46953985095024, 59.19038526713848, 58.48967246711254, 35.50394207239151, 25.222862251102924, 55.66954359412193, 83.57577815651894, 41.40785627067089, 3.2885451754555106, 0.053613453201251104, 0.8246671361848712, 0.6497886450961232, 0.60665751574561, 0.7348669704515487, 0.6595572677906603, 0.06261145943426527, 0.137221725017298, 0.5646271398290992, 4.324426352977753, 23.949877358973026, 53.15620265901089, 70.67366927862167, 72.01265662908554, 73.80556762218475, 75.44922262430191, 75.10608583688736, 73.38723286986351, 72.2408951818943, 71.46113142371178, 71.19903668761253, 71.64841577410698, 72.85875722765923, 71.89973428845406, 71.4027589559555, 71.09995320439339, 69.96664121747017, 72.32254520058632, 74.9642014503479, 73.76420304179192, 71.50520145893097, 73.11784252524376, 71.10936149954796, 70.53070574998856, 53.84865090250969, 39.809255450963974, 34.95317302644253, 52.39189647138119, 45.69044306874275, 71.91030532121658, 70.10243073105812, 77.38663226366043, 73.90004575252533, 71.56370311975479, 70.39677813649178, 69.20486569404602, 71.47717416286469, 66.85090720653534, 61.667358353734016, 66.14785373210907, 71.2700928747654, 71.32370799779892, 68.63098248839378, 66.84078454971313, 69.51327234506607, 71.83702245354652, 70.70757105946541, 72.87309005856514, 68.66717174649239, 69.86867487430573, 71.51951149106026, 71.61663427948952, 69.68142852187157, 71.78927421569824, 72.37265691161156, 65.65886557102203, 27.18174833804369, 1.095593785867095, 0.4220303212059662, 2.6630201283842325, 5.300461929291487, 4.275402808561921, 6.908980216830969, 2.850860198959708, 0.9028698492329568, 1.1341468733735383, 0.6352143490221351, 0.3544299298664555, 0.6570784351788461, 24.59615807980299, 67.06890910863876, 53.28642167150974, 27.989545091986656, 29.54125452786684, 48.82112167775631, 36.747622936964035, 6.5676891803741455, 0.060807843910879456, 0.07568427943624556, 0.025822835450526327, 0.1515556691447273, 0.06322272194665857, 0.0655310090223793, 0.031900412650429644, 0.21110914618475363, 0.054340705974027514, 0.03626821890065912, 0.10090613111970015, 0.023247848330356646, 0.014007766512804665, 0.030490239296341315, 0.040567773539805785, 0.06011955760186538, 0.01307993998125312, 0.05837072370923124, 0.03570518485503271, 0.06777966453228146, 0.07931293628644198, 0.10280653383233584, 0.05428438809758518, 0.02267603838845389, 0.026895769478869624, 0.046739766767132096, 0.021551007448579185, 0.0694611930521205, 0.021213356230873615, 0.05102572155010421, 0.03908367485564668, 0.01678040425758809, 0.039255979281733744, 0.007630840336787514, 0.01173556729554548, 0.0034516627465563943, 0.19364434818271548, 0.17651252215728164, 0.15656005998607725, 0.14460514445090666, 0.1709976969868876, 0.11416794644901529, 0.13267328002257273, 0.13452848594170064, 0.1326638547470793, 0.12749752728268504, 0.11163425428094342, 0.13325525738764554, 0.12443239800632, 0.14507443411275744, 0.07766914597596042, 0.12586693977937102, 0.18266790983034298, 0.20107959921006113, 0.19838025968056172, 0.1781360147288069, 0.09949816565494984, 0.1444374190759845, 0.12343858805252239, 0.23586119612446055, 0.24065339210210368, 0.270946568925865, 0.21008852985687554, 0.12315286119701341, 0.15462011564522982, 0.3459976182784885, 0.12072991972672753, 0.19592814438510686, 0.11560950151761062, 0.3098457050509751, 0.12774960516253486, 0.16812465037219226, 0.11033787814085372, 0.15501153917284682, 0.18042739568045363, 0.14429857808863744, 0.19698742660693824, 0.15723618620540947, 0.18914736370788887, 0.4462421766947955, 14.26872929558158, 67.35270068049431, 74.44362938404083, 56.24951787292957, 39.80651579797268, 49.211744517087936, 75.40580615401268, 56.78511433303356, 12.553029209375381, 0.323851605062373, 1.9417009153403342, 2.4652595026418567, 1.2262605805881321, 0.2855487400665879, 0.44132838724181056, 0.2074674126924947, 0.1973662484670058, 0.39616979949641973, 4.171138778328896, 20.101331770420074, 49.24989067018032, 68.58602330088615, 75.8598741889, 77.04192996025085, 80.33547163009644, 78.70826214551926, 78.68434622883797, 74.76818516850471, 74.07527714967728, 74.49255555868149, 75.88716432452202, 73.39921742677689, 72.13434129953384, 72.50471502542496, 73.88230070471764, 71.17999970912933, 72.66497522592545, 79.69553276896477, 80.12973546981812, 76.6931314766407, 77.30287715792656, 71.17778062820435, 71.45670846104622, 55.06175100803375, 43.589060828089714, 38.952758610248566, 57.97532066702843, 48.63446809351444, 72.37958773970604, 70.93872025609016, 82.95149445533752, 78.01592409610748, 76.67929261922836, 74.27499443292618, 75.63732773065567, 77.10435301065445, 73.20867285132408, 67.27409809827805, 71.29242047667503, 77.24110767245293, 76.59594029188156, 70.44255807995796, 70.5273999273777, 72.80228465795517, 74.93878841400146, 70.09336441755295, 72.14124172925949, 68.39025780558586, 74.31844890117645, 73.16720187664032, 74.16420757770538, 70.92735886573792, 76.92152202129364, 74.31049212813377, 65.37007346749306, 22.297325134277344, 0.9149635315407068, 0.1515217826818116, 1.5918470383621752, 4.394390098750591, 5.878703501075506, 16.297188699245453, 14.470081441104412, 17.40045189857483, 13.08823049068451, 3.7983899423852563, 1.2561281654052436, 2.3010337399318814, 34.82063613831997, 67.80381247401237, 48.95129509270191, 37.367077097296715, 47.319567650556564, 60.60930892825127, 41.00734256207943, 5.22043869830668, 0.24409186618868262, 0.25730245106387883, 0.16689176496583968, 0.2982048812555149, 0.2037308327271603, 0.1339274799101986, 0.10225850972346961, 0.21314505022019148, 0.10740410158177838, 0.12203804406453855, 0.13616958225611597, 0.105936615873361, 0.1768075258587487, 0.14558240451151505, 0.09887699547107331, 0.19109173124888912, 0.10730684312875383, 0.129001667664852, 0.24339497467735782, 0.11283676358289085, 0.268813933362253, 0.14111706521362066, 0.15392188826808706, 0.161683565529529, 0.2093736338429153, 0.1549551062635146, 0.08538087669876404, 0.2515848563052714, 0.08861958689521998, 0.09597015887266025, 0.12458836776204407, 0.10783040605019778, 0.13636497489642352, 0.13005686807446182, 0.11918536940356717, 0.17001311935018748], [0.020633095082303043, 0.036082704245927744, 0.07986042604898103, 0.019885774636350106, 0.04187653983535711, 0.08048901028814726, 0.0341976046183845, 0.07843439670978114, 0.09346782986540347, 0.04029412513773423, 0.03596956012188457, 0.11734091720427386, 0.022669793215754908, 0.016213425697060302, 0.02126612664142158, 0.050163694759248756, 0.039130641671363264, 0.03567235966329463, 0.01693102683930192, 0.053595608260366134, 0.08204865589505062, 0.02927515801275149, 0.06021386601787526, 0.03121546600596048, 0.08374192519113421, 0.137541932053864, 0.05577327734499704, 0.0725727659300901, 0.04400297475513071, 0.09318477474153042, 0.09855860669631511, 0.04655253404052928, 0.1373321417486295, 0.08680098369950429, 0.034978061958099715, 0.02338258895179024, 0.1054346865566913, 0.020370298734633252, 0.04129314125748351, 0.03880405958625488, 0.14161145430989563, 0.014991727239248576, 0.047762850736035034, 0.03826948690402787, 0.2962673711590469, 4.20097810216248, 29.385164603590965, 56.45256757736206, 52.704699486494064, 41.345209032297134, 32.92406290769577, 41.12165942788124, 58.47552962601185, 25.71742281317711, 1.7489744257181883, 0.4873503599083051, 2.236673980951309, 1.1111107282340527, 0.33567508624400944, 0.07085164383170195, 0.14091232151258737, 0.11850774404592812, 0.13917775911977515, 0.07597186908242293, 4.046586686745286, 22.983587309718132, 55.73969163000584, 67.30639636516571, 67.59816750884056, 68.86147812008858, 69.23788592219353, 73.24771955609322, 76.66453421115875, 79.53912556171417, 79.37415361404419, 70.47696143388748, 71.9007982313633, 68.95806133747101, 69.60734009742737, 66.83362573385239, 65.71925953030586, 66.53278067708015, 71.26009941101074, 63.73770385980606, 65.52702784538269, 49.625325724482536, 72.02583432197571, 41.20831377804279, 41.3923417031765, 28.65108009427786, 46.28350004553795, 43.90728235244751, 64.15226921439171, 79.97782722115517, 65.08400961756706, 74.63584586977959, 67.55757808685303, 69.74468752741814, 66.20437949895859, 65.67314520478249, 64.29505035281181, 65.34845262765884, 65.99570229649544, 71.95996105670929, 70.19345864653587, 73.77307936549187, 72.04174786806107, 74.17804643511772, 74.48249369859695, 72.72261813282967, 75.29033035039902, 74.21256378293037, 71.70264646410942, 72.23578065633774, 73.6878651380539, 74.72860649228096, 69.00232896208763, 45.99796436727047, 8.340847883373499, 0.24756440485361964, 0.25307796837296337, 0.8805165986996144, 4.554221397265792, 7.7916638273745775, 4.848395911976695, 4.823286859318614, 1.6699922201223671, 2.1642170939594507, 0.6612027576193213, 0.08581712594605051, 8.188467510044575, 42.9269577562809, 44.87435705959797, 26.607996225357056, 23.371151313185692, 36.03305988013744, 46.58001333475113, 22.15844638645649, 1.3264120439998806, 0.11984226657659747, 0.10146608896320686, 0.02476125071552815, 0.008221498974307906, 0.012411664756655227, 0.03935513392207213, 0.04033341814647429, 0.008735535502637504, 0.029807366954628378, 0.07072713371599093, 0.14404571353225037, 0.02173317872802727, 0.022961293980188202, 0.01698086576652713, 0.012067570769431768, 0.05907757113163825, 0.027898392436327413, 0.0453511861996958, 0.047136930807027966, 0.01363640509225661, 0.09378459333674982, 0.05163166657439433, 0.05188629002077505, 0.03227213957870845, 0.08407077082665637, 0.05232165982306469, 0.06258237466681749, 0.023920623752928805, 0.015183186496869894, 0.0504687285865657, 0.022031484986655414, 0.03824680687102955, 0.03671191931061912, 0.033333689061691985, 0.045574932591989636, 0.05093467858387157, 0.04645220309612341, 0.03552123984263744, 0.012824451932829106, 0.02644817464897642, 0.03910174244083464, 0.05857371594174765, 0.042231987754348665, 0.010341668312321417, 0.06936783087439835, 0.06228577534784563, 0.051332213697605766, 0.04476475223782472, 0.09640551012125798, 0.07784340225043707, 0.02326030342373997, 0.00906923942238791, 0.046482571779051796, 0.01720134856441291, 0.03992394187662285, 0.013690590221813181, 0.06602929439395666, 0.0759990316873882, 0.009184007922158344, 0.057313282013637945, 0.04348747155745514, 0.04985526931704953, 0.3174021636368707, 0.07448199277860112, 0.0475656843627803, 0.05163020825420972, 0.015253004967235029, 0.07316382718272507, 0.059021357155870646, 0.11247426897170953, 0.03345476303366013, 0.04278769309166819, 0.006196203012223123, 0.0412552546185907, 0.058319085073890164, 0.042850909230764955, 0.021025134592491668, 0.13026817236095667, 0.012681230418820633, 0.003996820541942725, 0.03525050437019672, 0.33170893031638116, 8.553885351866484, 42.28269852697849, 63.9029797911644, 44.0115487575531, 28.674502037465572, 37.279096618294716, 70.47237128019333, 77.20576196908951, 14.610072579234838, 0.7423211017157882, 0.2566930290777236, 2.037800964899361, 0.9986896044574678, 0.946956864790991, 1.1751836026087403, 1.2004584213718772, 0.21154615242267027, 0.11069646163377911, 0.38519067456945777, 7.17822901904583, 32.53127798438072, 62.76749812066555, 69.97342765331268, 68.48111093044281, 71.00108250975609, 71.88372954726219, 73.92208456993103, 77.96566799283028, 78.98633882403374, 78.09227719902992, 71.41679540276527, 71.20025262236595, 70.02239942550659, 69.54674854874611, 66.76067724823952, 65.450629144907, 68.78283753991127, 72.61598825454712, 68.18795666098595, 65.99672064185143, 54.390505626797676, 65.4844169318676, 45.15990033745766, 43.27792972326279, 34.9250241369009, 53.58636237680912, 49.40412059426308, 66.49470672011375, 78.77128556370735, 68.40035766363144, 77.80077964067459, 72.1439091861248, 73.011205047369, 69.78799000382423, 68.72871324419975, 70.36321073770523, 66.72480717301369, 68.90922635793686, 72.34485760331154, 72.75795623660088, 75.28781488537788, 74.27411288022995, 75.51548346877098, 75.13906046748161, 71.42795160412788, 76.30028575658798, 75.02556055784225, 72.41327673196793, 73.5695318877697, 73.72373521327972, 73.36377292871475, 72.7650086581707, 51.96286529302597, 14.378293566405773, 0.8608884550631046, 1.1770332721062005, 4.4289839174598455, 6.182787409052253, 12.573755197227001, 7.62344827875495, 2.4302807170897722, 2.2755767684429884, 2.17608243227005, 0.7049398950766772, 0.254883702727966, 4.143945537507534, 50.94847932457924, 64.96538758277893, 35.91291792690754, 24.07439287751913, 34.67355743050575, 53.48002128303051, 30.370387136936188, 2.5422685453668237, 0.2627925924025476, 0.17668444808805361, 0.03872264227538835, 0.03975396408350207, 0.04017085811938159, 0.04018027597339824, 0.05467278737341985, 0.04335724690463394, 0.009052527184394421, 0.021099872574268375, 0.04095942713320255, 0.043500689207576215, 0.07642935859621502, 0.021540702728088945, 0.0346359059039969, 0.0048069322474475484, 0.044009420307702385, 0.03137911327939946, 0.07436189102008939, 0.027807243714050855, 0.14389394433237612, 0.06211889973201323, 0.03282663892605342, 0.038242569207795896, 0.0907833110250067, 0.011998097397736274, 0.06176573762786575, 0.05064210912678391, 0.006300709001152427, 0.0253992361103883, 0.06803312280680984, 0.04781804425874725, 0.022533330811711494, 0.08442254140391015, 0.02244301329483278, 0.020495068602031097, 0.044375785219017416, 0.1112630171701312, 0.1274610433029011, 0.21690475550713018, 0.10280612565111369, 0.11347801628289744, 0.12529682193417102, 0.0974780174146872, 0.22510465612867847, 0.22485063382191584, 0.1006639312254265, 0.17794565384974703, 0.26750030228868127, 0.10327618714654818, 0.10845994023839012, 0.13795373495668173, 0.16189432062674314, 0.1559540518792346, 0.14501044614007697, 0.19148509920341894, 0.09305737024988048, 0.161386112740729, 0.08296962405438535, 0.13684119621757418, 0.0861223935498856, 0.22079170943470672, 0.40417938376776874, 0.17585334659088403, 0.1660337531939149, 0.14826063736109063, 0.2006991149391979, 0.1725684228586033, 0.15872484538704157, 0.2149949423619546, 0.16114475147332996, 0.13791641977149993, 0.09307300730142742, 0.20484786888118833, 0.17114626010879874, 0.17360443132929504, 0.12972554366569966, 0.2356505300849676, 0.16598208487266675, 0.18188077316153795, 0.12980148021597415, 0.4419864941155538, 7.104583270847797, 46.7383736371994, 79.11811575293541, 64.27161321043968, 56.24926708638668, 43.678192645311356, 55.30765861272812, 70.70504799485207, 33.638903349637985, 2.9426931962370872, 0.8774453541263938, 6.13339813426137, 6.625052327290177, 0.44874959683511406, 1.253116352017969, 1.320824206341058, 0.20860613440163434, 0.23019825312076136, 0.4002186603611335, 6.040838900953531, 28.33010371774435, 61.68454863131046, 71.00148528814316, 67.3831370472908, 70.7335464656353, 68.92789855599403, 74.20773804187775, 80.21412894129753, 83.47036421298981, 82.06311732530594, 71.82531908154488, 71.64108216762543, 71.23131975531578, 65.99400758743286, 65.12748688459396, 64.26437079906464, 65.12830764055252, 71.38704299926758, 68.37367549538612, 67.4319264292717, 60.57971231639385, 74.03446733951569, 60.32748945057392, 50.08059449493885, 36.5084295719862, 59.38139721751213, 54.65252436697483, 67.96563059091568, 78.66789311170578, 68.42257127165794, 78.65253433585167, 72.75959014892578, 75.89515149593353, 69.67010512948036, 69.43472295999527, 70.55608838796616, 69.22632694244385, 70.9959451854229, 75.72119683027267, 73.7380300462246, 78.893091827631, 77.53050774335861, 81.75056129693985, 77.42060244083405, 76.02721720933914, 79.25886020064354, 78.74532535672188, 74.29732203483582, 76.22799843549728, 75.1257535815239, 76.38734668493271, 69.00414526462555, 48.7075799703598, 9.153042901307344, 0.4450462502427399, 0.6053115567192435, 2.647064784541726, 10.014778710901737, 21.599433682858944, 18.47136553376913, 12.373014818876982, 9.862878061830997, 8.845715392380953, 1.6189063363708556, 0.51848633447662, 11.27488324418664, 54.97678376734257, 55.25590538978577, 37.64880158007145, 35.02126157283783, 49.13823366165161, 63.10822203755379, 31.54287312179804, 1.7462132801301777, 0.3453658428043127, 0.17169962025946006, 0.08759167525568046, 0.11579339829040691, 0.1639282505493611, 0.11424647309468128, 0.19132289540721104, 0.09411866369191557, 0.14898626483045518, 0.10410676171886735, 0.2508621528977528, 0.09229252769728191, 0.2400604754802771, 0.13363704783841968, 0.13144475844455883, 0.1529151204158552, 0.2545006951550022, 0.15277286554919556, 0.16405587026383728, 0.16905813856283203, 0.24457904160954058, 0.19343923340784386, 0.10773460962809622, 0.07126058946596459, 0.26768426585476846, 0.1669596417923458, 0.08396013887249865, 0.11209911332116462, 0.08781273878412321, 0.08590081793954596, 0.24437030515400693, 0.0798131586634554, 0.12420993181876838, 0.2169581752968952, 0.15040213416796178, 0.07155943749239668, 0.1333159502246417], [0.0467892531742109, 0.04895137426501606, 0.040637765487190336, 0.06379191210726276, 0.036771881132153794, 0.03042087260837434, 0.03940053851692937, 0.04125171086343471, 0.01301510874327505, 0.06342195149045438, 0.08209965628338978, 0.029269814549479634, 0.057926615118049085, 0.03839344411971979, 0.06646499445196241, 0.02696919942536624, 0.059067006659461185, 0.014725692344654817, 0.01858386764070019, 0.030616940603067633, 0.022518473015225027, 0.04312476914492436, 0.033200937396031804, 0.08614520716946572, 0.04505968914600089, 0.08703076004167087, 0.03207648347597569, 0.01705176313407719, 0.07397328023216687, 0.020106209194636904, 0.10430832160636783, 0.040825933319865726, 0.08940023719333112, 0.042598085492500104, 0.0146186217716604, 0.01427431998308748, 0.06609576856135391, 0.016763683670433238, 0.09554268181091174, 0.015352492646343308, 0.06322692250250839, 0.06688528752420098, 0.043810372590087354, 0.09083455632207915, 0.07579916389659047, 0.17249858676223084, 1.5613854979164898, 23.361345939338207, 56.148298904299736, 54.40193921327591, 38.4602290391922, 24.210796058177948, 29.149807132780552, 54.8792240023613, 52.96880051493645, 8.944705780595541, 0.3726509615080431, 1.8659238377586007, 6.627743532881141, 1.0909139807336032, 0.8298932213801891, 1.856826413422823, 0.29205894854385406, 0.08983198902569711, 0.06582772708497941, 0.3048183670034632, 7.399201411753893, 32.13835246860981, 60.59645801782608, 74.6253128349781, 76.13294273614883, 72.32537224888802, 71.39810800552368, 69.35231298208237, 70.4233767092228, 69.08252745866776, 73.17613899707794, 73.17436829209328, 75.1150381565094, 72.45211064815521, 76.33738696575165, 76.14981383085251, 77.37324178218842, 73.94305944442749, 80.01989096403122, 76.1465536057949, 51.46009907126427, 32.13319234549999, 48.94773468375206, 50.13432741165161, 35.616005659103394, 48.27752284705639, 46.74210123717785, 82.07795172929764, 79.08508032560349, 78.30164596438408, 79.05694663524628, 69.58229184150696, 74.39322888851166, 77.49888584017754, 74.52483862638474, 76.30500510334969, 82.35396891832352, 77.00640186667442, 72.95052990317345, 75.19501626491547, 73.65258783102036, 72.01449573040009, 72.30514213442802, 73.24576646089554, 70.88495314121246, 72.41727411746979, 72.99561828374863, 71.21884882450104, 67.157261967659, 45.192346796393394, 16.934241615235806, 1.3327711215242743, 0.08645036345114931, 0.7445455261040479, 1.2930037616752088, 6.858832882717252, 7.489565787836909, 7.083236016333103, 2.958266898058355, 2.856040270999074, 0.9843627701047808, 0.4832656978396699, 1.1236672732047737, 25.121905468404293, 50.99450245499611, 29.996097721159458, 24.21982817351818, 28.975276798009872, 43.99754650890827, 40.48412963747978, 10.431477651000023, 0.13791034900350496, 0.03467697635642253, 0.17146867874544114, 0.06287868454819545, 0.1268658705521375, 0.06495036752312444, 0.04907263006316498, 0.012968675346201053, 0.024736370214668568, 0.06765376660041511, 0.06775486195692793, 0.04818587862246204, 0.02898729933804134, 0.05254637471807655, 0.12635283870622516, 0.06557619839441031, 0.04085818334715441, 0.0868104757682886, 0.07062373028020374, 0.03165219764923677, 0.07235265235067345, 0.08223100900067948, 0.033957096820813604, 0.05944302320131101, 0.024524282962374855, 0.08076168276602402, 0.060482059634523466, 0.0043091348379675765, 0.052584584191208705, 0.03125080336758401, 0.0612518894195091, 0.07152312420657836, 0.03569181506463792, 0.044758191652363166, 0.06908374416525476, 0.042652021074900404, 0.05133575003128499, 0.03726100469066296, 0.04743207180581521, 0.022689922116114758, 0.03841994250251446, 0.026191742217633873, 0.06490701125585474, 0.007522083697040216, 0.048721145212766714, 0.041852041540551, 0.008382408650504658, 0.030801598077232484, 0.032814100341056474, 0.040972362767206505, 0.03891211257723626, 0.11017206750693731, 0.05168819225218613, 0.03898742943420075, 0.025831576094788034, 0.02222205737780314, 0.08823454583762214, 0.05910125306400005, 0.03458843071712181, 0.08722488360945135, 0.03910360894224141, 0.04265506016963627, 0.006172700586830615, 0.09850546150119044, 0.05383476905990392, 0.035013454980799, 0.04631102434359491, 0.025336099752166774, 0.024725816874706652, 0.07808455571648665, 0.035475753611535765, 0.06588236399693415, 0.028424970332707744, 0.02644919881277019, 0.036101951845921576, 0.07857685195631348, 0.02047449441306526, 0.09226540962117724, 0.04509367579885293, 0.03784342363360338, 0.0232083530863747, 0.03245586565753911, 0.10157584518310614, 0.056906904210336506, 0.25613852601964027, 3.71630294714123, 35.24451479315758, 65.1449203491211, 55.342426747083664, 30.68352073431015, 21.432261653244495, 48.07518370449543, 88.9798329770565, 49.39680978655815, 3.7834603060036898, 0.3070940589532256, 1.7271953006274998, 1.841444957535714, 1.4499763073399663, 1.153470380231738, 2.480961922556162, 2.0617717411369085, 0.4086207220098004, 0.17855709447758272, 0.9316721255891025, 14.13312692195177, 41.22629061341286, 64.78264778852463, 73.51847022771835, 71.13746479153633, 70.76368644833565, 72.41883963346481, 71.20635509490967, 71.94840207695961, 68.80194291472435, 72.97101080417633, 69.8156601190567, 72.60257497429848, 70.47247767448425, 73.12606528401375, 71.83972030878067, 72.95550763607025, 72.83436253666878, 76.32879182696342, 74.92599070072174, 68.76608803868294, 46.03356085717678, 54.913984537124634, 46.73134781420231, 43.52033011615276, 50.05470268428326, 53.53718161582947, 79.36238184571266, 76.62807896733284, 76.35285973548889, 76.40049397945404, 70.79998210072517, 73.03440660238266, 76.68753057718277, 72.54192262887955, 76.70776829123497, 80.80400928854942, 78.30757364630699, 75.62799543142319, 73.99032890796661, 74.03072834014893, 72.26980403065681, 74.7364416718483, 75.88557600975037, 70.64940378069878, 72.39054635167122, 73.46233204007149, 73.52388113737106, 69.6584777534008, 51.877160891890526, 23.292733021080494, 3.899878221563995, 0.7226762745995075, 2.9927279613912106, 2.9052260192111135, 6.070289695635438, 8.12706945464015, 4.859658982604742, 1.515887095592916, 0.25770920736249536, 1.7703709588386118, 0.41053881752304733, 0.2554617467103526, 21.73523649573326, 70.4865825176239, 45.669813975691795, 23.965536318719387, 23.674382641911507, 40.250920951366425, 48.34604077041149, 16.38064742088318, 0.5542998877353966, 0.15908250119537115, 0.15597665769746527, 0.04050984149216674, 0.06225481665751431, 0.11178122178534977, 0.05653744454320986, 0.04199097900709603, 0.044566888245753944, 0.03355209941219073, 0.059315125181456096, 0.04521189250226598, 0.043574993032962084, 0.023142979152908083, 0.018238082484458573, 0.013854784829163691, 0.003173208474436251, 0.06328458737698384, 0.07049346109852195, 0.0170389907725621, 0.014148146528896177, 0.037323348806239665, 0.05363081945688464, 0.06169367508846335, 0.028236436992301606, 0.027919478707190137, 0.022871559049235657, 0.027998797595500946, 0.0554203935462283, 0.0553032047173474, 0.0929089481360279, 0.09204843532643281, 0.004919220118608791, 0.01914207958179759, 0.10555707413004711, 0.043708468292606995, 0.030949994215916377, 0.048669770039850846, 0.10558296766248532, 0.12040395362419076, 0.14504099293844774, 0.10585316136712208, 0.20260552904801443, 0.13534630299545825, 0.15667659201426432, 0.11897862190380692, 0.13007120636757463, 0.17538528889417648, 0.11819892897619866, 0.1498955293209292, 0.1693823977257125, 0.1943863622727804, 0.18410451477393508, 0.10590310790576041, 0.13615175586892292, 0.1554477884201333, 0.13574620184954256, 0.1819369537406601, 0.13017535937251523, 0.2579736494226381, 0.18112764169927686, 0.20467257359996438, 0.13462052709655836, 0.1669656828744337, 0.2562466124072671, 0.1463941062684171, 0.15998991031665355, 0.17419052019249648, 0.09764454793184996, 0.18859165837056935, 0.1611194442375563, 0.19547242118278518, 0.16266101854853332, 0.09721191294374876, 0.09921282471623272, 0.13636693416628987, 0.11541641695657745, 0.2480964208371006, 0.13291980663780123, 0.11774801489082165, 0.19237111962866038, 0.15583372005494311, 0.33501222962513566, 0.2214912578347139, 0.2654371614335105, 2.6958696031942964, 35.69626495242119, 78.88448908925056, 70.17989337444305, 55.49386762082577, 33.43653380870819, 39.657225608825684, 71.4226470887661, 63.81485491991043, 10.758295264095068, 0.38207516830880195, 4.356237770989537, 17.330543249845505, 6.445368519052863, 3.5469144489616156, 3.8321257196366787, 1.1176266660913825, 0.32030212052632123, 0.18777351477183402, 0.7702207483816892, 10.035453401505947, 36.69695645570755, 64.6507340669632, 77.17686831951141, 77.30113685131073, 73.16575035452843, 72.96182289719582, 70.36191880702972, 70.72032317519188, 69.03142020106316, 73.55725094676018, 71.55751705169678, 75.49822479486465, 72.2629263997078, 78.51680561900139, 80.68305417895317, 80.60960412025452, 79.06739607453346, 83.31016480922699, 80.97301661968231, 58.06880325078964, 43.768274411559105, 63.439883440732956, 58.45977947115898, 52.60853424668312, 59.20948684215546, 56.35202497243881, 78.36115837097168, 79.34206813573837, 80.82930833101273, 82.88303732872009, 73.47997829318047, 79.31579634547234, 84.1529443860054, 79.84002381563187, 83.00520077347755, 88.57872650027275, 80.29916077852249, 78.26791897416115, 76.43254145979881, 76.56250968575478, 74.44556728005409, 76.85059502720833, 76.64798989892006, 70.46260580420494, 70.76215133070946, 74.76051717996597, 71.89671725034714, 70.75573727488518, 48.983969539403915, 19.386495128273964, 2.103578047826886, 0.5719194235280156, 2.3776723025366664, 3.8440786907449365, 12.067103683948517, 14.60029760375619, 19.5302889123559, 11.957456767559052, 12.384906280785799, 4.101415844634175, 1.3662428129464388, 2.281692777760327, 32.889070585370064, 64.00165289640427, 41.52083940804005, 34.215431213378906, 38.93815599381924, 56.51111863553524, 57.22567409276962, 14.841824993491173, 0.40014331752900034, 0.29846481105778366, 0.22635777248069644, 0.14200307079590857, 0.24465349386446178, 0.1926645648200065, 0.11093499531853013, 0.09752765225130133, 0.14352911937749013, 0.3593984304461628, 0.15029649686766788, 0.10726473366958089, 0.111755409889156, 0.1276048121508211, 0.1786388791515492, 0.09453256687265821, 0.18477912701200694, 0.10057425752165727, 0.1573986720177345, 0.1577596229617484, 0.1473021536367014, 0.19125098129734397, 0.14822937810095027, 0.16831416520290077, 0.10492696848814376, 0.19916270597605035, 0.1045746635645628, 0.07697102249949239, 0.13018465106142685, 0.21232214203337207, 0.24911959015298635, 0.22359143185894936, 0.13480958179570735, 0.07977795859915204, 0.1423274932312779, 0.18743200809694827, 0.12310540085309185, 0.14035768486792222, 0.21419735625386238], [0.03255551382608246, 0.014417355960176792, 0.03715642866154667, 0.07211684976937249, 0.03008240688359365, 0.0030609959776484175, 0.04888320429017767, 0.0500474484579172, 0.035673428355949, 0.055867671107989736, 0.08869921191944741, 0.062408905068878084, 0.03256753661844414, 0.10667224749340676, 0.0700900964147877, 0.039765252149663866, 0.08677028847159818, 0.038244198221946135, 0.04164712343481369, 0.050806762010324746, 0.03418429048906546, 0.04246098113071639, 0.035137044833390974, 0.05765656242147088, 0.03384742223715875, 0.01767436751833884, 0.05015304865082726, 0.030931021210562903, 0.03724300389876589, 0.09795105492230505, 0.02933681935246568, 0.08478082803776488, 0.013058328640909167, 0.02075991142191924, 0.022410911697079428, 0.05128272357978858, 0.01457307895179838, 0.014787966883886838, 0.02889121347834589, 0.022971656217123382, 0.044791781256208196, 0.09019284349051304, 0.0577017963223625, 0.06212229505763389, 0.043319530959706753, 0.007210280555227655, 0.233110410918016, 0.4358934023184702, 12.365746758878231, 45.48524267971516, 57.8651911765337, 50.6056959182024, 36.46997943520546, 18.192325606942177, 31.872304044663906, 57.77499161660671, 25.99617015570402, 2.892584097571671, 0.2035107117262669, 1.8366309721022844, 1.1045229504816234, 1.4398471196182072, 2.090718112885952, 0.68373370799236, 0.19050964998314157, 0.0014949565365895978, 0.04681164005887695, 0.14576667977962643, 5.0863624177873135, 20.927139557898045, 45.00049129128456, 53.75868313014507, 59.11016397178173, 56.51937939226627, 64.16705042123795, 64.05877143144608, 64.86224591732025, 56.83777950704098, 51.343224942684174, 54.02011290192604, 50.79472817480564, 47.49799087643623, 48.82701896131039, 37.41540290415287, 21.134000457823277, 6.696458570659161, 0.6755934166722, 0.577669464983046, 17.391875758767128, 43.78848172724247, 26.28494706004858, 54.2892524600029, 56.36729635298252, 61.95100553333759, 65.9755177795887, 66.27225145697594, 71.19618684053421, 76.16840243339539, 73.44014123082161, 69.4845762848854, 69.77229684591293, 70.39296314120293, 70.77072367072105, 74.18031111359596, 79.26490187644958, 78.25129866600037, 78.95995303988457, 79.02418479323387, 74.19427156448364, 69.38760548830032, 68.00407692790031, 53.10057744383812, 42.031756192445755, 24.710767529904842, 8.52448157966137, 1.4470017794519663, 0.17443384072976187, 0.11716303182765841, 0.7929197209887207, 2.1986525086686015, 3.0420685512945056, 4.787371186539531, 5.5633560474962, 7.562330458313227, 2.2182613564655185, 0.5977199203334749, 0.15942255326081067, 11.1497369594872, 44.01478238403797, 39.89429488778114, 25.939912274479866, 27.5368544831872, 38.27286869287491, 50.593042597174644, 29.15912803262472, 3.408677391707897, 0.14358040178194642, 0.02491032220859779, 0.07369921993813477, 0.02933880274213152, 0.005821606291647186, 0.06273275605053641, 0.03566861923900433, 0.012988640046387445, 0.028985666613152716, 0.030311552400235087, 0.011716998760675779, 0.02324843648239039, 0.05698836605006363, 0.021526470191020053, 0.04300047425203957, 0.031681616383139044, 0.07925484096631408, 0.05151268174813595, 0.04493435895710718, 0.024851282505551353, 0.04829869249078911, 0.07948256155941635, 0.040047943621175364, 0.031110251729842275, 0.03769365823245607, 0.05783107473689597, 0.026471348210179713, 0.03293210924312007, 0.041569962340872735, 0.008506702615704853, 0.06408369488781318, 0.023003759670245927, 0.01946912921994226, 0.03148616808175575, 0.012211155935801798, 0.0201054800345446, 0.023405821884807665, 0.028167079581180587, 0.029041268317087088, 0.05098210553114768, 0.05719686501834076, 0.03466208516329061, 0.016683787762303837, 0.03442242341407109, 0.04530950347543694, 0.053013742217444815, 0.07288644948857836, 0.03983485446951818, 0.059123020255356096, 0.033357204010826536, 0.017205792173626833, 0.05486477726662997, 0.035507484135450795, 0.0418967262521619, 0.008824086708045797, 0.05848554508702364, 0.10270164610119537, 0.012547992646432249, 0.07063343015033752, 0.009559177487972192, 0.07409022786305286, 0.03426756687986199, 0.07427082950016484, 0.021747027203673497, 0.08620999666163698, 0.0273611647207872, 0.02888883675041143, 0.03571397188352421, 0.12813262757845223, 0.07728703640168533, 0.02487230383849237, 0.1226731963106431, 0.08992436414700933, 0.04392032547912095, 0.039074928645277396, 0.03438267027377151, 0.02429112613754114, 0.06785365665564314, 0.06509893806651235, 0.022956629582040478, 0.07551748174591921, 0.048980726205627434, 0.062039950062171556, 0.0540325662586838, 0.1413143429090269, 0.0683732787729241, 0.09187840929371305, 1.0540944314561784, 21.01077876985073, 57.767088040709496, 62.721117809414864, 40.46379312872887, 18.182867914438248, 30.15350617468357, 71.60724878311157, 74.71794426441193, 19.163984768092632, 1.7519344668835402, 0.08321294459165074, 2.5672016199678183, 0.24172575096599758, 2.3234513495117426, 2.8437989903613925, 2.9216539626941085, 1.331906549166888, 0.09573230054229498, 0.028509881303762086, 0.957445251988247, 11.095278281718493, 32.92832247912884, 59.069513753056526, 61.74934655427933, 67.033950984478, 62.66685292124748, 69.00932058691978, 68.62441644072533, 69.23464849591255, 65.98060950636864, 61.52239993214607, 63.41549634933472, 60.6571901589632, 61.14659249782562, 62.30298064649105, 51.224245727062225, 36.19662210345268, 17.45463129132986, 2.86209215875715, 1.579545079730451, 29.220880419015884, 64.3825900554657, 40.825674310326576, 61.88123747706413, 61.226703599095345, 71.20860457420349, 71.03832051157951, 70.67572876811028, 75.03773510456085, 79.08897131681442, 76.56752541661263, 75.1288390159607, 75.47615557909012, 75.87236791849136, 73.18447574973106, 73.53762120008469, 76.07188001275063, 77.842638194561, 80.8853705227375, 78.99461477994919, 77.92498737573624, 72.23642662167549, 72.48713716864586, 60.42064905166626, 47.5142540037632, 35.01482091844082, 12.769648935645819, 4.233432160690427, 0.551086685154587, 0.4323336761444807, 1.8901179707609117, 2.7025952422991395, 7.483738800510764, 8.236826565116644, 4.363192822784185, 2.045450904406607, 1.4025441650301218, 0.2236205685767345, 0.15254495199769735, 5.850040689110756, 54.37512405216694, 64.89516735076904, 33.46174165606499, 18.88686753809452, 30.592671409249306, 53.87064792215824, 39.65994246304035, 6.8358806893229485, 0.03628135862527415, 0.13538737344788387, 0.09697759465780109, 0.02811647253111005, 0.07401369759463705, 0.02731140557443723, 0.04988899621821474, 0.03302841403638013, 0.031790682405699044, 0.06519203307107091, 0.03401657995709684, 0.054478726888191886, 0.023956085424288176, 0.05471458141983021, 0.013055523322691442, 0.13203075825003907, 0.0944090067059733, 0.03401723304705229, 0.054807082706247456, 0.0571935587504413, 0.011560790590010583, 0.07256782322656363, 0.025170428270939738, 0.02079663103359053, 0.0512337418331299, 0.056785900742397644, 0.02410995490208734, 0.039370748709188774, 0.01646033637371147, 0.07197210128651932, 0.011626176583376946, 0.052194407471688464, 0.035504188999766484, 0.029730311616731342, 0.046259196460596286, 0.008228215410781559, 0.04393588831590023, 0.07270756963407621, 0.02832720536389388, 0.058026901533594355, 0.10923577399807982, 0.10916340717813, 0.10238903865683824, 0.15156300156377256, 0.09681166528025642, 0.12755207513691857, 0.18910151382442564, 0.14971306489314884, 0.15227017924189568, 0.12263660100870766, 0.24307760264491662, 0.18865088175516576, 0.1270743546774611, 0.2561522409087047, 0.23729514417937025, 0.13034557836363092, 0.2229167305631563, 0.14177515724441037, 0.16686445393133909, 0.1819133831304498, 0.1610956955119036, 0.2135753771290183, 0.2029080581269227, 0.12183603888843209, 0.1511673181084916, 0.1618712695199065, 0.18949822144350037, 0.07560598285635933, 0.27337582607287914, 0.15715302113676444, 0.17817049490986392, 0.21670550369890407, 0.15933704300550744, 0.11627923784544691, 0.12001561000943184, 0.11185459792613983, 0.13188777607865632, 0.12302992443437688, 0.1905225930386223, 0.10947314993245527, 0.18364907358773053, 0.13525356422178447, 0.12801441829651594, 0.27345556241925806, 0.2663085318636149, 0.25373637210577726, 0.20955200161552057, 0.8459509816020727, 20.14699012041092, 69.37496736645699, 77.83129960298538, 63.191365376114845, 49.39786992967129, 30.692055076360703, 49.40078057348728, 73.41837599873543, 33.651663064956665, 3.1823308998718858, 0.29875490174163133, 5.1124845910817385, 9.85986102372408, 9.802118372172117, 6.318608270958066, 2.650047861970961, 0.8048752450849861, 0.16265592741547152, 0.06737835559761152, 0.6829700677189976, 6.09168017283082, 24.644331894814968, 50.104875192046165, 55.854460671544075, 62.29971282184124, 61.353187412023544, 68.69542703032494, 68.97915780544281, 66.71320259571075, 61.5762734413147, 55.690545067191124, 60.19441679120064, 54.281763061881065, 49.245418310165405, 53.2677798718214, 42.66178518533707, 25.77770657837391, 8.978520166128874, 1.2828713678754866, 0.7750322995707393, 24.624134078621864, 59.75829899311066, 41.61331124603748, 68.69915083050728, 70.50103694200516, 71.11699149012566, 69.45380553603172, 68.81960436701775, 71.95423096418381, 80.1779092848301, 75.29360577464104, 73.82466539740562, 75.38813710212708, 76.4180338382721, 75.44034630060196, 78.12582179903984, 78.7133538722992, 78.12212079763412, 83.00648510456085, 81.59111425280571, 77.86951795220375, 73.43300521373749, 78.18694531917572, 57.79877074062824, 41.38611763715744, 30.41359081864357, 8.51470660418272, 1.726998898666352, 0.3172258590348065, 0.38381152669899166, 1.7125667980872095, 4.330769637599587, 10.156915783882141, 17.755974121391773, 15.822020396590233, 17.522936426103115, 8.478715885430574, 1.6607817518524826, 0.23200716386782005, 15.413500517606735, 53.028533309698105, 52.15784043073654, 38.94228637218475, 39.40055698156357, 50.51790162920952, 66.05985805392265, 42.371856942772865, 5.895271087065339, 0.20649116195272654, 0.24331584689207375, 0.16863941884366795, 0.1171821792377159, 0.16446805908344686, 0.1695050747366622, 0.14309659571154043, 0.1011172795551829, 0.16517859126906842, 0.2199235450825654, 0.1139198019518517, 0.17969039850868285, 0.19556456623831764, 0.19584668625611812, 0.12013239436782897, 0.3191743529168889, 0.22743701847502962, 0.11138265879708342, 0.10734949435573071, 0.11274300806690007, 0.1316377316834405, 0.16385486698709428, 0.0963722173764836, 0.14601227128878236, 0.13210466131567955, 0.0956412687082775, 0.08344556335941888, 0.1333459181478247, 0.1633310443139635, 0.12307540324400179, 0.15320736332796514, 0.12274553344468586, 0.10386473251855932, 0.20353211526526138, 0.13132056745234877, 0.1044072573131416, 0.13617078453535214, 0.2441087574698031, 0.1697274370235391, 0.16836241964483634], [0.1343276904663071, 0.028155362924735527, 0.0292174356218311, 0.05789016453491058, 0.0644956091127824, 0.05853418915648945, 0.05791334551759064, 0.10283800089382567, 0.011501384451548802, 0.06001125970215071, 0.040037698272499256, 0.07802757361787371, 0.08680718805408105, 0.019262695277575403, 0.18133878271328285, 0.04328959643316921, 0.053795813728356734, 0.0756272157013882, 0.11029597648303024, 0.0716717541217804, 0.027788931220129598, 0.08175379320164211, 0.039097627231967635, 0.05724381699110381, 0.13178760098526254, 0.024154467064363416, 0.06183440484164748, 0.13024368148762733, 0.03870328335324302, 0.0415122937556589, 0.06463680270826444, 0.056328099526581354, 0.027937941486015916, 0.03374889100086875, 0.036624453496187925, 0.029593867766379844, 0.049811297067208216, 0.06887090363306925, 0.020306357146182563, 0.03151708224322647, 0.020028133403684478, 0.008817024245217908, 0.05880008211534005, 0.0034820325890905224, 0.06569021454197355, 0.02271846511575859, 0.0025432860502405674, 0.03677684238937218, 0.23995667870622128, 3.413200811482966, 28.8995810598135, 61.174395605921745, 51.31672516465187, 42.389658987522125, 31.49039413779974, 26.100115478038788, 52.57816627621651, 48.91986317932606, 12.621452137827873, 0.2383830733015202, 0.8506327460054308, 2.743200813420117, 4.717777445912361, 4.079918498173356, 0.9853037539869547, 0.08879661880200729, 0.2609788131667301, 0.1400151095003821, 0.07296735842828639, 0.19902000582078472, 1.322777420282364, 3.0305967293679714, 2.9609101312234998, 5.197439482435584, 7.862967476248741, 7.852914165705442, 8.379087131470442, 3.306947825476527, 2.4726154329255223, 1.4217948820441961, 1.5364714222960174, 0.8304079750087112, 0.8363510342314839, 0.6376639707013965, 0.1444848719984293, 0.14934939768863842, 0.4385022592032328, 0.27224983961787075, 0.017649919318500906, 0.7197080994956195, 0.8108398562762886, 9.0435422770679, 22.231324575841427, 53.470962569117546, 75.01259565353394, 79.53102439641953, 82.92899966239929, 79.67046171426773, 82.25333511829376, 83.74022573232651, 86.69612511992455, 87.63624787330627, 84.42407503724098, 76.93060353398323, 39.27929408848286, 21.146176904439926, 20.355038456618786, 21.2778702378273, 19.149313755333424, 12.565107811242342, 9.488664641976357, 5.333299767225981, 1.0742345382459462, 0.4799439338967204, 1.3735271408222616, 2.825030372478068, 0.29653205070644617, 1.3514498504810035, 2.366279326379299, 4.76362151093781, 3.669317993335426, 5.821224460378289, 3.1162752443924546, 0.705082209315151, 0.06040506923454814, 6.718430416658521, 33.05996261537075, 45.35126566886902, 24.01519015431404, 21.930245831608772, 41.83047719299793, 50.45558497309685, 46.379178911447525, 13.891016263514757, 0.41449859098065645, 0.06043271794624161, 0.1005598672782071, 0.03779723607294727, 0.13850737712346017, 0.07071741158142686, 0.056359637092100456, 0.005389905481933965, 0.0845062556618359, 0.05799355683848262, 0.015408564686367754, 0.07080032431986183, 0.04589618976751808, 0.09177559215459041, 0.06704783270834014, 0.10755970768514089, 0.07023190599284135, 0.0763250571617391, 0.07991107762791216, 0.0402448873501271, 0.05293810994771775, 0.04204565302643459, 0.042743657759274356, 0.05450948519865051, 0.05070857958344277, 0.033756857956177555, 0.008542421255697263, 0.10544624921749346, 0.0018819187130247883, 0.07480938380467705, 0.09218449325999245, 0.06327995637548156, 0.03651739127235487, 0.05834836651047226, 0.06914006575243548, 0.25529636652208865, 0.03116617997875437, 0.02680750585568603, 0.09793561082915403, 0.036755932378582656, 0.06514948574476875, 0.026706030148488935, 0.04875844555499498, 0.05635671303025447, 0.03805268330324907, 0.0283466329346993, 0.08105054148472846, 0.026330497857998125, 0.07874650691519491, 0.04213581283693202, 0.03899928524333518, 0.02168542709114263, 0.04240777656377759, 0.01926711105625145, 0.09861247177468613, 0.03219766134861857, 0.17126187187386677, 0.039406048963428475, 0.03962808841606602, 0.007253050989675103, 0.03758353093871847, 0.02848223073669942, 0.03499228892906103, 0.009702112347440561, 0.0387048604170559, 0.01217475080920849, 0.0632648536702618, 0.025710084664751776, 0.1389293622924015, 0.0389781229023356, 0.05491177005751524, 0.03230538779462222, 0.05043207391281612, 0.03673609477118589, 0.017887336070998572, 0.03305362108221743, 0.019759147544391453, 0.11356040951795876, 0.023488103797717486, 0.027842351009894628, 0.019653595591080375, 0.06841243448434398, 0.0380609100102447, 0.029543763521360233, 0.039193060001707636, 0.0817044181167148, 0.08109325950499624, 0.0364264447853202, 0.02893243421567604, 0.09976127184927464, 0.541106223827228, 8.00628723576665, 42.484543696045876, 69.27918210625648, 48.39660085737705, 22.989744879305363, 16.462521627545357, 44.07400220632553, 80.38464099168777, 47.87498004734516, 5.342601193115115, 0.3965857584262267, 0.6847248610574752, 2.5844743056222796, 0.381715553230606, 2.1602833550423384, 2.2635715501382947, 0.334485542261973, 0.11215288192033768, 0.5371473706327379, 0.3974476590519771, 0.5609852727502584, 3.1832295516505837, 7.51745724119246, 7.461487669497728, 10.004827994853258, 14.15873184800148, 15.514384154230356, 16.613297536969185, 9.542015679180622, 6.219543311744928, 4.381329249590635, 5.531253470107913, 4.794423133134842, 2.469845381565392, 1.8854406592436135, 1.0919304261915386, 1.0988700413145125, 1.0370360780507326, 0.531157348304987, 0.08210308500565588, 2.4796813912689686, 2.7225123485550284, 18.742543682456017, 35.49123555421829, 58.73582325875759, 74.38321262598038, 73.94467815756798, 79.87322643399239, 75.58477655053139, 77.32202813029289, 76.1564102768898, 80.15616685152054, 81.89414039254189, 87.74815186858177, 85.2601669728756, 52.583618983626366, 32.633127719163895, 32.91424423456192, 32.00610436499119, 29.492132663726807, 19.558188915252686, 18.46320927143097, 7.986268009990454, 2.8785801865160465, 1.1784006049856544, 2.4236427107825875, 3.729851832613349, 1.3784098788164556, 2.850677571259439, 2.6893527153879404, 2.516810861416161, 3.973344429396093, 0.7852167030796409, 2.186769596301019, 0.9467622439842671, 0.06437288015149534, 2.6242237351834774, 35.8207880705595, 67.7787034213543, 38.36906813085079, 18.33539742976427, 32.60219357907772, 50.96603438258171, 55.16615800559521, 21.313031651079655, 1.0518797440454364, 0.05831006797961891, 0.019477992318570614, 0.04297874416806735, 0.10612561862217262, 0.06438004187657498, 0.012460185444069793, 0.03282441248302348, 0.06955526769161224, 0.0742041549528949, 0.01764012482453836, 0.05972364408080466, 0.023265761919901706, 0.046413785821641795, 0.04927731068164576, 0.01462505804738612, 0.051611094240797684, 0.03974503975769039, 0.05815508156956639, 0.024828518980939407, 0.060205205154488795, 0.03532965070917271, 0.04195019799226429, 0.01827257379773073, 0.015554601723124506, 0.01262347555893939, 0.06395695832907222, 0.07156763080274686, 0.06607460250961594, 0.1025688907247968, 0.048100342391990125, 0.13550283678341657, 0.02458635990478797, 0.1513424055883661, 0.04948289672029205, 0.06818169335019775, 0.10319770502974279, 0.03812620787357446, 0.06336773760267533, 0.000755437338284537, 0.050296617118874565, 0.02199410486355191, 0.21065887034637854, 0.1747550570871681, 0.09200347602018155, 0.1308233878808096, 0.16715282283257693, 0.20084407122340053, 0.315717191551812, 0.13898955046897754, 0.09616950716008432, 0.17861239932244644, 0.24586150248069316, 0.09814864431973547, 0.1572448544902727, 0.266148584196344, 0.23856926331063733, 0.2034173347055912, 0.1646193681517616, 0.18267518287757412, 0.207321536145173, 0.16671161603881046, 0.17518777371151373, 0.2721835213014856, 0.1518901254166849, 0.14187116146786138, 0.20089726836886257, 0.10741367528680712, 0.17513049475383013, 0.21336637350032106, 0.14813634246820584, 0.1312347306520678, 0.15361103229224682, 0.16269497922621667, 0.17089256434701383, 0.15166322118602693, 0.08376525089261122, 0.20871240994893014, 0.09869864254142158, 0.21330177696654573, 0.11870894770254381, 0.09093724729609676, 0.09679386115749367, 0.11010833186446689, 0.09301313824835233, 0.1690897688968107, 0.13135714048985392, 0.11929895510547794, 0.087105405254988, 0.20731960656121373, 0.7194856333080679, 7.466784585267305, 45.025155767798424, 87.86010906100273, 68.6822797358036, 57.2283985465765, 44.297510012984276, 42.12143898010254, 70.7064539194107, 60.50006479024887, 16.64443116635084, 0.3253382456023246, 1.212378025520593, 8.035822100937366, 13.496118653565645, 13.232961874455214, 4.6938439551740885, 0.15741023467853665, 0.49715950386598706, 0.8896550489589572, 0.4937224101740867, 0.5665225256234407, 2.059365757741034, 4.641729276627302, 3.5233818367123604, 5.67497743293643, 8.543082531541586, 10.22512687370181, 11.129355803132057, 5.785717265680432, 2.8830622835084796, 1.7821536515839398, 2.8272204799577594, 4.034172277897596, 1.0897214384749532, 0.9076733258552849, 0.6477407331112772, 1.018745640758425, 1.3099345844238997, 0.6666729203425348, 0.15272979129804298, 1.168666121084243, 1.293976865708828, 13.947188649326563, 31.229929514229298, 69.50708627700806, 84.02743712067604, 81.63444712758064, 88.19472670555115, 83.66388022899628, 85.48446893692017, 88.73623564839363, 89.39396515488625, 90.48466622829437, 89.84634608030319, 81.04173213243484, 42.93994165956974, 22.95245748013258, 24.09016963094473, 22.823146618902683, 22.16189470142126, 11.839642189443111, 11.958961486816406, 6.496755061671138, 0.969104926334694, 0.7954098342452198, 1.5611011069267988, 5.064362548291683, 1.887533871922642, 2.829205635935068, 3.9666807744652033, 11.492673307657242, 12.22349664196372, 17.45514616370201, 11.79993337020278, 1.784164218697697, 0.09624421174521558, 10.574120096862316, 40.483016297221184, 59.61711756885052, 32.86874547600746, 32.72355906665325, 54.95462715625763, 63.299800157547, 62.295301258563995, 20.526050180196762, 0.8256108511704952, 0.17493378109065816, 0.3103054506937042, 0.14011351828230545, 0.24344487668713555, 0.1342944719363004, 0.15202356356894597, 0.1130605730577372, 0.19388851476833224, 0.22207106812857091, 0.12729926995234564, 0.2601178624900058, 0.1527449904824607, 0.17090559646021575, 0.16159115330083296, 0.12862317234976217, 0.1529016430140473, 0.11678285925881937, 0.1695882249623537, 0.13154076266800985, 0.25598591077141464, 0.11091916530858725, 0.1126244870829396, 0.2191126300022006, 0.21027344337198883, 0.14238983363611624, 0.13568711205152795, 0.15367139858426526, 0.09202121334965341, 0.16916273685637861, 0.1425563864177093, 0.23433198599377647, 0.22726938215782866, 0.39943697105627507, 0.15838964696740732, 0.34014435892459005, 0.20347967511042953, 0.14829106541583315, 0.20726473216200247, 0.1757691425154917, 0.17238042200915515, 0.27755625487770885], [0.037701072287745774, 0.09816173580475152, 0.01152613043814199, 0.014736034172528889, 0.06164832986542024, 0.052618288827943616, 0.04349093738710508, 0.10685699031455442, 0.03351105493493378, 0.05161399232747499, 0.042017173109343275, 0.030372879773494788, 0.01840529021137627, 0.029471756643033586, 0.0428574289981043, 0.002905254664256063, 0.08235107365180738, 0.06949094575247727, 0.05074098546174355, 0.030798245425103232, 0.06320966014754958, 0.009849802518147044, 0.049248489376623183, 0.041540606689522974, 0.08987531560705975, 0.08316669394844212, 0.0407240438653389, 0.03574617367121391, 0.04837468841287773, 0.030251097050495446, 0.05888179628527723, 0.031304868825827725, 0.0261702459101798, 0.09048291933140717, 0.03401666530407965, 0.11166457843501121, 0.06534389875014313, 0.04956174991093576, 0.02637369827425573, 0.03819980665866751, 0.04332084456109442, 0.02378879791649524, 0.09513343189610168, 0.018268885323777795, 0.026521582331042737, 0.004511516190177645, 0.06717266194755211, 0.035865481331711635, 0.16579978371737525, 0.009257969431928359, 0.15076096256962046, 13.84958803653717, 53.53324122726917, 60.7100947201252, 60.165739730000496, 38.99639166891575, 33.40338058769703, 40.10078340768814, 50.65662078559399, 34.33533377945423, 7.529360577464104, 0.4593840683810413, 0.9319850150495768, 0.8001449739094824, 4.6440851502120495, 2.3478747764602304, 1.370858852751553, 0.4003541171550751, 0.7160480646416545, 0.3572204051306471, 0.03708036594616715, 0.11155966843944043, 0.08938374667195603, 0.1829745652503334, 0.06327269817120396, 0.32491412304807454, 0.02073264306091005, 0.2856938150944188, 0.13051636138698086, 0.2782067027874291, 0.2059722671401687, 0.12203498641611077, 0.1896987052168697, 0.10650323078152724, 0.2451349695911631, 0.27830763487145305, 0.08067580143688247, 0.06284990406129509, 0.09992657782277092, 0.017594710952835158, 0.036195247230352834, 0.1470448065083474, 0.15030500188004225, 6.6722215712070465, 23.282673060894012, 37.04382464289665, 51.7828119546175, 66.60988613963127, 70.64245775341988, 62.677351757884026, 54.628912433981895, 35.09058125317097, 16.021876372396946, 3.0676430789753795, 0.06758873962098733, 0.14867965393932536, 0.09438205932383426, 0.10666133792256005, 0.17352074675727636, 0.16723355365684256, 0.04870829492574558, 0.04946199042024091, 0.3422325843712315, 0.4775840527145192, 2.1404586313292384, 5.544005585834384, 1.8816092773340642, 1.6430422849953175, 2.085356363095343, 0.492426382843405, 6.5993723552674055, 2.5145810935646296, 0.5558222404215485, 2.786003379151225, 22.869530729949474, 44.008543118834496, 32.55545608699322, 20.581789389252663, 33.17420728504658, 54.10830616950989, 49.77718837559223, 25.10930724442005, 2.868271814659238, 0.032602031642454676, 0.024815614888211712, 0.06443508696975186, 0.017106210798374377, 0.042887779127340764, 0.04995973031327594, 0.05629364160995465, 0.04795042113983072, 0.03914445675036404, 0.030654832808068022, 0.029220461728982627, 0.039126730553107336, 0.05089764170406852, 0.024224993358075153, 0.04435820745129604, 0.044874530722154304, 0.04701760830357671, 0.033160174934891984, 0.018552541587268934, 0.018126368850062136, 0.0275511897780234, 0.02282495774124982, 0.06016332205035724, 0.04299945750972256, 0.03640109302068595, 0.019806030868494418, 0.045340640281210653, 0.10697240169974975, 0.028078595169063192, 0.018502472594263963, 0.02625312339660013, 0.05364064549212344, 0.05231883595115505, 0.11116112771560438, 0.01623548047064105, 0.054434658159152605, 0.07274748233612627, 0.012277245114091784, 0.06820717127993703, 0.00396573522266408, 0.05892552362638526, 0.053663028666051105, 0.01530492840174702, 0.03985294431913644, 0.08325835660798475, 0.12748237262712792, 0.04947616544086486, 0.10703800013288856, 0.027812409061880317, 0.013072449855826562, 0.05528945643163752, 0.0867247131827753, 0.0532981183641823, 0.03507357636408415, 0.07498611143091694, 0.049695102716214024, 0.0524404850875726, 0.07858071112423204, 0.05056970148871187, 0.10148221583222039, 0.057001498353201896, 0.019403469559620135, 0.0176609865957289, 0.0212585752888117, 0.03626830053690355, 0.07769001516862772, 0.04782563271874096, 0.05481807020260021, 0.048083347210194916, 0.05045691359555349, 0.04532731130893808, 0.0510110715549672, 0.04220575654471759, 0.08411001559579745, 0.05529595393454656, 0.06537635286804289, 0.06570609650225379, 0.07060741787427105, 0.082200484466739, 0.005636935829897993, 0.040135951203410514, 0.0354763436189387, 0.016645092182443477, 0.08046434129937552, 0.049742362680262886, 0.06005374023516197, 0.010117038764292374, 0.044141448379377834, 0.04084635351318866, 0.05499283113749698, 0.12589576479513198, 0.06936924837646075, 0.09083152835955843, 1.0537110082805157, 22.742224261164665, 63.408755511045456, 65.6531734764576, 48.99360202252865, 22.704606279730797, 33.02324518561363, 64.14584755897522, 77.68282637000084, 35.82323133945465, 2.966114664450288, 0.7859406236093491, 0.46491205925121903, 1.3138293754309416, 1.5385165438055992, 1.4894698443822563, 0.569373203907162, 0.29419956961646676, 0.3781926375813782, 0.436434606090188, 0.32377664814703166, 0.22992518730461597, 0.25128734414465725, 0.21797833149321377, 0.45336189621593803, 0.7682621316052973, 0.5769223300740123, 0.5041631811764091, 0.3156083927024156, 0.8559705689549446, 0.36955967894755304, 0.39947873912751675, 0.7611051562707871, 1.8711520009674132, 1.83065828634426, 1.7965731653384864, 0.8701543766073883, 0.1627141860080883, 0.35383585549425334, 0.10004474257584661, 0.1098388060927391, 0.1605569853563793, 1.1195543501526117, 14.323870036751032, 35.85203759372234, 53.27102869749069, 64.86072599887848, 77.0810678601265, 81.710724234581, 72.34375566244125, 69.29618999361992, 52.42600344121456, 28.771885111927986, 9.553930889815092, 0.9051937214098871, 0.3113462682813406, 0.23047504451824352, 0.46369170129764825, 0.3904139989754185, 0.4449633968761191, 0.3073192562442273, 0.63872737926431, 1.0827574809081852, 0.934902842855081, 3.85829942766577, 2.5376810040324926, 2.984478366561234, 1.362961451523006, 1.3879391737282276, 0.502014277735725, 1.0657324944622815, 0.569398021325469, 0.8428121125325561, 0.8628776483237743, 18.50887142121792, 59.034019857645035, 51.86562091112137, 25.4442535713315, 18.505557999014854, 46.26161701977253, 58.17203231155872, 34.81004610657692, 5.485336259007454, 0.09085287252673879, 0.1068728425889276, 0.02929665060946718, 0.02598625265818555, 0.01443683919205796, 0.029898424763814546, 0.020780216582352296, 0.04364900371001568, 0.0199486085693934, 0.03495874014333822, 0.030878957695676945, 0.017784953088266775, 0.02494452965038363, 0.041584857244743034, 0.03813766663370188, 0.04734323301818222, 0.029369882031460293, 0.0257069583676639, 0.04654261894756928, 0.04428379972523544, 0.022643255870207213, 0.09476274397457018, 0.04618664781446569, 0.039115702238632366, 0.037296932059689425, 0.05861553225258831, 0.10141669161384925, 0.09258196529117413, 0.05398370325565338, 0.030884408770361915, 0.08207923980080523, 0.0786628520290833, 0.008744246460992144, 0.0868810985411983, 0.07439821172738448, 0.0659892703697551, 0.08968039051978849, 0.09506392234470695, 0.02366763674217509, 0.07548034467617981, 0.08228461432736367, 0.03260183868405875, 0.07009975175606087, 0.1681141267181374, 0.16495685238623992, 0.14693973324028775, 0.10429309273604304, 0.11811721851699986, 0.13336524367332458, 0.11821892985608429, 0.1968159608077258, 0.13372845074627548, 0.15344005631050095, 0.08255035514594056, 0.16176511271623895, 0.17791380087146536, 0.1437301523401402, 0.18674650113098323, 0.09449805700569414, 0.2254731027642265, 0.127067779249046, 0.2303019311511889, 0.15843301807763055, 0.21509663143660873, 0.13805710128508508, 0.1714786235243082, 0.15462329203728586, 0.1550909786601551, 0.09450363795622252, 0.23333461373113096, 0.1720482367090881, 0.11938526688027196, 0.14032219536602497, 0.1354805871960707, 0.10882948525249958, 0.11367412138497457, 0.2138149127131328, 0.12472278554923832, 0.3084966883761808, 0.20147180941421539, 0.1442624651826918, 0.08105875705950893, 0.1575960239279084, 0.20147865201579407, 0.19969311892054975, 0.20034206769196317, 0.23466728831408545, 0.1156774080300238, 0.10326740011805668, 0.173253336106427, 0.21103059727465734, 0.2832275693072006, 0.22841047873953357, 0.8766494155861437, 22.000095583498478, 74.7129513323307, 84.348975867033, 77.76778981089592, 51.334702000021935, 49.38590057194233, 55.704402923583984, 65.80677643418312, 44.83272269368172, 8.735197372734547, 0.544098800746724, 1.8409486091695726, 3.2338836835697293, 11.841391045600176, 7.186852181330323, 1.3372317259199917, 0.42735484486911446, 0.6366193830035627, 0.841771918348968, 0.27543041738681495, 0.24468404066283256, 0.38655949174426496, 0.4675042623421177, 0.24114172527333722, 0.8674588368739933, 0.27808228915091604, 0.4270524642197415, 0.3778343286830932, 0.5043355375528336, 0.30867106339428574, 0.4540228529367596, 0.2873410563915968, 0.6174495304003358, 0.8927474298980087, 0.46626434137579054, 0.3451902506640181, 0.1564611613866873, 0.33907171804457903, 0.13879800215363503, 0.11438956658821553, 0.23329603689489886, 0.8182728511746973, 8.113003559410572, 25.41066337376833, 42.95682415366173, 53.21404315531254, 71.62842884659767, 72.80128911137581, 60.48402965068817, 58.888103887438774, 39.68810275197029, 19.305690564215183, 4.26657160744071, 0.33511494286358356, 0.2414629267877899, 0.1494545303285122, 0.2166855992982164, 0.1790985802654177, 0.3410913987318054, 0.6033560272771865, 0.6710872740950435, 1.150070868898183, 2.339414767920971, 6.877044355496764, 11.210494749248028, 8.0979991145432, 6.3705282099545, 10.958847552537918, 5.774249006062746, 16.736813709139824, 5.519037125632167, 0.8838933112565428, 3.8529208162799478, 29.675537422299385, 58.49901996552944, 44.977084547281265, 35.35907864570618, 44.22445513308048, 67.34938725829124, 66.0629890859127, 36.326024159789085, 4.142558611929417, 0.23909154231660068, 0.20957935717888176, 0.2689070877386257, 0.14240684366086498, 0.16582547686994076, 0.11905138948350213, 0.11167220771312714, 0.16730141564039513, 0.1298161450540647, 0.16041499766288325, 0.17052775423508137, 0.19664955645566806, 0.09478313077124767, 0.1754021504893899, 0.14328661520266905, 0.11650459840893745, 0.1276043668622151, 0.11428995552705601, 0.14322040078695863, 0.1564996491651982, 0.2124770579393953, 0.22741138469427824, 0.14785633014980704, 0.20040834147948772, 0.1435579443932511, 0.10476944764377549, 0.1785248110536486, 0.2560999640263617, 0.16596035478869453, 0.10125049506314099, 0.10980794017086737, 0.14984565699705854, 0.1990688985097222, 0.24562462378526106, 0.14890448015648872, 0.14548457460477948, 0.1050666777882725, 0.16690142772858962, 0.113287514395779, 0.12172066461062059, 0.22339243238093331, 0.15896230295766145, 0.13983208104036748], [0.07741664507193491, 0.07424286537570879, 0.05890682521567214, 0.021692583250114694, 0.032274258410325274, 0.0690489225962665, 0.09679650320322253, 0.059880808694288135, 0.04712738678790629, 0.01139639560278738, 0.025561655129422434, 0.03937895686249249, 0.020914699307468254, 0.01370559830320417, 0.04021231448859908, 0.06611792909097858, 0.04569154996715952, 0.002604735877866915, 0.003513687506710994, 0.05308105130097829, 0.02725948863371741, 0.05031256216170732, 0.045345531034399755, 0.017877146383398212, 0.02679094297491247, 0.02091368442052044, 0.006542994242408895, 0.04621225562004838, 0.03216023484128527, 0.039161674576462246, 0.059154082846362144, 0.029180669625930022, 0.09656798851210624, 0.022548127381014638, 0.014130599374766462, 0.0637234489840921, 0.07765678921714425, 0.05939070921158418, 0.01327430474702851, 0.028526679816422984, 0.11780916043790057, 0.020932280785928015, 0.0534364658233244, 0.00910756300072535, 0.017119281874329317, 0.04502672665694263, 0.012735101063299226, 0.1504308998119086, 0.04895370460872073, 0.014115185895207105, 0.14004565629875287, 0.1978719627368264, 1.947710292879492, 24.83665857464075, 36.54163978993893, 54.73317123949528, 49.542729556560516, 36.363341957330704, 33.956672698259354, 33.76954033970833, 50.3559885174036, 36.67823486030102, 10.356280636042356, 0.27844469470437616, 0.472053152625449, 1.103941344190389, 0.08901305132894777, 0.44821287563536316, 0.07208629554952495, 0.3276552603347227, 0.5205062229651958, 0.5080849269870669, 0.4986578703392297, 0.12955400365171954, 0.30424064956605434, 0.19128072657622397, 1.6198062943294644, 1.7717857891693711, 1.10537588596344, 0.6760084850247949, 1.6043234313838184, 1.192015630658716, 0.6480630033183843, 3.6382841086015105, 4.571104366332293, 4.340088637545705, 1.0516343009658158, 0.40935357799753547, 0.013131722407706548, 0.13506051676813513, 0.08596695071901195, 0.07815253644366749, 0.06889876385685056, 0.045502495268010534, 0.0694886822020635, 0.08288448487292044, 0.6744912383146584, 2.5261122873052955, 2.5405747862532735, 0.9122339717578143, 0.5934890848584473, 0.18935587751911953, 0.05734631871746387, 0.1461516466224566, 0.2116162408492528, 0.45192575140390545, 1.1806384474039078, 0.20707728050183505, 0.11002707411535084, 0.1743113121483475, 0.3009382408345118, 0.3644743049517274, 1.2465270305983722, 0.4408952995436266, 1.4521355414763093, 0.9007659496273845, 2.684071473777294, 1.9287653407081962, 1.368949692696333, 0.719261682825163, 0.18103800510289147, 3.7504970747977495, 24.357675276696682, 46.90471351146698, 44.79013837873936, 28.397612795233727, 40.4105693846941, 54.539970606565475, 59.60042506456375, 32.38284274935722, 8.562752176076174, 0.09662159383879043, 0.057407442000112496, 0.009286407603212865, 0.037289198880898766, 0.05718505002732854, 0.05986823671264574, 0.08008148957742378, 0.01992843328480376, 0.0037580338312181993, 0.0269986441344372, 0.02018427385337418, 0.014127276408544276, 0.03057491463550832, 0.030119033726805355, 0.044891422003274783, 0.07750352830043994, 0.027455009294499177, 0.06747056744643487, 0.06851856160210446, 0.049168344849022105, 0.024557642500440124, 0.002066352499241475, 0.0295115023618564, 0.027333625475876033, 0.009568345794832567, 0.0820221909089014, 0.03732070304977242, 0.038535049607162364, 0.04719980926893186, 0.0455297024018364, 0.02093700270052068, 0.10851520055439323, 0.08600110435509123, 0.05535926284210291, 0.042634729034034535, 0.02223997282271739, 0.060789802300860174, 0.05571133027842734, 0.024464738598908298, 0.06952292489586398, 0.055387178726959974, 0.061191845961729996, 0.013106058013363509, 0.06155557253805455, 0.08326136972755194, 0.041622625140007585, 0.15550891170278192, 0.08416532786213793, 0.051886238070437685, 0.020078792404092383, 0.006944314309293986, 0.05806265820865519, 0.03647173063654918, 0.025023202870215755, 0.03491126866720151, 0.04720509336038958, 0.15111054381122813, 0.031348006159532815, 0.055855091704870574, 0.036366935673868284, 0.0732421460270416, 0.031695616999058984, 0.04280433575331699, 0.04571663084789179, 0.037994187223375775, 0.037514028808800504, 0.01530579393147491, 0.042555556719889864, 0.05926294848904945, 0.04826278738619294, 0.02129425403836649, 0.008930867843446322, 0.03609312028856948, 0.02201513732870808, 0.1115160969493445, 0.03532397327944636, 0.0627827545395121, 0.08693278912687674, 0.019520452442520764, 0.08220392061048187, 0.07986351338331588, 0.005397066743171308, 0.03268707434472162, 0.007065751933623687, 0.020902045689581428, 0.005300791171976016, 0.07528809874202125, 0.02324805984244449, 0.04358860773209017, 0.02964740815514233, 0.01966586885828292, 0.03625045559601858, 0.05241967526671942, 0.11968418169999495, 0.009364911056763958, 0.10977379395626485, 0.17625054402742535, 6.175572546198964, 37.84897103905678, 51.810128688812256, 61.03973463177681, 43.226708471775055, 30.836409330368042, 37.16994747519493, 58.43351908028126, 75.06528362631798, 33.81470091640949, 3.065181286074221, 0.7384055899456143, 0.3660362586379051, 0.10225333695416339, 0.9801885159686208, 1.2206795113161206, 0.7552778127137572, 0.6259141699410975, 0.9017406566999853, 1.4500048058107495, 0.4367722832830623, 0.40148072701413184, 1.0903127817437053, 0.5966803198680282, 3.0582708818838, 2.2845193510875106, 2.048416407778859, 3.521250388585031, 6.641647461801767, 2.278865254484117, 4.829302886500955, 3.926637335680425, 5.3667165990918875, 4.573197579011321, 3.963355952873826, 1.4040006743744016, 0.1351856131805107, 0.7077564345672727, 0.9204754920210689, 0.7221061864402145, 0.4837103630416095, 0.029090173993608914, 0.21711543638957664, 1.5598296001553535, 3.3551420643925667, 6.797841405496001, 7.880005287006497, 4.589377585798502, 2.854241542518139, 0.8347798779141158, 0.4044601530767977, 0.45862559345550835, 1.759007431101054, 2.8143714694306254, 2.0684323087334633, 1.1669634561985731, 0.4371923685539514, 0.8221362344920635, 0.42774129600729793, 1.0714837233535945, 1.6582610621117055, 1.6638288320973516, 2.93557807803154, 1.5016059181652963, 3.0099476873874664, 3.4814520366489887, 0.5288266483694315, 0.4645765194436535, 0.20772551681147888, 0.7686187780927867, 18.750532753765583, 57.28616304695606, 65.241229981184, 34.016914665699005, 27.675835825502872, 42.77799054980278, 63.94099295139313, 45.478175058960915, 13.687472585588694, 0.2878543554106727, 0.19817921187495813, 0.024159712193068117, 0.051479043904691935, 0.033354565675836056, 0.027772073335654568, 0.023795408596924972, 0.009842255803960143, 0.0170750443066936, 0.05811969967908226, 0.012661757391470019, 0.036529020726447925, 0.024341896460100543, 0.036734918467118405, 0.03911671527021099, 0.06783071687095799, 0.022656592263956554, 0.05002302066714037, 0.033880956179928035, 0.04799581460247282, 0.024758549297985155, 0.03642155774286948, 0.021883404260734096, 0.01888121281808708, 0.026455649931449443, 0.03309655803604983, 0.020983416616218165, 0.0569220662873704, 0.07489829309633933, 0.025069024923141114, 0.08123885403620079, 0.03164076857501641, 0.01969631361134816, 0.08490253283525817, 0.08693253679666668, 0.009249205595551757, 0.010452225124026882, 0.035171439667465165, 0.04425844796060119, 0.02343599760934012, 0.019171019630448427, 0.021429981716210023, 0.08813229273073375, 0.03326590871438384, 0.02547622651036363, 0.16146734822541475, 0.1853232696885243, 0.14927562820957974, 0.20921042072586715, 0.17485500953625888, 0.25616533239372075, 0.2437158051179722, 0.17382597725372761, 0.10410717732156627, 0.12732618022710085, 0.1082537419279106, 0.20050168881425634, 0.14496280025923625, 0.1444748233188875, 0.2078332321252674, 0.1944872795138508, 0.13510439253877848, 0.13504484260920435, 0.13285118766361848, 0.08915339887607843, 0.1299846571055241, 0.16213945200433955, 0.14369541982887313, 0.2053484771749936, 0.11665162528515793, 0.10579781941487454, 0.1019058188830968, 0.148859313048888, 0.11458202774520032, 0.17945748288184404, 0.15213559818221256, 0.2447150624357164, 0.1801197903114371, 0.11913203867152333, 0.14984357898356393, 0.21997810777975246, 0.24773606361122802, 0.17139385541668162, 0.1113540044752881, 0.10410018629045226, 0.2762468095170334, 0.17716959002427757, 0.18656178057426587, 0.16772976843640208, 0.1597239394322969, 0.09956949346815236, 0.13310540292877704, 0.21054055716376752, 0.2937866683350876, 0.12498559488449246, 0.2391490587615408, 0.3699251124635339, 4.480446456000209, 39.828832000494, 62.44852803647518, 80.7596504688263, 63.610254898667336, 56.45754911005497, 44.937399476766586, 48.19390073418617, 67.57428959012032, 47.28150129318237, 14.044716116040945, 0.58763318345882, 0.6227286939974874, 3.0889497231692076, 0.6039242155384272, 1.513279841747135, 2.4312926502898335, 2.5639703683555126, 1.9427012116648257, 2.4399701971560717, 1.1658093868754804, 0.5741746618878096, 0.8002748794388026, 0.8491230988875031, 3.810048666782677, 4.168119840323925, 3.1653123255819082, 1.560307068284601, 3.199970740824938, 3.80564684048295, 5.063129039481282, 8.35586467757821, 12.08701841533184, 10.222543962299824, 4.810429299250245, 1.1932858312502503, 0.12022404218441807, 0.6968079158104956, 0.5383720330428332, 0.4799172462662682, 0.23965925560332835, 0.1790228218305856, 0.20104314491618425, 0.98767856718041, 1.4569944120012224, 3.034410774707794, 4.07656280323863, 1.7441769456490874, 1.3935714215040207, 0.3983269853051752, 0.38254099956247956, 0.28407545818481594, 1.3449982716701925, 2.151837833225727, 2.199713601730764, 0.4888482514070347, 0.3320278163300827, 0.7502005132846534, 0.8965947828255594, 0.880605181446299, 2.636476415209472, 2.1196554601192474, 5.3273925092071295, 2.51894302200526, 7.660006592050195, 12.054183427244425, 4.47078357450664, 2.0611435873433948, 0.41634339198935777, 5.693580759689212, 30.971558578312397, 59.53337766230106, 58.55702765285969, 44.8799579590559, 55.11037319898605, 68.39716583490372, 76.1786162853241, 51.25212483108044, 13.832515552639961, 0.2392634385614656, 0.4284765268675983, 0.15369056083727628, 0.15036962809972465, 0.14169776608468965, 0.19535965926479548, 0.17268480645725504, 0.10039770058938302, 0.11477060746983625, 0.22118057997431606, 0.15001097781350836, 0.12320609544985928, 0.1284595436300151, 0.09847650289884768, 0.12450848298612982, 0.27829294034745544, 0.1579246172332205, 0.11306217609671876, 0.15643842198187485, 0.1523705621366389, 0.11625692146481015, 0.11262893996899948, 0.16047325625550002, 0.09393577623995952, 0.15883490588748828, 0.2692187007050961, 0.17551231489051133, 0.10589408339001238, 0.12913280515931547, 0.10649528237991035, 0.13684938952792436, 0.16969067102763802, 0.1235425406775903, 0.14700646715937182, 0.1487434489536099, 0.08958175909356214, 0.16066680836956948, 0.06300176231889054, 0.10810049585415982, 0.3429433540441096, 0.15296745667001233, 0.0788038081373088, 0.15631299902452156, 0.11120425391709432, 0.26435564446728677], [0.05218761682044715, 0.033735261458787136, 0.016323827585438266, 0.09363005592604168, 0.08483470795908943, 0.006412385064322734, 0.04105572821572423, 0.021196418565523345, 0.02552754416683456, 0.015928706307022367, 0.05413763952674344, 0.0037427351526275743, 0.025706848900881596, 0.10910606884863228, 0.024385989308939315, 0.06189355772221461, 0.06432693378883414, 0.07210933181340806, 0.044229801060282625, 0.025788290331547614, 0.009631606462789932, 0.04185479490843136, 0.03484561457298696, 0.02340213155548554, 0.03873876172292512, 0.04717425341368653, 0.05433158126834314, 0.004885359167019487, 0.0418805029039504, 0.038494049658766016, 0.058446637995075434, 0.05726216288167052, 0.07185986629338004, 0.027660150044539478, 0.0437622034951346, 0.040429411237710156, 0.07772402037517168, 0.04845861789362971, 0.04833378865441773, 0.10701642589992844, 0.028369793508318253, 0.016165610977623146, 0.012471035643102368, 0.004179518282398931, 0.041095210472121835, 0.04693985349149443, 0.05920364346820861, 0.04829836965654977, 0.06360725092235953, 0.009343149431515485, 0.07925821031676605, 0.05431481244158931, 0.1882485783426091, 0.04723827849375084, 5.243008062243462, 32.81643748283386, 63.89910399913788, 57.11812846362591, 43.740995675325394, 43.99584420025349, 31.078405044972897, 33.067957386374474, 55.00847786664963, 47.21513405442238, 21.009237952530384, 5.9707241132855415, 0.5244645418133587, 0.383644484099932, 0.8830130053684115, 0.49735477776266634, 1.7354745813645422, 1.1505632987245917, 1.1811130656860769, 1.2363807437941432, 2.984879957512021, 0.531425055814907, 3.2731935242190957, 1.7536689550615847, 1.7024462786503136, 6.757368827238679, 11.784925125539303, 1.5550051652826369, 6.020139511674643, 3.501818706281483, 2.3424220690503716, 4.402416693046689, 2.563111139461398, 1.5515219396911561, 1.2967845587991178, 0.10271331266267225, 1.255250887479633, 0.6534277810715139, 1.3873887970112264, 0.42862243310082704, 0.13756646745605394, 0.2592244651168585, 0.08093940487015061, 0.11913497015484609, 0.14690896379761398, 0.07056746806483716, 0.07495385769288987, 0.22488575224997476, 0.0677927337528672, 0.5045165028423071, 1.5341685083694756, 3.197635766118765, 0.9642412466928363, 2.608156534843147, 1.2988322926685214, 0.956997707253322, 0.5005980224814266, 2.905057640746236, 2.090450464747846, 1.2935324083082378, 1.888492489233613, 1.3487953366711736, 0.08002401766134426, 0.20039858965901658, 0.7014939549844712, 6.038896730169654, 29.424059316515923, 46.62885971367359, 41.01422779262066, 30.746593549847603, 25.668198354542255, 42.90915571153164, 57.987134233117104, 50.30244179069996, 15.301675368100405, 1.1357924225740135, 0.4301133187254891, 0.09124213640461676, 0.043822870356962085, 0.06790107989218086, 0.03032265307410853, 0.052627903351094574, 0.004376397537271259, 0.058341624098829925, 0.03925934492144734, 0.10187535372097045, 0.034159187343902886, 0.024694511230336502, 0.027201102020626422, 0.06534123443998396, 0.022155963561090175, 0.10660861575161107, 0.09345511687570252, 0.06793953056330793, 0.05180660191399511, 0.028858069163106848, 0.08856406682753004, 0.04923291540762875, 0.03317896982480306, 0.09290172703913413, 0.001624924452698906, 0.026512479889788665, 0.039525441970909014, 0.05197898797632661, 0.016025608529162128, 0.0305320055122138, 0.049407420301577076, 0.018086595300701447, 0.020508113702817354, 0.04438354808371514, 0.05485930021677632, 0.03871500928653404, 0.020854260656051338, 0.035062522074440494, 0.0949991328525357, 0.011151523976877797, 0.014848719092697138, 0.060081359260948375, 0.01387426342262188, 0.008838289559207624, 0.08884982336894609, 0.03903167256794404, 0.06674522199318744, 0.035664025344885886, 0.025433152259211056, 0.05789680304587819, 0.1047581373131834, 0.02959253004519269, 0.06738545795087703, 0.04343487926234957, 0.03628779675636906, 0.004094548403372755, 0.06099118407291826, 0.017370623172610067, 0.01967238677025307, 0.027610149700194597, 0.038708404172211885, 0.05269549074000679, 0.047103823599172756, 0.024689408965059556, 0.03888734710926656, 0.03619748109485954, 0.01664381197770126, 0.03745521360542625, 0.08553680192562751, 0.007112470593710896, 0.03771927717025392, 0.016929512858041562, 0.04120402045373339, 0.019563213136279956, 0.010492119272385025, 0.027836493609356694, 0.06782446798752062, 0.08591783538577147, 0.008190402058971813, 0.006767255499653402, 0.035864965539076366, 0.0721661135321483, 0.03191423515090719, 0.032052308015408926, 0.016883902317204047, 0.05209849972743541, 0.01319160630373517, 0.059570127123151906, 0.03285358630819246, 0.055603154833079316, 0.02099528912367532, 0.009078038510779152, 0.026536835321167018, 0.010366217629780294, 0.05313409630616661, 0.08078905317233875, 0.06724049424519762, 0.01779584967152914, 0.29354493599385023, 0.1536992736510001, 9.737254902720451, 42.89053291082382, 71.02706551551819, 56.373345628380775, 32.82468684017658, 25.659333430230618, 40.14915481209755, 63.01342472434044, 74.53987061977386, 42.30938069522381, 11.02769510820508, 0.21969816967612132, 0.8539850567467511, 0.4040018026717007, 0.25136719923466444, 0.5830349551979452, 0.7829182420391589, 1.3479317142628133, 0.49581182305701077, 0.5563075456302613, 1.4754649833776057, 1.5543225081637502, 3.1911060540005565, 2.7897856011986732, 2.8133528865873814, 3.4993260400369763, 5.500356378033757, 3.6288629891350865, 5.5909311678260565, 3.328035268932581, 4.627039739862084, 4.2594987619668245, 4.6584065817296505, 2.3585327295586467, 3.350387094542384, 2.0122539857402444, 2.1754806395620108, 3.028578325174749, 1.9768590037710965, 2.1858044480904937, 0.6944623135495931, 0.8038140926510096, 0.20181083731586114, 0.5073364265263081, 0.11695169043377973, 0.19354770571226254, 0.39447779185138643, 0.9277452144306153, 0.08715839459910057, 3.4667681995779276, 2.197999181225896, 5.789078185334802, 1.489588231779635, 3.0433854181319475, 2.4525240110233426, 1.3887079199776053, 1.0753919323906302, 2.286077979952097, 1.1926262103952467, 0.7216782937757671, 2.1326158521696925, 0.8367852796800435, 0.23804079479305074, 0.195434482593555, 0.23426419822499156, 2.3099081637337804, 19.998989962041378, 58.91027569770813, 61.21846564114094, 38.39729681611061, 27.40070778876543, 37.168260365724564, 62.32536144554615, 64.7810746729374, 25.253053531050682, 2.1619099052622914, 0.2683467959286645, 0.013711566098209005, 0.026625022874213755, 0.043847943816217594, 0.06259382600546815, 0.07530448536272161, 0.005608789415418869, 0.14172120310831815, 0.05396001390181482, 0.07006357947830111, 0.02904781220422592, 0.10346098933950998, 0.02632816380355507, 0.07740422894130461, 0.028183061731397174, 0.0640347131411545, 0.019058174220845103, 0.026607213185343426, 0.012728946803690633, 0.051993719607708044, 0.02476896162988851, 0.01701436074654339, 0.07155422019422986, 0.06732523266691715, 0.042048283939948305, 0.008534643548046006, 0.02059022863249993, 0.04358261860033963, 0.04872929028351791, 0.01919383510539774, 0.10740972706116736, 0.07633538785739802, 0.00943208098760806, 0.032924591287155636, 0.10746859421487898, 0.03610263091104571, 0.046400059800362214, 0.060275070936768316, 0.034272542980033904, 0.01900208826555172, 0.020153168588876724, 0.08960205683251843, 0.005973928855382837, 0.04029445168271195, 0.058919337825500406, 0.03892926361004356, 0.10190525485086255, 0.14131783100310713, 0.10047988602309488, 0.23917752754641697, 0.16974760859739035, 0.08240421142545529, 0.13833798933774233, 0.14827316481387243, 0.1846725249197334, 0.08442205900792032, 0.11336661991663277, 0.07720925932517275, 0.13318868674105033, 0.1407475647283718, 0.11826634567114525, 0.11175187726621516, 0.19895042205462232, 0.2094550771289505, 0.13094199792249128, 0.10881188150960952, 0.10224847588688135, 0.10637564075295813, 0.15448903752258047, 0.20634798682294786, 0.14908678131178021, 0.17561456799739972, 0.1822818594519049, 0.06656864279648289, 0.09780473308637738, 0.10295629181200638, 0.11685961959301494, 0.13173397339414805, 0.16612856998108327, 0.08049350028159097, 0.1832555275177583, 0.15039474237710238, 0.21383688028436154, 0.10840096918400377, 0.14800447766901925, 0.16515436756890267, 0.19854013313306496, 0.15274335775757208, 0.070019250997575, 0.2454960986506194, 0.17210008314577863, 0.22102104790974408, 0.16530552820768207, 0.21558782929787412, 0.2615573618095368, 0.3089615103090182, 0.18292240711161867, 0.2313938975566998, 0.30127645237371325, 0.13628134969621897, 7.758806515485048, 54.42025043070316, 89.55911189317703, 74.30487602949142, 61.91470228135586, 58.84092561900616, 45.616141855716705, 47.208218425512314, 72.03973397612572, 57.38947190344334, 27.490500770509243, 8.12423100695014, 1.0269919107668102, 0.46028975571971387, 1.9188393233343959, 1.787916161119938, 5.396404881030321, 4.383278070017695, 5.687506785616279, 4.65230030938983, 9.339448548853397, 5.187628883868456, 14.22880008816719, 12.542139943689108, 7.619220055639744, 18.928625397384167, 31.234204284846783, 10.802852623164654, 18.03244348615408, 12.290051020681858, 8.413494285196066, 12.711959481239319, 10.357892699539661, 7.643595272675157, 4.4070296455174685, 2.182614281773567, 3.887157216668129, 3.3504362544044852, 3.040702287107706, 1.807611573021859, 0.43670317449141294, 0.39522881561424583, 0.18693105841521174, 0.4115356405964121, 0.2884802530752495, 0.1544610585551709, 0.2710251178359613, 0.8233576908241957, 0.2062791897333227, 2.241140166297555, 4.013414466753602, 11.648902874439955, 7.021672669798136, 8.698383998125792, 6.220513209700584, 2.4813889246433973, 4.447655165567994, 11.347313057631254, 9.844860378652811, 5.843917317688465, 9.022829588502645, 4.0405625849962234, 0.9967924375087023, 0.3716725140111521, 0.9929847449529916, 9.693913478404284, 37.94517047703266, 58.40319290757179, 55.78441523015499, 41.21045306324959, 40.97129009664059, 54.85207065939903, 73.89064505696297, 71.95982426404953, 28.533280715346336, 1.9594941730611026, 0.5104954820126295, 0.16793341375887394, 0.08312149715493433, 0.31165874213911593, 0.273587130359374, 0.1645822756108828, 0.12196106108603999, 0.22600494063226506, 0.1247384597081691, 0.19575624814024195, 0.09787148926989175, 0.16584472818067297, 0.1028752863931004, 0.18391174933640286, 0.0843001612520311, 0.1890283083776012, 0.21382037492003292, 0.11478769913082942, 0.1316333084832877, 0.1789720737724565, 0.2202730075805448, 0.08523343421984464, 0.10500004034838639, 0.17200041271280497, 0.09315548959420994, 0.08980193946626969, 0.12354709004284814, 0.18432503653457388, 0.15608959773089737, 0.10440377664053813, 0.1982767300796695, 0.13618258468341082, 0.08225952231441624, 0.1601697623846121, 0.2751939097652212, 0.1619212605874054, 0.09989466547267511, 0.1679616598994471, 0.1382993976585567, 0.09668139609857462, 0.15294277283828706, 0.17094344599172473, 0.10803320532431826, 0.1616493525216356, 0.15757144399685785, 0.14255334361223504], [0.08328679570695385, 0.05736880950280465, 0.01470928531489335, 0.057039540843106806, 0.03420404274947941, 0.034137921102228574, 0.012141907991463086, 0.06729729822836816, 0.025173383874061983, 0.058793618009076454, 0.061367193193291314, 0.008604917511547683, 0.05159785061550792, 0.018777330697048455, 0.06707428285153583, 0.05077967362012714, 0.025341563814436086, 0.03768942056922242, 0.01961133770237211, 0.013772050206171116, 0.031260859468602575, 0.034315209049964324, 0.02028155271545984, 0.14434356708079576, 0.04179318180831615, 0.050142680847784504, 0.07029068408883177, 0.15039395570056513, 0.046660835650982335, 0.018996509170392528, 0.04194133674900513, 0.015720294541097246, 0.02065194563328987, 0.03268217988079414, 0.02460826995957177, 0.014898892914061435, 0.036109718421357684, 0.09026032697875053, 0.008778208066360094, 0.041160727269016206, 0.03132652098429389, 0.03620290619437583, 0.01799705332814483, 0.018484996871848125, 0.006664083985015168, 0.04889544230536558, 0.029808969993609935, 0.009546595301799243, 0.026892743371718097, 0.014896110787958605, 0.03134394661174156, 0.09708553261589259, 0.12660160660743713, 0.07764766822219826, 0.04794440232217312, 2.8152204863727093, 27.445600479841232, 65.05963012576103, 63.83829206228256, 54.028073474764824, 54.29133094847202, 41.738886907696724, 29.6649169921875, 39.67440068721771, 47.446241453289986, 48.2323432713747, 40.81508427858353, 20.567264668643475, 9.24704510718584, 2.8974851220846176, 0.5972087290138006, 0.1271064451429993, 1.179886800237, 0.821574458386749, 2.1950082667171955, 2.3940655728802085, 2.582089933566749, 1.6040680138394237, 1.832475420087576, 1.789407106116414, 3.0888758646324277, 1.892727599479258, 1.940517753828317, 1.4125103177502751, 5.338330697268248, 3.9630389073863626, 2.835519234649837, 2.011115471832454, 1.778011042624712, 2.573322616517544, 1.9267680728808045, 3.6876387102529407, 0.639452071627602, 0.8803351584356278, 1.727522558066994, 0.9731485031079501, 0.11069253567256965, 0.41552794980816543, 0.4133829945931211, 0.282383598969318, 0.6063274678308517, 0.5606764799449593, 0.6303729338105768, 8.193932566791773, 4.325989969074726, 7.9268833715468645, 2.4001929815858603, 3.2044165022671223, 1.3648134958930314, 3.589209741912782, 1.3638427667319775, 2.10284611210227, 1.2614534609019756, 1.1701419856399298, 0.021436616516439244, 1.5105219022370875, 8.955733738839626, 20.909493304789066, 35.80300122499466, 63.2113941013813, 55.66915601491928, 21.110042743384838, 31.165082193911076, 43.92962135374546, 59.96288761496544, 48.04168850183487, 25.348928086459637, 4.886290328577161, 0.07631241096532904, 0.06869249133160338, 0.13028469256823882, 0.03632693762483541, 0.041277585842181, 0.04212880696286447, 0.04724847189208958, 0.03812696857494302, 0.060285101062618196, 0.04357871490356047, 0.017741140400175937, 0.060119999179732986, 0.04720180935692042, 0.05561799036513548, 0.02606713562272489, 0.020776555938937236, 0.018396228588244412, 0.042457474482944235, 0.00530419855749642, 0.02709711785428226, 0.0635720657010097, 0.036468235120992176, 0.023360127852356527, 0.08883609363692813, 0.051306450041010976, 0.022526282264152542, 0.04203683631203603, 0.04517692621448077, 0.03184879256878048, 0.059345248955651186, 0.036578904182533734, 0.12425232329405844, 0.024518835598428268, 0.029974127537570894, 0.017565648449817672, 0.05285226201522164, 0.03373318715603091, 0.047574523341609165, 0.03920937240764033, 0.04079392820131034, 0.07100791044649668, 0.01892074702482205, 0.023947066474647727, 0.05074752007203642, 0.045871750844526105, 0.013403744578681653, 0.049271280731773004, 0.027568819496082142, 0.06371146329911426, 0.04390049900393933, 0.006172981675263145, 0.08506288868375123, 0.024247315304819494, 0.0473489030264318, 0.007223550619528396, 0.023455523514712695, 0.0044319667722447775, 0.06918944825883955, 0.13794215745292604, 0.04952957409841474, 0.007921082233224297, 0.038910079092602246, 0.06560072637512349, 0.0221674445856479, 0.0187335662485566, 0.013824802063027164, 0.011278792098892154, 0.03894579494954087, 0.025562746086507104, 0.06796826652134769, 0.014288375332398573, 0.1106422625889536, 0.003864203390548937, 0.030422334639297333, 0.024931788830144797, 0.05741428460169118, 0.07964659103890881, 0.0024392276691287407, 0.04420948105689604, 0.02290900967636844, 0.015905779509921558, 0.08816229776130058, 0.01568646930536488, 0.01104141059840913, 0.10977350451867096, 0.0398215254972456, 0.01259712096725707, 0.020861220145889092, 0.04365351967862807, 0.05412042170064524, 0.05876946852367837, 0.005503030588442925, 0.053195575819700025, 0.05577893622103147, 0.03523900479194708, 0.04638905746105593, 0.03746692840650212, 0.05244922016572673, 0.01593835051608039, 0.0650859356392175, 0.051792159720207565, 0.10702780302381143, 0.12816672184271738, 5.372550236061215, 38.42147871851921, 77.72877350449562, 62.48800791800022, 51.943197548389435, 37.32528313994408, 20.876140594482422, 36.414126232266426, 62.46195271611214, 66.87098532915115, 58.40158939361572, 39.891338646411896, 14.101992342621088, 0.9526327508501709, 0.9691004734486341, 0.7005954813212156, 0.5313557095360011, 0.5907375575043261, 0.26551701652351767, 0.8735906984657049, 0.9582101390697062, 1.5412871888838708, 1.8710068962536752, 2.3372405720874667, 2.3198733665049076, 1.694582006894052, 1.846058622468263, 1.4899227325804532, 0.35379079228732735, 2.8635443933308125, 2.55116980522871, 2.31997097376734, 2.339723501354456, 1.7380284005776048, 1.2803560215979815, 2.4704400496557355, 3.722619633190334, 2.5576268462464213, 4.256619941443205, 1.3983152294531465, 1.023324157577008, 1.103366268798709, 0.3718101675622165, 0.9129096823744476, 0.5383442470338196, 0.5109380988869816, 1.0073697636835277, 1.5826743305660784, 2.9431192483752966, 1.6564865573309362, 1.0282305255532265, 1.3087738654576242, 1.0027343686670065, 1.296041936147958, 2.0289312908425927, 0.6770506384782493, 0.8836978592444211, 0.3382776497164741, 0.5336791067384183, 0.10386412395746447, 0.9703561279457062, 4.646337954327464, 10.177009105682373, 27.71684892475605, 60.949561670422554, 71.83081358671188, 32.5914591550827, 29.17089220136404, 36.184911131858826, 55.369903072714806, 63.22025142610073, 37.29802340269089, 9.656862616539001, 0.09200136089930311, 0.2893645071890205, 0.1680550814489834, 0.008724253002583282, 0.012248813436599448, 0.058109710371354595, 0.055902451858855784, 0.0433158239320619, 0.017018065918819048, 0.06433098591514863, 0.026435604522703215, 0.07616593327838928, 0.09328779968200251, 0.008887307485565543, 0.03515477103064768, 0.005830308900840464, 0.03446286304097157, 0.06465687780291773, 0.01694440776191186, 0.029834943306923378, 0.023861353984102607, 0.020721188011521008, 0.03397236650926061, 0.030416861300182063, 0.014279772913141642, 0.07543818326666951, 0.03909014267264865, 0.03187618523952551, 0.027230773084738757, 0.04306583519792184, 0.06297422864008695, 0.07564978441223502, 0.05075324574136175, 0.06930854811798781, 0.016453534590255003, 0.067081236775266, 0.017286801303271204, 0.0407222515786998, 0.05967733035504352, 0.038100729943835177, 0.06712291578878649, 0.06859002300188877, 0.04242496099323034, 0.04786086989042815, 0.05832133749208879, 0.0558416959393071, 0.05866687402885873, 0.05538469624298159, 0.12440512407920323, 0.08455542294541374, 0.12318219087319449, 0.24183241243008524, 0.10755223425803706, 0.07865439896704629, 0.12372694953228347, 0.14022455841768533, 0.14666432223748416, 0.18008728424319997, 0.183743252127897, 0.10978252161294222, 0.12113238641177304, 0.08911688521038741, 0.1546220007003285, 0.17422241769963875, 0.08322082619997673, 0.0916284836421255, 0.0857862748671323, 0.17582848464371637, 0.10164183695451356, 0.15744682255899534, 0.12073127043549903, 0.32625058258417994, 0.12788431980879977, 0.14347737684147432, 0.16380190732888877, 0.1875586630194448, 0.1017618273908738, 0.08425527616054751, 0.1414305780781433, 0.06417152806534432, 0.07811341783963144, 0.16026702825911343, 0.16379147273255512, 0.12421584673575126, 0.17624986125156283, 0.28221896092873067, 0.0994142510171514, 0.1140163405216299, 0.22214247757801786, 0.20139891566941515, 0.1693356572650373, 0.08866172604029998, 0.07449075012118556, 0.16401620989199728, 0.16043053823523223, 0.14225823601009324, 0.21260010602418333, 0.18742555141216144, 0.1979766204021871, 0.31545176985673606, 0.3795745165552944, 0.2196161772008054, 0.2447521104477346, 3.601223984733224, 37.0687323063612, 92.8563317656517, 84.07483577728271, 68.90990272164345, 67.0114865899086, 60.254449769854546, 44.18858885765076, 57.42615893483162, 63.068327978253365, 61.73284783959389, 54.988965913653374, 26.227752529084682, 12.908168602734804, 3.744099880568683, 0.8712167758494616, 0.3303280606633052, 1.973777487874031, 1.4303859835490584, 4.066281979903579, 4.727628417313099, 4.823262160643935, 5.341990850865841, 8.177227713167667, 9.801356513053179, 14.543934278190136, 8.702787961810827, 11.215079203248024, 10.166899748146534, 22.177867144346237, 14.57704285159707, 16.276240423321724, 11.960416808724403, 9.813580457121134, 7.623621169477701, 9.896643999963999, 11.783158220350742, 10.193097442388535, 9.31710384786129, 4.020464038476348, 4.739181222394109, 2.221785904839635, 1.3001262419857085, 1.430991932284087, 2.2803580993786454, 2.802388812415302, 2.567463805899024, 6.635253354907036, 30.031014047563076, 15.256525240838528, 22.674156613647938, 10.599023960530758, 13.571015484631062, 6.99052051641047, 9.494203794747591, 3.3549090893939137, 3.7449531722813845, 1.7534971330314875, 1.3922641729004681, 0.15595534321619198, 2.985840355977416, 13.18335933610797, 27.981552220880985, 48.113561645150185, 73.83661195635796, 68.27216014266014, 32.40142375230789, 48.887823298573494, 57.42088481783867, 76.15485236048698, 68.56386289000511, 42.99935907125473, 9.762746784836054, 0.1367969493730925, 0.3094491607043892, 0.3652996028540656, 0.12573851854540408, 0.09013657385366969, 0.17019018094288185, 0.22029061132343486, 0.15588249400025234, 0.17584858200279996, 0.16723557229852304, 0.10279196547344327, 0.16287817095872015, 0.2047302681603469, 0.14687299932120368, 0.08372122669243254, 0.09199046617140993, 0.1518643877352588, 0.12937413674080744, 0.10790088781504892, 0.07149661469156854, 0.19869019539328292, 0.0699237514345441, 0.1252616589772515, 0.17587513604667038, 0.1078148654778488, 0.1863588922424242, 0.1058920424839016, 0.1187306406791322, 0.1560970488935709, 0.1894138244097121, 0.18484942323993891, 0.1996467198478058, 0.13335774798179045, 0.19300565589219332, 0.10016852538683452, 0.12056669918820262, 0.07748585034278221, 0.1410101365763694, 0.13554884993936867, 0.16078725893748924, 0.2531615935731679, 0.11395600391551852, 0.15009917464340106, 0.12402104781358503, 0.11706932084052823, 0.1163055544020608, 0.1525528187630698, 0.24816863180603832], [0.02246988831757335, 0.003178917445438856, 0.04175523208687082, 0.01233100443641888, 0.00887471509486204, 0.07077751812175848, 0.10326173753128387, 0.030137913963699248, 0.02093992861773586, 0.06938455888302997, 0.06689322108286433, 0.03834378701867536, 0.03992232770542614, 0.026793970937433187, 0.04270388977602124, 0.06386462031514384, 0.040321068809134886, 0.0325769284972921, 0.045539368875324726, 0.06812899344367906, 0.012433587799023371, 0.1187415502499789, 0.012577920679177623, 0.010995185930369189, 0.11160109512275085, 0.06211884778167587, 0.09703813164378516, 0.05038550414610654, 0.08047347713727504, 0.05377536013838835, 0.056732989323791116, 0.026513021657592617, 0.011608246295509161, 0.03883718163706362, 0.05797306243039202, 0.036642665800172836, 0.08880162829882465, 0.041379727626917884, 0.04390373847854789, 0.06596963314223103, 0.0874884425138589, 0.03666529759357218, 0.024822618906910066, 0.010385286186647136, 0.04173608096607495, 0.044991240865783766, 0.05132200545631349, 0.07448820455465466, 0.04890227377472911, 0.07174786136602052, 0.10091401272802614, 0.0649024396261666, 0.042539281421341, 0.13513015990611166, 0.09186311363009736, 0.10783479956444353, 0.15022327657788992, 6.524861678481102, 39.823516085743904, 65.59523418545723, 52.971243783831596, 52.27966569364071, 44.73833575844765, 40.10248951613903, 26.844913512468338, 29.947295039892197, 29.604106955230236, 38.663894310593605, 45.33459596335888, 47.56411112844944, 36.95698790252209, 30.40947373956442, 28.10219954699278, 18.983496353030205, 11.204221285879612, 6.871614921838045, 3.8209410198032856, 1.0796933015808463, 0.22307262610411271, 0.08029661592445336, 0.24868323700502515, 0.7070616655983031, 0.506528316764161, 1.2754850392229855, 1.592655919957906, 1.2821928667835891, 1.7458201199769974, 0.7700103940442204, 1.263473646249622, 0.8276407734956592, 1.1099180672317743, 2.858861619606614, 0.5417593731544912, 3.8535796059295535, 1.889928337186575, 2.452210052870214, 2.4993484234437346, 1.7292731953784823, 1.0630022222176194, 1.4445446175523102, 0.9913517825771123, 1.9427922880277038, 1.3205966935493052, 0.7319001015275717, 1.3837273372337222, 0.7495604851283133, 1.3577893353067338, 0.2166115478030406, 0.21737067581852898, 1.279587869066745, 2.5345062743872404, 6.632111398503184, 12.944372110068798, 25.985606722533703, 37.6442114263773, 50.99171720445156, 34.61089499294758, 77.05198422074318, 84.42643851041794, 44.62162882089615, 28.233347609639168, 36.00867658853531, 51.416165828704834, 49.0985219925642, 29.205130264163017, 7.975296098738909, 0.2635088242823258, 0.27718886209186167, 0.020380892892717384, 0.10936277772998437, 0.007677362327740411, 0.01086933902115561, 0.09096322988625616, 0.04042550383019261, 0.03826763524557464, 0.03605780148063786, 0.04061094055941794, 0.07632763241417706, 0.10857783039682545, 0.08464854763587937, 0.028945880076207686, 0.04612836695741862, 0.0163526804317371, 0.06110531525337137, 0.034591662770253606, 0.03335561581479851, 0.011194534217793262, 0.03529038367560133, 0.024129701596393716, 0.03438339386775624, 0.009557424164086115, 0.02727406070334837, 0.042138940989389084, 0.03485501016257331, 0.01690568620688282, 0.020958306049578823, 0.03692475613206625, 0.048131820585695095, 0.03689285120344721, 0.028224994930496905, 0.04319158098951448, 0.02717358132940717, 0.0479253291268833, 0.048334000166505575, 0.03340120594657492, 0.03341707677464001, 0.06951948133064434, 0.030838610837236047, 0.01336001259915065, 0.0356144239049172, 0.024821674523991533, 0.03923326214135159, 0.03513347139232792, 0.04913252509140875, 0.03628182617831044, 0.02805443640681915, 0.030204597787815146, 0.05865276209078729, 0.03745792244444601, 0.006498788679891732, 0.06067355228879023, 0.07165536750108004, 0.07134711646358483, 0.028873511400888674, 0.09950624764314853, 0.03329998071421869, 0.03827428117801901, 0.040457972791045904, 0.031452136900043115, 0.011797095048677875, 0.05730374912673142, 0.024079747636278626, 0.029448100685840473, 0.017667291140242014, 0.015225338629534235, 0.03056941717659356, 0.017689798623905517, 0.05808683366922196, 0.012191952864668565, 0.008955864304880379, 0.03823214203293901, 0.05523852654732764, 0.10758523014374077, 0.03752218130102847, 0.0038837272086311714, 0.029110531104379334, 0.06745665959897451, 0.07203499088063836, 0.027690741371770855, 0.08768952742684633, 0.002963816145893361, 0.06774151814170182, 0.03733504505362362, 0.04870361568464432, 0.022154434736876283, 0.052030533843208104, 0.09446098672924563, 0.005877397243239102, 0.05695159634342417, 0.05160018838068936, 0.04265889336238615, 0.025233367960026953, 0.043047407671110705, 0.03406827796425205, 0.06914298981428146, 0.11227237511775456, 0.05398847526521422, 0.06470364794950001, 0.0728464922576677, 0.0394504405267071, 0.05655014640069567, 0.17080126533983275, 0.41531910945195705, 12.289859130978584, 60.62988102436066, 71.44827291369438, 59.31241571903229, 51.69846028089523, 35.68539373576641, 30.155159085989, 30.833836868405342, 43.922652527689934, 52.15184435248375, 64.63614284992218, 67.41890072822571, 52.85950317978859, 38.06202940642834, 25.70080630481243, 13.765566945075989, 5.804530056193471, 2.2056227596476674, 1.4813644043169916, 2.1605412662029266, 1.3835378224030137, 0.5673195328563452, 0.36058411526028067, 0.49095405091065913, 0.8196216006763279, 1.013355036266148, 0.501622601877898, 0.7444122363813221, 1.7604222614318132, 1.2451968644745648, 1.287299080286175, 1.1252568941563368, 1.2468389701098204, 1.5134450141340494, 1.5940478327684104, 1.542645141016692, 3.085091505199671, 1.341100512072444, 1.8799558910541236, 1.6032991488464177, 1.3527093641459942, 0.3990959987277165, 0.801858325721696, 0.25619584950618446, 0.895116365281865, 0.7821810222230852, 0.5019208265002817, 0.35067006130702794, 0.4155921010533348, 0.8940110995899886, 0.24865381827112287, 0.5472461006138474, 1.072406005114317, 1.6247484041377902, 2.040033582597971, 5.889465948566794, 18.02704207599163, 31.979570388793945, 57.76586830615997, 51.23670905828476, 90.01286074519157, 95.39812177419662, 63.533369824290276, 34.13878932595253, 22.440653443336487, 50.43301798403263, 59.858765602111816, 45.76035551726818, 12.913470268249512, 0.8079124696087092, 0.29447538137901574, 0.062023756399867125, 0.09869755900581367, 0.04363964522781316, 0.02254304738016799, 0.06941892774193548, 0.0781074732367415, 0.01634312156966189, 0.0036564829815688427, 0.07616593327838928, 0.042858839078689925, 0.011958509385294747, 0.04232743907778058, 0.05532579940336291, 0.028792784287361428, 0.03086222968704533, 0.020022209209855646, 0.038873940211487934, 0.041616558082751, 0.031060691107995808, 0.04159541058470495, 0.05049555722507648, 0.043347164828446694, 0.022045591358619276, 0.05380284186685458, 0.02237671538750874, 0.03196503887011204, 0.03853230366075877, 0.03904282333678566, 0.08725458435947075, 0.027827326230180915, 0.04767467988131102, 0.012723915970127564, 0.03386774224054534, 0.03954975472879596, 0.05253821480437182, 0.03862111647322308, 0.05936283043411095, 0.07342242854065262, 0.02263032951304922, 0.0034110313208657317, 0.01875870093499543, 0.06368607442709617, 0.040925896901171654, 0.0914304934849497, 0.01270454684345168, 0.09389383747475222, 0.06771157248294912, 0.030255974816100206, 0.11722789553459734, 0.1197975299146492, 0.14830923319095746, 0.11850504262838513, 0.0985565954761114, 0.18626496603246778, 0.1481863929075189, 0.12679658364504576, 0.25598686072044075, 0.1487874731537886, 0.18722631444688886, 0.061623664587386884, 0.14226242172298953, 0.13635020615765825, 0.13213272934081033, 0.1540564396418631, 0.17303541186265647, 0.09610020541003905, 0.12083206893294118, 0.1320386547013186, 0.14518569689244032, 0.17632354167290032, 0.08594528742833063, 0.13588161411462352, 0.2592963940696791, 0.3360057278769091, 0.15463495859876275, 0.14204461622284725, 0.13872911600628868, 0.09852719900663942, 0.16289242019411176, 0.13060150056844577, 0.11173026592587121, 0.13144514436135069, 0.23284669616259634, 0.20649383368436247, 0.17261361965211108, 0.0853751102113165, 0.10920036613242701, 0.18490297661628574, 0.19471609848551452, 0.08321042871102691, 0.1247275056084618, 0.07134721294278279, 0.1324138548807241, 0.14787746651563793, 0.1419636033824645, 0.13351171393878758, 0.13276897254399955, 0.21391908056102693, 0.1880749751580879, 0.1758280096692033, 0.16906012751860544, 0.2054898117785342, 0.20423571579158306, 0.18265756429173052, 0.38029113435186446, 9.658779613673687, 63.29803325235844, 92.77218908071518, 72.42641642689705, 68.21703270077705, 60.7366780936718, 52.71577209234238, 42.85191938281059, 44.32648345828056, 42.81254969537258, 57.21629619598389, 62.15614892542362, 62.28577516973019, 49.398895874619484, 41.01692944765091, 37.28443153202534, 23.475512713193893, 15.225119926035404, 9.045913349837065, 4.979167319834232, 1.515777138993144, 0.3786989307263866, 0.21223786374321207, 0.3390501067042351, 1.5495308465324342, 2.234675525687635, 3.4330005990341306, 3.111563972197473, 5.350124789401889, 6.546365674585104, 5.8658388163894415, 5.261269882321358, 7.194577166810632, 7.725672293454409, 13.267028946429491, 6.988254887983203, 14.656562134623528, 8.912402763962746, 10.401254072785378, 10.190270394086838, 7.062850585207343, 6.297788713127375, 5.323895271867514, 5.319329341873527, 6.7702392116189, 2.3454046715050936, 2.9211229411885142, 2.899901792407036, 1.6441044467501342, 2.096392158418894, 0.34208623284939677, 0.5770409549586475, 2.3156924033537507, 4.161261208355427, 9.308737646788359, 18.55217009782791, 33.885893896222115, 48.4022131562233, 61.61712124943733, 47.08900362253189, 88.5899966955185, 93.56598928570747, 60.4450361430645, 42.13174782693386, 49.31076720356941, 68.7669087946415, 70.5570687353611, 50.5990082770586, 12.900008540600538, 0.4974432714516297, 0.4553218191722408, 0.11710862498148344, 0.2262803664780222, 0.22248000634135678, 0.12671230535488576, 0.2034562232438475, 0.1634770247619599, 0.16697795799700543, 0.08491074841003865, 0.2145677770022303, 0.11496709848870523, 0.16927867516642436, 0.216425149992574, 0.14586605335352942, 0.13660078489920124, 0.1235435128910467, 0.23810003302060068, 0.2549379091942683, 0.08471696623018943, 0.12306192584219389, 0.1415989565430209, 0.15154593216720968, 0.12564674456370994, 0.08641344160423614, 0.08451940651866607, 0.0887514220084995, 0.10662900254828855, 0.1271433595684357, 0.0724969852308277, 0.17049257643520832, 0.08108679539873265, 0.19329770584590733, 0.08449261498753913, 0.10286336007993668, 0.09669269158621319, 0.12774451402947307, 0.16676637169439346, 0.1257572800386697, 0.1821192994248122, 0.15829511219635606, 0.07221643114462495, 0.1434649236034602, 0.18108517600921914, 0.19493565545417368, 0.18805686675477773, 0.12741103739244863, 0.17825984949013218, 0.1987539607216604, 0.15565982001135126], [0.06899181433254853, 0.03593016692320816, 0.010433740080770804, 0.01649230624025222, 0.13643889280501753, 0.09091033702134155, 0.028023435042996425, 0.021921055267739575, 0.03838086471660063, 0.06483359058620408, 0.029659438368980773, 0.03303095589217264, 0.06145347528217826, 0.05089277321530972, 0.059064642919111066, 0.028123803094786126, 0.03935910441214219, 0.03836164680251386, 0.022763125707569998, 0.04989319677406456, 0.012903011975140544, 0.056090415600920096, 0.0381512293824926, 0.019323851956869476, 0.019754412642214447, 0.07495686339098029, 0.03487186062557157, 0.06151386012788862, 0.01977059702767292, 0.059104154861415736, 0.016873894455784466, 0.0805482930445578, 0.05156043895112816, 0.015095753151399549, 0.051067571257590316, 0.049483226976008154, 0.025455054892518092, 0.02488214842742309, 0.021376589756982867, 0.037672017206205055, 0.06647476111538708, 0.020337134010333102, 0.06864201044663787, 0.04447077641088981, 0.1077404132229276, 0.04709498833108228, 0.03891686974384356, 0.01045745077135507, 0.02401534035016084, 0.012956116352142999, 0.03553958573320415, 0.04585842558299191, 0.017761206217983272, 0.09284147206926718, 0.051900995676987804, 0.05979159141134005, 0.10324576651328243, 0.1397819267003797, 0.24295620212797076, 15.080952811986208, 54.241314232349396, 58.70045855641365, 57.569377049803734, 54.951750710606575, 47.36483082175255, 41.69928163290024, 33.2401717454195, 32.07531005144119, 30.556240864098072, 33.76995071768761, 33.35282430052757, 28.402328342199326, 30.414421074092388, 36.69975310564041, 46.279415264725685, 47.42662690579891, 41.93714126944542, 43.51417064666748, 46.191579177975655, 39.88159216940403, 35.24867556989193, 26.800381802022457, 15.520806759595871, 12.031979318708181, 8.366186823695898, 3.3897783933207393, 1.3006856432184577, 0.6665663479361683, 0.28961835138034075, 0.010283171304763528, 0.15547585644526407, 0.07685584118007682, 0.39301659213379025, 0.0814812394673936, 0.10278886329615489, 0.03297949537227396, 0.04267823002010118, 0.20844367827521637, 0.288339868420735, 1.303096970077604, 1.42982515739277, 2.6797318691387773, 5.81487737596035, 9.085069298744202, 11.695207189768553, 17.281164899468422, 26.539335809648037, 33.45783166587353, 37.05657675862312, 39.71404395997524, 45.04422314465046, 46.58260479569435, 38.48056174814701, 33.666524067521095, 27.354209683835506, 30.339812077581882, 20.972013249993324, 35.23142069578171, 38.685503751039505, 27.744956016540527, 44.382507652044296, 53.10233294963837, 39.75181773304939, 10.206977147608995, 0.07675951783312485, 0.36461002891883254, 0.04170456937572453, 0.31583151197992265, 0.05345282275811769, 0.054977186664473265, 0.05766957598098088, 0.03096809705311898, 0.020754005781782325, 0.010299844580003992, 0.07141176494769752, 0.02306791091541527, 0.0565049904253101, 0.04887645074632019, 0.03219790625735186, 0.02510914913727902, 0.06766118065570481, 0.012322003112785751, 0.05226034358202014, 0.03173544806486461, 0.04630835261195898, 0.012407474405335961, 0.06822609604569152, 0.021270210309012327, 0.0034648797009140253, 0.059451019842526875, 0.026181619323324412, 0.03571695902792271, 0.011895976022060495, 0.016864747485669795, 0.04147435516642872, 0.030266370449680835, 0.042407565051689744, 0.06298406209680252, 0.06094360498536844, 0.0070779662928543985, 0.015816801569599193, 0.04165247060882393, 0.03927197998564225, 0.0767437694594264, 0.02747690821706783, 0.022229374953894876, 0.051135837711626664, 0.034000282394117676, 0.027439251643954776, 0.03324987461382989, 0.03512968272843864, 0.024548395340389106, 0.03589112253393978, 0.058450048163649626, 0.03847886160656344, 0.04277763327991124, 0.025722075915837195, 0.026089529928867705, 0.03878196584992111, 0.026135303742194083, 0.059513976229936816, 0.056488243862986565, 0.04961017504683696, 0.04848928343562875, 0.05052285712736193, 0.04841591842705384, 0.006111551792855607, 0.038922094463487156, 0.02865822178137023, 0.064908592030406, 0.027725991531042382, 0.03518850164255127, 0.022815673473814968, 0.070009558548918, 0.04280920424207579, 0.008166435327439103, 0.024551501228415873, 0.05378813249990344, 0.0308946374207153, 0.11808605573605746, 0.06623693247092888, 0.061087496287655085, 0.09131253653322347, 0.04109811226953752, 0.05831694768858142, 0.05745646085415501, 0.017051288159564137, 0.013596469198091654, 0.032917670760070905, 0.060655065390164964, 0.00964518498221878, 0.04610425457940437, 0.02964661591249751, 0.02426827541057719, 0.04924780660076067, 0.015455779193871422, 0.10518486480577849, 0.02283406945934985, 0.058672573723015375, 0.029463975224643946, 0.017684991362330038, 0.06707383756292984, 0.05086608187411912, 0.01660610159888165, 0.017867982714960817, 0.05110272308229469, 0.07896958166384138, 0.07761462038615718, 0.034036740398732945, 0.04369971466076095, 0.15573301061522216, 0.11636992829153314, 0.008436144780716859, 0.21262176189338788, 0.746794055448845, 28.105748556554317, 67.55063965916634, 66.50952592492104, 67.7049645781517, 60.826543271541595, 43.15765857696533, 30.85517842322588, 19.401620216667652, 27.554852217435837, 36.07226237654686, 47.02051989734173, 49.66098301112652, 54.408881440758705, 66.30323499441147, 69.76153582334518, 69.87904071807861, 66.16035506129265, 60.517536252737045, 51.80393882095814, 44.63834032416344, 39.36186745762825, 29.37874674797058, 15.399738606065512, 8.5102522931993, 2.7283892082050443, 1.5359579748474061, 1.5129334665834904, 0.9064613096415997, 0.46956407837569714, 0.45538953272625804, 0.11839835889986716, 0.3560150385601446, 0.2798767725471407, 0.9446832805406302, 0.1966820179950446, 0.1698430339456536, 0.025623429646657314, 0.1979000010760501, 0.4015038820216432, 0.3303539764601737, 0.32434068038128316, 0.5350369994994253, 0.7208927453029901, 1.4141830592416227, 1.7847715923562646, 4.754219865426421, 10.31458642333746, 17.79265735298395, 27.258483320474625, 39.98608656227589, 44.74629633128643, 55.980952084064484, 71.53647378087044, 65.5693119764328, 63.36187742650509, 56.00093141198158, 55.94547338783741, 25.371211990714073, 52.92113967239857, 53.38572174310684, 27.389135509729385, 44.27224896848202, 61.63533367216587, 55.851964205503464, 19.312157817184925, 0.7593111775349826, 0.4206669662380591, 0.0573309970786795, 0.03161015127261635, 0.04541343754681293, 0.056174382189055905, 0.09292583199567162, 0.021800972062919755, 0.04083005966094788, 0.03748281036678236, 0.0414046007063007, 0.02067860543320421, 0.005540905631278292, 0.04247608012519777, 0.06529322490678169, 0.03599792500608601, 0.07029141881503165, 0.017425553232897073, 0.07828500980394892, 0.037836477131349966, 0.05246238215477206, 0.04843615308345761, 0.04788028076291084, 0.042673298448789865, 0.03144891597912647, 0.09162513655610383, 0.11132588449981995, 0.020643422067223582, 0.05202716820349451, 0.02759633647656301, 0.026142660281038843, 0.039905462399474345, 0.02296934628247982, 0.048049746474134736, 0.02279970245581353, 0.04932019939587917, 0.013805797516397433, 0.01420712964318227, 0.048479524193680845, 0.007982880870258668, 0.034093763315468095, 0.04113524562853854, 0.03119568405963946, 0.06965562090044841, 0.022999982138571795, 0.0233859620129806, 0.11267639289144427, 0.03948475372453686, 0.016560090298298746, 0.024805979955999646, 0.037015212801634334, 0.044085516419727355, 0.16755024291342124, 0.1279121355037205, 0.0768693260033615, 0.12047723328578286, 0.1800382579676807, 0.16857946815434843, 0.10436256518005393, 0.12881377071607858, 0.09802639033296145, 0.16650798555929214, 0.12399963685311377, 0.1414593288791366, 0.2132813530624844, 0.1409954865812324, 0.33146627771202475, 0.08177403899026103, 0.10044450042187236, 0.1365960796829313, 0.14167910849209875, 0.08346510410774499, 0.07420660404022783, 0.17167643556604162, 0.18222826154669747, 0.164777297177352, 0.1571800501551479, 0.19114415656076744, 0.1540614862460643, 0.16929277597228065, 0.09455102408537641, 0.13286099885590374, 0.13379571901168674, 0.1357124638161622, 0.24585813313024119, 0.20734463178087026, 0.1566856016870588, 0.16906904813367873, 0.11670392443193123, 0.17682815756415948, 0.08279182031401433, 0.13689886109204963, 0.22958967718295753, 0.14112383360043168, 0.2194564521778375, 0.1819739572238177, 0.2650114061543718, 0.20837125950492918, 0.13438998634228483, 0.12705032393569127, 0.1219951850362122, 0.08850298807374202, 0.10737319855252281, 0.2086902197333984, 0.17886225075926632, 0.25686102162580937, 0.27031586214434355, 0.27048572490457445, 0.1944995843223296, 0.2537830680375919, 0.4540961474413052, 23.15294612199068, 77.25082755088806, 84.46372970938683, 83.12078297138214, 73.57506439089775, 64.92410659790039, 57.98255167901516, 48.05730566382408, 49.22119081020355, 45.36226227879524, 48.83434496819973, 47.85215847194195, 43.46666939556599, 47.21204102039337, 53.7090577930212, 61.66955083608627, 62.07064211368561, 56.47651769220829, 57.07561634480953, 57.650320306420326, 53.72331462800503, 46.06988690793514, 35.346360728144646, 21.22387133538723, 16.915288232266903, 11.388840079307556, 5.878314971923828, 2.273220419883728, 1.0078251454979181, 0.5707914778031409, 0.16531600733287632, 0.4460119624854997, 0.17902846215292811, 0.8622901642229408, 0.27292632206808776, 0.23000057466560975, 0.16641466791043058, 0.17273280856898054, 0.36707419669255614, 0.562460187356919, 1.533777010627091, 2.261751447804272, 4.461972797289491, 7.956068180501461, 11.620311308652163, 14.93791138753295, 23.102937005460262, 33.46172645688057, 42.93867252767086, 49.74616304039955, 50.79264588654041, 60.70453941822052, 60.89149698615074, 54.491306617856026, 48.453020229935646, 38.72515842318535, 44.02617037296295, 28.336301185190678, 51.11625552177429, 50.39265654981136, 38.713253661990166, 61.35701760649681, 76.97987169027328, 65.76893046498299, 22.72307138890028, 0.8022504765540361, 0.660916882334277, 0.08524426957592368, 0.31759473611600697, 0.07798021717462689, 0.17863908695289865, 0.25373185984790325, 0.17349974397802725, 0.08823645315715112, 0.1134448719676584, 0.16478160163387656, 0.05261528684059158, 0.13200554007198662, 0.1646268935292028, 0.11930947133805603, 0.06621433407417499, 0.14620594214648008, 0.06650789800914936, 0.11823988810647279, 0.12193360162200406, 0.08775007925578393, 0.17635579541092739, 0.1619364449288696, 0.2636693062959239, 0.06360044542816468, 0.19158721872372553, 0.18175912031438202, 0.1672837376827374, 0.07396732820780016, 0.14739714853931218, 0.1455879260902293, 0.05632072628941387, 0.17513276572572067, 0.11896527066710405, 0.16385578725021333, 0.14807217638008296, 0.07804048698744737, 0.16397145838709548, 0.12965352565515786, 0.2218170606647618, 0.1650344068184495, 0.19180221890565008, 0.14220353972632438, 0.16945028939517215, 0.1199773300322704, 0.13711913052247837, 0.14172170776873827, 0.1520085276570171, 0.11618708536843769, 0.09558079109410755, 0.16217176511418074, 0.1515168696641922], [0.030924180464353412, 0.07107465920853429, 0.05485577501531225, 0.0020237163471392705, 0.036231430640327744, 0.030673458859382663, 0.026465590999578126, 0.030627004125562962, 0.03282593017502222, 0.02979721251904266, 0.028546257672132924, 0.05386130455008242, 0.06840076050139032, 0.034030669630737975, 0.028977974252484273, 0.06637433369178325, 0.021182648015383165, 0.03567397012375295, 0.01949391695234226, 0.034516598243499175, 0.057019595624296926, 0.03546549713064451, 0.027180525976291392, 0.05359192720788997, 0.02778181773464894, 0.031654431513743475, 0.04688036293373443, 0.043256025383016095, 0.04016737744677812, 0.060963947253185324, 0.06950722105102614, 0.06303530739387497, 0.0192547060578363, 0.041586775696487166, 0.009850220903899753, 0.041806751978583634, 0.007296759777091211, 0.037399882785393856, 0.05118893095641397, 0.007897335362940794, 0.07752809338853694, 0.06704036670271307, 0.05231797505985014, 0.02270718447107356, 0.07270167698152363, 0.02658061832335079, 0.09277317221858539, 0.03888429688231554, 0.03450162912486121, 0.015047817832964938, 0.09910930995829403, 0.03896039670507889, 0.10364194720750675, 0.08379481805604883, 0.08023626447538845, 0.06720589532051235, 0.08250472048530355, 0.17523590940982103, 0.08041854336624965, 0.40566219482570887, 0.3994831920135766, 13.919157553464174, 31.716159023344517, 44.49812024831772, 60.465209260582924, 60.72092793881893, 56.65213666856289, 52.259614169597626, 49.37405280768871, 52.54934102296829, 59.93084013462067, 45.795192047953606, 32.56574213504791, 29.91387203335762, 34.887330159544945, 29.225081093609333, 20.283965170383453, 20.26284020394087, 28.299931436777115, 31.984065547585487, 25.86133249104023, 36.90370716154575, 63.78440335392952, 50.06240867078304, 36.23007170855999, 48.41500706970692, 46.20978780090809, 36.81535430252552, 35.262639820575714, 32.20123149454594, 30.772544257342815, 25.075394064188004, 28.419890999794006, 29.87671572715044, 33.52628879249096, 32.78348945081234, 36.55655778944492, 36.21428355574608, 33.852425292134285, 33.993811905384064, 44.6364214271307, 55.4093411564827, 48.491804748773575, 50.81500768661499, 57.22600467503071, 50.396216958761215, 34.7595202177763, 28.10535527765751, 24.54125102609396, 33.4074729681015, 35.107000172138214, 19.30410034954548, 24.33397974818945, 32.37086959183216, 35.3421201556921, 39.875113517045975, 43.39889623224735, 46.84561528265476, 56.75647906959057, 50.82587890326977, 37.62098327279091, 16.614796556532383, 0.9242593171074986, 0.190934841230046, 0.03069603870244464, 0.145752742246259, 0.033517886404297315, 0.0939169034245424, 0.03308070205093827, 0.05454192447359674, 0.08663696906296536, 0.02902441228798125, 0.04513237137871329, 0.031997830665204674, 0.05896462367672939, 0.057036086145672016, 0.01863310728367651, 0.026262684114044532, 0.02406617561064195, 0.0825104869727511, 0.013762035850959364, 0.06723073500324972, 0.0560370329185389, 0.0890465296106413, 0.03652396299003158, 0.02578216946858447, 0.017770967315300368, 0.038572268313146196, 0.022456295882875565, 0.02735762838710798, 0.0700130763289053, 0.05730169337766711, 0.008279265894088894, 0.01022032716718968, 0.029491482928278856, 0.033492478978587314, 0.014351442114275414, 0.029282199138833676, 0.04569480428472161, 0.045958348346175626, 0.02830364403052954, 0.020465414236241486, 0.049374057052773423, 0.06933684620889835, 0.13070721208350733, 0.013261649273772491, 0.06148435604700353, 0.018621720882947557, 0.018376185034867376, 0.0581410030281404, 0.028150101097708102, 0.07304750295588747, 0.019397350552026182, 0.04061090345203411, 0.031034571220516227, 0.030822717744740658, 0.023023211360850837, 0.1250392966903746, 0.0957230682251975, 0.04126727370021399, 0.07236360645038076, 0.02782338542601792, 0.04589367759763263, 0.134217897139024, 0.02675291532796109, 0.02841657849785406, 0.03737767030543182, 0.07824996559065767, 0.0717271925532259, 0.05946113160462119, 0.039634096101508476, 0.12896199245005846, 0.018834650472854264, 0.03691755729960278, 0.0077592444085894385, 0.02905638586526038, 0.014737058336322661, 0.051407159480731934, 0.015431933061336167, 0.07825927954399958, 0.026555259137239773, 0.04739893491205294, 0.021033602497482207, 0.03950883270590566, 0.04168678009591531, 0.08271429556771182, 0.01014285437122453, 0.02557540898123989, 0.012643686095543671, 0.019200156348233577, 0.040343882428715006, 0.021352878138714004, 0.019118297459499445, 0.04944971158693079, 0.04125484272663016, 0.041630747946328484, 0.04377477918751538, 0.034264360801898874, 0.03387991717318073, 0.051967751860502176, 0.025194768859364558, 0.05523235187865794, 0.02438366638671141, 0.04428469772392418, 0.019965492429037113, 0.02881395776057616, 0.04511783641646616, 0.04767922553583048, 0.04412808229972143, 0.03581209864933044, 0.05310602085955907, 0.12820326519431546, 0.13102909637382254, 0.07433380815200508, 0.05395800639234949, 0.3852858179016039, 2.6547816954553127, 25.508912801742554, 45.40057562291622, 61.17021583020687, 67.44435176253319, 60.959467738866806, 50.6896486133337, 44.40872624516487, 34.9143049120903, 39.81778599321842, 39.236553981900215, 26.48057196289301, 18.86330310255289, 24.93165347725153, 35.72305731475353, 41.56262196600437, 36.59655824303627, 41.248508021235466, 54.573199823498726, 57.77264714241028, 60.46899385750294, 69.9418893456459, 65.31984016299248, 61.274938210844994, 60.372213050723076, 59.19006608426571, 45.54395332932472, 35.658118799328804, 33.53663183748722, 28.435325771570206, 25.033026337623596, 26.080166548490524, 28.541976548731327, 26.734523735940456, 24.969765432178974, 30.436197705566883, 33.628442510962486, 37.481333166360855, 37.89796940982342, 29.420717395842075, 46.842393055558205, 61.73416256904602, 68.18145141005516, 73.76999393105507, 67.93224558234215, 66.31888255476952, 61.025435999035835, 57.87762030959129, 44.17395584285259, 54.30330030620098, 46.14073410630226, 27.759549133479595, 23.973713479936123, 20.79722262918949, 17.843124344944954, 20.440032295882702, 30.001877211034298, 38.01536411046982, 48.30404542386532, 60.02246841788292, 57.637397199869156, 27.920546494424343, 3.3606686303392053, 0.2091135852970183, 0.027220386728004087, 0.12537179369246587, 0.1061325948103331, 0.03703068658069242, 0.0833680089272093, 0.06577263004146516, 0.04406888117955532, 0.002462290372022835, 0.0643931185186375, 0.02373202732997015, 0.009782883989828406, 0.022016810871718917, 0.049820280764834024, 0.08615275481133722, 0.041974343766923994, 0.0207614699320402, 0.019247412601544056, 0.05157934516319074, 0.03545091021806002, 0.06651964620687068, 0.030823838387732394, 0.03950130732846446, 0.019517517248459626, 0.025939851730072405, 0.05940256502071861, 0.05769932868133765, 0.10325727722374722, 0.030391216387215536, 0.039396397332893685, 0.010388265909568872, 0.012078356958227232, 0.0545607453386765, 0.016114451027533505, 0.02493551070074318, 0.08670932846143842, 0.03575799237296451, 0.06789138744352385, 0.014135308301774785, 0.07574126895633526, 0.06630277581280097, 0.0376306202088017, 0.03643698699306697, 0.03958361150580458, 0.00379275428258552, 0.029728422850894276, 0.10277804278302938, 0.017587239381100517, 0.02064015847281553, 0.003303050921203976, 0.01279527254155255, 0.04641968960640952, 0.010514770547160879, 0.10806553327711299, 0.15288777969544753, 0.20115206250920892, 0.077978688350413, 0.20364092895761132, 0.10564632480964065, 0.15980570926330984, 0.13347531901672482, 0.122846777230734, 0.15347639186074957, 0.14222816418623552, 0.14301145653007552, 0.24681735900230706, 0.2206636592745781, 0.0864979499601759, 0.2504355664132163, 0.11269542155787349, 0.16891597275389358, 0.11300072626909241, 0.17465641081798822, 0.11035849500331096, 0.1829189041745849, 0.14849913393845782, 0.14942949026590213, 0.10721118771471083, 0.09107245918130502, 0.09812874734052457, 0.10293024985003285, 0.11815719801234081, 0.18453135358868167, 0.10127564644790255, 0.1382646948331967, 0.07812267984263599, 0.13203687354689464, 0.1753317948896438, 0.12584715412231162, 0.19401668367208913, 0.18586211343063042, 0.17888794391183183, 0.1484202139545232, 0.21436545270262286, 0.23478577961213887, 0.175688827293925, 0.1337258829153143, 0.1840092081693001, 0.13293346215505153, 0.13014644529903308, 0.14967542316298932, 0.14880580420140177, 0.11370356980478391, 0.25178354408126324, 0.17998785129748285, 0.18921856535598636, 0.1454308134270832, 0.3281712013995275, 0.27538170281331986, 0.20350910868728533, 0.19133880705339834, 0.17911682225530967, 0.7768655230756849, 1.1954233353026211, 20.879205130040646, 48.10562387108803, 73.11690777540207, 84.88921567797661, 79.76471945643425, 70.54195314645767, 67.83891499042511, 62.705375254154205, 67.793537825346, 75.35316377878189, 58.63870806992054, 45.225139036774635, 43.321224600076675, 47.30031028389931, 41.10628545284271, 28.272464610636234, 30.189330652356148, 38.21404404938221, 40.55924020707607, 37.76781499385834, 50.609241127967834, 81.24589517712593, 70.14870464801788, 53.53113614022732, 64.76322323083878, 66.23549982905388, 54.23698626458645, 52.8164628893137, 47.13572211563587, 43.38911175727844, 34.85687479376793, 40.64480781555176, 39.92781288921833, 47.0424485206604, 44.993419870734215, 49.81291025876999, 48.69237318634987, 48.372327759861946, 46.82421863079071, 59.48587641119957, 69.90317702293396, 63.18349599838257, 66.91428780555725, 72.73065090179443, 65.57272419333458, 47.21611440181732, 43.33715334534645, 32.966179847717285, 50.96932500600815, 46.130797639489174, 24.42858137190342, 37.16964729130268, 43.65863509476185, 50.5295480042696, 53.573511466383934, 57.76446618139744, 61.525394171476364, 75.16723215579987, 82.89287880063057, 72.30421498417854, 30.443001240491867, 2.6471274811774492, 0.53992994944565, 0.10393418269813992, 0.38391964277252555, 0.18534635048126802, 0.29696320882067084, 0.177820126991719, 0.09218361752573401, 0.14308111451100558, 0.0947858915606048, 0.1467577289440669, 0.13625794235849753, 0.19535548839485273, 0.15795177983818576, 0.1628153704223223, 0.21233898878563195, 0.1246990665094927, 0.1502579200314358, 0.09483023488428444, 0.26417622284498066, 0.1026185107184574, 0.11507298811920919, 0.12339902415988036, 0.11281803919700906, 0.12148032750701532, 0.1492914804839529, 0.2026553568430245, 0.07830909991753288, 0.19141544122248888, 0.17716788308462128, 0.09477982079260983, 0.13759226450929418, 0.17639915167819709, 0.13397546717897058, 0.13228448369773105, 0.10460226403665729, 0.15948544285492972, 0.12885270378319547, 0.3179823746904731, 0.07225792462122627, 0.14591589599149302, 0.15004621498519555, 0.3203239099821076, 0.12052104226313531, 0.09658493174356408, 0.11638599578873254, 0.10914670885540545, 0.21769871993456036, 0.13813152385409921, 0.14975268073612824, 0.10751327150501311, 0.13248331990325823, 0.08730314308195375, 0.16850669315317646], [0.04655555458157323, 0.018185286098741926, 0.013868809564883122, 0.030268895607150625, 0.09608928841771558, 0.01763449934514938, 0.020447970055101905, 0.0875031815667171, 0.13496651634341106, 0.06026189410476945, 0.05188669449125882, 0.021366446453612298, 0.029068449475744274, 0.037853231115150265, 0.05434955979580991, 0.004110182671865914, 0.050942267043865286, 0.015439425042131916, 0.013862994837836595, 0.058799989346880466, 0.05502783453266602, 0.03261493387981318, 0.009319562122982461, 0.01998623916733777, 0.046723309642402455, 0.044305103074293584, 0.04365853288618382, 0.06216270128788892, 0.022001602410455234, 0.017725212055665907, 0.014220403882063692, 0.030617371048720088, 0.011538040980667574, 0.02786976780043915, 0.09115766515606083, 0.04165145386650693, 0.04828492565138731, 0.015764498712087516, 0.036144065015832894, 0.027855570515384898, 0.0340700813831063, 0.040381498183705844, 0.08309519544127397, 0.06915306075825356, 0.01742589462082833, 0.02708124702621717, 0.04347837653767783, 0.00797863578554825, 0.02849119031452574, 0.053186625518719666, 0.05287778076308314, 0.06422522987122647, 0.027766707607952412, 0.049701140087563545, 0.02554338345362339, 0.0352941092569381, 0.061178268369985744, 0.10485664999578148, 0.11195785293239169, 0.2592434047255665, 0.09249876311514527, 0.5321419110987335, 0.07568671368062496, 1.7732325615361333, 20.9100803732872, 41.840314865112305, 56.81324042379856, 64.30632054805756, 64.7695840895176, 63.44306007027626, 65.60767471790314, 64.40810188651085, 72.74111554026604, 71.82789534330368, 69.08921509981155, 59.0851841121912, 64.87160861492157, 54.29770700633526, 45.74975028634071, 60.05318596959114, 36.71438232064247, 22.590863183140755, 74.09671559929848, 33.444855362176895, 16.365704722702503, 14.860471542924643, 16.81050505489111, 24.388797506690025, 21.018355563282967, 23.038146682083607, 23.381623551249504, 16.44786961376667, 24.450394101440907, 28.753980472683907, 41.909706741571426, 26.39883454889059, 32.56066180765629, 24.440096653997898, 31.271664574742317, 106.78111016750336, 43.197184056043625, 31.85642469674349, 29.885954931378365, 47.569765225052834, 48.11474338173866, 29.95830114930868, 33.493887931108475, 38.719777911901474, 45.778864324092865, 52.757695242762566, 53.308753073215485, 66.86427488923073, 68.66906404495239, 67.25283443927765, 70.87806031107903, 68.31227838993073, 63.69911313056946, 52.278951331973076, 28.7887904047966, 8.01202017813921, 1.3195380941033363, 0.15575365716358647, 0.10327422045520507, 0.03631061779742595, 0.030807110379100777, 0.022393107574316673, 0.02076066655718023, 0.06231948369531892, 0.032165585726033896, 0.027044200869568158, 0.021196771085669752, 0.01807690285204444, 0.0219914739500382, 0.03772819407458883, 0.01767150839441456, 0.028084313416911755, 0.04455290247278754, 0.06905168338562362, 0.01697176518064225, 0.044764822741854005, 0.06292253063293174, 0.07813937816536054, 0.0346266105043469, 0.022429645359807182, 0.0263380065371166, 0.05882144483621232, 0.057360619903192855, 0.07536343415267766, 0.056888862600317225, 0.009082711258088239, 0.04972367169102654, 0.04078679245139938, 0.011743157610908384, 0.039197156656882726, 0.05727215590013657, 0.021526357013499364, 0.041453471130807884, 0.026221159096166957, 0.06638223014306277, 0.037980932465870865, 0.023567778916913085, 0.032409006453235634, 0.0447915140830446, 0.10920624394202605, 0.05688491066393908, 0.07212562195491046, 0.03660387374111451, 0.035308469814481214, 0.05588978710875381, 0.023099155332602095, 0.06609589472645894, 0.02426588755042758, 0.05563341961533297, 0.021766371282865293, 0.08335145903402008, 0.03779198908887338, 0.06654240787611343, 0.030850030634610448, 0.027667959293466993, 0.017040890670614317, 0.09552288873237558, 0.0234106829520897, 0.06047517992556095, 0.014442078754655086, 0.07464355832780711, 0.03240483929403126, 0.13737460743868724, 0.028135174652561545, 0.041205734814866446, 0.06807756260968745, 0.07116301931091584, 0.027319372529746033, 0.08423689316259697, 0.030668664585391525, 0.03789045353187248, 0.04922593550872989, 0.05351613166567404, 0.06543864132254384, 0.05551834219659213, 0.0513917858916102, 0.04515585293120239, 0.038252577069215477, 0.030937078990973532, 0.035773904019151814, 0.0247484690771671, 0.03890581174346153, 0.05156287690624595, 0.017150030907941982, 0.008321343811985571, 0.006019378906785278, 0.03884177924192045, 0.050289870996493846, 0.020115096413064748, 0.03172011529386509, 0.05610103202343453, 0.02503914791304851, 0.04047329814056866, 0.022512346586154308, 0.07836133227101527, 0.033815213027992286, 0.04853496633586474, 0.03164263878716156, 0.005073388310847804, 0.01961388326890301, 0.11827057591290213, 0.04507698118686676, 0.07238200429128483, 0.024197702732635662, 0.04693950468208641, 0.05302571677020751, 0.03762300206290092, 0.0779500043427106, 0.086760633130325, 0.09805156398215331, 0.04054685981827788, 0.16287555859889835, 0.1472011918667704, 0.4474337986903265, 0.25109008129220456, 6.0098890867084265, 33.39399889111519, 56.89288794994354, 71.45992308855057, 70.77580779790878, 72.54218861460686, 68.11919555068016, 71.89534172415733, 61.82853050529957, 52.35734112560749, 46.5750166028738, 46.57764986157417, 33.62349897623062, 29.037390165030956, 23.672363050282, 23.829076141119003, 35.00656396150589, 17.397111877799034, 20.608758442103863, 85.90037181973457, 43.171425238251686, 23.5465632006526, 37.21204921603203, 42.28188157081604, 50.52948720753193, 49.72134277224541, 55.09245716035366, 56.58469408750534, 47.04887397587299, 50.795795917510986, 62.66410946846008, 69.97015982866287, 58.13206985592842, 64.40618678927422, 53.48604395985603, 45.80725260078907, 98.24754327535629, 54.08865362405777, 49.42719295620918, 38.47799688577652, 48.769349455833435, 53.24026554822922, 33.005154356360435, 21.60648040473461, 21.28141924738884, 20.062750540673733, 31.998109593987465, 34.8887474834919, 24.878484830260277, 41.742283925414085, 50.63058078289032, 60.03215029835701, 67.28641703724861, 69.80058252811432, 71.53151884675026, 55.54323457181454, 23.405229784548283, 4.66080472804606, 0.06286711446591653, 0.1971447470714338, 0.1438138072262518, 0.04167617480561603, 0.07527266949182376, 0.0209805092526949, 0.05606269267445896, 0.0435440491855843, 0.04090702408575453, 0.1346738132997416, 0.016196111391764134, 0.04702682206698228, 0.07369001730694436, 0.05241548584308475, 0.012169321071269223, 0.04513090192631353, 0.045724059746135026, 0.07974954176461324, 0.02354464988457039, 0.10785801394376904, 0.05241628736257553, 0.011937469498661812, 0.015857317266636528, 0.027816546535177622, 0.0931519569712691, 0.028428415753296576, 0.019840798631776124, 0.032484850235050544, 0.020412111334735528, 0.11441883689258248, 0.04337853170000017, 0.04062721214722842, 0.06094210584706161, 0.037634917243849486, 0.015278307564585702, 0.013937090861873003, 0.03147759627609048, 0.0369171973579796, 0.020375326785142533, 0.023895574413472787, 0.047900697245495394, 0.029630453791469336, 0.11806534981587902, 0.024774295816314407, 0.04224431482725777, 0.019389140543353278, 0.005944970253040083, 0.04895451354968827, 0.03282299869169947, 0.052354036015458405, 0.02886524573114002, 0.02337066449399572, 0.042210276224068366, 0.00932788159843767, 0.09784713198314421, 0.21302011708030477, 0.1869346504099667, 0.11782414439949207, 0.10913794409134425, 0.15975923597579822, 0.0785672634083312, 0.1534952424117364, 0.09261689818231389, 0.2104180137393996, 0.15610015107085928, 0.24029107560636476, 0.10545657991315238, 0.16235538729233667, 0.19268694799393415, 0.1964205742115155, 0.11289275120361708, 0.15555774501990527, 0.08149407120072283, 0.12089267271221615, 0.12870871229097247, 0.1433842076221481, 0.07308349711820483, 0.13382028409978375, 0.13516024657292292, 0.1329234876902774, 0.23095476877642795, 0.27072778379078954, 0.20766515051946044, 0.09287451990530826, 0.1300783161423169, 0.08453101370832883, 0.17870789888547733, 0.19171563995769247, 0.1479801649111323, 0.18820960074663162, 0.23569597920868546, 0.13768535951385275, 0.13229759002570063, 0.12000040340353735, 0.07920478310552426, 0.13902404549298808, 0.16987461975077167, 0.17849996394943446, 0.1321748091140762, 0.13089123502140865, 0.15704184741480276, 0.12451918475562707, 0.0799853666103445, 0.16103555186418816, 0.1406298897927627, 0.12932203797390684, 0.12110308642149903, 0.1944737130543217, 0.08395872879191302, 0.1353810355067253, 0.1421040325658396, 0.22060057672206312, 0.23558533983305097, 0.22955688909860328, 0.3395745379384607, 0.2922173822298646, 0.6529157585464418, 0.25714300805702806, 3.8280765619128942, 29.54209428280592, 59.27453555166721, 81.8190336227417, 86.29023849964142, 85.2674549818039, 81.61329746246338, 88.39398801326752, 84.1215580701828, 87.67841041088104, 88.092732578516, 87.0756259560585, 68.1459841132164, 82.86861330270767, 71.02120622992516, 63.67396228015423, 77.45793923735619, 52.28581376373768, 28.70263382792473, 90.1739265024662, 43.24873208999634, 23.5981435328722, 26.343741305172443, 29.444317929446697, 38.79991561174393, 35.596197322010994, 36.6229098290205, 38.29148009419441, 32.657609805464745, 38.03293436765671, 47.86816321313381, 56.10782727599144, 40.686936154961586, 44.69711177051067, 39.482765570282936, 41.295173317193985, 120.90935245156288, 55.074529722332954, 46.43224686384201, 41.16820693016052, 58.19610022008419, 64.94635820388794, 41.88582502305508, 45.77027678489685, 54.82644863426685, 56.72568932175636, 67.83354207873344, 71.38443633913994, 78.00438031554222, 87.23708689212799, 81.37199521064758, 89.92469027638435, 91.65812686085701, 89.95191961526871, 86.296226978302, 62.656418681144714, 28.12775507569313, 3.958215778693557, 0.24665791599545628, 0.24179978761821985, 0.32924764207564294, 0.12876915279775858, 0.2686659194296226, 0.06311157791060396, 0.25224085547961295, 0.12757166783558205, 0.07921955926576629, 0.3875405516009778, 0.12696663936367258, 0.07711845755693503, 0.21571448422037065, 0.11461178044555709, 0.06732155903591774, 0.15497765270993114, 0.1232260518008843, 0.1649861375335604, 0.1498446922050789, 0.2120116719743237, 0.21532464888878167, 0.2315652891411446, 0.08060887455940247, 0.1918522545020096, 0.1939596570446156, 0.13579892402049154, 0.09066838945727795, 0.08941513951867819, 0.16443867003545165, 0.2137963887071237, 0.1962005571112968, 0.10278020243276842, 0.1534297553007491, 0.1670642994577065, 0.12162057115347125, 0.12315964442677796, 0.1403446082258597, 0.12002051560557447, 0.12544623110443354, 0.12005781594780274, 0.12111751377233304, 0.12744217790896073, 0.1724384431145154, 0.11821644366136752, 0.2424697540118359, 0.08253117062849924, 0.08182616002159193, 0.08396215009270236, 0.08519133960362524, 0.1421101181767881, 0.14966641349019483, 0.13320718106115237, 0.18234813323942944, 0.23302855202928185, 0.1506628209608607], [0.03446612478001043, 0.014787651471124263, 0.047715215987409465, 0.0620836291636806, 0.043449484728625976, 0.020626805380743463, 0.010312350696040085, 0.06529430102091283, 0.03691461097332649, 0.030460460620815866, 0.026580757476040162, 0.054336768880602904, 0.026732402366178576, 0.04092956311069429, 0.028039951539540198, 0.0314650205837097, 0.016087828335002996, 0.028956528039998375, 0.02368304743868066, 0.03137728759611491, 0.015679415191698354, 0.026047080937132705, 0.08943632783484645, 0.04069967173563782, 0.04385598127555568, 0.02425714319542749, 0.04284589602320921, 0.05397679015004542, 0.0941955872986, 0.020098839668207802, 0.04635091478121467, 0.009286462336604018, 0.07986841897945851, 0.036164377597742714, 0.11339857679558918, 0.06108673558628652, 0.034147617261623964, 0.04904259534669109, 0.0986841409758199, 0.04056982186739333, 0.02843366459273966, 0.03716583538334817, 0.017933367780642584, 0.0243453363145818, 0.04706976644229144, 0.01664347615587758, 0.04078615049365908, 0.04798726506123785, 0.02868454575946089, 0.01807515694963513, 0.021782989824714605, 0.07643072414794005, 0.025657824480731506, 0.05080694012576714, 0.005428436861620867, 0.03234380877984222, 0.07221171850687824, 0.03416808940528426, 0.0729148366372101, 0.10243444325169548, 0.06851192680187523, 0.1521268259966746, 0.06954557524295524, 0.03547962391166948, 0.34389523265417665, 0.36764743155799806, 3.2106531551107764, 12.969086933881044, 20.003718808293343, 33.840900510549545, 40.77900901436806, 42.90016919374466, 53.21526288986206, 59.8471724241972, 69.07906964421272, 71.27236515283585, 72.84063220024109, 68.79139468073845, 73.8827794790268, 62.05487675964832, 62.183017283678055, 64.47156608104706, 40.32056741416454, 45.44056847691536, 58.489254489541054, 48.41503746807575, 31.885852217674255, 35.20110972225666, 31.774544790387154, 39.78036180138588, 40.29290109872818, 44.77720387279987, 42.6509215682745, 42.55894370377064, 36.88658528029919, 47.24669136106968, 50.392512157559395, 45.281812995672226, 51.15278676152229, 70.02731636166573, 48.54755915701389, 57.52980597317219, 72.95231580734253, 79.85517740249634, 53.736587315797806, 65.839082300663, 79.87121254205704, 71.01159274578094, 74.0490585565567, 73.57197135686874, 68.03057670593262, 68.52522656321526, 56.016480177640915, 50.976267233490944, 38.840303644537926, 22.54985388368368, 17.114346250891685, 5.181901166215539, 1.289223914500326, 0.06005900206218939, 0.0736711073841434, 0.0802779286459554, 0.05251114496786613, 0.07531278999522328, 0.08848781857523136, 0.19153237401042134, 0.013382020988501608, 0.05370059247070458, 0.005673862315234146, 0.07821740757208318, 0.11529152834555134, 0.024936937479651533, 0.04549223878711928, 0.009791171924007358, 0.054261511395452544, 0.01813951228541555, 0.024710341240279377, 0.02625557619467145, 0.05129744778969325, 0.05702767019101884, 0.04791493534867186, 0.10490484506590292, 0.03296171722467989, 0.06508289283374324, 0.015474745705432724, 0.033680958513286896, 0.014708707367390161, 0.03169746865751222, 0.033741814622771926, 0.022054933142499067, 0.0645613188680727, 0.012086423175787786, 0.0770103489048779, 0.015029033147584414, 0.027315784245729446, 0.0673455155629199, 0.034618754871189594, 0.03685165458591655, 0.029095387581037357, 0.05018596290028654, 0.024331996210094076, 0.03989839715359267, 0.06325652677332982, 0.03254291586927138, 0.022525655149365775, 0.030204380709619727, 0.05511285497050267, 0.09259537589969113, 0.021925931177975144, 0.046285910066217184, 0.06955882257898338, 0.05702829730580561, 0.0673925899900496, 0.00690829370796564, 0.09157706022961065, 0.03764908113225829, 0.03507949870254379, 0.007016004383331165, 0.018214352312497795, 0.021535813830269035, 0.003020529215973511, 0.003942801004086505, 0.015754557643958833, 0.016926948737818748, 0.027221735581406392, 0.020253583024896216, 0.06041138120053802, 0.15169293677899987, 0.0251061657036189, 0.026177717481914442, 0.027050659409724176, 0.029886247975809965, 0.09127623809035867, 0.04713252616056707, 0.04834996005229186, 0.0382782442466123, 0.027314071739965584, 0.02589708732557483, 0.01910827475512633, 0.07037651346763596, 0.046765931183472276, 0.04623672793968581, 0.025591378143872134, 0.02459502447891282, 0.05338257848052308, 0.08084933782811277, 0.03385789394087624, 0.033958428975893185, 0.04108944398467429, 0.03795642674958799, 0.06923038512468338, 0.07606457074871287, 0.01629408601729665, 0.04933719457767438, 0.01724705558444839, 0.04555191488179844, 0.08295983512653038, 0.06478396317106672, 0.04852579710131977, 0.02200016264396254, 0.021223399344307836, 0.053928268534946255, 0.026845366519410163, 0.02067894682113547, 0.05349451290385332, 0.07198607592727058, 0.11663293800665997, 0.03596798676881008, 0.04990075554815121, 0.046992219431558624, 0.07842722756322473, 0.0775282789254561, 0.04419975521159358, 0.07331205633818172, 0.04105846302991267, 0.11468874115962535, 0.08862016577040777, 0.25449725158978254, 0.10289693484082818, 0.15767932258313522, 0.23526097676949576, 1.2008930230513215, 8.628083020448685, 23.348787613213062, 34.40302334725857, 50.702780708670616, 56.17289878427982, 60.16075059771538, 68.63869607448578, 76.35341450572014, 81.81613817811012, 73.35063323378563, 68.1506198644638, 65.97528979182243, 63.80910202860832, 55.12971796095371, 44.60824973881245, 35.27985289692879, 50.23274213075638, 41.27994753420353, 34.30458202958107, 20.108562782406807, 14.135856125503778, 26.5672168135643, 15.904000047594309, 19.15286846458912, 17.367425970733166, 14.535822663456202, 17.818117886781693, 18.762781396508217, 29.89882294088602, 17.44486391544342, 26.914757564663887, 16.03665567934513, 29.937888644635677, 88.64062517881393, 40.73501497507095, 35.21970592439175, 45.53952656686306, 58.69863085448742, 50.433029383420944, 52.71026998758316, 61.84494562447071, 62.99836993217468, 73.76829922199249, 75.88581159710884, 75.83122372627258, 83.44162255525589, 74.04447600245476, 67.55085244774818, 57.332737147808075, 40.46267218887806, 28.46718706190586, 11.709078345447779, 2.0428252452984452, 0.011974247554462636, 0.28940369258634746, 0.08110315233352594, 0.08882021909812465, 0.06880606961203739, 0.07351891516009346, 0.06698507670080289, 0.04768017177411821, 0.004118944189031026, 0.03485922556137666, 0.03465858222625684, 0.034528498581494205, 0.020122733112657443, 0.017294712597504258, 0.02089022884320002, 0.03628539961937349, 0.04222459967422765, 0.031974215526133776, 0.04446368147910107, 0.03283837599155959, 0.09449318109545857, 0.04073562507983297, 0.026663980061130133, 0.03666596552648116, 0.023839777895773295, 0.027971093222731724, 0.012803205172531307, 0.033347596909152344, 0.02632629359140992, 0.012167081640654942, 0.026004921382991597, 0.046462006866931915, 0.08854468193021603, 0.06515799817861989, 0.020281202050682623, 0.06884993796120398, 0.07156828389270231, 0.041656522735138424, 0.041289898072136566, 0.05424161812698003, 0.03473095646768343, 0.050780126330209896, 0.04961659091350157, 0.06444146201829426, 0.02889128398237517, 0.08994241317850538, 0.05012463552702684, 0.017625350519665517, 0.08236637673689984, 0.02349280344787985, 0.046878967696102336, 0.024535287157050334, 0.07448011514497921, 0.06905449612531811, 0.02875654521631077, 0.04109443863853812, 0.032150527549674734, 0.1920188666554168, 0.06808728474425152, 0.1598342225770466, 0.13808488729409873, 0.1264267714577727, 0.06377087964210659, 0.12529391271527857, 0.150346354348585, 0.15885405329754576, 0.08671374424011447, 0.14504829567158595, 0.21621320745907724, 0.09606107938452624, 0.08241777046350762, 0.1034281864122022, 0.1448496969533153, 0.16743338434025645, 0.11305587526294403, 0.138354747032281, 0.09893614464090206, 0.07933126733405516, 0.21167853672523052, 0.21671400871127844, 0.15738748043077067, 0.17471897386712953, 0.12915907718706876, 0.22822063736384735, 0.31508725660387427, 0.29838792455848306, 0.14601326576666906, 0.10796353250043467, 0.15088490123162046, 0.22624591598287225, 0.1428887201473117, 0.23619456886081025, 0.14132531185168773, 0.1327597995987162, 0.17046817461960018, 0.13367336854571477, 0.1744425535434857, 0.14001055271364748, 0.1570797266322188, 0.1305066837812774, 0.1253956908476539, 0.1563894550781697, 0.14162580744596198, 0.17522902227938175, 0.13637214404297993, 0.09451848090975545, 0.14535526279360056, 0.26296180207282305, 0.14458007470238954, 0.13905865926062688, 0.12772269488777965, 0.20203463936923072, 0.12172947390354238, 0.30407295387703925, 0.16605279670329764, 0.16394441452575848, 0.22899852687260136, 0.13620150944916531, 0.35094403254333884, 0.23505379882408306, 0.24957212212029845, 0.4076491022715345, 0.5552788695786148, 5.117538794875145, 17.306298650801182, 31.49475820362568, 48.80125254392624, 60.16482397913933, 64.6691706776619, 75.92953965067863, 83.60758244991302, 95.51402315497398, 88.56253176927567, 91.1250002682209, 86.20193883776665, 92.00373351573944, 77.46657237410545, 78.99002462625504, 77.35232010483742, 57.17469222843647, 57.18590162694454, 70.66767320036888, 58.54951165616512, 41.37926660478115, 52.26251721382141, 39.70170222222805, 55.010791942477226, 50.331080853939056, 62.8925684094429, 53.71706776320934, 52.42393635213375, 54.60251905024052, 58.16356636583805, 70.9313714504242, 57.210505306720734, 60.28968147933483, 86.3333585858345, 59.60449084639549, 72.21776962280273, 93.38616013526917, 94.81647178530693, 69.8300689458847, 85.11203572154045, 96.06228813529015, 89.94126498699188, 97.80563458800316, 94.71361130475998, 91.19614005088806, 94.12033393979073, 78.65379586815834, 71.00524708628654, 56.574586629867554, 39.286882281303406, 23.967449516057968, 10.024610683321953, 1.648645440582186, 0.23308835428906605, 0.25122500373981893, 0.2573557966388762, 0.1958141356590204, 0.43962578172795475, 0.2042149059707299, 0.36378811520989984, 0.0894706670078449, 0.12546083657070994, 0.17262843291973695, 0.15707610495155677, 0.19586259790230542, 0.15464851021533832, 0.20542377547826618, 0.09976919798646122, 0.14584509510314092, 0.13703237345907837, 0.1370111628784798, 0.0846859667217359, 0.14771811256650835, 0.1725308850291185, 0.17823250876972452, 0.26374185865279287, 0.19429439533269033, 0.1575149517157115, 0.06897458166349679, 0.09035740731633268, 0.08806477213511243, 0.2573491173097864, 0.11526921938639134, 0.22531435737619177, 0.22355573455570266, 0.14344326773425564, 0.19743666343856603, 0.19282900990219787, 0.16387719078920782, 0.17713705427013338, 0.14191113354172558, 0.13032038987148553, 0.13450666680000722, 0.16961308690952137, 0.1680502129602246, 0.20203343708999455, 0.09531778880045749, 0.15025058761239052, 0.2846380358096212, 0.12001934301224537, 0.22275325027294457, 0.28654648340307176, 0.10114404882187955, 0.13599317375337705, 0.2195966587169096, 0.13186718890210614, 0.20012559805763885, 0.18407959345495328, 0.11898641445441172, 0.1733570735086687], [0.04502991789195221, 0.004737613799079554, 0.07977778790518641, 0.03312226974230725, 0.05293005764542613, 0.05039591276727151, 0.1317630655830726, 0.07004219820373692, 0.013296836350491503, 0.046301198308356106, 0.03746411566680763, 0.030708831473020837, 0.06827484772657044, 0.045933812943985686, 0.05856501797097735, 0.09446095704333857, 0.06814837834099308, 0.08232140258769505, 0.00380753832814662, 0.0495812832377851, 0.07546763910795562, 0.04740094984299503, 0.0269576775826863, 0.10616536063025706, 0.019285766793473158, 0.045833274198230356, 0.09389059428940527, 0.05499860875715967, 0.07056800241116434, 0.006508131391456118, 0.02522275895898929, 0.01693660222372273, 0.04350895673269406, 0.04112959417398088, 0.05509686168807093, 0.07646928614121862, 0.029205906357674394, 0.055979397729970515, 0.04770575360453222, 0.014991993484727573, 0.016145576701092068, 0.025337133192806505, 0.024356062203878537, 0.07407056837109849, 0.020571704626490828, 0.05349828672478907, 0.07408901074086316, 0.012058388547302457, 0.017759211696102284, 0.03870083797664847, 0.023492326617997605, 0.014798201100347796, 0.04704698993009515, 0.013610983751277672, 0.03679735164041631, 0.02783943808026379, 0.037781955252285115, 0.03508611123834271, 0.03841824669507332, 0.02998925807332853, 0.0848395393404644, 0.2293923549586907, 0.17478067602496594, 0.056936063192551956, 0.05789476213976741, 0.029722198087256402, 0.13740837515797466, 0.3448693756945431, 0.5040122580248863, 0.09642989709391259, 0.047611140907974914, 1.0218791663646698, 5.107143027707934, 8.372270297259092, 11.488130651414394, 29.836753271520138, 46.166667714715004, 49.198099449276924, 50.45181177556515, 65.9335832297802, 70.57482898235321, 79.04396653175354, 75.17920911312103, 73.79774004220963, 64.39772084355354, 72.31819823384285, 85.4594586789608, 85.4871515929699, 81.24825105071068, 85.23045256733894, 92.77725040912628, 85.4741258919239, 85.64516991376877, 86.59696564078331, 84.7991681098938, 88.24134260416031, 85.65424382686615, 88.57520028948784, 80.95255091786385, 66.84164330363274, 83.45770329236984, 77.27115646004677, 66.0406006872654, 60.10224133729935, 64.80016484856606, 52.8179220110178, 37.02893704175949, 31.102252565324306, 22.39000976085663, 21.588767655193806, 14.421685338020325, 8.814557064324617, 4.274287568405271, 1.849215303082019, 0.4172425187425688, 0.12993892596568912, 0.2846573613351211, 0.1183967558608856, 0.0395240059151547, 0.04974032548489049, 0.01592083954164991, 0.046930769603932276, 0.05403530849434901, 0.030777431893511675, 0.06188139392179437, 0.05152841527888086, 0.05202225147513673, 0.08243670265073888, 0.04737836257845629, 0.044339635205687955, 0.05619549257971812, 0.027006291966245044, 0.027137874749314506, 0.007479731648345478, 0.07587219122797251, 0.037030270977993496, 0.07213088378193788, 0.07815281103830785, 0.03221713159291539, 0.014783294136577751, 0.03822060905804392, 0.044058754574507475, 0.030015123775228858, 0.08282810391392559, 0.028739915542246308, 0.048462551276315935, 0.06113274132076185, 0.048017641165643, 0.08485268277581781, 0.039009682732285, 0.02304576522874413, 0.03308631268737372, 0.007500242290916503, 0.028999080932408106, 0.01852261819294654, 0.023168219595390838, 0.02667622178705642, 0.0667741138022393, 0.010315156941942405, 0.033007949314196594, 0.021315434933057986, 0.05071074665465858, 0.053860091138631105, 0.06825590811786242, 0.02421139164653141, 0.023344795081357006, 0.07002903992542997, 0.014881939478073036, 0.024398245877819136, 0.026823439766303636, 0.08312984631629661, 0.033209590837941505, 0.05356256784580182, 0.01930062830069801, 0.01699428936262848, 0.028385083605826367, 0.032424398596049286, 0.032312898329109885, 0.042106420078198425, 0.045758484266116284, 0.057872289908118546, 0.009879516255750787, 0.09623348771128803, 0.03183886634360533, 0.014385359190782765, 0.04708425316493958, 0.07058763221721165, 0.08275553671410307, 0.08678978469106369, 0.02023078424826963, 0.013490985893440666, 0.09176889798254706, 0.02198469443101203, 0.008270827675005421, 0.00942229669817607, 0.08625528993434273, 0.05378634021326434, 0.028633278197958134, 0.016021873670979403, 0.051804256727336906, 0.01859015548689058, 0.042928612092509866, 0.026637563314579893, 0.004583221107168356, 0.01935471416800283, 0.043163026857655495, 0.07681515664444305, 0.02495880857168231, 0.012083169785910286, 0.05957074310572352, 0.05615167989162728, 0.03953909377742093, 0.02496584042091854, 0.045984672324266285, 0.025079398292291444, 0.03620675423007924, 0.017886924179038033, 0.030683728327858262, 0.10277114080963656, 0.06998402866884135, 0.047018524855957367, 0.03648136000265367, 0.04383719009638298, 0.03283020494563971, 0.036700709169963375, 0.07256203447468579, 0.06002863337926101, 0.019149809049849864, 0.02038686903688358, 0.02327788490219973, 0.018020343777607195, 0.039425708455382846, 0.02682904483663151, 0.049284721026197076, 0.054103170477901585, 0.05009958804294001, 0.017812021069403272, 0.26608757965732366, 0.038056156554375775, 0.1910251160734333, 0.020119226464885287, 0.08194277368602343, 0.28308917360845953, 0.19069416273850948, 0.32431206316687167, 0.5950112000573426, 1.7175254132598639, 4.627318549901247, 12.472274042665958, 19.50905755162239, 28.281373232603073, 47.115359008312225, 63.558630868792534, 69.12573873996735, 68.47823828458786, 74.71522361040115, 77.9397913813591, 84.59480747580528, 66.72533914446831, 69.64290618896484, 63.4537298977375, 69.99631762504578, 71.15739852190018, 70.8904704451561, 62.53293290734291, 64.87588718533516, 69.84928071498871, 72.57688075304031, 74.4823645055294, 72.20617264509201, 69.49972227215767, 76.0120940208435, 76.95267274975777, 83.1008492410183, 80.46224042773247, 72.9228749871254, 86.3995510339737, 89.41959097981453, 82.365011125803, 76.6788898408413, 76.64808869361877, 71.65373548865318, 57.743609100580215, 51.468785405159, 40.73442600667477, 39.02508772909641, 29.34394631534815, 20.294171422719955, 12.210889868438244, 5.940648252144456, 1.9652247405610979, 0.09752866157214157, 0.2842479036189616, 0.14560650946805254, 0.03969219884311315, 0.09482442386797629, 0.029958932063891552, 0.051630145171657205, 0.08186024686438031, 0.02273217814945383, 0.05751779935962986, 0.07314931077416986, 0.05641068200930022, 0.050277109767193906, 0.09140920868958347, 0.038678131968481466, 0.03129223005089443, 0.054816630436107516, 0.03756666192202829, 0.007697849314354244, 0.06255305241211317, 0.00939738929446321, 0.07964702148456126, 0.06712761358357966, 0.03394199040485546, 0.04499766044318676, 0.022588381470995955, 0.009001510097732535, 0.03259274366428144, 0.060315625596558675, 0.04437256800883915, 0.014352043253893498, 0.04582014189509209, 0.013558602040575352, 0.0704131755628623, 0.036796624335693195, 0.026295644747733604, 0.01834973674704088, 0.016888264290173538, 0.07421171001624316, 0.02166508296795655, 0.053959505530656315, 0.0722356972983107, 0.07007212159805931, 0.033575209890841506, 0.046628392665297724, 0.03343619820952881, 0.03986448842624668, 0.03248460532631725, 0.05339911353075877, 0.035040728907915764, 0.0655554182594642, 0.012708804915746441, 0.03524172476318199, 0.024169226526282728, 0.03325827943626791, 0.06326811169856228, 0.03299098381830845, 0.0392898063728353, 0.028727655262628105, 0.027490329957799986, 0.0377814060630044, 0.20983449270715937, 0.08478627540171146, 0.2250585687579587, 0.15643862978322431, 0.1520744600566104, 0.16693935147486627, 0.2911577437771484, 0.1862508206977509, 0.1923865414573811, 0.18878495815442875, 0.1387007808079943, 0.1829933119006455, 0.23183094832347706, 0.13396816444583237, 0.14764983498025686, 0.262447107816115, 0.17559651896590367, 0.27772012108471245, 0.09832855575950816, 0.17675324517767876, 0.18313636828679591, 0.21468300285050645, 0.06806866425904445, 0.22004898288287222, 0.12234720794367604, 0.12633008445845917, 0.2023200099938549, 0.1680126751307398, 0.15369738859590143, 0.18261794844875112, 0.18821203499101102, 0.05724288559576962, 0.13833411532687023, 0.09562211387674324, 0.26195951679255813, 0.1831761177163571, 0.12601612630533054, 0.16442492546048015, 0.15223899419652298, 0.09889342662063427, 0.07267789856996387, 0.14743247476872057, 0.1919407185050659, 0.18883239623392, 0.21292964927852154, 0.12241797914612107, 0.134572139068041, 0.08140562204062007, 0.13227704737801105, 0.1347378606442362, 0.1719221903476864, 0.0740862351085525, 0.16046875884057954, 0.18675840517971665, 0.07332253546337597, 0.16462258907267824, 0.11543367189005949, 0.1517578004859388, 0.1940278010442853, 0.18850332795409486, 0.2000790208694525, 0.46592241909820586, 0.2906366076786071, 0.25637895218096673, 0.22563213016837835, 0.10496731163584627, 0.26623039855621755, 0.4900321253808215, 0.7720031496137381, 0.37998697254806757, 0.5795510171446949, 2.014349573291838, 7.701687030494213, 13.089322932064533, 22.16438926756382, 42.06888400018215, 63.546102941036224, 74.5516499876976, 77.28881791234016, 92.49798819422722, 95.26487812399864, 105.12414827942848, 95.40131360292435, 93.5432893037796, 85.6680978834629, 91.09032332897186, 103.69149595499039, 105.79596742987633, 102.13191524147987, 106.56824558973312, 110.58195501565933, 106.05466514825821, 109.52579408884048, 105.54470211267471, 106.4843612909317, 107.16126456856728, 107.02779293060303, 110.46574965119362, 100.22846817970276, 89.81109917163849, 106.65364980697632, 101.19870811700821, 90.76031103730202, 81.40319913625717, 83.44967052340508, 74.81106206774712, 57.342453226447105, 50.613641291856766, 37.609960064291954, 33.48606415092945, 23.557348921895027, 15.209683254361153, 8.281299378722906, 2.7682267455384135, 0.8866629470139742, 0.13389593863394111, 0.444135456928052, 0.31917135464027524, 0.19113725458737463, 0.20363635732792318, 0.08655203026137315, 0.18601063202368096, 0.09516751873889007, 0.23672119685215876, 0.156995982688386, 0.2002998098032549, 0.13758647575741634, 0.20017150731291622, 0.17599631391931325, 0.20309588086092845, 0.14268747938331217, 0.1479044510051608, 0.17623739317059517, 0.07373372980509885, 0.20488414505962282, 0.1612345958710648, 0.16634637548122555, 0.1415945333428681, 0.08857329172315076, 0.11500111853820272, 0.15945191262289882, 0.20623426011297852, 0.15833986370125785, 0.09791343545657583, 0.09357081027701497, 0.10152198010473512, 0.20934642670908943, 0.11498773761559278, 0.17773574480088428, 0.08590345256379806, 0.18947098462376744, 0.16906495147850364, 0.09186871684505604, 0.10548607286182232, 0.09331592707894742, 0.1492920148302801, 0.26493490557186306, 0.26231533207464963, 0.15589525894029066, 0.16081740497611463, 0.09481630477239378, 0.1386798670864664, 0.1803250832017511, 0.08321422108565457, 0.12859969079727307, 0.10681844316422939, 0.13311640155734494, 0.09613955407985486, 0.07992160128196701, 0.12510604545241222, 0.15599660662701353, 0.12332869082456455, 0.1215368123666849, 0.09765534618054517, 0.1342666710843332, 0.1664001663448289], [0.06848523174994625, 0.020308390630816575, 0.04800990798685234, 0.022060131886973977, 0.02830335830367403, 0.04756132053444162, 0.07138626475352794, 0.06539534442708828, 0.10586277960101143, 0.016896685810934287, 0.023953339477884583, 0.024455086968373507, 0.01415434717273456, 0.05207540780247655, 0.048813045359565876, 0.07375801287707873, 0.06531691426062025, 0.02732184944761684, 0.054492657000082545, 0.057342578293173574, 0.01586994305398548, 0.03945493794162758, 0.025919002946466208, 0.08126557135256007, 0.027358023580745794, 0.03009772852237802, 0.030265971545304637, 0.10185555322095752, 0.027704051790351514, 0.026178788029938005, 0.015653848204237875, 0.028926435807079542, 0.08014665756491013, 0.02387527852988569, 0.01845918126491597, 0.059610648386296816, 0.0406881907110801, 0.05539682664675638, 0.030168230696290266, 0.037523647042689845, 0.035810380577459, 0.05913433800742496, 0.0163823811817565, 0.04304725553083699, 0.010261610059387749, 0.03142934183415491, 0.08496785667375661, 0.08664934808621183, 0.043390279897721484, 0.04984560655429959, 0.042036784361698665, 0.07296251220395789, 0.06315235150395893, 0.03803060440986883, 0.06635959463892505, 0.08813603315502405, 0.042852148617384955, 0.06344077235553414, 0.013196284617151832, 0.14297709509264678, 0.01347607892967062, 0.1396153590758331, 0.08060310807195492, 0.09894455317407846, 0.11334232942317612, 0.07017605938017368, 0.0377646743436344, 0.06162843659694772, 0.21415861614514142, 0.019433183297223877, 0.06228579761227593, 0.1393816716154106, 0.5137400922831148, 0.5999807990156114, 0.43937600450590253, 0.17506447329651564, 0.1902024750597775, 0.5719762423541397, 3.356040003709495, 6.761452183127403, 13.00204636529088, 24.891660623252392, 34.91079770028591, 42.617878541350365, 53.6099287122488, 44.95792597532272, 44.460327476263046, 42.67255760729313, 47.77104802429676, 46.056279838085175, 42.134099900722504, 45.56558936834335, 47.0333556085825, 42.585850059986115, 37.740836441516876, 35.17671503126621, 34.04971830546856, 32.81695045530796, 30.52684184163809, 28.66134714335203, 28.46988681703806, 18.231075927615166, 7.140626711770892, 4.340355098247528, 2.2248454531654716, 1.2651624181307852, 0.7440407469402999, 0.05799139347800519, 0.055308926675934345, 0.0984314396919217, 0.26960378629155457, 0.28231760719791055, 0.3614203672623262, 0.07157926025683992, 0.0349588997050887, 0.10737953649368137, 0.10029821569332853, 0.1565895974636078, 0.056093844323186204, 0.03149956013658084, 0.05680318907252513, 0.034265358990523964, 0.030673610999656375, 0.03958594556024764, 0.056875986338127404, 0.04347824666183442, 0.0271505357886781, 0.043153950391570106, 0.07923892189865, 0.050698304548859596, 0.11508169351145625, 0.01615163633687189, 0.01714578211249318, 0.040871445526136085, 0.021463710472744424, 0.06094911172112916, 0.01170485908005503, 0.01621724590222584, 0.015279725994332694, 0.05942642135778442, 0.11180293702636845, 0.017789246412576176, 0.045264521904755384, 0.03687852404254954, 0.017338480756734498, 0.05280754019622691, 0.04491220213822089, 0.03805427149927709, 0.006651913690802758, 0.019293793120596092, 0.029129146023478825, 0.02807341683364939, 0.019076362405030522, 0.04100603771803435, 0.07158873006119393, 0.052660301807918586, 0.031083419380593114, 0.011466821706562769, 0.054951582569628954, 0.07030312990536913, 0.1059195538982749, 0.07426779411616735, 0.04675605319789611, 0.03735555801540613, 0.04498871756368317, 0.07022196863545105, 0.03313684923341498, 0.04920765641145408, 0.016865203906490933, 0.04048631170007866, 0.013470307803800097, 0.03128497184661683, 0.025527095167490188, 0.01676056479482213, 0.04646236680855509, 0.004778713009727653, 0.043722539412556216, 0.05558222626859788, 0.03178171726176515, 0.02831913636327954, 0.044474153182818554, 0.02492537667421857, 0.045191743192845024, 0.07243694548378699, 0.03243560131522827, 0.0403373329754686, 0.028413630316208582, 0.06016059465764556, 0.0220893409641576, 0.02020455303863855, 0.04980335237632971, 0.004371479417386581, 0.01969748434930807, 0.012429630296537653, 0.027193680543859955, 0.04612731310771778, 0.02248158270958811, 0.023410610592691228, 0.04379763362521771, 0.05567531014094129, 0.09094446839299053, 0.01826737690862501, 0.03255218158301432, 0.055767956146155484, 0.021608629649563227, 0.04667409411922563, 0.024888480802474078, 0.018569777967059053, 0.023013808349787723, 0.022167839779285714, 0.03522801729559433, 0.07405611875583418, 0.0051938987144239945, 0.05605300764727872, 0.021577967818302568, 0.03575994793209247, 0.06285965588176623, 0.016036165579862427, 0.029923967631475534, 0.09530907598673366, 0.02342367239180021, 0.009328188662038883, 0.04362815307104029, 0.025449880267842673, 0.024307399580720812, 0.022922357202332933, 0.029005355791014154, 0.033798974836827256, 0.04019272550067399, 0.02318751357961446, 0.08243916658102535, 0.03925919649191201, 0.06259361820411868, 0.0534296269324841, 0.1064572918403428, 0.09816301229875535, 0.04168069448496681, 0.053385580467875116, 0.09011529647978023, 0.12322326874709688, 0.06644316046731547, 0.015827048773644492, 0.0694652897072956, 0.07850756504922174, 0.0689185643568635, 0.04406556377944071, 0.17645362531766295, 0.19035099365282804, 0.2703939954517409, 0.4184722574427724, 0.428358762874268, 0.6830755120608956, 1.744719841517508, 3.9832440856844187, 9.382372945547104, 18.52827697992325, 28.022533021867275, 39.63900178670883, 57.185054272413254, 63.068601563572884, 68.31386670470238, 63.469920828938484, 66.30705758929253, 63.96427810192108, 67.04151257872581, 64.44225445389748, 62.79970899224281, 64.76165011525154, 65.35196363925934, 62.2501976788044, 59.32634957134724, 53.85299026966095, 52.20872350037098, 50.08428409695625, 47.31499269604683, 45.71110635995865, 44.020941853523254, 30.224007591605186, 16.05017725378275, 10.286379586905241, 7.224769396707416, 4.922330919653177, 2.727855099365115, 0.537654880899936, 0.19350881717400625, 0.24120609916280955, 0.24446549301501364, 0.0720779834955465, 0.11127334044431336, 0.2411377473617904, 0.0934158795280382, 0.14886986638884991, 0.05064890348876361, 0.10084493362228386, 0.0690884271170944, 0.06804963559261523, 0.07767168412101455, 0.06453569993027486, 0.04355490680609364, 0.07256129232700914, 0.03427913696214091, 0.12802473414922133, 0.04841872003453318, 0.024289905304613058, 0.03326567864860408, 0.07044977086479776, 0.03907540361979045, 0.06963000938412733, 0.03929723156034015, 0.03394486251636408, 0.06423389073461294, 0.0069035221622471, 0.0033111739594460232, 0.11988350030151196, 0.07589741682750173, 0.049547066519153304, 0.033445003791712224, 0.04986393389117438, 0.03579744494345505, 0.050829724059440196, 0.06677559809759259, 0.04424904123879969, 0.024711133482924197, 0.02798112891468918, 0.03752810735022649, 0.031560650022584014, 0.02194667606090661, 0.00649711142614251, 0.020536033298412804, 0.0570894502743613, 0.030539588406099938, 0.04910464631393552, 0.02953793951746775, 0.03350698054418899, 0.037355012536863796, 0.027306616866553668, 0.06734756389050744, 0.050829635001719, 0.08758007548749447, 0.10166496969759464, 0.06886351926368661, 0.042676556477090344, 0.03959613895858638, 0.041522086394252256, 0.0164591786233359, 0.03812284965533763, 0.05113244980748277, 0.06479738120106049, 0.04553668972221203, 0.008315774921356933, 0.0662012054817751, 0.029472196365532, 0.2423941736924462, 0.1161978836171329, 0.11906876316061243, 0.13875213742721826, 0.15281408443115652, 0.11554270080523565, 0.1704254120704718, 0.1652002619812265, 0.26031847984995693, 0.13043807965004817, 0.06105382133682724, 0.15102348988875747, 0.08537085028365254, 0.12938884610775858, 0.14826795493718237, 0.1169588892662432, 0.1337767200311646, 0.1049872011935804, 0.12668628565734252, 0.12357564046396874, 0.14581039227778092, 0.13606465741759166, 0.12606736418092623, 0.21586392307654023, 0.13877787510864437, 0.1828960163402371, 0.2068811160279438, 0.17465258133597672, 0.07315168564673513, 0.14787319174502045, 0.17545083537697792, 0.09594661794835702, 0.19716974260518327, 0.04662949846533593, 0.11142277930048294, 0.16059974790550768, 0.07246937733725645, 0.1747238275129348, 0.14315426058601588, 0.10453407550812699, 0.08159281394910067, 0.17492422222858295, 0.0843583011010196, 0.17219679983099923, 0.07127263452275656, 0.09089502651477233, 0.16020272858440876, 0.12044328745105304, 0.12067542382283136, 0.0754658282676246, 0.15192116203252226, 0.19686687213834375, 0.09376427333336323, 0.12815349677111953, 0.18965925264637917, 0.23568052769405767, 0.1768386218464002, 0.16836433438584208, 0.1656912371981889, 0.21369578316807747, 0.19422058132477105, 0.1858106380677782, 0.2881405275547877, 0.3318265755660832, 0.22863842197693884, 0.1264639975852333, 0.11992827407084405, 0.1967736435472034, 0.2676992572378367, 0.10428702196804807, 0.11757367698010057, 0.24378059461014345, 0.7349313888698816, 0.9917685727123171, 0.7292913633864373, 0.3718274744460359, 0.6286350614391267, 1.5969210723415017, 5.219435077160597, 11.833497919142246, 20.169623605906963, 34.24009948968887, 49.702191799879074, 58.1126718968153, 70.12508511543274, 64.32214289903641, 60.97413495182991, 60.01501701772213, 62.400973588228226, 61.31115406751633, 59.31046262383461, 61.322549656033516, 62.688044384121895, 57.35144354403019, 55.48225924372673, 49.0733977407217, 49.17765274643898, 46.92495882511139, 43.734102845191956, 42.185989916324615, 37.70832158625126, 24.885126873850822, 12.333617582917213, 7.245763745158911, 4.107768153771758, 2.5254439981654286, 1.4323407411575317, 0.22400694550015032, 0.16164475120604038, 0.1783467995119281, 0.32055492571089417, 0.3709721640916541, 0.49396482529118657, 0.303298122016713, 0.14576831250451505, 0.19216446118662134, 0.24728848919039592, 0.30869620735757053, 0.19470407569315284, 0.19711299799382687, 0.18274415808264166, 0.16530766559299082, 0.18759464233880863, 0.09779765299754217, 0.16683830064721406, 0.2775931544601917, 0.21757248061476275, 0.15474740881472826, 0.12460991973057389, 0.16273548564640805, 0.2383251115679741, 0.10159884433960542, 0.09627397928852588, 0.1527993899071589, 0.14865108125377446, 0.1420568468165584, 0.12056859166477807, 0.2100291135138832, 0.09505164722213522, 0.21882041677599773, 0.1281123817898333, 0.07425858406350017, 0.1194766401022207, 0.14422069711145014, 0.12018064880976453, 0.0940716041077394, 0.10431264090584591, 0.20747125701745972, 0.11645483740721829, 0.07342416516621597, 0.06846686359494925, 0.09050714303157292, 0.14801820740103722, 0.10057862134999596, 0.14131011266727, 0.2216920829960145, 0.10533859327551909, 0.11195291022886522, 0.10999611171428114, 0.1973099639872089, 0.2512271114392206, 0.2039811442955397, 0.1894520450150594, 0.1950519796810113, 0.2827674674335867, 0.20144969341345131, 0.18023252254351974, 0.16819705429952592, 0.14434134063776582, 0.11699945505824871, 0.08207069768104702, 0.24019630334805697, 0.1478687982307747, 0.08828120466205291, 0.2155035361647606, 0.10926019807811826], [0.02049417802481912, 0.010337472394894576, 0.08382606989471242, 0.044687179251923226, 0.011675260375341168, 0.009477946641709423, 0.02226830431027338, 0.04172597291471902, 0.004162251752859447, 0.039825833664508536, 0.01940328216733178, 0.016174193915503565, 0.026454128528712317, 0.030083551646384876, 0.03657940884295385, 0.04527123463049065, 0.02444238696625689, 0.08189584026695229, 0.03459879480942618, 0.03220840393623803, 0.03275404204032384, 0.01939842481078813, 0.09391144121764228, 0.014631776339228963, 0.08461152930976823, 0.04309507210564334, 0.03999714732344728, 0.03799821337452158, 0.008753586389502743, 0.017191997503687162, 0.043080218019895256, 0.015820501175767276, 0.019297540966363158, 0.042382090832688846, 0.030996456371212844, 0.047165173236862756, 0.01034735130815534, 0.06187741972098593, 0.09472733610891737, 0.062341429002117366, 0.0409800885245204, 0.03911824409442488, 0.1027683429128956, 0.0064815328187251, 0.02204117557994323, 0.008086921625363175, 0.04433851456269622, 0.03563196827599313, 0.07517359277699143, 0.03281054174294695, 0.04378543271741364, 0.025047062918019947, 0.021342653199099004, 0.02665589992830064, 0.05173553385247942, 0.084098208026262, 0.05805005283036735, 0.02398118671408156, 0.04188668870483525, 0.07265524822287261, 0.037509416360990144, 0.09697148678242229, 0.08177081806934439, 0.05581354627793189, 0.05389863457821775, 0.03699156797665637, 0.07279361423570663, 0.06355514473398216, 0.17905685672303662, 0.0623823436035309, 0.06931199168320745, 0.12046835719957016, 0.08793238041107543, 0.1872407566406764, 0.21548685268498957, 0.15643901570001617, 0.037388702330645174, 0.05160111977602355, 0.23707129759714007, 0.18244786304421723, 0.21614807657897472, 0.269278577179648, 0.05543231985939201, 0.02656370292243082, 0.14524340629577637, 0.15006441244622692, 0.18849826650694013, 0.10555794986430556, 0.2870154316769913, 0.27048937627114356, 0.49705530633218586, 0.40398663317319006, 0.391005075071007, 0.3262498998083174, 0.30594978597946465, 0.3524507110705599, 0.051613435716717504, 0.11200399225344881, 0.02039898645307403, 0.4029614897444844, 0.2387092323624529, 0.16986569913569838, 0.3180257754866034, 0.37454429897479713, 0.049266438218182884, 0.12530287785921246, 0.008451255835097982, 0.020810685455217026, 0.00860109823406674, 0.10058414292871021, 0.03531493763148319, 0.14560483221430331, 0.0707593206607271, 0.024536008895665873, 0.028251799449208193, 0.015210048532026121, 0.13170318910852075, 0.05286759107548278, 0.049503183327033184, 0.03395064384676516, 0.01828758373449091, 0.08998763223644346, 0.01569048617966473, 0.017437154856452253, 0.05010283122828696, 0.029475818046194036, 0.05416357016656548, 0.0647525183740072, 0.074848791846307, 0.002642653130351391, 0.014624600698880386, 0.042305189490434714, 0.008806503374216845, 0.09983328243833967, 0.08999088284326717, 0.0531779869197635, 0.015267495400621556, 0.04242119088303298, 0.05340026385965757, 0.05587432817264926, 0.02710090651817154, 0.03577381125069223, 0.029600773450511042, 0.11321016776491888, 0.021887808907194994, 0.06501969895907678, 0.06932497926754877, 0.024684865165909287, 0.039898645773064345, 0.08178257368854247, 0.0431623181066243, 0.029172446629672777, 0.020041993011545856, 0.046098168968455866, 0.03723640249518212, 0.057018872030312195, 0.06550716381752864, 0.06729022556100972, 0.04493601023568772, 0.0680741858377587, 0.020583716286637355, 0.02616209527332103, 0.018878292466979474, 0.08802336771623231, 0.009140124730038224, 0.12279539834707975, 0.06929325987584889, 0.06054591773136053, 0.04458487790543586, 0.08613895086455159, 0.011073012174165342, 0.05585385973972734, 0.016464312429889105, 0.04110040550585836, 0.038246458061621524, 0.06260458714677952, 0.013661100983881624, 0.06797064139391296, 0.053365728017524816, 0.037266095823724754, 0.10223205215879716, 0.06149043794721365, 0.018167736161558423, 0.01325070074017276, 0.03581782802939415, 0.060064167410018854, 0.0254299999869545, 0.019020998188352678, 0.10372523101978004, 0.015891901348368265, 0.03921827446902171, 0.06396187134669162, 0.030054285052756313, 0.019296147584100254, 0.03310947882710025, 0.05228072295722086, 0.040808971534715965, 0.05126685275172349, 0.01411694200214697, 0.015099722713785013, 0.0967788252455648, 0.0846213850309141, 0.083809430943802, 0.03687754811835475, 0.0681746429472696, 0.027095473997178487, 0.03765128531085793, 0.04603618108376395, 0.03822690618108027, 0.058901021620840766, 0.042190182575723156, 0.0076698040174960624, 0.02028701492235996, 0.08604993767221458, 0.050778267250279896, 0.026810333438334055, 0.07054354122374207, 0.03295006179541815, 0.15486686490476131, 0.010698189562390326, 0.04450117477972526, 0.08442870122962631, 0.0205181735145743, 0.017063483501260635, 0.01969076976820361, 0.03542068996466696, 0.02806775981298415, 0.09430632315343246, 0.015210523506539175, 0.02852785612049047, 0.00790147933003027, 0.13110760075505823, 0.061602884452440776, 0.08773428635322489, 0.01746459205605788, 0.05881124401639681, 0.01929611047671642, 0.1385523661156185, 0.03541411082551349, 0.09033480891957879, 0.05846684296557214, 0.04037457765662111, 0.06925274603418075, 0.09829292524955235, 0.09309882661909796, 0.1721019236720167, 0.08368253111257218, 0.06792511805542745, 0.03835962816083338, 0.07963500611367635, 0.08549772785045207, 0.20369339879835024, 0.06233841588255018, 0.14504957216558978, 0.30755205312743783, 0.20248809159966186, 0.09774697173270397, 0.3763226926093921, 0.06300749169895425, 0.45458920067176223, 1.8380862940102816, 1.2834908533841372, 1.033592156600207, 1.054837410338223, 1.887291872408241, 1.8165453686378896, 1.7242040298879147, 1.5301055763848126, 1.334409664850682, 1.2444067443720996, 0.959545411169529, 0.7689193182159215, 0.27784928446635604, 0.3504105767933652, 0.15349196211900562, 0.3225772484438494, 0.3125159227056429, 0.14317876630229875, 0.19959729281254113, 0.23577659128932282, 0.3304802009370178, 0.174775970808696, 0.08688878719112836, 0.0905860927014146, 0.07013045440544374, 0.13257067068479955, 0.12443315499695018, 0.06356523794238456, 0.03609472703828942, 0.09598334683687426, 0.07849573521525599, 0.03205948829418048, 0.021338519436540082, 0.08072214113781229, 0.0605730580718955, 0.0159600156621309, 0.0522599984833505, 0.005006879355278215, 0.03146208167891018, 0.05682088929461315, 0.04344101311289705, 0.07296620067791082, 0.05063933349447325, 0.03350518083607312, 0.028270861512282863, 0.051321207647561096, 0.09324094047769904, 0.024868880682333838, 0.06585859300685115, 0.015931743546389043, 0.048248894381686114, 0.027570042184379417, 0.032411544598289765, 0.05455528684251476, 0.0167018553474918, 0.0431708824908128, 0.03627179976319894, 0.04925828572595492, 0.03936376509955153, 0.09458568238187581, 0.05037187831476331, 0.03807336324825883, 0.00794536252215039, 0.027181700424989685, 0.02151069769752212, 0.022032104679965414, 0.021765137462352868, 0.131167892832309, 0.0483660423924448, 0.0748051016125828, 0.05382592265959829, 0.03520130368997343, 0.04483604665438179, 0.03804437867074739, 0.049432137529947795, 0.04201558120257687, 0.021923535896348767, 0.013372815574257402, 0.020186242400086485, 0.01760422528604977, 0.010976173034578096, 0.0750654841249343, 0.04220878079649992, 0.07092114596161991, 0.011778656389651587, 0.05457838618895039, 0.06781349162338302, 0.009912585428537568, 0.019388893779250793, 0.053066950495122, 0.02615127661556471, 0.052546942461049184, 0.10323499052901752, 0.09123156822170131, 0.1585140754468739, 0.11973881861194968, 0.16774121235357597, 0.16786929219961166, 0.1077704256749712, 0.09255995319108479, 0.11373843590263277, 0.14636151114245877, 0.08132517323247157, 0.07967704877955839, 0.16572844848269597, 0.06368312810081989, 0.1280058835982345, 0.16921535512665287, 0.10182295067352243, 0.15330560883739963, 0.1544017015839927, 0.11709833881468512, 0.07156553794629872, 0.08701884114998393, 0.2041861551697366, 0.06986407533986494, 0.21258763794321567, 0.1861622676369734, 0.11875187352416106, 0.13159205991541967, 0.14850437350105494, 0.16312110557919368, 0.10444277650094591, 0.09344430378405377, 0.18200548365712166, 0.10020696863648482, 0.1166939277027268, 0.10591645914246328, 0.08148868320859037, 0.1676016440615058, 0.20751182280946523, 0.10017321576015092, 0.17904461128637195, 0.10838913935003802, 0.2798072184668854, 0.09855138559942134, 0.09955707733752206, 0.15325775515520945, 0.22300797019852325, 0.06802249525208026, 0.2848347940016538, 0.17131293163402006, 0.09473834215896204, 0.16388370684580877, 0.13344922510441393, 0.10257352172629908, 0.11144672840600833, 0.1423517317743972, 0.1603660752880387, 0.25764339370653033, 0.12523201759904623, 0.2386598350130953, 0.1574794325279072, 0.26898385549429804, 0.14451616094447672, 0.14733896416146308, 0.24706299504032359, 0.247664847120177, 0.20556288363877684, 0.36066955130081624, 0.4862228891579434, 0.29706538771279156, 0.21254058578051627, 0.2678843785542995, 0.09288556306273676, 0.339313272270374, 0.40807061246596277, 0.231163683347404, 0.13266415160614997, 0.13664911355590448, 0.35721820837352425, 0.3816480771638453, 0.3767988842446357, 0.34385488950647414, 0.20348911522887647, 0.19837396626826376, 0.5662305350415409, 0.49982452648691833, 0.4059258056804538, 0.3505942731862888, 0.8714715403039008, 0.7687435182742774, 0.7673294597771019, 0.5948766635265201, 0.45088537910487503, 0.49112207314465195, 0.46146585198584944, 0.4539945622673258, 0.12650273769395426, 0.2644593670265749, 0.14334395353216678, 0.4025143606122583, 0.2887556789210066, 0.24842738901497796, 0.5404832353815436, 0.6056120968423784, 0.4396779992384836, 0.16626822733087465, 0.15223794034682214, 0.08321102985064499, 0.15669585816795006, 0.23570020945044234, 0.1914229814428836, 0.23410094057908282, 0.2565281535498798, 0.2025831607170403, 0.13900653080781922, 0.10031023106421344, 0.2104061096906662, 0.11101486525149085, 0.2612180222058669, 0.07198860665084794, 0.24092154490062967, 0.1722363563021645, 0.07764567184494808, 0.1924758218228817, 0.16014368331525475, 0.06633560842601582, 0.1459142632666044, 0.1100968434184324, 0.21244251838652417, 0.10474474896909669, 0.1859279567725025, 0.17909256886923686, 0.16248671774519607, 0.23598329426022246, 0.10400129511253908, 0.12575695349369198, 0.1554550466244109, 0.21440011099912226, 0.10687785950722173, 0.1779730390990153, 0.12789423490175977, 0.11619437325862236, 0.08376635669264942, 0.19033439923077822, 0.09654158289777115, 0.21664348983904347, 0.0960563073749654, 0.11605755833443254, 0.079706615942996, 0.1500479961396195, 0.11870391594129615, 0.14765082945814356, 0.18389539240160957, 0.17071352864149958, 0.17833817575592548, 0.19676135358167812, 0.21175281086470932, 0.11568798363441601, 0.16173315583728254, 0.1271462836302817, 0.0849870931415353, 0.12505274440627545, 0.08298982531414367, 0.08688423040439375, 0.1430329045979306, 0.2234514182782732, 0.1485417629010044, 0.1395118740038015, 0.09361291231471114, 0.24169374955818057, 0.14355640072608367, 0.12136491612181999, 0.14878288668114692, 0.06648909198702313, 0.13003853702684864, 0.2223915423383005], [0.031212519679684192, 0.04532744118478149, 0.05190351155761164, 0.03553898088284768, 0.073231963760918, 0.014963912472012453, 0.06031023760442622, 0.025205852834915277, 0.018099710905516986, 0.02569364423834486, 0.060680406022584066, 0.08434669391135685, 0.05754040146712214, 0.00799350378656527, 0.046502435361617245, 0.04023335437523201, 0.08919541927753016, 0.02931818216893589, 0.02233298433566233, 0.0061558696052088635, 0.05254155446891673, 0.021175590190978255, 0.09745505536557175, 0.015479510293516796, 0.0806037537404336, 0.00974291933744098, 0.081028024724219, 0.03796508761297446, 0.04383435138151981, 0.045280129270395264, 0.08449825530988164, 0.027260228926024865, 0.021308113646227866, 0.036395935094333254, 0.03761352112633176, 0.05256985627056565, 0.03265407845901791, 0.0668880705779884, 0.032710396335460246, 0.05933126689342316, 0.13700397888896987, 0.03760562096431386, 0.021019162159063853, 0.05354225155315362, 0.018703089954215102, 0.020742172237078194, 0.058878400959656574, 0.023663627289352007, 0.042111882285098545, 0.02250366345833754, 0.03480623992800247, 0.08549102625693195, 0.06365691544488072, 0.03902114520315081, 0.049753331622923724, 0.042669201793614775, 0.0348552773357369, 0.03477106954960618, 0.051646279462147504, 0.17590315954294056, 0.03525697589793708, 0.09166251853457652, 0.05585288752627093, 0.021490459330379963, 0.11528171715326607, 0.04787220990692731, 0.05836953627294861, 0.13246706686913967, 0.09979507667594589, 0.16462773957755417, 0.09703467323561199, 0.051064287254121155, 0.13652082590851933, 0.14943171670893207, 0.1203193562105298, 0.10105419700266793, 0.04593163474055473, 0.09077608250663616, 0.02750377210759325, 0.025495186528132763, 0.07654106666450389, 0.09463151742238551, 0.0491616618091939, 0.1544133384595625, 0.21593536221189424, 0.069056024949532, 0.02608746861369582, 0.06739811899024062, 0.03648048055765685, 0.031029476376716048, 0.047828597598709166, 0.04673312825616449, 0.03267505526309833, 0.03782998333917931, 0.10973708733217791, 0.03793996220338158, 0.02424912243441213, 0.03678039356600493, 0.01844763715780573, 0.17504574148915708, 0.10414973949082196, 0.13989701896207407, 0.17307758069364354, 0.06635702680796385, 0.02178845945309149, 0.052225277104298584, 0.005642229198201676, 0.10173191141802818, 0.040018324507400393, 0.06925621928530745, 0.10626211442286149, 0.04006703165941872, 0.15683627250837162, 0.11274899719865061, 0.05011888388253283, 0.011729462203220464, 0.07564504208858125, 0.11909448599908501, 0.04158205563726369, 0.07629261788679287, 0.051930488625657745, 0.1132144796429202, 0.012812591485271696, 0.03584355828934349, 0.06594409584067762, 0.05633408123685513, 0.051436207140795887, 0.05799087026389316, 0.04668614659749437, 0.08444090213743038, 0.019611018578871153, 0.0033875692497531418, 0.05921847157878801, 0.04806650416867342, 0.02261863697640365, 0.010861821992875775, 0.020935264219588134, 0.04362552957900334, 0.015806352130312007, 0.05372910949517973, 0.03852228466712404, 0.02395764950051671, 0.009823031396081205, 0.024756686507316772, 0.028563620217028074, 0.021855840896023437, 0.032036426055128686, 0.017051954237103928, 0.018319930240977556, 0.0320024505344918, 0.05350538907805458, 0.041087614590651356, 0.023640051113034133, 0.08301531808683649, 0.04197124901111238, 0.040786087411106564, 0.020371578939375468, 0.0725477332889568, 0.052107193987467326, 0.052507523287204094, 0.027284588068141602, 0.028615425835596398, 0.010755427701951703, 0.061841740971431136, 0.03893699307809584, 0.059676321034203283, 0.054653409897582605, 0.030428038044192363, 0.02630583072459558, 0.04518610287050251, 0.04880776868958492, 0.04810818689293228, 0.025619217958592344, 0.025425394960620906, 0.017509228528069798, 0.04551713413093239, 0.04934078657242935, 0.004965521784470184, 0.006846154146842309, 0.043560981284826994, 0.007676529730815673, 0.042536335095064715, 0.02923777974501718, 0.031123137268878054, 0.002160736753467063, 0.03387694858247414, 0.0026276812286596396, 0.09253705793526024, 0.00901247069123201, 0.018711641350819264, 0.04465709258511197, 0.07935247049317695, 0.025159008473565336, 0.043129630212206393, 0.03407772921491414, 0.02222618928499287, 0.017680236051091924, 0.015428496917593293, 0.05598623291007243, 0.022009157473803498, 0.034204068724648096, 0.052960667526349425, 0.08368359980522655, 0.02418132353341207, 0.057173116292688064, 0.025431311732972972, 0.06888711213832721, 0.06144818747998215, 0.017220154586539138, 0.06360630839481018, 0.028774273268936668, 0.03486619803879876, 0.06638905048021115, 0.051054245996056125, 0.015399986386910314, 0.01577717273903545, 0.018280635376868304, 0.05355866414902266, 0.06340583204291761, 0.023784888653608505, 0.023561522611998953, 0.023506060060753953, 0.04694826202467084, 0.031474275165237486, 0.01802613252948504, 0.03190432376868557, 0.02779704660497373, 0.01974823055206798, 0.049627121989033185, 0.009861719554464798, 0.018281885895703454, 0.06293041224125773, 0.01001130684016971, 0.03982360351074021, 0.03212778072338551, 0.0976688606897369, 0.008028030351852067, 0.1499160868115723, 0.01679570363194216, 0.04701743018813431, 0.08944059518398717, 0.01894435288704699, 0.03341037518111989, 0.07531963259680197, 0.07525843509938568, 0.027687438814609777, 0.11240887091844343, 0.062485932576237246, 0.14965293608838692, 0.09809733222937211, 0.032258309656754136, 0.09905321843689308, 0.04424224687681999, 0.0851269879785832, 0.09047327883308753, 0.03654535539681092, 0.07269162088050507, 0.053952102607581764, 0.02349156220589066, 0.1817464444320649, 0.2873622521292418, 0.1280974200926721, 0.09625148479244672, 0.14811695757089183, 0.06424474093364552, 0.11401993251638487, 0.1398257282562554, 0.13781909452518448, 0.07825280059478246, 0.15074653521878645, 0.12589503749040887, 0.029509374253393617, 0.12217524490552023, 0.08363641405594535, 0.10067611729027703, 0.10204625548794866, 0.07299846925889142, 0.1313712858245708, 0.14388448937097564, 0.13918384473072365, 0.052065811833017506, 0.0472311167686712, 0.1419506751699373, 0.03983063535997644, 0.03703785201651044, 0.08759123738855124, 0.0217657942630467, 0.0506695760122966, 0.01895480974781094, 0.10174527749768458, 0.03977966094680596, 0.03796193348534871, 0.02903534968936583, 0.08766222381382249, 0.03672815008030739, 0.0704928302729968, 0.08124064261210151, 0.05792746858787723, 0.005952145429546363, 0.034393821042613126, 0.05207622416492086, 0.025315720376966055, 0.06607901086681522, 0.017736676381900907, 0.04160140342719387, 0.02750668874796247, 0.1161197799956426, 0.040770227715256624, 0.03723538575286511, 0.024567084474256262, 0.039802467144909315, 0.043595146053121425, 0.027110561859444715, 0.042513109583524056, 0.015931045927572995, 0.055257788990275, 0.03628462778578978, 0.014558748080162331, 0.03643093477876391, 0.05725626651837956, 0.03151141223497689, 0.019001982509507798, 0.04924774722894654, 0.041544543782947585, 0.013163143084966578, 0.05385814300097991, 0.05808257745229639, 0.02939365673228167, 0.019856255712511484, 0.03471238051133696, 0.03303172401501797, 0.029058855361654423, 0.03304812918941025, 0.010464495608175639, 0.04484699333261233, 0.026349142463004682, 0.060777939070248976, 0.04152288420300465, 0.037314053406589665, 0.021799977585033048, 0.02993420926941326, 0.04035289952298626, 0.052407823168323375, 0.021785654134873766, 0.013286038101796294, 0.05818744291900657, 0.04494014028750826, 0.04296069142583292, 0.05110759157105349, 0.044359832754707895, 0.03300024211057462, 0.045316728283069097, 0.1358242757851258, 0.2636014739982784, 0.18350183148868382, 0.1428484809002839, 0.15894205716904253, 0.11860447557410225, 0.15429541119374335, 0.11079443997005001, 0.10362728236941621, 0.1341395263443701, 0.19201097020413727, 0.10946681199129671, 0.10489948675967753, 0.15375300514278933, 0.1253226338303648, 0.21234872576314956, 0.12459035671781749, 0.11841740983072668, 0.12299865775275975, 0.17807351105147973, 0.09995362168410793, 0.14987316098995507, 0.23414845287334174, 0.07563776904135011, 0.13021286751609296, 0.09409236939973198, 0.20700094319181517, 0.2732852246845141, 0.16606360237346962, 0.14468250592472032, 0.24024645768804476, 0.1148457573435735, 0.0937035062815994, 0.19255566206993535, 0.20390672172652557, 0.13417376903817058, 0.10224311758065596, 0.23456145805539563, 0.0883389511727728, 0.09528526046779007, 0.16835349902976304, 0.28168111166451126, 0.13216357299825177, 0.10234661007416435, 0.13922923448262736, 0.10670270523405634, 0.14346232608659193, 0.1259471065714024, 0.19804614479653537, 0.09468331190873869, 0.22186472138855606, 0.2165039660758339, 0.18497627112083137, 0.10778877898701467, 0.0917672504147049, 0.23943013977259398, 0.09294747302192263, 0.22799371829023585, 0.21579913358436897, 0.30007176857907325, 0.23867874493589625, 0.277079944498837, 0.19290291296783835, 0.15685016551287845, 0.29402946936897933, 0.17596918100025505, 0.13980462157633156, 0.3956565004773438, 0.28565534215886146, 0.3489913826342672, 0.28324787446763366, 0.24786852212855592, 0.2573937352281064, 0.32207074749749154, 0.34019595303107053, 0.2792850136756897, 0.11501836605020799, 0.21791355684399605, 0.18295396323082969, 0.15317987417802215, 0.1916046443511732, 0.224387860216666, 0.1591385481879115, 0.3201774100307375, 0.4688176262425259, 0.24396017950493842, 0.1869915286079049, 0.14636293606599793, 0.07413822997477837, 0.16974849917460233, 0.16990538919344544, 0.16562447359319776, 0.1296308753080666, 0.2199317977647297, 0.17760471120709553, 0.15954873320879415, 0.16884762095287442, 0.15640566358342767, 0.14268097816966474, 0.3349914198042825, 0.2916646603262052, 0.30205167015083134, 0.2976826170925051, 0.18159513536375016, 0.14500629011308774, 0.11438019326305948, 0.21975380106596276, 0.2802680031163618, 0.12836824462283403, 0.1282054916373454, 0.4085277457488701, 0.15426152473082766, 0.38833631202578545, 0.2165817579953, 0.22303784906398505, 0.1638433785410598, 0.2282038945122622, 0.29521577758714557, 0.15090093162143603, 0.14766776526812464, 0.18378344684606418, 0.2844467991963029, 0.09975538661819883, 0.09428452627616934, 0.1821085679694079, 0.11015584415872581, 0.19222597038606182, 0.21323246037354693, 0.1614597486332059, 0.17773433472029865, 0.290585191687569, 0.10729757370427251, 0.28583782142959535, 0.1335031643975526, 0.13236953382147476, 0.09376338275615126, 0.12488368316553533, 0.24119290377711877, 0.16707807371858507, 0.15537143626715988, 0.1039533078437671, 0.10400765531812795, 0.11022411432350054, 0.1838025645702146, 0.09686564168077894, 0.12812965898774564, 0.08659647006425075, 0.15180560963926837, 0.0601473065034952, 0.09969619291950949, 0.12894385436084121, 0.13810738921165466, 0.06527798119350336, 0.2910751278977841, 0.17002370237605646, 0.12205103907035664, 0.2226774176233448, 0.22198613674845546, 0.13160130707547069, 0.12630744895432144, 0.15905654086964205, 0.15208890225039795, 0.1879897914477624, 0.11247433576500043, 0.11582303966861218, 0.13707503210753202, 0.15910374146187678, 0.15266464557498693, 0.16384708927944303, 0.1476006009033881, 0.12869630358181894, 0.20059479866176844, 0.12224156322190538, 0.1409054343821481, 0.2395605796482414, 0.17231855657882988], [0.007511862932005897, 0.06820792084909044, 0.08555226086173207, 0.08769982101512142, 0.06551775426487438, 0.1071316962770652, 0.023210410690808203, 0.05082643634523265, 0.04258441142155789, 0.05007788393413648, 0.1035756956844125, 0.06361711406498216, 0.027614520950010046, 0.029801416785630863, 0.05343554927094374, 0.02367301731283078, 0.0735532098042313, 0.05701002563000657, 0.041721041343407705, 0.018538958429417107, 0.06121794729551766, 0.06015364073391538, 0.04281532696040813, 0.06704835221171379, 0.09415747059392743, 0.0028335785054878215, 0.08650700416183099, 0.023673369832977187, 0.04174689776846208, 0.03484821951133199, 0.04741605254821479, 0.02837575666490011, 0.01029455770549248, 0.00912108122065547, 0.03634576962213032, 0.016957998341240454, 0.011429012065491406, 0.07300215031136759, 0.022865783284942154, 0.005766384474554798, 0.01836871717387112, 0.060207798960618675, 0.0703217281261459, 0.045760424982290715, 0.01890883740998106, 0.02619686860271031, 0.06697453820379451, 0.00884645040059695, 0.02756675075943349, 0.028117971669416875, 0.07270829693879932, 0.06182868288306054, 0.04619372048182413, 0.02378879606112605, 0.01781866329110926, 0.042891875782515854, 0.006742908881278709, 0.06482056589447893, 0.002352632486690709, 0.06074961129343137, 0.021249827223073225, 0.08006658725207672, 0.03233049465052318, 0.058561566984280944, 0.1100695323839318, 0.027771208733611275, 0.05960873735602945, 0.057546720854588784, 0.12540478957816958, 0.028575821124832146, 0.054017181537346914, 0.023904270528873894, 0.09606891646399163, 0.1633458278956823, 0.11830709700006992, 0.058925820485455915, 0.04834146246139426, 0.03812893155554775, 0.07646210957318544, 0.0169500870470074, 0.042383708714623936, 0.20264168648282066, 0.031231960238073952, 0.1199773077678401, 0.14024588774191216, 0.01395587925799191, 0.037312424392439425, 0.04256067753885873, 0.11546692010597326, 0.024710927536943927, 0.026846730215766, 0.08213504188461229, 0.060548893743543886, 0.05896310227399226, 0.07724124589003623, 0.02693987531529274, 0.0386397926195059, 0.04405965257319622, 0.05204753644648008, 0.11760175242670812, 0.06553967730724253, 0.08263448500656523, 0.13719330076128244, 0.13003746833419427, 0.05981542548397556, 0.01492341625635163, 0.06322717483271845, 0.0361203608190408, 0.02109625274897553, 0.028887756925541908, 0.061178876931080595, 0.024519282742403448, 0.060449605516623706, 0.08093970172922127, 0.017181366238219198, 0.07604012440424412, 0.013516069557226729, 0.02371069243963575, 0.03468751114269253, 0.057564829257898964, 0.04566795709251892, 0.04361468309070915, 0.010599532160995295, 0.03762433050724212, 0.03180867206538096, 0.012952425095136277, 0.04509746817348059, 0.026943266930175014, 0.036965362742193975, 0.10386643203673884, 0.06084170439862646, 0.037664866613340564, 0.01480637585700606, 0.014563128606823739, 0.04966646694811061, 0.03913521701178979, 0.07395624794298783, 0.04314425423217472, 0.024924716162786353, 0.06250440463190898, 0.014714789267600281, 0.027447424545243848, 0.03203623680747114, 0.0458117519156076, 0.03837167692836374, 0.029829887425876223, 0.03582751305657439, 0.03438554238528013, 0.04738937976071611, 0.06119951976870652, 0.03780636077863164, 0.05985154210065957, 0.040620918734930456, 0.022743978297512513, 0.0650152683374472, 0.030425919212575536, 0.019213685700378846, 0.0229613830379094, 0.01106299132516142, 0.055066626591724344, 0.0363397990440717, 0.0475224394176621, 0.0662048791127745, 0.09504349844064564, 0.014678974148409907, 0.059423834973131306, 0.039324145545833744, 0.03897892813256476, 0.018648100522113964, 0.06537178123835474, 0.062094034074107185, 0.07771521850372665, 0.012389631319820182, 0.033660553162917495, 0.05922655727772508, 0.015532451398030389, 0.028959526316612028, 0.047321643942268565, 0.013123654334776802, 0.047958744326024316, 0.04514702508458868, 0.02436873437545728, 0.044842455099569634, 0.04262631307938136, 0.09300046978751197, 0.019374841212993488, 0.04841941023187246, 0.08922960259951651, 0.029503700534405652, 0.03371269645867869, 0.029746143482043408, 0.019962132355431095, 0.03686781485157553, 0.03717498235346284, 0.06071107156458311, 0.03191940420947503, 0.06325306836515665, 0.03498216232401319, 0.01680538680375321, 0.027339006046531722, 0.05441735869680997, 0.012624625887838192, 0.0739188288571313, 0.03368124795088079, 0.03787187386478763, 0.06733632777468301, 0.03099202203884488, 0.00828213058412075, 0.0038191858720892924, 0.04214057742501609, 0.034201794042019174, 0.049928749358514324, 0.042274850493413396, 0.03626812613219954, 0.05782482214272022, 0.01758034482918447, 0.03622571981395595, 0.054133591111167334, 0.013551654610637343, 0.028206109127495438, 0.04283729453163687, 0.030401270632864907, 0.02021969841734972, 0.05033132365497295, 0.014572197651432361, 0.021232340368442237, 0.014586303095711628, 0.0790954647527542, 0.05913945511565544, 0.037108341202838346, 0.03692430713272188, 0.041629935294622555, 0.025226952093362343, 0.06706555519485846, 0.018536179086368065, 0.0561683188425377, 0.02243804461613763, 0.0266150094466866, 0.014479185210802825, 0.04745392063341569, 0.061316114879446104, 0.024162508234439883, 0.15039472753414884, 0.0189919783588266, 0.021343445441743825, 0.067031661310466, 0.0687303111772053, 0.08817673995508812, 0.0364104218169814, 0.03508940637402702, 0.02697097501368262, 0.02763923261227319, 0.025847599063126836, 0.07859236284275539, 0.044026530522387475, 0.047857285317149945, 0.1152992392599117, 0.14907054312061518, 0.020016836060676724, 0.03663289542600978, 0.1264707066002302, 0.029015282016189303, 0.07333174551604316, 0.06497950424090959, 0.07306760773644783, 0.01758630056428956, 0.037664684787159786, 0.010540549046709202, 0.03178627404849976, 0.04888452902378049, 0.04209626007650513, 0.045844187479815446, 0.03647927827842068, 0.03860088181681931, 0.08390133109060116, 0.14638693712186068, 0.07635311776539311, 0.09516075777355582, 0.13226956652943045, 0.07631409564055502, 0.06239467067644, 0.02307285732968012, 0.10647472488926724, 0.07002737009315751, 0.016649563622195274, 0.060269608729868196, 0.053911778013571166, 0.03127686388324946, 0.060202819149708375, 0.08330580210895278, 0.03467966293101199, 0.044061199951102026, 0.013592349350801669, 0.06193159279064275, 0.06337775659631006, 0.09391134473844431, 0.013886186025047209, 0.03467036010988522, 0.04277420826838352, 0.06997418036917225, 0.026913501242233906, 0.05107458826387301, 0.06300888693658635, 0.04883022978901863, 0.027138691111758817, 0.08625541609944776, 0.07777947364957072, 0.03316842390631791, 0.018869755913328845, 0.05095361077110283, 0.03406871954211965, 0.04333458171458915, 0.034833717945730314, 0.017280283391301055, 0.07468082898412831, 0.020087811353732832, 0.01549241438624449, 0.02501693172234809, 0.04940660022839438, 0.025613058132876176, 0.015430430212290958, 0.08778180606896058, 0.0871822917542886, 0.02002575853111921, 0.051765479511232115, 0.09536472221952863, 0.026192102159257047, 0.030172787483024877, 0.06309394448180683, 0.04719668853795156, 0.10400146580650471, 0.03248899141908623, 0.034872784599428996, 0.04433166825037915, 0.024830699039739557, 0.059441323683131486, 0.012267008114577038, 0.08220475923735648, 0.07641099786269478, 0.06821129762101918, 0.012609312598215183, 0.02600158357381588, 0.025559662462910637, 0.018487752095097676, 0.032939326629275456, 0.017018867438309826, 0.01138302117396961, 0.02892689222790068, 0.05270758403639775, 0.005851384503330337, 0.02220902340923203, 0.008409300371567952, 0.08756856477702968, 0.1839648128952831, 0.15091659093741328, 0.1939478568965569, 0.14602386363549158, 0.20642659510485828, 0.16343498951755464, 0.07931385654956102, 0.16549646796192974, 0.11188118907739408, 0.25170386710669845, 0.18688035488594323, 0.14125804358627647, 0.21025925350841135, 0.14052716171136126, 0.12006953445961699, 0.12453315197490156, 0.15024267631815746, 0.12026399199385196, 0.1363942155148834, 0.08039950727834366, 0.1632552413502708, 0.13364423182792962, 0.12999041617149487, 0.1910247004707344, 0.14832955319434404, 0.2921543293632567, 0.10703866806579754, 0.235953786468599, 0.1353867500438355, 0.18684602313442156, 0.14307056117104366, 0.09505621885182336, 0.11715910586644895, 0.12220122749567963, 0.13521356246201321, 0.0904383607849013, 0.17271474469453096, 0.1657909224741161, 0.10143267747480422, 0.12406745430780575, 0.15283743239706382, 0.12038959306664765, 0.12302348259254359, 0.13717465801164508, 0.09882499318337068, 0.10225505131529644, 0.12276481444132514, 0.055916983110364527, 0.11928060921491124, 0.1705301142646931, 0.14606563170673326, 0.1197863309062086, 0.11715269371052273, 0.04784657241543755, 0.1613771475967951, 0.09586572385160252, 0.15821349079487845, 0.13465560099575669, 0.22345440171193331, 0.07182084416854195, 0.2658462035469711, 0.0903578451834619, 0.2171481799450703, 0.13291044073412195, 0.12279878254048526, 0.15584685606881976, 0.1156797754811123, 0.28009113448206335, 0.1872923507471569, 0.16699906467692927, 0.1884198363404721, 0.1942420590785332, 0.2299648179905489, 0.28030822752043605, 0.21782807627459988, 0.2108054148266092, 0.1437146562966518, 0.14512518217088655, 0.12155959630035795, 0.21979366923915222, 0.28042189485859126, 0.23427080333931372, 0.2819215675117448, 0.3134976950241253, 0.06774456836865284, 0.20839561679167673, 0.1452957870787941, 0.15058100660098717, 0.16169411886949092, 0.13189307501306757, 0.14559604518581182, 0.20996266161091626, 0.1022555930831004, 0.1769156864611432, 0.13212078076321632, 0.1746983124758117, 0.14018520974786952, 0.18950083380332217, 0.31108598224818707, 0.2333587483735755, 0.21436428010929376, 0.29689789982512593, 0.3228156559634954, 0.22681244183331728, 0.1291896536713466, 0.24671887600561604, 0.18110537726897746, 0.09397715097293258, 0.3462309791939333, 0.21056012017652392, 0.2026280012796633, 0.210339316399768, 0.2749435091391206, 0.16052839782787487, 0.12130641262046993, 0.10508240389754064, 0.15366571373306215, 0.12466351763578132, 0.20355534448754042, 0.1611718547064811, 0.11760194538510405, 0.09643599754781462, 0.2368270864826627, 0.09239543389412574, 0.15560108644422144, 0.14748613204574212, 0.14681729371659458, 0.10207312123384327, 0.25412065617274493, 0.207279619644396, 0.1304499540128745, 0.1230316239525564, 0.10125951957888901, 0.09164930830593221, 0.1342207915149629, 0.13210381526732817, 0.15399359457660466, 0.10887502343393862, 0.13279732258524746, 0.09371195192215964, 0.07415227883029729, 0.07268971356097609, 0.1455383506254293, 0.10386538560851477, 0.13217844563769177, 0.15239374683005735, 0.07307639476493932, 0.12309044657740742, 0.1500469126040116, 0.09813417244004086, 0.13750004523899406, 0.13942392950411886, 0.14126491587376222, 0.21932812000159174, 0.12513602821854874, 0.049299178062938154, 0.13281629187986255, 0.0959110097028315, 0.18286894279299304, 0.14640958746895194, 0.1772890312713571, 0.1489446748746559, 0.3510720084886998, 0.1092961996619124, 0.09944366975105368, 0.07928848994197324, 0.11248597264057025, 0.09373641310958192, 0.19536066858563572, 0.1583031570771709, 0.121519171516411, 0.1170285175612662, 0.10668431481462903, 0.12743983272230253, 0.16971154022030532], [0.03188900955137797, 0.009268084904761054, 0.031734657677588984, 0.09334986549220048, 0.05488737937412225, 0.04243965551722795, 0.007088606835168321, 0.0320078941877, 0.014679027954116464, 0.07428741650073789, 0.014740561273356434, 0.047999354646890424, 0.07715989166172221, 0.017190268299600575, 0.0396672886563465, 0.037264374041114934, 0.09571066693752073, 0.0686618554755114, 0.05240116239292547, 0.03255427072872408, 0.04400019170134328, 0.08257235240307637, 0.05021597535233013, 0.013067060936009511, 0.08269718164228834, 0.00851941375003662, 0.027084453104180284, 0.05508312824531458, 0.09850385104073212, 0.05226894507359248, 0.03455737554759253, 0.0878850684966892, 0.03798653939156793, 0.04918425649520941, 0.05335545298294164, 0.04076156685187016, 0.035187228859285824, 0.07668571124668233, 0.017722902121022344, 0.047024328450788744, 0.040653795877005905, 0.004216051429466461, 0.06606810871744528, 0.027560145645111334, 0.04812822488020174, 0.029630179196828976, 0.029069301090203226, 0.04504231546889059, 0.02272212390380446, 0.10299986330210231, 0.011117733993160073, 0.021459925519593526, 0.026651460029825103, 0.09302667502197437, 0.08193671033950523, 0.0815742825216148, 0.006184398225741461, 0.04051867676025722, 0.10819226983585395, 0.08237466652644798, 0.02830200202879496, 0.029981792067701463, 0.06365733104757965, 0.03666608055937104, 0.0629337593272794, 0.05059902374341618, 0.02205958455306245, 0.1272847832296975, 0.02511492119083414, 0.036827230505878106, 0.02331830040930072, 0.058409137272974476, 0.07123442133888602, 0.051872018520953134, 0.06044762769306544, 0.053711112414021045, 0.024270576068374794, 0.10341162167605944, 0.03993987207650207, 0.08578017441323027, 0.017801710782805458, 0.10800505566294305, 0.05199019069550559, 0.024973215513455216, 0.06997309683356434, 0.09390982333570719, 0.03732375327672344, 0.05901945354708005, 0.005150310526005342, 0.0976986504974775, 0.013850113937223796, 0.04466859216336161, 0.056829887835192494, 0.005559626770264003, 0.024887395411496982, 0.08450608496787027, 0.03221103484975174, 0.004764490677189315, 0.018397916974208783, 0.062421529000857845, 0.03653067942650523, 0.07834196963813156, 0.07820401922799647, 0.08460794473649003, 0.026591616951918695, 0.05998731801810209, 0.08530678067472763, 0.021293098143360112, 0.023778610084264074, 0.055710384040139616, 0.08893307007383555, 0.019620302846306004, 0.12825508194509894, 0.03687352567794733, 0.02660596637724666, 0.055091841059038416, 0.039165377893368714, 0.017430937514291145, 0.022666722579742782, 0.0236911609681556, 0.10445945255924016, 0.07889500324381515, 0.06623548528295942, 0.07098678892361932, 0.023578898144478444, 0.06888055897434242, 0.009124063726630993, 0.03794289739744272, 0.028526269779831637, 0.027462486432341393, 0.050489638597355224, 0.043122435090481304, 0.04114321629458573, 0.0030819880885246675, 0.0336459885147633, 0.0439040242054034, 0.019021547377633397, 0.03216035358491354, 0.01586008362210123, 0.022781527259212453, 0.0418067371356301, 0.0615269219269976, 0.048497977695660666, 0.04628937960660551, 0.06982173581491224, 0.049251944074057974, 0.014973922188801225, 0.07049927211483009, 0.018795209034578875, 0.06459001771872863, 0.005967167426206288, 0.029014994433964603, 0.025723166872921865, 0.05685342133801896, 0.02401709367404692, 0.06034589037881233, 0.026417069384478964, 0.09793511359021068, 0.014658599411632167, 0.0118331866178778, 0.039423355847247876, 0.043781295244116336, 0.02369227233430138, 0.07019247568678111, 0.060689022357109934, 0.019822838658001274, 0.034041731341858394, 0.09233066666638479, 0.07727301723207347, 0.05623593591735698, 0.0377255668718135, 0.02682802438357612, 0.08155394767527469, 0.011377398477634415, 0.022643352349405177, 0.024027784311329015, 0.015391189153888263, 0.07449646465829574, 0.038045254405005835, 0.04329673218308017, 0.0665759900584817, 0.017168265476357192, 0.030222765562939458, 0.036201158436597325, 0.01788095174561022, 0.08930720898206346, 0.019781111404881813, 0.03949708821892273, 0.05121528090967331, 0.03036389793123817, 0.004347744143160526, 0.016427062182629015, 0.09343119745608419, 0.044275784530327655, 0.03172794124111533, 0.027565151431190316, 0.06559744608239271, 0.05166452887351625, 0.08138738747220486, 0.0056825941464921925, 0.03484512104478199, 0.04482308875594754, 0.03279660420957953, 0.025201216267305426, 0.043521940606296994, 0.055552339981659316, 0.005332543960321345, 0.03312359447591007, 0.06311195640591905, 0.005729390732085449, 0.026422965747769922, 0.01021712479996495, 0.01738362745527411, 0.03125019109575078, 0.02148961884813616, 0.025606204399082344, 0.039338825226877816, 0.019187955440429505, 0.026391350256744772, 0.03006680137332296, 0.02507219760445878, 0.017508820346847642, 0.049306514192721806, 0.06050073578080628, 0.02843173686414957, 0.08110754584777169, 0.02061609618976945, 0.008190717471734388, 0.03401139234483708, 0.047344160702778026, 0.012909547513118014, 0.07503670363803394, 0.03405040333746001, 0.03864107282424811, 0.027821392759506125, 0.036112323359702714, 0.031176121046883054, 0.03796946628426667, 0.05102587369037792, 0.0343595004233066, 0.019030850198760163, 0.06412365211872384, 0.04624478766345419, 0.11390907791792415, 0.01710634067421779, 0.027952229684160557, 0.018181816558353603, 0.05966590870229993, 0.05596987597527914, 0.018082372480421327, 0.04137255476962309, 0.06551038473844528, 0.04713045185781084, 0.05637049842334818, 0.13763688242761418, 0.10170175053644925, 0.029860361864848528, 0.08122899089357816, 0.015264455378201092, 0.033643535716691986, 0.09412347280886024, 0.05995531661028508, 0.0555076367163565, 0.03130686149233952, 0.034414408219163306, 0.04331503725552466, 0.013260342166176997, 0.04144459504459519, 0.09584564133547246, 0.06315655205980875, 0.04655854543671012, 0.014808847208769294, 0.0867509629460983, 0.05597452924121171, 0.0638635442010127, 0.037807922999490984, 0.027178351483598817, 0.05995494553644676, 0.0465308187995106, 0.03379349036549684, 0.06022163630404975, 0.02828291955665918, 0.0818994693690911, 0.027127282446599565, 0.04166558806900866, 0.07391751525574364, 0.09785391521290876, 0.03460278385318816, 0.0622644237591885, 0.06357934616971761, 0.024090991173579823, 0.08310957084177062, 0.06989557208726183, 0.03760476378374733, 0.027473562986415345, 0.010769479340524413, 0.07728435724857263, 0.04667024237278383, 0.06093911870266311, 0.038758150330977514, 0.05130088022269774, 0.02303378510987386, 0.03152945384499617, 0.032466593402205035, 0.06100432750827167, 0.03280056356743444, 0.00613073955719301, 0.04708086155005731, 0.017533598802401684, 0.04848870084970258, 0.020122564274061006, 0.017705751088215038, 0.03680426474602427, 0.06099111727962736, 0.032978055605781265, 0.03216482873540372, 0.0643282251257915, 0.06356635116389953, 0.027318942084093578, 0.033019619586411864, 0.052761564147658646, 0.05221453080594074, 0.03594043453631457, 0.029458533426804934, 0.030932767112972215, 0.05126897158334032, 0.054195445409277454, 0.09504188798018731, 0.03012011726241326, 0.012093270415789448, 0.013556005451391684, 0.042890903569059446, 0.06773814879124984, 0.022776894402340986, 0.033797861615312286, 0.019950337773479987, 0.06006992647598963, 0.004645058706955751, 0.03588845822378062, 0.03825011313892901, 0.023160736891441047, 0.02138762363756541, 0.02053126871032873, 0.06632777134655043, 0.06257038898183964, 0.052793970025959425, 0.057165141915902495, 0.04554208142508287, 0.060418320281314664, 0.0060409916386561235, 0.0016733665188439772, 0.06644252964179032, 0.09214127057930455, 0.24310884706210345, 0.13703175005503, 0.14064700371818617, 0.17252626887056977, 0.12337969121290371, 0.175502919300925, 0.08128326415317133, 0.11294074589386582, 0.3242333955131471, 0.11038743134122342, 0.09604196908185259, 0.2180625355686061, 0.07244108666782267, 0.07847727058106102, 0.17391792935086414, 0.21836139843799174, 0.1497689337702468, 0.13427323166979477, 0.09799062623642385, 0.14455904223723337, 0.10290085338056087, 0.1299588748952374, 0.11928725885809399, 0.15702989883720875, 0.0989074086828623, 0.10847502067917958, 0.13269655377371237, 0.2366484812228009, 0.16330245678545907, 0.09911121727782302, 0.17908982292283326, 0.16556777351070195, 0.1762898630113341, 0.10064742586109787, 0.08840906186378561, 0.06290948367677629, 0.18824197322828695, 0.07409361947793514, 0.22455997910583392, 0.2672633790643886, 0.08094301170785911, 0.1515587416361086, 0.15576229576254264, 0.12214773349114694, 0.13479703949997202, 0.10978659600368701, 0.1390880037797615, 0.12807757506379858, 0.2396314695943147, 0.17229678196599707, 0.13807693147100508, 0.1697300493833609, 0.27662667038384825, 0.15545236004982144, 0.14076021092478186, 0.1696314476430416, 0.10001841117627919, 0.17908658715896308, 0.10177952761296183, 0.12664036155911162, 0.08651948708575219, 0.15277197497198358, 0.08396244695177302, 0.22222856670850888, 0.19720411888556555, 0.18350908969296142, 0.3136129060294479, 0.18219679448520765, 0.08840230831992812, 0.1351517712464556, 0.1672484856680967, 0.2097812807187438, 0.1818082801764831, 0.22485637804493308, 0.1642373253707774, 0.165010747150518, 0.32345224055461586, 0.268944165436551, 0.16724081186112016, 0.11910021537914872, 0.3019906359259039, 0.16052799706812948, 0.12086465663742274, 0.20457205711863935, 0.15486561809666455, 0.12062621201039292, 0.12708480411674827, 0.10209939326159656, 0.18459857732523233, 0.08414213574724272, 0.11595549818594009, 0.14229725813493133, 0.1545178031665273, 0.07737916661426425, 0.10301242786226794, 0.12451341084670275, 0.07361068172031082, 0.19511623482685536, 0.16466404544189572, 0.1298123601009138, 0.21169716463191435, 0.17738141381414607, 0.3191177122062072, 0.13407930848188698, 0.14472376933554187, 0.157028429384809, 0.12189607121399604, 0.10420170467114076, 0.22313618363114074, 0.2667782816570252, 0.11976831898209639, 0.23450063163181767, 0.13377097580814734, 0.13542694476200268, 0.1988921337760985, 0.15693373134126887, 0.20038122340338305, 0.10361613531131297, 0.10723340761614963, 0.19471011677524075, 0.2394478622591123, 0.22162503737490624, 0.29184672399424016, 0.13618665165267885, 0.10679401908419095, 0.20152785640675575, 0.11451642931206152, 0.17425753612769768, 0.11327643413096666, 0.1482320498325862, 0.16930864308960736, 0.20156957994913682, 0.06545342490426265, 0.115295320720179, 0.15835472149774432, 0.1384754796163179, 0.08826541175949387, 0.10334274295018986, 0.12641509005334228, 0.153549597307574, 0.1695144406403415, 0.14920074550900608, 0.15234106918796897, 0.11554223325219937, 0.17472560866735876, 0.18148191331420094, 0.12195308299851604, 0.08951668016379699, 0.17784348980057985, 0.11665690937661566, 0.13996497000334784, 0.11054723057895899, 0.11707836019922979, 0.09710942977108061, 0.2098220246261917, 0.12271282699657604, 0.13219578220741823, 0.1456237124511972, 0.06394987081876025, 0.09278296856791712, 0.120372961537214, 0.12530602456536144, 0.15414870344102383, 0.09903960002702661, 0.15721687552286312, 0.21783315256470814, 0.22865261184051633, 0.13286650559166446, 0.10296561318682507, 0.14891111495671794, 0.10023635768448003, 0.1557806268101558, 0.1476387621369213, 0.10391828589490615, 0.1025515838409774], [0.07631535729160532, 0.042530516657279804, 0.04149797030549962, 0.045107305340934545, 0.010132221250387374, 0.037298241950338706, 0.03552477988705505, 0.06259832342038862, 0.02641431230586022, 0.03936257395253051, 0.0073157875158358365, 0.08170418062945828, 0.008750084380153567, 0.018313879882043693, 0.024969829464680515, 0.067166754452046, 0.06525522694573738, 0.04883705754764378, 0.015104898266145028, 0.07118749534129165, 0.0037686896803279524, 0.036315089237177745, 0.049811330463853665, 0.04332623255322687, 0.07774098587105982, 0.030908860680938233, 0.0240524866967462, 0.0543964375538053, 0.047030766581883654, 0.09018253505928442, 0.03409389690204989, 0.023132846981752664, 0.03891590495186392, 0.02443474284518743, 0.020484344568103552, 0.12117403573938645, 0.04161485114309471, 0.038851505087222904, 0.010476213192305295, 0.05094507978355978, 0.02169060357118724, 0.025650080169725697, 0.06378258331096731, 0.011089366325904848, 0.022313835070235655, 0.08380019120522775, 0.08729203313123435, 0.07467904782970436, 0.03800166436121799, 0.022939421032788232, 0.016952005498751532, 0.02657511900906684, 0.0785373400140088, 0.007545067546743667, 0.013684025925613241, 0.062349414511118084, 0.049188575794687495, 0.03782843967201188, 0.061632388533325866, 0.035097054205834866, 0.03276488852861803, 0.012902154794574017, 0.037895014029345475, 0.033125004556495696, 0.022686610282107722, 0.08304812843562104, 0.04327889095293358, 0.0511591782560572, 0.022799904691055417, 0.04405802355904598, 0.010489394662727136, 0.012415294786478626, 0.02038604154222412, 0.07761698783724569, 0.0660577928647399, 0.05995647064992227, 0.005051208763688919, 0.041050444124266505, 0.028048443564330228, 0.043016285708290525, 0.050344782503088936, 0.1276209464413114, 0.04987997170246672, 0.09788283670786768, 0.04745233614812605, 0.02719555632211268, 0.058775624638656154, 0.01885406320070615, 0.031071301964402664, 0.0077030791362631135, 0.06267192220548168, 0.05223502892476972, 0.0035096629790132283, 0.04443389167136047, 0.023779611983627547, 0.02400523972028168, 0.07606423678225838, 0.07226584333693609, 0.055692342430120334, 0.10258582653477788, 0.019983936654170975, 0.05395621410571039, 0.04682757396949455, 0.03537151154887397, 0.020324229917605408, 0.023785499070072547, 0.06464602760388516, 0.004618408183887368, 0.07203876841231249, 0.05672089602740016, 0.038015371828805655, 0.031646572169847786, 0.05233710020547733, 0.07053773762891069, 0.02620900828333106, 0.023232478451973293, 0.06733586022164673, 0.04026929658721201, 0.025995073083322495, 0.055134644426289015, 0.05566599989833776, 0.08192497698473744, 0.11995047912932932, 0.1061044228845276, 0.008351135475095361, 0.028082257667847443, 0.018282932323927525, 0.03888173647283111, 0.07601830526255071, 0.07020794204436243, 0.03080834234424401, 0.07017994823399931, 0.03062083873373922, 0.023051186617522035, 0.03151488919684198, 0.018530262314016, 0.022991132027527783, 0.05295296032272745, 0.03719807056768332, 0.05935597298957873, 0.025132671507890336, 0.02098570614180062, 0.03856187824567314, 0.018863007935578935, 0.013308908310136758, 0.030806911854597274, 0.0033488256622149493, 0.07790068862959743, 0.04130124179937411, 0.003392360972611641, 0.06847554672276601, 0.06952167808776721, 0.06264325304073282, 0.05666195836965926, 0.03401351488719229, 0.03930872000637464, 0.04891224823950324, 0.10208947816863656, 0.03698356020322535, 0.029187191248638555, 0.015089510761754354, 0.03310627645987552, 0.05304303478624206, 0.01716763279546285, 0.03065874207095476, 0.04557526655844413, 0.04263000526407268, 0.060373531669029035, 0.04084593791048974, 0.0533031204395229, 0.07800882696756162, 0.03812612623733003, 0.018772002076730132, 0.013768306071142433, 0.03813978546531871, 0.015961362660164014, 0.0477406159916427, 0.014966052640374983, 0.06365277426084504, 0.0350221084227087, 0.01964230938028777, 0.03443456495006103, 0.016876384361239616, 0.056033656146610156, 0.03522157174302265, 0.02480205956089776, 0.04066804140165914, 0.07290001594810747, 0.026230313487758394, 0.060097218956798315, 0.06452073823311366, 0.05661904739099555, 0.01658672783378279, 0.10970346062094904, 0.011300437763566151, 0.013743627805524739, 0.0376945599418832, 0.02172196858737152, 0.016953111298789736, 0.03392644241102971, 0.08931348012993112, 0.018654713057912886, 0.004635888080883888, 0.09990681443014182, 0.009593307004251983, 0.021883550834900234, 0.06454180780565366, 0.026891446468653157, 0.034679659220273606, 0.06657484715105966, 0.013931593402958242, 0.04760236872243695, 0.050326833661529236, 0.07283023180207238, 0.04273265541996807, 0.055991275803535245, 0.02420557135337731, 0.05189851319300942, 0.0352716667111963, 0.06713679395033978, 0.031461042672162876, 0.06424013961805031, 0.012246485875948565, 0.01228077588166343, 0.034981034259544685, 0.017926578984770458, 0.068358027638169, 0.033496393807581626, 0.0988243697793223, 0.0126175420882646, 0.018939849906018935, 0.030324636463774368, 0.08355361263966188, 0.03117041393124964, 0.0365381009032717, 0.03229604415537324, 0.03155398182570934, 0.0789230118971318, 0.011331051355227828, 0.026302248006686568, 0.034597503472468816, 0.14380083448486403, 0.035229405111749656, 0.023043202963890508, 0.04479896153497975, 0.05370696380850859, 0.010054338417830877, 0.016668473544996232, 0.03402745984203648, 0.06930618808837608, 0.06637434111326002, 0.0210836881888099, 0.021858755681023467, 0.02075396496366011, 0.04414940420247149, 0.03339373994094785, 0.05800939798064064, 0.06706026368192397, 0.12954165431438014, 0.011288239638815867, 0.05984625058772508, 0.04445046382897999, 0.04631742536730599, 0.10871196616790257, 0.01210050913869054, 0.04312251301598735, 0.04037189108203165, 0.0796616640582215, 0.13156351691577584, 0.06650722265476361, 0.07220689454698004, 0.04397701071866322, 0.08756332521443255, 0.04949034046148881, 0.05900599469896406, 0.044470609427662566, 0.11065121288993396, 0.02987354797369335, 0.08928790572099388, 0.03295588765467983, 0.037367736658779904, 0.030082527482591104, 0.0690736212709453, 0.04952970768499654, 0.01692790239758324, 0.04650693648727611, 0.07414995590806939, 0.11063305995776318, 0.010948789640679024, 0.060933823478990234, 0.014699888797622407, 0.03155833823257126, 0.13403722870862111, 0.025639326449891087, 0.05731218363507651, 0.07549546964582987, 0.057778853515628725, 0.01461697976992582, 0.03398042252229061, 0.06492047381470911, 0.021592300545307808, 0.005923543985772994, 0.02444327197736129, 0.1139591951505281, 0.019502863542584237, 0.05668236372002866, 0.018835726586985402, 0.03413901948079001, 0.02048259866569424, 0.066825923131546, 0.047364402780658565, 0.022384225921996403, 0.01952688686287729, 0.021515332409762777, 0.022960997121117543, 0.037585167374345474, 0.03931690960598644, 0.03575728362193331, 0.044447369073168375, 0.07998084693099372, 0.01886133810330648, 0.016281341486319434, 0.0530843687010929, 0.095127828681143, 0.05173448000277858, 0.024851766756910365, 0.02168404113035649, 0.007798279984854162, 0.049020319784176536, 0.050472676812205464, 0.054271508124656975, 0.06716371164657176, 0.07068365870509297, 0.052906835844623856, 0.04186047975963447, 0.01794519390386995, 0.015163350744842319, 0.04671507922466844, 0.021431545792438556, 0.022958865301916376, 0.0015992266617104178, 0.09561042505083606, 0.02034143661148846, 0.0061264675696293125, 0.0451442086341558, 0.03955559172027279, 0.07778071303619072, 0.03346932397107594, 0.029635088503709994, 0.024128779477905482, 0.006525601547764381, 0.016633984087093268, 0.13220700348028913, 0.11559761231183074, 0.1691308245062828, 0.11411063780542463, 0.11710751918144524, 0.13764249306404963, 0.12794980691978708, 0.14749891182873398, 0.14537323761032894, 0.1353650793316774, 0.1687873140326701, 0.20992227393435314, 0.07003571925451979, 0.17665836901869625, 0.10425160668091848, 0.2711481659207493, 0.12529030587757006, 0.2387941488996148, 0.09039825512445532, 0.11945203790673986, 0.10727847824455239, 0.12227872255607508, 0.09248702233890072, 0.1374810462584719, 0.174637604795862, 0.10559405534877442, 0.06930489675141871, 0.1801763122784905, 0.05945601820712909, 0.26180633751209825, 0.13528780691558495, 0.10327229829272255, 0.12107431335607544, 0.13204509654315189, 0.07326107821427286, 0.3618911560624838, 0.11506322145578451, 0.19862644490785897, 0.14563558681402355, 0.14939095795853063, 0.13239268882898614, 0.14455737982643768, 0.15977890288922936, 0.12373893521726131, 0.14226108585717157, 0.24602683814009652, 0.14072901103645563, 0.176198564004153, 0.1454072873457335, 0.08878662207280286, 0.11292949493508786, 0.14746734086656943, 0.19423806632403284, 0.15017430967418477, 0.12615323066711426, 0.1193265629990492, 0.14662209403468296, 0.15829347947146744, 0.21829510980751365, 0.1133309819852002, 0.08995137832243927, 0.12221013326779939, 0.06947273344849236, 0.11434408777859062, 0.22484359826194122, 0.27152514725457877, 0.0980471185175702, 0.18200796243036166, 0.1912187720881775, 0.11594379451707937, 0.13699008588446304, 0.1068355274037458, 0.14216435432899743, 0.1704317648545839, 0.14305798918940127, 0.1346888195257634, 0.09566144770360552, 0.11893449380295351, 0.14772793860174716, 0.11099844152340665, 0.13067203428363428, 0.2631588571239263, 0.35401049768552184, 0.13189026969484985, 0.15468805184355006, 0.08736077084904537, 0.19762801879551262, 0.11159231551573612, 0.11596515352721326, 0.08049941519857384, 0.12162948434706777, 0.14361954265041277, 0.1742132447543554, 0.20397001208039, 0.14176708267768845, 0.1204932710970752, 0.2365252550225705, 0.15563426044536754, 0.15834247606107965, 0.12221920973388478, 0.1913491080631502, 0.07862273152568378, 0.2672168909339234, 0.201317947357893, 0.10722468738094904, 0.10770611857878976, 0.273215314373374, 0.10317863183445297, 0.11311157344607636, 0.15673842775868252, 0.1858262825408019, 0.2855135325808078, 0.1529259854578413, 0.22724437178112566, 0.11053120018914342, 0.19729207822820172, 0.13079272233881056, 0.15014708769740537, 0.1959442489896901, 0.19232535880291834, 0.1911440971889533, 0.14606567623559386, 0.21592933597275987, 0.20557888434268534, 0.0853536621434614, 0.11065130194765516, 0.1332137268036604, 0.29821556818205863, 0.11996060944511555, 0.13856391393346712, 0.08668562426464632, 0.16331151098711416, 0.1691945007769391, 0.15265698661096394, 0.14598073001252487, 0.10202816934906878, 0.18732441152678803, 0.17911256232764572, 0.14271217805799097, 0.1002350811904762, 0.1168586102721747, 0.18673140584724024, 0.0823642838804517, 0.09492138546193019, 0.09264440217521042, 0.06608337469515391, 0.111799805163173, 0.13894232019083574, 0.18943763250717893, 0.11228640913031995, 0.1426288645598106, 0.1980550357257016, 0.14686862064991146, 0.13416299305390567, 0.13172392471460626, 0.1817260353709571, 0.23127320950152352, 0.27265436947345734, 0.1687705860240385, 0.08346532675204799, 0.10495094727957621, 0.1360260063665919, 0.13588064932264388, 0.15197380998870358, 0.19298968487419188, 0.18474486947525293, 0.09099180257180706, 0.1534608512884006, 0.13312235358171165, 0.15758189343614504, 0.15949396271025762, 0.14027000754140317, 0.14502129633910954, 0.11796958307968453, 0.09023378777783364, 0.07332422013860196], [0.050191592090413906, 0.03833619484794326, 0.018540906567068305, 0.019059929400100373, 0.012700881561613642, 0.14027630095370114, 0.06550538266310468, 0.045330773427849635, 0.024507736779924016, 0.006108860579843167, 0.04018784959043842, 0.03464531633653678, 0.046782087738392875, 0.0712823640787974, 0.04356127814389765, 0.05311773937137332, 0.09211056792992167, 0.03588238003430888, 0.052862514785374515, 0.013578944308392238, 0.024732338497415185, 0.025139992794720456, 0.022887992054165807, 0.06648434224189259, 0.025397529170732014, 0.0612338069913676, 0.010581590740912361, 0.05525369233509991, 0.04338754137279466, 0.06888926436658949, 0.11276848599663936, 0.02366988359426614, 0.0856341420148965, 0.09677319976617582, 0.012740882393700304, 0.03822507307631895, 0.03664387550088577, 0.025194258632836863, 0.04198526446998585, 0.0057576753715693485, 0.00943100116273854, 0.016296102803607937, 0.04222632516757585, 0.034095715163857676, 0.041063847311306745, 0.03631578314525541, 0.09241010615369305, 0.09462819260079414, 0.05515530952834524, 0.035294046174385585, 0.05095866108604241, 0.060095382141298614, 0.06161734519992024, 0.060716830630553886, 0.0340868131024763, 0.03895784371707123, 0.02781568193313433, 0.01003417797619477, 0.06463662459282205, 0.0712945575651247, 0.028487661402323283, 0.035612256833701394, 0.028181777815916575, 0.021053096861578524, 0.046935530481277965, 0.00969838769378839, 0.015772899823787156, 0.015138717008085223, 0.06884115093271248, 0.04385791085951496, 0.0350121710653184, 0.06328832037979737, 0.12928157608257607, 0.040670802191016264, 0.038172269269125536, 0.03471849951893091, 0.07259389487444423, 0.028199654298077803, 0.023467828323191497, 0.049447733763372526, 0.056646358425496146, 0.06414305185899138, 0.07685950738959946, 0.02420202574285213, 0.07193644109065644, 0.032187827891903, 0.03073532057896955, 0.06824709140346386, 0.03485492852632888, 0.03255144685681444, 0.030793449295742903, 0.041595061775296926, 0.02957375556434272, 0.007984929197846213, 0.018722040695138276, 0.02574580423242878, 0.021899516286794096, 0.04001675857580267, 0.03898703238519374, 0.0926535009057261, 0.04735173803055659, 0.03504834705381654, 0.043040717209805734, 0.017967695821425878, 0.1019154668028932, 0.011975584347965196, 0.07937866830616258, 0.10295964631950483, 0.05031159736972768, 0.010177947751799366, 0.029811921885993797, 0.07221842010039836, 0.013596812441392103, 0.026580289923003875, 0.048788291023811325, 0.02555567156377947, 0.013010791299166158, 0.04626127076335251, 0.05333094726665877, 0.010043863003375009, 0.03753028926439583, 0.052903863543178886, 0.0509765245806193, 0.0501658766734181, 0.02272294212161796, 0.012079515636287397, 0.021897827900829725, 0.02635298307723133, 0.036523213420878164, 0.09555447453749366, 0.01068438283255091, 0.02194927914388245, 0.051896613294957206, 0.06307310497504659, 0.055006482944008894, 0.04876103193964809, 0.052185078675393015, 0.02703098136407789, 0.040563676884630695, 0.031121265201363713, 0.054730570991523564, 0.05727750307414681, 0.010124463024112629, 0.011665761812764686, 0.03308779327198863, 0.03442498382355552, 0.07416633510729298, 0.026754368082038127, 0.06686284497845918, 0.03704604161612224, 0.024579730670666322, 0.028331710200291127, 0.013603190272988286, 0.07179902502684854, 0.05315206370141823, 0.03389101599168498, 0.04149227803281974, 0.06951602292247117, 0.0768714040168561, 0.031238227675203234, 0.05728342541260645, 0.04429994514794089, 0.04475505978916772, 0.09791628530365415, 0.026452931815583725, 0.04467023602046538, 0.038549142991541885, 0.046955475700087845, 0.08056338090682402, 0.012663987545238342, 0.0435434962855652, 0.0184087578963954, 0.04380630562081933, 0.04857029256527312, 0.0250575197787839, 0.05350708117475733, 0.05339375893527176, 0.029543950913648587, 0.03315802641736809, 0.03670070545922499, 0.028989635247853585, 0.08864761039149016, 0.04517811365076341, 0.08385254972381517, 0.008386337394767907, 0.012258933547855122, 0.013004389347770484, 0.009230803116224706, 0.08403419778915122, 0.04838402834138833, 0.01947483262483729, 0.008446209230896784, 0.10845451513887383, 0.034297571910428815, 0.02680538331333082, 0.017177277004520874, 0.016248375286522787, 0.04444881255039945, 0.06275732113863342, 0.07870447167078964, 0.04439380827534478, 0.10133646545000374, 0.02904996999859577, 0.0670506083406508, 0.06715177791193128, 0.05235196542344056, 0.0300116616563173, 0.014962084005674114, 0.05869661930773873, 0.08505509613314644, 0.04388471723359544, 0.055802454880904406, 0.09608265361748636, 0.03852543879474979, 0.03810475980571937, 0.0057129016022372525, 0.0313131957227597, 0.030025886771909427, 0.03512298113491852, 0.015438856371474685, 0.03750189840502571, 0.03241669139242731, 0.0693373211834114, 0.020931629551341757, 0.0747047335607931, 0.063746047380846, 0.032951145331026055, 0.051064851286355406, 0.021517876120924484, 0.017444168151996564, 0.003323984819871839, 0.03186780639225617, 0.030592813382099848, 0.02010100488405442, 0.06955033983103931, 0.008579899713367922, 0.022637448564637452, 0.028233752273081336, 0.01105353636376094, 0.02181408395699691, 0.04864741655183025, 0.027875831146957353, 0.020261112113075797, 0.08597581938374788, 0.03859879267110955, 0.057623907923698425, 0.0592759509163443, 0.04619574283424299, 0.05490270101290662, 0.03045482029847335, 0.02870508840715047, 0.03270964676630683, 0.036819987144554034, 0.030535291371052153, 0.05920384755881969, 0.10212192486505955, 0.06359606675687246, 0.10286478500347584, 0.06684423933620565, 0.10753379930974916, 0.061805487057426944, 0.012375537007756066, 0.05549043002247345, 0.0440713636635337, 0.04016520666482393, 0.0811925959715154, 0.022329800522129517, 0.0577339758456219, 0.04356499259301927, 0.00533388863914297, 0.032648861160851084, 0.018265938997501507, 0.13138842943590134, 0.039065392047632486, 0.0700057068024762, 0.07483947789296508, 0.06420108038582839, 0.037559303527814336, 0.013111071220919257, 0.01698242427664809, 0.029204507409303915, 0.030292226874735206, 0.02386430587648647, 0.1051829574862495, 0.061993035196792334, 0.018022330878011417, 0.03883994613715913, 0.04987136278941762, 0.010699201666284353, 0.024922632583184168, 0.02401775047474075, 0.050513439273345284, 0.06872870071674697, 0.015452096286026062, 0.04112359391001519, 0.030494844322674908, 0.02768787853710819, 0.09117671608692035, 0.04607002672855742, 0.024727978379814886, 0.0511759767687181, 0.020275318674976006, 0.0858038043952547, 0.015636402167729102, 0.026742890768218786, 0.03654003419796936, 0.046101278567221016, 0.0005096600602882972, 0.026999224864994176, 0.002649489238137903, 0.031985804162104614, 0.031555373352603056, 0.02119606790074613, 0.04732406705443282, 0.0416845684958389, 0.03032669221283868, 0.03424202215683181, 0.02447287624818273, 0.05005065082514193, 0.033406605070922524, 0.06597319545107894, 0.041331050160806626, 0.044390828552423045, 0.011702620577125344, 0.026123472052859142, 0.029336709885683376, 0.0706355601141695, 0.019694207767315675, 0.024136301144608296, 0.09884074155706912, 0.11714491600287147, 0.05761644562880974, 0.025646311914897524, 0.03890129206411075, 0.0687737342377659, 0.018699948814173695, 0.07259143836563453, 0.03379342357220594, 0.07886571067501791, 0.06815343236667104, 0.06343549568555318, 0.0254337404112448, 0.05662346688040998, 0.03327046550111845, 0.026768687821459025, 0.04028810260933824, 0.007941745479911333, 0.007765042437313241, 0.039617787406314164, 0.032238397834589705, 0.024863863764039706, 0.029753151211480144, 0.16260034055449069, 0.14043581817531958, 0.1587340925470926, 0.12621910369489342, 0.08348324219696224, 0.1496335066622123, 0.126705655711703, 0.19123587117064744, 0.09175268205581233, 0.1099207614606712, 0.08157210802892223, 0.07809959904989228, 0.11702382718794979, 0.1297380414325744, 0.10850541904801503, 0.11400436967960559, 0.24992642342112958, 0.10153175418963656, 0.17770401056623086, 0.1500927476445213, 0.08537217872799374, 0.09961895761080086, 0.16938454995397478, 0.16396103863371536, 0.1535356300882995, 0.23784154298482463, 0.09479372121859342, 0.11138576839584857, 0.13270289171487093, 0.17872769938549027, 0.17598644335521385, 0.1780983284697868, 0.20102123671676964, 0.167363325599581, 0.08083410895778798, 0.12646315153688192, 0.14167716406518593, 0.07582950289361179, 0.09020795361720957, 0.0786736948066391, 0.08747135827434249, 0.11163228016812354, 0.163577570929192, 0.15617890778230503, 0.18609860620927066, 0.16337664186721668, 0.25471823348198086, 0.158275474968832, 0.2403501357184723, 0.14329394762171432, 0.16701462009223178, 0.13254059886094183, 0.1566773490048945, 0.1424319579382427, 0.053608050366165116, 0.07894084570580162, 0.25606163952033967, 0.18584094737889245, 0.16367519303457811, 0.21681862184777856, 0.09819171114941128, 0.12697667320026085, 0.13147898629540578, 0.1410366757772863, 0.14713272132212296, 0.12283344825846143, 0.14894804422510788, 0.21996755443979055, 0.13593472220236436, 0.15126001235330477, 0.09524793043965474, 0.2083257064805366, 0.21631731593515724, 0.1730954516096972, 0.15338917466579005, 0.16447270492790267, 0.1989577544736676, 0.09267588407965377, 0.18468589842086658, 0.37939476838801056, 0.25184428144712, 0.20409867080161348, 0.12445717089576647, 0.16515116149093956, 0.14343194256071, 0.1305521180620417, 0.14389292016858235, 0.17490563885075971, 0.08320210181409493, 0.17691148590529338, 0.10314087878214195, 0.17018887476297095, 0.08039659063797444, 0.1341947866603732, 0.09313171860412695, 0.14516515424475074, 0.14364110946189612, 0.10401662046206184, 0.21053727687103674, 0.16119266452733427, 0.1477611274458468, 0.10107329988386482, 0.13004696782445535, 0.11348689236911014, 0.18709970405325294, 0.15077190182637423, 0.14198853954439983, 0.16467599401948974, 0.19417728442931548, 0.11385830017388798, 0.1241549535188824, 0.13446691737044603, 0.14038284367416054, 0.10549536455073394, 0.09249701164662838, 0.24613203015178442, 0.13777061743894592, 0.08627045943285339, 0.1078257082554046, 0.10966768168145791, 0.12565066310344264, 0.19074964569881558, 0.09062776429345831, 0.15235580824082717, 0.1689378364244476, 0.11574000818654895, 0.11435530905146152, 0.08400464546866715, 0.1840147445909679, 0.20266403997084126, 0.18198577221482992, 0.17304120061453432, 0.1381529273930937, 0.16249639535089955, 0.12657621031394228, 0.10178751312196255, 0.10890148099861108, 0.13384122750721872, 0.16534992348169908, 0.10026375035522506, 0.12024133422528394, 0.12096386693883687, 0.14935212879208848, 0.08598764179623686, 0.2675539447227493, 0.17026887828251347, 0.14535714784869924, 0.07259313046233729, 0.12282285781111568, 0.09727524782647379, 0.11551291841897182, 0.14024922740645707, 0.18806056265020743, 0.24971473321784288, 0.15104308258742094, 0.20743364497320727, 0.10053476042230614, 0.09127007084316574, 0.1821850982378237, 0.14597865199903026, 0.1765833972604014, 0.146276431332808, 0.17181345087010413, 0.1422112135333009, 0.12791854765964672, 0.1577448839088902, 0.11920711433049291, 0.12339140972471796, 0.24296804680489004, 0.09639737618272193, 0.13398121140198782, 0.12239554402185604, 0.0687450057012029, 0.13736044726101682, 0.2279004451702349, 0.14791599882300943], [0.07684162163059227, 0.02228756118711317, 0.043982832867186517, 0.025694037576613482, 0.06720844830852002, 0.03442914727202151, 0.06742945246514864, 0.01877438622614136, 0.03998197782493662, 0.032675062684575096, 0.02065560627670493, 0.018837711832020432, 0.05654358952597249, 0.03801952785579488, 0.05223876934906002, 0.03613954162574373, 0.017666177918727044, 0.055204324671649374, 0.05251455513644032, 0.017328244684904348, 0.044413642172003165, 0.024916476468206383, 0.03611588566855062, 0.028783475900127087, 0.01795641888747923, 0.012928540927532595, 0.03946595883462578, 0.04946564178681001, 0.04463770026632119, 0.054233064875006676, 0.042737137991935015, 0.055919094520504586, 0.03248229724704288, 0.10961887805024162, 0.05256199321593158, 0.042703329454525374, 0.09621489691198803, 0.03273798938607797, 0.0835144123993814, 0.05671043174515944, 0.03248611559683923, 0.019870432588504627, 0.05879003343579825, 0.04488385209697299, 0.08926770446123555, 0.03551090543624014, 0.10510189269552939, 0.04016273902379908, 0.01688310265308246, 0.024103526047838386, 0.011958833147218684, 0.047507492563454434, 0.06437619013013318, 0.07123832503566518, 0.031924651193548925, 0.009615538965590531, 0.05071906984085217, 0.00857491155329626, 0.03980303859862033, 0.0293030423563323, 0.0468864559661597, 0.018930450605694205, 0.038312672477331944, 0.036204004572937265, 0.044787833030568436, 0.039736044927849434, 0.049632595328148454, 0.0707989142392762, 0.058736160935950466, 0.07474224170437083, 0.05239164434897248, 0.01946014181157807, 0.03602998949645553, 0.0998218533641193, 0.06757084644050337, 0.035398406980675645, 0.02801051796268439, 0.00883885266375728, 0.052584561926778406, 0.04486123885726556, 0.0864732067566365, 0.057381849037483335, 0.035429632844170555, 0.09431115453480743, 0.05956912151305005, 0.03524674910295289, 0.040778777256491594, 0.035036910558119416, 0.05886915008886717, 0.06895478116348386, 0.05959885194897652, 0.052758499077754095, 0.0467719017615309, 0.07996341388206929, 0.013691172807739349, 0.007844962929084431, 0.03435703278228175, 0.024693047344044317, 0.03624199140176643, 0.019183170443284325, 0.02433474401186686, 0.07743991140159778, 0.05854277580510825, 0.0837472834973596, 0.009260415736207506, 0.0536210231075529, 0.009575875810696743, 0.024817305129545275, 0.062073057270026766, 0.04113797302125022, 0.07651911393622868, 0.02819277644448448, 0.01904491575260181, 0.013195082337915665, 0.01638714391447138, 0.006809539363530348, 0.1191591122187674, 0.11148479316034354, 0.03144814043480437, 0.08924275345634669, 0.025324316302430816, 0.011277225239609834, 0.02034506014751969, 0.09525486952043138, 0.03218935300537851, 0.008240670504164882, 0.015758715526317246, 0.04648785587050952, 0.0263302381063113, 0.04496494286286179, 0.0074239119385310914, 0.10453018665430136, 0.03827501590421889, 0.03944097443309147, 0.036892732459818944, 0.06584386879694648, 0.035215115058235824, 0.01664631116000237, 0.09423468363820575, 0.018022401382040698, 0.03891143722285051, 0.004775018041982548, 0.030284304448287003, 0.006453585856434074, 0.01657270680880174, 0.021327704489522148, 0.020818452030653134, 0.1061687151377555, 0.028914815629832447, 0.08834302556351759, 0.012413626809575362, 0.028611258676392026, 0.02106942225509556, 0.013554984998336295, 0.05044275341788307, 0.0075154679143452086, 0.07631529791979119, 0.02384931820415659, 0.039884841826278716, 0.02527180749893887, 0.052904687327099964, 0.06986195279750973, 0.06572122889338061, 0.02601607957330998, 0.08386608649743721, 0.038833545113448054, 0.05909138621063903, 0.018725508380157407, 0.06603002912015654, 0.026660503099265043, 0.07348505096160807, 0.028685026300081518, 0.010119347771251341, 0.05743309433455579, 0.043065623685834, 0.03261490048316773, 0.05101430731883738, 0.03631024301284924, 0.014601322309317766, 0.021543333641602658, 0.08542131632566452, 0.01185108907520771, 0.08160852521541528, 0.04674270567193162, 0.00887429670910933, 0.053556304119410925, 0.022187736758496612, 0.007922197310108459, 0.10022072805440985, 0.09468118936638348, 0.03231324713851791, 0.03511819799314253, 0.06109385649324395, 0.052210935100447387, 0.041772991680772975, 0.039844112761784345, 0.05769776274973992, 0.02197239147790242, 0.04205307821393944, 0.05401590504334308, 0.0400316905870568, 0.030555900812032633, 0.03701057066791691, 0.0619706668658182, 0.035973627091152593, 0.06276122483541258, 0.03316594142233953, 0.04646234825486317, 0.042828058503801, 0.05343511882529128, 0.04241476388415322, 0.0277553341948078, 0.1058251378708519, 0.012878970101155574, 0.026300811950932257, 0.03200057661160827, 0.017605761531740427, 0.04567229494568892, 0.030918412121536676, 0.0430885078094434, 0.013269159808260156, 0.019809342702501453, 0.020769496259163134, 0.014474499475909397, 0.05581032906775363, 0.06792556334403343, 0.018482015293557197, 0.07646799480426125, 0.023411319343722425, 0.05037506954977289, 0.03998808941105381, 0.03771084637264721, 0.02364547621255042, 0.030408096536120865, 0.05094068626931403, 0.02929494366981089, 0.05794647127913777, 0.03790313312492799, 0.030205111725081224, 0.025764510064618662, 0.050832499691750854, 0.03632299310993403, 0.01830210014304612, 0.053393829439301044, 0.03961825495935045, 0.02599334758997429, 0.02327064154087566, 0.0704083516029641, 0.06863290429464541, 0.03848429783829488, 0.026102166848431807, 0.01876653801446082, 0.10006722965044901, 0.03268375323386863, 0.03467954047664534, 0.01628083311516093, 0.07083649659762159, 0.06454003407270648, 0.031281665578717366, 0.03026665061042877, 0.025803791941143572, 0.06032895827956963, 0.07523729131207801, 0.01149600017015473, 0.05178003302717116, 0.03352367515617516, 0.0650584910181351, 0.07079996808897704, 0.033893672880367376, 0.04125250496144872, 0.0360918549267808, 0.06461174038122408, 0.07203887231298722, 0.004823760446015513, 0.018792327646224294, 0.039770840521669015, 0.02359526806685608, 0.11191976591362618, 0.04714523172879126, 0.04047178787004668, 0.026062181786983274, 0.06419198907678947, 0.07195324331405573, 0.03338159840495791, 0.06374857810442336, 0.056640491748112254, 0.081823488289956, 0.046490408858517185, 0.06954745287657715, 0.008939882154663792, 0.036546854535117745, 0.04124301660340279, 0.02691480185603723, 0.047937192357494496, 0.04837143780605402, 0.08331745382747613, 0.029532360422308557, 0.018343664123676717, 0.09268994035664946, 0.07502375316107646, 0.044641826607403345, 0.04196877394861076, 0.09650612308178097, 0.005863671221959521, 0.013445743643387686, 0.019539512650226243, 0.007232523648781353, 0.0823791119910311, 0.040917291698860936, 0.047575180142303, 0.014765572577744024, 0.06557099593919702, 0.041418827677262016, 0.0380695634521544, 0.053269790587364696, 0.02433921916235704, 0.06964819200220518, 0.06493284541647881, 0.02577961091446923, 0.03197673140675761, 0.033120996959041804, 0.033923462688107975, 0.017625819928070996, 0.08425400708802044, 0.050052862425218336, 0.03896159898431506, 0.018878147748182528, 0.03228709756513126, 0.03537368233082816, 0.008870572983141756, 0.016974626159935724, 0.01826818028348498, 0.05483413398906123, 0.037545013474300504, 0.08036096012801863, 0.024829031062836293, 0.03683274095237721, 0.03591265594877768, 0.04774479428306222, 0.03462371983914636, 0.05997601510898676, 0.039865961589384824, 0.03248074615839869, 0.011822545147879282, 0.012840391409554286, 0.02425258826406207, 0.061437103504431434, 0.016917202483455185, 0.02567406823800411, 0.014470975202129921, 0.05885856335225981, 0.03235342330299318, 0.20470562885748222, 0.16963037895038724, 0.08609814016381279, 0.15241745102684945, 0.205276548222173, 0.18654248473467305, 0.1272328180493787, 0.21812365885125473, 0.17902743798913434, 0.1520196598721668, 0.14527986058965325, 0.16535152652068064, 0.14082532696193084, 0.11831342751975171, 0.10905718358117156, 0.0868386476940941, 0.12907656520837918, 0.17588732211152092, 0.18716379592660815, 0.11393662643968128, 0.17160349729238078, 0.1400273252511397, 0.10458780699991621, 0.1379878440639004, 0.10758814678411, 0.10186376137426123, 0.18789770576404408, 0.23456252674805, 0.13016256474656984, 0.2306304353987798, 0.0913671289163176, 0.12722797924652696, 0.18348903686273843, 0.2451147831743583, 0.11475235805846751, 0.1125809081713669, 0.26974660519044846, 0.25687381625175476, 0.17768619902199134, 0.131267711694818, 0.27064959111157805, 0.11438172208727337, 0.14660204120445997, 0.11073553570895456, 0.1957109771319665, 0.0967295837472193, 0.2608777623390779, 0.09610154127585702, 0.08554293948691338, 0.1327688092715107, 0.08165388528141193, 0.12293983512790874, 0.21793000283651054, 0.12948468705872074, 0.07862244950956665, 0.12145916145527735, 0.14907808334100991, 0.09199911219184287, 0.136096584610641, 0.12501033808803186, 0.08923792949644849, 0.14272825297666714, 0.12067854826455005, 0.145658326218836, 0.1877688243985176, 0.1869749341858551, 0.2173244400182739, 0.13615730713354424, 0.1863049974781461, 0.14146102097583935, 0.1243111384974327, 0.13033138850005344, 0.32350965309888124, 0.24307788466103375, 0.18485675565898418, 0.16991500742733479, 0.12464321247534826, 0.10702560626668856, 0.10903385787969455, 0.15225517301587388, 0.1943615300115198, 0.12762557744281366, 0.1597055490128696, 0.135160053614527, 0.21648939029546455, 0.15040157013572752, 0.2106154101784341, 0.07580970981507562, 0.1365651618107222, 0.1432416113675572, 0.16401226166635752, 0.1327857153955847, 0.08207567749195732, 0.15968782652635127, 0.14437294128583744, 0.16168497561011463, 0.2147455362137407, 0.08306473027914762, 0.11055044407839887, 0.1862337364582345, 0.11900112382136285, 0.33577952126506716, 0.1693540476844646, 0.2212804730515927, 0.11944863887038082, 0.179173759825062, 0.22153223922941834, 0.1314732717582956, 0.11569556838367134, 0.24318528827279806, 0.1703214817098342, 0.19047862821025774, 0.15399335708934814, 0.11721392831532285, 0.15346245432738215, 0.18596944282762706, 0.27348958246875554, 0.1247051966493018, 0.250159606221132, 0.1434351337957196, 0.2382817107718438, 0.12790612410753965, 0.1693928916938603, 0.13209149561589584, 0.21270504570566118, 0.1265335813513957, 0.1615818022401072, 0.11042220095987432, 0.11942160985199735, 0.20336584449978545, 0.17170502309454605, 0.17258844600291923, 0.11318654520437121, 0.22110290679847822, 0.09479107917286456, 0.12559197406517342, 0.1449423169833608, 0.12665115238633007, 0.18540027493145317, 0.061305617200559936, 0.15670697554014623, 0.11277929166681133, 0.14264447934692726, 0.14094558457145467, 0.09703390882350504, 0.11034463910618797, 0.14172598253935575, 0.28882941871415824, 0.12305849711992778, 0.1576129300519824, 0.14536807226249948, 0.09223049899446778, 0.18292159074917436, 0.14199354161974043, 0.09012447684654035, 0.1317175867734477, 0.1982250320725143, 0.1538591322605498, 0.23225927143357694, 0.05581467805313878, 0.08284699899377301, 0.1322917122161016, 0.11560852930415422, 0.10624128975905478, 0.2178023089072667, 0.1413533798768185, 0.13837937149219215, 0.07754612757707946, 0.16244330210611224, 0.11429336940636858, 0.1434533906285651, 0.08126516317133792, 0.13639811921166256, 0.13807629322400317, 0.13399730116361752, 0.20586660015396774], [0.017689293963485397, 0.06205973571923096, 0.0549814725673059, 0.0593380538339261, 0.046448132416117005, 0.008447100735793356, 0.005785108860436594, 0.04528904988546856, 0.019374837502255104, 0.02379918056249153, 0.054365104078897275, 0.03301243188616354, 0.03459313964413013, 0.021173502900637686, 0.008996078504424077, 0.046185749815776944, 0.07565492007415742, 0.0168066280457424, 0.039305866448557936, 0.06962422805372626, 0.019610582567111123, 0.07436469633830711, 0.02851455497875577, 0.02345982240512967, 0.061616539969691075, 0.040460911695845425, 0.013765842140855966, 0.017386742620146833, 0.033221721241716295, 0.044353186822263524, 0.05508519141585566, 0.04998117467039265, 0.06630849777138792, 0.02342641462746542, 0.06277021224377677, 0.0822365825297311, 0.022925938064872753, 0.05081965682620648, 0.021391918817244004, 0.05542642349610105, 0.03263544313085731, 0.027016361054847948, 0.034425195335643366, 0.029864894531783648, 0.03733282603207044, 0.08791784915956669, 0.028085324593121186, 0.0295087137419614, 0.03260406883782707, 0.013486789976013824, 0.03652971834526397, 0.0431596389535116, 0.025056061458599288, 0.02819295084918849, 0.029367178758548107, 0.05842723825480789, 0.010236778725811746, 0.05481578438775614, 0.05429773191281129, 0.09286153974244371, 0.037941650589345954, 0.04074950695212465, 0.0751435877464246, 0.034128466140828095, 0.034518390530138277, 0.041350843239342794, 0.029029477445874363, 0.04631675001292024, 0.03450195195910055, 0.03337971334985923, 0.08007065422134474, 0.07291383473784663, 0.06637005892116576, 0.03357537687406875, 0.05922675765759777, 0.04396344054839574, 0.031019681882753503, 0.02046192985289963, 0.07924112607724965, 0.05523329440620728, 0.010156783555430593, 0.04474370121897664, 0.03643341355200391, 0.03977035441494081, 0.03231461640098132, 0.03425872047955636, 0.03444592723099049, 0.03537151154887397, 0.053910516362520866, 0.06613725461647846, 0.03520869177009445, 0.016811672794574406, 0.07043058634735644, 0.04348300011770334, 0.0437460914690746, 0.04102308856090531, 0.10650800279108807, 0.05379429603635799, 0.05942871459410526, 0.03879847492498811, 0.01879818875750061, 0.04652741605241317, 0.06115507996582892, 0.11207203235244378, 0.04879279586020857, 0.03681529677123763, 0.09303869781433605, 0.018975376515300013, 0.02853959689673502, 0.05275609823002014, 0.02520437596103875, 0.042908507311949506, 0.02912939278758131, 0.026394973792776, 0.050051541402353905, 0.09186483541270718, 0.011698956222971901, 0.030272611911641434, 0.04026652095490135, 0.041634146982687525, 0.02575091020844411, 0.09466623509069905, 0.075239198631607, 0.041910292711691, 0.060770959171350114, 0.06815813016146421, 0.02109099463268649, 0.03176585756591521, 0.01730295414745342, 0.05419671077106614, 0.009604115457477747, 0.044234573069843464, 0.01505069458289654, 0.06792824249714613, 0.05257485834590625, 0.010828906815731898, 0.012424220039974898, 0.02673822451470187, 0.0036117386662226636, 0.08108324793283828, 0.05502309220901225, 0.06892554054502398, 0.035753443007706665, 0.05070852021162864, 0.006313501307886327, 0.019251407211413607, 0.050988009315915406, 0.03380601781827863, 0.014339299650600879, 0.03775388722715434, 0.020303043456806336, 0.07309032487682998, 0.025458192321821116, 0.05162012246728409, 0.007815090557414806, 0.03719320950040128, 0.0655999916489236, 0.0812918359588366, 0.03182356696925126, 0.03138790030789096, 0.049137349051306956, 0.05426438721769955, 0.023963202620507218, 0.05567149550188333, 0.022303188961814158, 0.023352090393018443, 0.00829881591926096, 0.026887257045018487, 0.01501831560744904, 0.03478108483250253, 0.09198209474561736, 0.04219693611958064, 0.041212365904357284, 0.036788349389098585, 0.0102106291524251, 0.02818637171003502, 0.052665073817479424, 0.03861524608510081, 0.031084187503438443, 0.031688228918937966, 0.04920261351799127, 0.017286086986132432, 0.01993167090404313, 0.06793780135922134, 0.0037631646227964666, 0.021747320352005772, 0.024136907850333955, 0.03491087532893289, 0.046557610330637544, 0.011821116513601737, 0.01636925444472581, 0.05418799053586554, 0.05976955704682041, 0.06529936246806756, 0.027698190679075196, 0.025186493912769947, 0.043215930854785256, 0.04818602334125899, 0.07256216063979082, 0.02334355012862943, 0.0092366030003177, 0.020427303097676486, 0.019755683570110705, 0.026822747713595163, 0.027078105886175763, 0.08526331308530644, 0.04019888161565177, 0.011426104701968143, 0.010576758431852795, 0.04560248853522353, 0.0020754036859216285, 0.01356266808215878, 0.007527615944127319, 0.04979734469088726, 0.008313787820952712, 0.030529294817824848, 0.039149885560618713, 0.03691378718940541, 0.02093495066219475, 0.06216227826371323, 0.054851147724548355, 0.0228556585352635, 0.03718838925124146, 0.023927644469949882, 0.04858585169131402, 0.03327828031615354, 0.03451511394814588, 0.039025961741572246, 0.04545196243270766, 0.017370721507177223, 0.05694519160897471, 0.05924232420511544, 0.0651328319509048, 0.041109979210887104, 0.01881597432657145, 0.09728672142955475, 0.027107533896923997, 0.0786959815013688, 0.06652902695350349, 0.019740790521609597, 0.06513006374007091, 0.025776150650926866, 0.0616800974967191, 0.06750470623956062, 0.05115164545713924, 0.05358488793717697, 0.01795380096154986, 0.022015760732756462, 0.044479708158178255, 0.11101053110905923, 0.05468047602334991, 0.058515746786724776, 0.03401954483706504, 0.036205589058226906, 0.048791938679642044, 0.036667486929218285, 0.06470436041126959, 0.021303707144397777, 0.020356977183837444, 0.05221101673669182, 0.04698510223533958, 0.04215214379655663, 0.017953053247765638, 0.020779019869223703, 0.03397349457372911, 0.10931581462500617, 0.013509825312212342, 0.02510071648430312, 0.04837756794586312, 0.02101015063090017, 0.0640618015313521, 0.11543218017322943, 0.1069829921470955, 0.03224101761588827, 0.045075437519699335, 0.032377609895775095, 0.011130463681183755, 0.02841851550329011, 0.047932899033185095, 0.044301318121142685, 0.0606252904253779, 0.038355375654646195, 0.047947793937055394, 0.019946189167967532, 0.005688090213880059, 0.052021090014022775, 0.011679637191264192, 0.014449824921030086, 0.029587611461465713, 0.038505753327626735, 0.0771291964338161, 0.04617463986505754, 0.0607056947046658, 0.07693219333305024, 0.025573154707672074, 0.009046426730492385, 0.05168034775124397, 0.046372804426937364, 0.04672505740018096, 0.04314118545153178, 0.019227250304538757, 0.05791971314465627, 0.002509997480046877, 0.03185841822414659, 0.0227209420336294, 0.048953426303341985, 0.042536142136668786, 0.020579413685481995, 0.038292430399451405, 0.022978637971391436, 0.04559086279186886, 0.03557338684913702, 0.025646612484706566, 0.03080321224842919, 0.05938826383498963, 0.035507461871020496, 0.03935390937840566, 0.06845458105090074, 0.043321816774550825, 0.02693798283871729, 0.0545953813707456, 0.013041275942669017, 0.029334587343328167, 0.02739737967203837, 0.048478399839950725, 0.07269258567248471, 0.05914073160965927, 0.025252112754969858, 0.030932082481740508, 0.043319360265741125, 0.05478189421410207, 0.032068178843474016, 0.007332750692512491, 0.09272321083699353, 0.030835037396172993, 0.04469712032005191, 0.06635590616497211, 0.009824753178691026, 0.00777180618570128, 0.029433526760840323, 0.061270179649000056, 0.00904431439266773, 0.016583234173594974, 0.01702773239230737, 0.013843288033967838, 0.03791582385019865, 0.014509627180814277, 0.02274265727464808, 0.03792323790548835, 0.05682688584784046, 0.045977120971656404, 0.018694061727728695, 0.10086614420288242, 0.1281680428655818, 0.10706656539696269, 0.14830782311037183, 0.13206143863499165, 0.04989219858543947, 0.1180994143942371, 0.17442113516153768, 0.29109160357620567, 0.12116425423300825, 0.09452969476114959, 0.10536994159338064, 0.16847602761117741, 0.10531837717280723, 0.06152475114504341, 0.2148973202565685, 0.16899351234314963, 0.18442706699715927, 0.11971141109825112, 0.09451756064663641, 0.15954940114170313, 0.12100056614144705, 0.14574658242054284, 0.059912928845733404, 0.14525005593895912, 0.09252152478438802, 0.10607936055748723, 0.0748313959047664, 0.1446475210832432, 0.1834688356029801, 0.16037530760513619, 0.0985751640109811, 0.15211909281788394, 0.16533229005290195, 0.11198500069440342, 0.14121960033662617, 0.11543488159077242, 0.14092539815464988, 0.07453507860191166, 0.15875344775849953, 0.15624682913767174, 0.13388884370215237, 0.12346018454991281, 0.13527668954338878, 0.14007264078827575, 0.28353360132314265, 0.11904295868589543, 0.059249678888591006, 0.17327289911918342, 0.18608162587042898, 0.1500631804810837, 0.1453677160316147, 0.12682695232797414, 0.10911723074968904, 0.1499577212962322, 0.1039265311555937, 0.20888576080324128, 0.2226691649411805, 0.08474639238556847, 0.2055787804420106, 0.19358660909347236, 0.16562858509132639, 0.18765977321891114, 0.15121294534765184, 0.13090852706227452, 0.09143738061538897, 0.17476234497735277, 0.14247482438804582, 0.1528213723213412, 0.14771305111935362, 0.14419353450648487, 0.11539752187673002, 0.22996659914497286, 0.20069080288521945, 0.1371629914501682, 0.1798066039918922, 0.10789021573145874, 0.16219055629335344, 0.14733474876265973, 0.08867321448633447, 0.12128958071116358, 0.18269430060172454, 0.1551616459619254, 0.12543797842226923, 0.20784190041013062, 0.1482541806763038, 0.08237938658567145, 0.10799931886140257, 0.12898585991933942, 0.14334723382489756, 0.12366286508040503, 0.11818253493402153, 0.18318929825909436, 0.13628932036226615, 0.18005344230914488, 0.304043535143137, 0.21185783960390836, 0.13887019827961922, 0.17521064670290798, 0.11969675368163735, 0.08465809165500104, 0.10952315584290773, 0.1426268310751766, 0.22814550233306363, 0.19710041116923094, 0.09936511341948062, 0.23805486591299996, 0.14621435810113326, 0.07042980709229596, 0.1617080415599048, 0.16326306358678266, 0.16683500551152974, 0.11222751971217804, 0.14090095181018114, 0.1084719407663215, 0.15190520585747436, 0.14097794221015647, 0.19198220456019044, 0.10725400221417658, 0.14943881164072081, 0.13867219327948987, 0.13937289942987263, 0.14717579557327554, 0.1324384644976817, 0.08214593661250547, 0.13597202254459262, 0.1286031788913533, 0.07923570839921013, 0.13659176038345322, 0.24144974624505267, 0.1673747695167549, 0.17860061401734129, 0.07368426566245034, 0.12681632477324456, 0.13304542255355045, 0.15628454508259892, 0.11346280967700295, 0.2069715689867735, 0.12225115919136442, 0.11776043102145195, 0.12077772145858034, 0.16413001081673428, 0.14581328665371984, 0.20430672448128462, 0.16853676497703418, 0.11212668410735205, 0.1292223675409332, 0.15586536523187533, 0.06421251688152552, 0.14311942417407408, 0.13593308947747573, 0.1000229679630138, 0.1345809706253931, 0.09736420164699666, 0.19830662378808483, 0.1703570008976385, 0.09131612110650167, 0.14870638609863818, 0.09843636755249463, 0.14491659414488822, 0.1840677933068946, 0.12894130137283355, 0.20733544399263337, 0.1437009562505409, 0.12611880985787138, 0.16124467423651367, 0.12989325419766828, 0.1610053316107951, 0.1275564538082108, 0.10020302783232182, 0.140294038283173, 0.09494752390310168, 0.11672658220049925, 0.15983631543349475, 0.1252599520375952, 0.19563619833206758], [0.02633178919495549, 0.03723065085068811, 0.03748273244127631, 0.02648710214998573, 0.05307038292812649, 0.0343582610366866, 0.07623076729942113, 0.013982360942463856, 0.02599714553070953, 0.06463039055233821, 0.028417226021701936, 0.03347090103488881, 0.050618579334695823, 0.0670617850846611, 0.02781687679089373, 0.05330603336915374, 0.02523839229979785, 0.04206396552035585, 0.047094643232412636, 0.008778139417700004, 0.03944026568206027, 0.05180660562473349, 0.12325701420195401, 0.009954975048458437, 0.00809560939160292, 0.04666477645514533, 0.04565303992421832, 0.013326259722816758, 0.08287352335173637, 0.022411598183680326, 0.027045720416936092, 0.03457877908658702, 0.029274304542923346, 0.021895479003433138, 0.028267284360481426, 0.03277317089668941, 0.02010557465837337, 0.01199412783535081, 0.04920746345305815, 0.04789341677678749, 0.008085597819444956, 0.005146408220753074, 0.05527609035198111, 0.10495114023797214, 0.024579743658250663, 0.021940193400951102, 0.06124771854956634, 0.015338079210778233, 0.06933798911632039, 0.03545924824720714, 0.025434955678065307, 0.017507490047137253, 0.027130091475555673, 0.04312948549340945, 0.05764397188613657, 0.04659148937207647, 0.040259604138555005, 0.06236334462300874, 0.0629498268244788, 0.05480079671542626, 0.04106274151126854, 0.011483002381282859, 0.0408208273438504, 0.04700341472926084, 0.023167646286310628, 0.019716106689884327, 0.017614023490750697, 0.06232284562429413, 0.011847256810142426, 0.04569720884319395, 0.026446759002283216, 0.08664679509820417, 0.04891706477792468, 0.0298040198686067, 0.03198675411113072, 0.02451346615998773, 0.03464455563516822, 0.11466297379229218, 0.0586381529137725, 0.04424669605214149, 0.02565196522482438, 0.012575862147059524, 0.005760582271250314, 0.013461751768772956, 0.03582864854251966, 0.04466420978133101, 0.0346670018916484, 0.028228037735971157, 0.03957643493777141, 0.024086020639515482, 0.020420772198121995, 0.024112151659210213, 0.03678991903143469, 0.026851589427678846, 0.007951693969516782, 0.04580954773700796, 0.06277789347223006, 0.07176380269811489, 0.029394465673249215, 0.06543619965668768, 0.03305632621049881, 0.04121875208511483, 0.04006657523859758, 0.06702792830765247, 0.07202520937426016, 0.04934938806400169, 0.03196648234734312, 0.028947312421223614, 0.028007859218632802, 0.049277867292403243, 0.04633970464055892, 0.005349054890757543, 0.02551543973822845, 0.03914081651601009, 0.04985298350220546, 0.016739142702135723, 0.03578429779736325, 0.028052080087945797, 0.033613137347856537, 0.004890247137154802, 0.04128509637666866, 0.05227090063272044, 0.06453467576648109, 0.04105866712052375, 0.03217380872229114, 0.011209446747670881, 0.05552396767598111, 0.06967692053876817, 0.04360186620033346, 0.03659964721009601, 0.0314154896477703, 0.008518985159753356, 0.038057258643675596, 0.03254648559959605, 0.07982764538610354, 0.010043346283055143, 0.042844793933909386, 0.026527270892984234, 0.027114001713925973, 0.12016910099191591, 0.04477032205613796, 0.029953211960673798, 0.060777215476264246, 0.007820191895007156, 0.03748158582311589, 0.025621218046580907, 0.018414606020087376, 0.06193080611410551, 0.04925867906422354, 0.028496522645582445, 0.006903198864165461, 0.0227395550973597, 0.01695579972874839, 0.016282102187687997, 0.03691692647407763, 0.012451403054001275, 0.025220597453881055, 0.03397906810278073, 0.05812038616568316, 0.011479943805170478, 0.02433773857774213, 0.03844990671495907, 0.05367122939787805, 0.032046315172920004, 0.0677472104143817, 0.04548091732431203, 0.0919696266646497, 0.026286317806807347, 0.060389725331333466, 0.04738945768622216, 0.006356191033773939, 0.027141745049448218, 0.029542435077019036, 0.027226399979554117, 0.06337366736261174, 0.018999015774170402, 0.0611445934191579, 0.0895029133243952, 0.025506277925160248, 0.053156958165345713, 0.02809779081871966, 0.031181605518213473, 0.09281508871936239, 0.024604956270195544, 0.04446289109182544, 0.03774051372602116, 0.020933852283633314, 0.04556657229841221, 0.06288707081694156, 0.03542880906024948, 0.028872947368654422, 0.05614113026240375, 0.045596907584695145, 0.038259482753346674, 0.07368623235379346, 0.018614362488733605, 0.03302694829471875, 0.06417814060114324, 0.03687738484586589, 0.056104264076566324, 0.01947368600667687, 0.013246405560494168, 0.059454025540617295, 0.021995466704538558, 0.04293396297725849, 0.008312924146594014, 0.023929624148877338, 0.015077451789693441, 0.025835615233518183, 0.025738219483173452, 0.009449105855310336, 0.031794756796443835, 0.018149098978028633, 0.020206577246426605, 0.06164454862300772, 0.015774513994983863, 0.01322670988884056, 0.012773381040460663, 0.04837264379602857, 0.010690470298868604, 0.0341649835172575, 0.05508135822310578, 0.07116140142898075, 0.03983465408964548, 0.052524128841469064, 0.02454810219205683, 0.05710169571102597, 0.04318922838137951, 0.017402233097527642, 0.031512339919572696, 0.0227187285781838, 0.13070013199467212, 0.05474340643559117, 0.055724982084939256, 0.06827626522863284, 0.04198757254926022, 0.010124870277650189, 0.010153869698115159, 0.09547966605168767, 0.016948817974480335, 0.05714320403058082, 0.017608808047953062, 0.052717818252858706, 0.022014126152498648, 0.021649013615387958, 0.08933660545153543, 0.027700268692569807, 0.12336589468759485, 0.05091421386168804, 0.03352529303811025, 0.009209324434777955, 0.020037332324136514, 0.00659773412735376, 0.024662608157086652, 0.06749886553734541, 0.011792616187449312, 0.02216460958152311, 0.02677290693100076, 0.06800909948651679, 0.08087475638603792, 0.08171034045517445, 0.06330492964480072, 0.06267122458666563, 0.04883882756985258, 0.01980246670427732, 0.061006557662039995, 0.024016824645514134, 0.030301253245852422, 0.04063192107423674, 0.01524178833278711, 0.011492359935800778, 0.01581934713613009, 0.06381208368111402, 0.06744855534634553, 0.023342731910815928, 0.036998655486968346, 0.01796741194993956, 0.06656395242316648, 0.019450967010925524, 0.015530519958701916, 0.04923513071844354, 0.015345773426815867, 0.06211662133864593, 0.041868138723657466, 0.02704910275497241, 0.042666344525059685, 0.0630728823307436, 0.03922146570403129, 0.06809671001974493, 0.035752949479501694, 0.06388396068359725, 0.03801912709604949, 0.03453438010183163, 0.05314847170666326, 0.08029392192838714, 0.020560238444886636, 0.005381380060498486, 0.00821253011963563, 0.01817614469473483, 0.05062913638539612, 0.07653391236090101, 0.12348048971034586, 0.011768639251386048, 0.012709623133559944, 0.026716813554230612, 0.06273593244259246, 0.05287241503538098, 0.008934845754993148, 0.02670588728506118, 0.03989965880464297, 0.03095573472819524, 0.018609484723128844, 0.025299871813331265, 0.07877675685449503, 0.016663026181049645, 0.040113768409355544, 0.0535756964382017, 0.039514999953098595, 0.020656394808611367, 0.013402745462371968, 0.0922286584682297, 0.016506280881003477, 0.0335035926400451, 0.039002995981718414, 0.05937736168561969, 0.017711048167257104, 0.011047099160350626, 0.015917735508992337, 0.03095284591836389, 0.07890885171946138, 0.04144190104852896, 0.030280979626695625, 0.05438615509774536, 0.04158412994001992, 0.04000244625785854, 0.007801404426572844, 0.01491327759140404, 0.018206986496807076, 0.011923493930225959, 0.07645948979188688, 0.07744664268102497, 0.038086866625235416, 0.06982622580835596, 0.03448431110882666, 0.03754450139240362, 0.03273794485721737, 0.016072183861979283, 0.02841444111254532, 0.04081723905983381, 0.04223011012072675, 0.05856425726960879, 0.1329601794714108, 0.16252381028607488, 0.16627168573904783, 0.1315342466114089, 0.10278678528266028, 0.16835602233186364, 0.1341243865317665, 0.14605712669435889, 0.06464515186962672, 0.18863712233724073, 0.1094856031704694, 0.06922432177816518, 0.09408339683432132, 0.10999335834640078, 0.17677406984148547, 0.1097831895458512, 0.09637058465159498, 0.13391144952038303, 0.1465399531298317, 0.21454925299622118, 0.1030685639125295, 0.14505119004752487, 0.15266707981936634, 0.3045761300018057, 0.10261771662044339, 0.08548551209969446, 0.08799457980785519, 0.12608119781361893, 0.1522776749334298, 0.10889895769651048, 0.11822895627119578, 0.0818374555092305, 0.1433124567847699, 0.08578166613006033, 0.10654597106622532, 0.0767934785108082, 0.1119785217451863, 0.07727090211119503, 0.1076017577724997, 0.17396159732015803, 0.1424908547778614, 0.07955942579428665, 0.12630897777853534, 0.1332393308985047, 0.2363356511341408, 0.08040672837523744, 0.15620365098584443, 0.14358623506268486, 0.10672885851818137, 0.13359522039536387, 0.14876771718263626, 0.19306274189148098, 0.14330874604638666, 0.1366283037350513, 0.09004658102639951, 0.1979406113969162, 0.21351512958062813, 0.1289780525257811, 0.1431414214312099, 0.24979574605822563, 0.10201023906120099, 0.08719556877622381, 0.11641024175332859, 0.26792145625222474, 0.09059164396603592, 0.20737454033223912, 0.0676891150942538, 0.15835889236768708, 0.1635124400490895, 0.20078417990589514, 0.1659488069708459, 0.10175117015023716, 0.17401672404957935, 0.20741466083563864, 0.14504810271319002, 0.13485635194228962, 0.0982179534912575, 0.1817696142825298, 0.18553038826212287, 0.15164530574111268, 0.10293616476701573, 0.10119670419953763, 0.10474526105099358, 0.19960040983278304, 0.20806703832931817, 0.23689619527431205, 0.18569128587841988, 0.16951978410361335, 0.17362660670187324, 0.05922747754084412, 0.17324364365777, 0.06839489011326805, 0.1141266236663796, 0.177185338397976, 0.18767152883810923, 0.20749369956320152, 0.17095493443775922, 0.12353416925179772, 0.09688957594335079, 0.09430541031179018, 0.2026652274071239, 0.0813438234035857, 0.13237895909696817, 0.1625474847969599, 0.1461193335126154, 0.1806288442458026, 0.10042474445072003, 0.16764118568971753, 0.08863391034537926, 0.10871549879084341, 0.10761650424683467, 0.1686637316015549, 0.21616315701976418, 0.12774516711942852, 0.1420068260631524, 0.10620904344250448, 0.21352991316234693, 0.09812170435907319, 0.26455736020579934, 0.10870354279177263, 0.0652987539069727, 0.1488111328217201, 0.21357764810090885, 0.13390230626100674, 0.21715505223255605, 0.11078498500864953, 0.13267341360915452, 0.1282141005503945, 0.113689075660659, 0.18173835502238944, 0.12769571039825678, 0.18943890900118276, 0.05620780852041207, 0.21493588224984705, 0.10994782016496174, 0.17400569573510438, 0.1294088247232139, 0.18510984285967425, 0.19440965086687356, 0.1165684824809432, 0.2322058071149513, 0.15673234214773402, 0.14925490744644776, 0.18429198127705604, 0.12042957256198861, 0.15234172227792442, 0.13956725306343287, 0.14743428560905159, 0.1215937796223443, 0.14993708959082142, 0.10631713725160807, 0.10278699308400974, 0.13754944258835167, 0.10000271475291811, 0.18809694272931665, 0.15798823413206264, 0.07670423525269143, 0.11744780131266452, 0.13222422130638734, 0.15985360747436062, 0.18792185524944216, 0.08705584463314153, 0.10596555963275023, 0.12397609592881054, 0.1809724883059971, 0.11772982485126704, 0.12106953392503783, 0.3067686123540625, 0.16361507907276973, 0.12455584685085341, 0.12078580344677903, 0.11449544879724272, 0.07730409837677144, 0.21562898880802095, 0.11278378166025504, 0.22125175193650648, 0.20838396507315338], [0.024380078102694824, 0.02421323773887707, 0.026862345002882648, 0.05013829104427714, 0.04889071853540372, 0.0387332772515947, 0.01803139992262004, 0.005922679847571999, 0.05306520644808188, 0.025302395115431864, 0.03148593801597599, 0.03957465749408584, 0.021719436008424964, 0.02974230286781676, 0.06383844476658851, 0.02884464371163631, 0.04502895309997257, 0.004932880738124368, 0.04037618811707944, 0.018294635992788244, 0.08861320442520082, 0.01952639147930313, 0.0342664128402248, 0.04276275692973286, 0.004444149590199231, 0.026211425829387736, 0.0684104158426635, 0.033039980407920666, 0.04153604990278836, 0.041499295039102435, 0.06938932347111404, 0.00995834068817203, 0.10457640019012615, 0.05045666497608181, 0.011274863354628906, 0.05631500433082692, 0.031701001280453056, 0.09666623402154073, 0.03099924128036946, 0.04163865181908477, 0.036612426993087865, 0.030574356169381645, 0.01464849785406841, 0.039839993842178956, 0.021870650452910922, 0.03765447654586751, 0.036864857393084094, 0.019357977762410883, 0.04092780793143902, 0.045398709626169875, 0.012602880960912444, 0.02677476230019238, 0.021069451941002626, 0.029633112535520922, 0.01862947261543013, 0.0352816263330169, 0.0500475152512081, 0.12368416471872479, 0.03127867472358048, 0.05618205599603243, 0.06093724106904119, 0.05076928355265409, 0.06660126018687151, 0.0243713411691715, 0.05118678243889008, 0.0397328870894853, 0.042712190697784536, 0.08827153447782621, 0.02375801734160632, 0.02500163234799402, 0.011594669631449506, 0.037652773316949606, 0.09215921571012586, 0.09662118565756828, 0.08867247976013459, 0.030393442830245476, 0.09760664645000361, 0.031782466830918565, 0.011127491379738785, 0.03889233063091524, 0.04248449607985094, 0.10925634633167647, 0.039363657488138415, 0.07666346165933646, 0.05325247999280691, 0.03430838871281594, 0.03145021844829898, 0.005794899643660756, 0.042285210874979384, 0.055149758263723925, 0.03927620280592237, 0.058953647312591784, 0.03802953571721446, 0.03352747866301797, 0.028252385745872743, 0.008343111931026215, 0.15080222598044202, 0.015973346489772666, 0.04883916524704546, 0.05281278346956242, 0.06744130456354469, 0.05306131388351787, 0.029448564528138377, 0.02493642910849303, 0.1486154433223419, 0.03961638103646692, 0.01210027257911861, 0.05036460155679379, 0.02458849729009671, 0.025378099744557403, 0.06022903551638592, 0.03256115785916336, 0.03935194639780093, 0.033685511589283124, 0.011332111698720837, 0.028588467321242206, 0.06911600532475859, 0.02755132893071277, 0.029947825823910534, 0.06921905252966098, 0.01726213416986866, 0.01584471745445626, 0.020084421594219748, 0.007649789686183794, 0.052154483637423255, 0.02928384670667583, 0.025718509896250907, 0.045580966252600774, 0.019228272612963337, 0.05111951417347882, 0.031075927399797365, 0.03129855314909946, 0.01777804925950477, 0.060143592054373585, 0.030969763174653053, 0.0024939508557508816, 0.025111108407145366, 0.036202431219862774, 0.037104470902704634, 0.03581289274734445, 0.050465310996514745, 0.03058238249650458, 0.01776102068106411, 0.023014865910226945, 0.03232954099075869, 0.02863145065930439, 0.06375566561473534, 0.03100377209193539, 0.019479934890114237, 0.036159019291517325, 0.02538635799282929, 0.03403892231290229, 0.03245016225264408, 0.026175390848948155, 0.0061146205734985415, 0.04115337258554064, 0.033284814926446415, 0.03186172449204605, 0.05585924402112141, 0.008773018598731142, 0.020655712032748852, 0.01933793606440304, 0.01261644185433397, 0.03875725233228877, 0.02542103855375899, 0.04713512367743533, 0.04566158204397652, 0.026164648261328693, 0.05537261407880578, 0.061960410384926945, 0.028867192013422027, 0.031224126869346946, 0.033292937732767314, 0.023406450854963623, 0.04220364513457753, 0.058980813628295437, 0.02895230893045664, 0.08020193272386678, 0.03183804998116102, 0.06394834941602312, 0.07721114438027143, 0.06352818250888959, 0.05943161639152095, 0.03305192898551468, 0.03693884580570739, 0.041086994897341356, 0.03881443110003602, 0.04601888904289808, 0.06634349003434181, 0.0327667327655945, 0.04747383987705689, 0.053016265519545414, 0.04333167620643508, 0.047970047235139646, 0.08407551315031014, 0.025024926508194767, 0.061557027147500776, 0.03534396302711684, 0.04582398622005712, 0.031228553780238144, 0.03318845818284899, 0.013617658441944513, 0.07641588861588389, 0.026031792694993783, 0.07517079488025047, 0.06419931407435797, 0.08637454564450309, 0.03437062521697953, 0.07217432910692878, 0.03873215660860296, 0.018587168342492077, 0.03855269416817464, 0.024409845646005124, 0.05716311585274525, 0.024288821769005153, 0.05443780857603997, 0.022240536854951642, 0.027596952459134627, 0.017123751458711922, 0.03157513674523216, 0.023596086284669582, 0.057554732338758186, 0.014969334788474953, 0.06660515646217391, 0.007166869090724504, 0.01715161168249324, 0.03395073290448636, 0.04334797748015262, 0.029089832605677657, 0.06780031108064577, 0.06413851733668707, 0.11245031244470738, 0.05332378554157913, 0.05590856715571135, 0.05405706826422829, 0.03749241746845655, 0.0329711647646036, 0.14989184826845303, 0.03562549303751439, 0.026256045603076927, 0.015833147372177336, 0.009453428865526803, 0.05512170508154668, 0.045066119855619036, 0.08235669913119636, 0.0616167997213779, 0.0327937766269315, 0.028418407891876996, 0.034694346322794445, 0.021046946312708315, 0.04737348666822072, 0.051098381518386304, 0.051366330226301216, 0.09591696914867498, 0.05826119755511172, 0.08067729315371253, 0.03530022455379367, 0.0684510038990993, 0.023523313138866797, 0.04830919759115204, 0.09240466621122323, 0.006907500073793926, 0.09033232272486202, 0.02328394268261036, 0.03589475905755535, 0.059764836987596937, 0.037025202109362, 0.07755046914098784, 0.021531082638830412, 0.044145396605017595, 0.043546223678276874, 0.0172538480910589, 0.07335695627261885, 0.09738562745042145, 0.044314424449112266, 0.028728952165693045, 0.06567111908225343, 0.048696899248170666, 0.043599276104941964, 0.02484913398802746, 0.034455089044058695, 0.015714713590568863, 0.04303626061300747, 0.02187398826208664, 0.05639518225507345, 0.03953869301767554, 0.049785396113293245, 0.018152501725126058, 0.07740126035059802, 0.04805836651939899, 0.05058761693362612, 0.03239804493205156, 0.039348933278233744, 0.05989198914903682, 0.1011957171431277, 0.11564583706785925, 0.02565024344221456, 0.039265619780053385, 0.022864972488605417, 0.03881368895235937, 0.033148630827781744, 0.027238897746428847, 0.14126690482953563, 0.015601062950736377, 0.00731410701519053, 0.05901801378058735, 0.082826374709839, 0.05208282185776625, 0.0391832413879456, 0.03579737815016415, 0.004805100534213125, 0.056744429530226626, 0.06940653387573548, 0.012058193733537337, 0.011378584058547858, 0.022855580609757453, 0.06552280829055235, 0.05507024827238638, 0.04258113483956549, 0.05539075216802303, 0.01974671471543843, 0.03899155948602129, 0.017361461359541863, 0.026811793613887858, 0.09461164270760491, 0.05082455500087235, 0.04022215165605303, 0.05391399703512434, 0.023666825945838355, 0.04092818642675411, 0.05127885327965487, 0.06526471901452169, 0.017578162915015128, 0.010800958461913979, 0.0660873600281775, 0.04189772815152537, 0.034818377753254026, 0.022241919104999397, 0.0386786997114541, 0.03994753475126345, 0.026948307968268637, 0.05061784460849594, 0.04378351055493113, 0.026356883063272107, 0.018903159980254713, 0.0660686801711563, 0.021125714156369213, 0.03419296248466708, 0.022295327762549277, 0.05246880915365182, 0.04622032276529353, 0.02725030826695729, 0.13939464435679838, 0.18058807065244764, 0.19852033263305202, 0.15208927332423627, 0.15679861593525857, 0.1487295114202425, 0.12727764376904815, 0.09061766366357915, 0.1414877234492451, 0.21373850118834525, 0.1672288335976191, 0.22555844974704087, 0.10652679397026077, 0.13028338638832793, 0.17266386304982007, 0.11643817619187757, 0.1441711958614178, 0.14961207343731076, 0.1262431195937097, 0.07100154281943105, 0.1267242687754333, 0.11407242462155409, 0.09034024886204861, 0.13349534216104075, 0.13216021849075332, 0.17354409472318366, 0.16295786277623847, 0.1285118205123581, 0.23269699013326317, 0.12989426351850852, 0.17701881530229002, 0.06349591392790899, 0.18063797266222537, 0.12025591742713004, 0.16249269945546985, 0.1220499406917952, 0.0800720791448839, 0.24261747108539566, 0.15893787145614624, 0.2432515620603226, 0.17236796877114102, 0.12769910943461582, 0.07056933827698231, 0.10259015325573273, 0.13951041939435527, 0.17067232460249215, 0.2083435477106832, 0.1996230156510137, 0.19242045760620385, 0.09364009718410671, 0.11744496630853973, 0.1436305561219342, 0.15829201001906767, 0.14164108084514737, 0.09936575166648254, 0.20819827972445637, 0.16624691284960136, 0.1911164150806144, 0.1270974354702048, 0.23972091323230416, 0.1728140440536663, 0.23771441308781505, 0.21875363832805306, 0.2147622939082794, 0.18140646658139303, 0.2293267342611216, 0.1346334849949926, 0.1882179276435636, 0.13546840113122016, 0.1007999075227417, 0.1996354985749349, 0.1615408356883563, 0.10535253823036328, 0.20160118059720844, 0.21595811645966023, 0.09629540509195067, 0.1486385241150856, 0.14018721354659647, 0.22389911144273356, 0.12049332304741256, 0.1712022625724785, 0.1581955308211036, 0.10804278645082377, 0.17806551069952548, 0.1434856146806851, 0.07874273680499755, 0.14390472031664103, 0.07384060649201274, 0.2184122207108885, 0.1404975648620166, 0.11727280289051123, 0.2045824026572518, 0.21786751400213689, 0.11904992003110237, 0.15865282737649977, 0.09863248749752529, 0.3236622386611998, 0.13658493262482807, 0.15639655000995845, 0.12228402149048634, 0.16013137850677595, 0.12927687086630613, 0.21787453471915796, 0.1355946107651107, 0.2870300371432677, 0.21819604793563485, 0.1077762663771864, 0.08917609375203028, 0.1274256280157715, 0.09307576066930778, 0.16145750734722242, 0.15025305154267699, 0.1784913698793389, 0.13290894159581512, 0.1681541433208622, 0.11152278369991109, 0.19279620697489008, 0.15109702188055962, 0.2637695556040853, 0.14277735346695408, 0.20174435572698712, 0.07317571638850495, 0.128612277621869, 0.15380231343442574, 0.1384212583070621, 0.10670151037629694, 0.19127167237456888, 0.1584959076717496, 0.054865712372702546, 0.23889796051662415, 0.18013803230132908, 0.1474899021559395, 0.10034219536464661, 0.13882541708881035, 0.09354936220915988, 0.11823607346741483, 0.17428705876227468, 0.14185609587002546, 0.09951643733074889, 0.13297818397404626, 0.14592929917853326, 0.16331115475622937, 0.124192973744357, 0.12662131804972887, 0.08249755133874714, 0.10193665511906147, 0.2741577825509012, 0.19144405843690038, 0.19041236926568672, 0.2211244884529151, 0.1367957322509028, 0.09489658288657665, 0.10490155735169537, 0.21813226776430383, 0.1517251756740734, 0.15804016962647438, 0.0927233295806218, 0.16800396231701598, 0.17338990612188354, 0.1593359891558066, 0.1629009548923932, 0.1285961878602393, 0.1279870033613406, 0.21158026152988896, 0.0712376125738956, 0.10614898143103346, 0.15427575912326574, 0.05546641783439554, 0.17829418124165386, 0.2515975321875885, 0.09004873325466178, 0.2363203332060948, 0.06841759241069667, 0.15075955248903483, 0.13115956593537703, 0.1922023404040374], [0.08542024021153338, 0.045080521231284365, 0.0487185810925439, 0.06537172186654061, 0.05563080354477279, 0.027559358968574088, 0.05778520258900244, 0.05558904289500788, 0.061257507477421314, 0.04691200068918988, 0.04888747163931839, 0.022871212095196825, 0.049175862804986537, 0.039317388291237876, 0.012127376739954343, 0.055822615322540514, 0.0020549387318169465, 0.03700511959323194, 0.05459445368614979, 0.022491466261271853, 0.027415974182076752, 0.04362640902400017, 0.0037219696287138504, 0.017035079654306173, 0.018197217978013214, 0.020406587900652084, 0.06573475824552588, 0.04006738046882674, 0.1273529717582278, 0.05558080876653548, 0.050394736463204026, 0.06435543968109414, 0.07755412792903371, 0.03970835910877213, 0.023433901042153593, 0.04222157542244531, 0.03721675784618128, 0.023016563573037274, 0.042604293557815254, 0.03795392571191769, 0.056171684482251294, 0.03679277629998978, 0.014214478760550264, 0.07717625601799227, 0.06655051212874241, 0.040468403676641174, 0.02690074372367235, 0.03869753913022578, 0.052191950962878764, 0.041974885534727946, 0.029470045992638916, 0.044317600841168314, 0.05824652158480603, 0.04474921166547574, 0.026094934619322885, 0.03760653380595613, 0.017480247661296744, 0.01860081643826561, 0.06960273545701057, 0.034508174867369235, 0.01514768122433452, 0.05181777865800541, 0.03521220955008175, 0.037718976600444876, 0.049150236445711926, 0.046268228397821076, 0.017822155095927883, 0.03580013522878289, 0.021777963629574515, 0.032284414701280184, 0.01573634162923554, 0.05447186573292129, 0.024358563241548836, 0.04633656164514832, 0.07666985897230916, 0.05071077262982726, 0.04065520966832992, 0.0463560875505209, 0.06224798518815078, 0.04931136041705031, 0.034966310049640015, 0.048793122405186296, 0.08366343565285206, 0.02515496191335842, 0.01345529508398613, 0.03739054285688326, 0.06747009247192182, 0.03937858949939255, 0.026436545194883365, 0.031182625971268862, 0.13704724609851837, 0.013648486328747822, 0.007679873569941265, 0.026972286759701092, 0.027688297850545496, 0.0824904564069584, 0.010437768087285804, 0.012871568105765618, 0.05430156881629955, 0.019640509672171902, 0.08971901188488118, 0.07999938577995636, 0.038240914218476973, 0.036338429781608284, 0.08380766463233158, 0.034001347376033664, 0.058727359064505436, 0.025008202210301533, 0.06672151037491858, 0.012516283459262922, 0.03187488648109138, 0.017755630833562464, 0.06678934267256409, 0.05910225496336352, 0.08235022018197924, 0.004159157924732426, 0.062470473640132695, 0.058491612144280225, 0.06257398097659461, 0.027739682300307322, 0.03783462547289673, 0.042766412007040344, 0.026049695152323693, 0.07243025131174363, 0.02835729203070514, 0.061115887147025205, 0.013664941598108271, 0.06644030319876038, 0.035999116153107025, 0.050206865489599295, 0.08389506736421026, 0.08792150794761255, 0.07670083621633239, 0.02578708248620387, 0.015669648528273683, 0.03320278905448504, 0.0371124675439205, 0.04231133818393573, 0.051207551441621035, 0.03583943565899972, 0.026049353764392436, 0.04306674061808735, 0.06094824711908586, 0.016337496090272907, 0.0598938964685658, 0.04740745105664246, 0.04256127496773843, 0.052516740761348046, 0.0664408301236108, 0.016361038869945332, 0.02789708069030894, 0.018218701297882944, 0.06733499190886505, 0.031461881299037486, 0.01997721650695894, 0.03709098607941996, 0.06797409980208613, 0.032856974212336354, 0.04974826275429223, 0.026186513787251897, 0.031545194797217846, 0.04539454988844227, 0.013307306198839797, 0.0481006578047527, 0.022267957356234547, 0.027600217908911873, 0.014410736002901103, 0.037676596257369965, 0.03001529817993287, 0.026426674630783964, 0.03311698936158791, 0.0560990467783995, 0.03915570028766524, 0.047683006778243, 0.06369203387293965, 0.04509504135057796, 0.04114110859518405, 0.007005411152931629, 0.0989182737248484, 0.016518535594514105, 0.021890920361329336, 0.07221836072858423, 0.020131709388806485, 0.02699547701922711, 0.03243397601181641, 0.06541762370034121, 0.04713312730018515, 0.02197263082052814, 0.037281755139702, 0.024652728316141292, 0.06005898350849748, 0.046619030472356826, 0.07489244497264735, 0.03136507555609569, 0.032464092364534736, 0.03958914792747237, 0.06431541565689258, 0.01617499172425596, 0.07820918457582593, 0.02498493773600785, 0.04674894342315383, 0.038487425990751944, 0.04501137533225119, 0.06344305074890144, 0.054142200024216436, 0.04717820535006467, 0.01475304234190844, 0.01208894091178081, 0.08207768871216103, 0.03985579045547638, 0.04021073371404782, 0.047199749897117727, 0.05821840532007627, 0.036470851191552356, 0.02462914286297746, 0.011861346483783564, 0.015923950995784253, 0.016362330206902698, 0.07957840251037851, 0.058552857881295495, 0.003886944650730584, 0.046443130340776406, 0.034617964483913966, 0.046347029638127424, 0.056289800995728, 0.01573011129949009, 0.016206842847168446, 0.13658983079949394, 0.0579056976857828, 0.019804732110060286, 0.03641324939962942, 0.0491350595257245, 0.027236448659095913, 0.0767153971537482, 0.0818482537579257, 0.04976271608029492, 0.01449411443900317, 0.03011728225828847, 0.033257477916777134, 0.017634261857892852, 0.11377065995475277, 0.061254056490724906, 0.02071558850730071, 0.04839579880353995, 0.017600779865460936, 0.0501961971167475, 0.04281595036445651, 0.02863671805243939, 0.0336207369400654, 0.030973540706327185, 0.025586364936316386, 0.04872284844168462, 0.05197409351239912, 0.08730661633308046, 0.047864595471764915, 0.047810155228944495, 0.05829738096508663, 0.06064764762413688, 0.04940194696246181, 0.03832644673821051, 0.019035466357308906, 0.07105335214873776, 0.024189971409214195, 0.04783391879755072, 0.03015540452906862, 0.014813777852396015, 0.05858380172867328, 0.011510382064443547, 0.037086867159814574, 0.03431387318414636, 0.03906293924956117, 0.03341380761412438, 0.03487320020212792, 0.0446199703583261, 0.023445738297596108, 0.03884704477968626, 0.02657482400536537, 0.0352339767414378, 0.019988736494269688, 0.05887902807444334, 0.046500899115926586, 0.022608107756241225, 0.04533063984126784, 0.008277737997559598, 0.04601540837029461, 0.028121140639996156, 0.04779454415256623, 0.06905565387569368, 0.02386909272900084, 0.05413805884018075, 0.039090246573323384, 0.008667598376632668, 0.03813278330198955, 0.02447959082928719, 0.07352857050136663, 0.018579329407657497, 0.03279686767200474, 0.05142538662767038, 0.02780100781819783, 0.019536293584678788, 0.03452461714914534, 0.029206370199972298, 0.01393821799865691, 0.05174909660127014, 0.03583259676815942, 0.014489071545540355, 0.04451360575330909, 0.04841493508138228, 0.030053761838644277, 0.01854271369666094, 0.05212636366195511, 0.04605700203683227, 0.01734765184664866, 0.05566405176068656, 0.04201556264888495, 0.02296739814482862, 0.034431930325808935, 0.03227598390367348, 0.0601980545616243, 0.028019214078085497, 0.04680638936406467, 0.010826016150531359, 0.034102323988918215, 0.047270231661968865, 0.02462370477587683, 0.053026881942059845, 0.03537220545695163, 0.025132703049166594, 0.053946217376505956, 0.03383931427379139, 0.05001730613003019, 0.03250419060350396, 0.040236089189420454, 0.03432076031458564, 0.024096353190543596, 0.020087881857762113, 0.11469756529550068, 0.037723945279140025, 0.0476805502694333, 0.08074618672253564, 0.04848644843150396, 0.040485250428901054, 0.017560765118105337, 0.09721093330881558, 0.04031091993965674, 0.018553771697042976, 0.013932811452832539, 0.03375036045326851, 0.08190849388483912, 0.0849347049370408, 0.03263559156039264, 0.04534895975666586, 0.2193827717565, 0.08275146232335828, 0.12075717881089076, 0.15831497206818312, 0.18296180031029508, 0.14440071245189756, 0.10977661411743611, 0.11781419219914824, 0.11781297507695854, 0.13785418326733634, 0.1293812316725962, 0.13320804195245728, 0.12212714631459676, 0.10701697508920915, 0.09708800396765582, 0.11886945940204896, 0.1423352412530221, 0.1030410747625865, 0.14922673552064225, 0.10756120682344772, 0.11298190540401265, 0.21639203536324203, 0.1146371841605287, 0.08822446747217327, 0.15316522418288514, 0.12042768008541316, 0.17159540788270533, 0.10512317006941885, 0.2889229590073228, 0.13997948641190305, 0.11571194016141817, 0.14652444224338979, 0.1962710017687641, 0.11339096236042678, 0.11010073227225803, 0.1542725382023491, 0.1410175728960894, 0.1308497044374235, 0.2592074254062027, 0.097484347934369, 0.0977172858256381, 0.11592469905735925, 0.14528008323395625, 0.15485819661989808, 0.1715482963481918, 0.09879553734208457, 0.10482461148058064, 0.1922975727939047, 0.11643361940514296, 0.09566108405124396, 0.10502729201107286, 0.18495335360057652, 0.14288260485045612, 0.1640499330824241, 0.1773198155569844, 0.1441533546312712, 0.06744197991793044, 0.13168993435101584, 0.15756034146761522, 0.1378620055038482, 0.13818390463711694, 0.15814700920600444, 0.1348712542676367, 0.12089371171896346, 0.31210379325784743, 0.15563219727482647, 0.12681595369940624, 0.16456856072181836, 0.11146007964271121, 0.13340105972019956, 0.13226708775619045, 0.10693903474020772, 0.1354196123429574, 0.17020045226672664, 0.1286322413943708, 0.12399409300996922, 0.16376309300540015, 0.1690528099425137, 0.1255441500688903, 0.11857110119308345, 0.14185428502969444, 0.19633510848507285, 0.17466740944655612, 0.12562127405544743, 0.12749353452818468, 0.1846248345100321, 0.12082685905625112, 0.10848692472791299, 0.17949249740922824, 0.15232060075504705, 0.20827028289204463, 0.19247512420406565, 0.09043273530551232, 0.10522379045141861, 0.1660150065436028, 0.23961870465427637, 0.18821972364094108, 0.0955987733323127, 0.1934862113557756, 0.09478065941948444, 0.13951168104540557, 0.12593055667821318, 0.1423103644629009, 0.1306765020126477, 0.290950684575364, 0.07164744136389345, 0.14805399376200512, 0.10406454835901968, 0.10629905853420496, 0.08960483246482909, 0.11472686528577469, 0.1360917606507428, 0.11411730229156092, 0.136200915731024, 0.19968206092016771, 0.09068784114788286, 0.11093904744484462, 0.10160098914639093, 0.13833384815370664, 0.13481701811542735, 0.1396827757707797, 0.21791756444144994, 0.18522089783800766, 0.12794131675036624, 0.17615393124287948, 0.32924535626079887, 0.20049674611072987, 0.1332319391076453, 0.10959556719171815, 0.09931226508342661, 0.13993783708428964, 0.1251037893234752, 0.09557129160384648, 0.11022160586435348, 0.13752348226262257, 0.1459607810829766, 0.15044296713313088, 0.14312323881313205, 0.14004774915520102, 0.13073867914499715, 0.14138783037196845, 0.08834463602397591, 0.15558438812149689, 0.07972813080414198, 0.20526733074802905, 0.08605371520388871, 0.1296965850633569, 0.11208286770852283, 0.09374611297971569, 0.12698942329734564, 0.06869385688332841, 0.15773511724546552, 0.22936330729862675, 0.17515488172648475, 0.141716408834327, 0.16016738751204684, 0.17079032608307898, 0.12403597982483916, 0.108817840955453, 0.14973669487517327, 0.14116073318291456, 0.07875320850871503, 0.10874198604142293, 0.19320130086271092, 0.2349022077396512, 0.11401387659134343, 0.14464070816757157, 0.2639645920135081, 0.10058988715172745, 0.0950325740268454, 0.11792320627137087, 0.178728025930468, 0.11627178668277338, 0.125697240291629, 0.12670841650106013, 0.15289855567971244], [0.039769808936398476, 0.05087365920189768, 0.010816112189786509, 0.0477094754751306, 0.05162237117474433, 0.005122702168591786, 0.09130000908044167, 0.07965997196151875, 0.06100794176745694, 0.012357028772385092, 0.014791625671932707, 0.0404408217582386, 0.018448861701472197, 0.020744272515003104, 0.04335319477831945, 0.03619292801886331, 0.033661358393146656, 0.008382942996831844, 0.025481796328676865, 0.021271674195304513, 0.0637791768531315, 0.024535153570468538, 0.029012506383878645, 0.08100838749669492, 0.03328887447423767, 0.020336250854597893, 0.06040113585186191, 0.043426381671451963, 0.009786834998521954, 0.04955517448252067, 0.0136607521744736, 0.012237716473464388, 0.055226381300599314, 0.034757714602164924, 0.023180160751508083, 0.03256218202295713, 0.08012971433345228, 0.0648847987758927, 0.0522798509337008, 0.0652270253340248, 0.03668211465992499, 0.03313037028419785, 0.02701765795791289, 0.03213896859961096, 0.04417805852426682, 0.09749257093062624, 0.022661744624201674, 0.023011305456748232, 0.06891436380101368, 0.0613472331315279, 0.027344865302438848, 0.01052081441230257, 0.04566322961181868, 0.03595005277020391, 0.06932534291991033, 0.03223978936148342, 0.03897534355928656, 0.0288154977170052, 0.03535929950885475, 0.024400561378570274, 0.019467776655801572, 0.0925745586573612, 0.07015366136329249, 0.032505185081390664, 0.010829553411895176, 0.05039484036387876, 0.055946186621440575, 0.022811398703197483, 0.03933648004021961, 0.12080141823389567, 0.03629784543591086, 0.04774868313688785, 0.03228022527764551, 0.03934919302992057, 0.0372322687326232, 0.05283062098897062, 0.02808911696774885, 0.03383950352144893, 0.024907539154810365, 0.029296954890014604, 0.028922109086124692, 0.0478800469863927, 0.022371017548721284, 0.06188363520777784, 0.06871459991089068, 0.03872840134135913, 0.12359632411971688, 0.02317874696018407, 0.03929192891519051, 0.03418568943743594, 0.04837841770495288, 0.05983853596262634, 0.028583780658664182, 0.07790553485392593, 0.03698191634612158, 0.024231643001257908, 0.03535766307322774, 0.0774216694117058, 0.018584938188723754, 0.09894158458337188, 0.04018107007141225, 0.03730607531906571, 0.08649225026601925, 0.0369260289153317, 0.08875025683664717, 0.06683786428766325, 0.018539867560321, 0.055165777521324344, 0.04680044105043635, 0.03828456363407895, 0.04650388997106347, 0.08054192541749217, 0.033786718267947435, 0.03478966777038295, 0.05416865758888889, 0.013007520283281337, 0.04373056573967915, 0.02222299804998329, 0.010433866245875834, 0.023734363239782397, 0.02623706703161588, 0.04245005671691615, 0.030365519523911644, 0.07160556197050028, 0.14714437304064631, 0.016272348511847667, 0.07715258892858401, 0.0028591035152203403, 0.01904639633721672, 0.05235075943346601, 0.02582001714472426, 0.016601734059804585, 0.06522774521727115, 0.07264450934599154, 0.07739083317574114, 0.05696061714843381, 0.01961587964615319, 0.06202379350725096, 0.028598963144759182, 0.029208238556748256, 0.060516777302837, 0.03362717507116031, 0.0434132493683137, 0.04356789439043496, 0.006117548809925211, 0.01212067143569584, 0.03386472541023977, 0.030990053492132574, 0.027312038255331572, 0.03698525601066649, 0.04208044490951579, 0.040196866684709676, 0.024713011116546113, 0.01260179742530454, 0.02793698411551304, 0.04600477339408826, 0.026049092157336418, 0.03748358220036607, 0.09239777908078395, 0.06449305612477474, 0.030598813646065537, 0.025842294562608004, 0.02747755017480813, 0.033889965852722526, 0.03304518286313396, 0.05395894520916045, 0.03744136884051841, 0.03728992618562188, 0.021222792638582177, 0.022125457580841612, 0.024003684920899104, 0.034536005405243486, 0.0296314130173414, 0.008855673440848477, 0.04770711173478048, 0.030282118823379278, 0.04919161488942336, 0.05842691913130693, 0.038696192132192664, 0.03868123414576985, 0.02644134689035127, 0.05868386921065394, 0.029609417615574785, 0.0627802980307024, 0.05783750173577573, 0.036362586688483134, 0.036686422827187926, 0.05949860635155346, 0.05427007949037943, 0.03845418519631494, 0.03876580929500051, 0.04567607247736305, 0.06972954623051919, 0.09634254631237127, 0.06806113146012649, 0.026060315285576507, 0.12405554283759557, 0.010148042911168886, 0.024111856655508745, 0.045271787530509755, 0.04835502892092336, 0.019796846790995914, 0.03590219537727535, 0.03771834948565811, 0.050655452942010015, 0.03954779545892961, 0.043583256847341545, 0.019064911066379864, 0.014812729568802752, 0.06936679928912781, 0.040235573396785185, 0.012978137729078298, 0.06304312963038683, 0.05798773097922094, 0.04965544976585079, 0.04034641315229237, 0.03103192546404898, 0.005243673167569796, 0.06389484799001366, 0.021991434987285174, 0.04819583824428264, 0.04559220978990197, 0.045754595412290655, 0.026911690401902888, 0.05012064277252648, 0.04687480424763635, 0.06940827050129883, 0.04332102267653681, 0.05316348164342344, 0.05268432141747326, 0.09860178484814242, 0.04676032425777521, 0.02398669530521147, 0.07809608869138174, 0.031177787168417126, 0.09742286842083558, 0.0484868825878948, 0.09753453196026385, 0.029599983063235413, 0.007884797705628444, 0.05385814300097991, 0.011341265162627678, 0.07842890481697395, 0.1237445829610806, 0.07665085257031024, 0.06748300584149547, 0.03379800633410923, 0.0477250791300321, 0.05347020014596637, 0.03247997061407659, 0.011944866855628788, 0.023960310099937487, 0.045793784520355985, 0.011271773237240268, 0.029053623220534064, 0.08890417084330693, 0.038016392281861044, 0.07447466035955586, 0.01250835639439174, 0.040214689361164346, 0.02537348173063947, 0.047256461111828685, 0.07732011392363347, 0.007581888739878195, 0.024682072835275903, 0.036687832907773554, 0.052151351774227805, 0.02518273493478773, 0.014556105106748873, 0.03635787776147481, 0.03209515962225851, 0.03604408288083505, 0.06839106063125655, 0.022371807935996912, 0.08238353519118391, 0.08783744488027878, 0.0020449157955226838, 0.08646368500194512, 0.04999844073608983, 0.03351813131303061, 0.05860883065906819, 0.05654531130858231, 0.03328413957206067, 0.047010227644932456, 0.04465318517759442, 0.05098848429042846, 0.0333276442688657, 0.010665687204891583, 0.01570880052895518, 0.058670807411544956, 0.05135018109285738, 0.11455083527835086, 0.005018956417188747, 0.04109076129680034, 0.0492497473169351, 0.061251035949680954, 0.0027978438629361335, 0.01497244067650172, 0.05958115172688849, 0.039089285492082126, 0.1106843349407427, 0.008281460795842577, 0.06728485983330756, 0.03030663381650811, 0.048942546418402344, 0.024601709374110214, 0.017032823525369167, 0.03857115880236961, 0.04885656861006282, 0.03973272010625806, 0.026830692404473666, 0.06024613459885586, 0.04191487176285591, 0.055678757416899316, 0.03655825392343104, 0.010418790443509351, 0.010836652982106898, 0.02516939854103839, 0.07249543414218351, 0.07847285480238497, 0.09274632873712108, 0.021055636862001847, 0.038363097701221704, 0.05728716583689675, 0.0854949522181414, 0.08748424937948585, 0.020049989652761724, 0.03924634620489087, 0.09986812627175823, 0.010522593711357331, 0.07845076848752797, 0.05984566800179891, 0.06921220250660554, 0.003788720941884094, 0.06256537948502228, 0.012066433428117307, 0.03391908772755414, 0.02649194466357585, 0.025657596270320937, 0.030438378016697243, 0.012915250918013044, 0.035074734114459716, 0.05375824992370326, 0.03188162518199533, 0.08517524984199554, 0.028308861328696366, 0.012181986749055795, 0.02453792178130243, 0.025794266475713812, 0.054346546676242724, 0.03558480108040385, 0.01758068065100815, 0.13048976281424984, 0.14833942375844344, 0.06810640246840194, 0.08438129283604212, 0.1416836355929263, 0.13226538081653416, 0.1334472806775011, 0.1974059088388458, 0.13788722368190065, 0.1432562168338336, 0.09717731401906349, 0.3296750894514844, 0.11940532713197172, 0.14877389185130596, 0.11036856594728306, 0.16182037303224206, 0.21605947898933664, 0.15547089889878407, 0.23997034906642511, 0.06982025894103572, 0.19151082204189152, 0.06748377025360242, 0.15775901440065354, 0.16321439354214817, 0.15554327314021066, 0.09222918539308012, 0.12155477976193652, 0.10565233620582148, 0.10618434476782568, 0.10285141150234267, 0.08651007665321231, 0.0777640740852803, 0.17506365693407133, 0.16003359312890097, 0.11425356060499325, 0.13240045169368386, 0.2091717696748674, 0.13374326401390135, 0.18180632090661675, 0.08727111198822968, 0.07312111658393405, 0.09345602229586802, 0.2754324657144025, 0.1033385943446774, 0.20941344264429063, 0.20223050698405132, 0.1837583028827794, 0.11365391270373948, 0.13426710152998567, 0.11972596461419016, 0.10749678840511478, 0.12022611277643591, 0.257858675904572, 0.17034836229868233, 0.24104935757350177, 0.12431579176336527, 0.12526493926998228, 0.2057040252839215, 0.11137702589621767, 0.2424993657041341, 0.11685901103192009, 0.19405753148021176, 0.14124622859526426, 0.1114975284144748, 0.15770691563375294, 0.10480351222213358, 0.2086286511621438, 0.16028446872951463, 0.18782905710395426, 0.2626886323560029, 0.1733742022770457, 0.12361253262497485, 0.17474692314863205, 0.2700544480467215, 0.10821552874404006, 0.14088419411564246, 0.10673953060177155, 0.0590609396022046, 0.09358536379295401, 0.16671534162014723, 0.16930766345467418, 0.2580434113042429, 0.27966879308223724, 0.11477826643385924, 0.1432778875459917, 0.15465968695934862, 0.14577515510609373, 0.11178430169820786, 0.11489530312246643, 0.11261475010542199, 0.21223412331892177, 0.19194656662875786, 0.19890659081283957, 0.23196704336442053, 0.12956095015397295, 0.07515312434406951, 0.1777217330527492, 0.25888043513987213, 0.19912598450900987, 0.1420672665699385, 0.1300427078967914, 0.1686481316573918, 0.18351355742197484, 0.2306887978920713, 0.22111285157734528, 0.15100860240636393, 0.1355156017234549, 0.15359862358309329, 0.23799506365321577, 0.12154762545833364, 0.1674423791700974, 0.151325469778385, 0.1409495179541409, 0.12376774539006874, 0.1082285757001955, 0.20702363806776702, 0.2838892681756988, 0.1435765574569814, 0.0949827981821727, 0.17150173400295898, 0.06873595892102458, 0.0999336875975132, 0.14619906985899433, 0.18269489431986585, 0.25367593159899116, 0.11388203405658714, 0.1924214669270441, 0.11015501295332797, 0.08906511298846453, 0.10835618057171814, 0.06987089567701332, 0.18566584505606443, 0.11697179521434009, 0.14502147445455194, 0.13089029991533607, 0.1734447359922342, 0.12725678941933438, 0.23436244373442605, 0.21690579451387748, 0.15030037087853998, 0.09344836333184503, 0.13988912251079455, 0.19990641216281801, 0.1622621587011963, 0.2975786570459604, 0.10408937319880351, 0.12024327123071998, 0.165006234892644, 0.2401113125961274, 0.17188843747135252, 0.10601339105051011, 0.16428409551735967, 0.2160051983082667, 0.1208364253398031, 0.1866452573449351, 0.18691888719331473, 0.1475218590348959, 0.13063555030385032, 0.20101127709494904, 0.11827379683381878, 0.16387359879445285, 0.11320008197799325, 0.1418503071181476, 0.12802655983250588, 0.10080329171614721, 0.13265769492136315, 0.1347286580130458, 0.15132647909922525, 0.1484876751783304, 0.10480091470526531, 0.17251890676561743, 0.15371156361652538, 0.11863497042213567, 0.19393432012293488, 0.11648919142317027, 0.0825277938565705], [0.017522603884572163, 0.03863027086481452, 0.060606788683799095, 0.02597936923848465, 0.03891285843565129, 0.06013827085553203, 0.08094023607554846, 0.022022107950760983, 0.03204831155017018, 0.05161480497918092, 0.04323869252402801, 0.03584876445529517, 0.02720323569519678, 0.036357514109113254, 0.06750335553078912, 0.012699558683380019, 0.04275522784155328, 0.086727169691585, 0.040050207171589136, 0.05330417799996212, 0.043526508525246754, 0.05924833189055789, 0.06196490408910904, 0.04802880677743815, 0.022591396445932332, 0.03348308338900097, 0.02640656613948522, 0.03629340368206613, 0.04316508260671981, 0.05069589999038726, 0.05456254875753075, 0.06743549354723655, 0.07357720343861729, 0.01113681460992666, 0.06219401991984341, 0.0661777016648557, 0.06775509944418445, 0.024486043803335633, 0.029768771564704366, 0.017772143619367853, 0.04516682187386323, 0.04794167121872306, 0.04938770143780857, 0.022331060317810625, 0.039191267715068534, 0.0790258809865918, 0.01983606558496831, 0.06205032528669108, 0.02100894649629481, 0.05265998268441763, 0.01726129739836324, 0.06410833419067785, 0.04915984354738612, 0.09126916542300023, 0.017777620669221506, 0.08810677027213387, 0.03699400222103577, 0.053374047492980026, 0.04109216766664758, 0.04673795592680108, 0.03354835156642366, 0.04864641094172839, 0.031889443707768805, 0.04444323531060945, 0.03177969490934629, 0.062136080450727604, 0.05866823215910699, 0.05499660495843273, 0.024193839853978716, 0.05340154777513817, 0.0046487522831739625, 0.03801915307121817, 0.03942606468626764, 0.04106129803403746, 0.059481061980477534, 0.015086239745869534, 0.03009878422744805, 0.010908757267316105, 0.052853775996482, 0.016639041823509615, 0.0686532688268926, 0.04824160649150144, 0.06197174297994934, 0.04374178701255005, 0.038814842991996557, 0.034536279999883845, 0.03818983961537015, 0.03600828909839038, 0.04407264386827592, 0.029092374461470172, 0.015728884900454432, 0.01913528707518708, 0.01725022269965848, 0.01155425134129473, 0.042557141205179505, 0.10136989920283668, 0.030035454910830595, 0.05288981097692158, 0.05362894924473949, 0.06524274402181618, 0.04570688644889742, 0.03916937806934584, 0.0050004300919681555, 0.023777324313414283, 0.06544537260197103, 0.050125147608923726, 0.08520459436113015, 0.03050058483495377, 0.08715328120160848, 0.035386391609790735, 0.017730980398482643, 0.04259766988980118, 0.022662971023237333, 0.11728564204531722, 0.02590285937912995, 0.026176902974839322, 0.0829305722436402, 0.041921454612747766, 0.0470388782559894, 0.028723579016514122, 0.0533854505920317, 0.04690375913924072, 0.024257716504507698, 0.0849115573510062, 0.09500002342974767, 0.05477614999108482, 0.05881127741304226, 0.03842516351141967, 0.02943845833215164, 0.017342618230031803, 0.030923039412300568, 0.007747376539555262, 0.09628638799767941, 0.03719943611940835, 0.014543865236191778, 0.05763927038060501, 0.0733472712454386, 0.04708445354481228, 0.02856252554920502, 0.056304966783500277, 0.07716691980022006, 0.008622182649560273, 0.07496415870264173, 0.045077389368088916, 0.01929735914018238, 0.04822174661967438, 0.08706394146429375, 0.04064716849825345, 0.030127883837849367, 0.056956490807351656, 0.05936318666499574, 0.00718332714313874, 0.045645666687050834, 0.07046816870570183, 0.04442113044206053, 0.06634783901972696, 0.042700104822870344, 0.05768992195953615, 0.07072635446093045, 0.13601868879050016, 0.0310187968716491, 0.01923978703416651, 0.05519819082110189, 0.016693289107934106, 0.0442227692110464, 0.013018013323744526, 0.04172226217633579, 0.019259882537880912, 0.01610949719179189, 0.033454106232966296, 0.04797694549779408, 0.0548334103950765, 0.0836234784219414, 0.06221397627086844, 0.024589480635768268, 0.013265591005620081, 0.012274697692191694, 0.06931222917046398, 0.014718745842401404, 0.009530939696560381, 0.023497009569837246, 0.023706862957624253, 0.012825915819121292, 0.0439686281606555, 0.052337831220938824, 0.07271938462508842, 0.05749212847149465, 0.028059121214027982, 0.03925972712750081, 0.04435513124917634, 0.02120112749253167, 0.04630794814147521, 0.06906086375238374, 0.04463016004592646, 0.0323433041194221, 0.04316428479796741, 0.05750319018261507, 0.03684152055939194, 0.05257350763713475, 0.04374093725346029, 0.015224845101329265, 0.03568936597730499, 0.05488231421622913, 0.02342053867323557, 0.06068560847779736, 0.04633154101611581, 0.043900970267714, 0.018366622462053783, 0.03773850992729422, 0.04276005922292825, 0.035172964780940674, 0.032102881668834016, 0.03232017879781779, 0.04560582077829167, 0.03366374810866546, 0.05874385700735729, 0.07166943862102926, 0.024340740565094166, 0.08415749078267254, 0.021993503723933827, 0.011897569784196094, 0.059495715686352924, 0.07882965714088641, 0.044721477606799453, 0.04666865788749419, 0.07683170653763227, 0.05055528898083139, 0.03489040318527259, 0.05913005210459232, 0.048074578735395335, 0.02323580141819548, 0.07184837042586878, 0.09448302851524204, 0.03251448419177905, 0.056927743717096746, 0.009800096249819035, 0.021030465068179183, 0.02845405510015553, 0.034950383560499176, 0.03387090750038624, 0.029896426531195175, 0.022083941839809995, 0.04366226959973574, 0.045095887398929335, 0.05403917508374434, 0.03848580439807847, 0.030678809744131286, 0.05035512433096301, 0.05099899681226816, 0.0070121373300935375, 0.07098765723640099, 0.05084573960630223, 0.03567050058336463, 0.05712874328310136, 0.09139222835074179, 0.08934584519010969, 0.027746855157602113, 0.048412942414870486, 0.013170170295779826, 0.023349865805357695, 0.09794069454073906, 0.021207443169259932, 0.03980100140324794, 0.03206839406630024, 0.04691585243563168, 0.03760779174626805, 0.03520014222885948, 0.031838387658353895, 0.05590821092482656, 0.04724817874375731, 0.030664417645311914, 0.0051559949133661576, 0.01483290763644618, 0.06725199011270888, 0.016602593095740303, 0.041217865218641236, 0.03526930668158457, 0.04570288998365868, 0.030797584913671017, 0.06945831351913512, 0.0554898214613786, 0.014793018126511015, 0.06493005494121462, 0.019471077357593458, 0.03923975593352225, 0.05664684824296273, 0.03347839301568456, 0.07439424865879118, 0.028042873746016994, 0.01801689464627998, 0.009327087500423659, 0.021813868734170683, 0.038342785119311884, 0.05145882038050331, 0.05748887044319417, 0.019531688558345195, 0.08695515003637411, 0.059889643962378614, 0.08104527223622426, 0.01972528891201364, 0.01555378628836479, 0.02324373312148964, 0.030881482853146736, 0.05920323899772484, 0.024820336802804377, 0.03159741230774671, 0.032205635725404136, 0.037378364213509485, 0.08718433266039938, 0.03391214122530073, 0.025754127418622375, 0.006219905817488325, 0.06147343905468006, 0.03135241822747048, 0.029964995410409756, 0.031375228136312217, 0.0544769308908144, 0.022633891821897123, 0.03571882924006786, 0.05087557765364181, 0.03497573532513343, 0.028484945141826756, 0.0705074134748429, 0.029291403625393286, 0.0068871457460772945, 0.05276956821035128, 0.05678777837601956, 0.02268238375108922, 0.07564637795439921, 0.038621828934992664, 0.027953064600296784, 0.04586879338603467, 0.021362772822612897, 0.06220781273441389, 0.0641300123243127, 0.04807319834071677, 0.04921342660964001, 0.014752102597412886, 0.024362474359804764, 0.025403496038052253, 0.03276846939115785, 0.10043166868854314, 0.014976053080317797, 0.007248544297908666, 0.023056040263327304, 0.0350084529054584, 0.012850826005887939, 0.04401438527565915, 0.12606596894329414, 0.03655063206679188, 0.058236413533450104, 0.011383846813259879, 0.13212150806793943, 0.11700739603838883, 0.21385555271990597, 0.14586866571335122, 0.07453449972672388, 0.1496674821828492, 0.1162787109205965, 0.20626382727641612, 0.11607706939685158, 0.17341631173621863, 0.1461168102105148, 0.11405970421037637, 0.14627813827246428, 0.12375276142847724, 0.15291938034351915, 0.13198234053561464, 0.16312594438204542, 0.17850783071480691, 0.11475815423182212, 0.13943978177849203, 0.1572018989827484, 0.15820995817193761, 0.23491093539632857, 0.185129331657663, 0.13198470056522638, 0.1430353833711706, 0.14693833800265566, 0.1279246629565023, 0.17877677018987015, 0.09709845340694301, 0.19648350833449513, 0.1392411088454537, 0.15616030956152827, 0.06179307834827341, 0.15665916638681665, 0.12647863273741677, 0.11863567546242848, 0.10501111319172196, 0.1786110337707214, 0.07482915461878292, 0.20831982867093757, 0.13412536616669968, 0.1604555782978423, 0.11216006590984762, 0.10424265637993813, 0.25272728875279427, 0.180904834123794, 0.17980436270590872, 0.09546537228743546, 0.17673123307758942, 0.1221233316755388, 0.11112895561382174, 0.16500783793162555, 0.21517532877624035, 0.11076023438363336, 0.18341599468840286, 0.12966373760718852, 0.20079670735867694, 0.15356120449723676, 0.2564555121352896, 0.10715687734773383, 0.14741038845386356, 0.10683326385333203, 0.10994553435011767, 0.12592558428877965, 0.24340309377294034, 0.1837431630701758, 0.1731177160399966, 0.20076731831068173, 0.1750907304813154, 0.16820161108626053, 0.06330291842459701, 0.16622350551187992, 0.11218103900318965, 0.2537703327834606, 0.14458840159932151, 0.08590708908741362, 0.11596173222642392, 0.14043948438484222, 0.12438806210411713, 0.10524785830057226, 0.16517320327693596, 0.09821557119721547, 0.13259919884148985, 0.14179457182763144, 0.10165354804485105, 0.12352913749055006, 0.1341099591809325, 0.13081984041491523, 0.13387122511630878, 0.15276532532880083, 0.09160440095001832, 0.11296053155092523, 0.09385448880493641, 0.14161307219183072, 0.2160136291058734, 0.17619341349927709, 0.1442587692872621, 0.12192200927529484, 0.17479933361755684, 0.11238107748795301, 0.25997629039920866, 0.09698428882984444, 0.1769407413667068, 0.16891434002900496, 0.1335217329324223, 0.22530929592903703, 0.11926305742235854, 0.18695302598644048, 0.16284657031064853, 0.10534890912822448, 0.11310364730888978, 0.07853890594560653, 0.21853523910976946, 0.13713287509744987, 0.10205536906141788, 0.22967351018451154, 0.1518234657123685, 0.15655507275369018, 0.15561671607429162, 0.22060685529140756, 0.18419388419715688, 0.18688455544179305, 0.18715766578679904, 0.14845727680949494, 0.24098490946926177, 0.13189994730055332, 0.28498755767941475, 0.10179482327657752, 0.1749566540820524, 0.1247125884401612, 0.10246673409710638, 0.21084644075017422, 0.15072906506247818, 0.13101858756272122, 0.12719197024125606, 0.1756581023801118, 0.15970722626661882, 0.18234284914797172, 0.16735964454710484, 0.19794496038230136, 0.10468684660736471, 0.15601608058204874, 0.11554030366824009, 0.09745098097482696, 0.11611412483034655, 0.2242324544931762, 0.10890402656514198, 0.11097143476945348, 0.18440489162458107, 0.1725222315872088, 0.03934754175134003, 0.14399368898011744, 0.21180115436436608, 0.07283524872036651, 0.14318209112389013, 0.22243077226448804, 0.1702632973319851, 0.18643459130544215, 0.2773217955837026, 0.14383170782821253, 0.14214005641406402, 0.13187786098569632, 0.12379516774672084, 0.087575132783968, 0.2655757946195081, 0.17136299691628665, 0.0937137108121533, 0.08796945068752393, 0.1066633862501476, 0.08076557161984965, 0.19750408013351262, 0.3775574779137969, 0.15033964533358812, 0.2567350643221289, 0.10436408658279106], [0.01860617659986019, 0.017963025857170578, 0.049408956547267735, 0.004931766125082504, 0.017052674120350275, 0.0635389807575848, 0.021378860728873406, 0.016633199265925214, 0.03422156114538666, 0.02253907689009793, 0.046538826572941616, 0.0422597552096704, 0.027804957899206784, 0.08794809167739004, 0.027429093497630674, 0.03708711577928625, 0.04193249777017627, 0.04676428361563012, 0.09017517295433208, 0.08492227396345697, 0.01581605385581497, 0.019829313896480016, 0.04663666390115395, 0.09315533374319784, 0.030717919071321376, 0.04283362832211424, 0.03872529174259398, 0.034377156116534024, 0.04041706932184752, 0.02056526835076511, 0.038319466839311644, 0.01082471460904344, 0.03195004006556701, 0.04923377629893366, 0.011113736600236734, 0.020636210247175768, 0.04453034860489424, 0.055827001415309496, 0.07728725904598832, 0.06396697732270695, 0.014984917106630746, 0.024818396086629946, 0.028013391929562204, 0.038126501021906734, 0.02556233976065414, 0.050060424910043366, 0.0071834175923868315, 0.04437628245796077, 0.039224972351803444, 0.007038896856101928, 0.017304236207564827, 0.042424894199939445, 0.07196829406893812, 0.0807254808023572, 0.0724264960444998, 0.02943839896033751, 0.059483162258402444, 0.047966006241040304, 0.07857522665290162, 0.03408282034797594, 0.02289094394654967, 0.09218018138199113, 0.05502455052919686, 0.06422627629945055, 0.048533047884120606, 0.017550323100294918, 0.03225009779271204, 0.021420680750452448, 0.007679919954171055, 0.03676716849440709, 0.011197890580660896, 0.06471837215940468, 0.013761967202299275, 0.04032165881653782, 0.041192157223122194, 0.07789982773829252, 0.052776859811274335, 0.03252262555179186, 0.09468924909015186, 0.04296348190109711, 0.04710989807790611, 0.021196225607127417, 0.07463687157724053, 0.029239405048429035, 0.05021092132665217, 0.047670163912698627, 0.044450237473938614, 0.027651826858345885, 0.034460677416063845, 0.03601324664487038, 0.05007475207094103, 0.038820865520392545, 0.017663719554548152, 0.0569207155785989, 0.03078224472119473, 0.06489415725809522, 0.019916301025659777, 0.07462122710421681, 0.015175061835179804, 0.06407269625924528, 0.0338662468129769, 0.03486181936750654, 0.11888365668710321, 0.07956981586175971, 0.041875367242028005, 0.04016056082036812, 0.02511096368834842, 0.033214871218660846, 0.03023962715815287, 0.04065218541654758, 0.041181210544891655, 0.09262422317988239, 0.005500010975083569, 0.010784299101942452, 0.016661052068229765, 0.05564221035456285, 0.06247290046303533, 0.06332616248982958, 0.060330531632644124, 0.0490284054831136, 0.01792087929061381, 0.014424588189285714, 0.045712686332990415, 0.07850922746001743, 0.05364601864130236, 0.012628844997379929, 0.015386586910608457, 0.03811880495049991, 0.025637441394792404, 0.05224616856139619, 0.05871850524272304, 0.045824101252947, 0.049929773522308096, 0.021264334354782477, 0.03410022742173169, 0.02734132154728286, 0.010941013788396958, 0.02229015499324305, 0.05322556600731332, 0.009875421455944888, 0.03354000982653815, 0.05762866137956735, 0.048217909716186114, 0.017038064943335485, 0.02564371439802926, 0.01677842086792225, 0.00834967066111858, 0.02006409973546397, 0.040124154766090214, 0.07238197460537776, 0.03374837520823348, 0.05600564007181674, 0.041459003841737285, 0.003449539276516589, 0.010960346735373605, 0.07932632463052869, 0.036279377090977505, 0.0706999636895489, 0.023092876763257664, 0.09998404231737368, 0.03733282232133206, 0.034114246591343544, 0.01922418894537259, 0.021966708482068498, 0.0172646036662627, 0.017059893361874856, 0.06306174269411713, 0.048507213723496534, 0.06516481109429151, 0.018062045055557974, 0.03579537064069882, 0.02439480787870707, 0.023175872993306257, 0.0717135147715453, 0.019929062254959717, 0.0572146505874116, 0.009447460142837372, 0.03455025092989672, 0.07004786079050973, 0.026246551678923424, 0.03483358435914852, 0.020051494357176125, 0.036788475554203615, 0.05270598841889296, 0.05058062219177373, 0.03889537343638949, 0.03259078810515348, 0.02400382963969605, 0.047131743194768205, 0.035901894807466306, 0.04542235445114784, 0.03305254125734791, 0.03862800731440075, 0.03729970027052332, 0.023118299031921197, 0.025081934581976384, 0.05167094474018086, 0.03787111687415745, 0.030950105538067874, 0.008083502179943025, 0.047100528463488445, 0.0799929365166463, 0.017520987858006265, 0.05851552414242178, 0.03369079568074085, 0.014128876664472045, 0.05549642657570075, 0.004671185088227503, 0.010414046264486387, 0.05230994873272721, 0.03172430100676138, 0.06301763685769401, 0.09494736063061282, 0.05238359946815763, 0.024749357799009886, 0.08323964706505649, 0.058543436316540465, 0.03701067456859164, 0.06692493305308744, 0.027067422670370433, 0.017215271254826803, 0.025845213058346417, 0.03588204606785439, 0.060426780764828436, 0.05554261413635686, 0.06050502910511568, 0.022082516916270833, 0.009516274858469842, 0.053326331108110026, 0.030061170327826403, 0.0632427228265442, 0.028614381262741517, 0.05540746162296273, 0.010806833488459233, 0.05593577428953722, 0.0974679464707151, 0.030108100036159158, 0.08833512911223806, 0.01954189679963747, 0.016661324807500932, 0.014539942058036104, 0.03740086613106541, 0.04710184206487611, 0.02948113553429721, 0.025697577621031087, 0.06507587211672217, 0.020352839710540138, 0.03577716575819068, 0.024949194048531353, 0.09152396698482335, 0.04024891721201129, 0.026784671827044804, 0.04422919992066454, 0.01771477189322468, 0.11049315027776174, 0.019457316084299237, 0.046579459158238024, 0.010537700127315475, 0.04078845486219507, 0.01917601613968145, 0.09847783134318888, 0.02044244476564927, 0.08581460264394991, 0.015993033812264912, 0.03743273024156224, 0.03544765590049792, 0.027668412003549747, 0.054340190181392245, 0.02903249056544155, 0.059386605134932324, 0.01658297627727734, 0.0335810988326557, 0.01925384516653139, 0.05060055998910684, 0.018939951951324474, 0.03466725422185846, 0.024322502285940573, 0.0660575924848672, 0.15080808894708753, 0.022265888619585894, 0.046185545725165866, 0.020199844111630227, 0.05222319538006559, 0.02348452850128524, 0.04093449839274399, 0.024644319782964885, 0.1209666054637637, 0.013220636337791802, 0.05076550231024157, 0.03831769310636446, 0.10607838834403083, 0.05138066480867565, 0.007710866584602627, 0.07949989812914282, 0.044040174907422625, 0.04588065290590748, 0.03278445525211282, 0.05416496911493596, 0.05346073034161236, 0.03607401369663421, 0.028531537172966637, 0.015532541383436183, 0.03268143402237911, 0.05980197776807472, 0.024999712040880695, 0.027719065437850077, 0.08518535789335147, 0.0380422301532235, 0.017773522158677224, 0.022573141468456015, 0.03770838986383751, 0.04497722540691029, 0.08935484744142741, 0.009273082341678673, 0.02400201694399584, 0.016013325985113624, 0.01664814612013288, 0.04648882808396593, 0.07049687497783452, 0.023417802003677934, 0.03530541587679181, 0.10154420000617392, 0.032914906259975396, 0.013305195716384333, 0.024748175928834826, 0.044986821376369335, 0.04027950482850429, 0.043856908960151486, 0.020247612446837593, 0.05459267253172584, 0.011946244467253564, 0.015728419202787336, 0.08150480265612714, 0.02485672801412875, 0.029912434656580444, 0.024033302179304883, 0.03436265826167073, 0.01651259470236255, 0.030443129617196973, 0.013485132203641115, 0.028219081868883222, 0.028991284671064932, 0.07099285227013752, 0.05081010167486966, 0.011452308081061346, 0.037866749335080385, 0.06543003983097151, 0.04060275467054453, 0.03759226972761098, 0.05866318926564418, 0.07608126907143742, 0.045317782132769935, 0.12004386357148178, 0.13624563755001873, 0.1171623267873656, 0.11966671896516345, 0.05943299307546113, 0.11344897604431026, 0.10613617196213454, 0.08247475998359732, 0.11791761789936572, 0.1703335193451494, 0.13426595862256363, 0.16692243050783873, 0.11092812303104438, 0.1194704209046904, 0.1465409030788578, 0.13404233468463644, 0.09322585261543281, 0.20172605436528102, 0.16680833272403106, 0.21372831892222166, 0.24543917592382059, 0.11972362684900872, 0.21487395744770765, 0.1920458659878932, 0.10460424557095394, 0.18786971195368096, 0.1077204271859955, 0.22070622886531055, 0.07578153788927011, 0.07710061632678844, 0.2497272309847176, 0.10555618355283514, 0.09875909046968445, 0.10265628603519872, 0.08445757077424787, 0.1692731090588495, 0.18589873099699616, 0.15225860173814, 0.16508580796653405, 0.2652113704243675, 0.10287657773005776, 0.12566746532684192, 0.1342549006221816, 0.18536399875301868, 0.09486186521826312, 0.1251571052125655, 0.10494951493456028, 0.15441620314959437, 0.0952805626729969, 0.22732597833964974, 0.08538671740097925, 0.1336463840561919, 0.21228552446700633, 0.22750480624381453, 0.12984603876248002, 0.0646707411215175, 0.15782830130774528, 0.150574846775271, 0.11020682228263468, 0.11327871252433397, 0.13890951726352796, 0.12464420695323497, 0.15454959677299485, 0.11672549124341458, 0.21162042656214908, 0.06983518353081308, 0.10477725503733382, 0.08662652704515494, 0.13393083441769704, 0.15688897983636707, 0.14545521524269134, 0.14490941015537828, 0.1747030028491281, 0.1342311518965289, 0.10501182565349154, 0.21682065533241257, 0.09730034726089798, 0.14706025802297518, 0.23087354813469574, 0.16446565452497452, 0.16416452068369836, 0.26304418046493083, 0.1493366327486001, 0.16424257977632806, 0.20513031544396654, 0.12338589556748047, 0.17049879563273862, 0.14519090676913038, 0.1226103215594776, 0.18288810504600406, 0.20303658326156437, 0.14987761387601495, 0.12108851064112969, 0.2434188569895923, 0.12929162476211786, 0.14318357541924343, 0.10332059726351872, 0.31983044114895165, 0.09238681755959988, 0.11479187742224894, 0.13328626431757584, 0.16174977994523942, 0.27309191005770117, 0.19558408472221345, 0.12364959547994658, 0.1249916508095339, 0.07926511229015887, 0.13963290344690904, 0.20649708429118618, 0.109355734748533, 0.1707789266947657, 0.13242213724879548, 0.12746678752591833, 0.1446934006526135, 0.16996844206005335, 0.12336471467278898, 0.07206050591776147, 0.14888105797581375, 0.16545125632546842, 0.08508118262398057, 0.13436371431453153, 0.163324513414409, 0.1481714757392183, 0.1529312992352061, 0.1383491957676597, 0.07875523457187228, 0.08184156700735912, 0.10171743953833356, 0.1585784344933927, 0.11320230099954642, 0.12823121447581798, 0.15186771255685017, 0.17797734355553985, 0.1041347481077537, 0.13731134677072987, 0.1424935710383579, 0.10700196144171059, 0.0991118629463017, 0.15281004714779556, 0.12796178518328816, 0.15290756535250694, 0.13644178718095645, 0.21400922181783244, 0.0846611344604753, 0.17834884783951566, 0.2311104119871743, 0.11353748457622714, 0.07984994692378677, 0.1271626999368891, 0.14102824497967958, 0.1035670422425028, 0.0798801523342263, 0.17759994661901146, 0.11489764830912463, 0.10244399469229393, 0.16908071469515562, 0.2118841264746152, 0.12683611043030396, 0.15543132758466527, 0.14746729633770883, 0.15018179052276537, 0.1333109036204405, 0.1423948653973639, 0.10247835612972267, 0.12728175526717678, 0.07293374656001106, 0.11811633536126465, 0.32144746219273657, 0.0950943875068333, 0.17454807210015133, 0.11866634842590429, 0.10933605299214832, 0.09913570815115236, 0.21231797116342932, 0.2033505859435536, 0.22751031297957525], [0.06513834610814229, 0.05445887443784159, 0.05259431003651116, 0.013944301754236221, 0.0030805643245912506, 0.08681012695888057, 0.025856489992293064, 0.05050582483818289, 0.025284106741310097, 0.07799224738846533, 0.0549617314391071, 0.03968492579588201, 0.01855694252299145, 0.03185715657309629, 0.03463675195234828, 0.038619925326202065, 0.014168441484798677, 0.04561762463708874, 0.0733958522323519, 0.043130698904860765, 0.027108118338219356, 0.02998122618009802, 0.02306729307747446, 0.04597952181939036, 0.02744399396760855, 0.03981277928687632, 0.041942409152397886, 0.050282846568734385, 0.02538313521654345, 0.01372642203932628, 0.026774610159918666, 0.07245558823342435, 0.0553025850240374, 0.07263216000865214, 0.02018736304307822, 0.03995350904006045, 0.08072859040112235, 0.04097878605534788, 0.012066281287843594, 0.08224394463468343, 0.05026039660151582, 0.07514825585531071, 0.028272323543205857, 0.06825019358075224, 0.06012627032760065, 0.021238611516309902, 0.050648855249164626, 0.013853230957465712, 0.037696081344620325, 0.03329481165565085, 0.030839328865113202, 0.03971171361627057, 0.050704831737675704, 0.03472439959296025, 0.004976163718311, 0.05753578901931178, 0.019473541287879925, 0.02666385018528672, 0.008692745122971246, 0.12112101670936681, 0.05230822695011739, 0.018901248949987348, 0.04701245779870078, 0.00917377277801279, 0.06887717478093691, 0.04125444196688477, 0.022791260525991675, 0.06310092809144408, 0.022163275571074337, 0.04116549185710028, 0.021030637617514003, 0.04855691164266318, 0.12506650382420048, 0.038927063142182305, 0.0428207780350931, 0.015696286063757725, 0.05678490626451094, 0.0023797473158992943, 0.006375020248015062, 0.028412854771886487, 0.09521279716864228, 0.03494169301120564, 0.03433174410020001, 0.07462507885065861, 0.02959894776722649, 0.02630181199492654, 0.03877475959598087, 0.0932931802526582, 0.04169666179222986, 0.03917072506737895, 0.014672470151708694, 0.018192687166447286, 0.07909821812063456, 0.0834810380183626, 0.10675623634597287, 0.11057665673433803, 0.061616480597876944, 0.04359311256848741, 0.02237000266177347, 0.021421489691419993, 0.02065013293758966, 0.022634379783994518, 0.02880219471990131, 0.013390104832069483, 0.04165180267591495, 0.03555553819751367, 0.07182814690168016, 0.038339400925906375, 0.006310750259217457, 0.04783548843988683, 0.03803354331466835, 0.0338866966922069, 0.03314368070277851, 0.02539850138418842, 0.02032494237937499, 0.04168129562458489, 0.04443831858225167, 0.017654574439802673, 0.029793832036375534, 0.01633167950785719, 0.03928411038941704, 0.05504480373929255, 0.02778570844384376, 0.01647009190492099, 0.07606426646816544, 0.03934549713449087, 0.01979105618374888, 0.058821574712055735, 0.045129087375244126, 0.1037554290087428, 0.04485530167585239, 0.11233229612116702, 0.08532999505405314, 0.0374156534235226, 0.010345162900193827, 0.06896344944834709, 0.008457668918708805, 0.056049089107546024, 0.030216080667742062, 0.05774265526270028, 0.020887121099804062, 0.05085467877506744, 0.05231662806181703, 0.04285744755179621, 0.04727277351776138, 0.03128120173641946, 0.04648942551284563, 0.010629945372784277, 0.05854483897564933, 0.023813648731447756, 0.02683537906705169, 0.03826123422186356, 0.03833997237961739, 0.10888084187172353, 0.04441885947016999, 0.03140506989439018, 0.013488527529261773, 0.028942802018718794, 0.017390637040080037, 0.013162320228730096, 0.07971394836204126, 0.07059766605379991, 0.029137545279809274, 0.036467637692112476, 0.07287565123988315, 0.05692185848602094, 0.01648330027819611, 0.07092921310686506, 0.01653331175475614, 0.0715351544204168, 0.030184090392140206, 0.04937199759297073, 0.02925696982856607, 0.022454379286500625, 0.030197712512745056, 0.09182012101518922, 0.015002383552200627, 0.08571298778406344, 0.06029581025359221, 0.032823603542055935, 0.04560480774671305, 0.009370993884658674, 0.05388545774621889, 0.02785980817861855, 0.042244359356118366, 0.01712748817226384, 0.07147590134991333, 0.05806642089737579, 0.05124750125105493, 0.06001647328957915, 0.062373756954912096, 0.07031924193142913, 0.006994072527959361, 0.057540156558388844, 0.04502141287957784, 0.02999622498464305, 0.02763999145827256, 0.038652368311886676, 0.10753831898909993, 0.03302083299786318, 0.013652877987624379, 0.05121736634464469, 0.06573083228431642, 0.025047706731129438, 0.06787279664422385, 0.055826574680395424, 0.001323585477166489, 0.018741384774330072, 0.036077060212846845, 0.07702802686253563, 0.05411129699496087, 0.020219371872371994, 0.02726070575590711, 0.04064861568622291, 0.01810890611523064, 0.019888351744157262, 0.028090694031561725, 0.07722856258624233, 0.00684195776557317, 0.01939690155268181, 0.011090310708823381, 0.03267106250859797, 0.0936426650150679, 0.019145165060763247, 0.03530731577484403, 0.019811522761301603, 0.029291908285813406, 0.07557205186458305, 0.01311324849666562, 0.02173148106521694, 0.05384973075706512, 0.018664765448193066, 0.021036489451944362, 0.043828276902786456, 0.019686302039190196, 0.05246061955404002, 0.01976659128558822, 0.02620292638312094, 0.043231478848611005, 0.03738432365935296, 0.034099307158612646, 0.08732930378755555, 0.039020451295073144, 0.05624658573651686, 0.021772145191789605, 0.03473982884315774, 0.05476324775372632, 0.056745060355751775, 0.06319642765447497, 0.025398275029147044, 0.046649495634483173, 0.01753960648784414, 0.047998493755585514, 0.03128062657197006, 0.04870377895713318, 0.011584083822526736, 0.07912251603556797, 0.015529276861343533, 0.07613753870828077, 0.032807354218675755, 0.043259261146886274, 0.030143708281684667, 0.0598343836463755, 0.05335834364814218, 0.044098496582591906, 0.015909193389234133, 0.061588594398926944, 0.0636291442788206, 0.044962148676859215, 0.053111342058400624, 0.02983457779919263, 0.1341058179968968, 0.02805753672873834, 0.03727171388163697, 0.043481938846525736, 0.04738583600556012, 0.03466139125521295, 0.05829081666888669, 0.02122998961567646, 0.01040918334183516, 0.06365640336298384, 0.062095043394947425, 0.060832802337245084, 0.022765808571421076, 0.03409696939343121, 0.021826505653734785, 0.0400391269067768, 0.0657663811580278, 0.02507767279894324, 0.02745213161688298, 0.035987182418466546, 0.05818289355374873, 0.07031299304799177, 0.04354237193183508, 0.1511339214630425, 0.03148545933072455, 0.0640198627661448, 0.014081497029110324, 0.07934421038953587, 0.013510438511730172, 0.0347586942370981, 0.05413709033746272, 0.027466859537526034, 0.04377779972855933, 0.07518393831560388, 0.05860432211193256, 0.05507918001967482, 0.06591167140868492, 0.015619368023180868, 0.0033339987112412928, 0.03291587105195504, 0.01997243336518295, 0.009770361175469588, 0.02535821018682327, 0.03349405604240019, 0.017858258725027554, 0.037338659312808886, 0.04787182027939707, 0.030444001640717033, 0.032219220738625154, 0.0895933217543643, 0.0332290017104242, 0.07996031912625767, 0.03858387550280895, 0.08564073228626512, 0.024792153744783718, 0.024479575986333657, 0.012715532484435244, 0.02689566001208732, 0.019238549502915703, 0.010226394224446267, 0.031727143432362936, 0.03606466263590846, 0.033016224260791205, 0.006446921834140085, 0.027363912522559986, 0.009859142446657643, 0.01864729343651561, 0.02902159954828676, 0.008474126971123042, 0.03481065570667852, 0.048083792498800904, 0.07833745738025755, 0.03839486904325895, 0.024358782175113447, 0.032230586730293, 0.016891255145310424, 0.019376340351300314, 0.028333381887932774, 0.023569320728711318, 0.08542960611521266, 0.03166666952893138, 0.22181566542712972, 0.11217699429835193, 0.18974301143316552, 0.09364700657897629, 0.1474573218729347, 0.16687393857864663, 0.16498503915499896, 0.12847762234741822, 0.0978141138330102, 0.12850957922637463, 0.11558507001609541, 0.16012230946216732, 0.1591419175383635, 0.18314362649107352, 0.11165553907630965, 0.11111863976111636, 0.14041917922440916, 0.13195220933994278, 0.1107217391836457, 0.15980648109689355, 0.15464775322470814, 0.12057432104484178, 0.18842550634872168, 0.13822691951645538, 0.13894181553041562, 0.10019731329521164, 0.14638702617958188, 0.09600489880540408, 0.18105646973708645, 0.10033143422333524, 0.1511227447190322, 0.13019576843362302, 0.12332204118138179, 0.1313258070149459, 0.141924625786487, 0.14990712166763842, 0.15281675616279244, 0.16388590360293165, 0.1395491891889833, 0.23443468438927084, 0.08464779806672595, 0.18656271568033844, 0.07447631534887478, 0.12782111851265654, 0.0925384605943691, 0.2422058314550668, 0.2025033946847543, 0.08351747004780918, 0.06961924082133919, 0.22991445584921166, 0.10431382092065178, 0.19928254798287526, 0.14880363713018596, 0.10363327892264351, 0.13640919205499813, 0.17757213092409074, 0.1744576042983681, 0.14891126338625327, 0.11305167470709421, 0.23035628604702652, 0.12952596531249583, 0.20861266530118883, 0.1070874123251997, 0.16000316507415846, 0.1891185386921279, 0.2168851182796061, 0.1872341663693078, 0.13853102194843814, 0.08086824775091372, 0.14117475977400318, 0.19722313270904124, 0.2370465692365542, 0.2271683610160835, 0.13786112976958975, 0.10132470983080566, 0.11824506087577902, 0.17139958479674533, 0.09130174570600502, 0.19341610808623955, 0.1559134860872291, 0.1701367463101633, 0.1636871712980792, 0.1619597928947769, 0.13669101521372795, 0.10999596328474581, 0.1495863654417917, 0.16163314401637763, 0.1617508931667544, 0.28030074667185545, 0.07591305387904868, 0.11716139910276979, 0.20505163294728845, 0.1083976443624124, 0.14515129092615098, 0.2738277049502358, 0.1925378356827423, 0.13839019200531766, 0.16455707227578387, 0.10409456081106327, 0.12189060158561915, 0.15115342510398477, 0.09883135338895954, 0.13645637780427933, 0.11157111235661432, 0.1431523755309172, 0.1137124904198572, 0.1798810117179528, 0.14182241720845923, 0.14800146454945207, 0.07700314265093766, 0.1583688223036006, 0.17138333176262677, 0.1474311834317632, 0.06618267405428924, 0.1223350441432558, 0.12975221645319834, 0.1508959147031419, 0.17349811125313863, 0.22828870714874938, 0.1611833431525156, 0.10310531506547704, 0.06825525502790697, 0.12207377847516909, 0.1468857197323814, 0.15188319375738502, 0.17621398583287373, 0.12502948549808934, 0.1571842803969048, 0.16432256845291704, 0.16994113102555275, 0.14727174042491242, 0.17963815131224692, 0.17889299051603302, 0.0913436028349679, 0.11199287488125265, 0.12069521690136753, 0.13455159642035142, 0.19371559435967356, 0.10300685433321632, 0.10008069220930338, 0.08825220153084956, 0.20379660185426474, 0.2119813923491165, 0.13618297060020268, 0.1787105409312062, 0.20863363839453086, 0.2321497304365039, 0.11310144313029014, 0.21777428541099653, 0.10547701866016723, 0.16599680908257142, 0.11091237465734594, 0.13434663007501513, 0.21558049687882885, 0.24255477444967255, 0.10265734730637632, 0.09422486502444372, 0.10030184479546733, 0.11046691535739228, 0.11377382150385529, 0.1258125255117193, 0.1731068064691499, 0.11402486779843457, 0.0936515411012806, 0.22732520650606602, 0.18974979466293007, 0.17162380245281383, 0.21027684240834787, 0.19620063132606447, 0.07632915381691419, 0.10640926004271023, 0.11729589110473171, 0.09828443508013152, 0.08992068309453316, 0.23719802673440427, 0.24275775183923542], [0.06351247124257497, 0.056947870762087405, 0.029891674930695444, 0.03376496591954492, 0.05477192346006632, 0.009031975259858882, 0.020791014831047505, 0.041194943987648, 0.045972656953381374, 0.08162110461853445, 0.02640812464960618, 0.08155194387654774, 0.015362173035100568, 0.053313992902985774, 0.006611581675315392, 0.04653101546864491, 0.03792154209804721, 0.0010891670012824761, 0.015671566980017815, 0.09887228283332661, 0.044703543608193286, 0.02910610975959571, 0.05424423419754021, 0.022379016045306344, 0.09605908300727606, 0.04459612144273706, 0.040670379166840576, 0.027323760477884207, 0.05047277329140343, 0.06374109725584276, 0.028409663536876906, 0.04753539731609635, 0.020470768831728492, 0.02848756492312532, 0.031001701499917544, 0.0358958759898087, 0.03737083141459152, 0.048289590049535036, 0.06419083874789067, 0.020798645964532625, 0.019588104769354686, 0.06497076916275546, 0.08351825672434643, 0.05740707092627417, 0.01741376607242273, 0.06423146391171031, 0.05930220439040568, 0.0439189191092737, 0.029848045924154576, 0.0606809292366961, 0.066527230956126, 0.03323969976918306, 0.03883349687384907, 0.12087618219084106, 0.02010223313845927, 0.07446889387210831, 0.025624524314480368, 0.07159764325479046, 0.02471313542628195, 0.05680737107468303, 0.09611956804292277, 0.013162006671336712, 0.04584546397381928, 0.033260372292716056, 0.02875816309824586, 0.0438192375440849, 0.09121828377828933, 0.07024005477433093, 0.0703228561906144, 0.06259871675865725, 0.03095278654654976, 0.012150277561886469, 0.04793569321918767, 0.021470838801178616, 0.05206087284022942, 0.04418120894115418, 0.0642205766052939, 0.05516746219655033, 0.03487086243694648, 0.0441916732233949, 0.04692726295616012, 0.03558537253411487, 0.026511400064919144, 0.02116237625159556, 0.01983986538107274, 0.06088161338993814, 0.01953190007043304, 0.04524861396930646, 0.05041876720497385, 0.01851110006100498, 0.031559217677568085, 0.02190748509747209, 0.010133978285011835, 0.07418747147312388, 0.0477381372184027, 0.017023732216330245, 0.04676825410570018, 0.023698144577792846, 0.08643421431770548, 0.019052747265959624, 0.021979892735544126, 0.020675152591138612, 0.03525229294609744, 0.027379941057006363, 0.07230428658658639, 0.06193248707859311, 0.12095739541109651, 0.013539753344957717, 0.08697402285179123, 0.055929388108779676, 0.0178986612445442, 0.03034503068192862, 0.11322645048494451, 0.11061164157581516, 0.060831344017060474, 0.03505365712044295, 0.017766694400052074, 0.05218146070546936, 0.05617935457848944, 0.011703779255185509, 0.06604980735573918, 0.020840037395828404, 0.06523531512357295, 0.02232982835266739, 0.04207552075968124, 0.010476998013473349, 0.11387040460249409, 0.026930633721349295, 0.04044152679853141, 0.079974323452916, 0.06584020258742385, 0.061730630332021974, 0.018771985378407408, 0.04849380311497953, 0.017428115497750696, 0.04600792752171401, 0.04040217441797722, 0.03858558244246524, 0.021082673301862087, 0.03570283224689774, 0.05131150406668894, 0.046846213008393534, 0.005515696266229497, 0.0331974641449051, 0.027996018252451904, 0.03555856616003439, 0.08517052978277206, 0.07432567421346903, 0.03264719503931701, 0.03589609121263493, 0.058132720660069026, 0.008232317632064223, 0.024872066351235844, 0.02766225217783358, 0.06121101563621778, 0.05508163281774614, 0.026803633700183127, 0.04539159614068922, 0.017463779404351953, 0.023399971905746497, 0.026544132488197647, 0.04173753557552118, 0.07375039844191633, 0.008795998273853911, 0.08233759624999948, 0.04386571825307328, 0.027675926248775795, 0.04811636907106731, 0.0203251390485093, 0.025000535824801773, 0.043715537249227054, 0.013955163085483946, 0.0481763939751545, 0.07403394338325597, 0.0665495621797163, 0.04931664821924642, 0.08699416473973542, 0.039440889086108655, 0.003504986752886907, 0.049576618839637376, 0.0565762774203904, 0.06863178365165368, 0.005482950855366653, 0.028754392988048494, 0.05414427432697266, 0.016529456297575962, 0.07492006770917214, 0.0633985070453491, 0.012839130686188582, 0.037469195667654276, 0.10244567936751992, 0.07164386421209201, 0.05998515465762466, 0.011210052525711944, 0.002202494156335888, 0.08642429922474548, 0.0076861484285473125, 0.015468634119315539, 0.048783481906866655, 0.034491706610424444, 0.05301706332829781, 0.030547824389941525, 0.053338450379669666, 0.0319943054637406, 0.01797080727556022, 0.024231160605268087, 0.010547985366429202, 0.03597476257709786, 0.054041854236857034, 0.004936811337756808, 0.023733170237392187, 0.011884155464940704, 0.025307630967290606, 0.006753278539690655, 0.02966676707728766, 0.025999396093538962, 0.04097445562365465, 0.019312202093715314, 0.06394362935679965, 0.03961927541240584, 0.04057228950841818, 0.024569472334405873, 0.0427488268178422, 0.06108990084612742, 0.020121809138800018, 0.008242496187449433, 0.02884079010982532, 0.014049617147975368, 0.01915571283461759, 0.02462629858200671, 0.015830215888854582, 0.02402234065812081, 0.019613534459494986, 0.024793994271021802, 0.011534225413925014, 0.05194838922761846, 0.05622179429337848, 0.08637775914394297, 0.0726135988952592, 0.06304941562120803, 0.04487157326366287, 0.01396998841300956, 0.05964169242361095, 0.08579061643104069, 0.014608622259402182, 0.0268976341249072, 0.045235537327243946, 0.028282800813030917, 0.07693024148466066, 0.04607197115547024, 0.05103261981275864, 0.01821354522689944, 0.13658442796440795, 0.08112169860396534, 0.007735060135019012, 0.02048819816991454, 0.0347536698973272, 0.026668733516999055, 0.11140386195620522, 0.041078593785641715, 0.058276348499930464, 0.04205077013466507, 0.03000452405103715, 0.06003379872709047, 0.022303688056126703, 0.032730215389165096, 0.043432452439446934, 0.07569284382043406, 0.05381816721637733, 0.03531848138663918, 0.038143945203046314, 0.03904831894033123, 0.048438142039231025, 0.04551823622023221, 0.03948420082451776, 0.04922455511405133, 0.04898566519841552, 0.027411367300373968, 0.06907756207510829, 0.03067051624384476, 0.017931139482243452, 0.035537136645871215, 0.04380269878311083, 0.04753061417432036, 0.03719411120982841, 0.06795832916395739, 0.0729692805907689, 0.03319399831525516, 0.03772531454160344, 0.01960543762834277, 0.04229813537676819, 0.01503629320723121, 0.012920513672725065, 0.029899879373260774, 0.027910482021979988, 0.05711584846721962, 0.04836948595766444, 0.013772008460364304, 0.03725648501131218, 0.07898600539192557, 0.05269125678751152, 0.07613370922626927, 0.06608534880797379, 0.024519971084373537, 0.0411164433171507, 0.033660508634056896, 0.02541657268011477, 0.057234272971982136, 0.04429736618476454, 0.030494764541799668, 0.0344976697670063, 0.021067680063424632, 0.07015494527877308, 0.040345960442209616, 0.02797085944621358, 0.03897269409208093, 0.06273808467085473, 0.06320945976767689, 0.03006890165124787, 0.06542891918797977, 0.03729511379788164, 0.014743027986696688, 0.041792695701587945, 0.07847485860111192, 0.04755126443342306, 0.036576451384462416, 0.07446429997798987, 0.05155802697117906, 0.01951216079760343, 0.11636645504040644, 0.0266025933160563, 0.08263011375674978, 0.029819881419825833, 0.030240334053814877, 0.05729223099478986, 0.014707040318171494, 0.026368102480773814, 0.08530738181434572, 0.13754369836533442, 0.044334480990073644, 0.05227630717854481, 0.03792754978348967, 0.03257991193095222, 0.022162874811328948, 0.05750313081080094, 0.051584540196927264, 0.01856054564996157, 0.00939096878937562, 0.003295478231848392, 0.016545113758184016, 0.010522527845751029, 0.013592782579507912, 0.24760045838775113, 0.13342339836526662, 0.14088554482441396, 0.1509647414786741, 0.15575674449792132, 0.08143730432493612, 0.08548538593458943, 0.10098730723257177, 0.25564146519172937, 0.18513995921239257, 0.12304714968195185, 0.15372560505056754, 0.10204868231085129, 0.14186406653607264, 0.2340128179639578, 0.14184386527631432, 0.1809629294439219, 0.07945428573293611, 0.1336166833061725, 0.2942407736554742, 0.16037781606428325, 0.10456086703925394, 0.15370357810752466, 0.10162530932575464, 0.12296822969801724, 0.1239838513720315, 0.09463976268307306, 0.15773237129906192, 0.11429427482653409, 0.1505269337212667, 0.10596754858852364, 0.09465306939091533, 0.11756485284422524, 0.05709499411750585, 0.14519607211695984, 0.153544862405397, 0.11663589917588979, 0.09486448499956168, 0.2413082928978838, 0.09245142151485197, 0.12030110679916106, 0.13151998253306374, 0.14522384328301996, 0.19015180121641606, 0.07901322736870497, 0.20803039107704535, 0.25085986708290875, 0.20528917957562953, 0.06558242501341738, 0.2175522199831903, 0.1800969915348105, 0.16520326025784016, 0.12527028273325413, 0.2193808273295872, 0.16171562630916014, 0.17383831174811348, 0.08266061602625996, 0.1784716732800007, 0.11521018896019086, 0.12966495472937822, 0.17170723469462246, 0.13464430550811812, 0.13011395407374948, 0.18778690311592072, 0.09384279255755246, 0.12744232633849606, 0.1159711649233941, 0.19926276232581586, 0.15688679792219773, 0.16544528945814818, 0.09927634513587691, 0.12134456643252634, 0.198131833167281, 0.13527050003176555, 0.14997853111708537, 0.10381703468738124, 0.23751057480694726, 0.19659411802422255, 0.12583504227222875, 0.1723119811504148, 0.12169104549684562, 0.13693334127310663, 0.10593031503958628, 0.10088897266541608, 0.0717362690193113, 0.16972173732938245, 0.08054264530073851, 0.1229795919789467, 0.2483578200917691, 0.11113360145827755, 0.13132165098795667, 0.20424476999323815, 0.11300385813228786, 0.0982206103799399, 0.1514242496341467, 0.11462039678008296, 0.14686783397337422, 0.13138382812030613, 0.21276714862324297, 0.18657524313312024, 0.13423955300822854, 0.18066149874357507, 0.1319256701390259, 0.15033299569040537, 0.10339366912376136, 0.12246455633430742, 0.2993074752157554, 0.13683761906577274, 0.13019780191825703, 0.30345988052431494, 0.11011317066731863, 0.10092329699546099, 0.20992073026718572, 0.252778556314297, 0.10268862883094698, 0.13953168934676796, 0.05150157921889331, 0.20399681845447049, 0.18487795139662921, 0.15240720938891172, 0.16438329097582027, 0.13394490553764626, 0.1976386908791028, 0.07448382588336244, 0.1926368975546211, 0.26179416629020125, 0.20898670773021877, 0.09954331791959703, 0.10779954754980281, 0.15818994987057522, 0.2806812903145328, 0.1878160546766594, 0.251324184355326, 0.15540048392722383, 0.06753350156941451, 0.11442889299360104, 0.12857570458436385, 0.14639377972343937, 0.1855251338565722, 0.16139423183631152, 0.19629148504463956, 0.1292936730897054, 0.07850201378460042, 0.1255825042608194, 0.07686595665290952, 0.13263796863611788, 0.259639325668104, 0.29762464051600546, 0.16049955796916038, 0.15726930083474144, 0.17893217591335997, 0.17143740464234725, 0.11427600315073505, 0.21225122240139171, 0.15965664148097858, 0.14672289253212512, 0.12099000538000837, 0.0850067674764432, 0.1456725606112741, 0.09828228285186924, 0.16493783856276423, 0.13702901895157993, 0.2526528958696872, 0.08565527095925063, 0.1476692347205244, 0.10706094733905047, 0.11153585292049684, 0.13430492137558758, 0.11341442164848559, 0.20349879283457994, 0.09662638811278157, 0.10126339358976111, 0.11598379627685063, 0.17337849189061671, 0.16019263537600636, 0.14047666598344222], [0.03511659495416097, 0.0331836305122124, 0.0419789673469495, 0.008624088113720063, 0.024860427620296832, 0.020533311471808702, 0.022306595419649966, 0.03762185915547889, 0.02804015934088966, 0.07436857777065597, 0.04803624680789653, 0.0639007703284733, 0.018837671013898216, 0.052180039492668584, 0.027399576429161243, 0.008009563862287905, 0.04309732081310358, 0.03172152166371234, 0.045414005289785564, 0.03620140334533062, 0.009784014837350696, 0.06777122631319799, 0.04062334555783309, 0.03977095184382051, 0.03959385685448069, 0.02552000394643983, 0.09360776923131198, 0.03447414739639498, 0.0572425590507919, 0.017599158272787463, 0.024654591106809676, 0.07442155227181502, 0.01793990424630465, 0.027945414913119748, 0.0805580522865057, 0.045935935486340895, 0.05477891449118033, 0.04640589308110066, 0.02834863858879544, 0.01575060570758069, 0.03191320727637503, 0.02721423988987226, 0.02040162478806451, 0.03473769516858738, 0.07513233678764664, 0.023360528612101916, 0.07026348437648267, 0.03063626427319832, 0.05985502648400143, 0.07655089269974269, 0.11552925308933482, 0.03829002584097907, 0.06785505189327523, 0.06771306419977918, 0.026005103209172376, 0.026672891399357468, 0.04341674117313232, 0.04677416531194467, 0.021151251457922626, 0.04177160015387926, 0.04927990819851402, 0.009844453488767613, 0.04863330461375881, 0.010203524016105803, 0.018380487636022735, 0.08322529392899014, 0.011371105065336451, 0.03866959727020003, 0.0950115044543054, 0.045793717727065086, 0.1397759301471524, 0.02396231018792605, 0.05422142057796009, 0.03453711120528169, 0.002347767012906843, 0.08989971000119112, 0.023644160755793564, 0.033264825178775936, 0.03399169203476049, 0.025578494460205548, 0.05223048327025026, 0.05435045779449865, 0.009972871011996176, 0.027430516565800644, 0.04153003479586914, 0.05327564984327182, 0.05500587809365243, 0.05459586376673542, 0.01423725341737736, 0.02708645875827642, 0.03908053557097446, 0.01689558743237285, 0.02975919229356805, 0.009741138183017028, 0.09481023400439881, 0.043400584618211724, 0.04928181922878139, 0.0371700767573202, 0.09797672581044026, 0.049096690490841866, 0.1290736411465332, 0.018455817480571568, 0.017022249776346143, 0.04387349224998616, 0.09681792158517055, 0.058039822324644774, 0.0294685004701023, 0.030469694793282542, 0.021903635206399485, 0.04443812191311736, 0.04889203584752977, 0.021695663162972778, 0.01337656713076285, 0.030543558896169998, 0.046728404486202635, 0.03922023002814967, 0.032124982826644555, 0.024402798953815363, 0.054330104394466616, 0.026926605714834295, 0.021892549375479575, 0.04155520102358423, 0.01999392596189864, 0.03891827982442919, 0.03203425898391288, 0.022842778562335297, 0.008205610520235496, 0.04998799500754103, 0.09018753713462502, 0.02556332496169489, 0.00658483791994513, 0.02816323896695394, 0.019902090753021184, 0.03251651767641306, 0.10525843390496448, 0.021008308249292895, 0.0568879386264598, 0.019771955157921184, 0.009616615079721669, 0.035012868684134446, 0.041215523742721416, 0.044177954623592086, 0.04733604160719551, 0.03930522820155602, 0.005349167604435934, 0.03614158995333128, 0.022104263698565774, 0.021599180254270323, 0.04843912538490258, 0.018821809462679084, 0.04333868950197939, 0.017375419301970396, 0.07129066871129908, 0.018010167077591177, 0.04349089285824448, 0.053188139499980025, 0.054444298657472245, 0.09333357535069808, 0.050404076391714625, 0.047224834488588385, 0.011859828791784821, 0.04438151830981951, 0.052893521715304814, 0.05256757045572158, 0.05449709133245051, 0.05184892288525589, 0.044149652821943164, 0.009374700912303524, 0.07499372586607933, 0.02557023435656447, 0.05943116368143819, 0.04616653190169018, 0.032155243898159824, 0.0069809838259971, 0.032982486227410845, 0.008903208927222295, 0.03935176086088177, 0.045465384173439816, 0.07602208279422484, 0.09277864926843904, 0.052567024977179244, 0.06332901233690791, 0.027169065360794775, 0.011403280877857469, 0.018216131611552555, 0.05155385981197469, 0.034333926014369354, 0.0638079721829854, 0.021187067504797596, 0.01831059216783615, 0.04498502537899185, 0.018213871771877166, 0.10960118524963036, 0.019746729558391962, 0.0701244652736932, 0.03898536255292129, 0.0023468451263397583, 0.10462972350069322, 0.07425698102451861, 0.05321114236721769, 0.0763287530571688, 0.007248986339618568, 0.0626735104015097, 0.02365380867558997, 0.04729753898573108, 0.12893024337245151, 0.047063165038707666, 0.07564478233689442, 0.0033333996589135495, 0.031781973302713595, 0.049828774644993246, 0.006569272763954359, 0.02694865492230747, 0.005743593119404977, 0.04155846647336148, 0.09693413448985666, 0.04706408901256509, 0.009481785400566878, 0.03230991860618815, 0.019117553456453606, 0.054720885964343324, 0.062254890872281976, 0.09424280273378827, 0.04288387171982322, 0.034284766152268276, 0.06172007699206006, 0.03437026156461798, 0.031347546027973294, 0.09092521708225831, 0.1513640466146171, 0.012236090242367936, 0.05391481339756865, 0.012842044543504016, 0.026860255857172888, 0.03669800775242038, 0.0559731599787483, 0.02568445459473878, 0.02178050734073622, 0.05529254747671075, 0.07165015762438998, 0.035055315820500255, 0.02608713835797971, 0.01712011122435797, 0.07575436044135131, 0.03992799400293734, 0.07990400496055372, 0.0419543577299919, 0.03405697505513672, 0.04036872953292914, 0.04571400735585485, 0.032534689162275754, 0.01543961428978946, 0.004770160685438896, 0.08657096987008117, 0.0418383414944401, 0.04627019879990257, 0.04468798448215239, 0.05626051584840752, 0.0625087387743406, 0.04295428669138346, 0.02394928364083171, 0.011545957841008203, 0.03915956316632219, 0.0022012914132574224, 0.027735279509215616, 0.06855730913230218, 0.01474062621127814, 0.02303709879925009, 0.008088831727945944, 0.012723025392915588, 0.07964493604958989, 0.004187960212220787, 0.00630895240647078, 0.014928532436897513, 0.08556391258025542, 0.024383777708862908, 0.03879777359543368, 0.018768244954117108, 0.009881053429126041, 0.05949551530648023, 0.04121832906093914, 0.08118362340610474, 0.025681144616100937, 0.026860387588385493, 0.036455689114518464, 0.029624716989928856, 0.04126400453969836, 0.03173498422256671, 0.021777696456410922, 0.001614324380625476, 0.05027376268117223, 0.015003138687461615, 0.016975498183455784, 0.027767126921389718, 0.06327356648398563, 0.037693420745199546, 0.03305421480035875, 0.10201403143582866, 0.022557958982361015, 0.04948980611516163, 0.051353453964111395, 0.023875590231909882, 0.011233518307562917, 0.07795443496434018, 0.027216425514779985, 0.05542902843444608, 0.014091064240346896, 0.02303606721397955, 0.032079552256618626, 0.01467790452807094, 0.042667457746574655, 0.025146427215076983, 0.02976553023472661, 0.01699153599474812, 0.060148286138428375, 0.03385715921467636, 0.05495153433002997, 0.04186982710962184, 0.006908455588927609, 0.058809915572055615, 0.036655586591223255, 0.01994585520151304, 0.051634230694617145, 0.02435888793115737, 0.02916588604421122, 0.016572881213505752, 0.04745192054542713, 0.009701911967567867, 0.05398655681347009, 0.04338675098551903, 0.030052336915105116, 0.05201765015954152, 0.003861652257910464, 0.03141439497994725, 0.03370045844349079, 0.04720943121355958, 0.021186926496739034, 0.039615182467969134, 0.051719299372052774, 0.0774196804559324, 0.04947947913024109, 0.08622259090770967, 0.06821789531386457, 0.024884905506041832, 0.02219485952082323, 0.05823209423397202, 0.03264348430093378, 0.025047690032806713, 0.04270410499884747, 0.05078416732430924, 0.03214941061742138, 0.07359662544331513, 0.13251374795800075, 0.11755378000088967, 0.27914842881727964, 0.19761446717893705, 0.1266886160010472, 0.13328619010280818, 0.1861510463641025, 0.1437314585200511, 0.13669980224221945, 0.15601689694449306, 0.12964037479832768, 0.18393399892374873, 0.0815780229459051, 0.1996090484317392, 0.08818089598207735, 0.11797382816439494, 0.17168577178381383, 0.10177377596846782, 0.12754183349898085, 0.13644120830576867, 0.06877291045384482, 0.2132536709541455, 0.12476623087422922, 0.14555239205947146, 0.21903982531512156, 0.09096984242205508, 0.17891810479341075, 0.12500619690399617, 0.18877247523050755, 0.23599932465003803, 0.11137309251353145, 0.21278945758240297, 0.08029772172449157, 0.07249856600537896, 0.13965025485958904, 0.11960961070144549, 0.11691030827932991, 0.11916214018128812, 0.1292373292380944, 0.11905817271326669, 0.1279723533662036, 0.15956893446855247, 0.12119537248509005, 0.21745695790741593, 0.24254857009509578, 0.19153568398905918, 0.19403017591685057, 0.11938940064283088, 0.09460210610996, 0.16002345539163798, 0.2032703152508475, 0.12181870231870562, 0.19898012280464172, 0.22479700623080134, 0.14957677689380944, 0.1427101148874499, 0.1300318873836659, 0.08519657916622236, 0.1597473764559254, 0.13263047294458374, 0.12975566001841798, 0.06768306659068912, 0.1161308008886408, 0.13014322437811643, 0.10484646772965789, 0.16404738009441644, 0.06313671445241198, 0.13392704946454614, 0.12572155304951593, 0.18498470191843808, 0.17891314724693075, 0.12744321691570804, 0.1668549099122174, 0.1446671286248602, 0.1667352905496955, 0.177071760117542, 0.10462520382134244, 0.15583052881993353, 0.1462683716090396, 0.07106172357453033, 0.1275612332392484, 0.1625902918749489, 0.1340196843375452, 0.12875309272203594, 0.12112940297811292, 0.10296130873030052, 0.12333508071606047, 0.13922191690653563, 0.15500150533625856, 0.1792834492516704, 0.09711757113109343, 0.10735410309280269, 0.0933377313776873, 0.12350271703326143, 0.17988973937463015, 0.1250910243834369, 0.14594224223401397, 0.07943818112835288, 0.19625782122602686, 0.10483580306754448, 0.18751502473605797, 0.09343139041448012, 0.07315092123462819, 0.14952306024497375, 0.1475708556245081, 0.12223803059896454, 0.17017882608342916, 0.0974594934086781, 0.14833749417448416, 0.12158476252807304, 0.13035427633440122, 0.08814562170300633, 0.1337337348377332, 0.09490663156611845, 0.1604013124597259, 0.1510693843010813, 0.12238627459737472, 0.17349990725051612, 0.1230592021602206, 0.1548361251479946, 0.10305802541552112, 0.10053890902781859, 0.06385446773492731, 0.1721701567294076, 0.13102537079248577, 0.13995403074659407, 0.11543782049557194, 0.17154688626760617, 0.14724843698786572, 0.13100867246976122, 0.09416034270543605, 0.16884239623323083, 0.10501759956241585, 0.09904937411192805, 0.23085327266016975, 0.11761575675336644, 0.1728810154600069, 0.12328246986726299, 0.1506780943600461, 0.1037987184827216, 0.121556798403617, 0.12558262300444767, 0.12001131297438405, 0.1279003353556618, 0.08282828202936798, 0.07859150195145048, 0.09437745800823905, 0.07831526716472581, 0.1400115026626736, 0.11369464918971062, 0.16315502172801644, 0.11196266204933636, 0.14061044552363455, 0.10963519787765108, 0.0716444653517101, 0.21411569032352418, 0.09767451585503295, 0.12991050170967355, 0.19524143513990566, 0.1650395870092325, 0.06711847774568014, 0.08502445285557769, 0.10540680406847969, 0.11646911632851698, 0.21340211533242837, 0.20062755706021562, 0.19956141739385203, 0.0784583977656439, 0.17567165399668738, 0.12442486520740204, 0.14329365076264367, 0.11939529329538345, 0.13310635287780315, 0.22943821968510747, 0.09929069085046649, 0.1218716471339576], [0.03712738100148272, 0.05947548845142592, 0.0422220429754816, 0.047894904782879166, 0.0055179704850161215, 0.03629102880950086, 0.10420268430607393, 0.04495149514696095, 0.013663474001077702, 0.03372972503711935, 0.022752405384380836, 0.0660153197532054, 0.0809137562464457, 0.09154351515462622, 0.03552731803210918, 0.05077354348031804, 0.021639475162373856, 0.02826796528097475, 0.007295248115042341, 0.046284522250061855, 0.03966911062889267, 0.012484334001783282, 0.029615900275530294, 0.06978042045375332, 0.04370141788967885, 0.006630395118918386, 0.029650653195858467, 0.04055138320836704, 0.09396660505444743, 0.008722273323655827, 0.06250607446418144, 0.05380987000535242, 0.025926274138328154, 0.02799273053824436, 0.08345604248461314, 0.023039091465761885, 0.025642374821472913, 0.03346120487549342, 0.024229219889093656, 0.0322106229577912, 0.030918970587663352, 0.04325377296481747, 0.057700289762578905, 0.0188032149526407, 0.03700940178532619, 0.026813389231392648, 0.05111395177664235, 0.05193193952436559, 0.021417062780528795, 0.04154029498749878, 0.02644839358254103, 0.040439934891765006, 0.02490275972377276, 0.015971980938047636, 0.054464462809846736, 0.06785766425309703, 0.09596658914233558, 0.03316706948680803, 0.02763799322565319, 0.08461532910587266, 0.015075594565132633, 0.03199361155566294, 0.02214689266111236, 0.016759501668275334, 0.0962929634260945, 0.04582116234814748, 0.029258383619890083, 0.00903479078260716, 0.07738023530691862, 0.03681179754494224, 0.045961020077811554, 0.03390445628610905, 0.03343375283293426, 0.06346069159917533, 0.04425399507454131, 0.028506819944595918, 0.026797518403327558, 0.045892018897575326, 0.06630833449889906, 0.010061895336548332, 0.05230031194514595, 0.03661630100395996, 0.03573592461179942, 0.08007811280549504, 0.022895805013831705, 0.024809904061839916, 0.0372946351126302, 0.05751765093009453, 0.09259144251700491, 0.06591640631086193, 0.0860295063466765, 0.018698069325182587, 0.013019608941249317, 0.046650586591567844, 0.03480302642856259, 0.05024657781177666, 0.030628748172603082, 0.015453910837095464, 0.0466168003185885, 0.042404696650919504, 0.020163992812740617, 0.021374120260588825, 0.007735818517176085, 0.05988964025164023, 0.0190074929560069, 0.034317687823204324, 0.024668669648235664, 0.03691523066663649, 0.02765393270237837, 0.04343880522355903, 0.011000495996995596, 0.021194546498009004, 0.04200808180030435, 0.035044528704020195, 0.021867954601475503, 0.06230631057405844, 0.023002230846032035, 0.04873379883065354, 0.032230456854449585, 0.027167263797309715, 0.05308517393132206, 0.03371348684595432, 0.03920058908988722, 0.04350316427007783, 0.11040324650821276, 0.014411549582291627, 0.05122862472489942, 0.0198701951012481, 0.04690362555265892, 0.014185618492774665, 0.02657645301951561, 0.031481711484957486, 0.021063956337457057, 0.07500792315113358, 0.015332654111261945, 0.010588798850221792, 0.016055797241278924, 0.0038665049760311376, 0.048033185448730364, 0.023420256657118443, 0.02028825801971834, 0.047230675190803595, 0.0927304541983176, 0.02494797507097246, 0.033798596341512166, 0.007305168310267618, 0.06330271062324755, 0.030294564639916644, 0.022313181980280206, 0.016571380219829734, 0.02532149985199794, 0.02239251942228293, 0.05944673393969424, 0.02911936451710062, 0.00513643190060975, 0.04276221516192891, 0.04384574705909472, 0.0419134134426713, 0.0033123395951406565, 0.021409680266515352, 0.03400881338166073, 0.06252724793739617, 0.009923747329594335, 0.06371660638251342, 0.022337782320391852, 0.0030111711976132938, 0.02685878826014232, 0.03661691698653158, 0.11157359112985432, 0.04308635187044274, 0.1068415462214034, 0.021933790521870833, 0.04435123126313556, 0.07509479895816185, 0.038139414391480386, 0.08177282186807133, 0.021531142010644544, 0.02026894177106442, 0.07188069095718674, 0.02947812983620679, 0.004510865419433685, 0.04410342444316484, 0.022210728493519127, 0.03382322822290007, 0.052322431656648405, 0.03413313053897582, 0.023884455185907427, 0.012516450442490168, 0.01735892321448773, 0.08598614265793003, 0.01908904199808603, 0.06414265852072276, 0.045648156592505984, 0.008445230523648206, 0.049806910974439234, 0.0342752666620072, 0.05762522152508609, 0.06467024388257414, 0.009106216002692236, 0.023618482446181588, 0.03207206398656126, 0.0702335980895441, 0.07170670185587369, 0.06459847078076564, 0.055999962642090395, 0.01874010828032624, 0.0377064231724944, 0.04572640122205485, 0.06875109873362817, 0.024712018494028598, 0.031697639351477847, 0.06610120108234696, 0.009225701778632356, 0.038767698060837574, 0.04756353584525641, 0.02694387178053148, 0.0332940695079742, 0.010852781706489623, 0.04357903031632304, 0.03834577226371039, 0.02592671757156495, 0.059438707612571307, 0.0593491192557849, 0.03647575307695661, 0.07859110119170509, 0.05988892036839388, 0.0076469616396934725, 0.14125461486401036, 0.054504052677657455, 0.05888449770282023, 0.017767648059816565, 0.0949420320102945, 0.00898911715921713, 0.07283915983862244, 0.011889339366462082, 0.047732303937664255, 0.036634056887123734, 0.03672342259960715, 0.035366401862120256, 0.03304562815173995, 0.043295422292430885, 0.04178644681815058, 0.058497211648500524, 0.03669285724754445, 0.09962756652384996, 0.07756335282465443, 0.04210202656395268, 0.03718614796525799, 0.02865387279598508, 0.06925586305442266, 0.03789060938288458, 0.03111266556516057, 0.020890013620373793, 0.06598990119528025, 0.02963521095807664, 0.01761849121976411, 0.03122654256003443, 0.05006156410672702, 0.022691259837301914, 0.05359594593755901, 0.07071001979056746, 0.016519639539183117, 0.006787177526348387, 0.03455624377238564, 0.03363424402778037, 0.036990977969253436, 0.02961682424938772, 0.0751859718002379, 0.04326617425249424, 0.05420683737611398, 0.042009265525848605, 0.017228874821739737, 0.04771384301420767, 0.036518738270387985, 0.051102352008456364, 0.020900175477436278, 0.013942492769274395, 0.01853412890341133, 0.02258384323795326, 0.04162872559390962, 0.010187335919908946, 0.014095840888330713, 0.010469289882166777, 0.012000880451523699, 0.010481637364136986, 0.046952536795288324, 0.06597998610232025, 0.0035673375941769336, 0.01383461418299703, 0.06965053718886338, 0.06041571163223125, 0.04802931514859665, 0.07195312457042746, 0.03247258624469396, 0.023663222818868235, 0.03295840353530366, 0.027473989721329417, 0.019710664892045315, 0.09136132532148622, 0.07865928972023539, 0.03600355419621337, 0.05798766418593004, 0.028929239269928075, 0.019566239243431482, 0.04143279860727489, 0.03703426002175547, 0.11949099323828705, 0.04822754650376737, 0.05187962553463876, 0.05591639310296159, 0.015942864629323594, 0.03948345867684111, 0.03510282069328241, 0.03195001780113671, 0.06591956043848768, 0.012367231447569793, 0.023604045818501618, 0.11066724327974953, 0.03586430502764415, 0.028391681298671756, 0.02074387917673448, 0.04926174784486648, 0.07155895509640686, 0.041442765650572255, 0.021970413654344156, 0.020899073388136458, 0.010301383608748438, 0.044510737352538854, 0.027225366538914386, 0.0022472011323770857, 0.0062811060979584, 0.026245217668474652, 0.08468456406262703, 0.022385617448890116, 0.03711975543410517, 0.08923778106691316, 0.0658763748651836, 0.006090690021665068, 0.062008264067117125, 0.07029283631709404, 0.05054024935816415, 0.03027315739018377, 0.012236013244546484, 0.030412916785280686, 0.03775746808969416, 0.030120308365439996, 0.059460166812641546, 0.04432229121448472, 0.02185964069212787, 0.04459592106286436, 0.019198319532733876, 0.03231768147088587, 0.1725904646445997, 0.1034080667886883, 0.1763067691354081, 0.1843903010012582, 0.10296749824192375, 0.0965893772081472, 0.23193118278868496, 0.17327289911918342, 0.18911953317001462, 0.09634970803745091, 0.1598690589889884, 0.13613483490189537, 0.14982533699367195, 0.24622628290671855, 0.08421350066782907, 0.16113614256028086, 0.1414379698690027, 0.10718660036218353, 0.16449442016892135, 0.09716443775687367, 0.16119023028295487, 0.1669307128759101, 0.09128721445449628, 0.26004320243373513, 0.2002307603834197, 0.11146808741614223, 0.1656966845621355, 0.14582961390260607, 0.170382694050204, 0.22272806178079918, 0.12591733160661533, 0.17307731352047995, 0.10709389869589359, 0.1280179657624103, 0.236473883560393, 0.09674956236267462, 0.10818188718985766, 0.13814988458761945, 0.13599032390629873, 0.08505203106324188, 0.16659929940942675, 0.12481461890274659, 0.12829888350097463, 0.12172649789135903, 0.12383916968246922, 0.16274544526822865, 0.160535670875106, 0.2018910931656137, 0.19099143741186708, 0.12407314658048563, 0.11731077858712524, 0.2228624201961793, 0.17129183979704976, 0.11765727991587482, 0.19598371640313417, 0.1643341311137192, 0.16282574564684182, 0.12330410347203724, 0.11934975511394441, 0.214543761103414, 0.10362438057200052, 0.14199480327079073, 0.18435378733556718, 0.15055503143230453, 0.2379353207652457, 0.11459926783572882, 0.11322713326080702, 0.11225773254409432, 0.2542516600806266, 0.15807888004928827, 0.09326849642093293, 0.19944208004744723, 0.10097354039316997, 0.11819506238680333, 0.15815119491890073, 0.13755497901001945, 0.15561478649033234, 0.1095279426954221, 0.11823780267150141, 0.11243028187891468, 0.1514618913643062, 0.14551331056281924, 0.11944229350774549, 0.26053031848277897, 0.1190896397747565, 0.1853114992263727, 0.10402242405689321, 0.20821162353968248, 0.17286289221374318, 0.1277329068398103, 0.16898043570108712, 0.1498233777238056, 0.12874583451775834, 0.135248398873955, 0.07932279942906462, 0.10519620482227765, 0.11923651079996489, 0.10427634988445789, 0.19208883633837104, 0.14856184541713446, 0.12217544528539293, 0.10631472527165897, 0.18836690636817366, 0.19272064149845392, 0.10676811813027598, 0.11039601798984222, 0.24517090438166633, 0.16077915468486026, 0.16533935529878363, 0.11908946908079088, 0.06795818073442206, 0.08877748623490334, 0.2718098647892475, 0.17060732730897143, 0.11509039890370332, 0.22558751225005835, 0.2777202398283407, 0.1287749267066829, 0.13184305425966159, 0.10193650668952614, 0.14678045350592583, 0.09804251720197499, 0.20245033112587407, 0.140779432549607, 0.15048981149448082, 0.11907053689355962, 0.10149857276701368, 0.21995826275087893, 0.13888493733247742, 0.20882678974885494, 0.3937232057796791, 0.0984832044923678, 0.14509818283841014, 0.1821552193723619, 0.0985230875085108, 0.1970586579409428, 0.08350762174814008, 0.0800683164561633, 0.16460308543173596, 0.08966803376097232, 0.14111151394899935, 0.16770086920587346, 0.15264837769791484, 0.10827939797309227, 0.11314305535051972, 0.2516138891223818, 0.12033403589157388, 0.11866843386087567, 0.12368424635496922, 0.1383724992047064, 0.0793927171616815, 0.10855560307390988, 0.2204898779746145, 0.1475057247444056, 0.0727242160064634, 0.18668255768716335, 0.17567279690410942, 0.14260435884352773, 0.14562386088073254, 0.11236683567403816, 0.12915998260723427, 0.24222095642471686, 0.13571851974120364, 0.1915984696825035, 0.07298349271877669, 0.1662033042521216, 0.11063738667871803, 0.10621051289490424, 0.21020567044615746, 0.14392895885976031, 0.15478375920793042, 0.14832743065198883, 0.08119661099044606, 0.18815149058355018, 0.15563114342512563, 0.2053523957147263], [0.08960579725680873, 0.03445231712248642, 0.02507354089175351, 0.037530864428845234, 0.02540346820751438, 0.059039554616902024, 0.012708009890047833, 0.023896327693364583, 0.061088134534657, 0.06120859623479191, 0.15764454554300755, 0.07736559273325838, 0.014442718857026193, 0.02948894107248634, 0.0336746725224657, 0.047404623473994434, 0.041480830404907465, 0.018965094059240073, 0.035838834519381635, 0.02512853217922384, 0.01735057776386384, 0.023143626676755957, 0.04290210628823843, 0.02866205311875092, 0.0019310575862618862, 0.0555659101519268, 0.018163708155043423, 0.007799208597134566, 0.03208681046089623, 0.06162839948956389, 0.06796929068514146, 0.006988091281527886, 0.0225352993584238, 0.05571064379182644, 0.03818976540060248, 0.06719901561154984, 0.1224281094619073, 0.02919641243352089, 0.02286844017362455, 0.026896042218140792, 0.04800367394636851, 0.07352408792939968, 0.07117651155567728, 0.043231248782831244, 0.048130121067515574, 0.04819650617719162, 0.04429736247402616, 0.022514847623824608, 0.015702228811278474, 0.06637842292548157, 0.038533157130586915, 0.036925323875038885, 0.0464278161234688, 0.05392826482420787, 0.03810776921454817, 0.034832604724215344, 0.039265723680728115, 0.04660630635044072, 0.08943541499320418, 0.031965194721124135, 0.026517359510762617, 0.05564857056015171, 0.09959465969586745, 0.05381410024710931, 0.008253968862845795, 0.04765266778122168, 0.044429457338992506, 0.021811694241478108, 0.04564925497106742, 0.10852116742171347, 0.05930441970122047, 0.04180322306638118, 0.05221408180659637, 0.034796688487404026, 0.024878157528291922, 0.017597772312001325, 0.023790408376953565, 0.02702876976400148, 0.009569942340021953, 0.02604990851978073, 0.014791885423619533, 0.059903644578298554, 0.01821484027459519, 0.02995654420374194, 0.07251611779793166, 0.0822560787491966, 0.04434041075001005, 0.027381043146306183, 0.029048218530078884, 0.04532979008217808, 0.015047828037495492, 0.04482360454858281, 0.03244155705033336, 0.00923587476790999, 0.05342019423551392, 0.027951494957960676, 0.07095216773450375, 0.04601958666171413, 0.04300048167351633, 0.008840513219183777, 0.013785767878289334, 0.02441191994876135, 0.026059727133542765, 0.03965147348935716, 0.1199528540018946, 0.02584846552053932, 0.09322100639110431, 0.05345045901776757, 0.028481993249442894, 0.021741336786362808, 0.014878654546919279, 0.055471631421823986, 0.08321644752868451, 0.03434959646256175, 0.07369838131126016, 0.020161796055617742, 0.018916091903520282, 0.04898657061858103, 0.012115034824091708, 0.07315395661862567, 0.04277577048924286, 0.04168544794083573, 0.03770473849726841, 0.0251157264210633, 0.038542155671166256, 0.020201628976792563, 0.02719373063882813, 0.07306452782358974, 0.04028143441246357, 0.11875021111336537, 0.06132702073955443, 0.04152671739575453, 0.03391935861145612, 0.03187555070326198, 0.00905003542357008, 0.040413481037830934, 0.002976975583806052, 0.04464735189685598, 0.04610409501765389, 0.05757866660133004, 0.06931257055839524, 0.05321680124325212, 0.05091436229122337, 0.018463559936208185, 0.07467791976523586, 0.0400143169099465, 0.04562562498904299, 0.039788214198779315, 0.025501533746137284, 0.010389923681941582, 0.045250350594869815, 0.03650056678452529, 0.05497357611602638, 0.03014140576851787, 0.0324865423317533, 0.02655552074429579, 0.011314880885038292, 0.04750436441099737, 0.029875551772420295, 0.061099418890080415, 0.03656749366200529, 0.06365552020724863, 0.05954052285233047, 0.05773888515250292, 0.006167000892673968, 0.024697908411326353, 0.05985941257677041, 0.04673391864344012, 0.051675212089321576, 0.020773811847902834, 0.02187259673519293, 0.007918409573903773, 0.10740911107859574, 0.04661283724999521, 0.031025086573208682, 0.06566511510754935, 0.014453752737608738, 0.04068534457474016, 0.06630895048147067, 0.00900446570085478, 0.00556956691070809, 0.023309402058657724, 0.05279500903270673, 0.0797459868772421, 0.00476782477562665, 0.06352266093017533, 0.021826038100698497, 0.0649718452768866, 0.05194064120587427, 0.019814357765426394, 0.08484407386276871, 0.09162001573713496, 0.010184714283241192, 0.022002576479280833, 0.06246113000088371, 0.030049227316339966, 0.017149309169326443, 0.05588090731180273, 0.05246650107437745, 0.0154334748731344, 0.025891769837471657, 0.04269274271791801, 0.02717806946748169, 0.056369240483036265, 0.03783599102462176, 0.029106345391483046, 0.0037910280934738694, 0.022016016773704905, 0.032140716357389465, 0.016292933833028655, 0.020397658008732833, 0.03659850059193559, 0.03542007027135696, 0.004595716554831597, 0.016457705460197758, 0.06763863420928828, 0.0717879892908968, 0.09414278349140659, 0.024508449241693597, 0.02488580907083815, 0.03419274726184085, 0.04780285249580629, 0.02093311384669505, 0.02750795967585873, 0.013745436790486565, 0.026459299442649353, 0.030275170465756673, 0.06910777490702458, 0.018887489532062318, 0.0734426817507483, 0.017425202568119857, 0.05152660443854984, 0.035419580453890376, 0.03380648166057654, 0.03286775390733965, 0.013970801992400084, 0.026465396185813006, 0.06793591630412266, 0.05521073311683722, 0.03138350679364521, 0.07605046994285658, 0.036557893981807865, 0.006427389898817637, 0.02796713015413843, 0.056590574895380996, 0.025736273200891446, 0.024630089101265185, 0.04308140174543951, 0.14664507092675194, 0.04483654018258676, 0.02308860384800937, 0.06276969274040312, 0.023747757149976678, 0.035387181997066364, 0.00991785003861878, 0.019929726477130316, 0.051531602803152055, 0.029206663348304573, 0.026708397599577438, 0.0627540482673794, 0.05093157269584481, 0.03076033652178012, 0.020923536430927925, 0.036101447185501456, 0.03796087963564787, 0.05014132271753624, 0.01237880060216412, 0.07728480253717862, 0.05383432377129793, 0.043702720358851366, 0.030162586663209368, 0.008365912563021993, 0.043657838978106156, 0.010868834360735491, 0.032055039118858986, 0.030606097825511824, 0.03803850457188673, 0.020625076176656876, 0.0764773013361264, 0.026273204057361, 0.13342237420147285, 0.012271868254174478, 0.033942201916943304, 0.011478609794721706, 0.018934751351480372, 0.05141450674273074, 0.04954409792844672, 0.04172593209659681, 0.07334678142797202, 0.0715687959745992, 0.03109446810412919, 0.05036184818891343, 0.03304854479210917, 0.030919790660846047, 0.030003815300005954, 0.04405435734952334, 0.030397216651181225, 0.030650543194497004, 0.03111882910161512, 0.014676338596473215, 0.09302863429184072, 0.016771702576079406, 0.03631538238551002, 0.046943289635237306, 0.017832775229180697, 0.04823849689273629, 0.085137036658125, 0.05257406424789224, 0.04097192861081567, 0.06449670006986707, 0.027162454680365045, 0.06869588294648565, 0.01822115038521588, 0.02581918779469561, 0.012516374372353312, 0.05669047910487279, 0.041908990242518485, 0.04352769967226777, 0.1552815770264715, 0.022398308174160775, 0.05378929025027901, 0.06431888890801929, 0.045737633627140895, 0.022312725559459068, 0.05631344210996758, 0.03603368539188523, 0.08251680264947936, 0.01971885263628792, 0.08178856282029301, 0.043061935211881064, 0.011796871476690285, 0.0933120159606915, 0.01931426155351801, 0.05690675578080118, 0.032957260627881624, 0.028102889373258222, 0.033191334005095996, 0.03526699489157181, 0.04653860392863862, 0.0340271889581345, 0.04356983510660939, 0.009848961108218646, 0.05452881443488877, 0.028243919696251396, 0.04507249490416143, 0.022104849995230325, 0.013309182904777117, 0.02774479755316861, 0.06070356845157221, 0.040680271995370276, 0.027929083953495137, 0.03242954539018683, 0.13915527204517275, 0.1595112547511235, 0.14978431107010692, 0.12197464980999939, 0.185217676917091, 0.10934780861134641, 0.15432223241077736, 0.15808061667485163, 0.12538010574644431, 0.1733926817541942, 0.1695956612820737, 0.22319806390441954, 0.1545092387823388, 0.1298785745166242, 0.1837230211822316, 0.32816410646773875, 0.07409060635836795, 0.12181148864328861, 0.1515501327230595, 0.10869088175240904, 0.164549917972181, 0.20308232924435288, 0.1374762668274343, 0.12178776218206622, 0.09878598590148613, 0.15167114732321352, 0.11828835777123459, 0.16192194336326793, 0.17931975511601195, 0.17494998959591612, 0.1752634282456711, 0.12450713969883509, 0.12523703451734036, 0.12241012722370215, 0.09599036013241857, 0.14893565035890788, 0.20180276274913922, 0.08463532256428152, 0.08037310166400857, 0.15718603186542168, 0.1436322185327299, 0.3808104892959818, 0.08851498118019663, 0.16464477928820997, 0.18618007918121293, 0.13557083235355094, 0.08432166127022356, 0.13690847932593897, 0.1425521116470918, 0.12218582793138921, 0.14874387939926237, 0.17290415562456474, 0.16743770363973454, 0.2133366875932552, 0.14351690362673253, 0.14814860274782404, 0.11874927600729279, 0.10014833154855296, 0.29491111112292856, 0.08902782006771304, 0.13003547937842086, 0.2139548966079019, 0.21298017469234765, 0.14882584218867123, 0.09580542435287498, 0.1200780097860843, 0.11497072759084404, 0.11463291681138799, 0.2200088623794727, 0.3247824066784233, 0.13245191221358255, 0.09559314043144695, 0.24006492836633697, 0.11069051703088917, 0.12383817520458251, 0.14698800252517685, 0.07886884253821336, 0.10419850601465441, 0.0959905085619539, 0.10701809573220089, 0.1516498625278473, 0.13927558902651072, 0.11475882958620787, 0.15629474219167605, 0.15125842415727675, 0.13528694602428004, 0.09354270514450036, 0.16080566419987008, 0.057192842577933334, 0.15148889069678262, 0.15087192849023268, 0.16375019447878003, 0.1407582961837761, 0.17125955637311563, 0.1663940362050198, 0.07302754660486244, 0.23134926479542628, 0.14898688823450357, 0.07219140592496842, 0.13993492786539719, 0.12225014987052418, 0.1319871941814199, 0.14662114408565685, 0.14541384793119505, 0.20220316626364365, 0.09519659608486108, 0.16606416640570387, 0.17269669566303492, 0.10935396843706258, 0.1361777458805591, 0.11124283817480318, 0.12629401608137414, 0.27537840767763555, 0.16685633483575657, 0.13661645905813202, 0.0994413171429187, 0.13614605617476627, 0.16722593922168016, 0.09102608237299137, 0.2686020056717098, 0.12951705954037607, 0.15928090695524588, 0.08058323335717432, 0.09678330039605498, 0.09911310975439847, 0.07696288113947958, 0.14060320216231048, 0.12358208230580203, 0.10693140546209179, 0.1401307064224966, 0.18021716008661315, 0.13563073851400986, 0.12865281372796744, 0.11774434125982225, 0.15896772063570097, 0.10587192286038771, 0.16323921096045524, 0.14090672571910545, 0.13240223284810781, 0.18373765633441508, 0.24172405886929482, 0.1499186991713941, 0.27945475769229233, 0.10975942597724497, 0.1623626158107072, 0.11589827117859386, 0.21681865153368562, 0.11765200324589387, 0.15532099991105497, 0.10413345677079633, 0.2198241715086624, 0.08575845917221159, 0.1803458039648831, 0.11341646255459636, 0.09434441759367473, 0.15895972028374672, 0.07660112125449814, 0.2374373990460299, 0.11960307238041423, 0.2438263999647461, 0.18686662515392527, 0.13000923703657463, 0.117353370442288, 0.1908807089785114, 0.15435935463756323, 0.08132496543112211, 0.1894678082317114, 0.12102229622541927, 0.13218889507697895, 0.19298716157209128, 0.09739629211253487, 0.13422800519037992, 0.13978577102534473, 0.12189094297355041, 0.191024744999595, 0.20832837821217254], [0.024344185985682998, 0.08298848202684894, 0.01700794673524797, 0.01935617248818744, 0.03324240489746444, 0.0634250017174054, 0.012753380160575034, 0.009423558349226369, 0.05656766479660291, 0.012686515437962953, 0.04457036149688065, 0.05966150034510065, 0.026174737758992705, 0.02117642325174529, 0.01919794474815717, 0.07203803368611261, 0.05347143582184799, 0.017646646447246894, 0.09337897994555533, 0.013750162415817613, 0.05189644260099158, 0.0007312582249596744, 0.024946249577624258, 0.06836763102910481, 0.11517974606249481, 0.006725897001160774, 0.015967195940902457, 0.013853071395715233, 0.07456660503521562, 0.0855151831638068, 0.03943903742765542, 0.025163060599879827, 0.06059142622689251, 0.038640282436972484, 0.065422937477706, 0.06570457509951666, 0.028072689528926276, 0.03211189134162851, 0.05769397037511226, 0.03227052540751174, 0.05580658122198656, 0.03555173097993247, 0.03856464274576865, 0.02337254769372521, 0.022281126766756643, 0.04794863627466839, 0.04000410124717746, 0.020711174583993852, 0.025153201167995576, 0.08880112363840453, 0.08327573028509505, 0.0022035607616999187, 0.007747597328489064, 0.02942127761343727, 0.07558199664345011, 0.05293251044349745, 0.10651644101017155, 0.007390710570689407, 0.03495361561363097, 0.018368576165812556, 0.06861774221761152, 0.019167967548128217, 0.032665629987604916, 0.022093307743489277, 0.013814088233630173, 0.02440517197101144, 0.008543518706574105, 0.025098439946305007, 0.019851509678119328, 0.02327205533219967, 0.048567669073236175, 0.012051552439515945, 0.018779649908537976, 0.020402057089086156, 0.035656095496960916, 0.03638583075371571, 0.032446807745145634, 0.015634864066669252, 0.07842326449463144, 0.07988640121766366, 0.06141562575066928, 0.04649170019547455, 0.008621553679404315, 0.05757638078648597, 0.05437487445306033, 0.08407049623201601, 0.04091149181476794, 0.02655331842106534, 0.012526435111794854, 0.05405440024333075, 0.030213177014957182, 0.022265777297434397, 0.026815884702955373, 0.019771459774347022, 0.058987147858715616, 0.02641565188241657, 0.01119420025133877, 0.07191090378910303, 0.03237899400119204, 0.026161162022617646, 0.09830806506215595, 0.04180714160611387, 0.08011075246031396, 0.02775620436295867, 0.07361702708294615, 0.07980145499459468, 0.0283044937896193, 0.0420925716025522, 0.060713201528415084, 0.03002457131515257, 0.019991478729934897, 0.03923059040971566, 0.02510059031919809, 0.010088719336636132, 0.09213134064339101, 0.04286574105208274, 0.03979553919634782, 0.050514990361989476, 0.05537820245081093, 0.015099395241122693, 0.015796674524608534, 0.06565666204551235, 0.03387514516361989, 0.01160562836957979, 0.028856416029157117, 0.07674697553738952, 0.043675899141817354, 0.05652640880725812, 0.023742627054161858, 0.08495075759128667, 0.07805734116118401, 0.02086955075355945, 0.025217408074240666, 0.050487356493249536, 0.03211595460015815, 0.02308860384800937, 0.08351651267730631, 0.06014612277795095, 0.053877316386206076, 0.0203504796809284, 0.04542393893643748, 0.05103423769469373, 0.04811361570318695, 0.010248533417325234, 0.04468327184440568, 0.03335512228659354, 0.050218546894029714, 0.007450686771335313, 0.003179841883138579, 0.032587329696980305, 0.018797110788000282, 0.01588225528394105, 0.07144273477024399, 0.038505397096741945, 0.016743170708650723, 0.014808709911449114, 0.05811877941596322, 0.03260651421442162, 0.01512777125753928, 0.018518495562602766, 0.01003053495878703, 0.05380500893807039, 0.024022605975915212, 0.04047996633744333, 0.06660984683549032, 0.025805849545577075, 0.007881079545768443, 0.03037225080333883, 0.018897582740464713, 0.1270512887276709, 0.016227005144173745, 0.076882625289727, 0.08085871115326881, 0.002841118262040254, 0.04677744931541383, 0.037986442912369967, 0.05439667133032344, 0.03812123177340254, 0.062233027201727964, 0.061127260560169816, 0.002692022417249973, 0.03741683343832847, 0.03307548846350983, 0.030614645511377603, 0.07291115558473393, 0.07930915133329108, 0.012471005957195302, 0.0584486603474943, 0.03548213608155493, 0.022396181921067182, 0.05837473501742352, 0.09798583196243271, 0.03878709780110512, 0.041172879937221296, 0.023997061252885032, 0.018035260945907794, 0.054749896517023444, 0.006314958700386342, 0.015622132523276377, 0.0398834725638153, 0.023523055242549162, 0.03384662813914474, 0.04322973851230927, 0.21180520649068058, 0.03296064482128713, 0.08701192433363758, 0.04497342190006748, 0.0297858057092526, 0.033355448831571266, 0.057977281539933756, 0.05144610368006397, 0.050791280809789896, 0.04158631185418926, 0.035368179305805825, 0.05875821385416202, 0.06548469158587977, 0.02447728275001282, 0.03603684323024936, 0.012058837546646828, 0.03370591322891414, 0.07981770802871324, 0.02082156719552586, 0.07863122911658138, 0.08480143005726859, 0.028984469900024123, 0.052288496954133734, 0.04026439470180776, 0.03700746477989014, 0.02133157293428667, 0.044799399402108975, 0.045649466483155265, 0.01757582514983369, 0.03918905982573051, 0.030927726074878592, 0.006658985430476605, 0.018499797151889652, 0.05276650314044673, 0.019538852138794027, 0.037344039883464575, 0.0410494496463798, 0.03135964674584102, 0.03295084476121701, 0.008703286403033417, 0.006482175240307697, 0.01623161202587653, 0.02400029516138602, 0.03785002132644877, 0.0312290064903209, 0.07507018191972747, 0.041780520768952556, 0.060080372204538435, 0.07544184947619215, 0.02697241106943693, 0.07335329006309621, 0.0617087147111306, 0.013428163092612522, 0.030867610257701017, 0.032435768298455514, 0.05582434081588872, 0.06886699251481332, 0.04980057303328067, 0.05069931758043822, 0.03100752735917922, 0.055861117944004945, 0.007586399142383016, 0.06216906891495455, 0.06289960569120012, 0.025109262314799707, 0.06140258992672898, 0.026970485196216032, 0.02142111861758167, 0.041828374451142736, 0.009054662714333972, 0.05368910402467009, 0.012640097811527085, 0.08145999177941121, 0.14022964955074713, 0.0353585796256084, 0.03735040379979182, 0.020288629093556665, 0.04975002535502426, 0.03734503436135128, 0.014096356680965982, 0.036073490482522175, 0.015081630081112962, 0.04880823995335959, 0.04240700101945549, 0.028919509713887237, 0.02121802248439053, 0.03936390610761009, 0.018231243593618274, 0.06281516412855126, 0.024438229083898477, 0.02509595375158824, 0.04898521248833276, 0.0486316904425621, 0.02926662145910086, 0.042636933212634176, 0.05910448140639346, 0.04688168024586048, 0.03167378672515042, 0.08437934098765254, 0.05325874742993619, 0.017154706438304856, 0.02818936998664867, 0.11807815186330117, 0.08738952907151543, 0.03231631220842246, 0.0532795943581732, 0.03758351238502655, 0.07196421967819333, 0.09487133502261713, 0.035407643008511513, 0.042850645768339746, 0.04861744862864725, 0.008820515122351935, 0.034688735686358996, 0.09458064319915138, 0.017551328710396774, 0.020083685012650676, 0.08251574879977852, 0.03074999840464443, 0.03480916398984846, 0.05856624251464382, 0.029029058132437058, 0.017396329312759917, 0.032304786655004136, 0.025262599301640876, 0.11540630148374476, 0.04667707755288575, 0.010729308742156718, 0.050735449040075764, 0.018287921411683783, 0.029118242018739693, 0.027923501147597563, 0.072219607536681, 0.026188061165157706, 0.022306181672320236, 0.03366596341948025, 0.052341230257297866, 0.02445822254230734, 0.030956094669818413, 0.034796502950484864, 0.0571954178303713, 0.03327918202558067, 0.020036814676132053, 0.01659204346651677, 0.09103519594646059, 0.0329754358244827, 0.03498679703625385, 0.05154725098691415, 0.09800073428777978, 0.12274666893063113, 0.18165913817938417, 0.15695460053393617, 0.14446183573454618, 0.16906976059544832, 0.17082813108572736, 0.08468894273391925, 0.19284336303826421, 0.15779125329572707, 0.18805812840582803, 0.18584706267574802, 0.1184972129703965, 0.16948714444879442, 0.07570857735117897, 0.21788560756249353, 0.17283375549595803, 0.15745605487609282, 0.17957097210455686, 0.20847048464929685, 0.1083775915321894, 0.15688212239183486, 0.12408064227201976, 0.19504751195199788, 0.15131917636608705, 0.14531352440826595, 0.0933379762864206, 0.12400440144119784, 0.3197313199052587, 0.1423807645915076, 0.2503825770691037, 0.09663040313171223, 0.11029471483197995, 0.14375419792486355, 0.16222374513745308, 0.13100484298774973, 0.19493948493618518, 0.14528996864100918, 0.08066147798672318, 0.11120832830783911, 0.14553450630046427, 0.12605023541254923, 0.12957801955053583, 0.12177670418168418, 0.09027339619933628, 0.17358831188175827, 0.08813309425022453, 0.24858282442437485, 0.17212052189279348, 0.09496714628767222, 0.19753005530219525, 0.12949391937581822, 0.0705646479036659, 0.10245631434372626, 0.1257436245214194, 0.1273016893537715, 0.14354390295920894, 0.18191854847827926, 0.10714125513914041, 0.11422961149946786, 0.11887273227330297, 0.16032585088396445, 0.20839879318373278, 0.17339844082016498, 0.11363000070559792, 0.12431405513780192, 0.1087691263819579, 0.08731300622457638, 0.11183513881405815, 0.16007991798687726, 0.07872937814681791, 0.12093925732187927, 0.07228438960737549, 0.12474047834984958, 0.10094419587403536, 0.16284330486087129, 0.14770516951102763, 0.11182599555468187, 0.2912168187322095, 0.14677825674880296, 0.17389128624927253, 0.10724609091994353, 0.09645507074310444, 0.10467360669281334, 0.12130666495067999, 0.20483841391978785, 0.18343763571465388, 0.13450973929138854, 0.12279838178073987, 0.059635321085806936, 0.15500298963161185, 0.14472114213276654, 0.1249528068001382, 0.1659512412152253, 0.07553222079877742, 0.10360115877119824, 0.14595101441955194, 0.13386980019276962, 0.15894521871814504, 0.1344977313419804, 0.36485971708316356, 0.2604971296386793, 0.17890707647893578, 0.17453505482990295, 0.07262083483510651, 0.1341453002532944, 0.20436158403754234, 0.12601366237504408, 0.15700362680945545, 0.07455279366695322, 0.17269156000111252, 0.17586943635251373, 0.13346199004445225, 0.08475335373077542, 0.16830465086968616, 0.1458933940739371, 0.17556983133545145, 0.11603677077800967, 0.13348124135518447, 0.12230345091666095, 0.1485118840355426, 0.1257356835412793, 0.15190146543318406, 0.1517351798247546, 0.14886483462760225, 0.1228248912957497, 0.1511275686789304, 0.14729062066180632, 0.12107910020858981, 0.09995158077799715, 0.19286929367808625, 0.18093357008183375, 0.19033868884434924, 0.1300215715309605, 0.12978285230929032, 0.16605965414782986, 0.19602351036155596, 0.18684502865653485, 0.17131784465163946, 0.16573854169109836, 0.1191801149980165, 0.1277239268529229, 0.19278351624961942, 0.15366783627541736, 0.08128578003379516, 0.21993969421600923, 0.15079553180839866, 0.13481559319188818, 0.0804686383344233, 0.07355033027124591, 0.08655695070046932, 0.11795753060141578, 0.06409088629879989, 0.18721396510954946, 0.1616535085486248, 0.05061211151769385, 0.15114975889446214, 0.1038681909267325, 0.08657187529024668, 0.15207794815069064, 0.18970588920637965, 0.08942545537138358, 0.14572259620763361, 0.06747536914190277, 0.17135759408120066, 0.19831596000585705, 0.15417074522702023, 0.1520749053452164, 0.13378412666497752, 0.1485060210688971, 0.1860899230814539, 0.11992583982646465, 0.2613354893401265, 0.306436694227159, 0.11691684660036117, 0.2089101477758959, 0.12491618923377246], [0.03363750205608085, 0.06004047434544191, 0.05046813857916277, 0.02974907310999697, 0.04461771051865071, 0.029983903477841523, 0.051695224101422355, 0.024988101140479557, 0.014129882274573902, 0.008151135025400436, 0.028370819527481217, 0.043321712873876095, 0.019956994838139508, 0.004218387339278706, 0.04251588150509633, 0.05819048572448082, 0.045474828002625145, 0.06534156098496169, 0.037375588581198826, 0.058624512239475735, 0.025642287619120907, 0.050655831437325105, 0.024455415368720423, 0.06704833736876026, 0.053777397333760746, 0.017793810620787553, 0.07811392250005156, 0.04322177526773885, 0.02963622955576284, 0.04768396414874587, 0.05078895788756199, 0.06616405356908217, 0.04723851969174575, 0.06922734231920913, 0.10091159332660027, 0.014781718928134069, 0.07781859967508353, 0.06256458538700826, 0.03440649692493025, 0.012242964385222876, 0.0017816066701925592, 0.012636951105378103, 0.0541987776523456, 0.06056427475414239, 0.043805956811411306, 0.03584749167202972, 0.02273134137794841, 0.03911933134077117, 0.05600274569587782, 0.0467872382432688, 0.0651971019397024, 0.034760735143208876, 0.025957984253182076, 0.012024631032545585, 0.05728787829866633, 0.018829518521670252, 0.07138028304325417, 0.01944059920788277, 0.034440134768374264, 0.029137728961359244, 0.04541799062280916, 0.024503087224729825, 0.10548098172876053, 0.02371118782320991, 0.01877358285128139, 0.06794778324547224, 0.07669475060538389, 0.07404817035421729, 0.05347256017557811, 0.0628496368881315, 0.10729439731221646, 0.030515049293171614, 0.02683104306925088, 0.04755681198730599, 0.05859851109562442, 0.007143266011553351, 0.045302690559765324, 0.01432249000572483, 0.01966814168554265, 0.03794058931816835, 0.028928241081302986, 0.02474780299962731, 0.09994560648920015, 0.020937043518642895, 0.04698227836342994, 0.04271465091733262, 0.0478328389726812, 0.025232861444237642, 0.01584468405781081, 0.009325935316155665, 0.023452274763258174, 0.03663593081000727, 0.0840475935547147, 0.031346547839348204, 0.04414201612235047, 0.03632644409663044, 0.04750955202325713, 0.028556734941957984, 0.01318806533163297, 0.11674799316097051, 0.021021347783971578, 0.0200310055151931, 0.040592813602415845, 0.06953522228286602, 0.01988824413274415, 0.03246680491429288, 0.038802757117082365, 0.04484506374865305, 0.016209149071073625, 0.025617718820285518, 0.004044707620778354, 0.04527044053247664, 0.037434377809404396, 0.04554499806545209, 0.006887743174956995, 0.010498627907509217, 0.03840316254354548, 0.035169087059330195, 0.03834838833427057, 0.040203601674875244, 0.023721394209132995, 0.019178604379703756, 0.09752970057888888, 0.04155544222157914, 0.025901670087478124, 0.02441360462398734, 0.025438959564780816, 0.03357874993525911, 0.03748624279978685, 0.008463888116239104, 0.039518361882073805, 0.03800432496063877, 0.020242428545316216, 0.061963853950146586, 0.030835269317321945, 0.03825286650680937, 0.054915859291213565, 0.04149046348175034, 0.04799080881639384, 0.031686529400758445, 0.02011601667618379, 0.04840955822146498, 0.0018001434318648535, 0.028392599706421606, 0.04064822605869267, 0.02475112967658788, 0.04706881278252695, 0.04953078750986606, 0.039880388940218836, 0.0665519741596654, 0.03414776569115929, 0.08579770394135267, 0.02397609372565057, 0.041277125710621476, 0.04188704493572004, 0.03854636364849284, 0.008043283341976348, 0.04692072463512886, 0.031017180845083203, 0.007008793954810244, 0.0468692158756312, 0.021253558370517567, 0.05911388070671819, 0.043433142636786215, 0.05757353093940765, 0.06505242025014013, 0.020297579394537024, 0.02218322264525341, 0.06252079125260934, 0.02586656093626516, 0.0963575673813466, 0.08652240372612141, 0.05473208497278392, 0.03426954470342025, 0.032556241130805574, 0.0735433615045622, 0.0039253433715202846, 0.029436892400553916, 0.042128417335334234, 0.043977381792501546, 0.04683230887167156, 0.044828962854808196, 0.015468278816115344, 0.04158247866143938, 0.023262362883542664, 0.031430848393938504, 0.005099178406453575, 0.014323738669190789, 0.031683234265074134, 0.0527328912721714, 0.036639266763813794, 0.05007225103327073, 0.016269123880192637, 0.027739940196624957, 0.030695021960127633, 0.03714638369274326, 0.04513362560828682, 0.0407691478903871, 0.006742392160958843, 0.007139480594560155, 0.054818281714688055, 0.03027276776265353, 0.02812653790897457, 0.020734511417686008, 0.010871303857129533, 0.0869254047574941, 0.0316356588882627, 0.025717276075738482, 0.07139267690945417, 0.04394008145027328, 0.03769920578633901, 0.04098310164408758, 0.039512510047643445, 0.06741529228747822, 0.04670232541684527, 0.045027698870399036, 0.01636134500586195, 0.05922407108300831, 0.023695604577369522, 0.04678841454733629, 0.033795980270951986, 0.027613391030172352, 0.03047610880457796, 0.044050917495042086, 0.01432849676348269, 0.015727042518847156, 0.05974560794129502, 0.01890614155854564, 0.03433445293921977, 0.031260629402822815, 0.0646645664528478, 0.03465333524218295, 0.009187728865072131, 0.04303020097722765, 0.03136825194815174, 0.011042015448765596, 0.01587861876032548, 0.02351181912672473, 0.08442674195975997, 0.047150137324933894, 0.008213893815991469, 0.045654490822926164, 0.016637459193589166, 0.027200543554499745, 0.02248365886771353, 0.01700793560303282, 0.10171195506700315, 0.07717026688624173, 0.03018558581970865, 0.026317205993109383, 0.04602548302500509, 0.04589650146954227, 0.01586161244631512, 0.019292852448415942, 0.03580269192752894, 0.015507231364608742, 0.06160121090942994, 0.002432539758956409, 0.07851318310713395, 0.11005184700479731, 0.02608729791973019, 0.02682218368136091, 0.06721746540279128, 0.02821091824444011, 0.04337174104875885, 0.05634174762235489, 0.01637377597944578, 0.031344139570137486, 0.07282473990926519, 0.042653100899769925, 0.0202937777430634, 0.08181106473784894, 0.12047212730976753, 0.011316352192807244, 0.027026561874663457, 0.08003441515029408, 0.04254948224115651, 0.03317114016681444, 0.015355820250988472, 0.015061073518154444, 0.025352382472192403, 0.014769826011615805, 0.024439052867819555, 0.008965687557065394, 0.026202614681096748, 0.04581163317197934, 0.06639676139457151, 0.041891902292263694, 0.12186570253106765, 0.030659207768621854, 0.0751483449130319, 0.017988707877520937, 0.042663784115575254, 0.061061309606884606, 0.0019171252711203124, 0.06850855002994649, 0.07370107530732639, 0.06786190191633068, 0.05807047673442867, 0.10878362794755958, 0.04322129287174903, 0.0637196195020806, 0.04917402970022522, 0.061644782399525866, 0.025050779222510755, 0.05182275104743894, 0.04607102120644413, 0.06737644085660577, 0.03702815214637667, 0.04326060072344262, 0.0778087365324609, 0.046507886436302215, 0.024283589627884794, 0.029518749433918856, 0.04002851419500075, 0.026893409449257888, 0.03184464767400641, 0.05390944024838973, 0.041740756496437825, 0.018332682193431538, 0.03155039725243114, 0.0268173615768319, 0.0707519288698677, 0.033951634613913484, 0.0396375211130362, 0.03548701941326726, 0.013373715428315336, 0.07288576671271585, 0.037755790835944936, 0.032462463350384496, 0.0831981684314087, 0.05605560516414698, 0.05698272572772112, 0.041823439169093035, 0.05159830332559068, 0.021736969247285742, 0.02157404556783149, 0.0681286965846084, 0.047493825913988985, 0.029470379959093407, 0.08044252957915887, 0.05857784970430657, 0.039923225704114884, 0.09601385652786121, 0.04024549220048357, 0.034935462681460194, 0.06170213186123874, 0.021546380157815292, 0.020956493353878614, 0.01518403718364425, 0.07826993678463623, 0.03205022258043755, 0.1762804080499336, 0.15887927147559822, 0.08939422579715028, 0.10199308802839369, 0.1203779413481243, 0.1891366025665775, 0.16736417164793238, 0.1655045128427446, 0.1602286592242308, 0.23519437643699348, 0.09044963400810957, 0.15716290654381737, 0.20712477795314044, 0.23248402343597263, 0.09154606814263389, 0.06158871685329359, 0.12631378689548, 0.12469732988392934, 0.09026406740304083, 0.20630669372621924, 0.09781421031220816, 0.08772130619036034, 0.08222909425967373, 0.1289646641816944, 0.17475085653131828, 0.10177290023420937, 0.12898502871394157, 0.12065300354151987, 0.11959608877077699, 0.20696776919066906, 0.14920004789019004, 0.21377722645411268, 0.12895393272629008, 0.13959910604171455, 0.1484567573061213, 0.14929853088688105, 0.18606727273436263, 0.19383145845495164, 0.16128644230775535, 0.11045294813811779, 0.11597319840802811, 0.11173775419592857, 0.11080500073148869, 0.1475171686615795, 0.0823676458094269, 0.09718703615362756, 0.10465609200764447, 0.1332870955229737, 0.11698982198140584, 0.10081207132316194, 0.13745809905231, 0.18011561944149435, 0.13653517904458568, 0.07653676220797934, 0.1605806450243108, 0.08006084302905947, 0.19287523085949942, 0.1072344317799434, 0.21003488742280751, 0.1612242651754059, 0.21152595116291195, 0.15100030519533902, 0.24416201398707926, 0.18830827670171857, 0.1061734277755022, 0.12535809364635497, 0.22676405380479991, 0.14465283486060798, 0.15725623903563246, 0.17987342696869746, 0.24094841064652428, 0.15158747759414837, 0.1334779165335931, 0.13497822743374854, 0.15543079323833808, 0.14070788951357827, 0.15371143002994359, 0.0922136299777776, 0.10522792421397753, 0.10863251925911754, 0.12633499747607857, 0.1288862488581799, 0.20097540167625993, 0.18464919179677963, 0.16060216730693355, 0.1112733775516972, 0.1755013904767111, 0.2110811969032511, 0.16585738922003657, 0.17979314143303782, 0.06647793008596636, 0.1287199929356575, 0.18334832566324621, 0.11975202141911723, 0.13562190695665777, 0.15167488774750382, 0.23191530082840472, 0.0866494223009795, 0.1896537162247114, 0.20047906815307215, 0.17184659518534318, 0.06033442790794652, 0.11126706187496893, 0.1931304406025447, 0.1576318102888763, 0.10263301228405908, 0.08178455522283912, 0.12594692845596, 0.1096838382363785, 0.1323920802678913, 0.10723054292611778, 0.21173637971514836, 0.13122808100888506, 0.06883977053803392, 0.10916300641838461, 0.17765707714715973, 0.18175575096393004, 0.2932228142162785, 0.09799824809306301, 0.190449446963612, 0.10520799754885957, 0.1981832046294585, 0.20919134753057733, 0.1912705146241933, 0.18911160703282803, 0.20574175607180223, 0.15207204065518454, 0.14717711659613997, 0.10383699103840627, 0.12195482704555616, 0.0884141307324171, 0.12477905518608168, 0.12241802367498167, 0.10455373500008136, 0.11926287188543938, 0.18427859293296933, 0.17513586790300906, 0.176146509766113, 0.0831808170187287, 0.14308915939182043, 0.11307385750114918, 0.1209615588595625, 0.09127721772529185, 0.11260417450102977, 0.15434635221026838, 0.09357515926240012, 0.16934990650042892, 0.11515444624819793, 0.24029517226153985, 0.14939974498702213, 0.10884742296184413, 0.2012606238713488, 0.20718354120617732, 0.07915958631201647, 0.2751100470777601, 0.1353663409827277, 0.16370680852560326, 0.17653000715654343, 0.16038317437050864, 0.14565853402018547, 0.14987265632953495, 0.16150911629665643, 0.2016526708030142, 0.10784547906951047, 0.21231430495390669, 0.1684949969057925, 0.0983494620595593, 0.1485815123305656, 0.14113110664766282, 0.13806127215502784, 0.3391195123549551, 0.22678657056530938, 0.10900412002229132, 0.08509327220963314, 0.15450205479282886, 0.1297537749633193], [0.01902724521642085, 0.04211877312627621, 0.03722701803781092, 0.057309608382638544, 0.042336693659308366, 0.03147346251353156, 0.01626025521545671, 0.03732478857273236, 0.029383778746705502, 0.024907995575631503, 0.06496270943898708, 0.05846943677170202, 0.03898701754224021, 0.04767649072164204, 0.0673008085868787, 0.031193075410556048, 0.05683798466634471, 0.05808847381558735, 0.03889795611030422, 0.04823942086659372, 0.017964740218303632, 0.032391035347245634, 0.03818181328824721, 0.005714854842153727, 0.03470955663942732, 0.026889583677984774, 0.027900750610569958, 0.03526040833094157, 0.028536450190586038, 0.01169899425804033, 0.060752620702260174, 0.10591692669549957, 0.029761645091639366, 0.011567215733521152, 0.03339171387779061, 0.029936509927210864, 0.07888050909969024, 0.03772647600271739, 0.006253858146010316, 0.04164963560469914, 0.08220403193263337, 0.044461655415943824, 0.05216921526880469, 0.02526768672396429, 0.08326317314640619, 0.04639838996808976, 0.045207246657810174, 0.03507628520310391, 0.016985851143545005, 0.029280315939104185, 0.03317472474009264, 0.02115390649123583, 0.027192494962946512, 0.05145359566085972, 0.020316743502917234, 0.029404258311842568, 0.02293493103934452, 0.05706695948902052, 0.045150902806199156, 0.09548916554194875, 0.055041805462678894, 0.008103648706310196, 0.07239578597364016, 0.04724015612737276, 0.045202047913335264, 0.033034425432560965, 0.032311970644514076, 0.03529970133968163, 0.1017485948977992, 0.041687704069772735, 0.07823892243322916, 0.0515701462427387, 0.07054954519844614, 0.03003915822773706, 0.015655939205316827, 0.032696596099413, 0.013136736542946892, 0.020157678991381545, 0.024745363189140335, 0.05980234513117466, 0.12746248306939378, 0.04285004091798328, 0.04907271169940941, 0.03547500404238235, 0.041451096258242615, 0.059942974694422446, 0.054390500372392125, 0.05745403774199076, 0.04463904355361592, 0.040467245926265605, 0.06649603106779978, 0.09176860854495317, 0.05834898249304388, 0.024171245167963207, 0.036933565424988046, 0.011688593058352126, 0.0164310048421612, 0.010712913772294996, 0.0541955455992138, 0.050362464171485044, 0.037471511168405414, 0.06954599084565416, 0.023349312905338593, 0.10663568187737837, 0.012311939590290422, 0.041984889685409144, 0.14477678836556152, 0.04251514306815807, 0.07873619848396629, 0.05678492110746447, 0.06762009536032565, 0.06973933515837416, 0.04153735608269926, 0.0198512944552931, 0.030618059390690178, 0.01773650754330447, 0.02310850268258946, 0.03063636446313467, 0.046462693353532813, 0.04964246218150947, 0.08454288064967841, 0.046271404789877124, 0.030161055983626284, 0.09354415233246982, 0.06862649956019595, 0.05014946036681067, 0.02409470376733225, 0.07891178320278414, 0.028414806620276067, 0.03409702876524534, 0.10947869377559982, 0.02255468425573781, 0.03485951499897055, 0.013069645465293434, 0.0785600052040536, 0.025630340896896087, 0.01439681795091019, 0.06674340373137966, 0.039017478993628174, 0.07181348206358962, 0.020800818601856008, 0.015493437622353667, 0.023139585682656616, 0.04873337209573947, 0.013193712147767656, 0.04875165490375366, 0.044943591274204664, 0.028916125520481728, 0.04202594529488124, 0.062151780584827065, 0.0811011262703687, 0.04543226954410784, 0.01152511926193256, 0.03919727540051099, 0.03428731914027594, 0.05031724882428534, 0.016504523846379016, 0.014343171806103783, 0.03200111837941222, 0.03515152042382397, 0.0865895755123347, 0.056095324907801114, 0.06955113392905332, 0.02913991829700535, 0.07401123366435058, 0.020653561659855768, 0.04465737831196748, 0.001800000800358248, 0.058593768771970645, 0.019864419336954597, 0.01920227332448121, 0.011995016557193594, 0.03389546516700648, 0.03801085957093164, 0.05958036876108963, 0.036792446044273674, 0.056937989065772854, 0.05609410407487303, 0.03794574353378266, 0.03952945327910129, 0.025276117521570995, 0.07021732279099524, 0.02426618812023662, 0.017944212413567584, 0.015414047302328981, 0.050164518543169834, 0.11141879396745935, 0.030801668581261765, 0.019067174616793636, 0.027213915200263727, 0.04123390302993357, 0.03941115865018219, 0.032239707725238986, 0.020994604492443614, 0.07060004834784195, 0.04496459776419215, 0.039115082545322366, 0.06493137596407905, 0.09353441535495222, 0.05541738784813788, 0.050335038104094565, 0.02797704339172924, 0.059288062766427174, 0.03159567197144497, 0.10458690900122747, 0.047296559350797907, 0.033863742064568214, 0.010778783089335775, 0.045601212041219696, 0.027705428474291693, 0.06423122642445378, 0.08319154105265625, 0.016201250764424913, 0.032303832995239645, 0.034364728853688575, 0.0550607042532647, 0.03825021703960374, 0.040930947216111235, 0.02331233354198048, 0.0756171447574161, 0.05684564734110609, 0.09517705533653498, 0.09187852061586455, 0.03438176114286762, 0.02128034619090613, 0.024829405847413, 0.0346657179761678, 0.03759582461498212, 0.007678492711420404, 0.05845143969054334, 0.03868342719215434, 0.037433746983879246, 0.04049660899909213, 0.023907671420602128, 0.13835065037710592, 0.00444859180788626, 0.06727901913109235, 0.014251151060307166, 0.03395258456293959, 0.04443755045940634, 0.005858692802576115, 0.054677051011822186, 0.014076338175073033, 0.0641249657201115, 0.018194523981946986, 0.0503541966463672, 0.05643874261295423, 0.0918393129541073, 0.04175198519078549, 0.009567619417794049, 0.023318203930102754, 0.02059949991235044, 0.024748426403675694, 0.04507383819145616, 0.039103697999962606, 0.02136156126653077, 0.038665207466692664, 0.07114796113455668, 0.03169689349306282, 0.05166468101378996, 0.028592653034138493, 0.021999604177835863, 0.06808977836044505, 0.009707667322800262, 0.011019530229532393, 0.02931517461547628, 0.03834760165773332, 0.029145226508262567, 0.05428122283774428, 0.07823863299563527, 0.0810353942506481, 0.08380213563214056, 0.021834572798979934, 0.010605858042254113, 0.03775800985749811, 0.060704941424774006, 0.07011623485595919, 0.048237843802780844, 0.010746536772785475, 0.04200370683975052, 0.022207455622265115, 0.00285644778614369, 0.11454598905402236, 0.057530278572812676, 0.07102758478140458, 0.07624238933203742, 0.020264232844056096, 0.06469967003795318, 0.03112886108283419, 0.05897735150938388, 0.060330153137329035, 0.032776128355180845, 0.06926980058779009, 0.016762006416684017, 0.05129282049892936, 0.04348945680249017, 0.07055974230752327, 0.013664325615536654, 0.06558856257470325, 0.043965251388726756, 0.036958178752684034, 0.044209718544152565, 0.041070125880651176, 0.039065150849637575, 0.037526378146139905, 0.07068332473863848, 0.028928710489708465, 0.025772911176318303, 0.020108287208131514, 0.026454035760252737, 0.038955394629738294, 0.011322999980620807, 0.048879337700782344, 0.07719602683209814, 0.033508613269077614, 0.041220421917387284, 0.057145449027302675, 0.03828077497018967, 0.030116796151560266, 0.03327320773678366, 0.01263690286577912, 0.022220654718694277, 0.02729790961893741, 0.03158753061143216, 0.040335677986149676, 0.029756574367638677, 0.07596415816806257, 0.02328327660507057, 0.01669268611294683, 0.06877206440549344, 0.025712886272231117, 0.01258018979569897, 0.008756746083236067, 0.037131600111024454, 0.03802407351031434, 0.011383150122128427, 0.016493692201038357, 0.03573385030904319, 0.059822936018463224, 0.03401830173970666, 0.02028069367952412, 0.011029445322492393, 0.08051702636294067, 0.03590593580156565, 0.038716059425496496, 0.024780121675576083, 0.04120590921957046, 0.04152799017901998, 0.09951110871043056, 0.0351613613020163, 0.019396446987229865, 0.029259201837703586, 0.08527489801053889, 0.12449335801647976, 0.07813866570359096, 0.16106618772028014, 0.11741968133719638, 0.182124613202177, 0.22935597487958148, 0.09017982622026466, 0.15264999557984993, 0.12713889183942229, 0.117473368300125, 0.234590238542296, 0.09502083325060084, 0.162947739881929, 0.15918294346192852, 0.18448464281391352, 0.11529571405844763, 0.06272581696975976, 0.2835630200570449, 0.13685994286788628, 0.09618984200642444, 0.13046651874901727, 0.11524527028086595, 0.1942558036535047, 0.15896323806373402, 0.18794581177644432, 0.09818975187954493, 0.1734472147654742, 0.21034164674347267, 0.13432283682050183, 0.10009914200054482, 0.19262765039457008, 0.08432514194282703, 0.1877332606818527, 0.23424516955856234, 0.138695229543373, 0.13977998227346689, 0.11769489196012728, 0.10220808078884147, 0.1293694760533981, 0.17868704453576356, 0.11061628742027096, 0.15453948872163892, 0.12333791572018526, 0.22193388955201954, 0.20853962312685326, 0.1437357036047615, 0.09883378021186218, 0.0944388855714351, 0.16071295511210337, 0.14280589646659791, 0.17552249715663493, 0.1615816686535254, 0.16762579354690388, 0.08865894298651256, 0.13148455240298063, 0.10609812947222963, 0.08792932276264764, 0.19181905081495643, 0.1563061267370358, 0.11706980323651806, 0.130610836786218, 0.12915466882986948, 0.14286130521213636, 0.0770265945175197, 0.14601739210775122, 0.11552790238056332, 0.14884580596117303, 0.13454191881464794, 0.1276652971864678, 0.27638671919703484, 0.1338193193078041, 0.10917666193563491, 0.17780644178856164, 0.10893982776906341, 0.10025506722740829, 0.10079054904053919, 0.20053052867297083, 0.11434272222686559, 0.11859848644235171, 0.2104519002023153, 0.1505291898502037, 0.2083058762946166, 0.17765390075510368, 0.1814954649307765, 0.1024996409250889, 0.2116703731007874, 0.11216268569114618, 0.1191296563774813, 0.12452760071028024, 0.16691943223122507, 0.1638079187250696, 0.18033698725048453, 0.10124926309799775, 0.08187854080460966, 0.14048457727767527, 0.10132588242413476, 0.06691036469419487, 0.1337164724827744, 0.10929955416941084, 0.2039984066504985, 0.19783647323492914, 0.10564012787654065, 0.16100209584692493, 0.13908545079175383, 0.15168726677075028, 0.25783074146602303, 0.24985868018120527, 0.16997975239064544, 0.20065491262357682, 0.10569696154561825, 0.11039701246772893, 0.09735865780385211, 0.18646849261131138, 0.21704395272536203, 0.144751095212996, 0.19112288660835475, 0.08843151183100417, 0.19282960362033918, 0.16834508307510987, 0.1652858019224368, 0.17225580057129264, 0.20734243502374738, 0.1501152792479843, 0.17244712624233216, 0.12621496251085773, 0.2297954450477846, 0.13315585412783548, 0.11431942621129565, 0.16170611197594553, 0.1823965212679468, 0.10650989526766352, 0.10672965261619538, 0.06942185180378146, 0.14378403226146474, 0.08872521677403711, 0.1375528416247107, 0.1267178269336, 0.14380426320713013, 0.2319240730139427, 0.13178301451262087, 0.13232677127234638, 0.10814683555508964, 0.13703897857340053, 0.0793061159492936, 0.1234122714959085, 0.17163625569082797, 0.14737893623532727, 0.11649130654404871, 0.0791573895548936, 0.22329429077217355, 0.13880269252695143, 0.11720767201040871, 0.14434108830755576, 0.19392284651985392, 0.10246150195598602, 0.11448798279161565, 0.10227377570117824, 0.11431963401264511, 0.09648674560594372, 0.18694480299018323, 0.0985120443510823, 0.13406387181021273, 0.1502325088949874, 0.17457867827033624, 0.10606072522932664, 0.14991029805969447, 0.07105076947482303, 0.08632607597974129, 0.1425731144263409, 0.1326800335664302, 0.0976006721612066, 0.18339850968914106, 0.06370683971908875, 0.1824504160322249, 0.11415480301366188], [0.02082196981064044, 0.01459867005905835, 0.011887182499776827, 0.018866867103497498, 0.023284041017177515, 0.02975106948724715, 0.01760126597218914, 0.03746714362932835, 0.0069448556132556405, 0.03924717369955033, 0.038505786724272184, 0.009614099199097836, 0.021869618867640384, 0.04912305899779312, 0.0073851170964189805, 0.01280498818232445, 0.025573497950972524, 0.015364072005468188, 0.016735368881199975, 0.011689290677168174, 0.007144876935853972, 0.0667577346030157, 0.026527077934588306, 0.06136963485914748, 0.043996625681756996, 0.007332312825383269, 0.018911308761744294, 0.007758008732707822, 0.021185956138651818, 0.030119621878839098, 0.027900999230041634, 0.046594357772846706, 0.016393153455283027, 0.015124001147341914, 0.017296176483796444, 0.03541921680152882, 0.056359588852501474, 0.0372917815548135, 0.01644641739403596, 0.03048797203518916, 0.011688709946611198, 0.06017934872943442, 0.030906489519111346, 0.03015818201674847, 0.020979080618417356, 0.035066403506789356, 0.025565143223502673, 0.03946224809624255, 0.06230064798728563, 0.04706003317551222, 0.02183810171118239, 0.031276259032892995, 0.01598104998265626, 0.04995804192731157, 0.06343758854200132, 0.02900802752265008, 0.05646154881105758, 0.02863009438442532, 0.04707246785983443, 0.03354399144882336, 0.07214343349914998, 0.06430435765651055, 0.04065593697305303, 0.045145681797293946, 0.0638972748129163, 0.05687014192517381, 0.000675220741186422, 0.011168546989210881, 0.02427815710689174, 0.07720459863776341, 0.009068097442650469, 0.02612888602016028, 0.03636835688666906, 0.046082513363217004, 0.04068826492584776, 0.011320292996970238, 0.02118762411555508, 0.06356399113428779, 0.018851953645935282, 0.13299719779752195, 0.04837292952288408, 0.03320665564388037, 0.012688969163718866, 0.024870819543139078, 0.06850636069430038, 0.03307995619252324, 0.03408337324799504, 0.02539704306400381, 0.014705424291605595, 0.02855379047105089, 0.01675174993579276, 0.06190529849845916, 0.012648921019717818, 0.05039708164986223, 0.009922551544150338, 0.014450287835643394, 0.05105599746457301, 0.041089829901466146, 0.09025186649523675, 0.030904892046237364, 0.07035130271106027, 0.01444675428501796, 0.043347098035155796, 0.009376617508678464, 0.043010148147004656, 0.0762136014236603, 0.02421178312943084, 0.05472261145769153, 0.037309244289644994, 0.019854936545016244, 0.03547554952092469, 0.030460070993285626, 0.06533186111482792, 0.06626070346101187, 0.08370571580599062, 0.028788131021428853, 0.023247824210557155, 0.014229227090254426, 0.019508656005200464, 0.03478923732473049, 0.04436351380718406, 0.04474156012292951, 0.0411108438129304, 0.07327068902668543, 0.11819525534519926, 0.08851351172779687, 0.03665319687570445, 0.04151036417169962, 0.013966317565063946, 0.003344096094224369, 0.009636000904720277, 0.051311659917701036, 0.023667185887461528, 0.05425876173831057, 0.0412074269115692, 0.027829886639665347, 0.08076977959717624, 0.08536592984455638, 0.040283048583660275, 0.09150612575467676, 0.02594482597487513, 0.05300586803059559, 0.04517885208770167, 0.009709280566312373, 0.043591839785221964, 0.05100496739032678, 0.08804815544863231, 0.053719880888820626, 0.041547757282387465, 0.04829323399462737, 0.04783715085068252, 0.029169405679567717, 0.03387124146684073, 0.008581002730352338, 0.013408533286565216, 0.046255281631601974, 0.03118309352430515, 0.07578022428788245, 0.017331545386696234, 0.047125672426773235, 0.03801582453888841, 0.019739150375244208, 0.07438929853378795, 0.06988593158894219, 0.04292563236958813, 0.0650327088078484, 0.022880706019350328, 0.0413220033806283, 0.029814647423336282, 0.024695778447494376, 0.0711794504604768, 0.08815926979877986, 0.014192403577908408, 0.02007099614274921, 0.052427401024033315, 0.0313906351220794, 0.0554462648142362, 0.04629950621165335, 0.06197677103045862, 0.05179140644031577, 0.02520338890462881, 0.007063759730954189, 0.015321174014388816, 0.02455626210576156, 0.0075217715311737265, 0.010191955789196072, 0.040782243086141534, 0.03348474208905827, 0.010975353889079997, 0.03067819376155967, 0.022539095443789847, 0.03981243789894506, 0.002983509962177777, 0.025552591650921386, 0.054862313336343504, 0.04601749751600437, 0.02872530822060071, 0.068033308343729, 0.03027011644007871, 0.035972079713246785, 0.03142808018310461, 0.05822013823490124, 0.04368167676148005, 0.018095831328537315, 0.05929231156187598, 0.06653350952547044, 0.012635321163543267, 0.05923097676713951, 0.0341393757116748, 0.0514977979764808, 0.01763209107593866, 0.03785607354075182, 0.0046969733284640824, 0.052515360366669483, 0.028271136106923223, 0.01464034443415585, 0.013276620247779647, 0.02140615692042047, 0.01249202729013632, 0.04313928926421795, 0.04201526578981429, 0.05116878164699301, 0.029454564792104065, 0.033053543156711385, 0.03495119250146672, 0.035799712204607204, 0.03148321804474108, 0.02662587819941109, 0.03482611835352145, 0.03012423803738784, 0.03055295819649473, 0.01829550245020073, 0.037635032276739366, 0.044666681133094244, 0.05028947394748684, 0.03621884010499343, 0.02169065181078622, 0.023642782216484193, 0.035838133189827204, 0.10152759074117057, 0.06153667745820712, 0.041144971473841, 0.008963270938693313, 0.034735991939669475, 0.039548062632093206, 0.021268880009301938, 0.05971806313027628, 0.03591388791392092, 0.01819063698349055, 0.022233152485569008, 0.0371839103900129, 0.029787238054268528, 0.06991560265305452, 0.08050772725255229, 0.042722450889414176, 0.0486195414850954, 0.059986074920743704, 0.01939946010679705, 0.1301985589088872, 0.011173707698617363, 0.007533953421443584, 0.038593864810536616, 0.020403695380082354, 0.009862889364740113, 0.017342208193440456, 0.02525643019907875, 0.017174970780615695, 0.020923239571857266, 0.06521852032165043, 0.037009234802098945, 0.041042432640097104, 0.03897525450156536, 0.015379117194243008, 0.026965852339344565, 0.02700067761907121, 0.050809433741960675, 0.038221017239266075, 0.011787319108407246, 0.05058599534095265, 0.033351845704601146, 0.060458440784714185, 0.05262165446765721, 0.03668024073704146, 0.033993350734817795, 0.024595653449068777, 0.02443488014250761, 0.04358970239991322, 0.04071365008712746, 0.03571055058273487, 0.06774309149477631, 0.022776718142267782, 0.03771214142034296, 0.027036337814934086, 0.027461877871246543, 0.021060967337689362, 0.008235843761212891, 0.12521102966275066, 0.08296298183267936, 0.07771993856295012, 0.008340141484950436, 0.10900903303991072, 0.054544996964978054, 0.03406848947633989, 0.042063765140483156, 0.015207853630272439, 0.15775148902321234, 0.05580933458986692, 0.03181797859724611, 0.023730008688289672, 0.07785446767229587, 0.04480438292375766, 0.04156339062319603, 0.02881946635170607, 0.013100091146043269, 0.03126202464045491, 0.024597282463219017, 0.05873156333109364, 0.0068823639958282, 0.10048296593595296, 0.028047935193171725, 0.020883005890937056, 0.025704399813548662, 0.021201285198912956, 0.11007759210770018, 0.04916752106510103, 0.0329278084973339, 0.009655477642809274, 0.05290301749482751, 0.04173869703663513, 0.041509473594487645, 0.013533957171603106, 0.06958318728720769, 0.037314661967684515, 0.06464415739174001, 0.05259668119833805, 0.024023895457503386, 0.13498173037078232, 0.06253240586374886, 0.020381477334012743, 0.041611734122852795, 0.02721647746511735, 0.01800661404558923, 0.011850562150357291, 0.02058663663774496, 0.034145713652833365, 0.016847141887410544, 0.11548454611329362, 0.06517836271086708, 0.059371194438426755, 0.05164491019968409, 0.049236637278227136, 0.04002449175459333, 0.1799510556156747, 0.10976366364047863, 0.10427122906548902, 0.1165439173928462, 0.1100099972973112, 0.1020312195760198, 0.10125580884050578, 0.08910156728234142, 0.08550569109502248, 0.09171254670945928, 0.10408418558654375, 0.09792501296033151, 0.08389339753193781, 0.15832993376534432, 0.0692459850688465, 0.15070899738930166, 0.13405478792265058, 0.08819749782560393, 0.10119599173776805, 0.18640426715137437, 0.11618193486356176, 0.1654919408611022, 0.1417615610989742, 0.19064598251134157, 0.14996055630035698, 0.09458197906496935, 0.11660734875476919, 0.14925860334187746, 0.18270097993081436, 0.17112175439251587, 0.1378064780146815, 0.25605896778870374, 0.12491871253587306, 0.19379368313821033, 0.1444302499294281, 0.18686454714043066, 0.08499967996613123, 0.12183373080915771, 0.12447873028577305, 0.13956683746073395, 0.08032452067709528, 0.1180819293949753, 0.1198199501959607, 0.11021702681318857, 0.20189701550407335, 0.0998557620914653, 0.17972989560803398, 0.11369852320058271, 0.1886692870175466, 0.10333420083043166, 0.08611796292825602, 0.149186065827962, 0.1205018800101243, 0.11814326047897339, 0.1426110975444317, 0.10040300694527104, 0.10174137380090542, 0.20026730373501778, 0.19046498753596097, 0.13002240273635834, 0.253066539298743, 0.15515486273216084, 0.09729890007292852, 0.24375445616897196, 0.20631870167562738, 0.09404970332980156, 0.14052192214876413, 0.07613377601956017, 0.131696316821035, 0.11518969084136188, 0.20813729002838954, 0.10015351916081272, 0.15729383623693138, 0.13741680595558137, 0.12028626384562813, 0.11210988930542953, 0.12850306316977367, 0.12156607524957508, 0.1039979702909477, 0.31701244704890996, 0.11551807634532452, 0.1345148155814968, 0.22782299463870004, 0.09096785346628167, 0.13202888803789392, 0.10020330242696218, 0.13082359568215907, 0.07259570571477525, 0.13662232202477753, 0.14497525349725038, 0.09821273619309068, 0.12178479359135963, 0.19704516569618136, 0.17063107603462413, 0.11052833549911156, 0.08143295533955097, 0.19401358149480075, 0.15445703611476347, 0.11926860868697986, 0.12200353419757448, 0.17108000116422772, 0.14404111221665516, 0.13025974156334996, 0.07548674941062927, 0.1359680446330458, 0.17938908655196428, 0.09296086136600934, 0.1472684898180887, 0.14939204149413854, 0.10519597475649789, 0.14147335547022521, 0.10370183110353537, 0.11497373328893445, 0.1463937945663929, 0.14045734045794234, 0.14752994844457135, 0.11754695224226452, 0.09731338679557666, 0.07032290814095177, 0.08746037448872812, 0.19836872670566663, 0.21281325083691627, 0.17272703466005623, 0.19292721088277176, 0.30746854667086154, 0.18102243484463543, 0.13452799612423405, 0.15370148525107652, 0.12324814553721808, 0.34084129496477544, 0.20769730035681278, 0.15540535241598263, 0.060629038271144964, 0.16977744293399155, 0.18319538387004286, 0.08311173791298643, 0.1409785804571584, 0.2148999771452509, 0.12227979867020622, 0.18668398261070251, 0.0978819906595163, 0.11740606292732991, 0.13243934023194015, 0.16845478734467179, 0.08796326859737746, 0.08315197716001421, 0.1369656395399943, 0.16732908290578052, 0.1046863864758052, 0.14195809664670378, 0.09042962570674717, 0.09883057413389906, 0.18540839402703568, 0.08035164617467672, 0.1381605418282561, 0.17997067800024524, 0.10883422015467659, 0.15482968330616131, 0.13927640538895503, 0.11550248382263817, 0.16618872847175226, 0.09744473951286636, 0.11140821094159037, 0.1665523659903556, 0.0814168136275839, 0.18922356743132696, 0.1321238829405047, 0.16463891632156447, 0.1503070947364904, 0.1071405278344173, 0.24193802004447207, 0.15590584196615964, 0.24149135104380548, 0.13538893195800483, 0.26739316585008055, 0.23874491482274607], [0.05423297581728548, 0.08702526072738692, 0.02361734881560551, 0.0300547748702229, 0.04713778798759449, 0.04671739472541958, 0.038358336823876016, 0.015183039922703756, 0.015372231919172918, 0.06421299927751534, 0.014714092576468829, 0.002409916546639579, 0.03011804110428784, 0.05166644732526038, 0.09211960728862323, 0.028649542364291847, 0.08975443459348753, 0.027857004715770017, 0.09610465087462217, 0.006411060794562218, 0.053876247693551704, 0.04058121383422986, 0.02804192750772927, 0.01844797112426022, 0.04018013867607806, 0.039551183363073505, 0.04550260287942365, 0.008357264687219867, 0.04770906729390845, 0.0012305070549700758, 0.03287496758275665, 0.03207418652891647, 0.009265897424484137, 0.035867537080775946, 0.005552483135033981, 0.019548123418644536, 0.08052794335526414, 0.026708568293543067, 0.011353749941918068, 0.08730442699743435, 0.03695935505675152, 0.12798908137483522, 0.04050144780194387, 0.12161571750766598, 0.03363267067470588, 0.06003313079418149, 0.04788142367033288, 0.0574438257899601, 0.03908179351128638, 0.02330418847122928, 0.050128624570788816, 0.016692969984433148, 0.028390926163410768, 0.023696272510278504, 0.05639071823679842, 0.04956621392921079, 0.02916219200415071, 0.0716829976590816, 0.041145372233586386, 0.026710711244959384, 0.021378895980888046, 0.012536662834463641, 0.033793764960137196, 0.02547605210565962, 0.032574843062320724, 0.00787315248089726, 0.029085743371979333, 0.03404743103601504, 0.03974660568928812, 0.039127246345742606, 0.04010681077488698, 0.025312436373496894, 0.0084592190796684, 0.030962543933128472, 0.010239957900921581, 0.039143803660408594, 0.0531240290729329, 0.06357755017234012, 0.08083004940999672, 0.06462136603659019, 0.05474864970892668, 0.018405622322461568, 0.027146090324094985, 0.0600195828883443, 0.008322606390720466, 0.02596390844701091, 0.024912040280469228, 0.06460323536884971, 0.009519711929897312, 0.03492642703349702, 0.03768294533074368, 0.03043294549570419, 0.04663748768507503, 0.028822861677326728, 0.053850428375881165, 0.03799371967033949, 0.017422673699911684, 0.06326820075628348, 0.030563225809601136, 0.07355031542829238, 0.042290019991924055, 0.021582693443633616, 0.00862778029841138, 0.04145182727370411, 0.03807895533100236, 0.02243813367385883, 0.0630429812008515, 0.011873865587403998, 0.030484704730042722, 0.038174287910806015, 0.02376194330281578, 0.015002939235273516, 0.014555811958416598, 0.05244570238573942, 0.05106679200252984, 0.014926525855116779, 0.06577322375960648, 0.052362552160047926, 0.1031180057907477, 0.01755808410962345, 0.03178758022841066, 0.01288749830564484, 0.027571476384764537, 0.04324788773374166, 0.019959067285526544, 0.002827002149388136, 0.10969027265673503, 0.06646352499956265, 0.011738554439943982, 0.01505522261140868, 0.031099557381821796, 0.026736910913314205, 0.059800604794872925, 0.029260075716592837, 0.03139392654702533, 0.025192872672050726, 0.0038776691962993937, 0.013682228072866565, 0.0398154176218668, 0.05485302164743189, 0.027057845254603308, 0.011918292402697261, 0.018159878673031926, 0.04386337306641508, 0.07315769704291597, 0.029737094846495893, 0.05280559948005248, 0.028917797208123375, 0.027312453858030494, 0.06544749514432624, 0.026078881965077017, 0.029611413992824964, 0.03804107240284793, 0.05055551533587277, 0.06775885471142828, 0.0388876476790756, 0.010835580578714143, 0.03705344453919679, 0.01618006430362584, 0.07760864609736018, 0.03837458243651781, 0.03563407597539481, 0.01826361421990441, 0.10300203779479489, 0.02229017725767335, 0.01625853343284689, 0.01617736474145204, 0.026320710785512347, 0.027771474051405676, 0.0865860799967777, 0.04008671712654177, 0.02188749534980161, 0.04922620268189348, 0.061953593758516945, 0.017825368595367763, 0.06379842074238695, 0.021498196219909005, 0.04748995190311689, 0.05354478598746937, 0.028304900115472265, 0.1243457745295018, 0.048011715116444975, 0.03617269336245954, 0.034933948700199835, 0.03940715847420506, 0.12542709853732958, 0.03754606361326296, 0.03315299465612043, 0.03408344004128594, 0.016185084932658356, 0.03708802119945176, 0.01960100886208238, 0.054210087982937694, 0.015020156133687124, 0.06368151764036156, 0.01979109143576352, 0.04764174336742144, 0.057172485467162915, 0.02257058662507916, 0.021272375524858944, 0.055574337238795124, 0.0362324139859993, 0.05189402319956571, 0.03954496787628159, 0.030157686633174308, 0.06566304451553151, 0.041570500397938304, 0.048742285289335996, 0.02161236265237676, 0.04590895099681802, 0.045757270854664966, 0.047013611838337965, 0.059268462646286935, 0.05901488933886867, 0.12730801245197654, 0.048294373191311024, 0.0666412990540266, 0.06712773232720792, 0.04622182190360036, 0.03338786213134881, 0.010646557420841418, 0.022279456934484188, 0.06479312127339654, 0.04787088146258611, 0.0671222255914472, 0.07034015565295704, 0.024621691700303927, 0.07225661844131537, 0.016865719699126203, 0.009087324633583194, 0.004510273092819261, 0.04268579250492621, 0.015447925416083308, 0.025373442767886445, 0.04681836020608898, 0.0671360814885702, 0.007412074683088576, 0.030134143853501882, 0.014444800581259187, 0.00496873621159466, 0.036191451144986786, 0.026519251987338066, 0.06849879078799859, 0.051589520007837564, 0.029266450765135232, 0.031220438395394012, 0.021174617977521848, 0.026680852788558695, 0.04651225397537928, 0.007641925240022829, 0.011944982816203265, 0.06628717586863786, 0.053314979959395714, 0.08480692937155254, 0.03641808078100439, 0.05088889920443762, 0.012093848363292636, 0.04714848233561497, 0.024654077169543598, 0.0520846252766205, 0.034610468792379834, 0.05106904442072846, 0.023437229574483354, 0.032314575582859106, 0.012063354442943819, 0.0563052042707568, 0.0014081224753681454, 0.008210258220060496, 0.03319984272820875, 0.03699102620885242, 0.029485135710274335, 0.06644017703365535, 0.07456657534930855, 0.037376093241618946, 0.027879703302460257, 0.03830019697488751, 0.07081490010023117, 0.04305489965190645, 0.02230631154816365, 0.07075115703628398, 0.08161347534041852, 0.0065721754890546435, 0.03970796948124189, 0.012397781028994359, 0.07416235719574615, 0.04414606453792658, 0.09749217017088085, 0.014311525701486971, 0.030384319979930297, 0.07370768042164855, 0.04424316342920065, 0.018556011127657257, 0.07694166313740425, 0.019928179099224508, 0.05594085429038387, 0.06077917474613059, 0.04775654619152192, 0.045489299882319756, 0.05181642794923391, 0.014379745771293528, 0.05466926217195578, 0.041976410648203455, 0.06322793182334863, 0.06049888412235305, 0.029520495336328167, 0.048053820864879526, 0.0440944259025855, 0.027428340217738878, 0.022118607557786163, 0.032094469424919225, 0.06685400599963032, 0.011495588278194191, 0.05339777395420242, 0.05161303124623373, 0.0027627725148704485, 0.05552864691708237, 0.08021567729883827, 0.011547856811375823, 0.02046632522251457, 0.060490401374408975, 0.024756463863013778, 0.08844472205964848, 0.031132775911828503, 0.0223459162589279, 0.008337158051290317, 0.04739145777421072, 0.0582582363858819, 0.03575267117412295, 0.0066303357471042546, 0.01758230966515839, 0.05454105245007668, 0.03117233980447054, 0.014481926518783439, 0.014984867939347168, 0.017142837641586084, 0.0542711036541732, 0.027786873615696095, 0.14144456014037132, 0.030925779792596586, 0.021210250342846848, 0.02331457297259476, 0.03926030229195021, 0.02301834843819961, 0.013082870536891278, 0.035517833384801634, 0.10258557420456782, 0.06578292362974025, 0.03408349570236169, 0.027257414330961183, 0.0893814311712049, 0.026676811794459354, 0.026585238192637917, 0.13056053401669487, 0.17443297983845696, 0.1041356312634889, 0.10281758441124111, 0.14410244330065325, 0.11461844493169338, 0.1268756520585157, 0.11967702739639208, 0.1259654969908297, 0.17269173811655492, 0.11273366442765109, 0.10996696757501923, 0.14297771849669516, 0.09005384665215388, 0.12909281824249774, 0.10663836103049107, 0.3082744893617928, 0.19649780209874734, 0.153613822767511, 0.12654894380830228, 0.17904047010233626, 0.11789558353484608, 0.15034730429761112, 0.08970620241598226, 0.15183044190052897, 0.10887035532505251, 0.16942622896749526, 0.15627411048626527, 0.12706806126516312, 0.11393080800189637, 0.1746635651215911, 0.1471737917745486, 0.09790207317564636, 0.10335224244045094, 0.10248600025079213, 0.18284448160557076, 0.16683093854226172, 0.09780048800166696, 0.20895243535051122, 0.13063660415355116, 0.1176409526669886, 0.24001260695513338, 0.14623274852056056, 0.17551246332004666, 0.1502331768278964, 0.13082107238005847, 0.1611226354725659, 0.1056912618514616, 0.1266449035028927, 0.12333030870649964, 0.14604966068873182, 0.15407720493385568, 0.11302132086711936, 0.09626042767195031, 0.11283621439361013, 0.12932444253237918, 0.17008610215270892, 0.08881597401341423, 0.17451550666010007, 0.12222494653542526, 0.06552137594553642, 0.07606398445204832, 0.11740577348973602, 0.08253405016148463, 0.07767195129417814, 0.11170499579748139, 0.1664733124198392, 0.13876136974431574, 0.11343246325850487, 0.20396282809088007, 0.11320898032863624, 0.08467507941531949, 0.10442346581839956, 0.16540402604732662, 0.09362153607071377, 0.12896220025140792, 0.21917877020314336, 0.1331549635506235, 0.17705307283904403, 0.17894419870572165, 0.11557453151908703, 0.13282996224006638, 0.18348489567870274, 0.21923434222117066, 0.1157134838285856, 0.18949655903270468, 0.06957492718356661, 0.1991678267950192, 0.12803491641534492, 0.178769942431245, 0.1479973827372305, 0.06485443751444109, 0.17794373910874128, 0.11940255149966106, 0.15434792556334287, 0.18246292864205316, 0.22359938768204302, 0.14578533737221733, 0.15660126402508467, 0.23753839050186798, 0.24102204653900117, 0.20119080261792988, 0.1101057417690754, 0.16516633098945022, 0.18745314446277916, 0.12955410755239427, 0.15881335391895846, 0.09859678277280182, 0.17197733192006126, 0.15785175317432731, 0.10254570603137836, 0.0880871553090401, 0.08791151121840812, 0.22437246807385236, 0.15163979900535196, 0.09055380927748047, 0.19532088947016746, 0.07475899939890951, 0.21735191432526335, 0.12752255250234157, 0.08618249266874045, 0.22659010923234746, 0.1954656231100671, 0.1593708255677484, 0.11893295013578609, 0.06858026375994086, 0.2147502265870571, 0.16460866638226435, 0.1518319855676964, 0.1032655818562489, 0.12636428262339905, 0.10644492766004987, 0.12126187633839436, 0.09996749984566122, 0.16512744245119393, 0.17603867570869625, 0.10561677248915657, 0.18032267864327878, 0.12646870280150324, 0.12626289040781558, 0.10278551621013321, 0.05653651314787567, 0.12760546524077654, 0.1962997525697574, 0.1033797167474404, 0.20644884469220415, 0.1275766550679691, 0.16642241593217477, 0.07864848405006342, 0.10491340202861466, 0.16275541973300278, 0.13493347592884675, 0.08794375011348166, 0.0978190713794902, 0.1277949652285315, 0.12273114320123568, 0.09002259481349029, 0.1609772487427108, 0.1064859758480452, 0.1286208420060575, 0.2296541995019652, 0.20471005205763504, 0.14273660955950618, 0.1864454266615212, 0.16163232765393332, 0.16650660516461357, 0.05966858043393586, 0.13695389876374975, 0.21616989572066814, 0.2696713217301294, 0.1399252057308331, 0.08577356187743135, 0.07311711640795693, 0.13087247352814302, 0.17607477377168834, 0.18817225587554276], [0.00989180993201444, 0.005600684235105291, 0.05153430422069505, 0.021242767543299124, 0.029644992464454845, 0.019732207583729178, 0.038981009856797755, 0.08636746555566788, 0.06521615287056193, 0.050268834820599295, 0.00867852000737912, 0.025873359008983243, 0.05775874502432998, 0.03375954082002863, 0.057848604265018366, 0.008836939778120723, 0.05282478028675541, 0.04744263998873066, 0.022768730777897872, 0.053060872305650264, 0.03502959669276606, 0.0692356692161411, 0.031416023994097486, 0.0515689736494096, 0.020634816864912864, 0.04669274057960138, 0.0653004163177684, 0.0076229480600886745, 0.015658384581911378, 0.10542733187321573, 0.024778129009064287, 0.025929133262252435, 0.04784629411005881, 0.045887198648415506, 0.010601841167954262, 0.08420711077633314, 0.07174308935645968, 0.015814923935977276, 0.012244857789482921, 0.0762592806131579, 0.04466806523851119, 0.03400938854611013, 0.01925654101796681, 0.05513366479135584, 0.05457644918351434, 0.05876900097064208, 0.03696476160257589, 0.1018786859640386, 0.021507894234673586, 0.07271931041032076, 0.024106659766403027, 0.03113367762125563, 0.06564344439539127, 0.04761557524034288, 0.00905034527022508, 0.011835345339932246, 0.044771457542083226, 0.09515171841485426, 0.038138690797495656, 0.04273631420801394, 0.029339969769353047, 0.057294587313663214, 0.03849090666335542, 0.06417428885470144, 0.040155896422220394, 0.0649941542360466, 0.048236916118185036, 0.023157167161116377, 0.03270590634201653, 0.052237236814107746, 0.06254464387893677, 0.03935589091270231, 0.022344062745105475, 0.052733425618498586, 0.09254770033294335, 0.03944431780837476, 0.0447004414309049, 0.05377003151807003, 0.02354928645218024, 0.031377718041767366, 0.02657017630554037, 0.05643872034852393, 0.04754199500894174, 0.07581846715766005, 0.09477317114942707, 0.016336963599314913, 0.06039883890480269, 0.060505203509819694, 0.01744116987538291, 0.03382808557944372, 0.01871554875833681, 0.08857481312588789, 0.03646954872237984, 0.03337739413836971, 0.03481336454569828, 0.023500666502513923, 0.01686557869106764, 0.06558963868883438, 0.01936586864758283, 0.053297491249395534, 0.035299107621540315, 0.013824598900100682, 0.0061248598922247766, 0.11647175837424584, 0.04514949643635191, 0.02466331690811785, 0.055043055981514044, 0.0315909741766518, 0.02964157858514227, 0.030025755040696822, 0.023513839623774402, 0.01924424919707235, 0.038451702712336555, 0.041820477999863215, 0.03074981472309446, 0.029153609066270292, 0.008046020939218579, 0.015074889524839818, 0.05091524915769696, 0.038665393003611825, 0.022585073347727302, 0.02787898341921391, 0.0530483151669614, 0.0897941469156649, 0.031530837950413115, 0.03969514145865105, 0.00986540431767935, 0.027006204763893038, 0.04774876477313228, 0.02031201045610942, 0.03267750435043126, 0.043911634929827414, 0.03912365064024925, 0.04328879120294005, 0.028453442828322295, 0.028228724222572055, 0.05829023779369891, 0.037793258161400445, 0.010419409209134756, 0.0020054360902577173, 0.06400351325282827, 0.06948922396986745, 0.01831479457905516, 0.027828485835925676, 0.032764446950750425, 0.003901638247043593, 0.008103482650767546, 0.03303841447632294, 0.007721479760220973, 0.04135842798859812, 0.0415941823303001, 0.014101591605140129, 0.05007506377296522, 0.04521060116530862, 0.05910906045755837, 0.03022717577550793, 0.051307986286701635, 0.016729652488720603, 0.02109857010509586, 0.03311934196972288, 0.058088080477318726, 0.02804279953124933, 0.04161658405791968, 0.04580725078994874, 0.02697565796552226, 0.03815142234088853, 0.035886150144506246, 0.03590263324440457, 0.08306300107506104, 0.03996900137281045, 0.04186666556051932, 0.01381726277031703, 0.026195504906354472, 0.02837715746863978, 0.017317233068752103, 0.053671106943511404, 0.03466480142378714, 0.017778180990717374, 0.06575901905307546, 0.03906941448803991, 0.011194241997145582, 0.06655929915723391, 0.04409464112541173, 0.03807068780588452, 0.14042835216969252, 0.027351429598638788, 0.05011665001802612, 0.03313337598228827, 0.06713933209539391, 0.024092798303172458, 0.02021909171162406, 0.039262948048417456, 0.024095082262647338, 0.01647110122576123, 0.024078873757389374, 0.07512346070143394, 0.02269286287628347, 0.026179027372563723, 0.020534402428893372, 0.04398239871079568, 0.0861645772238262, 0.011687238638842246, 0.025648725750215817, 0.06364743079757318, 0.008649270112073282, 0.047058641648618504, 0.05257586024526972, 0.011191349476575851, 0.024883304322429467, 0.04529207413725089, 0.04484775403398089, 0.049550302283023484, 0.059483151126187295, 0.0318636392330518, 0.014044201325305039, 0.07666202189284377, 0.07171820514486171, 0.04654666736314539, 0.05059384355263319, 0.06549986108439043, 0.05971701299131382, 0.021753300206910353, 0.02306525217136368, 0.009459899465582566, 0.007948717957333429, 0.04382508937851526, 0.0025172779487547814, 0.05272348826110829, 0.01184466207632795, 0.09500187137746252, 0.03782187537581194, 0.044318231666693464, 0.03906837177055422, 0.018377387314103544, 0.010499710515432525, 0.014359685519593768, 0.050247490653418936, 0.023017014427750837, 0.01417014285834739, 0.05748120405769441, 0.03609559906180948, 0.0483088302280521, 0.051530259515857324, 0.04076510689628776, 0.0674605558742769, 0.10163320577703416, 0.03173041630361695, 0.01525090654467931, 0.03521088481647894, 0.01752221054630354, 0.07550519920187071, 0.031597211927874014, 0.04586386552546173, 0.060511838310048915, 0.06368419679347426, 0.04768462466017809, 0.017824650567490608, 0.032143161733984016, 0.05908422819629777, 0.03451688768109307, 0.0261931745626498, 0.05899036506889388, 0.06998953540460207, 0.08293374863569625, 0.058891073131235316, 0.10207729210378602, 0.042236670706188306, 0.13233785895863548, 0.01543602229503449, 0.06406468106433749, 0.04042491753352806, 0.05040219875809271, 0.05875351605936885, 0.09409560516360216, 0.02585546582849929, 0.04934555487125181, 0.029623774462379515, 0.019834317827189807, 0.033822326513472944, 0.04442816600203514, 0.021820230795128737, 0.015532535817328608, 0.07800753563060425, 0.03385265066754073, 0.011072402685385896, 0.05153171041456517, 0.014141478332021507, 0.017674478840490337, 0.03670576690637972, 0.03086071756115416, 0.04626117428415455, 0.028070448242942803, 0.0840461092593614, 0.10667503796867095, 0.012557672107504914, 0.016182409490284044, 0.020370267193356995, 0.0453904495225288, 0.10016163083491847, 0.08005396332009695, 0.013687292303075083, 0.030470696692646015, 0.00816302330349572, 0.051879974344046786, 0.04230058075336274, 0.04194969333184417, 0.00887456017153454, 0.03227644774597138, 0.035415194361121394, 0.041153001511702314, 0.0860668660607189, 0.047345433486043476, 0.045679924223804846, 0.033774012699723244, 0.026849852802115493, 0.0140115431167942, 0.04648122478101868, 0.03220817387045827, 0.03646430544904433, 0.0491814919951139, 0.05296477160300128, 0.02502248669770779, 0.06342810389469378, 0.024869676635717042, 0.11779002044931985, 0.00968652724623098, 0.013849381994077703, 0.0020825048795813927, 0.01393762056977721, 0.07205201574834064, 0.060185901893419214, 0.04132871610636357, 0.08399539088713937, 0.04237891815137118, 0.035025054748984985, 0.038741281314287335, 0.04547555901808664, 0.08838900903356262, 0.010827924397744937, 0.035731594180106185, 0.020649401922128163, 0.008141744074237067, 0.014701848067488754, 0.0588457724370528, 0.09057651157490909, 0.043231423187535256, 0.03939708381949458, 0.012164477629994508, 0.04845731171371881, 0.06152590147394221, 0.018699446009122767, 0.005063392045485671, 0.12579370464663953, 0.10320368674001656, 0.1513568329392001, 0.17162697884486988, 0.06386085020494647, 0.1128041313495487, 0.11621224417467602, 0.1124262074881699, 0.2694915735628456, 0.20743845409015194, 0.12990639021154493, 0.09691767365438864, 0.17877901147585362, 0.14474150666501373, 0.10496135961147957, 0.12709443719359115, 0.14355053775943816, 0.11272173069301061, 0.13024314714130014, 0.13027685548877344, 0.18155220954213291, 0.2496433089254424, 0.11788817690103315, 0.10674569042748772, 0.1449905862682499, 0.11464413808425888, 0.14387214003363624, 0.1047875708900392, 0.07797683298122138, 0.21680373436538503, 0.11645666309050284, 0.10562689538346604, 0.12981129140825942, 0.13486512412782758, 0.10425104264868423, 0.12325614588917233, 0.1629918976686895, 0.10270718252286315, 0.10844473363249563, 0.14015485590789467, 0.10949147355859168, 0.1435113523621112, 0.13662935758475214, 0.17853543860837817, 0.1804813349735923, 0.19289954361738637, 0.07227808877360076, 0.15476999979000539, 0.10204499383689836, 0.13346166349947453, 0.16073835140559822, 0.13945636135758832, 0.15316889039240777, 0.15818508138181642, 0.14462092251051217, 0.10929141280939803, 0.14176055177813396, 0.12026304946630262, 0.13195499981520697, 0.10918262138147838, 0.1432662655133754, 0.19361711136298254, 0.12762781872879714, 0.19546874013030902, 0.160687321331352, 0.15445442375494167, 0.21353096701204777, 0.19496277353027835, 0.16221170750213787, 0.1570964843267575, 0.15730931743746623, 0.1037091932084877, 0.12416431200108491, 0.13486533192917705, 0.21462435834109783, 0.14845291298115626, 0.1216200739145279, 0.16560185293201357, 0.16548214451177046, 0.11957975410041399, 0.2595017908606678, 0.14324213087093085, 0.16484892927110195, 0.13570180657552555, 0.20408455515280366, 0.10865490985452197, 0.1885327763739042, 0.12147315093898214, 0.1766723213950172, 0.258952037547715, 0.10302582362783141, 0.30269778391811997, 0.115068958257325, 0.11562459680135362, 0.09075056004803628, 0.15232681995257735, 0.13713606633245945, 0.26616315997671336, 0.14534178539179265, 0.17246777279069647, 0.1326705637620762, 0.10348036681534722, 0.1479923361330293, 0.27121641382109374, 0.14333443919895217, 0.08909040538128465, 0.2447483254945837, 0.10627418916556053, 0.19222600007196888, 0.1805435714777559, 0.1381486377795227, 0.07799802129738964, 0.11465463205240667, 0.09572283815941773, 0.12067951305652969, 0.09814684090088122, 0.21253904211334884, 0.16921721049584448, 0.10950777112157084, 0.12540658557554707, 0.10144234023755416, 0.10713213414419442, 0.16037066176068038, 0.22440671076765284, 0.08452311725704931, 0.11313863957184367, 0.09113440624787472, 0.15904465166386217, 0.12589828809723258, 0.1119971125444863, 0.11626406834693626, 0.1462622414692305, 0.12204717990243807, 0.13227467250544578, 0.13668196101207286, 0.15406207996420562, 0.14927102689398453, 0.10202370904153213, 0.15496626816457137, 0.08947311609517783, 0.09829824644839391, 0.09675115798017941, 0.11785659109591506, 0.14094144338741899, 0.1299816439859569, 0.14498907228698954, 0.12695390410954133, 0.1629108254564926, 0.1716236540232785, 0.1035851877531968, 0.16548934334423393, 0.06589794909814373, 0.14143749489448965, 0.12986487447051331, 0.1816734319436364, 0.12797737028449774, 0.14366368559421971, 0.16553059191210195, 0.09449954130104743, 0.24790687632048503, 0.11201095359865576, 0.12909155659144744, 0.2497375913662836, 0.24790004856185988, 0.13267742120660841, 0.1388362524448894, 0.18189511145465076, 0.17267864663153887, 0.16285592137137428, 0.15469976293388754, 0.10223513949313201, 0.15838825172977522, 0.10572215003776364, 0.16395207348978147, 0.17388612090144306, 0.12634917249670252], [0.05729846132453531, 0.027295748113829177, 0.04518714929872658, 0.03986433628597297, 0.03614183486206457, 0.005158787707841839, 0.029256446614454035, 0.03329916435177438, 0.01773941119608935, 0.026471876990399323, 0.11618905948125757, 0.030958278439356945, 0.015456313540198607, 0.021285439179337118, 0.03460881009232253, 0.017009195398713928, 0.0613763587170979, 0.02499748003174318, 0.03671114747703541, 0.05513598029210698, 0.05317369730619248, 0.09556376622640528, 0.025081190578930546, 0.059815844797412865, 0.023435105176758952, 0.03170643380144611, 0.03502577463223133, 0.026460284643690102, 0.05350234998331871, 0.018393291538814083, 0.06009496653859969, 0.038689364373567514, 0.059920595231233165, 0.05143491580383852, 0.07169758828240447, 0.0768207895453088, 0.042741371944430284, 0.04073607036843896, 0.09245565917808563, 0.007297682359421742, 0.02247668082418386, 0.020045974633831065, 0.06812356092268601, 0.045551406510639936, 0.06834243511548266, 0.03653855361335445, 0.049260196756222285, 0.015310686540033203, 0.010325255716452375, 0.04882284170889761, 0.0197942381419125, 0.029944233829155564, 0.02222808176156832, 0.038511352831847034, 0.013773740447504679, 0.026299895398551598, 0.018869403393182438, 0.014949028700357303, 0.013159121572243748, 0.032608926194370724, 0.021709467109758407, 0.03414179511310067, 0.02765420915238792, 0.014072520752961282, 0.0007939693557545979, 0.041739231382962316, 0.05652747378917411, 0.02781955223326804, 0.07801513522281311, 0.02945021024061134, 0.031579300193698145, 0.03543195576639846, 0.0306501016166294, 0.04042305103212129, 0.0024162906674973783, 0.036672351707238704, 0.050449588597984985, 0.021273741076583974, 0.0203149586377549, 0.09221532207448035, 0.03356581430125516, 0.11610178291448392, 0.057417390489717945, 0.00214595108445792, 0.023509095444751438, 0.026541891202214174, 0.032415240493719466, 0.02834031911334023, 0.031206304192892276, 0.016093591111712158, 0.16890862549189478, 0.027531650885066483, 0.03897347334714141, 0.031205591731122695, 0.022129635872261133, 0.04747258193674497, 0.025140792458842043, 0.04667906279792078, 0.032450711441924796, 0.04600955653586425, 0.03532495662511792, 0.02098991968523478, 0.023765127116348594, 0.04127994958253112, 0.04339367522334214, 0.03867357147100847, 0.014895931744831614, 0.043383808369981125, 0.09567928151227534, 0.04018336330773309, 0.0228876617984497, 0.036281143402447924, 0.06353046090225689, 0.017413517452951055, 0.05806236506032292, 0.11629870437900536, 0.025319381020381115, 0.036647805172833614, 0.05817541270516813, 0.041601863558753394, 0.051839107982232235, 0.056901234202086926, 0.019985073995485436, 0.02415512572042644, 0.02238048178696772, 0.04311481323384214, 0.05570816130784806, 0.024164699425455183, 0.03072719777264865, 0.028189360709802713, 0.001166698937140609, 0.0812309056345839, 0.0412334095017286, 0.02700401357287774, 0.030948762250773143, 0.009706883429316804, 0.013434576176223345, 0.05450345153803937, 0.06107307635829784, 0.1002474527922459, 0.047082397795747966, 0.07569092907942832, 0.060280325342318974, 0.02906360325141577, 0.02883429446228547, 0.04422296959091909, 0.09259323851438239, 0.06161886660265736, 0.06284278686507605, 0.04804941621841863, 0.04811416118172929, 0.03426014169235714, 0.03727249684743583, 0.03224573396437336, 0.033129190269391984, 0.010568785910436418, 0.06579381835763343, 0.04144908132730052, 0.04412723254063167, 0.024683822448423598, 0.09397352929227054, 0.003167050967931573, 0.025511326384730637, 0.08556530781788751, 0.020037892645632382, 0.08118688885588199, 0.04826227159355767, 0.0864373536023777, 0.04606862406944856, 0.0252427635496133, 0.02351337763684569, 0.01455021894798847, 0.019079533230978996, 0.0705348803603556, 0.017252940815524198, 0.006705032446916448, 0.06450528671848588, 0.08753650399739854, 0.002592991158962832, 0.05749742369516753, 0.07842789549613371, 0.015105854708963307, 0.05956999353657011, 0.06297896354226395, 0.04461220378288999, 0.0726025334734004, 0.0628792263159994, 0.0318431893538218, 0.06130306421255227, 0.007991884049260989, 0.010106190420628991, 0.028674474815488793, 0.07289127344847657, 0.037662124377675354, 0.053868618415435776, 0.02767704503639834, 0.03114655388344545, 0.06304232068941928, 0.037418952269945294, 0.050167056688223965, 0.04564593757095281, 0.041370398830622435, 0.006863445260023582, 0.014190731890266761, 0.030478914122795686, 0.04436352493939921, 0.046896066778572276, 0.032153477586689405, 0.04587748022458982, 0.08260201604571193, 0.06187599850818515, 0.05392160775954835, 0.027684978595061693, 0.026730070167104714, 0.046397569894907065, 0.08314829610753804, 0.015819981672393624, 0.04192425622022711, 0.05201134932576679, 0.05090544538688846, 0.04921560481307097, 0.044961447347304784, 0.017176280671264976, 0.018055573527817614, 0.060397365741664544, 0.041585992730688304, 0.04778532667842228, 0.037960642148391344, 0.04390085152408574, 0.014316525921458378, 0.016272142565867398, 0.01611406696611084, 0.020347798672446515, 0.0380118651810335, 0.03489815862849355, 0.0891407229937613, 0.03157627965265419, 0.0244253435448627, 0.03051519215659937, 0.02172831209463766, 0.04534564235655125, 0.01842041889176471, 0.050474031231715344, 0.01839867025410058, 0.13756499800365418, 0.09371958120027557, 0.030057858493819367, 0.036815660423599184, 0.03791763840126805, 0.02861268545530038, 0.0451461790362373, 0.023598945408593863, 0.045176124694989994, 0.02193880187405739, 0.014766147742193425, 0.0793343991972506, 0.04242135415552184, 0.012108723785786424, 0.029292908329807688, 0.055335573488264345, 0.012282034749659942, 0.013805388407490682, 0.05499469392816536, 0.0301321920051123, 0.042386220884509385, 0.023652597119507845, 0.04684394945797976, 0.04400427722430322, 0.015049986759549938, 0.07092720930813812, 0.0584913078637328, 0.08253344902186655, 0.0020213057587170624, 0.02778721314825816, 0.045123027739464305, 0.026985730764863547, 0.07936615569633432, 0.028870882342744153, 0.0150445727922488, 0.02949568719486706, 0.042528564808890224, 0.02854054870113032, 0.013556607518694364, 0.016117965096782427, 0.023212247506307904, 0.004741370921692578, 0.022293513211479876, 0.04751120701257605, 0.062009618486627005, 0.032817165410961024, 0.05153256388439331, 0.06140013341791928, 0.040017526698648, 0.051063853097730316, 0.020429267933650408, 0.03344943070260342, 0.055570251715835184, 0.044870044439448975, 0.033037327229976654, 0.007375914465228561, 0.05009018874261528, 0.05461872562591452, 0.027664781046041753, 0.054309973638737574, 0.03446840688411612, 0.005330029007382109, 0.0765679101459682, 0.0851359531225171, 0.03781451327085961, 0.033392960685887374, 0.0792355822341051, 0.04885446462139953, 0.021255599276628345, 0.033753507159417495, 0.02144818103261059, 0.07594851369503886, 0.03555546769348439, 0.015015935168776195, 0.052668320713564754, 0.036706264145323075, 0.022359610738931224, 0.04085004569787998, 0.08829189158859663, 0.02894365734391613, 0.0641422503395006, 0.012072184144926723, 0.04521600771113299, 0.04070952003530692, 0.043656484558596276, 0.07566352898720652, 0.06833519917563535, 0.051236354192951694, 0.09578075536410324, 0.022562300546269398, 0.02473791017109761, 0.014224697206373094, 0.061127869121264666, 0.04977072014298756, 0.021069761787657626, 0.014417132388189202, 0.057156488473992795, 0.10849937796592712, 0.05997452710289508, 0.010509416879358469, 0.0319286625017412, 0.008007808683032636, 0.039743618544889614, 0.013361971869016998, 0.021379764293669723, 0.04307893410441466, 0.026362662538303994, 0.022804672989877872, 0.14024539792444557, 0.2409466146491468, 0.0725343894737307, 0.24128491524606943, 0.15775429434143007, 0.12627411168068647, 0.10223906545434147, 0.16159664519364014, 0.0975773464597296, 0.10761082681710832, 0.20995004510041326, 0.17481615068390965, 0.11958652990870178, 0.05353090411517769, 0.12662670604186133, 0.11981571995420381, 0.22913083696039394, 0.12165476931841113, 0.11459178698714823, 0.14544449863024056, 0.10643959903973155, 0.1896867121104151, 0.14362623682245612, 0.08220472212997265, 0.14145977416774258, 0.17524451832287014, 0.060692762781400234, 0.1538584049558267, 0.19334092852659523, 0.09476368650211953, 0.10811311236466281, 0.15645091974874958, 0.24838550220010802, 0.13745686708716676, 0.22366362798493356, 0.12160435522673652, 0.08529867642209865, 0.24280838115373626, 0.18446766247507185, 0.13873533520381898, 0.10709687470807694, 0.17193937848787755, 0.1249801178346388, 0.07544440988567658, 0.12152594732469879, 0.09294413335737772, 0.10245489684166387, 0.15703500481322408, 0.14331256068544462, 0.11317265219986439, 0.1920415466884151, 0.14459135534707457, 0.06656403405941091, 0.09551142255077139, 0.1697752164909616, 0.09092355467146263, 0.13422625372186303, 0.15241516521200538, 0.11948576851864345, 0.1242548762820661, 0.12832963810069486, 0.15458642214071006, 0.1633791354834102, 0.08719269666471519, 0.10798129951581359, 0.08289775447337888, 0.127883295645006, 0.13384300866164267, 0.2560525556327775, 0.19398742821067572, 0.0960635878436733, 0.15919625759124756, 0.17905284912558272, 0.1293254370102659, 0.07657225170987658, 0.13449838443193585, 0.10109035443747416, 0.09338942196336575, 0.13746097858529538, 0.22951227118028328, 0.13492167578078806, 0.16675776278134435, 0.10722813836764544, 0.13245262467535213, 0.13850718416506425, 0.09295862750150263, 0.17698014940833673, 0.09757841515238397, 0.08989588051917963, 0.11928581167012453, 0.3307805926306173, 0.15872923890128732, 0.06627088572713546, 0.1464276810293086, 0.1850024244049564, 0.1690258551388979, 0.09805540830711834, 0.10870924248592928, 0.1609598082723096, 0.11973971661063842, 0.1847069160430692, 0.08729076405870728, 0.17711722408421338, 0.11626112944213673, 0.1314147756784223, 0.09004701147205196, 0.143447483133059, 0.15516926039708778, 0.1918585627572611, 0.10769994391012006, 0.16423000779468566, 0.16100458946311846, 0.1742579517303966, 0.14679642452392727, 0.0895275006769225, 0.22090794460382313, 0.1434383844025433, 0.12519961543148383, 0.1524563247221522, 0.09788547133211978, 0.2536257030442357, 0.2225341385928914, 0.09543334861518815, 0.10519202653085813, 0.11618862161412835, 0.2862657140940428, 0.0942763032799121, 0.17274327285122126, 0.07470512689906172, 0.10430908601847477, 0.09007745436974801, 0.20750735508045182, 0.08225244222558104, 0.1271759843803011, 0.09818607082706876, 0.20002282544737682, 0.14913990424247459, 0.16651853889925405, 0.145125612616539, 0.17801458452595398, 0.13650420180056244, 0.21745038247900084, 0.15240452281432226, 0.1485966521431692, 0.09722321585286409, 0.09259402519091964, 0.09453556514927186, 0.12671134056290612, 0.19304874498629943, 0.20366745331557468, 0.10639637635904364, 0.12282461670110933, 0.0871464163355995, 0.17831751436460763, 0.161160989664495, 0.1570652102236636, 0.17789643461583182, 0.1418861825368367, 0.1561319298343733, 0.17265841568587348, 0.27354663878213614, 0.19670321373268962, 0.10278247340465896, 0.16087000840343535, 0.09340916309156455, 0.1755626473459415, 0.1706373694469221, 0.19865292473696172, 0.1885269134072587, 0.1264355139574036, 0.09757052612258121, 0.12399237864883617, 0.11111198269645683, 0.11730903454008512, 0.13764805917162448, 0.10434645315399393], [0.06935309924301691, 0.018048779165837914, 0.03335302200866863, 0.01848952397267567, 0.05646449142659549, 0.04360272709163837, 0.01320183124335017, 0.15096431103302166, 0.07371355080977082, 0.02501179049431812, 0.056054336091619916, 0.07902972531155683, 0.02156301539798733, 0.046899473236408085, 0.04358271136879921, 0.01795988471712917, 0.022198208462214097, 0.03745530266314745, 0.014849368471914204, 0.029898443317506462, 0.01871081014542142, 0.054766687608207576, 0.029706839341088198, 0.025431567773921415, 0.04410147259477526, 0.053529853976215236, 0.04268654949555639, 0.01787651184713468, 0.014782195758016314, 0.06510376202641055, 0.028975979730603285, 0.015870041388552636, 0.03578672833100427, 0.019661723963508848, 0.015210331475827843, 0.046567837125621736, 0.028957568902114872, 0.021404900835477747, 0.07072147112921812, 0.019506192074913997, 0.04523252049693838, 0.044727021449944004, 0.04294703590858262, 0.04630427822121419, 0.0821211191941984, 0.01705062579276273, 0.07267795052030124, 0.09610473993234336, 0.038154194262460805, 0.015955957969708834, 0.035796650845441036, 0.026761134613479953, 0.0504856606858084, 0.030934991700632963, 0.0755412972648628, 0.027567522593017202, 0.07216722675366327, 0.032769990793894976, 0.022549318528035656, 0.03213674957805779, 0.033672097270027734, 0.03153804049361497, 0.03042813637875952, 0.02616540339658968, 0.011161276725033531, 0.07682179886614904, 0.05061269039288163, 0.012843153126596007, 0.0317836987960618, 0.029205073296907358, 0.014884515658195596, 0.030752228558412753, 0.028085280064260587, 0.036458869217312895, 0.04975627794920001, 0.038130519751575775, 0.01817105912778061, 0.026283265724487137, 0.07039910444291309, 0.03463078508502804, 0.025701028607727494, 0.037263386984704994, 0.03639285889221355, 0.000987688626992167, 0.07433518112520687, 0.030618628989032004, 0.016357849490304943, 0.06039238964149263, 0.03332535103254486, 0.04402427439345047, 0.022938142683415208, 0.06515731540275738, 0.03369502221175935, 0.017464460324845277, 0.051262622509966604, 0.0243689069247921, 0.04542223199678119, 0.030458132132480387, 0.023209126775327604, 0.03765161927731242, 0.025650120987847913, 0.06757709532394074, 0.038896019104868174, 0.04634212404198479, 0.03719511681993026, 0.02260113527881913, 0.035698969368240796, 0.06671875700703822, 0.04125467203266453, 0.009619085503800306, 0.018823495993274264, 0.035511213427525945, 0.05210216964769643, 0.05812703209812753, 0.009819847582548391, 0.09488315743510611, 0.0462493221857585, 0.06030681630363688, 0.007444327029588749, 0.0619898773584282, 0.06883954789373092, 0.03334249835461378, 0.011751836100302171, 0.016139088475028984, 0.017856010017567314, 0.04742410856124479, 0.032336917938664556, 0.04808765908819623, 0.07747105191810988, 0.07358476592344232, 0.06073325435863808, 0.03236909004044719, 0.03800773141847458, 0.010322564503439935, 0.058794697833945975, 0.005086172268420341, 0.0028822316198784392, 0.045467265517800115, 0.04939030266541522, 0.02375734013185138, 0.049157272005686536, 0.03079190748394467, 0.022721329805790447, 0.021857792744413018, 0.052993143908679485, 0.08794200606644154, 0.02171333740989212, 0.03865310674882494, 0.1947288931114599, 0.06286787145654671, 0.08349148745764978, 0.021048458438599482, 0.01502141407399904, 0.03236917909816839, 0.00890461529706954, 0.039142612513387576, 0.029935120255686343, 0.022668290366709698, 0.060692569823004305, 0.04964646606822498, 0.03258276548876893, 0.01798323639377486, 0.06998821438173763, 0.023725854516669642, 0.04025214926514309, 0.036794260595343076, 0.03446369053563103, 0.070811219047755, 0.07120581896742806, 0.04801570044946857, 0.08265862707048655, 0.009170437751890859, 0.027441750826255884, 0.03413706763240043, 0.03949032354285009, 0.025237423797079828, 0.05461422450025566, 0.02441045977320755, 0.020214004289300647, 0.019485577067825943, 0.022674125502817333, 0.058104671188630164, 0.04130298213567585, 0.03296540198789444, 0.013112459037074586, 0.016934886007220484, 0.024788752853055485, 0.016176210701814853, 0.02597619099105941, 0.030567606336262543, 0.04362324747489765, 0.04230396865750663, 0.023218767273647245, 0.05064382348791696, 0.021698381278838497, 0.02830287405231502, 0.024284726969199255, 0.020100784095120616, 0.0745982576336246, 0.03427589006605558, 0.013062622892903164, 0.04268420801963657, 0.0491265174059663, 0.04490786057431251, 0.08183251280570403, 0.04451024753507227, 0.03314897963718977, 0.029138727149984334, 0.02780564253043849, 0.012530801723187324, 0.02945939988421742, 0.08158616430591792, 0.01725799113046378, 0.025989657260652166, 0.04723861246020533, 0.027469818851386663, 0.024402086492045783, 0.05070955179689918, 0.04230348626151681, 0.061789961328031495, 0.011919535500055645, 0.011212441313546151, 0.006122148270151229, 0.044776619179174304, 0.018207539396826178, 0.05478640647197608, 0.011118272050225642, 0.05402735638199374, 0.05609506886685267, 0.03938946938433219, 0.033673533325782046, 0.05495697427249979, 0.11136689558043145, 0.016872918531589676, 0.023260654088517185, 0.03654700667539146, 0.050421405539964326, 0.007967267010826617, 0.008340556159964763, 0.018463424494257197, 0.025305508424935397, 0.06602821085834876, 0.0571816955198301, 0.04520668262557592, 0.012124772729293909, 0.014485294013866223, 0.01633179454074707, 0.10487769730389118, 0.091609781520674, 0.03820416306552943, 0.07497270082239993, 0.04083701358467806, 0.03522207640344277, 0.04652726391213946, 0.08771794426138513, 0.07616401853738353, 0.0476413760043215, 0.03138620078971144, 0.06747531719156541, 0.00836422696011141, 0.027661727108352352, 0.05425325500254985, 0.06800978968385607, 0.017044996602635365, 0.041174716752721, 0.08188905703718774, 0.08127866283757612, 0.08803432923741639, 0.03575133530830499, 0.06577821099199355, 0.0821793926297687, 0.010930911303148605, 0.029662963570444845, 0.030215119586500805, 0.005551069807552267, 0.05422365815320518, 0.036288260598666966, 0.025305128074251115, 0.020421195222297683, 0.056512975934310816, 0.0520710588170914, 0.045594922339660116, 0.04845127434236929, 0.00796106080088066, 0.01762467887601815, 0.036930429851054214, 0.020562887912092265, 0.12124459914048202, 0.06145190192910377, 0.02022993634454906, 0.044054542886442505, 0.03455767611740157, 0.03204282336810138, 0.011050854427594459, 0.07048998042591847, 0.06909884687047452, 0.02530159730667947, 0.018734022669377737, 0.03818565390247386, 0.04023448986117728, 0.015498340435442515, 0.03138852000120096, 0.008196221424441319, 0.028740050984197296, 0.05807201669085771, 0.05768918723333627, 0.0683331953769084, 0.08933192249969579, 0.06114000323577784, 0.019214910244045313, 0.03480805076833349, 0.0178980415512342, 0.004873490370300715, 0.04634968652680982, 0.05916444322792813, 0.07508492839406244, 0.0658420060062781, 0.03049956252652919, 0.010439896195748588, 0.02204995518695796, 0.06072595904697664, 0.005223868956818478, 0.04657000790757593, 0.07147518888814375, 0.03214177391782869, 0.06639691724558361, 0.04213193511532154, 0.011865815140481573, 0.12085802183719352, 0.0029845679864592967, 0.05454872254631482, 0.034063238781527616, 0.034201359885628335, 0.05936907931754831, 0.06517804358736612, 0.029942465662315954, 0.02095776428177487, 0.013349424934858689, 0.07786532529280521, 0.035086359857814386, 0.027811457257485017, 0.05365436038118787, 0.0243865013908362, 0.01882847209344618, 0.0461149823240703, 0.03845867147902027, 0.030679614974360447, 0.027894937738892622, 0.05088762642117217, 0.049926144420169294, 0.025142584745481145, 0.015452490551979281, 0.1389778542215936, 0.16923282528296113, 0.12393079523462802, 0.22762626613257453, 0.157893075956963, 0.13262906286399812, 0.1293859665747732, 0.21798538189614192, 0.1737507531652227, 0.08381446270504966, 0.16878502821782604, 0.12547008373076096, 0.09722418064484373, 0.1219805350410752, 0.1721874190843664, 0.13126664300216362, 0.12751096015563235, 0.07996685744728893, 0.16169024485861883, 0.10818006150657311, 0.08089873517747037, 0.17035336437402293, 0.15148992970352992, 0.07791020296281204, 0.10321086330804974, 0.07321123557630926, 0.18134811893105507, 0.15524528600508347, 0.18783269362756982, 0.1333140948554501, 0.08666284775245003, 0.1496908301487565, 0.21523140545468777, 0.13507022405974567, 0.1137310812191572, 0.19939211866585538, 0.10494188565644436, 0.056565200866316445, 0.10113625627127476, 0.07069159968523309, 0.12069011834682897, 0.0925805997394491, 0.09916013965266757, 0.09673581778770313, 0.13672660861629993, 0.11501941247843206, 0.1833901382633485, 0.10860822134418413, 0.12440725404303521, 0.11237206781515852, 0.09470188786508515, 0.15033492527436465, 0.14150108210742474, 0.1263735446264036, 0.18372009712038562, 0.113909686479019, 0.14771342219319195, 0.1559978534351103, 0.09702525538159534, 0.12904681992949918, 0.1169678321457468, 0.09806472968193702, 0.13076112169073895, 0.06475669666542672, 0.09939526687958278, 0.17573524120962247, 0.16361184330889955, 0.11135430875583552, 0.06887205396196805, 0.07620001269970089, 0.0943420130352024, 0.23176238872110844, 0.1932782170479186, 0.12259493683814071, 0.11909901309991255, 0.12110371724702418, 0.0974581872287672, 0.10777778035844676, 0.11179801658727229, 0.11987408244749531, 0.09824553912039846, 0.09338710646261461, 0.15589993447065353, 0.08017241751076654, 0.19572947145206854, 0.17173414496937767, 0.1427532485104166, 0.08647129943710752, 0.10387607995653525, 0.1651361255790107, 0.16726883535739034, 0.1907046715496108, 0.10721846076194197, 0.18438446772051975, 0.14541640091920272, 0.12437166806194, 0.11310300906188786, 0.12357667204923928, 0.1353841822128743, 0.1425691958866082, 0.11107055601314642, 0.1603824767516926, 0.12359803105937317, 0.10509677187656052, 0.17477531771874055, 0.09345723941805772, 0.22019793192157522, 0.16046895179897547, 0.07199605781352147, 0.07529074820922688, 0.131399086676538, 0.22173385106725618, 0.15138156129978597, 0.1257504225941375, 0.12965312489541247, 0.22405153373256326, 0.10282343253493309, 0.10551952145760879, 0.24478332517901435, 0.20491161936661229, 0.16194494994124398, 0.15160003473283723, 0.14349478762596846, 0.12805213424144313, 0.06707533670123667, 0.2158745061024092, 0.129239407251589, 0.14185563573846593, 0.17394249443896115, 0.2041860661120154, 0.11918934731511399, 0.1591746462509036, 0.15515235427301377, 0.11943332094233483, 0.14739220583578572, 0.10536458328715526, 0.0887219661672134, 0.13461855298373848, 0.13562416308559477, 0.11102333315648139, 0.22153593512484804, 0.12306426360737532, 0.12012662788038142, 0.16260918695479631, 0.13119909272063524, 0.1780286556459032, 0.14458326593739912, 0.26242567459121346, 0.36682813020888716, 0.14797554875258356, 0.14820889482507482, 0.07266422820976004, 0.2527432597707957, 0.10980544655467384, 0.16168506466783583, 0.12122619387810118, 0.11113787622889504, 0.12746589694870636, 0.186174928676337, 0.07029796455753967, 0.14096680999500677, 0.0850267089845147, 0.22821765393018723, 0.12189987101010047, 0.19989407766843215, 0.14630164951086044, 0.07249665126437321, 0.24450565804727376, 0.15726438781712204, 0.13599827972939238, 0.15087422914803028, 0.13513798214262351, 0.14357774489326403, 0.2477328575332649, 0.1317371497862041, 0.046492152905557305], [0.03164781526720617, 0.029221022050478496, 0.060063781493227, 0.022083617150201462, 0.04088787296495866, 0.015752474064356647, 0.027296148873574566, 0.026738679080153815, 0.020074166968697682, 0.05790145631181076, 0.011602371268963907, 0.028780212305719033, 0.027110634218843188, 0.03260207988205366, 0.023892346071079373, 0.04735202746815048, 0.0803821929730475, 0.06531162274768576, 0.0587634645489743, 0.05739937856560573, 0.0195097989126225, 0.046419845457421616, 0.030898630175215658, 0.01779515947418986, 0.023883182402641978, 0.03117181287962012, 0.042644232235033996, 0.02646665041538654, 0.054074505023891106, 0.018613570246088784, 0.05212142466916703, 0.010833466385520296, 0.05925460674916394, 0.04196580906864256, 0.07536229866673239, 0.08617722342023626, 0.02065868062345544, 0.03915252389560919, 0.062238582177087665, 0.04761694079206791, 0.01452733204132528, 0.03530582776875235, 0.06232077503227629, 0.06906968788825907, 0.05218250342295505, 0.07760028951452114, 0.021002020403102506, 0.014181030164763797, 0.03730100273969583, 0.02926497945736628, 0.026740699577203486, 0.013615227908303495, 0.038368708337657154, 0.014589944257750176, 0.026688337347877678, 0.0387872573628556, 0.05693602608516812, 0.032750605896580964, 0.05426668416475877, 0.032763767885626294, 0.04028305229439866, 0.03960399830248207, 0.012657853694690857, 0.05734679369197693, 0.008224196681112517, 0.06431975722080097, 0.04709033135441132, 0.02287511950271437, 0.017251718127226923, 0.03127781383227557, 0.04064842272782698, 0.04370924012619071, 0.10169232526095584, 0.027026777097489685, 0.011714293632394401, 0.0029670757976418827, 0.05512465882929973, 0.030313079369079787, 0.05325313308276236, 0.07094465720001608, 0.04771947591507342, 0.052107605879427865, 0.02743461878708331, 0.03310806132503785, 0.017963075952138752, 0.031536689784843475, 0.039497429606853984, 0.012653411940846127, 0.03095339325227542, 0.05475520658364985, 0.08397255500312895, 0.014071357436478138, 0.027538977738004178, 0.006926547757757362, 0.05496822894201614, 0.012977972601220245, 0.08465964274364524, 0.009037117415573448, 0.040820560170686804, 0.014406385162146762, 0.08504262805217877, 0.01602672546141548, 0.04150788168772124, 0.026673381216824055, 0.01445342248189263, 0.00866321135617909, 0.03005097692948766, 0.04019569038064219, 0.0446224046027055, 0.03760184714337811, 0.04194335539068561, 0.08855726133333519, 0.03581098542781547, 0.034773837760440074, 0.03927961668523494, 0.039687757089268416, 0.06436958501581103, 0.02335267297894461, 0.028759998058376368, 0.0363583675789414, 0.04368865294964053, 0.020012648492411245, 0.02859854754206026, 0.018789527894114144, 0.017942631639016327, 0.09834356198552996, 0.006722035050188424, 0.06724725521053188, 0.032156965680769645, 0.01595216745045036, 0.020050405255460646, 0.040907387738116086, 0.032255600817734376, 0.009701172602945007, 0.08666022797115147, 0.001963868166967586, 0.011563112584553892, 0.07856786454794928, 0.061581377012771554, 0.04685672181949485, 0.04369341011624783, 0.03552900641807355, 0.029095801328367088, 0.03635659013525583, 0.10818098919116892, 0.014394726949831238, 0.00713294830347877, 0.03498909398331307, 0.018114446247636806, 0.017430854022677522, 0.06196792091941461, 0.06024516238539945, 0.018648569930519443, 0.10021589667303488, 0.011603570765146287, 0.02898404316511005, 0.02862201610696502, 0.019306233371025883, 0.07511284056818113, 0.02700333821849199, 0.016336920925823506, 0.03756331483600661, 0.043584266168181784, 0.10848250894923694, 0.05937641173659358, 0.03129842327325605, 0.07689417310757563, 0.04780592498718761, 0.06770701569621451, 0.11634496986516751, 0.05040946438384708, 0.09525328874588013, 0.05478877392306458, 0.04327715061663184, 0.05822414212161675, 0.03908704791683704, 0.023621762738912366, 0.024578277916589286, 0.02258486554637784, 0.05866143408638891, 0.020447560018510558, 0.05379374313633889, 0.09340427233837545, 0.030330117224366404, 0.03636165529314894, 0.02196810928580817, 0.06286105854087509, 0.019284972695459146, 0.018451989853929263, 0.012487336916819913, 0.037872129905736074, 0.04970594178303145, 0.03259114804677665, 0.03303481134935282, 0.05796165562060196, 0.017060134559869766, 0.06236921501113102, 0.03976523359597195, 0.05625346544547938, 0.019224461684643757, 0.05724094116885681, 0.03407034484553151, 0.03221851940907072, 0.05606785060081165, 0.037281807090039365, 0.011997695710306289, 0.06801660259952769, 0.036569130097632296, 0.04878381958405953, 0.09103032003622502, 0.08815765191684477, 0.06446472092648037, 0.04689642300945707, 0.015886344517639372, 0.025005292991409078, 0.0633539336558897, 0.06375838929670863, 0.007151792824515724, 0.043381247960496694, 0.045969239363330416, 0.006452572361013154, 0.03477707723504864, 0.025022917143360246, 0.01171756279291003, 0.04820887035748456, 0.041025426326086745, 0.025516821988276206, 0.05051750624261331, 0.03110911067778943, 0.040110202389769256, 0.07768397408653982, 0.0283633869184996, 0.06486484984634444, 0.0668969689286314, 0.037338254842325114, 0.05563652179262135, 0.06845933079603128, 0.04782655669259839, 0.09560443591908552, 0.048022353803389706, 0.024457899708068, 0.012601770522451261, 0.051286894449731335, 0.07391919993096963, 0.025221250543836504, 0.0805221768678166, 0.02821891674102517, 0.0012025802698190091, 0.0183761794687598, 0.05525507644051686, 0.0083983787408215, 0.030543531065632124, 0.052665122057078406, 0.017760317496140487, 0.01880868643638678, 0.06605188536923379, 0.04132205904170405, 0.054128462870721705, 0.04032205957628321, 0.004722535213659285, 0.03995878199930303, 0.019446412079560105, 0.03872508394124452, 0.006722958096361253, 0.05911778069275897, 0.06196758695296012, 0.019992627203464508, 0.03965499869082123, 0.031200597077258863, 0.024438204964098986, 0.019705994927790016, 0.04701634665252641, 0.009519265713606728, 0.044157950032968074, 0.03686609306896571, 0.013748048222623765, 0.03132617217488587, 0.05295537230267655, 0.11469194723758847, 0.03474016280961223, 0.04364902968518436, 0.03462071414105594, 0.033060003552236594, 0.06683102168608457, 0.021192937892919872, 0.06654254146269523, 0.0749154515506234, 0.025184759142575786, 0.040490887040505186, 0.047581421604263596, 0.03964261595683638, 0.04897328617516905, 0.013531743716157507, 0.008444941086054314, 0.021665832537109964, 0.04873327190580312, 0.0028672615735558793, 0.009151015747193014, 0.04022790330054704, 0.03598732713726349, 0.04014781072328333, 0.01210336640724563, 0.03861575445625931, 0.026000240286521148, 0.021131777502887417, 0.03922447140212171, 0.006129432913439814, 0.0794461666373536, 0.03187893489666749, 0.03881662414642051, 0.01350290292975842, 0.010920769855147228, 0.07508642753236927, 0.029109651659382507, 0.10165115090785548, 0.042584441107464954, 0.04461638949578628, 0.02361027800361626, 0.05589700820564758, 0.04344886132457759, 0.07486459959181957, 0.06280303001403809, 0.0502729945583269, 0.04664830819820054, 0.04322226879594382, 0.07094276472344063, 0.031038369161251467, 0.051356793628656305, 0.009412658982910216, 0.033368299118592404, 0.0687002541963011, 0.045719558620476164, 0.018143135821446776, 0.08420170794124715, 0.03683478927996475, 0.056608579398016445, 0.011904785314982291, 0.008094033255474642, 0.028097486538172234, 0.032188777840929106, 0.02785871722153388, 0.014390431770152645, 0.03692577658512164, 0.03469144823611714, 0.0426404250174528, 0.02793395429762313, 0.04822870054340456, 0.0449831329024164, 0.04184591511148028, 0.0445473771833349, 0.06026806506270077, 0.032319633319275454, 0.08649346738820896, 0.06199740644660778, 0.11831693787826225, 0.16878686874406412, 0.12363208079477772, 0.18302816315554082, 0.182622178690508, 0.10595842759357765, 0.16656023275572807, 0.2280056371819228, 0.20211520692100748, 0.07848725246731192, 0.1670199487125501, 0.14715823635924608, 0.10733183866250329, 0.10283954456099309, 0.13734643551288173, 0.11723626696038991, 0.20813334180274978, 0.22462555527454242, 0.17407119768904522, 0.14153956988593563, 0.13787865929771215, 0.10572297382168472, 0.13635102252010256, 0.10747079097200185, 0.12086798888049088, 0.16354968101950362, 0.11413595988415182, 0.11547874251846224, 0.09441447633435018, 0.10631240234943107, 0.12901772774057463, 0.1734740359825082, 0.20539812685456127, 0.1680536416824907, 0.13203006063122302, 0.08331202872795984, 0.21040796505985782, 0.14883931959047914, 0.12151975039159879, 0.1534506244934164, 0.20392555743455887, 0.11440391230280511, 0.12994526390684769, 0.1294835441512987, 0.09397185203852132, 0.1567899773363024, 0.14024274103576317, 0.04470239699003287, 0.16205793450353667, 0.1449412779766135, 0.11633231624728069, 0.1258364671957679, 0.23045027162879705, 0.13325879001058638, 0.1697840035194531, 0.08705293541424908, 0.14722811698447913, 0.17153388384031132, 0.12850408733356744, 0.150495748675894, 0.14160651160636917, 0.21489959122845903, 0.12809626234229654, 0.10645613408996724, 0.21070285001769662, 0.13017475081142038, 0.18790634436300024, 0.13407513761194423, 0.15045439620735124, 0.22594617737922817, 0.22265111590968445, 0.10096540645463392, 0.07959783935802989, 0.13402427081018686, 0.14977148675825447, 0.08953780168667436, 0.14763898478122428, 0.15034855110570788, 0.0962607839028351, 0.1392931630834937, 0.1472887207637541, 0.056341628878726624, 0.12364754715235904, 0.11520903863129206, 0.16494555689860135, 0.07264491752721369, 0.19274041231255978, 0.2029026107629761, 0.13772579171927646, 0.08886090363375843, 0.12568014120915905, 0.07617086856043898, 0.0883563025854528, 0.11875629672431387, 0.15837784681934863, 0.14055603125598282, 0.06697797434753738, 0.1270920326351188, 0.1421867375029251, 0.14198407181538641, 0.18516727024689317, 0.12372945056995377, 0.13549256545957178, 0.14448332833126187, 0.09643363751820289, 0.06688096080324613, 0.12677951424848288, 0.19352386792888865, 0.18027288053417578, 0.13884049752959982, 0.15077335643582046, 0.08044517162488773, 0.10353193123592064, 0.2607069496298209, 0.166104108793661, 0.08172716494300403, 0.11477061489131302, 0.15041892154840752, 0.1492073803092353, 0.08318928492371924, 0.09524473178316839, 0.09434102597879246, 0.1481441647047177, 0.23592061246745288, 0.155295321601443, 0.14529158652294427, 0.10542561751208268, 0.11158584398799576, 0.08414065145188943, 0.11582846476812847, 0.1274547795765102, 0.10542530581005849, 0.17023233493091539, 0.1337758294539526, 0.22518575802678242, 0.2911095041781664, 0.15262976463418454, 0.15090973349288106, 0.09566364446072839, 0.10207010069279931, 0.1592162362067029, 0.10478647993295453, 0.2114810363855213, 0.13850616000127047, 0.09383263255585916, 0.11914046946913004, 0.11726941869710572, 0.2515235252212733, 0.1936647275579162, 0.1804064225871116, 0.11158651934238151, 0.10569313948508352, 0.10937072613160126, 0.213586286699865, 0.10658091880031861, 0.2522869873791933, 0.1400170093984343, 0.14949704054743052, 0.14658748026704416, 0.17452604515710846, 0.11656688686343841, 0.16800978075480089, 0.15514451719354838, 0.14562234689947218, 0.17934000090463087, 0.09764937931322493, 0.18732037424342707, 0.2545937604736537, 0.10754027825896628, 0.2203508440288715, 0.13063710881397128, 0.12318073626374826, 0.12755764124449342, 0.1351888192584738], [0.018843582220142707, 0.022403865004889667, 0.012779685584973777, 0.08325115777552128, 0.02239667173853377, 0.013938473111920757, 0.03701599947817158, 0.017330890441371594, 0.03203488980943803, 0.06087484129238874, 0.02006266739044804, 0.04790084196429234, 0.011579368401726242, 0.03120768458757084, 0.054494686773978174, 0.05982932219922077, 0.06124811930931173, 0.04163712670560926, 0.018694453210628126, 0.052204623134457506, 0.034103355574188754, 0.021255654937704094, 0.016819968150230125, 0.03654816442576703, 0.0402393101103371, 0.07628839506651275, 0.012165383977844613, 0.04415433206304442, 0.00299139273010951, 0.02663933890289627, 0.036016961093991995, 0.05550608933845069, 0.060459887972683646, 0.023912727301649284, 0.004857356543652713, 0.040100112892105244, 0.045432896658894606, 0.039642782940063626, 0.03695786705065984, 0.02496152483217884, 0.038325652640196495, 0.04565326998999808, 0.07864283630624413, 0.05700809975678567, 0.0542265525291441, 0.033235732989851385, 0.04683974519139156, 0.03771987459913362, 0.008699874379090033, 0.02228734225354856, 0.02552615635067923, 0.04967109052813612, 0.04540275804174598, 0.03457890525169205, 0.034190216538263485, 0.04079503771208692, 0.044046739203622565, 0.0778469794022385, 0.02732952325459337, 0.01242885846295394, 0.017731577827362344, 0.09162296948488802, 0.025586578303773422, 0.03528603840095457, 0.041033975867321715, 0.030737647211935837, 0.022496728088299278, 0.043800665298476815, 0.027547705394681543, 0.07082876341883093, 0.050068169221049175, 0.030076230359554756, 0.07535758602898568, 0.08696326913195662, 0.046212029265007004, 0.01117871255701175, 0.04031343953101896, 0.02195648725319188, 0.0874897041649092, 0.0034769671992762596, 0.02399864388280548, 0.05985498195514083, 0.029651295153598767, 0.07310234766919166, 0.0033975251608353574, 0.04129214306885842, 0.041343132324982435, 0.013288346181070665, 0.03396352753043175, 0.06642986860242672, 0.03413118240132462, 0.031201491365209222, 0.03254168761486653, 0.06054192126612179, 0.024382569863519166, 0.048985869289026596, 0.029698397411266342, 0.061163443970144726, 0.0742435926804319, 0.008132390230457531, 0.06888957606861368, 0.014840718740742886, 0.021138787087693345, 0.03923566298908554, 0.03187084919773042, 0.061655421086470596, 0.037688118100049905, 0.10968593851430342, 0.028683408418146428, 0.052918517249054275, 0.02210101309174206, 0.052368300093803555, 0.01360982229016372, 0.03443889167101588, 0.024603052661404945, 0.03484034903522115, 0.00864635347170406, 0.045519457053160295, 0.0702831512899138, 0.021709257453039754, 0.04803004616405815, 0.06585363546037115, 0.034431206731824204, 0.04114532028324902, 0.011837527254101587, 0.02767121361102909, 0.05102975512272678, 0.04182260425295681, 0.042672530325944535, 0.03980969937401824, 0.012274023265490541, 0.04349736438598484, 0.02229165969765745, 0.10270944607327692, 0.011361302222212544, 0.004792183453901089, 0.008616232480562758, 0.0071164025848702295, 0.07515689445426688, 0.02148149233107688, 0.02882085602323059, 0.02290255855768919, 0.030815186801191885, 0.005228462387094623, 0.09714330881251954, 0.02485833661921788, 0.05365516190067865, 0.06809155209339224, 0.07041750970529392, 0.02454549539834261, 0.05494117765920237, 0.030607580265495926, 0.04552591002720874, 0.028728599645546637, 0.010141512939298991, 0.12469180830521509, 0.021592653065454215, 0.031942069399519823, 0.007699860070715658, 0.050396721708239056, 0.028998609668633435, 0.054657803411828354, 0.027436711643531453, 0.015877524092502426, 0.019327187910676003, 0.024270874782814644, 0.029973294476803858, 0.0679517537355423, 0.012904251361760544, 0.02862292338249972, 0.04313412762712687, 0.007240650165840634, 0.059208170569036156, 0.023483166660298593, 0.12580264010466635, 0.029142300591047388, 0.025641801512392703, 0.021285309303493705, 0.04790764745848719, 0.027226338752370793, 0.10373585115303285, 0.03595374866563361, 0.016908665929804556, 0.020268147673050407, 0.019833134101645555, 0.02745993344433373, 0.053838446401641704, 0.07977046290761791, 0.00414996781728405, 0.008807425492705079, 0.018592665801406838, 0.030629933753516525, 0.04352863848907873, 0.052444533503148705, 0.07241455488838255, 0.02259504410176305, 0.04798543195647653, 0.03587918137782253, 0.011182000271219295, 0.04214282613247633, 0.017127195023931563, 0.05001444515073672, 0.05271846392133739, 0.029309512028703466, 0.032310660753864795, 0.0236704235067009, 0.037248365915729664, 0.08068337876466103, 0.03632263316831086, 0.020365231721370947, 0.031971929711289704, 0.0483194763364736, 0.007619441412316519, 0.035698234642040916, 0.051342058286536485, 0.02151827502530068, 0.047012327922857367, 0.028009067063976545, 0.04282003588741645, 0.04169558196736034, 0.01669982371822698, 0.03958869150665123, 0.06460042262915522, 0.03512440976919606, 0.024350492385565303, 0.06622795990551822, 0.08560309797758237, 0.0679270105320029, 0.053384133279905654, 0.018359071109443903, 0.021410851004475262, 0.02404951253993204, 0.0017028479874170444, 0.04678439210692886, 0.03795401848037727, 0.020051898827659898, 0.07412691964418627, 0.02267422569275368, 0.02965028768812772, 0.041991799080278724, 0.04057565143739339, 0.01690675489953719, 0.04346719979366753, 0.011925059861823684, 0.025059796316782013, 0.03599306393880397, 0.029773651185678318, 0.10643822606652975, 0.02656245054822648, 0.07131167149054818, 0.04588561787386425, 0.03802407351031434, 0.021834366852999665, 0.029718175646848977, 0.0664865761063993, 0.04326577349274885, 0.06785312973079272, 0.01995724902371876, 0.07392225757939741, 0.054875534697202966, 0.09779322979738936, 0.011971117546636378, 0.052356744854478166, 0.035954876730102114, 0.06734736351063475, 0.023033434445096646, 0.05811054528749082, 0.010443353676237166, 0.061259908325155266, 0.06775357061997056, 0.031049063509271946, 0.0633702683262527, 0.031507404637522995, 0.03499274534988217, 0.042110550130018964, 0.004974889543518657, 0.018273371606483124, 0.022072715000831522, 0.06744954982423224, 0.04396621246996801, 0.06508131948066875, 0.01925060754729202, 0.0502463922748575, 0.02217430945165688, 0.017719723873597104, 0.02362626386457123, 0.02633689331560163, 0.029638023697771132, 0.04350149443780538, 0.043794776356662624, 0.005709714541808353, 0.046392141084652394, 0.0415180045820307, 0.030584354753955267, 0.04078160483913962, 0.03326176753034815, 0.04299084117519669, 0.019242601629230194, 0.02719509804592235, 0.026186684481217526, 0.011406433150114026, 0.015583802451146767, 0.02587236638646573, 0.037014982735854574, 0.015050264137244085, 0.0361165536014596, 0.06987434666370973, 0.015726216879556887, 0.04841660491365474, 0.01788263085472863, 0.008291732119687367, 0.028809686700697057, 0.033353693652316, 0.06361902880598791, 0.06204030258231796, 0.01737279766530264, 0.06403775594662875, 0.07095752604072914, 0.048511703716940247, 0.06826899960287847, 0.01346774646663107, 0.06472217937698588, 0.028884359744552057, 0.09415396023541689, 0.050567994549055584, 0.05702452719560824, 0.050308725258219056, 0.05496243276866153, 0.045756109393551014, 0.01540184639452491, 0.08522676973370835, 0.02248262728244299, 0.018011046522588003, 0.03821289814368356, 0.08066648006206378, 0.016337078632204793, 0.07392873652861454, 0.05831189366290346, 0.009959921462723287, 0.027595913452387322, 0.017611728399060667, 0.030214280959626194, 0.04283599948394112, 0.0031637034180675982, 0.04386621178127825, 0.02189048991567688, 0.040878581276047044, 0.061234178065205924, 0.009917507723002927, 0.07454617370967753, 0.04284676433599088, 0.022844381601316854, 0.21708920889068395, 0.15462206007214263, 0.08873449361999519, 0.10253394299070351, 0.1599221077049151, 0.11928009713301435, 0.1392784685594961, 0.10845406985026784, 0.10951339660095982, 0.15284690220141783, 0.12596767890499905, 0.3036222030641511, 0.1723839991609566, 0.13255481841042638, 0.1377091824542731, 0.12249013816472143, 0.1654825749574229, 0.14475778938503936, 0.11501082582981326, 0.15390250337077305, 0.11672459324472584, 0.18324142671190202, 0.05878059702808969, 0.13402029289864004, 0.1173272987944074, 0.11771625097026117, 0.11566788627533242, 0.12865642056567594, 0.11712726773112081, 0.1591905133682303, 0.12624101189430803, 0.25159871962387115, 0.1451727983658202, 0.08572810533223674, 0.09684655364253558, 0.07658187736524269, 0.2120216761250049, 0.1114391659211833, 0.08539743401343003, 0.11683558142976835, 0.17784947151085362, 0.131825435673818, 0.14114779012743384, 0.13786323746899143, 0.13872635521693155, 0.1632302309735678, 0.21409865061286837, 0.18956180865643546, 0.09221126994816586, 0.09874001727439463, 0.14892441424308345, 0.23835660831537098, 0.1362097918172367, 0.2626804984174669, 0.14917671476723626, 0.12512065091868863, 0.07056414324324578, 0.25710578192956746, 0.23808572441339493, 0.07280262390850112, 0.1271727486164309, 0.26917381561361253, 0.18566581537015736, 0.11744799427106045, 0.19912165036657825, 0.09494423618889414, 0.09989378973841667, 0.18594838067656383, 0.1057571497221943, 0.15162698953645304, 0.15757928107632324, 0.1944799767807126, 0.09867496803053655, 0.1753664086572826, 0.13675636873813346, 0.07164078429923393, 0.18861206743167713, 0.11072660025092773, 0.18926183256553486, 0.12239170711836778, 0.12227447747136466, 0.1774395685060881, 0.16688529343809932, 0.18084788171108812, 0.15804165392182767, 0.11401283758459613, 0.16243221441982314, 0.13937782729044557, 0.1820587698603049, 0.22682360373437405, 0.19433058245340362, 0.11823406966868788, 0.2040383341955021, 0.20983759488444775, 0.16580527561018243, 0.1339608320267871, 0.16361056681489572, 0.18405320268357173, 0.2036680025048554, 0.18566422717412934, 0.12750537920510396, 0.1223278082034085, 0.11873202107381076, 0.1588589811581187, 0.1419435505522415, 0.12881550734164193, 0.1465723552973941, 0.14437322330195457, 0.16706541267922148, 0.21304515714291483, 0.16572353546507657, 0.1507863588631153, 0.09452550162677653, 0.10595335872494616, 0.1166055304929614, 0.09833258562139235, 0.1162536782794632, 0.1118952601973433, 0.17204658914124593, 0.14676289429189637, 0.16528704873053357, 0.15074896946316585, 0.11252466822043061, 0.13152335188351572, 0.09035568553372286, 0.13434432941721752, 0.17170048115076497, 0.14109456329606473, 0.07553902629297227, 0.1556382086710073, 0.11379177405615337, 0.17284432367887348, 0.1433248506509699, 0.3085324598941952, 0.1066767300653737, 0.12421739782439545, 0.08599157517892309, 0.214425002632197, 0.16178984107682481, 0.07788534843712114, 0.2907187188975513, 0.12312789534917101, 0.13056237454293296, 0.15432294487254694, 0.16385957220336422, 0.13357507850741968, 0.11725571865099482, 0.16384170128731057, 0.10671509910025634, 0.13769383484032005, 0.16227921325480565, 0.23604089976288378, 0.09847320776316337, 0.17045915010385215, 0.14027575176442042, 0.2729061059653759, 0.13506385643268004, 0.21131733345100656, 0.10255716479150578, 0.18416814651573077, 0.15466583194211125, 0.10527192614972591, 0.14608648605644703, 0.14206201216438785, 0.1113029669795651, 0.06454021218814887, 0.11687783931847662, 0.12409155926434323, 0.05252752045635134, 0.05421795474831015, 0.1154084611334838, 0.12312163162278011, 0.20559564203722402, 0.15932055248413235, 0.16102476103696972, 0.12143421045038849]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.02314755449333461, 0.0016986331684165634, 0.011849110323964851, 0.049761061090976, 0.03603574114094954, 0.045315166062209755, 0.09095103639992885, 0.004601106402333244, 0.030563704494852573, 0.03442287983489223, 0.062044907608651556, 0.02667048498551594, 0.13211898476583883, 0.034766609242069535, 0.010734283914644038, 0.029717850957240444, 0.04758676506753545, 0.054419993321062066, 0.013807846771669574, 0.02618424467073055, 0.02213066560216248, 0.08443482394795865, 0.08452003734419122, 0.056481004212400876, 0.07730566430836916, 0.024173514284484554, 0.029912197169323917, 0.05642618547426537, 0.03519516241794918, 0.08560501271858811, 0.07935014014947228, 0.06295734478044324, 0.0688034572522156, 0.03775826589844655, 0.09666143232607283, 0.04820296286197845, 0.022131359510240145, 0.02669622266694205, 0.019558231470000464, 0.048911802950897254, 0.023382147373922635, 0.11207967647351325, 0.06900569991557859, 0.008817449124762788, 0.08693382071214728, 0.019639409438241273, 0.04618071805452928, 0.03611277978052385, 0.033121824453701265, 0.11304143306915648, 0.0738121302856598, 0.019305686037114356, 0.005766988861068967, 0.03062572948692832, 0.04078822479641531, 0.06837172026280314, 0.04445964419574011, 0.06502783289761283, 0.05608703140751459, 0.04145421327848453, 0.01592594551766524, 0.03386075120943133, 0.055506746139144525, 0.018958303407998756, 0.012296683817112353, 0.03294165697298013, 0.014293344938778318, 0.011301459144306136, 0.13899343932280317, 0.049986759331659414, 0.10470093257026747, 0.042323379529989325, 0.007853806546336273, 0.04671483431593515, 0.025559350760886446, 0.04949609581672121, 0.020214084070175886, 0.0511914468370378, 0.02338515863812063, 0.019561170374799985, 0.031004499396658503, 0.024072548803815152, 0.11885656829690561, 0.03782237632549368, 0.029036067717242986, 0.0245113918572315, 0.03029951847565826, 0.05907290673349053, 0.037314064538804814, 0.015070105455379235, 0.0281625394927687, 0.04905045840132516, 0.05310266264132224, 0.025058458595594857, 0.024961222407000605, 0.020183847118460108, 0.06711810667184182, 0.01639091959077632, 0.036529974386212416, 0.01343738149444107, 0.018116865649062674, 0.02806878026603954, 0.050611295155249536, 0.006974585121497512, 0.011359967284079175, 0.029808971848979127, 0.05879051212104969, 0.0446887117868755, 0.0914090676815249, 0.02802943159622373, 0.02275577102409443, 0.016306633879139554, 0.023645680303161498, 0.010127104142156895, 0.04444678648724221, 0.05962628543784376, 0.03210734939784743, 0.023075157987477724, 0.04298373140045442, 0.03618948445364367, 0.030458714718406554, 0.028679983406618703, 0.040173374000005424, 0.0060720542296621716, 0.07396120548946783, 0.038696203264407814, 0.01173690594441723, 0.054427244103862904, 0.017055919161066413, 0.007892806406744057, 0.01878052749816561, 0.04132623362238519, 0.02164130641176598, 0.03856675415590871, 0.01928864818182774, 0.044831300619989634, 0.04131483052333351, 0.06365727909724228, 0.056061252907966264, 0.015406654583784984, 0.04213449181406759, 0.0354155468812678, 0.04387311375467107, 0.06594259670237079, 0.03193328979250509, 0.03912913511157967, 0.10707791283493862, 0.01173201704659732, 0.0258039626351092, 0.04141732111747842, 0.03413915306737181, 0.0341878231120063, 0.011969251045229612, 0.10561099858023226, 0.03696007493999787, 0.005355146531655919, 0.017971953893720638, 0.11803889967268333, 0.014890184738760581, 0.01972424433915876, 0.05603652825811878, 0.02653801904671127, 0.030015403935976792, 0.004087849592906423, 0.058789131726371124, 0.018687488154682796, 0.03080457780015422, 0.01695770704827737, 0.008294086583191529, 0.03220844104362186, 0.05462203189381398, 0.043041912067565136, 0.026891038287431, 0.017035597302310634, 0.05726791081542615, 0.07482914719730616, 0.009950570401997538, 0.03628172598837409, 0.07321205193875358, 0.023006466653896496, 0.0221789089118829, 0.04856188032135833, 0.03893723427609075, 0.04650835027860012, 0.054105764284031466, 0.04464435362024233, 0.013648762778757373, 0.07131406862754375, 0.046734245188417844, 0.09317177973571233, 0.03775409873924218, 0.035279611402074806, 0.08227729675127193, 0.07101712792064063, 0.01855022052041022, 0.024499254031979945, 0.023748237690597307, 0.06151067260361742, 0.06015034930896945, 0.06106736924266443, 0.033276265385211445, 0.04614963319909293, 0.04846695221203845, 0.016940754539973568, 0.024483839624735992, 0.06486204452812672, 0.006194454790602322, 0.016095871360448655, 0.032302226245519705, 0.0636651755485218, 0.040260854657390155, 0.012967747661605245, 0.018778236117213964, 0.037187799243838526, 0.05542910635995213, 0.06418909470085055, 0.01798356850486016, 0.05818604025989771, 0.01804608888051007, 0.026480439519218635, 0.029852402331016492, 0.07067444123094901, 0.024442791436740663, 0.07588307111291215, 0.04115712785278447, 0.04783882439369336, 0.0811568318749778, 0.006370599367073737, 0.02768674119579373, 0.04154893358645495, 0.047326979984063655, 0.04406595711770933, 0.027672139440255705, 0.057645196429803036, 0.05690228434104938, 0.024150711797119584, 0.04061461419041734, 0.016999484396365006, 0.06743008329067379, 0.061952562173246406, 0.02209195889008697, 0.04280252491298597, 0.044311415040283464, 0.03835954281385057, 0.11722326453309506, 0.0068374673082871595, 0.03394019811821636, 0.018496745069569442, 0.017047150686266832, 0.052493626571958885, 0.10882629401749, 0.03452196397120133, 0.03404824368772097, 0.09557356257573701, 0.06411357375327498, 0.019930348025809508, 0.07647740523680113, 0.04267390329914633, 0.07051207416225225, 0.049390974309062585, 0.037239853481878527, 0.03890844636771362, 0.01251515075637144, 0.09619692209525965, 0.07468911135219969, 0.016516249779670034, 0.03280335775343701, 0.007907090894150315, 0.07252561728819273, 0.030482769579975866, 0.013420333434623899, 0.03414111975871492, 0.02952167906187242, 0.034066634107148275, 0.05964796357147861, 0.019917661011277232, 0.03146873503283132, 0.04045904519443866, 0.03585959981137421, 0.062012876514927484, 0.052215558680472896, 0.027200678996450733, 0.02770812247035792, 0.06281396927079186, 0.0598069835541537, 0.03124769005808048, 0.013174873656680575, 0.010530753625062061, 0.019124817226838786, 0.06081178471504245, 0.02806523465551436, 0.06640580075327307, 0.04421030113007873, 0.04274063350749202, 0.01909145026729675, 0.06518833717564121, 0.030101040356385056, 0.05206187845033128, 0.07042179189738818, 0.017574693374626804, 0.03572146386431996, 0.01464362008846365, 0.029780579134239815, 0.046520692194462754, 0.01395525307088974, 0.049305330467177555, 0.025590060831746086, 0.06692076960462146, 0.037327493701013736, 0.02993954716657754, 0.07259826612425968, 0.07993575403816067, 0.04283240748918615, 0.04367527573776897, 0.03747864691831637, 0.009780451600818196, 0.055465182158513926, 0.04262501061020885, 0.03062048250285443, 0.05486404996190686, 0.03146135437418707, 0.010567791432549711, 0.06099148093198892, 0.025422251965210307, 0.033852795386337675, 0.13308364315889776, 0.025986030013882555, 0.03178840772307012, 0.04224769530992489, 0.06703321982058696, 0.03505913045955822, 0.032906045016716234, 0.05410145240603015, 0.09371320615173317, 0.04390061032609083, 0.01763595952070318, 0.0337929003580939, 0.042212870030198246, 0.01608561673492659, 0.04861824643739965, 0.0745175416523125, 0.017575322344782762, 0.051378449497860856, 0.0635187498119194, 0.06529378151753917, 0.0839345644635614, 0.0444426712783752, 0.039817718279664405, 0.1133036932151299, 0.05297462361340877, 0.06473921166616492, 0.049382183569832705, 0.04534183884970844, 0.0681241175334435, 0.127052461321, 0.12116710408008657, 0.13603507541120052, 0.10202096309512854, 0.15664006350561976, 0.20637645560782403, 0.09940964970155619, 0.1962255674879998, 0.1298824930563569, 0.1814217251376249, 0.16262726567219943, 0.2424053059075959, 0.19335872522788122, 0.08493139495840296, 0.19303048815345392, 0.08482408782583661, 0.11345741426339373, 0.11715524669853039, 0.07820110258762725, 0.21977231022901833, 0.18170635361457244, 0.1495320550748147, 0.1629902352578938, 0.15552817785646766, 0.13982615870190784, 0.19478948204778135, 0.13336424919543788, 0.21071932569611818, 0.11749250086722896, 0.10443607490742579, 0.17831463483162224, 0.17132770037278533, 0.1502435520524159, 0.14434877695748582, 0.06426945445127785, 0.15837775776162744, 0.14209355344064534, 0.12685930996667594, 0.1491021882975474, 0.11458678491180763, 0.14607329067075625, 0.06992446389631368, 0.15952087298501283, 0.14687592338304967, 0.12005711090750992, 0.19392746267840266, 0.18762931547826156, 0.17947668966371566, 0.23812572617316619, 0.06133348484581802, 0.07434250612277538, 0.15045766165712848, 0.10400643819593824, 0.10043313071946613, 0.20390215009683743, 0.1332097192062065, 0.16893173597054556, 0.08296686326502822, 0.15481150068808347, 0.14758560952031985, 0.18582371470984071, 0.17064231215044856, 0.14519622054649517, 0.11343666381435469, 0.12573589134262875, 0.10872128754272126, 0.19658973935293034, 0.11225170630495995, 0.25211724336259067, 0.10853114930796437, 0.05872568923223298, 0.14753824565559626, 0.17615887394640595, 0.16974075115285814, 0.08978918194770813, 0.2009220264153555, 0.16123826208058745, 0.15308434492908418, 0.1495271865860559, 0.2067951307981275, 0.21130385604919866, 0.14178759563947096, 0.16904138086829334, 0.16823046578792855, 0.11072939814766869, 0.1715248147957027, 0.12203526101075113, 0.09015135001391172, 0.1349139426019974, 0.13096518261590973, 0.13197347929235548, 0.11213941194000654, 0.19041933061089367, 0.09371060121338814, 0.08634358324343339, 0.1313611480873078, 0.07615842274390161, 0.051728813705267385, 0.11843793763546273, 0.13469543948303908, 0.16615537635516375, 0.07558225639513694, 0.10810969848535024, 0.2302351378602907, 0.09917953197145835, 0.14873908512527123, 0.13710482191527262, 0.12493208603700623, 0.22368053410900757, 0.09530718351015821, 0.16711483971448615, 0.1323496739496477, 0.09071309643331915, 0.16515335824806243, 0.13310737704159692, 0.10674902267055586, 0.16105210175737739, 0.14707750553498045, 0.12312601029407233, 0.09034133239765652, 0.1819974833051674, 0.16263857600279152, 0.10464731240062974, 0.09228138806065544, 0.13656884286319837, 0.15887103363638744, 0.11919675394892693, 0.16225104132900015, 0.09935769194271415, 0.15623053157469258, 0.19239535817177966, 0.1309006751398556, 0.15715330315288156, 0.18139929743483663, 0.12776266696164384, 0.17307381058344617, 0.13772271922789514, 0.2755850809626281, 0.13687316793948412, 0.11974025837844238, 0.09769550379132852, 0.1722631775191985, 0.08326285402290523, 0.13603663392132148, 0.2937379537615925, 0.13109125866321847, 0.24265704239951447, 0.20555593713652343, 0.131648774840869, 0.12769884226145223, 0.15286365989595652, 0.21132160822162405, 0.1383590218028985, 0.20618358626961708, 0.08275346612208523, 0.20930488128215075, 0.09146131487796083, 0.1022489731258247, 0.12966550391865894, 0.15334081632317975, 0.10483643389306962, 0.15065599320223555, 0.1542695250827819, 0.16215873300097883, 0.09299356781411916, 0.08931584758101963, 0.1934907236136496, 0.19393948547076434, 0.11161860980791971, 0.12158761237515137, 0.19210180907975882, 0.12731242080917582, 0.1517959320335649, 0.15002700820332393], [0.005897560931771295, 0.044017684122081846, 0.017113253779825754, 0.010696042900235625, 0.04609765688655898, 0.025907327108143363, 0.045653744964511134, 0.09889419103274122, 0.021070503935334273, 0.056552383975940756, 0.06813464118749835, 0.01332662894128589, 0.07657692724023946, 0.038277869462035596, 0.03400520654395223, 0.02438575182168279, 0.017176058026961982, 0.023483252007281408, 0.020418901985976845, 0.03427074698265642, 0.01702419791399734, 0.025069336625165306, 0.035439388375380076, 0.004354186912678415, 0.015738857509859372, 0.02312320462806383, 0.0373485706950305, 0.04108378881937824, 0.054349415077012964, 0.028340413737169, 0.026310422763344832, 0.05330330226570368, 0.03142535650113132, 0.07789397219312377, 0.033684973532217555, 0.0544298564636847, 0.03523584324284457, 0.013035467709414661, 0.046103434506221674, 0.060376207111403346, 0.019425689461058937, 0.04849343575187959, 0.018251808505738154, 0.03871115382935386, 0.08584075592807494, 0.06531651350087486, 0.026860998004849534, 0.07150964680477045, 0.05301905970554799, 0.016589284532528836, 0.01854560621723067, 0.06079372084059287, 0.04301143577322364, 0.032586617235210724, 0.011666492828226183, 0.031214156115311198, 0.017631591981626116, 0.03518831610563211, 0.03322199212561827, 0.053794655977981165, 0.026991593731509056, 0.005167100689504878, 0.06457573137595318, 0.03644169592007529, 0.014826503829681315, 0.031983922817744315, 0.02726585811615223, 0.07617279072292149, 0.0202542286933749, 0.03169385439832695, 0.022533239898621105, 0.016850268184498418, 0.024162873742170632, 0.010372704000474187, 0.009103517368203029, 0.03489397662633564, 0.021855712875549216, 0.03632494495832361, 0.009473592090216698, 0.011726143875421258, 0.0686406745808199, 0.042460973709239624, 0.07140662186429836, 0.05424537339422386, 0.03459304687567055, 0.013263584423839347, 0.01983072954317322, 0.0450526053464273, 0.08344298810698092, 0.030591043359891046, 0.0030487526282740873, 0.04313995719712693, 0.0384284549363656, 0.05116099651786499, 0.06006100957165472, 0.036311923977336846, 0.02185192977776751, 0.03953352766984608, 0.04006407420092728, 0.020974278922949452, 0.03734140896995086, 0.09802132888580672, 0.02222897604951868, 0.048357214545831084, 0.04416021729412023, 0.05439777341962326, 0.015179231777437963, 0.04583601272315718, 0.027738747194234747, 0.05127814081788529, 0.025037190498551354, 0.015358858418039745, 0.029561274495790713, 0.08660011400934309, 0.05968352357740514, 0.03500454549794085, 0.05332395994628314, 0.02184628388931742, 0.023024046276987065, 0.0212296482277452, 0.016830135573400185, 0.029750911780865863, 0.010766555278678425, 0.03841174177068751, 0.015574030221614521, 0.013808049934596056, 0.01141862478107214, 0.00980019458438619, 0.011558329442777904, 0.0312116550776409, 0.03103047642071033, 0.027109244547318667, 0.009204965244862251, 0.019891209012712352, 0.045467803574865684, 0.030059244454605505, 0.06074996752431616, 0.02199870617914712, 0.02650021961017046, 0.02006120907026343, 0.015276630310836481, 0.08087617388810031, 0.03587223116483074, 0.07355656431172974, 0.026030076478491537, 0.01621208055439638, 0.04399237317556981, 0.035391508718021214, 0.030380566568055656, 0.023020476546662394, 0.033430531912017614, 0.03209380149201024, 0.08139477926306427, 0.024819574246066622, 0.08605501396232285, 0.07365072800894268, 0.0234039553834009, 0.026424360985402018, 0.03584167323424481, 0.004977772787242429, 0.059214504799456336, 0.061241306393640116, 0.007375300801868434, 0.012450674821593566, 0.021249929268378764, 0.05088803831313271, 0.10346526411012746, 0.02084671301417984, 0.013811281060043257, 0.0670306668325793, 0.05085520569991786, 0.032762977498350665, 0.029802967874275055, 0.07042404802632518, 0.027865025476785377, 0.05950787948677316, 0.01701906781818252, 0.03963134273362812, 0.045873105264035985, 0.058276934796595015, 0.09881515230517834, 0.04670022884965874, 0.04506637589656748, 0.05112454964546487, 0.028999272035434842, 0.07164427981479093, 0.08567412893171422, 0.05308591607899871, 0.06009642114804592, 0.013264240296848584, 0.013185508632886922, 0.04066237139340956, 0.038111502217361704, 0.01412845735103474, 0.0017112583759626432, 0.06341246684314683, 0.011919853695872007, 0.04054184289998375, 0.049917286887648515, 0.026193220946879592, 0.05296482355333865, 0.030636084302386735, 0.02562958761700429, 0.023942784282553475, 0.016554683752474375, 0.0222482922981726, 0.041410597259528004, 0.051020830796915106, 0.010268293099215953, 0.03092889310210012, 0.03340973322337959, 0.03641922739916481, 0.04531515121925622, 0.006570018158527091, 0.00796409061877057, 0.016149838484125212, 0.028742702306772117, 0.11076600829255767, 0.05043494231358636, 0.07328752093599178, 0.04108033412194345, 0.03126483366941102, 0.022715544764650986, 0.05585041988524608, 0.059570090015768073, 0.03643116484454367, 0.057746755628613755, 0.012088248859072337, 0.02897817834309535, 0.05736827144573908, 0.04357689664175268, 0.02607470923976507, 0.049831446376629174, 0.02296030321303988, 0.0473258630518103, 0.080277750530513, 0.014001149338582763, 0.03556947202014271, 0.0421464403916616, 0.059559443907346576, 0.004659774103856762, 0.02729682979406789, 0.02396422678430099, 0.03501772975141648, 0.029690829360333737, 0.009770065244083526, 0.03493263138807379, 0.024192220116674434, 0.029032553647994064, 0.01363077682981384, 0.049797537649283186, 0.032196225292864256, 0.08162101556081325, 0.028478440217440948, 0.018399193468212616, 0.09315433926531114, 0.03601596661610529, 0.05539737954677548, 0.046691452953382395, 0.022992306476226076, 0.048703151842346415, 0.07310098211746663, 0.04123972146771848, 0.040922694533946924, 0.05150821030838415, 0.0048098173465405125, 0.046821736978017725, 0.015358421478595119, 0.055827632240834646, 0.060591767614823766, 0.011649780590232695, 0.0512169655848993, 0.021184779834584333, 0.025905286202032585, 0.021199988295848016, 0.029249054823594633, 0.026853411400225013, 0.0339639802405145, 0.03953759834985249, 0.016973273595795035, 0.03578091360395774, 0.052602002397179604, 0.044590024699573405, 0.026616022478265222, 0.08879651490133256, 0.0425071241625119, 0.02673477167263627, 0.03679681358335074, 0.018469673377694562, 0.022339095921779517, 0.07598861193400808, 0.013079677446512505, 0.03776628480409272, 0.03651073791843373, 0.06135325565992389, 0.07298715892829932, 0.06643182787229307, 0.012709576749330154, 0.07306145533220842, 0.05060401468654163, 0.025019338136189617, 0.03430103402934037, 0.05340373711078428, 0.011744558414648054, 0.009863172308541834, 0.001232980030181352, 0.027766056373366155, 0.020270006752980407, 0.032883335297810845, 0.043424949326436035, 0.06994467999902554, 0.005208320035308134, 0.03505661828967277, 0.026652200322132558, 0.028338986958260648, 0.018899855567724444, 0.03791679977439344, 0.07437924985424615, 0.014986367077653995, 0.03376193424628582, 0.012778705022356007, 0.02324066990695428, 0.05634844179439824, 0.07617574447067454, 0.02375552929152036, 0.014358034241013229, 0.02601992389827501, 0.032934116752585396, 0.01391578287439188, 0.019337956473464146, 0.04129133412789088, 0.05149391283339355, 0.056237119642901234, 0.058462416054680943, 0.0057467240549158305, 0.02455354027915746, 0.08595176637754776, 0.03131279496301431, 0.055220896829268895, 0.025168854917865247, 0.020927113582729362, 0.11695535664330237, 0.03122540336335078, 0.015808253883733414, 0.06431920061004348, 0.08184808306396008, 0.041382573763257824, 0.07959455164382234, 0.007125341289793141, 0.07303311271243729, 0.054825053812237456, 0.058985481737181544, 0.11397697700886056, 0.18324973876588047, 0.10641563509125262, 0.16706738679204136, 0.240252647199668, 0.10514129331568256, 0.12325961914029904, 0.17352047958411276, 0.12458706158213317, 0.25326611765194684, 0.261432146653533, 0.12117307094740681, 0.1879051569267176, 0.1592946218443103, 0.10778566938824952, 0.18066936550894752, 0.10392018579295836, 0.11820649146102369, 0.1117725831863936, 0.21833729348145425, 0.14018958841916174, 0.1639060306479223, 0.12573626241646707, 0.1153723630704917, 0.12477019394282252, 0.1438268690253608, 0.1229819149011746, 0.10951353760901839, 0.1350468464079313, 0.1564278537989594, 0.16827486106194556, 0.1772969277226366, 0.09263039042707533, 0.1486308651510626, 0.1456577770295553, 0.150054081750568, 0.15301064966479316, 0.1140471916005481, 0.09077165930648334, 0.1543661527102813, 0.20311134721850976, 0.19350377056980506, 0.16483212704770267, 0.08832321022055112, 0.14237605937523767, 0.1363754243357107, 0.12010615202598274, 0.22661091905320063, 0.16793629329185933, 0.08488576029776596, 0.15172667481238022, 0.1394034016993828, 0.1382511729025282, 0.17118507443228737, 0.08174410817446187, 0.09737047279486433, 0.2363069893908687, 0.12445810600183904, 0.18012998742051423, 0.25093814881984144, 0.11283350555459037, 0.10381785847130232, 0.15502903901506215, 0.10090826850500889, 0.0977161577611696, 0.08548932673875242, 0.11313627954223193, 0.16458919242722914, 0.1433789383736439, 0.09385742028825916, 0.14587136713089421, 0.08092186049907468, 0.10520758936763741, 0.18198975012637675, 0.12196885363664478, 0.13208839343860745, 0.23601572611369193, 0.11104042481747456, 0.13560747960582376, 0.18283729761606082, 0.15347006876254454, 0.15480589005164802, 0.1326433863141574, 0.14351101097417995, 0.09994050793466158, 0.19392551825148985, 0.13839776191161945, 0.14379722764715552, 0.18031877494649962, 0.15065541432704777, 0.10841299939784221, 0.14695493242470548, 0.1842194882920012, 0.11914332673768513, 0.17356266325805336, 0.24666219076607376, 0.08549764621420763, 0.12402147825923748, 0.21374804520746693, 0.20269359229132533, 0.0726989607210271, 0.0946652480342891, 0.12431493829353712, 0.12366092807496898, 0.22634986118646339, 0.14151043316815048, 0.10353693331126124, 0.17203465540660545, 0.1425610767910257, 0.12529219093266875, 0.16827769606607035, 0.13744097028393298, 0.09743378541315906, 0.18311831925529987, 0.14061359222978354, 0.08032441677642055, 0.19640427664853632, 0.13253672485006973, 0.16791183210443705, 0.11593144517973997, 0.06572111757122912, 0.1494942352292128, 0.12727679772069678, 0.22051463602110744, 0.20936005254043266, 0.10106248679221608, 0.19844239228405058, 0.1265421012067236, 0.10962197280605324, 0.11011808368493803, 0.18505480518797413, 0.133517992508132, 0.14292949374066666, 0.13503751019015908, 0.16553641034988686, 0.10480233220732771, 0.11614238581387326, 0.12769029272021726, 0.10913281585089862, 0.1295057640527375, 0.09679993192548864, 0.15288288152078167, 0.08574850697186776, 0.13845039502484724, 0.10010591038735583, 0.23946807836182415, 0.17483639647252858, 0.12830413790652528, 0.1369299867656082, 0.10676434802007861, 0.1277788309380412, 0.09501811699010432, 0.13889856316382065, 0.08319752276293002, 0.12411806135787629, 0.16787172644399107, 0.12958906270796433, 0.14607621473260224, 0.2014140406390652, 0.11960156582063064, 0.16171639814274386, 0.1550137804588303, 0.1289060790440999, 0.12841544521506876, 0.11839041049825028, 0.209845372592099, 0.12561741488752887, 0.1933311321772635, 0.1473714257008396, 0.17404332262231037, 0.1327113967272453, 0.18595698958961293, 0.08099858372588642, 0.13683702534763142, 0.17346894484944642, 0.15601291903294623], [0.017743355710990727, 0.024151218312908895, 0.0289267104017199, 0.043380906572565436, 0.03147945535602048, 0.0648773179273121, 0.08938533486798406, 0.030972379245213233, 0.03259708893892821, 0.064679305505706, 0.035716836573556066, 0.016378438522224315, 0.055188617116073146, 0.09308819906436838, 0.0495774982846342, 0.09321961115347221, 0.11483655471238308, 0.03415795537875965, 0.06382078907336108, 0.008956516467151232, 0.02528609569708351, 0.014631264257332077, 0.048091162025230005, 0.09289126275689341, 0.049445540716988035, 0.05111351390951313, 0.06587774041690864, 0.030864432010275777, 0.05718441178032663, 0.09334696369478479, 0.047865801461739466, 0.0680671725422144, 0.06578707965672947, 0.04650305134418886, 0.023878026331658475, 0.0863940195995383, 0.058948749137925915, 0.05791682247945573, 0.09445493822568096, 0.04819318877707701, 0.028196320199640468, 0.029007615630689543, 0.03675113810459152, 0.10691564966691658, 0.06633389406488277, 0.016992667769955005, 0.04747012171719689, 0.021800665927003138, 0.04404978943057358, 0.0749935997009743, 0.030973267967056017, 0.024123949951899704, 0.03803496823820751, 0.10300341818947345, 0.09499682477326132, 0.045633068730239756, 0.013354157981666503, 0.05893125671718735, 0.04743119607155677, 0.02016633985476801, 0.07355991881922819, 0.05518455756828189, 0.0483206044009421, 0.02514901731046848, 0.02676373769645579, 0.07678438720176928, 0.05191765318159014, 0.05937719099165406, 0.020938887755619362, 0.022051224259485025, 0.02138353811460547, 0.017189479767694138, 0.08963719010353088, 0.02863064542907523, 0.05754981189966202, 0.09244014087016694, 0.017076166805054527, 0.033330063670291565, 0.025885832656058483, 0.02462179745634785, 0.02906360139604658, 0.0381829227990238, 0.03843439211777877, 0.1012600761896465, 0.017809967175708152, 0.03073385298193898, 0.13882063765777275, 0.042585992196109146, 0.03317499562399462, 0.05474773315654602, 0.017870296360342763, 0.05685488707968034, 0.04217364752548747, 0.04429443470144179, 0.058552802220219746, 0.05384456169849727, 0.0822847182280384, 0.03580128926842008, 0.04552052203507628, 0.11276706849457696, 0.08480947493808344, 0.05895579211937729, 0.02861962824681541, 0.0401223216613289, 0.013880133810744155, 0.04285350674763322, 0.03903304554114584, 0.012234508540132083, 0.06895797239849344, 0.017341781458526384, 0.07659471652004868, 0.048677915110602044, 0.029749262357654516, 0.029105985449859872, 0.06133574468549341, 0.037157133701839484, 0.02472911943186773, 0.05537468096008524, 0.04016635699372273, 0.03395612089661881, 0.03700271132402122, 0.04023101289931219, 0.12281871662708, 0.013958750441815937, 0.036886557791149244, 0.05841160862473771, 0.054566849503316917, 0.05193491553654894, 0.05670447972079273, 0.024687186232768, 0.03927411737095099, 0.0826366817636881, 0.11031051515601575, 0.012625824456335977, 0.03578519208531361, 0.05136549531016499, 0.01040414601447992, 0.03856883959088009, 0.06315641847322695, 0.04225723932904657, 0.06472591237979941, 0.020422720335773192, 0.02396138992480701, 0.047451905702473596, 0.06985986736253835, 0.0547881059901556, 0.029483057696779724, 0.03848832770017907, 0.029890864134358708, 0.04323545676015783, 0.01911430841573747, 0.016430971445515752, 0.029249676372273825, 0.04100263868167531, 0.08372707481612451, 0.10876508167712018, 0.052987874660175294, 0.011276293844275642, 0.024503866479790304, 0.07347551436396316, 0.025658971098891925, 0.041331347019877285, 0.032947634972515516, 0.06849944387795404, 0.03987720512668602, 0.004014977648694185, 0.048977249243762344, 0.04704994738858659, 0.04516694803896826, 0.04525067713984754, 0.028429020603653044, 0.02744159683061298, 0.0648763457138557, 0.031495378134422936, 0.01943118877534289, 0.02595354621007573, 0.04064345033839345, 0.015740330672997516, 0.020767926616827026, 0.060166542971273884, 0.048949121846817434, 0.03619447168603074, 0.04873844467510935, 0.05057688176748343, 0.027930230571655557, 0.03988683078205213, 0.047385346188093536, 0.020685572344518732, 0.04763717544847168, 0.04889469644695055, 0.037402921880129725, 0.09442136346478947, 0.0207533916545799, 0.03061101455386961, 0.09608960754121654, 0.05591144668869674, 0.04095988355402369, 0.024660060735186562, 0.01933669853315223, 0.03228360947105102, 0.07142336471588351, 0.054459468155982904, 0.1230438842321746, 0.009893689421005547, 0.01489060312451329, 0.035604223085101694, 0.02117223382811062, 0.0798475275223609, 0.0419790341402404, 0.03368997931829654, 0.012164883955847472, 0.03798754871240817, 0.015651246976631228, 0.039866766819613986, 0.07184555768617429, 0.0724634327343665, 0.04436966992216185, 0.05549568071728572, 0.05987612945318688, 0.019395881099626422, 0.022884157006046735, 0.04442051074875053, 0.05170427088160068, 0.045454778883140534, 0.029938621337350924, 0.028465241121011786, 0.057822139278869145, 0.05170722091861535, 0.054891153195057996, 0.01632846600841731, 0.0353739606362069, 0.031077934909262694, 0.012156455941294553, 0.04482543394260574, 0.06512123960419558, 0.021723039135395084, 0.03790907772781793, 0.08351226759259589, 0.09947702928911895, 0.024714083519938868, 0.015261782718880568, 0.04172389119048603, 0.05777523554570507, 0.0685625041660387, 0.03466565489361528, 0.07277562457602471, 0.03045595578441862, 0.007708656839895411, 0.0610950179543579, 0.027407920024415944, 0.05740176457038615, 0.022392350583686493, 0.042274241932318546, 0.13524664740543813, 0.020770199444086757, 0.038856039609527215, 0.025635226083977614, 0.026415317915962078, 0.015415079815284116, 0.009265191456506727, 0.026357912793173455, 0.013479023400577717, 0.08023284317459911, 0.06151227935333736, 0.04820654372451827, 0.08611909841420129, 0.025075028897845186, 0.035422619548626244, 0.03494610878988169, 0.011457174714450957, 0.060943430580664426, 0.03968174940382596, 0.036104760874877684, 0.040215205153799616, 0.0577617061935598, 0.0227819818246644, 0.020862793498963583, 0.05333020511898212, 0.0343241111113457, 0.01848028423410142, 0.05923965618421789, 0.04259573659510352, 0.002578344874564209, 0.03218986137653701, 0.07515518009313382, 0.04862855486862827, 0.028678469425358344, 0.047643606158089824, 0.023460332631657366, 0.05595280286797788, 0.017044167252606712, 0.028300541853241157, 0.03916325164027512, 0.017598540434846655, 0.10710486763855442, 0.019308764094603248, 0.009759210406627972, 0.03010858428751817, 0.09068936997209676, 0.012398727267282084, 0.026383719123259652, 0.04461644515686203, 0.031775375609868206, 0.0871228457253892, 0.02934373802418122, 0.016885954355529975, 0.07376513749477454, 0.10232769272988662, 0.050207095555379055, 0.040284265705849975, 0.06917868711752817, 0.0272719734130078, 0.015080363791639684, 0.0327314102469245, 0.07486065136617981, 0.020082005903532263, 0.022715450140822213, 0.012582084127643611, 0.0374058273882838, 0.033419963729102165, 0.06848395525594242, 0.05435894425318111, 0.04831850412301719, 0.024697899134480394, 0.01926278247992741, 0.053609575479640625, 0.07608116517076269, 0.02596432219434064, 0.03480413965007756, 0.07075039262417704, 0.056917127294582315, 0.03379076668352354, 0.03944430296542123, 0.06650984243606217, 0.013816285918437643, 0.03284934122348204, 0.0532862551335711, 0.006783513172194944, 0.07425879186484963, 0.032806931194500066, 0.020496395191003103, 0.049869626163854264, 0.026367221180407796, 0.03940843867894728, 0.04975527604983654, 0.0027574285877562943, 0.06973664116230793, 0.02893897624744568, 0.027100763654743787, 0.11440679925726727, 0.035435210083960555, 0.03011519311257871, 0.07454391758074053, 0.09153738501481712, 0.11585821004700847, 0.2134023973485455, 0.14194867137121037, 0.16475442418595776, 0.2604831475764513, 0.2255460261949338, 0.18059451249428093, 0.20266853738576174, 0.14952301571611315, 0.09394084510859102, 0.13227381161414087, 0.154529380670283, 0.1773485218291171, 0.18641344009665772, 0.1407806942006573, 0.11424113705288619, 0.17393933288985863, 0.3173082077410072, 0.134257334866561, 0.11761948975617997, 0.0850255586556159, 0.13279614999191836, 0.2221054889378138, 0.1667865877971053, 0.22666699573164806, 0.17335321434075013, 0.11748331307899207, 0.3433273115660995, 0.11630872337264009, 0.19568062329199165, 0.11838738995720632, 0.12612514779902995, 0.09654524168581702, 0.23336098965955898, 0.07612803179654293, 0.11097265189164318, 0.15725200879387558, 0.11709514757967554, 0.1691244717221707, 0.11313974537188187, 0.15224019647575915, 0.1322196942055598, 0.23649819631827995, 0.06430959721910767, 0.09720131507492624, 0.08191955930669792, 0.10154653777135536, 0.12895099382149056, 0.11194193386472762, 0.15033977892016992, 0.11510139011079445, 0.18713252182351425, 0.17703604797134176, 0.18084317649481818, 0.08563098046579398, 0.12287970632314682, 0.1330205606063828, 0.1146808743942529, 0.13860642415238544, 0.38332099677063525, 0.25987595203332603, 0.12703562941169366, 0.0915865003480576, 0.21971198846586049, 0.22191071970155463, 0.14286652993177995, 0.13480817171512172, 0.13571051938924938, 0.17543682362884283, 0.16073483362561092, 0.19111807749141008, 0.16496546129928902, 0.17238371714483947, 0.20346466888440773, 0.10606407973682508, 0.20527153130387887, 0.12827062251744792, 0.09285257459850982, 0.13128593884175643, 0.11318119431962259, 0.06770660751499236, 0.18475429475074634, 0.08251956343883649, 0.10767117084469646, 0.24231117189629003, 0.15214101586025208, 0.13506860617781058, 0.11430919941631146, 0.1278611202724278, 0.2118422693456523, 0.12316060179728083, 0.09034342525410466, 0.18500257283449173, 0.1781734635005705, 0.12187040032586083, 0.13957737595774233, 0.20100568130146712, 0.22475593577837572, 0.12879469752078876, 0.14821129938354716, 0.13019582780543715, 0.10374868288636208, 0.17902576073538512, 0.12500045268097892, 0.07048114144708961, 0.18279457959579304, 0.16187057190109044, 0.14688606112031266, 0.1558430414297618, 0.1288796734297648, 0.12458551791496575, 0.13123985147103667, 0.13736322289332747, 0.2093068405520171, 0.13201719179050997, 0.10830390368937515, 0.16558350704144686, 0.14860815543215722, 0.12033392456942238, 0.16708987386664376, 0.2690513018751517, 0.11837281417683698, 0.16112156677991152, 0.10125663262442686, 0.14551062398822978, 0.12234746769536287, 0.1822275045560673, 0.10990092385327443, 0.11264946035225876, 0.12962395849172026, 0.1652211311738938, 0.08911793906008825, 0.13290671515278518, 0.2749902050709352, 0.12542613374534994, 0.07585832790937275, 0.1950812351424247, 0.08819535301881842, 0.08929651463404298, 0.12593368854140863, 0.1437706290744245, 0.14367572322953492, 0.19975324772531167, 0.21042121981736273, 0.13203414244344458, 0.107331148465164, 0.11929258005693555, 0.1406463803141378, 0.13586500484962016, 0.09153957435046323, 0.08736867472180165, 0.15434375469340011, 0.18462818901753053, 0.12378683342831209, 0.1680418266914785, 0.14893560583004728, 0.15921910089673474, 0.2986903942655772, 0.12750389490975067, 0.12509209307609126, 0.15303543739719316, 0.15635789895895869, 0.06560841502505355, 0.1374925347045064, 0.11660684409434907, 0.10213212197413668, 0.11975288231042214, 0.14726446737768129, 0.1269435734138824, 0.13454294297844172, 0.16573331697145477, 0.22338137438055128, 0.11675219371682033, 0.13738363195443526], [0.05379266702220775, 0.07205760412034579, 0.033141999738290906, 0.04401713493280113, 0.01727849852613872, 0.030612528535129968, 0.04856924984778743, 0.04951911723765079, 0.039061247152858414, 0.03603747034503613, 0.019287219547550194, 0.028159787980257533, 0.02722147026361199, 0.01985964918276295, 0.023123241735447664, 0.016040579503169283, 0.03311691885755863, 0.04705632985860575, 0.04623811204510275, 0.07990275815245695, 0.06506080651888624, 0.03516792559821624, 0.015689688370912336, 0.03401458729058504, 0.05304584752593655, 0.01878264818515163, 0.14144564367597923, 0.026882457204919774, 0.03447422161116265, 0.04303273912228178, 0.011260515784670133, 0.009319765285908943, 0.013450515652948525, 0.020078061388630886, 0.039316768597927876, 0.029071805838611908, 0.028739212357322685, 0.09354115405585617, 0.028162381786387414, 0.050889281410491094, 0.04614935489371419, 0.007128821962396614, 0.07885702754720114, 0.08107178917271085, 0.05513409152626991, 0.0605904317490058, 0.010868293520616135, 0.03825366802630015, 0.0200933737505693, 0.035372183192521334, 0.015740020826342516, 0.032930925517575815, 0.015074844068294624, 0.051449139064061455, 0.02267726664285874, 0.025652855802036356, 0.04997172341973055, 0.031892531042103656, 0.07223860651720315, 0.010135585034731776, 0.026781727356137708, 0.040751915221335366, 0.06871975783724338, 0.011951443211728474, 0.026192857294518035, 0.028825475892517716, 0.10503836485440843, 0.03362986535648815, 0.030190684374247212, 0.0740231154486537, 0.024249148409580812, 0.02215864456957206, 0.022186946371220984, 0.09977922440157272, 0.012116394809709163, 0.036020497427671216, 0.04174259702267591, 0.03303152734588366, 0.05499403712747153, 0.025197175273206085, 0.05319151627190877, 0.01935227250214666, 0.020977358835807536, 0.030616562107752543, 0.015007565598352812, 0.053523356473306194, 0.038029888237360865, 0.03238861223508138, 0.08497530783643015, 0.042051415803143755, 0.030253976583480835, 0.02425984275760129, 0.02629601767694112, 0.11001982333255, 0.06739883887348697, 0.044668473419733346, 0.019737721740966663, 0.0494628772867145, 0.020899952833133284, 0.04244716234097723, 0.0819449927075766, 0.02475034856615821, 0.031688169547123834, 0.08379202015930787, 0.00344920925272163, 0.02913882548455149, 0.024987835822685156, 0.0480603554751724, 0.029480144767148886, 0.016911840466491412, 0.090783333289437, 0.057628542635939084, 0.0970579544082284, 0.008094138083833968, 0.038798315363237634, 0.037062999690533616, 0.022569913126062602, 0.019998100542579778, 0.06819051748607308, 0.021271408877510112, 0.01822542144509498, 0.07837892859242857, 0.018886971884057857, 0.09708824145491235, 0.03031436885066796, 0.016438639686384704, 0.040428216379950754, 0.01745073801430408, 0.02282278881466482, 0.03422964313358534, 0.01494501924753422, 0.0472986856038915, 0.0031405068966705585, 0.014422589028981747, 0.030013511459401343, 0.07663676660740748, 0.044098370417486876, 0.015328117733588442, 0.02618899441586109, 0.041625630838098004, 0.03284244296082761, 0.101786704180995, 0.05475011916132644, 0.028025763531331904, 0.0903879021643661, 0.06193228669872042, 0.03850071043416392, 0.05021056509576738, 0.06800253147957847, 0.03415255625441205, 0.031189494548016228, 0.008886556988727534, 0.034238574880873784, 0.04751364125695545, 0.03793094139837194, 0.02667696579010226, 0.045430577447405085, 0.05604361947916914, 0.03686732874484733, 0.05425063522125129, 0.015111998764041346, 0.04868484305916354, 0.07547784363850951, 0.013628095821331954, 0.029914742735854816, 0.023572356112708803, 0.013733810119447298, 0.05987352822558023, 0.07164496259065345, 0.0676355765608605, 0.04110656533157453, 0.023789996484993026, 0.04139389893680345, 0.04846148629439995, 0.06364651053445414, 0.04746717168018222, 0.042287300020689145, 0.024878743824956473, 0.048960588028421625, 0.03604855803132523, 0.0509695298387669, 0.03747017901332583, 0.027064133100793697, 0.05444593138236087, 0.03861791410599835, 0.021585354043054394, 0.024039489835558925, 0.09401675197295845, 0.04618174963979982, 0.05427596472145524, 0.04265782466973178, 0.03782155996304937, 0.006500922354462091, 0.05169279356778134, 0.031424458502442576, 0.05754112506110687, 0.04566653216897976, 0.01847570889367489, 0.016838204574014526, 0.04281973160686903, 0.06521424555103295, 0.03156699167448096, 0.04051055024319794, 0.032569176764809527, 0.08550851125619374, 0.03914671659003943, 0.027662315260386094, 0.025412950999452733, 0.012237529081176035, 0.04028823990665842, 0.037214293915894814, 0.08120548707665876, 0.03240081685362384, 0.0160279166084365, 0.06698396347928792, 0.035114850907120854, 0.03449546558840666, 0.03699031374708284, 0.030704742239322513, 0.050029967169393785, 0.020510739050223492, 0.026747872434498277, 0.01872533768619178, 0.023484053526772186, 0.06438115509808995, 0.022482515960291494, 0.05400589347118512, 0.0947818616987206, 0.0869416726345662, 0.05228215530223679, 0.025613572070142254, 0.025636706668592524, 0.022655460488749668, 0.029354161488299724, 0.04153072128247004, 0.006923589835423627, 0.014998756305431016, 0.0637696179910563, 0.09325377963250503, 0.027921003820665646, 0.022604884979955386, 0.08366865295101888, 0.04935689859848935, 0.03146425988234114, 0.012937402170791756, 0.028623706348298583, 0.07234094868181273, 0.036445098667172715, 0.08737153199035674, 0.11028269203961827, 0.024528631947760005, 0.02862464330974035, 0.030510080614476465, 0.00907531019038288, 0.05251119320746511, 0.028538582009787206, 0.04879969041212462, 0.07304916536668316, 0.000662724597759734, 0.09018182259751484, 0.01974311158846831, 0.058140695036854595, 0.015108550560398726, 0.011361250271875178, 0.04614207813574467, 0.0363204772293102, 0.04397607561259065, 0.034973816873389296, 0.01618853406398557, 0.04204471049888525, 0.05020827185944654, 0.04498265050642658, 0.033279259951086715, 0.08958236023318022, 0.06049385236110538, 0.08876222025719471, 0.0060617179678956745, 0.016232157504418865, 0.06793916691094637, 0.020927865007251967, 0.04998963144316804, 0.011736605374608189, 0.06383285639458336, 0.032285565030178986, 0.035595295048551634, 0.05214990087551996, 0.06399225487257354, 0.005058503611508058, 0.06307080431724899, 0.004525546492004651, 0.00950136047322303, 0.032696395719540305, 0.018240295939904172, 0.014772468985029263, 0.03554855829861481, 0.01506237784269615, 0.03994513761426788, 0.0778952709515579, 0.021638564176100772, 0.008009130633581663, 0.007316628461921937, 0.029577238092315383, 0.06445882827392779, 0.06347836213535629, 0.07199291110737249, 0.038186819074326195, 0.03694955870741978, 0.04048568458529189, 0.04167605235124938, 0.031704303837614134, 0.058991174009861425, 0.07595267714350484, 0.048914637955022044, 0.06971024296944961, 0.05247069049801212, 0.04022009590698872, 0.03883236880938057, 0.07083781019900925, 0.025797027265070938, 0.03193940508936066, 0.07849089641240425, 0.013189680430514272, 0.043139226181665435, 0.045636716386070475, 0.043875395858776756, 0.04951340641127899, 0.03141096625768114, 0.020135919221502263, 0.018184896471211687, 0.019113198904960882, 0.013671673805220053, 0.011365270856913412, 0.04739944699394982, 0.007402412384180934, 0.02968075841636164, 0.04532606450084131, 0.026604517333908007, 0.07825965803931467, 0.05094557702250313, 0.03533654526108876, 0.01403662306984188, 0.03974621606175788, 0.012627305040950887, 0.014384704245458124, 0.08467666761134751, 0.041019871350727044, 0.06353203425533138, 0.05747129638621118, 0.09620270342566073, 0.03646151497378014, 0.06891313925734721, 0.05105544456455391, 0.15484442235901952, 0.16153715463588014, 0.1476627038209699, 0.07331934422836639, 0.14217762392945588, 0.12335089588304982, 0.11454822291852906, 0.20108878699829802, 0.17238996602827683, 0.16946859075687826, 0.09734127670526505, 0.12677191465627402, 0.08581960471929051, 0.20101285044802353, 0.12967451359145343, 0.11369603700586595, 0.08673306976561435, 0.09489255302469246, 0.1606451376574114, 0.15903337101917714, 0.21457631170051172, 0.14691729069454595, 0.14889354089973494, 0.16834831883898005, 0.23678104364080355, 0.04541690337646287, 0.1841657271143049, 0.10964598870486952, 0.17384744016453624, 0.09704421725473367, 0.15811031742487103, 0.14834996225545183, 0.06125045336375479, 0.18184100888902321, 0.13054640352493152, 0.16653272876283154, 0.15142343327170238, 0.12336444007814862, 0.139896766631864, 0.2074297412764281, 0.145058908383362, 0.10536772999330424, 0.16092038538772613, 0.12177149430499412, 0.1097065034264233, 0.1365179315325804, 0.10436079886858352, 0.10759823257103562, 0.13085334096103907, 0.17160483315819874, 0.1159808128431905, 0.13851502124452963, 0.19240482797613367, 0.15940797748044133, 0.11446561446064152, 0.04262455418938771, 0.11525569003424607, 0.08866594143910334, 0.12058557200361975, 0.10105680936248973, 0.16313018946675584, 0.12768149084877223, 0.1982300341478549, 0.09137495115282945, 0.082441148115322, 0.16570918232901022, 0.15128027298487723, 0.2001636553904973, 0.13004263368202373, 0.1845492096617818, 0.19141781609505415, 0.10852051433175802, 0.1204173345468007, 0.28462381626013666, 0.10795211826916784, 0.15131794440094382, 0.1087605397333391, 0.12559326540213078, 0.20221992395818233, 0.16071953054051846, 0.09481727698585019, 0.1647570959175937, 0.12716746452497318, 0.17309085029410198, 0.1691037806449458, 0.2295137257897295, 0.10507326805964112, 0.1530093137989752, 0.2170345126069151, 0.14810873457463458, 0.1036053741700016, 0.09418165718670934, 0.13515040569473058, 0.15993479843018577, 0.234570185712073, 0.10046246781712398, 0.12090281044947915, 0.15760985756060109, 0.1182752737076953, 0.27910606702789664, 0.15706632344517857, 0.07127155840862542, 0.11957982089370489, 0.16205832042032853, 0.09128288773354143, 0.09708821919048205, 0.10432608862174675, 0.18191592127550393, 0.12240852418472059, 0.1161258210777305, 0.13225950300693512, 0.1326780891395174, 0.18050144717562944, 0.07790312287397683, 0.1138975597859826, 0.12890282843727618, 0.11140734262880869, 0.08813859356450848, 0.229527915653307, 0.11490728138596751, 0.1187094597844407, 0.19350142538314685, 0.07173418358433992, 0.20206209883326665, 0.10732676979387179, 0.0913334873621352, 0.10316920655895956, 0.13380334828980267, 0.17109099979279563, 0.10071295750094578, 0.06796573579777032, 0.11123151300125755, 0.09095518500544131, 0.14577024208847433, 0.16897932247957215, 0.13953845773357898, 0.1144227257464081, 0.14451693277806044, 0.09131681130384095, 0.11779451786424033, 0.1256355975056067, 0.25136823824141175, 0.1509627970517613, 0.08457597301458009, 0.1800887388526462, 0.13730245584156364, 0.1466433343011886, 0.11868402638356201, 0.184050620009657, 0.138231253658887, 0.09776041944860481, 0.15491004305658862, 0.08437577867880464, 0.1650170554057695, 0.08724438725039363, 0.14310720842331648, 0.12952535675140098, 0.11666784121189266, 0.16332176746800542, 0.16458258731290698, 0.11118783018901013, 0.19892067677574232, 0.1425262849079445, 0.09073992507182993, 0.1254883108776994, 0.06959575926885009, 0.1374413413577713, 0.1618799674906768, 0.18236484640510753, 0.17082041274989024, 0.1808481488842517, 0.17824276525061578, 0.1971191429765895, 0.09345554732135497, 0.18774476397084072, 0.17655489878961816], [0.012954950252606068, 0.020903353724861518, 0.03036880909348838, 0.025289379700552672, 0.03091273654717952, 0.013106853039062116, 0.017016058409353718, 0.026694695698097348, 0.024055754001892637, 0.0230946170995594, 0.044485044199973345, 0.03029831248568371, 0.007338496770898928, 0.07267022476298735, 0.07128908051527105, 0.049549879258847795, 0.019802516799245495, 0.009925213998940308, 0.06136169387900736, 0.1360317802755162, 0.020034450935781933, 0.030222923269320745, 0.03663779360067565, 0.07592636058689095, 0.03712211546371691, 0.044673234297079034, 0.054858342846273445, 0.05375719607400242, 0.02125287373928586, 0.005062817344878567, 0.062449634133372456, 0.05224908520176541, 0.04435067836311646, 0.01943498671607813, 0.008563359097024659, 0.025001090580190066, 0.032230627548415214, 0.08339103034813888, 0.06332024757284671, 0.028520907762867864, 0.030698799491801765, 0.030671167478431016, 0.03193284079316072, 0.022495516532217152, 0.05824076994031202, 0.03932968567823991, 0.04647547684726305, 0.04060575294715818, 0.06725247993017547, 0.10170518668019213, 0.022558061027666554, 0.05769037838035729, 0.06504104312625714, 0.07760604115901515, 0.04489168546569999, 0.04146756080444902, 0.02407131683867192, 0.08830484206555411, 0.046316297302837484, 0.046774102229392156, 0.07056709699099883, 0.0068997719972685445, 0.035788913955911994, 0.026229870054521598, 0.016693561847205274, 0.057623722386779264, 0.021292656565492507, 0.05186180285818409, 0.019568584430089686, 0.036436790323932655, 0.023053607874317095, 0.027244092780165374, 0.023218924980028532, 0.029225864564068615, 0.02550981611420866, 0.03137294974294491, 0.03891387517796829, 0.03298574796644971, 0.05343294804333709, 0.03980551737186033, 0.013004777119931532, 0.0176869914503186, 0.07759667525533587, 0.01288026793190511, 0.04127734835492447, 0.0596098988171434, 0.00832623734822846, 0.04148673790041357, 0.055894718680065125, 0.005325304309735657, 0.04926063833408989, 0.03276943047239911, 0.0328502355114324, 0.0786204234464094, 0.013469351360981818, 0.039567098719999194, 0.0295362900942564, 0.04056013312947471, 0.05022618730436079, 0.055832289217505604, 0.02365521690080641, 0.03628403406764846, 0.0861548625107389, 0.02771360694168834, 0.03931270905013662, 0.05309597960149404, 0.011761401456169551, 0.04792465748323593, 0.02683947572222678, 0.024018917501962278, 0.03639457325334661, 0.021632816242345143, 0.04018894425826147, 0.0640719837974757, 0.0699561981309671, 0.11262997897574678, 0.02669016303116223, 0.04304649482946843, 0.06120179074059706, 0.03178289356583264, 0.014173437066347105, 0.007357383965427289, 0.028995051070523914, 0.030111998166830745, 0.01850222768553067, 0.022793026837462094, 0.05969173915218562, 0.03341715841088444, 0.02400511355517665, 0.05648276310239453, 0.015029468231659848, 0.00833948097351822, 0.020273403933970258, 0.03145733935525641, 0.04116532116313465, 0.04102479921129998, 0.04084252403117716, 0.04270370423910208, 0.05230229719018098, 0.05312048531777691, 0.027492875524330884, 0.03559615965059493, 0.050247063918504864, 0.05028565559769049, 0.0785895055742003, 0.0033456724622737966, 0.01410022790878429, 0.06219364142452832, 0.030133730106172152, 0.006779454552088282, 0.06856401814729907, 0.03559079392289277, 0.02777199726551771, 0.017639269499341026, 0.050604567586560734, 0.03354720494826324, 0.04993150272639468, 0.03425331764447037, 0.016377507126890123, 0.07860197365516797, 0.07217798047349788, 0.037084436626173556, 0.03888092753186356, 0.0313846385688521, 0.023153354377427604, 0.03708193187776487, 0.019076982098340522, 0.03285841768956743, 0.026653313543647528, 0.06522180803585798, 0.11438129906309769, 0.02226627453637775, 0.07319443335290998, 0.04847897129366174, 0.08356444057426415, 0.041248412017012015, 0.01775213902874384, 0.04458304108993616, 0.04421906218340155, 0.043658974464051425, 0.056267265681526624, 0.04634510005416814, 0.053640100013581105, 0.04441189441422466, 0.02546163959777914, 0.04531179671175778, 0.04307003575377166, 0.0598579542565858, 0.02704386875848286, 0.019741087380680256, 0.04596661587129347, 0.07409985351841897, 0.036597142461687326, 0.009772448465810157, 0.035955117928097025, 0.10148797489819117, 0.05352937900170218, 0.037449283845489845, 0.0520301367942011, 0.08739977813092992, 0.04839668567001354, 0.059105542677571066, 0.04108003355213441, 0.030122132193355355, 0.023763110330037307, 0.04855213963310234, 0.004030697728012456, 0.026052804751088843, 0.025609588592487853, 0.06496544054243714, 0.009938307339325547, 0.028084070363547653, 0.02907339217927074, 0.05901896001887508, 0.060300099867163226, 0.04442212491994724, 0.047157989247352816, 0.048122651351150125, 0.045574253526865505, 0.017641562735661864, 0.026517678634263575, 0.059103338498971425, 0.019559758438845165, 0.09050141365150921, 0.1552118151448667, 0.05138973385328427, 0.02389214569120668, 0.007171535808083718, 0.03138029329420533, 0.07629859959706664, 0.07590886816615239, 0.024008135951589793, 0.015503352715313667, 0.0037551125524259987, 0.04140892000577878, 0.014295653945737286, 0.0748361085425131, 0.02835312672686996, 0.0146358405254432, 0.026467791467439383, 0.025480171025265008, 0.011358781703165732, 0.05843123100930825, 0.020371866521600168, 0.017460432318330277, 0.028833270298491698, 0.009176014991680859, 0.037550052657024935, 0.015512337340624072, 0.01988700660149334, 0.04655192176869605, 0.03319107425340917, 0.00836924202303635, 0.0813056918559596, 0.04612140190147329, 0.01971001736819744, 0.04531201935606077, 0.009395299221068854, 0.013109444062138209, 0.022449625830631703, 0.007981555208971258, 0.013426560053630965, 0.04488822705752682, 0.04794714826857671, 0.03472743497695774, 0.04804082585906144, 0.05789130744233262, 0.03492587413347792, 0.055075658528949134, 0.03092566847044509, 0.024549230256525334, 0.046275813147076406, 0.03321241099911276, 0.01709850173938321, 0.013052722642896697, 0.03418022351979744, 0.044747300635208376, 0.03253727925766725, 0.029372247627179604, 0.01675544583122246, 0.022781072693760507, 0.048852624095161445, 0.020772629977727775, 0.05305354730808176, 0.021963643412163947, 0.0770626480516512, 0.004257370965206064, 0.0068459157319011865, 0.029846483703295235, 0.07919512776425108, 0.03884472927893512, 0.03678848297568038, 0.008089191669569118, 0.08730655696126632, 0.03202540516213048, 0.03196237827069126, 0.04006417810160201, 0.024697960361663718, 0.01854866015492007, 0.021141343786439393, 0.004704468556155916, 0.023481823373003863, 0.07814717071596533, 0.027816938018077053, 0.019127052946714684, 0.057536037638783455, 0.007835126689315075, 0.03898236056556925, 0.04044417626573704, 0.010589069734123768, 0.055531155376229435, 0.05290974506351631, 0.019618373262346722, 0.03031394397112308, 0.014482613933068933, 0.04096200238564052, 0.09900517179630697, 0.07371036699623801, 0.04338625003583729, 0.03771669449633919, 0.039646775694563985, 0.05583348036452662, 0.018251433721161447, 0.035011261934414506, 0.019110104149149265, 0.035182764841010794, 0.010926662507699803, 0.03745965535927098, 0.04288921147235669, 0.06989690795307979, 0.05137811182066798, 0.07110293503501453, 0.06487996739451773, 0.05450034936075099, 0.04088559086085297, 0.038597100574406795, 0.022386072014342062, 0.051286263624206185, 0.0575094464875292, 0.07029951564618386, 0.021732234345108736, 0.06897400278830901, 0.044239556591492146, 0.02678076627489645, 0.04494773987971712, 0.04333216231316328, 0.0167889667864074, 0.053117034331080504, 0.04009030912129674, 0.03474044853646774, 0.03744087531231344, 0.0964977516559884, 0.0764427988906391, 0.09044642050866969, 0.13400424766587093, 0.15551130141830072, 0.12632371683139354, 0.10680650200811215, 0.08519339535268955, 0.11507575633004308, 0.12048735618009232, 0.15130235929973423, 0.21329334616893902, 0.14616776606999338, 0.1495470167719759, 0.18630078207934275, 0.15850257215788588, 0.07558297627838328, 0.15690195257775486, 0.12240410098456778, 0.15112206194316968, 0.2856271405471489, 0.24046910199103877, 0.07158372798585333, 0.1726778451120481, 0.23716700496152043, 0.10480893732164986, 0.1688748726155609, 0.1994772133184597, 0.08960037215729244, 0.0826529496407602, 0.17268973431782797, 0.19716199458343908, 0.12078215208020993, 0.08506962738465518, 0.11093446839367971, 0.12671852455241606, 0.18059037131024525, 0.11022940583643503, 0.2042309957323596, 0.1389461793587543, 0.09031924608279951, 0.19979133474407718, 0.11037459218641743, 0.17260891443584114, 0.1257128402357921, 0.18487223685951903, 0.15589435352012515, 0.10159506680793129, 0.1752556802239269, 0.16942315647611395, 0.15103615092812106, 0.08959548140410334, 0.15507750125834718, 0.2143985970178619, 0.18263878795551136, 0.23269112716661766, 0.14041251473827288, 0.05646580131724477, 0.11939210948185064, 0.12780461314832792, 0.16201763588469476, 0.10187153908191249, 0.1636897391290404, 0.1645002534496598, 0.0703699528821744, 0.08694504198501818, 0.12260035451618023, 0.11266043671639636, 0.13376435585087165, 0.1861755075515248, 0.11963826502324082, 0.12624521245015785, 0.25072426185943186, 0.0810849251865875, 0.11213705933187157, 0.0877064855012577, 0.08587520642322488, 0.09689756887382828, 0.18975748331286013, 0.19606130052125081, 0.055812611171859317, 0.09307336353231221, 0.16287520236801356, 0.1021584533737041, 0.06870412078569643, 0.10770634864456952, 0.08488243547617458, 0.13595275639090687, 0.10855441563762724, 0.11349245105520822, 0.1474354582023807, 0.14380390697624534, 0.1488305622478947, 0.1261330145644024, 0.21785592165542766, 0.1746619917685166, 0.11072175402659923, 0.07059747309540398, 0.13876368524506688, 0.10592869715765119, 0.1254307053750381, 0.17892807925818488, 0.18546300125308335, 0.1857275323709473, 0.12892706698039547, 0.2081970329163596, 0.22910115105332807, 0.11220885469811037, 0.15432276675710455, 0.08013665341422893, 0.11533729659277014, 0.10821652322192676, 0.08079908700892702, 0.18273499998031184, 0.158458904188592, 0.1563231516047381, 0.3366486949380487, 0.20013131259474903, 0.1828591464436613, 0.1223324540478643, 0.26595381496008486, 0.11434278159867972, 0.11518055500346236, 0.1300017413450405, 0.1231455139350146, 0.059658899117494, 0.08708765308256261, 0.22654712403891608, 0.14757434371858835, 0.11505223767017014, 0.16413774399552494, 0.14760376245249063, 0.16453762800665572, 0.1139184512430802, 0.13503213704098016, 0.14770297275390476, 0.18396153260255232, 0.12184232487925328, 0.12911963945953175, 0.15342007769504562, 0.18575784168206155, 0.15386808256153017, 0.1742320359335281, 0.14819118718151003, 0.1207324059214443, 0.17222385853528976, 0.10113912838278338, 0.08412635768763721, 0.08291381454910152, 0.10438593541039154, 0.11950488624279387, 0.11910132117918693, 0.17569087562151253, 0.12297573281102814, 0.12375972277368419, 0.20353207073640078, 0.1944681172608398, 0.1161954939016141, 0.1762174887699075, 0.14687601244077086, 0.15715121029643342, 0.1169626296905335, 0.09537920152070001, 0.15515700011746958, 0.12290837548789568, 0.1164064122713171, 0.14387116039870307, 0.1164162160421256, 0.0944300317496527, 0.08664799737744033, 0.11600648373132572, 0.20734619029099122, 0.08946239206125028, 0.14457409299211577, 0.16575191519223154, 0.18409042881103233, 0.11523171866429038], [0.03176763500960078, 0.008537588018953102, 0.05127943957631942, 0.0651462648238521, 0.02785771903290879, 0.010791270651679952, 0.02206898385338718, 0.055842504880274646, 0.03171510579704773, 0.05386172757425811, 0.047684082892374136, 0.027010115882148966, 0.028576483491633553, 0.02555758816015441, 0.026006915904872585, 0.026680544797272887, 0.029475415431079455, 0.033381531611667015, 0.03518784113111906, 0.02221305141574703, 0.08519884271663614, 0.08207212260458618, 0.019262361311120912, 0.019247935815656092, 0.012847309153585229, 0.03279388423834462, 0.035889786668121815, 0.015056884094519773, 0.037675093408324756, 0.03120019260677509, 0.04068313668540213, 0.02346154418773949, 0.025247966004826594, 0.07375355256954208, 0.05773721160949208, 0.0676589245267678, 0.05553385679377243, 0.06546310250996612, 0.00783785686508054, 0.09187435716739856, 0.03771417119423859, 0.03436452847381588, 0.09746153431478888, 0.019869809184456244, 0.05770465359091759, 0.01459888899262296, 0.02594334724562941, 0.06393442672560923, 0.034225620693177916, 0.04387740707898047, 0.05422175454441458, 0.04936845383781474, 0.03178140184900258, 0.01740002706355881, 0.014033830739208497, 0.04551674079266377, 0.030700578790856525, 0.0708585829124786, 0.038185267985682, 0.058256291958969086, 0.05443695881695021, 0.051365985127631575, 0.03765514447877649, 0.05330630054231733, 0.03327800572151318, 0.03610684259911068, 0.05947350691712927, 0.028879481978947297, 0.03036113157577347, 0.031080606640898623, 0.0172829514121986, 0.012991845196665963, 0.010886651471082587, 0.06043779423634987, 0.01926472319610184, 0.006106571981945308, 0.017337660683551803, 0.04641924431780353, 0.03068466900003841, 0.01816907573811477, 0.030137776666379068, 0.06623553723329678, 0.03860050332150422, 0.05125247364048846, 0.0704827148001641, 0.046644033427583054, 0.05172804929316044, 0.05927127909671981, 0.01964893119293265, 0.02412953461316647, 0.08175752620445564, 0.07831557886675, 0.08945773879531771, 0.037199239450274035, 0.07953295338666067, 0.05062442003691103, 0.02236530857771868, 0.04729960215627216, 0.025756539398571476, 0.03958155575674027, 0.05986988799122628, 0.025622177272452973, 0.023030324846331496, 0.03392980434000492, 0.025301022142230067, 0.012338072465354344, 0.03670666861580685, 0.024445925155305304, 0.011292288054391975, 0.05106235767016187, 0.03792310431890655, 0.0714250271266792, 0.02471986856107833, 0.09451261794310994, 0.04109525129024405, 0.04685937499743886, 0.01235434683621861, 0.027977082354482263, 0.06981251091929153, 0.10327410913305357, 0.08094653690932319, 0.012980763076484436, 0.020022749122290406, 0.022101695867604576, 0.060275954092503525, 0.125486099277623, 0.06388940804754384, 0.052226586994947866, 0.0529473719507223, 0.01242711441591382, 0.01375444553559646, 0.04472490261832718, 0.029207665247668047, 0.04138404692639597, 0.08700610589585267, 0.038350818867911585, 0.06402997823897749, 0.05484746667207219, 0.025955837591027375, 0.026651244806998875, 0.09483271365752444, 0.03199203078111168, 0.008920573327486636, 0.011043855047319084, 0.08715559670235962, 0.05535279502510093, 0.12107141155865975, 0.025253168460039888, 0.10415143158752471, 0.031627614007447846, 0.024845651460054796, 0.03218829915567767, 0.02161605669243727, 0.025304495393356774, 0.037127848554519005, 0.012500218745117309, 0.008809362498141127, 0.016836562572279945, 0.04106812579266261, 0.05498788843397051, 0.032948610896710306, 0.08171513472916558, 0.015587912093906198, 0.018807823689712677, 0.010822590211319039, 0.024898987758206204, 0.025612390199967194, 0.05618168492219411, 0.014446362802118529, 0.050545032499940135, 0.02616231420688564, 0.017099796787078958, 0.0619645589904394, 0.013653874320880277, 0.03593038585677277, 0.02880468648072565, 0.05903798126382753, 0.06212806154508144, 0.05124636576510966, 0.0641597576031927, 0.10879260051297024, 0.0616422294115182, 0.026751232508104295, 0.037050754253868945, 0.034234088598168455, 0.03153062272758689, 0.0402691889757989, 0.03399186272872612, 0.023367306275758892, 0.04589714342728257, 0.015054346877150238, 0.008102388910629088, 0.018465810499037616, 0.029424012427625712, 0.03149182695779018, 0.02630056147609139, 0.025165997649310157, 0.05706926756829489, 0.03966053140175063, 0.023018378124106675, 0.037330061531974934, 0.04656307624827605, 0.029816311689501163, 0.058585289734764956, 0.03111096975771943, 0.03989242286479566, 0.026770763979584444, 0.046235154586611316, 0.08786441452684812, 0.03319854396977462, 0.037284642094164155, 0.051399196236161515, 0.0943629712855909, 0.09241543477401137, 0.011425953489379026, 0.11059019350796007, 0.01330535342276562, 0.0571066903648898, 0.0321326083940221, 0.0157065388339106, 0.043546086380956694, 0.009308306525781518, 0.0497745830216445, 0.0669725715124514, 0.026482400644454174, 0.04697066375229042, 0.04069537470059004, 0.013652767593157478, 0.050389801181154326, 0.018995086102222558, 0.034761848364723846, 0.025260968432121444, 0.01998629297304433, 0.026415382853883784, 0.06696774755255319, 0.06140464567579329, 0.04115827447094489, 0.02783771629765397, 0.020869023828709032, 0.05871844587090891, 0.028196258972457144, 0.09016392941703089, 0.02081557806377532, 0.03652857914858032, 0.041117968430626206, 0.011121170136902947, 0.02113354938046541, 0.01770237802702468, 0.03624698605563026, 0.05111437109007966, 0.02797577988530975, 0.02816788666677894, 0.024941262345237192, 0.053542819296126254, 0.0657440721988678, 0.04769468818267342, 0.0236747613598709, 0.01224665749759879, 0.025223584598279558, 0.02017916602198966, 0.07875224371673539, 0.0359980585926678, 0.049714706547092646, 0.06744118581991643, 0.02123414564266568, 0.046310115212691016, 0.02838420230546035, 0.07067594779073261, 0.0901001418242231, 0.027101229352410883, 0.12429050679202192, 0.05088021236588247, 0.05912618922593538, 0.04720643664768431, 0.0553174576634774, 0.05437655170680955, 0.03832276568573434, 0.027154504423378967, 0.03969730110839009, 0.021745810081483796, 0.050405397414579056, 0.029195232418715023, 0.029600923735415563, 0.021010152486269362, 0.06546001517563127, 0.05891318171052262, 0.01850687724072486, 0.05279730597976595, 0.0032306435150530888, 0.0932748343620915, 0.0650946781388484, 0.05189138486457523, 0.05337031077942811, 0.03253411028708797, 0.006702684941046755, 0.09983154581277631, 0.04529767364147119, 0.010633657966536703, 0.004509743848757353, 0.028752697180607356, 0.061775719514116645, 0.02166875474358676, 0.07739118940662593, 0.060971016209805384, 0.10392216732725501, 0.007996453823579941, 0.00973147078184411, 0.01843589638156118, 0.06765470170648769, 0.03080678012338467, 0.04578185449645389, 0.07332334440434352, 0.08463314065011218, 0.0287014964123955, 0.03212282317690551, 0.029064414047752507, 0.018234731687698513, 0.03352481435285881, 0.028416207424015738, 0.08016540421522222, 0.0840014468121808, 0.02758161226665834, 0.02858298841601936, 0.015932478272588924, 0.038567217998206615, 0.03496849938528612, 0.024884131817088928, 0.027723275270545855, 0.013354907550819917, 0.04292103105399292, 0.05941230941971298, 0.027067893934145104, 0.038643232473987155, 0.031832821550779045, 0.06513175583677366, 0.04574763406708371, 0.09076561822439544, 0.06497314403532073, 0.030722013871127274, 0.024688388512004167, 0.014977224745962303, 0.056563709149486385, 0.024724362265260424, 0.05833288530993741, 0.03734350924787577, 0.029416524157568347, 0.03414636303205043, 0.04016008955659345, 0.033730671275407076, 0.06525530116050504, 0.03616266323660966, 0.028698117785097566, 0.1286877688835375, 0.1293815136887133, 0.1783809531480074, 0.17103544261772186, 0.20683930342784151, 0.20784715481568128, 0.11037361997296102, 0.17141086544143036, 0.08624421709100716, 0.1084468635963276, 0.15580887295072898, 0.16246777813648805, 0.12899975292384624, 0.1334573738859035, 0.12085289359674789, 0.1906829117797315, 0.09508516261121258, 0.14550562191288918, 0.08899354026652873, 0.08829208454699256, 0.16403869696659967, 0.15859694365644827, 0.15861677384236827, 0.08605252776760608, 0.13632884714752436, 0.11958326445892453, 0.1215530579793267, 0.13871654402464628, 0.10120383623871021, 0.10370512623921968, 0.16448846814455464, 0.09590179222868755, 0.2552563202334568, 0.17034950520610437, 0.141533647547476, 0.20673127641202882, 0.13901579281082377, 0.15424132347106934, 0.20405403804033995, 0.21294795064022765, 0.1281112537253648, 0.13748307974310592, 0.2932911808602512, 0.22016793431248516, 0.10818401715368964, 0.1145046588499099, 0.12906770396512002, 0.10163976636249572, 0.13961722928797826, 0.15638302807928994, 0.14343731570988894, 0.14991565636591986, 0.15480519243283197, 0.07340855780057609, 0.15174785570707172, 0.169309162592981, 0.1313772378489375, 0.1299253446632065, 0.1779633911792189, 0.1797431058366783, 0.1354554432327859, 0.14418937847949564, 0.11419780305004679, 0.106235530693084, 0.0870222105004359, 0.22018714109435678, 0.17249484633794054, 0.1138690761581529, 0.08457631440251134, 0.0830100488383323, 0.11880169389769435, 0.07206830588984303, 0.13345091720111668, 0.11927249754080549, 0.15219155611703172, 0.09583261664374731, 0.07038636918878183, 0.15403810859424993, 0.11349662192515098, 0.12472278554923832, 0.12911583966342732, 0.1211328836507164, 0.12902869668323547, 0.20652196108130738, 0.13125994883012027, 0.08513774911989458, 0.11684846511343494, 0.1817325662705116, 0.06541584996739402, 0.12101768006687053, 0.14465632295468822, 0.16270885738776997, 0.18760032719001174, 0.14653075049864128, 0.24115607840940356, 0.11691652005538344, 0.1047384184494149, 0.17540600965730846, 0.1675887603778392, 0.1690472586778924, 0.19279470783658326, 0.11857651887112297, 0.09305022336775437, 0.10278320070938207, 0.17678794800303876, 0.13229209813289344, 0.11855760894832201, 0.08022690599318594, 0.0987484554934781, 0.16754694777773693, 0.1803654560353607, 0.12862122792284936, 0.12214770380523987, 0.23142745747463778, 0.10016257336246781, 0.13704813667573035, 0.11049061955418438, 0.07700136149651371, 0.1166538665711414, 0.21326033544028178, 0.11303338818834163, 0.10074492180137895, 0.12592261569807306, 0.07787113630911335, 0.1707025003270246, 0.27823615120723844, 0.14962093468056992, 0.09577701493981294, 0.16896042739972472, 0.20973482227418572, 0.11802052409620956, 0.07796829828293994, 0.18894937355071306, 0.15762752067530528, 0.20170367119135335, 0.12889018224086612, 0.17832762241596356, 0.09806029906030744, 0.06787018428440206, 0.15059442463098094, 0.1058946548437234, 0.08640740052214824, 0.09719058361952193, 0.15035855525638908, 0.21033910859841853, 0.1896575011778623, 0.16895986336749047, 0.1685827484470792, 0.12899804598418996, 0.11791427823482081, 0.1121010874339845, 0.09252117597498, 0.1891362908645533, 0.10061101609608158, 0.14267287391703576, 0.07009955137618817, 0.11814398036221974, 0.07464479029295035, 0.13423717813566327, 0.15017131139757112, 0.2438658822211437, 0.17103925725677982, 0.051764262389042415, 0.09629674095776863, 0.13451658189296722, 0.11320950725348666, 0.0693152126041241, 0.1693611723021604, 0.15165299439104274, 0.10444262807141058, 0.07373867993010208, 0.1215183551539667, 0.18055341235594824, 0.09506102054729126, 0.1301608726498671, 0.13384697173023596], [0.0468079107668018, 0.030128856051305775, 0.06777469214284793, 0.04130909001105465, 0.009413170137122506, 0.0030054840271986905, 0.03745311332750134, 0.031150424183579162, 0.021547853320953436, 0.07889681408414617, 0.027564574411371723, 0.0726990720431786, 0.10238614428089932, 0.037422982131829485, 0.049862089654197916, 0.03437346393184271, 0.04001829482149333, 0.060380934592103586, 0.031597798224538565, 0.013333284150576219, 0.032894846008275636, 0.027228442741034087, 0.053784959818585776, 0.045432046899804845, 0.03609510182286613, 0.02321200259757461, 0.07569852125016041, 0.021029721065133344, 0.011116130954178516, 0.007121860617189668, 0.023345665249507874, 0.043186975963180885, 0.01613711065147072, 0.026396656612632796, 0.009863532250165008, 0.05115849919093307, 0.046171337307896465, 0.040737432209425606, 0.07937931397464126, 0.01862940211140085, 0.0500436635047663, 0.013455882308335276, 0.053305031469790265, 0.08447835090919398, 0.002625758138492529, 0.09645628786529414, 0.029909898366895504, 0.09110092796618119, 0.042345380497863516, 0.05103957373648882, 0.0628013008099515, 0.03425805625738576, 0.056009554900811054, 0.09002645398140885, 0.06467216604505666, 0.028448117918742355, 0.022196991340024397, 0.05707780226657633, 0.029500177188310772, 0.0276326571838581, 0.021464664132508915, 0.05504611734068021, 0.061205661040730774, 0.03398999622731935, 0.03173800105287228, 0.03474724660918582, 0.03944534568290692, 0.04496377026953269, 0.015654044873372186, 0.026363820288679563, 0.01084218754840549, 0.013030340396653628, 0.026156447529501747, 0.025373578209837433, 0.07718157721683383, 0.06302775233052671, 0.10144703061087057, 0.025009571472764947, 0.06928948234417476, 0.05763265784480609, 0.04794773085450288, 0.02097519361996092, 0.039381123933708295, 0.03643480136815924, 0.017746602607076056, 0.009743818263814319, 0.04101390819414519, 0.004375541748231626, 0.019165659468853846, 0.04008379306469578, 0.04821756090677809, 0.03874872134474572, 0.01568087907799054, 0.06623639070312493, 0.02829575871146517, 0.04929653601720929, 0.02251924670417793, 0.007978294397616992, 0.02568797423009528, 0.04594460748194251, 0.047863459985819645, 0.026118147143279202, 0.04387916596897412, 0.059344777691876516, 0.017773844992916565, 0.035391467899899, 0.019162074895575643, 0.04125070896407124, 0.07320058575714938, 0.06210164850926958, 0.023991994239622727, 0.04605262336554006, 0.06410175876226276, 0.05421160938567482, 0.09426912671187893, 0.025317533072666265, 0.019532478945620824, 0.03725849252077751, 0.068446246732492, 0.006358698101394111, 0.03822579667030368, 0.06521526971482672, 0.04364161562989466, 0.009400699273101054, 0.04822558352316264, 0.013912153772253077, 0.035200850979890674, 0.013222507477621548, 0.06619432577281259, 0.007207866256067064, 0.055676783304079436, 0.05132055826834403, 0.034900117898359895, 0.040952361887320876, 0.025548055273247883, 0.04745959064166527, 0.08117735967971385, 0.03293907800980378, 0.02497517292795237, 0.0346097897272557, 0.038327764050336555, 0.027266175384283997, 0.05369062542740721, 0.03590927917684894, 0.06823925432399847, 0.020536940573947504, 0.043176545077585615, 0.03575813338102307, 0.0584150633221725, 0.04565057228319347, 0.04295754843042232, 0.0555237042135559, 0.022965804382693022, 0.07246716573718004, 0.05436255851236638, 0.025823382784437854, 0.04728111525764689, 0.027552334540814627, 0.05784828885225579, 0.04737007649964653, 0.05377006120397709, 0.046782866993453354, 0.029140189180907328, 0.037735752848675475, 0.027169900276931003, 0.034449270606273785, 0.06476853392086923, 0.07419680026941933, 0.054987573021207936, 0.08775520007475279, 0.04878816114796791, 0.042540513386484236, 0.06291635596426204, 0.014917736043571495, 0.03818896017037332, 0.02101395970385056, 0.023721075085632037, 0.04749454208649695, 0.06374849646817893, 0.017517280830361415, 0.03175985359121114, 0.008569526344217593, 0.040086034350679256, 0.04929088456265163, 0.02094887891871622, 0.01608333277545171, 0.00727568371075904, 0.03411517427593935, 0.061618376785190776, 0.020562014033203013, 0.09181964604067616, 0.036183280099066906, 0.03458499828411732, 0.02726110837102169, 0.024024281374295242, 0.03041626201593317, 0.005974716923446977, 0.004886531760348589, 0.0293989834972308, 0.04261752234015148, 0.03497916775813792, 0.02673880895599723, 0.04426770996360574, 0.02900006056734128, 0.010083755296363961, 0.010822633812495042, 0.02514140844141366, 0.01191077444673283, 0.03739808307727799, 0.05237279379798565, 0.04910453499178402, 0.07996276821359061, 0.033553231187397614, 0.051347245898796245, 0.04255752341123298, 0.03753380704438314, 0.01364525334793143, 0.0337645057879854, 0.03479110753687564, 0.04478965129237622, 0.025611071032471955, 0.05920546915149316, 0.005663366027874872, 0.03135611412290018, 0.021153771049284842, 0.06883392983581871, 0.02640460315888049, 0.0212969294807408, 0.06511657891678624, 0.04782651587447617, 0.01911139363073744, 0.027759117292589508, 0.025573564744263422, 0.06882887581014074, 0.13231476332293823, 0.04901413769403007, 0.038697008494636975, 0.04108250119315926, 0.013267537287902087, 0.015341141497628996, 0.04084580432390794, 0.015064383496792288, 0.022371891427610535, 0.03846591484034434, 0.005832579408888705, 0.044144880812382326, 0.01673905735515291, 0.025197509239660576, 0.02675952229765244, 0.017796018510125577, 0.029478664182533976, 0.03742658154806122, 0.08983517283922993, 0.012296540026000002, 0.016183698971872218, 0.058302446122979745, 0.08674806857015938, 0.030558071593986824, 0.0355022816802375, 0.01631166749575641, 0.02081607159198029, 0.012880535105068702, 0.08741626123082824, 0.023128659413487185, 0.0140357556847448, 0.035576648588175885, 0.03635516521171667, 0.008011023110157112, 0.04959435245837085, 0.030086657534411643, 0.022823072686151136, 0.037748699614894576, 0.016493322982569225, 0.0017892383834805514, 0.04424736769578885, 0.05907721119001508, 0.03148977120872587, 0.032505968047189526, 0.06665312146651559, 0.04432819128851406, 0.03657673340057954, 0.06022724322974682, 0.05137469794135541, 0.0602142556454055, 0.03918731206795201, 0.011386625228624325, 0.03951454353227746, 0.012118306767661124, 0.06688273453619331, 0.044181787816341966, 0.03237140554119833, 0.033218656171811745, 0.02916206398367649, 0.06743627280229703, 0.05436420608020853, 0.017669027765805367, 0.04472809385333676, 0.0661083628074266, 0.013217474788689287, 0.03687806020025164, 0.04996471012418624, 0.026667254787753336, 0.03617947659222409, 0.014686445720144548, 0.029688933173019905, 0.05936455221672077, 0.08134049858199432, 0.0811677637102548, 0.028037426382070407, 0.034176412591477856, 0.03005985858180793, 0.015673678390157875, 0.05762230859545525, 0.020469369883358013, 0.01236340567629668, 0.026659566137823276, 0.02634518124978058, 0.035291637905174866, 0.029342769521463197, 0.01092567823434365, 0.03262147591158282, 0.006557947126566432, 0.055832864381955005, 0.06260112873860635, 0.026328878120693844, 0.024026806531765033, 0.08573364175390452, 0.05030252461438067, 0.0458793652796885, 0.0449924283020664, 0.029350007316679694, 0.02783991862088442, 0.028234149322088342, 0.02798945024551358, 0.045295632735360414, 0.004646131110348506, 0.03892282547894865, 0.04376779186713975, 0.05260621779598296, 0.023827076038287487, 0.05077464928035624, 0.03248632710892707, 0.028687744415947236, 0.008677976384205977, 0.02938633359008236, 0.03209541937394533, 0.04079089281731285, 0.06560039983014576, 0.04337343685619999, 0.06166436767671257, 0.005558368366109789, 0.04173768400505651, 0.15061974670970812, 0.10970559800625779, 0.11664330580970272, 0.1289166323840618, 0.06636936872382648, 0.08646833084640093, 0.17625565000344068, 0.20398400898557156, 0.15161695569986477, 0.14739973121322691, 0.15210043522529304, 0.18112568242941052, 0.2056339813861996, 0.12158411685959436, 0.17266319511691108, 0.12499889417085797, 0.12338701621047221, 0.15180047397734597, 0.13981624360894784, 0.13125692086759955, 0.20496456418186426, 0.20956633990863338, 0.11511986216646619, 0.15246527502313256, 0.0814663668279536, 0.17572819080669433, 0.20873891946393996, 0.10571955994237214, 0.14253339468268678, 0.042159242439083755, 0.06770216947188601, 0.10936046222923324, 0.20388810866279528, 0.1670856139389798, 0.31115565507207066, 0.15679086791351438, 0.11127882491564378, 0.15195454383501783, 0.19259055785369128, 0.09845775624853559, 0.08667081099702045, 0.12276468827622011, 0.13165312382625416, 0.1730558802955784, 0.11166240394231863, 0.16094591526780277, 0.09441561182029545, 0.1583612969261594, 0.10876523752813227, 0.17135708942078054, 0.17334546631900594, 0.14065046212635934, 0.15110699634533376, 0.13440503709716722, 0.08267633471405134, 0.10971465962938964, 0.16842205863213167, 0.21147042367374524, 0.24034755304455757, 0.2034108483348973, 0.1482429148745723, 0.23028566327411681, 0.18178150348830968, 0.1448972983052954, 0.13131504587363452, 0.22599976044148207, 0.13372050976613536, 0.144892830576282, 0.09042018558830023, 0.11560857383301482, 0.09582918792148121, 0.1539424160728231, 0.1235471197287552, 0.1818332905531861, 0.1717899099458009, 0.13480742956744507, 0.22482810221845284, 0.04641758190700784, 0.14414976263651624, 0.17652484180871397, 0.11508567884447984, 0.09832755386014469, 0.1887297720531933, 0.1537388894939795, 0.07226571717183106, 0.11850524300825782, 0.1766725440393202, 0.1193810960103292, 0.08327139614266343, 0.12942507775733247, 0.1647295177099295, 0.22581392666324973, 0.14396204380318522, 0.16067437827587128, 0.08108871756121516, 0.19533801823854446, 0.12227090031956322, 0.11098934279289097, 0.22898044815519825, 0.17739475762937218, 0.08872822247212753, 0.12303128998610191, 0.23161528020864353, 0.16740273364121094, 0.10518879818846472, 0.11944654601393268, 0.15025726694148034, 0.1371033227769658, 0.1701450880500488, 0.1370037265587598, 0.13134961511241272, 0.1654181713820435, 0.16301448864396662, 0.16780349338660017, 0.12913130602100864, 0.15575104480376467, 0.11319427838316187, 0.24080962903099135, 0.12442557024769485, 0.09429468627786264, 0.13394508365308866, 0.26373084518127143, 0.11030957262846641, 0.07283147861016914, 0.11238164152018726, 0.1031490795139689, 0.10668305316357873, 0.0848359102383256, 0.0955515653186012, 0.16541581135243177, 0.2659598411992192, 0.15447017212864012, 0.08802991345874034, 0.13599832425825298, 0.11050371103920043, 0.11845321103464812, 0.15519091626629233, 0.08036202139919624, 0.092260682140477, 0.13920190860517323, 0.12116196099668741, 0.1318930007982999, 0.1278371043736115, 0.08869678509654477, 0.21566220733802766, 0.23400630190735683, 0.1343969180015847, 0.1875526664662175, 0.1353612053208053, 0.12378380546579137, 0.1511934565496631, 0.3566802997374907, 0.09981417955714278, 0.14191217254847288, 0.12813611567253247, 0.1103757722012233, 0.12517785566160455, 0.1298552710795775, 0.0667282119684387, 0.10548057354753837, 0.14160375081701204, 0.11859358084620908, 0.14376240607816726, 0.1446358545217663, 0.11516309226863086, 0.14385281450813636, 0.12899889203254133, 0.122175252326997, 0.09441809801501222, 0.18738651444436982, 0.13271215371787548, 0.2040506835328415, 0.13884276850149035, 0.16473152150865644, 0.1398252829676494, 0.11855368298711255], [0.025009799683175515, 0.009042157525982475, 0.03235903393942863, 0.03187838570738677, 0.01820613117160974, 0.006718355853081448, 0.04402048944029957, 0.03885674464982003, 0.034210918747703545, 0.14427002024604008, 0.05148585682036355, 0.03272044130426366, 0.03146764778648503, 0.05331207445124164, 0.019293475852464326, 0.04950073052896187, 0.02927701709268149, 0.020957335691491608, 0.04616905149305239, 0.045604377301060595, 0.03861253724608105, 0.04769435792695731, 0.044171445988467894, 0.032534447964280844, 0.05020819022320211, 0.06788550963392481, 0.03622605378041044, 0.037235088893794455, 0.0044834119853476295, 0.04321064676332753, 0.024586528743384406, 0.017499265195510816, 0.08464350103167817, 0.013514467445929768, 0.010922887759079458, 0.02650786002050154, 0.05467697679705452, 0.1027166671701707, 0.03324550336401444, 0.031070819568412844, 0.030488313423120417, 0.0547688064398244, 0.013596015560324304, 0.0287600796946208, 0.055635137687204406, 0.01607395759492647, 0.012020414706057636, 0.02035969344433397, 0.08263867814093828, 0.060058716335333884, 0.02608349812362576, 0.09370137631776743, 0.03506948341964744, 0.040948150199255906, 0.07287064916454256, 0.02176810048695188, 0.05536498108995147, 0.028945913472853135, 0.0331838754209457, 0.04518191715760622, 0.04307776893256232, 0.02221516282588709, 0.00948298211369547, 0.035242507728980854, 0.021741125274274964, 0.040385468673775904, 0.009422972980246413, 0.06483580218628049, 0.018741206658887677, 0.022346129626384936, 0.04609649913618341, 0.03911495266947895, 0.08040223096031696, 0.059100618527736515, 0.03216723329387605, 0.05011591529182624, 0.03268278102041222, 0.033977858402067795, 0.03925180099031422, 0.012277816567802802, 0.04641533691028599, 0.047385598518303595, 0.04071854826179333, 0.06346649519400671, 0.072920877719298, 0.054258231102721766, 0.037655341147910804, 0.019951792382926214, 0.05781615756859537, 0.04885609734628815, 0.043526463996386155, 0.03369099234987516, 0.01787896835594438, 0.08957394427852705, 0.021137970725249033, 0.01989278978726361, 0.06515016852063127, 0.07130019788746722, 0.011510766125866212, 0.0362213040352799, 0.022792136260250118, 0.015428542374138488, 0.054554889793507755, 0.05679150024661794, 0.05682431430614088, 0.0193904856860172, 0.02532111764594447, 0.032204978924710304, 0.053816942672710866, 0.02704677426663693, 0.024116752974805422, 0.02223382041847799, 0.0436549074947834, 0.028614793154702056, 0.03282764824689366, 0.03334960441861767, 0.04558405729767401, 0.07237020414322615, 0.026774791986099444, 0.03823861727141775, 0.0630341273790691, 0.05513333082490135, 0.04510579507041257, 0.023430136498063803, 0.0528692238003714, 0.06096757635532413, 0.038920120350667275, 0.12111289019230753, 0.04865891984081827, 0.022384018120646942, 0.03186186178936623, 0.028451925136323553, 0.09521471190964803, 0.030726349868928082, 0.030904637860658113, 0.033643327915342525, 0.042473241410334595, 0.05286695282848086, 0.07256094351760112, 0.027515449801285286, 0.011113919354102109, 0.06403880237485282, 0.019423943558649626, 0.04441826204129029, 0.05802907231554855, 0.035194219890399836, 0.09176805193419568, 0.007462987869075732, 0.00884651255546487, 0.034488470846554264, 0.012650495300476905, 0.043545318258111365, 0.032393310029874556, 0.01201574195874855, 0.05180928848858457, 0.013923554088250967, 0.061714440380455926, 0.030372015171451494, 0.048783667443785816, 0.03057539517612895, 0.03563701859093271, 0.03365817086887546, 0.053546548588201404, 0.017788725053833332, 0.009860910613497254, 0.04534973901172634, 0.03233388255466707, 0.06966489032492973, 0.020484956839936785, 0.061534499254776165, 0.013080201588309137, 0.03422407331527211, 0.0652342835383024, 0.03047765432711458, 0.02337116915441584, 0.0322893240081612, 0.03957060165703297, 0.010190190405410249, 0.012636871324502863, 0.01896657278848579, 0.04729113425128162, 0.022448618365160655, 0.03670151811093092, 0.028417398571036756, 0.02045360852207523, 0.08127942724968307, 0.13403314689639956, 0.03129756238195114, 0.01163645811175229, 0.03127907548332587, 0.07419438828947023, 0.06327803421299905, 0.0030022533655937877, 0.03100726018601563, 0.07769928459310904, 0.05136516505444888, 0.022271636553341523, 0.03318664734251797, 0.034404389225528575, 0.045545161337940954, 0.03797908080741763, 0.029609794255520683, 0.012074253809259972, 0.04167979277553968, 0.01274594476853963, 0.049491672616568394, 0.036032431162311696, 0.02874503636121517, 0.024434381048195064, 0.04125132123590447, 0.06873242629808374, 0.021427302563097328, 0.027084651628683787, 0.02231465699878754, 0.028728896504617296, 0.009835408563958481, 0.017605394168640487, 0.015416382284456631, 0.02802065013383981, 0.0116100970262778, 0.019678004828165285, 0.01070098838681588, 0.12890020123450086, 0.029845862154616043, 0.07948614613269456, 0.049224391841562465, 0.010962285596178845, 0.06886855844641104, 0.03665596137579996, 0.03457400707702618, 0.0126593491222593, 0.04737038449093234, 0.031189127184916288, 0.039624752462259494, 0.08854537954903208, 0.09684188553364947, 0.022171062555571552, 0.04432817273482215, 0.00942212600421044, 0.025436835167056415, 0.08279128596768714, 0.057970958441728726, 0.03485993431240786, 0.03736499813385308, 0.030731424303667154, 0.04289384618459735, 0.0628263111866545, 0.04655009237467311, 0.05993519698677119, 0.03063474843656877, 0.04808334349945653, 0.16369206947274506, 0.09384140474139713, 0.03457461563812103, 0.0349409063346684, 0.043734035280067474, 0.06587963289348409, 0.01570230673678452, 0.030872462048137095, 0.04455765592865646, 0.04377009623567574, 0.01834132635849528, 0.04920149287499953, 0.036353855321067385, 0.01193247484479798, 0.050635381558095105, 0.016730986499169376, 0.07070057967212051, 0.07432675032760017, 0.03816158976405859, 0.030889444242347963, 0.04843393777264282, 0.05187124668736942, 0.08112258175970055, 0.03752326483663637, 0.01745875877531944, 0.023316125916608144, 0.03801511578785721, 0.09743618255015463, 0.037658120490959845, 0.08418132114456967, 0.03323109827761073, 0.04581637549563311, 0.03287996594735887, 0.06036072962160688, 0.08393060881644487, 0.06400041107553989, 0.0651650337385945, 0.04936781930155121, 0.011819515329989372, 0.02409929766145069, 0.053005170411779545, 0.04202131058264058, 0.030830484320176765, 0.011355064470990328, 0.04811111466551665, 0.04424862934683915, 0.05753499121055938, 0.026213181008643005, 0.04303550362237729, 0.06201939999300521, 0.02990527849760838, 0.05981673537462484, 0.04915711615467444, 0.022486955858767033, 0.01845767841587076, 0.03623410979344044, 0.04382943094242364, 0.07387576944893226, 0.06876393788843416, 0.061501299278461374, 0.04903984568954911, 0.010379859231761657, 0.06529223785037175, 0.03065237444388913, 0.02131297100277152, 0.03398984408704564, 0.026947948026645463, 0.05680887392372824, 0.059433289934531786, 0.110844238079153, 0.004644153286790242, 0.026653829336282797, 0.026225608271488454, 0.034736337038339116, 0.04715306880825665, 0.04152217545197345, 0.04636397658032365, 0.037416521736304276, 0.006897027906234143, 0.03923877629858907, 0.04325149828218855, 0.0640892016235739, 0.032350551191484556, 0.05162874251254834, 0.04615116573404521, 0.020299241805332713, 0.0769333065545652, 0.06508530481369235, 0.01400856432155706, 0.032105831705848686, 0.016616469401924405, 0.030398238959605806, 0.01849484702688642, 0.012120951596443774, 0.01959739460289711, 0.04961040511261672, 0.019306984795548487, 0.025851456375676207, 0.03425276845518965, 0.0104640837162151, 0.02897711150581017, 0.13021043327171355, 0.10480714132427238, 0.09415499182068743, 0.10417752549983561, 0.09463193302508444, 0.08665483997901902, 0.11337671312503517, 0.11727297358447686, 0.12615087063750252, 0.21325237961718813, 0.30131308478303254, 0.1128062984207645, 0.11414481370593421, 0.10809988729306497, 0.2036720101023093, 0.13701946008950472, 0.1294070584117435, 0.11867835637531243, 0.23830584541428834, 0.15603617794113234, 0.287204590276815, 0.14913635677658021, 0.1176729540748056, 0.1379612009623088, 0.1332775069749914, 0.16554311936488375, 0.11079742340371013, 0.18148413975723088, 0.05744063084421214, 0.11335406277794391, 0.1347478647949174, 0.15181028516963124, 0.20292304950999096, 0.15857315040193498, 0.14487118955003098, 0.16095857630716637, 0.10987311557983048, 0.12492910260334611, 0.19516782893333584, 0.13615858362754807, 0.1536462249350734, 0.24641947878990322, 0.14295008091721684, 0.07464869398972951, 0.1300759709556587, 0.07545966102043167, 0.2864766918355599, 0.1803042585379444, 0.13655647868290544, 0.19443629396846518, 0.13775604165857658, 0.1866098865866661, 0.1406528815277852, 0.22864057420520112, 0.16417214996181428, 0.1330811792286113, 0.17267530696699396, 0.09774069316335954, 0.21656448079738766, 0.13870845461497083, 0.10203674857621081, 0.09694602369563654, 0.10171333546168171, 0.12639515596674755, 0.15069128974573687, 0.16118070110678673, 0.0719717747415416, 0.09320243043475784, 0.11272442468907684, 0.14307550387457013, 0.11549133676453494, 0.13840404048096389, 0.12666362046729773, 0.18021045107161626, 0.1303230319172144, 0.237753821129445, 0.16250595421297476, 0.1024460801272653, 0.08149562228936702, 0.1714823194197379, 0.10808038365212269, 0.1352922004298307, 0.15343315433710814, 0.09698495676275343, 0.09843258259934373, 0.13151115097571164, 0.09706659300718457, 0.1778204832226038, 0.19140565971611068, 0.16563955403398722, 0.11464622351923026, 0.09983032869058661, 0.1309892875724472, 0.1395187314483337, 0.14154642733046785, 0.15740156639367342, 0.09580708676367067, 0.17854155390523374, 0.1375903794541955, 0.11336604104144499, 0.14207084372173995, 0.14353989536175504, 0.18932001694338396, 0.1687229995150119, 0.11856944620376453, 0.12536178954178467, 0.1406139781465754, 0.12424284606822766, 0.1619270641822368, 0.1368558016838506, 0.13667207560501993, 0.21331613010261208, 0.15048267203383148, 0.11343463775119744, 0.16074967657914385, 0.17800392728531733, 0.14915971958544105, 0.13619269273476675, 0.15709722647443414, 0.13792177807772532, 0.1686022520880215, 0.13923517166404054, 0.13337938900804147, 0.18434615805745125, 0.17297330894507468, 0.14146165922284126, 0.09639636686188169, 0.2735811338061467, 0.12765607971232384, 0.2616972418036312, 0.09352252614917234, 0.13697196263819933, 0.2410308038815856, 0.21025180234573781, 0.11999136404483579, 0.14660357002867386, 0.21892885939450935, 0.18537210300564766, 0.14966200513299555, 0.08586536554503255, 0.11542710388312116, 0.12518909177742898, 0.136917503841687, 0.13521051965653896, 0.14611596416216344, 0.133392020361498, 0.1708111507468857, 0.11122087060357444, 0.0983591545082163, 0.12978488579392433, 0.10897697226027958, 0.1477953404537402, 0.1467871476779692, 0.11192851583473384, 0.18859529489418492, 0.11165254822117276, 0.2825284068239853, 0.10031970829004422, 0.1518167566973716, 0.11511896416777745, 0.1981778908520937, 0.1311717668431811, 0.12261482639587484, 0.11856739787617698, 0.136902185913641, 0.06457151597714983, 0.13463985262205824, 0.11802479144535027, 0.17522357491543517, 0.1882938196649775, 0.08430330795818008, 0.14713105891132727, 0.15997085196431726, 0.12432407413143665, 0.09293328315834515, 0.10077860788442194], [0.007518548754887888, 0.036266122333472595, 0.017440989904571325, 0.020844941136601847, 0.04128192740608938, 0.02241707523353398, 0.06094987242249772, 0.04430468747159466, 0.05540043719520327, 0.03072059636906488, 0.022121412876003888, 0.15583395754219964, 0.06545565134729259, 0.04929606104269624, 0.051709065155591816, 0.006991263035160955, 0.04594956131768413, 0.05101070048112888, 0.036037618774571456, 0.08568918710807338, 0.00575437513361976, 0.09878004129859619, 0.08744599908823147, 0.02039118277025409, 0.038691902518621646, 0.061905843977001496, 0.019295576130389236, 0.039485199013142847, 0.08112356139463373, 0.0534077595511917, 0.04264838826202322, 0.03141028719255701, 0.023994845942070242, 0.02470891075063264, 0.03380227368324995, 0.02774829863483319, 0.03424392576562241, 0.03381014415936079, 0.048136559198610485, 0.011192876445420552, 0.02456095433444716, 0.01791520742699504, 0.05201097454119008, 0.027704981330316514, 0.0733289698837325, 0.018757533907773905, 0.04111035028472543, 0.037312621061573736, 0.025929777075361926, 0.03740747495612595, 0.02192861033108784, 0.16580589901423082, 0.041935785484383814, 0.03794841526541859, 0.04077829114976339, 0.09252856034436263, 0.06856368418084458, 0.11198254418559372, 0.06760228381608613, 0.024916719521570485, 0.03883579382090829, 0.008490381860610796, 0.1714225171599537, 0.005873056143173017, 0.05341076153854374, 0.04291856341296807, 0.010448594166518888, 0.026308613778383005, 0.03146366245346144, 0.05122737791680265, 0.06108424568083137, 0.058729964002850465, 0.036114160175202414, 0.07015245908405632, 0.045706281598540954, 0.027742316924559418, 0.04621541345841251, 0.005124546405568253, 0.09657892034738325, 0.02214235999417724, 0.04978857250534929, 0.01065016240318073, 0.022016267248545773, 0.17804047063691542, 0.05109020676172804, 0.003450468816481589, 0.01398564216287923, 0.05793578064185567, 0.009555219057801878, 0.030393166380235925, 0.11400811010389589, 0.008948389022407355, 0.012260411349416245, 0.02043853179202415, 0.019886659647454508, 0.005423908833108726, 0.04865967683144845, 0.03182498818205204, 0.06780416282708757, 0.02446291662636213, 0.06064407047233544, 0.04897783182968851, 0.035861017313436605, 0.07582634876598604, 0.050048179473378696, 0.0670804204128217, 0.054850676460773684, 0.028755072053172626, 0.034582378502818756, 0.05636270216200501, 0.04630726165487431, 0.03776308243686799, 0.07408097328152508, 0.04737588009447791, 0.07921369629912078, 0.050030768688884564, 0.04616217178408988, 0.04135284332733136, 0.02088829925924074, 0.03230751404771581, 0.016869981482159346, 0.024041391588980332, 0.05835948759340681, 0.013056718180450844, 0.019619939193944447, 0.05409699951997027, 0.030402059164771345, 0.06719023600453511, 0.031795562026673, 0.06427128755603917, 0.022590205298911314, 0.036416581642697565, 0.025273386418120936, 0.01788677018339513, 0.0191217818428413, 0.04556034196866676, 0.04028025810839608, 0.021318993531167507, 0.02725203004956711, 0.048917450694716536, 0.0296899962995667, 0.053631001283065416, 0.025724764345795847, 0.0020531374002530356, 0.09916439215885475, 0.001816480421439337, 0.04825965181225911, 0.038300004016491584, 0.07624164718436077, 0.017381801771989558, 0.031608700373908505, 0.06896662584040314, 0.04635638069885317, 0.04298431769711897, 0.034337232282268815, 0.028430378733901307, 0.023485300334868953, 0.014595669927075505, 0.034184364703833126, 0.027499178213474806, 0.03983399357821327, 0.04267012947821058, 0.04426923507708125, 0.034025756613118574, 0.036051663919351995, 0.010683892087399727, 0.03583588077162858, 0.0061787551203451585, 0.02337355886993464, 0.11861916267662309, 0.021965617524983827, 0.028838305770477746, 0.009812275820877403, 0.08436776348389685, 0.03561947793059517, 0.03527257955283858, 0.0036310333462097333, 0.0344040515483357, 0.0107947123615304, 0.0506423985643778, 0.06195443980686832, 0.018593706663523335, 0.018444176894263364, 0.016709206320228986, 0.0724262956646271, 0.055842215442680754, 0.042182972611044534, 0.08950200048275292, 0.02111218109348556, 0.023332640557782724, 0.056763398824841715, 0.07141162393963896, 0.048619515509926714, 0.024915322428569198, 0.0452228874200955, 0.08107642017421313, 0.04717258729215246, 0.04481624244363047, 0.08435773706878535, 0.02699896511330735, 0.10359139952925034, 0.023614051824552007, 0.009738631579239154, 0.029340652545215562, 0.0539588895480847, 0.04564554423268419, 0.04295824975997675, 0.0036375528816279257, 0.01854140751675004, 0.04320066116633825, 0.029430897702695802, 0.06014986320224125, 0.05774729739641771, 0.015592556082992814, 0.012691200245171785, 0.013669775762537029, 0.027373669909138698, 0.04682612307078671, 0.03111302365141455, 0.03359746318892576, 0.031872389154159464, 0.04232367638905998, 0.030094236717559397, 0.048186720960075036, 0.023564691582578234, 0.02017339396843454, 0.06964140135096386, 0.06323052934021689, 0.03144085996609647, 0.03794348369410727, 0.08321300396346487, 0.06696564727462828, 0.018108260446751956, 0.03539303383149672, 0.09435373896849342, 0.05430312732642051, 0.06255438085645437, 0.02137245228368556, 0.07164390874095261, 0.015036179102025926, 0.08769701569690369, 0.032867360569071025, 0.052161738130962476, 0.04450000589713454, 0.01820918325392995, 0.03810022899415344, 0.019446426922513638, 0.013618010034406325, 0.07030644730548374, 0.04550849553197622, 0.012762374990415992, 0.04170393855019938, 0.07482725472073071, 0.009835998571361415, 0.03161234060826246, 0.030123957876639906, 0.053532904203166254, 0.03411861413042061, 0.013078474239591742, 0.03220777311071288, 0.03566436302207876, 0.04040637497382704, 0.10322169124265201, 0.04661312297685072, 0.024164460082829464, 0.035000864445464686, 0.03194624398020096, 0.03673238774354104, 0.01981045221327804, 0.0011620155214586703, 0.021146112085261848, 0.03550460089172702, 0.00321322322179185, 0.031290938713937066, 0.02432384186249692, 0.021588580530078616, 0.014998674669186585, 0.017627508314035367, 0.08409900954575278, 0.014769910430914024, 0.056984536568052135, 0.025649937306297943, 0.05111847145599313, 0.10575755048193969, 0.04044596113089938, 0.056450924967066385, 0.0776573087205179, 0.03709601041919086, 0.0835862077656202, 0.021276373845466878, 0.029041448287898675, 0.09344751728349365, 0.0384433053113753, 0.011980041872448055, 0.029077366380079184, 0.0786317337770015, 0.004592784607666545, 0.03997421124950051, 0.01846539118560031, 0.04005148366559297, 0.035133671772200614, 0.022497952631965745, 0.01871231484983582, 0.03818569100985769, 0.0254355994911748, 0.03488334536086768, 0.032386641832999885, 0.041510482915327884, 0.01926823540998157, 0.05604987578408327, 0.025527260295348242, 0.020174466371827293, 0.041499443468637764, 0.014893698808009503, 0.03904832265106961, 0.048392284734291025, 0.0305517911692732, 0.026288750195817556, 0.014089324831729755, 0.018419700863887556, 0.03542648242728319, 0.029414132586680353, 0.04101867649296764, 0.01462575937694055, 0.04102407561731525, 0.05849877015862148, 0.05372773281123955, 0.023239812726387754, 0.016031927916628774, 0.06507640646304935, 0.00666151615405397, 0.013344684466574108, 0.02863385707314592, 0.020868472784059122, 0.03645541080913972, 0.022937771609576885, 0.07363157317740843, 0.01602367337909527, 0.01930633170559304, 0.0664903165306896, 0.023638622478756588, 0.013751061342190951, 0.0015517325732616882, 0.05465771806484554, 0.007520143908550381, 0.07971365892444737, 0.04195724097371567, 0.08422304468695074, 0.036317545745987445, 0.036167349899187684, 0.07718266075244173, 0.053393614216474816, 0.16439385915873572, 0.12268170874449424, 0.08846393626299687, 0.10914877202594653, 0.13415487395832315, 0.12282880241400562, 0.1803326531080529, 0.0829170948418323, 0.2013785659801215, 0.14802785532083362, 0.08867545577231795, 0.25459812430199236, 0.08358671242604032, 0.13553384371334687, 0.2480594618828036, 0.13478899461915717, 0.10931869415799156, 0.2183382137445733, 0.14303216245025396, 0.24163752445019782, 0.13749955542152748, 0.23454021778889, 0.15757654997287318, 0.08184885489754379, 0.16002024931367487, 0.1296262294636108, 0.097933228535112, 0.13552661519497633, 0.15415354224387556, 0.15795271494425833, 0.12731630966300145, 0.1142579986480996, 0.13242540269857273, 0.1495831593638286, 0.09605289349565282, 0.25736686948221177, 0.15199965157080442, 0.11151681683259085, 0.1562928274506703, 0.06571096499101259, 0.14240411255741492, 0.1568398645031266, 0.10597055428661406, 0.14956888044252992, 0.1337053847964853, 0.08830062666675076, 0.10155064184800722, 0.1083827049296815, 0.14088652445934713, 0.08382138694287278, 0.1126008496794384, 0.24496228666976094, 0.08601494540926069, 0.10623600566759706, 0.290858302032575, 0.20090654521482065, 0.1311447229818441, 0.2227678705821745, 0.15280543098924682, 0.13980435440316796, 0.14744097978109494, 0.07603313337313011, 0.22590978245716542, 0.09536754980217665, 0.22968269797274843, 0.09602922640624456, 0.23035305028315634, 0.13585421402240172, 0.14476832788204774, 0.1655516985920258, 0.183116122498177, 0.1287561355275102, 0.16191127127967775, 0.14249407569877803, 0.0834141111408826, 0.10402589730801992, 0.15837903425563127, 0.08832548119244166, 0.18809235625667498, 0.09367580190883018, 0.11910420813364908, 0.18358705972786993, 0.10643884947057813, 0.16825427388539538, 0.19322135369293392, 0.24082043470116332, 0.17646374821197242, 0.20160763728199527, 0.2333468888537027, 0.165749644220341, 0.2299827037495561, 0.1054262557590846, 0.09244138767826371, 0.08451801870251074, 0.05999339991831221, 0.15979741205228493, 0.1358376641292125, 0.15341666381573305, 0.19390270463190973, 0.14632379519753158, 0.15239298983942717, 0.11576622826396488, 0.12823756725993007, 0.19664081395603716, 0.18685601244214922, 0.12777169147739187, 0.11027206448488869, 0.19863915047608316, 0.1444541322416626, 0.14363233727635816, 0.16611918923445046, 0.12294963889871724, 0.24398404697421938, 0.15040418249554932, 0.1441740753944032, 0.20314708905061707, 0.19859402789734304, 0.1391781005077064, 0.10155720985494554, 0.23398445307975635, 0.13863950909581035, 0.11662516772048548, 0.17576457088580355, 0.12537262489786372, 0.07230666145915166, 0.2231240866240114, 0.06998920885962434, 0.11039163931855, 0.08290666766697541, 0.12970544630661607, 0.28647847298998386, 0.15580372244585305, 0.08913062236388214, 0.10220709373243153, 0.07405539887258783, 0.09723434064653702, 0.11838439910206944, 0.09545181324938312, 0.09081769472686574, 0.1408962465939112, 0.09017273870995268, 0.1613798935431987, 0.1313883700640872, 0.20201469043968245, 0.19896006997441873, 0.1205502383527346, 0.1793089642887935, 0.10810681153088808, 0.10209241707343608, 0.15335497650085017, 0.16156379773747176, 0.12875941582024097, 0.14781515579670668, 0.10055008577182889, 0.13581102102762088, 0.15377215255284682, 0.10499795491341501, 0.0796732192975469, 0.10102579501108266, 0.09276681943447329, 0.18969039316289127, 0.13031562528340146, 0.08576586580602452, 0.11268333939369768, 0.1338670394034125, 0.0864561002526898, 0.1035654688894283, 0.07146070958697237, 0.06129445529950317, 0.17646511376369745, 0.0893996212107595, 0.22593832545680925, 0.09182893772958778, 0.15259381500072777, 0.2653281844686717, 0.21731387183535844], [0.08699558224179782, 0.048140589060494676, 0.06862508205813356, 0.029343005153350532, 0.01885566995042609, 0.02883745044528041, 0.017503456474514678, 0.023656960947846528, 0.04909600771497935, 0.0801367944222875, 0.051784701136057265, 0.025406919194210786, 0.0669055555772502, 0.0032298888436343987, 0.032939026059466414, 0.06107237502874341, 0.021838589673279785, 0.03323364013340324, 0.039339181457762606, 0.02614661592815537, 0.007585130533698248, 0.020024261248181574, 0.021878593288420234, 0.024951010454969946, 0.0419350359152304, 0.009495273934589932, 0.01151772468801937, 0.029899205874244217, 0.046825362369418144, 0.05966675846138969, 0.017927065091498662, 0.0799496247782372, 0.05672606137522962, 0.06318471656413749, 0.02395860501565039, 0.029105297107889783, 0.09035097289597616, 0.017239261178474408, 0.0235192406034912, 0.023412822192767635, 0.0817752412694972, 0.03239892437704839, 0.07299628734472208, 0.007059914014462265, 0.05169031850527972, 0.03413052188989241, 0.04049865732667968, 0.03742409164260607, 0.026399332055007108, 0.027935807811445557, 0.01832839257986052, 0.13319126941496506, 0.0491177749063354, 0.06787123071262613, 0.04745761281810701, 0.03497130470350385, 0.03737377031939104, 0.026874352952290792, 0.031745444794069044, 0.03710722427058499, 0.01479693666624371, 0.03811965470958967, 0.07123377567040734, 0.09080719333724119, 0.02357451947318623, 0.026915243433904834, 0.042989078574464656, 0.033868013124447316, 0.01852192057413049, 0.03377285866008606, 0.0024904467591113644, 0.032482141396030784, 0.01500884765846422, 0.11080569092882797, 0.04450756467122119, 0.0741432246286422, 0.06020432570949197, 0.026850094000110403, 0.008396505745622562, 0.0036345367470858037, 0.04679122728703078, 0.0799158273730427, 0.040341277490369976, 0.05179128398594912, 0.053063855739310384, 0.02072123625111999, 0.03477103244222235, 0.050863083597505465, 0.025321585198980756, 0.10709384674555622, 0.0329122271068627, 0.053326583438320085, 0.04935487624607049, 0.02177737362217158, 0.034788632474374026, 0.08397283701924607, 0.06333997385809198, 0.04498064299696125, 0.056999639273271896, 0.024333831170224585, 0.04875162892858498, 0.008954304867074825, 0.07213195989606902, 0.05561630940064788, 0.040588809715700336, 0.06417570635676384, 0.06743290345184505, 0.06030453791026957, 0.02781502884317888, 0.07098149741068482, 0.00455407464869495, 0.06275798165006563, 0.02834710419847397, 0.04352535448560957, 0.024325146187038627, 0.02899970433645649, 0.09921387856593356, 0.032266673661069945, 0.03267215346568264, 0.02058816546195885, 0.051809340438921936, 0.041690286743687466, 0.016661833178659435, 0.040309739924850874, 0.003589786169868603, 0.019503225339576602, 0.05933741558692418, 0.06528233760036528, 0.03873068344546482, 0.015741662828077096, 0.05902049255382735, 0.05089391612273175, 0.026123058305529412, 0.0445995427435264, 0.02954894556751242, 0.03163177374517545, 0.021682029910152778, 0.04567343043163419, 0.05024025471357163, 0.02692291538551217, 0.0592816394782858, 0.0473768560186727, 0.01824502156523522, 0.006186567616168759, 0.019509194062266033, 0.012112595941289328, 0.0687462228233926, 0.026954822169500403, 0.055999665783019736, 0.08001546069863252, 0.03604311066737864, 0.04187510749034118, 0.03432707228057552, 0.014408297120098723, 0.03334499939228408, 0.056347862919210456, 0.06578011089004576, 0.051106129540130496, 0.04137929718126543, 0.032114952700794674, 0.029213030975370202, 0.03802857834671158, 0.03551483510818798, 0.06622385582886636, 0.022667255070700776, 0.029599543340737, 0.029418231097224634, 0.018268946550961118, 0.030540159859810956, 0.053331240414991044, 0.02961562011478236, 0.023542165545222815, 0.023582306457683444, 0.04221964212774765, 0.029862317423976492, 0.08110531940474175, 0.03767009133298416, 0.13164099713321775, 0.024643011747684795, 0.024064301687758416, 0.043847175693372265, 0.03481356492557097, 0.03270687855547294, 0.03723220565007068, 0.003605529905144067, 0.037182426094659604, 0.02468805825628806, 0.09253276090021245, 0.044310049488558434, 0.05359828741347883, 0.12237695322255604, 0.015101754343049834, 0.02070156748231966, 0.013340389286895515, 0.017153658154711593, 0.019591086347645614, 0.01952883871126687, 0.043604166858131066, 0.031137770565692335, 0.03484934757580049, 0.042389664449729025, 0.022006424514984246, 0.0032141105521077407, 0.021297948078426998, 0.052061117748962715, 0.045374382025329396, 0.07055203881463967, 0.07073865184793249, 0.027378668273740914, 0.05566699066548608, 0.020634247266571037, 0.016800251141830813, 0.02663528677658178, 0.033337177155772224, 0.05377109278924763, 0.011928155545319896, 0.035340441536391154, 0.018548157349869143, 0.09181396118947305, 0.06587944735656492, 0.029457871060003527, 0.04758732538903132, 0.0530824205634417, 0.01677400323387701, 0.017964328326343093, 0.03723869573150296, 0.019347045927133877, 0.018948315955640282, 0.054895891807973385, 0.036545088223647326, 0.016754477328504436, 0.028890552966913674, 0.05162589266547002, 0.026082544463861268, 0.10073091005324386, 0.030176871150615625, 0.034875868223025464, 0.03151274439005647, 0.061698866411461495, 0.08785533063928597, 0.07405361771816388, 0.044828101963503286, 0.032838925180840306, 0.017367905056744348, 0.0169277335589868, 0.05362539806810673, 0.021571412798948586, 0.03144701608107425, 0.04433810638147406, 0.037691732359235175, 0.057889663585228845, 0.031989236595109105, 0.022811020207882393, 0.04892584438493941, 0.024621485754323658, 0.05231783405179158, 0.0033050299043679843, 0.04417976175318472, 0.02253209699119907, 0.03490884926577564, 0.09054401292814873, 0.04276970343198627, 0.03841812795144506, 0.022133585953270085, 0.0681749323848635, 0.06342483844491653, 0.050524411926744506, 0.04925858629576396, 0.059938380800304, 0.006973290073801763, 0.021552693979174364, 0.05000429257052019, 0.016487604734720662, 0.02480520255630836, 0.026669514627428725, 0.03965302086726297, 0.06383337589795701, 0.008990479000203777, 0.06290165401878767, 0.06262980532483198, 0.06337549304589629, 0.01239116107171867, 0.021509985235752538, 0.07280182238901034, 0.011745060292014387, 0.03477701044175774, 0.019981365112471394, 0.056080752838170156, 0.032200136411120184, 0.01749039838614408, 0.020257440337445587, 0.027650854644889478, 0.08656414953293279, 0.036822651454713196, 0.0129368613306724, 0.04715266062703449, 0.050581490504555404, 0.03457283819443546, 0.010898667769652093, 0.08689998619956896, 0.025787301419768482, 0.07565903157228604, 0.04010980163002387, 0.06906044072820805, 0.044208813123987056, 0.021564425478572957, 0.04064935783389956, 0.06557331886142492, 0.04667801265895832, 0.029602133436128497, 0.07054658402921632, 0.021405644838523585, 0.04210397841234226, 0.06840226706117392, 0.014648343858425505, 0.05810362104966771, 0.019590913798310794, 0.08356193211511709, 0.0187915075730416, 0.013253709221316967, 0.03305205515061971, 0.04321714797697496, 0.0760397755948361, 0.04317484184866771, 0.06845901909400709, 0.0362163687532302, 0.05512924901267979, 0.015935602714307606, 0.05837896896991879, 0.009068726412806427, 0.020145068046986125, 0.08226996433222666, 0.0512441430328181, 0.05362414012779482, 0.06766445352695882, 0.02237960790807847, 0.0632960164512042, 0.004097644086868968, 0.09017748103360645, 0.0464744489727309, 0.023580311935802456, 0.08251186736742966, 0.051556895195972174, 0.019336431359988637, 0.059216259978711605, 0.052715855272253975, 0.019388003202038817, 0.053476604880415834, 0.009198183870466892, 0.04505916222115047, 0.0850489956792444, 0.017594979981367942, 0.2620175527408719, 0.20498276164289564, 0.16555457812501118, 0.11392115266062319, 0.12814822752261534, 0.12468806788092479, 0.09552739356877282, 0.11380332929547876, 0.17526894982438534, 0.18661983136553317, 0.12188881300971843, 0.1151617564028129, 0.17832921061199158, 0.09150260797468945, 0.16570052888710052, 0.08503700999426655, 0.1336271921172738, 0.07779686959111132, 0.17321219143923372, 0.08363248809473589, 0.11347351886797696, 0.17420652089640498, 0.11206763141672127, 0.0894530038931407, 0.1304633720428683, 0.0849844362528529, 0.11486548362881877, 0.08884854687494226, 0.11414582302677445, 0.2215956780128181, 0.18214199430076405, 0.1563491119304672, 0.09057411443791352, 0.13883448613341898, 0.1554935789317824, 0.11685218327329494, 0.12250925588887185, 0.09770488453796133, 0.14867515652440488, 0.1142507181793917, 0.22820337500888854, 0.08400267135584727, 0.1849409003625624, 0.1515543629648164, 0.153993075073231, 0.09865525658824481, 0.13296795717906207, 0.1292551853111945, 0.07568180808448233, 0.13878823549021035, 0.09516825346508995, 0.1795339834643528, 0.09045379003509879, 0.13473619823344052, 0.158949478645809, 0.14505317900329828, 0.12515369133325294, 0.13458834757329896, 0.17035875236615539, 0.12161012913566083, 0.12061129484209232, 0.1734323421260342, 0.24752808414632455, 0.2683366136625409, 0.18702574161579832, 0.15956091927364469, 0.1250277934013866, 0.10807167825987563, 0.05630315594316926, 0.153244930843357, 0.12201931225717999, 0.09293962109950371, 0.2433439891319722, 0.09191309727611952, 0.19018810708075762, 0.12333966718870215, 0.1180847198702395, 0.12184026913018897, 0.11381736330804415, 0.15072815964231268, 0.08790685795247555, 0.14969546115025878, 0.16493807605002075, 0.14006170153152198, 0.1360606646630913, 0.15424111566971987, 0.09968208469217643, 0.1018017326714471, 0.10847366254893132, 0.21084771724417806, 0.16184299369342625, 0.1699918048689142, 0.13541959750000387, 0.10309922945452854, 0.10724664753070101, 0.2527928352355957, 0.1279445376712829, 0.1281477970769629, 0.1874275106820278, 0.10875615364057012, 0.15958649368258193, 0.10616051440592855, 0.18424651731038466, 0.176404747471679, 0.1616776580340229, 0.2499317965703085, 0.20027717429911718, 0.1400431478396058, 0.08908925505238585, 0.2575334074208513, 0.10465278202900663, 0.12536138878203928, 0.16064445488154888, 0.2016699776868336, 0.16450179711682722, 0.1888740752474405, 0.20080837392015383, 0.10330834440537728, 0.12870353210018948, 0.139819924661424, 0.17860902997199446, 0.1556571779656224, 0.10067641414934769, 0.17549604701343924, 0.06637690152274445, 0.16730169765651226, 0.18497926939744502, 0.18802623089868575, 0.14330251200590283, 0.10779091637232341, 0.12118465587263927, 0.16413824865594506, 0.08773994151852094, 0.11925057449843735, 0.1792247305274941, 0.12939965177793056, 0.12396784324664623, 0.10547304817009717, 0.10477566684130579, 0.132839031284675, 0.15709079947555438, 0.19378332275664434, 0.12833035056246445, 0.17322329396847636, 0.16502407612279058, 0.1137781556462869, 0.18431360746035352, 0.14686260925373062, 0.09755166072864085, 0.13525170885259286, 0.299277551821433, 0.10422714549349621, 0.13057870179181919, 0.07045012709568255, 0.1082323161244858, 0.24758071725955233, 0.15662001067539677, 0.15489772340515628, 0.16032696410547942, 0.09692127307062037, 0.1317099278094247, 0.13198649656260386, 0.1656772254500538, 0.1655907355598174, 0.06517341258586384, 0.17252803518204018, 0.11510064796311781, 0.17041082144714892, 0.14123071770882234, 0.18421102780848742, 0.05956153305305634, 0.16991818381939083, 0.15826355607714504, 0.1358093586168252, 0.15743785741506144, 0.16014319349778816], [0.08833074301946908, 0.03448239265708253, 0.0929625757271424, 0.07095756314811297, 0.07877585143432952, 0.007030484612187138, 0.02070162314339541, 0.0464005273533985, 0.07179973006714135, 0.01801722861273447, 0.017099598262575455, 0.05881468016013969, 0.07016811840003356, 0.014207319818524411, 0.0012213228615109983, 0.05068032602139283, 0.043658009672071785, 0.02161008054827107, 0.07729312201263383, 0.025340624997625127, 0.007771409600536572, 0.028937113456777297, 0.01733344528474845, 0.04926417466776911, 0.029515291025745682, 0.03491513154585846, 0.015274130200850777, 0.03207272820873186, 0.022381259186659008, 0.05291188987030182, 0.022802108869655058, 0.05818784367875196, 0.03950881044147536, 0.06931059644557536, 0.07336327937082388, 0.07459253567503765, 0.020686002790171187, 0.024375582543143537, 0.05667529105267022, 0.0063882392896630336, 0.013902285991207464, 0.020700459826912265, 0.025878034539346118, 0.010101524167112075, 0.06655561810475774, 0.04213685926515609, 0.024344377088709734, 0.0167331943885074, 0.023356890233117156, 0.021705953040509485, 0.048114020173670724, 0.017287779082835186, 0.014256686554290354, 0.11116084569948725, 0.047908456399454735, 0.0037173080136199133, 0.03154281621391419, 0.04398333010612987, 0.01918255446071271, 0.03427994219237007, 0.03250218309403863, 0.036311051953816786, 0.04223688963975292, 0.016710315831005573, 0.03437484061578289, 0.05039038376708049, 0.032846521062310785, 0.024348798433493357, 0.03011003147548763, 0.056526000626035966, 0.0792615425598342, 0.024824290594551712, 0.034943314603879116, 0.033598687732592225, 0.027050074968428817, 0.03132993857434485, 0.008954520089901052, 0.04518746842222754, 0.07587038038764149, 0.07347751074121334, 0.004634241904568626, 0.017505480682302732, 0.07970468635903671, 0.08094301912933588, 0.04596209619194269, 0.07185438924352638, 0.013147674872016069, 0.04776816080266144, 0.025624739537306596, 0.058016184921143577, 0.026731882862804923, 0.025214780871465337, 0.04071834046044387, 0.05316596412740182, 0.011831616975541692, 0.023764722645864822, 0.07306903265998699, 0.04876267208601348, 0.038948648507357575, 0.06414792034775019, 0.022117483204056043, 0.02306744336237898, 0.08187029554392211, 0.008110995040624402, 0.04556051266263239, 0.049543890127097256, 0.03530947171384469, 0.04935286873660516, 0.08311177502037026, 0.024069671126198955, 0.02849523130862508, 0.015423079239553772, 0.035674445098266006, 0.055344056236208417, 0.014054589537408901, 0.022832731738162693, 0.04707456442702096, 0.01777194509486435, 0.07834188800188713, 0.011619351607805584, 0.04917988153465558, 0.03315757741802372, 0.04421657598868478, 0.006747955021637608, 0.015563091892545344, 0.01651422557188198, 0.09280944839701988, 0.03280395147157833, 0.046078257146291435, 0.03142443623801228, 0.04072739837283734, 0.05065243982244283, 0.09045820581377484, 0.04317125727538951, 0.07510340787121095, 0.031030027421365958, 0.04360955113952514, 0.027245031596976332, 0.016398886546085123, 0.009910084390867269, 0.05666596596711315, 0.049763268980314024, 0.06887092589749955, 0.029779007636534516, 0.020301802214817144, 0.036510797290247865, 0.06905018424731679, 0.026125188269361388, 0.021908464732405264, 0.03801575774559751, 0.030432186649704818, 0.036388751104823314, 0.053769215155625716, 0.04823516836040653, 0.04933791817165911, 0.05124945681018289, 0.06146737199742347, 0.01654709343711147, 0.032572835552855395, 0.013160182843421353, 0.04145869956118986, 0.11691261635860428, 0.034499695830163546, 0.018906273289758246, 0.03666844429972116, 0.06765314319636673, 0.03707000185386278, 0.04590817174175754, 0.013048788332525874, 0.020375924214022234, 0.04004596950835548, 0.02708551437535789, 0.1037711402750574, 0.043139166809851304, 0.021542676840908825, 0.021426578969112597, 0.04655646000173874, 0.02887229056796059, 0.08918444291339256, 0.057089906695182435, 0.03924221615307033, 0.024414530453213956, 0.04040893538331147, 0.024743743451836053, 0.09087207930861041, 0.05639251052343752, 0.05477167484059464, 0.03026669885002775, 0.05901953518332448, 0.031063123497006018, 0.010605864536046283, 0.02501637882232899, 0.07381612304016016, 0.061676249461015686, 0.0053267334078554995, 0.027794473207904957, 0.005007750914955977, 0.07932178268674761, 0.017439269977330696, 0.05605972037301399, 0.05268434739264194, 0.016618393419776112, 0.02547301115555456, 0.06524636570247822, 0.04054573546454776, 0.03091965707426425, 0.038484765391331166, 0.10362913031713106, 0.01222803330165334, 0.06483260352979414, 0.025313974474556744, 0.04020746455353219, 0.09271528469980694, 0.13981854426674545, 0.04074555872648489, 0.08744971724809147, 0.019345274049555883, 0.07071398285916075, 0.0626054777239915, 0.030050006571400445, 0.043366341924411245, 0.0435824256419437, 0.029811497006448917, 0.02675500261830166, 0.044984550404478796, 0.019851767574436963, 0.025759580348676536, 0.02030805109825451, 0.051325419335626066, 0.04266281932359561, 0.02722812547290232, 0.028959993869648315, 0.03144751703075599, 0.015443581996805733, 0.030972405220381916, 0.052095327046117745, 0.04715101305919234, 0.0626859487965703, 0.04738594732771162, 0.022311632747005206, 0.01913210882776184, 0.02438982806779677, 0.09368915314553306, 0.0368150147551205, 0.0856698838470038, 0.06437231611926109, 0.05854089446074795, 0.03509926580591127, 0.040237443608930334, 0.09092237465665676, 0.027604045535554178, 0.019925108463212382, 0.024584567618148867, 0.016330640501109883, 0.0285382294896408, 0.054739936895202845, 0.08940602594520897, 0.05262291982944589, 0.10084510431624949, 0.11128109588753432, 0.03290435292001348, 0.06744055499439128, 0.03634971784777008, 0.04726706269138958, 0.026087880505656358, 0.046287620716611855, 0.0838005103287287, 0.02013443678151816, 0.03294978349003941, 0.0260417040772154, 0.09173101134365425, 0.04948213972966187, 0.061106317152734846, 0.04691484311479144, 0.03814292103925254, 0.022882988123456016, 0.03981190355261788, 0.020285794089431874, 0.053682135257986374, 0.045010232424829155, 0.04899756924714893, 0.02330018087377539, 0.038019550120225176, 0.046098295133560896, 0.04787556441442575, 0.02270260356453946, 0.030385464742721524, 0.05618384457193315, 0.01040038147039013, 0.006808320849813754, 0.026685869706852827, 0.044495360052678734, 0.11289859190583229, 0.09126197401201352, 0.06109206791734323, 0.034604297834448516, 0.03339914277603384, 0.036988877691328526, 0.048482451966265216, 0.052361323905643076, 0.0667246051307302, 0.03447458897426259, 0.0584244255151134, 0.06603477144381031, 0.024579734381404705, 0.013380240761762252, 0.049305193169857375, 0.010484936210559681, 0.06893264289828949, 0.016447797788714524, 0.021081693666928913, 0.03373109801032115, 0.07309172011446208, 0.02938253750471631, 0.024558822515245993, 0.024382979900110513, 0.014543414381478215, 0.007677295998291811, 0.0157913700240897, 0.030297512821562123, 0.04077987192431465, 0.012863265328633133, 0.06983835992286913, 0.07983822099049576, 0.007266852617249242, 0.05489849303558003, 0.03696618652611505, 0.04291473393095657, 0.020112925631110556, 0.007623097881150898, 0.053475539898499846, 0.019038622340303846, 0.02164920100767631, 0.03643283467681613, 0.07997853143024258, 0.026686782548495103, 0.03481288214970846, 0.042409977031638846, 0.06553710947628133, 0.027930353026022203, 0.028575680116773583, 0.055529455858049914, 0.06443695718189701, 0.010799279352795566, 0.028605614643311128, 0.024825750770105515, 0.021124799459357746, 0.05457200371893123, 0.09270923619624227, 0.02655666550708702, 0.038733637193217874, 0.0711709083407186, 0.16618855035630986, 0.10208634630544111, 0.17374350980389863, 0.148675438540522, 0.13051091402303427, 0.09090806604945101, 0.08934139972552657, 0.0770638206449803, 0.328129077097401, 0.12934219470480457, 0.07247194516821764, 0.15311483235564083, 0.2808064757846296, 0.10585079391603358, 0.17991132102906704, 0.1564784682705067, 0.17639037949265912, 0.20825211511692032, 0.09075191075680777, 0.11895044997800142, 0.06180363168823533, 0.19761558040045202, 0.12073884776327759, 0.12679780076723546, 0.12105432731914334, 0.09230785304680467, 0.06063194006856065, 0.2269516687374562, 0.1274181916960515, 0.12725104519631714, 0.11317942800815217, 0.2297682230710052, 0.14405625202925876, 0.18370964768109843, 0.2335123877855949, 0.14548962120898068, 0.1857410988304764, 0.3430690144887194, 0.18578446994069964, 0.15472446160856634, 0.15828645875444636, 0.1420685282209888, 0.1306115640909411, 0.15806011855602264, 0.12467119144275784, 0.07720278779743239, 0.09670290353824385, 0.11815085264970548, 0.1340376739972271, 0.16666511306539178, 0.17717171256663278, 0.14047101081814617, 0.12794099020538852, 0.23030112963169813, 0.09519175728200935, 0.14460950827924535, 0.10725101878051646, 0.10572958635748364, 0.15936999436235055, 0.11636468130745925, 0.1559189334511757, 0.2691272977972403, 0.175152966985479, 0.09817154699703678, 0.08944721514126286, 0.1361659012036398, 0.1955576939508319, 0.1260640542022884, 0.1853518869029358, 0.14813178568147123, 0.09852644943748601, 0.16918286390136927, 0.14538907504174858, 0.1556046339101158, 0.08126988323056139, 0.17056321405107155, 0.11929386397241615, 0.09000686128274538, 0.18943659350043163, 0.16856892965734005, 0.1484423002693802, 0.087332435650751, 0.18012376822298393, 0.21420798380859196, 0.1623718926566653, 0.23201357602374628, 0.09420224436325952, 0.1337139937095344, 0.1915093229035847, 0.11405640907469206, 0.1389040847425349, 0.10975382276228629, 0.17877427657367662, 0.10468789303558879, 0.15442389179952443, 0.13938426913227886, 0.11208160605747253, 0.1629712659632787, 0.14135523524601012, 0.124945726711303, 0.09630401400499977, 0.12229470099555328, 0.1793203636771068, 0.10148747023777105, 0.17708725616103038, 0.1993954138015397, 0.08427846827544272, 0.11155665531987324, 0.15602848929120228, 0.14707104885019362, 0.10769810338388197, 0.16367341188015416, 0.09216814374667592, 0.20186311419820413, 0.12880162918008864, 0.08524769829818979, 0.17357766948407516, 0.20089758007088676, 0.11806300462922081, 0.12399818224366754, 0.21263814851408824, 0.1182137496653013, 0.16359164204914123, 0.16918878623982891, 0.13220517779700458, 0.09972990868845955, 0.2234336215769872, 0.09420767688425258, 0.1599373811041005, 0.1509673538384959, 0.1344014599453658, 0.18939225759822875, 0.23759976611472666, 0.1233017211779952, 0.23715118237305433, 0.14805782324401662, 0.17929115274455398, 0.16026122466428205, 0.15502406662562862, 0.11434408777859062, 0.15855474513955414, 0.1436298733460717, 0.1591836113948375, 0.12789399741450325, 0.1431170938303694, 0.1605896546971053, 0.15993570385035127, 0.15241800021613017, 0.1592812780290842, 0.1697139150928706, 0.14938160689780489, 0.1936665829271078, 0.18323192722164094, 0.09665093093644828, 0.1243693451397121, 0.09777316212421283, 0.1318837536382489, 0.12496576469857246, 0.12695666489889845, 0.08108016801998019, 0.05330983687599655, 0.18097882624715567, 0.18696870014537126, 0.07712452832493, 0.2235835205647163, 0.1094659065711312, 0.09372183732921258, 0.11825010747998022, 0.14974865829572082, 0.08078750950517133, 0.15445602679392323, 0.11419899790780619, 0.2266924365540035, 0.12693296070210636, 0.12188477572635747, 0.1401435158913955], [0.05267710774205625, 0.06770729771233164, 0.10498729767277837, 0.040381097423960455, 0.0303574950521579, 0.027085074652859475, 0.03882233868353069, 0.048271926934830844, 0.023316170445468742, 0.028288214780332055, 0.03733160519914236, 0.07343605437199585, 0.017984321784751955, 0.021256382242427208, 0.029126446461305022, 0.034823724927264266, 0.020414174505276605, 0.03359502152306959, 0.07311456341994926, 0.03467590766376816, 0.02407799802313093, 0.023961683073139284, 0.03927970945369452, 0.08583323797211051, 0.03132711470243521, 0.0852436684363056, 0.03260071433032863, 0.045360244112089276, 0.04072578791237902, 0.018742100946838036, 0.12068502721376717, 0.03303389479697216, 0.037752610733150505, 0.040963824358186685, 0.04871558652666863, 0.06657377845840529, 0.015248998297465732, 0.06293757396633737, 0.009070313681149855, 0.03391792626644019, 0.029285299460752867, 0.03636086119513493, 0.024172837074729614, 0.04833603736187797, 0.057714416543603875, 0.0076716292369383154, 0.0599688348302152, 0.055885605106595904, 0.04272750491509214, 0.03832956004771404, 0.022736497448931914, 0.014645545033999952, 0.10547614292590879, 0.07453336424077861, 0.029202661316958256, 0.05132705206051469, 0.008492095294059254, 0.0740315017173998, 0.025616835664550308, 0.020386056385177653, 0.05966638738755137, 0.01599601539055584, 0.010581383867247496, 0.05488569840963464, 0.01927990568219684, 0.05029046100389678, 0.025314111771876924, 0.03159947918902617, 0.045897228774265386, 0.04231977269228082, 0.011003712279489264, 0.018945968913612887, 0.04335084588092286, 0.05063907003204804, 0.033228675165446475, 0.02351269115024479, 0.051003212211071514, 0.02723213121498702, 0.07758791791275144, 0.0065736036594898906, 0.024031183347688057, 0.021445657730509993, 0.03128346157609485, 0.06772035951144062, 0.026897058960457798, 0.006635353129240684, 0.02283263711433392, 0.020059071684954688, 0.018314406806894112, 0.04720305616501719, 0.022188992843439337, 0.018231084031867795, 0.030646505911136046, 0.0641920707130339, 0.009320205008407356, 0.03504147847706918, 0.0834885633958038, 0.07599218166433275, 0.02088136759994086, 0.021846862764505204, 0.015392456371046137, 0.030904918021406047, 0.03727336516021751, 0.06047864204447251, 0.0728812618763186, 0.05726681243686471, 0.018727976021182258, 0.02219568701548269, 0.030814570818620268, 0.08430189787759446, 0.02515709558792878, 0.03047455957130296, 0.043570462221396156, 0.09460681874770671, 0.059404038183856755, 0.03967095857660752, 0.0510860767099075, 0.028771503202733584, 0.05388334262534045, 0.021581363143923227, 0.049841224172268994, 0.06354442812153138, 0.03554390503268223, 0.03855318027490284, 0.03099572721112054, 0.031248818122548983, 0.02158543939003721, 0.04035480313177686, 0.027909216660191305, 0.05290102482831571, 0.03456228856521193, 0.04199809249257669, 0.052324520802358165, 0.03993524478573818, 0.04345678746176418, 0.0034032603389277938, 0.011603572620515479, 0.041784524655668065, 0.02997758780111326, 0.018946564487123396, 0.056424107460770756, 0.04484459990635514, 0.060590928987949155, 0.09813090699026361, 0.03808156769082416, 0.047406656958628446, 0.05433821977931075, 0.018648067125468515, 0.0333138551650336, 0.08145547210006043, 0.0554575751448283, 0.057216428031097166, 0.01239123435880174, 0.05045627163781319, 0.03479072162008379, 0.04485733144974802, 0.03440677151957061, 0.049232332821702585, 0.03933770458388608, 0.05816967961436603, 0.025742731741047464, 0.030143706426315475, 0.07915855472674593, 0.03648816920758691, 0.05222784493525978, 0.014536910384777002, 0.020234524672559928, 0.051024548956775106, 0.04490691804676317, 0.012442484294297174, 0.03722156325238757, 0.01825227605877444, 0.0686609055264853, 0.05181339998671319, 0.015379086580651347, 0.031431631359737366, 0.054180517108761705, 0.0863391080929432, 0.06380703707691282, 0.023161768476711586, 0.0454244881257182, 0.015868609043536708, 0.03371316401171498, 0.16641592956148088, 0.02858358398952987, 0.032252661912934855, 0.008408861576754134, 0.03144966554827988, 0.014666915176348994, 0.023956324766913895, 0.0325206254638033, 0.07622253688168712, 0.0555932211864274, 0.07441525143804029, 0.06783474673284218, 0.019655590112961363, 0.005476069754877244, 0.02078368612274062, 0.07959570197272114, 0.021051751718914602, 0.034303954380447976, 0.05079095426481217, 0.04330021285568364, 0.008338364041264867, 0.04874448575719725, 0.0405677698290674, 0.05776899037300609, 0.0285239542790805, 0.0485735728580039, 0.06174194066261407, 0.04235545144183561, 0.07652986023458652, 0.059366110726841725, 0.023241098497237545, 0.0871747218479868, 0.025275935695390217, 0.023709438210062217, 0.029877182641939726, 0.014951718985685147, 0.06794661065214314, 0.046163489096215926, 0.059901028507738374, 0.02767020614555804, 0.03306559934571851, 0.07680870738113299, 0.03549832232238259, 0.016830534477776382, 0.028960146009922028, 0.041037649498321116, 0.016121276930789463, 0.02312493383215042, 0.025197403483616654, 0.04294532525818795, 0.05240343707555439, 0.033731888397596776, 0.06361924402881414, 0.049419825299992226, 0.02759305247309385, 0.010376526988693513, 0.013706870158785023, 0.08612062723841518, 0.05997016698529478, 0.03906382611603476, 0.0022577410209123627, 0.03309511084808037, 0.020001187876914628, 0.02999256619659718, 0.05637534835841507, 0.014336205822473858, 0.03708204691065475, 0.025681621445983183, 0.003294027333140548, 0.05561494755966123, 0.0379214567510644, 0.024738739521126263, 0.033785248815547675, 0.01574010802869452, 0.020196367149765138, 0.011051189321733546, 0.11118610840640031, 0.022625288474955596, 0.043327197345206514, 0.03698810585774481, 0.04554600738629233, 0.007682376462980756, 0.13911295478465036, 0.03915432360372506, 0.027055893406213727, 0.02912160209234571, 0.04080488972249441, 0.039377658104058355, 0.06585258161067031, 0.017514351202407852, 0.10082321838126518, 0.028102481192036066, 0.0741583644412458, 0.02130086471879622, 0.02964567709568655, 0.029634014244948048, 0.007044164249236928, 0.02289298670802964, 0.06779299350455403, 0.016891312661755364, 0.03815341871813871, 0.03930964398023207, 0.07289099143235944, 0.011100633055320941, 0.048199779048445635, 0.026268921865266748, 0.06939763552509248, 0.062418842426268384, 0.010113149910466745, 0.0486623003234854, 0.017739040122251026, 0.05553356735617854, 0.005140484954608837, 0.018943564355140552, 0.03579291413188912, 0.03406048541364726, 0.024935377114161383, 0.026388255500933155, 0.003860621368403372, 0.04707962958491407, 0.0716157145507168, 0.056768701469991356, 0.016882048803381622, 0.03774051372602116, 0.02337517489650054, 0.022664076823275536, 0.03307906190457288, 0.06730901674018241, 0.027342247376509476, 0.04195875495497603, 0.036296442776801996, 0.05988396282191388, 0.02449954532494303, 0.047921766818035394, 0.04832519458432216, 0.08515046210959554, 0.09407841702341102, 0.027186153311049566, 0.10950246476568282, 0.009578346234775381, 0.049196379477507435, 0.04483409480599221, 0.05732718615035992, 0.020263167862140108, 0.028438215813366696, 0.031185290281428024, 0.04066601162776351, 0.02697965072002262, 0.07064905235893093, 0.021080361511849333, 0.007569297740701586, 0.03515061500365846, 0.03429215794312768, 0.0396473694127053, 0.047792354816920124, 0.085510314675048, 0.07625857557286508, 0.020126800081925467, 0.07301546444068663, 0.061675021206610836, 0.015818562314962037, 0.019984764148830436, 0.04347627625975292, 0.0019416312193243357, 0.05038542622060049, 0.039015493748593144, 0.03850272165436763, 0.034247699586558156, 0.02004825302719837, 0.1353812136221677, 0.1448614228866063, 0.16956688079517335, 0.15920629142783582, 0.11484245478641242, 0.10236592817818746, 0.15257833380019292, 0.12311733458773233, 0.10248216334730387, 0.1086095349455718, 0.12956531398231164, 0.1340382528724149, 0.15026885928818956, 0.12828522798372433, 0.1382778605329804, 0.09511396536254324, 0.22110698861069977, 0.1967189769493416, 0.15029738744487986, 0.1965329798986204, 0.09789705625735223, 0.17022586340317503, 0.13817461294820532, 0.1310849652509205, 0.11100591495051049, 0.13595965836429968, 0.22310297994408756, 0.15105106809642166, 0.0945156830130145, 0.12787358835339546, 0.17632756411330774, 0.13027780543779954, 0.11055216586100869, 0.11674853492877446, 0.14758994366275147, 0.1669304011738859, 0.13559406157582998, 0.18339497706620023, 0.12837229674914852, 0.16894313535885885, 0.13588758098194376, 0.1076064036169555, 0.1457736114389263, 0.2819739037659019, 0.2018515218514949, 0.08255584703874774, 0.12221494238474406, 0.1689290493959561, 0.1753012035624124, 0.18128984549548477, 0.09847997614997439, 0.16901957656955346, 0.1881790391053073, 0.15004858985776082, 0.12721465027425438, 0.1157887524459511, 0.0822724356839899, 0.20811334834434092, 0.07647657403140329, 0.14719568513100967, 0.16783619241323322, 0.2394904466927983, 0.07428716417052783, 0.21590152027783915, 0.27836754103191197, 0.11694147848174907, 0.15298914222512394, 0.08313477417686954, 0.18946463183965534, 0.149562839360442, 0.1435426264652051, 0.10182531812461093, 0.09054175679921173, 0.12989865703275427, 0.09331447989097796, 0.0867233847384341, 0.1301837307983078, 0.21288219635607675, 0.2199175040004775, 0.06556886597536504, 0.07236331701278687, 0.1418827983434312, 0.11724244905053638, 0.14212295733159408, 0.10155463460250758, 0.14879839756758884, 0.27075708378106356, 0.1225088031787891, 0.11905550840310752, 0.19915368146030232, 0.1408431088202633, 0.11850576993310824, 0.12891514808870852, 0.18542590871220455, 0.07793940647388808, 0.17242480244021863, 0.16209781751967967, 0.28544617525767535, 0.11486165414680727, 0.18197573837824166, 0.19172027095919475, 0.07795170386089012, 0.11203244619537145, 0.17573761608218774, 0.18607214122312143, 0.14866441022604704, 0.1662854154710658, 0.19043690466787666, 0.1290732849156484, 0.22564872459042817, 0.07152186255552806, 0.22192753676790744, 0.10958479120745324, 0.1894693518988788, 0.08918745603295974, 0.13997289614053443, 0.13275111647089943, 0.10883234252105467, 0.15766338125104085, 0.10970953881042078, 0.12519244628492743, 0.2524028514744714, 0.10549124563112855, 0.07682927971472964, 0.1486657906207256, 0.16279727686196566, 0.15024119202280417, 0.1298306614626199, 0.1143247251457069, 0.1316416056943126, 0.11522335465997458, 0.1638513640500605, 0.08462867292109877, 0.11267599955317564, 0.11331481800880283, 0.075718841253547, 0.0863431156903971, 0.13529165124054998, 0.16261773649603128, 0.1944207979249768, 0.12308194156503305, 0.14791893772780895, 0.20001766009954736, 0.17109773849369958, 0.13753289269516245, 0.24675470689544454, 0.14179224148392677, 0.0981125833641272, 0.08496574897435494, 0.18446512433001772, 0.11829869588837028, 0.11222179775359109, 0.133687439665664, 0.147895292902831, 0.11210337324882858, 0.1762302388669923, 0.09926743194228038, 0.08834953419864178, 0.1265730190789327, 0.20478040765738115, 0.07636588270543143, 0.14161647122818977, 0.232417942606844, 0.17187709745485336, 0.15059820958413184, 0.15115787799004465, 0.12023540446534753, 0.16449171875137836, 0.12750871886964887, 0.06365430308505893, 0.11508001625770703, 0.10709489317378029, 0.134931561187841, 0.11328130261972547, 0.0513768464588793, 0.13491235440596938], [0.019570738513721153, 0.01853135327110067, 0.019651625188998878, 0.03258174503571354, 0.012504063070082339, 0.05722542657167651, 0.024534218464395963, 0.04751513297378551, 0.04281261812138837, 0.00875351403010427, 0.011367908264219295, 0.09126063814619556, 0.03681528934976086, 0.07685875782044604, 0.0991652010998223, 0.009011458587337984, 0.020475603923841845, 0.019251013873144984, 0.045162654714658856, 0.06881439650896937, 0.05851294888998382, 0.018067069395328872, 0.02914636570494622, 0.04609016119502485, 0.06870571640320122, 0.04245722957421094, 0.01610090497706551, 0.03667466720798984, 0.013159251448087161, 0.07574736198876053, 0.004797431365659577, 0.03126411378616467, 0.07560823156381957, 0.026344661746406928, 0.02936216926173074, 0.01199168895254843, 0.029710555645579007, 0.011426976725488203, 0.026878624012169894, 0.03594184832763858, 0.038149730244185776, 0.01297151313337963, 0.08649481067550369, 0.050415735531714745, 0.046956221558502875, 0.018207949433417525, 0.029140345031919423, 0.024530938171665184, 0.06745862629031762, 0.019636359211290255, 0.019577503189793788, 0.03534916177159175, 0.09137661356362514, 0.0268793531722622, 0.012011816925223684, 0.023574102015118115, 0.006089966427680338, 0.01615715977095533, 0.06273547231103294, 0.054175767363631167, 0.0735199022165034, 0.07612182744196616, 0.04039454142912291, 0.06634498175117187, 0.07122251729015261, 0.025253174026147462, 0.0372843229706632, 0.044225222009117715, 0.03307427505205851, 0.08438761593424715, 0.0369949039304629, 0.0416579662123695, 0.021380996258812957, 0.018393549435131717, 0.10862106792046688, 0.05409333331044763, 0.04741647557239048, 0.03671919235785026, 0.03420454369916115, 0.016999308136291802, 0.03860879682179075, 0.05893414367164951, 0.05957021989161149, 0.024182407069019973, 0.07990897734998725, 0.062357771093957126, 0.03856821247609332, 0.02808426332194358, 0.03106698266492458, 0.02279113065014826, 0.0064771332745294785, 0.008726954420126276, 0.05768588467617519, 0.03704005619511008, 0.048267819147440605, 0.09150664525805041, 0.02130875003786059, 0.07911639331723563, 0.038587634480791166, 0.021753587789135054, 0.02489377417077776, 0.0062472567424265435, 0.022812448842159938, 0.06205441080965102, 0.027279155547148548, 0.0299299066682579, 0.10270531973219477, 0.016391058743465692, 0.013209527314756997, 0.031104401750781108, 0.0435224489774555, 0.07806090347003192, 0.0022798813733970746, 0.025315842831332702, 0.04557659871352371, 0.07714300038060173, 0.02367114895605482, 0.022821510465291794, 0.016576697707932908, 0.003677197018987499, 0.03843813254206907, 0.03789008616877254, 0.032266124471789226, 0.05465016671223566, 0.02520319594623288, 0.01182394873467274, 0.08147853804985061, 0.02206368306360673, 0.02861970802769065, 0.09861038633971475, 0.033260520722251385, 0.06357660022331402, 0.013099061416141922, 0.033010691549861804, 0.049392466025892645, 0.010511965228943154, 0.07667953657801263, 0.034525296214269474, 0.024390740909439046, 0.04351154682808556, 0.03263567319663707, 0.03480071092781145, 0.016989328105410095, 0.02274620102980407, 0.1147019439667929, 0.011010827620339114, 0.03679634231957607, 0.022834045339550357, 0.05146329182025511, 0.008721687026991276, 0.05534830503165722, 0.03702525777043775, 0.04550390163785778, 0.030358187104866374, 0.04189455918094609, 0.030320109362946823, 0.02790530739730457, 0.036547266427078284, 0.031044345305417664, 0.021166454353078734, 0.01094509003451094, 0.024543610343243927, 0.057422978861723095, 0.05266397914965637, 0.03787199631915428, 0.04341226231190376, 0.10257038986310363, 0.011482818699732888, 0.016608003352303058, 0.09762321118614636, 0.0358631658309605, 0.02314296430995455, 0.04606420829077251, 0.039180814565042965, 0.0288365450251149, 0.026668701975722797, 0.020714067104563583, 0.038183100914466195, 0.005617252218144131, 0.006906822864038986, 0.03990651995991357, 0.01986668288736837, 0.039203661581268534, 0.034405387414153665, 0.03804742147622164, 0.05053776687418576, 0.05532015537028201, 0.060672910331049934, 0.025481419688730966, 0.04238870336848777, 0.06005594441376161, 0.043246822751825675, 0.0850104411074426, 0.07164980881498195, 0.005364178468880709, 0.12263083452126011, 0.07008404048974626, 0.006355488776534912, 0.016950710451055784, 0.0322156250331318, 0.018842515382857528, 0.011920679335162276, 0.017268592710024677, 0.004717585552498349, 0.03579256161174271, 0.10926445800578222, 0.025062751919904258, 0.04162321514741052, 0.044357973674777895, 0.06052369411918335, 0.025905443908413872, 0.03528925561113283, 0.036992514214944094, 0.08929790245019831, 0.08147944347001612, 0.0316814048710512, 0.03037335474800784, 0.012215804563311394, 0.045079363480908796, 0.06915320918778889, 0.036637763914768584, 0.03544978957506828, 0.01998217405343894, 0.09098358699702658, 0.044497920462163165, 0.05240415324806236, 0.06044201705662999, 0.09036777511937544, 0.030183504095475655, 0.07661067269509658, 0.022468930947070476, 0.032641198486089706, 0.048959667765302584, 0.028052927991666365, 0.0588806088489946, 0.04538949215202592, 0.05477720755152404, 0.026670880179153755, 0.0049950420998357, 0.049088942469097674, 0.060762984794564545, 0.023093513154890388, 0.052102971167187206, 0.05511448398465291, 0.02937730350822676, 0.02961917685752269, 0.03418641303142067, 0.0053708341420133365, 0.0471022205601912, 0.02303184253833024, 0.03319367177027743, 0.03271921676059719, 0.0347058867191663, 0.010440332207508618, 0.02361159902648069, 0.07327369472477585, 0.06003398055327125, 0.05425518087577075, 0.0690398461301811, 0.01844759077357594, 0.05227413268585224, 0.017631428709137253, 0.05661243856593501, 0.03717080035130493, 0.0050983866276510525, 0.00774213604927354, 0.03682709691929631, 0.027786010869021993, 0.01656915934290737, 0.022155293772812, 0.01226209880769602, 0.03958855420933105, 0.04230898186506238, 0.06710409492370673, 0.024308997053594794, 0.027081482658104505, 0.036277083854656667, 0.014877099747536704, 0.04061229126818944, 0.012725471697194735, 0.010886904728977242, 0.0389359169639647, 0.1167556298605632, 0.03200517050572671, 0.038849015181767754, 0.03489868555334397, 0.04025616428407375, 0.03959753790695686, 0.023621783147973474, 0.04237448381900322, 0.036288902556407265, 0.06485359146608971, 0.035878966154996306, 0.03605694801080972, 0.03316880982310977, 0.046209906722651795, 0.05307968945999164, 0.022884708050696645, 0.030243107830756344, 0.0326197986578336, 0.05074710075859912, 0.011404023025534116, 0.04801357048563659, 0.04569149430608377, 0.04883576249994803, 0.026736417385109235, 0.021566614814219065, 0.059962251980323344, 0.035318707741680555, 0.026047635692521, 0.016068042677943595, 0.007365345354628516, 0.03677860127936583, 0.03404559422051534, 0.038700507720932364, 0.056022178832790814, 0.041807534944382496, 0.053434855362866074, 0.013899415735068033, 0.005634340168398921, 0.053914475720375776, 0.053915655735181645, 0.04047802933200728, 0.03380206959263887, 0.05067055193649139, 0.052404264570213854, 0.021902529406361282, 0.03761600732104853, 0.028467923984862864, 0.05913018569117412, 0.039209929018397816, 0.052547792220138945, 0.03958881767175626, 0.05782829539384693, 0.003893270995831699, 0.040120770572684705, 0.03306151011202019, 0.016052839782787487, 0.0391467462759465, 0.02959006611490622, 0.011183659898961196, 0.08367102782358415, 0.05299168187775649, 0.04186000478512142, 0.009370631159981713, 0.030726993682037573, 0.030287143163150176, 0.0404109428927768, 0.02183682892791694, 0.033623085837461986, 0.030867643654346466, 0.03484161810774822, 0.0861436857667286, 0.13968942541396245, 0.10283307303325273, 0.14064508897718042, 0.12552118801977485, 0.06354086581268348, 0.14375424245372415, 0.11378050825442187, 0.12577618996147066, 0.17400682379957289, 0.09631185108446516, 0.22965788055444136, 0.14586004195734859, 0.12925592745887116, 0.19752925378270447, 0.05061061980086379, 0.13327102060429752, 0.12061263812938705, 0.0914565206039697, 0.20617356727598235, 0.09474260950810276, 0.1345493402914144, 0.10636481281835586, 0.07828155881725252, 0.11789564290666021, 0.11792009667260572, 0.12208690706756897, 0.07871426059864461, 0.07668082049349323, 0.18034997483482584, 0.09598715405445546, 0.12742230319418013, 0.12781682889908552, 0.14873215346597135, 0.14866904122754931, 0.17241362569620833, 0.15139791823457927, 0.1727150267106481, 0.1995392271783203, 0.12791789456969127, 0.17323767679044977, 0.1172715486609377, 0.21458929928485304, 0.1336458051810041, 0.1323109635268338, 0.1429692134843208, 0.12383997120196, 0.13121617696015164, 0.13754867075476795, 0.1028006337583065, 0.1298756801406853, 0.12899593828478828, 0.17835659586125985, 0.12744084204314277, 0.11259662685915828, 0.11608039421844296, 0.0820566042966675, 0.056634053617017344, 0.1614348718430847, 0.15337578632170334, 0.12583001051098108, 0.1154482328274753, 0.08475838549202308, 0.13239439576864243, 0.2015365840634331, 0.17086500098230317, 0.12938846019096673, 0.17451739171519876, 0.10328968681278639, 0.2005181199638173, 0.1497824111720547, 0.09340269898530096, 0.09984983975300565, 0.12421324921888299, 0.2764468628447503, 0.18949694494949654, 0.12201965364511125, 0.20136148174060509, 0.08821075258310884, 0.13642212026752532, 0.12278169087949209, 0.16209857451030985, 0.2389274089364335, 0.0912605194025673, 0.1573141265544109, 0.11855650314828381, 0.10127793968422338, 0.12610512465471402, 0.0902874450548552, 0.17629670561291277, 0.13762460730504245, 0.16583890974288806, 0.1479777306667529, 0.09336306829936802, 0.10991662027663551, 0.20493585790973157, 0.12549395120004192, 0.18929328478407115, 0.08851457299897447, 0.08496665439452045, 0.10691858115023933, 0.07717240427155048, 0.09369241117383353, 0.10707625042414293, 0.10012815255322494, 0.2047660990501754, 0.2711020933929831, 0.07085676465067081, 0.0996100518386811, 0.1350203072070144, 0.13296099583385512, 0.15441647032275796, 0.11284921682090499, 0.12290905084228143, 0.08029615579289384, 0.16096543375169858, 0.09366274753119797, 0.08729632274480537, 0.142294630932156, 0.1261691126273945, 0.17929726804140955, 0.07455556187778711, 0.17762494215276092, 0.1820496711297892, 0.13681097596418113, 0.1256835847743787, 0.11869131427374668, 0.12299850190174766, 0.12244644793099724, 0.1405687813530676, 0.13427348400000483, 0.14829777443083003, 0.11739096764358692, 0.11451010621385649, 0.09341903365566395, 0.1027262705611065, 0.15161910792812705, 0.10519295421545394, 0.1143249477900099, 0.15338173834607005, 0.1655685601872392, 0.18751460913335904, 0.14596245833672583, 0.15762499737320468, 0.1839392533292994, 0.22682165930746123, 0.20662047376390547, 0.16646311531076208, 0.1344946736935526, 0.22879697440657765, 0.21516139124287292, 0.24941261974163353, 0.24399029585765675, 0.25786698795855045, 0.13595897558843717, 0.10304589872248471, 0.11171940830536187, 0.17623126303078607, 0.1052252970112022, 0.09382576768985018, 0.12312206948990934, 0.11631755492999218, 0.1909520145272836, 0.13615128089440987, 0.10368859118898399, 0.21897883561905473, 0.16650222649332136, 0.0983236130559817, 0.05487186848768033, 0.15063620754517615, 0.0966634954966139, 0.18046337499981746, 0.11341874094796367, 0.09212878023390658, 0.11344537662807852, 0.17955552058992907], [0.03635294247942511, 0.044786923899664544, 0.03799001635343302, 0.04299848529626615, 0.030690253661305178, 0.02405590799753554, 0.019619067170424387, 0.02520567471947288, 0.08262418399681337, 0.027244244920439087, 0.020503226660366636, 0.03489922732114792, 0.019954124582000077, 0.06569441509782337, 0.01703955109405797, 0.011204919646843337, 0.051267765593365766, 0.07547086002887227, 0.04307298208004795, 0.029525721911340952, 0.051554427554947324, 0.007070243318594294, 0.060661848619929515, 0.09170369288767688, 0.07740003580693156, 0.03597323375288397, 0.02273298337968299, 0.03428519288718235, 0.032976356087601744, 0.04668800196668599, 0.03040380877791904, 0.01967276712093735, 0.018025728059001267, 0.05741497108829208, 0.0021038898648839677, 0.012438272606232204, 0.06571983365574852, 0.072000236104941, 0.02006606457143789, 0.010885439915000461, 0.04826251279155258, 0.04472155182156712, 0.04718710741144605, 0.10010745405452326, 0.05308267289365176, 0.0706205093592871, 0.06450447777751833, 0.04430266882991418, 0.007879559070715914, 0.08177667361451313, 0.022677240667690057, 0.03025191712367814, 0.04854652157519013, 0.02580058586318046, 0.023021270644676406, 0.06506776786409318, 0.026898383694060612, 0.03532712740707211, 0.03835381714452524, 0.059768770370283164, 0.029044279581285082, 0.05550553643843159, 0.03189485396433156, 0.0283866031531943, 0.006446121242333902, 0.06308198106125928, 0.10335780854802579, 0.026270730850228574, 0.04389795343740843, 0.005710028563044034, 0.023011615303403232, 0.035251895897090435, 0.0509021168545587, 0.1155337950331159, 0.0160269648040412, 0.036260029301047325, 0.049236819104407914, 0.09098000984522514, 0.034434869230608456, 0.03555820250767283, 0.037623428797814995, 0.05084480821096804, 0.08067522998317145, 0.01728136692690896, 0.05407560711319093, 0.0532509771437617, 0.04756706104672048, 0.011425499851611676, 0.05118966568261385, 0.037217611316009425, 0.0053971525539964205, 0.031007955949462485, 0.06957854144275188, 0.05948188576439861, 0.04866742485319264, 0.010412906140118139, 0.02309952826180961, 0.050760789672494866, 0.02074420943245059, 0.03248071276175324, 0.018527766842453275, 0.08545780030544847, 0.114789650979219, 0.011833128173748264, 0.06848812612588517, 0.060498090024339035, 0.016335566506313626, 0.07409381243633106, 0.05065842895419337, 0.020618858834495768, 0.015213933675113367, 0.00855557953400421, 0.04491298139328137, 0.10733184608398005, 0.00749788597204315, 0.0319051141559612, 0.012089406609447906, 0.06340678941342048, 0.10807457263581455, 0.04143476158787962, 0.029536338333855383, 0.0330431605107151, 0.050136658319388516, 0.014080846722208662, 0.05405291223723907, 0.048190390880336054, 0.04491540079470724, 0.04645418834115844, 0.01867296246928163, 0.11887160420883447, 0.052554438152583316, 0.015623056497133803, 0.005254034012978082, 0.020356867717055138, 0.028271930204937235, 0.0243273874730221, 0.10910484430496581, 0.04809466867300216, 0.014673839414172107, 0.018167942107538693, 0.018713628451223485, 0.018187852074333932, 0.024176375263778027, 0.046512394983437844, 0.01979654251044849, 0.09873051778413355, 0.056651267732377164, 0.0033934238672372885, 0.06570457509951666, 0.02598649385618046, 0.041102602262981236, 0.07174555328674614, 0.04340478146332316, 0.06016806808474939, 0.07625928803463466, 0.03238683479139581, 0.07549158821348101, 0.018325461096537765, 0.0028740517609548988, 0.025254144384234678, 0.041644566736067645, 0.01315824491030071, 0.03213538402633276, 0.05633385859255213, 0.10288500852766447, 0.05103678326122463, 0.05763305860455148, 0.0019671688687594724, 0.021645670240104664, 0.03486535570118576, 0.03595064648834523, 0.026807971553353127, 0.10754656424978748, 0.057750945052248426, 0.03163881672662683, 0.03151887081912719, 0.00782339333454729, 0.03156300634145737, 0.01609721835848177, 0.05284099992422853, 0.057407991189393215, 0.06859940374852158, 0.060754353617085144, 0.02114726055879146, 0.04719804666819982, 0.006174066602397943, 0.014909431411069818, 0.07665773227927275, 0.05016404356865678, 0.016883277057786472, 0.05259015400952194, 0.036631463080993854, 0.06121549078670796, 0.02709813830733765, 0.028543791886477266, 0.0035160686411472852, 0.05129296150698792, 0.046643933237646706, 0.016737300320528448, 0.003035203330910008, 0.06198858602147084, 0.04071003582794219, 0.04669278881920036, 0.025669928909337614, 0.029596804815810174, 0.04929610928229522, 0.08216389658628032, 0.03835595452983398, 0.04199064504064154, 0.049502749170642346, 0.023210234430735, 0.038469454884761944, 0.10259046495775692, 0.03419847664190456, 0.054620347218587995, 0.07538597317761742, 0.06036765014869161, 0.033543097160873, 0.05926089645072352, 0.103631356760161, 0.04832063408684917, 0.05018494986870792, 0.021129254200786818, 0.03403148599318229, 0.018933068531623576, 0.031867936268099584, 0.014387657993211178, 0.0245207317857421, 0.021415756600617897, 0.03401836111152079, 0.01914895372465253, 0.046216229820856825, 0.03381320180778857, 0.034675607093959115, 0.08974102398497052, 0.02743434419244295, 0.04330292540544178, 0.033322271119686775, 0.013005929304199526, 0.01824939281505067, 0.046476178176817484, 0.07273707000422291, 0.02528896409785375, 0.012912505899294047, 0.04940433667798061, 0.03240283178456593, 0.06729461907525547, 0.020060424249095377, 0.05264205239654984, 0.046140478807501495, 0.057515932858223096, 0.04278488406271208, 0.04130753892241046, 0.03281980745668989, 0.037545610903180204, 0.09018352953717113, 0.01793228610040387, 0.03315715068310965, 0.06744038430042565, 0.017994108857237734, 0.05413985112681985, 0.0657426769612357, 0.06529338817927055, 0.0091879570754827, 0.04149225205765106, 0.010852015439013485, 0.05596556038653944, 0.011729360157914925, 0.06585764305782504, 0.02971562080347212, 0.041131931939162314, 0.010256527275487315, 0.06799951836001128, 0.04121239187952597, 0.04875919141341001, 0.06708206055918708, 0.02404525632300647, 0.07482297252863646, 0.01473175383580383, 0.03780590806854889, 0.08116253156913444, 0.06998402866884135, 0.03204227046808228, 0.0374743907013908, 0.01669096433033701, 0.07197131460998207, 0.05542394101212267, 0.02625249071570579, 0.050951057783095166, 0.08708883309736848, 0.04484031771426089, 0.040686353895580396, 0.03061636358324904, 0.014480290083156433, 0.06057364436856005, 0.018962570757139474, 0.04861267290834803, 0.06542154966155067, 0.03638511829194613, 0.061748913140036166, 0.05116529355291277, 0.02174314206058625, 0.05057548281911295, 0.03994094076915644, 0.03454247322224546, 0.02610360290418612, 0.032840197964105755, 0.04007081290183123, 0.06746348735759966, 0.039258918186533265, 0.045809057919541374, 0.02855662733054487, 0.040424327526125126, 0.009908931278914679, 0.029235816764412448, 0.023453113390132785, 0.018782963597914204, 0.05336512316716835, 0.05452043187688105, 0.03145952498016413, 0.04342868232924957, 0.062468544056173414, 0.06895984261063859, 0.04221833965857513, 0.03727469731529709, 0.05120368856296409, 0.05709272685635369, 0.056578982548671775, 0.043369314225856215, 0.026313482267141808, 0.06213710461452138, 0.07858080018195324, 0.018244624516228214, 0.041199352344847284, 0.05068228529125918, 0.04171377200691495, 0.02992566158354748, 0.01673766026215162, 0.06194426125148311, 0.06696883850963786, 0.09267029570764862, 0.08422452156082727, 0.05446615119581111, 0.04445013728400227, 0.042866308795055375, 0.0761649091145955, 0.04787550504261162, 0.03955492007662542, 0.0929189077578485, 0.05358068367058877, 0.046389480485231616, 0.006780369712942047, 0.10396962767117657, 0.11664155434118584, 0.1238472294062376, 0.1863843627506867, 0.17149406019598246, 0.1814681093674153, 0.11582240142161027, 0.07968984340550378, 0.24461760360281914, 0.0751001201570034, 0.11199959873920307, 0.2229005517438054, 0.09175032202620059, 0.10209474741714075, 0.11062853285693564, 0.0876991382392589, 0.12315143627347425, 0.13819521496770903, 0.13051440211711451, 0.1480164410895668, 0.16365521441912279, 0.08657265454530716, 0.1226030410907697, 0.09868980356259272, 0.12525843805633485, 0.1993835245957598, 0.12674353492911905, 0.06113779163570143, 0.1191813989134971, 0.19618835620349273, 0.1430691362475045, 0.14051481237402186, 0.05882474368263502, 0.2668301429366693, 0.06464098099968396, 0.13498386775609106, 0.21551370358793065, 0.14143411070108414, 0.09391990170115605, 0.18550879176473245, 0.10030459816334769, 0.11606483138166368, 0.17993435729295015, 0.19434235291555524, 0.2433869446394965, 0.2061916163074784, 0.09297272088588215, 0.08982917628600262, 0.07540034857811406, 0.16494698182214051, 0.13455480249831453, 0.17103783233324066, 0.10121870887815021, 0.0880302325822413, 0.05412833299487829, 0.23209825507365167, 0.10251858053379692, 0.1330453038099222, 0.15969593077898026, 0.13812778342980891, 0.22223676001885906, 0.1352127015707083, 0.16811608598800376, 0.09235831908881664, 0.10705530701670796, 0.21977421012707055, 0.257605841034092, 0.12215580805786885, 0.15642016514902934, 0.11687659251037985, 0.11617034993832931, 0.1347460094257258, 0.19535217841621488, 0.2240180628723465, 0.1980418254970573, 0.09738861088408157, 0.12793941685231403, 0.18218098673969507, 0.1481691750814207, 0.19009753537829965, 0.09845998269156553, 0.13881968770874664, 0.17576333892066032, 0.12835184315918013, 0.1859044306911528, 0.17107456864323467, 0.12596534856129438, 0.21558999636908993, 0.09063635094207712, 0.11339106626110151, 0.1427414928912185, 0.09385460754856467, 0.15271842159563676, 0.15322177583584562, 0.10298470122506842, 0.07633511326275766, 0.15806498704478145, 0.13617966062156484, 0.09946481353836134, 0.10928656658506952, 0.17669366556219757, 0.18708305025938898, 0.1342717176885344, 0.11813131932285614, 0.2084955692407675, 0.1372755752527155, 0.1411650376394391, 0.1601169363129884, 0.1851991974399425, 0.14395226229680702, 0.12556832924019545, 0.08348476359969936, 0.19028581824386492, 0.21811113139847293, 0.13832172146067023, 0.19210777594707906, 0.25105027249082923, 0.2664758119499311, 0.23499589646235108, 0.1121062230959069, 0.17582082567969337, 0.12455238844268024, 0.15505823510466143, 0.18432353739626706, 0.20346670236904174, 0.12752054870361462, 0.11964067700318992, 0.1855433313176036, 0.10494457965251058, 0.2622632629936561, 0.2415808688965626, 0.12340934001258574, 0.162400598928798, 0.15152571606449783, 0.17429240222554654, 0.12879392568720505, 0.1556420826818794, 0.17870362411485985, 0.13642290694406256, 0.14874742686515674, 0.12813611567253247, 0.12763439415721223, 0.1786260845256038, 0.1907665963517502, 0.100767928379355, 0.22154872975079343, 0.17260597553104162, 0.09268182126106694, 0.15290375071344897, 0.13818489911500365, 0.16077581502031535, 0.17486878379713744, 0.15634825103916228, 0.14632002508733422, 0.13862549734767526, 0.10217205694061704, 0.15071172849275172, 0.10426471300888807, 0.08995552692795172, 0.16916606167797, 0.08653692013467662, 0.09207301525748335, 0.2017538552172482, 0.16077324718935415, 0.25942428095731884, 0.17615106655284762, 0.16864563804119825, 0.11248051043367013, 0.07067337995977141, 0.15026275883428752, 0.1483420212753117, 0.09766799979843199, 0.28252163843717426, 0.13734204199863598, 0.13969632738735527, 0.0647252296039369], [0.04646728724765126, 0.07077598187606782, 0.0173734266354586, 0.037261034376570024, 0.0955801602685824, 0.04509554601099808, 0.07867029577028006, 0.03306043770862743, 0.038326880894601345, 0.019717756113095675, 0.010933198973361868, 0.025332036493637133, 0.01787932458682917, 0.043500871033756994, 0.02241472262539901, 0.09130478109000251, 0.0504663611354772, 0.033316901681246236, 0.044704935135087, 0.07145663519622758, 0.07287266038474627, 0.008038475152716273, 0.010232721961074276, 0.025300816196249798, 0.021019138039264362, 0.020139295993431006, 0.02438518036797177, 0.025077919563045725, 0.04681850863562431, 0.021326372334442567, 0.042238745008944534, 0.02255261551908916, 0.02254960982099874, 0.01178129843538045, 0.02742600245255744, 0.021798678826598916, 0.04052352669532411, 0.05463799177960027, 0.07540182545199059, 0.030858611717121676, 0.07081340096192434, 0.03190341463778168, 0.03239935111196246, 0.0031525723625236424, 0.05883273290237412, 0.04414442439156119, 0.02623131909786025, 0.052634341482189484, 0.026052428111142945, 0.048838233851711266, 0.029090311290929094, 0.012045050298183924, 0.09567917761160061, 0.01631620016269153, 0.06889486758154817, 0.05115032814501319, 0.037364204035839066, 0.07128329918486997, 0.0722787641279865, 0.07613796915393323, 0.010272626313962974, 0.02611520638311049, 0.06417384356609546, 0.012413400454533985, 0.08384226355701685, 0.06803688549553044, 0.0487396506650839, 0.055767399535398, 0.03317704024084378, 0.020161452812317293, 0.010981561026710551, 0.014285448487498797, 0.11220089887501672, 0.03383144379768055, 0.04915389894449618, 0.09727000826387666, 0.03937255583878141, 0.020956474800186697, 0.023659059370402247, 0.009419711241207551, 0.06791800828068517, 0.03982265727245249, 0.07378899754257873, 0.07561011661891825, 0.010130041191587225, 0.03395214669581037, 0.02139587260899134, 0.07313765905564651, 0.01440820713469293, 0.03066288511035964, 0.02658061832335079, 0.06986800872255117, 0.02162988661439158, 0.025836878739937674, 0.033739013015292585, 0.0281027390883537, 0.03402607573661953, 0.022979819841566496, 0.02795354328554822, 0.03578110656235367, 0.04889556104899384, 0.021244604358798824, 0.05347187368897721, 0.024769132323854137, 0.042004170682048425, 0.04309693118557334, 0.010960029467241839, 0.016565298319619615, 0.030000006227055565, 0.013167120996513404, 0.03166147449519485, 0.039494746743002906, 0.1054077094886452, 0.012578119203681126, 0.020064687887497712, 0.052740835963049904, 0.039400942987413146, 0.05711852390959393, 0.09905551167321391, 0.07845225278288126, 0.037244328632368706, 0.021099828045407776, 0.021159238822292536, 0.0314930181048112, 0.05098156747408211, 0.040886006463551894, 0.02818321943777846, 0.039998141801333986, 0.026299635646864772, 0.042954097443725914, 0.03310408712422941, 0.03837027426925488, 0.04521414120972622, 0.029367534989432897, 0.048977824408211745, 0.08447633968899027, 0.03626943602284882, 0.09161594134639017, 0.02752252432401292, 0.07685997494263574, 0.030974622386565898, 0.047831592164584436, 0.021128157677594572, 0.02600887146400055, 0.03699193905049469, 0.053984957485226914, 0.06444060854846612, 0.023206141486298293, 0.05471714925079141, 0.025947887334041297, 0.05955750690191053, 0.0566525219619507, 0.10103035179781727, 0.028757574946212117, 0.011034025301341899, 0.07839748228434473, 0.02081547416310059, 0.049066073188441806, 0.024740650551393628, 0.04432829147845041, 0.024568795124650933, 0.01566941475175554, 0.04188161612546537, 0.03813597453699913, 0.050940890359925106, 0.04181640731985681, 0.0263649409316713, 0.07187311362940818, 0.00916607948965975, 0.04405886589665897, 0.027188025378563907, 0.05459177082229871, 0.05551275382458698, 0.03286625476903282, 0.07718736596871167, 0.06561928006703965, 0.04518128262134269, 0.04028031005873345, 0.011303521387162618, 0.003956123946409207, 0.06054551697161514, 0.03913526154065039, 0.024045540194492787, 0.0431553901580628, 0.04254458035575226, 0.03571176770492457, 0.021199685870669782, 0.07032496389001608, 0.04689991481427569, 0.014396232581930235, 0.015315992895921227, 0.088538358832011, 0.043210869407630526, 0.045518514525610954, 0.017274233032367192, 0.0827100727474317, 0.018015818532148842, 0.01472105948778335, 0.08883405273081735, 0.08168777174432762, 0.023087292101990897, 0.103725327498978, 0.004784836191902286, 0.05075047381978948, 0.05359943403163925, 0.005720727549487492, 0.016589176921115723, 0.050678437255555764, 0.030988049693405628, 0.06873152087791823, 0.028019407036481425, 0.0522724146139808, 0.026463672547833994, 0.06654261567746289, 0.08232164007495157, 0.08179597687558271, 0.02809502817399334, 0.07094100583344698, 0.04170719657849986, 0.02559095883043483, 0.018913692911155522, 0.03797304343606811, 0.050553500404930674, 0.0770845117222052, 0.09414665008080192, 0.06479227522504516, 0.009119395617744885, 0.010833113865373889, 0.04818513276404701, 0.01788610781659372, 0.06949387723580003, 0.04908155809971504, 0.03575618153263349, 0.05149421340320259, 0.07852720969822258, 0.04212060994177591, 0.0730005546938628, 0.05240931859589182, 0.019365256375749595, 0.051521654313546605, 0.026984452415490523, 0.028433890947781038, 0.03916064670193009, 0.02271178578666877, 0.044188133178977296, 0.03379903791937977, 0.045528088230639696, 0.03439621446887031, 0.05639531584165525, 0.04783581869560294, 0.02169267972931266, 0.01819794713810552, 0.04948303772835061, 0.03393424609384965, 0.01275299609915237, 0.08043973910389468, 0.059097497796756215, 0.08889381788321771, 0.03492256786557846, 0.019500716880429536, 0.028242025364306755, 0.0632216977828648, 0.043911783359362744, 0.04412544767546933, 0.01325779196122312, 0.07673430707654916, 0.016655684485158417, 0.050927004776895046, 0.03325748162751552, 0.04426203995535616, 0.025510625055176206, 0.02789848149404861, 0.046922045657993294, 0.01934272291691741, 0.06319539606920443, 0.0473489030264318, 0.07183012101450004, 0.02484772019670345, 0.03708594689669553, 0.059493960507097654, 0.0708544862573035, 0.04296720748243388, 0.03413984697544947, 0.022831945061625447, 0.02691768324439181, 0.01862089709902648, 0.05519423146324698, 0.09862793071079068, 0.05935629211307969, 0.02755054596491391, 0.05434006030554883, 0.11358936069882475, 0.020391351608850528, 0.018344823729421478, 0.10126785389729775, 0.03720462744240649, 0.05474206685903482, 0.013658699208463077, 0.03137379950203467, 0.052785606021643616, 0.05339571078366134, 0.02087975157337496, 0.017422213568352163, 0.036874393990729004, 0.0538442908145953, 0.02038096710748505, 0.04828234297747258, 0.017947795131476596, 0.03431184341025073, 0.02126758681697538, 0.0284275029116543, 0.06364732689689845, 0.08750124456128106, 0.01887405294837663, 0.055247866475838237, 0.04933123513183091, 0.02609950810438022, 0.04549096971459221, 0.05703317692677956, 0.010731581569416448, 0.010731109377957182, 0.01379098517645616, 0.0379561595764244, 0.030513533456542064, 0.048333703307434916, 0.016088913725980092, 0.036648068635258824, 0.02895208072004607, 0.031487437154282816, 0.03893171640811488, 0.03303527148091234, 0.007275496782312985, 0.0646471259824466, 0.01910212420625612, 0.013413009364739992, 0.09540228231344372, 0.02484900596755324, 0.06395508811692707, 0.10358682047808543, 0.018506695414544083, 0.007137237917049788, 0.02467437861923827, 0.04536964712315239, 0.045307993204914965, 0.04294682068575639, 0.039212901319842786, 0.037917608715360984, 0.017007423521135934, 0.05599256342975423, 0.012702931744570378, 0.0410672649013577, 0.035697692874236964, 0.11667519589536823, 0.16747819521697238, 0.08368624185095541, 0.07869931374443695, 0.19701026991242543, 0.08749093613005243, 0.1335614823619835, 0.09641034892410971, 0.10468334367033094, 0.08372239928576164, 0.1389614972868003, 0.13393448578426614, 0.22073174390243366, 0.15315075230319053, 0.07873235415900126, 0.19291373348096386, 0.12349999335128814, 0.10422903054859489, 0.19293902587378398, 0.20250317204045132, 0.163337129924912, 0.1427159333252348, 0.19989731343230233, 0.17000115592963994, 0.1184492331231013, 0.27984037762507796, 0.1428631308954209, 0.10087775139254518, 0.13498548563802615, 0.1147128535376396, 0.16191974660614505, 0.20244032697519287, 0.1264656154671684, 0.19065920758293942, 0.06671219642157666, 0.17185906326631084, 0.10772156267194077, 0.16685118433088064, 0.20571518718497828, 0.1854819111758843, 0.13935870956629515, 0.12354677091934718, 0.09951430736691691, 0.1869832759257406, 0.11391168285626918, 0.11466721145552583, 0.12152410679846071, 0.16588447761023417, 0.22237376047996804, 0.16587708581937477, 0.16794656461570412, 0.10173490227316506, 0.21078574791317806, 0.16068315046140924, 0.12984663248062134, 0.14408801594981924, 0.11997445792076178, 0.16069833480287343, 0.16005205776309595, 0.15320669539505616, 0.11991375766228884, 0.17266453098272905, 0.19148416409734637, 0.18499883241020143, 0.23908746050437912, 0.14320141664939, 0.12469115521525964, 0.11657782612019219, 0.11571183626074344, 0.09936063084751368, 0.10231405205558985, 0.08311504789162427, 0.21678783756215125, 0.11355231268680654, 0.1320535718696192, 0.1921948150265962, 0.11883252271218225, 0.0796409729809966, 0.07193588447989896, 0.13787478528684005, 0.14132252137642354, 0.23560137022286654, 0.1253999804612249, 0.12614316714461893, 0.15771926497109234, 0.1456503852386959, 0.16801539139123634, 0.15230148303089663, 0.11004216939909384, 0.14874208340188488, 0.18134305748390034, 0.252043919172138, 0.11029913803213276, 0.1796386856585741, 0.26770097902044654, 0.11964473655098118, 0.09498166269622743, 0.07971331753651612, 0.11959126481087878, 0.1305927729117684, 0.19413671863730997, 0.1174063523649238, 0.15505746327107772, 0.17116429429734126, 0.17388864420354366, 0.10752559115644544, 0.09887614942272194, 0.07470797674614005, 0.12010961043415591, 0.06552426289999858, 0.13345991203095764, 0.1844826538581401, 0.1810140337329358, 0.09810832343646325, 0.10129814836545847, 0.15156217035837471, 0.17691990185994655, 0.13103872945066541, 0.267171174637042, 0.12301867347559892, 0.11641421224339865, 0.15964770602295175, 0.17803273745812476, 0.13080570992315188, 0.09023582868394442, 0.1817793512600474, 0.20965141971828416, 0.07868688277085312, 0.13459337933454663, 0.1392335389391519, 0.13802247267449275, 0.1569561887299642, 0.14406532107386738, 0.1473481667926535, 0.17532578349346295, 0.15441902331076562, 0.17543373629450798, 0.138533663994167, 0.1501146113150753, 0.1837789049022831, 0.07753921818220988, 0.1366931525990367, 0.19240003370214254, 0.06868785290862434, 0.11543436208739877, 0.0809832954837475, 0.12540349824121222, 0.08254317115643062, 0.17623540421482176, 0.09930316635291092, 0.11782243003835902, 0.06627550930716097, 0.24766009737504646, 0.11864349769894034, 0.11545062996447086, 0.1643948833225295, 0.1469950974569656, 0.16512690810486674, 0.13237276958534494, 0.1829137685126625, 0.11406152247218415, 0.192745236272458, 0.24698501016246155, 0.15349651890574023, 0.11654366506263614, 0.0929337803972885, 0.11250999596086331, 0.19220863381633535, 0.12268627295270562, 0.12982865766389295, 0.12271011815755628, 0.1365507344598882, 0.20539950724923983, 0.11771208752179518, 0.1950710974051617, 0.24006271676626056], [0.01726479662465863, 0.024378289526794106, 0.01255601062439382, 0.08035059232497588, 0.018599423056002706, 0.04041636799229309, 0.08934917001170106, 0.05528957517526578, 0.0579149040277116, 0.030883310391800478, 0.043282879996695556, 0.054820574951008894, 0.015320148922910448, 0.01847918585553998, 0.03182307344104629, 0.029671155025425833, 0.05553332986892201, 0.03531058864609804, 0.03682223585201427, 0.02175165634980658, 0.006500707131635863, 0.011229057072341675, 0.017004785186145455, 0.06523255433421582, 0.03131126613880042, 0.017401700606569648, 0.02299103740369901, 0.028035699033353012, 0.027412129857111722, 0.05526486536837183, 0.022603508296015207, 0.05907540034968406, 0.007828565176168922, 0.01749385308357887, 0.034130978310713544, 0.042420474710525014, 0.013060695164313074, 0.040608547133160755, 0.03058377402339829, 0.015520403558184626, 0.03065669003262883, 0.009125676042458508, 0.02363196912483545, 0.017487940021965187, 0.059235860098851845, 0.00966159572271863, 0.010666923808457796, 0.046616766921943054, 0.03320748684927821, 0.007215123532660073, 0.022960781898291316, 0.03747434988326859, 0.06868454292998649, 0.004681094615079928, 0.09938737784978002, 0.031498131502303295, 0.08126382730551995, 0.00927013972614077, 0.02780550523311831, 0.06706221553031355, 0.04234892054228112, 0.0905821296328213, 0.043868315769941546, 0.04637867852579802, 0.02662040300492663, 0.0259933679990354, 0.09163246155367233, 0.09247573427273892, 0.033907317265402526, 0.013393570661719423, 0.019377177122805733, 0.030621853620687034, 0.036345591506687924, 0.035353317798580974, 0.04373212424980011, 0.07951395440613851, 0.0376393404440023, 0.029031301273789722, 0.02408335447398713, 0.04184259771136567, 0.044873888764414005, 0.02492679974238854, 0.030779726985201705, 0.030182825030351523, 0.04785807570442557, 0.036389797533047386, 0.03288488638645504, 0.0358680343197193, 0.021157184928597417, 0.040009088479564525, 0.013395343466982013, 0.0381122109683929, 0.008261761413450586, 0.017954736067622434, 0.015902206068858504, 0.04205622120935004, 0.015412465600093128, 0.013395445512287552, 0.024957929126685485, 0.08286473632324487, 0.021834220278833527, 0.040568311596871354, 0.03542401849699672, 0.021553350779868197, 0.03956209293392021, 0.016487146458530333, 0.060736957675544545, 0.06835555628640577, 0.041578604650567286, 0.03416395193198696, 0.036607057554647326, 0.05326135236828122, 0.061648133196285926, 0.044186882660142146, 0.029985558467160445, 0.052986887603765354, 0.00821115158032626, 0.13186147436499596, 0.04788079284480773, 0.07862713988288306, 0.07334887428442016, 0.02349914695514599, 0.014515954917442286, 0.010663736284186598, 0.02675426974747097, 0.04498810900258832, 0.06386139939422719, 0.03954065228754189, 0.019115280629193876, 0.015484980849578278, 0.029795115951856133, 0.038300853775581345, 0.07218808852485381, 0.04589059768477455, 0.05465993337566033, 0.06951646078960039, 0.045703287032665685, 0.0257101013630745, 0.041036569673451595, 0.012351555433269823, 0.06635625497438014, 0.03774190154217649, 0.02613175442093052, 0.029899343171564396, 0.06969739639316685, 0.06668358662864193, 0.04942736552038696, 0.03598337891162373, 0.04442015451786574, 0.08872051897924393, 0.06617115592234768, 0.012997838039154885, 0.03372811457666103, 0.08288798780995421, 0.019291223434265703, 0.04253089144185651, 0.07149570184992626, 0.03317785289254971, 0.09042192963534035, 0.059132694150321186, 0.034020157108898275, 0.07627019760548137, 0.025648953960626386, 0.0361321572563611, 0.03708215823280625, 0.015755824861116707, 0.03611629756051116, 0.02947884044260718, 0.05557375094213057, 0.030418928181461524, 0.038434948728536256, 0.012520140771812294, 0.005019022282795049, 0.032432213411084376, 0.04034058358229231, 0.010378184761066223, 0.04132992209633812, 0.005083626238047145, 0.07733683451078832, 0.02218736568465829, 0.02746392990957247, 0.06190808526298497, 0.013997471069160383, 0.08004050076124258, 0.01574358499055961, 0.033402864646632224, 0.034112962675862946, 0.08300716188387014, 0.07781011692713946, 0.03280753604485653, 0.05162820074474439, 0.06952265030122362, 0.002051824262707669, 0.05237746561761014, 0.06009925244143233, 0.02816519081534352, 0.030543122884409968, 0.04312943354307208, 0.010279091347911162, 0.013441392802633345, 0.046884073672117665, 0.034016531717497855, 0.02038335682300385, 0.08807723279460333, 0.0825548599823378, 0.06579061970114708, 0.03499299768009223, 0.00984150623480673, 0.05944105650996789, 0.03881846467265859, 0.03319010946142953, 0.05249989771982655, 0.05867581319762394, 0.018406104718451388, 0.0663699179131072, 0.024742504065216053, 0.03225754524464719, 0.03587789375160355, 0.009127382982114796, 0.03445208705670666, 0.035597833193605766, 0.04042086540721357, 0.024625318947073538, 0.06840951784397475, 0.0227050953253638, 0.010881335838348605, 0.027173160160600673, 0.02693613674637163, 0.07736634972388856, 0.03898817529261578, 0.07343065895838663, 0.062408964440692216, 0.04680202924646437, 0.0316603798273718, 0.015260406962624984, 0.07395008811727166, 0.0031761246509631746, 0.016213639064517338, 0.06377158468239941, 0.02014920552028343, 0.059932770163868554, 0.05120940310007427, 0.051873558477382176, 0.04653799165680539, 0.05188297262066044, 0.06838288958533667, 0.07272135131643154, 0.0675474910531193, 0.0666056240152102, 0.026577479038678575, 0.03300719974504318, 0.045987232733750716, 0.07869537294027396, 0.020200090875732712, 0.029361725828493945, 0.033547839484526776, 0.05157978674105834, 0.02017599890677957, 0.042397293727844954, 0.021540485649893526, 0.021472890839504544, 0.010341887245886028, 0.037243204278638586, 0.02476151603332255, 0.02973674789245706, 0.004757876286021201, 0.002531421428102476, 0.04069574206368998, 0.06850300618680194, 0.028604403087229002, 0.05525327302166261, 0.016708206276234705, 0.028101149036956485, 0.03245157604396809, 0.03544452403730247, 0.046944881542003714, 0.0327021956036333, 0.015003872485976899, 0.03715697042935062, 0.01839747539634118, 0.0058343689124740195, 0.02718209747399669, 0.04603642228175886, 0.045393165783025324, 0.01380169715048396, 0.0328000626177527, 0.053533891259576194, 0.057924180873669684, 0.0708226407004986, 0.012214846265123924, 0.024775809797574766, 0.013054827559244586, 0.0340551642148057, 0.07813845048076473, 0.03360896647791378, 0.03897629721905105, 0.02299848300026497, 0.02977548985654721, 0.017779399968276266, 0.015308705005736556, 0.029853945998183917, 0.013914277242292883, 0.03858164905977901, 0.01794822557712905, 0.09895796378259547, 0.0073368960511288606, 0.05477795340993907, 0.033834286223282106, 0.054136118124006316, 0.05113443134177942, 0.019231176265748218, 0.05283774189592805, 0.0668048090301454, 0.02114617331244517, 0.0198478638776578, 0.017061513099179137, 0.03787422276218422, 0.033021515773725696, 0.06651734554907307, 0.03142927504086401, 0.021521111884794664, 0.048935959857772104, 0.013410176215984393, 0.010553066294960445, 0.0317618982080603, 0.10064499161671847, 0.036780753507628106, 0.041193467113771476, 0.012349027492746245, 0.07263215258717537, 0.037223878753138706, 0.027458263612061273, 0.03779818973271176, 0.07493954166420735, 0.004931172406941187, 0.061676913683186285, 0.024645592566230334, 0.027941277439822443, 0.010788871659315191, 0.05104203024529852, 0.023754239809932187, 0.06357236256008036, 0.02839628632500535, 0.06371381590724923, 0.012756321848428342, 0.02996373747009784, 0.03790291419136338, 0.03662934796011541, 0.03321613658044953, 0.02318359875062015, 0.019090318492089864, 0.03561381163308397, 0.09287144741392694, 0.11334113456541672, 0.19818425847915933, 0.18013221386354417, 0.08735244395211339, 0.1475045076222159, 0.10925765251158737, 0.13417204725556076, 0.16043824172811583, 0.15973242960171774, 0.0616677481593797, 0.2036840477376245, 0.12149527436122298, 0.12393816476105712, 0.13360612996621057, 0.11366197984898463, 0.15825352224055678, 0.13017320714425296, 0.11997325564152561, 0.09628624698962085, 0.09542953397613019, 0.11985135788563639, 0.2650500275194645, 0.08944892208091915, 0.13378586329054087, 0.12243930104887113, 0.0966278427222278, 0.18809550296282396, 0.16150834446307272, 0.1644092661445029, 0.07998117347597145, 0.13692529639229178, 0.18299679999472573, 0.06990096007939428, 0.12911579513456672, 0.06617359016672708, 0.1669523835880682, 0.1295323032536544, 0.12974212324479595, 0.09332049870863557, 0.15347599110100418, 0.14045802323380485, 0.09936805232428014, 0.1601859857328236, 0.18235779600217938, 0.12546229118015617, 0.08196192109608091, 0.24903400568291545, 0.14891166414599866, 0.14063789014471695, 0.18371978541836143, 0.12265298020793125, 0.20626667712349445, 0.1552345248637721, 0.2128152991645038, 0.12685509456787258, 0.23146601946791634, 0.06750003070919774, 0.15558039536699653, 0.22386287979315966, 0.16677771171089262, 0.19235853280406445, 0.15026551962364465, 0.0945685981423594, 0.13286367058753967, 0.17705213773297146, 0.16684937349054962, 0.16421038541011512, 0.11068580439314246, 0.13201907684560865, 0.16326466662576422, 0.26165832357946783, 0.17585263412911445, 0.14384677342604846, 0.11715663451468572, 0.13770446239504963, 0.10949640884064138, 0.11042717334930785, 0.11516554877744056, 0.06998262600973248, 0.1513071238878183, 0.14485192339634523, 0.1876405070652254, 0.1652066592941992, 0.1596694509498775, 0.1655355197726749, 0.1514846010832116, 0.24445373739581555, 0.08008782751858234, 0.11992589177680202, 0.12295668930164538, 0.1120055210776627, 0.1364293190999888, 0.11564355867449194, 0.311334720463492, 0.10786947270389646, 0.0957065109105315, 0.08345455076778308, 0.10162999227759428, 0.22290313441772014, 0.10930092714261264, 0.11455709158326499, 0.18864512268919498, 0.08932731376262382, 0.15438006055774167, 0.16024663404095918, 0.28219164989423007, 0.10278975387336686, 0.0684486141835805, 0.11113739383290522, 0.15865704277530313, 0.09857229189947248, 0.1491682988125831, 0.09457924796151929, 0.12098086954210885, 0.11961571857682429, 0.17687825253233314, 0.19581523403758183, 0.07975216896738857, 0.18482424959074706, 0.19630239461548626, 0.1617936705588363, 0.10626851173583418, 0.10191991226747632, 0.04918731785437558, 0.11328110966132954, 0.14688564551761374, 0.13844727800460532, 0.13090610766084865, 0.057204364420613274, 0.11658423827611841, 0.12015998741844669, 0.21606080001220107, 0.10232420463580638, 0.11995744047453627, 0.1181192668445874, 0.24824560736306012, 0.11860777813126333, 0.16449378192191944, 0.07290740773896687, 0.1410783251048997, 0.10157560769584961, 0.19547371251974255, 0.15543910529231653, 0.15761367219965905, 0.1383294546394609, 0.1784055182361044, 0.08439376091700979, 0.29416391684208065, 0.3314669308019802, 0.10221047792583704, 0.11387463484425098, 0.1252579185529612, 0.17005082045216113, 0.08631882519694045, 0.12893269245978445, 0.16528835491044447, 0.16842412180267274, 0.13043589773587883, 0.19488008343614638, 0.0979257254221011, 0.21067298599518836, 0.1318463493953459, 0.10728926907177083, 0.097766705439426, 0.21066706365672871, 0.1360119946184568, 0.16516980424057692, 0.1629096973920241, 0.07600943659781478, 0.17552407050970942, 0.06928273622179404, 0.09749776596436277, 0.09414449043106288, 0.1757490896852687, 0.08079715000349097], [0.010891622932831524, 0.08528335849405266, 0.03642287505499553, 0.016924271440075245, 0.09101344359805807, 0.08550814018235542, 0.015332813673012424, 0.020057806323166005, 0.04766367383126635, 0.0493934716359945, 0.10066840637591667, 0.053536611230811104, 0.053340020022005774, 0.013011617866141023, 0.08559880836401135, 0.03321880831208546, 0.02700434753933223, 0.018398043139313813, 0.026064090961881448, 0.06591093668248504, 0.02714555783313699, 0.015556325361103518, 0.0887068040901795, 0.03957115826779045, 0.04538686123851221, 0.02109748100338038, 0.03326709243992809, 0.039489191767643206, 0.07978661204106174, 0.037559377742582, 0.036290153075242415, 0.06735416158335283, 0.03291506953246426, 0.0646557794243563, 0.060979806949035265, 0.044893637314089574, 0.003393136053091439, 0.03117216911050491, 0.013101770255161682, 0.017644535037106834, 0.06603933565202169, 0.03134820653940551, 0.07869386638049036, 0.041601807897677645, 0.017183707714139018, 0.05997597058012616, 0.011705310862453189, 0.04020815104013309, 0.017280216598010156, 0.04199489383609034, 0.0330599144945154, 0.010309537028660998, 0.028565525681187864, 0.10169181317905895, 0.052084654962527566, 0.07332443536142819, 0.019030338116863277, 0.03622267329774331, 0.05680383474100381, 0.05949924459855538, 0.047621493868064135, 0.04436771436303388, 0.045101728101144545, 0.02470659339451231, 0.04877318460785318, 0.021997012227075174, 0.011318806846247753, 0.08695538010215387, 0.050875855959020555, 0.01501732391261612, 0.08208836079575121, 0.014258167138905264, 0.03179521321726497, 0.024588642008893657, 0.04364134474599268, 0.015106940099940402, 0.03422601774218492, 0.01071980275810347, 0.0251662314258283, 0.042459148025955074, 0.03649636993941385, 0.05650871971738525, 0.03165429792716168, 0.041096197528531775, 0.048163217143155634, 0.023872211604611948, 0.00932679713514517, 0.013041243473708164, 0.028574455573107116, 0.01333731401246041, 0.0308512143601547, 0.03210474817024078, 0.0190825203753775, 0.03772506221139338, 0.031750665802974254, 0.013396949289017357, 0.049611295689828694, 0.01776830857124878, 0.031531019776593894, 0.09803108070627786, 0.026955697903758846, 0.03486381203401834, 0.04088996211066842, 0.022243190032895654, 0.042009803582914174, 0.016658771819493268, 0.028999687638133764, 0.06225832330528647, 0.035432271179161035, 0.00903312651644228, 0.06986694745137356, 0.005430729170257109, 0.036975611801608466, 0.023701198515482247, 0.03317262075142935, 0.0458918482036097, 0.04089115696842782, 0.039402824331773445, 0.05234868513070978, 0.03489841466944199, 0.04084403430169914, 0.05897346265555825, 0.07049009916954674, 0.08081284642685205, 0.04062836247612722, 0.055351581613649614, 0.038606544403592125, 0.04546001473499928, 0.05791406540083699, 0.04845634692173917, 0.06386911030858755, 0.03745555870409589, 0.04625341513019521, 0.04423928941832855, 0.006394728443410713, 0.06340509731671773, 0.09817144309636205, 0.023319177998928353, 0.021471423242473975, 0.04748373641632497, 0.04618123755790293, 0.018390437980997376, 0.02295615089678904, 0.04555188148515299, 0.03215794531570282, 0.06310218974249437, 0.07634801178937778, 0.03931070525140967, 0.018034593012998812, 0.041478707862552255, 0.003223655730835162, 0.0646804558346048, 0.094505656597903, 0.041881345241563395, 0.009778163002920337, 0.026641199838195462, 0.03710205892275553, 0.024349254854314495, 0.04365431748738047, 0.06752198343747295, 0.03167713752191048, 0.014261008636822226, 0.035129909083480015, 0.027954131437581964, 0.03826980602752883, 0.04895851743640378, 0.04900282365269959, 0.04583786067087203, 0.1016256507136859, 0.07722402064246126, 0.0962520191387739, 0.07567987850052305, 0.030631514528067783, 0.026632468470779713, 0.10197140989475884, 0.07027584113529883, 0.04354070952103939, 0.0034549444308140664, 0.034591065341373906, 0.022498537073261105, 0.0566944384627277, 0.05599792915745638, 0.05548278961214237, 0.00823790229333099, 0.04298220628697891, 0.04723859019577503, 0.09543579770252109, 0.0023421343439622433, 0.033466292297816835, 0.027804798337456305, 0.022848854896437842, 0.019648604647954926, 0.024805337998259347, 0.027245335877523758, 0.07736671337625012, 0.05629563056572806, 0.01665450447035255, 0.025748297848622315, 0.01591655549418647, 0.02316854428499937, 0.02900102721469011, 0.012696229223365663, 0.010751117679319577, 0.04752059518068563, 0.03616135705669876, 0.00734321265554172, 0.02642446674144594, 0.018441766769683454, 0.03255873474699911, 0.057328110124217346, 0.04274215862096753, 0.10880303510930389, 0.023912213364383206, 0.054419625957962126, 0.0717531751433853, 0.008752561298024375, 0.03291584878752474, 0.04347237998445053, 0.06170608750835527, 0.05466710623295512, 0.011883911483892007, 0.031602722374373116, 0.0601485236256849, 0.013865245400666026, 0.001690232636519795, 0.04002503352239728, 0.06490136351203546, 0.03253445538575761, 0.036177253859932534, 0.025862527363642585, 0.043171895522391424, 0.019986014667665586, 0.03031004027434392, 0.14772771595744416, 0.02140519027307164, 0.09227262329659425, 0.037921063412795775, 0.03469669150945265, 0.06745387654518709, 0.03722085079061799, 0.079907173931133, 0.08497034286847338, 0.011038456850656075, 0.06988191657001153, 0.0328613677265821, 0.018464339191268664, 0.05833717492350843, 0.020914461820211727, 0.022923114192963112, 0.019271794008091092, 0.059074097880511545, 0.024682438343006652, 0.017810764984460548, 0.018644827650859952, 0.024046788857958745, 0.025329448253614828, 0.030080161886871792, 0.03337959831696935, 0.05904801881115418, 0.06753206922439858, 0.0401171859994065, 0.013971564549137838, 0.07700074551394209, 0.023803653857612517, 0.09839828053372912, 0.038796927547082305, 0.01929740552441217, 0.021206686178629752, 0.025718498764035758, 0.028537815742311068, 0.04345863540947903, 0.06639944796916097, 0.10880520960199647, 0.036161898824502714, 0.05331467567884829, 0.07475315127521753, 0.06156331313832197, 0.02612333104480058, 0.0045310903351492016, 0.037929672325844876, 0.03548708620655816, 0.0244203414695221, 0.05839474331878591, 0.04664774416596629, 0.02443918459903216, 0.037942144117550924, 0.049376231545466, 0.039916869209264405, 0.024469683157803956, 0.03778190701268613, 0.05182356740988325, 0.04527581368165556, 0.02108768094331026, 0.07243986954563297, 0.05071006016805768, 0.018132378390873782, 0.00980402777713607, 0.06280734931351617, 0.06098493518948089, 0.03695949606481008, 0.040470860185450874, 0.09213361161528155, 0.03571342269424349, 0.02017836635786807, 0.0244925580045674, 0.04585897477227263, 0.01495772296038922, 0.082343236572342, 0.03550744702806696, 0.031090397424122784, 0.09951041851309128, 0.014835459696769249, 0.05287919826514553, 0.03527915869199205, 0.018666221913008485, 0.072500725655118, 0.05950471793767065, 0.007705164571234491, 0.030911665999155957, 0.04529511323198676, 0.025334107085654978, 0.037057489244034514, 0.03771204123040661, 0.02278880030644359, 0.08992872797534801, 0.020781144266948104, 0.013527194350899663, 0.01388724358548643, 0.049862605446833186, 0.05553073606279213, 0.025789702267502435, 0.05261863021587487, 0.030525066431437153, 0.07185180656961165, 0.03217510376998689, 0.03454142308328301, 0.01731123837089399, 0.06737572097335942, 0.03675471896713134, 0.06043635818059556, 0.027269101301499177, 0.02681848778593121, 0.02924215285020182, 0.017449426268285606, 0.03099345809459919, 0.041712859165272675, 0.11021575031918474, 0.026750371616799384, 0.014454614556598244, 0.020895470261166338, 0.00965845736573101, 0.00945446323385113, 0.10363284105551429, 0.12230566251673736, 0.19464918645098805, 0.11355551876476966, 0.23894621495855972, 0.2314477923209779, 0.2571789873763919, 0.08423417690210044, 0.2248596286517568, 0.14154917327687144, 0.3103598055895418, 0.13774921389995143, 0.09427976168808527, 0.08413797229877673, 0.21174558234633878, 0.1718075730605051, 0.17643182101892307, 0.12465332052670419, 0.17933450901182368, 0.1629184844205156, 0.09210258984239772, 0.05856815725564957, 0.1521833034348674, 0.12984091794351116, 0.17123306170105934, 0.17000413936330006, 0.10987275192746893, 0.12698826554697007, 0.15743055468192324, 0.12795286456821486, 0.1338558181305416, 0.10999824167811312, 0.1416557456832379, 0.15549007599474862, 0.1042387229972519, 0.1473409531172365, 0.09065650767297484, 0.15069219516590238, 0.2869614033261314, 0.13100472424412146, 0.12267350059119053, 0.12628726253751665, 0.13390353822614998, 0.13426276738755405, 0.06206727593962569, 0.11624012666288763, 0.1425265966099687, 0.12724901171168312, 0.0922236118640285, 0.08021274581551552, 0.15837236976949498, 0.17453094333177432, 0.15891443443251774, 0.18557594128651544, 0.0843818939756602, 0.1026183771318756, 0.1507273135939613, 0.2699512895196676, 0.10363096342189237, 0.18677042797207832, 0.12698703358182684, 0.15479138848604634, 0.1504399094847031, 0.06824097610660829, 0.17208892124472186, 0.20131901605054736, 0.09968047423171811, 0.14790060668019578, 0.15120694879442453, 0.11330660985549912, 0.1950533303897828, 0.08573266954044811, 0.10478458745637909, 0.07339654985116795, 0.1507696308544837, 0.11617311072768643, 0.11205620234250091, 0.12739582336507738, 0.10563587537035346, 0.07320155054912902, 0.16216673335293308, 0.1868105336325243, 0.11369452302460559, 0.11800096108345315, 0.1267213892424479, 0.13601432496216148, 0.15454725158633664, 0.11907813648576848, 0.17165477969683707, 0.09297685464844108, 0.12272207415662706, 0.11878701421665028, 0.10411037597805262, 0.27888193842954934, 0.11140281552798115, 0.21778011869173497, 0.23842942784540355, 0.17500112357083708, 0.12721744074951857, 0.18520526820793748, 0.1523797499248758, 0.07903899473603815, 0.1130195397126954, 0.1418991998070851, 0.167591595381964, 0.2174737156019546, 0.1366769292508252, 0.17215344356372952, 0.18899823655374348, 0.08890653087291867, 0.099260611605132, 0.1507330875028856, 0.13286292843986303, 0.1513482685550116, 0.12750058493111283, 0.10528594531933777, 0.14128161419648677, 0.13155749067664146, 0.1707019956666045, 0.1418744120746851, 0.10388019145466387, 0.16917158325668424, 0.22125100978882983, 0.21764567121863365, 0.2168125510797836, 0.19348420755704865, 0.1273746127844788, 0.10846032615518197, 0.12588853627676144, 0.16382556699682027, 0.18838988326024264, 0.16223101818468422, 0.15409814834129065, 0.18014766537817195, 0.1638133215601556, 0.1053122099256143, 0.2014084448455833, 0.11007058623363264, 0.10876742686377838, 0.175314087246079, 0.18146726331906393, 0.12185169820440933, 0.1748563305591233, 0.15950130997225642, 0.08095412908005528, 0.13693944172700867, 0.13403647171799093, 0.15760975365992635, 0.1478426597896032, 0.15597382269334048, 0.12683839624514803, 0.18786325526889414, 0.1427634753054008, 0.12961450353031978, 0.09516429781797342, 0.08507970575010404, 0.14268706378061324, 0.19691647728905082, 0.19721673539606854, 0.1521455726469867, 0.07763660280033946, 0.21452329267049208, 0.06618946470553055, 0.12838059396017343, 0.0745524448575452, 0.1400692862807773, 0.21282414556480944, 0.13248155359178782, 0.1390409070882015, 0.14206578227458522, 0.16951596946455538, 0.13443497533444315, 0.07704743402427994, 0.189982992305886, 0.1500395653420128, 0.18933052575448528], [0.022959492416703142, 0.05184914552955888, 0.07016648567514494, 0.07207865884993225, 0.01589875879290048, 0.031216824136208743, 0.06149519140308257, 0.055750033279764466, 0.05694628256605938, 0.027817387017421424, 0.03707517091243062, 0.08332951372722164, 0.04280878863937687, 0.032953338377410546, 0.0589405632490525, 0.05238468300376553, 0.021981087593303528, 0.018294645269634202, 0.026984868018189445, 0.07659692069864832, 0.07599807431688532, 0.026188990705122706, 0.05289373322739266, 0.041859841512632556, 0.04930564587994013, 0.04487077545491047, 0.0033506010186101776, 0.07939740011352114, 0.0748980333446525, 0.02188854919950245, 0.028565286338562146, 0.06773637505830266, 0.018335535751248244, 0.02327142265130533, 0.027470065615489148, 0.039587630235473625, 0.05547511209442746, 0.06243914016522467, 0.04079048092535231, 0.03332654589030426, 0.08229121944168583, 0.049433321255492046, 0.049196702311746776, 0.061082653774064966, 0.04081573992152698, 0.01040096127326251, 0.05504108557943255, 0.030859543112455867, 0.020208725763950497, 0.05040711548645049, 0.04717668394732755, 0.05021461351134349, 0.02745954567217268, 0.08621628265245818, 0.011940161639358848, 0.04304992355173454, 0.06814601088990457, 0.060685500866384245, 0.021783622505608946, 0.04362149229564238, 0.054850194064783864, 0.024016653951548506, 0.04939559046761133, 0.023937310943438206, 0.04015906910353806, 0.05996373627567664, 0.030808509327471256, 0.07178169587859884, 0.06284216346102767, 0.04324454435845837, 0.039365219708997756, 0.037008088183938526, 0.05958009416644927, 0.03845717234071344, 0.03555051385774277, 0.04627809896192048, 0.013006207609578269, 0.07512187992688268, 0.04498123671510257, 0.049193281010957435, 0.040891516910050996, 0.0642762599454727, 0.030601528051192872, 0.03657536784885451, 0.06968870584387332, 0.04593516365275718, 0.013044714869465679, 0.04628010647138581, 0.07305462757358328, 0.032637491458444856, 0.07987886099726893, 0.04293327649065759, 0.012428947520675138, 0.036068763001821935, 0.009705367592687253, 0.11109621947980486, 0.04249952828104142, 0.08559604015317746, 0.033989402509178035, 0.045098766931914724, 0.04046157962875441, 0.029799058611388318, 0.06766989346942864, 0.0242049980442971, 0.05366891389712691, 0.022909391882421914, 0.044496105911093764, 0.0382931391504826, 0.04852318103075959, 0.00851938035339117, 0.07046878468827344, 0.004207795036563766, 0.039699598055449314, 0.026653582572180312, 0.07188595278421417, 0.03516250792017672, 0.03689781988214236, 0.12145610380684957, 0.032806033195811324, 0.03661901726445649, 0.017262551627936773, 0.03523263716488145, 0.0589418471645331, 0.01259089063751162, 0.006063372957214597, 0.07174087775638327, 0.03806026063102763, 0.034392121524433605, 0.02435206202790141, 0.017199493195221294, 0.05642590345814824, 0.04917610400298145, 0.023044945155561436, 0.016291857718897518, 0.06667703346465714, 0.021454292618727777, 0.04853258033108432, 0.10036282707005739, 0.03248322493163869, 0.052423256129259244, 0.025808593636611477, 0.04287999770895112, 0.019571070624806453, 0.03409045333683025, 0.006941008041394525, 0.05954883119557053, 0.04528086028585676, 0.018012245091085788, 0.04948816596879624, 0.03839721051917877, 0.014496047733700834, 0.055169083789223805, 0.050131481839343905, 0.03965149946452584, 0.06455859518609941, 0.025621661479817703, 0.0016436615942438948, 0.07885030368925072, 0.05471331976877991, 0.046066701906966045, 0.06872035897686146, 0.037901003161096014, 0.00577880663513497, 0.04268154742021579, 0.06787927559344098, 0.039106599797378294, 0.049073498375946656, 0.03324606739624869, 0.046608002157881856, 0.017556495913595427, 0.04960445308825001, 0.08404230946325697, 0.03957381515647285, 0.012962469136255095, 0.08742717080167495, 0.05930103921855334, 0.08772100933128968, 0.02043166878138436, 0.12210149026941508, 0.0754091059206985, 0.015265024048858322, 0.008255725897470256, 0.059172699620830826, 0.058474078905419447, 0.05875344555533957, 0.08300905436044559, 0.017275099489779677, 0.009285026280849706, 0.031204638071358204, 0.04347277703345753, 0.04038407714688219, 0.022192262003954966, 0.019869074458256364, 0.020271131106710527, 0.015771983271406498, 0.05297058633004781, 0.04350284885731526, 0.017450133163947612, 0.03108360862825066, 0.04654017728171311, 0.007106756984285312, 0.015595606309943832, 0.015194384577625897, 0.07255882839672267, 0.10736023323261179, 0.05261254089418799, 0.02959676585305715, 0.06313543053693138, 0.00768899734794104, 0.029657375198439695, 0.055691321977064945, 0.045638152441824786, 0.007477132276108023, 0.026013079441327136, 0.03198532547685318, 0.024357195834454615, 0.0011063871465921693, 0.032765537907835096, 0.02513237650418887, 0.024905704194679856, 0.03252492249885108, 0.026787584756675642, 0.11199419590411708, 0.03637227913714014, 0.06936699224752374, 0.06109781585109886, 0.027666128044074867, 0.04222006144118495, 0.05481408486957662, 0.03882855045958422, 0.0371825151523808, 0.0730473619478289, 0.08691070281201974, 0.02192303494666703, 0.03796243814576883, 0.0516892609448405, 0.035022368174395524, 0.013661926623171894, 0.04300017739296891, 0.07076388486893848, 0.030876491910021286, 0.04872385034104809, 0.05561749683693051, 0.027331126293574926, 0.0483527839242015, 0.07747957177343778, 0.03889892832376063, 0.03385224619705696, 0.024570301684434526, 0.03628048660175409, 0.0300774604693288, 0.017605416433070786, 0.025587843665562104, 0.07067022583214566, 0.026542397718003485, 0.025294639672210906, 0.04455416783457622, 0.08024861381272785, 0.03905564393789973, 0.032082442921819165, 0.037498146848520264, 0.021087651257403195, 0.0030748022436455358, 0.02508298657630803, 0.013515530572476564, 0.02611435662402073, 0.13175528787542135, 0.0031314529269366176, 0.046122118073981255, 0.04614111705450341, 0.03449529118370265, 0.07305437524337322, 0.007592579377160291, 0.03546333377016708, 0.02024042474658927, 0.05363253010727931, 0.06757695431588218, 0.04338111808465328, 0.035499899386195466, 0.04065719862410333, 0.04817700624698773, 0.039305476821027696, 0.01987129533517873, 0.039554589820909314, 0.05392634637246374, 0.02434042515233159, 0.061541408649645746, 0.03155037127726246, 0.03316480593639426, 0.026423934250487946, 0.03648902267741505, 0.021182427226449363, 0.05674661515513435, 0.019740809075301513, 0.020087210214114748, 0.02660884776560124, 0.06946815439732745, 0.02674319319339702, 0.06059886254661251, 0.06593216210603714, 0.04093622759683058, 0.021161040385777596, 0.023170638996816706, 0.045976939145475626, 0.03476727717497852, 0.08854224768583663, 0.022675962318317033, 0.080150093708653, 0.06346763810142875, 0.005602816518148757, 0.04684091778472066, 0.02814531238982454, 0.0735668430570513, 0.033928936027223244, 0.041617036768002436, 0.023622506741958205, 0.016374481019738596, 0.03828877532214392, 0.05208546019275673, 0.049064525810536, 0.020893136206723284, 0.05587886269495357, 0.04359669714176562, 0.03043325534235919, 0.035396421735640615, 0.021522195420402568, 0.01106067396904109, 0.03394042076251935, 0.01815211209759582, 0.02188793136156164, 0.017239053377124947, 0.05591416294919327, 0.039343563839793205, 0.03878322379023302, 0.018262734774907585, 0.01745038363878848, 0.049132517669931985, 0.011482854879432125, 0.009802553686313331, 0.045069893676554784, 0.034235075654578395, 0.03049446768272901, 0.03085263742832467, 0.011949721429118654, 0.044903222151333466, 0.018867108301492408, 0.06023320267559029, 0.041073795800912194, 0.06296523381024599, 0.05849988338013645, 0.05752604462031741, 0.02512472310627345, 0.1547920861048624, 0.1641215058043599, 0.22451665252447128, 0.19303578708786517, 0.16963091329671443, 0.09480210748733953, 0.19682632118929178, 0.29941283049993217, 0.11152040882734582, 0.1764948887284845, 0.16186074586585164, 0.20068534067831933, 0.18570348678622395, 0.07589326080051251, 0.110341269755736, 0.12948222312843427, 0.11560843282495625, 0.11933451140066609, 0.3307812160346657, 0.1844831436756067, 0.11186363728484139, 0.12810693442588672, 0.21939727332210168, 0.1169468071020674, 0.12499206641223282, 0.12646135553950444, 0.14185207342961803, 0.1119288572226651, 0.16713619872462004, 0.13318052311660722, 0.09246367437299341, 0.22786842891946435, 0.10765252067358233, 0.21872601559152827, 0.1693710428662598, 0.15725275094155222, 0.10101769817993045, 0.18811175599694252, 0.13416612491710111, 0.06754482674296014, 0.1490354395355098, 0.07220607076305896, 0.13490671408362687, 0.12553006410598755, 0.1474410539958626, 0.1529361677239649, 0.23068254900863394, 0.10477868738234974, 0.1492448736098595, 0.140524564194493, 0.12784424383426085, 0.096725398034323, 0.17986550083151087, 0.22657931840512902, 0.07413859362713993, 0.16701326938346028, 0.200169830059167, 0.1013555089593865, 0.1328202401055023, 0.1406144382781349, 0.1320355079951696, 0.12968002032721415, 0.09008581837406382, 0.10539729715674184, 0.15427715436089784, 0.2091086722793989, 0.10447845896123908, 0.17751283332472667, 0.1346302789170295, 0.16830359701998532, 0.1248487873817794, 0.12319967587245628, 0.07849313027691096, 0.1363355413195677, 0.14239393029129133, 0.13907940970966592, 0.14096388593316078, 0.14610978949349374, 0.10191234236117452, 0.12095507248886861, 0.07624735429999419, 0.17810738267144188, 0.10699246195144951, 0.1267158379778266, 0.15483199880691245, 0.08382905332837254, 0.08961275118053891, 0.15769670368172228, 0.10901553425355814, 0.11012560906237923, 0.27933435165323317, 0.09335283408290707, 0.1047133635438513, 0.1586931259953417, 0.05836657510371879, 0.20882583979982883, 0.13880034734029323, 0.1226931823475752, 0.088092179648811, 0.15681060904171318, 0.17005757399601862, 0.0808011501794681, 0.10429275876958854, 0.07888980821007863, 0.1774197383201681, 0.12134547927416861, 0.11624882463365793, 0.21658204001141712, 0.12111810749047436, 0.20062377210706472, 0.19969801709521562, 0.10334211212466471, 0.11890300447703339, 0.1928082000813447, 0.17661302379565313, 0.09772747551323846, 0.2270927361678332, 0.2378868733649142, 0.13218744046753272, 0.14108656294411048, 0.12013945219223388, 0.12578907364513725, 0.11480375920655206, 0.14024885633261874, 0.18145198991987854, 0.19100084784440696, 0.1378295142785646, 0.09351945365779102, 0.09198654763167724, 0.18012612825259566, 0.11206396520719863, 0.15942433441523463, 0.15161702991463244, 0.09328864573035389, 0.16524056060006842, 0.12078511324943975, 0.2017683270969428, 0.2481918313424103, 0.09573828225256875, 0.10211372413323261, 0.08634097088361159, 0.12986825866391882, 0.23567087977426127, 0.16174780583241954, 0.09006067441077903, 0.13073349895421416, 0.09609996050130576, 0.21846650139195845, 0.11419105692766607, 0.06836179774836637, 0.07790696719894186, 0.1459773161332123, 0.09470453733229078, 0.18386117939371616, 0.14088082476519048, 0.14798785356106237, 0.08043410620302893, 0.1278649497544393, 0.0686297650099732, 0.10519494317122735, 0.24633107415866107, 0.1638564106542617, 0.0664977305859793, 0.11744676230591722, 0.10314666011254303, 0.09305250918259844, 0.12919035129016265, 0.11997830224572681, 0.19637852412415668, 0.14157238765619695, 0.15957466384861618, 0.18233048496767879, 0.17150287691038102, 0.11855452903546393, 0.18486206943634897, 0.1468986479449086], [0.04029907155199908, 0.035918017965741456, 0.08106428605969995, 0.013265579873404931, 0.05063909229647834, 0.05383203053497709, 0.0718189739563968, 0.08374784010811709, 0.03696524028782733, 0.047616098454454914, 0.03616520880314056, 0.01685659499344183, 0.008643779146950692, 0.027520706062205136, 0.08871165773598477, 0.056130795856006444, 0.08716574928257614, 0.012957258331880439, 0.03241860984417144, 0.03229021458537318, 0.04756684211315587, 0.026539438404142857, 0.038468226630357094, 0.06679424826870672, 0.05285085193463601, 0.06101280654547736, 0.09282107042963617, 0.09207067007082514, 0.016707859322195873, 0.036091669389861636, 0.013414646728051594, 0.07060916192131117, 0.032146672092494555, 0.01062668919985299, 0.11173641090863384, 0.058070417362614535, 0.0221696580410935, 0.008936178837757325, 0.035532809924916364, 0.012975685858691577, 0.016751794464653358, 0.03668066376121715, 0.038306189817376435, 0.025671127477835398, 0.0427055373438634, 0.05038998671807349, 0.012711711351585109, 0.014679079904453829, 0.01814397815905977, 0.06500835894257762, 0.03200486993591767, 0.026867519627558067, 0.04096083721378818, 0.02817307242366951, 0.005181550768611487, 0.08185063605196774, 0.025915325604728423, 0.014355392195284367, 0.045955272144055925, 0.035441841173451394, 0.062415710563072935, 0.013610942933155457, 0.05049414714449085, 0.0899143674178049, 0.04232703460729681, 0.12455743504688144, 0.054491462142323144, 0.05503358246642165, 0.03563533762644511, 0.05336531612556428, 0.0562836931203492, 0.01912000068841735, 0.058518730220384896, 0.02809285739203915, 0.02000622891500825, 0.060507481903187, 0.03715827660926152, 0.05864027545612771, 0.029414149285003077, 0.007175350447141682, 0.023483751101593953, 0.030990825325716287, 0.028014048730256036, 0.016264140358543955, 0.0562669391365489, 0.023449936998076737, 0.056245843588840216, 0.021093098621349782, 0.04651847317290958, 0.015821395463717636, 0.0258194772322895, 0.051295948651386425, 0.05053279077401385, 0.01609001210454153, 0.02774914653855376, 0.026861665937758517, 0.004150282766204327, 0.028556642173498403, 0.06407859633327462, 0.018088361612171866, 0.10765030165202916, 0.053908186018816195, 0.006712484537274577, 0.045809106159140356, 0.02445518159220228, 0.05552358918066602, 0.041133976556011476, 0.045717896209680475, 0.06699882127577439, 0.0035910515316572855, 0.007214197703433456, 0.03803161744144745, 0.01723420158668887, 0.03657665918581188, 0.049591832867008634, 0.06183710996992886, 0.007913163517514477, 0.01097104201107868, 0.0365199962106999, 0.02563676975114504, 0.045983076706761494, 0.033596724751987495, 0.10379372382885776, 0.028223171102581546, 0.04501797302509658, 0.03617224436311517, 0.03452593446127139, 0.12333357415627688, 0.01770373430190375, 0.055392919239238836, 0.020505482789303642, 0.04279825385310687, 0.037918803573120385, 0.057269228127552196, 0.04032639742945321, 0.012752957136399345, 0.07160257111536339, 0.04910195973934606, 0.08172574001946487, 0.007735527224213001, 0.007306680436158786, 0.039631524559808895, 0.007448433889294392, 0.037424956244649366, 0.049549489631317556, 0.09231946023646742, 0.04436379582330119, 0.025981831313401926, 0.019766218356380705, 0.039062787109287456, 0.059739819189417176, 0.054084613075247034, 0.029720609891228378, 0.02492628580512246, 0.016069821976998355, 0.028666361286013853, 0.016933049191720784, 0.06263751623919234, 0.03944872987631243, 0.01736463589622872, 0.017592631083971355, 0.07781039152177982, 0.01106902869651094, 0.028337328258203343, 0.026653695749701, 0.012390155461616814, 0.02911974301241571, 0.08131890950608067, 0.1133741156081669, 0.015389096297440119, 0.014023694857314695, 0.005534701740543824, 0.014876475415803725, 0.018724749534158036, 0.04174422603682615, 0.09812655800487846, 0.03237613302189857, 0.045067106912028976, 0.08472959758364595, 0.009206259364873404, 0.04751656531880144, 0.03927712677977979, 0.022242006307351403, 0.05924218690779526, 0.0708138091431465, 0.11786453207605518, 0.09458704793360084, 0.02701762641663663, 0.04425389117386658, 0.012817033239116427, 0.0718065355613362, 0.010149398258363362, 0.05075970613688696, 0.03689190496515948, 0.027349047304596752, 0.0061206333612062735, 0.02019328167079948, 0.05532426686841063, 0.050937194464495406, 0.06744509693817236, 0.04809837570064701, 0.011245923305978067, 0.05789824281237088, 0.02108746386511484, 0.04787074045452755, 0.06634918972849846, 0.010936748294625431, 0.020120495537412353, 0.03040277533727931, 0.0587050797912525, 0.07708144665230066, 0.030471852587652393, 0.03556349402060732, 0.06367406647768803, 0.05332538115908392, 0.027124421467306092, 0.06293929574894719, 0.02498203222785378, 0.019129418542433996, 0.0056455428875779035, 0.02001209373702295, 0.04246356009389274, 0.03273590024036821, 0.03845608880510554, 0.027088646238553338, 0.02934961397841107, 0.05761987435107585, 0.03684326460643206, 0.03587156694266014, 0.028205025591887534, 0.06728811786160804, 0.03666821794467978, 0.033029890910256654, 0.04685571249865461, 0.04729553889774252, 0.009651977488829289, 0.09015696807182394, 0.016494228402734734, 0.031729128677397966, 0.051854370249202475, 0.028811889023927506, 0.06828135636169463, 0.02792412826238433, 0.02666126751137199, 0.03654628308140673, 0.022499433216580655, 0.05833166818774771, 0.007404169882647693, 0.031557128531858325, 0.03140193432045635, 0.06669906040770002, 0.005519804517462035, 0.031291417399188504, 0.05625568075629417, 0.05336406560672913, 0.0377526775264414, 0.02921011433500098, 0.0616490683023585, 0.010547834153840085, 0.07014160888502374, 0.03934730055334512, 0.06285269453655928, 0.05262622609734535, 0.010279520865879022, 0.0785759613791015, 0.012943554575031158, 0.024428388205706142, 0.03702585519931745, 0.04856375053350348, 0.0366457939526299, 0.06457507828599773, 0.017002629247144796, 0.023700992569501977, 0.045221143373055384, 0.03501594117551576, 0.0423725171276601, 0.02844213435309939, 0.024925454599724617, 0.03180831583449617, 0.030367755243787542, 0.03531094116624445, 0.017310442417510785, 0.027887150754395407, 0.018488876448827796, 0.05322702432749793, 0.03641028451966122, 0.054466136352857575, 0.017959472825168632, 0.03052127405680949, 0.015809771575732157, 0.023107083325157873, 0.005890885777262156, 0.026821942483366, 0.01888221100671217, 0.044857995671918616, 0.07553312621894293, 0.034552918950794265, 0.03756222387892194, 0.0069842942684772424, 0.007351559033850208, 0.024670116836205125, 0.06233184045413509, 0.03692579884955194, 0.014346413136081537, 0.07690244063269347, 0.015325468266382813, 0.04094743402674794, 0.0027180901224710396, 0.028165493240521755, 0.014337159482238349, 0.06887474053655751, 0.040041564861894585, 0.031131139476201497, 0.07912878718343563, 0.044131165923317894, 0.042908195609925315, 0.02715487735258648, 0.019087348046014085, 0.02008904702961445, 0.059176555078011006, 0.013350944482226623, 0.10244159755529836, 0.05261662641714793, 0.0171580609458033, 0.018271423468831927, 0.04843295071623288, 0.02098619967000559, 0.0783253826375585, 0.03574078938981984, 0.12074985381332226, 0.005028273617426748, 0.01593638939084485, 0.02696679857763229, 0.02975656509079272, 0.08104978449409828, 0.027237699177931063, 0.022211394571058918, 0.018036361179838423, 0.04390264752146322, 0.03757905578822829, 0.02035073015576927, 0.02840741854015505, 0.04380869162559975, 0.04914727898722049, 0.015283884804375703, 0.05101209200802259, 0.03082128539972473, 0.024799011189315934, 0.020659120345953852, 0.039633602573303506, 0.042027949093608186, 0.0358536477870075, 0.09948125210939907, 0.17721668671583757, 0.24786285212030634, 0.05156291401362978, 0.06539526279084384, 0.1486126528470777, 0.11949508247198537, 0.24835127434926108, 0.09900581004330888, 0.12958829087438062, 0.21985381288686767, 0.08114114287309349, 0.13167240482289344, 0.09814547534915619, 0.1934416824951768, 0.13593423238489777, 0.1427758246427402, 0.14295116445282474, 0.16817853029351681, 0.09160948466160335, 0.061261570735950954, 0.19360088801477104, 0.1811759258271195, 0.3051590424729511, 0.1338665495859459, 0.19419816846493632, 0.14059359877137467, 0.21012571145547554, 0.07782602857332677, 0.17960227589355782, 0.12327543430728838, 0.11926595921977423, 0.14763891056645662, 0.15123382938327268, 0.21538326371228322, 0.1379439831362106, 0.0795353356807027, 0.11259753970080055, 0.09499600098934025, 0.14825299324002117, 0.14545696671120822, 0.12812813016353175, 0.17081181867979467, 0.09606010717106983, 0.08186544931959361, 0.09198487037792802, 0.15131162130273879, 0.10423556886962615, 0.08419924401096068, 0.23740507109323516, 0.10664907022146508, 0.12371189877740107, 0.07410974634694867, 0.15719287446700037, 0.15830841148272157, 0.13647297222632915, 0.08666662528412417, 0.07336016235058196, 0.16595222085015848, 0.14937023719539866, 0.1819212202099152, 0.185227592010051, 0.17036491219187155, 0.2680192713160068, 0.12585071643115953, 0.17811232537496835, 0.1819657045416534, 0.0966638962563593, 0.12442943683709018, 0.14093463047174737, 0.1331989877508022, 0.11957032882492058, 0.07514621494919993, 0.0984324341698084, 0.167916092032101, 0.19748718885239214, 0.17765542957931757, 0.16851559892529622, 0.14200247707776725, 0.1670267913141288, 0.11480784101877362, 0.1749460562132299, 0.10078145773150027, 0.21392820897744969, 0.14171591901686043, 0.13086757535347715, 0.16376471088733524, 0.17670586647000164, 0.14800704549998045, 0.09064498954103328, 0.0644152938912157, 0.12151022863690741, 0.21846050483873114, 0.17324601853033528, 0.18952661601360887, 0.086254963389365, 0.04301748427678831, 0.1683977310312912, 0.1951783971162513, 0.16782281891210005, 0.2209548483369872, 0.21235898224404082, 0.15761515649501234, 0.129014061531052, 0.14181542617734522, 0.09715994034195319, 0.1559150594403036, 0.11022564314771444, 0.1733521159621887, 0.1309214107459411, 0.11363439421984367, 0.14288235252024606, 0.19230049685575068, 0.15105810365639627, 0.1319839881034568, 0.1291852304711938, 0.07220078667160124, 0.12347702388069592, 0.15634920098818839, 0.2972893085097894, 0.1423138377140276, 0.17412412766134366, 0.19295587262604386, 0.08329818767379038, 0.12446321939933114, 0.11645009508356452, 0.09302955455495976, 0.19549490825738758, 0.18232371658086777, 0.06822504961746745, 0.1201062930340413, 0.13632047572173178, 0.16019857255741954, 0.16762441315222532, 0.14040886337170377, 0.14674150559585541, 0.20442300417926162, 0.18883206968894228, 0.2049663453362882, 0.15475871914532036, 0.0849251906038262, 0.13579077523900196, 0.11570647053304128, 0.24381810275372118, 0.14228565094526857, 0.1927114388672635, 0.2113559696590528, 0.0810439363704063, 0.12170489397249185, 0.22427030402468517, 0.13929166394518688, 0.14717025915160775, 0.25934510864317417, 0.2812836173688993, 0.0880154712649528, 0.1711910858284682, 0.0989159062737599, 0.13247911934740841, 0.1785725014633499, 0.14440449740504846, 0.22676740831229836, 0.10654698038706556, 0.13314249546965584, 0.13007169618504122, 0.11368882333044894, 0.13949324609711766, 0.13341885642148554, 0.22965103795286268, 0.1674064146936871, 0.13530766678741202, 0.07358622795436531, 0.10691782415960915, 0.13200024113757536, 0.1214077380427625, 0.11066623395890929, 0.15700217220000923], [0.034772186481859535, 0.034002887332462706, 0.06025823902746197, 0.053325525877880864, 0.00638679256553587, 0.0233410342480056, 0.03390379577467684, 0.02290613756485982, 0.027589211858867202, 0.024348551669390872, 0.049130105689982884, 0.023121002304833382, 0.05693531362339854, 0.05492017116921488, 0.06657767473370768, 0.05137816748174373, 0.023447914645657875, 0.029865543911000714, 0.043299474418745376, 0.0620105276175309, 0.03315379246487282, 0.03356229281052947, 0.044188775136717595, 0.013118665247020544, 0.032448347701574676, 0.004563944285109756, 0.024840636397129856, 0.03352471045218408, 0.019815185260085855, 0.035108197553199716, 0.04777974201715551, 0.043083476048195735, 0.015681233453506138, 0.009091592910408508, 0.028976757130294573, 0.061133765484555624, 0.0823491663322784, 0.06360749583109282, 0.025412468603462912, 0.056337213100050576, 0.01568884417793015, 0.03983188587881159, 0.05591895722318441, 0.11966278558247723, 0.02855800586985424, 0.01483301617554389, 0.031640030138078146, 0.03681983500428032, 0.030250989439082332, 0.04134078342758585, 0.07235919067170471, 0.01037303518387489, 0.051885562716051936, 0.03931955907319207, 0.06168437968881335, 0.028516304591903463, 0.033505344108561985, 0.04144682519836351, 0.032511819881619886, 0.08916932536521927, 0.06160643562907353, 0.04234270134475082, 0.03738200815860182, 0.07670479928492568, 0.05230018206930254, 0.007784821136738174, 0.03224090629373677, 0.03042693224415416, 0.02247803709906293, 0.028863240077043884, 0.016500978235853836, 0.006501418665720848, 0.02648129298904678, 0.07646743819350377, 0.04397171549499035, 0.01958185403054813, 0.04031231888802722, 0.01759766470058821, 0.0837558478815481, 0.0697364704683423, 0.018580865653348155, 0.02287286893988494, 0.050069545904989354, 0.05272712107398547, 0.07477401304640807, 0.01230934392879135, 0.035492507595336065, 0.04453152490896173, 0.11562642248463817, 0.009899039378069574, 0.01654785042774165, 0.0926065600651782, 0.05737172614317387, 0.03413572063436732, 0.058810717091546394, 0.0699425871425774, 0.031357680054497905, 0.03777893100050278, 0.04348964605014771, 0.039455553924199194, 0.016646659969410393, 0.03931675375497434, 0.03369002013641875, 0.045087085527484305, 0.03360507020261139, 0.0672931941517163, 0.06709953813697211, 0.050053801242029294, 0.041963248659158126, 0.021173113273107447, 0.040792596046230756, 0.039320290088653564, 0.0128280606259068, 0.02371912880335003, 0.04905719339149073, 0.01693970069027273, 0.004979574814569787, 0.0650921993656084, 0.012426197863533162, 0.01929973401274765, 0.04041113585117273, 0.022216563629626762, 0.008587470547354314, 0.025310497512691654, 0.09512265591183677, 0.02824953589879442, 0.05654108106682543, 0.07296868687262759, 0.006131615755293751, 0.03747853930690326, 0.01214690450069611, 0.01450871248380281, 0.08398874866543338, 0.008899045478756307, 0.06906913127750158, 0.05203094202443026, 0.017253397236345336, 0.05810444854432717, 0.10290158068528399, 0.054279196774587035, 0.03686435644340236, 0.027865927186212502, 0.05373608939407859, 0.028714535947074182, 0.03548034008417744, 0.028255820034246426, 0.05937604437349364, 0.1050431739713531, 0.016010789695428684, 0.02631273826409597, 0.08866839794791304, 0.024351100946660154, 0.049905386549653485, 0.07046098471619189, 0.04534723426331766, 0.05438732769107446, 0.017677456708042882, 0.03636780398664996, 0.04124066770600621, 0.04461228170839604, 0.017955001385416836, 0.046452195674646646, 0.06670443355687894, 0.03401906244107522, 0.035674916362040676, 0.024613876885268837, 0.03830449772067368, 0.022152900346554816, 0.011928656495001633, 0.034550061682239175, 0.006484691584773827, 0.023500323259213474, 0.03591409571527038, 0.019482248535496183, 0.06345750036416575, 0.02580751937784953, 0.013665810838574544, 0.004526636057562428, 0.0235727772815153, 0.008611020748503506, 0.06582230198546313, 0.021441061981022358, 0.042603250840329565, 0.02930304421170149, 0.03371865961526055, 0.041217163889086805, 0.021897234182688408, 0.02978635675390251, 0.0750134966801852, 0.03569556291040499, 0.04431878085597418, 0.02039074675849406, 0.10688526614103466, 0.036354935145936906, 0.01720590535114752, 0.038429783380706795, 0.007198972080004751, 0.053148456863709725, 0.0448250220506452, 0.05969290061329957, 0.007373238095169654, 0.03842936777800787, 0.0382114732201444, 0.009836257395363646, 0.06359121311106719, 0.03811825576121919, 0.013118635561113479, 0.008234231445385376, 0.05377744557335973, 0.05591183631622698, 0.09092963286093436, 0.028548304144351278, 0.03291455745056737, 0.04790774764842354, 0.04025390815513674, 0.03539587625709828, 0.014883036928949878, 0.025679888531158213, 0.009574976884323405, 0.06250237114727497, 0.053461676579900086, 0.04286979317839723, 0.020590432723111007, 0.025597343155823182, 0.04527787314145826, 0.010566587297944352, 0.052293409971753135, 0.026238575446768664, 0.09354322464787401, 0.023436832525476348, 0.02689966575417202, 0.04756777350849006, 0.0500351213850081, 0.03230174756026827, 0.015056086285767378, 0.06442943922593258, 0.018229618290206417, 0.01755607474478893, 0.03594856105337385, 0.041086545897996984, 0.014448896308749681, 0.09732016260386445, 0.012236774873599643, 0.03292973808129318, 0.07447031879564747, 0.06243652038392611, 0.04333164280978963, 0.04232691215293016, 0.013375869511946803, 0.04300703112676274, 0.07768366238451563, 0.05898329611227382, 0.07326935316086747, 0.006190807598613901, 0.023784961013006978, 0.05855038652953226, 0.08251224586274475, 0.04246894437528681, 0.0753082703158725, 0.004611181520886021, 0.022844036502647214, 0.03593885376176331, 0.02892403495934559, 0.033814318740041927, 0.059389221205492504, 0.00563572380997357, 0.034139275521738455, 0.11984778073383495, 0.034019630184047855, 0.03510998983983882, 0.06164304206322413, 0.06625667359912768, 0.02027199385338463, 0.0310442265617894, 0.023979342477105092, 0.049479668377898633, 0.007911030770628713, 0.060631806481978856, 0.03715177168487571, 0.05176352024136577, 0.04623601918865461, 0.04451135333511047, 0.04656942532164976, 0.09575955962645821, 0.05157088839041535, 0.01912514377181651, 0.05501221603481099, 0.022759494750062004, 0.014609851441491628, 0.07768712821416557, 0.029806352067680564, 0.01575634621985955, 0.01408207312124432, 0.04252312115568202, 0.03656137465441134, 0.0329669382335851, 0.018942182105092797, 0.02798926656396361, 0.02676899210200645, 0.056670274134376086, 0.05413514962128829, 0.010467586653248873, 0.08409261223278008, 0.041899431380443275, 0.008266031545645092, 0.07768163632135838, 0.012953041077707894, 0.06335979662253521, 0.01605505694897147, 0.014693176999571733, 0.09463123540626839, 0.037630234292009845, 0.09334976901300251, 0.06875826788018458, 0.022833258663013112, 0.017588042755960487, 0.057084284926531836, 0.04863645874138456, 0.1278820339939557, 0.04383888590382412, 0.02622593481646618, 0.05676662716723513, 0.027169939239684027, 0.09549147362122312, 0.06364495202433318, 0.03708637734234799, 0.057196367779397406, 0.01745454894262366, 0.030678100993100088, 0.04559415792755317, 0.049359288314008154, 0.04889567237114534, 0.04917446385661606, 0.036222595372237265, 0.03928295263904147, 0.006918753815625678, 0.018996742946910672, 0.056193351483670995, 0.04715742892585695, 0.05899342642806005, 0.019775814325839747, 0.05096709188364912, 0.046834164240863174, 0.01282812927456689, 0.03496512261335738, 0.017893351177917793, 0.0895585076068528, 0.07046325568808243, 0.014373048816196388, 0.06908990399097092, 0.07421003276249394, 0.0679589674109593, 0.10580243557342328, 0.1597806395147927, 0.10863476054510102, 0.16931400139583275, 0.13065281265880913, 0.2485779856215231, 0.15030537295388058, 0.09832644806010649, 0.10920717162662186, 0.10585483119939454, 0.14018837129697204, 0.18417587969452143, 0.3222819330403581, 0.09496492726611905, 0.1848139485809952, 0.13901185942813754, 0.20156388025498018, 0.11867552879266441, 0.14405558409634978, 0.19140243879519403, 0.11950605883612297, 0.16092183999717236, 0.10980146864312701, 0.08970007227617316, 0.1656111891497858, 0.10202735298662446, 0.14888754434650764, 0.12514815491158515, 0.14491920650471002, 0.15038111654575914, 0.1124534739938099, 0.1723802142078057, 0.12737551820464432, 0.12545537436380982, 0.12608381017344072, 0.10939135783701204, 0.15527593670412898, 0.13384704594500363, 0.11029811386833899, 0.26055118767544627, 0.09984480799175799, 0.11981201663729735, 0.10927659954177216, 0.1524629446794279, 0.19258370040915906, 0.17633955721976236, 0.18193855677964166, 0.1081780280219391, 0.1550165709340945, 0.08420817946898751, 0.15753749816212803, 0.10473786183865741, 0.17747204488841817, 0.12744609644869342, 0.08060604697675444, 0.14579250651877373, 0.15732110274257138, 0.18093376304022968, 0.13954834314063191, 0.18332653620745987, 0.14102385146543384, 0.1057707161817234, 0.2692212240071967, 0.14433685806579888, 0.17984426056500524, 0.15258011495461687, 0.14617883891332895, 0.10954918296192773, 0.13672841945663095, 0.12371517164865509, 0.1314647073741071, 0.17711278604110703, 0.1543966995086521, 0.09288589702919126, 0.16556061920709908, 0.13436441193334758, 0.1293874063412659, 0.1307904810528271, 0.20285820064600557, 0.18859836738556623, 0.18579539435449988, 0.11143659066874534, 0.25818602240178734, 0.12128881629905663, 0.11340339333401062, 0.07619553754921071, 0.1150218393013347, 0.12473694572690874, 0.23615893092937768, 0.12118582846596837, 0.09259628131985664, 0.20768201211467385, 0.24697715824004263, 0.09239773455192335, 0.13200378860346973, 0.1939702103845775, 0.09424315896467306, 0.12154487209045328, 0.2073380266665481, 0.14388466748641804, 0.08070219220826402, 0.13997240632306784, 0.13359725387999788, 0.16782038466772065, 0.18022915319306776, 0.17409536201739684, 0.08393605618039146, 0.18571515334770083, 0.13076220522634685, 0.11481719207949936, 0.12945026624947786, 0.06737507530488074, 0.10680728126317263, 0.17392861627740785, 0.12494740396505222, 0.12014299223665148, 0.11061193843488581, 0.14053918450372294, 0.13206062227254733, 0.14588300400646403, 0.1540627478971146, 0.22414900740841404, 0.15076050243806094, 0.11951588487136178, 0.2037808089517057, 0.1293457273277454, 0.23735248250886798, 0.24430461024167016, 0.09447225253097713, 0.15029780304757878, 0.07457778920070268, 0.08906483839382418, 0.14465610031038523, 0.171823751879856, 0.267718760878779, 0.1470956436241977, 0.2022334755747579, 0.11076229013269767, 0.2565055328886956, 0.07843229643185623, 0.2083570696413517, 0.18660757108591497, 0.21550880541326478, 0.12174846546258777, 0.1061499016941525, 0.11325212137307972, 0.1402918266830966, 0.25939079525414854, 0.1555018761428073, 0.11729347170330584, 0.1563338830601424, 0.07407801953377202, 0.08375862351385877, 0.1928746816702187, 0.07564689745777287, 0.1471163792302832, 0.15268365939846262, 0.12670748139498755, 0.14094510959694162, 0.13161405717255548, 0.09237581893103197, 0.14503039506962523, 0.18450975709129125, 0.14593191153835505, 0.1595976555836387, 0.15953556750901043, 0.10997326840879396, 0.07647571314009838, 0.19020541396457702, 0.0703093342599459, 0.13704331271583214, 0.12152022536611184, 0.0883625663118437, 0.13551707117585465, 0.16897320718271658, 0.193211022997275], [0.018013002081715968, 0.021190713305259123, 0.03596056529204361, 0.05679582325683441, 0.05833723058458418, 0.03833974231383763, 0.06665327731752768, 0.03112097390840063, 0.08275541797047481, 0.03167150091030635, 0.012897230644739466, 0.050478428456699476, 0.047801501787034795, 0.06922018059412949, 0.044174154827487655, 0.03855077942716889, 0.06496114350738935, 0.0437182275345549, 0.1054447575006634, 0.060970982813159935, 0.10394176744739525, 0.03440530948864762, 0.01031721176332212, 0.016736940378905274, 0.10958093203953467, 0.055326348592643626, 0.03600608491979074, 0.025847439501376357, 0.0013675758168574248, 0.0693274283548817, 0.03978996195655782, 0.0539817514072638, 0.030539070758095477, 0.022356189438141882, 0.0945427936676424, 0.02552672038291348, 0.061477405834011734, 0.037649511577910744, 0.03358469453814905, 0.038988984233583324, 0.02851534907676978, 0.07639713454409502, 0.004467974385988782, 0.024833268726069946, 0.08430088113527745, 0.01725572201394243, 0.04125975945498794, 0.0362313304503914, 0.017941932164831087, 0.014981152562540956, 0.040490219107596204, 0.0100037397169217, 0.023199376810225658, 0.023074530872690957, 0.04398424665851053, 0.01712533408863237, 0.023726019644527696, 0.019433181441854686, 0.015761172035126947, 0.040373776137130335, 0.022415603925765026, 0.04713778427685611, 0.06507030600914732, 0.09215726386173628, 0.11395015579182655, 0.045739689376205206, 0.05390096492192242, 0.019726055179489776, 0.014475832558673574, 0.01976320709218271, 0.06881892360979691, 0.05762394874182064, 0.05509279471880291, 0.018795600517478306, 0.06407665932783857, 0.039485978268203326, 0.05591272689343896, 0.09411111605004407, 0.023186276048363652, 0.04962473227351438, 0.07146548901800998, 0.04879797976172995, 0.04926353271002881, 0.011503474524943158, 0.031899403329589404, 0.09204358168062754, 0.044475771064753644, 0.036576692582457326, 0.046147777829901315, 0.056455459489370696, 0.04253101389622316, 0.040408478962490335, 0.030637679919891525, 0.03140699947834946, 0.016852535445650574, 0.06711252572131343, 0.06956003970117308, 0.15595169184962288, 0.02589008701761486, 0.020441453998500947, 0.019117002411803696, 0.018341495197091717, 0.012905016701552086, 0.009759492422745097, 0.017908457593875937, 0.03324904711917043, 0.027653218385239597, 0.11433031351771206, 0.04784136624948587, 0.04258170629327651, 0.03760487881663721, 0.027674870543705765, 0.009992613067879574, 0.035346271106391214, 0.024601447767054196, 0.06975144700845703, 0.05397106819145847, 0.04082520230440423, 0.013822920718666865, 0.014876421610097168, 0.05277587646560278, 0.058361613846500404, 0.047119590526563115, 0.017525945404486265, 0.015829670410312247, 0.059461268901941366, 0.027231077365286183, 0.03144736117974389, 0.049518608866492286, 0.023543655406683683, 0.08378098442335613, 0.03373516126885079, 0.03491488292638678, 0.04725007493107114, 0.031077845851541497, 0.07694397863815539, 0.034275322323082946, 0.013135562094248598, 0.04128884422243573, 0.054409525328082964, 0.035416938408161514, 0.06295237981248647, 0.030989238985057455, 0.042908024915959686, 0.028999307287449483, 0.038484650358441286, 0.04442574288987089, 0.02413762587821111, 0.05312746150593739, 0.02124781229213113, 0.07300599463633262, 0.057425298073212616, 0.01730948504700791, 0.029748477536486462, 0.03249427551054396, 0.017340564336336683, 0.017440370211261325, 0.025818978137976956, 0.02932677623903146, 0.014496562598651508, 0.03838662007183302, 0.026767893723445013, 0.02051273357210448, 0.0029233192344690906, 0.06095251446822658, 0.0015854309481255768, 0.011381310523574939, 0.06221740128239617, 0.02541581568948459, 0.034406062768539414, 0.018357282533543184, 0.04883478657575324, 0.06381950515788049, 0.0840211656759493, 0.04650125163607299, 0.06966298300540075, 0.060871843015775084, 0.042851540056290105, 0.05131708501721732, 0.044434748851927, 0.0749862301745452, 0.037849902582820505, 0.025576826483302284, 0.024691705912118778, 0.005457343513626256, 0.015649692177248653, 0.030251764983404428, 0.029071447752357926, 0.028584992214746308, 0.06404544459655881, 0.018368049240962137, 0.03731684759259224, 0.007809411272319267, 0.05098548972455319, 0.04368369911389891, 0.061857047767261975, 0.04283402166038286, 0.06421409765607677, 0.010914954200416105, 0.023594056510773953, 0.04020134554593824, 0.046414635580731556, 0.07280403398908675, 0.03212236304534599, 0.010731855236372212, 0.06478849027189426, 0.005655143959302222, 0.05535099531698506, 0.022279534859990235, 0.037257260555634275, 0.0920079808565788, 0.093016707978677, 0.03879228541336488, 0.03810950212937314, 0.02891285821533529, 0.082339295768179, 0.015827174938749522, 0.0672984856646508, 0.001772084683580033, 0.06147458938357886, 0.12070902826962993, 0.01596528491063509, 0.05093389561807271, 0.014653713296866044, 0.016908879297261592, 0.05875467380974442, 0.05830707712448202, 0.0642773657455109, 0.02136487866664538, 0.04647140987799503, 0.05131748577696271, 0.016874067005119286, 0.014816510811215267, 0.05826133114169352, 0.06904071444296278, 0.04188759041426238, 0.02703348425711738, 0.02605615369247971, 0.08012288657482713, 0.07303692735149525, 0.027488791856740136, 0.05442480614874512, 0.01631041512155207, 0.018830396111297887, 0.041076033376157284, 0.03267566382419318, 0.06241842682356946, 0.018665238567336928, 0.08467946550808847, 0.041647884136182256, 0.08085828812909313, 0.01844371305196546, 0.020658804933191277, 0.04401223675813526, 0.027090492330898996, 0.03936384302505758, 0.10950127732940018, 0.03819853016466368, 0.030730747093912214, 0.05240181548288092, 0.043333164212526754, 0.06065181478334125, 0.03723726338648703, 0.05674638508935459, 0.026495082092878874, 0.035206992251914926, 0.01565187038067961, 0.025852295002550818, 0.07343818433582783, 0.05383891024393961, 0.03908174156094901, 0.03576161776436493, 0.04547385578916874, 0.0624120888824109, 0.04384852640214376, 0.029326082330953795, 0.019269051772425883, 0.08669123490108177, 0.07978498673764989, 0.010133980140381027, 0.016036380802688655, 0.040537453096476384, 0.033482563885627314, 0.07637338581844233, 0.05434443155536428, 0.03415703511564061, 0.003970868101532687, 0.020026560050609987, 0.024445526250929106, 0.02526414111343911, 0.015448826197825838, 0.046505856662406586, 0.06766613078070804, 0.05736963699746411, 0.032756747168605216, 0.007796336485625943, 0.05772054297267459, 0.05355190689442679, 0.033742055820766836, 0.019439378374954686, 0.04562553593132179, 0.051725533412536606, 0.01805500578484498, 0.019015888501598965, 0.027095249497506302, 0.025771671789698303, 0.13614574447274208, 0.061252438608789816, 0.03299046802567318, 0.03514643671223894, 0.03517981480399612, 0.10735572839621454, 0.021745066078437958, 0.02986870731547242, 0.06362370433635078, 0.02307338796526892, 0.07150147575885057, 0.07417702203383669, 0.02575400867499411, 0.040621616353746504, 0.04663833744416479, 0.03493843127216678, 0.0791484689398203, 0.025556220753060188, 0.030304769170470536, 0.016500942983839195, 0.049545426372787915, 0.02402173209702596, 0.028065329279343132, 0.016275888556265272, 0.047247785405488685, 0.024888078187359497, 0.0454007616644958, 0.038929415750317276, 0.007568397422801354, 0.021571904471784364, 0.01812451348087052, 0.0719440629472956, 0.013806496990582673, 0.051601891609607264, 0.09174701204756275, 0.032300619495799765, 0.01045023802362266, 0.051283714346936904, 0.007292644568224205, 0.029808365143253468, 0.02299786330695497, 0.0153045786646544, 0.022328555569401942, 0.04326087531808298, 0.04435789946001023, 0.025064171277335845, 0.08969680682639591, 0.17167538171634078, 0.13030844129389152, 0.13162993913283572, 0.10236458489089273, 0.1657281516236253, 0.13901228987379, 0.1730926166055724, 0.19322760257637128, 0.11009875073796138, 0.10448411412653513, 0.11175364357768558, 0.1442050823243335, 0.14344993222039193, 0.16012768261134624, 0.12414157259627245, 0.1419776151305996, 0.08320155262481421, 0.17436960042687133, 0.08414836236624978, 0.2166703704278916, 0.17050810216460377, 0.07704356743488461, 0.11739927969756536, 0.218250417674426, 0.1271507513592951, 0.2218301224638708, 0.12449099056539126, 0.1142035992234014, 0.11595836287597194, 0.16985121241305023, 0.10837840047315694, 0.09593958980985917, 0.09852595962001942, 0.26266616012435406, 0.22632085805526003, 0.1669670781120658, 0.1485383341787383, 0.14539130148477852, 0.12820155825465918, 0.1108864440175239, 0.24186925264075398, 0.13965593971079215, 0.15399012132547796, 0.1344305372913368, 0.10865467236726545, 0.10722735911258496, 0.09127447920036502, 0.08992608592961915, 0.18707991839619353, 0.224117673933506, 0.19121279037790373, 0.12793123838491738, 0.08547893667127937, 0.20755166129674762, 0.07327789528062567, 0.10220606956863776, 0.13741337723331526, 0.16300577583024278, 0.08830766964820214, 0.0674337569216732, 0.10208449835772626, 0.14144065644359216, 0.1780557440361008, 0.29538338421843946, 0.1808388571953401, 0.09135305037489161, 0.09941084455931559, 0.16856860311236233, 0.0671879576111678, 0.19225961936172098, 0.18576382339233533, 0.13968526938697323, 0.21697016840334982, 0.14750560600077733, 0.15577740588923916, 0.15207009622827172, 0.2340428452589549, 0.16573275293922052, 0.17986484774155542, 0.22302487632259727, 0.1592268340755254, 0.2876857394585386, 0.12423561754985712, 0.1030388631625101, 0.21643712825607508, 0.13503428926924244, 0.09148518234724179, 0.10480939003173262, 0.23892715660622343, 0.10857664296054281, 0.11411119441618212, 0.09441558955586515, 0.15657803480280563, 0.07192936100182123, 0.24934300628956407, 0.14677424915134907, 0.19382194412173703, 0.12001089737168513, 0.14980896521592513, 0.1390843078843318, 0.19977990566985682, 0.1606326547334902, 0.15458988054888323, 0.11283575426205061, 0.1499871103442274, 0.18037657340755686, 0.2230892502120696, 0.21642727253492922, 0.14721128507517278, 0.11637245159363374, 0.15420492854900658, 0.1436580452718772, 0.12841409450629726, 0.09686453588074073, 0.1777893427060917, 0.1691975732683204, 0.11394596265745349, 0.09069216786883771, 0.11607244581682608, 0.11432373808929697, 0.16227280109887943, 0.14027631579665467, 0.0801739314920269, 0.11941082644625567, 0.21391832357039675, 0.08345150054083206, 0.15569973271340132, 0.18326153891393915, 0.10059979482321069, 0.2442782639991492, 0.16020290669985116, 0.14562552329152822, 0.12705449480563402, 0.22045185032766312, 0.21790561586385593, 0.11814830708317459, 0.10238562477752566, 0.1414555439259857, 0.14397234481293708, 0.16826332808705047, 0.15845681133214384, 0.07688540092203766, 0.18362461240030825, 0.17252865858608857, 0.09962122116121463, 0.1077304090722464, 0.09013631410198286, 0.07981130329426378, 0.06585839262697846, 0.29623079812154174, 0.07996263462700881, 0.10752590285846964, 0.09867432236205786, 0.13132592575857416, 0.11264652144745924, 0.17487752629676834, 0.13766567775746807, 0.13196455867728218, 0.0768060950213112, 0.16521672281669453, 0.17965444887522608, 0.05845746221893933, 0.1403083320474252, 0.18244718026835471, 0.12804251600755379, 0.1291639605187811, 0.14049140503630042, 0.12327522650593892, 0.10194231028435752, 0.1620095464750193, 0.09568223526002839, 0.17768719349987805, 0.1690028782468289, 0.15338547877036035, 0.2009418120724149], [0.04949715337716043, 0.02977803542307811, 0.017888944676087704, 0.01809633042284986, 0.07064724151859991, 0.062482258945237845, 0.017112634086515754, 0.0029691967165490496, 0.02986613762914203, 0.011625913120951736, 0.002708120064198738, 0.008229728464357322, 0.0429724693094613, 0.022686315278406255, 0.09498337705736049, 0.029723339139309246, 0.02982055491884239, 0.05990098026813939, 0.0030690074618178187, 0.040799579655868, 0.022466804693976883, 0.07856477721361443, 0.011970708437729627, 0.010190436241828138, 0.04687067790655419, 0.017901512946991716, 0.013284781089168973, 0.026901355995505583, 0.03611207845096942, 0.11320557387080044, 0.029001504044572357, 0.028123502524977084, 0.04195380854071118, 0.02118074811733095, 0.040333013675990514, 0.07728696218691766, 0.07299806107766926, 0.03238339864765294, 0.0499656266765669, 0.03313206980237737, 0.02899946313846158, 0.023863532187533565, 0.03676496431580745, 0.06983350627706386, 0.03951906692236662, 0.08955325320130214, 0.06916730257216841, 0.08367671267478727, 0.023803850526746828, 0.027535910812730435, 0.04263160088157747, 0.03752713884750847, 0.0751573545858264, 0.035416827086010017, 0.07762812747387215, 0.03858134848996997, 0.10032839141786098, 0.030038458753551822, 0.04944895830703899, 0.05633253385894932, 0.04494293447351083, 0.0499636117456248, 0.03992875099356752, 0.008867962478689151, 0.017574467019585427, 0.025899638458213303, 0.01284289801333216, 0.03120068613498006, 0.02604153338324977, 0.04211715153360274, 0.05397509805334266, 0.060490401374408975, 0.022096814391261432, 0.03276549708971288, 0.037854103138670325, 0.04558141896268353, 0.07141750917071477, 0.06584668153664097, 0.015644161321688443, 0.03902714917785488, 0.01751282423356315, 0.025733516122272704, 0.057373978561372496, 0.03172538825310767, 0.03318402756121941, 0.040544625953771174, 0.08401869432418607, 0.02813577764754882, 0.0631147765670903, 0.08040522181545384, 0.03804723593930248, 0.03323133205412887, 0.03185664078046102, 0.046467227875837125, 0.05093081570521463, 0.01110343280743109, 0.01250365767191397, 0.06655701334238984, 0.013868086898582987, 0.005939314623901737, 0.040886284768930636, 0.03487281428533606, 0.049041433885577135, 0.022622260512434877, 0.03586707323847804, 0.04875341379374731, 0.023994020302779973, 0.005246742412055028, 0.0026892108371612267, 0.01801402624550974, 0.01306674923398532, 0.010612039204715984, 0.01599083891051123, 0.013590218459285097, 0.03409575598197989, 0.0629597419174388, 0.030570248381991405, 0.01732129076117417, 0.06920283660292625, 0.08898194049834274, 0.022539032361237332, 0.08971113769803196, 0.062162178073776886, 0.04612791795807425, 0.06904039531946182, 0.06250789272598922, 0.067704870889429, 0.02697463751246687, 0.05343261036614422, 0.019237842607253697, 0.02035053534200415, 0.04435150585777592, 0.040911874020821415, 0.047384451900143176, 0.021607484886772, 0.04400584315590095, 0.018442228756612167, 0.06614068333874457, 0.06376243400154635, 0.06259408575715497, 0.04628478942322545, 0.0739722115395125, 0.014339407262013992, 0.01024965869873995, 0.0054328920668922365, 0.02532435712055303, 0.07691625200095586, 0.06981555372476578, 0.07766791401081719, 0.028845962879131548, 0.024410110963799525, 0.007713975719525479, 0.025796155241550878, 0.025913126992236357, 0.02735450951149687, 0.024033417212194763, 0.049421179719502106, 0.08621087981737219, 0.026202920817013364, 0.0336764648091048, 0.014492227528535295, 0.07270448972121812, 0.03506850007397588, 0.06204334167705383, 0.009815189678192837, 0.00671438489916909, 0.025601925917726476, 0.05561020523600746, 0.034427536811563186, 0.036955507021048106, 0.043517947851796634, 0.021379756872192957, 0.03152815508656204, 0.025676240875327494, 0.04468328297662083, 0.024773546247160994, 0.03557927208021283, 0.0441525434871437, 0.022846656283945777, 0.039275616509257816, 0.0317915989580797, 0.056268553307745606, 0.018175769910158124, 0.020884473487967625, 0.030716360561200418, 0.040943560015875846, 0.04329530354880262, 0.05679779736965429, 0.03299365926068276, 0.08004278657608666, 0.01926890148752136, 0.021430089327623136, 0.04502408832195215, 0.04115914649446495, 0.04074817479704507, 0.04703600985521916, 0.022983024064160418, 0.020752569726028014, 0.07733457838185132, 0.04991196568880696, 0.033535182155901566, 0.02756405305262888, 0.060086513476562686, 0.047082716919248924, 0.023892989884188864, 0.034349384950473905, 0.010568831366981613, 0.041024877136806026, 0.0075997531621396774, 0.08103053318336606, 0.01298422797844978, 0.018889526727434713, 0.03955237079935614, 0.032385725280619226, 0.10814247172675095, 0.04270165220077615, 0.05239725127466954, 0.020801907703571487, 0.06854522696812637, 0.06519046713947318, 0.13751528895227239, 0.07995326872332953, 0.03862351361021865, 0.04444463054824155, 0.02294230056577362, 0.035071691308985464, 0.032049012879724614, 0.021351946743379813, 0.012656166236411082, 0.023447914645657875, 0.016119004103529733, 0.023611641699972097, 0.04039325380290393, 0.0531246042373823, 0.07491708427551202, 0.07748573159915395, 0.06566120398929343, 0.0114951216528425, 0.021726555060013197, 0.018638172441569623, 0.007532044246545411, 0.038873572848387994, 0.057785428944043815, 0.05503141539520584, 0.03138713589578401, 0.07492738528526388, 0.04993954389647115, 0.020354698790470138, 0.009221337950293673, 0.045237786034704186, 0.06536246728501283, 0.043588960252236575, 0.008770291206019465, 0.02696718820516253, 0.06145490762719419, 0.00985768227110384, 0.035769005844485946, 0.02731357450102223, 0.08994686606456526, 0.1030537135375198, 0.03931753301003482, 0.025849374651443213, 0.026969813552568667, 0.032331901020370424, 0.021888473129365593, 0.02817815799062373, 0.02800689442665316, 0.030158966837916523, 0.047519875297439285, 0.06883053079945967, 0.05464917223434895, 0.05402280330599751, 0.024954711916507222, 0.031989845156203955, 0.02863898902432993, 0.04725248320028186, 0.024265275278594345, 0.045921144483145326, 0.03081995510001434, 0.02176805410272209, 0.06017597195750568, 0.032910245572566055, 0.019905118715541903, 0.033700191270327196, 0.013156913682905724, 0.023977648525033146, 0.026865575200645253, 0.06156050782010425, 0.03194615121174138, 0.040923729829955846, 0.0501328548125457, 0.01586173675605096, 0.051043102648691274, 0.011531550899235299, 0.03495842101983726, 0.061906819901196286, 0.08316955863847397, 0.03069231126573868, 0.1271796357468702, 0.04808880570635665, 0.020314839894126635, 0.01114634007535642, 0.05087687270133756, 0.01897668083984172, 0.037729878749814816, 0.017582626933290157, 0.051235356004326604, 0.05514552060049027, 0.027880595735041425, 0.04442326782736927, 0.013308388806763105, 0.03856177434499841, 0.03657803586975206, 0.04305217968067154, 0.07138823886634782, 0.026588069486024324, 0.12943816924234852, 0.0375283262837911, 0.04193970402411651, 0.026537993071542587, 0.034090872650267556, 0.01069436842954019, 0.023268778750207275, 0.040301112458109856, 0.023081896688381676, 0.07261374732479453, 0.019321805484651122, 0.030539482650056016, 0.029890461519244127, 0.05289253094815649, 0.04954864729370456, 0.016156857345777098, 0.07222927029943094, 0.027063704510510433, 0.010673328542907257, 0.06445040489779785, 0.01917529254569672, 0.017727058148011565, 0.046091215044725686, 0.047113712716964073, 0.053331114249886014, 0.03578376716177445, 0.04377842313260771, 0.08108770081889816, 0.10424181775306351, 0.008910379929147894, 0.029494165792129934, 0.06764482372091152, 0.017085438084905036, 0.033431277770432644, 0.01630993643630063, 0.020585521560860798, 0.23837007087422535, 0.12877973582362756, 0.12906803051009774, 0.04901070897176396, 0.1393977168481797, 0.17404201644239947, 0.11886723295901902, 0.1654054064420052, 0.10385610876255669, 0.1526202354580164, 0.24876384908566251, 0.15773314313264564, 0.11778659914853051, 0.1255453226622194, 0.2363389462698251, 0.10025655894423835, 0.08567138298531063, 0.22162242501508445, 0.1490364785422571, 0.12117167570977472, 0.07607866413309239, 0.20364242809591815, 0.17767402780009434, 0.11270106930169277, 0.1041335087211337, 0.10592974358587526, 0.11199365413631313, 0.051412495522527024, 0.22731431177817285, 0.1980612994520925, 0.16015583969419822, 0.148777513531968, 0.11461825939477421, 0.1926335578900762, 0.13250752876047045, 0.16515859781065956, 0.15534152771579102, 0.15593686373904347, 0.13294734031660482, 0.09198950880090706, 0.1686369549133815, 0.10510313208214939, 0.2397652788204141, 0.12810668209567666, 0.20125658658798784, 0.1074640745355282, 0.18645796895725653, 0.1445233152480796, 0.10820621479069814, 0.10529877705266699, 0.1476294852909632, 0.14486603904515505, 0.16706088557839394, 0.16137811238877475, 0.17911956820171326, 0.10955001416732557, 0.22103099268861115, 0.08624039503047243, 0.14703518827445805, 0.24887851090170443, 0.12169511988759041, 0.08210793122998439, 0.1601364547968842, 0.09236988917109556, 0.1075012338696979, 0.2187106679775752, 0.1469963145791553, 0.08437610522378236, 0.0966389972018078, 0.11801286513218656, 0.10831972627784126, 0.09213367840857245, 0.14393908175406978, 0.09548111323965713, 0.13550179777666926, 0.14370247023180127, 0.1319948531454429, 0.11665212994557805, 0.1441382445045747, 0.14080027205636725, 0.11510251817526296, 0.13837922306265682, 0.19363139028428122, 0.1901378043112345, 0.24178252526326105, 0.050664047012105584, 0.18160651990910992, 0.1524679467547685, 0.27911040117032826, 0.1337330965907313, 0.20195227582007647, 0.21082052495330572, 0.08546338125597686, 0.16024121636291966, 0.08543241143343039, 0.11573765557841398, 0.10803647819557227, 0.2005330816609785, 0.10022773392847739, 0.14767756161745638, 0.10000920854508877, 0.17011405143421143, 0.14327570563182235, 0.12594952597282827, 0.11060334436479025, 0.13435434841085225, 0.10568182915449142, 0.09010216046590358, 0.06870699289720505, 0.09246844638255425, 0.097884892456932, 0.18892111256718636, 0.0907622859813273, 0.1563747160253115, 0.15811745688552037, 0.1578551225247793, 0.09593470647814684, 0.16972195997368544, 0.1405512072960846, 0.20786333363503218, 0.13986957434099168, 0.1309286689502187, 0.255219450336881, 0.1390962119330652, 0.1181354679283686, 0.14482891681836918, 0.13292333926074207, 0.13419931376120076, 0.20486207358771935, 0.13315349409822375, 0.13196264393627644, 0.1571132568642497, 0.13097754679620266, 0.12713147036265582, 0.11583308092667721, 0.15666868072003126, 0.10139700985746458, 0.11757060448871925, 0.23886456387117505, 0.2180848890566267, 0.23307398631004617, 0.13433033251203597, 0.1098330321838148, 0.11713651489117183, 0.12386328948196024, 0.10109238792210817, 0.14004253927851096, 0.09430417834664695, 0.17177658097352833, 0.29546279401984066, 0.1940799443400465, 0.10933637211564928, 0.14963162160711363, 0.15079142031027004, 0.2278401976218447, 0.1603405602509156, 0.22851958929095417, 0.2247120748506859, 0.1116028540127445, 0.2762684802291915, 0.09589258217602037, 0.2556185476714745, 0.18350604688748717, 0.1301992713706568, 0.1948458852712065, 0.15347318578278646, 0.12155628632172011, 0.150433556700591, 0.1132129508187063, 0.18457321071764454, 0.194975909544155, 0.13816595950629562, 0.10453460243297741, 0.15278954902896658, 0.13440034672385082, 0.13849479029886425], [0.010912108064076165, 0.020530250112642534, 0.03945503442082554, 0.032481740636285394, 0.005758670313298353, 0.06391355753294192, 0.08696052318555303, 0.04814360960153863, 0.011823805871244986, 0.027536767993296962, 0.028583851162693463, 0.056099377034115605, 0.018060679503832944, 0.02774646181933349, 0.09191694902256131, 0.015071967318363022, 0.04522947398072574, 0.06612240424146876, 0.020826730687986128, 0.05629417966702022, 0.021726770282839425, 0.06353905497235246, 0.026088750673807226, 0.03449922827712726, 0.026467312782187946, 0.01893937307613669, 0.03725098569702823, 0.034803527378244326, 0.05726533927372657, 0.019824374903691933, 0.014366382474690909, 0.07074515306157991, 0.039093103841878474, 0.026975949258485343, 0.056723037123447284, 0.05824988351378124, 0.0196654309911537, 0.03729969284904655, 0.02247931173769757, 0.0158726611698512, 0.024159856911865063, 0.018789377609209623, 0.03902249220118392, 0.021225521886663046, 0.026509635608817916, 0.007585318389828899, 0.01935339500050759, 0.0058778402126336005, 0.013421731455309782, 0.03260664037952665, 0.05295906448736787, 0.00528277043486014, 0.032672042143531144, 0.03558159871317912, 0.0481414907699218, 0.07905986392870545, 0.030921586658223532, 0.02206460889283335, 0.04446581886440981, 0.07457251253072172, 0.046424354004557244, 0.08128945366479456, 0.027996836470265407, 0.030906925530871376, 0.04284143200493418, 0.04398841010697652, 0.008954417116910918, 0.038439435011241585, 0.010299099649273558, 0.03237973985960707, 0.03395825457118917, 0.03794815180299338, 0.0073437177798041375, 0.0614149132888997, 0.06940248917089775, 0.05195957339310553, 0.029768348540528677, 0.08139443045365624, 0.009947885682777269, 0.06324365793261677, 0.01167371299743536, 0.028513768302218523, 0.0633193198882509, 0.010878210468945326, 0.032673077439540066, 0.05543344421312213, 0.038740858290111646, 0.012965195601282176, 0.10323520575184375, 0.041141676338156685, 0.020132332792854868, 0.019029108007089235, 0.10216301016043872, 0.037989444899722, 0.05919480820011813, 0.05644767436024267, 0.033400627071387134, 0.06143738552054856, 0.01152211820226512, 0.09559930767863989, 0.031644434784539044, 0.08186535284039564, 0.05008123102015816, 0.04823129806027282, 0.0955577399872709, 0.0184812174848048, 0.047592676273779944, 0.041463994784862734, 0.016047101125877816, 0.024380311879212968, 0.045223889319458976, 0.0282404000608949, 0.017260453205381054, 0.015127568094612798, 0.05510216433322057, 0.043381674695410766, 0.07410777965560555, 0.05480276340676937, 0.020392336809891276, 0.039817926081013866, 0.05757080725743435, 0.041792821866692975, 0.02604926656204043, 0.023328959505306557, 0.061090720919310115, 0.06339928630040959, 0.08469658685498871, 0.05168789910385385, 0.048740322308731265, 0.03873651672620326, 0.024186238406400662, 0.018445316090947017, 0.06924461951712146, 0.013042653554293793, 0.026447825839568395, 0.07446409959811717, 0.02202396517532179, 0.07937504662550054, 0.02788608577247942, 0.04359454120276496, 0.04136655079491902, 0.03271369889262132, 0.071205566637218, 0.015609311922162306, 0.050386116417939775, 0.04286339957616292, 0.0689145790238399, 0.017222796632268, 0.05868546482815873, 0.0724203436402604, 0.028797018239856698, 0.01532875134216738, 0.011796409489761572, 0.08928846233175136, 0.0477300589409424, 0.059515798202482983, 0.04952985611453187, 0.08107978210318834, 0.029288718906173017, 0.11206860363017768, 0.04461135031306185, 0.03579896263545379, 0.02938111258117715, 0.0365274325304199, 0.06246237680898048, 0.04327643444412388, 0.018999670719495043, 0.02285909838974476, 0.017762193274393212, 0.053959538927301764, 0.030978522372606676, 0.021464281926455442, 0.04567755677271634, 0.013612996826850576, 0.022250214460655116, 0.02542443387937965, 0.027715898322639987, 0.031125723653531168, 0.038701402008882724, 0.07017241543508135, 0.01915732143970672, 0.06897883416968398, 0.07327192099182867, 0.013930974637332838, 0.06336706224828959, 0.031883614137768745, 0.048585387849016115, 0.0437659661838552, 0.022356603185471613, 0.06342535052681342, 0.074788061901927, 0.020927356636093464, 0.01667594140599249, 0.10036590698291548, 0.03598602837882936, 0.03340602990647312, 0.040244583069579676, 0.04317790691857226, 0.0307684185099788, 0.03033572415006347, 0.030152871950122062, 0.06778298935387284, 0.017473401348979678, 0.028087183673051186, 0.019936027310905047, 0.038898223283467814, 0.03163305394991767, 0.015850224190216977, 0.05922278345678933, 0.0012447910785340355, 0.04741330289107282, 0.026763062342070043, 0.04316642960475292, 0.09563154657371342, 0.05307960411300883, 0.030711994877492543, 0.03966336269513704, 0.020306566802901216, 0.0538045191206038, 0.06643369066296145, 0.015612440074619371, 0.0265061864774907, 0.051821697197738104, 0.018592547057778575, 0.07206011257949285, 0.028133914856880438, 0.011523882658366347, 0.029393868244369514, 0.03749470699403901, 0.01576872709847521, 0.06968638292164542, 0.022218801204871852, 0.008074365414358908, 0.02135785238351673, 0.14692205528263003, 0.019458141723589506, 0.0379014707141323, 0.017190771104651503, 0.007065590980346315, 0.03875039117701817, 0.04553259306703694, 0.03432645258726552, 0.020468147195060737, 0.06589706594240852, 0.016983522655209526, 0.06725961939082481, 0.07069176295772195, 0.05235664466454182, 0.006592068757527159, 0.07689787642448209, 0.04820744914468378, 0.03706128532940056, 0.04719400567410048, 0.04277175175957382, 0.030110061161394697, 0.02745586090895813, 0.014564441280526808, 0.015963795049174223, 0.04559549750410952, 0.041197378232027404, 0.02654132345924154, 0.07655893015908077, 0.007266644815899781, 0.0511989944789093, 0.03964906522014644, 0.0435142593778437, 0.06560203997651115, 0.053539676300715655, 0.10313987688277848, 0.030798121115367394, 0.12932785641169176, 0.040632347809150815, 0.01373903947751387, 0.09111292849411257, 0.026483792171347886, 0.04976543234079145, 0.023805177115718834, 0.07175655191531405, 0.019926303320971783, 0.05721577494114172, 0.1742943169665523, 0.017082300655602012, 0.014700378615088994, 0.02495955443009734, 0.05632789914670866, 0.056578373987576924, 0.023215551918838173, 0.04856348336033989, 0.02884889065171592, 0.03151449956931174, 0.025234410677512642, 0.02117577758326661, 0.03765515190025326, 0.033281222931691445, 0.06819027257733978, 0.01335381566605065, 0.03580012038582936, 0.030845594446873292, 0.03039482508029323, 0.0496718920476269, 0.056403609341941774, 0.0665656074124854, 0.02584763988124905, 0.03414861173951067, 0.0768665800569579, 0.026570992667984683, 0.01807949665817432, 0.016355623047275003, 0.07140668123611249, 0.04284453418222256, 0.020399242494022474, 0.03306054160930216, 0.016556566952203866, 0.13618062541354448, 0.014783251463086344, 0.04733741829113569, 0.014405354504560819, 0.01555640235892497, 0.07410129328491166, 0.03144498259644024, 0.0665411536465399, 0.023157569776230957, 0.06553663450176828, 0.07212862023152411, 0.0613200556836091, 0.012106399935873924, 0.05935491171840113, 0.03674090017739218, 0.013774746057606535, 0.052964018323109485, 0.027678462538460735, 0.023245215561473742, 0.07144153991248459, 0.041601221601013094, 0.02177069429308176, 0.05569791224843357, 0.028668031118286308, 0.0024505609599145828, 0.03064375810936326, 0.04035337449749932, 0.047295041658799164, 0.02212768216850236, 0.05398040811996907, 0.030351854729815386, 0.03458218925516121, 0.040004613329074346, 0.06378998252330348, 0.03328468133986462, 0.008786297476035543, 0.04263790542609058, 0.03292532230261713, 0.004327265041865758, 0.09600370394764468, 0.09613739443011582, 0.09724159142933786, 0.13694178691366687, 0.0729559367755428, 0.16291550098685548, 0.19954474875703454, 0.10305470059392974, 0.11482531117508188, 0.17097005940740928, 0.1290798603440635, 0.10498095231014304, 0.09614241134840995, 0.2587138378294185, 0.17240659013623372, 0.06691938920994289, 0.14833335299044847, 0.15332193608628586, 0.11618512609857135, 0.09839384991209954, 0.15607061359332874, 0.16013042855774984, 0.10991992283379659, 0.1523496038862504, 0.13115152105456218, 0.18184252287028357, 0.158550618798472, 0.07722234338871203, 0.1692328549688682, 0.17665917053818703, 0.08107670961180702, 0.13482656213454902, 0.12775264796800911, 0.1073140642256476, 0.17907995235873386, 0.16424152592662722, 0.17958624550374225, 0.18503769126255065, 0.14934743841877207, 0.12144832609919831, 0.16864158591488376, 0.10702181389206089, 0.17389732733136043, 0.1212901966937352, 0.09350659223855473, 0.10715460637584329, 0.10483654521522112, 0.08070758762187324, 0.13207657844759524, 0.12370595417451113, 0.104293411859544, 0.09263239422580227, 0.20092774095246568, 0.12729720678180456, 0.2035557897761464, 0.16907369397813454, 0.12327282936894335, 0.11733742911019363, 0.24425764713669196, 0.13369459396926686, 0.17834938218584284, 0.1518080587266013, 0.17917169665452093, 0.16235308663453907, 0.2692657825537026, 0.10318913322407752, 0.1228359789820388, 0.1682566784438677, 0.18492853618226945, 0.13081170647637919, 0.18094676546752453, 0.09874813636997715, 0.07637381626409478, 0.19289466028567404, 0.14177759148878977, 0.11496508726850152, 0.14552558568539098, 0.12481119018048048, 0.16524796723388135, 0.11435260021244176, 0.1589185607735999, 0.20463159220525995, 0.18232696718769148, 0.08723309918423183, 0.08261837298050523, 0.14765250671189278, 0.14034302002983168, 0.13536190293962136, 0.20800938829779625, 0.20045153447426856, 0.18479883845429868, 0.13542908214731142, 0.20573089102981612, 0.15857782593229786, 0.22834941482869908, 0.12758864817442372, 0.13704637036425993, 0.13929040229413658, 0.15561800741124898, 0.18588255217764527, 0.13757069769781083, 0.20121588720940053, 0.1495495400740765, 0.152433926705271, 0.17330838862108067, 0.13988974591484293, 0.13841242674971, 0.10918349711573683, 0.1418337572249584, 0.16951420315308496, 0.09550023838528432, 0.11731696067727171, 0.1392215013038367, 0.10190135115408339, 0.14554275898262858, 0.12429918991983868, 0.18264638754772022, 0.0773946255503688, 0.1387352609890513, 0.15408976207254454, 0.16440680221421644, 0.1485967412008904, 0.1373100109049119, 0.06356453290209174, 0.12779949232935905, 0.1400479272706434, 0.17858436098322272, 0.11974192078923807, 0.1529071942786686, 0.11630367676843889, 0.07557283854112029, 0.13523103261832148, 0.14632900507422164, 0.09291749767726287, 0.0813218038820196, 0.19036169542232528, 0.06653330172412097, 0.203397860750556, 0.07172257639467716, 0.10011268619564362, 0.12547389836981893, 0.11318896460579708, 0.19233779719797894, 0.08309794138767757, 0.13527302333386615, 0.15161567920586094, 0.163746572798118, 0.2007562157814391, 0.15449353493750095, 0.09726397460326552, 0.1378061663126573, 0.07934408422443084, 0.10837318317499012, 0.2173406188376248, 0.0934283624519594, 0.13535278936615214, 0.17463732277974486, 0.11571021837880835, 0.08787705330178142, 0.21140628727152944, 0.12602936621988192, 0.10143499297555536, 0.14066836272832006, 0.1336335449013859, 0.1512944628484547, 0.3076482948381454, 0.12193114511319436, 0.07589334243675694, 0.12367248331429437, 0.18510098161641508, 0.13427511672489345, 0.11788813237217255, 0.09136769294855185, 0.14231456501875073, 0.1539508468704298, 0.10506126011023298], [0.07198895546025597, 0.023970219626789913, 0.06396325916284695, 0.04029847412311938, 0.01452310922104516, 0.04635375349607784, 0.030876247001287993, 0.025631843745941296, 0.024574171984568238, 0.07017872369033284, 0.014320057616714621, 0.03619045666710008, 0.05221375897235703, 0.055770839389879256, 0.024725293660594616, 0.03512342271278612, 0.08486526960041374, 0.09901890152832493, 0.020639718750317115, 0.034389308784739114, 0.05319367592164781, 0.057307786410092376, 0.018808467502822168, 0.04904975707177073, 0.01864842892246088, 0.003591722015698906, 0.016794271286926232, 0.033977446510107256, 0.015785716714162845, 0.036452694548643194, 0.02713740905164741, 0.035393197103985585, 0.018056755397992674, 0.06855771731352434, 0.008504798079229658, 0.01049086133207311, 0.030247300965129398, 0.03342862088175025, 0.04185517340374645, 0.06790836778236553, 0.03296453367511276, 0.008389478534809314, 0.021880361455259845, 0.0818694569170475, 0.029246214253362268, 0.05011358865885995, 0.019469177459541243, 0.05705122595827561, 0.016948945994954556, 0.037410220902529545, 0.05663029834977351, 0.01273868749194662, 0.04737508970720228, 0.06225607459782623, 0.06678933525108732, 0.04421621604706161, 0.05847838707268238, 0.030808945339231286, 0.06304738213657402, 0.03232563358324114, 0.015646743995603174, 0.014230693759600399, 0.028925702936248854, 0.031462133629247546, 0.052817151008639485, 0.027596316067501903, 0.03771798212255817, 0.007948279162519611, 0.027316548657836393, 0.04302432316762861, 0.04924172470055055, 0.003837618965008005, 0.06635270750848576, 0.02700035478483187, 0.08975651260698214, 0.11534738980117254, 0.033335240150336176, 0.0050398492658132454, 0.03323231539980043, 0.020623024138330948, 0.05118699024023954, 0.01339216800261056, 0.02434548474411713, 0.03822869846771937, 0.03242924853111617, 0.039862840858404525, 0.013815087349939859, 0.024726152696530335, 0.043365492165321484, 0.03487124835373834, 0.03545057996234391, 0.03460094332695007, 0.05529951253265608, 0.029937276194687, 0.013963294240966206, 0.07619980489835143, 0.03527550361468457, 0.026110183898708783, 0.027704285566869657, 0.02059438465948915, 0.020632234190998133, 0.06339414321701042, 0.013726571396546206, 0.05474939927808009, 0.009879013450699858, 0.08706516600796022, 0.013110939489706652, 0.0732134842837695, 0.016650222278258298, 0.019490888989821542, 0.03056965651921928, 0.013508148986147717, 0.04717218653240707, 0.05438886393676512, 0.048286202145391144, 0.0481569831026718, 0.016445940564153716, 0.019873308410751633, 0.06027937910403125, 0.01943140585353831, 0.041989561505033635, 0.08324510185047984, 0.026411069120513275, 0.049399891213397495, 0.08162335332599469, 0.011395610781619325, 0.030739161193196196, 0.037390999277704395, 0.027391594630898908, 0.0415476385387592, 0.05599030730081722, 0.025278076791437343, 0.04401894206239376, 0.04098797384358477, 0.024012657486309763, 0.03375022686668672, 0.011379053466953337, 0.044674570162897, 0.03061666229768889, 0.06390972805093043, 0.09388738821144216, 0.1160207181237638, 0.026742900045064744, 0.04775310262630228, 0.026359959265391808, 0.060148286138428375, 0.11115401051938534, 0.06400110869435593, 0.045587096392409876, 0.0036506455262497184, 0.06384795909980312, 0.03926612072973512, 0.0701851952180732, 0.04797126806806773, 0.091313568118494, 0.06868595301057212, 0.04466092577786185, 0.05562383106735069, 0.05383943716879003, 0.04659630962123629, 0.029600567504530773, 0.04597926577844191, 0.03600366922910325, 0.013758213790424634, 0.03543032304150984, 0.03282956298789941, 0.0335350856767036, 0.034331725546508096, 0.032286689383909106, 0.03816859192738775, 0.09948499995516613, 0.024293916612805333, 0.05072022388048936, 0.02807237226079451, 0.07459689208189957, 0.02042211919615511, 0.017980657430598512, 0.024862806203600485, 0.01945868534676265, 0.021468460217874963, 0.00609408024502045, 0.05073861058917828, 0.0038179515877345693, 0.048499974072910845, 0.014776927437196719, 0.05077367335616145, 0.0180391108369804, 0.03469912946457043, 0.04140005876251962, 0.004031940361528541, 0.005473562223414774, 0.048531326101510786, 0.08306072268169373, 0.01464144652345567, 0.03784039196034428, 0.022829679655842483, 0.03385662486834917, 0.04593109668348916, 0.03372153172676917, 0.043349851403036155, 0.0022288589525487623, 0.045055996961309575, 0.01669361565291183, 0.031160354119492695, 0.024884623489924707, 0.02942900151538197, 0.02710505883442238, 0.022526182074216194, 0.03700397297507152, 0.0381433292204747, 0.009597052066965261, 0.04425290411745664, 0.013129084072716068, 0.048469345638295636, 0.06524035430629738, 0.06341082669678144, 0.028044090868206695, 0.057577512561692856, 0.017132714747276623, 0.02668882159923669, 0.02559207390731899, 0.016802512836875394, 0.007291459914995357, 0.025580132751201745, 0.1323045662138611, 0.00797484433860518, 0.02179512764996616, 0.023204011522466317, 0.03974323633883614, 0.021529872938117478, 0.02733333418291295, 0.019063979671045672, 0.08644853776786476, 0.015366585103038233, 0.08680818253196776, 0.05188677983824164, 0.056647159944986925, 0.05645695491693914, 0.06691371920169331, 0.02368737230426632, 0.01013698491078685, 0.03445908922003582, 0.004119987370359013, 0.03796267192228697, 0.03456217724306043, 0.01976962295884732, 0.049798008913057856, 0.052423590095713735, 0.06505808283691294, 0.06365128254401498, 0.08377636826480739, 0.03740490341442637, 0.0186548651981866, 0.009854527215793496, 0.0467513628245797, 0.07893368398072198, 0.02026842597842915, 0.03306352504296228, 0.07283286642632447, 0.026972988089255523, 0.017454658409405965, 0.03500261591398157, 0.041774116034503095, 0.05506169130967464, 0.0612134906987194, 0.02263146870973287, 0.04817654982616659, 0.024770336458459496, 0.05845473111548927, 0.020706035211333074, 0.019517140608513728, 0.013741204693360487, 0.027855475891556125, 0.03968975717725698, 0.011112716147181345, 0.10973706506774761, 0.03748531511519104, 0.05725759867345914, 0.038975603310973383, 0.0467304268386215, 0.03986680392699782, 0.03704609727719799, 0.08411008238908835, 0.0607683505222667, 0.01681914807704743, 0.04406379004649352, 0.07460130043909885, 0.025494260698906146, 0.03726343893504236, 0.06886156741529703, 0.04074635653523728, 0.044722386737703346, 0.04422319594596047, 0.03239079414925072, 0.040883219699026085, 0.007807620841049356, 0.08092025003861636, 0.025415819400222972, 0.05608227424090728, 0.03214193719031755, 0.03373494604602456, 0.07405821903375909, 0.03717842591868248, 0.07858750919695012, 0.0402021285117371, 0.0381451437715441, 0.03878081181028392, 0.09433209052076563, 0.028594654977496248, 0.06610312324482948, 0.019383108738111332, 0.04554564744466916, 0.029532367843785323, 0.03398067856323905, 0.06844951218226925, 0.0163514410451171, 0.044660647472483106, 0.056485709428670816, 0.02248077933472814, 0.04327286842453759, 0.04149923937802669, 0.07202399967354722, 0.051037673838436604, 0.06025237977155484, 0.09449054647120647, 0.05121778936882038, 0.02524131821701303, 0.01732116645143833, 0.032051985181169584, 0.05101077840663493, 0.02546660827647429, 0.026998705361620523, 0.01568911877257051, 0.027943977001996245, 0.023627243499504402, 0.05098612426081672, 0.02278498010127805, 0.027073469318565913, 0.05724620299588423, 0.04251350663253106, 0.02529651359509444, 0.03571385685063433, 0.03926276622223668, 0.04517070701695047, 0.00331660810388712, 0.0885918528365437, 0.08925770773203112, 0.0566052471549483, 0.07718966662650928, 0.055129801912698895, 0.007943226992210839, 0.039419808381353505, 0.14856209774734452, 0.1225927697669249, 0.12435466545866802, 0.05437978375994135, 0.04650342612876557, 0.13897634024033323, 0.19728437473531812, 0.16490815265569836, 0.09154992731055245, 0.21815165266161785, 0.12697477330220863, 0.17532106343423948, 0.1252951892092824, 0.15578631166135892, 0.11185763331013732, 0.1479369422304444, 0.2708602126222104, 0.24749468750087544, 0.11264160842983983, 0.13377133203903213, 0.1283455200609751, 0.1356752376887016, 0.09134556210483424, 0.22609380539506674, 0.11082437820732594, 0.09757730935234576, 0.13472760416334495, 0.07637993898242712, 0.14497335359919816, 0.17363135644700378, 0.1577062180149369, 0.15103843674296513, 0.17788211116567254, 0.16065362782683223, 0.1069544862548355, 0.15921172394882888, 0.1047793182078749, 0.13435690139885992, 0.10908116979408078, 0.17887375404825434, 0.09950732375727966, 0.12156349257566035, 0.18978440843056887, 0.1489502112963237, 0.20554243004880846, 0.08369571165530942, 0.11453785511548631, 0.1758882572175935, 0.29306889278814197, 0.17289498267928138, 0.060958611211390235, 0.1444267766783014, 0.18881446594605222, 0.12584814860019833, 0.10451890600961633, 0.14672127465019003, 0.22244289895752445, 0.1067697508551646, 0.3567310923244804, 0.14224607963114977, 0.2393388852942735, 0.24875693226931617, 0.13384412188315764, 0.08352348144399002, 0.10747669104603119, 0.10385397137724794, 0.1342263724654913, 0.09784822294022888, 0.1176088399370201, 0.09983617681427859, 0.1917739282362163, 0.17770602920791134, 0.15320415725000203, 0.1378278518677689, 0.14627905853558332, 0.24419083900284022, 0.13813379482598975, 0.05687539261998609, 0.11740176589228213, 0.1623762267990969, 0.15299111633794382, 0.112087342859013, 0.09654530105763115, 0.08651001728139818, 0.07404028132441454, 0.10963865628582425, 0.17094484122935683, 0.1562545623164624, 0.14683540211990476, 0.09430518024601042, 0.10952420969260857, 0.11680132389301434, 0.15196889697108418, 0.12735408497974277, 0.12004977106698789, 0.12035260442644358, 0.2469072034000419, 0.12832315173000097, 0.2107292556320317, 0.12206854633404873, 0.0713344405812677, 0.11453921324573457, 0.11569303023861721, 0.1261834954493679, 0.11375294488971122, 0.19964382547186688, 0.2154808709747158, 0.19447098195087165, 0.09574652009177953, 0.12196651587146334, 0.1975001467508264, 0.066444414696889, 0.2094436777406372, 0.09155887019005604, 0.14805684360908344, 0.12031959369778633, 0.13340678910026327, 0.08274323932710104, 0.08623784946394153, 0.10147997454623692, 0.12133092575822957, 0.16079962311778218, 0.15726213168818504, 0.14265475067077205, 0.1936959571321495, 0.16298121074214578, 0.06804627366364002, 0.12080385989975184, 0.10547983882133849, 0.12935745326103643, 0.09816576566663571, 0.12303313051234, 0.11328401888022199, 0.14787117310333997, 0.12248213781276718, 0.11418532754760236, 0.06981473736232147, 0.2028735779458657, 0.18591355910757557, 0.14031345286639407, 0.13808945892378688, 0.17621677630813792, 0.11004457395756617, 0.09937086506397463, 0.15385533246444538, 0.16938557411776856, 0.21962143160635605, 0.15356853691628203, 0.18708005198277533, 0.14379114203620702, 0.22955632506636903, 0.10529011618928052, 0.16392462886869907, 0.16526239458471537, 0.329261178849265, 0.12796795985195786, 0.1354274494224228, 0.1332247699610889, 0.14274132961872965, 0.13090760679915547, 0.14305359567515552, 0.2173943058005534, 0.14046771568246186, 0.15987833583494648, 0.13106333906762302, 0.2464362364844419, 0.1700733372126706, 0.16251055552856997, 0.19053552125114948, 0.17847066395916045, 0.3110355162061751, 0.14168655965477228, 0.17861275555333123, 0.199195672175847, 0.14564752054866403, 0.15809596428880468], [0.02208238518505823, 0.016652858757879585, 0.02578509353043046, 0.03436473256442696, 0.04244620125973597, 0.022401799978979398, 0.07198558610980399, 0.07082524563884363, 0.015134547065827064, 0.013013976968068164, 0.03743843735719565, 0.011649129355646437, 0.015440297993336571, 0.02987107291119173, 0.04072409210493788, 0.03504293679725379, 0.02243388858914841, 0.021222698014753405, 0.03468217510089744, 0.14689799485495314, 0.052707788127008826, 0.017706229773466475, 0.04415212788444478, 0.0626126913994085, 0.03505559783661738, 0.050428979157004505, 0.07189312193077058, 0.02488355850800872, 0.08045761001994833, 0.058623914810596034, 0.036670425834017806, 0.04406357111292891, 0.008808228867565049, 0.08682730025611818, 0.05520421334949788, 0.08659929764689878, 0.02613228320115013, 0.044879833367303945, 0.07124202093109488, 0.003200098803972651, 0.025199340489052702, 0.024977746325021144, 0.007507989848818397, 0.022455483231169637, 0.008894689999578986, 0.015683814272051677, 0.028263356543902773, 0.039440369582735, 0.027047136063629296, 0.059017167732235976, 0.018324167904211208, 0.01298653884077794, 0.03864042344503105, 0.01202436664243578, 0.09405145479831845, 0.05667176956194453, 0.08747197425691411, 0.05183190914976876, 0.03253856688388623, 0.05575880917604081, 0.0016305408871630789, 0.04736507442430593, 0.038070858499850146, 0.04717486197478138, 0.026912389876088127, 0.051331961367395706, 0.009866037926258286, 0.060277148950262927, 0.03535005605954211, 0.02225397158326814, 0.016001859803509433, 0.01712310579023324, 0.015725265075161587, 0.0054821581488795346, 0.007927686419861857, 0.01553483276438783, 0.1331009203568101, 0.03722340006788727, 0.011955234658671543, 0.04757216702273581, 0.10936518970993347, 0.03183436150720809, 0.03632952400948852, 0.06282054469920695, 0.011027321852452587, 0.021028745140938554, 0.037077642264193855, 0.07742690897430293, 0.05388781035435386, 0.03979722016083542, 0.02869013413146604, 0.027480988173920196, 0.05831327405758202, 0.00870191342983162, 0.037438199869939126, 0.09384577599121258, 0.011074483481934294, 0.0198218590230681, 0.03785229229833931, 0.028636684655793943, 0.03468771152256522, 0.03720893189893104, 0.02598877781565534, 0.03688093973323703, 0.009026646639540559, 0.015293771139113232, 0.015983454541128594, 0.03361251394380815, 0.03170438918459695, 0.027926189577556215, 0.050239961565239355, 0.04830448124266695, 0.008087043152045226, 0.0384494577156147, 0.036508893681457266, 0.03790602750086691, 0.041910251893568784, 0.05589880049228668, 0.02237516615423374, 0.02276614810398314, 0.036329594513517804, 0.015812899728189223, 0.04761489988595713, 0.04100428253877908, 0.040050218303804286, 0.04759256866236683, 0.009967777095880592, 0.026742914888018277, 0.03956902459322009, 0.05627772996376734, 0.046594506202382036, 0.012001106806565076, 0.03839825694740284, 0.022705173250869848, 0.02036889793089358, 0.013598212317447178, 0.07656320492969826, 0.009504833724349737, 0.05158142688742373, 0.029724752930633258, 0.06568017328390852, 0.07422415583278053, 0.06615776757826097, 0.07618205272592604, 0.05020417520427145, 0.037697676962125115, 0.02177966685849242, 0.08788311664829962, 0.008833983247313881, 0.023130188237701077, 0.012814782676286995, 0.06418410004698671, 0.04506732955633197, 0.05716415114875417, 0.032302408071700484, 0.03961700072977692, 0.00561595995350217, 0.05974001585855149, 0.050148143054684624, 0.058624686644179747, 0.07062078395392746, 0.007550450900453143, 0.009505343950877432, 0.04144411635934375, 0.013588955880550202, 0.022692079910484608, 0.019779909125645645, 0.036942241131328046, 0.045767493938910775, 0.031740969643578865, 0.07329385887715034, 0.03278613992733881, 0.045116600740584545, 0.036433198329177685, 0.015794288519828115, 0.018818594107870013, 0.055288636358454823, 0.037445279958774336, 0.04311069431423675, 0.050152644180343486, 0.014129274641163647, 0.038495322442031465, 0.022291754321486223, 0.016378347609133925, 0.033902359718922526, 0.05594873960944824, 0.011877096712851198, 0.021944583204458468, 0.05754950761911459, 0.05410010169725865, 0.01605147608643165, 0.05499539525771979, 0.0361294781032484, 0.027848737190652173, 0.024395134423684794, 0.06383819985785522, 0.03920916460629087, 0.004189921801298624, 0.03614382381783798, 0.030716058136022184, 0.038836543390061706, 0.03639979055151343, 0.07300205383216962, 0.03215889897546731, 0.0898339186096564, 0.018397759267827496, 0.0548017392429756, 0.03437830644543283, 0.06009884054947179, 0.04501470015384257, 0.030100396543275565, 0.021455342757690232, 0.03228254077839665, 0.04007448282209225, 0.10807230166392401, 0.051081419733236544, 0.00784425046731485, 0.03523524952470325, 0.03652698353107553, 0.03187388829246629, 0.029914698206994217, 0.010936214875982841, 0.012271929481357802, 0.024901809774746653, 0.029557148154708557, 0.02749284769379301, 0.022433588019339368, 0.04501337170950137, 0.005701474847228383, 0.06109591595304664, 0.03388221040950157, 0.04451050728675909, 0.050567066864459775, 0.04286766692530364, 0.06033524427039083, 0.04061628773342818, 0.07767296061501838, 0.03606546415539924, 0.047168075034278445, 0.024544330226490274, 0.03538840654073283, 0.08371348609216511, 0.03244885978347156, 0.038049625654821284, 0.027338952240825165, 0.0821855895628687, 0.006461852453867323, 0.008713012248335872, 0.02002230568905361, 0.040956250741146505, 0.03186588794051204, 0.06360247149132192, 0.007339526036957977, 0.018294751025678124, 0.03369304438820109, 0.025894634527503513, 0.017842604975157883, 0.03752536511456128, 0.04043399399961345, 0.09186552561004646, 0.08150000096065924, 0.06609960546484217, 0.022708190081175417, 0.0404097257705871, 0.006926796377229039, 0.041732837780728005, 0.013447450583043974, 0.07476604980183765, 0.03548482265614439, 0.01863141147623537, 0.04212236883176956, 0.06104032538132742, 0.00938319386477815, 0.02968619650346227, 0.045845174536225386, 0.07450083590811118, 0.0845843370188959, 0.03784450716921128, 0.0875888550945092, 0.03799096630245913, 0.0312165680952603, 0.03174113291606773, 0.013868649075448047, 0.1156932306184899, 0.060941775591345504, 0.007431397889376967, 0.03564110040315427, 0.007643675317012821, 0.02449724095640704, 0.022449664793384727, 0.06382490799296647, 0.015262938613886945, 0.07497093451092951, 0.03391836042283103, 0.024364882629015483, 0.05303082274622284, 0.03320611016533803, 0.04577530504320748, 0.05134220300533343, 0.0387704588501947, 0.012134317676100181, 0.06356652185786515, 0.037695521023124456, 0.05059496790636331, 0.04848278964345809, 0.05127320924657397, 0.03729512864083517, 0.036374212431837805, 0.08266796328825876, 0.026634251480572857, 0.015132328971958486, 0.05613079956674483, 0.014388927065738244, 0.026960358591168188, 0.07115230269846506, 0.013241493470559362, 0.027483745252538938, 0.03680233516206499, 0.10014778978074901, 0.0407505570910871, 0.034647754291654564, 0.10138754005311057, 0.06169290325487964, 0.045394338376354426, 0.022182790344231762, 0.018744553744909354, 0.04700173747551162, 0.04122261867451016, 0.07176409213570878, 0.026745137620309833, 0.02605446530651534, 0.05237926532572601, 0.048634792619850487, 0.021259387940517627, 0.046017044805921614, 0.03862938770907931, 0.058162417699350044, 0.06724688413669355, 0.04033328455989249, 0.028418725160008762, 0.011157468579767738, 0.045205892238300294, 0.04714289025287144, 0.03447824405157007, 0.023312893863476347, 0.04108659042685758, 0.0407810111209983, 0.04258964727341663, 0.09116761735640466, 0.03996352061221842, 0.03840957841021009, 0.01375256882965914, 0.1042744203004986, 0.13876322511350736, 0.22506561916088685, 0.1039621616655495, 0.10735952819231898, 0.13849949551513419, 0.15925178508041427, 0.11353973328368738, 0.08323132758960128, 0.14626287971623242, 0.11688535727444105, 0.10672458374756388, 0.1269042692729272, 0.11178168191690929, 0.14722054707817733, 0.12201808029203676, 0.16167353169294074, 0.14926989882951602, 0.16302847070619464, 0.20822232530917972, 0.19562911824323237, 0.19794386200373992, 0.15772882383316755, 0.17330963542917743, 0.23860883462475613, 0.12736267904983833, 0.1590692761237733, 0.1261476200306788, 0.21676889795344323, 0.13218283915193751, 0.09729327459353954, 0.11129804654046893, 0.1254461272037588, 0.20366593933431432, 0.09503736087935977, 0.1785564562305808, 0.07965341879753396, 0.0972288339107763, 0.14991271746112034, 0.19000087806489319, 0.20028636208735406, 0.18140164262149483, 0.13045687082922086, 0.19957511743996292, 0.08547714809537865, 0.06139174714917317, 0.1716462301556021, 0.16572320892009884, 0.08902276604203507, 0.15903298510238528, 0.21176401729462668, 0.11670621766825207, 0.05667670484399423, 0.08775122958468273, 0.12609562516445294, 0.1934825599892065, 0.17572347074747086, 0.11034415671019815, 0.12566045945277438, 0.1265854129451327, 0.12272824882529676, 0.07984220632351935, 0.16262686491245404, 0.14701167703606188, 0.13333929819054902, 0.14750861912034452, 0.10183215330471285, 0.19332066789502278, 0.08819397262413986, 0.1913541546673514, 0.11537925762240775, 0.06118325189163443, 0.13299966172780842, 0.08814182932837866, 0.10574672996881418, 0.21133346774149686, 0.27227967395447195, 0.1097647768619936, 0.09692041960079223, 0.14941904082661495, 0.2468121045967564, 0.14537573122652248, 0.0785869600076694, 0.33205076353624463, 0.24364191689528525, 0.1220228745660279, 0.15661478595575318, 0.10174655399168842, 0.07510333365644328, 0.11141506096464582, 0.10511088010389358, 0.1704638553201221, 0.13172499340726063, 0.08889625954907387, 0.09252671239664778, 0.2163346970337443, 0.12407186266500503, 0.14718409278430045, 0.1680403869249858, 0.1927153574069962, 0.20383924565976486, 0.19402398640522733, 0.12005938930087723, 0.094929749466246, 0.09323335572844371, 0.14836633403319865, 0.07995656385901384, 0.1475553447380662, 0.13828989816829562, 0.21819745801622048, 0.11874448915477842, 0.10889113545999862, 0.042723196747829206, 0.126036386936903, 0.14611759688705206, 0.08504449084284715, 0.1800538579118438, 0.20762085914611816, 0.12158131154137664, 0.12354208796750754, 0.1746838999679312, 0.17775766784325242, 0.08655219353386201, 0.12980511673958972, 0.1593114240677096, 0.15497322950977832, 0.17435172951081768, 0.07299762321054004, 0.17523484071716666, 0.17448110069381073, 0.13619702687719837, 0.11048699787352234, 0.10185587234445848, 0.09059300209628418, 0.17747811565641314, 0.10014221625169739, 0.158321903727483, 0.17158316244604066, 0.1479430278413929, 0.09191824778099544, 0.09847296285443008, 0.14209843677235767, 0.25953046744689345, 0.15905756503343582, 0.1338803832186386, 0.2153705433011055, 0.18132882309146225, 0.1781822060002014, 0.09697824774775654, 0.11209965508896858, 0.1007356820628047, 0.14168829628033563, 0.14341101399622858, 0.14540739124640822, 0.13701943040359765, 0.116178209282225, 0.1320639916229993, 0.154211429762654, 0.10692606199881993, 0.10182361860643141, 0.1540810492588207, 0.1411910424940288, 0.11449689598521218, 0.12002698713331483, 0.10062913192086853, 0.1702924637356773, 0.16726077563362196, 0.13353228627238423, 0.1761770565644838, 0.10835447363206185, 0.1815592747880146, 0.12656311882892624, 0.29894762265030295, 0.1345997618045658, 0.13805885275360197, 0.1542673134827055], [0.1297674304805696, 0.04672990362450946, 0.036573798206518404, 0.10543463460635394, 0.04094632822670974, 0.03960668487707153, 0.0592251583293546, 0.05896093149203807, 0.04761524869536515, 0.0144187706791854, 0.01901566400192678, 0.11073006608057767, 0.03838967029878404, 0.013155437736713793, 0.05035573289205786, 0.015237197221722454, 0.011525202753546182, 0.0731096652452834, 0.012708746471616905, 0.04728776490082964, 0.08139632293023169, 0.03366333250596654, 0.037485879147425294, 0.029091506148688495, 0.034029396847472526, 0.018325153105251957, 0.0672154244966805, 0.024749367075855844, 0.007689488093092223, 0.05697100350516848, 0.02677694606973091, 0.011603066104726167, 0.024194492943934165, 0.042919201659969985, 0.016492831309733447, 0.03812656410445925, 0.0431597057468025, 0.0379845541465329, 0.07152854930609465, 0.034687919323914684, 0.05681200578692369, 0.052709714000229724, 0.05556820338824764, 0.08920432504964992, 0.03263102364144288, 0.013412831249297597, 0.043160054556210525, 0.020230351947247982, 0.02229673042165814, 0.021336810641514603, 0.029627392432303168, 0.029923552028776612, 0.05293231377436314, 0.03743160217709374, 0.025392092939000577, 0.04454057168914005, 0.02071822869766038, 0.07067972532240674, 0.04432231347891502, 0.04545659714494832, 0.02599478179035941, 0.04968952918716241, 0.015746546159789432, 0.0277944416666287, 0.07048763523926027, 0.033875653534778394, 0.031047735064930748, 0.025715699011925608, 0.0381970866874326, 0.040800570423016325, 0.030523804780386854, 0.019631733775895555, 0.03520410529745277, 0.006667892594123259, 0.02416605198959587, 0.032635632378514856, 0.04526193552010227, 0.04728759049612563, 0.039535115865874104, 0.02737301681918325, 0.057704994978848845, 0.03687432348669972, 0.03055766712350305, 0.027760666525864508, 0.052657685737358406, 0.03278097457950935, 0.06578411106602289, 0.10028955482994206, 0.06844630610430613, 0.08402489867876284, 0.04267387732397765, 0.012998271267861128, 0.013628662636619993, 0.01231368178196135, 0.05496423618751578, 0.0675698668055702, 0.053666780222556554, 0.01073192202966311, 0.07454158723703586, 0.007495037980334018, 0.06750371918315068, 0.0785299036942888, 0.05317686627677176, 0.006748289915776695, 0.049909620502148755, 0.01363315170237911, 0.028026672662235796, 0.010568298876023619, 0.017963298596441746, 0.0105733491909632, 0.07798821752658114, 0.037365647513070144, 0.05502086947672069, 0.027144988234795164, 0.05555898962484207, 0.014349939265230205, 0.005908381444896804, 0.08283413757453673, 0.07947380421683192, 0.018603820280986838, 0.011481356668809894, 0.057048190574278124, 0.05607827777566854, 0.06047258611943107, 0.06058792700059712, 0.024835369003994856, 0.0634682466625236, 0.03808674788160715, 0.014947782819945132, 0.048111782598425634, 0.021773143380414695, 0.054796143449493684, 0.05327593185938895, 0.025678157471702434, 0.026235078075842466, 0.054698933236068115, 0.04049826027767267, 0.03278270007285755, 0.07867222535423934, 0.05579116310400423, 0.020943116142007057, 0.006334575518849306, 0.0878554790688213, 0.022253014212765265, 0.019405490056669805, 0.02726834616623819, 0.05512034324056003, 0.06060951236577239, 0.04517736779234838, 0.00838005789773888, 0.06639701372478157, 0.016365172632504255, 0.024210775663959794, 0.029265226221468765, 0.012840152994613163, 0.03242178623622749, 0.038994045680738054, 0.030678579678351525, 0.04563500202493742, 0.04472118445846718, 0.011090262469224399, 0.02849189349944936, 0.017245283706870396, 0.06645762492553331, 0.014079161119298078, 0.020744357861985918, 0.023060758467181586, 0.019821723581117112, 0.007097443030943396, 0.08546683966415003, 0.02319715222256491, 0.03690857360197697, 0.06087002846470568, 0.03997570296633057, 0.031241808537743054, 0.0530650691507617, 0.07061256095767021, 0.026915575544990133, 0.04194398621621076, 0.06794036176870577, 0.03194741286279168, 0.011412857365939999, 0.030031068818061613, 0.037426689159474336, 0.043215229525230825, 0.04813529012608342, 0.0073775986766122514, 0.03350807150127366, 0.06248052974115126, 0.030645010483567603, 0.07324787540710531, 0.02311191099579446, 0.06706077576382086, 0.025290795347245876, 0.04621761021553539, 0.020174410710751545, 0.03777284910029266, 0.009406119734194363, 0.03624199511250481, 0.030909090746717993, 0.09240685554686934, 0.03366379634826444, 0.03756268029974308, 0.04533061757683754, 0.0412965959549183, 0.0684077366895508, 0.021790348218928557, 0.013620037952932762, 0.02834688340954017, 0.028388360187818762, 0.03735936894372571, 0.034818125423043966, 0.01021490485072718, 0.006074194861866999, 0.04840396984945983, 0.08113498304737732, 0.032775760992080905, 0.029429791902657598, 0.0813300788286142, 0.05390856822486967, 0.05858996155438945, 0.06560456327861175, 0.02629507886013016, 0.006026174196449574, 0.013308048346516443, 0.041373612330062315, 0.043091762127005495, 0.04634330776752904, 0.058907997809001245, 0.05438423664600123, 0.029202564837760292, 0.04191003296000417, 0.02654228825122118, 0.11335677161696367, 0.061360755062196404, 0.024558677796449047, 0.005538457471629954, 0.05093410341942217, 0.07208826224086806, 0.026689537771744654, 0.04090261572855525, 0.04737714545626659, 0.07904108017100953, 0.023364575172308832, 0.09444423645618372, 0.03367384502780624, 0.03485947418084834, 0.031538812327198684, 0.026021705052698962, 0.04217256770061795, 0.01866569869889645, 0.0528203348221723, 0.0523077371326508, 0.021628960785164963, 0.01271838604225195, 0.040045787682174705, 0.02049755108600948, 0.008999138935905648, 0.0422634733695304, 0.03574504931748379, 0.05536934120755177, 0.07699533525737934, 0.09366648795548826, 0.06966262677451596, 0.05541679412999656, 0.06152534857392311, 0.03380259280675091, 0.007652303711438435, 0.0510433846648084, 0.007285493975359714, 0.03556272218702361, 0.006897774692333769, 0.0997834769077599, 0.041156593506457284, 0.06110861781053245, 0.04162129669566639, 0.11752167469239794, 0.018265733051521238, 0.047049268323462456, 0.03951010548917111, 0.059135287956451066, 0.037416796330944635, 0.1326533014071174, 0.014539793628500775, 0.03717088940902613, 0.025761968208826147, 0.020222266248310916, 0.035425662354100496, 0.02978402641019784, 0.027503408455231693, 0.023259795052581467, 0.041829153706203215, 0.022428879092331044, 0.031722631174488924, 0.04070316725119483, 0.0609740441723261, 0.050943747628480196, 0.05874369373486843, 0.039681938651483506, 0.03284622791397851, 0.09181037661619484, 0.02109192602802068, 0.05143535367096774, 0.03552492089511361, 0.009846332050074125, 0.03976256186433602, 0.024263636987598147, 0.036535766848828644, 0.015843264700379223, 0.002647394526320568, 0.010881428606808186, 0.05358089518267661, 0.05666745768394321, 0.11657032300718129, 0.06321199049125426, 0.03947067518311087, 0.061547167715616524, 0.027834599277412053, 0.07214186756755225, 0.03145435963233467, 0.059941457002423704, 0.03735413309186697, 0.08082395637757145, 0.013621358975797193, 0.029231501175672747, 0.0502320947998669, 0.03196728757757228, 0.025390139235241804, 0.034643015678739175, 0.08974195166956633, 0.005132796768521075, 0.03785627392062452, 0.020823745398956817, 0.009539409456920112, 0.01857452400145121, 0.01756422352627851, 0.015846251844777726, 0.012750806763506262, 0.04343268992670346, 0.040649068396305665, 0.12747950793709606, 0.026796588863362558, 0.022146894516481552, 0.0233230631420156, 0.03908923354174476, 0.014082240104471566, 0.059620630272547714, 0.043465915878186934, 0.06279287743382156, 0.0406391681462992, 0.044242951917112805, 0.05882788296730723, 0.276526064844802, 0.14506263396469876, 0.2380647067911923, 0.2502862166147679, 0.11408688165829517, 0.12968092574737966, 0.18060113245155662, 0.16659876506309956, 0.13271654723212123, 0.16634017112664878, 0.1334078874788247, 0.3156633710023016, 0.12599191744811833, 0.1524057102506049, 0.15619176178006455, 0.10686661596992053, 0.1418300613295287, 0.20916549110552296, 0.1405384868849069, 0.09447399657801725, 0.2032250739284791, 0.10587501019472256, 0.15804451861185953, 0.2037239752826281, 0.19132386019919068, 0.12004575604805723, 0.2511249028611928, 0.04371969698695466, 0.21427409432362765, 0.2941480645677075, 0.10601267116726376, 0.09077663169591688, 0.13516398699721321, 0.11705973229254596, 0.16617767047137022, 0.14024155359948054, 0.10443381135701202, 0.13030566566158086, 0.11485128634376451, 0.25468163075856864, 0.1188967407506425, 0.16883028438314795, 0.15081635647220537, 0.12174534102086909, 0.0909864368441049, 0.10573043982731178, 0.07473067904356867, 0.1341399271041155, 0.08472957531921566, 0.11916588802705519, 0.09805405759834684, 0.2236193514545448, 0.14547739061526954, 0.15474375744815916, 0.1349847434903495, 0.1527912262827158, 0.10564548618276604, 0.299971163040027, 0.21888959978241473, 0.14245365833630785, 0.0686865096213296, 0.13638241536682472, 0.11956258080317639, 0.13022772531257942, 0.16318068519467488, 0.10681861385819502, 0.13804236223222688, 0.14259540854254737, 0.1268862944561988, 0.11713189873262309, 0.1436426828149706, 0.10122230829438195, 0.09976944289519452, 0.20243431557901204, 0.1342060524621047, 0.15993619366781786, 0.12562241696286947, 0.0928173671127297, 0.14787657593842596, 0.11444904972449876, 0.12236459646373987, 0.16948376025538892, 0.14758799923583865, 0.1481638167751953, 0.15517690451815724, 0.11644318568869494, 0.2127781620947644, 0.11835903249448165, 0.13504672766430303, 0.27089589508250356, 0.1107252346992027, 0.15417408489156514, 0.1905980843002908, 0.1347393449395895, 0.23484317731345072, 0.11681664182106033, 0.20910138438921422, 0.09151681268122047, 0.158780476776883, 0.1065006258431822, 0.28385043900925666, 0.12434384494554251, 0.14303863397799432, 0.0763370502681937, 0.17861167201772332, 0.16689498588675633, 0.17531089601106942, 0.1079785758338403, 0.15931356145301834, 0.13630851230118424, 0.2303365894476883, 0.10952332653687336, 0.1434166097897105, 0.1870920302462764, 0.1906151240109466, 0.10249436425510794, 0.11463578150141984, 0.15329345245845616, 0.20672079728683457, 0.13177391578210518, 0.12903027003630996, 0.09522816704702564, 0.12080221233190969, 0.18424331123242155, 0.28660502401180565, 0.08381676336284727, 0.12365433780360036, 0.2297138681751676, 0.08410473892581649, 0.12731865484965965, 0.1800114515936002, 0.15457301895366982, 0.15249942865921184, 0.190461395541206, 0.09655120855313726, 0.09988316960516386, 0.15884865046245977, 0.13003101164940745, 0.13001790532143787, 0.14874539338052273, 0.1761279857601039, 0.17744786571711302, 0.1700821242411621, 0.1391050880192779, 0.15130642626900226, 0.1569447002839297, 0.1203068732866086, 0.13073358801193535, 0.0769842327281367, 0.11393710141419433, 0.14810929860686883, 0.09216772072250023, 0.11074191817897372, 0.1537976527470164, 0.08688775560585782, 0.1372359594097361, 0.1401020001503639, 0.12475434166844934, 0.07644838726264425, 0.11226243776036426, 0.09525859510176815, 0.15444905060576275, 0.19967530737631023, 0.12558562128106132, 0.1610491331666708, 0.14224453596398234, 0.12473973620217294, 0.08505022022291087, 0.16679832857334986, 0.19380474113859236, 0.08865394091117196, 0.14224006823496893, 0.0586957621271722, 0.14803929923800752, 0.14293477783212438, 0.15336857264628634], [0.04876328064710833, 0.07106547884177417, 0.04030403280921746, 0.05469306655868422, 0.11669199069729075, 0.06579916924238205, 0.0438874038081849, 0.006267749295147951, 0.02717652023420669, 0.05202197688049637, 0.028819442231906578, 0.10933989731711335, 0.034947077292599715, 0.038948763540247455, 0.009036877145263134, 0.045461491608875804, 0.06430871406337246, 0.004039199029648444, 0.0704481010325253, 0.017180442264361773, 0.06577263004146516, 0.0062194865040510194, 0.0036407791367309983, 0.056969285433297046, 0.047187849559122697, 0.0426602552033728, 0.03251189409638755, 0.07428495999192819, 0.049297927544103004, 0.03171058611769695, 0.08989060384919867, 0.03865976010274608, 0.07246361827128567, 0.07728716256679036, 0.03183534856361803, 0.027384429195080884, 0.028667932783719152, 0.03272590722190216, 0.039445995062123984, 0.018031086365226656, 0.035473230309435166, 0.03940176677133422, 0.031086115232028533, 0.026919653646473307, 0.04032244178233668, 0.025483206409262493, 0.020436600352695677, 0.037629822400049306, 0.004481467094592517, 0.02938439472927712, 0.0163728204643121, 0.06762643330148421, 0.024943433127191383, 0.028305414052738342, 0.013551516385632567, 0.020814618837903254, 0.06528805955895223, 0.02468162012519315, 0.008972313080448657, 0.02905701669078553, 0.05635927715047728, 0.009463684418733465, 0.02366679625993129, 0.031042799782881048, 0.04308910894906148, 0.08063001834671013, 0.03217735618818551, 0.028701847077172715, 0.027457061332825106, 0.02877174996683607, 0.025774714595172554, 0.03961168695241213, 0.025584069844626356, 0.013138902686478104, 0.09888725195196457, 0.0012409204305185995, 0.013023631381656742, 0.034489591489546, 0.011307565164315747, 0.0413312987802783, 0.04002827299700584, 0.03604499943321571, 0.06452700938098133, 0.09300664445618168, 0.062479861808242276, 0.054651825412292965, 0.02272741541673895, 0.0451262597925961, 0.022342476404446643, 0.04301299799408298, 0.023351194249698892, 0.049872049276018515, 0.0741644723166246, 0.033368621952831745, 0.06274394763750024, 0.04701375284639653, 0.08964645210653543, 0.02192299041780643, 0.05253130912024062, 0.030628889180661645, 0.008266501881735167, 0.02171744705265155, 0.08691887385793962, 0.046259240989456885, 0.008491367061651545, 0.0376437005616026, 0.07354131317697465, 0.012219714753882727, 0.013290795268403599, 0.0352097641734872, 0.0228222173609538, 0.01573756988364039, 0.039147729621618055, 0.045327615589485504, 0.04573739613988437, 0.04873235164268408, 0.028911385052197147, 0.03037754046090413, 0.00780579423008021, 0.04290331598895136, 0.059048152397735976, 0.05596978691755794, 0.02619210401462624, 0.05800764280138537, 0.03986747557064518, 0.005568557126025553, 0.05262376958853565, 0.008048469098866917, 0.016952339465206023, 0.06552946535521187, 0.032723903423175216, 0.04599014195264317, 0.05619686555291992, 0.014905988773534773, 0.049156915774801746, 0.06845553842140362, 0.03488543450657744, 0.016522068217454944, 0.06755416296073236, 0.026884763428824954, 0.03943150462873746, 0.029721533865085803, 0.06352820477331989, 0.030979103103163652, 0.04396316966449376, 0.015437931469932664, 0.05558178840146866, 0.056510909053031355, 0.07109790327376686, 0.01565023951116018, 0.020418222920852713, 0.022675570835417602, 0.03421848865400534, 0.02527666114474414, 0.06271430625929497, 0.056601658870931715, 0.045281658094609156, 0.013756382541032508, 0.04757819326187018, 0.15252279146807268, 0.017507482625660487, 0.016182077379198745, 0.02206505789217772, 0.010602242855384247, 0.015216602623695508, 0.031899221503408626, 0.026211997283098754, 0.016646238800603896, 0.04781700896273833, 0.06315316786640324, 0.020421438275661785, 0.06882204063003883, 0.02951091420982266, 0.04757600021548569, 0.06903572721057571, 0.026487441682547797, 0.0458961192634888, 0.08464348618872464, 0.056862731580622494, 0.04516243207035586, 0.024514950455341022, 0.06411313588614576, 0.036895085067953914, 0.03083774066908518, 0.03251209818699863, 0.046267746001831256, 0.019329588758409955, 0.07315491398912854, 0.014958394604036584, 0.03503938562062103, 0.02382216673140647, 0.018517463977332227, 0.027482778605190106, 0.013121564261382446, 0.06517038462334312, 0.024637376991449855, 0.028166367119411007, 0.052137028324068524, 0.0693290239723865, 0.08977922232588753, 0.027153827213624027, 0.025791513107833453, 0.07888993437518366, 0.043703811315936036, 0.05795606724859681, 0.014251056436478393, 0.07108933888957836, 0.04525413183728233, 0.026545357031864114, 0.02651512379088672, 0.014627433847635984, 0.022189606970641762, 0.01377611717543914, 0.017445134799345396, 0.05564971346757375, 0.09783228902961127, 0.04819066547497641, 0.019282493922219146, 0.043201091611990705, 0.0444308303121943, 0.05956806395261083, 0.055448506100219674, 0.017492519073130097, 0.04168573737842962, 0.018282761629961897, 0.020294158093747683, 0.028230959942447953, 0.03690802441269625, 0.014153197771520354, 0.03771688003325835, 0.03048458784178365, 0.058242406375939026, 0.029178710356063675, 0.03815330368524883, 0.007174971951826592, 0.02218459005234763, 0.03741457730939146, 0.025966062530642375, 0.032876771001610905, 0.024755530612310395, 0.04442148667294532, 0.059453899375512265, 0.04374694122816436, 0.044954344994039275, 0.05354479711968452, 0.04737254785140976, 0.05505234395968728, 0.07929032304673456, 0.035292509928694926, 0.0612667843233794, 0.05157469189725816, 0.061813038410036825, 0.019559207394195255, 0.03336864792800043, 0.03201884828740731, 0.013461719299812103, 0.06539771187817678, 0.038181275231181644, 0.03307906932604965, 0.04870749711699318, 0.03452115874097217, 0.02226938599051209, 0.01765914050338324, 0.032658445998094976, 0.07755281432764605, 0.07859760982682928, 0.04760257652378641, 0.034007291978923604, 0.04809731442946941, 0.04855947205214761, 0.030705295139341615, 0.028708229547191877, 0.027478624433570076, 0.019167709651810583, 0.031349969140137546, 0.012109472427255241, 0.08134049858199432, 0.054152434240677394, 0.03478657301457133, 0.04809530692000408, 0.0042137823129451135, 0.05258159333607182, 0.030387511214939877, 0.018790195827023126, 0.013480253510351758, 0.057084685686277226, 0.007529972726842971, 0.06360644198139198, 0.039743184388498776, 0.05986113435938023, 0.05936288980592508, 0.04531673199380748, 0.023691257447353564, 0.029923219917691313, 0.06556802734849043, 0.012367814961180557, 0.04085419059265405, 0.07208285940578207, 0.023261385103978682, 0.0016265904582724033, 0.04260490582964849, 0.014005829507368617, 0.04361533989140298, 0.07953756212373264, 0.0251795993608539, 0.03631889274402056, 0.05192929747863673, 0.0641425175126642, 0.01788733421562938, 0.04766417478094809, 0.04284779592126142, 0.031198686046991497, 0.024188500101445243, 0.04037413607875351, 0.04461130578420125, 0.03939254929719027, 0.05829235291457735, 0.0845682027284056, 0.042290157289244235, 0.012110208081139717, 0.03430683762417175, 0.045755764294881374, 0.04043059867399279, 0.01779983129381435, 0.013796873190585757, 0.03298417461337522, 0.05724630689655896, 0.005150305887582363, 0.04683258346631192, 0.014733038678969024, 0.08025979055673815, 0.04516823937592562, 0.012765780520567205, 0.01347915327642113, 0.030363649311766494, 0.03752054115466308, 0.05430015873571392, 0.03152644814690575, 0.03639004615251906, 0.030633804053650238, 0.04746909013192635, 0.07494108533137478, 0.05472351687785704, 0.04908219263597857, 0.02727025163039798, 0.039970815923879854, 0.053859527106396854, 0.06682168546831235, 0.03743693450815044, 0.03651633742265403, 0.07758250765618868, 0.049681836826493964, 0.11672554319375195, 0.14899243949912488, 0.16340821282938123, 0.18269511696416885, 0.2614495129091665, 0.21187127247685567, 0.1766886783298105, 0.15858395607210696, 0.0894828382297419, 0.12954736885149032, 0.1405769746634178, 0.2578398847253993, 0.1091721719421912, 0.10698390498873778, 0.06596293154871091, 0.13477383996360004, 0.09898597243591212, 0.12110945404856466, 0.13443311996525154, 0.10014637227868661, 0.1463210937799886, 0.12318935259827413, 0.17320625425782055, 0.20162579021416605, 0.12940996763063595, 0.16982450993964449, 0.13007721776375547, 0.21588314470136538, 0.15121975826332346, 0.13047624088358134, 0.1854969174019061, 0.11819469873444177, 0.13961696211481467, 0.14179822319420055, 0.11361630808096379, 0.07834433708922006, 0.0973006738058757, 0.12633786216611043, 0.09989426471292973, 0.20089676370844245, 0.11281701503321528, 0.1566911826375872, 0.1056157260609325, 0.21126235515112057, 0.12331090154475532, 0.14269208069890738, 0.09799389910767786, 0.07165833609178662, 0.09516065387288108, 0.11761824294808321, 0.10237987313303165, 0.14857851405395195, 0.11526770540513098, 0.12019407426123507, 0.19877641811035573, 0.15169378282735124, 0.19662418984808028, 0.08773355162702501, 0.1675720323692076, 0.1350644204649143, 0.1283532235538587, 0.14548166538588703, 0.15177311841398478, 0.09103150747250766, 0.13667042803717777, 0.19042874104343355, 0.1310259199817665, 0.22465577552793548, 0.25717616721522063, 0.1794620990403928, 0.12996142788324505, 0.2292190634761937, 0.09897218333208002, 0.12493199697928503, 0.27392863703425974, 0.163369576621335, 0.1475202856818214, 0.10430820286273956, 0.1582832823623903, 0.156973896373529, 0.12037831242196262, 0.17022868356434628, 0.26333290559705347, 0.19799517409410328, 0.158362009387929, 0.13857105339411646, 0.12753512448398396, 0.15955897484673187, 0.2417208527913317, 0.1342444066540338, 0.13584274041932076, 0.22260526602622122, 0.1438654013327323, 0.14615670806961134, 0.21409418288385496, 0.1740014654933475, 0.1266537795891054, 0.16362282709451392, 0.223738866916392, 0.19622132240328938, 0.10149721463676542, 0.1879307016497478, 0.21121487254276872, 0.16538389900233597, 0.17925288761034608, 0.13996609806781635, 0.19308567425468937, 0.13276704296004027, 0.07943599921418354, 0.15452204825123772, 0.10873310995521024, 0.12236445545568131, 0.16536954586626962, 0.13561522762756795, 0.14301552349934354, 0.1406435898388736, 0.16197478427784517, 0.11785035705543123, 0.16291511507006362, 0.12948118412168697, 0.1366106851492077, 0.167935699573718, 0.10870631100260653, 0.17331396957160905, 0.11157790300785564, 0.11334444454405457, 0.1778533900505863, 0.18295209301868454, 0.060662995238089934, 0.19479592388961464, 0.2491030254168436, 0.17214055988006294, 0.1110204313590657, 0.1484648764017038, 0.09199874853948131, 0.14543069468345493, 0.09659214541898109, 0.1723898175987415, 0.14823892212007195, 0.15489022771362215, 0.21419176046038046, 0.13509554613847286, 0.15136317088035867, 0.13809616793878376, 0.13565226079663262, 0.10121103507117368, 0.1718149648513645, 0.18513543211156502, 0.12238251190865412, 0.13215036276960745, 0.11763469636207446, 0.14580687449779361, 0.13210899545811117, 0.13615141448099166, 0.14883234340231866, 0.114984679967165, 0.09880096986307763, 0.07595655115437694, 0.1437695455388166, 0.2750306372763589, 0.14058533124625683, 0.0786922410770785, 0.10931433775112964, 0.0827085439232178, 0.11800151769421063, 0.17192348168464378, 0.12641926092328504, 0.10023283248301595, 0.09182340872939676, 0.20132375095272437, 0.09005830695969053, 0.13000546692637727, 0.21128343214513734, 0.12765202758600935, 0.20988532982300967, 0.13751616468653083], [0.09621622535632923, 0.05472530174301937, 0.029786085870000534, 0.05487125992658548, 0.044222995566087775, 0.025636927457526326, 0.0223670303603285, 0.0485915662284242, 0.04038392500660848, 0.06686282271402888, 0.023620284009666648, 0.02700432527490193, 0.011983395452261902, 0.021950952686893288, 0.004400117968543782, 0.008062704418989597, 0.037127451505512, 0.01311381067353068, 0.06933689815923572, 0.026972175437549595, 0.025011508478200994, 0.04523887328105047, 0.030724227326572873, 0.022960334754316136, 0.027501514123287052, 0.061978908415767364, 0.014099956097197719, 0.03886260761646554, 0.032954759590211324, 0.03419247266720049, 0.04262147056579124, 0.04035053207189776, 0.06040044936526101, 0.013477026095642941, 0.028704372234642506, 0.010216338123427704, 0.03157746708893683, 0.06187690763908904, 0.023079282473190688, 0.051821641536662355, 0.09481765548116527, 0.13161793118342757, 0.022026824299246073, 0.02450153242534725, 0.024400253387284465, 0.006955328244657721, 0.05140655834111385, 0.014093538375163916, 0.02339655431569554, 0.06674352989648469, 0.025841160932031926, 0.01489518032030901, 0.015657154472137336, 0.07004326689639129, 0.04059024948219303, 0.023464971054636408, 0.07924062883830629, 0.04843646107474342, 0.04108394467039034, 0.03599891948397271, 0.07944376207888126, 0.013110254858474946, 0.02925650042016059, 0.1420741091715172, 0.09374124449095689, 0.009547697391099064, 0.024013282745727338, 0.04868734780757222, 0.03747740382095799, 0.03162277891533449, 0.0229823858171585, 0.06562765149283223, 0.03899466908478644, 0.014315550924948184, 0.028894913084513973, 0.025420483798370697, 0.05435355255031027, 0.04808870180568192, 0.03370944585185498, 0.027058669038524386, 0.051858259103028104, 0.09357011265819892, 0.06678897902020253, 0.06186755286762491, 0.02656680138898082, 0.04587247814924922, 0.031056648258527275, 0.008501592001266545, 0.09446425960049964, 0.034187567071057856, 0.024907364750106353, 0.030590937603847124, 0.05486905203724746, 0.06824580006650649, 0.04939979102346115, 0.023870426739449613, 0.03190362243913114, 0.0052199262972862925, 0.031608804274583235, 0.01070440968760522, 0.07050074898870662, 0.015113732606550911, 0.058725819108076394, 0.06461086464696564, 0.024365812168980483, 0.03581124889024068, 0.04808446414244827, 0.0686965805653017, 0.028863620427728165, 0.05118030348967295, 0.08622845387435518, 0.044429709669202566, 0.0639009484439157, 0.02532400088966824, 0.01946958935150178, 0.02581133958301507, 0.04515023116255179, 0.08029121308936737, 0.036132717577856965, 0.0785425869980827, 0.014701172713103006, 0.023632225165783893, 0.03129182929114904, 0.023362688261840958, 0.06616903337999247, 0.04333432196290232, 0.025856814681901596, 0.05287068212055601, 0.020903533695673104, 0.09178063875879161, 0.00619046481915575, 0.04393278984935023, 0.03930768471036572, 0.01092519583835383, 0.06072166572266724, 0.06994519208092242, 0.03525783678924199, 0.05929441183980089, 0.04640990067855455, 0.016662488123984076, 0.04644570559321437, 0.12722857296466827, 0.0070667672844138, 0.07201020314823836, 0.102757366548758, 0.015953998699842487, 0.020675727755588014, 0.03868798397888895, 0.0743541652627755, 0.02339403101359494, 0.008274624688056065, 0.021748275867139455, 0.037851854431210086, 0.02661963302671211, 0.02391612077190075, 0.054930171609157696, 0.019030230505450163, 0.08698687684955075, 0.064619592303643, 0.05242514860583469, 0.021187698330322746, 0.029740072714048438, 0.03273551061283797, 0.024330478518095333, 0.039720014538033865, 0.07657868613023311, 0.0516055132902693, 0.06366579895257019, 0.044490161308203824, 0.011726860975613818, 0.09371421547257341, 0.053577948856400326, 0.03551828980562277, 0.05425783776445314, 0.03478638747765217, 0.10904635564656928, 0.03857104748021811, 0.031595378823112696, 0.02188246729929233, 0.06361393767292611, 0.015016752458905103, 0.00996068216409185, 0.016376898565795273, 0.02714186379307648, 0.015056100201036315, 0.022295186754490715, 0.02144046826288104, 0.020841829682467505, 0.05423440074082464, 0.01856075345131103, 0.06908695024321787, 0.05083767988253385, 0.0368057861487614, 0.06154295973828994, 0.06929557537660003, 0.015051943246362498, 0.07963156996993348, 0.03130504694127012, 0.08728325352421962, 0.03048034275707323, 0.019320727515150793, 0.031728609174024314, 0.025033451929630246, 0.028540429957502056, 0.02270334942295449, 0.01718903262371896, 0.07455698680132627, 0.06229827311472036, 0.06095189477491658, 0.04444373626029119, 0.043389856873545796, 0.016973123310890514, 0.07915469555882737, 0.04989337488950696, 0.004624653820428648, 0.05991145568259526, 0.03456288970483001, 0.06852648773929104, 0.052385343515197746, 0.035603833457571454, 0.043719325913116336, 0.022155117512738798, 0.05683337964001112, 0.02446839182084659, 0.10723746716394089, 0.044614111102418974, 0.01454657593058073, 0.03785844841331709, 0.05502561922185123, 0.03613424640207086, 0.04994677241484169, 0.02012784836551873, 0.05924637633142993, 0.061805464792996645, 0.05491088690178003, 0.03647107012511697, 0.059278195913066156, 0.048568184865871444, 0.04466477381356526, 0.08447081811027601, 0.05491233408974949, 0.017845490074250847, 0.026947677142743487, 0.049731208200682886, 0.054144552632351406, 0.07898849158664234, 0.03710509430675302, 0.01891395451821154, 0.05804677995911334, 0.04357426943897735, 0.01730286137899384, 0.02486538331140764, 0.06644531269557774, 0.03541588826919906, 0.060857523276354186, 0.050848199825850315, 0.07739154563751072, 0.07072656968375668, 0.046863338066032156, 0.04325141664594412, 0.030817186889180448, 0.034383846577838995, 0.0931086229684297, 0.026370215746283066, 0.03484121734800283, 0.036739508650498465, 0.024448498552374076, 0.0744666600076016, 0.05033304543758277, 0.07712248741881922, 0.07222563377581537, 0.04428151391039137, 0.03499899794405792, 0.10153337207157165, 0.024022784091357607, 0.021005324815632775, 0.026373507171228994, 0.027406957087805495, 0.04638248203264084, 0.06053884877474047, 0.049967148079304025, 0.047277953708544374, 0.09008064560475759, 0.02433974794257665, 0.04712537927844096, 0.03884148238284979, 0.10334905120544136, 0.0927418535866309, 0.05026343198551331, 0.013186041123844916, 0.03499360624118708, 0.013710655111935921, 0.019084834020759445, 0.009891403606161475, 0.01157943983344012, 0.005663421225108323, 0.03538014272635337, 0.01267728497623466, 0.024225130655395333, 0.024402333256148268, 0.003844731754725217, 0.01857711966295028, 0.006645287703577196, 0.042238195819663815, 0.051435654240776785, 0.06531682520289905, 0.015450166702066781, 0.03784903427003883, 0.033275141031481326, 0.033860220573842525, 0.011141883478558157, 0.035886413606931455, 0.07467479532351717, 0.010808828938024817, 0.10544298376771621, 0.007487163793484797, 0.02597698137833504, 0.07271258655237034, 0.07643688397365622, 0.04329160394263454, 0.11461210699053481, 0.01641657749132719, 0.037854351758142, 0.05425310286227614, 0.09176421503070742, 0.05750995114794932, 0.05729327371227555, 0.053399844546220265, 0.05673471110640094, 0.03514658514177427, 0.014997754406067543, 0.010771803190436913, 0.03026057056558784, 0.06443543577915989, 0.027707484223356005, 0.014135690507828258, 0.05940747432759963, 0.03617029251472559, 0.025653661032265518, 0.12505985418101773, 0.017801823960326146, 0.029562161362264305, 0.11134655331261456, 0.014841420070297318, 0.07909339416073635, 0.04779073322424665, 0.05005898514355067, 0.04556549247354269, 0.09690949518699199, 0.02650708262081025, 0.057033284538192675, 0.008758582898735767, 0.12248769649886526, 0.2356809432967566, 0.11523288383614272, 0.16719714389182627, 0.07717103129834868, 0.13440681825159118, 0.10450554735143669, 0.1193636332754977, 0.1137425251363311, 0.14932885504094884, 0.13805466704070568, 0.1835113755078055, 0.12055066879838705, 0.07689259233302437, 0.1053158167633228, 0.09387631536810659, 0.14839477313216776, 0.15348831075243652, 0.1623762267990969, 0.09536506360745989, 0.23289031960302964, 0.1763549938914366, 0.16811050503747538, 0.15032382274512202, 0.16058175824582577, 0.1382978688343428, 0.1217907085083425, 0.07171322533395141, 0.14408154442207888, 0.09895017865346745, 0.13612950628157705, 0.15855824807658792, 0.1469966708100401, 0.12509795604273677, 0.09260583276045509, 0.11286704320809804, 0.12063102112733759, 0.17546557442983612, 0.09453560967813246, 0.17806907300837338, 0.2232756480225362, 0.25528122670948505, 0.0985155621310696, 0.11984516837401316, 0.12207272462546825, 0.07420205467496999, 0.1396661516628228, 0.08511509877280332, 0.1281377929262817, 0.13198783242842183, 0.10321210269466974, 0.07334053996601142, 0.21687251661205664, 0.2150558281573467, 0.1341415153001435, 0.08814800399704836, 0.135297974338755, 0.11631094981567003, 0.10027382872067392, 0.12098583451006562, 0.19531029160134494, 0.0843426120991353, 0.14194022573065013, 0.25670430972240865, 0.18396893923636526, 0.0995754825999029, 0.2523802308132872, 0.21313304227078333, 0.1272488187532872, 0.19204837444704026, 0.14486161584500223, 0.15030657523311675, 0.13969790074042976, 0.146276431332808, 0.18203657964477316, 0.1537890438339673, 0.11885712490766309, 0.12263172509847209, 0.19248806725954637, 0.16466820146888494, 0.17800735600758344, 0.2416270156390965, 0.1253226783592254, 0.17526777723105624, 0.15637360280379653, 0.16777383716544136, 0.1744963592500426, 0.05970786231046077, 0.27137137425597757, 0.19038197089685127, 0.10742424346972257, 0.1474262258852832, 0.22933210741030052, 0.14734450058313087, 0.17397069605067372, 0.15472288825549185, 0.11938002731767483, 0.15719336428446695, 0.07593644637381658, 0.16367388685466722, 0.16416388243669644, 0.11332229143590666, 0.14355199236888438, 0.10879157634917647, 0.12894245912320912, 0.1745612229569815, 0.2815667021786794, 0.10082414606586099, 0.13100405631121248, 0.2012073970399797, 0.1985249636345543, 0.15316420001909137, 0.13259283121442422, 0.1321804049075581, 0.1027290387719404, 0.14085764007177204, 0.1592321033240296, 0.1571137466817163, 0.07759528001770377, 0.19125684426398948, 0.08825206794426776, 0.14203041151631624, 0.12651620025280863, 0.11571904251468368, 0.12895284919068217, 0.2516195591306314, 0.08365321627934463, 0.18208256311481819, 0.08604227870819159, 0.11193141763214953, 0.14674674515845254, 0.13457086257403716, 0.18278125062352046, 0.13402468641288579, 0.11168055687448941, 0.19282394845504314, 0.18163816508604214, 0.1487034620367922, 0.160122161032632, 0.12916145205963403, 0.1559735109913163, 0.16364034177968279, 0.15893989009782672, 0.12702112784609199, 0.22898908675415441, 0.10954255558317527, 0.17043783562257886, 0.15817288047401235, 0.17112739471485838, 0.13741656846832484, 0.11985903169261292, 0.13534714904380962, 0.15698979317676276, 0.11593344155699015, 0.1190722883620765, 0.11903677659574896, 0.16955236438661814, 0.17867536313133314, 0.1183213759213686, 0.16851458960445598, 0.1875945829669945, 0.14109803654719144, 0.17939361365279183, 0.16032838902901858, 0.07403846306260675, 0.1423181124846451, 0.16486852196976542, 0.15166062366915867, 0.17804250412154943, 0.10365681984694675, 0.09618755619158037, 0.11265208013355732, 0.19524741685017943, 0.085181431932142, 0.11734701023669913, 0.2074707523570396], [0.05928970291279256, 0.04170371961663477, 0.04076566350704525, 0.03583892357710283, 0.026866413827519864, 0.08187971339793876, 0.07577411641250364, 0.08946445523179136, 0.0260571518811048, 0.0342002615070669, 0.050734473115880974, 0.07877997777541168, 0.05587349696725141, 0.05097715911688283, 0.04430271335877478, 0.019417321746004745, 0.013918828462919919, 0.060136775427963585, 0.024200986736104824, 0.034664864506339654, 0.03968134493334219, 0.02300439606187865, 0.012154803735029418, 0.04217500565573573, 0.07232792399008758, 0.05199987943342421, 0.04089566180482507, 0.029580186273960862, 0.033860517432913184, 0.01375507636112161, 0.04809976351680234, 0.054576853653998114, 0.023025484188110568, 0.03352014995471109, 0.1118296394997742, 0.022007808620401192, 0.032127554368344136, 0.05756492573709693, 0.05304466751113068, 0.049707188591128215, 0.029749755885859486, 0.0398681583465077, 0.031408943905262277, 0.015867712900217157, 0.03862212208332494, 0.020553160211420618, 0.05588940861343872, 0.02151220054656733, 0.09306502921390347, 0.03522669998346828, 0.012050685054418864, 0.017874817895062733, 0.021181019001232926, 0.028444180825317744, 0.06964523083297536, 0.015755205167806707, 0.05834333103848621, 0.017839695756265428, 0.07819043792551383, 0.02174903842387721, 0.03477808284515049, 0.03162483837513719, 0.020257883770682383, 0.014300040038506268, 0.0366112692427123, 0.012814899564546067, 0.029237043163448106, 0.025141252590401564, 0.09868610766716301, 0.06250038219150156, 0.04874994796409737, 0.004377571522127255, 0.0365114095620811, 0.048940345950541086, 0.03304019192000851, 0.020908029255224392, 0.018851758832170162, 0.1239712125970982, 0.08574089995818213, 0.023437999552697875, 0.01724534493405372, 0.020505989305092953, 0.10192391986493021, 0.061400578706525266, 0.08200273179681972, 0.04857260806602426, 0.025835262713371776, 0.03781128121772781, 0.03142386849503964, 0.013461334310704842, 0.027735832409234717, 0.04258756925992202, 0.02540894340199884, 0.06819304078817368, 0.04600869564455934, 0.13548244256526232, 0.026310170433134772, 0.06141623431176413, 0.04339155639172532, 0.018341090726607945, 0.12423882362782024, 0.056333331667701714, 0.04722265999589581, 0.04702942700532731, 0.03822803424554877, 0.06306651470367797, 0.02767438443697756, 0.009410456659679767, 0.030339273471327033, 0.04194372275378555, 0.027647739480016753, 0.05649203994835261, 0.021295639999152627, 0.031122254113142844, 0.055436917464248836, 0.0880412312108092, 0.0027361020465832553, 0.032498954751645215, 0.026001164260378573, 0.023472047432733234, 0.027872070313605946, 0.09103446122026071, 0.012751580452459166, 0.007322989595195395, 0.027460926066851243, 0.006092946150602074, 0.03291960776550695, 0.0329067834536545, 0.08594386250479147, 0.0406081166875083, 0.030111927662801463, 0.01776976318069501, 0.0270788721536519, 0.04183104989351705, 0.0363928700244287, 0.01278842901228927, 0.04024040106742177, 0.10650527910911478, 0.050414462748449296, 0.10989602567860857, 0.054566675098612905, 0.030352958674484398, 0.031681594118708745, 0.0703859758505132, 0.02214452706539305, 0.00990262116829399, 0.03560791526979301, 0.02023296430706978, 0.06451492721680552, 0.010786918883241015, 0.05088242767669726, 0.0300854051602073, 0.02994071790453745, 0.05692522412573453, 0.0379901536507532, 0.06746884566382505, 0.01467620037146844, 0.028712485764117446, 0.07181170833064243, 0.021432224857562687, 0.039522814768133685, 0.048455185460625216, 0.08362020555068739, 0.08520848321495578, 0.03150071788695641, 0.07196171121904626, 0.028620817538467236, 0.02280845608765958, 0.031802697776583955, 0.027476709692564327, 0.007866248652135255, 0.040770331615931354, 0.012174583825981244, 0.03746816779312212, 0.07723429196630605, 0.014867177233099937, 0.031540341151412576, 0.0596297512674937, 0.034139676281483844, 0.009713126746646594, 0.06453695415984839, 0.005171630109543912, 0.012375361675367458, 0.07544762338511646, 0.010606507421471179, 0.08616137114586309, 0.03340110575663857, 0.046280381066026166, 0.04998809890821576, 0.04594106743752491, 0.03892488493875135, 0.03872034161759075, 0.03274716975283809, 0.047191749545163475, 0.010834410768438829, 0.018460288920323364, 0.053294945682864636, 0.046351378623512574, 0.02518292974855285, 0.04418244832777418, 0.06222331619937904, 0.05428826952993404, 0.008791634445515228, 0.049407624392188154, 0.008060318414209178, 0.008915240068745334, 0.018545311213529203, 0.018708268289628904, 0.02330832779989578, 0.01151807442511199, 0.07368376842350699, 0.046231744418037124, 0.04338555983849801, 0.03317100658023264, 0.0021640592558469507, 0.06880999557324685, 0.013098919480398763, 0.01370267238598899, 0.058176362654194236, 0.012836079531552969, 0.013286759840411833, 0.01933051458763657, 0.06545875352458097, 0.06133650167612359, 0.02431012697343249, 0.014578376030840445, 0.008220875570259523, 0.03800292230152991, 0.018279791183886118, 0.05991840589558706, 0.046747603846597485, 0.028582201739482116, 0.030364549165824428, 0.02205844721174799, 0.050377670777379535, 0.02569939402746968, 0.04174713896645699, 0.05920161369431298, 0.03929407372197602, 0.05089344485895708, 0.02692815865884768, 0.02835195598891005, 0.04988228720321786, 0.03452876946539618, 0.04122479316720273, 0.027732088274206035, 0.08618130523245782, 0.02105762581777526, 0.03089871366682928, 0.012561654657474719, 0.02510081852960866, 0.03693375096190721, 0.07211904652649537, 0.07711793805356137, 0.023774377987137996, 0.06205282261362299, 0.023865715957072098, 0.022656063483736943, 0.016194207782973535, 0.08017844374990091, 0.017739017857820727, 0.02626466564834118, 0.10975550001603551, 0.024677597684785724, 0.02623675904033007, 0.035992425691802055, 0.05942211690125987, 0.04494137225265149, 0.022190566196513828, 0.11515972291817889, 0.10129731716006063, 0.056625619108672254, 0.04337467624281999, 0.09485363480052911, 0.04392811802972574, 0.02546771036577411, 0.049722324692993425, 0.07372268664767034, 0.025999626159318723, 0.06776448761229403, 0.06900023770867847, 0.0531898056215141, 0.03644390009867493, 0.0808828383742366, 0.02413084450381575, 0.03849945991532877, 0.013342051697691204, 0.13450696365907788, 0.06343736589769833, 0.016592954452789854, 0.05766299684182741, 0.027797686707344837, 0.03621186762757134, 0.031744149746373296, 0.028708969839499332, 0.008934866164054256, 0.08236832858528942, 0.04627882626664359, 0.04331693715357687, 0.06088155772886239, 0.01706703467789339, 0.029186250576458406, 0.01032841077176272, 0.03626117220846936, 0.03625203265983146, 0.05154194092028774, 0.026075622081407346, 0.014015425476827659, 0.05860704208316747, 0.023570478479086887, 0.01807680822821567, 0.03045403733267449, 0.021214927728578914, 0.03085468018980464, 0.12703709886409342, 0.03638789763499517, 0.03262024394643959, 0.03110567638941575, 0.02516905344236875, 0.04414152630488388, 0.06679870857624337, 0.01712434517685324, 0.039553179740323685, 0.03280479751992971, 0.05520565311599057, 0.014115543053776491, 0.04871515237027779, 0.023078685044310987, 0.04133653092139866, 0.08352612348971888, 0.0308676362328697, 0.05968294841295574, 0.09502138986135833, 0.020805803978873882, 0.013874935066269245, 0.040641094019520096, 0.04794124819454737, 0.029996748198755085, 0.0165283412206918, 0.08432297487161122, 0.060424702751333825, 0.03184096662153024, 0.020245812738721725, 0.010359263706050115, 0.042309954078518786, 0.018388439748378005, 0.12767702311975881, 0.022229857349884696, 0.08654647899675183, 0.021137527292012237, 0.052474980111583136, 0.08848246026900597, 0.13022186234593391, 0.14893740182742476, 0.2695575950201601, 0.18333217652980238, 0.1958485713112168, 0.15782144386321306, 0.14777254167711362, 0.29760368226561695, 0.06746478611603379, 0.16291854379232973, 0.1125348950154148, 0.19639023521449417, 0.15026574226794764, 0.11689522783854045, 0.08168572341674007, 0.09639451891416684, 0.08155522416927852, 0.1303612079937011, 0.06203604265465401, 0.08473785026581027, 0.08630371507024392, 0.11429717662394978, 0.07441306210239418, 0.10982049730955623, 0.15338299999712035, 0.14327529002912343, 0.14830774889560416, 0.11806290815002285, 0.08725217237952165, 0.14884303032886237, 0.22087482997449115, 0.16734992241254076, 0.06865462695714086, 0.10151857364689931, 0.24294187867781147, 0.12799044692656025, 0.1462829325464554, 0.1307283336063847, 0.1985805801814422, 0.2030450289021246, 0.1341890572803095, 0.13051970105152577, 0.1299542884225957, 0.10393066491815262, 0.08417231889325194, 0.11237054641242139, 0.1500307783135213, 0.1386907321284525, 0.1925580220995471, 0.1657478482229635, 0.08154983617714606, 0.17093497066525742, 0.12958046863786876, 0.104968654923141, 0.10891233861912042, 0.11813022836577147, 0.2244586611050181, 0.07233350494061597, 0.14942337496904656, 0.10194622882409021, 0.09311804824392311, 0.11049426349927671, 0.18979139946168289, 0.14293066633399576, 0.1054731520707719, 0.11216371727641672, 0.09811847601667978, 0.2026826233486645, 0.17487068369518965, 0.09896635005134158, 0.23692874587140977, 0.1425929891411215, 0.09923900768626481, 0.08717351956875063, 0.10448813656694256, 0.1356791116995737, 0.1631186861777678, 0.18114085192792118, 0.09848123780102469, 0.15054225164931267, 0.18983626971021295, 0.17743180564139038, 0.21491559193236753, 0.24366660072701052, 0.1670307692256756, 0.16410166077548638, 0.17626982502406463, 0.12456046300940216, 0.06197415495989844, 0.11642785291769542, 0.13508580916095525, 0.11005368010955863, 0.14558433409547433, 0.2326043404173106, 0.3128369164187461, 0.23309332667849958, 0.17300422681728378, 0.2042443840764463, 0.11879357480211183, 0.07708175093284808, 0.16905968222999945, 0.20141270477324724, 0.15425986232003197, 0.10097526959725656, 0.21204490534728393, 0.19832304009469226, 0.1818291493691504, 0.19656935997772962, 0.24907325045205653, 0.1120504506980069, 0.04221025395963807, 0.26243570842780173, 0.14230984495952725, 0.1085632546164561, 0.10449868990690447, 0.2444469096371904, 0.10392323601990938, 0.2174852485768497, 0.08938290804508142, 0.0923944023088552, 0.1409845770103857, 0.14484931103652343, 0.1985033819801174, 0.09518190898234025, 0.0875786950928159, 0.08830972539726645, 0.18208097491879016, 0.19964017410529777, 0.16677115112543106, 0.1638949429616332, 0.14808651467319578, 0.10882080212468281, 0.16772273287642747, 0.10736128708231263, 0.07998204921022989, 0.07895990405813791, 0.11962119562667795, 0.29376529448200017, 0.3304290521191433, 0.2473561730585061, 0.16700283478712663, 0.2220343318185769, 0.1933809302863665, 0.17018652957631275, 0.09903295038384385, 0.10068538671475835, 0.09288485802244395, 0.11204443930182606, 0.16199131932808086, 0.10776642549899407, 0.18615824519656599, 0.13260170730063692, 0.14142329018795863, 0.19705637212609872, 0.1637646069866605, 0.18329172948142514, 0.16975241771433502, 0.1033622540126089, 0.0935982697410509, 0.09728181583341211, 0.10651794756995514, 0.1153536832134705, 0.12091031356249005, 0.14630684454459697, 0.18659382651094347, 0.18676566338399425, 0.09083701283088885, 0.09378897200804204, 0.13640744058648124, 0.13345879880944267, 0.15124666853807867, 0.09634904010454193, 0.2356329411850311, 0.10735011033830233, 0.16189797199331224, 0.10952129305223934], [0.039079771158867516, 0.0507947985897772, 0.05549119072384201, 0.06826097698649392, 0.03642477866378613, 0.05690934216545429, 0.02062560866761487, 0.03403881470148917, 0.0647636728535872, 0.009323246886197012, 0.0254051454612636, 0.029472033093043137, 0.003417333778088505, 0.031014805972517934, 0.015783720336912666, 0.043903463883907534, 0.062407242658082396, 0.050805819482775405, 0.02621096198708983, 0.023708107910351828, 0.0683420046698302, 0.06632951539359055, 0.04365091474028304, 0.06560376918059774, 0.04199457471258938, 0.09487004368565977, 0.06135837276815437, 0.0949939971906133, 0.014072603316890309, 0.025006474861584138, 0.018839621006918605, 0.0654043689428363, 0.01947358210600214, 0.030204089416656643, 0.05194245204620529, 0.017292497286689468, 0.06588169606402516, 0.05032651453802828, 0.02167203503631754, 0.04102309227164369, 0.06076191239117179, 0.014119402221695054, 0.05654935972415842, 0.023204742537927814, 0.05404632196587045, 0.024319132935488597, 0.012684812209045049, 0.061538299050880596, 0.06108112123911269, 0.028621862111322116, 0.047061569421202876, 0.04922059575619642, 0.06446443148888648, 0.0654475470946636, 0.04509669633989688, 0.035300955569255166, 0.09997294720960781, 0.02259500884974841, 0.06766244230675511, 0.03248693195928354, 0.04653284857340623, 0.004247204005878302, 0.030550830088031944, 0.1073734657256864, 0.03989513912529219, 0.13942919875262305, 0.015035097421787214, 0.009555781234666938, 0.07393788720946759, 0.03279809592640959, 0.0266533636386157, 0.09426117831026204, 0.04779144197527785, 0.06984115039813332, 0.05984885181533173, 0.02944224328530254, 0.07816018056473695, 0.1035261202196125, 0.06033164856489748, 0.07988091674633324, 0.23058215127093717, 0.29860154434572905, 0.12816160102374852, 0.006756937327736523, 0.3744367469334975, 0.5789120576810092, 0.15157670160988346, 0.1641128968913108, 0.0076059009279561, 0.21550528763327748, 0.1211808634980116, 0.031368971831398085, 0.044541046663653105, 0.05948986756266095, 0.06812864463427104, 0.03122034562693443, 0.004050663355883444, 0.10147528417292051, 0.06581585272215307, 0.09917549468809739, 0.044279179855948314, 0.03609316852816846, 0.052246417180867866, 0.03199673228664324, 0.06192551460117102, 0.04938261030474678, 0.0256038462248398, 0.051559889761847444, 0.029016879489063285, 0.023115484436857514, 0.024167950032278895, 0.06864843744551763, 0.06219500326551497, 0.041610197877162136, 0.06594857841264457, 0.045025242361589335, 0.019807665448752232, 0.028141865113866515, 0.029851897670596372, 0.1159796625142917, 0.037086948796059005, 0.028535032688523643, 0.024875072049326263, 0.018701338485698216, 0.08105551387416199, 0.0436221973359352, 0.10818926413776353, 0.07104991600499488, 0.03180863866873551, 0.024177063605748117, 0.051813021491398104, 0.027713785057130735, 0.03899003808328416, 0.013840747105859919, 0.032307458386640064, 0.009424884938198375, 0.03892256201652344, 0.03013516430655727, 0.0072005129641183885, 0.028842996143794153, 0.049458487483207136, 0.0494194542261539, 0.016158688595169224, 0.04606586699082982, 0.05132481819600798, 0.03746180758753326, 0.03026866183063248, 0.030782792055106256, 0.059974601317662746, 0.016032009552873205, 0.04739303112728521, 0.08025749732041731, 0.039956551845534705, 0.0544508592429338, 0.02372815888520563, 0.09741601097630337, 0.01700815453659743, 0.025274575709772762, 0.04465030935534742, 0.03695764440635685, 0.04125256062252447, 0.07962938063428737, 0.06553745086421259, 0.03772712167119607, 0.02920766895840643, 0.060985751551925205, 0.013497718100552447, 0.03485542205453385, 0.039719417109154165, 0.058396513340994716, 0.01468677504817606, 0.013415605026239064, 0.08836350883939303, 0.03692619960929733, 0.021540624802582897, 0.03879305724694859, 0.04840972520469222, 0.05608202191069722, 0.03241361890104599, 0.018400751978333574, 0.013562476051447447, 0.09247112553566694, 0.020831742040172685, 0.021756480309704784, 0.017113517242250964, 0.013921936206315877, 0.03224763386242557, 0.018634535917954054, 0.0173628250558977, 0.07131387566914782, 0.03592443754314445, 0.045204185298644006, 0.012841894258599496, 0.012957774124515709, 0.0025315610446341452, 0.03523987681546714, 0.056970502555486746, 0.12863691692473367, 0.01908297123009106, 0.08974865326308645, 0.016075735038612038, 0.03722969348018523, 0.031033992345328443, 0.011232566503167618, 0.03705134797201026, 0.0662808601919096, 0.041308796862722374, 0.03677771441289224, 0.046403020969592035, 0.04066049375978764, 0.021242594993964303, 0.036352682727738284, 0.05185678593988996, 0.03635793713328894, 0.04789216625795234, 0.028351805704005528, 0.05419843255367596, 0.028350180400593672, 0.043538063764572144, 0.0325279949902324, 0.018197279205196537, 0.03143155343423132, 0.13141784816980362, 0.07290831315913238, 0.02588286777609028, 0.03942296993045602, 0.06329144482151605, 0.02302354903804371, 0.046003619354451075, 0.00791092965300777, 0.02445484762574779, 0.018091378442477435, 0.04123100865399465, 0.01355393022095086, 0.054622354728053324, 0.022471834599855356, 0.0849324710725341, 0.02732783672399819, 0.10956641563097946, 0.12269508224562742, 0.011145571024826495, 0.09329578519100323, 0.03663531853817403, 0.06432543465052731, 0.03174292891344521, 0.08392752148211002, 0.0453477129485691, 0.07007212159805931, 0.07633023735252209, 0.11827039779745974, 0.0376280969067011, 0.025373312892043032, 0.0313015328720212, 0.04744236168335192, 0.016403651134169195, 0.05645990866469219, 0.1173940698208753, 0.2487330202711746, 0.06644742039497942, 0.09463621521717869, 0.18201847124146298, 0.1786927887587808, 0.03790130744164344, 0.00798599232439301, 0.029297737855813466, 0.2634526288602501, 0.10126273307832889, 0.12064649490639567, 0.0945587053138297, 0.08273771032691002, 0.045663971759495325, 0.025118518751696683, 0.05141377943800762, 0.0699992204317823, 0.04375274482299574, 0.10580901100183837, 0.07291818372323178, 0.010650537187757436, 0.10588341872789897, 0.07500780440750532, 0.07146079864469357, 0.11443087452789769, 0.061983212872291915, 0.04609193121723365, 0.029276710956764873, 0.04779818809765857, 0.03557972850103397, 0.02601259147922974, 0.039816512289689854, 0.026329501524742227, 0.06745260005118325, 0.04894623489235528, 0.0395327706792159, 0.002362774862376682, 0.002841226337295666, 0.07469933814718388, 0.020011503729620017, 0.023650287184864283, 0.007444494012815994, 0.06342048945953138, 0.05534735508263111, 0.03122611582512036, 0.034962384088430554, 0.0872914690990001, 0.04240440350258723, 0.059245166630716994, 0.004226345017741551, 0.011656204806058668, 0.02725147714954801, 0.01637494300666731, 0.05590452616161201, 0.07061696189339273, 0.05028634208429139, 0.10012893922976218, 0.04476827372855041, 0.02209725967986742, 0.021056037621747237, 0.07534265401773155, 0.019703941034094896, 0.029076366336084902, 0.029865786964364816, 0.03599946867325343, 0.020229761939845048, 0.02455534184264252, 0.08283054557978176, 0.06466219900175929, 0.032830765267135575, 0.07886616338510066, 0.0228209557099035, 0.045830658127670176, 0.027014542793040164, 0.017200641668750905, 0.049309898386127315, 0.02865350543288514, 0.053451015628525056, 0.08626572453067638, 0.016684615256963298, 0.06686338674626313, 0.05815416130644735, 0.007551668022642843, 0.02357423374633072, 0.017742708187142853, 0.023308580130105838, 0.01588819988683099, 0.058815207084990107, 0.043634817557176575, 0.04702654005086515, 0.006392764071279089, 0.04026840229926165, 0.037262540936353616, 0.10044017370091751, 0.08877967557054944, 0.11335230388795026, 0.14256596012273803, 0.15564156317850575, 0.09183649279293604, 0.09420598478754982, 0.244638042349834, 0.09077010821783915, 0.09547417415888049, 0.1436583569739014, 0.12704134394880384, 0.07348197104874998, 0.09616959621780552, 0.08569827099563554, 0.134093067899812, 0.15338423196226358, 0.11157434069900773, 0.1384986939956434, 0.15552399214357138, 0.04649610484193545, 0.18971209356095642, 0.13689575891476125, 0.19271566910902038, 0.14724238106282428, 0.21918783924775198, 0.17436401947634295, 0.17609922011615708, 0.10292817183653824, 0.19169696752214804, 0.18618386413436383, 0.2032183055416681, 0.18707135401200503, 0.11562392886844464, 0.1378863479476422, 0.1628861713106744, 0.209275477391202, 0.1314876991091296, 0.21485308825504035, 0.09467296637012623, 0.13389571598963812, 0.1151618454605341, 0.17171839659567922, 0.2389807693543844, 0.12405997345922515, 0.1431976316962391, 0.08707689194125123, 0.12246415557456203, 0.22435798135120422, 0.17918103287229314, 0.12041403198963962, 0.1720667607150972, 0.2056682834518142, 0.10591380225378089, 0.13511130935512483, 0.19521160080330446, 0.07176358747528866, 0.16171197494259104, 0.2182572751189582, 0.15353928145486861, 0.1360538072185591, 0.08087192138191313, 0.13518211024347693, 0.11461411821073852, 0.24362570839002728, 0.3262225887738168, 0.20864291524048895, 0.19738358503673226, 0.09268925015931018, 0.2059965205262415, 0.1437075762078166, 0.17263572080992162, 0.11479966997285374, 0.22311573004117236, 0.18826226354576647, 0.1858345649088733, 0.1359632652020082, 0.10853428117115982, 0.2068695830530487, 0.12328356082434766, 0.09216216945787892, 0.27728177898097783, 0.32932147092651576, 0.4035951948026195, 0.2200214343611151, 0.1434413975221105, 0.7304257806390524, 0.916232307208702, 0.17835555685451254, 0.2985239453846589, 0.20377834502141923, 0.5323635460808873, 0.22805984364822507, 0.2197466912912205, 0.19390605913940817, 0.11645813996437937, 0.10938781037111767, 0.17326077242614701, 0.2362026137416251, 0.15109470637980849, 0.1606817403808236, 0.249352891696617, 0.18752789357677102, 0.15157845307840034, 0.32987716142088175, 0.17192879546200857, 0.26956771791446954, 0.1858376374002546, 0.15229940501740202, 0.19754780747462064, 0.09403405143530108, 0.11304823114187457, 0.20059359638253227, 0.1188297693443019, 0.12467981519876048, 0.16847779392264783, 0.11335489398334175, 0.1275501010240987, 0.13302482053404674, 0.06911665099323727, 0.07661983821890317, 0.19917355617508292, 0.15199340268736705, 0.18230789399240166, 0.09663384669693187, 0.10728086053859442, 0.17021560692228377, 0.17967499152291566, 0.17584311979589984, 0.1523414847906679, 0.15605063497787341, 0.1382890372769907, 0.14076224440941587, 0.15877314435783774, 0.14408500283025205, 0.12815754889743403, 0.1490069559076801, 0.08283415241749026, 0.11386267142370343, 0.15908673143712804, 0.1406017623958178, 0.08547424629796296, 0.1972096849931404, 0.20982674468541518, 0.11768208249122836, 0.09643328870879486, 0.11157037020893767, 0.1437549846014008, 0.18065262265736237, 0.21121555531863123, 0.17136615846538916, 0.15616839897120371, 0.13204499264247715, 0.09956185676855966, 0.20620438124751672, 0.11169724035426043, 0.13556922931456938, 0.2040083217434585, 0.10116014600498602, 0.1986963106901385, 0.20679879700765014, 0.12555691500892863, 0.11003993553458713, 0.2009441572590731, 0.1254988939035684, 0.12294241780182347, 0.10431406582938507, 0.2607838955009356, 0.11359606229234487, 0.13996136316563934, 0.1617359314695932, 0.14383080240804702, 0.08878259221091866, 0.13567421352490783, 0.1427696054452099, 0.07444044735166244, 0.15544597757980227, 0.12525720609119162], [0.02870152053219499, 0.014537763854605146, 0.0303318445730838, 0.03176672587869689, 0.02869606945751002, 0.02505812833987875, 0.03774317432544194, 0.027527376114448998, 0.03882649842125829, 0.030197823834896553, 0.003543602551872027, 0.05891498512937687, 0.09262833467801102, 0.00972059924606583, 0.015972784312907606, 0.010400116152595729, 0.06006329167576041, 0.12735081952996552, 0.03744739507965278, 0.021107023167132866, 0.021713252062909305, 0.022526901957462542, 0.040700317404116504, 0.06118692552263383, 0.04712016569101252, 0.030547664828191046, 0.005497358260981855, 0.049300350656267256, 0.016624421514279675, 0.021950731897959486, 0.019974203387391753, 0.0412893822795013, 0.08959771526861005, 0.03907611608156003, 0.04293131351005286, 0.03427443916734774, 0.07724411800154485, 0.04505819742917083, 0.009302792368544033, 0.047781063040019944, 0.04902232358290348, 0.03846606326987967, 0.0274607145547634, 0.017143197583209258, 0.01972080262930831, 0.08368966315174475, 0.06818032037699595, 0.048627170763211325, 0.03094440955464961, 0.037631161976605654, 0.05408035314758308, 0.06593139027245343, 0.05011522509448696, 0.023304904643737245, 0.012810688804165693, 0.0955927990435157, 0.07842659673769958, 0.04673247145547066, 0.04271213503670879, 0.02369683097640518, 0.01713613233732758, 0.032556252263020724, 0.10588475459371693, 0.06884801579872146, 0.06070910116250161, 0.020151940334471874, 0.07866812869906425, 0.2216051032883115, 0.08919832849642262, 0.08319705520989373, 0.5158315238077193, 0.8151914540212601, 1.1266471445560455, 2.4360635317862034, 3.485674560070038, 3.4713037312030792, 3.4190914453938603, 2.919681631028652, 4.914916092529893, 5.3609176352620125, 8.565534576773643, 14.395203609019518, 24.20961432158947, 44.17242832481861, 49.48051169514656, 44.35119353234768, 25.089947283267975, 11.654189340770245, 5.807463023811579, 3.3319286350160837, 1.5998216229490936, 0.46575145795941353, 0.1407260721316561, 0.14734611846506596, 0.07400348564260639, 0.054017422735341825, 0.1384085972676985, 0.20431840588571504, 0.16228286462137476, 0.038300464148051105, 0.06194477704411838, 0.07283818020368926, 0.10785188380395994, 0.1036348300112877, 0.018842031131498516, 0.14341698086354882, 0.03733173507498577, 0.03590727166738361, 0.09505856403848156, 0.05051680862379726, 0.011164865936734714, 0.08858152956236154, 0.023811372193449643, 0.03376862841832917, 0.02837608877598541, 0.03390065277926624, 0.07760351785691455, 0.04834991181269288, 0.033047164397430606, 0.04103700011910405, 0.06573284350452013, 0.048382391905761324, 0.06046191032510251, 0.043481144748511724, 0.06601848130230792, 0.08549455887987278, 0.015565562316623982, 0.04956870383466594, 0.04075728837051429, 0.022979073983151466, 0.046032307072891854, 0.031821206939639524, 0.01422338546035462, 0.06783836841350421, 0.028225076566741336, 0.027507343693287112, 0.03299803793197498, 0.059820846872753464, 0.01599477414856665, 0.017097369964176323, 0.10574519372312352, 0.024468755473208148, 0.048220343960565515, 0.03315590387501288, 0.0362552758451784, 0.09036914067110047, 0.020782728752237745, 0.043366868849261664, 0.044299640867393464, 0.020476511199376546, 0.09747109317686409, 0.11662774297292344, 0.06331437718472444, 0.030929464555811137, 0.06174392219691072, 0.07475392310880125, 0.07086495796102099, 0.022530128444486763, 0.018712734163273126, 0.015843324072193354, 0.0279103911088896, 0.050000715418718755, 0.03898316579579841, 0.0036799016834265785, 0.01597376394784078, 0.07783648543409072, 0.04052619100548327, 0.07449261291185394, 0.08327730363816954, 0.0608940814709058, 0.010299717487214366, 0.03511491770041175, 0.07342872195295058, 0.03694527280458715, 0.012080468368367292, 0.021103603721712716, 0.015428775222972035, 0.05882491808733903, 0.032822297362145036, 0.08486084640026093, 0.02920053135312628, 0.044142160841147415, 0.05534267213079147, 0.040628251153975725, 0.05324614576238673, 0.014618371296819532, 0.04928450580337085, 0.032556701262365095, 0.07618520685355179, 0.03169073737808503, 0.019331898693053517, 0.02751381522102747, 0.021242667353362776, 0.07511436939239502, 0.06459398078732193, 0.024046573635132518, 0.01687679068709258, 0.06043502602551598, 0.027546299024834298, 0.010816839494509622, 0.04795598353666719, 0.01660802747210255, 0.03274131420766935, 0.0052634221810876625, 0.04783867967489641, 0.030027178108866792, 0.018418494873913005, 0.04373933421447873, 0.054659321103827097, 0.050516066476120614, 0.032454381362185813, 0.020226279411872383, 0.03269729742896743, 0.07702815302764066, 0.029019990943197627, 0.05259309291432146, 0.06232541345525533, 0.023606016220583115, 0.022167704337334726, 0.02581665336037986, 0.005938122549196123, 0.01518746312285657, 0.011350541080901166, 0.02451410997309722, 0.04526737175183371, 0.02788447902275948, 0.05089137797767762, 0.06750064669176936, 0.02014032386796316, 0.03372717575985007, 0.01236573602000135, 0.015850769668759312, 0.005825355992783443, 0.01546219134979765, 0.0348305563966278, 0.04240977665176615, 0.024269153000204824, 0.08604552189353853, 0.03131262797978707, 0.054257507508737035, 0.06119646583101712, 0.022976068285061046, 0.05915010493481532, 0.19654708070447668, 0.04076865436218213, 0.08371827294467948, 0.2221755328355357, 0.37346518656704575, 0.8337467489764094, 1.5343297622166574, 2.2155969869345427, 2.202526875771582, 2.310039969161153, 1.878818564582616, 3.2916930690407753, 4.435808351263404, 8.445347025990486, 15.216297749429941, 24.786068089306355, 46.32399067282677, 51.870283260941505, 47.749947756528854, 25.991673097014427, 11.865025777369738, 5.8481859136372805, 3.80254240706563, 1.6294834250584245, 0.4727220948552713, 0.11051752982893959, 0.037990250129951164, 0.035671324367285706, 0.11794004560215399, 0.08644221466965973, 0.07263269435497932, 0.0573534841532819, 0.039776992925908417, 0.028794763966288883, 0.12483692786190659, 0.044811195839429274, 0.07482542903744616, 0.06936159683391452, 0.044382646374288015, 0.08913868208765052, 0.03102648366620997, 0.06516493725939654, 0.055311590986093506, 0.0655021023703739, 0.08174789312761277, 0.008831882041704375, 0.03396892665477935, 0.03168541246850509, 0.042338701168773696, 0.04146493360167369, 0.013087103561701952, 0.007504846853407798, 0.03515054449962918, 0.04631920652172994, 0.10404368658782914, 0.029735510361206252, 0.07119389265426435, 0.03601030031859409, 0.04612473785527982, 0.028672535954683553, 0.019255051156505942, 0.11574351854505949, 0.01718865598377306, 0.014127969388937345, 0.02038837188592879, 0.046431411828962155, 0.031859319933573715, 0.026399228154332377, 0.03018401617737254, 0.02664841536898166, 0.048144648608285934, 0.04079423248185776, 0.02949596364487661, 0.04130628098209854, 0.05275594237900805, 0.04984574385161977, 0.006076674562791595, 0.03416935847781133, 0.11569152367883362, 0.03089334051765036, 0.00635761827652459, 0.02128754131263122, 0.03933247986424249, 0.025599718028388452, 0.0832155198440887, 0.029297630244400352, 0.08034530823351815, 0.028775805803888943, 0.05598913470748812, 0.01052102685207501, 0.026045049307867885, 0.04617696649802383, 0.015611744311172515, 0.10525848585530184, 0.0364958727004705, 0.0919448389322497, 0.048788636122480966, 0.029018495515629184, 0.012861078776040813, 0.06400378784746863, 0.030039737102924846, 0.029960763313283678, 0.035677016639965586, 0.005591269164142432, 0.036220769688952714, 0.11182383590494283, 0.11613638183916919, 0.027709044588846155, 0.02270025095640449, 0.08987805413198657, 0.2218948377412744, 0.11011808368493803, 0.18877522117691115, 0.10966912886942737, 0.09507008959189989, 0.2091552346246317, 0.1579577021766454, 0.12106948197470047, 0.0695616501616314, 0.160994466568809, 0.09945930680260062, 0.25354424491524696, 0.12520233169198036, 0.15006898407591507, 0.08530246879672632, 0.23335346428211778, 0.17284801957430318, 0.15396819828310981, 0.1261986797908321, 0.0810773107514251, 0.18824890488758683, 0.1811798888957128, 0.07526198256528005, 0.1667945139342919, 0.14332112506963313, 0.11311518028378487, 0.08330501543241553, 0.21066888934001327, 0.11961855358094908, 0.16239581949776039, 0.1266303870943375, 0.22992714657448232, 0.13517271465389058, 0.1401286877808161, 0.11537194004631601, 0.18329713231651112, 0.2001933561405167, 0.13468452991219237, 0.1738452137215063, 0.14940002700313926, 0.13623419363284484, 0.1510309855802916, 0.15987786086043343, 0.08807514735963196, 0.10371029900852591, 0.11727060613338836, 0.19579645770136267, 0.1570006730617024, 0.13548460963647813, 0.11929097701795399, 0.15163608826696873, 0.15569315728498623, 0.08417873104917817, 0.12363596222712658, 0.21274252416333184, 0.17864876455860212, 0.0663687453197781, 0.215895360452123, 0.0841303875495214, 0.1577739167260006, 0.19761696079513058, 0.22130960976937786, 0.1888728135963902, 0.21548901975620538, 0.14755506272194907, 0.33270435815211385, 0.46950455813203007, 0.14810958062298596, 0.45190408069174737, 1.275105772074312, 1.7303006839938462, 2.400101311504841, 4.101268602535129, 5.608274387195706, 5.363909974694252, 6.533038839697838, 5.110636465251446, 7.478150250390172, 8.671767376363277, 14.840508364140987, 22.48931933194399, 36.94581650197506, 63.165177181363106, 71.78305014967918, 65.55244848132133, 38.98322917521, 19.987533576786518, 9.574792720377445, 5.606672773137689, 2.5052563939243555, 1.1909846984781325, 0.38471528445370495, 0.35397178726270795, 0.25146468775346875, 0.16268135339487344, 0.19517861976055428, 0.4660938848974183, 0.46430720889475197, 0.23635948891751468, 0.18613880092743784, 0.2669493615394458, 0.2660733601078391, 0.1647023847908713, 0.10960213519865647, 0.1721050258493051, 0.15790388162713498, 0.15047401859192178, 0.2059788425685838, 0.17088438587961718, 0.11857302335556597, 0.3364478994626552, 0.08807916980003938, 0.09548772577545606, 0.0923526639235206, 0.1658993650926277, 0.16253221139777452, 0.13923049613367766, 0.07031605811789632, 0.17625098931603134, 0.17446548590669408, 0.1741633575875312, 0.12322782553383149, 0.15196793217910454, 0.14032384293386713, 0.13300580671057105, 0.09781646644114517, 0.1333793147932738, 0.2662638248875737, 0.17487188597442582, 0.05712581922125537, 0.17995967937167734, 0.11765529096010141, 0.11556477227713913, 0.1585167323355563, 0.08349107185495086, 0.11348165280651301, 0.11790546894189902, 0.14457343990216032, 0.1795050545479171, 0.19663601968204603, 0.1997153091360815, 0.13662634446518496, 0.13873514224542305, 0.08735482624615543, 0.37697619816754013, 0.10858483627089299, 0.18858889758121222, 0.16025567339966074, 0.17331515700789168, 0.19862669723806903, 0.2438919761334546, 0.06403446081094444, 0.16384903370635584, 0.11857841134769842, 0.1422137368354015, 0.12870066741015762, 0.12999752594623715, 0.10136463737580925, 0.07597525327582844, 0.18751762225292623, 0.09239958992111497, 0.18661990558030084, 0.15242451627273113, 0.10294939726009034, 0.15388844709377736, 0.1606991363223642, 0.12793874891940504, 0.21326478832634166, 0.21797588240588084, 0.08188055944629014, 0.16695269529009238, 0.34463209623936564, 0.2212630325811915, 0.16767783294199035, 0.09760554807144217], [0.013614780764328316, 0.04324269641074352, 0.039817844444769435, 0.011558500136743532, 0.06630302072153427, 0.05062617150542792, 0.03696594532812014, 0.06159873213618994, 0.10453733353642747, 0.04833775543374941, 0.029969823081046343, 0.02244158837129362, 0.054054467036621645, 0.04872274454100989, 0.050479849669500254, 0.030889433110132813, 0.0733437979943119, 0.04986303218174726, 0.01754602235450875, 0.04539747766102664, 0.05047796461440157, 0.011160579106217483, 0.05453341575048398, 0.07788640970829874, 0.02947910576040158, 0.11851449016830884, 0.04857296800764743, 0.01884906112536555, 0.0646171357948333, 0.04791845683939755, 0.04308776566176675, 0.026077421789523214, 0.018640974049048964, 0.06646983325481415, 0.05093700150609948, 0.046115850636851974, 0.04689432644227054, 0.043991289639961906, 0.04510169099376071, 0.014428788745135535, 0.040579180349595845, 0.04214481137751136, 0.0625696023053024, 0.0736079654598143, 0.04837494074308779, 0.020513965537247714, 0.07217489313916303, 0.0014723522258464072, 0.047088639257708564, 0.07459567495970987, 0.04565220129734371, 0.046611100624431856, 0.06544469724758528, 0.03835452218481805, 0.013824278848915128, 0.036886442758259363, 0.03360063587024342, 0.02967399745102739, 0.05511188646778464, 0.05655477740219794, 0.029588453799078707, 0.012656785929721082, 0.12093884171918035, 0.12350169286946766, 0.08044108981266618, 1.7568429722450674, 5.071989689022303, 13.750113174319267, 30.466179996728897, 30.98595790565014, 43.42671073973179, 46.766537725925446, 54.459319934248924, 49.28543396294117, 56.07227638363838, 60.82417979836464, 69.75035682320595, 64.66348618268967, 75.86856052279472, 81.76558569073677, 87.4787387251854, 88.66893365979195, 105.04312142729759, 110.43051794171333, 111.67373523116112, 116.83480069041252, 97.54536375403404, 99.51475247740746, 92.64431834220886, 79.37259569764137, 70.6309063732624, 60.6565859913826, 51.12275317311287, 54.64013323187828, 56.33063592016697, 56.75761140882969, 52.10050530731678, 61.25811271369457, 45.03257296979427, 25.149243101477623, 12.125395406037569, 2.3202725825831294, 0.5189443880226463, 0.24583151971455663, 0.052026129196747206, 0.3051736776251346, 0.24864981067366898, 0.07785549183608964, 0.019326579349581152, 0.010592140370135894, 0.04163762023381423, 0.16300896706525236, 0.01635541339055635, 0.03728707633854356, 0.007070924702929915, 0.023133006543503143, 0.038958140576141886, 0.03966603442677297, 0.0842308669234626, 0.013399927156569902, 0.013945132959634066, 0.07145089097321033, 0.04757647147926036, 0.06213879671122413, 0.05818290839670226, 0.045192938050604425, 0.06059901468688622, 0.04463678000320215, 0.05483100212586578, 0.0201553430815693, 0.014499229691864457, 0.01960018136742292, 0.01823566864914028, 0.018970064593304414, 0.05118060034874361, 0.05582388439506758, 0.045814683398930356, 0.12646704039070755, 0.04177822011115495, 0.083874101692345, 0.03908675476850476, 0.052389967095223255, 0.07001769990893081, 0.016928518380154856, 0.03693926511914469, 0.07325888887862675, 0.03927238445612602, 0.046153952498571016, 0.02582199125754414, 0.04378230085421819, 0.07890911889262497, 0.05975982378004119, 0.08412849507294595, 0.05382380753871985, 0.07702410832280293, 0.057583479429013096, 0.033243410507566296, 0.02336007590201916, 0.06764342848327942, 0.09152530285064131, 0.08070886411587708, 0.025286533564212732, 0.00956782721914351, 0.10390619630925357, 0.03338705690111965, 0.05118909051816445, 0.024683059891685843, 0.025061863198061474, 0.03897392605722416, 0.030021085076441523, 0.10190611574216746, 0.048834044428076595, 0.058235738179064356, 0.08972265582997352, 0.009040917211677879, 0.04462746233912185, 0.01540668890811503, 0.05006985389627516, 0.05210629969951697, 0.10319443215848878, 0.04941672312270384, 0.049123415228677914, 0.010114822525792988, 0.02750139723502798, 0.06157820804219227, 0.03558341326424852, 0.03277854775660671, 0.023062962645781226, 0.03072369483561488, 0.05028810468502343, 0.04671640766900964, 0.0375853825971717, 0.059912401920882985, 0.10613236474455334, 0.02217325189121766, 0.034485888172639534, 0.04415545641677454, 0.025481588527327403, 0.08665085464599542, 0.061290592420846224, 0.026118071073142346, 0.03006250990438275, 0.027609849130385555, 0.06669767259154469, 0.027112641728308517, 0.004876054954365827, 0.03643649717560038, 0.056467152026016265, 0.014387629234988708, 0.042614613121259026, 0.029287010111147538, 0.05286709012580104, 0.01683518032223219, 0.014442681749642361, 0.047470852732658386, 0.026621037541190162, 0.06582242072909139, 0.026211830299871508, 0.07339893214520998, 0.031135429089772515, 0.014531851720676059, 0.03402961578103714, 0.07582107209600508, 0.05361737545172218, 0.017707849510770757, 0.03884204270434566, 0.06551333848619834, 0.07132374623324722, 0.026331212175136898, 0.057850003213388845, 0.09324352315161377, 0.12538056587800384, 0.04312779339670669, 0.050303927273489535, 0.03535084273607936, 0.04842815273150336, 0.015447341902472544, 0.07132626211387105, 0.07734413724392653, 0.07713684797636233, 0.054164497851161286, 1.0150714754126966, 4.037509448826313, 11.857033856213093, 27.86426581442356, 30.814759992063046, 43.4829743206501, 44.96000066399574, 53.260328471660614, 50.28866373002529, 56.15059398114681, 62.088425159454346, 72.92171224951744, 67.91679561138153, 84.53669339418411, 93.46709579229355, 102.27401241660118, 105.56522861123085, 122.2152891755104, 129.08705323934555, 130.17102867364883, 133.43207448720932, 114.13258329033852, 109.49324503540993, 102.99364820122719, 91.3977800309658, 78.74408662319183, 70.56982085108757, 58.70627984404564, 64.19036597013474, 64.22293782234192, 64.04182434082031, 58.29199567437172, 66.65343180298805, 48.98981362581253, 26.01202480494976, 10.591993387788534, 1.940762959420681, 0.3017714055022225, 0.13051311078015715, 0.024677256296854466, 0.17604651278816164, 0.07227104579214938, 0.08935449863201939, 0.06054060024325736, 0.029558085116150323, 0.04212583837215789, 0.0951586797600612, 0.05922668344283011, 0.10342233828851022, 0.04250378820870537, 0.012712357020063791, 0.0144588735565776, 0.020604086384992115, 0.03596119611756876, 0.021948778194200713, 0.05713249483960681, 0.08156551033607684, 0.024248345034720842, 0.07033014408079907, 0.05229404450801667, 0.033515099639771506, 0.07463085275958292, 0.04201643467240501, 0.03976560466981027, 0.012359437041595811, 0.044365936919348314, 0.062054121372057125, 0.028278134559514, 0.04628387658158317, 0.027249382437730674, 0.04377690544060897, 0.05263486469630152, 0.12083914902177639, 0.027284118659736123, 0.0775506101490464, 0.04561923138680868, 0.061268869758350775, 0.033745028122211806, 0.03952504863264039, 0.05863607490027789, 0.019665464387799148, 0.06247294499189593, 0.015551175783912186, 0.04943487605487462, 0.04318033745221328, 0.04846143434406258, 0.040216878696810454, 0.02883071545511484, 0.03872992645483464, 0.02631185510836076, 0.035451377771096304, 0.07884850769187324, 0.025638751285441685, 0.05733452599088196, 0.040604702808195725, 0.06570746205397882, 0.029634747115778737, 0.021476636829902418, 0.07484145942726173, 0.047627175008528866, 0.04389748959511053, 0.08706636086571962, 0.05020681725000031, 0.04032830474898219, 0.03376291017048061, 0.019344613538123667, 0.05546608015720267, 0.00665146840219677, 0.06745717910234816, 0.019942211256420705, 0.013698772399948211, 0.1774885502527468, 0.16456716548418626, 0.22388149285688996, 0.1228021147835534, 0.1322952299960889, 0.10990624505211599, 0.13774229708360508, 0.18884502758737653, 0.2345296644489281, 0.16136675752932206, 0.2070307478425093, 0.183292115398217, 0.12876006891019642, 0.13811090699164197, 0.16144116525538266, 0.15027777990326285, 0.1513667925610207, 0.1997531289816834, 0.1589477271772921, 0.1087182892661076, 0.13425460376311094, 0.12209334890940227, 0.1322171263745986, 0.1640387118095532, 0.16799231059849262, 0.20079739013453946, 0.16307147074257955, 0.10988199908751994, 0.16991620970657095, 0.1242813709541224, 0.0695024490414653, 0.10043634421890602, 0.09139409114141017, 0.19506695622112602, 0.17833731486462057, 0.11295279837213457, 0.11776794155593961, 0.0890936708310619, 0.15010808041552082, 0.18569333420600742, 0.1071193246752955, 0.16520002449396998, 0.14927050739061087, 0.17875613848445937, 0.1764543674653396, 0.1880862409598194, 0.13609858840936795, 0.1707340416032821, 0.13528296811273322, 0.1913601512205787, 0.16929362202063203, 0.2306632383260876, 0.1799336596741341, 0.12615331972483546, 0.27110114344395697, 0.16090385033749044, 0.14463637402513996, 0.17508145363535732, 0.202735805651173, 0.21396540541900322, 0.1140361929719802, 0.22890940977958962, 0.3002856852253899, 0.23345202149357647, 0.27629861142486334, 3.5228035552427173, 10.69871636107564, 23.644411750137806, 46.16089962422848, 50.711106061935425, 64.99501079320908, 68.59964936971664, 76.4144316315651, 73.34867253899574, 80.19218891859055, 85.84896817803383, 95.51220685243607, 93.95786225795746, 108.71858060359955, 115.77771261334419, 125.42712762951851, 125.50288796424866, 141.29008322954178, 144.62423712015152, 145.96396923065186, 150.37901312112808, 132.62604653835297, 130.57876199483871, 126.0020063817501, 112.37925857305527, 101.29440978169441, 91.17179855704308, 74.41441655158997, 83.44511076807976, 82.82140463590622, 83.59603106975555, 76.56447798013687, 89.5932188630104, 70.2183473110199, 41.30232833325863, 19.90678410977125, 4.177747098729014, 1.338196755386889, 0.4718438966665417, 0.13888355693779886, 0.34901664534118026, 0.39504396147094667, 0.1660036516841501, 0.14502423524390906, 0.12022194190649316, 0.15078088181326166, 0.4323964915238321, 0.20180852181511, 0.3065717651043087, 0.10323277150746435, 0.18831091874744743, 0.12676430022111163, 0.12815220543416217, 0.16330707294400781, 0.13002776104258373, 0.11349173117196187, 0.18455004086717963, 0.16328681231243536, 0.18726821610471234, 0.10136932774912566, 0.11427042220020667, 0.1692306433687918, 0.12708717898931354, 0.15388761588837951, 0.1290063135093078, 0.12206689134472981, 0.11763032511225902, 0.10366945120040327, 0.20347225363366306, 0.12619865010492504, 0.11838364211143926, 0.24904653313569725, 0.21377621713327244, 0.09248691843822598, 0.15238982829032466, 0.20867027080385014, 0.23440881312126294, 0.19207222707336769, 0.1323391799814999, 0.129571562865749, 0.16173032083315775, 0.1353704376379028, 0.0972684052248951, 0.18002954515395686, 0.16814069560496137, 0.1672305999090895, 0.12714224634692073, 0.16631302336463705, 0.16866442922037095, 0.15084081765962765, 0.1152214250760153, 0.13968374056275934, 0.13964228419354185, 0.12265953337191604, 0.2182124790851958, 0.16455883858725429, 0.07977596222190186, 0.07444738643243909, 0.17709421750623733, 0.19050381670240313, 0.15810389042599127, 0.15016429068055004, 0.05837639371748082, 0.1918217373895459, 0.09645061785704456, 0.22166992246638983, 0.1560156946652569, 0.23821453156415373, 0.22721814428223297, 0.10827283738763072, 0.08592408426920883], [0.03898421593476087, 0.021763777476735413, 0.08269724843557924, 0.050175101569038816, 0.030578282130591106, 0.06752964240149595, 0.04054669654578902, 0.025284702314820606, 0.08558893037843518, 0.044774841735488735, 0.008887430867616786, 0.027212145178054925, 0.031410123920068145, 0.01876099602668546, 0.017950643123185728, 0.05176345344807487, 0.018580657851998694, 0.04056641169881914, 0.05417473948909901, 0.038630493509117514, 0.0312209059484303, 0.06202455420861952, 0.06523169344291091, 0.07556391050457023, 0.04307354240154382, 0.03162665292620659, 0.07535535216447897, 0.05131633915880229, 0.010232237709715264, 0.03783501138968859, 0.022593828834942542, 0.008783052435319405, 0.061321543689700775, 0.06125907340901904, 0.011260795017733471, 0.035123804918839596, 0.035963886402896605, 0.02162457469239598, 0.0365026670624502, 0.010938208470179234, 0.042615885904524475, 0.013562517797254259, 0.03737673148862086, 0.07628242819919251, 0.04836255429836456, 0.03530442882038187, 0.05939098751696292, 0.01171904337752494, 0.003326648666188703, 0.05064475117251277, 0.06378188569215126, 0.040625520050525665, 0.0621615991985891, 0.09575760777806863, 0.05745252004999202, 0.049539184910827316, 0.0432608048140537, 0.008723017326701665, 0.05485741887241602, 0.045572806338896044, 0.006340540066958056, 0.22252109163673595, 4.441564092412591, 18.258732743561268, 48.08419682085514, 58.19829650223255, 78.50527703762054, 90.77705293893814, 84.65298235416412, 92.97830522060394, 94.38756600022316, 94.65107426047325, 93.71028274297714, 106.08551949262619, 94.91157308220863, 101.78535863757133, 90.03979369997978, 93.40973407030106, 94.98582109808922, 89.2279900610447, 93.67546901106834, 90.6145204603672, 82.98844367265701, 77.32781141996384, 75.93802839517593, 92.88107603788376, 90.97974926233292, 99.50962275266647, 102.10264921188354, 104.03724700212479, 110.19439101219177, 115.5960975587368, 113.54829624295235, 101.15607440471649, 100.54392725229263, 105.76046973466873, 109.84470337629318, 101.35618686676025, 112.76893526315689, 95.26168629527092, 83.54542538523674, 74.6649295091629, 58.78646694123745, 48.57771433889866, 32.791966795921326, 19.675437323749065, 5.163693018257618, 1.080343066714704, 0.2028870998765342, 0.15090194094227627, 0.06983000334003009, 0.0890326959779486, 0.033889620754052885, 0.1037975681538228, 0.022465593137894757, 0.0939034037583042, 0.0009271249120956782, 0.02243499067844823, 0.027179197531950194, 0.01747416019497905, 0.1172528465394862, 0.03240670579543803, 0.05352681488147937, 0.052594718217733316, 0.0445684244914446, 0.028239650491741486, 0.034851277159759775, 0.052633458326454274, 0.07407072422211058, 0.006301394096226431, 0.08138621487887576, 0.07356940346653573, 0.03977747532189824, 0.022352482410497032, 0.05498892372997943, 0.06177435767313, 0.026450542100064922, 0.0450010149506852, 0.02235359377664281, 0.08484336140099913, 0.01586910442711087, 0.031854911576374434, 0.03583526107831858, 0.04426349827554077, 0.05202278211072553, 0.05555743853619788, 0.04394043397041969, 0.009233153868990485, 0.07575922150863335, 0.015661959878343623, 0.044758087751688436, 0.03321803276776336, 0.0531387903902214, 0.009836116387305083, 0.05547127890167758, 0.0068268351151346, 0.04834166284126695, 0.02363736268307548, 0.04162287375947926, 0.07322146979277022, 0.03521907070535235, 0.023286362084036227, 0.0632377207512036, 0.03607580227253493, 0.02121632296621101, 0.015306879322452005, 0.02812248763802927, 0.0405641407269286, 0.021028426017437596, 0.08564313684473746, 0.11493640326079912, 0.06715456838719547, 0.026363708966528066, 0.10925846887403168, 0.038908346177777275, 0.05456962884636596, 0.09909665634040721, 0.013930338245700113, 0.04353662399807945, 0.12538031354779378, 0.07524817861849442, 0.06304646187345497, 0.03641344606876373, 0.0712911288428586, 0.058138880485785194, 0.055371630733134225, 0.06235795663087629, 0.07245562534080818, 0.04315204678277951, 0.039990805671550333, 0.02041679428657517, 0.07784334287862293, 0.041455871978541836, 0.04329092858824879, 0.04214926426357124, 0.035747294314205647, 0.03224339248845354, 0.02563255806308007, 0.06691013462841511, 0.06136581279861275, 0.024688433040864766, 0.01860384440078633, 0.014197042928572046, 0.07741192501271144, 0.02046834571956424, 0.020076233849977143, 0.011849072288896423, 0.022566269180970266, 0.04542269954981748, 0.01920950184285175, 0.028246224064787384, 0.019521385693224147, 0.02464350898662815, 0.018121051361958962, 0.023040191699692514, 0.029892660131736193, 0.10539812094066292, 0.03554185670509469, 0.012382397235342069, 0.01151711612692452, 0.13099988544126973, 0.027017984502890613, 0.02039475064520957, 0.01346381586699863, 0.020162807231827173, 0.016601056850049645, 0.020428327261470258, 0.037187476409599185, 0.0579210786963813, 0.06656047175056301, 0.10412245814222842, 0.03292024972324725, 0.04947068096953444, 0.016293058142764494, 0.05232781964878086, 0.0464216191903688, 0.024737809981161263, 0.09991616549086757, 3.300155927427113, 15.977785438299179, 45.5423916131258, 62.119895070791245, 85.22714674472809, 98.45989108085632, 98.41812372207642, 102.999317497015, 106.01722955703735, 109.65320885181427, 112.75840982794762, 121.85385257005692, 111.34334295988083, 111.37045830488205, 108.55016604065895, 108.78630056977272, 111.56483307480812, 108.27189937233925, 111.08650714159012, 109.67231422662735, 102.79451608657837, 98.39060559868813, 97.78731197118759, 109.12737786769867, 105.3064700961113, 116.27657264471054, 122.54288479685783, 123.35720390081406, 127.52357393503189, 131.74698650836945, 126.72199174761772, 122.25418388843536, 118.38908448815346, 127.03560411930084, 128.31511706113815, 119.7529985010624, 129.273182451725, 111.53109848499298, 97.03791618347168, 83.67378249764442, 64.0828849375248, 50.78943505883217, 33.28977808356285, 18.551007360219955, 4.486693795770407, 0.5734574503730983, 0.07043156598228961, 0.11126469442388043, 0.06051422060409095, 0.07192211764049716, 0.011205360297026346, 0.0887244449404534, 0.025148011700366624, 0.042924333611154, 0.025148941240331624, 0.04093716270290315, 0.05341768206562847, 0.05995624800561927, 0.02324636217963416, 0.05985519717796706, 0.05565641506109387, 0.011593539711611811, 0.0032926692028922844, 0.03142979825497605, 0.05759142783062998, 0.04734699570690282, 0.02613754873891594, 0.04306954222556669, 0.026675090011849534, 0.06734412774676457, 0.08508530896506272, 0.04032795593957417, 0.048174646217375994, 0.06901188200572506, 0.0703922618413344, 0.02644262152898591, 0.029980393119330984, 0.02817740099999355, 0.032700733572710305, 0.10996684883139096, 0.039582739482284524, 0.05648837373882998, 0.010849242589756614, 0.03168081857438665, 0.03420377557631582, 0.04618487037078012, 0.07313196678296663, 0.033780714293243363, 0.04760923358844593, 0.025951349452952854, 0.0484142003551824, 0.07164770853705704, 0.025870000790746417, 0.019121651966997888, 0.0691118418762926, 0.04717856158094946, 0.015861964966461528, 0.05328720137185883, 0.01585639143740991, 0.013915195650042733, 0.04972894093953073, 0.034586256224429235, 0.053860228435951285, 0.028294630646996666, 0.032927767679211684, 0.06252787876292132, 0.022996725965640508, 0.021442598226713017, 0.00951200379859074, 0.03703823051182553, 0.05804854998132214, 0.027280461727059446, 0.053438666291185655, 0.03532681570504792, 0.1199586279108189, 0.10713276496971957, 0.14741430699359626, 0.30667097540572286, 0.18565926962764934, 0.14328918303363025, 0.1426313878619112, 0.15491700440179557, 0.23162420082371682, 0.1325042633106932, 0.12303123803576455, 0.20049854210810736, 0.19306366215460002, 0.2125703904312104, 0.10013209335738793, 0.18149378767702729, 0.11222697794437408, 0.18652419821592048, 0.2138522724271752, 0.0995172314287629, 0.12836153560783714, 0.1131905750662554, 0.20232539798598737, 0.2046388652524911, 0.11037977979867719, 0.11892769573023543, 0.1252066361485049, 0.19495805347105488, 0.11195270242751576, 0.1472303582704626, 0.12635576276807114, 0.06682910694507882, 0.18281895172549412, 0.1639943165355362, 0.07635530710103922, 0.07236584773636423, 0.10663547407602891, 0.08476321687339805, 0.13320240163011476, 0.16823552723508328, 0.17212384671438485, 0.19797948509221897, 0.10477246076334268, 0.16467545967316255, 0.27585902251303196, 0.1472247179481201, 0.1875654314062558, 0.1825100847054273, 0.09450653233216144, 0.08867970827850513, 0.25813686253968626, 0.14156886987620965, 0.1946261353441514, 0.17972073750570416, 0.25659732171334326, 0.12416052704793401, 0.06461021897848696, 0.13352847163332626, 0.16139181243488565, 0.24239402526291087, 0.09731495272717439, 0.49235973798204213, 7.512791091576219, 28.24118658900261, 64.73767340183258, 84.97623860836029, 108.08113440871239, 119.99581307172775, 115.96267908811569, 120.1283347606659, 122.37200796604156, 121.93320751190186, 125.70886731147766, 137.20502883195877, 124.62977081537247, 130.87593644857407, 120.882867872715, 124.71123844385147, 124.43458288908005, 118.21396708488464, 125.14153495430946, 118.37421208620071, 111.77338868379593, 102.61448934674263, 102.51766294240952, 121.59115746617317, 120.29256194829941, 127.11932882666588, 132.5722262263298, 134.20787125825882, 141.32168233394623, 147.93151885271072, 144.84158545732498, 133.74928146600723, 132.53352910280228, 138.93454402685165, 143.51463586091995, 133.51079106330872, 143.992999792099, 128.27835023403168, 117.91402637958527, 102.44786068797112, 83.88950452208519, 69.36774015426636, 51.09410651028156, 29.429360032081604, 8.912199474871159, 2.082388484850526, 0.2894948283210397, 0.21313243370968848, 0.22845787229016423, 0.17959837219677866, 0.10049074364360422, 0.2221136970911175, 0.17460076458519325, 0.2441239418112673, 0.08405946791754104, 0.10353630248573609, 0.13180219160858542, 0.09948068065568805, 0.24589242035290226, 0.10765806451672688, 0.16083877882920206, 0.13894942996557802, 0.15395212336443365, 0.1617583294864744, 0.2667182864388451, 0.23447652667528018, 0.17169626575196162, 0.11310623740428127, 0.14872652798658237, 0.19223944778786972, 0.1044111313240137, 0.08480474003590643, 0.1025143577135168, 0.1745261490577832, 0.11805100410128944, 0.1813028330798261, 0.09642406381317414, 0.13361496152356267, 0.2883704152191058, 0.23936873447382823, 0.18022149422904477, 0.2020179558894597, 0.11372290275176056, 0.19012886885320768, 0.20471195195568725, 0.08814328393782489, 0.15206852287519723, 0.1938147601322271, 0.2866630005883053, 0.19300806045066565, 0.1340118027292192, 0.09630146843846887, 0.12068429990904406, 0.140031288319733, 0.13943198922788724, 0.17916290962602943, 0.07636866575921886, 0.16685983777279034, 0.15209089120617136, 0.19202600611606613, 0.16709261981304735, 0.09943159500835463, 0.10225164485746063, 0.09481383342063054, 0.0997053732862696, 0.10155205935006961, 0.09630948363337666, 0.13604638574179262, 0.20106451876927167, 0.14388287148904055, 0.1197767275152728, 0.18005350168095902, 0.1365922502009198, 0.18819879507645965], [0.0189299867633963, 0.08593185455538332, 0.07593151109176688, 0.018179352628067136, 0.08476436720229685, 0.0305326029410935, 0.00843354169774102, 0.03297128721897025, 0.12159273319412023, 0.04499634313106071, 0.015520692995778518, 0.00942136251978809, 0.003953469376938301, 0.008450097157037817, 0.014491294277831912, 0.017253041005460545, 0.06887854775413871, 0.02198937738285167, 0.0274625068414025, 0.023251403217727784, 0.0459915297687985, 0.07954332861118019, 0.05017984760343097, 0.027297618325974327, 0.05129102821229026, 0.03869180603942368, 0.03479023551335558, 0.02532676353439456, 0.028753969963872805, 0.09629142718040384, 0.061203390068840235, 0.06316686791251414, 0.051314550582901575, 0.032190314086619765, 0.06614305821130984, 0.018765280074148905, 0.017059399833669886, 0.0286655096715549, 0.02572940276877489, 0.04361370716651436, 0.07379498667432927, 0.0755797627789434, 0.04068168578669429, 0.017988507497648243, 0.035702424065675586, 0.03609810009947978, 0.008487438317388296, 0.015445035678567365, 0.06033584169927053, 0.024061169824562967, 0.13285740686114877, 0.05235895645455457, 0.11856385783175938, 0.0475615023606224, 0.01778292888047872, 0.02568851599789923, 0.014941134104446974, 0.088512109068688, 0.12219742027809843, 0.43353545072022825, 7.726835506036878, 39.67380031943321, 62.565668150782585, 71.58133417367935, 80.4545496404171, 85.00752612948418, 83.99674996733665, 85.42717561125755, 83.43577846884727, 66.58005014061928, 75.11466577649117, 58.779114335775375, 65.01899510622025, 47.29415461421013, 70.34883230924606, 76.84237986803055, 50.904390290379524, 77.79208570718765, 56.30140408873558, 59.60465043783188, 51.96890316903591, 46.517282500863075, 45.78594334423542, 39.71667721867561, 35.01803554594517, 60.319209694862366, 53.855695724487305, 62.77692921459675, 69.62630107998848, 68.02460342645645, 75.2555850148201, 101.07545793056488, 84.09422233700752, 75.86080133914948, 84.27227318286896, 82.13618740439415, 75.3997340798378, 79.3828247487545, 96.9606663286686, 97.16446459293365, 94.93574738502502, 100.51869660615921, 112.26478591561317, 107.21741795539856, 99.57963019609451, 95.16188845038414, 73.86970818042755, 57.68843986093998, 29.062831699848175, 10.422118753194809, 1.057300390675664, 0.1268371642800048, 0.11951218897593208, 0.06705088293529116, 0.025325006499770097, 0.1330645105917938, 0.05969274105154909, 0.03291181150416378, 0.011222475150134414, 0.009915951068251161, 0.007488416631531436, 0.033469598565716296, 0.025645541936683003, 0.026728038537839893, 0.04291677483706735, 0.08692665898706764, 0.011031857302441495, 0.02506477241695393, 0.04249482306477148, 0.05627138089039363, 0.04339154525951017, 0.03003938458277844, 0.029246206831885502, 0.05900051764911041, 0.05063697346486151, 0.03867685918521602, 0.010518369963392615, 0.0594308074505534, 0.030713462474523112, 0.07035361079033464, 0.00963380229222821, 0.03967046875914093, 0.047782384062884375, 0.05267726730380673, 0.03309841711597983, 0.05750448151957244, 0.049865748442243785, 0.015282494205166586, 0.0383062862965744, 0.04893994890153408, 0.02481987110513728, 0.006266321124712704, 0.018159119827032555, 0.031383328678202815, 0.024551011410949286, 0.011623689460975584, 0.02452723671012791, 0.02556302810262423, 0.03023010169272311, 0.004795349641426583, 0.042327624614699744, 0.05982275048154406, 0.051318109181011096, 0.03141273627988994, 0.037631655504810624, 0.008602088073530467, 0.024491544972988777, 0.023908920084068086, 0.00937501168664312, 0.05421440728241578, 0.040661829625605606, 0.005524861790036084, 0.03332857937493827, 0.03323355478642043, 0.04874661572102923, 0.012919994169351412, 0.004263695454937988, 0.09108780679525807, 0.027445413325040136, 0.03877331611874979, 0.018960904635605402, 0.0746822464861907, 0.030736799308215268, 0.08563538882299326, 0.04440333374077454, 0.0683854945236817, 0.045760974171571434, 0.035913646715926006, 0.03002466222824296, 0.09619842865504324, 0.01932012637553271, 0.04915447781968396, 0.10015753417974338, 0.07219098290079273, 0.05694729930837639, 0.019834410595649388, 0.12472121219616383, 0.021386274784163106, 0.04139134594879579, 0.00369446192507894, 0.020805770582228433, 0.027791380307462532, 0.03559484233846888, 0.06907915769261308, 0.027154855088156182, 0.07354291621595621, 0.07055995010887273, 0.023758611059747636, 0.041039393545361236, 0.027348603871359956, 0.01621821997105144, 0.017386030158377253, 0.03693284925248008, 0.014974051136960043, 0.06483151257270947, 0.11953413428273052, 0.023144379956647754, 0.08994225732749328, 0.022056007401261013, 0.04943299471051432, 0.028911631816299632, 0.05543289502384141, 0.010160209494642913, 0.07544574575149454, 0.04334253382694442, 0.008856039876263821, 0.07170600423705764, 0.03152859666442964, 0.08308032280183397, 0.05567110587435309, 0.03879791089275386, 0.018017013389908243, 0.048769781860755756, 0.023582022586197127, 0.09317812509834766, 0.5003666505217552, 8.250694870948792, 41.49428263306618, 66.45167022943497, 82.94698029756546, 95.56443125009537, 100.52077889442444, 96.93440213799477, 102.28683292865753, 91.21233478188515, 90.49845188856125, 94.83768224716187, 73.67035567760468, 80.73853880167007, 73.58902484178543, 89.65805098414421, 98.83714243769646, 84.13086757063866, 98.55131417512894, 86.40952929854393, 92.8961232304573, 87.54408001899719, 84.21390071511269, 79.20124769210815, 75.397157818079, 68.95493790507317, 97.9682506620884, 86.92325413227081, 95.74242889881134, 106.2953594326973, 106.11049175262451, 108.2479378581047, 126.80499449372292, 115.4541751742363, 107.98765942454338, 108.85664999485016, 101.34940803050995, 97.73925215005875, 106.8737567961216, 110.06095737218857, 107.94498011469841, 109.11576569080353, 118.08596715331078, 124.50163409113884, 121.54210209846497, 114.35746282339096, 112.01529130339622, 82.85949379205704, 61.429301127791405, 31.23120814561844, 11.9299509935081, 1.2054910138249397, 0.07237643076223321, 0.09501885913778096, 0.08657647660584189, 0.0363942429976305, 0.04360847873613238, 0.021751394742750563, 0.040338843245990574, 0.029581245689769275, 0.05297813768265769, 0.034783708324539475, 0.007608551322846324, 0.049465430274722166, 0.009099573780986248, 0.004318636647440144, 0.07431075704516843, 0.03755197481950745, 0.055726896825945005, 0.025883112684823573, 0.07280292076757178, 0.058284771876060404, 0.027466507017379627, 0.07515392586356029, 0.03865529979520943, 0.03190283947333228, 0.04897453298326582, 0.020522526210697833, 0.08727034757612273, 0.010635480866767466, 0.03544161481841002, 0.03405053692404181, 0.05001605190045666, 0.06315779886790551, 0.056123786271200515, 0.043986710588796996, 0.031764425220899284, 0.031151830553426407, 0.09183534246403724, 0.02321526248124428, 0.05198473962082062, 0.017464434349676594, 0.06319014908513054, 0.022812870010966435, 0.07771284363116138, 0.04182896445854567, 0.020819967867282685, 0.013695732377527747, 0.033413180499337614, 0.01743145887303399, 0.049968320672633126, 0.016530838547623716, 0.028753283477271907, 0.019520337409630883, 0.023849737517593894, 0.058370842452859506, 0.01881432119262172, 0.05274053168250248, 0.05060498689999804, 0.006820012922617025, 0.08145975429215468, 0.02285837850649841, 0.07904208949184977, 0.0756283882947173, 0.07153454585932195, 0.06833912513684481, 0.008161548284988385, 0.19451683183433488, 0.29860789712984115, 0.12296351706027053, 0.11917220370378345, 0.1603462896309793, 0.16115551261464134, 0.17659910110523924, 0.1227157807443291, 0.22850562207167968, 0.16982575674774125, 0.21297313913237303, 0.11261640509474091, 0.10624506729072891, 0.23415752191795036, 0.13835734454914927, 0.08071366581134498, 0.21266594936605543, 0.22129519726149738, 0.18130525248125196, 0.11784318048739806, 0.1608010331983678, 0.17618510144529864, 0.1295902204583399, 0.16921979316975921, 0.08113555450108834, 0.10581256588920951, 0.11165530901052989, 0.1436930597992614, 0.07777174789225683, 0.20192388124996796, 0.2457340608816594, 0.15505097690038383, 0.132460001623258, 0.15557214268483222, 0.07007466716459021, 0.08826726712868549, 0.1097532438870985, 0.15784041315782815, 0.10603748858557083, 0.1733001953107305, 0.08862199145369232, 0.2244594180956483, 0.13077973475446925, 0.21778838621685281, 0.09054059162735939, 0.15375866030808538, 0.10357467152061872, 0.1699109553010203, 0.18212775990832597, 0.08429009772953577, 0.17199621215695515, 0.11137036883155815, 0.3043865557992831, 0.19599737192038447, 0.11433685926022008, 0.14215754141332582, 0.13621158781461418, 0.12354507140116766, 0.25011659134179354, 1.3096265634521842, 14.193843863904476, 57.900859862565994, 85.3974612057209, 99.38591659069061, 108.69969561696053, 110.54989993572235, 106.55164808034897, 110.28854236006737, 108.67967069149017, 92.2068402171135, 101.53280898928642, 81.92757099866867, 90.69031119346619, 69.67779591679573, 96.66828721761703, 105.31546801328659, 76.80437430739403, 107.86266133189201, 82.72606015205383, 85.50865843892097, 74.64723005890846, 66.09693646430969, 67.77024507522583, 56.45211160182953, 52.475681975483894, 85.42566329240799, 76.37952670454979, 89.29533764719963, 93.57377886772156, 94.69156488776207, 100.85812479257584, 126.8188713490963, 108.2459619641304, 101.88349977135658, 109.89481508731842, 106.36466011404991, 96.90599486231804, 106.90958887338638, 123.92734050750732, 125.17010942101479, 122.7051816880703, 129.2687138915062, 140.86629956960678, 138.95779877901077, 128.56274217367172, 128.08373987674713, 106.03719368577003, 84.98658165335655, 46.04600138962269, 18.732533119618893, 2.702923924662173, 0.130049743456766, 0.2394110368913971, 0.17237466294318438, 0.1608925696928054, 0.2726049127522856, 0.19036261568544433, 0.1718149648513645, 0.15310410090023652, 0.11412946609198116, 0.10473352027474903, 0.11435257052653469, 0.17074124043574557, 0.08673367090523243, 0.11580957710975781, 0.10223984470940195, 0.10395476245321333, 0.10438993558636867, 0.17730118765030056, 0.18584223871584982, 0.126705878356006, 0.07903239704319276, 0.22555070172529668, 0.09744170412886888, 0.13820437307003886, 0.1456718926783651, 0.0980877511028666, 0.16908674093429, 0.150364151049871, 0.13087851461023092, 0.13820897438563406, 0.10794708650792018, 0.1934825599892065, 0.12242379016242921, 0.15107257553609088, 0.1653817913029343, 0.2413002183311619, 0.1386961794923991, 0.11980536699411459, 0.14465118729276583, 0.2196920246933587, 0.12576596316648647, 0.15528350661043078, 0.12623032496776432, 0.14172219758620486, 0.09665076766395941, 0.1611424656584859, 0.11798904961324297, 0.10351417906349525, 0.09544599481159821, 0.15341863792855293, 0.1177535364695359, 0.09134387742960826, 0.1804605103097856, 0.1291363823111169, 0.09969069360522553, 0.18490153684979305, 0.11185844967258163, 0.10051683755591512, 0.19828639284241945, 0.16383750073146075, 0.08965115732280537, 0.2051433178712614, 0.2194438801961951, 0.15542141249170527, 0.09033345078933053], [0.02207003955845721, 0.04398805758683011, 0.042690534828579985, 0.04318223363952711, 0.03308516235847492, 0.08285382675239816, 0.05578088435868267, 0.03210623988707084, 0.04531128091912251, 0.03820280864601955, 0.035566596197895706, 0.03537239841534756, 0.05221556610194966, 0.03502233848848846, 0.07132541606551968, 0.07164916314650327, 0.025041309418156743, 0.06406133397831582, 0.033295750472461805, 0.03151756463921629, 0.03303078519820701, 0.04716819377790671, 0.025193870860675815, 0.03507282308419235, 0.07424060924677178, 0.03084719934122404, 0.015188012312137289, 0.05279246346617583, 0.045883376587880775, 0.0903666990052443, 0.022829523804830387, 0.025542448347550817, 0.07051219290588051, 0.024723033820919227, 0.0661777016648557, 0.035516170974005945, 0.05637274713080842, 0.040435229675495066, 0.020062222101842053, 0.05922601179918274, 0.029654979916813318, 0.0786129648622591, 0.05881588986085262, 0.010792106495500775, 0.019779602989729028, 0.03471767202427145, 0.059206515579717234, 0.030859162761771586, 0.043216502308496274, 0.08181550278095528, 0.02748914066614816, 0.031061099289217964, 0.12631825462449342, 0.026128659665118903, 0.02641345141455531, 0.10386626876424998, 0.19122767786029726, 0.13220502936746925, 7.536432472988963, 36.39096647500992, 55.054413601756096, 51.65517300367355, 66.83790430426598, 75.82315295934677, 71.86844676733017, 49.870420172810555, 55.13467289507389, 50.68406291306019, 43.39259997010231, 26.43448993563652, 29.437145814299583, 30.094708129763603, 32.42794252932072, 31.16284791380167, 32.07456149160862, 37.56259560585022, 23.409314565360546, 37.31118589639664, 24.43024568259716, 20.76689835637808, 20.990750044584274, 40.52990958094597, 30.973665565252304, 29.27529349923134, 22.468435652554035, 19.82676040381193, 23.31685222685337, 23.609457425773144, 20.2208486571908, 27.610648423433304, 24.34226330369711, 31.43137950450182, 23.96729562431574, 31.252496503293514, 33.953819051384926, 33.0802421271801, 44.96164597570896, 22.62026220560074, 55.163498148322105, 71.97693094611168, 54.06027674674988, 66.43915370106697, 70.55721312761307, 73.1097261607647, 84.79914531111717, 89.5170709490776, 95.55210471153259, 92.7954514324665, 91.33102521300316, 80.66780179738998, 50.2701511234045, 18.634933456778526, 2.186563932336867, 0.19990979635622352, 0.06639789688051678, 0.05792750198452268, 0.05110702011734247, 0.04953888805175666, 0.02930218332039658, 0.046499381423927844, 0.09000174788525328, 0.06715895447996445, 0.053300270592444576, 0.013723223382839933, 0.031146149412961677, 0.040743766439845785, 0.05338903887604829, 0.020910669445584062, 0.06369555165292695, 0.003615116133914853, 0.04479977418668568, 0.03623493357736152, 0.04021219203423243, 0.06052785014617257, 0.037023613913333975, 0.01779335976607399, 0.004553394655886223, 0.03687608608743176, 0.010920339409494773, 0.0531945627881214, 0.06787516409531236, 0.050851331689045765, 0.036517235421342775, 0.05177160965104122, 0.06209333645529114, 0.012076585080649238, 0.041244523163186386, 0.04412566289829556, 0.047273434029193595, 0.02494074469723273, 0.015326530465245014, 0.02291101718583377, 0.027568131154112052, 0.03603027893404942, 0.06380375678418204, 0.09120510323555209, 0.04752130393171683, 0.03187310532666743, 0.1580423812265508, 0.020793582662008703, 0.027271593062323518, 0.03484122848021798, 0.08419820500421338, 0.019746861289604567, 0.019161284508300014, 0.012546262514661066, 0.04127416083065327, 0.07887912870501168, 0.02074075659038499, 0.02066642864519963, 0.026638483577698935, 0.06947734218556434, 0.028463886701501906, 0.03008153486007359, 0.01818238615669543, 0.02127812160324538, 0.031281710107577965, 0.03821049729594961, 0.043126383316121064, 0.02786186207231367, 0.006813316431362182, 0.03417303210881073, 0.09029518565512262, 0.023325412039412186, 0.03297170653240755, 0.03357593719556462, 0.014500642555503873, 0.036025109875481576, 0.021657592842529994, 0.012285013544897083, 0.029264413569762837, 0.013559139169956325, 0.05478435072291177, 0.04464440557057969, 0.023198810922622215, 0.01579955220222473, 0.04111310365260579, 0.037551741042989306, 0.03687562595587224, 0.05354185450414661, 0.00571029063394235, 0.03437808380112983, 0.024286754887725692, 0.09555621116305701, 0.049472462123958394, 0.09217233688104898, 0.005939063685218571, 0.08944608707679436, 0.06448084037401713, 0.0772000418510288, 0.015438427781191422, 0.013163860185159137, 0.008050474752963055, 0.06091550356359221, 0.017862934255390428, 0.07016794770606793, 0.06521454983158037, 0.07413433369947597, 0.07741631852695718, 0.03063278731133323, 0.04472468368476257, 0.020956916378054302, 0.04114788811421022, 0.07038169365841895, 0.04023762172437273, 0.05538291508855764, 0.025364587090734858, 0.0674458613502793, 0.12382039334625006, 0.003673900259855145, 0.009019383796839975, 0.09255479526473209, 0.10822407828527503, 0.051921445556217805, 8.967492207884789, 40.81280820071697, 64.32897493243217, 68.07988286018372, 79.15198713541031, 87.12307021021843, 83.46980184316635, 69.43590089678764, 85.8534899353981, 75.57991281151772, 71.41600504517555, 42.96115592122078, 56.08516529202461, 52.29045331478119, 56.69551894068718, 35.69243095815182, 47.42396704852581, 53.684089332818985, 35.64463712275028, 57.101242169737816, 35.090433061122894, 40.92297948896885, 34.49476942420006, 49.83044631779194, 37.3108097165823, 39.41118121147156, 36.6957975178957, 36.55727595090866, 39.781798124313354, 44.90897700190544, 38.448160886764526, 44.65684533119202, 49.6870382130146, 57.84428849816322, 44.218960627913475, 56.672963351011276, 58.07317681610584, 54.042455703020096, 63.044009283185005, 44.45982590317726, 86.46312162280083, 99.85252395272255, 87.91464373469353, 92.55187690258026, 105.49214333295822, 98.00205364823341, 98.74809801578522, 101.21600478887558, 108.81127282977104, 108.84860202670097, 107.88976907730103, 92.61770457029343, 59.69639651477337, 22.14024156332016, 2.399095077998936, 0.11039233693736605, 0.005184464162084623, 0.008544905595044838, 0.050608460151124746, 0.06353737029712647, 0.01362370137940161, 0.06935286175576039, 0.05005737839383073, 0.06859378569060937, 0.086144880624488, 0.018072548300551716, 0.03788079819059931, 0.030096644986770116, 0.03262205107603222, 0.015380100539914565, 0.021546133393712807, 0.003417715056457382, 0.03873067602398805, 0.012093621080566663, 0.07086837184033357, 0.0036675133833341533, 0.03352316307427827, 0.06720903460518457, 0.0073281187633256195, 0.030614485949627124, 0.036193562555126846, 0.07429892721120268, 0.02953532344690757, 0.03558749878720846, 0.0018388637113275763, 0.046919533488107845, 0.049882650855579413, 0.04077359335497022, 0.04387362212582957, 0.02783505569823319, 0.03679793793708086, 0.025227083824574947, 0.05539651494473219, 0.05718979977245908, 0.06796537956688553, 0.05981368143693544, 0.05861803329025861, 0.03152249249978922, 0.07398297268082388, 0.015688656785641797, 0.06285881725489162, 0.014467211585724726, 0.04855262945056893, 0.045570765432785265, 0.08579943314543925, 0.014241945646062959, 0.04680069338064641, 0.058784897773875855, 0.02234319628769299, 0.01914261021738639, 0.07160216293414123, 0.012467917695175856, 0.06304869573796168, 0.060385053511708975, 0.06440337499952875, 0.03315368485345971, 0.033341114249196835, 0.030091963890299667, 0.14141983177978545, 0.1397840492427349, 0.15921507845632732, 0.12091933807823807, 0.11592086957534775, 0.18717069790000096, 0.1475163671420887, 0.1361118580098264, 0.1994020931306295, 0.10006744487327524, 0.13451578037347645, 0.1042772775690537, 0.08660355015308596, 0.11206132316146977, 0.13227505842223763, 0.12383904351736419, 0.11728835830581374, 0.20523478015093133, 0.12809848878532648, 0.09505277528660372, 0.10921212175162509, 0.17819850356318057, 0.1750302454456687, 0.16286168043734506, 0.15246883733198047, 0.12336084808339365, 0.18240990961203352, 0.14701378473546356, 0.09258080754079856, 0.14103695779340342, 0.11284315347438678, 0.20559215394314378, 0.1343435575836338, 0.15066788240801543, 0.11579813319258392, 0.16290331492200494, 0.14668569609057158, 0.227055688155815, 0.08436431249720044, 0.20044277713168412, 0.1554045212105848, 0.16883176867850125, 0.16546886006835848, 0.11430024169385433, 0.15368557360488921, 0.22011620661942288, 0.1282345541403629, 0.16438076767371967, 0.12107408329029568, 0.19964104983955622, 0.11598501339904033, 0.11508359340950847, 0.2656785672297701, 0.20032263826578856, 0.1629047843744047, 0.2580979443155229, 0.3777517128037289, 0.4920688160927966, 17.206183522939682, 57.424988597631454, 82.04008296132088, 77.8481175005436, 91.30846962332726, 99.61997643113136, 97.03710302710533, 71.26353442668915, 79.65435817837715, 69.86598461866379, 66.57009467482567, 41.79399535059929, 46.307731345295906, 50.142219588160515, 53.70858661830425, 47.59818769991398, 49.44648452103138, 55.237115398049355, 32.23248481750488, 55.25542661547661, 33.98310787975788, 27.721739262342453, 30.657505430281162, 53.00319246947765, 43.87704357504845, 41.110241040587425, 31.79934985935688, 30.059164837002754, 35.07657900452614, 36.98740527033806, 28.611459620296955, 42.3495027422905, 36.76454722881317, 47.709498926997185, 35.345365181565285, 43.988647386431694, 51.12853266298771, 51.23401500284672, 62.61441953480244, 36.32053345441818, 77.88126692175865, 100.19483998417854, 79.98646795749664, 88.32360818982124, 90.88353842496872, 95.98604902625084, 109.71263006329536, 112.14339762926102, 120.28712823987007, 118.33357706665993, 121.68472364544868, 112.48823672533035, 78.32770496606827, 32.775346487760544, 4.31797762401402, 0.31380684406030923, 0.1370694808429107, 0.15791345533216372, 0.13874847121769562, 0.1660904087475501, 0.08618762833066285, 0.07238093559863046, 0.1445240425528027, 0.15219407941913232, 0.1682202093070373, 0.0620339201122988, 0.14954689802834764, 0.18383737129624933, 0.12559574417537078, 0.0822388163942378, 0.11738375396816991, 0.08408738009165972, 0.17175213462905958, 0.09913245754432864, 0.1614918836276047, 0.12065097005688585, 0.15919395693344995, 0.16894182917894796, 0.13406652869889513, 0.09163779017399065, 0.1115085270430427, 0.12209541207994334, 0.1718238854664378, 0.12259032067959197, 0.12424670523614623, 0.21392611612100154, 0.14064614282688126, 0.18345926189795136, 0.1157914761279244, 0.17867281014332548, 0.13518837396986783, 0.05808978370623663, 0.09152787068160251, 0.10885844385484233, 0.12504526355769485, 0.12072626836015843, 0.15179401729255915, 0.20698826730949804, 0.21437990973936394, 0.15430464351084083, 0.19049707800149918, 0.1709222502540797, 0.09374257293529809, 0.16057405475294217, 0.26788233022671193, 0.14584773714886978, 0.2168840792728588, 0.18329313956201077, 0.12129971102694981, 0.17459815222537145, 0.16423659806605428, 0.08656962658278644, 0.11847834757645614, 0.3037831897381693, 0.15511299076024443, 0.14763159299036488, 0.13672507979208604, 0.11021520112990402], [0.01594750861841021, 0.09343871541204862, 0.042347881535533816, 0.025552656588843092, 0.014737915516889188, 0.03862529105390422, 0.020476717145356815, 0.004520491538642091, 0.05728975964302663, 0.018056770240946207, 0.01968161537661217, 0.07471850782167166, 0.00711398782186734, 0.03035790694411844, 0.03071690232900437, 0.030733305648027454, 0.070194004510995, 0.030179270142980386, 0.02354380012548063, 0.044469173371908255, 0.08348813295015134, 0.06887467374326661, 0.06717479933286086, 0.054562337245442905, 0.07470950557035394, 0.008124554078676738, 0.04690798567025922, 0.03145555077935569, 0.09967657053493895, 0.06441652585635893, 0.03385950440133456, 0.0748347355693113, 0.07546164997620508, 0.04053066986671183, 0.00947720820477116, 0.09789359042770229, 0.037597346017719246, 0.08409609290538356, 0.13948873383924365, 0.04868659823841881, 0.0210877829886158, 0.060758888139389455, 0.04320745181757957, 0.03942495146475267, 0.08485211874358356, 0.10531163847190328, 0.02058477755781496, 0.057678830562508665, 0.08013751430553384, 0.03593224122596439, 0.03494361888442654, 0.04018307758087758, 0.04312955970817711, 0.0348776976170484, 0.13795409118756652, 0.03785445565881673, 3.6462774546816945, 42.131417244672775, 61.849759966135025, 74.02185201644897, 59.11576487123966, 39.378901943564415, 34.85474310815334, 34.702329486608505, 34.73341941833496, 30.930239595472813, 17.268621772527695, 25.89689288288355, 19.16961796581745, 37.70760342478752, 34.049817100167274, 32.335303500294685, 46.071999594569206, 69.56029862165451, 73.40603426098824, 63.022365644574165, 103.57818603515625, 70.40101870894432, 88.0525915324688, 101.27658113837242, 93.10161620378494, 116.39006495475769, 103.86727452278137, 111.63454413414001, 114.39611434936523, 103.45228359103203, 87.97079712152481, 88.62351089715958, 95.3629432618618, 86.20028972625732, 76.0216923058033, 64.97451469302177, 62.482547610998154, 80.12207508087158, 57.576657459139824, 52.762642577290535, 75.20102754235268, 76.56614229083061, 48.78866381943226, 40.52026949822903, 33.782759830355644, 40.583114326000214, 29.243116825819016, 38.15894700586796, 52.23031394183636, 56.85998171567917, 67.91641563177109, 72.95553803443909, 85.17680704593658, 78.29858332872391, 85.23080974817276, 80.52366033196449, 49.73108544945717, 12.480548098683357, 0.2963302459102124, 0.12584298325236887, 0.06389784626662731, 0.041217393954866566, 0.018953061990032438, 0.03198682461516, 0.023581093046232127, 0.04435528338945005, 0.030296757686301135, 0.01403759713866748, 0.036093046073801816, 0.02701760415220633, 0.048392755998065695, 0.03785526459978428, 0.07654837681911886, 0.1321147396811284, 0.0455575663363561, 0.00835811630167882, 0.00527697194229404, 0.039180239400593564, 0.05443206806376111, 0.059973580864607356, 0.041429340199101716, 0.03739817955647595, 0.061393164651235566, 0.028448188422771636, 0.031234743291861378, 0.009549885799060576, 0.029339659922698047, 0.023696465468674432, 0.04047533904667944, 0.0775877917476464, 0.04485723125981167, 0.05517193363630213, 0.04651330782508012, 0.08718149765627459, 0.032250632139039226, 0.029740011486865114, 0.049205196191906, 0.023039024672470987, 0.011850333939946722, 0.04001430206699297, 0.05762882465205621, 0.08163855993188918, 0.05776381389296148, 0.010453796621732181, 0.06614762984099798, 0.05763582681538537, 0.030103062708803918, 0.11038534590625204, 0.03175440993800294, 0.02626673067425145, 0.016963037523964886, 0.02017828472162364, 0.06478977418737486, 0.05566609266679734, 0.039769508366589434, 0.04999871533073019, 0.018231072899652645, 0.01462214511775528, 0.05781728192232549, 0.04861614987021312, 0.009719515710457927, 0.02953113587864209, 0.11123375428724103, 0.08105954373604618, 0.0481441031297436, 0.08872266378602944, 0.01657815602811752, 0.008721862359379884, 0.08206243015592918, 0.027949172035732772, 0.0359199995000381, 0.10615139341098256, 0.004848244361710385, 0.05285899700538721, 0.003589843222471245, 0.08072035256191157, 0.019251910016464535, 0.038566850635106675, 0.0505183040513657, 0.010533188797126058, 0.04154639544140082, 0.03645829034212511, 0.03905205194314476, 0.015531650806224206, 0.032964066122076474, 0.031794022070243955, 0.03091406684688991, 0.05286110841552727, 0.059486041791387834, 0.041760883541428484, 0.028248443086340558, 0.05408885073848069, 0.04221940464049112, 0.016206623913603835, 0.02382919301453512, 0.028368175626383163, 0.02044500331976451, 0.04562099027680233, 0.00899799417311442, 0.03362527146236971, 0.04873762089118827, 0.028373123896017205, 0.10295254396623932, 0.13214084843639284, 0.10897177722654305, 0.08717322270967998, 0.018044949683826417, 0.03718845975527074, 0.11475332285044715, 0.02380751488090027, 0.09438869412406348, 0.05016338676796295, 0.12549163569929078, 0.03540142010024283, 0.11825890192994848, 0.014288168458733708, 3.9287702087312937, 49.43274065852165, 76.52832671999931, 86.05675622820854, 68.76220464706421, 49.82375867664814, 47.546571269631386, 60.49875006079674, 57.00734540820122, 39.73478324711323, 34.843476712703705, 36.876139640808105, 27.84241508692503, 34.44281481206417, 33.05524706840515, 35.157457664608955, 42.48703636229038, 58.232737854123116, 54.637891352176666, 55.85918381810188, 59.550932720303535, 56.15472815930843, 57.687106132507324, 55.591510981321335, 57.28245824575424, 71.84107303619385, 70.35952493548393, 58.495163172483444, 58.526180908083916, 54.93072263896465, 65.10850310325623, 56.89537301659584, 49.551062509417534, 61.09763592481613, 53.35971213877201, 50.174213871359825, 46.39136105775833, 45.52819937467575, 40.76293587684631, 42.04356975853443, 70.11487886309624, 49.337396174669266, 54.911111891269684, 52.469260320067406, 40.49867905676365, 57.5435346364975, 44.33653771877289, 51.464187651872635, 79.37593191862106, 88.05301710963249, 85.10334938764572, 90.05484089255333, 94.37701016664505, 89.58495050668716, 99.11069735884666, 95.92586025595665, 60.33734992146492, 17.516493871808052, 0.5983340030070394, 0.28248372953385115, 0.06407379463780671, 0.038102700345916674, 0.018138222803827375, 0.08691669936524704, 0.043084522476419806, 0.018820258374034893, 0.08691532639204524, 0.03515056676405948, 0.019674388713610824, 0.004488806471272255, 0.048144867541850545, 0.03587496968975756, 0.0894838772364892, 0.023180349999165628, 0.03774034674279392, 0.04748325030959677, 0.04521896888036281, 0.02199530899815727, 0.025316456958535127, 0.0552269601757871, 0.038170788684510626, 0.027164202438143548, 0.07428583572618663, 0.11813660341431387, 0.1071998180123046, 0.07480734289856628, 0.04986317318980582, 0.02873528268537484, 0.06636424048338085, 0.04648980400816072, 0.03125148985418491, 0.024183062014344614, 0.09207189461449161, 0.046337942039826885, 0.01250934994459385, 0.04724775571958162, 0.06534356478368863, 0.0718279168359004, 0.03884841033141129, 0.05709961769753136, 0.029675600490008947, 0.009399855080118868, 0.036902202264172956, 0.023743070487398654, 0.048514204754610546, 0.043517168596736155, 0.013459810124913929, 0.010605178977129981, 0.00909985672478797, 0.01881483698525699, 0.021937738747510593, 0.020390774589031935, 0.01183901618787786, 0.017358630066155456, 0.027024665687349625, 0.031972794313333, 0.03541844125720672, 0.040619794381200336, 0.032472089005750604, 0.021543788207054604, 0.10621404551784508, 0.27991720475256443, 0.24586957704741508, 0.26232278323732316, 0.10591026220936328, 0.22509211383294314, 0.05940241659118328, 0.09364690267830156, 0.15309230075217783, 0.15768653625855222, 0.1409240474458784, 0.2074956291471608, 0.22478200000477955, 0.22185109555721283, 0.09406157027115114, 0.1493211812339723, 0.16591478692134842, 0.1683900275384076, 0.15284109860658646, 0.12901192414574325, 0.17002248525386676, 0.3110421064775437, 0.18103543727193028, 0.12542294251034036, 0.11147087789140642, 0.107296445639804, 0.2074185200035572, 0.12152487121056765, 0.15872601798037067, 0.13031192938797176, 0.14399644976947457, 0.25008761789649725, 0.1893797895172611, 0.2034251717850566, 0.09843633786658756, 0.2475694366148673, 0.28456649277359247, 0.2221161758643575, 0.20596282702172175, 0.14823901117779315, 0.12262514224858023, 0.24823763669701293, 0.26938488241285086, 0.2031691902084276, 0.15822524641407654, 0.3340818436117843, 0.14654538565082476, 0.1430441258708015, 0.14541947341058403, 0.17298496066359803, 0.2745979354949668, 0.12695516576059163, 0.25672369461972266, 0.1638099818956107, 0.3234061086550355, 0.2045713594998233, 7.554996851831675, 64.82437714934349, 92.22145423293114, 98.08915257453918, 80.5144952237606, 60.922997295856476, 56.57878540456295, 55.90851657092571, 57.23730146884918, 44.64544214308262, 25.84669567644596, 40.301754623651505, 34.334307834506035, 58.66203501820564, 50.11325754225254, 46.477639228105545, 65.57118147611618, 91.84065386652946, 93.28735783696175, 91.83092638850212, 136.91613793373108, 97.96855464577675, 120.86547240614891, 133.30820113420486, 125.99716544151306, 155.64876794815063, 138.99827420711517, 148.53769272565842, 150.21398037672043, 137.59713739156723, 122.89019376039505, 120.22201493382454, 131.14705950021744, 117.18283921480179, 102.36842975020409, 95.6773915886879, 92.67211765050888, 112.13314577937126, 85.06836846470833, 79.4745822250843, 100.06627008318901, 99.69863221049309, 68.61978828907013, 59.33352738618851, 47.724960297346115, 57.263869643211365, 40.7493744045496, 54.5700041949749, 69.49766278266907, 79.2728890478611, 95.32344818115234, 99.69423204660416, 108.44334617257118, 101.34409591555595, 114.34993922710419, 112.48365417122841, 79.48137626051903, 26.503334641456604, 1.3038424425758421, 0.28071848675608635, 0.24883503589080647, 0.16156189783941954, 0.09722530870931223, 0.20212681411067024, 0.09939508134266362, 0.10802891571074724, 0.16343503404641524, 0.1775882503716275, 0.10282021161401644, 0.11678921204293147, 0.20654348336393014, 0.13440653623547405, 0.17343390063615516, 0.1998251469922252, 0.16703673609299585, 0.12647879600990564, 0.1506351536954753, 0.07243935746373609, 0.14969504554755986, 0.20169019378954545, 0.1848174218321219, 0.09076266447664239, 0.18234037037473172, 0.23866464413003996, 0.2832893456798047, 0.19899253151379526, 0.08677841498865746, 0.12207663574372418, 0.10886848511290736, 0.14111124677583575, 0.198863071273081, 0.14003479125676677, 0.19818305619992316, 0.152813401655294, 0.14665412512840703, 0.1408235012786463, 0.149977685068734, 0.1416350100771524, 0.13282071508001536, 0.12649968004552647, 0.18075682019116357, 0.20612831111066043, 0.1722437480930239, 0.0631373526994139, 0.15763727249577641, 0.11825907262391411, 0.12120554732973687, 0.15478252724278718, 0.06526448152726516, 0.16152308351593092, 0.08679561055032536, 0.13769102952210233, 0.13867680943803862, 0.23794624517904595, 0.09811720694415271, 0.07346957718254998, 0.09367100021336228, 0.16035678359912708, 0.11861460588988848, 0.1101265664328821], [0.03782962710829452, 0.0106658161530504, 0.02875568618037505, 0.031798486088518985, 0.057412180613027886, 0.028312028443906456, 0.07202212946140207, 0.022395462037820835, 0.028048575295542832, 0.04048759561555926, 0.04181732016149908, 0.04328522518335376, 0.05333637607691344, 0.04211402338114567, 0.0594023683515843, 0.022229590176721103, 0.1180438869050704, 0.03108457527559949, 0.004694347517215647, 0.02824087132466957, 0.030292250994534697, 0.07155610524932854, 0.04954620933858678, 0.02202606359787751, 0.022215507924556732, 0.05747154129494447, 0.021991401590639725, 0.025016228537424468, 0.055704038677504286, 0.05835778807522729, 0.09704489260911942, 0.0639317549939733, 0.038524585324921645, 0.023022955319902394, 0.05285839215503074, 0.045331448782235384, 0.03861661163682584, 0.03183549328241497, 0.04352654934336897, 0.04047812952194363, 0.0022775185607315507, 0.023666538363613654, 0.025200800664606504, 0.05039344512624666, 0.010825065273820655, 0.06408644083421677, 0.07476162660168484, 0.039092198421712965, 0.056312009764951654, 0.04355559329269454, 0.03964275696489494, 0.12990582617931068, 0.6541613198351115, 0.12864462041761726, 4.450940089300275, 30.76735943555832, 67.17404946684837, 81.88606962561607, 72.20377877354622, 75.49045041203499, 56.37777999043465, 29.83297247439623, 22.341454066336155, 28.895479179918766, 34.18913282454014, 45.19456207752228, 82.29897066950798, 68.96330505609512, 79.51624318957329, 67.5622746348381, 98.57900708913803, 97.19575971364975, 82.35354334115982, 54.96927537024021, 36.58001393079758, 38.353754952549934, 44.89019840955734, 38.933953419327736, 44.907248094677925, 79.93148490786552, 65.65992951393127, 62.40162715315819, 59.67869706451893, 75.22292956709862, 85.06944000720978, 71.21390908956528, 77.91521430015564, 75.03934621810913, 82.43441060185432, 74.69213604927063, 93.11278000473976, 73.62709879875183, 81.81069687008858, 93.61302316188812, 86.09826520085335, 75.5658307671547, 71.92988187074661, 75.88865384459496, 84.17793184518814, 75.08384943008423, 89.84963670372963, 90.39488464593887, 94.82258945703506, 73.53259027004242, 41.36045761406422, 27.815400436520576, 27.168789133429527, 31.0431220382452, 53.45123402774334, 76.5320885181427, 70.63962310552597, 76.00833222270012, 83.12009900808334, 72.97327548265457, 39.03046824038029, 8.146872092038393, 0.42025952716358006, 0.13784725160803646, 0.03336055851832498, 0.02587094702903414, 0.00889416678546695, 0.05356484623916913, 0.021829661636729725, 0.028324776685622055, 0.03292848756245803, 0.021105715131852776, 0.010647954513842706, 0.049895378688233905, 0.05615403992123902, 0.06372649178956635, 0.0842135600396432, 0.01673256356298225, 0.03017819773958763, 0.02108223914547125, 0.05287297535687685, 0.03150691853079479, 0.007737813966741669, 0.03958584537031129, 0.04224771757435519, 0.05424434180895332, 0.06764831923646852, 0.017865964073280338, 0.05937509813520592, 0.04128105167183094, 0.05019328789785504, 0.06149943648779299, 0.019691385750775225, 0.06541814320371486, 0.03241998281737324, 0.04137615418585483, 0.016707059658074286, 0.12288543570321053, 0.02160470739909215, 0.020459666302485857, 0.04677825083490461, 0.06312406083452515, 0.019167127065884415, 0.08930372830945998, 0.052240665536373854, 0.04256198000803124, 0.009149476718448568, 0.06332591015961953, 0.0676357101474423, 0.001799908263819816, 0.052866600308334455, 0.04090703521796968, 0.016521875259059016, 0.04421616409672424, 0.04614801531715784, 0.040782187425065786, 0.03594426772906445, 0.02752734457317274, 0.02616202848003013, 0.011326917592668906, 0.043371748470235616, 0.022480783045466524, 0.03318119255709462, 0.0627638965670485, 0.04487841586524155, 0.011854631902679102, 0.08800100680673495, 0.0046554385698982514, 0.03733041034138296, 0.013347530602914048, 0.022971841754042543, 0.02675575033208588, 0.07376433597528376, 0.02672536124009639, 0.031350748395198025, 0.0725343672093004, 0.030473874940071255, 0.01908363545226166, 0.13349379849387333, 0.05429010263469536, 0.09381904383189976, 0.03621973068220541, 0.013452208677335875, 0.03777107907808386, 0.041152934718411416, 0.024553785187890753, 0.04227078352414537, 0.059544949763221666, 0.04465624653676059, 0.02885848476580577, 0.029684782712138258, 0.06825465388828889, 0.07551800867076963, 0.0220784295379417, 0.027926074544666335, 0.04794479194970336, 0.03262950966018252, 0.04501687464653514, 0.05782689644547645, 0.025405613014299888, 0.06728377629769966, 0.089016762067331, 0.0206362918834202, 0.06396619064616971, 0.05897361479583196, 0.05951202067080885, 0.0579823392763501, 0.08648271366837434, 0.07425240939483047, 0.030021465427125804, 0.07588672247948125, 0.04307745351979975, 0.07899402058683336, 0.05317820585332811, 0.3308461687993258, 0.23078328813426197, 5.589702408760786, 36.38433963060379, 78.54113191366196, 95.63494026660919, 84.42554175853729, 85.60417011380196, 73.15238267183304, 52.512992173433304, 35.85734970867634, 30.675727352499962, 35.076974183321, 33.63324165344238, 38.9647925645113, 40.31412675976753, 52.723402082920074, 50.993195325136185, 64.47839051485062, 63.150992542505264, 56.52694098651409, 46.4008529484272, 39.77431632578373, 36.616792157292366, 44.82476972043514, 38.317208513617516, 40.70910036563873, 55.654804185032845, 50.315995663404465, 48.645738288760185, 48.285624012351036, 52.620328813791275, 55.21373525261879, 51.94168522953987, 52.0920317620039, 53.90195444226265, 60.43718956410885, 55.17060376703739, 58.29156629741192, 56.72855816781521, 58.01067776978016, 70.55596679449081, 70.37200346589088, 57.04678349196911, 56.45917922258377, 64.1035558283329, 58.224385902285576, 57.316101640462875, 70.10221034288406, 68.0632321536541, 61.22103810310364, 61.59820966422558, 45.59407263994217, 34.953830391168594, 44.92834076285362, 61.46679371595383, 82.89323598146439, 94.42401364445686, 87.18927785754204, 90.28632447123528, 96.77257642149925, 90.31540051102638, 50.84942243993282, 12.706946600228548, 0.5512168875429779, 0.06744433994754218, 0.04683395643951371, 0.05017042232793756, 0.10641456639859825, 0.052153266515233554, 0.051271116390125826, 0.035468695787130855, 0.032076405550469644, 0.028381155789247714, 0.019467329511826392, 0.010204262453044066, 0.10064557049190626, 0.05589446263911668, 0.036433335626497865, 0.026475986633158755, 0.039569247237523086, 0.0236766649686615, 0.03137316496577114, 0.06753681896952912, 0.052580750998458825, 0.03534553266945295, 0.03205364017048851, 0.01849083386332495, 0.050062866575899534, 0.020905129313177895, 0.028026613290421665, 0.026926815371552948, 0.03391668687982019, 0.05416610831161961, 0.032480890877195634, 0.06527383258799091, 0.07512693395256065, 0.06933695753104985, 0.00646709387183364, 0.07259747202624567, 0.05782833992270753, 0.04433099660673179, 0.013606851844087942, 0.053644575164071284, 0.026472684075997677, 0.07082812517182902, 0.050956679551745765, 0.0454536137112882, 0.03441761429712642, 0.012018448942399118, 0.013704246666748077, 0.021254074163152836, 0.016759306854510214, 0.02577130071585998, 0.011681453597702784, 0.042873678321484476, 0.02393688977463171, 0.024011073001020122, 0.04714981449069455, 0.051030170725425705, 0.08890224125934765, 0.027378427075746004, 0.036020760890096426, 0.03563183097867295, 0.16935173218371347, 0.13961757067590952, 0.13457190158078447, 0.10613230537273921, 0.27389880269765854, 0.09165697469143197, 0.09362397773656994, 0.11648299449007027, 0.1683068327838555, 0.16811363690067083, 0.15223313122987747, 0.0851579949085135, 0.1624756003729999, 0.13263047294458374, 0.15201491012703627, 0.11787593888584524, 0.3373254742473364, 0.1615764290909283, 0.12388573202770203, 0.11088685962022282, 0.08446370833553374, 0.1935864903498441, 0.14955516555346549, 0.11718568959622644, 0.10569584090262651, 0.174111436936073, 0.13411754393018782, 0.1935130771016702, 0.18385672650765628, 0.17307655652984977, 0.23358905164059252, 0.18995934748090804, 0.12034953193506226, 0.1029816287336871, 0.15623226820025593, 0.13105916819768026, 0.09087728918530047, 0.16859630006365478, 0.1387854153290391, 0.1795178046450019, 0.04938894082442857, 0.18760773382382467, 0.2064591902308166, 0.14414245990337804, 0.18820293626049533, 0.1843255857238546, 0.1867180917179212, 0.20202046434860677, 0.21643022628268227, 0.13919904391514137, 0.18703157489653677, 0.23496529029216617, 0.9048224694561213, 0.6587249937001616, 10.647155977785587, 50.58358870446682, 95.46520337462425, 108.74168336391449, 91.95091634988785, 98.35863411426544, 78.70123252272606, 50.52077807486057, 42.78681367635727, 52.2126030921936, 57.53721557557583, 70.17479404807091, 116.80740416049957, 96.58469930291176, 106.52060374617577, 96.14975184202194, 129.21781182289124, 133.86602640151978, 113.26413989067078, 76.47942334413528, 58.65836061537266, 53.54450762271881, 64.63827833533287, 55.09350210428238, 64.92181152105331, 109.08673524856567, 93.12557011842728, 87.2188250720501, 80.99081486463547, 102.33349442481995, 119.31499600410461, 98.81612956523895, 106.48927822709084, 104.26785662770271, 112.73295879364014, 102.17458695173264, 128.4018436074257, 100.49437031149864, 115.75616776943207, 131.1501905322075, 121.46970838308334, 101.54806137084961, 98.69467288255692, 102.7666787803173, 113.04800748825073, 103.85578393936157, 118.74846920371056, 116.67523965239525, 129.86788094043732, 102.03740671277046, 59.62309084832668, 41.715563759207726, 44.49902459979057, 47.18281298875809, 72.78268530964851, 99.8099434375763, 95.82361534237862, 97.99005389213562, 107.19393521547318, 106.76299273967743, 66.31691426038742, 18.321723863482475, 1.4572125440463424, 0.2563000767258927, 0.1648917215061374, 0.1621327578322962, 0.14649545395513996, 0.19286294089397416, 0.11615653857006691, 0.11378169569070451, 0.1291600419790484, 0.2041855317656882, 0.05768190305388998, 0.10278576854034327, 0.18932148639578372, 0.10911789126112126, 0.20134470920311287, 0.19251919293310493, 0.09229061295627616, 0.13756597763858736, 0.16055624320870265, 0.1109990278200712, 0.1361401189933531, 0.2507695625536144, 0.13944070204161108, 0.14629305544076487, 0.1662841983488761, 0.08669591785292141, 0.1197072996001225, 0.14307817560620606, 0.1684036385267973, 0.1097993906296324, 0.25446620013099164, 0.20920065406244248, 0.12557597336126491, 0.19364599575055763, 0.15047302411403507, 0.2830187586368993, 0.13396599737461656, 0.08605855400674045, 0.20352828578324988, 0.1724877959350124, 0.1672453834908083, 0.2295920075266622, 0.15199712826870382, 0.15854046621825546, 0.17755896522430703, 0.13572718802606687, 0.2300131763331592, 0.09317055519204587, 0.19229895318858325, 0.15190726902801543, 0.17781459057005122, 0.1314138702582568, 0.08537775225704536, 0.07996639731572941, 0.14649178774561733, 0.08532080726581626, 0.19068748340941966, 0.11792970006354153, 0.10269129314110614, 0.1705629617208615], [0.02162387150747236, 0.04380750047857873, 0.04289914511900861, 0.04420760342327412, 0.063497947412543, 0.07600547352922149, 0.009835985583777074, 0.05554454372031614, 0.041946654237108305, 0.06730779961799271, 0.01576930040755542, 0.01592365042597521, 0.026310372668376658, 0.03218041754735168, 0.047031375142978504, 0.041399891779292375, 0.025913299541571178, 0.04097362070751842, 0.025937144746421836, 0.07972223073011264, 0.02653155865118606, 0.022717808315064758, 0.05294784321449697, 0.02325753892364446, 0.011154124276799848, 0.0360627293412108, 0.06493922046502121, 0.05334915214916691, 0.012985090725123882, 0.0801886037515942, 0.019206147335353307, 0.07231710347696207, 0.04028520452266093, 0.00438497351751721, 0.02923518779425649, 0.08996826960355975, 0.06019049949827604, 0.007437657905029482, 0.0940136869030539, 0.021135961360414512, 0.007721628189756302, 0.02819260389514966, 0.062436230946332216, 0.06244878066354431, 0.036650239417213015, 0.01823983580834465, 0.048215204587904736, 0.020156704922555946, 0.06734239854267798, 0.07128835321054794, 0.41666584031190723, 0.8549973461776972, 7.562307184562087, 34.35972087085247, 67.9361517727375, 81.98764577507973, 73.10276493430138, 58.434073850512505, 49.062499925494194, 44.262255504727364, 26.015587113797665, 44.59588520228863, 29.984092265367508, 66.24814555048943, 66.99136286973953, 51.90168857574463, 67.60432317852974, 58.46908517181873, 52.152011543512344, 43.108508214354515, 34.03708018362522, 17.42598842829466, 8.250784166157246, 3.8357143895700574, 0.39474885386880487, 0.04927476140437648, 0.14169304602546617, 0.17694923153612763, 0.8134930639062077, 1.4594406494870782, 2.08859093952924, 1.6845712065696716, 1.3388652820140123, 1.1158368433825672, 1.1350767547264695, 0.5243789276573807, 2.02698128297925, 1.863204489927739, 0.939102330012247, 3.2712109806016088, 4.773422135040164, 4.024698911234736, 4.73767127841711, 1.80195237044245, 3.8354227552190423, 1.6659267945215106, 3.5896866163238883, 1.1228180187754333, 4.435767978429794, 6.1840104684233665, 16.109512969851494, 31.214361749589443, 35.905641317367554, 40.587609484791756, 92.58083134889603, 87.51288369297981, 48.327015191316605, 33.24774473905563, 20.210904590785503, 26.650354452431202, 41.6309878975153, 62.1172010153532, 67.41876393556595, 77.53633663058281, 80.08790731430054, 71.26183211803436, 43.60271729528904, 10.937619991600513, 0.6631193391513079, 0.0692048626660835, 0.06836650296463631, 0.04438065370777622, 0.039140352673712187, 0.03764176355616655, 0.043179907006560825, 0.019031004194403067, 0.06296276987995952, 0.06268368524615653, 0.0829925415746402, 0.019121876466670074, 0.0749280680611264, 0.02546343188441824, 0.04790560284163803, 0.037965005976730026, 0.05869099382834975, 0.03241560043534264, 0.045125473116058856, 0.13602612511022016, 0.020067161094630137, 0.06297958694631234, 0.02818140488670906, 0.016378061882278416, 0.029712995456065983, 0.0620301574235782, 0.055476299530710094, 0.0846076849848032, 0.09812928910832852, 0.022291925015451852, 0.05010923596273642, 0.024113220351864584, 0.02200442999310326, 0.0150380882769241, 0.04179266601568088, 0.02959372675832128, 0.016347292439604644, 0.03414918319322169, 0.07142288231989369, 0.08169458465999924, 0.05096553337352816, 0.02092358838126529, 0.04278106942365412, 0.03197963691491168, 0.061059380022925325, 0.08803684511804022, 0.04247789467626717, 0.06561003290698864, 0.036696716415463015, 0.01947088439919753, 0.024309837535838597, 0.0710929160413798, 0.04208558428217657, 0.0418551622715313, 0.08010586912860163, 0.01392236943502212, 0.029624037924804725, 0.17184631316922605, 0.04498581576626748, 0.020406394942256156, 0.06525359422084875, 0.04749272753542755, 0.010785623835545266, 0.08228376085753553, 0.05121404894453008, 0.0693187303841114, 0.08154483410180546, 0.04738130148325581, 0.09535621720715426, 0.029069692573102657, 0.048848423539311625, 0.0567256457725307, 0.05555366471526213, 0.0061064481360517675, 0.025458593081566505, 0.09329197055194527, 0.013018398312851787, 0.037414662656374276, 0.06135963441920467, 0.03504582375171594, 0.051079516124445945, 0.026664909601095133, 0.028611965572054032, 0.030692558029841166, 0.057225790224038064, 0.07947498423163779, 0.05443444664706476, 0.07045019388897344, 0.07403962823445909, 0.03596484377339948, 0.024044599522312637, 0.034006638888968155, 0.08877889631548896, 0.011303375740681076, 0.04942593688610941, 0.03097683955274988, 0.03909964216290973, 0.02640102229634067, 0.03185232148098294, 0.015560781030217186, 0.10246244448353536, 0.06515102941193618, 0.05862598540261388, 0.08422412822255865, 0.034669788656174205, 0.10183592341491021, 0.011518420451466227, 0.06203156379342545, 0.23786793375620618, 0.9424557688180357, 8.087715916335583, 41.774946972727776, 80.69548711180687, 95.08440300822258, 85.17800778150558, 78.9194244146347, 73.77614200115204, 72.6385286450386, 45.42518690228462, 47.30343371629715, 39.07933361828327, 53.93675297498703, 58.47752831876278, 54.8382394015789, 66.77856668829918, 58.24988633394241, 56.928237453103065, 48.07106852531433, 36.46885469555855, 20.865972340106964, 9.680325407534838, 4.250187361612916, 0.9212288609705865, 0.46700743900146335, 0.2953129692468792, 0.33767594606615603, 1.0260245064273477, 1.8758115009404719, 1.7785468138754368, 2.521075657568872, 1.8670805194415152, 1.5572029910981655, 1.8010962288826704, 0.8290691999718547, 1.99121308978647, 1.5518138115294278, 1.4198506926186383, 3.0398546950891614, 3.421210781671107, 2.5634692702442408, 3.4157820604741573, 2.6206110790371895, 3.6075739189982414, 2.212045839987695, 2.963202833198011, 1.6022080136463046, 5.082820532843471, 7.308262316510081, 15.237234625965357, 25.21387193351984, 35.680397003889084, 46.79238773882389, 64.81050789356232, 64.98863473534584, 50.938014686107635, 29.817704893648624, 30.917101800441742, 54.78941962122917, 67.56699398159981, 75.89851811528206, 80.02727776765823, 85.50634056329727, 94.74306732416153, 84.72277700901031, 56.70913740992546, 16.768716797232628, 0.09461334222578444, 0.07830970105715096, 0.07052334738546051, 0.03829390356258955, 0.035524457052815706, 0.06458247007685713, 0.13080876757157966, 0.029274972475832328, 0.02467868307576282, 0.026443879469297826, 0.051642357211676426, 0.05169278614630457, 0.057947706955019385, 0.12338899774476886, 0.07996659027412534, 0.03436402010265738, 0.004556681442409172, 0.03258767108491156, 0.041230144051951356, 0.045362329547060654, 0.04922449203149881, 0.049743141935323365, 0.026161816967942286, 0.03977654021582566, 0.034867827052948996, 0.021568431220657658, 0.05314453832397703, 0.07019574855803512, 0.037448515722644515, 0.09223116692737676, 0.007511382855227566, 0.07616900576977059, 0.030862956991768442, 0.03774450648052152, 0.029130487455404364, 0.1140004288754426, 0.023962774030223954, 0.06563734394148923, 0.024105106822389644, 0.04277397078112699, 0.01765281554980902, 0.007031189188637654, 0.02655276737641543, 0.04577146813971922, 0.026258357393089682, 0.013364081423787866, 0.037187520938459784, 0.0349234435998369, 0.03324098368466366, 0.0201704810388037, 0.03009922209457727, 0.07309161621378735, 0.06165470491396263, 0.029353300596994814, 0.06076760095311329, 0.0057592631037550746, 0.054532328504137695, 0.02400354391284054, 0.1706715824548155, 0.10155772193684243, 0.14678708830615506, 0.11952751432545483, 0.0908288120990619, 0.2288803324336186, 0.13421691750409082, 0.28446746058762074, 0.2986936300294474, 0.14908323384588584, 0.1655411155661568, 0.12482874939450994, 0.20163333043456078, 0.13934465328929946, 0.09889410939649679, 0.10973555850796402, 0.1237160548043903, 0.17152880755020306, 0.12657503772061318, 0.17303775704931468, 0.14327670010970905, 0.1466642034938559, 0.14941206463845447, 0.11525552676175721, 0.12395234720315784, 0.21646411274559796, 0.19790164864389226, 0.22070122678996995, 0.09672824045992456, 0.17134145979071036, 0.09552669594995677, 0.17385732557158917, 0.21804125077323988, 0.14994351658970118, 0.20078962726984173, 0.19432823726674542, 0.11523399705765769, 0.1019952773640398, 0.16864703327883035, 0.12306318749324419, 0.1275378407444805, 0.19992140354588628, 0.24623223493108526, 0.12761756224790588, 0.13821103755617514, 0.22721765446476638, 0.16671566816512495, 0.22589716594666243, 0.21162051561987028, 0.2767230605240911, 0.5872795649338514, 1.3527684984728694, 13.450644593685865, 56.200477704405785, 98.93928095698357, 104.41100254654884, 93.04886743426323, 77.92064040899277, 69.24517393112183, 61.25540725886822, 41.379749178886414, 65.64475312829018, 51.276416927576065, 95.15479043126106, 95.75149521231651, 79.49833855032921, 102.31850042939186, 84.8674276471138, 74.80701148509979, 61.56301215291023, 50.139810517430305, 27.182149216532707, 12.023258786648512, 6.46081374026835, 0.8809944230597466, 0.6789985683280975, 0.6444737396668643, 0.8782446174882352, 1.61916519748047, 2.2704209201037884, 3.829685300588608, 3.821131009608507, 2.9253148287534714, 2.2457609558478, 2.197832465171814, 1.2121186894364655, 4.053432494401932, 3.9379569282755256, 1.8978201574645936, 6.13221924751997, 7.2227678541094065, 5.995498783886433, 7.366381622850895, 2.86973022390157, 6.047304728999734, 3.752812100574374, 6.157943867146969, 2.3996873712167144, 6.842273846268654, 8.816794194281101, 22.586972191929817, 43.25986549258232, 48.616324067115784, 57.95802399516106, 120.51777586340904, 118.98446694016457, 71.77241832017899, 47.863740250468254, 33.392281383275986, 41.43505901098251, 59.2680075019598, 83.59267204999924, 88.9613051712513, 99.19062227010727, 103.32743749022484, 100.64955398440361, 68.42666745185852, 23.44894263893366, 0.8687230409123003, 0.2696636033942923, 0.14031466998858377, 0.1332497358089313, 0.26980707538314164, 0.23001869791187346, 0.18980012711836025, 0.14696808328153566, 0.13335333962459117, 0.2524383261334151, 0.18028159334789962, 0.16889540042029694, 0.1364730464410968, 0.14907858800143003, 0.22132428945042193, 0.18498734396416694, 0.12002376621239819, 0.1297591332695447, 0.18234593648230657, 0.22274562099482864, 0.09658877606852911, 0.21620517742121592, 0.09629352003685199, 0.17054975149221718, 0.12271145402337424, 0.18534933391492814, 0.20066953293280676, 0.14573537599062547, 0.1136235662852414, 0.1717572851339355, 0.09820152976317331, 0.10805840123794042, 0.12531273358035833, 0.11595054063946009, 0.1585017706383951, 0.1387229116517119, 0.10851904487935826, 0.194011666753795, 0.13454211177304387, 0.17010689713060856, 0.13395597838098183, 0.09863610917818733, 0.14604051742935553, 0.08317637897562236, 0.06836766813648865, 0.16520569450221956, 0.14659641572507098, 0.128138386644423, 0.0954602292040363, 0.04255839914549142, 0.14450724032940343, 0.25976148317568004, 0.1399038318777457, 0.14188039378495887, 0.1871753140585497, 0.11375207657692954, 0.15562943648546934, 0.26442757342010736], [0.04477868234971538, 0.02068204714305466, 0.024966923956526443, 0.027026975621993188, 0.02884875335439574, 0.03129565877316054, 0.03917937108781189, 0.025418326004000846, 0.08827602447126992, 0.03376404936716426, 0.07014627699390985, 0.029741961479885504, 0.016553064015170094, 0.024760373125900514, 0.01955416450073244, 0.0704593668342568, 0.05474015953950584, 0.06494359171483666, 0.06644500841503032, 0.04041872431116644, 0.013927066302130697, 0.018202958490292076, 0.01843743633799022, 0.050644940420170315, 0.02032503514783457, 0.029327058255148586, 0.010404842705611372, 0.006017613522999454, 0.02831619745848002, 0.0252948845809442, 0.03679953355458565, 0.05697053966287058, 0.024143897026078776, 0.009845949844020652, 0.039774042888893746, 0.022663006275251973, 0.0021649846212312696, 0.048352887824876234, 0.023280998211703263, 0.037749764596810564, 0.07177978855906986, 0.05049929764936678, 0.05857853248016909, 0.04651994262530934, 0.056666852833586745, 0.057313756988151, 0.034080564219038934, 0.02620731247588992, 0.06456261020503007, 1.7386947898194194, 21.680530831217766, 46.80135905742645, 70.84724396467209, 81.85991942882538, 75.47987177968025, 72.5282433629036, 60.24314917623997, 23.386606983840466, 24.832596592605114, 25.433004274964333, 49.823428094387054, 60.047315284609795, 46.90141148865223, 31.591793596744537, 31.798335313796997, 23.53275664150715, 17.231902442872524, 12.567359190434217, 6.084828665480018, 1.0630151652731001, 0.25985757645685226, 0.11946604223339818, 0.026818562000698876, 0.08425637453910895, 0.02210964241385227, 0.24816466873744503, 0.22609186096815392, 0.07254663491039537, 0.1924276861245744, 0.31390347168780863, 0.18697515683015808, 0.09512959499261342, 0.04522293937043287, 0.024951487284852192, 0.20087328215595335, 0.04423564547323622, 0.09690122766187415, 0.010001140344684245, 0.2511568448971957, 0.028305924279266037, 0.0761390823754482, 0.0542024067544844, 0.0936504353012424, 0.10813410772243515, 0.04451296750630718, 0.0417274163919501, 0.025821675844781566, 0.12683461129199713, 0.09729881843668409, 0.05191722644667607, 0.20570602908264846, 0.05965938893496059, 1.2146280985325575, 2.9849685402587056, 9.307206328958273, 25.781732462346554, 71.09176844358444, 111.26469478011131, 87.33585879206657, 49.3899055570364, 25.012135058641434, 23.407515361905098, 50.05289778113365, 56.75741761922836, 64.33495581150055, 72.68768280744553, 81.96990072727203, 71.92127913236618, 32.5982341915369, 8.002160657197237, 0.2879547531483695, 0.26655822002794594, 0.09046261417097412, 0.021800445138069335, 0.09713283710880205, 0.0672263340675272, 0.020136358944000676, 0.04614734738424886, 0.08024808688787743, 0.02781388036964927, 0.05978618857625406, 0.09696598746813834, 0.06298996959230863, 0.038566895163967274, 0.06991309419390745, 0.012030201778543415, 0.03672271755931433, 0.050694137389655225, 0.015568195085506886, 0.023237643799802754, 0.00669313164507912, 0.051213759506936185, 0.02099828368955059, 0.03681435795442667, 0.04578881955239922, 0.027448398614069447, 0.026247828172927257, 0.040669562804396264, 0.06409829293261282, 0.030458980036200956, 0.021320394334907178, 0.03394522987946402, 0.02894308403483592, 0.0354670482192887, 0.036919505437253974, 0.019906025991076604, 0.04363232394098304, 0.029947232105769217, 0.034211423408123665, 0.1052179274847731, 0.027482466903165914, 0.03767329741094727, 0.033687155446386896, 0.0456469802884385, 0.015105286965990672, 0.02245608437078772, 0.02575546328444034, 0.05972799306618981, 0.03891570828272961, 0.046825098906992935, 0.03757534876058344, 0.0388486515294062, 0.03795227443333715, 0.03360724098456558, 0.009295839372498449, 0.051836399143212475, 0.05261378399154637, 0.017489144156570546, 0.03059599348489428, 0.007267299297382124, 0.030195450817700475, 0.04663028885261156, 0.005427395535662072, 0.031013911684567574, 0.05190711839532014, 0.04588719122693874, 0.025484091420366894, 0.03715593142260332, 0.018587110826047137, 0.015914761352178175, 0.061054032848915085, 0.018314436492801178, 0.03211838142306078, 0.048800926088006236, 0.06212621730810497, 0.035218410193920135, 0.013486558982549468, 0.030699474846187513, 0.022699879882566165, 0.04658414582081605, 0.03647073244792409, 0.0350530708237784, 0.10004333249526098, 0.028926886661793105, 0.021228588811936788, 0.027422863167885225, 0.12990440125577152, 0.043147556789335795, 0.039834587296354584, 0.027067584087490104, 0.0921911874320358, 0.007009869605099084, 0.01613559667021036, 0.05832402777741663, 0.037361380163929425, 0.13058175944024697, 0.06752118933945894, 0.03466069734713528, 0.012661673899856396, 0.07422954382491298, 0.07490346586564556, 0.03674351995869074, 0.06890197735629044, 0.02623712454806082, 0.06504551085527055, 2.857016106136143, 25.23146688938141, 54.57691602408886, 86.10900342464447, 92.78681829571724, 90.1628614962101, 91.89167752861977, 81.77006185054779, 38.14210630953312, 32.568523585796356, 40.78022114932537, 40.303597524762154, 48.731636479496956, 40.81170625984669, 45.26915967464447, 42.89727374911308, 33.961673229932785, 24.013795629143715, 19.331890158355236, 8.695366010069847, 2.9957948718219995, 0.8840264228638262, 0.11144885094836354, 0.07506972178816795, 0.06513358152005821, 0.18982405395945534, 0.09194590762490407, 0.32602452440187335, 0.1836770970840007, 0.039049472979968414, 0.030991797539172694, 0.05738403837312944, 0.09610719644115306, 0.22283325379248708, 0.18372774124145508, 0.24773692450253293, 0.317901213420555, 0.16617666115052998, 0.08711488248081878, 0.06777147122193128, 0.029625678071170114, 0.049127615784527734, 0.0655580083548557, 0.04436635623278562, 0.042892428682534955, 0.04688101602368988, 0.03714291044161655, 0.025135673495242372, 0.033821695687947795, 0.03511404567689169, 0.12769458233378828, 0.0974508399667684, 0.1459523948142305, 0.595167288556695, 2.675712634809315, 11.62164218723774, 31.714048236608505, 58.68850439786911, 73.99806529283524, 63.001759350299835, 35.97056843340397, 38.11867296695709, 43.85104537010193, 71.70811057090759, 78.16133469343185, 73.4461373090744, 84.76115494966507, 95.24219334125519, 89.56347405910492, 46.41966573894024, 13.782330695539713, 0.2328089505317621, 0.09196858023642562, 0.03424156573601067, 0.03158908170007635, 0.04601341570378281, 0.07060977790388279, 0.056040643466985784, 0.023000030378170777, 0.07382641662843525, 0.08005852752830833, 0.05742208086303435, 0.06428233813494444, 0.07385970195173286, 0.03309307365270797, 0.04137300005822908, 0.034690880493144505, 0.03751334974367637, 0.012123601991333999, 0.048252282285830006, 0.017479878442827612, 0.07601596007589251, 0.07241552710183896, 0.0053421487427840475, 0.042673402349464595, 0.02172610049456125, 0.02673699626029702, 0.04180862590146717, 0.03944014693843201, 0.06928002738277428, 0.04849152101087384, 0.04046816990012303, 0.03894758723617997, 0.004189562787360046, 0.04760785690450575, 0.05620474345050752, 0.03549937988282181, 0.051929824403487146, 0.00843304816953605, 0.06219324437552132, 0.06685664804535918, 0.021975749696139246, 0.06676356788375415, 0.04449347499758005, 0.02034301924140891, 0.03017067792825401, 0.03367679506482091, 0.016035260159696918, 0.02003011122724274, 0.04669305599236395, 0.03863100930175278, 0.055702684257994406, 0.05876077055290807, 0.030607006956415717, 0.041014709713635966, 0.026231165102217346, 0.014802216119278455, 0.11822857035440393, 0.18668341857846826, 0.20485336077399552, 0.14426981244469061, 0.09000672027468681, 0.1399676120490767, 0.1322869921568781, 0.10075382757349871, 0.22666193428449333, 0.15290226641809568, 0.1291659940034151, 0.1374073509941809, 0.1543527643661946, 0.11983189135207795, 0.145103526301682, 0.22945916309254244, 0.1534705882659182, 0.09427521232282743, 0.11178520711837336, 0.129489540704526, 0.08501081218128093, 0.10222056371276267, 0.11605864929151721, 0.09228387425537221, 0.11788439936935902, 0.1201856805710122, 0.1631031752913259, 0.09194961094181053, 0.16238468728261068, 0.13003681524423882, 0.15396579372463748, 0.1615384459728375, 0.11958819974097423, 0.12343534486717544, 0.18340950831770897, 0.07631362808751874, 0.0970493009663187, 0.18866894562961534, 0.17944593506399542, 0.17013137316098437, 0.23416020849253982, 0.23317908926401287, 0.17529553355416283, 0.20647364726755768, 0.1933235622709617, 0.15005667926743627, 0.14868294907500967, 0.0796457078831736, 0.36197050649207085, 4.583667442202568, 34.02905501425266, 71.16357699036598, 99.32109206914902, 105.42407378554344, 94.39407885074615, 92.83036395907402, 78.24874520301819, 34.15757551789284, 36.78802236914635, 35.68568632006645, 70.5157345533371, 87.25323602557182, 67.98342123627663, 53.606432899832726, 51.24229095876217, 40.54383963346481, 28.27925104647875, 21.222452111542225, 11.01430557668209, 3.317110142670572, 1.0129277966916561, 0.4528864467283711, 0.14871391147607937, 0.08926251684897579, 0.34982151933945715, 0.46437020238954574, 0.7723776076454669, 0.5345805489923805, 0.4464750626357272, 0.5462537601124495, 0.4105965862981975, 0.2995846525300294, 0.44489713793154806, 0.27539770351722836, 0.5453734542243183, 0.28063664271030575, 0.2097785347723402, 0.18262933299411088, 0.3962245403090492, 0.14615880092605948, 0.1694012334337458, 0.35560944001190364, 0.13552544260164723, 0.32340272446163, 0.35556891874875873, 0.31049472803715616, 0.16877291636774316, 0.2120734631898813, 0.20767228998010978, 0.31319320667535067, 0.4803815041668713, 0.47952773747965693, 2.749516312032938, 4.376464085653424, 13.738502897322178, 36.10760807991028, 93.05042535066605, 147.89931178092957, 117.84606322646141, 67.41390019655228, 38.19642059504986, 38.37341129779816, 69.29596960544586, 76.12289607524872, 85.40365487337112, 93.987827450037, 102.91838943958282, 105.06151244044304, 60.3902430832386, 19.79739747941494, 0.7559895620215684, 0.37175266596022993, 0.09004722669487819, 0.16816846677102149, 0.21023323381086811, 0.18203711399110034, 0.10631327066221274, 0.17307403322774917, 0.184806423203554, 0.11140806251205504, 0.2206353092333302, 0.17567883798619732, 0.2218983109924011, 0.11309914247249253, 0.15958950680214912, 0.13441058836178854, 0.11580838967347518, 0.08857459790306166, 0.14990903640864417, 0.09363505800138228, 0.10007936376496218, 0.2534055523574352, 0.15174188883975148, 0.1301980542484671, 0.11973282205872238, 0.12469982350012287, 0.08396574208745733, 0.16053059458499774, 0.19285689981188625, 0.1711927037104033, 0.2642170409671962, 0.13091781875118613, 0.1083638469572179, 0.13779121945844963, 0.19617930200183764, 0.16560869553359225, 0.11697786598233506, 0.17186977987876162, 0.14564188022632152, 0.23531510902103037, 0.059374407937866636, 0.1305697811767459, 0.17472593521233648, 0.16775715368567035, 0.17568639304954559, 0.15094851813046262, 0.11071819913922809, 0.14748878893442452, 0.13088730163872242, 0.13774225255474448, 0.1830431990674697, 0.2594270120607689, 0.19678900600410998, 0.10187791413045488, 0.18318567657843232, 0.14992555661592633], [0.032272503231070004, 0.04047842638101429, 0.05042864147981163, 0.06326979637378827, 0.0621133299137, 0.03756130732654128, 0.03403827293368522, 0.031366207331302576, 0.027350412856321782, 0.020721312321256846, 0.04997154159354977, 0.010220832755294396, 0.024863177277438808, 0.018564017045719083, 0.034497951783123426, 0.032734334308770485, 0.08751032102736644, 0.04478815586480778, 0.025290402008977253, 0.06541893730172887, 0.0837459773174487, 0.04270149263902567, 0.02706010694964789, 0.0842482183361426, 0.0425827712751925, 0.045380174487945624, 0.03390764752111863, 0.06023019326676149, 0.017284509922319558, 0.008734529892535647, 0.02833906859450508, 0.06954187934752554, 0.027079233950644266, 0.04850671648455318, 0.04991537585738115, 0.03155712111038156, 0.05149996133695822, 0.0694690746604465, 0.021783013944514096, 0.05882669924176298, 0.042521933719399385, 0.07623770638019778, 0.017425338010070845, 0.06800279865274206, 0.07010604516835883, 0.02478245944075752, 0.1421597826993093, 0.176593356882222, 17.41089753806591, 61.06864348053932, 68.57149288058281, 79.30904030799866, 79.49209928512573, 66.02037817239761, 47.431517243385315, 24.715171493589878, 23.91279324889183, 38.02686609327793, 46.66051961481571, 89.08191069960594, 70.03568351268768, 41.13548308610916, 30.07645770907402, 14.569545853883028, 5.144099369645119, 1.0022096405737102, 0.6227975059300661, 0.030004503641976044, 0.09987600045860745, 0.09319608507212251, 0.0726683322864119, 0.07880935198045336, 0.07696582746575586, 0.13954147085314617, 0.08790721418336034, 0.11259324266575277, 0.017286099973716773, 0.024705023752176203, 0.059119521029060706, 0.13579037447925657, 0.011293507031950867, 0.0973133348452393, 0.026187226249021478, 0.06756856804713607, 0.04511755068961065, 0.22937938221730292, 0.11866427783388644, 0.06800386734539643, 0.13487348071066663, 0.08437827971647494, 0.06793112203013152, 0.1603012264240533, 0.15497521846555173, 0.06600491484277882, 0.08949630821007304, 0.07809899048879743, 0.014605438445869368, 0.0629911050782539, 0.017129081934399437, 0.10276702189003117, 0.01821790348913055, 0.15259952953783795, 0.09639491225243546, 0.06373933094437234, 0.05894384354178328, 1.167219348717481, 6.1326913721859455, 16.16253912448883, 45.08757881820202, 89.43575531244278, 76.48607298731804, 46.16013206541538, 25.056444481015205, 21.81713730096817, 54.39047522842884, 65.22719353437424, 69.19424146413803, 72.6687142252922, 82.77659744024277, 74.75888326764107, 35.73080509901047, 8.332383837550879, 0.5932673311326653, 0.18535443989094347, 0.014875358483550372, 0.061883694579591975, 0.06096685647207778, 0.06676717472146265, 0.03724640664586332, 0.007969380276335869, 0.025097207981161773, 0.07203792978543788, 0.03416837513213977, 0.04647594440029934, 0.05572653317358345, 0.07850245165172964, 0.046031127058085985, 0.03552673173544463, 0.06051596465113107, 0.021525826377910562, 0.08605482842540368, 0.05108188357553445, 0.07975546410307288, 0.028404577969922684, 0.049065063867601566, 0.015468938399862964, 0.05351023901312146, 0.04581933295412455, 0.02006087510380894, 0.08178937176126055, 0.0760944867215585, 0.08418198907747865, 0.04652562005503569, 0.04938637670420576, 0.02665764397534076, 0.043880891462322325, 0.07016897929133847, 0.0531673630757723, 0.06500596180558205, 0.0132284938263183, 0.031544137236778624, 0.028259792379685678, 0.029969409333716612, 0.06198712027980946, 0.029072616634948645, 0.015893218660494313, 0.04839481545786839, 0.023240386035467964, 0.10664387518772855, 0.009989315149141476, 0.017036460048984736, 0.02595578378532082, 0.045597389980684966, 0.026342791534261778, 0.03595206027966924, 0.02239860132249305, 0.048844809280126356, 0.09218709819833748, 0.060155766987008974, 0.02981535617436748, 0.012755558364005992, 0.08457589137833565, 0.03193211719917599, 0.015950428969517816, 0.049887437708093785, 0.020649698781198822, 0.08844476658850908, 0.019407840809435584, 0.04061062143591698, 0.02147419330867706, 0.015805259317858145, 0.02276310529850889, 0.017434082365070935, 0.0331087366794236, 0.04230724152876064, 0.0762467308959458, 0.04064607754116878, 0.017920886712090578, 0.00816805599242798, 0.03493159238132648, 0.032852372896741144, 0.04075414537510369, 0.022895825422892813, 0.02349895214138087, 0.01152771306806244, 0.025036253537109587, 0.030033768380235415, 0.04288760101189837, 0.027612546837190166, 0.0559947156580165, 0.04856848914641887, 0.009521754691377282, 0.061301323876250535, 0.047333188049378805, 0.027285419273539446, 0.04267473079380579, 0.04227847217407543, 0.08849362217006274, 0.02759037888608873, 0.06515088840387762, 0.03365512064192444, 0.10149635374546051, 0.15477399254450575, 0.015865373279666528, 24.680656045675278, 72.86092311143875, 85.1216872036457, 91.73428237438202, 87.82905712723732, 77.48399063944817, 76.08815833926201, 49.97161254286766, 43.20090025663376, 37.514467388391495, 34.72498007118702, 48.646870627999306, 61.14055462181568, 48.34898181259632, 35.92726595699787, 20.212534703314304, 7.504209252074361, 2.070302995853126, 1.0674311220645905, 0.13278138125315309, 0.1399042474804446, 0.13726628356380388, 0.045642994955414906, 0.0233069288515253, 0.23543493618490174, 0.1711606577737257, 0.15295397926820442, 0.2761721791466698, 0.11477556501631625, 0.021977386131766252, 0.42174420843366534, 0.2696478401776403, 0.023506278994318563, 0.13191997044486925, 0.09208170580677688, 0.7177570229396224, 0.993629404110834, 1.980921698268503, 0.9804727882146835, 0.6527780159376562, 0.2761084138182923, 0.3666760789928958, 0.1596697626519017, 0.1657250346033834, 0.21797804947709665, 0.22320207150187343, 0.11937458737520501, 0.08801243588095531, 0.11678651062538847, 0.08853274077409878, 0.06553256753250025, 0.010177173135161866, 0.03803593303018715, 0.11658985633403063, 0.09159671972156502, 0.06300235603703186, 0.061236760739120655, 0.543275373056531, 6.391282696276903, 18.443419933319092, 43.127218410372734, 64.46147382259369, 50.81226423382759, 39.82429124414921, 41.87414065003395, 37.83932715654373, 71.23777940869331, 80.88317424058914, 81.1505126953125, 80.49902245402336, 93.07564839720726, 92.05823019146919, 51.08056403696537, 13.885267172008753, 0.3076393296942115, 0.14693568111397326, 0.04510196558840107, 0.03882561897626147, 0.02384656669164542, 0.026681895506044384, 0.08702713836100884, 0.044278986897552386, 0.04295092847314663, 0.1070472621358931, 0.04081313498318195, 0.0015164941260081832, 0.09563245199387893, 0.02744014036579756, 0.03256474985391833, 0.039785713161109015, 0.027825279757962562, 0.041957912617363036, 0.03698348969919607, 0.03836058924207464, 0.03265955550887156, 0.034812592712114565, 0.01930410897330148, 0.05079609734821133, 0.03443349625740666, 0.014356729916471522, 0.02650314552738564, 0.08855279360432178, 0.04740752527141012, 0.09316843264969066, 0.03414532773604151, 0.049633548987912945, 0.042085899694939144, 0.06516144174383953, 0.057316309976158664, 0.018835765549738426, 0.028475278668338433, 0.03205684253771324, 0.028024154926242772, 0.044652569195022807, 0.0530161133792717, 0.03739393447176553, 0.03206631234206725, 0.05383004900068045, 0.02435894544760231, 0.008614615526312264, 0.026180099775956478, 0.006819534237365588, 0.03562101788702421, 0.03546838408510666, 0.032180673588300124, 0.02579765066911932, 0.04176434194960166, 0.05296341347275302, 0.1292979033314623, 0.16058017004979774, 0.17195006541442126, 0.14418418344575912, 0.11387599297449924, 0.14796852803556249, 0.14656828832812607, 0.1662280029268004, 0.10396710436907597, 0.1135997952951584, 0.1527440850622952, 0.12187453408841975, 0.10104377724928781, 0.13359364704228938, 0.1518791713169776, 0.20683016016846523, 0.1887597399763763, 0.13505616778274998, 0.12268774982658215, 0.1571357884677127, 0.17992692097323015, 0.08990615926450118, 0.10297819258994423, 0.09823423621128313, 0.08277324435766786, 0.1657703352975659, 0.15354553033830598, 0.12961187632754445, 0.1406642363872379, 0.2420430487836711, 0.11820585321402177, 0.1698182907421142, 0.09889085136819631, 0.1541755988728255, 0.1482816252973862, 0.09092154345125891, 0.2383668054244481, 0.22113700106274337, 0.13580619706772268, 0.17182504321681336, 0.1312783095636405, 0.17676914198091254, 0.1068563743319828, 0.13652835128596053, 0.10297630011336878, 0.23076132056303322, 0.3665958676720038, 0.36669418739620596, 30.984513983130455, 86.61986321210861, 95.26325181126595, 101.6693888604641, 100.8389662206173, 85.44990599155426, 64.47925686836243, 33.7163469940424, 36.403722390532494, 54.577178210020065, 72.51065030694008, 126.06952875852585, 98.46068903803825, 64.82914209365845, 48.71744804084301, 23.688751570880413, 9.752222299575806, 2.08123120944947, 2.031005979515612, 0.6245023082010448, 0.35466774366796017, 0.36506707314401865, 0.32908680383116007, 0.4329706763383001, 0.4937204212183133, 0.5375207005999982, 0.28396116744261235, 0.4852278175530955, 0.2521549444645643, 0.13480073539540172, 0.27684732573106885, 0.26715615356806666, 0.11901328762178309, 0.18319780327146873, 0.2842834376497194, 0.3826294338796288, 0.48556561348959804, 0.8269859023857862, 0.4074708087136969, 0.3297203901456669, 0.28151205042377114, 0.391362463706173, 0.1904402146465145, 0.42076632496900856, 0.3835195064311847, 0.25591380370315164, 0.28356883849482983, 0.2553880959749222, 0.2919486357131973, 0.17856291291536763, 0.21465097175678238, 0.21180663141421974, 0.19854725775076076, 0.3779644420137629, 0.15916323201963678, 0.2614227362209931, 0.17046974797267467, 2.355585037730634, 9.74554605782032, 22.766670249402523, 61.585370153188705, 118.14414963126183, 104.13951471447945, 62.746166065335274, 39.98889461159706, 30.383511632680893, 74.31049972772598, 84.30293753743172, 90.07358148694038, 90.23264095187187, 103.63873198628426, 103.65266963839531, 60.94698540866375, 16.407361887395382, 0.8380006800871342, 0.43841664504725486, 0.1096602676261682, 0.1513469178462401, 0.2897671074606478, 0.11740492001990788, 0.14741337188752368, 0.10407663794467226, 0.11142091650981456, 0.21697914839023724, 0.11219688385608606, 0.10285055061103776, 0.2966677746735513, 0.17856727674370632, 0.15505670628044754, 0.15317729150410742, 0.14557508693542331, 0.1136742698145099, 0.19194511201931164, 0.13268859795061871, 0.17125868063885719, 0.13581820501713082, 0.1166700676549226, 0.18004612473305315, 0.16597418842138723, 0.1675142635940574, 0.1493270293576643, 0.18832007684977725, 0.1498525738134049, 0.2059227362042293, 0.1975912824855186, 0.1635855861240998, 0.08853867795551196, 0.1814388093771413, 0.14537049166392535, 0.10730632362538017, 0.13192250858992338, 0.1494640001328662, 0.1356784882955253, 0.2675244666170329, 0.16748454800108448, 0.1681057404493913, 0.147932251857128, 0.22100470581790432, 0.11693802749505267, 0.189043537247926, 0.25946854264475405, 0.08093823227682151, 0.11749429686460644, 0.13280039507662877, 0.14201772079104558, 0.10497520066564903, 0.11068661333411, 0.10377727783634327], [0.04378881320008077, 0.05132813559612259, 0.07318468895391561, 0.024190507610910572, 0.014048691318748752, 0.053576709469780326, 0.022369206708390266, 0.020856073351751547, 0.07124023977667093, 0.04091628608875908, 0.06414222065359354, 0.017322081148449797, 0.10998572164680809, 0.016055852902354673, 0.024975931773951743, 0.08082437198027037, 0.01053755726388772, 0.05601428609224968, 0.03415382532693911, 0.05902634067751933, 0.035588801256380975, 0.03909507053322159, 0.06170285545522347, 0.041627237587817945, 0.08960284350905567, 0.05906172256800346, 0.04334715740696993, 0.07764003152260557, 0.011027282889699563, 0.039328461134573445, 0.04748815961647779, 0.045414547057589516, 0.03270730157964863, 0.07943945020087995, 0.0670059681579005, 0.0696178233192768, 0.07449330310919322, 0.03301492179161869, 0.04465327052457724, 0.05815872922539711, 0.028529173432616517, 0.12934170488733798, 0.03927415447833482, 0.04729226973722689, 0.1175406514084898, 0.12322067865170538, 3.2165872491896152, 28.407910242676735, 76.05981945991516, 75.78697890043259, 85.77858835458755, 69.02076557278633, 59.43421058356762, 40.00805698335171, 17.48823668807745, 18.49494706839323, 40.74445366859436, 49.242477267980576, 40.85085555911064, 56.64397470653057, 20.173638090491295, 5.537158353254199, 0.6099525920581073, 0.06331777622108348, 0.08404342268477194, 0.07679807982640341, 0.021143392114026938, 0.037374679450294934, 0.05888890977075789, 0.06782174430554733, 0.09444886745768599, 0.039462864078814164, 0.17761907918611541, 0.09435461470275186, 0.07661712937988341, 0.15482531947782263, 0.17336137796519324, 0.09041166573297232, 0.16903452342376113, 0.039913024884299375, 0.16482660546898842, 0.1783203790546395, 0.13284749176818877, 0.3570996131747961, 0.7528119231574237, 1.4552571927197278, 0.815117951715365, 0.2428222741582431, 0.15081513935001567, 0.13430391205474734, 0.08438947872491553, 0.18810941081028432, 0.11105088909971528, 0.31283142452593893, 0.03188083108398132, 0.09711282880743966, 0.008985119766293792, 0.10460331788635813, 0.0361828385211993, 0.07359612078289501, 0.03872741428494919, 0.04775712135597132, 0.037891948959440924, 0.019325345529068727, 0.05395545711508021, 0.0465134005935397, 0.04602017295837868, 0.06838256304035895, 1.25051372917369, 9.858192913234234, 51.25115968286991, 81.5817591547966, 64.72800672054291, 40.26195555925369, 25.279783196747303, 33.24652120471001, 49.88870099186897, 78.70545029640198, 72.51396372914314, 69.26515325903893, 81.00998103618622, 74.93991315364838, 39.17190805077553, 5.659918366000056, 0.27600383036769927, 0.23008195857983083, 0.08843495539622381, 0.019094036651949864, 0.04524252835835796, 0.03908002719981596, 0.018250880821142346, 0.08649731171317399, 0.03240018973883707, 0.03648115962278098, 0.028004408231936395, 0.011311209109408082, 0.04321142230764963, 0.11486161703942344, 0.03207530717190821, 0.07635022338945419, 0.05324771540472284, 0.028164159230072983, 0.03550067493051756, 0.03862126490275841, 0.11751208614441566, 0.066937913215952, 0.04654450771340635, 0.052727651709574275, 0.01915074601129163, 0.0862277636770159, 0.03996218474640045, 0.053026251116534695, 0.017467109792050906, 0.07087738893460482, 0.0633589579956606, 0.07334307068958879, 0.02559522989031393, 0.07973078027134761, 0.0654489423322957, 0.04741289099911228, 0.05611820160993375, 0.030480103414447512, 0.05450169264804572, 0.032682565797585994, 0.05154328791832086, 0.0447977555450052, 0.03699769440572709, 0.02659638525074115, 0.032415411187685095, 0.019502273535181303, 0.058820691556320526, 0.041481494627078064, 0.04304169684473891, 0.03839829034404829, 0.0498156163666863, 0.06598009000299498, 0.03165685091516934, 0.008473142697766889, 0.03454530822637025, 0.008860131893015932, 0.01921702907566214, 0.06583226160728373, 0.016802789286884945, 0.044240473143872805, 0.17114974820287898, 0.03162972170684952, 0.04421745914441999, 0.007454405395037611, 0.06514999040518887, 0.02704156438994687, 0.011895193056261633, 0.0242616777177318, 0.019604161134338938, 0.14334493316709995, 0.06227293619303964, 0.09746852534590289, 0.0031704089542472502, 0.09466767485719174, 0.020988938194932416, 0.06700184181681834, 0.01718636089208303, 0.008964936132542789, 0.027758963296946604, 0.01747783197060926, 0.04165591046330519, 0.06544948410009965, 0.05135600695211906, 0.06991854897933081, 0.05012572277337313, 0.11122576877824031, 0.06747235602233559, 0.0094244146021083, 0.06806341727497056, 0.021680612408090383, 0.05642417796480004, 0.07325726357521489, 0.02003482757572783, 0.03377716682734899, 0.06442044439609163, 0.049769903780543245, 0.14902294176863506, 0.10206762191955931, 5.152359176427126, 38.778450563549995, 89.9711161851883, 89.55430895090103, 92.95373573899269, 76.46844193339348, 88.07820215821266, 61.70077756047249, 28.22963710874319, 19.858524799346924, 38.821813836693764, 41.21490262448788, 45.818078219890594, 58.13349857926369, 26.695627123117447, 10.175609830766916, 1.563154065515846, 0.1431246637366712, 0.0828484832891263, 0.09853788593318313, 0.02444241108605638, 0.022303574878606014, 0.10886769101489335, 0.11952712098718621, 0.12522489298135042, 0.24967798206489533, 0.7965539291035384, 0.3869072621455416, 0.39878886833321303, 0.6333231192547828, 0.5262799537740648, 0.8866090374067426, 0.5354317033197731, 1.2738003046251833, 1.1959616001695395, 1.4835457247681916, 1.3556688115932047, 1.07754249824211, 2.706165863201022, 5.4616654291749, 3.149075796827674, 1.0363744385540485, 1.303818456362933, 0.7611194055061787, 1.1801970773376524, 0.8475243346765637, 0.475135380984284, 1.1266805115155876, 0.39433642756193876, 0.674986814847216, 0.26623752317391336, 0.6018917995970696, 0.20921015355270356, 0.10265172182698734, 0.0364160213212017, 0.0783169963688124, 0.1725110993720591, 0.02291352935571922, 0.03471530828392133, 0.10591106372885406, 0.028990934006287716, 0.08973903502919711, 1.501642728690058, 11.11638804897666, 40.93738071620464, 64.4669683277607, 52.21875116229057, 45.966034680604935, 46.41233213245869, 56.23445928096771, 72.11886093020439, 92.31230735778809, 81.82780355215073, 79.29417550563812, 90.52961021661758, 93.05322960019112, 54.561150670051575, 14.22243732959032, 0.7415873848367482, 0.07448364034644328, 0.04435736882442143, 0.0424679944262607, 0.11694445449393243, 0.021208068428677507, 0.07795443496434018, 0.02895298799558077, 0.017359297999064438, 0.01609270981134614, 0.06630803021835163, 0.04471021551580634, 0.07770424956106581, 0.024589603090134915, 0.017865411173261236, 0.04476350914046634, 0.06046299386071041, 0.029098749510012567, 0.04322333377785981, 0.02957199110824149, 0.010601756748656044, 0.016153345131897368, 0.07951068895636126, 0.0683249872236047, 0.024231494571722578, 0.06730132066877559, 0.04316981750889681, 0.04421533660206478, 0.05052861990407109, 0.0666912307497114, 0.034426434722263366, 0.016707046670489945, 0.03825702253379859, 0.054006049322197214, 0.04639286096789874, 0.023007715317362454, 0.07265910739079118, 0.020269188535166904, 0.022634177548752632, 0.02647719818924088, 0.061641086504096165, 0.022876793045725208, 0.016782395068730693, 0.040663069012225606, 0.04930907831294462, 0.07085573306540027, 0.06474872599937953, 0.048006319702835754, 0.059671341223292984, 0.012209618762426544, 0.0306813515999238, 0.0682803470408544, 0.17411200096830726, 0.14648283744463697, 0.16131240263348445, 0.11557596386410296, 0.1055697796982713, 0.18648492376087233, 0.1412707194685936, 0.21886360977077857, 0.2643241477198899, 0.08709527493920177, 0.0996398193819914, 0.066687334474409, 0.2484287990955636, 0.11815891237347387, 0.09412057101144455, 0.14663399808341637, 0.08307275289553218, 0.2183897781651467, 0.09530009599984623, 0.14208392036380246, 0.20835692121181637, 0.1894194053602405, 0.17351001530187204, 0.1325250879744999, 0.19483157666400075, 0.08262796894996427, 0.1431165001122281, 0.14379795495187864, 0.15117166709387675, 0.18026885809376836, 0.1371417660266161, 0.2403440501075238, 0.21316976373782381, 0.1876583631383255, 0.12572462554089725, 0.11418788053561002, 0.22423099988372996, 0.16000977018848062, 0.17506285541458055, 0.18382242444204167, 0.1902511896332726, 0.25455819675698876, 0.22813865973148495, 0.24804873042739928, 0.244045392901171, 0.20272176421713084, 6.789796762168407, 52.27536432445049, 104.88958686590195, 95.9454520046711, 104.54917073249817, 83.46507489681244, 75.65762624144554, 54.546760842204094, 25.300058908760548, 31.65533948689699, 60.289255902171135, 71.87901020050049, 62.11361400783062, 81.41524448990822, 32.39561766386032, 10.763059258460999, 1.4355873106978834, 0.3166818944737315, 0.17255447048228234, 0.28357899107504636, 0.13544352434109896, 0.15509034041315317, 0.22562743979506195, 0.15267601527739316, 0.21462833625264466, 0.3357242461061105, 0.6923935620579869, 0.3475334483664483, 0.39283307385630906, 0.3813282708870247, 0.41185699054040015, 0.5958778504282236, 0.35345914133358747, 0.6806072476319969, 0.725892623886466, 0.7601389393676072, 0.7750210189260542, 0.9811981930397451, 1.6960429097525775, 5.197612848132849, 2.2014061734080315, 0.47638227813877165, 0.583684720331803, 0.5274872202426195, 0.7667181082069874, 0.5099121539387852, 0.25319035921711475, 0.807194901863113, 0.3385810396866873, 0.5483716120943427, 0.42197608505375683, 0.6632040033582598, 0.20945198979461566, 0.19773407169850543, 0.1652454587747343, 0.13221151573816314, 0.2480530645698309, 0.11532476171851158, 0.23505293793277815, 0.15808505471795797, 0.1597640005638823, 0.43832141265738755, 2.1521522663533688, 14.433174021542072, 68.13855931162834, 110.50610348582268, 86.63847461342812, 55.05541294813156, 41.396164298057556, 47.69668221473694, 64.7362370789051, 96.15124896168709, 90.70818543434143, 88.89276444911957, 101.75748333334923, 103.33930805325508, 64.71469983458519, 19.658653624355793, 1.4003259153105319, 0.26744265225715935, 0.14175422867992893, 0.0758576970838476, 0.2951470547122881, 0.21010052296333015, 0.14221295015886426, 0.18044823518721387, 0.10147679815418087, 0.08587205229559913, 0.09877926946501248, 0.10027822223491967, 0.14883698924677446, 0.26565707463305444, 0.09409996899194084, 0.15132355503737926, 0.13330082525499165, 0.15691915556089953, 0.12046905481838621, 0.12894584331661463, 0.20216936885844916, 0.14040156063856557, 0.16689318988937885, 0.14067403273656964, 0.08860599817126058, 0.14776547643123195, 0.12241183416335844, 0.12719024845864624, 0.09947215337888338, 0.1682123276987113, 0.1734523949562572, 0.23779232375090942, 0.11849687158246525, 0.15408038132591173, 0.13651916349772364, 0.14380797394551337, 0.19380730896955356, 0.17087049287511036, 0.119928021740634, 0.15124567406019196, 0.17145858553703874, 0.15191192971542478, 0.16788073611678556, 0.10955274527077563, 0.11398967515560798, 0.11980797935393639, 0.1964030446833931, 0.1486511851544492, 0.09258227699319832, 0.08073743680142798, 0.10510776308365166, 0.2207105778506957], [0.042464899670449086, 0.03801649247179739, 0.04945453183609061, 0.0357930069003487, 0.006165733211673796, 0.016915547494136263, 0.023198731141746975, 0.046615219544037245, 0.026619056006893516, 0.009686444682301953, 0.006729845690642833, 0.007682454852329101, 0.020487333567871246, 0.07954464963404462, 0.07607106454088353, 0.038378990793717094, 0.09752142563229427, 0.019045496483158786, 0.021552567814069334, 0.07194893143605441, 0.03153503479552455, 0.011408062164264265, 0.02908774902607547, 0.036974071845179424, 0.021674920135410503, 0.04189227336610202, 0.02565245875302935, 0.016188665795198176, 0.0021645455944963032, 0.06961209393921308, 0.05586816092545632, 0.03204169901437126, 0.039434703285223804, 0.05753545876359567, 0.013570466198871145, 0.030134548323985655, 0.04327305025071837, 0.028431870450731367, 0.05575794086325914, 0.02805606727633858, 0.05122588248923421, 0.11254089899011888, 0.14290380058810115, 0.2400897309416905, 1.486321238335222, 19.255284368991852, 62.630872651934624, 72.32711255550385, 60.08169583976269, 52.16168202459812, 56.46214686334133, 48.31625796854496, 20.68788729608059, 27.735811807215214, 44.406621158123016, 75.06399929523468, 73.53252187371254, 48.75858083367348, 20.554900132119656, 3.862291113473475, 0.232311578001827, 0.07681809554924257, 0.07022214675089344, 0.16116783226607367, 0.0876671368314419, 0.01633646821574075, 0.04585861854138784, 0.04506332195887808, 0.05901172036828939, 0.13784279872197658, 0.08925879868911579, 0.21383964107371867, 0.28601813362911344, 0.2720900403801352, 0.5426023341715336, 0.43621121963951737, 0.1077740993059706, 0.2731538051739335, 1.3555845036171377, 1.2757383193820715, 0.8677925658412278, 1.1617635539732873, 0.6746476830448955, 2.875042576342821, 4.384298315271735, 9.56217359751463, 5.932200355455279, 3.5980810783803463, 1.5848929365165532, 0.587493006605655, 0.7360406324733049, 0.8565300889313221, 0.4307480627903715, 0.7667948759626597, 0.2335079200565815, 0.1313523610588163, 0.028280656006245408, 0.2792395942378789, 0.03475017809250858, 0.11032035603420809, 0.19608490081736818, 0.09217678976710886, 0.07473620804375969, 0.07182203160482459, 0.04584639165841509, 0.09966454774257727, 0.053438402828760445, 0.0854605610948056, 0.03649524187494535, 0.1071317408059258, 0.6847461161669344, 13.98001128807664, 70.20834624767303, 82.34727367758751, 33.03874835371971, 22.9812865331769, 14.804488196969032, 34.93470601737499, 55.161104276776314, 74.39629152417183, 79.26991760730743, 64.20196294784546, 78.48927229642868, 70.94567388296127, 38.38612921535969, 12.220509052276611, 0.715932942694053, 0.1065317663596943, 0.10902211710345, 0.05625556943414267, 0.04707545871497132, 0.04595692713337485, 0.03430292650591582, 0.061481402299250476, 0.024764607078395784, 0.026675225453800522, 0.01059451153196278, 0.03800749393121805, 0.06020740562235005, 0.038578613675781526, 0.029531213804148138, 0.07233703014208004, 0.027592970836849418, 0.019927112261939328, 0.03366286495293025, 0.07295421499293298, 0.01969702607311774, 0.01662795228185132, 0.07643989709322341, 0.022016176335455384, 0.06020424407324754, 0.08205356891267002, 0.07478833649656735, 0.023924434681248385, 0.07812348136212677, 0.05204778506595176, 0.031477473821723834, 0.06633703334955499, 0.04085545224370435, 0.05555072581046261, 0.007798441401973832, 0.046824134115013294, 0.04464756711968221, 0.035711797390831634, 0.058312131150159985, 0.03531856302288361, 0.014565617584594293, 0.029521801516239066, 0.02427852261462249, 0.0348757940082578, 0.017359607845719438, 0.045257831443450414, 0.05301367171341553, 0.054533144866582006, 0.05741328641306609, 0.022256916054175235, 0.008282368071377277, 0.07200167587143369, 0.03097559088928392, 0.0480733690346824, 0.06273873776081018, 0.01193391553897527, 0.025214237248292193, 0.04416744952322915, 0.0210676206916105, 0.0479668931075139, 0.1454903485137038, 0.04674257950682659, 0.035215608586440794, 0.06875725113786757, 0.026840581522264984, 0.015523715392191662, 0.06337872880976647, 0.010341094075556612, 0.03485741472104564, 0.02920925158832688, 0.022546693180629518, 0.05254592571873218, 0.03826731612207368, 0.02199480433773715, 0.036107963242102414, 0.02811488062434364, 0.028115030909248162, 0.038208552869036794, 0.022313625413517002, 0.07478539017029107, 0.04307550538214855, 0.029946495524200145, 0.08279960544314235, 0.03068669691856485, 0.037403634341899306, 0.020264474042051006, 0.04204576434858609, 0.0071525920247950125, 0.004741626034956425, 0.0451239368703682, 0.011404950710129924, 0.1314497902058065, 0.10603906936012208, 0.20811395690543577, 2.747842976823449, 27.63420145958662, 77.15573385357857, 85.69410368800163, 71.23226970434189, 70.69345861673355, 85.68991631269455, 71.75395131111145, 25.44268235564232, 39.9650888890028, 35.313439294695854, 43.34745839238167, 49.93950426578522, 44.20078620314598, 27.24766530096531, 6.607211334630847, 0.6006595375947654, 0.14377696701558307, 0.09101344359805807, 0.19525566953234375, 0.053423622957780026, 0.17819841450545937, 0.17349493486108258, 0.441020306898281, 0.4632093943655491, 0.8425738534424454, 0.4790036624763161, 1.0752195166423917, 1.3750192732550204, 1.1452898941934109, 1.8419741978868842, 2.697288589552045, 2.671153354458511, 3.057254198938608, 3.8505514059215784, 3.008080325089395, 3.139571794308722, 4.131601424887776, 2.968776421621442, 6.1423419043421745, 7.238559806719422, 10.045332871377468, 8.671646732836962, 7.4396321922540665, 5.276236329227686, 4.868690622970462, 2.4059415981173515, 3.732706904411316, 1.8711183965206146, 1.420878537464887, 0.7859623536933213, 0.9143686853349209, 0.7264530938118696, 0.7149775908328593, 0.49408520164433867, 0.4411750892177224, 0.11058709133067168, 0.2675309084588662, 0.04040540647110902, 0.1332232856657356, 0.0577147208241513, 0.24673613836057484, 0.018837390853150282, 0.04018021289084572, 0.05099963134853169, 0.0841885496629402, 1.0724872257560492, 15.83001896739006, 57.36110642552376, 56.31575971841812, 34.373153150081635, 33.40946026146412, 26.68299850076437, 54.147124886512756, 71.92242667078972, 86.51700273156166, 90.56746378540993, 74.03094112873077, 91.15032210946083, 85.85029050707817, 55.742613673210144, 20.92465829104185, 0.9075000789016485, 0.22452794801210985, 0.05783708984381519, 0.10552862760960124, 0.021012751858506817, 0.054695192811777815, 0.039940198621479794, 0.019467698730295524, 0.04880149383097887, 0.00884618693817174, 0.07073278145981021, 0.03378711160621606, 0.042651471885619685, 0.04915449637337588, 0.031419731021742336, 0.006974283624003874, 0.05051459702372085, 0.017822225599957164, 0.01798934055841528, 0.07725469360593706, 0.05044329518568702, 0.03146114286209922, 0.05008180618460756, 0.052135573714622296, 0.03159062907798216, 0.07649193648830988, 0.024565730054746382, 0.03062352530832868, 0.040508179081371054, 0.010852700070245191, 0.03218670724891126, 0.07979601505212486, 0.018113121514033992, 0.05983047252811957, 0.05178018516744487, 0.01094597319024615, 0.03754425277293194, 0.032549572933930904, 0.04793099171365611, 0.038379762627300806, 0.032635895840940066, 0.01654951469390653, 0.03808505949564278, 0.07236729492433369, 0.021780468377983198, 0.050201288249809295, 0.03156690261675976, 0.10229411054751836, 0.040717772717471235, 0.040994304363266565, 0.11104811346740462, 0.14534711401211098, 0.13323367573320866, 0.100449406018015, 0.17652574722887948, 0.09934372472343966, 0.11963140015723184, 0.1346124822157435, 0.11318571399897337, 0.14935978775611147, 0.21922522864770144, 0.09735807892866433, 0.15480933361686766, 0.1313623652094975, 0.12485468003433198, 0.11242482709349133, 0.19950057612732053, 0.11884076055139303, 0.2584919653600082, 0.19432028144365177, 0.14438438520301133, 0.25951648538466543, 0.11429383695940487, 0.0873568226234056, 0.16274173452984542, 0.20550137443933636, 0.10361220935010351, 0.13076061703031883, 0.11237427941523492, 0.22557943768333644, 0.17617077799513936, 0.17587034177267924, 0.21939604135695845, 0.15558648097794503, 0.1036748688784428, 0.14258270297432318, 0.09487777686445042, 0.07741488618194126, 0.17363477032631636, 0.13304674357641488, 0.09739106739289127, 0.29578182846307755, 0.25281263573560864, 0.35117970895953476, 4.798286100849509, 37.20236733555794, 97.04749166965485, 96.09919175505638, 80.73462501168251, 69.60012808442116, 75.95724016427994, 67.97155067324638, 30.322416611015797, 41.358227133750916, 64.29217010736465, 101.2239083647728, 101.71739548444748, 70.06015419960022, 33.01915280520916, 7.1710611786693335, 0.6568989541847259, 0.29241399199236184, 0.22492153861094266, 0.4488923563621938, 0.2513864653883502, 0.25725486455485225, 0.2224797836970538, 0.3764567244797945, 0.2751160436309874, 0.5609020334668458, 0.2714677940821275, 0.7483151613269001, 1.1203456576913595, 0.918214910198003, 1.1355149187147617, 2.52845058683306, 1.5189933101646602, 1.8165566492825747, 3.0269700614735484, 4.060975564643741, 2.4281720677390695, 3.866887204349041, 2.5886647682636976, 7.951658042147756, 11.700320765376091, 26.59831814467907, 19.010138623416424, 7.045939592644572, 6.483104769140482, 3.6780629865825176, 3.3910990599542856, 3.272900227457285, 1.8732217024080455, 2.0528624067083, 0.9720827196724713, 0.6644007610157132, 0.7431584224104881, 0.6404253537766635, 0.5844266898930073, 0.4163918097037822, 0.30017100856639445, 0.3108419937780127, 0.1526575951720588, 0.19571298093069345, 0.16662666981574148, 0.44080419349484146, 0.4673307482153177, 0.28907649451866746, 0.21581854816759005, 0.30009759531822056, 1.4584360783919692, 19.703831300139427, 95.02253472805023, 106.51276096701622, 51.53185062110424, 36.68502129614353, 23.496250100433826, 47.57309004664421, 71.42938032746315, 94.88777875900269, 97.91741698980331, 85.27475818991661, 100.81675261259079, 98.30280750989914, 68.5646304488182, 24.91873227059841, 0.9735064557753503, 0.30365462007466704, 0.21207484358455986, 0.2823749603703618, 0.1393931600614451, 0.14312228886410594, 0.1590838815900497, 0.1838992367265746, 0.1803180921706371, 0.1599694715696387, 0.17649852525210008, 0.15076856216182932, 0.12176149757578969, 0.13918924756580964, 0.07138682136428542, 0.22369352169334888, 0.12451513262931257, 0.10159854748053476, 0.1164557873562444, 0.14523874560836703, 0.18055752385407686, 0.17958832351723686, 0.24687595898285508, 0.15417056711157784, 0.16598491987679154, 0.17959923308808357, 0.14595085114706308, 0.14326587959658355, 0.22055673063732684, 0.11479854190838523, 0.13148654135875404, 0.11697365058353171, 0.1501524608465843, 0.22150406730361283, 0.1693850991432555, 0.08889452292351052, 0.10417399287689477, 0.14510688080918044, 0.19743927579838783, 0.13082441204460338, 0.12786187726305798, 0.10329892655136064, 0.13666600483702496, 0.1889086890150793, 0.08938113431213424, 0.14084995142184198, 0.13185372634325176, 0.1440831771469675, 0.13088857813272625, 0.15764230425702408], [0.018895825705840252, 0.042905716836685315, 0.04769744526129216, 0.08078923870925792, 0.04141225595958531, 0.012898619388579391, 0.027696372417267412, 0.033634492647252046, 0.015770335703564342, 0.10071315788081847, 0.012639553260669345, 0.016157222853507847, 0.0320426860707812, 0.013572759435191983, 0.04897667407931294, 0.042566551637719385, 0.025828674297372345, 0.04599431653332431, 0.035141865082550794, 0.08540917478967458, 0.06225995603017509, 0.02956804102723254, 0.015223452646750957, 0.061805624354747124, 0.01612393381947186, 0.042309401178499684, 0.023937043770274613, 0.00951508463913342, 0.04888678886345588, 0.013802275097987149, 0.04611757984093856, 0.03504832107864786, 0.05611104359559249, 0.02627061025123112, 0.013077189396426547, 0.020929228703607805, 0.0640668703999836, 0.16474590433062986, 0.048921892448561266, 0.08450978086329997, 0.027573508014029358, 0.10105410794494674, 2.519720555283129, 24.316227100789547, 58.87035883963108, 70.74867725372314, 71.14666029810905, 74.2728741466999, 60.69016858935356, 31.58376082777977, 58.524224013090134, 37.951063960790634, 51.28261059522629, 52.77595326304436, 68.6967645585537, 59.45702075958252, 27.169275507330894, 6.490918574854732, 0.20302840479416773, 0.03338019574584905, 0.052348996832733974, 0.1352847195812501, 0.027714243333321065, 0.03252081100072246, 0.11832774354843423, 0.045355550028034486, 0.06336144419037737, 0.21363228501286358, 0.28326761559583247, 0.5330744048114866, 0.6376624864060432, 0.7057444425299764, 1.4492188417352736, 1.1579243349842727, 1.299051612149924, 1.7758425464853644, 2.7422361401841044, 3.621299732476473, 1.6552273998968303, 3.374968688003719, 5.222464939579368, 3.803527979180217, 5.726555865257978, 2.085058316588402, 4.665069999173284, 7.045803749933839, 4.549909578636289, 6.961836805567145, 3.658279348164797, 2.7009822288528085, 3.3973513869568706, 3.7750259460881352, 3.5383630078285933, 1.6317346855066717, 0.5250156309921294, 1.34026313200593, 0.5448003381025046, 1.4811814203858376, 0.5755157524254173, 0.023620473257324193, 0.12012090592179447, 0.019295657766633667, 0.02635761964484118, 0.10627332827425562, 0.027923551242565736, 0.019835954262816813, 0.03238990728277713, 0.03732244709681254, 0.010978453283314593, 0.013583990912593435, 0.05453436569951009, 0.14409699593670666, 8.29532727599144, 57.202882915735245, 80.63955411314964, 69.24233928322792, 47.21793830394745, 19.493212401866913, 20.065334402024746, 44.16590787470341, 50.124417543411255, 72.01581805944443, 74.90059286355972, 69.41051825881004, 70.66556811332703, 78.98483410477638, 37.15161345899105, 1.578420577570796, 0.41460148233454674, 0.10027978074504063, 0.015805205512151588, 0.05951379440375604, 0.07083149452228099, 0.008853358867781935, 0.018231269568786956, 0.07811327683157288, 0.07949106657179072, 0.005355726334528299, 0.030125187986413948, 0.14847090264083818, 0.03254503841162659, 0.05646609075483866, 0.045102128860889934, 0.03756389000045601, 0.03139031228784006, 0.03376584165380336, 0.007421375648846151, 0.08012172882445157, 0.04623773354978766, 0.06592806545086205, 0.023210195467981976, 0.02430381871818099, 0.014735789263795596, 0.03721338478499092, 0.06969104360905476, 0.029600350426335353, 0.0563318733475171, 0.11318693854263984, 0.01610407023690641, 0.059433575661387295, 0.06946301873540506, 0.006141604599179118, 0.05358575624995865, 0.061566597141791135, 0.03541066726029385, 0.022275577357504517, 0.031428955917363055, 0.014914262792444788, 0.04104020248632878, 0.001781538137493044, 0.06883168112835847, 0.01299238603678532, 0.03326149293570779, 0.04620382853318006, 0.0789789178816136, 0.014157607984088827, 0.01465412611651118, 0.043435851475805975, 0.04556027146463748, 0.033631646510912105, 0.03615641806391068, 0.030510078759107273, 0.07509983814088628, 0.008003825205378234, 0.04170868829532992, 0.031213981710607186, 0.0327739687054418, 0.040539301044191234, 0.05568375207076315, 0.07643804914550856, 0.06457547904574312, 0.013611899375973735, 0.07574117989861406, 0.03680146313854493, 0.07404664895148017, 0.0024442162930427003, 0.046815139285172336, 0.0395762160042068, 0.05807295921840705, 0.06818791996920481, 0.07006715663010255, 0.010454750281496672, 0.0368975007586414, 0.010655251680873334, 0.029466886298905592, 0.03299934782262426, 0.05461352688143961, 0.03395749758055899, 0.06358044454827905, 0.035669795543071814, 0.061390741539071314, 0.09432690290850587, 0.04189570579910651, 0.07689490041229874, 0.01952463630004786, 0.052405262758838944, 0.013033603063377086, 0.11049424865632318, 3.7570586102083325, 34.76590767502785, 78.46498399972916, 87.47765958309174, 83.65104451775551, 86.50922074913979, 76.70828506350517, 45.58596007525921, 53.58450807631016, 45.25671914219856, 48.47580760717392, 36.64965659379959, 47.22577728331089, 54.75190043449402, 32.04836189746857, 10.285636726766825, 0.7566873589530587, 0.03764492881600745, 0.06307714967988431, 0.05489314215083141, 0.08085603200015612, 0.1637468845001422, 0.24269440211355686, 0.5011707230005413, 0.6167161103803664, 2.7683993987739086, 2.4021959491074085, 2.366281463764608, 4.274358339607716, 5.196927934885025, 4.201143868267536, 5.1968087162822485, 7.876046849414706, 7.773864157497883, 6.001571333035827, 8.141181897372007, 9.165566079318523, 9.381428696215153, 10.879419464617968, 9.214998576790094, 6.249537477269769, 6.841109683737159, 11.478722356259823, 9.836921654641628, 9.430782347917557, 11.351647675037384, 14.463638886809349, 8.933129701763391, 5.964058795943856, 6.529371561482549, 5.438836254179478, 4.510463895276189, 4.225122481584549, 3.9360135700553656, 2.788622626103461, 2.3971942299976945, 2.99512539524585, 1.5988751174882054, 1.6350794560275972, 0.7598822156433016, 0.6006555596832186, 0.5637327628210187, 0.20215299708070233, 0.04640223800379317, 0.08208877639845014, 0.08359017825569026, 0.05186323520320002, 0.03760205123398919, 0.11714640771970153, 0.20921018323861063, 7.4239542335271835, 48.0394846200943, 53.33777591586113, 47.665474489331245, 35.104325115680695, 29.33122269809246, 39.012183621525764, 65.75578317046165, 68.93788442015648, 83.0978474020958, 85.01223787665367, 76.92199319601059, 83.66491377353668, 93.64591419696808, 55.063202530145645, 3.941252063959837, 0.5050375498831272, 0.048704435757827014, 0.05956755929219071, 0.06781096089980565, 0.08328630588948727, 0.03851104855129961, 0.024118899636960123, 0.024373940541408956, 0.03155890226480551, 0.025742961806827225, 0.08390746865188703, 0.037688414959120564, 0.015199980371107813, 0.02651264501764672, 0.031937687017489225, 0.023471347958547994, 0.034279496903764084, 0.04595813683408778, 0.015973697154549882, 0.10376374106272124, 0.052154680306557566, 0.041592364068492316, 0.01400971279508667, 0.02250158544484293, 0.04444561760465149, 0.013827340208081296, 0.0669215117522981, 0.0888753384060692, 0.03628669466706924, 0.03239838631998282, 0.016841913457028568, 0.00709364416252356, 0.018508869907236658, 0.01756146830302896, 0.05459660962515045, 0.04013134617707692, 0.024195561636588536, 0.01953354021679843, 0.07958338974276558, 0.01590699848748045, 0.07616815229994245, 0.017095091570809018, 0.07119674250134267, 0.04421343299327418, 0.05011086868762504, 0.012308979348745197, 0.07726691677817143, 0.02145662667317083, 0.11423754505813122, 0.17618602170841768, 0.2165130796493031, 0.13964782061520964, 0.15911999449599534, 0.11133333566249348, 0.21659710560925305, 0.13215938728535548, 0.12987386930035427, 0.14524683501804247, 0.0900925941823516, 0.09158146116533317, 0.1724441724945791, 0.1568297712947242, 0.1843599323183298, 0.12280219641979784, 0.1671889951103367, 0.24142420152202249, 0.1316642708843574, 0.12404167209751904, 0.1898829359561205, 0.2522100415080786, 0.13763732771622017, 0.22465792775619775, 0.2548693644348532, 0.1306409531389363, 0.24839310179231688, 0.11080506752477959, 0.08613076497567818, 0.1820639055222273, 0.21893815108342096, 0.14651189994765446, 0.15910142596112564, 0.0856551670585759, 0.0983208003162872, 0.20491561212111264, 0.08746833773329854, 0.2346457215026021, 0.09550672475597821, 0.1759972787112929, 0.09163714450551197, 0.41150176897644997, 6.01727731525898, 42.80349858105183, 93.15984427928925, 100.51992774009705, 91.39401063323021, 93.02953407168388, 81.34863406419754, 47.78927564620972, 72.09395706653595, 53.972292467951775, 75.4337802529335, 72.43362843990326, 91.06122449040413, 80.44226869940758, 41.60846650600433, 11.313108243048191, 1.089816908352077, 0.27283293020445853, 0.26063463476020843, 0.21885440713958815, 0.17530571582028642, 0.13132723193848506, 0.3165245591662824, 0.40329979034140706, 0.18432681768899783, 1.2437215936370194, 1.034762968774885, 1.09921416034922, 1.9736266834661365, 2.3866053856909275, 3.0566737800836563, 4.048261921852827, 7.841429756954312, 8.964169286191463, 8.168323840945959, 12.216058541089296, 11.733927112072706, 14.652528651058674, 21.364009715616703, 17.6828508451581, 15.236077588051558, 12.487125545740128, 18.54613982141018, 20.88985785841942, 16.798896677792072, 14.569929633289576, 14.154537823051214, 11.772562488913536, 9.964464660733938, 12.779441960155964, 9.147913176566362, 9.036786239594221, 7.303923424333334, 5.281104817986488, 2.890879176557064, 4.3474621418863535, 2.528848140500486, 1.451764942612499, 1.618321524001658, 0.6050915247760713, 0.34279335115570575, 0.3878464945591986, 0.2393067502998747, 0.12197717311209999, 0.19987026957096532, 0.195159784052521, 0.2603533607907593, 0.13507878844393417, 0.2291395200882107, 0.39621777192223817, 11.527619082480669, 76.47314608097076, 104.64480400085449, 93.33141267299652, 66.52632102370262, 28.18342588841915, 30.982089713215828, 59.14078652858734, 65.739094465971, 91.93558037281036, 93.96347835659981, 90.69736361503601, 90.88383480906487, 104.21051010489464, 60.43624721467495, 4.850362306460738, 0.8777999226003885, 0.21011189266573638, 0.19937056669732556, 0.15633504081051797, 0.249876580783166, 0.21483597432961687, 0.10240235278615728, 0.19692815869348124, 0.18257770920172334, 0.18865340505726635, 0.10719733181758784, 0.3101245447760448, 0.12999084661714733, 0.1412300200900063, 0.09583352206391282, 0.26413237676024437, 0.07705211697611958, 0.17662344354903325, 0.11611773166805506, 0.1705171266803518, 0.19615105586126447, 0.15845406538574025, 0.07165558272390626, 0.07334655878366902, 0.09127013021497987, 0.09088391656405292, 0.17820040346123278, 0.1444763076142408, 0.1307740350603126, 0.22141444555018097, 0.12678076105657965, 0.11806241833255626, 0.17129989952081814, 0.08278442110167816, 0.23131870315410197, 0.23657953570364043, 0.1289600777090527, 0.12206812330987304, 0.1296247451682575, 0.12048210177454166, 0.1817377464612946, 0.08689761874848045, 0.22555261646630242, 0.18855330417864025, 0.19163988152286038, 0.1084434794029221, 0.15605906577548012, 0.11219068692298606], [0.05702950329578016, 0.008743298367335228, 0.036102927770116366, 0.03268504828156438, 0.04782683128723875, 0.03496262899716385, 0.0556719445012277, 0.030777958818362094, 0.02033667387877358, 0.07013262889813632, 0.06057848688215017, 0.04139491938985884, 0.040531590129830875, 0.043379815615480766, 0.026944311503029894, 0.1149656884081196, 0.029627884105138946, 0.01419963580701733, 0.06411190392100252, 0.02721936998568708, 0.006689584179184749, 0.005789989409095142, 0.02189552724303212, 0.14176093769492581, 0.01773540545400465, 0.029032340280537028, 0.018087743774231058, 0.01651096568821231, 0.010342250898247585, 0.05312374334607739, 0.06126588261395227, 0.07082050331518985, 0.05763122549979016, 0.04854639912082348, 0.051685709768207744, 0.046738111777813174, 0.059312115772627294, 0.04592521887389012, 0.07218822211143561, 0.1130021437711548, 0.9283319860696793, 24.086058251559734, 58.644422963261604, 86.65051236748695, 69.29564282298088, 77.38622948527336, 68.90699967741966, 45.95335856080055, 20.908680148422718, 41.12201280891895, 171.1911043524742, 114.35641407966614, 37.20460921525955, 58.81055384874344, 41.51346020400524, 12.92215945199132, 0.7701993745286018, 0.1819328125566244, 0.011943863100896124, 0.06301315428572707, 0.08528324717190117, 0.042494218214415014, 0.057337208854733035, 0.26544407824985683, 0.24141413799952716, 0.35068134195171297, 1.5597317554056644, 4.231412569060922, 2.3586524231359363, 3.844360588118434, 3.214713237248361, 5.58852874673903, 3.2395539293065667, 2.3966589337214828, 6.790116420015693, 5.293524926528335, 6.408437825739384, 8.630787525326014, 9.738083258271217, 3.0321042984724045, 6.412738244980574, 5.241153761744499, 3.3342602849006653, 5.750941056758165, 7.82476432621479, 4.451720472425222, 7.300194874405861, 13.919627778232098, 13.338520210236311, 10.409325789660215, 1.3228106684982777, 4.21764163300395, 3.5601636255159974, 2.8668658901005983, 1.2204613792710006, 3.3000381337478757, 1.230956178624183, 1.401995806954801, 1.9309290871024132, 0.8445704681798816, 0.8714908955153078, 0.8875373750925064, 0.1750636420911178, 0.7108155079185963, 0.21734755049692467, 0.12375424572383054, 0.17663790058577433, 0.04451852619240526, 0.11582464270759374, 0.08636397746158764, 0.10613519974867813, 0.0227044088387629, 0.05102198112581391, 2.159078107215464, 31.54184527695179, 76.40047878026962, 75.27031302452087, 55.645954459905624, 26.66949212551117, 13.335902150720358, 22.565628737211227, 33.215701058506966, 62.44951978325844, 71.88944444060326, 76.91893056035042, 64.50245082378387, 80.78210726380348, 49.83947463333607, 5.910316379740834, 0.38528278993908316, 0.07238975973450579, 0.07502284774091095, 0.017363724909955636, 0.019935120035370346, 0.022388509969459847, 0.05413337217760272, 0.06215977351530455, 0.0417665683926316, 0.004663853133024531, 0.05924598670389969, 0.041982778275269084, 0.044548126752488315, 0.04219320311676711, 0.0931273696187418, 0.011242709806538187, 0.05885416241653729, 0.04983327948139049, 0.03612285443523433, 0.04900362888292875, 0.017185731921927072, 0.03157167091558222, 0.047434669322683476, 0.015475022155442275, 0.02695371822483139, 0.055610591152799316, 0.03436694045376498, 0.008372517677344149, 0.04844417198910378, 0.03280972538050264, 0.013427452486212132, 0.03172289092617575, 0.04995480987417977, 0.038667010885546915, 0.03850872191833332, 0.039082238799892366, 0.038999544995022006, 0.024621905067760963, 0.07751963290502317, 0.028107208672736306, 0.03268779793870635, 0.02437815594021231, 0.06160652839753311, 0.036017718084622175, 0.0954474345780909, 0.022988549353613053, 0.0451380117010558, 0.010218504266958917, 0.03031311647646362, 0.04584718946716748, 0.004588272349792533, 0.023093930612958502, 0.01858473966422025, 0.04108743647520896, 0.002476490208209725, 0.04862387191678863, 0.06063490865926724, 0.013998330105096102, 0.05646340789098758, 0.04543026203464251, 0.03528605695464648, 0.03489766510028858, 0.031576142355334014, 0.037430934244184755, 0.05429903067124542, 0.005188628074392909, 0.04404923653055448, 0.03267383814090863, 0.050867191384895705, 0.025918036299117375, 0.06281145339016803, 0.012221006090840092, 0.015091234399733366, 0.07272039394592866, 0.037090448022354394, 0.10193217254709452, 0.017761026247171685, 0.05815707794681657, 0.024537218596378807, 0.08547602003091015, 0.054946224263403565, 0.0395898269925965, 0.006881763320052414, 0.06909341434948146, 0.06642829524935223, 0.09270260881748982, 0.22457198705524206, 1.0745835257694125, 31.45105104893446, 76.42577022314072, 99.03739929199219, 79.47759166359901, 85.23066535592079, 79.75925534963608, 67.67567574977875, 35.483803153038025, 47.24646717309952, 145.64515113830566, 86.47679328918457, 33.69389399886131, 44.79718320071697, 38.2993570715189, 17.50140108168125, 1.5240520262159407, 0.11793299519922584, 0.01592109187185997, 0.08137928321957588, 0.062350549997063354, 0.08226005666074343, 0.5113249062560499, 1.6021163435652852, 1.4087798679247499, 2.454889384098351, 6.339240688830614, 9.133730437606573, 8.60364368185401, 11.35698163881898, 10.111065544188023, 10.864514764398336, 9.324416555464268, 10.522801950573921, 10.538188274949789, 12.010120041668415, 12.70888639613986, 15.220680814236403, 9.887226205319166, 12.12405787780881, 12.28636046871543, 13.6528336443007, 8.694966081529856, 13.834425900131464, 14.44337172433734, 11.301491316407919, 11.843676622956991, 9.320798199623823, 13.333544377237558, 9.737423043698072, 7.316161617636681, 6.814688751474023, 8.533101417124271, 5.171484975144267, 5.248809875920415, 5.986724104732275, 5.192488823086023, 5.854817507788539, 4.45705633610487, 4.0546902269124985, 3.4801147459074855, 4.064236739650369, 1.577913067303598, 1.736825646366924, 1.103549727704376, 0.6940781779121608, 0.4988402605522424, 0.19506033626385033, 0.33274217799771577, 0.08195852205972187, 0.036887088426738046, 0.04429463508131448, 0.1337189512560144, 2.4136442597955465, 29.794636331498623, 59.100846871733665, 61.60624623298645, 34.93823982775211, 26.396773159503937, 24.3506171554327, 40.699764266610146, 56.29520282149315, 80.5134616792202, 87.4485531449318, 88.77044901251793, 75.20025238394737, 91.49633914232254, 71.68388307094574, 15.374113731086254, 0.19635131699033082, 0.07223871783935465, 0.0932707599713467, 0.037472891563083977, 0.0625643775856588, 0.0713284662924707, 0.04390991685795598, 0.06665372260613367, 0.031094933801796287, 0.011502153502078727, 0.025191564636770636, 0.09647107144701295, 0.10802832199260592, 0.043764389120042324, 0.05264755542157218, 0.03763488384720404, 0.05270320536510553, 0.06581621637451462, 0.04129186847421806, 0.009149519391939975, 0.05853108326846268, 0.04989101114915684, 0.06195121517521329, 0.03594854621042032, 0.030396149813896045, 0.059280374116497114, 0.04326415561081376, 0.047926382976584136, 0.01784692984074354, 0.03876821014273446, 0.027525619079824537, 0.02465198987920303, 0.006940641605979181, 0.017198956993524916, 0.0465263696241891, 0.05703007474949118, 0.05599855627224315, 0.041718321372172795, 0.022205860004760325, 0.02134143236617092, 0.03690426172397565, 0.02791226317640394, 0.052009820501552895, 0.033413169367122464, 0.01547038002172485, 0.06507395737571642, 0.026519994135014713, 0.19736574380658567, 0.1466717288712971, 0.09821471772738732, 0.1387664905632846, 0.13634609465952963, 0.18445891997544095, 0.12908420932944864, 0.16043613402871415, 0.13332893780898303, 0.256674267584458, 0.15369203028967604, 0.1332266698591411, 0.13856452249456197, 0.13102992757922038, 0.06752585744834505, 0.13328111381269991, 0.16797835822217166, 0.1135588955366984, 0.14248551131458953, 0.16928989643929526, 0.10703827472752891, 0.15066911437315866, 0.10191648354521021, 0.29919410473667085, 0.10747614927822724, 0.15847756178118289, 0.13983824086608365, 0.1079288890468888, 0.3169091697782278, 0.12024857758660801, 0.11970902880420908, 0.18886905832914636, 0.19393472088268027, 0.19759284099563956, 0.16907796874875203, 0.2549985278164968, 0.14172282099025324, 0.21090391266625375, 0.21340241219149902, 0.3380889957770705, 1.5678539383225143, 41.01784519851208, 91.67058259248734, 114.13382202386856, 89.81766521930695, 94.19151172041893, 89.84859555959702, 62.734762877225876, 35.77823415398598, 54.75355714559555, 169.4933706521988, 125.44670417904854, 52.379015162587166, 80.01031547784805, 62.102393209934235, 21.120953857898712, 1.9405058794654906, 0.25795726280193776, 0.17053896066499874, 0.15205884526949376, 0.16511302994331345, 0.13563290558522567, 0.26705257943831384, 1.0096361045725644, 0.9553208097349852, 1.4218922518193722, 5.420700777322054, 11.880060620605946, 10.07542060688138, 13.201212678104639, 12.170973010361195, 17.620051614940166, 14.424538034945726, 12.076923307031393, 22.21659656614065, 18.212852105498314, 24.64791890233755, 25.79232059419155, 26.078882217407227, 15.478454232215881, 17.912730909883976, 19.485356323421, 14.725788719952106, 19.255398362874985, 20.31175307929516, 17.306061163544655, 20.960499867796898, 29.868660159409046, 31.812797337770462, 20.805888064205647, 12.815065998584032, 13.614931628108025, 14.318451527506113, 9.265723954886198, 7.53285638988018, 10.45863289386034, 5.573733765631914, 7.458594599738717, 7.993700411170721, 4.373183911666274, 4.604788608849049, 5.418156813830137, 2.120989663526416, 2.088357964530587, 0.8022570074535906, 0.36896964185871184, 0.642595631070435, 0.23829668731195852, 0.34404467151034623, 0.23646371613722295, 0.22999557259026915, 0.10780741431517527, 0.500578845385462, 3.361178277991712, 43.89941677451134, 96.56984969973564, 98.79691019654274, 76.64824828505516, 38.99474635720253, 21.361300460994244, 36.36884406208992, 46.94410599768162, 78.54086592793465, 90.98431661725044, 96.90519690513611, 85.2863247692585, 103.61271098256111, 84.74075004458427, 18.052443712949753, 0.49489286611787975, 0.24040981923462823, 0.17883891763631254, 0.15563722903607413, 0.20241801801603287, 0.10950990850687958, 0.15923753584502265, 0.27761461737100035, 0.24609802494524047, 0.11640009659458883, 0.15515095903538167, 0.19474468601401895, 0.25951375428121537, 0.09789177958737127, 0.20155651815002784, 0.16192176524782553, 0.18499581929063424, 0.18407150404527783, 0.12946065631695092, 0.11324345308821648, 0.13695510104298592, 0.0971073962864466, 0.1306594771449454, 0.10602338777971454, 0.13123104959959164, 0.2167428337270394, 0.13944398233434185, 0.26513267308473587, 0.1223386732453946, 0.1140547837712802, 0.1320875622332096, 0.16460465878481045, 0.14332860591821373, 0.12289025224163197, 0.09581804086337797, 0.15305124514270574, 0.2186545022414066, 0.10052776196971536, 0.1563106686808169, 0.14151316427160054, 0.14455231837928295, 0.07209834802779369, 0.23099184647435322, 0.14235337934223935, 0.26355332345701754, 0.1632559092831798, 0.11965456258621998], [0.006475939808296971, 0.09012299997266382, 0.048683332788641565, 0.07140205023461021, 0.02109526569256559, 0.02932404328021221, 0.07891104847658426, 0.05936166155152023, 0.03417082050873432, 0.06570488680154085, 0.02685868621483678, 0.017778420333343092, 0.02543279973906465, 0.025975142707466148, 0.06029466363543179, 0.029700490267714486, 0.041877089024637826, 0.017555124795762822, 0.026400569586257916, 0.03757261765713338, 0.04276723579096142, 0.01646369644731749, 0.02263657283037901, 0.07225923080113716, 0.019262630339653697, 0.0321789963345509, 0.02739937790465774, 0.04265224742994178, 0.022104044765001163, 0.03196488301909994, 0.015295947487174999, 0.006557810756930849, 0.05775958736194298, 0.0012830970308641554, 0.05161555454833433, 0.05170685726625379, 0.03063528834900353, 0.1442618269356899, 0.06844620962510817, 1.6815173579379916, 34.850627928972244, 22.572282180190086, 56.935020089149475, 70.70777624845505, 65.25408089160919, 51.52956694364548, 34.12253379821777, 19.766653329133987, 18.58498513698578, 30.268871784210205, 40.7022113353014, 51.78200259804726, 52.82644875347614, 21.24393615871668, 4.734692238271236, 0.1594054838642478, 0.04860702887526713, 0.1200766590773128, 0.051917797900387086, 0.04002474408480339, 0.0978402077453211, 0.1375491902581416, 0.32516295032110065, 1.538921578321606, 0.08334852012922056, 2.1370694506913424, 6.9977339543402195, 9.462594240903854, 10.998115595430136, 10.824344269931316, 13.309421371668577, 14.051957577466965, 9.892422426491976, 11.804522573947906, 9.561935160309076, 11.488452684134245, 4.519493160769343, 5.740012368187308, 7.832171553745866, 10.556519441306591, 9.175453148782253, 11.038940604776144, 6.361881298944354, 6.077830865979195, 12.504406068474054, 5.83146633580327, 9.476938471198082, 12.160273734480143, 15.746191665530205, 10.896662939339876, 5.191682791337371, 4.876377135515213, 4.815767537802458, 3.020959021523595, 4.837335655465722, 6.619706964120269, 4.636841788887978, 2.263072351925075, 4.192379163578153, 3.7192606134340167, 2.7385638747364283, 1.9764115777797997, 2.297700368799269, 1.0820764862000942, 1.3705042842775583, 0.9389045624993742, 0.2474067430011928, 0.2242701407521963, 0.11062792429584078, 0.04789694197825156, 0.07936336522107013, 0.013978701226733392, 0.09732146136229858, 0.1799188760924153, 0.5931771453469992, 20.17551898956299, 48.43053683638573, 101.31199523806572, 84.82553869485855, 55.07861450314522, 29.95504852384329, 11.439754497259855, 34.46215197443962, 34.59160342812538, 42.80535668134689, 78.44910845160484, 72.42597565054893, 67.8442195057869, 67.09545448422432, 18.643173314630985, 0.8660182391759008, 0.24077468871837482, 0.0651491666212678, 0.08713374787475914, 0.03403979062568396, 0.05606973194517195, 0.053550392913166434, 0.08638143277494237, 0.028864381129096728, 0.051001720494241454, 0.027460328637971543, 0.027864533803949598, 0.03664603515062481, 0.012903547249152325, 0.03585826765629463, 0.03679933688545134, 0.04026961942145135, 0.03175121499225497, 0.011469168748590164, 0.05587048755842261, 0.03895270805514883, 0.018015538371400908, 0.11275060765910894, 0.020052024992764927, 0.037995311577105895, 0.04778037284268066, 0.013520160646294244, 0.042328348208684474, 0.06352579279337078, 0.011214088881388307, 0.028686339901469182, 0.029290761667652987, 0.04535845553618856, 0.06792026440962218, 0.04661988023144659, 0.02497109853720758, 0.04246411670465022, 0.008972158157121157, 0.07005589824984781, 0.03396828098630067, 0.030324256113090087, 0.032997767048073, 0.09714206942589954, 0.07529704162152484, 0.055211657090694644, 0.05267676264338661, 0.03918107060599141, 0.049773210048442706, 0.026395519271318335, 0.08982113140518777, 0.028717755012621637, 0.04136521863983944, 0.06197675989824347, 0.054905498909647577, 0.07788439848809503, 0.05708180244255345, 0.01716681828838773, 0.05158738262252882, 0.026061370990646537, 0.008933209319366142, 0.056144039481296204, 0.03702078633068595, 0.015087340907484759, 0.04225314267387148, 0.06236706278286874, 0.025411991773580667, 0.09195641643600538, 0.03725595808646176, 0.029646949878952, 0.031058748536452185, 0.027913793855987024, 0.0344326687627472, 0.0344517234043451, 0.013292471594468225, 0.07604877784615383, 0.02463051027007168, 0.02379868703428656, 0.039158023209893145, 0.03536865799105726, 0.05697521148249507, 0.014615135532949353, 0.022750488788005896, 0.061066794078215025, 0.07992655882844701, 0.045079500778228976, 2.8592102508991957, 43.55642057955265, 29.375661313533783, 62.635648995637894, 84.23699587583542, 83.72921392321587, 79.42789033055305, 59.19133901596069, 27.44305271655321, 18.257623203098774, 32.473604679107666, 62.90220849215984, 65.14682784676552, 49.12639729678631, 30.46619139611721, 7.647563209757209, 0.41531839699018747, 0.06875339196994901, 0.12541558040538803, 0.22172225872054696, 0.18953895050799474, 1.162210030015558, 1.799335260875523, 1.9169598491862416, 4.100000895559788, 1.8013498652726412, 10.505465380847454, 12.498252298682928, 12.662577331066132, 7.968397093936801, 12.571499068289995, 11.857107002288103, 16.95679910480976, 9.351173769682646, 9.369029011577368, 8.90313696116209, 10.412181336432695, 12.283744309097528, 17.9096644744277, 13.845328465104103, 14.418806042522192, 11.739072985947132, 12.977655474096537, 8.170287385582924, 11.063729524612427, 11.430558990687132, 5.9384856931865215, 8.921781610697508, 7.122943410649896, 10.40457034483552, 9.469595365226269, 5.534111391752958, 2.930443841032684, 5.791049804538488, 2.3860565526410937, 2.6200251979753375, 3.1898440467193723, 3.337408653460443, 2.9518637666478753, 5.292979180812836, 6.815625401213765, 4.708030968904495, 4.752510907128453, 4.835164546966553, 4.094321625307202, 2.4005361506715417, 1.8429792439565063, 0.7225698209367692, 1.4719653711654246, 0.41955730703193694, 0.5938017962034792, 0.3216773201711476, 0.10223601522739045, 0.0740417507768143, 0.18847606144845486, 0.6807975342962891, 18.2582900673151, 44.79165829718113, 83.05006876587868, 58.3725019544363, 29.859669841825962, 25.9227466955781, 19.55133408308029, 38.33770841360092, 43.42103764414787, 59.96012136340141, 89.45792332291603, 85.52572712302208, 75.36729902029037, 89.72780004143715, 35.53659372031689, 0.5421708198264241, 0.4947979305870831, 0.09697798057459295, 0.1377194092492573, 0.03412373494938947, 0.0629845741786994, 0.02541191384807462, 0.027414024189056363, 0.046666539055877365, 0.06001183115586173, 0.04203391225019004, 0.025072559401451144, 0.0653585339023266, 0.018779030215227976, 0.06823966992669739, 0.008800453942967579, 0.04183846765954513, 0.02957567216071766, 0.038995218274067156, 0.08186844759620726, 0.015007137008069549, 0.05211771764152218, 0.07047925639199093, 0.05545524109038524, 0.030900120036676526, 0.07975822489243001, 0.06616072132601403, 0.0542730740562547, 0.03594618618080858, 0.06345103625790216, 0.016271194472210482, 0.033416820733691566, 0.006375183056661626, 0.05479339750309009, 0.06454611968365498, 0.027575652820814867, 0.08530575651093386, 0.02507671913917875, 0.01082239075913094, 0.029386352143774275, 0.005519198275578674, 0.06984437874052674, 0.06335513593512587, 0.060446046918514185, 0.007102394547473523, 0.03920615519746207, 0.11773020334658213, 0.12485393788665533, 0.13248900475446135, 0.23188638675492257, 0.10929405485512689, 0.1360371385817416, 0.23344201734289527, 0.11425914155552164, 0.11346415296429768, 0.18509609828470275, 0.12416807468980551, 0.11950652638915926, 0.10169320099521428, 0.11580160644371063, 0.199829792836681, 0.17011712392559275, 0.19776680041104555, 0.18520609941333532, 0.1953872523154132, 0.14466301712673157, 0.1657641161000356, 0.148494933382608, 0.1396779518108815, 0.16740359453251585, 0.14409819821594283, 0.19685649691382423, 0.12143078172812238, 0.13977049762615934, 0.22491419134894386, 0.12866394594311714, 0.10502464254386723, 0.1013556425459683, 0.21750767627963796, 0.1740930910455063, 0.13937430951045826, 0.3053891676245257, 0.16839244693983346, 0.19209925609175116, 0.13376594404689968, 5.410334933549166, 58.76714117825031, 39.26362372934818, 74.98011499643326, 90.71694776415825, 85.26151970028877, 68.77054139971733, 46.217888966202736, 29.59953010082245, 33.30588921904564, 48.24324108660221, 54.95604068040848, 70.77709212899208, 75.9692171216011, 35.6621427834034, 8.900819085538387, 0.789623991586268, 0.29483493708539754, 0.424160641268827, 0.3059110161848366, 0.2537854725960642, 0.36083068640436977, 0.9872775699477643, 0.9019152692053467, 2.61447393335402, 0.6459443201310933, 11.446725223213434, 20.94784464687109, 26.02826703339815, 27.354464270174503, 28.090480975806713, 30.38619238883257, 33.501358330249786, 25.58607906103134, 29.020091593265533, 22.276139371097088, 26.671882197260857, 20.705499351024628, 21.604217626154423, 20.42134679853916, 28.627150878310204, 20.97136538475752, 26.209276020526886, 18.68768222630024, 19.060757607221603, 29.10470925271511, 21.394352987408638, 23.26353918761015, 27.238350100815296, 37.6786869764328, 27.079406529664993, 20.85202518850565, 16.145470440387726, 14.788272567093372, 12.532522659748793, 15.063341706991196, 14.419940281659365, 14.547905065119267, 9.083793517202139, 9.723927117884159, 11.41806811094284, 9.335272572934628, 7.764963135123253, 8.40598588809371, 5.303332200273871, 4.953715335577726, 2.844435218721628, 0.6662667577620596, 1.3651593960821629, 0.39424199669156224, 0.610813720850274, 0.33768078486900777, 0.334793800720945, 0.17025369394104928, 0.6881680700462312, 1.3387282518669963, 28.378231935203075, 65.54820030927658, 127.7618059515953, 108.56273576617241, 76.82439923286438, 44.87036347389221, 19.163152612745762, 48.22548843920231, 46.26449726521969, 57.609749883413315, 98.27655091881752, 92.41821527481079, 87.88168430328369, 101.08594536781311, 41.852861791849136, 1.298094775993377, 0.6108871044125408, 0.325982014182955, 0.3647027973784134, 0.23209032893646508, 0.21934732678346336, 0.19281979242805392, 0.22972002800088376, 0.1573488739086315, 0.18000745883909985, 0.12190067995106801, 0.1457297950400971, 0.2146339023602195, 0.149131755460985, 0.19689355976879597, 0.14764772728085518, 0.12751907925121486, 0.09086888807360083, 0.09479926506173797, 0.18330483580939472, 0.11081009928602725, 0.11177339954883792, 0.1530303611070849, 0.15148679784033448, 0.15298810321837664, 0.14078410807996988, 0.15269125899067149, 0.11046074068872258, 0.09690243736258708, 0.08166408239048906, 0.10429397589177825, 0.08964075983385555, 0.11676137408358045, 0.11995737368124537, 0.2808813436422497, 0.10942332955892198, 0.17882986343465745, 0.08850067999446765, 0.1108988378837239, 0.14364627480972558, 0.08435021911282092, 0.11627573490841314, 0.16738843987695873, 0.3409637790173292, 0.19233221624745056, 0.08346077738679014], [0.014167450717650354, 0.021719309843319934, 0.039938120607985184, 0.009467369181948015, 0.02793541076243855, 0.05412578000687063, 0.005100772168589174, 0.01764482818543911, 0.05289105036354158, 0.04097110853763297, 0.03731673255970236, 0.07282496997504495, 0.01815168907342013, 0.010663208431651583, 0.03248821587476414, 0.02753857883362798, 0.044703773673973046, 0.08000553076271899, 0.024554122865083627, 0.055647208719165064, 0.034105604281648993, 0.05970786231046077, 0.02925741511717206, 0.03293036890681833, 0.0768068445904646, 0.05335751244274434, 0.02540597110055387, 0.037562079160124995, 0.02761147257842822, 0.0068938315689592855, 0.03207046465831809, 0.09841074119322002, 0.09028017200762406, 0.01816279902413953, 0.11971722953603603, 0.027387651971366722, 0.004138849517403287, 0.40510828548576683, 7.9974679090082645, 52.149199694395065, 76.3020108640194, 19.537130445241928, 41.899055913090706, 67.89651229977608, 28.474883548915386, 15.178190544247627, 14.86608574166894, 48.271412774920464, 34.118023440241814, 50.36239877343178, 42.11362659931183, 33.544543012976646, 13.226437624543905, 2.992875915952027, 0.04700333309301641, 0.014705694247822976, 0.02780482802336337, 0.11628976892097853, 0.09931385327945463, 0.6725142756476998, 0.34348921850323677, 1.7167722224257886, 4.048707922920585, 6.714274864643812, 4.609610075131059, 9.346593115478754, 11.389562040567398, 8.185310829430819, 7.676006108522415, 15.819251295179129, 12.846994735300541, 9.272309001535177, 6.474945181980729, 10.168545059859753, 5.453592762351036, 6.920147817581892, 10.376193467527628, 14.47642520070076, 6.996448673307896, 9.163501840084791, 11.048534139990807, 9.099250137805939, 6.561683602631092, 14.08022141084075, 11.217379029840231, 8.284915834665298, 7.764640152454376, 5.514066992327571, 5.855555618181825, 4.841166324913502, 3.575191106647253, 3.703563418239355, 5.643474273383617, 4.839768474921584, 6.2321135122329, 3.7020199885591865, 8.960421737283468, 6.011390956118703, 4.443033188581467, 6.942785577848554, 3.615006795153022, 5.279624797403812, 3.665681113488972, 2.584528452716768, 1.801223165821284, 2.007310688495636, 0.7353287644218653, 1.3110426999628544, 0.9171382617205381, 0.500185388373211, 0.2853836864233017, 0.1552391707082279, 0.09089455154025927, 0.13455067615723237, 0.3339541348395869, 0.18420492735458538, 14.621337074786425, 37.749195992946625, 70.69202229380608, 117.99214258790016, 88.69148924946785, 43.25573891401291, 120.16239613294601, 110.317891985178, 34.42647188901901, 52.74530790746212, 68.61956030130386, 76.78998067975044, 61.39168694615364, 71.81053027510643, 29.252321831882, 4.801922980695963, 0.4040833795443177, 0.1032545609632507, 0.07728892887826078, 0.03670925500045996, 0.09839986872975715, 0.019608578768384177, 0.030397884584090207, 0.03831275782431476, 0.01085671972759883, 0.05939765200309921, 0.030605567189923022, 0.08750382723519579, 0.07282310718437657, 0.0202535199423437, 0.051395626505836844, 0.006060509658709634, 0.08306386938784271, 0.0080625930968381, 0.015695560614403803, 0.05976482585538179, 0.040560485649621114, 0.03664327807200607, 0.059136237905477174, 0.026151324855163693, 0.03654137748526409, 0.05354569511837326, 0.040552325735916384, 0.03161458189424593, 0.030728750716662034, 0.06667981651844457, 0.050374123311485164, 0.0342745133821154, 0.04780339055287186, 0.044055333273718134, 0.03802188417466823, 0.038363524436135776, 0.026214338759018574, 0.022446436450991314, 0.033695497186272405, 0.03405628114705905, 0.020945882497471757, 0.04757557348057162, 0.021752099783043377, 0.03599160932935774, 0.019852491168421693, 0.049479278750368394, 0.05865943028766196, 0.05293089627230074, 0.05799380174721591, 0.07640849682502449, 0.03198462043656036, 0.043229115108260885, 0.052059878362342715, 0.048719505066401325, 0.060633676694124006, 0.043630902728182264, 0.03624382821726613, 0.013639232674904633, 0.05540930214920081, 0.03746996007976122, 0.10057521489216015, 0.06583625436178409, 0.025906080300046597, 0.07887455707532354, 0.07906465820269659, 0.017638050521782134, 0.06336113248835318, 0.04589677235344425, 0.032692595923435874, 0.044756722199963406, 0.015024928143247962, 0.07957975321915, 0.08156996322213672, 0.06802978314226493, 0.05080632785393391, 0.06281539419433102, 0.08255160195403732, 0.05699283748981543, 0.06065775938623119, 0.04157566945650615, 0.061008657939964905, 0.3266862529562786, 11.912068203091621, 64.57343101501465, 89.0142135322094, 22.4780947342515, 60.735971331596375, 91.81619077920914, 45.70115469396114, 27.263877131044865, 22.00822524726391, 45.14065057039261, 32.79509022831917, 41.325237303972244, 42.84781560301781, 38.24649050831795, 20.26615932583809, 3.9547092793509364, 0.19568751042243093, 0.03294941612693947, 0.04265265561116394, 0.17689475789666176, 0.7274580805096775, 1.704273030627519, 2.2419312363490462, 6.1759814992547035, 8.699390944093466, 10.628365986049175, 9.354626834392548, 9.454134944826365, 12.870808057487011, 5.1040509436279535, 5.221429970115423, 2.2995822178199887, 2.964172731153667, 2.660505138337612, 7.279939586296678, 3.60102117061615, 3.332328088581562, 6.827620407566428, 8.868155088275671, 11.080906502902508, 11.654782108962536, 14.666111022233963, 15.168558061122894, 13.331579882651567, 9.421487096697092, 11.14926578477025, 4.670804841443896, 4.376813191920519, 2.3710701568052173, 2.587636448442936, 3.0516694486141205, 3.6001061322167516, 2.2520118579268456, 2.460234984755516, 2.990957968868315, 4.074633456766605, 5.541722858324647, 4.085659040138125, 4.9588982574641705, 6.044662920758128, 2.1802550833672285, 4.05490824021399, 5.875672213733196, 5.121180899441242, 4.081813171505928, 3.745800289325416, 4.085810082033277, 4.134540567174554, 3.107468504458666, 1.951418062672019, 1.7735857050865889, 2.747244033962488, 2.4188799038529396, 0.3343631175812334, 0.05674028092471417, 0.1458852452924475, 0.22161317785503343, 0.58534552808851, 14.165324494242668, 41.43720209598541, 64.8713730275631, 91.36713087558746, 64.59476307034492, 31.08600653707981, 120.60299769043922, 106.53652489185333, 33.376793414354324, 70.3960333764553, 80.43412193655968, 90.80273196101189, 69.36872810125351, 89.61322098970413, 51.165238693356514, 10.57030700147152, 0.3925487125525251, 0.0658520769502502, 0.07406247153994627, 0.03460288033238612, 0.12481077457778156, 0.08252243555034511, 0.02213219257100718, 0.039245032603503205, 0.03115055034868419, 0.09696911190985702, 0.059008399257436395, 0.10669017035979778, 0.09558767822454683, 0.047851982672000304, 0.10660604792064987, 0.011866212189488579, 0.04556285413855221, 0.06534362415550277, 0.07213106189738028, 0.025895714352373034, 0.052118463499937207, 0.014738445224793395, 0.03611466854636092, 0.08201073957025073, 0.029008480232732836, 0.04906228081381414, 0.027707682747859508, 0.05987638178339694, 0.030632080415671226, 0.04858316511672456, 0.0212811273013358, 0.023904096124169882, 0.08314571343362331, 0.02852656107279472, 0.07062866556225345, 0.04840414796490222, 0.05064229837444145, 0.07995967345777899, 0.028375675028655678, 0.0370302041847026, 0.0387277890695259, 0.07840635094908066, 0.016226741681748535, 0.07347583348746412, 0.06386824199580587, 0.11558281388715841, 0.16074066690634936, 0.17026856658048928, 0.15126762678846717, 0.17359721765387803, 0.13694839202798903, 0.08603623020462692, 0.1198672027385328, 0.1082562652300112, 0.22800425678724423, 0.1746016403194517, 0.10372183940489776, 0.14503875165246427, 0.21115210169227794, 0.09105300749070011, 0.15093259164132178, 0.20437406696146354, 0.07893219226389192, 0.13148450787412003, 0.15210490295430645, 0.14619092107750475, 0.1573791090049781, 0.18405076843919232, 0.15235641680192202, 0.1111407186544966, 0.14605553849833086, 0.15207420772640035, 0.1455516499117948, 0.12981780746486038, 0.15117689181352034, 0.2113602592726238, 0.19337285571964458, 0.2079631673404947, 0.25264173396863043, 0.1760865145479329, 0.13350583612918854, 0.40555321786087006, 16.81871261447668, 81.60667061805725, 100.285784304142, 30.53511019796133, 61.02053806185722, 89.20802593231201, 39.95686233043671, 21.980857215821743, 21.899771466851234, 68.50441128015518, 52.81793721020222, 70.74620738625526, 61.9454388320446, 51.75600439310074, 25.15802063047886, 5.967958811670542, 0.4938212048728019, 0.12953144236234948, 0.1529307648888789, 0.19159786112140864, 0.7290378457400948, 1.6621774644590914, 1.580846153665334, 5.8598550874739885, 15.15215054154396, 20.924200415611267, 18.935888707637787, 24.63219154626131, 27.69232504069805, 24.700610674917698, 27.189583517611027, 31.5003078058362, 26.67236667126417, 23.61680433154106, 19.320143088698387, 22.662232853472233, 17.42067251354456, 21.49223953485489, 25.24952732026577, 30.375201478600502, 19.3676595389843, 27.765885293483734, 26.675172820687294, 26.690816581249237, 19.036319218575954, 33.198799565434456, 25.93544751405716, 26.320665143430233, 22.492790445685387, 18.845176175236702, 15.980257205665112, 14.896910637617111, 14.106143619865179, 11.038715466856956, 13.361172694712877, 11.99097951874137, 15.360667202621698, 8.481493536382914, 17.856980301439762, 14.495527725666761, 12.553333193063736, 17.02020440250635, 14.498797450214624, 13.262176606804132, 9.930833615362644, 9.6466563642025, 9.79726793244481, 10.537066385149956, 3.7521383492276073, 3.9011449785903096, 4.175563640892506, 4.874425940215588, 4.533966584131122, 0.49280728271696717, 0.4602807015180588, 0.312191040138714, 0.9801132325083017, 0.9682705148588866, 22.414393052458763, 51.87393106520176, 97.08634838461876, 144.93004471063614, 112.67561227083206, 62.88905739784241, 128.61362904310226, 124.05979380011559, 50.28111353516579, 69.27167370915413, 86.11688420176506, 100.9955558180809, 79.67913284897804, 101.53134226799011, 59.24911871552467, 9.815316963940859, 0.6097101175691932, 0.13245480658952147, 0.24606645398307592, 0.1715783978579566, 0.3357850428437814, 0.21187541366089135, 0.12135518656577915, 0.2178993818233721, 0.08847315373714082, 0.20080276328371838, 0.16082911606645212, 0.24621031188871711, 0.1826859885477461, 0.12558179179904982, 0.1983695282251574, 0.10761614801594988, 0.23115125979529694, 0.10302053953637369, 0.10639788291882724, 0.11356230199453421, 0.19044312386540696, 0.18866827769670635, 0.1283287029946223, 0.2013867741334252, 0.08316241917782463, 0.1966199596063234, 0.13847280788468197, 0.16775516472989693, 0.09253547716070898, 0.13836080295732245, 0.08345337075297721, 0.1299272890901193, 0.08777068127528764, 0.14338417793624103, 0.13132570311427116, 0.0957749888766557, 0.14314762578578666, 0.21708027343265712, 0.12882307724794373, 0.15791732934303582, 0.10471023168065585, 0.17477527318987995, 0.09970158833311871, 0.18402752437395975], [0.08141377824358642, 0.017693895279080607, 0.0388051616755547, 0.04368104964669328, 0.07841819562599994, 0.06697555494611152, 0.038089460431365296, 0.04137437674216926, 0.020382245456858072, 0.021204034856054932, 0.029288026853464544, 0.05893666697375011, 0.013979231862322195, 0.11715711691067554, 0.05868378757440951, 0.038959309458732605, 0.08713929913938046, 0.059089400965604, 0.0753641095070634, 0.03717484876688104, 0.12654401594772935, 0.03555411698471289, 0.023886768831289373, 0.04455288020835724, 0.012276727466087323, 0.05948073914623819, 0.0378041120711714, 0.04072060401085764, 0.0582322315312922, 0.022407176838896703, 0.03891412750817835, 0.036176704670651816, 0.05355220375349745, 0.07600431577884592, 0.04248955381626729, 0.07098183137713932, 0.965970866382122, 19.89924531430006, 86.45888105034828, 97.44903892278671, 86.63992613554001, 49.08372178673744, 23.66028729826212, 13.525932803750038, 25.87141714990139, 65.3861466050148, 58.926280438899994, 36.355582773685455, 45.52582070231438, 52.34026104211807, 30.500659346580505, 11.083855144679546, 1.6512908111326396, 0.062211397307692096, 0.07984662952367216, 0.03216941149730701, 0.014331816018966492, 0.18621444061864167, 0.9341729257721454, 0.8145975577645004, 7.6553162187337875, 7.7198457811027765, 6.513055711984634, 6.9867002964019775, 7.275119069963694, 10.399080589413643, 9.361894894391298, 6.509944153949618, 2.843621112406254, 6.067745257169008, 3.635935834608972, 6.9244886096566916, 4.618561919778585, 3.2774433586746454, 4.900933792814612, 5.25729957036674, 10.855739135295153, 15.259453933686018, 14.643181152641773, 11.41236936673522, 9.261490032076836, 8.24778612703085, 6.461743265390396, 5.909374030306935, 5.585752995684743, 3.5880106687545776, 9.440508875995874, 10.167776551097631, 29.491627290844917, 12.05339876934886, 7.64016168192029, 7.910063099116087, 12.809453699737787, 11.305926628410816, 14.998125806450844, 17.562372609972954, 14.23279082402587, 15.889245439320803, 14.686284139752388, 10.793155543506145, 3.486377759836614, 1.4913033647462726, 2.640546471811831, 3.844953356310725, 2.5815888354554772, 2.4400694668293, 3.6323300655931234, 2.577047129161656, 1.8893358064815402, 1.7134628375060856, 1.2030958360992372, 0.38179917843081057, 0.0692384596914053, 0.1476740586804226, 0.04545951007457916, 0.16000369942048565, 0.10810540145030245, 7.281462354585528, 29.85213104635477, 42.578638046979904, 47.67481058835983, 56.21658504009247, 28.06755680590868, 43.29648032784462, 43.42138722538948, 19.10353761166334, 39.479866325855255, 56.659671664237976, 63.75069156289101, 61.16647683084011, 72.88169279694557, 70.68842008709908, 12.467368505895138, 0.4694293637294322, 0.020438132887647953, 0.08348287854460068, 0.01592901986441575, 0.05394599102146458, 0.06819679605541751, 0.08547091405489482, 0.007992245846253354, 0.04896016500424594, 0.03760945415706374, 0.0358334428165108, 0.024251278373412788, 0.03562591606169008, 0.05348238250007853, 0.02282571844261838, 0.053917514815111645, 0.11434710831963457, 0.02902372394601116, 0.05322642689861823, 0.06737817748216912, 0.04386527667520568, 0.033561873497092165, 0.02735950045462232, 0.0247704681896721, 0.02536520863941405, 0.03292091023467947, 0.027359904925106093, 0.011097420483565656, 0.1141810453555081, 0.045461632616934367, 0.01814690222090576, 0.022014029673300683, 0.004864071124757174, 0.014635732914030086, 0.09904345919494517, 0.015492942238779506, 0.08328663243446499, 0.052974163481849246, 0.042420945974299684, 0.07295457122381777, 0.005588023659583996, 0.036063289662706666, 0.03904123885149602, 0.0549430293176556, 0.022685565709252842, 0.03172089454892557, 0.029393413678917568, 0.032088535954244435, 0.02555601666244911, 0.019720130985660944, 0.06678003614069894, 0.04668310379202012, 0.03118535336398054, 0.019500852322380524, 0.007651335208720411, 0.009108242065849481, 0.03868096697260626, 0.06350381780066527, 0.05134136066772044, 0.04055750592669938, 0.07331314729526639, 0.023590273412992246, 0.05519692174857482, 0.01786945587809896, 0.029925858252681792, 0.13656532508321106, 0.056208053429145366, 0.03806915527093224, 0.027680920902639627, 0.1068280910840258, 0.05250320398772601, 0.06523161922814324, 0.08309448297950439, 0.08269589772680774, 0.027992188770440407, 0.055174627632368356, 0.08219814670155756, 0.13680990727152675, 0.08127987995976582, 1.6224082047119737, 27.9953720793128, 101.06594324111938, 107.38666847348213, 102.58104354143143, 58.40957656502724, 29.431087039411068, 21.051068007946014, 22.615704350173473, 41.868775337934494, 31.6868606954813, 33.38473878800869, 42.891555055975914, 44.955585300922394, 32.375391349196434, 14.639900028705597, 1.85520532540977, 0.04411474961671047, 0.03358428264618851, 0.02871669188607484, 0.08643534980365075, 0.1475142891285941, 0.4602399130817503, 1.3560153055004776, 2.5851713307201862, 5.188218802213669, 5.873797964304686, 8.451670836657286, 7.479930454865098, 5.913513908162713, 5.304566184058785, 2.445766073651612, 2.468052115291357, 1.5087990509346128, 1.7789222812280059, 2.354145389981568, 1.6264561749994755, 0.7307065499480814, 3.3629285590723157, 4.26410648971796, 4.648340921849012, 5.572266569361091, 6.948324255645275, 6.870824564248323, 11.657759249210358, 11.287707556039095, 5.777317341417074, 3.7782754842191935, 2.1602265955880284, 3.0408998765051365, 7.936870660632849, 10.708716474473476, 20.015226490795612, 14.525139536708593, 9.74326428025961, 8.835248854011297, 12.641554959118366, 14.226905889809132, 17.580938413739204, 18.46987411379814, 16.893114522099495, 17.918328009545803, 16.29520520567894, 9.276790861040354, 3.8680131314322352, 2.212206143885851, 2.63364699203521, 3.4356172336265445, 1.6260491218417883, 1.085184719413519, 3.2557526975870132, 1.9013754604384303, 3.7234897864982486, 2.3548362404108047, 1.9718400668352842, 1.0866926447488368, 0.23714457725873217, 0.02405157014436554, 0.054062693743617274, 0.08856988526531495, 0.21886199188884348, 6.565870502963662, 29.754962660372257, 53.84709298610687, 51.88591182231903, 41.78202599287033, 40.422595739364624, 61.098145097494125, 40.724519938230515, 27.464597560465336, 62.6661841571331, 69.09246012568474, 74.5817443728447, 70.32517477869987, 82.88483083248138, 89.40054640173912, 24.755517728626728, 0.13836901111062616, 0.03835368355794344, 0.06837300417828374, 0.09513755081570707, 0.07083036645781249, 0.06324091940768994, 0.03463688553893007, 0.06580611574463546, 0.03467483154963702, 0.035715411650016904, 0.04215546490740962, 0.013396340727922507, 0.06414118164684623, 0.03838856820948422, 0.012609603891178267, 0.03875481437717099, 0.11467335643828847, 0.007438869461111608, 0.018849159459932707, 0.052298308146419004, 0.08589971213950776, 0.01615978697373066, 0.012036316147714388, 0.012687294693023432, 0.020025888406962622, 0.07201683794846758, 0.027080779473180883, 0.020141370296187233, 0.07414392966893502, 0.05346009951608721, 0.0013883909718970244, 0.05147594914888032, 0.03060402908886317, 0.01802569651772501, 0.06618305254960433, 0.02044019605818903, 0.05348031561879907, 0.04970125883119181, 0.10389485629275441, 0.043732142803492025, 0.010892384561884683, 0.01733452510961797, 0.033344635739922523, 0.14464476029388607, 0.1412876255926676, 0.1635243440978229, 0.11524187124450691, 0.17991817847359926, 0.14379828149685636, 0.11751350364647806, 0.14562892232788727, 0.15934427152387798, 0.14824243990005925, 0.16937595588387921, 0.12988580303499475, 0.13935636437963694, 0.23151552071794868, 0.2840606449171901, 0.12465624458855018, 0.24437085434328765, 0.16349587531294674, 0.10403811305877753, 0.11816409256425686, 0.2479549526469782, 0.07361712356214412, 0.17520404158858582, 0.17199701367644593, 0.15640818688552827, 0.18355165928369388, 0.19759490416618064, 0.21042488602688536, 0.18350935686612502, 0.18223396124085411, 0.19101548299659044, 0.20345367025583982, 0.16577553033130243, 0.2415180832031183, 0.16929583362070844, 0.27035623497795314, 1.9658640562556684, 36.93803831934929, 117.02517807483673, 116.98006689548492, 111.0576742887497, 71.61575272679329, 38.99224229156971, 24.451492242515087, 39.72654528915882, 87.232466340065, 84.70263049006462, 52.9885670542717, 61.199614852666855, 72.58495151996613, 48.02122659981251, 19.656109660863876, 3.926625461317599, 0.15117144444957376, 0.14023254392668605, 0.14532682369463146, 0.16638518980471417, 0.5889889982063323, 2.6347938179969788, 5.6921240128576756, 17.01896946877241, 19.056790620088577, 20.555506199598312, 23.94297882914543, 20.748148262500763, 27.469375804066658, 26.79498989135027, 21.08570694923401, 15.254082921892405, 17.829319685697556, 11.719499286264181, 19.150907769799232, 15.347617752850056, 13.128907307982445, 17.49246396124363, 18.042710535228252, 24.876478537917137, 30.678964778780937, 30.394487343728542, 26.556974463164806, 25.598225109279156, 23.935977704823017, 17.201574370265007, 21.913277842104435, 17.109193727374077, 8.966535609215498, 13.891059011220932, 12.6375100761652, 33.306117206811905, 19.554107934236526, 12.645808830857277, 13.179612737149, 18.52131575345993, 17.239901013672352, 22.34521396458149, 25.2426078915596, 20.856907926499844, 25.445030629634857, 27.06940356642008, 19.78006850928068, 11.857889760285616, 8.945498038083315, 12.071757484227419, 12.612105589359999, 10.014992449432611, 10.24330984801054, 11.955915000289679, 9.90347508341074, 7.200418878346682, 8.080281615257263, 5.270586032420397, 2.0430791191756725, 1.032185044605285, 0.49501158006023616, 0.30535452417097986, 0.3793616982875392, 0.5028670351020992, 12.056988626718521, 43.690857365727425, 60.18965944647789, 63.62988844513893, 77.58698031306267, 39.59905453026295, 55.53125001490116, 54.576448649168015, 33.89138080179691, 55.14659285545349, 72.31665551662445, 88.32574367523193, 80.95723986625671, 94.29923593997955, 97.33389750123024, 24.37546782195568, 0.4235719400458038, 0.12575052649481222, 0.12154737312812358, 0.20225110900355503, 0.18785948515869677, 0.12583674921188504, 0.2711275639012456, 0.18532319547375664, 0.10232801185338758, 0.15240337990690023, 0.17827303003286943, 0.058069200240424834, 0.1179331139428541, 0.14384171197889373, 0.09395686807692982, 0.13597637152997777, 0.26207606366369873, 0.0820193336403463, 0.10569059391855262, 0.14497311611194164, 0.16034413740271702, 0.08606754883658141, 0.11820559346233495, 0.11799815576523542, 0.1859395342762582, 0.25473052344750613, 0.14280326926382259, 0.15044647007016465, 0.27766238199546933, 0.1290736411465332, 0.2034842170542106, 0.10626041490468197, 0.11248624723521061, 0.1286094426177442, 0.24082680232822895, 0.13243879104265943, 0.12486463965615258, 0.1844544819323346, 0.14787752588745207, 0.22354617569362745, 0.15553899836959317, 0.09082121992832981, 0.20704324560938403], [0.09499693609541282, 0.05557579926971812, 0.10692835523514077, 0.07210578434751369, 0.03969764249632135, 0.02728476803895319, 0.10292259088600986, 0.04240595459123142, 0.159848828043323, 0.08245959790656343, 0.011746857217076467, 0.1070548543066252, 0.056560425146017224, 0.04383648876682855, 0.020753822100232355, 0.05743293477280531, 0.09823008760577068, 0.08459766599116847, 0.026396628782094922, 0.057206809797207825, 0.09621586170396768, 0.014132112428342225, 0.013809070387651445, 0.062352776440093294, 0.07342882585362531, 0.0020542077163554495, 0.07075396235450171, 0.1291393063729629, 0.18343144620303065, 0.06374758362653665, 0.053071132497279905, 0.23817380249965936, 0.042088148402399383, 0.04057374782860279, 0.116213928849902, 1.5952415624633431, 49.44025285542011, 92.49116376042366, 87.04425483942032, 68.75519022345543, 90.12892171740532, 68.14808160066605, 52.00293034315109, 48.38517867028713, 47.8847037255764, 58.84630613029003, 51.646171286702156, 59.37941752374172, 40.0378055870533, 15.59896381571889, 3.2300470769405365, 0.1290164957754314, 0.17193541541928425, 0.0799569497758057, 0.06666447632596828, 0.09977499415981583, 0.19115378963761032, 0.896425157552585, 0.16724523506127298, 2.6393279246985912, 3.977605188265443, 8.237913306802511, 6.31410788744688, 7.0582884550094604, 6.835134979337454, 5.0681181717664, 7.443627202883363, 5.678279455751181, 3.085705884732306, 5.227993642911315, 5.982158649712801, 11.749635469168425, 9.908448066562414, 14.25345791503787, 12.580714523792267, 10.103536248207092, 6.857451181858778, 11.315492615103722, 10.66073739901185, 11.587486770004034, 10.876071844249964, 10.804194901138544, 7.044097641482949, 10.367915611714125, 24.962956197559834, 53.817047998309135, 85.88895723223686, 108.59852224588394, 105.79692497849464, 116.46096155047417, 64.15484547615051, 32.36895449459553, 31.454856544733047, 41.33729785680771, 46.81932829320431, 49.517981484532356, 43.91677424311638, 48.70209686458111, 31.19974583387375, 24.672180600464344, 13.212572168558836, 5.690044574439526, 1.3035988993942738, 1.5319635579362512, 2.603917862288654, 0.36910806724336, 1.9207914685830474, 1.5993079380132258, 1.1381023423746228, 1.4341202331706882, 0.7695759704802185, 0.11933976580621675, 0.3328391321701929, 0.11945666148676537, 0.24297566124005243, 0.04405878054967616, 0.12250088446307927, 0.12255424488103017, 1.5059705777093768, 14.3178179115057, 37.95410759747028, 40.546001717448235, 31.62841983139515, 21.58094957470894, 30.328691974282265, 37.032755836844444, 16.50687664747238, 27.60240286588669, 53.46756175160408, 68.95002096891403, 64.2294354736805, 69.2306587100029, 71.17978692054749, 20.96951298415661, 0.5541830440051854, 0.27291136037092656, 0.025900467808241956, 0.26559250778518617, 0.30150832899380475, 0.07346619298914447, 0.06766819395124912, 0.08762980680330656, 0.052637970584328286, 0.03595605674490798, 0.17672548885457218, 0.05114637620863505, 0.1891511189751327, 0.1710809807991609, 0.18511417700210586, 0.056896781316027045, 0.04426015861099586, 0.026135465159313753, 0.033840813412098214, 0.046756004958297126, 0.03838605603959877, 0.08998936144053005, 0.026871818517975044, 0.03362449220730923, 0.1284829806536436, 0.1073174929479137, 0.02326914054719964, 0.0767899607308209, 0.014866190176689997, 0.10507263723411597, 0.11423127391026355, 0.2065449973451905, 0.10442742888699286, 0.045476757586584426, 0.07134244093322195, 0.01589613159012515, 0.03286060702521354, 0.13003611762542278, 0.029131075607438106, 0.06542263319715858, 0.062291037174873054, 0.057873343757819384, 0.06880192100652494, 0.02506902121240273, 0.019143795798299834, 0.02585061218269402, 0.0079119630936475, 0.05106632444949355, 0.013127171187079512, 0.0420300048426725, 0.0318413080094615, 0.024317502065969165, 0.032815009471960366, 0.07986067837919109, 0.020292449298722204, 0.0688390654977411, 0.06820532333222218, 0.04697739874245599, 0.0984273207723163, 0.0633131897484418, 0.09718380781123415, 0.030218921237974428, 0.0830508818035014, 0.07873344511608593, 0.03987953547039069, 0.04290201351977885, 0.0859934082836844, 0.019820020352199208, 0.06075993827835191, 0.058401916176080704, 0.10581376074696891, 0.1347478202660568, 0.03453620578511618, 0.13527256320230663, 0.009282348055421608, 0.16491981921717525, 0.03722993467818014, 5.305725121870637, 67.97994822263718, 108.88265579938889, 99.00608897209167, 78.93966972827911, 95.98971962928772, 92.19152703881264, 61.029551178216934, 28.01435776054859, 36.12834736704826, 46.6407036781311, 52.21160374581814, 53.39379630982876, 40.36676153540611, 18.615184016525745, 4.608175652101636, 0.1577665694640018, 0.12647458061110228, 0.0870992305863183, 0.0898784474702552, 0.12251810228917748, 0.22528468631207943, 0.3301315993303433, 0.24150741111952811, 0.5330067209433764, 3.326344834640622, 5.118885347619653, 3.1773557793349028, 3.7004737090319395, 4.44940117187798, 1.2666318705305457, 4.302670620381832, 6.7980024218559265, 6.8178207334131, 7.759935054928064, 9.930048007518053, 14.823372233659029, 14.741018302738667, 17.653738707304, 15.886272098869085, 13.089205138385296, 8.725220058113337, 9.272619634866714, 6.843146374449134, 5.950923850759864, 3.2004934502765536, 3.3923126198351383, 3.9581079594790936, 7.274062251672149, 24.067011773586273, 53.913106843829155, 83.37364420294762, 108.35261464118958, 109.7539034485817, 113.03313508629799, 68.29988345503807, 36.13492861390114, 38.3208829164505, 45.54196983575821, 51.96870557963848, 55.32518707215786, 51.41727916896343, 49.181634932756424, 38.89688640832901, 31.82536706328392, 17.441162914037704, 7.01585185714066, 1.8041642080061138, 1.4947755471803248, 0.8855710399802774, 0.6267584965098649, 0.7536266825627536, 1.4769441727548838, 0.9755863097961992, 1.81829244364053, 1.5558740124106407, 0.4985699406825006, 0.2907240326749161, 0.15441185416420922, 0.1843214890686795, 0.05798485144623555, 0.10183543359744363, 0.05494071381690446, 2.451110486872494, 14.005450922995806, 35.40593013167381, 36.97248727083206, 22.563185468316078, 20.29756274074316, 31.372796148061752, 26.278544403612614, 28.79673007875681, 47.6878172904253, 73.1087838113308, 82.62291848659515, 76.1116410791874, 80.45393407344818, 93.8832038640976, 43.89747887849808, 1.55637665418908, 0.25734905793797225, 0.09361534655909054, 0.3068387304665521, 0.10501049720915034, 0.054813862225273624, 0.06472302542533726, 0.013216773459134856, 0.018549480228102766, 0.04546474963717628, 0.09978024114388973, 0.02437333754642168, 0.14272176660597324, 0.09120610513491556, 0.16442627616925165, 0.05978831111860927, 0.045193843470769934, 0.026480979431653395, 0.036826436407864094, 0.0445028483227361, 0.06706836793455295, 0.08588749638875015, 0.022275083829299547, 0.02412761801679153, 0.053331448216340505, 0.004786041718034539, 0.01825327239203034, 0.04842492809984833, 0.0658742300583981, 0.009443780945730396, 0.06571635298314504, 0.06634235454839654, 0.05345482655684464, 0.031161367151071317, 0.060601968434639275, 0.023148200161813293, 0.06168469881231431, 0.04601850683684461, 0.021184028410061728, 0.08227826154325157, 0.031191071611829102, 0.0393412631819956, 0.23823440627893433, 0.15292727679479867, 0.2100122964475304, 0.2450019321986474, 0.26094841479789466, 0.14390080177690834, 0.26653907261788845, 0.2426211818237789, 0.22674680629279464, 0.14812516572419554, 0.20245420513674617, 0.22800584498327225, 0.12149766407674178, 0.13435425935313106, 0.1584188875858672, 0.11653025445411913, 0.17158244998427108, 0.2873825276037678, 0.18225604755571112, 0.1992411509854719, 0.33341774018481374, 0.13161511102225631, 0.19222487200750038, 0.13534229539800435, 0.2248157825670205, 0.08273521671071649, 0.1586851553292945, 0.1577316439943388, 0.20445393689442426, 0.2781812025932595, 0.22906874888576567, 0.3180301986867562, 0.15443115000380203, 0.27777397132012993, 0.32641260826494545, 7.638524919748306, 86.78496435284615, 121.51370242238045, 106.51463806629181, 88.30505758523941, 109.47132781147957, 89.74847093224525, 78.37808266282082, 70.16074240207672, 72.23902568221092, 92.43317127227783, 73.77769991755486, 82.85554200410843, 60.53792595863342, 25.343226492404938, 7.485104352235794, 0.5165144184138626, 0.2891384490067139, 0.1303185790311545, 0.3055793058592826, 0.20375848514959216, 0.47590774891432375, 1.6501549095846713, 2.4876049160957336, 8.877133056521416, 12.434189636260271, 19.736777432262897, 14.077905435115099, 21.735240295529366, 17.21243228763342, 15.299913212656975, 17.446307837963104, 13.768967762589455, 7.230192180722952, 7.472229218110442, 9.814621601253748, 20.29560774564743, 15.703784041106701, 20.168037191033363, 18.737345561385155, 17.865583039820194, 11.816211696714163, 18.887866884469986, 19.568685851991177, 26.787772178649902, 26.59462284296751, 24.55712277442217, 18.335120044648647, 16.424265280365944, 26.6302877292037, 48.558973744511604, 78.43068704009056, 102.51298919320107, 102.30613589286804, 109.00300294160843, 74.92380201816559, 41.01890914142132, 37.84018211066723, 50.09458914399147, 51.652026772499084, 57.019383162260056, 54.70322884619236, 55.44960379600525, 38.53819325566292, 34.30252254009247, 20.23712318390608, 12.329639196395874, 9.95820164680481, 5.8327364176511765, 6.345305163413286, 6.770216412842274, 7.012838143855333, 7.993990145623684, 4.529693713411689, 6.669511366635561, 4.556075222790241, 1.5572002599947155, 1.351914256811142, 0.46524317585863173, 0.43857219920028, 0.08636441532871686, 0.38895410543773323, 0.28895953204482794, 3.287481707520783, 24.319559521973133, 60.26601254940033, 59.902455657720566, 46.962523609399796, 33.315498903393745, 44.99823801219463, 53.909899815917015, 27.50438142567873, 42.41215378046036, 67.69674181938171, 88.22019293904305, 86.17236882448196, 90.71132406592369, 109.06039506196976, 46.485759392380714, 0.9719777503050864, 0.43334391724783927, 0.16131808748468757, 0.5051641305908561, 0.2968572301324457, 0.21997594070853665, 0.2098482521250844, 0.13905275176512077, 0.19806796393822879, 0.11985643417574465, 0.2075503848027438, 0.18526084022596478, 0.2708582830382511, 0.29692918877117336, 0.21124399441760033, 0.20061546005308628, 0.23679190868278965, 0.12821105774492025, 0.1535372924990952, 0.11873838127939962, 0.1746729903970845, 0.31173455994576216, 0.09229624585714191, 0.067273564345669, 0.1303061851649545, 0.2814674028195441, 0.16796893294667825, 0.1748558704275638, 0.1967667564167641, 0.18790074856951833, 0.20304296573158354, 0.3164239536272362, 0.1424055523239076, 0.1625721389427781, 0.18137574166757986, 0.10781085045891814, 0.11412958483560942, 0.15741894749226049, 0.2753239340381697, 0.21951083675958216, 0.12663861009059474, 0.1929978039697744], [0.08007129988982342, 0.13220914086559787, 0.11931508197449148, 0.10966622707201168, 0.061021155706839636, 0.05016270028136205, 0.06977472818107344, 0.10750415051006712, 0.30681569420266896, 0.11207083749468438, 0.14284922304796055, 0.03958219771448057, 0.029949189520266373, 0.11152653154567815, 0.05745076487073675, 0.02922752140875673, 0.05554328206926584, 0.0181023418190307, 0.18582608958240598, 0.155118883412797, 0.03145291244436521, 0.061015611863695085, 0.0076119823643239215, 0.0673889386234805, 0.09978107234928757, 0.1356197547283955, 0.10004235286032781, 0.12610142875928432, 0.18373148166574538, 0.14585011202143505, 0.08265600728918798, 0.17526210722280666, 0.2363064105156809, 0.16269315354293212, 6.711014164611697, 73.01881983876228, 86.8177641928196, 84.3457156419754, 85.398920327425, 92.07285180687904, 53.461554273962975, 31.11541125923395, 27.113623693585396, 32.04542465507984, 39.42483767867088, 44.70006421208382, 42.81367443501949, 29.36205044388771, 7.1981181018054485, 1.9483605329878628, 0.0247262046468677, 0.027707578847184777, 1.5927885565906763, 0.15168143349001184, 0.24836126365698874, 0.30995922395959496, 0.0838775081501808, 0.24870208755601197, 0.9586451563518494, 0.6453899655025452, 0.9531913802493364, 3.470012512989342, 3.41109786182642, 4.58133484236896, 10.491097401827574, 12.197197303175926, 21.911174654960632, 30.354640781879425, 41.24394066631794, 42.393071204423904, 42.407624423503876, 54.13384459912777, 50.03200650215149, 47.374045327305794, 52.136352583765984, 49.72478538751602, 41.434717029333115, 38.89082573354244, 23.33276007324457, 15.851196181029081, 18.651789352297783, 20.6376026943326, 36.54812604188919, 54.16038617491722, 112.2628404200077, 111.5192811191082, 99.15469139814377, 94.1348871588707, 98.73614385724068, 98.29595267772675, 78.27931836247444, 54.485629722476006, 67.54528194665909, 82.46091037988663, 72.1907226741314, 75.51908567547798, 72.22979217767715, 72.26110249757767, 64.39079001545906, 54.70384821295738, 38.06152403354645, 16.090080812573433, 7.603647066280246, 4.813212174922228, 1.7705633235163987, 0.8843631797935814, 0.156328524753917, 0.8922061964403838, 1.4128893474116921, 0.8559661754406989, 2.9803866986185312, 0.5601705133449286, 0.15643616585293785, 0.082799108204199, 0.11598168857744895, 0.0679318567563314, 0.08211187203414738, 0.014936467850930057, 0.11675996400299482, 0.9567622980102897, 7.8964427299797535, 30.73577743023634, 52.42549046874046, 72.50008687376976, 83.67451205849648, 57.38508693873882, 41.85108728706837, 21.527370549738407, 17.119643166661263, 40.41319124400616, 63.09713803231716, 54.967983439564705, 65.35709336400032, 69.83125448226929, 44.8412000387907, 3.360191755928099, 0.18720936379395425, 0.1889001246308908, 0.0961208890657872, 0.12727515015285462, 0.05376571221859194, 0.05443285474029835, 0.09161646827124059, 0.023847687334637158, 0.061932835888001136, 0.28502956323791295, 0.21039298851974308, 0.2111487026559189, 0.2737241011345759, 0.31535873422399163, 0.13241131673566997, 0.010837295867531793, 0.0915417043142952, 0.050119258667109534, 0.07636973445187323, 0.02230572710686829, 0.03247146560170222, 0.13909284258261323, 0.04464911078684963, 0.08661278247018345, 0.08602931338828057, 0.062237769525381736, 0.08193696266971529, 0.1099308324046433, 0.26171057077590376, 0.18311506864847615, 0.2766251267166808, 0.11877436059876345, 0.04517164212302305, 0.05746010479924735, 0.036745200923178345, 0.06715853145578876, 0.038624240914941765, 0.06520004084450193, 0.02501018559996737, 0.034591696166899055, 0.09199137159157544, 0.046502253535436466, 0.07200308595201932, 0.10140835729544051, 0.017926380460266955, 0.059342870372347534, 0.10434407828142866, 0.1070636413351167, 0.1267741559422575, 0.020537593663902953, 0.049944620186579414, 0.023083501582732424, 0.03288609237642959, 0.0786377303302288, 0.08308146570925601, 0.01547828760521952, 0.03543567763699684, 0.07410923426505178, 0.10826660334714688, 0.08937887076172046, 0.08258092420874164, 0.03431987344811205, 0.03525553613144439, 0.12352302219369449, 0.09503578752628528, 0.08940070474636741, 0.17756068700691685, 0.1472460918012075, 0.15655919909477234, 0.10817879985552281, 0.09863192346529104, 0.1892809206037782, 0.2991641219705343, 0.123450581158977, 16.14670157432556, 97.1166555583477, 99.63165700435638, 95.16995161771774, 95.31476944684982, 109.222501963377, 81.89322084188461, 53.495752438902855, 47.838794589042664, 43.5043253749609, 45.376116335392, 47.39312030375004, 40.37512868642807, 34.619091153144836, 10.552852638065815, 1.9899711501784623, 0.11086472877650522, 0.027117551035189535, 1.5347551018930972, 0.12855105043854564, 0.2587143424898386, 0.24482654785970226, 0.19476344750728458, 0.2832389686955139, 0.7158775487914681, 0.5968491139356047, 0.6752264988608658, 3.3307720720767975, 2.4479595059528947, 4.270040346309543, 9.165633525699377, 15.412902999669313, 26.000484824180603, 37.18040071427822, 44.28036533296108, 49.50579173862934, 49.32157762348652, 64.12385433912277, 58.592175766825676, 55.005054250359535, 58.15457224845886, 55.28780087828636, 45.96621327102184, 41.099863797426224, 25.412658266723156, 19.44676749408245, 16.132710725069046, 18.156765215098858, 36.388055831193924, 61.79131530225277, 116.43247827887535, 123.46087753772736, 115.15991896390915, 106.10878184437752, 113.00658211112022, 111.92297145724297, 89.1750817000866, 59.59795139729977, 69.16752129793167, 88.00922825932503, 78.73945087194443, 81.50811150670052, 78.93371924757957, 79.67968761920929, 70.10466501116753, 57.16872274875641, 44.04038541018963, 24.520779624581337, 13.085161205381155, 8.539699763059616, 3.6126397596672177, 2.261757622472942, 0.7001740601845086, 0.5628088186495006, 0.14905933669069782, 0.12537768634501845, 3.4539844980463386, 0.3558182209962979, 0.0682208119542338, 0.14465466054389253, 0.07726722105871886, 0.101092870318098, 0.07001749952905811, 0.026956521687679924, 0.06531678067403845, 0.8412822789978236, 8.485956396907568, 30.31520839780569, 47.14032366871834, 60.64967796206474, 82.90519773960114, 61.53055429458618, 34.743754863739014, 27.098679095506668, 38.28060507774353, 57.85093434154987, 77.47766017913818, 65.85585460066795, 78.29697981476784, 85.60037031769753, 73.31366881728172, 9.83925947919488, 0.40801539667882025, 0.06537678331369534, 0.06119363082689233, 0.16258702642517164, 0.13529243791708723, 0.03774260658246931, 0.04375207317934837, 0.03422078189032618, 0.16175506403669715, 0.12727258232189342, 0.13273746095364913, 0.28384506586007774, 0.30639421369414777, 0.3360109229106456, 0.0919086072826758, 0.04693763818067964, 0.06803969081374817, 0.010922857145487797, 0.027354568883311003, 0.07319346856093034, 0.043532375202630647, 0.08691122231539339, 0.006837485861979076, 0.02098618668242125, 0.014200976311258273, 0.04181248878012411, 0.08597846142947674, 0.08949132839916274, 0.18903936637798324, 0.2401926222955808, 0.1775233866646886, 0.13277900638058782, 0.03929327962396201, 0.04533090701443143, 0.06518706068163738, 0.07386773941107094, 0.05200829909881577, 0.07997480584890582, 0.11023314626072533, 0.03376032749656588, 0.20488309120992199, 0.2827909786719829, 0.2515698946081102, 0.20600852847564965, 0.1832604850642383, 0.15853973891353235, 0.3545543731888756, 0.3904195799259469, 0.3938706259941682, 0.2933228260371834, 0.23592840501805767, 0.1606042156345211, 0.14211703499313444, 0.18430637894198298, 0.217813485651277, 0.13813395809847862, 0.17113631532993168, 0.14544408302754164, 0.2738938154652715, 0.1929897887748666, 0.20242215920006856, 0.15764270501676947, 0.1949578753556125, 0.2889426704496145, 0.22637770656729117, 0.2957701322156936, 0.2746342116734013, 0.3595558548113331, 0.4006317991297692, 0.3758623532485217, 0.214489005447831, 0.29740131343714893, 0.5204254772979766, 0.30114084715023637, 21.388543099164963, 117.8582301735878, 112.39517971873283, 103.85453000664711, 106.40097856521606, 111.970674097538, 72.08865255117416, 42.32851266860962, 40.700775012373924, 50.052548199892044, 58.4255813062191, 64.96349528431892, 62.948558405041695, 47.511943727731705, 13.928559198975563, 3.4967124927788973, 0.3274035535287112, 0.3778355458052829, 3.4454905288293958, 0.2718757971888408, 0.39643305412027985, 0.5585245485417545, 0.599170729983598, 1.0604434157721698, 1.4020208618603647, 1.3271309179253876, 2.6849283277988434, 9.122602734714746, 13.915293160825968, 14.625683091580868, 19.317053854465485, 18.6652672290802, 25.268739089369774, 35.486094430089, 43.74996319413185, 46.56018979847431, 47.24573001265526, 59.27035577595234, 56.95228636264801, 54.37770411372185, 57.77726009488106, 55.04676841199398, 47.82220087945461, 45.462835282087326, 30.226365365087986, 27.222237065434456, 24.073952101171017, 28.892479240894318, 46.46052874624729, 65.6120976805687, 116.89891085028648, 119.05784860253334, 111.13594248890877, 106.40417039394379, 112.00291156768799, 108.61242190003395, 88.37557420134544, 70.43265581130981, 76.58323377370834, 92.0792506635189, 83.91782820224762, 83.21999564766884, 80.88059037923813, 81.27071544528008, 71.90851181745529, 60.18105290830135, 48.17829877138138, 24.315001666545868, 10.706440396606922, 7.727616364136338, 3.3583635790273547, 3.200343120843172, 1.8293320387601852, 3.952032560482621, 6.423422796651721, 4.332456747069955, 8.02192434668541, 2.1245638467371464, 0.23171863169409335, 0.37400636065285653, 0.3129467839607969, 0.5217099271249026, 0.3240585158346221, 0.2607877249829471, 0.30382647179067135, 1.8273467640392482, 12.498304545879364, 48.19880247116089, 78.01043719053268, 95.52301347255707, 98.25888946652412, 77.93853744864464, 58.52667488157749, 32.174594923853874, 29.35336410999298, 54.72999840974808, 81.42668947577477, 74.51038420200348, 87.21596002578735, 103.7296611070633, 81.0246254503727, 8.935547322034836, 1.0288141504861414, 0.3043691301718354, 0.19493810454150662, 0.2372227402520366, 0.24203311884775758, 0.1599495968548581, 0.2116837614448741, 0.34140357573051006, 0.3210694418521598, 0.4355159163242206, 0.6420281552709639, 0.4586219717748463, 0.48210981767624617, 0.5208521231543273, 0.31736425473354757, 0.08975476855994202, 0.13815163605613634, 0.16613618441624567, 0.16490558482473716, 0.16226484527578577, 0.16632417042274028, 0.24335460184374824, 0.09267801404348575, 0.11355160022503696, 0.21157218696316704, 0.15540756401605904, 0.21324255358194932, 0.4537849500775337, 0.3498311375733465, 0.33532550500240177, 0.535115726524964, 0.2522951806895435, 0.10713418247178197, 0.15320345963118598, 0.19266765215434134, 0.2335805317852646, 0.16019070579204708, 0.20661162736359984, 0.1751293518464081, 0.12356655657640658], [0.024197409584303387, 0.046542451964342035, 0.10281775510520674, 0.09052145906025544, 0.0359615634806687, 0.04810378224647138, 0.020233487521181814, 0.10682889260351658, 0.06612380690057762, 0.10208407533355057, 0.07151344660087489, 0.012585456261149375, 0.04723051191831473, 0.018208810324722435, 0.031911934493109584, 0.07762594555970281, 0.05478682949615177, 0.012973877801414346, 0.11145565644255839, 0.021387606939242687, 0.001040557140186138, 0.09356306967674755, 0.02629845006595133, 0.038963921906542964, 0.0722727453103289, 0.06284707647864707, 0.07175904553150758, 0.07204860929050483, 0.15252553741447628, 0.19891947449650615, 0.11548754438990727, 0.48756133764982224, 0.2899959561182186, 18.9664276689291, 89.54995438456535, 98.52059662342072, 85.83397418260574, 68.93165275454521, 48.823663741350174, 29.548743925988674, 17.306602634489536, 23.211715668439865, 41.017970591783524, 24.697331450879574, 37.25056774914265, 29.26417339593172, 20.757334269583225, 7.2447131015360355, 1.6709234076552093, 0.2676014421740547, 0.181730042968411, 0.2767754264641553, 1.2480205879546702, 0.384867187240161, 0.4953305551316589, 0.1937068667029962, 0.12031982376356609, 0.14817520132055506, 1.3627164834178984, 2.6238352060317993, 1.6900353133678436, 1.207183466758579, 2.60258128400892, 17.543432526290417, 39.11693640053272, 63.49245361983776, 74.76086676120758, 82.60898843407631, 86.8491581082344, 87.56394535303116, 88.5116297006607, 84.85947847366333, 89.69788044691086, 82.52462536096573, 85.18823683261871, 82.32418611645699, 83.49439412355423, 78.778185993433, 61.81468404829502, 52.33898051083088, 46.25078000128269, 50.89617133140564, 59.6368271112442, 83.86169001460075, 76.6509385406971, 65.10840430855751, 64.75772872567177, 66.24098673462868, 69.77187126874924, 69.93853032588959, 37.54142314195633, 44.5650764554739, 79.69679430127144, 92.33320623636246, 82.62310847640038, 83.34210589528084, 84.948028922081, 82.38926902413368, 71.70499473810196, 75.98245561122894, 75.40018245577812, 59.07498925924301, 48.56872782111168, 38.90827439725399, 33.14986579120159, 23.442275896668434, 10.890465471893549, 1.5729620517231524, 1.13206458510831, 0.9540472249500453, 1.6722048888914287, 0.7079777133185416, 0.19849330361466855, 0.024247543515230063, 0.20818330318434164, 0.10492089772014879, 0.023093646741472185, 0.12037757769576274, 0.2076656700228341, 0.0501627782068681, 0.05145158815139439, 1.3600553199648857, 18.60156934708357, 30.23391555994749, 43.284529969096184, 37.09061913192272, 61.73599027097225, 58.08021403849125, 20.946847200393677, 17.427373453974724, 25.66632505506277, 51.230720579624176, 65.59826642274857, 63.96814629435539, 69.80235323309898, 57.287948951125145, 10.41288809850812, 0.29044540075119585, 0.40445863909553736, 0.10698012745706365, 0.06272999526117928, 0.036978105417802, 0.010344876245653722, 0.2766316873021424, 0.12400047547998838, 0.051503245340427384, 0.05558710588957183, 0.028229863419255707, 0.10644012596458197, 0.08536053443094715, 0.056904766825027764, 0.06557815766427666, 0.03867757535772398, 0.04626381632988341, 0.04438677271537017, 0.043166125324205495, 0.018513914656068664, 0.036977893905714154, 0.051085449595120735, 0.010706722405302571, 0.10129786634934135, 0.0340296454669442, 0.04794880696863402, 0.06405453590559773, 0.09928615632816218, 0.16411114542279392, 0.10603701361105777, 0.0635612006590236, 0.004521512919382076, 0.014634402614319697, 0.02330296949367039, 0.031279862159863114, 0.030130716986604966, 0.030290709182736464, 0.05576156254392117, 0.052425460307858884, 0.04099769597814884, 0.061909562136861496, 0.1120194215036463, 0.02371423990553012, 0.06774138455512002, 0.05279929122480098, 0.03219554993847851, 0.04995980081730522, 0.06223498276085593, 0.13280885556014255, 0.06579709122888744, 0.051456415822030976, 0.06102783874666784, 0.028490347976912744, 0.0255933337030001, 0.024575123788963538, 0.00977468325800146, 0.04565458730212413, 0.211276070040185, 0.024957862333394587, 0.015124372221180238, 0.01800816327886423, 0.04585405062243808, 0.027876250460394658, 0.06294696955592372, 0.05171961849555373, 0.05885767277504783, 0.08806454949080944, 0.2246512335841544, 0.13639915821840987, 0.07482357366825454, 0.42960758961271495, 0.1811890469980426, 33.02568845450878, 107.64928758144379, 106.69390484690666, 95.90297028422356, 85.21656811237335, 69.84066277742386, 47.223045229911804, 27.651824913918972, 22.354597561061382, 30.645802058279514, 27.97186654061079, 43.35948474705219, 38.24198015034199, 25.305289328098297, 8.639593552798033, 1.4577033114619553, 0.31981746840756387, 0.07448273492627777, 0.963512338930741, 2.4109540041536093, 0.5399823747575283, 1.0431928164325655, 0.1274112451937981, 0.09723324226797558, 0.16815726034110412, 1.7058238224126399, 3.257191157899797, 1.239968107547611, 1.7130823829211295, 4.972290638834238, 21.402300260961056, 43.548380210995674, 66.4039371907711, 76.39138206839561, 87.22232848405838, 88.34068447351456, 87.59938225150108, 88.9112314581871, 88.86289805173874, 93.67898002266884, 86.04078948497772, 86.51086986064911, 84.23604592680931, 87.27741032838821, 83.45336392521858, 70.99545881152153, 58.281975612044334, 52.64062352478504, 54.22730438411236, 73.86629596352577, 95.69404989480972, 92.40567594766617, 77.30810567736626, 70.4925025999546, 75.89125290513039, 78.42281386256218, 81.04003742337227, 47.379672825336456, 51.19527608156204, 82.68020421266556, 96.28555655479431, 86.97107076644897, 85.4532042145729, 86.7556831240654, 83.76101821660995, 77.35817179083824, 79.91672649979591, 77.36905440688133, 64.44262683391571, 52.368801310658455, 42.906777039170265, 36.33609741926193, 27.561974935233593, 13.827895000576973, 2.410265766084194, 0.17448585043894127, 0.5171688145492226, 2.719707624055445, 1.5112072904594243, 0.05482479777128901, 0.29888100747484714, 0.09652767505031079, 0.062156300264177844, 0.03501145860354882, 0.08604711008956656, 0.0432755661313422, 0.06307218471192755, 0.11145194570417516, 1.860269622411579, 18.445608615875244, 33.12013998627663, 49.84929330646992, 45.04556827247143, 45.61676122248173, 44.3056757748127, 19.14570964872837, 34.101688116788864, 45.33888593316078, 68.45654904842377, 81.01195693016052, 75.96957430243492, 78.41877087950706, 81.88261181116104, 27.681128941476345, 0.2341702423291281, 0.2329739002743736, 0.08874890612787567, 0.05544196035771165, 0.06857687214505859, 0.04418783631990664, 0.24096800334518775, 0.08806425263173878, 0.019086223692283966, 0.06478822309873067, 0.0933514314237982, 0.17890930292196572, 0.06071667106880341, 0.1557986016268842, 0.0739224134304095, 0.06259097615838982, 0.03645748511189595, 0.015807623058208264, 0.037729210816905834, 0.03243300008762162, 0.028541301981022116, 0.04741082411783282, 0.10668881222954951, 0.049140907649416476, 0.05135250772582367, 0.013558191076299408, 0.0013175910112295242, 0.041928263817681, 0.14814417954767123, 0.022333910164888948, 0.10394050579634495, 0.01656250413361704, 0.046572186111006886, 0.03830947753158398, 0.07417922621243633, 0.04344388893514406, 0.07197939659818076, 0.03703494650835637, 0.03958345565479249, 0.1943031675182283, 0.18184191430918872, 0.3473140695132315, 0.2018516554380767, 0.18840499338693917, 0.15351030800957233, 0.08823672033031471, 0.17900959675898775, 0.19491500890580937, 0.32506727264262736, 0.22258193290326744, 0.14357817533891648, 0.11307050299365073, 0.14863337361020967, 0.10766336345113814, 0.11630548760876991, 0.1627038701553829, 0.08120625891024247, 0.25966066983528435, 0.1392517364001833, 0.09651788612245582, 0.33762853767257184, 0.24643251090310514, 0.2172517540748231, 0.2688191580818966, 0.2572859753854573, 0.21811448590597138, 0.20933354302542284, 0.36601224273908883, 0.31001610215753317, 0.21761651965789497, 0.753391154576093, 0.308324153884314, 42.33431115746498, 124.9481101334095, 114.06299382448196, 107.64915078878403, 91.4315602183342, 66.41189396381378, 44.001939073204994, 22.665597572922707, 35.3631292283535, 61.65739148855209, 40.32282069325447, 54.72474709153175, 49.42980341613293, 33.73160697519779, 12.944359760731459, 2.948100306093693, 0.6624980724882334, 0.48731473681982607, 1.2666767556220293, 4.804843598976731, 0.6742484075948596, 2.01542301569134, 0.4006137797841802, 0.3709762904327363, 0.24956386943813413, 2.6799622317776084, 4.132319586351514, 3.512346278876066, 6.051717242226005, 5.148709947243333, 21.69388711452484, 43.803878501057625, 67.52395749092102, 79.57947939634323, 88.41681718826294, 92.56848201155663, 88.9988623559475, 91.20452240109444, 90.61072826385498, 92.27436259388924, 89.59494397044182, 91.5480999648571, 83.61192181706429, 88.6720722913742, 84.90683153271675, 75.54060772061348, 60.33008091151714, 59.90411996841431, 65.66565960645676, 79.3829083442688, 101.91309258341789, 102.09904700517654, 82.0166078209877, 78.268131762743, 82.28244915604591, 88.17780241370201, 86.63578435778618, 50.616950914263725, 58.11357244849205, 90.08224502205849, 102.44719192385674, 91.34805589914322, 87.97560006380081, 90.43352097272873, 86.86343014240265, 79.43172052502632, 80.86266294121742, 77.83365547657013, 59.93918068706989, 55.256650149822235, 42.10843227803707, 36.2701253592968, 26.72960489988327, 12.533809840679169, 2.2492090333253145, 2.126823775470257, 2.613125955685973, 6.1754210293293, 3.625706546008587, 0.41993313061539084, 0.38516357133630663, 0.364354700432159, 0.1769513837643899, 0.25528122670948505, 0.3117289493093267, 0.40061226580291986, 0.27864065137691796, 0.4036460170755163, 2.848309585824609, 29.916628785431385, 49.82685171067715, 63.81778836250305, 50.0341609865427, 85.02302169799805, 79.68895152211189, 30.506360940635204, 29.750271812081337, 37.834330424666405, 70.99459245800972, 91.28750994801521, 85.2632600069046, 92.43711546063423, 95.25308355689049, 27.16976948082447, 0.40776594600174576, 0.5989937426056713, 0.21072149276733398, 0.18227421533083543, 0.19649023219244555, 0.303346777218394, 0.5196215235628188, 0.21045224159024656, 0.18504575098631904, 0.26362002769019455, 0.4067845002282411, 0.39023338991682976, 0.352809049654752, 0.3534189169295132, 0.19796042673988268, 0.15316406643250957, 0.2049408302991651, 0.19732782006030902, 0.239687486900948, 0.11963121462031268, 0.19945782842114568, 0.1176853256765753, 0.154893760336563, 0.35609204380307347, 0.12562724092276767, 0.12913423008285463, 0.2068158218753524, 0.16814495553262532, 0.311681303428486, 0.4019755613990128, 0.24398110806941986, 0.15997315262211487, 0.09388411534018815, 0.11115733534097672, 0.14469179761363193, 0.16023679316276684, 0.21330746181774884, 0.10760591379948892, 0.16564488265430555], [0.04005858601885848, 0.050661857676459476, 0.04570410710584838, 0.00709702603671758, 0.028085127923986875, 0.05756203507189639, 0.08201974182156846, 0.01580518324772129, 0.0651466878480278, 0.07876543910242617, 0.04049059018143453, 0.05489488619787153, 0.025004083290696144, 0.08618822947028093, 0.0673851759347599, 0.033695426682243124, 0.05239886544586625, 0.052267312348703854, 0.1095933407486882, 0.09630663378629833, 0.03607224367442541, 0.07436856292770244, 0.0323366210795939, 0.03342865798913408, 0.0762503599980846, 0.053668238542741165, 0.033122340246336535, 0.03140452070510946, 0.0030226028229662916, 0.024599985736131202, 0.15059265831951052, 0.24363315955270082, 26.570914015173912, 98.72767791152, 89.3659682571888, 72.13167384266853, 68.79566565155983, 49.25017565488815, 22.633909173309803, 35.07090210914612, 59.135577008128166, 67.60804697871208, 60.29298350214958, 51.2834807485342, 37.28793494403362, 16.405264399945736, 3.4876497415825725, 0.46535909932572395, 0.050934507889905944, 0.2266259994939901, 0.04251879814546555, 0.7841081719379872, 2.2441351180896163, 0.6315447553060949, 0.21294501173542812, 0.05305352504365146, 0.4047078819712624, 0.06463139245170169, 0.24064607452601194, 1.4595817169174552, 2.1674302965402603, 10.798290967941284, 25.54603300988674, 60.09245306253433, 77.26598113775253, 87.92591392993927, 86.27551048994064, 91.6608627140522, 91.36795923113823, 93.04509803652763, 89.96086433529854, 87.19098776578903, 83.01490545272827, 86.60472482442856, 80.97803235054016, 81.57873451709747, 86.93631783127785, 84.49149861931801, 82.87015601992607, 86.16491362452507, 67.99828603863716, 57.52632915973663, 28.637896701693535, 51.42623148858547, 60.11286176741123, 67.08767250180244, 64.7779056429863, 66.05424955487251, 71.26013740897179, 63.82241651415825, 25.28126321732998, 53.817013800144196, 87.62567684054375, 85.47211959958076, 80.10378286242485, 78.61893653869629, 84.73350003361702, 83.85176494717598, 79.192546159029, 79.32029530405998, 82.31550738215446, 84.57472935318947, 75.13492628931999, 71.34685635566711, 75.38885146379471, 78.12206000089645, 64.1591164469719, 41.1121941357851, 12.745002508163452, 4.00808097794652, 0.274835096206516, 0.3983434312976897, 0.7598297309596092, 0.23616094957105815, 0.09931121865520254, 0.09818641963647678, 0.0808069240883924, 0.05125816591316834, 0.09330584871349856, 0.12294573520193808, 0.04394741386931855, 0.2271257172105834, 0.3602846438298002, 8.189912382513285, 24.556174725294113, 42.81711705029011, 62.29223482310772, 55.32327197492123, 69.22266393899918, 36.01756431162357, 18.53064615279436, 13.72270429506898, 46.718439906835556, 58.820026740431786, 59.854262843728065, 69.87647205591202, 76.78437978029251, 24.74192775785923, 0.40101246151607484, 0.2709391771350056, 0.07480221465812065, 0.03524837069562636, 0.03176089630869683, 0.05186976239201613, 0.04649090980819892, 0.08144951265421696, 0.1154231111286208, 0.12914936989545822, 0.09221111409715377, 0.0759743107482791, 0.05927704187342897, 0.08059806146775372, 0.04187583479506429, 0.035880929135601036, 0.043408206474850886, 0.011190339228051016, 0.05551295791519806, 0.0815891551610548, 0.14191238034982234, 0.08274878317024559, 0.0864990334957838, 0.029947261791676283, 0.035121392938890494, 0.02729218394961208, 0.09178163323667832, 0.11201247500139289, 0.05896515431231819, 0.06239641472348012, 0.06066486916097347, 0.03481645188003313, 0.03113454964477569, 0.0867993880819995, 0.1067762817547191, 0.02105509880493628, 0.04315808415412903, 0.098364535078872, 0.034132596192648634, 0.06148008498712443, 0.08725423555006273, 0.13315174262970686, 0.00599274044361664, 0.05801762468763627, 0.03533504612278193, 0.03466705013124738, 0.0330951034266036, 0.11702304051141255, 0.020205727487336844, 0.06922527914866805, 0.056047942489385605, 0.05509316208190285, 0.13321605714736506, 0.06827035031164996, 0.055713504771119915, 0.0732581689953804, 0.1164585110382177, 0.06646831185207702, 0.003935027934858226, 0.024184119574783836, 0.08042680346989073, 0.04323644381656777, 0.06906236289069057, 0.04677330442063976, 0.06003194706863724, 0.025414216361241415, 0.03647540797828697, 0.03727768445969559, 0.036906387977069244, 0.6871899194084108, 39.723273664712906, 116.95795968174934, 100.6352287530899, 85.2676297724247, 84.86618891358376, 62.7143769711256, 37.541248351335526, 44.83411341905594, 44.7274911403656, 50.81194885075092, 53.78898270428181, 50.88657304644585, 40.39135381579399, 20.682892464101315, 4.50336872600019, 0.6007316743489355, 0.1261221495224163, 0.15110825799638405, 0.041548859371687286, 1.3633511681109667, 3.339942405000329, 0.9136606170795858, 0.21037073893239722, 0.12074796875822358, 0.7222972449380904, 0.27359864849131554, 1.1254442716017365, 1.4285877300426364, 4.023002777248621, 14.539793450385332, 29.115449376404285, 62.05985069274902, 77.74302273988724, 91.10066637396812, 88.14402982592583, 94.2652353644371, 93.93814891576767, 94.87283796072006, 89.25983235239983, 88.66473108530045, 84.14034426212311, 89.57719132304192, 83.14987421035767, 81.54431596398354, 88.84077563881874, 86.19420245289803, 86.88695847988129, 88.16542267799377, 69.73193541169167, 62.89709776639938, 34.90646593272686, 58.94531361758709, 69.71783816814423, 72.80901029706001, 73.49366515874863, 73.25823739171028, 81.09232261776924, 73.40452954173088, 31.020230166614056, 60.88520832359791, 91.76679342985153, 91.1006511747837, 84.08870503306389, 82.57878765463829, 87.71451607346535, 86.56614929437637, 81.99950113892555, 79.99148368835449, 84.56637740135193, 85.86339220404625, 79.62193071842194, 74.65299054980278, 79.03597936034203, 82.29145467281342, 70.31179189682007, 45.7156927138567, 14.660194739699364, 5.758854607120156, 0.8490462123882025, 0.9430900379084051, 1.1264862469397485, 0.3030424372991547, 0.14174242853187025, 0.07296162162674591, 0.016373998623748776, 0.04459829593542963, 0.06245778291486204, 0.11542438020114787, 0.058183316577924415, 0.37000098964199424, 0.7322755688801408, 7.62697116471827, 30.811169184744358, 41.14128917455673, 54.73845675587654, 50.9687664359808, 43.04083004593849, 29.736130870878696, 22.306670732796192, 27.7437324821949, 63.07019367814064, 73.13499480485916, 75.70682600140572, 81.20430260896683, 94.10214811563492, 49.618695080280304, 0.9532420244067907, 0.2763553411932662, 0.12459488381864503, 0.05060341354692355, 0.08825239448924549, 0.06776942289434373, 0.014410856601898558, 0.06152930793177802, 0.04500455870584119, 0.10867223158129491, 0.06703839258989319, 0.08767471415922046, 0.12554012762848288, 0.07985530523001216, 0.048391768941655755, 0.07093348787748255, 0.05737407132983208, 0.04851464262173977, 0.01164400946436217, 0.12253281907760538, 0.12884630647022277, 0.06805143158999272, 0.1250791797065176, 0.04572651996568311, 0.06905014713993296, 0.04563402239000425, 0.11668764913338237, 0.026978415044141002, 0.04934825257805642, 0.04018222782178782, 0.07383676216704771, 0.07297235308215022, 0.025938131802831776, 0.0464484441181412, 0.06832743631093763, 0.035196594762965105, 0.016466334782307968, 0.04690282032242976, 0.14836179208941758, 0.1608209079131484, 0.1949097990291193, 0.26543805201072246, 0.07054622037685476, 0.2100357334711589, 0.12086798888049088, 0.08892855039448477, 0.13394932873779908, 0.2362762051052414, 0.18995618593180552, 0.21582599933026358, 0.15748983743833378, 0.18329989310586825, 0.24244959728093818, 0.1137164757528808, 0.12555363471619785, 0.11197357162018307, 0.2322375710355118, 0.26646358135621995, 0.12603243871126324, 0.1916039318894036, 0.16307813522871584, 0.19406324601732194, 0.24227704794611782, 0.14246628968976438, 0.1987096990342252, 0.21099421719554812, 0.16497867152793333, 0.1224194782844279, 0.3052014933200553, 0.7185070076957345, 46.48370750248432, 133.56631368398666, 108.84137481451035, 96.71317800879478, 91.12601861357689, 65.66265016794205, 33.68267320096493, 51.41234703361988, 81.60254403948784, 94.3305766582489, 82.94267892837524, 74.26604971289635, 56.857568845152855, 29.41742107272148, 7.018510764464736, 1.5371701098047197, 0.3153509268304333, 0.3332341031637043, 0.1528216098085977, 1.9142304081469774, 6.7570482194423676, 1.964856160338968, 0.6634751544333994, 0.18381941132247448, 1.3868652563542128, 0.3349989600246772, 1.269204926211387, 4.59127938374877, 4.09871038980782, 15.788307655602694, 31.235443018376827, 66.05421915650368, 81.91838309168816, 94.9098251760006, 90.39632096886635, 98.95786955952644, 96.40579730272293, 98.68893519043922, 95.65765544772148, 93.83303135633469, 86.76392868161201, 89.86543625593185, 87.45691269636154, 85.38670778274536, 93.48346531391144, 93.13603475689888, 88.7510472536087, 92.04244583845139, 76.66184395551682, 71.7895781993866, 40.47611586749554, 69.05138432979584, 83.17817509174347, 83.3973777294159, 78.72777789831161, 80.76579853892326, 88.32268863916397, 82.33279645442963, 38.24683628976345, 66.09834238886833, 96.75109997391701, 95.50830826163292, 88.2442456483841, 85.71743443608284, 90.86320951581001, 89.75381344556808, 81.43428906798363, 79.04835909605026, 85.3791081905365, 90.06470516324043, 78.5009452700615, 78.09324234724045, 84.07258629798889, 87.11111605167389, 73.9255727827549, 49.07740652561188, 14.155917149037123, 6.379307163879275, 1.3748413952998817, 2.2248012805357575, 2.3747844574972987, 0.5161097401287407, 0.4889888735488057, 0.17472068080678582, 0.24670609622262418, 0.2404073256184347, 0.2673039003275335, 0.25349416479002684, 0.294988828827627, 0.6179466506000608, 1.0726686660200357, 13.688947856426239, 42.89126247167587, 67.44137272238731, 84.61585834622383, 73.44940513372421, 92.5848439335823, 50.41220650076866, 27.750089541077614, 22.61222943663597, 61.94439388811588, 80.24730116128922, 82.36500352621078, 87.81615301966667, 108.77618551254272, 48.94983597099781, 0.8815485995728523, 0.6859774282202125, 0.1784423881326802, 0.14460946375038475, 0.3212184354197234, 0.2009566847118549, 0.1664329692721367, 0.24969089543446898, 0.25593787897378206, 0.21967804263113067, 0.21759361698059365, 0.14901703427312896, 0.20060913695488125, 0.16432285046903417, 0.11474211642052978, 0.10255459696054459, 0.20566924824379385, 0.12931184086482972, 0.13973033259389922, 0.22384235198842362, 0.342505932203494, 0.23472133150789887, 0.27074333920609206, 0.15651413588784635, 0.17907413392094895, 0.11810106196207926, 0.2940954908262938, 0.28853220341261476, 0.1619350051623769, 0.2339722670149058, 0.1773875142680481, 0.2084217849187553, 0.09681048526545055, 0.24466602131724358, 0.32734219275880605, 0.12403155662468635, 0.16882416908629239, 0.21258446155115962], [0.07698528657783754, 0.10385379326180555, 0.004490680394155788, 0.0462891384086106, 0.08745923900278285, 0.042379485894343816, 0.01608760383533081, 0.07397590001346543, 0.044273684252402745, 0.05318006493325811, 0.09441973816137761, 0.04785536686540581, 0.06495761088444851, 0.03563573467545211, 0.07079538903781213, 0.0322124820377212, 0.08626953916973434, 0.05644619006488938, 0.13144266558811069, 0.09737261760164984, 0.0166104060554062, 0.03622981646913104, 0.042843758637900464, 0.0820072514761705, 0.0576999372424325, 0.10177758318604901, 0.02168804687244119, 0.08188451509340666, 0.1087768076104112, 0.05352938642317895, 0.9670509584248066, 52.85144381225109, 108.59817266464233, 89.2863017320633, 94.46321994066238, 64.844880849123, 48.15514661371708, 26.16547767072916, 26.157800182700157, 21.378485038876534, 45.84264010190964, 57.36687071621418, 39.64192382991314, 30.603183545172215, 11.640993598848581, 2.315196767449379, 0.3034296602709219, 0.09877921751467511, 0.08626912356703542, 0.012440304235497024, 0.08512873202562332, 0.1006354253331665, 0.21914522512815893, 0.20795242104213685, 0.04841761052375659, 0.006659119480900699, 0.13185936666559428, 0.27865902695339173, 0.4111183458007872, 5.78329679556191, 22.646294608712196, 36.44015483558178, 58.02029885351658, 80.61973437666893, 83.00808861851692, 81.59962579607964, 76.04051649570465, 78.20563271641731, 85.41716694831848, 82.7526131272316, 76.0365343093872, 76.09027862548828, 77.39309951663017, 75.9606371819973, 75.2832855284214, 74.83421802520752, 77.32810020446777, 77.83314630389214, 79.93492752313614, 80.81399515271187, 84.98383820056915, 86.98493242263794, 70.43078631162643, 33.608558177948, 70.30154764652252, 63.5345059633255, 66.29066526889801, 72.47074484825134, 72.875886708498, 41.65552698075771, 31.131611689925194, 73.66252809762955, 88.33424001932144, 77.65057370066643, 79.09730046987534, 81.69607982039452, 87.08232879638672, 79.66096222400665, 79.54243138432503, 83.99220541119576, 83.03399562835693, 83.0603738129139, 82.12436243891716, 82.46933832764626, 80.21451652050018, 77.93013229966164, 81.46844923496246, 80.08377313613892, 65.53221076726913, 41.28239080309868, 24.104042686522007, 7.050202963873744, 1.2741184188053012, 0.10937032537185587, 0.240522610838525, 0.17973363603232428, 0.012167805234639673, 0.020144737791270018, 0.054032503176131286, 0.05363504598790314, 0.03165265035931952, 0.11744406830985099, 0.0380032340035541, 0.05987429634842556, 4.069211622700095, 19.66780163347721, 37.1492575854063, 56.627950966358185, 57.50201806426048, 65.8344541490078, 59.898682460188866, 30.799365118145943, 22.90405947715044, 42.788508385419846, 56.76777206361294, 61.67618528008461, 59.58975523710251, 69.26664277911186, 32.56039582192898, 1.0992105980403721, 0.17367316904710606, 0.07457298750523478, 0.05286885272653308, 0.053968845459166914, 0.05276228032016661, 0.06819402784458362, 0.03470944160653744, 0.037927501543890685, 0.04180928641289938, 0.034815416584024206, 0.05555618801736273, 0.04584112612064928, 0.03024233599717263, 0.007258737696247408, 0.04165174330410082, 0.12817224342143163, 0.0006897743151057512, 0.07823277002898976, 0.056654722429811954, 0.010169816596317105, 0.027079957544628996, 0.019382208884053398, 0.05645636862027459, 0.07450905890436843, 0.048124554959940724, 0.055739405725034885, 0.16242477810010314, 0.04710397573944647, 0.04247209108143579, 0.030310479996842332, 0.0720175429887604, 0.0961739823105745, 0.03447211391176097, 0.08833118830807507, 0.033610829268582165, 0.010841984385479009, 0.05679230176610872, 0.06680926933768205, 0.0669018374173902, 0.005622848939310643, 0.045924688238301314, 0.05190966767258942, 0.10194872244028375, 0.047936721093719825, 0.01755241410137387, 0.05178117593459319, 0.05802359155495651, 0.01364459376418381, 0.07947622361825779, 0.08600312299677171, 0.044194352376507595, 0.059480019262991846, 0.08157254589605145, 0.04363173393358011, 0.13200883520767093, 0.11040608893381432, 0.06975483120186254, 0.03984003094956279, 0.021023904482717626, 0.07767321294522844, 0.04510057777224574, 0.09903308397042565, 0.11532099902979098, 0.12641253706533462, 0.10487779378308915, 0.0894148055522237, 1.9945770967751741, 68.71812701225281, 123.98809924721718, 99.8518779873848, 104.5271623134613, 80.36735951900482, 63.53918731212616, 46.119607239961624, 22.48983610421419, 24.74154207855463, 50.90466767549515, 51.844900622963905, 47.00442776083946, 35.044170543551445, 14.870482105761766, 2.9333221865817904, 0.3648107056505978, 0.09517494021565653, 0.07994018465979025, 0.10535702080233023, 0.15486833435716107, 0.11281169383437373, 0.22963791678193957, 0.40537623048294336, 0.19162463780958205, 0.1584971247939393, 0.30887509463354945, 0.47468923148699105, 0.6204652029555291, 5.755347395315766, 22.55739837884903, 36.31919592618942, 59.289244562387466, 83.46780315041542, 86.34455278515816, 83.40891391038895, 79.90594267845154, 81.94469287991524, 86.22909978032112, 86.50802001357079, 78.515445291996, 79.38306793570518, 80.05879327654839, 78.41068491339684, 76.74101650714874, 76.90576806664467, 77.96802386641502, 81.5588691830635, 83.43274623155594, 83.04008290171623, 88.37198719382286, 89.03151020407677, 67.26568534970284, 39.123662039637566, 78.7115603685379, 71.43090024590492, 71.89878433942795, 79.99079212546349, 81.84550300240517, 49.214788153767586, 37.146369740366936, 78.14745023846626, 91.18749931454659, 79.67793971300125, 80.6610381603241, 84.2578187584877, 90.29593035578728, 82.49557211995125, 82.77503952383995, 84.98982667922974, 86.6945444047451, 87.23232954740524, 86.93286761641502, 85.88387310504913, 82.26195305585861, 81.96653410792351, 85.2154129743576, 84.30891841650009, 70.61146661639214, 45.44172361493111, 26.39482006430626, 8.843936137855053, 2.145090107806027, 0.8150563831441104, 0.46124362328555435, 0.3311609284719452, 0.3404504503123462, 0.08955657802289352, 0.038585074071306735, 0.1167619158513844, 0.04596601844241377, 0.05340843490557745, 0.04119998688111082, 0.03494066513667349, 4.581932360306382, 20.47633934766054, 37.36221715807915, 47.9424150288105, 53.52766312658787, 60.78395135700703, 58.36462877690792, 37.037000209093094, 38.53982336819172, 63.613503724336624, 74.29213911294937, 75.99722161889076, 68.49443301558495, 79.08794537186623, 57.612930312752724, 3.3676457684487104, 0.3739105345448479, 0.04086745648237411, 0.013908692581026116, 0.03793170581047889, 0.03452834644122049, 0.029922635476395953, 0.04412359972775448, 0.111987397831399, 0.015497685490117874, 0.018483056155673694, 0.03907220125256572, 0.05297048614011146, 0.04172838860540651, 0.04456445029063616, 0.03148742231132928, 0.14544053556164727, 0.01961959966138238, 0.04066120251081884, 0.059557421554927714, 0.07363676078966819, 0.03175124838890042, 0.01851181994425133, 0.02013792302022921, 0.03681910769955721, 0.026813235235749744, 0.07517143312725239, 0.12239241215866059, 0.08662848631502129, 0.034780012429109775, 0.041253299059462734, 0.06606964496313594, 0.07103801195626147, 0.03690869234560523, 0.0753048638580367, 0.04883983317995444, 0.03858669566398021, 0.13173208833904937, 0.22638070484390482, 0.24115585576510057, 0.23247115459525958, 0.19158588285790756, 0.07989891382749192, 0.12436380129656754, 0.2595685247797519, 0.1449571896228008, 0.12600440037203953, 0.24661580653628334, 0.14798202028032392, 0.14930915844161063, 0.15292267547920346, 0.21168604725971818, 0.20731068594614044, 0.20177380414679646, 0.08177678493666463, 0.23789398313965648, 0.22455525904661044, 0.19909655093215406, 0.15435488690854982, 0.17068488174118102, 0.17831264587584883, 0.141466052737087, 0.3424769884441048, 0.18613768770592287, 0.2564604993676767, 0.33711701980791986, 0.16716239653760567, 2.3760597640648484, 82.19478785991669, 139.00067567825317, 109.52985227108002, 117.08228141069412, 84.97569903731346, 63.57036083936691, 40.39942838251591, 41.89926490187645, 34.64019142091274, 65.1944924890995, 77.59223163127899, 58.969499319791794, 47.81628079712391, 20.985671617090702, 5.598127981647849, 0.8096032007597387, 0.41852726542856544, 0.38062878185883164, 0.4446161608211696, 0.3569591394625604, 0.27463171805720776, 0.3827545599779114, 0.9791001118719578, 0.2500604256056249, 0.1016900988179259, 0.3842358570545912, 1.060906753409654, 2.0301678869873285, 10.01376986503601, 29.04617339372635, 43.19983251392841, 63.90771433711052, 89.0688394010067, 90.93198582530022, 86.8859401345253, 84.11507561802864, 84.48563933372498, 91.83941513299942, 92.1409897506237, 84.33923318982124, 81.57789096236229, 84.051413834095, 83.06760102510452, 79.69525918364525, 79.47954475879669, 82.35173463821411, 83.63488778471947, 86.71642363071442, 86.67561382055283, 93.15596088767052, 95.4805089533329, 81.46945998072624, 49.44064803421497, 89.4829335808754, 80.25581270456314, 80.08132606744766, 88.45702663064003, 90.5077613890171, 56.17254160344601, 43.6823458224535, 82.90575250983238, 95.95921486616135, 85.44595420360565, 85.36883354187012, 90.14633238315582, 94.86936494708061, 84.64114218950272, 83.20228099822998, 90.97308441996574, 88.8376522064209, 89.28335309028625, 89.05661925673485, 88.21153700351715, 86.32423147559166, 85.83335101604462, 89.45587143301964, 89.42525267601013, 73.27620282769203, 48.797441348433495, 27.83632591366768, 10.26851674541831, 3.5526804020628333, 1.84536955319345, 0.5063751374837011, 0.3785957721993327, 0.2969304652651772, 0.17460374801885337, 0.35569526196923107, 0.2045380519120954, 0.20314514462370425, 0.12829659768613055, 0.1209242214099504, 0.23624715744517744, 6.99265125207603, 32.31837160885334, 57.50852331519127, 79.03027966618538, 78.25692236423492, 87.01399326324463, 83.25084239244461, 43.698042780160904, 36.727685406804085, 58.0860885232687, 73.61775130033493, 84.13161233067513, 75.68227931857109, 94.34367835521698, 63.09379801154137, 2.7525136386975646, 0.5616934003774077, 0.19254494545748457, 0.16620769776636735, 0.16360252193408087, 0.13729724596487358, 0.23035612277453765, 0.20243756618583575, 0.16172255796846002, 0.12716933473711833, 0.17255024024052545, 0.11666642370983027, 0.13297194993356243, 0.14487310429103673, 0.06553561775945127, 0.11202524736290798, 0.24829227360896766, 0.11823766166344285, 0.209211251931265, 0.3009258914971724, 0.18069410871248692, 0.1582836385932751, 0.09733408529427834, 0.11928168532904238, 0.19749787577893585, 0.1982070572557859, 0.1469549917965196, 0.3269560681656003, 0.16355506901163608, 0.10636395934852771, 0.10579534064163454, 0.13164107134798542, 0.1743640046333894, 0.19587549642892554, 0.2955176535760984, 0.12296189917833544, 0.16661227215081453], [0.03603971534175798, 0.08426165863056667, 0.049301820108667016, 0.04771643682033755, 0.0328875061677536, 0.04399149744131137, 0.08568149103666656, 0.05001292003726121, 0.023547347591375, 0.03646632409072481, 0.03477133301203139, 0.0495492150366772, 0.049398317860323004, 0.018396859413769562, 0.06589693235582672, 0.03840060955553781, 0.05228877154877409, 0.018756763929559384, 0.07569202003651299, 0.06463529614848085, 0.022229423193493858, 0.04299507141695358, 0.06380304432241246, 0.03453846562479157, 0.09054076974280179, 0.0228482444799738, 0.013973923651064979, 0.09080449934117496, 0.14709770679473877, 0.02224551295512356, 41.84612475335598, 89.10236120223999, 87.66023978590965, 82.15151578187943, 69.88480120897293, 47.333657294511795, 19.80237901210785, 27.500562630593777, 61.88342235982418, 77.64853700995445, 59.29898723959923, 49.097769632935524, 30.516282208263874, 9.743207283318043, 0.7343385019339621, 0.15210563025902957, 0.07503412838559598, 0.08488458028296009, 0.1688693361938931, 0.2313281878014095, 0.1136086045880802, 0.18473698786692694, 0.04449535263120197, 0.04605664580594748, 0.017293163364229258, 0.3520526527427137, 0.28467080905102193, 6.902554761618376, 25.908202975988388, 40.24848148226738, 52.03863322734833, 69.03101742267609, 77.31726318597794, 89.2986586689949, 84.71832364797592, 77.82378360629082, 71.9041420519352, 70.48412784934044, 68.0933341383934, 69.79596197605133, 69.44189697504044, 73.06406021118164, 72.34024465084076, 71.5258951485157, 71.39317587018013, 71.10152631998062, 70.80062046647072, 70.29242813587189, 72.76589021086693, 75.3421975672245, 79.18824478983879, 80.26137560606003, 82.8841544687748, 61.07329063117504, 36.05318360030651, 56.932018250226974, 66.2963117659092, 74.21169742941856, 59.78597670793533, 31.91202901303768, 65.62294229865074, 82.28167399764061, 75.66426828503609, 70.55467486381531, 72.22602277994156, 84.13738042116165, 88.05805563926697, 79.41971316933632, 77.90846586227417, 78.84779825806618, 73.86202499270439, 77.7915309369564, 82.88830384612083, 82.37226113677025, 80.86036026477814, 78.18916440010071, 75.93501895666122, 80.46323597431183, 77.80775606632233, 82.53072783350945, 78.86587008833885, 65.68775162100792, 35.125763565301895, 11.987274717539549, 0.8032837242353708, 0.05554809118621051, 0.18740155035629869, 0.1230231263616588, 0.05821051629027352, 0.10637758517987095, 0.1582014828454703, 0.08025448420085013, 0.02787275308946846, 0.04994500610337127, 0.1138252968667075, 0.6270963221322745, 7.501116693019867, 23.064490668475628, 42.67574563622475, 40.73532275855541, 30.176626034080982, 44.427938014268875, 33.22244189679623, 16.89870972186327, 26.893624998629093, 49.92333993315697, 60.2811623364687, 64.32193771004677, 76.94672986865044, 47.795172929763794, 3.026172579266131, 0.22687087854137644, 0.043448564465506934, 0.051781339207082056, 0.028503990506578702, 0.04893413788522594, 0.07406772594549693, 0.11025521031115204, 0.08048402305576019, 0.06865850838948973, 0.05975900370685849, 0.03528599387209397, 0.0588961457106052, 0.038116437499411404, 0.03786055982345715, 0.027340338201611303, 0.09024591447087005, 0.005261179967419594, 0.019269350486865733, 0.01288417626710725, 0.03596924099838361, 0.018256882940477226, 0.058909741856041364, 0.10864731768378988, 0.09353684959933162, 0.032573685311945155, 0.087948410800891, 0.08927587550715543, 0.05499139137100428, 0.0335799039748963, 0.042854260027525015, 0.02589349347545067, 0.06603662681300193, 0.020587193248502444, 0.06123372535512317, 0.04808439734915737, 0.044894557577208616, 0.0685118006367702, 0.08690490663866512, 0.04323001681768801, 0.05846223793923855, 0.040089166213874705, 0.07569663619506173, 0.04396096548589412, 0.006072307951399125, 0.031678347222623415, 0.027403075655456632, 0.020542528945952654, 0.08217869501095265, 0.059148264408577234, 0.03906800440745428, 0.051651801040861756, 0.02996060560690239, 0.019648497036541812, 0.10616744606522843, 0.06228389771422371, 0.05547093380300794, 0.0519142764096614, 0.06586345407413319, 0.019834891136270016, 0.11271301787928678, 0.05297744748531841, 0.0464007054688409, 0.0403929717867868, 0.0208249884963152, 0.8988056110683829, 57.991371005773544, 103.89641135931015, 97.31892630457878, 94.50129389762878, 86.94501176476479, 69.11591246724129, 45.075989440083504, 31.83857135474682, 51.901137605309486, 47.31759175658226, 44.267480224370956, 52.637754678726196, 32.89722494781017, 12.646604888141155, 0.8364323142450303, 0.12821669806726277, 0.11782583649619482, 0.08122385523165576, 0.20127384894294664, 0.3746727202087641, 0.5314442922826856, 0.5446292879059911, 0.4164509737165645, 0.2942743187304586, 0.1611779403174296, 0.25583326583728194, 1.107946210540831, 7.331118565052748, 26.56954798847437, 43.93907144665718, 52.577505111694336, 68.11968192458153, 76.69267550110817, 91.50096729397774, 86.53208032250404, 81.13274484872818, 73.26693892478943, 73.51163059473038, 72.14457035064697, 72.86789193749428, 71.76587507128716, 74.49912920594215, 75.48930287361145, 74.25544828176498, 74.98042657971382, 73.77753272652626, 72.6951152086258, 73.35654571652412, 74.74496081471443, 79.91896837949753, 82.18211933970451, 82.91746348142624, 85.56522980332375, 63.70213396847248, 46.25503197312355, 66.18754640221596, 76.85712307691574, 81.46866202354431, 68.2484570145607, 40.47851733863354, 69.4795073568821, 87.6607109606266, 80.2003812789917, 74.5682018995285, 76.55861109495163, 86.69848099350929, 89.21005502343178, 82.68852576613426, 80.06356582045555, 83.65528509020805, 77.52939820289612, 80.94321861863136, 85.88009610772133, 86.68775036931038, 84.51016321778297, 80.83952218294144, 80.17497584223747, 85.25590360164642, 82.73551404476166, 84.65468466281891, 84.01897877454758, 72.29612901806831, 39.283785447478294, 14.105231668800116, 0.8724539063405246, 0.40472269523888826, 0.48199086624663323, 0.507706431671977, 0.05547640714212321, 0.23779499548254535, 0.06042227592843119, 0.11421307644923218, 0.1177671697223559, 0.12579600530443713, 0.0569015050859889, 0.7095692935399711, 8.90311986207962, 26.68983433395624, 38.479057028889656, 37.16711662709713, 29.247790575027466, 40.067455396056175, 35.35896085202694, 33.33495385944843, 46.35704889893532, 64.24516662955284, 72.73082569241524, 73.2648566365242, 88.46062123775482, 73.73916238546371, 9.871808532625437, 0.20324680401245132, 0.050763624676619656, 0.02985053026350215, 0.022536852302437183, 0.07486644753953442, 0.08673639458720572, 0.04052188654895872, 0.08609844444436021, 0.09234930199454539, 0.03250863606808707, 0.048519781994400546, 0.070987211947795, 0.04138921227422543, 0.019232723643654026, 0.03971097889007069, 0.025973990523198154, 0.042945388340740465, 0.014829553128947737, 0.06596271632588468, 0.018138391642423812, 0.07592319161631167, 0.01243558232090436, 0.021584135065495502, 0.026910987216979265, 0.03346601028169971, 0.07156155261327513, 0.06879641427076422, 0.0712637955439277, 0.04724397818790749, 0.010693899021134712, 0.011417273144616047, 0.05016988427087199, 0.0434442785626743, 0.03204684951924719, 0.03346591751324013, 0.07841937564080581, 0.2229959622491151, 0.20463712862692773, 0.13257847807835788, 0.16722485568607226, 0.14884509349940345, 0.16312972933519632, 0.18194436037447304, 0.11975953937508166, 0.06794370143325068, 0.11985677556367591, 0.17794082988984883, 0.2037702704546973, 0.20732631557621062, 0.19443227152805775, 0.2608956629410386, 0.11700578557793051, 0.13339516706764698, 0.2578187780454755, 0.18749731709249318, 0.17738839000230655, 0.1006925039109774, 0.14818149473285303, 0.1042549463454634, 0.2243449937668629, 0.17444944067392498, 0.1635175311821513, 0.236134514270816, 0.2353193095768802, 1.3941671582870185, 72.73562863469124, 116.88042104244232, 105.6532546877861, 104.48330506682396, 90.95384985208511, 64.37017992138863, 31.111427173018456, 38.634274899959564, 79.2274358868599, 93.2430750131607, 76.4298740029335, 70.51773324608803, 46.83076947927475, 17.609925158321857, 1.4022172638215125, 0.374945355579257, 0.38921658822800964, 0.3669769159751013, 0.4588527500163764, 0.5678985267877579, 0.37084516778122634, 0.42162130877841264, 0.19358502089744434, 0.19888117967639118, 0.1792410874622874, 1.5777813806198537, 2.972874501720071, 9.589988104999065, 31.32138680666685, 45.6197402626276, 58.07701840996742, 71.02747589349747, 79.98916581273079, 95.02703368663788, 91.50074690580368, 84.24789369106293, 77.70118698477745, 76.99613481760025, 75.38312897086143, 73.8770417869091, 75.63858166337013, 78.63294258713722, 80.29754966497421, 77.80103042721748, 78.20074617862701, 77.9465702176094, 79.23736095428467, 78.70733499526978, 80.51307410001755, 83.13646093010902, 85.83245426416397, 87.40864768624306, 90.72760239243507, 69.79392528533936, 56.08355037868023, 74.49681892991066, 85.78878700733185, 90.48009127378464, 76.25678569078445, 45.230086371302605, 74.63158249855042, 90.88100016117096, 84.27798807621002, 78.81828904151917, 80.40383756160736, 92.56177917122841, 94.90585818886757, 82.1087072789669, 82.24990770220757, 87.79481336474419, 80.57076260447502, 84.7349439561367, 88.41205984354019, 90.07540538907051, 89.04707416892052, 85.4749770462513, 83.19644451141357, 88.99158954620361, 85.95048353075981, 91.11523479223251, 88.8121023774147, 76.64324775338173, 41.44211523234844, 17.55510739982128, 3.6845793994143605, 0.5465225363150239, 0.5896046839188784, 0.4693289956776425, 0.10497026538359933, 0.20527133834548295, 0.5248710606247187, 0.2603149472270161, 0.1629023501300253, 0.3034888836555183, 0.33567550184670836, 1.9940239889547229, 14.798404723405838, 40.74350751936436, 65.2931047976017, 58.117239251732826, 43.294109255075455, 62.30562150478363, 47.52795986831188, 26.257717721164227, 37.0033910125494, 64.60655763745308, 81.29310384392738, 82.7085430920124, 100.13538837432861, 79.61034134030342, 7.196603883057833, 0.49348988046403974, 0.14997306891018525, 0.09888721484458074, 0.1511797565035522, 0.14115107042016461, 0.14146102097583935, 0.24447885167319328, 0.2549913141410798, 0.18261324323248118, 0.17704820435028523, 0.0981969729764387, 0.21017447055783123, 0.19502511393511668, 0.1443323161220178, 0.1514025789219886, 0.14149438793538138, 0.10507834434974939, 0.27811351872514933, 0.11765354691306129, 0.1948754969635047, 0.1189371506916359, 0.18846816499717534, 0.15705575526226312, 0.1218121343117673, 0.2372115635080263, 0.18043435702566057, 0.20526556443655863, 0.19027815927984193, 0.15889387694187462, 0.1518712897086516, 0.15129257779335603, 0.14504937920719385, 0.11025487634469755, 0.13991616637213156, 0.1686159076052718], [0.009180728557112161, 0.03699279252032284, 0.038090744346845895, 0.02113764418027131, 0.033452291681896895, 0.04695010255090892, 0.016395700877183117, 0.0665074452990666, 0.09231952702975832, 0.0930939729732927, 0.027422675775596872, 0.06535264124977402, 0.020357689645607024, 0.018271894732606597, 0.02188302019931143, 0.06535881591844372, 0.047458332701353356, 0.0868933588208165, 0.08951405296102166, 0.05996363608574029, 0.04169967862253543, 0.08725678111659363, 0.02531630110752303, 0.048254887224175036, 0.021767451107734814, 0.04987318847270217, 0.10880862348130904, 0.1992726032040082, 0.9718192869331688, 54.020519480109215, 96.32448926568031, 88.83287206292152, 80.5118277668953, 64.49308052659035, 22.57276475429535, 15.31584670767188, 27.739875689148903, 61.764952316880226, 71.27336829900742, 68.1478764116764, 59.24724921584129, 23.105655759572983, 5.134284496307373, 0.09702477298560552, 0.03777722035010811, 0.11381440213881433, 1.5485062077641487, 0.19166815734934062, 0.08191191518562846, 0.02261994686705293, 0.10617007326800376, 0.41512463707476854, 0.8789656881708652, 0.2786810538964346, 0.4719732084777206, 3.491691774688661, 24.593082144856453, 62.899225652217865, 81.49279832839966, 79.91853520274162, 76.74382835626602, 71.5387612581253, 75.5520299077034, 80.75033336877823, 81.81913241744041, 78.12570780515671, 74.1283831000328, 70.45158639550209, 69.82710510492325, 72.85751849412918, 73.15162271261215, 76.13143801689148, 78.45384299755096, 71.28809630870819, 71.56659096479416, 68.01120534539223, 65.0421890616417, 66.63121059536934, 66.63585394620895, 68.31668615341187, 72.43140175938606, 77.43602961301804, 78.75530362129211, 82.9485534131527, 49.9720723181963, 28.348585925996304, 57.67762564122677, 69.89484786987305, 43.050188943743706, 61.59397669136524, 82.48542666435242, 74.27740350365639, 69.26973581314087, 69.91773024201393, 77.1052497625351, 79.93759498000145, 84.52574238181114, 79.00899320840836, 80.38178354501724, 77.82091096043587, 72.43183493614197, 65.41729733347893, 70.59992283582687, 71.30986154079437, 71.25602602958679, 64.96599555015564, 69.88458842039108, 77.87325695157051, 79.17997643351555, 76.99836149811745, 78.25847268104553, 82.33797177672386, 75.95432952046394, 54.61674928665161, 17.49946318566799, 0.8511428686324507, 1.5239756740629673, 2.701430842280388, 0.16084789240267128, 0.4102117085130885, 0.07028000458376482, 0.09404516880749725, 0.07317825453355908, 0.13726067292736843, 0.03192276613845024, 0.08199205229175277, 0.2351758227450773, 2.8842093469575047, 18.8639110699296, 56.29928760230541, 71.95939868688583, 63.99827107787132, 55.45746177434921, 39.74771395325661, 18.453181609511375, 17.83808011561632, 48.50841365754604, 54.62946720421314, 67.20938757061958, 83.99184063076973, 64.74542498588562, 5.293624196201563, 0.2169576706364751, 0.02724688696616795, 0.026403365627629682, 0.06923549110069871, 0.013748786659562029, 0.021460478419612627, 0.009877515240077628, 0.02679290781088639, 0.035218350822106004, 0.04276804473192897, 0.18607700971188024, 0.015633663642802276, 0.06000088447763119, 0.016554451831325423, 0.09080498173716478, 0.03528050940076355, 0.06418246732209809, 0.014642200731032062, 0.05579823206062429, 0.0238052068016259, 0.007747544914309401, 0.05907741156988777, 0.09215128215146251, 0.03242989791033324, 0.06708518500090577, 0.048711608615121804, 0.03946643751987722, 0.015304141725209774, 0.012014093463221798, 0.02471875533956336, 0.02239083289168775, 0.022216611869225744, 0.05626300204312429, 0.03619736606196966, 0.05782900414487813, 0.04689927285653539, 0.03228996225516312, 0.03517138400638942, 0.03753749551833607, 0.06215269342646934, 0.02593485522083938, 0.02469613838911755, 0.024890913191484287, 0.016586507044848986, 0.04281282963347621, 0.05427809097454883, 0.04548477278149221, 0.016219548415392637, 0.005352497528292588, 0.07645843594218604, 0.06723323604092002, 0.11233878249186091, 0.052015304972883314, 0.11202259789570235, 0.038460768046206795, 0.02125609837094089, 0.020836987168877386, 0.013405110130406683, 0.04010354161437135, 0.06023192989232484, 0.05523007348529063, 0.14036624925211072, 2.4114408530294895, 71.21036767959595, 110.94155251979828, 99.36251744627953, 98.53924602270126, 85.03632098436356, 43.124311566352844, 28.033356741070747, 35.02332866191864, 60.82429379224777, 79.35013130307198, 76.04182362556458, 59.29583340883255, 26.46693829447031, 5.721150655299425, 0.14877261535730213, 0.09537106758216396, 0.1669234101427719, 1.986735148821026, 0.1451049660681747, 0.4198846238432452, 0.8763806393835694, 1.3647377374581993, 1.4168388792313635, 1.534275021404028, 1.038173285778612, 1.1768704745918512, 3.73400857206434, 27.609588280320168, 62.598057612776756, 83.67071986198425, 87.76487097144127, 80.7062329351902, 70.50894051790237, 78.20899173617363, 84.32861655950546, 85.35730496048927, 80.54085060954094, 77.75746196508408, 73.3469246327877, 72.94790804386139, 75.4911495745182, 78.39525014162064, 79.60056066513062, 80.93880325555801, 75.24105459451675, 74.96211156249046, 70.34332260489464, 69.94859218597412, 67.73553773760796, 69.57476064562798, 69.94407802820206, 77.21908405423164, 80.88282465934753, 83.17635118961334, 86.07208460569382, 54.208924770355225, 37.63371258974075, 64.34569403529167, 76.02456495165825, 52.00693532824516, 66.31939172744751, 85.33081278204918, 78.77431020140648, 73.4369570016861, 74.3705441057682, 79.86642479896545, 82.62991771101952, 85.15347629785538, 80.40761455893517, 81.06355056166649, 84.00599867105484, 76.11822232604027, 70.73035463690758, 73.06921273469925, 74.0510268509388, 75.18515959382057, 69.22865241765976, 74.66527909040451, 81.90388306975365, 81.99001684784889, 82.23926827311516, 83.0437459051609, 86.30261063575745, 81.60365357995033, 55.65428741276264, 20.746651142835617, 1.893718633800745, 0.6547993887215853, 2.0294404635205865, 0.577107451390475, 0.6460366433020681, 0.3403119061840698, 0.37582993623800576, 0.1833244285080582, 0.10004174429923296, 0.03767221758607775, 0.014449959435296478, 0.2120808549807407, 3.5733755165711045, 22.58315909653902, 44.26320545375347, 44.66021195054054, 36.9519379734993, 39.566604271531105, 27.73853436112404, 18.701863065361977, 33.67352329194546, 65.75471922755241, 65.76620221138, 74.6815650165081, 93.03462579846382, 91.14611953496933, 16.458402648568153, 0.12870117207057774, 0.052237325871828943, 0.055617051548324525, 0.10172713940846734, 0.06565183808561414, 0.04121165715332609, 0.06576684871106409, 0.06274825951550156, 0.04326301270339172, 0.004090947595614125, 0.06860361172584817, 0.04063101936480962, 0.08903531575924717, 0.051189888326916844, 0.029615729581564665, 0.023609341042174492, 0.05932664331339765, 0.018067279052047525, 0.03452873235801235, 0.03995004321041051, 0.06795048466301523, 0.019577738821681123, 0.052318483431008644, 0.011457703494670568, 0.09809428942389786, 0.013175813401176129, 0.0430328244692646, 0.043604704915196635, 0.024983453440654557, 0.04782595926371869, 0.05070064231404103, 0.006494820045190863, 0.0777444665436633, 0.02989512406202266, 0.1479431168991141, 0.18679499306017533, 0.08799567818641663, 0.1897050134721212, 0.132650867162738, 0.16495636256877333, 0.11125797056593001, 0.22925873869098723, 0.15504101727856323, 0.18453209573635831, 0.13234991143690422, 0.15795133454957977, 0.13281804334837943, 0.1342996075982228, 0.06645947287324816, 0.20882336102658883, 0.23841468879254535, 0.20113279635552317, 0.13331081456271932, 0.23985580599401146, 0.09904311780701391, 0.1307928262394853, 0.11157422937685624, 0.15182178845861927, 0.17402983037754893, 0.18954500643303618, 0.26689200836699456, 0.31002542353235185, 3.069586199708283, 85.93106657266617, 127.53805875778198, 110.42562380433083, 105.47581180930138, 83.03827419877052, 37.63234846293926, 23.027634546160698, 35.22557280957699, 79.33807075023651, 85.82996159791946, 86.6195060312748, 82.48254641890526, 37.587871849536896, 9.45482935756445, 0.239490995882079, 0.27447283908259124, 0.3899287531385198, 2.5272994861006737, 0.5061244103126228, 0.41802331747021526, 0.6955177069175988, 0.9289050428196788, 1.110643947031349, 1.8772444990463555, 1.8873638310469687, 3.191693597473204, 5.115538677200675, 28.95073961466551, 66.71180427074432, 87.3660595715046, 89.89289358258247, 81.14178836345673, 73.0184854567051, 77.87609159946442, 88.24074223637581, 91.14621832966805, 85.78064784407616, 83.89958158135414, 76.96966543793678, 77.33547940850258, 79.07658398151398, 82.50827103853226, 82.05856516957283, 88.53783309459686, 81.09471648931503, 79.97289508581161, 73.81424635648727, 72.12916597723961, 71.3223248720169, 72.49056458473206, 74.05078366398811, 81.17948234081268, 85.15887960791588, 88.97272735834122, 91.53707295656204, 61.99480578303337, 46.83997258543968, 73.72232168912888, 86.13668113946915, 60.725552290678024, 72.54542604088783, 90.49595922231674, 83.08443412184715, 76.86913043260574, 78.70934128761292, 84.6813440322876, 87.04626873135567, 90.0019933283329, 81.92573949694633, 86.09844759106636, 86.6972042620182, 79.69259932637215, 72.78865098953247, 76.89520463347435, 78.43782305717468, 77.92267709970474, 71.22291460633278, 77.43313416838646, 86.17753654718399, 84.59531664848328, 86.02245926856995, 85.76647460460663, 89.3957206606865, 84.22628805041313, 60.556389167904854, 23.574280813336372, 4.1179511323571205, 3.287549391388893, 5.691044870764017, 3.0170585308223963, 0.9854360937606543, 0.20526627689832821, 0.4019431443884969, 0.3212233929662034, 0.21592537290416658, 0.3012352780206129, 0.2521205088123679, 0.8590105839539319, 6.7729465663433075, 34.77354906499386, 84.15554344654083, 100.17502024769783, 87.80745148658752, 77.23803743720055, 52.53428243100643, 27.518970742821693, 27.75915965437889, 63.367755711078644, 71.73321962356567, 82.55779758095741, 102.67966344952583, 103.37541371583939, 15.083962250500917, 0.5226491298526525, 0.16145606758072972, 0.13827754883095622, 0.13913559028878808, 0.17047112836735323, 0.13709884020499885, 0.1351107156369835, 0.20943156589055434, 0.1350481525878422, 0.1891698210965842, 0.35928419907577336, 0.15972373163094744, 0.1808290311601013, 0.13116894668200985, 0.12485052400734276, 0.09415266147698276, 0.22388165612937883, 0.09180442459182814, 0.1356437854701653, 0.16222358186496422, 0.20973740494810045, 0.1397944096243009, 0.10472534922882915, 0.14195334690157324, 0.12674487079493701, 0.10878192100790329, 0.08093179785646498, 0.07134452636819333, 0.09364863930386491, 0.16419953521108255, 0.12710386246908456, 0.12971016636583954, 0.22340390598401427, 0.15977801231201738], [0.07040879689157009, 0.05608111649053171, 0.06258451205212623, 0.023988378125068266, 0.05440483124402817, 0.06712675269227475, 0.019745582940231543, 0.039898668037494645, 0.0771444253041409, 0.006066527548682643, 0.10235639158054255, 0.011292617382423487, 0.04240037364070304, 0.021342367472243495, 0.08818757531116717, 0.03749813200556673, 0.06286270610871725, 0.03613238732214086, 0.0950115935120266, 0.11860152924782597, 0.09073498978978023, 0.0961058160464745, 0.03653860556369182, 0.029993961434229277, 0.02414816994132707, 0.03110551868303446, 0.044607364980038255, 1.6803518892265856, 70.28402298688889, 97.50297322869301, 83.0191308259964, 72.1343868970871, 46.72003962099552, 27.890944182872772, 20.5698599293828, 37.705581933259964, 71.68683171272278, 41.744924783706665, 40.91941528022289, 32.27762259542942, 20.242670886218548, 3.377811647951603, 0.10814141045557335, 0.20645384676754475, 0.0676827400457114, 0.02335865097848, 0.5260865797754377, 0.0329191327909939, 0.07442573056323454, 0.39632823318243027, 0.96705790492706, 1.341389890294522, 3.5234554577618837, 2.5949719548225403, 6.425182577222586, 45.226784348487854, 83.16277831792831, 88.60668540000916, 80.87871327996254, 79.43030700087547, 81.18151903152466, 78.61507594585419, 76.03133618831635, 77.83626213669777, 83.06566312909126, 80.74049189686775, 78.98851230740547, 78.2077606022358, 78.41095849871635, 79.24033999443054, 80.95822021365166, 85.03648057579994, 75.15667632222176, 76.24725580215454, 69.67026472091675, 66.55589863657951, 63.87765794992447, 63.211036920547485, 64.61834460496902, 65.59611573815346, 67.07393243908882, 72.32161805033684, 77.87394851446152, 76.93826392292976, 85.23288443684578, 43.087225556373596, 29.556068032979965, 37.476864606142044, 51.20754562318325, 82.19373151659966, 72.41949319839478, 67.99473702907562, 61.40677593648434, 74.63827773928642, 79.49983566999435, 85.50484344363213, 82.08610609173775, 73.72344642877579, 79.29335474967957, 79.87312763929367, 70.16315907239914, 62.80383937060833, 59.55785974860191, 64.06193286180496, 60.352146327495575, 60.261798575520515, 60.0360868871212, 63.75935509800911, 71.59798488020897, 77.27288916707039, 75.61830595135689, 77.35321685671806, 81.95758178830147, 82.17225506901741, 61.49340748786926, 40.16973450779915, 16.61235138773918, 3.767522773705423, 0.6522398698143661, 1.4694567932747304, 0.19241287285694852, 0.2851436461787671, 0.06129981731646694, 0.07748173884465359, 0.0380925143690547, 0.14514286012854427, 0.05878880889213178, 0.23842544993385673, 4.466224294155836, 12.527441382408142, 37.15914845466614, 60.484823808074, 64.61046382784843, 88.23408499360085, 69.55924227833748, 26.01604498922825, 12.026411667466164, 36.46200746297836, 67.13678106665611, 61.17271229624748, 76.74550786614418, 78.06064009666443, 19.882362820208073, 0.7605837529990822, 0.058709926015581004, 0.04233186598867178, 0.0653636472998187, 0.06264596187975258, 0.03513169394864235, 0.03228341280191671, 0.055797749664634466, 0.011347568779456196, 0.04779572045663372, 0.02245748146378901, 0.026214281242573634, 0.01693119753326755, 0.04038408827909734, 0.04323695960920304, 0.10102127533173189, 0.005929399067099439, 0.02377619439357659, 0.023003193782642484, 0.09685900688054971, 0.0645489917951636, 0.05650553590385243, 0.017917118457262404, 0.028820883853768464, 0.04816821921849623, 0.03430898243095726, 0.04111198300961405, 0.03807446533755865, 0.03342301395605318, 0.06103348649048712, 0.02827064072334906, 0.04624731096555479, 0.04555844207061455, 0.057248833909397945, 0.04146168670558836, 0.03691955738759134, 0.041366246514371596, 0.06295839120866731, 0.052657340638688765, 0.019634925010905135, 0.02132055760739604, 0.028035532050125767, 0.0318029092886718, 0.020432720775716007, 0.07503159766201861, 0.004081121096533025, 0.060220675222808495, 0.02019458042923361, 0.009335588802059647, 0.022558717828360386, 0.01348501809843583, 0.04156297873123549, 0.07448472388205118, 0.09587778375134803, 0.03290610809926875, 0.0417701974947704, 0.028692199157376308, 0.053906052344245836, 0.007993059425643878, 0.020583718142006546, 3.853648714721203, 91.7939467728138, 110.96356093883514, 91.3745404779911, 84.59692776203156, 57.473671585321426, 47.3484992980957, 26.587570421397686, 29.99324407428503, 42.042080238461494, 28.76235142350197, 37.711114436388016, 34.56451088190079, 25.00978298485279, 4.8141611739993095, 0.08071737654972821, 0.13198758009821177, 0.09408953439560719, 0.017664847619016655, 0.6243453884962946, 0.37876127113122493, 0.5688944295980036, 1.3838414498604834, 3.793750866316259, 2.6734130457043648, 2.162854392081499, 1.519448454491794, 5.441758772358298, 46.98772385716438, 86.02824255824089, 91.09231442213058, 84.29195612668991, 84.23353046178818, 83.34900632500648, 79.93187248706818, 75.56852102279663, 80.97331300377846, 84.01657730340958, 82.99440935254097, 82.7459254860878, 80.76044082641602, 80.55380031466484, 81.84622496366501, 85.23311242461205, 85.64246445894241, 80.20924240350723, 79.4228745996952, 72.74417817592621, 70.41320085525513, 67.35795199871063, 64.19269144535065, 66.59269586205482, 67.58376628160477, 69.80389595031738, 73.99551182985306, 80.86992055177689, 81.37572661042213, 85.80201029777527, 48.55015441775322, 38.4381066262722, 45.69660633802414, 57.31267422437668, 83.97746980190277, 76.07107445597649, 71.0409651696682, 65.38455069065094, 76.9879424571991, 83.44718545675278, 86.41057804226875, 82.73158505558968, 75.67999184131622, 82.63477385044098, 83.17326575517654, 72.62007683515549, 63.67710091173649, 61.7079021781683, 66.6498675942421, 63.94639626145363, 62.776024863123894, 63.00468899309635, 67.57704064249992, 73.69080618023872, 80.49136206507683, 80.34450754523277, 81.20850518345833, 85.17360001802444, 87.22993567585945, 70.41641548275948, 45.054714381694794, 19.890055507421494, 4.956458313390613, 0.4984923417214304, 1.741456410381943, 1.3717041886411607, 1.047872502822429, 0.3101145406253636, 0.09343024750705808, 0.21587177499895915, 0.12219389507663436, 0.014129051069176057, 0.06642842883593403, 4.094115011394024, 16.93154565989971, 38.92956085503101, 55.16132466495037, 51.92016698420048, 59.080514162778854, 39.62935410439968, 23.89013696461916, 23.690003603696823, 55.33000521361828, 82.92948603630066, 68.01183611154556, 81.37085527181625, 97.69930109381676, 35.912838131189346, 0.7045376510359347, 0.0866368057904765, 0.04235416752635501, 0.06489355611847714, 0.04457662893400993, 0.015497709609917365, 0.042996822885470465, 0.043888042055186816, 0.025216534195351414, 0.016787484346423298, 0.04895500336715486, 0.07099722351995297, 0.05289070526487194, 0.023021124070510268, 0.021170860854908824, 0.034687622464844026, 0.011465428324299864, 0.05741243665397633, 0.03926090714230668, 0.09905009399517439, 0.01994599064346403, 0.06062124943127856, 0.0944934185827151, 0.021796597102365922, 0.0826778264308814, 0.022650361934211105, 0.06666789762675762, 0.0167997891549021, 0.030722316296305507, 0.013353409340197686, 0.027810477622551844, 0.07311373963602819, 0.0356338125129696, 0.15129177627386525, 0.2654979581711814, 0.24416624422883615, 0.06680215956293978, 0.19982578523922712, 0.08347580587724224, 0.12687580048805103, 0.09438536188099533, 0.14753910654690117, 0.15281675616279244, 0.14262270473409444, 0.17639420897467062, 0.1014979493629653, 0.30318736389745027, 0.28659127943683416, 0.1447481117793359, 0.11481772642582655, 0.058635447785491124, 0.2022840455174446, 0.20631174033042043, 0.193240322987549, 0.17416703864000738, 0.14513368718326092, 0.14639703033026308, 0.23156356735853478, 0.16408536321250722, 0.11338709577103145, 6.011587595567107, 108.3522042632103, 122.28859484195709, 105.69233179092407, 97.96365290880203, 64.01109918951988, 42.32752852141857, 31.619136929512024, 52.29036211967468, 93.61623018980026, 58.59729029238224, 59.96127650141716, 52.8689456731081, 34.33203935623169, 6.903049685060978, 0.3039170434931293, 0.40210718871094286, 0.4337789345299825, 0.3358806314645335, 1.164242208469659, 0.4260146152228117, 0.5085994431283325, 1.3072925386950374, 4.2643368523567915, 5.154953962191939, 9.546982012689114, 8.599170371890068, 6.438910290598869, 49.045161455869675, 89.00190979242325, 93.85402143001556, 86.05695381760597, 87.0530703663826, 85.8555418252945, 80.27146026492119, 75.84146037697792, 80.89513599872589, 85.75466483831406, 86.51025429368019, 85.69902822375298, 85.17863094806671, 84.45979312062263, 85.97672492265701, 86.6204559803009, 90.97483232617378, 84.7221690416336, 82.45546907186508, 76.32449045777321, 74.38418537378311, 72.8720261156559, 70.16941353678703, 69.5290718972683, 73.78229007124901, 74.64564934372902, 78.46547797322273, 83.79328608512878, 82.8240492939949, 88.5509803891182, 54.93404746055603, 46.092689484357834, 51.96210913360119, 62.42143549025059, 87.98357963562012, 81.2137109041214, 75.63088327646255, 68.58397901058197, 82.86878049373627, 89.41680192947388, 89.89968001842499, 83.57280671596527, 77.90949180722237, 86.00288271903992, 85.91782808303833, 75.15518680214882, 69.21640187501907, 66.26491025090218, 69.39091891050339, 66.37103095650673, 65.56311830878258, 64.5927719771862, 71.1742316186428, 79.01911586523056, 85.83626165986061, 83.85234251618385, 83.69527414441109, 88.92103493213654, 91.60729318857193, 66.6600738465786, 44.0268125385046, 20.193881504237652, 5.399377746507525, 3.617756422609091, 6.777453599497676, 2.5990192126482725, 0.7220306061208248, 0.35000025818590075, 0.1363158001913689, 0.30742903472855687, 0.34483404946513474, 0.22297222836641595, 0.5573288595769554, 8.18853685632348, 24.40620057284832, 57.03593127429485, 85.37095382809639, 88.67828115820885, 120.55450469255447, 94.43290516734123, 36.17126986384392, 19.86996028572321, 50.28555169701576, 87.82315224409103, 77.55070745944977, 92.8884020447731, 110.72382420301437, 33.20328712463379, 0.9858872601762414, 0.2711592387640849, 0.17737938032951206, 0.1697817919193767, 0.1456748167402111, 0.1692277638358064, 0.08993916257168166, 0.2253789539099671, 0.11914002418052405, 0.1822272373829037, 0.1220412649854552, 0.13064803322777152, 0.16183058498427272, 0.09924565732944757, 0.16716352460207418, 0.19142814679071307, 0.1330441312165931, 0.12298909146920778, 0.11820301820989698, 0.28207747789565474, 0.10309416058589704, 0.26562688406556845, 0.1989916557795368, 0.13989669241709635, 0.16876300127478316, 0.1547823045984842, 0.19362819904927164, 0.10921498644165695, 0.14062169648241252, 0.15311637602280825, 0.1614378998056054, 0.15189983270829543, 0.13421491370536387], [0.026263936488248874, 0.033003863791236654, 0.011942738747166004, 0.029842377771274187, 0.05931820509431418, 0.02075774063996505, 0.032516443461645395, 0.018422018220007885, 0.06915031481184997, 0.04540590103715658, 0.015329368252423592, 0.10424663429148495, 0.026721500216808636, 0.03485616420221049, 0.049213281890843064, 0.013053666098130634, 0.0382437195366947, 0.10424280480947345, 0.0663139451353345, 0.07789449169649743, 0.07288659049663693, 0.15427541773533449, 0.06915032223332673, 0.020279480268072803, 0.014345860236062435, 0.09146940428763628, 1.490469784475863, 73.3482013642788, 97.92373225092888, 86.45388811826706, 92.61964246630669, 89.35746431350708, 43.74967060983181, 22.883654572069645, 42.94041283428669, 58.30185614526272, 75.86834773421288, 64.98003199696541, 59.6868210285902, 31.458994522690773, 7.63007084839046, 0.15580047183902934, 0.12621791625861079, 0.09779761589015834, 0.057603135210229084, 0.10421233964734711, 0.013114518496877281, 0.03714599406521302, 0.5373327294364572, 0.7787187548819929, 2.1046137297526, 1.7488212464377284, 0.9841616777703166, 5.269240904599428, 52.34761744737625, 82.0833170413971, 86.79960116744041, 78.01210910081863, 78.84314730763435, 72.79443427920341, 80.55670335888863, 80.19762262701988, 77.53660261631012, 73.94608408212662, 78.2747358083725, 76.34237229824066, 76.94072619080544, 79.33502331376076, 78.46145018935204, 75.05008444190025, 80.19085139036179, 70.48225075006485, 77.06089094281197, 78.62123921513557, 74.35894712805748, 69.96231704950333, 67.7200497686863, 63.42358611524105, 61.4859788864851, 60.2161668241024, 65.54476529359818, 68.68658870458603, 77.81663239002228, 79.20501708984375, 77.86511018872261, 70.32980293035507, 32.1572944521904, 30.396725423634052, 69.55492570996284, 79.09370586276054, 71.01595491170883, 62.92416371405125, 66.0717362165451, 77.94508069753647, 77.25542530417442, 79.36935067176819, 75.10613143444061, 77.29624271392822, 78.3490826189518, 80.31448155641556, 72.30505093932152, 59.78286847472191, 57.17166379094124, 59.25255373120308, 57.23345227539539, 62.12541237473488, 62.65565872192383, 64.58202615380287, 60.751725286245346, 63.44779461622238, 67.61563137173653, 73.646971732378, 78.24337989091873, 79.46856334805489, 76.60961955785751, 78.81318971514702, 78.29328641295433, 70.23270294070244, 37.32147194445133, 2.4283126601949334, 2.3728878842666745, 1.0621205507777631, 0.1221927373262588, 0.15729313861811534, 0.08168864747858606, 0.053511077639996074, 0.08066693277214654, 0.037821671285200864, 0.09636061760829762, 2.499619396403432, 7.094857217743993, 19.542961232364178, 35.641072914004326, 46.49801753461361, 46.48155301809311, 61.26218609511852, 40.637474209070206, 13.760991990566254, 25.252371467649937, 58.562392964959145, 71.76043376326561, 67.37613782286644, 80.47912672162056, 32.879251912236214, 1.4513280848041177, 0.11408780934289098, 0.010202066623605788, 0.0504502268449869, 0.0450680086214561, 0.1117356464965269, 0.01895658719149651, 0.09119855749304406, 0.03880310592649039, 0.04107296459551435, 0.0509422633331269, 0.016162406755029224, 0.02574742025899468, 0.0662646591081284, 0.08549381673219614, 0.010886408417718485, 0.04730691231088713, 0.024428024553344585, 0.008935576770454645, 0.10732805370935239, 0.02817560871335445, 0.0617395435256185, 0.028149323698016815, 0.029666750378964934, 0.020925753597111907, 0.012033870771119837, 0.050904992676805705, 0.07622750184964389, 0.04764448189234827, 0.02426542927423725, 0.010266529570799321, 0.04744917088828515, 0.024437501779175363, 0.009225257417710964, 0.04349774288129993, 0.07366943755187094, 0.03737742539669853, 0.01601463030965533, 0.0712264580943156, 0.06235291002667509, 0.008057121613092022, 0.043700115420506336, 0.027356062455510255, 0.05241143000603188, 0.004146285373280989, 0.0158329785335809, 0.08773745532380417, 0.06694062205497175, 0.05115854371979367, 0.10339011423639022, 0.016889854341570754, 0.028396685229381546, 0.017064939966076054, 0.011707418561854865, 0.03617808877606876, 0.03648560508736409, 0.02858019979612436, 0.025357699960295577, 3.002843731082976, 91.51678204536438, 106.9656054675579, 96.78543493151665, 107.57639229297638, 96.2623094022274, 66.70047327876091, 32.39497549831867, 39.9081489443779, 43.026212230324745, 51.35854572057724, 54.71770606935024, 54.248123466968536, 37.63310082256794, 8.723036125302315, 0.15521614928729832, 0.11773178412113339, 0.07553723771707155, 0.01872924138297094, 0.1618155193864368, 0.30383855395484716, 0.6292307982221246, 1.9964368594810367, 2.2071804385632277, 5.0760160479694605, 0.24128533084876835, 0.17023539257934317, 6.791433999314904, 55.7809080183506, 86.9560919702053, 89.93572488427162, 82.70663559436798, 81.03057593107224, 77.91822373867035, 84.80044484138489, 83.25578972697258, 75.93156114220619, 75.175059735775, 79.84079137444496, 80.5981895327568, 79.90937009453773, 80.68618521094322, 80.47313824295998, 77.1652789413929, 79.98503163456917, 74.88303780555725, 79.71910670399666, 80.7383944094181, 76.63059443235397, 72.62567013502121, 71.74834281206131, 66.84244886040688, 64.99302729964256, 63.88819098472595, 67.41491854190826, 71.7775784432888, 80.56304901838303, 81.3319681584835, 79.85714569687843, 73.04107144474983, 38.332985267043114, 34.47025313973427, 70.77198520302773, 80.79425901174545, 72.18203634023666, 65.03272756934166, 68.18797945976257, 81.84040367603302, 80.7552807033062, 80.42259335517883, 76.75405740737915, 77.14016988873482, 79.5097379386425, 83.27525988221169, 76.0405620932579, 63.826049119234085, 60.99901221692562, 61.52773104608059, 61.40229977667332, 64.61950734257698, 65.6825079023838, 67.25112453103065, 66.31570592522621, 67.9273134469986, 71.60686120390892, 76.95410907268524, 83.41099619865417, 84.63415056467056, 78.08177456259727, 81.46647334098816, 87.25388199090958, 79.23325717449188, 43.16236272454262, 3.631863878108561, 0.9100513451267034, 0.6750461866613477, 0.6052284361794591, 0.6246640370227396, 0.5295839358586818, 0.1163083226128947, 0.04444732825504616, 0.06392094932380132, 0.1826398863340728, 2.1145468717440963, 9.249153044074774, 23.238787315785885, 40.15724077820778, 43.535544499754906, 46.575575172901154, 50.00519894063473, 46.10744409263134, 24.894932247698307, 34.341554045677185, 76.2013466656208, 82.88241416215897, 70.62197685241699, 93.05560827255249, 53.30543205142021, 1.9327888498082757, 0.12801685254089534, 0.05609297972114291, 0.05449119496915955, 0.02950334059278248, 0.08148244174662977, 0.0192925964074675, 0.06297560903476551, 0.03832319242064841, 0.08691128910868429, 0.010789811403810745, 0.020188986491120886, 0.05152576952241361, 0.021640586528519634, 0.05480890838953201, 0.02670042322279187, 0.007723695998720359, 0.01856716931797564, 0.018067279052047525, 0.07443433205480687, 0.0559317073202692, 0.026167841351707466, 0.011010010330210207, 0.048572522719041444, 0.049168894038302824, 0.01725884088955354, 0.025413570692762733, 0.0724362552864477, 0.05571428031544201, 0.041338749942951836, 0.023622645894647576, 0.04428047490364406, 0.10924870221060701, 0.10625879702274688, 0.08493333938531578, 0.11084046796895564, 0.14024039584910497, 0.09400803173775785, 0.1323381409747526, 0.17959961900487542, 0.08686068205861375, 0.23283925984287634, 0.1356096615199931, 0.24797294230666012, 0.08149789326125756, 0.1493904978269711, 0.15505758201470599, 0.15020012157037854, 0.13651061395648867, 0.1797625352628529, 0.09631001055822708, 0.14912767364876345, 0.21150975750060752, 0.39891411317512393, 0.20368450786918402, 0.20254434639355168, 0.12236786933499388, 0.10158290300751105, 4.701266856864095, 108.7037006020546, 119.0730781853199, 109.62420120835304, 117.03260287642479, 110.02624243497849, 63.5039784014225, 36.62939228117466, 57.7990747243166, 77.23695829510689, 100.23106724023819, 89.15169015526772, 81.65135622024536, 49.80480149388313, 12.589650694280863, 0.3857258817879483, 0.4312980535905808, 0.1823319841059856, 0.283274176181294, 0.24153583537554368, 0.16891824372578412, 0.25259423651732504, 2.013168786652386, 6.168132545426488, 8.077457416802645, 7.371134217828512, 6.365455482155085, 5.77469595707953, 53.485667780041695, 86.85990393161774, 94.11279514431953, 82.89686098694801, 85.20085215568542, 79.23907086253166, 87.05747812986374, 83.17850947380066, 77.59806051850319, 76.41575396060944, 84.04032602906227, 82.32911825180054, 81.28323197364807, 84.26875457167625, 83.29138621687889, 79.49021458625793, 83.27850490808487, 79.22457844018936, 83.4309983253479, 84.45739164948463, 80.98069980740547, 76.32471084594727, 75.19490987062454, 69.14665281772614, 69.43666085600853, 67.29132637381554, 73.33538085222244, 76.45873725414276, 86.50625690817833, 85.52392601966858, 85.46212613582611, 74.61740165948868, 45.01314461231232, 45.58039717376232, 73.18234026432037, 88.33940774202347, 76.79844662547112, 69.51793849468231, 72.90407359600067, 85.94090044498444, 82.94208616018295, 80.16758143901825, 79.41526740789413, 81.20508536696434, 84.02081787586212, 87.680773884058, 78.8293768465519, 67.79464736580849, 64.02008190751076, 65.1542754471302, 63.94994527101517, 68.68857979774475, 68.93071800470352, 71.95518851280212, 68.58825758099556, 69.8210634291172, 74.78692576289177, 79.67005893588066, 88.217244297266, 85.3972028195858, 79.00325551629066, 79.07132506370544, 86.42181023955345, 77.99363449215889, 41.8466567248106, 2.8462493838742375, 5.965492743998766, 3.836836041882634, 1.5524247474968433, 0.6604132906068116, 0.3380892629502341, 0.1004294422455132, 0.2044553024461493, 0.2049982428434305, 0.30095762573182583, 4.680249709635973, 16.01255737245083, 34.296192079782486, 52.99747757613659, 64.38385918736458, 68.7968435883522, 84.91620182991028, 54.88980643451214, 21.81233625859022, 37.38376960158348, 79.12330627441406, 93.49418833851814, 80.8804003894329, 106.26996919512749, 55.51421172916889, 2.17226411215961, 0.17687366605969146, 0.15245616144966334, 0.18327994417632, 0.18277647119248286, 0.23198139650048688, 0.17086687119444832, 0.15101925964700058, 0.15257977356668562, 0.15092272107722238, 0.1387356172199361, 0.17594543227460235, 0.1291116836364381, 0.2076513911015354, 0.1404198323143646, 0.1586423779372126, 0.17030208196956664, 0.09267563174944371, 0.09390255028847605, 0.17085044004488736, 0.12227394312503748, 0.10830558836460114, 0.09652687353082001, 0.0945156607485842, 0.07147939686547033, 0.10165596744627692, 0.18430268304655328, 0.12353267753496766, 0.20427184354048222, 0.1428322575520724, 0.16439166240161285, 0.11431064660428092], [0.026154497536481358, 0.03651183258625679, 0.05695293591998052, 0.027023357652069535, 0.02601974021672504, 0.11060416072723456, 0.09262054954888299, 0.01986177172511816, 0.04250616308127064, 0.03039286024431931, 0.02609223320177989, 0.04335500932938885, 0.028161522750451695, 0.02261382971482817, 0.04536689375527203, 0.009446607600693824, 0.03178101593221072, 0.07907482562586665, 0.047163106355583295, 0.05424844959634356, 0.0247258280069218, 0.0758205600141082, 0.04442675592144951, 0.07828931426047347, 0.07061894342768937, 2.032527085393667, 61.81548960506916, 106.6815859079361, 93.60973253846169, 89.47648912668228, 62.1755962818861, 45.25374390184879, 27.55524169653654, 38.478437662124634, 49.48270797729492, 61.96924455463886, 53.80313314497471, 35.93144953250885, 20.378884077072144, 5.755759198218584, 0.07759136889944784, 0.016649270473862998, 0.020396591171447653, 0.1754721943871118, 0.027484949387144297, 0.15864861197769642, 0.0658157562429551, 0.6190710933879018, 1.4466772531159222, 2.7847786573693156, 6.455500675365329, 1.208492734003812, 4.986044000834227, 59.823435097932816, 82.94751986861229, 85.67993804812431, 79.46575909852982, 73.06478977203369, 62.887974455952644, 76.31914794445038, 75.0455778837204, 84.12531226873398, 72.38079607486725, 74.85764756798744, 73.92681911587715, 72.20030575990677, 72.70452350378036, 75.78805804252625, 72.87644147872925, 77.6858814060688, 68.23889672756195, 72.04750835895538, 76.39503747224808, 72.76405110955238, 76.56027540564537, 76.03315249085426, 69.07438069581985, 64.54170271754265, 62.7835750579834, 60.20173899829388, 60.46678617596626, 65.48288941383362, 70.30459508299828, 78.35900008678436, 76.41270652413368, 75.58816596865654, 49.54696632921696, 20.70910345762968, 67.15244382619858, 72.46173173189163, 64.95994627475739, 57.31890968978405, 65.97317710518837, 76.62467435002327, 75.1143465936184, 74.34565544128418, 76.1600960791111, 77.67801582813263, 77.23350808024406, 74.07736703753471, 64.88203525543213, 59.07828368246555, 58.22356894612312, 57.97016814351082, 64.98659044504166, 72.57186502218246, 74.16886612772942, 75.5190096795559, 72.62868717312813, 69.37808319926262, 68.40061604976654, 77.4750991165638, 79.79097604751587, 79.73633497953415, 70.88307604193687, 75.34094363451004, 79.33756157755852, 82.02376663684845, 89.43783760070801, 68.26985746622086, 7.087091859430075, 1.3822735589928925, 0.9411945927422494, 0.6279258651193231, 0.734665225027129, 0.2459056008956395, 0.07473554753232747, 0.08967510642833076, 0.10836455941898748, 0.10632173114572652, 0.4478184983599931, 5.843777200207114, 16.342725455760956, 34.372552782297134, 36.952485144138336, 42.452849596738815, 41.57585285604, 51.94388531148434, 31.85113538056612, 20.705514550209045, 43.18799614906311, 58.480568155646324, 67.53117710351944, 83.29428926110268, 24.064074531197548, 0.6606836698483676, 0.06530680620926432, 0.08821879746392369, 0.0070251592387649, 0.06453982627135701, 0.0437603666796349, 0.04906535330519546, 0.09163201626506634, 0.014175631040416192, 0.08096180288703181, 0.03559631179086864, 0.04657642748497892, 0.026629577805579174, 0.05048821367381606, 0.0477219138701912, 0.04547548480331898, 0.047133464977378026, 0.0345025159913348, 0.08066531489021145, 0.08065128829912283, 0.04568864074826706, 0.051064517319900915, 0.03216629818780348, 0.06903877743752673, 0.02204662850999739, 0.03386751217476558, 0.07394245141767897, 0.022193835357029457, 0.02295734575454844, 0.020630696089938283, 0.01827192070777528, 0.09494242534856312, 0.03577977811801247, 0.042308013362344354, 0.014447965841100086, 0.061802974887541495, 0.04666316228394862, 0.022347632475430146, 0.04332908611104358, 0.020408623240655288, 0.025577216110832524, 0.023155142953328323, 0.03626786266977433, 0.012166192918812158, 0.021323027103790082, 0.013862849191355053, 0.016923698130995035, 0.008039717322390061, 0.036431569315027446, 0.018753906661004294, 0.020576474780682474, 0.055606572423130274, 0.05924131859501358, 0.061469672655221075, 0.0216598712358973, 0.06204731958860066, 3.3280751667916775, 74.97264459729195, 118.5334387421608, 105.49721986055374, 100.9842324256897, 71.91951602697372, 73.49159806966782, 35.52892193198204, 37.460092306137085, 41.789336800575256, 51.32537730038166, 52.576433569192886, 43.350285440683365, 27.90671333670616, 7.9209433402866125, 0.08796910929959267, 0.04173570989223663, 0.03229642265068833, 0.16149167582625523, 0.04341921994637232, 0.5327472067438066, 1.0621104575693607, 3.0654833698645234, 1.6637508175335824, 3.9955715741962194, 1.0633978759869933, 0.8891490823589265, 5.597501490265131, 64.43889543414116, 89.37745124101639, 89.63519141077995, 83.10898080468178, 76.68753057718277, 67.17178478837013, 78.8497893512249, 77.691710293293, 84.43925902247429, 74.15186583995819, 76.90409615635872, 73.86853024363518, 72.63614237308502, 74.1460445523262, 75.68551674485207, 75.30213251709938, 76.50847658514977, 72.81422361731529, 74.92901533842087, 76.46702840924263, 74.79649364948273, 78.20395320653915, 77.27423429489136, 71.6588044166565, 68.23936030268669, 65.61575308442116, 64.55419644713402, 63.876882791519165, 68.01095455884933, 73.46219524741173, 81.32214188575745, 79.650459587574, 76.21469154953957, 54.152748584747314, 24.286016821861267, 69.51039969921112, 76.1013588309288, 68.75719651579857, 61.580369621515274, 69.25414144992828, 79.69509959220886, 78.94084006547928, 75.18811583518982, 78.20164293050766, 80.47665685415268, 79.85363468527794, 75.98641499876976, 68.64798277616501, 62.36935928463936, 60.10475680232048, 60.14939300715923, 68.12969818711281, 76.966762393713, 79.49665144085884, 79.2889241874218, 75.73274061083794, 72.00990557670593, 71.4852525293827, 80.1038284599781, 83.42953160405159, 82.60756731033325, 72.23838731646538, 79.19439285993576, 82.278922945261, 85.03950521349907, 93.9219617843628, 75.91108784079552, 9.069035109132528, 0.5274745146743953, 0.5542589211836457, 1.2748096254654229, 2.069164481945336, 0.9854880440980196, 0.4166814550990239, 0.03985367904533632, 0.04645736844395287, 0.1120555195666384, 0.2377815032377839, 5.2055957447737455, 17.94635720551014, 38.678025752305984, 35.13142146170139, 40.42575716972351, 34.636798202991486, 28.006049506366253, 30.579550713300705, 32.976142913103104, 57.085222229361534, 68.84016126394272, 74.26445379853249, 92.58837014436722, 39.66794863343239, 0.4679270490305498, 0.009992880241043167, 0.1137619990913663, 0.015652219190087635, 0.08425477892160416, 0.021535461310122628, 0.10889151395531371, 0.046810374697088264, 0.041649008489912376, 0.013779604341834784, 0.05274698465655092, 0.06625902620726265, 0.02771610797935864, 0.08071041520452127, 0.03268756787292659, 0.05001316123525612, 0.06446380808483809, 0.029292019607964903, 0.07504607696318999, 0.021186778067203704, 0.03402895155886654, 0.07246577792102471, 0.026206581460428424, 0.05643277945637237, 0.013783728827547748, 0.0755702261812985, 0.05690195408533327, 0.04262810907675885, 0.012053911541443085, 0.006909355442985543, 0.10336561594158411, 0.25264407915528864, 0.08931863063480705, 0.20114901970373467, 0.0858012588287238, 0.17836119717685506, 0.2974594384431839, 0.1544447461492382, 0.10341880566556938, 0.160972602898255, 0.1856021539424546, 0.08027110830880702, 0.15475530526600778, 0.12605543044628575, 0.08606311079347506, 0.13377725437749177, 0.0689420904382132, 0.20225769927492365, 0.17094023991376162, 0.2038682042621076, 0.12022620925563388, 0.14725168759468943, 0.3072131588123739, 0.11627055471763015, 0.14911959908204153, 0.1669709966517985, 4.989134659990668, 96.7795680463314, 131.55549198389053, 117.32089340686798, 111.92473456263542, 80.44560492038727, 66.77143827080727, 39.679264426231384, 52.93769158422947, 66.96802452206612, 83.77044171094894, 75.33329844474792, 58.32406595349312, 36.8404633551836, 11.185916718095541, 0.2410841642995365, 0.3293233411386609, 0.17820062610553578, 0.43838776065967977, 0.12444132604287006, 0.313550743740052, 0.40427399275358766, 2.4345483630895615, 8.73429587110877, 12.743670679628849, 17.647081464529037, 8.626403510570526, 6.289114728569984, 68.29172909259796, 89.38010349869728, 91.77281230688095, 85.62604174017906, 80.13317048549652, 68.46948355436325, 83.63439381122589, 81.30250453948975, 87.14089125394821, 73.46297040581703, 76.7914018034935, 75.69947719573975, 74.27296534180641, 74.82357859611511, 76.59677624702454, 75.82983300089836, 77.5960086286068, 77.45566695928574, 77.66433656215668, 79.29129526019096, 76.94484516978264, 81.03119909763336, 82.65627309679985, 76.70781388878822, 72.98852026462555, 69.94750544428825, 67.51095458865166, 68.50473046302795, 70.7931424677372, 77.3946650326252, 85.04515171051025, 82.15110540390015, 78.71465340256691, 59.54918101429939, 30.212513208389282, 71.40042588114738, 78.68585854768753, 71.23032420873642, 66.65635004639626, 74.32292506098747, 85.02035424113274, 81.41936346888542, 79.95477765798569, 80.21275341510773, 83.86966198682785, 84.35624867677689, 80.35345986485481, 71.06355115771294, 64.2690521478653, 64.16851714253426, 63.89062285423279, 71.5950134396553, 79.34121698141098, 82.82603278756142, 83.19751605391502, 78.87282371520996, 76.87139511108398, 75.33228009939194, 84.6949777007103, 86.10107704997063, 85.13940945267677, 71.467325091362, 79.2364414036274, 86.67777970433235, 86.28039702773094, 100.9947882592678, 75.82434609532356, 8.473399970680475, 5.13150779530406, 4.781064949929714, 2.572889202274382, 2.2117841290310025, 0.7104853412602097, 0.2973550034221262, 0.23899112973595038, 0.31791454239282757, 0.2875816903542727, 1.1478610499761999, 9.723925217986107, 29.54797636717558, 56.90381616353989, 54.58953134715557, 58.3046717941761, 57.93296433985233, 71.30380466580391, 52.183207869529724, 31.133959963917732, 58.287584111094475, 81.3138735294342, 82.7215763926506, 108.8670614361763, 43.53827655315399, 0.625771974446252, 0.20452003256650642, 0.27600394911132753, 0.10223089440842159, 0.2530266414396465, 0.16575277608353645, 0.1672287890687585, 0.1582592516206205, 0.14794388873269781, 0.113568855158519, 0.21424538805149496, 0.18927464203443378, 0.06553208513651043, 0.19505934178596362, 0.153715897758957, 0.1775414653820917, 0.10542232979787514, 0.13130950945196673, 0.1679650737787597, 0.16225736442720518, 0.12483835278544575, 0.16386444069212303, 0.16334670362994075, 0.178077919408679, 0.10221331292996183, 0.10735103060142137, 0.27118821220938116, 0.11395701323635876, 0.10785585429403, 0.18497600394766778, 0.13152747822459787], [0.034585499233799055, 0.03672161175927613, 0.009447337688470725, 0.032682992532500066, 0.021724013204220682, 0.024955552398751024, 0.026030787084891926, 0.03992144454969093, 0.04633852091501467, 0.02603056258521974, 0.0350840109604178, 0.031757482429384254, 0.01691611894784728, 0.049474688566988334, 0.008832982275635004, 0.028057531162630767, 0.04919200080621522, 0.09210094227455556, 0.051704519501072355, 0.0063883315942803165, 0.04419319833687041, 0.09507350347121246, 0.026593730217427947, 0.09246634610462934, 0.7255207188427448, 59.57967057824135, 109.54825088381767, 90.24659380316734, 79.90991726517677, 59.493213817477226, 41.08393885195255, 28.51660531014204, 49.87451255321503, 56.61011092364788, 51.75645276904106, 41.421812921762466, 36.584360897541046, 27.290912680327892, 6.703140987083316, 0.5430385388899595, 0.1260623917914927, 0.10886329007917084, 0.15832741046324372, 0.049865818946273066, 0.041456903563812375, 0.32216651423368603, 1.6553928097710013, 3.76001485157758, 3.2396092638373375, 1.4170948904938996, 1.8786034011282027, 3.4328654687851667, 64.44610744714737, 85.44561982154846, 82.39634424448013, 74.73844796419144, 68.53513643145561, 61.67273126542568, 73.25203612446785, 74.69761535525322, 78.68916437029839, 74.4473759829998, 70.37823513150215, 72.48375535011292, 72.57225260138512, 74.04864057898521, 78.74797761440277, 72.22581759095192, 79.12585973739624, 75.07599145174026, 77.20907539129257, 72.32599541544914, 73.20536702871323, 74.32724922895432, 76.82293251156807, 71.00146248936653, 76.21862053871155, 70.36305114626884, 64.36734527349472, 56.36288478970528, 59.63134780526161, 61.453053653240204, 73.28172013163567, 68.30950453877449, 75.05566254258156, 67.71335452795029, 45.781634375452995, 18.519220165908337, 65.24626851081848, 76.09155535697937, 68.05224314332008, 59.779410660266876, 63.57972353696823, 76.05581447482109, 72.80990704894066, 71.87334090471268, 75.75396627187729, 71.84426486492157, 65.51086351275444, 63.84383216500282, 61.1998238414526, 56.04652896523476, 57.89452560245991, 66.15441218018532, 73.13911378383636, 76.9821135699749, 76.8753544986248, 77.02299177646637, 76.45502865314484, 71.92649245262146, 72.59094759821892, 74.0323394536972, 79.2872066795826, 71.44492149353027, 74.68283414840698, 81.60827413201332, 79.5630718767643, 77.29324847459793, 76.7667943239212, 82.44591638445854, 69.15935173630714, 2.405237448401749, 0.9633052500430495, 1.1919407034292817, 0.9266213653609157, 0.31644633680116385, 0.061842772556701675, 0.03275419046985917, 0.03554178991180379, 0.06967401874135248, 0.03421396526391618, 0.16833255562232807, 0.5649697151966393, 6.9617850333452225, 37.598933055996895, 52.66287513077259, 63.48404847085476, 146.02310925722122, 109.58927348256111, 32.190124690532684, 25.08881874382496, 48.435867950320244, 64.60412576794624, 68.77190932631493, 67.6373054087162, 13.434146828949451, 0.18751202645944431, 0.029116922851244453, 0.08372113021323457, 0.06522419032990001, 0.08446349311270751, 0.01637436042074114, 0.04400210644234903, 0.025396304627065547, 0.005318052135407925, 0.058905667465296574, 0.03194331991835497, 0.013866431909264065, 0.09200029220664874, 0.06851010854006745, 0.059397314325906336, 0.02291453867655946, 0.05452112578495871, 0.0520269937987905, 0.05515781056601554, 0.05464334266434889, 0.017569676456332672, 0.03191172669176012, 0.005193725701246876, 0.02748741888353834, 0.06699203062453307, 0.04847585427341983, 0.011122387259092648, 0.08851691818563268, 0.020499172678682953, 0.017317329547950067, 0.11557241639820859, 0.023427989835909102, 0.04221106290060561, 0.002168327996514563, 0.017688097250356805, 0.03771692456211895, 0.04457394978089724, 0.06016619416186586, 0.04374495969386771, 0.028996015862503555, 0.08656467645778321, 0.030313431889226194, 0.07067890895996243, 0.11037676667911, 0.020264277372916695, 0.04068209767865483, 0.01509020466983202, 0.046641762455692515, 0.015242309691529954, 0.01948591660038801, 0.03774235425225925, 0.09788112234673463, 0.05414538383774925, 0.05909175357373897, 1.1418346920982003, 69.82871621847153, 122.04567387700081, 101.03524088859558, 88.60309079289436, 84.80543777346611, 67.77320131659508, 33.99790808558464, 53.805660009384155, 40.045306384563446, 57.808505818247795, 47.91043974459171, 44.243511110544205, 33.042232766747475, 7.983919735997915, 0.6184089789167047, 0.03525100531987846, 0.19031724077649415, 0.1503037550719455, 0.340455318801105, 0.5427951738238335, 1.9433256844058633, 3.6357437074184418, 4.236896149814129, 5.102004278451204, 2.0523209357634187, 1.4688611752353609, 4.127205535769463, 66.77659839391708, 90.07241874933243, 85.93587711453438, 79.28535997867584, 71.15712493658066, 64.7504635155201, 77.4189305305481, 79.53668609261513, 82.70280539989471, 75.69207519292831, 71.10923990607262, 73.65815833210945, 74.71539840102196, 73.90682458877563, 78.40300172567368, 74.79841634631157, 80.6359975039959, 77.93412208557129, 80.03236949443817, 73.50557371973991, 76.19864881038666, 75.42055696249008, 78.07638645172119, 71.17750704288483, 78.18021968007088, 73.2393904030323, 68.59567478299141, 59.48338374495506, 61.10297463834286, 63.586141392588615, 76.92846804857254, 73.88503655791283, 77.36452504992485, 69.64696437120438, 50.3107101470232, 21.13541968166828, 63.7092699855566, 81.47746995091438, 70.34350499510765, 62.01726257801056, 66.65713280439377, 79.34108018875122, 74.8841093480587, 75.3302738070488, 79.46858614683151, 72.93555870652199, 67.81324356794357, 64.74064484238625, 61.47082529962063, 57.48628690838814, 60.104050040245056, 67.84064009785652, 77.74379029870033, 79.41108763217926, 80.1627404987812, 78.56452345848083, 80.20631656050682, 74.57764059305191, 76.45650297403336, 75.96148833632469, 82.33426317572594, 72.5720702111721, 75.80789297819138, 84.83609452843666, 84.61578235030174, 81.08941197395325, 80.12066915631294, 84.22618925571442, 76.14675119519234, 2.9993880540132523, 1.190221889410168, 1.3423863868229091, 1.9326015911065042, 1.534952928777784, 0.881026602583006, 0.46640950546134263, 0.10066531904158182, 0.03699998022057116, 0.008913350375223672, 0.2050578224589117, 0.14235383947379887, 7.396398587152362, 36.33328177034855, 42.813932821154594, 38.31639915704727, 125.35971164703369, 102.61066675186157, 35.20149350166321, 42.77399316430092, 59.02883693575859, 74.41930308938026, 76.35428085923195, 83.51284593343735, 26.38490829616785, 0.14988190348958597, 0.06217526213731617, 0.03974392653617542, 0.028210146410856396, 0.09273427625885233, 0.04883605564828031, 0.05477583828906063, 0.048792569505167194, 0.04085897744516842, 0.03339774382766336, 0.05123413146066014, 0.04850119861657731, 0.04692989015893545, 0.08063220768235624, 0.0640902628947515, 0.04158437113801483, 0.05778971113613807, 0.07614812915562652, 0.035330207319930196, 0.04375985088699963, 0.02826058647769969, 0.004745335381812765, 0.03954946900194045, 0.09780356049304828, 0.04639178114302922, 0.057768133192439564, 0.02344876811548602, 0.044625117152463645, 0.02744011810136726, 0.03239793732063845, 0.18126306880731136, 0.10620124347042292, 0.2410455429344438, 0.11927615632885136, 0.07797146725351922, 0.13302870938787237, 0.14367946365382522, 0.14237887953640893, 0.18839629541616887, 0.04765761048474815, 0.16515833063749596, 0.1019800039648544, 0.11133667532703839, 0.18633679108461365, 0.09845115113421343, 0.17138775496277958, 0.1343783939955756, 0.24922114564105868, 0.15995422785636038, 0.17108227213611826, 0.12211591019877233, 0.19751368352444842, 0.18480676459148526, 0.1515855034813285, 1.9757124152965844, 87.39457324147224, 135.03849148750305, 113.48191380500793, 101.68717190623283, 80.93846127390862, 64.40021350979805, 42.840652987360954, 66.63901537656784, 76.53153374791145, 72.37190455198288, 61.56668655574322, 59.0063801407814, 45.21362945437431, 12.355925235897303, 1.338926434982568, 0.2752548549324274, 0.35703172150533646, 0.3141139744548127, 0.2719343377975747, 0.35841505508869886, 1.6147459158673882, 4.214226566255093, 12.971009630709887, 11.86670433729887, 4.043378233909607, 9.86558636650443, 4.2085054982453585, 74.88681480288506, 92.04061433672905, 90.6820960342884, 80.75431555509567, 73.9281414449215, 67.67359346151352, 80.6018753349781, 80.4120147228241, 84.96477082371712, 76.53916373848915, 71.04189231991768, 76.20519205927849, 75.9130409359932, 78.01666885614395, 83.03146496415138, 76.33862569928169, 82.86465391516685, 80.53005158901215, 85.01391738653183, 77.72297501564026, 79.52743738889694, 79.53876838088036, 82.09358409047127, 73.75661864876747, 81.99129357933998, 77.4244250357151, 72.95582681894302, 63.64301294088364, 65.97434744238853, 68.31919401884079, 81.43518581986427, 78.18661853671074, 82.67053753137589, 72.98647597432137, 60.92574454843998, 27.18282178044319, 71.21468424797058, 85.94933599233627, 73.62808674573898, 66.0463535785675, 69.77402195334435, 83.7905502319336, 78.20940211415291, 77.7750626206398, 84.30071085691452, 77.45665490627289, 70.27270719408989, 69.31431502103806, 64.41571667790413, 59.47923056781292, 65.22961780428886, 71.6559773683548, 81.8841165304184, 81.08416825532913, 82.5060823559761, 81.90506860613823, 84.0509806573391, 77.95005843043327, 80.37443473935127, 79.0734301507473, 84.03170049190521, 74.76338982582092, 75.585126131773, 88.95203366875648, 87.60457277297974, 85.02398684620857, 83.52356135845184, 88.36542874574661, 79.33286502957344, 2.0323245087638497, 4.913301654160023, 4.240692621096969, 3.627911852672696, 0.9311850392259657, 0.7599276944529265, 0.3747626388212666, 0.16961054876446724, 0.2126484940527007, 0.16507391876075417, 0.32375658047385514, 0.8589670644141734, 12.428436744958162, 58.83702702820301, 74.42475199699402, 78.21220636367798, 156.30091935396194, 118.25943544507027, 46.45117744803429, 41.5204556286335, 64.22440454363823, 88.80156174302101, 85.7300877571106, 96.50760903954506, 27.884953804314137, 0.4352702060714364, 0.13664188503753394, 0.19895190634997562, 0.17986471415497363, 0.1846135687083006, 0.15510377328610048, 0.11396896923542954, 0.18536610645242035, 0.12736638978822157, 0.18820876954123378, 0.24490876297932118, 0.1174051129783038, 0.1949082998908125, 0.2780062041711062, 0.13899375102482736, 0.13390243984758854, 0.17636476055486128, 0.15191362181212753, 0.21193284104811028, 0.15632751543307677, 0.09019800141686574, 0.09710792321129702, 0.08644286775961518, 0.14181685110088438, 0.17462804593378678, 0.2618398825870827, 0.09339288037153892, 0.17404501471901312, 0.12386253249133006, 0.05446986193419434], [0.0356405400816584, 0.006400276461135945, 0.013720065544475801, 0.06572005630005151, 0.003359308266226435, 0.015971383509167936, 0.06195816909894347, 0.029588093857455533, 0.04242648610670585, 0.09777247934835032, 0.02460113235429162, 0.04217367350065615, 0.01684405084233731, 0.032845704699866474, 0.07985533491591923, 0.04757929535117, 0.060922290504095145, 0.03117315616691485, 0.12410904426360503, 0.012863096490036696, 0.06322639557765797, 0.1001866115257144, 0.19471713749226183, 0.2661201450973749, 21.628477424383163, 100.12170150876045, 94.71861943602562, 82.30797618627548, 74.27474364638329, 31.89450815320015, 44.16995465755463, 93.4761469066143, 38.80505293607712, 58.48695941269398, 45.32889246940613, 40.6555612385273, 23.908242993056774, 3.721659234724939, 0.09062490702490322, 0.06946039153262973, 0.006629041163250804, 0.02704679838643642, 0.01897617803479079, 0.15376073832158, 0.35771170689258724, 1.8988371966406703, 4.187297886237502, 4.864480923861265, 1.6486461530439556, 0.5022066424135119, 4.660842726007104, 64.48433339595795, 88.40470343828201, 78.89581248164177, 77.77155920863152, 66.10734030604362, 62.434810772538185, 72.59816721081734, 76.97831377387047, 79.35411348938942, 73.52397993206978, 76.64906144142151, 69.37886595726013, 75.47137543559074, 73.12895312905312, 68.82500007748604, 71.18505343794823, 70.69841355085373, 71.05199977755547, 69.96626123785973, 71.4980274438858, 67.09844872355461, 69.73388090729713, 71.06086850166321, 74.67992350459099, 70.90964421629906, 75.17175391316414, 70.9584791958332, 62.97715187072754, 57.33163520693779, 56.166442930698395, 54.69404473900795, 67.10886016488075, 69.59583431482315, 78.08884218335152, 61.5320248156786, 57.7195829898119, 21.619525104761124, 40.67282751202583, 69.71133291721344, 68.23717921972275, 64.3040482699871, 57.95658007264137, 71.61664187908173, 75.1639187335968, 74.67799320816994, 68.46534177660942, 63.68359476327896, 57.912342846393585, 58.662715181708336, 55.24265930056572, 61.22060872614384, 63.87325018644333, 73.6500495672226, 76.46619245409966, 76.94912374019623, 70.0601314008236, 71.22029274702072, 76.59449636936188, 74.74348649382591, 75.72045966982841, 74.62997138500214, 74.02992278337479, 68.95701259374619, 74.06001716852188, 80.46010494232178, 75.27826979756355, 72.6501028239727, 78.26974287629128, 76.87135711312294, 81.59099265933037, 47.89452999830246, 0.36130316730123013, 0.3924369451124221, 1.8441683426499367, 1.0234418325126171, 0.6282760400790721, 0.03891895888955332, 0.06794315224396996, 0.070673647132935, 0.09221533691743389, 0.09803010107134469, 0.0337954236601945, 0.07500336636439897, 1.6077927639707923, 25.40726825594902, 57.74288333952427, 83.51694971323013, 122.83714100718498, 67.87465587258339, 13.765406403690577, 39.62710082530975, 60.89201755821705, 64.09382075071335, 68.4366837143898, 69.25343468785286, 6.483760233968496, 0.3408324782503769, 0.03955725784180686, 0.07398318048217334, 0.07491940719773993, 0.08373879332793877, 0.033225576698896475, 0.02624694687256124, 0.024362615367863327, 0.03265047162130941, 0.056282976947841235, 0.044984134801779874, 0.0077529941336251795, 0.026984352225554176, 0.028308484688750468, 0.01810685222153552, 0.03401350746571552, 0.04141343597439118, 0.01473340233133058, 0.046053562182351016, 0.03606377576943487, 0.0075321615986467805, 0.08614203077740967, 0.021097545941302087, 0.02786725748592289, 0.029597888351418078, 0.07164013863075525, 0.03256501702708192, 0.04345872446720023, 0.04736927126941737, 0.041622866338002495, 0.079430010082433, 0.03507680841721594, 0.07891072193160653, 0.02723693662119331, 0.02695400580705609, 0.049197206972166896, 0.024412923703494016, 0.045116830806364305, 0.021535170017159544, 0.052178904006723315, 0.050976739803445525, 0.0223893170550582, 0.040746542072156444, 0.04964240280969534, 0.019545447976270225, 0.039525545871583745, 0.06856268970295787, 0.1908580437884666, 0.03498343881801702, 0.03085159471083898, 0.10916543324128725, 0.17992312117712572, 0.15830524993361905, 28.419984094798565, 118.34885224699974, 103.85636150836945, 95.32929226756096, 87.84553304314613, 40.9753330796957, 43.95251892507076, 70.8344766497612, 30.32181054353714, 54.184203296899796, 43.26643534004688, 43.30594941973686, 30.262208841741085, 4.764001490548253, 0.08730847170227207, 0.09423089868505485, 0.08906694609322585, 0.06735281087458134, 0.22499058803077787, 0.7730266603175551, 1.4564357232302427, 3.3782692858949304, 3.8595657097175717, 5.668828887864947, 1.5977506153285503, 0.29887857323046774, 6.195287788286805, 67.72136449813843, 89.62779700756073, 83.60818281769753, 82.67259702086449, 70.47407358884811, 64.0039099752903, 76.1938002705574, 80.39401888847351, 80.51644071936607, 78.59720930457115, 75.40285751223564, 69.52876791357994, 75.59335649013519, 74.81246799230576, 72.48800352215767, 73.92057985067368, 74.46233198046684, 74.34282839298248, 73.27491849660873, 75.36710903048515, 69.57834005355835, 70.91437116265297, 73.52981641888618, 75.96225589513779, 72.2495511174202, 76.91353484988213, 72.56696328520775, 64.20048102736473, 60.012243166565895, 58.03690396249294, 59.64565023779869, 68.74498397111893, 73.37631225585938, 79.25012066960335, 66.64938881993294, 66.71036794781685, 24.430181086063385, 45.82716353237629, 74.80653271079063, 71.8235331773758, 67.25259125232697, 59.63625334203243, 74.44919988512993, 77.45087161660194, 76.66556775569916, 73.81861612200737, 66.34200811386108, 59.22103062272072, 59.93049055337906, 56.650392562150955, 62.84172713756561, 66.33031234145164, 77.1109114587307, 78.63287419080734, 78.05549517273903, 71.08477681875229, 72.5919583439827, 77.170849442482, 76.66667729616165, 77.94261083006859, 77.57313385605812, 75.50514802336693, 69.56282168626785, 75.53390488028526, 81.21279895305634, 77.4717628955841, 76.09580352902412, 82.5305150449276, 80.34054815769196, 85.5085064470768, 54.307274892926216, 0.7178165134973824, 0.5167609301861376, 1.4084872836247087, 2.726637264713645, 1.3026874233037233, 0.9783157508354634, 0.19047709938604385, 0.14057880034670234, 0.18135503574740142, 0.08084282177151181, 0.037396439220174216, 0.09441561924177222, 2.365069566294551, 26.373113729059696, 53.39540742337704, 82.76278898119926, 131.18376553058624, 68.23614567518234, 23.308895453810692, 53.40110331773758, 67.78013214468956, 71.37499764561653, 74.92531433701515, 84.75656479597092, 12.923309840261936, 0.2468930877512321, 0.05138203407113906, 0.0714124996738974, 0.05677708402799908, 0.0005665245168984256, 0.03154304256895557, 0.05514729433343746, 0.02785935917927418, 0.04468609571631532, 0.00615853066847194, 0.060615898546529934, 0.1060222003434319, 0.027104196087748278, 0.04016211190901231, 0.035779941390501335, 0.03819041477981955, 0.061436313117155805, 0.04251909129379783, 0.08455531162326224, 0.0365082220378099, 0.06980062913498841, 0.039364139884128235, 0.03308420498797204, 0.05028131774452049, 0.005326223181327805, 0.07546847031335346, 0.005494648030435201, 0.04298836982343346, 0.033079317945521325, 0.17287929367739707, 0.18964893679367378, 0.1681279158219695, 0.14052771090064198, 0.15333631890825927, 0.2008729852968827, 0.2066414023283869, 0.07890859196777456, 0.11329394139465876, 0.1931099870125763, 0.15751141909277067, 0.16401267726905644, 0.08500390278641135, 0.1462110481224954, 0.18580530944745988, 0.09852296876488253, 0.15472063212655485, 0.17943487706361338, 0.24702912342036143, 0.12514034751802683, 0.16932937869569287, 0.2013483308837749, 0.36587732029147446, 0.43279276869725436, 38.535206615924835, 132.00794130563736, 116.86524465680122, 107.11115285754204, 95.90645849704742, 48.22633199393749, 58.62011946737766, 110.26417046785355, 51.46871320903301, 80.03230109810829, 63.92761006951332, 65.42611286044121, 38.58098275959492, 7.458988353610039, 0.24260875827167183, 0.17006144800689071, 0.17763120587915182, 0.27573490573558956, 0.363108545425348, 0.6621147086843848, 1.8945459206588566, 5.621263515204191, 14.686938654631376, 15.207657013088465, 6.493971236050129, 2.6679441891610622, 7.055601999163628, 71.85399234294891, 90.33465787768364, 87.8214879333973, 83.18673983216286, 73.52758973836899, 67.7601908147335, 80.71282178163528, 82.75946035981178, 84.20416563749313, 81.3205535709858, 77.76223450899124, 69.7883927822113, 77.9350720345974, 79.70925763249397, 74.78973761200905, 76.96803912520409, 79.6550877392292, 77.93073266744614, 76.62526711821556, 78.64110454916954, 72.41149082779884, 74.38363060355186, 77.02106148004532, 79.86477568745613, 75.90990990400314, 79.83237102627754, 77.50453993678093, 68.85225221514702, 65.83503171801567, 60.20787946879864, 62.489478439092636, 72.94722408056259, 77.10102438926697, 82.6450788974762, 68.78783047199249, 65.78357487916946, 29.143799655139446, 51.30760945379734, 80.82179993391037, 75.30164614319801, 73.02160888910294, 61.08744107186794, 79.58590865135193, 80.79751923680305, 81.45657867193222, 76.04490906000137, 70.2272616326809, 63.4510662406683, 62.6382290571928, 59.6053571999073, 67.1053871512413, 70.22850036621094, 80.27424931526184, 81.05050966143608, 79.15003404021263, 69.92389351129532, 74.65053588151932, 81.11247673630714, 80.72992846369743, 82.49320104718208, 79.97424781322479, 76.45460307598114, 69.69999432563782, 77.05136105418205, 86.34042620658875, 81.22086971998215, 79.23165366053581, 85.40367007255554, 83.85691747069359, 89.4462351500988, 54.52393926680088, 1.058230153284967, 4.987797606736422, 5.400534784421325, 5.2786211762577295, 1.4059404702857137, 0.6719961378257722, 0.2551623643375933, 0.22308865649392828, 0.20649999351007864, 0.5282877304125577, 0.2659407234750688, 0.1793639425886795, 4.1758799739181995, 43.71644139289856, 80.01774787902832, 85.44173642992973, 128.12982380390167, 81.95685222744942, 23.274408504366875, 56.10169820487499, 78.99338364601135, 85.98613321781158, 84.42453861236572, 96.73502683639526, 14.725555032491684, 0.4169032088248059, 0.17932587041286752, 0.17753585474565625, 0.19940097990911454, 0.17263714573346078, 0.15471888065803796, 0.14658635220257565, 0.11674319888697937, 0.281395266065374, 0.07053035325952806, 0.11738465196685866, 0.18814755720086396, 0.0976836888003163, 0.09757348729181103, 0.1033907376404386, 0.1435418546316214, 0.14909555349731818, 0.14063319977140054, 0.2147273239097558, 0.10162364691495895, 0.08356348320376128, 0.14199889992596582, 0.2082824392709881, 0.17074962670449167, 0.08888316806405783, 0.13818718492984772, 0.08371573479962535, 0.1418373195338063, 0.13494312384864315], [0.07948871396365575, 0.018849250373023096, 0.06736759445630014, 0.03537718155712355, 0.057015209531527944, 0.019193361986253876, 0.010410688973934157, 0.02977285152155673, 0.04333876000600867, 0.06184565580042545, 0.028395536755851936, 0.00867609875058406, 0.055270516822929494, 0.033428962269681506, 0.026711661193985492, 0.04883981462626252, 0.04971436515916139, 0.035316585199325345, 0.04213279600662645, 0.01774154487065971, 0.059325095935491845, 0.0462858395621879, 0.07438992193783633, 2.883239211514592, 73.91755521297455, 96.59774020314217, 87.82717242836952, 81.54763698577881, 40.01942977309227, 54.10769820213318, 181.88021957874298, 96.43086075782776, 62.276598662137985, 46.7205373942852, 48.07521790266037, 28.120109885931015, 1.1003418685868382, 0.013512774421542417, 0.06649577131611295, 0.18385292671155185, 0.16364154405891895, 0.14075069659156725, 0.3987532155588269, 1.5627400064840913, 1.2890465115197003, 2.8732642717659473, 1.5115335979498923, 1.0277608945034444, 2.2737272176891565, 12.514334935694933, 70.39021968841553, 88.02642613649368, 75.92253282666206, 78.79872769117355, 67.04821541905403, 58.79703037440777, 71.05422645807266, 77.4022114276886, 77.20216736197472, 70.32919496297836, 77.4606142938137, 69.41463723778725, 73.33000034093857, 72.03038647770882, 69.13153722882271, 67.04687789082527, 66.82510659098625, 66.39626920223236, 65.43926775455475, 64.46947619318962, 63.18500831723213, 61.653481498360634, 61.68420284986496, 67.3024369776249, 72.1675743162632, 70.66942110657692, 73.24888229370117, 68.2261674106121, 60.164212211966515, 53.56587007641792, 53.43631222844124, 55.170246586203575, 68.31999197602272, 66.08660101890564, 76.70288935303688, 65.71401581168175, 79.41768407821655, 25.562328435480595, 40.619584769010544, 81.81524142622948, 62.67242342233658, 67.1270763874054, 56.182934045791626, 71.3830304145813, 73.99534463882446, 75.39464995265007, 69.41144540905952, 61.639376655220985, 51.343209743499756, 54.000445157289505, 53.2561980932951, 59.13605958223343, 67.15466290712357, 76.3587874174118, 75.19228801131248, 70.80593258142471, 64.24782648682594, 70.74827447533607, 67.56966903805733, 71.84675753116608, 71.70139253139496, 73.44618290662766, 70.26697710156441, 70.27910605072975, 74.02823567390442, 78.18723410367966, 73.92070144414902, 68.14867436885834, 62.49213829636574, 79.42343696951866, 74.70730483531952, 83.23816627264023, 23.236070461571217, 1.240883027203381, 1.7354542762041092, 2.983531029894948, 0.3692596731707454, 0.33631547063123435, 0.21891471405979246, 0.06841428985353559, 0.05757177576015238, 0.016634987841825932, 0.0310789516515797, 0.09396925452165306, 0.04191525396890938, 2.3377302708104253, 17.396374717354774, 37.47059494256973, 42.64916606247425, 38.2361626625061, 37.77144379913807, 24.102752655744553, 41.37073986232281, 62.006661146879196, 62.67811171710491, 71.12771451473236, 51.37792468070984, 1.5674835769459605, 0.06927828333573416, 0.06544569914694875, 0.06854773542727344, 0.10203872268903069, 0.05853378097526729, 0.02246108644612832, 0.08614957841928117, 0.0382759435888147, 0.07323160753003322, 0.014294160373538034, 0.0017991814229390002, 0.012920121262141038, 0.07555859672720544, 0.018296550733793993, 0.033323833340546116, 0.10996590630384162, 0.038124827478895895, 0.03365297212440055, 0.047400756884599105, 0.01028998978654272, 0.009526275298412656, 0.06183508019603323, 0.0032315695762008545, 0.0692579113820102, 0.028556521574500948, 0.028006460270262323, 0.1300327928038314, 0.028563358609972056, 0.003165603084198665, 0.013018210920563433, 0.08701311176992022, 0.06474411726230755, 0.05548349836317357, 0.03731835044163745, 0.04231266662827693, 0.051385344049776904, 0.027767900610342622, 0.020917870133416727, 0.07527073248638771, 0.0153749361197697, 0.052929912926629186, 0.0123328588779259, 0.027069363386544865, 0.02933459290943574, 0.033077792832045816, 0.039555324547109194, 0.015659284435969312, 0.04721202130895108, 0.05424749222584069, 0.02262089681607904, 0.061467238410841674, 3.8927999138832092, 93.94824877381325, 108.44151467084885, 101.3907878100872, 88.93574014306068, 53.772301599383354, 62.58844792842865, 154.04668271541595, 90.79919815063477, 50.79758942127228, 43.231158033013344, 50.264432430267334, 33.61723691225052, 2.2473210096359253, 0.13665206730365753, 0.044395912264008075, 0.059175234055146575, 0.08136101154377684, 0.7199567486532032, 0.7647081941831857, 1.7698843474499881, 2.3123143846169114, 3.584438622929156, 2.247119857929647, 0.6427131872624159, 2.0069463830441236, 15.62473688274622, 72.14966967701912, 93.17261159420013, 79.08899411559105, 82.96486213803291, 70.42127922177315, 62.04114429652691, 73.96626099944115, 79.1381786763668, 78.22983741760254, 78.72417569160461, 78.31565961241722, 70.66849395632744, 74.62858065962791, 75.2075707912445, 73.48587557673454, 72.19791948795319, 71.12203761935234, 70.59065893292427, 68.1331180036068, 68.0303031206131, 66.35615855455399, 64.4101157784462, 65.17617747187614, 71.26037299633026, 74.84016850590706, 72.11126893758774, 73.48792746663094, 69.01544585824013, 64.35503393411636, 56.78878493607044, 58.398530557751656, 58.67691121995449, 71.74030244350433, 68.73070433735847, 80.31936049461365, 66.6118012368679, 79.16994497179985, 27.360435649752617, 45.31910039484501, 83.82592633366585, 64.23393443226814, 68.85577082633972, 59.26798090338707, 76.34665086865425, 76.59045338630676, 77.17812225222588, 70.96776589751244, 63.374754935503006, 54.0101308375597, 57.4203946441412, 55.07270582020283, 63.1207537651062, 68.93210873007774, 78.7839312851429, 76.64960101246834, 73.2920403778553, 65.1282924413681, 71.74192875623703, 69.76331412792206, 73.56114193797112, 73.95634353160858, 75.46872317790985, 70.22071838378906, 71.92106634378433, 75.57264760136604, 82.88280934095383, 76.50753423571587, 72.55256965756416, 66.23598620295525, 80.4051598906517, 77.30422988533974, 88.68443682789803, 26.81629154831171, 0.9114228340331465, 1.2769701657816768, 1.2158030667342246, 2.0357649866491556, 1.324197594076395, 0.7374055311083794, 0.3774072078522295, 0.25833997351583093, 0.10751502297353, 0.14110582909779623, 0.12693796277744696, 0.1227182149887085, 2.4476624093949795, 21.44383203238249, 43.691465333104134, 51.416887789964676, 36.00035883486271, 30.901516936719418, 36.4806492626667, 53.58141504228115, 69.6237476170063, 71.973085552454, 77.34514608979225, 67.99829363822937, 3.791185528971255, 0.08666822832310572, 0.03733729005034547, 0.03235505231714342, 0.0230875574197853, 0.053975513656041585, 0.03280587734479923, 0.12485015293350443, 0.03957308414101135, 0.07229677605209872, 0.019439124189375434, 0.06283119451836683, 0.059334677061997354, 0.060745852315449156, 0.05141673318576068, 0.03545464693161193, 0.11719593123416416, 0.059574476108537056, 0.053149295490584336, 0.1434806126053445, 0.03850654742564075, 0.010596659121802077, 0.09151163991191424, 0.005646122690450284, 0.048928363976301625, 0.03404798022529576, 0.03800736405537464, 0.046826475590933114, 0.0109022514152457, 0.14976128964917734, 0.12857102905400097, 0.11187494019395672, 0.10644338399288245, 0.1601615542313084, 0.06455375638324767, 0.1631575747160241, 0.1481205050367862, 0.15901751874480397, 0.14005920791532844, 0.1939412220963277, 0.12860699353041127, 0.11753610204323195, 0.15999623341485858, 0.17177301866468042, 0.13192268670536578, 0.18299528601346537, 0.12212887551868334, 0.08070704585406929, 0.18259828153531998, 0.16026359953684732, 0.23590452270582318, 0.27844080585055053, 5.866978280246258, 111.32011860609055, 120.97047597169876, 112.87349045276642, 103.46240624785423, 59.36992183327675, 68.88862386345863, 188.5852637887001, 99.60635036230087, 78.09433668851852, 68.12818586826324, 75.7071527838707, 43.30479808151722, 3.4350363397970796, 0.44090058363508433, 0.2487382449908182, 0.370731886359863, 0.6952666828874499, 0.605104883434251, 1.2306508887559175, 4.916086904704571, 5.238755140453577, 9.00934411212802, 7.169558359310031, 5.353376939892769, 8.256955984979868, 16.6128396615386, 80.5588236451149, 94.70360264182091, 79.83952224254608, 83.89521181583405, 72.91705369949341, 64.73161652684212, 77.12705299258232, 82.34119400382042, 81.16146370768547, 81.61747723817825, 81.33794903755188, 67.99546658992767, 76.26057028770447, 78.68654251098633, 77.49016910791397, 75.7450519502163, 74.94770273566246, 74.80098500847816, 73.47825318574905, 71.43519401550293, 71.03885248303413, 69.04327556490898, 69.01364475488663, 76.736950725317, 79.35090646147728, 77.15420633554459, 75.83186969161034, 71.60532608628273, 68.0431692302227, 59.16232377290726, 59.191468209028244, 61.46705210208893, 76.91324606537819, 73.71958583593369, 81.63842171430588, 69.26992580294609, 79.12079080939293, 31.30366835743189, 47.467584908008575, 84.71838444471359, 69.63504821062088, 72.78510957956314, 64.08848583698273, 79.94918435811996, 78.28137025237083, 79.42041993141174, 76.4156399667263, 65.91469064354897, 57.010199055075645, 60.59901148080826, 57.022863775491714, 64.57586288452148, 73.40826854109764, 82.77369439601898, 79.29137885570526, 74.28472951054573, 65.02279490232468, 71.97512984275818, 72.09440544247627, 74.95484635233879, 75.89971125125885, 77.7731703221798, 73.2634811103344, 71.18790328502655, 79.21490415930748, 86.45715594291687, 81.41408935189247, 74.41358059644699, 69.51302915811539, 84.75447490811348, 81.15799829363823, 90.86783766746521, 27.27537151426077, 2.5207419879734516, 7.894769394770265, 9.500258769840002, 4.295422984287143, 2.532741744071245, 0.5503499403130263, 0.450158400926739, 0.36014134995639324, 0.11519798805238679, 0.23767834471073002, 0.4410842800280079, 0.17652718699537218, 4.951868634670973, 31.91140964627266, 57.425957545638084, 52.00583338737488, 53.698384165763855, 52.36471652984619, 35.48499248921871, 61.88839249312878, 81.59524843096733, 85.92212185263634, 88.21592956781387, 78.01832556724548, 3.8617244688794017, 0.28393471729941666, 0.161048999580089, 0.14131766773061827, 0.2652424812549725, 0.18322273943340406, 0.10087010727147572, 0.23727164778392762, 0.12233618705067784, 0.15731958876131102, 0.07489711308153346, 0.11861563005368225, 0.12388441842631437, 0.2581298863515258, 0.2243191670277156, 0.13877726654754952, 0.24460381449898705, 0.15213650360237807, 0.14333074330352247, 0.16942560556344688, 0.1559463335433975, 0.1377975128707476, 0.21937408862868324, 0.23095257201930508, 0.32264258712530136, 0.12438474470400251, 0.1624142099171877, 0.17112291214289144, 0.10231271618977189], [0.10517059330595657, 0.0189758885971969, 0.06275477557210252, 0.04617648781277239, 0.06662397732725367, 0.03587706996768247, 0.06795766865252517, 0.07697891152929515, 0.009555210708640516, 0.06233440828509629, 0.03869490450597368, 0.04308476367441472, 0.01837170246290043, 0.03462439519353211, 0.07521837396780029, 0.07085089426254854, 0.04034433884953614, 0.053113650137674995, 0.09624655693187378, 0.04508371617703233, 0.03758581675356254, 0.15747440076665953, 0.034396941773593426, 40.82357682287693, 107.37997323274612, 87.71830067038536, 78.45179110765457, 51.96173295378685, 41.04113794863224, 45.67800633609295, 88.77098858356476, 77.04367026686668, 54.766012877225876, 48.01798537373543, 21.57798383384943, 0.6957518099807203, 0.08342444925801829, 0.04047275266202632, 0.1042325037997216, 0.1538717042421922, 0.11138060304801911, 0.262927069561556, 0.589194365311414, 1.054668438155204, 1.140527087263763, 0.9528911369852722, 1.94999978877604, 3.232397250831127, 30.385514125227928, 70.12242525815964, 82.92899206280708, 76.95293873548508, 76.27052575349808, 70.97392916679382, 61.26046098768711, 61.409724578261375, 74.30350050330162, 76.17010474205017, 70.53096413612366, 78.70570108294487, 73.3035309612751, 67.56639361381531, 74.16932210326195, 66.54372408986092, 68.34205359220505, 62.03533820807934, 61.61586731672287, 59.521271511912346, 60.06542891263962, 57.519975900650024, 56.80706575512886, 53.39209020137787, 59.121160581707954, 63.55583421885967, 70.97926408052444, 68.06789070367813, 71.59796968102455, 62.376955077052116, 57.37419292330742, 50.170364677906036, 57.04781323671341, 66.84352800250053, 73.71069431304932, 68.77425760030746, 73.08771014213562, 61.57942347228527, 68.62706109881401, 27.93413646519184, 55.062438771128654, 72.99503311514854, 55.006657764315605, 59.31981772184372, 55.73850989341736, 68.91336053609848, 71.76022857427597, 75.31568259000778, 68.08725446462631, 59.79853883385658, 52.13417910039425, 52.68301025032997, 56.944238394498825, 70.60918673872948, 70.62255442142487, 70.64626514911652, 67.35326305031776, 68.41522246599197, 69.8436114192009, 71.74648091197014, 71.70054137706757, 72.28861302137375, 68.69302555918694, 66.99577063322067, 71.19304060935974, 69.18053179979324, 72.18056201934814, 74.6992264688015, 71.5195494890213, 68.18713590502739, 61.93012185394764, 71.32642105221748, 75.42936488986015, 80.20590618252754, 68.91719833016396, 10.890288781374693, 1.0106550436466932, 1.0137713514268398, 1.5634828666225076, 1.719406193587929, 0.31021208851598203, 0.22096105269156396, 0.17661951016634703, 0.06332969511277042, 0.12784911232301965, 0.08850799757055938, 0.042468870160519145, 0.061935233024996705, 4.547930834814906, 23.120596557855606, 36.87563046813011, 74.86242011189461, 61.725780218839645, 19.61516685783863, 31.04278765618801, 51.70227527618408, 63.01749050617218, 66.14169046282768, 77.087671905756, 27.83983312547207, 0.4722324258182198, 0.01694760641839821, 0.06085368637286592, 0.06518022550153546, 0.04649059068469796, 0.0022877312085256563, 0.07865579420467839, 0.057492109917802736, 0.059040886771981604, 0.029954996825836133, 0.047472181176999584, 0.04108872410142794, 0.024909309177019168, 0.037771628267364576, 0.018674623024708126, 0.004828431337955408, 0.020044412412971724, 0.012554588483908447, 0.044477299888967536, 0.0504521972470684, 0.029102439839334693, 0.03793988056713715, 0.010981865307257976, 0.0716854096390307, 0.011591228849283652, 0.030206028277461883, 0.01657028369663749, 0.050948486241395585, 0.07033967325696722, 0.05344788747606799, 0.029997679594089277, 0.021809254430991132, 0.059375625060056336, 0.057651230090414174, 0.03648337864433415, 0.03508690533635672, 0.014321723738248693, 0.02168012815673137, 0.03841681806079578, 0.03065261749725323, 0.031997463302104734, 0.036233542050467804, 0.04721254081232473, 0.01342063400443294, 0.05652567037031986, 0.020038644070154987, 0.021349414164433256, 0.049302588231512345, 0.09605206971173175, 0.15171597304288298, 0.05065525256213732, 52.06788785755634, 125.51842913031578, 97.55515202879906, 90.93555003404617, 69.79942739009857, 56.851606965065, 54.431220442056656, 117.35635310411453, 102.86207646131516, 61.16704300045967, 52.24683165550232, 27.988308258354664, 0.9963606856763363, 0.03034814213606296, 0.07327048122533597, 0.049815438251243904, 0.15928954555420205, 0.7534127065446228, 1.2815034412778914, 2.0424319664016366, 2.6769656175747514, 1.6042458917945623, 0.5867665924597532, 1.162771568633616, 3.645425825379789, 33.26875761151314, 72.49991968274117, 86.35416626930237, 79.15443420410156, 80.70900678634644, 73.95037785172462, 63.816625624895096, 63.854380398988724, 78.41644540429115, 78.69785830378532, 74.47135269641876, 78.867367208004, 74.69386115670204, 68.25936242938042, 77.39265114068985, 69.76050227880478, 72.7991384267807, 65.05003184080124, 63.49851809442043, 62.83685199916363, 62.95551583170891, 60.221520736813545, 59.33228865265846, 56.85097999870777, 63.54057043790817, 65.31204298138618, 73.88916313648224, 70.37512689828873, 74.54507634043694, 64.14976134896278, 60.72541929781437, 53.199444338679314, 59.59899254143238, 69.9850246310234, 76.59646466374397, 72.20011577010155, 75.61490133404732, 63.98220553994179, 70.2054812014103, 30.69113552570343, 55.48550046980381, 76.33716657757759, 59.573381915688515, 62.56109319627285, 58.89960967004299, 71.86330944299698, 74.42792862653732, 76.92875683307648, 72.42681920528412, 63.13940316438675, 53.91786798834801, 55.925102680921555, 59.87817496061325, 71.64207011461258, 72.96388998627663, 73.69183212518692, 68.15231457352638, 69.50536116957664, 70.55489525198936, 74.00688841938972, 74.3638564646244, 73.19803342223167, 70.74661016464233, 67.44417697191238, 71.97465106844902, 69.44731548428535, 74.81904923915863, 76.20149865746498, 74.60470274090767, 67.88757517933846, 66.8400701880455, 71.55646830797195, 79.45043072104454, 81.18151143193245, 77.48142957687378, 13.789713699370623, 0.5395283584948629, 0.7782931777182966, 1.4463054668158293, 1.9553779251873493, 1.5928041120059788, 0.9051965118851513, 0.6247108220122755, 0.1997547023347579, 0.44759822892956436, 0.1849942607805133, 0.0031414747036251356, 0.11716169596184045, 4.121331525966525, 28.420225381851196, 31.696667969226837, 71.83636128902435, 54.45944532752037, 26.65218025445938, 45.189044773578644, 62.71963968873024, 71.03331997990608, 74.6212774515152, 89.4265142083168, 37.46320813894272, 0.4077463236171752, 0.026174717349931598, 0.028624095975828823, 0.04154488517087884, 0.1163527624157723, 0.013233985719125485, 0.12454406154574826, 0.00799546027337783, 0.05042221448093187, 0.022533972769451793, 0.06167968189402018, 0.035880524665117264, 0.005057519338151906, 0.060305573206278495, 0.03175176418153569, 0.012957613635080634, 0.027815288594865706, 0.09784035617485642, 0.020332664425950497, 0.07621757933520712, 0.05298485411913134, 0.02318698665476404, 0.010960397758026375, 0.07861083489842713, 0.028143874478701036, 0.011264596669207094, 0.09935026304447092, 0.07746019429760054, 0.15307805151678622, 0.10865728472708724, 0.1644359389320016, 0.09507541821221821, 0.1149225993140135, 0.14379305677721277, 0.1664249540772289, 0.19663097307784483, 0.08637027829536237, 0.09457455016672611, 0.11190567995072342, 0.13921359000960365, 0.08131497612339444, 0.07580040328321047, 0.1312361704185605, 0.1322735592839308, 0.137338450003881, 0.0896306369395461, 0.17180006252601743, 0.12923689879244193, 0.1228420645929873, 0.3107248235028237, 0.19512281025527045, 64.43102225661278, 140.20718693733215, 108.07408958673477, 102.76160225272179, 74.5947852730751, 57.558315843343735, 58.611512929201126, 93.10103863477707, 89.71605867147446, 72.83218905329704, 71.46325930953026, 37.213075160980225, 2.163348365575075, 0.516279365401715, 0.11932605091715232, 0.23442877689376473, 0.20763409906066954, 0.6053068663459271, 1.5876102657057345, 4.2345663998275995, 6.4201573468744755, 6.684539085254073, 7.633640756830573, 6.748854434117675, 5.17349649220705, 34.00016136467457, 74.17223274707794, 88.02456423640251, 82.19032689929008, 83.24144929647446, 76.76938578486443, 67.61326789855957, 67.18731835484505, 82.04731777310371, 81.92247927188873, 78.46096381545067, 82.28385508060455, 72.63459965586662, 69.8889809846878, 80.21463051438332, 72.74585768580437, 74.6127887070179, 69.04021292924881, 67.28510230779648, 66.33237183094025, 66.1317577958107, 64.56846848130226, 64.18943122029305, 60.56197486817837, 66.44684448838234, 67.97420293092728, 77.597216963768, 73.41267630457878, 78.27241033315659, 68.03151905536652, 64.52398046851158, 56.95058025419712, 61.789666190743446, 73.70361909270287, 81.76132991909981, 74.0716065466404, 79.85519260168076, 65.94150960445404, 70.92885598540306, 35.953963324427605, 60.870328322052956, 80.85033640265465, 61.975540816783905, 65.23229286074638, 62.242898270487785, 76.17885947227478, 76.85551956295967, 79.46390479803085, 75.99480494856834, 66.39268979430199, 55.57693876326084, 59.02821756899357, 62.8237920999527, 76.8689252436161, 77.71781489253044, 74.31438311934471, 67.97343537211418, 70.55821627378464, 72.41523742675781, 76.58867508172989, 78.18971917033195, 74.96762126684189, 71.91372513771057, 68.29240545630455, 73.56408298015594, 70.07142439484596, 76.57887920737267, 79.81061339378357, 79.93325561285019, 72.99583107233047, 69.68311563134193, 75.71748062968254, 84.11373049020767, 84.04010564088821, 81.7548930644989, 14.093707837164402, 2.7103836368769407, 6.824292736127973, 7.40127420052886, 5.08020437322557, 2.368481308221817, 0.833786646835506, 0.598611863097176, 0.5834257998503745, 0.3219116310356185, 0.3742533177137375, 0.3475668153259903, 0.18269792228238657, 7.41435594856739, 39.83519285917282, 57.15606562793255, 96.1063201725483, 81.13864973187447, 31.806143894791603, 43.990938663482666, 70.0583378970623, 82.10056811571121, 86.5496277809143, 100.22065579891205, 43.23002189397812, 0.4766522120917216, 0.0663005567912478, 0.1292606326751411, 0.1579665782628581, 0.2623918920289725, 0.23095850920071825, 0.18597239657538012, 0.2657968655694276, 0.16789698915090412, 0.12106145935831591, 0.19545981951523572, 0.1580212893895805, 0.08204085592296906, 0.10541307521634735, 0.15410233405418694, 0.13691731088329107, 0.14250565320253372, 0.21449051942909136, 0.15108771534869447, 0.20016061258502305, 0.14015181310242042, 0.1428539282642305, 0.10809227285790257, 0.1494987474870868, 0.06273068545851856, 0.07471385455573909, 0.1526029731030576, 0.11111213854746893], [0.04166779595834669, 0.04531237187620718, 0.03669082376291044, 0.053761767703690566, 0.013211809418862686, 0.03322855271107983, 0.04572327306959778, 0.0364531806553714, 0.03517148790706415, 0.021255369210848585, 0.025558512134011835, 0.0504576854291372, 0.03533261187840253, 0.025356473561259918, 0.04518795452895574, 0.015216113733913517, 0.04531712162133772, 0.06405730411643162, 0.10919067368377, 0.06242995979846455, 0.0676018904778175, 0.19009639247087762, 6.878021853044629, 92.72602155804634, 86.76463544368744, 82.67122149467468, 66.21583208441734, 49.4940959662199, 17.12972402572632, 37.53923445940018, 35.80845393240452, 28.15022137016058, 46.89150922000408, 32.16277375817299, 1.6346784587949514, 0.18695142294745892, 0.07337192539125681, 0.17547212017234415, 0.12800800614058971, 0.2786765119526535, 0.8324677613563836, 1.6887268773280084, 0.3028285800246522, 0.6987914093770087, 0.6254947080742568, 1.9786424143239856, 12.787163145840168, 61.77289769053459, 77.92861998081207, 84.38804537057877, 85.01394778490067, 76.49868071079254, 74.26513016223907, 67.1125839650631, 57.980849370360374, 62.31639392673969, 69.65220049023628, 74.6344855427742, 80.85172712802887, 74.9992735683918, 65.47131523489952, 71.6908822953701, 71.7964406311512, 68.32542568445206, 63.00711706280708, 56.134938821196556, 54.29801099002361, 55.768186300992966, 53.012471571564674, 50.204201862215996, 54.041726142168045, 54.98275704681873, 57.7044901996851, 56.88564173877239, 65.5450464785099, 65.07870510220528, 61.65654793381691, 51.16667881608009, 50.60294106602669, 52.1627763658762, 67.81577423214912, 70.69475814700127, 73.797208070755, 69.28361266851425, 70.08686676621437, 65.74706643819809, 71.67135894298553, 36.54443643987179, 50.528214275836945, 73.77681836485863, 56.058156341314316, 59.069718942046165, 58.00611421465874, 69.70621839165688, 70.51346987485886, 73.36550563573837, 66.5317015349865, 60.79824239015579, 52.32748232781887, 55.97301431000233, 60.672936514019966, 65.35715416073799, 71.59268036484718, 68.64230588078499, 65.12980476021767, 72.05053299665451, 67.22391799092293, 69.74522709846497, 66.47658169269562, 69.036435931921, 68.88592600822449, 67.25972726941109, 65.65745204687119, 73.66812899708748, 74.50904667377472, 74.9208077788353, 67.71304294466972, 65.34986615180969, 58.447445333004, 62.9694002866745, 71.97620138525963, 76.59369081258774, 75.65487518906593, 78.41131567955017, 17.75817420333624, 0.9557620016857982, 2.045730189420283, 0.9725325205363333, 2.7495431480929255, 0.582680149236694, 0.1395290473010391, 0.11452043690951541, 0.20526139356661588, 0.18815897143213078, 0.03689704433782026, 0.09071880354895256, 0.045501957210944965, 9.227172173559666, 47.42368586361408, 26.144806779921055, 30.250889249145985, 39.67866785824299, 16.501735523343086, 33.88305924832821, 46.74585163593292, 60.785836055874825, 68.43979954719543, 65.17225608229637, 4.845789251849055, 0.21015312639065087, 0.08070737982052378, 0.05994986553560011, 0.03973456063249614, 0.07486439921194687, 0.09251288618543185, 0.010873027495108545, 0.054845592749188654, 0.02652038190717576, 0.08852934173773974, 0.0607231574394973, 0.020881744239886757, 0.029120828403392807, 0.1416768820490688, 0.017866878770291805, 0.05847804568475112, 0.0487438994605327, 0.06881364693981595, 0.09595789117156528, 0.03330171362904366, 0.033470203416072764, 0.10508457096875645, 0.021132842484803405, 0.13277777441544458, 0.0033137378477476886, 0.04773743959958665, 0.04990199864550959, 0.03466109810688067, 0.08164840081008151, 0.03164460176776629, 0.12066050665453076, 0.020415736726135947, 0.004854328117289697, 0.023518821290053893, 0.013295711996761383, 0.062003985585761257, 0.04598773368343245, 0.13638789241667837, 0.06354671393637545, 0.11477142383228056, 0.028559694255818613, 0.053341203747550026, 0.05155692117114086, 0.0627453280321788, 0.042873882412095554, 0.03977969434345141, 0.09122241011937149, 0.11504736918141134, 0.20557168551022187, 8.269047886133194, 106.46796897053719, 97.81426772475243, 94.40254479646683, 73.47771361470222, 58.98644261062145, 28.538108356297016, 51.16726018488407, 39.82209496200085, 35.47406427562237, 46.00723206996918, 36.39100827276707, 2.13408756069839, 0.23029387142742053, 0.04012885627162177, 0.03023969580681296, 0.19551003322703764, 0.8022951835300773, 2.7765946090221405, 2.883100756444037, 1.7378521850332618, 0.5672013235744089, 1.1871245806105435, 1.7727947537787259, 16.27838920801878, 63.65116350352764, 80.31332641839981, 86.75760582089424, 88.42918172478676, 81.08229875564575, 77.80781686306, 70.68923324346542, 59.599923491477966, 64.55004706978798, 72.93435797095299, 79.12586733698845, 81.70868754386902, 76.11363977193832, 68.23768839240074, 73.63975211977959, 74.53480929136276, 72.14966207742691, 65.56042805314064, 58.001182079315186, 57.66827434301376, 58.81118841469288, 56.81400038301945, 54.00160789489746, 56.73964977264404, 56.804789677262306, 60.6009341776371, 59.94255490601063, 67.37565144896507, 70.26820823550224, 64.48415860533714, 54.392090141773224, 53.4372241795063, 54.72234562039375, 71.41446232795715, 72.93037578463554, 77.29574874043465, 70.29017105698586, 70.68607941269875, 67.6664650440216, 72.95173823833466, 38.95438872277737, 54.255574867129326, 76.04774370789528, 58.43608394265175, 61.596868336200714, 59.086525440216064, 73.13730508089066, 73.99349793791771, 76.35933458805084, 69.22036126255989, 64.6362492442131, 53.87446291744709, 57.91900768876076, 61.92661464214325, 70.46774312853813, 74.01090860366821, 67.28798255324364, 67.42434963583946, 74.67875316739082, 69.67901945114136, 71.53028771281242, 69.23961862921715, 72.99608945846558, 70.7687857747078, 68.2194721698761, 66.27298101782799, 75.66975519061089, 76.40940830111504, 79.00073245167732, 69.56574752926826, 69.33183968067169, 62.29095809161663, 67.4329523742199, 73.73298391699791, 79.31727826595306, 77.83680930733681, 83.95372867584229, 22.66938216984272, 0.6378283118829131, 1.1663845810107887, 1.09887431608513, 3.409014386124909, 2.237490937113762, 1.0804298683069646, 0.39719963329844177, 0.3630114725092426, 0.3479158622212708, 0.2546729921596125, 0.2320851932745427, 0.06127223539806437, 10.886623878031969, 46.06550194323063, 29.042398296296597, 29.837811514735222, 38.175141736865044, 28.25960610061884, 45.74140213429928, 55.860608741641045, 68.92664462327957, 75.44242858886719, 79.53096359968185, 10.281482599675655, 0.15493831888306886, 0.017421617994841654, 0.01804696275939932, 0.02498403231584234, 0.07487815120839514, 0.0775856692052912, 0.0435794384975452, 0.007686708286200883, 0.1259400264825672, 0.029149081965442747, 0.037309474355424754, 0.09030396526213735, 0.023610133284819312, 0.05236814795352984, 0.019012159209523816, 0.04137892981816549, 0.04183420031040441, 0.07745309194433503, 0.08862877468345687, 0.03877594332152512, 0.02617848374939058, 0.0072202271894639125, 0.06303339265286922, 0.09504557645414025, 0.04324360183090903, 0.05080242786789313, 0.030383885823539458, 0.1551373628899455, 0.20976617059204727, 0.18745508888969198, 0.16996881313389167, 0.1025146248866804, 0.08294725572341122, 0.13580867584096268, 0.14447776222368702, 0.09909252257784829, 0.11275147597189061, 0.26426346972584724, 0.19714968977496028, 0.276295761577785, 0.13417501584626734, 0.16597452980931848, 0.14410852891160175, 0.1113894568698015, 0.11523604538524523, 0.24904032878112048, 0.23648422909900546, 0.24330986518179998, 0.3673141181934625, 10.341018754988909, 124.72997903823853, 109.79289695620537, 106.60176739096642, 83.8180835545063, 65.19497886300087, 27.11653433740139, 53.088893070816994, 50.86428724229336, 41.399945095181465, 69.3591146171093, 49.669084176421165, 4.126143492758274, 0.41296207811683416, 0.1689537035417743, 0.43983981711789966, 0.3206023044185713, 1.2354005151428282, 3.8718846486881375, 5.281808730214834, 3.5090905660763383, 5.577028663828969, 7.270498042926192, 7.6926216669380665, 15.91752827167511, 67.04905897378922, 81.22849211096764, 85.6874768435955, 88.06204542517662, 84.3929623067379, 78.93661469221115, 72.97318428754807, 63.51117521524429, 69.56996530294418, 74.56269979476929, 83.1614787876606, 84.49582278728485, 77.00267806649208, 68.88899624347687, 74.84050288796425, 77.37552165985107, 77.12152808904648, 69.68572989106178, 63.0771891027689, 61.661115288734436, 61.674490571022034, 59.47462521493435, 57.209502160549164, 60.465612038969994, 60.6540135294199, 66.35611295700073, 62.56298169493675, 70.7436691224575, 72.48519167304039, 66.94949671626091, 55.31691111624241, 56.46768316626549, 58.9358901232481, 74.79016318917274, 76.29143223166466, 79.87394079566002, 72.14726060628891, 74.20753285288811, 68.6326240003109, 75.2696442604065, 44.20154236257076, 57.06257924437523, 79.41725090146065, 61.36294908821583, 64.1611835360527, 63.37120972573757, 75.82889825105667, 76.18927851319313, 80.78582346439362, 71.61937013268471, 67.29089319705963, 57.23626412451267, 61.495432779192924, 66.56692564487457, 73.15894111990929, 76.61718115210533, 71.48761600255966, 68.1300401687622, 76.98301032185555, 73.89520481228828, 76.41414284706116, 72.58152410387993, 76.86632618308067, 75.58885753154755, 68.44258859753609, 65.93523994088173, 78.29513311386108, 80.44024720788002, 81.0767662525177, 73.44341665506363, 71.36832520365715, 66.01926863193512, 71.4188700914383, 78.8457615673542, 83.37377339601517, 82.02533975243568, 87.09369018673897, 21.972018890082836, 1.5927949687466025, 7.052681855857372, 5.726331677287817, 7.340809470042586, 2.9820823576301336, 0.7804328785277903, 0.5256721645127982, 0.6514292070642114, 0.64978270791471, 0.2872107649454847, 0.48222081328276545, 0.18988520692801103, 17.43083316832781, 69.97819259762764, 39.09746244549751, 42.863463163375854, 54.987123012542725, 26.056826300919056, 48.35364796221256, 64.09847170114517, 81.80602312088013, 85.17206490039825, 90.44386401772499, 12.710854690521955, 0.36254029779229313, 0.1378149978700094, 0.2630633575608954, 0.1165946209221147, 0.17452301719458774, 0.19725002814084291, 0.16616604843875393, 0.1624498181627132, 0.3086881327908486, 0.1290038347360678, 0.1698276269598864, 0.12540688243461773, 0.14976894861320034, 0.21640143095282838, 0.1528328310814686, 0.11778946383856237, 0.1514905976364389, 0.17625238455366343, 0.14345641859108582, 0.1284623341052793, 0.09816526100621559, 0.23149526008637622, 0.11433509294874966, 0.25133683055173606, 0.137291575956624, 0.11645728649455123, 0.14280031551606953], [0.008254409513028804, 0.0680395275412593, 0.04948473724653013, 0.02310528918314958, 0.049445611221017316, 0.025948494039766956, 0.03486556721327361, 0.052206779073458165, 0.03256502815929707, 0.0673824967816472, 0.06543748357216828, 0.014535568952851463, 0.020890258529107086, 0.033874792643473484, 0.025008296834130306, 0.04038513470732141, 0.0694502834812738, 0.023847997181292158, 0.08936799087678082, 0.06166974453662988, 0.1759862355538644, 0.07488650036975741, 28.3546295017004, 92.40974172949791, 85.77615648508072, 78.21852162480354, 56.02507531642914, 70.60977190732956, 63.51193517446518, 30.42916238307953, 49.292908161878586, 59.29959520697594, 44.28934045135975, 5.773850977420807, 0.16737764904974028, 0.06811516723246314, 0.15566997259156778, 0.06102519670093898, 0.08303504437208176, 0.5817524052690715, 2.6145606162026525, 0.8659193851053715, 1.0988942650146782, 1.2395973899401724, 7.693729782477021, 51.960004046559334, 85.06322354078293, 82.86255642771721, 76.44535437226295, 82.06055626273155, 77.45239153504372, 75.77577710151672, 72.31444403529167, 63.508921936154366, 56.79847441613674, 60.15471272170544, 67.58470863103867, 73.53822156786919, 74.25553187727928, 74.31730896234512, 66.51362210512161, 69.2283408343792, 72.02391162514687, 65.7767428457737, 59.39497008919716, 53.88305805623531, 52.37359285354614, 52.26461470127106, 51.14091619849205, 49.74022015929222, 50.185506865382195, 49.19290512800217, 52.36372098326683, 54.62173841893673, 55.726536735892296, 54.42329786717892, 50.44968768954277, 46.977331414818764, 51.92072555422783, 51.44536346197128, 63.84880229830742, 68.62977415323257, 70.80751329660416, 65.24742364883423, 71.41032814979553, 66.5234787762165, 72.88125962018967, 39.04495686292648, 50.66565290093422, 74.09659400582314, 56.08647242188454, 57.79438957571983, 58.17956730723381, 68.57830971479416, 70.10543256998062, 73.28245729207993, 66.41326949000359, 58.153588101267815, 50.39665013551712, 51.11541576683521, 59.27270784974098, 71.24908000230789, 59.18908193707466, 63.43463972210884, 65.86418375372887, 69.30070415139198, 63.94694343209267, 60.58340571820736, 60.3973601013422, 65.92821031808853, 66.88186034560204, 69.89620819687843, 67.1871055662632, 74.262325912714, 71.3086000084877, 68.86492073535919, 64.8565386235714, 62.29331776499748, 63.99380251765251, 63.077436089515686, 62.674855291843414, 73.76664251089096, 74.07809659838676, 77.55060866475105, 79.79545220732689, 32.70579881966114, 1.2279941188171506, 1.574595607817173, 1.598931758198887, 1.5412140428088605, 1.4116597571410239, 0.2126708030118607, 0.6551784183830023, 0.22701294044964015, 0.09601174140698276, 0.045221759355627, 0.07086626414093189, 0.15070458903210238, 14.306390024721622, 41.56746670603752, 50.7269474118948, 43.44696365296841, 24.876263849437237, 19.497992545366287, 37.832787707448006, 60.006908252835274, 61.63460411131382, 69.14715439081192, 40.78901767730713, 2.3314788937568665, 0.11728207231499255, 0.06568737211637199, 0.07797133366693743, 0.021194012151681818, 0.048755009411252104, 0.09554741671308875, 0.03731427976163104, 0.04887700735707767, 0.04650219787436072, 0.021333791955839843, 0.02158657673135167, 0.02384794152021641, 0.01013675020658411, 0.04513589658017736, 0.017638477256696206, 0.06289832919719629, 0.03506430693960283, 0.03713551865075715, 0.11205992792383768, 0.017379002019879408, 0.04090618545887992, 0.0686344553832896, 0.06262109251110815, 0.02912230156653095, 0.0290885616777814, 0.0624466803856194, 0.05408253135101404, 0.024328734471055213, 0.019773446874751244, 0.030919341661501676, 0.053884901135461405, 0.035948152872151695, 0.01656606273172656, 0.024852696296875365, 0.04409942055644933, 0.10495102149434388, 0.06361775973346084, 0.06912568293046206, 0.01990357690374367, 0.10986086272168905, 0.06670752831269056, 0.059610407188301906, 0.04459198025870137, 0.05102801107568666, 0.05710479788831435, 0.023086108376446646, 0.1683821459300816, 0.07942131953313947, 38.16088870167732, 109.78104159235954, 94.2488506436348, 87.88128152489662, 67.29607611894608, 87.11791008710861, 44.264341592788696, 29.689414277672768, 47.43061289191246, 44.04844097793102, 48.743925020098686, 7.38091679289937, 0.13580325816292316, 0.037435387130244635, 0.15401752141769975, 0.4695882130181417, 1.147641136776656, 1.3639718410558999, 2.9507672879844904, 1.1380308587104082, 0.11580264545045793, 0.3338389832060784, 9.838833902031183, 57.50921867787838, 87.34785094857216, 85.52301406860352, 78.27085241675377, 85.6835250556469, 81.45936012268066, 79.5431761443615, 76.91712945699692, 65.08606150746346, 58.86715941131115, 62.41169661283493, 70.71816489100456, 76.79899379611015, 76.67612358927727, 74.6032740175724, 67.3281691968441, 71.00680500268936, 73.52598622441292, 69.13457706570625, 62.13219501078129, 56.074457466602325, 55.65135017037392, 54.40571241080761, 54.98803876340389, 52.05499894917011, 53.43187026679516, 52.58832313120365, 54.18999418616295, 57.066641226410866, 59.49211187660694, 56.88186474144459, 54.782785177230835, 50.527872294187546, 54.082235768437386, 54.52188737690449, 68.81320551037788, 71.81097865104675, 73.81458073854446, 69.18182373046875, 73.83446887135506, 69.84573930501938, 74.75272759795189, 41.62075884640217, 53.39045248925686, 77.83699169754982, 58.83582629263401, 58.69710333645344, 61.71520538628101, 71.0143817961216, 73.68591964244843, 75.51008015871048, 69.71525430679321, 60.26336409151554, 53.107759058475494, 52.932406067848206, 61.83458358049393, 73.98507758975029, 66.67051568627357, 65.22506564855576, 69.35631796717644, 70.25107115507126, 67.89337366819382, 65.17475634813309, 64.54690843820572, 67.55087524652481, 69.6738213300705, 73.18883031606674, 67.98598229885101, 77.69589766860008, 74.40094247460365, 70.8486270904541, 67.85350620746613, 65.47385349869728, 68.58660086989403, 66.34212970733643, 66.43920689821243, 75.43127998709679, 77.84016072750092, 79.58637982606888, 85.68100199103355, 37.60072275996208, 2.2757047740742564, 1.12305894959718, 0.42208129190839827, 1.1870340979658067, 1.979983386117965, 0.8138479292392731, 0.7493136764969677, 0.445853469427675, 0.09681209572590888, 0.12310599457123317, 0.15055111289257184, 0.15373134927358478, 17.270755358040333, 39.84354481101036, 38.19876126945019, 39.58192124962807, 26.155353114008904, 33.21820892393589, 45.6783103197813, 67.42213055491447, 69.60934638977051, 78.23422238230705, 56.434769332408905, 4.399789609014988, 0.13160966365830973, 0.06897226616274565, 0.028090146697650198, 0.07021990546490997, 0.04890219584922306, 0.04867978532274719, 0.02090817768475972, 0.03598293362301774, 0.07304287937586196, 0.056747342459857464, 0.04504334705416113, 0.0704965706972871, 0.08025560484384187, 0.026627670486050192, 0.0362567378761014, 0.02208093985245796, 0.02842331348801963, 0.04226644567097537, 0.02253838854812784, 0.02305319969309494, 0.04507417215791065, 0.035600059636635706, 0.03584919119020924, 0.021427771971502807, 0.06280087778577581, 0.08444447186775506, 0.170928914740216, 0.12034429237246513, 0.21726336126448587, 0.10262232535751536, 0.15226965973852202, 0.09583412320353091, 0.12685218534898013, 0.12499261560151353, 0.1651366747682914, 0.19890096533345059, 0.17857509898021817, 0.12652580364374444, 0.08349251904292032, 0.24389029887970537, 0.1737749026506208, 0.15711634419858456, 0.24798441590974107, 0.1964760571718216, 0.18555587361333892, 0.2541023102821782, 0.31196964264381677, 0.3152548335492611, 47.008656933903694, 118.10714721679688, 107.93121725320816, 100.82009643316269, 78.6414997279644, 83.89417827129364, 75.79849228262901, 40.5939057469368, 68.26997146010399, 86.67520344257355, 67.34190165996552, 10.509130284190178, 0.3267845726804808, 0.21143359830603004, 0.4160757438512519, 0.5999593657907099, 1.397332507185638, 2.2539742151275277, 7.8575190436095, 4.455111315473914, 7.009459175169468, 6.250922977924347, 9.826531112194061, 57.350478395819664, 90.29756426811218, 85.11377602815628, 79.07656118273735, 84.29531514644623, 84.50491189956665, 82.58964747190475, 78.63372534513474, 68.69720533490181, 62.226296961307526, 65.26804894208908, 75.62092781066895, 79.29444909095764, 79.05656665563583, 78.32844972610474, 67.1188460290432, 74.77864220738411, 75.52727043628693, 72.14865133166313, 65.804443359375, 60.58402128517628, 57.025341242551804, 58.452005088329315, 59.345933720469475, 55.155624970793724, 56.561348140239716, 54.762703254818916, 57.63029918074608, 60.33526763319969, 62.47991815209389, 61.571888476610184, 56.82215854525566, 53.94922390580177, 56.43556348979473, 56.38620413839817, 73.31894293427467, 75.29799073934555, 76.48342832922935, 72.44765728712082, 76.76248535513878, 74.83734905719757, 76.01150125265121, 45.234801918268204, 57.643982246518135, 80.97730278968811, 62.59330026805401, 63.326030150055885, 65.53430825471878, 74.93455544114113, 76.4346693456173, 77.8328575193882, 72.99116492271423, 62.7272392809391, 55.403413474559784, 54.74231354892254, 65.26299521327019, 76.9214004278183, 68.38602483272552, 67.42015466094017, 74.27708432078362, 75.2238567173481, 70.41209131479263, 68.0965107679367, 69.29234459996223, 73.21228265762329, 74.89437639713287, 75.27158215641975, 68.5680578649044, 80.16135737299919, 77.02888146042824, 75.28588458895683, 69.3087749183178, 68.111512362957, 71.49545878171921, 69.05252426862717, 69.54780489206314, 80.10129779577255, 80.34305602312088, 83.22479099035263, 88.06079149246216, 36.76176577806473, 2.287588161416352, 5.756466910243034, 6.398343667387962, 4.495703112334013, 4.205358317121863, 0.5902523116674274, 1.4136845734901726, 0.9747658506967127, 0.3016074205515906, 0.2263517610845156, 0.14472151320660487, 0.319939655601047, 26.091347448527813, 62.79105305671692, 67.11999356746674, 62.62909434735775, 34.0173364430666, 30.87514255195856, 52.66855202615261, 80.60686826705933, 78.29957127571106, 88.20688605308533, 66.4282938838005, 4.769312655553222, 0.2697868592804298, 0.13485834089806303, 0.17538159299874678, 0.16303143929690123, 0.15553723205812275, 0.1842340047005564, 0.08459048200165853, 0.16985329042654485, 0.1727254019351676, 0.11617051321081817, 0.12191191606689245, 0.13409798091743141, 0.14383889181772247, 0.15098173666046932, 0.13826512527884915, 0.13478246371960267, 0.18968408490763977, 0.10049291071482003, 0.19069693837082013, 0.11008015993866138, 0.10434107258333825, 0.2964662073645741, 0.11677757516736165, 0.09671324165537953, 0.1813581379246898, 0.13468645949615166], [0.031763612569193356, 0.03673439525300637, 0.046554660293622874, 0.03594300236727577, 0.017763141368050128, 0.052844499150523916, 0.04254392355505843, 0.02411868812487228, 0.02847126921551535, 0.030537313723471016, 0.058023287274409086, 0.057232929684687406, 0.010884616131079383, 0.013376810184126953, 0.0915083076688461, 0.0156959149899194, 0.07859792152885348, 0.04275488645362202, 0.03395785381144378, 0.05998898413963616, 0.03905396668415051, 1.0923043498769403, 59.847848787903786, 98.05235534906387, 79.10534083843231, 76.63041964173317, 48.390403389930725, 25.056442581117153, 43.86767327785492, 58.1209060549736, 47.45025783777237, 42.553711384534836, 14.905988350510597, 0.011664032608678099, 0.14521113771479577, 0.023297789302887395, 0.11671923493850045, 0.5860556743573397, 0.7674504595343024, 1.0112497117370367, 0.7903109828475863, 0.9148300043307245, 0.6670784892048687, 22.759175151586533, 82.57807329297066, 86.41640692949295, 76.62180170416832, 78.73628944158554, 79.82173159718513, 77.29179695248604, 82.52413898706436, 75.55028960108757, 70.60786440968513, 60.19532114267349, 53.34593787789345, 55.928541496396065, 60.70953235030174, 67.30212539434433, 70.24442911148071, 73.45553040504456, 71.58473879098892, 67.12455332279205, 69.31249871850014, 61.77922435104847, 60.98213732242584, 52.969013303518295, 51.00812092423439, 50.30681535601616, 51.09891325235367, 49.79084484279156, 49.76304553449154, 48.6175362020731, 51.245984360575676, 48.054341822862625, 51.09939582645893, 49.65733900666237, 48.04387338459492, 47.05730192363262, 51.26198910176754, 48.004237711429596, 53.28093096613884, 55.379463359713554, 60.05011573433876, 56.57596215605736, 59.52418975532055, 57.04315088689327, 75.67160189151764, 47.055067643523216, 51.06727235019207, 73.22991371154785, 58.63450549542904, 59.6838153898716, 57.93460965156555, 68.25237840414047, 65.95990061759949, 70.6507109105587, 63.36726553738117, 59.69401404261589, 49.625074937939644, 53.001281172037125, 58.444166108965874, 70.70314049720764, 70.02242982387543, 58.25695775449276, 64.011539965868, 66.29730731248856, 62.81969211995602, 56.45401909947395, 54.323207437992096, 57.213328555226326, 65.1153427362442, 69.644585698843, 65.07004156708717, 68.32351818680763, 70.15049815177917, 67.30937540531158, 60.40148667991161, 56.31430059671402, 61.29079855978489, 62.14871272444725, 65.39589688181877, 65.1751971244812, 72.43730664253235, 69.77410554885864, 69.64523166418076, 77.37204104661942, 53.10980714857578, 6.186183951795101, 0.8465775323566049, 1.5993732470087707, 2.252388750202954, 0.2975679701194167, 0.374854754190892, 0.5655929411295801, 0.6722983997315168, 0.15304038010071963, 0.0591172426356934, 0.021828643039043527, 1.395858305040747, 29.003258496522903, 43.441389352083206, 48.45534950494766, 42.839015275239944, 20.077391155064106, 37.88301721215248, 49.19617295265198, 60.51596313714981, 66.90507709980011, 76.03505238890648, 33.5855808109045, 0.46460267272777855, 0.06516297056805342, 0.011583839841478039, 0.027971705494564958, 0.06120488920714706, 0.020343748401501216, 0.03737711740541272, 0.019086038155364804, 0.02056538523902418, 0.018004326375375967, 0.04303619381971657, 0.08874473525793292, 0.06326698363409378, 0.021205816010478884, 0.060294118156889454, 0.03361148978001438, 0.06731605972163379, 0.04558718173939269, 0.03789554837567266, 0.05668717283697333, 0.057059794053202495, 0.06649188988376409, 0.0832241287571378, 0.03880161420966033, 0.026834349337150343, 0.03647102930699475, 0.07979045636602677, 0.042851836915360764, 0.05268944223644212, 0.06179369804158341, 0.045651303298654966, 0.061486152044381015, 0.03246572508942336, 0.07247299901791848, 0.028722849856421817, 0.05902852630242705, 0.04241048911353573, 0.11264767177635804, 0.022513168514706194, 0.04755002875754144, 0.03770150644413661, 0.040079674145090394, 0.04277894688129891, 0.09308402077294886, 0.011649272219074192, 0.02040818908426445, 0.10678007412934676, 1.735125237610191, 75.68575993180275, 108.28121647238731, 89.73052069544792, 83.36457028985023, 58.65049883723259, 37.298809960484505, 54.75036911666393, 43.777621909976006, 35.836937204003334, 47.07624010741711, 18.59188176691532, 0.02121623019775143, 0.03440339474764187, 0.16396802966482937, 0.7254334422759712, 2.1593324560672045, 2.857286841608584, 3.258858318440616, 1.1781258322298527, 0.08763474950683303, 0.814225118374452, 25.74890222400427, 87.9422302544117, 89.09154698252678, 81.44545286893845, 82.2232711315155, 81.41113311052322, 79.13752511143684, 84.76651266217232, 77.25592687726021, 73.66970971226692, 61.769599467515945, 56.926899924874306, 58.67009438574314, 64.04231071472168, 70.51502779126167, 74.04720425605774, 76.79830983281136, 72.38394990563393, 67.94160068035126, 71.13822475075722, 65.4551813006401, 64.55069303512573, 55.12924678623676, 53.35458241403103, 52.13271237909794, 53.288705348968506, 52.21726544201374, 53.36514964699745, 51.231560334563255, 53.646589145064354, 50.86826182901859, 52.785692140460014, 51.196100637316704, 51.98023796081543, 48.65407504141331, 52.69982434809208, 51.68517619371414, 56.78264066576958, 57.58719049394131, 61.5141885727644, 60.01680292189121, 62.65655167400837, 59.28523197770119, 77.78443291783333, 51.67624667286873, 54.7576305270195, 75.98662778735161, 61.378775238990784, 62.066051959991455, 61.24753028154373, 70.42811885476112, 69.25400465726852, 72.8734016418457, 65.44307515025139, 62.001463025808334, 51.630683317780495, 54.1968984156847, 61.82556286454201, 73.74965742230415, 70.23871421813965, 62.548740059137344, 67.4979516863823, 70.22904753684998, 63.913695216178894, 57.341484278440475, 55.89245863258839, 60.95941074192524, 67.4516473710537, 72.62333706021309, 65.76624780893326, 70.90168744325638, 72.72309690713882, 68.1320920586586, 62.7964373677969, 59.82757307589054, 62.69186317920685, 65.47902882099152, 67.3616074025631, 68.83099615573883, 74.90255355834961, 75.1176980137825, 73.38683009147644, 80.82745403051376, 59.34978291392326, 8.788139931857586, 0.602115037618205, 0.5698968039359897, 1.0215848009102046, 1.8309059855528176, 0.8486641547642648, 1.00019586738199, 0.6139435654040426, 0.1929723483044654, 0.024005293525988236, 0.10815615692990832, 1.3375348784029484, 33.31074915826321, 41.72587260603905, 43.51176157593727, 37.9203350096941, 23.3071019500494, 49.2508178204298, 58.01863074302673, 68.63825529813766, 75.46903476119041, 86.58487468957901, 45.50338290631771, 0.8835399895906448, 0.028045051949447952, 0.03587607548979577, 0.037517620803555474, 0.07182063636719249, 0.03558765092748217, 0.032621056598145515, 0.01714275414997246, 0.02855448252375936, 0.06542914183228277, 0.20220392325427383, 0.06873052640003152, 0.06929208728251979, 0.05491510972206015, 0.002957774831884308, 0.08571908823796548, 0.028989073070988525, 0.07488336850656196, 0.034035742210107855, 0.012463159600883955, 0.05353147556888871, 0.047821354237385094, 0.06392712399247102, 0.01558930362079991, 0.046177074109436944, 0.012047016061842442, 0.17617159435758367, 0.1778977704816498, 0.13898698263801634, 0.13245700334664434, 0.11735921856597997, 0.15650515590095893, 0.09293049268308096, 0.273538920446299, 0.11276666773483157, 0.11247478105360642, 0.13244777102954686, 0.1379522803472355, 0.12731733382679522, 0.1423009391874075, 0.21062128798803315, 0.20520620746538043, 0.17915259377332404, 0.2854316291632131, 0.2084188163280487, 0.15953277703374624, 0.2515899919671938, 3.3546407287940383, 91.85608863830566, 120.5946533381939, 101.45264849066734, 99.12205874919891, 66.23987719416618, 37.24027030169964, 50.63077077269554, 77.95289307832718, 73.78650784492493, 62.38553501665592, 27.801293693482876, 0.15309544745832682, 0.4735012608580291, 0.2129339982639067, 1.1149970884434879, 3.2133514853194356, 5.214442620053887, 6.989479372277856, 4.823058871552348, 6.272464022040367, 4.137087855488062, 26.278698295354843, 89.46762040257454, 93.42690914869308, 81.98826894164085, 83.82872298359871, 83.8686740398407, 83.74949723482132, 88.10734659433365, 79.52229246497154, 76.98997154831886, 66.05418115854263, 60.54234132170677, 61.191057711839676, 67.07858338952065, 75.03913342952728, 76.09309047460556, 78.56773048639297, 75.22077888250351, 71.48749440908432, 74.19310122728348, 69.18260648846626, 68.28425109386444, 58.32249663770199, 57.03748919069767, 55.09302332997322, 57.38510973751545, 54.64586712419987, 55.02951733767986, 55.0018510222435, 58.49485158920288, 52.52687282860279, 57.16029480099678, 54.98925469815731, 55.05041241645813, 50.7303786277771, 57.17689611017704, 52.76506684720516, 58.94015349447727, 60.59477850794792, 64.5657554268837, 62.86457531154156, 64.74556177854538, 63.1740041077137, 82.48263761401176, 54.35864433646202, 59.92074407637119, 78.39883714914322, 65.08752822875977, 65.03337353467941, 64.97528985142708, 72.39928588271141, 73.00075560808182, 75.97419485449791, 67.73753643035889, 66.16722509264946, 53.69684524834156, 58.44018392264843, 63.71732175350189, 76.0725411772728, 74.37218561768532, 65.22448047995567, 69.4137404859066, 73.46056893467903, 69.58426013588905, 61.51329942047596, 60.716060400009155, 63.01374390721321, 71.80620610713959, 75.81954315304756, 65.995322316885, 74.22190368175507, 76.56577751040459, 72.19915822148323, 65.76617181301117, 61.44608862698078, 65.97392946481705, 68.70038196444511, 72.1014578640461, 72.03403428196907, 78.49551156163216, 79.19023588299751, 76.23739153146744, 84.44204807281494, 61.90827302634716, 7.161192633211613, 3.5376956686377525, 7.07389896735549, 5.313922232016921, 2.550367573276162, 0.9309876279439777, 1.3194796722382307, 1.705335311125964, 0.8011310803703964, 0.2693517826264724, 0.32589147216640413, 2.5712367659434676, 49.023825600743294, 62.31599874794483, 66.37918531894684, 60.51546536386013, 29.332888908684254, 53.56006778776646, 65.53176239132881, 78.91142204403877, 83.37656244635582, 94.5847450196743, 51.037812530994415, 0.822972902096808, 0.17130910215200856, 0.11384606958017685, 0.07012421294348314, 0.1258876160136424, 0.1525547928758897, 0.1280774563201703, 0.11148932768264785, 0.15066532942000777, 0.20555387396598235, 0.2623665996361524, 0.17709409876260906, 0.27596601052209735, 0.18976183229824528, 0.0960142795520369, 0.12065255825291388, 0.1502740543219261, 0.17817876243498176, 0.10736456737504341, 0.13467795448377728, 0.15296727855456993, 0.23923841334180906, 0.18706555041717365, 0.1075767473957967, 0.1296496664872393, 0.09821465835557319], [0.009671317857282702, 0.026035486735054292, 0.04372734110802412, 0.04285922499548178, 0.06480472846305929, 0.05856747076904867, 0.010845381566468859, 0.020980581612093374, 0.051140910290996544, 0.03731572323886212, 0.013537551021727268, 0.009525168570689857, 0.06296977575402707, 0.043025180348195136, 0.0547670586820459, 0.04460783253307454, 0.04345686538727023, 0.017530504046590067, 0.009686183075245935, 0.21403841790743172, 0.06722322446876206, 8.21484474465251, 80.81246763467789, 83.14925104379654, 82.96680763363838, 60.81734396517277, 39.06877778470516, 35.32827369868755, 21.400464959442616, 44.79459173977375, 48.76298859715462, 26.86573449522257, 2.1402933401986957, 0.13230769807705656, 0.1928800399764441, 0.2739103208296001, 0.5656494630966336, 0.9499611973296851, 1.809987158048898, 1.392947779968381, 0.28923670935910195, 0.09402406954905018, 34.14447382092476, 99.24140274524689, 77.64264732599258, 75.48690140247345, 80.70474341511726, 79.2249508202076, 78.720733076334, 79.39393535256386, 78.14226731657982, 71.47218123078346, 66.18181630969048, 53.353028297424316, 54.52806584537029, 54.54823896288872, 56.10981836915016, 65.2716663479805, 69.67230141162872, 72.31399565935135, 68.78926679491997, 66.05804935097694, 72.40183174610138, 67.18343496322632, 63.469081073999405, 53.18372078239918, 49.220780432224274, 48.950911313295364, 50.48133999109268, 48.33806499838829, 49.682588651776314, 47.51586891710758, 48.74026961624622, 49.6574492007494, 47.1582967042923, 45.554862543940544, 50.57131916284561, 48.492534309625626, 52.279559299349785, 47.36940957605839, 49.01709996163845, 46.77684277296066, 50.36183260381222, 48.17293345928192, 52.72580735385418, 53.7883785367012, 66.61812409758568, 53.980876207351685, 45.88598817586899, 72.22629636526108, 57.51324646174908, 59.09783363342285, 59.439686089754105, 66.79661571979523, 65.58441996574402, 68.05432543158531, 60.78312300145626, 56.46471552550793, 50.23013927042484, 47.82945469021797, 53.42258736491203, 68.58295306563377, 72.04511448740959, 71.06855168938637, 63.320980221033096, 64.13301184773445, 57.23149158060551, 54.36715207993984, 51.010028421878815, 53.57465520501137, 61.91220201551914, 71.1235499382019, 67.41162031888962, 70.00109016895294, 68.0947856605053, 67.62557163834572, 57.58554898202419, 54.15026351809502, 56.256558895111084, 63.10784585773945, 64.10734802484512, 70.53129851818085, 66.6713972389698, 73.0028834939003, 76.402348279953, 67.23966434597969, 65.96098735928535, 71.13046556711197, 17.735198736190796, 0.5215784779284149, 1.9529258692637086, 1.2798781972378492, 0.4415820533176884, 0.08982157669379376, 0.18935065279947594, 0.1813000871334225, 0.1082682806008961, 0.04661545332055539, 0.06881257824716158, 9.074090737849474, 35.12982934713364, 35.551743507385254, 49.899431616067886, 35.198704451322556, 18.92986413091421, 40.14271795749664, 51.38638682663441, 62.504654824733734, 65.96587389707565, 72.24170073866844, 16.043683402240276, 0.20098475273698568, 0.046530859617632814, 0.05841856254846789, 0.057252403639722615, 0.03290894681413192, 0.01676204537943704, 0.024048532904998865, 0.05470443626109045, 0.04901718049950432, 0.05992907055770047, 0.07778958912240341, 0.101257263449952, 0.04416120806126855, 0.07558954428532161, 0.0777427373395767, 0.036451948690228164, 0.05302271849359386, 0.07655391324078664, 0.023282779366127215, 0.0340909951046342, 0.019000611391675193, 0.039600562158739194, 0.03986823998275213, 0.030467277247225866, 0.03807044660788961, 0.06866233045002446, 0.10992608265951276, 0.07643266857485287, 0.03266702522523701, 0.034810893193935044, 0.05589065913227387, 0.01690187713393243, 0.02910256414907053, 0.00765762537412229, 0.05042641132604331, 0.05143135349499062, 0.051991667569382116, 0.07638324896106496, 0.060107787139713764, 0.06676827310002409, 0.011412592048145598, 0.05497154263139237, 0.012034333685733145, 0.13250830059405416, 0.16355131374439225, 0.35711261560209095, 11.979577280580997, 96.09034582972527, 92.70951524376869, 93.33797872066498, 74.81579661369324, 48.857132345438, 38.50857764482498, 26.61777500063181, 40.85859954357147, 52.600520476698875, 33.1628192961216, 2.3287005303427577, 0.11652954941382632, 0.047767533687874675, 0.5821108329109848, 1.0364808328449726, 2.6214881194755435, 4.850478675216436, 3.157589239999652, 0.19373209972400218, 0.8838223025668412, 37.99145959317684, 100.77347293496132, 81.7539431154728, 79.2059974372387, 82.64339178800583, 81.76702961325645, 79.66476961970329, 80.92379406094551, 81.96091040968895, 73.89905780553818, 68.58372062444687, 56.632153540849686, 59.2882414162159, 57.356611266732216, 58.82394813001156, 65.58368280529976, 72.9697872698307, 74.81120645999908, 69.7422556579113, 66.19745627045631, 72.68109396100044, 71.31212621927261, 65.32647460699081, 57.07223832607269, 53.188717514276505, 51.457712799310684, 52.79147543013096, 52.14560888707638, 51.36444680392742, 50.894161239266396, 51.810941845178604, 50.08661337196827, 50.125093907117844, 48.54244463145733, 51.716144531965256, 49.3528613448143, 53.93163084983826, 50.98483197391033, 51.39149755239487, 49.830203130841255, 51.94446288049221, 50.883134230971336, 54.70481336116791, 56.866684556007385, 69.41312491893768, 57.99497701227665, 48.794070929288864, 75.64825594425201, 60.94162009656429, 62.052923664450645, 62.58102312684059, 68.474240899086, 71.16404056549072, 70.99621117115021, 64.83615651726723, 59.59567911922932, 51.62253275513649, 52.122958302497864, 56.56404599547386, 72.06691011786461, 73.79056602716446, 74.11876201629639, 64.80875998735428, 65.55823937058449, 60.447965785861015, 59.308220744132996, 54.05976377427578, 56.816827431321144, 64.97195363044739, 74.81064409017563, 68.37192758917809, 73.15464735031128, 69.02975589036942, 70.80701172351837, 61.01079538464546, 55.834523141384125, 60.30136585235596, 67.22217008471489, 67.14754968881607, 73.98299530148506, 70.20493403077126, 75.7543158531189, 78.08607593178749, 73.4740050137043, 71.04272827506065, 78.79204764962196, 21.981066204607487, 0.2394638184341602, 1.2220760551281273, 0.8888429019134492, 1.5479933540336788, 0.8254684775602072, 0.503657452063635, 0.427412316785194, 0.23781231720931828, 0.06553109808010049, 0.08862254064297304, 9.887544438242912, 41.05592295527458, 30.858246758580208, 38.15789446234703, 30.42028035968542, 28.80520172417164, 51.741029396653175, 58.600774705410004, 68.64315703511238, 74.56848308444023, 86.19818463921547, 25.097674168646336, 0.23229997081216425, 0.11291276692645624, 0.12218337884405628, 0.03901659212715458, 0.06120246238424443, 0.0029850775172235444, 0.01689888071268797, 0.02856354600226041, 0.06481664735474624, 0.03199287682946306, 0.06388500711182132, 0.02927759225713089, 0.05505479304702021, 0.06736354975146241, 0.08010043660760857, 0.031765801904839464, 0.015865354725974612, 0.07416144435410388, 0.04346414585597813, 0.05245550244580954, 0.06720427743857726, 0.04288748597900849, 0.03239523961383384, 0.07487422524718568, 0.10817774600582197, 0.1599838098627515, 0.1747074260492809, 0.20036402042023838, 0.21831985301105306, 0.17957616713829339, 0.26258309895638376, 0.11449630226707086, 0.10907253119512461, 0.13868155918316916, 0.151747083873488, 0.13553086027968675, 0.12161930950242095, 0.2046152055845596, 0.27279733680188656, 0.14544886245857924, 0.1880541059654206, 0.17210716323461384, 0.11649975218460895, 0.35182742576580495, 0.3920059057418257, 0.4912630218314007, 15.91536808758974, 111.67670667171478, 103.80125686526299, 103.01111966371536, 83.9351324737072, 56.21719680726528, 49.963598772883415, 33.04213397204876, 68.35949465632439, 72.15360626578331, 44.726286605000496, 3.6291802721098065, 0.2507658815011382, 0.3494087071157992, 0.7340810657478869, 3.122713048942387, 3.5300321923568845, 7.865533288568258, 5.03108630888164, 4.385015526786447, 3.2983163511380553, 38.11437539756298, 104.7895610332489, 83.24302241206169, 81.82145029306412, 87.05671817064285, 84.12642180919647, 81.63944005966187, 81.60873770713806, 84.87542241811752, 76.8279330432415, 71.37026309967041, 58.26784037053585, 62.534034848213196, 60.47012619674206, 62.08767279982567, 70.92261672019958, 75.5431155860424, 76.83327555656433, 71.90612554550171, 68.70451614260674, 76.23172223567963, 73.95820543169975, 69.50390204787254, 59.9427904933691, 55.71524374186993, 53.95824082195759, 56.64702594280243, 54.64464358985424, 56.02868132293224, 54.05136622488499, 54.41259764134884, 53.2053492218256, 52.53283850848675, 50.28411917388439, 55.99270485341549, 53.87239582836628, 57.21696496009827, 52.98826307058334, 54.34574402868748, 51.73167809844017, 55.34648112952709, 53.8196736574173, 57.14052826166153, 60.594086945056915, 71.50798290967941, 60.20040526986122, 54.857998341321945, 79.03208076953888, 65.34966096282005, 65.4690657556057, 66.67582780122757, 72.00676694512367, 73.07686552405357, 73.67195159196854, 66.67798608541489, 62.5047118216753, 53.851451352238655, 53.14818508923054, 59.005095809698105, 74.71709311008453, 75.80526351928711, 76.88445881009102, 69.59575071930885, 68.63316357135773, 65.27960792183876, 63.1361885368824, 56.774645894765854, 58.71946133673191, 70.34672722220421, 78.58913093805313, 71.32663384079933, 74.39449042081833, 72.59428381919861, 74.44921508431435, 62.71950289607048, 57.879774793982506, 63.15737619996071, 71.14621192216873, 71.14137098193169, 77.28109672665596, 73.7421490252018, 78.63756313920021, 82.30102255940437, 74.97094988822937, 74.94647160172462, 81.83040261268616, 21.529582031071186, 1.8607013742439449, 7.677138922736049, 5.818165149539709, 2.484170850366354, 0.48116981342900544, 0.46853673818986863, 1.3101699342951179, 0.429821684374474, 0.26909022009931505, 0.22056686837458983, 14.552034493535757, 56.85241252183914, 48.20411458611488, 67.62722834944725, 48.35947684943676, 30.29042422771454, 56.554196923971176, 65.92282980680466, 80.59523329138756, 82.3096252977848, 96.73770189285278, 27.22369808703661, 0.4317789355991408, 0.26595209317747504, 0.1762563773081638, 0.22597225644858554, 0.12951340817380697, 0.14563576492946595, 0.12150524140452035, 0.10032459162175655, 0.1782443534466438, 0.16110418568132445, 0.1797372428700328, 0.16473630093969405, 0.12208150423248298, 0.16468651767354459, 0.1619944957201369, 0.28495980135630816, 0.13003093743463978, 0.19326518493471667, 0.13633876224048436, 0.10342965586460195, 0.11568848829483613, 0.1717511549941264, 0.11919008204131387, 0.09854981224634685, 0.2595912344986573], [0.011589871646719985, 0.046342428322532214, 0.06191219676111359, 0.06704879750031978, 0.04002534522442147, 0.03238589968532324, 0.01761370436724974, 0.04142686884733848, 0.020906711943098344, 0.04648087597161066, 0.03206957037036773, 0.0585657378542237, 0.02524672290746821, 0.1217415115388576, 0.06521405259263702, 0.05721848749089986, 0.03144309754134156, 0.06744655896909535, 0.09340367119875737, 0.06652325304457918, 0.021547471114899963, 40.88865973055363, 93.65226745605469, 86.57829344272614, 70.72174429893494, 51.612402498722076, 68.16620662808418, 39.66391704976559, 49.09726046025753, 52.620302215218544, 37.11472123861313, 11.951458789408207, 0.05698200584447477, 0.09786436465219595, 0.10973296841257252, 0.5251941026654094, 0.5597382271662354, 1.4200848550535738, 0.8502811461221427, 0.5974573187995702, 1.033741773571819, 28.102315440773964, 99.53687489032745, 74.6053259074688, 83.79631072282791, 77.22283825278282, 75.53392767906189, 76.63947075605392, 77.73825779557228, 74.8908805847168, 79.89629879593849, 70.32094940543175, 61.77706226706505, 53.221175372600555, 52.633559703826904, 52.42506869137287, 54.48919013142586, 60.13648509979248, 67.57302805781364, 68.76808673143387, 66.34412840008736, 65.96886813640594, 67.1339464187622, 66.04867145419121, 63.023395389318466, 54.6163123100996, 50.96572279930115, 49.29731212556362, 48.517058193683624, 49.23125647008419, 50.78972004354, 48.60848888754845, 48.99478375911713, 49.37773860991001, 48.202400878071785, 47.19875693321228, 49.97126676142216, 53.6087241768837, 59.75090838968754, 59.29007291793823, 60.743707716464996, 53.07112902402878, 54.7773552685976, 52.53988333046436, 57.148732021450996, 58.220620304346085, 70.71676656603813, 57.48418562114239, 47.6346505433321, 69.70785230398178, 56.61126606166363, 59.780979976058006, 58.574107736349106, 67.4118635058403, 65.61911970376968, 68.77845257520676, 62.15160056948662, 54.03973124921322, 46.04022569954395, 49.36541207134724, 48.64430956542492, 53.980139046907425, 60.15344358980656, 61.535934805870056, 56.00942775607109, 55.57562403380871, 51.804090812802315, 53.68671879172325, 50.94037815928459, 52.964708134531975, 59.571136236190796, 67.34019935131073, 65.53503781557083, 66.67582780122757, 69.29521724581718, 66.02897331118584, 60.09564109146595, 53.33010032773018, 52.6820071041584, 59.7761694341898, 65.34925058484077, 68.19422632455826, 73.12041118741035, 69.32201340794563, 72.92357414960861, 76.40925630927086, 75.37760406732559, 61.62500582635403, 71.01542294025421, 19.01701245456934, 0.7550562964752316, 1.5695991134271026, 1.3710347120650113, 0.8217517426237464, 0.430111923487857, 0.11223138630157337, 0.2721396752167493, 0.1306971040321514, 0.022222465559025295, 0.29198283387813717, 21.396777257323265, 39.580135345458984, 61.123793721199036, 44.65849444270134, 22.984784245491028, 18.51440392434597, 45.74649766087532, 62.23895028233528, 60.20012408494949, 70.72416096925735, 61.181220039725304, 2.6870286650955677, 0.1972360015497543, 0.05534448297112249, 0.05374962245696224, 0.06020801047270652, 0.06862311536679044, 0.029926173665444367, 0.0702608423307538, 0.021942972744000144, 0.061501347518060356, 0.045876730655436404, 0.03603407501941547, 0.010049815027741715, 0.015247265382640762, 0.0077042456996423425, 0.07211185511550866, 0.034474080603104085, 0.02529248744394863, 0.040936799050541595, 0.020705981405626517, 0.07613267021952197, 0.0367103533790214, 0.06539141104440205, 0.06916129859746434, 0.016999406470858958, 0.016706918650015723, 0.031270050967577845, 0.05305734710418619, 0.0747741169470828, 0.029953801968076732, 0.015877507394179702, 0.0540772287058644, 0.015721409617981408, 0.016440060899185482, 0.045714189182035625, 0.051673007910721935, 0.033245110025745817, 0.021871028948226012, 0.05142125657584984, 0.011713405838236213, 0.036481155912042595, 0.01518656234111404, 0.08494781868648715, 0.025415249801881146, 0.0872950982011389, 0.06723316182615235, 51.17299787700176, 107.09691882133484, 93.80141705274582, 78.56910601258278, 55.55127114057541, 63.775344640016556, 36.122054904699326, 40.97575105726719, 43.19462679326534, 44.21072646975517, 15.331462919712067, 0.05907018305151723, 0.04742057964904234, 0.47991163562983274, 1.3070758315734565, 1.698261871933937, 2.5542585644870996, 2.204475221224129, 0.42340522399172187, 0.4723332094727084, 30.22524632513523, 102.98805490136147, 76.23357653617859, 85.64894691109657, 79.20484989881516, 78.14049661159515, 79.11216527223587, 80.88218629360199, 77.49143823981285, 81.73874393105507, 73.40118572115898, 65.20967647433281, 53.83093625307083, 55.74957109987736, 55.29414273798466, 56.573651880025864, 62.68039919435978, 68.87586414813995, 72.18567654490471, 69.0250289440155, 67.62200742959976, 68.6073325574398, 69.24716502428055, 68.24739307165146, 57.072318121790886, 52.323241755366325, 49.73759450018406, 51.531014665961266, 50.65907925367355, 53.63319106400013, 51.52565315365791, 51.087536662817, 52.725898548960686, 50.232799127697945, 49.19016167521477, 50.84090709686279, 56.54823884367943, 61.847350895404816, 62.45710797607899, 63.54740247130394, 56.39123126864433, 57.843646332621574, 55.969556495547295, 58.706268444657326, 60.37551887333393, 74.50738996267319, 60.73308348655701, 51.59431926906109, 73.31188291311264, 60.042109563946724, 62.86056652665138, 62.87467896938324, 69.74837332963943, 67.75856450200081, 70.12573108077049, 64.50460910797119, 55.559379905462265, 49.36598964035511, 51.48231267929077, 50.97919687628746, 55.98323576152325, 62.36959487199783, 63.40620964765549, 60.22237189114094, 57.150050550699234, 53.692809864878654, 55.509256795048714, 52.452032044529915, 57.39879660308361, 61.51766158640385, 68.98194685578346, 66.21858313679695, 68.74544754624367, 72.64438033103943, 68.84397625923157, 63.86604577302933, 56.81246906518936, 55.9121947735548, 62.239752039313316, 67.42701709270477, 71.03259041905403, 75.59126660227776, 72.94930636882782, 75.95577344298363, 77.06440955400467, 77.2838705778122, 64.84851345419884, 78.48528251051903, 23.843695856630802, 0.44422507868148386, 0.6488251592963934, 1.3189411698840559, 1.7000085907056928, 1.5341156674548984, 0.7658689131494612, 0.4736735875485465, 0.993738470133394, 0.06415273688617162, 0.13575348973972723, 24.650802947580814, 38.14074218273163, 51.21284633874893, 41.54585726559162, 29.480478689074516, 31.967050060629845, 60.54350025951862, 71.44622102379799, 67.41339102387428, 77.60127514600754, 75.52488416433334, 4.885886600241065, 0.28056940413080156, 0.057546687457943335, 0.062316641269717366, 0.041340275056427345, 0.03831415677268524, 0.06766706588678062, 0.05094509462651331, 0.015185343363555148, 0.07599250820931047, 0.0103421367930423, 0.02725477228523232, 0.04006543233117554, 0.011111916483059758, 0.029164238476369064, 0.07519567909184843, 0.030051210706005804, 0.03887820384989027, 0.028566204746311996, 0.03773581964196637, 0.06631824217038229, 0.020726935945276637, 0.029863195013604127, 0.029285744749358855, 0.015216859592328547, 0.09694526670500636, 0.12303614363190718, 0.1137103233486414, 0.1529908343218267, 0.07062403456075117, 0.1383568547316827, 0.1382891708635725, 0.10503624973352998, 0.11831756128231063, 0.09186016730382107, 0.1984244174673222, 0.09562388760969043, 0.08722814163775183, 0.17608170543098822, 0.17442005162592977, 0.1610238110879436, 0.15727682621218264, 0.10487841718713753, 0.14848029823042452, 0.15592412848491222, 0.10208040912402794, 62.51222021877766, 119.82875123620033, 108.25600862503052, 92.77513012290001, 66.81997686624527, 80.53165510296822, 53.046525344252586, 67.77384728193283, 75.92874929308891, 56.28574512898922, 20.534411631524563, 0.2894283615751192, 0.27585252129938453, 0.7047735352534801, 4.154009772464633, 2.282386478036642, 5.307205142453313, 4.252140456810594, 4.894689777866006, 4.789158990606666, 28.97509440779686, 105.33167034387589, 80.3014862537384, 90.06448477506638, 83.11230182647705, 79.83177825808525, 81.5021002292633, 82.62091219425201, 81.5124736726284, 86.41539618372917, 75.96960470080376, 67.39806264638901, 57.03438475728035, 57.60405018925667, 59.6724957972765, 60.53502291440964, 64.72168385982513, 73.124218583107, 74.59226220846176, 72.61870890855789, 68.91976699233055, 70.12893050909042, 72.80889630317688, 71.587725430727, 61.30927696824074, 55.85827946662903, 53.931801840662956, 52.75083281099796, 53.51786345243454, 56.291178837418556, 53.10943476855755, 53.322139754891396, 54.5760914683342, 54.00519110262394, 51.7536561191082, 54.4320297986269, 59.83157426118851, 65.23501351475716, 65.53939998149872, 65.73561385273933, 59.96995523571968, 60.96232898533344, 60.015074014663696, 61.57899409532547, 63.42274636030197, 78.44843968749046, 66.433514803648, 54.9966187030077, 76.49600565433502, 62.81705506145954, 65.63839986920357, 66.27467572689056, 72.70876407623291, 71.06627941131592, 72.16542363166809, 67.75116249918938, 58.82259540259838, 51.115795746445656, 54.74208936095238, 53.35587814450264, 59.86320376396179, 66.0299764573574, 67.74281814694405, 62.13435709476471, 60.0258844345808, 59.21632647514343, 59.28758405148983, 56.69932633638382, 59.331665486097336, 66.5867605805397, 72.35912203788757, 67.9005628824234, 70.01191958785057, 76.90945386886597, 71.8089647591114, 66.03938475251198, 60.705417171120644, 57.30913281440735, 67.34057933092117, 72.30543851852417, 73.44975471496582, 78.81647273898125, 75.3335340321064, 78.38829651474953, 82.99669682979584, 81.65685832500458, 69.75437700748444, 82.64912188053131, 26.117788329720497, 2.026650463230908, 8.540557567030191, 5.462614428251982, 3.6200885474681854, 1.545068935956806, 1.0624257219024003, 0.9274564892984927, 1.0956338024698198, 0.13971421314636245, 0.5645799986086786, 34.635289683938026, 57.20062203705311, 77.9938168823719, 58.894647136330605, 32.8635473549366, 29.536757469177246, 63.528840467333794, 80.46483188867569, 78.81335690617561, 87.06283584237099, 88.34221199154854, 6.585379606112838, 0.48874164931476116, 0.19990483880974352, 0.19865691749146208, 0.19101865938864648, 0.1480849413201213, 0.11318923177896068, 0.18373777507804334, 0.10555930057307705, 0.09361282325698994, 0.12016385400784202, 0.11026634994777851, 0.13071191729977727, 0.05356577763450332, 0.1287866081111133, 0.1735865604132414, 0.08386300658457913, 0.10537500304053538, 0.142173171043396, 0.1398859015898779, 0.12633921287488192, 0.09630880827899091, 0.09083053388167173, 0.1247362035792321, 0.09020125202368945], [0.014354471932165325, 0.05702274233044591, 0.0839990125678014, 0.04381628750707023, 0.02955205702164676, 0.04926198904286139, 0.04260823807271663, 0.011279301397735253, 0.053528429052676074, 0.025303784786956385, 0.05152347257535439, 0.010639534848451149, 0.02943968658655649, 0.04491059538850095, 0.05071218642115127, 0.07942483731312677, 0.02297253937285859, 0.058612875363905914, 0.04770027655467857, 0.09316478128312156, 3.884087693877518, 67.74238497018814, 81.25354036688805, 75.47370851039886, 69.95765089988708, 63.0226544290781, 58.26930329203606, 47.91539087891579, 60.34591466188431, 37.41968147456646, 36.274244338274, 1.8956684041768312, 0.10769364307634532, 0.11126983750727959, 0.4418163048103452, 0.37166150053963065, 0.565044404938817, 1.621309113688767, 2.061116276308894, 1.958192742895335, 10.106808822602034, 91.32120653986931, 73.0693419277668, 89.4462351500988, 74.24822866916656, 72.7449381351471, 71.37475445866585, 77.03265085816383, 75.36244288086891, 77.3314668238163, 68.22541505098343, 66.95457324385643, 56.42563462257385, 51.54067374765873, 52.54346653819084, 51.477452740073204, 51.68547637760639, 61.58837579190731, 66.54086664319038, 68.6682964861393, 67.77137741446495, 64.31186825037003, 64.91758614778519, 68.2451967895031, 63.19455340504646, 54.712169766426086, 48.3715146034956, 46.800348311662674, 47.80507139861584, 51.2388027459383, 52.392314448952675, 51.53406970202923, 49.218660145998, 47.92847737669945, 46.786919832229614, 48.78401666879654, 56.824278831481934, 67.68050909042358, 70.78827112913132, 66.63754865527153, 65.54468929767609, 62.77461513876915, 62.576729357242584, 60.342225059866905, 62.80542768537998, 62.14741699397564, 67.00783878564835, 56.437075808644295, 52.23143108189106, 68.29457134008408, 55.71309305727482, 58.263907581567764, 59.45964261889458, 65.72479203343391, 65.6115049123764, 65.83237186074257, 58.136781603097916, 52.609943971037865, 45.375546365976334, 46.575138196349144, 47.23279930651188, 47.46733032166958, 46.0307452082634, 49.58521507680416, 49.15069319307804, 50.03845475614071, 47.69857071340084, 49.17075991630554, 49.26132045686245, 50.87641999125481, 58.261601105332375, 64.69668120145798, 67.03034117817879, 64.11471202969551, 66.41316309571266, 65.33970549702644, 59.075129851698875, 55.51325038075447, 52.29377053678036, 54.91903446614742, 60.84488868713379, 68.44522565603256, 70.4115441441536, 72.53051564097404, 69.12734225392342, 67.72389516234398, 69.0904538333416, 77.16239869594574, 60.43974682688713, 67.78214603662491, 8.164924923330545, 0.7176182116381824, 1.165683874860406, 1.9789557787589729, 0.6405222485773265, 0.3887157276039943, 0.3749576455447823, 0.6998620613012463, 0.40692150068935007, 0.116821228293702, 3.5046835150569677, 27.37433720380068, 36.95630393922329, 46.72960750758648, 40.243005976080894, 36.800926476716995, 26.575230583548546, 34.221123307943344, 47.6775236427784, 57.20846101641655, 68.99455457925797, 24.721671044826508, 0.3524052619468421, 0.035630239071906544, 0.0993284884316381, 0.028109056620451156, 0.04545398107438814, 0.036217775123077445, 0.043087127414764836, 0.02628053833177546, 0.039840784229454584, 0.002699769047467271, 0.042243498464813456, 0.04423060629051179, 0.05002537327527534, 0.03304021789517719, 0.045417229921440594, 0.011427990684751421, 0.04086367152922321, 0.04593497440509964, 0.016978748790279496, 0.03793450370721985, 0.047097693459363654, 0.10813813016284257, 0.01856697450421052, 0.030773194230278023, 0.05943562398897484, 0.10339895321521908, 0.042513707012403756, 0.04776302885147743, 0.043013521208195016, 0.10302781258360483, 0.05302734578435775, 0.024489671050105244, 0.06041757813363802, 0.025318746484117582, 0.028044918362866156, 0.010722272254497511, 0.05505444423761219, 0.05007301544537768, 0.061260424117790535, 0.026462520363566, 0.025094961129070725, 0.014006944584252778, 0.11518657382111996, 0.16396865306887776, 6.026411550119519, 84.44101452827454, 92.62037202715874, 87.0229759812355, 81.09633520245552, 71.3544711470604, 68.77880975604057, 41.73343040049076, 38.68240311741829, 46.74322597682476, 42.467976585030556, 2.558675827458501, 0.15513194521190599, 0.050868122780229896, 0.8097751415334642, 0.7371589599642903, 1.8429369712248445, 1.7406674777157605, 0.4734516853932291, 1.1833808314986527, 10.92327481135726, 96.67191222310066, 76.99296578764915, 90.32379046082497, 76.48068487644196, 76.89298555254936, 75.22768691182137, 79.34771463274956, 78.1780081987381, 81.1673229932785, 70.49460008740425, 70.04061564803123, 59.281139597296715, 54.849919974803925, 55.302072912454605, 54.871434420347214, 54.285209476947784, 64.76882413029671, 69.22030046582222, 73.21995064616203, 70.9120836853981, 66.16299971938133, 66.14670619368553, 69.3571463227272, 67.31125250458717, 57.96270914375782, 50.78820392489433, 51.26076556742191, 49.86552983522415, 54.41116511821747, 55.47651395201683, 54.07599650323391, 51.622563153505325, 49.55504089593887, 49.856030344963074, 49.824321046471596, 60.73154836893082, 69.75213512778282, 71.21070206165314, 69.34194713830948, 68.41142266988754, 64.30254355072975, 63.74503746628761, 63.73695529997349, 67.15768754482269, 66.02638944983482, 68.60020413994789, 61.31770871579647, 55.263056606054306, 70.54063841700554, 59.35501143336296, 58.71137537062168, 63.7651763856411, 67.49476745724678, 67.49696373939514, 68.52233111858368, 59.871491119265556, 54.234881177544594, 48.69602859020233, 50.56124970316887, 49.424141719937325, 50.914835929870605, 49.650826156139374, 51.85223042964935, 51.30369186401367, 52.18189314007759, 50.32503917813301, 52.45221063494682, 51.29040777683258, 53.67297112941742, 60.32344646751881, 66.81387439370155, 69.2525227367878, 65.56558817625046, 70.22983029484749, 67.72780895233154, 62.19418108463287, 57.346655800938606, 55.77465735375881, 58.245170786976814, 65.03785729408264, 70.97684741020203, 71.98174148797989, 73.27700838446617, 70.68038731813431, 69.68649744987488, 72.42703199386597, 77.52880543470383, 66.77608162164688, 75.28492704033852, 12.094432767480612, 0.5495592264924198, 0.46023124479688704, 0.9936714987270534, 2.318421369418502, 1.0555692273192108, 0.9938683756627142, 0.6695712148211896, 0.5024827807210386, 0.05524056374270003, 2.7701323432847857, 32.54938781261444, 34.61290128529072, 41.26145772635937, 35.485098883509636, 36.261708810925484, 40.622176229953766, 45.64535848796368, 54.090724512934685, 64.91748735308647, 78.45722481608391, 37.57757820188999, 0.28992129606194794, 0.011231072930968367, 0.12169088964583352, 0.009301782120019197, 0.06887130439281464, 0.05100344598758966, 0.03743207715160679, 0.009940669224306475, 0.06812243285821751, 0.031736954624648206, 0.08461969293421134, 0.023741602890368085, 0.058888397688861005, 0.04279896260413807, 0.03260314115323126, 0.038863936060806736, 0.07305855353479274, 0.07203077548183501, 0.0381215063680429, 0.017138067487394437, 0.03120668639894575, 0.010298248962499201, 0.06628571383771487, 0.03632985426520463, 0.08490230276947841, 0.14710857183672488, 0.16113707766635343, 0.18845681013772264, 0.16642173315631226, 0.14962500164983794, 0.14874214277369902, 0.08226667661801912, 0.21107114822370932, 0.13363047241000459, 0.12363897534669377, 0.13850574439857155, 0.14832413551630452, 0.1319607291952707, 0.20187411282677203, 0.146261113404762, 0.18469315662514418, 0.1798753862385638, 0.17676274466793984, 0.2775153476977721, 7.047890787944198, 101.44441813230515, 103.17360654473305, 96.81613728404045, 90.50897732377052, 83.53522673249245, 72.47684732079506, 69.20224383473396, 82.6894149184227, 54.94369514286518, 57.76362642645836, 3.8953334279358387, 0.3041252901311964, 0.368704249849543, 1.7943543219007552, 1.3691265019588172, 2.691803821362555, 4.080193508416414, 6.718325922265649, 6.851836508139968, 10.6653456017375, 98.27908158302307, 78.65949556231499, 95.73420614004135, 79.38820526003838, 78.25249940156937, 77.7663154900074, 82.83367797732353, 80.40925607085228, 83.55712875723839, 72.564607411623, 73.50331664085388, 62.077466547489166, 56.68763816356659, 59.93579126894474, 57.24233239889145, 57.488274201750755, 67.64913037419319, 72.35851407051086, 76.47621631622314, 72.6392126083374, 68.31295475363731, 68.0096398293972, 74.03833553195, 70.24255201220512, 61.454254388809204, 52.18580313026905, 52.14122772216797, 52.647022381424904, 56.72710284590721, 59.000209271907806, 56.15447737276554, 53.988696187734604, 53.50813217461109, 52.071809247136116, 53.20836625993252, 63.461789265275, 75.55139154195786, 76.07669815421104, 71.44112929701805, 72.42387816309929, 68.73997583985329, 67.5614082813263, 66.43897891044617, 71.1725065112114, 71.31089508533478, 71.16523370146751, 66.35125681757927, 58.316774144768715, 72.26875528693199, 62.392226457595825, 62.90231108665466, 65.6659559905529, 71.4862708747387, 70.94267964363098, 69.67265859246254, 63.859510123729706, 56.747944727540016, 50.274216905236244, 51.90831542015076, 53.07407006621361, 54.570859149098396, 51.71947315335274, 54.48815278708935, 56.54294192790985, 55.480051562190056, 51.792273446917534, 55.911605805158615, 55.30201971530914, 55.136177614331245, 62.58657082915306, 71.13379418849945, 72.01125830411911, 66.86281576752663, 71.33354187011719, 70.25438457727432, 64.39221113920212, 59.695362970232964, 58.10771316289902, 60.533408001065254, 67.49294355511665, 74.56652238965034, 76.48447707295418, 78.63245621323586, 75.5467101931572, 73.90219643712044, 75.72742089629173, 82.45750576257706, 68.04332122206688, 80.65576404333115, 12.891254760324955, 2.13174213655293, 9.394775480031967, 6.872918726876378, 4.344847882166505, 1.2718992191366851, 2.067584954202175, 2.111998158507049, 1.2679314007982612, 0.31773060851264745, 5.512682916596532, 45.87757162749767, 51.514025777578354, 60.626218020915985, 53.32256533205509, 47.891216576099396, 37.875638008117676, 48.63746613264084, 64.39531937241554, 74.19981926679611, 88.93450900912285, 41.019163727760315, 0.5633324780501425, 0.1372076093684882, 0.2683776989579201, 0.14368716714670882, 0.21478921902598813, 0.13583754538558424, 0.13416884117759764, 0.21625340217724442, 0.1152572114369832, 0.10021400419645943, 0.12126490430091508, 0.17133334069512784, 0.18090999947162345, 0.11976716123172082, 0.12679545558057725, 0.07633267901837826, 0.10681572690373287, 0.1340695418184623, 0.1912253475165926, 0.11772065932746045, 0.12589718971867114, 0.1839366409694776, 0.17207774450071156, 0.17386871011694893], [0.022958863446547184, 0.01439626690626028, 0.02470495139277773, 0.010911525478149997, 0.015416566893691197, 0.03889272025844548, 0.09703708521556109, 0.03452320335782133, 0.0922361838456709, 0.016330701728293207, 0.05469998337503057, 0.09595599869498983, 0.027827680605696514, 0.04452660446986556, 0.03428508156503085, 0.016943847440415993, 0.039784288237569854, 0.060352291402523406, 0.08805626712273806, 0.11442582050221972, 14.509743712842464, 82.48448431491852, 77.15032294392586, 69.92935001850128, 39.00111101567745, 54.13434997200966, 21.562404669821262, 29.590744972229004, 52.80175007879734, 44.20031502842903, 14.594023190438747, 0.10004280557041056, 0.06893405297887512, 0.1605455414392054, 0.3116704383864999, 0.21490613697096705, 1.0969342826865613, 1.0754632973112166, 1.1054860800504684, 1.3506733858957887, 69.13759410381317, 77.9268416762352, 84.30123522877693, 74.66754376888275, 73.90123128890991, 68.38913306593895, 66.49890929460526, 73.69595870375633, 76.83791130781174, 69.8448121547699, 65.74867755174637, 56.17063790559769, 54.49153080582619, 53.62152189016342, 53.30052651464939, 50.02115048468113, 51.65147200226784, 58.038268089294434, 65.23586466908455, 67.34415113925934, 66.34331524372101, 64.02626037597656, 64.21102166175842, 65.76456069946289, 62.16265797615051, 52.164531871676445, 48.073542192578316, 49.17806692421436, 51.73229746520519, 56.44753284752369, 57.28778935968876, 52.802346646785736, 49.423070177435875, 46.826152727007866, 46.342940255999565, 52.743939980864525, 63.14718894660473, 69.44869101047516, 65.8644725382328, 62.309261709451675, 68.26519131660461, 62.83644922077656, 67.3294535279274, 63.56187589466572, 63.07331331074238, 59.59026820957661, 64.8959045112133, 57.13319465517998, 50.615620985627174, 67.80268013477325, 56.69513896107674, 59.77080412209034, 61.550271436572075, 65.4637536406517, 64.2893734574318, 63.70014667510986, 57.305314019322395, 48.35130348801613, 49.15262348949909, 47.45674408972263, 46.01820968091488, 49.09469559788704, 48.164421916007996, 48.65837261080742, 48.216866701841354, 47.83713027834892, 45.72306051850319, 48.043622598052025, 48.434959799051285, 49.28432822227478, 55.288051664829254, 63.40635024011135, 66.10086545348167, 63.52233901619911, 65.37107661366463, 66.84117212891579, 62.31441803276539, 58.7065876275301, 52.14495912194252, 52.39530108869076, 56.91713444888592, 62.82999336719513, 63.64226438105106, 64.65513423085213, 60.26243694126606, 62.38347552716732, 61.657486483454704, 67.51854658126831, 69.65764179825783, 69.03641313314438, 55.410625487565994, 1.7274681734852493, 1.0810891329310834, 2.1182872960343957, 2.232301365584135, 0.323524406994693, 0.07914377114502713, 1.1308799986727536, 0.054449645831482485, 0.09383173455717042, 0.1324788373312913, 7.685963474214077, 36.39920823276043, 36.65148429572582, 106.1766842007637, 156.4651009440422, 34.83158715069294, 27.072811983525753, 56.47671528160572, 60.54916575551033, 62.74032197892666, 66.51260375976562, 6.45849633961916, 0.5255629203747958, 0.057442155957687646, 0.061185853119241074, 0.09971360370400362, 0.05256177428236697, 0.028858594232588075, 0.03406982163141947, 0.05382757764891721, 0.052586317106033675, 0.030640800650871824, 0.09193630423396826, 0.031042441696627066, 0.024907271981646772, 0.0671655818587169, 0.05044061232183594, 0.0583245435700519, 0.0077951054481673054, 0.06792073196265846, 0.03234066207369324, 0.001254352839623607, 0.04967582914105151, 0.05480726082168985, 0.05224216838541906, 0.028059787291567773, 0.038662272272631526, 0.02688465396204265, 0.02201247487391811, 0.05755576763476711, 0.057268894161097705, 0.024593918678874616, 0.011179032608197303, 0.0800748250912875, 0.015118286610231735, 0.03556953510269523, 0.022044741599529516, 0.054399049913627096, 0.02612177253467962, 0.014328930919873528, 0.08620618202257901, 0.03919326038158033, 0.026424451898492407, 0.04038872670207638, 0.12659529835218564, 20.438905656337738, 100.87419793009758, 83.60866919159889, 82.76243939995766, 45.40793962776661, 65.69810226559639, 31.84179738163948, 36.94826737046242, 54.61535096168518, 45.449277609586716, 18.182936310768127, 0.22963260300457478, 0.03527467240928672, 0.4694556357571855, 0.9193958155810833, 1.0203774156980217, 2.313137990422547, 1.1735340161249042, 0.29918757383711636, 1.6822200827300549, 73.63692507147789, 82.01356798410416, 85.616724640131, 77.63908311724663, 78.31539362668991, 70.58724671602249, 72.09743767976761, 76.77716016769409, 80.42023748159409, 73.33500847220421, 67.6649983227253, 58.680129647254944, 56.809566020965576, 57.21154645085335, 55.6620541960001, 53.884087800979614, 55.94201177358627, 60.899218171834946, 68.71381804347038, 70.87629720568657, 70.38514316082001, 63.32503840327263, 67.70640090107918, 68.43684330582619, 64.80496019124985, 55.20665243268013, 51.8053637444973, 49.40527193248272, 56.01047269999981, 59.72742184996605, 60.01971736550331, 58.14424820244312, 51.70324422419071, 49.56658847630024, 49.738954827189445, 55.42621225118637, 68.22179764509201, 70.42257875204086, 69.58341658115387, 64.63709279894829, 69.9279136955738, 65.11514514684677, 68.68565395474434, 66.11677899956703, 65.21718487143517, 61.377791091799736, 68.74469518661499, 60.0992850959301, 54.074320793151855, 69.45328876376152, 60.683807730674744, 63.24366196990013, 64.1490849852562, 67.1502323448658, 66.47057041525841, 66.9101232290268, 59.25333268940449, 50.00501275062561, 50.46473868191242, 50.309178829193115, 48.94163221120834, 49.59072098135948, 48.580678179860115, 52.05189451575279, 49.28592413663864, 50.47271065413952, 48.656989485025406, 49.39662739634514, 50.738897770643234, 51.63256801664829, 56.02164410054684, 66.30787834525108, 69.1378752887249, 65.12421146035194, 68.6633263528347, 68.10278043150902, 65.3197717666626, 60.85826396942139, 54.678074195981026, 55.13466529548168, 59.63805064558983, 65.21715447306633, 65.72542279958725, 67.75150448083878, 63.178890645504, 63.03684286773205, 63.272529020905495, 71.63602083921432, 73.52727055549622, 71.65413826704025, 60.337935090065, 2.9951747925952077, 1.1472484515979886, 0.7047938404139131, 0.6848254369106144, 1.475865743122995, 0.6508801365271211, 1.955810389481485, 0.33452282776124775, 0.25497961789369583, 0.13349192828172818, 7.5374493934214115, 38.607718124985695, 31.055157892405987, 82.61100992560387, 126.0402399301529, 34.83854457736015, 33.61150301992893, 61.242001578211784, 67.84953162074089, 69.23748314380646, 79.51378852128983, 11.26360259950161, 0.46711528790183365, 0.03162385502946563, 0.09683546595624648, 0.061565554424305446, 0.05718370302929543, 0.04212182706396561, 0.02600306601379998, 0.04518570211075712, 0.06458963180193678, 0.02874312904168619, 0.027351153148629237, 0.012214389844302787, 0.052772718627238646, 0.07396417408017442, 0.049142351126647554, 0.044437728574848734, 0.007770227266519214, 0.036523295057122596, 0.04458852927200496, 0.021826895281265024, 0.03551437497662846, 0.0673455378273502, 0.03574075599317439, 0.10410318456706591, 0.18951586971525103, 0.0988392646831926, 0.1144094709889032, 0.09796681071748026, 0.17003278626361862, 0.22173576580826193, 0.09670736384578049, 0.11618270669714548, 0.10608598051476292, 0.16928110941080377, 0.16531434492208064, 0.21917926002060995, 0.09175777318887413, 0.08966975554358214, 0.2083089339430444, 0.11186385992914438, 0.11474636892671697, 0.08829312355373986, 0.23921457555843517, 26.21291622519493, 117.733543664217, 95.07067054510117, 96.41123861074448, 54.914584904909134, 75.06065547466278, 30.232965610921383, 44.847891479730606, 72.17718780040741, 67.91521489620209, 24.003057405352592, 0.40126814623363316, 0.16183353873202577, 0.5791162967216223, 1.3519396679475904, 1.6462546563707292, 4.046436119824648, 4.467956526204944, 4.36262427829206, 1.5644545457325876, 75.7266229391098, 84.82743099331856, 89.69146639108658, 78.38430672883987, 80.41285827755928, 74.65030789375305, 74.19117093086243, 82.04770535230637, 83.73143300414085, 75.55555611848831, 71.65737569332123, 61.04588270187378, 60.15429474413395, 59.0297868847847, 59.67605620622635, 55.68758122622967, 58.318909630179405, 63.50074477493763, 71.78195580840111, 74.04740184545517, 72.84147575497627, 65.75498521327972, 69.1144685447216, 71.31364613771439, 68.16866129636765, 58.597833663225174, 53.95839661359787, 53.24879989027977, 58.40710289776325, 62.291501462459564, 63.13287511467934, 59.909709468483925, 54.92943450808525, 51.57171048223972, 52.46347703039646, 57.855524495244026, 69.79286134243011, 71.88997641205788, 70.51410064101219, 68.45256686210632, 71.88160166144371, 67.34133929014206, 72.68787279725075, 69.86619740724564, 68.10158729553223, 66.00185036659241, 70.78455492854118, 65.20278364419937, 57.414938136935234, 72.92662158608437, 63.51010747253895, 64.77384746074677, 66.04079067707062, 68.65437403321266, 67.09957346320152, 70.96791788935661, 62.98698954284191, 51.695906817913055, 53.11661638319492, 52.6044000685215, 51.002216041088104, 53.192946687340736, 52.60977678000927, 54.7160417586565, 53.21031175553799, 53.019041419029236, 52.406103909015656, 51.643804013729095, 52.95352153480053, 53.84414054453373, 59.76505123078823, 71.00078612565994, 72.55725100636482, 67.10405722260475, 71.38312920928001, 71.39413341879845, 67.77846023440361, 63.46065692603588, 56.869994178414345, 58.077835366129875, 63.380439430475235, 67.87666976451874, 68.46297070384026, 69.34548854827881, 66.49915248155594, 67.21994340419769, 67.92969971895218, 75.43657690286636, 76.43069475889206, 75.05946233868599, 63.998727053403854, 3.3029067423194647, 4.353262530639768, 10.270965714007616, 8.042542040348053, 2.8825538232922554, 0.4478647786891088, 4.102527284994721, 0.8302608516532928, 0.43846396438311785, 0.24930390994995832, 13.588543944060802, 56.499590054154396, 52.347218468785286, 117.98511296510696, 156.2068971991539, 42.77634143829346, 40.31825713813305, 73.57875779271126, 78.76997083425522, 78.37316572666168, 86.93377956748009, 11.504199989140034, 0.8401379466522485, 0.18873645138228312, 0.14655769045930356, 0.24823480169288814, 0.19382109807338566, 0.12252492262632586, 0.1052328001242131, 0.14929246011888608, 0.09153485429123975, 0.13269518822198734, 0.10068526054965332, 0.10055159233161248, 0.14458973746513948, 0.16112521814648062, 0.11832358009996824, 0.1638729457044974, 0.10126412831596099, 0.20210644957842305, 0.15576030680676922, 0.09007153945276514, 0.12005290293018334, 0.1394157955655828, 0.15211428370093927], [0.08682931889779866, 0.036075453463126905, 0.020946062468283344, 0.04157124996709172, 0.031253285851562396, 0.004493856786211836, 0.044681223516818136, 0.07870782617828809, 0.04636094861780293, 0.028721640155708883, 0.039642920237383805, 0.00578740256059973, 0.03880014475726057, 0.028930927655892447, 0.01424810454409453, 0.060172042285557836, 0.023644967841391917, 0.05215658762608655, 0.1244558572943788, 0.32639714190736413, 47.99914978444576, 89.63697731494904, 67.62208342552185, 62.99115031957626, 83.83294075727463, 66.76129281520844, 33.83200138807297, 36.45878903567791, 30.65393552184105, 45.24750843644142, 1.796434591524303, 0.18095472129061818, 0.02543900965974899, 0.21519015688681975, 0.3408772742841393, 0.3742519224761054, 1.4241065829992294, 0.5572796997148544, 0.09374874760396779, 43.21493290364742, 83.81682962179184, 77.82789498567581, 78.19151267409325, 74.90386068820953, 67.3871648311615, 56.71390615403652, 60.39567679166794, 59.150787591934204, 63.115859627723694, 58.12164321541786, 55.378589406609535, 56.12172693014145, 56.559691429138184, 54.33331489562988, 53.43918487429619, 51.37487344443798, 53.19808401167393, 55.404667407274246, 61.94828487932682, 67.50009477138519, 69.47175577282906, 64.28060352802277, 65.83622485399246, 66.86358332633972, 62.45256721973419, 48.73472571372986, 47.96296812593937, 48.2795899361372, 57.65448488295078, 63.35847280919552, 62.77776516973972, 58.61754320561886, 53.447791412472725, 47.60255366563797, 46.902015656232834, 54.123995527625084, 64.71172839403152, 64.84532162547112, 60.301251858472824, 64.83634650707245, 64.08875942230225, 63.11977341771126, 64.94207963347435, 62.2706937789917, 60.23912139236927, 56.29577279090881, 64.77255553007126, 54.72763113677502, 49.0610446035862, 67.74480924010277, 56.16960056126118, 59.2752081155777, 58.19807231426239, 64.61878538131714, 60.48065543174744, 63.11305157840252, 50.06323702633381, 45.441731214523315, 46.226780489087105, 49.08893130719662, 48.49704846739769, 46.94146893918514, 46.95518620312214, 46.436065658926964, 48.151772394776344, 47.38104075193405, 45.777990370988846, 47.97795072197914, 46.128935739398, 48.03875505924225, 50.03599628806114, 59.378433376550674, 64.46394369006157, 64.75777432322502, 63.69064338505268, 66.34089857339859, 63.57512578368187, 63.30004334449768, 56.821801364421844, 52.6032829284668, 51.16341479122639, 54.70520094037056, 56.43484152853489, 57.665694281458855, 59.14232164621353, 56.06369264423847, 64.89879235625267, 69.70035150647163, 71.41308680176735, 67.70990431308746, 72.50112041831017, 50.76231591403484, 1.29553442588076, 0.2965341880917549, 1.2468950171023607, 0.7879760081414133, 0.6863751006312668, 0.2915578504325822, 0.3902799967909232, 0.3419621754437685, 0.037969354962115176, 0.2836322772782296, 15.027723368257284, 41.11796222627163, 71.60819873213768, 89.47594195604324, 44.40223999321461, 33.170365691185, 46.64992198348045, 49.54478904604912, 57.78456710278988, 63.58473926782608, 41.58255949616432, 0.8154301287140697, 0.10488307787454687, 0.11078591269324534, 0.018268623716721777, 0.052618403860833496, 0.09467122232308611, 0.03143724941764958, 0.0037503291787288617, 0.053970155349816196, 0.029792674285999965, 0.03508025940391235, 0.11412305393605493, 0.033690836498863064, 0.04790172512002755, 0.03174013843818102, 0.07253643780131824, 0.02452724969771225, 0.12271655999938957, 0.021425152190204244, 0.10964574379613623, 0.021400948899099603, 0.062285025778692216, 0.05721852459828369, 0.03489565016934648, 0.015562885018880479, 0.034745524826576, 0.0719665277574677, 0.0412085995048983, 0.04760572322993539, 0.052430670184548944, 0.03572533045371529, 0.037427204952109605, 0.05503457323356997, 0.07356320653343573, 0.023553160463052336, 0.04083082778379321, 0.052728683294844814, 0.03272054891567677, 0.058845408784691244, 0.006892999435876845, 0.09957582398783416, 0.08730096858926117, 0.5758931196760386, 62.00998596847057, 101.80353686213493, 76.52912467718124, 72.45584964752197, 80.8442035317421, 80.317772179842, 41.409934759140015, 31.114960983395576, 34.79846052825451, 48.76695178449154, 2.436059257015586, 0.22370113612851128, 0.07059070470859297, 1.3243285682983696, 0.9193272411357611, 1.7601173277944326, 1.7754351370967925, 0.3405364800710231, 0.23867384676123038, 45.18786683678627, 87.91816994547844, 78.75693753361702, 81.6999252140522, 76.41235694289207, 71.81978657841682, 58.443884924054146, 60.752599239349365, 61.586434096097946, 66.5425081551075, 58.94937179982662, 59.02881793677807, 57.82001540064812, 58.71222272515297, 57.47469753026962, 57.227691784501076, 54.665417075157166, 56.085955649614334, 58.31332392990589, 65.50869762897491, 70.40072232484818, 72.86539927124977, 63.679969757795334, 70.00163733959198, 68.77064779400826, 65.828967243433, 53.45507562160492, 51.78454466164112, 51.705425307154655, 60.856934040784836, 66.66750624775887, 64.69427213072777, 60.34372977912426, 55.81299729645252, 49.60618615150452, 50.275554433465004, 57.510123029351234, 67.20668211579323, 68.05172637104988, 63.03458958864212, 66.36332497000694, 66.67898923158646, 64.40048709511757, 67.24307656288147, 64.36196476221085, 63.89867082238197, 58.73961165547371, 66.88237711787224, 56.150871366262436, 53.082239627838135, 68.08823481202126, 59.73803088068962, 61.98470212519169, 62.32959441840649, 67.00675964355469, 63.928385227918625, 65.48281341791153, 53.72985027730465, 48.95357497036457, 48.688398599624634, 50.0603149831295, 50.90509705245495, 50.342252254486084, 49.86642278730869, 49.239783212542534, 50.90716414153576, 49.819784089922905, 48.92416834831238, 50.49663037061691, 48.86585287749767, 49.066976085305214, 52.75187015533447, 63.11429791152477, 66.7114394903183, 66.29061967134476, 66.94109916687012, 69.41728949546814, 65.30439779162407, 64.94148686528206, 59.793112725019455, 55.09933099150658, 54.07971270382404, 56.18572689592838, 58.66563342511654, 60.5109816044569, 62.55023717880249, 59.860479310154915, 67.15541526675224, 72.33628526329994, 73.68608683347702, 70.90755432844162, 74.59974780678749, 56.780607774853706, 3.0098085198551416, 0.641454920405522, 0.8334048860706389, 1.50570435449481, 1.6808024025522172, 1.576827869284898, 1.3477572798728943, 1.0697621782310307, 0.05932379717705771, 0.16608601523330435, 18.582015596330166, 38.749260529875755, 65.9843561053276, 83.00542116165161, 37.88904368877411, 40.87699055671692, 53.963237553834915, 57.06327460706234, 66.02639704942703, 72.76505425572395, 55.5272526293993, 1.6059539001435041, 0.11359825162799098, 0.08233418979216367, 0.022057452733861282, 0.13464773423038423, 0.017351637179672252, 0.04386522101412993, 0.019235601321270224, 0.03757530423172284, 0.07942704891320318, 0.016470947230118327, 0.058663048257585615, 0.00843996684125159, 0.04436559924215544, 0.01531978990897187, 0.06297714528045617, 0.1302939694141969, 0.06149224878754467, 0.024635859299451113, 0.02845279344910523, 0.0668061374744866, 0.030539434410457034, 0.07548136883997358, 0.18469931645086035, 0.07034238209598698, 0.19984521466540173, 0.16088112577563152, 0.10841840965440497, 0.14643725473433733, 0.1881128692184575, 0.23661306593567133, 0.16201790305785835, 0.17801320413127542, 0.11471634905319661, 0.1208858894824516, 0.1519320419174619, 0.1227133242355194, 0.0705351030046586, 0.11763539398089051, 0.11963966768234968, 0.14574254513718188, 0.22063452255679294, 0.8627571235410869, 76.18742421269417, 112.94103562831879, 88.49806442856789, 81.46819084882736, 98.511583507061, 79.5066525042057, 46.297912672162056, 49.17208604514599, 45.72502501308918, 70.04591256380081, 3.9764792611822486, 0.4917415289673954, 0.22829851834103465, 2.179767759516835, 0.9736346988938749, 2.9261693079024553, 4.3404206447303295, 4.442893546074629, 0.8858218265231699, 46.669209748506546, 90.33400431275368, 83.56460675597191, 82.38855466246605, 81.24258935451508, 74.12085950374603, 62.41478204727173, 63.79530116915703, 64.70291286706924, 68.1733350455761, 62.358218282461166, 60.05631700158119, 61.741651967167854, 61.98738858103752, 59.8187917470932, 60.862025767564774, 58.28058108687401, 60.081144869327545, 63.47983069717884, 68.23606967926025, 73.23841765522957, 76.0054063796997, 64.56564903259277, 70.67355528473854, 73.51356849074364, 68.57996642589569, 54.034308940172195, 52.786163315176964, 54.19594086706638, 63.89329791069031, 71.42158314585686, 66.38784885406494, 62.71800197660923, 58.06359753012657, 51.87073923647404, 51.77844598889351, 61.445431262254715, 70.44723182916641, 70.14063388109207, 66.3436496257782, 69.2694166302681, 69.93135631084442, 66.16152539849281, 69.39226403832436, 68.88809949159622, 67.25370079278946, 63.30782912671566, 68.19013774394989, 62.34047323465347, 57.323047667741776, 71.50390192866325, 63.52784492075443, 67.23087161779404, 64.93567317724228, 70.61393648386002, 66.69862657785416, 68.69883924722672, 55.466596484184265, 51.8752533942461, 51.37985497713089, 52.77823694050312, 53.66006322205067, 52.95721873641014, 52.775428891181946, 50.029472038149834, 54.09753754734993, 52.75741025805473, 50.49963220953941, 54.092791602015495, 51.15796968340874, 51.47630140185356, 55.37689849734306, 67.50338539481163, 68.92950966954231, 69.01163846254349, 66.42995819449425, 73.21024596691132, 68.39891374111176, 69.62464436888695, 62.148081958293915, 58.89185428619385, 56.621639505028725, 60.07274352014065, 61.62029027938843, 63.25330205261707, 65.90934813022614, 62.658614963293076, 70.19782841205597, 77.24309116601944, 75.83940848708153, 73.96420910954475, 74.9702051281929, 58.700086176395416, 2.8277712129056454, 2.1351662278175354, 9.548426885157824, 6.47860961034894, 3.3870734134688973, 1.4034365233965218, 1.3139660493470728, 1.7632361291907728, 0.14463376166531816, 0.524078921880573, 24.805730134248734, 62.405312955379486, 78.04920271039009, 95.12933939695358, 54.49101023375988, 47.05962359905243, 62.879246324300766, 67.60931611061096, 74.55150559544563, 81.68355569243431, 59.56876516342163, 1.7242888128384948, 0.21114324044901878, 0.3033635497558862, 0.14715848868945614, 0.211072810634505, 0.17130346182966605, 0.18707993323914707, 0.09498900253674947, 0.12686984846368432, 0.19240585213992745, 0.10370492585934699, 0.1690566839533858, 0.16652086924295872, 0.129127417167183, 0.13318126526428387, 0.20697732805274427, 0.13665635691722855, 0.17704263824271038, 0.16158051090314984, 0.1085575252363924, 0.08546157041564584, 0.17216047912370414, 0.2809636329766363], [0.017750799452187493, 0.027902867586817592, 0.04462754397536628, 0.04090748421731405, 0.05635911016725004, 0.028477171144913882, 0.021192527856328525, 0.04008209354651626, 0.048721994971856475, 0.02418252952338662, 0.03488328969979193, 0.02408464210020611, 0.07811052346369252, 0.028441633403417654, 0.064990391547326, 0.08256018118117936, 0.007850209913158324, 0.07502300359192304, 0.16212161077419296, 4.006991386413574, 81.42233490943909, 81.27029746770859, 65.32424792647362, 76.195168197155, 52.30740040540695, 15.443228222429752, 32.711403518915176, 44.58656810224056, 54.52115401625633, 15.473601892590523, 0.06999461169471033, 0.03740959749848116, 0.02934946554887574, 0.6103077542502433, 0.5369115457870066, 0.9911158983595669, 1.683472115546465, 0.1293089464888908, 16.388746686279774, 79.82157960534096, 75.19043371081352, 82.9207769036293, 73.82582813501358, 69.44697350263596, 62.270853370428085, 60.67877300083637, 57.172055169939995, 59.19033966958523, 54.72351975739002, 55.79892285168171, 56.86255797743797, 57.484774589538574, 57.976236417889595, 56.18491753935814, 51.65310971438885, 51.24012127518654, 50.7580791413784, 54.3107783049345, 64.73094776272774, 64.58372846245766, 65.44301435351372, 64.16883632540703, 64.66268822550774, 66.12242549657822, 58.32858011126518, 48.31259496510029, 47.430951073765755, 49.77558486163616, 62.23215624690056, 65.3905163705349, 65.29775574803352, 61.71625413000584, 57.58472442626953, 48.85741353034973, 51.21237516403198, 58.72975118458271, 68.62080663442612, 57.24378012120724, 63.855991512537, 64.61786583065987, 60.891071408987045, 54.778901785612106, 58.358347713947296, 52.34985552728176, 53.44077318906784, 54.26591031253338, 68.09776470065117, 53.80290135741234, 45.746999233961105, 63.71101789176464, 53.62931527197361, 56.21447615325451, 55.76734274625778, 62.44422286748886, 63.090271800756454, 55.60385271906853, 46.159945875406265, 45.62430001795292, 46.03587493300438, 47.55414426326752, 46.79855860769749, 47.554862424731255, 47.97273740172386, 47.787976115942, 46.77818790078163, 45.402095541357994, 44.93580736219883, 46.88758783042431, 48.29826973378658, 47.46656276285648, 45.925388261675835, 54.130360186100006, 61.16702780127525, 63.60780782997608, 64.59957361221313, 64.94074210524559, 64.84245657920837, 60.800130888819695, 61.642009913921356, 55.29519908130169, 51.195165887475014, 50.74271656572819, 53.199075758457184, 52.26898446679115, 56.29831105470657, 61.4448194950819, 63.46441112458706, 66.85640171170235, 70.07123440504074, 68.15265655517578, 70.92120319604874, 70.70025265216827, 50.583885088562965, 2.5958323711529374, 0.5765353445895016, 0.8269648847635835, 1.829730779863894, 1.11321154050529, 0.19980214041424915, 0.19725379825104028, 0.15295200515538454, 0.03465149842668325, 3.960531991906464, 27.668213434517384, 26.483894884586334, 35.34867100417614, 26.80342733860016, 16.986916288733482, 31.04979258030653, 54.104418978095055, 62.71352581679821, 58.26241426169872, 67.0237523317337, 12.211687825620174, 0.7399010471999645, 0.12459624937037006, 0.13801197870634496, 0.1034228948992677, 0.04086060645931866, 0.08463101810775697, 0.05425970797659829, 0.03409082812140696, 0.051424822595436126, 0.052790619229199365, 0.060112848586868495, 0.033791182286222465, 0.009226928177668015, 0.10733059185440652, 0.013885361313441535, 0.01275009894015966, 0.07781776846968569, 0.06828471829066984, 0.010232937183900503, 0.05366697318095248, 0.05036933645897079, 0.016922907743719406, 0.014833921595709398, 0.10675154597265646, 0.06856043357402086, 0.02569833832239965, 0.03658406581962481, 0.09868654553429224, 0.005619322810161975, 0.043880594603251666, 0.006215299399627838, 0.049087565785157494, 0.002871921101359476, 0.00886205127244466, 0.02970100049424218, 0.022695979896525387, 0.061899131251266226, 0.0306816837110091, 0.0451815683481982, 0.147163386864122, 0.22076994966482744, 6.394266011193395, 96.97146534919739, 88.03521126508713, 76.2509036064148, 80.95420762896538, 70.85078537464142, 30.62264610081911, 31.58490266650915, 38.06754671037197, 55.28238236904144, 17.75525975972414, 0.04399310790176969, 0.07975267362780869, 0.09949017272447236, 2.1542965387925506, 1.6940075252205133, 2.0270463544875383, 0.8326592948287725, 0.5505789967719465, 17.71473303437233, 87.63823136687279, 77.40188464522362, 83.8252803683281, 77.13899195194244, 72.27254748344421, 65.76831489801407, 63.54725807905197, 59.581855461001396, 61.634702906012535, 56.33875988423824, 60.00915013253689, 61.44606202840805, 61.11145578324795, 60.70171996951103, 59.428195506334305, 54.84292075037956, 54.76719841361046, 52.66636334359646, 56.650753542780876, 67.31498390436172, 66.88461899757385, 67.75154247879982, 65.19674196839333, 66.23994559049606, 67.53859430551529, 60.10498858988285, 50.223212242126465, 50.05632519721985, 52.657810002565384, 64.59348633885384, 68.99102836847305, 66.91358104348183, 64.9883459508419, 59.85903158783913, 50.205068215727806, 54.144096449017525, 61.31862826645374, 70.59048414230347, 59.49412576854229, 68.45163211226463, 67.48347446322441, 64.308410435915, 59.43940870463848, 60.37674240767956, 54.1420179605484, 56.06996990740299, 56.64870925247669, 70.82291767001152, 55.70985943078995, 49.094820991158485, 66.7049266397953, 57.83026345074177, 58.838136568665504, 58.99425119161606, 63.953030705451965, 65.14047458767891, 59.00678291916847, 49.048094898462296, 49.130854457616806, 47.07378923892975, 49.54285874962807, 49.604597836732864, 49.155344143509865, 50.526842549443245, 48.32905948162079, 49.10509563982487, 48.91227498650551, 47.48277269303799, 48.242918103933334, 50.06909251213074, 50.19508235156536, 48.67735639214516, 56.54039986431599, 63.04309733211994, 66.23089447617531, 65.50615936517715, 68.28172042965889, 68.92219126224518, 64.73632827401161, 63.38948294520378, 57.32492096722126, 51.67986787855625, 52.811040580272675, 55.085214748978615, 55.51213704049587, 59.25600774586201, 63.80526423454285, 66.27973705530167, 68.99591490626335, 74.30063545703888, 69.81970310211182, 73.16496759653091, 71.63392335176468, 58.179434314370155, 3.87420323677361, 0.08705145111889578, 0.490668264683336, 1.9353217701427639, 3.826341717503965, 1.310827061533928, 0.3970351436873898, 0.25329915806651115, 0.10259849499561824, 3.749655894935131, 35.68033240735531, 30.308011583983898, 40.228000581264496, 24.173841141164303, 22.07452218979597, 40.51080420613289, 59.045803025364876, 69.94215533137321, 64.9354375898838, 79.95362251996994, 17.6513809338212, 0.5816396581940353, 0.12324699520831928, 0.13645369122968987, 0.05208110007515643, 0.0861090274702292, 0.047286492117564194, 0.05530399510462303, 0.007182305762398755, 0.03646437224233523, 0.02825307223247364, 0.0526875646028202, 0.049951347755268216, 0.06266956959734671, 0.12047915544826537, 0.0547936609655153, 0.04803338953934144, 0.13870493683498353, 0.049793140424299054, 0.023992059177544434, 0.06278467670199461, 0.06492857064586133, 0.02161510488804197, 0.10477234201971442, 0.15454631648026407, 0.17088906140998006, 0.09438445646082982, 0.11589712084969506, 0.14241416123695672, 0.08272566527011804, 0.13414711109362543, 0.12076077080564573, 0.10882334026973695, 0.16399295098381117, 0.16348465404007584, 0.17324068991001695, 0.16260648553725332, 0.18068101722747087, 0.1355975348269567, 0.12806120328605175, 0.34462120151147246, 0.5232126277405769, 9.423969313502312, 113.72418120503426, 97.72667482495308, 89.58158388733864, 94.29824039340019, 70.55923461914062, 23.43773514032364, 45.30998468399048, 63.19015324115753, 79.33408856391907, 24.516662545502186, 0.15004205895820633, 0.28241554100532085, 0.3633576992433518, 2.2940696636214852, 2.283492931164801, 4.4064924493432045, 6.891520628705621, 2.6829130109399557, 18.851611129939556, 90.53812935948372, 79.6758422255516, 89.42236483097076, 80.60563713312149, 75.39673984050751, 68.6893017590046, 65.35117328166962, 62.13682696223259, 64.58220094442368, 60.27854807674885, 63.82301688194275, 64.07787680625916, 64.58983093500137, 62.9599653929472, 62.596522495150566, 58.73571306467056, 57.46843546628952, 57.1336430311203, 61.08627453446388, 70.1715262234211, 69.75834399461746, 68.72736051678658, 65.19018352031708, 68.3468109369278, 71.277646869421, 63.973731994628906, 53.04571218788624, 52.30866953730583, 55.77261686325073, 68.01233768463135, 70.80185920000076, 70.70386245846748, 67.86862939596176, 62.614727318286896, 52.84918673336506, 57.83521458506584, 66.72746703028679, 73.62164229154587, 61.373459324240685, 69.90667283535004, 69.90031957626343, 66.59803077578545, 60.9396518021822, 63.95725607872009, 57.73314446210861, 58.22808690369129, 61.133285611867905, 73.6407932639122, 60.54430201649666, 53.38089980185032, 70.27535185217857, 61.058878004550934, 62.14458994567394, 63.05896908044815, 67.45417043566704, 69.18790340423584, 60.25731481611729, 51.975150033831596, 50.70692628622055, 50.951785147190094, 51.18742190301418, 52.49439977109432, 52.496512457728386, 53.65557186305523, 52.20769755542278, 51.603036001324654, 51.930814012885094, 49.44874919950962, 51.09899304807186, 53.10122340917587, 52.75594353675842, 52.50323049724102, 59.19744148850441, 66.2533512711525, 67.74032548069954, 67.3559533059597, 69.80696618556976, 72.08239048719406, 67.20758646726608, 67.34915167093277, 60.44788219034672, 55.790103524923325, 57.252413257956505, 59.875306114554405, 56.94843716919422, 62.93042577803135, 68.63970682024956, 69.76638436317444, 74.1145746409893, 76.53471797704697, 73.197281062603, 76.37258067727089, 70.18354877829552, 60.46691536903381, 3.561771414242685, 2.3776647029444575, 6.632471429184079, 8.34974130615592, 5.678330278024077, 1.5344500495120883, 0.4080381657695398, 0.61679074075073, 0.26292421971447766, 6.331334263086319, 47.46156223118305, 41.10537730157375, 49.18575011193752, 36.362304612994194, 26.458468548953533, 45.12690670788288, 67.78053492307663, 80.23885041475296, 72.3735536634922, 88.14756363630295, 18.039148226380348, 0.9837799170054495, 0.27567960089072585, 0.27159639343153685, 0.193298002704978, 0.14234563132049516, 0.1598636561539024, 0.1541177261970006, 0.16356724023353308, 0.2524983510375023, 0.2692992682568729, 0.1591070811264217, 0.1764083988382481, 0.16889449500013143, 0.22765249363146722, 0.11762925641960464, 0.09867907952866517, 0.22071569866966456, 0.14706626941915601, 0.08535037442925386, 0.16475608659675345, 0.15744265168905258, 0.11023825965821743], [0.04574286947899964, 0.059770826119347475, 0.05415838255430572, 0.031193309187074192, 0.025478178358753212, 0.04769053957716096, 0.021909140086791012, 0.013479340668709483, 0.014580928091163514, 0.06094828051573131, 0.0046368375660676975, 0.03449936928518582, 0.01946749835042283, 0.07465112081263214, 0.017503374838270247, 0.05047169346653391, 0.07635777103132568, 0.10354735306464136, 0.029130159055057447, 26.360876485705376, 89.59242850542068, 71.51211708784103, 64.08711031079292, 58.490645214915276, 24.69541635364294, 26.401967480778694, 51.91734753549099, 38.427801579236984, 38.79753693938255, 3.2237947499379516, 0.035018419948755763, 0.01673986073001288, 0.13558831735281274, 1.3960804743692279, 1.5107440715655684, 0.9678594244178385, 0.6507067708298564, 1.6719998186454177, 63.22839058935642, 78.13278302550316, 84.10845637321472, 78.74582692980766, 74.03626084327698, 70.55151343345642, 63.68771754205227, 57.275318428874016, 58.86586748063564, 59.03893679380417, 60.23015387356281, 60.94006597995758, 60.62320098280907, 61.78486704826355, 60.46300157904625, 56.4678655564785, 51.74500398337841, 50.11557161808014, 50.5753393471241, 56.25783942639828, 61.40857703983784, 66.97918072342873, 69.98665854334831, 64.10051599144936, 66.66472479701042, 63.094139993190765, 54.521841779351234, 46.52188405394554, 46.48681953549385, 50.34306921064854, 64.81527283787727, 65.65555214881897, 63.44701565802097, 61.58739924430847, 57.167810797691345, 54.13759499788284, 57.33556039631367, 60.189252868294716, 62.15298369526863, 58.39078277349472, 67.54193812608719, 60.607583820819855, 59.14934366941452, 53.13816882669926, 51.95707440376282, 48.58830817043781, 51.973329931497574, 51.632921397686005, 67.68902063369751, 48.62902298569679, 44.455387741327286, 64.9545505642891, 50.389647111296654, 51.71225354075432, 50.56412994861603, 55.17487853765488, 52.977099269628525, 47.692563235759735, 47.11788967251778, 46.383715867996216, 47.30213798582554, 47.20159538090229, 46.97978988289833, 53.09485115110874, 50.9748575091362, 51.96329087018967, 51.541870683431625, 52.12479740381241, 46.09436899423599, 45.73218762874603, 46.63830980658531, 46.1029527336359, 45.93709543347359, 48.73994663357735, 56.863177344202995, 61.29718981683254, 62.77795895934105, 63.9899343252182, 64.43492084741592, 66.41437903046608, 64.5241628587246, 57.560143545269966, 47.43500165641308, 50.04898019134998, 49.21746701002121, 55.46382263302803, 58.640642166137695, 57.98067457973957, 66.2739309668541, 67.43802890181541, 66.1403301358223, 70.20016148686409, 70.47638386487961, 68.12784388661385, 74.10900413990021, 58.18047545850277, 3.435189281590283, 1.049159683752805, 1.4564725337550044, 1.9917315244674683, 2.0621120603755116, 0.47412196348886937, 0.29715714685153216, 0.07193719808128662, 0.13871513394406065, 10.910937823355198, 25.755612663924694, 27.90092434734106, 28.78841422498226, 27.912204042077065, 22.32868865132332, 38.61542411148548, 50.6367364525795, 54.44613464176655, 63.622687831521034, 46.41275770962238, 0.9469760418869555, 0.14929811528418213, 0.08275389656773768, 0.022919902548892424, 0.062203018460422754, 0.048440160680911504, 0.03333522159664426, 0.06213231405126862, 0.08576078951591626, 0.04846868512686342, 0.08867508469847962, 0.05009098655136768, 0.039295134993153624, 0.015746598110126797, 0.043210442672716454, 0.08694594740518369, 0.061333789126365446, 0.03452422381087672, 0.042212157568428665, 0.027003649920516182, 0.02977169191581197, 0.0281418242957443, 0.024314299698744435, 0.05350363760953769, 0.014593399882869562, 0.021869173579034396, 0.013664277375937672, 0.017010087831295095, 0.051532682628021576, 0.037392973390524276, 0.017849091345851775, 0.06061173138732556, 0.04279188251530286, 0.05361528259527404, 0.03281186647654977, 0.03252041766245384, 0.05769186267571058, 0.03227136403438635, 0.10984986409312114, 0.1964117426541634, 0.0497919344343245, 34.379130229353905, 103.28618690371513, 80.84469750523567, 73.94393339753151, 67.53926306962967, 41.14779442548752, 30.00417798757553, 35.404877588152885, 35.72786405682564, 43.69668245315552, 4.434113642200828, 0.11068860228988342, 0.06710183137329295, 1.1551939439959824, 1.9718451728112996, 2.756641642190516, 1.9672832801006734, 0.7309424341656268, 1.9641888211481273, 68.01791578531265, 79.54974219202995, 84.8743736743927, 80.68343415856361, 78.56550380587578, 72.69575357437134, 67.61156558990479, 61.988995894789696, 62.45006315410137, 60.765598341822624, 63.598498329520226, 63.730693235993385, 62.14516371488571, 64.2915241420269, 62.661556005477905, 59.42351035773754, 54.45190653204918, 52.0604744553566, 53.016381561756134, 58.140049427747726, 64.61279690265656, 69.5906437933445, 70.94990685582161, 64.24183040857315, 69.27162051200867, 65.89870870113373, 56.95600636303425, 48.71419541537762, 49.01291638612747, 54.376689568161964, 68.4180799126625, 67.20126360654831, 66.28057301044464, 64.28144708275795, 60.48626013100147, 59.047714322805405, 58.944975435733795, 62.467071041464806, 65.56038245558739, 61.37599378824234, 69.36969324946404, 63.15855793654919, 61.03040233254433, 54.77416343986988, 54.27145041525364, 50.05476348102093, 54.62730512022972, 55.5764751881361, 69.06498000025749, 52.45819911360741, 48.712208122015, 68.25167164206505, 53.83016109466553, 54.63421694934368, 51.91665977239609, 56.954015269875526, 56.827075481414795, 51.40277534723282, 48.05825561285019, 49.3260233849287, 48.51306840777397, 50.1270318031311, 50.08459948003292, 55.98172344267368, 54.673366248607635, 53.35005305707455, 54.44325439631939, 55.38204722106457, 48.81141319870949, 46.93979322910309, 48.16951364278793, 48.831400126218796, 48.61464835703373, 50.938546657562256, 59.21709023416042, 64.0257740020752, 65.76579183340073, 65.66428408026695, 66.70347511768341, 69.71903890371323, 67.87072688341141, 61.99289828538895, 49.84933130443096, 53.11031632125378, 51.77437640726566, 57.77461163699627, 61.01343624293804, 60.75549088418484, 68.97450685501099, 71.12107247114182, 69.1194386780262, 72.14101374149323, 72.43653908371925, 70.09690582752228, 74.93635654449463, 65.90526714920998, 5.473494194447994, 0.6537617475260049, 0.7939750549849123, 2.1046075550839305, 2.7532175509259105, 1.18926647817716, 0.677425452740863, 0.09808698669075966, 0.2535647578770295, 16.09381601214409, 36.340550780296326, 30.635022036731243, 32.11242265999317, 32.20362536609173, 36.273252591490746, 47.39030085504055, 55.640011578798294, 60.902398601174355, 70.10125279426575, 61.29040718078613, 2.336438577622175, 0.1045647930004634, 0.036732280132127926, 0.04625897381629329, 0.019180528397555463, 0.06436768511775881, 0.050910273057525046, 0.0798331001715269, 0.019034813267353456, 0.05004027560062241, 0.0644512138387654, 0.02778212943667313, 0.026829948401427828, 0.08687593319336884, 0.035501988531905226, 0.05625365098239854, 0.031574261010973714, 0.03477771177131217, 0.011034523467969848, 0.020090442267246544, 0.01676970990956761, 0.03479926373984199, 0.18463335436536, 0.1693060010438785, 0.13236278027761728, 0.1902954067918472, 0.09562312319758348, 0.1307441561948508, 0.12501091696321964, 0.15480275818845257, 0.12728024128591642, 0.17128726816736162, 0.15139238181291148, 0.12632064434001222, 0.1390874694334343, 0.16949656972428784, 0.1403715185006149, 0.1245055663457606, 0.20556659437716007, 0.27517829497810453, 0.1094982419454027, 40.74778988957405, 115.14426380395889, 89.95771810412407, 87.3249077796936, 74.83132258057594, 39.15724843740463, 39.34471897780895, 71.99266970157623, 53.83733510971069, 59.068047031760216, 6.085626147687435, 0.19039127742871642, 0.3377702285069972, 1.309597590006888, 3.332894495688379, 5.688976356759667, 5.322278458625078, 5.653360392898321, 2.196154617704451, 70.43672919273376, 83.88524875044823, 88.16197246313095, 82.48780533671379, 80.86668312549591, 77.43926703929901, 70.2835214138031, 63.42235878109932, 64.94676098227501, 63.29197257757187, 65.37943616509438, 66.6283455491066, 64.77440223097801, 68.60502988100052, 67.27472886443138, 63.122505471110344, 57.87902243435383, 53.191529363393784, 56.120222210884094, 61.519667878746986, 66.79182797670364, 71.60760596394539, 74.12613362073898, 65.19336014986038, 73.33677917718887, 68.05462941527367, 59.822576344013214, 50.532587841153145, 51.896935030817986, 56.26718692481518, 72.08867534995079, 71.15371271967888, 68.3262312412262, 67.21833229064941, 64.30579617619514, 60.35604111850262, 64.28754195570946, 65.44730052351952, 68.52032482624054, 63.66573952138424, 72.1638885140419, 67.87540063261986, 63.69763121008873, 57.422879710793495, 55.87985850870609, 52.894734889268875, 59.3522147834301, 59.12571273744106, 71.20848298072815, 55.85082046687603, 51.80083058774471, 70.76623231172562, 56.77203543484211, 57.63765938580036, 54.05654914677143, 61.217211708426476, 60.25580249726772, 53.63878436386585, 50.48714987933636, 52.028134390711784, 51.120374500751495, 52.54466347396374, 52.08031699061394, 59.566926062107086, 56.62816375494003, 56.326216757297516, 56.949375718832016, 58.299067094922066, 50.56986764073372, 50.360183492302895, 49.89192321896553, 51.64739482104778, 51.395080760121346, 54.22513090074062, 62.02516995370388, 66.71511769294739, 69.2187349498272, 66.91792041063309, 69.34731245040894, 71.08610674738884, 69.41697031259537, 65.01267984509468, 52.172154262661934, 56.714818105101585, 55.2063712477684, 62.03892141580582, 64.72521767020226, 63.746960163116455, 73.00544455647469, 77.22948789596558, 72.53601014614105, 75.10655701160431, 75.17061397433281, 73.08840930461884, 77.3568494617939, 67.71839305758476, 4.501156769692898, 3.8265654304996133, 8.002875968813896, 7.419636715203524, 6.784731633961201, 2.055904380977154, 0.9773660986684263, 0.28111301246099174, 0.4933497332967818, 23.625359572470188, 43.6785726249218, 39.50784042477608, 37.916994988918304, 40.16556613147259, 35.45583285391331, 50.5875176936388, 68.36898654699326, 70.42857483029366, 79.33992505073547, 67.5321726500988, 2.52845058683306, 0.2862891659606248, 0.1326118895667605, 0.1957311635487713, 0.09246619025361724, 0.15374078939203173, 0.17524235125165433, 0.2596367133082822, 0.199696384370327, 0.16125499008921906, 0.14919032575562596, 0.16448309499537572, 0.10755132883787155, 0.1325069647282362, 0.1501756306970492, 0.14574388100299984, 0.20073320920346305, 0.19932283175876364, 0.14702028594911098, 0.15361311030574143, 0.18995152524439618, 0.14260337920859456], [0.01569950327393599, 0.02951145412225742, 0.044810691179009154, 0.09363611185108311, 0.048918552784016356, 0.0897496180550661, 0.0784753484185785, 0.04348805043264292, 0.053276722246664576, 0.044164573700982146, 0.06061701918952167, 0.06441525678383186, 0.05121611953654792, 0.02647498287842609, 0.07093383668689057, 0.022165411101013888, 0.021655284763255622, 0.018348825760767795, 0.20731496071675792, 44.640886187553406, 86.0812497138977, 67.08147883415222, 68.96760642528534, 57.754875496029854, 19.09348525106907, 50.23461163043976, 46.676737144589424, 56.239117830991745, 25.625272057950497, 0.2135038934648037, 0.050121704043704085, 0.07720214212895371, 0.7613561803009361, 2.124724150635302, 1.6893271263688803, 0.4058599326526746, 0.9480507310945541, 29.56379871815443, 85.43301969766617, 78.59205678105354, 82.89283320307732, 71.41344398260117, 74.23751324415207, 67.28963926434517, 67.68243178725243, 64.75538805127144, 63.05876009166241, 61.625192016363144, 64.7453185915947, 64.03717339038849, 66.33622482419014, 62.25420646369457, 63.46645541489124, 55.56015506386757, 50.68970941007137, 50.18158167600632, 51.60080172121525, 58.85447569191456, 68.65855380892754, 64.5645546913147, 67.84190163016319, 63.433013409376144, 64.98741120100021, 58.159804567694664, 47.674202620983124, 47.02002972364426, 47.387724593281746, 53.61144483089447, 66.50441139936447, 62.254586443305016, 60.27675837278366, 62.76537783443928, 62.094770818948746, 59.87971007823944, 60.90762712061405, 64.35946449637413, 62.6285357773304, 59.91884037852287, 63.608924970030785, 58.90154756605625, 55.78576795756817, 52.44716830551624, 52.71062716841698, 47.714472860097885, 53.63720744848251, 54.40683715045452, 66.5600024163723, 45.64721278846264, 39.20254200696945, 67.2890616953373, 49.82145980000496, 50.30175022780895, 47.144978418946266, 50.1211117208004, 44.76926609873772, 46.139115393161774, 45.427831560373306, 47.296723276376724, 44.526766911149025, 48.782416954636574, 51.42834037542343, 54.60952967405319, 55.663190335035324, 61.301890164613724, 61.40013389289379, 56.942600682377815, 53.897569477558136, 45.81313468515873, 45.21733805537224, 45.60276657342911, 44.4794100522995, 46.06698766350746, 51.3445358723402, 60.731426775455475, 62.70870767533779, 63.83945479989052, 59.76777568459511, 66.01070389151573, 63.13226714730263, 62.35684655606747, 49.15993429720402, 49.90363039076328, 49.53554034233093, 53.83702352643013, 53.12102034687996, 61.672776862978935, 60.57376563549042, 62.72264912724495, 66.85688808560371, 70.3931151330471, 66.10471084713936, 65.13564884662628, 67.02145725488663, 73.66252049803734, 55.60930162668228, 3.5155015345662832, 0.943027816247195, 4.582758815959096, 1.8066891725175083, 1.0135747119784355, 0.5714836344122887, 0.18363993032835424, 0.022356317458616104, 2.1437518671154976, 12.797892820090055, 27.491855397820473, 23.191829435527325, 45.83873011171818, 29.439214803278446, 25.13113707304001, 45.32627061009407, 47.82153971493244, 55.60375392436981, 60.20135521888733, 16.02748867124319, 0.5142455839086324, 0.08965413333498873, 0.3132491052383557, 0.02086664524540538, 0.08391745053813793, 0.13175809319363907, 0.08027732008486055, 0.0527644288376905, 0.003001357222274237, 0.013747975863225292, 0.0522327987710014, 0.042316392209613696, 0.07548490146291442, 0.03374528416316025, 0.008833491574478103, 0.019264635993749835, 0.05770227871835232, 0.06406957923900336, 0.03811113485426176, 0.04716834591818042, 0.07526791232521646, 0.016800137964310125, 0.02538375305448426, 0.022268369248195086, 0.040822742084856145, 0.03851044370094314, 0.009199544783768943, 0.08234463923145086, 0.05929035229200963, 0.027969002221652772, 0.01642143299250165, 0.08105368076940067, 0.050480150239309296, 0.06555224186740816, 0.031656071660108864, 0.07741489360341802, 0.054994538077153265, 0.032121450203703716, 0.0353095793252578, 0.40559261105954647, 57.64600373804569, 97.11920142173767, 76.83310076594353, 77.45507419109344, 66.09320506453514, 25.97390715032816, 37.52206318080425, 40.868969187140465, 56.53829097747803, 29.06977392733097, 0.18067706900183111, 0.0905985533609055, 0.082577257999219, 2.820690292865038, 1.2048311554826796, 3.0002539325505495, 1.315790545195341, 0.45651540043763816, 32.31725826859474, 89.41897541284561, 82.43929713964462, 84.98365581035614, 73.3979406952858, 75.57712376117706, 69.40901353955269, 70.23088663816452, 67.37826570868492, 64.51839476823807, 65.8501473069191, 67.2165159881115, 66.38505220413208, 68.96437659859657, 65.00622019171715, 65.23259684443474, 58.31086166203022, 52.67033413052559, 53.7128271907568, 52.92675197124481, 61.17833599448204, 69.678023904562, 67.9297225177288, 68.91705393791199, 64.9741043150425, 68.30553755164146, 61.23685285449028, 49.944861978292465, 49.65871453285217, 48.513653576374054, 56.10767148435116, 69.27500233054161, 62.242742478847504, 62.09108881652355, 65.60148864984512, 64.15897205471992, 63.327702060341835, 65.32863289117813, 67.81462669372559, 65.11917293071747, 60.3389610350132, 67.18392133712769, 61.43943898379803, 58.75045247375965, 55.51540486514568, 55.38455128669739, 49.671124666929245, 55.091868191957474, 57.146364748477936, 70.22731482982635, 48.85626219213009, 41.943217143416405, 69.02909472584724, 52.20715418457985, 52.61804513633251, 50.4040065407753, 53.55689875781536, 46.80716894567013, 48.894700929522514, 46.94806158542633, 48.87103579938412, 46.51155240833759, 51.64612948894501, 53.66999588906765, 59.59076218307018, 58.58278267085552, 63.730032071471214, 63.35362806916237, 61.854836493730545, 56.95236995816231, 51.478721871972084, 46.92687012255192, 48.536858931183815, 48.83072756230831, 50.18828831613064, 54.79408577084541, 62.16248698532581, 64.25280421972275, 66.0335710644722, 61.503503546118736, 68.51657822728157, 64.27344471216202, 64.47294160723686, 50.65796211361885, 51.5132962167263, 51.102238073945045, 56.552859395742416, 56.214730739593506, 63.605391159653664, 64.44680660963058, 65.70738136768341, 68.51168408989906, 72.52537071704865, 67.45222494006157, 67.82491654157639, 71.079381108284, 74.39048543572426, 61.939404755830765, 6.759632080793381, 0.638763892930001, 0.45057251933030784, 4.350404608994722, 2.5181600265204906, 0.9492048597894609, 0.40108795277774334, 0.036942571387044154, 2.2547222999855876, 22.458009012043476, 32.571635618805885, 23.700054064393044, 38.36196631193161, 30.120434649288654, 34.243564903736115, 54.17009845376015, 55.41580840945244, 59.64281179010868, 71.86113595962524, 29.357163906097412, 0.6303654529619962, 0.11365299244062044, 0.1779788575368002, 0.05452964564028662, 0.09112829095101915, 0.06292781472438946, 0.08574495950597338, 0.122927337361034, 0.06403616032912396, 0.03477744830888696, 0.04854832499404438, 0.03163046385452617, 0.04283041111193597, 0.03887340586516075, 0.03682763868710026, 0.06710388712235726, 0.009589269720891025, 0.09546285640681162, 0.030886551721778233, 0.08358720224350691, 0.0745632431062404, 0.10652891651261598, 0.1842861925251782, 0.17279676685575396, 0.1593554185819812, 0.16030357161071151, 0.21430189517559484, 0.14485360065009445, 0.18345016316743568, 0.17642916413024068, 0.14611357444664463, 0.18273075489560142, 0.1732083471142687, 0.1064103732642252, 0.13615632749861106, 0.21664331172360107, 0.18778956000460312, 0.15863550564972684, 0.08470958928228356, 0.695491167716682, 69.42894726991653, 106.85193076729774, 89.18629109859467, 86.78641587495804, 76.5708540380001, 28.538106456398964, 68.32842752337456, 61.21394768357277, 76.99954703450203, 42.102569192647934, 0.48704340762924403, 0.10131106915650889, 0.6210187263786793, 3.1476527731865644, 7.156418189406395, 6.078590350225568, 7.077888753265142, 2.336651128716767, 34.72246840596199, 92.39401817321777, 84.6384747326374, 87.53025636076927, 77.10546255111694, 80.30117467045784, 72.17226326465607, 72.15811282396317, 69.60380628705025, 67.65783190727234, 66.77082270383835, 71.6123329102993, 68.95481631159782, 72.1184429526329, 68.85055750608444, 70.4229511320591, 60.869993939995766, 56.86632737517357, 56.90394155681133, 55.33185951411724, 64.26406681537628, 73.99071648716927, 69.89651218056679, 69.66376706957817, 64.68159601092339, 72.7532596886158, 61.6956402361393, 53.00341285765171, 51.62579298019409, 52.31381066143513, 59.75341245532036, 73.97230267524719, 65.07647082209587, 64.51693564653397, 68.78738969564438, 66.68519049882889, 65.70035934448242, 68.6472000181675, 70.57611331343651, 67.17139720916748, 63.85826379060745, 68.46587374806404, 65.03090366721153, 62.978307008743286, 59.048751667141914, 58.05274911224842, 52.681452333927155, 57.693846970796585, 60.29635772109032, 74.47608724236488, 53.676166757941246, 46.31442278623581, 71.7814314365387, 56.23569041490555, 55.156559720635414, 53.29803764820099, 56.74282260239124, 48.911237642169, 51.50050610303879, 49.741458892822266, 52.21658147871494, 49.70968499779701, 54.02660675346851, 57.576281279325485, 61.28342315554619, 61.31031051278114, 67.91264623403549, 67.00630366802216, 64.68432426452637, 59.560895785689354, 52.5303116440773, 48.33458058536053, 50.84569104015827, 51.9569756090641, 53.03004562854767, 59.1580718010664, 66.29517182707787, 67.37727776169777, 68.64146992564201, 61.81656874716282, 71.82923287153244, 68.2723805308342, 69.33309361338615, 54.107884392142296, 55.09753368794918, 53.984280824661255, 59.36656281352043, 58.05899977684021, 68.23174551129341, 66.97336703538895, 68.27412083745003, 72.25316852331161, 75.51071092486382, 71.546900421381, 70.53965047001839, 75.47018229961395, 76.27583786845207, 65.73311358690262, 6.414873255416751, 5.138796279206872, 13.275646883994341, 8.30419884994626, 4.330147420987487, 1.3760987715795636, 0.8379180345218629, 0.1337029950809665, 4.601611979305744, 25.76352383941412, 43.91115814447403, 32.390286549925804, 58.985295072197914, 37.889503464102745, 37.88953386247158, 59.01251681149006, 67.26165756583214, 68.97201418876648, 84.59677577018738, 33.670304864645004, 1.1472435831092298, 0.3776318411109969, 0.5008701828774065, 0.15657473966712132, 0.35909423895645887, 0.25966651795897633, 0.16135566984303296, 0.22189865238033235, 0.15998823306290433, 0.18575527385110036, 0.14984666631789878, 0.15104254824109375, 0.23302206565858796, 0.31297970563173294, 0.19230919482652098, 0.16028795682359487, 0.14751691633136943, 0.17479116999311373, 0.12141340805101208, 0.13947844767244533, 0.27734316943679005], [0.0635290879290551, 0.05537048782571219, 0.060840876903967, 0.1406628411496058, 0.1179293957829941, 0.0916758029779885, 0.13695228088181466, 0.09339705866295844, 0.0367084720346611, 0.019267988645879086, 0.043907516010222025, 0.005120805053593358, 0.012888497421954526, 0.055921847888384946, 0.06283143200562336, 0.06365252193063498, 0.11918384057935327, 0.018365522228123154, 8.529448863118887, 76.46018877625465, 77.51308187842369, 69.27367240190506, 57.40923464298248, 46.10448405146599, 32.61055313050747, 102.00606599450111, 57.40244820713997, 39.95204038918018, 4.631587145850062, 0.1926007104339078, 0.4557606659363955, 0.11250696057686582, 0.8232616866007447, 0.6760923773981631, 1.3885059370659292, 1.8163198744878173, 3.4988821763545275, 68.62856581807137, 78.82667899131775, 79.74479332566261, 75.5275060236454, 75.71093738079071, 71.09132006764412, 73.3476921916008, 69.97848898172379, 68.9086563885212, 66.44551455974579, 68.11786562204361, 70.89361667633057, 67.23790884017944, 67.59912505745888, 64.9795912206173, 61.810055896639824, 53.05721037089825, 50.14777489006519, 51.00215524435043, 54.000916332006454, 65.8182442188263, 66.43682822585106, 67.06648483872414, 64.48572412133217, 65.8871953189373, 62.58190467953682, 56.462492644786835, 48.032800778746605, 49.201496466994286, 46.44243411719799, 56.61198042333126, 65.43874338269234, 58.16305339336395, 57.00543791055679, 59.523114413022995, 62.547326534986496, 61.322754845023155, 63.81661042571068, 60.7519418746233, 57.46116265654564, 54.92695324122906, 63.599767461419106, 56.64153903722763, 52.66309551894665, 48.44032131135464, 53.47302585840225, 49.3949630856514, 53.354536816477776, 53.012840151786804, 65.94678372144699, 42.76435688138008, 35.27406580746174, 68.79618242383003, 53.06329004466534, 58.011977300047874, 52.03910820186138, 48.499943912029266, 42.62149974703789, 47.048832178115845, 43.25965650379658, 42.906039878726006, 44.977650716900826, 48.28442707657814, 50.246322602033615, 54.7317349165678, 59.59843397140503, 63.7632916867733, 67.03571408987045, 62.953137159347534, 60.08543103933334, 48.425433710217476, 45.21600052714348, 46.75900273025036, 44.560691490769386, 45.93263067305088, 46.32019467651844, 55.82519084215164, 61.68257653713226, 62.12674230337143, 58.174426183104515, 64.02705073356628, 64.89076718688011, 57.25750118494034, 47.52006009221077, 47.5802830606699, 48.630474507808685, 52.575928196311, 58.83681043982506, 60.653530955314636, 61.42761401832104, 63.92634093761444, 65.88426947593689, 65.81880658864975, 66.41633972525597, 63.70817944407463, 71.0306753218174, 64.08064305782318, 72.58519470691681, 45.89070752263069, 1.1060653114691377, 1.2304764543659985, 1.257616023067385, 0.31922855938319117, 0.5288123991340399, 0.1592394060571678, 0.012539304880192503, 0.8953879319597036, 12.899278029799461, 21.694747768342495, 47.29346305131912, 61.59700892865658, 82.36520871520042, 23.40422473847866, 26.70419566333294, 53.04615296423435, 51.748043820261955, 56.47914335131645, 49.34129856526852, 3.543871524743736, 0.6695527501869947, 0.048060611516120844, 0.08118442492559552, 0.060707234661094844, 0.0357367038668599, 0.0702930218540132, 0.05774986893811729, 0.017280433676205575, 0.06886620583827607, 0.04533950850600377, 0.05891154156415723, 0.058140787805314176, 0.032700882002245635, 0.00855138083352358, 0.054835529226693325, 0.046433868337771855, 0.08079510909738019, 0.03192036529071629, 0.038793691783212125, 0.04483645854634233, 0.034770004567690194, 0.08083430933766067, 0.046980608531157486, 0.07581733167171478, 0.08467712032143027, 0.04172905653831549, 0.11330521461786702, 0.07707641489105299, 0.06317121689789928, 0.018933421051769983, 0.05977524189802352, 0.07727763339062221, 0.047370106185553595, 0.01995696144149406, 0.03122992675343994, 0.042630079478840344, 0.16031088918680325, 0.1530053062015213, 13.137749433517456, 94.3186604976654, 83.00479799509048, 78.37750509381294, 62.352324798703194, 58.45933489501476, 29.793547689914703, 74.16933730244637, 52.93182849884033, 43.48199017345905, 5.570305874571204, 0.17213128303410485, 0.14523320918669924, 1.4237533207051456, 1.999070830643177, 1.727381490636617, 3.879612246528268, 1.1396371037699282, 3.974173259921372, 73.97086635231972, 80.20008489489555, 81.74575075507164, 75.48871010541916, 75.99105075001717, 72.32553943991661, 77.33488664031029, 72.8315506875515, 72.0209401845932, 70.5059614777565, 69.7210755944252, 72.9440626502037, 72.616056650877, 68.92018496990204, 67.77271494269371, 65.77735841274261, 56.12124815583229, 51.366369500756264, 53.3739347755909, 56.21854193508625, 66.78048178553581, 68.55430260300636, 68.72492864727974, 67.0889188349247, 67.79749721288681, 64.3313916027546, 60.50568088889122, 48.7898987531662, 50.849038660526276, 48.45077835023403, 60.259020924568176, 67.61521339416504, 62.32281178236008, 58.77820998430252, 59.23296578228474, 64.26067739725113, 62.59374104440212, 66.80258139967918, 63.04981917142868, 59.182945266366005, 56.758234575390816, 66.75575271248817, 59.656981229782104, 55.71451038122177, 51.94124825298786, 55.27178093791008, 53.19118358194828, 55.40465980768204, 55.91447465121746, 70.27991160750389, 45.59370405972004, 39.72866177558899, 72.78182655572891, 56.36111408472061, 59.69468280673027, 53.5204853117466, 51.564456671476364, 45.12479402124882, 47.41188369691372, 43.8404705375433, 45.01222886145115, 46.58841848373413, 49.54098545014858, 52.358690053224564, 57.5279288738966, 60.95078520476818, 66.4359238743782, 66.9043019413948, 66.01369053125381, 63.29445384442806, 50.98049260675907, 45.44160582125187, 49.53823819756508, 48.335025161504745, 48.36690925061703, 49.02072496712208, 57.78778553009033, 64.7256888449192, 63.71905066072941, 59.74781535565853, 66.94868355989456, 67.33137622475624, 58.855269849300385, 49.98781867325306, 50.01205377280712, 52.13878445327282, 55.42866311967373, 61.84106603264809, 62.43748962879181, 64.53208923339844, 66.01888865232468, 69.82305452227592, 67.34250962734222, 68.757903277874, 68.27148377895355, 74.7533355653286, 68.76915827393532, 72.26333677768707, 51.067610532045364, 2.1943309530615807, 0.7520029228180647, 1.6960317478515208, 2.187941358424723, 2.054174761287868, 0.7578581117559224, 0.06117402699601371, 0.4950084333540872, 12.583686914294958, 29.64219991117716, 38.51479411125183, 52.435293942689896, 61.79819293320179, 30.98759561777115, 41.149325743317604, 61.950397565960884, 60.50238646566868, 63.48800025880337, 67.11098045110703, 8.851103503257036, 0.7526058435905725, 0.1442874310305342, 0.16795211588032544, 0.09391846935614012, 0.0824357898090966, 0.03971903490310069, 0.055650318317930214, 0.044601832269108854, 0.07146502888645045, 0.05098384586744942, 0.11886141452123411, 0.01840896384237567, 0.06489102539489977, 0.026703872354119085, 0.07607787745655514, 0.054791519869468175, 0.04082458632183261, 0.013506191571650561, 0.00626016037131194, 0.009688417867437238, 0.18736864352831617, 0.25406505446881056, 0.1581806581816636, 0.1967348885955289, 0.1914359096554108, 0.19996717921458185, 0.25441184523515403, 0.22365509328665212, 0.1711871227598749, 0.114370738301659, 0.22981263318797573, 0.11557017511222512, 0.12232025314006023, 0.19469692138954997, 0.27461070043500513, 0.09828919224673882, 0.3635179140837863, 0.2836795669281855, 17.78810329735279, 108.67176711559296, 93.6033184826374, 91.97029531002045, 73.83718192577362, 63.03048200905323, 48.76774214208126, 128.55292350053787, 72.09141120314598, 62.95318655669689, 7.190760746598244, 0.34980587486643344, 0.9456905233673751, 1.2093925732187927, 4.9378440622240305, 4.155412847176194, 7.092889873310924, 7.261664466932416, 3.661366682499647, 78.8508152961731, 79.87519472837448, 83.6554066836834, 80.61345711350441, 78.50315675139427, 75.77581509947777, 81.34127005934715, 76.83001533150673, 74.89939972758293, 71.92702442407608, 72.2977477312088, 76.45129725337029, 73.71563404798508, 72.4554392695427, 72.28579357266426, 69.40627008676529, 58.63442189991474, 55.24447940289974, 55.08576191961765, 58.32826092839241, 69.46849554777145, 71.74523457884789, 71.0179916024208, 67.52417027950287, 71.39515176415443, 67.62884706258774, 63.6938314139843, 50.19453518092632, 53.33662457764149, 49.53304007649422, 63.568647131323814, 69.59766581654549, 61.91433370113373, 59.71742458641529, 61.09681136906147, 67.86808222532272, 65.95436811447144, 69.28723007440567, 66.91000163555145, 63.49498808383942, 57.89672948420048, 71.55548796057701, 62.55914390087128, 57.24785350263119, 56.512220576405525, 59.91917856037617, 55.677382573485374, 57.10637949407101, 59.48260858654976, 72.4964390695095, 48.77260968089104, 43.307864516973495, 74.14292111992836, 58.02194036543369, 63.973671197891235, 57.23041243851185, 54.31554704904556, 48.34459684789181, 52.699915543198586, 46.9318288564682, 48.294523134827614, 49.87640105187893, 52.28081703186035, 55.460680201649666, 60.77168561518192, 65.27168154716492, 68.26323062181473, 69.84257787466049, 69.2421492934227, 64.95029479265213, 53.05569425225258, 49.04581122100353, 53.193828240036964, 50.2638890594244, 51.73102453351021, 52.30029858648777, 61.14707887172699, 69.39671739935875, 67.36926779150963, 60.65035432577133, 69.06633272767067, 69.32094946503639, 61.791782677173615, 52.12354727089405, 52.730853483080864, 55.42699880897999, 58.017775788903236, 64.7165997326374, 67.48570114374161, 66.60329729318619, 68.73206466436386, 71.97938561439514, 70.86290672421455, 71.66565924882889, 68.50333213806152, 77.36346110701561, 69.75358664989471, 75.31395748257637, 51.93617172539234, 1.9266893458552659, 7.803012868389487, 8.21574529632926, 5.351407695561647, 2.77878827881068, 0.8194621873553842, 0.13809346652124077, 1.1738172196783125, 20.310599841177464, 35.44088065624237, 61.97866044938564, 71.69642999768257, 92.80776277184486, 33.039694502949715, 39.719131886959076, 69.31405663490295, 70.42769327759743, 71.9013985991478, 77.18679338693619, 10.488773826509714, 1.2070786161348224, 0.3002990735694766, 0.19016830658074468, 0.22099620080552995, 0.1259218290215358, 0.19195006956579164, 0.1947892297175713, 0.14015395048772916, 0.20308660401497036, 0.27482369681820273, 0.17678024451015517, 0.12958308099769056, 0.14037712913705036, 0.13956814364064485, 0.1751785710803233, 0.18297110684216022, 0.26531378680374473, 0.1129515960928984, 0.148222268326208, 0.1420027739368379], [0.037004689147579484, 0.0340997153398348, 0.045556902114185505, 0.06223725744348485, 0.019524376548361033, 0.10547341182245873, 0.019558899402909447, 0.01978869429876795, 0.04361103172414005, 0.07782312677591108, 0.09018484313855879, 0.057754730005399324, 0.034987850885954686, 0.03579295866074972, 0.029454117648128886, 0.05068085294624325, 0.2711508673382923, 0.14140690356725827, 37.24136844277382, 74.4719834625721, 76.75463497638702, 61.350314766168594, 55.0425810366869, 41.39554873108864, 33.7650565803051, 65.61509191989899, 62.38329313695431, 24.430412873625755, 0.16808944288641214, 0.015535936709056841, 0.1918146721436642, 0.29282727919053286, 1.8979003094136715, 0.6266202789265662, 1.2974010757170618, 1.101200266275555, 19.739311896264553, 89.84813958406448, 70.45650333166122, 82.58915349841118, 73.34730461239815, 74.05520662665367, 70.84499448537827, 73.29318791627884, 71.33594334125519, 75.56228935718536, 69.41684111952782, 73.74578922986984, 66.83872506022453, 73.69329124689102, 71.99656069278717, 63.82367804646492, 58.10368537902832, 50.371639877557755, 47.591025084257126, 51.47191263735294, 62.06392787396908, 66.66576594114304, 67.71253377199173, 65.07974624633789, 61.8331054598093, 64.08590957522392, 57.887602373957634, 50.44796258211136, 48.392880856990814, 47.411093339324, 43.885410726070404, 56.24297842383385, 64.29593950510025, 61.43636874854565, 57.42850340902805, 58.594858422875404, 63.077170103788376, 63.6732517182827, 60.59040114283562, 54.60317641496658, 55.085841715335846, 60.382347106933594, 62.802266255021095, 54.2665296792984, 52.61196926236153, 48.89584466814995, 54.39362905919552, 50.2227258682251, 59.21891413629055, 54.427584037184715, 68.00228342413902, 41.08130559325218, 32.942727506160736, 65.78365087509155, 56.59650765359402, 60.998176261782646, 50.814240127801895, 49.329215213656425, 44.214552864432335, 49.27934288978577, 46.17272078990936, 45.5973594635725, 43.5395722836256, 45.1234944909811, 47.59234361350536, 51.463347896933556, 57.88265883922577, 60.00282347202301, 55.8277253061533, 68.42505633831024, 58.58562111854553, 57.60552451014519, 41.30438782274723, 46.707367300987244, 41.68617993593216, 48.50284695625305, 45.292703211307526, 52.7508632093668, 59.1859395056963, 63.365658223629, 61.02122202515602, 64.2327032983303, 57.55277194082737, 55.807236805558205, 48.64491753280163, 50.832479149103165, 46.442130133509636, 51.470635905861855, 55.186403319239616, 61.895045936107635, 60.95664829015732, 65.35835489630699, 62.878851145505905, 70.53342640399933, 62.63165540993214, 66.39592722058296, 62.75134518742561, 71.91000133752823, 63.6457259953022, 78.10545489192009, 28.143307641148567, 0.2769635757431388, 2.2955264104530215, 2.0713104167953134, 0.5695522692985833, 0.6199665984604508, 0.16958046209765598, 0.2091823230148293, 6.572972796857357, 24.842519760131836, 31.015256233513355, 33.74427929520607, 57.64187715947628, 37.6206336915493, 25.207108296453953, 38.54727856814861, 42.771204113960266, 49.31325986981392, 61.41589164733887, 39.82131980359554, 0.9879861725494266, 0.060100272894487716, 0.020076209730177652, 0.03709283402713481, 0.0844639161368832, 0.007105104314177879, 0.027838772002724, 0.04269448676495813, 0.04445738064532634, 0.02816824289766373, 0.0930146522296127, 0.024742964196775574, 0.03807377885095775, 0.07923501820187084, 0.07036987866740674, 0.04372343741124496, 0.04633302160073072, 0.023319697502302006, 0.02876278853364056, 0.016148908944160212, 0.014937760115572019, 0.04832029269891791, 0.04204545635730028, 0.015360190573119326, 0.017494912499387283, 0.07454560967744328, 0.10939561776467599, 0.01912896583235124, 0.014066108597035054, 0.011004121388396015, 0.09791186210350133, 0.045906305240350775, 0.1087107638886664, 0.012435465432645287, 0.04422146674187388, 0.09566972265020013, 0.20901749201584607, 0.18118342151865363, 49.53103378415108, 85.21166637539864, 81.17093279957771, 75.76968982815742, 63.77355873584747, 54.71894860267639, 43.14034290611744, 71.21288314461708, 65.03959000110626, 24.12906624376774, 0.4667782934848219, 0.18222613900434226, 0.42100743390619755, 1.9090896402485669, 1.9772695004940033, 2.3673245077952743, 2.851199568249285, 0.7143489620648324, 21.614140793681145, 92.91680172085762, 73.10687631368637, 84.52621355652809, 75.63176482915878, 77.87790030241013, 75.25173962116241, 74.97208222746849, 74.93649333715439, 78.20586070418358, 72.53818362951279, 75.73243662714958, 68.94495204091072, 74.04702186584473, 74.50464650988579, 69.43909272551537, 61.546764224767685, 53.658448308706284, 49.187783002853394, 54.947179555892944, 64.14545997977257, 69.31781083345413, 70.99445566534996, 66.06006324291229, 63.83921921253204, 68.2223904132843, 61.13185688853264, 52.402030527591705, 50.652881786227226, 50.26944816112518, 46.405864879488945, 57.907342314720154, 68.06010112166405, 63.101488798856735, 57.746523544192314, 60.62877908349037, 64.55352008342743, 64.34227421879768, 61.82656981050968, 59.40730802714825, 57.682287991046906, 63.67797486484051, 64.81291696429253, 56.64014831185341, 55.93584090471268, 52.24740542471409, 55.472573563456535, 51.97663955390453, 60.59337638318539, 56.45197480916977, 69.5314809679985, 44.57818575203419, 35.48846550285816, 67.64219954609871, 59.87391538918018, 64.28331658244133, 53.67757648229599, 51.3423015922308, 44.924457371234894, 50.58796986937523, 49.06566135585308, 49.696499705314636, 44.569719806313515, 47.191009148955345, 48.33033241331577, 54.554333835840225, 58.97644154727459, 64.0512478351593, 58.83971728384495, 68.78905400633812, 62.35444888472557, 59.027263820171356, 44.28948864340782, 48.94548140466213, 45.53126201033592, 49.86232280731201, 47.540062218904495, 54.90832284092903, 62.8991724550724, 66.50162234902382, 63.26632395386696, 66.77694037556648, 62.591761350631714, 58.26661303639412, 51.57749757170677, 51.685917153954506, 48.28101105988026, 54.02589239180088, 57.58933737874031, 64.57800596952438, 64.78311136364937, 67.56877988576889, 65.65372824668884, 72.87273287773132, 65.69490283727646, 67.59701237082481, 66.99106648564339, 71.39718845486641, 67.91480451822281, 80.68581283092499, 32.73847706615925, 0.39419518201611936, 0.38564279093407094, 3.861597888171673, 2.987757115624845, 1.261176432017237, 0.303518035216257, 0.12223335506860167, 2.558646141551435, 34.10981968045235, 30.559115409851074, 35.930621176958084, 58.596154153347015, 32.237204164266586, 33.47275726497173, 48.75408187508583, 48.987168967723846, 57.10804000496864, 67.62364134192467, 56.281667947769165, 1.581008357461542, 0.12756703683407977, 0.023920586645544972, 0.0344549999863375, 0.05860078948899172, 0.028634862683247775, 0.012794726135325618, 0.08671082017826848, 0.04415429866639897, 0.026863074162974954, 0.01056682664057007, 0.010924149410129758, 0.02504210908227833, 0.04370482805825304, 0.035041040609939955, 0.03659702000732068, 0.03589227286283858, 0.05578969736234285, 0.03349419333972037, 0.025901914996211417, 0.10952563461614773, 0.12277106332476251, 0.1331852431758307, 0.10818123409990221, 0.1435140537796542, 0.2307956077856943, 0.26188061165157706, 0.08468166968668811, 0.1443173989537172, 0.12796046416042373, 0.29369538417086005, 0.12868340505519882, 0.2088481339160353, 0.16316876630298793, 0.13877832039725035, 0.19053034106036648, 0.5538336408790201, 0.23457594477804378, 61.20733603835106, 95.01788377761841, 96.00949376821518, 82.28394627571106, 73.23603138327599, 55.41170842945576, 50.08219800889492, 78.09066608548164, 77.70082980394363, 41.291992887854576, 0.7116480788681656, 0.28650554653722793, 0.47762273345142603, 2.1244959253817797, 6.2002265732735395, 3.7687368085607886, 8.00106631591916, 3.626585961319506, 23.300157822668552, 96.1748456954956, 76.43610566854477, 85.8624042570591, 78.72767150402069, 80.83593517541885, 76.34692445397377, 78.47398951649666, 76.11317619681358, 80.69061577320099, 73.66923093795776, 79.41440105438232, 70.79247370362282, 77.18512907624245, 76.36591583490372, 73.20403710007668, 62.75131098926067, 56.63635611534119, 52.38074027001858, 59.64477248489857, 67.20850601792336, 73.07406887412071, 72.89186865091324, 68.29182028770447, 66.06591492891312, 72.18903556466103, 62.559767067432404, 56.679753586649895, 52.63409547507763, 51.410618126392365, 48.469199761748314, 62.3453863710165, 70.60676246881485, 65.01617565751076, 58.577527552843094, 61.50649018585682, 68.25844287872314, 68.44887346029282, 64.06739696860313, 60.1605150103569, 58.57593543827534, 64.48063239455223, 67.57516354322433, 59.17021594941616, 57.84903824329376, 54.96224194765091, 58.915287628769875, 53.80640856921673, 63.86916160583496, 58.916256576776505, 72.56096720695496, 48.21006886661053, 39.904132559895515, 67.37742215394974, 61.10649324953556, 67.16933771967888, 56.78922191262245, 53.117646127939224, 47.79962249100208, 53.25142174959183, 51.93179436028004, 52.75116719305515, 48.01409438252449, 49.89435888826847, 50.873091369867325, 58.19611541926861, 62.473895475268364, 66.50085479021072, 61.01628988981247, 69.21792939305305, 65.71205511689186, 62.047657147049904, 45.973588675260544, 51.649290919303894, 47.133700624108315, 52.651688531041145, 49.37552332878113, 57.41447076201439, 67.02632859349251, 71.16298422217369, 64.13805037736893, 68.29743638634682, 64.3179327249527, 61.65673412382603, 52.810064032673836, 55.66152982413769, 50.70004865527153, 57.6757637411356, 61.8515382707119, 69.37124356627464, 68.29403176903725, 71.90753906965256, 69.76147502660751, 78.35821732878685, 68.0707785487175, 71.32065296173096, 69.53822940587997, 75.59577316045761, 71.3040554523468, 85.46721786260605, 32.59959451854229, 0.8708126319106668, 12.635423988103867, 7.725179744884372, 5.3633153066039085, 1.1595096811652184, 0.3659553051693365, 0.19981542485766113, 9.262846559286118, 39.18283246457577, 45.14097735285759, 43.971198722720146, 70.58593958616257, 48.056777492165565, 37.95803278684616, 52.772788032889366, 59.971801936626434, 67.32373103499413, 77.71814927458763, 61.65671892464161, 1.9033635850064456, 0.18319563620025292, 0.19764158525504172, 0.10940684645902365, 0.18260800366988406, 0.09756848521647044, 0.09659361487138085, 0.14135379547951743, 0.09635682523366995, 0.13747699413215742, 0.1889638602733612, 0.13698797818506137, 0.16779822413809597, 0.15294507349608466, 0.1760789446416311, 0.16282994620269164, 0.1649553977767937, 0.14505932398606092, 0.18814041774021462, 0.1515053812181577], [0.016546470033063088, 0.04518803245446179, 0.04112879636522848, 0.040894763806136325, 0.041926824051188305, 0.03203831111022737, 0.03600904608902056, 0.012121848667447921, 0.0398958664300153, 0.06103296698711347, 0.11456691019702703, 0.09345346930786036, 0.02527879853005288, 0.07044663158012554, 0.023085817083483562, 0.07586420571897179, 0.139480332727544, 4.323632195591927, 72.88841843605042, 72.7284774184227, 61.52041643857956, 47.86199614405632, 63.54729227721691, 28.596743009984493, 29.90717489272356, 24.512604363262653, 37.680328488349915, 4.7206448670476675, 0.0977423407312017, 0.13274755416205153, 0.307013105484657, 1.7828505579382181, 1.006869615521282, 1.044460404664278, 2.29456577450037, 0.4023292986676097, 52.52913370728493, 80.32792523503304, 72.75134459137917, 70.49663677811623, 74.10398080945015, 79.80274021625519, 73.2862114906311, 75.05084440112114, 70.2825790643692, 74.44544568657875, 71.35751098394394, 71.39129877090454, 75.57194083929062, 76.09435960650444, 64.50183525681496, 69.35903862118721, 55.99021978676319, 49.63860221207142, 47.45121918618679, 54.154420495033264, 63.805340230464935, 65.1143091917038, 60.893807262182236, 62.021639943122864, 67.55196958780289, 62.27946750819683, 53.51984694600105, 44.817071333527565, 47.97735035419464, 45.37050023674965, 46.6232094168663, 55.05819819867611, 62.089599296450615, 58.86067695915699, 60.54193094372749, 62.91693650186062, 63.04561659693718, 60.83685211837292, 59.229846149683, 60.63192531466484, 59.759366735816, 59.25730727612972, 59.29568141698837, 53.23328152298927, 54.44287821650505, 52.49210089445114, 56.25585213303566, 54.98669743537903, 58.937018662691116, 55.36349281668663, 65.83130031824112, 35.35045690834522, 34.90301571786404, 64.18461307883263, 53.369310423731804, 59.39381495118141, 46.06755003333092, 47.12358936667442, 46.062427908182144, 54.88732136785984, 56.8498058617115, 57.07958333194256, 45.53958736360073, 46.067291647195816, 46.28215491771698, 47.43401750922203, 51.70624226331711, 65.58305963873863, 49.108291268348694, 58.78558538854122, 58.445043861866, 59.52923968434334, 48.12208838760853, 42.561592161655426, 43.97117592394352, 43.835941180586815, 45.342009365558624, 48.818013444542885, 58.370985835790634, 62.38727532327175, 64.70848336815834, 63.247146382927895, 60.6368612498045, 50.74548281729221, 47.1978297829628, 48.52438040077686, 47.29411281645298, 49.55814532935619, 55.328990668058395, 58.251387253403664, 62.99094133079052, 64.635990858078, 63.25291447341442, 65.23872971534729, 66.07204779982567, 64.88317519426346, 67.7382279932499, 66.88173115253448, 68.80751341581345, 64.97557863593102, 72.01312020421028, 8.615552242845297, 1.4082677266560495, 0.9911126922816038, 1.8302195286378264, 1.4629731536842883, 0.1767205906799063, 0.030500070897687692, 0.5044967320282012, 16.183183416724205, 46.97048418223858, 30.10603342205286, 29.422586895525455, 63.30804951488972, 26.67034137994051, 28.042058274149895, 37.978452891111374, 50.84184564650059, 55.19085668027401, 64.81755271553993, 9.913086667656898, 0.7003018877003342, 0.0927302983473055, 0.09260114980861545, 0.06833020452177152, 0.03813592629740015, 0.05227687492151745, 0.028370005020406097, 0.06884827555040829, 0.05208994647546206, 0.0236734774443903, 0.0031354076463685487, 0.05014983886212576, 0.08013956263312139, 0.02016625636315439, 0.00319336868415121, 0.04350114562839735, 0.06870118930237368, 0.06506897756480612, 0.0436965605331352, 0.008474854275846155, 0.031045514188008383, 0.023274298473552335, 0.031919500688673, 0.05193347577005625, 0.016883440330275334, 0.012604176936292788, 0.03814847601461224, 0.04287606803700328, 0.03524849314999301, 0.10875586420297623, 0.029537262307712808, 0.03693112375913188, 0.03824878469458781, 0.051332224829820916, 0.10097987091285177, 0.15770857804454863, 6.958600329235196, 88.97962778806686, 79.32265117764473, 75.62480360269547, 53.28982628881931, 75.13658300042152, 36.352805122733116, 28.504259772598743, 30.21798111498356, 44.15255919098854, 6.519769951701164, 0.07496510865166783, 0.18336505367187783, 1.0748318186961114, 1.7572034779004753, 2.3747528716921806, 2.9114279989153147, 1.6848231805488467, 0.7666430028621107, 54.479249864816666, 85.29195606708527, 75.94533160328865, 72.55702301859856, 75.77847495675087, 80.92662870883942, 74.29613649845123, 77.96672433614731, 73.30163106322289, 76.32991656661034, 72.63702392578125, 73.45224738121033, 74.6911709010601, 77.65272438526154, 69.31723326444626, 71.04687765240669, 60.87772272527218, 51.90458782017231, 48.70857171714306, 56.33243702352047, 66.64791449904442, 68.00093069672585, 61.200310215353966, 64.03437674045563, 70.28527691960335, 65.87525635957718, 55.87865777313709, 46.45707093179226, 49.49853412806988, 47.832030951976776, 48.04942488670349, 56.584002524614334, 64.450424015522, 60.05504786968231, 62.444036677479744, 66.39774352312088, 64.56882566213608, 62.96078994870186, 63.57378825545311, 63.69264967739582, 59.56554293632507, 62.017182782292366, 62.42286041378975, 56.361794248223305, 58.03544104099274, 54.747044295072556, 57.964179664850235, 60.04959516227245, 61.079115718603134, 58.86735700070858, 68.75558540225029, 37.80197896063328, 37.747653275728226, 65.93815818428993, 57.66779936850071, 62.49307684600353, 47.34528847038746, 50.85039518773556, 48.59581656754017, 56.76564037799835, 58.11407022178173, 61.4063161611557, 49.10022430121899, 47.899705320596695, 47.341940850019455, 48.545879647135735, 55.13646259903908, 65.32393634319305, 54.025390818715096, 59.3868613243103, 63.111007288098335, 62.83013395965099, 49.84745420515537, 45.90667426586151, 46.30578964948654, 47.99939677119255, 47.99876980483532, 50.97711838781834, 61.36512637138367, 64.28707078099251, 64.17758345603943, 66.25962093472481, 62.64761455357075, 52.16577060520649, 49.78519834578037, 51.266993433237076, 50.0392185151577, 52.45622701942921, 57.718165665864944, 61.45710043609142, 64.84200060367584, 68.11299428343773, 65.84854379296303, 69.67018872499466, 67.64349147677422, 67.78013214468956, 69.19826164841652, 69.4211196899414, 70.11971980333328, 67.45304569602013, 76.31146475672722, 11.418833769857883, 1.1384000326506793, 0.03455375015619211, 3.6527651315554976, 2.757145115174353, 0.9603942499961704, 0.06344779307255521, 0.8037909376434982, 15.908740293234587, 54.85310040414333, 28.480661138892174, 42.81783901154995, 56.189321503043175, 28.11183203011751, 39.90966126322746, 47.41869293153286, 60.11219680309296, 61.24701730906963, 75.57564944028854, 17.230015844106674, 0.7959287439007312, 0.122420428233454, 0.11243715416640043, 0.006210635465322412, 0.04722884208604228, 0.011838314858323429, 0.014166304099489935, 0.08458923519356176, 0.013203051148593659, 0.026412779770907946, 0.031122864529606886, 0.017031367060553748, 0.06114477895607706, 0.05288252308673691, 0.05838464268890675, 0.048896184453042224, 0.06948129783268087, 0.0735988889937289, 0.03780329199798871, 0.06586500516277738, 0.16075383260613307, 0.14796955219935626, 0.14920993329724297, 0.14006385375978425, 0.11396817513741553, 0.07615763606736436, 0.13669488922460005, 0.1631848857505247, 0.17914984782692045, 0.20972542668459937, 0.1418993779225275, 0.08974918018793687, 0.12118018072214909, 0.14611191203584895, 0.21573774312855676, 0.26779950654599816, 8.363827150315046, 103.72806519269943, 91.4310510456562, 85.86852192878723, 62.625978514552116, 80.95558315515518, 36.25440940260887, 42.867707535624504, 37.21215561032295, 56.2611148506403, 8.897672854363918, 0.33501683094073087, 0.32943012134637684, 1.6325328801758587, 5.537877939641476, 3.819812717847526, 5.1982896868139505, 8.981831688433886, 0.7671965262852609, 59.241386130452156, 87.02256560325623, 78.15705612301826, 77.57058799266815, 77.84152865409851, 83.76267492771149, 76.26332134008408, 78.9274799823761, 74.87464785575867, 78.85000213980675, 75.94540759921074, 73.72116655111313, 73.9484703540802, 78.67152571678162, 75.61775118112564, 75.38179144263268, 63.49661059677601, 55.38201302289963, 50.56325979530811, 59.55195486545563, 70.16781762242317, 70.11488646268845, 63.69369462132454, 64.71467703580856, 72.94049844145775, 68.96287947893143, 60.00755801796913, 47.94832371175289, 52.18257710337639, 50.504564344882965, 51.99859477579594, 59.18373562395573, 66.14527747035027, 61.4529662579298, 64.85186487436295, 70.02425372600555, 67.88876831531525, 65.7571130990982, 64.60607886314392, 64.04281988739967, 63.711048290133476, 64.86037641763687, 65.52910253405571, 59.185586124658585, 61.419243067502975, 59.08824674785137, 62.33652524650097, 62.040110751986504, 63.34963448345661, 61.14626571536064, 72.04206705093384, 41.226305812597275, 42.87039399147034, 68.35417494177818, 59.813289642333984, 64.76840615272522, 50.31247325241566, 52.484687492251396, 50.98536014556885, 58.69654096662998, 59.70340333878994, 63.39007571339607, 51.8957494944334, 50.07440462708473, 51.05469882488251, 50.157407373189926, 60.14492064714432, 70.75626164674759, 56.790612637996674, 63.40169169008732, 61.86798758804798, 65.72751268744469, 53.183777779340744, 49.516092985868454, 47.61015705764294, 50.93741051852703, 49.85357567667961, 53.05727116763592, 64.64197933673859, 67.87898004055023, 66.34667426347733, 68.97190779447556, 66.44304469227791, 55.590412840247154, 52.17757277190685, 53.59210766851902, 53.037409633398056, 54.68206398189068, 60.8243203908205, 64.35468435287476, 68.85740473866463, 70.38097858428955, 67.98844456672668, 71.07473775744438, 71.9592010974884, 71.60939946770668, 73.05275201797485, 73.53901952505112, 72.83761516213417, 70.88735461235046, 79.69353407621384, 11.981089599430561, 4.687518244609237, 8.453104309737682, 8.66492584347725, 4.791943766176701, 0.8750678692013025, 0.14726485329447314, 0.9582324628718197, 22.759823016822338, 69.48533624410629, 43.620876520872116, 39.60457183420658, 77.06725180149078, 38.86820174753666, 42.75308668613434, 52.358538061380386, 70.06632506847382, 71.35215327143669, 86.00344508886337, 20.607346817851067, 0.9780936408787966, 0.2122795575996861, 0.21055590477772057, 0.18366315955063328, 0.11401332740206271, 0.14468657289398834, 0.13751563034020364, 0.1966518719564192, 0.16886011871974915, 0.11819029037724249, 0.13847487105522305, 0.12499328353442252, 0.30238738807383925, 0.07913211200502701, 0.11653954614303075, 0.1395265239989385, 0.24755279766395688, 0.12993053969694301, 0.08973457472166047], [0.016337811503035482, 0.04416264782776125, 0.015733489926788025, 0.02441252665448701, 0.07782016560668126, 0.050012489591608755, 0.031247960941982456, 0.0911626523884479, 0.06832792612840421, 0.06973749463213608, 0.01794289881217992, 0.0598523547523655, 0.034895813441835344, 0.06907549148309045, 0.13243997847894207, 0.13086686289170757, 0.11459052533609793, 23.708430714905262, 82.10148006677628, 68.06816428899765, 52.116768434643745, 71.3000276684761, 50.18161587417126, 30.338503047823906, 47.66454353928566, 37.45166435837746, 32.18402221798897, 0.7767077127937227, 0.10617662643198855, 0.0177146568603348, 0.8776529179885983, 1.0048964526504278, 1.0536080575548112, 0.7590359298046678, 2.5448680808767676, 6.718293623998761, 68.24199736118317, 73.79280030727386, 77.72919148206711, 72.53542497754097, 74.95889693498611, 69.3473656475544, 74.3012510240078, 66.93707138299942, 69.21973049640656, 69.11919549107552, 71.52728587388992, 71.17984771728516, 71.66013434529305, 59.93476152420044, 67.51027062535286, 67.15881988406181, 54.57556709647179, 48.42553250491619, 46.7432601749897, 56.03895217180252, 69.19803366065025, 63.33272159099579, 62.52590708434582, 63.742320612072945, 62.67685778439045, 58.15808705985546, 49.76288594305515, 43.05165946483612, 48.110928386449814, 44.080385863780975, 46.879566460847855, 52.63807386159897, 63.25269788503647, 61.65770687162876, 65.85034489631653, 57.313099801540375, 59.70562621951103, 56.09477497637272, 59.2794106900692, 56.71061933040619, 60.55752910673618, 58.49625751376152, 58.25572282075882, 55.397421196103096, 60.38164794445038, 54.9902768433094, 60.38271948695183, 54.437744691967964, 59.142401441931725, 55.27512475848198, 67.05157443881035, 40.407658740878105, 37.88074493408203, 62.184818387031555, 53.04369829595089, 54.793170019984245, 45.14780938625336, 47.86985032260418, 50.72408236563206, 58.57630401849747, 58.85885685682297, 63.14549803733826, 51.042957454919815, 44.828569516539574, 43.265246003866196, 42.753538861870766, 47.82216288149357, 60.63436098396778, 58.36354583501816, 49.00372467935085, 61.841810792684555, 58.297326788306236, 53.846101239323616, 43.81533868610859, 43.95707108080387, 44.00950826704502, 44.82818193733692, 48.505362421274185, 58.26393038034439, 60.25194950401783, 63.44365283846855, 61.290992349386215, 58.95327419042587, 48.31577159464359, 46.55270799994469, 48.17921832203865, 47.01583094894886, 50.31253404915333, 50.85810497403145, 58.566990718245506, 60.653538554906845, 63.18073354661465, 62.34261251986027, 63.90824630856514, 61.355930864810944, 60.99339231848717, 66.91480457782745, 62.52290144562721, 68.7521655857563, 63.96462768316269, 70.46835869550705, 50.81864409148693, 0.27394549862947315, 2.741413009352982, 2.4306908575817943, 1.1267265840433538, 0.5126902204938233, 0.10594244915409945, 0.07429278222844005, 2.976863100193441, 30.396829918026924, 45.67448012530804, 29.96229663491249, 58.958593904972076, 61.42691105604172, 17.842033803462982, 25.84929283708334, 43.102470338344574, 52.91131719946861, 55.89685879647732, 43.61274875700474, 3.0603581573814154, 0.15350395522546023, 0.04050231982546393, 0.032865961620700546, 0.034249384261784144, 0.021016447753936518, 0.07309449574677274, 0.047942780729499646, 0.024005935483728535, 0.002610254905448528, 0.0640520868182648, 0.018300159426871687, 0.08849208592437208, 0.0014884898791933665, 0.024245606509794015, 0.06290460776654072, 0.01944719875609735, 0.01223515328092617, 0.04291171338991262, 0.025897836894728243, 0.07084421493345872, 0.036198850357322954, 0.04068016067321878, 0.10119853730429895, 0.028376268746796995, 0.020413189304235857, 0.05661997878632974, 0.046879780347808264, 0.07385750519460998, 0.05389016667322721, 0.06026297021890059, 0.023487526777898893, 0.024360949246329255, 0.05483053086209111, 0.11681184754706919, 0.06957216639420949, 31.33883737027645, 93.08514788746834, 74.02793169021606, 61.52686849236488, 73.36686596274376, 66.30383536219597, 37.87724532186985, 39.74394455552101, 38.95449511706829, 40.72497211396694, 1.4348342386074364, 0.06933758093509823, 0.23109163565095514, 2.5954668782651424, 1.2862846534699202, 3.158426145091653, 2.6595321530476213, 1.0974639980122447, 7.82022119499743, 70.80689772963524, 75.17467975616455, 78.40472683310509, 75.77890813350677, 76.49960026144981, 70.04686251282692, 77.7416244149208, 66.80315136909485, 69.4764219224453, 69.55645322799683, 73.33943903446198, 73.51039186120033, 73.99509385228157, 64.75548684597015, 70.2144031226635, 69.87739160656929, 56.863450929522514, 51.58714905381203, 48.67401257157326, 59.15981970727444, 70.8424562215805, 66.73434466123581, 64.20377925038338, 64.71790686249733, 67.62997940182686, 61.221953853964806, 52.729816138744354, 45.754253044724464, 49.85568456351757, 46.66004844009876, 49.32014890015125, 54.870689660310745, 63.835677802562714, 64.24790248274803, 66.90829172730446, 62.18562014400959, 61.54931768774986, 58.55610050261021, 61.628923416137695, 60.900297313928604, 63.37025597691536, 61.13700561225414, 60.42115822434425, 60.05695536732674, 62.938063368201256, 57.489645928144455, 61.951168924570084, 56.29007689654827, 61.89757660031319, 56.907030791044235, 68.67597207427025, 42.09810063242912, 39.29684914648533, 65.02660229802132, 57.06710860133171, 58.018554747104645, 47.51603230834007, 50.103245079517365, 53.08646500110626, 60.58603137731552, 60.98584212362766, 64.38267365098, 54.87054146826267, 46.58482387661934, 45.613671988248825, 46.01007431745529, 50.55873803794384, 61.725179851055145, 60.10333187878132, 52.24256828427315, 62.88851782679558, 63.07969316840172, 55.861364901065826, 46.88933573663235, 45.23808114230633, 46.017502918839455, 47.463606521487236, 50.1907429844141, 59.90108013153076, 63.05771514773369, 64.04291868209839, 64.38195928931236, 60.93719333410263, 52.210262417793274, 48.423571810126305, 50.41039019823074, 49.294656068086624, 53.14367473125458, 53.46185825765133, 61.21635675430298, 62.763565331697464, 65.97514539957047, 65.65525576472282, 66.78431957960129, 64.76918891072273, 62.61060833930969, 69.19227316975594, 64.94041532278061, 70.47960609197617, 66.91687166690826, 72.31082662940025, 57.88129851222038, 0.580004439689219, 0.9498315886594355, 3.2426274893805385, 2.265596129000187, 1.3787181372754276, 0.3751074703177437, 0.1774340172414668, 1.1591686494648457, 40.12476772069931, 43.67564678192139, 29.53632429242134, 61.481042951345444, 52.5906828045845, 24.028229154646397, 37.573740407824516, 51.45620808005333, 61.98715299367905, 63.53754200041294, 57.44511231780052, 4.175663385540247, 0.1741925982059911, 0.008140821955748834, 0.024605941471236292, 0.058551607362460345, 0.029600443194794934, 0.04743047247757204, 0.06292600388405845, 0.04311305805458687, 0.03068078756768955, 0.016786478736321442, 0.05856635012605693, 0.07198459905339405, 0.029044602415524423, 0.04584498157782946, 0.028608067441382445, 0.0703553696803283, 0.05365976692701224, 0.05960902308288496, 0.09616507653845474, 0.1733080472331494, 0.13278644270030782, 0.2529535547364503, 0.19634695316199213, 0.11608368935412727, 0.11817149177659303, 0.14674806618131697, 0.20073996274732053, 0.1442935611703433, 0.17270905984332785, 0.14017624460393563, 0.19637784134829417, 0.18459002778399736, 0.18946117343148217, 0.2126873380620964, 0.29576366068795323, 41.566999331116676, 106.3088259100914, 84.82975646853447, 71.97625458240509, 86.6748158633709, 63.87839511036873, 41.755514815449715, 66.49893209338188, 54.45626109838486, 52.398660108447075, 1.7481566383503377, 0.3143758635269478, 0.4111400165129453, 5.342566519975662, 4.839529562741518, 2.397159319370985, 5.80987399443984, 6.120034726336598, 8.463302962481976, 74.34874847531319, 77.4878740310669, 81.96585014462471, 77.47540310025215, 80.81346318125725, 71.63690999150276, 78.94735291600227, 68.46638292074203, 71.48443177342415, 71.10239267349243, 72.75400444865227, 71.77969112992287, 75.19231081008911, 69.24880653619766, 75.39091095328331, 72.35505625605583, 60.05625240504742, 52.414231672883034, 51.07694663107395, 61.52767404913902, 74.2206421494484, 69.18595790863037, 66.1336424946785, 66.09469458460808, 70.12758538126945, 62.039510384202, 55.13985961675644, 48.02351027727127, 53.21074113249779, 48.834306970238686, 51.69334955513477, 58.3400858938694, 68.02530258893967, 64.90725830197334, 70.81858590245247, 65.16584202647209, 65.79666137695312, 62.68202170729637, 64.46857944130898, 64.0230305492878, 64.17859420180321, 63.16502898931503, 61.617596223950386, 62.1629923582077, 64.10465776920319, 59.4304183870554, 64.91766974329948, 60.706534311175346, 64.0935243666172, 59.42716956138611, 69.33674901723862, 45.62629111111164, 45.11464096605778, 67.27493405342102, 61.60659581422806, 61.631932854652405, 50.4366809874773, 52.177291586995125, 55.56635633111, 63.13305750489235, 64.48561012744904, 69.13691774010658, 55.87504796683788, 50.015769973397255, 48.10455232858658, 47.52373829483986, 52.20456272363663, 66.94596290588379, 62.201488092541695, 55.37454642355442, 65.82495465874672, 65.68436220288277, 58.97371709346771, 48.560748249292374, 47.228353545069695, 48.83762799203396, 49.09340746700764, 53.83754029870033, 63.123406022787094, 65.47096565365791, 68.35077792406082, 66.78178131580353, 63.63986290991306, 53.56018178164959, 51.606372222304344, 53.46359856426716, 52.15970993041992, 54.54207569360733, 57.16853655874729, 64.21604499220848, 64.39043283462524, 68.91716033220291, 67.61245474219322, 69.34461459517479, 66.40543431043625, 66.6303214430809, 71.44933685660362, 68.51938247680664, 73.60945254564285, 70.91896891593933, 75.35564124584198, 59.491576105356216, 0.39852237794548273, 8.790074028074741, 9.850736763328314, 6.965304119512439, 1.9658950483426452, 0.2865973947336897, 0.1861517588258721, 4.1491935309022665, 47.66502991318703, 60.414299592375755, 42.87881813943386, 70.43191865086555, 69.93078634142876, 28.47376260906458, 39.22348268330097, 60.03124974668026, 69.12624031305313, 72.39596486091614, 65.32728776335716, 5.196503307670355, 0.28795982943847775, 0.11762431371607818, 0.1726601374684833, 0.16784092731541023, 0.17477568879257888, 0.1667162321973592, 0.15059136698255315, 0.18739013612503186, 0.12624884897377342, 0.09482662062509917, 0.11284854146651924, 0.210076789080631, 0.10924865026026964, 0.11307612105156295, 0.23311608092626557, 0.09731507147080265, 0.18212657247204334, 0.16794620838481933], [0.06890130942338146, 0.044107881039963104, 0.03804118372499943, 0.04861705900111701, 0.06827828387031332, 0.014983150795160327, 0.030398597045859788, 0.00709243353412603, 0.038326031135511585, 0.02120591434504604, 0.03412255122384522, 0.041847755637718365, 0.034223405382363126, 0.0413536967971595, 0.048819160656421445, 0.13530300610000268, 1.9389030779711902, 68.5481545329094, 72.22753509879112, 66.32275834679604, 75.96721082925797, 52.666522935032845, 16.174899861216545, 29.693261571228504, 37.108295783400536, 38.65533336997032, 12.400980368256569, 0.11095034293248318, 0.07014491886366159, 0.6589369510766119, 0.6577425682917237, 0.356267160968855, 3.5231894720345736, 2.1400639275088906, 0.35826998006086797, 24.82877779752016, 74.2528948187828, 70.21379515528679, 74.35365781188011, 69.92275357246399, 77.41277486085892, 74.45131257176399, 62.21857197582722, 66.55801892280579, 69.18372362852097, 67.29167595505714, 66.06954753398895, 65.03548622131348, 60.053284764289856, 68.24191376566887, 67.71479845046997, 60.54812841117382, 51.24530799686909, 48.77628028392792, 46.68850511312485, 54.11161959171295, 63.033624440431595, 62.24049299955368, 69.83986482024193, 63.04240196943283, 60.819563046097755, 56.16571716964245, 46.72273367643356, 45.00160463154316, 47.90144942700863, 46.22289329767227, 46.03167235851288, 49.069001376628876, 58.04064676165581, 61.776321306824684, 59.80350896716118, 56.27532608807087, 51.80431880056858, 54.097628742456436, 60.28848834335804, 55.89466631412506, 59.55058693885803, 60.08088268339634, 57.89156176149845, 59.205618649721146, 59.01830390095711, 58.46246212720871, 59.48923923075199, 58.11826139688492, 62.96560049057007, 58.432709723711014, 60.0322300940752, 35.65206952393055, 37.95588210225105, 66.2599629163742, 57.24873885512352, 55.82865625619888, 50.06170190870762, 52.74175129830837, 53.18295702338219, 58.52877616882324, 58.4859524667263, 57.88814574480057, 55.38075149059296, 45.585048124194145, 44.017837420105934, 45.18477380275726, 47.90902242064476, 54.478493705391884, 61.68275512754917, 50.60129575431347, 56.34855575859547, 61.19739957153797, 55.23793615400791, 45.93823157250881, 42.51763232052326, 44.44699019193649, 43.53887692093849, 46.30781874060631, 53.995874002575874, 62.169991582632065, 62.55164310336113, 62.44458764791489, 59.36725437641144, 52.67593502998352, 44.64504696428776, 48.444048911333084, 46.259975507855415, 47.242006212472916, 51.54990345239639, 57.15263441205025, 61.267942786216736, 64.79230687022209, 62.10724554955959, 64.99579355120659, 60.09599827229977, 64.56793650984764, 60.67064143717289, 62.79116705060005, 61.52607813477516, 69.17694479227066, 63.07910040020943, 72.37376645207405, 17.58256282657385, 0.5584387562703341, 1.4185207639820874, 4.212761269882321, 0.8156636380590498, 0.46555461070965976, 0.1507387129822746, 0.11595517906243913, 15.992013774812222, 33.67290772497654, 65.63518524169922, 89.48296397924423, 95.04793256521225, 46.81908130645752, 22.156631983816624, 36.234407275915146, 47.43846707046032, 54.392124339938164, 65.05041942000389, 20.501435101032257, 0.9032903204206377, 0.049875296172103845, 0.09241471489076503, 0.05766676695202477, 0.104388621984981, 0.038330242823576555, 0.02347821653529536, 0.023754755602567457, 0.1300654621445574, 0.012820184583688388, 0.05217235826421529, 0.03784169442951679, 0.0533700027881423, 0.02793179650325328, 0.07273145936778747, 0.015834704026929103, 0.037858682189835235, 0.019785185795626603, 0.03855378883599769, 0.03535264615493361, 0.054399888540501706, 0.03838947734038811, 0.10695703924284317, 0.038603423672611825, 0.006901615770402714, 0.05151114550244529, 0.036810728852287866, 0.029902760761615355, 0.07241373110446148, 0.04010148586530704, 0.019057060999330133, 0.0578336574108107, 0.04978071687219199, 0.06969623122131452, 3.2744723930954933, 82.69547939300537, 79.45330336689949, 76.96764394640923, 80.48134580254555, 62.935867086052895, 26.024661026895046, 32.41723470389843, 27.059400603175163, 41.471685245633125, 16.994293592870235, 0.08072450858890079, 0.20702458801679313, 2.008183691650629, 3.1283927941694856, 2.17874513939023, 5.634254068136215, 1.7036210093647242, 0.863508889451623, 29.069418646395206, 76.72039121389389, 71.93053543567657, 77.09131211042404, 73.15764918923378, 77.53909528255463, 71.63624122738838, 66.52817532420158, 67.89448320865631, 70.55045709013939, 68.17457377910614, 70.0422951579094, 68.39179292321205, 65.00891044735909, 69.78013962507248, 71.18124604225159, 64.26129296422005, 55.90731203556061, 52.27210029959679, 49.78567712008953, 57.58702710270882, 66.43287643790245, 63.572925701737404, 69.6359221637249, 64.53208163380623, 64.54899832606316, 60.24611681699753, 49.5617513358593, 47.34819531440735, 49.662377536296844, 47.907757088541985, 48.75905580818653, 51.48721821606159, 59.99357096850872, 61.45884454250336, 62.307753190398216, 57.988688349723816, 54.16776157915592, 55.88314153254032, 63.709779158234596, 59.759104549884796, 60.97739517688751, 62.271119356155396, 61.15202620625496, 60.76544634997845, 61.34360432624817, 59.4345373660326, 62.000554874539375, 60.244836285710335, 64.90023627877235, 60.48983193933964, 60.68047530949116, 39.5291268825531, 40.71025550365448, 67.70829319953918, 58.459148705005646, 58.37171159684658, 52.36328400671482, 53.758470341563225, 55.47276355326176, 61.69844068586826, 60.633164048194885, 59.519880786538124, 58.2196019589901, 48.39956469833851, 47.183470353484154, 47.26235792040825, 50.203145518898964, 57.32704125344753, 64.05102744698524, 52.9647271335125, 57.305656000971794, 61.7324298620224, 59.139091819524765, 46.56023919582367, 46.50978170335293, 46.085538268089294, 47.28965565562248, 48.351318687200546, 57.56705157458782, 64.56341475248337, 64.51832637190819, 64.01022523641586, 63.84817153215408, 53.336434587836266, 47.86894977092743, 49.31851118803024, 48.77946451306343, 48.8663924485445, 54.00698080658913, 60.98783701658249, 64.1027806699276, 65.94858482480049, 64.19570848345757, 65.76522946357727, 63.330479711294174, 67.54065379500389, 65.37768065929413, 64.86524775624275, 64.84584599733353, 70.03670185804367, 67.4441009759903, 75.06288975477219, 20.96481453627348, 0.6521533650811762, 0.9930347953923047, 3.894635927863419, 3.2124844193458557, 1.5268718311563134, 0.230420274019707, 0.5205131694674492, 12.936748769134283, 40.768871158361435, 54.34651158750057, 88.655436784029, 87.98202931880951, 41.88533864915371, 27.689032517373562, 46.02924808859825, 53.33691716194153, 59.93042215704918, 73.40281963348389, 27.93916169553995, 0.8195663255173713, 0.09681461902800947, 0.19270450720796362, 0.08437334443442523, 0.10247886079014279, 0.023651726951356977, 0.12715239892713726, 0.07211954376543872, 0.09275808435631916, 0.010839021360879997, 0.07695614986005239, 0.038090651578386314, 0.06450402506743558, 0.03474810750049073, 0.020244988954800647, 0.021195668996369932, 0.06483280390966684, 0.05074945707747247, 0.1949272840283811, 0.15184881747700274, 0.17123319528764114, 0.1250832318328321, 0.15825095440959558, 0.10123981555807404, 0.13542298169340938, 0.12284944154089317, 0.12200787576148286, 0.10900006047450006, 0.2687222039094195, 0.2193342352984473, 0.12526767037343234, 0.08964354288764298, 0.1444566555437632, 0.21702850121073425, 4.202853301540017, 94.75881367921829, 88.30587834119797, 88.44828709959984, 94.65827867388725, 69.56992730498314, 25.348367616534233, 41.32114112377167, 52.390049770474434, 56.28528535366058, 21.087291464209557, 0.24281023652292788, 0.262981602572836, 2.472049738280475, 5.145206060260534, 2.109137149527669, 9.552353974431753, 8.657759428024292, 1.3913105428218842, 33.94938848912716, 80.63365682959557, 74.39640551805496, 79.32448267936707, 74.8415820300579, 78.58248129487038, 73.35857480764389, 68.38716477155685, 69.26439329981804, 73.06678086519241, 71.23635828495026, 71.88156366348267, 73.74049231410027, 69.4031086564064, 72.36710920929909, 73.93802091479301, 65.83446934819221, 57.060166373848915, 54.275527596473694, 51.235838904976845, 59.23728235065937, 68.74083459377289, 66.67205080389977, 70.72718560695648, 66.75685465335846, 65.963776409626, 61.90784364938736, 51.34595699608326, 49.39826510846615, 51.113170087337494, 50.4028932005167, 51.446780785918236, 53.22734624147415, 64.62598979473114, 66.9614052772522, 64.3995675444603, 63.33902545273304, 56.67275436222553, 60.988665372133255, 65.73933765292168, 62.92564943432808, 61.84868082404137, 66.0327199101448, 63.6580715328455, 64.76364880800247, 62.92627640068531, 64.33301031589508, 63.52368414402008, 62.95623019337654, 66.86098426580429, 62.26569704711437, 61.08095861971378, 43.376876413822174, 45.13811610639095, 71.49260893464088, 61.55341386795044, 61.34625658392906, 57.24547863006592, 58.58041159808636, 58.77720303833485, 62.59189814329147, 62.13345654308796, 62.041604071855545, 60.3924697637558, 50.83866901695728, 49.62184891104698, 50.687619522213936, 52.66396187245846, 61.65311671793461, 67.63348281383514, 55.257626697421074, 59.25412304699421, 63.775618225336075, 63.399347215890884, 49.461907893419266, 49.97914753854275, 47.66477532684803, 50.92648610472679, 50.73257490992546, 59.74709339439869, 67.99140080809593, 67.0235775411129, 65.82587420940399, 66.18197590112686, 56.53227970004082, 50.37812992930412, 53.20798248052597, 51.41874209046364, 51.92857213318348, 58.79917345941067, 64.71682772040367, 65.79120486974716, 69.46756839752197, 66.37419998645782, 68.24332728981972, 65.48164308071136, 71.60619243979454, 67.43628859519958, 69.00001108646393, 65.58361440896988, 74.28757935762405, 70.00089257955551, 77.45137318968773, 20.71541301906109, 1.8739062594249845, 9.067788776010275, 7.923337686806917, 4.727162467315793, 1.49471296928823, 0.42597151128575206, 0.865677623078227, 20.282724536955357, 53.175023049116135, 78.2159149646759, 92.49827697873116, 102.50386968255043, 59.39461290836334, 36.384582817554474, 49.693429470062256, 64.07490536570549, 69.01904046535492, 83.69815438985825, 32.056660652160645, 1.1091135791502893, 0.4303811152931303, 0.3644237498519942, 0.16000910225557163, 0.22956150525715202, 0.16911943996092305, 0.1796288596233353, 0.11247184957028367, 0.1848681253613904, 0.11264223183388822, 0.18413621932268143, 0.19901877385564148, 0.12749354937113822, 0.15582983120111749, 0.22936464316444471, 0.1810689378180541, 0.22014709480572492, 0.11747205469873734], [0.01302303859120002, 0.09123417316004634, 0.004685352687374689, 0.02075143980619032, 0.06532306666485965, 0.018269124666403513, 0.060020640448783524, 0.08156478303135373, 0.10573533800197765, 0.038108084627310745, 0.10236101516056806, 0.03555919698555954, 0.10433246367028914, 0.06249185491469689, 0.1430811738828197, 0.1857275768998079, 20.94013676047325, 84.02836427092552, 73.99646937847137, 53.01755949854851, 59.89348813891411, 44.387462586164474, 28.176061883568764, 53.15341740846634, 47.5130532681942, 41.22889347374439, 10.697669517248869, 0.09119757043663412, 0.2263508556643501, 1.173653353471309, 0.2507036895258352, 1.123234808910638, 5.864248601719737, 1.4051096211187541, 3.1543131032958627, 53.115544840693474, 71.43881902098656, 73.64724531769753, 73.3494020998478, 71.73524111509323, 77.32620790600777, 57.60826796293259, 64.6245002746582, 71.24255955219269, 68.55310186743736, 71.60900428891182, 67.76116356253624, 66.47003844380379, 71.93666830658913, 67.53839671611786, 63.15927989780903, 51.55080020427704, 48.04825834929943, 47.42905117571354, 45.713994204998016, 50.470324382185936, 57.360665649175644, 61.5263707190752, 61.49954795837402, 62.030318677425385, 62.74624586105347, 58.526978865265846, 51.694713681936264, 47.8561482578516, 47.439869195222855, 45.89238703250885, 45.59488579630852, 46.76588796079159, 52.63065665960312, 53.77480946481228, 54.0993120521307, 47.37349435687065, 49.308582320809364, 55.33741481602192, 61.17274649441242, 56.45941101014614, 55.23168548941612, 56.896387562155724, 57.48048081994057, 59.8027566075325, 59.195002019405365, 55.866825208067894, 61.79212085902691, 56.330195143818855, 61.00401654839516, 56.13467663526535, 55.58999486267567, 36.3641133159399, 37.782751992344856, 62.884794026613235, 53.23417827486992, 54.599129632115364, 54.594816863536835, 55.817116275429726, 55.53645573556423, 58.60265180468559, 58.99620808660984, 59.9749443680048, 54.6964044123888, 50.81447571516037, 43.94132472574711, 43.12305003404617, 44.1659876704216, 49.47663590312004, 59.22534339129925, 57.16512054204941, 49.814449176192284, 64.49024587869644, 56.132674142718315, 50.5372653901577, 44.386983811855316, 44.45183493196964, 44.20371204614639, 45.5815789103508, 49.889320358633995, 61.75318814814091, 60.22755101323128, 62.77549669146538, 57.43568882346153, 52.93670363724232, 45.81519037485123, 46.198764592409134, 46.12977549433708, 48.681213185191154, 50.208788216114044, 56.47734224796295, 58.56780007481575, 61.92303143441677, 60.389980897307396, 61.84316731989384, 60.10234013199806, 61.22882768511772, 58.65606553852558, 57.91095972061157, 61.11452601850033, 66.34548872709274, 64.03647422790527, 70.04036486148834, 56.62128992378712, 0.9790972620248795, 2.0831764675676823, 1.7799891927279532, 1.1589121632277966, 0.7830330077558756, 0.2656395599478856, 0.04372510353277903, 2.698409054428339, 32.8670659661293, 29.25474800169468, 45.722885727882385, 57.595181465148926, 63.24753016233444, 20.33149491995573, 23.31944178789854, 34.338157027959824, 49.56941932439804, 62.193744108080864, 58.27454321086407, 4.382680552080274, 0.1688463889877312, 0.041415154046262614, 0.033545876503922045, 0.05850628069310915, 0.013355386236071354, 0.05572084461164195, 0.11006049302523024, 0.09378756934893318, 0.06806159901316278, 0.10871077873161994, 0.048683529457775876, 0.0167304280330427, 0.024475989557686262, 0.07921817887108773, 0.09326362793217413, 0.020816056749026757, 0.06171596920466982, 0.017610704235266894, 0.04536622582236305, 0.04739067851915024, 0.03761163978197146, 0.023554590952699073, 0.02180287010560278, 0.1650790247367695, 0.04591424250975251, 0.04667109955335036, 0.02214735093730269, 0.042200531825073995, 0.007914884372439701, 0.048360806540586054, 0.052475529300863855, 0.10033919708803296, 0.16321969247655943, 25.784872993826866, 95.3691141307354, 80.75806975364685, 63.12218628823757, 65.17584308981895, 59.932930022478104, 33.24679858982563, 28.87211613357067, 43.669472113251686, 50.81469990313053, 10.559985805302858, 0.12534914334537461, 0.21687026048311964, 3.355463147163391, 2.824838007800281, 3.558515226468444, 4.1457295417785645, 1.0098035330884159, 3.852298124693334, 58.83851274847984, 77.2624397277832, 75.65087780356407, 75.77718302607536, 75.17516613006592, 75.726448148489, 59.715395495295525, 68.01382720470428, 73.93951043486595, 71.65156200528145, 72.68684685230255, 71.6309367120266, 68.92880290746689, 72.65693485736847, 69.93256464600563, 68.24892818927765, 55.21180875599384, 50.30914083123207, 50.33268056809902, 48.205471113324165, 52.26798892021179, 59.44488041102886, 63.35967734456062, 64.39455941319466, 63.185293301939964, 65.88488504290581, 59.92593839764595, 53.98453541100025, 50.397881269454956, 50.115089043974876, 46.685244888067245, 47.550694048404694, 48.87191355228424, 55.03957539796829, 55.81574834883213, 55.48053793609142, 50.105236172676086, 54.223846569657326, 58.117478638887405, 62.94519558548927, 59.08030517399311, 58.08977052569389, 57.463697120547295, 60.418783351778984, 61.68766066431999, 60.97522169351578, 59.86563183367252, 63.534380570054054, 58.66690635681152, 61.74379505217075, 57.27747671306133, 58.3014951646328, 37.43042729794979, 43.998097479343414, 65.2626684308052, 56.91807679831982, 57.08600878715515, 56.7846355587244, 58.4033714979887, 57.57446117699146, 62.0682330429554, 60.881929099559784, 61.314547285437584, 58.536949530243874, 54.24267075955868, 47.06014037132263, 45.31871281564236, 46.2430664151907, 51.68407425284386, 61.47692397236824, 57.8706818819046, 51.59722991287708, 66.26367151737213, 60.08549943566322, 53.41996930539608, 45.87567552924156, 45.7862663269043, 46.62512831389904, 48.10649402439594, 52.604335471987724, 62.03096464276314, 61.96694187819958, 63.3653200417757, 60.84399193525314, 56.079036220908165, 48.96149754524231, 49.07880485057831, 48.97149480879307, 49.98765528202057, 51.383536979556084, 57.6158257573843, 62.58031636476517, 64.10165593028069, 64.35738980770111, 65.37016466259956, 61.238726153969765, 62.46660366654396, 60.63038259744644, 60.419539511203766, 64.0556176006794, 68.62397566437721, 67.89217293262482, 72.17232406139374, 61.537238135933876, 1.1055464018136263, 0.9996453719213605, 1.1497189127840102, 2.3987872945144773, 2.0786278741434216, 0.6596196675673127, 0.17190825281431898, 0.6517523084767163, 35.38029670715332, 38.51983644068241, 54.66686099767685, 61.145539954304695, 55.96993647515774, 30.29412902891636, 36.38766065239906, 37.34174005687237, 59.922024607658386, 67.98484995961189, 69.9046741425991, 6.789357410743833, 0.24542477825889364, 0.027606748808466364, 0.11836370060336776, 0.008462593068543356, 0.09042215970112011, 0.039740772408549674, 0.03345252545841504, 0.06125388950749766, 0.10673092168872245, 0.06033183410181664, 0.01310666842982755, 0.035420842104940675, 0.04526699325651862, 0.030165829848556314, 0.044079868675908074, 0.016961128349066712, 0.04719374221167527, 0.09987427125452086, 0.13860134786227718, 0.15995792375179008, 0.11527168331667781, 0.11197383137186989, 0.13681315787835047, 0.22018130781361833, 0.17128521983977407, 0.13487592979799956, 0.083853032119805, 0.1898454871843569, 0.15144541568588465, 0.1792809704784304, 0.1321936002932489, 0.28659484174568206, 0.3021627548150718, 31.74609001725912, 107.63469636440277, 90.1026651263237, 72.85865843296051, 74.90088924765587, 60.34601345658302, 41.11586473882198, 67.60619267821312, 67.88395777344704, 58.94990757107735, 15.23127369582653, 0.3047981805866584, 1.268196317832917, 3.3266443060711026, 3.1659813271835446, 4.819494662806392, 16.69523064047098, 5.451906127855182, 3.9854992646723986, 62.86736436188221, 76.81211829185486, 79.85283672809601, 78.68039444088936, 77.19661965966225, 77.87805989384651, 65.38060650229454, 70.1911635696888, 77.20098182559013, 73.18804755806923, 78.30523297190666, 73.36813509464264, 72.25965097546577, 74.54968929290771, 73.03472578525543, 71.11018225550652, 57.21834048628807, 52.32334814965725, 53.22760462760925, 50.331894010305405, 55.384874269366264, 60.739900320768356, 67.27709233760834, 65.87301447987556, 65.52119135856628, 69.83914285898209, 62.56212294101715, 55.71705624461174, 52.51190543174744, 52.68781319260597, 50.81951804459095, 49.79057125747204, 52.19797767698765, 57.579986080527306, 58.098646849393845, 59.170622527599335, 52.34366945922375, 55.71828357875347, 61.61644868552685, 67.93791487812996, 62.67766714096069, 58.967990800738335, 58.76422293484211, 61.57559707760811, 65.30007362365723, 62.57647857069969, 61.51515372097492, 66.48836866021156, 61.48859694600105, 64.19028237462044, 59.960166960954666, 58.68251971900463, 41.54598265886307, 46.976020485162735, 67.9294641315937, 60.219119265675545, 59.491644501686096, 61.11839421093464, 61.11311249434948, 59.724769592285156, 62.87159353494644, 61.56959339976311, 64.20526877045631, 60.99486663937569, 58.384782895445824, 49.011958837509155, 48.413350358605385, 49.66505639255047, 54.73949410021305, 65.34174978733063, 61.811283230781555, 55.82042969763279, 66.13204658031464, 63.99777710437775, 55.45948326587677, 50.397752076387405, 48.69225159287453, 49.37539413571358, 50.19581951200962, 55.707309767603874, 66.85336947441101, 65.3956688940525, 66.74465730786324, 64.32052418589592, 58.480723947286606, 51.26670464873314, 51.87129020690918, 53.5509292781353, 52.41547040641308, 54.88676279783249, 61.31563402712345, 65.26639223098755, 66.31993129849434, 67.81331956386566, 67.36210137605667, 66.53275027871132, 67.86318048834801, 66.62049517035484, 61.65904060006142, 68.63589182496071, 72.62089759111404, 71.43689632415771, 74.21825587749481, 63.20777669548988, 1.0079453140497208, 5.648328037932515, 8.523948658257723, 3.9159860322251916, 3.885542778298259, 1.2659616814926267, 0.3033359121764079, 3.690284793265164, 46.51015408337116, 44.73953269422054, 53.03826078772545, 65.63434168696404, 72.22367450594902, 30.477032214403152, 35.11703923344612, 48.81347268819809, 69.25340428948402, 75.35782232880592, 79.91330668330193, 8.514870945364237, 0.36606831941753626, 0.1596371378400363, 0.23090666276402771, 0.15863353153690696, 0.15994772664271295, 0.13456845801556483, 0.1654171769041568, 0.16991750104352832, 0.27104218723252416, 0.1562197259045206, 0.10910590557614341, 0.11702709263772704, 0.15077424701303244, 0.1546819810755551, 0.14154966309433803, 0.08770157990511507, 0.16374722588807344], [0.07371616316959262, 0.044589601675397716, 0.03755273181013763, 0.04719268465123605, 0.08650834002764896, 0.012630009241547668, 0.059957134872092865, 0.08481432116241194, 0.10647554867318831, 0.0476754591363715, 0.07854853160097264, 0.060825607215519994, 0.020244365550752264, 0.021020412677899003, 0.1186038892774377, 0.10348055235226639, 50.12521170079708, 80.1439543068409, 61.114754006266594, 57.20090702176094, 61.80230051279068, 23.437835834920406, 25.04253912717104, 67.6662826538086, 31.049579791724682, 40.41881874203682, 1.7801502090878785, 0.06188107108755503, 0.25112956354860216, 1.7349040182307363, 1.493435287848115, 3.621833366341889, 2.0679186237975955, 0.5020824365783483, 14.206329993903637, 73.6128343641758, 70.64672872424126, 77.59028613567352, 68.7657080590725, 77.6926602423191, 54.09662939608097, 61.7009599506855, 72.53702089190483, 71.62874802947044, 70.74213400483131, 67.70168915390968, 67.23968714475632, 67.73021802306175, 67.45021864771843, 62.61625103652477, 53.06066818535328, 47.16123774647713, 48.078953102231026, 46.5432883054018, 49.938052743673325, 48.37115742266178, 56.17936983704567, 61.3234806060791, 65.83415016531944, 62.883422300219536, 60.92541016638279, 58.33807960152626, 52.43603490293026, 49.78677526116371, 48.43632012605667, 44.18881684541702, 45.396376848220825, 45.38145124912262, 45.30493475496769, 48.774665370583534, 47.434553280472755, 47.70778901875019, 51.840158477425575, 57.935753390192986, 58.96256849169731, 59.98226657509804, 54.165698289871216, 53.13883759081364, 58.80388520658016, 57.47774116694927, 57.35894814133644, 53.65591764450073, 58.54802593588829, 58.26992645859718, 61.312806978821754, 54.71923738718033, 59.601971581578255, 41.021196618676186, 39.13034588098526, 59.636203944683075, 54.23156775534153, 59.63531479239464, 58.18934418261051, 60.994608253240585, 57.202548533678055, 56.11659720540047, 50.21761134266853, 59.378691762685776, 56.17101028561592, 55.54513446986675, 49.93496350944042, 46.538694351911545, 44.840877056121826, 51.50996379554272, 54.23920914530754, 61.81404188275337, 46.49202145636082, 57.63000279664993, 60.39046347141266, 51.226347014307976, 44.32823896408081, 43.073850274086, 44.02537241578102, 44.45751942694187, 46.86812147498131, 56.54359169304371, 61.211766600608826, 60.4346626996994, 57.345196679234505, 51.50079108774662, 45.26092551648617, 44.92356821894646, 45.73407232761383, 47.08786368370056, 48.839383497834206, 53.6287909001112, 56.61641098558903, 61.12579621374607, 58.19802671670914, 57.70324006676674, 55.53386427462101, 57.44873732328415, 56.953620091080666, 58.37296932935715, 57.444565147161484, 61.502903178334236, 64.28507208824158, 63.17821428179741, 72.86913827061653, 22.441373504698277, 0.5902041611261666, 3.97592734079808, 2.4238243885338306, 1.1497908714227378, 1.1092650960199535, 0.41311421839054674, 0.11638914991635829, 18.297815546393394, 34.98737499117851, 25.986286886036396, 59.81946811079979, 64.23550754785538, 36.9471350312233, 17.827928960323334, 32.268366292119026, 46.174867674708366, 51.85894846916199, 64.47682499885559, 25.090712942183018, 0.5921154585666955, 0.11250370254856534, 0.010081235705001745, 0.01327906284132041, 0.10230710555333644, 0.027262065741524566, 0.030322506499942392, 0.07026810053503141, 0.01519114139227895, 0.07629142302903347, 0.014529267191392137, 0.026585445993987378, 0.04037028433231171, 0.000587940289733524, 0.0526404679112602, 0.021234769046714064, 0.11898271855898201, 0.07649202554603107, 0.11271157811279409, 0.032693616376491264, 0.06071442607208155, 0.06828567566117272, 0.056654180662008, 0.037748042814200744, 0.07161371075198986, 0.13941969926236197, 0.012023911149299238, 0.018042444935417734, 0.01229809204232879, 0.02342996209335979, 0.0399597393698059, 0.07807178335497156, 0.08479551514028572, 63.75975027680397, 90.28155952692032, 71.71273112297058, 67.05979719758034, 77.4011778831482, 32.68184870481491, 32.7253183722496, 57.8067959100008, 35.341762974858284, 47.65928082168102, 1.066388078033924, 0.0938995742762927, 0.589851908152923, 4.539546584710479, 6.318096723407507, 9.710280150175095, 3.4218375105410814, 0.35278215422295034, 18.526388481259346, 76.46061435341835, 73.90642181038857, 79.79130282998085, 71.11879259347916, 78.02226215600967, 57.41747260093689, 63.56341481208801, 72.35618099570274, 73.3272036910057, 72.99785256385803, 71.19513809680939, 70.19938632845879, 71.2553496658802, 68.58654007315636, 64.42711606621742, 55.15915498137474, 49.284924790263176, 51.17521695792675, 48.09837765991688, 51.260328590869904, 49.33171167969704, 59.87509332597256, 64.31856349110603, 66.04110985994339, 64.00917649269104, 65.43966293334961, 61.15888483822346, 53.57807122170925, 53.17669875919819, 50.2268410474062, 47.417685985565186, 47.12472930550575, 48.140350207686424, 48.176083490252495, 49.195758774876595, 48.70043635368347, 51.002679616212845, 54.980211183428764, 59.91921275854111, 62.596298307180405, 61.01423420011997, 55.748849138617516, 53.19743424654007, 59.56414461135864, 58.88620398938656, 57.84876845777035, 56.34619228541851, 60.263409689068794, 60.46169064939022, 63.7291619181633, 57.23717987537384, 60.968720242381096, 41.8432293087244, 40.25710701942444, 61.66872248053551, 56.4580886811018, 60.87077669799328, 59.862117022275925, 61.32868632674217, 57.38720342516899, 57.63371899724007, 51.31478726863861, 61.77266210317612, 60.461694449186325, 58.33121336996555, 52.40591011941433, 49.63648572564125, 46.94497615098953, 53.04847463965416, 57.902026399970055, 62.377194464206696, 50.350938588380814, 60.55106185376644, 62.818130403757095, 54.34975281357765, 47.728269919753075, 45.63984878361225, 45.438197404146194, 47.605954483151436, 49.72143776714802, 58.31472605466843, 61.295297518372536, 63.66220571100712, 58.46187315881252, 54.488399773836136, 47.39459462463856, 47.86348946392536, 48.06651636958122, 49.92672175168991, 50.873520746827126, 55.23865431547165, 58.81449803709984, 60.26211775839329, 61.23556472361088, 58.35627682507038, 57.35683925449848, 60.372574031353, 60.47639586031437, 60.56184187531471, 60.60708984732628, 63.3881264179945, 66.5948237478733, 67.24426209926605, 74.05499383807182, 27.991617880761623, 0.38060233171563596, 0.7323479431215674, 2.4707321589812636, 3.558874069713056, 1.5070643252693117, 0.5514941539149731, 0.31933694262988865, 16.288238279521465, 40.87118446826935, 30.925328359007835, 60.29775604605675, 67.33310893177986, 34.544261768460274, 22.12731085717678, 41.25390373170376, 52.00814366340637, 59.87806476652622, 70.9044536948204, 33.04912939667702, 0.7028472167439759, 0.1304466143483296, 0.011324539009365253, 0.015235339997161645, 0.05160464868822601, 0.09022275946335867, 0.03427326286328025, 0.049534546487848274, 0.10442046012030914, 0.04868472431553528, 0.008370814448426245, 0.019598006874730345, 0.05471392461913638, 0.041898021299857646, 0.06652557596680708, 0.08231179919675924, 0.05705365649191663, 0.18609070975799114, 0.197504926181864, 0.12825919344322756, 0.1345625802059658, 0.15245334128849208, 0.16356866515707225, 0.16027725505409762, 0.1668503085966222, 0.20280745258787647, 0.1659789975383319, 0.1334590362966992, 0.14793231122894213, 0.11658321411232464, 0.12498958763899282, 0.1571828406304121, 0.3882868849905208, 76.47722706198692, 98.02248135209084, 81.17489978671074, 74.4289393723011, 80.5343909561634, 33.94999645650387, 38.62175837159157, 91.6827343404293, 47.381986901164055, 55.55322043597698, 2.4229212244972587, 0.31622247537598014, 0.3880073921754956, 6.152237998321652, 9.792458340525627, 10.919294524937868, 11.51395596563816, 1.8917039106599987, 20.455531664192677, 80.18435373902321, 75.73505848646164, 83.5874131321907, 74.97369334101677, 81.32538691163063, 61.34188301861286, 66.6792780160904, 73.8010686635971, 75.57849168777466, 74.97094228863716, 71.72242060303688, 72.56994992494583, 74.06684160232544, 71.35715380311012, 67.38421618938446, 56.580350920557976, 52.08724781870842, 53.43090131878853, 51.80200472474098, 54.10958670079708, 52.55420856177807, 62.86033473908901, 67.44655564427376, 67.94144868850708, 65.73980122804642, 66.5531475841999, 63.10548238456249, 56.49304300546646, 53.6816992610693, 52.73930802941322, 48.678511530160904, 50.165261551737785, 49.78032320737839, 48.79763513803482, 51.34689934551716, 52.13653117418289, 52.9561547935009, 57.437106147408485, 63.7370540946722, 65.53668692708015, 62.39199087023735, 56.448171213269234, 55.960011407732964, 62.21025802195072, 61.39944612979889, 59.89489026367664, 58.98000195622444, 63.64113584160805, 63.34648445248604, 66.51619836688042, 59.73553441464901, 61.437250301241875, 44.11002427339554, 45.199292823672295, 64.52698990702629, 58.09683054685593, 63.40497471392155, 63.784106969833374, 66.3483689725399, 60.34297741949558, 59.14525508880615, 53.00249710679054, 63.65209825336933, 62.96001859009266, 61.40188179910183, 54.77876499295235, 50.91341480612755, 50.50928749144077, 56.747412756085396, 61.86838656663895, 66.83033511042595, 50.34211166203022, 63.461200296878815, 65.38098648190498, 56.94154053926468, 49.38605636358261, 48.56777027249336, 48.23077775537968, 50.50451494753361, 52.72467881441116, 61.88247621059418, 65.11009141802788, 67.09858551621437, 62.8828789293766, 58.80525693297386, 50.000848174095154, 49.32829946279526, 51.697236746549606, 51.60104110836983, 53.65865729749203, 59.740341156721115, 62.235215082764626, 65.18230274319649, 64.5639543235302, 63.57607953250408, 60.93370892107487, 64.92382541298866, 63.66820178925991, 65.09311392903328, 63.010635673999786, 68.70475932955742, 70.45196637511253, 71.1742316186428, 76.05000838637352, 28.692786656320095, 0.6101801642216742, 11.941832955926657, 10.204162448644638, 4.887226028367877, 2.119874660857022, 0.8692218828946352, 0.33685038099065423, 23.402417935431004, 50.39478063583374, 39.482146203517914, 66.95046946406364, 74.31204244494438, 44.23356704413891, 30.083075053989887, 45.14499373733997, 62.00588978827, 70.15525549650192, 80.54569154977798, 37.74989515542984, 1.0424834419973195, 0.21292466204613447, 0.1055067936249543, 0.13111203879816458, 0.17371354188071564, 0.13220274355262518, 0.14587074372684583, 0.11535786892636679, 0.11741123569663614, 0.13997972389915958, 0.16005449200747535, 0.07320267861359753, 0.12351213488727808, 0.10694597382098436, 0.1572966415551491, 0.17855638201581314, 0.22870625427458435], [0.04796045497641899, 0.05735247854318004, 0.09975661858334206, 0.057838447974063456, 0.10752826288808137, 0.04283835951355286, 0.05924411649175454, 0.01625215467356611, 0.06032413431967143, 0.07426173819112591, 0.021325012348825112, 0.08305502298753709, 0.06778196519007906, 0.04351972900622059, 0.029398389779089484, 2.7439365489408374, 72.83786594867706, 70.01605376601219, 64.74923238158226, 43.16798262298107, 16.77114676684141, 44.80580113828182, 39.18428398668766, 26.11551985144615, 52.132169008255005, 33.679010197520256, 0.40836215775925666, 0.051942459467682056, 0.14739351201569661, 3.7279915949329734, 3.254391420632601, 4.50477940030396, 0.47211590863298625, 0.8621597243472934, 36.69186472892761, 71.89653486013412, 72.16340973973274, 69.21190291643143, 73.58283117413521, 71.32284924387932, 60.47845155000687, 69.77627903223038, 68.0848453938961, 70.78193306922913, 69.83731895685196, 64.45700526237488, 61.92276544868946, 64.30075004696846, 66.54715910553932, 53.996303379535675, 50.16568712890148, 46.66955552995205, 47.587525472044945, 47.99684330821037, 48.195660039782524, 48.559479117393494, 54.17995132505894, 63.717838525772095, 62.492883056402206, 63.22950392961502, 60.82456737756729, 59.667092487215996, 56.57111741602421, 55.3740144520998, 48.89915809035301, 45.98833568394184, 44.94061030447483, 43.936012610793114, 44.043151661753654, 45.829629600048065, 44.85639162361622, 46.637781634926796, 53.83554920554161, 59.522859826684, 58.912312388420105, 59.31547075510025, 51.09012432396412, 58.51222425699234, 61.07892572879791, 59.64842028915882, 58.828283697366714, 54.59610499441624, 56.53414160013199, 57.79871754348278, 58.263831585645676, 58.50465506315231, 65.33663526177406, 44.53366734087467, 37.544155195355415, 57.68818907439709, 53.53829115629196, 58.49437661468983, 53.65687899291515, 56.60529278218746, 51.42300546169281, 50.92267490923405, 49.94129776954651, 54.35556270182133, 55.73069751262665, 57.47275963425636, 54.07586731016636, 51.08113020658493, 48.453069627285004, 47.774988412857056, 52.550834342837334, 56.66884057223797, 54.09117668867111, 51.29744879901409, 59.318837374448776, 51.00404754281044, 46.5049559623003, 43.61210659146309, 45.37328168749809, 46.793987452983856, 46.023985370993614, 50.7802851498127, 56.93367876112461, 57.75367096066475, 57.79548391699791, 49.40520353615284, 45.758387222886086, 45.21744444966316, 46.00617192685604, 45.095980167388916, 48.59548978507519, 49.52773176133633, 52.58103892207146, 53.36207941174507, 56.176725178956985, 53.08690957725048, 52.89481468498707, 51.43413506448269, 55.50258435308933, 56.7455280572176, 60.71547143161297, 58.569939360022545, 63.13347548246384, 63.52965362370014, 69.78301227092743, 59.750467613339424, 3.3606056962162256, 0.4049947072053328, 2.6418690383434296, 1.2464954447932541, 0.756235005101189, 0.17552895384142175, 0.06171093373268377, 1.045956218149513, 45.54555304348469, 35.48756495118141, 30.895494259893894, 63.88518914580345, 103.91336604952812, 42.41605617105961, 21.543002910912037, 40.85745960474014, 48.58851335942745, 57.58953116834164, 51.12222880125046, 7.004372198134661, 0.2042838218039833, 0.017039502854458988, 0.049242155146203004, 0.019246379160904326, 0.051910164911532775, 0.055183507429319434, 0.05158208739885595, 0.0129219664268021, 0.07132632148568518, 0.0542681165097747, 0.04739677155157551, 0.02321201372978976, 0.018298356008017436, 0.04471966305573005, 0.014421638152271044, 0.0749490040470846, 0.05066537545644678, 0.07673604370211251, 0.06447955645853654, 0.051556817270466127, 0.05471966142067686, 0.05997657914122101, 0.04629361726983916, 0.0034263745283169555, 0.022424678536481224, 0.03581422861316241, 0.02665908745257184, 0.04962637984135654, 0.03298399649793282, 0.08847579578286968, 0.0188993564734119, 4.165069554001093, 86.61125287413597, 74.09119829535484, 75.0185689330101, 48.723231330513954, 29.46311742067337, 41.96367144584656, 33.22125256061554, 29.441093802452087, 57.3663729429245, 36.01917922496796, 0.20422498433617875, 0.112258378212573, 0.9170469478704035, 2.890911237336695, 7.0302193611860275, 5.728705124929547, 0.8660888322629035, 0.8549218252301216, 42.0474037528038, 75.90513736009598, 77.56700098514557, 72.71830916404724, 73.43240484595299, 74.67913314700127, 63.34498733282089, 71.3592740893364, 68.25796410441399, 73.0558830499649, 71.31156384944916, 67.66974806785583, 65.22163063287735, 64.94913965463638, 67.03854113817215, 59.32774029672146, 52.22894601523876, 48.33815239369869, 49.14940506219864, 51.318435072898865, 50.62511667609215, 52.11251266300678, 55.82068808376789, 67.03550890088081, 64.1753263771534, 64.44206446409225, 64.44123610854149, 63.06075878441334, 58.855269849300385, 58.00355315208435, 52.687729597091675, 48.84810782968998, 46.71861469745636, 47.11186319589615, 45.936605259776115, 47.43594020605087, 46.566581055521965, 49.79532480239868, 55.86286582052708, 61.930444836616516, 60.317142605781555, 61.3124193996191, 52.27252967655659, 59.80167746543884, 64.4089986383915, 62.55629405379295, 61.43633835017681, 55.02567954361439, 59.322925955057144, 59.918456599116325, 61.19397975504398, 59.813460633158684, 67.61342748999596, 45.51311418414116, 39.78275187313557, 60.69435976445675, 56.5440970659256, 58.993578627705574, 54.37707334756851, 56.44545815885067, 52.270580381155014, 52.482886388897896, 52.25776366889477, 55.07665000855923, 59.10390190780163, 61.41067072749138, 56.686939001083374, 54.44203846156597, 52.10770212113857, 51.84306152164936, 55.66876083612442, 57.65843667089939, 56.19871839880943, 54.87157501280308, 61.60278081893921, 55.79701155424118, 47.80292071402073, 46.25503957271576, 46.33310258388519, 48.24327528476715, 46.83806508779526, 53.60628850758076, 61.35133311152458, 60.49227140843868, 61.14490918815136, 52.769691199064255, 47.665379494428635, 47.912465035915375, 47.497451305389404, 48.44857066869736, 49.573606699705124, 52.28527419269085, 55.6866654753685, 56.60200975835323, 58.35756495594978, 56.601033210754395, 54.561853632330894, 54.329268112778664, 59.28652010858059, 59.31747704744339, 63.646827936172485, 61.916123405098915, 63.21258723735809, 66.30564406514168, 70.11747792363167, 61.77420102059841, 5.348760187625885, 0.2908856427529827, 0.8044116699602455, 1.7719640233553946, 2.295232401229441, 0.34433957131113857, 0.08795266330707818, 0.46869710145983845, 48.378114849328995, 34.42376263439655, 37.414669543504715, 73.72674465179443, 89.47631433606148, 46.84115432202816, 32.67560563981533, 47.80988194048405, 56.674772053956985, 64.94964122772217, 62.23944045603275, 9.252091236412525, 0.3147249994799495, 0.02898956288845511, 0.03718727231898811, 0.02423642057692632, 0.07534234231570736, 0.030769019649596885, 0.03784350526984781, 0.03104273298959015, 0.04673247145547066, 0.03435117352637462, 0.054691830882802606, 0.010441718168294756, 0.018933873761852738, 0.05267028740490787, 0.03995160172053147, 0.05575555485847872, 0.09280031255912036, 0.12971430754987523, 0.17897722427733243, 0.16006224002921954, 0.15077495947480202, 0.15044051804579794, 0.12934700382174924, 0.09823686341405846, 0.10749338194727898, 0.10189873137278482, 0.17749876220477745, 0.17224790412001312, 0.18780820275424048, 0.12530556443380192, 0.15219400520436466, 6.386392833665013, 99.22093704342842, 84.28401455283165, 84.30494382977486, 56.51286654174328, 28.152402453124523, 56.49738237261772, 48.51479731500149, 39.915718138217926, 72.9251928627491, 40.20893320441246, 1.0189555794931948, 0.12621831701835617, 1.1787731037475169, 11.024308539927006, 9.567231126129627, 11.635360401123762, 5.620949557051063, 1.3431337592191994, 47.68477365374565, 79.90712821483612, 79.90212008357048, 75.48448473215103, 77.5611113011837, 78.59307512640953, 65.33287346363068, 72.08786979317665, 70.13016164302826, 75.04906609654427, 74.28897008299828, 71.43052026629448, 68.44539284706116, 69.19889241456985, 71.72985300421715, 60.7137843221426, 56.08913987874985, 50.95159515738487, 52.24552072584629, 53.576239719986916, 54.035046100616455, 54.43429447710514, 58.57529707252979, 68.81659492850304, 66.41146078705788, 65.92575564980507, 68.41512367129326, 65.29932886362076, 62.99971505999565, 62.01209865510464, 54.95658405125141, 51.11658610403538, 49.10527043044567, 49.346245899796486, 47.97339476644993, 49.10156562924385, 49.880007058382034, 52.57337473332882, 59.02265086770058, 65.02180695533752, 62.07043692469597, 62.03403867781162, 54.20193314552307, 60.155233293771744, 64.61591273546219, 64.38741579651833, 62.850759252905846, 58.65112580358982, 62.25367829203606, 63.41607391834259, 64.56333115696907, 64.44505110383034, 69.4465783238411, 49.571300223469734, 42.97964572906494, 62.35460087656975, 58.972098380327225, 62.68672585487366, 57.73198552429676, 60.05161665380001, 53.74808929860592, 55.15529818832874, 52.386439964175224, 58.15453425049782, 60.156692415475845, 62.44890421628952, 58.95619623363018, 56.765351593494415, 53.35875079035759, 54.24581319093704, 58.2608525454998, 59.547091126441956, 58.35724197328091, 57.98866555094719, 62.55272604525089, 57.256194055080414, 50.65953902900219, 49.768977016210556, 49.65695522725582, 52.53456361591816, 49.8622278124094, 56.59723721444607, 64.2316697537899, 63.32538798451424, 64.07760322093964, 55.86742177605629, 49.736655950546265, 52.33204208314419, 50.89221954345703, 50.976423025131226, 53.85901674628258, 53.620530143380165, 59.47598934173584, 58.9178790897131, 62.129835337400436, 60.495987609028816, 57.34085351228714, 57.17080503702164, 62.94589854776859, 63.272092044353485, 69.54171001911163, 65.17715781927109, 66.74572885036469, 70.08255779743195, 72.0980304479599, 64.0369226038456, 5.846066102385521, 2.1107610873878, 9.826707802712917, 4.934148285537958, 3.234553160145879, 1.2913237768225372, 0.20398368244059384, 1.400523860938847, 57.83067762851715, 49.836780577898026, 41.315418630838394, 73.65488290786743, 116.40604689717293, 54.01556834578514, 34.55570675432682, 55.79040750861168, 63.80519583821297, 72.03279554843903, 68.56258615851402, 12.013433463871479, 0.49655557377263904, 0.08980020284070633, 0.17115213791839778, 0.13760332250967622, 0.11067969651776366, 0.11695461449562572, 0.12380088228383102, 0.14823402394540608, 0.2085097145754844, 0.2956316474592313, 0.19037624151678756, 0.1912847490166314, 0.16431300959084183, 0.16704676992958412, 0.11154758627526462, 0.18943147268146276], [0.09074795510969125, 0.041415372979827225, 0.08446120729786344, 0.04688880857429467, 0.032324282874469645, 0.0164360291819321, 0.03338917202199809, 0.06794362721848302, 0.04984991843230091, 0.03234498137317132, 0.05005216851714067, 0.029451870796037838, 0.1745884894626215, 0.23421186197083443, 0.21301916713127866, 15.584089513868093, 82.85492643713951, 60.05746454000473, 59.99916806817055, 53.503325432538986, 34.45041820406914, 59.64185044169426, 63.12936030328274, 38.35190065205097, 62.773615792393684, 12.653968892991543, 0.25104780856054276, 0.04548111028270796, 1.3038072944618762, 2.295309822075069, 6.951247248798609, 10.308737587183714, 1.5212343586608768, 3.15986983012408, 60.14446087181568, 70.59693619608879, 74.29540693759918, 65.99222168326378, 65.97307831048965, 66.09152555465698, 70.81577405333519, 66.29677534103394, 69.09750625491142, 68.83867174386978, 70.52103146910667, 64.61881577968597, 65.60370773077011, 56.80301137268543, 55.304972156882286, 48.1773716211319, 51.14106439054012, 46.61743372678757, 47.7944053709507, 46.34883373975754, 48.323268592357635, 46.397710517048836, 54.798185750842094, 63.01661275327206, 64.28975343704224, 64.27398428320885, 63.78861352801323, 59.907676577568054, 61.64888374507427, 56.964365914464, 51.57636143267155, 46.567128226161, 46.233555525541306, 43.46987642347813, 45.99695362150669, 44.11801144480705, 45.75684830546379, 46.11256241798401, 52.52826735377312, 54.88715797662735, 59.798584431409836, 54.51260447502136, 53.77615839242935, 61.1768464744091, 56.03693448007107, 55.71734122931957, 61.41559146344662, 55.4996395111084, 56.14443451166153, 54.774665012955666, 58.11920374631882, 54.77414444088936, 63.46935085952282, 47.64568515121937, 34.56034630537033, 52.223117128014565, 49.09119598567486, 54.539636224508286, 48.2930564135313, 50.36902941763401, 50.62067091464996, 53.5893452167511, 54.172986298799515, 57.7778984606266, 57.08258897066116, 55.894833505153656, 57.12717577815056, 58.520082235336304, 58.300609812140465, 53.58870305120945, 50.85513733327389, 53.932102024555206, 58.8758609443903, 50.41822537779808, 56.421409249305725, 54.740071669220924, 46.73256754875183, 42.26836569607258, 42.49071076512337, 44.19397696852684, 45.119671896100044, 48.97620275616646, 52.710471376776695, 53.823196068406105, 53.1827138364315, 47.48944513499737, 44.10652086138725, 45.1908914744854, 43.603716641664505, 45.80986686050892, 47.708203196525574, 47.089034020900726, 49.20625381171703, 51.4386872202158, 50.36590218544006, 51.01218670606613, 50.95464639365673, 53.426379561424255, 55.14307424426079, 59.759944304823875, 57.32922613620758, 58.79699617624283, 61.591518223285675, 67.14587777853012, 54.36260752379894, 71.83054000139236, 35.61134710907936, 0.3145933127962053, 0.3447730449261144, 1.8022519606165588, 0.5411623895633966, 0.8097716979682446, 0.1906553632579744, 0.06835666208644398, 14.624735992401838, 58.67259465157986, 31.48722890764475, 42.13270537555218, 60.71794129908085, 42.31430143117905, 20.661632604897022, 32.86698617041111, 44.00148689746857, 51.576866805553436, 60.26064723730087, 25.048197023570538, 0.6316914036870003, 0.07453878191881813, 0.034023084881482646, 0.05194764707994182, 0.051732394567807205, 0.007821790295565734, 0.0085448035497393, 0.0314596214593621, 0.1087841994012706, 0.030995066699688323, 0.05558687582379207, 0.07317216892261058, 0.028880819700134452, 0.056872531640692614, 0.009515247911622282, 0.02136878978490131, 0.05260806574369781, 0.03878839655953925, 0.011188807620783336, 0.025962413019442465, 0.022954445812501945, 0.024372938642045483, 0.041373612330062315, 0.0258737003969145, 0.03289976273663342, 0.021804346979479305, 0.057591283111833036, 0.03699569802847691, 0.04777819834998809, 0.18980205670231953, 0.36334968404844403, 21.120442785322666, 95.18210336565971, 66.79677531123161, 68.63754853606224, 60.545989125967026, 36.90928906202316, 72.94254273176193, 54.58572015166283, 33.766219317913055, 71.6125912964344, 12.253871262073517, 0.23136660136515275, 0.008826968096400378, 2.5151890609413385, 6.737013319507241, 8.539027199149132, 4.233615025877953, 0.6289940234273672, 4.30772197432816, 64.45990830659866, 75.13208404183388, 77.19800278544426, 68.6913612484932, 68.09420049190521, 68.94044548273087, 74.13861975073814, 70.12000098824501, 71.30055204033852, 70.41333004832268, 72.62355744838715, 68.10194447636604, 68.41152906417847, 60.35923674702644, 55.13789512217045, 51.305565163493156, 53.404477536678314, 48.593361899256706, 48.9886698871851, 48.965498730540276, 50.485698357224464, 47.737051248550415, 57.29312427341938, 64.51102316379547, 66.659215092659, 65.54239422082901, 67.19191610813141, 62.03043267130852, 63.90729635953903, 59.301445707678795, 54.06529247760773, 48.39811697602272, 47.6680963486433, 44.953134432435036, 50.289370492100716, 47.9497866332531, 48.237062618136406, 50.31572587788105, 55.76910965144634, 56.545457392930984, 63.40871371328831, 54.69510108232498, 54.89977329969406, 65.75674071907997, 59.25707548856735, 58.828249499201775, 61.317746713757515, 57.09612764418125, 57.57873594760895, 56.96260280907154, 61.2820628285408, 57.181197479367256, 65.01877471804619, 49.506137520074844, 37.3379972577095, 54.19723279774189, 50.47845974564552, 55.50839804112911, 50.63816897571087, 51.73910669982433, 53.08635860681534, 56.71924486756325, 57.261836752295494, 59.824309051036835, 59.00622434914112, 58.55570152401924, 58.92033375799656, 60.827383026480675, 61.97154723107815, 55.898245722055435, 53.65890808403492, 55.665831193327904, 60.083040967583656, 53.21344278752804, 58.55062119662762, 56.53767541050911, 50.152570232748985, 44.26847577095032, 45.08715324103832, 46.23996198177338, 48.27359765768051, 50.42623154819012, 55.44529102742672, 55.512817203998566, 56.37117214500904, 51.02350249886513, 46.65735438466072, 47.7730543166399, 46.73539839684963, 47.4600575119257, 49.865883216261864, 50.431144684553146, 52.318738996982574, 53.76486539840698, 52.323275953531265, 54.90921199321747, 54.591172859072685, 58.06443348526955, 57.668061554431915, 61.124325692653656, 60.45165538787842, 60.89465081691742, 65.6678406894207, 67.96788766980171, 59.12812180817127, 73.03996190428734, 41.415372267365456, 0.40797766589093953, 0.21342167834518477, 1.5259462245739996, 1.2621889589354396, 1.534507165197283, 0.1677492423914373, 0.17842865840066224, 14.117916338145733, 64.13567170500755, 27.667519971728325, 47.61654831469059, 65.12140721082687, 42.04382814466953, 26.732222959399223, 40.434637293219566, 48.50843645632267, 58.636827170848846, 71.17963492870331, 31.23112455010414, 0.5726549809332937, 0.09597703858162276, 0.01786570061085513, 0.17785331583581865, 0.03241260958020575, 0.05363740601751488, 0.033981442975346, 0.028823407155869063, 0.06731168105034158, 0.06150540335511323, 0.00731919072677556, 0.04601358639774844, 0.06430553024983965, 0.12620679888641462, 0.007570630823465763, 0.0703553919447586, 0.16587454767432064, 0.17431306361686438, 0.20439368934603408, 0.15953954542055726, 0.06630468313232996, 0.10605564893921837, 0.13771921629086137, 0.28991814935579896, 0.15593359828926623, 0.08725747131393291, 0.16160786646651104, 0.14475434581981972, 0.26418518798891455, 0.30731996870599687, 0.5066319205798209, 26.024478636682034, 103.54828163981438, 75.54212003946304, 79.36597645282745, 70.48423424363136, 46.505294144153595, 69.59996089339256, 77.64465361833572, 56.856626495718956, 79.49493393301964, 15.334733594208956, 0.317962514818646, 0.1292344942339696, 4.027987634763122, 10.564002189785242, 11.1051463522017, 22.372777685523033, 6.105129551142454, 5.106194028630853, 69.98943239450455, 79.21656087040901, 82.5823138654232, 71.61949932575226, 71.7481680214405, 72.71002560853958, 77.42799684405327, 71.68607175350189, 72.99351319670677, 72.3349629342556, 73.93698737025261, 69.95541661977768, 70.50315722823143, 62.72817403078079, 59.298702254891396, 53.232700154185295, 55.70023454725742, 49.63640592992306, 52.360525354743004, 51.67994387447834, 52.88680851459503, 51.077550798654556, 59.46877732872963, 67.50223025679588, 69.59933012723923, 67.92746543884277, 68.08680608868599, 65.12582257390022, 67.64172077178955, 62.56020784378052, 56.44003205001354, 51.68543837964535, 50.928325206041336, 46.27375736832619, 52.04996421933174, 50.85536152124405, 50.26380926370621, 53.40353138744831, 57.94790893793106, 59.43023219704628, 65.0989656150341, 59.62543532252312, 59.50400523841381, 67.68132224678993, 63.682166039943695, 60.617265701293945, 66.37194290757179, 60.57392902672291, 58.99418659508228, 59.24619287252426, 63.69418479502201, 60.72058595716953, 67.60993167757988, 53.59588086605072, 40.301241651177406, 55.39514511823654, 53.38121898472309, 57.66964226961136, 52.91686110198498, 52.56621211767197, 54.00840952992439, 57.106729075312614, 60.34431494772434, 63.40168409049511, 61.8865267932415, 59.32093866169453, 60.5486261844635, 62.43435099720955, 64.5998015999794, 59.34643529355526, 56.24064914882183, 58.83689023554325, 62.824905440211296, 56.088288724422455, 61.1081575602293, 59.07418750226498, 51.922386065125465, 46.304524317383766, 46.44246071577072, 48.70273143053055, 51.09835468232632, 53.90124388039112, 58.09092566370964, 58.44066649675369, 59.35250736773014, 53.681524470448494, 49.95800547301769, 51.83000922203064, 49.92762990295887, 50.16608610749245, 53.849923834204674, 51.92040637135506, 55.13520486652851, 56.37382820248604, 56.12672746181488, 56.904002353549004, 57.412494868040085, 59.10622738301754, 61.12828128039837, 63.49273860454559, 63.361942023038864, 63.17013971507549, 69.1661761701107, 70.69067716598511, 62.85057306289673, 75.88544681668282, 44.308312833309174, 0.46883763454388827, 4.101410619914532, 9.983304999768734, 2.2107904823496938, 2.3409617599099874, 0.6690070638433099, 0.2534114895388484, 19.673235341906548, 74.8743362724781, 44.127780720591545, 48.6422348767519, 68.53542521595955, 49.821292608976364, 32.258141040802, 46.3776969909668, 59.59692545235157, 68.60629141330719, 78.8546834886074, 36.36635139584541, 0.9069127135444432, 0.34151736181229353, 0.16397757368395105, 0.22459146101027727, 0.11756111241993494, 0.15893353731371462, 0.08657675120048225, 0.07190009811893106, 0.14151173934806138, 0.1050852017942816, 0.16283598728477955, 0.16577738570049405, 0.18359077046625316, 0.2133408436202444, 0.13175834552384913, 0.18364824238233268], [0.0856053466850426, 0.05545643223740626, 0.06453874273574911, 0.010902934191108216, 0.0762830070743803, 0.06412383023416623, 0.07776892773108557, 0.02060499922663439, 0.04921139683574438, 0.008572750048188027, 0.026861851474677678, 0.014578021655324847, 0.008202807985071559, 0.03120105349808, 0.08465608043479733, 32.489905804395676, 75.56365728378296, 60.8190006762743, 62.03066825866699, 24.819234609603882, 26.066521480679512, 25.096830613911152, 42.66088463366032, 42.519357427954674, 61.568005084991455, 5.895103896036744, 0.23544044292066246, 0.4105202935170382, 1.1818004725500941, 0.40238089277409017, 9.057144597172737, 2.1535802772268653, 0.23131036141421646, 13.149342611432076, 68.83841335773468, 68.78641694784164, 70.58840185403824, 63.39206300675869, 64.30321991443634, 64.3767611682415, 67.43931323289871, 66.53221070766449, 71.56706213951111, 71.30547657608986, 68.30708026885986, 65.47466665506363, 65.53480222821236, 63.20426568388939, 55.90649127960205, 50.76833099126816, 51.54058255255222, 45.69405287504196, 46.01095587015152, 47.56756514310837, 46.67426347732544, 45.57891145348549, 54.77892078459263, 62.19449266791344, 61.79781675338745, 61.777119264006615, 59.49062615633011, 59.479815736413, 61.35587766766548, 54.65806066989899, 50.81032253801823, 46.61785930395126, 45.26623383164406, 45.86911328136921, 46.43508531153202, 44.848123267292976, 45.38003392517567, 44.49554778635502, 53.982472121715546, 56.87675401568413, 57.43064649403095, 52.73817948997021, 57.31664501130581, 58.68839420378208, 55.63730612397194, 53.13589654862881, 56.530432999134064, 56.81930489838123, 59.43565830588341, 53.55932302772999, 55.63380651175976, 54.77525778114796, 62.594899982213974, 47.28505030274391, 36.717224568128586, 51.890623569488525, 48.84202055633068, 54.84848365187645, 49.90763917565346, 50.50233766436577, 56.66630610823631, 56.914174407720566, 56.55153326690197, 53.85480657219887, 56.3965167850256, 57.92077079415321, 56.32177099585533, 54.57262605428696, 57.38865874707699, 53.47715623676777, 56.041821017861366, 51.477410942316055, 54.59969960153103, 52.814384400844574, 53.17016310989857, 56.24822214245796, 47.52722270786762, 43.34776617586613, 43.13006445765495, 44.1115365922451, 45.039150416851044, 46.43373258411884, 51.53427109122276, 52.77704380452633, 49.3604077398777, 45.9316199272871, 44.9833770096302, 43.89006927609444, 43.84267821907997, 42.586716413497925, 46.22390404343605, 48.876720294356346, 48.37334990501404, 45.640331357717514, 49.69749145209789, 52.012536227703094, 52.197821885347366, 54.246725142002106, 58.19976322352886, 59.60819184780121, 60.162479504942894, 59.70430389046669, 62.932325676083565, 64.52143460512161, 70.31493812799454, 46.90820172429085, 60.47329522669315, 22.28299990296364, 0.10018566899816506, 0.9304437227547169, 1.4826957578770816, 0.4108419403200969, 0.2013331910711713, 0.042266608943464234, 1.2462086789309978, 43.217866346240044, 48.47089447081089, 28.706000447273254, 70.64215376973152, 62.99353279173374, 18.20360340178013, 24.902345649898052, 42.717968970537186, 51.679081320762634, 57.103978022933006, 48.84041324257851, 2.647253111936152, 0.023857680353103206, 0.04395595969981514, 0.029639932872669306, 0.11849478614749387, 0.024648414582770783, 0.06628877890761942, 0.022464593093900476, 0.018685465802263934, 0.16504083381732926, 0.03557484145858325, 0.05766697846411262, 0.028838508005719632, 0.020254466180631425, 0.04145220205828082, 0.043569152330746874, 0.022033355198800564, 0.03784299689868931, 0.036577883729478344, 0.03251368267228827, 0.03259520017309114, 0.03978119719249662, 0.0926932503352873, 0.12281735849683173, 0.05769997063907795, 0.02088391687721014, 0.0417454097623704, 0.02148859839508077, 0.027727281012630556, 0.04139219570788555, 0.11551815798156895, 45.64208306372166, 84.8670856654644, 68.7505316734314, 69.02844876050949, 39.82985034584999, 33.84542606770992, 24.06026903539896, 30.107874423265457, 47.73192532360554, 68.37055206298828, 5.343273282051086, 0.32300579419825226, 0.6738268677145243, 0.8172374067362398, 8.774203229695559, 10.7690410874784, 2.3750803666189313, 0.4475032043410465, 14.367099367082119, 74.40228760242462, 71.63406014442444, 76.00884899497032, 68.16327318549156, 66.85585454106331, 67.41574689745903, 70.44128894805908, 68.258838057518, 72.52166971564293, 72.69456803798676, 71.17875337600708, 67.27026790380478, 69.60459664463997, 65.1703029870987, 58.56396608054638, 51.65844462811947, 52.97591373324394, 48.720617070794106, 47.246094793081284, 50.96692733466625, 49.240204989910126, 48.274167627096176, 58.58461797237396, 64.7634208202362, 63.31747680902481, 62.68606089055538, 60.03013260662556, 63.46802093088627, 63.40787015855312, 56.94097436964512, 53.16623792052269, 49.29750971496105, 46.229884922504425, 45.92215843498707, 48.24851520359516, 47.05343373119831, 45.66752269864082, 45.862402841448784, 55.80778017640114, 57.99423225224018, 61.31311856210232, 56.176759377121925, 59.322359785437584, 60.12766197323799, 57.17223756015301, 56.6376556456089, 60.47851234674454, 60.24145066738129, 60.471307933330536, 56.250042244791985, 58.45493473112583, 57.82504253089428, 65.17668664455414, 48.911860808730125, 37.91483670473099, 52.465916499495506, 51.23639367520809, 56.32906660437584, 51.25714436173439, 52.49689243733883, 57.54543833434582, 58.07102993130684, 58.284050300717354, 56.67930521070957, 59.62548092007637, 59.63886760175228, 57.45067901909351, 55.409356355667114, 56.38814963400364, 57.67084300518036, 58.74334305524826, 55.798257887363434, 56.97905592620373, 54.533134773373604, 54.26945172250271, 59.05711501836777, 50.00705324113369, 44.30146560072899, 44.55557696521282, 44.54442836344242, 47.3471237719059, 49.4620256870985, 52.4899198114872, 53.89409266412258, 52.27062217891216, 47.23805442452431, 47.222110480070114, 45.77373839914799, 46.361737847328186, 45.8938005566597, 49.08402197062969, 50.49522444605827, 50.66807337105274, 48.52061480283737, 52.27890573441982, 55.89000776410103, 55.048314929008484, 57.83266492187977, 60.15312060713768, 63.36489446461201, 62.631199434399605, 63.066595271229744, 65.4694989323616, 64.8984731733799, 70.64767867326736, 53.85199852287769, 65.17686903476715, 28.020982705056667, 0.07375975692411885, 0.3453334257937968, 1.450220444239676, 1.3410865003243089, 0.287284356309101, 0.046960203180788085, 1.2339504179544747, 46.89160421490669, 51.05995774269104, 20.99436555057764, 71.14512518048286, 53.79258871078491, 26.117883324623108, 35.921334475278854, 50.59342637658119, 59.35503423213959, 62.71735601127148, 59.26739953458309, 3.7442779960110784, 0.05254576986772008, 0.05191343036131002, 0.06887920084409416, 0.12968077731784433, 0.0444519444135949, 0.03508528745442163, 0.030697114816575777, 0.01269667915039463, 0.07134675281122327, 0.04174856388999615, 0.07563605468021706, 0.011471782036096556, 0.05113471706863493, 0.03141014989523683, 0.03951521146518644, 0.11932962806895375, 0.19453292159596458, 0.12067159434081987, 0.08981079328805208, 0.17793097416870296, 0.10733920818893239, 0.2594910148764029, 0.3223096299916506, 0.17637282027862966, 0.10689668779377826, 0.09441724454518408, 0.08921264452510513, 0.09258517136913724, 0.12032256228849292, 0.3249920188682154, 53.9026004076004, 95.84170237183571, 76.88801541924477, 80.99742650985718, 39.235155656933784, 34.74941276013851, 34.01409901678562, 59.84865814447403, 59.74339239299297, 74.20359626412392, 7.646306902170181, 0.47979814640711993, 1.2626919569447637, 3.512008571997285, 7.443420113995671, 18.41524824500084, 9.867974538356066, 1.9149428699165583, 16.833415925502777, 79.93989005684853, 73.71870428323746, 78.41569304466248, 71.3543951511383, 69.13909122347832, 69.27022978663445, 73.78816455602646, 69.74227085709572, 75.3457921743393, 74.4362273812294, 71.9718924164772, 69.3875902891159, 69.70279097557068, 68.83876293897629, 60.1473069190979, 54.93934817612171, 56.80952802300453, 50.21636500954628, 50.802217572927475, 52.69417405128479, 51.20162174105644, 50.955087170004845, 60.7330758869648, 67.4724854528904, 66.57296732068062, 66.17847248911858, 63.49944904446602, 64.65917721390724, 65.51547646522522, 59.690252244472504, 55.02290189266205, 50.61464063823223, 49.41446743905544, 48.40289331972599, 50.515944734215736, 51.14911235868931, 48.788979202508926, 48.68978552520275, 58.11362944543362, 62.3795997351408, 63.14248479902744, 57.96175919473171, 62.233353182673454, 63.113777339458466, 59.62005481123924, 59.14400115609169, 64.58492159843445, 64.38512831926346, 63.610391691327095, 58.64976927638054, 61.54766857624054, 61.049576103687286, 67.99372628331184, 53.867684081196785, 39.478365406394005, 54.22343999147415, 54.93193097412586, 58.063103556632996, 52.62244150042534, 54.878973215818405, 61.25021293759346, 61.145650148391724, 62.31372646987438, 58.01290065050125, 62.46485576033592, 62.225172221660614, 59.95740830898285, 57.62450069189072, 61.12241439521313, 58.69706153869629, 60.61278574168682, 55.274220407009125, 59.284920394420624, 57.05576241016388, 57.99183078110218, 61.64948031306267, 52.39531248807907, 47.05532222986221, 45.86481191217899, 49.3507144600153, 49.923191741108894, 52.286797910928726, 56.088493913412094, 57.152391225099564, 56.062503308057785, 51.84284493327141, 49.03601914644241, 48.720461279153824, 47.74728409945965, 47.71189659833908, 51.734151765704155, 54.16443295776844, 53.60027343034744, 51.185229420661926, 56.09027221798897, 58.90391863882542, 58.874211832880974, 61.10111653804779, 63.39004911482334, 66.76605775952339, 65.19911304116249, 64.41169649362564, 66.94473937153816, 69.09904897212982, 75.7044093310833, 57.64161877334118, 67.7420961856842, 28.69309823960066, 0.316708255559206, 5.385586861521006, 8.80225332453847, 1.5211878111585975, 0.600874344818294, 0.16459738573757932, 1.990472604520619, 53.841959461569786, 64.3069589138031, 39.45428229868412, 76.90712839365005, 71.37844786047935, 25.751341693103313, 35.36482013761997, 58.05624112486839, 67.25335121154785, 70.55086746811867, 68.97228017449379, 5.385643858462572, 0.17642239574342966, 0.20838613214436918, 0.1903420581948012, 0.19786014774581417, 0.1301559151033871, 0.09660412368248217, 0.12372632612823509, 0.13024915853748098, 0.3214091673726216, 0.13428474980173633, 0.12272611143998802, 0.08764782614889555, 0.1490614443900995, 0.1338198536541313, 0.1753447824739851], [0.06662555068032816, 0.03384396753972396, 0.05000678989745211, 0.020652915991377085, 0.05614648856862914, 0.03585236016078852, 0.038208326513995416, 0.06453069785493426, 0.06669427355518565, 0.044506399499368854, 0.029143066858523525, 0.016561021693632938, 0.053659206605516374, 0.05703358139726333, 2.8483865316957235, 66.31616950035095, 64.13529172539711, 59.053193628787994, 52.27891333401203, 23.26640233397484, 39.74721997976303, 84.01466220617294, 45.0467462092638, 55.86653262376785, 50.76546974480152, 0.19230885343858972, 0.0238609791995259, 0.18039846676401794, 2.20144250895828, 7.4102374445647, 11.604696996510029, 0.29401536856312305, 0.3207539103459567, 28.889131620526314, 70.7691353559494, 68.70975226163864, 70.20355090498924, 64.6708881855011, 67.21365854144096, 57.38758720457554, 61.23373322188854, 65.33070757985115, 69.77736577391624, 66.40585988759995, 68.3409820497036, 66.14017814397812, 66.51932939887047, 63.14072549343109, 61.98825493454933, 51.200603395700455, 50.77061466872692, 47.084899842739105, 48.183002918958664, 45.418981835246086, 47.69567146897316, 42.68031299114227, 48.61969828605652, 62.36563168466091, 60.976042449474335, 61.50640279054642, 61.44359216094017, 57.520181089639664, 61.97069987654686, 56.21207848191261, 51.87761306762695, 48.23773518204689, 44.6353080868721, 44.080959632992744, 44.46821205317974, 43.34792196750641, 44.56772871315479, 47.42454841732979, 52.373885437846184, 56.299477592110634, 59.28878478705883, 58.799652233719826, 60.68264879286289, 56.958696618676186, 57.216740772128105, 49.5897102355957, 53.239156007766724, 54.41578567028046, 56.503241658210754, 49.981305822730064, 53.335712626576424, 54.19649563729763, 62.489212453365326, 44.86679166555405, 36.62264384329319, 55.90433679521084, 49.93484951555729, 55.72078764438629, 48.88042129576206, 49.28567335009575, 53.19387383759022, 55.326452404260635, 52.182136327028275, 54.80567514896393, 53.564695939421654, 57.47389957308769, 60.003385841846466, 54.590196311473846, 51.79964505136013, 57.71433547139168, 56.2996181845665, 56.19382046163082, 52.387066930532455, 49.18635047972202, 50.50918869674206, 56.05887830257416, 49.822751730680466, 44.775626957416534, 41.830032616853714, 43.35260331630707, 42.32389211654663, 46.66837379336357, 45.54242581129074, 47.918046936392784, 45.22869184613228, 44.74390625953674, 44.16413716971874, 45.84750384092331, 43.841276094317436, 45.42729578912258, 44.48740862309933, 44.12152245640755, 45.77789917588234, 48.99448737502098, 51.04217849671841, 53.19023363292217, 54.91552345454693, 57.46146284043789, 58.25463607907295, 59.58484590053558, 59.00188498198986, 63.735803961753845, 62.26582244038582, 60.28829835355282, 59.367945939302444, 66.42016232013702, 51.42956770956516, 64.12049531936646, 15.31393826007843, 0.12390397401759401, 0.37328861479181796, 1.3182606501504779, 0.25275914173107594, 0.042738789270515554, 0.11051906607463025, 20.442716851830482, 63.74334655702114, 37.76952110230923, 37.97132067382336, 42.10644878447056, 28.800797760486603, 14.841040335595608, 27.1401234716177, 46.882807686924934, 49.12426941096783, 55.60891404747963, 15.401987135410309, 0.14891690370859578, 0.05081825045635924, 0.06557981265359558, 0.06654666038230062, 0.025408733745280188, 0.0738604886282701, 0.04815124630113132, 0.03507096400426235, 0.031952433491824195, 0.022703928298142273, 0.0214583373235655, 0.04553209582809359, 0.03749179777514655, 0.024014288355829194, 0.03241893267841078, 0.02745649173448328, 0.027036833198508248, 0.054157061531441286, 0.05221780367719475, 0.02883422581362538, 0.05405290110502392, 0.04382934930617921, 0.06643242159043439, 0.024433770631731022, 0.040053201737464406, 0.02728583673160756, 0.023379716840281617, 0.04973582806997001, 0.08692143426742405, 4.743978939950466, 79.1042996942997, 71.44992962479591, 66.01424530148506, 59.779752641916275, 29.610245525836945, 32.48875066637993, 65.38009732961655, 41.306895688176155, 66.11750096082687, 52.76125945150852, 0.15240694221574813, 0.14851762825855985, 0.5772587901446968, 4.758563507348299, 10.523169580847025, 8.53142000734806, 0.9331763105001301, 0.33493083086796105, 31.961460560560226, 73.8268768787384, 72.57419049739838, 73.78862053155899, 66.77665919065475, 70.24440631270409, 60.48201955854893, 63.67416746914387, 69.36373516917229, 72.50173598527908, 68.27000945806503, 70.47076776623726, 67.41199269890785, 69.41788986325264, 66.55389234423637, 63.52099388837814, 53.06569151580334, 52.61281281709671, 49.30150330066681, 51.89025118947029, 47.9558777064085, 48.66522364318371, 46.11514247953892, 50.155743062496185, 64.37536284327507, 63.085556253790855, 62.70839989185333, 62.24971130490303, 62.54456788301468, 63.663687631487846, 57.83270291984081, 54.807594045996666, 49.82953056693077, 47.95604109764099, 46.761256009340286, 46.0237155854702, 47.49237097799778, 46.93738415837288, 50.08144944906235, 56.25790402293205, 59.74806994199753, 61.69572003185749, 58.245839551091194, 62.03816145658493, 59.72492918372154, 60.05350895226002, 52.049641236662865, 55.51030173897743, 56.244521141052246, 58.84102441370487, 53.99564981460571, 54.93752807378769, 56.34281426668167, 66.5964424610138, 46.71322658658028, 38.644754737615585, 57.43756592273712, 52.488209903240204, 58.56036387383938, 51.940583288669586, 50.87061770260334, 55.71307025849819, 59.39716637134552, 53.30873787403107, 57.95276127755642, 57.78682418167591, 60.46961322426796, 61.125739216804504, 56.46215446293354, 53.286714255809784, 59.76127043366432, 58.046346455812454, 59.290984869003296, 55.26302620768547, 51.07488714158535, 53.601185381412506, 59.14145149290562, 51.150069907307625, 46.20118126273155, 43.33800449967384, 46.85651309788227, 44.77172836661339, 48.4871120005846, 48.30879136919975, 49.64899465441704, 47.55977176129818, 45.16192942857742, 46.5763883292675, 47.3696755617857, 47.49991737306118, 46.03217013180256, 48.447255939245224, 47.392044961452484, 47.565650045871735, 51.00733816623688, 53.29500921070576, 55.5411446839571, 57.8059371560812, 59.24970008432865, 61.96534976363182, 63.50216969847679, 60.44147193431854, 66.88729405403137, 65.38312956690788, 63.41956973075867, 62.2024342417717, 67.270967066288, 53.55716094374657, 67.76817038655281, 20.078101716935635, 0.08707347806193866, 0.2890635811490938, 1.2933900346979499, 0.7691886287648231, 0.1925337835564278, 0.12308900681091473, 18.75995434820652, 72.94025525450706, 36.23071767389774, 34.32426497340202, 39.54734690487385, 27.214147299528122, 19.21923380345106, 32.61159807443619, 53.33697035908699, 55.529391914606094, 68.05643051862717, 21.564868837594986, 0.13362900295760483, 0.018814291506714653, 0.018530533197917975, 0.024146479699993506, 0.06597751475055702, 0.06080829662096221, 0.015353211601905059, 0.018317735339223873, 0.07230196366435848, 0.02368893266975647, 0.01878627728729043, 0.031069739743543323, 0.06621797801926732, 0.04522072777035646, 0.08040187472943217, 0.15412065025884658, 0.14965915528591722, 0.20763582084327936, 0.15347573877079412, 0.16015401401091367, 0.10509893894777633, 0.12059147207764909, 0.19774854357820004, 0.21877955412492156, 0.12086345435818657, 0.12650754681089893, 0.1407603593543172, 0.11874320523929782, 0.2240896355942823, 5.597397470846772, 92.34803304076195, 80.37530109286308, 76.04551702737808, 68.08100759983063, 34.322482869029045, 50.10558195412159, 104.16300505399704, 61.74800902605057, 72.89721876382828, 58.777005448937416, 0.4294974548975006, 0.1458103329059668, 1.500819360371679, 8.897860944271088, 16.42577949911356, 20.76202131807804, 7.560237245634198, 0.9950207825750113, 37.18420810997486, 74.86143976449966, 73.44034641981125, 77.33298674225807, 69.86964002251625, 73.53011280298233, 62.27149933576584, 67.50685840845108, 73.66045340895653, 75.5780129134655, 71.65262594819069, 73.1109268963337, 69.60875362157822, 70.18688499927521, 69.95426148176193, 66.71245783567429, 55.55258207023144, 55.216045528650284, 52.324252501130104, 54.55153338611126, 50.1751372218132, 51.026481539011, 48.322402238845825, 51.87477461993694, 67.49739691615105, 65.51538527011871, 64.23448920249939, 65.31096383929253, 61.96217693388462, 65.76762333512306, 59.12182554602623, 58.226863369345665, 53.61100025475025, 49.71520610153675, 48.41464228928089, 48.567257300019264, 48.88636037707329, 49.27175469696522, 50.621734857559204, 57.76702344417572, 62.33035817742348, 64.06853690743446, 61.10704801976681, 63.70582737028599, 63.02277982234955, 63.635835126042366, 54.429521933197975, 58.13040554523468, 58.72869864106178, 61.46495841443539, 56.565934494137764, 57.78708636760712, 60.45125260949135, 67.94225424528122, 49.51934181153774, 40.55792547762394, 58.32179367542267, 54.880181550979614, 59.46491293609142, 53.70106682181358, 50.91990105807781, 57.71192640066147, 59.912179335951805, 54.8435515165329, 59.21804018318653, 60.93600779771805, 63.744858875870705, 64.2868883907795, 57.77021147310734, 55.31603716313839, 60.932857766747475, 60.54193094372749, 60.762949883937836, 57.13580511510372, 51.607299372553825, 55.972121357917786, 61.48219808936119, 54.289153665304184, 49.65608887374401, 45.20611345767975, 48.864336758852005, 47.85998985171318, 51.12057588994503, 52.009465992450714, 52.786558493971825, 49.67514485120773, 49.549246206879616, 49.053942784667015, 50.3348046541214, 50.152064859867096, 49.52198646962643, 51.158387660980225, 50.93236818909645, 49.55597944557667, 53.30581583082676, 57.05193221569061, 58.14023181796074, 60.383950620889664, 64.25303220748901, 63.24180766940117, 65.1552101969719, 63.228607177734375, 68.78355950117111, 69.59914773702621, 66.043860912323, 66.29692733287811, 69.54023569822311, 56.12045019865036, 69.16401028633118, 22.003756687045097, 0.5667628033552319, 5.163478329777718, 7.119426224380732, 0.7394935190677643, 0.3839104698272422, 0.2341359105776064, 25.415399819612503, 79.60715711116791, 52.21109837293625, 46.17162264883518, 53.38932774960995, 39.60434764623642, 22.646942473948002, 38.058161213994026, 61.55192814767361, 63.041847199201584, 74.99873399734497, 26.581654138863087, 0.32851401425432414, 0.12670234573306516, 0.17044043313944712, 0.13886696251574904, 0.12140229810029268, 0.16300930845318362, 0.13267672358779237, 0.18069691403070465, 0.17382614052621648, 0.09698034060420468, 0.08308001109980978, 0.1812710691592656, 0.1299101603217423, 0.08260685484856367, 0.1722804398741573], [0.028177419553685468, 0.05593489113380201, 0.039054352600942366, 0.015556388443656033, 0.019886023255821783, 0.05155442013347056, 0.07100853385054506, 0.0371421905583702, 0.04579966975143179, 0.022499388687720057, 0.03974797124101315, 0.006178000448926468, 0.1674885259126313, 0.26441130554303527, 11.057196725159883, 74.73539292812347, 65.73321998119354, 63.90655159950256, 37.538170516490936, 21.645532809197903, 53.84933866560459, 43.95193375647068, 31.980014964938164, 75.38801550865173, 26.5930288285017, 0.17535402963403612, 0.1807282623485662, 0.9461073728743941, 0.4819593101274222, 13.062411826103926, 8.797153998166323, 1.164613994769752, 1.5913502150215209, 46.409296095371246, 66.06243431568146, 64.64763343334198, 71.84342131018639, 66.98554918169975, 67.27370291948318, 61.80372163653374, 57.99093782901764, 57.2764203697443, 58.571037501096725, 62.649259865283966, 66.33407413959503, 67.05815568566322, 67.22498953342438, 64.06418234109879, 61.77246451377869, 49.92975778877735, 48.7680347263813, 47.17229135334492, 46.06137916445732, 45.97011186182499, 44.884171932935715, 46.7803879827261, 45.24302467703819, 53.78876231610775, 60.546399503946304, 61.20589591562748, 60.994710847735405, 59.71967026591301, 59.6331413090229, 55.98523445427418, 52.812910079956055, 48.91337312757969, 43.86100083589554, 42.55382537841797, 44.29553031921387, 45.232392847537994, 46.36580742895603, 53.57647530734539, 60.40239483118057, 59.13867004215717, 58.833094239234924, 57.37163566052914, 57.26619891822338, 54.66037854552269, 51.44840329885483, 46.19301550090313, 48.34109723567963, 47.16279946267605, 49.77732136845589, 44.89377401769161, 51.10441915690899, 51.715551763772964, 62.848950549960136, 44.43322353065014, 35.15551216900349, 60.801092237234116, 53.928328827023506, 59.14643682539463, 53.55354353785515, 53.439868837594986, 53.48548159003258, 58.30966092646122, 50.32109498977661, 48.97608496248722, 52.51364193856716, 57.069821655750275, 55.041619688272476, 58.642443269491196, 55.991990491747856, 58.82427491247654, 52.56837420165539, 56.44578494131565, 57.73345224559307, 55.753367096185684, 50.88425897061825, 54.35893692076206, 55.557107627391815, 46.249917447566986, 41.98122650384903, 43.43134269118309, 42.45607942342758, 45.30312605202198, 44.798839911818504, 45.47663614153862, 44.38957527279854, 44.74754646420479, 43.6693961173296, 44.083361104130745, 43.33246439695358, 43.34925189614296, 44.274202063679695, 43.639962896704674, 49.09780763089657, 51.81885302066803, 53.12138892710209, 56.977209225296974, 56.71587444841862, 58.34234297275543, 61.414044946432114, 63.3599167317152, 61.61924533545971, 63.41361165046692, 61.81674353778362, 61.7192217707634, 60.22095836699009, 58.43634992837906, 63.541284799575806, 55.063673704862595, 63.193664252758026, 12.512288745492697, 0.47687865619082004, 2.2140469076111913, 0.6989896518643945, 0.17921822931384668, 0.07222358544822782, 1.8991204001940787, 51.50752052664757, 48.63637559115887, 20.586575232446194, 29.286464899778366, 62.461565136909485, 34.460457265377045, 24.583898037672043, 44.3083356320858, 47.00973987579346, 60.75752377510071, 34.13212068378925, 0.656773739028722, 0.05123398303112481, 0.07283982777153142, 0.08406597655266523, 0.025949468108592555, 0.05721465429814998, 0.06041639811883215, 0.017834263235272374, 0.1200543501181528, 0.06755733193131164, 0.06419133598683402, 0.08246164623415098, 0.05736762206652202, 0.05597096693236381, 0.04375477830762975, 0.011262627194810193, 0.0962721610267181, 0.03802796236413997, 0.04183394426945597, 0.1210581419582013, 0.04145363069255836, 0.01963281916687265, 0.08179701588233002, 0.032001953295548446, 0.048589139405521564, 0.07119611167581752, 0.021660095735569485, 0.18239251367049292, 0.2604927361244336, 16.669388227164745, 88.35748717188835, 71.09493747353554, 69.03253734111786, 46.38397425413132, 31.712589114904404, 43.96427929401398, 44.57804895937443, 36.88712105154991, 83.07124122977257, 28.788345828652382, 0.07805379369528964, 0.25639554660301656, 1.8352073547430336, 2.5997741846367717, 5.629207463935018, 3.8805553084239364, 0.790277972118929, 2.064486932940781, 52.01946705579758, 68.29050555825233, 66.93900927901268, 73.05638462305069, 69.55417335033417, 69.45823609828949, 64.66779515147209, 61.178408190608025, 61.345375031232834, 59.347142055630684, 65.55150613188744, 67.36530840396881, 70.70415124297142, 68.20573210716248, 66.61176323890686, 63.21458213031292, 51.863208040595055, 49.34839278459549, 49.6169775724411, 48.45628045499325, 49.458666667342186, 46.471130177378654, 48.80705863237381, 45.94350948929787, 56.340792775154114, 62.4149264395237, 62.37518437206745, 63.5262718051672, 60.93043349683285, 61.01071558892727, 58.362873271107674, 54.38999645411968, 49.2603325098753, 46.78909331560135, 44.84992817044258, 45.5591107159853, 47.90717951953411, 49.65620666742325, 56.64050929248333, 61.351808086037636, 60.29865279793739, 58.77826698124409, 59.25106421113014, 61.160032376646996, 57.27375291287899, 55.281056240200996, 49.01100128889084, 48.90673108398914, 50.59732496738434, 52.624546587467194, 48.14653627574444, 53.58309455215931, 55.72682552039623, 64.58432883024216, 46.29601277410984, 38.714256808161736, 62.72202596068382, 55.55605508387089, 60.473785400390625, 56.43111772835255, 54.64869037270546, 56.39547184109688, 60.466409996151924, 52.7542070299387, 51.74251511693001, 53.98859739303589, 57.96158820390701, 57.345838844776154, 59.95329312980175, 58.2792891561985, 61.78274296224117, 55.147975981235504, 58.624409437179565, 59.68900591135025, 57.81993940472603, 52.492214888334274, 55.001015067100525, 56.45891323685646, 49.78791519999504, 45.597515255212784, 45.889681577682495, 46.6478206962347, 46.79461821913719, 45.79857386648655, 46.55099809169769, 46.88665688037872, 47.693832367658615, 47.855053916573524, 45.41691094636917, 46.11931085586548, 45.37069022655487, 46.48198239505291, 46.728900745511055, 50.91053456068039, 53.50048318505287, 55.14203689992428, 59.6172733604908, 59.47844780981541, 62.34792843461037, 64.94180604815483, 64.15027812123299, 64.19929549098015, 65.09138122200966, 65.90754702687263, 64.29348483681679, 62.1536448597908, 60.917620584368706, 68.30560594797134, 59.19839523732662, 69.86881166696548, 17.166146971285343, 0.2564376115333289, 0.7282024843152612, 0.8113580534700304, 0.7487784989643842, 0.1334271239466034, 1.9269622187130153, 53.308179304003716, 56.46624304354191, 22.605997771024704, 30.22009190171957, 51.4694731682539, 30.605936497449875, 32.047134563326836, 51.813882887363434, 52.546950951218605, 69.37362223863602, 43.02020475268364, 0.8781058655586094, 0.054935162552283145, 0.10661882770364173, 0.07539427038864233, 0.09254611955839209, 0.05568988221057225, 0.011148374487675028, 0.016806607636681292, 0.09743267961312085, 0.08968400477897376, 0.029681702799280174, 0.043507138470886275, 0.09984471151256002, 0.023173934132501017, 0.017359797093376983, 0.15297541249310598, 0.20507677691057324, 0.12542185897473246, 0.1180759551061783, 0.16939952649408951, 0.14731656614458188, 0.13194404571549967, 0.14302837749710307, 0.1638419387745671, 0.1558793621370569, 0.10912967656622641, 0.16339213791070506, 0.2514309645630419, 0.42939301987644285, 20.861581675708294, 102.09434285759926, 78.28488126397133, 82.27812498807907, 51.54632784426212, 33.08784931898117, 68.10050055384636, 61.31988599896431, 45.26392735540867, 91.43863543868065, 32.2744345664978, 0.2521676797186956, 0.5206661112606525, 2.801104006357491, 3.9872870687395334, 26.583497039973736, 18.515344373881817, 4.683888489380479, 2.556642461568117, 59.43538472056389, 67.24879145622253, 67.95896574854851, 75.78382506966591, 71.95020318031311, 72.55557909607887, 67.8569184243679, 65.71095317602158, 64.72672238945961, 60.88701702654362, 69.09432962536812, 70.14665275812149, 74.89194452762604, 71.4214539527893, 69.25605654716492, 65.3354649245739, 55.2566197514534, 52.61951945722103, 51.36639229953289, 50.56246943771839, 51.2278251349926, 48.677227199077606, 53.113291561603546, 47.77466543018818, 59.244334772229195, 65.21982192993164, 66.1154642701149, 66.6059647500515, 64.7357203066349, 63.45919780433178, 62.01061673462391, 58.22464808821678, 54.87504422664642, 49.318796172738075, 48.50546881556511, 49.66273471713066, 50.880029797554016, 52.35131844878197, 59.86381933093071, 64.47898328304291, 63.835943788290024, 61.728128492832184, 61.59019589424133, 62.32403911650181, 58.67096833884716, 56.885694935917854, 52.21020922064781, 51.94567881524563, 52.65228129923344, 55.561678782105446, 50.35691946744919, 55.62791682779789, 58.685130178928375, 66.11313879489899, 51.05255573987961, 40.8291245251894, 64.87029388546944, 57.3538564145565, 63.700807839632034, 59.12184454500675, 56.287337243556976, 56.824278831481934, 62.34014645218849, 56.44500598311424, 53.70343029499054, 55.83074614405632, 61.30616873502731, 59.86970141530037, 64.1893020272255, 61.20350204408169, 65.70718377828598, 56.21265225112438, 61.300203055143356, 63.04377369582653, 59.49287183582783, 53.44610810279846, 58.83842155337334, 60.93400530517101, 51.677367612719536, 48.70180808007717, 48.084303215146065, 48.00152845680714, 51.461083218455315, 48.602382615208626, 50.922363325953484, 49.68048736453056, 51.923788189888, 47.99945756793022, 47.77721129357815, 49.50469359755516, 48.11196953058243, 48.75605396926403, 49.91378344595432, 53.585670813918114, 57.88239665329456, 58.9883729070425, 62.08045318722725, 62.86327198147774, 65.42376458644867, 67.7518692612648, 66.17132887244225, 69.63140040636063, 70.51446542143822, 67.30247497558594, 67.66189008951187, 63.67074765264988, 64.79348480701447, 71.35427355766296, 62.261137291789055, 70.1791562139988, 17.093690559267998, 1.0711045749485493, 8.278668019920588, 2.981313136406243, 0.9490778634790331, 0.1357702029054053, 2.739768885076046, 60.95050401985645, 64.03312280774117, 34.15545143187046, 41.46085202693939, 80.27124747633934, 44.49193798005581, 36.08836591243744, 59.119883850216866, 62.06813044846058, 77.38371402025223, 48.19687217473984, 1.1163209611549973, 0.21782139694551006, 0.2653326670406386, 0.12373332458082587, 0.1593393288203515, 0.07955482447869144, 0.14949542266549543, 0.17431928281439468, 0.25290255434811115, 0.24663179239723831, 0.1262679518549703, 0.11482075438834727, 0.13936236093286425, 0.15608737128786743, 0.13019277015700936], [0.03517872384691145, 0.07204655354144052, 0.07911833774414845, 0.019023068780370522, 0.052263067263993435, 0.046623939779237844, 0.026895780611084774, 0.07810160284861922, 0.1102803839603439, 0.07779414590913802, 0.05191401294723619, 0.06793503314838745, 0.032380148040829226, 0.04500623224885203, 32.312622517347336, 77.71480545401573, 57.45802782475948, 59.28530037403107, 31.305408664047718, 25.140756256878376, 36.650507748126984, 36.63842439651489, 49.98713470995426, 72.15596973896027, 6.310503780841827, 0.1958471315447241, 0.05594845388259273, 0.7121207378804684, 2.1744371205568314, 5.603802027180791, 3.2621237682178617, 0.9230272332206368, 12.216197233647108, 71.99408322572708, 73.68588924407959, 70.00883415341377, 68.63317877054214, 69.23741474747658, 67.11785808205605, 64.94573503732681, 61.665735840797424, 56.13209277391434, 52.08617627620697, 53.47025200724602, 55.2535343170166, 59.28854160010815, 59.85767126083374, 59.739816784858704, 51.20007902383804, 46.69650748372078, 47.53176726400852, 46.03648290038109, 46.10238656401634, 44.87797066569328, 44.888743087649345, 44.38646703958511, 46.29602037370205, 45.13310797512531, 49.661674574017525, 53.52285638451576, 60.82464337348938, 57.84379452466965, 54.936828911304474, 53.57088200747967, 52.93239086866379, 45.510435327887535, 43.46586763858795, 41.800834983587265, 45.16681596636772, 45.3693450987339, 48.963036462664604, 55.09576678276062, 49.50571194291115, 55.63018150627613, 57.44584187865257, 57.965008020401, 57.823811396956444, 52.08478935062885, 48.30898515880108, 44.15283277630806, 46.37624926865101, 43.66184592247009, 48.133191391825676, 44.00233805179596, 52.38618157804012, 52.917921245098114, 63.14091548323631, 39.46619085967541, 35.76495386660099, 63.97025138139725, 52.749385088682175, 57.178864404559135, 53.73128280043602, 58.50091986358166, 53.78810115158558, 56.795810759067535, 54.54467095434666, 50.34367337822914, 47.38398939371109, 49.57040347158909, 50.43514207005501, 55.021689757704735, 54.85595025122166, 53.718390092253685, 53.52022312581539, 53.485701978206635, 55.75021706521511, 55.321710258722305, 57.70287148654461, 54.93623614311218, 55.824670270085335, 53.933884128928185, 42.58512809872627, 42.77316860854626, 43.41878056526184, 43.92666131258011, 43.328375816345215, 44.38049376010895, 45.3921514749527, 46.61482326686382, 44.285126477479935, 44.03902508318424, 43.87799732387066, 43.74544143676758, 43.349479883909225, 44.20332446694374, 48.48362758755684, 54.17055822908878, 56.45393930375576, 57.69435614347458, 61.79843991994858, 61.838303580880165, 58.36673766374588, 63.61256517469883, 61.47924944758415, 58.26234966516495, 60.88965028524399, 58.487111404538155, 58.81574057042599, 63.81279543042183, 67.76302546262741, 66.06903076171875, 61.65046826004982, 62.21670247614384, 5.187588986009359, 0.5908006697427481, 1.3493911921977997, 0.26803963584825397, 0.12800671480363235, 0.03710496072017122, 25.434514693915844, 67.28801295161247, 38.06115545332432, 38.966023698449135, 66.39386773109436, 53.07335190474987, 19.674149192869663, 29.163112118840218, 41.63839749991894, 52.97367565333843, 41.53088986873627, 1.7127686622552574, 0.28168939403258264, 0.03449000338150654, 0.0436201601405628, 0.05492208219948225, 0.13812408753437921, 0.09387881640577689, 0.028447294134821277, 0.0771539841662161, 0.03932688036002219, 0.014611079695896478, 0.029272504834807478, 0.038199925402295776, 0.0610052069532685, 0.05374979315092787, 0.029192915062594693, 0.03216692159185186, 0.02669428380613681, 0.04947941975842696, 0.07346222249907441, 0.06290388788329437, 0.01803922586987028, 0.04007458672276698, 0.0618665138608776, 0.027279025671305135, 0.05549518347834237, 0.03173011202306952, 0.05987576209008694, 0.03522140104905702, 42.04095929861069, 87.83348768949509, 63.3506528288126, 68.61048638820648, 38.17757360637188, 21.861477121710777, 46.568990126252174, 39.90256704390049, 58.717268854379654, 77.58535400032997, 6.496287686750293, 0.326469189603813, 0.34540268301498145, 2.2435169387608767, 5.835229558870196, 7.829940598458052, 4.1923444904387, 0.7082199503201991, 14.050112776458263, 76.98240235447884, 72.74935349822044, 73.72178211808205, 69.73793908953667, 72.43553593754768, 69.58330258727074, 66.3918386399746, 65.36926031112671, 58.341529816389084, 53.90725515782833, 56.88269689679146, 58.374846428632736, 61.270427852869034, 62.12506279349327, 61.06214962899685, 54.37713034451008, 47.79861934483051, 49.03101861476898, 48.72299574315548, 48.09001810848713, 47.84377232193947, 47.70577512681484, 46.32866822183132, 48.208548948168755, 47.62767031788826, 51.752861961722374, 56.91102057695389, 62.33510412275791, 59.82585936784744, 57.91139669716358, 56.21207848191261, 54.93431344628334, 48.31503443419933, 44.56573761999607, 44.398808777332306, 47.32305966317654, 46.74864448606968, 50.501691699028015, 57.56831310689449, 52.44559518992901, 55.55363081395626, 57.762345895171165, 59.891143664717674, 60.635846704244614, 55.87704285979271, 51.221810057759285, 46.20817668735981, 48.80123354494572, 45.1948356628418, 49.99497748911381, 45.951568856835365, 55.01175709068775, 57.496291771531105, 65.50529301166534, 41.527603045105934, 37.56868287920952, 65.81330448389053, 55.30468337237835, 59.6014092117548, 58.45590367913246, 60.4080755263567, 55.50615236163139, 60.045430585742, 55.56811563670635, 52.63654254376888, 49.46306683123112, 52.081977501511574, 52.296460792422295, 56.18044137954712, 56.61134585738182, 57.99154959619045, 55.41824787855148, 57.366798520088196, 57.01593674719334, 58.728178068995476, 59.23295818269253, 56.370936557650566, 57.30030968785286, 54.39475379884243, 44.971270859241486, 44.50343236327171, 45.726119354367256, 44.73064877092838, 45.62500678002834, 46.98787584900856, 47.62502186000347, 48.346789330244064, 45.63417948782444, 46.31610609591007, 47.39787004888058, 46.11631281673908, 45.832844227552414, 47.526059970259666, 52.20296300947666, 56.50032341480255, 59.16219837963581, 61.32350720465183, 63.985625356435776, 64.41383957862854, 63.20850245654583, 64.97722774744034, 62.17025376856327, 61.75466626882553, 61.49848781526089, 62.20150709152222, 63.27496849000454, 68.92561107873917, 70.56038215756416, 68.52581173181534, 65.10003715753555, 68.26006159186363, 7.195920394733548, 0.3090026549762115, 1.4905318873934448, 1.1437058541923761, 0.16391187877161428, 0.05634517263388261, 26.476120501756668, 72.45812952518463, 44.76541310548782, 42.153197675943375, 61.22300259768963, 51.45928971469402, 29.51954249292612, 34.93457302451134, 46.896939128637314, 59.982384368777275, 54.60664562880993, 3.2257533073425293, 0.20062772033270448, 0.018055198743240908, 0.07627250568475574, 0.04318991115724202, 0.09204528119880706, 0.03200970131729264, 0.050993538316106424, 0.024280105244542938, 0.02668261353392154, 0.04155278162215836, 0.07014970571617596, 0.0027499226916916086, 0.022226345136004966, 0.01273315014259424, 0.14011497289175168, 0.1650146656902507, 0.1192845351761207, 0.27118562953546643, 0.13565220142481849, 0.13495272723957896, 0.09273301460780203, 0.19129142834572122, 0.20572422654367983, 0.31856288260314614, 0.12628816795768216, 0.14925927127478644, 0.1598813192686066, 0.1235871808603406, 49.24323342740536, 99.51348334550858, 72.5148756802082, 79.88739967346191, 44.13855694234371, 36.96590982377529, 53.140087723731995, 51.78807467222214, 68.28819528222084, 84.68496143817902, 8.187641054391861, 0.47377110575325787, 1.1165546486154199, 4.208677913993597, 7.747784731909633, 22.371010780334473, 14.130753949284554, 2.596642915159464, 17.85220965743065, 80.16830340027809, 76.4240451157093, 74.6927972137928, 72.06389307975769, 75.21929696202278, 74.16556030511856, 69.53009784221649, 67.18126907944679, 61.744688004255295, 56.60394385457039, 58.93473498523235, 59.36193846166134, 63.578929379582405, 64.94299918413162, 64.57762598991394, 55.57003453373909, 49.11510430276394, 50.422978922724724, 50.19278347492218, 50.349266678094864, 49.436130076646805, 49.880607426166534, 48.70641343295574, 51.181995794177055, 50.52725292742252, 53.3747099339962, 59.0069805085659, 64.76177170872688, 62.105995416641235, 60.403956547379494, 59.23626780509949, 58.75251956284046, 51.38438433408737, 47.081168442964554, 47.92270548641682, 50.09974546730518, 49.05085355043411, 53.774532079696655, 59.982752948999405, 54.17530037462711, 58.111535757780075, 60.54736465215683, 62.53663770854473, 62.40284688770771, 60.08283577859402, 53.77297416329384, 49.22725908458233, 50.8682656288147, 47.560144141316414, 52.80439093708992, 48.40105041861534, 56.62743799388409, 61.60549007356167, 68.22258800268173, 45.946328938007355, 42.428177520632744, 67.01875939965248, 58.88004831969738, 63.2839398086071, 61.62439025938511, 61.59701272845268, 58.8864129781723, 62.44590237736702, 60.1705426722765, 55.372277945280075, 51.96869418025017, 53.80640856921673, 55.787223279476166, 59.03211236000061, 60.80144181847572, 58.769690841436386, 59.382274970412254, 59.66952055692673, 61.008397713303566, 62.74748079478741, 62.10471488535404, 58.43640312552452, 62.106322199106216, 57.0009845495224, 47.49856844544411, 47.86538176238537, 47.755195274949074, 47.66162909567356, 47.2173797339201, 49.43223528563976, 50.45190677046776, 51.50157004594803, 49.06174376606941, 48.07857312262058, 49.06014405190945, 48.33178773522377, 49.69500258564949, 49.66212294995785, 55.190518498420715, 59.166241362690926, 62.204299941658974, 63.22623610496521, 69.5611421763897, 68.17495375871658, 66.50613650679588, 67.51756623387337, 62.294469103217125, 63.67157220840454, 65.6422832608223, 65.15068843960762, 66.00207835435867, 71.1087915301323, 73.68099510669708, 69.46591928601265, 69.74484711885452, 69.57843884825706, 7.433995194733143, 2.2018856601789594, 6.76174096763134, 1.5755466255359352, 0.3943138662725687, 0.18642648705281317, 32.702971771359444, 80.73422983288765, 55.20944148302078, 53.038576170802116, 74.63632464408875, 64.64098379015923, 28.883363530039787, 39.98156860470772, 56.46466612815857, 68.35729837417603, 64.50623542070389, 4.335750220343471, 0.46980812621768564, 0.20522253471426666, 0.1610511666513048, 0.1540295293671079, 0.18507987493649125, 0.23116473719710484, 0.19820352463284507, 0.1507641389616765, 0.0645244935003575, 0.17284494708292186, 0.21549670840613544, 0.15635852236300707, 0.1995966545655392, 0.16484395688166842], [0.029813929395459127, 0.020650696969823912, 0.023538542009191588, 0.019662670201796573, 0.023172462824732065, 0.029201991528680082, 0.011954952642554417, 0.033585340206627734, 0.05756258426117711, 0.01661810583755141, 0.0028685475763268187, 0.06092990493925754, 0.022278052420006134, 1.1418984574265778, 57.07784682512283, 63.91452357172966, 64.82823014259338, 42.910250052809715, 26.8824402987957, 50.28891071677208, 40.266055539250374, 30.6126906350255, 63.81394296884537, 49.85825702548027, 0.42572574166115373, 0.061010216450085863, 0.30739234294742346, 1.6211257735267282, 1.6175006492994726, 1.3472039345651865, 0.8015568950213492, 0.17050393129466102, 51.48115374147892, 81.008081138134, 67.38385140895844, 71.21901601552963, 70.63018441200256, 67.7570141851902, 70.2308638393879, 69.03247654438019, 64.3284809589386, 63.32875460386276, 55.77971488237381, 50.7037078589201, 50.06178170442581, 49.31296728551388, 48.97904500365257, 49.66149598360062, 48.95743936300278, 48.540202751755714, 47.915071696043015, 46.65370278060436, 44.98813055455685, 47.7895188331604, 45.42524769902229, 44.25420753657818, 44.75483827292919, 47.05630637705326, 44.374676272273064, 44.305527582764626, 49.77700978517532, 54.86153595149517, 54.116973504424095, 52.16662175953388, 47.80343368649483, 44.573895782232285, 42.32771471142769, 42.61032834649086, 43.12585428357124, 43.53359900414944, 48.63516345620155, 57.58856222033501, 51.43322691321373, 47.19823256134987, 59.60045166313648, 56.45458906888962, 56.46196447312832, 48.47978599369526, 46.030228435993195, 43.53877432644367, 48.21603834629059, 41.96555994451046, 45.07939025759697, 43.51653032004833, 51.65162779390812, 50.79632788896561, 63.44413161277771, 38.302947878837585, 36.36737734079361, 66.5280233323574, 53.92673671245575, 55.72437085211277, 52.49983347952366, 58.453411012887955, 55.03825306892395, 57.52099424600601, 53.72977428138256, 49.21234108507633, 48.24427083134651, 47.40353934466839, 45.78879699110985, 46.92150101065636, 48.083068281412125, 49.21354182064533, 46.88321806490421, 50.60811638832092, 52.38732531666756, 52.738502472639084, 55.221809819340706, 55.07170267403126, 54.14470061659813, 55.19162803888321, 46.99128806591034, 42.77618184685707, 41.682095155119896, 45.078083127737045, 43.9506646245718, 43.012122586369514, 42.97817140817642, 46.24282322824001, 44.535023868083954, 43.841181099414825, 46.063096672296524, 44.43803787231445, 44.23629529774189, 47.799736484885216, 52.0622755587101, 57.3616573959589, 60.44030159711838, 62.39467352628708, 59.78197932243347, 59.1785679012537, 58.83849374949932, 57.6780816167593, 62.1904306858778, 63.752439469099045, 62.40791201591492, 66.46069094538689, 67.54978090524673, 67.39018946886063, 63.25231410562992, 66.53566852211952, 58.327466771006584, 60.42504921555519, 39.29077707231045, 0.25672467425465584, 0.6223901559133083, 0.6104921631049365, 0.07147009033360519, 0.21192359388805926, 5.025991257280111, 58.387811332941055, 48.429822474718094, 32.535963132977486, 71.80486857891083, 65.3802265226841, 20.035901181399822, 20.583341605961323, 39.028940722346306, 49.88328628242016, 50.2963887155056, 4.624306736513972, 0.4143685370218009, 0.053241915520629846, 0.11178604574524797, 0.040648734429851174, 0.10814647932420485, 0.056348241414525546, 0.02140207139746053, 0.024836035081534646, 0.02043938155111391, 0.03522578343108762, 0.036559374566422775, 0.047915239629219286, 0.0214676995165064, 0.01969236724107759, 0.04464082099730149, 0.04774835288117174, 0.027334237747709267, 0.032536744911340065, 0.03223620107746683, 0.08115018965327181, 0.017122975914389826, 0.06278144093812443, 0.07483715497073717, 0.01405802475346718, 0.018701896951824892, 0.062279378034872934, 0.04318030034482945, 2.3909198166802526, 70.26467442512512, 72.61313080787659, 70.18623143434525, 51.72482326626778, 35.82041949033737, 49.80152606964111, 44.07593250274658, 33.021216094493866, 73.03792521357536, 52.88015887141228, 0.4715574870351702, 0.051229493037681095, 0.7937627413775772, 2.6392505038529634, 4.277632338926196, 5.7854104321449995, 1.8717566435225308, 0.41335479298140854, 55.552392080426216, 83.04645895957947, 69.81647327542305, 74.1302601993084, 71.45793199539185, 69.88072782754898, 71.437306702137, 69.78396981954575, 68.0195876955986, 64.70614269375801, 58.42951789498329, 52.93150931596756, 52.79122084379196, 52.5818482786417, 52.11602747440338, 53.216630816459656, 53.35578314960003, 51.39036901295185, 50.95270849764347, 47.799880877137184, 47.684484869241714, 48.93435180187225, 48.075746074318886, 46.3327644020319, 46.7027847468853, 49.954372867941856, 45.58687202632427, 47.144480645656586, 52.84269668161869, 57.094972506165504, 56.54957637190819, 55.177397802472115, 50.38303926587105, 45.9628314524889, 45.77124573290348, 43.73828262090683, 44.62713472545147, 45.247554033994675, 51.77039422094822, 61.01277507841587, 53.83400648832321, 47.34620422124863, 59.80549246072769, 60.45869641005993, 59.49174329638481, 52.622874677181244, 47.799599692225456, 46.35637253522873, 50.30123345553875, 46.134563237428665, 48.6142797768116, 46.8025977909565, 55.90339444577694, 54.473006799817085, 66.21884912252426, 40.20497381687164, 37.455410957336426, 69.47408884763718, 57.42756485939026, 59.17427033185959, 54.699246659874916, 59.865514039993286, 57.20015846192837, 59.4131863117218, 57.360057681798935, 51.70055016875267, 50.12123331427574, 50.55979438126087, 48.814437836408615, 49.29372511804104, 49.31454800069332, 51.84746168553829, 50.45422464609146, 53.905191868543625, 54.43027429282665, 56.126826256513596, 57.17330530285835, 57.55750648677349, 56.8235644698143, 57.61717088520527, 49.54886242747307, 44.16029557585716, 44.52090002596378, 45.64942426979542, 45.83358898758888, 45.08070878684521, 46.41326308250427, 46.71719737350941, 46.277108788490295, 46.007623448967934, 48.25953461229801, 45.51429972052574, 46.94276086986065, 51.118470802903175, 55.80290503799915, 59.57829885184765, 62.96466954052448, 64.51862275600433, 61.881959438323975, 59.61376614868641, 61.168528720736504, 61.160872131586075, 64.8056061565876, 65.69413527846336, 63.91363441944122, 67.51400202512741, 70.10697528719902, 68.48960727453232, 63.87344017624855, 67.17204317450523, 63.40293802320957, 63.549800142645836, 47.093988955020905, 0.277579766116105, 0.32487185031641275, 1.4688459760509431, 0.5271113372873515, 0.15730535436887294, 4.5928021520376205, 62.4601212143898, 56.629022508859634, 34.410892724990845, 68.80059018731117, 63.07155020534992, 22.71075814962387, 25.85013449192047, 45.668818429112434, 58.610293194651604, 60.64155399799347, 8.004574477672577, 0.5342917644884437, 0.06459233321947977, 0.04215928325720597, 0.060736430750694126, 0.15055160271003842, 0.014975231151765911, 0.047792907716939226, 0.028923571117047686, 0.06191368476720527, 0.02446404098009225, 0.04182102718914393, 0.048054451690404676, 0.033531508524902165, 0.07564077473944053, 0.1581548314425163, 0.12956276099430397, 0.1233082520775497, 0.1306768285576254, 0.1624894340056926, 0.16464062326122075, 0.1434351337957196, 0.1487945532426238, 0.11527742011821829, 0.11836934834718704, 0.17211698926985264, 0.09522458247374743, 0.24348677834495902, 3.178491680882871, 81.47341176867485, 81.13740339875221, 81.77317008376122, 58.99518594145775, 44.282683208584785, 66.21981427073479, 53.77862825989723, 45.61461053788662, 78.42551171779633, 59.11164969205856, 0.7626224029809237, 0.1324681207188405, 1.8331964313983917, 6.9491644855588675, 7.939989818260074, 11.145344395190477, 6.191657558083534, 1.084333446342498, 61.68930597603321, 85.64281404018402, 73.21028396487236, 77.28909149765968, 74.70449298620224, 71.5442405641079, 74.69527468085289, 74.19631585478783, 73.4222061932087, 67.28411436080933, 62.359992787241936, 54.79626685380936, 54.9956763535738, 55.51836870610714, 52.53050923347473, 54.59708534181118, 55.0725082308054, 55.51553785800934, 54.113029316067696, 51.402026787400246, 50.35305127501488, 52.16984398663044, 50.24420231580734, 48.26351299881935, 48.547251373529434, 51.99116997420788, 48.34927439689636, 49.241105541586876, 54.61051382124424, 60.839268788695335, 59.21941950917244, 57.8046490252018, 52.5269678235054, 49.23560343682766, 48.18177558481693, 46.18097014725208, 46.65280982851982, 48.55227470397949, 53.682151436805725, 62.6634407043457, 54.20741245150566, 49.1653224080801, 62.40697346627712, 61.48864634335041, 61.80181793868542, 53.9308100938797, 51.56811587512493, 48.42429757118225, 53.13775084912777, 48.412476405501366, 50.028237104415894, 48.94975997507572, 58.103347197175026, 58.12891602516174, 68.31926241517067, 44.88275080919266, 40.298710986971855, 71.18230998516083, 61.06490068137646, 60.54449200630188, 57.58207216858864, 63.71594622731209, 58.226057812571526, 61.17181554436684, 59.206363409757614, 54.63550888001919, 51.9616873562336, 52.20439933240414, 52.5964242964983, 51.34919062256813, 52.0130567997694, 55.323887541890144, 54.07117076218128, 55.13674758374691, 57.757208570837975, 59.72218573093414, 61.377696096897125, 60.89275471866131, 59.15604650974274, 60.11899843811989, 52.36136510968208, 48.08045022189617, 46.15950129926205, 48.85094627737999, 48.7748059630394, 46.256844475865364, 47.78518706560135, 49.878893718123436, 48.85763771831989, 47.60066896677017, 51.784822046756744, 49.10310074687004, 50.589493587613106, 53.437767550349236, 57.62357734143734, 62.48192064464092, 66.9837860763073, 66.41424983739853, 65.39290264248848, 62.040027156472206, 62.95975640416145, 66.3854929804802, 69.40495535731316, 65.91124042868614, 68.13910648226738, 69.97563153505325, 71.50706335902214, 71.3859410583973, 68.7229223549366, 70.7768489420414, 65.72714790701866, 67.76677206158638, 46.751513332128525, 0.27457059477455914, 4.141287105157971, 3.021804951131344, 0.6194441264960915, 0.21591545781120658, 6.598862232640386, 67.30331853032112, 62.85271994769573, 45.303019657731056, 77.73392602801323, 73.23679894208908, 28.629717640578747, 31.89474754035473, 55.85402749478817, 63.53783838450909, 73.27535167336464, 11.05135453864932, 0.6367785588372499, 0.1646223515854217, 0.12929974385770038, 0.2063617462408729, 0.18026762612862512, 0.212488412798848, 0.250568826450035, 0.13115209992974997, 0.12289008154766634, 0.11025434199837036, 0.1808035309659317, 0.14843799581285566, 0.18521130929002538, 0.15937876654788852], [0.05178099039767403, 0.017706456128507853, 0.03066716730245389, 0.114595289924182, 0.03750724557903595, 0.06754141286364757, 0.05137744017702062, 0.03915706212865189, 0.010302167502231896, 0.040898448569350876, 0.08589065793785267, 0.06079345737816766, 0.09283287057769485, 13.690935149788857, 72.79839366674423, 64.83652889728546, 60.015484392642975, 41.48449815809727, 25.90018540620804, 51.07666924595833, 49.7636117041111, 42.780669406056404, 76.57735168933868, 26.062130816280842, 0.0882546506181825, 0.062453248392557725, 0.5772418098058552, 1.2763644545339048, 7.9154706839472055, 5.57719680480659, 2.1573439752683043, 6.091248420998454, 82.62791901826859, 66.3722924888134, 71.29732221364975, 62.69978195428848, 70.7590202987194, 66.59830436110497, 72.52716422080994, 66.15166872739792, 66.01835668087006, 62.87193551659584, 62.730320915579796, 58.215741366147995, 56.271822676062584, 52.47408226132393, 53.23874182999134, 50.24029232561588, 50.69591827690601, 48.890954330563545, 46.611703634262085, 43.8204950094223, 47.799744084477425, 45.03213979303837, 44.10259947180748, 44.40252497792244, 44.92521733045578, 43.55192922055721, 47.06389456987381, 45.29629401862621, 46.08387775719166, 46.42872825264931, 51.15854725241661, 46.759291514754295, 47.16444477438927, 43.69990848004818, 42.60316573083401, 42.04546585679054, 44.213025346398354, 46.00418843328953, 52.15809881687164, 55.14990247786045, 61.384402737021446, 55.07844351232052, 59.04052130877972, 56.08490690588951, 53.99672895669937, 46.291335225105286, 44.141706973314285, 42.62893594801426, 46.23540602624416, 41.79527588188648, 48.03850807249546, 43.21839451789856, 53.56477193534374, 51.532283797860146, 63.34373340010643, 39.45927903056145, 41.7365538328886, 62.34914816915989, 50.20854502916336, 49.222049564123154, 50.329218953847885, 57.26780243217945, 55.70755295455456, 56.152440682053566, 55.41939161717892, 50.60368202626705, 48.269569873809814, 53.549458757042885, 49.86388832330704, 49.186095893383026, 46.87116891145706, 46.45671755075455, 45.49024321138859, 46.470727398991585, 47.74388708174229, 52.135144248604774, 54.231503158807755, 55.19732013344765, 56.84106633067131, 55.337103232741356, 49.280129447579384, 42.85425245761871, 41.50904484093189, 42.147786766290665, 42.03040726482868, 46.199494153261185, 45.33640466630459, 44.756787568330765, 44.840877056121826, 44.60190027952194, 47.24195681512356, 42.398216128349304, 45.88038727641106, 48.441066071391106, 56.59914091229439, 60.661848708987236, 61.91827408969402, 59.221319407224655, 60.56175448000431, 60.13462319970131, 62.30796977877617, 59.416112154722214, 58.08408983051777, 59.93110992014408, 64.24336552619934, 63.58546122908592, 62.8323720395565, 60.15618324279785, 64.26781341433525, 62.00291454792023, 68.83679464459419, 58.84251393377781, 63.920838832855225, 11.872649118304253, 1.0943894879892468, 1.5842856816016138, 0.16949630255112424, 0.06581516252481379, 0.27810001163743436, 33.5312133282423, 69.45540145039558, 39.19081583619118, 55.66240757703781, 78.83009880781174, 37.18816749751568, 16.799540743231773, 36.70337811112404, 44.47235383093357, 50.522339791059494, 18.338710851967335, 0.4748754214961082, 0.03746470938494895, 0.07249232454341836, 0.022439243184635416, 0.019828818512905855, 0.05453535646665841, 0.0900037145765964, 0.0329561808030121, 0.026290342102583963, 0.02060590650216909, 0.0623474626627285, 0.054098350228741765, 0.04293503538065124, 0.011499762858875329, 0.01257112260645954, 0.05984042101772502, 0.007134812485674047, 0.05926722697040532, 0.03806482854997739, 0.08085217283223756, 0.03779578888497781, 0.06759633179171942, 0.016767364722909406, 0.1654086125199683, 0.055885033652884886, 0.14186739135766402, 0.10680878782295622, 21.915191039443016, 84.64839980006218, 71.6889064013958, 66.35955557227135, 51.672735661268234, 38.143998607993126, 47.957279831171036, 44.468025863170624, 48.71302507817745, 85.3368316590786, 27.94209323823452, 0.12817942741094157, 0.11175317602464929, 1.1948407790623605, 2.5571326352655888, 5.225343760102987, 2.4409526819363236, 0.9781540813855827, 8.479006569832563, 86.80786192417145, 67.6747789978981, 75.33503115177155, 64.52263534069061, 72.36474573612213, 68.87927636504173, 73.97370859980583, 68.24534878134727, 68.67991626262665, 66.09230071306229, 64.94173765182495, 61.315010860562325, 59.258356019854546, 55.410420298576355, 55.13663738965988, 51.09042450785637, 53.26648034155369, 49.61199603974819, 49.89885404706001, 48.217193484306335, 49.84119974076748, 48.00673797726631, 46.50143355131149, 46.311580538749695, 47.566353008151054, 47.048060819506645, 48.458043560385704, 46.94874934852123, 47.29059800505638, 48.47718693315983, 52.75587134063244, 48.70194487273693, 49.99112069606781, 44.377621114254, 45.05265489220619, 45.234828516840935, 45.18885478377342, 46.94200851023197, 54.97618339955807, 57.714692652225494, 62.19818986952305, 57.87258937954903, 61.51204168796539, 58.21256473660469, 56.44852839410305, 47.42389105260372, 47.19914451241493, 47.40446649491787, 48.50378170609474, 43.387690633535385, 51.09483987092972, 46.18330702185631, 56.90773755311966, 56.55665539205074, 65.66734671592712, 40.897053480148315, 44.48568731546402, 64.85372677445412, 51.19928486645222, 51.59523881971836, 51.21481463313103, 58.63637499511242, 59.556754007935524, 58.25750112533569, 59.30786356329918, 53.33798490464687, 51.174122616648674, 54.939633160829544, 54.25162307918072, 51.182569563388824, 48.200531378388405, 47.882161661982536, 47.22574308514595, 48.580085411667824, 49.946431294083595, 53.885049149394035, 56.70425087213516, 57.56961643695831, 57.64403164386749, 58.587046042084694, 51.528115421533585, 44.21661615371704, 44.89803358912468, 44.52814243733883, 44.14773344993591, 47.949972823262215, 47.806158140301704, 45.72277553379536, 46.91078558564186, 47.08165481686592, 48.28239418566227, 44.860951378941536, 48.186707720160484, 50.76755963265896, 60.39856843650341, 62.62254349887371, 63.13757546246052, 61.52249112725258, 63.66671606898308, 63.65519508719444, 63.48553419113159, 60.37588745355606, 62.878414168953896, 61.23262748122215, 67.8608626127243, 64.62476626038551, 64.26310166716576, 61.84822864830494, 66.90182447433472, 63.71550925076008, 70.65356075763702, 59.68312382698059, 70.44791579246521, 14.186677448451519, 0.6741724710445851, 0.3334915393497795, 0.5022017145529389, 0.2930091350572184, 0.12079528809408657, 32.668587416410446, 77.00618147850037, 43.060554787516594, 56.716782599687576, 73.99732813239098, 34.84206698834896, 22.4723057448864, 40.422398149967194, 51.694447696208954, 58.82803671061993, 27.27593768388033, 0.4520861146738753, 0.05622613585728686, 0.10036996653070673, 0.07612835092004389, 0.056456194215570576, 0.06585376904695295, 0.07241728599183261, 0.027453884940769058, 0.07238858714117669, 0.05317979404935613, 0.032894007381401025, 0.013756842672592029, 0.04913757169560995, 0.017532483725517523, 0.08579338464187458, 0.14805878803599626, 0.07035240851109847, 0.18241725687403232, 0.13765674229944125, 0.18613385822391137, 0.15326482040109113, 0.14000883093103766, 0.15069790970301256, 0.32118037808686495, 0.11689991079038009, 0.20333123073214665, 0.22095618420280516, 29.380397759377956, 96.12357124686241, 81.25731736421585, 76.07541382312775, 55.81185355782509, 36.599392890930176, 57.57414199411869, 65.1919238269329, 59.07374292612076, 90.50811856985092, 31.35314740240574, 0.39425440540071577, 0.16810394445201382, 1.8273333460092545, 5.0808284897357225, 13.968797139823437, 15.432262010872364, 7.586601655930281, 11.01127428933978, 90.50824016332626, 69.50229093432426, 77.70067781209946, 66.4305129647255, 77.14283734560013, 70.83632335066795, 77.51865237951279, 69.99257102608681, 72.24280267953873, 68.88438329100609, 66.68335899710655, 63.08815911412239, 61.33018344640732, 57.42611713707447, 60.066755041480064, 52.866472005844116, 56.53786540031433, 53.6365082859993, 51.66048891842365, 49.87654164433479, 53.71391773223877, 50.20879961550236, 47.297160252928734, 49.46498952805996, 48.93965631723404, 48.40815223753452, 51.59013569355011, 49.509481340646744, 49.0748530626297, 50.69486953318119, 55.7173640280962, 50.69262005388737, 53.40769216418266, 48.46586734056473, 49.05756779015064, 46.49932086467743, 48.23852173984051, 51.573393791913986, 59.6673508733511, 61.77167035639286, 63.72409299015999, 57.46000751852989, 64.26479637622833, 61.29993326961994, 58.92893649637699, 52.04574264585972, 48.6249116063118, 48.98342616856098, 50.7838911563158, 46.307431161403656, 55.54207943379879, 48.13504949212074, 58.8444784283638, 58.757615089416504, 69.31561455130577, 43.52621600031853, 46.64905562996864, 66.3313838839531, 54.29813638329506, 53.32533918321133, 55.66339932382107, 61.545726880431175, 63.553041368722916, 61.09004773199558, 61.11911617219448, 54.6187099814415, 56.128205582499504, 57.56009414792061, 56.756030693650246, 51.49370066821575, 49.56331305205822, 51.122654378414154, 50.5093938857317, 49.99645560979843, 52.56021223962307, 57.647481858730316, 58.59042406082153, 61.53324835002422, 60.99889822304249, 61.83391861617565, 53.87756735086441, 46.50860756635666, 45.72764307260513, 45.387656316161156, 47.678078413009644, 52.2857453674078, 49.019737020134926, 49.314225018024445, 48.78485642373562, 48.557738810777664, 51.89888432621956, 47.2370208799839, 50.284233167767525, 53.92224155366421, 62.87236109375954, 65.47097325325012, 65.62893077731133, 63.7893582880497, 65.47693893313408, 64.1069908440113, 66.17654219269753, 61.74196355044842, 62.54269078373909, 64.7026164829731, 70.52466407418251, 68.17552372813225, 66.47633850574493, 65.54829150438309, 70.5584366619587, 68.13694059848785, 75.06749510765076, 63.0254852771759, 74.60614666342735, 15.017681457102299, 2.2866500867530704, 6.305935950949788, 0.9069206099957228, 0.4154154105344787, 0.5560944601893425, 40.47834254801273, 82.45758175849915, 55.261399894952774, 63.83510023355484, 84.50377956032753, 48.02115440368652, 25.572000816464424, 53.59559208154678, 58.826619386672974, 69.06347528100014, 32.897905111312866, 0.9715614351443946, 0.20709504751721397, 0.1565535884583369, 0.15220102592138574, 0.1722916611470282, 0.15536635997705162, 0.23039113730192184, 0.16784175852080807, 0.147274709015619, 0.19414694543229416, 0.10608347205561586, 0.15328218665672466, 0.1790143465041183, 0.08438921155175194], [0.014531702363456134, 0.08233655724325217, 0.10864558847970329, 0.04556268344458658, 0.022023876117600594, 0.006563661663676612, 0.034693266497924924, 0.0202928482030984, 0.06342272332403809, 0.05283204962324817, 0.018252494992339052, 0.09388116159243509, 0.24173392943339422, 40.77506862580776, 67.91620284318924, 55.20365059375763, 47.55540579557419, 23.4506943449378, 18.730779513716698, 56.81806996464729, 43.806253373622894, 45.59056542813778, 74.97520565986633, 7.03247026540339, 0.07326789855142124, 0.5197323113679886, 0.9029209683649242, 2.5880180904641747, 7.203540410846472, 3.593238713219762, 2.2137080132961273, 33.16369324922562, 81.02552980184555, 69.17976424098015, 63.01480405032635, 60.97366377711296, 66.63399204611778, 65.44083327054977, 68.39952170848846, 65.91816365718842, 65.9273287653923, 64.61878538131714, 65.34777626395226, 61.28295198082924, 62.30464115738869, 61.99536055326462, 58.089428544044495, 55.53463563323021, 50.021952241659164, 46.30377195775509, 47.68847085535526, 45.01613885164261, 44.5994608104229, 45.21390683948994, 46.15950509905815, 44.36128579080105, 46.84449054300785, 45.143356025218964, 44.05974917113781, 43.75650644302368, 46.26480504870415, 44.31924484670162, 46.23931981623173, 44.46020968258381, 43.78142170608044, 41.21923439204693, 43.970769345760345, 42.05773539841175, 44.76319782435894, 44.65583078563213, 52.66197457909584, 55.414159297943115, 57.05343313515186, 56.013968512415886, 60.50387978553772, 54.070239812135696, 50.28102234005928, 42.816136702895164, 44.70955990254879, 43.68736155331135, 45.19616939127445, 49.40121755003929, 53.329917937517166, 50.8644088357687, 54.424977377057076, 51.80005922913551, 61.789141818881035, 41.10331401228905, 42.504481226205826, 57.77301572263241, 51.04214809834957, 51.410086154937744, 46.32936358451843, 55.061735808849335, 56.168244034051895, 56.17700636386871, 54.79926489293575, 52.71225728094578, 47.30691812932491, 51.34377971291542, 52.73847967386246, 55.96089296042919, 53.27054612338543, 53.34962747991085, 49.16280694305897, 46.478969156742096, 44.74016726016998, 48.90562154352665, 49.036380127072334, 53.870864510536194, 54.341309666633606, 54.75655518472195, 48.83042357861996, 43.55143524706364, 40.79708084464073, 43.20798687636852, 42.448742017149925, 42.58485451340675, 44.66980643570423, 44.166994616389275, 43.065350130200386, 46.07316613197327, 42.97022223472595, 44.68809865415096, 46.73428885638714, 51.97363391518593, 55.83881691098213, 59.51561361551285, 57.70798601210117, 60.64153879880905, 60.23356229066849, 59.59355503320694, 59.36946965754032, 62.01763495802879, 64.5821325480938, 59.6439403295517, 58.486332446336746, 63.086661994457245, 61.30172297358513, 59.31472219526768, 56.61462888121605, 56.17687337100506, 61.28161445260048, 64.42151516675949, 61.05394966900349, 40.63962869346142, 0.2608968206914142, 0.8687404962256551, 0.6557080743368715, 0.15569961396977305, 0.24795872275717556, 6.066537396982312, 58.81417125463486, 48.06187681853771, 41.12157583236694, 68.37472423911095, 31.867352910339832, 21.73828773200512, 39.00927297770977, 45.97153678536415, 54.99845780432224, 32.37018562853336, 0.6639154558070004, 0.06326549933874048, 0.08128886736813001, 0.022593626599700656, 0.0316820245643612, 0.07854417519411072, 0.02797145687509328, 0.0876148599490989, 0.027485120081109926, 0.02365332442423096, 0.02363929226703476, 0.016826884966576472, 0.02488361787982285, 0.06405533000361174, 0.05157881081686355, 0.029963409069750924, 0.02648403708008118, 0.059817748406203464, 0.035471701485221274, 0.021591562108369544, 0.050797188305296004, 0.020944969655829482, 0.03383600800589193, 0.03716275547049008, 0.018767567744362168, 0.09510157891782, 0.4944743838859722, 55.95428131520748, 77.7396485209465, 61.56939961016178, 55.28292573988438, 35.7131702452898, 23.446278981864452, 47.048155814409256, 45.36220148205757, 53.8514893501997, 82.22666814923286, 7.2995921317487955, 0.08970343420514837, 0.32867829606402665, 2.4540135310962796, 4.397967606782913, 12.476762551814318, 8.742851112037897, 2.2552143735811114, 39.084524139761925, 84.53576624393463, 71.10524252057076, 64.82007578015327, 63.5032944381237, 69.47151258587837, 69.16888922452927, 69.73799228668213, 67.23207995295525, 67.74344131350517, 67.62125506997108, 65.59985473752022, 64.97416511178017, 64.11814704537392, 64.86968591809273, 59.93728078901768, 57.360760644078255, 51.755263432860374, 50.54445840418339, 49.749776646494865, 47.773331701755524, 46.73715390264988, 48.03108707070351, 46.780737563967705, 47.38585129380226, 48.510233759880066, 48.195059671998024, 46.857512444257736, 45.72116442024708, 47.10027001798153, 48.32124710083008, 47.9438741505146, 46.943357437849045, 45.092788338661194, 44.493359103798866, 45.99971607327461, 44.84202839434147, 46.944900155067444, 49.56256069242954, 54.21432428061962, 59.94579613208771, 59.41849082708359, 56.14892967045307, 61.7498405277729, 57.682348787784576, 52.76326194405556, 44.736310467123985, 46.99953742325306, 45.22983558475971, 47.29697786271572, 53.2173565775156, 56.15149453282356, 52.22215197980404, 55.954763889312744, 53.01946319639683, 63.14497746527195, 43.136729300022125, 44.44352097809315, 62.08811737596989, 54.46655474603176, 54.80677329003811, 45.52716962993145, 56.30550406873226, 59.97810959815979, 59.59830477833748, 57.393191903829575, 54.20090340077877, 48.97223196923733, 53.87578524649143, 55.60536503791809, 59.53879237174988, 56.08938306570053, 56.16495721042156, 50.77132523059845, 48.25727753341198, 47.95961290597916, 51.10402397811413, 51.752512380480766, 54.83390763401985, 57.05523803830147, 57.45111979544163, 49.74281921982765, 46.038580387830734, 43.64247836172581, 46.80499166250229, 44.44020755589008, 46.17303617298603, 46.00692808628082, 46.14776752889156, 45.086872056126595, 48.68629731237888, 46.16455502808094, 46.51278354227543, 47.96648673713207, 56.0655203461647, 58.25592041015625, 61.08364127576351, 60.16973331570625, 64.27361190319061, 61.1641551554203, 61.12968720495701, 61.71878859400749, 64.74668651819229, 64.69611123204231, 62.01907508075237, 61.73934929072857, 65.7547116279602, 62.753480672836304, 62.83678740262985, 57.52189479768276, 57.58073464035988, 65.47962158918381, 66.50799840688705, 64.62532863020897, 48.404002860188484, 0.3787429549265653, 0.9535113943275064, 1.412009575869888, 0.6196981784887612, 0.3098275372758508, 6.426880611106753, 64.0708775818348, 56.084986701607704, 43.98141637444496, 68.00041392445564, 25.420141965150833, 20.149556882679462, 47.64780543744564, 52.11596667766571, 61.2293216586113, 43.5588638484478, 1.012607782613486, 0.027285040778224356, 0.018320490562473424, 0.016461915292893536, 0.08196632203180343, 0.03666055155918002, 0.009516847239865456, 0.036459867405937985, 0.017080996331060305, 0.0256332371282042, 0.05023245103075169, 0.02935357333626598, 0.01372262224322185, 0.09075598514755256, 0.20509006135398522, 0.13099921750836074, 0.2108942499035038, 0.12228574327309616, 0.11362182223820128, 0.12606746808160096, 0.09989200858399272, 0.1266015917644836, 0.12304226635023952, 0.13275068602524698, 0.14900131558533758, 0.15167174104135484, 1.1272483435459435, 64.81851786375046, 85.62783524394035, 70.26241734623909, 66.5016071498394, 36.01848766207695, 26.6985871642828, 70.23440524935722, 59.551806673407555, 59.85396645963192, 88.81601616740227, 9.105003029108047, 0.17969675129279494, 1.0240392317064106, 4.094485016539693, 8.31524295732379, 22.259002290666103, 9.878161791712046, 4.021541755646467, 47.66894370317459, 82.80856892466545, 77.61832103133202, 66.54549479484558, 68.16336438059807, 70.13707727193832, 71.59632056951523, 71.5209174156189, 68.47476527094841, 69.23451170325279, 69.45317476987839, 70.78535288572311, 67.50246584415436, 66.34877935051918, 67.76364102959633, 62.79878184199333, 61.56531102955341, 53.191160783171654, 52.81490497291088, 53.2549973577261, 50.54092839360237, 49.14747096598148, 49.71758097410202, 49.37502175569534, 49.936673417687416, 51.202868074178696, 51.423609629273415, 47.58202716708183, 49.06251512467861, 50.092028081417084, 50.95800161361694, 49.86121706664562, 50.364849641919136, 47.890821397304535, 47.38764479756355, 49.13740150630474, 47.736321687698364, 49.206402003765106, 51.79586425423622, 57.645844146609306, 61.9473235309124, 61.33869118988514, 58.92889469861984, 65.86188867688179, 59.707111939787865, 55.40686748921871, 48.50804887712002, 50.31257204711437, 48.82701516151428, 50.01251354813576, 56.23855546116829, 56.692965477705, 57.13679686188698, 59.41065564751625, 58.1076143682003, 66.84371799230576, 47.275516614317894, 46.649409011006355, 62.97065421938896, 57.25278563797474, 56.14014454185963, 49.68381218612194, 58.84018465876579, 62.49598369002342, 59.76136922836304, 58.523711040616035, 57.807878851890564, 52.45161026716232, 55.975636169314384, 56.12436778843403, 62.78935834765434, 58.73621463775635, 58.60228702425957, 53.54396425187588, 51.74863658845425, 50.06996266543865, 55.10508008301258, 54.41156789660454, 58.28737512230873, 58.581353947520256, 62.12275631725788, 51.97980858385563, 47.27954059839249, 46.06662668287754, 49.13472644984722, 47.12895467877388, 47.414152175188065, 49.61502827703953, 48.47294636070728, 47.45338127017021, 51.26059837639332, 47.54154793918133, 49.74701799452305, 51.092958971858025, 58.19228142499924, 60.7157564163208, 64.18608739972115, 62.33565889298916, 65.73418512940407, 64.4779497385025, 64.29745942354202, 62.78765603899956, 69.20709237456322, 68.2765831053257, 64.55907538533211, 64.16132792830467, 69.19775247573853, 67.81242281198502, 66.84047296643257, 61.07180871069431, 61.50305137038231, 68.0008926987648, 72.84966811537743, 66.62202268838882, 49.7841078042984, 0.4039970529265702, 5.250735422596335, 2.7336934860795736, 0.5181669734884053, 0.3487719740951434, 8.535049762576818, 70.37797674536705, 63.46589304506779, 51.48702062666416, 77.62050211429596, 45.07374756038189, 33.62955205142498, 55.44739231467247, 61.10470354557037, 68.97002309560776, 54.69401054084301, 1.797020472586155, 0.2506151661509648, 0.1267791134887375, 0.0703279250592459, 0.1750065857777372, 0.1578316409722902, 0.0999944398063235, 0.15229521930450574, 0.08144451800035313, 0.10045037080999464, 0.15729874925455078, 0.07733379170531407, 0.20785111788427457, 0.17951287678442895], [0.0660449537099339, 0.009874864845187403, 0.061300232919165865, 0.03878487135807518, 0.029263595351949334, 0.07577716663945466, 0.00774200339037634, 0.0199839088236331, 0.0601008517696755, 0.08246774668805301, 0.19159325980581343, 0.07546225111582316, 4.549064598977566, 64.78851467370987, 65.97243994474411, 58.85992459952831, 42.520250380039215, 28.533075526356697, 57.576957643032074, 67.08863005042076, 36.71947784721851, 72.2463820874691, 50.1559292525053, 0.7647409674245864, 0.03042951491806889, 0.23972217488335446, 0.38212153769563884, 2.0798801444470882, 2.6408875035122037, 0.48600395559333265, 0.01500869273513672, 60.24157226085663, 72.37152457237244, 67.19595909118652, 59.13664475083351, 53.08973282575607, 60.53304702043533, 67.12835311889648, 67.17240035533905, 66.08524829149246, 64.4549609720707, 68.19036573171616, 65.26124730706215, 64.46707472205162, 61.15424148738384, 62.81053841114044, 61.43163040280342, 62.258333042263985, 60.792147517204285, 53.181893080472946, 48.48422795534134, 45.51569804549217, 44.73404198884964, 44.88137148320675, 45.9979035705328, 44.97969500720501, 45.06556659936905, 44.8116984218359, 44.19510170817375, 45.15063263475895, 43.307332545518875, 43.76540556550026, 44.05472584068775, 44.47384715080261, 43.14046069979668, 43.05672839283943, 41.85146726667881, 42.70161844789982, 44.71646413207054, 49.82976995408535, 52.614993900060654, 58.21227975189686, 57.75264121592045, 57.8600462526083, 56.36269859969616, 51.79171867668629, 45.52153453230858, 41.097918301820755, 42.1935211122036, 44.100418388843536, 53.48748788237572, 56.084310337901115, 57.43242859840393, 55.08689425885677, 58.67900490760803, 51.58839538693428, 60.73474779725075, 39.576757326722145, 42.9122069478035, 63.15473534166813, 51.976236775517464, 49.32195760309696, 43.9327447861433, 48.619694486260414, 51.2260278314352, 55.57855747640133, 50.93750551342964, 50.47651045024395, 45.84952913224697, 54.15096268057823, 52.17994004487991, 55.85993617773056, 52.667731270194054, 55.46732984483242, 57.512858882546425, 52.54554882645607, 48.25552962720394, 47.71082505583763, 47.200930416584015, 51.72344014048576, 51.52368865907192, 50.762566700577736, 45.34787245094776, 44.56780470907688, 42.48272359371185, 42.54048049449921, 43.567641377449036, 43.628593906760216, 43.97117592394352, 42.98411808907986, 45.27400441467762, 47.52691492438316, 43.53500112891197, 44.069366455078125, 43.99194560945034, 53.54799963533878, 56.88206233084202, 60.773015543818474, 59.18143294751644, 57.989520505070686, 56.81773938238621, 60.36696173250675, 58.77719163894653, 59.48856666684151, 55.10873928666115, 58.51150989532471, 52.85753108561039, 53.93804490566254, 47.934769839048386, 50.78030414879322, 49.789256528019905, 59.07547563314438, 59.46261405944824, 67.30257377028465, 58.63451689481735, 60.427659675478935, 9.783921148627996, 0.3604510333389044, 0.4338106093928218, 0.1287858362775296, 0.08201151140383445, 0.23515018896432593, 39.63101081550121, 62.9787477850914, 41.821148693561554, 45.200288370251656, 37.52758048474789, 31.968387588858604, 32.192355170845985, 40.59926725924015, 47.14541159570217, 44.245072826743126, 5.479703536257148, 0.22143498819787055, 0.05917364585911855, 0.015573978271277156, 0.04763056291267276, 0.012319779452809598, 0.06792756714276038, 0.0704641017364338, 0.0714965553197544, 0.05407088334322907, 0.04215153894620016, 0.0834311285871081, 0.03581887074687984, 0.05816744203912094, 0.0291679046858917, 0.045674862776650116, 0.06998915690928698, 0.07844184787245467, 0.035205073800170794, 0.01709043644950725, 0.0434602792665828, 0.05406621523434296, 0.12576565146446228, 0.07047708932077512, 0.09308010223321617, 0.07273867304320447, 6.618144772946835, 76.64886385202408, 72.80321940779686, 65.73800012469292, 50.061424523591995, 37.653178945183754, 52.3737258464098, 58.138248324394226, 38.37055005133152, 79.98095065355301, 54.118550419807434, 0.9012400335632265, 0.03904833378328476, 0.6442151754163206, 1.9908594712615013, 5.998600842431188, 5.711528146639466, 0.5776775989215821, 1.0186031484045088, 66.83245539665222, 72.66655594110489, 72.06594496965408, 61.642762273550034, 56.31636008620262, 62.07806311547756, 69.0589003264904, 68.76275181770325, 69.38753709197044, 62.51363754272461, 69.41466003656387, 67.84102007746696, 67.74996176362038, 63.31346422433853, 64.49992775917053, 64.43825706839561, 64.50260281562805, 60.438891872763634, 56.01681835949421, 50.64475402235985, 48.61074596643448, 48.09500724077225, 47.10766062140465, 47.558628022670746, 46.67707912623882, 47.47052974998951, 48.32342058420181, 45.14937870204449, 47.032660245895386, 45.40438301861286, 46.6408708691597, 46.329511776566505, 47.06755377352238, 46.48016229271889, 46.56081676483154, 45.02754583954811, 44.37831647694111, 45.97636252641678, 53.27791012823582, 54.988050162792206, 59.69980113208294, 60.04008427262306, 60.12264624238014, 58.350835517048836, 53.63270089030266, 47.19687603414059, 44.789477214217186, 44.53071869909763, 46.62146531045437, 57.76997968554497, 58.46204034984112, 61.007865741848946, 58.368679359555244, 61.19808353483677, 55.044138953089714, 62.820395082235336, 41.70443415641785, 45.99993646144867, 64.92886394262314, 55.777617394924164, 52.37302668392658, 45.566277131438255, 51.53519444167614, 52.30753719806671, 58.021332398056984, 52.9977435618639, 52.789628729224205, 48.42481814324856, 55.9924540668726, 54.74773585796356, 58.165542259812355, 53.58026370406151, 56.67305074632168, 58.70131731033325, 57.24374212324619, 50.110715478658676, 50.557894483208656, 48.981875851750374, 53.1649573892355, 52.40955412387848, 53.35859879851341, 47.44021877646446, 45.09927839040756, 43.37542489171028, 44.87214557826519, 45.93429498374462, 45.453985556960106, 46.781208738684654, 45.451952666044235, 45.659934505820274, 49.1804113984108, 45.58523431420326, 47.557427287101746, 46.10412307083607, 55.73753334581852, 58.23719881474972, 63.863788694143295, 59.978234991431236, 61.8705790489912, 59.91491138935089, 63.13827842473984, 59.03482161462307, 61.51253946125507, 58.5418626666069, 59.55318219959736, 54.77290950715542, 55.369200110435486, 49.62080396711826, 53.791357576847076, 51.644301787018776, 62.76759311556816, 61.66918225586414, 70.25665685534477, 60.589242205023766, 67.3701037466526, 12.954053990542889, 0.1553991629043594, 1.6918699024245143, 0.8002909098286182, 0.22501041821669787, 0.3774755448102951, 40.68033590912819, 70.58478444814682, 44.94387432932854, 48.345607593655586, 34.41581346094608, 34.78040769696236, 39.7443625330925, 45.822976157069206, 54.49966236948967, 57.92977251112461, 11.763650067150593, 0.3630049416096881, 0.029506654282158706, 0.07374121065367945, 0.05712781559850555, 0.017415252223145217, 0.11115824818261899, 0.04942179199133534, 0.04029559459013399, 0.06531926686875522, 0.047967130594770424, 0.047246189787983894, 0.06439086238970049, 0.08143970146193169, 0.24590123706730083, 0.12230889828060754, 0.17929642199305817, 0.2388822121429257, 0.1900061621563509, 0.15826716291485354, 0.17537659092340618, 0.13312737050000578, 0.36428900551982224, 0.17873365140985698, 0.32095850561745465, 0.3019707463681698, 8.150786831974983, 89.96019557118416, 80.98900616168976, 74.47307780385017, 56.72290027141571, 37.66964726150036, 68.47095027565956, 80.1542441546917, 51.44252501428127, 87.16359123587608, 59.981844797730446, 1.2117967754602432, 0.14048705605091527, 0.9523811331018806, 1.708289177622646, 7.297369251027703, 5.87411287240684, 1.4078477304428816, 2.4885828886181116, 72.58590146899223, 73.40046375989914, 74.6580670773983, 61.37532502412796, 58.950249552726746, 64.80913236737251, 74.01087060570717, 71.49672791361809, 72.76680216193199, 64.49156820774078, 71.66834950447083, 69.75818440318108, 70.33186241984367, 66.36023953557014, 68.16401794552803, 66.27268463373184, 67.94048354029655, 63.867596089839935, 57.05089867115021, 54.67739403247833, 49.51499484479427, 49.33528728783131, 48.42118173837662, 50.21340876817703, 49.492047876119614, 49.22847881913185, 51.36547654867172, 47.862068340182304, 50.335959792137146, 47.597473338246346, 48.54002796113491, 48.59819523990154, 49.47930335998535, 47.948908880352974, 48.60080949962139, 45.86060933768749, 47.13499255478382, 48.159181997179985, 57.45784543454647, 58.250368908047676, 64.21017050743103, 63.22838678956032, 61.40093944966793, 61.805074363946915, 54.6450387686491, 48.74872036278248, 47.05375291407108, 46.87914468348026, 49.13990177214146, 59.54375110566616, 62.2114397585392, 63.18461313843727, 62.08595909178257, 64.2320117354393, 58.66810329258442, 66.09784841537476, 45.25380849838257, 47.374664694070816, 69.16473224759102, 57.977573946118355, 55.85211619734764, 48.212124556303024, 55.167351141572, 56.00457921624184, 60.16794741153717, 54.64142136275768, 55.504404455423355, 51.85883067548275, 59.41885940730572, 56.852834299206734, 60.01842923462391, 57.68742151558399, 58.20458896458149, 58.83669264614582, 57.99316830933094, 52.54629738628864, 53.345565497875214, 52.37959273159504, 57.68771409988403, 54.384802132844925, 55.608936846256256, 48.783180713653564, 48.841765969991684, 46.48610517382622, 46.14525966346264, 47.00084075331688, 47.432683780789375, 49.276246055960655, 49.195846170187, 48.57027433812618, 51.572208255529404, 47.92838618159294, 49.88944575190544, 47.92695365846157, 59.83025573194027, 61.67492374777794, 67.33712151646614, 63.9889919757843, 63.655590265989304, 61.157630905508995, 65.1212552189827, 63.10551278293133, 64.2728291451931, 62.62376323342323, 63.41970272362232, 57.22041517496109, 58.32513749599457, 53.1417216360569, 56.828405410051346, 53.72815936803818, 63.12978968024254, 64.78792190551758, 72.48233422636986, 64.23122137784958, 67.97248542308807, 15.466731861233711, 0.4823345993645489, 4.423669902607799, 0.8884391142055392, 0.4235658247489482, 0.455235819099471, 48.56155380606651, 76.98116362094879, 56.35705590248108, 55.28034187853336, 45.155268386006355, 42.514839470386505, 44.847237914800644, 59.6990791708231, 61.08442023396492, 68.62723588943481, 13.554752357304096, 0.41730447323061526, 0.2258411783259362, 0.14783114165766165, 0.10799540032166988, 0.21440947690280154, 0.29057524690870196, 0.21997417439706624, 0.18412563629681244, 0.1314223901135847, 0.14116232137894258, 0.11938258772715926, 0.16427336406195536, 0.12933633173815906], [0.05238188139628619, 0.09342626217403449, 0.03928289697796572, 0.00725119701201038, 0.08989156864117831, 0.033181233375216834, 0.07032433306449093, 0.01725048616208369, 0.09561361628584564, 0.007849446428735973, 0.29501993965823203, 0.29448137793224305, 13.922517523169518, 72.84798860549927, 60.052015632390976, 51.38160288333893, 36.94574050605297, 26.33175864815712, 29.172841496765614, 41.87064863741398, 44.4649176299572, 74.175546169281, 25.04036944359541, 0.08082693981123157, 0.14125647023320198, 0.3171160211786628, 2.018028013408184, 1.8793226312845945, 2.8403727617114782, 0.7251222152262926, 10.043166037648916, 76.67793989181519, 67.54916533827782, 72.79660016298294, 62.88086883723736, 59.759883508086205, 49.71672222018242, 60.26507779955864, 64.05438646674156, 67.78768613934517, 63.820630609989166, 63.70607055723667, 61.57563127577305, 66.46943047642708, 64.87100824713707, 62.6016104221344, 62.311704978346825, 63.60913775861263, 58.992370292544365, 60.56851051747799, 55.95153406262398, 49.74012516438961, 44.920110404491425, 43.9714153110981, 44.45442259311676, 45.5353619903326, 45.52685044705868, 44.670125618577, 42.706314995884895, 44.15008172392845, 45.13010613620281, 43.15195508301258, 43.84361296892166, 42.90709622204304, 42.748409137129784, 42.426627203822136, 44.49726149439812, 43.21429453790188, 46.70145481824875, 48.28764170408249, 53.77118445932865, 56.941297352313995, 56.91429600119591, 56.8411461263895, 55.03182761371136, 47.81514845788479, 42.747991159558296, 42.756077125668526, 43.23694132268429, 48.59696410596371, 56.76607355475426, 54.99541036784649, 57.6809960603714, 55.44475145637989, 55.97321189939976, 54.13092255592346, 60.328701585531235, 33.23424406349659, 43.46139907836914, 61.36381544172764, 50.02828270196915, 49.00039605796337, 45.580674558877945, 48.43236453831196, 45.37015825510025, 49.08279463648796, 46.21069975197315, 49.592111706733704, 42.9209540784359, 50.38217671215534, 52.89700336754322, 56.00357227027416, 55.38099467754364, 54.59290936589241, 41.253120973706245, 45.351683646440506, 54.8524734377861, 51.29997566342354, 47.3694171756506, 49.573728293180466, 48.16511727869511, 47.97009654343128, 44.7872619330883, 41.77186533808708, 42.907077223062515, 42.32601620256901, 43.782698437571526, 42.93751358985901, 43.765804544091225, 43.8974978774786, 43.99830646812916, 44.340960681438446, 43.486492931842804, 45.40591813623905, 43.4568165242672, 47.7467293292284, 54.055181220173836, 57.20189496874809, 57.061093524098396, 57.3814657330513, 57.081939205527306, 54.5467684417963, 53.33316296339035, 51.64644867181778, 49.95454765856266, 45.69651134312153, 43.155739679932594, 44.69497628509998, 49.598388969898224, 53.82343165576458, 58.48966106772423, 59.78445678949356, 61.866885647177696, 65.00054329633713, 65.64157649874687, 55.6280118227005, 40.89886598289013, 3.6251655500382185, 0.3660750878043473, 2.236909093335271, 0.19286902650492266, 0.10245075565762818, 10.539249368011951, 61.43605716526508, 56.03246212005615, 30.189758129417896, 43.7957127392292, 23.522195108234882, 13.260619640350342, 40.046206936240196, 47.57354982197285, 52.25456424057484, 21.928929202258587, 0.7454887067433447, 0.144711434841156, 0.014137430844129995, 0.05838355915329885, 0.021545393101405352, 0.06561465648701414, 0.034998419068870135, 0.0881402708182577, 0.10313356120605022, 0.04177105838607531, 0.045388115468085743, 0.05805780827358831, 0.037714705540565774, 0.0443782677029958, 0.06481770862592384, 0.017814935854403302, 0.05568540706008207, 0.05057676673459355, 0.011279421996732708, 0.10202816934906878, 0.0772333049098961, 0.04330974945332855, 0.03742327528016176, 0.32673110836185515, 0.20105688949115574, 18.962777964770794, 86.68542489409447, 66.71746596693993, 59.819137528538704, 43.67199517786503, 34.14308689534664, 28.40739157050848, 47.01208055019379, 48.53506922721863, 81.75631418824196, 26.29024587571621, 0.07354293105890974, 0.07792676769895479, 1.368768133688718, 3.485759343020618, 2.5115699926391244, 0.664531379006803, 0.9208561840932816, 13.494969215244055, 80.29552057385445, 70.08767232298851, 74.48654428124428, 65.58590188622475, 62.362477853894234, 51.288310289382935, 63.57628472149372, 68.37919279932976, 68.96659567952156, 65.09410947561264, 63.94766539335251, 62.82121203839779, 66.745994836092, 67.182986587286, 65.3305783867836, 63.621840476989746, 64.94217842817307, 61.84247575700283, 61.642044112086296, 56.96411892771721, 52.64572285115719, 46.390308514237404, 46.81865952908993, 46.589820608496666, 47.34216883778572, 47.70393222570419, 47.76681885123253, 46.33554205298424, 46.20430089533329, 46.033975034952164, 44.18430268764496, 45.95272019505501, 44.5147405564785, 43.668579161167145, 45.038569048047066, 46.81063815951347, 43.88488255441189, 48.372206166386604, 51.91091828048229, 57.65164263546467, 58.40826943516731, 58.93256530165672, 58.2129143178463, 56.711284294724464, 50.43025553226471, 45.09276933968067, 44.56570342183113, 45.24362124502659, 52.457100972533226, 60.11712893843651, 57.133783623576164, 59.73697453737259, 56.39022812247276, 59.05092895030975, 56.02678522467613, 63.947893381118774, 34.71553757786751, 44.33102801442146, 63.83149042725563, 52.33607366681099, 52.632111981511116, 47.5887756049633, 50.074279233813286, 46.107303500175476, 51.35255724191666, 48.36132735013962, 49.85556297004223, 45.32896086573601, 51.256369203329086, 55.55765859782696, 60.00868655741215, 56.256380304694176, 55.407977029681206, 45.49170233309269, 47.673921436071396, 57.04320788383484, 54.38016638159752, 50.56001856923103, 51.677572801709175, 49.40212570130825, 50.82429438829422, 47.980021610856056, 43.122639656066895, 44.72547724843025, 45.25307513773441, 46.40746459364891, 45.98689556121826, 46.361316069960594, 46.03144437074661, 46.28646768629551, 46.13675191998482, 46.12126015126705, 45.86708799004555, 45.26475191116333, 49.11004677414894, 55.89204825460911, 58.43571916222572, 58.73719118535519, 58.008375093340874, 58.529866710305214, 56.11883908510208, 55.468602776527405, 52.58272983133793, 51.53628498315811, 47.67180114984512, 45.87441399693489, 48.08847539126873, 52.996143847703934, 57.189283445477486, 61.41955465078354, 62.27213770151138, 64.01338666677475, 68.00530046224594, 66.76766127347946, 59.11055915057659, 47.60384559631348, 6.458238428458571, 1.296361950226128, 1.522280490025878, 0.26731063902843744, 0.11664318706607446, 9.87225215882063, 66.69560194015503, 63.12110714614391, 34.89517293870449, 48.738514110445976, 33.354636803269386, 17.248408757150173, 48.30766282975674, 51.85643680393696, 60.90411230921745, 31.163144297897816, 0.8245815814007074, 0.11699394090101123, 0.019408783336984925, 0.06303787522483617, 0.01985702197998762, 0.0803115034068469, 0.11460873764008284, 0.023564992152387276, 0.05018591466068756, 0.08019039974897169, 0.07675130225834437, 0.04262112175638322, 0.036218728782841936, 0.1543364964891225, 0.15590303664794192, 0.06594768783543259, 0.11799046711530536, 0.22775347024435177, 0.18428549490636215, 0.2042643923778087, 0.15815964055946097, 0.22379507718142122, 0.17094579117838293, 0.4083207459188998, 0.42405938263982534, 23.95764034241438, 97.08381772041321, 74.7052301466465, 68.94877463579178, 51.94718353450298, 37.88102611899376, 42.355221435427666, 60.47604247927666, 58.200823366642, 88.27412724494934, 30.691859386861324, 0.19508098281221464, 0.36514838284347206, 1.5082585299387574, 7.651395779103041, 7.120490167289972, 6.200867313891649, 2.8475546138361096, 17.121499367058277, 81.08177438378334, 71.26441597938538, 77.42504820227623, 68.5508219897747, 65.63601359724998, 54.36477720737457, 66.81398078799248, 71.83270588517189, 73.84923487901688, 67.84609660506248, 65.46181574463844, 64.88300040364265, 69.63092163205147, 68.77199292182922, 68.82275059819221, 65.48402935266495, 68.476642370224, 62.08087116479874, 64.53847289085388, 60.71998178958893, 54.13365460932255, 48.66396211087704, 48.07739898562431, 47.92335905134678, 50.11959180235863, 49.415052607655525, 49.87875692546368, 47.792068496346474, 49.14453372359276, 48.91645096242428, 45.783982649445534, 48.43848221004009, 46.74440011382103, 46.004211232066154, 48.186931908130646, 50.122540444135666, 48.364728167653084, 50.29714487493038, 52.44589537382126, 60.0189384073019, 62.63727530837059, 60.471041947603226, 61.94427229464054, 60.54854638874531, 52.874592170119286, 46.546951308846474, 48.688698783516884, 46.845231503248215, 53.63280348479748, 61.60922147333622, 60.6131087243557, 62.25149340927601, 60.97263403236866, 59.488049894571304, 59.38142381608486, 65.37476241588593, 37.10222750902176, 47.03185848891735, 64.66552287340164, 54.6336317807436, 55.79396791756153, 49.19174239039421, 53.79398323595524, 48.52174334228039, 54.3694281578064, 51.988244131207466, 53.880949169397354, 47.44204267859459, 54.74559277296066, 57.60240487754345, 60.43772533535957, 56.63016624748707, 56.95243075489998, 49.81212370097637, 51.60383775830269, 60.12448914349079, 56.27687640488148, 52.21286527812481, 55.899754241108894, 53.233866691589355, 54.669771641492844, 50.70112019777298, 45.08691765367985, 48.217288479208946, 48.000308722257614, 47.64646030962467, 46.415314972400665, 49.06146638095379, 48.02037924528122, 48.05442921817303, 48.77204731106758, 47.59805850684643, 48.70237424969673, 46.69192872941494, 53.00517216324806, 59.52198967337608, 61.474245116114616, 62.412068992853165, 62.05743782222271, 60.442296490073204, 60.659994408488274, 57.77021907269955, 57.576847448945045, 54.66542087495327, 50.128654316067696, 47.81288377940655, 50.76599031686783, 54.66144248843193, 58.79676438868046, 64.04923394322395, 64.06037494540215, 67.80744507908821, 71.35393157601357, 69.508758187294, 58.57670679688454, 50.47675363719463, 7.157511105760932, 2.949248794466257, 4.688443494960666, 0.33470296184532344, 0.20076899556443095, 12.653188984841108, 75.26112511754036, 69.1599977016449, 45.732499212026596, 49.63072143495083, 32.08810776472092, 22.38880332559347, 55.94874121248722, 60.55395349860191, 69.52537089586258, 37.58345648646355, 0.9302849625237286, 0.24908803403377533, 0.1267042159452103, 0.17827699310146272, 0.10841432784218341, 0.22658267291262746, 0.14280289818998426, 0.10960414641886018, 0.19242977898102254, 0.2655686700018123, 0.189889244211372, 0.14023104478837922, 0.12679756327997893], [0.030434362997766584, 0.0878501652914565, 0.03586788217944559, 0.06127514090621844, 0.04164974692685064, 0.006530047476189793, 0.038605386653216556, 0.005816037864860846, 0.1350209306110628, 0.06801175637519918, 0.08939788458519615, 0.012392529406497488, 26.511764489114285, 79.65827956795692, 55.74932411313057, 57.813848331570625, 22.673261761665344, 25.35027701407671, 37.048475593328476, 33.82132016122341, 55.28084345161915, 74.63007017970085, 9.519031662493944, 0.05877599942323286, 0.04376643744762987, 0.8485337148886174, 4.3448274582624435, 4.245734475553036, 1.3670345954596996, 0.9523474692832679, 58.426614850759506, 67.877406924963, 69.93671402335167, 68.37531700730324, 67.08795368671417, 64.26494836807251, 53.656837195158005, 48.65680709481239, 61.01856216788292, 62.671853452920914, 65.47829166054726, 63.73562157154083, 61.07674844563007, 60.57437740266323, 61.17012843489647, 59.99073252081871, 60.97723178565502, 62.44486503303051, 63.151995688676834, 59.29551422595978, 58.1281940639019, 52.50749386847019, 47.4926483631134, 42.666166350245476, 45.086606070399284, 43.43286640942097, 44.22219805419445, 44.49483722448349, 45.40849059820175, 45.386729165911674, 42.87840016186237, 44.29450437426567, 42.96310141682625, 43.994419276714325, 41.71809822320938, 41.89386919140816, 40.4587621986866, 42.14709520339966, 46.3194765150547, 47.625333443284035, 52.54958041012287, 55.65920054912567, 58.47346633672714, 54.83221672475338, 48.125284016132355, 40.90074308216572, 44.20629970729351, 39.04963061213493, 48.08642730116844, 56.75435118377209, 56.63895897567272, 52.220749855041504, 57.181170880794525, 55.64930967986584, 56.59693323075771, 54.97985400259495, 59.52786035835743, 33.11120666563511, 48.214860409498215, 59.113116413354874, 50.33414348959923, 46.400336176157, 47.364192456007004, 48.76669719815254, 48.17717783153057, 45.139480233192444, 43.05679298937321, 43.615910187363625, 42.24254608154297, 45.058833360672, 50.967136323451996, 51.72659017145634, 53.00269089639187, 49.162316769361496, 52.245619520545006, 46.23070567846298, 44.62091825902462, 50.7743726670742, 50.330917462706566, 48.956709802150726, 48.45012478530407, 47.13632248342037, 43.94619606435299, 41.322391256690025, 42.719519287347794, 41.23699463903904, 45.40667809545994, 43.350509628653526, 43.27154986560345, 41.6732682287693, 43.54017645120621, 46.39076828956604, 44.2596298456192, 43.176239579916, 44.16222967207432, 43.42090085148811, 44.26330424845219, 46.894651651382446, 49.13521662354469, 49.613386765122414, 50.34425474703312, 48.185096606612206, 47.775888964533806, 45.7774356007576, 43.98284509778023, 46.9025020301342, 49.91874597966671, 54.41004417836666, 57.089561596512794, 60.63236229121685, 61.78450986742973, 62.99431174993515, 63.87945905327797, 63.78459334373474, 65.21604493260384, 60.47932930290699, 58.01891192793846, 30.52836176007986, 2.196133006364107, 1.6805961448699236, 0.2835048356791958, 0.04058972255734261, 1.092262789607048, 43.222034722566605, 62.48495288193226, 39.743492379784584, 25.74740130454302, 31.46500390022993, 29.660000056028366, 34.8537627607584, 41.73534169793129, 50.04021406173706, 37.58759066462517, 1.8203093041665852, 0.2311046826071106, 0.05854059760167729, 0.017992320281337015, 0.0756716109754052, 0.08344698086148128, 0.014686939248349518, 0.017831613768066745, 0.028764812741428614, 0.04978114360710606, 0.01857209346781019, 0.03646096578449942, 0.043140350535395555, 0.06233744366909377, 0.06852527061710134, 0.07484653571736999, 0.0758053979370743, 0.021830889891134575, 0.020938948982802685, 0.054387802665587515, 0.02484944197931327, 0.0900296971667558, 0.09559469894156791, 0.11895298070157878, 0.06000187524477951, 36.76133640110493, 87.94885709881783, 64.33605015277863, 62.51198463141918, 33.08629900217056, 25.97283560782671, 29.29031789302826, 42.471612989902496, 60.058163702487946, 80.01330971717834, 10.072729401290417, 0.18847135623218492, 0.16533269081264734, 1.0884695244021714, 2.8163808491081, 1.4775201980955899, 0.7306662958581001, 3.175187995657325, 62.431998923420906, 68.51563587784767, 71.61000743508339, 70.94602346420288, 70.39718851447105, 66.72786980867386, 58.18299472332001, 50.96004590392113, 62.03277334570885, 65.99723741412163, 68.3611361682415, 66.01845547556877, 63.33817429840565, 60.25615967810154, 63.0539495497942, 62.45637461543083, 62.31893219053745, 65.25888383388519, 64.79272484779358, 61.88073970377445, 60.904028713703156, 54.68524821102619, 48.38742054998875, 45.11777579784393, 48.060413897037506, 47.1289698779583, 48.246717900037766, 46.78207889199257, 46.747808530926704, 46.78269065916538, 45.651514157652855, 45.03658175468445, 45.26410594582558, 45.89815512299538, 45.641695484519005, 45.414349883794785, 43.92356067895889, 45.666728541255, 48.301066383719444, 50.22045738995075, 55.49570292234421, 59.52481672167778, 60.83620235323906, 56.99487067759037, 50.612938329577446, 42.29823589324951, 44.646194502711296, 41.70509532094002, 50.54809860885143, 60.013204514980316, 58.24579015374184, 54.598590061068535, 58.893788382411, 58.42587769031525, 60.541794151067734, 55.93169912695885, 60.69022558629513, 35.08008621633053, 49.49335880577564, 59.574951231479645, 52.77658402919769, 49.04925763607025, 49.80587303638458, 49.653915390372276, 49.508109614253044, 49.26674276590347, 46.61564402282238, 46.8737717717886, 45.2954238653183, 48.41083109378815, 52.17336639761925, 54.52502220869064, 54.159816205501556, 50.54397962987423, 55.808669328689575, 53.07820804417133, 47.968246042728424, 53.66912193596363, 52.559668868780136, 52.966877818107605, 50.53153529763222, 48.93472798168659, 46.505423337221146, 42.998367324471474, 44.70772460103035, 44.917169362306595, 47.36400626599789, 45.86791254580021, 46.388173028826714, 43.75048376619816, 45.0485473126173, 47.79917411506176, 47.60080195963383, 46.48479804396629, 47.15288579463959, 45.71074157953262, 47.22592927515507, 49.15024481713772, 50.80520041286945, 52.19418928027153, 52.732422798871994, 49.32673014700413, 49.323682710528374, 48.15298452973366, 45.85533142089844, 49.376686066389084, 54.17719267308712, 56.34735122323036, 60.14905862510204, 63.62517669796944, 64.8152956366539, 65.87459519505501, 69.88458082079887, 65.01308262348175, 66.534703373909, 62.985397428274155, 62.923665940761566, 36.74452230334282, 2.7157525112852454, 0.33364611386787146, 0.7342870265711099, 0.0676269899122417, 1.084666047245264, 46.64731912314892, 67.69438594579697, 46.57125860452652, 25.649801641702652, 33.274191319942474, 34.57732379436493, 39.81049418449402, 49.01401832699776, 58.82743254303932, 50.79953491687775, 3.912277431227267, 0.2908293582731858, 0.07860240410082042, 0.004024805075459881, 0.049485408890177496, 0.09774562102393247, 0.012184917304693954, 0.05239329191681463, 0.014324017902254127, 0.08657931903144345, 0.01621403240278596, 0.03208479181921575, 0.05396779532020446, 0.12302266623009928, 0.17549897107528523, 0.13475141226081178, 0.22815884614828974, 0.11345112085109577, 0.13767413824098185, 0.13052544527454302, 0.12692150194197893, 0.20493110816460103, 0.1645999980974011, 0.2150246876408346, 0.12982708431081846, 46.087631955742836, 100.1876051723957, 70.60975670814514, 75.33501595258713, 34.05177399516106, 35.82307554781437, 55.109731033444405, 50.16137816011906, 65.62155917286873, 86.55987963080406, 12.250627186149359, 0.19533818151103333, 0.47790893528144807, 2.815372715704143, 9.374434221535921, 16.55692756175995, 8.75338414683938, 3.8036203617230058, 69.66300711035728, 69.1455128788948, 75.58071836829185, 70.25981828570366, 73.20712253451347, 68.74340325593948, 59.88623432815075, 53.69855895638466, 66.2874886393547, 66.9071213901043, 70.98028242588043, 68.8055831193924, 65.83535090088844, 61.86133034527302, 65.2475680410862, 63.17721113562584, 63.49007114768028, 65.57682797312737, 67.52972558140755, 63.20288635790348, 64.01782482862473, 56.14270940423012, 52.25090503692627, 47.46872864663601, 49.85069543123245, 48.03712114691734, 50.36457985639572, 48.21319989860058, 49.42261040210724, 49.87691022455692, 47.17470422387123, 48.38261380791664, 47.53693878650665, 48.86661283671856, 48.52265149354935, 47.11458005011082, 45.630915462970734, 46.80827088654041, 50.9102837741375, 50.84129087626934, 58.39191131293774, 62.36784316599369, 64.17978733778, 59.64816190302372, 52.28202536702156, 44.540119394659996, 48.94149161875248, 44.80367325246334, 53.85651268064976, 63.63289788365364, 60.078348219394684, 55.082779079675674, 61.36264130473137, 59.82977315783501, 60.65175265073776, 58.98450091481209, 61.91617280244827, 36.86637416481972, 53.25498975813389, 62.20811873674393, 56.73535220324993, 49.74235564470291, 54.05072785913944, 52.08421178162098, 53.26070465147495, 51.6245998442173, 48.511100113391876, 48.78797985613346, 47.154177725315094, 51.5794924646616, 55.46163395047188, 56.92821465432644, 57.84386672079563, 54.09369595348835, 56.73281393945217, 50.65347835421562, 52.32805609703064, 55.9831103682518, 55.05883276462555, 54.24275815486908, 53.05539786815643, 51.83489575982094, 50.74789568781853, 45.44722571969032, 47.697544768452644, 44.96135339140892, 49.02914151549339, 47.848005294799805, 49.91271950304508, 44.62117284536362, 46.42290696501732, 49.341967329382896, 50.96147082746029, 48.34325172007084, 49.52613204717636, 46.14676058292389, 50.17261415719986, 51.233916208148, 54.126818776130676, 54.61557514965534, 56.64692334830761, 52.58797734975815, 52.96351499855518, 52.93936349451542, 48.511768877506256, 51.61375902593136, 57.11032748222351, 59.00660052895546, 61.185510009527206, 67.0360104739666, 68.84433344006538, 71.97630777955055, 70.43696478009224, 69.27409797906876, 66.4200559258461, 65.0329327583313, 64.00703340768814, 40.952158123254776, 4.974139714613557, 6.811665063723922, 1.92495426395908, 0.19381222198717296, 1.8128624162636697, 53.93062770366669, 75.19397512078285, 55.47315113246441, 38.18052984774113, 40.71888864040375, 43.020398542284966, 47.77104042470455, 58.49307328462601, 67.59531006217003, 63.333010375499725, 5.259889606386423, 0.3496593452291563, 0.17541369830723852, 0.25368914182763547, 0.17118871095590293, 0.16680849599651992, 0.15975004818756133, 0.1806817890610546, 0.13434015854727477, 0.2121214207727462, 0.10292393417330459, 0.20314634690294042, 0.13772497535683215], [0.09919545103912242, 0.09010161127662286, 0.14977868559071794, 0.018965431736432947, 0.06147144638816826, 0.019515550557116512, 0.021688853958039545, 0.024034669586399104, 0.03142898560327012, 0.017968072461371776, 0.05053868342656642, 1.0711051686666906, 53.3078221231699, 68.66260439157486, 52.12661750614643, 45.77597267925739, 23.31953678280115, 32.2811184078455, 39.160869643092155, 39.07731972634792, 67.8926745057106, 54.23235811293125, 1.2127064703963697, 0.02697403080674121, 0.14749413239769638, 2.3293989803642035, 3.572642868384719, 1.3352162903174758, 1.7060296051204205, 54.49805125594139, 79.8879924416542, 65.22550642490387, 69.12142217159271, 64.11226496100426, 72.93194890022278, 65.20428076386452, 63.499042466282845, 50.344843715429306, 52.229386791586876, 59.7875802218914, 65.75638353824615, 60.935190841555595, 63.389015570282936, 63.94846335053444, 62.48091369867325, 58.34895841777325, 61.16111911833286, 56.583770737051964, 58.02265092730522, 59.09635551273823, 60.05880206823349, 55.6268984824419, 51.15405589342117, 43.85639548301697, 46.28481477499008, 45.85977718234062, 48.08838039636612, 45.35573422908783, 44.01440240442753, 43.85847397148609, 44.99805562198162, 44.051488414406776, 45.49579091370106, 43.661864921450615, 44.48252208530903, 42.38519802689552, 45.57999439537525, 43.371218517422676, 45.566277131438255, 47.16915272176266, 51.37482784688473, 50.54064720869064, 52.18849718570709, 46.901878863573074, 44.427679628133774, 42.0590653270483, 42.882861122488976, 39.42931763827801, 52.7651010453701, 57.020591497421265, 58.63998860120773, 51.40193559229374, 54.830248430371284, 51.62694051861763, 56.981575191020966, 52.53145918250084, 60.259423702955246, 33.01718071103096, 43.466882184147835, 58.84581595659256, 50.01961536705494, 46.19352847337723, 45.17241306602955, 50.248800069093704, 48.45695301890373, 49.36573885381222, 46.609758138656616, 47.1781088411808, 43.8291547447443, 44.55286771059036, 44.88001115620136, 53.16602133214474, 53.24334718286991, 54.43274416029453, 55.511255487799644, 61.14474959671497, 55.739638432860374, 47.39912398159504, 52.45501108467579, 52.169634997844696, 52.49282285571098, 48.34189899265766, 43.91318343579769, 43.21726217865944, 40.825286731123924, 41.879315972328186, 43.3465426415205, 43.31783518195152, 43.27174365520477, 43.785578683018684, 45.05512855947018, 44.534776881337166, 44.33837682008743, 43.36819387972355, 44.67845477163792, 44.978851452469826, 46.196294724941254, 46.772985979914665, 45.58426916599274, 45.80360859632492, 44.07544992864132, 44.16550509631634, 43.629209473729134, 47.96597756445408, 53.75478453934193, 57.5356500595808, 58.30488458275795, 61.207666620612144, 60.12694001197815, 60.820034220814705, 63.76688629388809, 63.03277708590031, 63.35683509707451, 65.2347931265831, 61.309960931539536, 62.30852074921131, 64.37353894114494, 51.28384932875633, 4.54426403157413, 0.5236223526299, 0.8772088761907071, 0.15342582191806287, 0.07374685097602196, 19.09554284065962, 67.80874460935593, 48.3478494733572, 46.965225264430046, 36.90444812178612, 31.042783856391907, 29.98655453324318, 36.02619364857674, 47.61288531124592, 45.886508747935295, 7.205982254818082, 0.48230577434878796, 0.1224451714369934, 0.08124862069962546, 0.043445733172120526, 0.12003911382635124, 0.05155971164640505, 0.04673668314353563, 0.03596827620640397, 0.03229518326406833, 0.04490645049372688, 0.027037762738473248, 0.074825020856224, 0.03303140489151701, 0.03881500626448542, 0.10911950914305635, 0.024964352414826863, 0.05491544368851464, 0.01969616332644364, 0.02099790704960469, 0.04983229242498055, 0.06089592941862065, 0.04126013795030303, 0.048762493970571086, 1.746201643254608, 67.47870191931725, 76.6981852054596, 59.62148733437061, 51.404196470975876, 27.483488246798515, 33.400865122675896, 41.064183712005615, 45.03518722951412, 76.56689465045929, 60.43709076941013, 1.4612353406846523, 0.17477800429333, 0.6885031645651907, 3.4756853710860014, 1.6914338758215308, 0.27724600746296346, 3.18054998293519, 59.38276894390583, 80.59911668300629, 69.17888268828392, 72.10046231746674, 67.26201474666595, 73.4872967004776, 67.54231810569763, 65.32395914196968, 52.900415584445, 53.000114634633064, 61.46717369556427, 68.33705306053162, 63.735032603144646, 66.86448007822037, 63.860391676425934, 62.24825218319893, 60.34440614283085, 62.682204097509384, 58.16321678459644, 58.207362815737724, 61.69455349445343, 61.049344316124916, 57.89642550051212, 53.641246631741524, 46.569161117076874, 48.41104008257389, 48.56842763721943, 50.75861871242523, 46.94779559969902, 47.5570473074913, 47.07410842180252, 48.212485536932945, 46.03827640414238, 47.45084300637245, 46.6170309484005, 45.267860144376755, 44.26920533180237, 47.12600223720074, 44.54949729144573, 47.69634783267975, 47.97944404184818, 54.39408503472805, 51.664383709430695, 53.61837185919285, 48.70459333062172, 45.62989331781864, 44.912385419011116, 45.72820544242859, 42.011374086141586, 55.10788053274155, 59.32086266577244, 60.81177346408367, 54.38621565699577, 57.30349771678448, 55.46670287847519, 59.47127379477024, 56.00590154528618, 62.20326639711857, 35.23907348513603, 46.10633835196495, 61.886469796299934, 53.1005584448576, 50.07533937692642, 47.37159065902233, 52.631219029426575, 50.65915904939175, 51.33412443101406, 49.39631961286068, 48.65284010767937, 46.40374079346657, 45.89955344796181, 47.09239304065704, 54.95342642068863, 55.02401143312454, 56.66600212454796, 54.53698016703129, 62.05509714782238, 59.966759607195854, 49.66637872159481, 53.47360722720623, 54.865442141890526, 52.16699793934822, 50.44091396033764, 45.821741223335266, 45.08011981844902, 42.69871160387993, 43.08467589318752, 46.44545495510101, 45.47531001269817, 45.16685016453266, 45.825951397418976, 47.37468749284744, 47.791718915104866, 44.90904159843922, 45.6698177754879, 44.972737580537796, 46.701082438230515, 49.31640610098839, 49.08348999917507, 46.88656948506832, 47.165026143193245, 46.30852170288563, 46.45086966454983, 46.01406030356884, 50.40779493749142, 56.391550451517105, 60.37814073264599, 59.26718294620514, 63.91076177358627, 62.7807480096817, 63.13761346042156, 64.63891670107841, 64.13165912032127, 61.975267231464386, 67.66768097877502, 64.78593081235886, 64.69465970993042, 65.52122175693512, 56.39174044132233, 6.998729025945067, 0.5206092330627143, 1.061398945748806, 0.2563109714537859, 0.06258379959035665, 19.906805008649826, 72.19257697463036, 58.244699612259865, 45.27997009456158, 33.21036994457245, 44.92186591029167, 34.345103055238724, 45.56399345397949, 52.4124875664711, 57.503613978624344, 11.481260620057583, 0.4804024921031669, 0.07925463316496462, 0.09567793822498061, 0.03721002285601571, 0.058688960343715735, 0.055604954541195184, 0.13977204129332677, 0.085773064638488, 0.011567131314222934, 0.04031417796795722, 0.030924896636861376, 0.0565711862873286, 0.14717989222845063, 0.21422772493679076, 0.32902974751777947, 0.07836698743631132, 0.19278605439467356, 0.16170520655578002, 0.0660538520605769, 0.1395658281398937, 0.17578750324901193, 0.15859246108448133, 0.13732525461819023, 2.285529621876776, 77.04826802015305, 86.42220541834831, 69.21649307012558, 62.301912903785706, 33.123749792575836, 43.42941239476204, 58.357762545347214, 53.73901538550854, 83.37767958641052, 66.05208367109299, 2.2859763354063034, 0.33390488591976464, 1.1327731283381581, 7.345547340810299, 11.542935110628605, 5.4046656377613544, 3.5796779533848166, 64.8124685883522, 82.49971389770508, 69.38653394579887, 75.08907794952393, 67.62575402855873, 77.33756929636002, 69.48915123939514, 69.33104172348976, 55.38591541349888, 57.5449063628912, 63.992312997579575, 71.59847885370255, 65.68911954760551, 69.25588935613632, 66.80387333035469, 63.709881752729416, 60.50306662917137, 64.74850282073021, 59.1298621147871, 60.501269325613976, 64.12801131606102, 64.06969964504242, 60.94961106777191, 56.67588159441948, 48.564521446824074, 50.41493095457554, 50.43120548129082, 52.11394518613815, 50.69369539618492, 48.67496632039547, 47.60650925338268, 49.7455170750618, 48.2923648506403, 49.85859900712967, 49.74350318312645, 47.98819877207279, 44.88461650907993, 51.33865378797054, 46.86623677611351, 50.484687611460686, 50.778377652168274, 56.510624662041664, 55.86371697485447, 57.2615859657526, 50.723162814974785, 48.150974437594414, 47.40639679133892, 48.19693297147751, 44.14229974150658, 56.8359100073576, 61.13493472337723, 64.03766736388206, 56.77933104336262, 60.53298242390156, 58.237214013934135, 60.68495526909828, 58.36337864398956, 63.037105053663254, 39.26545523107052, 50.11362612247467, 65.47560900449753, 54.44185607135296, 50.34220665693283, 51.19540527462959, 55.25468945503235, 53.554124906659126, 53.643203526735306, 51.1917270720005, 52.097328677773476, 47.77534939348698, 48.82667697966099, 49.89344693720341, 58.08453820645809, 57.71467745304108, 59.66578535735607, 59.60807405412197, 62.992985621094704, 61.28968521952629, 54.12387013435364, 57.112371772527695, 54.86155495047569, 57.83378206193447, 52.42902047932148, 49.27025377750397, 47.95696444809437, 45.158578008413315, 44.03878949582577, 48.45917209982872, 48.42218108475208, 47.32988029718399, 47.46139504015446, 50.48129819333553, 50.35360984504223, 48.63633759319782, 47.26854398846626, 47.531546875834465, 48.500388488173485, 50.39745569229126, 50.14929100871086, 49.9484945833683, 50.66789098083973, 49.11007337272167, 48.75025928020477, 47.73248769342899, 52.673058584332466, 59.42500367760658, 64.10671725869179, 61.18904761970043, 66.12680286169052, 66.03641331195831, 67.1898490190506, 68.39468836784363, 65.6653480231762, 64.34703156352043, 67.79351502656937, 67.61362507939339, 68.8110776245594, 67.08511143922806, 56.69494517147541, 8.365071583539248, 2.7872646739706397, 3.8830076018348336, 0.3603570774430409, 0.1859868981409818, 24.174975380301476, 80.30597761273384, 62.185521349310875, 65.47210559248924, 47.19118773937225, 43.24565805494785, 43.12746919691563, 55.24810440838337, 62.72851221263409, 69.99938786029816, 15.063807182013988, 0.7947815617080778, 0.20435527578229085, 0.24314503418281674, 0.12760185840306804, 0.144260966044385, 0.2264624449890107, 0.1839823424234055, 0.08447336367680691, 0.08489525236655027, 0.13436795939924195, 0.24363323376746848, 0.1734955731080845], [0.011190254808752798, 0.01939008307090262, 0.01836556304624537, 0.06079775812395383, 0.07758011051919311, 0.007710586423854693, 0.10087033733725548, 0.015373526039184071, 0.027406337394495495, 0.08123241961584426, 0.23034622252453119, 7.570276306942105, 73.56374859809875, 60.424650236964226, 57.352013513445854, 41.329063698649406, 16.071946285665035, 32.53708407282829, 34.88428272306919, 42.07622900605202, 77.30392590165138, 31.58513255417347, 0.05405177304055542, 0.03825426916591823, 0.3847800591029227, 0.87235540850088, 0.7232018338982016, 2.8724216669797897, 57.01356567442417, 81.65397807955742, 67.63972207903862, 71.33240193128586, 65.45410215854645, 67.63776898384094, 68.1505286693573, 67.52704292535782, 62.921899035573006, 57.79301404953003, 47.83579654991627, 48.31959418952465, 57.25406236946583, 64.04185473918915, 62.49047018587589, 64.45458099246025, 64.36436623334885, 63.15095454454422, 62.65142574906349, 60.91138891875744, 59.09128278493881, 59.86737594008446, 58.946354761719704, 58.770462200045586, 52.37813360989094, 44.424730986356735, 45.61976686120033, 45.5375012755394, 49.763744696974754, 45.139404237270355, 43.62217225134373, 43.99728812277317, 45.12369967997074, 46.10207498073578, 47.45955593883991, 44.79557208716869, 43.22332665324211, 44.13815416395664, 43.84273141622543, 43.12952108681202, 44.8072412610054, 42.89440110325813, 45.06074085831642, 45.51878347992897, 43.29853981733322, 41.842423751950264, 43.87303099036217, 42.98726052045822, 45.13616681098938, 43.63524354994297, 52.77103632688522, 56.944572776556015, 57.952115312218666, 54.5828665047884, 57.50572666525841, 54.431889206171036, 57.72205285727978, 52.24462017416954, 54.100843369960785, 34.117039293050766, 47.38669104874134, 57.354954555630684, 49.91609372198582, 48.33820179104805, 40.923336669802666, 46.64007291197777, 48.64028178155422, 48.528438583016396, 47.056754752993584, 47.905253022909164, 45.45242004096508, 45.57009972631931, 44.683873280882835, 48.54494869709015, 48.965430334210396, 50.56971564888954, 49.97636988759041, 55.14178991317749, 58.90435941517353, 57.54414260387421, 52.59776562452316, 51.65964916348457, 49.53538075089455, 49.75731164216995, 44.9737673252821, 42.707352340221405, 40.23344948887825, 41.57220125198364, 41.49194955825806, 41.66952162981033, 45.475199818611145, 45.094760432839394, 46.01247198879719, 45.07655940949917, 44.604776725173, 44.64291147887707, 44.8443690687418, 43.796058520674706, 45.727388486266136, 44.8046687990427, 44.331286400556564, 43.85989509522915, 46.00863039493561, 50.84956303238869, 54.57001179456711, 58.021959364414215, 59.77223664522171, 61.82772494852543, 61.331878155469894, 61.89710542559624, 63.87879028916359, 61.826117634773254, 62.73011952638626, 61.371555626392365, 63.42686153948307, 63.04920360445976, 63.93671438097954, 63.133080303668976, 60.08644938468933, 71.29422158002853, 33.20009909570217, 0.397334496374242, 0.7158055307809263, 0.14064094779314473, 0.03692936857987661, 3.1865375116467476, 56.42568401992321, 56.33111849427223, 44.1339173913002, 32.31023624539375, 18.708111830055714, 28.311235830187798, 23.116659969091415, 45.26874169707298, 48.46324548125267, 19.65481013059616, 0.667729857377708, 0.16020871029468253, 0.053252483703545295, 0.013436406497930875, 0.05997645297611598, 0.04500557915889658, 0.09298119621234946, 0.05213719901803415, 0.07918983625131659, 0.008270019661722472, 0.02226922457339242, 0.07304057871806435, 0.011563451189431362, 0.025278215944126714, 0.10323755093850195, 0.09060373355168849, 0.02542291062127333, 0.01435189667972736, 0.06638571823714301, 0.04504882781475317, 0.03591738342947792, 0.041316819479106925, 0.15502458612900227, 10.29398962855339, 84.65889483690262, 66.62025958299637, 65.70148408412933, 49.03141379356384, 28.090893253684044, 26.39272827655077, 38.858774453401566, 48.848362416028976, 82.28820204734802, 34.221013113856316, 0.064914788963506, 0.05373129140934907, 1.0728051024489105, 2.9841869696974754, 0.9353416599333286, 5.180049240589142, 61.592145189642906, 82.69383788108826, 71.06920525431633, 73.5593256354332, 69.74018096923828, 69.96669441461563, 68.37290033698082, 70.95380544662476, 66.51015669107437, 59.549534395337105, 49.50461000204086, 50.10841280221939, 59.28351067006588, 67.11728811264038, 65.0961385667324, 67.38154873251915, 67.2007392346859, 63.393233343958855, 62.21055820584297, 62.10477188229561, 60.96777029335499, 60.94721719622612, 60.4886844009161, 60.73020704090595, 54.660838320851326, 47.140570655465126, 46.294173672795296, 46.83431088924408, 51.93336747586727, 47.31828711926937, 46.69169694185257, 45.871940329670906, 47.83217914402485, 47.31177046895027, 49.443444684147835, 45.44880263507366, 45.404333621263504, 45.96380800008774, 44.800606817007065, 44.70770940184593, 45.5225832760334, 44.11420404911041, 46.85011804103851, 46.205900609493256, 45.73038652539253, 42.92894884943962, 47.33978636562824, 44.776732698082924, 47.19699762761593, 42.935735285282135, 54.927910789847374, 58.336377292871475, 59.35880362987518, 57.96136021614075, 59.13934640586376, 58.19791652262211, 59.99449051916599, 54.329165518283844, 54.112067967653275, 34.7440018504858, 50.31778156757355, 59.80830430984497, 51.06201343238354, 50.04425324499607, 43.62023815512657, 48.73557686805725, 50.752428844571114, 51.97674594819546, 51.91312976181507, 50.70556215941906, 48.167541548609734, 48.58249828219414, 48.23905751109123, 51.75627417862415, 50.879847407341, 52.412544563412666, 53.6215902864933, 55.726605132222176, 59.82524000108242, 60.98622590303421, 56.43959507346153, 54.847115725278854, 51.404428258538246, 51.950375363230705, 46.853883638978004, 44.753588140010834, 43.66422839462757, 43.9720194786787, 43.557632714509964, 44.89988788962364, 47.558909207582474, 46.226472705602646, 47.90011189877987, 47.29632809758186, 46.036403104662895, 46.724124401807785, 47.597283348441124, 45.84705166518688, 47.59373813867569, 46.280213221907616, 46.35376587510109, 46.76303431391716, 50.11428348720074, 53.98673549294472, 56.63322128355503, 61.24470703303814, 62.18795321881771, 62.35756851732731, 64.57387179136276, 63.56248386204243, 64.87164661288261, 62.48884007334709, 64.51163113117218, 62.89182364940643, 66.61203682422638, 65.02374485135078, 65.48640042543411, 65.67517429590225, 62.78525076806545, 74.34129327535629, 39.52693060040474, 1.0538987419568002, 0.22748154733562842, 0.4481593519449234, 0.03607572434702888, 3.172753513790667, 59.106736555695534, 63.30089829862118, 49.92154262959957, 26.797317266464233, 26.4695867523551, 37.87676274776459, 27.168606743216515, 53.957724049687386, 59.83741074800491, 30.288279242813587, 1.2665058835409582, 0.10436706259497441, 0.07753398604108952, 0.027446251951914746, 0.09733118349686265, 0.031453788178623654, 0.04008347023045644, 0.02046187419182388, 0.05918676331930328, 0.047080227013793774, 0.027060125503339805, 0.06808460559113882, 0.12530416919616982, 0.11957419541431591, 0.15713663451606408, 0.14851253712549806, 0.1422327506588772, 0.13641214580275118, 0.15474092244403437, 0.14751369541045278, 0.115050144813722, 0.3237500792602077, 0.37517138407565653, 13.749616350978613, 97.3865094780922, 75.5943900346756, 77.6716397702694, 56.07471965253353, 26.99271608144045, 44.952146485447884, 53.1428349763155, 54.94389273226261, 88.36302727460861, 39.96373616158962, 0.17799319582991302, 0.24154907529009506, 1.8313421308994293, 4.467510525137186, 6.720424834638834, 5.183295216411352, 66.87176048755646, 83.713209182024, 74.23040762543678, 77.37036913633347, 72.10662558674812, 73.34337562322617, 70.43258741497993, 71.55220493674278, 69.55728158354759, 61.969229355454445, 53.23385909199715, 52.97334507107735, 62.673475965857506, 69.15526315569878, 68.13934966921806, 69.50821861624718, 68.16657900810242, 65.81110060214996, 65.78783065080643, 64.10716563463211, 62.708392292261124, 62.433070465922356, 64.08704951405525, 63.50308544933796, 58.2838299125433, 48.22620280086994, 48.719948306679726, 50.36693572998047, 53.72803397476673, 48.5154090821743, 49.00604635477066, 48.68144877254963, 50.279764607548714, 50.176109969615936, 52.384992241859436, 48.36545392870903, 47.33009308576584, 48.42835575342178, 47.62313716113567, 47.22483493387699, 48.65771524608135, 47.06788815557957, 49.44355867803097, 49.93438594043255, 47.49645195901394, 45.25696612894535, 48.99292565882206, 47.45295189321041, 48.986956179142, 45.83461493253708, 57.186908572912216, 63.12389239668846, 61.61266028881073, 59.346826672554016, 62.227110117673874, 60.886534452438354, 61.34226679801941, 55.99614366889, 53.25841337442398, 37.023571729660034, 52.83012695610523, 61.412931606173515, 55.19611559808254, 54.76536691188812, 45.19768550992012, 52.552396059036255, 55.42677462100983, 56.194937601685524, 54.250479340553284, 53.68642620742321, 52.56811581552029, 50.4692642390728, 49.536554887890816, 55.14470815658569, 52.428116127848625, 55.32001554965973, 56.897348910570145, 60.53161069750786, 61.54045656323433, 60.241587460041046, 58.87508198618889, 58.040395975112915, 52.383962497115135, 54.02009390294552, 50.432831794023514, 47.854841127991676, 46.155709102749825, 46.744369715452194, 44.672614485025406, 45.67366696894169, 50.703723058104515, 48.66430029273033, 50.59449791908264, 49.619561433792114, 48.93766142427921, 48.155116215348244, 49.49022397398949, 46.78816616535187, 50.3378064930439, 48.327512964606285, 49.030935019254684, 48.23097534477711, 52.78004564344883, 56.269311010837555, 59.93634983897209, 63.24388235807419, 65.60576722025871, 65.37770345807076, 68.92979845404625, 63.42444486916065, 69.46446016430855, 64.22810554504395, 66.39418691396713, 62.958616465330124, 68.10930088162422, 65.53349509835243, 67.99238875508308, 68.41740354895592, 66.16961896419525, 75.35019233822823, 40.96153222024441, 1.0687975049950182, 4.373159687966108, 1.3931524939835072, 0.11733635299606249, 4.447591518983245, 66.74866989254951, 67.90816247463226, 63.83370950818062, 44.68245975673199, 26.54585435986519, 42.101368457078934, 38.76631021499634, 65.51581084728241, 69.4539575278759, 36.65342219173908, 1.6863503423519433, 0.3580510464962572, 0.1888071038410999, 0.13478572916937992, 0.2747301565250382, 0.180126276682131, 0.18074562860419974, 0.12381851571262814, 0.2220593867241405, 0.1026321662357077, 0.11000808997778222, 0.14352309313835576], [0.018819616416294593, 0.031151619041338563, 0.05362252595659811, 0.025779720381251536, 0.07154918843298219, 0.03823556333372835, 0.06740332144545391, 0.00573934989006375, 0.04645690831239335, 0.17935282521648332, 0.028280652295507025, 15.310695134103298, 75.94037666916847, 58.722611367702484, 46.43285483121872, 24.77865658700466, 19.53588791191578, 42.446408942341805, 42.58736997842789, 56.47570453584194, 76.48692414164543, 11.83743640780449, 0.16306097677443177, 0.386656861519441, 1.0900207911618054, 0.8798081742133945, 0.871830799151212, 36.91595010459423, 75.6245756149292, 65.82131445407867, 70.04517540335655, 64.50171366333961, 68.60039412975311, 65.00295996665955, 67.15644881129265, 65.36112114787102, 65.27876436710358, 60.93256518244743, 51.798106133937836, 50.13262130320072, 49.00168038904667, 50.71984179317951, 59.07524764537811, 60.641242414712906, 61.150384694337845, 60.816527009010315, 61.932158544659615, 60.95393143594265, 62.564262226223946, 61.16620324552059, 60.71794509887695, 55.5128476023674, 50.368706434965134, 45.42638383805752, 45.37966914474964, 44.28463250398636, 43.81261043250561, 49.94071640074253, 46.26566380262375, 44.90505561232567, 44.797236397862434, 45.947427079081535, 44.92418758571148, 43.99558201432228, 45.173043832182884, 44.20876197516918, 44.630774930119514, 42.98976078629494, 42.633579298853874, 41.823747754096985, 44.34525825083256, 43.249879628419876, 43.57606552541256, 41.26235067844391, 40.546001717448235, 43.36396090686321, 43.376336842775345, 43.85227270424366, 50.89865259826183, 51.80964611470699, 57.204212844371796, 54.58116799592972, 56.497283577919006, 55.34472942352295, 61.18467025458813, 54.202552512288094, 56.74639821052551, 30.655466839671135, 46.22584953904152, 57.821436524391174, 49.99007575213909, 47.373532354831696, 42.80374176800251, 43.43089431524277, 44.30504120886326, 46.56822256743908, 46.03044502437115, 47.71630056202412, 45.23769736289978, 45.93690164387226, 44.69769313931465, 47.140475660562515, 44.95890632271767, 45.499586910009384, 46.89774088561535, 48.47987338900566, 49.98996175825596, 49.61626701056957, 52.64365956187248, 49.717508777976036, 49.103036150336266, 48.03426370024681, 43.697503209114075, 43.13727647066116, 41.90746106207371, 44.08917099237442, 43.65561805665493, 40.947887152433395, 41.87412165105343, 42.52740919589996, 45.91400787234306, 47.56175145506859, 44.23154175281525, 44.54127833247185, 42.761370241642, 45.666880533099174, 44.20962832868099, 46.45525082945824, 45.23895889520645, 49.06609073281288, 54.80404123663902, 57.294587194919586, 57.328834757208824, 58.92351798713207, 60.60208931565285, 59.35104824602604, 59.370947778224945, 65.99311843514442, 63.1451902538538, 59.34167794883251, 61.75605699419975, 64.0681341290474, 61.67944550514221, 61.47155486047268, 60.14241278171539, 62.88472943007946, 61.72477327287197, 62.97796882688999, 62.335708290338516, 10.955695621669292, 0.10820303097716533, 0.9374884853605181, 0.01696598013950279, 0.021854048609384336, 26.092301197350025, 72.68339663743973, 44.66794453561306, 52.81501516699791, 27.647660337388515, 29.0994693338871, 36.66200213134289, 35.34128040075302, 51.81766748428345, 33.80585879087448, 2.813939955085516, 0.3371851786505431, 0.020573224173858762, 0.05730881428462453, 0.03874286951031536, 0.05135867126227822, 0.05863487262104172, 0.03882041281030979, 0.042008645832538605, 0.040737558374530636, 0.08005388168385252, 0.06624653586186469, 0.04381445069157053, 0.023791658895788714, 0.0560443801805377, 0.02919132686656667, 0.053881928834016435, 0.05410343022958841, 0.0328837880078936, 0.03290722132078372, 0.022991952100710478, 0.21195586246903986, 0.05928990700340364, 21.645584106445312, 88.20719003677368, 64.42725285887718, 53.9980398863554, 32.615249678492546, 20.742925442755222, 27.624213695526123, 49.6536798030138, 63.59931908547878, 83.64982858300209, 11.944482363760471, 0.1556557381991297, 0.2120820275740698, 1.6699771396815777, 1.5007612947374582, 1.3191026612184942, 41.71565495431423, 79.06960755586624, 68.49900037050247, 71.71419784426689, 67.33247056603432, 72.29882687330246, 69.13559541106224, 68.66708815097809, 67.99845322966576, 66.86719313263893, 62.72163078188896, 54.603605791926384, 51.50079108774662, 50.63740521669388, 55.031576827168465, 63.49211923778057, 61.7457215487957, 63.61964799463749, 61.50372013449669, 62.69631274044514, 63.23971018195152, 64.00472313165665, 62.618207931518555, 61.48655265569687, 55.481852665543556, 52.754283025860786, 47.925654128193855, 45.744563564658165, 47.066668421030045, 46.43333360552788, 51.12491525709629, 46.96623221039772, 46.14199943840504, 45.52488975226879, 47.36680671572685, 47.44806535542011, 45.24031922221184, 47.542163506150246, 46.04835346341133, 46.07609957456589, 46.42294116318226, 46.35612554848194, 44.55202415585518, 46.0966032743454, 45.12073963880539, 47.0854964107275, 44.87226337194443, 44.50210623443127, 44.9118572473526, 44.92224209010601, 46.260583475232124, 52.76966080069542, 54.990485832095146, 58.61023239791393, 57.62034751474857, 58.747017458081245, 57.699516266584396, 61.60482130944729, 57.43440829217434, 58.86663503944874, 31.6905901953578, 49.86709915101528, 59.987118914723396, 53.504708558321, 47.4700927734375, 45.491432547569275, 46.20444528758526, 42.721107602119446, 48.497740030288696, 48.87718766927719, 50.10740585625172, 48.40282492339611, 50.12770056724548, 47.4254185706377, 49.90250185132027, 46.830594688653946, 47.66580127179623, 50.66994667053223, 52.872954457998276, 51.035943031311035, 53.442939072847366, 55.96626967191696, 53.44016142189503, 50.20088084042072, 51.3467625528574, 46.56645566225052, 44.82982724905014, 44.12035971879959, 43.791118785738945, 45.17527051270008, 43.06255728006363, 44.68714490532875, 45.22570140659809, 47.688953429460526, 48.732913210988045, 46.633320674300194, 46.61794289946556, 45.79891964793205, 49.29740712046623, 45.48377975821495, 46.59802436828613, 46.56289525330067, 50.66544011235237, 58.691878616809845, 59.25612933933735, 60.4855951666832, 60.74457786977291, 63.123064041137695, 59.314368814229965, 61.238315775990486, 66.44357666373253, 64.34159025549889, 62.5234904140234, 63.856105506420135, 64.52105462551117, 64.59622979164124, 62.7729432284832, 63.00180494785309, 64.49916020035744, 65.21590054035187, 62.99616225063801, 65.94084084033966, 15.199670791625977, 0.24414962012087926, 0.3431516600539908, 0.05106465090648271, 0.04494325730775017, 26.510206572711468, 77.52119064331055, 53.012976944446564, 46.93340577185154, 20.830717831850052, 39.87998105585575, 42.14623644948006, 42.36041575670242, 58.89089673757553, 47.6940755546093, 4.161965120583773, 0.14031925646122545, 0.0167059278828674, 0.12108893366530538, 0.11065418890211731, 0.09058285693754442, 0.05399667970777955, 0.050813897760235704, 0.06423599843401462, 0.06106100532633718, 0.03477712547464762, 0.05594300651864614, 0.08349426308996044, 0.10038722146418877, 0.09992573919589631, 0.10906550305662677, 0.17706997896311805, 0.21112565154908225, 0.14215691800927743, 0.12184841049020179, 0.22391542384866625, 0.3354516701074317, 0.1368147906032391, 28.37938517332077, 98.81487563252449, 72.73024052381516, 62.987327724695206, 36.2396015971899, 29.514091685414314, 58.16381335258484, 62.96133331954479, 70.1431493461132, 93.0257722735405, 14.700721465051174, 0.33940942492336035, 0.6809535040520132, 4.170479513704777, 6.195891005918384, 2.721333224326372, 46.71751655638218, 81.29735201597214, 70.66087916493416, 75.99864274263382, 70.69779798388481, 76.08995944261551, 70.55291935801506, 71.04184672236443, 70.11460527777672, 69.87732321023941, 66.59305304288864, 56.40429496765137, 54.987681582570076, 55.46669527888298, 56.27605564892292, 65.712860673666, 64.62478145956993, 66.99263960123062, 63.647025525569916, 67.13482797145844, 63.791045397520065, 67.78474509716034, 65.70030614733696, 65.01570448279381, 58.90942834317684, 56.37251727283001, 48.253242149949074, 48.71585212647915, 48.26917089521885, 48.41699816286564, 53.223291859030724, 49.10329073667526, 48.62051144242287, 47.24710933864117, 49.48580481112003, 49.72856618463993, 47.76366502046585, 48.868448138237, 48.52214992046356, 48.31178180873394, 48.10687020421028, 48.66868905723095, 47.30043567717075, 49.04225081205368, 48.430920615792274, 47.80246093869209, 45.86757816374302, 45.611699894070625, 48.49134877324104, 48.104575127363205, 48.122677356004715, 54.514219388365746, 58.57635721564293, 62.71587409079075, 59.31785702705383, 61.348232477903366, 60.02928905189037, 65.0207582116127, 60.15313200652599, 57.43627779185772, 34.98256824910641, 51.33611172437668, 62.31624573469162, 57.18587502837181, 50.43948903679848, 48.481780886650085, 48.222201615571976, 48.94894681870937, 52.56043642759323, 52.90220908820629, 55.14645226299763, 51.41379855573177, 53.33029791712761, 49.488806650042534, 53.7721724063158, 48.32106851041317, 47.97608122229576, 52.17344619333744, 54.812351390719414, 53.48379448056221, 54.91449750959873, 58.02558816969395, 55.539571568369865, 53.77593420445919, 51.08769625425339, 48.61228488385677, 47.45085820555687, 46.20279237627983, 46.28772921860218, 47.39943936467171, 45.78334428369999, 47.120933309197426, 46.74545265734196, 49.72993791103363, 51.28768712282181, 47.8750142455101, 50.03186210989952, 47.52787247300148, 51.89585208892822, 47.456101924180984, 50.67685090005398, 50.02804711461067, 54.89181652665138, 60.270382314920425, 63.0115058273077, 61.60828672349453, 62.70446330308914, 66.36086270213127, 62.210208624601364, 62.77904950082302, 68.04576829075813, 64.92526173591614, 65.2192671597004, 64.77980554103851, 70.17537161707878, 68.92065614461899, 65.73462590575218, 64.40890744328499, 68.50406169891357, 66.30242943763733, 67.40399032831192, 69.19719010591507, 16.231112144887447, 1.0079250088892877, 3.1031486112624407, 0.13520642300136387, 0.23471321241231635, 32.45676778256893, 84.36561897397041, 59.682063683867455, 71.75617799162865, 36.555049270391464, 41.24144420027733, 52.123421877622604, 52.66208857297897, 70.66586449742317, 57.35508754849434, 6.3167007733136415, 0.5195951624773443, 0.1370410417439416, 0.17838405532529578, 0.1213360539986752, 0.13521718414267525, 0.18620085931615904, 0.1745972319622524, 0.17000329331494868, 0.17629867972573265, 0.17139689822215587, 0.23270546545973048], [0.025494824731140397, 0.13038010307354853, 0.02877903971238993, 0.04339127437560819, 0.042875377839664, 0.043836711411131546, 0.02407418523944216, 0.012846588342654286, 0.05712654652597848, 0.06006913979945239, 0.26908116589765996, 35.59302069246769, 72.05735743045807, 54.65014949440956, 45.052742287516594, 18.977336883544922, 36.04800067842007, 41.8286456912756, 43.95731806755066, 64.55882459878922, 60.84037072956562, 3.2476161466911435, 0.13669241045136005, 0.19910654023988172, 1.0781501093879342, 0.622138538165018, 1.3065413665026426, 56.2701203674078, 77.95395702123642, 67.14667573571205, 63.73535938560963, 63.75305503606796, 66.02908730506897, 67.42856740951538, 63.350185453891754, 64.08360689878464, 67.51250490546227, 60.89630372822285, 50.04962615668774, 47.10656628012657, 48.60657379031181, 48.01814116537571, 47.66636364161968, 53.467789739370346, 55.44910602271557, 57.6630762219429, 59.848730340600014, 58.394164592027664, 57.80466042459011, 59.08397197723389, 56.53465457260609, 49.520458951592445, 44.64696206152439, 45.544306710362434, 45.45639082789421, 45.5001150816679, 43.909892812371254, 45.61023697257042, 47.48051181435585, 44.218360260128975, 44.47634741663933, 43.24258401989937, 44.25124369561672, 44.70431998372078, 44.38672162592411, 44.93823543190956, 44.119204580783844, 44.408198073506355, 43.57954993844032, 43.99932861328125, 44.196177050471306, 42.38781228661537, 43.217866346240044, 42.69714988768101, 43.96888084709644, 43.33648458123207, 43.36290456354618, 44.71703790128231, 48.97597096860409, 49.005647376179695, 54.608879908919334, 52.59096398949623, 53.850174620747566, 55.21800622344017, 54.77885998785496, 51.723603531718254, 58.868424743413925, 32.78661288321018, 45.5552539229393, 58.785262405872345, 49.59908053278923, 52.30575889348984, 50.034772753715515, 45.867540165781975, 39.60783205926418, 40.26867359876633, 41.96450360119343, 44.44885969161987, 43.9962013810873, 44.64151315391064, 46.06287628412247, 46.61855846643448, 46.004606410861015, 43.7600364536047, 42.30871573090553, 42.82861143350601, 43.27800191938877, 46.0073384642601, 48.06889124214649, 46.397083550691605, 45.73279179632664, 42.67359875142574, 41.19721457362175, 42.06878140568733, 41.025980561971664, 43.73119980096817, 41.32334120571613, 41.83360442519188, 44.10122014582157, 42.93361499905586, 44.880923107266426, 45.103028789162636, 43.844593316316605, 43.06808218359947, 44.2957279086113, 42.83277980983257, 43.14255438745022, 44.0171230584383, 48.38588163256645, 54.509477242827415, 60.31462714076042, 65.42655363678932, 57.025858014822006, 58.17997768521309, 55.90838357806206, 58.871726766228676, 64.73342522978783, 52.88456663489342, 60.41203871369362, 62.93467015028, 59.777180179953575, 60.36259576678276, 64.10231709480286, 61.63476750254631, 63.027373775839806, 62.40692786872387, 67.19607308506966, 63.541831970214844, 70.91804936528206, 43.090660572052, 0.7954918267205358, 0.2658749098191038, 0.1116598435328342, 0.01739167233608896, 5.132656283676624, 62.08982728421688, 52.18257710337639, 50.46873226761818, 31.211690492928028, 19.40883032977581, 29.867389127612114, 30.887440592050552, 45.66970758140087, 44.64241750538349, 11.55116356909275, 0.5026969348546118, 0.1633352300268598, 0.025001064605021384, 0.08136538279359229, 0.03849164510029368, 0.04782028183399234, 0.008228195929405047, 0.11634873997536488, 0.042059104453073815, 0.10232951841317117, 0.12184225808596238, 0.024677107867319137, 0.0695395861112047, 0.0054399944201577455, 0.05413799575762823, 0.04440109245479107, 0.06193037195771467, 0.018099746157531627, 0.030621291443821974, 0.020947897428413853, 0.03461659151071217, 0.1850569574162364, 46.164748817682266, 80.54069101810455, 62.22698092460632, 51.43367908895016, 25.447388403117657, 33.77091966569424, 41.21844783425331, 50.29403664171696, 70.01321151852608, 66.64377272129059, 3.3509152662009, 0.13306149747222662, 0.6574920786079019, 3.135758461430669, 2.502779639326036, 2.788677723146975, 58.88687655329704, 80.7073500752449, 71.64409160614014, 65.34716829657555, 66.53525814414024, 69.25547137856483, 69.9420565366745, 67.30455726385117, 66.9789831340313, 69.13207679986954, 62.32395552098751, 52.33835734426975, 49.69138137996197, 50.374204739928246, 50.49541063606739, 51.36326886713505, 58.015340119600296, 58.691415041685104, 58.768102526664734, 61.66641220450401, 61.246470138430595, 60.433104783296585, 61.047680005431175, 57.38118074834347, 51.770158633589745, 46.51949018239975, 46.42379231750965, 47.07755483686924, 47.3967719078064, 45.2490321546793, 46.833174750208855, 50.4134414345026, 44.79425735771656, 45.002474784851074, 46.51480883359909, 46.481112241744995, 46.35878920555115, 46.44305348396301, 47.9727678000927, 46.57831862568855, 47.30137802660465, 47.32729643583298, 46.073869094252586, 46.07543081045151, 44.23274628818035, 45.14325723052025, 45.448684841394424, 46.08615763485432, 45.57413510978222, 46.01959280669689, 46.61184802651405, 51.458544954657555, 51.33471339941025, 56.32786966860294, 54.741545990109444, 58.061876222491264, 57.60273925960064, 58.229375034570694, 56.11786633729935, 59.966683611273766, 33.97000998258591, 49.15008522570133, 60.97208306193352, 51.55611611902714, 54.62545461952686, 51.548482328653336, 47.51498356461525, 40.76778061687946, 43.76556135714054, 42.87652686238289, 46.78186610341072, 47.43728533387184, 49.37962330877781, 48.31449866294861, 46.50243289768696, 46.75928011536598, 46.16857901215553, 44.757353737950325, 44.00705739855766, 44.68942478299141, 46.61419250071049, 48.63079749047756, 48.01606647670269, 48.177052438259125, 46.8273838609457, 43.23143161833286, 44.698905274271965, 42.2014132887125, 44.365408569574356, 44.35443855822086, 44.49786566197872, 45.30668646097183, 45.01040875911713, 46.98469161987305, 46.51279114186764, 44.70889873802662, 45.91741628944874, 45.74282705783844, 44.70558151602745, 46.219158098101616, 45.77327862381935, 51.12104706466198, 57.9960523545742, 61.20035581290722, 66.44641891121864, 59.7431606054306, 60.838531628251076, 57.55303032696247, 59.97978150844574, 64.6616318821907, 55.81333547830582, 60.55613078176975, 66.14811971783638, 64.31076630949974, 62.17378377914429, 63.96902024745941, 64.43555921316147, 66.59579649567604, 65.28621196746826, 68.19428712129593, 66.24515131115913, 70.8795802295208, 49.04143765568733, 1.3540007011033595, 0.6507834198419005, 0.3565377480117604, 0.03442276480200235, 5.16094671562314, 65.28408408164978, 59.69560995697975, 51.97541981935501, 24.417102187871933, 30.2367540076375, 41.761628687381744, 42.18070439994335, 55.01152150332928, 56.47725485265255, 19.18782278895378, 0.6241252971813083, 0.08722408208996058, 0.0332408649410354, 0.1143471454270184, 0.08022782625630498, 0.014729960621480132, 0.03588780513382517, 0.021750018058810383, 0.06417307173251174, 0.06506431687739678, 0.024633540087961592, 0.10250296574668027, 0.2487251683487557, 0.15533302270341665, 0.04907808484858833, 0.07423454590025358, 0.13047533546341583, 0.17359338817186654, 0.12951622833497822, 0.15745543147204444, 0.14547338301781565, 0.3294136159820482, 53.89130361378193, 89.59420680999756, 70.26085942983627, 61.81397348642349, 32.61740416288376, 51.39079459011555, 60.00302866101265, 61.160142570734024, 75.3258964419365, 74.39358606934547, 4.281880035996437, 0.26978730456903577, 1.2037032097578049, 5.121742319315672, 7.653246754780412, 5.225696666166186, 63.129101917147636, 79.70942482352257, 75.78026846051216, 67.32424780726433, 71.40693873167038, 72.34381645917892, 73.36764112114906, 67.21947222948074, 69.88027945160866, 72.70391553640366, 65.21640971302986, 54.944075122475624, 51.86382740736008, 52.62701265513897, 53.28800618648529, 53.93359154462814, 61.11915796995163, 59.375047758221626, 61.79184727370739, 64.76622506976128, 63.72268706560135, 62.35528104007244, 62.94749066233635, 62.49758340418339, 54.852150455117226, 49.45578642189503, 49.04907524585724, 48.71809020638466, 50.24633780121803, 47.40682236850262, 48.98278400301933, 52.7526681125164, 49.14313539862633, 46.776861771941185, 47.46523283421993, 48.11067380011082, 48.12075085937977, 47.889647260308266, 49.84529212117195, 49.15220931172371, 49.85383786261082, 47.91210785508156, 48.386219814419746, 48.02848421037197, 46.185267716646194, 46.46593205630779, 47.593760937452316, 48.37398447096348, 49.17349956929684, 49.430323988199234, 49.53916534781456, 54.69078071415424, 53.95165957510471, 59.75388742983341, 58.77534493803978, 60.41209191083908, 60.08308656513691, 60.063643008470535, 58.54474291205406, 62.0006612688303, 37.600175589323044, 51.6506664454937, 63.06635208427906, 55.061367228627205, 55.7106763869524, 55.340112671256065, 49.65647645294666, 44.24490563571453, 46.164327040314674, 46.29009649157524, 48.810288459062576, 49.39804472029209, 51.39810159802437, 50.53152769804001, 51.321129128336906, 50.678032636642456, 50.003120452165604, 48.15017268061638, 47.16066397726536, 47.377734929323196, 48.65613453090191, 52.7386848628521, 50.00475436449051, 50.65400272607803, 49.08501751720905, 44.940587505698204, 47.55203537642956, 44.124771282076836, 47.8104443103075, 46.11102730035782, 46.18913970887661, 48.16046632826328, 46.21239826083183, 48.24823021888733, 48.236238062381744, 47.37287878990173, 48.875451162457466, 48.54395315051079, 46.40657164156437, 47.63914570212364, 48.799105659127235, 51.757288724184036, 59.925068244338036, 63.15979287028313, 70.13312548398972, 63.273832350969315, 62.259165197610855, 61.254058331251144, 60.222231298685074, 64.84605878591537, 61.41552686691284, 63.927708864212036, 67.02789410948753, 66.03161796927452, 64.10154193639755, 66.53894394636154, 66.69355005025864, 69.46730241179466, 67.06947907805443, 71.84288933873177, 70.39286434650421, 73.973169028759, 50.327923223376274, 1.5067468048073351, 1.6401923191733658, 0.4830654663965106, 0.14200872596120462, 7.428637482225895, 73.48767668008804, 64.88073572516441, 69.75686967372894, 42.98052728176117, 27.11578767746687, 44.145050793886185, 51.35380357503891, 64.03691500425339, 69.51119005680084, 25.160606391727924, 0.7528696325607598, 0.19356337987119332, 0.14790216519031674, 0.3093148913467303, 0.1404403304331936, 0.145041556970682, 0.1055788561643567, 0.2987041388405487, 0.21391246060375124, 0.26247628906276077, 0.1466648862697184], [0.040473476256011054, 0.0366743221093202, 0.06984290186665021, 0.02201063063694164, 0.04532787163043395, 0.06692900002235547, 0.0361122602771502, 0.02760503444733331, 0.053949349239701405, 0.019632190196716692, 1.5835423464886844, 51.31458207964897, 64.27845284342766, 58.07919569313526, 28.613931387662888, 13.766710683703423, 47.070099636912346, 34.88016374409199, 54.72985401749611, 68.94636556506157, 43.79422701895237, 0.06361206746078096, 0.05293332680594176, 0.5148952302988619, 1.719898742157966, 2.239854410290718, 8.892494682222605, 93.55182364583015, 66.75323724746704, 67.90741011500359, 57.54914693534374, 62.04648680984974, 64.07821118831635, 69.79720070958138, 64.54446136951447, 64.65452626347542, 65.7278698682785, 63.14385652542114, 52.95200161635876, 50.0568837672472, 45.671656876802444, 47.78820030391216, 45.50424166023731, 45.43352745473385, 48.781672194600105, 52.38817647099495, 51.87772326171398, 50.624102130532265, 50.13446420431137, 47.51152195036411, 45.06948418915272, 43.29297311604023, 46.08171187341213, 45.77696442604065, 44.69719536602497, 45.60177482664585, 45.854438468813896, 44.082186967134476, 44.282512217760086, 44.560630694031715, 44.7529611736536, 45.59834361076355, 46.81943088769913, 44.667811542749405, 43.69352862238884, 44.559163972735405, 43.57560954988003, 43.866974115371704, 45.40233872830868, 44.37312975525856, 45.82313194870949, 45.32695837318897, 43.87496508657932, 43.23124162852764, 41.80835857987404, 43.13555896282196, 43.02885688841343, 44.46132302284241, 47.40297697484493, 48.44012752175331, 50.096625834703445, 49.95330512523651, 52.40560233592987, 47.972509413957596, 54.85072173178196, 53.3524127304554, 61.5803924202919, 37.3138115555048, 41.25044211745262, 61.201252564787865, 51.7156657576561, 54.40498284995556, 52.22156301140785, 54.99311529099941, 44.959643483161926, 44.74228374660015, 39.79753687977791, 42.20771335065365, 41.88114367425442, 43.87778453528881, 43.18041555583477, 43.51292051374912, 41.620747447013855, 42.69367307424545, 42.527530789375305, 42.0934496819973, 40.375466868281364, 40.6678269803524, 39.28129658102989, 43.0941753834486, 40.41839696466923, 43.53919990360737, 40.39879001677036, 41.81668013334274, 42.08904571831226, 42.41162180900574, 41.57430253922939, 42.97173835337162, 42.265481650829315, 45.06733350455761, 44.917940720915794, 43.80469545722008, 43.21571186184883, 44.687954261898994, 42.1304102987051, 43.34893651306629, 42.86748334765434, 45.673465579748154, 49.82550658285618, 58.39911192655563, 50.72519950568676, 58.58271047472954, 57.18000054359436, 54.053224325180054, 58.518771305680275, 59.19851303100586, 56.72336004674435, 56.145604848861694, 54.89375442266464, 59.34358924627304, 59.78875815868378, 61.167312785983086, 62.547265738248825, 62.98461467027664, 62.671237885951996, 62.795354425907135, 65.26908248662949, 64.67848777770996, 62.29688957333565, 65.41569381952286, 8.522795420140028, 0.2486462632077746, 0.13676845090230927, 0.017586103895155247, 0.25254665000829846, 32.140294164419174, 68.38501408696175, 49.00108762085438, 38.157468885183334, 14.21324847266078, 24.224572218954563, 28.690533377230167, 43.596025854349136, 47.765880301594734, 28.005367442965508, 1.8126364471390843, 0.11525399051606655, 0.03757940459763631, 0.04807026685739402, 0.03006636721693212, 0.06376037825248204, 0.06049277253623586, 0.10092810611240566, 0.02795353215333307, 0.032419300041510724, 0.038630448980256915, 0.003775885033974191, 0.020490394927037414, 0.03597525610530283, 0.0033718988015607465, 0.06669748705462553, 0.01440687683498254, 0.057812190789263695, 0.03229414054658264, 0.08997577271657065, 0.06315984719549306, 2.7727276040241122, 65.26354998350143, 72.02150255441666, 65.31072825193405, 36.22384384274483, 21.64939720183611, 40.413335636258125, 40.397942662239075, 61.737612783908844, 75.70978984236717, 47.35657386481762, 0.044384687280398794, 0.054785460233688354, 1.4002856612205505, 4.537818152457476, 1.761145528871566, 9.962359573692083, 92.68974870443344, 70.76691627502441, 70.75177788734436, 58.67865912616253, 64.457628428936, 66.38502940535545, 70.77004730701447, 67.28213846683502, 67.74405688047409, 66.97270587086678, 66.41584575176239, 53.23753349483013, 51.44450470805168, 48.73576305806637, 50.32773703336716, 46.241975873708725, 48.71444620192051, 49.81162212789059, 55.887260511517525, 53.927641063928604, 53.4653464704752, 50.94263143837452, 48.18510040640831, 46.184332966804504, 47.08931140601635, 47.49419488012791, 47.11085245013237, 46.096694469451904, 47.816679775714874, 47.368326634168625, 45.143690407276154, 46.50372102856636, 46.28411941230297, 47.821190133690834, 46.72613449394703, 47.27517083287239, 47.296613082289696, 46.802020221948624, 46.55763253569603, 45.63069507479668, 45.96901372075081, 47.0276103168726, 46.6043434292078, 48.45175489783287, 47.77093403041363, 46.016526371240616, 45.671862065792084, 44.38566908240318, 45.55317923426628, 46.7114444822073, 47.02639438211918, 51.10569208860397, 50.548786371946335, 52.10419490933418, 53.20005990564823, 54.50175605714321, 51.34139724075794, 55.51744535565376, 57.66777276992798, 64.09451991319656, 39.95802126824856, 42.65673905611038, 63.438629508018494, 53.75033877789974, 56.479059755802155, 55.00114046037197, 54.93066944181919, 46.79540477693081, 46.07380069792271, 42.71291144192219, 44.78095047175884, 46.06046341359615, 48.937688022851944, 44.53198403120041, 46.121864318847656, 43.334694877266884, 44.84104044735432, 44.04865376651287, 44.447514563798904, 41.997216045856476, 42.640996500849724, 43.17611798644066, 43.79508197307587, 43.20680893957615, 45.71671865880489, 42.05982528626919, 46.025007516145706, 45.96041098237038, 44.97045010328293, 45.07663920521736, 45.383590534329414, 43.748131692409515, 45.13333596289158, 45.888404846191406, 45.12592636048794, 46.291103437542915, 45.72116442024708, 44.8665826767683, 44.60747458040714, 44.57444295287132, 47.817572727799416, 53.02711218595505, 60.738209411501884, 54.5435956120491, 61.35322920978069, 58.037994503974915, 57.45794042944908, 60.51190875470638, 61.13809995353222, 58.52518916130066, 57.29395642876625, 56.37790538370609, 62.44279034435749, 63.22546474635601, 62.87682965397835, 63.656388223171234, 64.72571924328804, 65.05674228072166, 64.96082782745361, 65.3295524418354, 67.76043400168419, 63.6724803596735, 69.45218682289124, 10.720370449125767, 0.12037241234793328, 0.2439722022973001, 0.06855952073237859, 0.3000987530685961, 35.44688433408737, 75.59306770563126, 53.88149634003639, 35.188395604491234, 15.980038717389107, 33.608539178967476, 34.89813677966595, 53.64613316953182, 56.43652863800526, 40.5193917453289, 2.57200313732028, 0.12410470269969665, 0.009215932332153898, 0.08272821825812571, 0.042002627014881, 0.031884426789474674, 0.022699061664752662, 0.05518910322280135, 0.025403282670595217, 0.07928039311082102, 0.021915008619544096, 0.13099375530146062, 0.11751948535675183, 0.09098960581468418, 0.13618397992104292, 0.12068614043528214, 0.09449721095734276, 0.16548416315345094, 0.14731165312696248, 0.4109719645930454, 0.18246355204610154, 4.262024201452732, 78.40547159314156, 81.08043685555458, 76.54187679290771, 44.718405827879906, 25.616447031497955, 60.372950211167336, 51.11390344798565, 71.22945785522461, 80.27557924389839, 51.41471430659294, 0.209625429706648, 0.22064713906729594, 1.4687569183297455, 7.0108304265886545, 7.612039390951395, 11.019300408661366, 94.77681711316109, 75.06371811032295, 72.12002366781235, 61.761752888560295, 69.1084648668766, 68.65302130579948, 75.47613278031349, 68.77896174788475, 69.1572618484497, 71.86627328395844, 71.30932956933975, 56.35469242930412, 55.416807755827904, 50.64288072288036, 52.649260461330414, 49.75059360265732, 49.688368141651154, 52.667689472436905, 58.88791389763355, 54.82080213725567, 55.959642827510834, 52.743708193302155, 50.9037671238184, 47.876800149679184, 48.50226178765297, 48.41937683522701, 49.68877471983433, 48.349517583847046, 50.63817657530308, 50.82226149737835, 46.88665688037872, 48.61803397536278, 48.99788059294224, 50.714620873332024, 49.08948987722397, 50.389514118433, 48.10511849820614, 48.61945129930973, 49.29492965340614, 46.728969141840935, 48.60521346330643, 49.0995479375124, 49.074207097291946, 49.945325553417206, 50.1581559330225, 46.96467809379101, 47.70313046872616, 45.798372477293015, 48.63848067820072, 48.79291959106922, 49.320897459983826, 54.33017626404762, 52.817754819989204, 55.72511561214924, 55.876533687114716, 57.42100641131401, 53.08884747326374, 60.236613526940346, 59.96079012751579, 65.3508996963501, 42.64704957604408, 46.57077603042126, 66.49402275681496, 55.87404102087021, 59.37795840203762, 57.47283183038235, 58.92732158303261, 49.13606017827988, 48.89181688427925, 44.73735921084881, 49.16262835264206, 48.61163131892681, 51.73938028514385, 47.15780273079872, 48.98537166416645, 45.91752268373966, 47.5066202133894, 47.80797824263573, 46.506297290325165, 45.03411948680878, 45.49532353878021, 44.43769209086895, 47.402095422148705, 43.86090584099293, 47.47583046555519, 44.57350820302963, 47.43937522172928, 46.27208165824413, 46.93779073655605, 48.03747072815895, 47.4710351228714, 45.58937229216099, 46.65621064603329, 48.48198987543583, 47.13712804019451, 47.77037926018238, 48.609704822301865, 46.68750956654549, 47.421656772494316, 45.87203152477741, 50.60088537633419, 54.73235048353672, 63.955036997795105, 58.485200107097626, 65.73844850063324, 60.85987888276577, 57.28014796972275, 63.22027042508125, 63.88240769505501, 63.42763289809227, 58.91596779227257, 57.82221928238869, 61.477151960134506, 64.87462565302849, 66.33541166782379, 67.16141134500504, 67.93647855520248, 68.30570474267006, 67.46121525764465, 69.01583343744278, 71.55473560094833, 65.13407573103905, 73.84846732020378, 10.52876003086567, 0.5209792382083833, 1.0097315744496882, 0.23702954436885193, 0.3737315285252407, 42.16362811625004, 79.99098211526871, 64.02528762817383, 51.40332251787186, 18.843910843133926, 34.683334305882454, 43.544367626309395, 64.33555617928505, 65.82069128751755, 50.352971479296684, 3.241782272234559, 0.21820777386892587, 0.1462325852480717, 0.19166915182722732, 0.13464472111081704, 0.28970767627470195, 0.25055187579710037, 0.1448664249619469, 0.18243147642351687, 0.2303122470038943, 0.07826661196304485], [0.023670109949307516, 0.050666284587350674, 0.06327721042907797, 0.10232611195533536, 0.0627278875617776, 0.05337231086741667, 0.09045693674124777, 0.07234888966195285, 0.15303873253287748, 0.16825932048959658, 4.924261216074228, 66.72278568148613, 56.56525433063507, 55.29835291206837, 33.03380101919174, 23.75801805406809, 72.37238332629204, 45.79648017883301, 54.697616547346115, 72.43593111634254, 22.52966746687889, 0.2713402931112796, 0.14266190497437492, 1.479427576996386, 2.248449311591685, 0.559665912296623, 30.207928754389286, 66.157056838274, 65.43413043022156, 72.4908609688282, 53.89672972261906, 58.498089015483856, 59.95911441743374, 65.82987919449806, 65.879907310009, 65.27224391698837, 63.178784251213074, 62.42875009775162, 53.15160870552063, 50.585598796606064, 49.397980123758316, 48.67127671837807, 45.37582755088806, 45.699767768383026, 42.438193783164024, 44.48403440415859, 44.70897853374481, 45.20953707396984, 42.92495906352997, 46.895225420594215, 43.72859314084053, 44.33944836258888, 45.11407479643822, 44.08363848924637, 44.79790896177292, 45.23545168340206, 43.7899674475193, 44.557894840836525, 44.69762474298477, 45.01151069998741, 44.89503175020218, 43.220662996172905, 45.617255195975304, 43.9910526573658, 42.05118075013161, 43.96113686263561, 41.639689430594444, 43.35641451179981, 41.993743032217026, 43.47905673086643, 43.219325467944145, 45.1269257068634, 45.203229412436485, 44.24937419593334, 43.519501760602, 43.8693717867136, 44.18149843811989, 43.98833580315113, 48.57604622840881, 44.86065499484539, 47.39970535039902, 47.977988719940186, 47.641060799360275, 47.254575937986374, 54.24541041254997, 51.66742354631424, 59.04468588531017, 40.98180033266544, 30.995721481740475, 56.477061063051224, 54.01860058307648, 55.267213582992554, 50.774365067481995, 54.53675597906113, 53.45163680613041, 49.28315028548241, 43.88166792690754, 41.52113199234009, 40.451538786292076, 42.92288437485695, 40.59666059911251, 42.21810199320316, 39.41495440900326, 42.30216108262539, 40.9267108887434, 41.601034104824066, 42.63802506029606, 44.14579555392265, 40.69179989397526, 42.897087559103966, 40.25094375014305, 43.1557472795248, 41.30341127514839, 43.74993659555912, 41.540157571434975, 44.466509744524956, 42.64709897339344, 43.63884575664997, 41.98538348078728, 44.359575882554054, 41.95355258882046, 44.02379550039768, 42.729098573327065, 43.362676575779915, 44.900370463728905, 45.001627430319786, 45.36730080842972, 43.91699083149433, 52.46533893048763, 60.52703574299812, 58.33226591348648, 47.544914558529854, 58.61480735242367, 54.334561228752136, 57.611250802874565, 55.791011676192284, 56.40843294560909, 58.52352865040302, 54.89068418741226, 56.525056287646294, 62.04616002738476, 61.168528720736504, 64.2800335586071, 63.834074288606644, 62.05773800611496, 63.46723437309265, 61.013740226626396, 69.8493567109108, 61.08774125576019, 69.91133138537407, 25.3383931517601, 0.08050172327784821, 0.12690352712525055, 0.037778994083055295, 0.064704093238106, 7.702420391142368, 59.98795107007027, 53.39402809739113, 46.66345305740833, 30.03329012542963, 21.6326666995883, 29.57552868872881, 39.91812340915203, 46.36691316962242, 41.60236783325672, 6.351305516436696, 0.262094201752916, 0.050929079079651274, 0.10738186683738604, 0.01718808267469285, 0.10814269437105395, 0.06566676267539151, 0.08367772199562751, 0.03724989102920517, 0.03271173591201659, 0.022063375072320923, 0.1306230525369756, 0.03718123865837697, 0.07493849523598328, 0.10138801502762362, 0.04847522344789468, 0.02573884659796022, 0.043077794907731004, 0.0468146160710603, 0.11697388064931147, 0.2522382134338841, 8.746118936687708, 80.84730416536331, 62.46395520865917, 63.14449489116669, 42.54666656255722, 26.627475880086422, 58.64764139056206, 51.359571665525436, 61.21576018631458, 81.63940966129303, 24.755422733724117, 0.27573368861339986, 0.1536821448826231, 1.6409781645052135, 3.432754799723625, 0.40079806989524513, 33.040629252791405, 68.85791391134262, 71.40902101993561, 73.7829664349556, 56.20395831763744, 59.52450513839722, 63.31414058804512, 68.70387777686119, 67.99684971570969, 66.39028072357178, 64.07336264848709, 64.77905318140984, 57.45996952056885, 52.411625012755394, 50.93956120312214, 51.36153236031532, 46.961752250790596, 48.66431549191475, 47.00693942606449, 47.68839865922928, 48.28330613672733, 47.550876438617706, 45.753318294882774, 47.95015901327133, 45.654728785157204, 47.30644315481186, 45.25537021458149, 46.10214337706566, 45.1673099398613, 47.58569397032261, 46.58527985215187, 45.62998451292515, 45.97987733781338, 47.68230378627777, 46.85048282146454, 46.37479014694691, 47.87506364285946, 46.01286716759205, 44.93249014019966, 44.85669560730457, 46.202932968735695, 45.40874518454075, 44.689010605216026, 46.4781180024147, 45.71992948651314, 46.651305109262466, 45.759356170892715, 44.719279780983925, 43.79237271845341, 46.16285651922226, 45.016762018203735, 46.24818854033947, 49.981074035167694, 46.7807337641716, 48.341876193881035, 50.72355039417744, 50.20551659166813, 49.41664092242718, 57.7783278375864, 52.42208585143089, 61.21806286275387, 43.616483956575394, 31.751829609274864, 58.79087470471859, 55.80882512032986, 57.9726380109787, 53.2791830599308, 56.80211842060089, 56.15302585065365, 52.04138047993183, 44.714366644620895, 42.28495940566063, 44.462831541895866, 43.37028756737709, 43.45993995666504, 44.81745511293411, 40.57551473379135, 44.830458015203476, 43.84952925145626, 43.81681680679321, 45.78889958560467, 45.378684997558594, 41.4653167873621, 43.90879847109318, 41.43158979713917, 43.34771677851677, 42.231959849596024, 46.62759058177471, 43.66341903805733, 46.92112483084202, 44.900473058223724, 44.495080411434174, 45.1077139377594, 44.756924360990524, 45.10221563279629, 45.358371287584305, 44.3899742513895, 46.201424449682236, 47.664915919303894, 46.774855479598045, 46.73623815178871, 45.695375204086304, 55.37949375808239, 61.06057271361351, 59.1303750872612, 53.42162221670151, 59.07426729798317, 57.08636596798897, 59.964358136057854, 58.23200449347496, 56.40256606042385, 59.45650778710842, 55.81076681613922, 58.66424649953842, 63.970866948366165, 64.9710264801979, 65.06760209798813, 67.65448808670044, 63.41141536831856, 65.81980973482132, 62.22563959658146, 70.66337943077087, 62.06202417612076, 72.91325390338898, 28.50224018096924, 0.1820388506166637, 0.5197953048627824, 0.4197782592382282, 0.10351020857342519, 8.794036265462637, 66.58603101968765, 61.159363612532616, 44.623125940561295, 27.19598427414894, 26.89273774623871, 36.49130769073963, 47.681346237659454, 53.21064233779907, 52.80453532934189, 8.534975666552782, 0.23362066713161767, 0.029299608067958616, 0.04532507373369299, 0.04862744906859007, 0.12214398564537987, 0.06218140340934042, 0.016411215474363416, 0.026345337100792676, 0.0038596702597715193, 0.09744951894390397, 0.21913243050221354, 0.17975100228795782, 0.23828197794500738, 0.23058348713675514, 0.2023065771209076, 0.14533338428009301, 0.13927403051638976, 0.2323145465925336, 0.35050236561801285, 0.4719236626988277, 12.491468712687492, 93.42098146677017, 70.11734873056412, 74.64114278554916, 47.495315819978714, 38.700596541166306, 80.1776584982872, 65.880416482687, 67.40318477153778, 85.53442105650902, 29.379943683743477, 0.2788629394490272, 0.2040249013225548, 3.4213164635002613, 10.0798967666924, 2.979513220489025, 35.07280960679054, 77.17561438679695, 73.37802216410637, 77.1618515253067, 57.66917869448662, 63.527092561125755, 65.90286567807198, 70.78895509243011, 68.7326118350029, 67.9236276447773, 67.980305403471, 66.7978848516941, 59.32128444314003, 55.91516621410847, 53.19114938378334, 54.420432820916176, 50.554159283638, 50.572892278432846, 47.81500406563282, 49.91686508059502, 50.57828038930893, 50.09824454784393, 47.75066591799259, 50.458712205290794, 48.41532625257969, 50.474146977066994, 47.775467187166214, 47.140905037522316, 48.94450485706329, 50.41488915681839, 47.72996082901955, 47.94185645878315, 48.53824585676193, 49.55741956830025, 51.268938928842545, 48.62835422158241, 49.93538908660412, 48.321064710617065, 45.95122307538986, 48.60709436237812, 45.13143226504326, 48.718823567032814, 46.672363579273224, 49.75239850580692, 48.52975711226463, 48.13262142241001, 50.0557666271925, 46.846268847584724, 47.24201761186123, 48.2950285077095, 48.423195630311966, 49.52040575444698, 53.123410418629646, 50.177181512117386, 51.60701438784599, 52.76581160724163, 51.87026806175709, 51.20953291654587, 60.7812687009573, 56.761346608400345, 65.11557072401047, 45.58944448828697, 33.84910047054291, 59.69520717859268, 56.271222308278084, 62.308737337589264, 54.89214710891247, 58.01401399075985, 58.00672598183155, 54.02001030743122, 48.28166842460632, 46.13063804805279, 47.092651426792145, 47.287504971027374, 44.983764588832855, 48.00440490245819, 43.25017601251602, 47.38204389810562, 45.19285596907139, 47.28033475577831, 47.62675076723099, 47.52629175782204, 43.95720787346363, 47.30662554502487, 43.896388337016106, 46.57054424285889, 46.173666939139366, 49.55751836299896, 44.9363849312067, 49.72840279340744, 47.431046068668365, 47.473371997475624, 46.95775106549263, 47.493499517440796, 46.71572685241699, 47.700143828988075, 47.032154873013496, 48.23306903243065, 49.602823331952095, 49.429184049367905, 50.55454686284065, 47.41331622004509, 57.420668229460716, 65.46447560191154, 62.0792980492115, 56.30351297557354, 64.16591048240662, 61.121487244963646, 62.62508176267147, 58.58455717563629, 58.64316523075104, 61.35345719754696, 60.494855269789696, 60.88684603571892, 64.68419507145882, 68.49074721336365, 68.73987704515457, 69.70042750239372, 64.74150359630585, 68.75391349196434, 66.44040003418922, 74.9154956638813, 65.31549319624901, 73.82509857416153, 30.44853374361992, 0.3605576354311779, 1.999484533444047, 0.43454260448925197, 0.238311322464142, 11.97956683114171, 73.35054203867912, 66.63320168852806, 63.647967875003815, 40.812663808465004, 30.56482270359993, 41.102953031659126, 59.69206474721432, 63.92166718840599, 65.03605619072914, 12.442173957824707, 0.4259316431125626, 0.1889483493869193, 0.2898259449284524, 0.0992904236773029, 0.22852652095025405, 0.15479581168619916, 0.1314528181683272, 0.09292056274716742, 0.08962590203736909, 0.191197813837789], [0.020937791232427116, 0.02518585566576803, 0.01750534152961336, 0.04858877575316001, 0.07798871476552449, 0.04740629701700527, 0.09272335926652886, 0.018309393599338364, 0.07389574064291082, 0.10172273847274482, 13.067252766340971, 64.66487690806389, 56.131439208984375, 40.35415381193161, 10.800427403301, 23.674245849251747, 45.03733791410923, 51.330491825938225, 62.585647478699684, 71.11309289932251, 8.496366888284683, 0.34307913738302886, 0.1665516832144931, 1.680819382891059, 3.113774503581226, 0.7137893827166408, 44.84369270503521, 68.72998237609863, 71.63929626345634, 63.207005336880684, 51.861973106861115, 52.59111598134041, 60.20820625126362, 59.352948144078255, 65.08726984262466, 66.29600778222084, 65.8518648147583, 59.53028462827206, 56.1333467066288, 51.80667847394943, 51.3367310911417, 48.32131169736385, 48.62725228071213, 45.148595944046974, 43.36773790419102, 42.86888547241688, 44.36887018382549, 46.03530876338482, 47.3277448117733, 46.708089262247086, 46.10789626836777, 45.87832398712635, 48.0882778018713, 45.031398832798004, 46.30883328616619, 42.97659069299698, 46.020565554499626, 43.59615504741669, 44.70677465200424, 43.79606232047081, 43.1501691788435, 42.74475373327732, 44.768878519535065, 44.15550783276558, 43.30646239221096, 41.03848189115524, 43.19032162427902, 40.57727783918381, 43.1325913220644, 43.258265778422356, 43.20396289229393, 43.55629898607731, 44.81362871825695, 43.55935402214527, 44.50234942138195, 43.32110680639744, 41.93259671330452, 41.44172765314579, 44.05995436012745, 43.465236872434616, 45.08130915462971, 42.932425662875175, 49.132020995020866, 47.541399747133255, 53.71721975505352, 52.545054852962494, 58.78384508192539, 40.961486622691154, 28.072304651141167, 56.68260343372822, 51.96156196296215, 55.71522854268551, 52.246957048773766, 53.99860605597496, 51.18010729551315, 54.26448158919811, 45.33796638250351, 40.829816088080406, 40.13826459646225, 43.93252819776535, 41.53011851012707, 42.74469293653965, 41.21679872274399, 41.06754653155804, 44.09957863390446, 41.85077950358391, 40.010515451431274, 42.78201073408127, 40.666500851511955, 41.99213571846485, 40.46105347573757, 42.574522867798805, 43.36616098880768, 44.41135190427303, 43.71498227119446, 43.455486595630646, 41.52848079800606, 42.406484484672546, 42.07042671740055, 42.451812252402306, 41.66723035275936, 42.68223948776722, 42.53837160766125, 42.49772138893604, 44.732700660824776, 44.450892582535744, 44.89248588681221, 43.10517579317093, 49.07226920127869, 54.07399021089077, 59.550374150276184, 49.65831935405731, 49.47275631129742, 53.63384462893009, 53.91646586358547, 57.224116176366806, 58.26581507921219, 58.49188394844532, 54.99085061252117, 51.61215931177139, 58.750300481915474, 60.730826407670975, 58.936418294906616, 60.81777714192867, 58.52031022310257, 61.338060423731804, 62.87505894899368, 65.95850989222527, 61.81634835898876, 68.97171780467033, 52.928796261548996, 1.0198829672299325, 0.6530271400697529, 0.159618524776306, 0.015133300257730298, 5.291132954880595, 58.02772365510464, 59.68838274478912, 55.099311992526054, 35.09932838380337, 17.391668669879436, 21.3431279361248, 33.285066336393356, 44.942886382341385, 48.43867979943752, 20.55661763995886, 0.8618872670922428, 0.08560513888369314, 0.14792223286349326, 0.023455876034859102, 0.06978525925660506, 0.01007017770461971, 0.06321973851299845, 0.027703248415491544, 0.05257346681901254, 0.027808713166450616, 0.03474984783679247, 0.06035852544300724, 0.053164316559559666, 0.024774314370006323, 0.1870441617211327, 0.06927346679731272, 0.10718167992308736, 0.020797911238332745, 0.22493814787594602, 0.026645378129614983, 19.70609027892351, 75.07219925522804, 64.26585271954536, 51.09376072883606, 24.92240097373724, 36.13339349627495, 46.53202570974827, 56.802954375743866, 65.71467697620392, 79.83855709433556, 8.16736439242959, 0.2725079585798085, 0.19456401758361608, 1.7039951705373824, 1.858438120689243, 1.101179604884237, 47.43954241275787, 70.15448793768883, 73.93892526626587, 65.64926728606224, 53.42587798833847, 55.358822867274284, 62.0653185993433, 62.87640027701855, 66.8748839199543, 67.59308338165283, 66.9427178800106, 61.99810780584812, 59.91222873330116, 53.563548400998116, 53.786649629473686, 50.31273163855076, 49.95164841413498, 46.331423074007034, 46.91965810954571, 45.29861569404602, 46.007205471396446, 47.85573787987232, 49.76597897708416, 48.81325230002403, 47.41071715950966, 46.954813823103905, 50.72157829999924, 47.143485099077225, 48.979690968990326, 45.74070677161217, 47.19668984413147, 44.71292272210121, 46.03816621005535, 44.99522477388382, 46.640251502394676, 44.73577469587326, 46.37387439608574, 46.17005713284016, 45.25334872305393, 42.862589210271835, 45.593263283371925, 44.44405294954777, 45.82608439028263, 46.28929853439331, 45.18731966614723, 43.22568632662296, 47.10673347115517, 44.642968475818634, 46.54383547604084, 45.205364897847176, 44.35768358409405, 43.55391651391983, 47.065057307481766, 45.1571948826313, 47.107409834861755, 47.225971072912216, 48.80316384136677, 50.738331601023674, 55.728516429662704, 54.83796201646328, 60.804599449038506, 44.21149402856827, 29.940930381417274, 59.24666024744511, 55.62571294605732, 57.96115882694721, 54.351512119174004, 56.59346401691437, 54.384262561798096, 55.955295860767365, 48.23441796004772, 42.07705736160278, 41.69183403253555, 44.75331075489521, 42.96842873096466, 43.76365765929222, 44.795503690838814, 42.75078780949116, 43.953514471650124, 44.57267984747887, 42.91571795940399, 44.40040089190006, 41.72607019543648, 43.93285498023033, 41.38921067118645, 44.78079468011856, 45.19248738884926, 46.26959279179573, 45.439371541142464, 44.38113212585449, 43.2158562541008, 44.084835425019264, 44.09302778542042, 44.881367683410645, 43.458325043320656, 44.438820630311966, 44.86060939729214, 44.85780134797096, 47.426079735159874, 45.33044658601284, 46.018772050738335, 44.87437225878239, 50.23621514439583, 57.75821551680565, 60.381807535886765, 55.32154306769371, 52.551951482892036, 55.56902378797531, 56.760275065898895, 59.02445577085018, 60.00519834458828, 57.389874681830406, 58.58084097504616, 53.112767189741135, 59.936292842030525, 61.396535485982895, 61.58657468855381, 63.264838233590126, 59.97913174331188, 62.09287852048874, 65.1589947938919, 65.62564015388489, 64.99868139624596, 68.5226882994175, 57.09013916552067, 1.7707573506049812, 0.8629404043313116, 0.6238550366833806, 0.03696204905281775, 4.3095568008720875, 63.03568013012409, 66.11105650663376, 56.716516613960266, 29.47464220225811, 21.032640896737576, 26.574843004345894, 41.74595832824707, 54.41632144153118, 59.12478178739548, 28.168069012463093, 1.1016497109085321, 0.08062762863119133, 0.08295730440295301, 0.07187741808593273, 0.04569670789351221, 0.0348715229483787, 0.05033818852098193, 0.03891345957526937, 0.03656089225842152, 0.09035344424773939, 0.12010664184344932, 0.07499159590224735, 0.17182106530526653, 0.10657121893018484, 0.2674380212556571, 0.1870584554853849, 0.21573358710156754, 0.10428810550365597, 0.2866963972337544, 0.2281644567847252, 26.578781493008137, 88.82018074393272, 71.5776027739048, 59.82932098209858, 20.38834746927023, 34.05691131949425, 56.084241941571236, 66.57147020101547, 75.65134137868881, 85.15453264117241, 11.435581371188164, 0.3629366046516225, 0.2954581333324313, 4.885224010795355, 12.384814135730267, 1.4924094616435468, 53.3091938495636, 72.54648238420486, 76.17263540625572, 68.56748789548874, 56.140098944306374, 57.74493522942066, 64.6119837462902, 65.51961064338684, 71.10880672931671, 69.89100247621536, 69.44286972284317, 63.50567691028118, 63.018429055809975, 54.660135358572006, 55.83728939294815, 53.54371726512909, 52.439933493733406, 48.915907591581345, 49.53630410134792, 47.518547773361206, 48.55050779879093, 50.87241880595684, 51.95198267698288, 50.795271545648575, 50.313423201441765, 49.165687188506126, 52.87531793117523, 49.032675325870514, 52.656198889017105, 48.110312819480896, 51.006118431687355, 47.61739566922188, 48.87445941567421, 47.92914994060993, 48.59974555671215, 47.49369330704212, 48.67566168308258, 49.46277804672718, 46.64114825427532, 44.86258529126644, 48.87896217405796, 45.14995627105236, 47.461676225066185, 49.01938743889332, 48.10672581195831, 46.010180711746216, 49.371902123093605, 47.10445739328861, 48.932577297091484, 49.20126087963581, 46.71593204140663, 45.715381130576134, 48.85132625699043, 48.61962229013443, 49.097750633955, 49.951971396803856, 52.91448622941971, 54.07836377620697, 60.379930436611176, 58.04190069437027, 65.16100108623505, 48.315156027674675, 32.67914704978466, 60.84854029119015, 56.21160350739956, 60.787929743528366, 54.727140963077545, 58.157927468419075, 57.76204951107502, 56.14011414349079, 51.56536862254143, 44.691548869013786, 44.10983428359032, 47.72387735545635, 45.89625142514706, 46.61558322608471, 47.56953343749046, 45.09586237370968, 48.261217921972275, 46.59025378525257, 43.82731184363365, 46.91033720970154, 43.65784853696823, 45.8306897431612, 45.26092931628227, 47.75958023965359, 48.00069250166416, 48.47142644226551, 48.41142766177654, 48.28641436994076, 45.777063220739365, 47.68350452184677, 46.63060002028942, 46.67362131178379, 45.619390681385994, 45.28044506907463, 47.024882063269615, 47.389833480119705, 50.215092077851295, 47.714370265603065, 47.94312559068203, 45.15189416706562, 52.4312661588192, 59.102811366319656, 63.93229901790619, 57.497158125042915, 57.123288586735725, 62.50362128019333, 58.84597174823284, 61.76941707730293, 64.19104233384132, 57.77883321046829, 59.488342478871346, 55.65752863883972, 60.83362229168415, 61.91567122936249, 64.46845784783363, 63.35563816130161, 62.47666172683239, 64.8808953166008, 67.64052763581276, 69.03239294886589, 68.70852872729301, 71.33304789662361, 58.91132444143295, 1.7354401457123458, 3.151178271509707, 0.9969389671459794, 0.1001467953028623, 6.424619732424617, 69.75579053163528, 71.43387168645859, 73.30333337187767, 46.10970117151737, 26.371618509292603, 31.729093529284, 51.713100895285606, 64.14263293147087, 69.2087110877037, 35.16702935099602, 1.410005777142942, 0.23475869122194126, 0.16579424729570746, 0.09720191621454433, 0.15697503928095102, 0.09967342382878996, 0.13527928706025705, 0.17936943448148668, 0.1717849523993209, 0.27547328383661807], [0.013963422261440428, 0.05213638265558984, 0.0776177151419688, 0.03053272910619853, 0.02868188330467092, 0.025181267337757163, 0.06586714254808612, 0.07221413048682734, 0.10140540354768746, 0.054402341338573024, 33.40653821825981, 69.13489624857903, 52.16895863413811, 40.18604323267937, 19.778905771672726, 24.399824514985085, 37.005059123039246, 54.18651357293129, 65.1070211827755, 56.00564695894718, 1.2222893186844885, 0.03887015154759865, 0.2951331320218742, 0.6630103325005621, 2.8266801964491606, 7.075074529275298, 81.9708962738514, 66.06894716620445, 69.7877924144268, 60.941331312060356, 52.80124470591545, 48.29764276742935, 54.48955491185188, 58.00013713538647, 59.63691830635071, 58.511217311024666, 60.959072560071945, 57.94885128736496, 55.55004760622978, 52.75006905198097, 52.89106048643589, 47.358336970210075, 46.62433795630932, 45.519790425896645, 45.02983331680298, 45.95050871372223, 44.77216154336929, 44.96354967355728, 43.73461201786995, 42.9815836250782, 45.114097595214844, 45.3615403175354, 45.57601220905781, 48.33331145346165, 47.68173761665821, 42.77108632028103, 45.11486895382404, 44.02416028082371, 43.588418662548065, 43.64929519593716, 43.0899728089571, 43.124699145555496, 44.78600040078163, 43.22167754173279, 43.726282864809036, 40.91181568801403, 40.94353258609772, 43.61568979918957, 44.22612324357033, 43.26964996755123, 43.55386331677437, 44.04602810740471, 44.63970065116882, 44.4097787886858, 43.7195648252964, 44.026687145233154, 41.13083593547344, 42.10472747683525, 45.16071729362011, 43.773274943232536, 45.79306036233902, 42.516047805547714, 47.56068751215935, 51.92735619843006, 55.628315806388855, 50.950500816106796, 57.80980534851551, 44.976510778069496, 37.24731892347336, 59.11907449364662, 50.60284227132797, 56.03373885154724, 52.409371733665466, 52.836886793375015, 51.99595011770725, 54.682481959462166, 46.440241634845734, 41.60846650600433, 41.897289007902145, 41.6751529276371, 42.450809106230736, 43.083657547831535, 42.75513477623463, 41.547662168741226, 41.89758539199829, 38.95856469869614, 41.16075173020363, 41.924069970846176, 38.476655557751656, 40.647729858756065, 42.68493354320526, 41.134654730558395, 40.86012706160545, 41.82112969458103, 43.40660601854324, 44.14256952702999, 41.82008855044842, 43.034890964627266, 41.65600195527077, 42.77271643280983, 43.291475996375084, 42.703305557370186, 43.21967124938965, 43.08561824262142, 44.1820228099823, 42.9148668050766, 46.004777401685715, 45.159641951322556, 44.57692801952362, 47.235892340540886, 53.21320720016956, 50.199193730950356, 47.44333080947399, 52.91426584124565, 53.845474272966385, 59.4864159822464, 54.82724279165268, 57.839572951197624, 58.73947486281395, 53.928712606430054, 50.212329626083374, 54.78029631078243, 57.12608143687248, 56.83345153927803, 61.55144937336445, 62.186824679374695, 65.34358128905296, 63.59707720577717, 65.14644786715508, 61.56645856797695, 71.85463070869446, 11.142862178385258, 0.8153303840663284, 0.9487165859900415, 0.21476961148437113, 0.47144524462055415, 30.31398106366396, 67.71985977888107, 50.63386760652065, 48.03389132022858, 26.815531589090824, 30.85493143647909, 32.59474217891693, 38.69711212813854, 51.454532369971275, 38.04831214249134, 2.5947254430502653, 0.08568058561650105, 0.0894901632273104, 0.006527161449412233, 0.11969904691795819, 0.03758549763006158, 0.04076646873727441, 0.034455237473594025, 0.06813956162659451, 0.036310432260506786, 0.03144601418171078, 0.049774987492128275, 0.036081858197576366, 0.016171472088899463, 0.03610934734751936, 0.046250082887127064, 0.03225812040909659, 0.015990779538697097, 0.060928442908334546, 0.017301408624916803, 41.89735360443592, 78.42637807130814, 58.01596328616142, 43.31262946128845, 18.271591253578663, 22.7939185872674, 41.80629529058933, 59.64406572282314, 69.82223376631737, 60.572321712970734, 1.443389360792935, 0.0778535325662233, 0.7381913170684129, 2.1995979454368353, 0.985439537325874, 8.174546957015991, 83.5094565153122, 67.37965643405914, 73.33855748176575, 62.97944314777851, 56.539275124669075, 51.223250180482864, 57.9924501478672, 59.42530386149883, 63.88064458966255, 61.495303586125374, 61.33764244616032, 60.24645499885082, 57.591586858034134, 53.89614075422287, 55.10926365852356, 48.95120769739151, 49.6761479973793, 47.89004243910313, 47.00055956840515, 46.36090949177742, 46.57202236354351, 46.323603093624115, 46.26676194369793, 44.841192439198494, 48.02368886768818, 45.83014257252216, 48.249434754252434, 50.06886072456837, 49.76991556584835, 46.54985435307026, 47.32696205377579, 44.971039071679115, 45.50765387713909, 46.34260967373848, 45.991246327757835, 45.2213354408741, 46.17852307856083, 44.18560601770878, 45.468390583992004, 43.312511667609215, 43.2239194214344, 43.208298459649086, 45.55390879511833, 45.08565612137318, 45.19517004489899, 46.26306094229221, 47.11052946746349, 45.42049415409565, 44.973638132214546, 46.489259004592896, 44.40237678587437, 43.87669399380684, 44.85858030617237, 45.131918638944626, 48.00873287022114, 45.123205706477165, 51.0592357814312, 53.836084976792336, 57.25796476006508, 53.44149515032768, 59.87655244767666, 45.32454550266266, 39.44338068366051, 60.62448151409626, 54.48821738362312, 57.40125507116318, 56.175060868263245, 56.64102606475353, 54.811701625585556, 56.821998953819275, 46.36112228035927, 44.34873126447201, 43.402688428759575, 43.39598938822746, 44.19957406818867, 44.77896697819233, 43.85742902755737, 43.101296201348305, 44.293581023812294, 41.91492386162281, 42.843286246061325, 43.00714485347271, 41.364770382642746, 42.28507339954376, 44.15024131536484, 43.06994788348675, 44.60282742977142, 44.99459020793438, 45.4385431855917, 46.581449657678604, 44.3016441911459, 45.07796913385391, 42.95188821852207, 45.37339948117733, 44.43753629922867, 45.20927868783474, 44.80289429426193, 44.10185091197491, 45.90804599225521, 45.910439863801, 47.54147954285145, 46.65348619222641, 46.06630750000477, 48.74154634773731, 56.18979647755623, 52.81373843550682, 52.71666504442692, 55.212933495640755, 56.281306967139244, 60.19368723034859, 58.471186459064484, 58.5721280425787, 59.79619435966015, 55.12540519237518, 53.24793353676796, 55.67524328827858, 58.05249832570553, 56.453566923737526, 64.90359529852867, 65.33034279942513, 68.01222369074821, 65.30012682080269, 69.80790093541145, 62.18109458684921, 75.94867542386055, 13.466060366481543, 0.6446722790133208, 1.5871166484430432, 0.518848680658266, 0.4214973107445985, 30.962545461952686, 74.56852868199348, 58.12855884432793, 42.06923358142376, 28.65909956395626, 38.08705486357212, 38.98333936929703, 46.548786610364914, 58.9708786457777, 48.834717348217964, 3.4206512616947293, 0.051320413549547084, 0.06770388383301906, 0.007656446750843315, 0.07193100114818662, 0.03078733028814895, 0.012633064106921665, 0.025159214419545606, 0.028789713651349302, 0.031906153162708506, 0.13909570727264509, 0.07392216852167621, 0.20889346429612488, 0.16919876070460305, 0.2046653747675009, 0.1473468606127426, 0.14152943214867264, 0.12455605465220287, 0.1651295501505956, 0.24178767576813698, 53.2375904917717, 89.44705590605736, 68.34814086556435, 56.52936525642872, 29.86768551170826, 34.32912491261959, 52.07283519208431, 70.54483339190483, 74.74331930279732, 68.21385607123375, 2.0967571763321757, 0.18393729405943304, 1.5533231617882848, 8.013602793216705, 7.984655946493149, 8.856073636561632, 88.56836825609207, 69.79308933019638, 76.7183469235897, 66.76022127270699, 58.525158762931824, 53.67913819849491, 61.49448662996292, 61.008732095360756, 65.38676977157593, 63.48050706088543, 66.47087439894676, 63.1428761780262, 61.107465997338295, 56.519227400422096, 57.070429623126984, 52.159044966101646, 52.026086300611496, 50.80748409032822, 50.27209661900997, 51.699687615036964, 50.280999541282654, 49.24546770751476, 47.19879873096943, 46.261921003460884, 50.39190039038658, 47.46495924890041, 50.483760461211205, 53.39800268411636, 52.591473162174225, 48.45213867723942, 50.270770490169525, 48.59395086765289, 47.80893199145794, 48.40189777314663, 48.29340599477291, 48.769520446658134, 49.8123212903738, 47.1044459939003, 49.0053091943264, 45.127640068531036, 45.901738330721855, 45.7355010509491, 48.59409525990486, 47.69863910973072, 48.71224232017994, 49.12289768457413, 50.45754186809063, 48.042627051472664, 48.0084440857172, 49.54609617590904, 46.53497435152531, 47.969268187880516, 49.808000922203064, 48.40423084795475, 49.08338740468025, 48.51456552743912, 54.11801464855671, 56.420748084783554, 61.12774170935154, 54.84307274222374, 61.58033922314644, 49.167005717754364, 41.867696195840836, 61.53063029050827, 56.644920855760574, 60.58886222541332, 58.11073400080204, 58.83663944900036, 56.10994756221771, 59.71878871321678, 50.564848110079765, 45.68152874708176, 46.85687027871609, 46.56824916601181, 46.59360520541668, 46.691434755921364, 47.096664011478424, 44.27962817251682, 48.467630445957184, 42.991276904940605, 46.13044045865536, 44.94265839457512, 42.60364070534706, 45.50567418336868, 47.97798492014408, 46.296814531087875, 46.04944780468941, 46.666310504078865, 48.46882738173008, 49.736526757478714, 45.72774566709995, 47.38667584955692, 46.120200008153915, 49.002884924411774, 48.21053624153137, 46.474303007125854, 47.988517954945564, 47.03424096107483, 47.907654494047165, 47.12010495364666, 51.83181032538414, 49.396976977586746, 49.145327880978584, 52.297585532069206, 59.17439192533493, 55.09715750813484, 54.60286483168602, 60.58869123458862, 60.01086384057999, 63.37631285190582, 61.00408114492893, 61.721475049853325, 58.17067198455334, 56.78413778543472, 53.87517347931862, 54.12972941994667, 58.58609989285469, 56.343984603881836, 65.86475372314453, 67.02147245407104, 68.9497321844101, 68.53886783123016, 71.5386700630188, 64.89936232566833, 78.10599446296692, 13.489260971546173, 1.6922376514412463, 4.039328126236796, 0.31299481575842947, 0.48360364220570773, 39.055402502417564, 79.11712780594826, 67.23388865590096, 62.94095121324062, 37.01432682573795, 45.12361988425255, 49.07235659658909, 58.22235681116581, 69.99497249722481, 58.12949359416962, 4.817494545131922, 0.14405531692318618, 0.20468942035222426, 0.12114285069401376, 0.2368617002503015, 0.23316181206610054, 0.19498503796057776, 0.07417107000946999, 0.11150129852467217, 0.20151105418335646], [0.03633015112427529, 0.03937212910386734, 0.04076350014656782, 0.05386482604080811, 0.027120638369524386, 0.052358281100168824, 0.03563734884664882, 0.028671701038547326, 0.053986864804755896, 0.26842668070457876, 37.78507746756077, 66.2806262075901, 48.117661625146866, 41.518342941999435, 27.115466594696045, 46.098058596253395, 32.527276799082756, 59.474211037158966, 69.08068835735321, 42.78762303292751, 0.011715709279087605, 0.04749507272208575, 0.650096369208768, 0.3090057126246393, 0.31470439746044576, 25.14701832085848, 81.31631299853325, 65.31062185764313, 68.47868666052818, 59.84141193330288, 55.1654664427042, 45.21060101687908, 50.157475769519806, 53.33218641579151, 56.13732509315014, 54.9218425154686, 54.826304242014885, 54.64450679719448, 52.32875905930996, 51.85440011322498, 49.88876558840275, 49.22128960490227, 46.69488497078419, 44.74251553416252, 45.9027224779129, 45.577030554413795, 45.75893059372902, 45.39921149611473, 43.69962729513645, 43.02178926765919, 47.20049723982811, 45.07434792816639, 43.66289846599102, 43.880360797047615, 44.50355775654316, 44.384377151727676, 43.422986939549446, 43.66294026374817, 44.318382292985916, 43.758850917220116, 42.027751207351685, 42.790024504065514, 42.691427394747734, 42.11893871426582, 40.655477643013, 42.65847556293011, 42.50627852976322, 42.86196984350681, 45.42737938463688, 42.989202216267586, 43.032763078808784, 42.71022118628025, 42.59177014231682, 42.573398128151894, 44.46626275777817, 43.87583903968334, 41.53994098305702, 40.6601095944643, 42.63375788927078, 42.61148348450661, 43.50957669317722, 42.725549563765526, 47.44757138192654, 54.557704254984856, 56.856934279203415, 55.428693518042564, 54.581095799803734, 48.084740191698074, 39.403289034962654, 54.28889147937298, 50.24567283689976, 50.879205241799355, 51.04923851788044, 55.69657154381275, 53.86131942272186, 50.601379349827766, 43.6137443035841, 42.26623021066189, 42.328269481658936, 40.57934112846851, 41.34698733687401, 41.08064062893391, 42.06636093556881, 40.643227100372314, 41.56820006668568, 40.74707932770252, 42.62491196393967, 40.00250548124313, 41.02264814078808, 40.458089634776115, 40.30948340892792, 42.06245094537735, 42.75956533849239, 43.8565094769001, 42.66428925096989, 42.19708152115345, 40.492432191967964, 42.31003426015377, 40.95828339457512, 41.10588647425175, 44.231325164437294, 43.13484840095043, 41.85332536697388, 42.04883247613907, 42.827748879790306, 44.56458628177643, 45.809494480490685, 43.263513296842575, 44.700911566615105, 44.8673540353775, 49.92125004529953, 52.39413075149059, 49.20919105410576, 52.710197791457176, 53.28373521566391, 57.44771897792816, 57.03567288815975, 52.75915436446667, 56.389810144901276, 55.75079083442688, 49.625409319996834, 50.12219086289406, 57.04140678048134, 57.35224910080433, 58.62904518842697, 59.728994965553284, 64.77582335472107, 61.72671876847744, 67.04944655299187, 59.173529371619225, 73.546292334795, 36.907267570495605, 0.271029036375694, 0.880131097510457, 0.37635665328707546, 0.0592995215265546, 10.59675358235836, 64.97052490711212, 55.1718956977129, 52.56348006427288, 31.376527547836304, 17.243721708655357, 21.69565211981535, 41.875687167048454, 48.65529477596283, 47.42587834596634, 6.373009951785207, 0.3101973939919844, 0.02146145619917661, 0.08879208427970298, 0.04057700214616489, 0.02184630615374772, 0.020108782591705676, 0.0247605530967121, 0.014515213697450235, 0.012151813807577128, 0.021674051822628826, 0.0646211211278569, 0.04037093742226716, 0.047188020253088325, 0.027054043603129685, 0.028190639059175737, 0.01229392024470144, 0.05188839400943834, 0.0572121718141716, 0.4907925892621279, 46.61744512617588, 73.86878862977028, 56.837733909487724, 48.75891901552677, 36.0900492221117, 43.64394128322601, 37.695516273379326, 65.17814576625824, 76.23059749603271, 45.70269741117954, 0.04762773904076312, 0.050001680210698396, 1.0692308004945517, 0.685333184665069, 0.4786792251979932, 28.154575936496258, 82.26830631494522, 67.4564503133297, 68.83546471595764, 62.29421451687813, 58.84089522063732, 48.68554875254631, 51.03103369474411, 53.46888028085232, 59.5400957018137, 58.92478711903095, 58.7890812009573, 56.07055887579918, 55.16461908817291, 55.30269607901573, 52.112926840782166, 51.65841422975063, 48.018642738461494, 45.30557692050934, 48.417526334524155, 46.59605607390404, 48.077965155243874, 47.82345861196518, 46.90471351146698, 44.52998913824558, 48.05034063756466, 45.90003602206707, 46.726791858673096, 45.35575322806835, 46.32892660796642, 46.674575060606, 45.63598819077015, 47.28908948600292, 46.41113519668579, 46.17922984063625, 44.09430831670761, 44.766176864504814, 45.37221014499664, 44.7354669123888, 43.479736894369125, 42.903201431035995, 44.340470507740974, 44.74633812904358, 46.271937265992165, 44.78492505848408, 44.68816325068474, 44.94974121451378, 43.88685464859009, 45.24348445236683, 46.56585529446602, 46.13190717995167, 43.60560514032841, 42.94695608317852, 45.662928745150566, 46.047498509287834, 45.043550580739975, 44.47899207472801, 50.096204057335854, 57.65101566910744, 59.35055047273636, 57.68379271030426, 56.454140692949295, 51.64943911135197, 41.21941298246384, 56.679582595825195, 52.06745468080044, 53.55057969689369, 53.96468907594681, 58.39413799345493, 57.70896255970001, 52.51661337912083, 46.37652285397053, 44.628726840019226, 43.73863600194454, 43.333881720900536, 43.21052514016628, 42.38744370639324, 43.39896082878113, 41.72170042991638, 42.48941883444786, 44.01231251657009, 44.3362071365118, 42.61719457805157, 43.55004072189331, 42.85810925066471, 43.18585306406021, 42.464340180158615, 44.63371977210045, 45.20496591925621, 44.38403517007828, 44.281980246305466, 43.58887083828449, 43.89106102287769, 43.89670372009277, 43.188858702778816, 44.98953267931938, 43.86520341038704, 42.86122128367424, 43.699741289019585, 44.193775579333305, 44.1967698186636, 46.669817715883255, 45.929366648197174, 46.626701429486275, 47.45661489665508, 51.45765580236912, 55.318339839577675, 53.306754380464554, 54.92411479353905, 56.46915748715401, 59.74686160683632, 60.1781764626503, 55.202670246362686, 58.15462924540043, 56.11349277198315, 50.10202914476395, 52.824237272143364, 57.99895919859409, 54.483399242162704, 59.901802092790604, 60.83794265985489, 65.75133740901947, 62.96273924410343, 69.25980314612389, 61.355991661548615, 77.1968400478363, 40.501943081617355, 0.2923287934390828, 0.6836565246339887, 0.8291213284246624, 0.13730601815041155, 11.058056429028511, 69.24354001879692, 62.23480090498924, 49.94431100785732, 33.50492633879185, 27.738513462245464, 28.55609469115734, 53.10679391026497, 57.460953667759895, 57.07076780498028, 9.872220810502768, 0.2695182611932978, 0.03555403905920684, 0.029562046329374425, 0.03172059397911653, 0.015412650209327694, 0.022631218234892003, 0.05082371637399774, 0.04190371728327591, 0.022210251663636882, 0.10332810037652962, 0.1672069847700186, 0.08368705821339972, 0.22004034428391606, 0.08893788661225699, 0.13077082898234949, 0.1247769029578194, 0.2118276638793759, 0.18088118929881603, 0.9787429310381413, 62.12597854435444, 81.23541533946991, 65.21357506513596, 57.31770895421505, 40.43746814131737, 61.63866609334946, 49.43282425403595, 73.64383310079575, 80.8478893339634, 52.50692769885063, 0.20698454172816128, 0.175202319805976, 2.1297075832262635, 5.241850074380636, 3.6174989864230156, 29.34277217835188, 89.0904450416565, 70.70933416485786, 74.0670695900917, 64.15075689554214, 61.63260541856289, 49.91947554051876, 54.13963928818703, 58.584807962179184, 63.05524528026581, 62.607344314455986, 60.77312953770161, 58.23662504553795, 58.107025399804115, 58.07707920670509, 55.118417367339134, 53.87372575700283, 51.048600152134895, 48.21694649755955, 50.925589352846146, 48.913943096995354, 50.86036205291748, 50.69828175008297, 48.33220951259136, 46.10877402126789, 51.2618675082922, 47.64660470187664, 49.10579100251198, 49.14010316133499, 47.27338872849941, 49.91015464067459, 47.74217337369919, 49.67307396233082, 49.83920484781265, 47.59654998779297, 45.3709752112627, 48.87970693409443, 47.59762533009052, 46.635509356856346, 45.86520329117775, 46.02069094777107, 46.874516531825066, 47.14642234146595, 49.809938818216324, 47.19372220337391, 47.3802237957716, 46.523403972387314, 46.443011686205864, 47.63235546648502, 49.21637266874313, 49.734744653105736, 46.06430500745773, 44.187661707401276, 48.08110758662224, 47.34697178006172, 48.732673823833466, 45.89871749281883, 52.491348534822464, 60.85984468460083, 61.78998537361622, 58.554033413529396, 59.1061931848526, 53.95569495856762, 44.440956115722656, 59.09928135573864, 53.529042452573776, 55.250030905008316, 57.487400248646736, 60.76016843318939, 59.61216643452644, 56.02651163935661, 48.33023741841316, 48.47652576863766, 46.895970180630684, 44.86892335116863, 45.21142557263374, 44.42725785076618, 46.563244834542274, 44.027279913425446, 45.683542639017105, 45.91151140630245, 46.546985507011414, 44.90082263946533, 45.70804752409458, 45.62941454350948, 45.621852949261665, 45.74916511774063, 47.609264105558395, 48.47165063023567, 46.68068893253803, 46.015762612223625, 46.05384036898613, 48.231727704405785, 45.43309047818184, 45.50958797335625, 47.96123921871185, 46.305364072322845, 45.579663813114166, 47.080199494957924, 45.6490632891655, 48.32680240273476, 50.13810060918331, 49.057921171188354, 50.05979061126709, 50.851455330848694, 54.05482403934002, 60.322853699326515, 58.00869807600975, 57.611155807971954, 59.87698942422867, 63.7675778567791, 64.18740972876549, 58.59706990420818, 60.57466998696327, 56.65304481983185, 52.19590678811073, 56.60316489636898, 58.01314763724804, 56.69455759227276, 61.531595438718796, 65.66207259893417, 70.23077264428139, 66.10490083694458, 71.69012233614922, 64.93471562862396, 79.32334274053574, 42.74538829922676, 0.2967757423175499, 4.971077078953385, 1.6481679724529386, 0.19080573722021654, 15.435696076601744, 76.0535041987896, 68.27926576137543, 68.5833178460598, 42.99711339175701, 28.692549169063568, 36.09961710870266, 62.938378751277924, 66.82208195328712, 69.08066555857658, 12.833121679723263, 0.5177055357489735, 0.09446435607969761, 0.17516111576696858, 0.17268241674173623, 0.11778792759287171, 0.1061613456113264, 0.1944899364025332, 0.09645035068388097, 0.06804549440857954], [0.023717262301943265, 0.01209730027767364, 0.0713417210499756, 0.06747090883436613, 0.08130660469760187, 0.025149666689685546, 0.052471477174549364, 0.06890104967169464, 0.01957449934707256, 2.5058080768212676, 56.607413068413734, 61.81270815432072, 49.204103127121925, 17.43908252567053, 14.467515628784895, 29.14394024759531, 42.49154672026634, 60.67686170339584, 70.28887912631035, 20.96622996032238, 0.22202696971362457, 0.13435241882689297, 0.2813211997272447, 0.6873558042570949, 0.40832718776073307, 52.481685653328896, 73.10521200299263, 67.37783253192902, 66.73311352729797, 59.98344071209431, 56.16304211318493, 50.37615783512592, 47.369637563824654, 47.90207639336586, 49.69645790755749, 50.018384233117104, 51.004343926906586, 49.37245309352875, 49.181034564971924, 49.25641871988773, 47.08467185497284, 47.38764099776745, 43.80528822541237, 46.11541226506233, 43.40024895966053, 42.588114738464355, 43.63076739013195, 44.28446911275387, 43.150769546628, 44.90085683763027, 42.3088601231575, 43.09113934636116, 45.50700791180134, 44.974512085318565, 43.44200871884823, 43.98789122700691, 42.173461988568306, 43.39228838682175, 42.24309325218201, 43.07823903858662, 42.22492262721062, 40.687905102968216, 42.074777483940125, 44.475359469652176, 41.65039345622063, 40.77595017850399, 40.97735837101936, 41.44762113690376, 41.959605664014816, 42.11395338177681, 43.78410816192627, 43.96551422774792, 42.723687663674355, 43.575499355793, 42.29489967226982, 41.052495539188385, 40.939501002430916, 41.839938685297966, 42.16577120125294, 43.31390239298344, 41.73268184065819, 39.05700221657753, 43.213355988264084, 52.03102223575115, 52.36169949173927, 54.527913853526115, 53.57839420437813, 49.82962176203728, 38.749321326613426, 55.46637609601021, 51.980997920036316, 47.40055650472641, 43.85138735175133, 48.79518806934357, 43.28764960169792, 42.68969088792801, 41.104161366820335, 43.35921876132488, 40.76398082077503, 41.73387497663498, 39.81823056936264, 41.858075112104416, 40.376823395490646, 41.44334636628628, 40.259394496679306, 40.467402935028076, 43.13970074057579, 41.96731925010681, 39.7112625092268, 41.85963302850723, 40.71776770055294, 42.09797143936157, 41.44316777586937, 41.55371144413948, 41.80561512708664, 41.68900318443775, 41.139507070183754, 43.4136888384819, 41.91169023513794, 43.10631953179836, 44.246957525610924, 43.192837089300156, 41.68459162116051, 42.51461148262024, 42.56591632962227, 43.123171627521515, 40.62346816062927, 42.73183062672615, 44.39876697957516, 44.843483716249466, 47.98196330666542, 55.96516013145447, 49.70013611018658, 49.827828258275986, 51.02865882217884, 55.28622016310692, 58.030638098716736, 57.887260392308235, 55.80338381230831, 53.5608771443367, 54.50705677270889, 52.31010966002941, 49.51537482440472, 51.59456245601177, 52.75201454758644, 53.062328696250916, 60.72403237223625, 62.648974880576134, 63.31113114953041, 63.916757851839066, 66.06858998537064, 61.80986970663071, 2.438827883452177, 0.7170570886228234, 1.5359838609583676, 0.11327352491207421, 3.6114641977474093, 52.792166993021965, 62.263409569859505, 51.18406668305397, 36.210498958826065, 14.918559975922108, 16.205436922609806, 30.051394253969193, 45.35810150206089, 54.1818892210722, 21.49048212915659, 0.36171983869280666, 0.023718145457678474, 0.057264623101218604, 0.027823214732052293, 0.06815959961386397, 0.06424566119676456, 0.019150900006934535, 0.05062458702013828, 0.06938511549378745, 0.040232957326225005, 0.039075867462088354, 0.05851145717315376, 0.007072043026710162, 0.023631516414752696, 0.06534076688694768, 0.022714442675351165, 0.07335202841204591, 0.06310073513304815, 4.266587281599641, 68.34478944540024, 66.65666922926903, 56.68980024755001, 25.291461870074272, 16.886269189417362, 27.586270831525326, 46.84076674282551, 65.70469111204147, 76.87649443745613, 22.852327153086662, 0.24193671386456117, 0.10388598020654172, 0.7637144881300628, 0.5205017107073218, 0.9011201024986804, 54.53985661268234, 76.30410835146904, 69.97623190283775, 67.95071259140968, 62.66765847802162, 57.12698198854923, 52.44272634387016, 49.485386833548546, 50.67992493510246, 52.97847859561443, 52.27324403822422, 52.189082354307175, 52.96081714332104, 50.46507306396961, 51.480344384908676, 50.19671246409416, 50.613006725907326, 48.323173597455025, 47.953035458922386, 45.39683282375336, 44.38426695764065, 44.84799787402153, 45.28146341443062, 45.19472546875477, 46.9355184584856, 45.80552749335766, 43.95413763821125, 47.74886101484299, 46.3825873285532, 46.64776749908924, 44.17330227792263, 45.243636444211006, 45.98023071885109, 44.30851802229881, 45.237959548830986, 44.472262635827065, 44.373768121004105, 44.2995049059391, 45.61085253953934, 44.54513892531395, 43.59399676322937, 43.51580075919628, 42.96277083456516, 44.40485045313835, 43.92257273197174, 46.015086248517036, 45.58662123978138, 45.379988327622414, 44.47375975549221, 45.67078672349453, 44.4308752566576, 43.4846044331789, 43.705152198672295, 43.61639276146889, 45.013923570513725, 42.8997778147459, 42.79334172606468, 44.65284414589405, 55.60646317899227, 57.28935867547989, 56.87465652823448, 55.50425626337528, 52.4774868786335, 41.983263194561005, 57.3274440318346, 54.90774907171726, 49.73203159868717, 46.01749911904335, 50.81757254898548, 47.20856420695782, 43.6595356464386, 44.944961071014404, 45.17636865377426, 43.65937985479832, 43.15784476697445, 43.12593027949333, 43.031615540385246, 42.84367762506008, 44.621651619672775, 41.624212861061096, 41.8470823019743, 44.21027809381485, 43.76799702644348, 41.645324528217316, 42.27212369441986, 42.28307470679283, 44.27131801843643, 43.34613226354122, 44.74786564707756, 45.71562811732292, 44.407358318567276, 44.7094801068306, 45.17017878592014, 42.808548510074615, 44.849160611629486, 44.95535351336002, 44.39370185136795, 43.27609062194824, 45.566748306155205, 45.739228650927544, 45.46817399561405, 43.611589819192886, 44.21185500919819, 45.96445396542549, 45.85414208471775, 50.054607689380646, 58.308456391096115, 53.95103640854359, 51.89662344753742, 53.148800656199455, 60.259628891944885, 60.37169247865677, 59.87137712538242, 58.54549527168274, 57.192422077059746, 53.8924815505743, 52.73258239030838, 51.4468377828598, 51.61649487912655, 54.5790933072567, 54.45653088390827, 63.72057057917118, 65.46704426407814, 65.26513069868088, 66.86698034405708, 69.57115083932877, 67.55162000656128, 3.468294767662883, 0.9429347806144506, 2.5342462258413434, 0.19253871141700074, 3.475284017622471, 56.03346526622772, 68.96206632256508, 55.389137640595436, 34.36535216867924, 20.131371058523655, 23.80331352353096, 36.37745440006256, 53.07575337588787, 62.59430721402168, 28.377067297697067, 0.6336024042684585, 0.047821847765590064, 0.03062258278077934, 0.05001805940992199, 0.04950701280904468, 0.07035010785330087, 0.030988437465566676, 0.08644444853416644, 0.06011913457768969, 0.07654723391169682, 0.1278193373582326, 0.14247816405259073, 0.14679921499919146, 0.12673191289650276, 0.17779248941224068, 0.16926542040891945, 0.17078670440241694, 0.21572689292952418, 6.678625177592039, 79.8638105392456, 76.08486011624336, 66.72754302620888, 29.790494553744793, 22.412407658994198, 39.19525019824505, 58.513618782162666, 71.10114634037018, 83.21717619895935, 26.07374109327793, 0.3405361238401383, 0.3360523347510025, 1.5524091920815408, 4.335422962903976, 0.7303222955670208, 58.913744911551476, 79.15044441819191, 73.65017116069794, 71.0082945227623, 65.72193458676338, 60.56474111974239, 54.62888963520527, 52.5672722607851, 51.79581105709076, 55.36892652511597, 53.21899428963661, 56.53113216161728, 55.83116412162781, 53.98365765810013, 53.98784123361111, 52.494779750704765, 53.068674355745316, 50.78252322971821, 51.29369460046291, 47.50183247029781, 46.416310518980026, 47.48575933277607, 47.259781658649445, 47.61092461645603, 49.98028367757797, 46.254462003707886, 46.73990495502949, 48.69553081691265, 47.85053975880146, 47.6079797744751, 47.352762669324875, 48.92381116747856, 48.31540301442146, 45.986811965703964, 48.08695167303085, 47.770983427762985, 46.2687948346138, 46.884403601288795, 48.87120679020882, 46.94116875529289, 45.53550258278847, 44.81448367238045, 43.582912757992744, 44.72432591021061, 46.46500110626221, 49.56756882369518, 48.25779050588608, 47.21546083688736, 48.06854926049709, 47.055101841688156, 46.63496978580952, 46.60744786262512, 46.58311016857624, 46.12059138715267, 48.43789704144001, 45.91123402118683, 42.774418741464615, 47.12645061314106, 57.60077476501465, 58.04060876369476, 58.72659735381603, 57.267316058278084, 55.10626561939716, 44.28822711110115, 60.45254074037075, 58.54954585433006, 53.38214233517647, 48.634460493922234, 54.64926414191723, 49.554227739572525, 46.483376920223236, 45.823713317513466, 47.80134379863739, 44.54505912959576, 47.00698882341385, 45.82313194870949, 46.92444205284119, 45.464480593800545, 47.38807037472725, 43.45704451203346, 44.86541993916035, 46.441058591008186, 45.867000594735146, 43.75038497149944, 45.814844593405724, 45.329755023121834, 47.50665821135044, 44.862520694732666, 46.87684580683708, 48.12453545629978, 46.71642601490021, 45.84624230861664, 47.70134076476097, 44.496866315603256, 47.43573881685734, 48.02794463932514, 47.83843740820885, 45.1791463047266, 48.08469459414482, 47.89689727127552, 47.78920345008373, 45.74182391166687, 46.75163492560387, 48.47062848508358, 49.29684855043888, 52.18858078122139, 61.505578234791756, 58.514097556471825, 55.86299501359463, 58.34888622164726, 61.872038170695305, 64.08877462148666, 62.035129219293594, 60.94769977033138, 60.81941865384579, 55.56343048810959, 54.02752250432968, 52.248868346214294, 54.666883796453476, 57.65084847807884, 57.08560600876808, 65.37578836083412, 69.31041643023491, 66.83974340558052, 70.59044614434242, 72.13098987936974, 69.1391596198082, 2.9614665638655424, 4.211570983752608, 2.6346404012292624, 0.2216367781511508, 5.163691593334079, 64.65921521186829, 74.74851742386818, 68.99847596883774, 48.67504991590977, 24.774199426174164, 28.60804170370102, 47.086579352617264, 64.294693171978, 73.90966683626175, 35.0389838218689, 1.008335743099451, 0.17729553248500451, 0.08599289620178752, 0.15823954017832875, 0.20673881663242355, 0.22010412445524707, 0.13236692146165296, 0.24586806306615472, 0.20752463227836415], [0.07282726321136579, 0.01679397999396315, 0.022890845611982513, 0.02126181476342026, 0.07741657085716724, 0.01727935941744363, 0.07637196089490317, 0.0917572907928843, 0.015166327684710268, 8.80434226244688, 59.63010147213936, 54.02532622218132, 38.44765171408653, 34.306611120700836, 47.83845640718937, 41.317709907889366, 46.59775838255882, 61.682990714907646, 63.562301471829414, 5.874996325001121, 0.02124571201420622, 0.02427908479148755, 0.13545382535085082, 0.7010202866513282, 9.714814256876707, 68.60325917601585, 67.2824652493, 68.66642698645592, 61.434525847435, 62.084556967020035, 56.49210065603256, 51.211820393800735, 48.96564692258835, 46.13234035670757, 44.83422361314297, 46.22455380856991, 44.91146206855774, 45.101904049515724, 44.44474071264267, 44.04034361243248, 44.573819786310196, 43.37707780301571, 42.119428887963295, 42.54102386534214, 42.29098588228226, 43.896988704800606, 41.9862612336874, 43.96836407482624, 42.623445242643356, 44.31278899312019, 43.732643723487854, 43.51002126932144, 44.17565815150738, 46.31402000784874, 43.74140225350857, 42.921535447239876, 43.29342529177666, 42.38329812884331, 42.928489074110985, 42.61280961334705, 43.058472499251366, 42.17534288764, 40.4699981957674, 44.60222326219082, 41.84351049363613, 42.516674771904945, 41.74132637679577, 42.009819969534874, 43.97216387093067, 41.33752964437008, 41.77674047648907, 41.1674165725708, 38.96885074675083, 41.13607205450535, 41.69646218419075, 41.39128915965557, 38.225796818733215, 40.97746856510639, 39.96600084006786, 42.43784040212631, 40.6075394153595, 42.41503402590752, 42.54912503063679, 49.42174404859543, 54.64095398783684, 55.310322269797325, 55.070148557424545, 54.893241450190544, 39.333186596632004, 51.562879756093025, 52.77482472360134, 47.13973090052605, 43.47821317613125, 42.58126750588417, 42.215119153261185, 41.742891892790794, 42.108082696795464, 40.10221213102341, 41.98748476803303, 39.54173840582371, 39.412492141127586, 38.12612056732178, 41.304820999503136, 40.35396382212639, 40.62026113271713, 40.990034490823746, 41.373095735907555, 42.180183827877045, 41.092070415616035, 40.800599455833435, 38.943848088383675, 41.046776846051216, 40.09692661464214, 43.049656972289085, 40.68782530725002, 43.08977521955967, 40.85637666285038, 42.04560644924641, 41.090808883309364, 44.43054087460041, 41.29101254045963, 41.51040896773338, 42.99574926495552, 42.92260318994522, 41.84241235256195, 43.09592708945274, 42.75851659476757, 43.76324348151684, 43.65643121302128, 43.994411677122116, 48.99280026555061, 53.945006132125854, 50.39207898080349, 50.67787304520607, 50.83117201924324, 57.720840722322464, 58.33368323743343, 59.197601079940796, 58.64495873451233, 58.991830721497536, 55.55841475725174, 56.42712414264679, 56.52296259999275, 58.6492221057415, 63.60793322324753, 67.74195939302444, 60.80222837626934, 58.930509611964226, 55.484440326690674, 66.00112840533257, 61.82001896202564, 81.18859425187111, 14.871503300964832, 0.6288445845711976, 2.366930041462183, 0.06796698260586709, 0.9750078502111137, 37.71960698068142, 66.72166854143143, 51.72000132501125, 52.884676828980446, 35.66267475485802, 12.910281289368868, 29.559457451105118, 46.34932391345501, 52.06968516111374, 37.49450705945492, 1.882620023097843, 0.07758317558909766, 0.04530710633844137, 0.03417513238673564, 0.020180639185127802, 0.026204906062048394, 0.027294690553389955, 0.02526889456930803, 0.11189646247657947, 0.023205171128211077, 0.030756750093132723, 0.023663096653763205, 0.0830072806274984, 0.06927255395567045, 0.02907789144956041, 0.048118242993950844, 0.11313441675156355, 0.0818965230428148, 12.450494561344385, 71.48057878017426, 59.75437380373478, 49.826661720871925, 42.830165550112724, 44.83144976198673, 39.600965827703476, 54.80483919382095, 66.09512776136398, 73.38546216487885, 8.035227432847023, 0.1269327529007569, 0.06966869754251093, 1.3622644264250994, 0.4270290123531595, 11.248151678591967, 71.97595819830894, 68.62271413207054, 72.1499128639698, 63.511528596282005, 64.52418565750122, 58.491716757416725, 54.239057153463364, 50.91355159878731, 50.04180997610092, 46.36269919574261, 49.54830385744572, 46.82691648602486, 48.1818325817585, 47.47794695198536, 45.97623333334923, 46.91454358398914, 46.335435658693314, 44.72594082355499, 43.859146535396576, 45.39105713367462, 47.611844167113304, 43.53702262043953, 46.47947072982788, 45.358508080244064, 45.776687040925026, 44.94385153055191, 45.16441449522972, 45.65388523042202, 46.5948211401701, 44.569343626499176, 44.054566249251366, 43.90619181096554, 44.133286625146866, 44.42151255905628, 44.68983136117458, 44.21912021934986, 43.024350330233574, 42.36773036420345, 43.52837048470974, 43.40850591659546, 45.08875295519829, 43.58452007174492, 43.760994002223015, 45.488730892539024, 42.78721645474434, 44.22041594982147, 44.63269762694836, 41.51569828391075, 44.27546739578247, 43.469523042440414, 44.45475697517395, 43.05428892374039, 43.12639385461807, 44.382120072841644, 44.612927287817, 43.7639806419611, 45.709552243351936, 46.25151336193085, 51.29283964633942, 56.90013036131859, 55.14690823853016, 57.25267544388771, 56.62353180348873, 42.78918854892254, 56.06490097939968, 56.04398690164089, 52.06866301596165, 45.47160901129246, 44.81245458126068, 44.182463586330414, 43.48861321806908, 43.3484273403883, 43.17271716892719, 42.77486331760883, 42.96738758683205, 41.69387832283974, 41.130915731191635, 42.03123182058334, 42.5981006026268, 42.32047230005264, 43.582414984703064, 44.78148624300957, 43.138264417648315, 43.34981046617031, 42.49234087765217, 42.05508694052696, 42.392041459679604, 42.33847953379154, 45.05673587322235, 41.84458203613758, 44.5309466868639, 43.778461664915085, 43.207774087786674, 43.53079095482826, 45.28509981930256, 43.632952272892, 45.117091834545135, 45.08662506937981, 44.95036818087101, 43.293330296874046, 45.75755126774311, 44.73254106938839, 46.50892294943333, 45.86869530379772, 46.31053179502487, 50.787614956498146, 56.39112867414951, 53.798421397805214, 53.190860599279404, 52.33574688434601, 58.283674120903015, 59.474279433488846, 61.59362331032753, 59.53736364841461, 60.425319001078606, 58.1840168684721, 58.26906770467758, 58.97476963698864, 60.93609519302845, 65.19640758633614, 70.83930239081383, 63.028718903660774, 60.195476934313774, 58.50308954715729, 68.05385425686836, 64.11767587065697, 82.99976706504822, 16.991609036922455, 0.4956634825794026, 6.947942851111293, 0.1028985898301471, 0.7411222660448402, 41.01604789495468, 73.11743974685669, 58.79199184477329, 49.30530309677124, 35.68499855697155, 20.056423880159855, 36.25546954572201, 54.14423704147339, 60.35692647099495, 45.3766331076622, 2.3761675832793117, 0.13772816659184173, 0.08680358121637255, 0.04402468999614939, 0.09199337539030239, 0.06405384570825845, 0.0821051407547202, 0.05326029109710362, 0.06978390854783356, 0.24309452361194417, 0.11571661569178104, 0.15708924096543342, 0.1614020243869163, 0.23221932904561982, 0.10948092021862976, 0.23536484775831923, 0.23707120853941888, 0.15902180835837498, 18.528512567281723, 81.43192559480667, 68.70149150490761, 55.55780678987503, 46.86062067747116, 58.830008804798126, 56.14695757627487, 64.30613055825233, 70.98057121038437, 80.24948984384537, 8.218897227197886, 0.30499689804855734, 0.1925150814349763, 3.109957608394325, 3.2401369605213404, 11.4838264323771, 74.23318907618523, 71.55329167842865, 76.1318787932396, 66.78270846605301, 68.42548951506615, 62.23800413310528, 57.80674271285534, 54.4050170481205, 52.31603354215622, 49.61658239364624, 51.43150560557842, 49.832646399736404, 50.824469178915024, 50.78649401664734, 48.57358016073704, 49.858287423849106, 49.86141085624695, 47.4701763689518, 46.480340883135796, 47.55854442715645, 49.09767843782902, 46.432721838355064, 49.31798301637173, 48.11518795788288, 48.25456827878952, 47.434750869870186, 46.74675218760967, 48.01003240048885, 50.441879108548164, 47.483680844306946, 47.25719779729843, 48.753895685076714, 44.94814909994602, 46.94147653877735, 47.449619472026825, 47.45819181203842, 46.29279814660549, 43.77459727227688, 46.8612552434206, 46.61553002893925, 47.86013424396515, 46.17265619337559, 46.17799870669842, 48.30057621002197, 46.12823657691479, 47.01520778238773, 46.499172672629356, 42.64090150594711, 44.85658921301365, 45.635752603411674, 46.46208666265011, 43.85984569787979, 45.990155786275864, 46.14864908158779, 47.45889477431774, 46.97826236486435, 49.573523104190826, 49.92857985198498, 55.44398009777069, 60.42998135089874, 58.860885947942734, 60.685232654213905, 59.963373988866806, 45.17153911292553, 58.08329567313194, 59.638400226831436, 52.89277419447899, 46.92967437207699, 45.28326451778412, 46.39225400984287, 45.35057790577412, 46.24030016362667, 43.987021073699, 46.60894118249416, 45.24195693433285, 43.738886788487434, 42.91714668273926, 46.0764529556036, 44.40296955406666, 44.50972482562065, 45.13167925179005, 45.70199824869633, 46.8645990639925, 46.15485414862633, 45.899542048573494, 43.57951574027538, 45.93321204185486, 44.201888144016266, 48.32797273993492, 43.978391736745834, 47.39457942545414, 44.96903657913208, 46.601577177643776, 44.03425253927708, 48.490706607699394, 45.893188789486885, 46.908285319805145, 47.54762381315231, 49.178959876298904, 45.40806122124195, 48.83142672479153, 46.9635571539402, 47.91889809072018, 48.46403203904629, 48.54341357946396, 55.12940637767315, 59.11060854792595, 55.032135397195816, 57.94083371758461, 56.511346623301506, 62.273870408535004, 62.33464814722538, 64.98324662446976, 62.959551215171814, 63.95753726363182, 59.04873266816139, 59.11073014140129, 58.270682618021965, 62.96531930565834, 67.04247012734413, 74.05767649412155, 65.84306448698044, 63.1320695579052, 61.994953975081444, 73.24182987213135, 67.20834642648697, 86.73071846365929, 17.757201455533504, 1.6749864583835006, 7.7870280761271715, 0.1512936464860104, 1.618909186217934, 47.953206449747086, 80.68649679422379, 67.73873716592789, 66.91333785653114, 46.25754363834858, 24.064672999083996, 46.21899090707302, 65.02190575003624, 69.96337339282036, 56.440222039818764, 3.311171536333859, 0.2588601299794391, 0.12371473378152587, 0.13273236982058734, 0.27118839032482356, 0.14502940059173852, 0.1963979980791919, 0.1541890762746334, 0.29274745378643274], [0.051007297734031454, 0.11648215586319566, 0.07688830271945335, 0.11309601060929708, 0.06952160387299955, 0.07570170506369323, 0.04412647555000149, 0.1695058317272924, 0.0770922820083797, 17.00615655630827, 63.71084690093994, 46.227422654628754, 29.12811789661646, 24.713984057307243, 31.111668460071087, 33.10720548033714, 55.994099378585815, 67.05970600247383, 54.18836787343025, 3.037725384347141, 0.14063992362935096, 0.1811141791404225, 0.36705991777125746, 3.81509764585644, 35.07608503103256, 69.57894802093506, 68.63561823964119, 68.26891511678696, 61.24073624610901, 61.342433989048004, 55.12539379298687, 49.8286110162735, 47.99270153045654, 46.85623951256275, 45.833110213279724, 43.59441094100475, 43.63031521439552, 44.380174577236176, 44.93488781154156, 44.37651917338371, 44.910284131765366, 44.56274338066578, 44.48411040008068, 43.28755080699921, 42.68458016216755, 43.05909186601639, 44.02442626655102, 42.55249164998531, 42.09882639348507, 45.33261626958847, 43.68549585342407, 44.285050481557846, 43.58426548540592, 43.050694316625595, 43.71137626469135, 44.276500940322876, 42.67663858830929, 41.58585771918297, 42.48734034597874, 42.4847336858511, 42.71721661090851, 42.094175443053246, 41.885764226317406, 42.28248953819275, 43.754484951496124, 40.8696873486042, 41.41128368675709, 43.334292098879814, 42.74103373289108, 42.6879695802927, 42.278104573488235, 41.842195764184, 40.5304491519928, 40.273970514535904, 41.21868722140789, 42.639795765280724, 41.66264779865742, 42.39531308412552, 40.92528976500034, 42.047491148114204, 43.7879953533411, 42.0016124099493, 42.72577375173569, 43.284795954823494, 48.57502408325672, 53.43209445476532, 54.10984508693218, 52.22780607640743, 38.51920947432518, 53.12081515789032, 53.11029352247715, 50.247557535767555, 41.850692108273506, 42.20894068479538, 40.931867212057114, 40.26092581450939, 41.142733097076416, 40.84666818380356, 41.44795551896095, 38.5057619959116, 40.477726981043816, 39.504922181367874, 41.09154984354973, 40.22735081613064, 39.85927976667881, 40.373384580016136, 41.98568746447563, 41.16928607225418, 39.91221472620964, 41.38452172279358, 40.28080254793167, 41.24312750995159, 42.15765483677387, 41.496596708893776, 41.22735075652599, 42.72094041109085, 41.17551013827324, 44.13397438824177, 41.74970492720604, 41.77609831094742, 41.58373363316059, 42.41311512887478, 40.79390801489353, 42.21798039972782, 42.26887866854668, 43.04182559251785, 42.29537084698677, 43.06283466517925, 42.788610979914665, 43.062150701880455, 46.24321460723877, 53.481225818395615, 52.84732103347778, 49.92094986140728, 53.486192151904106, 53.63504156470299, 56.4622912555933, 57.14449904859066, 54.95420157909393, 60.03039859235287, 57.381537929177284, 62.242195308208466, 62.42437273263931, 61.86351902782917, 60.61620935797691, 61.51696242392063, 55.895065292716026, 57.00798757374287, 54.47249382734299, 62.30572409927845, 63.13143499195576, 75.84130078554153, 39.637170284986496, 0.12063514746841975, 3.4887673566117883, 0.12173941868240945, 0.06455268026911654, 28.163414262235165, 69.9857085943222, 55.329986214637756, 55.85793748497963, 34.18075427412987, 17.91949264705181, 28.39936450123787, 40.26414804160595, 51.45902372896671, 46.758390963077545, 6.578436903655529, 0.1605046639451757, 0.13855509721906856, 0.019862443368765526, 0.1043627284525428, 0.057596251790528186, 0.08314281905768439, 0.02983616228448227, 0.04811401646293234, 0.06306363517069258, 0.08527966259862296, 0.047124844932113774, 0.05875303366337903, 0.0664408078591805, 0.10425521351862699, 0.043445410337881185, 0.28567980334628373, 0.09028108484926634, 23.758151046931744, 72.04870909452438, 54.66329678893089, 33.05924445390701, 29.692345820367336, 28.58794078230858, 30.208975598216057, 64.48773041367531, 70.55288895964622, 59.035589173436165, 2.553186547011137, 0.11691028601489961, 0.3370701754465699, 1.6323893191292882, 4.510727506130934, 38.59273172914982, 69.984500259161, 70.87172985076904, 71.43257975578308, 64.90157380700111, 64.23807621002197, 57.4433796107769, 52.33406737446785, 51.509637013077736, 48.75249736011028, 48.43882419168949, 45.98310336470604, 48.16575184464455, 45.41718453168869, 47.28421434760094, 45.2642997354269, 47.674856185913086, 46.70439966022968, 46.75127774477005, 45.89115209877491, 44.65707331895828, 45.03858424723148, 44.97183322906494, 44.89283926784992, 45.14284685254097, 46.69880636036396, 44.845687597990036, 45.78959874808788, 45.48708938062191, 45.19862025976181, 45.93993008136749, 45.715278536081314, 45.00495985150337, 43.77476066350937, 44.559103175997734, 43.55169363319874, 43.731108605861664, 43.88401240110397, 44.09091889858246, 44.00112971663475, 45.97688689827919, 42.35501244664192, 43.98854099214077, 44.16977986693382, 45.378574803471565, 45.31289152801037, 44.036908596754074, 43.2131963968277, 41.38883829116821, 42.95043669641018, 43.19266229867935, 42.181718945503235, 43.18639263510704, 43.77596899867058, 43.60154315829277, 44.70649726688862, 43.88795278966427, 43.73340368270874, 44.46138761937618, 45.11424958705902, 50.809026807546616, 55.59359326958656, 56.4050967246294, 56.1077930778265, 39.62476395070553, 54.49795626103878, 54.95324023067951, 52.78763763606548, 45.82060508430004, 43.45349170267582, 44.05745409429073, 43.51235814392567, 42.459761425852776, 42.55507931113243, 43.949289098381996, 41.7182844132185, 43.31963628530502, 42.73385211825371, 42.83488109707832, 42.390601336956024, 41.819769367575645, 40.350779592990875, 45.32041132450104, 43.32143358886242, 43.29155579209328, 42.9575727134943, 43.22673887014389, 43.33146885037422, 43.38381864130497, 44.200147837400436, 43.87815311551094, 43.95917996764183, 45.032633766531944, 43.314476162195206, 43.54910597205162, 42.38302834331989, 44.7395820915699, 45.09215757250786, 42.945348769426346, 44.333661273121834, 44.300055876374245, 44.61004704236984, 44.54391539096832, 45.54460309445858, 44.546848833560944, 45.86067393422127, 48.81994754076004, 54.3328171223402, 54.23088759183884, 51.483388021588326, 56.210691556334496, 56.00973553955555, 60.47978527843952, 58.90745624899864, 58.18139120936394, 63.36726553738117, 59.69349727034569, 62.119397297501564, 64.91393834352493, 63.878889083862305, 63.36519464850426, 64.43485245108604, 58.11312027275562, 59.10719633102417, 56.10456325113773, 64.1237935423851, 66.10613197088242, 78.4883451461792, 44.23539474606514, 0.0892236505751498, 5.227649761363864, 0.15321678860345855, 0.12856966350227594, 29.951839596033096, 75.33702224493027, 59.75581392645836, 57.82193809747696, 39.97244529426098, 26.706222854554653, 36.65754497051239, 49.19884420931339, 58.95880289375782, 56.73420466482639, 8.697052169591188, 0.16199808771489188, 0.10543284603045322, 0.0620444771629991, 0.0744889689667616, 0.0519302548491396, 0.21270575816743076, 0.033305320466752164, 0.04671333517762832, 0.21086714667035267, 0.2553674642695114, 0.17817681800806895, 0.14676035614684224, 0.2438047737814486, 0.16669334436301142, 0.2650032128440216, 0.3366020286921412, 0.21774084423668683, 32.40994289517403, 84.54501494765282, 63.21644023060799, 44.45365883409977, 34.667720943689346, 36.38171397149563, 46.313176453113556, 70.88032498955727, 78.73739138245583, 64.83713686466217, 4.030311210080981, 0.1850529943476431, 0.9711806243285537, 4.3237818125635386, 5.377994868904352, 41.87738947570324, 70.86729928851128, 74.3974694609642, 73.56545090675354, 65.41105806827545, 66.03421702980995, 59.91837300360203, 53.92153859138489, 52.95540243387222, 49.766917526721954, 49.77383695542812, 48.813427090644836, 51.4276260137558, 48.42757299542427, 50.717546716332436, 47.30774648487568, 50.103674456477165, 50.28212808072567, 50.56439593434334, 47.98351362347603, 46.690192222595215, 47.83789403736591, 48.43486860394478, 47.332380563020706, 47.59420171380043, 49.962029457092285, 47.371860444545746, 47.59394712746143, 46.110757514834404, 48.76344837248325, 49.988415241241455, 48.42872433364391, 47.46754691004753, 46.19777664542198, 47.779137790203094, 45.934298783540726, 46.28064639866352, 46.397425532341, 48.179925084114075, 46.40237666666508, 50.328884571790695, 44.698563292622566, 45.07731556892395, 47.22519211471081, 47.195443511009216, 46.41862079501152, 46.6531366109848, 47.30399988591671, 45.18963374197483, 45.75517639517784, 46.63417562842369, 45.9274173527956, 45.48760235309601, 47.399891540408134, 46.38587795197964, 46.660238429903984, 46.739825159311295, 46.131398007273674, 45.26877209544182, 48.03743273019791, 53.765484765172005, 58.91438327729702, 60.47726221382618, 56.485963985323906, 44.67296406626701, 56.899355202913284, 58.25513005256653, 55.44884383678436, 48.24423663318157, 45.71228429675102, 46.66823700070381, 46.03867918252945, 45.10498188436031, 44.69838850200176, 46.58154845237732, 42.7007444947958, 45.07556766271591, 45.42608365416527, 44.064031541347504, 43.644499853253365, 44.14048723876476, 42.905671298503876, 47.768410965800285, 46.278651505708694, 45.951971635222435, 45.860533341765404, 45.41275396943092, 45.94241514801979, 46.25921554863453, 46.62889011204243, 46.18871793150902, 47.00567789375782, 47.93185159564018, 46.292045786976814, 46.12209230661392, 44.59241218864918, 45.933105647563934, 46.77076309919357, 44.15019191801548, 45.97774565219879, 47.65558362007141, 47.22139231860638, 47.191514521837234, 46.05802394449711, 47.50050254166126, 47.9664259403944, 50.87980180978775, 57.669372484087944, 58.480302169919014, 56.22841380536556, 58.170295804739, 58.523350059986115, 64.29756581783295, 61.94202281534672, 60.67556977272034, 65.27719125151634, 61.688401624560356, 65.28390929102898, 68.71099099516869, 67.66189008951187, 64.79230687022209, 67.17554658651352, 62.14358679950237, 63.39738272130489, 60.47057457268238, 67.6934663951397, 69.65052098035812, 81.13712221384048, 45.450341552495956, 0.2354814688442275, 6.556809889152646, 0.4385686368914321, 0.23936613695695996, 35.947078093886375, 82.87363663315773, 67.73692846298218, 71.70069336891174, 44.440063163638115, 29.67874825000763, 41.90541297197342, 60.50024338066578, 68.62744107842445, 67.09876030683517, 11.618990879505873, 0.3433131513884291, 0.20417582447407767, 0.09176551378914155, 0.12468989356420934, 0.11192948804819025, 0.24510848976206034, 0.17196075234096497, 0.09507504713837989], [0.10788349187350832, 0.049793797224992886, 0.05193987308302894, 0.03742780609172769, 0.02315673486009473, 0.08543204035959207, 0.028975085442652926, 0.0031758243130752817, 0.15037577308248729, 30.709748826920986, 64.69419613480568, 46.24209366738796, 49.09216873347759, 16.158631034195423, 25.933127738535404, 48.950508534908295, 52.85228356719017, 66.60447522997856, 47.76071637868881, 3.782188561744988, 0.14148690708680078, 0.47967106103897095, 0.3380275459494442, 17.77302000671625, 65.48564046621323, 68.05033564567566, 67.04071462154388, 66.0890480875969, 67.66756698489189, 60.922062546014786, 51.43275573849678, 47.02482886612415, 47.831035405397415, 45.25603897869587, 45.368113964796066, 46.578029841184616, 46.276147440075874, 45.269402861595154, 45.946302339434624, 44.56073708832264, 43.833505511283875, 42.35865265130997, 43.14505845308304, 41.117057874798775, 43.0976065993309, 41.951971873641014, 42.000457271933556, 42.12652310729027, 41.7528435587883, 44.02114324271679, 42.3369026184082, 41.328797712922096, 43.024069145321846, 43.44168573617935, 40.40983982384205, 42.95836307108402, 42.726526111364365, 42.25857362151146, 43.15731279551983, 41.62760987877846, 40.58743089437485, 42.05353282392025, 41.744119226932526, 41.40239596366882, 43.815977051854134, 42.194668650627136, 41.969397738575935, 44.54548850655556, 42.96290382742882, 42.62624949216843, 41.254424303770065, 40.30614718794823, 39.07139204442501, 41.09942302107811, 39.52090412378311, 41.23485155403614, 39.99771773815155, 42.22816005349159, 41.462972313165665, 42.28987634181976, 42.987864688038826, 43.454027473926544, 43.910527378320694, 44.947035759687424, 42.88387946784496, 48.037850707769394, 52.205109894275665, 56.367539539933205, 37.5356550514698, 50.179917365312576, 55.90306006371975, 51.735291704535484, 45.61799615621567, 41.932250931859016, 42.45178945362568, 42.281790375709534, 41.431038826704025, 40.322395116090775, 39.723684042692184, 39.924172684550285, 38.28660495579243, 39.85544957220554, 39.702264592051506, 41.5677934885025, 40.15015795826912, 41.81348830461502, 40.3855287283659, 42.50624433159828, 40.71093946695328, 41.10435515642166, 39.10687834024429, 44.41864751279354, 42.47339129447937, 43.02110530436039, 41.00249782204628, 42.39321939647198, 40.31185448169708, 43.46286579966545, 40.88616706430912, 42.19502963125706, 41.37829765677452, 43.47787119448185, 41.98481351137161, 41.337989419698715, 42.0325693488121, 42.35265277326107, 41.73985205590725, 42.12186075747013, 42.88452163338661, 44.18527163565159, 43.88585150241852, 50.872620195150375, 51.8602441996336, 51.52862459421158, 53.66843797266483, 54.398523196578026, 53.08095909655094, 57.840671092271805, 57.63077035546303, 62.83386155962944, 60.07079802453518, 57.87178762257099, 57.24197141826153, 55.35219222307205, 58.917415514588356, 54.957085624337196, 51.859324648976326, 49.76506322622299, 52.471703588962555, 58.553379848599434, 64.67351004481316, 72.02981650829315, 59.71163369715214, 1.3899302668869495, 4.5050757844001055, 0.6693292153067887, 0.18498346995329484, 17.258776500821114, 66.8904934823513, 60.24048551917076, 55.251702815294266, 47.08678834140301, 15.75192080810666, 22.095020189881325, 44.88592363893986, 48.738282322883606, 52.56449081003666, 10.947990585118532, 0.4655166721204296, 0.0262412007941748, 0.061702413877355866, 0.02567582341725938, 0.0337205298274057, 0.06690627546049654, 0.024302850215462968, 0.05743200337747112, 0.05738528889196459, 0.057949566034949385, 0.031841935124248266, 0.024449251832265873, 0.056624977150931954, 0.03793701958784368, 0.03425439746933989, 0.02592656914202962, 0.12438824021955952, 40.32000884413719, 74.08622056245804, 56.07320353388786, 54.07220810651779, 23.543388471007347, 27.94761434197426, 47.71571919322014, 62.38941080868244, 72.40867137908936, 55.39500832557678, 3.03976041264832, 0.20137461775448173, 0.23322366265347227, 0.9128985204733908, 20.417550802230835, 67.90344312787056, 67.31714978814125, 68.97027388215065, 68.44615280628204, 70.15410795807838, 61.573579385876656, 53.83395329117775, 49.48222920298576, 50.0913555175066, 46.53810538351536, 48.765576258301735, 47.146220952272415, 48.260644152760506, 47.30976417660713, 47.68655575811863, 46.504161804914474, 46.44280269742012, 45.75619854032993, 44.21665035188198, 44.41150389611721, 46.2970083206892, 44.36406724154949, 44.04219031333923, 43.95770564675331, 43.88531193137169, 46.45074047148228, 44.98942628502846, 45.397585183382034, 44.75106127560139, 44.07021000981331, 43.30831289291382, 44.92508813738823, 44.607049003243446, 43.8787192851305, 44.799064099788666, 43.6384391784668, 42.248184978961945, 44.40217539668083, 44.00279022753239, 43.02638702094555, 45.51184505224228, 46.081457287073135, 44.1327128559351, 45.730226933956146, 43.85870575904846, 44.559369161725044, 43.80191020667553, 42.340204641222954, 40.88202528655529, 42.60465905070305, 41.64261907339096, 43.15527230501175, 43.209814578294754, 44.59610179066658, 44.4481985270977, 46.97209909558296, 45.51873788237572, 45.022986084222794, 45.715065747499466, 46.04831546545029, 44.62612397968769, 49.29766930639744, 55.522841066122055, 57.95818358659744, 40.805778577923775, 52.02985569834709, 59.19044986367226, 55.44336833059788, 47.123205587267876, 44.01871517300606, 44.151704236865044, 44.14171077311039, 44.89961430430412, 43.601239174604416, 42.25547678768635, 41.10185109078884, 41.68850541114807, 41.55979111790657, 42.248519361019135, 42.428401708602905, 43.70259873569012, 42.320122718811035, 42.665463387966156, 42.69938796758652, 43.37762117385864, 42.564430609345436, 42.109747007489204, 45.19436068832874, 44.358462542295456, 44.1882810741663, 44.23383682966232, 44.21125844120979, 44.21147122979164, 43.48165199160576, 44.09891366958618, 42.69222155213356, 43.411804139614105, 45.17280824482441, 43.38503457605839, 43.28887313604355, 44.5863439142704, 43.915869891643524, 43.475389927625656, 43.41685026884079, 44.49033826589584, 46.758957132697105, 46.10017888247967, 54.53998580574989, 53.006281703710556, 55.02423942089081, 55.38461968302727, 55.74449837207794, 55.844334214925766, 59.76796567440033, 59.510415494441986, 63.73545058071613, 61.899332106113434, 57.99829043447971, 58.35858330130577, 60.22442378103733, 60.76170735061169, 57.53226064145565, 53.65988843142986, 52.36728139221668, 54.043029472231865, 62.56665989756584, 65.98313257098198, 71.68336629867554, 61.92255645990372, 2.0002860529348254, 0.5986977741122246, 1.196149333845824, 0.027132277100463398, 17.828250043094158, 72.09350109100342, 64.02716472744942, 58.87425743043423, 46.02421335875988, 18.451181016862392, 29.470597319304943, 54.14438143372536, 55.01134291291237, 63.5720631480217, 15.223261825740337, 0.5256034119520336, 0.09764988397364505, 0.07874307077145204, 0.0124110070282768, 0.08204126410419121, 0.026481448840058874, 0.026828514201042708, 0.0083305000589462, 0.2050253312336281, 0.16545407648663968, 0.1234954439860303, 0.12540349824121222, 0.16684704314684495, 0.14618722518207505, 0.1481277632410638, 0.09321310251834802, 0.5793489748612046, 51.517722979187965, 84.55227255821228, 65.865498483181, 64.13875713944435, 26.391316652297974, 37.98297844827175, 66.16376727819443, 67.79486775398254, 79.57039788365364, 63.66914413869381, 5.168688800185919, 0.407800767570734, 1.8589307880029082, 2.8149875113740563, 21.434556730091572, 71.74596413969994, 70.20807266235352, 71.06777653098106, 70.26435524225235, 72.97902837395668, 64.55118700861931, 56.996933966875076, 51.892793253064156, 52.51500226557255, 49.51264277100563, 50.782261043787, 50.224010199308395, 51.43717870116234, 49.25633892416954, 50.88780418038368, 48.684807792305946, 47.97973282635212, 48.35111349821091, 48.243252485990524, 47.639936059713364, 48.69523823261261, 46.75497114658356, 46.511666402220726, 46.524072736501694, 45.523898005485535, 48.64818915724754, 46.162579134106636, 46.387325674295425, 46.568116173148155, 46.252790093421936, 44.657563492655754, 46.77846148610115, 45.77273145318031, 46.298562437295914, 47.25556768476963, 45.48672080039978, 44.6600067615509, 47.06333599984646, 44.46008048951626, 45.85983797907829, 47.65175722539425, 46.56693063676357, 45.64859211444855, 47.63310022652149, 46.97654485702515, 46.38073682785034, 45.70188045501709, 45.03703773021698, 43.610028102993965, 45.78008405864239, 43.648580834269524, 46.43383897840977, 45.65997630357742, 47.380212396383286, 47.03398257493973, 50.078968182206154, 48.192479610443115, 48.023077100515366, 49.31925594806671, 47.6288178563118, 47.77096442878246, 51.66883707046509, 57.66908369958401, 59.954934641718864, 45.461075976490974, 54.616126120090485, 61.52567535638809, 56.089557856321335, 49.249757677316666, 46.153334230184555, 49.715012311935425, 45.97587235271931, 47.142086774110794, 46.18581868708134, 44.98178869485855, 44.175380766391754, 43.64182859659195, 44.20451760292053, 45.13060390949249, 45.49572251737118, 47.12045833468437, 46.24123111367226, 44.89370182156563, 45.56581735610962, 44.54256646335125, 45.735584646463394, 43.68035472929478, 48.48069414496422, 47.55357429385185, 46.84447154402733, 46.2276316434145, 46.324237659573555, 45.73197104036808, 46.358443424105644, 46.19503699243069, 45.92311978340149, 46.23474106192589, 47.8825606405735, 46.1908458173275, 44.62607078254223, 46.055713668465614, 46.51834264397621, 44.160082787275314, 46.268798634409904, 48.84251832962036, 49.62309904396534, 48.336138501763344, 55.88221438229084, 57.24407650530338, 56.84917889535427, 58.06927062571049, 59.61027413606644, 57.47369818389416, 61.06302358210087, 62.57410749793053, 65.36739841103554, 64.68811646103859, 62.58859612047672, 60.297778844833374, 61.01209111511707, 64.44573506712914, 60.83382748067379, 58.053155690431595, 55.11856555938721, 57.43725813925266, 64.60368499159813, 69.96021196246147, 74.45081859827042, 65.85521623492241, 1.9456937885843217, 10.608048476278782, 2.103512976318598, 0.5469251365866512, 21.347514800727367, 78.83124634623528, 71.60142749547958, 67.74537920951843, 59.29916203022003, 25.131967328488827, 35.37116199731827, 63.27146127820015, 63.71910385787487, 73.98814782500267, 22.155028469860554, 0.8199128194246441, 0.2184719784418121, 0.30191137455403805, 0.13010996131924912, 0.1410164448316209, 0.08264521646196954, 0.10679165163310245, 0.15103692276170477], [0.1147590002801735, 0.11345393359079026, 0.05862683887244202, 0.027253208209003787, 0.07554459240054712, 0.032297005236614496, 0.04993676826416049, 0.11780585045926273, 2.3003167659044266, 37.16162592172623, 58.028905391693115, 46.01782590150833, 32.590414211153984, 12.886142134666443, 23.98856308311224, 37.11935319006443, 59.86095808446407, 68.69301036000252, 33.00183333456516, 0.5605165322776884, 0.004259172528691124, 0.5725481116678566, 0.5630242789629847, 20.678444802761078, 67.06274583935738, 61.63119949400425, 71.23937532305717, 64.05110344290733, 65.32813891768456, 56.21416836977005, 48.38346116244793, 48.668290078639984, 51.068442687392235, 54.775497168302536, 54.88172426819801, 54.294796362519264, 54.36805263161659, 51.35912708938122, 54.07259188592434, 52.11367540061474, 51.929495483636856, 51.08312889933586, 49.41681191325188, 46.29650294780731, 44.76004399359226, 43.78839433193207, 42.56432041525841, 43.677155300974846, 42.45835170149803, 43.14979299902916, 44.18968699872494, 42.280205860733986, 43.25934872031212, 41.96560174226761, 43.880326598882675, 42.54052609205246, 43.410200625658035, 42.02172853052616, 41.15507483482361, 41.247846856713295, 42.891916036605835, 41.966920271515846, 41.462877318263054, 41.97653375566006, 44.12837728857994, 41.39359563589096, 41.990706995129585, 45.056884065270424, 42.7290415763855, 41.593666300177574, 41.28617540001869, 40.9072445333004, 39.812017902731895, 41.635334864258766, 40.862923711538315, 40.68104267120361, 40.6819736212492, 41.02889880537987, 39.761047437787056, 42.4634700268507, 45.72525680065155, 43.65565225481987, 44.159911796450615, 43.90515446662903, 41.19990102946758, 49.71424475312233, 52.07166865468025, 55.55665925145149, 43.12368459999561, 50.20287573337555, 55.28707131743431, 48.686760887503624, 46.04622557759285, 41.123935505747795, 42.95350693166256, 40.991284623742104, 42.774924114346504, 40.76828598976135, 40.778689831495285, 38.58939550817013, 39.43226248025894, 39.60576876997948, 39.66364346444607, 41.03915065526962, 38.85238319635391, 39.63243953883648, 40.203989669680595, 39.572015181183815, 40.998413041234016, 41.845664978027344, 40.36554180085659, 43.56059655547142, 40.4621060192585, 40.66806256771088, 41.354959309101105, 41.50120586156845, 41.215552389621735, 40.00260427594185, 40.479501485824585, 40.81418752670288, 41.270349249243736, 40.34375376999378, 42.45597302913666, 43.08895826339722, 42.29613460600376, 41.209362521767616, 41.98833592236042, 43.60202953219414, 40.27189962565899, 40.93353912234306, 41.14834539592266, 47.021048069000244, 49.380261674523354, 50.71752771735191, 51.50134965777397, 49.87781077623367, 53.72594028711319, 53.508280366659164, 50.80119162797928, 50.25190070271492, 51.48350581526756, 50.05586922168732, 47.33942538499832, 46.57383866608143, 46.07713311910629, 46.656662821769714, 47.61066623032093, 49.47803422808647, 50.96719332039356, 58.271275386214256, 64.30340230464935, 67.34907567501068, 71.39213472604752, 7.115174252539873, 1.4157481002621353, 0.512084390502423, 0.18606341356644407, 7.201844276860356, 61.71494320034981, 60.8243203908205, 60.86538478732109, 59.61570784449577, 41.21927618980408, 35.571700036525726, 47.00383499264717, 44.93367187678814, 60.811477079987526, 20.675363168120384, 0.9738700487650931, 0.01797343818907393, 0.02202100215072278, 0.03398090120754205, 0.02728202765865717, 0.11010989779606462, 0.10737546952441335, 0.004188175435047015, 0.050107358329114504, 0.07158059612265788, 0.008381677635043161, 0.03766093694139272, 0.039940154092619196, 0.03277577583503444, 0.051826818016706966, 0.04208231512166094, 2.455007890239358, 50.397493690252304, 67.55001649260521, 52.15543515980244, 40.16571432352066, 18.415690921247005, 27.34924715012312, 42.095957547426224, 64.71056565642357, 75.34739568829536, 40.64851641654968, 0.6444128241855651, 0.031262800184777007, 0.23708060412900522, 0.41239231650251895, 22.326509468257427, 70.39579778909683, 64.99618113040924, 71.88793212175369, 66.96658819913864, 67.65270978212357, 59.93915408849716, 52.20894768834114, 49.38003748655319, 54.9642064422369, 56.93286560475826, 57.30243377387524, 57.10333585739136, 56.897744089365005, 55.20779237151146, 55.14518693089485, 53.48381727933884, 54.368972182273865, 51.72448508441448, 51.834173798561096, 48.39650586247444, 47.88501910865307, 46.03756204247475, 44.61779482662678, 46.14196144044399, 44.300888031721115, 45.113816410303116, 45.131455063819885, 44.70213510096073, 45.17948068678379, 44.3226570636034, 45.47727830708027, 44.609792456030846, 43.93964521586895, 44.13250386714935, 44.676102697849274, 44.13973867893219, 42.76088006794453, 43.44271928071976, 43.07674951851368, 44.156697168946266, 46.024380549788475, 43.33243779838085, 44.456759467720985, 47.333854883909225, 44.311538860201836, 43.89804504811764, 42.59393222630024, 41.98622703552246, 43.21522168815136, 42.87714242935181, 41.35551027953625, 43.31794157624245, 42.70379573106766, 43.22935312986374, 43.04096303880215, 45.67732997238636, 47.54258908331394, 46.44070900976658, 46.35672211647034, 45.76034031808376, 43.63572612404823, 51.26333422958851, 54.34547804296017, 57.90082186460495, 46.0191710293293, 54.606771022081375, 58.479067236185074, 51.56787648797035, 47.881861478090286, 42.59838178753853, 45.137508139014244, 43.276675790548325, 45.53573057055473, 42.18436360359192, 43.00651788711548, 40.74280075728893, 42.03221216797829, 41.68700449168682, 41.86665505170822, 41.86193190515041, 41.90021485090256, 41.261514723300934, 43.093236833810806, 42.23990522325039, 43.35103400051594, 43.982689306139946, 42.29889705777168, 45.24056240916252, 43.04054506123066, 43.32623653113842, 43.5562913864851, 43.94966147840023, 43.19331206381321, 41.73694521188736, 42.715225517749786, 43.1456284224987, 42.67783932387829, 42.89552964270115, 43.838882222771645, 45.78169897198677, 46.111342683434486, 42.691959366202354, 43.28527472913265, 43.22798900306225, 44.15880985558033, 43.95179696381092, 42.866438403725624, 49.76608157157898, 51.73338420689106, 51.759800389409065, 52.932774648070335, 52.25485302507877, 55.54305978119373, 53.95690329372883, 52.91546657681465, 53.2221595197916, 53.47841016948223, 53.16149577498436, 49.95669834315777, 48.311211839318275, 47.44114972651005, 49.17740575969219, 50.38953311741352, 51.60335138440132, 52.03565038740635, 60.046973302960396, 67.09455013275146, 69.83518347144127, 75.5316174030304, 8.89776499941945, 1.1097697564400733, 0.9118599887005985, 0.23932953423354775, 7.920943815261126, 67.0394378900528, 67.49261677265167, 65.72427526116371, 50.44993847608566, 31.749823316931725, 38.01906131207943, 56.51382029056549, 53.222889080643654, 70.26236414909363, 30.088352970778942, 1.1453515221364796, 0.03067995079618413, 0.03826182794000488, 0.07022538993624039, 0.06014861639414448, 0.07360291143413633, 0.02188571419537766, 0.03758601342269685, 0.15353497699834406, 0.20791529881535098, 0.1319579387200065, 0.0997191623901017, 0.16495061834575608, 0.2168508162139915, 0.23953230382176116, 0.2330833818996325, 4.514011004939675, 65.72182819247246, 76.19633093476295, 62.727782651782036, 46.76331549882889, 19.803059175610542, 34.15336534380913, 53.01426887512207, 70.12768417596817, 83.3544172346592, 48.86051796376705, 0.9798687393777072, 0.2751525572966784, 2.049912102520466, 2.0846999483183026, 24.383274503052235, 72.1120136976242, 66.52808412909508, 75.17082676291466, 69.82087343931198, 71.29188850522041, 61.262421682477, 54.34787951409817, 53.27456250786781, 56.1945766210556, 58.72699253261089, 58.65840621292591, 59.882347136735916, 59.707670509815216, 55.88797867298126, 58.48141930997372, 56.98212616145611, 56.28622390329838, 54.36190836131573, 55.830483958125114, 50.00746361911297, 50.37530668079853, 49.04993399977684, 46.27029575407505, 49.32032749056816, 45.95023512840271, 47.05726392567158, 49.42333996295929, 46.558134108781815, 48.74244309961796, 46.31068758666515, 47.49552100896835, 46.883529648184776, 47.09263622760773, 48.013592809438705, 46.23085767030716, 44.92045998573303, 46.15478955209255, 45.665543004870415, 45.330416187644005, 45.85509963333607, 49.51506704092026, 45.74524372816086, 45.81372745335102, 49.99082051217556, 47.04564034938812, 45.06085105240345, 43.064886555075645, 45.08065178990364, 43.776162788271904, 46.559258848428726, 45.216984674334526, 45.741888508200645, 45.9413094073534, 47.078880965709686, 45.117357820272446, 48.582711070775986, 51.54710300266743, 49.82630454003811, 48.868539333343506, 47.49691553413868, 44.35759998857975, 53.01144182682037, 57.244695872068405, 60.53252264857292, 48.7250742316246, 56.50137595832348, 61.34109266102314, 55.71781240403652, 51.52428902685642, 44.466638937592506, 47.497546300292015, 45.09576357901096, 47.875926196575165, 45.73487788438797, 45.529042929410934, 44.15875665843487, 44.21410068869591, 45.19995018839836, 42.45683938264847, 45.566645711660385, 45.29866509139538, 44.286038428545, 44.685586988925934, 43.84704418480396, 46.050139367580414, 45.93913212418556, 44.10120114684105, 49.14750136435032, 44.52512539923191, 44.679260328412056, 46.252155527472496, 46.07109524309635, 45.227080732584, 44.112558737397194, 45.398280546069145, 46.093145459890366, 44.962489530444145, 44.20117758214474, 46.500080823898315, 47.88021616637707, 48.65092881023884, 44.499248787760735, 46.21684402227402, 47.47371777892113, 45.988814458251, 47.03675642609596, 46.46649442613125, 52.05142714083195, 55.266442224383354, 56.26400649547577, 56.247093603014946, 54.586027935147285, 59.143096804618835, 57.630983144044876, 55.44187121093273, 56.034316420555115, 56.576988101005554, 55.37179917097092, 53.00363704562187, 50.21231822669506, 51.049645096063614, 53.03776681423187, 52.19477824866772, 55.52014321088791, 54.01880957186222, 64.69680279493332, 70.6939297914505, 74.78073209524155, 78.28263938426971, 10.528783779591322, 4.366314830258489, 1.4574596495367587, 0.23809235921362415, 9.239689651876688, 73.28580871224403, 72.48218223452568, 76.9752587378025, 74.04745504260063, 54.315205067396164, 49.76645775139332, 66.33851990103722, 62.10537225008011, 79.07539084553719, 38.615127727389336, 1.6324483347125351, 0.13421347393887118, 0.10876972752157599, 0.16124529764056206, 0.15411734028020874, 0.20265503029804677, 0.19435571157373488, 0.11794702179031447], [0.011287592114967993, 0.09328666419605725, 0.06697554752463475, 0.058044701945618726, 0.08341935812495649, 0.06287715572398156, 0.09781619926798157, 0.13739336893195286, 3.3792712446302176, 47.92891435325146, 52.372247725725174, 45.885342210531235, 36.63712486624718, 24.51910201460123, 45.15743046998978, 47.853853181004524, 63.56746159493923, 67.81464949250221, 36.05725698173046, 0.47147012141067535, 0.07692440078244545, 0.2980128728086129, 0.983519155997783, 32.774138152599335, 69.7287055850029, 66.1408469080925, 66.28821060061455, 65.42586967349052, 62.67059952020645, 49.02436137199402, 48.535924181342125, 51.72163903713226, 57.43150904774666, 57.777043506503105, 59.72937494516373, 57.391690984368324, 60.56638263165951, 58.4276369959116, 61.32487513124943, 58.672670647501945, 58.67028057575226, 57.888932302594185, 57.42169797420502, 55.15021026134491, 51.1292128264904, 48.50874803960323, 45.138271898031235, 41.84416405856609, 43.26930798590183, 42.7323891967535, 41.94812647998333, 43.4560489654541, 43.199980705976486, 40.761351361870766, 41.00401014089584, 41.973866298794746, 43.18557187914848, 42.457523345947266, 43.184158354997635, 40.720001980662346, 42.55069054663181, 44.23159494996071, 42.26446710526943, 41.960521414875984, 42.04916685819626, 44.65757489204407, 41.6193301230669, 42.1231184899807, 41.95799835026264, 43.594798520207405, 40.02930924296379, 39.8674189299345, 41.27334728837013, 39.67668056488037, 39.926315769553185, 40.69103613495827, 40.395860373973846, 39.94024962186813, 41.754443272948265, 43.20903941988945, 46.38474561274052, 45.945986956357956, 45.70971183478832, 46.300192549824715, 44.42854978144169, 48.92246603965759, 52.71191529929638, 55.70472210645676, 44.874379858374596, 50.7448710501194, 53.32577995955944, 49.54483464360237, 45.13550944626331, 44.64855037629604, 43.961345851421356, 44.71922658383846, 42.45675578713417, 40.08195921778679, 39.98347230255604, 40.473429411649704, 40.418077781796455, 38.14315505325794, 40.80712750554085, 40.12293241918087, 40.050485506653786, 40.656518787145615, 39.24384959042072, 39.20755013823509, 43.37204307317734, 40.053639337420464, 42.61214844882488, 41.48422837257385, 42.00737290084362, 39.43553030490875, 40.31524010002613, 39.37934651970863, 41.135931462049484, 40.688117891550064, 41.748473793268204, 40.8268104493618, 40.99218137562275, 41.80392801761627, 42.45720416307449, 42.62557312846184, 42.55563788115978, 41.08757525682449, 42.27822616696358, 40.469245836138725, 40.97827412188053, 41.3781950622797, 42.17775195837021, 42.56504237651825, 42.61186346411705, 45.60975059866905, 45.32081790268421, 45.75109161436558, 45.57002753019333, 45.44964998960495, 44.76046197116375, 44.65346731245518, 43.85537713766098, 42.50554896891117, 44.669415056705475, 45.95915324985981, 48.200599774718285, 51.38429693877697, 55.12050725519657, 56.43137991428375, 57.96109423041344, 59.89483326673508, 63.63285608589649, 64.72847029566765, 73.45905661582947, 13.692380972206593, 0.7002611586358398, 0.8053539600223303, 0.09048403255292214, 1.67200444964692, 53.28323744237423, 64.75769072771072, 61.16133190691471, 54.30602855980396, 29.43668033927679, 13.937943745404482, 33.73052403330803, 47.309650182724, 58.34307633340359, 35.99336341023445, 1.407030418049544, 0.08738841585000046, 0.03811474911344703, 0.039196225261548534, 0.04962870276358444, 0.021369619134929962, 0.03084463893173961, 0.03082975701545365, 0.057258199813077226, 0.03213849733583629, 0.03268543790909462, 0.028420645467122085, 0.10799119234434329, 0.051949572953162715, 0.0412099724781001, 0.09313915492384695, 4.633935894817114, 61.224036142230034, 59.99007895588875, 51.855061277747154, 42.20728017389774, 21.287780106067657, 37.33429625630379, 52.644845098257065, 68.01148653030396, 74.67597171664238, 40.21635800600052, 0.314993835054338, 0.048918092652456835, 0.2579670591512695, 1.3697949098423123, 35.599362552165985, 74.69421833753586, 66.09921634197235, 69.03750747442245, 66.99169725179672, 63.88110816478729, 50.948407128453255, 50.49619719386101, 55.29401734471321, 59.89844307303429, 60.42626895010471, 60.36929860711098, 61.98631323873997, 61.64493575692177, 61.092544198036194, 62.177613973617554, 60.31218387186527, 60.631286948919296, 59.40982349216938, 59.317986220121384, 57.59082309901714, 52.67644040286541, 49.519189819693565, 45.463709235191345, 43.48088823258877, 45.297623947262764, 45.523787811398506, 44.42748203873634, 44.584083035588264, 45.07089011371136, 43.13568435609341, 43.73618133366108, 44.098659083247185, 45.44495344161987, 43.551184460520744, 44.38526250422001, 42.596671879291534, 44.58573594689369, 44.39351186156273, 44.34562683105469, 43.956010937690735, 44.111111015081406, 46.90214104950428, 43.71103048324585, 45.53974315524101, 43.174503073096275, 45.33597908914089, 41.237796396017075, 43.49552884697914, 42.34891377389431, 42.42394454777241, 42.040970697999, 42.977616637945175, 43.93090948462486, 41.61852456629276, 43.00805680453777, 46.232594177126884, 47.4162420630455, 49.18433278799057, 46.30222164094448, 49.94685307145119, 47.61680290102959, 51.25061251223087, 54.76098194718361, 57.36372068524361, 47.273639515042305, 52.23066732287407, 55.76185204088688, 52.27007880806923, 47.38878093659878, 47.063753977417946, 44.37979459762573, 46.698202192783356, 45.513110384345055, 41.82815171778202, 42.91714668273926, 41.453051045536995, 43.01361210644245, 43.00434820353985, 43.91152672469616, 42.16920621693134, 42.179199680686, 41.68287791311741, 42.02877335250378, 41.28642238676548, 45.57614520192146, 42.02643647789955, 46.34652726352215, 43.435412272810936, 45.41821047663689, 43.13029244542122, 43.217797949910164, 41.565069034695625, 42.4865347892046, 42.912548929452896, 42.326297387480736, 42.06122361123562, 44.92530472576618, 43.25652167201042, 45.81949554383755, 43.1622601300478, 44.495809972286224, 42.744449749588966, 43.166063725948334, 42.86509707570076, 43.236561343073845, 45.31515620648861, 45.05211532115936, 45.437768027186394, 45.440237894654274, 48.15400667488575, 48.440731689333916, 48.30585792660713, 48.16213823854923, 47.433660328388214, 47.51771181821823, 46.86158962547779, 46.63688488304615, 44.338566809892654, 46.991257667541504, 47.27719992399216, 51.79350458085537, 54.108355566859245, 57.59799711406231, 59.36753176152706, 60.46880766749382, 60.8307496458292, 65.20467594265938, 67.24135905504227, 76.35384768247604, 15.883311107754707, 0.9922139206901193, 2.081258757971227, 0.07511541582061909, 1.6465692082419991, 56.47628590464592, 70.19772201776505, 66.61820769309998, 59.2252141982317, 39.22858200967312, 23.794287107884884, 39.743758365511894, 54.194227159023285, 65.73976323008537, 45.320810303092, 2.36894678324461, 0.08084588684141636, 0.019872803750331514, 0.07115682979929261, 0.10764889157144353, 0.12671990494709462, 0.07115861095371656, 0.04769435050548054, 0.1663126819767058, 0.20311533997301012, 0.11709738144418225, 0.16823056968860328, 0.17404186801286414, 0.14093943958869204, 0.32589058158919215, 0.30482353235129267, 7.631248310208321, 76.60338789224625, 68.236533254385, 63.703038319945335, 50.48892438411713, 36.79057963192463, 59.50820781290531, 63.47111776471138, 73.10995414853096, 80.97115471959114, 45.570384711027145, 0.7667521282564849, 0.2416066956357099, 0.716583242174238, 2.6136327534914017, 39.33579705655575, 77.024215310812, 67.87492945790291, 71.6802504658699, 71.45808398723602, 67.78249561786652, 53.422879949212074, 53.52845348417759, 57.15680658817291, 62.052228301763535, 65.26341319084167, 64.07442659139633, 62.84132435917854, 63.40229965746403, 63.73103141784668, 64.43437367677689, 62.100462913513184, 62.478835210204124, 62.61922627687454, 60.11619418859482, 58.79115588963032, 55.71201391518116, 53.886626064777374, 49.531314969062805, 44.13371980190277, 47.02543683350086, 49.263125360012054, 45.18478900194168, 46.501881927251816, 47.91910707950592, 44.54882092773914, 44.81686994433403, 45.58710761368275, 46.97137713432312, 45.65211832523346, 48.14294546842575, 46.217999160289764, 49.413122311234474, 47.57495954632759, 46.03820040822029, 46.59341521561146, 47.022085413336754, 48.72201159596443, 46.931361481547356, 46.33588403463364, 45.322672203183174, 48.28591659665108, 42.55909949541092, 46.09783820807934, 44.89867575466633, 43.456121161580086, 44.91542145609856, 45.31029246747494, 46.06091558933258, 44.713070914149284, 46.86094366014004, 48.19363474845886, 51.047331020236015, 51.768623515963554, 50.70365086197853, 52.779475674033165, 48.819350972771645, 53.69316704571247, 58.495292365550995, 59.304816126823425, 50.88801696896553, 55.65216712653637, 58.4501051902771, 54.702624678611755, 50.10565795004368, 49.73005570471287, 47.057054936885834, 50.48481300473213, 48.40471722185612, 44.506760984659195, 45.941123217344284, 44.78281997144222, 46.130182072520256, 44.464237466454506, 46.94934971630573, 45.7132950425148, 44.760834351181984, 45.019178688526154, 44.57683302462101, 44.68087524175644, 49.22972895205021, 45.30756041407585, 47.86127798259258, 47.125656455755234, 46.9746183604002, 43.75063955783844, 44.54198509454727, 42.809422463178635, 45.40431462228298, 45.60348093509674, 45.24348825216293, 46.53215490281582, 46.16797864437103, 45.0667255371809, 48.38234022259712, 44.495673179626465, 46.918514370918274, 44.65950898826122, 46.68181747198105, 44.534450098872185, 45.18228493630886, 47.43831507861614, 47.377613335847855, 48.77316825091839, 49.050298780202866, 51.58981271088123, 51.23852916061878, 51.62441365420818, 52.25328370928764, 51.012369096279144, 50.25753200054169, 48.89553688466549, 48.693038150668144, 45.55433437228203, 49.47936415672302, 50.78308179974556, 53.169680535793304, 56.57299071550369, 60.062734857201576, 62.684639766812325, 62.1550165861845, 64.82859492301941, 67.32231751084328, 71.27478942275047, 80.3621917963028, 18.61168060451746, 1.8170696217566729, 3.7865314912050962, 0.18012785003520548, 2.34441957436502, 63.55490326881409, 74.67964991927147, 75.43243512511253, 71.10535651445389, 43.37371878325939, 27.19891581684351, 51.09219901263714, 65.90525195002556, 74.71789106726646, 57.77029126882553, 3.106509055942297, 0.27025907300412655, 0.14744737709406763, 0.1075645093806088, 0.270765395835042, 0.28181532165035605, 0.31933964404743165, 0.12357729545328766], [0.021285960538079962, 0.05272779271763284, 0.02666562948434148, 0.05931208608672023, 0.06491785403341055, 0.05799069214845076, 0.06034851016011089, 0.09644150428357534, 8.811927605420351, 60.74230559170246, 52.7744447439909, 44.722718596458435, 23.57219472527504, 26.532000303268433, 35.22095985710621, 45.80395817756653, 65.08764982223511, 65.00661537051201, 32.61455051600933, 0.06192543667566497, 0.030154276464600116, 0.8064847555942833, 1.286425602156669, 42.54698574542999, 73.28237369656563, 62.37918555736542, 63.79701107740402, 56.786866039037704, 56.252246126532555, 48.61434057354927, 56.284669786691666, 56.43244385719299, 60.11310875415802, 61.2481914460659, 61.24670572578907, 59.05308723449707, 58.898712918162346, 57.81675897538662, 59.76758569478989, 57.98099756240845, 59.69131998717785, 57.76230789721012, 59.99324418604374, 54.802749305963516, 52.222414165735245, 49.94304567575455, 49.43587549030781, 44.6879618614912, 41.177793815732, 43.73850300908089, 44.98862832784653, 41.83387041091919, 43.509956672787666, 43.21480371057987, 43.50676864385605, 41.89657084643841, 42.086758241057396, 42.92199522256851, 43.7740159034729, 42.729132771492004, 43.973178416490555, 41.7642505466938, 43.32992613315582, 42.08192490041256, 44.14712928235531, 43.354051038622856, 41.70824155211449, 42.67760373651981, 42.29516185820103, 43.313951790332794, 39.95457485318184, 41.014790162444115, 40.210035145282745, 40.285221710801125, 41.54860071837902, 41.42942771315575, 39.83159065246582, 40.13321466743946, 40.05913004279137, 46.39104567468166, 48.22748713195324, 46.69311806559563, 47.91450172662735, 48.88920642435551, 46.62934988737106, 47.92717784643173, 51.062294617295265, 57.34968423843384, 44.883605763316154, 53.96550603210926, 55.52175052464008, 48.5700311511755, 46.700140088796616, 43.75875972211361, 47.38806277513504, 43.83393868803978, 43.457998260855675, 38.73118110001087, 40.310972929000854, 38.466365709900856, 40.101360976696014, 40.06417237222195, 40.53314320743084, 42.40911394357681, 40.65175764262676, 38.93070079386234, 41.47733174264431, 41.292669251561165, 41.72388531267643, 41.97979778051376, 41.02454423904419, 40.6425279378891, 42.25545398890972, 40.52566520869732, 42.22797006368637, 41.35871730744839, 41.458727940917015, 41.35053634643555, 39.57580357789993, 40.47798536717892, 41.741691157221794, 42.56392903625965, 42.057241424918175, 41.08924336731434, 40.95712825655937, 40.69520831108093, 40.67256152629852, 41.53707593679428, 41.89267985522747, 41.66276179254055, 39.68428015708923, 40.94519689679146, 41.7252304404974, 40.20841263234615, 41.71044923365116, 41.12529203295708, 42.732708379626274, 41.40998035669327, 41.80385582149029, 42.67424091696739, 45.94136640429497, 48.267058208584785, 54.184537678956985, 55.62822841107845, 59.96167168021202, 59.26575042307377, 63.88985529541969, 64.29041460156441, 65.0060074031353, 62.796718552708626, 63.62729698419571, 64.87210258841515, 75.65754264593124, 17.01017864048481, 0.4814942507073283, 0.6907357228919864, 0.03335885157866869, 0.2929494366981089, 38.22459988296032, 70.89909598231316, 57.50375837087631, 52.83954285085201, 19.86868165433407, 12.78015062212944, 25.175767578184605, 37.628560066223145, 52.50277832150459, 51.41155667603016, 5.85593132302165, 0.1431125370436348, 0.034178119531134143, 0.08846369135426357, 0.037604997560265474, 0.026138138746318873, 0.0626575764908921, 0.028698757887468673, 0.014277230129664531, 0.07262089420692064, 0.01849818854680052, 0.024770104537310544, 0.05139888824487571, 0.01599306720891036, 0.05926611374889035, 0.08823251235298812, 12.26273713633418, 72.12291151285172, 61.64234809577465, 53.647010922431946, 32.844567373394966, 33.984851986169815, 36.836591362953186, 52.368793711066246, 70.96200540661812, 71.13609686493874, 35.329390838742256, 0.05331271640898194, 0.0753516711120028, 1.2662217300385237, 1.017927615903318, 45.269319266080856, 74.44191947579384, 65.07581725716591, 65.13307258486748, 59.64049771428108, 58.52644309401512, 52.985656410455704, 57.9838702082634, 59.22998294234276, 62.412334978580475, 62.20244184136391, 62.856033369898796, 61.201887130737305, 61.599296405911446, 60.905134454369545, 60.63829377293587, 58.97351570427418, 60.65000094473362, 61.75655096769333, 59.028437957167625, 56.42226040363312, 56.17885686457157, 53.653896152973175, 52.480028942227364, 46.589828208088875, 43.518008440732956, 44.14409324526787, 46.74336276948452, 43.23677413165569, 44.79844473302364, 44.941358864307404, 43.97353559732437, 44.133499413728714, 43.31963248550892, 44.69041272997856, 45.7383318990469, 44.465111419558525, 45.07368676364422, 44.2677766084671, 45.76597161591053, 43.64386148750782, 46.287596225738525, 44.285153076052666, 42.927649319171906, 45.32654419541359, 44.66241583228111, 44.96494419872761, 43.002303913235664, 43.08110028505325, 43.43480810523033, 41.67330242693424, 42.25597836077213, 42.816626876592636, 42.906518653035164, 42.36339099705219, 43.32293450832367, 48.984113931655884, 52.07074910402298, 50.50988405942917, 49.78706784546375, 49.63852621614933, 48.07196147739887, 50.85870914161205, 52.88979135453701, 60.10724946856499, 47.02219560742378, 55.80621846020222, 57.000045999884605, 49.39585603773594, 47.43925742805004, 47.6343047618866, 50.89088961482048, 45.833095014095306, 45.93438997864723, 41.50204561650753, 41.34258717298508, 40.4553347826004, 42.22737729549408, 42.582901418209076, 42.317611053586006, 43.0716235935688, 41.67716681957245, 42.18474738299847, 43.60784322023392, 43.36981639266014, 43.10591675341129, 45.71042999625206, 42.69186817109585, 44.06123109161854, 42.92677916586399, 43.472163900732994, 45.10843589901924, 42.485056668519974, 42.90298484265804, 42.0901058614254, 41.8182722479105, 42.20680519938469, 43.01675833761692, 44.18507784605026, 42.44158320128918, 42.821118235588074, 43.09092275798321, 43.93775671720505, 41.531102657318115, 43.36338333785534, 44.74117040634155, 43.1261582672596, 42.19870403409004, 43.038139790296555, 43.54091741144657, 41.386592611670494, 44.19568307697773, 43.62874589860439, 45.36532111465931, 44.52699489891529, 43.602078929543495, 45.58379039168358, 48.3653399348259, 51.00608043372631, 56.455786004662514, 57.99359768629074, 62.08172991871834, 63.8031667470932, 66.65410056710243, 68.10970366001129, 67.48951613903046, 65.6881695985794, 67.4211198091507, 66.59806877374649, 76.09310567378998, 19.903964661061764, 0.6042511761188507, 0.5551462329458445, 0.07648092301678844, 0.3566257964121178, 41.50581881403923, 78.9279055595398, 61.88349835574627, 59.68142531812191, 26.73907209187746, 19.72704615443945, 32.72202014923096, 45.87244190275669, 61.1857607960701, 62.43346184492111, 7.774567594751716, 0.2157994156004861, 0.09232173862983473, 0.03067164059757488, 0.11536295263795182, 0.022398276632884517, 0.03791129303863272, 0.04813305626157671, 0.08350577380042523, 0.2468087204033509, 0.19286714144982398, 0.11314294402836822, 0.20195166725898162, 0.24002278922125697, 0.18601835035951808, 0.3036029962822795, 18.46213772892952, 84.74916279315948, 70.7233402132988, 64.20660629868507, 38.78923058509827, 41.48743540048599, 49.38895560801029, 60.529961585998535, 73.7945406138897, 77.9536834359169, 40.94125650823116, 0.14760536549147218, 0.1718123970204033, 2.1173893567174673, 3.286822442896664, 47.01584994792938, 77.30179041624069, 68.91573160886765, 67.32743203639984, 63.3244114369154, 61.551745757460594, 55.81994332373142, 60.42388267815113, 62.1396654099226, 65.69998696446419, 65.45964986085892, 63.35066042840481, 62.660929039120674, 63.76282051205635, 62.470722645521164, 62.8141900151968, 61.099516823887825, 63.30150626599789, 63.50077897310257, 62.69329570233822, 59.37345564365387, 57.59468749165535, 54.918050318956375, 54.753321558237076, 50.12380577623844, 46.11622542142868, 48.375173807144165, 51.95074774324894, 44.61972892284393, 47.82460995018482, 47.95645147562027, 47.294621989130974, 45.7090924680233, 45.27751162648201, 47.76014260947704, 48.16237762570381, 47.0898699760437, 48.344756439328194, 46.66691467165947, 48.76130148768425, 45.17172910273075, 49.71390277147293, 46.89131163060665, 45.641919672489166, 47.59195223450661, 47.088733837008476, 48.94844524562359, 45.695230811834335, 46.003698259592056, 44.553213492035866, 44.54473614692688, 44.93996433913708, 44.606232047080994, 46.959479972720146, 44.735915288329124, 45.300960168242455, 52.035680785775185, 54.678047597408295, 51.16947926580906, 51.610316410660744, 53.8783273100853, 50.58148741722107, 52.628141194581985, 56.21195688843727, 63.19067761301994, 52.29036211967468, 58.94027128815651, 60.323017090559006, 53.84768195450306, 52.236279621720314, 48.61074596643448, 54.325008541345596, 46.94855555891991, 47.998963594436646, 44.11731608211994, 44.21085946261883, 41.93545415997505, 44.54301103949547, 43.74908544123173, 44.752619192004204, 46.5103554725647, 44.176076129078865, 44.46263775229454, 45.52603729069233, 46.62581227719784, 45.97633972764015, 48.01611587405205, 45.28144061565399, 48.259211629629135, 46.14070750772953, 46.50004282593727, 47.294838577508926, 46.15359641611576, 47.04869158565998, 44.87199358642101, 43.6603944003582, 44.13858734071255, 46.1137555539608, 46.20104447007179, 45.06942339241505, 44.68700431287289, 45.225671008229256, 45.309057533741, 44.98161770403385, 46.751220747828484, 47.580518648028374, 46.69874556362629, 45.185761749744415, 45.50620995461941, 46.58579662442207, 44.23775061964989, 47.34648160636425, 45.838745310902596, 47.49941200017929, 46.819016709923744, 45.35601161420345, 46.80404931306839, 52.408417984843254, 53.236705139279366, 59.64730694890022, 60.486716106534004, 66.31056860089302, 67.21115827560425, 69.71896290779114, 71.55679509043694, 70.35105139017105, 68.74484717845917, 69.9621194601059, 70.66540092229843, 79.80432853102684, 22.150012739002705, 1.2709284899756312, 3.0130005860701203, 0.18140033644158393, 0.40480385650880635, 46.230656281113625, 83.55810150504112, 68.781917989254, 67.20703169703484, 31.38988573104143, 24.98235795646906, 39.04117986559868, 56.25696547329426, 68.5756878554821, 74.24483925104141, 10.567987225949764, 0.5251499300356954, 0.20039023307617754, 0.2479535128804855, 0.2226787238032557, 0.18036205699900165, 0.14206177467713133, 0.10947173985186964], [0.06475589514593594, 0.02866397157049505, 0.0636292110721115, 0.03641752417024691, 0.06106671615270898, 0.02950821835838724, 0.1244187647535, 0.06575755702215247, 17.027298621833324, 69.08150911331177, 49.17536526918411, 43.72310243546963, 13.72690686956048, 24.521598480641842, 36.923192515969276, 54.05642755329609, 65.81152617931366, 64.80518817901611, 28.048398233950138, 0.07759500542306341, 0.07884872291469947, 0.7140689645893872, 1.5401712362654507, 46.443638652563095, 76.64144665002823, 61.77686087787151, 58.44626359641552, 52.76117965579033, 54.83964532613754, 51.306199729442596, 57.349904626607895, 59.568708166480064, 61.284585893154144, 59.74261723458767, 60.68930223584175, 57.30680733919144, 60.225027948617935, 60.26819363236427, 58.65551836788654, 56.22430242598057, 57.40271799266338, 60.27096748352051, 58.54326479136944, 54.365035593509674, 54.2173907160759, 54.08854342997074, 51.250160336494446, 49.36070032417774, 44.52146999537945, 41.26374900341034, 42.307636588811874, 41.978342458605766, 41.83460757136345, 42.995779663324356, 40.96534721553326, 40.08987419307232, 42.30089195072651, 42.09095701575279, 41.87337689101696, 40.175339207053185, 41.861263141036034, 42.084656953811646, 41.41773194074631, 41.123772114515305, 40.134385004639626, 42.865659445524216, 42.79034748673439, 43.65192465484142, 43.702845722436905, 40.899169966578484, 41.41256421804428, 40.97789794206619, 40.18897287547588, 40.45574136078358, 40.23694910109043, 40.351585149765015, 40.921964943408966, 40.80624595284462, 39.77965123951435, 44.9753974378109, 47.60701842606068, 49.489106833934784, 48.47852446138859, 51.4657037705183, 47.66485132277012, 50.54634690284729, 50.659345239400864, 57.8809679299593, 39.87347960472107, 50.26248313486576, 57.089664191007614, 48.802449479699135, 47.13345743715763, 45.33003620803356, 45.634912848472595, 44.38527770340443, 42.472726330161095, 38.751171827316284, 39.07124765217304, 38.78536619246006, 39.905101507902145, 40.11502504348755, 41.6393968462944, 41.09307736158371, 41.62859782576561, 39.20336656272411, 40.516564697027206, 41.27368167042732, 41.01490795612335, 40.49209401011467, 41.59161061048508, 39.7832116484642, 40.76913334429264, 39.946390092372894, 40.9306550770998, 40.99774047732353, 40.95378063619137, 41.2111522257328, 39.74521368741989, 40.592188239097595, 42.19145402312279, 40.69376438856125, 42.602580562233925, 41.76028735935688, 40.800230875611305, 41.17853857576847, 41.660820096731186, 38.99589769542217, 41.028116047382355, 40.18314018845558, 41.69487006962299, 41.72835387289524, 40.851638317108154, 42.11278684437275, 43.635452538728714, 41.34015530347824, 44.17258411645889, 45.421227514743805, 49.100136905908585, 51.15633577108383, 55.53875841200352, 56.534525379538536, 61.19534768164158, 61.14170975983143, 62.6682398468256, 62.55883231759071, 65.18218874931335, 60.78953705728054, 67.07156136631966, 69.18131455779076, 74.00196388363838, 65.35917565226555, 72.16048389673233, 18.969005830585957, 0.19810188008705154, 0.9221539925783873, 0.37684753944631666, 0.33363866270519793, 24.882090836763382, 71.67500674724579, 61.41983583569527, 61.904169246554375, 50.01662492752075, 14.738045912235975, 16.50698684155941, 39.35234136879444, 47.66461193561554, 55.679141879081726, 11.048684231936932, 0.13890742440707982, 0.035494366675266065, 0.03196938043402042, 0.0546661154658068, 0.08047174793318845, 0.020942114242643584, 0.017095650036935695, 0.041621144555392675, 0.008206268248613924, 0.0692408048780635, 0.05022782745072618, 0.053509634162764996, 0.019121130608255044, 0.13885440537706017, 0.03747236463823356, 21.62797775119543, 77.73660868406296, 56.758644953370094, 50.64624734222889, 23.855144642293453, 30.609960481524467, 35.756012946367264, 60.2275700122118, 68.65259572863579, 71.90741747617722, 31.661411561071873, 0.03708348667714745, 0.01731755033688387, 2.0642131101340055, 1.999858575873077, 49.38442625105381, 76.95508182048798, 63.62550728023052, 59.967230781912804, 55.973390489816666, 55.56628033518791, 54.363964051008224, 59.16067086160183, 63.539913073182106, 65.19997179508209, 61.19312860071659, 63.42607498168945, 60.37162788212299, 61.077443808317184, 60.29826521873474, 60.4145921766758, 59.051658511161804, 61.69157065451145, 60.91012738645077, 58.34413267672062, 55.79740293323994, 56.544754430651665, 54.487731009721756, 53.509541898965836, 52.00666554272175, 47.623824924230576, 43.90689097344875, 45.139533430337906, 44.27202858030796, 43.41422080993652, 44.07611109316349, 43.930259719491005, 41.91533423960209, 44.534723684191704, 44.97665897011757, 42.96277843415737, 43.476100489497185, 44.72384713590145, 43.68523366749287, 43.51896598935127, 42.98067547380924, 43.86704631149769, 44.723413959145546, 45.15082262456417, 45.840614810585976, 45.08804239332676, 44.56623159348965, 41.767529770731926, 42.000362277030945, 42.829789370298386, 41.70389838516712, 42.71688222885132, 42.6402023434639, 42.830336540937424, 42.81437359750271, 43.05067911744118, 47.63111673295498, 50.814635306596756, 49.82119381427765, 51.399359330534935, 51.90498299896717, 50.2329321205616, 51.859537437558174, 54.5229285210371, 59.92905803024769, 43.35315428674221, 52.9855690151453, 57.64032684266567, 50.54980471730232, 50.2535118162632, 47.68396809697151, 49.33678820729256, 48.04930329322815, 46.06300547719002, 39.83831629157066, 42.538060024380684, 39.609583765268326, 40.78508108854294, 41.782930344343185, 42.395164892077446, 42.5833497941494, 43.3558065444231, 43.25288526713848, 43.6891208589077, 42.52932049334049, 42.459468841552734, 42.730728685855865, 43.80901962518692, 43.42143662273884, 43.21154348552227, 41.4644580334425, 42.232845202088356, 44.35941629111767, 43.71508866548538, 42.28416904807091, 41.826346814632416, 43.445899710059166, 44.464982226490974, 41.7597021907568, 44.262384697794914, 42.83901147544384, 43.167462050914764, 43.816125243902206, 43.44061799347401, 42.425658255815506, 44.74178597331047, 42.85050965845585, 43.38837839663029, 43.180943727493286, 43.26624535024166, 44.47883628308773, 46.15157872438431, 44.626796543598175, 47.01093301177025, 47.77108982205391, 51.80529534816742, 53.40448893606663, 58.88904243707657, 60.33071547746658, 63.61331753432751, 64.46680873632431, 65.32939285039902, 66.47549495100975, 67.95026421546936, 62.58683681488037, 69.29182782769203, 72.04065352678299, 76.14150747656822, 68.59840303659439, 74.32092636823654, 20.42941376566887, 0.17004491295665503, 2.743101781234145, 0.37406582152470946, 0.28474627062678337, 26.58075738698244, 77.40685477852821, 66.24278023838997, 68.40566977858543, 45.09389407932758, 22.552088163793087, 25.006152279675007, 44.61287409067154, 53.20566460490227, 65.40798783302307, 15.377715937793255, 0.1280158432200551, 0.037197714336798526, 0.04893259421805851, 0.058987771262764, 0.0667543058807496, 0.03499996273603756, 0.04934903925459366, 0.224011977261398, 0.149593252572231, 0.1567768116365187, 0.10336456951336004, 0.11069733736803755, 0.08913304918678477, 0.16207920445594937, 0.1720204358571209, 28.895707167685032, 90.773154348135, 65.11001542210579, 60.879159048199654, 25.95510195940733, 33.92304070293903, 50.420706644654274, 67.9340010881424, 73.9135730266571, 78.17580431699753, 33.87922905385494, 0.20536953932605684, 0.19693005859153345, 2.8525387588888407, 2.6846716040745378, 53.47291186451912, 81.06303378939629, 66.42988979816437, 62.94148698449135, 57.09054574370384, 59.60867442190647, 56.26481585204601, 61.55369885265827, 64.63781476020813, 66.33392974734306, 65.86856111884117, 65.46243891119957, 60.3775517642498, 63.018995225429535, 60.93869045376778, 61.330780014395714, 61.42999269068241, 62.433507442474365, 63.65876689553261, 60.89389465749264, 57.44215227663517, 57.411354929208755, 57.648595198988914, 57.4511805921793, 53.87287080287933, 49.47224333882332, 46.384582221508026, 48.414851278066635, 46.65149509906769, 46.43244065344334, 46.503021866083145, 46.5906185656786, 44.72271479666233, 46.81618966162205, 47.718341052532196, 46.10488682985306, 44.9885181337595, 47.94830471277237, 46.352492943406105, 45.84798261523247, 45.73815330862999, 44.010754600167274, 47.04211413860321, 48.27541396021843, 48.70674781501293, 47.861167788505554, 46.22535556554794, 43.77630718052387, 46.83371052145958, 44.93735767900944, 44.35147851705551, 44.0682303160429, 44.44278381764889, 45.80060675740242, 46.07509642839432, 45.11632427573204, 49.509078562259674, 53.279692232608795, 52.83152908086777, 52.62803480029106, 54.757660925388336, 52.16361612081528, 55.81919476389885, 55.01973286271095, 62.81141996383667, 46.56258746981621, 55.09602136909962, 60.592380836606026, 54.437976479530334, 51.941088661551476, 50.619618371129036, 53.044671043753624, 51.08388885855675, 48.87639731168747, 43.25371362268925, 45.15155218541622, 41.614375188946724, 43.420756459236145, 45.309802293777466, 45.93442417681217, 44.90361548960209, 48.67326781153679, 44.185362830758095, 45.694664642214775, 45.637777894735336, 44.549782276153564, 46.10888421535492, 45.630402490496635, 44.35229927301407, 44.67674106359482, 43.158878311514854, 46.027614176273346, 47.014504820108414, 46.77571043372154, 45.64785875380039, 43.88437718153, 45.3021153062582, 47.224504351615906, 44.258767291903496, 46.27335079014301, 45.16406871378422, 45.587852373719215, 45.19045829772949, 45.84264010190964, 44.44906868040562, 47.14496321976185, 46.04914762079716, 46.80915243923664, 45.86249403655529, 45.31459383666515, 47.8145556896925, 49.163954481482506, 45.92889927327633, 49.44389306008816, 51.75433248281479, 54.37888965010643, 54.40784029662609, 62.9017449170351, 62.78876557946205, 66.15524813532829, 67.50406935811043, 67.4635711312294, 68.83160412311554, 71.35399237275124, 67.33148261904716, 71.18982598185539, 74.78445589542389, 77.56593704223633, 70.11601880192757, 77.75994703173637, 23.421266824007034, 0.2766880311537534, 5.893345540389419, 2.700680145062506, 0.45549910340923816, 31.190548427402973, 83.0255600810051, 71.97508424520493, 79.2425362765789, 63.23706552386284, 25.61683841049671, 30.181892551481724, 55.60006432235241, 64.47654381394386, 77.49921262264252, 20.554155372083187, 0.25709622306749225, 0.12741396145429462, 0.16774612537119538, 0.18624984106281772, 0.2183438095380552, 0.20231046597473323, 0.1264650811208412], [0.027087026501249056, 0.02477262598404195, 0.09391423169290647, 0.06151561901788227, 0.03501636419969145, 0.025243867494282313, 0.1258352500735782, 0.11694659930071793, 32.129643335938454, 68.26204508543015, 44.551780968904495, 37.50917807221413, 9.606716707348824, 50.99263295531273, 49.93757016956806, 51.478208899497986, 65.33107995986938, 66.75281167030334, 23.110046423971653, 0.2548312477301806, 0.0968199253838975, 0.7201915641780943, 1.5039112069644034, 44.2239573597908, 76.6318179666996, 60.264644622802734, 60.91682642698288, 49.43625546991825, 55.7888837903738, 57.50530108809471, 62.93919950723648, 57.65703834593296, 60.782484635710716, 60.73338747024536, 61.45089536905289, 59.09934975206852, 58.012817054986954, 54.437007531523705, 57.030246779322624, 58.32142889499664, 61.32163390517235, 56.7233220487833, 56.83010391891003, 54.75469708442688, 51.09270438551903, 51.09190262854099, 52.79506243765354, 48.405674770474434, 46.358777806162834, 44.12522345781326, 43.02313819527626, 41.326738223433495, 41.268684938549995, 41.222232431173325, 41.80502995848656, 42.25069284439087, 42.00648754835129, 40.70523217320442, 41.085124388337135, 41.7735106498003, 39.75121356546879, 41.41169026494026, 40.63595049083233, 41.54758617281914, 41.203400641679764, 42.87999227643013, 42.83114589750767, 41.97859704494476, 41.521181389689445, 40.51420882344246, 41.759022027254105, 40.632036700844765, 42.50853940844536, 42.960646748542786, 40.069864466786385, 40.705004185438156, 41.92636504769325, 39.87102493643761, 41.385608464479446, 43.440857380628586, 47.982867658138275, 47.75587923824787, 51.28768712282181, 52.70197123289108, 49.18540433049202, 52.05897353589535, 49.00708369910717, 56.14050932228565, 37.28459492325783, 46.4486163854599, 54.397630244493484, 47.131891921162605, 48.00412751734257, 46.14686317741871, 47.955376133322716, 45.47479324042797, 46.33244141936302, 37.59654678404331, 39.44616213440895, 39.526353031396866, 39.818697944283485, 40.211946442723274, 39.04523804783821, 38.60391452908516, 41.97830446064472, 42.68829256296158, 41.63157306611538, 40.24090088903904, 41.044914945960045, 43.240893110632896, 43.00399862229824, 41.34268216788769, 42.92127326130867, 40.481910556554794, 44.84840825200081, 40.57547673583031, 41.36833839118481, 39.49350759387016, 40.73159135878086, 39.21618327498436, 44.39551055431366, 40.93558721244335, 43.08722175657749, 41.690758690238, 41.97873003780842, 39.72668208181858, 43.57510417699814, 40.777618288993835, 41.65370687842369, 40.65998800098896, 43.525425642728806, 42.15157136321068, 41.74454480409622, 41.365404948592186, 43.01018089056015, 44.27997015416622, 47.89628550410271, 49.84654225409031, 58.667335733771324, 58.4449602663517, 61.863378435373306, 60.08040010929108, 62.50430144369602, 59.96478371322155, 61.03872388601303, 61.85259461402893, 65.09705051779747, 58.763421177864075, 60.32323367893696, 58.69435988366604, 69.07918363809586, 70.34933388233185, 75.98801091313362, 17.46348861604929, 0.07550044945674017, 0.6624999130144715, 0.08442165824817494, 0.15146539430133998, 14.503351505845785, 66.93565025925636, 61.83445058763027, 58.60196404159069, 39.09923315048218, 29.54011268913746, 18.528172485530376, 31.463814564049244, 49.63460862636566, 60.37534028291702, 13.950653113424778, 0.23540262307506055, 0.014408973402169067, 0.04364132619230077, 0.04616199366864748, 0.030268897462519817, 0.07298960059415549, 0.02062624134850921, 0.03618477552663535, 0.026035985829366837, 0.08209804582293145, 0.03025712514499901, 0.06247840719879605, 0.03369439880771097, 0.08196355382096954, 0.051866671346942894, 40.11428028345108, 78.06504786014557, 51.757630705833435, 47.9583665728569, 14.189930073916912, 46.30070932209492, 52.05442517995834, 59.56050060689449, 69.02106195688248, 73.22485998272896, 24.570952132344246, 0.20195723336655647, 0.07822191982995719, 1.9315749336965382, 1.7184427077881992, 45.571422055363655, 78.86157631874084, 61.32610246539116, 62.226844131946564, 52.3271669447422, 57.65727013349533, 60.061944499611855, 65.66785588860512, 58.92238564789295, 63.175611421465874, 62.78418302536011, 62.85977616906166, 60.08062429726124, 59.46748919785023, 56.16416685283184, 58.88420149683952, 59.968895092606544, 60.75765296816826, 58.73022235929966, 57.31760635972023, 55.92374235391617, 55.71305885910988, 53.11535865068436, 54.90715630352497, 50.616677328944206, 50.2651733905077, 44.028761833906174, 45.265048295259476, 43.15836913883686, 43.387166261672974, 43.50186690688133, 43.503428623080254, 42.60978117585182, 43.90556484460831, 44.1719039529562, 44.00224305689335, 42.60062366724014, 43.30778852105141, 42.209544852375984, 42.98940360546112, 43.6711972206831, 44.66389015316963, 43.805379420518875, 42.560228034853935, 42.815372943878174, 44.67846617102623, 43.32508139312267, 44.60166469216347, 42.758562192320824, 45.279419124126434, 44.69334617257118, 41.69600620865822, 42.419544383883476, 44.36863839626312, 41.76186807453632, 43.518487215042114, 47.9841747879982, 48.68354246020317, 50.26433363556862, 53.42211239039898, 53.38592313230038, 51.18170700967312, 52.652596682310104, 51.40659034252167, 58.44857767224312, 41.53693154454231, 49.119705855846405, 56.86144843697548, 48.94615396857262, 48.943630903959274, 48.716216906905174, 48.299763053655624, 49.51605498790741, 47.262544110417366, 39.371594935655594, 41.3370318710804, 43.510340452194214, 43.62214185297489, 41.69913724064827, 41.367745622992516, 40.64063563942909, 44.26066718995571, 43.78746718168259, 43.26874181628227, 42.55396597087383, 42.38795667886734, 43.56929048895836, 43.462972193956375, 43.63479137420654, 43.9386572688818, 42.743059024214745, 46.05830132961273, 44.01004783809185, 43.05376075208187, 40.99063865840435, 41.92763037979603, 41.23675525188446, 44.88789193332195, 44.22872990369797, 44.115921556949615, 45.04875250160694, 44.775197580456734, 43.313180431723595, 45.6130526214838, 43.53538490831852, 44.99201014637947, 44.00024436414242, 45.346607118844986, 44.24576818943024, 44.46546100080013, 42.93582268059254, 44.8614377528429, 47.451420575380325, 50.45070603489876, 53.20185340940952, 58.57109069824219, 59.51124384999275, 62.97837920486927, 62.55562148988247, 64.92035239934921, 61.69671557843685, 63.40720519423485, 61.237893998622894, 66.53468057513237, 59.059626683592796, 61.98677681386471, 58.16959664225578, 68.74098658561707, 70.55464446544647, 77.43425130844116, 18.374607525765896, 0.19767158286413178, 1.8364240019582212, 0.39103321731090546, 0.12285873322980478, 15.330803655087948, 75.43749645352364, 64.53464269638062, 66.16395726799965, 45.40342167019844, 29.17559824883938, 23.830991238355637, 40.43239161372185, 55.276150703430176, 71.97484105825424, 18.3134688064456, 0.5110544082708657, 0.05259376084723044, 0.06342235225019976, 0.0717820595309604, 0.06157663468911778, 0.019560617474780884, 0.0646819401299581, 0.12523749464889988, 0.14276139729190618, 0.17738513939548284, 0.18303907272638753, 0.1521739672170952, 0.14960572065319866, 0.1537633952102624, 0.33859288436360657, 52.3866793513298, 88.53398010134697, 61.40861123800278, 55.5275110155344, 18.922148644924164, 63.027749955654144, 64.5131054520607, 66.02358520030975, 75.98519906401634, 80.67653372883797, 27.437389120459557, 0.32274034281726927, 0.24090144754154608, 3.0147335305809975, 3.2575243525207043, 47.427272871136665, 82.83055454492569, 66.58362194895744, 64.53246921300888, 54.974602684378624, 60.86721248924732, 61.687474474310875, 68.49981352686882, 61.31931222975254, 66.42157584428787, 63.09613488614559, 63.475468531250954, 61.62247896194458, 62.516472190618515, 58.616399466991425, 59.54177901148796, 61.81081585586071, 63.57474200427532, 59.42333936691284, 60.67276172339916, 58.89264464378357, 56.59273065626621, 56.911411955952644, 57.1979545801878, 53.316428661346436, 52.6541393995285, 46.363451555371284, 47.519258335232735, 45.60030810534954, 45.940610244870186, 46.323063522577286, 45.29185965657234, 46.12789839506149, 46.464013159275055, 45.63059248030186, 47.12140068411827, 44.69325117766857, 44.862364903092384, 46.52411073446274, 45.05696766078472, 46.41067922115326, 46.298725828528404, 46.12212650477886, 46.434925720095634, 44.872441962361336, 46.0930884629488, 44.002273455262184, 46.214818730950356, 43.87823671102524, 47.614469826221466, 46.0906869918108, 44.65449705719948, 44.41200166940689, 47.55471043288708, 43.82727384567261, 47.233395874500275, 50.81401214003563, 54.32700723409653, 51.79308280348778, 55.17469994723797, 57.09907628595829, 55.39534650743008, 58.57730336487293, 54.46248896420002, 62.49184191226959, 44.71723549067974, 52.12630592286587, 59.44700829684734, 51.324773132801056, 51.70270845293999, 50.377252176404, 50.501649901270866, 51.97497524321079, 50.63623107969761, 42.36460693180561, 44.62567560374737, 45.79901084303856, 44.29259307682514, 45.16057290136814, 41.50503605604172, 43.07038106024265, 47.32181712985039, 48.50655935704708, 46.293546706438065, 45.448289662599564, 45.30625708401203, 47.95549772679806, 47.95284926891327, 45.4725893586874, 48.03111366927624, 45.030954256653786, 49.55281041562557, 45.95357894897461, 45.33595249056816, 42.19843044877052, 46.126553267240524, 43.541115000844, 47.366346940398216, 46.08258582651615, 47.911351695656776, 47.063617184758186, 47.108808159828186, 44.95489373803139, 48.706383034586906, 46.17265239357948, 45.65694406628609, 46.12789839506149, 48.651346787810326, 48.063294142484665, 46.81041017174721, 45.72771906852722, 46.6842607408762, 49.75810579955578, 51.80336885154247, 55.767532736063, 63.52463789284229, 61.386424228549004, 66.1439323425293, 65.53651973605156, 65.89428573846817, 63.083162382245064, 66.522878408432, 63.352389335632324, 70.02687558531761, 61.78702153265476, 62.776917815208435, 63.73102381825447, 72.04429373145103, 68.80407840013504, 76.37950390577316, 21.236532256007195, 0.535430753370747, 3.69440495967865, 0.36531581135932356, 0.16619966772850603, 17.9405340179801, 82.52367541193962, 70.6068080663681, 74.98180970549583, 51.223706156015396, 42.26475588977337, 29.943117164075375, 48.817686662077904, 65.29144808650017, 80.70855841040611, 26.74287758767605, 0.6275560380890965, 0.1716551507706754, 0.19184002390829846, 0.23156396811828017, 0.15258798171998933, 0.1481560242245905, 0.07012476955424063], [0.09080221352633089, 0.0524780859996099, 0.031099844964046497, 0.061066482376190834, 0.037174863609834574, 0.0706924828409683, 0.05925953832047526, 0.23960828490089625, 43.76548156142235, 63.328028842806816, 42.13542602956295, 28.22512485086918, 18.160838596522808, 40.44353261590004, 45.69056086242199, 57.615958750247955, 60.89737147092819, 67.19098135828972, 20.063711889088154, 0.004437560710357502, 0.048915487714111805, 1.510386890731752, 0.1927607471588999, 38.75253975391388, 76.31803080439568, 60.977980345487595, 61.239550709724426, 56.870757937431335, 63.447547629475594, 59.32907022535801, 62.25079424679279, 61.80179513990879, 64.51372101902962, 53.16640131175518, 54.40230019390583, 50.81182725727558, 54.92506094276905, 54.694873094558716, 54.780170917510986, 50.25343582034111, 52.28622794151306, 54.38713140785694, 56.19571655988693, 54.53294098377228, 53.85316506028175, 51.3712028414011, 52.47022546827793, 50.247728526592255, 47.90613077580929, 42.83685319125652, 41.93682588636875, 41.42718583345413, 42.42487169802189, 41.07177950441837, 42.02532313764095, 40.94401516020298, 42.12987072765827, 39.51672434806824, 41.034932881593704, 41.380315348505974, 41.74384944140911, 44.1671048104763, 41.86108835041523, 41.17508836090565, 41.74042582511902, 41.188000068068504, 43.77643257379532, 43.417807817459106, 42.6198810338974, 42.260739505290985, 39.73796747624874, 40.36309473216534, 40.0107092410326, 41.30240432918072, 40.163480043411255, 41.07764258980751, 40.920566618442535, 40.02847708761692, 38.546465411782265, 43.80219519138336, 45.41550502181053, 45.85148982703686, 47.29069299995899, 53.69713023304939, 51.553627252578735, 53.31046678125858, 47.646399512887, 54.58154037594795, 38.72922420501709, 43.214214742183685, 49.227943047881126, 48.109856843948364, 47.9787752777338, 47.18453049659729, 47.109450325369835, 46.27939626574516, 43.705889359116554, 39.173792749643326, 39.2628675699234, 38.245073184370995, 40.24872846901417, 39.518282264471054, 39.662055149674416, 41.01113095879555, 39.33170087635517, 38.73855650424957, 39.5715744048357, 40.646187141537666, 41.596272960305214, 40.75124770402908, 41.727818101644516, 42.839015275239944, 44.016602486371994, 41.17364823818207, 40.737203657627106, 42.223436906933784, 39.36758995056152, 41.441355273127556, 40.19578590989113, 42.22839564085007, 41.88638359308243, 41.50252819061279, 42.32439748942852, 39.647030755877495, 41.04841835796833, 40.70876598358154, 41.242728531360626, 41.70281924307346, 42.946652099490166, 42.57310174405575, 43.17299075424671, 42.816661074757576, 43.34940768778324, 44.229182079434395, 45.6384314596653, 46.76319770514965, 52.40810640156269, 56.58453069627285, 58.504373878240585, 57.196237072348595, 59.27363879978657, 57.387704998254776, 60.26192016899586, 58.31480585038662, 62.28860221803188, 62.28710129857063, 68.09983938932419, 61.830681189894676, 63.460128754377365, 57.9953645914793, 54.26972910761833, 50.10093480348587, 73.15479934215546, 17.40775130689144, 0.1460697580478154, 1.7027206951752305, 0.610434691188857, 0.15808251657290384, 7.929663872346282, 66.17843449115753, 65.98516926169395, 60.84925465285778, 48.326346427202225, 56.674813851714134, 13.500682208687067, 34.2297488451004, 39.09141696989536, 62.6436323672533, 24.060375429689884, 0.2743611903861165, 0.0590646577620646, 0.10459694283781573, 0.05696808315406088, 0.018452843323757406, 0.040515110740670934, 0.06349523115204647, 0.0065640517550491495, 0.02926210920122685, 0.022911794585525058, 0.06563953327713534, 0.09279807127313688, 0.06413734474335797, 0.030126791025395505, 0.7990162563510239, 54.598023891448975, 73.08753535151482, 49.56339664757252, 35.82896523177624, 24.97127965092659, 47.67884977161884, 52.41736650466919, 63.11098828911781, 65.19051030278206, 75.27244850993156, 22.25177127867937, 0.08853602106682956, 0.10871674559894018, 3.084581382572651, 0.05215203455009032, 39.81900952756405, 78.50848406553268, 63.67936559021473, 63.524793684482574, 59.21363241970539, 63.65810193121433, 61.28284938633442, 63.97611826658249, 65.88781848549843, 65.134037733078, 54.37810689210892, 56.67295575141907, 52.41277255117893, 57.23222494125366, 55.33484235405922, 55.42910009622574, 51.856151819229126, 55.19257798790932, 57.110502272844315, 58.40741068124771, 55.42536489665508, 56.728356778621674, 55.390741154551506, 53.4660380333662, 51.029072999954224, 50.97841411828995, 42.94507898390293, 45.2937975525856, 43.94534111022949, 44.12262819707394, 42.38444186747074, 43.70025426149368, 42.3846660554409, 43.51462282240391, 43.020793721079826, 44.82003517448902, 42.95101806521416, 43.62618863582611, 46.24002657830715, 42.91558116674423, 42.96202227473259, 43.421220034360886, 43.14462527632713, 44.01628330349922, 44.7567343711853, 44.230812191963196, 44.99020144343376, 41.03821210563183, 43.532972037792206, 41.949897184967995, 43.033827021718025, 43.00101198256016, 42.54929982125759, 42.34425142407417, 41.84085823595524, 40.25386959314346, 46.030502021312714, 47.75638461112976, 48.59980635344982, 51.934074237942696, 55.295351073145866, 54.581061601638794, 53.79759304225445, 52.352876365184784, 55.14919951558113, 42.50071182847023, 45.93802258372307, 52.26637780666351, 51.53825707733631, 50.66699802875519, 49.374174401164055, 49.39619421958923, 48.99652026593685, 45.327250957489014, 40.69124132394791, 41.59082405269146, 39.64357674121857, 40.60399800539017, 39.91444520652294, 42.17694640159607, 43.340664356946945, 42.97380544245243, 41.651043221354485, 40.97269222140312, 43.874615505337715, 43.17337453365326, 41.58472158014774, 42.96619065105915, 44.46760408580303, 45.941921174526215, 42.518004700541496, 42.46633507311344, 44.04040440917015, 42.35864505171776, 42.58265823125839, 42.49619387090206, 44.91987481713295, 43.66705164313316, 41.22303418815136, 44.259770438075066, 42.58295841515064, 44.90025646984577, 42.42785073816776, 41.974516063928604, 44.38303202390671, 45.13110548257828, 43.934906870126724, 44.5673069357872, 44.946066811680794, 46.50587931275368, 46.46309740841389, 47.6952800899744, 49.11288522183895, 54.58193555474281, 59.218241572380066, 60.200184881687164, 59.654777348041534, 62.62232691049576, 58.63333895802498, 60.83946257829666, 59.168582037091255, 64.49602916836739, 63.356333523988724, 66.91755563020706, 63.11369754374027, 65.9451650083065, 58.408459424972534, 56.72915853559971, 52.964081168174744, 74.97180104255676, 20.15324078500271, 0.37819634831976146, 3.472827449440956, 1.4550321735441685, 0.1987863628892228, 8.019732814282179, 72.53931596875191, 71.73179090023041, 68.84928837418556, 48.09562660753727, 59.86924163997173, 25.119992271065712, 43.54603573679924, 46.11432932317257, 69.95806887745857, 31.861126944422722, 0.4446742561412975, 0.02056731296761427, 0.027027706637454685, 0.029168609726184513, 0.06047180686437059, 0.015389997079182649, 0.057377648481633514, 0.16641104622976854, 0.16267035476630554, 0.13777366024442017, 0.2241473746835254, 0.19145207363180816, 0.17771089769667014, 0.16068206692580134, 1.611718072090298, 65.31988576054573, 80.64719930291176, 59.23708476126194, 43.640616461634636, 28.361482433974743, 50.23986674845219, 59.928085282444954, 71.9516471028328, 70.07374227046967, 79.98908221721649, 24.851308688521385, 0.29312586004380137, 0.15771596983540803, 5.566127048805356, 1.107723566237837, 43.64468604326248, 81.6111771762371, 64.43778589367867, 68.23810636997223, 60.86387246847153, 68.17553132772446, 63.092878460884094, 65.136948376894, 66.83331415057182, 66.96034893393517, 57.1593676507473, 61.12391151487827, 57.07668408751488, 59.256418123841286, 57.18345455825329, 57.224560752511024, 53.77598360180855, 54.95945289731026, 58.63585822284222, 60.60282647609711, 59.09297749400139, 59.88171637058258, 58.26017998158932, 57.77850642800331, 54.950318187475204, 52.73705095052719, 47.4579182267189, 46.48543640971184, 46.23868525028229, 45.65940633416176, 43.167291060090065, 48.11015322804451, 43.73284891247749, 46.13430865108967, 46.09466917812824, 47.87858225405216, 46.92684732377529, 47.830742821097374, 49.79080304503441, 44.66264761984348, 46.416420713067055, 46.70794866979122, 44.991740360856056, 48.25824648141861, 46.47582292556763, 46.79985053837299, 47.72358477115631, 44.07445818185806, 45.55411398410797, 43.580435290932655, 45.29803052544594, 44.82292301952839, 45.365419909358025, 44.38467733561993, 43.84070612490177, 42.91270852088928, 50.908228084445, 50.148394256830215, 48.715703934431076, 54.16194409132004, 57.508519515395164, 57.34223663806915, 58.779859095811844, 53.043660297989845, 58.304424807429314, 45.93511953949928, 50.851242542266846, 53.12093295156956, 53.38886797428131, 54.00706820189953, 51.465430185198784, 52.86100409924984, 50.59358976781368, 47.809957936406136, 43.491371870040894, 42.94433802366257, 41.78378149867058, 43.77550542354584, 43.774209693074226, 44.7561340034008, 44.80555035173893, 45.18641151487827, 43.382040336728096, 42.88698010146618, 45.41435368359089, 45.96774458885193, 45.546134412288666, 44.99625451862812, 48.167894929647446, 46.88532315194607, 44.98176209628582, 44.64467078447342, 46.07031248509884, 42.68714502453804, 45.761689245700836, 44.16824474930763, 47.10862196981907, 45.77473774552345, 44.361445382237434, 46.927827671170235, 45.09486682713032, 46.798839792609215, 44.514805153012276, 44.582574516534805, 46.5263906121254, 49.074290692806244, 46.745904833078384, 47.61689029633999, 48.59911099076271, 48.60550984740257, 49.76376749575138, 50.78766815364361, 51.87337629497051, 56.44841060042381, 62.15190835297108, 62.03374229371548, 60.68808250129223, 64.11903619766235, 60.4597869515419, 63.21127250790596, 60.86424104869366, 66.8256613612175, 65.49353644251823, 69.63311031460762, 65.07661521434784, 68.13950926065445, 60.410492196679115, 59.74728338420391, 55.72840243577957, 74.04912695288658, 21.13811943680048, 0.5111899541225284, 12.333633732050657, 2.497069020755589, 0.35254252958111465, 9.713535625487566, 78.57297420501709, 76.91006183624268, 75.32360136508942, 63.38137038052082, 69.4939997792244, 23.578753173351288, 53.356508910655975, 55.90866856276989, 81.14137038588524, 40.27334734797478, 0.8463275176472962, 0.14235373557312414, 0.22976071253651753, 0.19574726815335453, 0.16394101548939943, 0.13244915142422542, 0.12109943505492993], [0.09444470400922, 0.015339431774918921, 0.03858845084323548, 0.05790140065073501, 0.06395624586730264, 0.11679293020279147, 0.030383800476556644, 0.6524555082432926, 48.914064690470695, 64.64217692613602, 44.90816384553909, 32.33004458248615, 12.358890026807785, 31.473979018628597, 36.05400435626507, 64.05951619148254, 60.586950927972794, 70.74292436242104, 20.406413599848747, 0.1362390027497895, 0.14775502699194476, 0.9588336618617177, 0.3094201278872788, 24.29214209318161, 80.66468596458435, 58.05824741721153, 69.00745868682861, 53.67556259036064, 65.96132934093475, 59.065945744514465, 64.7368374466896, 55.73114588856697, 49.41303871572018, 51.448486894369125, 59.90131951868534, 58.86359520256519, 63.24207745492458, 59.09535616636276, 58.37637394666672, 54.322812259197235, 55.7867369055748, 51.35136030614376, 56.85788042843342, 56.39267139136791, 52.34170876443386, 53.14419910311699, 54.49139781296253, 51.43373228609562, 50.17744369804859, 46.46796494722366, 42.879524901509285, 42.247052639722824, 40.335420817136765, 40.050280317664146, 40.101592764258385, 39.94709685444832, 40.460962280631065, 40.77623136341572, 41.36195853352547, 39.349651113152504, 40.21158166229725, 41.62363149225712, 43.049930557608604, 40.927410051226616, 41.234057396650314, 41.821004301309586, 40.99944658577442, 42.72242233157158, 42.905705496668816, 41.33777663111687, 42.71176390349865, 39.55724157392979, 39.31969352066517, 40.204631835222244, 40.57644948363304, 38.13306279480457, 40.4314948618412, 39.171197488904, 39.09804381430149, 44.13305103778839, 47.961463406682014, 47.6992204785347, 46.42061948776245, 48.995391726493835, 50.14142543077469, 52.656540870666504, 49.546175971627235, 46.92030407488346, 39.944813176989555, 42.79537841677666, 47.97423832118511, 47.2888994961977, 47.3898296803236, 48.220810890197754, 46.18328042328358, 46.28902494907379, 45.121275410056114, 38.5347506403923, 37.923496440052986, 39.72309127449989, 40.384977757930756, 39.02415297925472, 38.929424062371254, 38.256658762693405, 40.54969131946564, 38.914863243699074, 40.14507383108139, 40.10398283600807, 44.46339011192322, 40.63160352408886, 40.64050264656544, 41.44738554954529, 43.152300864458084, 41.50406330823898, 40.96033148467541, 41.55576333403587, 42.02352203428745, 40.803240314126015, 43.83187919855118, 40.46072669327259, 42.475823163986206, 41.54494911432266, 44.73447136580944, 40.85525192320347, 41.02100282907486, 41.017001643776894, 40.64627453684807, 42.18492977321148, 41.94783769547939, 41.49418763816357, 43.65045413374901, 40.970362946391106, 43.31290304660797, 42.731370851397514, 45.24538055062294, 46.25762723386288, 51.54152110219002, 52.54585660994053, 57.26147957146168, 57.905533611774445, 61.58309407532215, 59.83350835740566, 63.08254301548004, 59.33556027710438, 63.85440319776535, 59.561325162649155, 64.15093928575516, 61.22856169939041, 68.00117388367653, 65.0221337378025, 73.66907894611359, 49.0426953881979, 63.68290700018406, 18.096454851329327, 0.3635125112487003, 1.3369259610772133, 0.1919988138251938, 0.06240475646336563, 3.2780066784471273, 60.905674025416374, 67.66258165240288, 64.2712028324604, 66.27618044614792, 45.04336439073086, 10.545764118432999, 24.356107860803604, 42.00899921357632, 58.710778802633286, 40.80804705619812, 0.8850648952648044, 0.05426943753263913, 0.09419994370546192, 0.08855813706759363, 0.028758378321072087, 0.041985650386777706, 0.03818768367636949, 0.016918187684495933, 0.04070734925335273, 0.028101688949391246, 0.033184914427693, 0.04022816676297225, 0.0707779559888877, 0.027932831799262203, 1.2413671449758112, 57.50713258981705, 71.92423537373543, 50.496554374694824, 37.85294182598591, 15.209469515830278, 32.05774359405041, 43.03150534629822, 69.96724918484688, 64.24768209457397, 75.56027546525002, 21.15446235984564, 0.14169013680657372, 0.21718488656915724, 1.3150482787750661, 0.8644707722123712, 24.592563472688198, 81.10544711351395, 60.081281661987305, 70.93003392219543, 57.486849278211594, 67.95980170369148, 61.721733435988426, 67.95923173427582, 56.790141463279724, 51.96088559925556, 55.033814907073975, 61.55909836292267, 58.98358516395092, 63.320953622460365, 57.26236492395401, 58.580521792173386, 56.16428844630718, 55.79783610999584, 54.67377282679081, 59.76961478590965, 56.99411451816559, 55.11682905256748, 55.29226943850517, 56.18823476135731, 54.21581380069256, 51.94133944809437, 48.753048330545425, 45.925654247403145, 43.62456612288952, 42.65936091542244, 43.56398217380047, 44.263190254569054, 41.50191642343998, 42.45183125138283, 42.43967570364475, 42.7222665399313, 41.447503343224525, 41.59827545285225, 44.23496536910534, 43.69816817343235, 42.0618087798357, 43.5635831952095, 43.91455516219139, 43.69384780526161, 44.52659972012043, 43.833171129226685, 45.143272429704666, 43.82374383509159, 41.93440541625023, 42.48213842511177, 41.07066236436367, 41.17587111890316, 40.73022723197937, 42.0253649353981, 40.73632590472698, 43.09459336102009, 45.57316996157169, 49.36261922121048, 50.619926154613495, 49.421474263072014, 52.11147531867027, 52.92141705751419, 55.02590373158455, 52.52928949892521, 50.97747556865215, 44.17736425995827, 46.68235704302788, 51.56748130917549, 50.76919734477997, 50.407836735248566, 50.451758578419685, 48.84439542889595, 47.879657596349716, 46.97253607213497, 41.30711607635021, 39.740422144532204, 41.82580724358559, 41.65095962584019, 39.552404433488846, 42.12571755051613, 40.22888593375683, 41.18778347969055, 41.151685416698456, 42.98709332942963, 42.29657918214798, 44.57113333046436, 43.26505221426487, 43.15983586013317, 44.5169672369957, 45.74397839605808, 42.7656602114439, 42.90131293237209, 44.058415442705154, 43.94218347966671, 42.59305067360401, 43.86056765913963, 41.45452156662941, 44.136862233281136, 42.92862966656685, 45.71494795382023, 40.75258903205395, 44.39089000225067, 42.83515468239784, 43.176079988479614, 42.37040162086487, 44.28087830543518, 42.43840657174587, 45.52609048783779, 42.28185877203941, 46.31122335791588, 44.92705263197422, 45.103929340839386, 46.771390065550804, 54.10249248147011, 54.695975035429, 60.487616658210754, 58.95881809294224, 64.16547730565071, 60.57501956820488, 64.94187444448471, 61.208369582891464, 65.68841278553009, 60.59137009084225, 67.01269492506981, 64.86767962574959, 69.83082130551338, 68.0040617287159, 73.41731205582619, 51.652216762304306, 67.34161287546158, 21.76089271903038, 0.3743769001448527, 2.6338590681552887, 1.9337344053201377, 0.19815725914668292, 4.04770097695291, 65.6618370115757, 74.12046432495117, 68.98107290267944, 68.03283378481865, 44.23662208020687, 12.844933345913887, 33.730588629841805, 50.623399168252945, 66.88159435987473, 52.01606623828411, 1.7971388599835336, 0.06403929961379617, 0.057283777932752855, 0.03821808204520494, 0.041154125865432434, 0.03685769566800445, 0.015464792577404296, 0.21187192556681111, 0.10837521665962413, 0.16580914962105453, 0.12208432439365424, 0.2539859712123871, 0.2840842748992145, 0.21103282371768728, 2.887971382588148, 69.93977665901184, 78.69564682245255, 60.789464861154556, 45.157016292214394, 19.303788766264915, 40.20737908780575, 52.13892124593258, 76.53493076562881, 69.33845892548561, 83.73255014419556, 24.796736016869545, 0.24070483777904883, 0.3075474814977497, 5.30775991268456, 0.6991349346935749, 26.894269064068794, 85.81797704100609, 63.59854392707348, 73.13886299729347, 58.99652346968651, 69.21232089400291, 63.85861337184906, 69.2563909292221, 59.96938906610012, 54.8920027166605, 57.21960201859474, 63.777487725019455, 60.315231308341026, 64.1412802040577, 57.601124346256256, 60.00330604612827, 57.95594170689583, 60.468974858522415, 57.32612170279026, 61.39347285032272, 57.20192536711693, 59.79052126407623, 58.85646678507328, 59.04403991997242, 56.90320059657097, 55.16318656504154, 49.37782980501652, 47.580701038241386, 45.55597968399525, 42.918738797307014, 45.92657379806042, 45.72871461510658, 43.421896398067474, 44.597108736634254, 44.66520868241787, 44.840823858976364, 43.71945843100548, 44.05870422720909, 46.6408708691597, 48.228178694844246, 43.45111683011055, 46.19387045502663, 47.04224333167076, 46.35327190160751, 45.928766280412674, 46.868471056222916, 45.32479628920555, 46.56862534582615, 43.50485734641552, 43.455649986863136, 44.95812736451626, 43.78747098147869, 41.881725043058395, 44.680005088448524, 43.42254996299744, 45.725887566804886, 49.30762857198715, 52.31803983449936, 51.1390732973814, 52.38213859498501, 52.79909782111645, 55.22680655121803, 57.299963906407356, 55.57378873229027, 52.26848289370537, 47.738696560263634, 50.59933505952358, 56.51131622493267, 52.528822124004364, 54.163665398955345, 55.52890554070473, 50.34968085587025, 51.433728486299515, 51.77428141236305, 43.09853374958038, 42.85504661500454, 44.794819727540016, 46.061546355485916, 41.328805312514305, 44.22534428536892, 42.2119577229023, 43.8315562158823, 42.738214284181595, 45.820540487766266, 44.052806943655014, 47.0221234112978, 44.389126896858215, 44.34595741331577, 45.774224773049355, 47.83901497721672, 45.983802527189255, 44.90579277276993, 46.53395600616932, 47.09760256111622, 44.47955444455147, 47.468629851937294, 43.37308421730995, 45.16738213598728, 44.977529123425484, 50.615989565849304, 42.063081711530685, 45.79543523490429, 45.080450400710106, 45.513976737856865, 44.51943330466747, 46.85360245406628, 45.812120139598846, 49.30789455771446, 45.40254011750221, 49.09513257443905, 48.28989118337631, 49.38858702778816, 49.808456897735596, 54.59381751716137, 57.41194389760494, 63.791045397520065, 62.56611652672291, 65.90932533144951, 63.53204749524593, 68.4735569357872, 64.67402681708336, 69.78634089231491, 63.77960041165352, 67.92738184332848, 68.01045298576355, 73.20064768195152, 70.55315494537354, 77.04361706972122, 51.73347920179367, 70.95873758196831, 21.046094074845314, 0.6533056532498449, 8.661202993243933, 2.6628282386809587, 0.28223427885677665, 4.368325397372246, 74.49583098292351, 79.00420546531677, 77.21505627036095, 80.83750829100609, 56.50316186249256, 20.164383687078953, 38.56050945818424, 59.777180179953575, 73.94761919975281, 65.34301891922951, 3.084235363639891, 0.1360956791904755, 0.20415586070157588, 0.14540126110659912, 0.1452276430791244, 0.1853498534183018, 0.13618276279885322], [0.06384427804732695, 0.09934526096913032, 0.07082194308168255, 0.07741718683973886, 0.04091097231139429, 0.11127803081762977, 0.08799152958090417, 2.377698663622141, 60.212929397821426, 53.62875670194626, 44.55791004002094, 32.96854332089424, 19.926734939217567, 49.422462210059166, 45.27983710169792, 63.674961626529694, 59.802065044641495, 67.6879794895649, 20.996322445571423, 0.19825722643872723, 0.05491609306773171, 1.6903354972600937, 0.8328974351752549, 8.065332267433405, 77.64629513025284, 64.60775077342987, 64.7842513024807, 60.8024487644434, 63.24923627078533, 61.967496648430824, 56.61214381456375, 48.79016473889351, 60.465760231018066, 63.10984455049038, 59.19484242796898, 54.24149662256241, 53.912514075636864, 54.319039061665535, 54.90502081811428, 55.08669286966324, 55.292030051350594, 57.60161072015762, 51.09110087156296, 62.72988773882389, 63.47226910293102, 54.635102301836014, 54.85409215092659, 52.850452065467834, 56.72141835093498, 49.074891060590744, 45.017430782318115, 45.48666760325432, 44.52629193663597, 42.51530684530735, 42.68963389098644, 40.009375512599945, 41.23434618115425, 40.236223340034485, 42.0550337433815, 41.22921645641327, 40.121564492583275, 42.474295645952225, 41.4545139670372, 41.03829190135002, 40.46599701046944, 40.57695485651493, 41.661796644330025, 42.55512870848179, 43.66603709757328, 44.886805191636086, 42.395609468221664, 38.7283768504858, 39.39473569393158, 38.09387929737568, 39.31349225342274, 39.730595871806145, 39.687411189079285, 39.36801552772522, 39.33265462517738, 42.65293166041374, 44.45566512644291, 45.97167357802391, 44.17459420859814, 47.51078858971596, 49.42767933011055, 50.389810502529144, 49.43335622549057, 42.84065678715706, 41.1572977155447, 43.6386139690876, 47.17640273272991, 49.17096130549908, 47.4441933631897, 47.716213166713715, 47.58882500231266, 45.11385440826416, 42.388560846447945, 38.567432686686516, 38.783903270959854, 40.6123423576355, 39.66183476150036, 37.99324929714203, 40.643458887934685, 38.59642133116722, 42.270531579852104, 41.65109261870384, 40.13788841664791, 40.16724944114685, 41.748363599181175, 44.062762409448624, 40.429860949516296, 40.03389559686184, 40.199084132909775, 41.823686957359314, 41.18603557348251, 41.23727962374687, 41.59725710749626, 42.53420703113079, 41.245642974972725, 41.58873416483402, 41.788348853588104, 40.42475402355194, 40.70836320519447, 41.65262393653393, 40.08247599005699, 39.76891681551933, 41.91511005163193, 39.64712955057621, 42.293273359537125, 42.01443292200565, 39.18276026844978, 41.27501919865608, 41.8352535367012, 40.82131214439869, 41.84013247489929, 43.64377409219742, 47.62010872364044, 51.129900589585304, 51.628840416669846, 52.4947227537632, 55.27431160211563, 57.74999275803566, 56.56897813081741, 56.22634671628475, 57.38392420113087, 59.5998664945364, 62.09980934858322, 60.10435402393341, 63.65409694612026, 60.56912608444691, 67.84071609377861, 63.38612012565136, 57.0990838855505, 26.202468685805798, 0.2689866756554693, 0.6013086496386677, 1.2497010477818549, 0.13246629503555596, 0.807985853170976, 54.42286469042301, 67.0654284954071, 69.82351049780846, 53.49230222404003, 50.59645101428032, 31.710123047232628, 20.770711451768875, 36.33776932954788, 57.316246032714844, 47.588167637586594, 1.6249366127885878, 0.11587523491471075, 0.018342237344768364, 0.04307590614189394, 0.06898362102219835, 0.017427033817511983, 0.08562516944948584, 0.01609606246347539, 0.021481256699189544, 0.06679079728201032, 0.06565425748704001, 0.04700735924416222, 0.16862065735040233, 0.058852147485595196, 3.4350570011883974, 68.21754947304726, 62.78157636523247, 50.49675956368446, 39.44077402353287, 19.408098869025707, 40.86498700082302, 46.78197629749775, 70.41558712720871, 64.29707944393158, 74.2316235601902, 21.568151861429214, 0.07661971205379814, 0.12144572116085328, 3.496391884982586, 2.101775757037103, 9.985449984669685, 81.4107683300972, 63.35649311542511, 67.77789786458015, 60.34979425370693, 67.56238102912903, 62.88724109530449, 59.31716926395893, 51.4777947217226, 64.00653183460236, 62.954930663108826, 60.665534511208534, 57.137986198067665, 57.9444283246994, 56.65782876312733, 58.610414788126945, 55.03096126019955, 58.84071663022041, 57.034544348716736, 54.582691714167595, 63.05533267557621, 59.70732472836971, 56.98678471148014, 56.63489319384098, 55.11779420077801, 57.00780898332596, 52.848016396164894, 47.88841612637043, 45.87971091270447, 45.684811770915985, 44.24474224448204, 44.02497723698616, 42.230709716677666, 43.48231315612793, 40.51368065178394, 43.55889804661274, 43.55401910841465, 43.61749090254307, 43.59955586493015, 43.50637346506119, 43.067603409290314, 42.67389513552189, 42.98908442258835, 43.35251972079277, 42.09121160209179, 46.05503350496292, 47.64204114675522, 43.26829344034195, 41.66840448975563, 42.53266431391239, 39.98302772641182, 41.666162610054016, 43.24802912771702, 42.717547193169594, 41.21863402426243, 40.96691273152828, 45.291380882263184, 47.0619110763073, 47.93244816362858, 47.82435156404972, 48.81457082927227, 52.295218259096146, 53.390741273760796, 51.513459607958794, 46.08424633741379, 46.416918486356735, 45.1908914744854, 48.24523217976093, 50.78156568109989, 51.04013420641422, 50.027252957224846, 47.67147056758404, 46.69858977198601, 43.33540543913841, 40.79152174293995, 40.03256566822529, 42.174712121486664, 42.01046213507652, 40.868137031793594, 40.9113635122776, 41.69061429798603, 44.89207550883293, 42.95237459242344, 40.82460276782513, 40.97005516290665, 42.37464219331741, 45.3015111386776, 42.51060649752617, 42.616833597421646, 42.8942035138607, 44.126006215810776, 43.087909519672394, 44.55321729183197, 43.00220511853695, 43.59430834650993, 43.533709198236465, 43.29672731459141, 43.63661527633667, 41.77388682961464, 43.624220341444016, 43.41536074876785, 41.78007289767265, 41.612669080495834, 43.92511859536171, 42.22768887877464, 44.792999625205994, 43.32112580537796, 41.40473663806915, 43.153003826737404, 43.93890805542469, 43.246406614780426, 44.59297455847263, 45.943080112338066, 49.65078055858612, 53.88636767864227, 54.03419494628906, 55.199873596429825, 57.28150449693203, 58.406916707754135, 59.40777540206909, 60.224796161055565, 59.42187264561653, 59.97798800468445, 63.0700720846653, 60.91526851058006, 67.06340700387955, 63.30296538770199, 71.43312692642212, 64.53173965215683, 61.84736989438534, 32.45672218501568, 0.17410100233973935, 2.316980534233153, 2.557167070917785, 0.05260210258711595, 0.935710477642715, 57.66947887837887, 71.84795066714287, 72.94418424367905, 62.27511294186115, 50.522864162921906, 27.296954356133938, 24.224855303764343, 43.611776009202, 66.49438753724098, 58.81989374756813, 3.523990991525352, 0.11026070220395923, 0.02805569805786945, 0.03896933216310572, 0.0747395477083046, 0.0406675404519774, 0.08704007399501279, 0.23385938635328785, 0.1981541866553016, 0.15248114214045927, 0.20230271795298904, 0.13483338989317417, 0.33295962726697326, 0.1897142012603581, 6.059012375771999, 78.75524282455444, 69.1017696261406, 59.701393246650696, 47.326650470495224, 28.596385829150677, 61.81657634675503, 59.58964504301548, 74.78179603815079, 70.07513299584389, 78.84091302752495, 25.013955160975456, 0.22014580346876755, 0.13417375419521704, 6.68786390684545, 2.5468009896576405, 11.646036878228188, 83.36618140339851, 65.28131783008575, 74.08767968416214, 63.12353901565075, 68.76275181770325, 64.65121284127235, 63.5977915674448, 54.30068224668503, 64.39377665519714, 63.14700275659561, 62.36543409526348, 59.00890700519085, 59.89649757742882, 60.80436386168003, 61.9154242426157, 58.942076191306114, 60.4425472766161, 61.67447917163372, 55.30953951179981, 64.22930628061295, 60.83381228148937, 59.148868694901466, 58.27134758234024, 59.517266526818275, 60.500433370471, 55.103643760085106, 49.30771976709366, 50.10635331273079, 48.09868544340134, 47.82055176794529, 46.38647072017193, 43.74878145754337, 45.38420990109444, 44.73549351096153, 47.04323887825012, 46.13194897770882, 45.27444899082184, 45.74222669005394, 45.26713818311691, 44.98733639717102, 43.63362863659859, 44.91428151726723, 44.715730771422386, 44.62618477642536, 47.9256921261549, 48.760602325201035, 46.74231022596359, 43.04205738008022, 45.013760179281235, 42.588688507676125, 42.57605418562889, 45.11673465371132, 44.6048679202795, 43.78856912255287, 42.37945653498173, 47.8383120149374, 47.87743851542473, 48.84307309985161, 49.35430906713009, 51.50373212993145, 54.555834755301476, 54.41604785621166, 53.847412168979645, 50.143161937594414, 49.45702135562897, 51.742032542824745, 53.0447356402874, 53.97352360188961, 52.108192294836044, 52.20434233546257, 51.555401757359505, 49.68530550599098, 46.13378807902336, 43.70080903172493, 41.85499727725983, 44.44107010960579, 43.9465456455946, 40.96541181206703, 43.57274450361729, 43.12585808336735, 47.924916967749596, 46.71891488134861, 43.983004689216614, 42.96798795461655, 46.10385708510876, 47.69471772015095, 43.51759426295757, 44.77263271808624, 45.61138831079006, 46.77268199622631, 45.167469531297684, 46.70258715748787, 46.57151699066162, 47.72190526127815, 46.3380841165781, 46.43470913171768, 46.31138674914837, 43.54705788195133, 45.003272742033005, 47.451215386390686, 43.70972715318203, 46.17005333304405, 45.753413289785385, 44.87182259559631, 47.155002281069756, 46.06079399585724, 43.71790051460266, 45.903581231832504, 46.30933865904808, 45.05339205265045, 45.498541966080666, 50.56493170559406, 52.43890754878521, 57.14217737317085, 56.20056509971619, 57.86580674350262, 61.341199055314064, 62.808406725525856, 61.67001821100712, 62.16928482055664, 63.270146548748016, 63.97111013531685, 65.68835958838463, 64.28753435611725, 70.34632444381714, 68.15848544239998, 73.52921605110168, 67.24429249763489, 61.61193832755089, 32.47368447482586, 0.4255526134511456, 7.082745842635632, 5.97382047213614, 0.27540277980733663, 1.5861351136118174, 62.96976886689663, 77.05845907330513, 81.08573377132416, 71.0012648999691, 66.10012829303741, 45.890908911824226, 34.90711569786072, 55.02955533564091, 73.99064049124718, 73.72996687889099, 6.62346163764596, 0.4182221833616495, 0.1668493141187355, 0.18572019995190203, 0.1842001627665013, 0.09692441977676935, 0.18769974529277533], [0.07077877977280878, 0.05259409110294655, 0.10854933934751898, 0.03194362790964078, 0.07050516476738267, 0.11731573613360524, 0.1606112066656351, 6.5572630148380995, 63.915830701589584, 52.861007899045944, 45.85870184004307, 31.338877268135548, 15.716910436749458, 40.042038559913635, 44.391064792871475, 66.93348437547684, 62.0790396630764, 68.06118786334991, 19.962869100272655, 0.1937065995298326, 0.03684831492137164, 1.9234212837181985, 0.3325305471662432, 2.2196696558967233, 41.16540268063545, 68.75101804733276, 69.06723707914352, 56.31263628602028, 61.969563737511635, 54.88706298172474, 55.685058161616325, 61.21040627360344, 60.459448769688606, 57.05246798694134, 58.23907591402531, 57.474648132920265, 59.48696315288544, 56.956397742033005, 57.24867045879364, 51.28010652959347, 50.49451008439064, 52.13643237948418, 57.52249136567116, 47.78125807642937, 56.64252318441868, 52.556435242295265, 53.69132414460182, 53.702655136585236, 53.634866774082184, 51.752717569470406, 47.43992619216442, 47.16901212930679, 43.625299483537674, 40.814130529761314, 40.56408114731312, 41.52951814234257, 41.1776228249073, 40.761495754122734, 42.11751379072666, 41.95233665406704, 43.375744074583054, 41.8653479218483, 39.547198712825775, 40.6736558675766, 40.2942880243063, 42.01785273849964, 40.883659198880196, 40.459085181355476, 41.823550164699554, 44.29806478321552, 43.39612238109112, 42.05316424369812, 40.17775967717171, 38.606509789824486, 38.23226407170296, 40.51240772008896, 39.96399074792862, 37.09018595516682, 38.653277680277824, 42.22522281110287, 42.17720478773117, 43.264687433838844, 46.892865747213364, 47.18688637018204, 49.335021302103996, 50.70303149521351, 47.62974500656128, 43.86606216430664, 42.82367169857025, 43.59231345355511, 47.497983276844025, 48.79772633314133, 48.86948548257351, 48.75763088464737, 44.3617607653141, 44.13912311196327, 42.89281278848648, 39.07821647822857, 39.224736616015434, 38.25087547302246, 38.734999895095825, 38.742185309529305, 41.71103060245514, 38.5965771228075, 39.385205805301666, 38.966624066233635, 40.39065085351467, 41.59121923148632, 42.99945026636124, 43.89994494616985, 42.39515349268913, 39.91146236658096, 39.982423558831215, 41.66681617498398, 39.8677609115839, 40.16973830759525, 42.25981995463371, 40.17341271042824, 40.931080654263496, 39.04227800667286, 42.15619571506977, 40.30316814780235, 42.20695719122887, 40.57998709380627, 39.76387828588486, 39.16374608874321, 39.21189710497856, 42.535445764660835, 40.587514489889145, 42.70822249352932, 42.30323262512684, 44.52311910688877, 42.16306194663048, 40.912393257021904, 41.25321216881275, 42.885159999132156, 42.252987921237946, 42.828657031059265, 44.57738019526005, 45.394970923662186, 46.271732077002525, 47.85572648048401, 45.92191144824028, 44.85965184867382, 43.93719434738159, 46.49459391832352, 47.468253672122955, 54.68604616820812, 56.95864722132683, 66.56493455171585, 67.20490381121635, 67.03278824687004, 58.97892281413078, 33.181913271546364, 0.5755555315408856, 0.5206827353686094, 1.5005479124374688, 0.058786356094060466, 0.45578880817629397, 44.10900592803955, 71.0648050904274, 65.07275462150574, 59.50202934443951, 35.507289692759514, 23.980737403035164, 20.989530310034752, 40.6698826700449, 57.09027595818043, 55.59230133891106, 5.243520084768534, 0.1398551618331112, 0.14416313613764942, 0.049412192311137915, 0.12144183230702765, 0.02437820417981129, 0.04621987747668754, 0.03173689154209569, 0.05822305116453208, 0.06604224487091415, 0.03646858764113858, 0.042668582100304775, 0.19856885424815118, 0.06919851730344817, 8.669924475252628, 70.10349467396736, 61.21820725500584, 54.97358053922653, 38.40153358876705, 16.8132409080863, 40.65733574330807, 53.24208565056324, 71.01170673966408, 66.00216954946518, 72.15235233306885, 21.361290961503983, 0.26664267643354833, 0.035273102766950615, 1.667059964966029, 1.2067876942455769, 1.3591893226839602, 49.93132710456848, 70.72799876332283, 71.04573011398315, 59.787736013531685, 63.013979494571686, 55.63414469361305, 59.622133299708366, 62.7849467843771, 61.33160077035427, 57.593243569135666, 59.83394533395767, 60.551913008093834, 60.736127123236656, 57.327060252428055, 57.560177743434906, 53.89133021235466, 53.857436031103134, 55.520971566438675, 56.03502318263054, 51.17053180932999, 53.711641654372215, 52.116441652178764, 55.05740024149418, 54.3917253613472, 56.84602126479149, 54.33104641735554, 49.225051403045654, 48.74561592936516, 46.45305834710598, 41.72712653875351, 43.490934893488884, 42.221198827028275, 44.26669366657734, 43.025680258870125, 44.61229272186756, 43.7087582051754, 44.510739371180534, 43.059243857860565, 40.53661622107029, 43.02004896104336, 42.43247129023075, 43.088133707642555, 43.704312443733215, 42.51896604895592, 43.395898193120956, 44.68540079891682, 45.359572023153305, 44.90378648042679, 42.273104041814804, 40.394591242074966, 41.16792194545269, 40.807021111249924, 41.06068029999733, 40.45667231082916, 40.451717376708984, 42.742587849497795, 43.88785399496555, 45.75450383126736, 47.803072705864906, 48.61746780574322, 52.57323794066906, 52.54194661974907, 50.57142935693264, 48.24859119951725, 46.258550584316254, 46.440731808543205, 50.10655850172043, 51.90922737121582, 52.32192322611809, 48.29560987651348, 47.22142271697521, 45.871355161070824, 45.3673730045557, 42.42147088050842, 41.12765930593014, 40.61298072338104, 40.93062087893486, 41.32748298346996, 42.83807672560215, 39.694152027368546, 40.458363220095634, 40.90882144868374, 43.336119800806046, 42.277633398771286, 45.36671184003353, 44.45498876273632, 45.29776453971863, 41.832836866378784, 42.489722818136215, 41.34681634604931, 41.88748553395271, 42.952131405472755, 42.74993285536766, 41.81223437190056, 41.7076525837183, 41.39069639146328, 44.40838046371937, 43.59593465924263, 43.83134722709656, 42.52403497695923, 43.08499127626419, 39.94816079735756, 41.571988463401794, 44.66045893728733, 44.046951457858086, 45.30268907546997, 44.216661751270294, 46.407392397522926, 43.59381437301636, 43.33948642015457, 43.7540365755558, 43.36616478860378, 44.52103681862354, 44.55960474908352, 45.950375720858574, 46.459039226174355, 49.08166989684105, 49.39268320798874, 48.52989010512829, 46.894788444042206, 47.53391034901142, 48.20649705827236, 50.458035841584206, 56.443045288324356, 59.68929469585419, 68.26774477958679, 69.8573362827301, 67.12503209710121, 63.01529802381992, 40.35032361745834, 0.756391390459612, 0.8654830022715032, 6.30828944966197, 0.07138575267163105, 0.46563001291360706, 49.36848230659962, 75.54123848676682, 67.8675502538681, 66.5876953303814, 43.07593256235123, 28.49314346909523, 30.15743136405945, 51.326315850019455, 62.6239912211895, 67.47772917151451, 8.309329524636269, 0.16950019140494987, 0.112240232701879, 0.07985305652255192, 0.05025365418987349, 0.026965505385305732, 0.08966870911535807, 0.21980782941682264, 0.17661118326941505, 0.19540544977644458, 0.3701801737770438, 0.12908961216453463, 0.293799462961033, 0.3391155938152224, 12.185252644121647, 82.38433688879013, 71.20102778077126, 61.3861620426178, 46.34966969490051, 25.60551691800356, 51.91336914896965, 61.298949122428894, 77.4761326611042, 73.26191559433937, 79.08927530050278, 24.879221990704536, 0.33774291747249663, 0.4154915252001956, 3.394566373899579, 1.9487354066222906, 3.133083642460406, 53.921979367733, 69.2002223432064, 70.50855293869972, 61.61869056522846, 66.63861259818077, 58.85220341384411, 58.47964480519295, 61.46296352148056, 62.75878518819809, 61.53816148638725, 62.17464253306389, 61.94444328546524, 61.88615821301937, 60.22858075797558, 60.930019319057465, 56.2373623251915, 55.150806829333305, 57.8132289648056, 56.839774399995804, 55.69017268717289, 55.05781061947346, 52.59111978113651, 56.795620769262314, 55.566770508885384, 57.58098542690277, 55.902729481458664, 51.4759062230587, 50.705189779400826, 48.06574121117592, 43.42511482536793, 45.991443917155266, 45.857094526290894, 46.58399172127247, 44.01808440685272, 46.94403000175953, 45.767483934760094, 47.42391385138035, 45.08985489606857, 42.71513432264328, 45.2474894374609, 45.55573649704456, 46.98875740170479, 47.815676629543304, 44.94567543268204, 45.301089361310005, 47.30526901781559, 46.29744149744511, 47.50551447272301, 45.552221685647964, 43.327878043055534, 43.32696609199047, 42.53771424293518, 43.688558489084244, 41.758953630924225, 41.606323421001434, 46.908319517970085, 47.7788832038641, 46.79828882217407, 50.314665734767914, 50.680126324296, 56.04334093630314, 56.94875255227089, 53.231233432888985, 51.071615517139435, 51.600018963217735, 51.5571990609169, 52.76443228125572, 53.17406930029392, 55.392747446894646, 55.176995024085045, 51.102545857429504, 48.65516938269138, 48.50361831486225, 44.50008474290371, 43.563438802957535, 42.82243676483631, 43.87985162436962, 42.35562801361084, 45.79144544899464, 42.042646408081055, 43.08711536228657, 44.75258879363537, 44.628331661224365, 44.12930063903332, 47.72699698805809, 45.38954861462116, 47.174571231007576, 43.58560301363468, 44.27992835640907, 45.43844439089298, 45.02091519534588, 46.23177342116833, 46.15610048174858, 43.43736916780472, 44.41357098519802, 43.68052192032337, 46.307697147130966, 45.42425215244293, 45.36841034889221, 46.36563263833523, 43.49023573100567, 42.13840126991272, 42.9044895619154, 48.08386243879795, 46.50215171277523, 47.03938588500023, 45.423929169774055, 50.09580507874489, 47.13083937764168, 46.86969459056854, 45.293474569916725, 46.28452219069004, 46.75333723425865, 47.631242126226425, 48.54836471378803, 48.83628286421299, 50.6538051366806, 53.99542562663555, 50.92758424580097, 49.63587775826454, 48.117198050022125, 50.558802634477615, 52.63352930545807, 61.59555360674858, 61.768064349889755, 72.98814788460732, 72.81781822443008, 72.46130615472794, 63.247446566820145, 41.791555881500244, 0.8665096003096551, 4.731103805825114, 8.76722490414977, 0.10772374458611012, 0.7782098196912557, 53.02642062306404, 83.56286644935608, 74.29827958345413, 76.90907388925552, 46.75459876656532, 39.80716556310654, 35.739172250032425, 62.22437046468258, 72.80964106321335, 82.03593358397484, 14.56438573077321, 0.46939445310272276, 0.2663789765210822, 0.3648380166850984, 0.157572868920397, 0.1508640468819067, 0.12335413906839676], [0.029840576207789127, 0.010288884914189111, 0.08887735704774968, 0.044709933499689214, 0.08264473406597972, 0.132527151145041, 0.1488843679544516, 8.487635906785727, 67.82276585698128, 47.55770847201347, 44.56656217575073, 28.178689442574978, 38.96072678267956, 60.865380987524986, 41.3819644600153, 69.82546359300613, 53.966737166047096, 70.0693117082119, 14.883685447275639, 0.12165533335064538, 0.053608714588335715, 3.924446040764451, 0.9735908231232315, 1.0102247167378664, 24.316854067146778, 47.95126475393772, 60.34872271120548, 64.0326364338398, 49.80406053364277, 51.3947007805109, 60.57988330721855, 57.501660883426666, 58.721961602568626, 63.05942505598068, 61.52864679694176, 61.16304561495781, 57.91440233588219, 59.69782143831253, 54.6844806522131, 58.52099038660526, 53.75399798154831, 53.08096669614315, 50.898268818855286, 53.77842307090759, 33.04077364504337, 32.12976112961769, 46.486215367913246, 50.68096987903118, 54.23053801059723, 53.73844541609287, 51.75339013338089, 47.740695253014565, 42.36322000622749, 42.32927642762661, 40.81089310348034, 39.293140545487404, 39.37257908284664, 40.55324412882328, 40.947290584445, 40.79484276473522, 39.84430477023125, 39.17870208621025, 41.92665383219719, 39.39538165926933, 38.58656845986843, 39.35553319752216, 39.514227882027626, 38.690914660692215, 40.70406563580036, 41.96849338710308, 42.82904461026192, 42.31478400528431, 40.08890524506569, 39.9858395755291, 36.00312888622284, 38.66178162395954, 37.84613259136677, 38.430032059550285, 38.03153224289417, 39.83155645430088, 42.108314484357834, 44.85713638365269, 44.55387845635414, 47.351656928658485, 47.48864717781544, 50.64455643296242, 48.931805938482285, 46.08063653111458, 41.69417470693588, 46.80339574813843, 47.795233726501465, 51.203236654400826, 47.84305416047573, 47.30567179620266, 45.19971460103989, 42.816771268844604, 38.22110407054424, 37.463496923446655, 39.93418134748936, 39.809958413243294, 35.584296360611916, 39.388694018125534, 40.23586995899677, 39.48378771543503, 40.04633232951164, 42.93118312954903, 42.084417566657066, 43.78831073641777, 44.17844720184803, 43.60476918518543, 40.04140019416809, 41.04309484362602, 38.586040288209915, 38.67755837738514, 39.356357753276825, 38.66100646555424, 40.08863925933838, 40.01622274518013, 40.017256289720535, 40.35623989999294, 40.55976837873459, 39.31015223264694, 40.45162618160248, 41.76868110895157, 38.83454315364361, 40.86161658167839, 41.22816391289234, 41.593065932393074, 45.514569506049156, 49.13314573466778, 49.6067713201046, 52.48649999499321, 49.5391995459795, 49.934648126363754, 47.191206738352776, 47.22168490290642, 44.56208601593971, 43.27477589249611, 41.58441759645939, 42.886163145303726, 43.506749644875526, 44.049189537763596, 44.81114365160465, 46.16123020648956, 46.01863905787468, 48.12080405652523, 47.96440824866295, 46.99105627834797, 49.420668706297874, 58.570881709456444, 62.40928374230862, 69.19348910450935, 59.53776642680168, 36.37614347040653, 1.6990385740064085, 0.7646222237963229, 3.0710336845368147, 0.2693540387554094, 0.08495233094436117, 35.694608241319656, 72.68434658646584, 64.9423000216484, 57.098483517766, 56.72041520476341, 27.128292806446552, 8.701419085264206, 33.16301688551903, 48.39893393218517, 65.0536796450615, 11.986188925802708, 0.2745749882888049, 0.08498864423017949, 0.04351249306637328, 0.12899227207526565, 0.038601872583967634, 0.0462752825114876, 0.08118417259538546, 0.054110881392261945, 0.05458091320178937, 0.048612357495585456, 0.06348417315166444, 0.18283567973412573, 0.12463090766686946, 10.598572734743357, 77.08563521504402, 52.929172441363335, 49.28847000002861, 35.64358837902546, 31.12940590828657, 48.678032755851746, 48.274201825261116, 77.257120013237, 59.54784728586674, 76.91684067249298, 15.891478769481182, 0.12387163122184575, 0.32771599770057946, 5.305716572329402, 2.8685601241886616, 0.8337583264801651, 27.4395702034235, 51.80792860686779, 63.042337372899055, 63.09276446700096, 52.58567467331886, 53.17830987274647, 59.94061700999737, 58.69462966918945, 61.43829144537449, 64.59667056798935, 61.948459669947624, 61.387222185730934, 62.10466168820858, 60.30204601585865, 57.22811356186867, 59.19113762676716, 54.273521304130554, 55.72498641908169, 52.576475366950035, 55.354605093598366, 34.85364116728306, 32.5370042771101, 49.510811269283295, 52.61981964111328, 58.51619504392147, 55.736226215958595, 53.78557428717613, 49.72829259932041, 44.13853794336319, 44.1313449293375, 42.444566041231155, 41.077604591846466, 41.43734268844128, 42.55322881042957, 42.567550241947174, 43.246646001935005, 42.66609035432339, 42.17118591070175, 44.27738629281521, 39.4305145740509, 41.75672695040703, 41.30774304270744, 42.059711292386055, 39.970898777246475, 42.10999019443989, 44.096113219857216, 43.9943964779377, 43.36643077433109, 43.72817896306515, 41.42960250377655, 38.361799120903015, 39.82598215341568, 41.09921783208847, 40.64393766224384, 40.77082805335522, 41.34819947183132, 44.43201519548893, 47.42767184972763, 45.37426583468914, 48.24216194450855, 50.00352703034878, 52.007246911525726, 52.34934255480766, 49.53367844223976, 45.91960497200489, 49.408809542655945, 51.43053285777569, 51.99240490794182, 50.5117953568697, 50.71406230330467, 46.63500398397446, 43.94752599298954, 40.55925540626049, 40.064480155706406, 42.22819045186043, 40.1162675768137, 39.21277105808258, 41.30896657705307, 43.45681272447109, 41.6730098426342, 41.732841432094574, 44.235725328326225, 43.846462815999985, 44.51881393790245, 47.43864186108112, 45.48718437552452, 41.53766490519047, 40.63075616955757, 40.83345249295235, 40.72993844747543, 41.00241422653198, 41.73773556947708, 41.14028602838516, 42.957998290658, 42.251855581998825, 42.4886778742075, 42.90399178862572, 41.33869618177414, 42.13934741914272, 42.142968624830246, 41.15298494696617, 42.52197168767452, 42.96060875058174, 44.143952652812004, 47.0003467798233, 50.58820925652981, 52.011601477861404, 54.267734214663506, 51.923818588256836, 51.88512526452541, 49.10525903105736, 48.42693842947483, 45.50727769732475, 46.019611805677414, 42.73915283381939, 45.3925846517086, 46.23626098036766, 46.03688187897205, 46.2456426769495, 47.662404254078865, 49.64925304055214, 51.168840900063515, 50.82070358097553, 49.2762840539217, 52.00093165040016, 61.6405887901783, 66.88161715865135, 70.82674786448479, 64.74271953105927, 44.3407478928566, 2.3300204845145345, 0.4374624806223437, 2.4659429909661412, 0.16683041903888807, 0.031675879581598565, 38.01800116896629, 78.7234765291214, 70.3843604028225, 65.47968998551369, 55.41345253586769, 34.069481045007706, 16.451116539537907, 39.68735419213772, 55.792212411761284, 76.26157343387604, 18.62757135182619, 0.30229604453779757, 0.054198922371142544, 0.08158212702255696, 0.10289194018696435, 0.03280181779700797, 0.029161160418880172, 0.1484390496625565, 0.19358795980224386, 0.3154363628709689, 0.15201038302620873, 0.16552928573219106, 0.45960285351611674, 0.3297783370362595, 14.94354173541069, 89.50700908899307, 62.52051517367363, 59.00367088615894, 44.12371873855591, 51.836978048086166, 73.97211268544197, 57.08665855228901, 80.80284655094147, 64.58745986223221, 82.28009328246117, 18.12547769397497, 0.2850988501450047, 1.7501079523935914, 12.772786617279053, 5.836620284244418, 1.4563068863935769, 30.1720092818141, 53.07433985173702, 64.06878009438515, 63.80993038415909, 55.091765597462654, 53.965673223137856, 62.700769901275635, 60.76894596219063, 63.89844283461571, 66.91486537456512, 64.75871667265892, 62.82730311155319, 63.721474930644035, 63.70181858539581, 58.63201282918453, 60.43899826705456, 56.92419447004795, 56.87572427093983, 53.822964280843735, 57.32973150908947, 40.12246124446392, 34.98431995511055, 49.1846139729023, 53.308479487895966, 59.54491384327412, 58.87479320168495, 56.815687492489815, 50.978934690356255, 44.84336592257023, 46.924647241830826, 45.54060950875282, 43.528340086340904, 45.618182346224785, 45.15455782413483, 46.408300548791885, 45.204190760850906, 44.68425706028938, 41.894047781825066, 47.97243341803551, 41.39162354171276, 46.00009985268116, 44.76838834583759, 43.87618862092495, 41.20264068245888, 44.144948199391365, 46.309779435396194, 45.812728106975555, 45.22763550281525, 44.57447715103626, 44.207762628793716, 38.82486507296562, 42.949927523732185, 42.07051411271095, 43.37860532104969, 43.38266730308533, 45.30680425465107, 47.063290402293205, 49.12447080016136, 48.9225610345602, 51.57172188162804, 53.144856467843056, 54.96960215270519, 52.938519939780235, 51.409922763705254, 50.11083327233791, 54.16385918855667, 52.3883930593729, 55.89204825460911, 53.611380234360695, 54.634330943226814, 50.25454916059971, 47.01238073408604, 43.03083658218384, 42.645525857806206, 45.21920755505562, 43.30852188169956, 40.87265498936176, 43.56881931424141, 44.840326085686684, 44.7321230918169, 43.79589132964611, 45.52031859755516, 45.685453936457634, 45.89038074016571, 48.9437410980463, 48.12835045158863, 42.59554713964462, 43.456668332219124, 42.530411034822464, 40.82386940717697, 43.43044213950634, 44.60811294615269, 45.2573499083519, 46.36118307709694, 44.8534581810236, 46.16395466029644, 45.976746305823326, 43.86647254228592, 43.31182390451431, 46.1663219332695, 42.585105299949646, 45.686749666929245, 44.51416298747063, 46.648842841386795, 48.167096972465515, 53.49311538040638, 53.57384964823723, 59.610160142183304, 55.80405257642269, 55.61820074915886, 52.17207446694374, 51.26189410686493, 48.57182465493679, 49.998397305607796, 45.35019412636757, 47.8597466647625, 48.30032542347908, 50.24770952761173, 50.1676744222641, 52.074731290340424, 51.484288573265076, 55.32129228115082, 52.19967618584633, 52.42208585143089, 54.591112062335014, 64.445621073246, 70.16690567135811, 75.8989816904068, 63.393438532948494, 44.7346081584692, 3.10594882350415, 2.830561213195324, 10.818776618689299, 0.3381614590762183, 0.20963991642929614, 42.570225298404694, 85.79965442419052, 75.2179442346096, 74.67545494437218, 70.35277649760246, 39.50824700295925, 18.949357084929943, 49.11615304648876, 65.03043249249458, 84.7577503323555, 27.569074854254723, 0.4794812493491918, 0.25141362799331546, 0.1756165421102196, 0.25724067469127476, 0.17541899724164978, 0.23443662881618366], [0.06618492276174948, 0.10580375659628771, 0.0800933936261572, 0.1043230012874119, 0.06114296440500766, 0.11131235514767468, 0.02949441441160161, 8.216083478182554, 67.96512141823769, 56.39384552836418, 46.32334090769291, 20.928864665329456, 23.67743957787752, 67.86551356315613, 48.73787574470043, 70.85151493549347, 56.050317361950874, 71.34140744805336, 15.443230122327805, 0.2859546057879925, 0.2185532436124049, 0.48233795387204736, 0.9299565176479518, 0.1520210551097989, 16.503112949430943, 45.44609718024731, 41.11741125583649, 49.80195164680481, 59.4191899895668, 60.3646894544363, 60.271024480462074, 62.955170050263405, 59.257531464099884, 57.64274351298809, 57.7877589315176, 57.993875071406364, 56.42680875957012, 57.976529002189636, 59.41135860979557, 55.436266511678696, 54.92822617292404, 57.134786769747734, 53.17279636859894, 52.51722514629364, 52.46664606034756, 49.6803467720747, 52.258789613842964, 49.795165210962296, 55.07661961019039, 54.373421743512154, 53.07090863585472, 48.12123343348503, 40.0040215998888, 38.13954144716263, 39.03303310275078, 37.70581752061844, 38.57383154332638, 38.137660548090935, 38.34149681031704, 42.330507561564445, 39.71087113022804, 39.725853726267815, 41.18668533861637, 40.75814813375473, 39.46577288210392, 40.76764762401581, 41.08988553285599, 38.377268090844154, 38.99469316005707, 41.90883658826351, 42.49775938689709, 41.307100877165794, 41.65830463171005, 39.65601347386837, 38.90771962702274, 37.480056434869766, 38.875744342803955, 39.194611832499504, 38.391228541731834, 39.17713277041912, 42.20700278878212, 43.9446647465229, 44.43151742219925, 45.82705333828926, 49.20852608978748, 49.97006982564926, 47.48528055846691, 45.996254459023476, 42.180913388729095, 44.12901185452938, 46.27667561173439, 47.177348881959915, 47.074541598558426, 46.13659992814064, 44.157966300845146, 40.78682519495487, 38.62930476665497, 37.11976356804371, 38.03403250873089, 38.10408174991608, 40.099586471915245, 39.464834332466125, 39.74070332944393, 40.838536620140076, 42.39751696586609, 41.54252864420414, 41.970476880669594, 41.711885556578636, 41.74566574394703, 44.85104151070118, 41.739145293831825, 39.834406301379204, 38.259333819150925, 38.80539491772652, 39.023932591080666, 38.35296079516411, 40.892372131347656, 40.59324458241463, 40.95021642744541, 40.10922655463219, 39.64591361582279, 39.245643094182014, 40.708792582154274, 41.119964718818665, 40.23208536207676, 41.17903254926205, 39.1114266961813, 44.09814611077309, 50.30960060656071, 53.57465900480747, 51.78098805248737, 52.999738454818726, 55.70087671279907, 54.7936449944973, 53.01692113280296, 53.29256974160671, 51.79249003529549, 51.311515644192696, 45.21046802401543, 48.197255954146385, 46.402125880122185, 52.0302926748991, 51.79120570421219, 56.23833507299423, 56.024737134575844, 59.178742691874504, 55.19431449472904, 59.88167457282543, 53.30088369548321, 58.68715927004814, 60.64134120941162, 67.82369300723076, 55.72065845131874, 40.555751994252205, 3.1030020816251636, 0.39633678272366524, 4.61598708294332, 0.33082832756917924, 0.2202306457911618, 25.471334718167782, 70.41279047727585, 65.85643976926804, 59.182284101843834, 60.659112855792046, 35.61304561793804, 17.577406503260136, 39.70273196697235, 46.45361691713333, 62.18766063451767, 26.602686010301113, 0.18275307869771495, 0.08180192147847265, 0.03950095851905644, 0.07891742352512665, 0.061637000981136225, 0.0976166728651151, 0.037111450801603496, 0.09968419981305487, 0.02438248266116716, 0.037786051907460205, 0.09742766269482672, 0.13069990935036913, 0.21431813336675987, 10.831120256334543, 79.0759988129139, 62.500205263495445, 50.76431840658188, 27.93617505580187, 31.77510716021061, 66.87134250998497, 51.918415278196335, 76.56906053423882, 60.86009547114372, 77.09002777934074, 16.540852524340153, 0.246291384100914, 0.1638953437213786, 4.781770762056112, 3.8438834762200713, 0.19707878498593345, 17.988690733909607, 47.69975244998932, 46.15141533315182, 52.426888793706894, 61.226034834980965, 59.46106754243374, 61.87097042798996, 63.861318826675415, 62.95104347169399, 59.178066328167915, 59.37122896313667, 61.87161639332771, 59.00564298033714, 60.17241217195988, 60.30186742544174, 57.920987382531166, 56.366331204771996, 57.236522510647774, 55.4136311262846, 53.252398297190666, 51.988810300827026, 52.9141366481781, 54.65959198772907, 51.491549983620644, 56.38853341341019, 56.53264448046684, 56.70264735817909, 49.20280359685421, 42.22178399562836, 39.56963650882244, 41.76135890185833, 39.87853333353996, 42.50444322824478, 40.33926621079445, 40.36046527326107, 42.914528623223305, 41.969234347343445, 40.953476652503014, 42.33396537601948, 41.925407499074936, 42.707093954086304, 45.39397917687893, 41.9627670943737, 40.02509526908398, 42.27221108973026, 45.064582452178, 43.386687487363815, 42.959958985447884, 44.15759012103081, 42.53071501851082, 40.948597714304924, 40.215377658605576, 40.191666930913925, 40.958237797021866, 39.40012760460377, 40.514968782663345, 44.274441450834274, 45.58022998273373, 46.19586914777756, 48.34541380405426, 51.2899935990572, 51.96001544594765, 49.63390186429024, 47.482624500989914, 46.66502237319946, 46.74280419945717, 50.2523984760046, 49.425600841641426, 47.290104031562805, 48.42078655958176, 47.578968331217766, 41.573086604475975, 39.31967072188854, 40.0540991127491, 40.689516216516495, 39.909748658537865, 41.9927778840065, 41.475253254175186, 40.93150623142719, 43.47515054047108, 43.107725456357, 42.45065711438656, 42.66351029276848, 42.518741860985756, 43.59728738665581, 46.10030807554722, 43.81726138293743, 41.53568521142006, 40.60695804655552, 41.313875913619995, 40.47097474336624, 39.83293958008289, 42.25806064903736, 41.882359609007835, 42.68854334950447, 41.88685476779938, 41.0897221416235, 42.87989728152752, 42.35725052654743, 42.83993862569332, 42.154166623950005, 42.415083423256874, 41.275767758488655, 46.8764354288578, 52.01664760708809, 56.09160594642162, 53.2616052031517, 57.078466191887856, 58.46523217856884, 57.053144350647926, 54.94361154735088, 57.17822603881359, 52.91181497275829, 53.521773442626, 48.0118753015995, 49.07492145895958, 48.930536806583405, 54.97928783297539, 55.35890266299248, 59.43244747817516, 59.06953275203705, 61.78458206355572, 56.443079486489296, 62.923339158296585, 54.90177199244499, 59.52804274857044, 63.03848817944527, 69.81746882200241, 61.47490628063679, 48.00242140889168, 3.6085457168519497, 0.2705513604450971, 4.0909569058567286, 0.48777317628264427, 0.18122048437362537, 27.36310500651598, 78.80771800875664, 70.02452731132507, 67.01496720314026, 58.12972158193588, 31.508712954819202, 18.89984954148531, 46.48384429514408, 53.96794930100441, 71.01759642362595, 33.2431697845459, 0.200419740867801, 0.12613500352017581, 0.06188097831909545, 0.11021714555681683, 0.07319200653000735, 0.05949156708084047, 0.16051098704338074, 0.21225796110229567, 0.18704753107158467, 0.2576692501315847, 0.15585654851747677, 0.2030623803148046, 0.37153503857553005, 15.755021441727877, 91.51429697871208, 71.84063225984573, 62.44137302041054, 34.52865220606327, 37.06448033452034, 77.1852658689022, 62.22665034234524, 82.44180500507355, 68.18489402532578, 84.06304121017456, 18.82122416049242, 0.3177624911768362, 0.9792408824432641, 7.917680740356445, 4.773985454812646, 0.5445085850078613, 21.151944994926453, 49.5445154607296, 52.607842683792114, 53.271982446312904, 58.52624170482159, 61.00374296307564, 66.5045253932476, 67.35163673758507, 63.70717249810696, 61.07895612716675, 61.436684131622314, 62.79701113700867, 61.1066148430109, 62.40319646894932, 62.1943748742342, 58.21679010987282, 57.21512205898762, 61.14560455083847, 56.56676284968853, 55.786964893341064, 53.76172676682472, 54.936958104372025, 56.83772251009941, 52.675870433449745, 58.85450229048729, 59.288651794195175, 59.316804483532906, 51.76582686603069, 45.01213766634464, 41.34051248431206, 43.88501554727554, 41.85828410089016, 45.166124403476715, 42.58730158209801, 43.14228840172291, 46.489259004592896, 43.50765019655228, 43.46312418580055, 44.28250461816788, 43.98650050163269, 46.00582614541054, 47.80631013214588, 46.10125422477722, 41.18217118084431, 42.44324371218681, 46.62066735327244, 46.045157834887505, 44.228102937340736, 46.889719516038895, 43.47527593374252, 44.029852375388145, 42.048213109374046, 42.955030649900436, 42.652118504047394, 41.50074988603592, 42.824823036789894, 45.74504613876343, 47.52765208482742, 49.7582083940506, 50.62572844326496, 54.00086313486099, 55.871962532401085, 54.17546756565571, 50.759633257985115, 50.158881694078445, 49.94624510407448, 51.92544870078564, 51.32113292813301, 51.07821196317673, 49.579207599163055, 49.65052217245102, 44.97071608901024, 43.24443832039833, 41.87827102839947, 42.42137968540192, 41.77544094622135, 43.675483390688896, 42.628631964325905, 44.42944273352623, 45.03685154020786, 44.71509240567684, 43.56105633080006, 44.28942784667015, 45.277276039123535, 44.480075016617775, 48.540666326880455, 46.07032768428326, 43.772647976875305, 43.04566718637943, 45.24024322628975, 43.27674798667431, 41.83723323047161, 45.526326075196266, 45.24093858897686, 44.35012198984623, 43.652175441384315, 43.47111515700817, 44.9294389039278, 47.23480559885502, 46.42876625061035, 45.5074068903923, 46.76656052470207, 42.6702169328928, 49.03930976986885, 56.096306294202805, 57.840834483504295, 55.853267535567284, 60.25730721652508, 60.013470500707626, 59.89530824124813, 56.6711812466383, 61.247078105807304, 55.97962595522404, 57.7935878187418, 49.32579539716244, 52.51897305250168, 50.444820150732994, 58.64633806049824, 55.951678454875946, 62.37879037857056, 60.15804514288902, 66.09314426779747, 58.537903279066086, 65.31399607658386, 57.44942128658295, 64.22098472714424, 66.99977561831474, 73.70969116687775, 59.868284091353416, 47.968865409493446, 5.002375049516559, 1.6135435178875923, 17.116886414587498, 1.218926024157554, 0.3235722309909761, 30.4334257543087, 85.6466518342495, 76.20240300893784, 76.78289785981178, 72.86409974098206, 47.731647938489914, 29.579535573720932, 56.278023943305016, 64.50014814734459, 80.48952296376228, 43.940952345728874, 0.3955043602036312, 0.20928693615132943, 0.14476308831945062, 0.21357171091949567, 0.1656652768724598, 0.16895521752303466], [0.05801744286145549, 0.04368258589238394, 0.03468816794338636, 0.021913099444645923, 0.10533203269005753, 0.1254644730943255, 0.17359718796797097, 10.799762438982725, 63.06839257478714, 53.78743998706341, 38.19590002298355, 13.534074816852808, 16.405093409121037, 41.7829417437315, 56.290662065148354, 70.06521552801132, 55.188759192824364, 67.05747172236443, 14.295779094099998, 0.18636472552316263, 0.1222332140605431, 3.295387183316052, 3.469240441918373, 0.3984671027865261, 9.669979512691498, 42.954738065600395, 52.31170937418938, 39.75144915282726, 52.90617987513542, 61.93221174180508, 63.769006580114365, 56.99328236281872, 59.15627829730511, 57.360050082206726, 60.54128497838974, 56.11779414117336, 57.966109961271286, 54.51577730476856, 56.88918694853783, 58.1299913674593, 56.7017962038517, 55.545050874352455, 55.568640008568764, 49.412753731012344, 51.267001032829285, 52.74016298353672, 54.45993170142174, 54.655161425471306, 56.91577032208443, 53.139658346772194, 54.75273258984089, 42.407024055719376, 39.05811935663223, 39.327570497989655, 40.092777237296104, 37.906697541475296, 37.713652700185776, 38.21239113807678, 37.116476744413376, 39.95275475084782, 41.26896992325783, 41.701645106077194, 41.124706864356995, 38.857976496219635, 40.814328119158745, 39.31796461343765, 39.929256811738014, 40.27625419199467, 42.15755224227905, 45.48268921673298, 45.89024394750595, 41.57060153782368, 41.552788093686104, 41.17210552096367, 41.277534663677216, 37.88289561867714, 40.28479613363743, 38.1440594047308, 38.04877191781998, 37.97679618000984, 39.20315757393837, 42.30737440288067, 43.31578329205513, 44.06163387000561, 46.842195466160774, 49.213724210858345, 49.32240217924118, 44.96031604707241, 46.8771193921566, 42.640396133065224, 46.2938316911459, 47.57292665541172, 46.90167747437954, 44.98554289340973, 43.556766360998154, 41.18218258023262, 37.95620508491993, 38.9464395493269, 39.605681374669075, 40.18931105732918, 38.43404844403267, 39.78204131126404, 41.69540964066982, 40.568967685103416, 39.24269825220108, 39.953963086009026, 39.282672107219696, 38.973304107785225, 42.880870029330254, 41.87189117074013, 42.39065833389759, 39.7852673381567, 38.96600469946861, 40.30906543135643, 38.99432837963104, 39.58559565246105, 39.08795155584812, 40.878145694732666, 38.66642877459526, 37.32955791056156, 38.16562704741955, 40.55320993065834, 40.22008940577507, 38.74288447201252, 40.40078490972519, 41.27746246755123, 42.42298699915409, 40.92328727245331, 52.769915387034416, 52.394423335790634, 52.04741835594177, 51.3576527684927, 50.69840334355831, 55.5149906873703, 54.584963992238045, 57.48448960483074, 55.872802287340164, 54.38515931367874, 52.202374041080475, 53.89258414506912, 53.281071558594704, 58.17633368074894, 59.0591137111187, 62.6811059564352, 58.53052407503128, 64.13453936576843, 63.366813361644745, 63.832660764455795, 58.30677688121796, 59.75110977888107, 59.424319714307785, 71.68288752436638, 53.885657116770744, 45.965324118733406, 4.215075820684433, 0.33575336798094213, 0.2670773077988997, 0.13276104640681297, 0.13951564411399886, 20.570739582180977, 73.5197165608406, 63.691323548555374, 61.883665546774864, 60.15710659325123, 52.51914404332638, 24.635634161531925, 29.31605201214552, 40.1266448199749, 64.59180682897568, 34.619911909103394, 0.3675246803322807, 0.02515218628104776, 0.04791967396158725, 0.1755186083028093, 0.05321989970980212, 0.044607123782043345, 0.1141676570114214, 0.054938799075898714, 0.1287062928895466, 0.0062532843730878085, 0.16309535305481404, 0.32564626657404006, 0.23922438675072044, 14.811775255948305, 73.3354340493679, 63.939062654972076, 46.62289023399353, 20.53360227495432, 22.1257833391428, 48.6767066270113, 59.18973550200462, 76.15916892886162, 60.33387690782547, 73.82969632744789, 14.5835424028337, 0.13953114015748724, 0.6447057647164911, 3.2789454655721784, 8.249016311019659, 0.8142359834164381, 10.209144931286573, 47.811363860964775, 51.95567987859249, 43.95659990608692, 56.076839938759804, 61.640858575701714, 64.65406268835068, 59.14336659014225, 61.067720130085945, 59.41038966178894, 61.767327189445496, 57.681516632437706, 61.59447066485882, 55.82319214940071, 59.06029164791107, 59.112481847405434, 58.117417842149734, 56.00520238280296, 55.891394689679146, 50.74453666806221, 52.10397832095623, 54.58573155105114, 55.58049537241459, 56.18556350469589, 56.91387042403221, 56.8787033110857, 56.58559463918209, 44.95000720024109, 41.4472221583128, 41.57040774822235, 43.35583694279194, 39.83679257333279, 42.8990026563406, 40.93807987868786, 40.777952671051025, 40.8505629748106, 41.790244951844215, 44.34866286814213, 42.805254086852074, 41.798923686146736, 42.73568741977215, 40.546165108680725, 43.746288791298866, 41.91009812057018, 44.30714629590511, 47.64646030962467, 45.34098342061043, 43.02936606109142, 43.54717567563057, 42.21535474061966, 43.39688614010811, 40.70569954812527, 42.424233332276344, 39.739738181233406, 39.516739547252655, 40.10584473609924, 44.030562937259674, 45.14145612716675, 47.2788642346859, 45.116293877363205, 50.14154702425003, 50.589774772524834, 50.156119242310524, 48.10693860054016, 49.579978957772255, 45.85342772305012, 48.88245418667793, 48.8832863420248, 47.842157408595085, 47.06346519291401, 45.382545590400696, 43.16987872123718, 40.6267473846674, 41.692951172590256, 39.70366291701794, 41.9570218026638, 40.396038964390755, 41.519517078995705, 42.45760694146156, 42.85843603312969, 41.91528104245663, 41.01737782359123, 39.570445865392685, 41.20294846594334, 41.95735618472099, 43.90531025826931, 44.738050773739815, 39.98937338590622, 40.310767740011215, 42.162613570690155, 40.234612226486206, 41.18915140628815, 42.422534823417664, 43.33895064890385, 41.41658440232277, 40.339152216911316, 40.815794840455055, 40.171953588724136, 41.79294280707836, 41.3252829015255, 42.10094287991524, 42.55974546074867, 45.56233674287796, 44.148747995495796, 53.88305425643921, 54.01310607790947, 54.16528411209583, 52.9892548173666, 55.074324533343315, 58.18468563258648, 55.82647517323494, 59.69936415553093, 58.51878270506859, 57.20489680767059, 54.63438794016838, 55.275626331567764, 55.65317027270794, 59.806575402617455, 60.76979711651802, 65.54093509912491, 61.43657013773918, 67.06992745399475, 67.64917597174644, 66.71897828578949, 60.63419759273529, 63.90214383602142, 60.88774658739567, 73.98493319749832, 57.48922035098076, 51.39522135257721, 5.0353791285306215, 0.43734486505854875, 3.1498530926182866, 0.49000879225786775, 0.1234656319138594, 21.704815328121185, 80.12724280357361, 69.0679894387722, 68.45578148961067, 64.69466730952263, 53.07943917810917, 24.26209520548582, 37.23229832947254, 48.084132224321365, 74.5591127872467, 40.99403187632561, 0.5596839019563049, 0.03916337780538015, 0.05174892590730451, 0.1353451155591756, 0.1005236578930635, 0.08887698597391136, 0.15089931373950094, 0.248830315831583, 0.24393082014285028, 0.26006668398622423, 0.2684156672330573, 0.39560861710924655, 0.4166046576574445, 18.85378461331129, 82.82908782362938, 69.46101754903793, 56.999787613749504, 25.35350874066353, 26.14945963025093, 53.74525085091591, 66.60633713006973, 83.38867619633675, 67.54386842250824, 78.40012907981873, 16.473960913717747, 0.35607589466962963, 1.4017560635693371, 8.732609711587429, 8.092907387763262, 1.1723920586518943, 11.956799402832985, 51.133510395884514, 56.10912300646305, 48.006844371557236, 60.18581785261631, 63.6764245480299, 66.62158951163292, 61.01080298423767, 65.50710931420326, 60.87933003902435, 62.88016587495804, 58.767699748277664, 62.36532390117645, 56.703027337789536, 61.014484986662865, 61.82908907532692, 61.58755883574486, 57.83781744539738, 57.639300897717476, 50.096367448568344, 54.567127749323845, 57.1528510004282, 58.38338077068329, 58.78074064850807, 61.18466645479202, 58.664740473032, 60.26423804461956, 47.71632336080074, 43.45502682030201, 44.31770972907543, 45.38363993167877, 41.98587365448475, 45.03834865987301, 41.81618236005306, 42.25781366229057, 44.05466504395008, 44.068902879953384, 46.80871166288853, 44.93678390979767, 42.903030440211296, 45.05561873316765, 43.06743621826172, 45.87995409965515, 44.803145080804825, 46.130524054169655, 48.4893386811018, 48.56419086456299, 44.24705632030964, 44.80939954519272, 45.57584501802921, 45.57013772428036, 42.64149807393551, 46.12008601427078, 41.35570406913757, 42.38313853740692, 41.59701392054558, 45.47089844942093, 47.47554928064346, 48.7136672437191, 46.71003095805645, 52.67481788992882, 52.963773384690285, 53.459889963269234, 49.994931891560555, 51.73423536121845, 48.200394585728645, 51.334413215518, 52.277328819036484, 52.069939747452736, 50.30285216867924, 46.60453721880913, 45.10686658322811, 43.35952274501324, 42.1764600276947, 41.98039814829826, 44.824393540620804, 43.35397884249687, 42.86349356174469, 45.63275456428528, 44.57009598612785, 42.75285869836807, 42.57448107004166, 40.93521483242512, 41.578189730644226, 44.29780639708042, 44.90858182311058, 46.545982360839844, 43.81181247532368, 41.90829701721668, 44.797973558306694, 44.02900882065296, 44.11683730781078, 44.640107229352, 45.11623688042164, 43.634441792964935, 41.76985524594784, 43.37375298142433, 41.80965431034565, 45.02566114068031, 41.496030539274216, 44.36429142951965, 45.45821852982044, 47.40185223519802, 46.041076853871346, 57.18964822590351, 57.4596693366766, 57.411867901682854, 55.76165825128555, 56.67396269738674, 58.33737663924694, 58.48335720598698, 62.43851937353611, 61.34672395884991, 58.14143255352974, 58.10042515397072, 58.60547125339508, 58.07852692902088, 62.03634515404701, 63.66420440375805, 67.83499360084534, 65.04737958312035, 69.39932405948639, 69.84906792640686, 70.43305099010468, 63.39210860431194, 66.8934953212738, 64.55668151378632, 77.1451324224472, 57.51971371471882, 53.408338129520416, 6.431853119283915, 0.7041047117672861, 5.954453386366367, 1.2285146908834577, 0.18213041679700837, 24.07457336783409, 86.11909568309784, 74.69063892960548, 77.04158797860146, 73.65995943546295, 67.51089379191399, 35.03944359719753, 45.756954699754715, 61.062951385974884, 86.19503080844879, 52.0811453461647, 0.8982061338610947, 0.11016889853635803, 0.12871559942141175, 0.29235675756353885, 0.21600696461973712, 0.23345666733803228], [0.14021304028574377, 0.01715848768071737, 0.00694224186190695, 0.05654047992720734, 0.0651925896818284, 0.1682348593021743, 0.14199337834725156, 8.934976402670145, 69.05655965209007, 52.69781805574894, 37.90456585586071, 20.93895312398672, 23.2276539131999, 41.8269319832325, 54.39903236925602, 69.55757796764374, 56.99148885905743, 69.6940590441227, 12.521849032491446, 0.43150155048351735, 0.34523976675700396, 2.819958832114935, 5.693327598273754, 1.0964982560835779, 6.3067324832081795, 44.97022591531277, 52.1923615783453, 58.82624700665474, 58.68937835097313, 53.721167743206024, 56.96739815175533, 59.72202993929386, 55.274718180298805, 55.42200207710266, 54.65949699282646, 53.85539934039116, 55.197498723864555, 55.26454612612724, 55.79260379076004, 55.34497641026974, 53.621164709329605, 55.62429942190647, 50.86739927530289, 52.470639646053314, 55.333132445812225, 53.1051068007946, 54.584827199578285, 53.81737478077412, 50.640129670500755, 49.86823529005051, 43.44100557267666, 40.40985122323036, 41.72958500683308, 37.96298772096634, 39.927543103694916, 41.02908119559288, 42.36566707491875, 41.0795196890831, 39.33871529996395, 40.0789687782526, 40.68067789077759, 39.57332991063595, 42.048794478178024, 38.55086177587509, 40.4630483686924, 39.71274442970753, 39.983692690730095, 38.80284905433655, 43.058936074376106, 47.6837021112442, 45.00348173081875, 41.16550527513027, 41.105472296476364, 42.190671265125275, 41.17704525589943, 37.47045435011387, 37.55209296941757, 36.84810854494572, 40.52844285964966, 40.11586859822273, 39.0386264026165, 40.558085069060326, 43.03858056664467, 44.94224801659584, 48.68481919169426, 47.835443168878555, 48.21964435279369, 43.1123536080122, 43.419392332434654, 42.47377127408981, 43.177375718951225, 44.23731744289398, 42.88810484111309, 43.55621539056301, 41.63118548691273, 38.305683732032776, 37.228931710124016, 39.21763859689236, 40.57622529566288, 40.667530596256256, 39.70892943441868, 38.90866197645664, 40.31664602458477, 37.80442222952843, 39.02285344898701, 38.00730474293232, 38.356122225522995, 39.023761600255966, 40.11793188750744, 40.64991474151611, 41.37266255915165, 38.86783316731453, 37.93153300881386, 39.38519060611725, 38.82351614534855, 39.49812054634094, 40.65798930823803, 40.71952700614929, 39.668598398566246, 38.47140423953533, 40.538508519530296, 39.59855675697327, 41.31806328892708, 41.93422682583332, 41.68691709637642, 41.21292673051357, 42.05161392688751, 41.05284132063389, 46.23501844704151, 54.184237495064735, 52.091849371790886, 57.08792768418789, 52.602895349264145, 54.54366400837898, 54.74679730832577, 56.578713208436966, 54.54087495803833, 58.159523382782936, 57.70932354032993, 55.7266279309988, 57.01817102730274, 60.411468744277954, 60.21486349403858, 56.961998641490936, 60.2188266813755, 57.707644030451775, 52.951272055506706, 69.15381163358688, 63.8240048289299, 65.03918722271919, 64.72977742552757, 68.60490828752518, 51.861004158854485, 50.198771953582764, 2.7598975924775004, 0.21040977590018883, 1.547837087418884, 0.9984447550959885, 0.19279016589280218, 17.424202524125576, 72.11190730333328, 64.1911943256855, 65.8015251159668, 53.16531077027321, 36.26470685005188, 9.525496065616608, 19.97950840741396, 39.24458675086498, 54.83827739953995, 28.94003938883543, 0.2837396215181798, 0.05407625278166961, 0.02505502059648279, 0.05684832649421878, 0.025411487113160547, 0.049317071243422106, 0.060731840567314066, 0.059815878194058314, 0.08909370051696897, 0.029387778922682628, 0.07186673858086579, 0.2857736108126119, 0.22539945202879608, 14.425524082034826, 77.46728673577309, 58.905639946460724, 45.48401914536953, 28.049785159528255, 28.345099613070488, 49.89794209599495, 60.23329250514507, 74.92241889238358, 61.73050716519356, 75.40126919746399, 13.437289260327816, 0.2477755310246721, 0.2413819287903607, 7.405833005905151, 9.856871534138918, 0.8471546263899654, 7.174879973754287, 47.00285084545612, 55.385242849588394, 58.65815542638302, 60.88225208222866, 56.92922540009022, 60.458924397826195, 62.320657297968864, 58.555842116475105, 59.47135739028454, 58.07711720466614, 56.10769048333168, 58.43033865094185, 56.61494806408882, 56.79138019680977, 57.49741651117802, 55.52252948284149, 56.63935035467148, 54.721825048327446, 53.34575168788433, 58.11768762767315, 55.603962913155556, 58.43717448413372, 56.37137733399868, 53.1237979978323, 51.55490018427372, 46.49425953626633, 42.405884116888046, 43.562435656785965, 41.59822605550289, 42.39751696586609, 43.07912439107895, 44.69892047345638, 44.10482995212078, 41.75442427396774, 41.48822955787182, 42.220822647213936, 41.20717763900757, 42.17259183526039, 41.0284960269928, 41.83892413973808, 42.58629083633423, 43.55837367475033, 39.704346880316734, 45.871647745370865, 47.503086403012276, 45.39857693016529, 42.88156919181347, 42.72322788834572, 43.20160321891308, 43.020561933517456, 39.44699048995972, 39.86533284187317, 40.015781968832016, 41.61412060260773, 40.769498124718666, 40.222631469368935, 42.214518785476685, 45.19099786877632, 45.938843339681625, 49.1678074747324, 49.90225486457348, 50.19531413912773, 45.87804660201073, 46.27185747027397, 46.88245050609112, 45.50970196723938, 47.5679337233305, 45.16724534332752, 46.342313289642334, 44.2212101072073, 40.48833221197128, 41.09373092651367, 40.82297645509243, 40.95201753079891, 42.022864669561386, 40.94363518059254, 39.52206306159496, 41.82096250355244, 38.44106666743755, 40.26211895048618, 38.60109128057957, 39.76377189159393, 40.58581218123436, 41.84293292462826, 40.82717142999172, 43.293037712574005, 39.86525684595108, 40.5560027807951, 40.79394981265068, 40.665592700242996, 40.73263630270958, 43.13247732818127, 42.31248512864113, 41.464712619781494, 41.068051904439926, 41.71788923442364, 43.02753835916519, 42.70338535308838, 42.19912201166153, 42.67497427761555, 43.49509187042713, 43.736948892474174, 41.78483784198761, 48.75550299882889, 54.70288686454296, 56.06802821159363, 59.28736366331577, 56.07254236936569, 56.642948761582375, 56.15596689283848, 57.15686358511448, 57.82585948705673, 62.12682969868183, 59.19214077293873, 59.007770866155624, 60.39585158228874, 61.7501825094223, 61.42674006521702, 59.584367126226425, 61.38301581144333, 60.50254225730896, 52.94966474175453, 72.12510019540787, 64.54940110445023, 67.54116296768188, 63.409287482500076, 74.04496237635612, 54.89585191011429, 52.903911396861076, 3.491697236895561, 0.07365276891505346, 2.154087550006807, 0.6882894854061306, 0.21884233981836587, 18.334741964936256, 80.25135174393654, 69.63773846626282, 76.22385665774345, 58.05792063474655, 46.09901234507561, 18.791796639561653, 29.88296639174223, 47.431878224015236, 65.18902078270912, 35.382762774825096, 0.3864126652479172, 0.03873475783620961, 0.00933777906539035, 0.023115026160667185, 0.04031822638353333, 0.04450140484550502, 0.3304693358950317, 0.24157899868441746, 0.17004198889480904, 0.17264419613638893, 0.22997936408501118, 0.372559410170652, 0.31251316191628575, 19.777393452823162, 88.35280582308769, 67.22289964556694, 53.413551449775696, 36.289527118206024, 34.0398046374321, 55.829097032547, 66.6612745821476, 78.20405200123787, 67.50367417931557, 82.89454311132431, 16.609959416091442, 0.6586572504602373, 1.2000678735785186, 10.431536547839642, 10.276402272284031, 3.5924782790243626, 7.1319047547876835, 54.37136985361576, 58.863515406847, 59.71196047961712, 64.2579035460949, 59.7831192612648, 63.56825195252895, 64.10505294799805, 61.099475026130676, 61.760578751564026, 61.39321066439152, 58.05190175771713, 59.64762233197689, 57.652360796928406, 58.95371116697788, 60.74489705264568, 56.02377958595753, 60.013709887862206, 56.33576184511185, 56.04359172284603, 58.607420548796654, 57.20640912652016, 61.108659133315086, 60.160431414842606, 56.087122187018394, 53.348738327622414, 48.366392478346825, 44.45023141801357, 46.9741889834404, 43.214556723833084, 45.33266566693783, 46.36247880756855, 48.024851605296135, 47.94012375175953, 44.380174577236176, 44.83144976198673, 43.97692121565342, 43.453358709812164, 45.0228226929903, 42.90016919374466, 44.57671523094177, 44.08110402524471, 45.21912395954132, 41.159000024199486, 47.41948328912258, 48.884266689419746, 48.29770736396313, 43.66963170468807, 43.72209548950195, 43.73056523501873, 44.6293918043375, 40.63229128718376, 41.70613646507263, 41.5418104827404, 45.18405944108963, 43.29900339245796, 42.89270639419556, 43.65922786295414, 46.395609229803085, 47.5189733505249, 51.299466490745544, 53.35924096405506, 54.73817937076092, 49.0223740786314, 48.72912101447582, 46.72393821179867, 47.11736910045147, 48.66896264255047, 49.48941081762314, 49.362710416316986, 46.263285130262375, 44.792330861091614, 42.03631214797497, 43.24762634932995, 45.972372740507126, 44.35631945729256, 42.900138795375824, 41.40230476856232, 44.332582131028175, 39.16149660944939, 42.03958377242088, 41.12635977566242, 40.774221271276474, 42.01642021536827, 42.716202065348625, 40.24305537343025, 45.502812936902046, 43.50098915398121, 42.98952899873257, 42.393527179956436, 42.51815669238567, 44.802905693650246, 46.95097602903843, 43.268289640545845, 43.3230485022068, 43.723691403865814, 45.23097552359104, 44.21613357961178, 45.44410988688469, 46.47474758327007, 45.76278738677502, 45.08857436478138, 46.46626263856888, 44.75065089762211, 50.626769587397575, 58.00085909664631, 56.160526648163795, 61.27996154129505, 58.2596518099308, 59.24995467066765, 59.62388500571251, 60.40153607726097, 59.94739204645157, 64.53220322728157, 63.614601865410805, 61.0770296305418, 64.28403094410896, 64.96469601988792, 63.375723883509636, 61.17127597332001, 64.06068652868271, 60.879090651869774, 56.88485138118267, 73.83350372314453, 67.70042762160301, 70.799320936203, 68.01677584648132, 74.75174725055695, 57.23857060074806, 56.031949147582054, 4.133547870442271, 0.7340377836953849, 8.925983235239983, 2.9080951027572155, 0.24361617921385914, 20.208881199359894, 87.25868493318558, 74.55534338951111, 83.25047001242638, 68.03199782967567, 48.06764870882034, 19.426879361271858, 35.28318531811237, 56.71840891242027, 75.93217670917511, 47.93609976768494, 1.1226751701906323, 0.20399284054292366, 0.16996407823171467, 0.19966932566603646, 0.12424856802681461, 0.10100364932441153], [0.034562077053124085, 0.04489389335503802, 0.01986095536267385, 0.07371686820988543, 0.0798132254567463, 0.05831681039126124, 0.1596784160938114, 9.043266791850328, 63.68075631558895, 51.32967486977577, 41.904079243540764, 18.347961455583572, 21.11391093581915, 42.15097479522228, 56.50330625474453, 70.12957647442818, 57.035289108753204, 69.83765333890915, 13.611402567476034, 0.3983908100053668, 0.29789861175231636, 3.0007716547697783, 11.872184593230486, 0.720543876523152, 5.729448460042477, 48.13424773514271, 52.297919914126396, 60.44622927904129, 62.011171504855156, 60.263671875, 56.027875766158104, 55.86605004966259, 50.24105988442898, 54.14144419133663, 50.49716614186764, 53.53917270898819, 54.60680142045021, 57.3288157582283, 54.99693788588047, 54.67817299067974, 55.843965634703636, 56.237882897257805, 56.67854145169258, 54.329321309924126, 52.62076959013939, 55.142591670155525, 50.691202729940414, 50.24859867990017, 45.60132645070553, 41.139560267329216, 41.85629300773144, 43.04449684917927, 40.23058824241161, 41.031117886304855, 40.84962822496891, 39.94556553661823, 41.12681195139885, 39.61484648287296, 39.788314774632454, 39.66681249439716, 37.616598308086395, 39.090972393751144, 39.757152646780014, 37.6816850155592, 37.547328025102615, 38.40110041201115, 39.821072816848755, 40.631470531225204, 43.22322025895119, 46.52473770081997, 42.183896228671074, 41.78694672882557, 37.80124180018902, 37.93432965874672, 42.52586267888546, 42.1069997549057, 39.67926062643528, 37.04171575605869, 37.80401945114136, 36.796150133013725, 40.515295565128326, 42.21988029778004, 42.39060893654823, 42.34178155660629, 44.750502705574036, 48.22511225938797, 47.81619340181351, 43.1879847496748, 43.10949996113777, 46.36726655066013, 41.52004525065422, 44.21382710337639, 41.08944855630398, 42.94531837105751, 39.939580857753754, 39.1037967056036, 36.2934485077858, 37.88479171693325, 39.520075768232346, 38.54532167315483, 38.34952957928181, 39.537003859877586, 39.69200134277344, 38.86529490351677, 38.55930872261524, 41.0201782733202, 38.388526886701584, 39.80156846344471, 39.14182886481285, 41.34468846023083, 42.07452289760113, 38.76085750758648, 40.69311462342739, 38.62943395972252, 37.144302651286125, 40.11128984391689, 38.71393762528896, 40.35526715219021, 38.946891725063324, 39.114356338977814, 40.56124269962311, 40.13377323746681, 40.60361422598362, 40.65412871539593, 40.47203868627548, 43.46752054989338, 43.61931100487709, 41.813989877700806, 40.68272978067398, 48.52078199386597, 52.035939171910286, 53.656529411673546, 53.55347894132137, 54.42934334278107, 54.355311915278435, 55.456272438168526, 56.30265422165394, 58.68277810513973, 57.285247296094894, 57.5468784570694, 54.72442410886288, 58.68932895362377, 55.23615404963493, 54.78397451341152, 54.764040783047676, 60.127528980374336, 32.52536930143833, 54.511776119470596, 64.8683787882328, 65.43900176882744, 71.30001246929169, 61.58180594444275, 54.84425067901611, 52.53273971378803, 1.944019147194922, 0.04788700462086126, 2.096214755438268, 0.28961235482711345, 0.22189219569554552, 14.395362250506878, 70.53411796689034, 63.739105984568596, 64.75059270858765, 52.883939668536186, 53.659607246518135, 18.290888518095016, 15.832304544746876, 36.58981740474701, 56.26836106181145, 37.02715493738651, 0.8861926035024226, 0.03062797633901937, 0.059500799397937953, 0.10351576725952327, 0.12309121841099113, 0.10281066759489477, 0.05362377647543326, 0.09726299496833235, 0.012510843516793102, 0.026833410520339385, 0.15948055952321738, 0.17133987159468234, 0.23636403086129576, 13.12193088233471, 76.247818171978, 57.729553654789925, 50.64285032451153, 23.365092538297176, 21.582524590194225, 43.99121604859829, 63.60884137451649, 74.77038145065308, 63.66258569061756, 77.58772507309914, 14.514654949307442, 0.6539538153447211, 1.7126114456914365, 9.316408485174179, 9.855382964015007, 2.4723356729373336, 7.245791293680668, 51.0293123871088, 53.825776129961014, 61.114070042967796, 65.59271112084389, 60.04639193415642, 60.879390835762024, 56.442391723394394, 52.6238664239645, 54.81839306652546, 52.18779042363167, 54.92080517113209, 56.92797526717186, 57.33402527868748, 57.69393436610699, 56.26472845673561, 57.30944439768791, 56.25745564699173, 58.44481587409973, 57.37161286175251, 54.20643210411072, 56.09514735639095, 54.34039771556854, 51.16712339222431, 48.088179007172585, 43.60655888915062, 43.564073368906975, 43.27618941664696, 43.30854468047619, 43.57259251177311, 43.64921160042286, 42.25322350859642, 42.66923278570175, 42.11764678359032, 42.04192064702511, 41.53724692761898, 40.93759350478649, 39.174039736390114, 41.21942438185215, 39.29452367126942, 39.06624712049961, 39.79106582701206, 42.120990604162216, 41.21098883450031, 44.639358669519424, 47.89620190858841, 43.6557624489069, 41.67216628789902, 38.16774733364582, 40.1354793459177, 43.56432415544987, 43.11179503798485, 41.7010485380888, 39.3664576113224, 39.392235428094864, 39.64844807982445, 42.23029173910618, 44.64065819978714, 43.99833686649799, 44.29673105478287, 46.59806236624718, 51.45541772246361, 50.27119606733322, 44.78368252515793, 45.514611303806305, 47.592962980270386, 44.97662477195263, 45.79063609242439, 43.042752742767334, 44.18727792799473, 41.52330167591572, 40.498667657375336, 37.574887946248055, 41.19145408272743, 40.44183790683746, 39.87182669341564, 39.91841219365597, 40.589684173464775, 39.19865861535072, 38.77318784594536, 38.796963170170784, 41.09672896564007, 39.43956948816776, 40.02364754676819, 40.478893518447876, 43.808088675141335, 45.14914311468601, 40.14505483210087, 41.51409476995468, 40.2460116147995, 39.47743445634842, 42.24867135286331, 42.15975232422352, 42.75261551141739, 40.52689254283905, 41.07101574540138, 42.89468988776207, 41.27223774790764, 42.1490179002285, 42.40170054137707, 43.2637070864439, 45.37844941020012, 46.35406605899334, 44.03693899512291, 43.04593697190285, 50.05607061088085, 54.12766233086586, 53.770253509283066, 55.21981492638588, 56.19605094194412, 56.731487810611725, 56.54291532933712, 58.00781272351742, 59.938238337635994, 59.359559789299965, 60.004833564162254, 55.76432190835476, 59.63306151330471, 55.849357545375824, 55.062130987644196, 55.40845960378647, 60.36284275352955, 34.113805666565895, 54.143393486738205, 67.96319872140884, 68.47671076655388, 71.28928184509277, 66.09131276607513, 55.326049625873566, 55.709703639149666, 2.345191645435989, 0.03084793406742392, 2.9891252797096968, 1.1797530949115753, 0.2175803473801352, 15.297674182802439, 76.91060900688171, 67.54698425531387, 73.38943675160408, 57.11950019001961, 50.18620602786541, 20.692078471183777, 20.92482928186655, 44.770584627985954, 66.09931513667107, 45.21210573613644, 1.4752647816203535, 0.024774336634436622, 0.031633580874768086, 0.06667399808065966, 0.07446028495905921, 0.028132245024607982, 0.18548909516539425, 0.24172806646674871, 0.06570372905116528, 0.1794043302652426, 0.277988066081889, 0.3418588388012722, 0.3897443739697337, 19.40919890999794, 86.29314914345741, 62.77143090963364, 56.92321412265301, 31.490443535149097, 29.531608745455742, 52.382993549108505, 71.500254124403, 79.19812425971031, 68.65150898694992, 84.39907237887383, 16.90344426780939, 1.0594111774116755, 2.274636081419885, 8.8097607716918, 22.586179934442043, 4.674929045140743, 7.805959610268474, 54.31451350450516, 56.99680857360363, 65.57884946465492, 67.51580312848091, 61.67302764952183, 64.25975784659386, 59.200386330485344, 54.0669871866703, 59.450834691524506, 54.69118349254131, 55.96128813922405, 59.521081522107124, 60.79991050064564, 59.79861102998257, 59.160374477505684, 59.47048343718052, 58.73043514788151, 59.51112985610962, 59.02648866176605, 58.19343276321888, 59.55110751092434, 56.035190373659134, 54.6463268995285, 49.23926264047623, 45.25848984718323, 46.21309742331505, 46.35807864367962, 45.09700231254101, 45.01541689038277, 44.78499345481396, 45.014421343803406, 45.16917943954468, 45.6072199344635, 44.783310145139694, 43.87138567864895, 43.64736869931221, 42.225591391325, 43.34281884133816, 40.292160138487816, 42.93275244534016, 42.73271217942238, 44.780832678079605, 43.08591082692146, 46.95913419127464, 49.196085557341576, 44.10350002348423, 41.75907142460346, 39.04203861951828, 40.523628517985344, 45.6076493114233, 43.90417031943798, 43.15907970070839, 42.26013533771038, 42.12661050260067, 41.18821665644646, 46.284886971116066, 46.16082742810249, 45.74995167553425, 46.35802544653416, 49.364355728030205, 55.060261487960815, 52.54663556814194, 47.834740206599236, 49.81058478355408, 49.1760378330946, 46.58276438713074, 48.579238057136536, 45.60426749289036, 46.993290558457375, 44.80867378413677, 43.73593434691429, 40.20848862826824, 42.51990079879761, 43.65378275513649, 41.11095540225506, 42.16894403100014, 42.49417617917061, 40.83515480160713, 41.42299845814705, 39.86483886837959, 43.07084083557129, 39.88424822688103, 41.94113485515118, 41.69428490102291, 45.86400255560875, 46.50501675903797, 41.08510918915272, 45.69198578596115, 42.11019538342953, 41.592533960938454, 44.370466098189354, 44.84029568731785, 44.98896650969982, 43.88230249285698, 42.88130700588226, 45.28468944132328, 45.149701684713364, 45.003838911652565, 44.12982501089573, 44.97843727469444, 49.39386494457722, 49.46730740368366, 46.46761156618595, 45.60143284499645, 52.86753974854946, 56.204387694597244, 57.705276757478714, 57.67049342393875, 59.9769202619791, 58.29331040382385, 59.16632495820522, 61.06262840330601, 61.940974071621895, 63.312943652272224, 61.37593299150467, 57.56825231015682, 61.9502379745245, 57.76486895978451, 55.943942070007324, 57.61229954659939, 62.620601803064346, 34.07793179154396, 55.41544362902641, 69.11959066987038, 71.94837167859077, 72.88256675004959, 67.00841635465622, 57.61451482772827, 59.64185044169426, 3.4977797605097294, 0.1372044181334786, 6.272962745279074, 2.5049797212705016, 0.5634440376888961, 16.68062422424555, 81.83192253112793, 74.28618863224983, 79.22305852174759, 68.68703708052635, 67.36429005861282, 28.002494797110558, 30.2716551348567, 54.066766798496246, 75.93067198991776, 58.69330354034901, 2.5674752052873373, 0.11082540979259647, 0.19260388682596385, 0.25895233440678567, 0.2576329739531502, 0.13491336372680962], [0.05277368341921829, 0.07426195341395214, 0.00580958767386619, 0.0154339396431169, 0.06188058869156521, 0.10899562985287048, 0.11042250524042174, 7.01243014074862, 64.0236309170723, 49.09056901931763, 38.03548023104668, 23.23899630457163, 31.13338429480791, 50.91261304914951, 53.23298513889313, 68.22114408016205, 54.40071947872639, 71.00122690200806, 12.514725364744663, 0.06402507264283486, 0.10475113886059262, 11.794311571866274, 8.553927149623632, 1.3782335445284843, 8.570330869406462, 54.463849291205406, 62.50872440636158, 63.78967747092247, 57.69952766597271, 58.75353790819645, 55.1339091360569, 53.559140637516975, 52.018110528588295, 52.76560261845589, 52.742765843868256, 54.47509668767452, 56.52965784072876, 56.22249372303486, 54.96434323489666, 55.84632150828838, 57.59510926902294, 57.335833981633186, 56.69599391520023, 54.68804486095905, 51.28772512078285, 50.55051147937775, 45.643488988280296, 41.86593309044838, 38.96396800875664, 40.88394038379192, 41.05865880846977, 39.71835672855377, 39.73732531070709, 38.544424921274185, 38.28925721347332, 38.79592962563038, 39.377974793314934, 38.13142128288746, 39.27223786711693, 39.53291907906532, 38.81794564425945, 37.32889674603939, 39.35666933655739, 38.403475284576416, 37.815749421715736, 39.70437727868557, 40.98683126270771, 37.36060604453087, 42.738822251558304, 46.53519853949547, 43.96574221551418, 42.020710185170174, 40.5205886811018, 39.08952847123146, 38.02338548004627, 40.19539833068848, 39.84664544463158, 38.78725469112396, 38.88303615152836, 38.72526481747627, 39.38093103468418, 37.901301831007004, 39.24967847764492, 41.7397266626358, 42.84089997410774, 43.15187908709049, 44.605221301317215, 42.67408512532711, 42.14171089231968, 42.36793555319309, 43.443076461553574, 42.11747199296951, 41.62734009325504, 41.62583537399769, 39.34461638331413, 38.04452754557133, 36.70430526137352, 38.215237185359, 38.467205464839935, 38.66494305431843, 41.5446375310421, 42.066056951880455, 39.78652507066727, 37.06379637122154, 39.40885953605175, 38.42059336602688, 39.50693607330322, 38.12954418361187, 38.027546256780624, 42.75724746286869, 40.24663858115673, 38.42574588954449, 39.30305041372776, 37.489821910858154, 39.763095527887344, 37.70417980849743, 40.84648199379444, 41.1145044118166, 37.20204435288906, 40.23896299302578, 38.50526042282581, 38.82342495024204, 40.292863100767136, 42.18958452343941, 42.78963312506676, 44.63034935295582, 43.93397592008114, 44.33735467493534, 41.90990433096886, 40.8666817098856, 44.3697327375412, 50.70872738957405, 52.20052354037762, 55.31935438513756, 56.40696242451668, 55.519668236374855, 56.37575089931488, 59.20797452330589, 53.61226178705692, 58.6301851272583, 54.45013202726841, 61.10727220773697, 60.395665392279625, 63.94423797726631, 56.90524488687515, 67.52602458000183, 60.80267295241356, 57.51127816736698, 57.388244569301605, 71.73231527209282, 67.03251466155052, 55.95699816942215, 65.22163063287735, 48.24720427393913, 1.8547222763299942, 0.09452084836084396, 1.360060425940901, 0.28328875196166337, 0.19078284938586876, 11.027322728186846, 69.43397060036659, 62.23872609436512, 70.82189932465553, 59.157118052244186, 42.787968814373016, 19.632284939289093, 22.746031656861305, 41.53576120734215, 57.7836437523365, 48.604286313056946, 1.637871356215328, 0.052997504026279785, 0.07178592612035573, 0.03438274819927756, 0.04597660146828275, 0.06342709457385354, 0.0489199814182939, 0.03777407735469751, 0.07103200056008063, 0.03352685154823121, 0.0786340789636597, 0.257932593813166, 0.1312404897180386, 11.594542041420937, 74.09477010369301, 55.09966157376766, 43.317117020487785, 24.7806628793478, 21.36550683528185, 50.536155849695206, 61.0990646481514, 72.19934061169624, 61.92693002521992, 75.73624402284622, 16.35753706097603, 0.5160479934420437, 2.6494216080754995, 9.83632318675518, 15.724867209792137, 1.3219059607945383, 9.988092742860317, 55.868763104081154, 62.91991554200649, 65.15429824590683, 61.037697941064835, 59.234052523970604, 55.21908916532993, 55.68354584276676, 53.49797531962395, 54.25977364182472, 52.97070801258087, 56.13991655409336, 58.44280198216438, 58.11178654432297, 59.03235174715519, 56.531318351626396, 59.474108442664146, 58.65380086004734, 57.06465393304825, 56.888320595026016, 54.35685843229294, 52.52486273646355, 47.17018626630306, 45.48345297574997, 42.36124411225319, 42.49770238995552, 42.49409258365631, 41.19984783232212, 43.38181234896183, 41.65683031082153, 41.7007065564394, 40.0035086274147, 41.099221631884575, 41.21897600591183, 42.039439380168915, 42.08201229572296, 39.854773208498955, 40.37227883934975, 40.17964817583561, 40.67144438624382, 39.82399865984917, 41.76833912730217, 42.317679449915886, 39.447974637150764, 43.09792198240757, 48.46791163086891, 44.57964867353439, 41.66313797235489, 40.50971366465092, 39.374630972743034, 39.705813601613045, 41.86876393854618, 43.04800026118755, 40.483232885599136, 39.378962740302086, 39.85208295285702, 41.10153950750828, 39.17048692703247, 42.199726179242134, 42.7970427274704, 45.42354919016361, 46.16129860281944, 47.76807278394699, 44.85182426869869, 45.078827887773514, 45.58635525405407, 45.151966363191605, 44.3308000266552, 44.124634489417076, 43.76074321568012, 42.12255232036114, 39.816604256629944, 38.74930612742901, 38.68269570171833, 41.05327069759369, 40.8196934312582, 43.12790237367153, 43.529077246785164, 40.3060369938612, 38.65618832409382, 40.31283102929592, 38.56314651668072, 38.08099038898945, 39.41505320370197, 39.094513803720474, 43.537626788020134, 42.54814848303795, 39.0180429071188, 40.999397188425064, 40.58606676757336, 42.50217854976654, 39.86237280070782, 43.02520528435707, 42.58743077516556, 40.8262062817812, 42.22460724413395, 40.84056571125984, 41.84829443693161, 43.325039595365524, 43.8130322098732, 45.21460220217705, 46.58923923969269, 45.74496254324913, 47.07462139427662, 42.77450233697891, 43.18217106163502, 48.16544786095619, 52.30197049677372, 54.43163461983204, 56.947301030159, 58.034882470965385, 58.16415533423424, 58.6674877256155, 59.80294279754162, 54.35901291668415, 58.67450214922428, 55.70868909358978, 62.96303562819958, 61.879911348223686, 66.72520235180855, 59.361353293061256, 66.33263781666756, 62.7293785661459, 58.32185447216034, 58.21594275534153, 68.81111562252045, 67.51492157578468, 57.25047916173935, 66.01138785481453, 51.920953541994095, 2.315508113242686, 0.1701411249814555, 2.643081648275256, 0.4088975430931896, 0.270673458580859, 11.607237160205841, 75.56058704853058, 67.34070852398872, 77.75205865502357, 64.25034955143929, 48.51288981735706, 21.99850156903267, 29.019424729049206, 48.59239675104618, 65.99411398172379, 59.98810686171055, 1.9239460118114948, 0.06193216424435377, 0.07837837940314785, 0.05249083238595631, 0.03878529809298925, 0.07842232938855886, 0.13222653680713847, 0.13538456812966615, 0.1378750376170501, 0.0945243809837848, 0.22397389024263248, 0.39502110332250595, 0.4519365570740774, 16.368833854794502, 85.92559486627579, 62.07590103149414, 55.60791850090027, 35.066851526498795, 44.62908022105694, 65.74850276112556, 66.63945615291595, 78.10882151126862, 65.86220785975456, 82.53410965204239, 17.59897604584694, 0.5431459425017238, 1.773949891794473, 26.4517505094409, 21.72026339918375, 2.817746875807643, 11.11586082726717, 57.02024571597576, 63.822044134140015, 67.78055012226105, 63.87403294444084, 62.91858561336994, 58.11872497200966, 57.54640348255634, 56.50969751179218, 58.19389633834362, 55.59292450547218, 58.32818113267422, 62.326163202524185, 60.1725185662508, 59.49560388922691, 58.37485782802105, 62.690350860357285, 61.75432808697224, 62.113082036376, 59.514838457107544, 57.00399398803711, 53.882647678256035, 49.38924819231033, 47.33488082885742, 45.40112279355526, 45.05839258432388, 43.82430240511894, 44.80358585715294, 46.058346927165985, 42.7142945677042, 44.560425505042076, 43.91460835933685, 45.506095960736275, 43.930852487683296, 45.29169246554375, 45.83904169499874, 44.26843397319317, 40.76135516166687, 43.86684492230415, 42.0386528223753, 42.02387161552906, 44.384753331542015, 45.39021357893944, 39.36603583395481, 47.16077797114849, 49.26192082464695, 46.3573756814003, 42.52338521182537, 40.63356041908264, 40.74484124779701, 39.59516353905201, 42.99757316708565, 44.04701605439186, 43.18791255354881, 43.10551777482033, 42.5806899368763, 43.11787471175194, 40.08567541837692, 44.08491522073746, 45.03600798547268, 50.04602015018463, 46.65856271982193, 49.648021906614304, 47.02045530080795, 48.76727096736431, 48.56894440948963, 47.03595466911793, 46.29581518471241, 45.98775431513786, 46.81936629116535, 43.93301457166672, 41.56441166996956, 40.62195584177971, 40.65535984933376, 43.25592130422592, 42.371796146035194, 45.25904081761837, 44.948255494236946, 41.0322730243206, 38.71016442775726, 41.003265380859375, 38.91333572566509, 40.820981562137604, 40.41655406355858, 39.339414462447166, 45.38507625460625, 44.04133915901184, 42.09175117313862, 43.33688735961914, 42.851269617676735, 45.904705971479416, 42.75298409163952, 45.14650605618954, 46.284199208021164, 43.051963448524475, 44.56572242081165, 42.66992434859276, 43.593487590551376, 46.206535175442696, 45.62862418591976, 47.517886608839035, 50.054588690400124, 49.549827575683594, 49.40969109535217, 46.22217133641243, 45.79043470323086, 49.75721664726734, 54.495285004377365, 57.52067506313324, 59.229595363140106, 61.04880474507809, 59.3016204982996, 60.114890858531, 62.708042711019516, 55.871620550751686, 62.883703485131264, 56.70435346662998, 64.84722152352333, 64.74961996078491, 68.46413344144821, 64.76823896169662, 70.9918262064457, 64.70389321446419, 59.85458962619305, 59.15315106511116, 70.55640757083893, 66.90370917320251, 62.88239635527134, 66.01132705807686, 57.97726996243, 2.7268025558441877, 0.390593598713167, 5.668789939954877, 2.2215085197240114, 0.4047877964330837, 13.505241014063358, 80.69892212748528, 74.05867204070091, 83.93844589591026, 73.88221710920334, 55.131880044937134, 31.514355652034283, 37.973402962088585, 59.282313734292984, 75.14339223504066, 72.32609421014786, 3.855932867154479, 0.1581363519653678, 0.23282538168132305, 0.08237540867412463, 0.20196245808620006, 0.19632747920695692], [0.0827408125041984, 0.028888992601423524, 0.027422842758824117, 0.040726530060055666, 0.05711245314159896, 0.04421847217599861, 0.027916437757085077, 6.707719266414642, 66.37587189674377, 53.311428129673004, 52.70479828119278, 28.48436214029789, 30.678560100495815, 51.970681473612785, 49.96073752641678, 67.39422485232353, 53.8966841250658, 70.90654358267784, 13.503025732934475, 0.1788555714301765, 2.5851110089570284, 18.864600732922554, 4.4504522904753685, 2.2795447055250406, 11.929463669657707, 60.01297652721405, 55.573066771030426, 60.210843309760094, 58.579655438661575, 54.807369858026505, 52.001817002892494, 49.88684669137001, 50.389612913131714, 53.90698917210102, 57.323724031448364, 59.82680171728134, 56.69233851134777, 56.882085129618645, 57.047885432839394, 57.38955929875374, 55.162324011325836, 54.65043067932129, 54.11848962306976, 50.27816489338875, 47.80279912054539, 43.134552016854286, 39.392493814229965, 39.85391065478325, 40.2617921680212, 39.44258652627468, 39.58676218986511, 40.186757594347, 37.418777123093605, 39.49685141444206, 38.05124558508396, 37.85725079476833, 38.55316445231438, 39.79292772710323, 38.90898495912552, 36.487211510539055, 38.340619057416916, 37.61971794068813, 38.268312737345695, 36.38488680124283, 38.380733504891396, 37.22061015665531, 38.64482693374157, 37.600741758942604, 41.071661710739136, 47.340945303440094, 42.38717012107372, 39.094567000865936, 40.67113660275936, 41.51492312550545, 39.518316462635994, 39.378130584955215, 40.93810647726059, 40.16063779592514, 36.66951432824135, 37.370284125208855, 39.09365125000477, 37.087165117263794, 37.43148364126682, 40.467581525444984, 39.21849735081196, 42.82336391508579, 45.17193429172039, 45.55432677268982, 40.78271381556988, 41.96716345846653, 42.275342121720314, 42.58776895701885, 39.950824454426765, 39.674609676003456, 39.425962418317795, 35.66967397928238, 38.56522120535374, 39.6394045650959, 38.68979372084141, 39.34566132724285, 42.88088522851467, 39.12105917930603, 36.48387148976326, 37.821665704250336, 36.96340195834637, 37.467912286520004, 38.718827962875366, 38.417941108345985, 37.175806760787964, 43.77998158335686, 43.67898300290108, 37.399166375398636, 37.89493337273598, 37.19586208462715, 38.8104372471571, 38.35026293992996, 39.8741901665926, 39.46218587458134, 38.93893875181675, 38.88410769402981, 39.211585521698, 37.907142117619514, 40.314233154058456, 43.1680092215538, 43.2180031388998, 45.589900463819504, 46.57283931970596, 44.07647967338562, 45.28553679585457, 40.76367683708668, 40.90118385851383, 44.77153077721596, 47.370762303471565, 50.49544483423233, 53.45297813415527, 54.759272038936615, 55.585260316729546, 57.26382024586201, 57.67621971666813, 57.09278762340546, 57.95513994991779, 58.208027780056, 57.37030193209648, 57.67028823494911, 58.85180443525314, 57.708780169487, 58.11779782176018, 66.55811011791229, 63.89594256877899, 58.10251124203205, 40.71290396153927, 71.07194870710373, 74.0042893588543, 47.4175263941288, 1.2691136123612523, 0.0946220921468921, 2.099370011128485, 0.06081037463445682, 0.10439064062666148, 9.564216937869787, 70.41510075330734, 62.42807753384113, 67.95644268393517, 69.42206963896751, 53.13541777431965, 19.965527057647705, 10.267105121165514, 25.419190116226673, 56.39895625412464, 51.91534884274006, 3.0320273526012897, 0.07296251962543465, 0.07073247717926279, 0.07099888593074866, 0.05319418429280631, 0.043585965686361305, 0.06791385225369595, 0.0591093202092452, 0.09037835072376765, 0.00891299228896969, 0.03500801874906756, 0.16035684297094122, 0.23040822154143825, 9.280427265912294, 74.49203118681908, 58.031314462423325, 56.92247316241264, 33.14362272620201, 34.13396738469601, 53.48322071135044, 55.50877042114735, 75.61879232525826, 59.12276029586792, 77.20949336886406, 14.970472790300846, 0.27848313795402646, 3.4651627857238054, 28.17129883915186, 11.132868714630604, 2.519352687522769, 12.94707851484418, 58.04125852882862, 58.785296604037285, 63.662270307540894, 61.33255451917648, 57.405488044023514, 54.07160013914108, 50.28641805052757, 53.6579505354166, 55.66975638270378, 59.089287891983986, 60.845409259200096, 60.337482914328575, 56.956268548965454, 58.97242896258831, 60.59182606637478, 57.042862102389336, 57.618736401200294, 55.050271824002266, 52.68481135368347, 49.68292683362961, 44.06481049954891, 41.718375608325005, 41.788082867860794, 44.027355909347534, 42.444778829813, 41.501346454024315, 42.98457786440849, 39.72620710730553, 40.271690636873245, 41.70976907014847, 39.86123666167259, 41.23282626271248, 41.858409494161606, 41.11787483096123, 39.48382191359997, 40.29254011809826, 41.371655613183975, 39.55851070582867, 39.7873268276453, 40.93002811074257, 40.417914390563965, 40.81310078501701, 40.48429682850838, 44.295477122068405, 50.31573727726936, 42.92451448738575, 39.87794816493988, 41.32200747728348, 39.80803571641445, 39.47084940969944, 40.25720201432705, 42.22821705043316, 41.78615637123585, 38.77851516008377, 40.41488215327263, 41.15732431411743, 40.93989238142967, 40.394674837589264, 40.62620401382446, 43.51480521261692, 44.21440087258816, 47.62140445411205, 46.47676147520542, 44.28647920489311, 46.12484335899353, 45.18867999315262, 43.27820710837841, 41.80118076503277, 40.115777403116226, 40.37965044379234, 37.57393799722195, 39.7947858273983, 41.28132686018944, 40.79570151865482, 41.13801375031471, 43.91750380396843, 40.54657928645611, 37.52231016755104, 38.17915432155132, 37.297548428177834, 38.46247471868992, 36.81534290313721, 39.72518876194954, 36.483765095472336, 44.91648159921169, 45.177443996071815, 39.48886804282665, 38.695759400725365, 40.91313421726227, 39.97159793972969, 38.61092895269394, 42.17471972107887, 41.6069807857275, 40.331510826945305, 39.98741269111633, 41.46528258919716, 40.875710025429726, 44.02890242636204, 45.33078856766224, 46.062994077801704, 49.30716499686241, 47.341948449611664, 45.110677778720856, 46.588422283530235, 42.53433622419834, 42.95089267194271, 44.94482807815075, 51.40411667525768, 52.67836309969425, 55.35731814801693, 56.23433768749237, 58.19731995463371, 58.33847098052502, 59.16389688849449, 58.271024599671364, 60.281838700175285, 60.17866663634777, 59.186984449625015, 60.61228796839714, 61.39624670147896, 59.390946105122566, 61.84640094637871, 67.89242371916771, 64.20650750398636, 57.15927265584469, 42.58442133665085, 68.86153891682625, 73.62562447786331, 51.75003871321678, 1.0061957454308867, 0.062045479062362574, 2.3821836104616523, 0.5320971447508782, 0.1305912886164151, 10.956938154995441, 75.85381731390953, 66.09905675053596, 76.03671669960022, 72.86922186613083, 48.41780751943588, 25.629594326019287, 20.060550458729267, 37.52440385520458, 63.55280198156834, 62.26663559675217, 4.349287943914533, 0.07734617072856054, 0.1268926472403109, 0.07125003612600267, 0.07312906498555094, 0.015101139288162813, 0.11950144267757423, 0.17664238315774128, 0.16059079760452732, 0.21755710331490263, 0.13991284155054018, 0.3117930411826819, 0.42097564029973, 14.426798913627863, 88.22854489088058, 64.94701936841011, 68.4364253282547, 40.03954969346523, 40.70777043700218, 63.77010852098465, 64.1135036945343, 80.60833498835564, 63.85856777429581, 82.81705766916275, 16.41920395195484, 0.3597193054156378, 7.862596996128559, 26.389437653124332, 7.939526718109846, 4.215848129242659, 16.94650735706091, 59.93497051298618, 58.574947491288185, 67.02197402715683, 63.68144407868385, 58.61263006925583, 57.47917369008064, 54.74158018827438, 56.38689950108528, 59.287656247615814, 60.19966810941696, 63.38909536600113, 59.421352073550224, 59.06855620443821, 61.0889495909214, 62.107701525092125, 59.65622887015343, 60.80250196158886, 57.568769082427025, 55.16201622784138, 52.837760746479034, 47.96289213001728, 43.77620838582516, 43.97511251270771, 46.03120498359203, 44.46959137916565, 44.848868027329445, 45.79215221107006, 40.79059459269047, 43.0718781799078, 43.2825730741024, 41.72268457710743, 45.11502094566822, 46.2700791656971, 43.51392365992069, 42.464279383420944, 42.80276142060757, 42.29266159236431, 41.365705132484436, 41.09833247959614, 43.41839298605919, 42.487252950668335, 42.45022773742676, 42.1304102987051, 45.14854274690151, 52.362455651164055, 44.07270647585392, 40.335789397358894, 42.94480159878731, 41.83207310736179, 41.12096406519413, 41.34898602962494, 44.76524971425533, 44.514383375644684, 38.59672911465168, 41.597371101379395, 44.406868144869804, 41.23637907207012, 42.702678591012955, 44.794321954250336, 45.352515801787376, 46.77814230322838, 49.89585980772972, 48.04005838930607, 46.77839308977127, 49.16251055896282, 46.91892474889755, 45.46548753976822, 44.676136896014214, 43.06002661585808, 44.36693228781223, 39.5465337485075, 42.08764739334583, 43.846618607640266, 43.03153574466705, 43.26658733189106, 47.07653649151325, 41.82085230946541, 38.86634364724159, 39.24641065299511, 38.137599751353264, 37.84918002784252, 37.566596791148186, 39.41191457211971, 37.288930490612984, 47.336590737104416, 48.2943369448185, 41.13976165652275, 42.68055237829685, 41.88033051788807, 42.68262326717377, 41.99180893599987, 43.79844479262829, 44.31192643940449, 41.90142698585987, 42.56030783057213, 44.59203600883484, 41.79407134652138, 47.050675079226494, 48.91569100320339, 48.62747646868229, 50.27439929544926, 51.882047429680824, 47.50187046825886, 49.588365107774734, 44.637147188186646, 45.58673903346062, 49.355430006980896, 54.836027920246124, 55.91058745980263, 58.82136806845665, 59.92870084941387, 62.919505164027214, 61.12467147409916, 62.36095413565636, 59.74984064698219, 61.523353680968285, 64.35321763157845, 63.820235431194305, 64.04946193099022, 65.45879110693932, 62.03183099627495, 65.0472503900528, 72.17873051762581, 66.3512872159481, 59.47172977030277, 49.640692099928856, 70.98237991333008, 71.49374127388, 57.48236171901226, 2.042049611918628, 0.5243754247203469, 6.446452410891652, 2.6982159772887826, 0.35355977655854076, 12.637045551091433, 83.2732991874218, 75.08299067616463, 79.53244552016258, 85.62121599912643, 65.81916376948357, 29.220433942973614, 21.990079320967197, 44.77346867322922, 74.05816286802292, 73.41539695858955, 6.5478950925171375, 0.22782387037295848, 0.22173607751028612, 0.18859994073864073, 0.21353993215598166, 0.19483901298372075], [0.027469913475215435, 0.02517636545235291, 0.05166435075807385, 0.0784460484283045, 0.07194493126007728, 0.1356252169352956, 0.14997582969954237, 7.992913853377104, 67.5208568572998, 56.50248169898987, 42.23242722451687, 16.500694379210472, 17.1093837171793, 50.74811987578869, 52.082372680306435, 68.045654296875, 58.66112306714058, 67.98484995961189, 12.749438770115376, 0.7006888731848449, 5.543141607195139, 6.623381841927767, 13.673286996781826, 1.5722613455727696, 9.675017092376947, 68.87639611959457, 63.727957382798195, 58.9335722476244, 58.807137832045555, 54.57024738192558, 51.767551973462105, 47.65876404941082, 51.01741902530193, 50.75782835483551, 56.68559767305851, 55.6545078009367, 56.73770047724247, 55.98493047058582, 58.02932716906071, 55.78130699694157, 54.959194511175156, 53.45533400774002, 46.9865383207798, 41.17000423371792, 39.25003185868263, 38.68483878672123, 39.17646400630474, 37.058909833431244, 41.32944367825985, 37.993606477975845, 39.3931245803833, 38.45107913017273, 40.564609318971634, 39.41135220229626, 38.00281338393688, 38.623882457613945, 38.504413068294525, 39.587750136852264, 37.26567953824997, 40.69069415330887, 38.841082602739334, 36.5954715013504, 37.17410445213318, 37.974972277879715, 37.72492289543152, 38.37296672165394, 37.81424470245838, 38.474949449300766, 39.6607556194067, 47.492880150675774, 48.16985182464123, 39.79055665433407, 40.37439912557602, 38.78518000245094, 37.91689619421959, 37.10918113589287, 37.76130594313145, 38.58292445540428, 36.374327167868614, 36.026706621050835, 39.345999509096146, 38.07122491300106, 36.843047216534615, 38.408095836639404, 40.12420915067196, 42.034267857670784, 42.21689745783806, 43.46552185714245, 42.12918296456337, 37.974843084812164, 40.43269939720631, 38.85104566812515, 40.00611908733845, 39.423260763287544, 37.27257236838341, 37.80124939978123, 36.87812693417072, 37.1002060174942, 38.370151072740555, 38.726853132247925, 39.22618813812733, 38.83945249021053, 37.02432408928871, 38.43151398003101, 37.379228845238686, 38.679287284612656, 36.62864752113819, 37.8892070800066, 37.73511774837971, 46.38995513319969, 42.97559894621372, 36.70404687523842, 38.697260320186615, 39.90176908671856, 39.45120446383953, 38.22036691009998, 39.92723532021046, 38.780532851815224, 40.64283952116966, 37.805664762854576, 38.631694838404655, 41.56892962753773, 45.15952415764332, 45.96560910344124, 49.4718823581934, 48.4203077852726, 48.691693022847176, 46.82344727218151, 45.936305075883865, 42.19179220497608, 40.451888367533684, 40.61973676085472, 42.535780146718025, 43.59110891819, 45.83868071436882, 50.53918428719044, 54.01238031685352, 52.06055425107479, 56.24969646334648, 56.250213235616684, 59.267650321125984, 55.595713555812836, 56.573370695114136, 57.14052066206932, 54.6862817555666, 57.71774388849735, 61.161396503448486, 58.62529098987579, 65.54914265871048, 48.00395652651787, 49.22790884971619, 63.636511489748955, 71.13719120621681, 47.25581467151642, 0.6799405615311116, 0.11112185326055624, 1.8143617920577526, 0.20037671114550903, 0.08559160211007111, 7.725284239277244, 68.20988908410072, 63.26353870332241, 68.08122038841248, 63.12276765704155, 54.65749070048332, 21.760092861950397, 11.87293030321598, 29.61548924446106, 54.29383881390095, 51.390011832118034, 4.726948253810406, 0.22485660068923607, 0.09655650006607175, 0.03532838905812241, 0.09655419198679738, 0.08549370541004464, 0.0336157126002945, 0.05382837916840799, 0.07446122748660855, 0.02707741568883648, 0.06293075362918898, 0.12773014605045319, 0.23082884115865454, 10.74874922633171, 77.06751018762589, 60.83642654120922, 53.95468421280384, 22.002101875841618, 24.480900764465332, 54.35152351856232, 57.42727607488632, 73.93372714519501, 63.31623427569866, 73.40243205428123, 14.473867937922478, 0.6799759471323341, 1.1815647664479911, 7.780132396146655, 9.316093102097511, 0.9957615053281188, 9.931597374379635, 69.21749621629715, 62.698402628302574, 61.47052891552448, 61.21884562075138, 57.899222150444984, 54.000479355454445, 51.047597005963326, 52.280513048172, 53.40081453323364, 56.57164178788662, 60.54865278303623, 58.05076941847801, 58.556647673249245, 58.69399130344391, 57.42567636072636, 55.927108973264694, 56.999643221497536, 47.9046830534935, 43.155371099710464, 41.757977083325386, 40.33490024507046, 41.92887291312218, 40.47461114823818, 42.34510637819767, 40.23078963160515, 42.43022181093693, 40.879749208688736, 42.67603062093258, 41.4739803224802, 40.43707296252251, 40.181411281228065, 40.22668585181236, 40.52023530006409, 39.23466928303242, 41.8830131739378, 40.37600263953209, 39.88908536732197, 39.01134766638279, 40.379566848278046, 39.50415842235088, 40.52853025496006, 39.12535294890404, 40.290967002511024, 41.52905836701393, 52.96787716448307, 49.9028704315424, 38.52519415318966, 39.50035862624645, 38.33950571715832, 38.77856835722923, 40.30319094657898, 39.45158064365387, 39.50593292713165, 37.89565533399582, 37.14068904519081, 39.20686237514019, 38.77732962369919, 38.725857585668564, 39.241733103990555, 39.68588747084141, 43.30817610025406, 45.44336512684822, 44.691864252090454, 43.81511069834232, 41.13672561943531, 42.103538140654564, 41.37804687023163, 42.6133643835783, 39.51760970056057, 38.94279934465885, 39.82322350144386, 40.85213229060173, 38.148277178406715, 41.22688338160515, 41.92055515944958, 40.90285196900368, 39.81234088540077, 36.71794272959232, 37.919088676571846, 37.393033504486084, 39.1254061460495, 37.70673707127571, 38.81974294781685, 36.94045878946781, 47.90320873260498, 45.28220817446709, 38.060631081461906, 39.16242755949497, 39.51084226369858, 41.80786460638046, 39.09917615354061, 40.20608715713024, 40.973664969205856, 41.86402179300785, 40.492500588297844, 40.69507151842117, 43.6380136013031, 47.908615842461586, 47.337757274508476, 49.18393760919571, 51.69164724647999, 51.56094565987587, 49.34757582843304, 48.61117534339428, 43.45063425600529, 42.23237402737141, 44.09314177930355, 45.21376244723797, 47.89299488067627, 48.55753742158413, 52.1140705794096, 55.33398360013962, 53.84075112640858, 57.17427045106888, 59.16189059615135, 60.59711918234825, 57.9516327381134, 58.47921542823315, 59.17795613408089, 57.68774449825287, 59.964624121785164, 62.41472885012627, 60.792345106601715, 67.05546543002129, 52.524767741560936, 51.080628633499146, 67.27541282773018, 71.19030475616455, 52.12124839425087, 0.6818394502624869, 0.030981641248217784, 2.4038194119930267, 0.5736639455426484, 0.2344614313915372, 8.367566149681807, 73.69555592536926, 68.90081360936165, 72.62727364897728, 72.19905942678452, 49.66439142823219, 19.363658353686333, 14.286907520145178, 34.46769967675209, 63.40998284518719, 64.00950327515602, 6.559750931337476, 0.17733253596816212, 0.06434054477722384, 0.07821592327672988, 0.017416974005755037, 0.0467316884896718, 0.09316103343735449, 0.19333475385792553, 0.25827148812823, 0.15728295635199174, 0.22222693398362026, 0.30143734999001026, 0.43540872051380575, 14.596412312239408, 86.09291508793831, 70.30714854598045, 62.580263167619705, 28.541201390326023, 27.54057638347149, 62.77293182909489, 65.68580612540245, 79.55749377608299, 68.33366364240646, 79.05206009745598, 15.96448615193367, 0.8363702706992626, 11.784084420651197, 13.442810364067554, 28.030153512954712, 2.4548243125900626, 12.17595549300313, 69.76289615035057, 62.609684988856316, 62.721839770674706, 63.50326403975487, 60.85959769785404, 57.33555659651756, 52.72859640419483, 54.55010466277599, 54.81864005327225, 62.088698744773865, 63.192007541656494, 60.68081349134445, 59.25396345555782, 61.60029575228691, 59.94494117796421, 59.04962942004204, 59.982547760009766, 51.10940828919411, 44.64632369577885, 44.39839459955692, 43.298646211624146, 44.55079682171345, 40.29302269220352, 45.035867393016815, 43.17615978419781, 43.73294770717621, 43.42781648039818, 46.48626856505871, 42.97139637172222, 43.64171460270882, 44.18110705912113, 44.002885222435, 44.59010951220989, 42.587385177612305, 44.01602491736412, 42.69798584282398, 40.74641816318035, 41.82899907231331, 41.085603162646294, 42.69360467791557, 41.84796765446663, 40.19218750298023, 43.76892417669296, 42.89092808961868, 54.51357342302799, 51.72250159084797, 38.88816587626934, 40.64571976661682, 38.497630432248116, 40.722848027944565, 39.70333993434906, 39.53345865011215, 42.06994794309139, 39.06798742711544, 40.234578028321266, 43.63901674747467, 41.74879677593708, 41.732533648610115, 42.67910085618496, 42.19300054013729, 46.77109368145466, 47.33000569045544, 47.504157945513725, 47.59362414479256, 42.67248161137104, 45.639088824391365, 43.4352982789278, 45.044682919979095, 44.10582169890404, 40.37465751171112, 42.93085254728794, 41.36592552065849, 40.79615369439125, 42.78115198016167, 43.601581156253815, 43.286433666944504, 41.57790094614029, 37.54100136458874, 37.939641773700714, 37.690910920500755, 41.322520449757576, 36.75958849489689, 38.548832684755325, 38.18837262690067, 48.7802928686142, 47.70525075495243, 40.47703541815281, 42.52374239265919, 42.3300401866436, 45.12912958860397, 41.879281774163246, 43.626329228281975, 41.912921369075775, 44.89386521279812, 43.29445123672485, 42.611825466156006, 45.81526257097721, 50.31254164874554, 51.61613389849663, 53.15292343497276, 52.37128257751465, 52.99726478755474, 52.275356724858284, 49.91623431444168, 45.057218447327614, 44.00861531496048, 45.19146904349327, 46.818879917263985, 50.31061515212059, 50.05297377705574, 54.0953678637743, 57.80474402010441, 57.641785964369774, 60.91434895992279, 60.749187022447586, 64.76471275091171, 60.15757016837597, 61.466664522886276, 63.214346542954445, 58.60664539039135, 63.7783008813858, 65.22088587284088, 62.219890505075455, 69.52910229563713, 57.66429975628853, 55.10472670197487, 67.39272013306618, 71.83816239237785, 53.90265740454197, 1.5146667673252523, 0.4559607489500195, 5.667048683390021, 2.2121346602216363, 0.33715905505232513, 9.787640199065208, 80.50877273082733, 74.49003249406815, 76.72106757760048, 80.54363206028938, 66.46614745259285, 30.58891911059618, 22.867866419255733, 44.94812250137329, 73.23271036148071, 75.67832753062248, 10.31016156077385, 0.5116725875996053, 0.2934062434360385, 0.21780319948447868, 0.29649684322066605, 0.13798483094433323], [0.07359554190770723, 0.03246332053095102, 0.03336655878229067, 0.02358999139687512, 0.1452616779715754, 0.26328751584514976, 0.17377650568960235, 8.78229869529605, 67.03820675611496, 54.06591184437275, 38.168085515499115, 16.65514849126339, 28.183427788317204, 35.035123229026794, 54.06085431575775, 70.05890026688576, 56.62184849381447, 68.52124437689781, 12.756045665591955, 0.5090463347733021, 1.8023545551113784, 14.771900195628405, 15.080771371722221, 1.1305912141688168, 10.581684540957212, 66.65935948491096, 62.49126434326172, 62.414709851145744, 59.09371465444565, 56.0864382237196, 49.327782690525055, 45.57097747921944, 46.91434979438782, 49.68292683362961, 51.476236805319786, 53.35648611187935, 54.88615483045578, 53.96112486720085, 55.63300855457783, 51.45960129797459, 48.74734863638878, 40.41394740343094, 41.02816924452782, 39.95177440345287, 38.28286975622177, 39.747953340411186, 40.34226804971695, 41.691484451293945, 42.33539789915085, 43.334645479917526, 41.352945417165756, 45.1920960098505, 42.77392476797104, 42.30784557759762, 39.19696390628815, 39.77557025849819, 37.69664481282234, 38.62439922988415, 36.89129322767258, 38.09519402682781, 38.717995807528496, 39.25807222723961, 37.69666761159897, 36.88813179731369, 36.45785428583622, 38.08754123747349, 36.570810824632645, 39.15559932589531, 40.08888244628906, 46.70469604432583, 52.796301171183586, 39.11286681890488, 39.931221306324005, 39.37647767364979, 37.387622594833374, 38.07159349322319, 36.98405385017395, 37.19167850911617, 37.75686398148537, 36.27657361328602, 38.415505439043045, 37.59503826498985, 39.20298658311367, 36.072034388780594, 38.10736857354641, 38.52228730916977, 40.39675332605839, 38.79410192370415, 38.15030246973038, 36.207702308893204, 39.68651823699474, 39.70075607299805, 38.50978597998619, 36.46287761628628, 38.672253862023354, 37.269593328237534, 37.82255105674267, 37.53312058746815, 40.03707982599735, 39.24351520836353, 38.5440943390131, 35.47026067972183, 38.20316903293133, 39.45135645568371, 41.11554555594921, 36.5789195895195, 37.66598805785179, 36.4188189804554, 40.84360174834728, 46.70416787266731, 41.0693134367466, 38.831058740615845, 39.85408164560795, 37.80227534472942, 38.55148494243622, 40.01936137676239, 40.661063343286514, 39.44702468812466, 38.4893848747015, 38.732119649648666, 37.942411825060844, 40.14261156320572, 45.55564910173416, 46.680134162306786, 48.60367074608803, 50.415595918893814, 50.92359445989132, 50.088186487555504, 47.74438105523586, 47.63383738696575, 42.76150703430176, 40.97703158855438, 40.434910878539085, 39.95907761156559, 43.34626145660877, 43.287919387221336, 45.56553237140179, 46.54395706951618, 50.21223463118076, 48.73860910534859, 51.48642785847187, 45.72069324553013, 47.445606887340546, 48.12098644673824, 51.66042812168598, 50.278316885232925, 54.4474645704031, 57.0225065946579, 63.028171733021736, 61.40210218727589, 63.61729972064495, 50.2751250565052, 61.28138266503811, 41.74624711275101, 0.4085043235681951, 0.3462762205163017, 1.2010832503437996, 0.5963267607148737, 0.015504362036153907, 6.0161468759179115, 69.86549064517021, 63.6897998303175, 73.82922515273094, 61.32203288376331, 74.99646931886673, 74.89395841956139, 30.186969079077244, 39.50715646147728, 57.01785184442997, 49.77303519845009, 5.340040605515242, 0.20984880131436512, 0.16163019026862457, 0.011219267216802109, 0.08188936131773517, 0.11072119741584174, 0.04318908366258256, 0.012022607752442127, 0.030935570575820748, 0.03320137155242264, 0.09090480802115053, 0.2988091082079336, 0.1925840269541368, 11.192095186561346, 80.11751532554626, 58.39856095612049, 48.3691131323576, 21.055555567145348, 31.681480184197426, 42.572524175047874, 58.13720338046551, 75.29402375221252, 61.87858521938324, 73.4121823310852, 13.505859430879354, 0.4162750847171992, 0.5282009288202971, 5.733010768890381, 9.522010702639818, 1.4644141076132655, 11.650511138141155, 66.7169263958931, 64.12470549345016, 67.6492291688919, 61.74776203930378, 58.52116897702217, 50.832737535238266, 48.53954918682575, 49.74541448056698, 51.943839713931084, 53.30656059086323, 55.93764580786228, 57.98471376299858, 56.55852869153023, 55.81811182200909, 54.15019512176514, 51.74777403473854, 42.701899632811546, 43.81013676524162, 41.765607073903084, 39.92535442113876, 43.09119634330273, 41.873802468180656, 42.78642229735851, 43.7945120036602, 43.24105650186539, 44.91010174155235, 48.38808171451092, 45.672052055597305, 43.269885554909706, 42.092469334602356, 41.030183136463165, 39.24160771071911, 40.307389721274376, 39.70607578754425, 39.921642020344734, 40.490615889430046, 41.684933602809906, 39.63819243013859, 39.03299130499363, 38.00447769463062, 41.21619455516338, 39.75789360702038, 38.563024923205376, 39.67752031981945, 48.0555235594511, 55.75502000749111, 40.03944709897041, 41.06781631708145, 41.66378393769264, 39.89536263048649, 37.94732876121998, 36.59593507647514, 38.97046186029911, 38.96172992885113, 40.22314824163914, 39.274627938866615, 39.70693454146385, 39.581807255744934, 36.94941870868206, 41.89034678041935, 40.6654255092144, 42.78887316584587, 41.93199634552002, 39.90038216114044, 39.91514816880226, 42.55441054701805, 40.11671595275402, 40.14042668044567, 37.75895766913891, 40.78303299844265, 38.55564571917057, 40.00952750444412, 39.067364260554314, 40.794458985328674, 39.4362598657608, 38.70979584753513, 36.27822272479534, 38.27058881521225, 39.76889781653881, 40.98361283540726, 36.33786432445049, 37.20435082912445, 36.46682180464268, 40.65765492618084, 50.23881420493126, 42.318948581814766, 39.021572917699814, 40.41557751595974, 41.03901006281376, 40.37931986153126, 41.994658783078194, 40.366670340299606, 41.45810857415199, 40.050766691565514, 39.69387464225292, 40.305364429950714, 41.98796734213829, 47.68362611532211, 48.956428617239, 49.386238753795624, 51.83122135698795, 54.56085428595543, 52.5999391078949, 51.09704375267029, 49.03872840106487, 43.87309558689594, 43.79581153392792, 41.73686161637306, 41.31179742515087, 45.44254817068577, 44.12274219095707, 48.52171674370766, 49.628266766667366, 53.688926473259926, 51.30669750273228, 53.61139543354511, 49.524410739541054, 50.66165551543236, 49.6846329420805, 53.11298757791519, 52.83579625189304, 58.61778639256954, 58.4880917519331, 66.80185183882713, 63.35976853966713, 64.65764209628105, 56.37387380003929, 59.27104353904724, 48.85534264147282, 0.6992606248240918, 0.3526198910549283, 4.4891242403537035, 0.7461860287003219, 0.17931893875356764, 6.697531538084149, 75.38433730602264, 68.50655436515808, 78.00263240933418, 68.9612227678299, 61.223652362823486, 39.86430309712887, 25.174291357398033, 46.08706958591938, 65.31815305352211, 60.72187788784504, 7.476366721093655, 0.22548926674062386, 0.16338248999090865, 0.0339231027464848, 0.07393966094241478, 0.01905469354824163, 0.22711759811500087, 0.11870873990119435, 0.4546884703449905, 0.23126902378862724, 0.24024671001825482, 0.5836331262253225, 0.5376898508984596, 17.382262274622917, 87.60038539767265, 66.96727976202965, 55.20016238093376, 30.899848826229572, 37.16449096798897, 48.06440368294716, 66.05316281318665, 79.72397044301033, 66.28759503364563, 80.16215533018112, 15.301062650978565, 0.7035669218748808, 7.174917971715331, 38.645260110497475, 30.02642009407282, 2.2904926305636764, 14.233915563672781, 68.49857479333878, 67.13508635759354, 68.9745144546032, 64.19495612382889, 60.360027104616165, 54.934815019369125, 49.260340109467506, 52.194383069872856, 54.75345455110073, 56.953327506780624, 58.37139241397381, 60.97842492163181, 58.92605625092983, 58.73204246163368, 56.66273050010204, 53.2492520660162, 44.012890085577965, 44.80816841125488, 44.06746655702591, 41.084816604852676, 45.26072792708874, 44.58088740706444, 45.91745428740978, 47.42924116551876, 46.263292729854584, 44.87791366875172, 50.782219246029854, 47.404170110821724, 45.982772782444954, 44.75588321685791, 42.26979061961174, 42.65757501125336, 43.282584473490715, 42.937380596995354, 43.402019664645195, 43.19904215633869, 44.37502585351467, 40.80392047762871, 42.29145705699921, 39.700068309903145, 41.96547634899616, 40.333106741309166, 41.07414297759533, 44.26350563764572, 51.153337731957436, 59.28135618567467, 39.254717007279396, 40.78416533768177, 40.847728326916695, 38.2099212706089, 38.40819463133812, 37.2070524841547, 39.950189888477325, 40.536817610263824, 41.39021761715412, 42.918670400977135, 43.43167707324028, 43.778161481022835, 39.60408166050911, 43.90966862440109, 42.60205999016762, 45.1288066059351, 43.77275437116623, 42.23898947238922, 42.111145332455635, 46.97012320160866, 42.367019802331924, 44.258938282728195, 39.395940229296684, 44.14415784180164, 41.19769334793091, 43.67072984576225, 41.04683004319668, 44.555090591311455, 41.66558504104614, 40.793858617544174, 36.9551146030426, 39.20500807464123, 39.151385352015495, 43.09121534228325, 36.05772815644741, 37.988666743040085, 37.712847143411636, 41.5431822091341, 51.70250706374645, 45.236021652817726, 40.87793670594692, 43.37467633187771, 42.83437192440033, 42.720051258802414, 44.20872017741203, 43.88392120599747, 43.56241285800934, 42.04189404845238, 43.17314654588699, 44.260283410549164, 44.89214390516281, 52.9215082526207, 52.717512398958206, 53.27328197658062, 53.24832871556282, 56.14057391881943, 54.3143805116415, 53.11600461602211, 51.07066176831722, 45.86423434317112, 45.583942383527756, 43.602918684482574, 43.97910229861736, 48.91504883766174, 45.94471402466297, 51.48586928844452, 53.04905220866203, 56.94435618817806, 52.670725509524345, 56.08299180865288, 52.19849444925785, 53.843125998973846, 54.33909818530083, 56.5400654822588, 55.31418666243553, 60.731434375047684, 62.434974163770676, 69.84092116355896, 66.6118848323822, 67.52258196473122, 58.886029198765755, 61.533404141664505, 53.62808033823967, 1.1474431911483407, 0.9137126861605793, 5.316558815538883, 1.5082198195159435, 0.48530363535974175, 7.928174352273345, 82.28599816560745, 76.03996932506561, 83.60075041651726, 76.83715894818306, 86.67625218629837, 86.33084312081337, 43.54388885200024, 55.50008028745651, 73.91712963581085, 74.5519083738327, 10.98710473626852, 0.3799334488576278, 0.32772947510238737, 0.18740514235105366, 0.2738413604674861, 0.12867625075159594], [0.04179479969025124, 0.04083300969796255, 0.07574509843834676, 0.032546786169405095, 0.13828197203110904, 0.214504100731574, 0.23296867555473, 11.267743427306414, 63.85193333029747, 50.69593347609043, 37.82621406018734, 22.123070284724236, 18.091057240962982, 28.243455067276955, 58.156563341617584, 69.20235022902489, 60.17032228410244, 68.65608394145966, 13.800162188708782, 0.3908223583130166, 0.249660259578377, 3.045500717125833, 2.1505941124632955, 0.6238992686849087, 11.208977680653334, 68.39464277029037, 55.23425415158272, 62.56851799786091, 59.536672085523605, 53.82744424045086, 48.86662423610687, 44.49574537575245, 41.378738433122635, 41.73764817416668, 42.75013044476509, 44.180810675024986, 44.309198185801506, 45.321539863944054, 44.576358050107956, 41.07459515333176, 39.31392543017864, 38.777781799435616, 39.49227645993233, 40.83895839750767, 40.99199518561363, 41.250924691557884, 43.399610593914986, 45.07314719259739, 45.95583222806454, 51.87951296567917, 50.95869317650795, 48.98935765028, 47.07987651228905, 43.3081229031086, 40.55398128926754, 39.658916518092155, 37.138420566916466, 38.26312221586704, 37.399276569485664, 36.25343285501003, 36.751840710639954, 38.51827472448349, 38.67766477167606, 37.33713090419769, 36.105495393276215, 37.27967418730259, 34.89357702434063, 37.96399846673012, 38.46942834556103, 42.77066454291344, 54.628973230719566, 43.69742341339588, 38.61786738038063, 38.82649898529053, 39.34225670993328, 38.14402140676975, 36.98708988726139, 36.40353240072727, 39.519912376999855, 37.37646259367466, 37.71510802209377, 34.83060300350189, 37.649105563759804, 36.45386829972267, 37.702169716358185, 37.37583562731743, 37.72607423365116, 37.99078322947025, 38.318287655711174, 36.96112588047981, 39.398736879229546, 37.04007424414158, 37.42868699133396, 36.431267112493515, 37.62069068849087, 38.74754682183266, 36.70148581266403, 36.713082790374756, 39.72342945635319, 38.875341564416885, 37.27237097918987, 37.29903034865856, 36.07619896531105, 36.07969477772713, 37.22301162779331, 36.862008199095726, 38.205969482660294, 37.16853015124798, 43.69745001196861, 51.137883961200714, 38.08779962360859, 37.224558144807816, 38.5545551776886, 39.832297414541245, 39.12876896560192, 36.912515088915825, 38.49036522209644, 39.020322784781456, 38.84112060070038, 38.07811014354229, 37.78237961232662, 40.56040294468403, 45.49522094428539, 47.9505617916584, 48.31262156367302, 49.30274963378906, 53.29359948635101, 54.51473616063595, 51.79580345749855, 50.05025692284107, 47.319035679101944, 45.46739883720875, 40.13138696551323, 41.93302609026432, 43.89416165649891, 42.479835748672485, 42.53398284316063, 41.240171268582344, 41.77446059882641, 44.7356341034174, 43.28894533216953, 43.65690618753433, 46.33239582180977, 46.44936874508858, 48.34640935063362, 51.531056463718414, 57.95100957155228, 58.4014867991209, 62.117280811071396, 64.54773679375648, 63.2001581043005, 43.03656667470932, 50.97491070628166, 31.171838231384754, 0.10935018348391168, 0.29597944754641503, 1.7493193759582937, 0.7999948225915432, 0.1710093635483645, 5.976735865697265, 69.02553051710129, 65.39756879210472, 72.36906990408897, 63.47606509923935, 64.17528837919235, 83.51048246026039, 23.300323113799095, 29.381725788116455, 54.68901000916958, 51.825890243053436, 4.00538882240653, 0.03484462380583864, 0.06958869402296841, 0.05135868981597014, 0.1250843598973006, 0.07262180704856291, 0.046369453630177304, 0.024993518818519078, 0.05993279242829885, 0.03344917466165498, 0.14135018864180893, 0.2587832137942314, 0.2898814872605726, 15.472440104931593, 73.71776953339577, 58.27493079006672, 47.199068516492844, 32.21874475479126, 19.743440374732018, 30.345832854509354, 63.919904083013535, 71.31671637296677, 66.04671835899353, 73.18414896726608, 15.250887293368578, 0.5008384783286601, 0.008155611103575211, 4.082486210390925, 4.8609057907015085, 0.5304639448877424, 12.688118610531092, 66.93048253655434, 60.27815669775009, 65.46237051486969, 61.01748302578926, 57.34515868127346, 51.40070825815201, 47.12711937725544, 42.88235954940319, 42.956033796072006, 44.809182956814766, 45.750951021909714, 47.087901681661606, 47.280224561691284, 45.095645785331726, 42.54176862537861, 42.72242613136768, 41.42243608832359, 41.09790310263634, 43.22634369134903, 42.82678373157978, 42.665307596325874, 45.46610690653324, 47.918039336800575, 47.685282826423645, 52.954615876078606, 52.068609818816185, 50.99725730717182, 48.591268211603165, 46.6471291333437, 44.693767949938774, 41.71162337064743, 39.90946367383003, 39.49408136308193, 39.14576165378094, 37.33495742082596, 39.675175845623016, 39.85391065478325, 39.96340177953243, 38.983320370316505, 39.09073680639267, 38.80264766514301, 40.061299726367, 39.533538445830345, 40.91059595346451, 44.77245792746544, 56.85945734381676, 44.31994780898094, 39.089859053492546, 39.785096347332, 38.70481811463833, 39.105130434036255, 38.72980937361717, 39.305885061621666, 39.96283181011677, 39.70038369297981, 38.84452901780605, 38.059548139572144, 38.333175256848335, 36.70355290174484, 39.292840361595154, 38.88264857232571, 39.126242101192474, 39.29070867598057, 40.757851749658585, 39.678097888827324, 42.45903566479683, 38.88242818415165, 39.24535430967808, 38.42251606285572, 40.63376180827618, 39.78309005498886, 40.0677327811718, 38.040359169244766, 41.6232743114233, 39.886284917593, 36.79826661944389, 36.501464545726776, 37.30778127908707, 35.774947330355644, 37.93172299861908, 37.841918617486954, 38.953940346837044, 36.82988852262497, 44.910215735435486, 53.65061312913895, 41.843043118715286, 40.49153544008732, 39.453343749046326, 42.0348834246397, 40.87535284459591, 41.31635718047619, 42.001031041145325, 40.386847257614136, 40.1874415576458, 39.643713533878326, 38.78388047218323, 41.94350592792034, 48.41821789741516, 51.15143783390522, 48.83789397776127, 52.635782584548, 55.65225072205067, 56.248062551021576, 52.921755239367485, 53.81732538342476, 50.50940528512001, 45.66508322954178, 42.91837401688099, 44.693201780319214, 44.513448625802994, 43.43741096556187, 44.3053337931633, 43.06427478790283, 44.39277470111847, 44.87391248345375, 44.930658638477325, 44.61529456079006, 47.588030844926834, 49.867684319615364, 50.005255937576294, 55.45435734093189, 58.835195526480675, 61.270572245121, 65.06048128008842, 65.1215136051178, 64.14619714021683, 50.88881112635136, 50.64479202032089, 37.433508932590485, 0.20349385013105348, 0.6469889672007412, 4.434838928282261, 0.6146512774284929, 0.06317497216514312, 6.384521909058094, 76.84083715081215, 72.00399309396744, 78.33995550870895, 68.61494734883308, 78.8081131875515, 99.11842614412308, 28.488771803677082, 33.84333238005638, 61.648036390542984, 62.81487017869949, 5.812562825158238, 0.07052339933579788, 0.06203994264069479, 0.07043633057037368, 0.046276878128992394, 0.03505224703985732, 0.3305832704063505, 0.19115126633550972, 0.18322800868190825, 0.22425755392760038, 0.22098641929915175, 0.6167140323668718, 0.6756515416782349, 21.343243829905987, 85.3777326643467, 64.5822161436081, 53.44318985939026, 34.50863108038902, 26.893490105867386, 39.428261294960976, 69.55292701721191, 77.6129937171936, 67.56738156080246, 83.08449491858482, 17.614709101617336, 0.5616833071690053, 1.2848038016818464, 8.689937051385641, 10.919038038700819, 1.0069338558241725, 15.144323911517859, 68.98690178990364, 62.11145952343941, 65.20361959934235, 65.66059067845345, 58.32951866090298, 54.45026881992817, 50.01711130142212, 44.91952143609524, 44.88705977797508, 47.988981530070305, 48.5006582736969, 48.694368079304695, 48.85139465332031, 48.30863557755947, 45.84385983645916, 43.63662287592888, 43.45275454223156, 44.42117057740688, 44.87731330096722, 46.21272124350071, 45.11118695139885, 48.44751812517643, 50.598043128848076, 49.581506475806236, 56.572743728756905, 55.10933205485344, 53.314353972673416, 49.91305768489838, 47.215567231178284, 46.998025104403496, 43.63232530653477, 44.12483587861061, 42.308863922953606, 41.87944136559963, 40.38709044456482, 42.23656140267849, 42.154596000909805, 42.46084436774254, 39.97519254684448, 42.0779313147068, 39.95424807071686, 41.04894272983074, 42.06724248826504, 44.39316228032112, 46.96103788912296, 60.34428454935551, 45.32232642173767, 39.195512384176254, 40.638716742396355, 38.454179763793945, 40.13914234936237, 39.454791471362114, 40.01827463507652, 43.90632100403309, 41.08639732003212, 41.731925681233406, 39.2245352268219, 41.93274490535259, 39.60231475532055, 42.09866680204868, 41.267457604408264, 43.21580305695534, 41.78310513496399, 42.50055603682995, 42.39309400320053, 44.624824449419975, 42.13341973721981, 43.345885276794434, 41.14152856171131, 42.72800423204899, 42.87286765873432, 42.10736073553562, 41.88805550336838, 42.84169413149357, 41.10989525914192, 38.08406822383404, 36.77341215312481, 36.71254701912403, 36.159262508153915, 38.65877978503704, 38.08140456676483, 39.19862441718578, 38.07508170604706, 46.65370658040047, 56.786763444542885, 42.615401074290276, 42.532101944088936, 41.67144052684307, 45.45922927558422, 43.70904698967934, 41.2100350856781, 42.99853831529617, 43.098560348153114, 42.29742273688316, 42.400119826197624, 41.80944912135601, 44.338961988687515, 50.31197547912598, 54.323412626981735, 51.527781039476395, 53.43117110431194, 57.670463025569916, 59.295734614133835, 55.35666458308697, 56.012440994381905, 53.92011746764183, 49.831833243370056, 44.36463341116905, 46.61612659692764, 47.176072150468826, 46.51468724012375, 45.53017906844616, 45.616886615753174, 46.698946952819824, 49.166690334677696, 47.009310498833656, 47.89858058094978, 51.61460638046265, 53.20928581058979, 54.409911185503006, 57.68104545772076, 62.192201390862465, 65.16525685787201, 67.21947982907295, 68.67331981658936, 66.8588487803936, 54.23700526356697, 56.5258314460516, 44.40357372164726, 0.42511186678893864, 1.6084954887628555, 8.45834992825985, 2.2540065133944154, 0.3669063822599128, 7.2849272936582565, 81.79298222064972, 77.98039600253105, 84.43975299596786, 73.81668582558632, 82.83763736486435, 94.9777503311634, 35.57848647236824, 48.03806729614735, 74.18374612927437, 77.39375308156013, 8.564301542937756, 0.4211371613200754, 0.1524516788776964, 0.190778455871623, 0.21074451418826357, 0.12610720266820863], [0.05740087399317417, 0.06187627310282551, 0.0611110854515573, 0.035857477269019, 0.06988602806814015, 0.2452723411261104, 0.12943393900059164, 18.258457258343697, 70.16093999147415, 51.21831424534321, 32.18572072684765, 12.856931202113628, 63.79113659262657, 41.894784942269325, 54.58760865032673, 71.85280680656433, 58.35576765239239, 70.05887746810913, 24.71040654927492, 0.17310904775513336, 0.18805551604600623, 0.8995244849938899, 4.914784049615264, 0.5753435741644353, 14.259818773716688, 58.927739560604095, 54.296829253435135, 63.252257108688354, 60.61985716223717, 56.89870923757553, 49.48682315647602, 47.6496559381485, 49.77311499416828, 49.26230080425739, 44.46100004017353, 41.69103987514973, 41.08550436794758, 40.34997023642063, 40.827680602669716, 41.590261682868004, 39.37852956354618, 39.743758365511894, 39.57266874611378, 43.30405332148075, 43.18503610789776, 48.613778203725815, 48.52184973657131, 50.72657123208046, 48.745365142822266, 50.61617575585842, 52.27118834853172, 49.098028019070625, 48.98866608738899, 47.95422099530697, 42.14442014694214, 39.43789377808571, 38.19545924663544, 39.22982074320316, 36.8937972933054, 36.74385353922844, 37.51591891050339, 38.42648684978485, 38.93471717834473, 36.33862808346748, 36.22206933796406, 37.12029553949833, 36.222392320632935, 39.052427262067795, 37.36660972237587, 41.15698613226414, 55.988354086875916, 48.548212721943855, 38.325792253017426, 37.95030780136585, 38.770106211304665, 38.73688459396362, 38.551731929183006, 36.813093423843384, 38.47684934735298, 39.28826920688152, 37.93053366243839, 35.92535085976124, 35.16468487679958, 36.580975279212, 36.48018188774586, 36.36930763721466, 37.06155449151993, 37.601763904094696, 38.37741628289223, 39.43271845579147, 38.3052771538496, 38.079736456274986, 37.02214300632477, 36.602531522512436, 37.84796789288521, 37.19035618007183, 38.532238975167274, 37.85551428794861, 38.51171247661114, 36.44887536764145, 36.631102189421654, 37.52002649009228, 36.95027746260166, 37.96687491238117, 36.52479529380798, 37.19825595617294, 36.94947570562363, 35.37772424519062, 48.56893301010132, 47.29538194835186, 37.78394132852554, 40.28199188411236, 38.04925449192524, 38.648493736982346, 35.74932910501957, 36.885536536574364, 37.63695381581783, 37.923443242907524, 38.547597751021385, 37.62916423380375, 38.04088734090328, 39.84614007174969, 41.16202466189861, 44.74426344037056, 48.44386272132397, 50.13097979128361, 52.22802646458149, 53.80434907972813, 50.93864165246487, 53.920953422784805, 49.587969928979874, 48.484113961458206, 44.464039877057076, 44.480633586645126, 41.95120811462402, 43.86545039713383, 43.08784872293472, 42.43984669446945, 43.162317126989365, 44.382918030023575, 43.81198726594448, 44.675031155347824, 42.80228264629841, 43.51620353758335, 48.54589484632015, 57.17272013425827, 58.09580460190773, 60.5993876606226, 63.32659251987934, 58.40267613530159, 57.264728397130966, 46.369318440556526, 55.776298865675926, 26.536959037184715, 0.035811486377497204, 0.43949644023086876, 4.810167588293552, 0.8970480866264552, 0.1822174113476649, 6.611763015389442, 67.95377522706985, 68.63580822944641, 69.25302430987358, 70.04800245165825, 40.63210129737854, 12.747027799487114, 14.7393967397511, 44.32601988315582, 55.077470764517784, 56.40742599964142, 3.6842927522957325, 0.16006442194338888, 0.0530825764144538, 0.021453099616337568, 0.04872254045039881, 0.06534419560921378, 0.08127176828566007, 0.05397381042712368, 0.02499011236068327, 0.013054148494120454, 0.04343535052612424, 0.2568775863619521, 0.17400152486516163, 21.892730444669724, 78.81801545619965, 56.51965297758579, 41.04189790785313, 17.085534296929836, 29.387374185025692, 39.74476911127567, 59.245999082922935, 77.87758111953735, 62.407019063830376, 73.44919234514236, 26.41307808458805, 0.14153042662655935, 0.17210686637554318, 1.8973586009815335, 2.565235700458288, 0.6608819717075676, 16.127814687788486, 59.6065541356802, 58.51774916052818, 64.8256766796112, 63.213085010647774, 57.34648481011391, 51.381564885377884, 50.07820822298527, 51.91211901605129, 48.84574815630913, 45.727472081780434, 41.59277714788914, 41.608819887042046, 43.37455473840237, 41.455897092819214, 42.57818967103958, 40.82133874297142, 40.44972628355026, 42.19809226691723, 44.58589933812618, 45.45756496489048, 49.277591183781624, 49.451025277376175, 51.811405420303345, 51.94882124662399, 51.98005937039852, 53.32185097038746, 51.17607571184635, 50.66493093967438, 49.00576137006283, 45.738449692726135, 41.45916111767292, 39.578756019473076, 40.093977972865105, 38.57119828462601, 38.59984494745731, 39.88100700080395, 39.4177358597517, 39.32907521724701, 38.10453772544861, 38.25401410460472, 36.60925716161728, 39.495540484786034, 42.380208894610405, 39.034583419561386, 41.15401469171047, 56.92745849490166, 49.54553760588169, 38.91999676823616, 38.55479836463928, 38.33081938326359, 39.60931017994881, 39.103416725993156, 36.88447259366512, 38.42945069074631, 40.152297243475914, 39.234654083848, 38.94371509552002, 37.968653216958046, 39.03594754636288, 38.20165291428566, 38.94486263394356, 38.49224612116814, 39.61720995604992, 40.21690517663956, 40.31733758747578, 41.2652613222599, 38.82757432758808, 38.66012491285801, 38.68106558918953, 38.967953994870186, 37.965377792716026, 40.747254118323326, 39.66167517006397, 39.48532663285732, 37.52329431474209, 36.15004800260067, 37.24611818790436, 37.7745596319437, 38.29865790903568, 37.87567600607872, 36.85147136449814, 38.23923669755459, 35.293855145573616, 49.041380658745766, 50.1046472042799, 39.46423776447773, 42.163172140717506, 40.10415382683277, 40.1442264765501, 38.55828657746315, 39.73439946770668, 40.25806836783886, 39.18393820524216, 40.908407270908356, 38.678154945373535, 40.719906985759735, 43.66419419646263, 42.48008273541927, 45.927223563194275, 50.62588423490524, 51.232502683997154, 53.96771751344204, 54.72557544708252, 51.26154072582722, 54.992868304252625, 51.144632399082184, 49.766704738140106, 46.10038787126541, 45.82138404250145, 46.34429678320885, 45.89447692036629, 44.93283972144127, 45.49495875835419, 45.65448559820652, 46.71852350234985, 46.21493272483349, 44.96801823377609, 45.2035865932703, 46.85584053397179, 51.131606698036194, 60.27074709534645, 61.98996104300022, 62.96798296272755, 66.37544631958008, 59.71894830465317, 58.93799901008606, 48.459263294935226, 52.79929541051388, 29.717460572719574, 0.038554616330657154, 2.623736411333084, 11.51414880529046, 0.8298865717370063, 0.3027247387217358, 7.589879455044866, 73.32455903291702, 73.44760403037071, 75.39305403828621, 75.37163838744164, 47.64038443565369, 23.912276476621628, 18.85573200881481, 51.59919060766697, 64.29270207881927, 66.30860790610313, 5.3022416587919, 0.19847966294037178, 0.11719564921804704, 0.013600225393020082, 0.07514526500017382, 0.0840412185061723, 0.2421572059392929, 0.24560118676163256, 0.11100449002697133, 0.1217425060167443, 0.20851698762271553, 0.4710407444508746, 0.32597512705251575, 27.529862858355045, 89.70598921179771, 62.774311155080795, 45.69187939167023, 22.48906284570694, 76.22593134641647, 56.504750177264214, 65.1306939125061, 84.80905517935753, 66.67620778083801, 82.76507645845413, 29.695550948381424, 0.23894391430076212, 0.7100201037246734, 4.424697272479534, 11.701850183308125, 1.1247492651455104, 18.895890153944492, 63.00220772624016, 62.84222491085529, 68.46857160329819, 64.95201230049133, 59.34928894042969, 54.074465185403824, 52.89377734065056, 55.387815311551094, 53.33922743797302, 49.366586208343506, 45.75363747775555, 44.207918420434, 46.26250237226486, 43.396308571100235, 44.7540745139122, 42.59973831474781, 42.04681858420372, 43.23261335492134, 47.693361192941666, 47.7374654263258, 51.89421057701111, 52.90891192853451, 53.05015794932842, 52.99607165157795, 54.077125042676926, 57.644590213894844, 52.822101786732674, 53.422682359814644, 51.60875089466572, 48.57571944594383, 44.33675430715084, 42.18397602438927, 43.369246423244476, 42.01797813177109, 40.69374538958073, 42.32501305639744, 41.96863777935505, 42.07605041563511, 40.157863944768906, 39.80883367359638, 39.91394743323326, 40.62400013208389, 44.13397438824177, 40.17267934978008, 44.61561754345894, 59.39713217318058, 53.00424501299858, 38.30085799098015, 37.369178384542465, 40.049216374754906, 40.380235612392426, 40.08270397782326, 36.75759740173817, 40.18596723675728, 42.31462061405182, 41.81480683386326, 41.35688200592995, 39.08409096300602, 41.41089990735054, 41.6655508428812, 39.988108053803444, 40.973338186740875, 41.775254756212234, 43.67440804839134, 44.98795196413994, 42.65999548137188, 41.79191306233406, 41.56537301838398, 40.869227573275566, 42.666979506611824, 39.89862285554409, 42.833965346217155, 42.08726741373539, 41.544059962034225, 40.076578706502914, 37.39951215684414, 37.67502777278423, 37.24185861647129, 38.00033591687679, 38.09370070695877, 37.90420487523079, 38.94372269511223, 36.25610791146755, 51.13117732107639, 51.29918150603771, 42.16753430664539, 44.064153134822845, 42.47371807694435, 42.05755680799484, 39.36238802969456, 40.786946788430214, 41.38619743287563, 41.79912127554417, 42.41232477128506, 41.32283203303814, 41.28171443939209, 46.63303568959236, 45.00639237463474, 48.47048029303551, 53.104346841573715, 53.696704655885696, 56.17088869214058, 58.837726190686226, 55.39372019469738, 58.03906984627247, 53.39753530919552, 53.44516955316067, 47.965107411146164, 50.68508505821228, 47.85812795162201, 48.24436582624912, 47.36643813550472, 46.36235721409321, 47.67860658466816, 49.562169313430786, 48.11024822294712, 49.10413809120655, 46.50003522634506, 47.00496733188629, 52.6395595818758, 61.039328053593636, 63.229902908205986, 64.91427272558212, 68.69675695896149, 62.926348596811295, 65.40907457470894, 54.41619224846363, 55.53012527525425, 36.3551913946867, 0.14803386671701446, 3.1694750022143126, 16.10939707607031, 3.981708730570972, 0.3651833825279027, 8.368278611451387, 79.52765017747879, 81.12549483776093, 82.76270538568497, 83.10588777065277, 50.28671443462372, 25.21449889987707, 25.59623971581459, 61.86212830245495, 75.07454752922058, 80.78705459833145, 7.715416168794036, 0.38811390521004796, 0.1794990579946898, 0.14566781086614355, 0.08803811419056728, 0.25086037174332887], [0.018930276200990193, 0.07788114045979455, 0.013165299951651832, 0.05266750435112044, 0.08267267592600547, 0.3077944682445377, 0.1442910823971033, 19.312672689557076, 68.96910354495049, 48.29597845673561, 28.368825539946556, 45.211873948574066, 112.1373863518238, 63.912076503038406, 55.880785658955574, 64.55043464899063, 61.531964018940926, 66.30757436156273, 30.78640591353178, 0.3408955014310777, 0.16061344795161858, 1.2657106574624777, 1.8941419548355043, 0.29678758699446917, 14.723534490913153, 48.016438856720924, 48.57508108019829, 61.57376937568188, 59.12984311580658, 54.47283200919628, 53.99449847638607, 56.4508842676878, 58.939290940761566, 56.715897247195244, 52.33715660870075, 44.10074137151241, 41.470150128006935, 40.26559956371784, 39.58463430404663, 40.54613471031189, 43.32961454987526, 45.513015389442444, 48.4556382894516, 47.973341569304466, 49.18313205242157, 53.80213759839535, 51.15024849772453, 47.68326133489609, 50.81439211964607, 52.17208966612816, 51.34911082684994, 50.46254999935627, 46.93353496491909, 43.71490627527237, 38.30590412020683, 39.95380349457264, 39.75834958255291, 37.53207944333553, 38.15350569784641, 37.923108860850334, 37.52163000404835, 37.57256247103214, 37.02250778675079, 37.68304534256458, 35.54868087172508, 39.290997460484505, 37.29327745735645, 39.49146330356598, 38.40393126010895, 40.37270061671734, 51.4702445268631, 52.080092802643776, 41.42922632396221, 37.40508645772934, 38.46422642469406, 36.34063057601452, 35.861746072769165, 37.32089817523956, 37.140829637646675, 38.0379842966795, 38.594726622104645, 37.8989839553833, 36.77784651517868, 35.68387381732464, 39.66467700898647, 37.439246624708176, 36.81820034980774, 37.69674740731716, 39.842682257294655, 38.40936116874218, 39.33384396135807, 36.42524443566799, 37.97419331967831, 35.619360879063606, 37.790974751114845, 37.4019668251276, 38.15648093819618, 38.56302112340927, 36.85208313167095, 38.037262335419655, 39.474292024970055, 37.733160853385925, 36.9909580796957, 35.63207879662514, 36.99727714061737, 37.997619062662125, 37.44382917881012, 40.010720640420914, 51.295453906059265, 44.25226204097271, 35.1894823461771, 39.151959121227264, 37.35158912837505, 39.02832895517349, 37.53309778869152, 38.8155821710825, 37.57634326815605, 39.28105339407921, 38.72167780995369, 38.83883312344551, 40.8416448533535, 39.38022807240486, 38.92705298960209, 41.466642916202545, 40.63715122640133, 43.512510135769844, 48.34466904401779, 49.55409474670887, 50.87481647729874, 54.04298387467861, 51.971813812851906, 51.30549676716328, 50.11632777750492, 48.1787471473217, 48.38422492146492, 46.41366586089134, 46.625329703092575, 47.65365332365036, 48.515146896243095, 47.04066641628742, 48.30243431031704, 46.06167174875736, 45.451428294181824, 44.94383633136749, 51.378623843193054, 59.40771460533142, 64.6091490983963, 60.66005900502205, 58.38581643998623, 55.16879506409168, 56.894176080822945, 47.746809124946594, 55.860977321863174, 25.411704517900944, 0.022532978291565087, 0.357121640117839, 4.603494303300977, 0.29015124309808016, 0.08073335498920642, 7.856059921905398, 67.86567315459251, 66.20516985654831, 64.18941602110863, 63.433940559625626, 58.51366437971592, 43.656495809555054, 19.625014029443264, 30.711943209171295, 58.818552419543266, 52.74513691663742, 2.453444986604154, 0.2278476784704253, 0.05554484800086357, 0.05331513581040781, 0.09212186341756023, 0.07804281733115204, 0.002958064965241647, 0.03221949533326551, 0.09781541259144433, 0.06026715964253526, 0.0163349746435415, 0.34418217663187534, 0.17740312905516475, 24.07909892499447, 77.00752660632133, 53.878479301929474, 34.69920225441456, 34.65111963450909, 96.26383692026138, 63.10487821698189, 60.147671699523926, 70.14578640460968, 65.69234937429428, 73.13482001423836, 33.25476676225662, 0.34603778331074864, 0.4408605967182666, 0.6264995166566223, 1.9620305369608104, 0.3533862327458337, 17.412119172513485, 49.32863764464855, 53.1913735717535, 64.6678863465786, 60.81079311668873, 56.969081461429596, 54.09407213330269, 59.02013160288334, 60.48185996711254, 60.13541355729103, 52.965969666838646, 45.71649827063084, 43.58692154288292, 42.817911207675934, 42.41681233048439, 42.298889458179474, 46.43191248178482, 46.32502041757107, 49.81167532503605, 49.92050148546696, 50.97072333097458, 57.05416649580002, 54.187889099121094, 50.03165692090988, 54.74238574504852, 55.08215211331844, 52.118645533919334, 54.57437016069889, 49.398717284202576, 44.07366022467613, 40.8185762912035, 42.06362888216972, 40.46435549855232, 40.95937393605709, 40.57820498943329, 40.46918123960495, 40.36058306694031, 38.68246391415596, 40.25058276951313, 38.983483761548996, 38.288789838552475, 39.409292712807655, 38.28250877559185, 41.228296905756, 39.39538165926933, 42.20390595495701, 56.27203546464443, 52.753200083971024, 42.627636417746544, 36.021056324243546, 36.199711337685585, 36.84704080224037, 36.0758987814188, 37.67636530101299, 38.66401210427284, 39.94038261473179, 40.90164743363857, 39.083350002765656, 38.901066184043884, 38.75977076590061, 42.26204663515091, 40.17839804291725, 39.6243991702795, 38.87539856135845, 41.425396129488945, 40.10440841317177, 39.865868613123894, 37.814058512449265, 40.849863812327385, 37.998280227184296, 39.54884022474289, 39.341565147042274, 40.979018881917, 40.90553842484951, 37.17441603541374, 37.6641109585762, 40.12736678123474, 37.275167629122734, 37.0542398840189, 36.20387211441994, 38.173257037997246, 36.8035901337862, 37.26787582039833, 39.90251764655113, 52.96132251620293, 44.13607947528362, 36.802495792508125, 40.47460734844208, 39.87879931926727, 41.9887501001358, 38.75751368701458, 40.22398419678211, 40.74490584433079, 40.66455155611038, 39.19937677681446, 39.93384696543217, 40.82421898841858, 42.278412356972694, 41.36568993330002, 42.37819120287895, 43.83231237530708, 46.53463616967201, 51.24199837446213, 51.672693863511086, 53.273278176784515, 55.63488185405731, 53.861938789486885, 53.27955164015293, 51.57543048262596, 51.21661193668842, 50.44005520641804, 48.37068624794483, 49.80218343436718, 50.13839699327946, 50.02414472401142, 49.984349459409714, 50.10840520262718, 47.796871438622475, 47.72138848900795, 48.17060798406601, 53.74899365007877, 60.85482135415077, 66.93204805254936, 61.242541149258614, 59.50053222477436, 58.339542523026466, 58.1447421759367, 50.64999774098396, 60.58980457484722, 27.40132335573435, 0.003638180924099288, 0.7828818471170962, 10.19754795357585, 1.9780660327523947, 0.2435629820683971, 9.042301643639803, 73.07061865925789, 70.32420203089714, 70.24813011288643, 73.16566675901413, 62.46104836463928, 40.59588544070721, 23.10493379831314, 39.988393038511276, 65.17713502049446, 64.26643028855324, 3.410381362773478, 0.12982560001546517, 0.04873881574894767, 0.04664756233978551, 0.07147456548409536, 0.04925316861772444, 0.14700489380629733, 0.1993289470556192, 0.20284163590986282, 0.2798932185396552, 0.18215708958450705, 0.5410898965783417, 0.29822085227351636, 29.002069160342216, 85.33870875835419, 63.796197921037674, 40.50569348037243, 58.11585612595081, 118.02994295954704, 70.7650999724865, 67.13826298713684, 74.12329897284508, 71.82471111416817, 77.93701753020287, 36.82593293488026, 0.4002473072614521, 0.8743052976205945, 5.741734625771642, 10.313370488584042, 0.22916672722203657, 20.47182708978653, 55.46183533966541, 55.853465124964714, 67.3546689748764, 63.61205980181694, 59.40793119370937, 57.22294203937054, 60.831217020750046, 63.02576646208763, 61.1137280613184, 55.97288891673088, 48.02617013454437, 45.07674179971218, 44.802974089980125, 44.18327674269676, 43.961980417370796, 47.988183572888374, 48.15320111811161, 53.76720607280731, 53.54074962437153, 52.509750947356224, 59.291858822107315, 56.31709724664688, 51.885942220687866, 57.56067171692848, 56.23336113989353, 55.3301952034235, 56.70665234327316, 52.256388142704964, 47.84511364996433, 42.28172957897186, 46.45365871489048, 44.50586423277855, 43.36490325629711, 43.99557061493397, 43.11508946120739, 42.05075517296791, 41.33706606924534, 42.51284457743168, 40.48432342708111, 40.51189474761486, 42.11470574140549, 41.683208495378494, 43.171182051301, 40.91399297118187, 44.95487093925476, 56.82470440864563, 56.468374729156494, 41.36858157813549, 36.69472597539425, 38.94459664821625, 35.75351268053055, 35.86544327437878, 38.277804628014565, 39.25786703824997, 41.190257146954536, 43.12721461057663, 41.5075059235096, 41.01296246051788, 40.17351530492306, 45.39633885025978, 42.7213241904974, 42.611301094293594, 41.41886427998543, 44.506802782416344, 42.18559853732586, 43.132895305752754, 40.22590309381485, 43.6203483492136, 40.11733531951904, 41.79774194955826, 40.66524691879749, 43.15717600286007, 43.84082771837711, 38.40040884912014, 38.31122763454914, 41.21909759938717, 38.12921740114689, 36.80021211504936, 35.81878937780857, 37.56818130612373, 37.52240516245365, 37.84349173307419, 40.62974162399769, 54.26143795251846, 47.09549367427826, 38.51681940257549, 43.09552051126957, 41.81343510746956, 43.87244962155819, 41.64090536534786, 42.624148204922676, 42.88239374756813, 43.4592217952013, 42.95626558363438, 42.315483167767525, 44.20811600983143, 44.6514306217432, 44.30628754198551, 46.60487160086632, 45.87667107582092, 47.43042670190334, 54.61640350520611, 55.48942945897579, 56.66107378900051, 58.2309215515852, 56.12858176231384, 56.752291694283485, 54.83790881931782, 53.672864735126495, 53.19945573806763, 49.85697649419308, 53.768950179219246, 52.96988345682621, 52.668358236551285, 51.969891116023064, 53.25299106538296, 51.56497344374657, 49.18612249195576, 49.61326517164707, 55.904401391744614, 63.90877068042755, 70.22858396172523, 64.57169830799103, 61.60833612084389, 63.176572769880295, 59.61464010179043, 55.7681293040514, 62.428567707538605, 33.39599758386612, 0.21409179316833615, 2.512039029970765, 12.075900211930275, 2.3056861152872443, 0.21678921795682982, 10.020207669585943, 81.75080448389053, 75.01501992344856, 73.81706580519676, 78.33396703004837, 73.6141262948513, 59.411723390221596, 33.26867401599884, 47.97315537929535, 75.67011997103691, 76.15340083837509, 5.6698790565133095, 0.5122386978473514, 0.18840034754248336, 0.12297851586481556, 0.19028860871912912, 0.20296348171541467], [0.012750626792694675, 0.04771047366375569, 0.08210692190914415, 0.03926709665392991, 0.08932882032240741, 0.1507182593923062, 0.23637005710043013, 9.547676425427198, 66.30002036690712, 50.97578465938568, 38.50651815533638, 37.83942975103855, 98.02329450845718, 63.58696974813938, 47.713598906993866, 68.68880018591881, 58.78504581749439, 67.71273136138916, 32.326461374759674, 0.20696195075288415, 0.05875141578144394, 0.8911898697260767, 0.5536073155235499, 0.42231337632983923, 14.13121372461319, 42.94816441833973, 46.35714389383793, 60.81461951136589, 57.716793939471245, 57.599167451262474, 55.27252949774265, 56.73024907708168, 55.741944909095764, 58.92927087843418, 52.97062061727047, 45.85462845861912, 40.348670706152916, 41.19650401175022, 42.159843519330025, 45.688945949077606, 49.064806401729584, 48.656035736203194, 50.322333723306656, 53.67411866784096, 51.50946602225304, 50.31223766505718, 51.078793331980705, 48.194854483008385, 51.22436732053757, 51.17809720337391, 50.707606449723244, 47.60845474898815, 40.7879613339901, 39.25961874425411, 40.30208520591259, 40.55399648845196, 42.21946991980076, 39.66139018535614, 37.787604331970215, 37.893037274479866, 37.818534672260284, 35.81860698759556, 34.904163256287575, 36.07447765767574, 36.251175776124, 38.835097923874855, 37.26206973195076, 37.8235200047493, 37.92652107775211, 43.143150955438614, 52.058198377490044, 53.374542742967606, 43.205467611551285, 37.48777002096176, 38.23550909757614, 37.13574171066284, 38.805710300803185, 37.769965678453445, 36.056831404566765, 37.590451911091805, 38.14021781086922, 37.21207581460476, 36.73253774642944, 35.82902982831001, 38.635065257549286, 37.57388100028038, 37.11929999291897, 37.43562161922455, 39.163673892617226, 38.31132262945175, 37.79944069683552, 37.89304107427597, 37.63625465333462, 35.96110314130783, 36.894317865371704, 38.214880004525185, 36.544459238648415, 36.635167971253395, 38.00138086080551, 37.38756939768791, 35.9298650175333, 38.53886961936951, 37.71331071853638, 36.66533835232258, 35.31061604619026, 35.73087349534035, 37.98664905130863, 44.27716210484505, 52.1635477244854, 40.98775841295719, 37.152517810463905, 37.613186091184616, 37.475580275058746, 37.6629102230072, 36.687536761164665, 38.362502083182335, 39.41446803510189, 38.63837867975235, 36.47686466574669, 37.36505180597305, 40.30259817838669, 39.27537649869919, 38.87279570102692, 39.63125020265579, 40.67324548959732, 39.29930001497269, 41.39355003833771, 46.32459484040737, 51.30002126097679, 51.31693035364151, 53.32816243171692, 50.81318758428097, 53.36280897259712, 49.68286603689194, 51.27660311758518, 49.75001223385334, 53.88221450150013, 52.147835567593575, 55.227452516555786, 52.50774085521698, 53.619021624326706, 49.171937853097916, 46.93459890782833, 45.308232977986336, 54.26255129277706, 57.31395095586777, 60.522456988692284, 58.64646725356579, 64.50035333633423, 63.66585731506348, 75.14766320586205, 47.36630894243717, 56.16205416619778, 26.642338782548904, 0.10649946809280664, 2.350490461103618, 12.337388880550861, 0.5929547385312617, 0.723217804916203, 8.486450370401144, 66.45783349871635, 63.1927864998579, 70.69217428565025, 56.678974628448486, 51.899986267089844, 23.801947496831417, 16.19137767702341, 37.289147078990936, 57.65418849885464, 47.86215953528881, 2.775028618052602, 0.11332014662912115, 0.049704249686328694, 0.12924966373248026, 0.10624513408401981, 0.07503275541239418, 0.044938507562619634, 0.04121016543649603, 0.020523400089587085, 0.02615510609757621, 0.08302367466967553, 0.2039823614177294, 0.2360390147077851, 14.6053665317595, 74.20627892017365, 58.684837594628334, 39.72346365451813, 41.665125265717506, 106.6369991004467, 71.11390605568886, 55.04998303949833, 71.0342775285244, 64.81673955917358, 70.24509787559509, 36.623719185590744, 0.17568795155966654, 0.02491502556949854, 1.352454184088856, 1.8868266348727047, 0.4771790775703266, 17.18517255038023, 45.09120762348175, 48.84291350841522, 62.72617153823376, 59.28563855588436, 60.09048096835613, 58.23776498436928, 57.908508852124214, 56.84720300137997, 60.22095836699009, 54.84565660357475, 47.69456572830677, 40.57361863553524, 44.01895076036453, 45.12402266263962, 47.38829456269741, 51.766548827290535, 51.15441307425499, 51.71683989465237, 54.3364155292511, 53.897337689995766, 52.36803375184536, 52.41110064089298, 50.53609125316143, 53.33190903067589, 53.80456566810608, 54.544488564133644, 50.30725233256817, 43.32359567284584, 41.317690908908844, 41.986196637153625, 42.650970965623856, 43.02993603050709, 42.117764577269554, 40.694516748189926, 39.957546293735504, 39.670407101511955, 38.16702537238598, 39.3108019977808, 38.36519993841648, 38.80561910569668, 40.53899489343166, 38.25636997818947, 39.22024525702, 38.82619500160217, 43.68941344320774, 51.87032885849476, 55.910541862249374, 44.63611364364624, 36.20254598557949, 37.865416556596756, 36.80320255458355, 37.53339037299156, 38.10391455888748, 36.452241986989975, 38.253425136208534, 39.6869970113039, 39.45700295269489, 39.14842151105404, 37.63544149696827, 39.689151495695114, 38.62631052732468, 40.108565390110016, 39.6066465228796, 42.008311450481415, 40.236531123518944, 40.026877373456955, 38.94977577030659, 38.39292325079441, 38.86307202279568, 39.442502930760384, 40.46621359884739, 39.17417652904987, 38.92685540020466, 37.84587040543556, 39.47242632508278, 38.015261515975, 37.283888161182404, 37.6595626026392, 36.803362146019936, 37.69897788763046, 36.97376400232315, 38.54120269417763, 44.428245797753334, 52.88304291665554, 42.04359255731106, 40.926623493433, 40.33040128648281, 40.75917787849903, 39.500541016459465, 39.22783724963665, 39.962349236011505, 40.41737861931324, 40.275258645415306, 39.00272972881794, 39.306021854281425, 41.90297730267048, 39.731325432658195, 39.923701509833336, 41.75514243543148, 42.75865338742733, 40.61267673969269, 44.18331854045391, 48.99888373911381, 53.831840604543686, 53.869587779045105, 55.25495924055576, 52.17252664268017, 57.06567607820034, 50.88183090090752, 53.72088275849819, 52.28019006550312, 55.692767947912216, 53.69018420577049, 56.95804685354233, 54.30222496390343, 57.706177309155464, 52.42515608668327, 49.46981906890869, 46.76478981971741, 57.315945848822594, 58.37286293506622, 63.81895110011101, 60.623911544680595, 66.41681849956512, 65.95268860459328, 74.63133931159973, 50.55565260350704, 60.34113071858883, 27.67059400677681, 0.1255127869080752, 0.6627740326803178, 8.905240148305893, 1.5994361811317503, 0.8764652442187071, 9.45145608857274, 72.68112435936928, 71.93569555878639, 75.25056168437004, 60.76293848454952, 59.702396392822266, 29.259803630411625, 14.534941110759974, 42.63229876756668, 66.86405450105667, 57.641246393322945, 3.260046229697764, 0.0724064654787071, 0.008060169056989253, 0.046107668458716944, 0.12277441783226095, 0.024334141016879585, 0.13092209352180362, 0.13493176898919046, 0.11024182196706533, 0.21193742752075195, 0.23503438424086198, 0.35978814703412354, 0.3933917626272887, 19.13867622613907, 86.49823173880577, 66.17513626813889, 53.812279254198074, 50.95243111252785, 100.90718016028404, 70.91128572821617, 60.82884594798088, 81.3076114654541, 69.15242850780487, 75.19300997257233, 41.561698615550995, 0.2997991332085803, 0.3190607449505478, 3.11938822735101, 5.6249322183430195, 0.5314998643007129, 20.855503901839256, 50.59894748032093, 51.85948424041271, 65.74318304657936, 60.2190812677145, 61.158976033329964, 59.071254059672356, 61.35712780058384, 59.180467799305916, 63.33177164196968, 56.37947849929333, 51.42633028328419, 42.63012148439884, 46.404363960027695, 48.27768623828888, 50.158756300807, 53.86095084249973, 53.71500067412853, 54.775128588080406, 57.045708149671555, 55.770595371723175, 52.92516365647316, 55.58557949960232, 52.54692815244198, 57.148302644491196, 55.87991550564766, 56.04419209063053, 51.949585005640984, 46.354491636157036, 43.10075283050537, 44.60753917694092, 45.822212398052216, 47.997960448265076, 45.89367896318436, 42.85074904561043, 43.058875277638435, 42.63556659221649, 40.78068092465401, 41.48809656500816, 42.24268287420273, 42.1882089972496, 43.4231199324131, 40.794629976153374, 42.801712676882744, 41.491261795163155, 46.473121270537376, 55.217443853616714, 58.93123917281628, 46.495749056339264, 37.29042001068592, 38.114747777581215, 37.82833814620972, 37.821243926882744, 38.685511350631714, 36.61092907190323, 37.93953537940979, 41.60419553518295, 39.52892169356346, 41.143314465880394, 40.978258922696114, 43.022978603839874, 40.698658525943756, 43.168062418699265, 41.07410877943039, 43.44357043504715, 42.75034323334694, 41.651404201984406, 42.5252965092659, 41.41560785472393, 40.35516455769539, 41.1226549744606, 43.724257573485374, 40.749165415763855, 40.780019760131836, 39.97029460966587, 40.09365878999233, 37.599404230713844, 39.28674928843975, 38.190637305378914, 37.99350008368492, 37.43548482656479, 36.462832018733025, 38.07736538350582, 46.22896157205105, 55.86618684232235, 44.282785803079605, 41.49595834314823, 42.09797903895378, 43.8981856405735, 40.81191144883633, 41.64894573390484, 42.88192257285118, 43.37842293083668, 42.3958944529295, 41.31969340145588, 42.25899159908295, 45.38493186235428, 41.550132036209106, 43.40377517044544, 44.29435238242149, 45.29280200600624, 43.145320639014244, 45.38987159729004, 52.24126495420933, 56.72639608383179, 56.124056205153465, 57.55966477096081, 55.72976276278496, 59.28534597158432, 54.3643706291914, 56.725742518901825, 55.02640150487423, 57.70932734012604, 56.8926827609539, 58.44239920377731, 55.722961127758026, 60.339728593826294, 55.090386271476746, 52.063738480210304, 49.72251310944557, 59.560964182019234, 63.46320278942585, 67.74628356099129, 63.60998131334782, 67.36073344945908, 66.59857034683228, 78.46595674753189, 53.287348821759224, 61.453585624694824, 30.291037894785404, 0.29294246050994843, 6.601028116419911, 19.450261406600475, 3.565652430988848, 1.570432218722999, 11.205187384039164, 77.76762261986732, 76.93359777331352, 82.39597946405411, 70.30574262142181, 66.67667895555496, 33.911105543375015, 28.58563430607319, 58.36969010531902, 73.89716550707817, 71.27680331468582, 4.954407373443246, 0.2080289216246456, 0.17732270993292332, 0.22516178665682673, 0.21281924739014357, 0.14760083839064464], [0.037969284458085895, 0.02978259220981272, 0.03791295544942841, 0.09539248596411198, 0.10788071624119766, 0.10214356589131057, 0.07752683173748665, 8.243498057126999, 64.45952072739601, 54.26708064973354, 47.723466977477074, 31.544558331370354, 50.29711827635765, 35.857912078499794, 54.91169326007366, 64.63858991861343, 60.4609876871109, 64.14269372820854, 39.643728733062744, 0.25273191975429654, 0.1477307587629184, 0.47262784210033715, 0.437814139877446, 0.3028422355419025, 10.166906397789717, 50.51913656294346, 48.82778272032738, 59.592582285404205, 56.59253686666489, 57.10173614323139, 60.58447726070881, 61.479397639632225, 56.95129841566086, 57.6506432890892, 51.66328936815262, 44.569119438529015, 42.75649510324001, 42.802803218364716, 45.93929171562195, 49.375880509614944, 52.08031699061394, 53.42389069497585, 52.97117918729782, 51.75936721265316, 51.54806815087795, 50.54007723927498, 50.71793049573898, 51.14319987595081, 47.54302226006985, 47.802772521972656, 42.97895036637783, 41.51168949902058, 39.06673729419708, 38.09539541602135, 39.3830057233572, 40.29956974089146, 41.056971698999405, 40.83167798817158, 37.05266676843166, 38.04198548197746, 35.70858769118786, 38.430393040180206, 36.0069552809, 37.387375608086586, 35.60779809951782, 37.24440447986126, 37.53064692020416, 37.83558815717697, 39.4498897343874, 45.856212973594666, 49.05982866883278, 50.925718545913696, 48.38709756731987, 38.42253126204014, 38.51127929985523, 38.14057119190693, 37.99483001232147, 39.56426739692688, 34.98186528682709, 36.48338511586189, 37.07770362496376, 40.223034247756004, 37.78157785534859, 36.218543127179146, 35.837624967098236, 36.10927239060402, 37.72796273231506, 37.67365604639053, 38.52930173277855, 38.44665616750717, 37.96883560717106, 37.81603440642357, 38.68097059428692, 37.430267706513405, 38.60970541834831, 37.57954269647598, 36.809802800416946, 36.19058422744274, 35.768559873104095, 37.79717601835728, 37.32940211892128, 38.601733446121216, 35.94539098441601, 36.544390842318535, 38.61979387700558, 35.47638215124607, 39.224736616015434, 48.25076088309288, 49.239638820290565, 42.19555400311947, 39.949684515595436, 36.83257877826691, 36.7606258392334, 37.99707189202309, 38.00914764404297, 36.80545583367348, 37.1819282323122, 38.26515890657902, 38.89160469174385, 37.329310923814774, 38.43267671763897, 38.97729769349098, 37.239985316991806, 38.5944302380085, 39.44232054054737, 38.95796053111553, 40.62867768108845, 38.08080419898033, 46.697772815823555, 49.88783843815327, 54.90016467869282, 52.8670609742403, 52.503602877259254, 53.795746341347694, 56.501125171780586, 52.463496029376984, 55.29412753880024, 52.3111280053854, 57.08044968545437, 55.73424652218819, 56.87872231006622, 52.95533023774624, 52.2930333763361, 46.119907423853874, 53.848073333501816, 52.83570505678654, 62.444002479314804, 58.41875687241554, 66.10005229711533, 59.98931519687176, 68.0015766620636, 59.38252575695515, 75.78917518258095, 25.62793381512165, 0.28674383531324565, 0.27305183408316225, 9.675235580652952, 3.563869851641357, 0.5602207418996841, 8.885368164628744, 69.62533593177795, 60.86246654391289, 69.8794586956501, 67.73375943303108, 57.555477395653725, 32.106783762574196, 23.259576000273228, 42.207272574305534, 59.319984912872314, 36.17308236658573, 2.017261404544115, 0.07513592136092484, 0.07506184017984197, 0.04622660875611473, 0.057044624554691836, 0.015478231016459176, 0.019860007269016933, 0.05000121636840049, 0.03334333698148839, 0.05532508694159333, 0.017112149835156742, 0.25157324911560863, 0.11158976994920522, 10.49877678975463, 77.33903601765633, 58.19227762520313, 53.31032618880272, 32.781452760100365, 67.86288410425186, 47.65672355890274, 58.19479689002037, 70.54522097110748, 64.45249870419502, 69.59401801228523, 43.71122807264328, 0.25299553060904145, 0.0700318007147871, 0.6393485271837562, 1.3397431536577642, 0.44459621189162135, 12.27776912972331, 51.99064560234547, 51.162856221199036, 62.805378288030624, 60.12702360749245, 61.29339762032032, 60.47054037451744, 60.60897834599018, 60.50441935658455, 60.519208163022995, 53.99670995771885, 47.01915197074413, 45.10599263012409, 44.31125767529011, 48.343616500496864, 52.83429533243179, 52.99601845443249, 57.44350500404835, 54.837665632367134, 53.61238718032837, 53.94425377249718, 53.922651931643486, 53.14724273979664, 53.44386242330074, 49.97660167515278, 51.60362496972084, 47.10388742387295, 43.13223414123058, 41.87947176396847, 41.257407143712044, 41.915965005755424, 44.1984873265028, 44.034389331936836, 43.123179227113724, 39.7134929895401, 40.82714483141899, 37.52581737935543, 39.25320848822594, 37.64093220233917, 38.35322678089142, 38.392197489738464, 40.127473175525665, 40.36353550851345, 39.72543194890022, 42.16618537902832, 48.54143388569355, 50.31925588846207, 53.17486345767975, 48.31829085946083, 37.4853191524744, 39.37158353626728, 37.97498747706413, 38.38535025715828, 39.6275720000267, 36.53581850230694, 37.63869792222977, 38.625615164637566, 40.34835912287235, 39.31833319365978, 39.304194152355194, 38.555478528141975, 38.63767571747303, 40.27003012597561, 38.24940875172615, 40.80669052898884, 40.822801664471626, 40.21143727004528, 39.97519634664059, 39.18064758181572, 38.78276713192463, 39.798692017793655, 38.772078305482864, 38.3965140581131, 37.652107402682304, 35.71137674152851, 37.72019974887371, 37.38022059202194, 37.225147113204, 36.71855069696903, 36.53419978916645, 36.79364986717701, 36.73762567341328, 39.54230457544327, 51.453905403614044, 52.491967901587486, 43.13680909574032, 40.419844686985016, 38.076468631625175, 38.42205248773098, 40.118760243058205, 40.826590061187744, 38.20470795035362, 39.99899446964264, 41.24648652970791, 41.14385403692722, 39.67777490615845, 40.01377187669277, 40.90836927294731, 41.16322539746761, 40.168564170598984, 41.611160561442375, 40.3360515832901, 41.47414371371269, 40.56599244475365, 47.787018567323685, 51.909462958574295, 56.712792813777924, 57.04567015171051, 54.93533559143543, 55.25099605321884, 59.71801355481148, 55.19774951040745, 56.803957521915436, 54.227254986763, 60.01921959221363, 58.963404446840286, 57.23450481891632, 55.84263190627098, 54.29013021290302, 49.62638966739178, 53.60852278769016, 56.17633379995823, 64.06560346484184, 61.329134702682495, 68.1606437265873, 63.10113541781902, 69.74946767091751, 61.25191144645214, 76.10242277383804, 29.544210769236088, 0.3065843222429976, 0.924936393275857, 9.325312357395887, 1.425334510859102, 0.27640732121653855, 10.544288847595453, 74.85108152031898, 65.27169674634933, 76.10545501112938, 70.5809998512268, 59.13539081811905, 31.478888355195522, 27.007092610001564, 49.99825671315193, 67.9309232532978, 46.38908877968788, 1.9571005390025675, 0.13243821216747165, 0.045207684524939395, 0.022818879551778082, 0.03866092527459841, 0.0256952509880648, 0.20300314208725467, 0.32694045337848365, 0.13289705239003524, 0.3076567850075662, 0.27373318502213806, 0.40827467339113355, 0.3415677684824914, 14.420132171362638, 88.18734750151634, 67.69991844892502, 64.60338100790977, 45.06761468946934, 63.646409958601, 46.62688761949539, 68.33253130316734, 75.28621897101402, 69.65488314628601, 73.8368247449398, 50.339698791503906, 0.4259362741140649, 0.7752130273729563, 3.3021192345768213, 2.3798721469938755, 0.49551549833267927, 14.356934912502766, 56.155518516898155, 52.96796835958958, 64.33631613850594, 61.10510632395744, 62.39557787775993, 63.92058804631233, 63.019971773028374, 61.90203756093979, 61.89758040010929, 56.51979736983776, 48.14072258770466, 48.124444261193275, 46.63066081702709, 50.1847393065691, 53.61559420824051, 55.54794251918793, 57.0575825124979, 57.24397391080856, 57.98483915627003, 57.86285810172558, 55.572337210178375, 54.129972606897354, 54.39250811934471, 51.9723229855299, 52.46425598859787, 48.941917195916176, 45.18872559070587, 43.373893573880196, 42.8253398090601, 44.676190093159676, 45.679032281041145, 47.16148853302002, 47.06102192401886, 41.64000101387501, 42.58379437029362, 39.640343114733696, 41.47193603217602, 40.802107974886894, 41.68626733124256, 38.80640186369419, 42.17286542057991, 42.437027245759964, 41.30176596343517, 43.99092726409435, 49.90864232182503, 53.14623959362507, 56.96723476052284, 50.77314533293247, 38.02837461233139, 39.32694353163242, 38.57627861201763, 38.84394384920597, 39.048593267798424, 36.706102564930916, 39.35619056224823, 39.34944212436676, 42.387694492936134, 40.69844953715801, 41.06099188327789, 40.503675788640976, 40.795196145772934, 42.978646382689476, 41.39489896595478, 42.97993831336498, 43.63587811589241, 43.134525418281555, 42.33971446752548, 43.42257276177406, 40.10596252977848, 42.951223254203796, 41.500385105609894, 41.62859782576561, 39.51578579843044, 38.84900137782097, 38.0184343457222, 36.983396485447884, 37.482070326805115, 36.97738140821457, 37.695147693157196, 37.67332546412945, 36.81333661079407, 40.528165474534035, 55.92251501977444, 54.76831555366516, 46.283591240644455, 43.17185841500759, 40.30620038509369, 39.53054800629616, 41.142638102173805, 43.535749688744545, 41.42334803938866, 42.17501990497112, 43.51128660142422, 43.570616617798805, 41.525684148073196, 42.15531416237354, 43.31420257687569, 44.8075832426548, 42.76867724955082, 43.07176798582077, 42.01133608818054, 46.570038869977, 41.81678272783756, 52.36197307705879, 54.69643861055374, 59.084743335843086, 57.878083884716034, 59.667556062340736, 58.25335934758186, 61.001759469509125, 53.990292102098465, 58.178731352090836, 55.45320600271225, 62.383874505758286, 62.07939684391022, 62.67403453588486, 58.095998391509056, 56.81122273206711, 51.059566363692284, 58.85947622358799, 57.65015311539173, 66.64545983076096, 63.48123662173748, 70.12842893600464, 65.36238268017769, 73.29878121614456, 64.0555340051651, 76.36206284165382, 31.360473409295082, 0.29141770326532423, 2.0207579294219613, 25.892496518790722, 9.191502537578344, 0.8262546791229397, 11.89358789473772, 80.33579841256142, 70.87464809417725, 80.52811369299889, 81.64631769061089, 70.00984489917755, 47.433284148573875, 40.74930980801582, 60.02542465925217, 79.26782011985779, 60.77572859823704, 3.3102420112118125, 0.2328038148698397, 0.24256063741631806, 0.1923565290053375, 0.14422109787119552, 0.21021166699938476], [0.033010290790116414, 0.0412699491425883, 0.0469212033203803, 0.04198118265776429, 0.03383949981071055, 0.016033273059292696, 0.15352993039414287, 4.66712093912065, 61.98667421936989, 57.35563091933727, 45.051438957452774, 28.764939084649086, 18.28698992729187, 35.79182602465153, 56.32196098566055, 64.16983187198639, 62.67868168652058, 59.29035410284996, 43.90556484460831, 0.16451938601676375, 0.08640571584692225, 0.19235833984566852, 0.8551331888884306, 0.6629621225874871, 6.275345217436552, 56.76660172641277, 54.39295269548893, 57.18733415007591, 48.10276262462139, 50.39948858320713, 54.91092950105667, 61.128003895282745, 56.1408095061779, 55.595120787620544, 47.25869871675968, 44.37143884599209, 43.81974644958973, 46.769083589315414, 49.04024451971054, 52.12245672941208, 52.14953027665615, 49.35484863817692, 49.373110458254814, 50.502919033169746, 48.788762614130974, 51.28027372062206, 51.72185182571411, 50.491006672382355, 45.3607689589262, 41.106296852231026, 39.197811260819435, 40.53080253303051, 39.72936473786831, 39.76965397596359, 40.80118462443352, 40.154151543974876, 39.3956096470356, 37.410930544137955, 35.81583693623543, 36.17001213133335, 37.080606669187546, 37.82557189464569, 37.59177803993225, 35.56750886142254, 36.2684116512537, 37.787167355418205, 37.26812660694122, 37.88588605821133, 37.505283281207085, 37.238818779587746, 46.620329171419144, 49.83045771718025, 51.04460656642914, 40.84343455731869, 36.45750850439072, 39.76313732564449, 37.86019183695316, 38.64029757678509, 36.404649540781975, 34.94915284216404, 37.52567678689957, 37.37633720040321, 37.2463271766901, 35.92486448585987, 35.666599944233894, 37.01387844979763, 36.14305257797241, 38.86958487331867, 37.92919233441353, 36.825271770358086, 36.892011389136314, 37.0074187964201, 35.35364493727684, 38.36300365626812, 36.49517968297005, 36.30225643515587, 36.44185334444046, 37.22176529467106, 37.760925963521004, 38.691891208291054, 36.48417167365551, 36.484878435730934, 38.03784750401974, 38.73348757624626, 37.80763305723667, 37.5865875184536, 39.831868037581444, 50.23564897477627, 47.145449593663216, 38.135027289390564, 36.62523530423641, 37.18015372753143, 36.66636809706688, 39.33670520782471, 36.066281497478485, 36.10495202243328, 37.40056470036507, 38.994886949658394, 39.491828083992004, 37.96711429953575, 39.38927158713341, 38.01786817610264, 39.47577014565468, 39.38504621386528, 39.34231750667095, 37.9264260828495, 39.94990490376949, 39.37050439417362, 39.16075944900513, 46.16447523236275, 50.432182028889656, 51.65507420897484, 54.9653235822916, 54.39840540289879, 56.44740365445614, 54.722509011626244, 54.514090195298195, 53.19397263228893, 54.1441610455513, 53.11529025435448, 54.6282322704792, 51.44869968295097, 52.865818440914154, 48.64499352872372, 49.97688286006451, 48.966699466109276, 52.024763971567154, 55.02765163779259, 59.19140741229057, 58.06578241288662, 66.3085775077343, 58.065307438373566, 74.14780005812645, 26.12669315189123, 0.46886619238648564, 0.3758011112222448, 5.552522828802466, 1.017526974901557, 0.34017870551906526, 12.620160207152367, 71.07834756374359, 61.862082704901695, 70.39745450019836, 64.63447853922844, 58.441757038235664, 27.166600450873375, 22.05807287245989, 45.62828220427036, 62.30543531477451, 35.49116335809231, 0.9485765872523189, 0.12845240416936576, 0.07209344243165106, 0.15986721846275032, 0.07536975725088269, 0.052953346239519306, 0.07781275155139156, 0.11089891209849156, 0.050640498666325584, 0.08791384898358956, 0.08897377687389962, 0.04729775420855731, 0.06006317293213215, 6.064401436597109, 71.51349261403084, 63.98694008588791, 51.442141234874725, 38.76231662929058, 28.91384929418564, 38.20805937051773, 64.55298811197281, 68.55218231678009, 67.58954957127571, 63.915025144815445, 49.383024126291275, 0.21300476946635172, 0.09405282035004348, 0.7334467372857034, 3.282777559943497, 0.45199934276752174, 7.652540942654014, 59.17611703276634, 53.885090947151184, 57.29784741997719, 49.63195636868477, 52.8485369682312, 58.30489598214626, 60.902364403009415, 60.2567258477211, 55.84902696311474, 50.09734019637108, 45.53917698562145, 45.16320616006851, 47.58956216275692, 50.52802048623562, 54.505008682608604, 54.942239820957184, 53.21892589330673, 53.12691003084183, 53.25519874691963, 50.56701399385929, 52.96441175043583, 54.27340351045132, 51.868653148412704, 48.86672303080559, 43.73626872897148, 41.704612746834755, 42.15846799314022, 41.461893171072006, 40.63295245170593, 41.203051060438156, 42.60048687458038, 42.28069603443146, 40.02781592309475, 39.78240609169006, 38.139032274484634, 39.184682965278625, 39.45337414741516, 38.259573206305504, 37.63458274304867, 37.37798251211643, 38.53358410298824, 38.76634441316128, 39.837940111756325, 39.44786064326763, 39.85001586377621, 48.16100589931011, 52.747637182474136, 54.06986363232136, 41.06635719537735, 37.050576880574226, 39.03617173433304, 37.13713623583317, 40.114447474479675, 36.67532421648502, 36.77092708647251, 38.67370158433914, 37.756537199020386, 39.113216400146484, 36.32597856223583, 37.768601551651955, 38.1623288244009, 39.82345148921013, 40.86398385465145, 40.48827901482582, 40.019194185733795, 39.11306820809841, 38.18457283079624, 37.671041786670685, 39.661557376384735, 37.96647973358631, 38.371188417077065, 35.98501905798912, 38.53565499186516, 37.922234907746315, 37.121834456920624, 35.936556458473206, 37.3208449780941, 37.36464522778988, 38.52493576705456, 38.211665377020836, 37.8029403090477, 41.69217601418495, 51.8099083006382, 48.06381091475487, 40.13587832450867, 38.4640896320343, 39.55429293215275, 37.82999865710735, 39.8000181466341, 39.45194162428379, 38.086826875805855, 39.22816403210163, 42.00117543339729, 41.05843082070351, 39.54141162335873, 40.47715701162815, 40.41218809783459, 41.507581919431686, 40.63310444355011, 41.868570148944855, 40.30741631984711, 42.81549073755741, 41.644826754927635, 40.82159332931042, 47.98488534986973, 51.58861957490444, 55.19186742603779, 56.81701362133026, 57.814019322395325, 59.49462354183197, 55.886789336800575, 56.39208622276783, 55.57102628052235, 58.86112533509731, 54.924069195985794, 57.72893808782101, 54.84204679727554, 56.686194241046906, 51.24922938644886, 53.77699054777622, 52.895677238702774, 55.72178319096565, 58.131834268569946, 63.49722236394882, 61.45297385752201, 66.50406941771507, 61.94755531847477, 76.5603058040142, 28.38257510215044, 0.7527839590329677, 1.118364182766527, 6.85740320943296, 0.49348064814694226, 0.20437506143935025, 13.532149270176888, 77.87979260087013, 66.93223804235458, 75.43344587087631, 73.65625843405724, 59.47637312114239, 34.548198357224464, 32.60385408997536, 52.0003654807806, 73.05444672703743, 43.39326873421669, 1.0343503346666694, 0.21160812175367028, 0.07801699059200473, 0.053555317063000984, 0.08413186442339793, 0.04939589103742037, 0.19200095121050254, 0.2518805576255545, 0.19908708112780005, 0.2067046778392978, 0.12170349873485975, 0.18978201871505007, 0.2677525137551129, 7.54969566129148, 83.97968888282776, 70.1633870601654, 62.36487552523613, 43.09704802930355, 30.271126963198185, 48.35913486778736, 69.86026212573051, 76.32506802678108, 72.85045087337494, 70.1638962328434, 53.06301645934582, 0.27441542653832585, 0.25008536176756024, 1.6947939642705023, 4.305302454158664, 1.056759157218039, 8.766946569085121, 61.80676527321339, 55.81207014620304, 57.98777639865875, 50.469971001148224, 53.84897768497467, 60.165371149778366, 63.77719894051552, 61.607416570186615, 59.44915898144245, 52.67164126038551, 49.504568204283714, 50.61202637851238, 49.44703169167042, 53.682888597249985, 56.3428408652544, 58.79644900560379, 55.35345755517483, 55.65716005861759, 54.895867109298706, 53.70800144970417, 55.35752333700657, 55.52086517214775, 55.60371972620487, 50.20572178065777, 46.205000057816505, 44.39070761203766, 44.40579280257225, 44.1943683475256, 42.499720081686974, 44.47802692651749, 44.479816630482674, 43.478562757372856, 41.686605513095856, 41.11437141895294, 41.25562883913517, 41.548072546720505, 41.87447503209114, 42.55554288625717, 39.47112679481506, 40.240957885980606, 40.33006310462952, 40.79929232597351, 42.19876103103161, 41.919396221637726, 40.61371028423309, 51.51007778942585, 55.431892946362495, 56.79148279130459, 43.251490741968155, 36.43046535551548, 39.86174963414669, 37.636440843343735, 40.04379026591778, 37.09932826459408, 36.134446039795876, 40.693855583667755, 40.242637395858765, 41.93181775510311, 38.20642925798893, 39.63699169456959, 40.12365058064461, 41.24506540596485, 42.391623482108116, 41.828128919005394, 42.007171511650085, 40.07666230201721, 40.90830847620964, 39.24551770091057, 42.049524039030075, 40.18002435564995, 38.15864682197571, 39.010314121842384, 39.7956407815218, 38.80640186369419, 37.46135763823986, 37.15054951608181, 38.057158067822456, 38.62046264111996, 38.597204089164734, 37.798794731497765, 38.58370341360569, 41.60167247056961, 55.48988923430443, 50.390950441360474, 40.94019256532192, 40.3424846380949, 42.496334463357925, 38.93519215285778, 44.574401155114174, 41.444972679018974, 39.03855420649052, 40.799022540450096, 44.03323419392109, 41.99292227625847, 42.48068690299988, 42.66056165099144, 41.463709473609924, 43.43313619494438, 45.20381458103657, 44.14810203015804, 42.108067497611046, 44.44914847612381, 45.460262820124626, 44.59550142288208, 49.90289703011513, 56.30387395620346, 57.41989307105541, 60.64665712416172, 60.45045845210552, 61.68974295258522, 59.77386675775051, 59.53210853040218, 57.16627947986126, 60.129713863134384, 56.845417097210884, 60.630025416612625, 57.13389381766319, 58.850322514772415, 54.17367406189442, 56.06238931417465, 55.49697585403919, 56.44492618739605, 60.07236734032631, 65.13696357607841, 63.81170868873596, 71.17969572544098, 62.782055139541626, 77.76296406984329, 31.483883187174797, 0.6186366104520857, 2.9697209084406495, 17.035137601196766, 4.421664560213685, 0.41964577103499323, 14.62059611454606, 86.11230924725533, 73.27272981405258, 82.22300514578819, 77.2908166050911, 73.88306066393852, 40.497440323233604, 36.88953012228012, 64.6629998087883, 81.14171996712685, 58.11557114124298, 1.640976145863533, 0.34873661817982793, 0.10714357063989155, 0.22623058321187273, 0.17534501996124163, 0.18000970012508333], [0.033625668511376716, 0.061348958624876104, 0.0280575014767237, 0.04822560578759294, 0.06463374505983666, 0.07478151615941897, 0.10560417082160711, 2.20228083897382, 62.84975230693817, 57.49230958521366, 45.04496410489082, 19.441018402576447, 17.514128498733044, 44.57477733492851, 60.51271431148052, 65.92644721269608, 61.28896325826645, 61.70827455818653, 45.717106238007545, 0.38870637654326856, 0.1392709431820549, 0.7746732188388705, 2.7051149820908904, 0.43538906844332814, 3.0752317467704415, 50.727099403738976, 47.62678496539593, 52.912407740950584, 56.541710793972015, 67.11794927716255, 57.54009202122688, 60.368717238307, 55.36752060055733, 49.664307832717896, 42.85299092531204, 44.0214092284441, 44.20351065695286, 46.541908979415894, 49.272172674536705, 51.11587934195995, 51.24207057058811, 51.83536693453789, 51.16945266723633, 56.72002762556076, 52.00690492987633, 48.599525168538094, 44.32269886136055, 42.882697731256485, 37.879342809319496, 38.12915660440922, 38.80970008671284, 39.46679122745991, 39.34191092848778, 41.30155697464943, 40.998489037156105, 40.72722539305687, 38.36200051009655, 38.42427536845207, 37.62006752192974, 38.972867131233215, 38.09539541602135, 37.80872359871864, 37.93705031275749, 36.311695128679276, 36.22713826596737, 36.64779469370842, 35.53242154419422, 35.38369372487068, 36.631326377391815, 36.22672028839588, 41.58700905740261, 52.364632934331894, 50.67505359649658, 46.62065215408802, 37.314263731241226, 37.80936576426029, 38.164319917559624, 38.70040275156498, 37.09194906055927, 38.38043712079525, 35.13500466942787, 36.612950563430786, 37.28992983698845, 38.56815844774246, 37.86930754780769, 39.11196626722813, 37.28682540357113, 38.165288865566254, 39.69943754374981, 39.74220424890518, 38.11567112803459, 37.07921974360943, 37.874950245022774, 37.20968574285507, 36.88208632171154, 35.95335155725479, 37.268119007349014, 38.41482527554035, 37.55496181547642, 37.250548750162125, 37.03432135283947, 37.35603109002113, 37.659156024456024, 36.351209208369255, 36.18427276611328, 36.70398607850075, 44.781262055039406, 50.5379531532526, 41.63011774420738, 35.78685209155083, 37.57515013217926, 36.01749591529369, 36.193407475948334, 36.91620089113712, 36.89417727291584, 36.05777755379677, 35.76069429516792, 37.614899799227715, 37.57723242044449, 39.53034661710262, 38.182148560881615, 40.43752893805504, 39.98487442731857, 39.37902353703976, 42.14983865618706, 39.911249577999115, 39.66308109462261, 41.13426715135574, 38.32116790115833, 39.09057341516018, 46.44289009273052, 51.290384978055954, 52.0535284280777, 54.51120615005493, 52.36657842993736, 53.648956418037415, 54.92360562086105, 53.5204017162323, 54.287268966436386, 53.27392414212227, 53.99147003889084, 50.43339416384697, 49.78483356535435, 48.221608847379684, 45.278020799160004, 44.46189299225807, 48.30799341201782, 48.871978148818016, 52.42204785346985, 56.150973960757256, 65.44407069683075, 59.69006605446339, 75.62633872032166, 26.831293143332005, 0.6929158559069037, 0.4826587100978941, 4.170321822166443, 0.3882702608825639, 0.45071305241435766, 16.61529242992401, 75.37505820393562, 62.07238242030144, 71.63396134972572, 67.71434247493744, 58.833196833729744, 22.743671983480453, 27.489997297525406, 44.02589678764343, 59.14722338318825, 38.22712294757366, 0.8577881183009595, 0.014222141435311642, 0.0530750733014429, 0.023171460925368592, 0.0008622879340691725, 0.0398637982289074, 0.07485087728127837, 0.009330080210929736, 0.030297687226266135, 0.05224582717346493, 0.10781113247503527, 0.03990862765931524, 0.1156238694966305, 2.977195819839835, 70.80332592129707, 62.247469425201416, 55.24355225265026, 27.064503729343414, 22.159574925899506, 50.183971747756004, 65.53711250424385, 70.08027032017708, 65.30334904789925, 65.35490468144417, 49.406761452555656, 0.6152031384408474, 0.1670081337215379, 0.8797157322987914, 4.536430276930332, 0.24326999700861052, 3.1453940318897367, 56.71820752322674, 50.2534282207489, 52.04762354493141, 56.513797491788864, 67.66276404261589, 61.164850518107414, 61.66937604546547, 56.58381253480911, 51.09461948275566, 44.93102341890335, 45.041038915514946, 47.47347839176655, 49.56075958907604, 52.32946202158928, 52.64252722263336, 54.00520630180836, 53.895870968699455, 54.46945019066334, 56.66708506643772, 53.383829444646835, 52.16203920543194, 48.427603393793106, 44.76266585290432, 39.827125892043114, 39.26069788634777, 40.36528721451759, 41.51278004050255, 41.69452428817749, 43.33850607275963, 42.86070071160793, 42.52785377204418, 41.11555315554142, 39.43062476813793, 40.63903212547302, 40.19406080245972, 39.460453167557716, 39.17211703956127, 38.73561546206474, 37.21270278096199, 37.620971873402596, 38.90138536691666, 37.30677433311939, 38.71558293700218, 38.86982426047325, 38.36549252271652, 44.06148187816143, 53.54045704007149, 52.35078647732735, 46.77453629672527, 37.473623380064964, 39.575005620718, 36.580268517136574, 38.26523870229721, 37.41352200508118, 39.04285557568073, 35.9693942964077, 39.16957877576351, 38.23731780052185, 40.53306721150875, 39.11456532776356, 41.040370389819145, 40.188623294234276, 40.6375578045845, 40.63917651772499, 42.46727742254734, 40.78263022005558, 39.94660668075085, 40.395647585392, 38.82027491927147, 37.577863186597824, 37.384578958153725, 38.42619426548481, 37.693775966763496, 37.444330751895905, 37.56267540156841, 37.872096598148346, 36.96692056953907, 37.82117933034897, 36.74894526600838, 37.315232679247856, 38.049121499061584, 47.057970687747, 53.03476497530937, 43.61154422163963, 37.386585250496864, 38.23617406189442, 38.31234097480774, 38.57638120651245, 38.9681363850832, 37.93683372437954, 38.44216860830784, 38.26189488172531, 38.235520496964455, 39.04054529964924, 39.57047626376152, 41.629939153790474, 42.306325659155846, 43.031227961182594, 42.589418068528175, 43.50830756127834, 41.83441758155823, 41.76918268203735, 42.55853332579136, 40.35068079829216, 40.91805875301361, 48.162981793284416, 53.42875063419342, 54.076163694262505, 55.702286437153816, 55.540350526571274, 55.974203646183014, 55.477083921432495, 57.314642518758774, 57.55543939769268, 56.2738935649395, 53.60191494226456, 52.064243853092194, 52.42683559656143, 49.61509667336941, 46.8464208394289, 47.31493949890137, 52.5604972243309, 51.898333355784416, 55.025926530361176, 58.60305838286877, 66.32519021630287, 62.612652629613876, 77.49701634049416, 29.532864578068256, 0.7562750217039138, 1.8779064947739244, 4.320563385263085, 0.4532635468058288, 0.32101921329740435, 17.38730650395155, 79.90482553839684, 66.51839464902878, 78.5757252573967, 71.85488909482956, 68.94280895590782, 27.373225763440132, 32.17509649693966, 54.28627721965313, 66.37502834200859, 48.38423252105713, 0.9788762801326811, 0.041454550955677405, 0.14845312078250572, 0.05624389545118902, 0.0020768940112247947, 0.06613473873585463, 0.1701673524803482, 0.14704899222124368, 0.10977095895214006, 0.13798074913211167, 0.22609643259784207, 0.19481756491586566, 0.36388901760801673, 3.9220436196774244, 82.89465710520744, 70.0013941526413, 62.6763030141592, 31.920240372419357, 28.779336512088776, 56.75059698522091, 75.06578519940376, 75.7413737475872, 72.83003076910973, 70.54505378007889, 53.87228563427925, 0.6076106114778668, 0.3794389113318175, 3.3411801885813475, 8.18116620182991, 0.33664100628811866, 3.6651443922892213, 62.08240628242493, 52.909424901008606, 54.49957117438316, 58.718659579753876, 70.00631868839264, 63.18525530397892, 63.14134106040001, 59.12786342203617, 54.50142927467823, 48.79654839634895, 47.68192000687122, 50.40816731750965, 51.10384538769722, 55.24187654256821, 54.140657633543015, 56.47286608815193, 55.124352648854256, 56.60518638789654, 61.35439194738865, 56.34766660630703, 53.21470431983471, 50.19457697868347, 47.33627535402775, 43.03424499928951, 42.069890946149826, 42.31807082891464, 44.18939061462879, 43.91841195523739, 46.14686317741871, 45.09323671460152, 45.57676836848259, 44.16056156158447, 41.91236659884453, 43.55659916996956, 42.675228863954544, 41.85882747173309, 42.085394114255905, 42.10907444357872, 40.006461068987846, 40.19703984260559, 40.18869549036026, 38.71524855494499, 41.00161626935005, 40.02238981425762, 42.05739341676235, 47.87403389811516, 55.85509143769741, 55.254309475421906, 49.78986069560051, 38.9421533793211, 39.625155329704285, 38.225770220160484, 38.94923999905586, 37.72476330399513, 38.923063203692436, 36.35787025094032, 39.694486409425735, 37.859849855303764, 40.90805768966675, 41.67726941406727, 41.30551256239414, 42.65477076172829, 42.897763922810555, 44.50620621442795, 45.425076708197594, 43.32109160721302, 41.76380977034569, 41.89220868051052, 41.53187781572342, 40.11406749486923, 38.43323528766632, 40.629061460494995, 38.3152212202549, 38.798456490039825, 37.40670517086983, 38.53782467544079, 37.593282759189606, 39.68197748064995, 35.59536136686802, 36.654881313443184, 37.03480392694473, 49.276143461465836, 55.60582101345062, 46.188071966171265, 39.6400011330843, 42.98491224646568, 39.77256081998348, 40.001665726304054, 41.26130573451519, 40.98075918853283, 41.68679550290108, 40.73762163519859, 39.57542359828949, 40.51903076469898, 43.180924728512764, 43.51036325097084, 45.43152116239071, 45.270690992474556, 44.812568575143814, 46.91263608634472, 44.201295375823975, 45.18768824636936, 45.70898227393627, 41.48184210062027, 43.960745483636856, 50.825198739767075, 54.68710631132126, 56.32480323314667, 58.91019970178604, 57.44622565805912, 59.454410299658775, 59.927743300795555, 58.760084956884384, 60.20704351365566, 59.082011282444, 59.41342189908028, 54.685320407152176, 57.110107094049454, 52.37455800175667, 49.475902542471886, 50.42855702340603, 55.70912607014179, 54.4642748683691, 57.42018185555935, 61.94828487932682, 70.14787629246712, 65.3039114177227, 79.32002931833267, 31.72691624611616, 0.7140307885129005, 4.084338610991836, 10.682507380843163, 2.1629700483754277, 0.541098564863205, 19.40542571246624, 86.4481808245182, 71.67670905590057, 84.82607826590538, 79.4774928689003, 77.07070961594582, 31.141073182225227, 41.732928827404976, 62.98551142215729, 78.08808222413063, 59.58403654396534, 1.6044915723614395, 0.13214274833444506, 0.2579583611804992, 0.12056623163516633, 0.23988181084860116, 0.16857060691108927], [0.0748150612344034, 0.061333306730375625, 0.05357944799470715, 0.0996485841460526, 0.10817692964337766, 0.044090429437346756, 0.08949610040872358, 0.5365861288737506, 48.40546578168869, 60.46177424490452, 44.92981128394604, 28.588947728276253, 23.57004404067993, 38.45958687365055, 57.768091186881065, 62.88951717317104, 59.78631488978863, 58.94863843917847, 47.953438237309456, 0.6844699184875935, 0.0755401692003943, 0.1778975478373468, 2.1463996125385165, 0.05948780810285825, 1.4615400368347764, 47.322064116597176, 55.71289926767349, 62.75166057050228, 64.70808818936348, 60.153622180223465, 58.055994138121605, 54.914208725094795, 49.95066046714783, 45.31740188598633, 43.13751205801964, 45.20766757428646, 44.94968041777611, 49.717679768800735, 50.69809556007385, 52.33011558651924, 53.3549851924181, 53.29687871038914, 51.88767492771149, 47.63489753007889, 44.140342846512794, 41.232043504714966, 38.294671922922134, 38.39912451803684, 37.305360808968544, 38.13550226390362, 40.337282717227936, 41.870447248220444, 44.74274732172489, 45.331058353185654, 43.08923564851284, 40.40447071194649, 39.15106616914272, 37.58711189031601, 39.18526813387871, 37.09276981651783, 36.69959731400013, 35.91478742659092, 34.5366507768631, 36.10466703772545, 35.08316025137901, 36.759884878993034, 36.491794064641, 35.768920853734016, 36.78810216486454, 37.06546448171139, 43.25476236641407, 51.34002551436424, 48.81532318890095, 47.864203825592995, 38.56571517884731, 39.13197219371796, 37.92836777865887, 38.510355949401855, 37.697188183665276, 38.13542626798153, 37.7610931545496, 35.32544285058975, 35.4708306491375, 37.660520151257515, 38.9266350120306, 40.63876233994961, 39.22323949635029, 39.45369333028793, 39.8321720212698, 38.18079963326454, 39.94611270725727, 39.909414276480675, 38.444421887397766, 37.055695205926895, 38.381341472268105, 36.4533781260252, 38.81236374378204, 38.278693780303, 37.67332926392555, 38.03330674767494, 38.07549588382244, 38.068603053689, 37.73765601217747, 36.664331406354904, 36.01911462843418, 39.263813719153404, 44.34980660676956, 45.35492107272148, 39.79362688958645, 35.09511820971966, 36.7719454318285, 35.82542762160301, 36.3045135140419, 38.14082957804203, 37.514562383294106, 36.208690255880356, 37.30884522199631, 37.77346909046173, 37.93273754417896, 37.18773052096367, 38.92502009868622, 37.62703634798527, 37.76440657675266, 40.75856991112232, 40.705106779932976, 41.297840774059296, 42.46555991470814, 42.490098997950554, 40.65675437450409, 39.641285464167595, 39.90008197724819, 44.898022189736366, 49.61600102484226, 49.947510436177254, 51.629919558763504, 51.06886066496372, 49.40890073776245, 49.25392605364323, 49.464651346206665, 48.57177525758743, 45.970982015132904, 45.15328109264374, 45.540252327919006, 43.31225328147411, 43.31422537565231, 41.40465684235096, 43.08972582221031, 44.784837663173676, 49.20539125800133, 52.031804993748665, 62.6951652020216, 58.463161289691925, 72.07052752375603, 32.82308332622051, 0.7915418199263513, 0.5098230962175876, 3.27373000793159, 0.4660852166125551, 0.29103968292474747, 20.45256782323122, 71.50466188788414, 64.98066276311874, 70.04490181803703, 68.17344903945923, 49.672222808003426, 34.8445900529623, 28.811074309051037, 37.497763484716415, 66.11114010214806, 32.91232913732529, 0.71771445334889, 0.05949386773863807, 0.006918868848515558, 0.012040322817483684, 0.03255560659454204, 0.029828948609065264, 0.01842292920628097, 0.039220909093273804, 0.10731497706728987, 0.05986244425002951, 0.1160874446213711, 0.03577017843781505, 0.0493341369292466, 0.7197405165061355, 55.66314473748207, 67.28593826293945, 54.654990434646606, 34.1483686119318, 31.611763425171375, 49.7411435097456, 62.861014902591705, 68.45138892531395, 63.83542701601982, 64.69580724835396, 52.121818363666534, 0.6826709525194019, 0.13267920236103237, 0.20538283861242235, 3.232641387730837, 0.08420732599915937, 1.5669668046757579, 52.511586248874664, 56.56208150088787, 64.90392208099365, 64.63152229785919, 62.463810816407204, 58.74600291252136, 58.22974741458893, 52.49287985265255, 47.04753264784813, 45.25142602622509, 46.33738495409489, 46.3650094717741, 52.04177185893059, 52.47979335486889, 52.99423635005951, 53.987795636057854, 53.891926780343056, 53.71439270675182, 49.99511428177357, 47.27061107754707, 43.94270405173302, 39.689254090189934, 39.34139795601368, 40.47578148543835, 39.270117580890656, 43.451318219304085, 44.57899510860443, 45.86294241249561, 46.59566089510918, 44.170973002910614, 42.1716532856226, 40.74084386229515, 41.0623712092638, 40.71151703596115, 38.58732081949711, 38.39679904282093, 38.48671741783619, 36.56798757612705, 37.50163547694683, 37.05978758633137, 39.10793088376522, 39.259174168109894, 38.34805145859718, 39.68917429447174, 39.891319647431374, 44.05084624886513, 55.06218418478966, 52.64588624238968, 51.34030669927597, 39.11819413304329, 37.97795511782169, 37.97033652663231, 38.20712462067604, 38.547160774469376, 37.6892352104187, 39.03390325605869, 36.818899512290955, 36.60712167620659, 39.420980885624886, 39.877309799194336, 41.82370215654373, 41.9925232976675, 41.91816508769989, 41.430411860346794, 40.801602602005005, 41.21399827301502, 41.33449740707874, 39.84345741569996, 38.681061789393425, 37.59768672287464, 37.78935223817825, 39.13765288889408, 37.71695092320442, 37.11437165737152, 39.14429113268852, 38.97526100277901, 37.55480982363224, 37.576955035328865, 37.86623731255531, 36.45330213010311, 39.883526265621185, 49.216992035508156, 47.57389560341835, 40.50084874033928, 37.12997741997242, 38.20539191365242, 37.15617701411247, 36.71551086008549, 38.98858688771725, 38.89928787946701, 39.49449174106121, 39.319879710674286, 40.51455080509186, 40.3621181845665, 37.487671226263046, 39.5688271522522, 41.07332222163677, 40.349776446819305, 42.53050982952118, 42.1294641494751, 42.92055889964104, 44.077908396720886, 43.03570032119751, 42.011374086141586, 40.3885305672884, 41.69747672975063, 46.576107144355774, 51.52400404214859, 52.29463689029217, 53.47554512321949, 53.6500583589077, 51.578888297080994, 52.325677424669266, 51.97261556982994, 49.52377997338772, 49.9149613827467, 47.19000980257988, 48.43761965632439, 46.55922085046768, 46.08789034187794, 44.786870554089546, 46.78509593009949, 47.09100991487503, 53.07908579707146, 54.22753997147083, 65.28979137539864, 62.33018718659878, 75.01686662435532, 34.81754690408707, 0.9960109856911004, 0.7225856732111424, 2.9699904564768076, 0.21045507659437135, 0.38199029630050063, 22.07000233232975, 77.41972088813782, 67.36351490020752, 78.13997983932495, 73.60488519072533, 57.17384487390518, 30.45160587877035, 30.843528248369694, 45.098267644643784, 73.47564652562141, 42.14623264968395, 0.9920974331907928, 0.03222198152798228, 0.03483406675513834, 0.010378811875852989, 0.08495418631355278, 0.040671922834008, 0.19493993022479117, 0.16255468362942338, 0.22927248326595873, 0.21637947822455317, 0.23524200747488067, 0.11681276781018823, 0.20202230487484485, 0.8193337661214173, 63.956906497478485, 74.46421667933464, 62.24238909780979, 41.34925961494446, 34.36837300658226, 51.0855645686388, 70.00276207923889, 73.1749078631401, 70.94647943973541, 67.49009370803833, 58.651456385850906, 0.7077179616317153, 0.4955053160665557, 1.7632564343512058, 8.752123564481735, 0.3170349489664659, 2.0380377396941185, 56.016616970300674, 57.804371640086174, 68.6153957247734, 69.74762097001076, 66.51220098137856, 62.78920255601406, 61.121684834361076, 55.13482488691807, 50.08751392364502, 48.756916522979736, 49.42656219005585, 48.477502316236496, 55.50939358770847, 55.40782883763313, 56.48136243224144, 56.93511128425598, 57.96529300510883, 55.40463700890541, 51.05201616883278, 49.757904410362244, 45.05826339125633, 41.873012110590935, 42.04964943230152, 42.05038659274578, 41.24632693827152, 46.346987038850784, 45.78971654176712, 49.34226751327515, 50.019037798047066, 47.62648098170757, 44.33818683028221, 43.29746067523956, 44.038462713360786, 42.96915829181671, 41.42523653805256, 39.74894508719444, 39.61048811674118, 38.854427486658096, 40.22751800715923, 38.03981959819794, 40.949654057621956, 41.73094153404236, 40.37075512111187, 42.10812449455261, 42.67911605536938, 46.3849052041769, 58.44577342271805, 55.29303319752216, 53.053847551345825, 39.24444615840912, 38.75634714961052, 36.793482676148415, 39.19637493789196, 39.03525598347187, 38.07937167584896, 41.023837476968765, 38.16411092877388, 37.10904434323311, 41.6258429735899, 42.00206458568573, 45.05222171545029, 43.181825280189514, 44.49393667280674, 43.69103975594044, 42.77737118303776, 43.36876004934311, 41.4726085960865, 41.8447720259428, 40.889077708125114, 41.11396104097366, 39.35552939772606, 39.79597136378288, 38.8284482806921, 37.69191786646843, 38.712995275855064, 38.979957550764084, 37.82169230282307, 37.807199880480766, 36.92510761320591, 36.65141589939594, 40.85986487567425, 51.6459546983242, 51.89375080168247, 44.137770384550095, 39.32524882256985, 40.126470029354095, 38.86510871350765, 39.3341289460659, 41.857242956757545, 41.21470883488655, 41.90391205251217, 41.822186037898064, 42.29303017258644, 42.10949622094631, 40.83248734474182, 41.62199378013611, 43.068538159132004, 42.54417769610882, 44.82282042503357, 45.44314093887806, 44.26282927393913, 47.48300068080425, 45.60924902558327, 44.9424684047699, 43.52867066860199, 44.965593963861465, 49.55002896487713, 54.13029558956623, 55.02143897116184, 57.04538516700268, 56.22584134340286, 55.051499158144, 56.540878638625145, 54.95333142578602, 53.28737162053585, 51.21016748249531, 49.49172489345074, 50.21802172064781, 49.198228642344475, 47.04188235104084, 46.73493482172489, 47.19029858708382, 50.24219982326031, 54.79806795716286, 56.9699402153492, 67.83801063895226, 64.68717411160469, 74.71300452947617, 38.585170134902, 0.8085177058819681, 5.530084082856774, 11.670770701020956, 2.9507005540654063, 0.30525041569489986, 23.637591116130352, 84.41555589437485, 73.44970151782036, 82.21336886286736, 79.17379036545753, 67.73040801286697, 48.49304348230362, 41.20289906859398, 56.34810358285904, 83.62298682332039, 50.79464837908745, 1.3765774271450937, 0.21040009829448536, 0.10172851238166913, 0.12144653010182083, 0.2072308011702262, 0.11312328453641385], [0.055217731569428, 0.044265179240028374, 0.0202275596166146, 0.10057545237941667, 0.022076629829825833, 0.03147393748804461, 0.09567690663971007, 0.1419273717328906, 32.36073933541775, 59.16698232293129, 48.40911738574505, 26.755705699324608, 23.23068805038929, 41.726754158735275, 54.21603798866272, 63.44269908964634, 59.46501173079014, 59.198741018772125, 55.26359997689724, 2.2803027648478746, 0.22324434423353523, 0.13731801125686616, 2.1846554847434163, 0.15574813558487222, 0.36679422890301794, 49.61031652987003, 66.3499952852726, 60.354255214333534, 56.09839618206024, 59.504609405994415, 54.643017277121544, 48.4476625174284, 44.07761961221695, 44.825886860489845, 44.64136116206646, 44.96992193162441, 47.051663026213646, 50.0592016428709, 50.11962980031967, 52.84650407731533, 51.30400724709034, 53.49563464522362, 46.921113431453705, 43.00000503659248, 38.48851852118969, 37.7274801582098, 38.086131513118744, 39.98912639915943, 39.7616022080183, 43.45218077301979, 44.45481397211552, 44.82980065047741, 45.55612787604332, 45.04947066307068, 41.97018429636955, 42.71355740725994, 40.0587310642004, 39.44390885531902, 36.96571983397007, 38.37804324924946, 37.32152134180069, 35.27864456176758, 36.87899708747864, 36.24162308871746, 36.185921877622604, 36.757775992155075, 36.39615319669247, 35.834923312067986, 36.93768493831158, 38.582001104950905, 44.96308609843254, 51.706994622945786, 47.13796019554138, 51.96826480329037, 41.17548733949661, 37.790777161717415, 38.13405454158783, 35.5672162771225, 37.2087661921978, 39.72658708691597, 36.530726775527, 35.76985940337181, 34.797111600637436, 37.521371617913246, 37.26451300084591, 39.53983090817928, 37.587571665644646, 38.30531135201454, 40.26878759264946, 39.19887140393257, 40.065148919820786, 38.871568366885185, 37.04902656376362, 36.35397166013718, 37.29987770318985, 37.54023000597954, 36.636144518852234, 37.63179749250412, 36.49113290011883, 36.173694133758545, 37.25730858743191, 37.8116874396801, 38.52721944451332, 38.10858070850372, 37.72199705243111, 41.63198724389076, 47.47354678809643, 46.42732612788677, 35.34731067717075, 36.50175713002682, 38.15072804689407, 36.60709887742996, 36.463098004460335, 35.87765581905842, 36.21690921485424, 36.24126970767975, 36.97141192853451, 37.44611285626888, 36.44123777747154, 37.63763777911663, 36.95732228457928, 38.44868525862694, 37.58347928524017, 40.18387354910374, 42.38118164241314, 43.68422292172909, 46.34025380015373, 46.65315940976143, 43.956276923418045, 41.977514103055, 40.39687491953373, 36.53828077018261, 38.58240768313408, 40.35211332142353, 43.34509491920471, 39.82295751571655, 42.08731301128864, 41.84735208749771, 41.307906433939934, 40.08701674640179, 41.661386266350746, 40.73716185986996, 43.63653548061848, 42.10628919303417, 42.41920620203018, 44.28186625242233, 49.91849899291992, 51.28935903310776, 54.3754356354475, 55.53812384605408, 63.93704116344452, 59.49187628924847, 74.56574723124504, 32.928466871380806, 0.5487134156282991, 0.711416588164866, 2.98816226888448, 0.24575675575761124, 0.2782458288129419, 25.66647134721279, 73.8437631726265, 61.77485078573227, 70.65275520086288, 64.77354347705841, 59.99053493142128, 31.674123778939247, 23.758437931537628, 43.165953531861305, 70.39624616503716, 30.737952813506126, 1.0611025616526604, 0.11166692362166941, 0.10289524274412543, 0.09394987704581581, 0.06541883340105414, 0.01721235275908839, 0.07706849617534317, 0.02837059317243984, 0.0350089390121866, 0.04822306764253881, 0.05686462034645956, 0.013974117537145503, 0.12803401099517941, 0.027478438896650914, 40.24538844823837, 66.66412442922592, 51.77704766392708, 29.365614652633667, 26.498362608253956, 46.72961890697479, 61.486180275678635, 69.53205093741417, 65.94464063644409, 63.52837689220905, 59.266947358846664, 2.1824594400823116, 0.2732623665360734, 0.6749142031185329, 4.732713969424367, 0.1359656103886664, 0.6052150775212795, 52.28741727769375, 67.95519635081291, 63.445472940802574, 58.044127374887466, 62.23025634884834, 55.70126049220562, 50.511441975831985, 46.84021197259426, 47.81519405543804, 45.957124158740044, 46.95800185203552, 49.32128883898258, 51.90925396978855, 52.697848454117775, 53.788526728749275, 53.177356123924255, 55.9320905059576, 51.1228633671999, 44.612543508410454, 40.17039567232132, 39.915049374103546, 40.52420608699322, 41.55896656215191, 41.4999595284462, 43.88101816177368, 46.07729271054268, 46.83168523013592, 47.56463170051575, 46.36414311826229, 44.817747697234154, 44.96722787618637, 40.65149545669556, 41.254724487662315, 39.00297291576862, 40.501574501395226, 38.358094319701195, 37.08163641393185, 36.453218534588814, 36.947974786162376, 38.866089060902596, 39.19959336519241, 39.03378166258335, 37.90285214781761, 38.94468404352665, 40.8813451230526, 46.57994493842125, 53.39473865926266, 50.09554669260979, 55.22106885910034, 43.750704154372215, 37.19162531197071, 37.13676005601883, 36.73631094396114, 38.4977900236845, 39.197039902210236, 36.644728258252144, 35.895153880119324, 35.804471746087074, 38.46848979592323, 37.88943126797676, 41.95980325341225, 40.342822819948196, 41.26342982053757, 42.53655530512333, 41.39197692275047, 43.11856247484684, 40.07834941148758, 38.23862873017788, 36.39777570962906, 38.61180290579796, 37.33635954558849, 36.69069059193134, 38.555744513869286, 37.07811780273914, 37.66268603503704, 37.68284775316715, 35.98987139761448, 37.73824118077755, 37.23895937204361, 39.254614412784576, 43.65711897611618, 49.996159225702286, 48.8364614546299, 37.96422265470028, 38.31343151628971, 38.25244098901749, 37.25977845489979, 38.45673322677612, 37.409851402044296, 37.93287053704262, 38.44615839421749, 39.70970459282398, 39.032189548015594, 39.512495175004005, 39.974903762340546, 39.22712668776512, 38.63638378679752, 40.704601407051086, 43.370952531695366, 43.425996378064156, 46.182189881801605, 48.458712324500084, 48.76672379672527, 46.24812014400959, 44.5754536986351, 41.50856986641884, 38.620367646217346, 41.63111709058285, 42.46646426618099, 44.040434807538986, 43.04155580699444, 44.1296312212944, 44.1743054240942, 43.37900049984455, 42.59623870253563, 44.62469145655632, 42.91209675371647, 45.04492990672588, 44.873486906290054, 44.1288598626852, 46.79692089557648, 52.77284502983093, 54.43574599921703, 56.492617428302765, 57.75699198246002, 66.52027934789658, 63.411027789115906, 76.44142538309097, 36.65993504226208, 0.5227133701555431, 0.42919756786432117, 2.055866145528853, 0.22391281148884445, 0.29881412512622774, 27.166114076972008, 80.2972760796547, 65.2091521024704, 76.73423767089844, 70.99285215139389, 66.89930140972137, 39.403110444545746, 32.432262897491455, 50.08205361664295, 78.76204445958138, 37.50130869448185, 0.8695372065994889, 0.03640420633018948, 0.11991615479928441, 0.06072851574572269, 0.012058267948305001, 0.023051498319546226, 0.3158345102565363, 0.15762182098114863, 0.2670581603888422, 0.2108089771354571, 0.10438094817800447, 0.1421393291093409, 0.2295707821031101, 0.2588080312125385, 47.87850245833397, 76.64755672216415, 62.60970778763294, 40.42837902903557, 32.898965254426, 53.75267565250397, 66.84611186385155, 74.15171384811401, 71.19383096694946, 68.80287006497383, 67.37100809812546, 2.5706615718081594, 0.5378857185132802, 3.5331076523289084, 5.694343568757176, 0.39369378704577684, 0.6774535949807614, 56.69269949197769, 69.31525737047195, 65.63159823417664, 61.90707229077816, 65.71177393198013, 57.540908977389336, 52.25898340344429, 48.218333423137665, 50.65545044839382, 49.63672511279583, 49.46809396147728, 51.22212544083595, 55.285171419382095, 55.14944650232792, 57.252002879977226, 54.41017337143421, 59.262076020240784, 51.89081355929375, 48.427599593997, 42.23450191318989, 41.798562705516815, 44.10774439573288, 44.940443113446236, 43.5013273358345, 48.25411610305309, 48.0520885437727, 49.079067036509514, 50.2792364358902, 50.371476486325264, 47.90943659842014, 47.20137879252434, 44.08703550696373, 42.87884473800659, 39.43041577935219, 42.357022538781166, 42.12977573275566, 39.59919512271881, 39.88930195569992, 39.897520914673805, 38.957740142941475, 39.77863289415836, 41.232746466994286, 39.201257675886154, 40.39404407143593, 43.46484549343586, 47.500848323106766, 55.77652685344219, 54.283032193779945, 57.56752274930477, 45.09047046303749, 37.94092230498791, 37.6848578453064, 35.09312331676483, 38.09520922601223, 41.018468365073204, 37.189459428191185, 35.72622634470463, 37.783736139535904, 40.43215602636337, 39.304159954190254, 44.13276605308056, 42.838905081152916, 42.76792109012604, 44.92195710539818, 44.034130945801735, 45.45400835573673, 42.635414600372314, 40.30324034392834, 38.488548919558525, 41.457853987812996, 37.707717418670654, 37.45441921055317, 39.354146271944046, 37.32274107635021, 37.05300495028496, 38.23018938302994, 37.68782548606396, 39.51984778046608, 37.85090893507004, 39.027002826333046, 45.66655375063419, 53.709000796079636, 52.675133273005486, 40.71218580007553, 41.30424723029137, 41.64191231131554, 40.21601602435112, 40.559149011969566, 38.5470087826252, 39.57376308739185, 41.68761245906353, 40.6005933880806, 41.80178113281727, 40.284982323646545, 42.16804727911949, 41.684865206480026, 42.25728929042816, 43.86227376759052, 45.55821396410465, 46.14295318722725, 49.03087042272091, 50.37465311586857, 51.39147475361824, 49.317534640431404, 47.157453149557114, 44.435210824012756, 40.6896910071373, 43.46352316439152, 44.81517903506756, 47.52403847873211, 44.72387373447418, 45.87091438472271, 47.11647994816303, 44.474956691265106, 45.20745858550072, 46.32671132683754, 44.37528043985367, 49.54141102731228, 47.656719759106636, 46.3124430924654, 48.771218955516815, 56.35642133653164, 56.84643164277077, 59.48061369359493, 62.78819181025028, 67.89151936769485, 65.44192001223564, 78.17087978124619, 38.91683153808117, 0.5656963074579835, 3.690333003178239, 7.01126835308969, 1.975216898135841, 0.37508689798414707, 30.231422893702984, 87.17084884643555, 70.37461012601852, 80.98288848996162, 76.01356834173203, 78.81135821342468, 44.57571968436241, 36.850225031375885, 60.44277146458626, 90.53765058517456, 47.71300233900547, 1.3248416595160961, 0.26267236447893083, 0.23899035790236667, 0.12128606293117628, 0.11722870447556488, 0.14407179260160774], [0.059678250618162565, 0.014867146619508276, 0.028141802031314, 0.018734850164037198, 0.1071638090070337, 0.031521279088337906, 0.1814483682392165, 0.18249307468067855, 19.83234230428934, 70.78144669532776, 50.86274832487106, 40.172922536730766, 38.703674376010895, 47.03033857047558, 50.09395457804203, 61.21525101363659, 60.598623901605606, 56.76361508667469, 61.39020122587681, 5.219583744183183, 0.4388037195894867, 0.36012959433719516, 2.551540997810662, 0.6358255818486214, 0.16453647025628015, 42.32023671269417, 65.97456783056259, 61.05321250855923, 57.65565901994705, 50.178313851356506, 48.74254569411278, 45.15738867223263, 42.60783948004246, 45.4532939940691, 46.604020446538925, 47.61017605662346, 47.89030462503433, 49.954722449183464, 51.78162261843681, 51.935882940888405, 50.85741341114044, 49.104537069797516, 40.263885855674744, 38.611954897642136, 39.16407287120819, 39.20997440814972, 41.88535764813423, 43.03518354892731, 45.63275836408138, 46.59652344882488, 45.0255623459816, 49.81899373233318, 46.15504413843155, 43.74927543103695, 42.12141238152981, 40.50314001739025, 38.831351324915886, 39.8746195435524, 37.51307666301727, 36.06802940368652, 35.06315052509308, 36.09770581126213, 35.62931254506111, 36.340421587228775, 33.991000056266785, 36.730729043483734, 37.72195525467396, 36.47700145840645, 37.16919131577015, 38.212907910346985, 41.94015070796013, 49.81765620410442, 48.89805614948273, 49.885144382715225, 45.60874365270138, 36.877518966794014, 38.47057968378067, 39.28341306746006, 37.99035765230656, 39.83341835439205, 36.79411344230175, 36.61306835711002, 34.62176240980625, 35.81952653825283, 37.28222765028477, 38.98420572280884, 37.939075604081154, 39.46979686617851, 41.98548227548599, 40.484851598739624, 41.12031430006027, 37.60804496705532, 35.78205294907093, 36.45932100713253, 34.85840231180191, 37.15407192707062, 37.31828011572361, 37.259630262851715, 37.77540698647499, 36.88440419733524, 37.14894600212574, 36.708511635661125, 35.63605718314648, 36.32882080972195, 38.52603390812874, 43.2330047339201, 48.66966560482979, 45.6049894541502, 35.21681047976017, 35.5685044080019, 34.361757561564445, 35.80133691430092, 36.113410368561745, 37.15501427650452, 36.8385786563158, 36.98086582124233, 36.12199030816555, 38.17397139966488, 37.772967517375946, 37.89142236113548, 37.684367671608925, 37.140863835811615, 39.544531255960464, 40.892448127269745, 43.014292269945145, 48.06551322340965, 49.93229605257511, 49.022719860076904, 48.96681725978851, 49.1911344230175, 47.88017816841602, 43.31204429268837, 42.44274593889713, 39.712132662534714, 38.944980427622795, 39.65328522026539, 41.80530734360218, 42.021895721554756, 43.04076164960861, 40.35283148288727, 42.98537202179432, 41.40418566763401, 42.54883624613285, 45.339163318276405, 48.74602250754833, 50.917742773890495, 55.01948207616806, 54.718051850795746, 58.68370905518532, 59.60122302174568, 64.99624952673912, 59.47809062898159, 67.81027212738991, 30.086983144283295, 0.3767987061291933, 0.29063185793347657, 0.5559344531502575, 0.5290691822301596, 0.2203951947740279, 32.95629657804966, 71.24661773443222, 65.02540916204453, 70.6138376891613, 68.4882241487503, 51.02700591087341, 18.313206620514393, 16.792946197092533, 45.04690960049629, 68.14604490995407, 25.675590857863426, 0.7323795882984996, 0.1227080995158758, 0.0589151335589122, 0.04781390307471156, 0.08560453774407506, 0.032862347361515276, 0.04549150777165778, 0.0648529754835181, 0.10230681611574255, 0.03016677794221323, 0.07416660228045657, 0.037886913487454876, 0.33442741725593805, 0.33352757804095745, 27.07709815353155, 77.56573185324669, 57.08744890987873, 42.95239359140396, 25.580025985836983, 43.48305031657219, 56.79755486547947, 68.33776742219925, 66.63159817457199, 60.547387450933456, 67.47534289956093, 5.556778125464916, 0.5232148244976997, 0.4931347182719037, 3.985001491382718, 0.45314922637771815, 0.18268695333972573, 46.71387255191803, 68.37063565850258, 62.89652019739151, 59.99337337911129, 54.847681894898415, 50.60861796140671, 47.77422085404396, 44.55138199031353, 48.62471401691437, 47.52658054232597, 49.52961266040802, 50.15279442071915, 54.32270206511021, 55.080867782235146, 55.18642231822014, 52.34330467879772, 51.16387456655502, 44.292372688651085, 40.355582535266876, 40.75219765305519, 41.11971393227577, 42.85627394914627, 43.42932499945164, 47.233677059412, 47.8456000238657, 45.97770385444164, 50.71299836039543, 46.739741563797, 46.813073828816414, 44.176608100533485, 41.40643894672394, 40.40767394006252, 40.77274315059185, 37.46819727122784, 37.67493277788162, 36.650534346699715, 37.7610057592392, 37.21685215830803, 38.751035034656525, 36.659574061632156, 38.44999618828297, 39.41802844405174, 39.49214726686478, 38.863885179162025, 38.24956834316254, 45.0742719322443, 53.16708527505398, 52.83306419849396, 50.99667213857174, 46.96220822632313, 36.84411495923996, 37.91957885026932, 38.46839100122452, 37.82690942287445, 39.40039739012718, 38.31392548978329, 37.90045067667961, 34.913940131664276, 37.961483001708984, 38.32967944443226, 41.10578007996082, 41.56337812542915, 42.98915281891823, 42.77536869049072, 43.58807288110256, 42.04657919704914, 39.77389834821224, 38.17850075662136, 37.99443483352661, 35.33793278038502, 38.172329887747765, 37.27232538163662, 37.14876361191273, 37.071825340390205, 37.38664984703064, 36.75327703356743, 38.1290540099144, 36.90054573118687, 37.816820964217186, 37.923735827207565, 44.50722075998783, 52.89671838283539, 47.15916305780411, 38.50616857409477, 36.98871240019798, 35.09222276508808, 37.10085578262806, 38.33688385784626, 39.398068115115166, 39.41399686038494, 38.37131381034851, 38.05020824074745, 40.60993708670139, 38.568606823682785, 40.10945454239845, 38.10919627547264, 40.09395897388458, 41.30924016237259, 42.9651191085577, 45.19743852317333, 48.72490704059601, 51.81943438947201, 51.48512452840805, 50.93451127409935, 51.54660522937775, 48.75351570546627, 45.25367550551891, 42.58459232747555, 42.589383870363235, 39.747687354683876, 42.339098900556564, 43.57042282819748, 43.71605381369591, 44.71140280365944, 43.375865668058395, 44.66487430036068, 44.48763281106949, 45.65991550683975, 48.1392140686512, 50.751718282699585, 53.11792351305485, 58.00517186522484, 57.49142423272133, 61.62241816520691, 63.582668378949165, 66.92424327135086, 64.57286104559898, 72.91915878653526, 36.97302304208279, 0.37170561379753053, 0.2264609161647968, 3.151384647935629, 0.7843114016577601, 0.24981329042930156, 34.91143986582756, 79.07433450222015, 68.95799294114113, 75.42986646294594, 73.20589900016785, 60.69693602621555, 28.10442052781582, 23.717899806797504, 49.17240522801876, 78.41218963265419, 33.18810693919659, 0.6169738434255123, 0.05268315253488254, 0.02622669180709636, 0.034436613277648576, 0.07173401289037429, 0.0009894555182654585, 0.22980871464824304, 0.1559585938230157, 0.27679427701514214, 0.1241397914418485, 0.19601309060817584, 0.11218027459108271, 0.49361138488166034, 0.4625751549610868, 32.92990319430828, 86.43758699297905, 63.25810119509697, 54.969252571463585, 52.094946205616, 61.294928938150406, 64.02657195925713, 72.35714614391327, 71.43408447504044, 65.46365484595299, 73.45729351043701, 6.675559217110276, 0.7298627577256411, 1.8456746055744588, 12.616440206766129, 1.1729516973719, 0.28953858534805477, 49.85438123345375, 69.77841451764107, 66.06385543942451, 61.65145620703697, 55.87901875376701, 53.45355570316315, 51.351569294929504, 45.16234740614891, 51.726844757795334, 51.271074414253235, 50.900807082653046, 52.01472871005535, 56.486913934350014, 57.8389535844326, 56.90472051501274, 52.19097085297108, 52.052608877420425, 46.37961968779564, 43.48716929554939, 42.47985854744911, 43.66275407373905, 46.29255495965481, 47.207473665475845, 51.06300137937069, 50.38622349500656, 48.84756065905094, 56.09629489481449, 50.578234791755676, 49.33835752308369, 46.29028648138046, 44.74351108074188, 43.628396317362785, 44.94265079498291, 40.20617075264454, 40.8890625089407, 38.95786553621292, 40.39086364209652, 39.38045226037502, 41.38132989406586, 37.82739579677582, 41.11165076494217, 41.42747461795807, 41.19634062051773, 42.245707511901855, 42.21423380076885, 46.859518736600876, 54.14444223046303, 55.7399196177721, 53.6785302311182, 49.9579256772995, 39.51685734093189, 37.731701731681824, 39.40661385655403, 37.71184779703617, 40.83969935774803, 38.73135969042778, 38.726811334490776, 35.57696655392647, 39.24221567809582, 39.10166881978512, 44.85631562769413, 42.611388489603996, 45.329724624753, 46.403995379805565, 45.86671561002731, 45.151563584804535, 41.55742384493351, 40.20246595144272, 39.97736983001232, 36.64402149617672, 39.12278428673744, 37.75485388934612, 39.08266983926296, 37.62550503015518, 38.53275574743748, 36.835132241249084, 36.64043068885803, 37.476788610219955, 38.19291718304157, 37.51981370151043, 45.70931665599346, 55.086791664361954, 50.532021671533585, 41.157996878027916, 39.81460176408291, 37.61837661266327, 39.85874019563198, 39.45452928543091, 41.157696694135666, 41.20680905878544, 41.54050335288048, 39.6212225407362, 42.35537342727184, 42.41555079817772, 41.82740695774555, 40.09232126176357, 43.22686806321144, 43.246338218450546, 46.892189383506775, 48.18795785307884, 51.77738584578037, 54.87557999789715, 54.48499895632267, 53.77739332616329, 52.791156247258186, 51.92767918109894, 48.571836054325104, 45.45909248292446, 45.43867237865925, 42.61471711099148, 43.92001926898956, 46.71192705631256, 46.05705499649048, 48.08465659618378, 45.54966822266579, 47.5848276168108, 46.6770601272583, 46.92810505628586, 51.095934212207794, 53.71886886656284, 55.45575186610222, 59.36238683760166, 60.46530805528164, 63.793652057647705, 65.64942687749863, 68.86074855923653, 66.392872184515, 73.60845699906349, 42.743993774056435, 0.24263724189950153, 1.5801398665644228, 5.324516063556075, 1.900565035175532, 0.2897293766727671, 37.50209145247936, 84.39409464597702, 75.45191287994385, 82.52173751592636, 79.5438601076603, 65.54063871502876, 27.321896217763424, 27.847138233482838, 61.10548250377178, 88.11501458287239, 41.318815648555756, 0.8759076241403818, 0.23582702764542773, 0.13400969502981752, 0.13351022964343429, 0.28980020724702626, 0.09270565162296407], [0.022862684818392154, 0.2137396440957673, 0.1034951355541125, 0.024993259066832252, 0.03393629071069881, 0.02818358309014002, 0.2534069772809744, 0.22253710718359798, 11.354756858199835, 64.32370841503143, 49.53601911664009, 37.55746588110924, 29.153692424297333, 40.12531869113445, 43.84395495057106, 56.87204606831074, 62.997849360108376, 54.194827526807785, 65.60373052954674, 9.441524371504784, 0.5456343933474272, 0.8959732786752284, 5.102580422535539, 0.4319492733338848, 0.39700127206742764, 41.62520460784435, 64.38286364078522, 61.660891100764275, 56.33325017988682, 53.064695969223976, 51.45795218646526, 50.058749467134476, 47.54849396646023, 48.26996125280857, 47.538295313715935, 49.17750835418701, 48.75449225306511, 51.317405328154564, 51.907962039113045, 51.41931585967541, 48.94772708415985, 42.63782747089863, 38.75020667910576, 40.70207454264164, 39.77899007499218, 39.62089575827122, 41.732738837599754, 43.90318617224693, 43.63748162984848, 45.44947899878025, 44.14164997637272, 44.78449188172817, 46.25641509890556, 46.36676877737045, 42.10043750703335, 39.57146801054478, 37.143702283501625, 38.82863827049732, 38.01111973822117, 36.4090421050787, 36.2022989988327, 36.49747475981712, 36.354416236281395, 37.59093068540096, 37.27241277694702, 36.44671708345413, 38.68856258690357, 36.75909072160721, 37.813648134469986, 36.1142273247242, 37.31548346579075, 46.7430853843689, 49.99405033886433, 49.87361200153828, 47.64388404786587, 38.79300378262997, 36.50727063417435, 39.851402789354324, 37.09869369864464, 38.14940191805363, 38.48151929676533, 36.75491854548454, 35.840634405612946, 36.38990633189678, 37.19765558838844, 39.1218077391386, 40.76890915632248, 41.343400329351425, 40.16579031944275, 40.39258494973183, 38.99456776678562, 37.18195483088493, 35.71931831538677, 37.37433850765228, 36.074025481939316, 37.574074789881706, 37.67452999949455, 36.30773954093456, 37.46322713792324, 38.58110435307026, 37.44257144629955, 39.255188181996346, 38.53275954723358, 37.88204066455364, 37.83498398959637, 48.239144906401634, 47.36614555120468, 52.196431159973145, 44.88475330173969, 41.28570042550564, 37.48743183910847, 37.06249304115772, 37.674951776862144, 36.69230170547962, 35.901560336351395, 37.84340053796768, 35.900796577334404, 37.62231320142746, 37.49754309654236, 37.67587512731552, 37.85965986549854, 38.01287904381752, 38.658749386668205, 40.04196256399155, 42.34057702124119, 45.3791219741106, 47.950212210416794, 51.252603605389595, 48.47819767892361, 48.106212839484215, 51.95342279970646, 48.98540586233139, 49.76025648415089, 46.920908242464066, 44.10701483488083, 42.43048399686813, 41.190435737371445, 37.904774844646454, 40.50620265305042, 40.38387581706047, 42.08220228552818, 42.2535464912653, 45.240144431591034, 47.422564923763275, 50.832239761948586, 56.3557867705822, 57.2954535484314, 54.32804077863693, 59.99389015138149, 57.5731198489666, 65.76435551047325, 60.71715094149113, 71.50420591235161, 28.96501734852791, 1.5647096070460975, 0.29184645682107657, 0.9971712296828628, 0.0930577413237188, 0.11502946857945062, 38.61130133271217, 73.544582426548, 61.84242635965347, 70.00608310103416, 66.38083443045616, 53.306815177202225, 37.587818652391434, 36.69565312564373, 43.02844651043415, 62.370856404304504, 20.436650477349758, 0.6293683033436537, 0.012048363987560151, 0.022674700667266734, 0.016014038446883205, 0.03471046577033121, 0.02490954109816812, 0.03094125542702386, 0.10093911216245033, 0.04156604751187842, 0.05219771745032631, 0.0361741850792896, 0.14168163179419935, 0.2571607899153605, 0.20762471831403673, 16.281411945819855, 74.38362300395966, 57.14449904859066, 42.945124581456184, 37.872541174292564, 50.77441826462746, 49.91426981985569, 64.57748159766197, 67.57885694503784, 60.195735320448875, 68.74185293912888, 9.652659092098475, 0.45881579106207937, 0.5701586930081248, 6.045871255919337, 0.28946552833076566, 0.36990391672588885, 48.03325295448303, 66.23789370059967, 64.39156517386436, 57.11779028177261, 54.74822223186493, 52.24507994949818, 52.05300025641918, 48.74603010714054, 50.8023239672184, 50.255480110645294, 52.3773318529129, 51.78248517215252, 54.779243767261505, 53.66433419287205, 54.04961071908474, 53.02771255373955, 46.1783292889595, 39.799892753362656, 42.73447148501873, 40.565441474318504, 41.42403580248356, 44.582342728972435, 46.803589537739754, 46.943562626838684, 47.320992574095726, 46.4372093975544, 48.04203808307648, 48.01724061369896, 47.68810227513313, 43.97931128740311, 41.998450979590416, 40.21819330751896, 41.16320639848709, 40.06315402686596, 37.40566782653332, 37.15386673808098, 38.20098415017128, 37.7825316041708, 39.060266241431236, 37.57670804858208, 38.96677225828171, 38.891642689704895, 40.09659223258495, 38.62209655344486, 39.475785344839096, 39.303525388240814, 49.92772489786148, 51.492872312664986, 50.9806028008461, 51.619090139865875, 39.0516597032547, 37.029206827282906, 40.56147448718548, 37.432008013129234, 38.48465792834759, 38.16680118441582, 38.57880927622318, 35.82086406648159, 37.343822345137596, 37.8046578168869, 40.62544405460358, 41.75813667476177, 42.23840810358524, 40.46194262802601, 42.93696641921997, 40.20794905722141, 37.38978087902069, 35.93333423137665, 38.12938079237938, 37.33804665505886, 37.65515863895416, 37.20457501709461, 39.432015493512154, 36.971195340156555, 37.63419896364212, 36.99097327888012, 39.46838714182377, 36.34408459067345, 38.80515553057194, 39.26469907164574, 50.46470828354359, 50.70995472371578, 53.70711609721184, 46.004074439406395, 42.03591696918011, 39.39347796142101, 40.10017164051533, 37.94275760650635, 39.26004812121391, 38.074291348457336, 39.12098318338394, 37.274818047881126, 38.8385671377182, 39.421486258506775, 38.87319087982178, 39.25098940730095, 39.11546967923641, 40.038094371557236, 41.36412441730499, 44.23070579767227, 48.65508958697319, 49.721365571022034, 52.76405610144138, 50.73152236640453, 52.04630881547928, 53.58312115073204, 53.17479886114597, 52.1477709710598, 48.60897906124592, 46.38523578643799, 45.430651009082794, 42.9387903213501, 40.949266478419304, 42.135551422834396, 43.531873896718025, 43.6121141910553, 45.265724658966064, 48.40811423957348, 50.66431537270546, 52.424677312374115, 60.080039128661156, 60.59288240969181, 57.27376811206341, 61.6056040674448, 60.7950771600008, 69.51798409223557, 63.39234419167042, 76.24563708901405, 39.38442304730415, 1.332684438675642, 0.9478718438185751, 2.512380061671138, 0.6558728904929012, 0.06547658733325079, 41.34309634566307, 77.08408489823341, 68.20791319012642, 75.2192285656929, 71.20700865983963, 66.66237652301788, 27.135428823530674, 29.91503857076168, 49.807487949728966, 71.83269828557968, 26.974902637302876, 0.793366078287363, 0.030317422788357362, 0.06230962055269629, 0.0443478359375149, 0.14551990083418787, 0.07347073493292555, 0.12261105628567748, 0.2650662063388154, 0.2207270238432102, 0.1781050523277372, 0.14325501455459744, 0.21326382353436202, 0.42959236074239016, 0.4004455200629309, 18.086033910512924, 83.80508825182915, 63.154594749212265, 53.9874916523695, 40.49624718725681, 52.318070232868195, 59.79925699532032, 69.54700693488121, 72.51368254423141, 63.66040080785751, 74.58539217710495, 11.86095429584384, 1.282556934747845, 2.227978860028088, 12.990605179220438, 0.9619613096583635, 1.1293021333403885, 51.1385603249073, 66.77696317434311, 67.08117485046387, 59.01700057089329, 57.64141358435154, 54.829408675432205, 53.916838243603706, 51.43705330789089, 53.02953265607357, 53.818712309002876, 52.764177694916725, 55.12781046330929, 57.50643342733383, 56.212124079465866, 57.36503541469574, 54.482430294156075, 46.99212782084942, 42.04975202679634, 45.14318883419037, 43.21107991039753, 43.727001026272774, 46.700706258416176, 48.87746885418892, 48.95657680928707, 50.42426325380802, 49.91711966693401, 51.321839690208435, 50.725640282034874, 51.93174496293068, 46.37870393693447, 43.804737254977226, 42.508733198046684, 43.6918681114912, 41.55627250671387, 40.01150339841843, 39.26457367837429, 39.00499440729618, 39.87860172986984, 42.195284217596054, 41.066987961530685, 41.44922465085983, 41.50492586195469, 42.19184920191765, 40.28762698173523, 39.909604266285896, 41.84100262820721, 52.470065876841545, 53.85441139340401, 56.02284103631973, 53.37009318172932, 40.733506456017494, 36.74260340631008, 41.763995960354805, 37.29692906141281, 37.425149381160736, 38.75423066318035, 38.51558066904545, 37.514896765351295, 37.191955894231796, 40.710293501615524, 43.89127001166344, 44.21443127095699, 45.435864329338074, 43.60692746937275, 45.19108906388283, 41.046279072761536, 39.99962143599987, 38.017290607094765, 40.42877420783043, 38.63509565591812, 38.38898666203022, 38.26385177671909, 38.20156171917915, 38.087856620550156, 38.07066634297371, 37.872484177351, 40.04494920372963, 37.71644555032253, 39.030825421214104, 39.86168123781681, 53.93472008407116, 54.445883855223656, 56.85905836522579, 48.14443878829479, 44.97820548713207, 41.19392015039921, 41.272260546684265, 40.62695637345314, 40.64022906124592, 39.51241917908192, 42.22582317888737, 39.497839361429214, 41.554247215390205, 40.75011156499386, 40.364637449383736, 42.320818081498146, 42.6805105805397, 43.92149738967419, 46.03178635239601, 46.50570072233677, 51.75353452563286, 52.24059998989105, 54.773403480648994, 52.61283181607723, 52.81779661774635, 56.80613860487938, 52.50119760632515, 55.72334110736847, 50.683819726109505, 48.33371423184872, 46.6648855805397, 45.52384100854397, 41.85166485607624, 44.06764134764671, 45.88114723563194, 47.28699579834938, 48.66092227399349, 50.949341878294945, 53.95826742053032, 55.14079436659813, 61.57332479953766, 62.043431773781776, 60.16983591020107, 64.289890229702, 63.21374997496605, 72.65945792198181, 67.1222810447216, 77.02074229717255, 46.03890337049961, 1.4621276990510523, 1.0269662621431053, 5.101563027128577, 2.01788742095232, 0.1614313095342368, 45.38123846054077, 83.96229341626167, 73.66027101874352, 81.07700183987617, 78.53762090206146, 72.35941842198372, 50.122069269418716, 51.56547121703625, 59.7697401791811, 83.85709226131439, 35.670836716890335, 1.0304434318095446, 0.13765668292762712, 0.178082876955159, 0.14699968392960727, 0.274816156597808, 0.10130004826351069], [0.07395373948384076, 0.05751050033723004, 0.019954258168581873, 0.03091171423875494, 0.08498125243932009, 0.06273326071095653, 0.20866476406808943, 0.13966760627226904, 5.649955300614238, 57.349707037210464, 53.17417569458485, 37.43556462228298, 13.111480493098497, 19.08815983682871, 42.22586877644062, 56.05457693338394, 65.59933796525002, 54.90330331027508, 65.20364239811897, 16.271557174623013, 0.40704606275539845, 0.3392723057186231, 1.2773284153081477, 0.20325795107055455, 5.703275939449668, 60.98599411547184, 58.967854008078575, 60.91680362820625, 59.74357098340988, 60.4630471765995, 55.13846509158611, 51.49758405983448, 46.813366413116455, 50.20342670381069, 49.083140417933464, 50.90741112828255, 49.43503953516483, 52.24153853952885, 50.092852637171745, 50.4699482023716, 44.27344970405102, 40.750837326049805, 38.11356224119663, 38.66495445370674, 39.65251766145229, 40.81989102065563, 41.57828472554684, 44.20007184147835, 44.888211116194725, 48.036942556500435, 45.590295642614365, 46.1882733553648, 45.30908413231373, 44.32387299835682, 39.64803010225296, 37.6724249124527, 38.406860902905464, 38.578364700078964, 37.292661890387535, 37.986994832754135, 37.41530790925026, 35.27129575610161, 36.18703901767731, 35.49671486020088, 36.57219395041466, 38.542186841368675, 37.8013975918293, 37.57111854851246, 36.92948117852211, 37.86795102059841, 36.56850054860115, 46.93146027624607, 49.82066944241524, 51.166561022400856, 46.277503967285156, 42.444961220026016, 35.08088797330856, 38.262609243392944, 38.00844468176365, 40.09618565440178, 38.41503046452999, 37.715358808636665, 35.53234934806824, 35.60558281838894, 36.20286136865616, 37.42690488696098, 38.44964660704136, 41.30634471774101, 40.351585149765015, 41.87233954668045, 38.34248475730419, 37.00577728450298, 34.205483347177505, 35.35315856337547, 35.87812699377537, 38.34753468632698, 38.052096739411354, 39.21962209045887, 37.72101290524006, 37.87631057202816, 35.93480095267296, 39.23281878232956, 36.74006514251232, 37.98931650817394, 41.35211706161499, 47.606254667043686, 46.34445637464523, 44.734551161527634, 42.95755751430988, 39.95378829538822, 37.364136055111885, 35.84080159664154, 36.208500266075134, 36.09374642372131, 35.969124510884285, 35.56355707347393, 36.29458084702492, 35.359257236123085, 38.29719118773937, 38.645457699894905, 38.48746977746487, 38.184386640787125, 39.52232524752617, 38.749765902757645, 39.493560791015625, 42.819807305932045, 46.850479021668434, 49.073287546634674, 48.6538128554821, 51.00810572504997, 52.59439140558243, 52.85382628440857, 51.92744359374046, 50.679567754268646, 52.14628145098686, 49.838589280843735, 45.712405890226364, 43.024753108620644, 41.945276632905006, 39.85285051167011, 44.42301347851753, 40.2315191924572, 47.97921985387802, 46.60684369504452, 53.61727371811867, 55.674114748835564, 56.435780078172684, 56.156814247369766, 59.257086887955666, 58.55252869427204, 66.27258583903313, 59.57476884126663, 69.70982819795609, 27.962161861360073, 3.1844868091866374, 0.13718948612222448, 2.185468878597021, 0.339499848196283, 0.22604706493439153, 46.19146518409252, 70.60126796364784, 64.5135310292244, 69.31245312094688, 65.83654403686523, 48.395871296525, 37.53554105758667, 35.260960310697556, 50.469062849879265, 63.340701162815094, 12.407604362815619, 0.5667483760043979, 0.07310769113246351, 0.05969195808575023, 0.05797005302156322, 0.0794028771633748, 0.027570454076339956, 0.0653524705558084, 0.06670158370980062, 0.031317915781983174, 0.032247522540274076, 0.055942078834050335, 0.09594240997103043, 0.2194423513719812, 0.10160501158679835, 7.733227238059044, 67.68107905983925, 59.533970430493355, 43.77534583210945, 17.696695402264595, 27.099972926080227, 48.344338461756706, 63.587984293699265, 70.12937128543854, 59.698201417922974, 72.38070487976074, 16.050868816673756, 0.536707128630951, 0.3663743514334783, 1.8716424121521413, 0.046993150826892816, 5.935817761346698, 64.71810445189476, 58.34681913256645, 62.16654896736145, 61.30175717175007, 61.35089613497257, 55.73855169117451, 55.5350536108017, 50.63009440898895, 53.698821142315865, 53.79603132605553, 52.849714905023575, 50.028700679540634, 53.45513641834259, 54.060968309640884, 52.44856283068657, 45.92039532959461, 43.26492682099342, 39.653376415371895, 42.10842847824097, 40.043417885899544, 41.95538409054279, 44.25355017185211, 46.99987180531025, 47.23223693668842, 50.74940800666809, 48.16191405057907, 49.564278200268745, 47.307366505265236, 47.19393119215965, 42.064692825078964, 40.83472542464733, 39.181373342871666, 40.864553824067116, 38.020634427666664, 39.29655276238918, 39.9649178981781, 36.80294416844845, 38.11475917696953, 37.92851597070694, 36.552381813526154, 39.67243239283562, 40.12506790459156, 38.01341861486435, 38.67551028728485, 38.28484185039997, 38.917720690369606, 48.77146974205971, 53.62679600715637, 54.02850665152073, 49.14698839187622, 41.35387636721134, 35.48162207007408, 39.02036838233471, 37.58714608848095, 40.68026751279831, 37.426426112651825, 37.90863923728466, 36.57663971185684, 35.32464109361172, 37.81120486557484, 39.154995158314705, 41.44214943051338, 42.377541437745094, 42.40912154316902, 42.64855429530144, 39.838198497891426, 37.156101018190384, 35.837434977293015, 35.78556016087532, 36.66938133537769, 39.46145251393318, 38.129316195845604, 37.78678737580776, 37.61037424206734, 37.79252506792545, 36.11300379037857, 38.86346720159054, 36.8555523455143, 38.19353275001049, 42.96768397092819, 52.46639907360077, 48.83280985057354, 48.45954068005085, 45.858853831887245, 42.56729565560818, 40.29569014906883, 38.529624715447426, 38.781699389219284, 37.96536259353161, 37.9436581581831, 38.48943427205086, 36.46561346948147, 38.54222483932972, 40.52597299218178, 39.739350602030754, 38.596330136060715, 39.411925971508026, 40.9251643717289, 42.11178369820118, 41.71333707869053, 44.801868349313736, 48.38666059076786, 51.10911950469017, 49.72123637795448, 53.15324641764164, 53.54585275053978, 56.16076223552227, 54.67190332710743, 52.96501211822033, 54.2425187677145, 51.34913742542267, 48.21584455668926, 45.436730682849884, 44.45544853806496, 43.40132810175419, 46.06034182012081, 43.09253387153149, 49.400533586740494, 49.19218696653843, 55.71656987071037, 57.200413048267365, 57.64868639409542, 60.23911379277706, 61.99387103319168, 62.16116465628147, 68.67019638419151, 63.643852695822716, 72.06151440739632, 37.37714655697346, 2.9385965410619974, 0.16566098725888878, 2.2987408004701138, 0.6086790666449815, 0.2401296139578335, 49.68966007232666, 76.36090010404587, 69.68775138258934, 76.13391548395157, 71.86253428459167, 55.557518005371094, 36.08626842498779, 39.88746665418148, 57.85067215561867, 72.48901426792145, 17.938045151531696, 0.533613619627431, 0.045356845075730234, 0.11466790165286511, 0.051966764804092236, 0.1787489841808565, 0.07776030397508293, 0.17962488171178848, 0.1331924123223871, 0.19724576821317896, 0.18292840366484597, 0.19978069234639406, 0.18187811627285555, 0.4961477784672752, 0.3814553265692666, 9.787608850747347, 79.65763360261917, 67.53262862563133, 52.22376689314842, 21.68296840041876, 30.77318262308836, 58.87762404978275, 69.45117607712746, 75.12646794319153, 64.06120330095291, 77.5612784922123, 18.951338678598404, 0.666815887670964, 2.5819220300763845, 10.704917628318071, 0.29278503614477813, 7.1896569058299065, 66.39805510640144, 59.09331567585468, 65.69377809762955, 63.53910371661186, 65.52150294184685, 58.19666638970375, 57.54983089864254, 51.604255735874176, 56.8306814879179, 54.9614629894495, 56.264705657958984, 51.155986189842224, 56.98002107441425, 55.029638931155205, 54.39894117414951, 48.221377059817314, 45.25436706840992, 41.099350824952126, 42.82993756234646, 42.40563713014126, 44.52347628772259, 45.865902453660965, 49.41269673407078, 49.28656630218029, 53.64696532487869, 49.420026540756226, 51.434146463871, 49.15476277470589, 48.6460916697979, 45.117057636380196, 42.51901164650917, 41.24985694885254, 43.49621661007404, 41.613896414637566, 41.945189237594604, 42.54888564348221, 38.1002439558506, 40.18130488693714, 39.19596455991268, 38.50776068866253, 41.40801586210728, 41.02776266634464, 40.900226309895515, 40.289534479379654, 41.191739067435265, 41.4308450371027, 50.93302175402641, 56.62424996495247, 57.98253647983074, 50.29977813363075, 43.408160135149956, 35.874061211943626, 38.22667837142944, 39.32695113122463, 40.95984511077404, 38.48778896033764, 38.44738572835922, 36.013468131423, 37.671478763222694, 40.76710045337677, 41.28024771809578, 43.469276055693626, 46.60780504345894, 46.18785917758942, 44.63904328644276, 40.692647248506546, 38.405454978346825, 36.053024008870125, 38.07870291173458, 38.36474396288395, 38.63223820924759, 39.7096361964941, 38.42872492969036, 38.68929214775562, 38.8664386421442, 35.4722023755312, 39.863554537296295, 38.117244243621826, 38.41582462191582, 44.12232421338558, 56.86753571033478, 53.17151963710785, 50.4524577409029, 46.81148171424866, 44.27951417863369, 42.26304978132248, 40.10737985372543, 41.83572091162205, 38.54764334857464, 40.06533890962601, 40.07020264863968, 39.8795934766531, 39.06794182956219, 43.582114800810814, 42.23761774599552, 42.31781244277954, 42.34885297715664, 42.937665581703186, 44.8053527623415, 43.42660054564476, 47.228748723864555, 50.188413709402084, 53.84121090173721, 51.90298430621624, 54.67551693320274, 56.63865119218826, 57.28314220905304, 56.781379133462906, 55.1329629868269, 55.84708906710148, 54.11847062408924, 51.17299407720566, 48.46158877015114, 47.12536007165909, 46.04893483221531, 47.64565855264664, 45.98353274166584, 51.02059945464134, 52.81248830258846, 57.067955955863, 61.695294454693794, 61.7435784637928, 62.654275596141815, 64.01147916913033, 64.01549935340881, 69.21004861593246, 65.71521654725075, 73.00815761089325, 47.99535758793354, 3.062062128446996, 0.7798198645468801, 10.277717001736164, 2.2763222409412265, 0.24090036400593817, 52.79067747294903, 82.15087741613388, 75.53816065192223, 82.80760377645493, 75.83405837416649, 64.30285513401031, 48.59353668987751, 49.8640251159668, 68.2596968114376, 82.97493919730186, 24.809064455330372, 0.7566474017221481, 0.20530066802166402, 0.28487944160588086, 0.11736433196347207, 0.20107229647692293, 0.2355296045425348], [0.06845700787380338, 0.06539999769302085, 0.035340051908860914, 0.026825204222404864, 0.07012571208178997, 0.0515646135318093, 0.0586903407383943, 0.1364724972518161, 2.713908185251057, 50.43569304049015, 52.9897677898407, 44.93719048798084, 41.54385857284069, 34.45058159530163, 42.746805623173714, 48.630869686603546, 66.47239431738853, 56.17113947868347, 67.06773117184639, 25.72216685861349, 0.14329437806736678, 0.4903334967093542, 3.4121634671464562, 0.1432117325020954, 18.123137019574642, 73.13026785850525, 61.13335020840168, 62.89803631603718, 57.87389650940895, 62.15521037578583, 56.740432530641556, 57.16501034796238, 51.88582822680473, 54.252341240644455, 51.20133675634861, 53.3512119948864, 52.61981964111328, 50.51793962717056, 47.960752844810486, 44.87186439335346, 38.12237776815891, 39.85273651778698, 39.1072241216898, 39.86094407737255, 36.17616780102253, 40.03016799688339, 40.5505158752203, 40.994845032691956, 41.97306454181671, 41.16176627576351, 45.34090742468834, 46.02204367518425, 45.27384862303734, 45.58202348649502, 41.72513544559479, 39.225036799907684, 37.975530847907066, 38.656990081071854, 37.178440019488335, 39.73528102040291, 35.62135197222233, 37.2833713889122, 37.06861451268196, 37.93395347893238, 37.48701386153698, 36.22490018606186, 34.98289503157139, 36.25179514288902, 36.2234790623188, 36.181343123316765, 37.81900204718113, 48.9792387932539, 48.90813320875168, 48.85931342840195, 50.82156613469124, 43.86587217450142, 35.257521495223045, 36.808377876877785, 38.81147839128971, 40.30727572739124, 39.25653710961342, 40.031756311655045, 36.16990953683853, 36.35383866727352, 37.32372522354126, 37.59471908211708, 40.27940422296524, 42.25495241582394, 41.538546457886696, 41.996554881334305, 39.09018583595753, 35.139716416597366, 34.1293316334486, 35.39427235722542, 36.05496570467949, 36.28963731229305, 39.715636074543, 36.88296027481556, 36.46381996572018, 36.53451897203922, 38.79941023886204, 37.156898975372314, 36.94489315152168, 36.54029466211796, 47.84257918596268, 49.47104640305042, 45.71796879172325, 47.98161372542381, 35.65949812531471, 35.67129649221897, 35.17172209918499, 38.042946830391884, 36.680708527565, 36.349700689315796, 35.34000366926193, 36.447294652462006, 35.72067104279995, 38.65816041827202, 39.561029970645905, 38.073698580265045, 39.7305578738451, 37.686100378632545, 38.410299718379974, 37.80492380261421, 40.184386521577835, 41.642664670944214, 44.65436026453972, 47.557495683431625, 48.679773062467575, 48.1060266494751, 49.9480652064085, 50.219841822981834, 50.65628260374069, 52.23088011145592, 53.96054729819298, 52.88049705326557, 50.47305643558502, 48.9829245954752, 45.58756738901138, 41.30180776119232, 40.59031493961811, 40.49986079335213, 42.713724598288536, 44.5799944549799, 48.961691334843636, 49.011951237916946, 53.442448899149895, 58.073754385113716, 62.648925483226776, 61.70921690762043, 55.85472285747528, 48.91709312796593, 61.38210766017437, 34.28007334470749, 3.2776958076283336, 0.3211230842862278, 1.0796168306842446, 0.60136558720842, 1.1191446846351027, 51.557708233594894, 70.67937657237053, 60.391360223293304, 68.0941092967987, 66.02068215608597, 58.49738225340843, 28.47499944269657, 29.84305713325739, 50.3817967325449, 59.69964914023876, 8.478403352200985, 0.7874534174334258, 0.09781952408957295, 0.09015522402478382, 0.05181402339076158, 0.0923497843905352, 0.07993194682057947, 0.10347931296564639, 0.10859540445380844, 0.04412183341628406, 0.053310816510929726, 0.008628182913525961, 0.051798093190882355, 0.152185826736968, 0.09542211992084049, 4.058661963790655, 62.19004690647125, 59.30372178554535, 51.612820476293564, 33.53011518716812, 33.535108119249344, 51.95072874426842, 55.431326776742935, 70.83174079656601, 60.22726982831955, 73.38531777262688, 26.82643510401249, 0.16676619357895106, 0.7695100677665323, 1.8014838080853224, 0.10894830309553072, 19.800731800496578, 73.83104905486107, 61.85765974223614, 64.76446196436882, 58.28541822731495, 64.99321728944778, 59.28441882133484, 58.78940038383007, 53.56073655188084, 55.219374150037766, 53.69124434888363, 56.39030031859875, 54.660203754901886, 53.01164321601391, 50.81449471414089, 46.673283129930496, 40.040032267570496, 43.140776082873344, 41.635942831635475, 42.1018510311842, 38.14542733132839, 42.507627457380295, 42.73227900266647, 43.861958384513855, 44.84010569751263, 44.461714401841164, 45.436559692025185, 48.19105848670006, 46.34886033833027, 48.60839009284973, 43.535647094249725, 42.26556144654751, 40.930624678730965, 39.01884846389294, 38.73551286756992, 40.21280139684677, 37.409661412239075, 38.44705134630203, 38.8560575991869, 40.23759126663208, 38.12169000506401, 39.38754267990589, 36.67708732187748, 37.28854291141033, 37.36265793442726, 37.45944634079933, 39.42551404237747, 49.795226007699966, 51.289218440651894, 52.042490020394325, 51.663619950413704, 44.53187383711338, 35.415904596447945, 38.05483639240265, 38.40822882950306, 38.72255936264992, 39.58368815481663, 40.757011994719505, 37.22280643880367, 37.44434215128422, 37.35530912876129, 38.596554324030876, 40.34972324967384, 43.47597509622574, 43.16154196858406, 44.61852818727493, 41.00002035498619, 38.39431777596474, 35.43360024690628, 35.71748301386833, 36.75195850431919, 38.80832076072693, 39.22358147799969, 37.064339742064476, 36.42480745911598, 37.98361301422119, 38.262730836868286, 37.88312740623951, 37.46418088674545, 36.75534412264824, 47.7501605451107, 53.24715457856655, 47.516556680202484, 50.6551730632782, 38.047776371240616, 37.87571780383587, 36.563291028141975, 39.24278944730759, 38.381075486540794, 38.80871593952179, 37.5237312912941, 37.23549775779247, 37.60628946125507, 38.66922162473202, 40.65863907337189, 39.255530163645744, 39.17318858206272, 40.568982884287834, 40.40998041629791, 41.94221019744873, 40.88283084332943, 44.709803089499474, 45.944227650761604, 50.640258863568306, 50.35457879304886, 49.46189269423485, 52.54549942910671, 52.48934984207153, 53.39616738259792, 54.74150039255619, 56.41060642898083, 54.684625044465065, 53.12429957091808, 50.93222379684448, 46.9150185585022, 43.054828494787216, 42.156834080815315, 42.795359417796135, 44.076107293367386, 47.248633056879044, 51.181429624557495, 52.48021513223648, 56.10249996185303, 60.8815149217844, 63.98371785879135, 64.32482555508614, 58.691046461462975, 49.67147804796696, 63.3180695772171, 44.59295175969601, 2.505728043615818, 0.42667037690989673, 3.2979301968589425, 0.39908023551106453, 1.1260558012872934, 55.94896540045738, 76.05655163526535, 67.19149053096771, 72.36938908696175, 71.81846424937248, 68.36599990725517, 31.55631110072136, 34.51637506484985, 55.575380846858025, 69.70657557249069, 13.04172383621335, 0.8275559905450791, 0.11948698564083315, 0.18462897569406778, 0.13347987580345944, 0.1005522083141841, 0.05392228682467248, 0.1500797303742729, 0.16779340017819777, 0.2052011905470863, 0.1844174339203164, 0.1530283276224509, 0.07963512485730462, 0.1926571730291471, 0.239475900598336, 5.243354793637991, 72.2991992533207, 66.72866776585579, 61.374952644109726, 52.804216146469116, 50.89561656117439, 59.35053147375584, 58.303216472268105, 78.19820791482925, 65.84940254688263, 79.99135449528694, 28.76565344631672, 0.24118745641317219, 2.2633974719792604, 10.085258278995752, 0.32308478839695454, 22.108099088072777, 75.64810395240784, 63.8940654695034, 67.44063556194305, 60.07909297943115, 67.7950045466423, 62.82751590013504, 60.265913754701614, 55.23710399866104, 57.266844883561134, 56.396319195628166, 57.99762926995754, 56.191996559500694, 54.58909057080746, 52.15971753001213, 49.640365317463875, 41.98414094746113, 44.22315180301666, 43.853477239608765, 44.89102676510811, 40.931798815727234, 45.866107642650604, 45.58379419147968, 46.06823019683361, 46.18671163916588, 45.10749734938145, 48.35241302847862, 51.64616748690605, 49.00581456720829, 51.37035168707371, 45.5972720682621, 43.401324301958084, 43.4542440623045, 41.66308477520943, 39.76620756089687, 43.200698867440224, 38.52233290672302, 40.78011855483055, 41.66715435683727, 41.83501794934273, 40.388997942209244, 39.4474882632494, 36.8448369204998, 39.4991996884346, 38.7501572817564, 40.292733907699585, 41.94085367023945, 53.18601965904236, 53.488601222634315, 54.13520112633705, 54.401061460375786, 45.10307818651199, 35.516029223799706, 37.2378384321928, 39.97575871646404, 40.54130136966705, 39.419966340065, 40.89680649340153, 38.0662851780653, 37.69430033862591, 38.14172253012657, 40.98020441830158, 42.49488674104214, 46.13394007086754, 45.09118862450123, 46.19100160896778, 42.78625510632992, 38.95915746688843, 36.92679852247238, 36.425624415278435, 37.49607637524605, 38.467266261577606, 39.001601189374924, 38.58552731573582, 36.58708915114403, 37.440644949674606, 38.626926094293594, 39.44307290017605, 37.12189145386219, 37.81891465187073, 49.67932842671871, 56.59733600914478, 51.466383934020996, 53.32434743642807, 40.17912000417709, 40.31605325639248, 38.51440653204918, 42.83146508038044, 40.308005288243294, 40.575928911566734, 39.23015512526035, 39.42340515553951, 38.64481173455715, 41.29529871046543, 43.10999393463135, 42.68012300133705, 42.42567725479603, 43.49321097135544, 43.117167949676514, 42.8998614102602, 44.09225642681122, 47.17276632785797, 48.040613159537315, 53.665215745568275, 52.969313487410545, 53.01466025412083, 53.82200673222542, 53.77124145627022, 53.522772789001465, 58.15780967473984, 58.95992003381252, 58.34820605814457, 54.75734554231167, 55.02778843045235, 49.67322215437889, 45.69790966808796, 45.38759171962738, 45.503447502851486, 46.910831183195114, 50.49425169825554, 53.09003300964832, 55.51723636686802, 58.132339641451836, 64.66724038124084, 66.46994724869728, 68.05795803666115, 58.66524964570999, 54.11716729402542, 61.831699535250664, 55.846887677907944, 4.192493157461286, 1.761091381777078, 15.8256577514112, 1.7241339711472392, 1.2998375762254, 60.04546858370304, 83.78702402114868, 73.77246379852295, 78.9508943259716, 78.3487406373024, 75.45917809009552, 35.98734833300114, 45.10298319160938, 62.37429141998291, 82.14486613869667, 18.21049813181162, 1.0372878145426512, 0.2119730951380916, 0.25513564702123404, 0.22428661643061787, 0.20781475264811888, 0.20102102891542017], [0.06527185105369426, 0.04465475110919215, 0.031247400620486587, 0.03786235582083464, 0.023264283190655988, 0.0325913595588645, 0.041696105181472376, 0.11415222033974715, 0.958149639191106, 47.57859595119953, 52.091446593403816, 43.61183300614357, 22.915038987994194, 16.11747734248638, 42.21486836671829, 54.977501928806305, 64.4965535402298, 54.47195045650005, 63.96715074777603, 35.16326755285263, 0.07294110124348663, 0.1242253759119194, 0.6024522695224732, 0.3585843538166955, 34.249200001358986, 76.62730380892754, 59.471380189061165, 63.11278559267521, 59.110391959548, 61.0047423094511, 58.686938881874084, 57.16456197202206, 55.469127148389816, 53.618223667144775, 51.77601411938667, 52.979097962379456, 48.562370762228966, 48.00196923315525, 43.98981012403965, 39.97519254684448, 38.26564908027649, 39.79390807449818, 38.149990886449814, 38.35187405347824, 37.19816096127033, 37.86329247057438, 37.250214368104935, 38.72129403054714, 39.71931807696819, 40.762327909469604, 41.61728963255882, 44.21772949397564, 44.821805879473686, 44.12548944354057, 42.67487548291683, 39.39424932003021, 39.14579585194588, 37.13593170046806, 37.875277027487755, 38.08648869395256, 35.82377091050148, 36.80658437311649, 35.74467055499554, 36.48357890546322, 34.620778262615204, 36.010576486587524, 35.61640843749046, 36.92616015672684, 34.9722708016634, 36.07250176370144, 43.894982412457466, 49.91484358906746, 47.701249569654465, 47.344615906476974, 47.41775818169117, 47.09137849509716, 39.33932326734066, 36.546252742409706, 37.564537301659584, 38.47289375960827, 38.25664356350899, 37.905401811003685, 35.62944173812866, 36.7595960944891, 37.574975341558456, 38.83761718869209, 42.37339586019516, 43.54937195777893, 42.79915541410446, 42.75814801454544, 40.36026008427143, 37.41085834801197, 35.78079901635647, 36.007825434207916, 37.302875742316246, 38.74469317495823, 38.969120532274246, 37.525125816464424, 38.32515008747578, 36.79750666022301, 36.70470803976059, 37.49684013426304, 36.1018817871809, 40.6469850987196, 49.28585194051266, 48.416093811392784, 50.00137634575367, 44.727570936083794, 38.30192193388939, 36.54083423316479, 36.538482159376144, 35.345904752612114, 37.19328582286835, 36.84117391705513, 36.22712306678295, 35.63366711139679, 35.273883417248726, 37.27971598505974, 37.86437161266804, 37.8904078155756, 38.75614196062088, 37.334440648555756, 38.68826240301132, 37.864523604512215, 39.236363992094994, 42.15689107775688, 46.48311473429203, 45.8526411652565, 46.685887053608894, 45.03357991576195, 47.96357989311218, 48.07535469532013, 49.18409340083599, 47.87137024104595, 52.6338142901659, 51.0064984112978, 50.93358412384987, 50.221000760793686, 48.21920357644558, 42.54982419312, 42.96559788286686, 39.515231028199196, 42.958914041519165, 43.966129794716835, 45.30766300857067, 45.98933883011341, 55.80659084022045, 56.52611643075943, 61.901820972561836, 60.295327976346016, 66.84405997395515, 41.516473442316055, 52.4647119641304, 42.855248004198074, 2.0769806625321507, 0.10354390949942172, 0.35654217121191323, 0.4199340211926028, 1.6866603819653392, 54.292782470583916, 69.52495291829109, 62.37923875451088, 66.04016751050949, 64.22004237771034, 46.15058317780495, 32.21108436584473, 23.896013349294662, 44.64866816997528, 60.34958526492119, 5.15507698059082, 0.5091377079952508, 0.04637603648006916, 0.03760499013878871, 0.025938729231711477, 0.061689422582276165, 0.024902204968384467, 0.1474320888519287, 0.061421243808581494, 0.07234448130475357, 0.07210355048300698, 0.07517991587519646, 0.04857012929278426, 0.04863165333517827, 0.10131279093911871, 2.015373855829239, 57.56303519010544, 59.816755056381226, 52.864917889237404, 32.42771074175835, 30.63151102513075, 51.14558234810829, 57.64843940734863, 71.58821180462837, 60.30887804925442, 70.02333417534828, 37.27113604545593, 0.06735440649208613, 0.06027146038832143, 0.7778082287404686, 0.23919884202769026, 35.49921132624149, 75.98588302731514, 62.10245780646801, 64.35384079813957, 60.670405849814415, 62.81306527554989, 60.543990433216095, 58.50976198911667, 56.58940963447094, 56.24998904764652, 54.63012456893921, 54.82966706156731, 50.988555774092674, 50.803528502583504, 45.36944009363651, 42.03484542667866, 39.89355772733688, 39.78522174060345, 39.07802648842335, 40.503007024526596, 39.04633618891239, 40.44411398470402, 38.177938386797905, 40.20814664661884, 42.117722779512405, 43.48589636385441, 44.650248885154724, 45.709328055381775, 45.169133841991425, 44.49884220957756, 44.73950609564781, 42.675924226641655, 40.39161220192909, 39.18815217912197, 40.41310764849186, 38.58650766313076, 36.684705913066864, 39.42243240773678, 37.54244148731232, 37.53980442881584, 36.90158687531948, 38.75242196023464, 37.35444277524948, 38.22946362197399, 38.31937439739704, 37.832563519477844, 45.371491983532906, 51.771195977926254, 50.693645998835564, 51.30969174206257, 50.807430893182755, 47.745437398552895, 39.04796250164509, 37.18254379928112, 39.05158370733261, 38.04011978209019, 40.134856179356575, 39.107908084988594, 34.95771758258343, 37.594080716371536, 36.601699367165565, 39.61155205965042, 43.27324457466602, 45.146984830498695, 46.09781160950661, 43.79077300429344, 42.240091413259506, 38.55290226638317, 35.74783578515053, 37.099145874381065, 36.896943524479866, 39.01350595057011, 38.20881932973862, 37.53407433629036, 39.171322882175446, 37.62035250663757, 36.73528119921684, 38.37460443377495, 36.70232556760311, 40.61532899737358, 50.430293530225754, 50.49873925745487, 50.814008340239525, 45.6237718462944, 39.471240788698196, 36.92050985991955, 37.56524786353111, 36.86662495136261, 38.7042785435915, 40.01136660575867, 37.974406108260155, 38.06091606616974, 37.206026539206505, 38.8340225815773, 39.51450526714325, 39.1796900331974, 39.64567422866821, 40.149424597620964, 42.30945289134979, 40.571281760931015, 42.75328427553177, 44.49652433395386, 48.05145777761936, 48.29977445304394, 48.479850590229034, 47.13447578251362, 48.591541796922684, 49.85333248972893, 50.737655237317085, 50.68296857178211, 53.969583213329315, 53.73553477227688, 51.520424634218216, 51.94200061261654, 49.96789254248142, 45.85402429103851, 44.534621089696884, 41.874136850237846, 44.67012941837311, 44.133157432079315, 46.57134220004082, 48.683914840221405, 56.14670678973198, 58.76261182129383, 62.20601364970207, 61.11918456852436, 69.20445531606674, 46.54056765139103, 54.36931796371937, 53.88300485908985, 2.3698074370622635, 0.17214625957421958, 1.2652016035281122, 0.5264057032763958, 1.7494320636615157, 58.242754116654396, 74.35344502329826, 67.41401419043541, 71.080072671175, 72.13657557964325, 54.493039324879646, 30.01767296344042, 29.58040952682495, 51.37913681566715, 73.37381199002266, 7.826828565448523, 0.5480026756413281, 0.011747813659894746, 0.04983620725397486, 0.0067100887918059016, 0.07320589953451417, 0.05157721519935876, 0.25868620024994016, 0.17746496479958296, 0.25544301490299404, 0.12374007070320658, 0.14526372629916295, 0.14908958662999794, 0.1585820858599618, 0.23947866138769314, 2.6031408039852977, 67.24425449967384, 67.390858232975, 60.567864552140236, 34.88049052655697, 28.50232757627964, 56.99941523373127, 68.09146463871002, 77.10228592157364, 64.04076039791107, 76.42046570777893, 41.68538957834244, 0.20689579570898786, 1.7878981120884418, 4.289713315665722, 0.3723242087289691, 38.764129132032394, 78.57129469513893, 63.4986624866724, 68.67354020476341, 63.23210299015045, 64.0553668141365, 62.087756395339966, 61.52046963572502, 59.71627704799175, 58.45084995031357, 56.631997749209404, 57.68154323101044, 53.888187780976295, 52.70484387874603, 47.609495893120766, 44.879661574959755, 41.69754512608051, 42.04062111675739, 42.36706160008907, 43.233646899461746, 41.58007062971592, 43.09045158326626, 40.20086243748665, 43.85410040616989, 44.780942872166634, 43.59603725373745, 46.67968198657036, 50.12703940272331, 46.8625395745039, 46.828827783465385, 47.991861775517464, 45.42718179523945, 42.698742002248764, 40.53018316626549, 43.549246564507484, 41.513961777091026, 38.19029152393341, 41.21229596436024, 40.20053565502167, 40.49066908657551, 38.08645449578762, 40.67821942269802, 39.31866377592087, 41.95428974926472, 40.343772768974304, 38.00906024873257, 49.44363087415695, 54.74068723618984, 53.210893124341965, 52.855425998568535, 52.288785204291344, 48.49656969308853, 40.41990928351879, 36.190903410315514, 39.437016025185585, 39.92214359343052, 39.85597014427185, 39.060513228178024, 36.12685404717922, 38.592488542199135, 39.14114490151405, 41.095053255558014, 47.44198948144913, 48.11904475092888, 48.95332798361778, 45.86768075823784, 43.6252386868, 40.75165048241615, 38.061600029468536, 37.57446236908436, 38.19908045232296, 40.34088872373104, 39.87138971686363, 37.27030768990517, 40.003261640667915, 37.22383998334408, 37.20831021666527, 38.24382305145264, 37.40225560963154, 41.11698567867279, 52.54684455692768, 52.26700097322464, 54.94150646030903, 50.78286901116371, 42.65163592994213, 40.66452115774155, 39.75852057337761, 38.87257531285286, 42.31202535331249, 41.405526995658875, 38.93077678978443, 39.91241231560707, 38.01382139325142, 41.31830647587776, 40.59672899544239, 41.42380401492119, 42.40051880478859, 41.874186247587204, 44.76804256439209, 43.81170608103275, 44.29371781647205, 47.55314111709595, 51.41586944460869, 52.24230229854584, 52.067872658371925, 50.42129561305046, 51.59680813550949, 52.296453192830086, 53.71795691549778, 52.1114107221365, 56.773076578974724, 57.02010132372379, 54.54046078026295, 56.9999548047781, 52.54133865237236, 49.26351673901081, 46.4843724668026, 44.11550357937813, 48.00288878381252, 49.018429890275, 49.25639972090721, 50.167929008603096, 58.948440849781036, 61.19187846779823, 64.68335911631584, 63.861592411994934, 70.24717256426811, 44.73200909793377, 53.52230541408062, 62.83418454229832, 5.486370278522372, 0.2607876359252259, 4.996703378856182, 1.5657514636404812, 1.8941031256690621, 63.205223232507706, 80.3082574903965, 73.71910706162453, 77.91681781411171, 76.52419254183769, 61.18810907006264, 44.33884039521217, 40.213268771767616, 60.245402455329895, 86.6378590464592, 14.059612266719341, 1.2889639846980572, 0.2024546652683057, 0.15604302054271102, 0.07170849043177441, 0.16259134572464973, 0.08371835458092391], [0.10655539634171873, 0.03890371888701338, 0.04785605335200671, 0.051066261366941035, 0.04047430003993213, 0.011686172729241662, 0.05259449186269194, 0.3676962055033073, 0.7802025752607733, 36.62028796970844, 59.09309148788452, 42.28974714875221, 29.341501146554947, 16.159542985260487, 39.38201017677784, 55.30115336179733, 63.25676366686821, 57.99775846302509, 60.54524056613445, 45.09175859391689, 0.38811443955637515, 0.30917222087737173, 0.4993430804461241, 0.7764470111578703, 46.58316716551781, 71.45106956362724, 60.210098549723625, 57.513227462768555, 55.386299192905426, 63.15389558672905, 56.918145194649696, 58.58760081231594, 54.686597138643265, 53.602633103728294, 51.34924001991749, 51.663243770599365, 47.53505788743496, 42.05616608262062, 38.72801586985588, 40.765827521681786, 38.34020867943764, 39.94588851928711, 37.96085603535175, 38.023662865161896, 37.35652506351471, 38.40486980974674, 37.002520859241486, 36.3248348236084, 37.618965581059456, 39.64630879461765, 38.10049094259739, 39.26335774362087, 40.87189503014088, 40.37908807396889, 40.2342664450407, 38.40676590800285, 37.711346223950386, 37.40271158516407, 38.15416306257248, 36.658456921577454, 36.91487476229668, 37.71621376276016, 36.671174839138985, 36.29003249108791, 34.17597033083439, 36.62963166832924, 39.132690355181694, 39.04413990676403, 40.93337953090668, 36.850149035453796, 38.4861246496439, 46.21975086629391, 49.62848335504532, 47.54669286310673, 47.696146443486214, 47.99603395164013, 40.29225893318653, 35.96293464303017, 35.92129647731781, 37.747128903865814, 40.5597759783268, 40.43498307466507, 38.48074033856392, 37.80686169862747, 37.597302943468094, 36.873988956213, 40.388990342617035, 44.30298171937466, 44.89364482462406, 40.7594058662653, 37.143424898386, 36.61812208592892, 37.23522797226906, 37.99712888896465, 37.69119590520859, 38.996448665857315, 37.4408995360136, 36.89913220703602, 36.531372740864754, 38.70875470340252, 37.22250625491142, 36.300170347094536, 36.892406567931175, 41.14928014576435, 48.4371180832386, 50.53590506315231, 49.29582640528679, 50.1639886200428, 38.2165253162384, 35.74513033032417, 37.60189689695835, 36.84707500040531, 38.494267612695694, 37.28890769183636, 35.415604412555695, 37.8708578646183, 37.08330452442169, 35.88802166283131, 39.29561801254749, 36.1884069442749, 38.02543357014656, 38.607984110713005, 36.82640790939331, 38.04105073213577, 41.38272441923618, 42.09033764898777, 44.86519955098629, 45.80942988395691, 44.5162832736969, 43.03010322153568, 44.49846222996712, 42.93451555073261, 44.22756716609001, 46.557472944259644, 49.214890748262405, 48.02959755063057, 49.55930806696415, 48.286566361784935, 47.094118148088455, 44.39806781709194, 41.60119369626045, 39.87506031990051, 40.9732735902071, 42.017837539315224, 43.70605655014515, 47.27523922920227, 58.44748333096504, 57.426694706082344, 63.908877074718475, 57.74863623082638, 67.34776094555855, 66.90143689513206, 60.49671337008476, 56.63789123296738, 0.20409239223226905, 0.12176536416518502, 0.4881284275325015, 0.2666694234358147, 2.4166558356955647, 53.97514991462231, 67.94885069131851, 63.07152360677719, 72.43822619318962, 58.75077545642853, 67.59360015392303, 47.166622057557106, 24.916463792324066, 51.34706273674965, 54.318199306726456, 6.44572569988668, 0.8578898815903813, 0.02109699860739056, 0.17396750481566414, 0.05930192979576532, 0.07505878253141418, 0.006372051193466177, 0.10419999773148447, 0.06579792985576205, 0.01972300680790795, 0.0399710274359677, 0.1250606111716479, 0.08900782660930417, 0.06704855259158649, 0.43346473888959736, 1.1961897066794336, 47.349821627140045, 65.54511487483978, 47.052673771977425, 32.16782748699188, 21.881806030869484, 51.6698744148016, 58.987130373716354, 69.84787479043007, 61.38912208378315, 64.34274539351463, 47.89164215326309, 0.26688289479352534, 0.3210462868446484, 0.4620485269697383, 0.7931846973951906, 48.565619587898254, 72.76054009795189, 62.39835552871227, 58.72637316584587, 58.09351332485676, 65.61440035700798, 60.56501470506191, 59.50964413583279, 57.56672479212284, 55.76526425778866, 55.148963928222656, 53.85270528495312, 50.626264214515686, 44.39752444624901, 39.82098922133446, 42.33014278113842, 40.5724710971117, 41.64855055510998, 40.25044597685337, 39.15391221642494, 40.08631378412247, 40.11123664677143, 38.57001654803753, 39.17911246418953, 39.14590984582901, 41.65995754301548, 40.89587554335594, 42.5136349350214, 44.95863653719425, 44.04259689152241, 43.00659008324146, 40.03297224640846, 40.85916571319103, 38.89124371111393, 40.16818419098854, 39.60012227296829, 38.41521665453911, 38.483035415410995, 38.6007758975029, 37.71123602986336, 35.51313377916813, 38.75038146972656, 40.34866690635681, 40.86839161813259, 43.40010456740856, 38.64343240857124, 40.159972831606865, 47.55802005529404, 50.27031451463699, 50.50698481500149, 50.93544602394104, 49.79565158486366, 41.74593932926655, 36.25494137406349, 36.43687181174755, 38.041103929281235, 40.46929143369198, 40.74820786714554, 39.61375214159489, 38.420281782746315, 36.93670079112053, 38.29414375126362, 41.39161974191666, 45.582285672426224, 46.21453754603863, 43.042186573147774, 39.37655366957188, 35.931221544742584, 37.05867424607277, 38.26032556593418, 37.77147799730301, 38.33644688129425, 38.67845892906189, 38.17126214504242, 36.19918316602707, 39.114873111248016, 37.59043671190739, 36.96084089577198, 36.31038799881935, 42.74084374308586, 50.427139699459076, 52.3137004673481, 52.51066289842129, 52.939599081873894, 40.56031934916973, 39.53120157122612, 40.1552002876997, 37.90169321000576, 37.84295976161957, 37.84273937344551, 37.918898686766624, 38.60050231218338, 37.59388692677021, 36.95837862789631, 39.569313526153564, 39.45053189992905, 40.38080558180809, 40.816634595394135, 38.51581245660782, 40.637037232518196, 41.60752035677433, 43.673963472247124, 47.11110323667526, 48.30650769174099, 46.65539748966694, 46.48599497973919, 47.19450496137142, 45.3906125575304, 46.94302685558796, 50.07453382015228, 50.129528269171715, 51.24851882457733, 51.6636161506176, 51.070688366889954, 48.62625293433666, 46.9597003608942, 45.01083053648472, 42.640947103500366, 43.57982352375984, 44.858747497200966, 44.53048311173916, 49.83490727841854, 60.869864746928215, 61.49553157389164, 66.09098598361015, 60.387157648801804, 65.92137828469276, 69.90456014871597, 60.548561587929726, 63.965782821178436, 3.1829882645979524, 0.27506275742780417, 1.160674556158483, 0.36640525446273386, 2.699927785433829, 59.504909589886665, 74.72511827945709, 67.8611969947815, 76.05706080794334, 66.71302780508995, 65.64651623368263, 41.13573767244816, 29.51351411640644, 57.77623414993286, 67.75008335709572, 9.509217739105225, 0.7322294369805604, 0.08057954488322139, 0.15116169262910262, 0.09753310703672469, 0.12149766407674178, 0.06362714790157042, 0.3017305873800069, 0.21658429614035413, 0.1458978172740899, 0.24771025171503425, 0.24427572585409507, 0.09936484624631703, 0.18870811618398875, 0.485239751287736, 1.6118178167380393, 55.098867416381836, 73.6861552298069, 57.755244076251984, 41.5517545491457, 25.671688467264175, 54.707036241889, 64.3454584479332, 76.00751906633377, 67.16886654496193, 70.46813070774078, 54.06863629817963, 0.8019830659031868, 1.051799354609102, 1.9808421400375664, 1.0851690452545881, 49.941852539777756, 75.20356580615044, 64.3955397605896, 61.34040489792824, 59.42954063415527, 68.24698269367218, 61.17431201040745, 62.52654545009136, 59.11997504532337, 58.14909294247627, 57.22070395946503, 55.325688645243645, 53.55154484510422, 45.848966762423515, 43.54645751416683, 46.346705853939056, 43.50040018558502, 44.4753784686327, 41.90810702741146, 40.121488496661186, 41.74945034086704, 42.79136203229427, 42.02730283141136, 39.88775163888931, 42.22345970571041, 45.55342622101307, 43.282823860645294, 44.25421133637428, 46.123543828725815, 46.39041490852833, 44.40140023827553, 43.03718984127045, 42.89984241127968, 41.388549506664276, 42.6714176684618, 40.551617816090584, 40.83999194204807, 40.95740184187889, 41.460939422249794, 40.16879975795746, 38.76318298280239, 39.982165172696114, 44.12884086370468, 44.443802163004875, 46.246056854724884, 41.196105033159256, 41.558518186211586, 50.66823676228523, 52.30654165148735, 52.399834245443344, 53.77792149782181, 52.39117071032524, 43.05546686053276, 36.153980791568756, 36.0881607234478, 38.32053333520889, 41.393838822841644, 41.3560726493597, 41.00993022322655, 37.895678132772446, 38.87469179928303, 40.16873516142368, 44.043622836470604, 48.583509027957916, 49.41311091184616, 44.03883509337902, 41.08849860727787, 37.118859216570854, 38.78014147281647, 40.54985471069813, 36.827080473303795, 39.26246479153633, 39.638017639517784, 39.20941963791847, 35.76403051614761, 39.588943272829056, 38.37662972509861, 37.48088859021664, 35.25059066712856, 42.98304654657841, 54.4514087587595, 57.432774379849434, 55.379565954208374, 55.528662353754044, 42.091773971915245, 41.554589197039604, 41.46601215004921, 40.936533361673355, 42.29235760867596, 38.91661494970322, 39.56328324973583, 42.10893765091896, 40.558058470487595, 38.813883662223816, 41.4233024418354, 40.63711702823639, 43.044109269976616, 43.02194885909557, 41.53071127831936, 42.30463095009327, 46.378415152430534, 46.01338014006615, 50.25192730128765, 50.964579060673714, 50.72879031300545, 48.70562307536602, 49.932033866643906, 48.02060343325138, 50.30960440635681, 51.73257865011692, 52.997344583272934, 52.706705778837204, 54.666256830096245, 54.009629264473915, 51.4316575974226, 49.39389154314995, 47.62975640594959, 44.88300919532776, 44.338832795619965, 46.98148839175701, 46.45665295422077, 52.57859945297241, 63.18277783691883, 63.75400498509407, 68.70351299643517, 63.0395483225584, 67.93850004673004, 71.59750610589981, 57.6717359572649, 71.05489522218704, 6.1141664162278175, 0.3191130218328908, 4.234435306861997, 1.119853227864951, 2.9622034868225455, 62.90692783892155, 82.32917904853821, 73.16779464483261, 82.65438839793205, 71.06222122907639, 86.30310460925102, 60.34882910549641, 39.89679895341396, 67.49974519014359, 78.89839634299278, 15.42020620778203, 1.233699987642467, 0.16921971895499155, 0.30713342246599495, 0.13705756195122376, 0.2782762568676844, 0.1593062438769266], [0.06747182909748517, 0.048875393185880966, 0.047182465277728625, 0.10538800546783023, 0.04470788888284005, 0.07430203680996783, 0.04168220475548878, 0.22742570814443752, 0.1332879564142786, 32.920122519135475, 64.37065869569778, 47.208416014909744, 33.781148716807365, 27.640746608376503, 40.33723331987858, 62.270423993468285, 65.72131901979446, 60.410868376493454, 53.72445456683636, 53.44833858311176, 2.597753405570984, 0.14804243110120296, 0.11667012702673674, 0.6510699482169002, 50.02730995416641, 66.46325960755348, 59.596150293946266, 52.63455905020237, 49.03799504041672, 55.405206978321075, 56.383069306612015, 55.434902384877205, 54.82767216861248, 52.02728323638439, 49.24079015851021, 45.34351788461208, 40.86421564221382, 39.78785879909992, 39.08224806189537, 38.40765506029129, 38.34625415503979, 38.318785429000854, 38.205361515283585, 37.78865307569504, 37.30374589562416, 37.69840411841869, 36.50673866271973, 36.89506642520428, 36.024966314435005, 35.24965211749077, 37.77142100036144, 36.36227421462536, 38.32189366221428, 38.88878904283047, 38.12274254858494, 38.95523987710476, 36.95437744259834, 37.21625559031963, 36.51339590549469, 38.33053059875965, 36.35149799287319, 38.48822593688965, 36.321555599570274, 36.314070001244545, 37.05217279493809, 36.819895058870316, 37.335212007164955, 34.96763505041599, 36.626344844698906, 34.31959882378578, 35.79773850739002, 42.69505240023136, 49.006658121943474, 47.43267998099327, 50.26811063289642, 48.05229753255844, 43.89834143221378, 37.001491114497185, 37.03611485660076, 37.30561539530754, 39.03775244951248, 38.83660264313221, 37.80816122889519, 34.522671326994896, 35.81689327955246, 35.89199244976044, 38.555049151182175, 44.70947630703449, 41.98727197945118, 42.26225562393665, 38.260903134942055, 37.17106841504574, 38.956934586167336, 37.01516658067703, 37.9966539144516, 39.28245551884174, 37.83317908644676, 37.50063233077526, 36.14302217960358, 37.96201877295971, 37.123122587800026, 37.66521669924259, 36.95026606321335, 42.81791500747204, 50.88889852166176, 49.59963910281658, 47.987043634057045, 49.036045745015144, 43.28099995851517, 38.28190080821514, 35.989423021674156, 36.5846648812294, 35.690918639302254, 38.171026557683945, 36.67805626988411, 36.713614761829376, 35.76784171164036, 36.16052784025669, 37.93375588953495, 38.69958579540253, 36.7245277762413, 38.140001222491264, 37.63462074100971, 37.560095340013504, 41.03639580309391, 44.287957325577736, 43.459267392754555, 42.937038615345955, 43.96305575966835, 42.22644254565239, 41.8486288189888, 45.60343913733959, 45.090215876698494, 45.358363687992096, 45.24557814002037, 45.22386610507965, 43.43086391687393, 46.8644280731678, 44.25839491188526, 44.27187658846378, 42.125432565808296, 40.7583799213171, 43.63730303943157, 43.05415593087673, 42.69711188971996, 53.0364178866148, 58.86879712343216, 60.226407274603844, 59.905833676457405, 63.91273766756058, 56.811116337776184, 64.32272046804428, 61.26495614647865, 68.38781833648682, 5.869305180385709, 0.5807028897106647, 0.5734135746024549, 0.5508523446042091, 2.7170667657628655, 57.43781290948391, 67.0410718023777, 60.89068382978439, 69.10214200615883, 62.07737535238266, 53.445629328489304, 36.041206642985344, 34.078543558716774, 52.74809315800667, 55.88271975517273, 4.067591009661555, 0.6560965441167355, 0.09512203250778839, 0.059204233475611545, 0.05374827916966751, 0.09789770934730768, 0.09354185167467222, 0.04977380747732241, 0.07288632332347333, 0.08447668849839829, 0.10858128138352185, 0.040838360582711175, 0.22920809453353286, 0.06751202381565236, 0.20635545282857493, 0.2724205929553136, 39.56237889826298, 73.01464766263962, 55.66246077418327, 37.78485327959061, 29.07875094562769, 48.156617134809494, 65.39298623800278, 69.64760273694992, 65.20930409431458, 60.71768671274185, 58.19133147597313, 2.6272001629695296, 0.4163189901737496, 0.1380319127929397, 0.524604837410152, 52.170850932598114, 68.2432208955288, 63.01924981176853, 53.86817805469036, 51.97011150419712, 56.27546668052673, 59.01002034544945, 56.646653562784195, 55.484200939536095, 53.9015706628561, 50.49637198448181, 47.46608018875122, 42.43264988064766, 41.88368573784828, 41.676384061574936, 40.44706642627716, 40.44494614005089, 39.58094850182533, 39.89401750266552, 40.314977914094925, 40.15327759087086, 39.72801201045513, 39.30126070976257, 39.51601758599281, 38.94863963127136, 37.90670894086361, 40.64526379108429, 39.491083323955536, 41.08369566500187, 41.48969627916813, 41.29946708679199, 41.05174317955971, 39.442366138100624, 37.741307616233826, 38.61373320221901, 38.75462964177132, 40.01246474683285, 38.248846381902695, 38.27851139008999, 37.53113329410553, 37.91263282299042, 39.388496428728104, 38.38551364839077, 39.12869676947594, 40.03635786473751, 36.66423261165619, 38.49764563143253, 44.86139975488186, 51.51464134454727, 49.92941580712795, 51.77311487495899, 50.484934598207474, 43.39429087936878, 36.13930217921734, 36.32224716246128, 37.13616728782654, 39.701208248734474, 39.24539230763912, 38.423352017998695, 35.22299274802208, 36.43206126987934, 37.264569997787476, 40.45819602906704, 47.49284975230694, 45.222593173384666, 43.058480098843575, 37.875706404447556, 39.0450556576252, 39.2347376793623, 38.10726597905159, 38.23930509388447, 39.585648849606514, 39.24826115369797, 37.69774295389652, 37.21808709204197, 37.89816699922085, 38.187996447086334, 38.09568040072918, 38.73899728059769, 44.937065094709396, 52.734018713235855, 51.26559890806675, 50.990330278873444, 51.57565467059612, 45.79247139394283, 39.743507578969, 37.85649463534355, 38.45743238925934, 38.02437722682953, 39.812162294983864, 39.95911180973053, 38.09052787721157, 37.48001463711262, 37.62734033167362, 38.617270812392235, 40.66601827740669, 39.316319301724434, 39.78505454957485, 39.56147454679012, 40.11370271444321, 41.53945840895176, 46.16437263786793, 46.13320671021938, 45.78726187348366, 45.536596924066544, 46.89953438937664, 45.70406913757324, 46.852914690971375, 46.04658655822277, 48.79388853907585, 46.70226417481899, 45.822219997644424, 45.49251548945904, 48.478273674845695, 46.130695044994354, 45.0997419655323, 44.55927796661854, 42.83582724630833, 44.838441386818886, 44.948624074459076, 45.28211697936058, 55.96626207232475, 60.55942140519619, 62.01494090259075, 61.91489227116108, 65.2656702697277, 61.55709587037563, 65.84918215870857, 63.20509023964405, 70.76605752110481, 8.088889103382826, 0.7717135932762176, 0.7302909472491592, 0.40918766346294433, 2.82209740485996, 60.29596634209156, 73.3693054318428, 66.60412564873695, 78.63453090190887, 66.5724429488182, 64.0230305492878, 41.01789839565754, 37.32554532587528, 59.51515004038811, 67.91980504989624, 8.052919283509254, 0.5384141276590526, 0.08502840108121745, 0.10778710173326544, 0.07015126422629692, 0.041993086706497706, 0.10005062038544565, 0.2510158665245399, 0.16778807155787945, 0.13670055923284963, 0.22587211104109883, 0.22644984332146123, 0.4072397336130962, 0.13179629895603284, 0.4713154281489551, 0.46466148050967604, 46.17739833891392, 82.05132275819778, 63.850033432245255, 45.38590461015701, 40.02884566783905, 55.51967963576317, 71.91963002085686, 76.83234840631485, 70.15672221779823, 66.07802107930183, 62.44878262281418, 3.2753111980855465, 0.7213044294621795, 0.7922706089448184, 0.6019179825671017, 55.15289671719074, 69.86557424068451, 64.86924514174461, 56.4839842915535, 54.09875728189945, 58.63768972456455, 61.19708798825741, 60.36397509276867, 57.949926629662514, 56.50209031999111, 52.769896388053894, 49.804862290620804, 45.575924813747406, 44.986002668738365, 42.7884703874588, 43.62556926906109, 43.37260164320469, 42.17788115143776, 42.16272376477718, 42.920403108000755, 43.07200737297535, 40.61524920165539, 41.06788091361523, 40.83322070538998, 40.999560579657555, 39.99289199709892, 43.274996280670166, 41.62197858095169, 44.85400155186653, 45.42185828089714, 43.3910496532917, 45.0279676169157, 41.59794107079506, 40.07121719419956, 40.58480143547058, 40.8202937990427, 41.90818302333355, 41.561630219221115, 39.63356427848339, 40.355726927518845, 41.118000224232674, 41.28116726875305, 40.23763306438923, 40.4097106307745, 41.32858492434025, 38.80024239420891, 41.51792876422405, 48.04176829755306, 53.701146617531776, 53.610069304704666, 55.02310328185558, 53.02384816110134, 44.20786142349243, 37.108003199100494, 35.76223321259022, 36.62756457924843, 39.977708011865616, 39.3200621008873, 38.68182174861431, 34.977480322122574, 37.35961429774761, 37.36755207180977, 41.3112236559391, 50.62895447015762, 47.49266356229782, 44.81680154800415, 39.61160145699978, 39.342868477106094, 40.815452858805656, 39.145871847867966, 39.65833894908428, 40.08999578654766, 38.91120783984661, 37.27289155125618, 35.47477103769779, 38.540085554122925, 37.89813660085201, 37.79366500675678, 37.634768933057785, 47.33197778463364, 54.53526645898819, 52.38886423408985, 53.65358076989651, 55.230401158332825, 48.210342451930046, 43.17060448229313, 39.12224851548672, 41.71740286052227, 40.26398845016956, 42.694653421640396, 40.85756599903107, 40.069530084729195, 40.05267798900604, 38.839000314474106, 40.757988542318344, 43.21205645799637, 40.566798001527786, 42.525231912732124, 42.53956474363804, 42.17940866947174, 44.70566891133785, 49.57465544342995, 48.96257668733597, 47.12032534182072, 48.210616037249565, 49.15858156979084, 47.79184810817242, 50.290012657642365, 48.854586482048035, 49.993567764759064, 47.76568651199341, 48.09517063200474, 47.4701763689518, 51.367030665278435, 48.39363321661949, 47.15850189328194, 46.59615486860275, 46.21334061026573, 48.28658916056156, 47.47449293732643, 49.4665664434433, 57.795111536979675, 61.42297446727753, 66.87381237745285, 65.09237676858902, 68.62091302871704, 64.03095692396164, 69.84237268567085, 64.84641596674919, 75.8961546421051, 10.933233126997948, 0.7549899781588465, 3.2524176640436053, 1.1026399140246212, 3.154976167716086, 65.17377600073814, 77.71457746624947, 71.95189788937569, 83.22162955999374, 74.76326063275337, 70.6748928129673, 48.140050023794174, 48.22739593684673, 68.44729274511337, 83.23066547513008, 11.445527337491512, 0.9693167649675161, 0.33317036752123386, 0.22956678934860975, 0.1958372164517641, 0.18390285840723664, 0.1452881726436317], [0.08217958558816463, 0.07170691707869992, 0.003346305375089287, 0.06950934359338135, 0.053693991067120805, 0.13203503302065656, 0.010256009627482854, 0.33960069122258574, 0.06037148705217987, 22.05619767308235, 64.24257516860962, 45.9198709577322, 35.71036219596863, 22.941595762968063, 36.17562063038349, 61.96736365556717, 63.14593121409416, 61.78647056221962, 51.20176613330841, 57.8447824716568, 5.908797411248088, 0.5998017336241901, 0.4826094611780718, 0.15895923046628013, 40.185089483857155, 68.2884232699871, 61.04350782930851, 53.03051680326462, 45.86548827588558, 48.07081013917923, 48.799147456884384, 48.76525707542896, 50.31254164874554, 44.52490881085396, 41.95414535701275, 39.17032353579998, 40.50528310239315, 38.299353271722794, 38.23939248919487, 38.59395906329155, 37.85181328654289, 39.151848927140236, 36.43962666392326, 37.27834425866604, 36.809175834059715, 37.11124062538147, 36.601269990205765, 38.701709881424904, 36.44851438701153, 37.084550857543945, 37.583532482385635, 38.34261775016785, 37.10517235100269, 37.50860430300236, 36.31605349481106, 36.182836443185806, 38.585405722260475, 37.24640317261219, 37.2293496876955, 39.086522832512856, 38.12568739056587, 35.76658017933369, 36.577981039881706, 38.162613809108734, 38.12059946358204, 36.51639014482498, 38.02547536790371, 35.875938311219215, 37.32170753180981, 37.50306040048599, 36.9596553593874, 41.787870079278946, 48.02793323993683, 51.05999954044819, 48.119968101382256, 48.12448225915432, 43.154968321323395, 36.275619864463806, 38.00431810319424, 39.32073846459389, 39.963291585445404, 39.540511071681976, 37.32736922800541, 34.64394561946392, 35.186560302972794, 36.02548308670521, 39.68804195523262, 42.72092521190643, 43.54937955737114, 40.534606128931046, 36.92466303706169, 34.95021678507328, 35.48068732023239, 36.95488661527634, 37.47814513742924, 37.78159685432911, 37.168408557772636, 39.14270281791687, 37.47119151055813, 36.04505583643913, 38.31128843128681, 37.831355184316635, 39.02572229504585, 49.772560223937035, 50.0104920566082, 48.28955300152302, 47.9474725574255, 48.76223623752594, 38.141038566827774, 35.78114479780197, 35.96755899488926, 36.531091555953026, 36.73109382390976, 37.513456642627716, 36.44349105656147, 37.73873895406723, 37.419772669672966, 36.919119134545326, 37.88870930671692, 38.1033293902874, 37.957838997244835, 36.74488328397274, 36.50103136897087, 37.79436036944389, 39.711251109838486, 39.833437353372574, 41.27481020987034, 40.42289972305298, 40.807047709822655, 39.01716895401478, 40.792255103588104, 43.084360510110855, 42.17197246849537, 42.79013849794865, 42.480101734399796, 41.965666338801384, 41.35962925851345, 41.78721271455288, 40.61259314417839, 41.761586889624596, 40.31215466558933, 41.72836147248745, 40.594152733683586, 45.42112112045288, 42.5349859893322, 51.376720145344734, 58.6440771818161, 59.93291102349758, 59.41133961081505, 59.48814108967781, 57.51419261097908, 60.38026861846447, 58.61540772020817, 69.96883749961853, 8.234767075628042, 0.3697635023854673, 0.4053531645331532, 0.619651690358296, 4.66095719486475, 61.472512409090996, 65.75497761368752, 63.16424623131752, 69.28077802062035, 62.655012756586075, 40.29997631907463, 21.83466386049986, 39.31402042508125, 53.313255831599236, 45.43664708733559, 1.4023089339025319, 0.3392431838437915, 0.06552439648658037, 0.029552485611930024, 0.06195762362040114, 0.07683610747335479, 0.07993982100742869, 0.0872106417955365, 0.04599814230459742, 0.008509645231242757, 0.06851829442894086, 0.10120438542799093, 0.0737936953373719, 0.09159952503978275, 0.31198599957861006, 0.11320385950966738, 28.426930122077465, 71.73611506819725, 50.980967581272125, 36.30802072584629, 23.945101015269756, 46.815441101789474, 67.9315236210823, 67.92438000440598, 66.27383217215538, 56.76800765097141, 64.23140376806259, 6.178667480126023, 0.8275027340278029, 0.15635507879778743, 0.19070290523814037, 42.76074707508087, 69.4594444334507, 64.00521710515022, 55.16982480883598, 47.66907289624214, 50.564608722925186, 50.20649313926697, 50.76328106224537, 51.707439199090004, 46.556222811341286, 43.61956559121609, 41.85528226196766, 40.796484276652336, 41.304023042321205, 40.213071182370186, 39.725792929530144, 39.72430340945721, 41.545807868242264, 39.019961804151535, 39.76491563022137, 40.422287955880165, 39.290191903710365, 40.492979362607, 40.53486071527004, 39.783736020326614, 38.2847810536623, 39.70102585852146, 40.36439806222916, 39.29925061762333, 38.565092012286186, 38.63068789243698, 39.82751727104187, 39.76290173828602, 38.22167783975601, 39.31198753416538, 39.170654118061066, 39.6907664090395, 39.24793057143688, 40.37031054496765, 39.54291634261608, 39.65416677296162, 37.980124801397324, 38.34481783211231, 38.57120968401432, 38.768092319369316, 39.405314326286316, 37.48787261545658, 43.26851762831211, 50.21267160773277, 52.78111718595028, 50.43130807578564, 48.10031175613403, 43.639689311385155, 37.282250449061394, 38.67657423019409, 38.5484679043293, 38.1558121740818, 39.16201338171959, 38.279278948903084, 36.51804305613041, 36.09295606613159, 37.23932795226574, 40.07806442677975, 45.22265397012234, 46.037543043494225, 43.49623940885067, 37.80057303607464, 35.88176339864731, 36.54446303844452, 36.59648984670639, 38.24282370507717, 39.51134383678436, 38.88959459960461, 38.615967482328415, 37.97897346317768, 36.48498483002186, 39.37296666204929, 37.666968405246735, 37.66549028456211, 52.20720738172531, 52.90680304169655, 49.536262303590775, 50.95720365643501, 52.313430681824684, 40.09614385664463, 38.38937044143677, 37.50703498721123, 38.17534692585468, 38.52210491895676, 39.10471245646477, 39.46128912270069, 38.42397518455982, 38.837499395012856, 38.66997018456459, 38.786072954535484, 40.197670608758926, 39.426057413220406, 39.12466898560524, 37.217456325888634, 41.27437323331833, 43.0589284747839, 42.75469779968262, 42.72620312869549, 43.229873701930046, 42.845919504761696, 41.93599373102188, 42.67851188778877, 46.713275983929634, 43.901430666446686, 44.93581876158714, 44.08745728433132, 42.84384481608868, 45.47952018678188, 43.86746048927307, 42.71208308637142, 43.611365631222725, 42.326510176062584, 44.30493101477623, 42.7304133027792, 46.84815354645252, 44.63494710624218, 53.695785105228424, 61.46257974207401, 62.96959787607193, 62.25364789366722, 61.916689574718475, 59.21314224600792, 62.22405508160591, 61.94049529731274, 74.09235343337059, 10.041155945509672, 0.5404708860442042, 1.2655185302719474, 0.7747810974251479, 4.538798974826932, 66.62915870547295, 71.9195844233036, 67.37549185752869, 75.38664758205414, 67.9003044962883, 51.3395619392395, 26.368869356811047, 42.56844699382782, 62.27293185889721, 55.681987926363945, 2.93744211550802, 0.3398025257047266, 0.04248436991474591, 0.06800100265536457, 0.08365114568732679, 0.036939521160093136, 0.034402782475808635, 0.18670271441806108, 0.13437803776469082, 0.14980311709223315, 0.2042863005772233, 0.25213229411747307, 0.20934558066073805, 0.26842252467758954, 0.5449402774684131, 0.30083306366577744, 31.960780397057533, 83.05144429206848, 60.5108942091465, 50.446142479777336, 33.54113079607487, 50.3029053658247, 71.32230207324028, 72.28988215327263, 71.90231055021286, 60.413528233766556, 71.17969572544098, 8.162816986441612, 1.0517093469388783, 0.8048222260549664, 0.30938640469685197, 44.74041424691677, 70.80587938427925, 65.86681321263313, 57.64315769076347, 50.473770797252655, 52.518319487571716, 52.14418776333332, 52.266670390963554, 54.20816481113434, 47.9274932295084, 46.10578738152981, 44.81858745217323, 44.07918892800808, 43.3507414162159, 43.338889852166176, 42.102937772870064, 41.412602216005325, 43.37854452431202, 40.431282073259354, 42.099928334355354, 41.86152532696724, 42.42828391492367, 43.62092971801758, 42.88118541240692, 41.66235141456127, 42.60987237095833, 42.49666124582291, 43.18921208381653, 42.89116747677326, 41.44623801112175, 41.64845936000347, 41.20761841535568, 43.620686531066895, 41.982533633708954, 40.65961942076683, 41.88454449176788, 42.296035811305046, 40.22968769073486, 41.09605260193348, 42.75730825960636, 42.2650370746851, 40.16435019671917, 40.96365250647068, 40.76606310904026, 40.15080772340298, 41.428610756993294, 40.03819316625595, 46.83944061398506, 50.57258449494839, 57.71753869950771, 53.24384495615959, 51.2253362685442, 44.46761928498745, 36.4928238093853, 39.50292728841305, 39.07682575285435, 40.07338307797909, 39.955779388546944, 38.61331522464752, 36.34333983063698, 36.27286121249199, 37.74478442966938, 41.569579392671585, 48.09587359428406, 48.18409726023674, 43.42055507004261, 39.32947799563408, 36.755503714084625, 36.28599710762501, 37.064947709441185, 39.100817665457726, 38.45075994729996, 39.07171122729778, 39.058480337262154, 37.658977434039116, 35.38492485880852, 39.132948741316795, 37.32958450913429, 39.777929931879044, 56.449254155159, 55.61827674508095, 53.17843146622181, 51.72875985503197, 54.7487998008728, 41.627302095294, 41.18415467441082, 38.358101919293404, 41.8798403441906, 41.40257075428963, 41.15431487560272, 39.926805943250656, 42.12788723409176, 39.72492277622223, 41.70279264450073, 39.80578623712063, 42.50637732446194, 41.816638335585594, 38.970936834812164, 40.3104979544878, 42.63115122914314, 47.31343097984791, 45.22188261151314, 45.6670743227005, 44.573219418525696, 43.817143589258194, 44.023704305291176, 45.25244057178497, 50.34627623856068, 47.28468172252178, 48.34476783871651, 46.732613146305084, 47.040917202830315, 48.04877512156963, 47.05121845006943, 46.208343878388405, 45.73077790439129, 45.786479115486145, 46.72013081610203, 44.559239968657494, 51.034947484731674, 48.748313784599304, 55.46773262321949, 64.13594529032707, 65.76730415225029, 65.05617991089821, 65.27083039283752, 62.119997665286064, 66.41243353486061, 65.66962659358978, 77.1841411292553, 11.458248104900122, 0.36631848255638033, 3.6586685897782445, 1.25318261096254, 5.288700610399246, 70.19614890217781, 75.82822188735008, 73.64301234483719, 82.07940325140953, 72.25653514266014, 58.52492697536945, 32.58041314780712, 55.48313319683075, 69.3928188085556, 69.34598252177238, 6.264777509495616, 0.43222178996074945, 0.11740417045075446, 0.16448861657408997, 0.17459196271374822, 0.1882231078343466, 0.2902429725509137], [0.02387129505223129, 0.09879352612188086, 0.07977883433341049, 0.03733735313289799, 0.06170201311761048, 0.08217824972234666, 0.05832631730299909, 0.31470439746044576, 0.14861568080959842, 13.350038342177868, 65.39880752563477, 52.66857482492924, 41.00014954805374, 28.40715028345585, 36.89116783440113, 58.02948676049709, 65.847487449646, 60.56263983249664, 53.33916284143925, 61.02639354765415, 13.398921769112349, 0.7000104314647615, 0.30156452441588044, 0.12304874529945664, 21.619766391813755, 69.69324588775635, 61.09343335032463, 61.014785170555115, 51.881249472498894, 44.98077034950256, 45.146992430090904, 42.28594355285168, 42.58691020309925, 40.777147114276886, 40.81146687269211, 39.34949532151222, 38.994286581873894, 38.49262610077858, 39.57875981926918, 39.99195344746113, 37.808081433176994, 37.594380900263786, 38.17760020494461, 37.24327594041824, 36.468645706772804, 36.337282955646515, 36.94007121026516, 37.157765328884125, 38.405606970191, 36.0969078540802, 37.77968555688858, 37.39220514893532, 37.56084389984608, 36.65509790182114, 37.32937552034855, 36.07757829129696, 37.435652017593384, 39.21146012842655, 37.00283244252205, 37.78110288083553, 39.45847347378731, 37.52207078039646, 35.923074781894684, 37.43652977049351, 37.19121873378754, 35.140434578061104, 36.2839338183403, 37.9345690459013, 37.231572568416595, 36.901434883475304, 37.331009432673454, 44.87831264734268, 48.79955403506756, 49.459479823708534, 50.0004605948925, 48.74245069921017, 44.68508541584015, 34.963402077555656, 37.47470252215862, 39.34110917150974, 41.121131256222725, 38.15360069274902, 39.676862955093384, 37.02672176063061, 36.41439601778984, 35.708405300974846, 39.55648921430111, 42.50014565885067, 43.39941680431366, 42.719982862472534, 36.61617659032345, 34.44765195250511, 37.259166687726974, 37.26058021187782, 37.9622695595026, 38.393166437745094, 38.59202116727829, 39.78728502988815, 37.443954572081566, 37.365602776408195, 37.68205739557743, 38.17159652709961, 40.453681871294975, 49.40982028841972, 52.36603885889053, 48.73472951352596, 46.61461427807808, 49.56329025328159, 44.889316856861115, 36.72046199440956, 37.07776442170143, 37.70546793937683, 35.733297765254974, 36.66560433804989, 37.45712846517563, 36.5106600522995, 36.11994981765747, 36.54835782945156, 36.446557492017746, 37.46138423681259, 37.69023455679417, 35.87207771837711, 36.15634806454182, 36.802659183740616, 36.41346886754036, 38.714298605918884, 38.58450897037983, 39.40142333507538, 39.36809912323952, 38.1466356664896, 37.26010903716087, 38.601269870996475, 39.829724952578545, 38.37040185928345, 38.64038497209549, 39.35898721218109, 38.52791480720043, 40.78379675745964, 40.21542325615883, 40.417838394641876, 39.6049328148365, 40.39859622716904, 40.10158136487007, 42.757646441459656, 42.34799422323704, 45.34362807869911, 49.89048309624195, 56.07184320688248, 53.41067500412464, 53.11818189918995, 48.96204091608524, 60.9863892942667, 56.93490989506245, 72.22172901034355, 7.920351522043347, 0.7810021354816854, 0.5232785898260772, 0.6150915194302797, 4.390124827623367, 63.468302115798, 60.90643398463726, 65.0140629708767, 63.35069082677364, 65.15216276049614, 34.652704149484634, 26.410610117018223, 46.52856409549713, 51.5946726500988, 38.03401730954647, 0.8324794576037675, 0.10521722244448029, 0.0458893471659394, 0.07890341177699156, 0.021900729698245414, 0.041617289098212495, 0.03328745697217528, 0.044157538141007535, 0.11279622747679241, 0.06699878416839056, 0.050594207204994746, 0.06739286458468996, 0.0640930533700157, 0.10109202426974662, 0.3973219689214602, 0.225970430765301, 16.975155919790268, 74.21531483530998, 58.065736815333366, 46.19957394897938, 23.783303797245026, 42.14726999402046, 63.38051922619343, 67.440415173769, 67.67059922218323, 57.80277952551842, 65.4076686501503, 13.95926820114255, 0.8525640517473221, 0.5384978419169784, 0.18625980068463832, 25.560723021626472, 72.69664272665977, 63.274801298975945, 62.832957208156586, 52.2926077991724, 47.099339067935944, 48.16020414233208, 43.49224202334881, 43.83250616490841, 42.636983916163445, 41.866202875971794, 42.07632400095463, 40.92940494418144, 39.73788768053055, 42.28028945624828, 42.197583094239235, 40.36973297595978, 37.95093476772308, 39.42998640239239, 39.81103755533695, 38.82234960794449, 38.712626695632935, 38.851372450590134, 38.58230508863926, 40.184815898537636, 38.69661435484886, 38.20097275078297, 38.908475786447525, 39.201823845505714, 38.748599365353584, 39.260804280638695, 38.22356253862381, 37.02538043260574, 40.75719438493252, 39.90561828017235, 40.09262144565582, 40.0168839097023, 40.34966625273228, 36.8167070299387, 39.09636430442333, 39.31264489889145, 36.20336674153805, 38.42463634908199, 40.16431599855423, 38.90599071979523, 38.65470640361309, 38.79659079015255, 45.836712419986725, 51.023320108652115, 51.350387558341026, 50.87791711091995, 50.21213963627815, 45.78791543841362, 37.28400215506554, 37.38338582217693, 38.3317731320858, 40.26793643832207, 40.05973041057587, 38.65772724151611, 38.22549283504486, 36.90364256501198, 35.459115877747536, 41.23240068554878, 42.59378783404827, 45.028484389185905, 43.805823996663094, 39.33561846613884, 35.70952244102955, 37.57224328815937, 37.900196090340614, 37.88831792771816, 38.7431276589632, 39.030954614281654, 38.75484623014927, 37.53468610346317, 37.39140719175339, 40.134882777929306, 39.2861907184124, 41.44180744886398, 52.017483562231064, 53.2203584164381, 51.42919532954693, 48.573895543813705, 53.50137233734131, 47.66389757394791, 38.113942220807076, 39.4819600135088, 37.78506986796856, 37.39915877580643, 37.43741512298584, 38.743291050195694, 37.70922593772411, 37.73124575614929, 38.84006045758724, 38.55253368616104, 38.86277183890343, 38.65108519792557, 38.255826607346535, 38.587043434381485, 39.85793083906174, 38.79152946174145, 40.60818538069725, 40.045914351940155, 42.09340788424015, 40.45667231082916, 41.52729906141758, 41.519353687763214, 40.890802815556526, 42.34666809439659, 42.273457422852516, 40.82901433110237, 42.59711645543575, 41.26566410064697, 42.924552485346794, 42.433212250471115, 42.88824163377285, 41.97298474609852, 42.71801456809044, 42.73838147521019, 44.82575386762619, 44.11071203649044, 46.88113197684288, 51.77034482359886, 56.43638804554939, 55.54210223257542, 55.70418253540993, 51.45361661911011, 64.5637795329094, 60.305112451314926, 74.74615395069122, 8.408832885324955, 0.7769082707818598, 0.8971405285410583, 0.9719856467563659, 5.1122642029076815, 68.99370342493057, 67.73296147584915, 69.77611184120178, 67.92983651161194, 70.45189037919044, 42.5221236795187, 26.144886575639248, 54.790802747011185, 57.650989070534706, 50.86691290140152, 1.8260341719724238, 0.14629397570388392, 0.057872186007443815, 0.07933034707093611, 0.032322297629434615, 0.03728606701770332, 0.015660013596061617, 0.18337870918912813, 0.26551078248303384, 0.1433864192222245, 0.09749473058036529, 0.334863651660271, 0.12006876262603328, 0.17928684828802943, 0.42992496164515615, 0.38071721617598087, 18.096504248678684, 83.55831429362297, 67.4835504591465, 56.795905753970146, 36.66044041514397, 52.59450159966946, 69.33240205049515, 75.67931547760963, 71.36515617370605, 64.51578810811043, 71.79216206073761, 18.131982944905758, 1.4205783535726368, 1.0441532148979604, 0.16775963245891035, 27.232965789735317, 74.89965051412582, 66.81499153375626, 65.18234074115753, 55.63916802406311, 49.06059242784977, 51.35134510695934, 44.644537791609764, 46.47215612232685, 45.4923103004694, 45.16267418861389, 44.61649149656296, 43.94206948578358, 42.59868197143078, 45.11574670672417, 45.260640531778336, 43.36689814925194, 40.79203091561794, 42.969796657562256, 42.58333459496498, 41.70372359454632, 41.83500275015831, 40.95178574323654, 41.60378895699978, 44.23941873013973, 40.09699121117592, 40.83659492433071, 42.741919085383415, 41.635669246315956, 40.0980893522501, 42.95420989394188, 40.082042813301086, 39.329645186662674, 42.895449846982956, 40.029278844594955, 40.461992025375366, 41.80776961147785, 42.091507986187935, 37.9392845928669, 40.994278863072395, 42.65639707446098, 38.207155019044876, 38.853500336408615, 42.48108968138695, 40.46921543776989, 40.08761331439018, 40.857281014323235, 51.19760915637016, 52.65732742846012, 56.19705408811569, 54.02555041015148, 52.18462139368057, 47.49023549258709, 36.67790807783604, 37.127264365553856, 39.45868246257305, 41.295815482735634, 39.08566027879715, 40.56632682681084, 38.85829947888851, 38.71744103729725, 37.10842117667198, 43.88047479093075, 46.43819734454155, 46.42725773155689, 45.650347620248795, 39.75416600704193, 35.346402525901794, 37.92540393769741, 38.6371361464262, 38.54470230638981, 40.48535697162151, 39.753079265356064, 40.59507228434086, 38.358094319701195, 37.35422998666763, 39.32792387902737, 39.51018489897251, 42.55300082266331, 53.31127993762493, 58.27804662287235, 54.509287253022194, 51.29851654171944, 56.41971454024315, 50.277845710515976, 41.139833852648735, 40.869501158595085, 41.81213177740574, 38.45148950815201, 39.15160574018955, 40.304387882351875, 39.49698060750961, 39.8763332515955, 40.559361800551414, 39.45833668112755, 40.6765741109848, 41.51752218604088, 39.83284838497639, 41.80833578109741, 42.48841568827629, 41.03655159473419, 43.754975125193596, 43.35602693259716, 44.52460862696171, 43.6911765486002, 44.869337528944016, 43.97744178771973, 42.522515058517456, 43.93002413213253, 44.25570845603943, 43.182296454906464, 44.529612958431244, 42.8704471886158, 47.18838728964329, 46.72355443239212, 46.65376357734203, 44.610100239515305, 45.72945177555084, 44.6537446975708, 46.617878302931786, 46.60936675965786, 49.250399842858315, 53.44377502799034, 61.00114390254021, 59.185225144028664, 58.024934604763985, 54.156958758831024, 66.06511697173119, 62.06457003951073, 78.66638079285622, 9.621345922350883, 0.85860317456536, 3.025751751847565, 1.4011627016589046, 5.319859413430095, 71.67232409119606, 73.36910784244537, 75.22073328495026, 76.28439500927925, 78.64803537726402, 51.00446172058582, 37.633792385458946, 64.6270689368248, 64.97858807444572, 65.50995156168938, 2.7790219662711024, 0.2526043000398204, 0.09710871730931103, 0.15156548033701256, 0.25750752130988985, 0.09892842630506493, 0.13510353164747357], [0.028169771721877623, 0.015561068612441886, 0.03445875896431971, 0.030866311499266885, 0.02924069453001721, 0.049578110556467436, 0.04926403365971055, 0.1452876828261651, 0.014110143929428887, 5.854349657893181, 52.46296025812626, 47.86400243639946, 34.39433701336384, 29.227982237935066, 34.08101722598076, 56.53422899544239, 64.39503818750381, 60.40077231824398, 52.942163944244385, 60.1448218524456, 23.875228464603424, 0.4774539393838495, 0.11925755810807459, 0.025783267847145908, 2.5088624004274607, 55.944097861647606, 66.55727416276932, 59.945948123931885, 55.287812277674675, 48.14502775669098, 46.303289383649826, 44.55876499414444, 42.94649250805378, 41.68864980340004, 39.84430477023125, 38.448461070656776, 39.94792900979519, 40.039207711815834, 38.920232355594635, 37.86576993763447, 38.62525038421154, 36.81454494595528, 38.02377685904503, 37.20571495592594, 37.37626500427723, 35.64921207726002, 36.97324723005295, 36.7632021009922, 36.97980187833309, 36.63090839982033, 37.97021873295307, 37.426684498786926, 38.08165155351162, 37.81356833875179, 35.7672755420208, 37.48322166502476, 37.349480241537094, 37.13061198592186, 37.1793557703495, 38.199574425816536, 36.279503256082535, 37.67882376909256, 36.42003871500492, 37.64521837234497, 36.10093183815479, 38.20286504924297, 36.09054319560528, 40.090265572071075, 38.92199546098709, 36.6575563699007, 37.78023272752762, 41.43348589539528, 47.50388815999031, 49.17225703597069, 48.18231135606766, 48.553133457899094, 43.542558923363686, 36.93508207798004, 39.08230125904083, 39.61501367390156, 40.44224448502064, 38.28067347407341, 37.37868167459965, 37.588050439953804, 36.15317143499851, 34.58815701305866, 37.283907160162926, 43.84777374565601, 44.58408683538437, 41.36381283402443, 36.579668149352074, 36.191135197877884, 36.77322216331959, 36.66105978190899, 38.063416332006454, 37.064039558172226, 38.12164820730686, 38.24872098863125, 38.318872824311256, 38.84223774075508, 38.00947442650795, 37.76523873209953, 41.37214198708534, 49.628015980124474, 49.17640641331673, 47.23955154418945, 44.3805355578661, 47.2340152412653, 44.163160622119904, 43.297247886657715, 41.12577460706234, 38.74513015151024, 36.65695980191231, 37.194262370467186, 38.519418463110924, 37.26813040673733, 35.88425986468792, 36.554217115044594, 36.54337249696255, 37.49273635447025, 37.2993229329586, 37.12184585630894, 36.70895241200924, 37.44648903608322, 35.91059625148773, 35.576457381248474, 36.72476336359978, 37.965161204338074, 37.7044115960598, 38.3908561617136, 38.06992918252945, 38.924013152718544, 39.10438947379589, 36.81677162647247, 37.261138781905174, 37.36633613705635, 37.54998028278351, 38.07385437190533, 40.05090728402138, 39.6620437502861, 39.495506286621094, 39.67666916549206, 40.7124175876379, 39.862387999892235, 41.29903391003609, 39.10375490784645, 41.19855210185051, 41.410090550780296, 44.13148172199726, 46.693235859274864, 49.817272424697876, 57.8934882581234, 59.92070987820625, 67.80488401651382, 5.013329386711121, 0.6913785415235907, 0.6558532384224236, 0.3589138970710337, 6.485536638647318, 66.90092772245407, 63.40297222137451, 64.33306351304054, 61.08220495283604, 58.20781119167805, 39.06451441347599, 25.77967867255211, 25.662418864667416, 54.24211598932743, 27.652144096791744, 0.43662358657456934, 0.1472170144552365, 0.05811221883050166, 0.043018456490244716, 0.028188258620502893, 0.0417745353479404, 0.009829725568124559, 0.013878610552637838, 0.013440751772577642, 0.009621172794140875, 0.07643840537639335, 0.058628378828871064, 0.04024036767077632, 0.04069792397785932, 0.2421250709448941, 0.019125817270833068, 7.9671331867575645, 65.07098391652107, 55.89175947010517, 42.821247428655624, 31.634830087423325, 42.99566186964512, 65.92683479189873, 69.86773252487183, 65.7403863966465, 57.1052585542202, 65.61146691441536, 25.032063089311123, 0.6572134466841817, 0.4279892920749262, 0.23885022557806224, 4.0787058882415295, 59.30982045829296, 68.35592284798622, 61.24725289642811, 57.75410033762455, 50.240372121334076, 49.416348338127136, 45.6798492372036, 45.58022998273373, 43.21666181087494, 42.556196451187134, 41.38914607465267, 43.176038190722466, 41.37634076178074, 42.198647037148476, 39.381037428975105, 40.952063128352165, 40.37486270070076, 39.88922595977783, 38.55542913079262, 41.35951526463032, 38.49708326160908, 39.01669017970562, 39.68231946229935, 38.61241087317467, 38.27932454645634, 38.47505584359169, 39.90031376481056, 40.21840989589691, 40.52414149045944, 39.91392843425274, 39.12688806653023, 38.33699405193329, 39.357695281505585, 39.42674517631531, 38.74923773109913, 38.501274436712265, 39.13680553436279, 39.13922220468521, 38.35654020309448, 38.6963027715683, 39.627898782491684, 38.21052543818951, 39.98345710337162, 39.70361731946468, 39.9090912938118, 40.067052617669106, 43.66976089775562, 49.46537710726261, 50.230792835354805, 51.78256876766682, 47.84271217882633, 44.465514197945595, 37.73609809577465, 39.50083740055561, 39.93302620947361, 40.03753200173378, 37.588172033429146, 37.616590708494186, 38.335208147764206, 37.68905282020569, 37.54360042512417, 39.71814014017582, 45.94131700694561, 45.062519162893295, 43.45676712691784, 38.37702490389347, 37.05275796353817, 36.318812146782875, 36.53675705194473, 37.49388009309769, 37.45082840323448, 38.98569904267788, 37.196610644459724, 38.687168061733246, 38.06338973343372, 38.1309425085783, 36.98333188891411, 43.5027826577425, 51.440169140696526, 51.1633425951004, 51.046301275491714, 48.66943761706352, 48.96598510444164, 47.78014853596687, 43.880892768502235, 42.13479906320572, 41.18416607379913, 38.785145804286, 38.1388308852911, 40.173625499010086, 39.06172916293144, 38.1375465542078, 38.355385065078735, 38.08678887784481, 38.92790414392948, 41.390821784734726, 39.21763859689236, 38.950759917497635, 38.36345203220844, 38.280411288142204, 37.907563894987106, 39.13549840450287, 40.03027819097042, 38.7457837164402, 41.057674661278725, 40.705387964844704, 41.45210489630699, 40.636410266160965, 39.046381786465645, 38.64411257207394, 39.68933768570423, 40.18520727753639, 40.77374629676342, 41.359625458717346, 42.717505395412445, 42.53135338425636, 41.20402380824089, 43.56064975261688, 42.10749372839928, 43.18418875336647, 41.59023508429527, 43.687308356165886, 44.607349187135696, 47.747614681720734, 49.25421483814716, 51.62440985441208, 61.854768097400665, 63.29707570374012, 70.24843409657478, 5.470441058278084, 0.949080535210669, 0.1492646592669189, 0.4470825253520161, 6.454446706920862, 72.50330910086632, 67.99374148249626, 69.49969187378883, 65.60582801699638, 65.7866071164608, 43.78149010241032, 28.63394871354103, 33.4021570533514, 61.76394537091255, 37.77283452451229, 0.5413742875680327, 0.05430992168840021, 0.008891047909855843, 0.03094912404776551, 0.05706797252059914, 0.035730859453906305, 0.031151953007793054, 0.10279304900905117, 0.17886469984659925, 0.1214773440733552, 0.27280318492557853, 0.13918056443799287, 0.16404629655880854, 0.14533902460243553, 0.3636437823297456, 0.17116454662755132, 8.798175193369389, 72.69525200128555, 63.65529768168926, 50.43298378586769, 38.73364336788654, 47.69481271505356, 70.85776939988136, 73.4353306889534, 70.63842996954918, 63.877825140953064, 71.51741400361061, 29.59543202072382, 0.7402673119213432, 0.9738482593093067, 0.22672081628115848, 5.3949980065226555, 60.519173964858055, 69.24225568771362, 65.32341197133064, 58.330905586481094, 53.51599395275116, 51.592396572232246, 47.807617262005806, 48.342913538217545, 46.26435287296772, 45.33977888524532, 43.60972411930561, 45.80716900527477, 44.05676253139973, 43.00944373011589, 42.04565964639187, 44.632766023278236, 42.06674091517925, 43.44301946461201, 41.44110068678856, 43.219686448574066, 41.56729191541672, 41.71714827418327, 42.03610695898533, 42.205840051174164, 40.35636909306049, 42.51638598740101, 42.452207431197166, 42.74045616388321, 43.7418582290411, 40.56116670370102, 42.46957249939442, 40.09815014898777, 41.550447419285774, 41.82212524116039, 40.56795313954353, 39.12616230547428, 40.490957871079445, 41.11066281795502, 41.28693535923958, 40.69275364279747, 41.4998759329319, 39.91043642163277, 43.11999499797821, 42.1581944078207, 42.90884032845497, 42.535814344882965, 44.83070120215416, 51.310683488845825, 53.55934962630272, 55.12380927801132, 50.193155854940414, 45.20184628665447, 37.810251116752625, 39.79309491813183, 40.2237182110548, 39.289428144693375, 38.41474547982216, 37.90749549865723, 38.78374367952347, 37.903163731098175, 36.707816272974014, 40.50951607525349, 49.67826068401337, 47.89002723991871, 44.42970871925354, 38.507722690701485, 37.82336801290512, 38.24825741350651, 37.411633506417274, 38.083775639534, 38.595756366848946, 39.29703153669834, 38.10078352689743, 39.08600226044655, 38.88728432357311, 37.51735523343086, 37.5224469602108, 43.90331916511059, 52.20759496092796, 52.805390283465385, 54.44597885012627, 50.190644189715385, 52.179468870162964, 49.79280933737755, 47.34332397580147, 44.657221511006355, 44.42414961755276, 40.96473164856434, 40.99544160068035, 41.88161484897137, 40.83090282976627, 39.16203238070011, 42.548042088747025, 39.35981176793575, 41.35156609117985, 42.89507366716862, 41.69641278684139, 41.08812242746353, 41.818872615695, 40.883237421512604, 39.58483949303627, 42.49793417751789, 43.34596127271652, 42.51631759107113, 44.489517509937286, 42.61478550732136, 45.22404469549656, 43.30537185072899, 42.01372615993023, 40.193338841199875, 42.30741240084171, 41.8419373780489, 43.208477050065994, 45.80977946519852, 45.08314445614815, 45.49226850271225, 44.070969969034195, 46.25153236091137, 43.643470108509064, 46.61707654595375, 43.23035627603531, 46.712196841835976, 45.51091030240059, 49.71494771540165, 51.66381374001503, 54.7933866083622, 64.13548171520233, 65.67625343799591, 72.92515486478806, 6.7802963219583035, 0.9133205947000533, 5.932965539395809, 0.9850537986494601, 7.6836769469082355, 78.28527644276619, 75.05926474928856, 73.3333745598793, 71.56085327267647, 73.0389055609703, 57.10116617381573, 38.46470519900322, 43.54969874024391, 72.06763967871666, 50.25729641318321, 1.2003916874527931, 0.19112230773316696, 0.11323486643959768, 0.11686882222420536, 0.14706488902447745, 0.1376329638878815, 0.1104351737012621], [0.03439814405282959, 0.024578415213909466, 0.01977946754777804, 0.06406218744814396, 0.009891118806990562, 0.08711340560694225, 0.04184436773357447, 0.10392173688160256, 0.09394586944836192, 2.6045716647058725, 45.31968176364899, 58.95532228052616, 37.16476455330849, 25.78683938831091, 33.34386818110943, 57.37145707011223, 62.593083679676056, 60.189192071557045, 55.03737531602383, 57.11212858557701, 34.25781033933163, 0.1600077367038466, 0.08785765356151387, 0.31496794894337654, 0.09990669568651356, 18.311200328171253, 69.74160209298134, 56.780083402991295, 61.19873709976673, 47.9872640222311, 46.45840086042881, 41.94468006491661, 41.386094838380814, 39.99780513346195, 46.0327211022377, 45.270022228360176, 47.77564957737923, 41.93955413997173, 43.44587691128254, 41.54621064662933, 40.03681384027004, 38.0601941049099, 38.65528017282486, 36.336880177259445, 36.54827803373337, 35.96326142549515, 38.072539642453194, 36.99859566986561, 37.489479929208755, 38.04348260164261, 37.51544773578644, 37.68939480185509, 37.09349937736988, 36.850251629948616, 36.838194876909256, 36.426027193665504, 36.60589814186096, 36.758281365036964, 39.400484785437584, 38.1573510915041, 36.9440495967865, 37.86844879388809, 38.43809522688389, 36.875702664256096, 37.47510530054569, 37.38666504621506, 36.42199940979481, 35.858273059129715, 37.517435029149055, 36.03052921593189, 37.11321271955967, 38.478791043162346, 47.26380944252014, 47.723022401332855, 50.089372023940086, 49.10902462899685, 48.60038012266159, 38.494962975382805, 37.324690371751785, 38.70002657175064, 40.444524362683296, 39.1066275537014, 38.47569800913334, 36.145146265625954, 36.90315619111061, 35.14589108526707, 40.457196682691574, 43.52704435586929, 45.351356863975525, 43.80576319992542, 37.2053349763155, 37.18296937644482, 36.67559780180454, 37.01178476214409, 38.60493667423725, 38.43041203916073, 38.742348700761795, 37.424454018473625, 37.17901758849621, 39.71869871020317, 34.68900740146637, 46.445637345314026, 46.9304533302784, 46.99592001736164, 52.09251433610916, 48.97564798593521, 45.85677154362202, 42.779100090265274, 39.371579736471176, 38.32527168095112, 39.07701574265957, 37.32397980988026, 37.08803907036781, 36.76235854625702, 37.07495257258415, 38.77902053296566, 38.33311066031456, 36.40833154320717, 38.54751035571098, 36.974326372146606, 36.414734199643135, 36.1372996866703, 36.750153601169586, 35.704278722405434, 36.45292975008488, 37.73117356002331, 36.61244139075279, 36.68772295117378, 37.96730048954487, 36.08947545289993, 37.60458715260029, 36.98496200144291, 38.54086071252823, 37.777743861079216, 36.7171523720026, 38.09413768351078, 39.44323629140854, 38.41518245637417, 39.968565702438354, 36.87957085669041, 40.505047515034676, 39.35727350413799, 40.6301824003458, 39.59958270192146, 42.917325273156166, 43.11738073825836, 42.27103695273399, 41.121302247047424, 44.55891318619251, 45.98608240485191, 52.47563257813454, 57.6093927025795, 61.4946386218071, 62.56961613893509, 2.4298594146966934, 0.5791189684532583, 0.7521563395857811, 0.6646201992407441, 7.846433138474822, 67.29697287082672, 60.80925799906254, 66.92308813333511, 62.78218053281307, 59.09926615655422, 32.0674292743206, 23.16555004566908, 36.05868570506573, 57.7868127822876, 29.968182519078255, 0.3602634777780622, 0.11891666741576046, 0.05900947537156753, 0.06910080614034086, 0.023991582347662188, 0.03326610167277977, 0.03399785186047666, 0.08510928033501841, 0.049014809337677434, 0.06241282360861078, 0.014874295357003575, 0.03282012286945246, 0.02071701343083987, 0.022262389393290505, 0.11780880420701578, 0.030578892547055148, 3.185634585097432, 56.98267713189125, 64.8909343779087, 44.91321757435799, 27.575697898864746, 33.30519385635853, 64.17725667357445, 65.01939788460732, 65.37643432617188, 59.08747918903828, 65.53564578294754, 37.67566993832588, 0.17170913459267467, 0.16408902942202985, 0.372531921020709, 0.09772308942046948, 22.192325368523598, 71.15787729620934, 57.56122648715973, 64.28274661302567, 49.363550171256065, 49.6471631526947, 43.760188445448875, 43.320453241467476, 42.09741286933422, 47.86304488778114, 47.59140506386757, 49.454722478985786, 44.504986479878426, 44.52792584896088, 44.30848002433777, 42.659349516034126, 40.536175444722176, 41.0346744954586, 38.04743818938732, 40.10446161031723, 39.10737991333008, 39.03679110109806, 40.29315568506718, 40.275566428899765, 40.428804606199265, 40.15534847974777, 39.48956720530987, 38.7957776337862, 39.673674926161766, 38.95802892744541, 38.32505129277706, 39.328395053744316, 37.473589181900024, 40.10196514427662, 40.10669209063053, 39.2959675937891, 38.98547485470772, 38.916998729109764, 38.89441654086113, 39.72803860902786, 39.47998411953449, 39.435678496956825, 39.5575987547636, 40.81656239926815, 37.59432390332222, 39.63761866092682, 40.08410230278969, 47.870173305273056, 51.42503075301647, 51.33635111153126, 50.082167610526085, 48.96121256053448, 40.35804860293865, 38.173804208636284, 39.70767170190811, 38.63867126405239, 38.24065402150154, 37.75480829179287, 36.15934990346432, 36.80183082818985, 37.20226094126701, 42.46204890310764, 44.73796337842941, 46.87869630753994, 45.65217912197113, 40.28988406062126, 37.52711310982704, 36.15694843232632, 37.56944663822651, 38.71271029114723, 37.1812404692173, 37.511465549468994, 39.30881090462208, 38.25521484017372, 39.322452172636986, 34.499226585030556, 46.74658879637718, 47.072413712739944, 50.081730633974075, 54.285536259412766, 50.66654585301876, 48.595736771821976, 45.95074810087681, 42.8674453496933, 41.61106176674366, 41.07774518430233, 38.18465642631054, 39.17419172823429, 39.16246935725212, 39.122168719768524, 40.658688470721245, 38.23039837181568, 38.07140350341797, 39.00652952492237, 38.366712257266045, 38.923876360058784, 39.632564932107925, 38.464974984526634, 38.665566220879555, 40.44612407684326, 38.397076427936554, 39.131774604320526, 38.85705314576626, 40.083182752132416, 39.577855467796326, 39.99299839138985, 38.21593634784222, 40.2155676484108, 39.8727348446846, 38.14513474702835, 38.75525280833244, 41.153554916381836, 40.563632771372795, 41.86798498034477, 40.462410002946854, 42.579933777451515, 41.0871534794569, 41.96013763546944, 41.427626609802246, 47.50715218484402, 44.55708548426628, 44.59899723529816, 42.76484325528145, 47.642493322491646, 48.75336371362209, 54.22744877636433, 60.357625633478165, 64.38925489783287, 63.26340191066265, 2.4952655425295234, 0.5771902750711888, 0.56945436517708, 0.4735237034037709, 8.516986481845379, 71.77270710468292, 67.99179598689079, 72.75963574647903, 69.34074640274048, 66.22919216752052, 41.44858628511429, 26.3608555868268, 40.26272691786289, 66.12391501665115, 39.25991132855415, 0.31552589556667954, 0.07218009559437633, 0.07469311894965358, 0.03721633482200559, 0.012429490216163686, 0.07381081668427214, 0.011689897382893832, 0.11349856635206379, 0.1369357161456719, 0.17102181678637862, 0.12276376801310107, 0.12189292450784706, 0.1682604633970186, 0.13845337845850736, 0.2269194001564756, 0.2253922977251932, 3.540730280801654, 64.15166884660721, 76.70461446046829, 52.11443156003952, 35.063644498586655, 44.960756823420525, 71.65835604071617, 71.43128782510757, 73.31664025783539, 63.515062406659126, 70.3565838932991, 40.416413471102715, 0.3501630260143429, 0.7231485180091113, 0.857207402586937, 0.34490318794269115, 25.26630152016878, 72.49224409461021, 60.3315894305706, 66.27900749444962, 51.84001788496971, 52.286607921123505, 45.961748510599136, 46.37163631618023, 44.41566087305546, 50.72339840233326, 48.976723328232765, 51.12467207014561, 47.447552382946014, 48.164129331707954, 47.60701462626457, 45.726503133773804, 43.15525710582733, 43.950060456991196, 41.186867728829384, 41.9563340395689, 40.569807440042496, 41.162438839673996, 42.950588688254356, 41.56572259962559, 42.67383433878422, 41.89817056059837, 43.600038439035416, 42.67893746495247, 42.72519238293171, 42.050888165831566, 40.90116485953331, 40.457223281264305, 41.19403034448624, 44.76154871284962, 42.80486650764942, 38.694558665156364, 40.346371829509735, 44.2158941924572, 40.35882756114006, 41.69304616749287, 40.225374922156334, 40.742321982979774, 40.88571108877659, 42.225838378071785, 40.03786638379097, 41.27291791141033, 42.56717786192894, 51.832182705402374, 53.72528292238712, 56.13830924034119, 52.306777238845825, 50.81312298774719, 40.81503488123417, 37.585580572485924, 40.20868241786957, 40.053992718458176, 39.11802314221859, 40.40553465485573, 36.98153458535671, 38.45527030527592, 38.38821530342102, 43.02606403827667, 47.34411433339119, 49.82822723686695, 47.872418984770775, 41.37847624719143, 39.46236066520214, 38.09598058462143, 37.78798811137676, 40.102234929800034, 37.567368149757385, 38.67921128869057, 37.97071650624275, 37.69143529236317, 39.99656639993191, 34.780141711235046, 49.70944181084633, 50.2686882019043, 52.74582467973232, 56.89947299659252, 56.84103973209858, 52.80545487999916, 47.28938207030296, 44.40942920744419, 43.705820962786674, 43.771112859249115, 42.814164608716965, 39.84416417777538, 40.798327177762985, 40.41303925216198, 43.415740728378296, 40.61669312417507, 39.37730982899666, 40.61050705611706, 40.328262001276016, 40.01117281615734, 40.72770416736603, 41.35153949260712, 40.76707765460014, 41.264250576496124, 42.45028093457222, 40.49766071140766, 43.231758400797844, 43.319491893053055, 40.94548188149929, 42.82616436481476, 40.758710503578186, 42.786844074726105, 42.85992555320263, 40.03210209310055, 41.88571482896805, 42.56927154958248, 43.087506741285324, 45.49574911594391, 43.15704680979252, 45.70730276405811, 44.09647420048714, 43.861521407961845, 44.10548731684685, 49.06368166208267, 50.090014189481735, 45.57117126882076, 46.56797178089619, 50.00155873596668, 52.39529348909855, 56.44690588116646, 65.06132483482361, 65.75893700122833, 69.68328282237053, 2.9843966709449887, 0.6940477795433253, 3.8718955731019378, 0.8782200969289988, 9.021457862108946, 77.88625985383987, 72.9248508810997, 78.0489519238472, 73.6590626835823, 74.81885924935341, 47.52120763063431, 32.53855459392071, 51.08967214822769, 75.06021469831467, 50.23453563451767, 0.8198000129777938, 0.3728538646828383, 0.16394566133385524, 0.11674331763060763, 0.18905769742559642, 0.1882231968920678, 0.2557113458169624], [0.0713815150083974, 0.01644134481466608, 0.12899602734250948, 0.011008193923771614, 0.01524497307400452, 0.05508818227099255, 0.006045883783372119, 0.02428656749543734, 0.1599326907307841, 0.6206481868866831, 37.076445892453194, 59.33136910200119, 39.933056607842445, 34.72319796681404, 31.87247883528471, 48.719545528292656, 61.041744723916054, 57.785703241825104, 56.86262257397175, 54.0301937609911, 46.77436150610447, 0.9671029087621719, 0.4317421844461933, 0.08396184581215493, 0.05720472436223645, 1.3512703101150692, 53.720799162983894, 61.01510435342789, 57.98992708325386, 49.53985311090946, 43.36252458393574, 42.14179448783398, 45.96918851137161, 51.147839426994324, 53.522635996341705, 52.642014250159264, 48.55838477611542, 45.2800726890564, 44.54539731144905, 42.20409594476223, 42.062378749251366, 39.3847232311964, 37.797825783491135, 37.14912459254265, 37.93138861656189, 39.01301957666874, 38.702329248189926, 38.86649563908577, 37.5370229780674, 35.78852020204067, 36.64054088294506, 34.12251479923725, 35.68582311272621, 37.056990936398506, 37.235182374715805, 35.51363155245781, 38.02231393754482, 37.84002631902695, 36.73580937087536, 38.153619691729546, 36.55411832034588, 37.767127230763435, 37.658555656671524, 36.080036759376526, 37.780882492661476, 37.2528400272131, 37.91871629655361, 37.68394209444523, 37.652065604925156, 37.518445774912834, 37.17430964112282, 36.38361766934395, 47.14607276022434, 48.98488149046898, 46.83733932673931, 50.27819909155369, 45.441157445311546, 40.21173745393753, 38.749739304184914, 37.17014126479626, 40.038694739341736, 39.476830288767815, 38.24329487979412, 37.97459989786148, 35.088897943496704, 37.68801927566528, 37.64316268265247, 41.59212738275528, 44.215924590826035, 42.77249224483967, 36.28399081528187, 36.20453707873821, 35.68639688193798, 36.30592703819275, 36.66667968034744, 37.422291934490204, 37.64053702354431, 36.685959845781326, 37.62520484626293, 39.00764286518097, 40.17965577542782, 39.38025087118149, 49.54186700284481, 42.404083013534546, 50.435620844364166, 48.09981398284435, 46.52651980519295, 37.62614719569683, 37.39507019519806, 34.94742773473263, 37.75007754564285, 35.43067820370197, 37.07638509571552, 34.949388429522514, 37.77191497385502, 38.1937113404274, 37.120215743780136, 35.74711762368679, 36.63378104567528, 38.68117958307266, 36.67039208114147, 37.858402132987976, 36.864128485322, 34.979387819767, 36.96409732103348, 35.67823491990566, 37.12863229215145, 36.319788694381714, 35.907298028469086, 37.29574352502823, 37.259254083037376, 38.29104691743851, 37.89524495601654, 37.28441633284092, 37.24618278443813, 37.72402994334698, 38.355179876089096, 38.2280994951725, 39.23820689320564, 38.43662470579147, 41.34979158639908, 41.66980281472206, 43.9505810290575, 43.72313283383846, 51.065433248877525, 52.08623707294464, 56.83884344995022, 46.549618765711784, 44.078584760427475, 44.35050956904888, 54.223390594124794, 56.19928456842899, 61.96769803762436, 57.551825791597366, 1.8264345754869282, 0.47224088630173355, 0.7484996295534074, 0.5991015618201345, 11.830951105803251, 71.03585064411163, 60.695720091462135, 67.77866542339325, 57.755126282572746, 57.94548086822033, 36.515535190701485, 32.640613317489624, 34.54023778438568, 54.91576664149761, 22.695950344204903, 0.13635826588142663, 0.12760993296978995, 0.10543818207224831, 0.02838099066138966, 0.03536976008035708, 0.01864439906057669, 0.08137278942740522, 0.046518113231286407, 0.04116417083423585, 0.04327899485360831, 0.019102664118690882, 0.042523024676484056, 0.06629041163250804, 0.01755079436406959, 0.04457365292182658, 0.11853370437165722, 1.2880726950243115, 46.33477069437504, 66.97987228631973, 46.10893741250038, 35.00680334866047, 41.09419450163841, 58.79238702356815, 65.61813175678253, 62.44877502322197, 62.29527845978737, 59.96103711426258, 50.48588454723358, 0.9793982177507132, 0.3047497331863269, 0.6242120987735689, 0.031691486947238445, 2.9498669737949967, 57.56990522146225, 63.512489944696426, 59.81912612915039, 52.1643228828907, 44.667005985975266, 43.86458404362202, 46.382754519581795, 52.641801461577415, 54.180274307727814, 53.963032364845276, 50.98618470132351, 47.10649028420448, 46.47418521344662, 45.7904689013958, 43.96348513662815, 43.180780336260796, 39.64771091938019, 39.17999021708965, 39.339129477739334, 39.42647539079189, 41.528674587607384, 42.12430402636528, 38.73080492019653, 38.82196202874184, 39.099924713373184, 37.04268090426922, 38.9244045317173, 38.036095798015594, 39.46681022644043, 39.72923934459686, 39.11840692162514, 40.45678250491619, 39.8506124317646, 39.970891177654266, 39.077741503715515, 38.99499334394932, 39.326525554060936, 37.417515590786934, 40.16228690743446, 38.81832182407379, 38.57656739652157, 39.65927369892597, 41.54303781688213, 41.30946435034275, 39.312375113368034, 40.00640407204628, 48.80804657936096, 51.20796360075474, 50.467767119407654, 51.72797329723835, 45.78027404844761, 38.03880125284195, 36.84378817677498, 37.76517413556576, 40.411766320466995, 38.47684554755688, 38.02871659398079, 38.2159249484539, 37.03693941235542, 38.41979540884495, 40.44591888785362, 43.99000011384487, 45.57999439537525, 43.88199470937252, 38.76931965351105, 37.728658095002174, 37.171364799141884, 37.49435506761074, 37.26912595331669, 38.14002022147179, 38.06603439152241, 37.99225755035877, 38.42524811625481, 38.42337481677532, 39.58072051405907, 44.07212510704994, 52.467159032821655, 46.25999830663204, 52.25635014474392, 50.19565612077713, 47.7956935018301, 39.45373132824898, 40.346835404634476, 38.09528902173042, 40.090694949030876, 38.33793260157108, 39.165406599640846, 38.01676623523235, 38.644427955150604, 38.683660849928856, 38.668412268161774, 36.397593319416046, 39.674282893538475, 39.73792567849159, 39.1104843467474, 39.35604616999626, 39.73909221589565, 37.38409258425236, 39.69828240573406, 38.92359137535095, 38.80363941192627, 38.66621978580952, 39.38923358917236, 38.59107121825218, 39.914122223854065, 38.886832147836685, 40.21821990609169, 40.79162813723087, 39.77443411946297, 39.484445080161095, 41.82011514902115, 39.64955762028694, 42.4328550696373, 42.45999701321125, 43.820316419005394, 43.4822029620409, 46.16807743906975, 47.12600603699684, 53.971984684467316, 54.84482064843178, 59.37377482652664, 48.87060262262821, 46.22773043811321, 46.66662588715553, 56.25293768942356, 59.538051411509514, 65.1168018579483, 60.623284578323364, 2.2934004245325923, 0.5872196587733924, 0.4403852659743279, 0.41123076633084565, 12.033777572214603, 75.0217379629612, 64.61500838398933, 73.17469507455826, 63.2379736751318, 67.5335481762886, 41.11709967255592, 30.09871121495962, 41.79811432957649, 63.14524345099926, 28.577649034559727, 0.3525961423292756, 0.048088683251990005, 0.09470872304518707, 0.029097827391524334, 0.06319584877928719, 0.03725981354364194, 0.03322628173918929, 0.14318700414150953, 0.09912390800309367, 0.20159945881459862, 0.1154019302339293, 0.14333273225929588, 0.20605203317245468, 0.10521030562813394, 0.17204363539349288, 0.2305838285246864, 1.304240827448666, 51.36484578251839, 72.78165176510811, 54.528214037418365, 45.01993104815483, 45.475526601076126, 63.344930335879326, 69.87020999193192, 71.12290397286415, 67.27812588214874, 65.59249833226204, 56.01232700049877, 1.434348220936954, 1.4046993618831038, 1.2555543961934745, 0.1612619959632866, 4.48093805462122, 60.58641895651817, 64.18576061725616, 61.058304235339165, 54.004313349723816, 47.3788520693779, 45.09704031050205, 49.487522318959236, 54.32185471057892, 58.42254526913166, 55.056951865553856, 53.5169743001461, 49.52144309878349, 50.11799968779087, 47.58814103901386, 47.73766301572323, 47.77247674763203, 43.42614457011223, 42.77276962995529, 41.672257483005524, 42.140958532691, 43.53465914726257, 44.05720330774784, 41.97762809693813, 41.04111894965172, 41.8157871812582, 38.99645246565342, 41.6494283080101, 41.65018446743488, 42.90369160473347, 39.52129170298576, 42.561599761247635, 43.68910565972328, 41.61706164479256, 43.470662981271744, 39.79677312076092, 42.606980726122856, 41.457834988832474, 38.97334210574627, 41.68000526726246, 39.80105169117451, 41.96193873882294, 41.95743218064308, 42.82393768429756, 42.45349556207657, 42.57495604455471, 43.16008664667606, 51.91095247864723, 53.51682610809803, 54.0698978304863, 54.142226949334145, 47.85171389579773, 39.52229864895344, 37.99602694809437, 37.70922593772411, 39.98758748173714, 40.22672764956951, 38.50848264992237, 39.69053082168102, 37.56745554506779, 39.734840244054794, 42.540453895926476, 45.47285154461861, 48.53430546820164, 47.050108909606934, 38.42175990343094, 37.44520850479603, 37.01880298554897, 37.8564490377903, 37.97968402504921, 40.05518205463886, 38.04178789258003, 37.25699320435524, 36.95114381611347, 38.363463431596756, 39.485706612467766, 44.1631568223238, 53.90124008059502, 47.12529547512531, 55.27037501335144, 52.9584726691246, 50.63406519591808, 41.588718965649605, 42.424833700060844, 39.67784710228443, 42.69863560795784, 40.056675374507904, 41.04665905237198, 39.10949259996414, 40.70031523704529, 41.1466620862484, 41.09526984393597, 39.69155676662922, 41.22209943830967, 41.619075536727905, 41.73506811261177, 42.2823641449213, 41.246167346835136, 39.544421061873436, 43.49681697785854, 42.426395416259766, 41.93107679486275, 42.06924118101597, 40.54885156452656, 42.97661729156971, 43.213272392749786, 42.11939848959446, 42.71362580358982, 44.243469312787056, 41.64253167808056, 42.05446757376194, 44.464845433831215, 42.66005627810955, 44.912127032876015, 46.02228686213493, 46.75464816391468, 46.5798195451498, 49.316497296094894, 48.90342906117439, 56.41583114862442, 58.78036066889763, 63.08309018611908, 51.60320319235325, 49.41920578479767, 50.09790636599064, 59.12295788526535, 61.62569738924503, 67.60439157485962, 62.7024532109499, 2.939976342022419, 0.961628471268341, 2.371988520026207, 0.8418741566129029, 13.340434357523918, 82.79770150780678, 70.82562312483788, 77.68953680992126, 68.1344935297966, 74.09175306558609, 50.66792517900467, 43.52924443781376, 51.05665571987629, 73.53718802332878, 36.86537101864815, 0.5803148355334997, 0.2350745492731221, 0.21716257760999724, 0.07945946592371911, 0.14917977241566405, 0.07123166797100566, 0.24460279033519328], [0.04409398061397951, 0.07749028838588856, 0.07069512488669716, 0.037267142251948826, 0.02577427301730495, 0.023445664082828443, 0.03965549964050297, 0.03314638954179827, 0.29962950793560594, 0.10114764081663452, 32.900108993053436, 61.560690477490425, 45.183497071266174, 23.547406755387783, 18.226575069129467, 48.382488414645195, 64.12846729159355, 57.37201564013958, 55.71765661239624, 50.68980060517788, 57.42188796401024, 5.87359182536602, 0.7673374749720097, 0.392902004532516, 0.4547584993997589, 0.24928250641096383, 34.99684028327465, 69.50648590922356, 54.060101956129074, 50.82833357155323, 39.69108559191227, 45.830024778842926, 52.55898870527744, 56.56418278813362, 54.032336845993996, 49.2364925891161, 47.3883705586195, 49.18390341103077, 42.1585363894701, 44.424670189619064, 41.20994009077549, 40.44732101261616, 37.54844516515732, 38.750795647501945, 38.100547939538956, 37.906876131892204, 37.525581791996956, 38.159577772021294, 35.50742268562317, 37.80618913471699, 36.458390057086945, 35.07184825837612, 35.02584792673588, 36.426559165120125, 35.99748998880386, 36.58289037644863, 34.98850353062153, 37.08169341087341, 37.90067866444588, 38.84309269487858, 37.502574026584625, 37.07760103046894, 36.066992059350014, 38.060277700424194, 36.41858719289303, 38.06994818150997, 38.07298421859741, 36.16587035357952, 37.889039888978004, 35.29353216290474, 37.835702151060104, 37.1709506213665, 46.913996413350105, 51.3852658867836, 48.5983282327652, 48.41757953166962, 50.23652672767639, 43.94372999668121, 37.84850746393204, 40.63174411654472, 39.377059042453766, 37.47831612825394, 38.33790600299835, 38.880228102207184, 37.07100458443165, 36.539990678429604, 36.9166112691164, 43.3286190032959, 45.4618701338768, 43.052271232008934, 36.733423098921776, 34.860214814543724, 37.33703970909119, 36.78950808942318, 38.18167358636856, 37.62859046459198, 38.54908347129822, 39.052100479602814, 38.771538734436035, 36.464693918824196, 40.97128629684448, 43.35621692240238, 45.33063657581806, 50.27767851948738, 46.873247399926186, 51.7826371639967, 44.54874113202095, 39.077277928590775, 37.746821120381355, 38.58112335205078, 37.11870342493057, 38.532660752534866, 37.06972025334835, 37.21203401684761, 37.35984228551388, 38.24415743350983, 35.476788729429245, 35.66674813628197, 36.22043542563915, 35.36549650132656, 36.030548214912415, 36.81595467031002, 36.28210611641407, 37.677053064107895, 35.20081713795662, 38.01995426416397, 36.228395998477936, 37.853960171341896, 36.133553087711334, 36.86003230512142, 36.40533730387688, 37.28906728327274, 36.84173248708248, 39.27230626344681, 39.19712349772453, 39.287497848272324, 39.47847940027714, 38.30968111753464, 38.228745460510254, 39.8291739821434, 41.13015957176685, 44.297844395041466, 47.267396450042725, 50.73999211192131, 55.56505300104618, 58.96192252635956, 60.347130596637726, 56.48149162530899, 47.590637505054474, 42.61968344449997, 50.18315479159355, 55.126488134264946, 63.676154762506485, 58.30413602292538, 3.3876101346686482, 0.8107996615581214, 0.4114656412275508, 0.45171676261816174, 19.75574031472206, 73.08172926306725, 58.95412154495716, 67.52249076962471, 57.58617214858532, 53.75121273100376, 27.948788478970528, 35.88129602372646, 37.37784571945667, 57.53508388996124, 14.187190420925617, 0.2853033266728744, 0.06065824178222101, 0.051882096886401996, 0.06061040665372275, 0.04019206127850339, 0.008955406956374645, 0.03323056393128354, 0.154162076942157, 0.03382075687113684, 0.09013302638777532, 0.031375365433632396, 0.09215361991664395, 0.04628414746548515, 0.10450487941852771, 0.02242137041321257, 0.31220971257425845, 0.22291517205303535, 40.82373261451721, 68.46788004040718, 51.6618150472641, 27.992030158638954, 28.632955066859722, 56.1480975151062, 68.16215604543686, 65.0584901869297, 62.822735756635666, 55.94488821923733, 64.14264053106308, 5.680843843147159, 0.42471977532841265, 0.38020703417714685, 0.4070835857419297, 0.3680308547336608, 39.105970188975334, 69.596738666296, 57.32269048690796, 52.71276265382767, 41.08207695186138, 47.29436360299587, 54.71635714173317, 57.06931248307228, 55.84990851581097, 52.37851358950138, 49.2631671577692, 51.18021748960018, 46.53375841677189, 47.80035585165024, 44.212546572089195, 44.18021410703659, 38.70589345693588, 41.200888976454735, 39.420122131705284, 40.44091835618019, 39.647665321826935, 39.25814442336559, 38.677725568413734, 39.60082143545151, 37.40003652870655, 37.603538408875465, 36.90591104328632, 39.67989519238472, 38.44794809818268, 39.67467047274113, 37.783986926078796, 38.82583022117615, 38.429165706038475, 40.192103907465935, 38.305083364248276, 38.45218487083912, 39.01376433670521, 40.19278407096863, 38.40298891067505, 39.46985766291618, 38.689284548163414, 38.62262852489948, 38.1700424104929, 37.77862161397934, 38.79992701113224, 40.66903531551361, 48.80155652761459, 51.13279603421688, 50.93092046678066, 48.29915128648281, 49.285601153969765, 44.82398696243763, 38.94690312445164, 40.63494734466076, 39.572858735919, 37.899151146411896, 38.78463663160801, 37.671683952212334, 37.3175885528326, 36.91006422042847, 38.02031524479389, 44.88225683569908, 46.82781703770161, 44.4971626996994, 38.35232622921467, 35.63491344451904, 37.939144000411034, 38.033386543393135, 39.34334345161915, 38.428762927651405, 38.411527052521706, 38.55710484087467, 38.2046889513731, 36.14967942237854, 39.02362480759621, 41.83730162680149, 50.495175048708916, 51.73711560666561, 47.509329468011856, 52.41630256175995, 46.42886124551296, 40.97663260996342, 38.024407625198364, 39.3771730363369, 39.62510213255882, 40.155865252017975, 38.41597281396389, 38.72667834162712, 38.56113642454147, 38.18691350519657, 37.27084346115589, 38.23379538953304, 37.80187636613846, 37.53312438726425, 39.18464496731758, 39.08480152487755, 39.30841952562332, 39.321798607707024, 38.41945342719555, 39.876340851187706, 39.36758615076542, 38.91911901533604, 38.220040127635, 38.705448880791664, 38.91751170158386, 39.47742685675621, 39.84296724200249, 41.4524544775486, 39.5806635171175, 41.18368349969387, 41.52824521064758, 40.509098097682, 41.32401756942272, 42.008509039878845, 42.431935518980026, 46.239464208483696, 50.557594299316406, 51.96265250444412, 58.30960772931576, 61.249350383877754, 62.37290449440479, 59.63631793856621, 50.31449854373932, 44.35842074453831, 54.32783558964729, 58.747188448905945, 65.76942443847656, 60.50747059285641, 3.8013685075566173, 0.8722497860435396, 0.5449525080621243, 0.46423563617281616, 20.992330759763718, 77.8175899386406, 62.77025677263737, 73.54522839188576, 61.90711408853531, 64.06547427177429, 37.08607457578182, 39.04752932488918, 43.36242578923702, 66.56061038374901, 18.343076817691326, 0.25490400788839906, 0.0588811617490137, 0.07443237278494053, 0.0751264812424779, 0.08102628067717887, 0.03996337589342147, 0.05366583398426883, 0.18145869893487543, 0.24635075591504574, 0.19697092124260962, 0.13052418362349272, 0.16885479009943083, 0.13800862419884652, 0.20553153532091528, 0.17532823258079588, 0.5267820612061769, 0.44230808154679835, 48.3385893702507, 77.09742218255997, 61.97544202208519, 32.00949378311634, 28.927205577492714, 61.602435037493706, 73.7782546877861, 68.62317010760307, 69.19937118887901, 59.647249951958656, 70.36881923675537, 7.332483641803265, 0.9535928524564952, 2.42859598249197, 0.9864997398108244, 0.843449825188145, 44.073310643434525, 71.94505825638771, 60.47138772904873, 55.78489400446415, 44.3712754547596, 50.92473439872265, 56.576456129550934, 60.26312090456486, 56.2120670825243, 55.245938524603844, 54.19977866113186, 53.873334378004074, 48.89603465795517, 51.890099197626114, 47.3250013589859, 47.496303766965866, 41.977920681238174, 44.883031994104385, 42.25427605211735, 43.46142187714577, 42.33934588730335, 42.25787065923214, 39.272123873233795, 43.02121929824352, 39.50312487781048, 39.87246125936508, 40.39117142558098, 41.484076380729675, 41.18230797350407, 42.63753488659859, 40.637440010905266, 41.47885166108608, 42.22375229001045, 42.6202230155468, 40.20037226378918, 40.30199021100998, 40.934124290943146, 42.40196652710438, 40.417640805244446, 41.31231799721718, 40.91174729168415, 40.55630676448345, 40.86835741996765, 38.40611234307289, 42.184891775250435, 42.14282803237438, 50.04455342888832, 55.826900750398636, 52.146995812654495, 50.67113220691681, 52.83083751797676, 46.261518225073814, 38.55075918138027, 40.7943107932806, 39.739909172058105, 36.71095110476017, 38.89905609190464, 39.56965170800686, 38.15322071313858, 39.91436541080475, 39.22777645289898, 47.13164113461971, 49.06308129429817, 46.309008076786995, 39.38425585627556, 36.051146909594536, 37.64270670711994, 40.18985442817211, 40.47090254724026, 39.51605558395386, 38.43215234577656, 38.69137443602085, 38.66520144045353, 36.19393564760685, 39.30508330464363, 42.77000717818737, 51.339778527617455, 55.51643081009388, 49.8425030708313, 55.881207436323166, 48.65679569542408, 42.69684970378876, 41.093784123659134, 42.799030020833015, 40.90808428823948, 43.36052969098091, 41.396403685212135, 42.22792446613312, 40.662222281098366, 42.08214908838272, 39.34564612805843, 40.59412993490696, 39.3066830188036, 38.24392944574356, 39.46452274918556, 40.82790479063988, 42.235683649778366, 41.45033039152622, 39.77209724485874, 42.48226761817932, 42.298923656344414, 42.85440444946289, 41.64832256734371, 42.14847072958946, 41.460399851202965, 43.15263144671917, 42.02780820429325, 45.53509600460529, 42.059240117669106, 43.847655951976776, 44.3265138566494, 42.84587770700455, 42.20248483121395, 44.98711220920086, 44.87681932747364, 48.758219853043556, 53.0757799744606, 55.853020548820496, 59.64397832751274, 64.49495762586594, 63.74907284975052, 62.72465541958809, 52.1454568952322, 47.498610243201256, 57.418103367090225, 60.86517579853535, 68.64767119288445, 63.295270800590515, 5.052935611456633, 1.061263696756214, 3.3924798108637333, 0.5975913803558797, 23.099657781422138, 83.20069268345833, 65.46982571482658, 80.56108832359314, 67.57338523864746, 71.65232196450233, 40.43959982693195, 46.49164527654648, 51.88534565269947, 76.67705833911896, 26.375762186944485, 0.4389576113317162, 0.18174917553551495, 0.1461633131839335, 0.17643955419771373, 0.1917775796027854, 0.27798566152341664, 0.17217732587596402], [0.0645885408448521, 0.017104197722801473, 0.10624330097925849, 0.022990781362750567, 0.13636399526149035, 0.049352976348018274, 0.04266020696377382, 0.08612656441982836, 0.2413305573281832, 0.08529668004484847, 23.07244934141636, 60.31321361660957, 46.27646282315254, 36.32624454796314, 35.203351601958275, 45.21115958690643, 64.38955128192902, 51.16518169641495, 57.02615439891815, 53.41281808912754, 60.61087444424629, 13.661610223352909, 0.5542559525929391, 0.2784723916556686, 0.45421848306432366, 0.3204612963600084, 31.75590869039297, 69.70264658331871, 49.183667823672295, 48.40006247162819, 38.59036445617676, 53.32266792654991, 52.38469585776329, 57.03153870999813, 46.195454970002174, 51.146186515688896, 48.62187556922436, 48.283993899822235, 44.018437787890434, 42.54387751221657, 39.12718825042248, 38.316144570708275, 35.20109452307224, 37.89823919534683, 35.95081329345703, 38.411192670464516, 36.727240830659866, 38.69993157684803, 34.11636292934418, 34.91930544376373, 34.615496546030045, 36.012738570570946, 35.661052241921425, 37.390316650271416, 36.059077084064484, 40.138397589325905, 38.24074521660805, 39.89896863698959, 39.12748083472252, 38.091166242957115, 36.634609401226044, 38.3900012075901, 38.02078261971474, 37.25236885249615, 35.67963324487209, 38.0831790715456, 36.681088507175446, 37.92428679764271, 36.05654641985893, 38.60974721610546, 35.356111004948616, 39.67372812330723, 45.94504080712795, 47.9707121104002, 48.74909654259682, 52.779768258333206, 49.33291241526604, 39.4077879935503, 37.15377934277058, 38.1496375054121, 39.07262697815895, 40.46233780682087, 38.36354322731495, 36.52313858270645, 36.51221416890621, 37.58775405585766, 37.130505591630936, 42.66774706542492, 43.3002383261919, 43.40617284178734, 37.955859303474426, 36.428755447268486, 37.43426889181137, 39.70770590007305, 39.22818683087826, 37.805896550416946, 40.384909361600876, 39.335546270012856, 39.457417130470276, 38.662290796637535, 37.426855489611626, 48.3198107779026, 52.258652821183205, 50.07489860057831, 48.71248930692673, 48.9320757240057, 47.63775497674942, 40.25891572237015, 35.56725047528744, 38.30958232283592, 36.78384639322758, 37.133112251758575, 36.54119901359081, 38.85461367666721, 36.647129729390144, 37.736778259277344, 37.64983132481575, 36.14131227135658, 37.59320676326752, 37.093202993273735, 37.01976053416729, 35.916782319545746, 36.92577637732029, 36.44311107695103, 35.48816531896591, 35.95384553074837, 34.85060513019562, 38.052491918206215, 37.203727662563324, 38.448461070656776, 36.99713654816151, 38.05912256240845, 38.29592205584049, 38.925008699297905, 37.73367002606392, 37.50679939985275, 39.72102038562298, 39.208674877882004, 39.144302532076836, 39.29532162845135, 42.48359754681587, 44.700311198830605, 47.908992022275925, 51.71294130384922, 55.469434931874275, 56.480587273836136, 58.506448566913605, 61.04635767638683, 56.60782724618912, 43.81861411035061, 45.47986976802349, 55.10082811117172, 62.26318918168545, 58.23098234832287, 2.269997955299914, 0.6165584188420326, 0.43289183056913316, 0.40443123900331557, 23.292303644120693, 71.86004921793938, 60.736693292856216, 65.75940057635307, 56.670903861522675, 54.7517978399992, 31.864989437162876, 50.11905983090401, 49.366749599575996, 49.881276190280914, 8.717404827475548, 0.4080565116601065, 0.06980363483307883, 0.04230332298902795, 0.07817671561497264, 0.10385630914242938, 0.04531515121925622, 0.04633192693290766, 0.12356070103123784, 0.020329714388935827, 0.097092479118146, 0.015343815084634116, 0.09657230039010756, 0.07081792064127512, 0.03991869860328734, 0.0454516210447764, 0.3475492412690073, 0.0234504323816509, 29.776731692254543, 69.02887433767319, 50.761168375611305, 34.27944637835026, 31.490791216492653, 53.56935068964958, 69.43523213267326, 60.21706737577915, 63.60603332519531, 59.08924609422684, 67.28577107191086, 14.21938894316554, 0.5871124332770705, 0.30589890433475375, 0.9475393616594374, 0.4676471999846399, 34.22947905957699, 72.59455740451813, 51.77650809288025, 53.18420335650444, 39.662936702370644, 55.325259268283844, 55.00894904136658, 58.92467312514782, 48.803813606500626, 52.54376292228699, 50.85598848760128, 52.895027473568916, 48.31135243177414, 45.34235134720802, 41.336830481886864, 40.80623835325241, 38.55332404375076, 39.84242387115955, 39.46241766214371, 40.858952924609184, 38.97751808166504, 39.86696295440197, 38.282820358872414, 39.04155604541302, 36.262730956077576, 39.150082021951675, 39.36567485332489, 40.34321799874306, 39.948859959840775, 40.519186556339264, 40.93111105263233, 40.25173030793667, 39.347869008779526, 41.4410512894392, 38.111103773117065, 40.38911193609238, 38.703476786613464, 38.03115226328373, 38.21519158780575, 40.47276444733143, 37.69335798919201, 39.22336108982563, 38.49517576396465, 39.93537828326225, 37.70218871533871, 42.46434397995472, 48.94004389643669, 50.50670363008976, 49.2002235352993, 53.06314565241337, 50.52215360105038, 42.16437667608261, 36.020900532603264, 38.17408159375191, 38.41379173099995, 39.26065608859062, 40.16109757125378, 37.36120641231537, 38.17808657884598, 39.55597244203091, 38.70258003473282, 43.67388367652893, 44.13097634911537, 44.170091450214386, 38.77432778477669, 37.631869688630104, 37.76398479938507, 39.21831116080284, 39.229075983166695, 38.42990666627884, 39.931658282876015, 38.88614818453789, 39.0618659555912, 38.07497911155224, 37.25603185594082, 47.15610422194004, 52.3476592451334, 52.29659378528595, 51.49813503026962, 51.793493181467056, 49.355300813913345, 41.65168538689613, 36.83619238436222, 41.39275588095188, 38.10609944164753, 38.791183680295944, 37.579485699534416, 40.30731372535229, 37.71717891097069, 38.66674415767193, 38.084527999162674, 37.77937777340412, 38.94034847617149, 38.53013388812542, 38.575347661972046, 38.80571410059929, 37.80205115675926, 38.48555088043213, 38.665463626384735, 38.016382455825806, 37.56378874182701, 39.12044361233711, 39.567102044820786, 40.145936384797096, 38.30525055527687, 39.675749614834785, 39.59555111825466, 39.88948434591293, 38.92935186624527, 40.45928657054901, 41.63370095193386, 41.19403034448624, 41.1060156673193, 43.45495082437992, 43.81118930876255, 48.155632987618446, 50.557533502578735, 54.0685261040926, 56.889494732022285, 59.01070810854435, 56.84393897652626, 63.58854666352272, 59.717325791716576, 45.25206819176674, 49.146049842238426, 58.95019255578518, 64.4577044248581, 61.2302640080452, 2.717496855184436, 0.6202681479044259, 0.7342400634661317, 0.548325777053833, 26.33629560470581, 76.82065263390541, 64.92590010166168, 72.45560646057129, 61.693861931562424, 63.42686153948307, 33.27156566083431, 50.87277598679066, 52.9125065356493, 60.77829346060753, 12.089094053953886, 0.3828741644974798, 0.07654167522559874, 0.09285241132602096, 0.08122571060084738, 0.12669314310187474, 0.03777268953854218, 0.059721836951212026, 0.1453442790079862, 0.11582085033296607, 0.14808001345954835, 0.12693524651695043, 0.3224343998590484, 0.15437719586770982, 0.10118377598701045, 0.1501114052371122, 0.5279367242474109, 0.17558385792654008, 32.75659829378128, 77.14665994048119, 62.01857350766659, 47.376910373568535, 46.369953006505966, 58.05434122681618, 73.72787699103355, 64.4530838727951, 69.97424080967903, 63.94562870264053, 73.53290945291519, 17.626492269337177, 0.8265917922835797, 1.971063008531928, 1.5919188782572746, 0.5663789645768702, 37.379270642995834, 73.61003011465073, 53.27786073088646, 54.10846196115017, 42.908851727843285, 57.53267481923103, 57.460011318325996, 59.0681192278862, 52.451192289590836, 55.70123389363289, 52.89053611457348, 55.01812934875488, 50.60602270066738, 47.64323428273201, 45.10607622563839, 43.46332937479019, 41.03821210563183, 42.8414623439312, 40.89513838291168, 43.28801438212395, 41.8967342376709, 43.306861370801926, 38.10732677578926, 39.994282722473145, 37.42383845150471, 41.70356020331383, 41.49066522717476, 44.70584750175476, 42.74615965783596, 43.98025743663311, 43.037934601306915, 42.469450905919075, 42.16373071074486, 44.074306190013885, 39.026964828372, 42.80873090028763, 41.51531830430031, 39.67582941055298, 39.59965109825134, 40.80007128417492, 38.50921221077442, 42.34455160796642, 39.546187967062, 41.65789045393467, 39.40660625696182, 44.42304387688637, 49.71934027969837, 53.23762089014053, 52.21878156065941, 55.50348490476608, 53.4114957600832, 43.6176048964262, 36.66852258145809, 36.66457079350948, 39.28410843014717, 40.785130485892296, 40.60813598334789, 39.07679535448551, 37.27750450372696, 41.52272030711174, 38.913578912615776, 45.78278571367264, 47.06531189382076, 47.90527582168579, 39.39340956509113, 37.91420213878155, 39.55388255417347, 42.02942691743374, 40.21840989589691, 38.54440212249756, 41.19012415409088, 40.193639025092125, 39.05086174607277, 38.49511116743088, 37.719561383128166, 48.37152600288391, 56.88184954226017, 55.13075910508633, 54.86136496067047, 55.16150325536728, 53.197430446743965, 44.95940409600735, 38.86215627193451, 44.224971905350685, 39.71941687166691, 42.1210628002882, 39.0249053388834, 43.698909133672714, 40.20238995552063, 40.699935257434845, 39.962459430098534, 39.00866501033306, 41.73653103411198, 40.76767422258854, 40.47481253743172, 40.41171692311764, 41.021926179528236, 40.67767985165119, 41.178249791264534, 40.10296069085598, 40.26717267930508, 41.371081843972206, 41.89007319509983, 43.84546346962452, 40.976005643606186, 42.10591301321983, 42.50109180808067, 42.98740491271019, 40.65285958349705, 42.51722574234009, 44.77959394454956, 44.21593599021435, 43.807454109191895, 45.74418358504772, 45.88409587740898, 49.77377995848656, 53.132343739271164, 58.91827806830406, 59.207617342472076, 59.90749418735504, 59.46921810507774, 63.90839830040932, 62.8863937407732, 49.92727272212505, 51.38031095266342, 60.83909399807453, 66.77384734153748, 64.61467400193214, 3.0306751001626253, 1.035457500256598, 1.8657446536235511, 0.692517589777708, 28.218674696981907, 84.31668519973755, 69.0125048160553, 78.17885175347328, 66.30682200193405, 69.5978482067585, 45.28653234243393, 59.67569522559643, 62.12283991277218, 73.83312374353409, 16.107531376183033, 0.6051855103578418, 0.15527480863966048, 0.4065184551291168, 0.12351445780950598, 0.15104001009603962, 0.13645660044858232, 0.130397662287578], [0.042702297869254835, 0.016810581837489735, 0.057251405451097526, 0.06234072396182455, 0.05077580703073181, 0.05701760295778513, 0.09942812175722793, 0.022972645128902514, 0.21085301617858931, 0.038644690794171765, 8.648130744695663, 57.77334250509739, 46.78528971970081, 28.237962462008, 27.43925292044878, 48.13617043197155, 59.59483556449413, 53.29163119196892, 61.227870136499405, 51.127559915184975, 60.46153865754604, 24.974334686994553, 0.09133692350587808, 0.21675450028851628, 0.6961323833093047, 0.27778492541983724, 31.598703525960445, 70.67914858460426, 52.35304355621338, 44.89922292530537, 43.90883646905422, 55.385030061006546, 55.597446262836456, 49.96472351253033, 49.184397384524345, 53.99823747575283, 44.743058905005455, 47.038200348615646, 43.141197860240936, 42.00623296201229, 37.62255258858204, 38.40426184237003, 36.26658774912357, 36.50899574160576, 35.785666555166245, 38.5561016947031, 37.33001008629799, 37.15157926082611, 36.56962148845196, 36.9510830193758, 36.82482339441776, 39.27529290318489, 34.746775701642036, 36.31721243262291, 35.08557692170143, 37.21128925681114, 34.68111902475357, 38.14964510500431, 36.798680797219276, 37.48530015349388, 37.08670534193516, 36.80208541452885, 37.28798434138298, 37.521584406495094, 37.001859694719315, 39.01194803416729, 38.30102898180485, 37.363440692424774, 37.15861648321152, 36.617339327931404, 34.52177457511425, 41.29780277609825, 46.344517171382904, 50.82362562417984, 51.58968351781368, 46.37474834918976, 36.96692816913128, 44.53896425664425, 40.887071415781975, 40.100513622164726, 37.506681606173515, 38.40841121971607, 36.58995799720287, 37.084155678749084, 37.730083018541336, 37.939094603061676, 38.660360500216484, 42.460430189967155, 42.66667552292347, 43.48805844783783, 38.577414751052856, 36.31670705974102, 38.703613579273224, 40.5625194311142, 37.54083037376404, 37.30214238166809, 38.76737795770168, 37.94901967048645, 39.61005114018917, 39.31192673742771, 40.00982008874416, 47.55110062658787, 50.69091394543648, 48.10889169573784, 48.34831304848194, 45.52107095718384, 47.80767425894737, 40.589083805680275, 35.795382633805275, 36.890236884355545, 37.325461730360985, 38.734863102436066, 37.390529438853264, 37.94622682034969, 36.65308780968189, 36.961676850914955, 37.17878200113773, 37.755807638168335, 35.34318029880524, 38.37495781481266, 37.43413969874382, 36.71215184032917, 36.553464755415916, 34.919719621539116, 37.83825181424618, 35.761879831552505, 35.19183062016964, 35.98690755665302, 37.81262218952179, 38.294698521494865, 37.573987394571304, 35.21258890628815, 36.92680612206459, 37.05651976168156, 36.691849529743195, 37.10036180913448, 38.122157379984856, 36.45850785076618, 38.0391014367342, 38.650595024228096, 39.447332471609116, 41.9535905867815, 45.65620690584183, 52.140984535217285, 55.705930441617966, 52.136869356036186, 50.874926671385765, 54.29643027484417, 63.480769246816635, 51.36938273906708, 46.26600198447704, 52.839656844735146, 61.99660308659077, 48.711809143424034, 0.620022586081177, 0.3605136409169063, 0.46039214241318405, 0.20739998115459457, 28.78878090530634, 69.41133141517639, 58.770625591278076, 67.0520456135273, 59.58779074251652, 48.20534951984882, 31.47171813994646, 54.567735716700554, 57.93289594352245, 45.9835859388113, 3.591072354465723, 0.266488844063133, 0.19807321834377944, 0.028270521979720797, 0.16397211147705093, 0.10151741589652374, 0.1457811813452281, 0.05225689630606212, 0.05397028893639799, 0.05741829962062184, 0.03975317369622644, 0.05628082843031734, 0.06756090166163631, 0.014836020018265117, 0.12987542781047523, 0.03532632217684295, 0.28529937844723463, 0.012297174562263535, 13.04212186485529, 67.34006255865097, 54.51676145195961, 33.75469073653221, 32.264498099684715, 53.88572171330452, 65.81230893731117, 56.80181443691254, 66.93968564271927, 56.3413817435503, 66.83445408940315, 27.11217787116766, 0.13523599016480148, 0.1804446877213195, 1.2964576575905085, 0.17604303953703493, 33.09802137315273, 72.82630696892738, 52.91302710771561, 46.83199301362038, 43.959073573350906, 57.48284429311752, 55.68198412656784, 51.45222209393978, 49.11584906280041, 55.850729271769524, 45.653083473443985, 48.18644553422928, 46.35293751955032, 45.63784249126911, 40.718261674046516, 40.573261454701424, 38.092237785458565, 38.92188526690006, 38.65536756813526, 38.406621515750885, 38.95622782409191, 38.95291820168495, 38.17794218659401, 40.08393511176109, 39.34669107198715, 39.90629084408283, 36.838878840208054, 37.89500176906586, 36.83200500905514, 39.10617917776108, 37.29831978678703, 38.655774146318436, 38.37716169655323, 38.573656752705574, 37.97338776290417, 38.647019416093826, 39.593761414289474, 36.843620985746384, 38.92972804605961, 40.669278502464294, 38.770638182759285, 38.86005498468876, 39.843050837516785, 38.59484061598778, 38.31385709345341, 45.24306647479534, 48.743100464344025, 52.16595679521561, 52.50582195818424, 48.127195313572884, 42.056770250201225, 43.88603389263153, 38.22332315146923, 38.46543475985527, 37.207664251327515, 39.17931765317917, 36.18545450270176, 37.472225055098534, 37.752995789051056, 38.67635004222393, 39.96389575302601, 42.64846310019493, 45.76501786708832, 44.808555990457535, 38.80682744085789, 38.553514033555984, 39.16848063468933, 38.89076113700867, 37.62398511171341, 36.61681495606899, 37.798931524157524, 38.44871185719967, 38.519137278199196, 38.72544340789318, 39.08983625471592, 48.114952370524406, 53.049671575427055, 50.580830052495, 50.949600264430046, 50.24863287806511, 50.74919521808624, 42.78161555528641, 38.435769751667976, 39.16395507752895, 39.68698941171169, 39.12029542028904, 38.21796923875809, 39.674358889460564, 37.86595992743969, 37.66861751675606, 39.63397465646267, 39.35180939733982, 37.76458516716957, 40.634711757302284, 38.60829569399357, 38.63446868956089, 38.113573640584946, 37.6483304053545, 39.3454447388649, 39.500411823391914, 36.99653998017311, 39.76473703980446, 40.31593546271324, 40.324169620871544, 39.33737017214298, 37.92706444859505, 39.559316262602806, 39.28306728601456, 38.5489846765995, 39.526565819978714, 40.22752560675144, 39.84753839671612, 39.51221778988838, 40.48438422381878, 40.876181200146675, 43.87517787516117, 48.89099232852459, 55.2337259799242, 57.349733635783195, 56.34158693253994, 52.42489390075207, 56.60094581544399, 64.83148276805878, 55.40863439440727, 47.64859579503536, 54.87548120319843, 64.38341081142426, 52.725469172000885, 0.4735774645814672, 0.3506247012410313, 0.49548361566849053, 0.42520110262557864, 31.367162950336933, 75.9424589574337, 63.67545560002327, 72.86678239703178, 61.304679214954376, 58.1258799880743, 36.78751699626446, 58.20549711585045, 62.25904360413551, 57.80335709452629, 5.1216948218643665, 0.32323621620889753, 0.20999705273425207, 0.10017395790782757, 0.11737393535440788, 0.07495390964322723, 0.10644673107890412, 0.04076862467627507, 0.12624893803149462, 0.10501866825507022, 0.1332743008970283, 0.16017798538086936, 0.17137727583758533, 0.1785187699715607, 0.24958574795164168, 0.1913324394263327, 0.42488640232477337, 0.32887223409488797, 13.74367156997323, 75.59672310948372, 62.182314321398735, 41.20862536132336, 38.248375207185745, 60.64224936068058, 70.25924071669579, 63.34562949836254, 74.2234767973423, 61.21609836816788, 71.94489866495132, 31.406867019832134, 0.4227577743586153, 1.6347229876555502, 2.185914167203009, 0.4042976821074262, 35.40382884442806, 76.84684842824936, 56.30520008504391, 49.26232360303402, 47.2605986148119, 60.15834152698517, 57.49284915626049, 52.86755874752998, 53.26274894177914, 57.78842009603977, 48.03025111556053, 50.078060030937195, 49.03455622494221, 47.157206162810326, 43.90052251517773, 42.30058416724205, 40.00744141638279, 40.16140915453434, 39.9698880314827, 41.82940945029259, 41.652175560593605, 40.288497135043144, 40.55585078895092, 40.809380784630775, 42.74128071963787, 43.942890241742134, 39.79652613401413, 40.639556497335434, 37.93919339776039, 42.193809896707535, 38.7913166731596, 41.884365901350975, 41.11135058104992, 41.21485322713852, 40.45815423130989, 40.33152602612972, 40.56259922683239, 39.140229150652885, 41.27629593014717, 43.192878887057304, 42.191264033317566, 39.71939407289028, 41.74421802163124, 41.164958104491234, 40.07522217929363, 48.18566657602787, 51.82437792420387, 55.25099225342274, 56.76021806895733, 49.48660656809807, 41.14989571273327, 45.62550835311413, 38.79964962601662, 39.59160692989826, 37.61902257800102, 39.71103452146053, 36.83108165860176, 39.03039984405041, 39.653308019042015, 40.82138434052467, 41.46784745156765, 43.44257868826389, 48.78676012158394, 46.82109519839287, 40.43233081698418, 40.09743958711624, 40.64584515988827, 41.05230174958706, 38.84150058031082, 37.64912076294422, 39.027242213487625, 38.838228955864906, 40.7144770771265, 38.77085857093334, 38.49140636622906, 49.11831133067608, 55.23344099521637, 53.353978246450424, 53.502234891057014, 51.97397209703922, 52.85995535552502, 45.73684997856617, 40.02405792474747, 40.91100633144379, 40.18720977008343, 42.834162935614586, 41.20731443166733, 41.745654344558716, 39.737268313765526, 41.16122670471668, 41.74282729625702, 40.03761559724808, 39.85011845827103, 42.8210536390543, 41.05937696993351, 40.130243226885796, 41.61725543439388, 39.90561068058014, 42.20860630273819, 41.61404460668564, 39.38106782734394, 42.19752609729767, 43.053266778588295, 44.827832356095314, 41.34959019720554, 38.808677941560745, 41.86962269246578, 41.22969523072243, 40.74452966451645, 41.26147672533989, 41.793193593621254, 42.03598536550999, 41.842784732580185, 43.08287858963013, 43.19833539426327, 46.790563836693764, 51.56398929655552, 58.20750340819359, 60.77042408287525, 58.17944571375847, 55.25623977184296, 60.28566889464855, 67.2700323164463, 58.34264315664768, 51.67317643761635, 59.24248047173023, 66.91537454724312, 54.66764755547047, 1.1585995112545788, 0.6294722040183842, 1.2078350130468607, 0.450097574503161, 33.928246423602104, 82.92898446321487, 66.93475350737572, 78.90734866261482, 68.41341376304626, 64.38359320163727, 41.81589737534523, 65.41251718997955, 70.79413041472435, 69.51679095625877, 7.855036351829767, 0.3155939653515816, 0.37815119605511427, 0.21644205611664802, 0.22757213388103992, 0.13384300866164267, 0.2208298261393793, 0.15010928269475698], [0.09312727313954383, 0.03463386499788612, 0.01604199886060087, 0.020956105581717566, 0.06338477731333114, 0.04244751115038525, 0.06599321859539486, 0.010070902226289036, 0.19508346158545464, 0.03860542747133877, 3.0178013909608126, 48.22886645793915, 51.880212128162384, 35.25382809340954, 22.873195633292198, 39.5875259488821, 61.536774560809135, 61.81794427335262, 58.37664373219013, 53.433523178100586, 56.476985067129135, 35.34544117748737, 0.09091490122955292, 0.2833552483934909, 0.6482297193724662, 0.18641609698534012, 28.23943678289652, 71.68900519609451, 48.30733984708786, 47.533192187547684, 47.29305647313595, 61.33155137300491, 49.290738478302956, 48.87803502380848, 56.13249935209751, 48.25185142457485, 45.20208187401295, 43.04747208952904, 40.471689105033875, 39.17207524180412, 37.64295369386673, 37.095817252993584, 37.03859992325306, 36.507251635193825, 36.76638253033161, 38.28854665160179, 36.77607960999012, 37.74382688105106, 36.855328157544136, 37.88366697728634, 36.0640662163496, 34.96173396706581, 36.16449102759361, 36.6582365334034, 36.927839666604996, 37.08449386060238, 35.621074587106705, 36.16892918944359, 37.522279769182205, 39.246946424245834, 38.789082393050194, 37.74659313261509, 37.36521519720554, 37.75798872113228, 38.64880912005901, 38.835200518369675, 35.233081206679344, 39.3892639875412, 37.47310280799866, 36.37567989528179, 35.93911752104759, 41.31449908018112, 45.96471235156059, 49.744502529501915, 44.80935014784336, 43.88889133930206, 47.36580356955528, 46.08516588807106, 42.723421677947044, 38.71973231434822, 39.06836740672588, 38.34906220436096, 37.17197276651859, 36.34602628648281, 36.632192730903625, 37.09710918366909, 39.818739742040634, 39.86310616135597, 43.36636617779732, 42.98511363565922, 39.79299992322922, 36.537403017282486, 37.56862208247185, 36.73771306872368, 36.80098347365856, 37.171562388539314, 37.991394996643066, 38.53894181549549, 40.26936896145344, 38.5696479678154, 40.04074662923813, 48.57725456357002, 53.88023480772972, 47.13310405611992, 49.49970446527004, 46.964256316423416, 48.85569602251053, 41.99297547340393, 36.123837009072304, 35.71147933602333, 37.52386048436165, 35.22299274802208, 36.11252501606941, 37.37590782344341, 36.73425905406475, 37.48942293226719, 38.583638817071915, 36.57818242907524, 36.81794956326485, 36.278507709503174, 38.18500600755215, 37.59899005293846, 35.06783567368984, 36.30268581211567, 36.161234602332115, 37.43925042450428, 38.18077303469181, 39.0230206400156, 38.314343467354774, 39.1122018545866, 38.44935402274132, 37.787364944815636, 37.81938202679157, 36.27762995660305, 37.92631968855858, 36.480831652879715, 37.544181793928146, 37.0712211728096, 38.41445669531822, 39.96942065656185, 38.739449456334114, 39.95448365807533, 43.19360464811325, 48.81715089082718, 54.40239138901234, 59.02762480080128, 57.56813831627369, 47.93576538562775, 54.76502873003483, 54.15898784995079, 53.68660859763622, 51.107443794608116, 68.20963829755783, 33.483924865722656, 0.17340693098958582, 0.5661069229245186, 0.5355692678131163, 0.22590243519516662, 36.44069440662861, 64.65267956256866, 60.68358354270458, 66.07847705483437, 61.92365080118179, 45.606357380747795, 24.611323066055775, 48.44169303774834, 50.74575260281563, 36.87121130526066, 1.3936965772882104, 0.1025703082268592, 0.07292431386304088, 0.03390445628610905, 0.072800879861461, 0.0485314782417845, 0.034866621062974446, 0.06287674012128264, 0.08158067241311073, 0.04225779965054244, 0.041685214164317586, 0.07026417457382195, 0.019846104987664148, 0.05255111333099194, 0.1883912636549212, 0.020480472412600648, 0.3199179848888889, 0.036150666419416666, 4.0342088509351015, 57.6382901519537, 57.653097957372665, 37.68395349383354, 28.83181929588318, 51.78782768547535, 68.17580491304398, 66.63225173950195, 63.86768728494644, 58.38621161878109, 62.281409204006195, 37.824367359280586, 0.23303900146856904, 0.5746228597126901, 1.2587330443784595, 0.24432654812699184, 30.243040770292282, 72.28914499282837, 48.62622633576393, 50.26984713971615, 48.74955631792545, 62.02258229255676, 51.671493127942085, 51.59116543829441, 57.50722758471966, 51.7281898856163, 46.29780247807503, 46.619379222393036, 43.663829416036606, 41.718778386712074, 39.41557377576828, 39.40803878009319, 38.30499216914177, 39.26692955195904, 39.15432259440422, 40.03992207348347, 39.7958991676569, 39.65015798807144, 38.72270755469799, 40.27080148458481, 37.29211091995239, 38.920771926641464, 38.38621661067009, 38.63421410322189, 38.94222177565098, 40.28463274240494, 38.32858890295029, 38.47581960260868, 39.055307507514954, 41.62073604762554, 39.69124898314476, 39.41368907690048, 39.2944248765707, 39.902924224734306, 41.00979723036289, 40.374729707837105, 37.07440160214901, 40.044413432478905, 38.6123538762331, 37.96110302209854, 39.11960005760193, 43.51957395672798, 47.568822875618935, 50.53291842341423, 46.741223484277725, 47.76290126144886, 45.907620415091515, 44.88592743873596, 42.30256386101246, 38.000594303011894, 39.60171818733215, 38.83678883314133, 38.89796935021877, 38.292768225073814, 38.51613163948059, 38.87206993997097, 41.299117505550385, 42.85886541008949, 43.768316209316254, 44.53656658530235, 39.68592926859856, 37.70267128944397, 39.10951919853687, 37.28936366736889, 36.47554613649845, 37.52057746052742, 38.965947702527046, 37.808408215641975, 39.56050179898739, 38.08211512863636, 40.59779293835163, 49.18334104120731, 52.68581070005894, 50.293580666184425, 52.542482390999794, 48.24671410024166, 51.39278568327427, 43.86168859899044, 36.7999043315649, 37.341599464416504, 39.055090919137, 37.47366517782211, 38.61133933067322, 38.38328316807747, 39.095782935619354, 40.111609026789665, 39.87060695886612, 39.61697816848755, 39.10635016858578, 38.4242145717144, 38.27902816236019, 39.673021361231804, 38.56430545449257, 38.384214118123055, 39.203461557626724, 39.517837688326836, 38.71437080204487, 39.87088434398174, 41.99312746524811, 40.42397126555443, 39.044075310230255, 39.4368602335453, 38.87121878564358, 39.661428183317184, 39.410193264484406, 36.99329875409603, 39.91622731089592, 38.73843111097813, 40.746368765830994, 41.77572973072529, 40.34118510782719, 42.192472368478775, 46.879292875528336, 51.0317138582468, 58.0240074545145, 59.654074385762215, 59.16593737900257, 50.873117968440056, 56.352173164486885, 57.24771291017532, 55.578185096383095, 54.29799199104309, 70.01953437924385, 37.335804775357246, 0.055843213631305844, 2.2647323878481984, 0.16190387948881835, 0.28127373196184635, 38.644762337207794, 71.87246695160866, 64.49567958712578, 74.20490339398384, 67.76769161224365, 51.56310774385929, 24.065368361771107, 53.65514248609543, 57.7255866676569, 45.61749078333378, 2.088779266923666, 0.11243123182794079, 0.037659255976905115, 0.018423018264002167, 0.01716074566502357, 0.0296884470662917, 0.08681434235768393, 0.02586022856121417, 0.165980392775964, 0.06594630001927726, 0.15779025881784037, 0.1868235509027727, 0.17633920098887756, 0.18307387945242226, 0.23532929888460785, 0.12533351371530443, 0.42342532135080546, 0.20628759084502235, 4.776568841189146, 65.41519984602928, 69.46958988904953, 47.88755737245083, 30.66320702433586, 51.43761947751045, 74.15542244911194, 71.55271410942078, 68.1478688120842, 62.13885225355625, 68.30356165766716, 42.37280309200287, 0.3878364904085174, 1.3523501646704972, 2.4222168372943997, 0.2483168535400182, 32.14804954826832, 75.21020025014877, 51.87484301626682, 53.43378536403179, 52.00657434761524, 64.00345399975777, 51.24336250126362, 53.44102397561073, 59.758914560079575, 54.66659501194954, 48.585154339671135, 50.15258923172951, 45.677280575037, 43.45498502254486, 43.126378655433655, 41.72476306557655, 40.63561610877514, 40.62541365623474, 42.35840946435928, 42.77589686214924, 41.55428521335125, 42.682467475533485, 42.477373480796814, 42.03935578465462, 40.34297861158848, 40.42231075465679, 41.6920430213213, 41.3757099956274, 43.30640159547329, 42.08096735179424, 41.144849583506584, 40.17011448740959, 41.64861895143986, 44.27805885672569, 42.31995552778244, 41.05188377201557, 40.42487941682339, 41.50369092822075, 43.27639080584049, 43.931924030184746, 38.24151657521725, 43.833592906594276, 41.557952016592026, 40.366438552737236, 41.24055504798889, 46.51062145829201, 50.92410743236542, 52.03988716006279, 50.04416964948177, 52.40940973162651, 47.54395321011543, 46.57263793051243, 43.00008103251457, 39.13746289908886, 38.53879362344742, 40.043417885899544, 39.671786427497864, 38.494157418608665, 40.28737239539623, 40.39371348917484, 43.5876739025116, 44.61876757442951, 46.32476583123207, 46.72891214489937, 44.245141223073006, 38.64380098879337, 40.27541443705559, 37.72159047424793, 36.96139566600323, 37.48852618038654, 38.88772889971733, 38.36982809007168, 40.207025706768036, 37.67736844718456, 39.814050793647766, 52.859438583254814, 56.178028509020805, 51.63386754691601, 55.81876538693905, 50.14547601342201, 53.43168027698994, 46.382978707551956, 39.17035013437271, 40.20432785153389, 40.61048425734043, 37.972304821014404, 41.85195364058018, 41.40445165336132, 41.07091695070267, 41.926992014050484, 42.933823987841606, 41.85168765485287, 41.29084914922714, 40.31568467617035, 42.14212886989117, 43.731769770383835, 40.366104170680046, 41.831704527139664, 40.85103414952755, 43.025817051529884, 43.449775502085686, 44.12081949412823, 43.40664401650429, 43.880094811320305, 41.32136531174183, 41.22527986764908, 41.20155394077301, 42.549543008208275, 41.516910418868065, 39.954495057463646, 41.695755422115326, 40.121059119701385, 43.04168879985809, 45.42240545153618, 43.54124419391155, 43.7825920432806, 49.18431378901005, 55.63257537782192, 59.835868030786514, 63.590051382780075, 60.59303820133209, 53.770766481757164, 58.56273874640465, 60.12037016451359, 57.9163858294487, 57.46811628341675, 74.2187650501728, 39.96726617217064, 0.1870511972811073, 2.327156150713563, 2.2313378797844052, 0.41001287230756134, 41.99513755738735, 76.26807108521461, 70.48690170049667, 77.86669090390205, 71.38521149754524, 59.566238299012184, 34.69934284687042, 60.18841311335564, 64.66506689786911, 60.19171133637428, 3.5391946882009506, 0.233390289649833, 0.2676238550338894, 0.1430662567145191, 0.1652734080562368, 0.10311583129805513, 0.12381141335936263, 0.18496948789106682], [0.05603610523394309, 0.04699926241301, 0.08439405035460368, 0.02146891478332691, 0.06399817721103318, 0.08429412759141997, 0.06207407401234377, 0.07747266980004497, 0.22094540821854025, 0.041925781333702616, 1.525718355551362, 43.607695028185844, 60.07583275437355, 36.874072551727295, 24.816658347845078, 42.05267786979675, 52.999601662158966, 57.98527993261814, 57.759617641568184, 53.20648916065693, 53.27921345829964, 47.19245687127113, 1.4785665669478476, 0.5808637873269618, 0.7190160616301, 0.1291165075963363, 19.275715872645378, 69.98472064733505, 53.27764794230461, 50.09126052260399, 55.339314714074135, 55.93888834118843, 47.71325692534447, 59.01410132646561, 50.90064749121666, 48.943760097026825, 43.35933655500412, 40.866062343120575, 37.02459007501602, 38.53179819881916, 37.56443850696087, 38.19760613143444, 35.225185230374336, 36.78267605602741, 37.11055666208267, 36.74979642033577, 37.47557267546654, 38.482142463326454, 37.32852816581726, 38.2398484647274, 36.46025575697422, 36.84151589870453, 36.69483616948128, 36.3187475502491, 35.245928317308426, 36.658244132995605, 35.78843280673027, 38.17804858088493, 37.697617560625076, 37.32267647981644, 36.60521797835827, 37.56150506436825, 38.24823461472988, 38.06961379945278, 39.580298736691475, 37.955258935689926, 38.140662387013435, 37.8226650506258, 35.100304931402206, 36.63218133151531, 34.83313366770744, 40.753409788012505, 47.992017567157745, 43.490231931209564, 45.465723127126694, 48.35915766656399, 47.003014236688614, 42.7080363035202, 41.3843659311533, 39.47938375174999, 38.647524788975716, 38.522659689188, 36.89856983721256, 37.43954300880432, 37.53580704331398, 36.365914419293404, 40.60928352177143, 40.448415353894234, 42.814867570996284, 40.42607255280018, 40.46951562166214, 38.61300364136696, 38.48429694771767, 37.49430947005749, 36.7451910674572, 38.005165457725525, 36.93429172039032, 39.702579975128174, 39.49052095413208, 39.42907065153122, 42.45596542954445, 50.103047490119934, 51.277420073747635, 49.280653819441795, 46.82387664914131, 48.49264830350876, 50.0176964700222, 44.10969749093056, 36.372142285108566, 34.65454325079918, 36.25703506171703, 35.85187420248985, 37.513300850987434, 37.63954147696495, 36.818299144506454, 37.00471334159374, 37.74556718766689, 36.59990206360817, 35.83301581442356, 37.23509877920151, 37.288656905293465, 35.522143095731735, 35.36145731806755, 35.17024777829647, 35.75815983116627, 35.4022329300642, 36.562861651182175, 37.70413801074028, 37.693449184298515, 38.075963258743286, 37.82663203775883, 38.578930869698524, 39.0260224789381, 39.275973066687584, 39.28350046277046, 38.44404950737953, 38.129779770970345, 36.595714688301086, 38.73204745352268, 38.44482846558094, 38.490220829844475, 39.04268078505993, 40.82900673151016, 45.310178473591805, 53.2098101824522, 53.088817074894905, 60.109004974365234, 52.84437999129295, 54.9028929322958, 53.89787346124649, 59.5160885900259, 50.404527112841606, 70.46588122844696, 10.466618165373802, 0.15436992282047868, 0.5292738962452859, 0.22341442963806912, 0.6004409305751324, 40.27400091290474, 66.40851974487305, 57.141018435359, 64.90547239780426, 52.836484014987946, 45.60114786028862, 29.45159263908863, 51.489665284752846, 51.6760528832674, 27.349106557667255, 1.2414629710838199, 0.10846843782928772, 0.15511512814555317, 0.13229922275058925, 0.10213235203991644, 0.03475230434560217, 0.050064384267898276, 0.024709936769795604, 0.019957735130446963, 0.04844416456762701, 0.09468867763644084, 0.07702140690525994, 0.05432918784208596, 0.02646574499522103, 0.0417126328102313, 0.05606019534752704, 0.11755093015381135, 0.11830976873170584, 1.4276357623748481, 52.32400171458721, 68.74714225530624, 41.59595377743244, 21.410804204642773, 45.27762942016125, 60.64814664423466, 62.92570263147354, 65.81544756889343, 58.52834299206734, 59.46662664413452, 50.51426142454147, 1.4680925477296114, 0.8773365255910903, 1.773343705572188, 0.17766835779184476, 21.743335761129856, 72.07029193639755, 53.14985699951649, 52.38767869770527, 57.06017017364502, 59.320380091667175, 50.5246576666832, 61.47170305252075, 52.73222900927067, 50.15720218420029, 44.89997908473015, 44.41368117928505, 40.03734201192856, 41.37358210980892, 38.32687519490719, 39.85579915344715, 37.89756283164024, 38.82691316306591, 39.22817923128605, 39.190857633948326, 39.78071138262749, 39.54062506556511, 38.767389357089996, 40.74199140071869, 39.355096220970154, 38.847591653466225, 38.74104917049408, 38.68157476186752, 37.87184581160545, 38.133055195212364, 37.59618580341339, 39.92450326681137, 37.92590171098709, 40.51755264401436, 38.22729013860226, 40.66615886986256, 40.08041650056839, 39.964697510004044, 38.964891359210014, 40.17752408981323, 38.91433887183666, 40.7951695472002, 38.49482998251915, 38.46873298287392, 38.904565796256065, 43.18304501473904, 50.503295212984085, 46.40531770884991, 48.52353684604168, 50.463480949401855, 47.94092930853367, 44.08478982746601, 41.40048086643219, 39.07147563993931, 38.32902207970619, 36.505416333675385, 38.340850844979286, 37.38183170557022, 38.297597765922546, 39.71862271428108, 41.597637087106705, 42.006244361400604, 43.30051191151142, 42.841792926192284, 42.414904832839966, 39.19433444738388, 39.750225618481636, 37.50604324042797, 38.07659402489662, 37.76929311454296, 38.984897285699844, 39.49456013739109, 39.788417369127274, 38.53961817920208, 41.47669717669487, 51.89932510256767, 54.71850022673607, 51.00455291569233, 49.86809849739075, 51.50836028158665, 52.03643314540386, 45.208066552877426, 39.23924043774605, 36.835930198431015, 38.7652462720871, 37.654413878917694, 39.488716050982475, 38.2629170268774, 37.732921466231346, 38.775353729724884, 40.31619764864445, 38.38960602879524, 38.97980555891991, 38.748652562499046, 39.223623275756836, 38.63359473645687, 36.9297281652689, 36.37367360293865, 39.7448755055666, 37.27031908929348, 39.676057398319244, 39.390529319643974, 39.49278563261032, 39.62352141737938, 40.79993449151516, 40.04819042980671, 41.92625105381012, 41.3349761813879, 41.35762296617031, 40.38391001522541, 41.55283749103546, 39.890240505337715, 40.89638091623783, 39.04318615794182, 42.139210626482964, 40.853310227394104, 44.4652634114027, 46.59380279481411, 57.145498394966125, 57.80952036380768, 62.791417837142944, 53.39991398155689, 57.144875228405, 56.15318164229393, 63.19130077958107, 52.321946024894714, 73.38983952999115, 11.134856957942247, 0.12846101308241487, 2.0079585537314415, 0.7617384754121304, 0.4195146186975762, 43.789256885647774, 71.14272370934486, 64.50055092573166, 72.15425223112106, 59.721714556217194, 56.5429001301527, 29.35396447777748, 57.73264668881893, 58.271256387233734, 35.54498367011547, 1.2228323332965374, 0.166609778534621, 0.10917531864834018, 0.13050040521193296, 0.09371529158670455, 0.05550752168346662, 0.026850774920603726, 0.040298058520420454, 0.17944241728400812, 0.20557325886329636, 0.17008153052302077, 0.17810338991694152, 0.13131572864949703, 0.12036752901622094, 0.17644096427829936, 0.27520150935743004, 0.28921524644829333, 0.16833169473102316, 2.031415170058608, 60.401581674814224, 78.38740736246109, 48.88672135770321, 35.546891167759895, 54.8701386898756, 66.92771628499031, 68.42230528593063, 70.03223329782486, 62.516274601221085, 64.83988031744957, 55.37943296134472, 2.737500169314444, 2.3533813934773207, 3.2742368057370186, 0.23632022930542007, 23.852460086345673, 76.32350251078606, 56.38070583343506, 56.766217947006226, 59.72448840737343, 58.92156109213829, 53.0076040327549, 64.58954215049744, 56.1950895935297, 52.38460086286068, 47.43196181952953, 46.10876642167568, 42.62430019676685, 44.51241888105869, 40.90939521789551, 43.121275529265404, 38.487538173794746, 40.09900130331516, 41.78543820977211, 41.604985892772675, 41.65102422237396, 42.544173896312714, 42.00516141951084, 42.87046618759632, 41.10935568809509, 41.18574298918247, 42.86252461373806, 41.21272914111614, 40.209305584430695, 41.01417079567909, 38.074435740709305, 43.77500385046005, 40.49965560436249, 41.736451238393784, 38.9649673551321, 41.07768818736076, 42.172105461359024, 41.570909321308136, 42.17849291861057, 42.417306303977966, 41.2275293469429, 42.34446041285992, 39.07048009335995, 41.089437156915665, 40.675950944423676, 45.34873500466347, 52.81319126486778, 50.37379816174507, 52.669156193733215, 52.29231521487236, 49.35064226388931, 44.098427295684814, 41.80375322699547, 40.310809537768364, 38.07231925427914, 38.784556835889816, 39.08504471182823, 38.68082620203495, 40.433048978447914, 41.26656085252762, 43.29666651785374, 45.929017066955566, 46.0201171785593, 44.97857786715031, 43.56704480946064, 41.66072130203247, 41.40982076525688, 38.35156626999378, 39.310858994722366, 39.02762219309807, 38.09483304619789, 40.595136880874634, 39.86616499722004, 39.60226535797119, 42.521793097257614, 54.52947556972504, 57.98820957541466, 53.752329871058464, 52.39692360162735, 54.15890045464039, 54.618759378790855, 47.482719495892525, 41.39606550335884, 39.19171638786793, 39.813252836465836, 39.41390186548233, 42.52381458878517, 41.65094442665577, 40.80290973186493, 39.820662438869476, 41.39958791434765, 40.85766859352589, 39.22400325536728, 41.17951512336731, 42.00038507580757, 41.252357214689255, 39.77333977818489, 39.58937644958496, 42.02188812196255, 40.255689695477486, 41.60355716943741, 42.52201348543167, 42.504789009690285, 42.67538845539093, 43.33427309989929, 42.5477647036314, 43.86364929378033, 45.750635638833046, 43.6001942306757, 42.15729005634785, 43.18703480064869, 42.27919891476631, 43.76361966133118, 42.77814254164696, 44.433607310056686, 43.17576840519905, 46.506924256682396, 49.5425433665514, 58.34591098129749, 59.71227966248989, 64.5642963051796, 54.95932750403881, 59.271879494190216, 60.3599701076746, 66.82854160666466, 54.36662010848522, 77.27055609226227, 13.281323779374361, 0.20592312212102115, 6.789668519049883, 1.5485836286097765, 1.0093065910041332, 46.832771971821785, 77.73788541555405, 67.00784638524055, 76.4851762354374, 66.26367911696434, 61.23713403940201, 38.84419843554497, 65.0296801328659, 66.07047468423843, 47.45150797069073, 1.6011691256426275, 0.40447386796586215, 0.11977591115282848, 0.2349346544360742, 0.26041691831778735, 0.1591822161572054, 0.15090737346326932, 0.10371823998866603], [0.05856770454556681, 0.04722520556242671, 0.04685110747232102, 0.04589105781633407, 0.02373349307163153, 0.026820038874575403, 0.07059699069941416, 0.07136627129511908, 0.106112831417704, 0.2069021188071929, 0.6574430374894291, 31.96888916194439, 55.88876523077488, 47.49351091682911, 32.97835059463978, 28.67547668516636, 47.79627867043018, 64.78960141539574, 57.04055942595005, 56.36593222618103, 49.68886211514473, 54.59679275751114, 6.025798358023167, 0.8492519950959831, 0.5500409693922848, 0.06162323785247281, 6.392769841477275, 63.13775025308132, 58.111611753702164, 57.932588160037994, 57.444154769182205, 47.31425553560257, 57.70607851445675, 54.00400936603546, 48.876769691705704, 43.94159831106663, 41.55262090265751, 37.780795097351074, 35.76331615447998, 36.82079181075096, 38.0307836830616, 36.10789306461811, 35.93117594718933, 36.828186213970184, 38.48593086004257, 36.286510080099106, 37.58482441306114, 38.24218533933163, 36.549193784594536, 38.255328834056854, 37.93904900550842, 37.49888062477112, 37.552978321909904, 36.32230795919895, 35.409498140215874, 35.59566915035248, 36.48719251155853, 37.74400547146797, 36.0150982439518, 40.48780784010887, 38.81254993379116, 39.638583809137344, 38.59397046267986, 36.98834002017975, 37.795564904809, 37.52753868699074, 36.6690431535244, 37.11939498782158, 38.380406722426414, 35.09816564619541, 34.53927643597126, 42.408490777015686, 43.08974102139473, 43.927162885665894, 46.86893083155155, 47.99520559608936, 47.10654728114605, 42.755142375826836, 40.00570110976696, 39.22090642154217, 38.84220354259014, 36.96121707558632, 36.09520174562931, 37.83524617552757, 37.55356349050999, 38.43115299940109, 39.60581436753273, 39.219591692090034, 43.61358091235161, 38.80093015730381, 39.35100004076958, 37.63602286577225, 37.4335241317749, 36.98234774172306, 37.093066200613976, 35.80600306391716, 37.58631393313408, 37.88042575120926, 38.42768378555775, 39.47908736765385, 43.804779052734375, 50.74699133634567, 51.518296748399734, 49.15858916938305, 50.8036956936121, 45.337730795145035, 48.17812018096447, 45.89101530611515, 38.48680481314659, 33.93542043864727, 36.12712383270264, 37.393789663910866, 39.08474452793598, 35.93143813312054, 37.25431054830551, 37.16960549354553, 40.03451116383076, 36.39573521912098, 37.51430779695511, 35.71206450462341, 36.75343282520771, 34.50770393013954, 35.0825484842062, 34.93109241127968, 34.60829213261604, 35.063815489411354, 36.06188893318176, 35.70121608674526, 37.601083740592, 35.21890036761761, 39.37560752034187, 37.907297909259796, 39.39701937139034, 36.89922720193863, 37.48248070478439, 36.060578003525734, 39.92426007986069, 37.0493533462286, 37.4567636847496, 38.32253582775593, 38.33422400057316, 39.93598245084286, 39.61161285638809, 40.83176538348198, 47.924050614237785, 52.69299991428852, 56.601933762431145, 55.87711505591869, 54.95457775890827, 56.69207252562046, 60.333546325564384, 60.152945816516876, 50.00074937939644, 0.14163962623570114, 0.20101794158108532, 1.9619918265379965, 0.43449305871035904, 0.8045151550322771, 50.20270474255085, 62.05527573823929, 55.30933812260628, 44.24872063100338, 53.37165869772434, 33.121526911854744, 24.20693166553974, 40.90860866010189, 57.42618553340435, 17.077522426843643, 0.4585887532448396, 0.03390489044249989, 0.12069143194821663, 0.05560369660088327, 0.03769436327274889, 0.0381749113148544, 0.13879887788789347, 0.07448852367815562, 0.027952558084507473, 0.018569458843558095, 0.08387506648432463, 0.0641683442518115, 0.044877940890728496, 0.04055087854794692, 0.02965251413115766, 0.048034243009169586, 0.07388394049485214, 0.12270137565792538, 0.7383989996742457, 39.95919540524483, 63.441726341843605, 50.05034051835537, 36.73034146428108, 43.71089369058609, 53.14170643687248, 67.34719857573509, 62.54505045711994, 61.440096348524094, 54.69902627170086, 60.31285643577576, 6.1246890015900135, 0.9451634204015136, 2.215560651384294, 0.39142652589362115, 8.49302401766181, 67.0480178296566, 57.76584550738335, 59.58779454231262, 60.14817327260971, 51.11195035278797, 58.68174836039543, 57.45609372854233, 51.18682913482189, 47.1662724763155, 44.65934179723263, 41.78332932293415, 39.1675078868866, 39.27805155515671, 40.30206620693207, 39.442719519138336, 37.57169611752033, 38.95804412662983, 40.287064611911774, 40.53244784474373, 39.19095642864704, 39.87558849155903, 39.10277456045151, 39.22746866941452, 39.52685460448265, 40.075370371341705, 38.91675554215908, 38.753531500697136, 38.3712188154459, 38.99068057537079, 39.35503542423248, 38.39135393500328, 39.52665701508522, 41.44682697951794, 40.856380462646484, 39.75315526127815, 41.006001234054565, 38.36037419736385, 39.83867347240448, 40.85973188281059, 37.59110547602177, 38.178067579865456, 38.82927663624287, 37.62489706277847, 36.7764063924551, 42.39095091819763, 47.466315776109695, 47.82517991960049, 49.9773084372282, 49.78576451539993, 47.59277679026127, 42.750795409083366, 40.47496072947979, 39.87441435456276, 39.50716406106949, 37.44365818798542, 39.17842090129852, 40.02378813922405, 39.52403895556927, 38.690709471702576, 42.268559485673904, 41.47385872900486, 44.78038050234318, 40.355761125683784, 41.02456323802471, 39.564632177352905, 38.34276594221592, 37.54559151828289, 37.790271788835526, 37.30984456837177, 39.56324525177479, 38.12034107744694, 39.28407423198223, 40.945075303316116, 44.45891015231609, 51.764303147792816, 53.23008209466934, 50.5811720341444, 52.40747183561325, 47.32982710003853, 51.15051448345184, 46.131417006254196, 40.33875323832035, 35.26599884033203, 38.51823292672634, 38.78818944096565, 41.01861655712128, 39.35560159385204, 38.895244896411896, 38.487872555851936, 40.028541684150696, 38.04377518594265, 39.590854570269585, 38.184618428349495, 38.44825968146324, 36.82426482439041, 36.31258048117161, 38.494723588228226, 38.12789127230644, 38.09568800032139, 37.39290051162243, 37.49694272875786, 39.0785888582468, 38.14141094684601, 41.068720668554306, 39.83172744512558, 41.819776967167854, 39.12988990545273, 39.79076184332371, 39.28563974797726, 41.1998288333416, 39.76243816316128, 40.259934067726135, 40.09576387703419, 42.03214377164841, 41.463367491960526, 41.245179399847984, 42.435811311006546, 52.30591468513012, 53.94728220999241, 59.06893998384476, 59.318252205848694, 56.26469045877457, 56.94795839488506, 63.322625532746315, 61.55050702393055, 53.22593651711941, 0.4236438393127173, 0.48795298382174224, 2.1445590863004327, 0.10055634207674302, 0.8388564654160291, 51.53436988592148, 70.43337777256966, 60.567108392715454, 52.57465146481991, 61.89332462847233, 43.51292811334133, 27.290853783488274, 48.18838343024254, 63.602852895855904, 24.379159323871136, 0.6066566845402122, 0.024340863019460812, 0.1671983313281089, 0.05946682758803945, 0.027355201564205345, 0.09325504128355533, 0.06750417189323343, 0.10150891830562614, 0.19488116697175428, 0.13428366626612842, 0.11963106619077735, 0.16228415595833212, 0.10321530877263285, 0.11882236271048896, 0.16400316293584183, 0.20265565370209515, 0.19876368285622448, 0.2000963722821325, 0.8624995092395693, 46.22427262365818, 71.2960758805275, 62.86702997982502, 44.32514972984791, 40.210342928767204, 62.02678866684437, 74.74237695336342, 69.2039081454277, 66.29223078489304, 59.21644426882267, 64.00258764624596, 9.715050794184208, 1.9864558638073504, 4.031904274597764, 0.2423354994971305, 8.937809150665998, 68.44921544194221, 61.5704445540905, 63.250497803092, 60.95254071056843, 54.649055153131485, 60.27460768818855, 62.535851150751114, 54.1640567779541, 49.38762567937374, 46.82654410600662, 44.42732244729996, 40.277899503707886, 42.30616606771946, 41.21468983590603, 40.15397295355797, 39.13842424750328, 41.026451736688614, 42.583448588848114, 40.95666088163853, 42.4379163980484, 42.989065423607826, 42.94348306953907, 42.810357213020325, 42.039781361818314, 44.899735897779465, 41.530870869755745, 41.76257483661175, 38.80357101559639, 40.5053286999464, 41.12224839627743, 41.92436635494232, 41.40180319547653, 45.26610463857651, 43.197374045848846, 42.885878160595894, 42.38660775125027, 41.23389020562172, 41.27171717584133, 42.136938348412514, 39.24118973314762, 41.04937590658665, 42.480565309524536, 40.644359439611435, 40.09623505175114, 46.94380961358547, 48.902608305215836, 50.9379842877388, 51.870796233415604, 53.81623104214668, 48.521826937794685, 44.07153233885765, 40.80199398100376, 39.5044282078743, 39.48257938027382, 38.79103548824787, 38.69657635688782, 41.746117919683456, 39.70265597105026, 41.29226267337799, 45.44161342084408, 43.20614777505398, 47.91626863181591, 42.89518766105175, 42.10637278854847, 41.73126831650734, 42.110313177108765, 39.44795183837414, 39.65422756969929, 37.960935831069946, 39.995038881897926, 38.16084310412407, 38.950930908322334, 41.0983856767416, 44.4768375903368, 53.8241346180439, 56.81019298732281, 53.2359603792429, 55.47250896692276, 48.973421305418015, 54.25138369202614, 49.852576330304146, 43.7267654389143, 38.53692412376404, 41.00193165242672, 42.202693819999695, 42.92509205639362, 40.62132887542248, 40.309772193431854, 40.829094126820564, 42.83003255724907, 38.69410648941994, 41.69560343027115, 39.58002135157585, 40.96688613295555, 39.68616485595703, 39.298707246780396, 40.930161103606224, 40.230314657092094, 40.01726008951664, 40.45083202421665, 40.33419728279114, 42.6596686989069, 40.3294513374567, 43.95111300051212, 41.72346353530884, 45.529308915138245, 41.073497012257576, 41.6016610711813, 39.27509531378746, 43.15170809626579, 42.19027988612652, 42.61291600763798, 42.297605127096176, 44.7316937148571, 44.21181321144104, 43.9764728397131, 44.17753145098686, 53.968013897538185, 56.82340107858181, 62.90711782872677, 61.105923280119896, 57.172518745064735, 60.28709761798382, 67.79406979680061, 63.73274892568588, 56.1173115670681, 0.8627818222157657, 0.6740314036142081, 7.8525802586227655, 1.0137636330910027, 0.7221191294956952, 58.62189397215843, 74.47808593511581, 67.40611061453819, 57.80073903501034, 70.8987919986248, 48.203096240758896, 34.51748840510845, 55.21498538553715, 73.95727828145027, 34.72792871296406, 1.0831242799758911, 0.11420539522077888, 0.19483068608678877, 0.12359463202301413, 0.1572284530266188, 0.13224022201029584, 0.38055999961216, 0.1490364340133965], [0.08141656871885061, 0.1148256154556293, 0.03172007076500449, 0.09909509783028625, 0.05286864492518362, 0.06407247361494228, 0.0407153236301383, 0.08530482882633805, 0.0319832623063121, 0.21555821760557592, 0.2836456656223163, 28.323866352438927, 59.59629848599434, 42.21931792795658, 13.670364003628492, 24.605592973530293, 47.55690671503544, 61.27946376800537, 54.28777813911438, 56.59703202545643, 48.30819860100746, 56.3928347826004, 14.518971517682076, 0.5484875058755279, 1.2614208064042032, 0.9165143233258277, 0.46550705388654023, 31.311608031392097, 69.98170360922813, 57.644977793097496, 50.80805025994778, 54.14041444659233, 58.4756588190794, 48.07844012975693, 44.25990343093872, 39.556090235710144, 40.24495907127857, 36.44757583737373, 37.861023992300034, 37.0015063136816, 39.12081979215145, 36.90059132874012, 37.34592363238335, 36.974075585603714, 36.312637478113174, 36.04655295610428, 40.05094148218632, 37.88754656910896, 38.870101645588875, 37.304711043834686, 38.37189897894859, 36.94950230419636, 33.549592941999435, 35.99588267505169, 37.23334327340126, 34.362099543213844, 37.29831978678703, 33.617894276976585, 36.416406109929085, 37.17530898749828, 38.245912939310074, 38.13318058848381, 38.02561216056347, 38.00344035029411, 37.26732864975929, 36.996619775891304, 37.6524455845356, 37.62592300772667, 37.71912440657616, 35.23713178932667, 34.76702481508255, 40.13617470860481, 43.551518842577934, 47.16266267001629, 46.23283736407757, 49.7005008906126, 46.602150946855545, 42.25257754325867, 39.93122510612011, 39.71465952694416, 38.21613013744354, 35.43904535472393, 39.09479878842831, 38.07572767138481, 39.61684897542, 38.35723556578159, 39.657047018408775, 41.02341569960117, 40.60622848570347, 40.30313774943352, 40.3743801265955, 38.556257486343384, 37.73728363215923, 36.37811936438084, 37.4785441160202, 36.4468614757061, 36.95739448070526, 38.960852175951004, 38.56889180839062, 39.48358252644539, 41.97059087455273, 49.22955796122551, 49.90045756101608, 47.320570796728134, 48.06668736040592, 47.47314780950546, 46.92944258451462, 46.07215158641338, 38.245031386613846, 35.47648474574089, 35.453017204999924, 38.5916031897068, 34.9690143764019, 37.40596801042557, 37.92429059743881, 38.20598468184471, 38.95174406468868, 38.71504716575146, 36.67280875146389, 35.979988127946854, 36.43319360911846, 34.86057199537754, 34.46872942149639, 36.21700420975685, 36.1793178319931, 35.99519491195679, 36.09795279800892, 36.195972338318825, 36.69396221637726, 38.0994687974453, 36.39503225684166, 36.67801447212696, 37.9244539886713, 38.861707895994186, 42.39815913140774, 44.77617032825947, 44.214982241392136, 45.48623062670231, 42.002224177122116, 37.051363438367844, 36.56265266239643, 37.82688282430172, 38.361096158623695, 38.039329424500465, 39.13278914988041, 49.47586454451084, 51.979785785079, 55.1201006770134, 56.156160682439804, 60.970331355929375, 52.97543875873089, 63.54767605662346, 13.404719308018684, 0.37063249794300646, 1.159269344061613, 1.8334919842891395, 0.39291310706175864, 1.016699094325304, 55.213423669338226, 55.23359298706055, 59.33084852993488, 56.22610732913017, 52.18502797186375, 29.17228102684021, 30.326273404061794, 39.945945516228676, 56.9160933047533, 10.570552088320255, 0.5839010118506849, 0.026510067909839563, 0.06463399739004672, 0.03255641924624797, 0.04043540779093746, 0.0968432065565139, 0.04166634505963884, 0.05431161378510296, 0.053884567169006914, 0.026066577156598214, 0.043837583434651606, 0.05602245713816956, 0.019697831303346902, 0.015246445309458068, 0.13160106958821416, 0.10910582393989898, 0.05052957727457397, 0.26907481311354786, 0.3564005100633949, 34.18296195566654, 66.8148623406887, 53.18120911717415, 20.983332842588425, 28.024752102792263, 54.48795139789581, 66.12220510840416, 60.029178857803345, 59.43091236054897, 54.68270614743233, 61.74491599202156, 15.980097614228725, 0.7789928745478392, 0.8085966703947634, 2.0285705476999283, 0.22280123754171655, 36.27714738249779, 72.03041687607765, 58.14978450536728, 51.759070828557014, 55.12212976813316, 59.18255768716335, 50.33769629895687, 46.758425161242485, 41.196078434586525, 41.55747704207897, 37.97071650624275, 40.668199360370636, 39.4649863243103, 40.979718044400215, 38.0535064637661, 39.6338302642107, 40.04649192094803, 39.01785671710968, 36.98264792561531, 40.11975198984146, 38.28156262636185, 39.95214678347111, 38.5409215092659, 40.066596642136574, 38.648003563284874, 37.42295689880848, 36.97955869138241, 39.28971312940121, 37.72106610238552, 39.85326088964939, 35.802423655986786, 38.642946034669876, 38.473729714751244, 40.083695724606514, 39.55500729382038, 40.19166313111782, 39.03570435941219, 38.14104616641998, 39.39314357936382, 40.086465775966644, 39.91574473679066, 38.950767517089844, 37.133188247680664, 37.08102844655514, 43.165448158979416, 47.55613535642624, 49.31148536503315, 47.476100251078606, 50.76847918331623, 48.191408067941666, 42.512240409851074, 40.003691017627716, 40.064917132258415, 38.8711503893137, 36.196470111608505, 37.334516644477844, 39.43815216422081, 40.41351042687893, 39.67607639729977, 42.13791869580746, 43.13374646008015, 41.649998277425766, 41.93410523235798, 40.90438708662987, 41.05118080973625, 38.5759936273098, 37.833198085427284, 38.58113095164299, 36.71429492533207, 37.97045052051544, 38.64041917026043, 39.958644434809685, 39.38679412007332, 42.3221480101347, 50.69643884897232, 51.55988171696663, 51.391820535063744, 51.07316203415394, 49.18670006096363, 50.4922454059124, 47.470130771398544, 41.439132392406464, 36.60269871354103, 38.57799991965294, 39.36777614057064, 36.618707254529, 38.713629841804504, 39.56365182995796, 40.19032560288906, 40.323903635144234, 39.95731070637703, 37.801633179187775, 37.913624569773674, 39.3138912320137, 38.22628319263458, 37.735767513513565, 38.401142209768295, 38.001384660601616, 36.80917203426361, 40.10314308106899, 39.76572498679161, 39.15570951998234, 39.08675841987133, 38.971332013607025, 39.62637886404991, 40.04384346306324, 40.22982828319073, 43.75399857759476, 46.666610687971115, 47.1113046258688, 46.12201631069183, 43.95371966063976, 39.83143866062164, 39.99042972922325, 39.985072016716, 40.59904687106609, 39.758790358901024, 43.0103974789381, 52.34127938747406, 55.15556417405605, 56.7237514257431, 58.71851518750191, 62.51625180244446, 55.60737892985344, 65.2437986433506, 18.916942924261093, 0.7567116420250386, 2.557126935571432, 3.458602912724018, 0.3578469261992723, 0.9645847126375884, 60.65866827964783, 59.45406071841717, 65.01913949847221, 57.40900665521622, 58.301449567079544, 35.13329856097698, 30.38418609648943, 44.64424520730972, 65.49589991569519, 17.691706269979477, 0.5363314831629395, 0.03595504000259098, 0.06109190464485437, 0.06400778060196899, 0.009120301037910394, 0.06361148116411641, 0.017609143869776744, 0.026277940814907197, 0.14163210085825995, 0.2354203158756718, 0.09422084258403629, 0.2079323830548674, 0.1111381285591051, 0.08867611628375016, 0.22417146479710937, 0.3221982781542465, 0.18878878763644025, 0.44954820710700005, 0.40481813543010503, 41.43848642706871, 73.96833568811417, 58.851508051157, 20.98463997244835, 32.08458535373211, 62.083417028188705, 71.54928669333458, 63.401387706398964, 64.78398531675339, 57.17029206454754, 68.55815559625626, 19.132678247988224, 0.8196287252940238, 4.394320277497172, 1.3661830849014223, 0.7742243085522205, 36.64215959608555, 74.50578644871712, 58.35109390318394, 53.23941819369793, 58.16684938967228, 62.09211856126785, 51.660842299461365, 47.91280321776867, 43.09189930558205, 45.87261289358139, 41.542635038495064, 41.74190014600754, 41.46470881998539, 42.916629910469055, 39.99349616467953, 42.41569899022579, 42.542262598872185, 40.29230073094368, 39.82986934483051, 42.06792265176773, 40.35647928714752, 42.75295749306679, 41.38899028301239, 43.360309302806854, 42.00324632227421, 38.930856585502625, 40.35641469061375, 41.99785441160202, 39.88655090332031, 43.63115876913071, 36.79406404495239, 39.186088889837265, 41.33477479219437, 42.332779839634895, 41.43160879611969, 41.799189671874046, 41.28897964954376, 39.70747411251068, 41.229839622974396, 40.94282582402229, 41.67308583855629, 41.182288974523544, 41.33994251489639, 40.73421321809292, 47.47686021029949, 51.476612985134125, 52.694702222943306, 49.683952778577805, 55.5016116052866, 48.36192771792412, 43.647938668727875, 39.305748268961906, 39.852801114320755, 39.1313262283802, 36.52821511030197, 39.84519772231579, 41.0371595621109, 42.57203780114651, 42.699498161673546, 43.89319650828838, 44.3570452183485, 44.81264837086201, 44.03566986322403, 44.708047583699226, 42.83685699105263, 41.69381372630596, 39.78351183235645, 40.214040130376816, 37.75532886385918, 39.78676065802574, 39.548794627189636, 40.071372985839844, 40.57590611279011, 44.024373069405556, 53.144126906991005, 54.86321546137333, 52.23718777298927, 53.55569042265415, 52.07109488546848, 53.60873557627201, 49.99527387320995, 44.10747081041336, 40.40027193725109, 40.21088629961014, 42.9922154545784, 38.414699882268906, 41.58857837319374, 41.651738584041595, 42.04406373202801, 42.72418163716793, 43.08949403464794, 40.67870959639549, 40.60913532972336, 42.15815640985966, 40.08657597005367, 39.048277884721756, 41.587123051285744, 41.474994868040085, 41.731598898768425, 41.817428693175316, 42.933402210474014, 41.16485171020031, 41.68061323463917, 40.53616024553776, 40.870040729641914, 42.89120927453041, 43.2146555185318, 46.720317006111145, 49.231697246432304, 48.168966472148895, 47.94477470219135, 48.17037619650364, 42.11869552731514, 42.01289400458336, 42.64894187450409, 43.07276353240013, 41.9494754076004, 44.14757385849953, 54.91533346474171, 57.34444431960583, 60.03131814301014, 62.878516763448715, 65.49714624881744, 57.62916684150696, 66.39500007033348, 21.36839658021927, 0.5624794831965119, 3.3395073283463717, 8.23544628918171, 0.7351657294202596, 0.8824271243065596, 63.84563326835632, 64.75549444556236, 71.2048351764679, 66.94443538784981, 63.70976775884628, 41.74406982958317, 40.94513989984989, 52.51207262277603, 75.04393637180328, 26.884552985429764, 0.8086888748221099, 0.21814023843035102, 0.21923866152064875, 0.09386065605212934, 0.1979223100352101, 0.22394359577447176, 0.07845424173865467, 0.13257935381261632], [0.02967918691865634, 0.08444839782896452, 0.007873587564972695, 0.11309811830869876, 0.019953575392719358, 0.10713476876844652, 0.042266597811249085, 0.022162264394864906, 0.03574691952962894, 0.2181970127276145, 0.06936551537364721, 22.41914089769125, 61.84748388826847, 40.72626784443855, 39.1803739964962, 37.246106788516045, 36.751969903707504, 62.50186197459698, 57.63806976377964, 60.39273954927921, 49.62307624518871, 57.36700750887394, 28.650141544640064, 0.18178460566559806, 1.4946560910902917, 1.1111121531575918, 0.20329890277935192, 1.2145879631862044, 53.36826927959919, 50.821725726127625, 54.78729173541069, 54.9983362108469, 50.472570061683655, 45.148151367902756, 39.80522006750107, 38.270129039883614, 36.94129094481468, 38.642550855875015, 40.147676691412926, 42.22335331141949, 38.742709681391716, 37.37925164401531, 36.37844994664192, 36.180811151862144, 37.74647153913975, 42.354020699858665, 47.01325848698616, 49.14433233439922, 47.292969077825546, 42.92669177055359, 38.47768150269985, 36.61649577319622, 38.346835523843765, 35.54251380264759, 37.58317530155182, 38.03607299923897, 36.46966025233269, 36.64999097585678, 36.628959104418755, 38.76503728330135, 37.5367645919323, 38.769627436995506, 37.52727650105953, 39.116647616028786, 40.929560735821724, 38.49898315966129, 36.834832057356834, 37.36993074417114, 38.12276914715767, 34.492991119623184, 33.97105112671852, 38.56843203306198, 46.83300755918026, 48.21948856115341, 46.075522005558014, 48.503192737698555, 46.42948821187019, 43.85090857744217, 40.424518436193466, 38.1968879699707, 37.02992878854275, 36.72043539583683, 37.58681170642376, 39.827718660235405, 38.78424525260925, 37.83858239650726, 39.417971447110176, 41.03538505733013, 38.78738768398762, 40.09693421423435, 37.569598630070686, 38.592290952801704, 38.774882555007935, 38.81196856498718, 37.83200494945049, 37.616324722766876, 35.93653365969658, 38.23039077222347, 40.21256200969219, 38.72205398976803, 40.76741963624954, 49.78669926524162, 48.62184517085552, 48.92797194421291, 47.688242867589, 48.36771100759506, 46.045131236314774, 46.061280369758606, 38.01062196493149, 34.96581494808197, 36.419939920306206, 36.60607673227787, 35.82690954208374, 37.491486221551895, 37.40991599857807, 37.255359292030334, 39.06590513885021, 37.326833456754684, 35.93745321035385, 38.42657044529915, 36.00938335061073, 36.60450741648674, 34.873533099889755, 36.156355664134026, 36.329470574855804, 34.07728962600231, 36.976674646139145, 36.13062724471092, 35.66932059824467, 38.19353275001049, 37.576662451028824, 38.89496751129627, 40.01676991581917, 42.890673503279686, 49.93475832045078, 51.38857550919056, 54.29829977452755, 53.85033801198006, 54.14622813463211, 48.61192390322685, 41.50540463626385, 38.24305549263954, 35.12651972472668, 38.67670342326164, 37.64758184552193, 42.293976321816444, 48.17031919956207, 52.89388373494148, 54.81075547635555, 59.49403837323189, 56.57146319746971, 48.51996883749962, 1.7225469625554979, 0.15550974290817976, 0.2119373978348449, 1.6317948885262012, 0.12339293112745509, 2.764506982639432, 55.48577405512333, 60.191198363900185, 58.9888858795166, 65.34766227006912, 46.5216750651598, 27.522409558296204, 23.657393753528595, 36.69954411685467, 55.31517080962658, 4.576738039031625, 0.29377601109445095, 0.049099547759396955, 0.06044280744390562, 0.10753871974884532, 0.13422941527096555, 0.043893548790947534, 0.021943514511804096, 0.018953117651108187, 0.023477787945012096, 0.06972415823838674, 0.07109748024959117, 0.08142847276758403, 0.0493079316947842, 0.02417975203570677, 0.01269567446797737, 0.05804771135444753, 0.06159405289508868, 0.18305804202100262, 0.137913525395561, 29.265541322529316, 68.74173134565353, 46.447343453764915, 27.628372572362423, 33.95522117614746, 50.91254085302353, 65.98086029291153, 61.789715588092804, 63.90127748250961, 54.81757611036301, 61.66347496211529, 29.97571561485529, 0.1984477209043689, 1.2393065867945552, 2.4740771669894457, 0.8535711758304387, 2.4916683230549097, 56.67902782559395, 51.192612424492836, 56.55919745564461, 56.969552636146545, 53.24645161628723, 48.44562962651253, 41.78283154964447, 39.351083636283875, 40.29421582818031, 41.4153266698122, 42.93440155684948, 43.47656786441803, 40.8474775403738, 39.17163826525211, 38.2971265912056, 37.35029719769955, 39.208606481552124, 45.010484755039215, 49.81099896132946, 49.54549580812454, 48.03969360888004, 44.86434079706669, 40.31162649393082, 39.82251673936844, 38.78491781651974, 37.744917422533035, 39.902323856949806, 40.163248255848885, 39.118148535490036, 39.018951058387756, 39.176699593663216, 39.9698918312788, 38.641418516635895, 39.58902686834335, 39.61989261209965, 41.10731519758701, 40.82158572971821, 40.50480052828789, 37.88978464901447, 40.29474399983883, 39.88427862524986, 36.68667420744896, 37.20298670232296, 42.65514314174652, 48.17199490964413, 50.071011409163475, 49.294914454221725, 50.26792824268341, 47.67596572637558, 42.97242231667042, 38.808187767863274, 37.65248738229275, 37.11132422089577, 37.3860152810812, 39.37047019600868, 39.40136633813381, 40.15678860247135, 40.156507417559624, 41.298783123493195, 42.97882117331028, 41.668803468346596, 40.92921495437622, 39.613098576664925, 39.74349997937679, 41.41863249242306, 39.866693168878555, 37.5679837167263, 39.04517725110054, 36.096945852041245, 37.7794423699379, 39.40132074058056, 38.38389873504639, 41.23039819300175, 51.648245975375175, 51.432288363575935, 50.98260149359703, 49.63914558291435, 49.36346657574177, 48.361239954829216, 47.53632701933384, 40.01489661633968, 37.39094741642475, 36.7500776052475, 39.00327309966087, 37.976138815283775, 38.78976255655289, 39.9626874178648, 39.82827343046665, 39.407955184578896, 38.482796028256416, 37.315669655799866, 40.11542782187462, 37.93136961758137, 38.489776253700256, 36.90355136990547, 37.932129576802254, 37.70007602870464, 37.95066878199577, 38.17304044961929, 39.37436118721962, 37.996205538511276, 38.655986934900284, 39.24834854900837, 41.58298507332802, 42.07541584968567, 45.456204637885094, 52.29684077203274, 54.424616396427155, 55.779513493180275, 56.4259348064661, 55.41727513074875, 51.95213846862316, 44.17868658900261, 39.576020166277885, 39.4494603574276, 40.96817806363106, 40.98029561340809, 45.36991886794567, 51.221304684877396, 57.69997604191303, 56.89780868589878, 60.8168575912714, 56.03320688009262, 49.911332577466965, 2.413529553450644, 0.08483169483952224, 3.920575473457575, 2.8333191527053714, 0.2458329446380958, 2.88378091994673, 60.15196546912193, 65.76921924948692, 65.06016969680786, 69.7877088189125, 54.303182512521744, 34.810874462127686, 25.651937127113342, 40.82493335008621, 65.68057000637054, 9.542376659810543, 0.23328897164901718, 0.03107986820396036, 0.16304294258588925, 0.0894580282329116, 0.03830731046036817, 0.043394447056925856, 0.006850710469734622, 0.022305914499156643, 0.08134861025610007, 0.19389213644899428, 0.18246908846776932, 0.22954332263907418, 0.128998520958703, 0.2209301051334478, 0.09900460776407272, 0.16477342316647992, 0.14499782962957397, 0.40015347010921687, 0.1962548229494132, 32.81471237540245, 77.62625500559807, 57.133046463131905, 49.357375502586365, 50.130694806575775, 52.159025967121124, 71.51125833392143, 66.97506174445152, 69.65923011302948, 58.67295943200588, 69.12125498056412, 35.55956728756428, 0.1861374799045734, 4.958958579227328, 3.5042011784389615, 0.5775674048345536, 2.4363371171057224, 57.927777618169785, 53.45569118857384, 60.068411752581596, 58.950359746813774, 59.12136197090149, 49.151631742715836, 44.00839112699032, 43.03361043334007, 42.50744506716728, 42.937741577625275, 46.045716404914856, 47.29766182601452, 43.20637956261635, 41.07381999492645, 40.34210465848446, 39.68291223049164, 43.03971670567989, 47.26553454995155, 52.98423148691654, 52.69505560398102, 51.116738095879555, 47.63624265789986, 40.83591856062412, 41.785046830773354, 41.423929408192635, 39.74957585334778, 42.08595268428326, 42.89850868284702, 41.12610898911953, 41.62588097155094, 40.93768090009689, 41.87102861702442, 40.03023639321327, 41.39033541083336, 42.04016134142876, 42.37835079431534, 43.653117790818214, 41.41408793628216, 39.33817192912102, 40.99258415400982, 42.8529567271471, 38.64274464547634, 37.95009881258011, 45.87917514145374, 51.28293737769127, 53.57403203845024, 50.867251083254814, 53.05396154522896, 49.625238329172134, 43.37688021361828, 40.502414256334305, 36.80777370929718, 37.867061868309975, 38.32669660449028, 40.124497935175896, 43.267449885606766, 43.98224472999573, 41.75534762442112, 42.22324691712856, 45.34621573984623, 44.348883256316185, 44.9440985172987, 40.66661864519119, 40.06313882768154, 43.581567630171776, 40.9020122140646, 39.711824879050255, 39.35440845787525, 35.80508351325989, 38.00918564200401, 40.29036283493042, 39.700873866677284, 42.61171907186508, 55.031884610652924, 53.532393872737885, 53.165325969457626, 54.06778894364834, 53.377844765782356, 48.565038219094276, 50.429856553673744, 43.28196130692959, 41.00176826119423, 38.32855850458145, 41.31143644452095, 40.03817416727543, 41.28855027258396, 41.104731336236, 42.85302132368088, 42.071209475398064, 39.905264899134636, 39.77466970682144, 42.78385363519192, 38.89820493757725, 40.284081771969795, 40.40002875030041, 40.740745067596436, 39.6892236918211, 38.20479154586792, 42.42122769355774, 41.75352372229099, 40.51838859915733, 42.449118196964264, 41.040465384721756, 43.2405549287796, 43.663726821541786, 46.7396579682827, 54.8051355779171, 56.72080658376217, 59.5693389326334, 58.604711294174194, 57.6153089851141, 53.92654292285442, 48.41192923486233, 43.423568308353424, 40.32287009060383, 42.47371047735214, 43.98159496486187, 47.580047473311424, 53.56434255838394, 58.81168618798256, 59.35001850128174, 65.46556234359741, 55.451864674687386, 53.23197819292545, 3.751806104555726, 0.19211202103178948, 6.706042131409049, 9.610370211303234, 0.3862186678452417, 3.0445018457248807, 64.84241858124733, 70.96450567245483, 70.1077352464199, 72.60325133800507, 59.2224745452404, 38.515105694532394, 34.374946653842926, 50.48953615128994, 75.92597544193268, 15.563704557716846, 0.5902973748743534, 0.11138501882669516, 0.18701561872148886, 0.2268307431950234, 0.16147474001627415, 0.1846504386048764, 0.10892528167460114, 0.09536395780742168], [0.020398713713802863, 0.030550006304110866, 0.005966926692053676, 0.0997836995520629, 0.06950230803340673, 0.06923238150193356, 0.08009590208530426, 0.021286068149493076, 0.06928672155481763, 0.20385423704283312, 0.0689632268040441, 17.5755313038826, 61.04356102645397, 46.83521904051304, 40.82178711891174, 48.836845234036446, 36.42957620322704, 50.494411289691925, 61.639144867658615, 54.16980966925621, 53.428385853767395, 50.27931623160839, 42.75817461311817, 0.16450933733722195, 0.27196535957045853, 3.482448533177376, 2.019123542122543, 0.5017868836876005, 15.51751233637333, 60.140733271837234, 57.042037546634674, 55.254488065838814, 45.98994679749012, 41.18044227361679, 37.95258767902851, 40.69816455245018, 42.336150258779526, 47.70717345178127, 45.36491833627224, 45.318298637866974, 39.654972329735756, 37.8835491836071, 36.772978976368904, 39.07302975654602, 48.609165251255035, 51.1654856801033, 52.90624067187309, 49.36693958938122, 48.966235890984535, 48.82794611155987, 46.380372047424316, 41.6447089612484, 36.32490701973438, 37.75728955864906, 37.300174087285995, 36.70958697795868, 37.77690030634403, 36.445493549108505, 37.3256479203701, 38.65529157221317, 37.851832285523415, 37.02958680689335, 38.14275607466698, 38.336655870079994, 38.84992852807045, 38.544098138809204, 36.75165832042694, 39.6009012311697, 39.26999978721142, 35.231245905160904, 34.493960067629814, 39.23232100903988, 46.11480809748173, 46.21021717786789, 44.633769169449806, 49.07478466629982, 47.09365837275982, 44.284989684820175, 40.49804449081421, 38.778689950704575, 35.524913147091866, 38.15798565745354, 36.97362720966339, 38.382405415177345, 38.08764383196831, 39.76303093135357, 39.57519181072712, 38.39384660124779, 39.040807485580444, 39.00023326277733, 38.141673132777214, 37.80527338385582, 39.26223300397396, 39.0436003357172, 37.91664160788059, 38.462702706456184, 35.43424241244793, 38.40196296572685, 39.46345880627632, 39.19969215989113, 39.60440844297409, 46.59135192632675, 48.09452086687088, 49.256171733140945, 45.0184491276741, 46.32019467651844, 47.8173903375864, 44.103393629193306, 40.52126504480839, 33.93239200115204, 35.68922773003578, 36.12758740782738, 37.05756090581417, 35.35326115787029, 37.913016602396965, 37.878715842962265, 37.186252400279045, 37.37743154168129, 37.9852507263422, 38.687905222177505, 38.21785904467106, 35.48418693244457, 36.24016396701336, 33.89604315161705, 35.71605809032917, 35.82805708050728, 36.4614374935627, 36.055417880415916, 37.44424715638161, 40.56940846145153, 40.48262111842632, 40.80997355282307, 44.788508266210556, 46.949969083070755, 49.95345711708069, 50.69351300597191, 51.62760928273201, 52.46348462998867, 50.12884050607681, 55.313460901379585, 52.33184449374676, 43.424305468797684, 37.792817652225494, 37.421683967113495, 40.2562140673399, 37.263566851615906, 43.62051174044609, 50.50169549882412, 55.195826813578606, 51.46168738603592, 61.132917031645775, 33.79122577607632, 0.14399566309293732, 0.3508245467673987, 2.108940272592008, 0.9656974591780454, 0.772567359963432, 3.881254233419895, 59.6205335855484, 57.62584961950779, 61.41305699944496, 59.60134081542492, 50.84010533988476, 22.092120945453644, 19.291566722095013, 38.99429798126221, 49.023080840706825, 4.655108358711004, 0.31568539794534445, 0.07258012061356567, 0.01094619212381076, 0.05927360201894771, 0.02514626394258812, 0.06739897246006876, 0.033292963707935996, 0.042437989395693876, 0.12137547688325867, 0.06319429026916623, 0.014213059403118677, 0.028413027321221307, 0.022691801605105866, 0.1038929786591325, 0.043379756243666634, 0.07329944724915549, 0.01992519937630277, 0.28181915113236755, 0.045201257526059635, 21.858270093798637, 71.2734366953373, 54.14163418114185, 44.7681375592947, 39.027850180864334, 38.32011915743351, 59.7326123714447, 65.94796165823936, 60.50227627158165, 56.810242384672165, 57.58511960506439, 44.41169388592243, 0.2313101090840064, 1.1285674665123224, 1.953146019950509, 3.580497046932578, 0.028535691344586667, 19.448314011096954, 59.83764633536339, 59.75606471300125, 56.00063882768154, 50.49312695860863, 43.09480994939804, 41.166987195611, 41.985166892409325, 44.17702227830887, 48.94653394818306, 48.59552018344402, 46.89905561506748, 43.18933367729187, 39.22695949673653, 38.09395529329777, 40.7389135658741, 49.7528050839901, 53.26089084148407, 53.689568638801575, 52.302601262927055, 51.49722307920456, 50.09423576295376, 48.31427447497845, 41.730029582977295, 38.87978732585907, 38.81529338657856, 40.45960575342178, 38.71063940227032, 39.66469220817089, 38.9344397932291, 40.10301388800144, 39.520717933773994, 40.42313531041145, 39.29272636771202, 40.33052667975426, 39.16035287082195, 41.00424952805042, 39.31744784116745, 39.34902034699917, 40.33452786505222, 40.540959388017654, 37.366837710142136, 35.90361222624779, 42.731070667505264, 46.582992374897, 48.66716533899307, 47.6738416403532, 49.631036818027496, 49.102906957268715, 45.64180567860603, 41.076605245471, 38.65320548415184, 36.737306490540504, 38.70674081146717, 38.90834279358387, 38.93891595304012, 41.62849523127079, 39.9972465634346, 39.79063265025616, 39.97065559029579, 40.27655057609081, 39.91363205015659, 39.451413452625275, 40.36465264856815, 40.15872649848461, 40.450919419527054, 39.68025617301464, 40.354294404387474, 36.113144382834435, 38.71685206890106, 40.10765343904495, 39.58300419151783, 39.86657157540321, 46.25392243266106, 50.3159386664629, 52.344980388879776, 48.93983490765095, 48.95335078239441, 49.277446791529655, 44.38166029751301, 41.8833589553833, 36.89723610877991, 37.93741509318352, 38.374532237648964, 38.52558933198452, 37.10356883704662, 39.221761375665665, 39.50149856507778, 38.91313813626766, 37.79909871518612, 38.8431990891695, 39.438516944646835, 38.36561031639576, 36.65139690041542, 37.91363976895809, 34.792738035321236, 37.296571880578995, 37.7128129452467, 37.92900614440441, 37.287182584404945, 39.29776109755039, 42.001004442572594, 44.39516097307205, 41.3945721834898, 46.61843307316303, 49.8355570435524, 52.182436510920525, 52.89582923054695, 54.542953446507454, 53.16107399761677, 54.039248675107956, 57.18753553926945, 55.26895388960838, 44.233555644750595, 38.46412383019924, 39.366271421313286, 40.94938427209854, 42.00630895793438, 45.6949420273304, 53.90412412583828, 59.080384969711304, 55.079933032393456, 63.03061120212078, 38.1633547693491, 0.21872036042623222, 0.7109317579306662, 5.1284717582166195, 4.794317688792944, 0.5326954345218837, 4.078692113980651, 64.39398184418678, 62.059132531285286, 66.72011822462082, 63.120457381010056, 56.96739435195923, 29.599872082471848, 22.562805488705635, 46.47260069847107, 57.78575263917446, 5.630729282274842, 0.2848028519656509, 0.054665403004037216, 0.04547466473013628, 0.07557457516668364, 0.01929865604324732, 0.04463493576622568, 0.03215116579667665, 0.05052200736827217, 0.1750384535989724, 0.1477923124912195, 0.11789424766902812, 0.23258030967554078, 0.29767510655801743, 0.1850161244510673, 0.14826470433035865, 0.14533902460243553, 0.22411381476558745, 0.44165036058984697, 0.14995130914030597, 25.566367618739605, 80.44750481843948, 61.058938801288605, 53.82464379072189, 55.72380468249321, 53.62241484224796, 60.840579718351364, 72.52526432275772, 63.80055248737335, 65.93822658061981, 61.607579961419106, 50.16297027468681, 0.21931211929768324, 1.8077683146111667, 8.451966270804405, 4.260368915274739, 0.5780376889742911, 21.91560711711645, 63.55192422866821, 60.89115120470524, 59.669706746935844, 52.67641380429268, 45.781368389725685, 43.1267624348402, 45.637956485152245, 47.33135461807251, 50.508508533239365, 51.442604809999466, 49.61250901222229, 44.56182383000851, 42.68827736377716, 41.01377561688423, 43.344608545303345, 52.745509296655655, 55.72752088308334, 57.40480028092861, 53.31001080572605, 53.47750961780548, 50.88873513042927, 50.73391243815422, 44.2455630004406, 41.43185958266258, 41.38123869895935, 42.32187822461128, 40.24006873369217, 41.69496886432171, 39.758072197437286, 42.118399143218994, 42.42005355656147, 44.06039133667946, 40.41569150984287, 42.55811534821987, 40.884772539138794, 42.499917671084404, 42.02937372028828, 39.660151451826096, 43.91504533588886, 43.38443800806999, 40.2320359647274, 39.285252168774605, 45.15932656824589, 50.25216668844223, 50.960368886590004, 49.90983545780182, 52.502694725990295, 51.21287293732166, 47.06118531525135, 41.28469727933407, 39.045884013175964, 37.08878003060818, 40.64541958272457, 39.332639425992966, 42.59992830455303, 44.28006514906883, 43.73641312122345, 42.89300657808781, 41.77809700369835, 43.345543295145035, 41.07380859553814, 42.22004368901253, 42.57303334772587, 43.82302187383175, 43.2912328094244, 42.092100754380226, 42.288736402988434, 35.0044284760952, 39.70132604241371, 39.74638022482395, 39.69343766570091, 40.12960106134415, 48.04640784859657, 52.22662813961506, 55.53776666522026, 51.628240048885345, 50.31203627586365, 52.2757139056921, 47.6167307049036, 44.92527432739735, 39.686373844742775, 40.4290933907032, 39.57366809248924, 41.24688930809498, 38.568264842033386, 41.404949426651, 42.69392006099224, 41.463135704398155, 39.724979773163795, 41.05434224009514, 41.62760607898235, 41.383738964796066, 41.09405770897865, 41.07657864689827, 37.64809861779213, 40.095117911696434, 39.551416486501694, 42.31277011334896, 40.36765828728676, 40.730804800987244, 45.025672540068626, 46.90977863967419, 44.281189888715744, 49.66943755745888, 49.34287168085575, 55.12817144393921, 55.94322390854359, 57.03102573752403, 56.06989771127701, 55.528244376182556, 61.11546076834202, 57.48198553919792, 47.75252401828766, 41.69823668897152, 41.66571423411369, 44.49984535574913, 43.748534470796585, 47.699543461203575, 56.20409891009331, 62.320725694298744, 57.99051605165005, 65.13967663049698, 41.40750288963318, 0.38436789996922016, 0.8900627552065998, 7.597824828699231, 9.194728564471006, 1.4415389788337052, 4.4209017511457205, 71.13238826394081, 67.74090304970741, 74.35505613684654, 68.12595918774605, 61.936463713645935, 32.82071225345135, 29.56721093505621, 54.22975145280361, 69.52028676867485, 9.78935295715928, 0.452286553918384, 0.14106875139987096, 0.311121100676246, 0.17763693525921553, 0.16688569419784471, 0.12844725366448984, 0.1780865283217281, 0.17098159238230437], [0.023124620274757035, 0.01456861029510037, 0.007494056026189355, 0.08326432347530499, 0.04110674715775531, 0.018800316865963396, 0.010599573906802107, 0.0799555322737433, 0.08896892322809435, 0.18574182613519952, 0.06803014679462649, 13.605913762003183, 63.2552095502615, 46.14151306450367, 45.55766299366951, 93.96658658981323, 66.07940420508385, 41.75716392695904, 62.86188505589962, 56.48632496595383, 56.6442596912384, 47.50519149005413, 51.01141154766083, 1.4649933390319347, 0.9244412323459983, 1.0739887389354408, 3.5788457980379462, 0.09162934453343041, 4.863738063722849, 63.83882403373718, 55.54207943379879, 52.98091046512127, 41.94119565188885, 40.04475921392441, 40.412210896611214, 42.46579550206661, 47.3830546438694, 49.57539260387421, 49.42291438579559, 48.573956340551376, 40.5648373067379, 37.51236230134964, 37.283151000738144, 48.04276764392853, 51.47782512009144, 51.242484748363495, 48.066691160202026, 46.295347809791565, 48.00313577055931, 49.290172308683395, 51.271237805485725, 46.96706436574459, 40.709392949938774, 37.56606101989746, 35.95501966774464, 35.90261667966843, 35.59643670916557, 37.20554396510124, 36.64702333509922, 38.591511994600296, 37.68438287079334, 39.1867196559906, 38.53391468524933, 38.89969065785408, 37.76681564748287, 38.18277172744274, 37.608512341976166, 37.07142636179924, 38.96584130823612, 33.74376252293587, 33.91644425690174, 40.25524891912937, 44.15825128555298, 43.737104684114456, 45.854582861065865, 46.62883311510086, 48.926763609051704, 42.0335952937603, 39.966806396842, 36.926414743065834, 37.394405230879784, 36.74112528562546, 40.31098812818527, 39.636148139834404, 38.16169045865536, 37.3343912512064, 37.978616282343864, 38.944440856575966, 37.94336557388306, 38.11286307871342, 36.863326728343964, 37.81467787921429, 38.43990013003349, 37.44702100753784, 39.82666991651058, 38.292262852191925, 36.819021105766296, 38.921208903193474, 39.20818090438843, 39.55404594540596, 39.70893323421478, 43.80328953266144, 45.064552053809166, 50.45012466609478, 47.002269476652145, 45.119124725461006, 49.14471611380577, 44.37107406556606, 38.2924984395504, 33.87712016701698, 34.93206135928631, 37.07954652607441, 38.86570908129215, 36.09582111239433, 38.700022771954536, 36.93280979990959, 38.18670451641083, 38.43561016023159, 36.51588097214699, 37.404850870370865, 37.76216849684715, 35.252874344587326, 37.05694153904915, 35.86471751332283, 35.5978312343359, 36.66831739246845, 36.89198099076748, 37.64071561396122, 38.479372411966324, 36.86049588024616, 40.51043942570686, 43.543999046087265, 47.43346653878689, 47.4180393666029, 48.866943418979645, 52.7106499671936, 53.15742239356041, 50.68630859255791, 49.145020097494125, 45.529267117381096, 55.96151612699032, 52.241983115673065, 44.607759565114975, 37.648387402296066, 39.819701090455055, 37.79615767300129, 41.34614758193493, 45.49911193549633, 53.628213331103325, 51.783252730965614, 63.10701370239258, 26.984419226646423, 0.4604502971051261, 0.9610459743998945, 2.479992974549532, 1.4907567878253758, 0.3425093163968995, 7.62891998514533, 62.82598078250885, 58.833592012524605, 61.96286849677563, 59.83822010457516, 49.51163962483406, 24.459859393537045, 25.953124165534973, 41.823208183050156, 41.65627174079418, 3.0150949861854315, 0.24870783177902922, 0.03074132269830443, 0.03242471400881186, 0.043562209539231844, 0.021963400358799845, 0.11083566627348773, 0.047280951985158026, 0.05986952433886472, 0.0570224120747298, 0.019311478499730583, 0.05239993413852062, 0.08963493397459388, 0.03222155479306821, 0.07818171026883647, 0.07487885624868795, 0.09087484009796754, 0.07622573553817347, 0.10756814590422437, 0.03161172462569084, 17.63217866420746, 69.00047466158867, 51.79931826889515, 45.634046494960785, 76.64460808038712, 59.74176608026028, 47.53553666174412, 68.67900431156158, 60.78071013092995, 61.485006138682365, 52.887249290943146, 54.46734130382538, 1.6294443584047258, 0.8526817860547453, 1.6594166751019657, 4.678946379572153, 0.13042856531683356, 6.174127198755741, 66.82502299547195, 58.04272525012493, 54.99184995889664, 43.69715362787247, 41.505530029535294, 40.89584894478321, 44.72040832042694, 48.85074868798256, 51.731149926781654, 52.85095363855362, 50.499514415860176, 42.715506702661514, 39.82024446129799, 39.43413957953453, 49.7197088599205, 52.41800867021084, 54.20981012284756, 49.04216341674328, 48.00609961152077, 50.49407310783863, 51.84168219566345, 52.88166359066963, 49.64932903647423, 42.53016784787178, 38.86614225804806, 37.620884478092194, 39.51726771891117, 38.213276490569115, 39.52712059020996, 38.25206100940704, 39.27642144262791, 40.037235617637634, 40.3327913582325, 39.708078280091286, 40.58749169111252, 39.53932173550129, 38.76965023577213, 38.78768406808376, 40.527960285544395, 40.335952788591385, 36.61188282072544, 35.80544449388981, 42.24413059651852, 45.81990212202072, 47.486697882413864, 45.296142026782036, 49.0661933273077, 51.239775493741035, 43.617969676852226, 39.57117162644863, 37.352816462516785, 36.60403624176979, 38.47296595573425, 42.62568712234497, 40.81774793565273, 40.76443299651146, 39.63939316570759, 39.86915543675423, 41.79490730166435, 39.957075119018555, 39.08616565167904, 39.32518422603607, 39.03857320547104, 39.309038892388344, 39.87732879817486, 40.17241336405277, 40.58179199695587, 39.16500382125378, 39.282250329852104, 39.377290830016136, 39.38920699059963, 41.05180397629738, 43.89163099229336, 46.329272389411926, 52.04942464828491, 50.0676903873682, 48.102029263973236, 50.920991599559784, 45.81186555325985, 40.01450523734093, 36.70615576207638, 37.460768669843674, 38.95216964185238, 40.13276629149914, 38.59163738787174, 39.62807357311249, 38.33849877119064, 40.07271431386471, 39.416333734989166, 39.31719705462456, 39.10609558224678, 39.797362089157104, 38.199840411543846, 38.56077544391155, 38.01841154694557, 37.39334888756275, 39.15049619972706, 39.659448489546776, 39.7463346272707, 41.223604157567024, 39.80355195701122, 44.09651219844818, 43.92850041389465, 49.7621563822031, 48.682584911584854, 50.36624036729336, 54.763242825865746, 55.40351986885071, 53.354400023818016, 51.16394676268101, 49.24533851444721, 58.17465417087078, 54.468374848365784, 46.0900904238224, 39.48883004486561, 42.923146560788155, 40.575165152549744, 43.13414923846722, 47.946397215127945, 56.28048241138458, 53.75595487654209, 65.0294977426529, 28.95296059548855, 0.2299314658739604, 2.190262796357274, 8.814981691539288, 4.6000198647379875, 0.46608637436293066, 7.321170698851347, 66.99923604726791, 62.357256934046745, 68.26707601547241, 65.1096810400486, 58.30133177340031, 24.587963819503784, 23.204573951661587, 47.9797176271677, 50.155811458826065, 4.344180542975664, 0.3434367338195443, 0.07215984238428064, 0.0477194796258118, 0.0741197430761531, 0.07192882665549405, 0.03832962684100494, 0.056937703338917345, 0.00874974948601448, 0.15043538238387555, 0.11647301260381937, 0.23579689644975588, 0.2199050656054169, 0.22508343070512637, 0.119677665643394, 0.15975067159160972, 0.14666577684693038, 0.2410427969880402, 0.24819420621497557, 0.163600325176958, 18.4180448949337, 80.31105414032936, 59.19390007853508, 58.02035965025425, 94.16536912322044, 72.94008046388626, 55.39910450577736, 72.81771183013916, 65.46055421233177, 66.78438797593117, 57.884524539113045, 61.56662195920944, 2.208755691535771, 2.886224901303649, 5.254945596680045, 9.36977282166481, 0.2549439651193097, 7.6120085176080465, 69.88197416067123, 59.85910378396511, 58.75853843986988, 45.177443996071815, 42.80172787606716, 43.276899978518486, 46.35802544653416, 51.762414649128914, 54.44092892110348, 54.527492076158524, 53.50332923233509, 43.995019644498825, 42.681034952402115, 41.22448191046715, 53.39079067111015, 54.72250521183014, 55.84257110953331, 52.12534077465534, 50.17022788524628, 52.95354053378105, 55.26752516627312, 54.77019265294075, 53.46479929983616, 46.66884496808052, 43.17906282842159, 40.4445281624794, 41.70512191951275, 39.58522327244282, 42.618383914232254, 41.71556755900383, 42.776193246245384, 40.89829981327057, 43.42607617378235, 41.14957273006439, 43.4129174798727, 42.32785150408745, 42.105776220560074, 41.77054300904274, 41.75957299768925, 42.905868887901306, 37.10660867393017, 39.05147351324558, 43.723151832818985, 48.27492758631706, 50.0230123847723, 48.647341802716255, 50.39209417998791, 52.093023508787155, 44.21005770564079, 40.62114268541336, 38.54394614696503, 38.924081549048424, 37.773370295763016, 43.93271818757057, 42.687775790691376, 42.19880662858486, 41.43378607928753, 41.76105871796608, 44.083121716976166, 41.165448278188705, 42.46959909796715, 40.599898025393486, 40.80781526863575, 42.58205786347389, 41.073702201247215, 41.39386922121048, 42.883393093943596, 39.177881330251694, 40.621017292141914, 39.57426466047764, 40.708082020282745, 41.509861797094345, 45.44357791543007, 46.52445271611214, 55.05072399973869, 51.423849016427994, 52.11419217288494, 54.937094897031784, 48.81301671266556, 41.99969731271267, 39.6222522854805, 39.90779936313629, 41.586378291249275, 42.52146251499653, 39.557754546403885, 41.41699478030205, 40.24809010326862, 42.468884736299515, 42.58243404328823, 41.5521003305912, 41.76429234445095, 42.12959334254265, 41.15054927766323, 41.071642711758614, 39.93294261395931, 40.03219708800316, 41.634947285056114, 41.944117695093155, 41.0048308968544, 43.01269255578518, 42.1840064227581, 44.541498720645905, 47.42522098124027, 52.25576497614384, 52.38892123103142, 54.78356793522835, 57.71519422531128, 57.75580644607544, 55.32146707177162, 51.85633420944214, 51.86477355659008, 60.03561571240425, 56.53437718749046, 49.2418958991766, 41.484205573797226, 43.58349032700062, 42.42686279118061, 45.88602997362614, 51.16833932697773, 57.7843277156353, 58.90982732176781, 64.36220034956932, 32.70548343658447, 0.48173907038290054, 3.4610485564917326, 13.837488535791636, 8.752377200871706, 0.7221016741823405, 8.843100182712078, 73.171047270298, 68.10829013586044, 71.57388657331467, 68.92189487814903, 63.328868597745895, 34.05544839799404, 36.29481263458729, 55.47594018280506, 60.60529634356499, 5.3745251800864935, 0.47146427328698337, 0.1743434471427463, 0.08524467033566907, 0.3005686216056347, 0.07673409185372293, 0.2274862673948519, 0.248222571099177, 0.13936682866187766], [0.027946615336986724, 0.032442989395349286, 0.06516397988889366, 0.014348399308801163, 0.014049101355340099, 0.09160244910162874, 0.05365406352211721, 0.004495938046602532, 0.07823806896340102, 0.21554582373937592, 0.03904676043021027, 6.257323259487748, 58.83179850876331, 49.780931174755096, 46.57351568341255, 80.64604416489601, 71.56472906470299, 38.39921571314335, 54.51694384217262, 55.21113999187946, 56.923537105321884, 48.05374525487423, 55.758162438869476, 7.291322350502014, 1.2868927395902574, 0.24180006963433698, 3.2632713066414, 0.4759036225732416, 2.238968820311129, 52.847784608602524, 57.48888596892357, 52.26392313838005, 43.005640134215355, 41.89058616757393, 43.55621159076691, 51.13121151924133, 53.14298316836357, 52.83779874444008, 53.25266048312187, 48.924886509776115, 38.7288898229599, 36.13784305751324, 45.35335175693035, 51.22081831097603, 50.811340883374214, 50.06515212357044, 45.313575491309166, 49.698942974209785, 46.83100126683712, 48.35144408047199, 48.845124989748, 50.9105459600687, 49.41926658153534, 41.572957411408424, 38.077334985136986, 36.85714066028595, 36.15920931100845, 36.070457473397255, 36.15965388715267, 37.7412012219429, 37.7543181180954, 37.524517849087715, 36.9249252229929, 37.67236791551113, 38.88459786772728, 36.81047536432743, 36.73977255821228, 39.33797813951969, 38.13040293753147, 35.183387473225594, 36.628050953149796, 38.92451472580433, 44.92624707520008, 44.510602578520775, 45.41846126317978, 49.01077330112457, 44.68724749982357, 43.17806728184223, 40.91668322682381, 36.30707457661629, 36.90345257520676, 38.23806256055832, 37.86246411502361, 37.19214208424091, 38.50751370191574, 37.38156571984291, 38.18249054253101, 38.48632983863354, 38.57982762157917, 39.98605236411095, 38.288394659757614, 37.481162175536156, 37.219721004366875, 37.83331587910652, 37.395529970526695, 38.06469686329365, 39.197518676519394, 39.064389020204544, 38.12171660363674, 38.063382133841515, 40.78603483736515, 41.15310654044151, 47.55363889038563, 46.0340890288353, 48.23235847055912, 43.72220188379288, 45.96001200377941, 43.02910387516022, 40.68364553153515, 33.9418762922287, 35.54731674492359, 36.87034875154495, 39.73593458533287, 36.964173316955566, 36.51399627327919, 38.08839999139309, 37.32774920761585, 37.257129997015, 38.53870242834091, 36.112046241760254, 36.36855527758598, 35.579949393868446, 35.28162360191345, 34.39149856567383, 35.968387350440025, 34.91326756775379, 36.87128730118275, 33.56629304587841, 36.04312174022198, 37.09841251373291, 41.74966312944889, 44.236059710383415, 47.41362400352955, 44.29246388375759, 49.4368976354599, 46.551290675997734, 53.087608739733696, 49.961831867694855, 53.711067885160446, 44.81789588928223, 49.112657234072685, 53.247097581624985, 52.90109574794769, 42.59357124567032, 36.92749008536339, 38.41982580721378, 41.509895995259285, 43.93268778920174, 55.13214223086834, 50.430209934711456, 62.875001952052116, 26.986752301454544, 0.508388732559979, 1.4968615164980292, 4.18032668530941, 5.956604070961475, 0.9251922857947648, 15.212327912449837, 66.52192085981369, 55.26101231575012, 62.03360930085182, 59.39374655485153, 42.976723685860634, 33.96757811307907, 38.0445921421051, 44.18421909213066, 31.825574152171612, 1.0548997507430613, 0.07470914191799238, 0.04061806888785213, 0.031360515058622696, 0.14671921147964895, 0.0701183796627447, 0.050567779326229356, 0.0525737414136529, 0.009319616856373614, 0.035946523858001456, 0.05057207265053876, 0.07689383914112113, 0.06098568104789592, 0.038784637581557035, 0.045284389198059216, 0.05991805337544065, 0.05061216346803121, 0.06835297361249104, 0.2915135590592399, 0.06013697951857466, 8.243668098002672, 68.68394404649734, 56.29212498664856, 56.822333335876465, 85.92104271054268, 71.44128888845444, 43.72074656188488, 63.62782895565033, 60.53897850215435, 62.4139840900898, 52.67512567341328, 58.76508928835392, 7.182001266628504, 1.0907499957829714, 2.234359667636454, 3.503037728369236, 0.5902002425864339, 2.9229245195165277, 55.721270218491554, 59.32416848838329, 55.23928128182888, 44.380611553788185, 44.395875334739685, 46.12570971250534, 52.90583409368992, 55.03923341631889, 54.9069245159626, 55.124181658029556, 52.04193904995918, 41.51393137872219, 38.09556260704994, 46.86599358916283, 53.93002353608608, 55.004514679312706, 51.60448372364044, 48.16664479672909, 50.467459335923195, 48.401722982525826, 50.64416125416756, 50.551317036151886, 51.8598148226738, 49.78278927505016, 43.7883335351944, 40.336845740675926, 38.56614075601101, 38.91073666512966, 39.003299698233604, 38.89376297593117, 41.15944840013981, 39.54381309449673, 39.49768736958504, 38.28690133988857, 39.2319106310606, 39.80240821838379, 38.42681743204594, 39.136087372899055, 43.1343050301075, 40.28396397829056, 36.9568283110857, 38.45007598400116, 42.55466513335705, 48.493168875575066, 48.382283225655556, 47.59669058024883, 51.03254221379757, 45.9341049939394, 42.563974633812904, 40.36431826651096, 37.48525455594063, 37.731154561042786, 38.14077638089657, 40.44434577226639, 39.57006588578224, 39.4934505969286, 39.48414869606495, 40.638709142804146, 39.904805123806, 41.661469861865044, 39.98915679752827, 40.80606736242771, 40.610685646533966, 38.87267030775547, 39.88995172083378, 39.237652122974396, 41.02890260517597, 40.17034247517586, 39.84562709927559, 39.06563155353069, 39.421144276857376, 40.67473880946636, 42.231876254081726, 47.85489812493324, 48.49605672061443, 49.831077083945274, 43.91261346638203, 50.008079186081886, 46.061527356505394, 41.25147186219692, 36.313640624284744, 37.46665835380554, 39.02337022125721, 40.821581929922104, 38.298471719026566, 38.3987445384264, 38.43556456267834, 38.49016763269901, 39.9491373449564, 40.45090802013874, 38.47118765115738, 38.033926114439964, 38.308788165450096, 37.523351311683655, 38.18477421998978, 39.05120372772217, 37.21070408821106, 39.077182933688164, 36.423078551888466, 37.9505205899477, 41.52996651828289, 45.3735476732254, 46.29866503179073, 48.44033271074295, 47.3754246532917, 51.15022949874401, 49.04045730829239, 55.28986036777496, 52.12558016180992, 55.1803008466959, 46.689926236867905, 51.01417399942875, 57.05090247094631, 54.487936198711395, 43.82590971887112, 39.83915984630585, 41.2719451636076, 42.03954577445984, 46.486865133047104, 57.72845171391964, 55.81790283322334, 64.31512087583542, 29.807534739375114, 0.4702171386452392, 1.9388725608587265, 9.733187220990658, 1.793826031498611, 0.501013743923977, 15.512254368513823, 72.64926686882973, 60.00623568892479, 68.53048548102379, 63.30801531672478, 52.83938705921173, 31.386118233203888, 39.6719042211771, 52.83527947962284, 39.01722975075245, 0.9913771343417466, 0.09939888113876805, 0.06944381937501021, 0.050586459183250554, 0.05627386337437201, 0.049861421721288934, 0.03438031024415977, 0.04254595703969244, 0.03983527378295548, 0.1098662952426821, 0.08180836332030594, 0.14268746454035863, 0.1159614279458765, 0.10514305220567621, 0.14601942559238523, 0.21324044588254765, 0.13542534172302112, 0.13696134992642328, 0.48885899770539254, 0.21556221036007628, 8.998893722891808, 76.27507790923119, 66.21894031763077, 60.094007179141045, 84.44256484508514, 75.22498145699501, 48.00345115363598, 66.44837960600853, 63.8992103934288, 69.10574421286583, 57.75922246277332, 64.82857212424278, 9.990744050592184, 2.789051290601492, 5.477407509461045, 11.03800680488348, 1.3275253842584789, 3.6025631753727794, 57.55102403461933, 60.8949775993824, 58.09865064918995, 46.13761827349663, 46.819651275873184, 48.41479808092117, 57.63425096869469, 57.9422814399004, 56.80580422282219, 57.8534422069788, 53.41784901916981, 43.65924306213856, 41.45289145410061, 50.25067336857319, 57.29585252702236, 56.60712048411369, 54.39920715987682, 49.94602091610432, 51.80594511330128, 49.354263469576836, 54.84325133264065, 51.88887566328049, 54.26691725850105, 53.19880597293377, 46.73706650733948, 42.99216985702515, 40.943688377738, 40.81277020275593, 41.28038451075554, 41.05061084032059, 43.10973174870014, 41.90635912120342, 40.66949889063835, 39.548604637384415, 40.7691865414381, 42.657829597592354, 41.9318063557148, 39.01065230369568, 44.16664123535156, 42.40019582211971, 40.74396349489689, 42.79064007103443, 43.94289784133434, 52.842700481414795, 51.506069004535675, 50.08116826415062, 52.86567024886608, 46.40601687133312, 43.36421549320221, 41.80513635277748, 37.46418848633766, 40.3560309112072, 39.65579688549042, 42.357664704322815, 40.195371732115746, 42.6773339509964, 40.691685900092125, 42.16327093541622, 42.26406052708626, 43.27798672020435, 43.077380284667015, 41.84294052422047, 43.16348746418953, 42.24603429436684, 42.61205345392227, 41.803278252482414, 41.6564617305994, 43.470681980252266, 41.53632737696171, 40.522359386086464, 40.96892662346363, 40.165744721889496, 42.648227512836456, 49.45537984371185, 50.6807266920805, 53.16593013703823, 47.90830805897713, 52.15773783624172, 48.07836793363094, 45.06532721221447, 38.71834918856621, 39.24870193004608, 41.58712685108185, 44.259873032569885, 40.639849081635475, 40.15682280063629, 40.50680302083492, 40.49628138542175, 41.952108666300774, 41.6682904958725, 39.59025800228119, 41.079208105802536, 41.38466231524944, 40.168590769171715, 39.40156012773514, 40.468919053673744, 39.93252843618393, 42.067318484187126, 38.79447050392628, 39.99385714530945, 43.561664298176765, 46.45120784640312, 48.951743468642235, 52.228991612792015, 49.858724400401115, 52.54886604845524, 50.29309809207916, 57.373231574893, 55.18660470843315, 56.52492329478264, 47.61822022497654, 52.604723051190376, 57.34100550413132, 57.622030824422836, 46.26573219895363, 43.097549602389336, 43.696541860699654, 46.878836899995804, 47.33159780502319, 61.55863858759403, 58.32402415573597, 66.6664271056652, 33.19050081074238, 0.4289171251002699, 4.1939727030694485, 16.461267694830894, 13.480453994125128, 1.1744471546262503, 17.553585581481457, 77.64219895005226, 63.00120837986469, 73.34255486726761, 69.42399993538857, 58.953935354948044, 44.621127247810364, 48.07581067085266, 60.79579912126064, 51.01512394845486, 1.834314283914864, 0.17359404126182199, 0.19480572023894638, 0.1310681481845677, 0.21013902558479458, 0.13752811326412484, 0.20332095940830186, 0.1885433742427267, 0.14123923756415024], [0.0329364842036739, 0.10755418610642664, 0.09519945335341617, 0.040103155697579496, 0.042814484622795135, 0.032915076953941025, 0.019076156459050253, 0.02101134363329038, 0.05113462801091373, 0.09783086410607211, 0.27119613834656775, 0.894338475773111, 41.793425381183624, 56.48400329053402, 28.990576677024364, 42.83634401857853, 60.62858149409294, 38.84847700595856, 47.03108713030815, 56.52229763567448, 58.81784565746784, 49.763102531433105, 56.65709540247917, 18.522337898612022, 0.723882116144523, 0.9054950333666056, 2.3222043039277196, 0.9481381857767701, 1.745636542327702, 51.1074323952198, 55.23796275258064, 53.188880905508995, 43.987009674310684, 45.72189398109913, 50.025512650609016, 52.046331614255905, 54.180996268987656, 55.25114044547081, 52.51229681074619, 46.84160649776459, 36.67540021240711, 43.052966594696045, 49.174270927906036, 51.76412835717201, 50.61459124088287, 50.34429654479027, 47.262490913271904, 51.133434399962425, 50.3720198571682, 49.53604571521282, 48.07904049754143, 50.813005194067955, 49.348157197237015, 48.80669005215168, 41.95432014763355, 38.377260491251945, 36.00878678262234, 38.98719996213913, 36.718964874744415, 37.36408665776253, 37.02528163790703, 38.326024040579796, 38.23447175323963, 38.83429616689682, 38.118684366345406, 39.31281588971615, 37.24922642111778, 39.3305267393589, 37.26531095802784, 34.924837946891785, 36.26662194728851, 43.13678249716759, 46.0305742174387, 43.07664692401886, 43.44507895410061, 45.86339458823204, 44.751068875193596, 39.81333643198013, 38.83517012000084, 37.21953861415386, 36.62230186164379, 41.163715571165085, 40.0647309422493, 38.70005317032337, 36.620143577456474, 36.82056002318859, 38.63777071237564, 38.92612583935261, 38.82578082382679, 38.45147430896759, 39.19035226106644, 36.67081765830517, 37.89861157536507, 35.50450824201107, 38.41321036219597, 37.39799603819847, 39.70675215125084, 37.81080208718777, 39.3394410610199, 37.11553439497948, 40.60134194791317, 43.46970543265343, 45.53012207150459, 46.60977713763714, 46.988274827599525, 42.83077731728554, 45.39662763476372, 45.88058486580849, 36.5500221401453, 34.625041633844376, 33.53291563689709, 38.52641388773918, 35.90824417769909, 38.73829051852226, 36.16255693137646, 37.38025479018688, 38.03271397948265, 38.36130514740944, 36.753463223576546, 37.834657207131386, 35.57481586933136, 34.33024205267429, 35.86715318262577, 34.59484465420246, 35.28250515460968, 34.07211430370808, 35.081017166376114, 35.33475615084171, 37.1267893910408, 39.11309100687504, 45.487849339842796, 46.440439224243164, 44.99266751110554, 46.7760144174099, 47.402456402778625, 47.368231639266014, 48.22115287184715, 51.71085901558399, 50.965608805418015, 51.890718564391136, 46.97838395833969, 52.48999960720539, 53.30345615744591, 49.56026941537857, 40.472152680158615, 37.31448411941528, 39.20676738023758, 43.15569028258324, 53.77300076186657, 52.13188402354717, 64.4954439997673, 27.480853088200092, 0.41565874591469765, 2.1457465225830674, 5.453778002411127, 2.5835236441344023, 0.5021867528557777, 28.677177093923092, 64.10128355026245, 56.46952606737614, 58.84664811193943, 58.24234373867512, 39.846748039126396, 24.586001224815845, 33.55902403593063, 45.8779364079237, 21.76325049251318, 0.8264942443929613, 0.03386338954442181, 0.15796574705746025, 0.04626288122381084, 0.06637566955760121, 0.03062234158278443, 0.08058382707531564, 0.03940420843719039, 0.05966876226011664, 0.043596867835731246, 0.029774372924293857, 0.07156279199989513, 0.02383600593020674, 0.06672428600722924, 0.12481617741286755, 0.043298301825416274, 0.03180829357006587, 0.08721795937162824, 0.10843735668458976, 0.14406106114620343, 1.625722695607692, 51.358610317111015, 61.869055330753326, 35.75229674577713, 58.31726811826229, 73.47077518701553, 43.14115606248379, 52.842898070812225, 62.635675594210625, 66.07348412275314, 53.0728617310524, 61.13946408033371, 19.087221287190914, 0.5677408946212381, 1.2709541385993361, 5.374951707199216, 1.8900737981311977, 1.936156062874943, 55.38517825305462, 57.70959712564945, 55.90844437479973, 46.72587990760803, 47.863098084926605, 52.22638875246048, 55.136743783950806, 55.49185372889042, 56.30985103547573, 54.7897008061409, 49.12134736776352, 38.434979394078255, 43.43617223203182, 50.773662105202675, 56.12904533743858, 53.78137931227684, 53.916990235447884, 48.08948993682861, 51.89598508179188, 51.080594435334206, 51.252896189689636, 50.53841292858124, 52.882788330316544, 49.229820147156715, 51.207591220736504, 41.9760549813509, 41.56494364142418, 38.344806432724, 40.28967127203941, 38.89861151576042, 40.50027497112751, 39.08383637666702, 39.99790772795677, 39.18512374162674, 40.26843421161175, 39.22238074243069, 39.80270840227604, 40.80434985458851, 41.30089960992336, 39.51328553259373, 38.74146714806557, 38.98427411913872, 45.42734518647194, 47.61219374835491, 47.370591312646866, 46.56964369118214, 48.374470844864845, 45.89660860598087, 40.21129667758942, 39.94680427014828, 36.622168868780136, 38.45156170427799, 41.77878096699715, 41.959776654839516, 39.730098098516464, 38.014376163482666, 39.44676250219345, 41.50204561650753, 40.48310749232769, 40.94357058405876, 40.423659682273865, 39.771268889307976, 39.266215190291405, 39.03170697391033, 36.81278184056282, 39.49778616428375, 38.504648655653, 40.35280488431454, 39.003155305981636, 40.950699001550674, 39.213948994874954, 41.6905876994133, 43.05852189660072, 45.252596363425255, 49.10429008305073, 49.664136841893196, 47.72209145128727, 48.747242242097855, 48.04964527487755, 39.531041979789734, 36.41998551785946, 35.736204609274864, 39.4841942936182, 38.73037174344063, 40.04453502595425, 38.238632529973984, 38.215309381484985, 39.91211973130703, 38.73034134507179, 37.730322405695915, 39.72411721944809, 38.211912363767624, 37.19562269747257, 38.69031049311161, 35.92990681529045, 37.78379313647747, 36.56749740242958, 37.17755846679211, 38.77286106348038, 38.62788364291191, 41.514261960983276, 47.349084466695786, 48.71736824512482, 47.158619686961174, 49.017464742064476, 47.90411688387394, 50.34086532890797, 49.23996940255165, 54.45813059806824, 51.8977177888155, 54.12407152354717, 48.953749760985374, 54.6514680236578, 55.24379163980484, 51.06629580259323, 42.22459964454174, 38.97304952144623, 43.650632724165916, 46.25639230012894, 57.16081917285919, 54.411890879273415, 64.44077253341675, 30.272044613957405, 0.36637776531279087, 3.4315281780436635, 11.5389652736485, 3.0419471953064203, 0.6096498551778495, 30.358602069318295, 69.29416850209236, 61.862451285123825, 65.90526714920998, 64.20613512396812, 47.317861542105675, 29.114368334412575, 38.04509751498699, 52.698859199881554, 29.49740868061781, 0.7042554568033665, 0.00101610314231948, 0.15345849125878885, 0.025806328230828512, 0.024030003332882188, 0.015003635926404968, 0.012735465643345378, 0.049498856606078334, 0.11754825100069866, 0.1769733364926651, 0.22531400114530697, 0.14688663999550045, 0.08859573426889256, 0.16628890356514603, 0.1683134527411312, 0.22983963252045214, 0.11703076626872644, 0.19629675429314375, 0.17379923025146127, 0.3370333055499941, 1.7341907252557576, 59.37320865690708, 73.07171300053596, 41.527827233076096, 54.36741806566715, 70.33066928386688, 50.70097200572491, 60.46024672687054, 66.97443097829819, 69.39916446805, 58.779619708657265, 67.72570386528969, 22.28996302932501, 1.2348192650824785, 3.7938294745981693, 7.713898625224829, 2.551142256706953, 2.603190913796425, 58.99674005806446, 60.11522524058819, 58.37080344557762, 47.85755418241024, 50.60111716389656, 55.176052674651146, 56.5218910574913, 58.89353759586811, 58.85744333267212, 57.3054014146328, 51.32042996585369, 41.42100356519222, 47.36842542886734, 54.326422065496445, 56.461550295352936, 54.70915272831917, 56.166906505823135, 49.57911640405655, 52.949812933802605, 55.25659695267677, 52.67902426421642, 52.63259835541248, 56.24874271452427, 51.90542757511139, 55.692946538329124, 46.80409871041775, 42.679070457816124, 40.7046128064394, 44.20485578477383, 41.80672086775303, 41.437091901898384, 42.02760301530361, 41.51876471936703, 40.78636161983013, 42.12132878601551, 41.54148370027542, 42.40339905023575, 40.565665662288666, 43.01444046199322, 42.19921700656414, 40.70091560482979, 40.76514735817909, 48.18077243864536, 51.22318558394909, 50.37431113421917, 48.90562914311886, 49.8819525539875, 46.31680905818939, 40.44567570090294, 40.9041590988636, 39.259056374430656, 39.32761989533901, 43.97268824279308, 43.747238740324974, 42.14692801237106, 39.335512071847916, 40.57647228240967, 42.38977298140526, 43.60365964472294, 42.940948605537415, 45.140870958566666, 41.043269634246826, 40.55229797959328, 43.03150914609432, 37.85133831202984, 42.423420175909996, 40.81830270588398, 44.14515718817711, 41.25033192336559, 40.777891874313354, 39.588848277926445, 43.471992909908295, 42.70596541464329, 46.76970295608044, 51.59170500934124, 52.03643314540386, 49.3689838796854, 51.575844660401344, 50.06823755800724, 42.197944074869156, 38.32761995494366, 38.78225035965443, 43.256137892603874, 41.86266526579857, 42.452025040984154, 40.283557400107384, 40.1434551179409, 41.990722194314, 42.0925947278738, 39.09871257841587, 40.610632449388504, 40.05990520119667, 38.35598163306713, 39.98664893209934, 38.00227761268616, 40.38453698158264, 39.47197414934635, 40.32714486122131, 40.450338050723076, 42.54286676645279, 43.35750125348568, 50.12172348797321, 50.28134152293205, 49.903375804424286, 50.399294793605804, 50.91278783977032, 52.24005661904812, 52.43468977510929, 57.05124445259571, 55.36262646317482, 54.90824304521084, 51.11771084368229, 56.39878146350384, 58.09934601187706, 54.58883598446846, 45.535593777894974, 41.28745213150978, 45.27599550783634, 47.36917398869991, 58.957811146974564, 58.40842142701149, 65.67792534828186, 33.177437111735344, 0.500947959953919, 6.54431520961225, 21.013571619987488, 7.471300167962909, 0.6988206796813756, 35.006860345602036, 72.74954348802567, 65.96345722675323, 69.50837820768356, 68.50041389465332, 52.189013957977295, 33.784253150224686, 43.76816801726818, 61.93364806473255, 37.289154678583145, 0.8956069545820355, 0.12503281031968072, 0.28015531541313976, 0.11686539350193925, 0.1464487283374183, 0.07918642979348078, 0.12413456672220491, 0.13143439806299284, 0.15594326105201617], [0.025990490321419202, 0.07531033348641358, 0.10926994247711264, 0.014704041113873245, 0.05223480999120511, 0.058883429010165855, 0.1113212683412712, 0.051253523779450916, 0.06441962803364731, 0.08130453410558403, 0.15353928145486861, 0.030452556748059578, 22.71937608718872, 59.54270236194134, 43.79936434328556, 21.012163795530796, 18.765766136348248, 39.49110612273216, 56.370051205158234, 56.85360185801983, 56.46138310432434, 52.17861391603947, 52.88474902510643, 27.57073726505041, 0.3096054866909981, 0.95909608528018, 1.383211633656174, 8.358311746269464, 4.925438677892089, 22.92347453534603, 63.82804021239281, 50.86078003048897, 53.83959598839283, 47.046518102288246, 53.67852263152599, 53.36187802255154, 55.56608274579048, 52.38691873848438, 49.80819471180439, 38.905473947525024, 38.75625595450401, 45.38733713328838, 53.20035628974438, 51.99480637907982, 50.72765797376633, 47.63527750968933, 49.20352555811405, 48.55043180286884, 52.89353035390377, 52.32473507523537, 46.82385005056858, 51.725131049752235, 49.72933754324913, 50.20846523344517, 45.80749958753586, 41.972741559147835, 38.636949956417084, 38.304577991366386, 36.82666629552841, 38.533971682190895, 38.20106014609337, 39.719432070851326, 38.646160662174225, 38.35684038698673, 38.01513992249966, 37.3955337703228, 38.960810378193855, 38.57861168682575, 36.91674806177616, 33.95135298371315, 36.52215823531151, 40.84588922560215, 43.58686074614525, 42.99396716058254, 44.15143825113773, 47.33583837747574, 45.00275976955891, 38.37472602725029, 37.92264148592949, 37.17366747558117, 41.48535691201687, 39.546830132603645, 38.328433111310005, 36.11383214592934, 36.906127631664276, 37.7413722127676, 38.620135858654976, 39.44585055112839, 38.91809307038784, 37.627256736159325, 39.76701311767101, 36.36881746351719, 37.21139945089817, 37.34173625707626, 36.4202781021595, 36.61372572183609, 38.87382164597511, 38.5961439460516, 38.70327539741993, 36.66196033358574, 38.39779458940029, 40.55949479341507, 46.8402461707592, 45.08497975766659, 46.114789098501205, 45.272157713770866, 41.387888342142105, 44.53824229538441, 38.31904001533985, 36.10891900956631, 35.09435825049877, 37.75829650461674, 37.4487841129303, 37.44843453168869, 36.0486314445734, 36.299645975232124, 36.377655789256096, 37.633875980973244, 36.67991816997528, 36.41699127852917, 35.1566369086504, 33.9278170466423, 34.03036214411259, 34.815658405423164, 34.44929726421833, 34.82312500476837, 36.77475348114967, 34.7289052605629, 37.8266928344965, 41.51028357446194, 43.43573145568371, 44.97846007347107, 44.81285735964775, 47.70416401326656, 44.11476641893387, 44.825852662324905, 46.224268823862076, 48.17466236650944, 51.17498517036438, 54.8210833221674, 51.118349209427834, 50.03485634922981, 54.15226221084595, 53.682349026203156, 46.51968017220497, 38.46164256334305, 38.8314463198185, 43.83157141506672, 53.87296199798584, 52.58526049554348, 58.437676057219505, 31.02494191378355, 0.7437719113659114, 0.7569757278542966, 7.110134297981858, 0.4884678265079856, 0.3075444238493219, 40.902540385723114, 62.37624831497669, 52.10440769791603, 60.55583439767361, 50.897307470440865, 30.17653103917837, 26.765381880104542, 39.46197688579559, 46.73506781458855, 11.000653859227896, 0.47143601230345666, 0.03583958779927343, 0.11221199398278259, 0.09989957106881775, 0.09975983950425871, 0.0656932796118781, 0.06150392277049832, 0.06436174793634564, 0.07566537693492137, 0.01635268228710629, 0.08753774338401854, 0.06299264874542132, 0.07245143220643513, 0.050890075508505106, 0.04759545932756737, 0.025695460644783452, 0.04792552950675599, 0.10071905053337105, 0.126540023193229, 0.33484854153357446, 0.12381037435261533, 30.918260738253593, 66.01280897855759, 45.22402189671993, 29.01140905916691, 38.47581200301647, 50.13887196779251, 58.35583224892616, 60.354908779263496, 60.690575167536736, 58.6502480506897, 58.421580120921135, 29.29152622818947, 0.2555792435305193, 0.48754037939943373, 2.843936257995665, 13.06314803659916, 6.531858528032899, 26.593786887824535, 66.46647423505783, 55.042372047901154, 56.0942468047142, 50.478041768074036, 54.977125748991966, 56.473246067762375, 57.77445204555988, 53.806860744953156, 53.35114359855652, 41.77184633910656, 41.18582658469677, 48.02374966442585, 53.173221945762634, 54.3231276422739, 51.884654089808464, 48.25575761497021, 49.54362250864506, 50.75544588267803, 52.922887578606606, 52.450823709368706, 49.98783767223358, 52.91657991707325, 51.642610877752304, 52.56367385387421, 49.42838229238987, 43.77802848815918, 42.85733409225941, 41.23510614037514, 39.65860493481159, 41.0216373950243, 38.01691822707653, 40.88179349899292, 39.506415501236916, 39.06191535294056, 39.31462079286575, 38.192996978759766, 42.46266067028046, 40.33844165503979, 38.503717705607414, 36.16541437804699, 39.163578897714615, 43.62300060689449, 46.45928241312504, 43.920399248600006, 47.96197637915611, 47.818078100681305, 46.170828491449356, 38.80250707268715, 38.61943669617176, 37.58992753922939, 42.0014376193285, 41.28004252910614, 38.635673224925995, 38.03737252950668, 38.66643637418747, 39.9403066188097, 40.3308192640543, 39.940747395157814, 40.65706595778465, 40.81033073365688, 41.37143902480602, 39.895153641700745, 38.67673002183437, 39.430506974458694, 39.95581358671188, 39.35980036854744, 40.52929401397705, 39.645925015211105, 39.86712634563446, 37.16817297041416, 37.55840443074703, 41.625094413757324, 47.00699642300606, 47.74697631597519, 47.445804476737976, 47.91825212538242, 44.907255694270134, 45.85835225880146, 40.38940452039242, 37.51514755189419, 38.34393247961998, 39.00057524442673, 37.53089390695095, 38.219416961073875, 38.544561713933945, 38.28313194215298, 37.35069237649441, 37.369717955589294, 38.856448978185654, 36.966194808483124, 36.68384715914726, 37.22237706184387, 37.08873823285103, 38.2322146743536, 36.265740394592285, 36.88244730234146, 38.84428583085537, 37.001088336110115, 40.31793795526028, 41.142269521951675, 47.165995091199875, 48.212914913892746, 48.12790207564831, 49.53380763530731, 47.30377949774265, 47.324807569384575, 48.04978966712952, 50.94967246055603, 54.056062772870064, 55.981347262859344, 52.34955154359341, 51.775569543242455, 55.96986047923565, 55.870685800909996, 47.84724533557892, 40.38329064846039, 40.23887559771538, 46.683675572276115, 56.493244394659996, 56.177538335323334, 60.82789599895477, 35.78590974211693, 0.5871161737013608, 1.756741446442902, 8.52983359247446, 0.80385304056108, 0.375291018281132, 43.04991915822029, 68.5688254237175, 57.28028856217861, 64.42017763853073, 55.07885009050369, 37.016420513391495, 26.459929570555687, 43.24255362153053, 53.2208675891161, 16.34141832590103, 0.5147184210363775, 0.04302737339457963, 0.12318409819272347, 0.04153151538048405, 0.09436637774342671, 0.042783811659319326, 0.08141716243699193, 0.04759388597449288, 0.11347855062922463, 0.12704362976364791, 0.19475184031762183, 0.1254306608461775, 0.1348030657391064, 0.17053305316949263, 0.1416308688931167, 0.20022651529870927, 0.09591494308551773, 0.21447618113597855, 0.2405427527264692, 0.4244569659931585, 0.1999890131992288, 35.078395307064056, 77.97010615468025, 57.25388377904892, 35.755268186330795, 30.994982421398163, 51.222076043486595, 65.54271340370178, 67.0767442882061, 65.19592121243477, 63.46669480204582, 61.82695358991623, 35.42120911180973, 0.28862666396889836, 5.873053204268217, 3.5977963311597705, 17.510379999876022, 8.574426099658012, 27.953382432460785, 69.07734453678131, 56.7523030936718, 59.65813256800175, 52.05326244235039, 57.021115869283676, 58.16842630505562, 59.636701717972755, 55.489072278141975, 54.16262045502663, 43.636018708348274, 43.41247670352459, 50.53183928132057, 56.75026260316372, 55.51410913467407, 54.329594895243645, 50.485622361302376, 51.86913192272186, 50.648318231105804, 55.293523371219635, 55.25101125240326, 51.0726148635149, 54.95170131325722, 52.68267206847668, 55.667685493826866, 50.328626185655594, 47.135604321956635, 43.82285848259926, 42.316642105579376, 41.3924290984869, 45.04651062190533, 41.386189833283424, 43.66031460464001, 41.80497296154499, 41.55281089246273, 42.49913111329079, 38.57690177857876, 44.191237315535545, 41.36546954512596, 41.54518850147724, 39.161067232489586, 40.33983238041401, 45.346512123942375, 49.53910835087299, 46.70118883252144, 48.388412296772, 50.45069843530655, 48.42767558991909, 38.95157307386398, 39.585306867957115, 38.03589440882206, 44.828732907772064, 43.29572796821594, 40.61649173498154, 40.07122099399567, 40.42919218540192, 43.50006580352783, 43.92163798213005, 42.53877058625221, 43.33500646054745, 42.880767434835434, 43.2617311924696, 41.99564293026924, 42.08239607512951, 43.2725378125906, 39.11195106804371, 40.861757174134254, 42.997193187475204, 41.77647069096565, 41.12014330923557, 38.28587159514427, 37.875106036663055, 41.11706167459488, 47.277720496058464, 50.03253847360611, 49.53914634883404, 50.30116505920887, 47.02131025493145, 49.14543807506561, 41.90190576016903, 41.00084111094475, 41.45851515233517, 42.68106535077095, 39.33279141783714, 40.37431173026562, 41.09933562576771, 39.814050793647766, 40.58906860649586, 40.01109682023525, 39.86342154443264, 39.3802622705698, 38.630193918943405, 38.97292032837868, 39.33336138725281, 40.764429196715355, 39.614933878183365, 39.280570819973946, 42.20959044992924, 39.12361264228821, 43.23778107762337, 44.25720937550068, 48.55724863708019, 49.40076157450676, 50.077098682522774, 52.75104179978371, 49.77440692484379, 49.75253909826279, 50.16274228692055, 55.15442803502083, 55.50270214676857, 59.04749013483524, 55.83136171102524, 53.73386286199093, 58.130314350128174, 60.65404012799263, 51.97834186255932, 43.6003690212965, 42.52748139202595, 48.23269285261631, 58.29685561358929, 57.812244817614555, 61.40272535383701, 37.12057672441006, 0.9553034137934446, 3.079011831432581, 18.029413148760796, 2.740639988332987, 0.4054546606494114, 47.04647250473499, 73.4785495698452, 61.88108928501606, 69.58638802170753, 60.86845122277737, 41.605191081762314, 35.40488138794899, 51.614347994327545, 62.02782981097698, 21.327603869140148, 0.6350054789800197, 0.17205864161951467, 0.17182899144245312, 0.20649965212214738, 0.17696975934086367, 0.12444868072634563, 0.21737125469371676, 0.13023581472225487, 0.25719875819049776], [0.1522927702171728, 0.009030884302774211, 0.05087187062599696, 0.034433592736604623, 0.055610338822589256, 0.03075347722187871, 0.0619752050988609, 0.02840326436853502, 0.006546075082951575, 0.08591396137489937, 0.22408542019547895, 0.03806109925790224, 6.865756586194038, 61.508724465966225, 44.547065421938896, 37.25049555301666, 18.84282600134611, 31.171549446880817, 52.90472835302353, 61.37105405330658, 54.44272242486477, 53.44885155558586, 49.383290112018585, 42.38392889499664, 0.5045704718213528, 0.49237858853302896, 3.8785183802247047, 7.906814273446798, 1.9821043848060071, 9.778649881482124, 55.81266671419144, 54.04318906366825, 54.85942326486111, 50.635053142905235, 54.037189185619354, 54.410116374492645, 54.96949575841427, 50.19437938928604, 46.16031065583229, 36.57312490046024, 42.614990696311, 49.772389233112335, 52.72065483033657, 52.3326500505209, 50.05203902721405, 50.95585472881794, 53.30668978393078, 53.10360208153725, 50.31998544931412, 54.339105784893036, 51.9902466237545, 49.76928099989891, 51.54249005019665, 50.382017120718956, 49.696514904499054, 44.14345107972622, 41.67984567582607, 40.041548386216164, 37.491983994841576, 38.67163069546223, 37.61254012584686, 38.05774323642254, 37.15643920004368, 37.84687355160713, 37.7562902122736, 37.77791105210781, 38.05717706680298, 40.15499509871006, 38.8028110563755, 35.75258933007717, 37.41702921688557, 42.66905799508095, 42.26536385715008, 44.34309996664524, 45.12027986347675, 47.299554124474525, 44.45498876273632, 40.231686383485794, 38.7352354824543, 39.067607447505, 37.47007057070732, 36.25192053616047, 36.32071204483509, 37.7743012458086, 37.37257160246372, 36.78051397204399, 37.63302482664585, 39.69340346753597, 38.478171676397324, 36.442012935876846, 38.99473875761032, 37.86236152052879, 37.279130816459656, 36.397532522678375, 36.984931603074074, 37.67082139849663, 36.93019933998585, 37.728487104177475, 39.832700192928314, 38.473319336771965, 39.7126380354166, 38.48974205553532, 41.88551723957062, 45.137671530246735, 44.53280098736286, 44.67831417918205, 41.6242166608572, 44.728129506111145, 38.61534431576729, 34.53000493347645, 36.46855071187019, 37.41523191332817, 36.71370595693588, 37.41583228111267, 37.48637929558754, 36.8615598231554, 38.099757581949234, 36.677117720246315, 38.534872233867645, 35.950190126895905, 35.203283205628395, 33.61638955771923, 35.54781451821327, 32.858227640390396, 35.390153378248215, 35.25084525346756, 35.35619080066681, 36.225891932845116, 37.44972266256809, 42.07900285720825, 43.13217334449291, 45.03514923155308, 44.95337001979351, 42.86491848528385, 44.32466335594654, 44.16230946779251, 46.52226023375988, 46.33109629154205, 48.96164573729038, 52.92905084788799, 51.938858181238174, 49.56034541130066, 52.285372987389565, 53.26720230281353, 52.15429522097111, 38.750332072377205, 38.0170626193285, 43.36727052927017, 54.16548550128937, 55.29807932674885, 59.508990570902824, 35.571365654468536, 3.298299964517355, 0.7126474846154451, 12.643959280103445, 1.0669352486729622, 2.297873734496534, 57.39411145448685, 54.90514241158962, 57.7165811508894, 56.246329843997955, 51.58641189336777, 28.437047079205513, 33.8490928709507, 40.815433859825134, 40.403516963124275, 3.260995941236615, 0.25526350422296673, 0.031222382822306827, 0.04624462810170371, 0.011333275942888577, 0.05064001998107415, 0.11371111002517864, 0.0392891421506647, 0.03616394715209026, 0.04065122062456794, 0.0054193404503166676, 0.03693603677675128, 0.06081402229028754, 0.023990060944925062, 0.02643939689733088, 0.031695939833298326, 0.04740479416796006, 0.009148063854809152, 0.021935861113888677, 0.20896831731079146, 0.1883754855953157, 0.01581184031238081, 10.619180928915739, 67.4020904302597, 49.49251905083656, 35.62925934791565, 24.71127290278673, 43.83902661502361, 58.09384770691395, 66.16739988327026, 59.047919511795044, 58.941244035959244, 54.57992546260357, 44.77729506790638, 0.5284754640888423, 0.34777856490109116, 2.023608726449311, 12.960502244532108, 4.389052335172892, 12.021502330899239, 59.369583651423454, 56.97730042040348, 57.28095732629299, 52.85403907299042, 56.08062453567982, 57.27777309715748, 56.324681639671326, 52.32140265405178, 48.595375791192055, 38.37491221725941, 45.748705342411995, 52.068670615553856, 55.38571022450924, 55.203019827604294, 49.074283093214035, 52.217535227537155, 54.440773129463196, 54.85397435724735, 54.01138857007027, 57.24969260394573, 53.23756769299507, 51.79681420326233, 53.063639625906944, 52.49349921941757, 50.38490876555443, 46.576175540685654, 44.22977104783058, 43.457021713256836, 40.46061649918556, 41.000993102788925, 40.17148241400719, 40.96078746020794, 39.87699821591377, 40.87067149579525, 39.656978622078896, 38.897121995687485, 40.09788416326046, 42.121461778879166, 40.09374998509884, 37.504074946045876, 39.87516671419144, 44.88962464034557, 45.13320676982403, 45.64620204269886, 46.219705268740654, 48.69675055146217, 44.96043764054775, 40.436521992087364, 39.085227102041245, 40.649162381887436, 38.59353348612785, 38.62780004739761, 38.653175085783005, 38.31064246594906, 38.65936495363712, 39.19104762375355, 38.94120343029499, 41.40284813940525, 40.835192799568176, 37.405356243252754, 39.6717332303524, 40.29534436762333, 38.2830673456192, 39.53592471778393, 37.17708349227905, 40.55108204483986, 39.46676082909107, 39.944247007369995, 40.636649653315544, 39.41536858677864, 40.18263481557369, 39.771869257092476, 44.4525720924139, 48.351318687200546, 48.58231969177723, 47.004705145955086, 42.84511014819145, 47.35875874757767, 40.432235822081566, 36.04418188333511, 39.28924195468426, 39.20767553150654, 39.46810595691204, 38.360564187169075, 38.24377745389938, 38.235512897372246, 38.61006259918213, 38.17786619067192, 40.877784714102745, 37.67516076564789, 38.63138325512409, 36.4805618673563, 35.51161766052246, 35.544060319662094, 35.74398659169674, 36.76281452178955, 37.86960393190384, 37.98380680382252, 39.97415520250797, 44.28661599755287, 46.053065210580826, 47.822056487202644, 47.154496908187866, 45.54305277764797, 45.45671381056309, 46.976921036839485, 49.08117212355137, 49.36946265399456, 51.64133794605732, 54.04197692871094, 53.49419832229614, 49.86125886440277, 53.077968657016754, 55.92347636818886, 54.545442312955856, 41.66247680783272, 40.22493414580822, 47.137534618377686, 56.81089594960213, 58.46334367990494, 57.87298075854778, 38.569910153746605, 3.8642945559695363, 0.5528531153686345, 13.735802192240953, 1.5437555126845837, 2.5892732106149197, 61.544955521821976, 61.24159500002861, 64.3171575665474, 62.8241340816021, 59.433424025774, 37.18757472932339, 34.73590448498726, 44.71995234489441, 48.74828718602657, 5.689348261803389, 0.3126332117244601, 0.06376929144607857, 0.10762730249552988, 0.08622455759905279, 0.07514638564316556, 0.18653942708624527, 0.01987490031751804, 0.04258618144376669, 0.035321783943800256, 0.2104690289706923, 0.20617352274712175, 0.1402221983880736, 0.17346364591503516, 0.08503700257278979, 0.14339314308017492, 0.33533396548591554, 0.10097665741341189, 0.14463500847341493, 0.20299588388297707, 0.3151080961106345, 0.15644508646801114, 11.273113489151001, 77.78316378593445, 58.29171448945999, 51.58565953373909, 30.20594336092472, 45.77578268945217, 61.3303392380476, 71.44453391432762, 64.15793091058731, 64.07840877771378, 57.96141341328621, 51.262327283620834, 0.6767416081856936, 1.4862887025810778, 11.241693925112486, 14.138129353523254, 4.914032639935613, 12.874345667660236, 61.78821086883545, 58.02061043679714, 61.37230418622494, 55.14213189482689, 56.96170225739479, 58.43416124582291, 59.0338184684515, 54.76334922015667, 51.31748512387276, 41.64036199450493, 48.50566640496254, 53.66824418306351, 58.50554421544075, 56.866528764367104, 51.761240512132645, 54.68391068279743, 56.88049301505089, 56.80781051516533, 55.51691338419914, 60.30072368681431, 55.03420248627663, 55.0451572984457, 56.22056722640991, 56.00336328148842, 53.69809538125992, 47.45704427361488, 44.90358129143715, 45.048395320773125, 42.532109543681145, 44.12699796259403, 43.80904242396355, 42.881299406290054, 40.60673765838146, 41.27652011811733, 41.19976803660393, 41.474394500255585, 40.9911098331213, 43.38049001991749, 44.306967705488205, 40.64554877579212, 42.31683969497681, 48.197582736611366, 47.60517172515392, 49.47562895715237, 48.35874728858471, 51.54006578028202, 46.27539128065109, 43.13026204705238, 39.97174993157387, 42.726047337055206, 40.508398935198784, 40.89404784142971, 40.60253128409386, 40.202754735946655, 40.78368656337261, 40.33915601670742, 40.794717371463776, 43.07981975376606, 42.41205498576164, 40.837172493338585, 42.20471151173115, 42.155093774199486, 41.33727885782719, 40.01015827059746, 40.05482867360115, 42.34736725687981, 40.09854532778263, 42.3592834174633, 43.128187358379364, 40.34868210554123, 42.725127786397934, 40.46238720417023, 43.52508366107941, 50.98366543650627, 50.51500618457794, 48.8745392113924, 45.04508189857006, 51.40926919877529, 44.27096463739872, 40.02189204096794, 41.51559188961983, 42.3784039914608, 40.59271261096001, 39.88777443766594, 39.86715294420719, 39.744529724121094, 41.53958760201931, 40.65810710191727, 42.04060211777687, 39.42217022180557, 39.53125096857548, 38.76480549573898, 38.69775049388409, 38.07883970439434, 39.0090411901474, 38.881326243281364, 40.6072848290205, 40.12536808848381, 41.070837154984474, 46.63688488304615, 48.226548582315445, 49.423431158065796, 48.879068568348885, 47.57542312145233, 48.762737810611725, 49.78085517883301, 51.117707043886185, 51.53405450284481, 54.57429796457291, 57.40087889134884, 56.16071663796902, 51.924753338098526, 55.729519575834274, 57.98660226166248, 56.972603872418404, 43.391190245747566, 43.51464182138443, 49.325571209192276, 59.31723766028881, 60.71887984871864, 60.31262844800949, 42.29560263454914, 5.846155397593975, 2.858372633345425, 39.54241096973419, 3.56372878421098, 2.8778316266834736, 66.00807443261147, 62.66012728214264, 68.30443561077118, 65.84104299545288, 65.59222474694252, 40.60400180518627, 45.53889200091362, 54.47870649397373, 59.74570646882057, 8.47000390291214, 0.4762421012856066, 0.08659437720780261, 0.15703301585745066, 0.2287756747682579, 0.12117837730329484, 0.350799432490021, 0.16521771729458123, 0.10192486981395632, 0.15120631054742262], [0.06362727406667545, 0.08554363710572943, 0.047975487177609466, 0.04213735279336106, 0.0358811369369505, 0.09897178257233463, 0.007510655086662155, 0.060748776377295144, 0.11039410324883647, 0.05222039377258625, 0.07327999555855058, 0.12666744994930923, 0.23523975134594366, 36.46475471556187, 53.70261333882809, 36.56704522669315, 20.59482078999281, 24.04180582612753, 46.59408017992973, 61.27935357391834, 54.0881634503603, 55.462462306022644, 48.5447359085083, 52.06248454749584, 2.0354823768138885, 0.4530609701760113, 1.4525073277764022, 6.4069112576544285, 0.2053867868380621, 7.437897585332394, 58.1095864623785, 58.471342250704765, 53.130869418382645, 52.06376127898693, 54.347731322050095, 55.90744502842426, 53.25024761259556, 48.937646225094795, 39.80043612420559, 38.207196816802025, 46.269057020545006, 51.22735396027565, 53.34968067705631, 49.34155695140362, 52.429343461990356, 54.96022805571556, 50.993598103523254, 51.32047176361084, 52.74521291255951, 52.2079711407423, 53.37647683918476, 51.590036898851395, 51.18821606040001, 49.739520996809006, 49.905826672911644, 47.36805684864521, 45.55892452597618, 43.410637602210045, 40.31960606575012, 37.203883454203606, 38.478924036026, 38.89299921691418, 37.3021499812603, 39.23249959945679, 37.1460847556591, 36.84708259999752, 38.50676894187927, 39.35564339160919, 38.773913607001305, 36.625588685274124, 38.57071191072464, 42.13825687766075, 41.12569861114025, 41.904706209897995, 43.44974510371685, 43.84648181498051, 45.889913365244865, 43.03795740008354, 40.28330281376839, 38.62366586923599, 37.678861767053604, 36.68502889573574, 36.91813878715038, 37.57996827363968, 38.08765523135662, 37.68701232969761, 37.7550932765007, 39.724086821079254, 39.02365520596504, 37.06674501299858, 38.877613842487335, 38.87720346450806, 37.30981037020683, 36.673268526792526, 35.83634063601494, 36.55549004673958, 37.01383285224438, 37.63141751289368, 38.6248742043972, 39.81510333716869, 39.93531748652458, 37.76310324668884, 40.19854076206684, 44.33695189654827, 42.475256994366646, 43.267081305384636, 39.903969168663025, 43.163977637887, 36.60626672208309, 33.67494061589241, 33.90949442982674, 36.12959749996662, 38.00442449748516, 37.29985110461712, 38.74496676027775, 35.71071557700634, 37.00514271855354, 36.95341229438782, 35.926908776164055, 37.2127103805542, 36.38346567749977, 35.30403099954128, 36.20086267590523, 35.060171484947205, 36.40840753912926, 35.380798280239105, 35.973976850509644, 36.780817955732346, 37.88544908165932, 41.181217432022095, 43.555778414011, 43.24929066002369, 43.573652654886246, 43.4915504604578, 41.06506526470184, 44.27571438252926, 42.56349205970764, 44.90270733833313, 45.96499353647232, 51.304440423846245, 51.3086923956871, 47.25747138261795, 49.09510597586632, 54.70046639442444, 54.26596350967884, 45.996623039245605, 36.88793420791626, 43.93961101770401, 54.80645790696144, 55.69342151284218, 55.55209569633007, 39.95110563933849, 6.824994273483753, 0.20303845347370952, 3.771462212316692, 0.8502049720846117, 7.020048256963491, 60.05574703216553, 54.35604527592659, 56.874531134963036, 57.970396131277084, 42.983320131897926, 21.595696583390236, 29.529353566467762, 45.169392228126526, 33.08863207697868, 0.774746899260208, 0.24497264705132693, 0.05525333239347674, 0.06883209673105739, 0.04157321294769645, 0.03886541293468326, 0.024044657038757578, 0.06005519113386981, 0.05306473518430721, 0.028302226528467145, 0.03022110500751296, 0.0208150511389249, 0.07198194216471165, 0.037562056895694695, 0.04732290930405725, 0.12611781537998468, 0.014088919433561387, 0.03126634765067138, 0.08592682279413566, 0.11115755798527971, 0.11964570876443759, 0.13377682393183932, 0.8166279550641775, 48.31854164600372, 61.29480354487896, 41.27384126186371, 21.334709487855434, 34.62741270661354, 52.67650879919529, 66.3806140422821, 58.36533173918724, 60.926607102155685, 53.713948130607605, 55.72221256792545, 1.9177224207669497, 0.35528247943148017, 2.51463167835027, 9.804825726896524, 0.17359212652081624, 7.771144928410649, 58.67458574473858, 58.42263266444206, 56.073822900652885, 54.43825766444206, 56.30148768424988, 57.332410365343094, 55.43025903403759, 51.08081862330437, 43.26239615678787, 40.19529193639755, 46.965240463614464, 54.05199319124222, 55.4740858823061, 52.172344252467155, 52.94960014522076, 56.549591571092606, 53.108652010560036, 53.855961710214615, 53.28776679933071, 54.16005939245224, 53.589060232043266, 52.42768295109272, 53.110692501068115, 51.80603250861168, 50.90686395764351, 49.50669229030609, 48.30594152212143, 46.467254385352135, 42.40963451564312, 40.27967780828476, 41.27558916807175, 40.96590578556061, 39.7188089042902, 40.90813368558884, 38.760443329811096, 38.31967078149319, 40.33244177699089, 41.356870606541634, 39.740277752280235, 38.21839861571789, 40.11071987450123, 44.65388149023056, 42.413506507873535, 44.968474209308624, 45.48533767461777, 46.18495233356953, 47.76442877948284, 43.60910855233669, 42.7058020234108, 40.85468575358391, 37.62172043323517, 38.8064094632864, 38.43013845384121, 39.0416244417429, 39.57396447658539, 38.62129859626293, 40.868627205491066, 39.86474387347698, 40.25219768285751, 40.28814375400543, 39.933288395404816, 41.82428352534771, 38.64617586135864, 38.18760506808758, 37.386243268847466, 38.50930340588093, 41.804710775613785, 39.281676560640335, 39.661785364151, 41.77645169198513, 41.665037870407104, 39.60498981177807, 39.82225835323334, 45.51859349012375, 45.50614535808563, 44.6914728730917, 43.244974091649055, 45.939907282590866, 41.32981225848198, 36.61888584494591, 37.71854303777218, 37.426768094301224, 39.95667614042759, 37.90148802101612, 39.93935286998749, 37.466240376234055, 38.80491994321346, 38.934800773859024, 38.279837518930435, 39.7972746938467, 38.87317568063736, 36.70078665018082, 38.734597116708755, 37.53552965819836, 38.6107237637043, 37.28652521967888, 38.48488591611385, 38.66701774299145, 40.90648457407951, 42.178819701075554, 44.42001923918724, 44.537151753902435, 45.84755323827267, 46.17722734808922, 42.4981963634491, 46.26809187233448, 43.77439968287945, 47.56549045443535, 49.5686137676239, 53.37624505162239, 54.094797894358635, 50.52107445895672, 50.35715125501156, 56.86851605772972, 57.538644298911095, 48.64856913685799, 38.48658062517643, 47.195477709174156, 55.7364846020937, 60.07068783044815, 57.05831587314606, 42.97792822122574, 7.922665597870946, 0.4674266040092334, 9.971326142549515, 0.7985861075576395, 6.559595614671707, 65.499167740345, 59.40580330789089, 63.43669921159744, 61.432542353868484, 53.313685208559036, 26.675965078175068, 31.41010444611311, 51.43140681087971, 40.40162466466427, 1.4826943329535425, 0.2723370271269232, 0.047413299180334434, 0.05502386033185758, 0.04103102211956866, 0.04393435949168634, 0.01972581954760244, 0.05407612661656458, 0.045315269962884486, 0.03847745894745458, 0.14194605901138857, 0.15319311409257352, 0.13059617194812745, 0.08588264274294488, 0.11936731432797387, 0.24669233680469915, 0.09045856204465963, 0.10784967220388353, 0.21939829748589545, 0.24611144297523424, 0.27786623511929065, 0.2796856249915436, 0.7681597152259201, 51.17112077772617, 71.70568630099297, 49.882264137268066, 27.0247882604599, 37.502384036779404, 57.1931554377079, 70.50474554300308, 65.21960154175758, 66.39101028442383, 57.22621366381645, 62.13747672736645, 2.949978830292821, 1.2106180074624717, 8.642202112823725, 12.08223732188344, 0.36178292124532163, 9.250250235199928, 61.902470737695694, 60.442630872130394, 59.25708308815956, 56.9002291560173, 57.144761234521866, 58.67304302752018, 59.051229134202, 52.79606178402901, 45.50216697156429, 42.26802371442318, 50.411119759082794, 55.646684020757675, 57.97943204641342, 51.76059074699879, 54.47119429707527, 58.89054335653782, 55.46997830271721, 54.6184515953064, 55.91495342552662, 55.07716678082943, 55.8266993612051, 54.545210525393486, 56.65212906897068, 52.81932793557644, 54.03111331164837, 51.97931461036205, 50.38992829620838, 47.299827709794044, 45.768369287252426, 41.05630673468113, 43.85571911931038, 42.59751923382282, 42.79147982597351, 43.38697627186775, 41.533314138650894, 39.74724277853966, 42.30581648647785, 42.92706415057182, 43.58815647661686, 41.37207359075546, 44.03782434761524, 47.09347978234291, 46.17279678583145, 45.881132036447525, 47.56874307990074, 46.40947088599205, 48.650206848978996, 43.743799924850464, 43.443832620978355, 41.856384202837944, 41.52884557843208, 40.24549104273319, 39.483422935009, 40.013312101364136, 42.577722296118736, 40.593662559986115, 42.86737695336342, 43.5915344953537, 43.39617557823658, 40.188991874456406, 42.69127540290356, 43.068469762802124, 42.44951717555523, 39.266720563173294, 39.30118091404438, 40.01322090625763, 44.224664121866226, 40.544595792889595, 41.20127275586128, 43.61076146364212, 42.12732866406441, 41.44308418035507, 41.73919089138508, 46.65369898080826, 47.82179810106754, 47.754853293299675, 45.62285229563713, 47.88034535944462, 42.477460876107216, 39.243671000003815, 39.917424246668816, 38.74262608587742, 43.07905599474907, 40.49026630818844, 43.2606216520071, 39.43907551467419, 40.839668959379196, 41.31077527999878, 40.83222135901451, 41.66401572525501, 40.515930131077766, 38.516606613993645, 41.53502404689789, 38.941549211740494, 40.86597874760628, 39.94201272726059, 41.4097485691309, 41.55760243535042, 42.745726481080055, 44.402581974864006, 48.545484468340874, 46.96412332355976, 47.87137784063816, 49.14646402001381, 44.840352684259415, 48.055903539061546, 46.95973835885525, 50.51169656217098, 52.34126418828964, 56.176151409745216, 55.46674847602844, 51.59950599074364, 54.173328280448914, 59.75174434483051, 60.09786397218704, 51.035137474536896, 40.8870068192482, 48.67221526801586, 60.00982269644737, 61.101257130503654, 58.801153153181076, 46.59110113978386, 9.551391676068306, 0.7809774961788207, 19.022463262081146, 2.1985002793371677, 8.452318701893091, 70.99461525678635, 63.999517410993576, 67.98415079712868, 66.4870311319828, 56.519440189003944, 29.487322121858597, 39.48195621371269, 58.90919275581837, 49.073914512991905, 2.5854012183845043, 0.5011216818820685, 0.10635907601681538, 0.20796076278202236, 0.23577687330543995, 0.20922541210893542, 0.21009890508139506, 0.2483958180528134, 0.1282876028562896, 0.10209243191638961], [0.07615413313033059, 0.05328106381057296, 0.027641460910672322, 0.05707665935915429, 0.1034319491009228, 0.056128480355255306, 0.06223837066499982, 0.10058715604827739, 0.07723260729108006, 0.06262101829634048, 0.07148504460928962, 0.27781606593634933, 0.10784179801703431, 10.65748667344451, 53.957792446017265, 44.445800855755806, 33.64132761955261, 24.930593334138393, 46.05869270861149, 65.20338401198387, 54.679172337055206, 54.85861010849476, 46.629376485943794, 57.13934272527695, 10.748591534793377, 0.6632031127810478, 0.6123189150821418, 11.517349183559418, 0.3407124284422025, 7.464486183598638, 52.231830060482025, 58.31278055906296, 47.42043323814869, 40.706907883286476, 58.10697600245476, 51.74897097051144, 54.559949934482574, 46.19463421404362, 43.15187148749828, 43.68633180856705, 50.43266840279102, 51.19921267032623, 51.96832939982414, 51.481355130672455, 52.81381443142891, 48.85573402047157, 50.822181701660156, 49.5172443240881, 50.15689060091972, 48.36803399026394, 51.12597540020943, 52.00469344854355, 52.67223782837391, 48.584185391664505, 48.168476298451424, 46.44270770251751, 48.487423583865166, 42.99216605722904, 40.5047245323658, 36.76190257072449, 39.18194331228733, 38.40481661260128, 39.215339720249176, 37.972331419587135, 38.29942926764488, 37.10807539522648, 38.56212817132473, 40.76400361955166, 36.73153840005398, 33.807637095451355, 41.43028266727924, 43.855517730116844, 41.222300827503204, 41.66551664471626, 45.525930896401405, 43.37197847664356, 44.968911185860634, 42.37851418554783, 37.08596058189869, 36.51886001229286, 37.74521380662918, 37.010967805981636, 35.08079297840595, 37.813279554247856, 36.74421451985836, 37.70824559032917, 37.83620372414589, 39.361160695552826, 37.54665546119213, 36.48298613727093, 37.64059782028198, 37.973995730280876, 35.506449937820435, 36.62379518151283, 35.673675164580345, 37.130668982863426, 35.907092839479446, 36.57133899629116, 37.31550246477127, 37.41993986070156, 39.463428407907486, 40.253759399056435, 40.708082020282745, 45.68206071853638, 43.302522003650665, 44.37344133853912, 38.89841012656689, 41.548980697989464, 38.16439591348171, 33.529492020606995, 33.59383776783943, 37.609781473875046, 39.19262833893299, 38.19760613143444, 37.10269868373871, 37.17228814959526, 38.035085052251816, 37.92869456112385, 35.44083125889301, 36.16118140518665, 35.913438498973846, 35.27417980134487, 35.61258964240551, 35.07574684917927, 36.012711971998215, 35.23132190108299, 36.94185331463814, 34.871492609381676, 37.09622003138065, 37.94891707599163, 40.189067870378494, 41.504751071333885, 40.9949666261673, 40.0339449942112, 39.00464102625847, 38.95120069384575, 39.25845980644226, 39.98205117881298, 45.971616581082344, 48.96977350115776, 53.32816243171692, 49.86846707761288, 48.28597739338875, 54.191947281360626, 52.612147852778435, 50.786892995238304, 39.654953330755234, 43.55180382728577, 51.193117797374725, 58.60541045665741, 54.14574936032295, 30.483387373387814, 3.2359460229054093, 1.3571808929555118, 4.489211635664105, 1.0976087464950979, 9.644817262887955, 57.47098132967949, 55.50123542547226, 53.77265118062496, 49.59334284067154, 39.583437368273735, 26.706078462302685, 28.951472975313663, 46.12577810883522, 18.778257966041565, 0.5866901215631515, 0.03315612280857749, 0.040770895648165606, 0.0290637516809511, 0.03591585460526403, 0.06998497861786745, 0.09733487197081558, 0.05984572366287466, 0.07311282679438591, 0.0744630086410325, 0.019993142996099778, 0.08906332441256382, 0.041114053601631895, 0.01853687113907654, 0.07297408228623681, 0.06456420582253486, 0.0704889117332641, 0.15645648585632443, 0.07328133142436855, 0.08754376962315291, 0.03207053516234737, 0.33811001339927316, 0.19878090068232268, 16.873693764209747, 62.444036677479744, 48.37556138634682, 24.628885723650455, 33.66581350564957, 54.33051824569702, 69.32511404156685, 59.30495671927929, 59.35125723481178, 52.43020221590996, 63.748993054032326, 10.6318380497396, 0.6892868725117296, 1.4435040671378374, 9.125539027154446, 0.3086334513500333, 8.593201842159033, 54.41417075693607, 59.915625751018524, 49.81213890016079, 43.29923138022423, 60.01618355512619, 53.423370122909546, 56.03351466357708, 47.7488724142313, 44.874414056539536, 43.41583572328091, 54.82221566140652, 51.23161353170872, 54.139054119586945, 53.63989010453224, 54.54710282385349, 51.33645750582218, 52.91412904858589, 50.83326570689678, 52.81375363469124, 49.917017072439194, 52.74475693702698, 53.497561141848564, 56.30568265914917, 51.05686470866203, 50.87540544569492, 49.16726030409336, 50.49020491540432, 44.700045213103294, 42.20210865139961, 38.99991787970066, 41.40825144946575, 39.273803383111954, 40.759310871362686, 41.378438249230385, 40.7438039034605, 37.57626727223396, 40.13414181768894, 40.31983025372028, 38.67994084954262, 37.29051120579243, 43.50532092154026, 44.84654255211353, 42.621359154582024, 44.415315091609955, 46.274536326527596, 46.10287293791771, 46.58917084336281, 43.97744558751583, 39.59220349788666, 39.551013708114624, 40.00354282557964, 39.52959805727005, 37.00154431164265, 38.698366060853004, 40.24968221783638, 39.72825139760971, 41.18460305035114, 39.971301555633545, 40.0402944535017, 39.92323413491249, 38.45793396234512, 40.75095511972904, 37.13256128132343, 39.22995753586292, 37.851722091436386, 39.77818451821804, 37.21666976809502, 37.59308136999607, 38.15601356327534, 38.6633775383234, 40.30975699424744, 41.391137167811394, 42.392926812171936, 46.61773771047592, 45.02665288746357, 45.20248845219612, 40.708879977464676, 42.75083340704441, 41.53035409748554, 37.33244575560093, 36.05495050549507, 39.61718715727329, 40.965867787599564, 39.57880921661854, 38.55845756828785, 39.29117225110531, 38.89431394636631, 39.78748261928558, 37.43421569466591, 38.201041147112846, 37.65412889420986, 36.092906668782234, 38.71790461242199, 36.67984217405319, 38.59437704086304, 38.20836715400219, 38.40694449841976, 37.97174625098705, 39.95027728378773, 40.88862173259258, 41.3814552873373, 43.39382350444794, 42.92345054447651, 43.73092621564865, 40.58115363121033, 40.428975597023964, 41.597097516059875, 44.55579735338688, 47.79120214283466, 51.659409776329994, 56.38377606868744, 50.94737358391285, 49.804261922836304, 56.69266529381275, 55.44757090508938, 51.679613292217255, 41.071574315428734, 46.60240173339844, 52.85786546766758, 62.43402421474457, 53.62204626202583, 33.9781491458416, 3.3661593357101083, 1.7682190868072212, 6.449522171169519, 1.3053720979951322, 10.30358886346221, 64.0757717192173, 58.20855975151062, 62.141933888196945, 57.24252238869667, 52.009902969002724, 25.36650024354458, 29.905273094773293, 54.69914026558399, 26.20040539652109, 0.37704299145843834, 0.024561841200920753, 0.03913359541911632, 0.05846037885930855, 0.054364380484912544, 0.01903589494759217, 0.11214014666620642, 0.037544371516560204, 0.03638966394646559, 0.028485908078437205, 0.1683289636275731, 0.19071047514444217, 0.11074532463680953, 0.0709402043139562, 0.28551436378620565, 0.13881875260267407, 0.18102709553204477, 0.22311387467198074, 0.20371502498164773, 0.2097563148709014, 0.12621285481145605, 0.5670949292834848, 0.24588158499682322, 17.703991010785103, 71.29803657531738, 58.45657244324684, 42.08714202046394, 38.10102291405201, 58.2844340801239, 74.15011033415794, 62.38656096160412, 65.87460279464722, 56.907372772693634, 69.24640506505966, 13.337146583944559, 1.2561918119899929, 4.50993999838829, 23.997608497738838, 0.7527060038410127, 9.899160414934158, 54.56043630838394, 61.40049487352371, 50.63657306134701, 44.464013278484344, 61.05745308101177, 55.32552145421505, 60.76443940401077, 49.86716374754906, 49.75509636104107, 47.88602605462074, 58.18185858428478, 55.08678026497364, 56.65863052010536, 55.44346712529659, 57.21573382616043, 54.24280755221844, 56.27866230905056, 54.36332568526268, 55.746808648109436, 51.84350609779358, 56.62846773862839, 55.49325205385685, 59.02750700712204, 51.595884785056114, 52.822162583470345, 51.33746825158596, 54.39411923289299, 46.15444757044315, 45.75665071606636, 39.833771735429764, 43.778856843709946, 42.18851678073406, 42.3293524235487, 43.659463450312614, 44.033067002892494, 40.93724772334099, 42.44384787976742, 43.867129907011986, 40.18662080168724, 39.422747790813446, 47.58846402168274, 48.210984617471695, 45.98040170967579, 45.87697505950928, 49.44956235587597, 46.51420086622238, 49.28526297211647, 45.73355175554752, 41.05315290391445, 41.03364855051041, 42.64445051550865, 40.404554307460785, 39.01314876973629, 43.41035641729832, 41.852295622229576, 40.262164548039436, 42.13561601936817, 42.50789724290371, 41.29903770983219, 41.92775957286358, 41.210278272628784, 41.320825740695, 39.42730374634266, 41.445497050881386, 40.26838481426239, 42.80632182955742, 38.38689677417278, 38.50908301770687, 40.67987613379955, 40.59705577790737, 40.916508436203, 42.695637568831444, 44.15839567780495, 48.58697824180126, 46.64158523082733, 47.944185733795166, 42.916124537587166, 46.008789986371994, 43.123608604073524, 37.023564130067825, 38.14709924161434, 41.7850012332201, 43.95979933440685, 42.61689819395542, 39.81660045683384, 41.54946327209473, 41.395529732108116, 44.08825904130936, 39.07482326030731, 39.03235673904419, 40.639719888567924, 38.537554889917374, 40.30947960913181, 39.497797563672066, 42.28598915040493, 39.92021709680557, 42.116848826408386, 38.961418345570564, 41.3102813065052, 43.533219024538994, 43.630007430911064, 46.962584406137466, 45.73598362505436, 44.58912916481495, 42.47421585023403, 43.52236680686474, 44.74681690335274, 44.735204726457596, 50.44065177440643, 54.76647265255451, 59.34236951172352, 54.22877490520477, 49.946507290005684, 57.3314718157053, 58.668304681777954, 54.59672436118126, 44.22246403992176, 48.73739697039127, 55.62580794095993, 64.74468782544136, 57.17978395521641, 37.772169560194016, 5.309461746364832, 2.18760650139302, 15.292769595980644, 3.671677429229021, 12.688623033463955, 69.37627449631691, 65.1131084561348, 63.43900568783283, 61.92976087331772, 53.130827620625496, 35.17426796257496, 38.82866866886616, 63.91880214214325, 35.25320492684841, 0.6281143112573773, 0.192566096666269, 0.08441043697530404, 0.19333684671437368, 0.17943802376976237, 0.13600345992017537, 0.2983181626768783, 0.16792701644590124, 0.1712293509626761, 0.09437386601348408], [0.02694583476113621, 0.06273533130297437, 0.06365358320181258, 0.0630455267673824, 0.040217234927695245, 0.11402856369386427, 0.06012014389852993, 0.10631304801790975, 0.05530319729587063, 0.03300686206785031, 0.00969396820437396, 0.022787451453041285, 0.17639438709011301, 2.0219555776566267, 42.06451043486595, 50.503405407071114, 39.718341529369354, 27.012537717819214, 31.386538110673428, 55.3042957931757, 59.17180806398392, 60.854498371481895, 47.70433120429516, 54.649894908070564, 21.78237486630678, 0.2271576740895398, 0.8282786048948765, 5.878242300823331, 0.9805325756315142, 3.4610732551664114, 47.34860569238663, 59.67713914811611, 53.70398886501789, 41.25448130071163, 53.3186249434948, 52.986556962132454, 53.78670662641525, 47.84188002347946, 47.12843410670757, 48.66360493004322, 53.9410999417305, 51.03343516588211, 50.82245148718357, 52.04492188990116, 51.35645963251591, 48.66955541074276, 48.162723407149315, 45.73622681200504, 47.40975581109524, 46.065061166882515, 48.80222149193287, 47.23060682415962, 49.21012960374355, 47.63724200427532, 50.35114757716656, 48.51401075720787, 47.660542353987694, 43.365720212459564, 40.93030549585819, 37.45105639100075, 38.639343827962875, 37.97385893762112, 38.73344957828522, 37.836302518844604, 37.83159837126732, 36.046936735510826, 37.833764255046844, 39.74887289106846, 36.391091868281364, 36.93177245557308, 40.171455815434456, 43.333950117230415, 39.95487883687019, 44.58853259682655, 43.9700435847044, 42.82744489610195, 42.47347868978977, 41.02452903985977, 37.91594244539738, 36.92299872636795, 37.04843379557133, 38.21051023900509, 37.47087612748146, 37.73661486804485, 37.40295857191086, 38.59746627509594, 38.515037298202515, 40.63341982662678, 38.109876438975334, 40.369542986154556, 37.8029441088438, 37.465598210692406, 38.156697526574135, 37.02419489622116, 36.76033705472946, 34.98249605298042, 36.142900586128235, 36.27704858779907, 36.23524323105812, 38.35281640291214, 38.43914397060871, 38.83537910878658, 41.2404752522707, 44.62716892361641, 43.722312077879906, 44.468576833605766, 40.0919146835804, 40.3543172031641, 40.78491389751434, 33.81456032395363, 34.98593866825104, 36.26795947551727, 39.19775806367397, 36.31709843873978, 37.27150082588196, 35.807481184601784, 35.20912729203701, 36.75717182457447, 34.961916357278824, 35.98470367491245, 36.95438124239445, 33.12390558421612, 34.85133849084377, 34.01468798518181, 35.7215715944767, 35.15813022851944, 35.33824436366558, 36.18381679058075, 36.188752725720406, 34.83350224792957, 37.310532331466675, 36.17122806608677, 37.918621301651, 35.86085692048073, 36.48789927363396, 37.92549133300781, 38.41343455016613, 39.46542330086231, 45.479265600442886, 48.372874930500984, 51.26959629356861, 54.25935186445713, 48.90239551663399, 50.097404792904854, 54.374751672148705, 51.20901994407177, 44.25814412534237, 42.361213713884354, 51.53427869081497, 54.94880586862564, 53.70463863015175, 11.867301855236292, 0.9920597320888191, 4.278478268533945, 4.364598747342825, 0.9689740708563477, 13.267730958759785, 61.30693629384041, 55.13801671564579, 43.603123873472214, 47.266891077160835, 30.484930090606213, 28.57005324214697, 37.25736938416958, 42.3270383477211, 9.923455361276865, 0.22241774015128613, 0.018330669117858633, 0.07601376331876963, 0.08288402474136092, 0.07884956154157408, 0.0413592517725192, 0.06555593034136109, 0.026032905916508753, 0.08093853655736893, 0.003540111674738, 0.012232270037202397, 0.07123730829334818, 0.09340428718132898, 0.0365616492490517, 0.04657178906199988, 0.0557053411466768, 0.038050634975661524, 0.09158693821518682, 0.021883484041609336, 0.020150333584751934, 0.03742518259969074, 0.06849291297839954, 0.061917996645206586, 3.162972363643348, 49.55310679972172, 56.81962788105011, 37.165672704577446, 31.38920746743679, 45.296818390488625, 60.594672113657, 64.17191416025162, 63.51501680910587, 52.83521108329296, 60.832151770591736, 23.699594289064407, 0.18541830911999568, 1.3513104454614222, 7.454766305163503, 1.2914775498211384, 3.8435063464567065, 51.3497643917799, 58.2324642688036, 56.52342617511749, 43.34046296775341, 53.67566138505936, 53.37679602205753, 55.62513157725334, 50.848977863788605, 49.77550886571407, 51.333227679133415, 54.99947614967823, 52.23418973386288, 52.95167103409767, 53.748085498809814, 54.32362541556358, 49.909702464938164, 50.21861828863621, 49.61032412946224, 50.74714332818985, 47.38284945487976, 50.872380807995796, 49.08875271677971, 50.010951831936836, 50.50538890063763, 51.148405596613884, 49.99503068625927, 50.82247048616409, 44.38507251441479, 43.05672079324722, 39.77646321058273, 41.31907783448696, 38.69317553937435, 39.96717877686024, 39.11956585943699, 39.071525037288666, 39.17703777551651, 40.48205494880676, 41.986299231648445, 37.40730933845043, 38.83647724986076, 41.97112284600735, 46.74310818314552, 41.83248348534107, 44.62293215095997, 46.09485536813736, 45.43367564678192, 44.70095336437225, 42.28942036628723, 41.55745804309845, 38.39418478310108, 38.481500297784805, 39.295010045170784, 39.22441363334656, 39.050781950354576, 38.88450287282467, 39.6789376437664, 39.486143589019775, 41.63221903145313, 39.775452464818954, 41.072862446308136, 40.68776451051235, 39.129741713404655, 39.98457044363022, 38.90224412083626, 38.78173738718033, 36.892638355493546, 38.38601142168045, 38.555683717131615, 37.12062992155552, 39.75544273853302, 39.82655972242355, 40.33498764038086, 44.319719821214676, 44.84099105000496, 45.161975026130676, 45.01680001616478, 42.211148366332054, 42.51818709075451, 44.174164831638336, 35.54841108620167, 36.49892248213291, 38.61417777836323, 39.78402100503445, 38.570768907666206, 37.65689134597778, 38.97311791777611, 38.072627037763596, 38.10115970671177, 37.417876571416855, 38.77413019537926, 38.847325667738914, 36.19239293038845, 38.21880139410496, 36.31981909275055, 36.83114245533943, 37.13583290576935, 36.469933837652206, 38.39314363896847, 38.65579314529896, 38.1530687212944, 38.390054404735565, 38.14207971096039, 39.8308040946722, 38.66284176707268, 39.51452426612377, 39.53510396182537, 40.807587280869484, 40.903030559420586, 46.269854977726936, 49.18656326830387, 53.027537763118744, 56.864541471004486, 48.683683052659035, 52.74783097207546, 56.4316762983799, 53.41390863060951, 46.34591929614544, 44.327000230550766, 55.96685864031315, 57.03539930284023, 55.08836857974529, 16.102815829217434, 1.3925750437192619, 7.664249539375305, 5.396541673690081, 0.7704370992723852, 15.539757292717695, 65.43503478169441, 59.20191004872322, 49.11872550845146, 51.602032855153084, 40.04854001104832, 28.079315274953842, 37.78014153242111, 49.13442626595497, 14.013466592878103, 0.34151038562413305, 0.11057002193410881, 0.02616649064293597, 0.05429612516309135, 0.08822094969218597, 0.08139507612213492, 0.03257944066717755, 0.029335127255762927, 0.11393868218874559, 0.053023920772830024, 0.14604817639337853, 0.13759340741671622, 0.17398832947947085, 0.13108551444020122, 0.19892466953024268, 0.15268227900378406, 0.2137046740972437, 0.18611297418829054, 0.1256483476026915, 0.14452153409365565, 0.234969268203713, 0.18100233748555183, 0.2356146991951391, 3.6410351609811187, 56.893739104270935, 65.80391138792038, 50.074313431978226, 37.66197927296162, 44.1308319568634, 63.603172078728676, 65.78799784183502, 69.61556285619736, 56.990500912070274, 71.0412235558033, 28.898353725671768, 0.30424168857280165, 3.8762648636475205, 14.591643568128347, 2.5482743605971336, 6.1881878692656755, 51.643101051449776, 58.29692400991917, 55.19494906067848, 42.57340952754021, 56.23404510319233, 54.12677317857742, 58.76817852258682, 52.83397234976292, 50.79054459929466, 54.64532755315304, 59.62209530174732, 54.33752506971359, 55.09704351425171, 56.10986016690731, 58.20847235620022, 53.90948943793774, 53.100873827934265, 50.80974496901035, 52.32052110135555, 50.28465114533901, 52.623862624168396, 51.71163037419319, 52.633947283029556, 52.95457787811756, 54.713294506073, 54.129596427083015, 54.7461361438036, 48.0554361641407, 46.42398230731487, 41.761431097984314, 43.97496812045574, 39.751133769750595, 41.87031425535679, 41.70105613768101, 41.46236814558506, 40.67750126123428, 41.142079532146454, 45.02115838229656, 39.769065007567406, 42.80432313680649, 45.20498491823673, 47.05532222986221, 44.83538255095482, 47.442441657185555, 47.946773394942284, 46.58991180360317, 47.206367924809456, 44.18497525155544, 42.750666216015816, 40.6912375241518, 41.23791418969631, 40.22959649562836, 41.43313251435757, 42.20828332006931, 41.37551240622997, 42.85194978117943, 42.78886556625366, 44.28054392337799, 42.378544583916664, 44.81428988277912, 42.29527585208416, 42.20188446342945, 41.69064849615097, 42.356653958559036, 41.05131380259991, 38.65482419729233, 41.65964595973492, 41.117589846253395, 39.53441999852657, 42.743932977318764, 42.05409899353981, 41.67223088443279, 46.11299179494381, 48.21242853999138, 47.6620052754879, 47.53367476165295, 43.748192489147186, 46.18742600083351, 46.48430787026882, 39.375102147459984, 38.369075730443, 39.20674838125706, 41.5419814735651, 39.83840748667717, 40.026106014847755, 40.06493993103504, 39.902529045939445, 40.7834167778492, 38.787136897444725, 41.598074063658714, 41.51048116385937, 38.573854342103004, 41.436586529016495, 37.762958854436874, 39.35842104256153, 39.219557493925095, 39.67665396630764, 41.54084153473377, 41.907483860850334, 39.11970645189285, 40.50997205078602, 39.59650106728077, 42.30040177702904, 40.899496749043465, 42.083695605397224, 41.90960794687271, 43.11409771442413, 44.15967620909214, 48.45679722726345, 51.05119161307812, 56.86970539391041, 59.41451244056225, 50.44892393052578, 52.56869338452816, 58.01765039563179, 56.5079116076231, 48.22664737701416, 47.025919407606125, 56.80474787950516, 59.90123972296715, 58.182675540447235, 20.869718939065933, 1.8426378560252488, 10.915360786020756, 13.576159458607435, 1.8022882961668074, 17.344638593494892, 69.25598815083504, 64.31996181607246, 54.31308098137379, 59.486104398965836, 41.33220613002777, 37.421057000756264, 48.19085709750652, 57.702525705099106, 17.832900993525982, 0.409661183366552, 0.3140928677748889, 0.13376754708588123, 0.12685463443631306, 0.2263252664124593, 0.17566295602591708, 0.14743026316864416, 0.17619038553675637, 0.32577682519331574, 0.22648843500064686], [0.025708789617056027, 0.02904873061197577, 0.02832204001606442, 0.010476062907400774, 0.0296504249854479, 0.021397024793259334, 0.004662490364353289, 0.015847825197852217, 0.0457633935729973, 0.03545935214788187, 0.012357931409496814, 0.027527912316145375, 0.10059466658276506, 0.07019250537268817, 26.63214012980461, 54.538538083434105, 31.5817279368639, 25.954701080918312, 31.27304010093212, 52.82806746661663, 54.23090659081936, 54.430053904652596, 49.709164425730705, 51.64956830441952, 42.21964851021767, 0.48635392275173217, 1.5122351353056729, 4.152531176805496, 5.024541635066271, 1.7582257417961955, 44.180054515600204, 47.820179387927055, 57.722546830773354, 43.94831635057926, 52.90566310286522, 54.59072068333626, 53.9841478317976, 52.422112450003624, 50.242625400424004, 52.02584311366081, 54.65649515390396, 52.342518121004105, 51.785517409443855, 52.03713230788708, 50.84124907851219, 45.59900477528572, 45.01965366303921, 44.98288303613663, 44.826863408088684, 46.773886531591415, 47.144248858094215, 46.31487496197224, 46.731902584433556, 46.726396679878235, 46.78970508277416, 45.37116900086403, 44.744936004281044, 42.49379999935627, 36.509953290224075, 37.57533632218838, 38.41359034180641, 38.354252725839615, 39.62334282696247, 38.791271075606346, 36.99830688536167, 35.942696928977966, 38.382131829857826, 36.903973147273064, 36.017153933644295, 35.32442830502987, 44.40229319036007, 43.776721358299255, 41.71292670071125, 41.412146240472794, 41.51041276752949, 42.58061394095421, 39.993271976709366, 39.05304282903671, 39.03346627950668, 36.84498891234398, 36.469443663954735, 37.122100442647934, 36.89968317747116, 36.16569936275482, 36.06688566505909, 39.98487062752247, 39.295139238238335, 42.20805913209915, 38.83415937423706, 40.177835673093796, 34.02962878346443, 38.97009328007698, 38.188562616705894, 37.57660545408726, 36.73900879919529, 37.36287832260132, 36.254747584462166, 36.85794621706009, 36.927471086382866, 36.30694158375263, 36.43195867538452, 39.02192249894142, 39.950231686234474, 41.62890560925007, 40.21723195910454, 42.012977600097656, 40.43381653726101, 39.18195091187954, 41.6451383382082, 36.56083635985851, 34.43820185959339, 37.75198504328728, 37.35631227493286, 35.69297052919865, 36.29857823252678, 37.04114958643913, 36.70121982693672, 35.34155398607254, 35.1659844070673, 34.99720126390457, 37.25340999662876, 35.06202198565006, 34.48653146624565, 35.36863133311272, 35.678014531731606, 35.56183576583862, 36.168951988220215, 36.027641370892525, 35.11836916208267, 34.44037154316902, 35.9926338493824, 34.831807538867, 35.911078825592995, 35.760207921266556, 37.23438821732998, 35.01157969236374, 35.64080312848091, 39.070153310894966, 38.30965831875801, 44.673898816108704, 47.78674118220806, 51.475233659148216, 51.26339502632618, 52.127951234579086, 54.78036090731621, 51.312860772013664, 50.29122859239578, 43.876519203186035, 53.14042590558529, 53.21096532046795, 52.39056274294853, 5.580747239291668, 4.7306834533810616, 10.469638053327799, 3.147109877318144, 0.0550676989951171, 11.005473900586367, 55.90748682618141, 53.07016007602215, 61.8349901586771, 44.85758475959301, 27.930999733507633, 24.455565623939037, 36.57242953777313, 35.458017736673355, 1.6099547292105854, 0.2294631113181822, 0.04466616162972059, 0.11397866168408655, 0.13404859841102734, 0.023341503656411078, 0.020079894493392203, 0.04148582876950968, 0.06234732907614671, 0.04025735914183315, 0.021257311782392208, 0.019998141360701993, 0.002799449684971478, 0.026075618370668963, 0.05035797417804133, 0.07856108131818473, 0.014349266693898244, 0.07776669386657886, 0.04917988524539396, 0.04487549180339556, 0.04190459301753435, 0.02342954649066087, 0.025162552228721324, 0.06118938574218191, 0.2150020669796504, 33.313568606972694, 61.983448192477226, 34.24992956221104, 26.69375952333212, 39.950558468699455, 57.786303609609604, 61.89830616116524, 63.69969829916954, 53.57288829982281, 59.33946646749973, 41.06658898293972, 0.8060995512641966, 1.6298720729537308, 4.888289021328092, 5.515804924070835, 2.4793657707050443, 49.000510051846504, 48.282150998711586, 58.44383552670479, 48.154363855719566, 52.479120790958405, 55.82221180200577, 56.99821449816227, 54.19844873249531, 50.6416267901659, 52.80890129506588, 55.21620512008667, 52.773369401693344, 53.25339384377003, 53.93747113645077, 52.05054558813572, 49.00895319879055, 47.44861252605915, 46.83563321828842, 47.36844062805176, 48.77427019178867, 50.44839195907116, 48.385429456830025, 49.89287696778774, 48.92327539622784, 48.6859705299139, 46.33290499448776, 46.5365094691515, 44.24382649362087, 39.93262343108654, 39.54133562743664, 39.88551735877991, 40.94777315855026, 40.817098170518875, 39.42430950701237, 38.455855473876, 38.11092518270016, 39.00717929005623, 38.66142824292183, 38.33122216165066, 38.24664629995823, 46.58238060772419, 45.47287434339523, 42.41518221795559, 42.48238921165466, 43.746322989463806, 43.267955258488655, 41.72151803970337, 41.34962819516659, 40.00757820904255, 39.29457686841488, 38.530559465289116, 39.41248834133148, 37.61208035051823, 37.52190738916397, 39.149626046419144, 41.26069396734238, 40.46074949204922, 43.81803274154663, 40.06383799016476, 42.37390883266926, 35.765789821743965, 40.72770796716213, 40.93562141060829, 39.86118346452713, 37.986162677407265, 39.213948994874954, 39.27465073764324, 40.0313763320446, 37.93297313153744, 38.55233609676361, 38.045150712132454, 40.42174458503723, 41.938630789518356, 42.577437311410904, 43.65000955760479, 42.632902935147285, 41.363740637898445, 43.01179580390453, 44.322926849126816, 37.212972566485405, 34.750119522213936, 38.85932922363281, 39.065205976367, 38.90037842094898, 38.92993703484535, 39.5097479224205, 39.97496455907822, 35.6707189232111, 36.38971634209156, 37.67023243010044, 38.98732155561447, 36.40437975525856, 37.27387569844723, 36.8560691177845, 38.17813217639923, 37.782486006617546, 37.16512553393841, 37.94960103929043, 38.5611592233181, 36.36281758546829, 38.09043288230896, 38.15600976347923, 39.0786724537611, 38.088020011782646, 39.76289413869381, 37.58741967380047, 39.147619754076004, 40.22285185754299, 41.06272839009762, 47.01944075524807, 51.32930628955364, 52.352336794137955, 53.94903011620045, 51.556560695171356, 56.64724253118038, 54.500087946653366, 53.31437677145004, 45.920741111040115, 54.92414519190788, 54.375420436263084, 56.55444771051407, 7.280860086902976, 4.872835725545883, 13.0913520231843, 1.216615866869688, 0.051533933146856725, 12.443882916122675, 62.94303350150585, 57.979675233364105, 63.06823678314686, 51.87027186155319, 36.67160041630268, 23.614756241440773, 42.37572133541107, 42.836142629384995, 3.0217123311012983, 0.3016754606505856, 0.06672599294688553, 0.16041201422922313, 0.12988455622689798, 0.03431864890444558, 0.03939349182473961, 0.06736315641319379, 0.022970125537540298, 0.0058763633387570735, 0.09602107762475498, 0.14950637676520273, 0.0976527263992466, 0.14046922966372222, 0.12948256451636553, 0.14028005622094497, 0.13985284633236006, 0.2053903046180494, 0.13687395461602136, 0.07790679650497623, 0.12814750021789223, 0.10637789688189514, 0.07508843133109622, 0.11241149069974199, 0.20655381405958906, 36.907362565398216, 72.21941873431206, 44.10340502858162, 35.84686607122421, 45.46145975589752, 62.153219282627106, 66.71335458755493, 67.12953105568886, 58.890075981616974, 61.911210268735886, 48.99451397359371, 0.9910280874464661, 3.393547316081822, 16.000396125018597, 11.869963612407446, 4.859358798712492, 51.594247072935104, 47.97378234565258, 57.52291314303875, 44.88867849111557, 54.13355581462383, 57.317378371953964, 58.51715259253979, 57.332737147808075, 52.17674441635609, 54.89766061306, 58.61677184700966, 54.95920971035957, 55.418567061424255, 56.88432700932026, 55.41602119803429, 50.649218782782555, 50.0415363907814, 50.06248086690903, 48.95286060869694, 51.584850177168846, 52.28783145546913, 49.9153907597065, 51.845337599515915, 51.24781586229801, 51.34214200079441, 48.80280286073685, 49.31403122842312, 46.42284236848354, 40.852109491825104, 42.158342599868774, 41.34931281208992, 41.70623905956745, 42.84511394798756, 42.96447314321995, 39.91408422589302, 39.2212750017643, 40.49625478684902, 40.82762360572815, 40.40244162082672, 40.89448481798172, 49.830898493528366, 49.13403108716011, 46.10562019050121, 44.471183493733406, 45.00238358974457, 45.48822171986103, 43.43055233359337, 42.337392792105675, 44.67340864241123, 41.65700510144234, 40.63050918281078, 40.50245985388756, 39.49491731822491, 39.89028990268707, 41.039496436715126, 44.24866743385792, 42.23247282207012, 46.52638301253319, 43.38974632322788, 45.360335782170296, 37.14159719645977, 44.04422700405121, 41.35466292500496, 43.55700574815273, 40.22421978414059, 42.01426953077316, 40.492964163422585, 40.85813216865063, 40.45740947127342, 40.44625706970692, 38.667530715465546, 43.59183467924595, 43.37428495287895, 44.774589613080025, 43.13993252813816, 44.65719871222973, 45.27768261730671, 44.65270355343819, 46.225401163101196, 40.62161386013031, 37.074329406023026, 41.26990467309952, 40.71479246020317, 41.71865299344063, 40.20503081381321, 41.686974093317986, 41.60530507564545, 38.26816834509373, 38.163977935910225, 39.06639151275158, 41.1024134606123, 38.51385556161404, 39.06960994005203, 39.534644186496735, 39.59666445851326, 40.769779309630394, 40.578801557421684, 40.3586033731699, 40.36155201494694, 37.76803158223629, 39.774551913142204, 39.59985628724098, 40.807621479034424, 40.392223969101906, 41.15300394594669, 39.659129306674004, 40.0221162289381, 44.61263470351696, 41.97869963943958, 49.489106833934784, 54.08064745366573, 56.41473300755024, 54.23345245420933, 53.0491928011179, 58.85962441563606, 55.26048794388771, 55.64853072166443, 47.6859325915575, 58.072861433029175, 57.805306389927864, 58.67692641913891, 11.29245350137353, 6.4870138093829155, 22.978926859796047, 11.171737778931856, 0.4207993653835729, 14.218156859278679, 67.02233120799065, 62.99699820578098, 68.49037483334541, 55.48597164452076, 37.78268359601498, 30.893233381211758, 50.77278055250645, 50.71192301809788, 4.790536416694522, 0.5140862299595028, 0.10664035740774125, 0.31553014065138996, 0.2563112386269495, 0.11584027975914069, 0.15988480736268684, 0.12365795948426239, 0.19980579178081825, 0.11602595768636093, 0.24707049073185772], [0.024379675487580243, 0.024404418691119645, 0.09631618522689678, 0.046308415694511496, 0.09097401329199784, 0.010488247116882121, 0.03718119412951637, 0.1351487432839349, 0.010400519695394905, 0.027546189558051992, 0.03158517800329719, 0.08854772473569028, 0.19017528276890516, 0.17722721036989242, 6.260026339441538, 48.16772013902664, 37.48184233903885, 31.283823922276497, 26.951070316135883, 42.97419682145119, 51.426208689808846, 53.831548020243645, 49.80856329202652, 59.606679528951645, 42.092579528689384, 2.6826795609667897, 2.79947935603559, 8.497832659631968, 12.62498689815402, 3.678555772639811, 39.66009825468063, 42.82146401703358, 62.05215610563755, 50.072709918022156, 55.757835656404495, 50.0645137578249, 54.531763046979904, 53.969883397221565, 54.00463253259659, 52.85358689725399, 51.69777251780033, 49.73346032202244, 54.177618250250816, 48.847374469041824, 49.62184891104698, 41.685248985886574, 44.54296924173832, 42.06462822854519, 46.254272013902664, 45.11386960744858, 47.31209725141525, 46.25949293375015, 47.091743275523186, 46.40749119222164, 45.436749681830406, 45.88319152593613, 45.39211727678776, 39.45356413722038, 38.07043835520744, 37.887326180934906, 38.418739065527916, 38.52009102702141, 37.202621921896935, 38.29869590699673, 38.13161887228489, 38.999116122722626, 39.06459040939808, 38.859921991825104, 35.641441494226456, 36.90130949020386, 45.24069540202618, 40.66787637770176, 41.23823717236519, 41.76804654300213, 43.03795740008354, 43.94292823970318, 41.468007043004036, 39.30631823837757, 38.56914259493351, 38.76399613916874, 38.40558797121048, 36.48027688264847, 36.64747171103954, 37.95071817934513, 38.525619730353355, 40.36405608057976, 42.24860295653343, 42.625766918063164, 42.89973981678486, 39.95973497629166, 37.040260434150696, 42.23286420106888, 40.5909913033247, 38.41379173099995, 36.86383590102196, 36.40477113425732, 36.639868319034576, 35.13061210513115, 35.80114312469959, 38.12467664480209, 38.329428657889366, 38.92665781080723, 37.47935347259045, 38.93981270492077, 41.27636432647705, 40.57261548936367, 40.352880880236626, 38.0273524671793, 41.45538792014122, 37.208367213606834, 35.05029581487179, 36.89589478075504, 37.50750236213207, 36.573014706373215, 35.9289226680994, 37.02880784869194, 37.403574138879776, 36.52122728526592, 35.44350631535053, 35.92879727482796, 35.18986612558365, 34.290188401937485, 35.07971003651619, 35.84373123943806, 34.906701520085335, 35.931856110692024, 34.83487777411938, 36.36118367314339, 35.54427310824394, 35.82312494516373, 35.3991436958313, 34.75719854235649, 35.890575125813484, 36.51878401637077, 37.069363072514534, 34.74452622234821, 36.928842812776566, 38.31972777843475, 39.005469381809235, 42.47995734214783, 46.11317038536072, 49.99992862343788, 52.94755205512047, 49.882134944200516, 52.05787539482117, 55.95506027340889, 52.00068086385727, 49.23791751265526, 51.49763345718384, 53.768649995326996, 41.83294326066971, 2.5518454564735293, 1.2118509225547314, 2.396586500108242, 1.4501814963296056, 0.15447551559191197, 23.628452606499195, 58.555849716067314, 50.11981599032879, 58.29521790146828, 36.4961676299572, 27.244515269994736, 24.100265689194202, 39.96077612042427, 20.295311361551285, 0.2451456119888462, 0.08427973734796979, 0.09331301786005497, 0.033234575239475816, 0.07675134678720497, 0.018082737988152076, 0.03263612961745821, 0.026719719062384684, 0.05348301332560368, 0.004539628280326724, 0.06030223725247197, 0.023017318708298262, 0.02667930726602208, 0.022638036716671195, 0.07268837027368136, 0.043579494158620946, 0.019698280302691273, 0.038973666305537336, 0.1331820519408211, 0.02825738596584415, 0.006000917055644095, 0.05792478572402615, 0.09654424720793031, 0.11845395318232477, 0.08130169167998247, 10.29468784108758, 56.92556619644165, 39.9498251080513, 28.70697509497404, 36.79402604699135, 51.09487406909466, 53.22522975504398, 60.0346277654171, 51.43624775111675, 63.17985579371452, 45.235223695635796, 3.4157307632267475, 3.721451433375478, 9.982819575816393, 15.948811993002892, 3.4025419084355235, 43.14952701330185, 43.55452448129654, 62.31078162789345, 50.55209219455719, 56.42474167048931, 50.98114617168903, 56.94093257188797, 55.27748443186283, 55.012403056025505, 54.30296212434769, 53.94098974764347, 50.634110793471336, 56.315410137176514, 49.9066436290741, 51.117802038788795, 44.42777842283249, 47.1787092089653, 44.21268716454506, 47.517210245132446, 48.61817076802254, 49.612718001008034, 48.63643258810043, 49.64747093617916, 47.71080605685711, 49.222068563103676, 47.90145322680473, 47.0945855230093, 40.225428119301796, 39.27568048238754, 39.64741453528404, 41.510272175073624, 40.26327408850193, 39.314700588583946, 39.54494543373585, 39.658316150307655, 41.06152005493641, 39.48347233235836, 40.57370603084564, 38.03928762674332, 39.13193419575691, 46.74460530281067, 44.45858336985111, 42.353283539414406, 41.60786993801594, 44.7670242190361, 44.8456571996212, 43.31203289330006, 40.837442278862, 40.85880473256111, 38.35457570850849, 38.46518397331238, 39.45663057267666, 37.84151203930378, 40.06236366927624, 40.85381560027599, 41.52535356581211, 43.25614169239998, 44.61430661380291, 43.662130907177925, 42.32531704008579, 40.87625339627266, 43.54261972010136, 41.19808852672577, 40.61564818024635, 39.25304889678955, 36.93635120987892, 38.28673794865608, 37.01597213745117, 36.95849262177944, 38.660360500216484, 39.05866652727127, 40.32074220478535, 40.73664888739586, 41.73778496682644, 43.09185370802879, 42.83785633742809, 41.301389783620834, 41.211384013295174, 41.62006348371506, 40.6121713668108, 37.63943888247013, 38.89320820569992, 38.826814368367195, 37.57202289998531, 37.46060527861118, 38.036817759275436, 39.58837330341339, 38.93277168273926, 37.88739077746868, 37.517142444849014, 37.775418385863304, 36.652027666568756, 37.552643939852715, 36.67377009987831, 37.15944103896618, 36.380099058151245, 37.90715731680393, 37.337947860360146, 38.259941786527634, 38.23355980217457, 36.46383136510849, 36.19005225598812, 38.28486084938049, 38.143937811255455, 39.48301635682583, 37.797783985733986, 39.7627991437912, 39.84069496393204, 41.315718814730644, 43.09634126722813, 49.508462995290756, 50.7603894174099, 55.373505279421806, 51.22270680963993, 54.145304784178734, 58.20400379598141, 55.162126421928406, 50.61473563313484, 55.21959833800793, 54.78091947734356, 46.21754698455334, 3.63548603374511, 1.0880019119940698, 1.9261812418699265, 0.5395915894769132, 0.12996078963624313, 25.656430386006832, 63.58172222971916, 54.43164981901646, 61.40447326004505, 42.42956444621086, 26.909947022795677, 19.618292190134525, 46.090272814035416, 27.317302264273167, 0.45127108809538186, 0.11492161225760356, 0.10534068613196723, 0.022742881774320267, 0.04508951606112532, 0.0721514190081507, 0.05660813782014884, 0.017365732419420965, 0.02809516547131352, 0.08246884506661445, 0.07033617774141021, 0.0924193458922673, 0.15802551963133737, 0.20539012650260702, 0.17626298242248595, 0.22306579834548756, 0.11347041669068858, 0.11535558311152272, 0.265378353651613, 0.1002260492532514, 0.08303926719236188, 0.2102708606980741, 0.16469552734633908, 0.3070111759006977, 0.24544113519368693, 9.639446251094341, 68.54683220386505, 49.25434023141861, 42.424020543694496, 37.09940806031227, 54.38865512609482, 61.77816040813923, 69.13183361291885, 54.67820718884468, 70.24360075592995, 48.09604838490486, 4.187232814729214, 5.418702559545636, 17.15166974812746, 16.41675878316164, 7.171714743599296, 45.369561687111855, 44.04614970088005, 63.28052379190922, 51.09917923808098, 57.05964580178261, 51.76690600812435, 57.08830766379833, 57.415599301457405, 56.722562089562416, 57.19230428338051, 53.719351440668106, 52.762444987893105, 57.19007760286331, 52.12192475795746, 53.749879002571106, 48.029361963272095, 49.51368011534214, 46.20376892387867, 50.2432219684124, 50.6823606044054, 52.22465604543686, 52.99226425588131, 51.92647844552994, 51.566318571567535, 52.51178003847599, 51.05858601629734, 51.05737768113613, 41.7705088108778, 40.82550711929798, 41.10217027366161, 43.38353745639324, 42.901974096894264, 39.87593427300453, 42.441431209445, 41.89537391066551, 43.12164030969143, 41.640882566571236, 42.05124914646149, 40.78212484717369, 40.75593665242195, 50.62054932117462, 46.93621002137661, 44.12378713488579, 43.51593375205994, 47.63702541589737, 48.51711519062519, 45.02283029258251, 43.00944373011589, 43.525957614183426, 40.31271703541279, 40.945082902908325, 40.27445308864117, 39.679291024804115, 40.79848296940327, 43.173328936100006, 44.21309754252434, 46.22886277735233, 45.733312368392944, 46.74641400575638, 44.188467264175415, 41.98391675949097, 45.87481677532196, 44.68353509902954, 42.47028686106205, 41.33787162601948, 40.23415245115757, 40.86846001446247, 40.03478854894638, 39.37360882759094, 41.498713195323944, 41.073797196149826, 42.69365407526493, 42.63942338526249, 43.38059261441231, 45.280353873968124, 44.5589891821146, 43.596728816628456, 43.91749620437622, 44.772446528077126, 42.1882089972496, 39.757916405797005, 41.74073360860348, 41.19891308248043, 40.21776393055916, 39.319647923111916, 41.08868479728699, 41.306553706526756, 41.634312719106674, 39.22417424619198, 40.680829882621765, 39.94979090988636, 39.26411770284176, 42.02216550707817, 39.651978090405464, 39.51411388814449, 38.58137033879757, 39.15293946862221, 39.216111078858376, 39.36699338257313, 39.74321499466896, 38.78021366894245, 39.05396617949009, 40.962250381708145, 40.66634885966778, 42.75780223309994, 40.86889699101448, 41.55749224126339, 42.724812403321266, 42.991713881492615, 45.39905570447445, 51.067705526947975, 54.221745282411575, 58.76831531524658, 51.823530569672585, 55.63670955598354, 60.842073038220406, 57.08442807197571, 53.8179637491703, 58.7616390734911, 56.36940523982048, 52.444641441106796, 5.095315212383866, 1.7173315049149096, 9.33036893606186, 6.746064908802509, 0.3275809861952439, 31.072811745107174, 70.09679183363914, 57.93388769030571, 66.97345823049545, 48.21859560906887, 38.24219673871994, 29.606462828814983, 56.021761894226074, 34.0723916888237, 0.9996857447549701, 0.1562509109498933, 0.20619798393454403, 0.11302066777716391, 0.19574952428229153, 0.18108045594999567, 0.12887324643088505, 0.09692749968962744, 0.1617846015142277, 0.18068741454044357, 0.24711016594665125], [0.0587467328296043, 0.06741419390891679, 0.04766362559166737, 0.08233060521888547, 0.06378841659170575, 0.027674067168845795, 0.08261138937086798, 0.03557647047273349, 0.024774787489150185, 0.0048206814608420245, 0.0323291402310133, 0.023184732381196227, 0.09218975508701988, 0.030961104166635778, 1.081280428916216, 37.06663861870766, 50.55591478943825, 31.39693435281515, 24.724798277020454, 34.53758932650089, 54.85801354050636, 54.825266897678375, 51.328443735837936, 51.28826089203358, 54.624573066830635, 7.606805171817541, 1.0754883522167802, 1.5280757728032768, 4.418091326951981, 30.205198600888252, 40.162982270121574, 62.75629252195358, 50.88629566133022, 60.23553438484669, 55.03640256822109, 56.85449481010437, 52.67549425363541, 55.29494449496269, 51.32828414440155, 52.19068966805935, 50.00692404806614, 52.78606832027435, 52.25421845912933, 50.16940712928772, 46.58009693026543, 43.19316007196903, 40.45326389372349, 43.74196082353592, 43.15045416355133, 45.829895585775375, 46.390772089362144, 47.34349876642227, 46.792349740862846, 47.61195056140423, 45.62117658555508, 44.82973225414753, 40.02948023378849, 37.42052122950554, 38.09004910290241, 39.38440024852753, 36.49158887565136, 39.35537740588188, 38.68305288255215, 38.84805902838707, 38.05004104971886, 38.71208332479, 40.1105222851038, 40.909957587718964, 35.890635922551155, 40.213386565446854, 43.70466202497482, 41.07906751334667, 42.3021724820137, 42.586853206157684, 44.36268411576748, 40.32451540231705, 40.17147481441498, 39.42033112049103, 38.88927161693573, 37.25834213197231, 36.92522920668125, 36.6888552904129, 38.072224259376526, 40.021303072571754, 41.11717946827412, 42.31985293328762, 45.503230914473534, 42.42305539548397, 44.03489090502262, 41.539796590805054, 42.9254986345768, 42.04749494791031, 41.2054867297411, 40.983430445194244, 39.48769010603428, 37.38630786538124, 36.4647851139307, 37.14364528656006, 35.412670969963074, 35.40784902870655, 37.613733261823654, 35.58930069208145, 37.01141998171806, 38.81946176290512, 41.8953625112772, 41.55754543840885, 41.21827304363251, 40.66117353737354, 40.38345403969288, 40.283276215195656, 35.580264776945114, 36.92924939095974, 36.28924213349819, 36.36594861745834, 35.66800966858864, 36.511556804180145, 35.79898104071617, 35.548597276210785, 35.72137400507927, 35.60528263449669, 35.2308165282011, 35.247813016176224, 36.02575667202473, 36.52567304670811, 34.237451031804085, 34.22527648508549, 35.49013741314411, 35.34515619277954, 35.63858404755592, 38.79336096346378, 41.94854065775871, 41.758516654372215, 42.696469724178314, 41.10156990587711, 41.18899181485176, 39.60204876959324, 40.29633231461048, 39.658411145210266, 38.36815617978573, 40.99872462451458, 45.39794996380806, 45.52148513495922, 51.250768303871155, 51.67437717318535, 47.37669378519058, 55.17825275659561, 54.10535752773285, 53.9043103158474, 52.02354043722153, 56.263436526060104, 18.342303559184074, 0.17590305564226583, 0.12667755800066516, 0.942930446472019, 0.6250851019285619, 0.3826345398556441, 40.79282887279987, 53.15765418112278, 55.020378828048706, 56.02343760430813, 32.15167075395584, 28.55042539536953, 35.808279141783714, 45.381911024451256, 7.245749495923519, 0.1804767781868577, 0.021217489993432537, 0.0476797969895415, 0.012642571946344106, 0.060411871018004604, 0.035908399731852114, 0.10697791585698724, 0.014074979117140174, 0.0369940615928499, 0.04517331937677227, 0.04845765681238845, 0.06907408882398158, 0.07553560499218293, 0.02203499348979676, 0.0731095539231319, 0.049979701507254504, 0.036762047675438225, 0.0017018863263729145, 0.009963053325918736, 0.06522930372739211, 0.009936307251336984, 0.04051088420965243, 0.046186336112441495, 0.026682869574869983, 0.0453240532806376, 1.9277284713461995, 45.020698606967926, 56.42923682928085, 30.099640265107155, 29.18782029300928, 49.328493252396584, 61.221817061305046, 59.15654048323631, 54.77395825088024, 58.12380529940128, 55.89354157447815, 6.596919586881995, 1.3005039654672146, 7.318536015227437, 7.202055640518665, 31.11122388392687, 41.31693094968796, 62.43985690176487, 52.5471181422472, 60.67640192806721, 55.623866245150566, 57.88694880902767, 54.78213541209698, 56.41647711396217, 52.45812691748142, 53.05990442633629, 50.17255716025829, 53.433222994208336, 54.58891578018665, 50.80262415111065, 46.450789868831635, 46.308115124702454, 42.220967039465904, 46.76982454955578, 46.443501859903336, 47.34663739800453, 48.317291513085365, 51.28443829715252, 48.82744073867798, 48.56573358178139, 47.7384115755558, 45.400913804769516, 42.47544698417187, 39.53913934528828, 41.656556725502014, 42.14182868599892, 39.86760891973972, 40.75044594705105, 39.04287837445736, 40.593901947140694, 39.28396783769131, 41.00487269461155, 41.182152181863785, 40.6509330868721, 38.24400544166565, 41.85022473335266, 46.37194409966469, 42.30434976518154, 41.930047050118446, 44.583843648433685, 45.60512624680996, 42.06764526665211, 40.73653109371662, 40.607246831059456, 39.19078163802624, 39.641027078032494, 39.11419674754143, 38.77370081841946, 37.61247172951698, 41.83961570262909, 42.68516153097153, 44.62652675807476, 47.401882633566856, 43.69758300483227, 46.52070611715317, 44.509960412979126, 43.06652046740055, 43.90114948153496, 42.57033549249172, 42.204236537218094, 41.38601504266262, 39.11793954670429, 38.57597842812538, 38.515979647636414, 37.54979029297829, 37.429796531796455, 39.16529640555382, 39.39524866640568, 39.071122258901596, 41.1007035523653, 42.484251111745834, 43.72783698141575, 42.910626232624054, 41.125934198498726, 42.04222463071346, 40.82548052072525, 38.11269208788872, 37.63321481645107, 38.331469148397446, 38.13293360173702, 36.28250889480114, 38.79113808274269, 38.80658805370331, 37.599826008081436, 37.72105470299721, 36.1449258774519, 38.4284171462059, 37.56135307252407, 37.232944294810295, 38.06410409510136, 36.47235810756683, 37.338411435484886, 37.70968571305275, 38.98870848119259, 37.80241593718529, 39.240961745381355, 43.497402146458626, 43.61098185181618, 44.08248335123062, 42.101790234446526, 41.976214572787285, 41.29728600382805, 42.31995552778244, 41.52344986796379, 41.311979815363884, 43.67146700620651, 49.007893055677414, 49.21266786754131, 55.68313166499138, 52.72392265498638, 48.59396606683731, 55.56397385895252, 56.797319278120995, 56.99805490672588, 55.26076912879944, 58.09239238500595, 22.85686980932951, 0.09072330838534981, 0.6766464945394546, 1.0016310028731823, 0.33450109767727554, 0.516226168256253, 44.155701622366905, 57.93839804828167, 60.63638247549534, 57.376488000154495, 43.688816875219345, 31.066319793462753, 33.716183602809906, 54.01586852967739, 12.18466842547059, 0.20035869179992005, 0.0003512388980198011, 0.14265700679970905, 0.03841249505057931, 0.0758179476542864, 0.0929785319021903, 0.07513131262385286, 0.02851474237104412, 0.06306572802714072, 0.08038354368181899, 0.04377194418339059, 0.16007130907382816, 0.1901341529446654, 0.11437115390435793, 0.1394148010876961, 0.11789720141678117, 0.13497511041350663, 0.16765173902967945, 0.11482675094157457, 0.21790007944218814, 0.15269853203790262, 0.10223700970527716, 0.15052754228236154, 0.17991237487876788, 0.16356204519979656, 2.3189343418926, 51.00703798234463, 67.00053557753563, 42.94924736022949, 33.31213988363743, 48.704726323485374, 64.24137443304062, 64.73454996943474, 60.368010476231575, 63.86027008295059, 63.04601937532425, 9.730210080742836, 2.7544439351186156, 7.153930747881532, 10.2075813151896, 36.884989365935326, 44.51253667473793, 57.70338445901871, 55.49624629318714, 61.29057057201862, 59.32266376912594, 59.481240659952164, 56.130040884017944, 56.72481156885624, 53.10341589152813, 52.15862698853016, 52.81837418675423, 54.84903462231159, 58.13424713909626, 53.172458186745644, 50.821246951818466, 51.21595837175846, 45.1837744563818, 48.16920205950737, 49.1275068372488, 51.193854957818985, 50.48462301492691, 53.62068213522434, 51.70468434691429, 49.37465697526932, 53.343053832650185, 47.97239921987057, 45.550078600645065, 40.79687565565109, 43.69081176817417, 44.44463811814785, 42.3060292750597, 42.744996920228004, 41.653239503502846, 42.63739049434662, 42.369455471634865, 42.58310280740261, 43.95599573850632, 43.07846702635288, 41.13988324999809, 43.90319377183914, 48.29426854848862, 45.74408859014511, 44.92650546133518, 47.318556904792786, 48.147398829460144, 42.513733729720116, 42.74992145597935, 41.55897036194801, 42.28370167315006, 41.25463709235191, 40.32076880335808, 41.12438388168812, 40.59303179383278, 44.063955545425415, 45.64684420824051, 47.71627776324749, 49.56735223531723, 45.10693117976189, 48.085914328694344, 44.70747381448746, 46.425407230854034, 45.090911239385605, 45.525828301906586, 45.38303576409817, 44.2224982380867, 41.700778752565384, 39.90501031279564, 40.65437950193882, 39.05003719031811, 39.31374303996563, 41.71765364706516, 40.77622376382351, 39.61510866880417, 42.58465692400932, 45.475370809435844, 46.74256481230259, 46.30553126335144, 43.95870119333267, 44.577934965491295, 43.04605856537819, 40.78311659395695, 40.09177029132843, 38.3003032207489, 40.45664571225643, 38.05637910962105, 40.42674891650677, 40.63683204352856, 40.710529088974, 38.826206400990486, 36.73408046364784, 39.565730318427086, 39.64013032615185, 41.054691821336746, 41.07842914760113, 38.46814401447773, 39.50813680887222, 40.10328367352486, 40.45887999236584, 39.74135309457779, 43.45126882195473, 47.51578912138939, 46.937741339206696, 47.98469536006451, 43.60256530344486, 45.06905861198902, 43.70691530406475, 45.2974833548069, 43.48833963274956, 42.64248602092266, 46.158368960022926, 50.88356740772724, 50.65169245004654, 58.25705274939537, 53.589394614100456, 48.6788535118103, 58.482566848397255, 60.42250715196133, 58.91097865998745, 60.08898004889488, 59.079845398664474, 28.169853016734123, 0.4367700865259394, 1.1091243848204613, 4.6017468720674515, 1.1760885477997363, 0.3965049533871934, 48.66920202970505, 63.55536304414272, 65.2617184817791, 63.68278920650482, 44.54688683152199, 39.613501355051994, 45.05478277802467, 62.72513039410114, 17.406940050423145, 0.3943409991916269, 0.11178034605109133, 0.2437515914789401, 0.15346227621193975, 0.22622710996074602, 0.15985798614565283, 0.26222677901387215, 0.054040121322032064, 0.21364165091654286, 0.2289016469148919, 0.17883320309920236], [0.04288452852051705, 0.05441506174975075, 0.009757881962286774, 0.03632041785749607, 0.040959245307021774, 0.03724744194187224, 0.0614973102346994, 0.07551891409093514, 0.07668745529372245, 0.07391471735900268, 0.03809058107435703, 0.014703619017382152, 0.07026968130958267, 0.10948066046694294, 0.07542452774941921, 12.902978081256151, 51.15773409605026, 37.89059400558472, 35.30373841524124, 28.53559859097004, 52.742974832654, 58.72380070388317, 55.912308767437935, 45.99410757422447, 56.67504943907261, 14.601077511906624, 0.4755658266367391, 5.837547434493899, 0.24905748723540455, 14.169394075870514, 20.089843086898327, 59.88841161131859, 54.001577496528625, 58.88665996491909, 55.79260379076004, 56.17244280874729, 55.430787205696106, 58.58200751245022, 55.14812417328358, 54.84333112835884, 54.09966163337231, 53.54986533522606, 51.01306825876236, 50.60126535594463, 40.7202185690403, 38.34401607513428, 39.7150357067585, 40.76208092272282, 42.31103740632534, 44.463412910699844, 44.76614646613598, 45.22780269384384, 45.48694498836994, 45.68750962615013, 43.40864270925522, 42.077779322862625, 36.15296244621277, 38.967653810977936, 38.132842406630516, 40.0095085054636, 39.374801963567734, 39.26314875483513, 39.311330169439316, 38.61304543912411, 38.13473850488663, 39.39109928905964, 38.96740682423115, 39.04075808823109, 38.09147022664547, 40.758718103170395, 43.966471776366234, 41.43798865377903, 40.01142740249634, 41.546393036842346, 41.51765137910843, 40.619242787361145, 40.37688799202442, 38.24732646346092, 39.40073177218437, 37.8248955309391, 37.54038579761982, 37.65608198940754, 37.78805650770664, 43.125846683979034, 43.34839314222336, 44.312773793935776, 44.760534167289734, 46.6539041697979, 46.0316077619791, 44.541635513305664, 45.91154180467129, 43.50296124815941, 43.81615564227104, 42.45555505156517, 42.21709884703159, 36.888933554291725, 36.74652859568596, 34.903255105018616, 36.407590582966805, 37.12615102529526, 36.843852773308754, 36.746961772441864, 37.17348128557205, 37.52067245543003, 39.18747581541538, 41.002098843455315, 40.789135470986366, 37.97452010214329, 40.25198109447956, 38.949414789676666, 35.51300458610058, 36.751935705542564, 38.59081283211708, 38.16643260419369, 35.631425231695175, 36.52357175946236, 35.78582614660263, 36.179063245654106, 35.92038072645664, 37.9963119328022, 37.970119938254356, 35.73332816362381, 35.4133777320385, 36.42324574291706, 34.29917111992836, 35.885190814733505, 37.969432175159454, 36.74850068986416, 40.99199898540974, 50.49671396613121, 47.951747328042984, 49.140973314642906, 50.86058624088764, 49.30860131978989, 48.20748120546341, 47.1362578868866, 45.164391696453094, 43.79834979772568, 45.7246146351099, 43.12776178121567, 44.578672125935555, 49.552624225616455, 48.76926206052303, 54.538880065083504, 48.97187098860741, 53.67763727903366, 52.46018260717392, 54.2035024613142, 55.48424273729324, 41.47245280444622, 4.673564443364739, 0.2849054761463776, 0.35535087576135993, 0.6161724426783621, 0.21268760523525998, 0.9145963762421161, 51.686156541109085, 51.49861000478268, 54.94144186377525, 48.522769287228584, 26.28099337220192, 20.36178309470415, 30.40485318750143, 40.85990287363529, 1.8891869019716978, 0.0799754292529542, 0.16105950839119032, 0.12941375258378685, 0.026898316900769714, 0.0425059960980434, 0.04364699991128873, 0.03988196600403171, 0.04899240761005785, 0.04843530332436785, 0.05957436849712394, 0.024255770222225692, 0.02881467207771493, 0.05560161116591189, 0.07303700156626292, 0.017077599150070455, 0.0014755184133719013, 0.04197283349640202, 0.04817996741621755, 0.030288300913525745, 0.018864134144678246, 0.03187091228028294, 0.04916173973469995, 0.019481712333799805, 0.06165382175822742, 0.07983476258232258, 0.03704102098708972, 20.310780331492424, 59.61508847773075, 38.443760722875595, 34.20227251946926, 36.67803727090359, 58.1010103225708, 62.34421223402023, 61.618477776646614, 50.564445331692696, 61.649134531617165, 15.124862305819988, 0.7332952204160392, 12.365275584161282, 1.5497387666255236, 19.166904911398888, 21.790504530072212, 60.84306098520756, 53.384566605091095, 59.2931317538023, 58.48745718598366, 57.660815343260765, 56.18493653833866, 58.70823293924332, 54.85637582838535, 56.5199189633131, 54.761776104569435, 55.32663859426975, 51.79157428443432, 51.7683195322752, 43.16411443054676, 41.183045133948326, 40.75626343488693, 43.285552114248276, 43.998029083013535, 45.87410621345043, 46.44036702811718, 48.381983041763306, 47.08805367350578, 49.3529449403286, 46.29903741180897, 44.2739512771368, 40.08200101554394, 40.753846764564514, 39.51298534870148, 41.10145591199398, 40.989810302853584, 41.9394401460886, 41.80794820189476, 39.18779879808426, 38.23670983314514, 40.67653611302376, 41.70651264488697, 41.31539963185787, 40.89604653418064, 42.06236734986305, 45.28734929859638, 42.96441614627838, 42.897456139326096, 42.446674928069115, 42.77022376656532, 41.30056902766228, 42.28679470717907, 39.86941382288933, 40.20497001707554, 39.98099483549595, 40.17445385456085, 38.45072194933891, 39.179340451955795, 44.36967574059963, 45.80425076186657, 46.46243244409561, 46.11541226506233, 47.170729637145996, 47.19857074320316, 47.25638084113598, 45.8525537699461, 45.13868987560272, 44.762354269623756, 44.35324162244797, 42.64490649104118, 39.56100717186928, 38.43375585973263, 37.51482456922531, 38.072524443268776, 39.82192017138004, 38.58142353594303, 38.04526850581169, 38.871963545680046, 39.76702831685543, 40.76000243425369, 42.17951886355877, 42.91407264769077, 40.313169211149216, 43.71154725551605, 40.6075394153595, 38.275756537914276, 38.87602172791958, 39.71762716770172, 39.64714474976063, 37.31285400688648, 38.587807193398476, 37.534712702035904, 38.22939142584801, 37.510994374752045, 38.65906096994877, 39.08070534467697, 37.00912110507488, 38.27137917280197, 36.6308856010437, 36.574473828077316, 36.37768238782883, 38.97293172776699, 38.08688007295132, 42.841150760650635, 50.15296921133995, 51.40428766608238, 52.074024528265, 53.448733761906624, 51.1467032879591, 49.27933529019356, 50.53193807601929, 47.818712666630745, 46.404664143919945, 47.76839956641197, 47.778529822826385, 47.16831296682358, 52.33214847743511, 52.59469158947468, 56.064665392041206, 48.2238545268774, 53.83223958313465, 54.37724433839321, 57.25247025489807, 56.17435410618782, 46.75146393477917, 6.8042948842048645, 0.457880447502248, 0.7460421707946807, 0.22579075681278482, 0.1378791342722252, 0.9670688887126744, 54.43799927830696, 55.607409328222275, 60.717492923140526, 54.36691649258137, 35.47173120081425, 22.5142402946949, 36.16061523556709, 49.91808861494064, 4.040383044630289, 0.17266420443775132, 0.08359878716873936, 0.06883704685606062, 0.03254821480368264, 0.030918721968191676, 0.03972974038333632, 0.013176539778214647, 0.06506416844786145, 0.034125779566238634, 0.018316616551601328, 0.04038385821331758, 0.09799812192795798, 0.16770321439253166, 0.1648312809993513, 0.10437447665026411, 0.12949132185894996, 0.12751464120810851, 0.21371025504777208, 0.08997512704809196, 0.11510597658343613, 0.1487576388171874, 0.11566486573428847, 0.13079567608656362, 0.23380782193271443, 0.23284653289010748, 0.180815375642851, 22.812908068299294, 69.03043985366821, 49.64222341775894, 44.87437605857849, 40.43068550527096, 63.39651636779308, 69.24579709768295, 66.84510111808777, 55.06726071238518, 66.98158219456673, 19.562946259975433, 1.2541751889511943, 18.84180575609207, 1.764942118898034, 18.783083707094193, 26.01896323263645, 59.373151659965515, 56.27084992825985, 59.58010375499725, 60.97299501299858, 59.50010284781456, 60.56154929101467, 62.12484620511532, 59.34540554881096, 58.81306931376457, 57.7718909829855, 57.7213840931654, 55.14622047543526, 56.820669025182724, 44.556625708937645, 41.686073541641235, 42.935803681612015, 44.4813821464777, 47.65133544802666, 49.22292731702328, 50.33170022070408, 50.80586537718773, 50.592734813690186, 51.501060873270035, 49.44192856550217, 47.208207026124, 40.953024476766586, 43.0305477976799, 41.615971103310585, 44.62039388716221, 44.65476684272289, 41.783298924565315, 42.00067386031151, 40.798566564917564, 42.927622720599174, 42.63625055551529, 43.27278859913349, 43.318754732608795, 43.35859179496765, 44.083163514733315, 46.94284826517105, 45.541057884693146, 44.045621529221535, 45.43988071382046, 43.72938729822636, 43.20766009390354, 42.996946200728416, 41.20572231709957, 42.98952519893646, 42.262574806809425, 41.08734346926212, 40.76126776635647, 41.77165634930134, 47.84390151500702, 48.055918738245964, 48.52856397628784, 48.798634484410286, 48.88216160237789, 50.610441863536835, 48.797502145171165, 48.631907030940056, 47.508128732442856, 46.215715482831, 46.58274158835411, 44.94624920189381, 41.390426605939865, 40.71084067225456, 40.791020169854164, 38.333011865615845, 42.39037334918976, 41.016849651932716, 40.61887040734291, 41.052153557538986, 40.95186933875084, 41.86904512345791, 45.1663713902235, 45.36364160478115, 42.450250536203384, 44.803342670202255, 41.31526283919811, 39.887668043375015, 41.84453643858433, 42.88826443254948, 42.4668974429369, 39.8315754532814, 40.60673005878925, 39.064252227544785, 39.54982437193394, 39.80946823954582, 41.90586134791374, 41.45056217908859, 39.72933813929558, 39.55933906137943, 38.12463104724884, 38.418146297335625, 37.67547994852066, 42.103059366345406, 40.764155611395836, 45.707082375884056, 54.73477855324745, 54.333960860967636, 54.572109282016754, 56.63943774998188, 53.76677669584751, 53.00687827169895, 52.66480542719364, 50.03249667584896, 48.29707659780979, 49.150362610816956, 49.80791352689266, 49.57639195024967, 55.14114014804363, 53.079100996255875, 58.7432898581028, 48.45267824828625, 55.055253356695175, 53.362759575247765, 59.28286470472813, 56.50504656136036, 48.13585124909878, 8.519847728312016, 0.8261976228095591, 2.3660812620073557, 1.485149951186031, 0.7916919712442905, 1.471108398400247, 57.9836156219244, 59.61884647607803, 64.44549947977066, 59.88408364355564, 37.57487654685974, 28.73501379042864, 42.53156237304211, 58.6307854950428, 6.052419729530811, 0.2969183534150943, 0.31418723927345127, 0.23844421142712235, 0.18054612446576357, 0.20642594201490283, 0.12400846841046587, 0.10021532521932386, 0.1647397890337743, 0.13942677935119718, 0.09470184333622456, 0.2630160975968465], [0.0602216697006952, 0.07375442830380052, 0.07175589140388183, 0.03564346414350439, 0.06514990134746768, 0.015982064869604073, 0.027890904166270047, 0.031074220460141078, 0.1387551802326925, 0.03285800579760689, 0.09829368224018253, 0.03963599228882231, 0.09473348109168, 0.08015514773433097, 0.30272892443463206, 2.9952239524573088, 33.78814794123173, 45.30161753296852, 31.128680147230625, 32.227864265441895, 45.13106368482113, 58.548690900206566, 55.177587792277336, 47.361973375082016, 53.401528894901276, 25.74345711618662, 0.2022975674481131, 9.033433869481087, 1.8027529399842024, 0.22908644168637693, 19.414828307926655, 66.33529767394066, 55.6757752597332, 57.45939575135708, 54.13719601929188, 54.47022154927254, 52.52881832420826, 55.574009120464325, 52.566880881786346, 54.49230596423149, 51.12353213131428, 52.176649421453476, 46.0630738735199, 41.24766446650028, 39.27918769419193, 40.094278156757355, 41.37453205883503, 42.146320044994354, 42.00531721115112, 45.31515620648861, 43.5833041369915, 44.500939697027206, 43.552085012197495, 43.315718695521355, 40.760887786746025, 40.571711137890816, 37.172250151634216, 38.94173160195351, 38.2928442209959, 41.51795156300068, 41.78183600306511, 38.95745135843754, 38.36330384016037, 37.77952216565609, 38.08775022625923, 39.05468054115772, 38.383374363183975, 38.727822080254555, 37.68996477127075, 41.193300783634186, 41.215483993291855, 41.30831301212311, 40.04682630300522, 42.09042504429817, 40.70509158074856, 38.57505887746811, 40.52739791572094, 38.54387395083904, 38.19763273000717, 40.026174411177635, 36.09070658683777, 36.995609030127525, 36.2582091987133, 42.44088403880596, 45.3262098133564, 47.25399076938629, 49.44329649209976, 49.43461395800114, 50.08622579276562, 47.67407722771168, 43.24320338666439, 44.07144494354725, 48.114496394991875, 47.46816247701645, 44.54181410372257, 38.54024514555931, 35.75659431517124, 37.28814013302326, 36.89443565905094, 37.11463764309883, 36.35704569518566, 37.86051481962204, 37.22881771624088, 37.58665971457958, 37.56298318505287, 38.84149678051472, 40.1748376339674, 37.15990461409092, 38.00718694925308, 39.64149825274944, 35.56270591914654, 36.814886927604675, 36.282934471964836, 38.709241077303886, 35.947173088788986, 37.17012606561184, 36.12510234117508, 37.87695653736591, 36.93197384476662, 36.55086189508438, 37.48370423913002, 38.08521956205368, 37.61012725532055, 36.899781972169876, 37.18689076602459, 37.759451642632484, 36.8863420933485, 37.561451867222786, 47.37539805471897, 49.27392438054085, 49.659865871071815, 47.673328667879105, 44.87921319901943, 45.85193060338497, 48.54360356926918, 50.079663544893265, 51.67466215789318, 48.76402974128723, 49.879209101200104, 48.292475044727325, 48.4750210493803, 49.1796400398016, 50.706542506814, 52.55174249410629, 47.628361880779266, 46.694968566298485, 52.1307098865509, 52.097834050655365, 50.08051089942455, 19.97631847858429, 0.5548690853174776, 2.448452766984701, 1.34264002321288, 0.1444422430358827, 0.07051243039313704, 6.043831240385771, 60.46865187585354, 47.87480905652046, 57.51838378608227, 39.62276145815849, 29.93379056453705, 27.19411477446556, 39.086025059223175, 25.2457370236516, 0.332438520854339, 0.03455264064541552, 0.04808991892787162, 0.00148329693274718, 0.03222940671548713, 0.05460502186906524, 0.0633069705509115, 0.015520719898631796, 0.02996154627908254, 0.053354766496340744, 0.03244684856326785, 0.043314873983035795, 0.031176365955616347, 0.0285065806019702, 0.053712867593276314, 0.027094865436083637, 0.03198262405931018, 0.0675684493035078, 0.019704900259966962, 0.0385137944977032, 0.16315190470777452, 0.043093346612295136, 0.058835946401814, 0.0457974321761867, 0.1464547694195062, 0.05740652915847022, 0.12393121083732694, 4.900791775435209, 47.314852103590965, 49.98690292239189, 27.02146153897047, 37.504698112607, 57.06670202314854, 60.34383237361908, 60.16702026128769, 50.31129911541939, 59.38605956733227, 26.62096682935953, 0.34017437137663364, 8.263083156198263, 5.2349168714135885, 0.38267218158580363, 21.283740922808647, 64.75513726472855, 59.255593568086624, 59.6804715692997, 57.07744784653187, 54.86235670745373, 55.06712391972542, 56.497264578938484, 54.99288350343704, 56.05718359351158, 54.12868067622185, 52.48235821723938, 48.49470779299736, 44.06395934522152, 41.15271516144276, 41.14265710115433, 42.983061745762825, 43.55697154998779, 44.94514346122742, 46.472330912947655, 46.05780355632305, 47.012490928173065, 45.483825355768204, 45.052134320139885, 43.11643458902836, 43.185993656516075, 39.097071066498756, 40.09847313165665, 40.871002078056335, 43.060786575078964, 43.42738330364227, 41.21165759861469, 40.102424919605255, 39.07932221889496, 39.452990368008614, 41.684899404644966, 40.32321587204933, 40.63997447490692, 39.1972678899765, 42.49475374817848, 43.235858380794525, 41.84927858412266, 41.64047598838806, 42.660120874643326, 42.69908018410206, 39.24787737429142, 40.40220983326435, 39.18887414038181, 40.13545274734497, 41.51252165436745, 38.06753911077976, 38.239989057183266, 38.33602890372276, 44.34995859861374, 48.07826913893223, 49.57598157227039, 48.52719604969025, 51.78483724594116, 50.512521117925644, 48.7592875957489, 44.652179181575775, 46.25689007341862, 49.92793008685112, 49.49356399476528, 46.42970860004425, 40.22895433008671, 40.83388566970825, 38.14289666712284, 39.48139764368534, 37.88924127817154, 37.14696250855923, 39.36529107391834, 40.42768366634846, 40.70905476808548, 39.67563942074776, 40.65089888870716, 41.235258132219315, 38.27544115483761, 40.55630676448345, 42.70086608827114, 37.13975429534912, 38.51421274244785, 38.726108372211456, 38.729820773005486, 38.07896509766579, 39.59887593984604, 36.96580342948437, 39.60991434752941, 37.98606388270855, 38.114747777581215, 38.67456413805485, 38.8249296694994, 40.950657203793526, 39.13383409380913, 38.29294301569462, 39.01832029223442, 37.45040662586689, 39.55304279923439, 48.36814038455486, 51.64305545389652, 52.95230560004711, 49.38343830406666, 47.132131308317184, 48.70924428105354, 50.1761669665575, 51.970191299915314, 52.72802643477917, 51.77954412996769, 52.11051397025585, 51.848518028855324, 51.84402287006378, 51.02552019059658, 53.71896006166935, 54.36230733990669, 46.88939653337002, 48.5352174192667, 52.50365987420082, 52.753500267863274, 51.369800716638565, 24.450437799096107, 0.5899140110705048, 4.222948523238301, 1.8844990222714841, 0.13480146270012483, 0.1706967709469609, 5.932541387155652, 64.68556299805641, 53.81699100136757, 60.57917274534702, 49.1475697606802, 38.59474942088127, 21.754784546792507, 43.62212285399437, 31.760398149490356, 0.708931521512568, 0.034325951637583785, 0.04607865048456006, 0.04936667268339079, 0.036726034959428944, 0.030269422532001045, 0.061624009686056525, 0.011062856810895028, 0.031949520562193356, 0.02156130845833104, 0.03746447189769242, 0.04822067050554324, 0.1269990118453279, 0.26207855727989227, 0.1207386251189746, 0.09706867844215594, 0.10335629456676543, 0.18074638559482992, 0.0893898842332419, 0.12023302959278226, 0.24923934310209006, 0.1438192545901984, 0.14365509152412415, 0.15513999009272084, 0.27865507872775197, 0.20979665801860392, 0.39947666111402214, 5.954602528363466, 56.90495230257511, 58.98887827992439, 41.87903858721256, 42.71673783659935, 59.072796776890755, 64.83892276883125, 64.87133502960205, 54.93442744016647, 64.94746014475822, 33.24509248137474, 0.27743240527343005, 26.48823995143175, 4.660850325599313, 0.5730063433293253, 24.779973216354847, 66.23460307717323, 60.94752497971058, 60.01056745648384, 60.25302104651928, 57.52601757645607, 56.92786127328873, 58.169452250003815, 56.780991554260254, 58.79318878054619, 57.16045059263706, 55.24768643081188, 49.14847791194916, 45.36927290260792, 44.046727269887924, 43.26239615678787, 45.36636605858803, 45.368224158883095, 46.48516282439232, 50.026025623083115, 49.568488374352455, 48.27906176447868, 47.49947279691696, 47.04418122768402, 45.58864273130894, 44.51255187392235, 41.71409323811531, 43.098225966095924, 43.07092823088169, 44.758030101656914, 45.82250118255615, 41.484068781137466, 40.797460824251175, 41.29966467618942, 41.647938787937164, 43.56837473809719, 42.911792770028114, 41.66919484734535, 41.742093935608864, 45.36276385188103, 44.660299345850945, 44.76892411708832, 43.592431247234344, 45.60107946395874, 44.99390244483948, 39.41802844405174, 43.315657898783684, 40.86014226078987, 42.55596846342087, 45.41461206972599, 41.760625541210175, 39.12631809711456, 41.47173844277859, 45.20471133291721, 49.87497992813587, 52.49161832034588, 51.92237086594105, 52.7627831697464, 52.41553120315075, 51.48421637713909, 46.011286452412605, 47.57605388760567, 51.23371861875057, 52.058688551187515, 48.71589012444019, 41.90906457602978, 41.36091738939285, 41.36208392679691, 41.80624209344387, 40.08127525448799, 39.56902474164963, 40.90979039669037, 42.797536700963974, 42.38539561629295, 41.04529492557049, 43.26501041650772, 45.16598001122475, 39.67565082013607, 41.88571482896805, 44.67270947992802, 40.18304139375687, 41.76955126225948, 40.837309285998344, 41.54023356735706, 40.22061377763748, 39.99788112938404, 39.61091749370098, 41.04312144219875, 40.10655149817467, 38.157624676823616, 41.853511556982994, 42.2731876373291, 42.92032331228256, 41.321190521121025, 41.391790732741356, 41.25929184257984, 40.24136446416378, 41.13909289240837, 50.4312738776207, 54.0000119805336, 53.67316871881485, 51.07142932713032, 48.67857612669468, 49.51518103480339, 51.70316442847252, 53.52324016392231, 54.63365077972412, 54.54870633780956, 54.484683573246, 54.747241884469986, 52.726745903491974, 53.10179717838764, 55.87641589343548, 56.9045989215374, 47.05128684639931, 49.53210532665253, 51.94251738488674, 54.17676329612732, 51.60687379539013, 28.695391416549683, 0.8423940755892545, 4.532138407230377, 3.1732747983187437, 0.20114683778956532, 0.3691156965214759, 7.458762740716338, 72.97598093748093, 58.23635146021843, 66.64723053574562, 49.70550522208214, 42.78022862970829, 34.468775019049644, 54.29357662796974, 39.324990436434746, 1.5169905801303685, 0.10908112526522018, 0.14245175843825564, 0.09550235350616276, 0.10412762349005789, 0.14227134233806282, 0.2022582187782973, 0.18618476955452934, 0.18305243138456717, 0.1411193361855112, 0.146695121366065, 0.13391458138357848], [0.079055715323193, 0.07118058594642207, 0.023089091810106765, 0.008103874133666977, 0.12508191080996767, 0.02356236680498114, 0.07712219798122533, 0.027870070225617383, 0.02859097578038927, 0.0538982263969956, 0.1158556793234311, 0.05427092553873081, 0.08423516395851038, 0.09143331364612095, 0.3120486962143332, 0.3998878109268844, 14.307670556008816, 49.056883826851845, 40.494560077786446, 20.853873789310455, 30.13835448771715, 55.46017862856388, 59.06324028968811, 50.14875143766403, 54.402296394109726, 38.317242711782455, 0.2870700240600854, 5.4212963953614235, 5.974769946187735, 0.3756433603120968, 16.388362906873226, 63.28381821513176, 56.568533554673195, 57.03748919069767, 49.46557089686394, 51.28760352730751, 48.14800679683685, 50.58432586491108, 49.119371473789215, 48.543538972735405, 46.36398732662201, 43.65695558488369, 37.96742968261242, 39.08050015568733, 38.617760986089706, 39.85555596649647, 40.68959221243858, 41.014892756938934, 40.50071954727173, 40.67226894199848, 43.00097018480301, 43.57711046934128, 42.05331243574619, 39.83329676091671, 36.647669300436974, 37.97168925404549, 39.947651624679565, 41.28276698291302, 40.85943549871445, 40.352022126317024, 39.0411152690649, 38.996482864022255, 39.21503573656082, 37.74019427597523, 37.86808781325817, 40.4856039583683, 39.88707147538662, 37.786559388041496, 38.9770583063364, 40.34120790660381, 39.951671808958054, 39.77517127990723, 40.5678391456604, 38.9515882730484, 41.583866626024246, 40.84140546619892, 37.75166966021061, 40.635646507143974, 39.52951066195965, 40.9750746935606, 37.33364649116993, 36.30132168531418, 37.854739129543304, 43.54746825993061, 47.76703163981438, 48.771895319223404, 50.417252629995346, 51.90316669642925, 50.20659193396568, 49.478448405861855, 45.91250315308571, 47.18868747353554, 50.59867009520531, 49.38272014260292, 45.99415697157383, 38.08380983769894, 36.43257424235344, 36.404007375240326, 35.79363092780113, 36.48189939558506, 36.73793725669384, 37.208838388323784, 36.920669451355934, 39.41472262144089, 37.08008609712124, 39.00747947394848, 37.997052893042564, 38.93850937485695, 39.247805178165436, 37.91812352836132, 38.98412972688675, 37.372822389006615, 36.74492888152599, 38.5704193264246, 35.65673567354679, 36.40726380050182, 36.66582092642784, 37.27993257343769, 35.699502378702164, 36.19422063231468, 36.48178920149803, 36.135585978627205, 35.23330919444561, 34.92666944861412, 35.85067726671696, 36.034853383898735, 37.150218933820724, 36.896924525499344, 47.4292753636837, 49.5369728654623, 48.42265605926514, 50.782785415649414, 51.26996487379074, 49.35868263244629, 48.763706758618355, 48.41861307621002, 49.85120080411434, 48.5234684497118, 50.456808507442474, 49.26938742399216, 49.009747356176376, 50.98525755107403, 50.306066796183586, 47.93104983866215, 47.79771499335766, 45.12718789279461, 44.96812842786312, 52.466634660959244, 43.83711151778698, 3.070240714587271, 0.179952094622422, 2.870919560082257, 0.714900407474488, 0.36911053117364645, 0.4117847647285089, 14.09863617271185, 60.605372339487076, 48.695413023233414, 52.78568834066391, 30.796604566276073, 24.200967885553837, 21.083725355565548, 42.642094641923904, 10.235487017780542, 0.17377586744260043, 0.0703577816602774, 0.03754748482606374, 0.013240616808616323, 0.02690169552806765, 0.026306617401132826, 0.0213351074125967, 0.0911837219609879, 0.029935936618130654, 0.0468214772263309, 0.0483479822287336, 0.04859593747823965, 0.08967005982412957, 0.05655594257405028, 0.07736013052635826, 0.017659396544331685, 0.056840400357032195, 0.024638133982080035, 0.08488840234349482, 0.051027242952841334, 0.07786516944179311, 0.05935626984864939, 0.10938236300717108, 0.08822152856737375, 0.09541331062791869, 0.049148076795972884, 0.3768231376307085, 0.7777150149922818, 23.460214734077454, 54.21175941824913, 39.96507368981838, 29.616541787981987, 41.210510060191154, 60.12495271861553, 64.5876270532608, 55.48244923353195, 59.20997701585293, 42.120827212929726, 0.19929439265979454, 3.2087986171245575, 5.292807715013623, 0.31579654198139906, 18.548968769609928, 65.21042123436928, 59.43576470017433, 62.211933732032776, 50.75279742479324, 55.640611946582794, 51.06269359588623, 52.31742426753044, 51.14023223519325, 50.33852845430374, 48.823614344000816, 45.702355429530144, 39.59447577595711, 42.19205439090729, 40.99562019109726, 41.883902326226234, 42.68635846674442, 44.58755224943161, 42.05484375357628, 42.81641408801079, 44.60190407931805, 44.55167457461357, 44.59633357822895, 43.075442388653755, 39.02640625834465, 39.8213692009449, 42.018464505672455, 42.78821960091591, 43.304760083556175, 43.39814007282257, 40.46486087143421, 39.60248954594135, 41.21010348200798, 39.81443077325821, 39.81160752475262, 41.465107798576355, 40.455980747938156, 40.28189688920975, 40.73520116508007, 42.58578546345234, 42.30909191071987, 41.73272743821144, 40.56565806269646, 40.60868315398693, 42.75071941316128, 39.93729718029499, 38.99475775659084, 43.0013919621706, 40.19596450030804, 40.099784061312675, 40.17755828797817, 38.435708954930305, 39.7772915661335, 44.83713045716286, 48.61211009323597, 50.02507947385311, 52.300389781594276, 53.53167951107025, 53.011863604187965, 50.39708711206913, 48.42884972691536, 48.76709997653961, 50.89082881808281, 50.2421048283577, 46.88298247754574, 40.039663687348366, 38.80849555134773, 38.95129568874836, 38.70364397764206, 36.90128669142723, 39.95419107377529, 38.01846094429493, 39.63027365505695, 40.62373034656048, 40.026011019945145, 40.481541976332664, 40.15004016458988, 40.971476286649704, 41.5588753670454, 40.523088946938515, 40.70543356239796, 38.896111249923706, 38.191359266638756, 38.91604498028755, 38.87873098254204, 37.29548513889313, 37.142140567302704, 38.980421125888824, 37.730485796928406, 37.98050478100777, 38.40255953371525, 37.599404230713844, 37.11929999291897, 36.70364409685135, 37.049710527062416, 37.954958751797676, 38.0911548435688, 38.94689932465553, 49.60159979760647, 50.910872742533684, 50.82885794341564, 52.14843213558197, 51.40434466302395, 49.948737770318985, 49.93492931127548, 49.68547649681568, 53.002755492925644, 51.88555084168911, 51.989118084311485, 51.05902299284935, 51.456512063741684, 52.538462206721306, 53.992100805044174, 49.383563697338104, 49.341211169958115, 46.5365968644619, 45.52742421627045, 52.65538953244686, 45.958917662501335, 4.494850058108568, 0.37755569675937295, 6.250821333378553, 0.6655086984392256, 0.426637603668496, 0.360978611279279, 14.456266332417727, 66.35892480611801, 52.44075424969196, 58.14481817185879, 39.89071547985077, 29.055887572467327, 24.61475048214197, 49.48502205312252, 15.410783663392067, 0.26487499941140413, 0.02598655322799459, 0.03065415374294389, 0.0335090808221139, 0.02351216051465599, 0.05882074350665789, 0.016090234748844523, 0.028368691419018432, 0.0665928961825557, 0.10519883944652975, 0.08354758640052751, 0.03801897124503739, 0.19108457694528624, 0.16168173984624445, 0.17158776376163587, 0.13237656938144937, 0.1420937167131342, 0.06175118782266509, 0.16410722688306123, 0.10708248446462676, 0.14603052812162787, 0.17707259132293984, 0.16063298127846792, 0.208876172255259, 0.17757367459125817, 0.21766064775874838, 0.49193240934982896, 0.7394190668128431, 30.85749439895153, 64.19688642024994, 51.105847880244255, 28.484814316034317, 40.45201376080513, 63.9948208630085, 70.48510059714317, 59.61874768137932, 63.45460385084152, 48.48743878304958, 0.3507583768805489, 14.233894664794207, 13.060714267194271, 0.6459219369571656, 19.995933026075363, 66.4794011414051, 60.99233977496624, 63.832789957523346, 54.052642956376076, 56.711386889219284, 52.08839535713196, 54.502538815140724, 53.78157690167427, 52.41433426737785, 50.54013803601265, 46.67301334440708, 41.52067981660366, 44.48796719312668, 43.93305256962776, 43.99100326001644, 44.641425758600235, 46.60492479801178, 44.19826693832874, 44.719880148768425, 48.62304590642452, 46.93736895918846, 47.466023191809654, 45.211110189557076, 40.0717643648386, 42.93176829814911, 43.48038665950298, 44.58287090063095, 44.201021790504456, 43.952435329556465, 41.29013478755951, 41.7938357591629, 42.39699639379978, 42.37551994621754, 41.79496809840202, 44.081286415457726, 42.09791824221611, 42.55277283489704, 43.63503076136112, 42.69797824323177, 43.71889986097813, 43.0777108669281, 42.97698587179184, 42.41930119693279, 45.401555970311165, 41.8411660194397, 39.39633160829544, 45.784309431910515, 43.65540146827698, 44.31514486670494, 43.34562689065933, 41.26439116895199, 40.2042518556118, 48.5533956438303, 53.479622304439545, 52.15507797896862, 54.92451377213001, 56.5305469930172, 54.111425802111626, 51.77993170917034, 51.0938785225153, 50.62505207955837, 52.9530693590641, 53.153269216418266, 49.897045344114304, 42.81715504825115, 41.333110481500626, 41.05632193386555, 39.662989899516106, 41.091033071279526, 40.74995197355747, 40.7806733250618, 40.58228217065334, 42.027485221624374, 40.867966040968895, 42.83757895231247, 41.92868672311306, 44.649443328380585, 44.171128794550896, 42.362783029675484, 42.38761089742184, 41.657989248633385, 40.33085726201534, 42.77563087642193, 40.25457255542278, 38.93918193876743, 38.92522148787975, 40.270987674593925, 39.315813928842545, 40.50036996603012, 40.306420773267746, 40.09959027171135, 38.578151911497116, 37.851893082261086, 39.712717831134796, 41.595106422901154, 42.33599066734314, 41.02128401398659, 51.28085508942604, 52.70013213157654, 52.68221989274025, 55.30372582376003, 55.48046953976154, 51.50501266121864, 53.57007645070553, 52.72488780319691, 54.24683913588524, 53.39181661605835, 53.439139276742935, 53.45018148422241, 52.00900241732597, 55.603233352303505, 56.71399734914303, 51.08401045203209, 50.37087231874466, 46.993617340922356, 46.434515342116356, 53.45758728682995, 48.1773716211319, 7.070092046633363, 0.406164777232334, 9.73479263484478, 1.9706155825406313, 0.4576065653236583, 0.9041547740343958, 17.59692795574665, 72.36953347921371, 56.02415196597576, 61.928111761808395, 40.56674100458622, 34.658517837524414, 30.505458489060402, 57.93557479977608, 20.46133015304804, 0.37310851039364934, 0.1528631107066758, 0.16766134242061526, 0.11875395895913243, 0.12035011081025004, 0.11436287153628655, 0.08184016434825025, 0.1655768573982641, 0.1581517292652279, 0.20306334510678425, 0.19741626922041178, 0.2065300356480293], [0.13626442872919142, 0.04762136028148234, 0.009719095469336025, 0.029748225206276402, 0.038527498254552484, 0.013897632725274889, 0.06760130418115295, 0.017785238815122284, 0.06294667269685306, 0.048654229467501864, 0.029372271746979095, 0.054616914785583504, 0.004332435491960496, 0.08437611264525913, 0.13048955501290038, 0.03166576410876587, 9.870347511023283, 51.574909910559654, 39.27560828626156, 35.36027178168297, 30.32853238284588, 40.6794847548008, 59.48932662606239, 51.01278707385063, 52.03115522861481, 44.47163186967373, 1.3878502347506583, 1.566873115953058, 4.251675931736827, 0.42882141773588955, 12.518192678689957, 61.28990940749645, 55.509214997291565, 55.15723988413811, 50.256939232349396, 49.244456961750984, 45.14029338955879, 43.409094884991646, 42.33906850218773, 40.319727659225464, 37.03293062746525, 37.58806183934212, 38.97371828556061, 39.330648332834244, 39.64914724230766, 42.98311114311218, 43.062553480267525, 44.95666824281216, 44.35231827199459, 43.98061841726303, 41.6486531496048, 41.737720370292664, 41.072706654667854, 39.6978872269392, 39.08748038113117, 40.50878271460533, 45.095729380846024, 40.23794464766979, 39.468178153038025, 38.82473587989807, 39.925639405846596, 39.21704202890396, 39.665604159235954, 38.32571625709534, 39.126207903027534, 38.86079974472523, 40.089809596538544, 39.276607632637024, 38.38526666164398, 38.98857168853283, 41.91510245203972, 39.31643329560757, 38.77473436295986, 38.73568765819073, 41.59090004861355, 42.4247083067894, 38.525346145033836, 39.23004873096943, 40.519950315356255, 40.903509333729744, 38.924837708473206, 35.10459490120411, 35.596231520175934, 42.02655427157879, 46.682003661990166, 49.654299169778824, 48.2436628639698, 50.46363674104214, 53.22822019457817, 48.82964842021465, 48.970446065068245, 49.30130571126938, 50.80931939184666, 49.440974816679955, 46.149519234895706, 38.842173144221306, 35.00137723982334, 36.34360581636429, 34.79375258088112, 35.997372195124626, 37.52365529537201, 37.32414700090885, 36.85947373509407, 36.95623554289341, 37.58622273802757, 38.46261911094189, 36.65183387696743, 39.65023398399353, 38.96939031779766, 39.71155509352684, 37.42165356874466, 36.77251540124416, 36.0125295817852, 37.89291948080063, 36.43338739871979, 36.14705756306648, 36.335052475333214, 37.51101717352867, 36.175822019577026, 37.971259877085686, 36.100943237543106, 35.964914336800575, 35.34079782664776, 35.45097291469574, 35.5131945759058, 35.67345857620239, 36.422846764326096, 38.287881687283516, 38.927049189805984, 43.37796315550804, 44.3675022572279, 47.462352588772774, 45.64079113304615, 48.4960263222456, 47.68991857767105, 50.63118875026703, 49.34594191610813, 50.612113773822784, 51.078063771128654, 49.76943299174309, 50.16975291073322, 53.051670268177986, 45.905811712145805, 51.11468240618706, 49.4686259329319, 57.582756131887436, 47.12237723171711, 53.259127736091614, 23.09014119207859, 0.27537537971511483, 0.32116194313857704, 1.1724209133535624, 0.3287842747522518, 0.46404882275965065, 0.7894116186071187, 20.329541824758053, 58.81021946668625, 50.97860790789127, 46.07528641819954, 35.09683571755886, 30.89191485196352, 26.29091463983059, 41.59989796578884, 2.6145033817738295, 0.07819347330951132, 0.043652250606101006, 0.043434048056951724, 0.02572668279753998, 0.03666369455459062, 0.05176402490178589, 0.05860196579305921, 0.07306547777261585, 0.08295785359223373, 0.023053103213896975, 0.019610113158705644, 0.0224974758020835, 0.12222557736095041, 0.06518329799291678, 0.01655125874094665, 0.04861698478634935, 0.05479712308442686, 0.08015537780011073, 0.01837380088545615, 0.05182310356758535, 0.023194966597657185, 0.009409884278284153, 0.025599582586437464, 0.014438648177019786, 0.042313842932344414, 0.028808489987568464, 0.09132810679147951, 0.2210172184277326, 14.114704560488462, 59.75761502981186, 44.57900270819664, 25.80951277166605, 38.485212698578835, 46.87269642949104, 63.32111321389675, 55.43253131210804, 55.58330342173576, 47.73538313806057, 1.3885065307840705, 1.989634393248707, 6.0081093572080135, 0.41131071047857404, 15.229889620095491, 63.98868799209595, 59.317773431539536, 56.184940338134766, 52.43047960102558, 52.21616730093956, 46.781337931752205, 46.50261528789997, 44.52033765614033, 41.263008043169975, 40.10843999683857, 39.49201047420502, 40.36842964589596, 40.54263509809971, 42.793087139725685, 45.178010165691376, 45.22346332669258, 45.53204096853733, 46.142907589673996, 46.60697288811207, 43.97472873330116, 42.68554911017418, 42.94861279428005, 42.111890092492104, 40.98153814673424, 43.135125786066055, 46.22799262404442, 42.402323707938194, 41.38706758618355, 40.91878451406956, 40.360161289572716, 42.5925263017416, 42.09659591317177, 41.709955260157585, 41.40931159257889, 40.1464569568634, 42.542160004377365, 38.916588351130486, 41.1692176759243, 41.73759877681732, 43.7762463837862, 40.96766509115696, 41.38953745365143, 39.867069348692894, 43.34725320339203, 43.63306246697903, 39.99057412147522, 41.97969138622284, 41.68090581893921, 42.03631594777107, 39.54982817173004, 37.2650221735239, 37.1545735001564, 44.807894825935364, 48.53604197502136, 51.48260526359081, 51.06596142053604, 53.373471200466156, 54.86492536962032, 52.52474494278431, 50.015640780329704, 52.09183417260647, 51.80119536817074, 50.8756448328495, 48.934139013290405, 41.147612035274506, 37.92760021984577, 38.3002158254385, 37.366366535425186, 39.1700803488493, 38.531475216150284, 38.82653318345547, 38.84608693420887, 39.31496277451515, 37.98667944967747, 39.80433851480484, 39.328068271279335, 40.511187985539436, 40.11396490037441, 40.577403232455254, 39.717741161584854, 38.950330540537834, 38.28997537493706, 39.85538497567177, 38.10017175972462, 37.92246289551258, 38.0221239477396, 38.46616432070732, 38.03118646144867, 39.25605073571205, 38.45576427876949, 37.233647257089615, 37.45493218302727, 36.19077041745186, 37.54675045609474, 37.19666384160519, 37.370911091566086, 41.4431943744421, 41.048619747161865, 47.53102630376816, 45.948730409145355, 51.04883573949337, 49.66725267469883, 50.92742845416069, 48.90424221754074, 53.03121596574783, 50.80934979021549, 52.85229116678238, 52.53706768155098, 50.037276819348335, 51.091150268912315, 54.62204620242119, 48.113022074103355, 52.60967418551445, 52.088950127363205, 57.0659838616848, 48.15452344715595, 53.98168936371803, 26.735979057848454, 0.1869540204643272, 0.6540052907075733, 1.5337403188459575, 0.5206328036729246, 0.4035966790979728, 0.9399349603336304, 20.684566274285316, 64.99941095709801, 55.86602345108986, 54.78530824184418, 43.7098753452301, 25.311737582087517, 26.913798116147518, 47.77794845402241, 3.9175527356565, 0.046490419990732335, 0.03246107553422917, 0.04767587473907042, 0.01265130424144445, 0.027633429017441813, 0.034719753748504445, 0.030410354520427063, 0.024603783676866442, 0.04590821627061814, 0.009946636091626715, 0.027876278290932532, 0.03483869775664061, 0.32521590997930616, 0.06327807874185964, 0.12633179139811546, 0.1332718666526489, 0.1132578804390505, 0.1539576894720085, 0.20353863132186234, 0.14290570048615336, 0.14167781715514138, 0.08844415060593747, 0.09725780735607259, 0.2655020251404494, 0.1860486002988182, 0.15171076316619292, 0.23310624004807323, 0.2845537575194612, 17.866356298327446, 69.70231220126152, 53.498298302292824, 44.373023360967636, 43.05362015962601, 49.428823068737984, 66.77960023283958, 61.09673537313938, 61.49137079715729, 55.51031693816185, 1.5962908999063075, 6.5237473882734776, 13.117295131087303, 0.506769900675863, 16.53632316738367, 62.6127590239048, 61.28175884485245, 58.863887786865234, 55.02290949225426, 55.25023989379406, 48.149192333221436, 46.725591123104095, 45.413217544555664, 43.120025396347046, 41.32994145154953, 40.74153542518616, 43.31930950284004, 42.936430647969246, 45.83079233765602, 47.76660606265068, 47.6205039024353, 49.79598976671696, 50.45083902776241, 49.03636112809181, 46.685408279299736, 47.46569260954857, 46.938778683543205, 43.61209899187088, 42.92165704071522, 45.2823905646801, 49.367665350437164, 44.4658599793911, 44.54619526863098, 43.585006445646286, 44.09066051244736, 42.85949997603893, 45.32951943576336, 42.74476133286953, 43.31284984946251, 42.22124062478542, 45.233095809817314, 41.83371461927891, 42.4608139693737, 43.526607379317284, 45.61329960823059, 42.97144576907158, 43.45584377646446, 40.65869987010956, 45.10842449963093, 45.81376925110817, 42.85161919891834, 42.99497410655022, 43.240729719400406, 44.61266130208969, 43.70194137096405, 40.431882441043854, 41.13792635500431, 47.865628749132156, 49.60153140127659, 52.91616193950176, 51.152934953570366, 55.241781547665596, 58.0890067666769, 55.227821096777916, 51.91699415445328, 54.15596701204777, 53.659899830818176, 51.60861410200596, 51.474838480353355, 43.08687977492809, 38.755013421177864, 39.7779793292284, 38.83887492120266, 39.84396658837795, 40.10122038424015, 40.869269371032715, 40.91004118323326, 40.96416547894478, 41.07209108769894, 41.50866486132145, 40.33817186951637, 43.20399709045887, 42.66545958817005, 43.82491037249565, 42.63058885931969, 40.021534860134125, 39.6644452214241, 42.36265383660793, 40.61077304184437, 40.28390698134899, 40.47063276171684, 40.59223763644695, 39.26866605877876, 42.250020280480385, 40.407153367996216, 39.304391741752625, 39.7516543418169, 37.4307806789875, 39.333847761154175, 39.8377501219511, 39.397270157933235, 44.72317077219486, 42.79519222676754, 48.25534723699093, 48.38427811861038, 53.0670328438282, 49.922720566391945, 52.39003077149391, 49.7587251663208, 54.76755179464817, 54.36134599149227, 54.494479447603226, 54.889692440629005, 51.50004632771015, 53.06772440671921, 56.84914469718933, 49.11889269948006, 55.53575277328491, 52.680912762880325, 59.057498797774315, 49.48818348348141, 52.98155263066292, 31.735646277666092, 0.48542044940404594, 1.2264644633978605, 5.269125960767269, 1.0583564965054393, 0.711196199990809, 1.066513352561742, 23.567433580756187, 69.39661100506783, 59.76076126098633, 56.43064275383949, 47.80127540230751, 38.51799733936787, 36.47005543112755, 58.24134439229965, 5.896621439605951, 0.3017392259789631, 0.13158349553123116, 0.1382394172833301, 0.13706508732866496, 0.16469399852212518, 0.18416201637592167, 0.14452368632191792, 0.14302670024335384, 0.14599928370444104, 0.14088722207816318, 0.09772138990228996, 0.11551359377335757], [0.043200379150221124, 0.03298209288914222, 0.028530167910503224, 0.012919743694510544, 0.04260976318619214, 0.02070415015623439, 0.069172527291812, 0.024194116303988267, 0.07778736267937347, 0.0763423640455585, 0.03955477164709009, 0.033111037337221205, 0.09125945070991293, 0.016955723658611532, 0.027613417005341034, 0.20824451552471146, 2.4314909521490335, 39.55749996006489, 50.17984136939049, 30.23266162723303, 26.686235927045345, 43.91029179096222, 55.40318548679352, 54.98395398259163, 47.32701525092125, 51.071349531412125, 1.6751591116189957, 1.2803205172531307, 2.046745684929192, 0.5259465810377151, 5.6688526365906, 57.56161026656628, 58.062400594353676, 54.609001502394676, 50.87290897965431, 47.54045359790325, 44.17534276843071, 42.45084710419178, 41.225329264998436, 39.34591591358185, 40.88227227330208, 42.06243574619293, 42.422861605882645, 44.93274852633476, 46.9112491607666, 49.823865070939064, 50.077965036034584, 51.06091529130936, 48.91208119690418, 48.30577813088894, 45.49899414181709, 44.023369923233986, 42.065688371658325, 41.39996029436588, 40.566634610295296, 39.45182763040066, 39.492994621396065, 38.27997051179409, 37.20740206539631, 39.85743306577206, 40.164851769804955, 40.11490345001221, 39.13336671888828, 38.76415193080902, 38.499739319086075, 39.6518374979496, 40.13820379972458, 38.494089022278786, 38.113110065460205, 40.19772380590439, 40.17262615263462, 38.95693838596344, 39.60231475532055, 38.77947650849819, 41.91110506653786, 40.317208394408226, 38.33275347948074, 38.6477679759264, 41.5509869903326, 40.598024725914, 38.17798778414726, 36.13536559045315, 35.615458488464355, 40.37851430475712, 47.60962888598442, 49.56660367548466, 51.21013708412647, 51.324643939733505, 54.96194936335087, 53.02316039800644, 50.75818553566933, 52.73339554667473, 52.0526734739542, 49.3693258613348, 45.91845743358135, 39.84756879508495, 35.415528416633606, 36.02769076824188, 35.503904074430466, 38.65603633224964, 38.70191887021065, 37.18889705836773, 37.31222324073315, 38.7456089258194, 37.71588318049908, 36.69002562761307, 38.070799335837364, 37.911986857652664, 38.78349669277668, 39.13817346096039, 38.25445868074894, 37.05893263220787, 39.17529746890068, 37.18238800764084, 36.67375870049, 36.441857144236565, 35.878020599484444, 37.5215882062912, 37.44347579777241, 37.61259712278843, 36.72359682619572, 36.868764236569405, 36.00240312516689, 35.99109873175621, 36.84712439775467, 36.50376722216606, 38.171987906098366, 38.07883210480213, 39.40407179296017, 43.18958826363087, 42.49250806868076, 43.987868428230286, 44.735812693834305, 45.489167869091034, 43.956303521990776, 46.47151775658131, 46.03259190917015, 49.99347276985645, 47.01333448290825, 51.042049303650856, 48.998632952570915, 52.30094455182552, 47.86484979093075, 52.18364864587784, 51.566052585840225, 52.765097245574, 47.90636256337166, 53.377259597182274, 9.306291528046131, 0.26938244816847146, 5.418515419587493, 1.8476258008740842, 0.15494229679461569, 0.7015424617566168, 0.1599833942600526, 21.84635203331709, 58.11101898550987, 46.674567461013794, 36.95098802447319, 30.515239164233208, 20.30213199555874, 41.688053235411644, 21.901521272957325, 0.3652020846493542, 0.0946346641285345, 0.03914074972271919, 0.08969517410150729, 0.11806412527221255, 0.06312370460364036, 0.031160179714788683, 0.06622914734180085, 0.040102925631799735, 0.03164960384310689, 0.03885423247993458, 0.021914041972195264, 0.046150475536705926, 0.01524443965536193, 0.0783009066071827, 0.030862320600135718, 0.05792865231342148, 0.005977502760288189, 0.08685338674695231, 0.016593919244769495, 0.06264962066779844, 0.026189196651102975, 0.06475539790699258, 0.014800367243879009, 0.04761748627061024, 0.04027741939353291, 0.0486788984562736, 0.11352586996508762, 0.18002224242081866, 5.01508679240942, 48.30118037760258, 53.61372850835323, 35.77592007815838, 34.45605710148811, 48.838319554924965, 61.22402474284172, 61.12698934972286, 52.622293308377266, 54.79168429970741, 1.81438316591084, 1.6533631249330938, 1.1707741767168045, 0.6949431065004319, 7.222138037905097, 60.05133546888828, 60.16889736056328, 56.88798241317272, 53.44872996211052, 48.99617828428745, 45.241269171237946, 46.18111073970795, 43.23645494878292, 40.83217196166515, 42.1647072583437, 44.74144019186497, 43.732111752033234, 47.426835894584656, 47.78924144804478, 52.203574776649475, 51.9006322324276, 52.61826552450657, 51.30093701183796, 50.09282223880291, 47.21799150109291, 45.839577466249466, 43.856410682201385, 41.768909096717834, 42.87714242935181, 41.4305866509676, 41.83503694832325, 38.70989844202995, 39.512863755226135, 41.71791963279247, 42.269125655293465, 40.773552507162094, 40.300462692976, 40.60649447143078, 40.260834619402885, 40.80966956913471, 41.768274530768394, 40.09044796228409, 40.35481497645378, 41.24659292399883, 41.899226903915405, 40.82036979496479, 40.26973374187946, 42.161302641034126, 42.98759490251541, 42.88504980504513, 39.93779115378857, 39.68838773667812, 42.416850328445435, 42.26502947509289, 39.51919421553612, 38.89494091272354, 37.94110469520092, 42.89845168590546, 50.63683904707432, 51.59769728779793, 52.51028671860695, 53.78860652446747, 55.80985866487026, 54.96821142733097, 52.224815636873245, 54.92083556950092, 54.112497344613075, 49.714282751083374, 49.57561679184437, 42.78779782354832, 38.178470358252525, 37.88012936711311, 37.752102836966515, 40.113440528512, 40.36625236272812, 38.996053487062454, 39.031494185328484, 40.12439154088497, 38.56166459619999, 40.08339934051037, 39.93014216423035, 40.163738429546356, 41.65612354874611, 42.0961057394743, 40.409364849328995, 38.797932118177414, 39.839182645082474, 38.75432945787907, 38.81911598145962, 37.23025403916836, 37.88907028734684, 38.92128489911556, 37.967881858348846, 40.610685646533966, 38.38266380131245, 39.51802387833595, 38.658415004611015, 38.76067891716957, 37.94496528804302, 39.18789379298687, 40.56040294468403, 40.392695143818855, 39.726309701800346, 44.86551873385906, 45.49585171043873, 47.46784329414368, 45.35321496427059, 48.80660265684128, 45.932163298130035, 48.73189486563206, 49.61442030966282, 51.50625139474869, 50.140813663601875, 53.148964047431946, 51.94028690457344, 53.27867768704891, 49.5961394906044, 52.9637011885643, 52.07391433417797, 55.91704711318016, 47.82158151268959, 55.23996144533157, 11.745601985603571, 0.16359686676878482, 6.553243780508637, 2.278791395947337, 0.3529321274254471, 0.6735331553500146, 0.24972553888801485, 23.74291766434908, 62.67471469938755, 51.74649730324745, 43.52043651044369, 40.372799411416054, 21.435920856893063, 44.027519300580025, 29.086531028151512, 0.5148036789614707, 0.1147962709364947, 0.055333714408334345, 0.03513165684125852, 0.06943572996533476, 0.017687446015770547, 0.04238790184899699, 0.04649266498745419, 0.05477952305227518, 0.028156140324426815, 0.04744604273582809, 0.046533338390872814, 0.07932605003588833, 0.21303668181644753, 0.18160631210776046, 0.18725457543041557, 0.163664773281198, 0.14548905717674643, 0.25471858971286565, 0.17261572735151276, 0.13374614354688674, 0.19055325858062133, 0.27211093925870955, 0.1132206765760202, 0.13593237701570615, 0.22335085726808757, 0.18255122937262058, 0.20274393958970904, 0.37076611421070993, 5.575828403234482, 54.847545102238655, 63.59615005552769, 40.343772768974304, 36.94623067975044, 55.454437136650085, 64.44007337093353, 64.08764988183975, 56.21145151555538, 59.95657995343208, 1.9731159671209753, 4.327372144907713, 8.89016730710864, 1.2803393974900246, 8.869831748306751, 61.712564527988434, 60.654473304748535, 58.99414099752903, 55.42015537619591, 52.37095959484577, 47.303224727511406, 46.8808887898922, 46.1605766415596, 42.259265184402466, 44.661792665719986, 47.421288192272186, 46.21517591178417, 49.56675946712494, 50.55030629038811, 54.35356020927429, 53.61693933606148, 55.68112537264824, 53.2973612844944, 53.861133232712746, 49.9624702334404, 47.96957217156887, 46.661439165472984, 45.602454990148544, 43.631937727332115, 43.531915694475174, 43.72870713472366, 41.01686865091324, 40.827456414699554, 44.39283549785614, 44.32929150760174, 45.40456920862198, 42.69562616944313, 42.694832012057304, 43.05906906723976, 41.27180837094784, 42.43442818522453, 41.785571202635765, 41.88397452235222, 42.776664420962334, 43.6344949901104, 43.485892564058304, 42.5604560226202, 43.24478790163994, 45.16772411763668, 43.83546240627766, 41.699768006801605, 41.94737412035465, 45.02345725893974, 46.02246165275574, 42.82301053404808, 40.83932317793369, 39.294204488396645, 44.95947629213333, 53.04111063480377, 53.529213443398476, 54.70346063375473, 54.95416358113289, 56.648462265729904, 57.46310815215111, 54.87958878278732, 58.393366634845734, 54.966543316841125, 53.082076236605644, 52.402623295784, 45.29372535645962, 39.39859248697758, 39.23704415559769, 41.02552458643913, 43.73378746211529, 43.50287765264511, 40.92131517827511, 41.36151775717735, 43.09046298265457, 40.63916891813278, 40.650705099105835, 41.51627965271473, 40.766135305166245, 43.80113884806633, 44.49575677514076, 41.82443931698799, 41.09669476747513, 42.999165281653404, 39.928287863731384, 40.486455112695694, 38.927478566765785, 39.96944725513458, 41.98604844510555, 41.148390993475914, 43.91669064760208, 40.046153739094734, 42.513999715447426, 39.825385585427284, 40.675092190504074, 39.230079129338264, 40.22516593337059, 42.053692415356636, 43.275098875164986, 43.352926298975945, 47.25448474287987, 46.95528879761696, 49.22956936061382, 47.92349584400654, 50.394244864583015, 48.63453648984432, 51.234193593263626, 51.24395526945591, 53.41892056167126, 52.26410932838917, 54.59420129656792, 52.81446039676666, 54.7690337151289, 52.09984794259071, 53.787686973810196, 53.80877584218979, 58.109392672777176, 50.433929935097694, 55.51980882883072, 15.489615183323622, 0.5751450941897929, 13.73372370377183, 6.040879273787141, 0.7936366950161755, 1.495775249786675, 0.22460916865384206, 26.632094532251358, 67.98749461770058, 54.935346990823746, 48.31725351512432, 38.722179383039474, 27.736560367047787, 55.29851630330086, 35.8965066075325, 0.946559845469892, 0.16074511979240924, 0.1247569391853176, 0.19492058985633776, 0.37072235718369484, 0.11459032495622523, 0.14342821697937325, 0.13818809035001323, 0.2530491730431095, 0.13357642921619117, 0.23006097064353526, 0.12890857266029343, 0.24298648175317794], [0.07720328503637575, 0.08613142548711039, 0.07393410967779346, 0.04073025564139243, 0.04224648931995034, 0.06061093728931155, 0.06893944097100757, 0.042752218432724476, 0.038948477813391946, 0.0868254597298801, 0.04938232828862965, 0.07699373221839778, 0.03849453576549422, 0.09722293383674696, 0.024325033009517938, 0.1576684130122885, 0.49203156027942896, 24.504079520702362, 47.55134001374245, 33.45778986811638, 34.04228210449219, 35.440086498856544, 46.36523365974426, 48.281824216246605, 47.93619096279144, 51.04353882372379, 2.4621757306158543, 0.9200467087794095, 1.0935525828972459, 0.4769027017755434, 1.6866510012187064, 50.33517323434353, 63.961458653211594, 55.019314885139465, 50.763132870197296, 47.494666054844856, 45.519292652606964, 43.11413191258907, 45.75877100229263, 44.4148401170969, 46.77846148610115, 47.2016029804945, 49.36633162200451, 51.835853308439255, 52.201629281044006, 52.823036536574364, 53.912430480122566, 53.368539065122604, 52.23454311490059, 52.11174130439758, 46.88531555235386, 44.9758268147707, 39.44664850831032, 39.63011786341667, 36.450870260596275, 37.61220194399357, 38.52704085409641, 37.2833713889122, 38.506077378988266, 40.31471572816372, 41.38124629855156, 38.38600002229214, 39.10707212984562, 40.043744668364525, 39.216616451740265, 39.61898446083069, 39.32551480829716, 38.06906282901764, 38.36480475962162, 39.67937462031841, 40.17617516219616, 38.87410283088684, 39.0072400867939, 38.88998977839947, 42.08938390016556, 39.936598017811775, 39.87186089158058, 38.62592674791813, 40.15124469995499, 40.017066299915314, 37.640719413757324, 36.45865224301815, 35.258600637316704, 40.845680236816406, 45.76545104384422, 49.31962452828884, 49.02560770511627, 51.901042610406876, 54.01098199188709, 51.109286695718765, 49.08014237880707, 51.3858662545681, 54.63204346597195, 47.52099484205246, 45.867608562111855, 39.85543057322502, 37.85299502313137, 37.22702041268349, 37.245772406458855, 36.66271649301052, 35.8814138174057, 37.5967063754797, 36.9062340259552, 36.81165710091591, 39.31983791291714, 39.186320677399635, 38.801602721214294, 37.77550958096981, 37.731823325157166, 37.28247843682766, 38.57817851006985, 37.786259204149246, 38.11348244547844, 37.16010980308056, 36.25587232410908, 35.728179439902306, 36.61314055323601, 36.975500509142876, 36.26882962882519, 38.32386575639248, 36.237184926867485, 36.315897703170776, 36.44764423370361, 35.28815545141697, 36.22374504804611, 36.22448220849037, 36.17036171257496, 36.840877532958984, 34.53319676220417, 40.43293498456478, 45.106904581189156, 46.98298931121826, 46.79229274392128, 44.39539276063442, 43.03855396807194, 44.7974643856287, 45.65209932625294, 46.816410049796104, 48.11420001089573, 49.213921800255775, 47.941362485289574, 48.39245148003101, 48.30896995961666, 51.12920522689819, 48.550895377993584, 53.35221894085407, 48.47321234643459, 53.07976596057415, 8.092051483690739, 0.12192318186862394, 1.9825594103895128, 0.4732786462409422, 0.02925128683273215, 0.3179032023763284, 0.08894446204067208, 27.97587912529707, 57.78361335396767, 46.29637375473976, 36.16582855582237, 26.200183108448982, 24.383337199687958, 44.079990684986115, 10.498744491487741, 0.15827770141186193, 0.0372334858548129, 0.07133642211556435, 0.04922602456645109, 0.07846546301152557, 0.015069649034558097, 0.0532865000423044, 0.06835316657088697, 0.04633624623238575, 0.04227163328323513, 0.04377733217552304, 0.07476847662474029, 0.07470966142136604, 0.030104448669590056, 0.016368189462809823, 0.04617417973349802, 0.01559799045935506, 0.023838709203118924, 0.07283054350409657, 0.059915017991443165, 0.03810836664342787, 0.040678594741621055, 0.01964467497600708, 0.01831772235163953, 0.005456064700410934, 0.043202260494581424, 0.05913342516578268, 0.05073622458439786, 0.1456817187136039, 1.2334781745448709, 31.514410749077797, 56.62106193602085, 33.46833810210228, 35.88384568691254, 52.687019035220146, 52.78684727847576, 56.37157492339611, 50.77284514904022, 56.39376953244209, 2.0413005771115422, 0.5006879707798362, 1.4271926111541688, 0.8998739474918693, 2.456201263703406, 53.358849585056305, 65.70270001888275, 58.271446377038956, 54.534935876727104, 49.63745467364788, 46.7377732694149, 44.32321563363075, 46.12209990620613, 46.62458494305611, 48.87718006968498, 49.942528903484344, 51.41357056796551, 53.36760811507702, 54.27540600299835, 54.7409076243639, 55.63414849340916, 53.90561364591122, 54.80143837630749, 54.370944276452065, 49.69503678381443, 47.246448174118996, 43.62100571393967, 41.23335063457489, 38.20000760257244, 39.01866987347603, 41.39612250030041, 39.048414677381516, 42.25625954568386, 41.50951601564884, 43.20850744843483, 40.29542036354542, 41.224926486611366, 40.43152906000614, 41.05776205658913, 40.055330246686935, 41.137724965810776, 40.17068825662136, 42.7675487101078, 41.50923103094101, 41.39315865933895, 40.58530680835247, 41.45555891096592, 41.39901414513588, 43.16460080444813, 41.12027630209923, 39.70622397959232, 39.7734347730875, 41.78463265299797, 42.997561767697334, 39.72048461437225, 38.520243018865585, 37.41384118795395, 43.87968063354492, 46.368615478277206, 51.10385678708553, 50.027431547641754, 52.82087445259094, 55.74378781020641, 51.87240354716778, 50.81720396876335, 53.27990882098675, 55.04024036228657, 49.56216551363468, 47.68741071224213, 43.107307478785515, 38.89161989092827, 39.057374596595764, 41.06070689857006, 39.03087481856346, 38.26482832431793, 39.29385110735893, 39.05194088816643, 39.019619822502136, 39.64740313589573, 41.28634639084339, 38.64984646439552, 38.90610471367836, 38.78250494599342, 38.42265285551548, 40.74200659990311, 40.761564150452614, 39.5456749945879, 39.70660015940666, 37.62703634798527, 38.48265163600445, 40.20014427602291, 37.748253643512726, 38.04009698331356, 40.29018044471741, 38.90655308961868, 38.66358272731304, 38.22026051580906, 37.118293046951294, 37.42896057665348, 38.6681766808033, 38.095718398690224, 39.13945399224758, 36.92503161728382, 42.55825214087963, 46.797004491090775, 50.009055733680725, 48.16664859652519, 45.895366072654724, 45.44556140899658, 46.57277472317219, 46.60097301006317, 48.170243203639984, 51.55515477061272, 50.762806087732315, 50.11310555040836, 51.159561797976494, 51.396023109555244, 52.04411253333092, 50.56912288069725, 55.49856796860695, 49.63381066918373, 54.04965631663799, 9.789479300379753, 0.2173453982686624, 5.327154072001576, 1.0730050667189062, 0.043596786199486814, 0.4608067951630801, 0.004045914074595203, 30.237470269203186, 62.14904710650444, 49.10373151302338, 47.07960672676563, 27.35422868281603, 22.274693548679352, 51.19966484606266, 14.114899300038815, 0.09313559261499904, 0.11349916007020511, 0.019163319848303217, 0.05402792041422799, 0.07110335805919021, 0.052998205355834216, 0.008553128591302084, 0.02729895419179229, 0.04581406741635874, 0.05176822916837409, 0.04069582741067279, 0.08848022640449926, 0.07999329274753109, 0.11396621586754918, 0.21620648360112682, 0.1662486940040253, 0.12881056463811547, 0.13639369601150975, 0.15571220079436898, 0.15036989527288824, 0.1484319695737213, 0.1183376215340104, 0.11044282524380833, 0.13023685372900218, 0.14011920313350856, 0.09212160366587341, 0.2149350065155886, 0.09358626921311952, 0.23912217817269266, 1.2230502278544009, 36.60597413778305, 63.00402022898197, 42.045211270451546, 43.92823822796345, 49.982696548104286, 56.212070882320404, 61.22291520237923, 56.08699679374695, 61.922168880701065, 2.506322474218905, 2.5101500563323498, 7.868890883401036, 1.7785601131618023, 4.634856870397925, 55.04817433655262, 66.75710543990135, 61.744327023625374, 55.68592831492424, 53.315691500902176, 49.273612797260284, 46.94862015545368, 49.82532799243927, 48.03031571209431, 51.17977291345596, 51.40372909605503, 53.35905857384205, 57.65701174736023, 56.929643377661705, 58.04467834532261, 58.78695331513882, 57.319126278162, 56.52039013803005, 57.21930183470249, 53.1868290156126, 49.719651862978935, 45.384620279073715, 43.353458270430565, 39.453788325190544, 41.90820202231407, 42.78016023337841, 42.43374042212963, 43.577596843242645, 44.46010708808899, 45.65040461719036, 41.927892565727234, 43.10231074690819, 42.25623294711113, 43.72790917754173, 41.64117895066738, 43.360567688941956, 42.04971022903919, 43.69336523115635, 43.18442814052105, 42.80707038938999, 42.92667277157307, 43.295051604509354, 41.73879951238632, 45.395339503884315, 43.004910573363304, 43.39818947017193, 42.55466513335705, 44.28641460835934, 43.72868813574314, 42.37981751561165, 40.06971247494221, 39.422823786735535, 46.294052079319954, 49.71011437475681, 52.472227960824966, 52.05453157424927, 54.49677832424641, 57.023661732673645, 53.93772952258587, 51.44489988684654, 56.80823229253292, 58.119443133473396, 51.218405440449715, 51.036980375647545, 45.134988874197006, 42.05680064857006, 42.04999141395092, 43.22882115840912, 40.02479128539562, 39.41845782101154, 41.897194012999535, 40.78999802470207, 41.174244806170464, 43.5475442558527, 43.57859618961811, 41.04830056428909, 40.99870182573795, 41.79412454366684, 39.22223635017872, 42.08244167268276, 43.00588712096214, 42.238187715411186, 41.28006912767887, 39.57992635667324, 39.44378726184368, 40.56060053408146, 39.8298579454422, 39.00825463235378, 42.849905490875244, 40.62202423810959, 41.71788923442364, 39.690344631671906, 39.16369669139385, 39.63810883462429, 40.39554879069328, 39.60586756467819, 40.63576050102711, 37.48899735510349, 46.41122259199619, 49.773331582546234, 51.80268108844757, 51.107022017240524, 47.77352549135685, 46.16542898118496, 49.07827287912369, 49.1646384447813, 52.65681825578213, 53.44620309770107, 52.86134608089924, 53.029099479317665, 54.14637252688408, 52.77616985142231, 54.748423621058464, 53.25836397707462, 58.29199567437172, 49.792531952261925, 55.88560000061989, 13.453463092446327, 0.44660360261332244, 5.85788014344871, 1.4761261478997767, 0.21773085492895916, 1.0002989368513227, 0.1602337503572926, 33.60652528703213, 69.4102218747139, 53.83293874561787, 49.41476382315159, 35.63663475215435, 33.68498347699642, 60.996280163526535, 18.65640990436077, 0.23148115928051993, 0.22170152311446145, 0.18852136214263737, 0.12985755689442158, 0.19546078430721536, 0.0953073393611703, 0.20249926834367216, 0.1416686738957651, 0.10223370714811608, 0.2559796767309308, 0.10354098543757573, 0.18186824570875615, 0.24101477349177003], [0.016875658911885694, 0.035589376420830376, 0.06964730884646997, 0.018089200239046477, 0.046499912059516646, 0.03450750322372187, 0.04884472393314354, 0.042067368267453276, 0.0348155946994666, 0.046004446849110536, 0.015150495819398202, 0.08601311972597614, 0.09816689373110421, 0.10229328676359728, 0.054940520858508535, 0.1052909622376319, 0.1668957428773865, 10.148710124194622, 45.43079160153866, 45.82212120294571, 33.817292377352715, 33.30393232405186, 36.02465093135834, 54.753553345799446, 47.92211651802063, 58.18223476409912, 6.850715568289161, 0.4842312913388014, 0.9079080226365477, 0.2293922659009695, 0.09151208520052023, 35.295732244849205, 66.9632063806057, 55.33812917768955, 54.27297793328762, 44.85489830374718, 47.9461882263422, 44.54436756670475, 48.94928880035877, 50.725632682442665, 52.933982983231544, 53.326289132237434, 55.75659692287445, 51.74401983618736, 55.42093813419342, 53.764789402484894, 55.57555943727493, 55.51534406840801, 53.877829536795616, 51.30341447889805, 50.02306558191776, 43.4655674546957, 38.05187255144119, 38.83922450244427, 39.07220900058746, 38.522857278585434, 40.874972864985466, 37.661865279078484, 39.00230795145035, 38.879578337073326, 40.17800286412239, 40.41925951838493, 39.687069207429886, 39.10224258899689, 40.318184942007065, 38.93303006887436, 39.59079757332802, 40.51753744482994, 39.617430344223976, 37.9773585498333, 39.96259622275829, 39.23410691320896, 37.02626198530197, 38.84359426796436, 39.991641864180565, 39.12382923066616, 39.1609076410532, 40.80152280628681, 40.083756521344185, 39.699999913573265, 38.20796437561512, 37.5196199119091, 37.567968517541885, 38.59824523329735, 41.97160542011261, 44.89522933959961, 48.288679048419, 52.742009684443474, 54.418202340602875, 55.22031269967556, 54.29524853825569, 49.49533469974995, 52.71436616778374, 47.11646854877472, 42.63526260852814, 39.57881681621075, 38.13416473567486, 39.20235961675644, 37.884890511631966, 38.268407732248306, 37.98642486333847, 37.35018700361252, 38.1689290702343, 38.31186220049858, 39.45533104240894, 38.23800176382065, 37.710624262690544, 37.669472470879555, 37.742721140384674, 37.76379480957985, 37.444391548633575, 35.67187026143074, 36.5473622828722, 37.416846826672554, 36.62518970668316, 36.81366719305515, 35.84860257804394, 38.236694633960724, 36.526630595326424, 37.43991918861866, 36.38934016227722, 37.57413938641548, 36.706471145153046, 37.29508616030216, 37.031976878643036, 37.02330954372883, 37.12332397699356, 36.427752301096916, 38.02519418299198, 38.79950903356075, 43.61703872680664, 46.66838899254799, 47.314046546816826, 47.13938891887665, 46.28512255847454, 45.47597877681255, 42.37452059984207, 43.05853709578514, 42.35767990350723, 43.43054473400116, 43.21205645799637, 45.907080844044685, 43.54074642062187, 48.50119784474373, 49.4867205619812, 52.443577498197556, 51.58974051475525, 48.06725353002548, 7.79768175445497, 0.049381333810742944, 0.821968331001699, 0.196575163572561, 0.19164739205734804, 0.3282024309737608, 0.3925917571177706, 33.84905107319355, 54.865757524967194, 49.00604635477066, 24.835737124085426, 20.78056812286377, 35.59815041720867, 42.49191150069237, 2.810938828624785, 0.0986122565518599, 0.02517379205528414, 0.035371014309930615, 0.04433800248079933, 0.07239219397888519, 0.07325278100324795, 0.008172182333510136, 0.019395276249269955, 0.030498551350319758, 0.028391267551342025, 0.03618816343077924, 0.058167891038465314, 0.018069520338030998, 0.05071488783869427, 0.04675826108723413, 0.027162371188751422, 0.014377954412339022, 0.058240443395334296, 0.07711876183748245, 0.06777993912692182, 0.06663962922175415, 0.0691649796499405, 0.04560931629384868, 0.025904102476488333, 0.07229106151498854, 0.04578001768095419, 0.08773834590101615, 0.060519066828419454, 0.15715619752882048, 0.13085460261208937, 15.696128401905298, 53.80704693496227, 47.54159353673458, 35.787931233644485, 42.51400351524353, 45.857687294483185, 57.24010191857815, 52.641406282782555, 62.54277817904949, 6.875916291028261, 0.5891585047356784, 0.5633051670156419, 0.2265586718567647, 0.4824149591149762, 39.357060715556145, 69.52001318335533, 57.634600549936295, 57.474811524152756, 47.12122209370136, 48.77088837325573, 46.22924655675888, 50.49279257655144, 52.501801773905754, 56.691107377409935, 54.01019923388958, 57.05648057162762, 54.38180409371853, 57.582368552684784, 55.555830895900726, 56.870868131518364, 56.93120889365673, 55.469195544719696, 52.83974044024944, 52.94931136071682, 44.99378465116024, 42.35642597079277, 40.098678320646286, 39.661960154771805, 40.80447904765606, 41.44761733710766, 39.7891279309988, 41.42270967364311, 42.142299860715866, 42.560870200395584, 42.224208265542984, 40.968459248542786, 39.706953540444374, 42.21587151288986, 40.119968578219414, 42.024167999625206, 42.97191694378853, 40.641828775405884, 41.907005086541176, 43.1396209448576, 40.73093019425869, 39.79651853442192, 40.991166830062866, 42.40167394280434, 41.63995161652565, 42.25697010755539, 42.212854474782944, 41.88688896596432, 42.400078028440475, 40.65192863345146, 40.215050876140594, 38.944919630885124, 40.01575157046318, 44.22518849372864, 46.20212361216545, 48.45210827887058, 54.39727686345577, 55.909006744623184, 55.32133027911186, 55.22580340504646, 52.21766822040081, 54.82755817472935, 49.02543671429157, 45.52703283727169, 41.550413221120834, 40.88228367269039, 41.34245038032532, 39.431570917367935, 40.63460536301136, 39.632006362080574, 38.60216282308102, 38.732169046998024, 41.00528307259083, 40.16997009515762, 40.16765981912613, 39.88320328295231, 40.19998848438263, 40.19663326442242, 39.400116205215454, 39.65156011283398, 38.30632969737053, 40.16533434391022, 38.91183480620384, 38.86281743645668, 37.46931441128254, 39.245472103357315, 39.806983172893524, 39.02446076273918, 40.592727810144424, 38.100658133625984, 38.940135687589645, 38.45939688384533, 38.17856155335903, 37.99326829612255, 38.674818724393845, 37.93749488890171, 39.077004343271255, 39.33045834302902, 39.74686659872532, 46.54408626258373, 49.13469985127449, 49.5898774266243, 48.55126015841961, 47.2603440284729, 47.29725144803524, 44.85085912048817, 46.38469621539116, 45.973896458745, 46.721627935767174, 46.467022597789764, 47.93362610042095, 46.20341934263706, 50.33808767795563, 51.99063800275326, 53.98932695388794, 52.20001056790352, 49.45511385798454, 10.031097885221243, 0.027389718852646183, 1.752009631600231, 0.23557153588626534, 0.24564296967582777, 0.21971381414914504, 0.314569296897389, 36.62224866449833, 58.77415180206299, 53.67362469434738, 39.04847927391529, 24.222731217741966, 36.23927861452103, 50.35072200000286, 4.071931326761842, 0.10372011762228794, 0.04299970983993262, 0.03079195386817446, 0.025556103864801116, 0.02687781507120235, 0.0497764643660048, 0.03154384779918473, 0.0822936388431117, 0.036524727402138524, 0.03941165217838716, 0.03813958137470763, 0.05459484331368003, 0.009911131746775936, 0.12870825215941295, 0.16888802347239107, 0.14489697176031768, 0.14039599453099072, 0.17464701522840187, 0.16800935030914843, 0.173623341252096, 0.19904111250070855, 0.14505343133350834, 0.14275966066634282, 0.15438351896591485, 0.14688635797938332, 0.20813381677726284, 0.11347717765602283, 0.2063886119867675, 0.3043368912767619, 0.27115805132780224, 15.271846018731594, 62.423962354660034, 56.0931296646595, 41.81311592459679, 44.83758643269539, 47.33924299478531, 65.92187225818634, 57.52178840339184, 69.73012670874596, 8.210948053747416, 1.295446080621332, 2.580080316402018, 2.015376230701804, 1.8067094776779413, 40.689482018351555, 70.53358599543571, 60.55013470351696, 60.265347585082054, 50.30625678598881, 51.550188437104225, 47.7943179756403, 53.80168542265892, 54.566698372364044, 57.964875027537346, 56.14959843456745, 59.675220251083374, 55.511453077197075, 61.00721597671509, 57.28206306695938, 57.1658843010664, 58.44537064433098, 57.463104352355, 54.48342204093933, 53.920448049902916, 46.57690890133381, 44.06534247100353, 43.09805877506733, 43.64571198821068, 43.77827927470207, 45.06020128726959, 41.626234352588654, 45.245908722281456, 43.903315365314484, 44.68359589576721, 43.81274342536926, 44.409303814172745, 42.72320508956909, 45.40658310055733, 41.30113899707794, 44.28673379123211, 44.904177859425545, 42.00021408498287, 42.40257829427719, 43.70993614196777, 43.3419144898653, 42.48910345137119, 42.80986703932285, 43.8553961366415, 41.58980950713158, 44.21981938183308, 46.401020139455795, 43.10264512896538, 45.68455718457699, 42.37153775990009, 42.929997593164444, 42.70026192069054, 41.26676984131336, 45.1503324508667, 46.82638071477413, 51.39277808368206, 56.794849410653114, 57.52307653427124, 58.03071029484272, 58.42031478881836, 55.21493598818779, 59.10868585109711, 51.15632817149162, 46.864431872963905, 42.887371480464935, 44.10148233175278, 45.09487062692642, 42.03506201505661, 41.60300239920616, 41.28697335720062, 40.722042471170425, 41.90936475992203, 43.26509401202202, 43.75539690256119, 42.085264921188354, 41.78434766829014, 41.80940732359886, 42.462497279047966, 41.933588460087776, 40.79188272356987, 39.772769808769226, 41.21313191950321, 40.62101349234581, 42.28256173431873, 38.64043436944485, 38.73365096747875, 42.45844289660454, 40.14304853975773, 42.487895116209984, 40.776588544249535, 42.27966628968716, 40.386376082897186, 41.21587157249451, 40.55070586502552, 41.012654677033424, 40.94605565071106, 40.85397519171238, 41.58760942518711, 43.174666464328766, 47.38209329545498, 52.35427089035511, 51.639027670025826, 52.75741025805473, 50.923754051327705, 50.07082521915436, 45.206307247281075, 47.6211042702198, 48.01655665040016, 49.70507584512234, 48.4005032479763, 49.575305208563805, 47.99028106033802, 52.0503555983305, 54.241177439689636, 55.78745126724243, 53.19655269384384, 49.346219301223755, 12.552065961062908, 0.10378146354923956, 2.1067461278289557, 0.5555773910600692, 0.4533829732099548, 0.5710811528842896, 0.48222865036223084, 42.35477305948734, 63.86048287153244, 57.45220273733139, 36.003820449113846, 27.736835852265358, 46.60908557474613, 57.48979412019253, 5.288712484762073, 0.20768078014953062, 0.10276680666720495, 0.15261949331033975, 0.13227016024757177, 0.1299685673438944, 0.15633529314072803, 0.130060326482635, 0.17524144583148882, 0.13788700103759766, 0.1490548244328238, 0.14771882502827793, 0.13462732516927645, 0.06754913119948469], [0.06101269893406425, 0.03720801534655038, 0.016928171426116023, 0.09191202858346514, 0.05189436087675858, 0.025251042206946295, 0.05365033051930368, 0.03654156673292164, 0.012830321393266786, 0.021084393229102716, 0.03151924189296551, 0.09940075877238996, 0.005339838344298187, 0.048007881923695095, 0.10265908393193968, 0.06935211218660697, 0.03274105074524414, 0.34191402490250766, 23.084407299757004, 47.25410856306553, 33.121751099824905, 30.852585062384605, 26.964645087718964, 50.537158995866776, 49.817204028367996, 58.85941922664642, 15.288110096007586, 0.46210294123739004, 0.6108029745519161, 0.516590770566836, 0.30537420592736453, 21.760096661746502, 65.43598473072052, 53.81656542420387, 56.75869435071945, 47.287136390805244, 47.66216106712818, 46.06036461889744, 50.85316143929958, 53.542136549949646, 53.00939753651619, 53.26079964637756, 55.580320581793785, 52.290354520082474, 55.25922641158104, 52.1266783028841, 52.60365150868893, 52.78387203812599, 54.538511484861374, 50.23238115012646, 45.07740676403046, 39.59156513214111, 39.81961369514465, 39.51232798397541, 39.42426770925522, 37.29491896927357, 38.35888847708702, 37.917758747935295, 37.20449522137642, 38.4494224190712, 40.27617819607258, 39.488655254244804, 39.39794272184372, 38.72131682932377, 40.564833506941795, 38.63069549202919, 40.86217135190964, 39.010219126939774, 40.337959080934525, 39.87806975841522, 39.78498995304108, 37.79529131948948, 39.44004066288471, 40.50530970096588, 38.13443832099438, 38.93351264297962, 38.812356144189835, 38.84496979415417, 38.382413014769554, 38.6001793295145, 39.118080139160156, 37.549075931310654, 36.25656768679619, 37.87475265562534, 40.14676854014397, 42.80483230948448, 47.07073040306568, 50.16308046877384, 55.539176389575005, 52.46261067688465, 53.83700832724571, 53.39140243828297, 52.750954404473305, 48.13520148396492, 45.41698694229126, 41.60361796617508, 40.48811562359333, 40.14869503676891, 38.9793685823679, 40.32591752707958, 37.98359401524067, 38.517180383205414, 38.90227071940899, 37.964443042874336, 37.29568652808666, 38.302621096372604, 37.19605587422848, 38.48022736608982, 37.81792290508747, 38.9861436188221, 38.954225331544876, 38.55181932449341, 37.62667536735535, 37.01029524207115, 35.25126323103905, 36.833623722195625, 36.62245765328407, 38.061033859848976, 36.218524128198624, 36.869398802518845, 36.52004174888134, 36.29034027457237, 35.89089810848236, 36.09511815011501, 37.10028201341629, 35.17312802374363, 39.345235750079155, 44.34518605470657, 46.10033467411995, 47.34175466001034, 46.98836222290993, 48.436563313007355, 47.966908514499664, 47.87493824958801, 48.207048028707504, 47.74845823645592, 47.62695215642452, 47.156039625406265, 43.638754561543465, 43.574199825525284, 40.852626264095306, 41.99979990720749, 44.94936503469944, 47.36321970820427, 48.416359797120094, 51.06862507760525, 53.67702171206474, 42.24679045379162, 4.7812083922326565, 0.48614799161441624, 2.7602212876081467, 0.17829400312621146, 0.06213354230567347, 0.7714216026943177, 0.22800970415119082, 33.57257030904293, 56.45764410495758, 33.96550342440605, 24.52652871608734, 27.96706359833479, 47.29496777057648, 18.906343393027782, 0.34285857109352946, 0.03006710936460877, 0.07114275125786662, 0.01403635960741667, 0.030158890767779667, 0.06443596270401031, 0.04586363545968197, 0.024787869697320275, 0.07485247289878316, 0.05669246434990782, 0.02147983919712715, 0.07731117104412988, 0.02452848908433225, 0.03184196109941695, 0.009829151331359753, 0.019968373817391694, 0.036648183668148704, 0.023017940256977454, 0.06275541381910443, 0.08547101795556955, 0.015237259376590373, 0.09002627586596645, 0.01436200009266031, 0.020279587879485916, 0.03640878538135439, 0.010662558124749921, 0.07934997687698342, 0.028653256813413464, 0.06079293045331724, 0.04503359894442838, 0.16801804827991873, 1.649293543305248, 32.54837326705456, 49.275816679000854, 31.043806001544, 38.01402658224106, 36.35171078145504, 56.85882277786732, 53.975062519311905, 62.91043125092983, 15.034618098288774, 0.5515853490214795, 0.15799942571902648, 0.9293655306100845, 0.22464621666586027, 22.931716293096542, 67.80102342367172, 55.57383432984352, 58.697050139307976, 49.8491907119751, 49.46957968175411, 48.55749562382698, 52.76463747024536, 53.2705195248127, 56.633703857660294, 53.62492650747299, 56.197236478328705, 52.914843410253525, 56.20283357799053, 52.80010476708412, 55.994228571653366, 54.78229120373726, 55.620366632938385, 52.254647836089134, 48.46440441906452, 40.802563950419426, 42.63846203684807, 40.43168485164642, 40.36185219883919, 38.811748176813126, 38.984494507312775, 39.78467836976051, 41.007011979818344, 41.61612689495087, 42.29039691388607, 39.639921337366104, 41.28486067056656, 40.517146065831184, 42.28627793490887, 40.49093507230282, 42.2665835916996, 41.28956101834774, 42.70855687558651, 40.75988084077835, 40.63608728349209, 39.93254743516445, 41.30287550389767, 40.93453086912632, 39.82039265334606, 41.171991527080536, 40.710217505693436, 41.09832488000393, 40.229611694812775, 39.841348528862, 42.457565143704414, 38.77192631363869, 39.0544867515564, 39.51944500207901, 43.17905902862549, 44.60729978978634, 48.317660093307495, 51.70610547065735, 55.94946697354317, 53.717481940984726, 54.402193799614906, 53.17146643996239, 54.457287043333054, 50.506973415613174, 46.56709022819996, 42.62189492583275, 42.75291569530964, 41.33984372019768, 41.88622020184994, 42.473034113645554, 39.918803572654724, 41.1485505849123, 40.770079493522644, 40.04753686487675, 39.97171953320503, 39.65182989835739, 40.31712479889393, 38.92756596207619, 38.9009065926075, 40.53674541413784, 40.04299230873585, 39.73979897797108, 39.77730676531792, 38.52584771811962, 37.349943816661835, 38.34585137665272, 39.002364948391914, 39.11853611469269, 38.46763104200363, 37.97698996961117, 39.42136086523533, 37.91165627539158, 37.94188745319843, 37.61307209730148, 37.81109467148781, 37.59123846888542, 40.87230160832405, 46.44956633448601, 48.20405378937721, 48.9623448997736, 48.318002074956894, 51.14634990692139, 50.11730432510376, 49.720894396305084, 49.49052795767784, 50.73190614581108, 48.92991364002228, 48.53531241416931, 44.96537737548351, 45.671793669462204, 44.99881558120251, 45.555455312132835, 47.30163261294365, 50.42826443910599, 50.36434046924114, 54.03354898095131, 53.51794324815273, 44.65556100010872, 5.873213745653629, 0.9974818630144, 3.2107315259054303, 0.09976807734346949, 0.032040660007623956, 1.2994808703660965, 0.11965403566136956, 38.95148567855358, 61.72344334423542, 43.89511540532112, 28.030180111527443, 21.766318827867508, 50.47760859131813, 25.26150617748499, 0.48806237638927996, 0.054493918651132844, 0.014630523965024622, 0.0318971694650827, 0.055843536465545185, 0.02025689114816487, 0.02921401432104176, 0.03128293094050605, 0.046752375856158324, 0.029025863186689094, 0.044066398695576936, 0.06925009656697512, 0.052806490057264455, 0.024113762119668536, 0.24740073160501197, 0.17535572173073888, 0.09173041020403616, 0.12199255041196011, 0.22795442899223417, 0.08825517012155615, 0.1448381639784202, 0.1658166156266816, 0.09954883207683451, 0.1306611395557411, 0.09167825206532143, 0.17497317428933457, 0.2222525974502787, 0.10148383371415548, 0.18916939065093175, 0.10779373653349467, 0.27356715174391866, 1.3984070182777941, 36.81099593639374, 59.80379395186901, 42.16700233519077, 40.98031461238861, 38.5321743786335, 59.346670880913734, 58.59892800450325, 70.77373310923576, 17.96773485839367, 0.6348979566246271, 3.1677344581112266, 1.8905531661584973, 0.31973918667063117, 25.269478149712086, 68.69662776589394, 58.06236259639263, 61.88145026564598, 52.08367981016636, 51.69451989233494, 50.50962947309017, 54.65347431600094, 55.90930312871933, 58.91656056046486, 58.186224550008774, 57.931406423449516, 55.51154047250748, 58.29376257956028, 55.22105745971203, 56.403348818421364, 56.5115138143301, 59.69927676022053, 55.993335619568825, 49.016837775707245, 43.433474376797676, 43.91845755279064, 43.70041385293007, 42.49886512756348, 40.35607270896435, 41.02204017341137, 40.63368201255798, 42.27142833173275, 42.09493160247803, 44.68243695795536, 42.29108467698097, 42.46285445988178, 43.536958023905754, 44.47046533226967, 41.73223726451397, 46.94233149290085, 42.34051622450352, 45.16528084874153, 43.68014194071293, 43.01838085055351, 41.96440860629082, 44.37198981642723, 42.816805467009544, 40.7981675863266, 43.933991119265556, 43.47891993820667, 43.32763485610485, 42.39208325743675, 42.680058404803276, 43.7224792689085, 42.49237507581711, 42.17338219285011, 43.16536836326122, 42.89194643497467, 46.46896429359913, 50.811496675014496, 52.47523359954357, 58.44507046043873, 54.69487689435482, 56.83372512459755, 55.01586467027664, 56.865457221865654, 53.2282467931509, 49.58062872290611, 44.3371494859457, 44.97318595647812, 44.70172472298145, 42.612665221095085, 45.39813615381718, 42.092419937253, 43.26843403279781, 43.86635474860668, 41.773746237158775, 39.5887266844511, 40.12025736272335, 43.24164167046547, 40.296480506658554, 41.439193189144135, 42.739217430353165, 42.00856603682041, 42.67854228615761, 40.01754507422447, 39.680050984025, 40.153250992298126, 39.83013533055782, 41.323436200618744, 41.992481499910355, 40.21353475749493, 40.77605277299881, 41.011317148804665, 40.31248904764652, 39.78155493736267, 40.70180855691433, 41.13450653851032, 39.30791415274143, 44.11111481487751, 48.76493029296398, 49.49235565960407, 51.74759924411774, 52.42493949830532, 51.63230203092098, 52.22624056041241, 51.64539232850075, 50.78015215694904, 54.13022719323635, 52.04871028661728, 52.91508659720421, 48.11864577233791, 47.2882117331028, 45.066831931471825, 47.477198392152786, 50.28535410761833, 52.599524930119514, 53.12674283981323, 55.95387853682041, 55.92390574514866, 47.106619477272034, 6.666460605338216, 1.8431974947452545, 9.331071898341179, 0.7470973266754299, 0.5223998276051134, 2.536718943156302, 0.4635594802675769, 42.306701838970184, 65.51576524972916, 48.49930554628372, 33.63949611783028, 34.978905245661736, 58.88996958732605, 32.163670510053635, 0.6849423993844539, 0.18254829046782106, 0.11371524378773756, 0.07786649046465755, 0.26956430403515697, 0.12006951961666346, 0.14845868689008057, 0.12020286128972657, 0.17271565011469647, 0.12877553526777774, 0.1387893338687718, 0.16489029658259824, 0.13732296880334616, 0.08149938497808762], [0.04960097241564654, 0.0559930792223895, 0.01101525267586112, 0.060217220525373705, 0.018758725054794922, 0.06140764024166856, 0.023801907955203205, 0.059810761085827835, 0.06045328285836149, 0.09592563001206145, 0.016717776270525064, 0.14609942911192775, 0.04187146725598723, 0.11914823975530453, 0.07440818619215861, 0.04912850265100133, 0.10537883994402364, 0.10696022305637598, 9.106567595154047, 55.1424814760685, 37.37916424870491, 35.57358093559742, 27.497372701764107, 37.90888622403145, 48.92145149409771, 55.43444260954857, 25.049164071679115, 0.5748960888013244, 0.6936926173511893, 0.1720560441026464, 0.16505868989042938, 5.1428544614464045, 59.296034798026085, 55.428419932723045, 58.908839374780655, 50.340975522994995, 48.07650603353977, 47.77166359126568, 51.79111070930958, 52.4385541677475, 58.2876069098711, 49.66823302209377, 52.02076658606529, 51.68407425284386, 54.30534079670906, 53.514128252863884, 53.6483408510685, 48.48014697432518, 47.73219890892506, 42.50135779380798, 37.141274213790894, 39.38952997326851, 39.82018746435642, 38.71958792209625, 36.254652589559555, 36.25542014837265, 40.03210589289665, 39.24247406423092, 38.33205431699753, 39.931152909994125, 38.847489058971405, 39.643113166093826, 40.10370925068855, 39.29452747106552, 40.61607375741005, 38.30195613205433, 39.915623143315315, 39.16441485285759, 41.103276014328, 39.38799865543842, 39.44402664899826, 38.81591275334358, 39.727027863264084, 40.013414695858955, 39.28215533494949, 38.45022037625313, 39.41642872989178, 40.173203721642494, 39.9552284181118, 40.520440489053726, 38.142110109329224, 35.98716974258423, 37.11901120841503, 37.95856475830078, 39.2451187223196, 43.35441581904888, 44.65574339032173, 51.17880016565323, 54.99006025493145, 55.07143668830395, 55.30793599784374, 52.54983879625797, 53.903713747859, 46.98946796357632, 44.63309660553932, 42.410641461610794, 43.33032511174679, 42.6112212985754, 42.803772166371346, 42.0938790589571, 40.983491241931915, 38.08717265725136, 38.95965903997421, 38.81133399903774, 38.72259736061096, 39.91654649376869, 38.00516165792942, 38.87172795832157, 39.086454436182976, 39.853967651724815, 40.88317282497883, 37.30498842895031, 38.130509331822395, 36.74109108746052, 36.39849007129669, 37.05558501183987, 37.05998137593269, 38.451941683888435, 36.98090761899948, 36.53999827802181, 36.06800280511379, 35.90374141931534, 35.05192972719669, 36.79988153278828, 34.85825031995773, 37.87631057202816, 46.07891142368317, 47.585777565836906, 47.753447368741035, 49.33948986232281, 49.404162392020226, 46.94504834711552, 45.57783231139183, 46.004374623298645, 49.1675528883934, 49.39270220696926, 49.871586710214615, 48.22353534400463, 45.85993677377701, 46.70397028326988, 44.512411281466484, 43.240969106554985, 43.843821957707405, 45.915296003222466, 48.0850213766098, 50.433519557118416, 51.8015031516552, 30.57989839464426, 2.141218828037381, 0.6801488378550857, 0.6425687950104475, 0.10741766061983071, 0.3133076161611825, 0.7841927767731249, 1.122639903333038, 43.074473440647125, 48.837008625268936, 28.75967636704445, 24.458778351545334, 37.98980288207531, 44.81858745217323, 4.284421149641275, 0.16008281236281618, 0.022000602366460953, 0.030424967408180237, 0.04240513822878711, 0.022617796494159847, 0.02048816477326909, 0.04042272448714357, 0.01892514424980618, 0.04911600117338821, 0.03187938389601186, 0.03367176701431163, 0.06689382964395918, 0.07197778613772243, 0.06481928197899833, 0.03098315151873976, 0.02872708751965547, 0.03495315548207145, 0.04850618955970276, 0.03183092536346521, 0.0854148596408777, 0.02397851312707644, 0.04695754629210569, 0.034264442438143305, 0.10322595117031597, 0.036544869290082715, 0.02485783010342857, 0.06660805083811283, 0.06230814367881976, 0.03631272178608924, 0.011771758126997156, 0.10509179948712699, 0.05141992442077026, 13.983066324144602, 63.28523933887482, 38.630501702427864, 33.54725606739521, 36.37769378721714, 44.70023900270462, 53.41215692460537, 61.20040141046047, 26.208924539387226, 0.6513475114479661, 0.3500699606956914, 0.5819277302362025, 0.19605482899351045, 6.110582258552313, 63.1949295848608, 57.83763125538826, 61.56067527830601, 52.44470223784447, 50.16048900783062, 48.82033132016659, 54.45287548005581, 54.84224058687687, 58.877453058958054, 53.10626193881035, 53.84846851229668, 51.297965571284294, 56.273152604699135, 54.721293076872826, 55.97980074584484, 52.26317457854748, 52.63471484184265, 45.04171147942543, 42.5237537920475, 40.31154289841652, 41.472217217087746, 42.2490893304348, 38.9689077436924, 38.48052375018597, 41.183284521102905, 40.37177726626396, 40.08140064775944, 41.73925928771496, 41.33043922483921, 41.34433887898922, 42.61395335197449, 41.069400832057, 42.323303148150444, 40.65296597778797, 41.79931506514549, 41.314271092414856, 42.776827812194824, 42.2664999961853, 40.40768913924694, 40.59278100728989, 41.269532293081284, 42.79074266552925, 40.97004376351833, 40.587651282548904, 40.981218963861465, 41.746133118867874, 41.3327457010746, 42.94149197638035, 39.68244105577469, 39.58419732749462, 39.45991359651089, 38.2112056016922, 40.597735941410065, 46.24493971467018, 46.83255158364773, 52.28571116924286, 56.39302857220173, 56.236176788806915, 56.80440589785576, 53.42354491353035, 54.28469270467758, 49.18207190930843, 45.77635645866394, 43.50954629480839, 45.017001405358315, 44.257969334721565, 43.820985183119774, 43.99900183081627, 42.7716638892889, 41.31712853908539, 40.33155642449856, 40.31059294939041, 38.9882031083107, 40.47798156738281, 39.80596102774143, 40.90247578918934, 39.94346804916859, 39.54654894769192, 41.874805614352226, 39.23818029463291, 39.85091641545296, 39.00935277342796, 38.30271229147911, 38.599092587828636, 37.96494461596012, 40.01287892460823, 40.19537553191185, 38.82022172212601, 37.91852630674839, 37.18059070408344, 37.712132781744, 37.5316196680069, 36.89880162477493, 39.387512281537056, 46.441202983260155, 49.55987423658371, 49.34841178357601, 50.351067781448364, 51.42725743353367, 48.82824629545212, 46.9913412630558, 48.35414193570614, 49.65374439954758, 51.19893528521061, 51.09311856329441, 50.335762202739716, 49.19484682381153, 49.24351841211319, 46.399089843034744, 44.67104896903038, 45.87946392595768, 48.60660798847675, 50.219868421554565, 52.99724958837032, 52.72759325802326, 32.48886086046696, 2.454069103114307, 1.4943662378937006, 1.642302512191236, 0.15133495442569256, 0.23825606214813888, 2.104731760919094, 1.1199160432443023, 48.290879130363464, 53.40467132627964, 41.31957560777664, 27.80862160027027, 33.08503367006779, 53.768649995326996, 6.5661208145320415, 0.11382539334590547, 0.023109769899747334, 0.03430388016568031, 0.025174025831802282, 0.036225408111931756, 0.010885744195547886, 0.06321717810351402, 0.04172184657363687, 0.03473158729320858, 0.013341732574190246, 0.043709121382562444, 0.019913913165510166, 0.03706619834701996, 0.036829456948908046, 0.11644076628726907, 0.15080752491485327, 0.07367873666225933, 0.1333148666890338, 0.14461879996815696, 0.16485143773024902, 0.14631254423875362, 0.09230716284946539, 0.11649331776425242, 0.17247326468350366, 0.13370278727961704, 0.2895976009313017, 0.1942178056924604, 0.22005480132065713, 0.14011975232278928, 0.13851926632924005, 0.2719909785082564, 0.17473763145972043, 16.60789042711258, 72.30483055114746, 48.30628350377083, 46.44845299422741, 38.52263309061527, 48.66580121219158, 56.748225912451744, 66.70489624142647, 29.398534186184406, 0.6707043258938938, 1.3028641138225794, 1.5182251576334238, 0.28556610632222146, 6.8335366901010275, 66.1802051961422, 57.339975759387016, 63.678400442004204, 54.017164260149, 52.845797315239906, 51.361011788249016, 56.50603070855141, 57.20330089330673, 63.514572232961655, 55.336073487997055, 53.97772237658501, 53.533533811569214, 58.346906527876854, 56.377050429582596, 59.35323692858219, 54.618219807744026, 54.39937435090542, 45.88754989206791, 42.08922430872917, 42.19099424779415, 43.979831859469414, 45.63927881419659, 39.81027379631996, 39.989738166332245, 44.16801676154137, 42.496231868863106, 41.91688075661659, 44.00287002325058, 42.4953693151474, 43.50714862346649, 44.88695718348026, 44.867863208055496, 45.316721722483635, 42.93955788016319, 43.31274725496769, 42.45930925011635, 44.54980127513409, 43.12881052494049, 42.17712119221687, 42.513467743992805, 42.75997191667557, 43.99899423122406, 43.26288253068924, 41.01172372698784, 41.98821432888508, 44.26998049020767, 43.27913425862789, 45.48684619367123, 40.634540766477585, 41.57303720712662, 40.7245921343565, 41.491432785987854, 42.721612975001335, 49.16691832244396, 49.731442630290985, 53.83814826607704, 58.075289502739906, 58.26049916446209, 58.54581445455551, 54.67598430812359, 58.320684134960175, 50.32548375427723, 49.63674031198025, 46.37110814452171, 47.90908321738243, 48.024851605296135, 46.587616726756096, 46.66296288371086, 44.1530417650938, 42.85385727882385, 42.86510467529297, 42.9817546159029, 41.47711895406246, 43.98364685475826, 40.8924101293087, 42.662529945373535, 42.85796865820885, 42.68880173563957, 46.26549281179905, 40.856285467743874, 42.54923142492771, 41.019000336527824, 39.33431513607502, 40.270892679691315, 40.91381058096886, 42.64795772731304, 41.26801997423172, 40.24921104311943, 38.66704434156418, 39.250282645225525, 39.22681890428066, 40.84075570106506, 38.890175968408585, 41.730895936489105, 50.21544545888901, 52.20746196806431, 53.10106761753559, 51.84394307434559, 53.26364189386368, 49.811097756028175, 48.25761951506138, 49.57187779247761, 49.57602716982365, 52.78975412249565, 53.97928789258003, 52.16652296483517, 51.15997977554798, 52.85450644791126, 48.2945953309536, 47.938277050852776, 47.86434441804886, 50.27282997965813, 51.73186048865318, 53.46845090389252, 52.63668313622475, 34.28400233387947, 3.9318342693150043, 2.0422065909951925, 3.8380021043121815, 0.3756162867648527, 0.7069718360435218, 4.18773153796792, 2.9369025444611907, 56.16290532052517, 58.23243007063866, 45.350292921066284, 34.93086062371731, 47.34345696866512, 61.39131456613541, 8.645093757659197, 0.380977324093692, 0.13424734555883333, 0.2009285127860494, 0.13592899282230064, 0.11975149449426681, 0.16035279084462672, 0.16171228664461523, 0.14471355738351122, 0.14869322039885446, 0.12800022843293846, 0.07909717911388725, 0.1183509208203759, 0.16871088766492903, 0.1975121843861416], [0.025897356354107615, 0.030788905496592633, 0.040451671957271174, 0.03349352911754977, 0.034493142666178755, 0.03983977119787596, 0.08315594765008427, 0.014185151867422974, 0.030600589234381914, 0.04017714411020279, 0.027067673145211302, 0.028152121594757773, 0.013889711226511281, 0.05629121107631363, 0.023871072407928295, 0.0715313917316962, 0.04978550372470636, 0.01917563764436636, 1.4352745399810374, 31.622602343559265, 47.27001450955868, 35.110241398215294, 26.512406654655933, 33.26258294284344, 47.63959787786007, 55.15428364276886, 30.890976302325726, 0.17009395407512784, 0.593146865721792, 0.21243646246148273, 0.14184468163875863, 0.30170366226229817, 36.56386099755764, 59.41193237900734, 57.91254423558712, 52.090219259262085, 49.66437242925167, 47.431441247463226, 50.888415947556496, 51.50083668529987, 56.002751514315605, 53.93480367958546, 48.88977259397507, 53.357838839292526, 50.858032777905464, 54.56680476665497, 49.5077258348465, 48.36881294846535, 41.468691006302834, 40.06470434367657, 40.064377561211586, 38.00431430339813, 38.41081269085407, 38.2386477291584, 38.23790296912193, 38.541320487856865, 39.588548094034195, 38.992204293608665, 38.18859301507473, 39.09759163856506, 40.65293937921524, 39.343624636530876, 39.75479297339916, 40.03434397280216, 40.1760383695364, 40.47106213867664, 41.58472537994385, 40.25637365877628, 40.72713039815426, 40.124410539865494, 39.79534439742565, 38.769274055957794, 40.69960467517376, 41.586952060461044, 39.41691130399704, 39.33399975299835, 39.362768009305, 41.37243077158928, 39.47059482336044, 38.394230380654335, 37.611726969480515, 37.58340708911419, 38.52984890341759, 37.93665513396263, 38.94259035587311, 40.44121474027634, 43.77167522907257, 50.86537018418312, 52.94863499701023, 50.85189990699291, 53.66022281348705, 54.43739891052246, 52.62117996811867, 50.220632180571556, 44.69234682619572, 44.754051715135574, 46.00170336663723, 47.46076047420502, 43.601075783371925, 44.91210423409939, 43.36700454354286, 39.63918037712574, 39.7285857796669, 40.28363719582558, 38.06516043841839, 39.4552094489336, 37.34391734004021, 38.9352073520422, 38.616343662142754, 38.14025200903416, 38.99748980998993, 38.338912948966026, 37.390084862709045, 36.177930906414986, 36.91059619188309, 36.218858510255814, 35.91120421886444, 38.11966851353645, 37.11920119822025, 36.65696740150452, 36.92886181175709, 35.31772546470165, 36.40893571078777, 36.07915140688419, 37.61807642877102, 40.73406882584095, 44.20912675559521, 46.628183349967, 51.20446398854256, 48.699737191200256, 50.03736041486263, 49.126488491892815, 47.3396647721529, 45.8291432261467, 47.543679624795914, 45.36473214626312, 49.026398062705994, 47.79711842536926, 49.73422408103943, 46.86464086174965, 46.59832835197449, 44.139039516448975, 46.71412713825703, 49.25753206014633, 49.83189024031162, 51.349931582808495, 49.225180596113205, 16.4892702922225, 0.26458107924554497, 1.250005743931979, 0.45493863348383456, 0.14260471507441252, 0.17407262261258438, 0.6948096980340779, 3.312856270931661, 50.792357102036476, 46.24366298317909, 30.89184645563364, 16.861397624015808, 43.268221244215965, 27.782606296241283, 0.42170941655058414, 0.01981901288672816, 0.02420044311293168, 0.07951960957143456, 0.018786440559779294, 0.04440007200173568, 0.03534770345140714, 0.01268590965992189, 0.04296755258110352, 0.026326701772632077, 0.06056593716493808, 0.043216698977630585, 0.07044100610073656, 0.06728712338372134, 0.019703916914295405, 0.03959461384511087, 0.03142381283396389, 0.12217701121699065, 0.014516851988446433, 0.020639488684537355, 0.06345593443256803, 0.018250493048981298, 0.041127594085992314, 0.030208809475880116, 0.04402086422487628, 0.005546934653466451, 0.08044974325457588, 0.03727442272065673, 0.02137018873327179, 0.015504642196901841, 0.09210617441567592, 0.03793748343014158, 0.028565998800331727, 2.538698874413967, 41.54246024787426, 51.232932060956955, 35.60051769018173, 32.72611252963543, 43.24091210961342, 51.514147371053696, 61.855813041329384, 32.987720891833305, 0.10269283680827357, 0.3698995232116431, 0.09077593407710083, 0.2008034905884415, 0.40751504071522504, 40.28467074036598, 62.47864902019501, 59.50361005961895, 56.21107533574104, 52.4271509796381, 49.93377037346363, 53.87133188545704, 54.49894040822983, 56.73793986439705, 53.90532486140728, 53.558103293180466, 53.52853707969189, 53.620332553982735, 56.22731186449528, 50.58637775480747, 50.01899600028992, 44.147083684802055, 41.86099715530872, 40.62622681260109, 39.41222995519638, 40.08577801287174, 40.540883392095566, 39.4007583707571, 39.50830399990082, 41.03042632341385, 41.78792327642441, 39.27798695862293, 41.18923880159855, 41.52067981660366, 40.24602301418781, 41.77062660455704, 43.084387108683586, 42.01271541416645, 41.970393285155296, 42.64471650123596, 42.12015084922314, 42.25388467311859, 43.193874433636665, 40.93620277941227, 41.11256651580334, 41.76377557218075, 43.49160745739937, 41.70543730258942, 41.4479973167181, 41.5032197535038, 43.08211863040924, 41.24358348548412, 40.91346859931946, 39.26382891833782, 38.65546256303787, 41.36712245643139, 40.30752271413803, 41.56672574579716, 42.21817798912525, 45.209274888038635, 52.2278668731451, 55.33550351858139, 53.15790116786957, 55.32006874680519, 54.48798939585686, 54.415458887815475, 49.70616638660431, 44.923549219965935, 46.14148646593094, 47.577672600746155, 48.22866886854172, 46.46712899208069, 45.24989850819111, 43.776763156056404, 41.658316031098366, 39.72790561616421, 40.84449090063572, 39.40583489835262, 41.60878948867321, 40.12901209294796, 40.468379482626915, 40.08686475455761, 39.7321841865778, 39.729224145412445, 40.264102444052696, 38.279932513833046, 37.90131703019142, 38.5127080231905, 38.758608028292656, 38.45080554485321, 39.46537770330906, 38.962843269109726, 38.559430316090584, 39.26633298397064, 37.40363873541355, 36.89713351428509, 37.04906836152077, 39.20191504061222, 43.70934337377548, 47.43924222886562, 47.06836313009262, 51.348388865590096, 51.622004583477974, 51.039123460650444, 50.07740646600723, 47.594703286886215, 45.947358682751656, 46.69183373451233, 46.543702483177185, 48.550716787576675, 49.758599773049355, 51.24359808862209, 48.86863052845001, 48.78018267452717, 46.74117408692837, 47.45811201632023, 50.67500039935112, 51.683086305856705, 52.62584611773491, 52.38405369222164, 18.1408516690135, 0.6951252592261881, 3.4751928225159645, 3.381476551294327, 0.3480536938877776, 0.20732141740154475, 0.8110870805103332, 3.432606845162809, 55.632765367627144, 50.55186040699482, 43.64157021045685, 17.52859052270651, 43.680062144994736, 34.80515576899052, 0.8651816903147846, 0.07135148771340027, 0.040371642462559976, 0.05534732910746243, 0.06879418782773428, 0.023535805339633953, 0.046814196757622994, 0.07491974116419442, 0.037405537950689904, 0.060563350780284964, 0.04191506472125184, 0.11546326131792739, 0.07744316942989826, 0.014538779669237556, 0.022031447879271582, 0.09000491685583256, 0.10197796305874363, 0.18449176743160933, 0.07951834792038426, 0.14447443740209565, 0.12631151592358947, 0.20116951782256365, 0.14076289749937132, 0.0707780450466089, 0.20596572139766067, 0.1459099439671263, 0.1798400451662019, 0.13842913991538808, 0.07199947911431082, 0.13524443580536172, 0.19852619559969753, 0.1894893156713806, 0.11155543077620678, 2.73315011523664, 46.484292671084404, 59.288488402962685, 45.99655084311962, 35.213409662246704, 46.919475719332695, 55.86446553468704, 67.29805961251259, 36.478969752788544, 0.19655346317449585, 0.8808169013354927, 0.5133580346591771, 0.38218013767618686, 0.6151407386641949, 42.24210910499096, 62.24121496081352, 61.60861350595951, 57.515028566122055, 56.09609730541706, 52.33117952942848, 56.837467923760414, 57.05525703728199, 58.82392533123493, 55.26670441031456, 55.01760497689247, 56.85517117381096, 55.02531856298447, 58.31585839390755, 54.26291987299919, 53.85925233364105, 45.9369320422411, 43.53861093521118, 43.55323255062103, 41.33296228945255, 43.88505734503269, 44.04008902609348, 42.291567251086235, 42.048494294285774, 42.33900770545006, 44.26449358463287, 42.59883776307106, 43.41636769473553, 45.588589534163475, 43.092378079891205, 44.24525521695614, 44.396836683154106, 44.6214996278286, 44.997424855828285, 44.79064755141735, 43.4490155428648, 44.29488055408001, 44.59378771483898, 42.9293592274189, 43.164494410157204, 43.910648971796036, 45.7315606623888, 43.65622602403164, 43.30865867435932, 43.87009754776955, 46.01982079446316, 43.12253326177597, 43.951758965849876, 42.12451681494713, 40.53883530199528, 43.39641876518726, 42.90896952152252, 43.779035434126854, 44.12127546966076, 49.022377878427505, 53.86416167020798, 55.79879745841026, 53.567587584257126, 55.557434409856796, 57.05325074493885, 55.66532202064991, 51.39434739947319, 47.259637266397476, 47.80097521841526, 50.032663866877556, 50.81735976040363, 47.83807262778282, 48.84007126092911, 46.38189576566219, 44.898937940597534, 43.099229112267494, 43.258041590452194, 41.46655552089214, 43.9800750464201, 40.38482956588268, 42.365279495716095, 43.125443905591965, 41.13112851977348, 42.52192609012127, 42.267126962542534, 40.97295440733433, 38.629867136478424, 40.32314747571945, 41.49163797497749, 38.0512797832489, 41.694296300411224, 41.70961707830429, 41.38091951608658, 42.281672582030296, 39.74877409636974, 39.751331359148026, 39.243310019373894, 42.66789525747299, 44.789948388934135, 49.379927292466164, 49.59469176828861, 55.345728769898415, 54.07481096684933, 53.08532886207104, 50.97515769302845, 49.00309391319752, 46.864139288663864, 49.722250923514366, 47.66289062798023, 50.33184841275215, 51.691130474209785, 53.98584634065628, 50.57093918323517, 50.837548077106476, 48.530410677194595, 51.33499078452587, 53.61347772181034, 54.554333835840225, 55.774813145399094, 54.68470484018326, 20.858291052281857, 0.7884957490023226, 5.164865730330348, 7.234875429421663, 0.4101698216982186, 0.4350661451462656, 1.0924032633192837, 5.599091704934835, 62.38668255507946, 55.5059015750885, 41.73993185162544, 24.7116756811738, 53.14527064561844, 42.69545517861843, 1.1390325799584389, 0.20612129039363936, 0.21567120216786861, 0.1731350674526766, 0.20356050983536988, 0.11336857918649912, 0.22297485556919128, 0.1296374062076211, 0.14698760176543146, 0.15133194130612537, 0.09030521949171089, 0.19513705949066207, 0.18594704481074587, 0.14449358481215313, 0.1503642846364528], [0.037391032674349844, 0.045905856241006404, 0.032537331208004616, 0.029281019124027807, 0.006813481095377938, 0.03010561384144239, 0.020551711168081965, 0.02175419263949152, 0.14531140186591074, 0.035258667994639836, 0.08429394947597757, 0.03679737390484661, 0.0121277626567462, 0.019493581130518578, 0.03286136401584372, 0.035608850375865586, 0.04026088063255884, 0.02293488651048392, 0.16036821267334744, 9.363253321498632, 43.83441746234894, 38.753417506814, 29.07677885144949, 33.030476197600365, 39.41666051745415, 53.81224125623703, 34.71842922270298, 0.609330078586936, 0.4496240842854604, 0.21139944466995075, 0.22696850064676255, 0.37496934179216623, 9.711763970553875, 54.47219364345074, 59.618401899933815, 57.89522096514702, 51.82138368487358, 49.650723561644554, 47.73790240287781, 53.98850239813328, 54.40374031662941, 56.5442718565464, 52.04917386174202, 48.90898056328297, 53.5330056399107, 52.652228102087975, 54.235971719026566, 48.390513584017754, 45.08555732667446, 39.50020283460617, 42.04847909510136, 39.60415005683899, 37.871066853404045, 37.75608882308006, 40.029955208301544, 36.38107180595398, 38.19090709090233, 38.86625625193119, 40.63030019402504, 39.33490790426731, 40.76565273106098, 39.93629403412342, 40.35979650914669, 40.038470551371574, 40.65682277083397, 39.30947586894035, 41.70707881450653, 39.728528782725334, 40.21824650466442, 40.25279805064201, 39.325488209724426, 40.173503905534744, 42.0035807043314, 39.45053569972515, 40.51585413515568, 39.48047809302807, 40.04382826387882, 38.499929308891296, 39.61538225412369, 41.20365522801876, 38.86684902012348, 38.59464682638645, 39.17005755007267, 38.63726153969765, 38.16702537238598, 38.95136408507824, 43.969697803258896, 50.00242508947849, 53.749286234378815, 54.53838229179382, 55.14959469437599, 52.92764492332935, 52.11461015045643, 48.63691136240959, 47.00825795531273, 44.97383572161198, 46.831373646855354, 47.26146496832371, 47.25509651005268, 46.44895076751709, 45.27993969619274, 38.412571996450424, 39.66716967523098, 38.56150880455971, 37.9332011193037, 39.956809133291245, 38.243264481425285, 36.533937603235245, 38.64369459450245, 38.61409418284893, 38.98975342512131, 39.1771137714386, 37.666155248880386, 35.292190834879875, 38.0400437861681, 37.74216637015343, 36.62888690829277, 35.998219549655914, 37.26181514561176, 36.90544366836548, 37.616727501153946, 36.167040690779686, 36.94026879966259, 35.82782529294491, 40.41355602443218, 43.092017099261284, 44.47802692651749, 46.49169847369194, 46.2617652118206, 45.611297115683556, 47.82928369939327, 48.794302716851234, 48.17679405212402, 49.227658063173294, 46.87521189451218, 46.971836909651756, 46.237138733267784, 47.67422541975975, 50.20526580512524, 47.73306526243687, 47.06400856375694, 44.148060232400894, 46.91491596400738, 49.024547562003136, 51.39207512140274, 50.12279123067856, 36.42669215798378, 4.8672685492783785, 0.04357035460998304, 2.2323840111494064, 1.4078639983199537, 0.2088480893871747, 0.18134863843442872, 0.7070065091829747, 8.461263421922922, 58.72157782316208, 39.089961647987366, 27.103736624121666, 28.63421279937029, 51.43133461475372, 12.51954635605216, 0.15774193016113713, 0.08083813881967217, 0.05495434706972446, 0.017224267940036952, 0.04877479135757312, 0.06137904529168736, 0.13155220658518374, 0.027898166081286035, 0.019042468520638067, 0.04945101776684169, 0.040597518818685785, 0.07249169371789321, 0.011812288666988024, 0.03384136260137893, 0.03576865332433954, 0.0056541606136306655, 0.004383710474940017, 0.008967764642875409, 0.05598652234766632, 0.005884336324015749, 0.01722093569696881, 0.04297782761568669, 0.006172129596961895, 0.09520190244074911, 0.023223184907692485, 0.037170069335843436, 0.08773450899752788, 0.057434638001723215, 0.00996680395473959, 0.08272604376543313, 0.02115139432135038, 0.022275093106145505, 0.015867746296862606, 0.1668791484553367, 14.29635001346469, 54.81908082962036, 37.433440536260605, 29.709340408444405, 43.90097849071026, 45.29650680720806, 59.36197265982628, 38.11338745057583, 0.2528241538675502, 0.7339678436983377, 0.3016547695733607, 0.19737303169677034, 0.24531164526706561, 11.18698826059699, 59.93958726525307, 61.35771296918392, 58.75107944011688, 53.45210038125515, 51.82805232703686, 49.402121901512146, 55.22350452840328, 55.77428497374058, 57.31725297868252, 53.798421397805214, 52.26046532392502, 53.021484687924385, 55.493119060993195, 54.608347937464714, 49.556602612137794, 47.253538593649864, 41.71421863138676, 42.98328593373299, 41.553217470645905, 41.3960313051939, 40.718596056103706, 42.735812813043594, 38.74857656657696, 40.24802930653095, 39.4311985373497, 41.73855632543564, 41.68876759707928, 41.420988366007805, 40.82480415701866, 41.32411256432533, 41.63666099309921, 42.12117299437523, 41.115427762269974, 43.6019991338253, 39.62747320532799, 41.91818028688431, 41.497565656900406, 41.026915311813354, 41.53235659003258, 40.971297696232796, 41.119888722896576, 42.48909205198288, 41.32191628217697, 42.18705005943775, 41.21293053030968, 41.83928892016411, 42.545899003744125, 40.44935770332813, 40.829360112547874, 40.0296626240015, 40.09495452046394, 40.52222639322281, 41.00659400224686, 45.07030114531517, 51.47897265851498, 55.27517035603523, 57.196066081523895, 56.97746001183987, 53.32593575119972, 53.34004819393158, 50.370302349328995, 47.47896909713745, 46.51753708720207, 49.055907279253006, 49.66021165251732, 48.31029988825321, 47.97228902578354, 47.66001798212528, 41.31005331873894, 41.651514396071434, 40.5690398812294, 39.75986950099468, 40.87949462234974, 40.922143533825874, 39.415664970874786, 41.06989100575447, 40.32506637275219, 41.41178905963898, 39.6585289388895, 39.22912918031216, 37.41012118756771, 38.476621359586716, 39.92125064134598, 38.861544504761696, 37.87366971373558, 38.240992203354836, 37.94148467481136, 39.210973754525185, 36.78290784358978, 38.22667457163334, 38.25434468686581, 42.12278790771961, 45.134627893567085, 46.6549377143383, 48.324005752801895, 47.880360558629036, 47.942179441452026, 50.66430017352104, 49.92738291621208, 48.234265968203545, 50.21674118936062, 50.077459663152695, 48.00182864069939, 47.699079886078835, 49.151871129870415, 51.758573055267334, 50.08557602763176, 49.61322337388992, 45.81666089594364, 48.77691484987736, 49.636231139302254, 52.91743487119675, 52.20439933240414, 37.6771404594183, 6.476278435438871, 0.6452435546088964, 3.358547631651163, 3.6566779715940356, 0.44877577980514616, 0.3027377708349377, 0.9352853754535317, 9.665635395795107, 62.04986482858658, 46.963021382689476, 32.821772396564484, 23.009325228631496, 58.742970675230026, 15.974926091730595, 0.1507125300122425, 0.06605424539884552, 0.02994910788402194, 0.023794297230779193, 0.06522462819702923, 0.03260511897678953, 0.041949466976802796, 0.02911873183620628, 0.06371525567374192, 0.0017219048322658637, 0.06644307883107103, 0.05118780660268385, 0.009365389742015395, 0.05807567918964196, 0.05692189559340477, 0.16695260623237118, 0.10553572996286675, 0.17111979512264952, 0.14226904168026522, 0.16143003304023296, 0.13540319603634998, 0.1072011019277852, 0.1033263340650592, 0.20271771209081635, 0.1712310579023324, 0.14615265594329685, 0.11366884471499361, 0.09532335490803234, 0.12389638926833868, 0.1398665612214245, 0.06992904294747859, 0.13174466032069176, 0.24407760211033747, 0.4197641584323719, 17.315942533314228, 64.98089075088501, 46.28690846264362, 39.28814001381397, 46.11160106956959, 49.603328704833984, 63.416043519973755, 42.699061185121536, 0.7399219460785389, 1.112853647209704, 0.8603840915020555, 0.4773947159992531, 0.48795663518831134, 12.071865778416395, 60.310093984007835, 63.76638472080231, 62.22878582775593, 57.471114322543144, 55.55063657462597, 52.48150706291199, 56.568826138973236, 57.94211804866791, 57.913585379719734, 55.18145598471165, 54.848445653915405, 56.61781311035156, 56.54793106019497, 57.26154036819935, 52.84375682473183, 48.963868618011475, 44.72318597137928, 45.88288374245167, 44.36726666986942, 44.13042537868023, 43.67691591382027, 45.21842859685421, 40.48773564398289, 43.36079567670822, 43.16111259162426, 43.773453533649445, 43.778324872255325, 44.33831602334976, 43.34927849471569, 44.81068007647991, 44.299824088811874, 43.09449836611748, 42.32033170759678, 46.731344014406204, 41.54576227068901, 43.70219975709915, 44.75379332900047, 42.54661716520786, 44.20245051383972, 44.27193358540535, 43.36456507444382, 43.90562184154987, 45.449490398168564, 43.67173679172993, 42.932794243097305, 43.805542811751366, 44.55871939659119, 42.438262179493904, 42.38684333860874, 42.58576646447182, 43.47693644464016, 41.14600092172623, 42.892543002963066, 47.68295355141163, 51.80160954594612, 56.12627528607845, 58.184913620352745, 58.36564712226391, 55.39394058287144, 54.612653106451035, 52.6014020293951, 51.04241408407688, 48.22139985859394, 50.921781957149506, 51.07763059437275, 50.15663601458073, 52.24868595600128, 49.5873049646616, 43.23390528559685, 43.689314648509026, 41.960874795913696, 42.099449560046196, 42.793824300169945, 42.06289932131767, 41.223835945129395, 41.50583781301975, 42.735436633229256, 43.56458254158497, 41.9117396324873, 42.15358145534992, 39.18618008494377, 41.147011667490005, 40.95378063619137, 40.28663143515587, 38.99963289499283, 40.08470647037029, 40.546491891145706, 42.00843684375286, 39.1461568325758, 41.12438768148422, 39.81020539999008, 45.11818237602711, 47.570357993245125, 48.204802349209785, 49.64856147766113, 49.80004034936428, 47.70650468766689, 51.699482426047325, 52.07751274108887, 50.749909579753876, 54.29709903895855, 51.50863766670227, 48.669012039899826, 49.48716513812542, 50.694531351327896, 53.61191600561142, 51.658543422818184, 52.57802948355675, 48.235991075634956, 51.427854001522064, 53.6845301091671, 54.84162122011185, 53.37078474462032, 39.493389800190926, 6.926096398383379, 0.5857252108398825, 6.084392163902521, 4.634933341294527, 0.4195732483640313, 0.5491144128609449, 1.3303283276036382, 12.267568577080965, 68.48929569125175, 49.336108043789864, 38.36782559752464, 35.25603957474232, 66.45005151629448, 19.69658888876438, 0.30900764220859855, 0.12605565309058875, 0.12052742473315448, 0.11152193765155971, 0.18488170666387305, 0.16148493712535128, 0.21081439481349662, 0.09471077137277462, 0.1307533439830877, 0.15967921761330217, 0.11851218208903447, 0.17754336528014392, 0.08592565020080656, 0.12344658098299988, 0.11948981322348118], [0.010795407197292661, 0.05569220142206177, 0.07512551645049825, 0.033405265494366176, 0.015289764469343936, 0.04593558667693287, 0.05168047020561062, 0.029856413639208768, 0.039507530236733146, 0.030536395315721165, 0.02676797164895106, 0.10356019964092411, 0.03817571283434518, 0.024054124987742398, 0.05900660326005891, 0.02621130337502109, 0.1328672922682017, 0.01427884151780745, 0.042477787064854056, 0.34713479632046074, 31.36978290975094, 46.857254058122635, 29.415074698626995, 30.991100929677486, 32.24751681089401, 47.93671153485775, 49.788124188780785, 1.9745585834607482, 0.29214165348093957, 0.2236450742930174, 0.04084869498910848, 0.03096498374361545, 0.39464599220082164, 24.579457975924015, 60.156460627913475, 55.74724182486534, 52.973789647221565, 52.229660376906395, 47.033773586153984, 49.13661114871502, 54.027104526758194, 55.59273451566696, 56.499802842736244, 51.83935672044754, 52.12263152003288, 52.73736633360386, 54.39454101026058, 51.55306488275528, 48.038219287991524, 42.95863285660744, 40.78334838151932, 39.235653430223465, 39.044177904725075, 39.609249383211136, 37.24722772836685, 38.45192268490791, 40.59178166091442, 39.40336883068085, 38.67833353579044, 40.21484188735485, 40.46977020800114, 41.25598222017288, 42.69091062247753, 40.53308621048927, 39.94170494377613, 42.17205226421356, 41.75424188375473, 39.83676977455616, 40.13774782419205, 38.64647604525089, 41.825548857450485, 38.62187996506691, 42.16543301939964, 39.975469931960106, 40.003029853105545, 39.20749694108963, 40.70034183561802, 42.29826249182224, 42.8018494695425, 42.635536193847656, 40.202427953481674, 39.339517056941986, 39.20222282409668, 40.61496801674366, 40.10288089513779, 42.17743277549744, 46.924844831228256, 52.20443733036518, 52.52735920250416, 51.261787712574005, 52.68046818673611, 55.1693270355463, 54.10167172551155, 52.64629282057285, 48.93505856394768, 47.03348480165005, 49.41911838948727, 48.40334929525852, 49.040616899728775, 49.032994508743286, 48.188979998230934, 41.111802756786346, 37.952728271484375, 39.11976344883442, 38.76520827412605, 38.58317144215107, 39.34766001999378, 38.93110357224941, 36.53428338468075, 38.02679009735584, 41.00078031420708, 36.85644909739494, 37.93932259082794, 37.80889078974724, 36.707937866449356, 35.65833158791065, 36.86032108962536, 36.56221188604832, 35.33118814229965, 35.359591618180275, 36.86656795442104, 34.771626368165016, 36.28049120306969, 37.40630239248276, 40.43108448386192, 42.61271841824055, 44.8976232111454, 46.773730739951134, 47.39545717835426, 46.599073112010956, 48.64822715520859, 45.53661212325096, 46.83489605784416, 48.21565456688404, 47.60196849703789, 48.693691715598106, 48.42943109571934, 49.28706407546997, 47.49587818980217, 46.493571773171425, 47.86708407104015, 46.80393911898136, 47.762528881430626, 48.74087758362293, 51.43161199986935, 45.31870521605015, 21.385381668806076, 1.0513752023689449, 0.8595994929783046, 2.34142177272588, 2.043889663182199, 0.4731084866216406, 0.1516285035177134, 0.32472478633280843, 24.982952624559402, 54.9940500408411, 29.993306770920753, 28.69030348956585, 34.29175391793251, 39.46572728455067, 2.0646384498104453, 0.0496110730455257, 0.08435723240836523, 0.0662519980687648, 0.06507305195555091, 0.03854992966807913, 0.10284337404300459, 0.05878903524717316, 0.05657726447680034, 0.047871434362605214, 0.12004102114588022, 0.012833298333134735, 0.048732333088992164, 0.02308326780621428, 0.04054720120620914, 0.030056567156862002, 0.0187728277160204, 0.06030813732650131, 0.02348071757296566, 0.02698900549148675, 0.0071725919769960456, 0.0374262550030835, 0.05663133364578243, 0.06432326015783474, 0.01580148920766078, 0.02110559267748613, 0.0034685013815760612, 0.027137262477481272, 0.02591539239801932, 0.01919303544127615, 0.040045145724434406, 0.041140667017316446, 0.015500415665883338, 0.06666524815955199, 0.04977497264917474, 1.379118065815419, 41.251259073615074, 51.96500077843666, 27.81210981309414, 41.088057830929756, 38.56240175664425, 53.376009464263916, 51.96359485387802, 1.850406895391643, 0.4026750801131129, 0.34901839680969715, 0.07940211275126785, 0.04865161710768007, 0.3941235796082765, 28.14879074692726, 63.34478214383125, 56.99111267924309, 54.638731107115746, 53.310656771063805, 49.000863432884216, 51.44547365605831, 56.55505187809467, 55.06183460354805, 56.86561681330204, 52.21468538045883, 52.47550718486309, 55.09925499558449, 56.09892435371876, 54.14102241396904, 50.17416447401047, 43.2948312163353, 42.97637790441513, 42.04516567289829, 41.12274996936321, 40.017400681972504, 39.92220439016819, 40.75168468058109, 40.44825576245785, 41.82864189147949, 40.98979890346527, 41.42391040921211, 43.21573086082935, 43.225997909903526, 44.04412440955639, 43.94753359258175, 42.16583199799061, 41.87496520578861, 43.15698601305485, 41.51351720094681, 42.69005186855793, 39.61729355156422, 42.74630405008793, 39.63735647499561, 43.62520448863506, 41.22379034757614, 42.95512564480305, 40.32097779214382, 42.8575848788023, 44.26796279847622, 45.42963266372681, 44.30891700088978, 42.14521050453186, 41.714028641581535, 41.424385383725166, 41.03845529258251, 40.89494839310646, 44.25595924258232, 48.722098991274834, 52.61352717876434, 55.96281945705414, 54.24786888062954, 51.710304245352745, 55.330867767333984, 56.38696409761906, 51.95768617093563, 49.965434074401855, 50.49661137163639, 50.869774147868156, 51.55929274857044, 49.38517101109028, 50.894066244363785, 49.123821035027504, 44.30932357907295, 41.72501005232334, 40.8631706982851, 40.81592783331871, 39.66784603893757, 41.01581230759621, 39.26262058317661, 38.32001656293869, 39.505514949560165, 40.66292904317379, 39.184261187911034, 40.7232242077589, 38.792840391397476, 37.52953737974167, 38.72697472572327, 39.45346154272556, 37.56752014160156, 37.75478929281235, 36.637835428118706, 40.02645179629326, 36.404607743024826, 38.00927683711052, 40.69371499121189, 42.25983515381813, 45.598871782422066, 47.20672510564327, 47.929393127560616, 48.02091881632805, 48.292543441057205, 48.98743115365505, 48.342305570840836, 49.16036747395992, 49.22660171985626, 50.156472623348236, 50.14834485948086, 51.46015606820583, 51.444044932723045, 50.424213856458664, 49.102770164608955, 48.439872935414314, 47.48613551259041, 49.76709611713886, 51.62409447133541, 53.18581826984882, 48.14395621418953, 22.348314598202705, 1.9732899265363812, 2.4466065410524607, 6.392348539084196, 6.0404969193041325, 1.4490559254772961, 0.2961300441529602, 0.30146320641506463, 26.365825720131397, 60.39059266448021, 40.15429973602295, 30.406443402171135, 33.00857417285442, 50.02423971891403, 2.6322351302951574, 0.022862707082822453, 0.04617267317371443, 0.07028358915704302, 0.04588476811477449, 0.042305764654884115, 0.053453089931281283, 0.013705690143979155, 0.059266878160997294, 0.03335061002871953, 0.08031189674511552, 0.02016874812397873, 0.048479924953426234, 0.0819636057713069, 0.07224118176964112, 0.03352908170199953, 0.1074687871732749, 0.19551689067156985, 0.1426187713514082, 0.1920977866393514, 0.08314944643643685, 0.17273971054237336, 0.21613893331959844, 0.11378797426004894, 0.09775327998795547, 0.17377953365212306, 0.1486967084929347, 0.17490832542534918, 0.14116659614956006, 0.08677183956024237, 0.20107253396417946, 0.11425000571762212, 0.21200880728429183, 0.10848829770111479, 0.11396007830626331, 1.5409750118851662, 49.3976229429245, 61.67544811964035, 38.034081906080246, 42.278739139437675, 42.93418496847153, 57.271511033177376, 61.562955155968666, 3.0981433298438787, 0.8207259757909924, 1.6974084614776075, 1.0464199120178819, 0.12662756693316624, 0.6178403156809509, 29.306254237890244, 63.919296115636826, 58.98924306035042, 56.733281314373016, 56.12173832952976, 50.41885234415531, 53.57063502073288, 57.683085948228836, 57.669991850852966, 57.71236717700958, 54.978736862540245, 55.62933035194874, 59.449831545352936, 59.64436210691929, 55.21713227033615, 52.566614896059036, 45.86017996072769, 44.95300903916359, 43.60030822455883, 44.338593408465385, 43.63240510225296, 41.35836772620678, 42.08018459379673, 44.23275388777256, 43.883328437805176, 42.65489235520363, 44.64421860873699, 45.82226939499378, 45.33987767994404, 45.37971094250679, 45.55997706949711, 43.80966559052467, 46.12016201019287, 46.114515513181686, 43.37949447333813, 43.548148423433304, 40.680864080786705, 44.508562088012695, 41.63585923612118, 45.685940310359, 44.13387179374695, 44.138507544994354, 42.531030401587486, 45.229512602090836, 45.99324122071266, 47.73749962449074, 46.58918224275112, 45.081392750144005, 42.462204694747925, 44.46241356432438, 45.47425366938114, 44.044044613838196, 45.85091605782509, 51.64402820169926, 55.32737195491791, 56.78680144250393, 55.59768944978714, 53.21334779262543, 57.13886395096779, 58.77555772662163, 54.46070685982704, 53.7598230689764, 51.229561641812325, 53.41285228729248, 52.62229710817337, 52.57244758307934, 53.51507820188999, 51.51151791214943, 46.264881044626236, 42.94065602123737, 41.3679014146328, 43.73187616467476, 41.35187767446041, 43.89480762183666, 41.73255644738674, 37.857904359698296, 40.92222332954407, 44.016792476177216, 40.71587920188904, 43.43190886080265, 40.22080756723881, 40.01349449157715, 39.49090473353863, 40.9501214325428, 40.42228415608406, 38.41697596013546, 37.57636986672878, 42.38349951803684, 37.47035935521126, 40.98275028169155, 42.68288545310497, 44.985675886273384, 46.55276119709015, 48.88355992734432, 51.36431761085987, 50.435970425605774, 50.78806333243847, 51.307552456855774, 49.118907898664474, 51.758128479123116, 51.06721915304661, 51.39940492808819, 51.9248141348362, 53.38880717754364, 54.78863686323166, 52.15220533311367, 49.482951164245605, 52.293261364102364, 51.54456853866577, 52.3058994859457, 53.502052500844, 54.871795400977135, 47.428747192025185, 24.372450783848763, 2.000937480479479, 2.912594061344862, 6.189197190105915, 7.565297624096274, 2.2609363915398717, 0.34122928977012634, 0.5919407866895199, 31.565244421362877, 63.86963278055191, 40.36850184202194, 39.548939019441605, 41.936005130410194, 56.64207100868225, 4.025562414899468, 0.2031545847421512, 0.21195436333073303, 0.19460246083326638, 0.1521778412279673, 0.13269834977108985, 0.27207570208702236, 0.13138685608282685, 0.1877407415304333, 0.154432263225317, 0.2109164698049426, 0.08593413294875063, 0.22199826344149187, 0.11373411660315469, 0.10331794037483633, 0.12552639789646491], [0.03148110663460102, 0.039371746897813864, 0.021635029697790742, 0.0588812285423046, 0.05268319706374314, 0.02895265588449547, 0.09280515878344886, 0.026523454398557078, 0.03503481770167127, 0.04072100105986465, 0.006667765965175931, 0.14840643969364464, 0.04398792028950993, 0.045528670816565864, 0.032161348062800243, 0.01810990430385573, 0.019941040518460795, 0.07418426539516076, 0.06707604174152948, 0.16053307335823774, 8.682028725743294, 44.251433685421944, 35.432334914803505, 29.042664282023907, 39.92058947682381, 34.29490774869919, 62.35268197953701, 10.590786002576351, 0.17072365153580904, 0.24019516044063494, 0.4664423380745575, 0.15728412894532084, 0.11209279764443636, 1.9992358842864633, 37.451234981417656, 61.335419565439224, 55.489209070801735, 55.75488321483135, 50.63442997634411, 48.82229961454868, 51.105110719799995, 56.2903618812561, 55.7171094417572, 54.65769588947296, 49.15693245828152, 52.26084150373936, 51.6828279197216, 53.80875684320927, 50.82247048616409, 41.75072707235813, 39.24204848706722, 40.549201145768166, 38.37110482156277, 39.15517754852772, 40.04041224718094, 40.561387091875076, 41.0456483066082, 40.374326929450035, 40.703100487589836, 38.924716114997864, 41.01800099015236, 42.33543209731579, 42.72328108549118, 41.56511463224888, 42.06567317247391, 40.89006565511227, 39.90552328526974, 40.962911546230316, 41.01464956998825, 39.402510076761246, 41.465312987565994, 40.29440201818943, 39.560497999191284, 39.7821819037199, 40.59045173227787, 40.06480693817139, 41.37815706431866, 43.98450940847397, 44.60304021835327, 46.39569662511349, 44.56064589321613, 41.47668957710266, 40.1505683362484, 39.516705349087715, 43.66582430899143, 45.04980884492397, 51.10609486699104, 54.42072920501232, 55.01529850065708, 58.92328999936581, 55.76854348182678, 50.82792319357395, 53.92997033894062, 52.022723481059074, 50.235295593738556, 49.90044616162777, 51.20403841137886, 49.81897093355656, 48.8536973297596, 47.83132418990135, 49.55950565636158, 43.0597872287035, 36.66196033358574, 38.91834765672684, 37.730048820376396, 37.97361955046654, 39.269859194755554, 37.231306582689285, 36.936499401926994, 39.518384858965874, 38.6336213350296, 37.80272752046585, 35.67455671727657, 36.67593978345394, 37.88790374994278, 36.351904571056366, 37.72068992257118, 37.532159239053726, 35.41730672121048, 36.82203434407711, 36.10184758901596, 37.61473260819912, 34.58376444876194, 36.6686137765646, 42.554790526628494, 45.339539498090744, 48.717581033706665, 47.47405216097832, 49.546552151441574, 47.917678356170654, 49.35636095702648, 47.1648171544075, 47.20004126429558, 48.27546335756779, 47.2176419198513, 47.143716886639595, 46.23444467782974, 46.90221704542637, 47.84301616251469, 45.85846625268459, 44.12373773753643, 47.51105077564716, 46.47418901324272, 47.896756678819656, 49.92853805422783, 38.21996413171291, 7.073189355432987, 0.39190304407384247, 1.3988975482061505, 1.3757337536662817, 3.220296800136566, 0.3211422613821924, 0.21391783375293016, 2.744673709385097, 50.068077966570854, 42.683265432715416, 30.198273472487926, 25.60508754104376, 38.729057013988495, 16.53440047055483, 0.16188667650567368, 0.09255525539629161, 0.03255369185353629, 0.05725653740228154, 0.07679053218453191, 0.025611069177102763, 0.01766633376973914, 0.023818630397727247, 0.05253126088064164, 0.019321109721204266, 0.025383792017237283, 0.11687633275869302, 0.07347587801632471, 0.04230767939588986, 0.05516775534488261, 0.03579577511118259, 0.048157376440940425, 0.02530932306399336, 0.019261858506069984, 0.031341349094873294, 0.022409290104405954, 0.032932291069300845, 0.04898914216028061, 0.03817762015387416, 0.035608423640951514, 0.0199185534438584, 0.07435521169099957, 0.04113544229767285, 0.0278876609809231, 0.08587317293859087, 0.08659007275127806, 0.04970332942320965, 0.02174457626097137, 0.022015326576365624, 0.09414773361640982, 0.3070975618902594, 13.678041491657495, 53.2844989746809, 33.96327294409275, 30.56833751499653, 51.953358203172684, 40.48445262014866, 67.94384256005287, 9.758312422782183, 0.17548654752317816, 0.7596905634272844, 1.0118282306939363, 0.1606186429853551, 0.07013343783910386, 3.4126161178573966, 42.133982107043266, 62.40353465080261, 56.72111436724663, 56.76174558699131, 52.58682981133461, 50.34580506384373, 54.40374031662941, 57.7626346796751, 55.544150322675705, 56.40372879803181, 52.429480254650116, 53.36826927959919, 55.00025510787964, 55.74278466403484, 52.38284915685654, 44.435989782214165, 39.90966126322746, 43.260769844055176, 41.727715507149696, 41.703917384147644, 41.57045714557171, 42.160770669579506, 42.91227534413338, 41.90000206232071, 40.88093474507332, 42.165151834487915, 43.346143662929535, 44.54068176448345, 43.480637446045876, 43.7883373349905, 42.48405732214451, 42.42234863340855, 41.75149843096733, 41.682934910058975, 41.9547039270401, 40.51034063100815, 43.47860835492611, 41.12221419811249, 41.915467232465744, 43.00736144185066, 43.08080770075321, 41.96017183363438, 42.329272627830505, 46.283530443906784, 46.17317296564579, 47.825134322047234, 45.78091621398926, 43.47064018249512, 41.57647982239723, 41.071403324604034, 44.74327549338341, 44.13411498069763, 52.432360500097275, 56.23166263103485, 55.16884446144104, 57.563065588474274, 57.53221124410629, 52.90516532957554, 55.48115350306034, 53.21570746600628, 52.6777209341526, 51.73975646495819, 52.01782554388046, 52.52031438052654, 51.487639993429184, 52.400537207722664, 49.1841845959425, 44.32055577635765, 39.610989689826965, 40.744981840252876, 40.14674574136734, 40.72417035698891, 39.25718307495117, 39.965453669428825, 39.26412530243397, 40.85422597825527, 40.75036235153675, 38.83039377629757, 37.68432967364788, 38.569070398807526, 40.17903260886669, 39.54494923353195, 39.11960385739803, 38.395328521728516, 37.99679450690746, 38.53805646300316, 36.678318455815315, 37.77196817100048, 37.27030009031296, 38.609382435679436, 45.75519159436226, 46.1664929240942, 49.22419644892216, 49.74224165081978, 51.54650643467903, 50.143051743507385, 50.51661729812622, 49.24744740128517, 50.7093695551157, 48.79908286035061, 48.43120560050011, 49.65707682073116, 47.87935361266136, 48.60898666083813, 50.06135232746601, 49.0590763092041, 47.64098480343819, 48.97440545260906, 49.462876841425896, 50.331954807043076, 51.71860679984093, 40.81233702600002, 8.01876861602068, 0.7133733050432056, 4.5540589559823275, 5.986820524558425, 8.783029206097126, 0.4398905503330752, 0.2709235029760748, 3.394510089419782, 56.17547124624252, 47.25453794002533, 38.983381167054176, 23.45281273126602, 43.63450638949871, 22.44277562946081, 0.25442523357924074, 0.09171326659270562, 0.07635910689714365, 0.03260761259298306, 0.05860822580871172, 0.032431018553324975, 0.033351073871017434, 0.0549958368355874, 0.05113937775604427, 0.04061595376697369, 0.07763923742459156, 0.05167494491615798, 0.05946968485659454, 0.06336813836242072, 0.10352660261560231, 0.032297921788995154, 0.15229992452077568, 0.16012391250114888, 0.10740865094703622, 0.18565215985290706, 0.15172925748629496, 0.18063823983538896, 0.1804851644556038, 0.1957392826443538, 0.17037472338415682, 0.12349867974990048, 0.15834234247449785, 0.18048911268124357, 0.24978105153422803, 0.27223452168982476, 0.20734507706947625, 0.12126808069297113, 0.10563284740783274, 0.21818960609380156, 0.26340750628151, 0.4793833749135956, 15.723748169839382, 60.048481822013855, 44.32030498981476, 37.474584728479385, 56.1612144112587, 41.70671783387661, 72.18136757612228, 13.383786231279373, 0.3424308862304315, 2.9147787066176534, 1.4784279931336641, 0.5314988549798727, 0.1940244168508798, 3.795242286287248, 42.77754597365856, 65.26220485568047, 58.90120938420296, 60.18914267420769, 55.17904691398144, 54.025725200772285, 56.2231282889843, 60.59447452425957, 58.080339431762695, 57.10518255829811, 53.21600764989853, 55.888202860951424, 57.48127497732639, 57.66299642622471, 54.57135692238808, 46.33861988782883, 42.8039887547493, 44.548684135079384, 44.55485500395298, 43.06387580931187, 44.75658617913723, 45.32207943499088, 46.189443692564964, 45.22863104939461, 43.010006099939346, 43.29318210482597, 45.10202944278717, 46.85441181063652, 45.64920388162136, 44.6741534024477, 46.17650158703327, 44.609826654195786, 43.3669513463974, 42.552347257733345, 45.83450473845005, 42.97268070280552, 44.76394258439541, 42.051051557064056, 44.26536753773689, 44.86592911183834, 45.331050753593445, 43.935799822211266, 45.1784623414278, 48.430612832307816, 47.9632531106472, 50.581707805395126, 48.26918229460716, 45.48359736800194, 44.15406011044979, 45.368695333600044, 48.1415281444788, 47.683154940605164, 55.04015676677227, 60.137959420681, 57.759651839733124, 61.61104157567024, 57.493711709976196, 52.83650301396847, 57.71904341876507, 54.91407573223114, 55.39142891764641, 53.42192240059376, 54.47438232600689, 53.15663203597069, 52.23211884498596, 54.100482389330864, 52.34166316688061, 48.43606933951378, 40.567698553204536, 44.24927920103073, 41.03557124733925, 41.48331642150879, 42.97474019229412, 40.60957610607147, 41.35720878839493, 43.19235071539879, 44.07686725258827, 41.28350414335728, 38.935838118195534, 40.42767606675625, 42.49725021421909, 41.01944871246815, 41.601737067103386, 41.199312061071396, 39.61821690201759, 40.46501286327839, 38.144135400652885, 40.95995910465717, 39.479163363575935, 40.1320481300354, 48.204973340034485, 48.16194824874401, 51.634148731827736, 52.20381036400795, 54.178268015384674, 51.26642346382141, 52.16229759156704, 51.87300771474838, 53.06633748114109, 51.58449299633503, 50.55276855826378, 51.602659821510315, 49.861475452780724, 51.42237849533558, 53.65791633725166, 52.217801213264465, 49.21774439513683, 51.90944775938988, 52.89410412311554, 52.38331653177738, 51.468929797410965, 42.197187915444374, 8.76808175817132, 1.7966887028887868, 4.268603548407555, 6.7817948665469885, 15.428430866450071, 1.2577610090374947, 0.5606311198789626, 6.608096687123179, 61.164269149303436, 51.46267153322697, 42.816497683525085, 31.680300347507, 53.0059739202261, 29.484360180795193, 0.33293840184342116, 0.24640613497467712, 0.21441697259433568, 0.17793763865483925, 0.17549061449244618, 0.11416055465815589, 0.11834143617306836, 0.12884102237876505, 0.18736692174570635, 0.1241846097400412, 0.17304424342000857, 0.31724085041787475, 0.2541521826060489, 0.10979058875818737, 0.20777626486960799, 0.09888213855447248], [0.07324371938011609, 0.03277147137850989, 0.05924646167841274, 0.08206899074139073, 0.017391303117619827, 0.011564806536625838, 0.02846166396921035, 0.0535559998388635, 0.14235017326427624, 0.0396035047742771, 0.017400387005181983, 0.06048355506209191, 0.04494280459766742, 0.0878700400062371, 0.028481256667873822, 0.03359240545250941, 0.033453738869866356, 0.07797073994879611, 0.035485772605170496, 0.1778733092942275, 1.0915072239004076, 26.87754426151514, 39.81482595205307, 31.65846671909094, 39.06033843755722, 32.39413574337959, 48.31818826496601, 29.662612415850163, 0.13210467615863308, 0.41985778778325766, 0.36170918145217, 0.04836190120840911, 0.0709652814839501, 0.02342837575270096, 6.866376427933574, 50.519698932766914, 59.42336216568947, 54.982912838459015, 51.71531617641449, 51.802882477641106, 49.501497969031334, 55.37912517786026, 55.27036361396313, 55.39610266685486, 54.17085841298103, 52.434495985507965, 51.8594766408205, 53.16975653171539, 52.216642275452614, 41.58285968005657, 39.259740337729454, 40.6495613604784, 40.41812717914581, 39.6037282794714, 40.90942941606045, 38.89970205724239, 41.847963854670525, 43.93692456185818, 40.764068216085434, 41.61863096058369, 42.330815345048904, 42.16577500104904, 40.24354934692383, 40.87063729763031, 41.61817118525505, 41.14309407770634, 39.350585862994194, 40.170802250504494, 37.90486603975296, 38.800455182790756, 39.781395345926285, 41.114690601825714, 41.194885298609734, 40.21727755665779, 42.36940607428551, 40.66207028925419, 42.60338991880417, 46.00632391870022, 45.208047553896904, 47.349555641412735, 45.28010308742523, 44.274243861436844, 41.13533869385719, 40.669236704707146, 44.57161970436573, 47.33790926635265, 51.81506462395191, 52.46063858270645, 53.08443211019039, 51.05015426874161, 53.10186557471752, 53.340644761919975, 53.696412071585655, 51.03412672877312, 53.08766573667526, 48.72851304709911, 52.14765317738056, 52.58560627698898, 53.02689179778099, 50.72597846388817, 51.820528730750084, 41.83779560029507, 36.73913039267063, 40.33372990787029, 38.08442160487175, 38.11239950358868, 38.14462557435036, 37.34932824969292, 37.70859517157078, 38.884704262018204, 38.433600068092346, 34.94428530335426, 36.41215033829212, 36.827251464128494, 38.28482285141945, 36.45403929054737, 36.22789062559605, 37.25337579846382, 35.6690888106823, 34.729794412851334, 35.746684446930885, 35.53478881716728, 34.47586163878441, 34.514292776584625, 38.73389795422554, 43.9366889744997, 48.28131504356861, 48.40103901922703, 38.68744544684887, 46.939249858260155, 48.27430821955204, 48.49633030593395, 45.44698253273964, 47.274581864476204, 46.25768043100834, 45.9540007263422, 48.40212196111679, 46.639461144804955, 45.17500452697277, 46.92250035703182, 44.278043657541275, 47.421706169843674, 47.672032937407494, 51.72144524753094, 47.38281525671482, 22.49099314212799, 1.1772644659504294, 0.9347579756285995, 4.090399285778403, 8.110144212841988, 9.888561833649874, 0.44876595376990736, 0.07563386534457095, 11.536497306078672, 52.74740159511566, 35.56076802313328, 26.875154189765453, 29.389218986034393, 41.63840889930725, 4.109432464465499, 0.09778391584404744, 0.05259622477751691, 0.1225683382654097, 0.03855128408758901, 0.024004727638384793, 0.032214185266639106, 0.05016619208618067, 0.07193368772277609, 0.01960563244210789, 0.021989472006680444, 0.04892952914815396, 0.014298300629889127, 0.06842448696261272, 0.026028764732473064, 0.04572824174829293, 0.05068997394118924, 0.028244138629816007, 0.031880170572549105, 0.054972080688457936, 0.054596364716417156, 0.016440795625385363, 0.017670365486992523, 0.06890906486660242, 0.015681333643442485, 0.022549693312612362, 0.0340550528926542, 0.07339883566601202, 0.059420988836791366, 0.02245432733616326, 0.022968926969042514, 0.06008165240928065, 0.02366709682974033, 0.034656326097319834, 0.030569780828955118, 0.021674793970305473, 0.1043266971828416, 1.9227431388571858, 37.798692137002945, 44.927151426672935, 31.92312441766262, 48.55931952595711, 38.377302289009094, 54.53761473298073, 29.706743247807026, 0.22554474970092997, 0.7687207194976509, 0.7384462002664804, 0.05076129804365337, 0.12571404251502827, 0.07613459980348125, 8.508720975369215, 54.258018136024475, 60.205983370542526, 57.40619480609894, 53.81001837551594, 53.51252853870392, 51.43049865961075, 56.925611793994904, 55.370298251509666, 56.271507292985916, 54.31288339197636, 55.26277542114258, 54.99186135828495, 54.99287970364094, 54.57829914987087, 43.33579681813717, 41.198213919997215, 42.91149638593197, 42.501813769340515, 41.26739680767059, 42.16969259083271, 42.44006708264351, 44.19990465044975, 46.397881507873535, 42.63375788927078, 42.811231166124344, 41.66731774806976, 44.78913143277168, 42.249480709433556, 41.713033095002174, 42.732237204909325, 41.97646915912628, 40.58108903467655, 42.62517035007477, 41.03324197232723, 40.78511528670788, 41.60509988665581, 42.06853061914444, 42.23407633602619, 40.67583695054054, 42.92821168899536, 42.203001603484154, 43.02612863481045, 46.77222982048988, 48.20575229823589, 48.98183025419712, 48.06021250784397, 46.57642252743244, 44.661929458379745, 43.43834571540356, 45.651609152555466, 48.63653898239136, 53.52269299328327, 55.22671155631542, 58.446567580103874, 52.03191518783569, 47.80372627079487, 54.09300059080124, 57.446700632572174, 52.610646933317184, 53.9925529807806, 50.25755099952221, 54.13589268922806, 54.10530053079128, 55.57360254228115, 51.048600152134895, 51.13177388906479, 43.56809355318546, 38.59998933970928, 40.58358170092106, 40.53638443350792, 40.54639309644699, 41.0758338868618, 39.899082630872726, 38.38946923613548, 41.10994465649128, 39.31438520550728, 37.93280974030495, 38.148140385746956, 40.156055241823196, 38.00578482449055, 39.460692554712296, 39.68011178076267, 37.78147906064987, 37.429933324456215, 36.723802015185356, 38.45152750611305, 36.736227348446846, 37.15667478740215, 36.70200638473034, 41.481298729777336, 44.87110063433647, 49.02309224009514, 50.5630774050951, 41.26502953469753, 48.73319059610367, 50.279662013053894, 50.45227915048599, 47.89057061076164, 48.934234008193016, 48.45137111842632, 48.16189885139465, 51.61079898476601, 49.66852940618992, 47.797840386629105, 48.37445564568043, 46.75522193312645, 49.393838346004486, 49.88576374948025, 53.08743014931679, 48.00553344190121, 24.917077459394932, 2.022768259048462, 1.6407682257704437, 6.874595861881971, 7.209308026358485, 9.259738326072693, 0.5859459552448243, 0.07493004959542304, 14.326862376183271, 58.28843906521797, 45.366012677550316, 36.56066156923771, 28.98106198757887, 51.19765095412731, 5.961065981537104, 0.14357103587826714, 0.056733720339252613, 0.03802380262641236, 0.10058609477709979, 0.02508608504285803, 0.039258539691218175, 0.028646748178289272, 0.04125250125071034, 0.06793458043830469, 0.1040687711792998, 0.08045563590712845, 0.048658225932740606, 0.03222579245630186, 0.06593893791432492, 0.03270302309829276, 0.028727009594149422, 0.18984505673870444, 0.21337970247259364, 0.2120484082843177, 0.26638791197910905, 0.12031621692585759, 0.13680849719094113, 0.10490570595720783, 0.09895213050185703, 0.21136974391993135, 0.13369640480959788, 0.13105980644468218, 0.10859118163352832, 0.16704151552403346, 0.10798661329317838, 0.1479506868054159, 0.14686035312479362, 0.10796291651786305, 0.16395179147366434, 0.15331363887526095, 0.20651684026233852, 2.0175558887422085, 44.61025983095169, 52.903558015823364, 41.380436941981316, 50.324416011571884, 43.820920586586, 57.38031819462776, 39.32734631001949, 0.28623424703255296, 1.6689741122536361, 1.415583046618849, 0.08823247524560429, 0.24420309928245842, 0.10976995705277659, 9.422574788331985, 56.397424936294556, 62.72747106850147, 60.12988865375519, 55.50669953227043, 56.25123918056488, 53.3778827637434, 59.218746945261955, 58.441578447818756, 56.73933818936348, 56.051920875906944, 57.22521811723709, 57.00402058660984, 57.908064275979996, 55.82503505051136, 46.31109036505222, 44.47115309536457, 45.79116806387901, 45.690127685666084, 43.09670604765415, 44.888648092746735, 44.67520214617252, 47.33295813202858, 51.17430120706558, 45.767700523138046, 44.971700236201286, 44.951967895030975, 46.27592325210571, 44.179351553320885, 45.276744067668915, 45.03819286823273, 44.98575188219547, 42.71787017583847, 46.56012900173664, 41.89504332840443, 43.216194435954094, 42.21676826477051, 46.03002704679966, 44.176136925816536, 43.650032356381416, 44.40190941095352, 44.092552810907364, 46.42578341066837, 49.62698623538017, 48.6861377209425, 51.461212411522865, 49.76458065211773, 48.26730139553547, 47.993415892124176, 46.26237317919731, 48.165888637304306, 51.02660313248634, 54.56775851547718, 56.195925548672676, 60.39217337965965, 51.96453720331192, 47.50956505537033, 54.01962652802467, 56.899560391902924, 55.29377035796642, 57.32339724898338, 52.02754162251949, 55.327995121479034, 55.728318840265274, 56.47856958210468, 53.00250470638275, 54.43453386425972, 45.378419011831284, 40.17326071858406, 42.69857861101627, 42.73435369133949, 41.502152010798454, 42.83184505999088, 42.6512635499239, 41.79206125438213, 43.87731336057186, 42.62353643774986, 38.95626962184906, 39.331070110201836, 41.51003658771515, 40.55468425154686, 41.13862931728363, 41.564898043870926, 41.24920338392258, 38.4296178817749, 38.33968810737133, 39.60794985294342, 39.26776550710201, 38.3308307826519, 39.91130657494068, 43.437350168824196, 47.7186868339777, 51.09328955411911, 52.69102022051811, 43.91191050410271, 50.92170976102352, 52.93825015425682, 51.70597247779369, 50.38936972618103, 51.59040927886963, 49.743233397603035, 50.30668616294861, 53.793603256344795, 52.13856786489487, 50.880200788378716, 51.04238748550415, 49.90149110555649, 50.41632927954197, 52.57680594921112, 54.80317868292332, 50.042497739195824, 25.12983374297619, 2.326764059253037, 3.1064534839242697, 8.949173390865326, 13.282016292214394, 17.172289341688156, 1.2800324452109635, 0.2581246319459751, 15.641135852783918, 66.31317526102066, 45.69780707359314, 41.40554219484329, 35.526558458805084, 60.876647382974625, 9.607040639966726, 0.36185725475661457, 0.2642254123929888, 0.15138763206778094, 0.2117505102069117, 0.1394351656199433, 0.15354226488852873, 0.13668972387677059, 0.1283879709080793, 0.08486415637889877, 0.17070897185476497, 0.19930270471377298, 0.10114867240190506, 0.10205240789218806, 0.08914772886782885, 0.12978337181266397, 0.20009156316518784], [0.018655013627721928, 0.04539753332210239, 0.035135486323270015, 0.023712054280622397, 0.05317102186381817, 0.0442703520093346, 0.035310651728650555, 0.030603240556956735, 0.07326909340918064, 0.02642762272444088, 0.06143920007161796, 0.04458435840206221, 0.049755580330383964, 0.035521633180906065, 0.04862419104028959, 0.014311100821942091, 0.03167432478221599, 0.032367282910854556, 0.01961380163265858, 0.08242254989454523, 0.036809166631428525, 6.14104094915092, 36.99821189045906, 29.86145194619894, 30.20744428038597, 35.42422994971275, 45.40211074054241, 54.61383104324341, 1.59543119603768, 0.15475539432372898, 0.12986900081159547, 0.07981317350640893, 0.014025115142430877, 0.043575716626946814, 0.13515548198483884, 14.708866328001022, 55.06168261170387, 58.77602130174637, 53.6174751073122, 52.93335221707821, 51.957724168896675, 55.205858275294304, 53.44255909323692, 55.10443411767483, 54.806571900844574, 52.17247724533081, 52.02243849635124, 54.93527479469776, 51.33356586098671, 41.08734726905823, 40.91931648552418, 41.97842985391617, 40.394762232899666, 41.54234245419502, 43.63401621580124, 43.898660615086555, 43.3902782946825, 43.74661177396774, 44.162491858005524, 41.713093891739845, 39.39585663378239, 40.617966055870056, 42.92731113731861, 41.993116065859795, 41.62440665066242, 41.41663379967213, 39.74891468882561, 40.43139986693859, 39.1971804946661, 39.32552620768547, 38.87873098254204, 39.6785044670105, 39.426236003637314, 39.17214743793011, 41.24806724488735, 41.1266827583313, 43.94764758646488, 47.030961737036705, 46.81007198989391, 47.008022367954254, 46.9073011726141, 47.94285200536251, 43.70866321027279, 43.20150822401047, 44.032200649380684, 48.47152143716812, 51.722155809402466, 55.09679652750492, 56.943562030792236, 77.97778934240341, 76.38427644968033, 52.554824128746986, 55.545795634388924, 52.98458106815815, 50.96408508718014, 52.96365559101105, 54.794268161058426, 53.50495934486389, 51.21122382581234, 50.5186577886343, 52.18553714454174, 41.4396795630455, 37.289815843105316, 38.360495790839195, 40.391125828027725, 37.117882668972015, 36.35323069989681, 36.289348527789116, 37.11439065635204, 35.07417753338814, 37.5862455368042, 36.58027991652489, 35.98218061029911, 37.197401002049446, 36.17209441959858, 36.89406327903271, 38.566163554787636, 37.66571067273617, 38.16891387104988, 36.621268317103386, 35.900017619132996, 35.59349186718464, 37.089969366788864, 35.271611139178276, 35.35283178091049, 40.40143467485905, 46.047061532735825, 50.482415333390236, 48.17492835223675, 44.76575128734112, 49.38113942742348, 48.64847794175148, 49.66777704656124, 47.69963465631008, 47.32005022466183, 47.67027363181114, 48.19397293031216, 48.75336371362209, 50.03058157861233, 47.63974986970425, 47.17964015901089, 48.95724557340145, 48.64868313074112, 50.89141018688679, 40.166789665818214, 8.21419782936573, 0.4369099368341267, 0.5775879474822432, 4.845507116988301, 6.033519543707371, 7.048086952418089, 0.3528836206533015, 0.12861325725680217, 37.34921045601368, 52.51985460519791, 32.15981751680374, 28.20638805627823, 36.13055884838104, 27.730927169322968, 0.9819772699847817, 0.02674526007467648, 0.022948929799895268, 0.061255948967300355, 0.03688431279442739, 0.02494540167390369, 0.03619220442487858, 0.03953972460294608, 0.01197199142552563, 0.013631897472805576, 0.01876770875242073, 0.019771428233070765, 0.01907537349325139, 0.055046981942723505, 0.009812220159801655, 0.012906472238682909, 0.032561840635025874, 0.057252381375292316, 0.041558726225048304, 0.03760377672733739, 0.047761039895704016, 0.06800532937631942, 0.019341973347763997, 0.031122756918193772, 0.02886539230530616, 0.01718056657409761, 0.04492446612857748, 0.08172294954420067, 0.022490150804514997, 0.026514914134168066, 0.027158172488270793, 0.0026223419399684644, 0.029330548204598017, 0.051236435829196125, 0.03428214637096971, 0.08456300769466907, 0.04875786296906881, 0.14733471907675266, 12.25847091525793, 42.37946793437004, 31.953374594449997, 37.23417542874813, 46.30088411271572, 47.512449100613594, 57.705937922000885, 1.4920510933734477, 0.2679349633399397, 0.29862722265534103, 0.10525697187404148, 0.12266890669707209, 0.15900321013759822, 0.0786875284393318, 17.36703459173441, 57.6840852946043, 60.27117647230625, 55.55064797401428, 53.797889426350594, 53.52236621081829, 58.29096592962742, 53.26589897274971, 58.43538478016853, 56.113029196858406, 53.30982081592083, 55.393051430583, 55.26978224515915, 53.06860975921154, 42.98966959118843, 43.79672348499298, 43.55948321521282, 40.00377461314201, 43.1434815376997, 43.86207237839699, 44.139404296875, 46.39275178313255, 45.858846232295036, 45.413251742720604, 42.71993726491928, 41.91583961248398, 42.05715782940388, 43.89941677451134, 42.47764326632023, 43.2141425460577, 43.15790556371212, 42.367749363183975, 41.02723829448223, 41.62661053240299, 41.02314971387386, 41.57467111945152, 40.677888840436935, 39.94126796722412, 40.55195599794388, 43.49581003189087, 42.50937916338444, 45.115625113248825, 47.04792782664299, 49.244654551148415, 48.45651984214783, 48.862657248973846, 48.77545192837715, 45.43571613729, 44.10571150481701, 45.08270747959614, 51.38630323112011, 52.37303428351879, 55.80913670361042, 58.815052807331085, 61.181607618927956, 65.7039387524128, 56.635767146945, 54.34296257793903, 55.08917793631554, 53.20162162184715, 55.04354618489742, 55.21697647869587, 52.89584822952747, 52.5671810656786, 52.662681341171265, 52.45874248445034, 42.83582344651222, 37.83952474594116, 40.551583617925644, 41.278074234724045, 39.84935849905014, 37.24253498017788, 37.97180324792862, 38.26026476919651, 36.80097967386246, 38.45992885529995, 39.4325702637434, 38.405352383852005, 39.514208883047104, 38.04000198841095, 38.166181817650795, 40.17094664275646, 39.986025765538216, 38.591109216213226, 38.64186309278011, 38.202762454748154, 37.12827891111374, 38.391152545809746, 38.442286401987076, 38.200482577085495, 42.98281855881214, 47.410481572151184, 53.126666843891144, 48.54840651154518, 45.72610415518284, 50.967539101839066, 52.13342674076557, 51.626465544104576, 49.29964520037174, 50.01138500869274, 48.94151821732521, 49.76413607597351, 51.35829493403435, 52.879436910152435, 48.61267626285553, 49.894165098667145, 52.419798374176025, 50.132074132561684, 52.885843366384506, 43.303517550230026, 9.095243252813816, 1.5720723057165742, 4.395615058019757, 8.242423664778471, 6.741752615198493, 5.160585734993219, 0.2768139587715268, 0.025706308988446835, 38.66889864206314, 56.43886171281338, 42.14596666395664, 28.740540593862534, 38.258657455444336, 37.37568363547325, 1.1918401275761425, 0.020090113866899628, 0.01950820329511771, 0.016764689280535094, 0.0663512825849466, 0.05736927705584094, 0.025136157746601384, 0.06995902571361512, 0.0243446943568415, 0.05791882998892106, 0.034267025112058036, 0.06537522480357438, 0.03509341026074253, 0.06748250860255212, 0.04570656361465808, 0.0220410271504079, 0.02077241661027074, 0.23549640085548162, 0.10878746485104784, 0.1268230634741485, 0.2225513564189896, 0.1877046434674412, 0.16922730370424688, 0.13303709565661848, 0.10021211914136074, 0.12142122286604717, 0.1794084714492783, 0.17871100106276572, 0.0896007803385146, 0.12565443321364, 0.06987840621150099, 0.14266885147662833, 0.14215795701602474, 0.1870356418658048, 0.12679316976573318, 0.15569614071864635, 0.20366844779346138, 0.209865870710928, 14.44547776132822, 53.0419047921896, 40.961574018001556, 40.094775930047035, 47.994726821780205, 52.894168719649315, 62.55796976387501, 2.7801319817081094, 0.3233125386759639, 1.0036727995611727, 0.2840269514126703, 0.13959830452222377, 0.13178770488593727, 0.34662354562897235, 18.281867802143097, 57.6432640850544, 62.741211131215096, 58.69583420455456, 57.40526765584946, 57.12220944464207, 61.25627361238003, 56.50018282234669, 59.08092074096203, 55.21190755069256, 55.10154627263546, 57.39434324204922, 59.144829511642456, 55.23823633790016, 44.99538816511631, 46.3859311491251, 45.78629672527313, 43.59101392328739, 46.06937013566494, 48.00700016319752, 46.665280759334564, 47.061249911785126, 49.3034677952528, 46.86716392636299, 44.85042214393616, 44.469819366931915, 45.33992327749729, 47.74147421121597, 44.425965920090675, 44.98179629445076, 45.36035858094692, 44.350057393312454, 44.55626092851162, 43.85258428752422, 43.538656532764435, 44.91191424429417, 44.334630221128464, 40.92860318720341, 42.362140864133835, 45.66900461912155, 45.1974081248045, 47.78924144804478, 50.11391490697861, 51.96437381207943, 49.40288566052914, 50.74669875204563, 51.87947116792202, 46.620990335941315, 46.23233199119568, 48.03749732673168, 54.20977972447872, 54.34229001402855, 56.85418702661991, 59.38702471554279, 66.06623411178589, 72.19320774078369, 57.71313473582268, 56.524079740047455, 55.87152175605297, 56.67183481156826, 57.15663179755211, 56.24085433781147, 55.44629417359829, 52.253241911530495, 53.91936890780926, 57.61020585894585, 45.50736889243126, 39.48198281228542, 41.4026315510273, 44.058613032102585, 41.32515370845795, 38.88275496661663, 38.920771926641464, 40.63617467880249, 38.16863268613815, 42.11577348411083, 41.10969007015228, 39.897528514266014, 41.1924534291029, 39.20547164976597, 40.20461663603783, 42.5115792453289, 40.2851989120245, 41.44736275076866, 40.98183073103428, 40.33228598535061, 39.01102088391781, 41.05863980948925, 40.68766191601753, 39.40270386636257, 43.96079868078232, 50.3660199791193, 55.49968130886555, 49.016906172037125, 45.80638624727726, 52.394381538033485, 52.37722925841808, 52.891755849123, 51.572405844926834, 51.01868815720081, 50.48861280083656, 51.44364595413208, 53.01138482987881, 54.67991329729557, 50.32724305987358, 51.39299467206001, 54.63504910469055, 52.04982362687588, 54.36250112950802, 43.936346992850304, 10.23724727332592, 1.101002914365381, 4.647063240408897, 11.865499801933765, 14.858745485544205, 15.120244603604078, 1.7737654829397798, 0.3071745077613741, 47.65815228223801, 61.08570076525211, 43.24020154774189, 38.89331080019474, 46.84818014502525, 45.802548453211784, 2.0112228160724044, 0.1640949962893501, 0.18495084514142945, 0.15302353334845975, 0.17916124721523374, 0.08958643462392502, 0.08180127580999397, 0.16217036987654865, 0.12343296257313341, 0.1732598224771209, 0.2001709135947749, 0.21963645267533138, 0.23974390496732667, 0.2206456844578497, 0.11638295298325829, 0.11519091538502835, 0.05992089580104221], [0.017857078710221685, 0.036018649479956366, 0.028002666040265467, 0.019940636047977023, 0.07670231309020892, 0.08018945722142234, 0.004178343833700637, 0.08919440995668992, 0.0028297156268308754, 0.11920708464458585, 0.022280685188889038, 0.0713272269058507, 0.04952967428835109, 0.12070752170984633, 0.021418793839984573, 0.011997258770861663, 0.0823415964259766, 0.04196762361971196, 0.08288183540571481, 0.055759005845175125, 0.017666452513367403, 0.7143835758324713, 28.779627196490765, 42.075446248054504, 22.429565638303757, 41.19281820952892, 34.47743475437164, 57.92910374701023, 9.955376498401165, 0.18494602118153125, 0.197236996027641, 0.09715282314573415, 0.07412631850456819, 0.07961525756400079, 0.14552758948411793, 0.5510960065294057, 31.19037363678217, 57.747712880373, 54.58988472819328, 52.11294583976269, 53.66289407014847, 52.24053919315338, 53.81689980626106, 57.53683939576149, 54.47125129401684, 53.176421374082565, 53.03957551717758, 53.90157826244831, 49.62344102561474, 40.44646605849266, 42.85431705415249, 39.35962177813053, 41.2209253013134, 46.33983202278614, 46.04212939739227, 51.23509034514427, 48.07734198868275, 47.78299458324909, 48.35895247757435, 44.653474912047386, 42.15569794178009, 40.71333333849907, 41.317846700549126, 42.92488306760788, 41.81026987731457, 40.19548952579498, 37.54119895398617, 38.41962441802025, 40.08202761411667, 38.23416776955128, 38.881181851029396, 39.80254881083965, 41.93776823580265, 39.6333134919405, 41.41584724187851, 37.928348779678345, 44.210703670978546, 44.597298726439476, 46.53340123593807, 47.548653557896614, 48.56226436793804, 46.29111483693123, 46.4930360019207, 42.30396218597889, 44.57572728395462, 48.55397701263428, 54.97223921120167, 51.69147625565529, 61.118527203798294, 50.54747924208641, 45.249784514307976, 67.66018778085709, 60.27556523680687, 53.53357940912247, 51.7386469244957, 54.95625726878643, 55.94493381679058, 56.047634705901146, 50.766271501779556, 50.41089937090874, 47.23786063492298, 39.39446210861206, 37.743975073099136, 39.920844063162804, 36.7148344963789, 38.771306946873665, 36.36979021131992, 38.19897785782814, 36.575921550393105, 35.56410804390907, 37.1563708037138, 40.3224179148674, 36.30006015300751, 36.62038676440716, 36.322729736566544, 38.01077015697956, 40.210061743855476, 41.366149708628654, 42.17505030333996, 42.55223326385021, 37.012818306684494, 36.74946203827858, 34.678113386034966, 36.321384608745575, 33.733753859996796, 35.41076347231865, 41.65692150592804, 46.272796019911766, 52.190051302313805, 51.30293570458889, 46.351584792137146, 48.29926908016205, 48.699083626270294, 51.25282019376755, 51.17473438382149, 48.60959082841873, 51.933276280760765, 51.24824903905392, 48.91875743865967, 46.95319131016731, 49.32508483529091, 49.99363996088505, 48.704357743263245, 50.71810528635979, 24.34595100581646, 1.3184699951671064, 1.4356067846529186, 1.604265128262341, 7.0825254544615746, 6.064057555049658, 3.2290802663192153, 1.4191459491848946, 8.754720725119114, 58.77292826771736, 35.31943917274475, 25.929339341819286, 27.905746288597584, 45.49416080117226, 15.264680553227663, 0.18413664976833388, 0.1282666000770405, 0.023332573764491826, 0.05956604902166873, 0.08750356006203219, 0.056423521164106205, 0.041156630613841116, 0.06138564298453275, 0.05138830892974511, 0.04557687330816407, 0.02063644402369391, 0.07494482575566508, 0.07146637217374519, 0.040912538242992014, 0.07084802957251668, 0.024276598596770782, 0.0011429361802584026, 0.03558468604751397, 0.035629678750410676, 0.030751132035220508, 0.018303367360203993, 0.09482555935392156, 0.04808547346328851, 0.008374526114494074, 0.06706581494654529, 0.032707130885683, 0.07424508439726196, 0.02690758261451265, 0.062367018254008144, 0.07732110840152018, 0.04995727751520462, 0.04678298573708162, 0.04719544172985479, 0.11033029339159839, 0.07069945160765201, 0.11814569472335279, 0.004966431379216374, 0.21714527072617784, 1.640138290822506, 37.656249180436134, 41.90152958035469, 21.39641247689724, 47.79018759727478, 40.87093748152256, 63.976004272699356, 9.448275659233332, 0.17596634599613026, 0.32333708892110735, 0.08517459675204009, 0.3623993491055444, 0.7700960675720125, 0.13730607752222568, 0.8702852914575487, 34.68067444860935, 59.93358738720417, 56.564665362238884, 53.31482894718647, 54.58399884402752, 54.61418442428112, 56.573902666568756, 57.63192929327488, 56.71570725739002, 55.63949480652809, 55.50468564033508, 55.05860477685928, 53.5268347710371, 41.14964872598648, 45.0098691880703, 41.20608329772949, 40.544364005327225, 47.956592068076134, 50.25439336895943, 49.61408972740173, 51.85485988855362, 49.53874357044697, 49.31506097316742, 44.95530791580677, 43.257543817162514, 42.13413789868355, 43.77159543335438, 44.13130313158035, 44.69134368002415, 42.56445720791817, 40.15238083899021, 41.12558841705322, 43.52128766477108, 39.82971355319023, 41.62730969488621, 42.35737971961498, 41.89371719956398, 40.653809532523155, 41.979516595602036, 39.549402594566345, 44.44113850593567, 45.20541429519653, 49.059961661696434, 48.56150060892105, 50.788481310009956, 50.33086806535721, 48.71392942965031, 45.69229356944561, 45.70573344826698, 51.423275247216225, 54.595785811543465, 53.523297160863876, 59.839888215065, 56.03750444948673, 48.95234003663063, 60.8252627402544, 59.006338343024254, 54.664584919810295, 52.00552940368652, 56.99518606066704, 56.1462128162384, 57.55215257406235, 53.409717455506325, 53.32074522972107, 49.70156863331795, 41.73060715198517, 39.654105976223946, 41.12839266657829, 38.23794476687908, 39.617111161351204, 38.252326995134354, 39.45106767117977, 38.67999404668808, 37.031254917383194, 39.17715176939964, 40.94699800014496, 37.88047514855862, 37.62607499957085, 37.343795746564865, 39.48348753154278, 42.58150689303875, 42.600771859288216, 42.53371685743332, 43.41114677488804, 39.542532563209534, 39.45673316717148, 37.26179614663124, 37.28792354464531, 36.56735301017761, 37.08607837557793, 44.253109395504, 47.86505877971649, 54.82489451766014, 52.02491596341133, 50.060516372323036, 50.65769612789154, 50.993788093328476, 55.085241347551346, 52.4240617454052, 51.63653500378132, 52.02754162251949, 52.59703606367111, 50.760773196816444, 48.067641109228134, 51.43882401287556, 51.8628204613924, 49.98597577214241, 51.245262399315834, 26.51480432599783, 2.1550716971978545, 4.227879708632827, 5.125275179743767, 7.887235349044204, 9.895773846656084, 0.26160732319112867, 0.9379002882633358, 7.611666060984135, 63.71388293802738, 43.3110411465168, 35.46143755316734, 24.9778912961483, 51.74275450408459, 20.641269497573376, 0.444728551665321, 0.09797350488952361, 0.06951005605515093, 0.0808604626217857, 0.20411042642081156, 0.026616655159159563, 0.07371163606876507, 0.01949358484125696, 0.0599000266083749, 0.05274865819956176, 0.0306408284814097, 0.05457118364574853, 0.06980511170695536, 0.03000667999003781, 0.011525093286763877, 0.029438027886499185, 0.1121221792709548, 0.14289139187894762, 0.12394483666867018, 0.07149963523261249, 0.10218410941888578, 0.15318732534069568, 0.0987535243621096, 0.07698703062487766, 0.1301351052825339, 0.10200854696449824, 0.1579873138689436, 0.16975351609289646, 0.17865495407022536, 0.13048900582361966, 0.21456618880620226, 0.14408712537260726, 0.15375707211205736, 0.25673144264146686, 0.14886474556988105, 0.14826172089669853, 0.1366159098688513, 0.30871366267092526, 2.097352556884289, 43.4418111294508, 54.029069021344185, 30.444407165050507, 52.606463357806206, 44.461433216929436, 70.39918720722198, 14.572396650910378, 0.22241300524910912, 0.8085478073917329, 0.2649715676670894, 0.300993308192119, 0.42032816098071635, 0.3832340467488393, 1.1262265546247363, 34.217034727334976, 61.62574678659439, 58.156031370162964, 56.82498559355736, 58.18469323217869, 56.37309484183788, 58.28137904405594, 60.81127189099789, 58.781113028526306, 57.31129489839077, 60.14690414071083, 58.76238763332367, 55.47797307372093, 43.43202665448189, 47.702708691358566, 43.284659162163734, 44.69154506921768, 51.142588108778, 51.79839111864567, 53.90569344162941, 53.70518960058689, 52.85724230110645, 52.39630043506622, 47.68937900662422, 46.343616619706154, 44.74756546318531, 46.610537096858025, 45.49834057688713, 45.7511106133461, 45.397045612335205, 41.14748664200306, 43.007680624723434, 44.791928082704544, 41.54046915471554, 44.095091074705124, 43.59249584376812, 44.56938922405243, 42.48555824160576, 45.36884732544422, 40.84485188126564, 48.21099981665611, 48.61503213644028, 51.68130420148373, 52.485424652695656, 53.605574145913124, 53.224902972579, 50.72654843330383, 47.406358793377876, 47.31252282857895, 54.65283215045929, 56.01273737847805, 55.19207641482353, 61.86132274568081, 64.03903529047966, 53.09460036456585, 59.86413091421127, 61.69694356620312, 56.34731322526932, 53.58232319355011, 58.339755311608315, 57.70451679825783, 57.790532782673836, 53.177150934934616, 55.21084360778332, 52.82414227724075, 42.788618579506874, 42.20499649643898, 43.819476664066315, 40.0623332709074, 41.798494309186935, 40.73224872350693, 41.53614118695259, 41.385555267333984, 39.51562620699406, 41.029487773776054, 44.07265327870846, 39.931513890624046, 39.38718929886818, 38.66803228855133, 41.64225049316883, 45.63042148947716, 47.08419308066368, 44.91935804486275, 45.09425885975361, 39.757540225982666, 41.72265037894249, 39.75078038871288, 38.877811431884766, 37.80873879790306, 38.04329261183739, 45.38355253636837, 48.96287687122822, 55.54889626801014, 54.05426926910877, 49.892759174108505, 51.47028252482414, 55.040350556373596, 57.00860694050789, 53.74051630496979, 53.34376819431782, 53.998644053936005, 54.9430263787508, 52.0639056712389, 49.03919957578182, 53.176223784685135, 53.208715841174126, 49.69635911285877, 52.68057078123093, 27.21894644200802, 1.8714243988506496, 3.9102193666622043, 5.809726752340794, 17.068741098046303, 18.27025942504406, 15.818490386009216, 2.422293070703745, 12.156551834195852, 69.74535629153252, 45.060376077890396, 43.29942896962166, 35.24411961436272, 60.51803782582283, 27.070885486900806, 0.651801765197888, 0.20325032179243863, 0.134021628764458, 0.27401499333791435, 0.2968713903101161, 0.1385501990444027, 0.1829345931764692, 0.12038318091072142, 0.14542028977302834, 0.21460513671627268, 0.12094575853552669, 0.19941139966249466, 0.16741282684961334, 0.0951673999952618, 0.21975153009407222, 0.106079367978964, 0.19246611453127116], [0.015058326644066256, 0.01915861834277166, 0.11714012172888033, 0.025726014864630997, 0.01757337049639318, 0.025087823523790576, 0.053162008480285294, 0.02901435989770107, 0.07008123517152853, 0.00736542420781916, 0.08384071988984942, 0.03482416650513187, 0.073529861838324, 0.07866796542657539, 0.02944506715721218, 0.06602492314414121, 0.021752990360255353, 0.03897296868672129, 0.02973601131088799, 0.03846580351819284, 0.020482648760662414, 0.12582729425048456, 6.459379317238927, 42.35179401934147, 34.15179222822189, 35.81925295293331, 37.687909081578255, 43.655409067869186, 39.25833821296692, 0.4175500647397712, 0.12279849310289137, 0.04872169440204743, 0.52762086619623, 2.3246212117373943, 0.054702799825463444, 0.026145406227442436, 10.727641358971596, 46.28361023962498, 58.155320808291435, 52.10539564490318, 55.8459909260273, 56.54873661696911, 59.41425405442715, 51.88118867576122, 53.002877086400986, 52.63143561780453, 53.41935753822327, 51.801088973879814, 46.308578699827194, 39.693354070186615, 40.824085995554924, 41.743895038962364, 47.84234739840031, 48.58764320611954, 51.095599830150604, 54.01214472949505, 54.566732570528984, 50.60805179178715, 51.17163375020027, 46.79768085479736, 40.26941455900669, 39.44686509668827, 43.07776406407356, 42.27548271417618, 41.68528698384762, 41.35484151542187, 38.727480098605156, 40.38497395813465, 39.07191261649132, 39.642022624611855, 41.33667469024658, 40.0980019569397, 40.81227242946625, 39.8867142945528, 41.209043338894844, 40.47047317028046, 45.298585295677185, 45.875918716192245, 46.18397958576679, 45.67166067659855, 44.545100927352905, 47.4874996393919, 46.72163173556328, 47.842020615935326, 47.56670258939266, 49.68047596514225, 53.846485018730164, 54.964871406555176, 44.341697841882706, 16.48300062865019, 63.41667428612709, 73.59530970454216, 49.45424370467663, 54.87998016178608, 52.88165979087353, 51.3558516651392, 53.66002522408962, 53.058084324002266, 52.47025206685066, 50.98037101328373, 44.74825702607632, 39.801728054881096, 39.9469106644392, 37.547335624694824, 38.76497648656368, 38.27973112463951, 39.00066263973713, 37.51649647951126, 37.72119149565697, 34.660174548625946, 38.13722737133503, 38.61711122095585, 37.88457132875919, 37.146882712841034, 36.82222433388233, 38.26536409556866, 42.524228766560555, 45.64671501517296, 47.469701394438744, 44.0704569965601, 43.550842478871346, 39.0700127184391, 35.196842551231384, 36.627211198210716, 36.26488544046879, 36.147547736763954, 35.07866509258747, 39.354685842990875, 41.746931076049805, 44.639951437711716, 48.210110664367676, 46.13503061234951, 45.63177801668644, 48.06062288582325, 47.58228935301304, 46.57708369195461, 49.475868344306946, 49.28484879434109, 49.44991573691368, 51.019007340073586, 49.377689212560654, 50.533180609345436, 48.643363416194916, 41.39150194823742, 10.006874185055494, 0.26770210708491504, 4.878942472860217, 5.066532706841826, 8.488549757748842, 3.6108882911503315, 1.4812144311144948, 0.3357277193572372, 28.760272935032845, 43.78934808075428, 34.45671446621418, 41.622624546289444, 33.05560804903507, 38.034484684467316, 4.731050608679652, 0.16063689981820062, 0.1176988698716741, 0.04020581327495165, 0.03734721627552062, 0.03156338483677246, 0.028272353229112923, 0.03446871858614031, 0.04213173844618723, 0.03885785044985823, 0.00751256611692952, 0.009734441227919888, 0.04021950961032417, 0.11644126352621242, 0.02657573870237684, 0.051745237433351576, 0.03187089372659102, 0.04750195243104827, 0.0281997210913687, 0.005021358656449593, 0.019266227900516242, 0.04526528631686233, 0.037421846645884216, 0.025052578930626623, 0.014202478232618887, 0.02951452104753116, 0.0444408789917361, 0.04687643697252497, 0.15607180102961138, 0.009234148346877191, 0.07483671710360795, 0.11601264355704188, 0.04373526724521071, 0.02483887194102863, 0.05728482436097693, 0.01173819635369, 0.052558738898369484, 0.03109087425400503, 0.026566211381577887, 0.0249521273872233, 11.979894563555717, 51.80191732943058, 29.0918792411685, 42.51052290201187, 46.501562744379044, 51.25622101128101, 40.6197215616703, 0.20459660736378282, 0.3117459890199825, 0.15725169709185138, 1.1954691703431308, 5.449607726186514, 0.3031429834663868, 0.017668029577180278, 13.082347456365824, 48.739517256617546, 60.377787351608276, 52.16975659132004, 57.73463398218155, 58.068917244672775, 61.9669608771801, 54.15727034211159, 54.858161732554436, 56.4790141582489, 57.28823013603687, 54.568267688155174, 47.94664420187473, 42.205870449543, 43.935070261359215, 44.11901839077473, 50.147562101483345, 51.08299970626831, 53.474116399884224, 55.010259971022606, 57.21755392849445, 53.39841686189175, 51.337103471159935, 48.63276958465576, 42.076107412576675, 41.52811221778393, 43.63734483718872, 44.98128332197666, 43.362934961915016, 42.957207933068275, 42.94677369296551, 42.19745770096779, 40.63246227800846, 41.25424951314926, 42.45754614472389, 42.06279292702675, 40.91915309429169, 42.533979043364525, 43.0831977725029, 43.175240233540535, 45.312374755740166, 48.31504963338375, 47.411347925662994, 46.810151785612106, 46.370234191417694, 48.725093230605125, 47.604495361447334, 50.01073144376278, 46.210179179906845, 50.38106717169285, 53.19907955825329, 58.1764704734087, 46.32576137781143, 17.656924836337566, 51.17599971592426, 69.8383828997612, 58.419805616140366, 55.724804028868675, 54.03644822537899, 52.94330768287182, 56.98439083993435, 56.45619258284569, 54.85868990421295, 51.704387962818146, 47.822151482105255, 40.16952931880951, 41.65396146476269, 38.58224429190159, 40.29623731970787, 41.058609411120415, 40.116514563560486, 38.44198241829872, 40.07872559130192, 36.980208456516266, 39.686715826392174, 39.15877975523472, 39.55258682370186, 38.76594923436642, 38.860712349414825, 38.37163679301739, 43.57654429972172, 48.66923242807388, 48.32209825515747, 47.16191031038761, 45.07559806108475, 40.492124408483505, 37.68752910196781, 38.06090086698532, 36.61066688597202, 38.294440135359764, 36.60641871392727, 42.058065980672836, 45.48811532557011, 47.2015193849802, 49.25685189664364, 47.486811876297, 47.525003626942635, 50.124485939741135, 50.546616688370705, 48.535821586847305, 50.50610326230526, 52.4895816296339, 51.020732447505, 52.24581331014633, 50.076524913311005, 50.78687399625778, 47.86432921886444, 43.53046037256718, 11.313560418784618, 1.4192436751909554, 5.196263920515776, 6.562623577192426, 7.636678693816066, 4.903974579647183, 1.1239586700685322, 0.15486425254493952, 29.8905735835433, 50.16674347221851, 36.32570877671242, 39.07386191189289, 32.1566066890955, 46.914528384804726, 6.354744331911206, 0.3477786242729053, 0.16310084494762123, 0.05849556408065837, 0.02685879939235747, 0.09939782728906721, 0.025334747188026085, 0.024551684909965843, 0.08479433512547985, 0.04019410218461417, 0.038517653665621765, 0.0470750208478421, 0.1058188518800307, 0.03690101111715194, 0.07342717828578316, 0.046232249078457244, 0.05509085029189009, 0.035650484860525467, 0.07652082087588497, 0.15567023976473138, 0.2119270374532789, 0.16750780690927058, 0.16850471904035658, 0.11821205014712177, 0.15009820985142142, 0.1469344343058765, 0.1840628802892752, 0.17863647459307685, 0.29152528499253094, 0.06713562877848744, 0.15140447882004082, 0.19476571847917512, 0.13380716292886063, 0.2009224271751009, 0.20616850582882762, 0.13186828728066757, 0.10641931614372879, 0.1372298737987876, 0.14296805573394522, 0.33073793398216367, 12.53783667460084, 59.37705785036087, 41.08751066029072, 47.06624664366245, 50.159577056765556, 52.013668566942215, 47.28173308074474, 0.742309286724776, 0.46053712838329375, 0.1661114115267992, 2.1496662497520447, 3.8879235880449414, 0.19827441457891837, 0.18197288853116333, 13.264153450727463, 48.41186083853245, 62.778616324067116, 55.91743469238281, 58.99558112025261, 63.01860764622688, 62.53295570611954, 55.77555030584335, 55.09682312607765, 58.33157055079937, 58.67762178182602, 55.76096288859844, 50.84585063159466, 44.07119795680046, 46.21422216296196, 45.811652764678, 53.13948355615139, 54.53085869550705, 55.32058171927929, 59.235443249344826, 60.80575838685036, 54.20164056122303, 54.53245460987091, 50.82912012934685, 43.144473284482956, 43.028210923075676, 47.19014659523964, 46.968998461961746, 44.919966012239456, 44.687011912465096, 42.900191992521286, 44.41753417253494, 43.35230313241482, 43.32586035132408, 45.69054186344147, 45.440032705664635, 44.44301560521126, 43.240969106554985, 44.04335305094719, 44.980052188038826, 48.8314875215292, 50.54156295955181, 49.59165193140507, 47.77767866849899, 48.23656864464283, 52.08031699061394, 51.08008526265621, 51.32408156991005, 49.42685857415199, 52.68391840159893, 56.6549751162529, 59.95424307882786, 49.22248654067516, 25.08957490324974, 56.38654612004757, 74.56325456500053, 59.31306168437004, 53.52838508784771, 55.593038499355316, 53.866183161735535, 59.92190681397915, 59.19527940452099, 55.49580551683903, 54.525253996253014, 49.00849722325802, 43.12265485525131, 44.389468878507614, 40.34575626254082, 42.74374678730965, 43.50962609052658, 43.31723101437092, 40.72576627135277, 42.45026953518391, 38.50163161754608, 41.97078466415405, 42.725412771105766, 41.26112334430218, 41.49628892540932, 39.8880860209465, 42.02803239226341, 46.908756494522095, 50.42803645133972, 51.651194617152214, 49.86859247088432, 48.66440288722515, 42.48545564711094, 38.09155002236366, 40.259060114622116, 38.58265087008476, 39.90858972072601, 39.42224241793156, 43.62621143460274, 46.28571532666683, 48.87332707643509, 51.39065399765968, 48.82155105471611, 49.84900452196598, 53.39945040643215, 53.0840103328228, 50.35541474819183, 52.277363017201424, 54.22894589602947, 52.04999841749668, 54.36403624713421, 50.13959392905235, 51.84770867228508, 48.074613735079765, 44.22602824866772, 12.564189210534096, 1.636651859153062, 9.133275412023067, 11.304972879588604, 15.639559887349606, 10.24583576247096, 5.467652957886457, 0.49800561158917844, 35.33075876533985, 55.815725550055504, 42.85050205886364, 50.65863847732544, 42.63217717409134, 55.049481466412544, 9.222042448818684, 0.5449310748372227, 0.327713979058899, 0.13534193916711956, 0.15487922908505425, 0.1746194518636912, 0.1055823294154834, 0.07392149316729046, 0.1425198875949718, 0.11342801779392175, 0.2015567704802379, 0.12584814860019833, 0.18133137607946992, 0.22705819661496207, 0.11773583624744788, 0.09480152861215174, 0.16636299958918244, 0.217990146484226], [0.01774828171619447, 0.06217267946340144, 0.04322308144764975, 0.008995845655590529, 0.012063589147146558, 0.05373183317715302, 0.023641323896299582, 0.0329251738730818, 0.019448512357485015, 0.06855743529740721, 0.07785992245771922, 0.05120919900946319, 0.02879917788959574, 0.015584071479679551, 0.06759662865079008, 0.03219993603124749, 0.03293812435003929, 0.08142833175952546, 0.024333111286978237, 0.08088266768027097, 0.07933513392345048, 0.08273845989606343, 0.2423905668547377, 25.29795002192259, 42.27040998637676, 25.59750694781542, 42.910250052809715, 32.55101412534714, 54.67343844473362, 10.526160020381212, 0.21689356392016634, 0.20815685304114595, 0.8787859696894884, 8.278972003608942, 2.2707526898011565, 0.14971677563153207, 1.9508935720659792, 26.766377426683903, 54.69317078590393, 56.0640574246645, 54.10221129655838, 55.61555989086628, 54.77875739336014, 53.93470108509064, 54.06851850450039, 53.28530453145504, 55.963966995477676, 49.93701919913292, 41.17674507200718, 40.567679554224014, 43.19154895842075, 48.68684448301792, 51.53103746473789, 54.16912190616131, 54.06240463256836, 56.024661138653755, 57.4910594522953, 54.374246299266815, 51.96873217821121, 46.1110083013773, 41.19478650391102, 38.82702335715294, 38.9527852088213, 41.37917160987854, 41.831294149160385, 42.807279378175735, 38.93154814839363, 39.107486307621, 40.65617300570011, 43.435746654868126, 40.16842357814312, 39.15206931531429, 38.49076800048351, 40.218162909150124, 40.91249205172062, 40.869132578372955, 41.67308583855629, 44.87898901104927, 46.92180499434471, 46.696477085351944, 43.66729862987995, 45.10105289518833, 42.876378670334816, 46.67752370238304, 45.6245432049036, 50.640190467238426, 50.923822447657585, 55.01508191227913, 49.103241339325905, 50.10964393615723, 37.1412818133831, 36.93284399807453, 53.36755871772766, 50.01715689897537, 51.60492070019245, 50.244548097252846, 52.185704335570335, 54.34368833899498, 53.48064824938774, 48.78858782351017, 40.48352167010307, 36.68846771121025, 38.25607739388943, 36.91109396517277, 40.18762394785881, 37.20230273902416, 37.90231257677078, 36.528055518865585, 37.81958721578121, 38.102991208434105, 35.39019517600536, 37.390187457203865, 37.29613110423088, 37.43440568447113, 37.110165283083916, 38.174362778663635, 45.04776455461979, 48.80203530192375, 47.91014336049557, 47.9440451413393, 45.70273920893669, 43.72787497937679, 41.670672968029976, 37.65649236738682, 35.08881814777851, 36.10566258430481, 36.53581090271473, 34.015379548072815, 35.70001535117626, 38.83148431777954, 43.13268631696701, 43.56370858848095, 44.12905365228653, 42.320776283741, 45.520983561873436, 46.81709781289101, 47.68875204026699, 48.610966354608536, 50.017647072672844, 49.942897483706474, 51.01932652294636, 48.66800129413605, 50.50500892102718, 28.8705962151289, 1.7175167449750006, 1.4544416614808142, 4.3400240410119295, 9.691552855074406, 6.787113156169653, 3.160634064115584, 0.5278539005666971, 1.2760136858560145, 46.80089548230171, 37.420673221349716, 39.16221857070923, 37.81600780785084, 37.071566954255104, 32.67840228974819, 0.6148634129203856, 0.051222928741481155, 0.02165473000786733, 0.025924678520823363, 0.039399013403453864, 0.013078272004349856, 0.019295043639431242, 0.04553316823148634, 0.08427914362982847, 0.04450088905286975, 0.06820753493229859, 0.04340046587458346, 0.045887655069236644, 0.06354281023959629, 0.044405036969692446, 0.02819594355969457, 0.14206382300471887, 0.05730236131057609, 0.04213790198264178, 0.036876475714962, 0.021052768461231608, 0.0751177832717076, 0.04823945797397755, 0.06731792251230218, 0.010240792817057809, 0.1059877201623749, 0.03560935874702409, 0.057097918179351836, 0.047318486103904434, 0.03151173506921623, 0.017862114182207733, 0.041532424511387944, 0.06372174204443581, 0.05935780980507843, 0.016284567973343655, 0.007538458721683128, 0.043915089627262205, 0.05864554099389352, 0.03225357846531551, 0.053579748564516194, 0.8336070470977575, 33.959530144929886, 46.56413398683071, 26.051569283008575, 48.920547142624855, 39.21382360160351, 61.657349690794945, 8.277548030018806, 0.3560997324530035, 0.2094922141986899, 1.2432843795977533, 6.119847586378455, 4.695581886917353, 0.16577233909629285, 2.7761065727099776, 30.616287142038345, 56.08080692589283, 57.13902734220028, 55.85925981402397, 57.86840960383415, 56.883662045001984, 55.005191043019295, 53.9645978808403, 55.543489158153534, 56.87976725399494, 52.612052857875824, 44.003595784306526, 41.60957984626293, 44.86048020422459, 51.837285831570625, 53.77433829009533, 54.08801905810833, 55.164493694901466, 56.39623939990997, 58.47845546901226, 54.861281365156174, 54.58407483994961, 48.29660922288895, 41.98447532951832, 40.19982889294624, 40.7159323990345, 43.39747130870819, 45.44539041817188, 45.36051817238331, 42.44676612317562, 42.08129793405533, 41.49673730134964, 45.029016360640526, 41.87556557357311, 39.83343355357647, 40.480478033423424, 42.811584547162056, 43.1479424983263, 41.58101677894592, 43.041441813111305, 46.82884678244591, 47.090078964829445, 49.132070392370224, 45.21148256957531, 48.390076607465744, 46.054144352674484, 48.13575625419617, 49.934606328606606, 52.178328931331635, 52.23299279808998, 55.553102642297745, 49.80180725455284, 48.95229063928127, 43.19732464849949, 41.30887158215046, 55.439275950193405, 52.18587912619114, 52.429761439561844, 51.89107574522495, 55.46964772045612, 54.61046062409878, 55.09796306490898, 51.81709751486778, 42.85564698278904, 38.78692030906677, 39.668700993061066, 39.0441969037056, 40.46645298600197, 37.781748846173286, 38.717292845249176, 38.17340523004532, 40.69891311228275, 38.268981501460075, 37.02201381325722, 38.89810234308243, 40.13129957020283, 39.80946823954582, 38.33046980202198, 38.995308727025986, 46.339759826660156, 50.9665397554636, 49.85234074294567, 49.568248987197876, 47.27118864655495, 45.490927174687386, 42.373331263661385, 38.68184834718704, 36.82632431387901, 38.16693797707558, 38.868900910019875, 36.43669322133064, 37.42828041315079, 42.20876209437847, 45.26102051138878, 47.012817710638046, 45.42470432817936, 44.38916489481926, 47.396289333701134, 47.82420717179775, 50.39014108479023, 51.04323863983154, 51.00571945309639, 51.54035076498985, 52.427318170666695, 50.13660728931427, 49.68104213476181, 31.177454330027103, 2.581141171976924, 1.660699937492609, 6.833046991378069, 9.269967377185822, 10.594693142920732, 1.9450676534324884, 0.7555554946884513, 1.6141106374561787, 48.02620813250542, 43.85582931339741, 48.856360986828804, 42.565509751439095, 42.51150704920292, 39.2391150444746, 1.0594637808389962, 0.12068009193171747, 0.06964767249883153, 0.015639942212146707, 0.027212842796870973, 0.040880774322431535, 0.037481645194930024, 0.06431477740989067, 0.0601900208130246, 0.07070807536365464, 0.04562354697554838, 0.06309007047093473, 0.03875786831486039, 0.01611115032574162, 0.06080343926441856, 0.021438854091684334, 0.10459827128215693, 0.07125408825231716, 0.0952557304117363, 0.22088271158281714, 0.10576739878160879, 0.13911990128690377, 0.11879547470016405, 0.1805302276625298, 0.1156253092631232, 0.24728615884669125, 0.13578244834206998, 0.20742986002005637, 0.11881874102982692, 0.2010363171575591, 0.14456595905357972, 0.12798462848877534, 0.20020839205244556, 0.24576952069764957, 0.16166464076377451, 0.23362736130366102, 0.1482633239356801, 0.23137970769312233, 0.12158437661128119, 0.146349903952796, 0.8111020422074944, 40.1618043333292, 55.55813357234001, 34.464203864336014, 54.5372499525547, 45.37651911377907, 66.5708926320076, 13.64582872018218, 0.3250435832887888, 0.539637899491936, 3.3389316592365503, 17.249664589762688, 5.384846851229668, 0.22320107702398673, 2.5687763979658484, 30.619459971785545, 58.19081850349903, 59.40713703632355, 58.5772729665041, 59.50882337987423, 56.55917465686798, 56.947772204875946, 56.29631236195564, 58.10593105852604, 59.34118017554283, 55.006862953305244, 46.92000009119511, 45.66993176937103, 47.027051746845245, 53.051685467362404, 56.26759350299835, 58.02085742354393, 57.80795104801655, 59.150506407022476, 62.31317549943924, 57.577276825904846, 55.71429759263992, 50.74664555490017, 45.138974860310555, 43.060273602604866, 42.76117645204067, 46.28480717539787, 46.680913120508194, 47.96949237585068, 43.40342938899994, 42.274775952100754, 45.03161542117596, 47.5121945142746, 45.20784616470337, 41.2108064442873, 41.259364038705826, 44.665315076708794, 45.283332914114, 43.847028985619545, 44.85651321709156, 48.970104083418846, 50.50007298588753, 51.07169531285763, 48.36403660476208, 49.22766946256161, 46.73252195119858, 50.33917061984539, 50.87321296334267, 54.43043388426304, 55.26524908840656, 56.850793808698654, 53.47016841173172, 51.407540291547775, 46.33641600608826, 46.67617857456207, 53.566189259290695, 53.26776847243309, 53.75098094344139, 53.8851023465395, 56.433260813355446, 57.384779155254364, 56.927781477570534, 54.35507632791996, 44.694790095090866, 40.468181893229485, 41.976712346076965, 40.92375084757805, 44.19155649840832, 41.36165454983711, 41.849662363529205, 40.6904661655426, 41.57076492905617, 40.08654177188873, 38.914855644106865, 41.54152549803257, 40.92258810997009, 41.465879157185555, 39.44324389100075, 41.62682332098484, 49.27077054977417, 53.18380817770958, 52.58212946355343, 51.15284375846386, 48.488305136561394, 46.8675135076046, 44.33795504271984, 41.95476472377777, 38.020927011966705, 40.75468651950359, 39.29034769535065, 38.065757006406784, 39.65967267751694, 43.33398051559925, 48.531440421938896, 49.10038009285927, 48.0642668902874, 46.46133430302143, 48.463747054338455, 50.45426644384861, 51.580374017357826, 53.54526378214359, 52.033047527074814, 53.454361259937286, 54.678674563765526, 51.147892624139786, 50.53060054779053, 32.14725159108639, 2.4936043191701174, 4.479677947238088, 10.261085294187069, 19.36759114265442, 13.84423602372408, 9.239422716200352, 2.035724138841033, 2.13924340903759, 56.111372485756874, 47.92403541505337, 52.237351164221764, 45.14606907963753, 47.71619036793709, 50.81858329474926, 1.6984928282909095, 0.28482710535172373, 0.10966273897793144, 0.17191577819176018, 0.141428871138487, 0.13094961235765368, 0.09955528876162134, 0.1323545869672671, 0.2888760552741587, 0.17383436352247372, 0.18363688752288, 0.104755703068804, 0.08033298116060905, 0.1603633293416351, 0.11902410071343184, 0.10726102293119766, 0.30180281319189817, 0.09072241780813783], [0.03187920949130785, 0.026743885246105492, 0.04461269360035658, 0.050987252325285226, 0.048250297040794976, 0.028074079200450797, 0.11132880856166594, 0.03605721147323493, 0.02999739757797215, 0.04923727181449067, 0.0446398450731067, 0.026838228914130013, 0.03817400960542727, 0.07046688479022123, 0.0238336904294556, 0.053295769466785714, 0.03424567723413929, 0.05184117857425008, 0.04527708646492101, 0.02259682154544862, 0.12330410347203724, 0.010232811018795474, 0.2107932436047122, 7.130343988537788, 40.337993279099464, 33.51622313261032, 45.10333277285099, 35.142733454704285, 44.76435676217079, 31.414352618157864, 0.6480554630979896, 0.5492066172882915, 0.6966390029992908, 7.9452150128781796, 2.2098077600821853, 0.10246403267956339, 0.23190682550193742, 8.288893271237612, 38.64124372601509, 54.71212796866894, 54.34082329273224, 55.27586571872234, 54.58356946706772, 54.37432609498501, 52.87544332444668, 54.16646584868431, 51.5047162771225, 47.11010009050369, 40.14068506658077, 42.952063009142876, 48.56799826025963, 54.197065606713295, 54.62673895061016, 55.16331195831299, 55.920926705002785, 54.58901837468147, 54.02755290269852, 52.90617227554321, 53.13705548644066, 44.162374064326286, 41.21752828359604, 39.76081185042858, 42.28403985500336, 40.72760917246342, 40.93040429055691, 42.53363326191902, 42.1480755507946, 41.51695601642132, 42.26919025182724, 42.514866068959236, 40.23119240999222, 40.284374356269836, 39.324637055397034, 39.99312378466129, 40.78518748283386, 41.21148660778999, 43.86714890599251, 44.42805580794811, 44.14896458387375, 45.00716753304005, 45.311303213238716, 44.553555473685265, 43.55065628886223, 43.349487483501434, 44.9333792924881, 49.42069910466671, 49.215251728892326, 54.15481187403202, 56.106014773249626, 46.49528168141842, 28.179958574473858, 45.761028081178665, 48.983198180794716, 52.92740933597088, 54.54309023916721, 53.05512808263302, 52.47492201626301, 50.743408128619194, 47.965175807476044, 42.08610087633133, 37.649595737457275, 37.74981535971165, 38.10073412954807, 38.84385645389557, 38.63495506346226, 37.04740785062313, 38.732735216617584, 37.8952943533659, 37.394792810082436, 37.23359405994415, 36.87017776072025, 38.2552832365036, 37.33521580696106, 37.257129997015, 35.65507896244526, 38.73011335730553, 46.228950172662735, 50.053836330771446, 50.13295188546181, 49.443703070282936, 50.08815608918667, 47.73368842899799, 46.61054469645023, 43.93361113965511, 39.48958620429039, 38.43288950622082, 34.733560010790825, 35.02842038869858, 35.4114056378603, 33.41014802455902, 34.95302103459835, 36.73522800207138, 37.66291402280331, 38.7051372975111, 40.58557279407978, 43.10227654874325, 45.12939177453518, 45.45253403484821, 46.93870648741722, 49.37277987599373, 50.14998257160187, 50.83309091627598, 50.83244115114212, 14.445124380290508, 0.20605103869456798, 1.060763073619455, 2.4204986169934273, 3.337400578893721, 4.636826114729047, 1.54582972638309, 0.8466314419638366, 6.237133517861366, 57.7056947350502, 32.14591406285763, 26.930382326245308, 22.054166682064533, 38.48325200378895, 14.587074313312769, 0.11979379691183567, 0.053868881877860986, 0.1158820849377662, 0.007770716620143503, 0.018977636354975402, 0.04965226224157959, 0.10226864003925584, 0.031159756690612994, 0.059166465580346994, 0.043886605999432504, 0.07495742742321454, 0.039778380742063746, 0.019184131524525583, 0.024625211335660424, 0.06556683249073103, 0.006938685119166621, 0.03503217565594241, 0.020705678980448283, 0.01294604819122469, 0.03227248838811647, 0.015453730866283877, 0.016845872814883478, 0.11250864525209181, 0.045644290003110655, 0.03810448892181739, 0.04921230225590989, 0.059907592803938314, 0.021416431955003645, 0.10520007141167298, 0.013890646332583856, 0.046555947919841856, 0.07945829333039, 0.01679772412899183, 0.026957714690070134, 0.054875853820703924, 0.06926160727743991, 0.03291920329502318, 0.004725529315692256, 0.052579259281628765, 0.044213585133547895, 0.07796156700351276, 11.482826136052608, 48.730382546782494, 30.805195905268192, 48.034628480672836, 42.32950821518898, 54.470810517668724, 32.496395856142044, 0.38530211546458304, 0.4597025387920439, 1.1495748767629266, 2.034662808291614, 6.746728923171759, 1.6269721160642803, 0.29778547876048833, 11.735309287905693, 40.87498426437378, 57.680950462818146, 54.72255080938339, 56.94297306239605, 54.94083769619465, 56.78632266819477, 54.830541014671326, 57.39694990217686, 53.054919093847275, 50.03770239651203, 41.26767039299011, 45.20146630704403, 49.21600788831711, 54.87654134631157, 58.55144955217838, 55.10816551744938, 56.19030945003033, 56.58725135028362, 56.55232362449169, 55.20870432257652, 55.60586281120777, 46.4917478710413, 42.051959708333015, 40.58904580771923, 42.24091976881027, 42.726347520947456, 43.090337589383125, 43.993442729115486, 43.703788071870804, 44.432250782847404, 44.06033053994179, 44.78286176919937, 42.00780227780342, 42.23990522325039, 41.841223016381264, 42.34921395778656, 41.62740848958492, 43.626690208911896, 45.36720581352711, 45.4655559360981, 45.830469354987144, 45.8355762809515, 46.64148263633251, 45.3071728348732, 45.043816566467285, 44.80517417192459, 46.55470669269562, 50.25636166334152, 51.96962133049965, 56.058053746819496, 58.46795663237572, 49.66987453401089, 26.63473729044199, 43.63934352993965, 49.0820574760437, 52.37271890044212, 56.41548916697502, 54.745516777038574, 54.48935352265835, 51.90844461321831, 50.751554891467094, 42.321931421756744, 38.53164620697498, 37.727715745568275, 40.50696641206741, 40.56124269962311, 39.45914603769779, 39.39296118915081, 40.6680853664875, 39.27850753068924, 39.26471047103405, 39.403847604990005, 37.13044859468937, 40.403053387999535, 38.49977731704712, 39.38399747014046, 37.73973070085049, 40.660831555724144, 47.725670859217644, 51.97137303650379, 50.884376764297485, 51.24196797609329, 51.76290102303028, 50.53158849477768, 48.087099865078926, 45.17002299427986, 41.477764919400215, 39.65558409690857, 36.35899879038334, 36.45287275314331, 37.18203082680702, 34.973931312561035, 37.46068127453327, 39.13400888442993, 40.712763369083405, 42.12098680436611, 43.85255768895149, 44.60835613310337, 46.94499135017395, 47.24074847996235, 51.091724038124084, 51.74520157277584, 52.12649591267109, 51.69149525463581, 50.578268989920616, 17.045056968927383, 0.34431968175340444, 3.5287003638222814, 5.167122334241867, 5.822079414501786, 7.49712310731411, 2.7377443062141538, 0.2488030938548036, 5.566203994676471, 63.17765191197395, 36.57487280666828, 33.138918578624725, 23.6023024097085, 44.33139279484749, 19.730490669608116, 0.13843607157468796, 0.04112907095986884, 0.029041852758382447, 0.04232967294228729, 0.05170145814190619, 0.011852875795739237, 0.05899730043893214, 0.012096260343241738, 0.07259254416567273, 0.04513020801823586, 0.09512555770925246, 0.022251062364375684, 0.004097743349120719, 0.03261133075284306, 0.026591878558974713, 0.031360169959953055, 0.04783935874002054, 0.04953537027176935, 0.0805965400650166, 0.11263109219726175, 0.09205319249304011, 0.144339841499459, 0.15525622526183724, 0.10999351419741288, 0.15288381662685424, 0.1175601030990947, 0.1621155845350586, 0.14529725653119385, 0.15295098099159077, 0.09754670318216085, 0.14855184126645327, 0.20414223487023264, 0.10420531150884926, 0.21868343115784228, 0.12649308977415785, 0.18587392842164263, 0.15751219092635438, 0.10365586247644387, 0.256663461914286, 0.12718673067865893, 0.3843410639092326, 13.68049805983901, 58.74446019530296, 41.85747094452381, 56.32442705333233, 46.740528121590614, 58.43057043850422, 39.281144589185715, 0.6287129572592676, 1.0433159535750747, 2.3242692556232214, 18.80065206438303, 8.27536029741168, 0.6157126079779118, 0.38253126258496195, 10.415561255067587, 41.604651510715485, 56.28980331122875, 56.768395230174065, 58.19261580705643, 55.932949259877205, 58.50162282586098, 56.1203134059906, 59.600033685564995, 56.354745626449585, 53.13552796840668, 44.18878264725208, 48.229394629597664, 53.272514417767525, 58.497332856059074, 60.39388708770275, 57.744277864694595, 58.45716521143913, 58.340116292238235, 59.000361263751984, 57.00437396764755, 58.098544254899025, 49.89999778568745, 44.847838282585144, 42.798756435513496, 44.92424838244915, 45.02687707543373, 45.84800161421299, 45.52821837365627, 45.83212986588478, 46.540324464440346, 45.792440995574, 47.40828908979893, 43.435256481170654, 43.97642724215984, 42.94135518372059, 43.61470565199852, 44.26808059215546, 45.061215832829475, 47.55699411034584, 47.90559120476246, 48.27362425625324, 47.43711814284325, 49.7357439994812, 48.01921270787716, 47.04168476164341, 46.88335865736008, 47.64732666313648, 53.373171016573906, 54.1878093034029, 58.31277295947075, 58.59646573662758, 50.873554944992065, 33.650599122047424, 44.30628754198551, 51.69537864625454, 55.79161584377289, 57.52616576850414, 56.01626358926296, 56.73630975186825, 53.39874744415283, 51.90402165055275, 44.61274869740009, 41.750430688261986, 40.985128954052925, 42.34445661306381, 42.580465748906136, 41.88889525830746, 40.53104192018509, 43.32829602062702, 41.94676235318184, 41.388222724199295, 40.891505777835846, 38.92840191721916, 43.58012370765209, 41.80998109281063, 41.314939856529236, 41.360636204481125, 43.127879574894905, 49.01048831641674, 55.497834607958794, 53.222854882478714, 52.78212413191795, 54.345949217677116, 52.981704622507095, 50.22028639912605, 47.42559716105461, 45.23043215274811, 42.119265496730804, 38.49584452807903, 39.39960703253746, 40.24255000054836, 36.7243567854166, 40.25760859251022, 42.27876573801041, 43.12110833823681, 44.63880389928818, 46.48245356976986, 48.38333576917648, 50.26340268552303, 47.92196832597256, 52.25653253495693, 54.32616367936134, 54.47505868971348, 53.22796180844307, 52.331757098436356, 18.341877982020378, 0.9056054649408907, 4.484191155061126, 8.23988065123558, 10.133563186973333, 8.19321820512414, 12.39113224670291, 1.6540986229665577, 7.581312814727426, 70.22399380803108, 41.87088422477245, 41.0220667719841, 31.703705191612244, 52.915348783135414, 26.54566816985607, 0.2073131498764269, 0.259630776126869, 0.2758643956622109, 0.13580202619777992, 0.1815809603431262, 0.10283768177032471, 0.13478538778144866, 0.13094054331304505, 0.18858693831134588, 0.1370748391491361, 0.2317355971899815, 0.16809941735118628, 0.11033375179977156, 0.22312619432341307, 0.14361034001922235, 0.06371191600919701, 0.13360126147745177, 0.16036583780078217], [0.06478802271885797, 0.09265118540497497, 0.0838935533829499, 0.04211194907838944, 0.050092029268853366, 0.03564389087841846, 0.03168222865497228, 0.06457308190874755, 0.05693104998499621, 0.087594962969888, 0.056249420740641654, 0.04947342320519965, 0.013315864089236129, 0.02576449707703432, 0.0623710555373691, 0.02797215634927852, 0.02672131096915109, 0.030694691704411525, 0.038996168223093264, 0.0596701649192255, 0.02427481929771602, 0.033233955546165816, 0.08204396552173421, 0.4974666639463976, 25.425091199576855, 49.703255742788315, 28.11399981379509, 37.595194056630135, 30.992495454847813, 48.78684751689434, 5.960750598460436, 0.7366778701543808, 0.8581376995425671, 2.6518052676692605, 7.003798903897405, 1.974145236890763, 0.14095115067902952, 1.2426986172795296, 20.81710696220398, 51.255784034729004, 51.80548533797264, 53.50348502397537, 51.17737904191017, 53.464153334498405, 54.50973562896252, 53.896779119968414, 51.720594093203545, 41.37574419379234, 41.66213862597942, 48.6324618011713, 52.773525193333626, 54.83942873775959, 56.611383855342865, 56.15131974220276, 55.33587969839573, 54.829545468091965, 53.58038529753685, 55.788568407297134, 50.51092520356178, 39.05829794704914, 43.17190021276474, 41.75779089331627, 40.57770721614361, 41.30296669900417, 42.10396371781826, 39.439983665943146, 43.34615506231785, 41.18961498141289, 40.946154445409775, 40.67556716501713, 41.995551735162735, 40.852831453084946, 40.36957338452339, 41.80440679192543, 41.33002124726772, 41.15368790924549, 42.642550617456436, 44.29603189229965, 44.98168610036373, 44.18506644666195, 45.37468001246452, 43.407430574297905, 42.97624111175537, 42.374934777617455, 46.31781980395317, 47.05749951303005, 50.69914050400257, 53.50429818034172, 55.29024414718151, 57.0634113997221, 53.02290961146355, 48.913798704743385, 53.28234829008579, 55.6489335000515, 54.096804186701775, 52.62229710817337, 50.98539434373379, 45.48894748091698, 40.44782258570194, 36.58968821167946, 37.03745238482952, 39.601915776729584, 40.729767456650734, 39.42610681056976, 37.673880234360695, 37.40912564098835, 38.261305913329124, 38.77148173749447, 36.79572835564613, 34.96827721595764, 37.90268495678902, 36.931476071476936, 37.39684469997883, 37.85001218318939, 38.14747542142868, 37.66150809824467, 46.24156169593334, 49.97940592467785, 48.88732552528381, 49.32896442711353, 47.60383039712906, 49.31025803089142, 48.360939770936966, 46.786114275455475, 45.67594304680824, 42.29464128613472, 40.20237855613232, 36.640913262963295, 35.06138741970062, 36.55976481735706, 36.79322429001331, 34.92367520928383, 34.672797471284866, 35.78651770949364, 36.3745741546154, 39.144781306385994, 41.02553978562355, 43.97609665989876, 45.40080741047859, 48.36858496069908, 49.070167914032936, 50.731602162122726, 46.16374187171459, 5.87535398080945, 0.9530184895265847, 1.5540922642685473, 5.179237984120846, 4.984663724899292, 7.519741868600249, 0.5596992198843509, 0.43725874624215066, 20.519347339868546, 41.32714860141277, 28.33178322762251, 40.63465096056461, 32.89145685732365, 41.6107539832592, 2.2442495869472623, 0.060280336474534124, 0.053364659324870445, 0.07759557687677443, 0.0949169771047309, 0.019880163999914657, 0.05612039094557986, 0.10701733132009394, 0.04370844231743831, 0.012463706007110886, 0.04512302031798754, 0.054112822108436376, 0.06320925196632743, 0.028350514367048163, 0.08094847391475923, 0.01632431183679728, 0.08074442783254199, 0.06805052616982721, 0.03975696978159249, 0.01710677483060863, 0.04106586224224884, 0.020100038236705586, 0.009493783145444468, 0.03685566960484721, 0.05010145454434678, 0.03891625747201033, 0.018865238089347258, 0.043080251416540705, 0.07081469972035848, 0.04343323169450741, 0.02971281919599278, 0.022479831241071224, 0.05547823282540776, 0.04114604016649537, 0.04712821428256575, 0.06061520834919065, 0.020060322203789838, 0.06641638377914205, 0.07189252079115249, 0.06300536173512228, 0.034412055611028336, 0.049401323558413424, 1.1759085324592888, 34.14018765091896, 49.56463158130646, 32.47816443443298, 47.1251130849123, 39.08984385430813, 53.68105709552765, 4.622490433976054, 0.4660298227099702, 1.3997032237239182, 1.8659441429190338, 5.545158823952079, 5.55808668024838, 0.32323122897651047, 2.3370016599074006, 25.109628327190876, 52.17728018760681, 54.99091520905495, 53.59609745442867, 53.42139042913914, 54.96064603328705, 58.40047985315323, 55.84957413375378, 52.36886590719223, 42.96187788248062, 44.261449947953224, 48.58741521835327, 55.639711394906044, 56.70461565256119, 57.74647034704685, 55.369029119610786, 57.599760219454765, 58.05189795792103, 54.736119881272316, 56.43574967980385, 51.942794770002365, 42.0419966429472, 43.56156550347805, 42.36297681927681, 44.19058375060558, 43.38323727250099, 45.23267023265362, 41.78432486951351, 44.155169650912285, 44.16789136826992, 43.396335169672966, 43.30427750945091, 41.9918317347765, 41.92063495516777, 41.54437534511089, 43.138142824172974, 42.35741011798382, 42.826247960329056, 43.555482029914856, 43.663331642746925, 45.86304120719433, 46.366024017333984, 46.21668063104153, 45.12333109974861, 43.95025044679642, 46.251262575387955, 48.680202439427376, 49.9943733215332, 53.4800972789526, 54.321645721793175, 56.8434602022171, 55.99656544625759, 52.43318125605583, 49.256882295012474, 54.0747881680727, 57.34615422785282, 55.42355999350548, 56.6939914226532, 52.33200028538704, 48.13120409846306, 43.83475564420223, 39.29878704249859, 39.63812403380871, 39.43352401256561, 41.78407408297062, 41.73238545656204, 39.810858964920044, 38.73451732099056, 39.84241247177124, 38.3436094969511, 37.92923793196678, 38.828615471720695, 40.167150646448135, 39.27496612071991, 38.16175505518913, 38.569541573524475, 38.951436281204224, 39.940834790468216, 48.69422748684883, 51.43415026366711, 51.67878873646259, 49.76249076426029, 50.32549895346165, 51.12034410238266, 50.94755977392197, 47.943026795983315, 47.349916622042656, 44.423701241612434, 41.98948726058006, 38.325826451182365, 37.166554257273674, 38.95622402429581, 38.217444866895676, 37.455110773444176, 37.78328016400337, 37.12638281285763, 39.44752246141434, 41.24286912381649, 43.937566727399826, 46.13558158278465, 47.33895421028137, 50.815011486411095, 52.21164554357529, 49.86038491129875, 46.963294968008995, 6.108346078544855, 1.4885411504656076, 4.7792434226721525, 6.999672325327992, 7.472993452101946, 8.378080185502768, 1.3362104119732976, 0.47867144749034196, 24.108931124210358, 50.233194306492805, 36.14472068846226, 41.91659577190876, 32.5135937333107, 48.15818265080452, 4.196260655298829, 0.09012936759972945, 0.08007641328731552, 0.056159476152970456, 0.05397983666625805, 0.05680325586581603, 0.04708634231064934, 0.04148463391175028, 0.027656025558826514, 0.017508057790109888, 0.06451507564634085, 0.029617931904795114, 0.032160008486243896, 0.03325507706904318, 0.05922067204664927, 0.036094181559747085, 0.09421883878530934, 0.06149564782390371, 0.02957739579869667, 0.21855435683391988, 0.18261134333442897, 0.12356979234027676, 0.1347155962139368, 0.17229869670700282, 0.0994190081837587, 0.08612936231656931, 0.1729345539934002, 0.10253950167680159, 0.16856695554452017, 0.1011333470523823, 0.14476334064966068, 0.09703686999273486, 0.17048836103640497, 0.08575417698011734, 0.15416641108458862, 0.1269500152557157, 0.11233873054152355, 0.13883280887966976, 0.29169262445066124, 0.15288418770069256, 0.06766961887478828, 0.2188879670575261, 1.0086875804699957, 38.50309833884239, 60.68177103996277, 37.322855070233345, 51.142352521419525, 43.61413188278675, 60.837091505527496, 7.90736049413681, 0.8057331677991897, 3.275720151141286, 4.939922075718641, 20.892588011920452, 6.025086846202612, 0.31358007341623306, 2.242648685351014, 24.977408722043037, 54.99281510710716, 54.1724619269371, 54.19016517698765, 54.91657979786396, 57.999973744153976, 62.681193351745605, 57.4991188198328, 56.09199732542038, 45.47476664185524, 46.83980159461498, 51.9096415489912, 58.75578358769417, 59.305226504802704, 60.336506366729736, 57.8091973811388, 58.699459210038185, 57.808616012334824, 57.13833957910538, 59.35733310878277, 54.37480866909027, 43.275912031531334, 48.456174060702324, 45.70025414228439, 46.332726404070854, 45.60520984232426, 46.695542335510254, 43.063917607069016, 46.22012324631214, 45.95388673245907, 45.01695200800896, 46.16163298487663, 45.60924902558327, 43.93578842282295, 44.00439754128456, 46.64100766181946, 44.37126025557518, 44.60774436593056, 45.11317044496536, 48.01092155277729, 49.667309671640396, 49.016005620360374, 49.13765229284763, 46.94270007312298, 46.02876551449299, 47.58314050734043, 50.37790194153786, 50.00509634613991, 54.6176802366972, 58.37162800133228, 57.265628948807716, 59.44232314825058, 52.522005289793015, 49.52405735850334, 54.68664273619652, 58.481727093458176, 57.74164080619812, 58.26225847005844, 54.08085264265537, 48.60560484230518, 45.60423709452152, 39.99366335570812, 41.69130586087704, 41.969070956110954, 44.90177258849144, 44.6585438400507, 41.64133474230766, 41.34898982942104, 41.56318813562393, 41.467482671141624, 40.00185951590538, 40.05764812231064, 43.226108103990555, 40.063123628497124, 41.29872992634773, 40.13918794691563, 42.66689211130142, 40.434781685471535, 50.528480261564255, 53.99297095835209, 54.30412106215954, 52.840838581323624, 51.97160862386227, 52.5709580630064, 53.57701487839222, 51.083698868751526, 50.59597223997116, 46.73450164496899, 44.611540362238884, 40.52506864070892, 38.92091251909733, 41.069723814725876, 40.79497955739498, 38.78461003303528, 39.53427940607071, 39.315137565135956, 41.392440497875214, 43.711858838796616, 46.002375930547714, 48.17743241786957, 50.11858865618706, 52.8840384632349, 54.64937053620815, 51.71932876110077, 47.42233693599701, 7.3837571404874325, 2.653245865367353, 6.584377409890294, 13.78044979646802, 12.002361807972193, 17.95450396835804, 6.743446849286556, 0.5248767009470612, 27.211438044905663, 51.71982653439045, 39.50423061847687, 50.37286341190338, 39.143504574894905, 61.271757781505585, 7.107815947383642, 0.24124581890646368, 0.20723100897157565, 0.1634722008020617, 0.3220574778970331, 0.11233242970774882, 0.1639066985808313, 0.17710658168653026, 0.1852421381045133, 0.08948711300035939, 0.1111936115194112, 0.14039277361007407, 0.11572881659958512, 0.11588094203034416, 0.1816095330286771, 0.11862075829412788, 0.17916586337378249, 0.13653369474923238, 0.2028246852569282], [0.06227678051800467, 0.045620730525115505, 0.024182431188819464, 0.051537810868467204, 0.06943570770090446, 0.05646945639455225, 0.050299875147175044, 0.04602061824698467, 0.11341809527948499, 0.05694292063708417, 0.10579640933428891, 0.12641035515116528, 0.056887474784161896, 0.049173016668646596, 0.013641870082210517, 0.03885929021635093, 0.02725241967709735, 0.03088093551923521, 0.060793141965405084, 0.03189093171386048, 0.013136746747477446, 0.015217395794024924, 0.034395565089653246, 0.02730228086875286, 2.875318774022162, 39.82200376689434, 29.868004694581032, 43.62891308963299, 37.62038290500641, 32.28016085922718, 27.11674902588129, 0.19278394669527188, 1.0746466973796487, 0.6710005912464112, 3.1095640920102596, 6.669948818162084, 1.2712680967524648, 0.17890833812998608, 5.420184480026364, 29.375116042792797, 52.82191939651966, 50.557643696665764, 54.3038322776556, 53.02742376923561, 55.81302009522915, 50.11006571352482, 42.93445475399494, 41.29132032394409, 48.98769333958626, 52.78800621628761, 55.859795585274696, 56.805929616093636, 55.76617620885372, 53.91432277858257, 58.197468146681786, 54.201043993234634, 52.36752077937126, 48.754222467541695, 42.77326740324497, 39.930757731199265, 41.264277175068855, 40.83775766193867, 42.12248772382736, 41.04931131005287, 40.26534877717495, 39.89029750227928, 42.75685988366604, 40.11776089668274, 42.62007862329483, 41.52519777417183, 41.936673894524574, 40.83758287131786, 39.86897684633732, 38.40525358915329, 41.20309665799141, 41.50453068315983, 46.991250067949295, 51.76580406725407, 52.73898124694824, 51.41502968966961, 51.82554826140404, 48.70270863175392, 49.449550956487656, 44.878282248973846, 44.85341638326645, 44.42375063896179, 47.72964544594288, 52.5478059053421, 53.83696652948856, 53.94378639757633, 49.08064775168896, 53.027332574129105, 54.220517948269844, 54.30986635386944, 53.5986091196537, 48.47601279616356, 41.5176247805357, 38.627792447805405, 38.572353422641754, 39.36469830572605, 41.558415591716766, 42.76247978210449, 43.56956027448177, 41.260948553681374, 39.624083787202835, 38.7050537019968, 38.850935474038124, 38.05269330739975, 38.01193289458752, 37.15917885303497, 37.71485723555088, 38.08718025684357, 36.99398271739483, 37.0677025616169, 37.927379831671715, 38.58959309756756, 47.59265519678593, 48.83540891110897, 49.548824429512024, 47.93048746883869, 47.86132737994194, 48.311907202005386, 50.772058591246605, 49.93682540953159, 48.332049921154976, 44.80541355907917, 45.92907786369324, 43.70055064558983, 39.97087977826595, 37.48819179832935, 37.31851950287819, 35.189486145973206, 35.24497836828232, 35.65111957490444, 37.47244544327259, 37.52301312983036, 39.94095258414745, 41.90939135849476, 46.26894682645798, 47.64527477324009, 46.83627538383007, 52.540578693151474, 33.88000041246414, 1.5464109764434397, 0.7483460940420628, 5.173635659739375, 5.5589839071035385, 4.3185466434806585, 7.072841674089432, 1.4239344047382474, 0.6366730551235378, 34.009634256362915, 33.55923682451248, 26.999871097505093, 41.33615791797638, 43.16499978303909, 27.47989933937788, 0.54626296274364, 0.18368419201578945, 0.0522557051590411, 0.008061950211413205, 0.03842581660137512, 0.01619025213585701, 0.04850797813560348, 0.09038316726218909, 0.028449459350667894, 0.022169656185724307, 0.05372837476897985, 0.044796634902013466, 0.05790029485069681, 0.03521652142808307, 0.03537996832164936, 0.057415071278228424, 0.04611721247783862, 0.05119602217746433, 0.07439879802404903, 0.02019959549215855, 0.12392378936056048, 0.10067425449960865, 0.03352265841385815, 0.06145840685348958, 0.02226781078206841, 0.04142895057157148, 0.03394000887055881, 0.02322728712897515, 0.06465491111157462, 0.07645733014214784, 0.08620990760391578, 0.03561642028216738, 0.03788803413044661, 0.06051691831089556, 0.0391293725988362, 0.06288367920205928, 0.07208498194813728, 0.05027466810133774, 0.0394218233122956, 0.03635523942648433, 0.058194070297759026, 0.07334036927204579, 0.06309066418907605, 5.970114720985293, 51.16893209517002, 29.048124589025974, 43.08092549443245, 40.92763043940067, 41.865629106760025, 27.707326635718346, 0.284090805798769, 1.0044804937206209, 1.182152428664267, 5.9343610145151615, 7.457495033740997, 3.2533920742571354, 0.7352838199585676, 8.194229900836945, 33.8297139108181, 53.580860272049904, 53.008261397480965, 57.13632568717003, 56.677078530192375, 57.24705174565315, 53.404245749115944, 44.94046211242676, 42.247789800167084, 51.6765658557415, 54.36984233558178, 57.8532750159502, 58.91730152070522, 56.55924305319786, 55.3751315921545, 58.70378337800503, 55.63566081225872, 56.04601979255676, 52.35802888870239, 43.71410071849823, 41.79026395082474, 42.784769386053085, 42.37585812807083, 44.011123180389404, 43.76551195979118, 44.451546147465706, 41.39047600328922, 45.47181040048599, 41.48340001702309, 43.832673355937004, 41.68044984340668, 43.41115817427635, 42.352322190999985, 42.54951260983944, 39.63381886482239, 42.15915575623512, 43.03127735853195, 48.584090396761894, 52.226719334721565, 53.496257811784744, 52.904587760567665, 50.54573513567448, 49.786991849541664, 49.723269268870354, 45.56809343397617, 46.311348751187325, 45.0520621240139, 49.995771646499634, 53.93014132976532, 57.96141721308231, 56.604437828063965, 49.162058383226395, 52.262931391596794, 57.19218648970127, 54.49549399316311, 54.701055362820625, 51.842191368341446, 46.175354048609734, 42.112612053751945, 39.94017742574215, 40.15069752931595, 43.01166281104088, 43.95560435950756, 45.669452995061874, 43.82924973964691, 40.999218598008156, 40.05961261689663, 40.335147231817245, 39.67532403767109, 39.807583540678024, 39.35005769133568, 39.837537333369255, 40.42959116399288, 39.456729367375374, 38.57094369828701, 38.35981942713261, 40.64039625227451, 50.26747606694698, 51.49418704211712, 50.43354995548725, 49.696001932024956, 51.52577854692936, 50.12646563351154, 51.266256272792816, 50.678074434399605, 49.1253637522459, 47.30688773095608, 47.61325389146805, 45.969842076301575, 41.99546433985233, 39.716035053133965, 38.89461413025856, 37.720176950097084, 36.12685024738312, 37.58795544505119, 38.781133219599724, 41.072064489126205, 42.59865537285805, 43.73349867761135, 48.44750672578812, 49.39492508769035, 49.26304556429386, 53.76107320189476, 35.13766832649708, 1.6573920962400734, 1.8596193823032081, 5.649368232116103, 10.973877646028996, 10.967569034546614, 6.13255980424583, 0.4252675693714991, 0.4544076416641474, 37.014448419213295, 36.358128637075424, 35.375729352235794, 44.844521060585976, 45.597146674990654, 35.73946863412857, 1.0648311115801334, 0.023723503763903864, 0.03672211641969625, 0.030015474440006074, 0.031906976946629584, 0.05466597074700985, 0.015433763383043697, 0.10511813088669442, 0.026638164454197977, 0.01909222952235723, 0.03020538446435239, 0.0801375662558712, 0.03789388225413859, 0.012573379663081141, 0.05586116618360393, 0.010574978205113439, 0.040575117091066204, 0.050066825933754444, 0.05520431725017261, 0.15313075884478167, 0.24854809191310778, 0.20972980535589159, 0.16714069613954052, 0.12987781752599403, 0.15285478380974382, 0.13636666699312627, 0.18278233415912837, 0.15360781137133017, 0.1596706680720672, 0.16170863527804613, 0.30030634661670774, 0.13076397153781727, 0.1384601171594113, 0.11765091971028596, 0.10482285259058699, 0.09493901889072731, 0.1619610545458272, 0.12182360791484825, 0.131951407820452, 0.16408052440965548, 0.1844647532561794, 0.11601320016779937, 0.10712991512264125, 6.147968927398324, 56.76802285015583, 40.520140305161476, 54.341324865818024, 49.122012332081795, 43.181859478354454, 32.20392934978008, 0.37026528327260166, 3.623771737329662, 3.6363257886841893, 12.075662724673748, 20.47229066491127, 2.725908891297877, 0.5469739402178675, 7.704242868348956, 33.4046421200037, 55.581487119197845, 52.19678074121475, 60.733425468206406, 59.325259029865265, 61.10110893845558, 55.73616921901703, 46.666173711419106, 46.55719555914402, 54.34323616325855, 58.430498242378235, 60.49915283918381, 62.55249045789242, 57.628650069236755, 56.34280286729336, 61.75079047679901, 59.203285574913025, 57.26347826421261, 52.962941229343414, 45.840588212013245, 44.742424339056015, 44.284955486655235, 44.21110264956951, 45.70079751312733, 45.389206632971764, 44.491907581686974, 43.427341505885124, 45.76287478208542, 44.26423519849777, 46.01620338857174, 45.26553466916084, 44.424465000629425, 43.63433159887791, 43.1967318803072, 41.96517236530781, 44.58996132016182, 44.96821202337742, 50.60999348759651, 55.88069446384907, 56.76611915230751, 54.73230868577957, 55.22624798119068, 53.05271901190281, 53.64041827619076, 46.55373774468899, 49.744931906461716, 48.05606313049793, 53.4332799911499, 55.22547282278538, 59.866919964551926, 57.175467386841774, 52.65124015510082, 54.41259004175663, 57.1791797876358, 56.627445593476295, 56.90908268094063, 53.123144432902336, 46.7723286151886, 43.38789202272892, 42.529544681310654, 42.121324986219406, 44.747637659311295, 47.11978577077389, 47.32805259525776, 45.14317363500595, 42.8405199944973, 42.37839259207249, 42.3634821921587, 40.843613147735596, 43.29465642571449, 41.23382940888405, 41.93704627454281, 41.885676831007004, 41.40873022377491, 40.906081795692444, 40.489988923072815, 42.35856145620346, 51.45038679242134, 52.42188826203346, 51.83794319629669, 50.69535210728645, 51.823154389858246, 53.37603606283665, 53.533621206879616, 52.594714388251305, 51.26205749809742, 49.07126985490322, 50.30276097357273, 49.15592551231384, 44.73859794437885, 41.58352464437485, 41.21927998960018, 40.10672248899937, 39.032018557190895, 41.191343888640404, 41.517913565039635, 42.127685844898224, 45.21209053695202, 44.57123592495918, 51.017901599407196, 51.620898842811584, 51.46502360701561, 55.533301904797554, 36.15349441766739, 1.877421427052468, 2.5304637663066387, 11.157291904091835, 11.532839052379131, 9.492564182728529, 15.172463301569223, 3.210020251572132, 0.7831285370048136, 41.56309314072132, 43.43582645058632, 38.885099440813065, 46.417492255568504, 52.32046030461788, 45.29361896216869, 1.43077700631693, 0.2717901236610487, 0.19106415304122493, 0.13417259644484147, 0.0742351841472555, 0.2636676438851282, 0.09116278597502969, 0.22706791874952614, 0.11981289979303256, 0.09442313719773665, 0.198179375147447, 0.2517833362799138, 0.11064604012062773, 0.08350827483809553, 0.12290344020584598, 0.14094107231358066, 0.12092502292944118, 0.13812383520416915, 0.18333941989112645], [0.08238233291194774, 0.011188194421265507, 0.03697214968269691, 0.020581478711392265, 0.013495474031515187, 0.03538335993653163, 0.04065571432875004, 0.018153646487917285, 0.05295520160871092, 0.025207813960150816, 0.02043708460405469, 0.02783501859084936, 0.02533897557441378, 0.025484343750576954, 0.04553029611997772, 0.04783207084983587, 0.07045083213597536, 0.05652509891660884, 0.026115508808288723, 0.003376862841832917, 0.06514696986414492, 0.037154209639993496, 0.019996068913314957, 0.011525647114467574, 0.126589598658029, 11.688270661979914, 46.21653623878956, 29.643560238182545, 45.999263897538185, 31.202985160052776, 38.012772649526596, 1.7365680914372206, 0.9893315378576517, 0.5169398768339306, 3.102297931909561, 3.845797860994935, 2.9143690411001444, 0.5159563233610243, 0.31849623774178326, 6.681681163609028, 36.36107727885246, 53.002671897411346, 54.93891879916191, 53.499765023589134, 52.225792184472084, 48.118493780493736, 40.81241302192211, 47.07157015800476, 54.304736629128456, 54.74613234400749, 58.05958114564419, 57.39459402859211, 55.62342166900635, 56.311800330877304, 54.71387207508087, 53.03319185972214, 48.52873496711254, 43.01833525300026, 42.04173445701599, 40.60723543167114, 40.39497122168541, 40.66639065742493, 40.78653261065483, 42.02486716210842, 41.297437995672226, 40.577988401055336, 38.961976915597916, 41.69423550367355, 42.533542066812515, 42.12819501757622, 42.195105627179146, 41.64180591702461, 39.08581227064133, 38.87325927615166, 39.172094240784645, 44.23493877053261, 52.65006981790066, 53.62323559820652, 54.31695677340031, 53.841435089707375, 53.30409832298756, 51.84644713997841, 53.07355709373951, 50.63471116125584, 49.286596700549126, 45.122236758470535, 47.26384364068508, 48.24643671512604, 54.54563230276108, 55.82481846213341, 56.54540799558163, 53.64570379257202, 53.03543373942375, 51.99226811528206, 48.35310459136963, 43.50777179002762, 40.22608548402786, 38.87205854058266, 40.56294120848179, 42.50662051141262, 46.408840119838715, 47.73042820394039, 49.89012211561203, 46.6815172880888, 39.40331183373928, 38.40864300727844, 37.711217030882835, 39.11201186478138, 38.41281898319721, 37.17528998851776, 38.349913358688354, 37.60259605944157, 36.11598663032055, 38.21538157761097, 36.46112211048603, 37.71374389529228, 45.95724195241928, 50.84432311356068, 51.010697185993195, 50.235945358872414, 51.53471566736698, 48.371924981474876, 47.92216971516609, 47.707124054431915, 49.535893723368645, 47.48268149793148, 49.28823821246624, 45.038208067417145, 45.15431083738804, 42.68366441130638, 42.94826701283455, 39.6425773948431, 39.71541948616505, 36.90602503716946, 37.261910140514374, 39.9642301350832, 41.06827609241009, 44.13480654358864, 49.23905745148659, 48.73674340546131, 52.26334556937218, 52.180054038763046, 20.83101611584425, 0.198164502508007, 1.2793051404878497, 2.7790796756744385, 12.273552305996418, 10.648270267993212, 4.566091960296035, 0.8068899682257324, 3.0886504892259836, 47.438421472907066, 40.00407099723816, 32.09017865359783, 37.44442954659462, 48.073010221123695, 8.26666921377182, 0.09900878605549224, 0.06534021027619019, 0.03490050381515175, 0.09726139935082756, 0.05065694836957846, 0.023610409734828863, 0.0690967688569799, 0.03353886691911612, 0.025136916592600755, 0.018696815095609054, 0.055715330454404466, 0.043373882144805975, 0.03380166883289348, 0.04462158824026119, 0.02354422500502551, 0.019741831383726094, 0.030094717258180026, 0.07300977216800675, 0.039223228304763325, 0.030610632347816136, 0.02540425117331324, 0.02846674768079538, 0.03439680076553486, 0.040248471923405305, 0.01304904344578972, 0.06165256381791551, 0.035748199734371156, 0.06133325106929988, 0.06575990963028744, 0.06694683383102529, 0.05285832907247823, 0.0627591839293018, 0.03655993117718026, 0.018522083846619353, 0.048781704463181086, 0.026309626809961628, 0.04111302943783812, 0.05726708332076669, 0.06108499896072317, 0.06377379628247581, 0.04599188228894491, 0.04678950921515934, 0.03683094495499972, 0.2537286834558472, 18.359932713210583, 51.856227815151215, 32.97256350517273, 50.84096409380436, 32.33624204993248, 43.15664783120155, 1.5519903833046556, 0.7024906890001148, 1.705130715854466, 1.9886481086723506, 5.686683654785156, 7.957950504496694, 1.2519517145119607, 1.4069673651829362, 9.99535035341978, 40.802571550011635, 51.680806428194046, 56.1299192905426, 56.554341316223145, 55.68121276795864, 50.28822295367718, 44.472426027059555, 49.36113730072975, 56.440404430031776, 57.14385308325291, 58.99675525724888, 58.82390633225441, 57.52403788268566, 57.53826431930065, 58.127168118953705, 55.968416556715965, 52.548717856407166, 45.09195998311043, 43.75750578939915, 42.5537645816803, 40.83879880607128, 42.35245518386364, 42.44171619415283, 42.89511166512966, 41.792483031749725, 43.29463742673397, 41.0069739818573, 43.90743434429169, 43.64543080329895, 44.17946934700012, 44.85701099038124, 43.367342725396156, 41.98915667831898, 41.99346944689751, 40.5671551823616, 44.02522422373295, 54.82344679534435, 54.636322036385536, 56.152706667780876, 55.36997526884079, 54.7313891351223, 54.286300018429756, 54.80673149228096, 54.2655835300684, 50.34916788339615, 46.21950387954712, 49.144214540719986, 51.47602021694183, 55.38583941757679, 56.98843762278557, 56.35875441133976, 55.78357547521591, 55.59567555785179, 55.31555838882923, 51.04677625000477, 45.72010427713394, 42.28645272552967, 40.552107989788055, 43.23705151677132, 44.08380568027496, 47.45271250605583, 48.22872966527939, 52.1193028986454, 47.4747209250927, 42.07769572734833, 39.483939707279205, 39.038725197315216, 39.534841775894165, 39.692993089556694, 39.92603078484535, 39.24235627055168, 39.66203235089779, 38.25136944651604, 39.54455405473709, 38.990137204527855, 39.29451987147331, 49.217068031430244, 52.8166376799345, 52.22423806786537, 51.164854913949966, 52.712014093995094, 49.539864510297775, 49.06600333750248, 48.21694269776344, 51.16982504725456, 49.17530447244644, 50.68952701985836, 48.166694194078445, 45.3509046882391, 44.57315482199192, 45.22470586001873, 42.07150585949421, 41.386850997805595, 39.267108142375946, 38.67405876517296, 41.68800003826618, 43.60214352607727, 45.516986176371574, 50.930863469839096, 49.642971977591515, 52.52589248120785, 52.69389666616917, 21.845679469406605, 0.18019336683209985, 3.8617296935990453, 5.1265504863113165, 15.700541865080595, 13.42280538752675, 2.154046702198684, 1.4588598744012415, 3.6433010268956423, 49.77676659822464, 44.35749739408493, 39.65170070528984, 37.61909477412701, 54.08325031399727, 14.154038149863482, 0.2199375123018399, 0.0975263534928672, 0.037532897913479246, 0.07937129877973348, 0.04096144577488303, 0.040826679178280756, 0.03250960828154348, 0.0378730316151632, 0.031370693614007905, 0.027667309914249927, 0.01013740979033173, 0.030309992034744937, 0.02014399564359337, 0.059872318524867296, 0.046644241228932515, 0.015071180641825777, 0.01557552008307539, 0.04021331638796255, 0.012441772760212189, 0.22278164484305307, 0.06069896342523862, 0.1675280972267501, 0.15163547970587388, 0.15983180317562073, 0.1025614989339374, 0.14324968593427911, 0.13132316496921703, 0.1706454885425046, 0.11990034705377184, 0.17108277679653838, 0.32702298020012677, 0.1713339937850833, 0.1435876006144099, 0.10166868043597788, 0.08701088532689027, 0.09749586606631055, 0.12231367029016837, 0.1412795955548063, 0.11813197983428836, 0.1486125192604959, 0.19518341403454542, 0.09469589873333462, 0.11543655142304488, 0.3714561037486419, 19.330431036651134, 63.684043139219284, 39.95338171720505, 58.35673280060291, 42.549645602703094, 48.38393613696098, 2.0324613014236093, 2.4445729376748204, 2.4447486782446504, 9.527194574475288, 13.337826747447252, 7.984580900520086, 2.7881362522020936, 1.042982640210539, 9.064802136272192, 41.257133558392525, 53.08348596096039, 58.137362971901894, 59.34371843934059, 57.20884099602699, 54.12893906235695, 45.76604001224041, 52.57898323237896, 58.6548838019371, 59.31390143930912, 61.62304513156414, 60.433378368616104, 58.51439394056797, 59.3733986467123, 60.053558349609375, 57.975328266620636, 53.878110721707344, 48.49536895751953, 47.28807874023914, 46.17573402822018, 42.6794808357954, 45.61430275440216, 43.873380571603775, 44.76826675236225, 44.940906688570976, 43.881303146481514, 40.91722659766674, 45.58969907462597, 46.47136576473713, 45.412746369838715, 47.64074921607971, 45.0190494954586, 44.12407971918583, 42.19068266451359, 43.408023342490196, 47.20289871096611, 57.90842145681381, 57.066880613565445, 58.87770004570484, 57.40397572517395, 58.21916118264198, 58.46584774553776, 56.8323989957571, 56.0822394490242, 52.70525425672531, 49.68625545501709, 52.26364955306053, 51.852959990501404, 57.689739391207695, 59.79288473725319, 58.365635722875595, 57.61567756533623, 57.46842406690121, 55.39439655840397, 52.27720342576504, 46.8829482793808, 45.2088189125061, 41.502452194690704, 45.352367609739304, 48.21563936769962, 50.257041826844215, 49.96852710843086, 54.80229713022709, 51.441772654652596, 43.94036717712879, 42.811284363269806, 40.573861822485924, 41.43130861222744, 42.33567148447037, 40.6816316395998, 42.2940219193697, 41.66599161922932, 40.57390742003918, 41.95995144546032, 39.33900788426399, 40.865188390016556, 50.07337108254433, 54.11617174744606, 54.16097894310951, 53.46326418220997, 54.3754356354475, 51.332319527864456, 51.20335444808006, 51.40662454068661, 53.308547884225845, 51.99421361088753, 53.9380145072937, 50.16560733318329, 48.48456233739853, 47.121431082487106, 46.325172409415245, 44.85973164439201, 44.79974426329136, 40.81170246005058, 40.837069898843765, 43.93528684973717, 45.12568697333336, 48.74109037220478, 53.91710042953491, 52.2406417876482, 54.943843334913254, 54.847412109375, 23.17450426518917, 0.6070864177308977, 5.577736850827932, 7.585195731371641, 20.441637709736824, 19.541011936962605, 14.154188241809607, 2.740322705358267, 4.553938787430525, 57.799162119627, 48.85749712586403, 44.06250782310963, 41.40894681215286, 63.88133615255356, 17.17409234493971, 0.3774706763215363, 0.3173941484419629, 0.15625010943040252, 0.2183183390297927, 0.1042807062913198, 0.16117400693474337, 0.1793484465451911, 0.16602990886894986, 0.16866141610080376, 0.13441143441013992, 0.1545301970327273, 0.1232745214656461, 0.10782409779494628, 0.1194309163838625, 0.12002144329017028, 0.22579139505978674, 0.12797557428712025, 0.24788188078673556, 0.1541562139755115], [0.04091412643902004, 0.011849323691421887, 0.04069615024491213, 0.03007574239745736, 0.011972716874879552, 0.004735043648906867, 0.046734957650187425, 0.055609648625249974, 0.00922093811823288, 0.04636012112314347, 0.010625849645293783, 0.03970598794694524, 0.018555638198449742, 0.038340618048096076, 0.020163050285191275, 0.04507116645982023, 0.048125311950570904, 0.03698439883009996, 0.02090344834869029, 0.020401554284035228, 0.06152808709884994, 0.055830111014074646, 0.06623725159442984, 0.041308867366751656, 0.03213438583770767, 0.6843144830781966, 25.957746617496014, 33.87600302696228, 31.495801247656345, 41.9175761193037, 37.02538043260574, 13.260774482041597, 0.2373775077285245, 2.102990741841495, 2.595038451254368, 2.3813811410218477, 7.875187145546079, 2.1431142138317227, 0.5909749260172248, 1.4434474264271557, 16.05488520115614, 51.745566353201866, 58.21983754634857, 56.224864795804024, 51.34514383971691, 46.25515356659889, 44.928633347153664, 54.26735043525696, 55.058099403977394, 57.65462547540665, 55.944466441869736, 58.77017341554165, 55.624816194176674, 54.68883141875267, 53.90810251235962, 49.8259511590004, 43.04322771728039, 43.044253662228584, 42.88978435099125, 42.14701920747757, 39.438414350152016, 40.02996660768986, 39.945576936006546, 42.4304535984993, 39.721575155854225, 42.30126433074474, 41.960194632411, 42.2472008317709, 41.50183282792568, 40.98226770758629, 41.258136704564095, 40.977848544716835, 39.52974624931812, 40.46275578439236, 37.6523619890213, 44.189865589141846, 52.38389790058136, 55.42412996292114, 55.87187513709068, 55.79136125743389, 54.18915443122387, 56.35534979403019, 55.47609597444534, 56.06452859938145, 54.0446899831295, 52.064844220876694, 49.76988896727562, 49.599992483854294, 53.949235305190086, 51.66635200381279, 52.98532962799072, 55.96058137714863, 52.831586077809334, 49.728303998708725, 43.733966052532196, 41.44101329147816, 41.537509113550186, 43.80800127983093, 44.69978682696819, 49.49145890772343, 52.028290182352066, 53.43025915324688, 52.03936658799648, 51.55996151268482, 42.788352593779564, 36.9619732350111, 38.62465001642704, 37.61693648993969, 38.45382258296013, 38.63330975174904, 36.42341673374176, 37.78899505734444, 36.92298352718353, 38.23683522641659, 37.487652227282524, 38.60600061714649, 47.034092769026756, 50.804558247327805, 51.43862642347813, 49.555265083909035, 49.57447685301304, 47.73423179984093, 44.232594296336174, 45.73633700609207, 46.68895348906517, 47.77503781020641, 45.150157660245895, 44.22946326434612, 44.10910852253437, 43.39914321899414, 41.56812787055969, 39.75057899951935, 40.56291460990906, 40.814860090613365, 41.61601670086384, 40.30677795410156, 44.05130982398987, 47.24700294435024, 51.38180047273636, 47.92770601809025, 52.10584782063961, 45.20854152739048, 6.24958117492497, 0.6698607711587101, 1.7747959401458502, 3.729320098645985, 20.179047100245953, 17.132412381470203, 3.4827876649796963, 0.9357930044643581, 9.03795562684536, 39.933535382151604, 33.135453164577484, 25.44269185513258, 34.28181365132332, 26.813071221113205, 1.8239130545407534, 0.14022608724189922, 0.08380278872209601, 0.06888307485496625, 0.07879516953835264, 0.02846236344339559, 0.046677864229422994, 0.10673142634914257, 0.0506660582323093, 0.028196084567753132, 0.035592129788710736, 0.04633544471289497, 0.05089983475045301, 0.04442570949322544, 0.03753391465579625, 0.08451747693470679, 0.03200495528290048, 0.032893536117626354, 0.06735146016580984, 0.04745364232803695, 0.038963235419942066, 0.02854644877515966, 0.0035454029557513422, 0.01537295736852684, 0.020805924577871338, 0.025708463072078303, 0.05810631875647232, 0.02049719485512469, 0.039986011397559196, 0.056119136716006324, 0.09310626293881796, 0.07297224918147549, 0.07259079269715585, 0.013479957578965696, 0.07436920117470436, 0.04411965892359149, 0.07054403846268542, 0.008130843780236319, 0.021166189035284333, 0.021337591751944274, 0.01741947875416372, 0.04019658837933093, 0.036921182691003196, 0.025218769915227313, 0.03996410690888297, 1.596458328422159, 36.569902673363686, 34.00643862783909, 39.57982376217842, 50.247625932097435, 43.93284738063812, 10.159257408231497, 0.3330529894446954, 1.6889154422096908, 2.178390333428979, 4.736612560227513, 8.924579210579395, 3.7273660534992814, 1.65695880074054, 2.2040553437545896, 18.560035675764084, 55.04696600139141, 58.616923838853836, 57.13627628982067, 53.29980455338955, 47.82093174755573, 47.87657216191292, 56.178526282310486, 55.844034031033516, 60.409120470285416, 56.50766082108021, 59.58859629929066, 56.63406863808632, 56.556134819984436, 55.2225735783577, 52.333463206887245, 45.66816106438637, 46.18516892194748, 44.209373742341995, 44.113288298249245, 41.89335621893406, 42.67640300095081, 43.507460206747055, 42.99482211470604, 43.40358518064022, 45.02268970012665, 43.846770599484444, 43.12532231211662, 43.445797115564346, 43.740893080830574, 42.64590963721275, 42.45996281504631, 42.54464887082577, 42.1545048058033, 40.16838937997818, 46.61630138754845, 52.757900431752205, 56.785889491438866, 57.69101232290268, 56.404317766427994, 55.677853748202324, 58.214643225073814, 57.035357505083084, 57.48141176998615, 56.06993570923805, 54.104050397872925, 52.6956407725811, 51.4536090195179, 56.51583418250084, 55.34738928079605, 55.60544863343239, 56.28257989883423, 55.77451676130295, 51.899446696043015, 46.836750358343124, 42.4855050444603, 44.148155227303505, 45.07301039993763, 46.25364504754543, 50.11533223092556, 53.63742023706436, 53.98516997694969, 53.42913441359997, 52.61152468621731, 44.64313946664333, 39.50589492917061, 41.58949792385101, 40.11280596256256, 39.710916727781296, 39.68893110752106, 39.29400309920311, 40.841675251722336, 38.71358044445515, 41.42490975558758, 39.252950102090836, 40.366187766194344, 48.76533307135105, 52.64802172780037, 52.47578077018261, 50.493381544947624, 51.16941846907139, 46.32793486118317, 47.35181272029877, 47.12986283004284, 48.96160773932934, 49.17820371687412, 46.499419659376144, 45.82023650407791, 47.52148501574993, 45.585143119096756, 44.64756242930889, 42.15249091386795, 42.90235787630081, 42.1498766541481, 45.41472986340523, 42.40033641457558, 45.56027725338936, 48.8338927924633, 52.64443852007389, 50.8401433378458, 53.15862312912941, 48.224671483039856, 6.969060217961669, 0.9414861677214503, 4.4366305321455, 2.7562908735126257, 13.06125858798623, 10.712476372718811, 0.8022432925645262, 0.8113959920592606, 9.994993172585964, 45.101972445845604, 45.862600430846214, 29.201339967548847, 37.934968024492264, 38.114705979824066, 2.295480575412512, 0.10528542581596412, 0.005465778949655942, 0.010465089326316956, 0.01819350723962998, 0.033101697408710606, 0.023575308005092666, 0.014789080105401808, 0.03455316757026594, 0.10366303904447705, 0.037593464585370384, 0.02744028879533289, 0.023599969572387636, 0.0027877339562110137, 0.018640157686604653, 0.07935497153084725, 0.03799649901338853, 0.05420904897619039, 0.04646169145416934, 0.06729818138410337, 0.1496906075044535, 0.20100076828384772, 0.19154312030877918, 0.13324506027856842, 0.10220366501016542, 0.129066115769092, 0.10269714126479812, 0.17578189261257648, 0.19115505128866062, 0.1268917418201454, 0.21768825565231964, 0.14305968128610402, 0.17860812455182895, 0.11091834152466618, 0.22376001812517643, 0.19441621145233512, 0.12098920386051759, 0.1107205443258863, 0.18696046230616048, 0.09254460557713173, 0.2539021975826472, 0.16928810044191778, 0.1233925303677097, 0.12056696636136621, 0.22356055851560086, 1.6212200559675694, 39.377427622675896, 45.86149848997593, 41.944991648197174, 53.24498109519482, 47.83803842961788, 16.422270387411118, 0.5078298063017428, 7.397107249125838, 7.995948940515518, 9.739165250211954, 18.3242754265666, 7.7731735445559025, 2.229187195189297, 2.382893697358668, 20.823260731995106, 55.38556583225727, 61.39104478061199, 61.4954973757267, 56.554212123155594, 52.09577836096287, 51.145430356264114, 58.60534965991974, 59.14173647761345, 60.486845299601555, 58.23593728244305, 60.15461012721062, 58.59733588993549, 58.632898181676865, 59.85522799193859, 53.91165532171726, 47.17662692070007, 49.14392575621605, 48.62084962427616, 47.5396366417408, 44.882963597774506, 44.359404891729355, 45.75466722249985, 47.08720251917839, 44.41954426467419, 47.16385580599308, 45.72908699512482, 45.79127065837383, 46.70515961945057, 45.39879731833935, 45.458495914936066, 44.939542561769485, 45.75313590466976, 43.784499540925026, 41.52155376970768, 47.60784678161144, 55.21891437470913, 60.23359268903732, 57.85280384123325, 57.18588262796402, 57.29259990155697, 60.19058659672737, 58.16542066633701, 59.7640784829855, 59.30015757679939, 57.621445655822754, 55.8678587526083, 54.78370472788811, 58.224659487605095, 56.24116592109203, 55.76860807836056, 59.90909390151501, 58.394825756549835, 54.83379743993282, 49.30279143154621, 46.42128825187683, 46.4310347288847, 48.48999984562397, 49.7201344370842, 54.10118155181408, 57.509746849536896, 57.511160373687744, 54.831578359007835, 56.34334243834019, 47.54522614181042, 40.35226531326771, 42.38295614719391, 42.83685319125652, 40.34666061401367, 42.918070033192635, 39.68627505004406, 43.032899871468544, 40.15876069664955, 43.98977592587471, 41.65516600012779, 43.34151931107044, 50.471236333251, 55.312928929924965, 55.16767792403698, 53.98523077368736, 53.05440992116928, 49.356379956007004, 48.08561034500599, 49.562545493245125, 51.317458525300026, 52.54157043993473, 47.934298664331436, 48.23246106505394, 49.679632410407066, 48.43832641839981, 47.28488311171532, 44.83341425657272, 43.29542778432369, 46.04405589401722, 48.30339565873146, 45.44695973396301, 46.97673864662647, 52.141189724206924, 54.69536326825619, 54.39669169485569, 53.90332616865635, 47.68616437911987, 7.310840478166938, 1.45615418208763, 6.386578073725104, 9.594290424138308, 32.04960823059082, 27.40833017975092, 9.925987925380468, 1.8045420502312481, 11.938377991318703, 53.04651394486427, 43.87861289083958, 33.856369480490685, 44.58816401660442, 46.731180623173714, 2.5580842467024922, 0.17918391240527853, 0.16857335285749286, 0.17787644115742296, 0.15993827168131247, 0.16342215036274865, 0.1200283007347025, 0.15490499645238742, 0.1353823416866362, 0.20186553359963, 0.10951007920084521, 0.09323805352323689, 0.13482408336130902, 0.12254662302439101, 0.1664186458219774, 0.2293406124226749, 0.13952312496257946, 0.12906302843475714, 0.1670190878212452, 0.13628004351630807], [0.019740593852475286, 0.02309684354258934, 0.0901398021960631, 0.05374791180656757, 0.02652920789842028, 0.048170861264225096, 0.05498056343640201, 0.046715068092453294, 0.07555225878604688, 0.10410910690552555, 0.02340797411306994, 0.014817236260569189, 0.07430384022882208, 0.032992367923725396, 0.029107319460308645, 0.04699235301814042, 0.030466646421700716, 0.024027290783124045, 0.016136680205818266, 0.07531661947723478, 0.029111573821865022, 0.032032648523454554, 0.02666859993041726, 0.05804469081340358, 0.10004697644035332, 0.09158759130514227, 4.958548676222563, 41.535286232829094, 23.837447091937065, 35.8841572701931, 35.09523220360279, 28.842751309275627, 0.5149689700920135, 1.1559244547970593, 0.49369999731425196, 4.379930924624205, 5.722834439948201, 1.0665695182979107, 2.8724810387939215, 0.7075131882447749, 5.259621245786548, 41.670638769865036, 58.233672603964806, 58.10104452073574, 52.25482262670994, 48.57429452240467, 52.20114290714264, 56.44439421594143, 58.311560824513435, 57.82706022262573, 56.26089446246624, 58.09955880045891, 56.384577825665474, 55.72639614343643, 51.07105694711208, 44.28915046155453, 41.320521757006645, 42.29202702641487, 43.17129224538803, 41.1644983291626, 41.820301339030266, 40.66149652004242, 41.65555737912655, 41.90339908003807, 40.46385392546654, 42.005267813801765, 42.3406758159399, 43.21581445634365, 41.76410235464573, 42.41262875497341, 41.14608071744442, 40.68166583776474, 39.89280916750431, 40.65480887889862, 36.61915563046932, 41.868433356285095, 50.98574012517929, 53.61182101070881, 53.24465811252594, 54.57897551357746, 54.71343509852886, 53.77859026193619, 51.89692743122578, 53.20982538163662, 56.41841500997543, 54.436638951301575, 53.3762526512146, 51.8505585193634, 54.36357267200947, 55.06311893463135, 55.86538888514042, 54.00323420763016, 53.71315397322178, 46.894693449139595, 42.26999580860138, 44.39918875694275, 47.02520504593849, 52.45862849056721, 51.63026534020901, 50.72307161986828, 53.17136384546757, 53.28699164092541, 52.09646612405777, 52.14446894824505, 44.27090764045715, 37.00762398540974, 37.97516606748104, 38.22507105767727, 38.55326324701309, 38.09367410838604, 40.06543770432472, 37.817463129758835, 37.79732421040535, 37.439212426543236, 36.9445663690567, 35.25781787931919, 45.267259776592255, 48.5233848541975, 50.47345161437988, 50.60940831899643, 49.567390233278275, 45.61766937375069, 44.09048952162266, 41.35259583592415, 41.43833063542843, 41.862026900053024, 43.05208504199982, 40.83024926483631, 40.84307357668877, 41.285920813679695, 42.97382064163685, 42.1581906080246, 41.63017474114895, 40.583380311727524, 41.79650701582432, 42.438965141773224, 47.9824610799551, 48.42380739748478, 50.40921226143837, 50.307677909731865, 54.072930067777634, 25.361932888627052, 0.5957133905030787, 0.5381099658552557, 3.245618878863752, 2.2270015999674797, 9.924475606530905, 8.65405747666955, 0.11353082751156762, 0.3588857251452282, 15.088257919996977, 39.018590077757835, 38.39250527322292, 24.344847165048122, 38.130440935492516, 8.88204239308834, 0.21669554407708347, 0.05227533125435002, 0.029259257498779334, 0.052738323793164454, 0.028868509325548075, 0.01768162015650887, 0.022454883946920745, 0.04288667703804094, 0.03184229135513306, 0.027475837669044267, 0.03715655853739008, 0.05563200582400896, 0.03596117014240008, 0.028215630882186815, 0.042443106503924355, 0.013940208809799515, 0.01375293619275908, 0.09381562995258719, 0.07002202662988566, 0.05035492024035193, 0.044084195396862924, 0.056475931633030996, 0.07749790282105096, 0.06871027318993583, 0.013623876711790217, 0.036247234675101936, 0.02872420613130089, 0.03680660251120571, 0.029497531431843527, 0.077921231277287, 0.024816778204694856, 0.007351534914050717, 0.03804397420026362, 0.034961423007189296, 0.0011074558392465406, 0.06951809351448901, 0.0377869387739338, 0.020273524532967713, 0.06233601874555461, 0.04619137158442754, 0.023740821779938415, 0.038349453316186555, 0.01555013677716488, 0.029717299912590533, 0.12158613550127484, 0.05530700451345183, 9.455870501697063, 48.619424700737, 26.641559824347496, 45.28774447739124, 39.497641772031784, 30.580622255802155, 0.47074952570255846, 0.7247268583159894, 0.29144637985154986, 3.428533226251602, 5.4135410115122795, 4.612869825214148, 3.9275388373062015, 1.193807115778327, 6.30034645088017, 45.3353863209486, 62.20896989107132, 58.48876811563969, 54.557472467422485, 50.43314717710018, 54.51671205461025, 58.47723953425884, 61.087049692869186, 59.47025544941425, 56.86604619026184, 59.2450225353241, 57.518296390771866, 56.830856278538704, 54.56655018031597, 45.71138754487038, 44.65353190898895, 44.40714552998543, 45.45517109334469, 43.848324716091156, 43.838916420936584, 41.61916673183441, 41.96530915796757, 44.62140463292599, 43.83305333554745, 43.3073515444994, 44.40217159688473, 45.703005194664, 44.731070548295975, 43.47716063261032, 43.56956407427788, 42.41165220737457, 41.83121435344219, 40.853268429636955, 39.46519151329994, 44.64782081544399, 51.60678260028362, 55.73428072035313, 55.95835469663143, 55.24062640964985, 55.18695808947086, 55.97063563764095, 54.3484228849411, 56.524672508239746, 58.981145694851875, 56.33879788219929, 55.28357930481434, 53.79422642290592, 54.668787494301796, 57.52440266311169, 57.66077734529972, 57.02337294816971, 55.083311051130295, 48.41709315776825, 44.40724812448025, 45.21982692182064, 47.18682937324047, 51.98204666376114, 51.46393686532974, 53.945743292570114, 56.54177539050579, 55.433067083358765, 54.53770212829113, 53.77743512392044, 46.00110299885273, 37.96894960105419, 38.35349656641483, 39.57701951265335, 39.03520658612251, 39.35831844806671, 41.815122216939926, 39.72968392074108, 38.378461226820946, 39.074811860919, 40.07746785879135, 39.62433837354183, 47.96183578670025, 50.18889248371124, 53.187277391552925, 50.962359979748726, 51.36407822370529, 48.991645127534866, 45.96201829612255, 44.012323915958405, 45.321661457419395, 44.69994641840458, 45.78696548938751, 44.50125887989998, 45.039279609918594, 44.10255767405033, 44.3007892370224, 40.638519152998924, 44.495980963110924, 42.281687781214714, 43.189937844872475, 44.43685233592987, 50.510343834757805, 50.03454476594925, 51.98756396770477, 50.591473281383514, 54.999479949474335, 26.070779152214527, 1.196510789450258, 2.998872706666589, 4.562271265313029, 6.419480983167887, 7.301872009411454, 4.760545575991273, 0.17590486648259684, 0.39717181760352105, 16.49132028222084, 46.061116978526115, 44.847975075244904, 22.667292281985283, 43.505317121744156, 13.75296302139759, 0.33816255745477974, 0.1807953673414886, 0.030415384426305536, 0.07563417704659514, 0.036789900477742776, 0.009966338257072493, 0.028821885753131937, 0.018919552167062648, 0.05512700401595794, 0.03113436781859491, 0.02453647459333297, 0.007470885248039849, 0.0208608861794346, 0.03610220788687002, 0.046140066915540956, 0.021706298139179125, 0.041605663354857825, 0.011923525471502217, 0.08900697313947603, 0.025563089329807553, 0.10703290899982676, 0.11193515805643983, 0.17878668528283015, 0.22512800409458578, 0.13932258181739599, 0.1358140935190022, 0.07241204642923549, 0.08150036461302079, 0.18243474187329412, 0.20184997818432748, 0.11376877489965409, 0.13357123418245465, 0.2248534539830871, 0.165203868818935, 0.1667105473461561, 0.13723895768634975, 0.13007217115955427, 0.11083199264248833, 0.12130368893849663, 0.18767132103675976, 0.10940625274088234, 0.0945772515842691, 0.1555463604745455, 0.18299234710866585, 0.21842269983608276, 0.34560980158858, 10.140652656555176, 58.07488292455673, 34.244697242975235, 47.37402252852917, 44.91694517433643, 36.589916199445724, 0.801945305429399, 3.4093333315104246, 2.3592789145186543, 11.856227349489927, 15.033247321844101, 4.466384360566735, 7.341768918558955, 2.280710767954588, 6.421545222401619, 47.01558776199818, 63.579993322491646, 64.06576305627823, 56.990322321653366, 52.41969957947731, 57.33484223484993, 61.168076545000076, 63.157440796494484, 59.64964002370834, 56.41723707318306, 62.3336374014616, 60.94526030123234, 60.10798282921314, 56.15954630076885, 49.49177049100399, 45.53954176604748, 47.59415611624718, 49.090405628085136, 45.944828018546104, 46.064126417040825, 44.762156680226326, 44.71905559301376, 47.47480072081089, 45.038971826434135, 46.72346703708172, 47.04483099281788, 47.39982694387436, 45.984000116586685, 45.44458866119385, 45.67275121808052, 44.607801362872124, 44.20858718454838, 44.076517671346664, 40.803369507193565, 45.83493031561375, 53.83595198392868, 57.81575582921505, 55.21518677473068, 58.7279386818409, 58.84445562958717, 56.42312295734882, 56.22028984129429, 57.96185038983822, 60.879888609051704, 59.01810251176357, 56.461831480264664, 55.884585455060005, 58.33890035748482, 57.82107174396515, 58.69396850466728, 58.67376118898392, 57.332797944545746, 50.28260685503483, 45.0505156069994, 48.41325156390667, 50.07199935615063, 54.737962782382965, 53.50828416645527, 55.933549627661705, 58.245641961693764, 55.63574060797691, 56.09851777553558, 55.871552154421806, 46.420083716511726, 40.29597893357277, 41.228809878230095, 41.716703698039055, 41.68798103928566, 41.617042645812035, 43.71050611138344, 41.62268914282322, 41.293277218937874, 41.9430385529995, 41.95033796131611, 40.60214750468731, 49.57522161304951, 53.36652137339115, 55.40202274918556, 54.058688431978226, 52.33578488230705, 49.88026924431324, 47.16805078089237, 45.27888335287571, 46.803186759352684, 46.86612278223038, 48.344612047076225, 44.80143517255783, 44.64461378753185, 45.88629595935345, 47.21417270600796, 46.198650598526, 45.88991716504097, 45.22385090589523, 45.82000091671944, 47.78072610497475, 51.76890850067139, 53.18822734057903, 53.12078095972538, 52.990896329283714, 55.3855050355196, 28.948336243629456, 0.6376148702111095, 1.868653753772378, 10.016131438314915, 7.287886384874582, 20.968889817595482, 20.758837088942528, 2.1163717238232493, 0.696941917994991, 19.215401709079742, 51.447783932089806, 48.22309456765652, 32.02622048556805, 54.58464480936527, 16.893585696816444, 0.5075280787423253, 0.33126856957096606, 0.12840821669669822, 0.22184438654221594, 0.12149801288614981, 0.12851612496888265, 0.11717918096110225, 0.1499750281800516, 0.1032579451566562, 0.11778000887716189, 0.09589052642695606, 0.14482431550277397, 0.1391797629185021, 0.08682832441991195, 0.13280777202453464, 0.19479660666547716, 0.12080518834409304, 0.10373220720794052, 0.21773878106614575, 0.12297317982302047], [0.025223649536201265, 0.0802012425265275, 0.04282471512851771, 0.039567247149534523, 0.012705897552223178, 0.012383150515233865, 0.021961929051030893, 0.019783005736826453, 0.03506649627524894, 0.040488946324330755, 0.08728103450266644, 0.04223798430757597, 0.03568996340618469, 0.0506963786756387, 0.017873339165817015, 0.04192431559204124, 0.0723808391194325, 0.0324944424937712, 0.05183298897463828, 0.05826441847602837, 0.03554579750925768, 0.03667634446173906, 0.013833866469212808, 0.0174040346610127, 0.011126763147331076, 0.07013340073172003, 0.12918837717734277, 20.963980481028557, 34.66382995247841, 27.64949183911085, 39.025448709726334, 24.350056685507298, 5.545629523694515, 0.37424099806230515, 1.0401071445085108, 2.537892130203545, 5.185886677354574, 5.334604047238827, 1.7181577230803668, 0.4929319932125509, 1.0576586402021348, 31.978517845273018, 63.56691062450409, 56.66452780365944, 56.73184499144554, 52.6858638972044, 56.27831652760506, 55.53380347788334, 59.61517207324505, 56.08516149222851, 59.34919014573097, 53.69893133640289, 56.056758016347885, 49.433891996741295, 47.29832299053669, 44.373201951384544, 43.15950907766819, 44.17083241045475, 41.72967620193958, 40.23055784404278, 41.03533945977688, 39.02759559452534, 41.8860188126564, 42.360742539167404, 41.9801739603281, 46.78251586854458, 46.79742246866226, 42.2708697617054, 41.65960036218166, 41.13233685493469, 43.218751698732376, 40.37751875817776, 41.62440665066242, 38.18200036883354, 39.97026041150093, 36.98994353413582, 43.03772181272507, 48.70930887758732, 52.714955136179924, 53.10422524809837, 55.77065996825695, 51.08120620250702, 53.23955878615379, 49.95099864900112, 53.67002248764038, 54.09656099975109, 54.19350519776344, 54.76744160056114, 55.14824956655502, 52.96962507069111, 51.813936084508896, 55.25145962834358, 50.886390656232834, 48.87013144791126, 46.66636370122433, 49.63132560253143, 51.48322083055973, 50.40668919682503, 51.30975253880024, 55.37153698503971, 52.89813190698624, 52.5383710116148, 55.51540106534958, 52.30232007801533, 42.549147829413414, 38.2658276706934, 38.458887711167336, 37.843985706567764, 38.496574088931084, 37.65065588057041, 38.307963609695435, 37.660778537392616, 37.584930807352066, 37.54710003733635, 37.3208449780941, 37.48808540403843, 42.391433492302895, 48.751942589879036, 50.078360214829445, 50.055523440241814, 48.840599432587624, 49.1481739282608, 45.153072103857994, 42.29792430996895, 39.797327890992165, 38.53772968053818, 37.52920679748058, 38.97064045071602, 38.84124219417572, 40.70705987513065, 43.28260727226734, 41.5606726706028, 44.798744916915894, 44.59743171930313, 46.458663046360016, 47.479520067572594, 48.85360613465309, 47.39045664668083, 50.857295617461205, 52.51109227538109, 39.93562527000904, 4.11533972248435, 0.833053404930979, 1.8940390041097999, 2.3923385655507445, 3.491279734298587, 1.3232928863726556, 3.4681584499776363, 0.17828591371653602, 0.09506202244665474, 21.396330781280994, 41.586549282073975, 26.699880994856358, 32.28502459824085, 28.158159144222736, 1.772851157002151, 0.03250411267799791, 0.00772400120695238, 0.009258827540179482, 0.05445107446576003, 0.025560796093486715, 0.013223522364569362, 0.0224936908489326, 0.04008583026006818, 0.06429805682273582, 0.05020830896683037, 0.07068910606903955, 0.017916589677042793, 0.03742396547750104, 0.053133020192035474, 0.04485583231144119, 0.01802964659873396, 0.026535994838923216, 0.02452946315315785, 0.06059538558474742, 0.05484215660544578, 0.017827455885708332, 0.04551621386781335, 0.047460533169214614, 0.06143666563730221, 0.013475334926624782, 0.08431862588622607, 0.03667252240120433, 0.03278550168033689, 0.02325899724382907, 0.010488226707821013, 0.12065620961948298, 0.024213345350290183, 0.05049998413596768, 0.0310517519392306, 0.043737994637922384, 0.038763371339882724, 0.02341387418709928, 0.020659604597312864, 0.025737180476426147, 0.03386691845662426, 0.01909753031213768, 0.012088120838598115, 0.039510502538178116, 0.020692312900791876, 0.05823011641041376, 0.07474314712453634, 0.42241763323545456, 30.10180614888668, 33.46925385296345, 31.814875826239586, 46.068826764822006, 31.154397167265415, 4.866481041535735, 0.23535039072157815, 0.6477587821427733, 0.9020605520345271, 5.617306502535939, 5.410489775240421, 4.890514276921749, 2.3096189042553306, 1.7350205057300627, 33.16351845860481, 66.29850044846535, 58.69070827960968, 60.3785815089941, 53.82358364760876, 59.171925857663155, 57.099414467811584, 60.50011418759823, 56.5292626619339, 60.28700642287731, 55.131845846772194, 57.470677345991135, 53.49382974207401, 48.67980346083641, 46.66062220931053, 45.26082292199135, 45.011385306715965, 43.80526162683964, 43.80149222910404, 43.86712610721588, 42.004762440919876, 43.69928151369095, 44.26527254283428, 42.2910200804472, 48.455771282315254, 46.19680389761925, 43.417249247431755, 44.75178323686123, 42.09981054067612, 44.35771778225899, 41.98518209159374, 43.96720513701439, 41.85879707336426, 41.591849997639656, 41.10788516700268, 45.65731264650822, 52.405735328793526, 52.99083553254604, 56.167677864432335, 56.83107666671276, 52.492883652448654, 55.06029948592186, 50.137409046292305, 55.820159912109375, 55.65879017114639, 56.707883477211, 54.76390399038792, 55.8178686350584, 55.12217916548252, 54.84260156750679, 57.39554017782211, 52.183029279112816, 50.722828432917595, 47.05606319010258, 51.313882917165756, 52.7263393253088, 53.35130698978901, 52.99353338778019, 56.23070888221264, 54.488262981176376, 55.55341422557831, 56.20310336351395, 53.80062147974968, 44.060919508337975, 39.1711138933897, 40.094680935144424, 39.94235470890999, 40.53196147084236, 38.84394384920597, 40.023875534534454, 38.67410436272621, 39.8614152520895, 39.804866686463356, 40.712455585598946, 39.338616505265236, 44.22458432614803, 51.67218089103699, 52.38549381494522, 51.949816793203354, 51.19177646934986, 50.113063752651215, 46.379444897174835, 43.67367468774319, 41.90729387104511, 40.88872812688351, 40.154554322361946, 40.69369599223137, 40.484517216682434, 42.326931953430176, 43.785039111971855, 44.836640283465385, 46.69787161052227, 46.31341964006424, 47.429887130856514, 47.955642119050026, 51.55725985765457, 49.54755149781704, 52.5797051936388, 51.569628193974495, 42.26943723857403, 4.536099219694734, 2.2331978799775243, 5.654356889426708, 3.559269248507917, 9.62935684248805, 7.460853103548288, 1.7041717423126101, 0.4389369796263054, 0.3586812486173585, 21.674983128905296, 52.86890387535095, 29.160739146173, 30.678155422210693, 38.26909549534321, 3.445215281099081, 0.08950136965722777, 0.04545116091321688, 0.06377335841534659, 0.017373832961311564, 0.016207199078053236, 0.04471761843888089, 0.04532019411271904, 0.039514714226243086, 0.021989045271766372, 0.011846573106595315, 0.026240308361593634, 0.023753505083732307, 0.061934821133036166, 0.001215262529967731, 0.06851096943137236, 0.04439430180354975, 0.01880306281236699, 0.018865050697058905, 0.09119312497205101, 0.026083312586706597, 0.10816043912200257, 0.18561857024906203, 0.15012273041065782, 0.198094651568681, 0.10576373999356292, 0.14160720922518522, 0.19548303389456123, 0.1280869112815708, 0.111822336766636, 0.1494781899964437, 0.2626655367203057, 0.15426094585563987, 0.11140545757371001, 0.12038782675517723, 0.09119542562984861, 0.12375476522720419, 0.09815824028919451, 0.15068205742863938, 0.16839235788211226, 0.11563574385945685, 0.12535696558188647, 0.12634016282390803, 0.16202970320591703, 0.10531713778618723, 0.10394374156021513, 0.2133738246629946, 0.5976562737487257, 34.259394854307175, 47.527644485235214, 37.558510825037956, 48.764006942510605, 36.506651267409325, 6.877305116504431, 0.5208912491798401, 3.9019783213734627, 8.232120517641306, 13.139368146657944, 13.117450922727585, 7.314767092466354, 3.236094689927995, 1.890431810170412, 35.0360731780529, 68.44347774982452, 62.349702939391136, 62.54965201020241, 58.001182079315186, 60.20447485148907, 60.33011130988598, 61.65607675909996, 58.52175414562225, 63.059231266379356, 57.92191073298454, 59.93210926651955, 54.75335955619812, 49.664083644747734, 49.91317927837372, 47.93072685599327, 48.632104620337486, 46.49459011852741, 45.78782804310322, 46.6607666015625, 42.638477236032486, 45.07841370999813, 47.88750037550926, 44.10298325121403, 51.20840437710285, 50.2470825612545, 46.741523668169975, 46.95516720414162, 45.24615950882435, 47.95640587806702, 43.87255221605301, 45.48148088157177, 42.75880917906761, 45.30668266117573, 42.530772015452385, 47.33143821358681, 52.96002298593521, 56.05982445180416, 56.671530827879906, 58.511156514286995, 55.279391929507256, 56.70135922729969, 52.3456035554409, 55.74284166097641, 55.742511078715324, 58.6540250480175, 56.81944169104099, 58.34882162511349, 56.78705982863903, 56.22822001576424, 60.36872483789921, 55.149245113134384, 53.73390845954418, 49.920721873641014, 53.18234905600548, 55.22190101444721, 54.834314212203026, 53.66357423365116, 58.998476564884186, 57.17010207474232, 57.60031118988991, 59.74609024822712, 55.302939265966415, 46.38386785984039, 41.227574944496155, 41.357436776161194, 40.91114692389965, 43.54512758553028, 41.301211193203926, 41.91634498536587, 41.71590954065323, 42.12884858250618, 42.87295885384083, 41.08892418444157, 42.57770709693432, 45.894157737493515, 52.5687275826931, 54.473876953125, 54.46280814707279, 53.58284376561642, 52.52562269568443, 49.20136347413063, 45.474960431456566, 44.09990921616554, 42.6753618568182, 40.93838766217232, 43.94032917916775, 42.74034596979618, 44.90552298724651, 46.59392058849335, 46.33210703730583, 49.69545096158981, 49.75237190723419, 51.7436246573925, 51.20320625603199, 53.09287145733833, 50.45268572866917, 55.07640682160854, 52.885782569646835, 41.80775061249733, 5.306137874722481, 1.0196274309419096, 5.8175961300730705, 6.264726687222719, 14.496940299868584, 12.671477403491735, 9.884792435914278, 1.338294600136578, 0.7185378216672689, 27.94530026614666, 55.00840187072754, 32.60290414094925, 40.84510266780853, 46.95518620312214, 3.323694714345038, 0.1912737949169241, 0.11787038762122393, 0.16116821818286553, 0.14378104882780463, 0.10348831521696411, 0.1036483964708168, 0.10291263868566602, 0.12047639465890825, 0.11004976156982593, 0.10188414817093872, 0.1339967519743368, 0.08429463225184008, 0.0939886542619206, 0.09701416027382948, 0.14632562088081613, 0.14023713039932773, 0.19536362233338878, 0.09845452048466541, 0.20656671258620918, 0.18930165620986372], [0.044486803089967, 0.005476035430547199, 0.01562765410199063, 0.03434984879277181, 0.03699486311234068, 0.04966759130184073, 0.04925805566017516, 0.03802771745540667, 0.012031152655254118, 0.02212703835539287, 0.05181996057217475, 0.030310240654216614, 0.011121067163912812, 0.04250663434504531, 0.03408806362131145, 0.04600671411026269, 0.05257523313048296, 0.05257261705992278, 0.07031056622508913, 0.05743437825003639, 0.024447019823128358, 0.0254959305311786, 0.04378296136565041, 0.05323244200553745, 0.016647776901663747, 0.016512472247995902, 0.19691016903379932, 3.9408295741304755, 37.35319264233112, 25.000481083989143, 35.87259829044342, 39.77686978876591, 11.793332174420357, 0.08594904269557446, 0.47514114005025476, 0.9489745565224439, 2.217455324716866, 4.906217409297824, 3.413920160382986, 1.2609603186137974, 0.21048832481028512, 14.239297024905682, 59.640045538544655, 58.87413963675499, 57.75648660957813, 55.66260136663914, 59.53329786658287, 56.94189012050629, 60.3350168466568, 58.98222863674164, 57.50228025019169, 55.00543802976608, 53.53286124765873, 46.79969094693661, 50.19589550793171, 45.1347266882658, 46.73719570040703, 43.86849783360958, 42.87360101938248, 42.50775285065174, 40.97401075065136, 41.283150762319565, 42.32674576342106, 44.11546178162098, 53.91225188970566, 54.948482885956764, 56.891048848629, 50.61843663454056, 44.49644073843956, 42.00942479074001, 42.91420944035053, 41.12613558769226, 39.25042323768139, 38.96583370864391, 40.57661287486553, 38.94510202109814, 40.27424789965153, 44.95095334947109, 49.67601120471954, 50.38169413805008, 53.06387901306152, 53.1802249699831, 53.83851684629917, 56.36181324720383, 51.50476947426796, 52.45043233036995, 53.1929998844862, 51.85721576213837, 50.911207124590874, 51.976134181022644, 54.99918736517429, 54.96481440961361, 51.96636490523815, 49.501961544156075, 51.90481960773468, 51.790096163749695, 56.8137001991272, 64.00460913777351, 54.34298537671566, 50.42603775858879, 56.11395254731178, 53.34527671337128, 52.915033400058746, 50.08582681417465, 38.456056863069534, 37.437308728694916, 38.344304859638214, 38.58876474201679, 38.66019330918789, 38.180168867111206, 37.84671016037464, 38.96427199244499, 39.00562897324562, 36.39651797711849, 38.51046994328499, 36.98150798678398, 40.9145325422287, 49.79481562972069, 50.31730659306049, 49.58673879504204, 50.598609298467636, 48.92728418111801, 45.97653351724148, 43.16269710659981, 38.78219336271286, 38.70109811425209, 38.0449341237545, 42.60960638523102, 47.36329950392246, 50.013136714696884, 46.399861201643944, 46.223463267087936, 48.60714375972748, 47.187802121043205, 48.34870062768459, 48.4328281134367, 50.49341954290867, 49.026063680648804, 48.84685769677162, 47.41209648549557, 10.542553290724754, 0.1284706758451648, 4.63565862737596, 5.990444580093026, 1.3427132880315185, 7.4603083077818155, 5.7444030325859785, 0.4362492176005617, 0.23750448919599876, 0.5584219540469348, 24.546684734523296, 40.08561082184315, 26.501843221485615, 40.0785356014967, 14.430649057030678, 0.2242215003934689, 0.14602752984501421, 0.03737359591468703, 0.058285402701585554, 0.059794133267132565, 0.03819057805230841, 0.062012130656512454, 0.03006461018230766, 0.03705292874656152, 0.018212031245639082, 0.05786105008155573, 0.017555245394760277, 0.01748085251165321, 0.05232909243204631, 0.04822851871722378, 0.06748645682819188, 0.03360527058248408, 0.0825365140917711, 0.02468804712407291, 0.02677846932783723, 0.03804143605520949, 0.0158772866052459, 0.04676288466725964, 0.02798865614749957, 0.0404766303836368, 0.02322106978681404, 0.04665204120101407, 0.020561485252983402, 0.018349527090322226, 0.01784466629032977, 0.03209077724022791, 0.08430053232586943, 0.029567849924205802, 0.06652660013060085, 0.07478701547370292, 0.07027889878372662, 0.09472584439208731, 0.017474525702709798, 0.06615571925067343, 0.07915620211861096, 0.02772700085188262, 0.018316432870051358, 0.03067970959818922, 0.07274577539646998, 0.030925516330171376, 0.04550079574983101, 0.043026041239500046, 0.14919596607796848, 6.517388429492712, 44.13755379617214, 24.916480891406536, 43.88468116521835, 45.10888047516346, 13.940844889730215, 0.2099277509842068, 0.345719312899746, 0.32452707819174975, 3.345574177801609, 5.550914090126753, 5.1293086633086205, 3.732689805328846, 0.30623551283497363, 16.453747898340225, 63.58061648905277, 60.39717011153698, 60.84399193525314, 58.009165450930595, 60.438473895192146, 57.715122029185295, 60.11503145098686, 60.44712223112583, 59.34013523161411, 56.95489302277565, 55.749981477856636, 49.33151789009571, 50.20081624388695, 46.413985043764114, 49.473535269498825, 46.187274008989334, 44.46696572005749, 44.425072968006134, 43.855612725019455, 42.58805014193058, 43.42695772647858, 45.3022824972868, 53.24471890926361, 55.381693840026855, 56.23162843286991, 52.61413894593716, 45.81753484904766, 42.970112040638924, 44.29983548820019, 43.35435502231121, 41.198658496141434, 41.53148643672466, 41.3610427826643, 40.48810042440891, 42.825586795806885, 47.00005799531937, 51.77566073834896, 52.36213646829128, 55.093825086951256, 55.72505101561546, 55.61513811349869, 57.45199754834175, 52.84945651888847, 54.49498102068901, 55.32655879855156, 53.42205159366131, 53.18331800401211, 51.76692120730877, 56.21424436569214, 56.64149723947048, 53.493282571434975, 51.82883508503437, 52.987613305449486, 54.52287532389164, 55.790711492300034, 59.644616693258286, 57.44221307337284, 52.42819972336292, 55.44071987271309, 55.383871123194695, 52.899237647652626, 50.276481583714485, 40.94039015471935, 38.4019173681736, 40.280350372195244, 39.6600678563118, 40.28055936098099, 39.642357006669044, 38.59352208673954, 40.418275371193886, 40.53676821291447, 37.72235803306103, 38.92602704465389, 38.84934715926647, 43.613698706030846, 50.720590353012085, 52.303099036216736, 52.131363451480865, 51.55421622097492, 49.56713564693928, 46.83639697730541, 44.26551952958107, 40.5181036144495, 39.96774114668369, 39.24641065299511, 44.568089693784714, 48.52988250553608, 50.34914128482342, 47.894628793001175, 49.11754757165909, 48.74412260949612, 49.62941810488701, 48.275049179792404, 50.60150854289532, 52.2779443860054, 52.44700491428375, 47.70740523934364, 50.37238463759422, 9.757201932370663, 0.4390092648100108, 6.627368303015828, 4.965844759717584, 5.109755387529731, 7.384337559342384, 2.655158112756908, 0.4198719479609281, 0.16661458765156567, 0.430563060217537, 28.937567621469498, 51.2251690775156, 23.33555292338133, 43.432676419615746, 20.811599157750607, 0.4254490393213928, 0.16550449799979106, 0.006556981870744494, 0.06942191859707236, 0.033692606521071866, 0.055463861135649495, 0.02136270788469119, 0.051260321852169, 0.05247464985586703, 0.04208116479276214, 0.033464488878962584, 0.024023362966545392, 0.040416568372165784, 0.0594532277318649, 0.039907837272039615, 0.05145472001458984, 0.015420146828546422, 0.02355570046347566, 0.01591323067259509, 0.018640287562448066, 0.039541817459394224, 0.17360465397359803, 0.20196866244077682, 0.10206684266449884, 0.11886732943821698, 0.1643998408690095, 0.14281315467087552, 0.11651336317299865, 0.16314093576511368, 0.039646363802603446, 0.08161063291481696, 0.198488553869538, 0.10033370519522578, 0.06783427917980589, 0.0887058541411534, 0.10812509062816389, 0.12745531392283738, 0.21912309428444132, 0.22190864168806002, 0.1665512824547477, 0.13579024089267477, 0.06942375912331045, 0.07649801467778161, 0.11178991975612007, 0.10077005092171021, 0.1563353673554957, 0.10019908702815883, 0.2705293631879613, 7.679868601262569, 54.0164764970541, 35.60847446322441, 46.18598207831383, 50.931798219680786, 18.4775136038661, 0.28919642558321357, 1.0672824550420046, 4.94462052360177, 9.697745572775602, 13.87073865160346, 10.3057243488729, 3.203518087975681, 0.5313903233036399, 17.91702277958393, 62.250212877988815, 62.06336170434952, 63.11160005629063, 60.18132269382477, 62.76043429970741, 58.72370570898056, 63.966056406497955, 63.53619687259197, 61.3836769759655, 60.144164487719536, 59.21245068311691, 51.36644169688225, 55.7571554929018, 49.009317979216576, 52.656438276171684, 49.8243248462677, 47.49183140695095, 46.711474880576134, 46.62917509675026, 44.99647870659828, 46.943528428673744, 47.48786821961403, 57.264196425676346, 59.98888202011585, 60.89357167482376, 57.12367616593838, 49.38322551548481, 45.57127386331558, 45.443205535411835, 45.68612650036812, 42.456467002630234, 43.18195067346096, 43.43093991279602, 42.32027851045132, 44.452659487724304, 50.84907665848732, 52.95868545770645, 55.29019854962826, 56.6394529491663, 57.713560312986374, 57.40228481590748, 60.405620858073235, 53.69452357292175, 54.86434780061245, 57.02000252902508, 52.69129380583763, 53.28515253961086, 54.13374200463295, 58.424042388796806, 58.40128920972347, 55.53400866687298, 52.93650604784489, 56.912183314561844, 56.58458389341831, 57.75715917348862, 62.1543288230896, 60.02409093081951, 52.656730860471725, 58.09667095541954, 59.43898692727089, 54.53163765370846, 53.07978115975857, 42.657111436128616, 40.29335707426071, 42.856919914484024, 42.54891984164715, 42.23520487546921, 41.1470040678978, 40.86990013718605, 43.05588863790035, 42.952507585287094, 39.679557010531425, 42.37418621778488, 41.51965767145157, 44.23300847411156, 52.80963845551014, 53.712971583008766, 53.78660403192043, 53.60007204115391, 51.29726640880108, 50.08636258542538, 46.928264647722244, 42.12194435298443, 41.94282956421375, 42.49057397246361, 48.41170124709606, 52.08007000386715, 54.366924092173576, 51.130956932902336, 50.66415198147297, 52.04525247216225, 50.39859563112259, 50.24320676922798, 51.81842744350433, 54.40556041896343, 54.310584515333176, 49.84488934278488, 48.08250971138477, 12.455309852957726, 0.29783303558360785, 8.882605712860823, 11.242888011038303, 8.108626194298267, 17.438066080212593, 12.255165092647076, 3.1866947282105684, 0.7200067990925163, 1.0843070852570236, 34.734889939427376, 51.796046644449234, 33.791867941617966, 52.74337761104107, 24.920730963349342, 0.4057221009861678, 0.3833480109460652, 0.13735884422203526, 0.20974444050807506, 0.13741395610850304, 0.10793967245263048, 0.15175756299868226, 0.10095957317389548, 0.17302457650657743, 0.09488001072895713, 0.1617492752848193, 0.18913522217189893, 0.07034077905700542, 0.20596912043401971, 0.1253627988626249, 0.09444284864002839, 0.10515303409192711, 0.15308421134250239, 0.10296316409949213, 0.1914247774402611, 0.13231937948148698], [0.03431618126342073, 0.0632436727755703, 0.020878072464256547, 0.018660796813492198, 0.0650930157280527, 0.03521158614603337, 0.08578498353017494, 0.051369232023716904, 0.0047169343179120915, 0.06878567539388314, 0.023725264509266708, 0.056536271949880756, 0.031184429390123114, 0.02888679584430065, 0.017435503577871714, 0.055923970430740155, 0.006495070056189434, 0.007819767943146871, 0.03879943229549099, 0.07404785123071633, 0.059406962245702744, 0.032868473790585995, 0.0275576520289178, 0.0085202811351337, 0.04283435562683735, 0.01634236457903171, 0.05321475662640296, 0.13112186483340338, 20.77606726437807, 38.05287949740887, 24.210201390087605, 44.747903645038605, 25.241589546203613, 2.577388873323798, 0.36682753649074584, 0.36370306508615613, 2.765732891857624, 3.9716478204354644, 3.9783829590305686, 4.107568189501762, 0.1347240715404041, 2.2162982868030667, 43.87610882520676, 61.57897509634495, 62.297881320118904, 58.934453800320625, 60.48200435936451, 58.31295154988766, 60.73740005493164, 56.90292701125145, 54.96681310236454, 53.806062787771225, 48.773027658462524, 48.898713514208794, 50.495475232601166, 49.92761090397835, 47.33583837747574, 43.32652911543846, 41.84971936047077, 40.25625966489315, 41.69893965125084, 41.65786385536194, 44.470351338386536, 52.80949406325817, 56.14635340869427, 58.51557567715645, 58.387305960059166, 55.90223170816898, 50.95500737428665, 46.17013692855835, 42.40814119577408, 39.893918707966805, 39.41483661532402, 39.900693744421005, 39.11419674754143, 42.00011909008026, 40.13442300260067, 39.725040569901466, 43.480337262153625, 47.90509723126888, 52.38441467285156, 54.84348312020302, 53.80968019366264, 55.58047257363796, 58.102754428982735, 56.6376518458128, 55.752268955111504, 51.5875518321991, 52.89498947560787, 49.00172218680382, 52.24540673196316, 55.45578606426716, 54.926968440413475, 54.399636536836624, 53.234030082821846, 53.65604303777218, 58.56844983994961, 62.58152090013027, 56.1209973692894, 52.24290266633034, 54.2514368891716, 52.607561498880386, 51.493704468011856, 42.10085928440094, 37.39007726311684, 37.13295266032219, 37.637675777077675, 38.18082623183727, 40.21586403250694, 38.654771000146866, 37.92283907532692, 36.37704022228718, 39.752429500222206, 36.64956919848919, 39.72488857805729, 37.08107404410839, 40.721039324998856, 45.59498079121113, 49.80099029839039, 52.15888537466526, 49.58178386092186, 49.02870833873749, 48.153246715664864, 43.71821589767933, 41.5091398358345, 36.68676160275936, 40.24732254445553, 48.41007113456726, 51.37806907296181, 49.17326398193836, 49.008630216121674, 49.6217805147171, 51.807126849889755, 49.13285315036774, 49.232597798109055, 49.2627377808094, 53.24287220835686, 46.42116665840149, 50.60714364051819, 15.156431961804628, 0.12764223123667762, 0.44300317706074566, 6.668346729129553, 4.240780966356397, 3.1858473736792803, 5.091098388656974, 2.9207719350233674, 0.2641563629731536, 0.08143429120536894, 2.150294641032815, 34.64541994035244, 33.45633454620838, 28.692000098526478, 32.793973088264465, 4.000878939405084, 0.17002886772388592, 0.052280259114922956, 0.02144811052858131, 0.11635858085355721, 0.049529347743373364, 0.017916018223331776, 0.001599627885298105, 0.017608757952984888, 0.04696770629379898, 0.046126467059366405, 0.023402999868267216, 0.020168629380350467, 0.0515645467385184, 0.06319554449873976, 0.06548232413479127, 0.00538824678187666, 0.052243582176743075, 0.0594074372202158, 0.03511670627631247, 0.026348101600888185, 0.024811419898469467, 0.031809881766093895, 0.043100597395095974, 0.013506786217476474, 0.043857825512532145, 0.020007859784527682, 0.030904741761332843, 0.04432902249391191, 0.01741757514537312, 0.029236685077194124, 0.05892751258215867, 0.03170573247189168, 0.039165047637652606, 0.0300870434512035, 0.028757161198882386, 0.01643928906560177, 0.021521100752579514, 0.054745996530982666, 0.015101709814189235, 0.004543382156043663, 0.03203005100658629, 0.07775656355079263, 0.03094159867032431, 0.05239549980615266, 0.01164709679869702, 0.07085965902660973, 0.038502369134221226, 0.05599514981440734, 0.5117510771378875, 27.518146187067032, 36.8895111232996, 26.76332999020815, 55.51398754119873, 28.838358744978905, 2.5781010976061225, 0.07787040158291347, 0.5510644207242876, 1.9421956012956798, 3.695322135463357, 6.4087712578475475, 4.876853534951806, 0.9765025356318802, 3.292185617610812, 47.34078571200371, 63.77065569162369, 65.5074816942215, 60.41114196181297, 62.128144428133965, 60.57646729052067, 60.60767501592636, 58.43668811023235, 57.49810427427292, 56.462013870477676, 50.3251987695694, 51.883909329771996, 51.25475808978081, 51.9664940983057, 49.63878080248833, 45.51894687116146, 43.28782059252262, 42.4386003613472, 43.37221786379814, 44.80292849242687, 45.091769993305206, 54.86526735126972, 57.79849335551262, 59.82878901064396, 60.60195252299309, 56.693638041615486, 52.306606248021126, 46.62256345152855, 44.498538225889206, 42.07589462399483, 41.856642588973045, 41.685275584459305, 41.11817881464958, 42.7427626401186, 41.95683181285858, 42.498933523893356, 46.83900363743305, 49.95112024247646, 53.608180806040764, 54.75903645157814, 54.46548320353031, 57.043238282203674, 58.18426005542278, 57.54751302301884, 56.07929840683937, 53.586339578032494, 53.31541031599045, 52.246554270386696, 52.47499041259289, 56.66196294128895, 56.15558311343193, 57.869184762239456, 54.175353571772575, 56.71351857483387, 59.416397139430046, 61.82132229208946, 59.046745374798775, 51.98753356933594, 57.05016151070595, 53.82707566022873, 53.508614748716354, 43.93853947520256, 40.0151702016592, 38.53201098740101, 38.955965638160706, 39.894648268818855, 41.67474254965782, 40.875174254179, 40.35595491528511, 38.44451688230038, 41.78837925195694, 37.80230574309826, 41.7364626377821, 39.23327095806599, 42.66732908785343, 48.61758939921856, 51.938660591840744, 52.51443989574909, 51.33893497288227, 49.441480189561844, 50.3735663741827, 44.963139295578, 42.41249956190586, 39.08325880765915, 41.858109310269356, 50.245824828743935, 54.63550128042698, 51.12995758652687, 50.725659281015396, 51.41698278486729, 53.499696627259254, 50.75654402375221, 52.68677204847336, 51.62550039589405, 55.204976722598076, 46.829796731472015, 53.25773321092129, 18.20907510817051, 0.4136166226817295, 2.230357057414949, 9.773506857454777, 3.4000307181850076, 5.758824683725834, 5.506327757611871, 1.4383731549605727, 0.28156352578662336, 0.1100163946102839, 1.854317004326731, 40.349252074956894, 37.33860522508621, 28.155997060239315, 41.27476841211319, 6.40991167165339, 0.1211163040716201, 0.05720506203942932, 0.047221758286468685, 0.027758597789215855, 0.027257803958491422, 0.00895125185707002, 0.03350270948430989, 0.031701216503279284, 0.007988970191945555, 0.05465590351377614, 0.041731357196113095, 0.036305968242231756, 0.011328172749927035, 0.04104352730792016, 0.06792862099246122, 0.05085361008241307, 0.05484920329763554, 0.0487564269133145, 0.04779795061040204, 0.04602929395332467, 0.041025092359632254, 0.13277159974677488, 0.11955453592236154, 0.0804290224914439, 0.10123253508936614, 0.23061284649884328, 0.17527571821119636, 0.20324938668636605, 0.15474785410333425, 0.08454417940811254, 0.18799072655383497, 0.1193600932310801, 0.096182546694763, 0.10575921289273538, 0.2093933304422535, 0.11175909094163217, 0.11075917311245576, 0.15980147902155295, 0.11709789352607913, 0.1897625150741078, 0.13503002934157848, 0.12584281997988, 0.0746453543251846, 0.16350384597899392, 0.1080082765838597, 0.26531717099715024, 0.1931208372116089, 0.15723833843367174, 0.555031051626429, 31.75640646368265, 52.35733352601528, 32.21847876906395, 57.10381843149662, 36.29217937588692, 4.960658513009548, 0.8317774452734739, 0.8915414102375507, 8.01850263029337, 14.243654441088438, 10.155274271965027, 7.7048190124332905, 0.6838944274932146, 3.179080174304545, 49.17739816009998, 63.45260135829449, 67.05087527632713, 64.34673517942429, 63.76529797911644, 61.641983315348625, 64.05735030770302, 60.389384329319, 60.87443210184574, 57.84539803862572, 52.4706244468689, 54.376089200377464, 55.857967883348465, 54.31116208434105, 52.97729305922985, 48.683006688952446, 46.67501203715801, 44.89313565194607, 47.55332350730896, 46.87904208898544, 49.656837433576584, 57.03709401190281, 58.35299000144005, 63.51645693182945, 62.994684129953384, 59.593380242586136, 54.3042616546154, 49.349186941981316, 48.03345434367657, 43.683147579431534, 42.98960119485855, 43.680772706866264, 43.10422584414482, 46.67794547975063, 42.94939175248146, 45.43051041662693, 47.98871174454689, 51.842396557331085, 56.14534266293049, 58.009868413209915, 57.637834176421165, 60.287154614925385, 61.829685643315315, 61.02390468120575, 57.706135511398315, 56.042162999510765, 54.305017814040184, 51.94358512759209, 52.53705248236656, 59.87378239631653, 58.70900809764862, 61.694728285074234, 58.07206727564335, 57.919657453894615, 62.976076528429985, 65.06784528493881, 58.78304712474346, 54.675904512405396, 57.958305180072784, 57.28153109550476, 55.722634345293045, 45.669658184051514, 42.31356047093868, 40.45530058443546, 39.96564745903015, 41.65807664394379, 44.168761521577835, 42.63355270028114, 41.39079138636589, 40.34741297364235, 44.22221705317497, 39.80553165078163, 43.611589819192886, 41.2255534529686, 43.998998031020164, 50.947962552309036, 53.88278067111969, 56.24093413352966, 53.23097884654999, 51.978630647063255, 52.351341247558594, 47.38930530846119, 45.622932091355324, 40.87707035243511, 43.815661668777466, 53.363299146294594, 55.16933083534241, 53.47791999578476, 52.31053903698921, 54.55235034227371, 55.02527676522732, 53.8006404787302, 53.9326985925436, 53.34477514028549, 56.85955233871937, 48.939454928040504, 52.32633478939533, 18.335771709680557, 0.27460859273560345, 2.1128329262137413, 11.223066374659538, 13.944735880941153, 10.093792621046305, 13.47634831443429, 9.964707847684622, 1.5271175117231905, 0.294348414754495, 3.6358230281621218, 46.73506781458855, 43.195477947592735, 36.094897761940956, 49.42469649016857, 7.221536245197058, 0.34821987559553236, 0.43024120561312884, 0.10769822212751023, 0.22907600709004328, 0.08052087810938247, 0.08369881383259781, 0.09639592899475247, 0.08808273210888728, 0.13794564554700628, 0.14879001129884273, 0.11507660237839445, 0.10053723919554614, 0.14766613254323602, 0.1803576634847559, 0.13532259879866615, 0.0820541477878578, 0.08745417755562812, 0.21228874538792297, 0.12352147852652706, 0.09252982199541293, 0.2317347956704907], [0.04079894883034285, 0.0551543892652262, 0.028380614021443762, 0.042561594091239385, 0.06164917962451, 0.05144419636053499, 0.03103876249952009, 0.025008975899254438, 0.040842802336555906, 0.013722837466048077, 0.09288493965868838, 0.0879038151470013, 0.07290338529855944, 0.039493492513429374, 0.05673675943398848, 0.05635492816509213, 0.06809016427723691, 0.011283437015663367, 0.062058388721197844, 0.030295481192297302, 0.04523292125668377, 0.06049988602171652, 0.014269128660089336, 0.034676237919484265, 0.04466953469091095, 0.03582140889193397, 0.036254863953217864, 0.3101232385961339, 3.742200694978237, 36.824310421943665, 26.98504239320755, 33.98219212889671, 43.767366260290146, 10.084256082773209, 0.03683674483909272, 0.04338460617873352, 0.5168013030197471, 0.7403783965855837, 5.83369966596365, 5.127674276009202, 0.7037671830039471, 0.02518876859539887, 10.410548374056816, 55.509522780776024, 59.675075858831406, 60.006524473428726, 56.84959687292576, 60.5793247371912, 60.08808709681034, 56.00533537566662, 52.772256061434746, 50.46333655714989, 49.39810931682587, 48.86606186628342, 49.22232694923878, 50.42819224298, 44.637489169836044, 43.11010032892227, 41.69795170426369, 41.05202816426754, 43.168184012174606, 42.24133774638176, 54.0337997674942, 57.536440417170525, 56.215475499629974, 57.150753512978554, 55.75527459383011, 55.8781486004591, 54.15077269077301, 53.22149075567722, 46.74124248325825, 39.512168392539024, 39.52987544238567, 39.80997361242771, 39.853203892707825, 40.13688147068024, 41.45960569381714, 39.91602212190628, 41.80217631161213, 42.95134864747524, 47.154409512877464, 49.32839825749397, 51.463511288166046, 53.59154149889946, 53.22806440293789, 56.46772876381874, 54.30480882525444, 55.922256633639336, 51.47060930728912, 48.14200311899185, 45.76116867363453, 55.37007786333561, 51.99317626655102, 56.54882401227951, 49.825434386730194, 59.754343405365944, 39.88976553082466, 37.787509337067604, 55.51762394607067, 52.62894295156002, 53.32207515835762, 49.42182384431362, 43.82153995335102, 36.2103583663702, 37.05843485891819, 36.66674047708511, 37.29226291179657, 39.42928723990917, 39.44241553544998, 39.842389672994614, 38.88609118759632, 37.90427327156067, 40.18586464226246, 39.314339607954025, 38.07196967303753, 39.35682512819767, 37.009474486112595, 44.11379747092724, 49.10291075706482, 49.43322703242302, 51.287546530365944, 51.29167690873146, 48.904956579208374, 45.931965708732605, 40.74073746800423, 36.274795308709145, 40.64820483326912, 47.49445706605911, 49.92734871804714, 50.017046704888344, 51.22622922062874, 52.55516991019249, 50.0309007614851, 50.805485397577286, 49.81622368097305, 52.3438860476017, 47.060159370303154, 52.04878248274326, 26.982055753469467, 0.4228052421240136, 1.4413993363268673, 1.5543020842596889, 6.853449046611786, 1.7118584923446178, 4.812148232012987, 4.360247980803251, 0.8737726730760187, 0.1484940279624425, 0.008663948865432758, 10.088450107723475, 47.0824109762907, 24.0239866822958, 33.74659337103367, 21.802435889840126, 0.6083716987632215, 0.13328909932170063, 0.04345520297647454, 0.06419431199901737, 0.09156745683867484, 0.021791147883050144, 0.055290933305514045, 0.0705408546491526, 0.04038781757117249, 0.009738968328747433, 0.030528398674505297, 0.06668156056548469, 0.0317390808777418, 0.008344642610609299, 0.07592622700030915, 0.018915646614914294, 0.09175965824397281, 0.08543023694073781, 0.018263901802129112, 0.0572543332236819, 0.00820824978291057, 0.07543111059931107, 0.017525529801787343, 0.026109681093657855, 0.05943929761997424, 0.01631923183595063, 0.03305875674413983, 0.04172501925495453, 0.03194249984517228, 0.01925101943925256, 0.07227705718833022, 0.01966105046449229, 0.0048421327755932, 0.025362952510477044, 0.03094489009527024, 0.020415807230165228, 0.03352054329297971, 0.025008951779454947, 0.046659596264362335, 0.01117383664677618, 0.031427876092493534, 0.01937631437613163, 0.10966577436192892, 0.02220719772594748, 0.031859698428888805, 0.11225228518014774, 0.0772804016014561, 0.08720104582607746, 0.05021751901949756, 0.35736016638111323, 7.4502834957093, 46.32409326732159, 24.06582433730364, 40.03561310470104, 49.30574007332325, 10.10074719786644, 0.07560113663203083, 0.3561685443855822, 1.653229775838554, 2.798070344142616, 3.771116193383932, 5.341627495363355, 2.5513068353757262, 0.12170228903414682, 13.953230325132608, 56.577922850847244, 60.58090925216675, 61.17841958999634, 58.58782880008221, 64.1100762784481, 61.33088260889053, 58.638233095407486, 54.80099380016327, 53.4464842826128, 50.63303165137768, 51.942426189780235, 53.14754672348499, 53.040719255805016, 48.1876614689827, 44.843989089131355, 45.611072927713394, 42.929963394999504, 44.63035315275192, 42.950698882341385, 54.882849007844925, 59.4026342779398, 55.77791377902031, 58.308961763978004, 58.504134491086006, 57.13018521666527, 55.33262327313423, 53.81731778383255, 47.09943786263466, 41.65470242500305, 41.66647419333458, 41.7333810031414, 41.36573173105717, 42.07058250904083, 41.75953879952431, 41.75916641950607, 43.323333486914635, 45.027925819158554, 49.80832390487194, 53.027495965361595, 54.54011119902134, 56.71660780906677, 55.141862109303474, 57.161575332283974, 55.3578045219183, 56.930783316493034, 53.287546411156654, 50.59289440512657, 48.23303863406181, 57.10064560174942, 55.2644207328558, 57.72525608539581, 51.69399172067642, 61.43491342663765, 45.63449487090111, 41.51352100074291, 58.66577781736851, 54.21742111444473, 56.32618635892868, 50.9027373790741, 46.66161395609379, 38.164517506957054, 38.67295682430267, 38.97118382155895, 39.8994056135416, 41.75643436610699, 41.97446286678314, 40.040195658802986, 40.96171461045742, 39.500936195254326, 42.44943358004093, 40.190363600850105, 40.52287995815277, 38.988472893834114, 38.74640688300133, 47.112881541252136, 51.99759162962437, 50.70657290518284, 53.10803264379501, 52.123524472117424, 50.32035402953625, 49.21247787773609, 43.735181987285614, 38.845927342772484, 43.01752209663391, 49.405336529016495, 52.215639129281044, 51.937254667282104, 53.092666268348694, 53.41229751706123, 53.0606833845377, 53.270800709724426, 51.407342702150345, 52.87487335503101, 48.1196603178978, 51.69235400855541, 30.992582850158215, 0.5999167368281633, 2.425705762580037, 3.837444009259343, 8.871440961956978, 5.6693147867918015, 5.010502813383937, 4.390989281237125, 1.1360687389969826, 0.08755527291214094, 0.059034485748270527, 10.744320563971996, 57.08598978817463, 26.27531837671995, 36.654531732201576, 28.20723921060562, 0.932273087091744, 0.2619374601636082, 0.046810879357508384, 0.03534775911248289, 0.10024084767792374, 0.05964124342426658, 0.05482048960402608, 0.021688234264729545, 0.06215574365342036, 0.007296481471712468, 0.07368926031631418, 0.03941531838790979, 0.0963449953997042, 0.05132384969328996, 0.035209044290240854, 0.07603797959745862, 0.03666101911221631, 0.04290799523005262, 0.03294876303698402, 0.05309439140546601, 0.06169964195578359, 0.06694721232634038, 0.13765236362814903, 0.20377988868858665, 0.150487644423265, 0.13133091299096122, 0.11432898507337086, 0.100926569866715, 0.15713973669335246, 0.11759052373236045, 0.13114307541400194, 0.06773284985683858, 0.10646255366737023, 0.17000106687191874, 0.14002961106598377, 0.1465018215822056, 0.1574693838483654, 0.1712008228059858, 0.11943410761887208, 0.15623922954546288, 0.18455391487805173, 0.1368566180462949, 0.2375464650685899, 0.15380645461846143, 0.13633542257593945, 0.14533708017552271, 0.12527746672276407, 0.14708786591654643, 0.12339992958004586, 0.44531045481562614, 8.431619312614202, 56.08777955174446, 36.75181031227112, 42.043839544057846, 58.213674277067184, 16.07380248606205, 0.07448260876117274, 0.878925493452698, 4.111731816083193, 8.187669552862644, 13.490461707115173, 11.234764996916056, 2.97051886562258, 0.15034435054985806, 13.07012066245079, 57.46294476091862, 61.3016963750124, 61.116254925727844, 58.649267703294754, 65.49261689186096, 64.32056218385696, 61.02038227021694, 56.37818656861782, 54.97223161160946, 54.62909482419491, 55.18099620938301, 56.08019135892391, 56.07986457645893, 50.686152800917625, 47.49719671905041, 48.563252314925194, 45.456805005669594, 48.85840147733688, 46.16463862359524, 58.397535011172295, 63.14902424812317, 58.122133389115334, 60.9303043037653, 61.861577332019806, 60.25605708360672, 57.339854165911674, 57.247173339128494, 50.0516552478075, 42.851945981383324, 43.044075071811676, 43.998321667313576, 44.66425113379955, 43.120564967393875, 46.442274525761604, 44.8298766463995, 45.9655749052763, 48.53258416056633, 51.59743510186672, 55.434792190790176, 55.43431341648102, 57.95075498521328, 58.10450993478298, 61.196347028017044, 56.47436320781708, 60.837159901857376, 55.2411013841629, 54.107257425785065, 49.42229501903057, 56.381507590413094, 55.82354553043842, 59.6961685270071, 54.06922906637192, 61.00832171738148, 46.23047389090061, 44.18703854084015, 58.433063104748726, 57.06068694591522, 57.90297254920006, 53.94149512052536, 47.377613335847855, 39.8555825650692, 40.433485954999924, 42.10783950984478, 42.41706691682339, 43.634741976857185, 42.53826901316643, 42.72470220923424, 43.00298027694225, 39.845991879701614, 45.15637792646885, 43.40521149337292, 42.419517785310745, 42.61581905186176, 41.27205155789852, 49.35834065079689, 53.371438309550285, 52.43969410657883, 54.25625883042812, 54.403804913163185, 51.74515597522259, 51.6276016831398, 45.78828401863575, 39.92473125457764, 44.92135293781757, 50.64333289861679, 53.44643868505955, 54.721540063619614, 53.39260697364807, 56.215543895959854, 54.82496291399002, 55.0467000156641, 51.128692254424095, 54.52740088105202, 47.408475279808044, 53.5300038009882, 29.30477611720562, 0.9952431893907487, 2.8777454188093543, 3.4187152655795217, 14.774914383888245, 6.017542351037264, 11.515871062874794, 15.318236779421568, 2.7416839823126793, 0.5598719324916601, 0.20455250894883648, 16.19886327534914, 61.30664370954037, 31.79621122777462, 45.449577793478966, 35.5625881254673, 1.0503776371479034, 0.32791465579066426, 0.2454967368976213, 0.14585705852368847, 0.30415637127589434, 0.1771369800553657, 0.23193922766949981, 0.11067883562645875, 0.2807940967613831, 0.13306258100783452, 0.19219747191527858, 0.08261383103672415, 0.17521930014481768, 0.06091129929700401, 0.16809201071737334, 0.1847460717544891, 0.2068734125350602, 0.1875953993294388, 0.08987761626485735, 0.14135557663394138, 0.1845963508822024, 0.31983599241357297], [0.01583697128808126, 0.05359063216019422, 0.11342544996296056, 0.05498409234860446, 0.05244585081527475, 0.04969778186932672, 0.012699778544629226, 0.0028741104370055837, 0.05115666979691014, 0.05047131497121882, 0.0293066714584711, 0.033010142360581085, 0.09204185989801772, 0.015821360211702995, 0.013196704858273733, 0.04682233069615904, 0.026727099721028935, 0.027269535457890015, 0.013211777877586428, 0.0876520415476989, 0.0369502414832823, 0.03342017895192839, 0.004518576797636342, 0.045156090418458916, 0.0694464539992623, 0.04110952650080435, 0.03023389963345835, 0.03846752530080266, 0.3606927953660488, 18.462682999670506, 44.68312852084637, 24.049175530672073, 46.428401470184326, 27.40008272230625, 1.1014618584886193, 0.2640170173253864, 1.3153508375398815, 1.7965019191615283, 4.175575515255332, 1.1141884443350136, 1.9536898657679558, 0.5038751685060561, 0.6401450000703335, 16.335874423384666, 59.15366783738136, 53.40491831302643, 58.12597498297691, 56.69602811336517, 61.020161882042885, 56.64709433913231, 52.5191630423069, 50.124615132808685, 47.658897042274475, 50.389571115374565, 48.79921205341816, 46.558229103684425, 45.068496242165565, 43.18394176661968, 42.96517610549927, 43.91199789941311, 42.0133575797081, 51.34820267558098, 54.54032398760319, 58.24780784547329, 56.7114020884037, 56.400795355439186, 57.27972239255905, 56.0430483520031, 55.949474573135376, 55.19842587411404, 46.846759021282196, 42.30650804936886, 39.216745644807816, 41.479341834783554, 40.782060250639915, 40.86777225136757, 42.62366183102131, 41.767829954624176, 41.330674812197685, 41.977517902851105, 44.94634799659252, 44.51789818704128, 48.64284284412861, 47.937247306108475, 51.30428843200207, 53.336673974990845, 52.84650407731533, 54.734858348965645, 52.423476576805115, 50.197992995381355, 46.99607960879803, 52.67234802246094, 52.71215848624706, 54.238449186086655, 51.88503786921501, 54.546882435679436, 46.80770851671696, 48.08790922164917, 57.39591255784035, 52.657973393797874, 50.088950246572495, 45.99248506128788, 39.76034827530384, 37.817421332001686, 37.42502398788929, 37.856274247169495, 38.070483952760696, 38.39724741876125, 40.14054827392101, 39.897847697138786, 40.98515935242176, 39.674222096800804, 39.52231004834175, 39.88734886050224, 37.962520346045494, 37.43128225207329, 38.28192360699177, 46.36087529361248, 48.65755945444107, 50.366426557302475, 49.07889984548092, 50.72925768792629, 47.267886623740196, 44.67015981674194, 43.63697245717049, 39.02836695313454, 38.60378533601761, 46.54801905155182, 47.15302638709545, 48.77711243927479, 48.90624091029167, 52.28273592889309, 50.53484492003918, 51.128384470939636, 52.22359210252762, 51.079222708940506, 51.446822583675385, 41.79356597363949, 6.202881205826998, 0.49160565657075495, 2.596151316538453, 3.7043058034032583, 9.93819572031498, 2.9049379471689463, 3.411997463554144, 1.866421492304653, 0.06379704776918516, 0.11370348816853948, 0.08961496278061531, 29.13135152310133, 40.336629152297974, 19.365227669477463, 42.34472259879112, 7.674670480191708, 0.07241074024932459, 0.12171190726803616, 0.08893780497601256, 0.04490552280913107, 0.07450766366673633, 0.06290213641477749, 0.07636900714715011, 0.03796713222982362, 0.009531047307973495, 0.04845748611842282, 0.029118060192558914, 0.034220399684272707, 0.09366529309772886, 0.01675782070378773, 0.024696982582099736, 0.05426922602055129, 0.06394258292857558, 0.06880753906443715, 0.043660718511091545, 0.007018679361863178, 0.06867645352031104, 0.035825371960527264, 0.0320110817119712, 0.0494517005427042, 0.06188444785948377, 0.04914613607979845, 0.026124533324036747, 0.03443230511038564, 0.014913785962562542, 0.007142746508179698, 0.021266319599817507, 0.01986679606488906, 0.04025226429803297, 0.06549670695676468, 0.013638017408084124, 0.06196752015966922, 0.043942011034232564, 0.0651206162001472, 0.05414005521743093, 0.008704352312634, 0.021138933661859483, 0.01538612585136434, 0.017088260101445485, 0.049031682065106, 0.040419896904495545, 0.060641996169579215, 0.03702378831803799, 0.031090044903976377, 0.02604735182103468, 0.0954390928382054, 0.8683652663603425, 28.056087121367455, 43.36901843547821, 24.428047500550747, 57.969358786940575, 29.439703077077866, 1.2165785813704133, 0.05599581032583956, 1.2298829737119377, 1.1613451014272869, 3.141384059563279, 7.771606603637338, 3.5634262254461646, 2.202569623477757, 0.4055822506779805, 21.082281433045864, 64.19705361127853, 54.63851451873779, 58.94142642617226, 57.1154610067606, 64.03430834412575, 56.24917969107628, 54.698859080672264, 51.8608445674181, 50.42355269193649, 54.11789685487747, 50.2507683634758, 49.57618296146393, 48.279859721660614, 44.318697676062584, 45.29407873749733, 45.008410066366196, 44.3407516926527, 52.10305117070675, 56.97475075721741, 60.30475527048111, 58.42159532010555, 57.160025015473366, 57.85226806998253, 58.28311175107956, 58.24060723185539, 55.20083874464035, 48.87211874127388, 44.7259446233511, 41.31925642490387, 43.131360188126564, 42.17019036412239, 42.55781136453152, 44.35288444161415, 44.879490584135056, 42.57326513528824, 42.49384559690952, 45.87565653026104, 47.06202507019043, 50.40865749120712, 50.95167875289917, 51.74014024436474, 54.88483250141144, 54.86185513436794, 56.760206669569016, 53.552057817578316, 53.19483518600464, 47.778974398970604, 52.997439578175545, 54.241827204823494, 55.524702966213226, 53.61051008105278, 56.0725461691618, 45.84267050027847, 47.4494256824255, 58.27683448791504, 55.565767362713814, 52.54423409700394, 47.780596911907196, 41.428842544555664, 39.184888154268265, 38.735778853297234, 38.94314132630825, 40.234790816903114, 39.99786593019962, 41.184382662177086, 41.584535390138626, 41.946579962968826, 42.62667126953602, 40.64601235091686, 41.310805678367615, 39.63722348213196, 39.68445494771004, 41.06046751141548, 46.59284144639969, 49.11621004343033, 52.23354756832123, 51.28514505922794, 53.05864289402962, 49.3346831202507, 47.476134449243546, 45.56892938911915, 40.72597526013851, 41.71068102121353, 48.49717006087303, 48.83052237331867, 51.78859904408455, 52.10962861776352, 54.858864694833755, 51.741629764437675, 52.52994306385517, 54.35848094522953, 51.75548382103443, 50.452203154563904, 46.904838904738426, 7.435769224539399, 0.6151206709910184, 4.671703018248081, 5.520501947030425, 7.335517778992653, 10.716156475245953, 3.9963500574231148, 0.98636977490969, 0.6269437959417701, 0.04768370810779743, 0.30318834353238344, 32.648915871977806, 51.94733552634716, 21.914393082261086, 48.2035294175148, 11.914786007255316, 0.019443107667029835, 0.17018842947436497, 0.03567620769899804, 0.04092802315426525, 0.04058275750139728, 0.03462076980213169, 0.008548382556909928, 0.04314599456847645, 0.059436113806441426, 0.03342136638821103, 0.034803746311808936, 0.051098325857310556, 0.048778721029520966, 0.029877639062760863, 0.028518636790977325, 0.03840446130197961, 0.0043627485138131306, 0.007194065092335222, 0.045811469899490476, 0.021352889270929154, 0.06828853292972781, 0.0326222774310736, 0.11891213289345615, 0.15063147264299914, 0.13368804822675884, 0.13512916542822495, 0.1328790033585392, 0.12504829152021557, 0.1787751671508886, 0.17553435667650774, 0.06369375565554947, 0.28963738004677, 0.0681848029489629, 0.14125667803455144, 0.240203071734868, 0.19939183664973825, 0.12217199429869652, 0.1356707254308276, 0.17610299022635445, 0.18067059747409075, 0.15025662869447842, 0.29453582188580185, 0.1433057032409124, 0.15562857559416443, 0.13879573118174449, 0.12127354289987125, 0.1628876110771671, 0.1271856768289581, 0.16504798812093213, 0.13572442723670974, 1.1282246536575258, 35.775977075099945, 60.60542553663254, 32.54423528909683, 58.973625898361206, 38.534537851810455, 2.1593177318573, 0.9901963477022946, 2.698285086080432, 4.2773012816905975, 11.576306819915771, 12.861003633588552, 4.368116408586502, 2.187943495810032, 1.0836534015834332, 18.55878934264183, 64.12690177559853, 53.11830349266529, 59.715061113238335, 59.23891246318817, 66.24782636761665, 59.73037049174309, 56.895851790905, 54.942232221364975, 52.88195617496967, 55.853852704167366, 53.85427460074425, 52.76402950286865, 49.967037588357925, 46.12630248069763, 47.96888440847397, 47.8983373939991, 45.81254571676254, 55.50547979772091, 58.76839131116867, 61.309136375784874, 59.5137707144022, 58.56925539672375, 59.42721135914326, 59.355486407876015, 61.1101258546114, 57.913277596235275, 51.2210538983345, 47.11220517754555, 42.547677308321, 46.63474939763546, 45.73269300162792, 44.69455070793629, 47.63598807156086, 46.53412699699402, 45.55477894842625, 44.808745980262756, 48.30345645546913, 48.68078000843525, 52.10547164082527, 53.4367074072361, 55.4452720284462, 57.3975882679224, 57.26298049092293, 59.39147427678108, 56.15128934383392, 54.9642938375473, 50.39413087069988, 53.77815328538418, 54.21963259577751, 55.220821872353554, 54.7509428858757, 55.341115817427635, 47.96285033226013, 53.578853979706764, 61.301153004169464, 55.43415382504463, 55.25329113006592, 50.62654159963131, 41.31449528038502, 42.053836807608604, 41.5379498898983, 41.450444385409355, 41.19335398077965, 41.603519171476364, 43.539085909724236, 43.24413053691387, 45.22437147796154, 46.17923744022846, 44.262187108397484, 44.09959763288498, 42.65797398984432, 41.73668682575226, 42.555022314190865, 48.411473259329796, 52.39160768687725, 55.289142206311226, 52.83773794770241, 55.41912943124771, 50.45058064162731, 50.29173016548157, 48.35087411105633, 43.065923899412155, 43.2271758466959, 50.80012768507004, 50.87659478187561, 52.789328545331955, 52.95379512012005, 57.283704578876495, 54.37967620790005, 55.57252340018749, 55.64770236611366, 53.367106541991234, 51.25078350305557, 44.55985553562641, 7.426577042788267, 1.0198921104893088, 6.098895035684109, 9.455270133912563, 21.37010268867016, 10.23226574063301, 11.10400641337037, 7.978491727262735, 2.000398146919906, 0.31487262749578804, 0.6960953352972865, 40.2910315990448, 53.6761287599802, 26.96744743734598, 57.83880539238453, 13.512526173144579, 0.365524236112833, 0.40740588563494384, 0.18100913555826992, 0.2049090515356511, 0.1713842074968852, 0.17921604739967734, 0.15708444669144228, 0.0902923358080443, 0.1167187822284177, 0.17560466774739325, 0.09170575605821796, 0.1968987102736719, 0.12123412743676454, 0.14045937394257635, 0.16143828572239727, 0.1638289660331793, 0.11674528432195075, 0.13251456432044506, 0.16179522906895727, 0.061548236408270895, 0.30933528556488454, 0.10955918711260892], [0.03788239751884248, 0.03195528333890252, 0.03904955090547446, 0.03485258333967067, 0.05897807139263023, 0.05595689952315297, 0.036857205850537866, 0.018099386215908453, 0.038035762336221524, 0.04928559676045552, 0.023500954084738623, 0.03143205809465144, 0.02815996609569993, 0.03603588957048487, 0.043142313516000286, 0.07794138058670796, 0.03496599092613906, 0.012048768458043924, 0.05454916783492081, 0.02947003857116215, 0.056101659138221294, 0.10432840412249789, 0.021843031427124515, 0.07685495060286485, 0.03706480310938787, 0.04657688761653844, 0.007701744661972043, 0.02483562690031249, 0.07465990784112364, 5.680176978930831, 46.402220875024796, 28.017002418637276, 32.31997512280941, 50.505901873111725, 7.560029681771994, 0.12058664069627412, 0.9909716248512268, 0.9699917631223798, 0.8587625878863037, 6.363606881350279, 5.669184643775225, 2.5912507670000196, 0.26532402844168246, 0.29332104488275945, 16.62164568901062, 56.918753162026405, 59.15628969669342, 60.48687569797039, 57.44478553533554, 58.11823859810829, 54.00141030550003, 51.86499774456024, 52.87740781903267, 51.6733056306839, 50.33164322376251, 48.03859926760197, 47.343434169888496, 45.26794373989105, 43.64748649299145, 43.617684692144394, 49.71731498837471, 54.781447649002075, 57.077805027365685, 57.08436727523804, 58.616304472088814, 58.331403359770775, 55.754020661115646, 56.76235355436802, 56.347560212016106, 56.77963122725487, 51.97073467075825, 46.25382363796234, 42.496110275387764, 41.25601261854172, 40.448331758379936, 40.591724663972855, 42.88430504500866, 41.320331767201424, 41.21342450380325, 41.97696693241596, 45.05897015333176, 47.93150581419468, 50.043751671910286, 51.145320162177086, 49.42623160779476, 54.63193707168102, 53.56416396796703, 50.066276863217354, 56.33421912789345, 49.03563156723976, 48.30577053129673, 55.61946988105774, 55.54489508271217, 57.5882164388895, 55.677846148610115, 56.63901597261429, 50.67835181951523, 54.0861039608717, 52.4160897731781, 51.07245147228241, 44.48898173868656, 39.63030785322189, 38.631660640239716, 38.12699072062969, 38.47665175795555, 38.363026455044746, 39.11489591002464, 38.254496678709984, 43.88541452586651, 44.7781728208065, 45.08762441575527, 41.33666329085827, 41.29566349089146, 39.06857259571552, 39.9752913415432, 38.57473589479923, 38.994176387786865, 43.43877889215946, 46.92104123532772, 48.8240285217762, 49.292581379413605, 48.57625521719456, 47.2152404487133, 44.0495391190052, 44.501916244626045, 39.34858717024326, 37.871135249733925, 39.52563486993313, 44.452480897307396, 44.94782231748104, 45.78278571367264, 45.19019231200218, 48.79730835556984, 48.80467616021633, 51.51109613478184, 48.74664567410946, 54.5318466424942, 23.517901338636875, 0.3185884718550369, 0.8328928635455668, 1.8854144169017673, 5.496347593143582, 5.810060184448957, 12.146033998578787, 2.458573286421597, 1.2217085435986519, 0.237463582016062, 0.10261874820571393, 3.60136647708714, 47.1975751966238, 28.86453364044428, 27.022495083510876, 30.304078795015812, 1.3060711417347193, 0.0843163178069517, 0.008569838046241784, 0.06726439140038565, 0.06825475036748685, 0.04074857184605207, 0.06720695659168996, 0.05173078410734888, 0.07044521407806315, 0.02272416852065362, 0.03181545529514551, 0.03462394619418774, 0.03132105135591701, 0.05531147224246524, 0.058227184927091, 0.030107382008282002, 0.01942169856192777, 0.011243916724197334, 0.01869411367806606, 0.08335208243806846, 0.05832006470882334, 0.019514775012794416, 0.09332724483101629, 0.003965487530876999, 0.011646054081211332, 0.023807232864783145, 0.04011768694908824, 0.02666900440090103, 0.010655401965777855, 0.025213702901965007, 0.007288604501809459, 0.024042599434324075, 0.011297152832412394, 0.04987472471839283, 0.020300865253375378, 0.01400617182298447, 0.03764434623008128, 0.07344150173594244, 0.06783951874240302, 0.025056324921024498, 0.028288858593441546, 0.062379241426242515, 0.08080063067609444, 0.10942920736852102, 0.026804299777722917, 0.049226436458411627, 0.0708140317874495, 0.016512555739609525, 0.031211109599098563, 0.08847467513987795, 0.022593190587940626, 0.19363939063623548, 9.213836789131165, 54.041064977645874, 25.768929049372673, 36.952819526195526, 53.11703436076641, 8.093036580830812, 0.04554815590381622, 0.57979034492746, 1.257092838641256, 1.5791802993044257, 4.41021054983139, 3.2983835600316525, 4.439553525298834, 1.3592331390827894, 0.5405287141911685, 21.224065124988556, 58.8422479480505, 59.2475114017725, 61.658645421266556, 60.21532706916332, 60.55593699216843, 54.70131374895573, 53.39577980339527, 54.26085278391838, 53.5603641718626, 52.3255330324173, 51.383890360593796, 49.2930943518877, 47.17547558248043, 44.95453655719757, 44.23380643129349, 49.425315856933594, 56.45656496286392, 58.39329443871975, 59.5665118843317, 60.60749642550945, 58.91254037618637, 58.72426427900791, 59.286140128970146, 57.02616959810257, 57.50573426485062, 53.19417022168636, 47.628130093216896, 43.29282112419605, 43.79841819405556, 41.643052250146866, 44.068861082196236, 43.636387288570404, 43.37026096880436, 42.882355749607086, 45.530167669057846, 47.48215712606907, 48.263155817985535, 52.03234076499939, 53.1524408608675, 50.95156095921993, 55.77052317559719, 54.41984765231609, 53.4614060819149, 58.72469365596771, 50.436589792370796, 49.72017243504524, 57.502413243055344, 55.91577798128128, 59.88308049738407, 56.087080389261246, 57.43642598390579, 51.24903939664364, 53.77286396920681, 54.64779742062092, 52.86032393574715, 47.12655320763588, 43.11935283243656, 39.94431920349598, 39.95949938893318, 40.6335262209177, 40.35665027797222, 41.476290598511696, 40.96887342631817, 44.98422056436539, 45.2825653553009, 45.39887331426144, 43.1402251124382, 40.74015609920025, 40.05630299448967, 39.84215788543224, 40.229440703988075, 41.06372393667698, 45.755959153175354, 49.93749037384987, 51.3972694426775, 50.841218680143356, 50.5694230645895, 48.06498125195503, 47.168841138482094, 46.053912565112114, 40.07123999297619, 39.266754761338234, 41.94227859377861, 45.78636892139912, 46.85262970626354, 46.545579582452774, 47.57765740156174, 49.653622806072235, 51.61798819899559, 52.5021817535162, 49.70832847058773, 55.508656427264214, 25.61358578503132, 0.5022422655019909, 2.3407021863386035, 3.584049856290221, 11.194763593375683, 7.079794351011515, 13.308067694306374, 2.546855849213898, 1.3330506440252066, 0.21513458486879244, 0.014814207370363874, 3.5812178207561374, 55.977832451462746, 36.94242708384991, 26.510778442025185, 39.14113350212574, 2.2376878140494227, 0.14477036136668175, 0.003937094816137687, 0.08601668203482404, 0.09263917745556682, 0.0241582334638224, 0.012934369569848059, 0.036581063832272775, 0.03851930123346392, 0.01986961065995274, 0.06743058052961715, 0.035751446630456485, 0.03146905415633228, 0.037378523775259964, 0.022387892131519038, 0.03609474930271972, 0.0759532857045997, 0.022250199617701583, 0.019884967550751753, 0.03849351531243883, 0.08751230256166309, 0.06214917193574365, 0.035311753817950375, 0.12987020309083164, 0.08376715079066344, 0.21053681673947722, 0.1185132359387353, 0.14820502081420273, 0.13646399223944172, 0.11134679079987109, 0.12776140531059355, 0.129482104384806, 0.11196888866834342, 0.19212868966860697, 0.12493655376601964, 0.08494703943142667, 0.12074097772710957, 0.18360237765591592, 0.20587721286574379, 0.10183491409406997, 0.11603608058067039, 0.19586776325013489, 0.14753273891983554, 0.24404144467553124, 0.2566213969839737, 0.0767699524294585, 0.15718922310043126, 0.0858423589670565, 0.18313819397008047, 0.12632088182726875, 0.1946200497332029, 0.2597322128713131, 10.95835167914629, 65.57844668626785, 36.456657350063324, 42.24789999425411, 61.97619818150997, 12.672208864241838, 0.14075289334869012, 4.949888940900564, 3.1768390070647, 5.095038777217269, 16.854086816310883, 13.295923545956612, 6.25351776368916, 0.48335051047615707, 0.4225045832572505, 20.28290882706642, 58.3562958240509, 59.21796038746834, 64.401885420084, 62.84015782177448, 63.521149680018425, 58.05402584373951, 55.51527187228203, 58.220510110259056, 56.94788619875908, 56.40922710299492, 55.70053473114967, 51.65802665054798, 51.63812331855297, 46.80759072303772, 46.01406030356884, 53.11801850795746, 59.90719020366669, 61.55506297945976, 63.08227702975273, 62.21884936094284, 59.70878764986992, 60.3876668214798, 61.302311941981316, 59.11760397255421, 59.2340487241745, 56.30847170948982, 49.065562561154366, 45.88807426393032, 47.29651428759098, 43.444227799773216, 45.074119940400124, 45.087240636348724, 44.84966978430748, 46.06379583477974, 47.01757125556469, 49.15566712617874, 52.74492412805557, 54.61288869380951, 55.1564647257328, 52.23392374813557, 58.21916878223419, 57.31195226311684, 54.24100264906883, 60.405210480093956, 53.50561670958996, 50.527872294187546, 58.10790695250034, 58.87716807425022, 61.71093441545963, 59.96675580739975, 60.211762860417366, 54.48371082544327, 56.81149631738663, 56.442741304636, 54.917210564017296, 48.35369735956192, 43.517389073967934, 42.08501033484936, 42.18783661723137, 43.39219719171524, 43.47982048988342, 44.25966404378414, 43.67151640355587, 47.10362143814564, 48.406240940093994, 50.50278224050999, 45.02903915941715, 45.037212520837784, 42.075936421751976, 43.11893105506897, 43.32122080028057, 42.94270411133766, 47.85299442708492, 51.36321187019348, 52.66052305698395, 53.05106230080128, 50.97646862268448, 50.73837339878082, 47.36837223172188, 47.91850671172142, 41.53804488480091, 42.10164204239845, 42.50803783535957, 48.35311979055405, 49.41784925758839, 50.29545396566391, 47.6203291118145, 53.015131428837776, 53.44890095293522, 55.21709427237511, 51.60159967839718, 55.6158372759819, 25.583464801311493, 0.5590427457354963, 1.9057324016466737, 5.125849423930049, 14.470230583101511, 11.88719093799591, 15.811194777488708, 7.008971851319075, 3.792920373380184, 1.8060661247000098, 0.2643970859935507, 6.798181487247348, 61.01018361747265, 37.15627580881119, 35.997349396348, 46.06070280075073, 2.360750148072839, 0.37816871074028313, 0.18637657020008191, 0.1439125425531529, 0.14715268509462476, 0.2081164950504899, 0.1530688934144564, 0.13603611441794783, 0.14397580322111025, 0.14849113358650357, 0.14449855720158666, 0.13123032229486853, 0.1139950705692172, 0.1600342759047635, 0.12349142154562287, 0.08912060337024741, 0.10367515089455992, 0.07736266124993563, 0.11505228219903074, 0.11824057830381207, 0.11853525546030141, 0.15252535929903388, 0.10862179522519], [0.05696372303646058, 0.02189418581110658, 0.05177985491172876, 0.04091594099008944, 0.01831264791690046, 0.0023007981098999153, 0.01348945335848839, 0.0587156591063831, 0.082636748556979, 0.026996356464223936, 0.04824992596695665, 0.06859904751763679, 0.12197033051052131, 0.04578356885758694, 0.061766676444676705, 0.030474837876681704, 0.05662128867697902, 0.05359889597457368, 0.09986333199776709, 0.007591657258672058, 0.02384851668466581, 0.042565861440380104, 0.06134630173619371, 0.015363272341346601, 0.026635490867192857, 0.04083194100530818, 0.08320496650412679, 0.02201403523940826, 0.15440192422829568, 0.42300244560465217, 16.984626911580563, 42.05368481576443, 36.266203969717026, 56.45683854818344, 23.275457248091698, 0.4874792858026922, 0.6679739349056035, 0.6858936545904726, 0.7715369027573615, 3.2717764377593994, 2.028453228995204, 5.541085917502642, 2.2471174830570817, 0.3038881887914613, 0.1409569097450003, 15.476417541503906, 63.83605778217316, 61.31240040063858, 60.03709003329277, 57.576710656285286, 55.79038091003895, 53.7703713029623, 52.83375196158886, 50.95707446336746, 50.33459946513176, 49.86767292022705, 45.63156522810459, 44.22285541892052, 44.23678547143936, 46.11432172358036, 53.86959917843342, 55.918859615921974, 57.128194123506546, 62.633198127150536, 61.58053681254387, 55.86923807859421, 55.17294064164162, 55.61467833817005, 56.6619211435318, 56.573499888181686, 54.5090326666832, 47.86966793239117, 43.565376698970795, 41.37434966862202, 41.91734433174133, 40.22915951907635, 41.53028570115566, 42.58481651544571, 43.21824632585049, 44.831195175647736, 50.05504086613655, 52.93082155287266, 54.63495410978794, 51.82120129466057, 53.15573148429394, 54.68246676027775, 54.090450927615166, 54.06262122094631, 59.65864934027195, 48.178382366895676, 49.998541697859764, 57.154279723763466, 54.37851347029209, 54.51099336147308, 53.736499920487404, 53.311994299292564, 55.3410018235445, 55.28285354375839, 55.013903975486755, 48.51727478206158, 42.059240117669106, 38.33529934287071, 39.105799198150635, 38.47006671130657, 38.65784503519535, 37.96227715909481, 40.63685104250908, 45.582414865493774, 48.99489015340805, 47.77474522590637, 46.53164193034172, 41.67298324406147, 40.1027213037014, 40.201261416077614, 37.73409940302372, 38.668378069996834, 40.091713294386864, 44.5450971275568, 46.33844509720802, 48.33619549870491, 47.563902139663696, 46.21698081493378, 47.06397816538811, 45.56701809167862, 45.327250957489014, 40.651400461792946, 38.770964965224266, 39.6366573125124, 40.744655057787895, 41.78460605442524, 45.65684527158737, 45.072543025016785, 47.45334327220917, 48.36049519479275, 50.96745550632477, 50.65600521862507, 47.604597955942154, 8.47197124734521, 0.1044231689593289, 2.4222978204488754, 5.166070265695453, 6.971512036398053, 6.908435896039009, 18.675114400684834, 1.5666993940249085, 0.6428289029281586, 0.14371811470482498, 0.06700867699692026, 12.516700308769941, 46.17679037153721, 20.274946354329586, 39.99248921871185, 16.186168156564236, 0.05193922741455026, 0.10297868240741082, 0.03079492802498862, 0.014224112765077734, 0.00943480559726595, 0.017808410520956386, 0.04432531546626706, 0.024552974391554017, 0.045016830117674544, 0.009369725739816204, 0.03500381819321774, 0.02433279401884647, 0.033221754638361745, 0.030251338248490356, 0.08001916401553899, 0.050448282418074086, 0.053369824672699906, 0.019590720839914866, 0.02163509649108164, 0.04580898741551209, 0.04529292760707904, 0.02164645691664191, 0.019286095193820074, 0.04536691230896395, 0.038467996564577334, 0.015342943061114056, 0.027260904280410614, 0.043868545835721307, 0.03705314768012613, 0.03535935145919211, 0.04870774573646486, 0.050488514243625104, 0.06868789743748493, 0.058266964042559266, 0.0734863719844725, 0.04236557433614507, 0.04183119461231399, 0.06568910874193534, 0.019645708416646812, 0.03209462527593132, 0.0216538950917311, 0.06563113958691247, 0.0635039662302006, 0.04855413601035252, 0.016341507398465183, 0.07947647594846785, 0.03547538253769744, 0.07676849782001227, 0.04080386926943902, 0.10220279669738375, 0.04035350437334273, 0.131520323920995, 0.8047591138165444, 26.9939187169075, 43.012456968426704, 36.1276064068079, 65.7698804140091, 28.258777745068073, 0.34008365124464035, 0.4337745707016438, 0.8206031355075538, 1.1234823893755674, 3.0423295497894287, 5.792825734242797, 7.633638856932521, 7.774846879765391, 1.40277951490134, 0.3402483189711347, 21.75706062465906, 63.70525360107422, 62.354726269841194, 62.03911900520325, 61.67019680142403, 57.88146570324898, 56.1576122045517, 55.36658585071564, 54.58865359425545, 52.27021560072899, 50.42236715555191, 46.85631550848484, 46.48299694061279, 47.67170615494251, 47.3382892459631, 54.765754491090775, 58.041494116187096, 58.86805236339569, 60.80669693648815, 61.75970859825611, 57.381674721837044, 56.4845884591341, 57.180228531360626, 57.87322394549847, 58.24551276862621, 56.98612354695797, 49.331529289484024, 46.69538274407387, 42.75804162025452, 44.2045783996582, 42.351049259305, 43.8062609732151, 42.93987326323986, 45.588950514793396, 45.9698610752821, 50.55256336927414, 55.798174291849136, 55.62032103538513, 54.01696667075157, 56.003291085362434, 55.32965563237667, 55.895270481705666, 57.79683284461498, 61.3512647151947, 48.365491926670074, 50.810740515589714, 58.40812124311924, 58.14573012292385, 55.80557629466057, 55.91010108590126, 56.9486765563488, 57.45245732367039, 57.038119956851006, 54.993974044919014, 51.556765884160995, 44.71969395875931, 40.938847437500954, 40.36058306694031, 39.906465634703636, 39.38887260854244, 40.02793751657009, 42.42343157529831, 46.26712292432785, 51.491234600543976, 49.119105488061905, 48.47428768873215, 43.41552414000034, 42.821547612547874, 41.86868414282799, 40.23699849843979, 40.1860736310482, 41.962022334337234, 46.35204836726189, 48.33167374134064, 51.00180186331272, 49.720449820160866, 49.66753765940666, 49.26334194839001, 47.979968413710594, 46.6560510545969, 42.85051345825195, 39.09121938049793, 41.13584786653519, 43.45551699399948, 44.04903754591942, 47.68929161131382, 47.68029749393463, 49.95862103998661, 50.78710198402405, 52.15205334126949, 52.78049781918526, 47.600440979003906, 10.16150213778019, 0.8488712436519563, 5.300102373585105, 2.7123341197147965, 6.796666793525219, 11.408158242702484, 13.12951147556305, 1.0342866880819201, 0.5965366994496435, 0.2219870570115745, 0.014212967562343692, 13.936307933181524, 60.18659681081772, 20.817944817245007, 41.707956567406654, 22.663141004741192, 0.09620853670639917, 0.13533444347558543, 0.038888482595211826, 0.029090010721120052, 0.03537446158588864, 0.015161635456024669, 0.028452008627937175, 0.03509559959638864, 0.0366500872769393, 0.054116933606565, 0.021473833367053885, 0.05447568037197925, 0.03476499878161121, 0.036025187800987624, 0.08012451929971576, 0.016446582521894015, 0.01264610549696954, 0.017411853186786175, 0.03560040102456696, 0.014454253687290475, 0.015130039446376031, 0.023383982334053144, 0.03930311679141596, 0.08670929135405459, 0.1338662824127823, 0.17206345073645934, 0.19665026891743764, 0.09542057625367306, 0.11266409550444223, 0.18746366811683401, 0.15601826249621809, 0.19940494297770783, 0.10409909533336759, 0.21575562888756394, 0.1613857565098442, 0.17394795664586127, 0.119432044448331, 0.1763704008772038, 0.08717482574866153, 0.15236906299833208, 0.15868693648371845, 0.19685536884935573, 0.11129130783956498, 0.11951338383369148, 0.10766389037598856, 0.180240300251171, 0.14102168439421803, 0.14828591491095722, 0.06843170063802972, 0.22512561437906697, 0.163337797857821, 0.19396036950638518, 0.8293125056661665, 34.29715342819691, 56.8629265576601, 42.87840396165848, 68.54188486933708, 34.57012318074703, 1.2635418050922453, 1.5454736142419279, 2.6599943032488227, 3.788851029239595, 13.9861517585814, 7.044233484193683, 15.255633238703012, 5.61783847399056, 0.5712183017749339, 0.35840139957144856, 19.894026294350624, 66.27939507365227, 63.1487924605608, 66.09436020255089, 63.20426568388939, 61.651311814785004, 59.402736872434616, 57.9301068931818, 56.88361644744873, 54.80761684477329, 53.8904182612896, 49.531041383743286, 49.03349608182907, 49.75749783217907, 51.835655719041824, 57.441384717822075, 59.872904643416405, 61.64523974061012, 64.30629014968872, 61.7365488409996, 59.82108302414417, 57.77468763291836, 58.35653901100159, 59.599524512887, 61.91344074904919, 59.829780757427216, 53.00267569720745, 49.963290989398956, 45.52845016121864, 46.40586107969284, 43.608922362327576, 45.67621283233166, 45.32371334731579, 46.80872306227684, 50.3182527422905, 54.16435696184635, 57.772506549954414, 58.62103521823883, 55.52651546895504, 58.04408557713032, 58.023433685302734, 59.40549552440643, 59.805511459708214, 63.00522096455097, 50.46033091843128, 54.95280705392361, 58.74917194247246, 57.534407526254654, 58.821835443377495, 57.847145944833755, 57.392378747463226, 59.881986156105995, 58.060447499156, 57.381298542022705, 53.47879394888878, 45.53073763847351, 40.964986234903336, 43.01155261695385, 42.408429980278015, 41.115522757172585, 41.102367863059044, 45.84139756858349, 50.305105447769165, 54.146026745438576, 52.25536219775677, 51.552597507834435, 46.45572580397129, 44.39028963446617, 45.173712596297264, 41.29114553332329, 42.111179530620575, 44.07978929579258, 50.18174886703491, 50.90883985161781, 52.12921656668186, 51.66625700891018, 51.4687018096447, 51.92162610590458, 50.55643156170845, 50.69716461002827, 44.99737545847893, 42.17104151844978, 44.01212252676487, 45.44074326753616, 44.0303273499012, 50.94629064202309, 50.16788721084595, 53.26939858496189, 53.31921771168709, 55.9416925907135, 52.74082414805889, 50.23781105875969, 9.64450377970934, 0.7831487234216183, 6.194521654397249, 10.685115940868855, 16.2774620577693, 12.914467714726925, 30.9201530367136, 8.502137828618288, 1.8722569104284048, 0.6762226985301822, 0.21545014606090263, 18.521243557333946, 62.03663393855095, 26.61342043429613, 54.572641253471375, 26.083177886903286, 0.11697331661707722, 0.23899038758827373, 0.1333493023412302, 0.10190111366682686, 0.130005570827052, 0.0822563681867905, 0.09673780674347654, 0.15204973169602454, 0.14040240668691695, 0.1435426264652051, 0.10117746773175895, 0.1660280831856653, 0.2180147561011836, 0.14617376262322068, 0.22795168304583058, 0.16593265783740208, 0.09656262278440408, 0.11950435931794345, 0.1433811499737203, 0.11582030856516212, 0.22542516002431512, 0.09684567048680037, 0.16640292713418603], [0.03740087355254218, 0.08752347188419662, 0.10082790875458159, 0.04346337402239442, 0.05132676633365918, 0.09497156206634827, 0.03531267408106942, 0.0449677741562482, 0.06369697657646611, 0.00932412818656303, 0.02122978552506538, 0.010133675859833602, 0.02762570326012792, 0.02415186769212596, 0.04177802715275902, 0.10872536935494281, 0.025304851624241564, 0.06438396783778444, 0.019052057068620343, 0.029680943953280803, 0.0721861663623713, 0.028207966352056246, 0.06215391797013581, 0.04593794670654461, 0.02002917797653936, 0.014148674381431192, 0.043144666124135256, 0.06889031821629032, 0.07475420512491837, 0.11558154481463134, 2.6443959027528763, 36.558214500546455, 36.016614362597466, 26.18057806044817, 47.19289384782314, 5.676582371816039, 0.05691279686288908, 0.8051979902666062, 0.5448294896632433, 1.3416704814881086, 3.5868590930476785, 2.4471472995355725, 12.61125823482871, 1.1618110514245927, 0.44507569866254926, 0.2939853857969865, 22.418485432863235, 69.710443764925, 57.65625558793545, 63.067841604352, 54.52229015529156, 58.532070592045784, 55.5817037075758, 54.86625149846077, 50.370636731386185, 48.527838215231895, 45.870002433657646, 45.33790938556194, 44.20361705124378, 49.90266144275665, 53.11022512614727, 57.50067673623562, 60.15391856431961, 58.475947603583336, 58.4308098256588, 59.613564759492874, 58.104262948036194, 55.53014427423477, 55.14347322285175, 58.22256200015545, 54.849653989076614, 49.90018017590046, 43.00268389284611, 40.796450078487396, 44.277032911777496, 39.745498672127724, 41.472988575696945, 42.334827929735184, 41.82042293250561, 47.16797478497028, 54.87651854753494, 54.38222587108612, 58.07547189295292, 54.94685277342796, 53.113941326737404, 53.179354816675186, 51.66456989943981, 52.61126630008221, 58.930919989943504, 49.308950901031494, 53.460353538393974, 55.776211470365524, 52.8280408680439, 51.450861766934395, 50.748769640922546, 55.297904536128044, 54.79035057127476, 51.964335814118385, 50.442015901207924, 44.890285804867744, 40.68595960736275, 40.568340718746185, 39.818773940205574, 38.380193933844566, 39.413407891988754, 39.82114501297474, 44.858447313308716, 51.988627910614014, 53.25699985027313, 50.44599428772926, 47.674768790602684, 43.3028943836689, 40.737013667821884, 39.69721466302872, 39.629270508885384, 37.98908092081547, 38.820073530077934, 43.648007065057755, 43.95930156111717, 47.028955444693565, 46.59043997526169, 45.89219704270363, 45.32472409307957, 45.42535409331322, 43.08070130646229, 40.119394809007645, 40.11655256152153, 41.41367755830288, 42.64793872833252, 46.701443418860435, 47.046457305550575, 49.01615381240845, 51.5808679908514, 50.57341285049915, 47.78710976243019, 53.51217895746231, 31.965096965432167, 2.0854444708675146, 1.1698194779455662, 4.136192053556442, 0.9377054893411696, 8.464265260845423, 7.429403616115451, 9.788524601608515, 0.6276474113110453, 0.38365193526260555, 0.08655945173813961, 0.34783927258104086, 32.5171959400177, 37.89176054298878, 27.941625863313675, 39.10014130175114, 3.870808118954301, 0.01980156870558858, 0.04982137914339546, 0.03730281358002685, 0.04124687206058297, 0.003929177491954761, 0.06258157314732671, 0.03730283955519553, 0.0489095802186057, 0.035420370841166005, 0.04320371510402765, 0.1183414064871613, 0.02577325070888037, 0.02097817705362104, 0.044577790395123884, 0.0382621544849826, 0.047441196511499584, 0.027641479464364238, 0.022124591123429127, 0.022447989395004697, 0.05397716122388374, 0.06469068262958899, 0.0431938334077131, 0.009203336230712011, 0.026266085005772766, 0.015154976535995957, 0.030697185320605058, 0.027288365599815734, 0.023208046950458083, 0.046223677272791974, 0.03290483160526492, 0.02938842459116131, 0.025521248899167404, 0.026771003322210163, 0.060951108098379336, 0.009750201661518076, 0.09607301311916672, 0.05438505300844554, 0.05175404672627337, 0.0796937990526203, 0.05321711294527631, 0.022926424171600956, 0.012562311458168551, 0.026868438035307918, 0.018440503263263963, 0.04645113440346904, 0.03306424492620863, 0.0332055424223654, 0.024890391832741443, 0.020727600167447235, 0.031234405614668503, 0.05806468427181244, 0.016669421638653148, 0.1317722979001701, 5.2057368122041225, 46.83979779481888, 39.36818651854992, 39.706113785505295, 54.58833821117878, 4.980618366971612, 0.04934605211019516, 0.327131244703196, 0.10152542366995476, 0.8615610189735889, 1.121303562540561, 9.95282968506217, 18.436065427958965, 5.449511306360364, 1.5621307329274714, 0.31942712841555476, 29.2709731310606, 70.41682586073875, 61.200283616781235, 62.94202655553818, 57.64734506607056, 60.51300689578056, 57.140087485313416, 57.41808816790581, 52.40258529782295, 49.722463712096214, 49.139384999871254, 47.40299217402935, 46.62430755794048, 51.04478515684605, 54.783556535840034, 60.26754006743431, 61.11699968576431, 60.40886588394642, 59.757303446531296, 59.246675446629524, 58.064870461821556, 58.91048088669777, 57.674202024936676, 59.57747429609299, 57.356455475091934, 51.22806452214718, 44.57138791680336, 43.71511906385422, 44.899735897779465, 43.06757681071758, 43.862129375338554, 43.51648472249508, 44.62704353034496, 50.090458765625954, 56.37720622122288, 56.77579343318939, 58.57795313000679, 56.18837535381317, 54.96012166142464, 55.85301294922829, 55.487537160515785, 55.50440065562725, 60.326524302363396, 51.210646256804466, 55.83236485719681, 57.02468387782574, 54.81505684554577, 55.43374344706535, 52.25937478244305, 57.1873227506876, 56.39829508960247, 54.90541219711304, 52.835351675748825, 48.168700486421585, 42.50988833606243, 42.79290094971657, 41.524114832282066, 40.31372018158436, 40.699471682310104, 41.03221222758293, 44.92402799427509, 51.54212906956673, 53.966649770736694, 52.71604187786579, 48.990459591150284, 44.17771764099598, 41.79641582071781, 40.78692398965359, 41.114356219768524, 40.01136660575867, 40.20413026213646, 46.254693791270256, 45.4481490701437, 49.01630200445652, 48.6610134691, 49.382799938321114, 47.16257147490978, 48.30744244158268, 45.33149152994156, 43.14503185451031, 42.26707376539707, 43.3317918330431, 44.534184113144875, 47.650476694107056, 48.26296202838421, 50.16520455479622, 53.1654741615057, 52.37320527434349, 50.08606620132923, 51.96791522204876, 34.56003852188587, 2.5645025772973895, 2.0826397463679314, 6.443001721054316, 4.097099751234055, 3.808170142583549, 8.952614106237888, 5.447097010910511, 0.3632986539741978, 0.2723960723960772, 0.09687099256552756, 0.1850940944859758, 35.12421704828739, 44.74346548318863, 23.783695176243782, 45.953206568956375, 6.038409881293774, 0.05284474776999559, 0.02721541062783217, 0.06883414505864494, 0.03260882600443438, 0.03744887937500607, 0.03717787672940176, 0.03651310165878385, 0.041599844917072915, 0.03506803994241636, 0.03560036020644475, 0.05785407018265687, 0.017679673874226864, 0.04517019493505359, 0.007391199460471398, 0.05044942161475774, 0.061227431942825206, 0.025410334928892553, 0.01601476760697551, 0.054215839627431706, 0.048665684516890906, 0.04953660594765097, 0.06177565272082575, 0.02496222616173327, 0.12752136506605893, 0.13277127320179716, 0.13080101954983547, 0.14495760522549972, 0.1277335747727193, 0.2263418905204162, 0.13495280145434663, 0.10593795173917897, 0.15028138674097136, 0.0673072726931423, 0.1347687339875847, 0.08611891287728213, 0.22894377121701837, 0.07058663773932494, 0.32828596711624414, 0.26975444226991385, 0.16759557329351082, 0.11743440554710105, 0.09485505972406827, 0.09726164425956085, 0.17100786441005766, 0.13718449888983741, 0.14791127876378596, 0.11036766052711755, 0.1843019260559231, 0.08396885910769925, 0.14918039581971243, 0.20907408819766715, 0.31475275580305606, 0.27037101855967194, 7.828348008915782, 58.767167776823044, 45.89685559272766, 36.15278385579586, 61.14176295697689, 9.77642985060811, 0.27127243112772703, 2.932890197262168, 2.0567389111965895, 5.792834283784032, 12.227653618901968, 9.724080059677362, 28.847740441560745, 5.180542264133692, 1.1261000926606357, 0.771895864745602, 26.31672665476799, 73.02163168787956, 61.458320170640945, 68.58762681484222, 59.13798227906227, 64.21316474676132, 62.3521576076746, 60.807308703660965, 54.56679716706276, 51.80745743215084, 51.234501376748085, 51.783723905682564, 48.30707386136055, 54.01788242161274, 57.235914543271065, 61.49149999022484, 63.662296906113625, 61.69948183000088, 61.069684624671936, 62.184176221489906, 61.34965360164642, 60.94993785023689, 57.97704957425594, 60.38957051932812, 60.051080882549286, 53.029475659132004, 47.04822041094303, 44.836518689990044, 47.96575337648392, 45.262578427791595, 45.96031218767166, 45.8955180644989, 46.120629385113716, 53.769865930080414, 58.87746445834637, 58.22213642299175, 60.86023986339569, 59.222983717918396, 57.98624128103256, 57.90364131331444, 56.749289855360985, 55.81292510032654, 63.61300975084305, 52.95436508953571, 57.50282362103462, 58.95701698958874, 57.00108714401722, 55.83519570529461, 53.492921590805054, 59.213138446211815, 58.71521316468716, 55.625142976641655, 53.49419452250004, 50.80830104649067, 43.97994965314865, 45.16910724341869, 44.838627576828, 42.738385275006294, 42.19619236886501, 44.333748668432236, 48.8200007379055, 55.847514644265175, 56.34722962975502, 54.50855769217014, 52.40338325500488, 46.381785571575165, 43.82494457066059, 42.880965024232864, 43.970845341682434, 41.89402878284454, 42.9977897554636, 49.01086449623108, 48.25637698173523, 51.406578943133354, 50.79708404839039, 50.42873181402683, 49.616973772645, 49.624227583408356, 46.31856456398964, 45.21136857569218, 45.004139095544815, 45.79232320189476, 45.045412480831146, 51.57535828649998, 51.90905638039112, 52.43656687438488, 56.23558022081852, 54.57940109074116, 51.844976618885994, 53.00745964050293, 33.94031457602978, 2.5482544116675854, 3.121362221427262, 8.614418003708124, 7.355774492025375, 18.490930683910847, 16.19414772838354, 22.53248881548643, 3.440341567620635, 1.0230383416637778, 0.23315590457059443, 0.6787128711584955, 43.84660720825195, 50.20503021776676, 36.295496597886086, 54.650966450572014, 6.950766099616885, 0.20668504061177373, 0.21622517087962478, 0.18483331863535568, 0.12363893823930994, 0.1032905477040913, 0.17144999146694317, 0.17395453207427636, 0.20335543958935887, 0.10187776570091955, 0.16512169822817668, 0.18797475553583354, 0.0651255960110575, 0.1344889443134889, 0.10535509121837094, 0.11620648510870524, 0.1486532186390832, 0.10401371866464615, 0.07832783172489144, 0.2107688714750111, 0.19973110203864053, 0.17814739927416667, 0.07547289351350628, 0.09937398208421655], [0.057652298783068545, 0.01538209135105717, 0.008621124161436455, 0.013427243757178076, 0.03791008704865817, 0.08618077088613063, 0.04097749471839052, 0.039032147542457096, 0.11319080513203517, 0.029296394568518735, 0.05038621660787612, 0.012394897785270587, 0.07920421907329, 0.045872496702941135, 0.04524545242020395, 0.08378954880754463, 0.033910415731952526, 0.020326851554273162, 0.05126311974890996, 0.04424574610311538, 0.053804593335371464, 0.021951032467768528, 0.04808976678759791, 0.06300643784925342, 0.04276247491361573, 0.04699453493230976, 0.03375945547304582, 0.06397741934051737, 0.054187103669391945, 0.044250996797927655, 0.8928823820315301, 22.4773233756423, 45.4875947535038, 25.99541399627924, 54.78787310421467, 24.879151694476604, 0.27306358970236033, 0.3572674869792536, 0.4315017879707739, 0.737368423724547, 3.1205642642453313, 10.922118723392487, 16.959563456475735, 13.321947399526834, 2.1196568850427866, 0.11883283441420645, 0.9581409709062427, 41.511130928993225, 66.81952849030495, 62.8406023979187, 58.812924921512604, 59.908964708447456, 56.82546056807041, 54.90706890821457, 52.2011087089777, 50.23331589996815, 47.704714983701706, 46.6816920787096, 47.55630634725094, 53.305682837963104, 53.148492872714996, 55.9964856505394, 56.951818987727165, 58.15363749861717, 59.809379652142525, 59.22237575054169, 58.92463132739067, 57.06749238073826, 55.023285672068596, 57.34597183763981, 57.87789769470692, 53.37466053664684, 43.813320994377136, 41.893447414040565, 41.86765819787979, 42.88084723055363, 42.077813521027565, 40.28360299766064, 41.4658297598362, 48.218709602952, 54.73821356892586, 57.59642779827118, 58.495299965143204, 51.077900379896164, 50.96631936728954, 50.30715353786945, 56.72696605324745, 58.59302692115307, 56.68984204530716, 50.43862268328667, 55.586005076766014, 57.566496804356575, 54.836605489254, 49.81237068772316, 46.76792465150356, 49.79361869394779, 53.64087425172329, 52.15736925601959, 47.7426977455616, 44.262179508805275, 41.67801417410374, 40.84640979766846, 37.85467833280563, 39.29385110735893, 38.78504320979118, 42.808092534542084, 52.26846769452095, 56.1143933236599, 55.5974006652832, 51.663251370191574, 46.20985619723797, 43.24591264128685, 39.91048201918602, 38.74697685241699, 38.65585394203663, 36.336055621504784, 38.425384908914566, 42.66737088561058, 43.42676393687725, 45.859195813536644, 45.20137131214142, 44.812302589416504, 44.90570917725563, 44.79091353714466, 43.97139631211758, 42.52955228090286, 40.53903669118881, 43.37344519793987, 45.97606994211674, 48.66156443953514, 50.39478063583374, 53.59917148947716, 51.665576845407486, 52.53889158368111, 52.94239193201065, 50.14974318444729, 14.451566934585571, 0.13598754827398807, 2.576809166930616, 4.394927294924855, 3.0963548133149743, 1.5685113030485809, 7.39104182459414, 3.2223650766536593, 0.29391307092737406, 0.05738160041801166, 0.12092075558030047, 5.101906908676028, 42.95642897486687, 26.76695689558983, 35.092500150203705, 27.77630053460598, 0.361271551810205, 0.09195213424391113, 0.044361094405758195, 0.06942571097170003, 0.1413960088393651, 0.03592085668060463, 0.059195283174631186, 0.035308506921865046, 0.037240105812088586, 0.01163177515991265, 0.021658583609678317, 0.04127578984480351, 0.028485826442192774, 0.005446201557788299, 0.03437658095208462, 0.048490897606825456, 0.03759553517738823, 0.04909240458800923, 0.023914953744679224, 0.10110201357747428, 0.006074705552236992, 0.018445681598677766, 0.010350019329052884, 0.011171839341841405, 0.029084170018904842, 0.030788770054641645, 0.020337230489531066, 0.027089598042948637, 0.00905331107787788, 0.024682957846380305, 0.08186237682821229, 0.010060880449600518, 0.07720250578131527, 0.058398290784680285, 0.024998209191835485, 0.0199482764583081, 0.07473137666238472, 0.006311556880973512, 0.046987618115963414, 0.07103868731064722, 0.011608604381763143, 0.013698141574423062, 0.010186075196543243, 0.03399457156774588, 0.018512910901336, 0.0290785797915305, 0.048114869932760485, 0.054584542303928174, 0.035300209710840136, 0.09315599425463006, 0.05154250866326038, 0.05342114047380164, 0.005951753018962336, 0.03677045249787625, 1.04438915848732, 32.799049615859985, 46.1973624676466, 24.41449172794819, 67.07520917057991, 25.213362760841846, 0.22549336339579895, 0.20592628367012367, 0.25666343222837895, 0.49007994937710464, 0.4385309654753655, 3.520285952836275, 12.091838456690311, 7.556693460792303, 5.776190226897597, 0.36678769800346345, 1.7856746376492083, 48.93182873725891, 68.38442131876945, 64.21002611517906, 61.80465638637543, 62.76917763054371, 59.53358665108681, 55.920147746801376, 52.97996051609516, 51.46530479192734, 51.11863799393177, 48.48933108150959, 48.7188995629549, 55.00274397432804, 56.22966393828392, 58.14411520957947, 60.04692770540714, 59.013310968875885, 62.03649714589119, 59.75247010588646, 62.05866515636444, 56.98041245341301, 57.22038857638836, 59.37222830951214, 60.826550871133804, 55.71511074900627, 45.46937473118305, 43.945831283926964, 43.412799686193466, 43.43700058758259, 45.182364732027054, 44.369018375873566, 44.27663013339043, 50.16737423837185, 56.43943168222904, 58.08518037199974, 59.98328872025013, 54.104589968919754, 52.87108115851879, 53.789890855550766, 58.18944677710533, 61.25394433736801, 57.094527930021286, 51.75921142101288, 55.303239449858665, 60.476365461945534, 56.83650277554989, 51.30846820771694, 49.941252171993256, 51.88027672469616, 54.85764116048813, 54.000042378902435, 49.953753501176834, 45.574423894286156, 42.96293802559376, 42.39927627146244, 40.234217047691345, 39.92094665765762, 39.75920453667641, 43.173971101641655, 54.15184423327446, 56.20022691786289, 57.580423057079315, 53.25432859361172, 49.3269657343626, 43.82848218083382, 42.38764509558678, 41.06541484594345, 41.1180230230093, 39.562238305807114, 40.28293803334236, 44.28081750869751, 45.51008574664593, 49.78649787604809, 48.61816316843033, 47.4097216129303, 48.7003755569458, 46.44823260605335, 45.04887409508228, 42.59949132800102, 42.33871892094612, 45.46910494565964, 47.54173032939434, 48.59313391149044, 52.5103285163641, 54.23575893044472, 54.790665954351425, 54.31297458708286, 53.93516466021538, 50.428253039717674, 15.889989249408245, 0.5567505781073123, 2.89619461633265, 3.5865071369335055, 4.407649962231517, 4.135087737813592, 4.980822131037712, 0.4487660725135356, 0.4673034668667242, 0.07319907919736579, 0.19120072305668145, 5.067826062440872, 52.45710477232933, 29.579837657511234, 36.30512148141861, 35.99018298089504, 0.8725899271667004, 0.15179113775957376, 0.047378677991218865, 0.03227623994462192, 0.040788384358165786, 0.019656258045870345, 0.07017332085524686, 0.129438154399395, 0.08302633155835792, 0.026872820417338517, 0.07147350421291776, 0.036006437439937145, 0.040860576773411594, 0.00958306722168345, 0.02938102166808676, 0.03287016959802713, 0.09090646301046945, 0.10866805328987539, 0.07996057145646773, 0.06133968177891802, 0.027249048471276183, 0.027657654572976753, 0.04082830448169261, 0.032214975653914735, 0.1273268778459169, 0.21085861197207123, 0.08298045198898762, 0.13407690392341465, 0.11403361771954224, 0.1943826663773507, 0.20950137230101973, 0.12921264540636912, 0.1572843367466703, 0.11518488172441721, 0.1187958606169559, 0.12045479816151783, 0.1874464057618752, 0.15299512393539771, 0.15762735740281641, 0.14511406479869038, 0.1483361137798056, 0.10741381629486568, 0.11189632146852091, 0.1967874326510355, 0.1065531476342585, 0.13977302092825994, 0.11546462686965242, 0.15049666893901303, 0.10000480018788949, 0.1920280247577466, 0.17318269849056378, 0.1929700476466678, 0.14835511276032776, 0.19874122546752915, 1.3481624331325293, 37.392493933439255, 60.71933202445507, 33.66853415966034, 67.43267878890038, 33.909277841448784, 0.4242195381084457, 0.9081694367341697, 1.285780230537057, 1.2752433959394693, 9.371900707483292, 23.230657652020454, 32.20589004456997, 26.876058541238308, 5.12533170171082, 0.26984421245288104, 1.620220709592104, 46.40309102833271, 71.53694495558739, 67.64745086431503, 64.1100762784481, 64.22327980399132, 64.48073118925095, 58.779190331697464, 56.929308995604515, 54.30336490273476, 55.64323000609875, 50.645335391163826, 51.979333609342575, 59.146733209490776, 57.70665608346462, 59.09835800528526, 61.43814705312252, 60.66298484802246, 65.06781488656998, 62.517748922109604, 62.761019468307495, 58.08023303747177, 58.327527567744255, 61.07473835349083, 64.14778545498848, 58.847955241799355, 49.34255249798298, 47.480173632502556, 46.96858048439026, 45.52164852619171, 47.25989185273647, 44.26409840583801, 46.211140528321266, 53.440552800893784, 58.078067153692245, 61.34190581738949, 62.459121868014336, 55.04371337592602, 55.622768104076385, 55.18101520836353, 61.279509365558624, 62.88260154426098, 58.86988386511803, 53.123186230659485, 60.29654011130333, 63.70085723698139, 58.90490658581257, 53.27598363161087, 51.57980024814606, 53.37958887219429, 57.38322503864765, 55.534434244036674, 51.4777947217226, 47.55798205733299, 46.36138066649437, 44.33792844414711, 42.75704987347126, 43.14793489873409, 41.59664534032345, 44.7374352067709, 55.15901818871498, 59.68551769852638, 59.86514165997505, 56.707347705960274, 50.47602407634258, 46.21209427714348, 44.84377630054951, 43.27812731266022, 43.448213785886765, 40.58254815638065, 42.9374223947525, 47.754123732447624, 46.90429553389549, 53.69820937514305, 50.03519833087921, 48.936145305633545, 49.83417011797428, 49.46389138698578, 48.66339214146137, 46.80113106966019, 45.282154977321625, 47.59518586099148, 50.3710775077343, 52.20249943435192, 54.68090124428272, 57.972197234630585, 56.15129314363003, 58.74138616025448, 54.14881579577923, 52.154052034020424, 16.19129028171301, 0.35153448523487896, 4.753430932760239, 10.745187867432833, 5.092448266223073, 9.866747204214334, 21.09821207821369, 9.910689946264029, 1.3545427657663822, 0.5853619147092104, 0.44244246964808553, 8.083462994545698, 57.316299229860306, 36.98257192969322, 44.79717180132866, 41.10906310379505, 0.7384597964119166, 0.24169643613277003, 0.23098478122847155, 0.12239290939760394, 0.22788241098169237, 0.13088372448692098, 0.19390827073948458, 0.19855643069604412, 0.14464357285760343, 0.18171310715842992, 0.19030962634133175, 0.1009450493438635, 0.10509856787393801, 0.09167744312435389, 0.16021032817661762, 0.1309166313149035, 0.13441217655781657, 0.2393754880176857, 0.2518665458774194, 0.23603727808222175, 0.10895307510509156, 0.07276286705746315, 0.08186547158402391, 0.1953839126508683], [0.05777517246315256, 0.0310139283828903, 0.00596808537011384, 0.1193665350729134, 0.055030179719324224, 0.02083443418086972, 0.010731756901805056, 0.025210808526026085, 0.030335993178596254, 0.0239465191407362, 0.029994438264111523, 0.02652992963703582, 0.03659581401734613, 0.08770036278292537, 0.08127910070470534, 0.029169786030252, 0.05608340972685255, 0.036403876074473374, 0.04252178157912567, 0.015454977674380643, 0.038755935020162724, 0.008656410500407219, 0.034207063290523365, 0.007921880969661288, 0.028984186028537806, 0.046843849268043414, 0.008493974783050362, 0.035065000847680494, 0.07054823159705848, 0.0666711779194884, 0.3568260575411841, 4.86562798731029, 42.00875602662563, 40.311599895358086, 38.6823271214962, 50.0468485057354, 8.371320348232985, 0.04163609512033872, 0.19572875899029896, 0.17082725535146892, 0.2586913655977696, 4.857711587101221, 5.892734248191118, 4.008001182228327, 3.0753588024526834, 0.26137224049307406, 0.0034154763216065476, 6.380831832066178, 54.340656101703644, 66.2586709856987, 63.111307471990585, 59.47138398885727, 61.67595349252224, 53.80811467766762, 53.69071237742901, 52.091249004006386, 53.46600763499737, 50.66639006137848, 49.419391974806786, 52.26470969617367, 55.11255428195, 54.67792220413685, 55.71540333330631, 57.46142104268074, 59.314915984869, 60.50424076616764, 60.12051835656166, 58.479420617222786, 56.6790696233511, 59.032682329416275, 56.58917784690857, 53.10628853738308, 42.77305841445923, 40.774848237633705, 42.39035815000534, 44.949961602687836, 41.77904315292835, 41.90845660865307, 40.624285116791725, 50.87736614048481, 57.56527327001095, 56.524474918842316, 55.0636813044548, 49.856957495212555, 46.45156502723694, 52.32109487056732, 55.11674925684929, 54.12779152393341, 55.26503250002861, 52.53144398331642, 57.31096811592579, 56.82260312139988, 54.921762719750404, 51.12693674862385, 46.59546710550785, 46.95197157561779, 46.29913240671158, 47.863664254546165, 45.390099585056305, 42.22605116665363, 41.54662102460861, 39.21634666621685, 38.94469924271107, 41.29850573837757, 41.518274545669556, 50.2801787853241, 55.25217019021511, 57.98019200563431, 54.54807557165623, 51.19444392621517, 44.305801168084145, 41.5823695063591, 39.751741737127304, 41.91824108362198, 39.716240242123604, 38.32007355988026, 40.51268510520458, 44.34001073241234, 43.9239938557148, 45.35220801830292, 44.86009642481804, 45.282223373651505, 43.64715591073036, 43.0325198918581, 42.33490012586117, 39.80064131319523, 42.675392255187035, 43.996854946017265, 47.73109316825867, 52.323644533753395, 52.20707058906555, 55.08627489209175, 53.20856764912605, 52.9679873585701, 50.90507425367832, 34.28021013736725, 2.457430735230446, 1.047705786768347, 1.7615181463770568, 3.3543664310127497, 0.6228777172509581, 2.248851852491498, 3.371985135599971, 0.20792965195141733, 0.13274090451886877, 0.06849010023870505, 0.21938645280897617, 24.277011305093765, 40.22345222532749, 19.834388494491577, 38.99743661284447, 7.482161410152912, 0.07401488503091969, 0.11503449291922152, 0.03125908573565539, 0.03482905725832097, 0.09512333126622252, 0.06015513245074544, 0.07495394675061107, 0.05878622250747867, 0.07411839978885837, 0.0426527298259316, 0.010443901937833289, 0.07549734727945179, 0.03522073311614804, 0.023989973742573056, 0.0519904541579308, 0.06612411118112504, 0.03892509274010081, 0.023133134563977364, 0.01704294641967863, 0.07315342969377525, 0.07611601642565802, 0.07597639618325047, 0.028789715506718494, 0.061792254564352334, 0.028264651591598522, 0.06744399113813415, 0.037248733278829604, 0.04300883454561699, 0.06021694221999496, 0.0988578777469229, 0.00524002272868529, 0.01650099307880737, 0.019830759229080286, 0.052347301025292836, 0.020073526866326574, 0.03312955392175354, 0.015171502309385687, 0.03853053734928835, 0.045479945110855624, 0.06979777928791009, 0.023541352893516887, 0.05018657888285816, 0.010309307890565833, 0.054211672468227334, 0.09334060348919593, 0.03343681419210043, 0.06055552854377311, 0.09026366664329544, 0.0767650616762694, 0.033295865505351685, 0.03602644203056116, 0.06810493301600218, 0.062133623941917904, 0.134981359296944, 0.4483108391286805, 7.544466191902757, 53.40185947716236, 37.796378061175346, 46.36795811355114, 59.3197987228632, 6.124189803376794, 0.060596717739827, 0.06788622209569439, 0.051216742940596305, 0.1561096208752133, 1.17786139016971, 4.644681243225932, 6.712725022807717, 4.780313540250063, 2.2184717701748013, 0.07572835558676161, 10.105500742793083, 58.28870125114918, 65.73454231023788, 63.53866294026375, 63.01996797323227, 61.75158463418484, 56.130831241607666, 54.809376150369644, 53.39793808758259, 54.55300770699978, 51.76769256591797, 50.26521138846874, 55.515636652708054, 56.61443129181862, 57.06602565944195, 57.715156227350235, 59.25262592732906, 59.479302763938904, 61.73104673624039, 59.74593065679073, 58.7005003541708, 57.033472806215286, 59.606953114271164, 57.66584247350693, 55.55549271404743, 44.842985942959785, 42.113322615623474, 43.27585123479366, 44.93864580988884, 43.801469430327415, 42.799432799220085, 43.199790716171265, 52.37768143415451, 59.82569217681885, 59.324898049235344, 56.89746290445328, 53.348533138632774, 52.04227723181248, 54.75645639002323, 55.78921437263489, 56.83530203998089, 55.70835091173649, 52.349027171730995, 59.098718985915184, 56.50614470243454, 55.91886721551418, 54.90386947989464, 48.50911661982536, 48.5919825732708, 48.631219267845154, 49.564741775393486, 47.92520955204964, 44.79638524353504, 42.9465951025486, 40.086769759655, 40.735565945506096, 42.94977553188801, 42.70522065460682, 52.37641990184784, 56.0334462672472, 59.526424035429955, 56.01793169975281, 51.67487874627113, 46.37043558061123, 45.30624948441982, 42.265713438391685, 43.90149526298046, 41.64690524339676, 40.84674417972565, 42.35855005681515, 46.598385348916054, 47.90565960109234, 46.918274983763695, 47.28093132376671, 46.595170721411705, 44.86909054219723, 46.36794291436672, 44.72293898463249, 42.28606894612312, 44.70197170972824, 45.41123025119305, 49.821653589606285, 53.36003892123699, 52.40662828087807, 56.307179778814316, 54.26136575639248, 54.08869542181492, 49.22156699001789, 36.40212267637253, 3.7843074230477214, 1.5025024325586855, 4.82423348352313, 5.746430698782206, 5.39425989612937, 3.1927421037107706, 1.771728079766035, 0.2094678272260353, 0.06623541106819175, 0.08821041861665435, 0.22711473342496902, 25.2977030351758, 48.91200140118599, 22.567931413650513, 45.5696627497673, 11.979812867939472, 0.12279957663849927, 0.16451745643280447, 0.004563065303955227, 0.0989458296680823, 0.11337996373185888, 0.08746528008487076, 0.022519367303175386, 0.08198263443773612, 0.05224972344876733, 0.037088544413563795, 0.041059910217882134, 0.05533643066883087, 0.03225786807888653, 0.03883764919009991, 0.03857624251395464, 0.07883016180130653, 0.09614523150958121, 0.08843377538141795, 0.06563562958035618, 0.06024481728672981, 0.08651143478346057, 0.04522765571891796, 0.07655252542463131, 0.013735253596678376, 0.17590497038327157, 0.08602511283243075, 0.12268728227354586, 0.14063330367207527, 0.21395501535153016, 0.16740941297030076, 0.10253593194647692, 0.09297193420934491, 0.08692608011187986, 0.11536967649590224, 0.15031537710456178, 0.09213522207573988, 0.1420829407288693, 0.16014988766983151, 0.26517616293858737, 0.1270691744866781, 0.13997124857269228, 0.18599222676130012, 0.14030226127943024, 0.07247882487718016, 0.2120828884653747, 0.13567096291808411, 0.17029522452503443, 0.17190179612953216, 0.26064698409754783, 0.19576914666686207, 0.08988039931864478, 0.14864349650451913, 0.22301942895865068, 0.3049871016992256, 0.6195829971693456, 11.010699570178986, 62.80855491757393, 49.00850482285023, 49.02736321091652, 64.07265588641167, 12.784629631787539, 0.2987658855272457, 0.519425121601671, 0.352757663349621, 0.5524044425692409, 13.069601990282536, 22.581815868616104, 10.447281002998352, 11.120521277189255, 2.310195523314178, 0.21441140648676082, 9.841667599976063, 56.05730138719082, 69.97719705104828, 67.54540354013443, 65.53170159459114, 67.01429083943367, 59.182113111019135, 58.421082347631454, 57.17933177947998, 57.84335754811764, 55.742279291152954, 55.111034363508224, 58.20764780044556, 60.04595495760441, 60.837304294109344, 59.38416346907616, 61.56976439058781, 61.40103064477444, 65.54928705096245, 62.876989245414734, 60.350466817617416, 57.66113832592964, 61.883623749017715, 61.17378383874893, 56.54914319515228, 46.318499967455864, 42.857710272073746, 45.90579651296139, 46.996987760066986, 45.29472850263119, 45.01885570585728, 45.628711581230164, 55.714187398552895, 61.64083197712898, 61.62842184305191, 56.99225641787052, 55.454513132572174, 52.82130762934685, 56.754871755838394, 58.190248534083366, 58.85325975716114, 56.741040498018265, 53.06230589747429, 60.680969282984734, 60.13631410896778, 58.14916893839836, 57.46775530278683, 51.424605175852776, 51.751646026968956, 49.35992896556854, 51.98443293571472, 49.86578442156315, 46.52414873242378, 45.50736129283905, 43.185693472623825, 43.288493156433105, 47.427075281739235, 45.66803567111492, 55.248169004917145, 58.89968566596508, 62.390193566679955, 58.02488140761852, 54.09517787396908, 50.00446557998657, 46.51870742440224, 43.451086431741714, 45.36343641579151, 43.988879173994064, 43.18244844675064, 45.208511129021645, 49.1634377092123, 49.6515367180109, 49.78178232908249, 51.06938123703003, 49.072508588433266, 48.73651161789894, 47.12603643536568, 47.096021845936775, 44.02696453034878, 47.776386737823486, 46.69447839260101, 52.858093455433846, 56.19158238172531, 55.0075127184391, 58.7028182297945, 55.999989062547684, 52.99712799489498, 51.540343165397644, 36.06511875987053, 3.124958253465593, 3.018459230661392, 5.492670340463519, 8.996782936155796, 7.683038106188178, 8.31909405067563, 10.873132701963186, 1.6641520522534847, 0.3288950922433287, 0.25236434885300696, 0.6653299299068749, 33.018316850066185, 53.8572346419096, 28.194998167455196, 54.435396417975426, 13.16019767895341, 0.21866814291570336, 0.31545646023005247, 0.2038470233674161, 0.12806678423658013, 0.1456643673009239, 0.1702601506258361, 0.19343013467732817, 0.18556026712758467, 0.184157207258977, 0.1707577903289348, 0.22384647832950577, 0.1741735843825154, 0.1291814455180429, 0.20868379273451865, 0.1343832179554738, 0.15398902294691652, 0.16557231545448303, 0.1745296668377705, 0.17086562438635156, 0.14935837767552584, 0.3238961932947859, 0.26138355082366616, 0.16802122467197478, 0.15942426020046696], [0.007535620470662252, 0.019599541265051812, 0.08799092844128609, 0.014989690971560776, 0.08845378368278034, 0.025404809639439918, 0.04767143298522569, 0.03235138610762078, 0.05396152788307518, 0.009048475985764526, 0.061660835053771734, 0.06290773962973617, 0.02717417875828687, 0.01652375103731174, 0.05228866764809936, 0.05361720846849494, 0.08655267592985183, 0.015457324716408039, 0.05478968676470686, 0.0390412425622344, 0.07732919038971886, 0.03995288563601207, 0.08140670557622798, 0.07057814014842734, 0.04015156227978878, 0.012887477896583732, 0.04120167526707519, 0.04993963666493073, 0.016788653229014017, 0.06964037718717009, 0.09046180523000658, 0.472578207263723, 21.54772225767374, 48.544534519314766, 32.20474250614643, 44.91093009710312, 37.692856416106224, 2.6085688127204776, 0.052466463966993615, 0.2537502651102841, 0.09767582945642062, 0.5269266909454018, 3.455781089141965, 3.66869340185076, 6.211106339469552, 1.7614403693005443, 0.2841158310184255, 0.24336613481864333, 14.53283317387104, 61.99733644723892, 62.93977327644825, 63.59541669487953, 61.522145345807076, 59.39737915992737, 55.80945208668709, 58.101546093821526, 53.84311079978943, 51.37535601854324, 49.931836277246475, 54.271541610360146, 52.63626515865326, 54.20700587332249, 54.04978930950165, 56.67543321847916, 57.87430688738823, 62.397097796201706, 63.030151426792145, 55.88966578245163, 58.34662154316902, 61.90708369016647, 58.390425592660904, 55.55545471608639, 40.80740489065647, 42.45267100632191, 42.89113327860832, 43.36413949728012, 42.32624039053917, 42.71081395447254, 42.73051209747791, 51.79729677736759, 57.85785757005215, 55.57137966156006, 56.09999589622021, 53.50609168410301, 46.29926919937134, 41.286631375551224, 56.99783451855183, 56.040525287389755, 55.931303948163986, 55.96079796552658, 56.050849333405495, 54.678245186805725, 56.19324669241905, 48.41778852045536, 47.94893927872181, 45.6411787122488, 44.73389379680157, 45.656180307269096, 44.67026621103287, 42.58915588259697, 40.20808205008507, 39.17699217796326, 38.58532212674618, 41.25344015657902, 48.59439164400101, 54.76415857672691, 57.53171347081661, 55.82612179219723, 56.44536316394806, 48.53334791958332, 41.01921692490578, 41.122871562838554, 45.680362209677696, 47.62301556766033, 43.11869166791439, 38.556078895926476, 38.842070549726486, 41.63813531398773, 45.18647611141205, 45.66351391375065, 45.27266688644886, 45.0964779406786, 43.19246470928192, 44.16413716971874, 42.498169764876366, 42.607049122452736, 41.84579037129879, 46.794356033205986, 49.129353538155556, 51.396862864494324, 51.26824736595154, 54.34266619384289, 53.62007796764374, 55.83080314099789, 49.17164146900177, 12.855026554316282, 0.5345324578229338, 1.4540173904970288, 2.2839550813660026, 3.27475571539253, 6.242765290662646, 3.6489548860117793, 0.42833994200918823, 0.052349802062963136, 0.009883967286441475, 0.06572251280886121, 6.866843327879906, 46.596903428435326, 22.314547710120678, 30.17040006816387, 30.79997308552265, 0.909696954768151, 0.07562365339254029, 0.05711770754714962, 0.03258809410908725, 0.014100156477070414, 0.046542622658307664, 0.023661940758756828, 0.045190585442469455, 0.017421243210264947, 0.04519107154919766, 0.05224569729762152, 0.03676046690088697, 0.04542717841104604, 0.06462276869569905, 0.027458918557385914, 0.05893261113669723, 0.09045917060575448, 0.02083651219436433, 0.043258734222035855, 0.004375923954285099, 0.09215477024554275, 0.054119705528137274, 0.02842048961610999, 0.028621754499909002, 0.04008591560705099, 0.03589750129322056, 0.024392574014200363, 0.05636759291519411, 0.026315495342714712, 0.07770479875034653, 0.03613068038248457, 0.014370748158398783, 0.014718507427460281, 0.049656982300803065, 0.05293349007843062, 0.05875753107829951, 0.041251016955357045, 0.012536316808109405, 0.006973616618779488, 0.015427660146087874, 0.036549103242577985, 0.024370482133235782, 0.06183651625178754, 0.045653963898075745, 0.033658304455457255, 0.04148308653384447, 0.013491454374161549, 0.0637308407749515, 0.03257885808125138, 0.0664817521465011, 0.0416046503232792, 0.052448663554969244, 0.04125517669308465, 0.037652331739082, 0.014561699044861598, 0.054811108857393265, 0.4652154789073393, 30.32873947173357, 55.08452698588371, 29.842821545898914, 58.72552961111069, 41.74477659165859, 1.9663604046218097, 0.08249808568507433, 0.05172805300389882, 0.11914334158063866, 0.11714219974237494, 1.4465560158714652, 4.917914131656289, 5.675958730280399, 3.844805876724422, 0.9187509783077985, 0.2758104563690722, 19.895295426249504, 64.63728278875351, 67.0246870815754, 65.57511806488037, 64.96496200561523, 59.64964382350445, 56.66461139917374, 59.36732657253742, 56.13802805542946, 52.785315960645676, 51.744297221302986, 55.24841599166393, 55.84656849503517, 57.112930342555046, 56.87214866280556, 60.24677038192749, 60.95488898456097, 63.267315700650215, 63.671446815133095, 57.18081749975681, 58.315246626734734, 62.75820381939411, 60.400202348828316, 58.22402112185955, 44.23255629837513, 45.41236639022827, 45.46646788716316, 46.11288160085678, 45.9410510212183, 43.752471059560776, 43.51045824587345, 53.41876856982708, 58.56746569275856, 56.36129267513752, 56.22357286512852, 56.02047376334667, 52.0835430175066, 44.53018292784691, 58.78227196633816, 57.98236168920994, 56.058095544576645, 55.87664768099785, 57.2771917283535, 56.08595184981823, 58.97954598069191, 51.24788425862789, 51.4889395236969, 47.657430320978165, 46.2808021903038, 47.344471514225006, 46.62377178668976, 43.78298342227936, 41.19419373571873, 40.526090785861015, 40.81190764904022, 43.01213398575783, 48.45459334552288, 54.97253939509392, 59.67218421399593, 58.86447675526142, 57.07731485366821, 50.967539101839066, 42.8627298027277, 42.96043016016483, 47.01805382966995, 48.64385738968849, 44.12805050611496, 40.773605704307556, 40.24822309613228, 44.2895532399416, 45.992393866181374, 47.39445023238659, 46.96725435554981, 47.36090563237667, 45.680943578481674, 45.675129890441895, 44.50347036123276, 43.048292845487595, 43.37339200079441, 48.85633058845997, 51.81428946554661, 52.78296768665314, 53.599650263786316, 56.80618420243263, 54.08334530889988, 53.71633060276508, 51.83925412595272, 13.901840932667255, 1.0534964385442436, 3.379276469349861, 3.719821320846677, 4.698926657438278, 3.3486819360405207, 2.13663128670305, 0.43699599627871066, 0.004509735963438288, 0.07064586112392135, 0.04637105666915886, 7.588102575391531, 54.46220017969608, 27.973441556096077, 29.51306004077196, 38.8741522282362, 1.4391217147931457, 0.09948993523721583, 0.02861999746528454, 0.038313281038426794, 0.037179891660343856, 0.031798074196558446, 0.02143565729056718, 0.02081963019008981, 0.06030310185451526, 0.030727997436770238, 0.020017721071781125, 0.06312026845989749, 0.05655472545186058, 0.06812838488258421, 0.03959191613830626, 0.041021767538040876, 0.05111188489536289, 0.06484349083621055, 0.03908038343070075, 0.03707711905008182, 0.030016405835340265, 0.04579583655868191, 0.08097516896668822, 0.030821166656096466, 0.04257057036738843, 0.08091535928542726, 0.12924926297273487, 0.18138056562747806, 0.14381260494701564, 0.16390500648412853, 0.09869767774944194, 0.10016632120823488, 0.11237249826081097, 0.1296909447410144, 0.11018909979611635, 0.156695383193437, 0.11402762116631493, 0.1416367615456693, 0.11980576775385998, 0.16759270860347897, 0.0973799054918345, 0.20876761089311913, 0.0954315897251945, 0.12666232913034037, 0.26717399479821324, 0.22080652270233259, 0.13592413917649537, 0.17505771975265816, 0.173809471889399, 0.14562512253178284, 0.07294357259524986, 0.10894907492911443, 0.12707615067483857, 0.14987145405029878, 0.15897159464657307, 0.2606111828936264, 0.5542706768028438, 36.69620789587498, 67.52303794026375, 38.531528413295746, 59.11626644432545, 50.76328106224537, 4.771659979596734, 0.11980358583969064, 0.4001055273693055, 0.24007871747016907, 2.116589262150228, 9.586945418268442, 12.513323239982128, 12.454925123602152, 5.507759805768728, 0.5782001896295696, 0.3118617640575394, 17.28039164096117, 67.13547393679619, 69.5519770681858, 69.02329623699188, 68.49251791834831, 63.6969168484211, 59.84560690820217, 63.781621903181076, 58.55630189180374, 57.408482283353806, 53.301259875297546, 60.45898139476776, 57.21802890300751, 59.884292632341385, 59.69687908887863, 61.53895564377308, 61.89539931714535, 65.12830764055252, 65.87965652346611, 57.72688999772072, 59.83751714229584, 65.26381596922874, 63.39581720530987, 61.2831761687994, 46.190412640571594, 47.17660792171955, 47.904018089175224, 46.420030519366264, 47.41901211440563, 46.789929270744324, 46.212288066744804, 56.39588601887226, 62.59325087070465, 58.8155809789896, 57.85691902041435, 59.75519835948944, 52.143522799015045, 46.517377495765686, 58.363355845212936, 57.4675577133894, 56.976962238550186, 57.58953496813774, 57.73932293057442, 58.31108585000038, 61.04088596999645, 52.685415521264076, 52.448182851076126, 50.537466779351234, 48.853188157081604, 49.94863137602806, 49.04798090457916, 46.481815204024315, 43.047084510326385, 43.09455156326294, 40.95120057463646, 45.51067851483822, 50.72425715625286, 58.11356104910374, 59.84836935997009, 60.02860888838768, 59.94162395596504, 52.97383524477482, 43.739950731396675, 46.37156791985035, 49.89058569073677, 51.8292036652565, 47.556792721152306, 43.94718401134014, 42.547776103019714, 46.58589541912079, 47.9198594391346, 48.67213927209377, 49.54038508236408, 50.1533529907465, 45.20856432616711, 48.985573053359985, 46.16024985909462, 46.67211279273033, 45.81435441970825, 50.88843494653702, 53.90040412545204, 55.945769771933556, 55.678910091519356, 58.28001111745834, 54.087817668914795, 56.70670174062252, 50.92293709516525, 15.272559430450201, 1.2007393687963486, 4.113388527184725, 6.975805331021547, 5.599041832610965, 15.10621290653944, 12.005924116820097, 3.416124042123556, 0.32586867338977754, 0.31999326834920794, 0.21375067241024226, 12.036688216030598, 60.70408724248409, 30.558290854096413, 38.83551590144634, 45.14606527984142, 1.3345761434175074, 0.15945269929943606, 0.2248020825209096, 0.2139346211333759, 0.1068803457019385, 0.22456198290456086, 0.1275155317853205, 0.1399299257900566, 0.16273977525997907, 0.12869397323811427, 0.12865745957242325, 0.1689286041073501, 0.13383138662902638, 0.18183526466600597, 0.15573072480037808, 0.14783180959057063, 0.14158343081362545, 0.166169002186507, 0.1656855078181252, 0.09154242419754155, 0.19675434770761058, 0.12789098429493606, 0.14960340515244752, 0.2243234566412866, 0.10669605559087358], [0.0470625824527815, 0.05772577511379495, 0.006763275268895086, 0.03912752465112135, 0.15589043498039246, 0.08285342599265277, 0.034675031929509714, 0.032834988087415695, 0.02700889319385169, 0.06264501935220324, 0.004999531629437115, 0.06504799704998732, 0.01504615078374627, 0.03173185235937126, 0.04250499048794154, 0.08986024258774705, 0.05759773608588148, 0.027793725494120736, 0.1097412730450742, 0.05628312908811495, 0.01726480961224297, 0.06389562724507414, 0.021503634307009634, 0.07250505979754962, 0.09229600094840862, 0.053611033799825236, 0.07859424789785407, 0.017497304070275277, 0.027333603211445734, 0.02079129499179544, 0.060083415010012686, 0.15524427668424323, 2.5802928674966097, 40.491755828261375, 40.6082271784544, 29.631607979536057, 49.29474726319313, 29.94337935000658, 1.547863685991615, 0.06610127529711463, 0.027283159433864057, 0.25949968316126615, 0.8572366728913039, 3.505680961534381, 2.499634358100593, 3.0295173497870564, 0.9065950149670243, 0.11085967475082725, 0.4232449794653803, 23.935386836528778, 69.16427627205849, 61.36664628982544, 67.4065437912941, 60.77505983412266, 61.7004431784153, 56.94868415594101, 56.95812664926052, 54.12676177918911, 53.92634533345699, 51.63029193878174, 52.988521456718445, 53.366266787052155, 55.52686505019665, 56.16184517741203, 58.47425289452076, 60.33241778612137, 60.13843819499016, 58.014002591371536, 62.397998347878456, 58.8959276676178, 59.34457339346409, 51.434021070599556, 45.899576246738434, 44.463500306010246, 43.5666686296463, 44.71872881054878, 45.25835685431957, 43.41162174940109, 42.35694654285908, 51.241154819726944, 58.40393386781216, 57.955063953995705, 59.586476013064384, 49.75187033414841, 54.96292971074581, 43.93750973045826, 39.78964850306511, 49.11090932786465, 55.11465556919575, 53.004317209124565, 58.338273391127586, 60.05622960627079, 55.71634568274021, 54.13106694817543, 51.44798532128334, 50.36470524966717, 44.455790519714355, 44.29722122848034, 45.59359386563301, 42.02428579330444, 38.978688418865204, 41.31569221615791, 40.064848735928535, 43.39385390281677, 54.642416909337044, 56.86743691563606, 56.710254549980164, 56.13299712538719, 51.8600732088089, 44.22694779932499, 38.706410229206085, 45.624767392873764, 51.817542091012, 50.63917212188244, 50.54151736199856, 42.1080256998539, 38.79807651042938, 42.27492794394493, 45.42828753590584, 47.95504555106163, 45.566809102892876, 47.822554260492325, 43.80740091204643, 45.06781607866287, 42.15148016810417, 43.93437869846821, 45.72249814867973, 46.09607510268688, 49.25970174372196, 52.04626701772213, 54.00654003024101, 55.035752803087234, 55.749559700489044, 45.880197286605835, 14.715072344988585, 0.6861636776011437, 0.49307881970889866, 1.5283055417239666, 4.912293283268809, 5.442652199417353, 2.6260766107589006, 1.6889496403746307, 0.2151223542750813, 0.016592177053098567, 0.02779094058496412, 2.7129596611484885, 36.601125597953796, 35.1050166785717, 18.13405193388462, 37.77510680258274, 8.473987989127636, 0.041225012100767344, 0.021795088687213138, 0.011815130164904986, 0.10060945758596063, 0.005920204321228084, 0.032800997723825276, 0.02350541624764446, 0.04346811263530981, 0.09068498387932777, 0.021386215412348974, 0.04784402684890665, 0.043507446462172084, 0.03617605900217313, 0.04196483685518615, 0.04267536904080771, 0.006146494888525922, 0.033076356776291505, 0.009586434716766234, 0.0021982057023706147, 0.01644504813157255, 0.0665384299645666, 0.04701097721408587, 0.0034103599091395154, 0.051296649980940856, 0.038131748005980626, 0.04646155415684916, 0.045933994770166464, 0.01604034758202033, 0.02920424765761709, 0.04076476921909489, 0.042046113157994114, 0.026248436734022107, 0.049773024511523545, 0.037794497548020445, 0.04927983769448474, 0.06261229806113988, 0.03561339603038505, 0.029964143795950804, 0.013855749621143332, 0.04951202601660043, 0.02670658675924642, 0.02585742509836564, 0.08198008887120523, 0.09186188908643089, 0.022543197665072512, 0.055951648828340694, 0.028609969194803853, 0.025500114388705697, 0.01185835284559289, 0.04679385448980611, 0.02794390278722858, 0.058640613133320585, 0.036773948013433255, 0.01382308770189411, 0.023572758727823384, 0.03253196176956408, 0.20129409473156556, 4.685811661183834, 51.42941191792488, 40.70938155055046, 35.06246276199818, 61.98399156332016, 30.07137168198824, 0.691392197040841, 0.080322368448833, 0.09524916240479797, 0.3416517795994878, 0.38518209534231573, 1.8268228671513498, 3.997338954359293, 6.184737179428339, 2.040889961645007, 0.13795287406537682, 0.4944135871483013, 29.852845408022404, 69.49671283364296, 62.82946139574051, 66.21701762080193, 62.054097801446915, 63.03909234702587, 57.51865357160568, 58.900263234972954, 55.42026177048683, 57.108127400279045, 52.57972039282322, 56.603134498000145, 55.641067922115326, 56.64549462497234, 58.01477774977684, 61.30781024694443, 61.42585851252079, 62.23649561405182, 57.46367812156677, 61.8121761828661, 61.72483406960964, 60.571911334991455, 53.92274312674999, 47.15211443603039, 44.89499755203724, 43.79746064543724, 45.15472121536732, 45.47250956296921, 45.95970802009106, 45.89330658316612, 54.38875772058964, 59.21672165393829, 59.326569959521294, 58.21335889399052, 51.6460382938385, 57.90433667600155, 46.69219471514225, 43.01032528281212, 50.67668370902538, 55.413935109972954, 54.355612099170685, 57.7773816883564, 59.467941373586655, 57.98838436603546, 55.97611494362354, 52.636132165789604, 50.25130033493042, 48.23452055454254, 46.30756035447121, 46.315026953816414, 43.05775433778763, 41.323831379413605, 43.085534647107124, 42.60009549558163, 45.00573121011257, 56.634235829114914, 58.382932394742966, 60.67586995661259, 57.55412086844444, 55.33849775791168, 45.91876141726971, 41.22829310595989, 46.97524532675743, 53.80034029483795, 52.82840184867382, 50.5737966299057, 44.34877306222916, 41.015895903110504, 44.94320556521416, 47.47898429632187, 48.815836161375046, 47.93583758175373, 49.09859798848629, 46.65873371064663, 46.163897663354874, 44.68651793897152, 46.67563900351524, 48.13058853149414, 47.910929918289185, 52.125162184238434, 53.84285621345043, 55.706899389624596, 55.557483807206154, 54.934317246079445, 47.423663064837456, 19.760064482688904, 1.2834861036390066, 2.0706361904740334, 1.9352125260047615, 4.202034920454025, 6.839647237211466, 2.717399960383773, 0.2675946441013366, 0.19892168609658256, 0.11195392697118223, 0.0273081809427822, 3.193355295807123, 37.083825096488, 47.03424096107483, 20.208472721278667, 43.41320626437664, 13.68581872433424, 0.008776643062446965, 0.09095047978917137, 0.01383753082336625, 0.08119697464280762, 0.09956204972695559, 0.05650413324474357, 0.03363059637194965, 0.030913415612303652, 0.04067786372615956, 0.020930306673108134, 0.055663079547230154, 0.02300554082466988, 0.0320277466380503, 0.047531708842143416, 0.04958997749781702, 0.06632933727814816, 0.046397443729802035, 0.021467564074555412, 0.07421810732921585, 0.016973306992440484, 0.008796131860435707, 0.023479932751797605, 0.05724589129386004, 0.020958022178092506, 0.07329290150664747, 0.16860493866261095, 0.16827594459755346, 0.12839451665058732, 0.10155223004403524, 0.2563921920955181, 0.15860825398704037, 0.19302253233036026, 0.21867174975341186, 0.13480434223311022, 0.164896723581478, 0.1569311338244006, 0.1296575926244259, 0.08910820950404741, 0.08576837426517159, 0.1625226525356993, 0.23086894681910053, 0.16842535376781598, 0.18903553689597175, 0.20653969841077924, 0.13367268576985225, 0.10401400068076327, 0.16588136058999225, 0.09774112360901199, 0.15554221929050982, 0.28342723671812564, 0.10777057410450652, 0.19252484809840098, 0.059575073537416756, 0.11301521299174055, 0.23069951450452209, 0.1780249597504735, 0.3697986504994333, 4.876791313290596, 59.9896115809679, 53.70826743543148, 41.34846545755863, 62.20264323055744, 40.4671635478735, 3.1092734076082706, 0.1594883669167757, 0.2619214297737926, 0.9714856767095625, 4.890670543536544, 11.27445861697197, 8.620135746896267, 10.488078463822603, 3.0380262807011604, 0.202904362231493, 0.6407056481111795, 27.316563203930855, 74.32862475514412, 66.81102454662323, 70.62205284833908, 65.66532522439957, 66.06903076171875, 60.923175886273384, 61.816386356949806, 58.916891142725945, 61.59066326916218, 55.482453033328056, 58.8873553276062, 60.64573757350445, 60.565668269991875, 62.00558580458164, 62.22681373357773, 64.9480453133583, 61.64306625723839, 60.372376441955566, 64.40247818827629, 64.0209710597992, 62.25192278623581, 54.213974699378014, 50.34039795398712, 48.8144264370203, 47.29811780154705, 48.901852145791054, 48.5018590092659, 48.823682740330696, 49.231286868453026, 55.96776679158211, 61.81213058531284, 62.42447152733803, 62.89011754095554, 54.85692299902439, 58.390657380223274, 51.472573801875114, 43.94383259117603, 51.81870862841606, 57.34314478933811, 53.921416997909546, 59.101660028100014, 63.885500729084015, 61.24984435737133, 57.40593262016773, 53.7116302549839, 53.097700998187065, 49.14196506142616, 49.15714904665947, 50.248697474598885, 45.85054747760296, 43.09172831475735, 44.815433621406555, 44.52889859676361, 46.74053572118282, 60.916932821273804, 60.95438741147518, 60.16219072043896, 60.60852997004986, 56.273315995931625, 48.11959572136402, 42.16525822877884, 49.07224640250206, 56.570042073726654, 52.72606573998928, 53.62452372908592, 48.15687172114849, 44.43059027194977, 47.54574291408062, 49.010818898677826, 51.310512498021126, 49.01442490518093, 53.219408467411995, 48.56794126331806, 49.46432836353779, 47.15879827737808, 50.40176086127758, 50.09111613035202, 51.18446186184883, 53.6498037725687, 56.68092392385006, 57.960501462221146, 58.577861934900284, 55.410291105508804, 46.753614619374275, 16.519560366868973, 1.064138242509216, 1.8636978697031736, 4.05897687189281, 10.594769138842821, 9.929830469191074, 8.87647284194827, 4.438123852014542, 0.6023788265883923, 0.23991750815184787, 0.09529720162390731, 5.143530825152993, 47.57137253880501, 46.468591913580894, 27.38569099456072, 53.516092747449875, 14.086399879306555, 0.12955498328665271, 0.1430555252591148, 0.16555983253056183, 0.30525365145877004, 0.15376519120763987, 0.18313570035388693, 0.10687574438634329, 0.11848095993627794, 0.1958017417928204, 0.1751023525139317, 0.14749010995728895, 0.19375249394215643, 0.05233845462498721, 0.1366100469022058, 0.14169925038004294, 0.20700391178252175, 0.11222051383811049, 0.13953798275906593, 0.18492028350010514, 0.14523582154652104, 0.10600778041407466, 0.08004551767953672, 0.22874509828398004, 0.16870024526724592, 0.22221277380594984], [0.037626011471729726, 0.025970572933147196, 0.04118863944313489, 0.06938051417819224, 0.040824909156071953, 0.022097124237916432, 0.03162919107126072, 0.05585616410826333, 0.035807437961921096, 0.03591744651203044, 0.0204479051171802, 0.03276256931712851, 0.004840230094487197, 0.05655603534250986, 0.003511281324790616, 0.06705174382659607, 0.047635219889343716, 0.020153218683844898, 0.06316425555269234, 0.1002335078374017, 0.06603224072023295, 0.0220617646118626, 0.05981578542559873, 0.0745745534368325, 0.09772303004865535, 0.03790115901210811, 0.04448940802831203, 0.07889239088399336, 0.08512803440680727, 0.009347493778477656, 0.07481612992705777, 0.02514506908482872, 0.2614424179773778, 10.14551354572177, 48.890756741166115, 34.256085231900215, 37.43987359106541, 50.31229846179485, 30.74967708438635, 3.8933413848280907, 0.11960632298723795, 0.09090802152059041, 0.17811615485697985, 1.4039402338676155, 4.253071881830692, 3.7795956758782268, 1.0125208622775972, 0.17395871778717265, 0.0182494744512951, 0.4399536328855902, 37.50510849058628, 70.04458263516426, 65.89830592274666, 66.24540209770203, 61.558418199419975, 62.76337534189224, 61.4984118193388, 56.77608981728554, 55.056864470243454, 54.29776020348072, 53.8264486938715, 52.34887517988682, 55.60569182038307, 59.97544214129448, 60.54969012737274, 62.453957945108414, 57.822869047522545, 60.08029751479626, 60.47040358185768, 59.26369093358517, 58.46284590661526, 51.46672211587429, 45.864298939704895, 44.86507035791874, 43.735447973012924, 44.59743931889534, 44.540385380387306, 44.770474433898926, 41.95490151643753, 49.434397369623184, 57.26339466869831, 58.26610006392002, 58.13046254217625, 57.375192269682884, 54.341146275401115, 52.57542282342911, 52.14167609810829, 44.06289920210838, 47.770253866910934, 58.76598224043846, 57.53707878291607, 61.08576536178589, 58.53042148053646, 56.55328117311001, 53.54229994118214, 51.63221463561058, 47.03384578227997, 42.865769639611244, 40.79005882143974, 41.640350595116615, 41.51150330901146, 42.41362430155277, 39.80124548077583, 50.32438561320305, 56.50357224047184, 56.970658376812935, 57.02997699379921, 54.76881332695484, 51.929829865694046, 40.83208076655865, 41.99388362467289, 52.7602107077837, 53.713689744472504, 55.203004628419876, 53.65124769508839, 50.72492212057114, 40.20288772881031, 43.22171173989773, 46.628434136509895, 48.94995376467705, 48.590899631381035, 48.65417383611202, 48.99701043963432, 47.616612911224365, 46.63777783513069, 45.95786891877651, 44.68891941010952, 51.3434187322855, 53.335005864501, 51.44195504486561, 54.574579149484634, 54.793265014886856, 45.559228509664536, 13.081698641180992, 1.0537456814199686, 1.8650837265886366, 2.253032815642655, 2.169499285519123, 1.6385904676280916, 4.358126744627953, 1.0926173580810428, 0.15131494612433016, 0.11843862783280201, 0.03608215876738541, 4.314533583819866, 29.954229667782784, 43.64997535943985, 21.04459125548601, 30.188401602208614, 25.042837411165237, 0.46027515025343746, 0.08212765009375289, 0.01836348503275076, 0.04322760854847729, 0.08204359444789588, 0.10496623552171513, 0.016765461114118807, 0.03908303289790638, 0.0035430014122539433, 0.030869406255078502, 0.03751857075258158, 0.05858713026100304, 0.0062874407922208775, 0.06402133964002132, 0.018592248343338724, 0.04638784776034299, 0.05661035313096363, 0.01948745655681705, 0.06596627863473259, 0.02507414945284836, 0.031261627591447905, 0.037061990369693376, 0.044597483283723705, 0.024022663492360152, 0.0019404668591960217, 0.05380969560064841, 0.021024455527367536, 0.05075099703390151, 0.0653188067371957, 0.029214672977104783, 0.04123306069232058, 0.04002868488896638, 0.014884001720929518, 0.054737651080358773, 0.03135992505121976, 0.06812747204094194, 0.03354834785568528, 0.07183602108852938, 0.008089087768894387, 0.03934908541850746, 0.026512001204537228, 0.08576585838454776, 0.04437011150002945, 0.025204826815752313, 0.036866133887087926, 0.008920221735024825, 0.03523380233673379, 0.004891460548606119, 0.06586833740584552, 0.0687871003174223, 0.0739745121973101, 0.023065131572366226, 0.033000238399836235, 0.08770258922595531, 0.04002649926405866, 0.04400651479954831, 0.057384854735573754, 0.07690093407290988, 0.3785829775733873, 16.757100820541382, 55.2327836304903, 32.568394392728806, 40.45457482337952, 62.734941467642784, 30.04910107702017, 3.0149593809619546, 0.04774313187226653, 0.12264614502782933, 0.11389911829610355, 0.5364225001540035, 1.387103812303394, 10.903624165803194, 6.91582839936018, 0.7303646276704967, 0.06204062912729569, 1.3682381808757782, 46.17639899253845, 70.25371581315994, 68.90401303768158, 65.5323551595211, 63.79353046417236, 62.449542582035065, 62.42548227310181, 56.75972029566765, 59.50112119317055, 56.42271637916565, 55.65093219280243, 53.82308587431908, 57.64707148075104, 62.617368176579475, 62.228934019804, 63.41131277382374, 57.35429339110851, 59.241864904761314, 62.133916318416595, 60.87195843458176, 60.105995535850525, 53.02870810031891, 47.66880691051483, 45.28581418097019, 46.008558198809624, 47.45603732764721, 47.18304857611656, 46.983867064118385, 45.02294808626175, 50.63262887299061, 58.74077819287777, 58.891079127788544, 59.83281299471855, 57.31558866798878, 56.402569860219955, 58.73772695660591, 54.51107315719128, 46.88955992460251, 50.37351697683334, 58.11754323542118, 58.413733541965485, 63.029988035559654, 59.67389792203903, 59.73210319876671, 56.61274038255215, 53.301096484065056, 48.478969037532806, 45.644739121198654, 43.76748025417328, 43.52804370224476, 43.782432451844215, 43.53573828935623, 42.68165431916714, 51.330286636948586, 57.26872578263283, 59.75032702088356, 58.738011941313744, 57.166473269462585, 53.34751479327679, 43.71859207749367, 43.56334000825882, 54.579287096858025, 56.75301365554333, 57.39751607179642, 57.12074272334576, 49.68760438263416, 41.11504018306732, 45.99857993423939, 48.463249281048775, 50.31792216002941, 50.44798158109188, 50.081909224390984, 52.24206671118736, 48.92123490571976, 48.367961794137955, 47.80830502510071, 48.34430806338787, 52.004047483205795, 53.68972823023796, 53.56735199689865, 56.22376665472984, 55.2890320122242, 49.29189741611481, 17.107234932482243, 1.7799337394535542, 2.2712692245841026, 1.7176414257846773, 3.3114218479022384, 3.2741228118538857, 4.729233831167221, 0.29575704073067755, 0.1460975588997826, 0.08794656285317615, 0.07896092822193168, 3.816503332927823, 29.487217627465725, 52.09127560257912, 25.078884176909924, 30.25920320302248, 34.700269997119904, 0.9916726278606802, 0.15834513294976205, 0.023073137490428053, 0.03751261130673811, 0.05258448400127236, 0.06868843920528889, 0.030257707730925176, 0.052498743680189364, 0.05008601787267253, 0.004057850592289469, 0.02561518438596977, 0.030884347543178592, 0.023827157674531918, 0.04722683457657695, 0.0076050377174397, 0.03393960440007504, 0.02314523713721428, 0.030157165274431463, 0.04625912966730539, 0.023659330254304223, 0.04711254012363497, 0.059119472789461724, 0.03448153176577762, 0.02287352574057877, 0.026764463145809714, 0.09477706742472947, 0.12180738456663676, 0.07552063587354496, 0.191658643016126, 0.09771141543751583, 0.12979566177818924, 0.15698511764639989, 0.09373722205054946, 0.19254645943874493, 0.10904479713644832, 0.1279290861566551, 0.11816037440439686, 0.10767663305159658, 0.10019813707913272, 0.1865862269187346, 0.11177685795701109, 0.2382628750638105, 0.1381629315437749, 0.08958066813647747, 0.09784946232684888, 0.22177480277605355, 0.15579465340124443, 0.15814409998711199, 0.1371801202185452, 0.161844685790129, 0.1255717282765545, 0.20909296843456104, 0.17440396186430007, 0.29865676013287157, 0.2348745850031264, 0.15460105729289353, 0.11360200689523481, 0.14227024395950139, 0.41762846522033215, 18.361021354794502, 67.8335952758789, 44.52113561332226, 47.86648370325565, 62.5426109880209, 41.641893312335014, 6.35771862231195, 0.21863563684746623, 0.2368965366622433, 0.6756631785538048, 6.740907160565257, 12.030440401285887, 8.028476145118475, 5.188357494771481, 0.42853717517573386, 0.10211312299361452, 1.256412675138563, 43.22792440652847, 76.2720000743866, 70.65304398536682, 70.59607744216919, 65.93529313802719, 66.4956946671009, 66.39139026403427, 62.11986847221851, 61.241169422864914, 58.51749077439308, 58.32330979406834, 56.72528274357319, 61.8267560005188, 65.4796975851059, 65.97785845398903, 65.65622091293335, 57.64228753745556, 60.13422042131424, 63.751162737607956, 65.23052975535393, 62.048994675278664, 55.9031018614769, 51.39858417212963, 48.480287566781044, 48.46492879092693, 49.5470005273819, 48.45140151679516, 50.40831930935383, 48.25851246714592, 55.83825834095478, 59.69285890460014, 60.811674669384956, 62.911479994654655, 61.627122312784195, 59.49414476752281, 58.07643324136734, 59.445252791047096, 47.999993339180946, 51.713640466332436, 59.24385979771614, 59.52583126723766, 65.08863776922226, 61.98269583284855, 62.07035332918167, 58.66734713315964, 55.46941593289375, 50.74939280748367, 47.551894783973694, 46.03976592421532, 46.50949291884899, 45.90462617576122, 46.07970178127289, 43.946253061294556, 55.27726024389267, 58.9407766610384, 61.07455216348171, 60.11825367808342, 59.886454716324806, 55.305211544036865, 45.20146630704403, 45.469994097948074, 57.923225462436676, 58.26311722397804, 60.027814731001854, 58.73774595558643, 53.62402595579624, 43.98155316710472, 48.34170140326023, 51.86947010457516, 52.20091491937637, 52.75340147316456, 52.367095202207565, 54.746580719947815, 53.976324051618576, 51.01662866771221, 50.96772909164429, 50.37709638476372, 55.96452176570892, 57.66434535384178, 56.26157082617283, 59.361326694488525, 56.962279826402664, 47.28335179388523, 15.054109152406454, 1.4517155452631414, 2.8902123123407364, 4.018269181251526, 4.330601021647453, 5.524190599098802, 15.061370562762022, 6.903228750452399, 1.0093238088302314, 0.348050250322558, 0.1956220529973507, 7.202297877520323, 40.50552248954773, 55.05728244781494, 30.3629357367754, 41.07964128255844, 39.66699108481407, 0.9007182740606368, 0.20523632381809875, 0.1301576368859969, 0.12038045722874813, 0.2650388656184077, 0.1627734539215453, 0.08565876647480763, 0.16301662602927536, 0.17860316700534895, 0.09968064492568374, 0.08053979545366019, 0.1620700760395266, 0.06275833788095042, 0.26073592307511717, 0.21869104559300467, 0.13490214245393872, 0.14117133105173707, 0.1703498762799427, 0.21671555237844586, 0.12065861417795531, 0.16593423119047657, 0.1183696229418274, 0.0817837833892554, 0.10674459204892628, 0.11447144774137996, 0.2466450768406503], [0.07755903352517635, 0.06657269492279738, 0.03216641322069336, 0.03710433731612284, 0.03330891617224552, 0.028140325157437474, 0.02793533098156331, 0.07785147681715898, 0.04789962484210264, 0.06294758553849533, 0.01749075461702887, 0.0624864966084715, 0.07027172221569344, 0.010021143079939066, 0.036949458517483436, 0.021650327216775622, 0.027461710888019297, 0.020282801378925797, 0.022365605436789338, 0.0639788516855333, 0.04346982699644286, 0.06839887544629164, 0.07263404506375082, 0.008314912174682831, 0.04861496614466887, 0.08198642681236379, 0.02706350598600693, 0.03838247517705895, 0.06408803645172156, 0.03808841029240284, 0.012571641182148596, 0.025475562288193032, 0.03457647100731265, 0.13942887220764533, 20.74108064174652, 53.58230419456959, 36.25857777893543, 39.550268948078156, 48.25308255851269, 39.980322271585464, 5.546802710741758, 0.17508663382614031, 0.05227522364293691, 0.489916973747313, 1.2119965022429824, 16.870439238846302, 10.166287031024694, 1.3802311685867608, 0.5087478132918477, 0.11137730049085803, 2.484324029646814, 35.06254255771637, 73.5146552324295, 65.60502246022224, 65.56429624557495, 62.41486944258213, 63.23472484946251, 63.434050753712654, 60.50819255411625, 56.38484001159668, 55.14380760490894, 53.405309692025185, 59.170759320259094, 59.25679050385952, 63.27039733529091, 61.34619578719139, 62.274136394262314, 64.65300634503365, 61.79948106408119, 58.67156870663166, 56.75435498356819, 50.66813036799431, 47.682573571801186, 44.94524605572224, 44.27095323801041, 46.23621538281441, 43.78289982676506, 45.52093796432018, 45.526060089468956, 49.044800475239754, 56.75394080579281, 58.387511149048805, 60.44822797179222, 57.72085212171078, 63.349577486515045, 54.22512710094452, 52.58220165967941, 58.05110760033131, 50.99240496754646, 52.774801924824715, 57.07898676395416, 59.88838881254196, 58.059562146663666, 55.77351361513138, 55.781854167580605, 56.01446248590946, 47.91297800838947, 39.77102190256119, 41.332304924726486, 41.02006807923317, 43.818165734410286, 39.62475635111332, 44.819351211190224, 56.24189168214798, 59.259385764598846, 56.890273690223694, 56.58043831586838, 56.64827987551689, 49.21911612153053, 40.84486708045006, 50.30175782740116, 54.93416905403137, 56.547782868146896, 55.31736709177494, 54.569365829229355, 52.0793442428112, 45.37334628403187, 41.54653362929821, 45.27385622262955, 49.26566742360592, 53.442182913422585, 48.67433935403824, 50.29900297522545, 49.27680462598801, 49.32251997292042, 48.87859359383583, 51.900845021009445, 50.108409002423286, 52.54285857081413, 55.15847481787205, 54.956234470009804, 41.625694781541824, 12.584368027746677, 0.09121638388023712, 0.2926979376934469, 2.332936115562916, 1.8094458058476448, 1.1778337229043245, 1.598362976219505, 3.786824312992394, 0.15122490876819938, 0.20195885124849156, 0.038031873482395895, 8.230990078300238, 34.3016941845417, 39.700110107660294, 25.621677450835705, 25.385096445679665, 34.417093992233276, 3.817401509732008, 0.08560755086364225, 0.005365818151403801, 0.0756728726264555, 0.021673534174624365, 0.019597838036133908, 0.0345040002866881, 0.030316910706460476, 0.026081841278937645, 0.02533099934225902, 0.1199352799449116, 0.03439726460783277, 0.05569782690145075, 0.035763369232881814, 0.006827593497291673, 0.031254684799932875, 0.036549207143252715, 0.12301430222578347, 0.07959921233123168, 0.04498759692069143, 0.0044429083482100395, 0.04441086282895412, 0.025532843101245817, 0.014641208108514547, 0.02921210885688197, 0.04198045906377956, 0.027876647509401664, 0.06044869638571981, 0.05787486516055651, 0.008892767837096471, 0.03997717241873033, 0.014808984506089473, 0.10299354762537405, 0.0476265701581724, 0.0573608091508504, 0.04177973409241531, 0.009615861799829872, 0.09574950352543965, 0.03565660386811942, 0.055053820833563805, 0.054771585782873444, 0.028805630863644183, 0.06889739088364877, 0.03164955189276952, 0.034136982285417616, 0.03535712130542379, 0.1008866423217114, 0.0793731764133554, 0.060796492762165144, 0.020863233221461996, 0.03157273960823659, 0.1256963051855564, 0.035700539010576904, 0.023110597394406796, 0.04641555955458898, 0.05022172328608576, 0.03598993207560852, 0.011900732260983204, 0.025445227001910098, 0.02478839105606312, 0.6135432806331664, 31.02939337491989, 56.743168383836746, 36.80824488401413, 45.408912375569344, 62.564767599105835, 39.429994001984596, 3.981241355650127, 0.18630394362844527, 0.054237057629507035, 0.279619098873809, 0.05037330694904085, 7.095041507855058, 7.866796720772982, 2.29388608597219, 1.5452085784636438, 0.2703000692417845, 4.641680354252458, 42.46298745274544, 70.57155355811119, 66.78992047905922, 68.1126295030117, 61.884763687849045, 65.25363251566887, 65.09464144706726, 60.753104612231255, 57.69869551062584, 56.13048546016216, 55.00956080853939, 59.201606065034866, 60.27175024151802, 65.11831417679787, 63.90250101685524, 60.50331361591816, 65.89771315455437, 64.27123323082924, 61.82910427451134, 58.511095717549324, 52.495524510741234, 48.1879236549139, 46.26303814351559, 46.67236737906933, 48.54455731809139, 45.17754279077053, 47.1873689442873, 46.364249512553215, 50.5346055328846, 58.53608317673206, 60.79101897776127, 61.99030302464962, 60.3243014216423, 63.10632973909378, 56.25644490122795, 56.74564205110073, 60.04445023834705, 53.39085526764393, 55.975594371557236, 60.166005715727806, 60.16315966844559, 59.239353239536285, 57.59962722659111, 56.95654593408108, 56.171443462371826, 50.30622638761997, 42.223205119371414, 43.39575760066509, 43.27819190919399, 44.41598005592823, 41.93945154547691, 45.801416113972664, 56.805595234036446, 61.461451202631, 59.05274145305157, 58.835890889167786, 58.28616678714752, 50.89712128043175, 42.53783963620663, 50.53653582930565, 56.832417994737625, 56.54039226472378, 56.25390663743019, 56.257493644952774, 55.833383202552795, 46.59823715686798, 44.11463722586632, 47.87886343896389, 51.31651997566223, 54.671530947089195, 51.53004191815853, 51.00411593914032, 49.925790801644325, 50.45392446219921, 49.17454071342945, 53.69085676968098, 53.19631710648537, 55.51084890961647, 55.261099711060524, 55.044541731476784, 44.68138061463833, 15.582697838544846, 0.3514806943712756, 0.9517665160819888, 2.145866216160357, 2.1057731425389647, 3.8200927153229713, 3.345713345333934, 1.0716625512577593, 0.12118385435314849, 0.08984263884485699, 0.028925485858053435, 6.76035214215517, 37.03343220055103, 48.130653128027916, 32.659118324518204, 23.14536552876234, 42.26706236600876, 6.6361230332404375, 0.05385632473917212, 0.06196548667503521, 0.08216271657147445, 0.018575152971607167, 0.03470384581305552, 0.030102981072559487, 0.06232912419363856, 0.0448741559375776, 0.029071562785247806, 0.1323932528612204, 0.01777559275069507, 0.03598819916078355, 0.11156886364915408, 0.05825919746712316, 0.05388864527049009, 0.07328622959903441, 0.15039456426165998, 0.08400291626458056, 0.01844704158429522, 0.03814841293205973, 0.023301830296986736, 0.022772925767640118, 0.026958545895467978, 0.06800172253861092, 0.02116010527970502, 0.05245583270152565, 0.2062717979424633, 0.11575735959922895, 0.21128306107129902, 0.17840614164015278, 0.1613120612455532, 0.17006015666993335, 0.1327129700803198, 0.16593909967923537, 0.13453461608150974, 0.13257604383397847, 0.13598714751424268, 0.22301739547401667, 0.21556449617492035, 0.14099492254899815, 0.15173176594544202, 0.11031331305275671, 0.10955147619824857, 0.1621347467880696, 0.10753727998235263, 0.12960181280504912, 0.15703626646427438, 0.168010730703827, 0.18897015368565917, 0.15159363741986454, 0.18761975661618635, 0.15826762304641306, 0.05528123343538027, 0.1735231067868881, 0.22237472527194768, 0.1455557020381093, 0.1302491733804345, 0.12981316162040457, 0.09767205934622325, 0.5908747657667845, 31.978274658322334, 70.1767547428608, 48.101907670497894, 50.047790855169296, 63.649776577949524, 52.98559181392193, 8.103804253041744, 0.2794584387447685, 0.202175825543236, 1.0842280020006, 3.5026715230196714, 30.07209364324808, 22.894278801977634, 3.2027246430516243, 1.047122636809945, 0.256535010994412, 2.997904233634472, 38.894078359007835, 76.59476235508919, 69.87373620271683, 71.13745719194412, 65.85584700107574, 68.52935314178467, 69.20873388648033, 65.94681411981583, 61.18900582194328, 59.10050109028816, 59.66490760445595, 63.95291671156883, 63.846758008003235, 67.9405215382576, 62.61740617454052, 63.172970563173294, 67.52035528421402, 68.19388434290886, 64.31053072214127, 62.30502873659134, 54.30783346295357, 50.38375362753868, 48.30024942755699, 47.57741421461105, 51.24819204211235, 47.214153707027435, 50.18823131918907, 49.78052839636803, 53.41290548443794, 61.78448706865311, 64.81531083583832, 64.55931097269058, 63.348179161548615, 69.17117670178413, 58.483459800481796, 58.03906984627247, 63.61123524606228, 54.268779158592224, 55.32011814415455, 57.640775218605995, 63.2534996420145, 62.30538211762905, 59.523148611187935, 59.12029802799225, 60.27117267251015, 52.30830855667591, 43.31034578382969, 44.55998092889786, 43.407103791832924, 46.98927417397499, 43.509029522538185, 48.97038906812668, 60.64056605100632, 63.71819190680981, 60.27938403189182, 60.14579840004444, 60.30393831431866, 52.31052003800869, 44.5223743468523, 53.45234356820583, 57.15453051030636, 59.59778420627117, 56.258113011717796, 59.91958513855934, 55.74191451072693, 49.523863568902016, 46.32291533052921, 48.005248457193375, 54.548295959830284, 58.278407603502274, 54.01389643549919, 55.30162453651428, 53.72236467897892, 52.36939027905464, 52.20603324472904, 56.17170564830303, 54.98419716954231, 58.27290549874306, 60.264549627900124, 55.11355742812157, 42.970241233706474, 14.522003754973412, 0.3348017268581316, 0.5455420701764524, 5.592492884024978, 7.61730020865798, 4.308409737423062, 11.498277056962252, 11.597048956900835, 0.4770961351459846, 0.34740903472993523, 0.1603017607703805, 12.274024430662394, 48.800074607133865, 51.065003871917725, 37.53236062824726, 34.09645199775696, 52.371476367115974, 6.15530158393085, 0.2586985792731866, 0.2631126361666247, 0.1676511304685846, 0.07457529558450915, 0.10497949770069681, 0.10620436049066484, 0.18142044864362106, 0.11840535735245794, 0.10113310956512578, 0.24274752504425123, 0.16409345262218267, 0.14735981851117685, 0.20155755715677515, 0.12494087306549773, 0.13259585917694494, 0.22372956038452685, 0.2994210534961894, 0.14619123277952895, 0.15665696962969378, 0.14789965673116967, 0.13700338517082855, 0.12809902313165367, 0.17539667343953624, 0.2620169293368235, 0.178905829670839, 0.29440146347042173], [0.02800156580633484, 0.05415571082266979, 0.04490199018619023, 0.023816340872144792, 0.08433035181951709, 0.029544188400905114, 0.04989765337086283, 0.030613112976425327, 0.09159213324892335, 0.0481701970420545, 0.038888159760972485, 0.0324791728053242, 0.00986736080449191, 0.04696923140727449, 0.08805540623143315, 0.023594405320181977, 0.052007939157192595, 0.09003262122860178, 0.056629073806107044, 0.03861132383462973, 0.031401392552652396, 0.00945281659369357, 0.016257761599263176, 0.03572272551537026, 0.0798948691226542, 0.03679807523440104, 0.08018580585485324, 0.036516697364277206, 0.03901614312781021, 0.02135482442099601, 0.0451858394080773, 0.05554176066652872, 0.05045413796324283, 0.02802365768729942, 0.20122126035857946, 23.253141045570374, 50.38827918469906, 33.9564561098814, 34.50489208102226, 49.085180908441544, 42.65376761555672, 7.78019841760397, 0.5778820160776377, 0.05515118689800147, 0.06957352452445775, 8.3164949901402, 3.507084036245942, 3.0181830329820514, 1.1505051143467426, 0.20687397656729445, 0.1268157162121497, 1.0602354956790805, 31.13809984177351, 69.84736561775208, 67.41925790905952, 65.23540109395981, 67.81028732657433, 61.36464759707451, 61.579119488596916, 62.881628796458244, 57.25864492356777, 53.90544645488262, 58.432899713516235, 60.63385561108589, 67.87351593375206, 58.210938423871994, 61.69025972485542, 58.264078572392464, 59.94094379246235, 56.190248653292656, 52.95042850077152, 48.29685240983963, 47.00858473777771, 45.46081759035587, 48.411883637309074, 49.08899210393429, 50.25331422686577, 46.17365553975105, 45.77689602971077, 43.06867875158787, 50.62486968934536, 52.86784753203392, 57.95561872422695, 59.35559280216694, 59.83040012419224, 64.0560507774353, 59.13343392312527, 47.18340575695038, 59.68735679984093, 39.47514697909355, 47.30886362493038, 64.43613678216934, 60.705717355012894, 60.186661407351494, 57.85223387181759, 53.6674652248621, 48.86600486934185, 43.26075464487076, 42.07534745335579, 43.85381922125816, 41.65940277278423, 42.65141174197197, 51.94771930575371, 57.48472519218922, 58.05876038968563, 59.64764893054962, 56.542045176029205, 56.50627389550209, 48.15261974930763, 44.9787412583828, 54.448251128196716, 56.21727280318737, 57.45686508715153, 58.179229125380516, 54.682215973734856, 55.42841613292694, 51.71401284635067, 45.21801441907883, 47.213750928640366, 49.5162183791399, 53.794667199254036, 52.881409004330635, 52.61283561587334, 50.323542058467865, 51.67419858276844, 52.06531919538975, 52.56928615272045, 55.55744580924511, 55.09165160357952, 56.59206949174404, 50.21012954413891, 12.383211571723223, 0.4318653215887025, 0.31107476097531617, 1.8009638297371566, 1.6134619410149753, 0.623329714871943, 3.9304190827533603, 2.148779472336173, 0.538021323736757, 0.11789691940066405, 0.07168762866058387, 10.956470780074596, 38.53068865835667, 36.694646179676056, 30.850286185741425, 21.94160532206297, 40.01304991543293, 11.051676571369171, 0.08100826133158989, 0.029207733896328136, 0.07430688303429633, 0.05810693844978232, 0.0340780038095545, 0.0797111949941609, 0.052810608976869844, 0.05131650985276792, 0.05322654564224649, 0.13289055117638782, 0.034385969120194204, 0.001927964685819461, 0.06750384534825571, 0.02007477367442334, 0.02829386623488972, 0.017491884536866564, 0.024993136612465605, 0.09856844757450745, 0.015829050717002247, 0.04802668794582132, 0.0333374035108136, 0.05690354599209968, 0.05672541941748932, 0.052633677260018885, 0.024154984712367877, 0.07266186075867154, 0.07008981439867057, 0.019435146277828608, 0.03405107869184576, 0.013779906767013017, 0.012819790317735169, 0.048893579514697194, 0.13975608511827886, 0.04358290432719514, 0.06165584782138467, 0.08588999000494368, 0.03856127710605506, 0.021049124516139273, 0.042429588283994235, 0.025903757377818692, 0.0254420840064995, 0.014541632299369667, 0.009744873041199753, 0.018840168340830132, 0.057907245063688606, 0.06962356754229404, 0.05041943513788283, 0.01640085509279743, 0.01999185908061918, 0.052632241204264574, 0.08513371183653362, 0.026969054706569295, 0.05483158842253033, 0.037474772907444276, 0.030140585695335176, 0.018056534609058872, 0.03737510247447062, 0.017135724156105425, 0.0520128076459514, 0.018666186660993844, 0.07291980160516687, 1.3700221851468086, 33.21777954697609, 53.423651307821274, 35.75903758406639, 39.597929790616035, 64.29824978113174, 45.10323777794838, 6.776504600420594, 0.45214961282908916, 0.0471710065176012, 0.116215390880825, 0.4371483443537727, 2.3180945869535208, 6.00727055221796, 1.4676460716873407, 0.8990182215347886, 0.10480967204784974, 2.4240317149087787, 43.17912742495537, 70.0567951798439, 66.60542517900467, 68.15639555454254, 68.84995713829994, 64.79378119111061, 64.58717107772827, 62.77978666126728, 57.291095182299614, 54.151916429400444, 61.541292518377304, 63.386826887726784, 69.21447917819023, 60.162901282310486, 59.25898678600788, 61.253579556941986, 62.162084206938744, 58.82592022418976, 54.74593475461006, 50.61304472386837, 46.84211567044258, 48.099574595689774, 48.80007840692997, 50.20765967667103, 50.92634931206703, 47.24261797964573, 47.793862000107765, 45.55545151233673, 52.443687692284584, 56.93865269422531, 59.44426864385605, 61.095014065504074, 62.60596498847008, 63.63015063107014, 59.83698137104511, 53.717025965452194, 63.83886203169823, 44.71099242568016, 50.67684330046177, 65.61873212456703, 61.54400937259197, 61.50192283093929, 58.91187161207199, 56.966645792126656, 50.94089113175869, 46.44730165600777, 44.435963183641434, 46.409679874777794, 44.00432914495468, 43.61516162753105, 52.163768112659454, 59.9144896119833, 59.55598644912243, 60.66349782049656, 58.1407979875803, 57.542341500520706, 51.18882402777672, 46.242576241493225, 55.129831954836845, 58.70931588113308, 59.21160712838173, 59.054325968027115, 57.706933468580246, 58.13459672033787, 51.445648446679115, 47.26256310939789, 49.262319803237915, 51.70216888189316, 54.38919469714165, 53.90995681285858, 55.49490116536617, 53.342282474040985, 52.107318341732025, 54.899879693984985, 52.46870554983616, 57.87004731595516, 56.086848601698875, 57.17452123761177, 50.48513978719711, 16.07913549989462, 0.8330101822502911, 0.9500298311468214, 4.370544953271747, 4.016630994156003, 3.508157003670931, 5.0600991770625114, 1.2829288397915661, 0.1469222185551189, 0.0967294278962072, 0.10972352829412557, 7.404109323397279, 43.49212042987347, 43.83388929069042, 35.59286870062351, 22.984782345592976, 42.65045799314976, 17.797462195158005, 0.0875379957142286, 0.05868370964890346, 0.0796074204845354, 0.04021218832349405, 0.034100672710337676, 0.07597425137646496, 0.021917821359238587, 0.034340341881033964, 0.06133487637271173, 0.056740525833447464, 0.027527064412424807, 0.08636011087219231, 0.07197077284217812, 0.05627908438327722, 0.026370904088253155, 0.029209489075583406, 0.05442132918688003, 0.06663640087936074, 0.056911056526587345, 0.0346501811145572, 0.04354761891590897, 0.026735422907222528, 0.027310190307616722, 0.010137439476238796, 0.022138061103760265, 0.021208895923336968, 0.05911922416999005, 0.17684846272459254, 0.1529056506115012, 0.10360927044530399, 0.15227583440719172, 0.24725957511691377, 0.20716264232760295, 0.23672890034504235, 0.12100001695216633, 0.15410003339638934, 0.119061245204648, 0.09090358347748406, 0.1505426672520116, 0.09578390949172899, 0.15507524512941018, 0.1081013419025112, 0.1103350505582057, 0.18094902159646153, 0.24150410114089027, 0.18716655671596527, 0.14548910170560703, 0.11672785127302632, 0.11000205631717108, 0.16714790981495753, 0.2154322454589419, 0.19321353145642206, 0.1315413712291047, 0.2183974371291697, 0.14414400357054546, 0.19218979810830206, 0.14014879998285323, 0.14040895242942497, 0.13099810428684577, 0.11676972324494272, 0.12243432123796083, 1.1135974572971463, 35.60885824263096, 66.00551337003708, 47.27669075131416, 47.7716825902462, 62.797584906220436, 56.08296521008015, 12.297124341130257, 1.440146709792316, 0.2479979081545025, 0.18377920176135376, 17.925209440290928, 16.305059976875782, 8.500501066446304, 4.486255394294858, 0.5257194838486612, 0.2770863566547632, 1.8206637538969517, 36.648691445589066, 73.00092279911041, 71.23761221766472, 72.45462611317635, 74.37122046947479, 66.46196007728577, 66.71383336186409, 68.83076816797256, 62.229701578617096, 57.52284474670887, 63.73632453382015, 66.87910929322243, 71.64849177002907, 58.61793838441372, 61.68067663908005, 62.76336394250393, 66.91993430256844, 59.68173690140247, 57.14560478925705, 53.00423361361027, 50.057978108525276, 51.32997505366802, 53.20453226566315, 54.338839799165726, 55.9346629679203, 49.6968986839056, 50.467835515737534, 46.17586322128773, 55.179799273610115, 57.53948025405407, 61.01980850100517, 63.24755296111107, 64.38051536679268, 66.03243112564087, 62.864214330911636, 53.81155349314213, 64.02215659618378, 48.678503930568695, 53.69462236762047, 67.70983591675758, 62.93257646262646, 65.07170587778091, 62.0650602132082, 58.106869608163834, 52.52195589244366, 48.488658517599106, 46.8300399184227, 48.388533890247345, 46.83316335082054, 45.10106049478054, 55.89626602828503, 61.2715107947588, 61.94829247891903, 60.716960951685905, 59.983353316783905, 59.05823975801468, 53.7954917550087, 50.70195995271206, 57.50943146646023, 62.157197669148445, 61.45824037492275, 61.52322828769684, 59.09857839345932, 60.1259558647871, 56.11532427370548, 49.645973816514015, 52.96468533575535, 53.609142154455185, 58.123755902051926, 56.61383472383022, 57.30967998504639, 54.940552711486816, 56.73482023179531, 55.773509815335274, 56.00710228085518, 59.91092160344124, 60.02042792737484, 57.87726312875748, 53.33321996033192, 14.2436857894063, 0.7024520973209292, 0.924870134331286, 6.399264167994261, 4.432827886193991, 1.8985116016119719, 13.195687774568796, 8.892816714942455, 2.038043914362788, 0.22592504101339728, 0.17634721618378535, 15.35753047093749, 50.567017793655396, 48.079553470015526, 42.01257862150669, 32.334463745355606, 52.999138087034225, 18.58110174536705, 0.18984737223945558, 0.18336304987315089, 0.1108779686910566, 0.2195381181081757, 0.10447667780681513, 0.17751891893567517, 0.10612153680995107, 0.1281250428291969, 0.14886354329064488, 0.21599142404738814, 0.17373631097143516, 0.17019153165165335, 0.19262285612057894, 0.11401470779674128, 0.19724918209249154, 0.09676463538198732, 0.14097185659920797, 0.13902542588766664, 0.12437343437341042, 0.14263962570112199, 0.09675000765128061, 0.1552788310800679, 0.18881911179050803, 0.07801126863341779, 0.08845608434057795, 0.17885270674014464, 0.15183961484581232], [0.03310255830001552, 0.0658817109069787, 0.046230909501900896, 0.07808785085217096, 0.048494051734451205, 0.07757768369629048, 0.05805969332868699, 0.15205103787593544, 0.011591460770432604, 0.04174749519734178, 0.0442332817328861, 0.0544224201439647, 0.03723588670254685, 0.030925275132176466, 0.05932856918661855, 0.05868819593160879, 0.02881743472244125, 0.013761097961833002, 0.08044156478717923, 0.05552980466745794, 0.06859360757516697, 0.04820333393581677, 0.06018875545123592, 0.019431582113611512, 0.034605719047249295, 0.07230651302961633, 0.0011734653526218608, 0.021125363491591997, 0.029358135689108167, 0.04517750508966856, 0.043132008795510046, 0.05262000318907667, 0.043736239458667114, 0.027935666803386994, 0.04976193682523444, 1.1066997586749494, 26.53579819947481, 48.15742269158363, 31.39106746762991, 31.428126879036427, 47.99212396144867, 42.87296265363693, 10.787545144557953, 0.9079946461133659, 0.19459085364360362, 0.21537553053349257, 2.375191985629499, 3.6674541933462024, 1.2249013222754002, 1.1581966141238809, 0.02519088186090812, 0.0585556669102516, 0.8565554406959563, 21.968401484191418, 66.33463650941849, 64.07615929841995, 65.46858698129654, 66.1131463944912, 64.4038537144661, 61.32704101502895, 57.88593806326389, 55.567294880747795, 64.43698793649673, 65.947475284338, 63.0499217659235, 60.7730383425951, 65.49056500196457, 61.37718312442303, 59.60178159177303, 50.7407558709383, 49.42315757274628, 46.47765062749386, 49.1283617913723, 51.8436124920845, 60.28730660676956, 59.56377223134041, 58.189363181591034, 54.47090171277523, 51.51357740163803, 45.73136307299137, 46.14611841738224, 49.15265388786793, 55.534373447299004, 54.90711070597172, 62.60686174035072, 56.58230781555176, 65.39838954806328, 57.66417436301708, 52.78729945421219, 39.75082978606224, 42.30626866221428, 65.25569200515747, 59.54647555947304, 59.599889293313026, 56.41906477510929, 56.76229275763035, 47.56370835006237, 43.91498453915119, 43.122966438531876, 42.745452895760536, 44.10966709256172, 48.8994886726141, 57.62140765786171, 59.43242087960243, 59.90564748644829, 59.091807156801224, 58.307282254099846, 57.40254320204258, 47.99927517771721, 48.43422643840313, 54.39997471868992, 58.09692934155464, 60.19205331802368, 57.968963608145714, 56.762425750494, 57.200268656015396, 57.42628052830696, 49.880504831671715, 46.66463479399681, 49.04900684952736, 53.95961634814739, 54.59709674119949, 53.22149455547333, 50.72945147752762, 53.82873237133026, 56.38595335185528, 55.62857039272785, 54.84223298728466, 57.41454295814037, 47.70129896700382, 11.0166709497571, 0.36263413494452834, 0.2515627699904144, 1.2302984576672316, 3.0733235366642475, 1.3502298784442246, 1.4133761962875724, 4.652211964130402, 0.6850651209242642, 0.1732874452136457, 0.16181793878786266, 7.6900568045675755, 41.36461839079857, 31.049906574189663, 47.68134243786335, 28.225252144038677, 35.241873934865, 17.754275612533092, 0.12307853510719724, 0.03625210687459912, 0.07343132689129561, 0.028953314540558495, 0.02862217752408469, 0.027536022134881932, 0.03470213516266085, 0.046006740085431375, 0.06311490273219533, 0.010208382300334051, 0.029136626872059423, 0.023990547051653266, 0.041371638217242435, 0.0251690423101536, 0.06150649060145952, 0.05866258070454933, 0.04336526952101849, 0.08744611041038297, 0.06620848595048301, 0.015335829575633397, 0.053826742732780986, 0.05656584653479513, 0.014363430582307046, 0.04854662918660324, 0.012412822507030796, 0.006079443701310083, 0.010880633581109578, 0.045904928556410596, 0.060539505575434305, 0.06384611857356504, 0.008027077619772172, 0.0451077580510173, 0.025887535884976387, 0.08930842610425316, 0.03260087760281749, 0.03909629878762644, 0.016251239976554643, 0.04818891400645953, 0.04691063142672647, 0.02258289143355796, 0.010645274433045415, 0.026842679944820702, 0.022664204843749758, 0.035317089859745465, 0.02729252533754334, 0.07943599921418354, 0.09947800892405212, 0.02938965099019697, 0.039534507304779254, 0.019014387507922947, 0.03174186764226761, 0.034313776704948395, 0.030074139358475804, 0.04690569985541515, 0.034613522730069235, 0.07065474463161081, 0.055902982494444586, 0.0073340058497706195, 0.010623841208143858, 0.03357603738550097, 0.03736288672371302, 0.01873651814094046, 0.12893435487058014, 3.2855561608448625, 37.79946729540825, 49.73840765655041, 31.205211840569973, 34.69493888318539, 64.10592690110207, 48.47953520715237, 9.192502833902836, 0.6767492077779025, 0.018840457778424025, 0.07832331946701743, 0.5332624353468418, 3.0416147131472826, 3.1650928873568773, 3.410313203930855, 0.5642604595050216, 0.16300721559673548, 1.5425463463179767, 31.401136927306652, 66.56140074133873, 64.79283884167671, 66.98348209261894, 68.98345917463303, 64.0155753493309, 63.53488974273205, 58.71580973267555, 57.48953193426132, 65.74423938989639, 67.55954638123512, 65.86114391684532, 58.951484486460686, 67.3996053636074, 64.25218105316162, 60.39420627057552, 53.997735902667046, 50.92481419444084, 48.22887785732746, 49.737222120165825, 54.07068058848381, 62.38900423049927, 61.954866126179695, 60.15437453985214, 54.939652159810066, 52.44205757975578, 46.753512024879456, 48.205539509654045, 52.09767825901508, 56.16906099021435, 58.226168006658554, 64.23153296113014, 59.961683079600334, 65.00801369547844, 57.306290566921234, 59.64433930814266, 40.2882045507431, 44.55213434994221, 65.86839392781258, 59.74069833755493, 60.842407420277596, 57.841708436608315, 57.26545795798302, 50.187615752220154, 45.26116110384464, 45.455399081110954, 44.236033111810684, 45.277344435453415, 49.83716055750847, 58.92241224646568, 60.47336362302303, 62.93480694293976, 61.69049151241779, 58.62463362514973, 57.13336944580078, 50.04951976239681, 48.81799824535847, 56.848350539803505, 60.77789448201656, 58.63483987748623, 59.49252225458622, 56.248309537768364, 58.73811453580856, 58.194105327129364, 50.411419942975044, 47.764234989881516, 52.487199157476425, 53.882184103131294, 56.12474016845226, 52.49287985265255, 53.61214779317379, 56.13218776881695, 56.705975979566574, 57.38279186189175, 55.21202154457569, 57.88390137255192, 52.57068067789078, 14.86579030752182, 1.1561836721375585, 1.0022039408795536, 3.278948552906513, 7.79343263246119, 6.033774130046368, 5.860849684104323, 0.3187163587426767, 0.3272960311733186, 0.14801700512180105, 0.20825925457756966, 6.258982345461845, 48.895027711987495, 44.59539122879505, 48.73378336429596, 29.87325981259346, 35.93645006418228, 26.453222930431366, 0.37022773060016334, 0.02594917496026028, 0.06289368335274048, 0.03440952117671259, 0.051253145284135826, 0.02640898554091109, 0.05254430041532032, 0.05836466036271304, 0.0271623099615681, 0.047149139136308804, 0.0406706166540971, 0.03716671482834499, 0.020797553152078763, 0.04093640200153459, 0.06074295422877185, 0.04998238437110558, 0.04077878467796836, 0.05190648756979499, 0.06143946353404317, 0.013538187413359992, 0.06277338121435605, 0.034739583934424445, 0.018041055263893213, 0.025553300401952583, 0.010427179495309247, 0.05564115650486201, 0.0239478030562168, 0.0065868213096109685, 0.19463170145172626, 0.1452163327485323, 0.19092403555987403, 0.15202987182419747, 0.11178886590641923, 0.15074175578774884, 0.11933600311749615, 0.22181066335178912, 0.15832142875296995, 0.10713185954955406, 0.1441815117141232, 0.14716046280227602, 0.19638379337266088, 0.06446466155466624, 0.19985648046713322, 0.12033619554131292, 0.10535210036323406, 0.151714859821368, 0.30090003507211804, 0.14597246248740703, 0.17078202887205407, 0.06872483412735164, 0.16537726420210674, 0.10047814939753152, 0.1082223565026652, 0.1452779903775081, 0.159764549753163, 0.2259465484530665, 0.15371095505543053, 0.11138631016365252, 0.1460785005474463, 0.19669033004902303, 0.13999358721775934, 0.15579875005641952, 0.2640549262287095, 2.2241833386942744, 38.15862022340298, 62.928252294659615, 42.348385602235794, 43.56161490082741, 61.4401875436306, 55.829249024391174, 16.63133706897497, 1.0786713939160109, 0.43997741129714996, 0.49276242731139064, 4.160133618861437, 13.363232184201479, 3.9629631489515305, 3.2817243039608, 0.4684612469282001, 0.20445735077373683, 1.622977105434984, 26.40303522348404, 68.72552141547203, 66.51715591549873, 69.26310136914253, 73.4158681333065, 67.2407814860344, 65.69534361362457, 61.753210946917534, 61.480032205581665, 69.80298399925232, 71.26854255795479, 65.69917380809784, 61.23924292623997, 69.30454194545746, 68.57253402471542, 63.408470526337624, 55.88643975555897, 53.48089523613453, 51.778681576251984, 52.495858892798424, 57.5342783331871, 65.58024019002914, 65.90221971273422, 64.55130100250244, 61.37293495237827, 55.84749564528465, 50.22605448961258, 49.87403377890587, 53.78390237689018, 58.592320159077644, 61.70766659080982, 66.2614144384861, 61.04145973920822, 66.62044957280159, 61.919296234846115, 58.25419530272484, 46.254427805542946, 47.37853668630123, 65.7299293577671, 63.10688450932503, 63.00830639898777, 61.41275301575661, 60.72804495692253, 52.979439944028854, 46.21831454336643, 48.23130212724209, 45.88722310960293, 48.25071528553963, 53.80119524896145, 62.77248725295067, 65.10646641254425, 65.22497445344925, 62.86875128746033, 61.84346370398998, 59.58113729953766, 54.03729557991028, 52.12708868086338, 60.15309780836105, 62.308722138404846, 61.831186562776566, 58.51256623864174, 57.81424731016159, 60.81216864287853, 62.253856882452965, 53.76663610339165, 51.591298431158066, 53.88473376631737, 56.76065504550934, 59.59478996694088, 57.4437215924263, 55.65232291817665, 56.545920968055725, 61.20604790747166, 58.87752145528793, 57.128296718001366, 59.797889068722725, 50.64922638237476, 13.063502367585897, 0.6326387403532863, 0.88265719008632, 2.8382254019379616, 8.298084028065205, 4.631155868992209, 6.387670990079641, 11.964946165680885, 1.5704811410978436, 0.3371911752037704, 0.38427041145041585, 12.547141425311565, 54.43866044282913, 43.43481570482254, 58.93570013344288, 37.126234620809555, 47.1636164188385, 27.406346686184406, 0.40730480512138456, 0.15726906334748492, 0.1357605995144695, 0.21903544664382935, 0.1544060357264243, 0.22870476997923106, 0.16672586527420208, 0.20553719048621133, 0.15585519780870527, 0.13086465129163116, 0.10648625786416233, 0.1362116917152889, 0.25411436276044697, 0.10508209961699322, 0.2567873412044719, 0.10036923180450685, 0.13423422438791022, 0.12963739136466756, 0.19319600192829967, 0.15583373489789665, 0.1711989674367942, 0.2008259331341833, 0.11410255581722595, 0.1008177042240277, 0.07641893142135814, 0.16704908543033525, 0.08720140205696225, 0.11360953969415277], [0.024650359009683598, 0.01587218062923057, 0.01199177058879286, 0.027214085894229356, 0.07388086800347082, 0.016742745829105843, 0.029004240714129992, 0.04011170894955285, 0.08546394528821111, 0.011320127869112184, 0.031640304732718505, 0.04876338083704468, 0.023553063983854372, 0.045523668741225265, 0.00410773126532149, 0.08286304422654212, 0.03288247811724432, 0.06436242329073139, 0.044757720388588496, 0.028151609512860887, 0.028654806046688464, 0.04174434106971603, 0.06242996721994132, 0.033139955121441744, 0.02446797621814767, 0.06619524603593163, 0.04815880507521797, 0.06148302389192395, 0.022964039926591795, 0.041282862512161955, 0.03448522766120732, 0.028485973016358912, 0.047404304350493476, 0.02226415199402254, 0.010276648754370399, 0.058425271563464776, 1.0766305471770465, 26.257096454501152, 49.764500856399536, 32.302503660321236, 34.72860887646675, 47.793425023555756, 48.48881430923939, 15.032828394323587, 0.8391402626875788, 0.1265313697513193, 0.35669775505084544, 2.4155465327203274, 2.4478571489453316, 3.311992292292416, 0.7021679438184947, 0.07186610033386387, 0.05537544908293057, 0.21595603844616562, 19.13841214030981, 56.495832055807114, 63.90301778912544, 63.30373294651508, 64.07115876674652, 64.36099961400032, 57.63772398233414, 59.58258882164955, 65.03332033753395, 67.22427517175674, 60.47758139669895, 63.67091864347458, 63.47726583480835, 60.085279047489166, 56.489383801817894, 50.249434635043144, 50.02597242593765, 53.81493531167507, 57.89909675717354, 61.24588496983051, 61.93467780947685, 61.9227996468544, 63.27866189181805, 58.49617011845112, 57.113169729709625, 49.5503481477499, 46.56846195459366, 46.19098260998726, 52.352739572525024, 54.03462812304497, 59.11659322679043, 59.77535627782345, 60.90328015387058, 57.305880188941956, 59.29535083472729, 42.054041996598244, 46.16831682622433, 67.16426119208336, 64.14023146033287, 62.92389012873173, 56.270538344979286, 55.00447288155556, 46.8669169396162, 46.29162020981312, 42.14701920747757, 45.004241690039635, 48.422773852944374, 53.74111287295818, 58.08594413101673, 60.55045768618584, 60.72756238281727, 58.629246577620506, 59.286816492676735, 56.10327132046223, 50.24832509458065, 49.78304386138916, 54.45105917751789, 59.71829853951931, 60.98677307367325, 60.4344879090786, 58.63818749785423, 59.06933136284351, 55.3349145501852, 54.55648072063923, 48.83395358920097, 49.81992468237877, 50.03519833087921, 54.87138882279396, 52.502428740262985, 55.53880400955677, 53.326315730810165, 60.995877385139465, 51.349870786070824, 58.64729940891266, 41.55654989182949, 7.4167355708777905, 0.12451752234483138, 0.4615258768899366, 1.302707134746015, 2.310279356315732, 7.043674439191818, 10.639930665493011, 12.942296471446753, 1.2781197228468955, 0.10823980439454317, 0.13393059693044052, 10.195624306797981, 47.959457114338875, 37.96369828283787, 31.37644585222006, 49.47348967194557, 36.895776987075806, 22.468038573861122, 0.31195842137094587, 0.03937436667911243, 0.04147098952671513, 0.019900255792890675, 0.03445917085628025, 0.01758873295329977, 0.016539247080800124, 0.03202557214535773, 0.09790460389922373, 0.019105890605715103, 0.06786210229620337, 0.037865565609536134, 0.04568229538563173, 0.039545995750813745, 0.058394264633534476, 0.017825069880927913, 0.02028663828241406, 0.009851540071394993, 0.012743260977003956, 0.008048406943998998, 0.0388424545963062, 0.04419671240611933, 0.029707204848818947, 0.018513332070142496, 0.07593492497107945, 0.03049328766792314, 0.007818286430847365, 0.053811261532246135, 0.015980387615854852, 0.07192563542048447, 0.022757633814762812, 0.008992325092549436, 0.04087888926733285, 0.05496432524523698, 0.041715709012351, 0.01806734398996923, 0.09383316690218635, 0.00357972566234821, 0.03724914146005176, 0.03417293191887438, 0.03312829969218001, 0.02758593898761319, 0.031497649106313474, 0.031289190956158563, 0.04018045779957902, 0.019618764745246153, 0.0724984472617507, 0.04653911601053551, 0.05738388994359411, 0.03502683961414732, 0.04704430335550569, 0.04743406818306539, 0.06853402795968577, 0.07891095941886306, 0.03734049983904697, 0.10878584696911275, 0.04478079375985544, 0.03229900532460306, 0.013404758537944872, 0.057276879670098424, 0.011642514964478323, 0.017050679598469287, 0.05083936084702145, 0.11028232096577995, 0.05159093750989996, 2.9302130034193397, 38.925806656479836, 51.38341158628464, 33.04338410496712, 36.43041215837002, 58.8149806112051, 53.00698846578598, 12.749152835458517, 0.8701795502565801, 0.09297982323914766, 0.1519530001678504, 0.7864199916366488, 2.201665509492159, 5.540671264752746, 1.9936782075092196, 0.15184025309281424, 0.06845430645626038, 0.8237471105530858, 28.704545125365257, 59.52761337161064, 64.70206171274185, 64.58680629730225, 67.00286865234375, 66.54740989208221, 59.83521446585655, 62.29816250503063, 67.87058249115944, 66.46245405077934, 62.44336411356926, 61.54084034264088, 66.28089979290962, 63.082744404673576, 59.45078529417515, 51.683591678738594, 50.65056771039963, 53.7440425157547, 59.232099428772926, 62.56955914199352, 64.06806573271751, 64.58235293626785, 63.44170354306698, 59.11386877298355, 58.21646712720394, 52.33557589352131, 48.2466609030962, 49.634585827589035, 55.74093796312809, 56.59178450703621, 61.818202659487724, 62.29012593626976, 65.47725051641464, 58.59973356127739, 60.71731813251972, 44.940287321805954, 47.84681595861912, 67.62865707278252, 64.01841759681702, 66.46428555250168, 59.40810598433018, 58.72892662882805, 49.913031086325645, 47.958685755729675, 46.16926297545433, 45.802369862794876, 50.512642711400986, 54.91266220808029, 59.02580089867115, 61.502979174256325, 59.53856058418751, 59.69211034476757, 61.71377286314964, 59.453809931874275, 52.97411262989044, 51.96021303534508, 57.81203202903271, 60.390159487724304, 61.76288902759552, 60.215824842453, 60.072124153375626, 60.39599597454071, 58.73528748750687, 56.336043030023575, 50.596173629164696, 51.812598556280136, 52.55308382213116, 57.50343158841133, 55.68679466843605, 56.39785051345825, 55.077660754323006, 59.88059543073177, 51.666450798511505, 60.46471528708935, 45.315547585487366, 12.126722484827042, 0.5500005965586752, 2.186129093170166, 2.947452678345144, 4.085227288305759, 6.962365452200174, 4.390847738832235, 2.010809825733304, 0.22671256359899417, 0.11251948802964762, 0.16118215571623296, 8.30429669469595, 51.25678338110447, 48.018198162317276, 31.69142235070467, 53.359389156103134, 40.79848676919937, 31.32624864578247, 0.9608645341359079, 0.03903520519088488, 0.04077171201060992, 0.00950155528698815, 0.047847611422184855, 0.06771316067897715, 0.015485460462514311, 0.057467515143798664, 0.048558340276940726, 0.04652547162550036, 0.07136263477150351, 0.053141020543989725, 0.04307377246732358, 0.024733151149121113, 0.01316676105489023, 0.0123416895075934, 0.029108401140547357, 0.023744784848531708, 0.008339960586454254, 0.0368480143515626, 0.037058086672914214, 0.04670958733186126, 0.03045679255592404, 0.04878481777268462, 0.06826692158938386, 0.15583147876895964, 0.025242962074116804, 0.024910628344514407, 0.01819223260099534, 0.14279409631853923, 0.17603164014872164, 0.0922423585143406, 0.10258459456963465, 0.2039965512813069, 0.1282590301707387, 0.14189493987942114, 0.23299623891944066, 0.16206897766096517, 0.10468459047842771, 0.13553200318710878, 0.1322503894334659, 0.07583920276374556, 0.17651696020038798, 0.15438307367730886, 0.1593944407068193, 0.0992606561339926, 0.16861949960002676, 0.09455379971768707, 0.15139073424506932, 0.12202104146126658, 0.19402591598918661, 0.21927038091234863, 0.1414429274154827, 0.16375032806536183, 0.16885174729395658, 0.185758494772017, 0.1459052090649493, 0.1288995481445454, 0.12490383989643306, 0.1936631987337023, 0.08201177115552127, 0.07214779732748866, 0.10023111070040613, 0.1495111858821474, 0.16734895762056112, 2.570747542195022, 40.37351377308369, 65.54957583546638, 44.33601714670658, 48.0452299118042, 59.89870525896549, 61.800829991698265, 20.883168317377567, 1.4727472979575396, 0.1870165835134685, 1.6826804517768323, 7.728727329522371, 12.576460652053356, 12.376855462789536, 2.4566486896947026, 0.12801798060536385, 0.13884057174436748, 0.5976590048521757, 24.755487330257893, 61.103282421827316, 68.38112309575081, 67.45806142687798, 68.53729471564293, 70.12272164225578, 64.60899710655212, 64.77942556142807, 71.1882072687149, 69.18282687664032, 62.801475897431374, 65.2780956029892, 67.70311027765274, 64.72550645470619, 60.29636912047863, 54.42620851099491, 55.80784857273102, 59.549541994929314, 62.63235077261925, 65.78435763716698, 66.82500779628754, 67.8971354663372, 66.40068456530571, 62.424528524279594, 63.29709850251675, 54.76085655391216, 51.13909989595413, 51.04062058031559, 57.85547509789467, 59.16191339492798, 62.79347352683544, 65.75675591826439, 64.73338723182678, 62.35390551388264, 63.17497305572033, 48.8919422775507, 51.22393414378166, 68.99130195379257, 67.51920014619827, 69.10515904426575, 62.35964700579643, 60.604000613093376, 53.21054354310036, 52.00784347951412, 48.756487146019936, 48.60211282968521, 54.03629243373871, 57.24474906921387, 60.18071472644806, 63.79153937101364, 60.52323214709759, 60.14251537621021, 64.1550886631012, 59.23322036862373, 55.701864659786224, 52.88219556212425, 59.416404739022255, 63.44228111207485, 64.75520566105843, 62.985997796058655, 61.28192223608494, 62.87058278918266, 60.65578803420067, 59.036550521850586, 52.375697940588, 54.35955248773098, 55.21350346505642, 58.946886733174324, 58.59874941408634, 58.07009898126125, 57.179004997015, 62.00243577361107, 54.240824058651924, 61.94684095680714, 43.00571992993355, 9.349067732691765, 0.40100949292536825, 2.0657080924138427, 3.5228505777195096, 7.991183046251535, 16.998083889484406, 20.58907739818096, 20.79006001353264, 3.737692474387586, 0.2716386958491057, 0.2888658730080351, 14.211345724761486, 59.63011287152767, 49.06712807714939, 41.01874195039272, 56.519493386149406, 49.73135903477669, 34.54045817255974, 0.9130934381391853, 0.2651418460300192, 0.2168979129055515, 0.11320983379846439, 0.11554327968042344, 0.1855908436118625, 0.0920180072716903, 0.09221302883815952, 0.1839907732210122, 0.2488312212517485, 0.11435455206083134, 0.20302396675106138, 0.10998486075550318, 0.13977837923448533, 0.14751921698916703, 0.11104312623501755, 0.18104659917298704, 0.1559345333953388, 0.11679554256261326, 0.09166411415208131, 0.2249119055340998, 0.1700087555218488, 0.12708532362012193, 0.15027055138489231, 0.11569038077141158, 0.24695107917068526, 0.033093819511123, 0.18463089043507352, 0.10494080212083645], [0.0618652744742576, 0.026161714922636747, 0.03891580105118919, 0.03850906701700296, 0.033109408323070966, 0.11453829298261553, 0.00984301093922113, 0.04026136673928704, 0.04708508808107581, 0.12533590343082324, 0.06540420567034744, 0.10832911444595084, 0.06184399710036814, 0.0472851191443624, 0.028880443060188554, 0.03836041854810901, 0.008318528289237292, 0.061105055501684546, 0.05247986344329547, 0.052061566748307087, 0.012347198098723311, 0.010677142254280625, 0.05477320737554692, 0.05401243921369314, 0.026492853794479743, 0.10111449650139548, 0.01591175008798018, 0.03240050144086126, 0.05621992779197171, 0.07074293404002674, 0.04066509507538285, 0.06119515965110622, 0.04824404815735761, 0.04592904093442485, 0.02589370127680013, 0.04084603067894932, 0.10265554388752207, 0.28312770591583103, 24.215458407998085, 48.182797729969025, 37.95622028410435, 35.15327028930187, 49.54398348927498, 55.944713428616524, 19.19845651835203, 0.8856058318633586, 0.050588685626280494, 0.16088364907773212, 2.177435397170484, 3.9920301642268896, 1.5548282372765243, 0.2204791019903496, 0.3452907968312502, 0.2182855806313455, 0.4940374963916838, 15.872243251651525, 51.39323405921459, 66.19634672999382, 64.67487037181854, 59.94138456881046, 60.10586254298687, 63.786842823028564, 67.36751988530159, 65.54425612092018, 61.00177086889744, 67.36457124352455, 64.78546723723412, 59.83012653887272, 54.350543171167374, 55.22798828780651, 57.862770706415176, 61.019451320171356, 61.15393750369549, 59.76189360022545, 62.91567116975784, 63.58429089188576, 63.53519752621651, 60.13673968613148, 60.17301253974438, 53.58834587037563, 53.84770855307579, 47.32762701809406, 51.43788926303387, 53.52360874414444, 60.95357045531273, 56.116714999079704, 68.08044523000717, 55.22458367049694, 58.518178537487984, 38.900834396481514, 44.15858946740627, 69.71831694245338, 58.48615005612373, 61.64406560361385, 56.969328448176384, 54.52482461929321, 44.84106704592705, 45.45213125646114, 45.03663495182991, 46.98252573609352, 50.43439731001854, 55.665515810251236, 59.82780106365681, 61.89139813184738, 60.619298592209816, 60.93095786869526, 59.7933217138052, 58.775785714387894, 50.78877009451389, 52.56056182086468, 56.47311307489872, 59.8646704852581, 60.448505356907845, 61.77905336022377, 58.09587299823761, 59.938401728868484, 59.62446637451649, 56.64933621883392, 54.04714845120907, 52.13460087776184, 51.974815651774406, 55.95396973192692, 51.836009100079536, 58.610046207904816, 56.63493499159813, 52.44878701865673, 57.47912809252739, 29.32867493480444, 5.0528467912226915, 0.15760807640617713, 0.9979360573925078, 2.811178690753877, 1.4656976074911654, 3.7965187802910805, 6.602978836745024, 6.1890157498419285, 2.8773160418495536, 0.08748394509893842, 0.021308558934833854, 11.731474343687296, 38.72388169169426, 36.135749369859695, 20.24675376713276, 30.369790568947792, 34.42005783319473, 16.1439049243927, 0.9902037098072469, 0.09668475802754983, 0.01759780199790839, 0.025206930804415606, 0.08709344925591722, 0.04316114180255681, 0.04340376843174454, 0.09565887987264432, 0.05222130290349014, 0.020141234854236245, 0.015916733609628864, 0.014982918874011375, 0.020828198285016697, 0.04840763234824408, 0.02786491415463388, 0.012286159235372907, 0.04083839769009501, 0.10023509603342973, 0.0417219282098813, 0.013154712287359871, 0.035972343175671995, 0.06644273002166301, 0.011374761998013128, 0.05030883658037055, 0.05881438330106903, 0.020615628636733163, 0.052276221831562, 0.026051235108752735, 0.023461327109544072, 0.008947438145696651, 0.09121725961449556, 0.044605023504118435, 0.03083171814068919, 0.06187299652083311, 0.02206051223765826, 0.04581690242048353, 0.04378037127025891, 0.028320103010628372, 0.0363762718916405, 0.08480666219838895, 0.02638050376845058, 0.027260724309599027, 0.03889507657731883, 0.029052626887278166, 0.03250836147344671, 0.027642626082524657, 0.03965575568145141, 0.012622720423678402, 0.03830364425084554, 0.039100551293813623, 0.011029198558389908, 0.10402849482488818, 0.03852795467537362, 0.016659575194353238, 0.016359426554117817, 0.01920478363899747, 0.04593616926285904, 0.09547188092255965, 0.03449856405495666, 0.08995051743113436, 0.014998128262959654, 0.034861407475546, 0.017565099260536954, 0.05198274695430882, 0.04197225462121423, 0.03155043435981497, 0.11422895098803565, 2.2500801365822554, 35.454039350152016, 52.87525333464146, 38.00263859331608, 34.39464099705219, 60.38889415562153, 63.20760950446129, 13.751209415495396, 0.5178727267775685, 0.02508399404177908, 0.2062859878060408, 0.6314914394170046, 0.7177281682379544, 3.024605163373053, 2.810541274957359, 1.2644647993147373, 0.3721280145691708, 1.3378012203611434, 22.776488922536373, 56.32003828883171, 67.8073538839817, 65.37161618471146, 62.48183324933052, 62.93828375637531, 66.2154521048069, 68.88689115643501, 65.62114119529724, 60.36180920898914, 67.32294827699661, 67.2264714539051, 61.89924091100693, 57.651391848921776, 55.62461860477924, 58.71926374733448, 62.28036426007748, 63.22074919939041, 62.87925772368908, 63.656912595033646, 63.564668744802475, 65.24590373039246, 62.468442767858505, 60.773771703243256, 56.601762771606445, 53.874641507864, 48.12058366835117, 53.6362536996603, 53.92915338277817, 62.607393711805344, 59.33538928627968, 69.60604816675186, 55.5517765134573, 60.501577109098434, 41.81839004158974, 46.72063998878002, 69.68984887003899, 60.85815377533436, 63.61646756529808, 58.80133934319019, 56.495729461312294, 48.47665876150131, 47.42371246218681, 46.32214777171612, 48.86050656437874, 51.803429648280144, 58.77729803323746, 61.139110699296, 63.70619215071201, 62.164253890514374, 61.41492269933224, 62.693584486842155, 60.618276447057724, 53.22646848857403, 54.78467367589474, 58.584842160344124, 60.73391564190388, 61.20149575173855, 62.7091408520937, 57.72913947701454, 60.87322376668453, 61.56826727092266, 59.90493692457676, 55.19836887717247, 53.77597980201244, 54.16541710495949, 57.96292193233967, 53.962207809090614, 59.915215373039246, 58.43766465783119, 55.31806245446205, 58.47238339483738, 36.027436181902885, 8.387006856501102, 0.5097089242190123, 0.9755077015142888, 4.658293062821031, 3.8275588396936655, 3.9242218527942896, 2.4689324805513024, 1.0388641362078488, 0.6017834460362792, 0.10121879051439464, 0.09886228610412218, 9.138274043798447, 43.96507725119591, 49.32967498898506, 25.89901316910982, 32.163499519228935, 43.30562263727188, 26.32217176258564, 2.714731553569436, 0.1722959359176457, 0.04077958990819752, 0.020917560286761727, 0.04429989690834191, 0.0905825081281364, 0.10379289262345992, 0.07354389585088938, 0.07153982995077968, 0.06036147919076029, 0.03163209286867641, 0.0405882865015883, 0.043582099096965976, 0.06159438686154317, 0.02104985738696996, 0.016325688520737458, 0.02656455268152058, 0.05227279310929589, 0.010969976101478096, 0.050924652168760076, 0.010527269241720205, 0.007422637299896451, 0.03579221280233469, 0.07701995971729048, 0.0374950409604935, 0.14443857682636008, 0.10616921237669885, 0.04069357870321255, 0.03483794447674882, 0.03368915924511384, 0.1713615274638869, 0.0997243203164544, 0.10786876024212688, 0.15311199735151604, 0.16186611901503056, 0.17430970910936594, 0.12267938582226634, 0.0922147580422461, 0.1938670370145701, 0.2135695586912334, 0.12689761962974444, 0.21701809630030766, 0.20357582776341587, 0.1374495346681215, 0.08587771488237195, 0.14677880593808368, 0.11163878138177097, 0.1366059057181701, 0.18417720071738586, 0.13176128442864865, 0.1286486428580247, 0.20288920757593587, 0.10686989626265131, 0.10066485148854554, 0.08571169644710608, 0.2549363952130079, 0.09262461651815102, 0.1381470644264482, 0.1488818891812116, 0.21899336687056348, 0.13818527018884197, 0.13219478772953153, 0.10844138654647395, 0.15565354144200683, 0.16019699920434505, 0.12177847791463137, 0.19929529807996005, 1.8092717276886106, 35.88069565594196, 66.22818902134895, 49.93256963789463, 46.17171384394169, 63.93097668886185, 67.64846920967102, 25.574316792190075, 1.6534989676438272, 0.16041783266700804, 0.6073237862437963, 7.339328499510884, 13.75492561608553, 9.286565836519003, 2.6594571070745587, 0.9436539513990283, 0.514042591676116, 1.1292850342579186, 19.725062660872936, 54.53273959457874, 69.8418103158474, 70.58128863573074, 64.37451928853989, 63.928324431180954, 70.1873105764389, 72.82430827617645, 67.90598899126053, 61.28436550498009, 68.54009136557579, 69.050153195858, 66.24457374215126, 59.91734705865383, 61.51791997253895, 64.04349625110626, 67.19573110342026, 65.56247994303703, 66.27395376563072, 64.21076327562332, 64.9946840107441, 67.48561754822731, 64.45841878652573, 63.44764642417431, 59.84049618244171, 58.35717357695103, 52.433158457279205, 55.4439003020525, 58.600930497050285, 65.88802367448807, 62.168027088046074, 70.7034520804882, 59.3736532330513, 61.85675539076328, 44.74123500287533, 48.811872974038124, 72.2410623729229, 62.68562771379948, 65.0969897210598, 61.69242560863495, 59.22715209424496, 50.38157634437084, 48.04469034075737, 49.46753539144993, 52.036607936024666, 54.91896227002144, 61.19362257421017, 64.27043527364731, 66.77857428789139, 63.25677506625652, 63.86923760175705, 64.45320546627045, 62.04055532813072, 54.9625763297081, 58.411419466137886, 60.960581079125404, 63.78982186317444, 63.487217500805855, 64.33707609772682, 57.87834607064724, 60.92021584510803, 64.78457048535347, 60.06263606250286, 57.704797983169556, 56.01211801171303, 57.00531631708145, 61.07395179569721, 56.3809110224247, 62.35848426818848, 59.793884083628654, 55.999920666217804, 60.53292162716389, 34.37815748155117, 6.373090697452426, 0.7388604374136776, 1.921275348868221, 9.56342563033104, 6.366963051259518, 9.86112255603075, 17.47509889304638, 13.611589707434177, 6.2616531271487474, 0.2289853908587247, 0.24004388105822727, 16.314470171928406, 48.18377807736397, 48.615982085466385, 32.139359414577484, 39.43100854754448, 50.93890763819218, 27.002859637141228, 2.060859315097332, 0.2427008587983437, 0.14655408362159505, 0.11415950822993182, 0.14769868314033374, 0.11272925607045181, 0.2132393920328468, 0.12459233083063737, 0.20144843176240101, 0.13700676936423406, 0.08696426360984333, 0.18287507293280214, 0.1388558599865064, 0.10202436955296434, 0.10473077432834543, 0.1972968873451464, 0.16045111056882888, 0.13457228749757633, 0.22281321580521762, 0.14898224239004776, 0.13073222246021032, 0.17230914614629, 0.13141066418029368, 0.18110794509993866, 0.17475836706580594, 0.2514748997054994, 0.22358501970302314, 0.08795232934062369, 0.20845497376285493, 0.04356976460258011], [0.05807523019029759, 0.08970623210188933, 0.010402071711723693, 0.022327974838844966, 0.011723384013748728, 0.03168287803418934, 0.03345355704368558, 0.019565046241041273, 0.038930573500692844, 0.042729861233965494, 0.04913721917546354, 0.08672387455590069, 0.017139583324023988, 0.04851693956879899, 0.04393333161715418, 0.03623539370892104, 0.03936901208362542, 0.06838183573563583, 0.026452837191754952, 0.012621866026165662, 0.013065170314803254, 0.02575873430032516, 0.039767742055119015, 0.028274741089262534, 0.04637167636246886, 0.02985965125844814, 0.020419579195731785, 0.06537382214446552, 0.042581813904689625, 0.01680573375779204, 0.05881435361516196, 0.020929230558976997, 0.028087113169021904, 0.030580679267586675, 0.10791286607855, 0.045637313814950176, 0.03041405598196434, 0.031272759806597605, 0.506896540755406, 23.37366107851267, 46.55688397586346, 37.14861921966076, 32.38285414874554, 36.17855027318001, 56.38351388275623, 25.90159323066473, 1.5997271030209959, 0.12324317314778455, 0.05662642062816303, 2.526034153997898, 1.5928083867765963, 7.977721318602562, 8.943768180906773, 0.06508370919618756, 0.32005691493395716, 1.8469927785918117, 21.49391144514084, 53.97461794316769, 67.72463232278824, 66.1071427166462, 66.59223228693008, 63.962849378585815, 68.82065311074257, 62.32611380517483, 66.78545191884041, 65.26449993252754, 62.47406266629696, 59.686566442251205, 60.68113647401333, 63.44082958996296, 64.50243562459946, 62.43243210017681, 64.59807649254799, 63.70322450995445, 65.96093416213989, 63.557019755244255, 64.23828139901161, 60.1103463023901, 59.17853370308876, 56.694606989622116, 55.01252464950085, 47.145183607935905, 50.266868099570274, 52.92508386075497, 61.42794460058212, 61.31254479289055, 65.94498261809349, 55.322371423244476, 64.60756838321686, 42.73219920694828, 44.22386236488819, 69.92069408297539, 62.21173234283924, 64.52063664793968, 58.89976546168327, 55.14826476573944, 49.543474316596985, 48.219963535666466, 45.988544672727585, 48.43592494726181, 51.118402406573296, 54.72606182098389, 60.00036120414734, 61.62388488650322, 59.536045119166374, 63.47497835755348, 60.26001647114754, 59.49257545173168, 57.83357687294483, 55.04895709455013, 54.63796354830265, 57.55035147070885, 60.97825773060322, 62.723124101758, 60.90337514877319, 60.48619173467159, 60.53709760308266, 59.360433742403984, 56.203855723142624, 57.92148135602474, 56.05492651462555, 57.699265480041504, 59.73167382180691, 58.07534649968147, 62.383315935730934, 52.46056638658047, 22.411168925464153, 2.354190987534821, 0.1230774589930661, 0.18700482789427042, 0.5651673639658839, 2.886810782365501, 2.7750447671860456, 2.1832372108474374, 1.6310697211883962, 0.24140169960446656, 0.26036036666482687, 0.26140198577195406, 15.203895214945078, 46.66023463010788, 53.69065538048744, 48.266028463840485, 30.074540711939335, 31.955608874559402, 12.112496048212051, 0.7962647289969027, 0.10661634150892496, 0.06415888929041103, 0.024876391216821503, 0.04215996974380687, 0.10089485047501512, 0.027698934682121035, 0.016402664077759255, 0.021664316700480413, 0.04549165620119311, 0.05150659242644906, 0.11100940304459073, 0.029800641241308767, 0.009793341778276954, 0.057924169741454534, 0.05783619184512645, 0.05061781492258888, 0.08596197832957841, 0.019347012530488428, 0.03183133354468737, 0.1253323708078824, 0.04222958319587633, 0.012723403888230678, 0.055987108644330874, 0.0622262031538412, 0.036903348882333376, 0.034378235941403545, 0.06199856419698335, 0.08239417758886702, 0.07558860175777227, 0.026461036068212707, 0.0379820531088626, 0.016323014933732338, 0.0946368534641806, 0.017230630000995006, 0.05481974745634943, 0.05384472126024775, 0.013284517626743764, 0.019833842852676753, 0.14341083588078618, 0.04944654261635151, 0.022251784102991223, 0.08555848005926237, 0.04097000273759477, 0.030743558418180328, 0.04168178544205148, 0.0551736888155574, 0.04061839543282986, 0.07893078218330629, 0.031893002305878326, 0.09979820111766458, 0.10359666877775453, 0.019353895950189326, 0.03287178376922384, 0.06627587295952253, 0.15728470782050863, 0.030730149665032513, 0.02366621367400512, 0.037798067278345115, 0.060537186363944784, 0.018477148660167586, 0.06944509586901404, 0.010999819714925252, 0.005314000936778029, 0.041787348527577706, 0.04486567690037191, 0.013894081548642134, 0.04794236883753911, 0.05647530822898261, 1.3380188774317503, 34.87829804420471, 49.903007224202156, 39.41173978149891, 36.58980220556259, 52.57281996309757, 70.26408165693283, 20.705292262136936, 0.6767702254001051, 0.2044626497081481, 0.08732330723432824, 0.2273459717980586, 0.47907205880619586, 5.139748603105545, 12.407548315823078, 0.6955047638621181, 0.2915687451604754, 2.4815349793061614, 28.04251614958048, 58.052711114287376, 69.73009631037712, 67.70400702953339, 68.7187197804451, 64.67592671513557, 70.88290125131607, 64.1568973660469, 65.26546508073807, 66.51980817317963, 65.36499693989754, 61.645600721240044, 62.90715962648392, 66.59485414624214, 67.08562821149826, 65.04378497600555, 66.58899486064911, 64.35622707009315, 67.49501824378967, 65.34246414899826, 66.1545717716217, 62.39003397524357, 60.52003651857376, 57.735933512449265, 58.62993434071541, 49.50063921511173, 53.210566341876984, 54.52854081988335, 62.44384288787842, 61.50619760155678, 67.88056075572968, 57.85938508808613, 67.12779074907303, 46.322934329509735, 45.048463717103004, 71.5194582939148, 65.87822780013084, 65.64910009503365, 60.2262818813324, 56.863580122590065, 51.50893025100231, 49.42034192383289, 48.01457695662975, 50.461413860321045, 53.31754960119724, 57.02034831047058, 62.11031958460808, 63.23973298072815, 60.572538301348686, 63.527468740940094, 62.364263758063316, 62.971201390028, 58.84016565978527, 57.176755517721176, 56.57373167574406, 60.98765082657337, 62.14721940457821, 64.59338754415512, 61.16030216217041, 61.663068383932114, 60.48910237848759, 61.168821305036545, 58.08708406984806, 58.98730516433716, 57.402300015091896, 58.58054459095001, 60.253693610429764, 59.94172655045986, 60.7419104129076, 54.0313944965601, 27.28567846119404, 3.9809760823845863, 0.7088788587134331, 0.4868211492430419, 3.7375587690621614, 6.334089590236545, 2.767970021814108, 1.160472217015922, 0.44168622116558254, 0.1698225803556852, 0.40866076829843223, 0.26659072609618306, 11.373835634440184, 48.43331828713417, 56.72442778944969, 39.99195724725723, 27.76289865374565, 36.53389200568199, 21.41784332692623, 1.6934694978408515, 0.12593287217896432, 0.057919980317819864, 0.05062886550149415, 0.040962540442706086, 0.04374101146822795, 0.02778106259938795, 0.007264166970344377, 0.021603258355753496, 0.06249567697523162, 0.007143649609133718, 0.0681871481356211, 0.06805457087466493, 0.0046308484343171585, 0.03920410315913614, 0.04845240982831456, 0.016809407388791442, 0.0259666989222751, 0.013834257952112239, 0.007502044318243861, 0.07821811261237599, 0.01731741303956369, 0.056753999524516985, 0.04330874755396508, 0.029492132307495922, 0.022182469365361612, 0.02777926103590289, 0.0629522833332885, 0.013588369583885651, 0.023212963678815868, 0.023843711278459523, 0.09219633793691173, 0.17777720117010176, 0.26728914643172175, 0.11083729157689959, 0.11295967065962031, 0.12229340223711915, 0.13452771410811692, 0.07629947533132508, 0.17473061074269935, 0.11320624180370942, 0.08734671457204968, 0.15037008823128417, 0.10551503146416508, 0.1416880587930791, 0.09029103704961017, 0.15245344518916681, 0.12402484760968946, 0.16153589298482984, 0.20881012111203745, 0.17938123462954536, 0.17767751589417458, 0.1641185223706998, 0.13861148559954017, 0.15820863714907318, 0.4363517230376601, 0.10474560243892483, 0.19764170399866998, 0.14190890709869564, 0.12805995647795498, 0.12308610501349904, 0.16916990600293502, 0.08260787159088068, 0.12448640409274958, 0.26113882020581514, 0.1522987667704001, 0.17954171664314345, 0.1262629052507691, 0.10391441930551082, 1.0283166146837175, 35.172824040055275, 61.154929250478745, 49.59319844841957, 43.91005240380764, 49.53884996473789, 68.69598940014839, 33.45350369811058, 2.285870178602636, 0.27613875281531364, 0.41879402298945934, 7.718336312100291, 9.035260621458292, 15.526018179953098, 13.355675339698792, 0.7752159959636629, 0.7616678823251277, 2.7258770680055022, 26.12933211028576, 58.60481008887291, 73.56026038527489, 72.82962799072266, 73.0300672352314, 67.41868793964386, 71.6705533862114, 64.39557015895844, 67.47766077518463, 68.6617836356163, 68.45994606614113, 65.44204920530319, 65.0533376634121, 66.65913909673691, 69.77813333272934, 69.52280983328819, 70.26092782616615, 68.1942643225193, 69.42710816860199, 69.58698838949203, 67.29328706860542, 65.41771531105042, 63.68104130029678, 60.13824820518494, 60.524242892861366, 51.593517512083054, 55.13278819620609, 58.22082169353962, 64.8110094666481, 67.17325150966644, 68.2167287170887, 61.39900915324688, 67.86594673991203, 50.858393758535385, 49.19639714062214, 71.92118793725967, 67.89605632424355, 68.61294865608215, 64.10472616553307, 58.55453118681908, 54.451173171401024, 51.71244353055954, 50.29820881783962, 52.24422499537468, 57.109491527080536, 58.74162174761295, 64.02445167303085, 64.68660414218903, 61.533780321478844, 64.0164265036583, 63.7157828360796, 63.986164927482605, 63.03524695336819, 58.228466883301735, 59.039955139160156, 62.1954882144928, 65.04864871501923, 66.90981164574623, 62.99123011529446, 63.27919766306877, 62.839542254805565, 63.50630007684231, 60.79261489212513, 62.33086735010147, 60.27187563478947, 62.22912020981312, 62.490747570991516, 61.75392530858517, 64.9069695174694, 54.52051185071468, 23.657091669738293, 3.0126248812302947, 0.5769976135343313, 0.1604648254578933, 2.2849615523591638, 8.062115740031004, 7.500666892156005, 11.141530349850655, 6.930682277306914, 1.7590995761565864, 0.9834178083110601, 0.5423877644352615, 20.870853178203106, 56.899347603321075, 65.14482915401459, 54.66326639056206, 41.280038729310036, 47.0015475153923, 23.82084958255291, 1.2877608742564917, 0.193954209680669, 0.1891709936899133, 0.11817562553915195, 0.17717980197630823, 0.18132625526050106, 0.09541016392176971, 0.13303031242685392, 0.06594320526346564, 0.14287594036431983, 0.13361969642573968, 0.17086112697143108, 0.14778995246160775, 0.14132013166090474, 0.10275078369886614, 0.13761181267909706, 0.16086378920590505, 0.1604618420242332, 0.1003974408376962, 0.09136169639532454, 0.1538357842946425, 0.07447942494763993, 0.2277685803710483, 0.11417393558076583, 0.14021537062944844, 0.10351414195611142, 0.13941735407570377, 0.14319144218461588, 0.12972226337296888, 0.20424727845238522, 0.11667714774375781], [0.03638434274762403, 0.023071122559485957, 0.03762055297556799, 0.03865049067826476, 0.04584737871482503, 0.0659411346714478, 0.043178701016586274, 0.053242995345499367, 0.01608475584362168, 0.01077383760275552, 0.014908210578141734, 0.014938498552510282, 0.049833902885438874, 0.047733187093399465, 0.10387510032160208, 0.034970247143064626, 0.057783625525189564, 0.020313012355472893, 0.0032185321288125124, 0.03384403433301486, 0.08511182590154931, 0.052946403448004276, 0.02036082893027924, 0.06229009464732371, 0.047468039992963895, 0.07243261876283213, 0.03466208145255223, 0.08374747645575553, 0.053445690718945116, 0.01939381421834696, 0.0489981518330751, 0.021483160307980143, 0.044806594523834065, 0.07723037342657335, 0.019954200652136933, 0.022912414278835058, 0.03612574510043487, 0.017037985162460245, 0.05567142870859243, 0.47601429163478315, 23.455746173858643, 48.09276916086674, 43.217216581106186, 31.38761345297098, 33.45314271748066, 58.11406262218952, 30.506676323711872, 2.8082939330488443, 0.13676661037607118, 0.36036093661095947, 0.5883589445147663, 7.67062084749341, 8.44254182651639, 0.4574932245304808, 0.5380319512914866, 0.1723103187396191, 2.419780930504203, 24.100377783179283, 53.875842243433, 61.80795840919018, 68.54063853621483, 66.72034621238708, 63.814018964767456, 62.75237113237381, 65.403982847929, 67.03316822648048, 64.61272850632668, 62.13617719709873, 66.1980414390564, 66.20178043842316, 68.37367549538612, 64.21114325523376, 66.87930688261986, 63.510989025235176, 66.9088464975357, 58.91490004956722, 62.00096905231476, 58.586962446570396, 60.98935313522816, 60.54484538733959, 57.00792297720909, 52.396156042814255, 52.65424959361553, 55.141949504613876, 61.65508881211281, 62.09708109498024, 68.45362320542336, 52.03607216477394, 62.09037825465202, 33.1465295702219, 38.354294523596764, 67.0312987267971, 60.22940531373024, 64.89447578787804, 61.13684602081776, 59.80720616877079, 52.1971645206213, 50.68667337298393, 47.99834042787552, 47.504184544086456, 48.103245198726654, 53.89454863965511, 59.83247481286526, 62.58350819349289, 64.47969764471054, 62.78608292341232, 62.52364620566368, 60.71153484284878, 57.83066622912884, 59.329590797424316, 58.07788476347923, 56.552506014704704, 59.096043929457664, 64.04580652713776, 62.3630478233099, 61.561830416321754, 63.186330646276474, 62.0249267667532, 58.92784595489502, 61.89095735549927, 60.78369677066803, 61.53202101588249, 57.22495973110199, 63.43113251030445, 42.819301933050156, 12.2281314432621, 0.47888200962916017, 0.0899612859939225, 0.11958941686316393, 1.5205882745794952, 2.356151444837451, 4.075364442542195, 2.0162962563335896, 1.1816507368348539, 0.15334902447648346, 0.20037044741911814, 0.5472123180516064, 19.369568936526775, 52.92617820203304, 33.167439848184586, 29.17131207883358, 38.82704235613346, 38.57738055288792, 17.144719921052456, 0.3852575272321701, 0.06604325419175439, 0.05001235600502696, 0.04673509123676922, 0.012227977640577592, 0.01784765157935908, 0.053684131635236554, 0.09286484972108155, 0.019375408955966122, 0.01357323812044342, 0.10398582875495777, 0.14235714945243672, 0.036096419134992175, 0.056636970257386565, 0.05799098900752142, 0.034979219708475284, 0.019488382386043668, 0.017956116462300997, 0.0764264196914155, 0.03838976306724362, 0.0509088221588172, 0.026129008474526927, 0.05888025261810981, 0.0604597209894564, 0.06197231814439874, 0.07176268947659992, 0.043998232431476936, 0.055031582378433086, 0.05591702392848674, 0.017141932221420575, 0.06011733115883544, 0.035180575505364686, 0.09833391406573355, 0.04834567786019761, 0.008461905654257862, 0.03991013050836045, 0.05647661440889351, 0.08307737647555768, 0.029321063557290472, 0.06856550986412913, 0.007618743793500471, 0.03923254967958201, 0.0425797173375031, 0.015734284024802037, 0.059642505075316876, 0.026953443630191032, 0.026098352209373843, 0.0370122330787126, 0.07150282646762207, 0.035208539629820734, 0.055627285764785483, 0.10729886504122987, 0.06177996088808868, 0.04756867521791719, 0.0657353519636672, 0.01849428485002136, 0.1292879437096417, 0.1002322684507817, 0.038515460619237274, 0.041254148818552494, 0.05178294224606361, 0.016821142598928418, 0.04909272742224857, 0.049926374485949054, 0.025334422498417553, 0.03982486145105213, 0.029001158945902716, 0.05204420420341194, 0.07520980958361179, 0.08075485500739887, 0.09154263199889101, 1.8663159292191267, 32.16383010149002, 54.37696695327759, 43.497744128108025, 26.31815727800131, 43.00870656967163, 71.09966441988945, 27.70017731934786, 1.8754702317528427, 0.08998765450087376, 0.4679804539773613, 0.6155903614126146, 11.635326202958822, 6.69121865183115, 1.5782694169320166, 0.27346906950697303, 0.07024192498647608, 4.2579916678369045, 30.798751451075077, 59.648560881614685, 63.91480475664139, 71.37843266129494, 68.49480539560318, 65.32139047980309, 62.44966797530651, 65.99965408444405, 68.44258859753609, 67.80605435371399, 61.969822123646736, 68.50178942084312, 67.9713986814022, 70.31211867928505, 66.34076938033104, 69.54798728227615, 65.95178425312042, 68.0836370587349, 62.07694597542286, 63.96955221891403, 60.966387167572975, 62.95925863087177, 62.94764265418053, 59.564790576696396, 53.66697125136852, 53.61278995871544, 55.85625417530537, 62.675679847598076, 64.03783455491066, 68.29597726464272, 54.72949303686619, 64.49339210987091, 38.75232316553593, 41.7572171241045, 65.46917214989662, 61.03548265993595, 65.66599398851395, 61.9823082536459, 59.93946947157383, 53.420470878481865, 52.82810926437378, 49.15138475596905, 49.04812149703503, 49.9885368347168, 57.981620728969574, 59.88480560481548, 65.16607761383057, 67.37959563732147, 62.49404579401016, 64.58595514297485, 61.90939396619797, 61.4172899723053, 59.8259087651968, 58.160260543227196, 58.76615323126316, 60.79617530107498, 64.02069747447968, 61.55900336802006, 63.3375359326601, 64.85324040055275, 63.24604444205761, 60.83393767476082, 61.878478825092316, 62.452913001179695, 61.841579005122185, 57.581802383065224, 63.985564559698105, 48.512145057320595, 17.606923319399357, 1.8611009465530515, 0.1836833608103916, 1.9296394125558436, 4.750436693429947, 3.6212270613759756, 4.916908610612154, 2.818284071981907, 1.0901446407660842, 0.45795406855177134, 0.2508094604127109, 0.2617108676349744, 16.536608152091503, 60.94897650182247, 44.35683622956276, 36.37685023248196, 46.38325609266758, 43.0854282528162, 26.051403991878033, 1.4308988372795284, 0.09764228438143618, 0.07712422404438257, 0.04375644442916382, 0.02059049395029433, 0.032951156463241205, 0.06649769347859547, 0.0558220216043992, 0.06874672006233595, 0.03477568941889331, 0.04038584345835261, 0.11399176059057936, 0.06600331922527403, 0.0468468623876106, 0.034005113775492646, 0.08621507295174524, 0.02461632597260177, 0.07517240534070879, 0.08663362939842045, 0.002089180729853979, 0.021224085830908734, 0.012613278449862264, 0.04880645879893564, 0.07038073628791608, 0.04058545149746351, 0.02396865740593057, 0.04491845844313502, 0.03392265374714043, 0.018566462422313634, 0.02130235643562628, 0.043896899587707594, 0.06266420386964455, 0.12868536432506517, 0.20024781493702903, 0.12759229954099283, 0.1075497035344597, 0.10239597773761488, 0.19854449696140364, 0.11308825516607612, 0.17248493124498054, 0.109928331366973, 0.26614742644596845, 0.06825936652603559, 0.08043715642997995, 0.18526471423683688, 0.18730906391283497, 0.24395158543484285, 0.10778785872389562, 0.14559668343281373, 0.24461313587380573, 0.18030482257017866, 0.17228744574822485, 0.23476559319533408, 0.1612705158186145, 0.24876009381841868, 0.1400275478954427, 0.2027962461579591, 0.2554398978827521, 0.11360151707776822, 0.1945326098939404, 0.14239753712899983, 0.08683055086294189, 0.15895810240181163, 0.19812378828646615, 0.16382135159801692, 0.14599438552977517, 0.05526439410459716, 0.10149099543923512, 0.13361310615437105, 0.1828203914919868, 0.1246122203883715, 1.4953857706859708, 33.08635599911213, 64.9145919084549, 55.287204310297966, 40.37239283323288, 44.3661305308342, 74.32049319148064, 39.231253266334534, 4.716082736849785, 0.18754923774395138, 0.7978256139904261, 1.232487615197897, 14.122151210904121, 14.099588971585035, 3.1609755707904696, 1.356944830622524, 0.25545925309415907, 3.639146899804473, 27.13637877255678, 60.6044527888298, 64.47634622454643, 73.88385102152824, 70.91219767928123, 65.57305857539177, 63.57006825506687, 67.10320606827736, 71.80276349186897, 71.75300136208534, 66.9963026046753, 71.53153404593468, 71.92222148180008, 73.26259195804596, 67.79905512928963, 70.97290322184563, 68.2883320748806, 69.90824595093727, 62.046756595373154, 65.21486699581146, 62.7123136818409, 66.60711988806725, 65.71934312582016, 61.841134428977966, 57.090720534324646, 58.04927609860897, 60.54968632757664, 67.0820640027523, 67.90590539574623, 73.39418649673462, 60.80573558807373, 64.93697270751, 41.85972422361374, 44.6226167678833, 67.04092741012573, 62.56390884518623, 67.62697756290436, 64.39778923988342, 62.75349207222462, 56.603297889232635, 55.3670684248209, 52.7202520519495, 51.41909547150135, 52.237275168299675, 59.73004370927811, 62.972432523965836, 67.53118470311165, 67.80996814370155, 62.81931973993778, 66.75313085317612, 63.68969723582268, 63.010388687253, 62.951560243964195, 62.63038247823715, 61.20260909199715, 63.05297680199146, 65.52462637424469, 63.873668164014816, 64.09010455012321, 66.04731112718582, 63.48695531487465, 63.10566857457161, 66.37586429715157, 65.4130719602108, 64.45628330111504, 60.7504827529192, 64.428301602602, 45.234133154153824, 14.012236408889294, 0.9730807598680258, 0.20801551843760535, 0.7091434788890183, 4.1252662148326635, 8.57853937894106, 9.301961660385132, 6.445982661098242, 4.92003726772964, 1.6642459784634411, 0.3795997495763004, 0.963259058771655, 26.68573435395956, 63.60376104712486, 43.3709791302681, 38.22272278368473, 49.312560707330704, 50.30579701066017, 28.544651605188847, 1.0836472269147635, 0.28059995092917234, 0.18930395686766133, 0.13546497240895405, 0.12704229389782995, 0.13923886755947024, 0.10700002443627454, 0.1593139918986708, 0.17890182207338512, 0.1209987181937322, 0.18230771587695926, 0.2945956389885396, 0.1556169387185946, 0.09569512636517175, 0.06642272914177738, 0.16456774435937405, 0.09990674763685092, 0.15722487587481737, 0.1659099035896361, 0.13912187539972365, 0.1260842999909073, 0.06338989071082324, 0.1427269319538027, 0.17042484803823754, 0.12638325191801414, 0.13487377756973729, 0.15620942489476874, 0.17107838328229263, 0.14183743827743456, 0.13051622780039907, 0.14479687088169158, 0.16637435444863513], [0.010617514399200445, 0.024714452738408, 0.03801602120802272, 0.026546383051027078, 0.016930551864788868, 0.03495407203445211, 0.04725193401100114, 0.024101449889712967, 0.07045485457638279, 0.022502852662000805, 0.04141649362281896, 0.06993335482547991, 0.06230277052964084, 0.025130075846391264, 0.04847357588005252, 0.03983157788752578, 0.04983555416401941, 0.04216278248350136, 0.031846833298914135, 0.026608018415572587, 0.05176320111786481, 0.060083366770413704, 0.06402910250471905, 0.03847618987492751, 0.025382829080626834, 0.0568928739085095, 0.0008458861225335568, 0.024728566531848628, 0.01345449170912616, 0.017262885594391264, 0.05058675604232121, 0.10448349814396352, 0.07961701645399444, 0.06023368507158011, 0.028707446581393015, 0.03021628290298395, 0.04823111623409204, 0.10008724537328817, 0.020492773510341067, 0.07203433779068291, 0.43434667750261724, 15.420231856405735, 44.86465238034725, 48.61062057316303, 39.115918055176735, 43.051131293177605, 60.92121139168739, 45.47585718333721, 6.838386179879308, 0.10278026922605932, 0.14585012686438859, 0.23431923589669168, 5.077348351478577, 1.9773666327819228, 0.575557075208053, 0.4207405279157683, 0.09655453337472863, 1.3610839960165322, 18.564973510801792, 42.59577512741089, 56.28528915345669, 60.55267296731472, 64.51460257172585, 63.448406383395195, 66.79258793592453, 66.74632161855698, 66.19424164295197, 63.92683491110802, 69.15675267577171, 66.49803534150124, 69.49675843119621, 66.79372787475586, 69.34921994805336, 65.37975534796715, 61.6519919782877, 57.462325394153595, 59.51999478042126, 58.08238372206688, 60.66050738096237, 57.12666280567646, 56.794807612895966, 53.99922542273998, 53.70473362505436, 54.87124063074589, 65.33832997083664, 61.570714339613914, 66.27083033323288, 53.171561434865, 65.70044293999672, 21.912037208676338, 31.307730339467525, 68.68015944957733, 63.22673387825489, 67.00000360608101, 62.23331518471241, 62.3861163854599, 58.120849058032036, 55.498795956373215, 51.7277605086565, 47.22558729350567, 48.573431968688965, 53.08035492897034, 62.07499288022518, 61.20455078780651, 61.858104318380356, 63.5760073363781, 63.664675578475, 65.07010236382484, 63.23770008981228, 63.702935725450516, 59.50095020234585, 62.46728762984276, 59.34323966503143, 61.79104931652546, 65.35533025860786, 64.97722014784813, 62.89053551852703, 64.58325728774071, 60.76931074261665, 61.93120859563351, 62.26599723100662, 62.65310525894165, 57.19283625483513, 31.047037728130817, 5.538904359564185, 0.0835034360352438, 0.1500889626913704, 0.46228619234170765, 3.1208694353699684, 7.5119180884212255, 29.10074796527624, 19.14009165018797, 3.445083238184452, 0.3992299415403977, 0.08900663175154477, 1.6333105321973562, 25.636969730257988, 50.817112773656845, 28.656109124422073, 25.896769389510155, 32.82801166176796, 31.014448776841164, 12.330684140324593, 0.3959432663396001, 0.07253291259985417, 0.04148351326875854, 0.07800153165590018, 0.019155315785610583, 0.03869508633215446, 0.012282540337764658, 0.034099110489478335, 0.07035217844531871, 0.017622918130655307, 0.023931661344249733, 0.018157832200813573, 0.06889687138027512, 0.029284930242283735, 0.011257412679697154, 0.053531082230620086, 0.011624766502791317, 0.012301578281039838, 0.017918493285833392, 0.019349543254065793, 0.06898796258610673, 0.055412990623153746, 0.05107037286506966, 0.028625988452404272, 0.07870951085351408, 0.06681954808300361, 0.05465860493131913, 0.042079624836333096, 0.032793962163850665, 0.05476648722833488, 0.06390445138094947, 0.04462164390133694, 0.05149914126377553, 0.03401008987566456, 0.03634850072558038, 0.027100246006739326, 0.016618842419120483, 0.024437123283860274, 0.03643225951236673, 0.04297911153116729, 0.032588476315140724, 0.03402072485187091, 0.029447929991874844, 0.05501662068127189, 0.06121116406575311, 0.061870532590546645, 0.008189889049390331, 0.09903911020956002, 0.010690334856917616, 0.06876173370983452, 0.03207004534488078, 0.028040853248967323, 0.03445513728365768, 0.05124295188579708, 0.040441630699206144, 0.036673464928753674, 0.02793161282170331, 0.1081134908599779, 0.05652092062518932, 0.04415942319610622, 0.0403223935427377, 0.06130431473138742, 0.04243354393111076, 0.03941221621062141, 0.03093955590884434, 0.07343842182308435, 0.011012929753633216, 0.04943294647091534, 0.04860163346165791, 0.05604170473816339, 0.038900104627828114, 0.04526726042968221, 0.1370718260295689, 1.3018462434411049, 24.202533401548862, 53.81563827395439, 44.48452837765217, 33.10215935111046, 52.00029708445072, 72.33142152428627, 43.542471528053284, 4.888392565771937, 0.05098164539958816, 0.1501781094702892, 0.24607786821434274, 0.22416420659283176, 1.0746564343571663, 0.9010581183247268, 0.2686300885397941, 0.03458869417954702, 2.7424971386790276, 25.292774699628353, 48.26774217188358, 62.62260429561138, 63.758123964071274, 64.2393909394741, 64.5073601603508, 66.79802924394608, 68.52669328451157, 69.73193541169167, 65.93330964446068, 71.95600926876068, 68.3659391105175, 72.99656063318253, 69.71580147743225, 71.5354098379612, 67.04834461212158, 65.33450737595558, 60.559888780117035, 61.36674888432026, 60.26695489883423, 63.7391097843647, 59.35028828680515, 59.62443217635155, 55.19948221743107, 55.990763157606125, 58.16593363881111, 66.80367574095726, 64.89416420459747, 70.1407478749752, 55.319213792681694, 69.05988827347755, 25.05377322435379, 33.62533427774906, 70.1355953514576, 65.03674015402794, 69.13092166185379, 63.586741760373116, 64.3447744846344, 59.06338848173618, 58.78485582768917, 52.26399153470993, 49.86078388988972, 51.73304222524166, 55.736389607191086, 64.70771580934525, 62.72952675819397, 65.12816324830055, 65.53154960274696, 63.79261091351509, 65.30481576919556, 64.2930668592453, 65.3335802257061, 62.288499623537064, 61.09016552567482, 60.37401035428047, 63.05002436041832, 66.66500598192215, 64.13154512643814, 63.80878284573555, 64.36603054404259, 61.595891788601875, 63.37655983865261, 62.65376642346382, 60.694477558135986, 61.15474686026573, 37.09696099162102, 9.074647407978773, 0.1290593176963739, 1.0799890919588506, 2.3262608237564564, 2.466201614588499, 13.124462496489286, 24.168069250881672, 16.97250746190548, 1.5567751578055322, 0.8469375630374998, 0.22256898984778672, 1.370044865179807, 22.55017876625061, 59.67141665518284, 40.8039964735508, 25.954986065626144, 31.717889830470085, 39.26131345331669, 20.917932651937008, 1.6503255441784859, 0.06631093201576732, 0.05328118255420122, 0.06610032534808852, 0.042705325831775554, 0.04347989794041496, 0.04004679329227656, 0.008680504324729554, 0.058053696775459684, 0.022066627534513827, 0.030585738859372213, 0.04567831376334652, 0.05221459017775487, 0.019098660231975373, 0.0294293929982814, 0.03464831461315043, 0.04766217098222114, 0.022893851310072932, 0.04419683486048598, 0.09474811624386348, 0.09453403632505797, 0.03727532814082224, 0.009109742131840903, 0.024158656487998087, 0.027510321560839657, 0.04390790934849065, 0.0172131691215327, 0.024343380755453836, 0.036486031822278164, 0.05772805350716226, 0.05283789032546338, 0.017361695136060007, 0.016583399301453028, 0.06481488846475258, 0.15500239591347054, 0.14073579426622018, 0.12462651415262371, 0.15648514759959653, 0.12032140453811735, 0.07807332702213898, 0.14555224362993613, 0.17033417243510485, 0.1216171943815425, 0.17375642317347229, 0.1429859414929524, 0.1673253276385367, 0.13581339590018615, 0.15122560638701543, 0.20332162734121084, 0.12986420653760433, 0.22280900040641427, 0.13186986063374206, 0.08423842198681086, 0.19388021755730733, 0.11788859250373207, 0.17738505033776164, 0.11044566024793312, 0.12013931860565208, 0.31126688816584647, 0.07472529105143622, 0.15224426344502717, 0.12111839692806825, 0.10302513343049213, 0.13109431631164625, 0.1858009456191212, 0.21092559822136536, 0.13823673070874065, 0.1291243446758017, 0.20741066808113828, 0.10234918532660231, 0.21758186136139557, 0.13648901745909825, 0.1482997040147893, 0.9742844046559185, 23.716963157057762, 64.52664792537689, 59.23968382179737, 51.52835100889206, 57.087179124355316, 71.42981350421906, 57.028042897582054, 9.311703387647867, 0.34926018852274865, 0.47800217871554196, 0.9460078063420951, 10.842760931700468, 6.059038024395704, 1.2909475970081985, 0.8384269697126001, 0.20481825718889013, 2.3993399273604155, 21.291733793914318, 45.429967045784, 61.85357876121998, 61.25717796385288, 64.8848395049572, 63.56360100209713, 68.63064050674438, 73.25519755482674, 71.9706916809082, 68.42238128185272, 75.12202978134155, 70.00471517443657, 73.13676550984383, 72.49036699533463, 75.68078979849815, 69.78055000305176, 66.43244326114655, 62.667042911052704, 64.84491884708405, 63.32262173295021, 65.94603136181831, 61.073328629136086, 61.617261841893196, 58.368584364652634, 56.738057658076286, 61.190996915102005, 70.50719261169434, 66.20826289057732, 70.11642917990685, 58.814486637711525, 68.01574990153313, 30.31275562942028, 36.53440497815609, 69.50595393776894, 68.02152559161186, 70.47272846102715, 67.91810274124146, 67.65825748443604, 61.79964825510979, 60.60139775276184, 55.39707541465759, 52.87978269159794, 51.977927684783936, 57.39110581576824, 67.73578852415085, 64.09876048564911, 65.53841203451157, 64.50297519564629, 64.0567347407341, 67.41266906261444, 66.96531906723976, 69.9909371137619, 63.80910962820053, 65.42288303375244, 63.083523362874985, 65.62652930617332, 67.63723701238632, 66.48117184638977, 62.17686541378498, 66.84928849339485, 61.55596353113651, 65.38642778992653, 65.00884965062141, 64.42918315529823, 59.31880697607994, 34.85191226005554, 7.237953739240766, 0.213909195153974, 0.4860977630596608, 2.12494311388582, 9.08827442675829, 17.191873490810394, 38.894256949424744, 35.7478965818882, 8.88783423230052, 1.7299386346712708, 0.27631835255306214, 2.7934106066823006, 33.36049608886242, 60.67072123289108, 39.53522175550461, 34.91427831351757, 42.922485396265984, 46.99383772909641, 21.49964153766632, 1.0940779047086835, 0.2033155268873088, 0.12685025576502085, 0.1179667332326062, 0.08570070524001494, 0.10578276865999214, 0.10289090860169381, 0.16732152784243226, 0.1312569505535066, 0.11142237111926079, 0.2330105029977858, 0.09390819061081856, 0.15494490915443748, 0.11303839026368223, 0.13713900523725897, 0.13771108235232532, 0.15189429628662765, 0.10149030524189584, 0.09083789598662406, 0.20314176043029875, 0.1866719449753873, 0.11937788993236609, 0.1702995438245125, 0.13948901585536078, 0.1730023862910457, 0.18586812482681125, 0.1148842005932238, 0.07100529066519812, 0.1870599397807382, 0.16142031090566888, 0.182097346696537, 0.07409079931676388, 0.10149794194148853], [0.0480119748681318, 0.024878736403479706, 0.04169200110482052, 0.043118754038005136, 0.028906744773848914, 0.05922667231061496, 0.03256132855312899, 0.013537347858800786, 0.022366822558979038, 0.002850594328265288, 0.02340423368877964, 0.02388842938671587, 0.0471330716391094, 0.1045747303578537, 0.039467502501793206, 0.09031575798871927, 0.03130222678009886, 0.004702919322880916, 0.02576213148131501, 0.08484405159833841, 0.020711809120257385, 0.05757403188908938, 0.024402889866905753, 0.0814655949943699, 0.03629443526733667, 0.03747341106645763, 0.06399169084033929, 0.04826319185667671, 0.07340573021792807, 0.023405662323057186, 0.1310641851159744, 0.025661069521447644, 0.026345607984694652, 0.013041335314483149, 0.05395743122790009, 0.010269010199408513, 0.04188672952295747, 0.08966364024672657, 0.030631288173026405, 0.07687452103709802, 0.1050766374100931, 0.2754521177848801, 7.796351350843906, 46.170733496546745, 48.06262157857418, 30.63808087259531, 29.41179547458887, 43.824458196759224, 53.93840968608856, 16.74285728484392, 0.41736440907698125, 0.10919142325292341, 0.13618697819765657, 0.36212784179951996, 0.7395741459913552, 0.2556483226362616, 0.12064631679095328, 0.11024486477253959, 1.113411148544401, 5.772082647308707, 17.781436555087566, 34.4719934463501, 52.75848940014839, 63.03067959845066, 69.07615900039673, 67.71301254630089, 68.65438923239708, 68.29837873578072, 68.07354480028152, 68.71745824813843, 67.75937005877495, 65.52873015403748, 65.10604083538055, 61.21241256594658, 61.09456188976765, 64.29179012775421, 64.25712078809738, 61.53105206787586, 62.44240276515484, 60.78839711844921, 61.52463421225548, 57.78761073946953, 57.31138229370117, 64.7500379383564, 65.41391551494598, 70.83750128746033, 65.7519681751728, 64.17373046278954, 49.205809235572815, 29.83654998242855, 35.71296885609627, 53.3099690079689, 59.24020439386368, 60.40273301303387, 67.56199344992638, 63.91010820865631, 62.49398499727249, 56.81014358997345, 54.98940289020538, 49.87613506615162, 49.28053982555866, 53.32687430083752, 64.09674659371376, 65.81339567899704, 63.27200844883919, 62.89531946182251, 65.13196304440498, 63.81231665611267, 63.487810268998146, 63.01843285560608, 64.16556090116501, 61.86316564679146, 62.29923404753208, 62.183275669813156, 65.59213355183601, 66.4323216676712, 64.89999309182167, 65.20654544234276, 63.66032861173153, 62.30814836919308, 65.55345922708511, 45.65782181918621, 13.36114989593625, 0.8398355660028756, 0.44904690119437873, 0.1528345825499855, 3.3840858237817883, 1.4566673920489848, 3.298825998790562, 10.936203617602587, 4.1955325193703175, 0.6644458835944533, 0.45408706355374306, 0.0730946367548313, 4.4736571703106165, 33.32313269376755, 49.08989265561104, 23.941593803465366, 22.44939297437668, 30.884100571274757, 34.752699583768845, 8.717811405658722, 0.12174057643278502, 0.035482421808410436, 0.11380338124581613, 0.030973793036537245, 0.02630463772220537, 0.04594290796376299, 0.04805756871064659, 0.027607964075286873, 0.10865905846003443, 0.010730569465522422, 0.03139118431136012, 0.029107664558978286, 0.050055062893079594, 0.05862386657099705, 0.07167562813265249, 0.004233708978063078, 0.005621004702334176, 0.06741781558957882, 0.046447709391941316, 0.09639656724175438, 0.0401854413212277, 0.007481115753762424, 0.09706705313874409, 0.07262043407536112, 0.0284256660961546, 0.03888506500516087, 0.01888542636152124, 0.04569048869598191, 0.031463220875593834, 0.010096694641106296, 0.05869052998605184, 0.03747431648662314, 0.04853820209973492, 0.037137819308554754, 0.0639179213612806, 0.03854225215036422, 0.01925346296047792, 0.01691524692432722, 0.01786824988812441, 0.07036954470095225, 0.0169082132197218, 0.014018164929439081, 0.05738048719649669, 0.035401308778091334, 0.0010288899989063793, 0.0913853857491631, 0.021712760390073527, 0.083653045585379, 0.020093093589821365, 0.05904135432501789, 0.05538934579817578, 0.009424831132491818, 0.0390610950125847, 0.032481569942319766, 0.029272957544890232, 0.0346254379110178, 0.10652212586137466, 0.001265439366306964, 0.010935758455161704, 0.04134039751079399, 0.05443105874292087, 0.08296092608361505, 0.06230572427739389, 0.04094932279258501, 0.0531079393113032, 0.05694718798622489, 0.020274103408155497, 0.08863451890647411, 0.058777632148121484, 0.011146033939439803, 0.05612720386125147, 0.09423287279787473, 0.032343103739549406, 0.021891380492888857, 0.07394973930786364, 0.457332861260511, 15.488763079047203, 55.073921754956245, 52.1029257774353, 32.56354585289955, 40.40707357227802, 66.41610413789749, 59.84719902276993, 11.779403071850538, 0.32896069809794426, 0.12218349758768454, 0.24841895821737126, 0.37003201141487807, 1.0600430122576654, 0.5743242788594216, 0.34296763711608946, 0.05789869923319202, 1.7011830839328468, 10.108831264078617, 23.778801038861275, 41.02180078625679, 56.58005453646183, 63.444959968328476, 69.29884225130081, 69.86983001232147, 68.82028833031654, 68.09052988886833, 68.89234006404877, 68.65103781223297, 69.27161291241646, 67.72842451930046, 67.49602138996124, 63.194640800356865, 63.19222413003445, 64.76687103509903, 65.30936792492867, 64.07075598835945, 63.790771812200546, 62.724685817956924, 62.242324501276016, 56.950910836458206, 57.91174627840519, 63.748400285840034, 68.08109119534492, 70.52603960037231, 67.91780635714531, 61.835738718509674, 55.205455496907234, 28.09133592993021, 36.6276253759861, 56.747222766280174, 59.83916625380516, 66.28462359309196, 68.98953884840012, 65.01726239919662, 63.56027618050575, 57.45022304356098, 56.06007143855095, 50.59265121817589, 51.628684625029564, 56.76017627120018, 65.6898795068264, 67.54801779985428, 65.27122557163239, 65.19921943545341, 63.922168761491776, 63.61198000609875, 65.38752973079681, 65.22280856966972, 65.97844362258911, 65.11633068323135, 64.95788678526878, 62.245102152228355, 66.18547171354294, 66.7582605779171, 65.46351045370102, 64.80507418513298, 63.448698967695236, 63.31113114953041, 67.36957177519798, 54.02229778468609, 20.129621252417564, 2.1896783402189612, 0.5627135268878192, 0.9421982732601464, 4.347272627055645, 4.761667940765619, 6.244552619755268, 5.004326719790697, 6.972054457291961, 1.3862559827975929, 0.7137432508170605, 0.04671173584938515, 2.4179380293935537, 32.3265715688467, 59.250809624791145, 35.589072704315186, 23.401469886302948, 35.04925847053528, 42.445044815540314, 15.771584752947092, 0.4854455339955166, 0.08471269145957194, 0.06544371761265211, 0.042296792089473456, 0.04777285117597785, 0.017317307283519767, 0.04970520705683157, 0.014268829945649486, 0.010876976648432901, 0.02551541561842896, 0.02934607950010104, 0.03445883317908738, 0.0216458836075617, 0.09802184096770361, 0.02101811387547059, 0.05754469850216992, 0.04194770808680914, 0.039520417631138116, 0.07702180024352856, 0.07821023100405, 0.017198539535456803, 0.1076623318658676, 0.040567543474026024, 0.04443055942829233, 0.03725770584424026, 0.05583063422818668, 0.011081158172601135, 0.01861362219642615, 0.05253687151707709, 0.04852347046835348, 0.0064336568721046206, 0.05273867631331086, 0.0075788719095726265, 0.07264161497005261, 0.13822892331518233, 0.09137462460785173, 0.13211174140451476, 0.146449277526699, 0.1302300111274235, 0.10177392439800315, 0.1676435160334222, 0.08535717250197195, 0.11660042451694608, 0.11933886038605124, 0.1313913386547938, 0.18081991758663207, 0.08881267145625316, 0.19321590632898733, 0.09956809823052026, 0.1727110191131942, 0.08815458684694022, 0.12160031794337556, 0.13140566210495308, 0.13381857716012746, 0.07224512257380411, 0.10143900799448602, 0.24059502960881218, 0.08502233773469925, 0.10809389073983766, 0.15602880099322647, 0.10288071149261668, 0.20313917775638402, 0.1463729699025862, 0.0973171197983902, 0.18958595814183354, 0.09703705552965403, 0.10947069342364557, 0.22235050157178193, 0.13117102469550446, 0.0648170555359684, 0.2105612779268995, 0.33535907976329327, 0.17696514318231493, 0.22397645807359368, 0.17628186265937984, 0.5497554503381252, 14.948616363108158, 65.57213142514229, 62.2516568005085, 42.992572635412216, 42.92189262807369, 55.634163692593575, 65.15653252601624, 21.599844060838223, 0.9713332692626864, 0.18789350520819426, 0.7425245095510036, 2.4368004547432065, 3.4651262126863003, 0.8083449339028448, 0.38353556650690734, 0.23677106917602941, 1.7992992815561593, 7.544511314481497, 20.541864931583405, 38.390491381287575, 55.71208991110325, 65.00105246901512, 70.28397738933563, 72.20913648605347, 73.34560990333557, 72.88944438099861, 72.17489272356033, 73.42695593833923, 71.16216346621513, 70.41356563568115, 70.12918889522552, 64.34225901961327, 64.52582716941833, 68.24166297912598, 68.61743241548538, 66.90302520990372, 67.37405553460121, 66.05958446860313, 68.5452438890934, 62.103894129395485, 63.158941715955734, 70.48601254820824, 72.37711787223816, 74.88171547651291, 73.6848708987236, 68.79432812333107, 53.92667971551418, 36.703039929270744, 44.93508540093899, 55.92020854353905, 62.460227608680725, 64.7555248439312, 71.65281593799591, 68.89826014637947, 66.35074764490128, 60.527157336473465, 60.51228113472462, 54.559710547327995, 53.93628939986229, 58.88066008687019, 68.47765311598778, 72.91744127869606, 66.62754759192467, 64.62396830320358, 65.72868302464485, 63.85548993945122, 65.4448002576828, 65.94100803136826, 67.88252145051956, 67.23267272114754, 66.38260513544083, 64.03714299201965, 67.55800366401672, 67.0486181974411, 64.80613052845001, 65.29772534966469, 62.29809030890465, 65.48826232552528, 67.22762659192085, 51.3151216506958, 15.04655135795474, 1.565555774141103, 0.887234341353178, 0.6067082192748785, 6.653910828754306, 4.728502370417118, 14.451911766082048, 21.41264520585537, 12.288462705910206, 2.3457732517272234, 1.6685237176716328, 0.2112616872182116, 7.439883928745985, 43.660869374871254, 61.70409098267555, 35.56968614459038, 33.903198167681694, 45.53866021335125, 49.94461879134178, 14.416297227144241, 0.35061941714957356, 0.31667316681705415, 0.21650561364367604, 0.1517776306718588, 0.11362638644641265, 0.1274044025922194, 0.23547104909084737, 0.19961725658504292, 0.15399466326925904, 0.1258096459787339, 0.15242974099237472, 0.10921215143753216, 0.1486804406158626, 0.19405468163313344, 0.20642595685785636, 0.08366112015210092, 0.089282213448314, 0.19449165818514302, 0.11363762998371385, 0.1438825746299699, 0.11061920406064019, 0.17225390067324042, 0.1527686946792528, 0.1742949997424148, 0.11492982041090727, 0.16560050222324207, 0.12899342982564121, 0.16437278216471896, 0.12750122317811474, 0.12486288818763569, 0.272962479502894, 0.1265391771448776, 0.12255258247023448, 0.22005382168572396], [0.03162867527862545, 0.0064047534669953166, 0.04458213195903227, 0.013446294688037597, 0.02654973755852552, 0.00397806925320765, 0.050320933587499894, 0.03707823598233517, 0.02092883350996999, 0.05241327053226996, 0.06399080026312731, 0.010677867703634547, 0.041989090241258964, 0.061576764564961195, 0.013519204203475965, 0.08776086266152561, 0.03960217261919752, 0.022127385309431702, 0.08140404126606882, 0.11052398651372641, 0.013087248280498898, 0.04193466855213046, 0.032766306030680425, 0.027220371885050554, 0.027768130676122382, 0.02584843954537064, 0.036561909000738524, 0.01715296424663393, 0.07942963158711791, 0.08618815525551327, 0.0194484270105022, 0.020769531511177775, 0.058036048503709026, 0.027954203796980437, 0.006572719576070085, 0.01771361228747992, 0.059631372860167176, 0.02552444755565375, 0.02822720467520412, 0.030090282925812062, 0.057512730490998365, 0.02313356686499901, 0.08541068877093494, 5.172157539054751, 35.92589423060417, 50.914003774523735, 32.78867997229099, 32.47627213597298, 37.23420962691307, 53.28329063951969, 32.71000899374485, 3.0819690227508545, 0.0958431328763254, 0.10612840167596005, 0.6549800571519881, 0.8240448602009565, 0.12621184549061581, 0.05113049795909319, 0.06079457431042101, 0.179508839501068, 0.18754497781628743, 3.2851179968565702, 13.926265072077513, 31.427971087396145, 55.120055079460144, 66.6766257584095, 68.28868925571442, 67.82116994261742, 66.94677606225014, 70.45884400606155, 68.18998575210571, 68.54924887418747, 69.32658836245537, 65.14759540557861, 67.77485802769661, 68.22241321206093, 68.58258068561554, 67.23819762468338, 61.95228226482868, 62.94450402259827, 63.38699407875538, 60.342054069042206, 59.596123695373535, 63.244068548083305, 64.21419069170952, 70.86390987038612, 54.593084156513214, 64.87049907445908, 43.78215126693249, 41.469507962465286, 46.773096174001694, 45.18535517156124, 71.69116348028183, 56.5470153093338, 61.82011395692825, 63.69569331407547, 69.01412352919579, 61.17695286870003, 59.867159351706505, 56.60340428352356, 54.592407792806625, 52.15186335146427, 61.319992393255234, 63.175106048583984, 70.23597076535225, 63.46194505691528, 66.17474108934402, 64.57457095384598, 68.64876553416252, 67.14188039302826, 67.12604284286499, 63.87886628508568, 65.82867085933685, 65.90272128582001, 67.69014537334442, 62.96029977500439, 64.11305531859398, 65.03219559788704, 63.60511377453804, 44.91450570523739, 20.1508317142725, 1.4624401135370135, 0.07532233401434496, 0.06168076542962808, 0.6423188396729529, 0.45722504204604775, 2.9236540803685784, 4.511248078197241, 1.77129763411358, 5.88092970661819, 2.988933390006423, 0.1861352237756364, 0.14334543782752007, 9.505229853093624, 41.0904973000288, 49.14052493870258, 24.557850435376167, 24.973101653158665, 34.48567271232605, 24.94095727801323, 3.9613902708515525, 0.09609843909856863, 0.03903674143657554, 0.07758937994367443, 0.06693340837955475, 0.025051666088984348, 0.038502884926856495, 0.03558590316970367, 0.024023850928642787, 0.02823559279931942, 0.03353385742229875, 0.021120806704857387, 0.058360845723655075, 0.03487799818685744, 0.03550331326550804, 0.07238211561343633, 0.01105074125007377, 0.052659084685728885, 0.06664031199761666, 0.03253525690524839, 0.058120738685829565, 0.028722411989292596, 0.0923897787288297, 0.02917803871241631, 0.037388680066214874, 0.053263189183780923, 0.0229737101108185, 0.01299283967455267, 0.06438332216930576, 0.04289995405997615, 0.026009005050582346, 0.058440637731109746, 0.022377800778485835, 0.03293981273600366, 0.020887961582047865, 0.048805891055963, 0.03198466125468258, 0.03144841131870635, 0.033911239515873604, 0.023896229358797427, 0.06786396508687176, 0.025910418153216597, 0.04035834688693285, 0.032452466621180065, 0.05401354872446973, 0.0399579916120274, 0.06642797612585127, 0.0368273640924599, 0.01388420727380435, 0.030374612688319758, 0.02509138583263848, 0.06958443409530446, 0.05727142117393669, 0.01411466917488724, 0.013036496511631412, 0.05064481796580367, 0.06362119587720372, 0.02374382191192126, 0.062772906239843, 0.08885413524694741, 0.01415400856785709, 0.029198100819485262, 0.011887609234690899, 0.0849748328619171, 0.05380507944209967, 0.006223353093446349, 0.02232183913292829, 0.0363452204328496, 0.06359649720252492, 0.05613034314592369, 0.1043615558592137, 0.10628870557411574, 0.013009294943913119, 0.038603412540396675, 0.011939921369048534, 0.07415418614982627, 0.019835564635286573, 0.0344269579363754, 0.13715852372115478, 10.749551933258772, 47.77800165116787, 51.622038781642914, 29.509913809597492, 28.950186744332314, 55.594482421875, 74.87082526087761, 28.58835306018591, 1.7107383836992085, 0.08014236795133911, 0.3708017966710031, 0.26272140559740365, 1.3511053752154112, 0.4655929055297747, 0.4010705271502957, 0.14741990278707817, 0.35887367266695946, 1.37305952841416, 5.432071192190051, 20.549823604524136, 40.651769042015076, 60.44971749186516, 69.70671996474266, 71.09844088554382, 70.20236536860466, 68.8981157541275, 72.86064192652702, 70.57110518217087, 69.77791294455528, 69.19743329286575, 66.67734771966934, 68.16917806863785, 69.82553958892822, 68.70703920722008, 66.41518458724022, 64.97197642922401, 63.99187982082367, 64.42805081605911, 62.32309676706791, 61.932561323046684, 68.05440902709961, 63.90738755464554, 74.6110711991787, 60.645931363105774, 66.47281229496002, 49.900210574269295, 43.44204671680927, 46.533085852861404, 53.18714439868927, 69.58654001355171, 60.702407732605934, 67.1032364666462, 67.66198128461838, 69.14723798632622, 64.46357890963554, 62.18932494521141, 58.51741477847099, 54.93488721549511, 54.072356298565865, 64.57929790019989, 65.6998273730278, 70.06378680467606, 65.00299796462059, 67.74888262152672, 64.77531418204308, 69.947969019413, 65.36923751235008, 68.85153785347939, 64.61723506450653, 68.60627621412277, 66.1030313372612, 68.5202032327652, 62.588976100087166, 64.705451130867, 64.91114929318428, 63.409937247633934, 52.26993441581726, 25.75601164251566, 3.8474493473768234, 0.4498692008201033, 0.213291757972911, 2.9387525701895356, 1.4123104722239077, 4.980814531445503, 5.580356335267425, 1.3613262330181897, 2.69951194524765, 1.7007553693838418, 0.33150038681924343, 0.1087938918499276, 5.426041390746832, 43.31356041133404, 56.29707232117653, 32.738929241895676, 24.67851486057043, 34.95665743947029, 33.88430938124657, 8.80268270149827, 0.07730943441856652, 0.12803789984900504, 0.10069359486806206, 0.011849123311549192, 0.05994724946503993, 0.02385376181337051, 0.07412098988424987, 0.0053252184989105444, 0.06466705264756456, 0.02591013613709947, 0.032071848763735034, 0.11799317595432512, 0.03817878903646488, 0.059750695363618433, 0.025344064852106385, 0.02704660171730211, 0.03741822867596056, 0.01652359147556126, 0.06211240965058096, 0.05956593398877885, 0.018090929443133064, 0.07414540654281154, 0.004845588400712586, 0.020098312743357383, 0.08341113512869924, 0.0065493776401126524, 0.05819096440973226, 0.07456937324604951, 0.04768026454257779, 0.07691930964938365, 0.019399224474909715, 0.05914960398513358, 0.027610149700194597, 0.03439388412516564, 0.05259591307549272, 0.12430914212018251, 0.10205772909102961, 0.20090694597456604, 0.09648927632952109, 0.14130828698398545, 0.06028978401445784, 0.24756392987910658, 0.1219916895206552, 0.1200693563441746, 0.1897289848420769, 0.12191288085887209, 0.12187460830318742, 0.14156747463857755, 0.19841911853291094, 0.11461820002296008, 0.11608949294895865, 0.15252930752467364, 0.14374934427905828, 0.1896236147149466, 0.18713514902628958, 0.1651392425992526, 0.13149856415111572, 0.12349341792287305, 0.10472347159520723, 0.144265255657956, 0.21531798440264538, 0.10978350124787539, 0.13771348691079766, 0.1597437250893563, 0.1864238450070843, 0.09543173815472983, 0.13889599533285946, 0.1965885073877871, 0.15473526727873832, 0.14438499376410618, 0.20485990651650354, 0.17080659396015108, 0.10742263300926425, 0.11278341058641672, 0.15549987234408036, 0.2893837436567992, 0.11140080430777743, 0.18612133077112958, 9.264611564576626, 54.452100321650505, 66.87974005937576, 45.20522050559521, 42.039139196276665, 47.61885479092598, 67.17027246952057, 41.42133794724941, 4.9529501516371965, 0.3048395033692941, 1.1059641418978572, 2.132242522202432, 2.3546661995351315, 0.4234799137338996, 0.6194322521332651, 0.20546784420730546, 0.5298108549322933, 1.0890276194550097, 4.3832965940237045, 17.218451164662838, 37.136319279670715, 59.11638803780079, 71.56124845147133, 71.97270557284355, 71.79508030414581, 70.43507248163223, 74.60484713315964, 74.96435344219208, 73.42756390571594, 75.1988996565342, 70.27459189295769, 72.56080001592636, 71.67322844266891, 74.09976303577423, 69.29470807313919, 66.75002261996269, 65.90987250208855, 68.27573955059052, 62.855208814144135, 66.04066908359528, 67.1242493391037, 68.15185859799385, 71.75079748034477, 62.2989908605814, 66.15553691983223, 58.44923883676529, 47.81930923461914, 52.847381830215454, 55.81596113741398, 71.60000637173653, 67.511767745018, 66.0834851861, 69.71702501177788, 71.34788230061531, 68.06993499398232, 64.13797438144684, 62.059869691729546, 57.26455360651016, 55.03928281366825, 62.47661992907524, 67.70493417978287, 70.91432556509972, 65.52131295204163, 68.12509283423424, 64.09127488732338, 69.2446419596672, 67.51537755131721, 70.00712424516678, 66.08970165252686, 71.33087441325188, 67.95984730124474, 70.61232537031174, 63.47034640610218, 64.79459434747696, 65.31249895691872, 63.98441702127457, 46.947928592562675, 22.50548556447029, 2.098541655577719, 0.5549120111390948, 0.2875010931165889, 1.880295379087329, 1.4029414812102914, 9.159701094031334, 11.779968291521072, 6.094057420268655, 16.473898217082024, 7.163448287174106, 0.4723257286241278, 0.5082809727173299, 13.989764414727688, 51.7986761033535, 59.250775426626205, 36.2310216575861, 34.975474029779434, 47.96468943357468, 39.94711585342884, 7.192043177783489, 0.1543642082833685, 0.22123520204331726, 0.11298504468868487, 0.16789320419775322, 0.12750172783853486, 0.0812469731317833, 0.16826837469125167, 0.101718537916895, 0.22423398331739008, 0.10159201658098027, 0.12918012449517846, 0.30110617401078343, 0.1292382346582599, 0.12968769413419068, 0.35085138282738626, 0.08285215692012571, 0.08155380666721612, 0.18128276540664956, 0.19631279952591285, 0.16916251421207562, 0.07654254353838041, 0.23284096678253263, 0.15431325242388994, 0.13796909741358832, 0.2093836825224571, 0.07057729410007596, 0.1494085171725601, 0.19576148770283908, 0.15118869196157902, 0.09036503659444861, 0.10114469449035823, 0.16886580357095227, 0.22441447363235056, 0.10093541626702063, 0.16906320000998676], [0.07597188392537646, 0.05833913790411316, 0.025641265310696326, 0.013298542362463195, 0.034830322620109655, 0.047215034428518265, 0.029822714568581432, 0.02471076797519345, 0.054917592206038535, 0.014261772121244576, 0.03943218369386159, 0.025670995746622793, 0.02262779322336428, 0.0377619506616611, 0.11687381687806919, 0.0324287550029112, 0.06583638052688912, 0.01929728121467633, 0.05141963127243798, 0.06025012735335622, 0.028506085218396038, 0.006109233045208384, 0.02045061581156915, 0.045172154204919934, 0.015436553858307889, 0.008981589926406741, 0.023280113200598862, 0.017787476390367374, 0.07697612105403095, 0.015573928176308982, 0.013848443177266745, 0.04642603496904485, 0.043138283654116094, 0.008266272743640002, 0.026437500710017048, 0.0367976188135799, 0.03042170195840299, 0.05333740766218398, 0.034316941964789294, 0.0520411131583387, 0.07515636010793969, 0.009982316696550697, 0.06891541022923775, 0.24549508932977915, 3.543973881751299, 28.848905079066753, 51.778810769319534, 42.495167925953865, 25.380439795553684, 26.280442401766777, 45.63900902867317, 49.53009903430939, 11.270564775913954, 0.27099653030745685, 0.28845516848377883, 0.4716797632863745, 0.6016525905579329, 0.3648835251806304, 0.13847481168340892, 0.07280249032191932, 0.018727636488620192, 0.08425462307059206, 0.21590592863503844, 2.8635137574747205, 14.770489521324635, 41.54054135084152, 61.87416225671768, 71.22528567910194, 70.63804239034653, 68.10607865452766, 68.47212821245193, 68.6417207121849, 69.60738569498062, 65.96235528588295, 68.43454822897911, 69.35059547424316, 70.1184430718422, 70.01247435808182, 68.0226731300354, 69.53543275594711, 68.11025843024254, 67.97348856925964, 65.70778414607048, 67.28897050023079, 66.81359320878983, 72.89579004049301, 62.6148185133934, 61.975772604346275, 40.181882455945015, 30.194532573223114, 47.71794207394123, 39.32348191738129, 64.8054313659668, 68.65657791495323, 60.15095092356205, 65.23407876491547, 65.5014780163765, 67.29290708899498, 65.32821491360664, 65.59193596243858, 62.64284200966358, 62.1241470426321, 64.8098087310791, 68.40905159711838, 67.21707075834274, 68.23597088456154, 67.26117879152298, 65.72664633393288, 66.92973777651787, 70.66753640770912, 66.58988401293755, 68.08720126748085, 65.42333140969276, 67.08276316523552, 65.61341241002083, 65.91757088899612, 61.26343622803688, 52.08339482545853, 27.284846305847168, 4.0523899253457785, 0.13472423481289297, 0.13615148869575933, 0.08395496610319242, 0.44735192495863885, 2.9087106697261333, 2.114239800721407, 4.922265373170376, 4.888749746605754, 1.379944165237248, 0.9905692026950419, 0.03973400031100027, 0.3695407690247521, 18.687351644039154, 43.81641402840614, 36.609743535518646, 26.338239200413227, 28.086360096931458, 38.45222286880016, 23.960862569510937, 2.93394036591053, 0.08456060313619673, 0.02251752492156811, 0.05169773256056942, 0.11356672519468702, 0.03843878563202452, 0.021578606065304484, 0.03544256847817451, 0.041193133147316985, 0.08802340482361615, 0.0382102338335244, 0.04637794008885976, 0.053464222146430984, 0.07323711426579393, 0.018375138606643304, 0.048054874714580365, 0.07480621483409777, 0.03976061743742321, 0.052230820947443135, 0.02375641244725557, 0.0670988776255399, 0.020945440919604152, 0.0802900776034221, 0.049285281347692944, 0.09156352345598862, 0.12239076459081843, 0.06665668377536349, 0.004941800889355363, 0.016593527761870064, 0.04112769056519028, 0.020978542561351787, 0.032765537907835096, 0.06162761652376503, 0.03427478426601738, 0.04287307347112801, 0.05089549318654463, 0.054953007493168116, 0.04715655690233689, 0.05047629107139073, 0.006132732687547104, 0.036415342256077565, 0.032300563834724016, 0.029716134740738198, 0.022103528972365893, 0.012324692470429, 0.036870976400678046, 0.06256717548239976, 0.014900315982231405, 0.027521229276317172, 0.01860750689957058, 0.03084389307332458, 0.03846042665827554, 0.042094542004633695, 0.07865808001952246, 0.0473809712275397, 0.038120192766655236, 0.09515167388599366, 0.052203483937773854, 0.044788749582949094, 0.04317019229347352, 0.0445790038065752, 0.05033454086515121, 0.030757416170672514, 0.02893241009587655, 0.04538149922154844, 0.0352432276122272, 0.08568082310375758, 0.03996217732492369, 0.04363545580417849, 0.02879460069380002, 0.05793785865535028, 0.052668116622953676, 0.044300672452664, 0.02123446476616664, 0.047947968341759406, 0.0016512778847754817, 0.0022703624017594848, 0.0473184935253812, 0.061173633657745086, 0.03399980741960462, 0.2601615007733926, 6.917083756998181, 41.42495535314083, 55.1438570022583, 36.35369427502155, 20.06403297185898, 34.13153551518917, 73.65903228521347, 54.21937420964241, 6.0548093263059855, 0.1928124451660551, 0.2405096380971372, 0.18649994482984766, 0.5595877196174115, 0.6102402484975755, 0.2673121530096978, 0.19589247676776722, 0.11652226152364165, 0.5593611567746848, 0.591273803729564, 5.753300730139017, 21.89923569560051, 49.562306106090546, 65.87499037384987, 73.58740612864494, 69.74416315555573, 69.74841132760048, 68.94790828227997, 70.17876103520393, 68.9962188899517, 68.44032391905785, 69.39655780792236, 71.72727674245834, 71.41309440135956, 72.0280534029007, 68.13999563455582, 70.77656015753746, 66.63053423166275, 68.8684393465519, 66.30007356405258, 66.200100928545, 66.27817913889885, 71.01603090763092, 58.09205800294876, 65.34548118710518, 47.77518220245838, 33.31692762672901, 49.74001497030258, 45.887253507971764, 67.59920865297318, 68.80463317036629, 62.726676911115646, 67.30643436312675, 68.95932286977768, 68.41767713427544, 66.35140880942345, 65.59389665722847, 63.03797900676727, 63.19966413080692, 65.63269257545471, 68.40370908379555, 70.17104744911194, 70.23623675107956, 70.05486488342285, 65.78724548220634, 67.85368099808693, 69.4495801627636, 65.84606632590294, 69.51196521520615, 65.94932198524475, 69.71452474594116, 64.78458568453789, 66.17324396967888, 64.43594679236412, 55.98643518984318, 32.46958069503307, 7.839586855843663, 0.49849762581288815, 0.38624324777629226, 0.6131624698173255, 2.0479388209059834, 5.988925136625767, 3.535844455473125, 3.1121360789984465, 1.9028654554858804, 1.8429438583552837, 0.7759402133524418, 0.3487755067180842, 0.010963062995870132, 15.374583955854177, 58.5094428062439, 53.64379249513149, 33.38142156600952, 27.512083612382412, 42.769213020801544, 32.57766969501972, 6.217983970418572, 0.05140372704772744, 0.06831959923147224, 0.08705045664100908, 0.09170967459795065, 0.06231905324966647, 0.02430690234177746, 0.06664046042715199, 0.06503849013824947, 0.02904039814893622, 0.03366206343343947, 0.024097926543618087, 0.05725310868001543, 0.10686821900890209, 0.09192353929392993, 0.024581281759310514, 0.02748605333181331, 0.024556048738304526, 0.06048613031452987, 0.0868040784553159, 0.025972411604016088, 0.013900258072681027, 0.07268095621839166, 0.11455589672550559, 0.04361194085504394, 0.08853107094182633, 0.01427862258424284, 0.018603417665872257, 0.02253741262393305, 0.05895327252801508, 0.036413895068108104, 0.04922465159324929, 0.007858778935769806, 0.02781467261229409, 0.011907331809197785, 0.061923848479636945, 0.012910647747048642, 0.17147071223007515, 0.09300107834860682, 0.12227064798935317, 0.07256711818627082, 0.13628525339299813, 0.10384131033788435, 0.08165018938598223, 0.1712900586426258, 0.2285137856961228, 0.07006378727965057, 0.07629865896888077, 0.13280104816658422, 0.0509986776887672, 0.16143769200425595, 0.15402341407025233, 0.1909721564152278, 0.20893055683700368, 0.16504721628734842, 0.1605631154961884, 0.20160023064818233, 0.12261925701750442, 0.11287882109172642, 0.16603697411483154, 0.22646300902124494, 0.08756110619287938, 0.07060909512802027, 0.12330794779700227, 0.103931288322201, 0.22930013568839058, 0.19024134875508025, 0.19043761712964624, 0.16159274149686098, 0.09144798590568826, 0.1295939163537696, 0.12742411403451115, 0.1337674431852065, 0.16587153455475345, 0.14729505870491266, 0.12720215250737965, 0.19171972176991403, 0.10861145710805431, 0.1965135059435852, 0.14019377413205802, 0.3901939373463392, 5.674760844558477, 44.17405843734741, 69.50891017913818, 52.29857347905636, 34.636042043566704, 32.34861798584461, 58.06134805083275, 63.16187895834446, 15.712537821382284, 0.5959151359274983, 0.7855035876855254, 3.161714393645525, 1.8390737660229206, 0.790984615450725, 0.452191915246658, 0.22897991380887106, 0.46939246414694935, 0.5715884850360453, 0.6821313814725727, 4.571378901600838, 18.866717219352722, 46.22775323688984, 65.66833466291428, 77.54126876592636, 73.06084558367729, 73.09831157326698, 71.34852066636086, 70.77979758381844, 73.1957383453846, 70.22920712828636, 72.78835460543633, 71.9575747847557, 72.24902674555779, 73.27998742461205, 71.6747559607029, 75.81041604280472, 69.31265830993652, 72.72010266780853, 71.43033027648926, 72.82328233122826, 70.06765499711037, 73.22419121861458, 65.05237251520157, 66.58711776137352, 49.48520824313164, 37.82349340617657, 51.67805917561054, 52.3528041690588, 64.05045747756958, 72.80596286058426, 64.95398059487343, 68.93648609519005, 71.34019151329994, 72.18325987458229, 72.67241522669792, 70.4492761194706, 66.48437887430191, 66.8665699660778, 71.8076728284359, 71.71887159347534, 73.37939009070396, 72.51790031790733, 72.54738673567772, 67.24639758467674, 64.45904195308685, 67.6359298825264, 64.89509135484695, 67.09082633256912, 65.74840396642685, 68.1687068939209, 65.30062839388847, 66.05539709329605, 63.69308665394783, 53.44347104430199, 29.74244613200426, 5.393000738695264, 0.22171272954437882, 0.40996181254740804, 0.21038859500549734, 1.6886435193009675, 9.794829413294792, 8.581702709197998, 15.253780838102102, 8.666942585259676, 8.905581180006266, 2.7520096907392144, 0.3214918723097071, 0.8090613142121583, 27.482031024992466, 53.59147310256958, 49.512851759791374, 39.03693929314613, 38.58029119670391, 53.81879970431328, 35.24252749979496, 4.948246954008937, 0.19609477138146758, 0.13344244187464938, 0.1802321069408208, 0.22685489268042147, 0.14605706732254475, 0.2632514474680647, 0.16133699740748852, 0.15973204368492588, 0.1575047694495879, 0.13340497825993225, 0.13976703921798617, 0.20175964396912605, 0.16325948643498123, 0.12082331159035675, 0.1886357567855157, 0.09498798579443246, 0.12170183632406406, 0.11911925888853148, 0.0892289866169449, 0.1407500435016118, 0.11421156246797182, 0.19283099885797128, 0.15022431558463722, 0.14832487766398117, 0.20525385334622115, 0.13860305480193347, 0.12055565603077412, 0.15515426901401952, 0.11546607405762188, 0.11077788265538402, 0.15283743239706382, 0.09694117004983127, 0.09318800308392383, 0.18068993784254417, 0.14111259748460725, 0.12819686788134277], [0.027547171048354357, 0.011625762836047215, 0.026253034338878933, 0.04575468075927347, 0.043961703922832385, 0.0068405323781917104, 0.018595654801174533, 0.053458325783140026, 0.034839169020415284, 0.056311438311240636, 0.020027031314384658, 0.09753044272656552, 0.024202413515013177, 0.027738788012356963, 0.05444140057079494, 0.047009214613353834, 0.024749654658080544, 0.04279202352336142, 0.04902777094685007, 0.03493511016131379, 0.0413009783369489, 0.04415806135511957, 0.008939284725784091, 0.034312949210288934, 0.03154866804834455, 0.028351011605991516, 0.05967434321064502, 0.04525949014350772, 0.06834221247117966, 0.04610352356394287, 0.027087980161013547, 0.09988699166569859, 0.015747820798424073, 0.02592758773971582, 0.01359236697680899, 0.01644987023610156, 0.07508365932153538, 0.0527445763873402, 0.04750529951706994, 0.06380369741236791, 0.03828230379440356, 0.0388924493745435, 0.04750531064928509, 0.028670255705947056, 0.09921039047185332, 1.1621576640754938, 16.30023803561926, 46.688261926174164, 46.82993732392788, 36.426217183470726, 26.079195700585842, 37.00963407754898, 61.3766435533762, 30.439395233988762, 1.8046368076466024, 0.11681828196742572, 1.0211810725741088, 0.7755329820793122, 0.451288721524179, 0.1617369259474799, 0.15348449611337855, 0.16563253331696615, 0.09955537039786577, 0.08275126194348559, 0.5756818153895438, 5.372134633362293, 23.241559267044067, 43.951063603162766, 62.74921350181103, 69.00601476430893, 69.91000905632973, 70.81860110163689, 74.92444038391113, 74.89181533455849, 73.46553906798363, 69.73126664757729, 68.2501669228077, 69.70633238554001, 70.92881038784981, 63.90129268169403, 65.42498052120209, 65.05779102444649, 69.76887702941895, 65.0411631166935, 67.74642795324326, 64.80306029319763, 71.00607544183731, 50.472406670451164, 35.71932591497898, 30.309793688356876, 46.52661480009556, 37.7873345464468, 69.053063839674, 73.31867694854736, 69.01495188474655, 68.13778415322304, 63.68805572390556, 64.65087845921516, 67.81360074877739, 66.52037054300308, 67.55581498146057, 66.11946925520897, 66.28675147891045, 67.58054405450821, 70.38825899362564, 69.1764584183693, 72.60374531149864, 70.28868913650513, 72.5581705570221, 70.16258150339127, 72.3190949857235, 71.66959583759308, 66.84459954500198, 60.0973130017519, 62.85052366554737, 51.47412791848183, 33.04048106074333, 12.976212501525879, 1.2638484011404216, 0.08433846349362284, 0.09948378283297643, 0.17561579996254295, 1.4936617319472134, 0.9669534105341882, 5.801869723945856, 0.7274522027000785, 2.7235907781869173, 2.5139351282268763, 0.10102516418555751, 0.17308385926298797, 4.221534049138427, 31.971089243888855, 41.93765804171562, 22.271532118320465, 21.538446955382824, 33.13686668872833, 38.809741884469986, 17.332076467573643, 0.7168289227411151, 0.11875808530021459, 0.018188954163633753, 0.10609024786390364, 0.0357141945278272, 0.04297780535125639, 0.06781958465580828, 0.03697807573189493, 0.05466939946927596, 0.04691141439252533, 0.04784007491252851, 0.10714274685597047, 0.042706795284175314, 0.07655875204363838, 0.05687073935405351, 0.08373144606593996, 0.03351690676936414, 0.07321803364902735, 0.04288362310035154, 0.053222612259560265, 0.04981230267731007, 0.10163477913010865, 0.029952000404591672, 0.04481521085835993, 0.008424284333159449, 0.049636680851108395, 0.01113403712224681, 0.03570333690731786, 0.012440249502105871, 0.045431048711179756, 0.02838303342286963, 0.015101546541700372, 0.07406293909298256, 0.03839477627479937, 0.027093431235698517, 0.04302860164898448, 0.026746748080768157, 0.020542705206025857, 0.04941272294672672, 0.027771967579610646, 0.06372157877194695, 0.00833114851047867, 0.040030985546763986, 0.04811774575500749, 0.06668272573733702, 0.040408282293356024, 0.056623633863637224, 0.06398837344022468, 0.027086438349215314, 0.008106082023005001, 0.0064337250569224125, 0.007394995545837446, 0.05532267125090584, 0.033410519899916835, 0.01859520394646097, 0.025069737384910695, 0.054314530425472185, 0.04277040847227909, 0.054914208012633026, 0.02381245943979593, 0.03869700107316021, 0.050972620883840136, 0.04332539392635226, 0.009786277460079873, 0.01805838997825049, 0.056993635298567824, 0.04234895022818819, 0.07658806687686592, 0.0489180778095033, 0.025992271475843154, 0.09779377156519331, 0.02918546389992116, 0.038450819556601346, 0.024504565953975543, 0.03349908409290947, 0.04087554960278794, 0.015050133333716076, 0.03517359189572744, 0.025467730774835218, 0.023882510758994613, 0.058996510051656514, 0.07003790116868913, 0.0365039287135005, 2.8602445079013705, 29.389853551983833, 54.92204390466213, 37.763346433639526, 21.7055144906044, 24.45493295788765, 59.270857349038124, 76.51865243911743, 22.2571137920022, 0.6518121552653611, 0.10618487911415286, 0.6142770568840206, 0.5947290058247745, 1.1175405769608915, 1.2922337092459202, 1.6840148926712573, 1.465111488942057, 0.06364579065120779, 0.16377968742744997, 1.1530306725762784, 8.898867890238762, 30.52652645856142, 51.527986228466034, 67.85750359296799, 70.95679208636284, 72.26411953568459, 72.13160544633865, 74.11487862467766, 73.17450508475304, 72.48671919107437, 68.19380834698677, 68.43223035335541, 69.98079925775528, 70.08421450853348, 66.35150760412216, 68.15125063061714, 69.61253061890602, 74.05415028333664, 68.2868729531765, 67.56108909845352, 67.0650789141655, 72.82376870512962, 58.22159305214882, 42.329280227422714, 34.197697564959526, 53.51670831441879, 46.28656268119812, 66.55575424432755, 76.51207879185677, 68.81401106715202, 70.88392719626427, 68.43457102775574, 71.2258480489254, 70.9391838312149, 71.21391668915749, 71.3099679350853, 70.14652356505394, 68.87939035892487, 68.4003272652626, 70.75145110487938, 70.24781093001366, 72.70342916250229, 71.27778366208076, 70.4703725874424, 72.3337621986866, 72.18794882297516, 72.82333552837372, 67.85624966025352, 63.28025780618191, 66.18556290864944, 57.09428854286671, 39.56580251455307, 18.849099464714527, 2.9971276503056288, 0.28342990844976157, 0.5777854181360453, 1.2915505771525204, 4.275073651224375, 4.748654589056969, 5.310002267360687, 2.696857787668705, 1.1127307475544512, 0.5782030988484621, 0.3054258297197521, 0.15349004737799987, 1.081904664169997, 32.37162575125694, 63.27611222863197, 30.72470862418413, 22.35399529337883, 34.705312326550484, 45.8977485448122, 25.134532190859318, 2.200833591632545, 0.06719461467582732, 0.06456602408434264, 0.06677227327600121, 0.05289600791002158, 0.02610859570268076, 0.009809104067244334, 0.02899272814829601, 0.01248605392902391, 0.05494232798810117, 0.02305138699739473, 0.06293427883065306, 0.02849826298188418, 0.09348066902020946, 0.040939381724456325, 0.051041061742580496, 0.04085654320078902, 0.0750146247446537, 0.04228140736813657, 0.009873454764601775, 0.029974073731864337, 0.08017143787583336, 0.044234276210772805, 0.006068375496397493, 0.07818987389327958, 0.020802236103918403, 0.06627508628298528, 0.04048802606121171, 0.07065573910949752, 0.03190403804183006, 0.027148188746650703, 0.017920608406711835, 0.05163000416359864, 0.010144107673113467, 0.03126956486084964, 0.053108347492525354, 0.05280136923829559, 0.017359385201416444, 0.08646896167192608, 0.11729217294487171, 0.14153614116366953, 0.20824433740926906, 0.17988954641623423, 0.1164089133089874, 0.15297882637241855, 0.14195915049640462, 0.14888021192746237, 0.12284519645618275, 0.21871469041798264, 0.18105456983903423, 0.15564123663352802, 0.11231478885747492, 0.1639769205939956, 0.11018702178262174, 0.12083411726052873, 0.13776496227364987, 0.20406346331583336, 0.11455273517640308, 0.25934798817615956, 0.10309218647307716, 0.10855857166461647, 0.15349027002230287, 0.12179759563878179, 0.21293092577252537, 0.09051980407093652, 0.27475096634589136, 0.20872164226602763, 0.15254933066898957, 0.11881039928994142, 0.2301646932028234, 0.13736418768530712, 0.12085376190952957, 0.07215207209810615, 0.14029193058377132, 0.12510825705248863, 0.1608826545998454, 0.12113470933400095, 0.15949924680171534, 0.15802041365532205, 0.1889880542876199, 0.14158607285935432, 0.16402716399170458, 0.17313548305537552, 2.05895917955786, 29.46483112871647, 70.08965581655502, 58.34865443408489, 46.29523381590843, 32.63156980276108, 49.55882169306278, 73.62131550908089, 38.58983248472214, 3.1351716304197907, 0.24530290276743472, 2.726065395399928, 2.6779910875484347, 1.4386142045259476, 0.7950096682179719, 0.8795151149388403, 1.2386951758526266, 0.22267148044193164, 0.1344513619551435, 1.2792923161759973, 6.8146854266524315, 26.294606141746044, 48.60336296260357, 65.65597772598267, 69.55640763044357, 73.1199400126934, 74.58529338240623, 76.41407445073128, 77.12623223662376, 78.36697205901146, 68.84791284799576, 69.83549505472183, 69.815234541893, 71.3591980934143, 67.72214725613594, 68.57704818248749, 70.66306784749031, 74.89392802119255, 70.24436071515083, 66.42718434333801, 66.2193962931633, 71.65384948253632, 57.63186849653721, 47.5106517970562, 37.10146375000477, 58.45716901123524, 51.0770758241415, 69.75148156285286, 74.12137627601624, 74.49720650911331, 70.61813145875931, 69.14578646421432, 72.74633646011353, 71.58144056797028, 72.05942451953888, 71.64538353681564, 72.13503286242485, 68.08503538370132, 70.88908731937408, 71.51321142911911, 69.5251353085041, 74.83293369412422, 71.8954785168171, 71.64147734642029, 73.01313534379005, 71.93014025688171, 72.2263191640377, 69.83234122395515, 61.22748635709286, 65.18886119127274, 55.22206820547581, 36.36075049638748, 16.33500996977091, 1.7953620990738273, 0.2562087628757581, 0.18677427229704335, 0.47027927124872804, 3.7491954071447253, 5.317115010693669, 12.216012943536043, 8.195168450474739, 8.043906167149544, 8.969982024282217, 0.35761029983405024, 0.3770611295476556, 6.079810559749603, 40.71443907916546, 55.87191313505173, 31.27681139856577, 31.442495808005333, 46.037045270204544, 51.881131678819656, 26.250351816415787, 1.4178707613609731, 0.2808297495357692, 0.1632649337989278, 0.2087532726000063, 0.12662470224313438, 0.1274320253287442, 0.15985041623935103, 0.1499955856706947, 0.1702133656363003, 0.14663393871160224, 0.10299426008714363, 0.15274349134415388, 0.11624345890595578, 0.1670047643710859, 0.12982049403944984, 0.17065262800315395, 0.1554461260093376, 0.15725453209597617, 0.17941754049388692, 0.1808880319003947, 0.26220555359032005, 0.2367964803124778, 0.10262780982884578, 0.13343125028768554, 0.17091911839088425, 0.0933144279406406, 0.16036496206652373, 0.11475595005322248, 0.19357731740456074, 0.12917408341309056, 0.19346189859788865, 0.04875355109106749, 0.19661661994177848, 0.08118933052173816, 0.08023799367947504, 0.10467716900166124, 0.1098217218532227, 0.18923646595794708], [0.02877059036109131, 0.0031754583415022353, 0.037296460795914754, 0.02985715207614703, 0.022528673835040536, 0.022774222670705058, 0.044639440602622926, 0.020840059660258703, 0.07674181761103682, 0.03100572394032497, 0.08054188088863157, 0.060587266489164904, 0.05604014622804243, 0.05409463577962015, 0.020331378655100707, 0.06308269352302887, 0.08898319472791627, 0.029538175149355084, 0.037083033967064694, 0.018146622060157824, 0.026660310140869115, 0.04284353228285909, 0.06162429912365042, 0.06437670221203007, 0.024111674829327967, 0.044343650224618614, 0.09514320598100312, 0.15907154709566385, 0.11219863532460295, 0.017552490171510726, 0.005942785091974656, 0.09603722675819881, 0.022037546477804426, 0.03494369680993259, 0.02783607615128858, 0.04981477031833492, 0.07764018737361766, 0.12406032969010994, 0.08282201830297709, 0.0466663757833885, 0.03152252218569629, 0.018567232400528155, 0.025832691171672195, 0.08580580077250488, 0.08049151132581756, 0.1181405145325698, 0.20935190375894308, 13.501440268009901, 50.407699942588806, 50.768509581685066, 52.8005987405777, 29.702821858227253, 25.805657878518105, 53.06967370212078, 50.275573432445526, 8.028668034821749, 0.0640210798883345, 0.2456116658868268, 1.7564841290004551, 1.8299685046076775, 2.3119849897921085, 1.1868513515219092, 0.2606653596740216, 0.26729567733127624, 0.05057909707829822, 0.14383365225512534, 0.9564049984328449, 7.0660528633743525, 23.315001726150513, 42.40657947957516, 53.99985998868942, 62.11987227201462, 68.20733562111855, 68.51954966783524, 65.87979331612587, 67.98060178756714, 69.69454541802406, 67.71067947149277, 72.27225869894028, 76.85001745820045, 73.79545256495476, 75.60807690024376, 71.19470492005348, 73.3064492046833, 70.2873820066452, 74.14652332663536, 75.20643845200539, 51.461022421717644, 45.13751953840256, 34.06919986009598, 30.706779286265373, 29.339576549828053, 61.08049124479294, 65.10880708694458, 68.02603214979172, 71.80635809898376, 67.37175285816193, 63.68901327252388, 71.72249659895897, 72.91132360696793, 71.62226557731628, 75.41399851441383, 75.15350729227066, 74.19129252433777, 70.25922551751137, 70.83017528057098, 70.72312742471695, 66.14749655127525, 60.45319050550461, 54.53614801168442, 51.11698128283024, 43.91219548881054, 34.80264410376549, 30.2300226688385, 24.681245014071465, 14.885981474071741, 3.1308633740991354, 0.15493474173126742, 0.5216404621023685, 0.11151072380016558, 3.2653569197282195, 2.052890667691827, 6.169207887724042, 6.884172772988677, 3.339395234361291, 2.939764503389597, 1.548691091593355, 0.3493045986397192, 0.23283952701603994, 15.204881262034178, 41.50957681238651, 31.052731722593307, 20.237033888697624, 28.348211646080017, 42.42467410862446, 36.98351427912712, 11.21084813028574, 0.08888747252058238, 0.13295768585521728, 0.08782859847997315, 0.04585550523188431, 0.058748714363900945, 0.03693183993163984, 0.052469102301984094, 0.0027016211697628023, 0.06571615260327235, 0.025273158207710367, 0.08631216813228093, 0.11948669620323926, 0.03866146333166398, 0.02669981466169702, 0.04616165599145461, 0.052839025811408646, 0.040774543303996325, 0.017288510098296683, 0.046567388126277365, 0.0670902909769211, 0.011899173750862246, 0.052855015383102, 0.02070623559120577, 0.030067241095821373, 0.043730836623581126, 0.055229468634934165, 0.020712141231342684, 0.014108218056207988, 0.021777117581223138, 0.053769478618050925, 0.020167351030977443, 0.08188221443560906, 0.007623005112691317, 0.07249489979585633, 0.025087673238886055, 0.04566384930512868, 0.05182134838833008, 0.07074412889778614, 0.023811787796148565, 0.027987105058855377, 0.036627618756028824, 0.027040295317419805, 0.028847074245277327, 0.01390174236803432, 0.024495355901308358, 0.018883045922848396, 0.08421748600085266, 0.08186825463781133, 0.03854575508739799, 0.07375014611170627, 0.09097125992411748, 0.053458771071746014, 0.006588319984075497, 0.027983982472505886, 0.03471690019068774, 0.0406094451318495, 0.027665519482980017, 0.050164210551884025, 0.03461885506112594, 0.04953223469783552, 0.03878754680044949, 0.0182921887608245, 0.052879350405419245, 0.12259092181921005, 0.13625825406052172, 0.02728768467932241, 0.07047317078104243, 0.049236292179557495, 0.04612103453837335, 0.03160893786116503, 0.046494735579472035, 0.08584750947193243, 0.08016455816687085, 0.023369527152681258, 0.0178840984517592, 0.06684742314973846, 0.1387919907574542, 0.07633247863850556, 0.0450929522048682, 0.040058515514829196, 0.026919442134385463, 0.061127694716560654, 0.003533038775458408, 0.09717485008877702, 0.0865213201905135, 0.9584631223697215, 25.481360480189323, 60.5399626493454, 50.111133456230164, 39.240395575761795, 21.67560439556837, 43.25474716722965, 76.70653715729713, 41.81372009217739, 2.8059504088014364, 0.15369682456366718, 0.24609937565401196, 0.1863421790767461, 2.163061718456447, 2.2913304856047034, 3.4953754395246506, 1.6585428407415748, 1.1018116772174835, 0.07710944046266377, 0.0731876798090525, 2.1159877069294453, 11.521821543574333, 31.16119310259819, 49.870986342430115, 61.21636815369129, 65.37913218140602, 69.8158349096775, 72.66173779964447, 70.93014791607857, 69.36714738607407, 71.56288236379623, 68.70419695973396, 73.93634900450706, 74.6708495914936, 71.04213550686836, 72.6375862956047, 70.0374162197113, 66.49898529052734, 67.23225474357605, 68.62494841217995, 73.83516043424606, 51.964377611875534, 50.039522498846054, 35.59572994709015, 36.84120051562786, 35.034994035959244, 59.21161472797394, 69.54987198114395, 68.81844162940979, 69.57671374082565, 67.5827707350254, 63.80461826920509, 72.35605180263519, 71.62463665008545, 72.47171759605408, 74.49810326099396, 75.28097525238991, 72.63533681631088, 72.86409214138985, 71.71315670013428, 72.81676948070526, 67.19865694642067, 64.76150572299957, 59.40568171441555, 54.41892810165882, 50.01779146492481, 42.31298290193081, 36.16736747324467, 31.493133790791035, 21.40166949480772, 5.649684090167284, 0.5954123754054308, 0.9206357959192246, 2.1035236632451415, 4.008607724681497, 3.118635155260563, 5.631430819630623, 7.08027882501483, 4.258328899741173, 0.7526237145066261, 0.6817207066342235, 0.29018639121204615, 0.19492318737320602, 12.242122292518616, 55.6918977946043, 51.33514277637005, 22.92264048010111, 19.152881763875484, 38.98710496723652, 45.473037734627724, 17.97873716801405, 0.46909456606954336, 0.18359715293627232, 0.04550413170363754, 0.11832971766125411, 0.04129224696953315, 0.06350985888275318, 0.030419700015045237, 0.027979319929727353, 0.026665542281989474, 0.07047226536087692, 0.07705171621637419, 0.03436282895563636, 0.00947185639233794, 0.03311511914944276, 0.017263369845750276, 0.0385486086452147, 0.03756447258638218, 0.09595705254469067, 0.02731498458160786, 0.03481312705844175, 0.031951516939443536, 0.05406371048593428, 0.029330089928407688, 0.07788246890413575, 0.04766894307977054, 0.09705088916234672, 0.04974725714419037, 0.02075418389722472, 0.008584407332818955, 0.08839415953843854, 0.12721043487545103, 0.12235266272909939, 0.018033618944173213, 0.009347482646262506, 0.005152334269951098, 0.004305177335481858, 0.05181030894163996, 0.019001659675268456, 0.03743710520211607, 0.16664675233187154, 0.08329397227498703, 0.129946302913595, 0.12995445169508457, 0.10944035442662425, 0.11263858788879588, 0.17900833510793746, 0.1651559557649307, 0.1991604795330204, 0.1280259364284575, 0.17170174280181527, 0.20467242517042905, 0.23573463025968522, 0.09824452979955822, 0.13366979139391333, 0.19827567622996867, 0.10609757286147214, 0.09658256429247558, 0.13119753421051428, 0.13132795924320817, 0.1596618810435757, 0.1746330183232203, 0.10357952516642399, 0.2224716349155642, 0.13912200898630545, 0.17488009412772954, 0.25233668158762157, 0.2711725380504504, 0.17721497977618128, 0.14673905650852248, 0.1712212763959542, 0.2881174616049975, 0.10493376656086184, 0.2975173556478694, 0.21254377701552585, 0.09450492929317988, 0.1615458822925575, 0.2391994060599245, 0.15748805628390983, 0.10342905472498387, 0.18667684315005317, 0.11967451151576824, 0.21544992341659963, 0.20500196842476726, 0.16313649772200733, 0.18132529046852142, 0.9381772577762604, 24.185069538652897, 70.97465112805367, 66.3686066865921, 63.4280850738287, 41.42536573112011, 35.535833761096, 66.32489383220673, 58.86733040213585, 10.597799476236105, 0.35739884711802006, 1.6810104413889349, 4.977983683347702, 5.224659321829677, 4.120498895645142, 4.462271556258202, 1.1541826045140624, 0.9042329073417932, 0.1879472960717976, 0.3920112788910046, 1.8247391539625823, 9.262351635843515, 27.00551189482212, 47.68096625804901, 56.719370260834694, 62.75269031524658, 69.75576013326645, 68.48785176873207, 65.17107054591179, 67.68107905983925, 70.2437299489975, 66.92745789885521, 73.47120836377144, 78.29615905880928, 73.49680379033089, 79.0264342725277, 73.79825681447983, 74.10096377134323, 72.7222153544426, 76.93784594535828, 81.33554756641388, 63.78659963607788, 59.434909746050835, 43.954639211297035, 42.71461375057697, 41.71298369765282, 61.00224204361439, 67.79060438275337, 68.70943307876587, 74.04798701405525, 68.91889303922653, 68.20844516158104, 75.10497629642487, 76.55902907252312, 77.09844052791595, 78.40416446328163, 81.09604641795158, 76.81091755628586, 73.87207925319672, 76.42478987574577, 72.95487686991692, 67.30927661061287, 61.49611294269562, 55.42717359960079, 49.73660655319691, 47.01861619949341, 37.15785652399063, 32.56271369755268, 26.249356269836426, 17.152528502047062, 3.759755278006196, 0.4114804248092696, 0.8281112357508391, 1.5423406823538244, 6.960840309038758, 6.193227348849177, 18.222355395555496, 19.883240573108196, 14.472870491445065, 11.065453682094812, 4.474850306287408, 0.9022675815504044, 0.36852527351584285, 20.40210273116827, 53.511179611086845, 41.652380749583244, 31.826634295284748, 39.47637811303139, 57.29177914559841, 50.40052592754364, 16.392656676471233, 0.3086276922840625, 0.3486576833529398, 0.17943094368092716, 0.19459040835499763, 0.1279699636506848, 0.20362872804980725, 0.23305097973207012, 0.2254588683717884, 0.1740592045825906, 0.2606491808546707, 0.13899346900871024, 0.14669283555122092, 0.1096915194648318, 0.09981536699342541, 0.1569917969754897, 0.16208198008826002, 0.23129394510760903, 0.22817079472588375, 0.12505093356594443, 0.1928045932436362, 0.12056618710630573, 0.15106022619875148, 0.17291021154960617, 0.1725059191812761, 0.12352619116427377, 0.20358004316221923, 0.1903832028619945, 0.10475389964994974, 0.1279243957833387, 0.16796443553175777, 0.1922987453872338, 0.2607491036178544, 0.09680535702500492, 0.14933777565602213, 0.16489621892105788, 0.12717561330646276, 0.13015324337175116, 0.14005929697304964, 0.11702756019076332], [0.014226695438992465, 0.06346308131469414, 0.0550595984532265, 0.03834373135759961, 0.04536284533969592, 0.08707115513971075, 0.04267877549864352, 0.04510634425969329, 0.02738448114541825, 0.10746857937192544, 0.03156030492391437, 0.07051413733279333, 0.030158753470459487, 0.063799341005506, 0.04662736479076557, 0.03707169023982715, 0.050347580399829894, 0.026783502944454085, 0.019440970281721093, 0.08321392422658391, 0.02175963258196134, 0.05167196519323625, 0.04577308602165431, 0.07461498564225622, 0.04175040070549585, 0.09441589383641258, 0.028956346213817596, 0.0697686499916017, 0.08691512601217255, 0.02564201487984974, 0.023170718777691945, 0.026026020641438663, 0.00270909784376272, 0.014250206677388633, 0.05760733205534052, 0.023442765996151138, 0.060493959972518496, 0.059826839715242386, 0.029633457634190563, 0.04734262445708737, 0.019648806883196812, 0.04338121827458963, 0.03905749930709135, 0.1332619070308283, 0.029814192857884336, 0.06794192027882673, 0.037397288979263976, 0.1026371237821877, 6.103293774649501, 38.10399055480957, 55.210197642445564, 41.21101163327694, 33.242660611867905, 24.912983179092407, 35.04966504871845, 56.696681678295135, 29.06244032084942, 1.741152664180845, 0.02182273739890661, 3.143159276805818, 5.388746866956353, 3.824318088591099, 2.5319302501156926, 1.1146245896816254, 0.21876693761441857, 0.03208605347026605, 0.18585294048534706, 0.0720346494927071, 0.3996049932902679, 5.419635409489274, 15.3865229152143, 26.205443926155567, 29.792848527431488, 25.634697452187538, 26.354411132633686, 28.817651756107807, 33.113630935549736, 32.03671932220459, 35.51978342235088, 41.04441337287426, 52.23121829330921, 59.41537119448185, 62.68074117600918, 55.86133070290089, 53.30852888524532, 48.596671521663666, 35.511363074183464, 23.771596625447273, 40.33512823283672, 69.4520652294159, 45.77045917510986, 50.403763353824615, 57.83870279788971, 70.39262115955353, 67.06884831190109, 66.31373003125191, 81.29317983984947, 69.43382620811462, 70.64989015460014, 73.42240378260612, 76.59123614430428, 73.19335967302322, 70.38044661283493, 70.10268151760101, 75.07575586438179, 68.12520682811737, 62.7381256967783, 46.446473300457, 36.103386506438255, 25.043014101684093, 18.925728052854538, 12.053022589534521, 6.705160103738308, 3.4920209320262074, 1.5166170126758516, 0.12049369412125088, 0.12102456719730981, 0.02433613182802219, 0.5257048190105706, 1.9675373914651573, 4.37781966291368, 2.777195214293897, 3.9561185287311673, 4.682467840611935, 1.633493397384882, 1.0742186265997589, 0.06564447598066181, 4.690156728029251, 31.226532496511936, 36.941404938697815, 18.498594872653484, 23.596080243587494, 37.491186037659645, 45.165885016322136, 27.530221939086914, 3.6384292133152485, 0.09079221679712646, 0.008747260508243926, 0.030893253315298352, 0.026237131969537586, 0.1030884386273101, 0.15954074769979343, 0.04996604970074259, 0.08400558057473972, 0.05183864042919595, 0.03512122595566325, 0.025166882660414558, 0.055893434764584526, 0.0324516836553812, 0.07120903246686794, 0.021177391754463315, 0.04485733144974802, 0.04486273057409562, 0.06346584952552803, 0.061091719107935205, 0.03847191510431003, 0.007011266234258073, 0.03490072274871636, 0.027710879548976664, 0.091486065502977, 0.020249968765710946, 0.051207688738941215, 0.018984671914950013, 0.01884060064185178, 0.029712312680203468, 0.01072228802513564, 0.04128407592361327, 0.057699992903508246, 0.0031598769510310376, 0.036225612202542834, 0.06493860448244959, 0.020504898348008282, 0.03560465724149253, 0.03024007244675886, 0.020574545196723193, 0.05656168308632914, 0.036827208241447806, 0.03915635708835907, 0.015542414730589371, 0.05389923942857422, 0.03709381366206799, 0.057829208235489205, 0.008778787869232474, 0.014661862078355625, 0.0635400420287624, 0.03314661960757803, 0.09251570634660311, 0.07599346557981335, 0.03738427913049236, 0.040282818517880514, 0.03225407941499725, 0.10601310903439298, 0.06126158557890449, 0.044513653992908075, 0.10026709744124673, 0.039675292719039135, 0.010660075640771538, 0.07420493420795538, 0.03474122779152822, 0.06799270544433966, 0.023536510379926767, 0.09318392127170227, 0.0335375421855133, 0.014582807580154622, 0.051545751848607324, 0.026375011875643395, 0.009826663281273795, 0.03391477213881444, 0.02394402923528105, 0.09591699883458205, 0.0458501061075367, 0.04926633802824654, 0.06105291220592335, 0.05495908568263985, 0.0243364175548777, 0.05679973808582872, 0.053195598084130324, 0.012307014512771275, 0.042942312138620764, 0.07639339411980473, 0.0468754350731615, 0.0653545708337333, 0.029531829786719754, 0.3534974658396095, 14.012840576469898, 54.07347343862057, 60.873371958732605, 38.05704027414322, 18.806644342839718, 34.217942878603935, 66.05890810489655, 67.10209652781487, 19.51521512120962, 0.8266607823316008, 0.09426241027540527, 1.099897411186248, 0.35432567296084017, 2.4866240937262774, 1.4835084392689168, 1.816191275138408, 1.8261184799484909, 0.046076776561676525, 0.316133625456132, 0.06692138558719307, 1.3886796589940786, 9.73016258329153, 22.601143531501293, 33.93992319703102, 37.583593279123306, 34.017423838377, 35.67429833114147, 37.63758838176727, 42.659125328063965, 39.67371292412281, 45.67562386393547, 51.18531681597233, 61.158204674720764, 68.28830167651176, 72.6081682741642, 68.10078173875809, 62.99859791994095, 63.385276570916176, 53.95232453942299, 39.51485864818096, 50.94434894621372, 67.8467957675457, 52.274140790104866, 56.95523880422115, 63.197806030511856, 70.9081394970417, 70.75381457805634, 69.69398304820061, 82.94913858175278, 70.37375897169113, 73.03968071937561, 77.34588325023651, 77.69088953733444, 76.16261154413223, 71.82352557778358, 72.0687948167324, 72.24493056535721, 71.17281049489975, 65.55500954389572, 52.82743290066719, 38.46759304404259, 29.12082228809595, 24.170782305300236, 15.83865875378251, 11.17746502161026, 6.972795892506838, 3.6302401777356863, 0.7984349469188601, 0.4687859513796866, 1.6243997728452086, 2.7446539979428053, 4.347557136788964, 4.528419831767678, 2.575861355289817, 2.371756020002067, 1.0703921131789684, 1.4704122045077384, 0.6770556257106364, 0.13469695346429944, 2.0209882920607924, 34.15907643735409, 56.99992060661316, 28.5159707441926, 15.138516873121262, 28.302232213318348, 45.42201407253742, 38.602865785360336, 7.328397436067462, 0.09076916569028981, 0.054756987738073803, 0.026316580733691808, 0.0979737943271175, 0.08123873529257253, 0.12633337959414348, 0.04794548585778102, 0.1307738124160096, 0.05360581650165841, 0.014367332423717016, 0.07329853440751322, 0.033136489291791804, 0.07648320141015574, 0.021825711555720773, 0.04024629000923596, 0.028855093150923494, 0.0580098506907234, 0.05087108023872133, 0.01208026520544081, 0.04304180074541364, 0.06966668632230721, 0.026636843431333546, 0.019706477323779836, 0.095106981752906, 0.04289453638193663, 0.093037777551217, 0.02267443349410314, 0.051502558853826486, 0.03631745668826625, 0.06544529838720337, 0.029044338953099214, 0.03414160215470474, 0.03528799396008253, 0.018053035382763483, 0.06707613822072744, 0.0271567327217781, 0.06475703063188121, 0.02202690222475212, 0.04172703789663501, 0.028448121629480738, 0.18034528446150944, 0.15252706623869017, 0.11558365993550979, 0.08638095780042931, 0.10643430752679706, 0.12311181300901808, 0.17733885906636715, 0.12384689543978311, 0.13417083013337106, 0.14834933885140345, 0.194160838436801, 0.1155259579536505, 0.12247862745425664, 0.16405983333243057, 0.15456475142855197, 0.19850281794788316, 0.11743679526261985, 0.13713621476199478, 0.1732144327252172, 0.15793407219462097, 0.09992006918764673, 0.19373270828509703, 0.11846778681501746, 0.13209112454205751, 0.13372598681598902, 0.15504454990150407, 0.15143783093662933, 0.13312646507984027, 0.15583012806018814, 0.12454116716980934, 0.226091890654061, 0.17793084058212116, 0.101317199296318, 0.18922730785561725, 0.16295835259370506, 0.06529170350404456, 0.24685562413651496, 0.16644289920805022, 0.10291812315699644, 0.22850456822197884, 0.27254414570052177, 0.32338241930119693, 0.18361833383096382, 0.18371380370808765, 0.1501742799882777, 0.26896313473116606, 0.159407606406603, 0.2532093581976369, 12.107984740287066, 60.02574764192104, 72.7028439939022, 55.07498949766159, 42.42906667292118, 35.5985189974308, 48.23798976838589, 68.9200709760189, 36.262970343232155, 2.7314950665459037, 0.20241129415808246, 7.270120438188314, 11.863877288997173, 11.522414311766624, 6.671682000160217, 4.108008965849876, 0.9995119040831923, 0.1481680024880916, 0.19150092179188505, 0.1734708744334057, 0.7073495001532137, 6.484982818365097, 17.77238544076681, 29.189796186983585, 33.05965103209019, 28.971967175602913, 31.94252997636795, 31.791797764599323, 37.63609126210213, 35.90138554573059, 39.66167517006397, 44.14122819900513, 56.50218531489372, 62.876442074775696, 68.0814103782177, 59.315447956323624, 54.84038628637791, 51.09950602054596, 45.30163273215294, 33.39877903461456, 57.115548402071, 76.08292981982231, 65.40042623877525, 67.34770774841309, 68.13429594039917, 72.6557569205761, 72.10244581103325, 70.17648875713348, 81.66769534349442, 72.23243683576584, 73.71976062655449, 74.59344774484634, 77.76102617383003, 75.97399726510048, 71.8691611289978, 70.0760069489479, 74.74714189767838, 68.8023228943348, 63.012957349419594, 49.51735831797123, 38.31857644021511, 27.412357963621616, 20.38917202502489, 14.268962033092976, 7.993192188441753, 5.208402369171381, 2.342724627815187, 0.5159592919517308, 0.3231292875716463, 1.047778814099729, 2.3615887155756354, 6.732113482430577, 11.615569163113832, 13.187400419265032, 13.895856253802776, 15.96693892031908, 5.965598188340664, 2.079478553496301, 0.20548105443594977, 6.892581721767783, 39.312101528048515, 49.26836907863617, 27.457881420850754, 32.777364179492, 49.10780109465122, 58.385048881173134, 41.0067155957222, 6.059784684330225, 0.18107545387465507, 0.1674565245048143, 0.13085239101201296, 0.17425361758796498, 0.21482996293343604, 0.23915322963148355, 0.16914833919145167, 0.15952091751387343, 0.12963638204382733, 0.13412349595455453, 0.14514047041302547, 0.14088195282965899, 0.21534621570026502, 0.22652687825029716, 0.12281181465368718, 0.1347327695111744, 0.1403920166194439, 0.16308601683704183, 0.12135638884501532, 0.09990188656956889, 0.15507591306231916, 0.1232324268494267, 0.20026308833621442, 0.20183843036647886, 0.12047205309499986, 0.13332677073776722, 0.12025306015857495, 0.23448345833458006, 0.25042431545443833, 0.21041672240244225, 0.1590554424910806, 0.15050640591653064, 0.10685604778700508, 0.10705008229706436, 0.16843010351294652, 0.07269450783496723, 0.17949619330465794, 0.16909307887544855, 0.15872897172812372, 0.18820136290742084], [0.06987502201809548, 0.05140738583577331, 0.06322214307147078, 0.09870849826256745, 0.02528041455661878, 0.0410122235189192, 0.11930961976759136, 0.04966964334016666, 0.017686137980490457, 0.0444570132822264, 0.06391225877450779, 0.057485178258502856, 0.0698098837165162, 0.04685539337515365, 0.06928361195605248, 0.05784958018921316, 0.09719718873384409, 0.08096291610854678, 0.03779037491767667, 0.04322513719671406, 0.06355413541314192, 0.045037795789539814, 0.08284295428893529, 0.05896502443647478, 0.016687277711753268, 0.05502675841853488, 0.03431358374655247, 0.03917326692317147, 0.05436192768684123, 0.07875240698922426, 0.023273450569831766, 0.025363286476931535, 0.03430587654293049, 0.04295377460948657, 0.03758639191801194, 0.037134308950044215, 0.03593518755224068, 0.025419136800337583, 0.06952872849069536, 0.03512415372824762, 0.016526370818610303, 0.06269880279432982, 0.04953856150677893, 0.020514633470156696, 0.10600737965432927, 0.03715645092597697, 0.06818215348175727, 0.03948668701923452, 0.07030107415630482, 3.358357879333198, 31.155067831277847, 52.60264836251736, 47.81585521996021, 36.690314412117004, 23.651714958250523, 25.475315004587173, 45.035977587103844, 43.37900049984455, 10.680802222341299, 0.4211898538051173, 0.11588984038098715, 1.5702253673225641, 1.0236416780389845, 0.5976214818656445, 2.8481233958154917, 0.21680153760826215, 0.9328706644009799, 0.1688467600615695, 0.09009878369397484, 0.34487421449739486, 0.29296834662090987, 0.8685891574714333, 0.31224500911775976, 0.15186210192041472, 0.5766041565220803, 0.6892775511369109, 1.4692583726719022, 1.5756263025105, 0.6193565530702472, 1.5861706179566681, 2.3279405711218715, 3.035809574648738, 3.104648580774665, 1.8986402009613812, 0.32414977031294256, 0.15612317249178886, 0.231702245073393, 0.11676947091473266, 6.025644466280937, 25.704832188785076, 16.148658469319344, 8.302146010100842, 13.65586968138814, 41.47802710533142, 87.71536722779274, 52.84466877579689, 81.92814856767654, 73.64894762635231, 65.58117493987083, 68.0362232029438, 70.24796292185783, 74.9033211171627, 74.89960491657257, 61.99736684560776, 44.826213642954826, 21.168077029287815, 11.369293928146362, 8.129208739846945, 3.4465468721464276, 2.559059369377792, 1.454851208254695, 0.2676154242362827, 0.35606342658866197, 0.24416520522208884, 0.7181887154001743, 0.4724174877628684, 1.0387140442617238, 2.637343956157565, 2.801659726537764, 3.85131374001503, 3.123171399347484, 1.6495635663159192, 1.3431045482866466, 1.174751257058233, 0.16139009065227583, 2.291891905479133, 19.669809825718403, 39.61252860724926, 26.01049728691578, 23.812320940196514, 37.573645412921906, 46.25362604856491, 40.431506261229515, 18.400917313992977, 1.0735617368482053, 0.10874943720409647, 0.07665934273973107, 0.03420306682528462, 0.0358475399116287, 0.008130913356581004, 0.02005432379519334, 0.08692962015629746, 0.0494770857039839, 0.059865683724638075, 0.039972986705834046, 0.013815257116220891, 0.009099335366045125, 0.029355117003433406, 0.008939505514717894, 0.05657414745655842, 0.10675927172997035, 0.05394732317654416, 0.07631042200955562, 0.057950323025579564, 0.057094738076557405, 0.05481132036948111, 0.005865057646587957, 0.023989227884158026, 0.02806287277053343, 0.0265197974658804, 0.05427289965155069, 0.02944413947261637, 0.04005972521554213, 0.06767945975298062, 0.04688197710493114, 0.03788453861488961, 0.05237579949607607, 0.1228145754430443, 0.04166088285273872, 0.05094601117889397, 0.03520362661220133, 0.1331218786071986, 0.011205315768165747, 0.11430652026319876, 0.033317762572551146, 0.013921945483161835, 0.03667621458589565, 0.015202830218186136, 0.056151798635255545, 0.05400234971602913, 0.022619941300945356, 0.02205917080573272, 0.06385163273080252, 0.024808937414491083, 0.027921412001887802, 0.037334295484470204, 0.046307773736771196, 0.07712843202170916, 0.10126929366379045, 0.04225485332426615, 0.07003884369623847, 0.0788907878450118, 0.04075887656654231, 0.0743728228553664, 0.05819237820105627, 0.042350531002739444, 0.061679540885961615, 0.01981664914637804, 0.10010025522205979, 0.06202153366757557, 0.02970138084492646, 0.06029176554875448, 0.033585432975087315, 0.05534615651413333, 0.03357916924869642, 0.05382977811677847, 0.02093379105644999, 0.028438076660677325, 0.013062573725619586, 0.05898863586480729, 0.04600355256116018, 0.013477879565471085, 0.015835522244742606, 0.04709073211415671, 0.05476968959555961, 0.030525387410307303, 0.04299767635529861, 0.042943495864165016, 0.0545587972010253, 0.07598536874866113, 0.07798559032380581, 0.014679200503451284, 0.049715823479346, 0.04704234408563934, 0.12906716961879283, 8.747498262673616, 45.67587085068226, 57.39524379372597, 45.79397611320019, 25.566694401204586, 18.8998419418931, 42.36610405147076, 69.17261302471161, 44.6959338337183, 4.831674434244633, 0.239694255287759, 0.28888427827041596, 1.2785157328471541, 0.4384001693688333, 0.8211941819172353, 3.5938929906114936, 1.5127198467962444, 0.5696249997708946, 0.6211554596666247, 0.9783347498159856, 2.4403622886165977, 0.9880106337368488, 2.1454717498272657, 1.6191678098402917, 1.8327573174610734, 1.6707052756100893, 2.4196740612387657, 4.232773371040821, 3.9023217279464006, 3.2579689286649227, 4.170659529045224, 5.993194682523608, 8.096300605684519, 8.292919155210257, 4.967158539220691, 3.2797828456386924, 0.7785336335655302, 0.8353969291783869, 0.616570768179372, 13.832329362630844, 45.27191832661629, 30.46573542058468, 17.305382899940014, 22.879446297883987, 53.13746206462383, 88.69678616523743, 57.14109443128109, 80.64422026276588, 72.68113195896149, 65.92115789651871, 66.37599349021912, 73.06514695286751, 73.98974373936653, 76.51307433843613, 67.23720207810402, 57.24180422723293, 30.361250527203083, 18.580480478703976, 12.013981584459543, 6.697266027331352, 5.052812593057752, 3.963323417119682, 0.6212436861824244, 1.055844712536782, 0.5984301853459328, 1.430046851746738, 1.5299051371403039, 3.4829004714265466, 3.989435378462076, 1.620594752021134, 4.933617264032364, 1.9030970055609941, 1.4876328804530203, 0.6778104195836931, 0.4919121041893959, 0.14258565672207624, 0.35447650705464184, 19.440581426024437, 55.38006752729416, 41.983624175190926, 23.362827859818935, 23.576266206800938, 41.92028917372227, 48.611274138092995, 26.669444628059864, 2.4697938468307257, 0.10886017305892892, 0.05186722053622361, 0.06162168305309024, 0.01750988347339444, 0.06521138828247786, 0.03758553102670703, 0.03190119932696689, 0.11228395262151025, 0.02278699688758934, 0.05487451053340919, 0.06074784498196095, 0.017689991582301445, 0.021911459298280533, 0.04710138564405497, 0.03970497120462824, 0.014106365470070159, 0.01915861834277166, 0.06337518876534887, 0.026471290693734773, 0.030790872187935747, 0.06066895839467179, 0.07110206672223285, 0.1087273434677627, 0.04118469492823351, 0.06347478498355485, 0.05085056727693882, 0.012144825559516903, 0.045359461146290414, 0.011100595947937109, 0.030293657364381943, 0.04452718705579173, 0.02965854964713799, 0.0672701133589726, 0.045680955809075385, 0.014906879350746749, 0.013492920115822926, 0.03836500873148907, 0.016866033256519586, 0.05062837568402756, 0.06991385118453763, 0.025054751567950007, 0.3222725819796324, 0.15303466556360945, 0.13075007853331044, 0.16895799315534532, 0.20125136186834425, 0.11387534730602056, 0.16366566385840997, 0.20653998042689636, 0.08489399813697673, 0.15821859677089378, 0.18940987618407235, 0.17421133001334965, 0.24099311762256548, 0.18289451720193028, 0.3381307638483122, 0.2743834548164159, 0.18011116655543447, 0.12520127784227952, 0.08661514992127195, 0.20168882823782042, 0.1271750492742285, 0.10705883221817203, 0.16465095395687968, 0.17635515716392547, 0.22539272817084566, 0.2498713560635224, 0.07171277262386866, 0.15179136040387675, 0.11821380161563866, 0.14399092819076031, 0.10466638559591956, 0.07550249778432772, 0.11233450029976666, 0.24840389261953533, 0.1267842936795205, 0.11102878794190474, 0.08262445116997696, 0.09623546182410792, 0.16625547723378986, 0.1363103825133294, 0.15355587587691844, 0.24941564770415425, 0.1863413181854412, 0.13321221282240003, 0.18888627615524456, 0.07899575721239671, 0.17097017815103754, 0.14910414756741375, 0.2599546196870506, 6.476729661226273, 47.58316710591316, 71.96070581674576, 65.74658006429672, 45.064517855644226, 32.057998180389404, 37.30174720287323, 54.6399812400341, 54.66105870902538, 14.065263513475657, 0.8039513602852821, 0.3531631431542337, 5.590601060539484, 5.9333032462745905, 8.1410251557827, 8.275006916373968, 1.7580630630254745, 1.773834591731429, 0.5226653383579105, 0.40513182641007006, 0.9318280359730124, 0.6096939684357494, 1.6263070330023766, 0.6125500495545566, 0.6756964267697185, 0.7218914979603142, 1.0019507794640958, 1.9672300829552114, 2.170224809087813, 1.7850631079636514, 2.6119660679250956, 3.173565720207989, 4.756030943244696, 4.67795510776341, 2.8141318447887897, 1.3245057337917387, 0.3101865289499983, 0.6186990696005523, 0.4005563969258219, 10.842645037919283, 38.84272791445255, 26.11098099499941, 13.364611510187387, 18.376602418720722, 52.603400722146034, 97.21207603812218, 64.61418762803078, 82.51450270414352, 77.07656130194664, 69.9916210770607, 74.18787270784378, 74.60783377289772, 78.76291081309319, 79.92852866649628, 68.23325023055077, 50.99439986050129, 23.586556054651737, 13.451274409890175, 7.908961158245802, 3.813335015438497, 2.841534074395895, 2.631144351325929, 0.22346366371493787, 0.5499421153217554, 0.40578022599220276, 0.6061232881620526, 0.5674973514396697, 2.564763338305056, 5.538673046976328, 5.5440540332347155, 10.862547419965267, 9.6522743627429, 7.671116720885038, 7.778739770874381, 2.7539900969713926, 0.35275534784886986, 2.911998680792749, 24.52481310814619, 52.12176516652107, 36.65828973054886, 34.58683468401432, 49.46783557534218, 60.7308492064476, 58.59366908669472, 25.85153851658106, 1.7633432359434664, 0.35727900511119515, 0.1535139445331879, 0.25301841844338924, 0.14021394570590928, 0.14392189361387864, 0.12203129794215783, 0.18335815169848502, 0.16647533106151968, 0.21065086999442428, 0.15667089232010767, 0.1706361523247324, 0.13062311190878972, 0.1386986582656391, 0.13541909283958375, 0.16935636318521574, 0.12670755560975522, 0.1342041525640525, 0.13145869597792625, 0.1580540626309812, 0.14997787802712992, 0.09720136702526361, 0.14072632446186617, 0.16951978410361335, 0.13367837062105536, 0.09399579372256994, 0.1386859526974149, 0.1022370022838004, 0.20869977859547362, 0.15880118269706145, 0.18945994146633893, 0.12221390337799676, 0.14065988740185276, 0.18747000605799258, 0.18853393412427977, 0.08795690097031184, 0.12327645104960538, 0.2801283309236169, 0.1357930907397531, 0.18468015419784933, 0.19162784388754517, 0.14283071388490498], [0.0813354148704093, 0.01821806490625022, 0.03897390008205548, 0.047099289076868445, 0.03275688075518701, 0.02426182800263632, 0.04983034057659097, 0.018291147898708005, 0.019512363032845315, 0.007902162105892785, 0.06958899088203907, 0.07202083070296794, 0.07912875749752857, 0.06513105079648085, 0.016139448416652158, 0.05409633900853805, 0.043996499516651966, 0.015430511848535389, 0.05896581111301202, 0.06794388697016984, 0.05719180357118603, 0.06600340828299522, 0.07048294486594386, 0.009034938284457894, 0.04471072017622646, 0.02854891456081532, 0.0075055866818729555, 0.03159466265060473, 0.0655207822273951, 0.1157692562264856, 0.03003962763614254, 0.010932193363260012, 0.025990549693233334, 0.05090802435006481, 0.04690057903644629, 0.06809717015130445, 0.03573353118554223, 0.07426881827996112, 0.030827688278805, 0.037346600292949006, 0.07629847343196161, 0.018908093406935222, 0.0334886309428839, 0.024188917559513357, 0.009335835566162132, 0.014597228437196463, 0.07970821156050079, 0.047744560506544076, 0.05468568590003997, 0.04932119387376588, 0.6507742765825242, 14.881597459316254, 54.40856605768204, 58.13215725123882, 50.52699834108353, 33.084456101059914, 28.907773420214653, 37.53180965781212, 42.8547540307045, 34.75543163716793, 6.306845052167773, 0.15912961272988468, 0.28257477621082217, 0.6157937098760158, 3.9464045874774456, 1.9125532731413841, 1.211100819054991, 3.9155953656882048, 5.004539033398032, 7.994543965905905, 1.5917007462121546, 0.8363293635193259, 0.3653178596869111, 0.3185111400671303, 0.1142320160579402, 0.15362425736384466, 0.12124611312174238, 0.2495571901090443, 0.04208737656881567, 0.17432156862923875, 0.062042417703196406, 0.2284160745330155, 0.14554029505234212, 0.10327583833714016, 0.1994075850234367, 0.1155756002117414, 0.14137508027488366, 0.0436486437683925, 0.08993626077426597, 0.5367358645889908, 0.18240407633129507, 0.035586942176450975, 0.06081366605940275, 3.0058785807341337, 24.01866126805544, 35.67684419453144, 54.1240107268095, 67.5543786585331, 76.32990136742592, 69.3579974770546, 52.833052799105644, 42.803513780236244, 26.676514148712158, 8.91091514378786, 0.3722900105640292, 0.0947930829715915, 0.15221908979583532, 0.47596637858077884, 0.4512139724101871, 0.6582551845349371, 0.2602695574751124, 0.925061252200976, 1.3391803088597953, 1.242778175510466, 3.5857336409389973, 5.290420493111014, 3.133454597555101, 4.9046979658305645, 2.3991663241758943, 4.779771119356155, 0.8396715810522437, 0.6908033473882824, 0.13361261633690447, 0.6181364029180259, 16.8618194013834, 40.94742737710476, 34.60285842418671, 26.017291322350502, 29.186288975179195, 43.7370552867651, 49.50720526278019, 27.690520137548447, 7.033410239964724, 0.0906168547226116, 0.14620672882301733, 0.062077220718492754, 0.058302112156525254, 0.02052982152235927, 0.03270957255153917, 0.029124064167262986, 0.024563212318753358, 0.07297453499631956, 0.09906841019983403, 0.04625728171959054, 0.03363360578077845, 0.024226529603765812, 0.03731323333340697, 0.018222990911453962, 0.03559680160833523, 0.09418406174518168, 0.08946850735810585, 0.04455360751308035, 0.07806383495335467, 0.009833845415414544, 0.04195888483081944, 0.01565776674397057, 0.025418266632186715, 0.07629721920238808, 0.05746862094383687, 0.07804755223332904, 0.06474442896433175, 0.13364754180656746, 0.07434003477101214, 0.044110842209192924, 0.03777463025471661, 0.03131350371404551, 0.11400880772271194, 0.09465539973462, 0.09619628384825774, 0.05833834751683753, 0.04222846626362298, 0.020019398325530346, 0.07003309205174446, 0.04646825575036928, 0.06757610084605403, 0.03022148164745886, 0.027151235262863338, 0.0057627688238426344, 0.026566103770164773, 0.08298725748318247, 0.01615449731616536, 0.0396009592077462, 0.0554408434254583, 0.04516492939728778, 0.026809539340320043, 0.025488243736617733, 0.05956803426670376, 0.05749485957494471, 0.018696959814406, 0.022689825636916794, 0.020540614204946905, 0.07380220777122304, 0.036656239681178704, 0.10964592933305539, 0.029186239444243256, 0.043516756704775617, 0.042944171218550764, 0.012637761901714839, 0.04682710270571988, 0.08773975598160177, 0.03404124152439181, 0.06835500709712505, 0.04237704793922603, 0.024401587397733238, 0.04566199022519868, 0.02401103589363629, 0.03977545668021776, 0.01072748676961055, 0.04770636216562707, 0.03624057018896565, 0.05145286464539822, 0.03341610085044522, 0.021623622888000682, 0.0479946902487427, 0.028033956841682084, 0.06426671592635103, 0.062193541234591976, 0.02645154771016678, 0.05690586149285082, 0.027159356213815045, 0.021313445977284573, 0.025699811485537793, 0.05856766001670621, 0.0730600229871925, 0.05074403197795618, 0.1410421379841864, 2.7285452373325825, 25.467367731034756, 65.27142316102982, 54.65448126196861, 35.841515958309174, 20.68574421107769, 29.58278439939022, 60.34474432468414, 69.41315531730652, 30.426724813878536, 1.6675728186964989, 0.1242910856672097, 0.3243686741916463, 1.0765255778096616, 0.8540022745728493, 1.21212522033602, 1.0224652849137783, 6.6250979248434305, 2.9120069928467274, 4.76984272710979, 2.2783178463578224, 2.4615893745794892, 2.715313397347927, 0.5261102691292763, 0.9698253439273685, 0.7291609235107899, 1.5458104899153113, 0.4665988124907017, 0.9196745068766177, 0.5844982923008502, 0.18518393888371065, 1.2031844188459218, 0.8834655373357236, 0.20224822947056964, 0.18156546429963782, 0.06197895294462796, 0.5859195347875357, 0.19840130698867142, 0.12077467123162933, 1.8404380115680397, 0.8278469124343246, 0.09785505069885403, 0.438168827095069, 7.14270425029099, 41.27788424491882, 46.58193223178387, 66.60206615924835, 74.69272881746292, 81.581591963768, 75.23553729057312, 62.988726049661636, 55.680984780192375, 39.35042627155781, 16.94425407797098, 2.161801611073315, 0.33272638509515673, 1.0873874137178063, 1.4014221564866602, 1.0133019578643143, 3.484121630899608, 2.4007401522248983, 1.6709010838530958, 5.42272369377315, 2.963308752514422, 5.861538872122765, 7.161557413637638, 3.3421149384230375, 5.365841221064329, 1.0834566433914006, 2.508529918268323, 0.49472552665974945, 0.6310335639864206, 0.12040166038786992, 0.2959813177585602, 12.396478559821844, 49.76822845637798, 52.53637611865997, 31.14442080259323, 21.174378991127014, 33.449236527085304, 53.27985942363739, 39.999195858836174, 12.483255453407764, 0.12014368243399076, 0.09406252764165401, 0.06045229951268993, 0.05679293259163387, 0.02781895294901915, 0.06054104924260173, 0.034671161629376, 0.05199505547352601, 0.07875791372498497, 0.00902876639884198, 0.0039274594200833235, 0.020885449412162416, 0.07949333754368126, 0.022140508335724007, 0.04486189194722101, 0.03295076312497258, 0.07490883159334771, 0.04200171046250034, 0.029094202000123914, 0.0023875271108408924, 0.009257858109776862, 0.013482335234584752, 0.04220288072247058, 0.04618010949343443, 0.07383627234958112, 0.052833997760899365, 0.07934092267532833, 0.03905289799149614, 0.05966454686131328, 0.06645542816841044, 0.10410345916170627, 0.04363704028946813, 0.010628761647240026, 0.05253508294117637, 0.10136271521332674, 0.01893020569696091, 0.06779848539736122, 0.0735009774507489, 0.021147394145373255, 0.034046392029267736, 0.031169556750683114, 0.059590391465462744, 0.07391660241410136, 0.2171026120777242, 0.10865994161576964, 0.20739745785249397, 0.13746169104706496, 0.13504482776625082, 0.06666590124950744, 0.13887566048651934, 0.09545683016767725, 0.10217806833679788, 0.12688522576354444, 0.1627060817554593, 0.1851813413668424, 0.1608440777636133, 0.21857449872186407, 0.11174028491950594, 0.13419376249657944, 0.25119490223005414, 0.25365568581037223, 0.1616754909628071, 0.11908091211807914, 0.1521766241057776, 0.1712312360177748, 0.16746430221246555, 0.1336389922653325, 0.08547981240553781, 0.12005741518805735, 0.1684283817303367, 0.12549656355986372, 0.27857264096383005, 0.4220001306384802, 0.07512778742238879, 0.11459419154562056, 0.12333133287029341, 0.08942256099544466, 0.11895184521563351, 0.1308017468545586, 0.10482936864718795, 0.20815262279938906, 0.19844592490699142, 0.1667509795515798, 0.1642456671106629, 0.07377448855550028, 0.1470675755990669, 0.08246165365562774, 0.11176247513503768, 0.23506288271164522, 0.174770790617913, 0.16617110988590866, 0.10593395898467861, 0.27441578276921064, 1.7173668905161321, 20.97368896007538, 75.56191697716713, 78.28541323542595, 60.90589061379433, 48.384228721261024, 39.07250538468361, 49.388974606990814, 57.67625771462917, 42.44957037270069, 8.551085852086544, 0.45285987784154713, 0.6436702609062195, 4.020357644185424, 10.441469214856625, 7.653043940663338, 5.2361152321100235, 12.506919633597136, 7.779952855780721, 9.822875708341599, 3.193041575141251, 1.7480585561133921, 1.436674646101892, 0.7158901949878782, 0.4728780052391812, 0.5459785123821348, 0.7150310254655778, 0.39206655404996127, 0.36506523261778057, 0.30725317541509867, 0.16412258933996782, 0.6102098501287401, 0.6752257863990963, 0.15942293917760253, 0.24571903981268406, 0.16567486542044207, 0.7097879005596042, 0.334289941820316, 0.22647296864306554, 1.490408987738192, 0.8383934840094298, 0.08866930336807854, 0.3765992762055248, 5.342663889750838, 30.030508674681187, 43.663365840911865, 57.58321970701218, 71.19774475693703, 77.28862032294273, 69.57506462931633, 56.56192570924759, 46.681984663009644, 28.442330695688725, 10.611098762601614, 0.961499159457162, 0.19159885559929535, 0.43253942916635424, 0.783583918819204, 0.8203964622225612, 1.7340589198283851, 1.2211731285788119, 2.229128535836935, 3.874841365031898, 4.8736142087727785, 6.349087860435247, 10.860373936593533, 7.351984195411205, 9.98127305880189, 5.85725792683661, 15.107390843331814, 4.292675731703639, 2.2358223516494036, 0.23925367189804092, 1.720301283057779, 22.283744663000107, 53.55458088219166, 45.202431455254555, 36.47006303071976, 43.01080025732517, 53.33941362798214, 64.98665124177933, 45.3866645693779, 11.33878156542778, 0.17406494880560786, 0.31103631772566587, 0.11180614310433157, 0.15916862001176924, 0.08653742479509674, 0.17322188388789073, 0.10727421831688844, 0.14371395867783576, 0.207679370068945, 0.19595324381953105, 0.1314071167143993, 0.18096141546266153, 0.16271071275696158, 0.18915117834694684, 0.10875775667955168, 0.19536711042746902, 0.25106722314376384, 0.14532100525684655, 0.14224489219486713, 0.16364838666049764, 0.1267240461311303, 0.07664927179575898, 0.1726505340775475, 0.12506390630733222, 0.19028014823561534, 0.20040476432768628, 0.184612856246531, 0.19123199715977535, 0.1370312602375634, 0.14810722059337422, 0.20327968115452677, 0.18594621360534802, 0.13790712808258832, 0.19988692336482927, 0.17502466449514031, 0.2830407558940351, 0.17116785660618916, 0.20144651702139527, 0.06099789679865353, 0.14152015530271456, 0.12321215879637748, 0.15667279221815988, 0.14016092667588964], [0.023713243572274223, 0.13298064790433273, 0.023806809840607457, 0.023873835052654613, 0.025375728582730517, 0.045700325863435864, 0.12492849404225126, 0.04886589740635827, 0.0841838147607632, 0.015776606851432007, 0.06120537902461365, 0.0705533153086435, 0.05441265719127841, 0.049297712321276776, 0.08053654484683648, 0.012607642765942728, 0.07138279150240123, 0.045511872303904966, 0.08304990216856822, 0.02026711608777987, 0.004803548517884337, 0.015185348929662723, 0.03911539795808494, 0.05085964745376259, 0.07163007510825992, 0.03068143138079904, 0.06966071945498697, 0.05787780406535603, 0.11102443153504282, 0.05217030622588936, 0.07538273741374724, 0.04763110096973833, 0.077214780903887, 0.0738692979211919, 0.04076314391568303, 0.039159411026048474, 0.018552096298662946, 0.036892880889354274, 0.03132649500912521, 0.03583879370125942, 0.018375424333498813, 0.026389608065073844, 0.029189323067839723, 0.06807115787523799, 0.037939138419460505, 0.09525010493234731, 0.07784185116179287, 0.011303090941510163, 0.006941796573300962, 0.01490777085564332, 0.09610215725842863, 0.08935063946410082, 4.753725891932845, 32.729745134711266, 57.07106798887253, 44.052825942635536, 42.841580137610435, 45.19957780838013, 22.840762473642826, 30.987633615732193, 52.60126903653145, 32.5223408639431, 8.737253062427044, 0.39316496229730546, 0.1391884608892724, 1.3151265308260918, 0.1815036137122661, 3.0334843369200826, 1.7023892817087471, 6.1695128213614225, 2.535823853686452, 4.790203459560871, 6.90102344378829, 0.7431953516788781, 2.3566546803340316, 0.4133631644072011, 2.1835153084248304, 1.0510839242488146, 3.012733650393784, 2.0567006757482886, 1.129575481172651, 1.2577585154213011, 0.8143706386908889, 1.5719516621902585, 0.61787866987288, 0.29798297910019755, 0.23883324523922056, 0.11815342048066668, 0.17424414778361097, 0.08393147712922655, 0.049589665795792826, 0.06300391454715282, 0.052173156072967686, 0.2903534931829199, 0.09165247727651149, 0.5628021096345037, 2.91620671749115, 5.125214857980609, 7.340685501694679, 7.1788350865244865, 2.992018824443221, 0.7744367409031838, 0.06073772208765149, 0.16296908404910937, 0.23891688528237864, 0.550728376256302, 3.609021878801286, 2.296070968732238, 2.4517685640603304, 6.4122081734240055, 6.216281661763787, 2.0257240254431963, 7.9550849832594395, 2.7113832207396626, 8.323997687548399, 9.300298299640417, 6.743512395769358, 5.620392886921763, 0.16104640206322074, 1.5051633585244417, 0.04744526719150599, 1.4878349821083248, 14.70194024965167, 39.824545830488205, 39.91362825036049, 26.63396593183279, 24.832159616053104, 41.907107681035995, 51.189447194337845, 46.22932255268097, 18.495458140969276, 0.6066828675102443, 0.27902229339815676, 0.025798505994316656, 0.05505506393092219, 0.062223364438978024, 0.04140924284001812, 0.04583088819344994, 0.04429538836120628, 0.011369787753210403, 0.004994942373741651, 0.047401101983268745, 0.0339213995175669, 0.08628987401607446, 0.08556105531170033, 0.04236476539517753, 0.05121195979882032, 0.03953451472625602, 0.09030428438563831, 0.029012228078499902, 0.038982342011877336, 0.0065723888565116795, 0.04138239564781543, 0.030751304584555328, 0.05064555640274193, 0.15746283810585737, 0.03779561819101218, 0.02704608592466684, 0.14341132569825277, 0.15944544109515846, 0.09840484854066744, 0.08315196231706068, 0.03225326676329132, 0.07205634989077225, 0.021051568037364632, 0.057885644855559804, 0.06358848200761713, 0.030679943374707364, 0.031625350457034074, 0.0782699887349736, 0.21430153894471005, 0.0403081851254683, 0.02717867802857654, 0.15322070714319125, 0.05288079017191194, 0.1265187532408163, 0.02486720899469219, 0.05045962243457325, 0.05423565125965979, 0.028358744784782175, 0.05473258592246566, 0.02593095152406022, 0.08618900130386464, 0.01395957979184459, 0.056838541277102195, 0.023802277173672337, 0.034924619903904386, 0.015307879366446286, 0.051633150869747624, 0.02173850363760721, 0.1082945748930797, 0.03184420980687719, 0.013100055894028628, 0.036806468924623914, 0.08940074927522801, 0.033907799661392346, 0.047511281227343716, 0.11951774766203016, 0.0848095046239905, 0.03870370637741871, 0.05034781417634804, 0.03226723398256581, 0.013901280381105607, 0.06439279197365977, 0.059905826492467895, 0.041045267644221894, 0.050303960670134984, 0.01961805970495334, 0.03991639052401297, 0.09642375953262672, 0.01581592583534075, 0.06892141420394182, 0.0393395154242171, 0.050613369458005764, 0.07671061030123383, 0.04841092748392839, 0.018716246377152856, 0.018238589000247885, 0.020712942750833463, 0.061971115865162574, 0.006279407971305773, 0.08274817460915074, 0.04004744267149363, 0.06108590809162706, 0.07408227203995921, 0.040579377018730156, 0.09041835990501568, 0.35831400426104665, 11.99203111231327, 48.796628192067146, 61.69480808079243, 44.50101189315319, 32.50157117843628, 32.0380986481905, 26.94127444177866, 60.676553919911385, 67.54318445920944, 28.115994706749916, 3.6649178294464946, 0.16321847535436973, 0.1872215943876654, 0.5611163063440472, 0.1523825849290006, 2.625876171514392, 1.0576959257014096, 0.7379698008298874, 2.308717640116811, 1.997316274791956, 1.7049321765080094, 2.1389816980808973, 3.4019154170528054, 3.823799891397357, 3.482534266076982, 2.4313408602029085, 2.033894774504006, 8.361531123518944, 3.027501320466399, 5.4097103420645, 4.706449303776026, 5.035460824146867, 2.5093535240739584, 1.2563619716092944, 1.8949299375526607, 0.7757560419850051, 0.6575725867878646, 0.09893260459648445, 0.07610370419570245, 0.21689239132683724, 0.2882315742317587, 0.12464952073059976, 0.44182509183883667, 2.0662217773497105, 5.201330948621035, 11.063002813607454, 13.16671147942543, 11.345532853156328, 6.760369716212153, 1.9296417874284089, 0.48249861400108784, 0.21287661540554836, 0.9320673043839633, 1.7059031431563199, 5.0987450033426285, 2.610950809903443, 3.575123897753656, 2.9980650125071406, 3.274916256777942, 3.540886309929192, 5.336441248655319, 2.380229327827692, 2.4895900720730424, 2.349004978314042, 2.899903692305088, 0.6450627674348652, 0.41320101998280734, 0.2707459218800068, 0.027781858552771155, 0.4933371167862788, 8.070727977901697, 40.70680148899555, 58.517209589481354, 38.94501082599163, 17.827315293252468, 25.46499665826559, 46.27164848148823, 54.678184390068054, 27.3110705986619, 2.2008404787629843, 0.14674629986984655, 0.006162467298054253, 0.03826549414952751, 0.07508350347052328, 0.031637573629268445, 0.06950543247512542, 0.07121396774891764, 0.003978815575464978, 0.034710102117969655, 0.01933624953380786, 0.0009905424167300225, 0.032253708341158926, 0.058430963836144656, 0.008415756128670182, 0.07396594039164484, 0.035893675521947443, 0.04884985588432755, 0.018024407036136836, 0.06331391705316491, 0.049885556363733485, 0.12164803803898394, 0.04366816967376508, 0.029479842341970652, 0.11301912410999648, 0.011082021846959833, 0.13531796779716387, 0.09506084985332564, 0.045839159429306164, 0.09358440642245114, 0.1376811441150494, 0.0637691949668806, 0.11187148920726031, 0.05156400497071445, 0.053976890339981765, 0.14239470212487504, 0.09729343044455163, 0.06902031280333176, 0.03551553643774241, 0.05177454855584074, 0.026536798213783186, 0.026542740961303934, 0.20733686891617253, 0.015249410189426271, 0.036439911054912955, 0.14526359271258116, 0.38620228122454137, 0.15991649706847966, 0.10211686341790482, 0.19038053113035858, 0.24065170000540093, 0.11230488118599169, 0.09829985690885223, 0.2649580012075603, 0.11358204312273301, 0.12558582908241078, 0.22380868816981092, 0.13403075718088076, 0.11911302484804764, 0.19460795272607356, 0.12433908777893521, 0.16699450789019465, 0.15760642883833498, 0.2686465345323086, 0.08724718514713459, 0.15795293758856133, 0.3050669567892328, 0.13458978733979166, 0.13769537850748748, 0.13998368696775287, 0.14123537839623168, 0.13570326118497178, 0.18315710389288142, 0.2404695621225983, 0.16567934799240902, 0.21573188016191125, 0.17717457725666463, 0.2596715942490846, 0.14391050906851888, 0.17347140877973288, 0.20326010329881683, 0.09986048957216553, 0.2163203142117709, 0.15395654656458646, 0.19646931847091764, 0.13363681035116315, 0.12979554303456098, 0.09262210063752718, 0.12857687717769295, 0.11081080432632007, 0.18239616503706202, 0.16687355266185477, 0.17745647463016212, 0.17535358434543014, 0.13176321401260793, 0.22062157950131223, 0.4760674887802452, 8.312544152140617, 49.54961858689785, 79.90973487496376, 59.77296240627766, 60.8864014595747, 56.6488878428936, 30.311668887734413, 43.639054745435715, 64.74138960242271, 38.51355917751789, 11.071325317025185, 1.0621261317282915, 0.39255990413948894, 3.1727668130770326, 0.26005997497122735, 8.445284329354763, 5.436478005722165, 9.664600901305676, 9.142859447747469, 8.099435437470675, 12.806537356227636, 4.021511357277632, 6.562871038913727, 5.261245658621192, 5.303240055218339, 3.785406039096415, 4.503515493124723, 6.70109954662621, 1.8599655199795961, 4.124668696895242, 2.0564104663208127, 3.337139580398798, 1.2184496247209609, 0.9231295902282, 1.5784324519336224, 0.4806047125020996, 0.3603369207121432, 0.18060043483274058, 0.2719714748673141, 0.23770648695062846, 0.2084020437905565, 0.3059747221414, 0.43065006961114705, 0.965532346162945, 3.161945231258869, 7.050963873043656, 8.561986517161131, 7.60657480917871, 4.291350552812219, 1.2181831640191376, 0.429590935818851, 0.106650947855087, 0.6047054298687726, 1.4505884307436645, 5.57385915890336, 8.029086962342262, 7.177747394889593, 10.911345351487398, 11.586385779082775, 7.18528856523335, 14.359178692102432, 9.978699646890163, 15.680304151028395, 23.586487658321857, 20.90044219046831, 16.11329946666956, 2.746267248876393, 2.5617505749687552, 0.09884594401228242, 2.0716146379709244, 18.836926817893982, 51.586058512330055, 51.93328768014908, 38.231602907180786, 37.41596147418022, 54.691107496619225, 66.93401634693146, 62.73839928209782, 30.242183916270733, 1.5945011959411204, 0.3906695352634415, 0.13979485491290689, 0.1479362149257213, 0.16292102256556973, 0.1640191933256574, 0.24165034876205027, 0.11188996126293205, 0.16553010209463537, 0.09283658873755485, 0.09408632831764407, 0.17768643650924787, 0.1705773445428349, 0.18174105643993244, 0.09952663443982601, 0.15535834478214383, 0.2001736595411785, 0.18859905016142875, 0.14498368429485708, 0.276625661063008, 0.12257731083082035, 0.2688308246433735, 0.15469152509467676, 0.10033035068772733, 0.26227130787447095, 0.15816406375961378, 0.17695867165457457, 0.31939485983457416, 0.23315125872613862, 0.22418463049689308, 0.15106678678421304, 0.20496742887189612, 0.26544363296125084, 0.10478482494363561, 0.17004577384795994, 0.25075184006709605, 0.1438020367641002, 0.13192663493100554, 0.22247853688895702, 0.2952128683682531, 0.12816694448702037, 0.09221060201525688, 0.2568009967217222, 0.15521263150731102, 0.2143297257134691], [0.07989442383404821, 0.08559008812881075, 0.11425160875660367, 0.11393231456167996, 0.11649754058453254, 0.31090317643247545, 0.12830602296162397, 0.05917848466197029, 0.00790529025834985, 0.10072670949739404, 0.0071964506332733436, 0.10582418050034903, 0.015502302576351212, 0.02237388409412233, 0.1395968795986846, 0.12056222403771244, 0.024453292826365214, 0.052296289504738525, 0.09460422865231521, 0.03016496339114383, 0.031629769946448505, 0.0199293535479228, 0.07014145303401165, 0.016164712978934404, 0.07411227707052603, 0.06531450970214792, 0.05463172805320937, 0.019789135876635555, 0.0377534530707635, 0.03587711078580469, 0.018776380748022348, 0.0050815871873055585, 0.044924933681613766, 0.025391434282937553, 0.009766027033037972, 0.046281505419756286, 0.022022935445420444, 0.06098756981373299, 0.020210113580105826, 0.06001625435601454, 0.018228469816676807, 0.02546266190620372, 0.011680749485094566, 0.0494443310162751, 0.00527128848261782, 0.02036087531450903, 0.11148697507451288, 0.05540297905099578, 0.045360002914094366, 0.11932998429983854, 0.08300437883008271, 0.057573493832023814, 0.031168617933872156, 0.32904951833188534, 15.731137823313475, 48.4709058701992, 55.22921182215214, 44.345444440841675, 49.37312185764313, 31.831028759479523, 27.36027415841818, 39.061406180262566, 49.727696031332016, 40.797958597540855, 20.0327093526721, 5.928060952574015, 0.299220762681216, 0.301409296807833, 0.405991263105534, 0.29103751585353166, 0.971846419852227, 3.1507738307118416, 4.282728815451264, 2.4415380880236626, 3.1551369465887547, 3.1474395096302032, 6.361553091555834, 2.0517922891303897, 3.2635636534541845, 8.92929570749402, 2.6684189261868596, 7.742703929543495, 7.452665967866778, 7.08354189991951, 3.4409647341817617, 1.1192069062963128, 2.1803975757211447, 0.9780202573165298, 0.3098880668403581, 0.16320952505338937, 0.4276736715110019, 0.3522611962398514, 0.30540629639290273, 0.23109064117306843, 0.46179147670045495, 0.21358915138989687, 0.10115509940078482, 0.09402913099620491, 0.07780482541420497, 0.31607009761501104, 0.26978225796483457, 0.07210471565485932, 0.11235472382395528, 0.25532949599437416, 0.5545609456021339, 1.5548138692975044, 3.189609171822667, 3.279139492660761, 2.3222705628722906, 2.168902480043471, 3.916563126258552, 1.986902339849621, 5.116352783516049, 1.333658373914659, 1.8029367551207542, 0.983160906471312, 0.5190415203105658, 0.20819848752580583, 0.549492136342451, 6.4429575484246016, 21.815748475492, 48.213899061083794, 46.5807580947876, 34.09415312111378, 23.020857609808445, 31.61230679601431, 49.02822196483612, 50.23300051689148, 32.399995028972626, 6.895988713949919, 0.06067283982702065, 0.017036105673469137, 0.04866448223765474, 0.06127678105258383, 0.020777600511792116, 0.044492918386822566, 0.03581959805160295, 0.020955897780368105, 0.08030803757719696, 0.07564742438262329, 0.06691076545394026, 0.061099971790099517, 0.03403450653422624, 0.01916016757604666, 0.05387799916206859, 0.035960431705461815, 0.07656218818738125, 0.020825018182222266, 0.038523345938301645, 0.019304754641780164, 0.1100821266300045, 0.04509834019700065, 0.04731998153147288, 0.0270575372633175, 0.030991571184131317, 0.027588534649112262, 0.048271526175085455, 0.042430230241734535, 0.02946976397652179, 0.03766768677451182, 0.006628487335547106, 0.029177218639233615, 0.047438250185223296, 0.023857817650423385, 0.05324425328581128, 0.08807837570202537, 0.049927981235668994, 0.005025910804761224, 0.05462744215037674, 0.03764783432416152, 0.07253648975165561, 0.07759984422591515, 0.03040314455574844, 0.11518972794874571, 0.014935101371520432, 0.10251946368953213, 0.08072951808571815, 0.11887892920640297, 0.04855287435930222, 0.017876391248137224, 0.102241559070535, 0.08541186136426404, 0.10102643325808458, 0.03409134762478061, 0.03224211228371132, 0.13130285980878398, 0.12504777201684192, 0.12392676537274383, 0.07447948431945406, 0.12317974178586155, 0.17638589692069218, 0.06196057365741581, 0.021666914217348676, 0.05023465520935133, 0.07051801134366542, 0.007960710136103444, 0.013655410566570936, 0.05445713410153985, 0.03950663965952117, 0.014058868946449365, 0.02342187082831515, 0.04047235561301932, 0.019039841317862738, 0.02676563017303124, 0.008561643808207009, 0.0644050670962315, 0.03921814088243991, 0.037511056507355534, 0.03734307138074655, 0.10633332349243574, 0.01432260318324552, 0.04729216954729054, 0.039348198552033864, 0.09956559719284996, 0.020122388013987802, 0.01648068420763593, 0.030930564789741766, 0.02887518123316113, 0.10447062930325046, 0.03748803137568757, 0.013937336698290892, 0.06516361623653211, 0.09102786352741532, 0.08728142784093507, 0.030595807947975118, 0.02451526772347279, 0.026694257830968127, 0.011836073572339956, 0.03113263490376994, 1.7773362225852907, 27.934987619519234, 60.239049196243286, 57.26145297288895, 42.51165524125099, 25.890269838273525, 18.599473759531975, 41.32685601711273, 62.94519178569317, 62.77094453573227, 39.04483146965504, 12.490551061928272, 1.6887832805514336, 0.2083592812414281, 0.14707038091728464, 0.2687517710728571, 0.29379391169641167, 1.223957072943449, 0.5409342236816883, 0.18445562483975664, 1.0993079678155482, 1.3315136265009642, 0.27291605074424297, 1.8910951120778918, 3.6973837623372674, 6.709878500550985, 6.166620226576924, 5.447058063000441, 5.479535395279527, 6.955209486186504, 5.548424748703837, 4.617542624473572, 4.847680125385523, 1.6283896774984896, 1.4657688536681235, 1.948981205932796, 0.8599176665302366, 2.360652540810406, 1.8718736059963703, 2.1437399927526712, 0.7492422522045672, 0.8112231607083231, 1.6606953064911067, 0.8611006499268115, 0.2890879532787949, 0.23373703588731587, 0.37295245158020407, 0.16031583189032972, 0.5617285484913737, 0.35536052368115634, 1.1496672593057156, 1.075671217404306, 2.4539256608113647, 2.6378120435401797, 3.2339891279116273, 3.5896916035562754, 2.8025360545143485, 1.365000398363918, 1.41816773917526, 0.2455440117046237, 1.2963257334195077, 1.2062002695165575, 0.8075415738858283, 0.27665326895657927, 0.20614166976884007, 0.22827142995083705, 3.5404246347025037, 18.141531832516193, 46.098685562610626, 62.1847689896822, 47.95670986175537, 26.78774558007717, 22.673962824046612, 40.69278784096241, 54.31571044027805, 44.510971158742905, 12.77723902836442, 0.21077363606309518, 0.07672661100514233, 0.038767319565522484, 0.009634148318582447, 0.004501883577177068, 0.023200451068987604, 0.06619160951231606, 0.021052399242762476, 0.05605035075859632, 0.1002049351518508, 0.06631493961322121, 0.03820424470177386, 0.01856829181633657, 0.012865690296166576, 0.0726572891289834, 0.017661118326941505, 0.027374226519896183, 0.05292731169902254, 0.029612356520374306, 0.028433397419576067, 0.05528601286641788, 0.062494801240973175, 0.0348583312734263, 0.053057911136420444, 0.05511909272172488, 0.04937607198371552, 0.020789432201127056, 0.04766266451042611, 0.016447406305815093, 0.02955591062345775, 0.025296554413216654, 0.057477051741443574, 0.06180306394526269, 0.10143548279302195, 0.00908389498363249, 0.054223665574681945, 0.023426269908668473, 0.03934042826585937, 0.05013167108700145, 0.09577291828463785, 0.04632408614270389, 0.03342405667353887, 0.0784805731382221, 0.06958436730201356, 0.01290860313019948, 0.016449380418634973, 0.1770614442648366, 0.24757725885137916, 0.3325997747015208, 0.1601232890971005, 0.2445104968501255, 0.5145107978023589, 0.23468539671739563, 0.20398757129441947, 0.1002941709884908, 0.22891589615028352, 0.19257187057519332, 0.18394424056168646, 0.18085632735164836, 0.2156572646345012, 0.40835850639268756, 0.29793150373734534, 0.09579093763022684, 0.1659015766927041, 0.25880405330099165, 0.11527122318511829, 0.14808504522079602, 0.132849391666241, 0.11561099323444068, 0.07362600706983358, 0.1598615336115472, 0.1579425623640418, 0.11955026857322082, 0.13689620420336723, 0.11405159253627062, 0.18421380344079807, 0.11141406648675911, 0.1610851867008023, 0.13562676060246304, 0.2515603060601279, 0.16547200677450746, 0.12875524495029822, 0.14173053932609037, 0.2177107724128291, 0.145918597409036, 0.14938588166842237, 0.14868392870994285, 0.1277170397224836, 0.23678347788518295, 0.14751534297829494, 0.1042214829067234, 0.15942811936838552, 0.31120481493417174, 0.19735168752958998, 0.16566977428738028, 0.30296540237031877, 0.13642682548379526, 0.25200592121109366, 0.15969508473062888, 1.068356609903276, 26.546099446713924, 73.01536962389946, 76.51906281709671, 58.67401957511902, 61.38332359492779, 43.892881125211716, 35.78838720917702, 50.4298185557127, 61.935889944434166, 52.986841946840286, 26.839124523103237, 8.55661740526557, 0.58745471178554, 0.3773189813364297, 0.6096561485901475, 0.9257901599630713, 4.112867480143905, 10.085626859217882, 15.078947469592094, 12.424573302268982, 14.12598330527544, 8.788865692913532, 18.052787594497204, 12.635597828775644, 15.00231983140111, 22.63997934758663, 10.999498721212149, 16.058183424174786, 15.464385487139225, 16.809615902602673, 10.460266806185246, 6.420032903552055, 4.77809208445251, 3.004809175617993, 1.9488641247153282, 0.6257932295557112, 1.8584623443894088, 2.4619068950414658, 0.9442974231205881, 1.4524094830267131, 0.8187395136337727, 0.47186019422952086, 0.45403730997350067, 0.3347425925312564, 0.21580867760349065, 0.45668125560041517, 0.5545869504567236, 0.4112581367371604, 0.7382963458076119, 1.0250229039229453, 4.232020536437631, 5.311694126576185, 10.015762858092785, 13.014853578060865, 9.176785927265882, 12.319847121834755, 13.338026236742735, 11.11257590353489, 12.196169458329678, 6.98631034232676, 6.95582932792604, 2.445892416872084, 0.7780936290509999, 0.4602609307039529, 1.070094422902912, 9.246909264475107, 29.263305142521858, 56.06335826218128, 57.269470542669296, 47.86449261009693, 35.7449821382761, 43.42578738927841, 63.05804193019867, 64.29071858525276, 49.91488918662071, 11.31417503580451, 0.22692866215948015, 0.13118574890540913, 0.27507068356499076, 0.30919421813450754, 0.14779174845898524, 0.14212505018804222, 0.1652204929268919, 0.12127424794016406, 0.10030889519839548, 0.2263885419233702, 0.15929221728583798, 0.2263631604728289, 0.12676228157943115, 0.05872531073691789, 0.17798243468860164, 0.14278109389124438, 0.1303562949760817, 0.12752633745549247, 0.15607332985382527, 0.1106113224523142, 0.34768924000672996, 0.12498342781327665, 0.19509043777361512, 0.17973428912227973, 0.22013345413142815, 0.16358799068257213, 0.0795083363482263, 0.17209662473760545, 0.17200341098941863, 0.17393369256751612, 0.1505819713929668, 0.18150169897126034, 0.16551514039747417, 0.2204123086994514, 0.21420783537905663, 0.20147382805589586, 0.11319323937641457, 0.12300463946303353, 0.11261480205575936, 0.1643456195597537, 0.07846440916182473, 0.17292683565756306, 0.1807100945734419, 0.28057783492840827, 0.15789764758665115, 0.2103531945613213], [0.01090961908630561, 0.010881877606152557, 0.038679119024891406, 0.04883429304754827, 0.12752633745549247, 0.01042881222019787, 0.04376099008368328, 0.05526690627448261, 0.07929631959996186, 0.03362324910995085, 0.034726054582279176, 0.05357253859983757, 0.04912251722998917, 0.0030344154947670177, 0.005787907684862148, 0.009927067512762733, 0.030408037164306734, 0.013839785096934065, 0.10992605297360569, 0.012222776113048894, 0.024030289059737697, 0.031592358282068744, 0.07920884265331551, 0.03690946046845056, 0.015150793606153456, 0.006068669572414365, 0.02528536097088363, 0.023497881593357306, 0.028868449953733943, 0.020285137288738042, 0.029603901602968108, 0.11074346926761791, 0.012623677794181276, 0.038005890892236494, 0.03987750198575668, 0.056453118013450876, 0.0508271116996184, 0.00807490068837069, 0.009819677816267358, 0.01157398875875515, 0.04684854706283659, 0.029789210311719216, 0.023155478775152005, 0.02234307012258796, 0.05038756731664762, 0.039199394232127815, 0.039373906547552906, 0.03011603173945332, 0.06867331423563883, 0.06148213331471197, 0.03211486735381186, 0.04534985404461622, 0.030328222892421763, 0.037777595134684816, 0.3371736902045086, 4.533792743459344, 36.68354317545891, 57.774246856570244, 48.06638337671757, 52.39994443953037, 43.710418716073036, 28.174346275627613, 20.853271521627903, 35.403334870934486, 38.41528885066509, 38.594460636377335, 32.070552706718445, 23.800393380224705, 7.336761262267828, 1.601687679067254, 0.3432333853561431, 0.03204617416486144, 0.35123643872793764, 1.0768996202386916, 2.007724866271019, 0.9674813447054476, 0.7820659596472979, 1.7951761465519667, 1.990912549663335, 7.0236974861472845, 7.719851480796933, 4.362713573500514, 9.73360899835825, 4.815585147589445, 3.057922488078475, 2.996615865267813, 1.053767055273056, 2.000541351735592, 3.530977154150605, 0.95171207212843, 2.111022798344493, 1.7765614204108715, 5.843538763001561, 0.5510263633914292, 1.763122254051268, 5.979148261249065, 0.8777306950651109, 0.32993124914355576, 0.3067221835954115, 0.22512087947688997, 0.12171915062936023, 0.10151113732717931, 0.34014287462923676, 1.3847645628266037, 1.4008543244563043, 4.015302490442991, 1.8123205890879035, 1.4434965862892568, 3.7206126283854246, 0.9686135652009398, 0.6597130594309419, 1.345654686447233, 0.6835412245709449, 0.42822867922950536, 0.16012714826501906, 1.068573435768485, 10.312886964529753, 17.030319459736347, 42.16576360166073, 40.76834298670292, 53.22552613914013, 40.50716780126095, 14.842271469533443, 29.106597751379013, 35.50124801695347, 53.99823747575283, 44.35848534107208, 16.639090552926064, 0.5306634935550392, 0.17738595575792715, 0.011308757239021361, 0.06177140021463856, 0.05739128915593028, 0.029068497715343256, 0.01086338143068133, 0.047711783554404974, 0.08579809727962129, 0.025087706635531504, 0.04020045496872626, 0.03922503914509434, 0.05837010030518286, 0.038680002180626616, 0.05368219834053889, 0.02419026270217728, 0.05618156246782746, 0.06254610590985976, 0.027785689890151843, 0.09362384414998814, 0.07245774788316339, 0.01728523537167348, 0.08585719449911267, 0.04043625383928884, 0.031577244444633834, 0.10350121374358423, 0.05686210817657411, 0.0650623872934375, 0.03480447732727043, 0.047694502645754255, 0.09043456098879687, 0.03843263322778512, 0.09081419178983197, 0.05147778596438002, 0.03594537352910265, 0.018348220910411328, 0.06232430023374036, 0.016077451255114283, 0.01475230761570856, 0.04361100945970975, 0.1239366210938897, 0.08234092107159086, 0.047564563719788566, 0.02503350387996761, 0.02158757491997676, 0.04020218788355123, 0.06440357537940145, 0.07411112674162723, 0.04336748483183328, 0.07757198400213383, 0.044214045265107416, 0.0725480895198416, 0.0647942344949115, 0.0390301548759453, 0.03983821639849339, 0.08669064118294045, 0.0586413181736134, 0.07176420345786028, 0.041302462632302195, 0.022754804376745597, 0.05166390918020625, 0.0334942527115345, 0.08590290337451734, 0.08709127476322465, 0.01313823289819993, 0.018694520003919024, 0.10849742611753754, 0.019013290984730702, 0.08006424206541851, 0.05371485654904973, 0.017089165521610994, 0.038809826073702425, 0.03702851950947661, 0.0073294597314088605, 0.04158994837780483, 0.049101648037321866, 0.027193977402930614, 0.03489394694042858, 0.0069295761841203785, 0.02431805682135746, 0.013827451530232793, 0.05242288505542092, 0.05394974628870841, 0.04642227970180102, 0.023913821969472338, 0.06905894158990122, 0.05369819904444739, 0.012977273127035005, 0.04174700537987519, 0.05661606766807381, 0.03704126589582302, 0.028526657551992685, 0.07873553055105731, 0.03652857914858032, 0.027802965232694987, 0.030515097532770596, 0.08205991427530535, 0.04795698914676905, 0.007777935397825786, 0.04229707410559058, 0.03566552448319271, 0.007290173216460971, 0.7220609451178461, 11.376210507005453, 55.94511240720749, 60.63452437520027, 53.22983130812645, 43.15433755517006, 21.90756294876337, 20.195511616766453, 31.70271534472704, 53.11194643378258, 60.678020641207695, 55.81824101507664, 36.692776679992676, 13.74046454206109, 3.3958583045750856, 0.23130403831601143, 0.19680362631333992, 0.04105356114450842, 0.1154122238222044, 0.3693620301783085, 0.18854699592338875, 0.7855270989239216, 0.9131919359788299, 1.7179708206094801, 1.5277368784882128, 1.32656047353521, 2.41974079515785, 0.5576347431633621, 1.670462682377547, 0.7158086774870753, 1.6750536672770977, 1.2817310728132725, 2.323849853128195, 1.579372426494956, 2.476978786289692, 2.230905652977526, 3.553279582411051, 3.067255737259984, 2.174103925935924, 1.5612989338114858, 2.4846700485795736, 3.9013629918918014, 2.7964217076078057, 0.9467620658688247, 0.7917127513792366, 0.3541379392845556, 0.3321060980670154, 0.47777362691704184, 0.5966799636371434, 1.4656353858299553, 0.6839782604947686, 1.0319247585721314, 1.6660030279308558, 0.77208062983118, 2.1946783969178796, 0.4191651561995968, 0.6967649899888784, 0.3728638688335195, 0.22067637968575582, 0.2235672526876442, 0.14910551311913878, 1.0734964278526604, 4.506052331998944, 11.264613345265388, 32.92618699371815, 54.57991026341915, 66.51176780462265, 58.23724061250687, 23.85080337524414, 25.90944930911064, 29.590241499245167, 56.94442078471184, 53.81462752819061, 27.43839606642723, 1.809285858180374, 0.12282100244192407, 0.045275275624589995, 0.0684622029075399, 0.1268170669209212, 0.0495306019729469, 0.009947093440132448, 0.04697576972830575, 0.035703878675121814, 0.031597798224538565, 0.056537244163337164, 0.01829219803767046, 0.0020217617156959022, 0.023916653262858745, 0.09867006243439391, 0.00910618167836219, 0.04963757884979714, 0.06560079316841438, 0.05148432057467289, 0.1574556392733939, 0.05048288505349774, 0.0687598338117823, 0.03346750570926815, 0.06292190722888336, 0.01598595001269132, 0.005988051461827126, 0.0442388367082458, 0.024202378262998536, 0.03390675694390666, 0.033009281469276175, 0.04541874019196257, 0.029322315931494813, 0.02548205608036369, 0.029543535310949665, 0.03662718831037637, 0.07036011942545883, 0.04392679700686131, 0.03126180199615192, 0.03288212559709791, 0.017452474639867432, 0.040865178089006804, 0.06539106965647079, 0.05228092704783194, 0.0501973697100766, 0.026206329130218364, 0.08448895619949326, 0.03112916907412, 0.04348702626884915, 0.09177056781481951, 0.09050123553606682, 0.1553988066734746, 0.22213661461137235, 0.2369334956165403, 0.09671791718574241, 0.20473311800742522, 0.21095322095789015, 0.21719897253206, 0.17599882237846032, 0.0963227532338351, 0.0874946617113892, 0.14070106175495312, 0.17256113496841863, 0.2606465091230348, 0.16241415054537356, 0.07136601154343225, 0.07856609823647887, 0.28853926865849644, 0.07476177503122017, 0.21367115870816633, 0.16662781272316352, 0.17238735366845503, 0.11968516133492813, 0.12102288994356059, 0.13848664151737466, 0.1019046017609071, 0.13453773310175166, 0.13464178220601752, 0.0740529052563943, 0.08623347821412608, 0.17785260337404907, 0.0763460822054185, 0.11672048174659722, 0.13758882094407454, 0.11912859510630369, 0.10405171662569046, 0.14119979983661324, 0.0914973313047085, 0.06387685090885498, 0.12847683567088097, 0.11101493204478174, 0.17521226458484307, 0.13593714160379022, 0.09947302911314182, 0.1647775643505156, 0.09787288450752385, 0.16734674602048472, 0.19470845436444506, 0.20220617938321084, 0.09611527842935175, 0.15190602221991867, 0.15415498201036826, 0.18134737678337842, 0.5894171283580363, 8.54627626016736, 59.5610211789608, 80.64730569720268, 66.74301579594612, 69.14416775107384, 56.26356951892376, 40.05056910216808, 31.822610311210155, 47.549348920583725, 56.552205830812454, 51.83840297162533, 43.63506495952606, 28.79802580922842, 10.467660259455442, 2.390164607204497, 0.49805204034782946, 0.17276751139434054, 0.4539665684569627, 2.9222609801217914, 3.843577355146408, 4.4147323071956635, 3.292841794900596, 8.222192600369453, 2.741936668753624, 17.28051133453846, 22.874825745821, 12.71675767377019, 22.22043626010418, 13.830934837460518, 11.995296087116003, 10.690254215151072, 3.6687919590622187, 5.595330856740475, 7.549028797075152, 2.276922846212983, 7.325600311160088, 6.0059586726129055, 12.308691870421171, 4.247548403218389, 4.553014487028122, 11.32488951086998, 3.983939685858786, 1.3158334116451442, 1.1941267736256123, 1.4018075983040035, 0.7749912142753601, 1.5050136228092015, 1.6974295978434384, 6.008270373567939, 10.283222906291485, 17.111264616250992, 11.633769236505032, 6.025505298748612, 10.279007982462645, 3.8874590629711747, 3.7999763572588563, 2.932374137453735, 1.6246441472321749, 0.6284216197673231, 0.31452420400455594, 2.297420371323824, 12.593366894870996, 24.64057009667158, 53.06859835982323, 55.30011981725693, 64.42286029458046, 51.7594888061285, 26.535670906305313, 44.79513891041279, 47.87060648202896, 73.36303576827049, 60.01573517918587, 28.223515637218952, 0.9489218343514949, 0.4288525879383087, 0.1413299873820506, 0.1798955726553686, 0.30148187885060906, 0.18171536328736693, 0.1033310689672362, 0.11441541559179313, 0.10714498814195395, 0.1185900779091753, 0.17383951402734965, 0.14383553731022403, 0.11828940419945866, 0.11999413225566968, 0.17551071185152978, 0.12064162641763687, 0.1755089603830129, 0.15963032492436469, 0.2071463447646238, 0.29290844046045095, 0.1582592516206205, 0.2415523407398723, 0.26427632372360677, 0.12918981694383547, 0.1277080745785497, 0.1806140161352232, 0.17418795236153528, 0.18150395510019735, 0.11989138933131471, 0.11202806752407923, 0.15237851795973256, 0.11920735923922621, 0.39390990044921637, 0.15892724390141666, 0.14278096030466259, 0.13751282502198592, 0.16188768582651392, 0.11164221752551384, 0.16496863769134507, 0.12400431980495341, 0.21003945905249566, 0.10541317911702208, 0.10508204766665585, 0.19035939476452768, 0.10037883519544266, 0.2962538640713319, 0.1866729839821346, 0.11646528684650548], [0.0448008540115552, 0.03817360884568188, 0.0022048592882129014, 0.07892892681411467, 0.06885986789711751, 0.09884951374260709, 0.06800416420446709, 0.028990071259613615, 0.03839609358692542, 0.041095555570791475, 0.09717899869428948, 0.01841355588112492, 0.023206842815852724, 0.017524485228932463, 0.0023419543731506565, 0.047255796889658086, 0.04989621360437013, 0.0652420315600466, 0.023101634105842095, 0.10616028434014879, 0.028245144239917863, 0.05161238928849343, 0.04673890958656557, 0.03718684187333565, 0.0843460185569711, 0.012365564398351125, 0.022062779498810414, 0.04757391106977593, 0.09055700051249005, 0.008501098473061575, 0.04986136977095157, 0.05879879077838268, 0.027415360054874327, 0.031639673907193355, 0.019616033641796093, 0.030713462474523112, 0.06273340171901509, 0.024150941862899344, 0.038110470632091165, 0.06721987738274038, 0.0360168052429799, 0.07289444984053262, 0.026757869163702708, 0.033341032612952404, 0.040955953882075846, 0.009375031168019632, 0.05430972873000428, 0.025673404015833512, 0.10294977575540543, 0.06127371969341766, 0.04108825283765327, 0.044515479676192626, 0.03314149878860917, 0.08628889438114129, 0.0818894429539796, 0.08277804605313577, 0.5462551256641746, 17.148044742643833, 54.04701545834541, 61.098711267113686, 52.55645424127579, 43.66999268531799, 43.012259379029274, 37.626219391822815, 28.52029111236334, 17.5919122248888, 20.401190780103207, 32.258597016334534, 47.58353568613529, 47.99016326665878, 37.0205432921648, 25.943565778434277, 18.30377172678709, 10.338159408420324, 6.29303801804781, 2.604931457899511, 0.9503054351080209, 0.21280980727169663, 0.118364932568511, 0.7136416656430811, 0.8552927803248167, 0.9820644871797413, 0.7069550931919366, 0.7864468276966363, 0.45844174863304943, 1.4602232887409627, 1.9967783661559224, 0.19147947372402996, 1.5952903660945594, 3.4247840149328113, 2.673864746466279, 2.698496449738741, 2.086853007785976, 1.0666984738782048, 2.2375754825770855, 6.631415085867047, 4.098250139504671, 1.9562220736406744, 0.8565718273166567, 0.9629803674761206, 0.8795657590962946, 0.7818128576036543, 1.5831111883744597, 2.561596683226526, 0.7230377302039415, 1.973042346071452, 0.9658090188167989, 0.18337771471124142, 0.14440693164942786, 0.3380633768392727, 1.7157081607729197, 5.735748996958137, 11.854397747665644, 20.88101763278246, 34.27483342587948, 43.15359279513359, 37.37851448357105, 88.23926791548729, 62.19917021691799, 26.53825856745243, 58.49578633904457, 40.914889723062515, 42.034492045640945, 49.47782903909683, 53.12858574092388, 29.200323522090912, 4.47319739498198, 0.2221369559993036, 0.045596195122925565, 0.1282193697988987, 0.0015479090052394895, 0.06051635056792293, 0.09273472154745832, 0.02230941187008284, 0.014049311012058752, 0.03848876185656991, 0.044065122201573104, 0.06321673281490803, 0.06912026525242254, 0.06117955970694311, 0.05172365577891469, 0.008794112291070633, 0.013371457444009138, 0.01692125832050806, 0.017076207623176742, 0.033500798454042524, 0.10972513133310713, 0.03240246442146599, 0.027029669618059415, 0.0465158125734888, 0.07326643652049825, 0.048470354959135875, 0.01891398791485699, 0.029699976330448408, 0.040858450520318, 0.011919816588488175, 0.03452459488471504, 0.04258337983628735, 0.05511745628609788, 0.028232362601556815, 0.02547231168136932, 0.047233981458703056, 0.06607909992453642, 0.017158534064947162, 0.030799475534877274, 0.015953421680023894, 0.036621239996748045, 0.047312014576164074, 0.0065618443295534234, 0.00982774217845872, 0.06274141691392288, 0.09265710774343461, 0.03425271650485229, 0.03157001963700168, 0.046160802521626465, 0.019506186508806422, 0.02403720216534566, 0.05144289018062409, 0.008681498802616261, 0.052592673600884154, 0.011529904259077739, 0.06036292266799137, 0.03608667102525942, 0.03215473552700132, 0.07809072296367958, 0.061500230585807, 0.022029835563444067, 0.056274646340170875, 0.018531017449276987, 0.009981299954233691, 0.029485529048542958, 0.02708464235183783, 0.03647751196695026, 0.05039602780016139, 0.04910881347313989, 0.07831874041585252, 0.04542855138424784, 0.06564525523572229, 0.037178915736149065, 0.06784919634810649, 0.018808094573614653, 0.04461992211872712, 0.03918473681551404, 0.054685611685272306, 0.039381606329698116, 0.06091193754400592, 0.0319925131771015, 0.059064253291580826, 0.04739547650387976, 0.09940522650140338, 0.01669954912358662, 0.015671271976316348, 0.03771074247197248, 0.10662559609045275, 0.04417203599587083, 0.0808008162130136, 0.0687771184311714, 0.13805567636154592, 0.10371009120717645, 0.03141876994050108, 0.07006536805420183, 0.027586944597715046, 0.04747494567709509, 0.01435084561308031, 0.06866999683552422, 0.08740726640098728, 0.04089410700544249, 0.028899009739689063, 0.026296761679986957, 0.1291692297672853, 0.07652726271771826, 0.06528388868900947, 2.2948994440957904, 30.939307808876038, 60.2366591244936, 62.9365548491478, 48.903577253222466, 32.43637427687645, 25.62735054641962, 26.19368925690651, 27.555902861058712, 27.921840324997902, 41.79290100932121, 64.88828971982002, 64.85879570245743, 51.40563279390335, 34.79342579841614, 19.678061082959175, 9.160555098205805, 3.31778721883893, 0.8549156505614519, 0.4531132470583543, 0.5511300859507173, 0.4366902314359322, 0.5666450096759945, 0.32447830424644053, 0.16964571172138676, 0.25290777906775475, 0.28532318654470146, 0.45704012853093445, 0.1764152414398268, 0.17132103588664904, 1.589628669898957, 0.25889058772008866, 1.5390368783846498, 0.6981318478938192, 1.1085231858305633, 0.7321747555397451, 2.123372135683894, 1.375571193639189, 0.6728559010662138, 0.8287092880345881, 0.23710674257017672, 0.8264354069251567, 0.442177671357058, 0.02815087849739939, 0.4189025249797851, 0.6047671171836555, 0.8583060780074447, 1.4050864661112428, 0.27677391248289496, 0.7657353265676647, 0.6637936248444021, 0.523688611574471, 0.41252685303334147, 0.2350425033364445, 0.6791999575216323, 2.1131611336022615, 4.9256030190736055, 16.175885908305645, 31.026062853634357, 46.440766006708145, 56.23665936291218, 76.90911188721657, 76.24042376875877, 38.148387372493744, 57.070980593562126, 38.14338304102421, 25.882843136787415, 52.17459373176098, 56.699649319052696, 41.05384826660156, 7.859873492270708, 0.2639151056064293, 0.1638643367914483, 0.08603332098573446, 0.09394708657055162, 0.010959940409520641, 0.061449842469301075, 0.06937626167200506, 0.10570130310952663, 0.04477971022424754, 0.037950166733935475, 0.05160477485333104, 0.07076822643284686, 0.037791595750604756, 0.05152457095391583, 0.03291197477665264, 0.04306670351070352, 0.09024359154864214, 0.03779735110583715, 0.1431425049668178, 0.07799367231200449, 0.018237117692478932, 0.04265411764208693, 0.012034492319799028, 0.0533271771564614, 0.04213485917716753, 0.011192574947926914, 0.01478150834373082, 0.01808078057365492, 0.04807306104339659, 0.05748445095377974, 0.05304545789840631, 0.09150987360044383, 0.045232505653984845, 0.019755336616071872, 0.07833141629816964, 0.014817838327871868, 0.039335496694548056, 0.030476364845526405, 0.0036803140392294154, 0.04625124063750263, 0.04008954099845141, 0.025457780429860577, 0.02780995811917819, 0.054587158374488354, 0.01216949454828864, 0.003397337304704706, 0.07298855416593142, 0.05716937957913615, 0.0278583146064193, 0.12414488999638706, 0.10185976861976087, 0.11126035285997204, 0.22913646243978292, 0.12879267887910828, 0.1328548093442805, 0.08504708093823865, 0.11786427232436836, 0.18472555879270658, 0.11353243055054918, 0.14958857704186812, 0.13062087062280625, 0.06771513479179703, 0.09832973577431403, 0.09809172901441343, 0.11195586397661828, 0.09205511465552263, 0.20376029598992318, 0.2129320686799474, 0.17563261702889577, 0.07958764967042953, 0.11285542117548175, 0.1307954831281677, 0.15154658525716513, 0.2025013612001203, 0.09493952355114743, 0.13948122330475599, 0.08181437471648678, 0.2036613380187191, 0.17024507018504664, 0.10724988329457119, 0.2095621987245977, 0.07750228891381994, 0.20766725821886212, 0.13588587404228747, 0.1553752805921249, 0.17759659211151302, 0.20441926375497133, 0.08468541011097841, 0.2222913524019532, 0.14431129849981517, 0.17689159634755924, 0.24190091266063973, 0.22855445538880304, 0.12850472558056936, 0.19376502139493823, 0.18982294073794037, 0.08056369260884821, 0.20249794732080773, 0.21279272303218022, 0.08937187230912969, 0.09789406540221535, 0.13176186330383644, 0.2530145592754707, 0.22355267690727487, 0.22132195910671726, 1.37652434874326, 26.585767418146133, 73.52123647928238, 81.57433435320854, 70.15691980719566, 55.437999218702316, 56.41174256801605, 49.18663926422596, 42.08375260233879, 27.049701623618603, 30.4717979952693, 46.98028385639191, 61.358495727181435, 61.04817397892475, 48.34857903420925, 35.00775329768658, 23.16560134291649, 13.42041626572609, 8.234547637403011, 3.5870578698813915, 1.1385800479911268, 0.37785881955642253, 0.40231864142697304, 1.0903973272070289, 1.11467897426337, 2.2267170902341604, 1.2456573522649705, 3.442813097499311, 4.016290437430143, 6.823822511360049, 12.287698946893215, 6.311429031193256, 8.637444768100977, 12.571184635162354, 10.014696065336466, 10.782468616962433, 12.46277455240488, 10.536798499524593, 12.663264144212008, 19.566105790436268, 13.101459480822086, 6.534500336274505, 3.4227029141038656, 2.3540826933458447, 3.292962913401425, 2.566124852746725, 4.576080674305558, 5.814122166484594, 1.9859797018580139, 3.377899043262005, 1.988942592870444, 0.6015618110541254, 0.3983260353561491, 0.5988627683836967, 2.757972995750606, 8.201936837285757, 16.704488843679428, 26.974072381854057, 43.6490748077631, 53.379053100943565, 51.65553778409958, 91.71424984931946, 73.02122130990028, 35.66664174199104, 69.5151038467884, 55.001607835292816, 52.11307503283024, 65.15762686729431, 69.56327006220818, 41.554178819060326, 6.924149477854371, 0.3633221355266869, 0.18019520735833794, 0.23456858267309144, 0.14641960646258667, 0.13337423850316554, 0.16330653859768063, 0.19602720625698566, 0.145695953106042, 0.14205010811565444, 0.18062977935187519, 0.1528010968468152, 0.2144931911607273, 0.09418821035069413, 0.12156488781329244, 0.14795671304455027, 0.18633187806699425, 0.19471226900350302, 0.2219390103709884, 0.20090639678528532, 0.2645681658759713, 0.12229094572830945, 0.09496851926087402, 0.09670827668742277, 0.2348072425229475, 0.14590451144613326, 0.15702461474575102, 0.13042221253272146, 0.16693200421286747, 0.15633683680789545, 0.16298039437970147, 0.11450183126726188, 0.21176180569455028, 0.14582116826204583, 0.12295884152990766, 0.20677991677075624, 0.21209201688179746, 0.2223060469259508, 0.143838906660676, 0.11998732676147483, 0.1423450672882609, 0.15976502472767606, 0.12813331035431474, 0.09403128322446719, 0.1451323661603965, 0.17535854189191014, 0.13212889985879883, 0.1495442708255723, 0.2214032391202636, 0.1143412824603729], [0.041630002087913454, 0.013265539982967312, 0.030033562434255145, 0.05433555917988997, 0.04606952948961407, 0.03666789511044044, 0.022131476398499217, 0.06800050541642122, 0.02351118644583039, 0.06880098590045236, 0.02171960299165221, 0.022871382789162453, 0.03221231876523234, 0.09648932827985846, 0.05519872887816746, 0.02541753747209441, 0.010691650313674472, 0.011351772118359804, 0.08133309936965816, 0.023222483578138053, 0.04540682872175239, 0.025383151914866176, 0.08249608188634738, 0.06271615420700982, 0.050005765733658336, 0.03549280445440672, 0.03143181689665653, 0.037970616613165475, 0.04751730004500132, 0.03483269378193654, 0.06195318557729479, 0.01224038078362355, 0.03871659377182368, 0.03270653716754168, 0.05952623650955502, 0.06109592337452341, 0.06380543403793126, 0.02667958371603163, 0.04175558831775561, 0.06508687074529007, 0.021817855922563467, 0.00848204846988665, 0.07478913059458137, 0.006426499785447959, 0.055917153804330155, 0.08501519085257314, 0.05277422889776062, 0.01664252620685147, 0.08917573752114549, 0.052351958001963794, 0.08067494054557756, 0.04151982284383848, 0.04810809783521108, 0.0500727000326151, 0.15686592872953042, 0.04954557851306163, 0.012648757747228956, 0.2529828547267243, 3.0839993013069034, 26.291349716484547, 54.381834492087364, 58.91428828239441, 51.61312445998192, 50.81952944397926, 47.05635957419872, 40.92832960188389, 33.98783482611179, 29.20479968190193, 29.193043112754822, 28.244057334959507, 31.19627472013235, 35.66609837114811, 38.88247758150101, 39.11767736077309, 40.682304203510284, 43.89692410826683, 40.24093508720398, 33.71641919016838, 27.347425147891045, 28.246960379183292, 17.967630364000797, 9.16836652904749, 5.391854625195265, 3.6325093684718013, 0.8586763206403702, 0.347105615073815, 0.09347265382530168, 0.06223047792445868, 0.1703759701922536, 0.9092090371996164, 0.9426414838526398, 1.1849806644022465, 0.8281565364450216, 1.1013250658288598, 1.368373311124742, 0.6384802737738937, 0.2738588157808408, 0.2092797521618195, 0.2016703487606719, 0.3399408026598394, 0.16961396264377981, 0.8440890815109015, 1.5190308331511915, 3.997356528416276, 8.276862166821957, 12.839349545538425, 18.286490254104137, 22.654224783182144, 25.29798422008753, 35.558974519371986, 40.04348628222942, 39.94561493396759, 41.539883986115456, 31.584013514220715, 34.94476407766342, 34.81125444173813, 28.072507940232754, 79.29226040840149, 45.83158649504185, 32.86505587399006, 39.979953691363335, 48.621100410819054, 60.21891787648201, 37.77673311531544, 11.406178548932076, 0.07110259364708327, 0.041836601158138365, 0.06098091274907347, 0.03903695665940177, 0.08342300949152559, 0.04916059311653953, 0.06520495386212133, 0.045483711510314606, 0.01985992192203412, 0.03946432982047554, 0.007594245034852065, 0.056580014133942313, 0.024217191530624405, 0.02316185196832521, 0.058981533511541784, 0.009976451874535996, 0.01192044834169792, 0.03520594211295247, 0.01556184693981777, 0.048105607929755934, 0.034934902359964326, 0.03377812048711348, 0.05449642711027991, 0.02305370435351506, 0.08518338378053159, 0.025072824719245546, 0.04661643295548856, 0.033417095328331925, 0.056281911965925246, 0.024733071368245874, 0.056635593573446386, 0.01971495079487795, 0.07721152287558652, 0.04911308082228061, 0.05308633168169763, 0.06278734101215377, 0.02395249714027159, 0.047652708599343896, 0.025768174418772105, 0.05282629426801577, 0.03394942301383708, 0.06367429654346779, 0.011851883173221722, 0.045854766794946045, 0.04909370334644336, 0.03906956662831362, 0.03974267230660189, 0.06545284602907486, 0.027758564392570406, 0.06535137217724696, 0.05257579716271721, 0.0642551681085024, 0.037313756547519006, 0.03174714060151018, 0.05916758251260035, 0.02581334894784959, 0.05912870510655921, 0.01770355989719974, 0.04859631968429312, 0.08991652706754394, 0.07338001480093226, 0.0216062009712914, 0.03879518721078057, 0.01970010227523744, 0.06086138615501113, 0.014468966764979996, 0.019838559201161843, 0.03660300913907122, 0.01831369248975534, 0.022256361298786942, 0.04991014371626079, 0.016171314382518176, 0.014523445042868843, 0.04409488603414502, 0.013924657105235383, 0.060305665974738076, 0.04500005015870556, 0.030507026676787063, 0.038469477149192244, 0.05444181617349386, 0.02495640957931755, 0.03313043336675037, 0.055306540671153925, 0.02936570002930239, 0.025916064041666687, 0.013629976238007657, 0.07851134258089587, 0.026009437351603992, 0.06631634227233008, 0.04139086355280597, 0.05898866926145274, 0.02300301566720009, 0.008102300780592486, 0.011477777661639266, 0.01896974918054184, 0.022986248695815448, 0.04140099757933058, 0.02630150214827154, 0.0436444395018043, 0.04483134143811185, 0.09642036791774444, 0.034046265864162706, 0.02766979054285912, 0.02069761740131071, 0.046294003186631016, 0.09999058063840494, 0.014178392757457914, 0.07933056229376234, 0.43371956271585077, 9.33587009087205, 41.85926824808121, 65.99625706672668, 61.974967047572136, 56.24398157000542, 48.64513412117958, 41.66180044412613, 21.46587084978819, 17.16205459088087, 23.108883686363697, 40.108975768089294, 49.71192687749863, 53.08345176279545, 64.18289557099342, 69.02840316295624, 64.65346992015839, 59.38198998570442, 51.11476980149746, 44.42234471440315, 35.67503169178963, 26.698885448276997, 17.146475426852703, 5.465166941285133, 3.0962353572249413, 0.4184102435829118, 0.6032076571136713, 0.47360145079437643, 0.33325063821393996, 0.0942909087461885, 0.35726273723412305, 0.27392436226364225, 0.8512757427524775, 0.5721049604471773, 0.5000135663431138, 0.7266112603247166, 0.663296920247376, 0.3593282529618591, 0.43849632202181965, 0.20818069082451984, 0.38813581340946257, 0.431601443560794, 0.14957409031921998, 0.25010632001794875, 0.6661613134201616, 0.7892069639638066, 0.6789979746099561, 2.113661519251764, 5.638484191149473, 14.337841887027025, 21.111933141946793, 30.088776648044586, 35.786540508270264, 48.6477217823267, 59.14928287267685, 64.41159769892693, 60.47664664685726, 59.513793513178825, 56.21976546943188, 33.33188742399216, 101.24472364783287, 51.77574813365936, 23.148321770131588, 41.74861058592796, 49.7403759509325, 66.67291715741158, 50.270880684256554, 20.41580479592085, 0.5983720009680837, 0.13846838468452916, 0.1328975273645483, 0.06909165545948781, 0.0366583659342723, 0.03785862652875949, 0.04433508584043011, 0.04632722913811449, 0.043266389475320466, 0.04604602567269467, 0.015801899244252127, 0.059233529755147174, 0.05043516124715097, 0.029881642949476372, 0.03586529950553086, 0.045368734281510115, 0.05221651976171415, 0.026616015056788456, 0.028907008236274123, 0.030588713016186375, 0.025319252999906894, 0.006753240504622227, 0.07613310808665119, 0.021423428552225232, 0.05134797320351936, 0.06767681028577499, 0.018590828985907137, 0.01975512881472241, 0.029644565729540773, 0.019342025298101362, 0.08007641328731552, 0.023711557041679043, 0.016748948328313418, 0.024273104936582968, 0.05693951417924836, 0.03543023398378864, 0.05142575399077032, 0.037558361000264995, 0.09218969571520574, 0.04670102665841114, 0.029346174123929814, 0.05530275942874141, 0.034319661936024204, 0.047097489368752576, 0.0076862258902110625, 0.06313419115031138, 0.03258277662098408, 0.05311005443218164, 0.07198393854196183, 0.021141980178072117, 0.04254856197803747, 0.16693966317689046, 0.0917376832512673, 0.11959274910623208, 0.10007191260228865, 0.12651179189560935, 0.15214477112749591, 0.13319305056938902, 0.12203769525513053, 0.16611730417935178, 0.21543221577303484, 0.12890662823338062, 0.11227996728848666, 0.06575810621143319, 0.19557718274882063, 0.1103210610745009, 0.1736831880407408, 0.12637568201171234, 0.1473169817472808, 0.07245237473398447, 0.07896241251728497, 0.2019834311795421, 0.114966089167865, 0.1900961995124817, 0.13784337759716436, 0.2282125034253113, 0.19334860233357176, 0.14229200372938067, 0.1959481675294228, 0.1249021477997303, 0.12697604979621246, 0.13265585439512506, 0.20971037592971697, 0.10349083851906471, 0.07390340702841058, 0.1880323313525878, 0.20193289092276245, 0.12751333502819762, 0.11979012328083627, 0.15773336577694863, 0.2705925644841045, 0.09101578136323951, 0.06549654368427582, 0.11430391532485373, 0.08211298525566235, 0.15053677459945902, 0.14109097130130976, 0.0838178394769784, 0.21806661738082767, 0.1845633698394522, 0.23406733613228425, 0.11316905278363265, 0.1912209391593933, 0.19431481923675165, 0.3250141942407936, 0.2544101234525442, 0.15710467763710767, 0.12357006693491712, 0.5749853246379644, 5.496721398085356, 36.97964608669281, 74.49827805161476, 80.40788814425468, 69.75402742624283, 69.51614499092102, 65.22084787487984, 53.37524190545082, 47.34612822532654, 39.19018507003784, 39.975032955408096, 39.6622109413147, 44.92947690188885, 49.947932213544846, 55.22889643907547, 53.59255224466324, 52.87245288491249, 57.252987027168274, 53.88620428740978, 44.03225764632225, 37.8113454580307, 35.566707104444504, 23.780583143234253, 13.679209928959608, 6.5688172448426485, 5.012672021985054, 1.274962448514998, 0.5844490730669349, 0.2722444664686918, 0.5618917616084218, 0.26959372276905924, 2.3677868954837322, 1.806221678853035, 2.4410125287249684, 1.3194867968559265, 2.0917269587516785, 2.111247223801911, 1.0797155066393316, 0.7446178409736603, 0.40762924239970744, 0.4876759252510965, 0.309466200415045, 0.33579911396373063, 1.1442983848974109, 2.2416274901479483, 5.609989520162344, 11.205631010234356, 16.745760329067707, 25.32336875796318, 30.495016649365425, 35.9639947861433, 46.97697423398495, 53.624132350087166, 50.86215555667877, 56.00760005414486, 41.064449697732925, 46.64503924548626, 47.50121310353279, 34.332411736249924, 96.00602835416794, 50.24542585015297, 43.681707456707954, 53.61328773200512, 63.50296765565872, 78.70686382055283, 54.96550977230072, 18.818353414535522, 0.34838338557165116, 0.3482843830715865, 0.19267453928478062, 0.10639345971867442, 0.16809802211355418, 0.16147028713021427, 0.1632310324930586, 0.33200709556695074, 0.12640382425161079, 0.21095470525324345, 0.12568290199851617, 0.17258872801903635, 0.12309911486227065, 0.10233101013000123, 0.1873554481426254, 0.1322609873022884, 0.10590866659185849, 0.17151127802208066, 0.11634091773885302, 0.13546304282499477, 0.22668348625302315, 0.10713046431192197, 0.23808054422261193, 0.08761393968597986, 0.20104025054024532, 0.18516942247515544, 0.1310480062966235, 0.1975217877770774, 0.13891230773879215, 0.14504473336273804, 0.18008075334364548, 0.16065880801761523, 0.18961813766509295, 0.12223157391417772, 0.16553039895370603, 0.13438721070997417, 0.128314602188766, 0.12301069538807496, 0.19240067194914445, 0.18398652813630179, 0.2062488507363014, 0.10096482015796937, 0.14628805336542428, 0.1374935737112537, 0.16480756195960566, 0.17829015880124643, 0.10358336949138902, 0.1531093701487407, 0.15159801609115675, 0.10942658758722246, 0.11158919107401744], [0.009423641840839991, 0.049020468213711865, 0.04086702974746004, 0.017569151386851445, 0.07460866996552795, 0.05543600462260656, 0.04502252981183119, 0.00558881729375571, 0.01112715834096889, 0.07766254828311503, 0.07360622141277418, 0.029221971999504603, 0.024431490382994525, 0.01883222364995163, 0.02117547144734999, 0.08810673316475004, 0.04056734309415333, 0.029578891226265114, 0.0234844709848403, 0.025736295465321746, 0.03680971210997086, 0.013225863840489183, 0.06941539511899464, 0.10884933770284988, 0.06348465554765426, 0.021064277316327207, 0.056128216892830096, 0.00904430975424475, 0.03808612447755877, 0.013684284749615472, 0.00601504708356515, 0.021431924287753645, 0.04719999109511264, 0.044741252131643705, 0.052986130613135174, 0.03914188149792608, 0.048635078346705996, 0.0368331417121226, 0.014148956397548318, 0.11401761701563373, 0.06195263267727569, 0.03939009278838057, 0.011556954614206916, 0.027618986823654268, 0.02716625818720786, 0.026700816561060492, 0.02717428080359241, 0.04674585608881898, 0.07529071852331981, 0.055603462824365124, 0.045867357330280356, 0.06683499217615463, 0.040293056445079856, 0.03573138266801834, 0.04423733756993897, 0.03520252452290151, 0.027394733915571123, 0.027011052843590733, 0.14236048911698163, 0.23434411268681288, 2.423868323676288, 19.427751414477825, 45.66869683563709, 56.6006076335907, 60.06943769752979, 50.67756146192551, 53.22527915239334, 49.028465151786804, 42.49029278755188, 42.567174062132835, 39.731025248765945, 24.720021933317184, 23.852653875947, 22.93678142130375, 21.662892177700996, 30.794624872505665, 29.31321356445551, 26.89390618354082, 31.2459684535861, 33.200805857777596, 36.36575482785702, 49.593065455555916, 49.68665063381195, 39.764820635318756, 35.54469868540764, 33.58879163861275, 26.88717294484377, 25.407600738108158, 18.73090110719204, 16.51301521807909, 15.650869030505419, 13.536010812968016, 13.959807772189379, 15.821710713207722, 15.785353314131498, 17.138980329036713, 16.091623529791832, 20.15470750629902, 19.005523771047592, 22.58144348859787, 36.73818804323673, 43.29976335167885, 49.38469223678112, 46.65894649922848, 43.425164222717285, 33.28464075922966, 30.84179174154997, 35.973292887210846, 34.040492400527, 45.424863919615746, 27.28921227157116, 22.204876095056534, 21.069350726902485, 26.876499317586422, 30.848870761692524, 35.21249011158943, 37.14469023048878, 30.528946928679943, 42.46888853609562, 58.43276672065258, 60.024531707167625, 49.39945064485073, 14.69547774642706, 0.47536405152641237, 0.4435156151885167, 0.022815081611042842, 0.11376496026059613, 0.025699329089547973, 0.07952545027364977, 0.04808021163626108, 0.017353485127387103, 0.0579565348016331, 0.050285900506423786, 0.02115940395015059, 0.0023428268605130143, 0.016494631017849315, 0.02820150966726942, 0.05571378678723704, 0.09409197606146336, 0.0321926963806618, 0.05437190586235374, 0.083032335533062, 0.021054980061308015, 0.01645807467866689, 0.03414767292269971, 0.06785527453757823, 0.025757511612027884, 0.017667352367425337, 0.04037291153508704, 0.024471894757880364, 0.07577205324196257, 0.03218693360395264, 0.04091269409400411, 0.034260965476278216, 0.034866598798544146, 0.08669867864227854, 0.026765071706904564, 0.07267490771482699, 0.0033265259799009073, 0.03432904268265702, 0.056841858677216806, 0.021438496005430352, 0.09873114118818194, 0.029868538476875983, 0.0410705637477804, 0.05566933956288267, 0.020936273540428374, 0.006088972877478227, 0.03283437581558246, 0.019053450450883247, 0.03205834909749683, 0.07427614327752963, 0.03766498535696883, 0.07310250352020375, 0.01040776676745736, 0.026617658913892228, 0.036910028211423196, 0.0075547613869275665, 0.0285802795769996, 0.009897532818285981, 0.036812632461078465, 0.09946830905391835, 0.035850608692271635, 0.04472020853427239, 0.04412965565279592, 0.03408842356293462, 0.021895417776249815, 0.03797923665842973, 0.022584683720197063, 0.04426700863405131, 0.008068279803410405, 0.05518465033674147, 0.02955712774564745, 0.053273701705620624, 0.024659480004629586, 0.04476951311517041, 0.05437320091004949, 0.03131669494905509, 0.008807590620563133, 0.05188063114474062, 0.018213858784292825, 0.01279372516364674, 0.06754685280611739, 0.017575511592440307, 0.045764521637465805, 0.03826734951871913, 0.07641272706678137, 0.019721952958207112, 0.025542652438161895, 0.043228692084085196, 0.05007781714084558, 0.0695782074762974, 0.014155610679154051, 0.06353332559228875, 0.03292921857791953, 0.06564550756593235, 0.03763575958146248, 0.03367852055816911, 0.0703462932142429, 0.07046424274449237, 0.03433008540014271, 0.02141039087291574, 0.03102460232184967, 0.02370835096371593, 0.04751733715238515, 0.042930285635520704, 0.08102064777631313, 0.05346064499462955, 0.018620620649016928, 0.09422608956811018, 0.05280104269331787, 0.1147885451791808, 0.035080344750895165, 0.05520361963135656, 0.32019225298427045, 0.5353037570603192, 8.597189728170633, 34.96737286448479, 58.746208101511, 67.02984720468521, 63.834256678819656, 53.16262811422348, 46.13624654710293, 36.49718977510929, 28.472290188074112, 27.289425060153008, 26.263983584940434, 20.04207205027342, 22.6916166767478, 28.5562751814723, 33.44110116362572, 45.425069108605385, 49.01922404766083, 49.69858959317207, 55.09289413690567, 68.83880093693733, 71.16782516241074, 57.233676463365555, 49.502588510513306, 42.432235702872276, 33.91997806727886, 27.36730758100748, 21.034417301416397, 18.623055294156075, 14.11034619435668, 9.94094392284751, 6.809369036927819, 6.444342099130154, 9.0088995359838, 8.27368838712573, 7.026811894029379, 11.106897108256817, 12.91635051369667, 17.764533162117004, 22.858720310032368, 20.891451872885227, 30.648752599954605, 45.456052646040916, 53.6074398458004, 60.1143778860569, 60.56160628795624, 58.575050085783005, 54.301673993468285, 57.668069154024124, 46.88124977052212, 59.18606869876385, 43.74028131365776, 31.96643829345703, 28.81081212311983, 19.534468688070774, 23.346165753901005, 24.7861060872674, 29.705350622534752, 39.62749220430851, 40.71057088673115, 50.18575385212898, 61.297782585024834, 59.156662076711655, 25.36082334816456, 2.3699675034731627, 0.08667078873259015, 0.042515621753409505, 0.1298973656957969, 0.059185768841416575, 0.11376435912097804, 0.012598776884260587, 0.0245387028917321, 0.07635844638571143, 0.04135801980737597, 0.014926437725080177, 0.049124302095151506, 0.04410470093716867, 0.018687237679841928, 0.03793477459112182, 0.05221066050580703, 0.029171977221267298, 0.0075263612507114885, 0.10104592205607332, 0.06425058163586073, 0.05292833215207793, 0.04246702592354268, 0.02819331635691924, 0.012499145414039958, 0.053437300739460625, 0.04942842308082618, 0.03127267445961479, 0.04522389303019736, 0.05404202493082266, 0.02452932585583767, 0.012362999350443715, 0.025791535372263752, 0.022855797687952872, 0.014985264060669579, 0.04399738638312556, 0.043209949144511484, 0.06822004012065008, 0.019923089821531903, 0.06345645393594168, 0.05817553887027316, 0.04587732437357772, 0.038159333635121584, 0.07170964076067321, 0.010076589860545937, 0.06926640897290781, 0.06166998573462479, 0.0625720588141121, 0.06731628978741355, 0.05000362463761121, 0.02111742622219026, 0.02207053123129299, 0.08165332867065445, 0.034522004789323546, 0.06239029942662455, 0.1281443831976503, 0.1782469658064656, 0.12123252439778298, 0.16118130966788158, 0.1536894476157613, 0.19847929186653346, 0.12265227516763844, 0.1590642740484327, 0.1611443210276775, 0.24577168776886538, 0.09695341548649594, 0.14405571768293157, 0.15311895869672298, 0.11925310522201471, 0.3498748055426404, 0.08147492379066534, 0.14420647756196558, 0.13084260950563475, 0.10619957363815047, 0.168697128247004, 0.09590611152816564, 0.1266241233679466, 0.22494067117804661, 0.11307871114695445, 0.08641673673992045, 0.1197652390692383, 0.12460380443371832, 0.08705978543730453, 0.14429636648856103, 0.19658444041851908, 0.10735446674516425, 0.19283217145130038, 0.10988212525262497, 0.1973261873354204, 0.19301417574752122, 0.12523103796411306, 0.1234096591360867, 0.10899984525167383, 0.1811185578117147, 0.10831404142663814, 0.182545114075765, 0.18328484235098585, 0.0905934399634134, 0.11416470326366834, 0.15315658558392897, 0.09624651240301318, 0.09236054553184658, 0.24237376463133842, 0.12044805203913711, 0.14019386318977922, 0.18135870195692405, 0.12246427431819029, 0.17941616009920835, 0.19892771233571693, 0.17295713012572378, 0.1348649905412458, 0.11616379677434452, 0.24007714411709458, 0.6595874880440533, 5.283180931583047, 29.08722259104252, 65.96227169036865, 78.07419016957283, 86.65102154016495, 68.59774187207222, 72.77333781123161, 64.58300650119781, 57.40196943283081, 56.77399232983589, 51.888495683670044, 35.758672803640366, 33.18009316921234, 35.05837418138981, 32.45032712817192, 42.33197048306465, 40.444455966353416, 37.837066277861595, 43.01688753068447, 44.24809746444225, 51.48074336349964, 64.12469029426575, 68.87164637446404, 54.466927126049995, 52.78903216123581, 46.05600245296955, 39.59149293601513, 38.57651799917221, 28.55166032910347, 25.504881218075752, 22.704572081565857, 20.419541895389557, 19.341243356466293, 23.57305157929659, 22.92809698730707, 24.796340838074684, 22.310960702598095, 29.315077364444733, 27.46136963367462, 33.3315834403038, 49.66174677014351, 57.03637205064297, 61.649605706334114, 60.296106934547424, 56.02518171072006, 45.04330359399319, 41.810011491179466, 49.77099470794201, 42.83217944204807, 60.54244011640549, 35.17717860639095, 31.233757808804512, 32.40920953452587, 36.62957467138767, 42.01228603720665, 48.41252200305462, 48.98345656692982, 46.4116595685482, 54.21354912221432, 70.48067763447762, 80.06485775113106, 65.79922243952751, 21.400020383298397, 1.36472811922431, 0.5109920678660274, 0.07400998685625382, 0.2027680742321536, 0.19855846418067813, 0.1519395672949031, 0.21833589824382216, 0.1374647783813998, 0.17802911577746272, 0.20306591293774545, 0.12674497469561175, 0.07828905450878665, 0.1364860637113452, 0.12578803463838995, 0.10730342924944125, 0.13046723121078685, 0.13976824149722233, 0.16999192361254245, 0.15962269564624876, 0.10388325652456842, 0.14680966443847865, 0.10310055789886974, 0.1359024239354767, 0.11617486961768009, 0.2036764333024621, 0.1481907270499505, 0.07140040266676806, 0.18119870976079255, 0.09572469352860935, 0.11944197438424453, 0.11277584068011492, 0.18842421501176432, 0.19514483719831333, 0.07153531769290566, 0.11746120449970476, 0.17600520484847948, 0.15993136970791966, 0.11598876124480739, 0.11889125627931207, 0.28838879079557955, 0.17731531814206392, 0.09566323627950624, 0.11719319270923734, 0.10577112436294556, 0.2035739872371778, 0.08652180258650333, 0.22310928819933906, 0.09721577211166732, 0.20150424126768485, 0.10245305631542578, 0.19463282951619476, 0.20592053944710642, 0.08229999162722379], [0.06275191088207066, 0.03558135009370744, 0.05192225820792373, 0.04838139742787462, 0.025170391163555905, 0.06098007412219886, 0.05781825784652028, 0.016811374080134556, 0.04733978945296258, 0.06831549515482038, 0.016044284675444942, 0.040657914796611294, 0.02787035224173451, 0.07252545401570387, 0.06247917903237976, 0.01660841895500198, 0.03754201519768685, 0.08341195891262032, 0.09225695655914024, 0.03774616889131721, 0.03537249860528391, 0.08102707477519289, 0.0397683209303068, 0.07550941460067406, 0.014377285551745445, 0.07005868130363524, 0.007119409674487542, 0.02105382602167083, 0.04378364043077454, 0.06857045998913236, 0.06548223507707007, 0.015745043310744222, 0.0208255859251949, 0.08766706261667423, 0.015450746504939161, 0.07669873593840748, 0.044023443188052624, 0.06266004784265533, 0.02972912789118709, 0.10755653871456161, 0.03163795583532192, 0.0937965270713903, 0.02348024630919099, 0.008254592266894178, 0.04835322921280749, 0.029159468322177418, 0.021216386048763525, 0.0513922052050475, 0.03596431684854906, 0.018996984144905582, 0.05600147291261237, 0.02694677543331636, 0.06746287879650481, 0.0625844304158818, 0.014554757181031164, 0.06163364647363778, 0.026708406876423396, 0.03436150793277193, 0.03886451122525614, 0.11133346182759851, 0.08043599125812761, 0.08741138532059267, 1.252889670431614, 8.757075648754835, 26.057012490928173, 48.26539009809494, 48.796001225709915, 57.97945484519005, 58.853331953287125, 63.254666179418564, 57.836134135723114, 62.39405415952206, 46.72993429005146, 49.76464904844761, 40.65845288336277, 44.89872135221958, 48.720864057540894, 45.50982356071472, 45.6789942830801, 43.074268251657486, 13.969334810972214, 45.85863724350929, 59.98619556427002, 39.710213765501976, 38.465628549456596, 34.59883823990822, 27.977459840476513, 26.707989759743214, 27.16748010367155, 30.853863693773746, 33.582666367292404, 30.795115046203136, 26.761099509894848, 33.82406361401081, 35.10406292974949, 34.30070623755455, 36.10343210399151, 32.167778089642525, 30.34056443721056, 82.37791523337364, 49.27564948797226, 26.485929675400257, 29.527632258832455, 26.80067628622055, 34.37833607196808, 54.01941753923893, 56.16809204220772, 48.80395419895649, 46.45628437399864, 37.47201606631279, 46.29076145589352, 48.46590153872967, 46.959445774555206, 55.95062971115112, 60.61775587499142, 59.824411645531654, 62.16438688337803, 65.5341562628746, 65.43892577290535, 42.61311359703541, 16.43836062401533, 1.9186543207615614, 0.03129857541352976, 0.05795548466267064, 0.08097269761492498, 0.06080987739551347, 0.085949057538528, 0.03611479471146595, 0.04098043362319004, 0.04703845152107533, 0.10053062665974721, 0.037473199554369785, 0.03341303949127905, 0.044823819771409035, 0.11393962471629493, 0.029351328339544125, 0.09981971597881056, 0.01336116571110324, 0.03180890213116072, 0.027328922114975285, 0.08634788769995794, 0.0923622450500261, 0.04961174839991145, 0.04640389670385048, 0.03453868455835618, 0.05531481190701015, 0.040355229866690934, 0.0743228911596816, 0.05631058113067411, 0.04081734296050854, 0.04719954580650665, 0.03133771628199611, 0.04671755799790844, 0.04191968830127735, 0.06200329909916036, 0.07554303389042616, 0.07246830122312531, 0.05010861255868804, 0.011384108420315897, 0.01815473187889438, 0.009152075163001427, 0.012724872412945842, 0.04177419396000914, 0.04003708228992764, 0.023863122150942218, 0.05739306659961585, 0.040853541213436984, 0.014818433901382377, 0.030401142612390686, 0.02149307354557095, 0.062067216567811556, 0.0344395299180178, 0.024731511002755724, 0.10124298452865332, 0.026001592850661837, 0.06133870956546161, 0.01995370341319358, 0.03291687666205689, 0.0031695264942754875, 0.004430118360687629, 0.025780623946047854, 0.015499802466365509, 0.01808616114431061, 0.0557749249128392, 0.06434377311961725, 0.06121114922279958, 0.06410189234884456, 0.022955675922275987, 0.009693559095467208, 0.0481602151558036, 0.04858288310060743, 0.0682501342089381, 0.08060155698331073, 0.02673471415619133, 0.04126176696445327, 0.01783424839231884, 0.03917744892532937, 0.041973460611188784, 0.05340080562746152, 0.019732112959900405, 0.07258711164467968, 0.07572083763079718, 0.06525210992549546, 0.03786866778682452, 0.026849867645069025, 0.02866418864869047, 0.05757687802542932, 0.032222619774984196, 0.05327595412381925, 0.017859021281765308, 0.0318668044928927, 0.045880508187110536, 0.017160853276436683, 0.06929583512828685, 0.049910321831703186, 0.03576626731955912, 0.06133550719823688, 0.005038063936808612, 0.011925529270229163, 0.03915206376404967, 0.04111225018277764, 0.0642117227835115, 0.03103773091424955, 0.08530468781827949, 0.09361169519252144, 0.043204568573855795, 0.05637951551761944, 0.06281441455939785, 0.049227879935642704, 0.051884931890526786, 0.03332790402055252, 0.057996833420475014, 0.03262224774516653, 0.07961971045006067, 0.01238596232724376, 0.0702486488444265, 0.23056058445945382, 0.17261974979192019, 5.046723419800401, 19.274321347475052, 41.70419096946716, 61.42833597958088, 62.55726300179958, 63.865992575883865, 59.65231508016586, 63.886633068323135, 56.24759137630463, 49.16487403213978, 31.514349952340126, 26.59116692841053, 22.889551855623722, 31.502929665148258, 32.28885479271412, 23.161875642836094, 30.207647569477558, 31.709760166704655, 16.79700057953596, 57.707765623927116, 64.32046338915825, 45.001711025834084, 52.20913767814636, 53.48782226443291, 49.27252225577831, 51.02788366377354, 50.84030292928219, 58.83036218583584, 61.47743694484234, 59.09354366362095, 57.30460725724697, 63.72473515570164, 64.98149111866951, 62.4381697922945, 62.017790749669075, 55.2001927793026, 40.870093926787376, 73.138627409935, 63.54422964155674, 48.668727055191994, 47.6595202088356, 38.99576090276241, 39.433683604002, 39.43457655608654, 35.367464795708656, 33.40964265167713, 31.181041337549686, 35.34749686717987, 24.51068926602602, 22.77741227298975, 28.851074762642384, 35.428261533379555, 45.6669033318758, 52.510206922888756, 56.72347404062748, 59.29952301084995, 67.95554593205452, 59.76173020899296, 31.00845269858837, 5.266354959458113, 0.11867533583426848, 0.0767105509294197, 0.027303273491270375, 0.024176421648007818, 0.041695715553942136, 0.060230315721128136, 0.03373703148099594, 0.09940454372554086, 0.018289669169462286, 0.06041908840415999, 0.030412655178224668, 0.0446089272008976, 0.05018667536205612, 0.06129970970505383, 0.08322850000695325, 0.007196094402388553, 0.0966874000732787, 0.02594145105831558, 0.050020523340208456, 0.061110287642804906, 0.08815190769382752, 0.02846737850632053, 0.0332301075104624, 0.03525507971062325, 0.07311083041713573, 0.06199194795044605, 0.06630497256992385, 0.029780944641970564, 0.01667421962338267, 0.02351097864448093, 0.026134615400223993, 0.11819575258414261, 0.03721336252056062, 0.02305206420714967, 0.03934102198400069, 0.02249177239718847, 0.03572320048988331, 0.07849982444895431, 0.013523579164029798, 0.029202418263594154, 0.03476802674413193, 0.03366503573488444, 0.016079633169283625, 0.055622914514970034, 0.026425195901538245, 0.008803264827292878, 0.02115522565873107, 0.039461672931793146, 0.01922649702464696, 0.029547782251029275, 0.07436537169269286, 0.025986877917603124, 0.022048630453355145, 0.033464893349446356, 0.16647157579427585, 0.0932237300730776, 0.13547126582125202, 0.1875497869332321, 0.0797559464990627, 0.11391346401069313, 0.18791747657814994, 0.17507036594906822, 0.18529250024585053, 0.16065175761468709, 0.12253151289769448, 0.0851272774161771, 0.11090982166933827, 0.12310756050283089, 0.17717822862323374, 0.20086207572603598, 0.1797879463993013, 0.16590258601354435, 0.15082535130204633, 0.12198726632050239, 0.150413503870368, 0.19857722567394376, 0.13893299881601706, 0.18034092063317075, 0.14713528915308416, 0.11675871719489805, 0.11727413133485243, 0.1379320939304307, 0.15847033326281235, 0.1522274612216279, 0.14906324038747698, 0.055139761534519494, 0.0945735334244091, 0.19804713927442208, 0.12934293685248122, 0.14416441263165325, 0.14383161877049133, 0.13716751855099574, 0.2140009542927146, 0.14931690646335483, 0.1463071710895747, 0.16865847719600424, 0.11403378841350786, 0.14172120310831815, 0.13665104313986376, 0.16329248232068494, 0.13221642875578254, 0.16119996726047248, 0.24991273821797222, 0.08868488104781136, 0.2337074835668318, 0.09995675354730338, 0.1300377503503114, 0.15666649880586192, 0.1242726952477824, 0.3479131608037278, 0.10722937033278868, 0.17843474401161075, 0.1161283666442614, 0.23007070762105286, 0.24660080031026155, 0.1767402427503839, 2.117649642750621, 13.671996016055346, 36.921269819140434, 66.02923169732094, 72.36067235469818, 81.48565471172333, 79.74213346838951, 86.97824478149414, 76.4174410700798, 81.49895399808884, 58.326866403222084, 63.822576105594635, 52.95810408890247, 58.04859213531017, 62.93010659515858, 57.4561583250761, 60.36141403019428, 53.43629702925682, 19.847547188401222, 60.400141552090645, 66.65550649166107, 55.264796912670135, 51.66242301464081, 52.288416624069214, 45.27569152414799, 44.22167748212814, 43.07567037642002, 49.56048220396042, 49.83884386718273, 49.14399795234203, 44.398987367749214, 48.99888373911381, 52.930578365921974, 49.04658257961273, 51.87833122909069, 45.809418484568596, 41.815771982073784, 99.26419392228127, 62.42653101682663, 37.72990062832832, 39.3392700701952, 35.372780710458755, 48.12852904200554, 68.5816003382206, 67.23661690950394, 64.33284312486649, 55.0127412378788, 53.224177211523056, 59.88423943519592, 59.11371298134327, 62.971702963113785, 68.6164140701294, 74.54605668783188, 75.37369027733803, 82.42232725024223, 82.72343829274178, 84.19748559594154, 61.798633709549904, 25.382352992892265, 2.6379174878820777, 0.12116407611756586, 0.2859682316193357, 0.24912021355703473, 0.1870132883777842, 0.15335662406869233, 0.11337085757986642, 0.12535231973743066, 0.1706590104731731, 0.1314020255813375, 0.0844204262830317, 0.12437584635335952, 0.15488084696698934, 0.2600751741556451, 0.10178934622672386, 0.20358364999992773, 0.15179676323896274, 0.1801946433261037, 0.16741732426453382, 0.21381372527685016, 0.12865095835877582, 0.2138952279346995, 0.11385676392819732, 0.20072077080840245, 0.15984551806468517, 0.12014646548777819, 0.13812738267006353, 0.17719424417009577, 0.12974770419532433, 0.13627254782477394, 0.1188073490629904, 0.11948645871598274, 0.18460840336047113, 0.11764756520278752, 0.1438889719429426, 0.16921878384891897, 0.17178208770928904, 0.1356133574154228, 0.13084229780361056, 0.11702877731295303, 0.08969665097538382, 0.10968360074912198, 0.13671739114215598, 0.09729881101520732, 0.17632685165153816, 0.2151796332327649, 0.15090878354385495, 0.11863026520586573, 0.09490074633504264, 0.08411101749516092, 0.06660612125415355, 0.22940455586649477, 0.15649038716219366, 0.15943867270834744, 0.14111301308730617], [0.03737941064173356, 0.05773702607257292, 0.08573431710829027, 0.035866891412297264, 0.011001684360962827, 0.02441101081785746, 0.018864076628233306, 0.053184684802545235, 0.021541481983149424, 0.057388517234358005, 0.008788369923422579, 0.017389219538017642, 0.04084010091901291, 0.02088236578856595, 0.067177114833612, 0.0053570983800455, 0.05479901185026392, 0.08561733979149722, 0.028792721204808913, 0.06678857083898038, 0.06545703174197115, 0.03230628208257258, 0.08280344234663062, 0.0499667324766051, 0.020753465869347565, 0.012160757614765316, 0.023975281073944643, 0.06095463329984341, 0.04026188253192231, 0.015708850623923354, 0.03753758457605727, 0.015236510735121556, 0.041171822376782075, 0.008821447445370723, 0.02331253021111479, 0.03630513703683391, 0.026698120709625073, 0.050395055586704984, 0.046837322079227306, 0.029979200116940774, 0.036480339549598284, 0.022314412090054248, 0.03323807817650959, 0.03885711572365835, 0.03501632709230762, 0.01896169316751184, 0.012357926771073835, 0.009288085784646682, 0.024196732374548446, 0.037919642199994996, 0.09449849487282336, 0.003514414115670661, 0.00918348192499252, 0.03271407367719803, 0.02769301976513816, 0.09693826825241558, 0.05238134333922062, 0.014713231685163919, 0.02305136287759524, 0.11118202659417875, 0.04763218450534623, 0.10266832367051393, 0.07413773273583502, 0.18449985684128478, 0.05804728461953346, 1.744447206147015, 7.7753327786922455, 20.283556692302227, 33.834357261657715, 38.25163923203945, 42.56962493062019, 51.33562155067921, 55.37349008023739, 54.76261965930462, 61.78014390170574, 63.100630044937134, 55.82543782889843, 55.25804087519646, 52.106923162937164, 72.69973576068878, 62.41455785930157, 46.96424871683121, 58.65953855216503, 49.536535888910294, 38.41132566332817, 31.627559177577496, 32.48528905212879, 28.05756524205208, 28.06032769382, 24.313018172979355, 33.59808973968029, 25.967909172177315, 36.14768072962761, 29.231394454836845, 29.187841191887856, 39.639389365911484, 39.411994367837906, 35.56042604148388, 49.121301770210266, 91.44439592957497, 44.488787949085236, 42.32121326029301, 45.6060191988945, 57.46652416884899, 63.70383247733116, 65.5127178132534, 62.93468154966831, 57.62727074325085, 58.794773295521736, 59.68222327530384, 69.25455942749977, 64.57060396671295, 60.93701474368572, 58.122030794620514, 50.75266443192959, 35.952694192528725, 31.556314900517464, 15.474509093910456, 7.690744092687964, 1.3203188334591687, 0.2236661661299877, 0.03554642462404445, 0.050928195923916064, 0.015711262603872456, 0.06724914026563056, 0.02396898766164668, 0.06828642523032613, 0.06581745576113462, 0.04357479265308939, 0.12092013217625208, 0.014169203113851836, 0.003467973992883344, 0.058055589252035134, 0.0620562068070285, 0.06531557097332552, 0.09304184452048503, 0.016026797820813954, 0.05542843842704315, 0.04462509117729496, 0.046162134676706046, 0.0212449197715614, 0.04757687223900575, 0.04107106098672375, 0.07767936534946784, 0.022243561106733978, 0.060212481912458315, 0.019056727032875642, 0.0521781544375699, 0.03750985051738098, 0.03750015064724721, 0.04622777763870545, 0.027474466551211663, 0.012500276261562249, 0.04864590257056989, 0.03519591198710259, 0.05387418081227224, 0.11075523230829276, 0.022026115548214875, 0.049132139174616896, 0.030910127898096107, 0.04191404797893483, 0.032324008279829286, 0.0476686870388221, 0.010558515514276223, 0.07752509511192329, 0.04052342279464938, 0.02893184791901149, 0.07342830635025166, 0.0538782626244938, 0.031377499108202755, 0.043424088435131125, 0.013274053344503045, 0.027421712838986423, 0.02622033716761507, 0.06534693413414061, 0.046605579045717604, 0.06330162708763964, 0.033318371133645996, 0.08405362721532583, 0.01789453119272366, 0.03482802567305043, 0.04809989710338414, 0.009393032887601294, 0.05294568727549631, 0.051030478716711514, 0.05361316376365721, 0.03678825290990062, 0.01823965212679468, 0.06790976301999763, 0.06494537286926061, 0.03892317057761829, 0.01764870590704959, 0.08499712697812356, 0.028449678284232505, 0.026411180442664772, 0.05901507116504945, 0.054074905783636495, 0.08556204236811027, 0.035727119029616006, 0.0848690397106111, 0.007723418621026212, 0.03861583238176536, 0.023844175120757427, 0.06210786028532311, 0.029454998948494904, 0.015038945457490627, 0.04219571528665256, 0.02335737633984536, 0.05553911119932309, 0.02933530351583613, 0.052918758447049186, 0.06861642119474709, 0.03095943247899413, 0.027685843197104987, 0.04610058465914335, 0.02996665225509787, 0.05615534610114992, 0.06277608263189904, 0.0287842699981411, 0.043884219994652085, 0.046136393284541555, 0.028727265635097865, 0.04933403673931025, 0.03706450625031721, 0.006414967274395167, 0.0660106516443193, 0.07019653523457237, 0.06059657673176844, 0.012548857248475542, 0.04991289337340277, 0.08424383224337362, 0.05974360785330646, 0.05924958240939304, 0.05713919272238854, 0.015504798047913937, 0.02166572678106604, 0.07694573752814904, 0.057123299629893154, 0.2262432294082828, 0.09584909232216887, 0.3788386029191315, 6.68387602083385, 16.148229092359543, 35.264877900481224, 49.339866042137146, 52.70608641207218, 56.39140225946903, 68.51039975881577, 64.73260447382927, 64.78790670633316, 63.346902430057526, 61.89560830593109, 54.05671253800392, 51.27903878688812, 42.72670850157738, 44.83119897544384, 24.819050319492817, 40.52895203232765, 66.83643758296967, 44.442643225193024, 38.93473617732525, 27.383863292634487, 27.332170866429806, 24.89566370844841, 23.745938502252102, 22.99269162118435, 29.762155674397945, 22.98600398004055, 23.07817943394184, 23.56561727821827, 26.05497770011425, 29.0238780900836, 28.26529249548912, 23.999500796198845, 30.89299589395523, 102.39822015166283, 40.294132232666016, 23.85300535708666, 26.604944989085197, 28.84865239262581, 43.00058260560036, 56.72114856541157, 59.919117763638496, 54.40847106277943, 58.50528962910175, 56.451929211616516, 66.41420423984528, 70.89051604270935, 69.30075734853745, 68.55867236852646, 63.491230085492134, 53.45084644854069, 48.55180352926254, 33.425244614481926, 18.154578432440758, 4.019699329510331, 0.19489231402985752, 0.03782235406106338, 0.019939775156672113, 0.016864491444721352, 0.0703132527996786, 0.02379727880907012, 0.0836976189748384, 0.06030570308212191, 0.018525449486332946, 0.11249438859522343, 0.03788299494772218, 0.013375518847169587, 0.032269360235659406, 0.05447723146062344, 0.03416294261114672, 0.02386746185948141, 0.025788535240280908, 0.033539965297677554, 0.01940526741236681, 0.04300318680179771, 0.07090747560141608, 0.030829872048343532, 0.023633119453734253, 0.010309619592590025, 0.04056928009958938, 0.009655452595325187, 0.09193321689963341, 0.044044145397492684, 0.024845319348969497, 0.05345488592865877, 0.042157349962508306, 0.05041354619606864, 0.06162762765598018, 0.04457240611372981, 0.06178757903398946, 0.008601185436418746, 0.0528680512070423, 0.04496145105804317, 0.07308290340006351, 0.06309097589110024, 0.11055583207053132, 0.03264122817199677, 0.02668442622962175, 0.06956546480068937, 0.09076049740542658, 0.0565066491253674, 0.06591457320610061, 0.03592195134842768, 0.04927569279971067, 0.034746066594379954, 0.05267296284728218, 0.02232636066764826, 0.03931338440452237, 0.011826631598523818, 0.03564692255167756, 0.01803275619749911, 0.2235851384466514, 0.09517135564237833, 0.19612448697444052, 0.07416540742269717, 0.07082161653670482, 0.07233062540763058, 0.17634298594202846, 0.21454153466038406, 0.17415847425581887, 0.12957505095982924, 0.1027212239569053, 0.12213876092573628, 0.16878927330253646, 0.16310537204844877, 0.10634787700837478, 0.16152090160176158, 0.1979397059767507, 0.1760196321993135, 0.07974696651217528, 0.1707672156044282, 0.15135356748942286, 0.16161223029484972, 0.13935741822933778, 0.1295742197544314, 0.12092021381249651, 0.11077240560553037, 0.12222358098370023, 0.11558327401871793, 0.12852414016379043, 0.13319909165147692, 0.16500555211678147, 0.11570344257052056, 0.08628838972072117, 0.1171398619771935, 0.0902724610932637, 0.10745371415396221, 0.14159483020193875, 0.18761530373012647, 0.12443810512195341, 0.1113423379138112, 0.08886477022315376, 0.20019959018100053, 0.10548642909270711, 0.0887342041824013, 0.1048708547023125, 0.09577413540682755, 0.10365174355683848, 0.09120303264353424, 0.08781590033322573, 0.12161512378952466, 0.23826597724109888, 0.11178388609550893, 0.11751714017009363, 0.08874569262843579, 0.16533751477254555, 0.30920229270122945, 0.16670181968947873, 0.14041220303624868, 0.06911144111654721, 0.2560415421612561, 0.11548288370249793, 0.19987500447314233, 0.16389518044888973, 0.3698852442903444, 0.1185186833026819, 3.297418411821127, 10.44639565050602, 27.62733142822981, 46.03824220597744, 57.12439812719822, 62.85378009080887, 75.29071033000946, 78.56357350945473, 82.45914727449417, 84.81838747859001, 82.11841195821762, 74.26944673061371, 70.48911318182945, 68.34769248962402, 89.17917028069496, 76.30078732967377, 60.52603259682655, 73.07116582989693, 57.929080948233604, 60.65628580749035, 41.06247000396252, 49.828668013215065, 42.079717218875885, 40.5608095228672, 31.719863824546337, 45.62665969133377, 38.219348564743996, 43.35484139621258, 38.00802290439606, 39.7221565246582, 51.92243166267872, 48.893868774175644, 49.62411358952522, 60.22267587482929, 108.39916974306107, 51.95520490407944, 56.899484395980835, 60.51202654838562, 69.0228022634983, 78.72992858290672, 79.81528714299202, 78.26194569468498, 71.77462980151176, 76.522566229105, 79.16680634021759, 87.77984976768494, 86.510429084301, 82.76656597852707, 79.88943636417389, 69.0287147462368, 53.18422235548496, 43.87052692472935, 25.78365135937929, 12.157098054885864, 1.930597317405045, 0.4066432249965146, 0.16826024075271562, 0.16738492209697142, 0.10183448364841752, 0.1671342839836143, 0.12158466604887508, 0.2190455250092782, 0.14981519925640896, 0.13476549822371453, 0.31465969048440456, 0.11180225425050594, 0.09375302237458527, 0.20527013606624678, 0.12860721617471427, 0.18016572925262153, 0.13432641397230327, 0.0927168432099279, 0.19564311514841393, 0.15560556901618838, 0.12539499322883785, 0.12725704174954444, 0.07532436749897897, 0.19739606796065345, 0.22661589144263417, 0.14167826244374737, 0.1279113785130903, 0.17378515913151205, 0.11265038803685457, 0.124769733811263, 0.13571675342973322, 0.18899075570516288, 0.1568122862954624, 0.07922572651295923, 0.11345018574502319, 0.17237910098629072, 0.11764667462557554, 0.1459104337845929, 0.12689855473581702, 0.19431514578172937, 0.11209041535039432, 0.24437685089651495, 0.14975646568927914, 0.1402943054563366, 0.20367144607007504, 0.19856275379424915, 0.18613446678500623, 0.175153189629782, 0.12489552784245461, 0.1394499046728015, 0.07514830780564807, 0.12771402660291642, 0.1222382606647443, 0.1181959974928759, 0.0966413201240357, 0.13165484560886398, 0.1006722061720211], [0.05333806817361619, 0.05817321223730687, 0.10730834968853742, 0.032783750211820006, 0.06426201813155785, 0.04105603991774842, 0.03513711162668187, 0.06377047146088444, 0.053553699181065895, 0.07789872193825431, 0.07213281336589716, 0.017004684996209107, 0.024176857659767848, 0.025502095923002344, 0.062182524052332155, 0.004939714990541688, 0.016163082109414972, 0.040145810635294765, 0.039082754592527635, 0.04395958880195394, 0.035042647359659895, 0.027975271514151245, 0.0629400898469612, 0.057178363276761957, 0.035249335487606004, 0.03953177991206758, 0.031550701532978565, 0.020293658999435138, 0.03505288899759762, 0.07881417594035156, 0.060089415273978375, 0.027775971466326155, 0.06402059749234468, 0.009142839135165559, 0.029392263350018766, 0.014280132854764815, 0.05536689583095722, 0.026166716997977346, 0.046080324027570896, 0.053717550545115955, 0.047956080015865155, 0.011021000609616749, 0.022426387331506703, 0.014522468190989457, 0.027959385843132623, 0.03907551494194195, 0.03847162937745452, 0.0651612933143042, 0.003187960051036498, 0.05559382974752225, 0.06042210523446556, 0.02485023607732728, 0.08930262993089855, 0.04146402076003142, 0.11101421958301216, 0.024523388674424496, 0.0798202832811512, 0.030114957480691373, 0.034505477160564624, 0.08910501084756106, 0.03664020558062475, 0.047751547826919705, 0.025280084300902672, 0.06008266173012089, 0.10625020295265131, 0.06355796489515342, 0.05034828544012271, 0.33197838929481804, 0.016372208192478865, 0.8995498961303383, 2.8100112034007907, 5.577778173610568, 8.074081297963858, 10.534405577927828, 22.55972195416689, 34.169947654008865, 46.27009056508541, 53.80035549402237, 67.9040738940239, 61.09135866165161, 72.06745728850365, 72.6093690097332, 64.19391497969627, 59.27935749292374, 60.109468549489975, 64.32425558567047, 60.941281914711, 65.04925668239594, 66.70924320816994, 68.49532216787338, 74.16615307331085, 73.96635979413986, 79.22801345586777, 77.6877661049366, 67.22432076931, 73.15204828977585, 69.98307153582573, 67.90019050240517, 61.49388626217842, 61.06093369424343, 68.25405031442642, 73.63198533654213, 69.28411424160004, 66.12890034914017, 57.273714914917946, 53.40339079499245, 48.98303858935833, 45.59852220118046, 33.74645657837391, 27.01154977083206, 26.082604117691517, 17.918461002409458, 10.38666095584631, 8.412594683468342, 2.379765040241182, 0.399667689925991, 0.017728663042362314, 0.07560719255707227, 0.04600659907737281, 0.05417613472673111, 0.05847873959282879, 0.04869462827628013, 0.040671202950761653, 0.04810504389752168, 0.0450613701104885, 0.01636132459680084, 0.007928956420073519, 0.012585197437147144, 0.03766527479456272, 0.030212206656869967, 0.06368588146870025, 0.06610237367567606, 0.032682829260011204, 0.08599400942330249, 0.01730319720081752, 0.015878294070716947, 0.045576424308819696, 0.02139560914656613, 0.02932622333901236, 0.05155553706572391, 0.03485839435597882, 0.05591976245341357, 0.039645881406613626, 0.06068019451049622, 0.0450941693270579, 0.03608028855524026, 0.047311064627137966, 0.02772116942651337, 0.011820905001513893, 0.07181699242210016, 0.010665429308573948, 0.041731505625648424, 0.01123807694966672, 0.01793456634914037, 0.036094329989282414, 0.04069822454766836, 0.0770400051260367, 0.0798861711518839, 0.0732284237165004, 0.05082341951492708, 0.022324941310216673, 0.023130848749133293, 0.03423246700549498, 0.08520854258676991, 0.017623812418605667, 0.03637446105130948, 0.05437494124635123, 0.08238468552008271, 0.08272918305010535, 0.013275327983137686, 0.049508152005728334, 0.017570554045960307, 0.00935848591325339, 0.03971317935793195, 0.03240071295294911, 0.024590899993199855, 0.0613963002251694, 0.05675772510585375, 0.024398334935540333, 0.01837554493249627, 0.005910777654207777, 0.03052980133361416, 0.06593131605768576, 0.06388019057339989, 0.022356063273036852, 0.0510701427992899, 0.0068552936954802135, 0.014777565684198635, 0.03729986354301218, 0.04608017930877395, 0.02026125497650355, 0.04654665994166862, 0.006861501760795363, 0.05608313142147381, 0.029880639194743708, 0.0401960429007886, 0.034771945283864625, 0.035361488844500855, 0.08584442213759758, 0.03801041799306404, 0.0329673798114527, 0.07807950169080868, 0.04282267422240693, 0.025299610206275247, 0.026439905268489383, 0.026492727629374713, 0.05592302419245243, 0.05649287486448884, 0.027869485784322023, 0.02829019445925951, 0.01459282286305097, 0.03817222845100332, 0.05530071852263063, 0.06779170958907343, 0.02207315843406832, 0.03824293286015745, 0.07018765914835967, 0.09196229424560443, 0.04379871716082562, 0.051813355457852595, 0.0470663006126415, 0.05096966713608708, 0.03567460837075487, 0.03618643051595427, 0.02530720052163815, 0.06978916295338422, 0.04253385261108633, 0.022625607598456554, 0.04113602117286064, 0.01922899806231726, 0.12519014562712982, 0.06921835491084494, 0.03069795529881958, 0.09562941660988145, 0.07440645698807202, 0.03984720751759596, 0.027677336329361424, 0.013112253091094317, 0.04248703793564346, 0.04788090045622084, 0.041174980215146206, 0.12902272981591523, 0.07949577178806067, 0.5440328386612236, 1.2143247085623443, 3.1257892213761806, 6.643274249508977, 11.937732975929976, 18.380455411970615, 22.350619174540043, 37.851307913661, 49.56419080495834, 59.73366491496563, 64.39306989312172, 74.51054379343987, 69.90627765655518, 74.60256725549698, 66.14491268992424, 64.69973623752594, 65.4456590116024, 55.626111924648285, 55.471509620547295, 58.757846876978874, 51.985147297382355, 47.80918277800083, 43.12896631658077, 50.226985439658165, 49.604685232043266, 55.40355786681175, 48.715943321585655, 43.500772565603256, 53.95522378385067, 55.125853568315506, 55.968819335103035, 63.4990880638361, 71.75453647971153, 67.71628797054291, 74.89716544747353, 76.110098361969, 79.70922723412514, 72.73297637701035, 67.7460403740406, 60.977011397480965, 61.451066359877586, 51.00103810429573, 45.840819999575615, 40.92117838561535, 31.2048926576972, 20.247392132878304, 17.00444094836712, 7.637299010530114, 2.2142580337822437, 0.3588547627441585, 0.16427557566203177, 0.13653975067427382, 0.09988236808567308, 0.025399080259376206, 0.033179663732880726, 0.050206705927848816, 0.04327741036831867, 0.05929037826717831, 0.04744783873320557, 0.0416845907602692, 0.021744843434134964, 0.016987086819426622, 0.015624271763954312, 0.017785261079552583, 0.06559584304341115, 0.018457227561157197, 0.04531769678578712, 0.04877416795352474, 0.04701263962488156, 0.04003037327493075, 0.07336416994803585, 0.03405661882425193, 0.05976151216600556, 0.028972432264708914, 0.0282028863512096, 0.04121560908970423, 0.023599938031111378, 0.03247106484195683, 0.09771765689947642, 0.03899699200701434, 0.04524500713159796, 0.034528120086179115, 0.047894915915094316, 0.02119355573086068, 0.03743837427464314, 0.1115394894441124, 0.014705949361086823, 0.02559052467404399, 0.0493824507429963, 0.03430400262004696, 0.0908689400239382, 0.07382899930234998, 0.05935142733505927, 0.03697147803904954, 0.03610461615608074, 0.028170486039016396, 0.07654328568605706, 0.04373225041490514, 0.0481831215438433, 0.014200974455889082, 0.04293824888009112, 0.024885679194994736, 0.07081780931912363, 0.07633576635271311, 0.050580113820615225, 0.02267135543661425, 0.03558766948117409, 0.029326551739359275, 0.06440430268412456, 0.16985465597826988, 0.15710953128291294, 0.2062796795507893, 0.184883933106903, 0.14560778596205637, 0.1318621274549514, 0.16525820887181908, 0.11460495268693194, 0.15625435451511294, 0.25447759951930493, 0.14134293043753132, 0.09922197539708577, 0.0718329634401016, 0.18701362976571545, 0.15421059855725616, 0.07857820266508497, 0.08045917595154606, 0.13237178995041177, 0.11383464050595649, 0.17371030611684546, 0.2296576282242313, 0.17176212393678725, 0.26459099433850497, 0.10869949808693491, 0.18391783494735137, 0.1693605785840191, 0.07715750194620341, 0.09574931056704372, 0.13280195358674973, 0.19213903520721942, 0.2900716254953295, 0.14416065736440942, 0.12820494244806468, 0.16596458503045142, 0.16700559557648376, 0.10648518917150795, 0.12803291261661798, 0.1790177306975238, 0.152768338448368, 0.10570193393505178, 0.12960129330167547, 0.1891549484571442, 0.09647389902966097, 0.11642105484497733, 0.1217960445501376, 0.1454241044120863, 0.1329548953799531, 0.19644168089143932, 0.1338093596859835, 0.1457614402170293, 0.21224415715551004, 0.09306853215093724, 0.1930459841969423, 0.0613528103713179, 0.2602709230268374, 0.21764702192740515, 0.10365554335294291, 0.17561121348990127, 0.12614273669896647, 0.21150523039977998, 0.10351641292800196, 0.23265673604328185, 0.168826024455484, 0.13927802327089012, 0.20403772563440725, 0.12057757907314226, 0.3118735196767375, 0.4029720282414928, 0.4747693834360689, 1.1818461888469756, 3.403223971836269, 8.02500693127513, 12.963043358176947, 17.228188142180443, 31.90813422203064, 47.52742029726505, 64.31725636124611, 75.50428926944733, 90.81293061375618, 83.71692538261414, 95.70019036531448, 86.60241454839706, 83.26334372162819, 76.31677687168121, 75.63404470682144, 77.24466428160667, 80.61684653162956, 81.32903471589088, 80.3829462826252, 86.60521879792213, 89.02259588241577, 92.57765471935272, 96.11250624060631, 93.93203884363174, 79.31734666228294, 93.51047426462173, 86.47483259439468, 84.45783242583275, 81.19945406913757, 78.81003588438034, 88.9060029387474, 92.84160375595093, 97.27896764874458, 91.00991204380989, 80.49247920513153, 78.00919085741043, 68.06565642356873, 67.02026411890984, 52.263121381402016, 43.10194216668606, 36.508554965257645, 24.308310225605965, 14.911357462406158, 11.99761301279068, 3.9111626660451293, 0.9971730108372867, 0.16316282912157476, 0.1797830333816819, 0.27226159523706883, 0.15283910965081304, 0.1954973573447205, 0.20017521805129945, 0.2632051077671349, 0.11926273829885758, 0.11307593551464379, 0.14758072618860751, 0.23959412472322583, 0.11849946909933351, 0.14120297622866929, 0.16284054407151416, 0.12361423214315437, 0.19378167518880218, 0.15548531140666455, 0.13684858800843358, 0.15044025087263435, 0.17516196181531996, 0.21660958853317425, 0.08265023338026367, 0.09734498744364828, 0.17360956699121743, 0.14151979907182977, 0.2217925401055254, 0.1669918658444658, 0.12775992101524025, 0.09709127683890983, 0.1489050590316765, 0.11931431014090776, 0.11049615597585216, 0.11978282054769807, 0.20540096185868606, 0.11819481005659327, 0.143323767115362, 0.13795021717669442, 0.15830048534553498, 0.21222877985564992, 0.17823230096837506, 0.23892193188657984, 0.2366834512213245, 0.2619355305796489, 0.13885280233807862, 0.12644001137232408, 0.13868932204786688, 0.07685659074923024, 0.18647037766641006, 0.19833240599837154, 0.26399487163871527, 0.17085281491745263, 0.10570512517006136, 0.1828790656873025, 0.1780758413951844, 0.197556757775601, 0.09838960482738912, 0.11086085476563312, 0.1893733031465672, 0.09308834749390371, 0.24306192848598585], [0.030040507081139367, 0.0023621874061063863, 0.052255263581173494, 0.07502240245230496, 0.07894505368312821, 0.07907780905952677, 0.0172556181132677, 0.05859836266608909, 0.15723010059446096, 0.023803421936463565, 0.025026854236784857, 0.06133824943390209, 0.03394195700821001, 0.006282486028794665, 0.021556616229645442, 0.029521480537368916, 0.04510990285780281, 0.10407637819298543, 0.025420288984605577, 0.03820021855062805, 0.00822778125439072, 0.03432043005886953, 0.05161023334949277, 0.014118233339104336, 0.024361392679566052, 0.028871322065242566, 0.01639509417145746, 0.028132308107160497, 0.021988279004290234, 0.10247362864902243, 0.01720031326840399, 0.026862142767640762, 0.04768025712110102, 0.10935881466139108, 0.006426988211387652, 0.024371337458433118, 0.055545857321703807, 0.016950378339970484, 0.0322857839637436, 0.012081846907676663, 0.034557486869744025, 0.04242159164277837, 0.01839626198488986, 0.01904890850710217, 0.06472898487118073, 0.026504581583139952, 0.03507314220769331, 0.018515580777602736, 0.05853303140611388, 0.026254587282892317, 0.048841562384041026, 0.021711138797400054, 0.020883785145997535, 0.03214079057215713, 0.013425743691186653, 0.027377005862945225, 0.07237171070300974, 0.023237131717905868, 0.017501975889899768, 0.053793197657796554, 0.04754778747155797, 0.003447805665928172, 0.08470038665109314, 0.0655421189730987, 0.0760680811072234, 0.05039601666794624, 0.038321040192386135, 0.08917665778426453, 0.024634625478938688, 0.016104441310744733, 0.12239943287568167, 0.23819385532988235, 0.10734811396105215, 0.1704504669760354, 0.11878631659783423, 0.18595261091832072, 0.9650290512945503, 4.26833376288414, 6.356776272878051, 14.816283714026213, 25.187765434384346, 40.42355328798294, 55.45516289770603, 57.032880038022995, 61.78391709923744, 65.05718305706978, 61.003321185708046, 53.633829429745674, 63.7324221432209, 68.99892434477806, 57.79124714434147, 60.67839302122593, 58.37141901254654, 58.07636484503746, 58.898986503481865, 55.38208521902561, 50.755567476153374, 48.78171779215336, 47.62124486267567, 51.4878223836422, 35.17654404044151, 26.836762949824333, 18.335025049746037, 10.526362359523773, 8.422425705939531, 5.243669701740146, 3.584038456901908, 0.8935401623602957, 0.17701031028991565, 0.137239521718584, 0.06701662539853714, 0.21100779849803075, 0.12991630530450493, 0.25373515498358756, 0.21771014900878072, 0.057081735649262555, 0.0975201565597672, 0.04154801703407429, 0.02806488955684472, 0.029464940016623586, 0.033298919443041086, 0.054010502208257094, 0.017548003888805397, 0.014915846350049833, 0.025230811261280905, 0.0479697911941912, 0.04366018787550274, 0.03279608841694426, 0.008410806003666949, 0.027404446773289237, 0.028206665738252923, 0.024688171433808748, 0.018302649332326837, 0.054681433393852785, 0.039533935851068236, 0.0983308712602593, 0.06415908224880695, 0.07785773312207311, 0.04607206392392982, 0.04055673780385405, 0.02012548462516861, 0.03706571224029176, 0.07117837434634566, 0.04545538002275862, 0.06612069730181247, 0.0022140148394100834, 0.02692059617402265, 0.02856234372302424, 0.11641449425951578, 0.062199864332797006, 0.029179378288972657, 0.10427826462546363, 0.07376898924121633, 0.025280256850237492, 0.012427094934537308, 0.015918579701974522, 0.05940285816905089, 0.030861203667882364, 0.028320518613327295, 0.05126575066242367, 0.024376506517000962, 0.08216669448302127, 0.10758632852230221, 0.09313618633314036, 0.028583660059666727, 0.07028781197732314, 0.07580438861623406, 0.008120036254695151, 0.0914490842842497, 0.060109442129032686, 0.013643280162796145, 0.029638875312230084, 0.036610293318517506, 0.01270025351914228, 0.022507938228955027, 0.03461451349721756, 0.05069618571724277, 0.06550225079990923, 0.06867378178867511, 0.03472843687632121, 0.04105802516278345, 0.04945032385876402, 0.03921248200640548, 0.00732176458768663, 0.045952299842610955, 0.010785574668261688, 0.013653748155775247, 0.07734134676866233, 0.055371333874063566, 0.05550903566472698, 0.04913228018267546, 0.021205118391662836, 0.03598412105930038, 0.10295016167219728, 0.07143892013118602, 0.05035313166445121, 0.0028130472219345393, 0.03932484316464979, 0.024952661733550485, 0.03363921270647552, 0.037096782252774574, 0.04339729690400418, 0.011758902273868443, 0.015213852038868936, 0.041901943550328724, 0.019176860332663637, 0.07124804717022926, 0.09106618803343736, 0.027880679226655047, 0.041991327816504054, 0.01575095080625033, 0.03230911708669737, 0.00044580321002740675, 0.05938976668403484, 0.029749948844255414, 0.03926327459339518, 0.030840640611131676, 0.040483884877176024, 0.04392747978272382, 0.0571334039705107, 0.021945817024970893, 0.04186142970866058, 0.03184025415976066, 0.05137031927006319, 0.03253408802265767, 0.038568813615711406, 0.03970700468926225, 0.05202138316235505, 0.03930086808395572, 0.008742727841308806, 0.07082316762534901, 0.042344656903878786, 0.04009851356386207, 0.09028929300257005, 0.02469785831635818, 0.005493163735081907, 0.013886780670873122, 0.02584142810519552, 0.07197843922767788, 0.031089135773072485, 0.008671816558489809, 0.07431912104948424, 0.028939282383362297, 0.11008897665305994, 0.14762261300347745, 0.11332772395689972, 0.2545841719256714, 0.2669002313632518, 0.09791802935069427, 0.31257568043656647, 0.28723584953695536, 1.5829688147641718, 5.062833605334163, 13.15140400081873, 19.138636328279972, 30.16535773873329, 44.127187952399254, 60.77377550303936, 70.93868985772133, 71.81249096989632, 77.85833895206451, 77.35564112663269, 76.01685896515846, 73.01038429141045, 82.0124964416027, 83.03363844752312, 78.36378023028374, 80.16147136688232, 77.68970400094986, 79.13410529494286, 77.69778236746788, 70.22153913974762, 69.27337601780891, 66.15118235349655, 64.72222343087196, 67.20398426055908, 55.48230484127998, 44.900328665971756, 33.770524486899376, 21.79964303970337, 17.810134515166283, 13.752361703664064, 10.15274265781045, 3.8380823750048876, 1.866846119519323, 0.6508346577174962, 0.13352183683309704, 0.3556274890433997, 0.10767391679110005, 0.0508393719792366, 0.09170857621938922, 0.060695015199598856, 0.14383216795977205, 0.08605858369264752, 0.026040392331196927, 0.03400404879357666, 0.06770975422114134, 0.047666364116594195, 0.058594321671989746, 0.041082382449530996, 0.03936391352908686, 0.058680180736701004, 0.037242042817524634, 0.02381072652497096, 0.030606639593315776, 0.03286045859567821, 0.07106924153049476, 0.01932215800479753, 0.012448101424524793, 0.033249355110456236, 0.06187138606037479, 0.04003898960945662, 0.037188025598879904, 0.04480978946958203, 0.017716168986225966, 0.046271349128801376, 0.02336425233806949, 0.06302249050349928, 0.028060525728506036, 0.03418154454266187, 0.039105601608753204, 0.00666291278321296, 0.0658109322830569, 0.05287623709591571, 0.09169204116915353, 0.05242959778115619, 0.028903085985803045, 0.03564947553968523, 0.06640998646616936, 0.018065648182528093, 0.018592355954751838, 0.06545275697135366, 0.009034976319526322, 0.015481802602153039, 0.07608974439790472, 0.15256794373271987, 0.03720568129210733, 0.009764444403117523, 0.0741631438722834, 0.038972070688032545, 0.0427724419569131, 0.022579553624382243, 0.03518133991747163, 0.005500515171661391, 0.04337881371611729, 0.02566926097642863, 0.1033611482125707, 0.048257744492730126, 0.054221461396082304, 0.0461769516550703, 0.05527996065211482, 0.019485300617816392, 0.12144949127105065, 0.13686494494322687, 0.22212471056263894, 0.1254480122588575, 0.14000868250150234, 0.167970847687684, 0.10759090015199035, 0.15325339132687077, 0.2413694013375789, 0.1238831048249267, 0.11764479699195363, 0.21871801523957402, 0.1525105905602686, 0.11142326169647276, 0.16188658744795248, 0.11840018458315171, 0.18481382983736694, 0.18663351656869054, 0.1790422957856208, 0.15290955430828035, 0.11593947521760128, 0.09833959891693667, 0.05915348170674406, 0.10425633416161872, 0.12554530781926587, 0.11228378934902139, 0.09345390717498958, 0.10861123446375132, 0.09494332334725186, 0.15921519719995558, 0.14227282663341612, 0.20419653039425611, 0.09960476032574661, 0.2933266555191949, 0.1204271383176092, 0.0991033208265435, 0.10105560708325356, 0.11600400495808572, 0.12570930761285126, 0.14413947646971792, 0.08926785289077088, 0.1222730302833952, 0.08716853975784034, 0.13654883456183597, 0.17737111280439422, 0.14338897221023217, 0.11124370648758486, 0.12755062052747235, 0.14998993050539866, 0.0719108889461495, 0.1622362429043278, 0.12521493335952982, 0.14426307374378666, 0.11779869615565985, 0.278136792476289, 0.10594388892059214, 0.15479300636798143, 0.14185216248733923, 0.1655178121291101, 0.16180340753635392, 0.25250179460272193, 0.07768301671603695, 0.20452672673854977, 0.16395207348978147, 0.21969105990137905, 0.14408402319531888, 0.17184978642035276, 0.2002048445865512, 0.16504730534506962, 0.22104236239101738, 0.24824311374686658, 0.3142683708574623, 0.3861260775011033, 0.3140285681001842, 0.1439141307491809, 0.4826008522650227, 2.2688860399648547, 7.524502063170075, 12.878819927573204, 25.73150485754013, 39.73164461553097, 57.85903550684452, 73.03077399730682, 74.82715040445328, 83.24257403612137, 84.95913192629814, 83.7371326982975, 78.46206575632095, 86.38432905077934, 89.1257755458355, 80.24971783161163, 83.71356636285782, 80.63556432723999, 82.16085568070412, 81.9473223388195, 72.1753790974617, 71.48660525679588, 67.95214131474495, 69.76092785596848, 71.0609520971775, 55.50442345440388, 43.696104884147644, 30.253794193267822, 17.316806986927986, 13.103530369699001, 8.359217997640371, 5.412663733586669, 1.4306235895492136, 0.5311331246048212, 0.30890668043866754, 0.1321965391980484, 0.28785337577573955, 0.4394195240456611, 0.37721709930337965, 0.37439251493196934, 0.18297260598046705, 0.21185230318224058, 0.1772860181517899, 0.2049929290660657, 0.20155148638878018, 0.1647660759044811, 0.13490232056938112, 0.20432223536772653, 0.13994058303069323, 0.1768104499205947, 0.1290177574264817, 0.11783368099713698, 0.2117486993665807, 0.15012212184956297, 0.1318801022716798, 0.1412081712624058, 0.22013291978510097, 0.061643335211556405, 0.12064313297742046, 0.19041876657865942, 0.17869007249828428, 0.16594715940300375, 0.11754033228498884, 0.19307972223032266, 0.14773436560062692, 0.08368008944671601, 0.08773438283242285, 0.17754211847204715, 0.11581659782677889, 0.18717105413088575, 0.12998202990274876, 0.14517358504235744, 0.1231666948297061, 0.19723858422366902, 0.1329399782116525, 0.0928385480074212, 0.1666309594293125, 0.23887979274149984, 0.17089280183427036, 0.09524090972263366, 0.17018698970787227, 0.19504978292388842, 0.06812730134697631, 0.17942450183909386, 0.18981471774168313, 0.12984416855033487, 0.14120958134299144, 0.3027368802577257, 0.14060728397453204, 0.0949838817177806, 0.09523124695988372, 0.16047790209995583, 0.13678268529474735, 0.13826773763867095, 0.14866055105812848, 0.2640448627062142, 0.13036573509452865, 0.09912574852933176, 0.1174262493441347, 0.14411045849556103, 0.11968893144512549], [0.03216435005015228, 0.05951950151938945, 0.05257043885649182, 0.02143144931324059, 0.051878790618502535, 0.006023841069691116, 0.023189420899143443, 0.027997259494441096, 0.06804375778301619, 0.0025217459096893435, 0.038064294203650206, 0.052399882188183255, 0.05332403787178919, 0.05495793164300267, 0.04917713929899037, 0.05666844474035315, 0.07363919503404759, 0.09563359490130097, 0.019604682493081782, 0.030282289517344907, 0.03720990411238745, 0.015230029002850642, 0.011038980064768111, 0.01615782213775674, 0.057768259357544594, 0.08824605654808693, 0.060847723216284066, 0.056099135836120695, 0.047773307596798986, 0.03772375603148248, 0.07184115675045177, 0.04799315400305204, 0.014514976210193709, 0.021154084606678225, 0.038922324529266916, 0.015096356146386825, 0.02403770497039659, 0.03821117636107374, 0.024428148863080423, 0.040184791942010634, 0.0389192520378856, 0.04478290145925712, 0.038087920474936254, 0.07954962202347815, 0.06412169284885749, 0.024437342217424884, 0.04374023963464424, 0.028767248841177206, 0.02649386125995079, 0.0556800895719789, 0.03728905045136344, 0.008284409905172652, 0.1175391893775668, 0.016051669044827577, 0.018737430982582737, 0.0380911191314226, 0.04081517588929273, 0.0358103583130287, 0.035028082711505704, 0.01935854736075271, 0.01594955137989018, 0.07993396546225995, 0.06319940366665833, 0.032979870156850666, 0.017543953617860097, 0.020935253087372985, 0.06997448464971967, 0.09300567966420203, 0.018518690376367886, 0.029392215110419784, 0.055104958519223146, 0.11112156382296234, 0.101960218307795, 0.09037714844453149, 0.04697283082350623, 0.012871447506768163, 0.014374906040757196, 0.0827075494453311, 0.07614359463332221, 0.4276244522770867, 0.2994437632150948, 0.04365950509964023, 0.34173555322922766, 0.6636798090767115, 1.9490681262686849, 3.550223121419549, 3.3697955030947924, 2.9005605820566416, 4.095958387479186, 4.308026432991028, 3.721748529933393, 3.2493747398257256, 3.2159343967214227, 2.7103083534166217, 3.0617360584437847, 2.309912913478911, 1.93183806957677, 1.0689277667552233, 0.8377372473478317, 0.6159001041669399, 0.655403200071305, 0.1348782898276113, 0.08966502064140514, 0.13911144080339, 0.16229727712925524, 0.23787863552570343, 0.18079456582199782, 0.037770351773360744, 0.07806721914676018, 0.0939242061576806, 0.018677224252314772, 0.11103091790573671, 0.051195706764701754, 0.11589125046157278, 0.04288367505068891, 0.06295529645285569, 0.11103145967354067, 0.010853668572963215, 0.03540595462254714, 0.017613173731660936, 0.06740450888173655, 0.06299613683950156, 0.061790213658241555, 0.05177215512958355, 0.016064879273471888, 0.03525529864418786, 0.02690573652216699, 0.009091888841794571, 0.07547919434728101, 0.0651871868467424, 0.03501924373267684, 0.04127883636101615, 0.02101243459037505, 0.006004663973726565, 0.013880277601856505, 0.04328345516114496, 0.029615813073178288, 0.007627002505614655, 0.052807202519034036, 0.03815572679741308, 0.04798733556526713, 0.07618801217176951, 0.02404336384643102, 0.041836282034637406, 0.04783437150763348, 0.011195868228242034, 0.015907694250927307, 0.029195143360993825, 0.054535887102247216, 0.057340251660207286, 0.021984330778650474, 0.017610967697692104, 0.06158806376333814, 0.053009853363619186, 0.021510875812964514, 0.057330507261212915, 0.01991667024412891, 0.015938907126837876, 0.02311968128196895, 0.02978780208650278, 0.027390444302000105, 0.03628786726039834, 0.013967972554382868, 0.02863227444322547, 0.03807676970609464, 0.05221059371251613, 0.0746116905065719, 0.021129471278982237, 0.03150762728182599, 0.057131344510708004, 0.0059977531873300904, 0.06516415800433606, 0.03426805298659019, 0.05435734863567632, 0.020040176605107263, 0.021895625577599276, 0.0305413454407244, 0.029825096862623468, 0.07445282637490891, 0.033734445096342824, 0.026952783118758816, 0.017390599932696205, 0.046193278903956525, 0.0033387690973540884, 0.015100184700713726, 0.05147647607373074, 0.060612492088694125, 0.011558743190107634, 0.05428404299891554, 0.037472694893949665, 0.008565530806663446, 0.027626007540675346, 0.04108594104764052, 0.08166077983332798, 0.059329274226911366, 0.08657301077619195, 0.06622339569730684, 0.028133525229350198, 0.015148889069678262, 0.0699297479877714, 0.020816700562136248, 0.012551282216008985, 0.028787745104636997, 0.031785988321644254, 0.023849718963901978, 0.02740128336881753, 0.02827333657478448, 0.02022975451836828, 0.06761969460058026, 0.05943162010225933, 0.04563361049804371, 0.01845321625296492, 0.030303216226457153, 0.026646341066225432, 0.017040384154825006, 0.06074614546378143, 0.011865024753205944, 0.02497659599612234, 0.12012505452730693, 0.049407487094867975, 0.07522123123635538, 0.03422495647100732, 0.03569703236280475, 0.025599666078051087, 0.014171244019962614, 0.05592838249867782, 0.016312969964928925, 0.01589237817825051, 0.08743840691749938, 0.03371588027221151, 0.022489343718916643, 0.024587295010860544, 0.07197658385848626, 0.025583769274817314, 0.014482296664937166, 0.04316499354899861, 0.030037833494134247, 0.04482795353396796, 0.027985149499727413, 0.01640240432607243, 0.042064199296873994, 0.08647711787489243, 0.03209528207662515, 0.06567744960193522, 0.040213412867160514, 0.07266920059919357, 0.09612482986995019, 0.07253343210322782, 0.0456252242292976, 0.054445055648102425, 0.058120738685829565, 0.034198365319753066, 0.10267970821587369, 0.19114718452328816, 0.09845454274909571, 0.22471115458756685, 0.5411033146083355, 0.49334011506289244, 2.9404470417648554, 4.930129526183009, 6.813708879053593, 10.039577130228281, 10.320318415760994, 9.6044453792274, 11.426165476441383, 11.041581463068724, 10.154541861265898, 9.836711715906858, 9.35641273856163, 7.752325488254428, 8.124015368521214, 7.209289502352476, 5.844948962330818, 4.045748356729746, 3.3383797388523817, 2.579390653409064, 1.5012678550556302, 0.3024240501690656, 0.19084593193838373, 0.13195436156820506, 0.0032845116083990433, 0.10112556934473105, 0.2130316203692928, 0.0701469300838653, 0.13146424724254757, 0.044132152979727834, 0.08653463431983255, 0.031515208320342936, 0.07151453013648279, 0.008146582877088804, 0.0291656689660158, 0.027921373039134778, 0.10255719447741285, 0.08052012854022905, 0.027830057333630975, 0.08617151630460285, 0.06949926522793248, 0.024739464970480185, 0.045499582338379696, 0.03669804485980421, 0.057698007658473216, 0.053504364914260805, 0.06421147045330144, 0.04978443503205199, 0.03566777319065295, 0.02889454386604484, 0.011514037141751032, 0.03698275868373457, 0.004118501683478826, 0.012088426046830136, 0.019558999592845794, 0.010989114234689623, 0.03694756975164637, 0.012730072085105348, 0.08307877171318978, 0.013605359199573286, 0.07069596351357177, 0.012456568401830737, 0.06246832141187042, 0.0982133521756623, 0.026435005238454323, 0.03860232900478877, 0.04068782705871854, 0.05380316470109392, 0.031048675737110898, 0.03330492341774516, 0.006099075826568878, 0.03440619264438283, 0.04420635290443897, 0.05395697851781733, 0.061175904629635625, 0.04844004935876001, 0.0832861648814287, 0.014798151933064219, 0.09223025408573449, 0.04667961940867826, 0.11286422304692678, 0.0733450819097925, 0.017752318999555428, 0.048708016620366834, 0.03117700049187988, 0.0398544360359665, 0.02274648675665958, 0.02238877714262344, 0.037872326574870385, 0.015396589205920463, 0.05192984295717906, 0.022327935876091942, 0.009925201939040562, 0.04696407719166018, 0.04242708353558555, 0.030223839821701404, 0.09547046342049725, 0.12981751060578972, 0.2792235044762492, 0.13567989837611094, 0.12336419516941532, 0.0954612904752139, 0.11079782416345552, 0.15347842534538358, 0.11895505129359663, 0.1378397410735488, 0.13835516263497993, 0.1304544959566556, 0.14533722860505804, 0.14596698543755338, 0.14028470206540078, 0.10185399471083656, 0.28507949493359774, 0.1274635220761411, 0.13665073143783957, 0.18176214827690274, 0.13127737445756793, 0.06591933037270792, 0.08916280188714154, 0.22173497913172469, 0.09524222332402132, 0.3155347122810781, 0.12175861062132753, 0.15857824153499678, 0.14133806194877252, 0.09822121894103475, 0.1409460447030142, 0.15000265091657639, 0.15552813332760707, 0.12712909549009055, 0.16723432549042627, 0.1680501239025034, 0.0767673178052064, 0.10388016919023357, 0.13952054228866473, 0.12814937043003738, 0.14381692424649373, 0.15307408844819292, 0.21555716375587508, 0.15581693267449737, 0.15660720120649785, 0.2043590904213488, 0.13506917021004483, 0.09657526898081414, 0.047547475769533776, 0.22671294951578602, 0.12227214712765999, 0.18813421338563785, 0.21410791261587292, 0.0896004241076298, 0.11273308555246331, 0.11604217361309566, 0.2426978456787765, 0.12343384572886862, 0.12196870520710945, 0.1434196377522312, 0.11940185388084501, 0.23524334334069863, 0.2219404501374811, 0.13702002412173897, 0.14036748121725395, 0.15908900240901858, 0.1846471879980527, 0.22255450312513858, 0.11931837711017579, 0.10697646866901778, 0.26192419056314975, 0.1381892481003888, 0.16758000303525478, 0.2371673018205911, 0.13776252802927047, 0.14157068071654066, 0.1339743984863162, 0.2227717445930466, 0.3077395196305588, 0.5238676175940782, 0.3439782344503328, 0.1628355123102665, 1.3566993875429034, 2.0728631084784865, 3.411130397580564, 5.475203152745962, 6.088217133656144, 6.310047805309296, 7.038585562258959, 6.54697934165597, 6.281917439773679, 6.043725796043873, 5.427310047671199, 4.526552706956863, 4.560067383572459, 3.384270826354623, 3.245963710360229, 1.763775225263089, 1.4983744290657341, 1.0173803265206516, 0.6358736136462539, 0.15788412565598264, 0.2770114887971431, 0.22451916098361835, 0.30659141717478633, 0.3664172475691885, 0.35229186178185046, 0.18345092015806586, 0.15947946114465594, 0.17786637763492763, 0.20460103056393564, 0.2557612181408331, 0.2970014442689717, 0.1994136261055246, 0.11540240520844236, 0.24032420507865027, 0.15504031965974718, 0.1861950705642812, 0.1258503453573212, 0.20112058060476556, 0.16736378573114052, 0.1347130283829756, 0.11226537666516379, 0.2197558493935503, 0.18744875094853342, 0.1292377003119327, 0.11397764494176954, 0.3388821141561493, 0.17148865736089647, 0.1619190044584684, 0.12179607423604466, 0.24488136288709939, 0.16230990848271176, 0.13551494863349944, 0.20484813605435193, 0.08172161367838271, 0.10699220219976269, 0.07357116977800615, 0.16620526352198794, 0.11715051921783015, 0.14039115572813898, 0.16807997308205813, 0.14321599242975935, 0.1139631136902608, 0.14411284821107984, 0.17192851344589144, 0.06284028582740575, 0.10618018874083646, 0.11292766925180331, 0.10926050235866569, 0.10289997764630243, 0.12236062597366981, 0.1243061586865224, 0.14581828872906044, 0.2604707091813907, 0.14409337425604463, 0.23037071339786053, 0.06040036772901658, 0.16650656063575298, 0.14897142187692225, 0.17660250014159828, 0.14011774852406234, 0.12179427823866718, 0.166580255900044, 0.19008713046787307, 0.12534469045931473, 0.15112534223590046, 0.24070688610663638, 0.0915951537899673, 0.1088881074974779, 0.09916131966747344, 0.12083203182555735, 0.08250621220213361, 0.15681022312492132, 0.23538138280855492, 0.09153133651125245], [0.04506990109803155, 0.018799971767293755, 0.04438293581188191, 0.047415789085789584, 0.014759294936084189, 0.030907151885912754, 0.0917552573082503, 0.0182789098835201, 0.043008207430830225, 0.05517535864782985, 0.04498442795011215, 0.03769793300307356, 0.014217522493709112, 0.025909347605193034, 0.07421816670102999, 0.048838957445695996, 0.02393451675743563, 0.030472923135675956, 0.04375395452370867, 0.0441205198148964, 0.011490645574667724, 0.05148789401573595, 0.00519842349604005, 0.05013396432332229, 0.032071392342913896, 0.0013189644482736185, 0.020862602395936847, 0.045815232588211074, 0.0159290087322006, 0.013825594305671984, 0.04449685548024718, 0.06985465748584829, 0.06964491913095117, 0.06861983507405967, 0.051392461245995946, 0.05103194445837289, 0.010166525171371177, 0.06341151689412072, 0.014374390248121927, 0.06446830549975857, 0.02502332161384402, 0.039901113414089195, 0.03191078416421078, 0.025812940766627435, 0.009316877403762192, 0.026233055723423604, 0.03318817245599348, 0.046696926292497665, 0.037278088930179365, 0.027899717169930227, 0.03881290598656051, 0.031099739208002575, 0.03079905622143997, 0.08622788984212093, 0.03073276202485431, 0.022983584385656286, 0.02775760331132915, 0.06005102026392706, 0.007504678014811361, 0.06303353366092779, 0.04279741522623226, 0.019081687314610463, 0.03842538244498428, 0.03966211588704027, 0.03554762319254223, 0.07726997442659922, 0.12679018633207306, 0.04744863654195797, 0.026350788175477646, 0.01239281884409138, 0.032958132651401684, 0.10358303552493453, 0.030335618394019548, 0.03834220995486248, 0.06963216161238961, 0.02137511288310634, 0.03461053558567073, 0.05775148682005238, 0.05509907328814734, 0.1097115500306245, 0.0743130428600125, 0.030930382963560987, 0.05265714768029284, 0.04159508032898884, 0.06299468223005533, 0.1182517253619153, 0.08630435331724584, 0.0870122508786153, 0.2220891765318811, 0.17171579907881096, 0.3723627410363406, 0.1576536739594303, 0.2388429080019705, 0.33153262571431696, 0.03840221259451937, 0.12420833620126359, 0.07193480836576782, 0.013410645624389872, 0.07135834515793249, 0.0305775307060685, 0.023925512650748715, 0.020153062832832802, 0.016763934145274106, 0.02502482817362761, 0.21280476066749543, 0.08091846146271564, 0.034187644996563904, 0.0333610631787451, 0.03602374803449493, 0.019002459339390043, 0.048743328006821685, 0.09680948336608708, 0.039678539615124464, 0.14277049602242187, 0.041536350472597405, 0.00360441598786565, 0.04134305811021477, 0.04766616002598312, 0.03793505660723895, 0.028111962128605228, 0.02024752895522397, 0.03122607129625976, 0.03314792949822731, 0.019135672991978936, 0.02711331151658669, 0.09671232881373726, 0.017176495894091204, 0.07526088418671861, 0.10843878160812892, 0.04954591247951612, 0.012855290024162969, 0.013601738446595846, 0.011224201571167214, 0.08525220313458703, 0.014486968484561658, 0.10681750805815682, 0.056737141640041955, 0.040179032876039855, 0.022071650018915534, 0.046514335699612275, 0.015279296476364834, 0.06474341222201474, 0.01924005049659172, 0.1080924658162985, 0.04730805892904755, 0.053472048093681224, 0.03208632435416803, 0.033306949480902404, 0.023540195143141318, 0.011532726275618188, 0.035005992685910314, 0.0346558474120684, 0.02339175818633521, 0.02567434097727528, 0.02234422972833272, 0.031697546583018266, 0.05677931789250579, 0.034086200830643065, 0.0457840215676697, 0.0707628161762841, 0.04609591655025724, 0.034847685165004805, 0.03818265562586021, 0.08645630805403925, 0.02415123501123162, 0.03623510056058876, 0.05971140235487837, 0.04945827226038091, 0.030862389248795807, 0.03673212799185421, 0.010673390697775176, 0.052611115970648825, 0.03393538900127169, 0.02563534668297507, 0.034760423441184685, 0.029237993112474214, 0.041208109687431715, 0.016304566997860093, 0.05770090574515052, 0.005423039128800156, 0.008988690424303059, 0.05046191938163247, 0.044583965063793585, 0.028809317482227925, 0.011293007937638322, 0.03780274280870799, 0.02811316997394897, 0.03716274804901332, 0.031014356973173562, 0.06702427694108337, 0.058080184026039205, 0.012606625095941126, 0.10488699641427957, 0.005706699103029678, 0.030365992643055506, 0.059702177459257655, 0.027698645244527142, 0.08488525563734584, 0.059353063770686276, 0.008058482526394073, 0.03474173616268672, 0.006430942003134987, 0.06106362881837413, 0.027130883718200494, 0.06634928620769642, 0.018053437997878063, 0.08893022022675723, 0.009819206552492687, 0.01583285422384506, 0.032661347795510665, 0.015452374591404805, 0.03210099290299695, 0.06759360068826936, 0.03005046113685239, 0.0359597489295993, 0.0352600038604578, 0.03586902137612924, 0.016962499466899317, 0.040183645323850214, 0.040869070653570816, 0.028204222217027564, 0.024489752686349675, 0.02496534874808276, 0.03792235103901476, 0.10053841178887524, 0.03445416507020127, 0.0042245740678481525, 0.024905986210796982, 0.0017947091714631824, 0.011508634306665044, 0.01711578450340312, 0.003234621890442213, 0.04720932731288485, 0.03969873345340602, 0.02285590901010437, 0.06674723321339116, 0.027127260182169266, 0.036243204813217744, 0.03954157255066093, 0.06705897976644337, 0.10136061493540183, 0.049380176060367376, 0.14876888977596536, 0.04384588806715328, 0.06487092061433941, 0.10597500717267394, 0.10129215181223117, 0.07044867990771309, 0.03100818972598063, 0.059279951092321426, 0.08469614898785949, 0.09622996250982396, 0.14502156351227313, 0.03693086400744505, 0.024691705912118778, 0.08325425995280966, 0.16950111166806892, 0.045249604736454785, 0.04497124369663652, 0.12609372526640072, 0.2765647158958018, 0.1663609067327343, 0.12887204415164888, 0.14513420668663457, 0.1617048354819417, 0.15093653986696154, 0.11324288163450547, 0.16363131726393476, 0.16629418765660375, 0.2519044547807425, 0.06061238076654263, 0.28858177887741476, 0.21610969270113856, 0.09077822731342167, 0.1668689216603525, 0.0978363559988793, 0.029170255438657477, 0.07195414873422123, 0.04421620862558484, 0.09870590816717595, 0.02086827425955562, 0.03370909333170857, 0.05593224166659638, 0.028405542761902325, 0.03659774360130541, 0.087612314382568, 0.07179532913141884, 0.030031165297259577, 0.06609931602724828, 0.030173140003171284, 0.020189845527056605, 0.02515327538276324, 0.027462475300126243, 0.0724140353850089, 0.047877839097054675, 0.011590868907660479, 0.037161723885219544, 0.025854595660348423, 0.09346595223178156, 0.05841742706252262, 0.012668917261180468, 0.11601032063481398, 0.06273761711781844, 0.020387299482536037, 0.04369999296613969, 0.04934860880894121, 0.0278021210397128, 0.006319582280411851, 0.06446535917348228, 0.03161420339893084, 0.04900666055618785, 0.0031044139359437395, 0.03130915472866036, 0.08745340572204441, 0.041746207571122795, 0.024948108657554258, 0.011665434340102365, 0.02155082933313679, 0.12311343831242993, 0.03412586862395983, 0.07517588601331227, 0.06744389465893619, 0.02264442475279793, 0.08678878279170021, 0.008634333462396171, 0.06705763647914864, 0.047384210702148266, 0.0197728809871478, 0.013220319069660036, 0.012869190450146561, 0.02675609357538633, 0.06648317707004026, 0.059833563573192805, 0.012174530020274688, 0.03353687425260432, 0.09790473748580553, 0.11255812423769385, 0.026866783045988996, 0.0037645779502781807, 0.04765054152812809, 0.013225805396359647, 0.055664779065409675, 0.06936495134141296, 0.003013969094354252, 0.0347177944786381, 0.04232968778524082, 0.017753025895217434, 0.017005814916046802, 0.013983344288135413, 0.06952955227461644, 0.004635833347492735, 0.06744799873558804, 0.0808083861193154, 0.10391844174591824, 0.15449213969986886, 0.10699209829908796, 0.15367076033726335, 0.12731820956105366, 0.18050953658530489, 0.08270323756732978, 0.1976445093168877, 0.11022239996236749, 0.13819901476381347, 0.11208408483071253, 0.09003388287965208, 0.12485736660892144, 0.13452814455376938, 0.17226286581717432, 0.27162970101926476, 0.09585323350620456, 0.19590052164858207, 0.21305526519427076, 0.10762330231955275, 0.1325305798673071, 0.13384674908593297, 0.08224497621995397, 0.0858511237311177, 0.06528558078571223, 0.09556067889207043, 0.14575461245840415, 0.18113807629561052, 0.10107835390954278, 0.25301120476797223, 0.10879679364734329, 0.15958000731188804, 0.1473309934954159, 0.15801855828613043, 0.3238692681770772, 0.23800560215022415, 0.09442071037483402, 0.10242907010251656, 0.13728654419537634, 0.15176354470895603, 0.14374273916473612, 0.10861246642889455, 0.1141564134741202, 0.08048219737247564, 0.1670883598853834, 0.13897755736252293, 0.14823414268903434, 0.18506325082853436, 0.14464930223766714, 0.12369243224384263, 0.1591124542756006, 0.10507208804483525, 0.17438560113077983, 0.07977049259352498, 0.1484735743724741, 0.12121881693019532, 0.1037191528303083, 0.12106062815291807, 0.11079132294980809, 0.11159198154928163, 0.10716064745793119, 0.0786753349530045, 0.13161842100089416, 0.2262812273693271, 0.2043704007519409, 0.27149917208589613, 0.140799262735527, 0.17122642690083012, 0.17107060557464138, 0.1634949995786883, 0.2598925761412829, 0.1658061216585338, 0.12827388796722516, 0.15872410323936492, 0.23411976144416258, 0.17440474854083732, 0.25583492824807763, 0.11636893381364644, 0.29335886472836137, 0.2620269334875047, 0.10140559650608338, 0.11171282545547001, 0.20629136095521972, 0.268395688617602, 0.2599536697380245, 0.2994899544864893, 0.322556794853881, 0.35185144166462123, 0.3951069846516475, 0.5786314664874226, 0.3782152582425624, 0.29223768739029765, 0.471450588083826, 0.23365915491012856, 0.37045090924948454, 0.3437334147747606, 0.13363266916712746, 0.197006470116321, 0.18269925814820454, 0.07217360180220567, 0.17623486986849457, 0.11218983345315792, 0.2622700313804671, 0.3856426425045356, 0.22770398383727297, 0.2282619898323901, 0.1148107873450499, 0.13831164309522137, 0.15213893784675747, 0.10474468959728256, 0.17446343757910654, 0.23623286368092522, 0.21372334653278813, 0.1732832149718888, 0.16841678938362747, 0.14305533230071887, 0.14987746544647962, 0.10795991081977263, 0.05791227682493627, 0.13457872933940962, 0.1317809958709404, 0.17292929958784953, 0.1573878960334696, 0.08939375082263723, 0.2956757607171312, 0.09018243115860969, 0.21930410410277545, 0.2798418322345242, 0.25430945854168385, 0.15987751947250217, 0.08114724332699552, 0.17599960905499756, 0.159997777082026, 0.2046927748597227, 0.1771982220816426, 0.13918911397922784, 0.18956528190756217, 0.1204011334630195, 0.1651184179354459, 0.14792155008763075, 0.1819325305405073, 0.14312944316770881, 0.17467554338509217, 0.14004258380737156, 0.19965966290328652, 0.19533653394319117, 0.18655285995919257, 0.10857836474315263, 0.0971347073209472, 0.12313437429838814, 0.126839732110966, 0.2106114025809802, 0.06371664348989725, 0.07253449337440543, 0.19542133173672482, 0.23963639745488763, 0.10711884227930568, 0.12997748795896769, 0.1514826566562988, 0.23875091137597337, 0.1462486304808408, 0.09095635017729364, 0.184092091221828, 0.14397394785191864, 0.14803628611844033, 0.2265119313960895, 0.13373195368330926, 0.15793708531418815, 0.13005943590542302, 0.1624233680195175, 0.10984598266077228, 0.10644433394190855, 0.1356137136463076, 0.21356623386964202, 0.18563611462013796], [0.04373285897599999, 0.035192646537325345, 0.04398171593493316, 0.03756035366677679, 0.05659716516674962, 0.02733939567406196, 0.0878353149164468, 0.06839019231847487, 0.028104672383051366, 0.05918749433476478, 0.008381165553146275, 0.032469254001625814, 0.035341866459930316, 0.01839635289798025, 0.08064997469773516, 0.05053804146882612, 0.0817171014205087, 0.03565159066056367, 0.006750053908035625, 0.04262374153768178, 0.10211582441115752, 0.03977180902438704, 0.022896940499776974, 0.05306521758029703, 0.03741943095519673, 0.0794660190877039, 0.04200071969535202, 0.060123027142253704, 0.08566454780520871, 0.02191552997828694, 0.01736478432576405, 0.04750939246150665, 0.025891434015647974, 0.021912932461418677, 0.028849163390987087, 0.01943081213539699, 0.022194902194314636, 0.052082888651057146, 0.04555450868792832, 0.02274964459502371, 0.07446085641277023, 0.022308502739178948, 0.06048129522241652, 0.04021851142169908, 0.02110808258294128, 0.0600692474108655, 0.03199596416379791, 0.04592769764713012, 0.043509721144801006, 0.0628423786838539, 0.07009146196651272, 0.056165613714256324, 0.026622891055012587, 0.05968282595858909, 0.06619207706535235, 0.012325173011049628, 0.06050180447346065, 0.02326741690922063, 0.028600046680367086, 0.01847392773925094, 0.028160179463156965, 0.03892520777299069, 0.09184844137053005, 0.005713702194043435, 0.08989520516479388, 0.055707949795760214, 0.049438071000622585, 0.04251418940839358, 0.03285919323388953, 0.013303479499882087, 0.08513980486895889, 0.03748973089386709, 0.03390043755644001, 0.012872778734163148, 0.06120456266216934, 0.04587993673339952, 0.03558283809979912, 0.019323922460898757, 0.03102842252701521, 0.03645396733190864, 0.08478199320961721, 0.01577384606207488, 0.11374651046935469, 0.03728738804056775, 0.04622739914339036, 0.02571333712694468, 0.07969362093717791, 0.07906292157713324, 0.09543121865135618, 0.022097619621490594, 0.06289303026278503, 0.08796542082563974, 0.057458368173683994, 0.058234866155544296, 0.055923510299180634, 0.058793250645976514, 0.04699554054241162, 0.05065551602456253, 0.03819145007582847, 0.028869884154119063, 0.11673712069750763, 0.05290077249810565, 0.019836848550767172, 0.011913231883227127, 0.1290704944403842, 0.04976367716153618, 0.08418426004936919, 0.01893804092105711, 0.09367390201077797, 0.019627245637821034, 0.036908169131493196, 0.08829207712551579, 0.07366509598796256, 0.01774146508978447, 0.041100052985711955, 0.0147461681990535, 0.04477864524233155, 0.023258256951521616, 0.05572628455411177, 0.0613455076381797, 0.13914773182477802, 0.020351485291030258, 0.015488620156247634, 0.04310856063966639, 0.049400199204683304, 0.028728217439493164, 0.03244802857807372, 0.04881158332864288, 0.04241282687871717, 0.0016755762635511928, 0.06036887840309646, 0.023130596418923233, 0.03367705110576935, 0.02883804787416011, 0.05037315480876714, 0.02403749716904713, 0.037884627672610804, 0.09420836708159186, 0.04310979631554801, 0.022020328651706222, 0.05464215893880464, 0.0870160803606268, 0.08313834390719421, 0.07618468735017814, 0.015519689241045853, 0.07447774027241394, 0.04118226810533088, 0.04741690972878132, 0.015664874663343653, 0.012378792253002757, 0.033417418162571266, 0.039040522678988054, 0.0383998822508147, 0.041630621781223454, 0.023358183425443713, 0.03793637763010338, 0.04377036340883933, 0.04408835513459053, 0.013244598430901533, 0.03462307417066768, 0.024991459358716384, 0.057648257788969204, 0.010086385282193078, 0.03351272847794462, 0.06021570283337496, 0.08677163918036968, 0.07264645377290435, 0.025934192854037974, 0.02244474435428856, 0.01579310293891467, 0.06831933205830865, 0.025413541006855667, 0.037420811349875294, 0.0306516285854741, 0.06909883202752098, 0.025951154639187735, 0.0533112655102741, 0.06541351220221259, 0.04007291317975614, 0.03402313312108163, 0.08606116636656225, 0.016335006184817757, 0.067278521892149, 0.0695210621051956, 0.03016059399669757, 0.010628459222061792, 0.07389165883068927, 0.08823846437735483, 0.046068779920460656, 0.01694688282441348, 0.05940275797911454, 0.0408269797480898, 0.005790219011032605, 0.04376543183752801, 0.06426186228054576, 0.04043164139147848, 0.04167805986071471, 0.06828618032159284, 0.04985438987205271, 0.04375586926471442, 0.014132941778370878, 0.003977591031798511, 0.05382853501942009, 0.06205067038536072, 0.042609755764715374, 0.08054184378124774, 0.09326419196440838, 0.03185265544743743, 0.04785259494383354, 0.03409589327930007, 0.028233889570401516, 0.03225056905648671, 0.043019981603720225, 0.02963510520203272, 0.08446069521596655, 0.06531185281346552, 0.04389022768009454, 0.042910180854960345, 0.018271924418513663, 0.04390145266370382, 0.014327223052532645, 0.01675702846114291, 0.02620503964863019, 0.032624155064695515, 0.06278757107793353, 0.0033211372920050053, 0.046422921659541316, 0.07272423827089369, 0.04722475656308234, 0.04318280880397651, 0.05908421706408262, 0.011590519170567859, 0.025010107674461324, 0.008176241881301394, 0.039329251521849073, 0.05654418324411381, 0.028559295351442415, 0.07769166273646988, 0.06676806529867463, 0.06178153424116317, 0.05462207642267458, 0.040769240658846684, 0.07476964921806939, 0.04746024002088234, 0.06040936255885754, 0.009024532446346711, 0.05596412804152351, 0.054801264268462546, 0.007316851570067229, 0.010278300960635534, 0.09110475002671592, 0.019023877721338067, 0.12188497610623017, 0.1075631141429767, 0.07207635077065788, 0.025096523349930067, 0.010070032058138167, 0.05415589635958895, 0.08372637719730847, 0.06421006779419258, 0.02242851915070787, 0.07385982069536112, 0.06746969171217643, 0.08995562340714969, 0.08647702881717123, 0.0732383388094604, 0.025599139153200667, 0.08695535783772357, 0.055925165288499556, 0.0414955397718586, 0.058268099528504536, 0.11576611694181338, 0.07210829280666076, 0.03693875303724781, 0.05641725743771531, 0.05010597422369756, 0.0502290185977472, 0.028088016733818222, 0.20190586190437898, 0.052345007788972, 0.04230954589729663, 0.05626328034850303, 0.16472206654725596, 0.07442383066518232, 0.0162602793352562, 0.07102613759343512, 0.04604901281709317, 0.08540288879885338, 0.031078693755262066, 0.06687231478281319, 0.02049860679107951, 0.05756645456131082, 0.052900798473274335, 0.028144171337771695, 0.026428819437569473, 0.034085087609128095, 0.052441401639953256, 0.06795724562834948, 0.0526119620190002, 0.020849434840783942, 0.06363160820910707, 0.06095195043599233, 0.04169078398263082, 0.007446916661137948, 0.03653359606687445, 0.060425700939958915, 0.024981434798974078, 0.05361709343560506, 0.0316182406822918, 0.026885524130193517, 0.05010405206121504, 0.038958734294283204, 0.026869734938372858, 0.03216435376089066, 0.01315382727625547, 0.04930226168653462, 0.01935845644766232, 0.030310357542475685, 0.06767810904420912, 0.03557043681212235, 0.045952414875500835, 0.057546193929738365, 0.03594300236727577, 0.01517394490292645, 0.020523947423498612, 0.08437648371909745, 0.023675512784393504, 0.028700136426778045, 0.026181866087426897, 0.020166710928606335, 0.02879147996281972, 0.0461403006920591, 0.07699956549913622, 0.03420086264668498, 0.026054346562887076, 0.04821195027034264, 0.06957881603739224, 0.023423423772328533, 0.024445570779789705, 0.013308604029589333, 0.02215915850683814, 0.08970828042947687, 0.04317187696869951, 0.004197254684186191, 0.029403725820884574, 0.033497896656626835, 0.024497715930920094, 0.029507144099625293, 0.03239813398977276, 0.029022935414104722, 0.02598171999125043, 0.009935386060533347, 0.16059392946772277, 0.14975011290516704, 0.13765421899734065, 0.0937170504766982, 0.25067349895834923, 0.16998484352370724, 0.20035379362525418, 0.1909710728796199, 0.11355681010172702, 0.08578115404816344, 0.0945923246035818, 0.1118460854922887, 0.09613105648895726, 0.09376398389576934, 0.23534054984338582, 0.22340478171827272, 0.17283179622609168, 0.12684201792581007, 0.20067143283085898, 0.14348644588608295, 0.20003394281957299, 0.19218475150410086, 0.09771128185093403, 0.1921519634197466, 0.11189540120540187, 0.15079795120982453, 0.08826496647088788, 0.2003746182890609, 0.11201269764569588, 0.2306831575697288, 0.20100321737118065, 0.13165937270969152, 0.0909875203797128, 0.2384808735223487, 0.11158397377585061, 0.13033870607614517, 0.14274389744969085, 0.11682763302815147, 0.16105236893054098, 0.14436056226259097, 0.1624010590603575, 0.16308877762639895, 0.1451278242166154, 0.10235712630674243, 0.07422322814818472, 0.14704357454320416, 0.11756441497709602, 0.23731763125397265, 0.13090109074255452, 0.21663893305230886, 0.11232340519200079, 0.12742714199703187, 0.08673942254972644, 0.12390977019094862, 0.16015644825529307, 0.17717638809699565, 0.21755251684226096, 0.10967499183607288, 0.1437663394608535, 0.14745248307008296, 0.1319803812657483, 0.20800083875656128, 0.1810171062243171, 0.14631310827098787, 0.24991986283566803, 0.10312520462321118, 0.16014616208849475, 0.23667847883189097, 0.1403175198356621, 0.15731964813312516, 0.16681841108947992, 0.17605017899768427, 0.18186581146437675, 0.1603155498742126, 0.25235122768208385, 0.13666742976056412, 0.13799363281577826, 0.2055200914037414, 0.2855874504894018, 0.19998034491436556, 0.21791553095681593, 0.12814209738280624, 0.19442532502580434, 0.15978840237949044, 0.08220346790039912, 0.121223403402837, 0.16522147256182507, 0.18331630941247568, 0.23800540919182822, 0.18838655843865126, 0.12618612265214324, 0.24757837207289413, 0.25187693594489247, 0.09541686551528983, 0.2586213662289083, 0.1611035771202296, 0.16923447285080329, 0.08799398608971387, 0.19988227752037346, 0.17351028247503564, 0.17062035942217335, 0.10020050453022122, 0.34647003980353475, 0.11771810633945279, 0.2853615110507235, 0.30085826700087637, 0.29430385620798916, 0.13604767707874998, 0.23901330510852858, 0.12996071542147547, 0.16361536108888686, 0.27669043571222574, 0.19885564979631454, 0.20085064665181562, 0.13623569277115166, 0.1328480854863301, 0.2207922437810339, 0.08794202833087184, 0.15332806622609496, 0.11448713674326427, 0.26716841384768486, 0.15250604861648753, 0.11054513772251084, 0.14583893527742475, 0.22043774952180684, 0.1580930847558193, 0.1073514016752597, 0.12392093951348215, 0.10160838093725033, 0.16444995068013668, 0.2639015985187143, 0.1376704275025986, 0.086869699152885, 0.0791932204447221, 0.15414460678584874, 0.14231772656785324, 0.1683882315410301, 0.1479653813294135, 0.11318580305669457, 0.08723948907572776, 0.08829722763039172, 0.1576441150973551, 0.21429203945444897, 0.1317815450602211, 0.13072573608951643, 0.2651888981927186, 0.21830604906426743, 0.12160881553427316, 0.14257890317821875, 0.13185173738747835, 0.08980664468253963, 0.18390517390798777, 0.18383300746791065, 0.1368866304983385, 0.14879551803460345, 0.09275870776036754, 0.16579752758843824, 0.08119237332721241, 0.17707325925584882, 0.11070576074416749, 0.07792220349074341, 0.10144403233425692, 0.11712833642377518, 0.2664433652535081, 0.09953775923349895, 0.12725527543807402, 0.12171077178209089, 0.06721086028846912, 0.124633401283063, 0.12863403739174828, 0.11850506489281543, 0.07895837523392402, 0.15201755217276514, 0.16385589115088806, 0.21035585145000368, 0.11147441793582402], [0.09709564808872528, 0.04980868470738642, 0.01195402031953563, 0.023373779658868443, 0.030391685795621015, 0.013769786655757343, 0.03845474551781081, 0.0113906588012469, 0.04734599751827773, 0.09234199926140718, 0.03315597808978055, 0.017685687125776894, 0.015180455393419834, 0.030136112400214188, 0.05151212142664008, 0.06879378706798889, 0.045813763135811314, 0.008668464834045153, 0.03475117257039528, 0.032222571535385214, 0.03251851776440162, 0.02324430457520066, 0.025783802193473093, 0.04026539289043285, 0.016891299674171023, 0.057767372491071, 0.02580211283202516, 0.0843026622897014, 0.003864077225443907, 0.047932086381479166, 0.07645712234079838, 0.06286147414357401, 0.02723603305639699, 0.0206662802156643, 0.058594941365299746, 0.13711717125261202, 0.044205529120517895, 0.036613113479688764, 0.028553376723721158, 0.05379571353842039, 0.02830522666044999, 0.0809955557633657, 0.017517421838419978, 0.020801788959943224, 0.06359974038787186, 0.035787630040431395, 0.01362216977213393, 0.031027891891426407, 0.018882663716794923, 0.019879969186149538, 0.015076936924742768, 0.06816120265284553, 0.033485239328001626, 0.010377955622971058, 0.034187771161668934, 0.0543487434333656, 0.06319257590803318, 0.07977251123520546, 0.0027445214800536633, 0.08904348680516705, 0.06641040206886828, 0.02182255186198745, 0.12851725303335115, 0.04786576435435563, 0.029127275811333675, 0.03409326607652474, 0.04554122053377796, 0.030194152059266344, 0.003394796840439085, 0.03914854227332398, 0.029397838734439574, 0.10489729000255466, 0.006544591251440579, 0.04449900399777107, 0.083560091588879, 0.008724868057470303, 0.06113462266512215, 0.06955780583666638, 0.0455007104028482, 0.07447264171787538, 0.06385014101397246, 0.024229928640124854, 0.01531685749796452, 0.03330559135065414, 0.024848412249411922, 0.04486831523536239, 0.055348427486023866, 0.025732039248396177, 0.12282505456823856, 0.015669665226596408, 0.056767013084026985, 0.030662538156320807, 0.023613799494341947, 0.02108294233039487, 0.05573223657847848, 0.038873391022207215, 0.0396722239383962, 0.024632886998006143, 0.014744652362423949, 0.008651399148220662, 0.003379885702088359, 0.028296927594055887, 0.027080039180873428, 0.04306214672396891, 0.1070055682794191, 0.06880122338770889, 0.029471836423908826, 0.02851904497219948, 0.03533145412802696, 0.007435892985085957, 0.057754358931561, 0.037388761702459306, 0.07885709434049204, 0.06608826544834301, 0.05879175521840807, 0.002457004657117068, 0.01710285072476836, 0.009407028865098255, 0.06602873778319918, 0.01830804660130525, 0.004557563206617488, 0.014111964046605863, 0.0818039030127693, 0.04073779586178716, 0.007133538310881704, 0.05055522589827888, 0.01833918155170977, 0.01913977335789241, 0.07057255177642219, 0.032454841493745334, 0.04603541296091862, 0.01664590854488779, 0.03928979152988177, 0.06445771505241282, 0.0385436065698741, 0.06874295737361535, 0.015880188402661588, 0.020004902326036245, 0.01662827140535228, 0.03988651165855117, 0.015693540117354132, 0.012658721079787938, 0.048897115848376416, 0.025910941367328633, 0.07261828926857561, 0.07777352162520401, 0.0900927277689334, 0.045970478749950416, 0.1298950205091387, 0.02302254899404943, 0.024484360983478837, 0.02762845477263909, 0.05200876294111367, 0.08242715121014044, 0.02461905707605183, 0.05248646113614086, 0.03741028398508206, 0.042643081906135194, 0.04735180853458587, 0.03169101939420216, 0.044024144517607056, 0.02167613169149263, 0.03367324759892654, 0.06613034522160888, 0.08019091183086857, 0.0062220663949119626, 0.05071438688901253, 0.05629897023027297, 0.019525146526575554, 0.009648952309362357, 0.014376553608599352, 0.010275683034706162, 0.10276293265633285, 0.02320521936781006, 0.09773558718734421, 0.038589653122471645, 0.06641563420998864, 0.031353765225503594, 0.015665987884858623, 0.018302727257832885, 0.023086562941898592, 0.03625313845986966, 0.026461780071258545, 0.02072206374577945, 0.061004665185464546, 0.08468469022773206, 0.0562550313770771, 0.089763095456874, 0.08120051468722522, 0.022338988310366403, 0.07149891534936614, 0.014846398025838425, 0.01882415650470648, 0.006103437799538369, 0.05064111093815882, 0.007115944772522198, 0.056825412684702314, 0.007486802460334729, 0.06259890229557641, 0.06187281840539072, 0.016842086006363388, 0.02411655630567111, 0.0938212034816388, 0.039387870056089014, 0.010013419177994365, 0.07075557281496003, 0.029197820658737328, 0.02621354095026618, 0.039795721022528596, 0.1115532340190839, 0.0145413150312379, 0.04850888355576899, 0.06482066979515366, 0.05334767898602877, 0.037701691981055774, 0.03484488726826385, 0.01090502704755636, 0.07019601573119871, 0.00894726374099264, 0.054417492283391766, 0.036174845590721816, 0.0130388231445977, 0.009493068828305695, 0.028345990976959, 0.02261652556626359, 0.01995121536310762, 0.020310374020482413, 0.00896948828085442, 0.012509279440564569, 0.06984348816331476, 0.030058359443501104, 0.04838314147491474, 0.02187735019106185, 0.03651834493211936, 0.05846164422109723, 0.05257089527731296, 0.04122027719859034, 0.025577765300113242, 0.04416436961037107, 0.03215941476810258, 0.01795417945686495, 0.06162546058476437, 0.1010840387607459, 0.06878954198327847, 0.0316025924985297, 0.0011455859953457548, 0.018472317278792616, 0.074817807180807, 0.061253262392710894, 0.09479531683609821, 0.14007857796968892, 0.0529720260965405, 0.04223405834636651, 0.030036408570595086, 0.13403716933680698, 0.07046119251754135, 0.02915344579378143, 0.02487839501554845, 0.002991896694766183, 0.07456649371306412, 0.026578189645078965, 0.04389515182992909, 0.07559804187621921, 0.031024366689962335, 0.012316979700699449, 0.14805237588007003, 0.04836825770325959, 0.022910555198905058, 0.07544478838099167, 0.03172687254846096, 0.06393137649865821, 0.03678572960780002, 0.036950824069208466, 0.0066077953306376, 0.019833228725474328, 0.03235956086427905, 0.10658237340976484, 0.03733659985300619, 0.0037744598785138805, 0.05182492554013152, 0.05434505867015105, 0.032312645998899825, 0.029172316753829364, 0.042216977817588486, 0.0477715338638518, 0.015175290045590373, 0.08430497036897577, 0.029311118778423406, 0.005882568157176138, 0.05159408421604894, 0.06298674124991521, 0.10618898319080472, 0.04684803127020132, 0.02453645418427186, 0.04261420494003687, 0.06681223050691187, 0.027765807753894478, 0.03454490746662486, 0.04256570930010639, 0.04629796254448593, 0.01624249005544698, 0.032294066331814975, 0.06945565663045272, 0.02985405175422784, 0.04358082631370053, 0.045098080445313826, 0.0447022782464046, 0.014566823574568843, 0.014203092359821312, 0.04251692051184364, 0.005098984984215349, 0.027033224505430553, 0.08865492054610513, 0.05235154239926487, 0.04291456694772933, 0.026963484888256062, 0.04898032915662043, 0.03208507383533288, 0.06934715464012697, 0.007459067473973846, 0.044403463616617955, 0.03556559058779385, 0.04492865555221215, 0.06366965069901198, 0.08079939871095121, 0.03857790863548871, 0.029275588458403945, 0.06624560075579211, 0.04002115209004842, 0.009606014427845366, 0.03435645761783235, 0.03669046753202565, 0.056541125595686026, 0.008252071747847367, 0.025368865572090726, 0.010806879872689024, 0.045646401413250715, 0.049164225929416716, 0.020156523096375167, 0.031946247690939344, 0.025244125390599947, 0.049226996779907495, 0.04975207368261181, 0.036097784686717205, 0.029689762523048557, 0.03644980759418104, 0.026807097674463876, 0.02742773536738241, 0.0660330273967702, 0.03257921060139779, 0.06464395701186731, 0.031474605420953594, 0.17429122963221744, 0.1610526064177975, 0.11900911675184034, 0.0714200473157689, 0.11367254803190008, 0.12199596429127268, 0.14712069852976128, 0.1380453901947476, 0.1334725582273677, 0.17818919703131542, 0.12327800213824958, 0.13123032229486853, 0.13338520744582638, 0.15278364153346047, 0.3001978149404749, 0.11734643136151135, 0.13333585462532938, 0.09525536675937474, 0.1122674769430887, 0.1120303533389233, 0.16412579541793093, 0.11905236911843531, 0.08960699211456813, 0.144634815515019, 0.07915025009424426, 0.13448901852825657, 0.20385371753945947, 0.21098286233609542, 0.08066606445936486, 0.2479671683977358, 0.12629916658625007, 0.11710437989677303, 0.10238261907943524, 0.20400413603056222, 0.08135353069519624, 0.3302772087045014, 0.2330396990873851, 0.1513025225722231, 0.08829831116599962, 0.10625288952724077, 0.1522876345552504, 0.1465835320414044, 0.08428694360191002, 0.0996486286749132, 0.14072072866838425, 0.1627527628443204, 0.14639269618783146, 0.14159511221805587, 0.15040280210087076, 0.147258025535848, 0.12299706213525496, 0.2116694231517613, 0.0942775871953927, 0.12602801551111042, 0.14338656765175983, 0.17313523072516546, 0.21882298460695893, 0.117056934395805, 0.08021293877391145, 0.22991858219029382, 0.16428828123025596, 0.15789148776093498, 0.11383372766431421, 0.10574839980108663, 0.1333766579045914, 0.128771364397835, 0.23745108424918726, 0.23073537508025765, 0.13397285481914878, 0.07978570662089624, 0.12036225234623998, 0.29754621034953743, 0.16116646671434864, 0.2520770486444235, 0.27826467936392874, 0.09278088313294575, 0.16562263306695968, 0.13852506992407143, 0.18069979356369004, 0.21306607086444274, 0.18907547928392887, 0.22415590938180685, 0.09775526152225211, 0.15885945613263175, 0.11306276239338331, 0.15627216605935246, 0.20945296942954883, 0.141037892899476, 0.18200313847046345, 0.2720404352294281, 0.24572963768150657, 0.08622638328233734, 0.15074554074089974, 0.22002759418683127, 0.174731352890376, 0.13397897011600435, 0.1148382764949929, 0.09962816766346805, 0.12416735480655916, 0.13437484652968124, 0.20470258605200797, 0.09846892557106912, 0.10916007493506186, 0.2277144926483743, 0.13055029237875715, 0.15710846259025857, 0.14968658506404608, 0.12231079075718299, 0.12115062098018825, 0.12515909416833892, 0.18313075765036047, 0.10246422563795932, 0.19941748527344316, 0.15455977903911844, 0.1565887514152564, 0.179749057861045, 0.21030684001743793, 0.1308484873152338, 0.11659987532766536, 0.19215307664126158, 0.13162002403987572, 0.1701835312996991, 0.22653729800367728, 0.1949748705374077, 0.1827662592404522, 0.14525332138873637, 0.1006958658399526, 0.20793183386558667, 0.16730845120036975, 0.18288374121766537, 0.10331269339076243, 0.10408308720798232, 0.14369813608936965, 0.13914554991060868, 0.12284360826015472, 0.21225623931968585, 0.09471312398090959, 0.11207123825442977, 0.10180287557886913, 0.12001569164567627, 0.12157690318417735, 0.14468428707914427, 0.14486706320894882, 0.14354825194459409, 0.11589363275561482, 0.19062578125158325, 0.18380691355559975, 0.13358917931327596, 0.16154325508978218, 0.13959729520138353, 0.10067560520838015, 0.14328533870866522, 0.16432475036708638, 0.16510799818206578, 0.1604471475002356, 0.18441390129737556, 0.10921648557996377, 0.22140899818623438, 0.12936567625729367, 0.09442837676033378, 0.07857269592932425, 0.08734169765375555, 0.14952294150134549, 0.1233177886751946, 0.23221420822665095, 0.14649965451098979, 0.13390062900725752, 0.18152001517591998, 0.12810583604732528, 0.15094010217580944, 0.0717818146222271, 0.12113045682781376, 0.13490788667695597, 0.13272433978272602, 0.22258837474510074, 0.18974740494741127], [0.06929302238859236, 0.01686537088971818, 0.061066300550010055, 0.027706474902515765, 0.04393798117234837, 0.06626374626648612, 0.04613247845554724, 0.041848698165267706, 0.049557304446352646, 0.022006059007253498, 0.0644970934081357, 0.05179500214580912, 0.03205132838047575, 0.04280241730157286, 0.04382194638310466, 0.05845756611961406, 0.027669259907270316, 0.05443901085527614, 0.06986992346355692, 0.08273379920865409, 0.05046994941949379, 0.004634931174223311, 0.03328314138343558, 0.00990428543445887, 0.03780728475248907, 0.07446547999279574, 0.007931526106403908, 0.02921806644735625, 0.0051598684603959555, 0.01939398491231259, 0.021064260618004482, 0.024184071335184854, 0.0474678618775215, 0.036765706463484094, 0.044245649623917416, 0.028581910446519032, 0.028823293978348374, 0.005846356452821055, 0.05551788206503261, 0.03228519395634066, 0.027645247719192412, 0.02319945844647009, 0.017570873169461265, 0.00909731579668005, 0.0448051696002949, 0.015109374344319804, 0.029854725253244396, 0.07276582822669297, 0.037258670636219904, 0.010134079402632779, 0.05634197026665788, 0.050770300294971094, 0.05348425642296206, 0.06195576082973275, 0.02212298808444757, 0.08557085908250883, 0.017459038936067373, 0.026547926718194503, 0.024196144222514704, 0.035244047685409896, 0.04973942748620175, 0.04213816544506699, 0.03541463032888714, 0.012909801698697265, 0.015751039863971528, 0.028565054417413194, 0.036503086375887506, 0.06574871062184684, 0.052646657422883436, 0.024039474992605392, 0.0681328377686441, 0.05061379248218145, 0.06964912710827775, 0.009600724770280067, 0.04137851050472818, 0.05669956670317333, 0.02951704434963176, 0.02068916248390451, 0.06501926851342432, 0.019642969891719986, 0.06305515984422527, 0.020826213039981667, 0.07683470481424592, 0.052110611577518284, 0.0325452796096215, 0.03826028427283745, 0.03515638520184439, 0.02891653926781146, 0.03687468713906128, 0.038364979045582004, 0.102429945836775, 0.12803781079128385, 0.13674434594577178, 0.041650567000033334, 0.05788917747850064, 0.034983212462975644, 0.09527636211714707, 0.041137716980301775, 0.009371281466883374, 0.0898286048322916, 0.0586784552433528, 0.07679959380766377, 0.045030281544313766, 0.11143120267661288, 0.045511927964980714, 0.026606378269207198, 0.061623642322956584, 0.01648242825467605, 0.03438158302742522, 0.046460674711852334, 0.03547362735844217, 0.010825038370967377, 0.06310365177341737, 0.04437220806721598, 0.04065508721396327, 0.04945928158122115, 0.04962869905284606, 0.09079864379600622, 0.10850069898879156, 0.026895014343608636, 0.07885716113378294, 0.041083447431446984, 0.06845084804808721, 0.03187811482348479, 0.03385429081390612, 0.05737565581512172, 0.08501556934788823, 0.008340167460119119, 0.04603409564879257, 0.025805276236496866, 0.043554832591325976, 0.03001394376042299, 0.07048872619634494, 0.05407628988905344, 0.04100873913557734, 0.005990182353343698, 0.02000260352360783, 0.07641558433533646, 0.04917145073704887, 0.060931207408430055, 0.015868161899561528, 0.026094669301528484, 0.0775187645922415, 0.0326320144085912, 0.06337417202303186, 0.027169751847395673, 0.03623924916610122, 0.046126318629831076, 0.03634919834439643, 0.11435786203946918, 0.045775264225085266, 0.07411179467453621, 0.01721436212392291, 0.040542688948335126, 0.04186168203887064, 0.03388035132957157, 0.038331986870616674, 0.04104118954273872, 0.05084075979539193, 0.029615098756039515, 0.0764861106290482, 0.06207342092238832, 0.017013312462950125, 0.02897326718084514, 0.06683731509838253, 0.046439538346021436, 0.0170383710792521, 0.04498491034610197, 0.04004267066193279, 0.03774702978262212, 0.028124558230047114, 0.04213091466226615, 0.04304399379179813, 0.03376563014171552, 0.02157968032406643, 0.03600912772526499, 0.025962054933188483, 0.042842496986850165, 0.04898291183053516, 0.03228981753636617, 0.05353528649720829, 0.017520607507321984, 0.06185539277794305, 0.01653879622608656, 0.06323809924651869, 0.01602566790097626, 0.0792095105862245, 0.09239936727681197, 0.05180106920306571, 0.012765234114340274, 0.013346710529731354, 0.04564984868920874, 0.11420653070672415, 0.07519599079387262, 0.05137156978889834, 0.03468565577350091, 0.029380268388194963, 0.03228168730856851, 0.01929739253682783, 0.05759897918323986, 0.030522199886036105, 0.03371153128682636, 0.03867977582558524, 0.023867465570219792, 0.026594294249662198, 0.06404851708794013, 0.025985799948102795, 0.01927807999891229, 0.046587058750446886, 0.044125544154667296, 0.0288446233025752, 0.03553503265720792, 0.09208781368215568, 0.012590932383318432, 0.03415348764974624, 0.016547063751204405, 0.008892619407561142, 0.023980895421118475, 0.006410406776922173, 0.0874945503892377, 0.015933474605844822, 0.03387982811545953, 0.021675942443835083, 0.029430714021145832, 0.06060650666768197, 0.0379145288025029, 0.06108949637564365, 0.03167434704664629, 0.0263282899686601, 0.0092432647034002, 0.030557188438251615, 0.11168610071763396, 0.021934491851425264, 0.037580499265459366, 0.025245336946682073, 0.039217294834088534, 0.02704948310565669, 0.050920507273986004, 0.023635050893062726, 0.029042537389614154, 0.061935704288771376, 0.05152558398549445, 0.01141132112024934, 0.03917151545465458, 0.04400950936542358, 0.03425146598601714, 0.033575803608982824, 0.040695085262996145, 0.029983517561049666, 0.04339089216955472, 0.03400518799026031, 0.012053911541443085, 0.041788832822931, 0.01745443576510297, 0.044912469311384484, 0.042517814799793996, 0.02997091032739263, 0.03644851625722367, 0.007130537251214264, 0.06887094816192985, 0.032545661815674976, 0.023784922050253954, 0.07545376836787909, 0.09333118563517928, 0.03771732532186434, 0.028019542478432413, 0.014790921559324488, 0.1276729561504908, 0.07245149899972603, 0.04438509917235933, 0.07697620269027539, 0.041523967738612555, 0.07955434208270162, 0.03825881110969931, 0.029429396709019784, 0.05143218470038846, 0.03197567013558, 0.03483630804112181, 0.08347118229721673, 0.08046601113164797, 0.03412387224670965, 0.03869484142342117, 0.0607015127025079, 0.06281814014073461, 0.05696190848539118, 0.062309813511092216, 0.021029123636253644, 0.035299909141031094, 0.05546985397813842, 0.12895458581624553, 0.030171394100761972, 0.031788960623089224, 0.06741103235981427, 0.09396542503964156, 0.05717613312299363, 0.08830228165606968, 0.021855447557754815, 0.03807087334280368, 0.03102423495874973, 0.023990797526494134, 0.07249354908708483, 0.05099764239275828, 0.05280377379676793, 0.008237687070504762, 0.05337963215424679, 0.029053960897726938, 0.04745194280985743, 0.027743932951125316, 0.046487596118822694, 0.042900288026430644, 0.038588012976106256, 0.021001563982281368, 0.11657586685032584, 0.04169046114839148, 0.07434795348672196, 0.06226280587725341, 0.05159511580131948, 0.029774953654850833, 0.05277528274746146, 0.006452796860685339, 0.030390656065719668, 0.0006280983063788881, 0.009514950124867028, 0.06831210353993811, 0.09629662963561714, 0.04216821129375603, 0.03092719729465898, 0.009215381287503988, 0.014237101277103648, 0.052809176631853916, 0.04546343603578862, 0.052715510173584335, 0.03419645057874732, 0.057328188049723394, 0.09403737625689246, 0.0656944299407769, 0.0750049768248573, 0.07579057724797167, 0.010122221738129156, 0.0792182753502857, 0.037601591102429666, 0.044727043714374304, 0.032773605053080246, 0.04344913591921795, 0.05692833372449968, 0.033009199833031744, 0.04348817288700957, 0.13608491804916412, 0.03578000076231547, 0.015684343052271288, 0.037287291561369784, 0.027856015803990886, 0.15083819045685232, 0.14512402442051098, 0.1569149995339103, 0.124450766161317, 0.1538139206240885, 0.13022336148424074, 0.13021219958318397, 0.09626991974073462, 0.17751269973814487, 0.08996205782750621, 0.15441189869306982, 0.16379644512198865, 0.0764004371012561, 0.22009251726558432, 0.11706943216267973, 0.10485203383723274, 0.2841734513640404, 0.2054833699367009, 0.09655274479882792, 0.15993628272553906, 0.08823346230201423, 0.12991240160772577, 0.12050858902512118, 0.13308070425409824, 0.07825654844054952, 0.1764615811407566, 0.17615252116229385, 0.11851440111058764, 0.17958116921363398, 0.12908768258057535, 0.11665247133350931, 0.09314144073869102, 0.1474904068163596, 0.10692155716242269, 0.13770872232271358, 0.16822528559714556, 0.1257462368812412, 0.09396817098604515, 0.0953793128428515, 0.0625796287204139, 0.08169507447746582, 0.0633951673808042, 0.04401741323817987, 0.22746367641957477, 0.09443206523428671, 0.1537058045505546, 0.09474300284637138, 0.14340645720949396, 0.10817393136676401, 0.15522931498708203, 0.22797672310844064, 0.19160795432981104, 0.14789784589083865, 0.11674799316097051, 0.10363658147980459, 0.27602089976426214, 0.1303151503088884, 0.05915175992413424, 0.1117206625349354, 0.08567018812755123, 0.11243600383750163, 0.12335661784163676, 0.08835751228616573, 0.16223222046392038, 0.11790021453634836, 0.06947510832105763, 0.1391378464177251, 0.12345398761681281, 0.1373313699150458, 0.10670107993064448, 0.1902249621343799, 0.2696541039040312, 0.14038005319889635, 0.09530806666589342, 0.13318684621481225, 0.13004661159357056, 0.11253462042077444, 0.07319703086977825, 0.13873833348043263, 0.09216317877871916, 0.22253168950555846, 0.1182333794713486, 0.12284267315408215, 0.14203311293385923, 0.3200964565621689, 0.14156548568280414, 0.21731344138970599, 0.17475486412877217, 0.16583510994678363, 0.18561312288511544, 0.14693928795168176, 0.2296408111578785, 0.21257027168758214, 0.24105526506900787, 0.17791004560422152, 0.13391737185884267, 0.15171717532211915, 0.15552172117168084, 0.09010155190480873, 0.13299120124429464, 0.14136479410808533, 0.3300567314727232, 0.16837064264109358, 0.2324284811038524, 0.11417414338211529, 0.12605764204636216, 0.16331651306245476, 0.12130352566600777, 0.21513565356144682, 0.2014102111570537, 0.13292008865391836, 0.16568377119256184, 0.1900884069618769, 0.2362010403885506, 0.12795163260307163, 0.12833809858420864, 0.13836586440447718, 0.11970015271799639, 0.2663605712587014, 0.12570016435347497, 0.10957163292914629, 0.08848654208122753, 0.1555072344490327, 0.12107337825000286, 0.19839173328364268, 0.2508603420574218, 0.1899765504640527, 0.09011236499645747, 0.18743604538030922, 0.1368191247456707, 0.07885019978857599, 0.12317084343521856, 0.19060350197833031, 0.11283161307801493, 0.15675123722758144, 0.1566742022987455, 0.23873409430962056, 0.2029558375943452, 0.21611294330796227, 0.1539704395690933, 0.14264654251746833, 0.18561414704890922, 0.17038735473761335, 0.17083568614907563, 0.16180550039280206, 0.19842217618133873, 0.15800031629623845, 0.15500249981414527, 0.20977958862204105, 0.13251144730020314, 0.13371941138757393, 0.1127283951791469, 0.09513300145044923, 0.21625962137477472, 0.06817693618359044, 0.11190651857759804, 0.15385139908175915, 0.14681745698908344, 0.24184450943721458, 0.0947608143906109, 0.19566426635719836, 0.18719024606980383, 0.18155808735173196, 0.19717729766853154, 0.09086204547202215, 0.14234874834073707, 0.14172512164805084, 0.07018928445177153, 0.14927467826055363, 0.24850007495842874, 0.13967922830488533, 0.2449030929710716, 0.15967780753271654, 0.1541126795927994, 0.07914198256912641, 0.15433357242727652], [0.08677965437527746, 0.028001296777802054, 0.05470449563290458, 0.09404146549059078, 0.04163524165051058, 0.037675471903639846, 0.10128148715011775, 0.01969551023648819, 0.027565450145630166, 0.01163634307886241, 0.027943036329816096, 0.036856148290098645, 0.03279386197391432, 0.036555990373017266, 0.015432349591719685, 0.06218924419954419, 0.03846043779049069, 0.026689712176448666, 0.044887670446769334, 0.03489147929940373, 0.08161017278325744, 0.05204825632972643, 0.021204175864113495, 0.02353706327994587, 0.026958005983033217, 0.04386184424220119, 0.036706998871522956, 0.0550074106286047, 0.022325150966935325, 0.028288079338381067, 0.07444989489158615, 0.023179826785053592, 0.024813071177050006, 0.05972921018837951, 0.02671848524187226, 0.02319757895747898, 0.05257732227619272, 0.026524127897573635, 0.04725339233118575, 0.028069502004655078, 0.05773507793492172, 0.010018400844273856, 0.025598953616281506, 0.014736661287315655, 0.015588973365083802, 0.06287927084486, 0.013425020097201923, 0.0755648233462125, 0.01980487311811885, 0.049407431433792226, 0.01969372166058747, 0.006473491184806335, 0.027345596317900345, 0.026501373649807647, 0.06671610753983259, 0.046735922442167066, 0.079726223484613, 0.08145190236973576, 0.08107521789497696, 0.05478316328662913, 0.0035247721780251595, 0.03039674167666817, 0.015760426176711917, 0.03657965375168715, 0.05007598032534588, 0.025174404327117372, 0.017818761625676416, 0.016373937396565452, 0.042486529564484954, 0.021106954518472776, 0.04463087250769604, 0.03280556935351342, 0.020214210235280916, 0.013348591874091653, 0.08686955814482644, 0.03849434280709829, 0.044087857895647176, 0.04116671269002836, 0.023777418937243056, 0.04257876367773861, 0.04941433340718504, 0.06263859977480024, 0.01879185267171124, 0.054827966741868295, 0.066108540922869, 0.016431871299573686, 0.046379405830521137, 0.015596112825733144, 0.05877048155525699, 0.01111711708290386, 0.036583164110197686, 0.05078002614027355, 0.08185115555534139, 0.04655216667742934, 0.029968515045766253, 0.10830447514308617, 0.020710658791358583, 0.050288642742088996, 0.0136778382693592, 0.03665928990812972, 0.03675351297715679, 0.04140948032727465, 0.023133167960622814, 0.015138102880882798, 0.00857535869727144, 0.018404275324428454, 0.03211543138604611, 0.08631525546661578, 0.03294942725915462, 0.011195326460438082, 0.03940724753192626, 0.05777778111223597, 0.014946544361009728, 0.08062949142185971, 0.002798868026729906, 0.012930141183460364, 0.022532089569722302, 0.03548879314621445, 0.032786870942800306, 0.07468372336006723, 0.03029402287211269, 0.016845583377289586, 0.06704153187456541, 0.04127290660107974, 0.10342993788071908, 0.03830703215498943, 0.08813773267320357, 0.042781926604220644, 0.031240353928296827, 0.0180756282134098, 0.06802677744417451, 0.03682676295284182, 0.08997319004265592, 0.0196830254571978, 0.010428481964481762, 0.06201499163580593, 0.021017431099608075, 0.0633813114836812, 0.05743315370636992, 0.06223556905752048, 0.007493779112337506, 0.009061785476660589, 0.012983649103261996, 0.054301494601531886, 0.030413003987632692, 0.020004121215606574, 0.051033762720180675, 0.021346569883462507, 0.03290617489255965, 0.07386034762021154, 0.02794507352518849, 0.05487841051944997, 0.02218228382844245, 0.006807035078963963, 0.023842312330089044, 0.018797003176587168, 0.0362956672324799, 0.047766212665010244, 0.04801172253792174, 0.04660337857785635, 0.06124733263277449, 0.08151146714226343, 0.03191602372680791, 0.01298779121498228, 0.08479906260618009, 0.06152659909275826, 0.06399106001481414, 0.032064345650724135, 0.06316971033811569, 0.008020957684493624, 0.07365489145740867, 0.024213866709033027, 0.1109770973562263, 0.04611241820384748, 0.04509087419137359, 0.026327009763917886, 0.030707695987075567, 0.04566228708426934, 0.07521594714489765, 0.06906141294166446, 0.026814315060619265, 0.037282508419593796, 0.03194998069375288, 0.03623243253969122, 0.03478622420516331, 0.025868698321573902, 0.03921637086023111, 0.023756132286507636, 0.060365327226463705, 0.04811160819372162, 0.01078821671399055, 0.019110812900180463, 0.010464297083672136, 0.010678531925805146, 0.020049833801749628, 0.025697701930766925, 0.02548661101172911, 0.03628296537499409, 0.02637862242409028, 0.030765991687076166, 0.031977911421563476, 0.03747042763279751, 0.0527502649492817, 0.04244049785484094, 0.05566660845943261, 0.001958204652510176, 0.02960958459880203, 0.06072168056562077, 0.026820743914868217, 0.047997851797845215, 0.032561647676629946, 0.03179253777489066, 0.06937895566807128, 0.013662717938132118, 0.04914100041787606, 0.03795403703406919, 0.01867669361672597, 0.017373940572724678, 0.03553737042238936, 0.047142634211922996, 0.040127527827280574, 0.03472011369012762, 0.07552615745225921, 0.06437361487769522, 0.01791573806258384, 0.0421903050300898, 0.06410662725102156, 0.06103605432144832, 0.022309821906674188, 0.042053905708598904, 0.0302943308633985, 0.03186457062838599, 0.05697770138795022, 0.04885559268586803, 0.0953572042635642, 0.02312428074219497, 0.03200716688297689, 0.04313145218475256, 0.04198458540486172, 0.053242935973685235, 0.036637938319472596, 0.08159636883647181, 0.012586032353283372, 0.02648171972396085, 0.03604150020692032, 0.022736107821401674, 0.0334305133583257, 0.03676580665342044, 0.029477903481165413, 0.03323231911053881, 0.09131189086474478, 0.025008226330101024, 0.02638661906530615, 0.0438593840226531, 0.05512498908501584, 0.07686982324230485, 0.05062794894911349, 0.023134394359658472, 0.018111037934431806, 0.03265320643549785, 0.016046019445639104, 0.011469798646430718, 0.03848580068734009, 0.0269669729823363, 0.04021411048597656, 0.04142779653193429, 0.04600427986588329, 0.04797894558578264, 0.10557651839917526, 0.018641135466168635, 0.010744519058789592, 0.09469960205024108, 0.09534105513012037, 0.03927750527509488, 0.0392805555020459, 0.05456991828395985, 0.01102547761547612, 0.08863697541528381, 0.031755074160173535, 0.05164216796401888, 0.06150487271952443, 0.07323577839997597, 0.024279205390485004, 0.035057497734669596, 0.033613445339142345, 0.01622730942472117, 0.06018194995704107, 0.03093002858804539, 0.08552097191568464, 0.06736117487889715, 0.05074944223451894, 0.069885174598312, 0.016981544831651263, 0.07983167524798773, 0.031893722189124674, 0.06714410410495475, 0.0550129878683947, 0.037263605918269604, 0.042554180035949685, 0.049752667400753126, 0.06238750895136036, 0.05781946383649483, 0.03757788690563757, 0.009323239464720245, 0.03750631047296338, 0.007816916240699356, 0.1047865764121525, 0.028598647731996607, 0.06326310962322168, 0.06388471025275066, 0.04743991630675737, 0.051419827941572294, 0.02059114889561897, 0.01565468126500491, 0.01837561543652555, 0.013946722083346685, 0.011653949604806257, 0.03842921563773416, 0.05917387221415993, 0.07208743103547022, 0.023202388074423652, 0.017160422830784228, 0.040733495116000995, 0.04840202542254701, 0.03740232816198841, 0.05825032880238723, 0.08103457788820378, 0.013430344079097267, 0.016354511681129225, 0.035432857475825585, 0.03495200886391103, 0.03751500844373368, 0.042793403918039985, 0.04270410499884747, 0.038244988609221764, 0.054638377696392126, 0.05448903903015889, 0.04090170288691297, 0.05449398173368536, 0.017014748518704437, 0.09840785423875786, 0.04725436454464216, 0.13781492365524173, 0.016129138130054343, 0.059585997951216996, 0.025463333549851086, 0.02324531760677928, 0.009411019764229422, 0.03289846397819929, 0.02360929094720632, 0.053248583717504516, 0.017795474886952434, 0.11677752321702428, 0.15940968442009762, 0.13127660262398422, 0.25652088050264865, 0.10793300796649419, 0.11132242609164678, 0.1250847161281854, 0.18054508545901626, 0.10449300505570136, 0.09772389836143702, 0.10618812229949981, 0.12907827214803547, 0.17897719459142536, 0.09606562132830732, 0.10207021201495081, 0.14448349160375074, 0.16394809557823464, 0.0739410042297095, 0.12164152940385975, 0.16729345981730148, 0.16186340275453404, 0.18399782362394035, 0.07587760890601203, 0.09242183208698407, 0.19427161139901727, 0.12417387828463688, 0.2176861182670109, 0.2069368661614135, 0.17417300550732762, 0.19752126827370375, 0.1394772602361627, 0.17750889994204044, 0.14034796273335814, 0.14986588794272393, 0.09479536878643557, 0.09055071452166885, 0.11192993333679624, 0.09435871135792695, 0.15473626175662503, 0.13463707698974758, 0.1230093149933964, 0.1147327950457111, 0.14756450284039602, 0.12923525122459978, 0.11236190781346522, 0.16267788014374673, 0.14180085039697587, 0.16892554645892233, 0.10434372947202064, 0.18927648256067187, 0.11341025077854283, 0.18374930805293843, 0.08872271573636681, 0.12419233549735509, 0.17356678959913552, 0.07548746187239885, 0.16148248803801835, 0.10303052884410135, 0.23567309137433767, 0.1875742184347473, 0.16551839100429788, 0.20288571948185563, 0.08814674976747483, 0.1087270985590294, 0.19259891443653032, 0.12712490977719426, 0.13816986320307478, 0.07156076593673788, 0.11715846761944704, 0.10394475088105537, 0.12582371709868312, 0.19741977215744555, 0.13004913489567116, 0.11153030165587552, 0.12496566079789773, 0.08407417728449218, 0.11398322589229792, 0.09809353243326768, 0.2091331928386353, 0.23284016526304185, 0.16270213352981955, 0.17461820505559444, 0.14599744317820296, 0.12851901934482157, 0.1565741014201194, 0.07845623069442809, 0.1558289851527661, 0.09556323930155486, 0.13152989762602374, 0.10941098022158258, 0.2001551355351694, 0.21943482599454, 0.18231524125440046, 0.16482282051583752, 0.12785889382939786, 0.19678395939990878, 0.1402520772535354, 0.1656043465482071, 0.10208684354438446, 0.16401163826230913, 0.12532359862234443, 0.18878354807384312, 0.23619327752385288, 0.16576565976720303, 0.17484255629824474, 0.11728602054063231, 0.16139069921337068, 0.15343003731686622, 0.11794698468293063, 0.04028572773677297, 0.10412038012873381, 0.13554482749896124, 0.12728306144708768, 0.18267041828949004, 0.12948594870977104, 0.34870173723902553, 0.10104249333380722, 0.1256243762327358, 0.10771510598715395, 0.1554996200138703, 0.215956661850214, 0.09996675769798458, 0.13155253313016146, 0.15752592065837234, 0.19580799067625776, 0.14782768324948847, 0.1624519407050684, 0.13477723899995908, 0.22512605966767296, 0.14797918527619913, 0.19013053126400337, 0.1905541491578333, 0.11656693139229901, 0.1561344976653345, 0.1195311063202098, 0.1901561502018012, 0.20636326022213325, 0.1574192740372382, 0.13373046938795596, 0.10633097088430077, 0.1254612224875018, 0.11852845738758333, 0.0841578544350341, 0.17154943925561383, 0.12305453405133449, 0.10936580569250509, 0.16497567325131968, 0.1832140563055873, 0.10158380842767656, 0.15089806693140417, 0.12556957604829222, 0.09765199909452349, 0.12031176403979771, 0.14289064973127097, 0.15282499400200322, 0.2622604131465778, 0.0982378727348987, 0.11576966440770775, 0.13130704552168027, 0.18616440502228215, 0.08992102448246442, 0.15543563204118982, 0.1749023437150754, 0.11851708026370034, 0.2125822499510832, 0.21327829541405663, 0.1746405882295221, 0.08573165279813111, 0.2020100297522731, 0.22985829011304304, 0.13782187015749514, 0.1393253426067531, 0.21795811539050192, 0.08985204927739687, 0.10974292803439312, 0.11658763731247745], [0.059363676482462324, 0.0397564799641259, 0.0061962373365531676, 0.05334926718205679, 0.025603636568121146, 0.043402432565926574, 0.03803894986049272, 0.03552568901795894, 0.04539778565231245, 0.04981239173503127, 0.02106197294779122, 0.030047264335735235, 0.06047309820132796, 0.015695644106017426, 0.012389597923174733, 0.043035726266680285, 0.015295115354092559, 0.03990979654190596, 0.03842061043542344, 0.021789301790704485, 0.07483098772354424, 0.01821427809773013, 0.03198039390554186, 0.03703172558743972, 0.09841946142842062, 0.07889751170296222, 0.054766320245107636, 0.03200814280717168, 0.02717598032177193, 0.052342640337883495, 0.035604134027380496, 0.018724265282799024, 0.018516597519919742, 0.032277943173539825, 0.07774336816510186, 0.06451080829720013, 0.026305995852453634, 0.010719378806243185, 0.026628831947164144, 0.05681976494088303, 0.07640063005965203, 0.04412300972035155, 0.016601481729594525, 0.029547459416789934, 0.008140434183587786, 0.00985500868409872, 0.046103516142466106, 0.04426383966347203, 0.026666529338399414, 0.00988016377959866, 0.05631129730318207, 0.00871177564476966, 0.03588891093386337, 0.07460813561920077, 0.018212161121482495, 0.031236082868417725, 0.031121393221837934, 0.017066227592295036, 0.006685662392555969, 0.06494558809208684, 0.036255001250538044, 0.04112487040401902, 0.02063419160549529, 0.013533659384847851, 0.06562165493960492, 0.01098734421248082, 0.030170475693012122, 0.04937466190312989, 0.04170148946286645, 0.02875740610761568, 0.04132686815864872, 0.034766954340739176, 0.030880269441695418, 0.00701367496731109, 0.016830504791869316, 0.028294437688600738, 0.017806009673222434, 0.023475860216422006, 0.038378256067517214, 0.048194476403295994, 0.04355373792350292, 0.057176526461262256, 0.029929958618595265, 0.08523748634615913, 0.02617405498313019, 0.061583121059811674, 0.06719181677908637, 0.03720793371030595, 0.05051339845522307, 0.05228745794738643, 0.08841234215651639, 0.0222731690882938, 0.03221899438358378, 0.0503251601185184, 0.03283003425167408, 0.03448180636041798, 0.04091789283847902, 0.006669463164143963, 0.015140082559810253, 0.07923334094812162, 0.01825634673878085, 0.019205303142371122, 0.041449615673627704, 0.05148508498677984, 0.07946780766360462, 0.0645726959919557, 0.03185342728102114, 0.060887116414960474, 0.05204941779084038, 0.0787717622006312, 0.05187970346014481, 0.03851489658700302, 0.04585115624649916, 0.11632954061497003, 0.009699898891994962, 0.029610573510581162, 0.040920297396951355, 0.0394943051651353, 0.015530747241427889, 0.040056849393295124, 0.04981688914995175, 0.05887085702852346, 0.004629392433344037, 0.048071046112454496, 0.014775994186493335, 0.025971027498599142, 0.08431935319094919, 0.02116633560945047, 0.06920115192770027, 0.029949363924970385, 0.03356651192007121, 0.026400888709758874, 0.03742262219020631, 0.008350097396032652, 0.03047257432626793, 0.024563470215070993, 0.021980983692628797, 0.06297272950178012, 0.038193624568521045, 0.09046626553754322, 0.010679415081540355, 0.028412105202733073, 0.056110828372766264, 0.0631894069374539, 0.010831335494003724, 0.03594526962842792, 0.03412193153053522, 0.05254204057564493, 0.00818848824565066, 0.03222160674340557, 0.08229764644056559, 0.057917100784834474, 0.06970493661356159, 0.008019414017326199, 0.058002766891149804, 0.008621758697699988, 0.0642080268880818, 0.061099648955860175, 0.07002478741924278, 0.029300511632754933, 0.015974880880094133, 0.03145274917187635, 0.026345327823946718, 0.06610793236177415, 0.011491076948004775, 0.04198749833449256, 0.05822526276460849, 0.0340316158690257, 0.03644506898126565, 0.014165651937219081, 0.02703936206671642, 0.036471136918407865, 0.002878824466279184, 0.022637415167992003, 0.01858719431766076, 0.02531197438656818, 0.042958368503605016, 0.034898455487564206, 0.012790330765710678, 0.03692283025884535, 0.1005583829828538, 0.023927477486722637, 0.019364052241144236, 0.05587541170825716, 0.03479143408185337, 0.021020097265136428, 0.05591900917352177, 0.03818279663391877, 0.07144571820390411, 0.011272600731899729, 0.009138296263699885, 0.022337695118039846, 0.014854530109005282, 0.031948900868883356, 0.05473121294926386, 0.02030389692663448, 0.028038489508617204, 0.028252847732801456, 0.04856549086980522, 0.006212404559846618, 0.02118687640177086, 0.061444001767085865, 0.04398617624246981, 0.02545015300711384, 0.020508301095105708, 0.04644502652809024, 0.10500317963305861, 0.03540043304383289, 0.04200021874567028, 0.012760440768033732, 0.08454976778011769, 0.05179776293516625, 0.04196840287477244, 0.056870331172831357, 0.05216522251430433, 0.06575200575753115, 0.038483652169816196, 0.05522120853129309, 0.0191466363685322, 0.07016830393695273, 0.019772311388805974, 0.04333947246777825, 0.01616297449800186, 0.03860832184727769, 0.03350525876157917, 0.015086228613654384, 0.04771299325511791, 0.04272940110240597, 0.01077355002053082, 0.07658572169020772, 0.02451570559060201, 0.017147930630017072, 0.01672511425567791, 0.09792789991479367, 0.004745585392811336, 0.05320548349118326, 0.03382608549145516, 0.010597602577036014, 0.05333610148227308, 0.02668450786586618, 0.04803595737030264, 0.07156138934078626, 0.03339942479215097, 0.05685578507836908, 0.02196192534029251, 0.029200319841038436, 0.027516607551660854, 0.023757223243592307, 0.007075510247886996, 0.04102980499737896, 0.014978250765125267, 0.08658751234179363, 0.010978194459312363, 0.05879496871784795, 0.0073431727651041, 0.03346494158904534, 0.09803208260564134, 0.0332755900308257, 0.043277610748191364, 0.050840830299421214, 0.05975801293971017, 0.08471910361549817, 0.12755045725498348, 0.025566594122210518, 0.013486725965776714, 0.015678474519518204, 0.13826276524923742, 0.03653237894468475, 0.03527318069245666, 0.03059165563172428, 0.015393567737191916, 0.07534902906627394, 0.05738825748267118, 0.05818936879222747, 0.042438045056769624, 0.015369392276625149, 0.05813248688355088, 0.06104254811361898, 0.04459276322450023, 0.04655466771509964, 0.042539641362964176, 0.04366029548691586, 0.002432766809761233, 0.034195140688098036, 0.016306726647599135, 0.03735029618837871, 0.03550749155692756, 0.058619053743314, 0.02151560885977233, 0.04073730975505896, 0.04340874824265484, 0.02240289279143326, 0.05120963316585403, 0.06177900351758581, 0.02612275588035118, 0.04338888837082777, 0.05155836093763355, 0.0413560865126783, 0.01954322895471705, 0.018972899597429205, 0.004321284723118879, 0.03656961991509888, 0.008899680942704435, 0.054648600780637935, 0.042508805126999505, 0.03414055201574229, 0.0813838177418802, 0.02143108195014065, 0.02415464332443662, 0.007230402961795335, 0.04107634136744309, 0.04381412785733119, 0.04027718190627638, 0.03978782086051069, 0.040265663774334826, 0.0448083125957055, 0.03704047921928577, 0.06451352455769666, 0.028697717025352176, 0.023629297393199522, 0.0319622817914933, 0.031701331536169164, 0.060199846848263405, 0.04597577397362329, 0.02351613100472605, 0.08848020414006896, 0.029598897672258317, 0.20262880279915407, 0.042854709026869386, 0.0198146880211425, 0.04770007617480587, 0.013856749665137613, 0.004664899561248603, 0.05899172319914214, 0.02417692816379713, 0.024017420219024643, 0.012400693958625197, 0.039440499458578415, 0.016623879746475723, 0.020298030249250587, 0.01127575857026386, 0.02365716874919599, 0.07462447028956376, 0.038260918809100986, 0.026695142842072528, 0.026157182255701628, 0.021110244088049512, 0.05488041431817692, 0.03721766697708517, 0.013862859395885607, 0.019979977296316065, 0.0626238236145582, 0.13596598146250471, 0.11734973391867243, 0.09799755047424696, 0.2288051974028349, 0.14527493272908032, 0.11516618702444248, 0.09687088866485283, 0.18246764870127663, 0.12680176383582875, 0.1078754173067864, 0.15468172874534503, 0.14735996694071218, 0.11083053061156534, 0.1490890671266243, 0.09719243898871355, 0.05547388384002261, 0.11081026255851611, 0.1102603756589815, 0.1687657175352797, 0.110425325401593, 0.10535452718613669, 0.12162020750110969, 0.19114029739284888, 0.11221083623240702, 0.216192145308014, 0.20460036263102666, 0.17894596501719207, 0.10183624995988794, 0.12913654558360577, 0.17074306611903012, 0.21078634163131937, 0.1511855304124765, 0.21387545712059364, 0.13483217277098447, 0.18479184742318466, 0.1945016029640101, 0.12221661221701652, 0.10492443034308963, 0.1081717420311179, 0.18705388385569677, 0.13399033981841058, 0.1793682767311111, 0.0937108312791679, 0.1946597546339035, 0.12036114654620178, 0.12825895595597103, 0.12992387521080673, 0.17461122886743397, 0.13492722704540938, 0.1668853231240064, 0.11363670229911804, 0.17022334010107443, 0.06412594535504468, 0.2042004044051282, 0.08039731794269755, 0.09722705275635235, 0.1540617088903673, 0.16923487361054868, 0.15176008630078286, 0.2374498374410905, 0.1543606905033812, 0.2499374665785581, 0.08267111741588451, 0.18062445073155686, 0.19611531402915716, 0.13339907076442614, 0.19217761204345152, 0.10730488385888748, 0.13647062703967094, 0.07793069366016425, 0.1542862827773206, 0.1779751171125099, 0.1279717596480623, 0.14010927319759503, 0.1090889771876391, 0.12802268582163379, 0.13512166973669082, 0.19139875774271786, 0.2794745285063982, 0.1342880746233277, 0.22549952322151512, 0.20272569759981707, 0.24807283538393676, 0.14747094770427793, 0.1101438510522712, 0.12303929775953293, 0.1522280549397692, 0.163386705389712, 0.11882884165970609, 0.14456199598498642, 0.25939124054275453, 0.10320648463675752, 0.10995262928190641, 0.19967477302998304, 0.14760161022422835, 0.10284276548190974, 0.19144508260069415, 0.12467763328459114, 0.12123786043957807, 0.167651308584027, 0.10221707561868243, 0.14577947440557182, 0.16583389282459393, 0.15111993940081447, 0.1558130289777182, 0.2835743600735441, 0.09615891671273857, 0.12739009398501366, 0.1445620256708935, 0.16861757001606748, 0.10958690632833168, 0.19897224119631574, 0.2217206111527048, 0.1421384236891754, 0.1134285595617257, 0.17951765621546656, 0.10356646336731501, 0.16875164641533047, 0.06152215733891353, 0.17356465221382678, 0.1802894749562256, 0.13135337037965655, 0.11971175248618238, 0.20223872998030856, 0.1410484017105773, 0.13775969302514568, 0.09839720441959798, 0.1218278678425122, 0.12054201535647735, 0.1404694077791646, 0.1759768696501851, 0.09278936588088982, 0.13880490412702784, 0.07573525013867766, 0.10663138484233059, 0.1890145638026297, 0.10853923871763982, 0.11647491992334835, 0.12372329816571437, 0.14922732923878357, 0.14754289150005206, 0.19548218784620985, 0.15232998150167987, 0.11554719079867937, 0.09582268670783378, 0.15313426178181544, 0.14408593793632463, 0.13377198512898758, 0.13581911043729633, 0.18115459650289267, 0.13376515737036243, 0.27421875740401447, 0.10858235007617623, 0.09398650945513509, 0.12733682262478396, 0.08482777629978955, 0.16374073951737955, 0.11140265967696905, 0.16540335811441764, 0.1282147684833035, 0.10736890151747502, 0.1117579554556869, 0.0871253912919201, 0.1674961848766543, 0.03827434054983314, 0.1682859190623276, 0.15020576189272106, 0.11409554252168164, 0.10413699681521393, 0.09435840707737952, 0.1339611882576719, 0.12762370723066851, 0.1293011984671466, 0.0783600854629185, 0.1262468154891394, 0.12343978291028179], [0.06435464558308013, 0.0495738246536348, 0.05185195826925337, 0.013439334270515246, 0.07144903560401872, 0.07303758786292747, 0.012028126548102591, 0.04663283812988084, 0.025689389876788482, 0.027186773004359566, 0.03366628625371959, 0.036879570470773615, 0.08252087704022415, 0.10667357593774796, 0.028336003524600528, 0.027362133223505225, 0.052414168530958705, 0.08028965457924642, 0.009956212579709245, 0.02762094052741304, 0.05979146153549664, 0.012149143003625795, 0.0899660876893904, 0.05067497884738259, 0.003975753288614214, 0.07210095296613872, 0.02968330398289254, 0.02364397150813602, 0.05191417250898667, 0.12370240670861676, 0.039899784969748, 0.06504824195872061, 0.01675044375588186, 0.016193274532270152, 0.01759695038344944, 0.058259883953724056, 0.06000960842357017, 0.017598755657672882, 0.016831217253638897, 0.03132488825940527, 0.05441634937596973, 0.05520007587620057, 0.021679109559045173, 0.03881306925904937, 0.055375968586304225, 0.06580799337825738, 0.02926792949438095, 0.05182560831599403, 0.02469958195433719, 0.03045316530915443, 0.030072085464780685, 0.04638792197511066, 0.03471835851087235, 0.0229731572107994, 0.045505515809054486, 0.08587926597101614, 0.07606894199852832, 0.022165361006045714, 0.006748494470230071, 0.029453883871610742, 0.021786051183880772, 0.09811688039917499, 0.04616210870153736, 0.05169108662812505, 0.06914770245202817, 0.015023419728095178, 0.026522830994508695, 0.03478521488432307, 0.05084334989078343, 0.025761632387002464, 0.02640526923642028, 0.07125255942810327, 0.0712822527566459, 0.034077606760547496, 0.019125551953038666, 0.002583335817689658, 0.016049839650804643, 0.026018357966677286, 0.03472064432571642, 0.036773120518773794, 0.02880289604945574, 0.0332036165491445, 0.0087455841821793, 0.056301820077351294, 0.014033158167876536, 0.025834930602286477, 0.03359727023052983, 0.05840808342327364, 0.05378832916903775, 0.03430979879340157, 0.024310275402967818, 0.04379237550892867, 0.04703466656792443, 0.02605829849926522, 0.04667813882406335, 0.014102225213719066, 0.06029393261997029, 0.08030109849642031, 0.02924552962213056, 0.05227267065492924, 0.05847110289323609, 0.04538379616860766, 0.04872407669608947, 0.04670043294026982, 0.05439853783173021, 0.02504242078430252, 0.07838836871087551, 0.06804734977777116, 0.12718223326373845, 0.008773900826781755, 0.12900206842459738, 0.05989713594317436, 0.029558663991338108, 0.016455623735964764, 0.02788221918308409, 0.02578850184363546, 0.036943628947483376, 0.026705124728323426, 0.03742126405995805, 0.018962641261168756, 0.04179928968369495, 0.026360679148638155, 0.03747987146198284, 0.002556185040702985, 0.018605104196467437, 0.03125353447103407, 0.04363224972621538, 0.02682065485714702, 0.10622982357745059, 0.06543784722452983, 0.04266805146471597, 0.0063057894658413716, 0.0252790601371089, 0.020036130044900347, 0.023580963170388713, 0.003991760950157186, 0.02827558528224472, 0.0354038395016687, 0.0030745510730412207, 0.04162229859502986, 0.0906878337264061, 0.014274573240982136, 0.050155913340859115, 0.01839881868363591, 0.09930780477588996, 0.0063924175810825545, 0.05878267875232268, 0.11170971585670486, 0.02191484163631685, 0.019995553120679688, 0.007072672924550716, 0.05147974894498475, 0.016810823035484646, 0.007307785308512393, 0.050389422685839236, 0.06638804858084768, 0.03738830528163817, 0.024125456511683296, 0.06392557290382683, 0.0563165813946398, 0.03925504788639955, 0.1045297784730792, 0.057311801429023035, 0.02862590681615984, 0.020129262156842742, 0.02877374819945544, 0.05318667746905703, 0.04972914503014181, 0.04639778140699491, 0.05517053468793165, 0.05302900819515344, 0.06139533914392814, 0.018807122360158246, 0.01029513101457269, 0.06498411297798157, 0.025351443655381445, 0.05472993645526003, 0.004188070606687688, 0.0775545509532094, 0.010287897857779171, 0.05594639813352842, 0.047964536788640544, 0.06651695963228121, 0.0172786135590286, 0.07285573941771872, 0.02499936137610348, 0.03355970271513797, 0.053034192096674815, 0.05985333809803706, 0.02483853055309737, 0.022883125420776196, 0.030604396451963112, 0.008492821671097772, 0.06097214427427389, 0.02661008715222124, 0.01628962385439081, 0.026002782142313663, 0.03491897587082349, 0.03842093326966278, 0.010867085675272392, 0.05415110950707458, 0.0608570334588876, 0.014073782404011581, 0.038446377802756615, 0.0595028699899558, 0.02625641667691525, 0.026727298245532438, 0.030002946987224277, 0.0071452470820077, 0.020366138996905647, 0.02374789815803524, 0.016869352512003388, 0.009075286998267984, 0.01731415315589402, 0.03282505444076378, 0.03865838712954428, 0.0243034847517265, 0.0045442351620295085, 0.00825600605821819, 0.020561268174787983, 0.03780846847803332, 0.0728506557061337, 0.018802782651619054, 0.05972982988168951, 0.09685935568995774, 0.07254017080413178, 0.0614886122639291, 0.04964495950844139, 0.010733764411270386, 0.05200861080083996, 0.00522952319442993, 0.013084847432764946, 0.08467493840726092, 0.08496146678226069, 0.04145852886722423, 0.04595301601511892, 0.05117588400025852, 0.024166311741282698, 0.055593870565644465, 0.03702185131260194, 0.0431195147393737, 0.03546250256476924, 0.038096035859780386, 0.06711398775223643, 0.02884198311221553, 0.026843386840482708, 0.028771998586307745, 0.06281165377004072, 0.03258493627072312, 0.0774815162003506, 0.005092378014524002, 0.045721235874225385, 0.007102711815605289, 0.05584613769315183, 0.04642780499125365, 0.04340832521847915, 0.03568542888388038, 0.009598810956958914, 0.03690873687446583, 0.07024780279607512, 0.008418970555794658, 0.06905454065417871, 0.07365635348833166, 0.049022568491636775, 0.034479049281799234, 0.03159400213917252, 0.03691612495458685, 0.05541145808820147, 0.06506914825877175, 0.019949742199969478, 0.07404944684822112, 0.042736299365060404, 0.036022894564666785, 0.028955440793652087, 0.0435106748045655, 0.04197367212327663, 0.06286506613832898, 0.050366275099804625, 0.02221453014499275, 0.042784531542565674, 0.006474312185673625, 0.02003891309868777, 0.11887224245583639, 0.046027535063331015, 0.05451606433780398, 0.027042117289965972, 0.03280676421127282, 0.036891893832944334, 0.028881968173664063, 0.027522435266291723, 0.013253215693111997, 0.012402868451317772, 0.025385779117641505, 0.03509069028950762, 0.05570132612774614, 0.04893407109193504, 0.016659057546348777, 0.01614044846064644, 0.09883409933536313, 0.026674505570554174, 0.031649507363908924, 0.025299294793512672, 0.017545549235364888, 0.06304718175670132, 0.042731709181680344, 0.05050110106822103, 0.06743480334989727, 0.006920068344697938, 0.025148302993329708, 0.05822633516800124, 0.025489993349765427, 0.027603941634879448, 0.06013091617205646, 0.04293968864658382, 0.01964906663488364, 0.03994603190221824, 0.011366900798748247, 0.005452736631923472, 0.06335627884254791, 0.039463279681513086, 0.15056260133860633, 0.012459701192710781, 0.03545996070897672, 0.046711706163478084, 0.02345393346331548, 0.024045241480052937, 0.012586823668243596, 0.05159784690476954, 0.005143331554791075, 0.039116503758123145, 0.017933198942046147, 0.03495080287393648, 0.014137434554868378, 0.05010075692553073, 0.040041379324975424, 0.024009343796933535, 0.013128836380928988, 0.08288298573461361, 0.023517160734627396, 0.023482454198529013, 0.0754000294546131, 0.03246945438149851, 0.02870210682885954, 0.11410441860789433, 0.08851723730913363, 0.03604515157348942, 0.03153029618260916, 0.03323001103126444, 0.0404655872262083, 0.047306711931014434, 0.06542943126987666, 0.020544651488307863, 0.12155469812569208, 0.13186419062549248, 0.18103902926668525, 0.11660996111459099, 0.14749022870091721, 0.12151109694968909, 0.10847699479199946, 0.20310073450673372, 0.1600238709943369, 0.11831674491986632, 0.09229485061950982, 0.12362471126834862, 0.18783496459946036, 0.11993386986432597, 0.15973422559909523, 0.12345556839136407, 0.14910720521584153, 0.14808218053076416, 0.11788292249548249, 0.07118863082723692, 0.09384009856148623, 0.08772218192461878, 0.13914072595071048, 0.08794227323960513, 0.16945201117778197, 0.1350976835237816, 0.144168360857293, 0.1040863675007131, 0.14055582345463336, 0.19784140109550208, 0.16741972882300615, 0.09724699426442385, 0.16573048196732998, 0.15717173810116947, 0.06379835394909605, 0.09993609215598553, 0.10697640929720365, 0.0811718158365693, 0.11295463889837265, 0.17046140623278916, 0.12483007041737437, 0.09977437817724422, 0.13326877931831405, 0.10773664311273023, 0.14098380517680198, 0.16194765135878697, 0.1082956361642573, 0.21702624508179724, 0.2971389197045937, 0.12022050214000046, 0.13892703194869682, 0.15116918832063675, 0.10480946424650028, 0.0906766124535352, 0.18753877346171066, 0.15656320669222623, 0.16195646807318553, 0.24911086249630898, 0.1106647941924166, 0.12289995211176574, 0.11020653284504078, 0.10302056180080399, 0.11958753922954202, 0.13921241741627455, 0.1952845836058259, 0.10677294209017418, 0.10609765449771658, 0.16617539949947968, 0.1351860139402561, 0.14724825887242332, 0.13408295984845608, 0.15901097300229594, 0.11598028591834009, 0.22103154187789187, 0.1317297579953447, 0.10555167871643789, 0.1748759826296009, 0.1758680708007887, 0.1656346261734143, 0.24715154810110107, 0.11219939231523313, 0.11649376305285841, 0.12463021004805341, 0.1437135727610439, 0.142426228558179, 0.09373786771902815, 0.2301559507031925, 0.24010801746044308, 0.16013752348953858, 0.1907551079057157, 0.15989215462468565, 0.12162829691078514, 0.2401242556516081, 0.1294682262232527, 0.15481727459700778, 0.16292437707306817, 0.09603367929230444, 0.10811408457811922, 0.13935344031779096, 0.19241590081946924, 0.11686045821988955, 0.1698551161098294, 0.13753811741480604, 0.27389046095777303, 0.19011592579772696, 0.14712896605487913, 0.18881029507610947, 0.1751960115507245, 0.18975996208610013, 0.06451368040870875, 0.2951460750773549, 0.14789279928663746, 0.15209602686809376, 0.17704520607367158, 0.2402965526562184, 0.12114050550735556, 0.07726537311100401, 0.14620316651416942, 0.11948904138989747, 0.20581505057634786, 0.10306053387466818, 0.12045742536429316, 0.15370592329418287, 0.08275257554487325, 0.14065656258026138, 0.17146281577879563, 0.09797725273529068, 0.1528932122164406, 0.1858730081585236, 0.2171443059341982, 0.12968935654498637, 0.13404715864453465, 0.06080122395360377, 0.14818297902820632, 0.0974770229368005, 0.07087673584464937, 0.213440039078705, 0.13986619014758617, 0.04157109411607962, 0.1300675846869126, 0.14470857015112415, 0.13264372770208865, 0.17817894055042416, 0.10840393035323359, 0.2752019843319431, 0.08701688930159435, 0.12020412294077687, 0.1431719830725342, 0.11438871311838739, 0.14790244720643386, 0.13325374340638518, 0.14470577967585996, 0.10374823759775609, 0.17358623386826366, 0.16050974023528397, 0.1527653550147079, 0.07381316187093034, 0.1489238947397098, 0.18922830233350396, 0.19318228703923523, 0.16291924141114578, 0.25998855067882687, 0.13095063652144745, 0.07398416011710651, 0.15316710923798382, 0.11426654818933457, 0.08519989656633697, 0.17074934468837455, 0.2098777747596614, 0.0882021956203971, 0.22496584482723847, 0.18650877638719976, 0.07050230749882758, 0.11395264198654331, 0.14692066004499793, 0.11372409760951996], [0.032113609413499944, 0.08287943826871924, 0.0657080854580272, 0.02477015648764791, 0.04431030924024526, 0.09318105658167042, 0.029776423107250594, 0.04336341415182687, 0.04676045413361862, 0.030037510659894906, 0.04385562504467089, 0.06905218804604374, 0.025800005132623482, 0.05599231109954417, 0.058193747463519685, 0.024956702727649827, 0.009864668663794873, 0.03136729457764886, 0.034946112500620075, 0.015170171081990702, 0.0270116799583775, 0.029090418902342208, 0.03949649821151979, 0.035903753887396306, 0.03420567176362965, 0.004314152683946304, 0.03073160427447874, 0.03146399641991593, 0.07021607598289847, 0.050028853947878815, 0.07725222225417383, 0.07492235352401622, 0.02452043492667144, 0.02838181815604912, 0.04258853034116328, 0.054656760694342665, 0.08173372552846558, 0.040826230178936385, 0.03780990453378763, 0.07524062355514616, 0.030559698752767872, 0.027073955425294116, 0.03594521767809056, 0.019313595475978218, 0.06595251179533079, 0.002651039631018648, 0.026608489679347258, 0.018269551401317585, 0.04366326407762244, 0.03448121264227666, 0.0261256725207204, 0.012435345761332428, 0.057583995221648365, 0.06797765468945727, 0.051876749712391756, 0.06101656923419796, 0.022098111294326372, 0.05401235386671033, 0.03237759134208318, 0.024697220069356263, 0.021721098419220652, 0.028145069336460438, 0.031647318028262816, 0.044968924485147, 0.03706739691551775, 0.022474116703961045, 0.021886547256144695, 0.05088981575681828, 0.03190100265783258, 0.0920500754727982, 0.02277439707540907, 0.052670573131763376, 0.009889351567835547, 0.027125926171720494, 0.009272856914321892, 0.060278466262388974, 0.06880598055431619, 0.08669048533192836, 0.04812083308934234, 0.008318482832692098, 0.03747177092009224, 0.14647364965640008, 0.039425385621143505, 0.031085013142728712, 0.055348152891383506, 0.05427245807368308, 0.06397970515536144, 0.07564899773569778, 0.05113878403790295, 0.026116878070752136, 0.08320299981278367, 0.009999450103350682, 0.02123785081494134, 0.034815357212210074, 0.022958817062317394, 0.04111300717340782, 0.055344215797958896, 0.03980906854849309, 0.0358877754479181, 0.01144601281339419, 0.016175017699424643, 0.05815447300847154, 0.028367155173327774, 0.016692222270648926, 0.0745909549004864, 0.01090814314011368, 0.048861563263926655, 0.009881554378807778, 0.02683356637135148, 0.10604069466353394, 0.07603291072882712, 0.06702290396788158, 0.08377636826480739, 0.014284614499047166, 0.06540845075505786, 0.12252864820766263, 0.05774002434918657, 0.0732705183327198, 0.07606349463458173, 0.0646197258902248, 0.02776802306470927, 0.058056613415828906, 0.017664422739471775, 0.03995724575361237, 0.021084541658638045, 0.009364648522023344, 0.06651894116657786, 0.03235965734347701, 0.08082482469035313, 0.12411547868396156, 0.01702520723483758, 0.05333778615749907, 0.0805715296883136, 0.018404423753963783, 0.03485329951217864, 0.0399522585212253, 0.057744232326513156, 0.060497047306853347, 0.031169285866781138, 0.04227321405778639, 0.043402117153164, 0.001969547915905423, 0.033546414560987614, 0.026792787211888935, 0.04497657973843161, 0.09062515193363652, 0.04915513090963941, 0.021943327119515743, 0.12657595798373222, 0.04253158906067256, 0.03994982056610752, 0.047984519114834256, 0.02185172383178724, 0.008175779894372681, 0.02343391031899955, 0.04399986515636556, 0.045421226386679336, 0.020638407004298642, 0.02535307823563926, 0.042567149066599086, 0.0626476836623624, 0.02126735675119562, 0.04034117730043363, 0.02298457515280461, 0.046676914280396886, 0.015808515490789432, 0.05324208250385709, 0.038587975868722424, 0.05435966042568907, 0.075586004240904, 0.03972080863604788, 0.020347177123767324, 0.06759391981177032, 0.04064737629960291, 0.04140143915719818, 0.05829776688187849, 0.05083075935544912, 0.03991763362137135, 0.01857155170000624, 0.006740165717928903, 0.07148318181862123, 0.025693822353787255, 0.06540223155752756, 0.08308876102091745, 0.032634437520755455, 0.03334885113872588, 0.033699720006552525, 0.022740885397070087, 0.05273138842312619, 0.0338065781397745, 0.038436670511146076, 0.04163918616541196, 0.05336641079338733, 0.012991537205380155, 0.04207076730381232, 0.02722717181313783, 0.03360245413205121, 0.009681389728939394, 0.03007602812431287, 0.027369361741875764, 0.031018149347801227, 0.0434955795208225, 0.019810253688774537, 0.0719293906877283, 0.024359023373108357, 0.06738439667969942, 0.05161578090337571, 0.14108245144598186, 0.05116602827911265, 0.04693440241680946, 0.022762402113585267, 0.05724203583667986, 0.00388072638088488, 0.021011705430282746, 0.05090638420369942, 0.056928489575511776, 0.05500363309693057, 0.042705878731794655, 0.013307963927218225, 0.018326895296922885, 0.06845022464403883, 0.03717987310665194, 0.062083005759632215, 0.06385889835655689, 0.007457398105543689, 0.02288339444930898, 0.025947527392418124, 0.022502758038172033, 0.09857724202447571, 0.05842706385010388, 0.05105293610540684, 0.060617564668064006, 0.030650496810267214, 0.02478639467881294, 0.036790701997233555, 0.04891148011665791, 0.025355046782351565, 0.01821018144255504, 0.016980260916170664, 0.04391372778627556, 0.04730651155114174, 0.036613276752177626, 0.030871842354827095, 0.01299500860113767, 0.010290791306033498, 0.07849318222724833, 0.038057626006775536, 0.0135115610100911, 0.04204068434773944, 0.01889934534119675, 0.017778984365577344, 0.0519153154164087, 0.05753543649916537, 0.040487866499461234, 0.03204523534805048, 0.05486587564519141, 0.026039186341222376, 0.02932853141828673, 0.04616751895810012, 0.06939220300409943, 0.045217610750114545, 0.08000056579476222, 0.03715056569490116, 0.06691967864753678, 0.06103847743361257, 0.07851674541598186, 0.043644584220601246, 0.09402296374901198, 0.02529140761907911, 0.09416981993126683, 0.09083928380277939, 0.05721544468542561, 0.007836368858988862, 0.06786533806007355, 0.05309226144163404, 0.024877780888346024, 0.03172749224177096, 0.11209817821509205, 0.019720934360520914, 0.06136001291451976, 0.1008422247832641, 0.03786234468861949, 0.06961827602935955, 0.018339335547352675, 0.03906816396920476, 0.04896245081909001, 0.07891275541624054, 0.0975126757111866, 0.05330078267434146, 0.06942364037968218, 0.0458545775472885, 0.09164216884528287, 0.03463464054220822, 0.05328448140062392, 0.06712176545988768, 0.06512319145258516, 0.04353145865024999, 0.03147332521621138, 0.02906417470512679, 0.03954757281462662, 0.030718837479071226, 0.009705195971037028, 0.03134582795610186, 0.06399926074664108, 0.023238688372657634, 0.04065293127496261, 0.020006577724416275, 0.04402595164719969, 0.02660640238900669, 0.03405016956094187, 0.05260294121399056, 0.023515091997978743, 0.07002049780567177, 0.03903007323970087, 0.04443260404514149, 0.061898199855932035, 0.004499869573919568, 0.05483483531861566, 0.04801550378033426, 0.013799047683278332, 0.030453874060185626, 0.0806002359604463, 0.05775308243755717, 0.04061208346683998, 0.02924116579379188, 0.04212719279166777, 0.07571300055133179, 0.005838822262376198, 0.013331646787264617, 0.04561661902698688, 0.06963029140024446, 0.04100785969058052, 0.031652297839173116, 0.05880571872694418, 0.0193668928113766, 0.04419271965161897, 0.13835832418408245, 0.03278333831985947, 0.03003174417244736, 0.035910488877561875, 0.03543023769452702, 0.05120621186506469, 0.038111413159640506, 0.022774770004616585, 0.04517918234341778, 0.0802123524772469, 0.044674726013909094, 0.037251716712489724, 0.04398987213789951, 0.04208287915389519, 0.027121855491714086, 0.047952959284884855, 0.09512385819107294, 0.11417601359426044, 0.18421496119117364, 0.0944486893422436, 0.18865668534999713, 0.19347973982803524, 0.15968221588991582, 0.16072227648692206, 0.12260216535651125, 0.16700405190931633, 0.08224820456234738, 0.1163269134121947, 0.07906381215434521, 0.18188357847975567, 0.13163185387384146, 0.12042513451888226, 0.10808928942424245, 0.060833755997009575, 0.1359873404726386, 0.08749210872338153, 0.07971945509780198, 0.09473079451709054, 0.14084431109949946, 0.1311776298098266, 0.15798486478161067, 0.11432178624090739, 0.10353499630582519, 0.11415217581088655, 0.13115064532030374, 0.21312219207175076, 0.18904554104665294, 0.18704405782045797, 0.10645569622283801, 0.12681265856372193, 0.16851375839905813, 0.20955966057954356, 0.1744478673208505, 0.13594995107268915, 0.13363853213377297, 0.15519677923293784, 0.13696237409021705, 0.12141444705775939, 0.12311246609897353, 0.15067407191963866, 0.10033242127974518, 0.14840639516478404, 0.2019980366458185, 0.13367670821025968, 0.13018597208429128, 0.10386714449850842, 0.13519667118089274, 0.0948710752709303, 0.17263376154005527, 0.20809096517041326, 0.1301353279268369, 0.25427534943446517, 0.09094771157833748, 0.12800932716345415, 0.1293377863476053, 0.11154823936522007, 0.07711269849096425, 0.10205856771790422, 0.0984187563881278, 0.16068334341980517, 0.10480970915523358, 0.1593917392892763, 0.10550080449320376, 0.14741331251570955, 0.18817811884218827, 0.22578829288249835, 0.12828135397285223, 0.10608744996716268, 0.1613072818145156, 0.09645540470955893, 0.06659501872491091, 0.20712100784294307, 0.164851660374552, 0.24775832804152742, 0.10599923087283969, 0.16064062539953738, 0.1427148943184875, 0.2641851583030075, 0.2060834111762233, 0.12028066063066944, 0.20084329938981682, 0.11409168335376307, 0.19693419977556914, 0.19779127644142136, 0.21877427003346384, 0.16067538759671152, 0.18557557021267712, 0.2468949876492843, 0.0788401065801736, 0.1830614113714546, 0.09093569620745257, 0.15797794796526432, 0.12596474000019953, 0.1759253052296117, 0.18104051356203854, 0.10004940326325595, 0.12861036288086325, 0.15322064777137712, 0.0497528937557945, 0.1954715751344338, 0.13165106065571308, 0.11634381953626871, 0.11591450194828212, 0.07956478410051204, 0.13389378640567884, 0.21745084261056036, 0.13690977066289634, 0.2913915499811992, 0.21481463016243652, 0.17723758559441194, 0.1628953145700507, 0.2685030031716451, 0.12210610642796382, 0.2255874380352907, 0.14700063387863338, 0.12438372054020874, 0.1565504417521879, 0.2692319406196475, 0.09149747231276706, 0.19275642785942182, 0.1327614174806513, 0.125828169984743, 0.20267511281417683, 0.17433963250368834, 0.14959071442717686, 0.22486114263301715, 0.13134062028257176, 0.17989806627156213, 0.21763698809081689, 0.09137728891801089, 0.16556544316699728, 0.19170201412634924, 0.22110594960395247, 0.14706745685543865, 0.1538516959408298, 0.10443397462950088, 0.09301169848185964, 0.1789486812776886, 0.09299747893237509, 0.13085359329124913, 0.15955588751239702, 0.330058007966727, 0.24075004941551015, 0.1144231265061535, 0.2008238254347816, 0.0705165567342192, 0.23748483712552115, 0.11294527299469337, 0.1655912699061446, 0.11895814604940824, 0.10922589601250365, 0.14132014650385827, 0.15301829378586262, 0.10572267696261406, 0.10891498066484928, 0.13587094203103334, 0.19725212099729106, 0.1225174566206988, 0.08054607402300462, 0.1609755418030545, 0.12098051331122406, 0.12938477913849056, 0.09186726965708658, 0.11635620598099194, 0.16261398122878745, 0.18312753672944382, 0.11094080633483827, 0.07439674227498472, 0.14678086910862476, 0.1226510877313558, 0.07767906106892042, 0.16838348179589957], [0.060554723313543946, 0.0341393979761051, 0.046106477311695926, 0.021502799390873406, 0.019643127598101273, 0.01748602713632863, 0.02854649515938945, 0.012988140024390304, 0.013695589514099993, 0.07561958642327227, 0.01272948949917918, 0.018177530655520968, 0.0218510020931717, 0.05830233851156663, 0.013874224459868856, 0.06482970915385522, 0.06787618083762936, 0.061234248569235206, 0.09127979297772981, 0.08380909697734751, 0.033520743672852404, 0.03598877061449457, 0.05843584716785699, 0.06614038647967391, 0.058059285147464834, 0.002012840404859162, 0.051459822279866785, 0.024005211889743805, 0.024325971826328896, 0.021717536110372748, 0.00787872972068726, 0.057192375024897046, 0.05803124680824112, 0.04230651793477591, 0.02367437358770985, 0.053128671206650324, 0.03621031282818876, 0.058083397525479086, 0.05151017328898888, 0.08865437877830118, 0.035543459744076245, 0.016838900337461382, 0.03661407085019164, 0.07795400451868773, 0.028533316472021397, 0.03638076188508421, 0.04167272381891962, 0.03226394997909665, 0.04053845499583986, 0.025884734277497046, 0.06690058318781666, 0.01739242004987318, 0.01562265202665003, 0.028120897586632054, 0.04185434961982537, 0.0563748325657798, 0.04912702206638642, 0.04013481200672686, 0.052393499718164094, 0.056795496711856686, 0.015181493472482543, 0.026638678391464055, 0.04798235575435683, 0.07491931814001873, 0.012914709150209092, 0.023786916572134942, 0.04545462674286682, 0.0128130775919999, 0.07693544393987395, 0.025218450791726355, 0.09368181330501102, 0.07714539009612054, 0.05290205641358625, 0.02360797363508027, 0.02661623955646064, 0.0042080306684511015, 0.017102995443565305, 0.04569133845507167, 0.011739571182260988, 0.02207517893111799, 0.029641684341186192, 0.017199769645230845, 0.06885339636937715, 0.10565631411736831, 0.033074887323891744, 0.013815641177643556, 0.029968331364216283, 0.05351792024157476, 0.05137719155754894, 0.046724767962587066, 0.043483645786182024, 0.0045375688205240294, 0.08892985657439567, 0.013132392195984721, 0.1079732397920452, 0.07842370978323743, 0.0746255241392646, 0.013835990866937209, 0.03620917363150511, 0.02324177014088491, 0.054212774557527155, 0.034713890781858936, 0.048556432957411744, 0.06417891985620372, 0.0549045415391447, 0.043260879028821364, 0.02950077276182128, 0.06686385429929942, 0.031639295411878265, 0.032497051142854616, 0.0678821699693799, 0.1014534872956574, 0.028574526077136397, 0.03109391705947928, 0.0589846505317837, 0.004234840753269964, 0.0171254602537374, 0.03872813416819554, 0.029213492962298915, 0.050451529314159416, 0.04064530941832345, 0.047223283399944194, 0.059462241115397774, 0.05120614878251217, 0.0221326972314273, 0.0418025328690419, 0.04057735095557291, 0.0458129245089367, 0.013317752855073195, 0.00628955823231081, 0.024407704549957998, 0.045010978283244185, 0.04732567380415276, 0.031446927023353055, 0.03266393418016378, 0.040437938514514826, 0.040711976544116624, 0.01272216635697987, 0.03948123594454955, 0.02887878436013125, 0.027541796043806244, 0.03968075863667764, 0.024954864056780934, 0.02327209986106027, 0.08189668631530367, 0.04958824458299205, 0.031052560880198143, 0.03231143629818689, 0.07508613067329861, 0.02084577234199969, 0.04221865878207609, 0.02620214898342965, 0.016677763378538657, 0.07449868367984891, 0.009385967641719617, 0.033098446801886894, 0.010496180675545475, 0.05483707289386075, 0.023504581331508234, 0.012106501981179463, 0.03542606682458427, 0.030038360418984666, 0.027759505064750556, 0.04326729860622436, 0.018861443859350402, 0.027056051112595014, 0.010518091658013873, 0.0756197125883773, 0.07650902814930305, 0.015000072689872468, 0.0903678048052825, 0.040650274386280216, 0.034393865571473725, 0.026797505415743217, 0.0767115676717367, 0.07219622988486663, 0.023315851321967784, 0.03200261009624228, 0.07149022480007261, 0.054293965513352305, 0.004952141789544839, 0.040557238753535785, 0.011195075057912618, 0.035892083615181036, 0.030901459613232873, 0.04263278089638334, 0.014427691294258693, 0.026794913464982528, 0.039701353234704584, 0.07126574739231728, 0.010449694400449516, 0.07193775469204411, 0.014525796723319218, 0.12435165233910084, 0.08211812091758475, 0.058913860775646754, 0.03072060750128003, 0.033923841183423065, 0.07020063188974746, 0.039020751864882186, 0.07611221662955359, 0.04934035983751528, 0.02896355803386541, 0.013472317168634618, 0.05727519870561082, 0.06413799783331342, 0.015725678822491318, 0.036313059463282116, 0.029788510837533977, 0.01367847558867652, 0.010001494720199844, 0.07683624105993658, 0.05704944109311327, 0.01498424360761419, 0.053367757791420445, 0.09927462335326709, 0.028700954644591548, 0.07732009908067994, 0.021633460055454634, 0.0878382167138625, 0.03123150010651443, 0.005977833943688893, 0.0425435970100807, 0.06709165652864613, 0.018087808712152764, 0.05079967078927439, 0.0685638994036708, 0.036925175445503555, 0.0714324411819689, 0.03756023863388691, 0.02353752341150539, 0.1176124467747286, 0.029240737203508615, 0.015617870740243234, 0.03764784174563829, 0.046827841142658144, 0.048051683479570784, 0.03464120854914654, 0.06917185193742625, 0.019753616688831244, 0.039981109512154944, 0.01688853146333713, 0.06998673008638434, 0.008009971115825465, 0.029901892448833678, 0.024705240830371622, 0.030729763748240657, 0.061328853844315745, 0.024624882935313508, 0.01637435856537195, 0.03517283119435888, 0.0015838599142625753, 0.04047973627166357, 0.029344739923544694, 0.03147492083371617, 0.03132697369437665, 0.026019172473752405, 0.03377133725734893, 0.14448415953665972, 0.03809404319326859, 0.04013053352537099, 0.023187391125247814, 0.01206629334774334, 0.04241067093971651, 0.014071564310143003, 0.03839073899143841, 0.045711528582614847, 0.014340372981678229, 0.07452912657754496, 0.013797723877360113, 0.028098017173761036, 0.03118947599432431, 0.018506604501453694, 0.031470727699343115, 0.020495044482231606, 0.043595880779321305, 0.03393360042537097, 0.04675752636103425, 0.042686356537160464, 0.02459308747347677, 0.07213730335934088, 0.0646955733827781, 0.04472171509405598, 0.03012911394762341, 0.0498558519029757, 0.01326132643953315, 0.04536429623840377, 0.0670048178290017, 0.0589548829884734, 0.03333036424010061, 0.0223564733096282, 0.02436778442643117, 0.014666441129520535, 0.03409757053304929, 0.03969465535192285, 0.023718605589237995, 0.021337042562663555, 0.04925897221255582, 0.04713195841759443, 0.09625888400478289, 0.04396660951897502, 0.024365203607885633, 0.011432482533564325, 0.025852966646198183, 0.042096493853023276, 0.004028411449326086, 0.029298197987372987, 0.09062111465027556, 0.056914006563602015, 0.007126014788809698, 0.01397006355546182, 0.010709730886446778, 0.03854454538668506, 0.03550188834196888, 0.08137667828123085, 0.059154290647711605, 0.019023165259568486, 0.05877195842913352, 0.03029011917533353, 0.0345181419106666, 0.03770561423152685, 0.024517280799045693, 0.04160291369771585, 0.05094656407891307, 0.055040785009623505, 0.026129989964829292, 0.0454125581018161, 0.07907602790510282, 0.04139377277169842, 0.02418724587187171, 0.03695853869430721, 0.02925365428382065, 0.043908217339776456, 0.04139061493333429, 0.040943697313196026, 0.03676512758829631, 0.0505339077062672, 0.01710015487333294, 0.045508187540690415, 0.01130108435972943, 0.08073890625382774, 0.02395588504441548, 0.0362790468352614, 0.007895745311543578, 0.033094465179601684, 0.04128281427256297, 0.039183007611427456, 0.09295666823163629, 0.024075728906609584, 0.09063728604814969, 0.03211340161215048, 0.024962506322481204, 0.0993632803147193, 0.08977787161711603, 0.2518034039530903, 0.10816882539074868, 0.11401340903830715, 0.11820157102192752, 0.07008789223618805, 0.10836558358278126, 0.14352272206451744, 0.14964989328291267, 0.16874746070243418, 0.13997072906931862, 0.10790307715069503, 0.1946887726080604, 0.08888418480637483, 0.2147208375390619, 0.13042423117440194, 0.21357423422159627, 0.12645219743717462, 0.14961869339458644, 0.1599826372694224, 0.18619060283526778, 0.12262552816537209, 0.07449968557921238, 0.16578105191001669, 0.1966085156891495, 0.13441407645586878, 0.13941443001385778, 0.122784807899734, 0.22333053726470098, 0.07221695806947537, 0.14617307984735817, 0.22742210130672902, 0.16422264568973333, 0.09716202577692457, 0.1754936424549669, 0.09359231029520743, 0.14225761260604486, 0.09365597172291018, 0.2741064556175843, 0.09071269567357376, 0.1974765316117555, 0.11168630851898342, 0.1250286542926915, 0.1301836417405866, 0.1321265843580477, 0.12889779667602852, 0.2170245529850945, 0.12103849730920047, 0.12756743759382516, 0.12102908687666059, 0.09625727354432456, 0.12550031882710755, 0.10752157613751478, 0.09384428427438252, 0.1577377296052873, 0.07592026013298891, 0.08982629675301723, 0.11741484253434464, 0.22519168036524206, 0.23052038974128664, 0.0878080929396674, 0.14543783414410427, 0.12627219693968073, 0.09112189363804646, 0.10346791357733309, 0.24603523925179616, 0.14179164776578546, 0.11820471030659974, 0.12514408794231713, 0.17432584339985624, 0.13985283148940653, 0.1663585615460761, 0.19075613206950948, 0.10699969789129682, 0.13524188281735405, 0.10157263168366626, 0.13522579305572435, 0.11347253181156702, 0.16391524812206626, 0.185582947160583, 0.10999464226188138, 0.23597845545737073, 0.25807511585298926, 0.11117513946373947, 0.11826023779576644, 0.06658977916231379, 0.12203379897982813, 0.1851274466025643, 0.1175666785275098, 0.12333891019807197, 0.304455011500977, 0.28036902425810695, 0.08614407910499722, 0.23720703640719876, 0.14349726639920846, 0.14901510468916968, 0.11510019525303505, 0.23032380966469646, 0.09647429236792959, 0.15707757440395653, 0.15627967659384012, 0.19326852459926158, 0.14804004138568416, 0.21226759417913854, 0.20188582391710952, 0.1447771000675857, 0.13544303452363238, 0.14875465538352728, 0.15926217514788732, 0.17617767996853217, 0.1947613398078829, 0.20268020394723862, 0.10941733300569467, 0.1843812913284637, 0.17358243407215923, 0.09875014016870409, 0.19331011455506086, 0.12735332798911259, 0.10039348519057967, 0.1532759823021479, 0.16195878357393667, 0.14238241215934977, 0.2591596607817337, 0.19891358184395358, 0.17036280449246988, 0.22331057349219918, 0.21960354584734887, 0.11108050079201348, 0.0659351158537902, 0.12589321180712432, 0.16233503760304302, 0.19881352549418807, 0.19295812875498086, 0.1584014025866054, 0.20491678471444175, 0.14114114048425108, 0.13185556686948985, 0.1705394801683724, 0.07588275941088796, 0.19213196996133775, 0.11938502197153866, 0.11794486956205219, 0.0735517923021689, 0.15195982792647555, 0.11334780647302978, 0.12894137558760121, 0.14909644407453015, 0.13609489251393825, 0.05206072441069409, 0.0841700033925008, 0.1561140886042267, 0.09713899693451822, 0.18384638096904382, 0.07056861839373596, 0.09623089019441977, 0.13126642035786062, 0.19761436327826232, 0.09932961649610661, 0.08666474765050225, 0.19017321959836408, 0.15298914222512394, 0.13458515633828938, 0.127570970216766, 0.13367430365178734, 0.0596299293829361, 0.11085840567830019, 0.13408046623226255, 0.20062742347363383, 0.09900189150357619, 0.22412766324123368, 0.17686870851321146, 0.10634374324581586, 0.19329892296809703, 0.18279184849234298, 0.12517982977442443], [0.04353609336249065, 0.023725479732092936, 0.04772744287038222, 0.06502072312287055, 0.038038404381950386, 0.05189728122786619, 0.051460968898027204, 0.02164231573260622, 0.03909572733391542, 0.017535289043735247, 0.05895807422348298, 0.060039335148758255, 0.08437653566943482, 0.047260754436138086, 0.03171502787154168, 0.0627030998293776, 0.07644317738595419, 0.0730414321878925, 0.06622312852414325, 0.04379131423775107, 0.04757617833092809, 0.07601296922075562, 0.05619545918307267, 0.018687220981519204, 0.052432002339628525, 0.019280586602690164, 0.0466777083784109, 0.07852152484701946, 0.022692833190376405, 0.06091944065701682, 0.04704595834482461, 0.012510606029536575, 0.05871757755812723, 0.004714440237876261, 0.03146083116007503, 0.0743279822927434, 0.01830077169870492, 0.015108044044609414, 0.03814677649643272, 0.05307014915160835, 0.0542854456580244, 0.024704097922949586, 0.03943827672628686, 0.08020694222068414, 0.044791699619963765, 0.08878970198566094, 0.04547345874016173, 0.0962346231972333, 0.05762627537478693, 0.029781898301735055, 0.030572806936106645, 0.021965706582705025, 0.059703071747208014, 0.06344696186715737, 0.06883456808282062, 0.024926508449425455, 0.032931222376646474, 0.012748127610393567, 0.027047881922044326, 0.05985434370813891, 0.01277055531318183, 0.030034315714146942, 0.09048724605236202, 0.04579009233566467, 0.01751724186760839, 0.021336478530429304, 0.027992953182547353, 0.008982989802461816, 0.011487418159958906, 0.06676825825707056, 0.08060440683038905, 0.009911713405017508, 0.027021852947655134, 0.03609228537243325, 0.05420285575382877, 0.03851949790259823, 0.07738733766018413, 0.04757393333420623, 0.02606664209451992, 0.03749778690689709, 0.02858965290215565, 0.018652061735338066, 0.01204288879307569, 0.06824721014709212, 0.005805994751426624, 0.012647230778384255, 0.09592690650606528, 0.04054156830534339, 0.017123374818766024, 0.08695104595972225, 0.056901508796727285, 0.03937516448786482, 0.0382820514641935, 0.04178860646788962, 0.010986692050209967, 0.03545871761161834, 0.02569435484474525, 0.0698207042296417, 0.02936911205324577, 0.03176915641233791, 0.07258895217091776, 0.0359950269194087, 0.04485321253014263, 0.09591234556864947, 0.010384410452388693, 0.03290288346761372, 0.012378243063722039, 0.06165178827359341, 0.0979193281091284, 0.027240799499850255, 0.03191961572156288, 0.04648138063203078, 0.05107931574457325, 0.04112338610866573, 0.03733356817974709, 0.0817740686761681, 0.04127962303755339, 0.024653296059113927, 0.040153187583200634, 0.026985784570570104, 0.006400673046300653, 0.03825587591563817, 0.021473694214364514, 0.021881235334149096, 0.03544724400853738, 0.01023741975586745, 0.062420311878668144, 0.04299623287806753, 0.04784558535902761, 0.04152993831667118, 0.031068424286786467, 0.06347184607875533, 0.03678060878883116, 0.04048125396366231, 0.01448767166948528, 0.042844986892305315, 0.0875915119831916, 0.04832287537283264, 0.020931431026838254, 0.07090121187502518, 0.06887623967486434, 0.0526807702408405, 0.05481354681251105, 0.04617790902557317, 0.03603503238991834, 0.023850047364248894, 0.02002765471843304, 0.06638227467192337, 0.03879403317114338, 0.024140685382008087, 0.02080594869767083, 0.07911982203950174, 0.026927500002784654, 0.026415509018988814, 0.016559112518734764, 0.052258888972573914, 0.010766766790766269, 0.12215081340400502, 0.017762219249561895, 0.0069557243659801316, 0.02690389042982133, 0.07241832499857992, 0.04054532357258722, 0.01314007899054559, 0.018085099873133004, 0.06787923848605715, 0.05473382530908566, 0.03269004293542821, 0.027884139490197413, 0.010030028442997718, 0.04182489006780088, 0.0337998950999463, 0.059637707090587355, 0.08269000507425517, 0.03814883224549703, 0.021205704688327387, 0.01828034593927441, 0.011609336324909236, 0.036413253110367805, 0.029519549098040443, 0.027384110071579926, 0.03174896257405635, 0.06359652688843198, 0.04989702254533768, 0.0569219104363583, 0.0620246692415094, 0.04103595369087998, 0.03733516750799026, 0.04505983757553622, 0.016631891230645124, 0.03513286283123307, 0.05345070763723925, 0.058671011502156034, 0.05114548192068469, 0.0042127270717173815, 0.06303026078967378, 0.05670463557180483, 0.139768761000596, 0.09591757770976983, 0.019936068129027262, 0.041216818790417165, 0.03197326557710767, 0.023477537470171228, 0.06035158636223059, 0.043342107092030346, 0.06830200291005895, 0.021387183915067, 0.033953734891838394, 0.050522174351499416, 0.03636924746388104, 0.03823911079962272, 0.049697136200848036, 0.03822263883193955, 0.0363650951476302, 0.01605171728442656, 0.03171388125338126, 0.03076364278967958, 0.05017063012928702, 0.017729466417222284, 0.0706821669882629, 0.023193465603981167, 0.06787262595025823, 0.03635614113591146, 0.059900238120462745, 0.06149325068690814, 0.031235611604643054, 0.011934666963497875, 0.021465183635882568, 0.018470786599209532, 0.02760265771939885, 0.021738008254033048, 0.053553973775706254, 0.031186900741886348, 0.021196899106143974, 0.020147389113844838, 0.10470556357176974, 0.017493812265456654, 0.04410643385199364, 0.10255006985971704, 0.04381767903396394, 0.017353820949210785, 0.05115506675792858, 0.04367144996649586, 0.08365170229808427, 0.03721319924807176, 0.055810243720770814, 0.03045933997782413, 0.028232371878402773, 0.03781784180318937, 0.03200750827090815, 0.07427699674735777, 0.08120750571833923, 0.048526116224820726, 0.03662004884972703, 0.021926389454165474, 0.00912122501176782, 0.06507798723760061, 0.016346706142940093, 0.009959720155165996, 0.043485048445290886, 0.023760902440699283, 0.011910182583960705, 0.044850110352854244, 0.061454525421140715, 0.040921651816461235, 0.004790080856764689, 0.03414379149035085, 0.045748892007395625, 0.014808369451202452, 0.017532416932226624, 0.020430826443771366, 0.03203561711416114, 0.035366194060770795, 0.04300773987779394, 0.024652824795339257, 0.04712765396106988, 0.014707275950058829, 0.003128085663774982, 0.024668209516676143, 0.05199679952056613, 0.046000554284546524, 0.016448961105197668, 0.031519843032583594, 0.017529630167700816, 0.04942325031151995, 0.04113963543204591, 0.01953147519088816, 0.05456405531731434, 0.06530824597575702, 0.02305999591044383, 0.015747434881632216, 0.039644193020649254, 0.07269108653417788, 0.01987280931643909, 0.021253248523862567, 0.005127151343913283, 0.02701700486795744, 0.027584105882851873, 0.06742850251612253, 0.016003698474378325, 0.03259698503825348, 0.0412273016263498, 0.05928391416091472, 0.020498052035691217, 0.025706672640808392, 0.04873158351983875, 0.01917276924359612, 0.02901642677898053, 0.013210966153565096, 0.05147499919985421, 0.009658114122430561, 0.014304287906270474, 0.038961283571552485, 0.032415114328614436, 0.02184309450967703, 0.015948603286233265, 0.0313286212622188, 0.06136806892754976, 0.0673069609911181, 0.052274106710683554, 0.019832959696941543, 0.03217266952560749, 0.06465143786044791, 0.03833570131973829, 0.028867132641607895, 0.026174941849603783, 0.08755329137784429, 0.07973555228090845, 0.04393425188027322, 0.019189812664990313, 0.028820115730923135, 0.03345256256579887, 0.05023141573474277, 0.08514324101270176, 0.042263911236659624, 0.016150085248227697, 0.02975411971419817, 0.03280738390458282, 0.012607654825842474, 0.03881354794430081, 0.015458495454367949, 0.10657533042831346, 0.027517041708051693, 0.0913918275909964, 0.02721072767599253, 0.05784555403806735, 0.07342348239035346, 0.00572574539546622, 0.04162737859587651, 0.07252545401570387, 0.00677093191370659, 0.01845298433181597, 0.07184304180555046, 0.10305299365427345, 0.19278709340142086, 0.2100280745071359, 0.14456312404945493, 0.21494930027984083, 0.19777030334807932, 0.13210240518674254, 0.151072634907905, 0.15075861738296226, 0.14795206720009446, 0.17308507638517767, 0.1599206679384224, 0.13594784337328747, 0.18232560163596645, 0.12155892836744897, 0.2632483601337299, 0.1779556876863353, 0.1741702892468311, 0.16132541990373284, 0.11873447016114369, 0.2738723822403699, 0.1609795494005084, 0.0961208890657872, 0.12815124064218253, 0.12782224657712504, 0.1367000545724295, 0.1671354120480828, 0.1587425678735599, 0.1795161422342062, 0.07823210209608078, 0.16280296171316877, 0.11040162862627767, 0.2037964088958688, 0.114075764286099, 0.1702680322341621, 0.1775666984030977, 0.10656951199052855, 0.14862667943816632, 0.13413752254564315, 0.1160926470765844, 0.11504326510475948, 0.14311139413621277, 0.1338428008602932, 0.17187709745485336, 0.1622466478147544, 0.11414552616770379, 0.14125557965599, 0.14671792014269158, 0.14081320026889443, 0.11501762390253134, 0.10545656507019885, 0.1248130900785327, 0.12435931130312383, 0.15185147436568514, 0.11403161392081529, 0.13066376675851643, 0.09509557494311593, 0.20898566872347146, 0.19665672560222447, 0.18123232905054465, 0.10176163443247788, 0.24477704660966992, 0.12114848359487951, 0.12482959544286132, 0.08977052435511723, 0.09789503761567175, 0.23424571874784306, 0.07288720647920854, 0.1345722281257622, 0.11354202652000822, 0.13612738373922184, 0.17893368989462033, 0.19946465617977083, 0.13436312059639022, 0.11333116752211936, 0.12217138573760167, 0.19707942323293537, 0.07934899724205025, 0.15790919540449977, 0.178633832547348, 0.13994028617162257, 0.10650334210367873, 0.12478594231652096, 0.08643649271107279, 0.07818594051059335, 0.21439803298562765, 0.16388544347137213, 0.13403903954895213, 0.1368703180924058, 0.16932918573729694, 0.24041036842390895, 0.1708697061985731, 0.18212937779026106, 0.10700875209295191, 0.13738317182287574, 0.11857176170451567, 0.15933839371427894, 0.13987240934511647, 0.12776942050550133, 0.12167940119979903, 0.07795253506628796, 0.09329261622042395, 0.26135813968721777, 0.06169075844809413, 0.15493586979573593, 0.10732224269304425, 0.19328028021845967, 0.15291630785213783, 0.16358095512259752, 0.20890003972453997, 0.2401761763030663, 0.17931971058715135, 0.069885397242615, 0.11306188665912487, 0.19016510050278157, 0.15725165256299078, 0.13866570690879598, 0.14492259069811553, 0.12700159451924264, 0.12512850284110755, 0.10285556010785513, 0.20070773869520053, 0.09828914771787822, 0.12112566997529939, 0.10619865337503143, 0.16843621880980209, 0.09574913987307809, 0.16762077662860975, 0.10779810778331012, 0.08418510609772056, 0.17046864959411323, 0.12081131106242537, 0.15002801752416417, 0.10697203062591143, 0.0795155722880736, 0.19252416532253847, 0.12309059500694275, 0.07835155076463707, 0.1990741232293658, 0.11874235919094644, 0.1521741453325376, 0.1583571854280308, 0.12909278855659068, 0.15634203184163198, 0.22745006543118507, 0.12911913479911163, 0.13687092665350065, 0.12228953564772382, 0.08214161731302738, 0.18728605733485892, 0.11710631690220907, 0.1431336288806051, 0.1513561501633376, 0.10149043882847764, 0.17266285372897983, 0.15492650389205664, 0.13926194835221395, 0.12351747092907317, 0.10621316236210987, 0.13421449810266495, 0.12431288996594958, 0.13854976859875023, 0.1473045433522202, 0.14455588068813086, 0.14874644723022357, 0.13926772226113826, 0.1921166223473847, 0.07981036076671444, 0.1614250458078459, 0.14797361916862428, 0.13173668965464458, 0.17840106535004452, 0.16179727739654481, 0.17003415181534365, 0.11495489758090116], [0.03286785038653761, 0.022038659699319396, 0.032701204836484976, 0.033315487889922224, 0.02511133105144836, 0.005966662765786168, 0.03300439813756384, 0.011601671794778667, 0.03720210414030589, 0.030340869088831823, 0.05498056714714039, 0.053555454360321164, 0.0553285008209059, 0.053358165532699786, 0.03517096098221373, 0.0034530074253780185, 0.07717311673332006, 0.03733871126314625, 0.037403255846584216, 0.040661770253791474, 0.016723644803278148, 0.013329504763532896, 0.06949280854314566, 0.017897607394843362, 0.023865003495302517, 0.05226107459748164, 0.012037095402774867, 0.08115375196211971, 0.04930774986860342, 0.059708593325922266, 0.03438675579673145, 0.07888047199230641, 0.0699871605320368, 0.04848697906709276, 0.021260955727484543, 0.06814822991145775, 0.04133840113354381, 0.04028469615150243, 0.04107316126464866, 0.021454895613715053, 0.0106954287730332, 0.06876859115436673, 0.0344791902898578, 0.05175039164896589, 0.04212887375615537, 0.0556974187202286, 0.019188888691132888, 0.015327262408391107, 0.036716387039632536, 0.03960781294154003, 0.0551983874902362, 0.06740574084687978, 0.01939753052283777, 0.06965749853407033, 0.02775405955617316, 0.020359893824206665, 0.028917869567521848, 0.07898864001617767, 0.06095582815760281, 0.017769021033018362, 0.04685708547185641, 0.030354656337294728, 0.018933851497422438, 0.06733662463375367, 0.052993500139564276, 0.0291784172077314, 0.024982303111755755, 0.01890613784780726, 0.0021030966945545515, 0.05544222382013686, 0.027115280063298997, 0.02205601667810697, 0.07937460133689456, 0.03795471609919332, 0.029143046449462418, 0.04507133344304748, 0.09943168406607583, 0.03608389168221038, 0.028106607533118222, 0.02418975989712635, 0.03420347871724516, 0.045489251642720774, 0.005498770196936675, 0.03469133691396564, 0.04408709719427861, 0.058371473278384656, 0.04739877535030246, 0.03392850929230917, 0.03575541340978816, 0.05983651732094586, 0.004375644721221761, 0.022403865004889667, 0.04858877946389839, 0.03237021810491569, 0.039880340700619854, 0.02933373016276164, 0.09203496534610167, 0.04171094442426693, 0.033504438688396476, 0.058056691341334954, 0.044225222009117715, 0.05363007359846961, 0.05609733241726644, 0.03927882629795931, 0.0294191680586664, 0.022591975321120117, 0.04352027077402454, 0.035800446930807084, 0.04512052299105562, 0.03360474365763366, 0.06459110125433654, 0.048681648113415577, 0.02500072692782851, 0.014196735864970833, 0.01593387351022102, 0.066829641291406, 0.018354681305936538, 0.03045304099941859, 0.051699205723707564, 0.03517212986480445, 0.0344083448726451, 0.06532347484608181, 0.023993532340682577, 0.03379564259375911, 0.01664720544795273, 0.0753123447066173, 0.03112258251348976, 0.02355550750507973, 0.07654298140550964, 0.04415277355292346, 0.030739617614017334, 0.035630665806820616, 0.05438717555080075, 0.020317287126090378, 0.07245751781738363, 0.09648452658439055, 0.02107199379679514, 0.028924754842591938, 0.019988332023785915, 0.042073197837453336, 0.010643402365531074, 0.020147073701082263, 0.02586549595434917, 0.051957859031972475, 0.070162797201192, 0.04975252639269456, 0.12508870888268575, 0.025776736947591417, 0.14299889939138666, 0.027382364169170614, 0.03075557564443443, 0.013974805879115593, 0.05180199688766152, 0.013498636508302297, 0.02605025361845037, 0.009079265837499406, 0.02339723338081967, 0.04137608739256393, 0.016656860789225902, 0.04422961181262508, 0.02792393344861921, 0.0432377425750019, 0.07903057135990821, 0.04941319792123977, 0.02156106540496694, 0.03064984928641934, 0.10907331787166186, 0.07350265470449813, 0.08333440448041074, 0.05749236966948956, 0.0455844135285588, 0.03522624356264714, 0.04841096088057384, 0.01201293107442325, 0.024958194444479886, 0.015629450099368114, 0.01817569755075965, 0.031499404285568744, 0.06590615725144744, 0.009908312513289275, 0.028491739503806457, 0.013719106318603735, 0.02339433900488075, 0.05922179640037939, 0.04785536315466743, 0.03962992523156572, 0.03775027296796907, 0.034106891907867976, 0.049704765478963964, 0.018837682146113366, 0.03788470559811685, 0.06134623494290281, 0.08264556527137756, 0.017197038541780785, 0.02151332675566664, 0.016223606107814703, 0.0382201043976238, 0.05761975560744759, 0.07186935094068758, 0.01854030542745022, 0.012626818934222683, 0.03795755481405649, 0.08215211870265193, 0.030774595034017693, 0.038482193849631585, 0.026492979959584773, 0.03966608266637195, 0.046235473710112274, 0.00929841091419803, 0.03374795589479618, 0.05818946898216382, 0.017076107433240395, 0.06488195635029115, 0.07702122878981754, 0.05945158758549951, 0.020056201428815257, 0.022767216796637513, 0.05181774897209834, 0.03195699770003557, 0.02913542830356164, 0.038269501746981405, 0.03050604889722308, 0.02831555735610891, 0.022380658047040924, 0.03776876357733272, 0.039545364925288595, 0.02372783790633548, 0.05081449889985379, 0.03126263320154976, 0.0755441100045573, 0.009800071202334948, 0.017012746575346682, 0.035421380162006244, 0.06118754521594383, 0.04683713283156976, 0.07610427564941347, 0.04628496753866784, 0.03809849236859009, 0.042932638243655674, 0.019473929060040973, 0.03546977932273876, 0.05842074075189885, 0.07197178216301836, 0.05120066802192014, 0.014306632165244082, 0.06178376068419311, 0.0432049878872931, 0.023471678214264102, 0.018266658880747855, 0.05454127509437967, 0.03523203973600175, 0.04209223763609771, 0.0587081782578025, 0.01895474109915085, 0.05856517382198945, 0.020600551906682085, 0.04973412855179049, 0.07158661494031549, 0.030956508417148143, 0.03877648137859069, 0.08231546540628187, 0.00441210504504852, 0.029162102946429513, 0.059163563782931305, 0.028198637555760797, 0.015366542429546826, 0.050371611141599715, 0.025181135606544558, 0.03655534841527697, 0.05596920062089339, 0.01699744720099261, 0.0634617157629691, 0.03582712342904415, 0.005810648945043795, 0.030820370702713262, 0.05730269898776896, 0.011439609006629325, 0.01434452900866745, 0.03328852937556803, 0.03845320185064338, 0.05233832103840541, 0.011993020179943414, 0.039543379680253565, 0.02324837896594545, 0.04390594636788592, 0.053023738946649246, 0.027947110720560886, 0.035216491742176004, 0.02437751398247201, 0.05633368047710974, 0.038769683305872604, 0.052966908988310024, 0.010691405404941179, 0.0318486107425997, 0.060210737865418196, 0.02196340592490742, 0.06147331660031341, 0.04315706741181202, 0.07544921900262125, 0.056501224025851116, 0.030365324710146524, 0.0281886779339402, 0.03165175236063078, 0.06997648844844662, 0.02853492693247972, 0.016343323804903775, 0.09122667004703544, 0.026224806751997676, 0.010558647245488828, 0.046729873938602395, 0.04125936240598094, 0.023282723705051467, 0.05095339183753822, 0.042210803148918785, 0.03865430160658434, 0.03418797154154163, 0.05459993815748021, 0.005807722563986317, 0.04488814913202077, 0.09539263439364731, 0.04372101429908071, 0.05476047583215404, 0.0889884120260831, 0.05021249096898828, 0.09500000858679414, 0.03363589901709929, 0.03552946283889469, 0.039808515648473985, 0.031443390689673834, 0.021473512388183735, 0.03518978555803187, 0.027864379808306694, 0.005037353794250521, 0.04603454093739856, 0.03345216922753025, 0.02832387683156412, 0.01932211347593693, 0.05590310123807285, 0.04830950558243785, 0.013293477204570081, 0.0236586270693806, 0.021788030862808228, 0.053241982313920744, 0.030070810826146044, 0.057270281977253035, 0.03621846903115511, 0.024947232923295815, 0.05442980080260895, 0.05033573201217223, 0.010443595801916672, 0.03939173664548434, 0.04218096881231759, 0.15843987552216277, 0.12064206428476609, 0.2279858515248634, 0.1362106527085416, 0.13282000261824578, 0.07643701756023802, 0.11584728563320823, 0.13243770750705153, 0.12311800994211808, 0.17022985615767539, 0.07563413993921131, 0.152922690322157, 0.11272770498180762, 0.10352436132961884, 0.1398976126802154, 0.15372640657005832, 0.2974920632550493, 0.1231680900673382, 0.15575913421344012, 0.1186856442654971, 0.16409783129347488, 0.22741567430784926, 0.26165197079535574, 0.085926748579368, 0.10168044347665273, 0.09414053478394635, 0.18559694406576455, 0.19457324990071356, 0.21058910846477374, 0.1041666827222798, 0.11624379287241027, 0.2884667756734416, 0.21535311767365783, 0.1571570584201254, 0.07398531044600531, 0.15113436675164849, 0.13463695824611932, 0.12808797997422516, 0.21695333649404347, 0.09201709443004802, 0.12777943949913606, 0.19534779974492267, 0.11082992205047049, 0.11899592878762633, 0.11262487299973145, 0.06941428931895643, 0.1528920396231115, 0.11547571455594152, 0.09137104745605029, 0.10239320210530423, 0.2664061391260475, 0.17714232351863757, 0.08101758270640858, 0.21045684290584177, 0.09684029733762145, 0.13065215956885368, 0.11527769471285865, 0.16060837166151032, 0.09305915140430443, 0.13191421137889847, 0.15283551765605807, 0.18241108220536262, 0.14098905958235264, 0.24203494453104213, 0.1366077907732688, 0.1523693004855886, 0.10665867361240089, 0.09022010257467628, 0.14420407300349325, 0.15443972923094407, 0.12413192467647605, 0.08711916467291303, 0.17581417603651062, 0.1951658251346089, 0.16389584838179871, 0.11442980583524331, 0.14602012321120128, 0.08851470658555627, 0.10048238706076518, 0.20020220254082233, 0.14417472848435864, 0.1424955451511778, 0.07638203183887526, 0.13888067740481347, 0.15837228071177378, 0.11861305480124429, 0.11087984632467851, 0.11215414357138798, 0.11285931745078415, 0.16455624107038602, 0.20229130372172222, 0.24196801765356213, 0.09219172177836299, 0.20177424943540245, 0.15310101356590167, 0.13343540631467476, 0.12496235081925988, 0.10972027768730186, 0.15832764795050025, 0.1381163691985421, 0.09491939650615677, 0.10408522459329106, 0.13636602874612436, 0.11731008838978596, 0.12878582143457606, 0.1389761918107979, 0.16647341632051393, 0.11480185188702308, 0.17844253656221554, 0.16410470358096063, 0.21286125294864178, 0.20263045036699623, 0.23345913126831874, 0.12873863568529487, 0.10433753996039741, 0.1260687000467442, 0.11609295135713182, 0.09185771821648814, 0.18498952587833628, 0.14094270503846928, 0.16949554556049407, 0.10855356958927587, 0.25870603043586016, 0.20984388829674572, 0.18554678972577676, 0.2104499112465419, 0.15511438599787652, 0.2365708228899166, 0.11944382233195938, 0.15530382661381736, 0.1579600918921642, 0.09779385320143774, 0.1974624308058992, 0.1526483628549613, 0.0888741880771704, 0.1783675648039207, 0.13958261552033946, 0.12214775575557724, 0.09827778543694876, 0.13428224134258926, 0.09083502387511544, 0.09444669296499342, 0.1346097214263864, 0.21456140937516466, 0.2283141776570119, 0.07995274921995588, 0.25005612114910036, 0.14134491939330474, 0.3369420807575807, 0.11301188074867241, 0.20592217217199504, 0.15325434127589688, 0.17513111815787852, 0.07175923848990351, 0.1471010167733766, 0.10046856827102602, 0.09827321380726062, 0.08597193795139901, 0.1627760662813671, 0.09650252366554923, 0.06817301764385775, 0.09130170117714442, 0.15989257022738457, 0.10645217844285071, 0.09964657292584889, 0.09351200991659425, 0.2234111345023848, 0.1299308068701066, 0.2629968017572537, 0.13082466437481344, 0.13119354145601392, 0.17831625271355733, 0.26350894302595407, 0.1000946074782405, 0.17113503883592784, 0.1409139987663366], [0.10005451666074805, 0.0411069252731977, 0.036138728974037804, 0.01878392282378627, 0.02068757614324568, 0.027903316586161964, 0.007232315847431892, 0.07434768631355837, 0.06445459061069414, 0.07622799166711047, 0.030500761095026974, 0.00949122180827544, 0.12286673358175904, 0.03521292201185133, 0.06980648468015715, 0.041041516087716445, 0.051513538928702474, 0.08932356591685675, 0.06763112367480062, 0.04067705478519201, 0.0100592467970273, 0.013834359069733182, 0.04887917442829348, 0.017118443247454707, 0.01679915647400776, 0.023345620720647275, 0.03063198393647326, 0.09102559255552478, 0.0753023182915058, 0.015326230823120568, 0.024025420570978895, 0.04698980374087114, 0.04795335633389186, 0.0995554742985405, 0.025817419627855998, 0.018649788908078335, 0.04525634714809712, 0.042184189733234234, 0.031891302787698805, 0.054467720838147216, 0.039776417761459015, 0.07961347640957683, 0.017684503400232643, 0.11751445359550416, 0.026492671968298964, 0.02811874535836978, 0.03246722793846857, 0.019791707418335136, 0.004458908588276245, 0.029339415013964754, 0.03517599274346139, 0.09987231198465452, 0.05168732393940445, 0.016644667302898597, 0.018091575111611746, 0.04081262290128507, 0.011135217137052678, 0.0433319804869825, 0.03096950527833542, 0.04063517539179884, 0.050944630784215406, 0.03486991619865876, 0.05618540308205411, 0.06603250047191978, 0.018175474906456657, 0.04417980628204532, 0.04734052417916246, 0.04641832405468449, 0.04636973564629443, 0.06580855741049163, 0.021247816002869513, 0.05709154313080944, 0.010765336301119532, 0.021474512432178017, 0.04086651395482477, 0.04248147924954537, 0.06416288946638815, 0.003856564139823604, 0.12303307114052586, 0.05129173325258307, 0.05040903022745624, 0.07006096711847931, 0.013832988879585173, 0.0940853041538503, 0.01920779119245708, 0.01643004932702752, 0.015939363547659013, 0.014172470418998273, 0.029748753986496013, 0.015369152006314835, 0.03301925222331192, 0.061140467078075744, 0.029796700437145773, 0.002815150282913237, 0.028696544432023074, 0.002466371488480945, 0.017543218891660217, 0.08299665307276882, 0.02326175061170943, 0.01904470795125235, 0.10347042945795693, 0.047325696068583056, 0.0075823335646418855, 0.08601858935435303, 0.03584494610549882, 0.04276762170775328, 0.04276808555005118, 0.04076204182638321, 0.02385767293162644, 0.015374674512713682, 0.029631815632455982, 0.028376610134728253, 0.0491499544295948, 0.05087207100586966, 0.07008401080383919, 0.033139624865725636, 0.0503145808033878, 0.06467524595791474, 0.05360173468943685, 0.023558383327326737, 0.021633951728290413, 0.023186969956441317, 0.04348499278421514, 0.057977303804364055, 0.06787060730857775, 0.031377439736388624, 0.038132252666400746, 0.011628505071712425, 0.023875647748354822, 0.01009746183626703, 0.009135908403550275, 0.04479840492422227, 0.04021503817057237, 0.031514566362602636, 0.008257071040134178, 0.0822874196455814, 0.08262238057795912, 0.04957232922606636, 0.04119732628169004, 0.04974797702743672, 0.03024279427336296, 0.04831151309190318, 0.059479477495187894, 0.06366855232045054, 0.016455174736620393, 0.013701131501875352, 0.017753070424078032, 0.0483199401787715, 0.05834493407746777, 0.02963632232422242, 0.05779980063380208, 0.047846130837569945, 0.03283008991274983, 0.07875657043769024, 0.031493942078668624, 0.04332917516876478, 0.06636453734245151, 0.03754805256903637, 0.06331295226118527, 0.09402262978255749, 0.06810192731791176, 0.022249873072723858, 0.022687910895911045, 0.04069012400577776, 0.04203998301818501, 0.07892242560046725, 0.00867827880938421, 0.03647503319371026, 0.031030173995532095, 0.015715286899649072, 0.028598896351468284, 0.03018144463567296, 0.06618804720346816, 0.07560924088465981, 0.08861209120368585, 0.005796787017970928, 0.033498664779472165, 0.04299387655919418, 0.08950594870839268, 0.06311228295089677, 0.04866349889198318, 0.01649065496167168, 0.018390699588053394, 0.025793188506213482, 0.038566987932426855, 0.06296156017924659, 0.03545291030604858, 0.025217382099071983, 0.11715676810126752, 0.0489535116503248, 0.00821947754957364, 0.01746103345794836, 0.041013444351847284, 0.02996454084495781, 0.035090857272734866, 0.05659025577188004, 0.04269099867087789, 0.05561717400269117, 0.024531754534109496, 0.015991928012226708, 0.029459002835210413, 0.01038619717292022, 0.06046296788554173, 0.08463826146908104, 0.03457112754404079, 0.09131667771725915, 0.028452338883653283, 0.03289235981355887, 0.012463269995350856, 0.055719482770655304, 0.025063928223971743, 0.016919115369091742, 0.08540858849301003, 0.003703432635120407, 0.028164170362288132, 0.024978586807264946, 0.028160194306110498, 0.027621311601251364, 0.0166901257034624, 0.07092088620993309, 0.033667841053102165, 0.04134820119361393, 0.11433415042120032, 0.025238203052140307, 0.0479356857977109, 0.05610863161564339, 0.04234045263729058, 0.10840344795724377, 0.05049091880209744, 0.004900336634818814, 0.04862325593421701, 0.02542033722420456, 0.05153363999852445, 0.0277804317738628, 0.12337769483565353, 0.07095586362993345, 0.03784307853493374, 0.041509117363602854, 0.0276587288317387, 0.021866255083295982, 0.108190266037127, 0.01647121440328192, 0.10400527302408591, 0.02674270152056124, 0.03459322870185133, 0.021929990725766402, 0.03811447080806829, 0.06584900445886888, 0.014935144045011839, 0.03565375773177948, 0.015081142119015567, 0.026329100764996838, 0.002436436730022251, 0.019812405917036813, 0.08652220334624872, 0.05074948305264115, 0.051157538109691814, 0.08615670303697698, 0.05203734675887972, 0.05817316770844627, 0.03831371519481763, 0.06225216719030868, 0.08276813096017577, 0.06540033165947534, 0.09290685527957976, 0.0516087453434011, 0.18933509738417342, 0.0599669312214246, 0.017887996582430787, 0.03426111019507516, 0.05646596458973363, 0.013014411124459002, 0.056174267156166025, 0.032322895058314316, 0.007626435690326616, 0.02546492174587911, 0.06889595111715607, 0.012758206903527025, 0.030821764084976166, 0.05485944122483488, 0.07457233441527933, 0.02643190120579675, 0.04219674316118471, 0.09117235225858167, 0.03178918326739222, 0.020255555282346904, 0.08025387563975528, 0.029562745803559665, 0.02100545654684538, 0.0615752357407473, 0.051430318198981695, 0.04208909464068711, 0.05316553739248775, 0.05281027129967697, 0.0887527949817013, 0.04241886425006669, 0.0664703527581878, 0.007600266635563457, 0.003585205727176799, 0.04710444700322114, 0.015880540922807995, 0.030593427509302273, 0.018920201546279714, 0.03516319440677762, 0.011658307867037365, 0.01287678633161704, 0.009555844317219453, 0.013808824551233556, 0.1223439647583291, 0.018975068524014205, 0.027722529412130825, 0.029659280662599485, 0.057228109435527585, 0.01773966352629941, 0.0036263160700400476, 0.01094876181014115, 0.07231299197883345, 0.03336280722578522, 0.03143441441352479, 0.03632653686509002, 0.02649865924468031, 0.053539412838290446, 0.052607672405429184, 0.06101062463130802, 0.029746748332399875, 0.05481104948557913, 0.02209593865700299, 0.037885674100834876, 0.015550967982562725, 0.02403689231869066, 0.035852375003742054, 0.08464394632028416, 0.011557272810023278, 0.05831714064697735, 0.025664893437351566, 0.021468324775923975, 0.026964535027218517, 0.07690532016567886, 0.016513782138645183, 0.037565671154879965, 0.024040085409069434, 0.016750618160585873, 0.021363060404837597, 0.05639848852297291, 0.03973136939748656, 0.034438160655554384, 0.04079029167769477, 0.030436385350185446, 0.03487164169200696, 0.08545608594431542, 0.016490662383148447, 0.02299530475283973, 0.32611037604510784, 0.09149434044957161, 0.21387529384810477, 0.13704696408240125, 0.10710234433645383, 0.12462514860089868, 0.11039178032660857, 0.11316135671222582, 0.11004881162079982, 0.27139286685269326, 0.1717931605526246, 0.11451507118181325, 0.27255990891717374, 0.13792085781460628, 0.12291241277125664, 0.09418865563930012, 0.0889005268982146, 0.17258534382563084, 0.28590167581569403, 0.09518061022390611, 0.16106510418467224, 0.16622451483272016, 0.09724578456371091, 0.10474591414094903, 0.050824629215640016, 0.08406072214711457, 0.1135363861976657, 0.20496245648246258, 0.28217042447067797, 0.17437556729419157, 0.14025087497429922, 0.17599086655536667, 0.17791785299777985, 0.14600125781726092, 0.07201646687462926, 0.181680912792217, 0.17105582199292257, 0.18588467472000048, 0.12384820904117078, 0.10412623567390256, 0.16053304367233068, 0.18764469277812168, 0.1250549263204448, 0.22179874446010217, 0.09261467916076072, 0.12977381295058876, 0.18546430743299425, 0.07483644993044436, 0.19246465992182493, 0.12875733780674636, 0.17996911949012429, 0.15198719833279029, 0.21550368459429592, 0.10404100743471645, 0.13593409879831597, 0.13367344276048243, 0.1279213381349109, 0.09044715523486957, 0.19622338557383046, 0.13843549269950017, 0.1613378434558399, 0.08067739705438726, 0.12859464419307187, 0.1422539315535687, 0.17979113763431087, 0.09168867924017832, 0.24258903198642656, 0.18231231719255447, 0.10814949244377203, 0.12749135261401534, 0.10249127692077309, 0.13281871128128842, 0.13527153903851286, 0.13139892340404913, 0.13876503595383838, 0.10737963297287934, 0.14492833492113277, 0.17411348526366055, 0.17796904634451494, 0.20564103178912774, 0.14159037731587887, 0.18216795462649316, 0.14743391453521326, 0.16548226325539872, 0.19481437368085608, 0.11740264904801734, 0.16207037289859727, 0.12913513550302014, 0.16915558255277574, 0.15986842074198648, 0.3606416465481743, 0.14584889489924535, 0.12870860839029774, 0.18781832564854994, 0.17458314599934965, 0.1054012899112422, 0.11741373673430644, 0.27617761166766286, 0.13465404248563573, 0.26684774667955935, 0.1823013334069401, 0.14177551347529516, 0.048719894693931565, 0.16491134389070794, 0.12430106013198383, 0.11392449974664487, 0.24035959067987278, 0.18460300052538514, 0.12647501105675474, 0.09861370373982936, 0.17471680679591373, 0.14545764948707074, 0.1682790319318883, 0.22757790778996423, 0.1124917168635875, 0.12167130436864682, 0.21144838188774884, 0.20893582608550787, 0.16751742514315993, 0.15903487015748397, 0.21961205085972324, 0.10548475183895789, 0.18230752291856334, 0.11214407262741588, 0.11210303928237408, 0.16948206815868616, 0.10008518220274709, 0.13930128217907622, 0.1061947867856361, 0.11319276440190151, 0.13940291188191622, 0.10595440515317023, 0.20301083073718473, 0.08466747982311063, 0.1246059566619806, 0.1931993564357981, 0.08396649907808751, 0.13245841342722997, 0.15221459238091484, 0.11794819438364357, 0.15798296488355845, 0.1015118052600883, 0.1602858491241932, 0.16890114464331418, 0.19019993691472337, 0.09660142968641594, 0.1496807814692147, 0.2132235249155201, 0.12564981705509126, 0.16787280997959897, 0.18057319801300764, 0.13626767933601514, 0.13385868282057345, 0.136592561902944, 0.14778962591663003, 0.16227848595008254, 0.18796096643200144, 0.12951645097928122, 0.07790338262566365, 0.1611892951768823, 0.11086735597928055, 0.14391760400030762, 0.055753384076524526, 0.11788051793701015, 0.12945777678396553, 0.18989530013641343, 0.07391806444502436, 0.22257998847635463, 0.1327055782894604, 0.11864176849485375, 0.1656962392735295, 0.16747570160077885, 0.16517823503818363, 0.096702294977149, 0.18931871076347306, 0.2157192784943618], [0.05508097601705231, 0.041808050737017766, 0.017520470210001804, 0.04977829004928935, 0.07323396755964495, 0.04607145536283497, 0.039999266155064106, 0.0539062601455953, 0.01746973142871866, 0.012094933754269732, 0.04754937566758599, 0.050865298908320256, 0.03821736216195859, 0.048847139623831026, 0.008184228317986708, 0.01227741209731903, 0.046612006044597365, 0.015084242440934759, 0.027043959671573248, 0.03831164460279979, 0.03805839784035925, 0.03912732798198704, 0.02455327496136306, 0.04632312877220102, 0.08311940429848619, 0.03787531371926889, 0.021699696735595353, 0.01868845480203163, 0.014759001787751913, 0.03373983308847528, 0.019579453182814177, 0.036243538779672235, 0.05292073627060745, 0.11942969184019603, 0.02792418763419846, 0.0063887815213092836, 0.007972612329467665, 0.05397108674515039, 0.026162974718317855, 0.10384832363342866, 0.03933141859306488, 0.011513614117575344, 0.0563653813151177, 0.05470335643622093, 0.013084451311442535, 0.08773731431574561, 0.038894931858521886, 0.04312401215429418, 0.018986714676429983, 0.04147788407863118, 0.011902558871952351, 0.023010526201687753, 0.04087337511009537, 0.07511500021792017, 0.04435083050339017, 0.02720966083870735, 0.030531701231666375, 0.030205731418391224, 0.026978672940458637, 0.017059156780305784, 0.036110742585151456, 0.031674502897658385, 0.11635507049504668, 0.0283215798845049, 0.04657444966142066, 0.04990486333554145, 0.02737682774750283, 0.11575156342587434, 0.050552606116980314, 0.04110913687327411, 0.07034792593913153, 0.08834291424136609, 0.050239571937709115, 0.04754544599563815, 0.026281992941221688, 0.02171778101910604, 0.015112115652300417, 0.06530038663186133, 0.06253645056858659, 0.030764908151468262, 0.08648678063764237, 0.04196791305730585, 0.08475788825307973, 0.07052857952658087, 0.05174200909095816, 0.055469954168074764, 0.037611572988680564, 0.03239919897168875, 0.017715578978823032, 0.0680011733493302, 0.051253293713671155, 0.04720950542832725, 0.03231403010431677, 0.016296395951940212, 0.06131749898486305, 0.03479437298665289, 0.06456860675825737, 0.036436352456803434, 0.12053897997247986, 0.012324702674959553, 0.04755268935696222, 0.03594075365981553, 0.03230452319257893, 0.1289131591329351, 0.031193747054203413, 0.0742993650783319, 0.038480175207951106, 0.07540050442912616, 0.03251815782277845, 0.03591954678995535, 0.05015040289436001, 0.03650309008662589, 0.026697384128056, 0.03143752030155156, 0.040357400648645125, 0.0410350185848074, 0.026994566032954026, 0.0343285157578066, 0.04427635598403867, 0.038444540987256914, 0.06633175667957403, 0.04670796944992617, 0.024124536248564254, 0.012468396380427293, 0.009662300763011444, 0.054937433524173684, 0.07159077838878147, 0.032821043132571504, 0.02942861188785173, 0.024716573425394017, 0.07350364918238483, 0.09859950645477511, 0.0518863679462811, 0.02219707668700721, 0.031592874074704014, 0.011135238473798381, 0.021421413621283136, 0.01552458092191955, 0.04564985982142389, 0.017682271391095128, 0.042559070789138786, 0.042187243670923635, 0.017940377365448512, 0.02553984711994417, 0.022378131034201942, 0.03686252704937942, 0.034238229782204144, 0.02687781507120235, 0.046249945589806885, 0.03624230310379062, 0.040589874697616324, 0.026249349575664382, 0.05440074572106823, 0.07522532789153047, 0.07918205112218857, 0.07153063474106602, 0.02639515932969516, 0.019686292762344237, 0.02463159751641797, 0.021987384716339875, 0.013368089021241758, 0.024717733031138778, 0.037489597307285294, 0.04614107994711958, 0.03163661254802719, 0.045415118511300534, 0.060329418411129154, 0.029730960995948408, 0.0424080622906331, 0.02031859887210885, 0.044485355901997536, 0.015552789027424296, 0.007197865816124249, 0.09929273917805403, 0.03976786450948566, 0.06501545387436636, 0.08411745933699422, 0.009178459440590814, 0.03485251283564139, 0.05169044838112313, 0.027915894133911934, 0.08064127672696486, 0.03668470846605487, 0.046663358953082934, 0.0395197348552756, 0.033876837260322645, 0.023415148825733922, 0.08954169054049999, 0.030451716265815776, 0.1261305357911624, 0.05077181427623145, 0.013618180728371954, 0.056991857854882255, 0.07235477489302866, 0.14582091593183577, 0.07290465437108651, 0.01733504090225324, 0.016740382088755723, 0.0347593584592687, 0.03611314714362379, 0.11400343457353301, 0.03487981273792684, 0.0030051303474465385, 0.013151643506716937, 0.057827107957564294, 0.06409566572983749, 0.007036205643089488, 0.030836909463687334, 0.03481526073301211, 0.037555333037744276, 0.0532391584420111, 0.017001397282001562, 0.013348968514037551, 0.058134947103098966, 0.014139524628262734, 0.07143546172301285, 0.02979650005727308, 0.027046484829043038, 0.03720176646311302, 0.11348678104695864, 0.027357103317626752, 0.022814996264060028, 0.019644405947474297, 0.030760585141251795, 0.029627334915858228, 0.01634217162063578, 0.02662801187398145, 0.03289933971245773, 0.05588459207501728, 0.04034362638776656, 0.08163225909811445, 0.04955613556376193, 0.10644173642504029, 0.027691318391589448, 0.03976504063757602, 0.014316038887045579, 0.051342080550966784, 0.05261389902443625, 0.008322590620082337, 0.0407195946900174, 0.04326960668549873, 0.015087696210684953, 0.017857707680377644, 0.046979977705632336, 0.030632069283456076, 0.013287704223330365, 0.026440610308782198, 0.059206010919297114, 0.04728770552901551, 0.009065282847586786, 0.02047895843134029, 0.016125238144013565, 0.023810088277969044, 0.0168971255334327, 0.119288275600411, 0.04045719724672381, 0.03711612262122799, 0.07186083108535968, 0.05132331534696277, 0.04259665685822256, 0.010073746507259784, 0.04391957962070592, 0.03231117283576168, 0.03580216129194014, 0.01307735266891541, 0.059092380688525736, 0.06661979161435738, 0.013540500131057343, 0.051150962681276724, 0.021007241412007716, 0.06118199024058413, 0.03902628457581159, 0.049419469069107436, 0.03622338947025128, 0.01454932002161513, 0.027974941258435138, 0.0739449227694422, 0.030012259085197, 0.01939950463565765, 0.013814026078762254, 0.023209080391097814, 0.055759625538485125, 0.04471481683140155, 0.019522534166753758, 0.04892174772976432, 0.047919440185069107, 0.026298908342141658, 0.07127416334697045, 0.0179761897015851, 0.013517903589672642, 0.012405499364831485, 0.045991340521140955, 0.042855109786614776, 0.011214667756576091, 0.005215374612816959, 0.009001365378935589, 0.02301360982528422, 0.041158704916597344, 0.034890674069174565, 0.04060682163981255, 0.07004354149103165, 0.024947542769950815, 0.07925959071144462, 0.06052310411178041, 0.03893645502103027, 0.022004849306540564, 0.02474999233527342, 0.05089547092211433, 0.047309661968029104, 0.014460385682468768, 0.009546703840896953, 0.07017815223662183, 0.03262909776822198, 0.029369666808634065, 0.03820187725068536, 0.02433092195133213, 0.02297754144819919, 0.10384427892859094, 0.08714781157323159, 0.057451703687547706, 0.02328070877410937, 0.04218395595671609, 0.05300058393913787, 0.007155589837566367, 0.026993597530236002, 0.04264128590875771, 0.014641095858678455, 0.06497034613857977, 0.04529729143541772, 0.03092603768891422, 0.07349913692451082, 0.0349390249903081, 0.04513248641160317, 0.041193467113771476, 0.034041271210298873, 0.030018355828360654, 0.04688660068495665, 0.052625057214754634, 0.07262182931299321, 0.03049464023206383, 0.006405763251677854, 0.037440526502905414, 0.043128164470545016, 0.019166550046065822, 0.059971788577968255, 0.009449074314034078, 0.06825716976891272, 0.018339999769523274, 0.06517066663946025, 0.05665039941959549, 0.04236475797370076, 0.0720336550148204, 0.2165608888026327, 0.13781011453829706, 0.11407396828872152, 0.1260975399054587, 0.11308733490295708, 0.14133776508970186, 0.09582798564224504, 0.14547467435477301, 0.12496552721131593, 0.15851840958930552, 0.1772418009932153, 0.1544135611038655, 0.1526825610199012, 0.2043728795251809, 0.10999009289662354, 0.09304526582127437, 0.18725619331235066, 0.1646004433860071, 0.21708909014705569, 0.21000334614655003, 0.14837650145636871, 0.10285011274390854, 0.11051408626371995, 0.0905800070904661, 0.1743833746877499, 0.1574100714060478, 0.08075415738858283, 0.09487245566560887, 0.13487331743817776, 0.21467326587298885, 0.15404153731651604, 0.16053644270868972, 0.16877340618520975, 0.16010464634746313, 0.16153841628693044, 0.09021738631417975, 0.12021284317597747, 0.142986431310419, 0.10075737503939308, 0.22158156236400828, 0.1398608912131749, 0.13377075316384435, 0.116908430645708, 0.154098074126523, 0.12054291335516609, 0.1426804141374305, 0.13774152525002137, 0.12126727917348035, 0.16111703967908397, 0.14368636562721804, 0.07372647160082124, 0.09654005407355726, 0.28343575657345355, 0.2835125243291259, 0.2621193160302937, 0.18925141281215474, 0.13285172200994566, 0.14737789722857997, 0.12932227546116337, 0.1260228650062345, 0.13781348388874903, 0.17179614398628473, 0.21768874546978623, 0.13398419483564794, 0.07610094340634532, 0.27519298950210214, 0.08513812761520967, 0.20783597807167098, 0.12000690461718477, 0.09044069855008274, 0.2729886624729261, 0.15899771824479103, 0.08653894619783387, 0.12157857301644981, 0.10466538369655609, 0.10588822042336687, 0.07434778279275633, 0.1309172695619054, 0.20055095257703215, 0.1064824580680579, 0.2008920139633119, 0.2162762454827316, 0.13057481293799356, 0.1275229681050405, 0.17295744182774797, 0.11883045954164118, 0.10260415758239105, 0.191163333656732, 0.12325855044764467, 0.14031141938176006, 0.15007649461040273, 0.14430438168346882, 0.1254480122588575, 0.14977187267504632, 0.13099371077260002, 0.1703223426011391, 0.16363548813387752, 0.10093339020386338, 0.22441751643782482, 0.12593598919920623, 0.214263882371597, 0.1056851762405131, 0.141895325796213, 0.3295247600181028, 0.13409177656285465, 0.2037295265472494, 0.10644061578204855, 0.09109213351621293, 0.1246654917486012, 0.14017176203196868, 0.1268110258388333, 0.18848570936825126, 0.08326026392751373, 0.0809547450626269, 0.10651540200342424, 0.13619270757772028, 0.11480329165351577, 0.13475475192535669, 0.17482578376075253, 0.06313939360552467, 0.10204317557509057, 0.09739814748172648, 0.13248458155430853, 0.09001204889500514, 0.20095459185540676, 0.1723252359079197, 0.16758562851464376, 0.1393842394463718, 0.1412522399914451, 0.12741734564770013, 0.17093989852583036, 0.17700336378766224, 0.10336879975511692, 0.11869989350088872, 0.12064526294125244, 0.1967947353841737, 0.12203787337057292, 0.155314483854454, 0.09476772378548048, 0.07046711485600099, 0.08953543423558585, 0.1760361820925027, 0.20051405299454927, 0.17228906363015994, 0.10177828080486506, 0.19165328470990062, 0.11123041462269612, 0.08793667744612321, 0.09329369233455509, 0.14430372859351337, 0.11930607230169699, 0.18205461383331567, 0.12429251801222563, 0.15089058608282357, 0.28362743847537786, 0.15536634513409808, 0.1514262831187807, 0.14027864614035934, 0.06936308112926781, 0.11670644031255506, 0.12048641365254298, 0.17640188278164715, 0.10211999528110027, 0.12092404329450801, 0.14082063658861443, 0.10728513530921191, 0.1397448341595009, 0.05153735815838445, 0.12290341051993892, 0.05461550841573626, 0.223981786693912, 0.06342767344904132, 0.13515876227756962, 0.09750132827321067, 0.12188444918137975, 0.13014617812586948], [0.024825591208355036, 0.03354311571456492, 0.04159689859079663, 0.03716536040883511, 0.06444552898756228, 0.03393201965081971, 0.017198556233779527, 0.055773177155060694, 0.09481864253757522, 0.01256599900443689, 0.029423266569210682, 0.03942565650504548, 0.06649885122897103, 0.042766560436575674, 0.05172691380721517, 0.04981527497875504, 0.03928958743927069, 0.06789837847463787, 0.022102579023339786, 0.004765927196785924, 0.03536424963385798, 0.047122217729338445, 0.062296180258272216, 0.032778217500890605, 0.05217901161813643, 0.04079371668922249, 0.07082905285642482, 0.041660712158773094, 0.06756825634511188, 0.10602332098642364, 0.05790822840936016, 0.05949132588284556, 0.03370292608451564, 0.021122597136127297, 0.015511194433202036, 0.038481503652292304, 0.015360878915089415, 0.04022731329314411, 0.048008961748564616, 0.04644488180929329, 0.020371257960505318, 0.02641204875544645, 0.020208961395837832, 0.06605587812373415, 0.0443633282702649, 0.034705018406384625, 0.030588232475565746, 0.028903794736834243, 0.08034559024963528, 0.034428030339768156, 0.036649044559453614, 0.05804934036859777, 0.05024465193855576, 0.11221654334804043, 0.022477482343674637, 0.03185103756550234, 0.024584612147009466, 0.023640774707018863, 0.02027379541686969, 0.017436770795029588, 0.03981863854278345, 0.0533893023384735, 0.06419223398552276, 0.04591417200572323, 0.012800474069081247, 0.04288664735213388, 0.03558701639121864, 0.023309520802285988, 0.07159095650422387, 0.03165479145536665, 0.0490383205760736, 0.052915648848284036, 0.05329427032847889, 0.024171625518647488, 0.051047362576355226, 0.0837745945318602, 0.014145018376439111, 0.1046288848738186, 0.021213471263763495, 0.0808766414411366, 0.0720485944475513, 0.054213898911257274, 0.04775865760166198, 0.053526098708971404, 0.0547222849127138, 0.040792536674416624, 0.031185212355921976, 0.01624938831810141, 0.08965871238615364, 0.06089296824939083, 0.017186321929330006, 0.00864466694110888, 0.031667099974583834, 0.07935946152429096, 0.10547741199843585, 0.06294032733421773, 0.01047786539857043, 0.016675176993885543, 0.05881768214749172, 0.03903043318132404, 0.11536796213476919, 0.03859855518385302, 0.04013858582766261, 0.023351676645688713, 0.08175296941772103, 0.049962832490564324, 0.047187960881274194, 0.04973904156940989, 0.03772214557102416, 0.0747184558713343, 0.035924329931731336, 0.06835594220319763, 0.006909656476636883, 0.016748393572925124, 0.05751899050665088, 0.046197193732950836, 0.02198003559897188, 0.0541050035826629, 0.03646131088316906, 0.027840864859172143, 0.05757304483267944, 0.09226858601323329, 0.03255048577557318, 0.007728848822807777, 0.04523957832134329, 0.10508718332857825, 0.034218711298308335, 0.08062229258939624, 0.04585435861372389, 0.056195358993136324, 0.035891508450731635, 0.027817286827485077, 0.08519355120370165, 0.08041278430027887, 0.0192593760220916, 0.014079150914767524, 0.04764624078234192, 0.03642989577201661, 0.04920507002680097, 0.012350837405392667, 0.051787591801257804, 0.03087635832343949, 0.07905605671112426, 0.04066362191224471, 0.06450490822317079, 0.0727760476002004, 0.007506015272156219, 0.060624978723353706, 0.039141992820077576, 0.018825677907443605, 0.08075463978457265, 0.020412450867297594, 0.02200585491664242, 0.04673727315093856, 0.048881426846492104, 0.039401711110258475, 0.06696356926113367, 0.0760495571012143, 0.06277491003856994, 0.014305073655123124, 0.02424094211164629, 0.06198731323820539, 0.0355742106330581, 0.030856019766360987, 0.02131777084287023, 0.08587912496295758, 0.058073838663403876, 0.0293141077781911, 0.027786231657955796, 0.022169450239744037, 0.07305784849449992, 0.1027265822631307, 0.03856082068523392, 0.0626573315821588, 0.05753047895268537, 0.025769760759430937, 0.058322929398855194, 0.011692572825268144, 0.038576880760956556, 0.05557428899919614, 0.055310692987404764, 0.031123422995733563, 0.03512196068186313, 0.039381650858558714, 0.05810727241623681, 0.030327111526275985, 0.0261733666411601, 0.03427360425121151, 0.017293308083026204, 0.014026003864273662, 0.04258671207935549, 0.017854772486316506, 0.06816326582338661, 0.022649835009360686, 0.009159744331554975, 0.05113154067657888, 0.010144110456167255, 0.015256445749400882, 0.03815961936197709, 0.04123391416214872, 0.022913514512765687, 0.04981397993105929, 0.01267828965865192, 0.03452226083027199, 0.04775400804646779, 0.07273708484717645, 0.021311612872523256, 0.048222844998235814, 0.06502034462755546, 0.007934646837384207, 0.05333534078090452, 0.005017791709178709, 0.007258278956214781, 0.07461969085852616, 0.027984834086964838, 0.05561482881603297, 0.060288934255368076, 0.04077102552400902, 0.05302842560922727, 0.03720186294231098, 0.05767544265836477, 0.06745955397491343, 0.01988992324186256, 0.00828445443403325, 0.0629712526279036, 0.04303350353438873, 0.050044680247083306, 0.027660832820401993, 0.045478008105419576, 0.0376728929404635, 0.03156560385832563, 0.03545594197930768, 0.010888707220146898, 0.02567103656474501, 0.014113313827692764, 0.040922898624558, 0.07233416545204818, 0.03418596774281468, 0.04386119115224574, 0.06483406556071714, 0.02370343794609653, 0.04557387132081203, 0.019900517399946693, 0.05504497814399656, 0.011997588098893175, 0.024678046684130095, 0.03666244403575547, 0.06497689930256456, 0.06634473684243858, 0.03173327728291042, 0.026097906920767855, 0.07027486150036566, 0.0194336211643531, 0.06204244367836509, 0.026482218818273395, 0.11872410235810094, 0.06320407177554443, 0.03242650629545096, 0.024835229851305485, 0.04690628244134132, 0.015739529153506737, 0.030485187126032542, 0.018804092542268336, 0.058333853812655434, 0.015782766677148174, 0.016711063544789795, 0.04352384050434921, 0.06271115955314599, 0.030434901054832153, 0.016093769227154553, 0.08099448707071133, 0.054430906602647156, 0.03208496993465815, 0.00723781377018895, 0.030993875552667305, 0.02124720558640547, 0.03921735791664105, 0.012310340262047248, 0.08632045792182907, 0.06663197025773115, 0.03252127113228198, 0.07525487279053777, 0.03092211358307395, 0.027971228664682712, 0.006128876302682329, 0.09056431808858179, 0.02878281353332568, 0.030350086562975775, 0.01508563211245928, 0.02821545462211361, 0.044602900961763225, 0.03611358130001463, 0.02938606085081119, 0.03640536408056505, 0.08299241540953517, 0.06581430163350888, 0.022616688838752452, 0.03183902219461743, 0.08216780770453624, 0.013894725361751625, 0.035128588060615584, 0.10028760298155248, 0.054220359306782484, 0.06042447639629245, 0.004894466710538836, 0.07853673887439072, 0.09131450322456658, 0.118251703097485, 0.03232235700124875, 0.022857280127936974, 0.014491368492599577, 0.02458769391523674, 0.01294875053645228, 0.03787823035963811, 0.03241986778448336, 0.0452714684070088, 0.049398284463677555, 0.036446338053792715, 0.07573923547170125, 0.022290180968411732, 0.10308408222044818, 0.04314346384489909, 0.0456649959232891, 0.04903010129055474, 0.07069787083310075, 0.019846034483634867, 0.02972232054162305, 0.04503732452576514, 0.025861861286102794, 0.053777189532411285, 0.07139623921830207, 0.01409856364261941, 0.04372776413219981, 0.025532149193168152, 0.055520861787954345, 0.07087828693329357, 0.027833795902552083, 0.034550941127236, 0.047891691283439286, 0.029246772719488945, 0.02254175047710305, 0.029771589870506432, 0.06020300468662754, 0.0487471983069554, 0.09010891400976107, 0.03132548197754659, 0.0045597956795973005, 0.060120329435449094, 0.013018963272770634, 0.0349489178188378, 0.08755470145842992, 0.019080245692748576, 0.20756775105837733, 0.10173786344239488, 0.12961880798684433, 0.22261378588154912, 0.1257514616008848, 0.12963825225597247, 0.0767229447956197, 0.22976577398367226, 0.15027215442387387, 0.17120291566243395, 0.1718697650358081, 0.12264098710147664, 0.13293364027049392, 0.18058532470604405, 0.2738777850754559, 0.1780514098936692, 0.13092319190036505, 0.1100545038934797, 0.11833324286271818, 0.10136048134882003, 0.16456133220344782, 0.20899919065413997, 0.1014374420628883, 0.11535100406035781, 0.19025577610591426, 0.10987785790348426, 0.15310245333239436, 0.12256301706656814, 0.12871816725237295, 0.17190847545862198, 0.19440325355390087, 0.12857493275078014, 0.10803078592289239, 0.05197952232265379, 0.10882484682952054, 0.15330773137975484, 0.11012898583430797, 0.1749603499774821, 0.12644685397390276, 0.15001379797467962, 0.11766399635234848, 0.12752835609717295, 0.15114457870367914, 0.18429995194310322, 0.10438153447466902, 0.2505896956427023, 0.09620429904316552, 0.08992089089588262, 0.2066555476631038, 0.10768507127068006, 0.09689486745628528, 0.1668739237356931, 0.1716805767500773, 0.19310559349833056, 0.12927657400723547, 0.20522899139905348, 0.1368004226242192, 0.10315980354789644, 0.1897823007311672, 0.2121609475580044, 0.14126735011814162, 0.07845034546335228, 0.13198280066717416, 0.1145084883319214, 0.07729776785708964, 0.133999542449601, 0.13403786695562303, 0.20492045092396438, 0.1799281529383734, 0.1355620304821059, 0.10256022986141033, 0.18842917255824432, 0.2093476289883256, 0.09070492538739927, 0.16324709256878123, 0.15296950499759987, 0.14834424771834165, 0.20522017468465492, 0.100771423894912, 0.18150527612306178, 0.22092398983659223, 0.15220820991089568, 0.0933043124678079, 0.13469618163071573, 0.1101675997779239, 0.09919762553181499, 0.1152213137538638, 0.0930825958494097, 0.2502768952399492, 0.19713921064976603, 0.16564703488256782, 0.14575615612557158, 0.09919847900164314, 0.23071054281899706, 0.31418723927345127, 0.15757407119963318, 0.14266043552197516, 0.07836726945242845, 0.1344268859247677, 0.09326114915893413, 0.12434255360858515, 0.1550831415806897, 0.14608509081881493, 0.18589185870951042, 0.14388116454938427, 0.16665576200466603, 0.15984099096385762, 0.18177629361161962, 0.11982323791016825, 0.21283667301759124, 0.144327670277562, 0.18454964010743424, 0.08239634466008283, 0.16669181553879753, 0.13601647719042376, 0.09259962098440155, 0.14719617494847625, 0.15796430729096755, 0.15297529374947771, 0.16735317301936448, 0.14024786185473204, 0.1520784231252037, 0.14341911824885756, 0.11470207755337469, 0.10498013594769873, 0.19355580996489152, 0.24965319433249533, 0.10842116302228533, 0.10597140033496544, 0.1632506400346756, 0.11723142815753818, 0.18383380898740143, 0.19284915179014206, 0.10027273034211248, 0.10117141180671751, 0.09614895709091797, 0.1339010297670029, 0.12815563415642828, 0.1095004090166185, 0.1822581997839734, 0.16446495690615848, 0.14937682746676728, 0.10655227190000005, 0.11309480090858415, 0.24488951166858897, 0.13553360622609034, 0.10641417306032963, 0.1321353713865392, 0.13847010646713898, 0.08514257307979278, 0.12165473963250406, 0.0874498656776268, 0.0984459115716163, 0.11982153839198872, 0.28364216268528253, 0.1648950611706823, 0.14579471811885014, 0.16271479456918314, 0.12895477877464145, 0.09534121840260923, 0.07760221909848042, 0.16203633800614625, 0.16128801566082984, 0.1509713614359498, 0.13233077886980027, 0.14677542174467817, 0.15528705407632515, 0.1161023617896717, 0.10389550938270986, 0.08044077811064199, 0.17230212542926893, 0.17185305187013, 0.09537585443467833, 0.14804490987444296, 0.16148578317370266, 0.06828944577137008], [0.04251059370290022, 0.13392056309385225, 0.04271949343092274, 0.01011961587209953, 0.045282596911420114, 0.04325051493651699, 0.04002445093647111, 0.061060355947120115, 0.013810049094900023, 0.09363818244310096, 0.06337858038023114, 0.014352621201396687, 0.04861735586018767, 0.037647723002010025, 0.1449098257580772, 0.03125465882476419, 0.018430807103868574, 0.012698289610852953, 0.014729071899637347, 0.046099727478576824, 0.036841001056018285, 0.03320026946312282, 0.010486987321201013, 0.08181286815670319, 0.03527127337292768, 0.05899378636968322, 0.04501114526647143, 0.05819764373882208, 0.053087623018654995, 0.02840921082679415, 0.0522295667178696, 0.05575397408392746, 0.00806561178251286, 0.057533822327968664, 0.057852597019518726, 0.04380639467854053, 0.04698551412730012, 0.05156386396265589, 0.06835318883531727, 0.04392801783978939, 0.066941186087206, 0.030075744252826553, 0.08507283346261829, 0.04008126234111842, 0.07829388589016162, 0.00926331846130779, 0.041806213921518065, 0.04088002104253974, 0.03205161039659288, 0.01470916564358049, 0.006997071732257609, 0.01756799734721426, 0.05018930998630822, 0.03490852272079792, 0.05507284207851626, 0.038956314892857336, 0.0898214356857352, 0.015547400107607245, 0.041566808213246986, 0.05539317528018728, 0.03726205482962541, 0.009237379472324392, 0.09590161411324516, 0.00960177305387333, 0.046734590287087485, 0.030375915157492273, 0.030742682683921885, 0.02482115316524869, 0.03361839917488396, 0.05121339585457463, 0.022773085329390597, 0.055089718516683206, 0.08969637638074346, 0.07130262471036986, 0.03478611288301181, 0.02707967552851187, 0.048803256431710906, 0.04294679842132609, 0.06906175432959571, 0.017303349341091234, 0.05836316122440621, 0.04887589042482432, 0.012281912295293296, 0.046368629846256226, 0.03568078303942457, 0.006089721518947044, 0.0695568039373029, 0.0390500518551562, 0.011277520243311301, 0.01951056889083702, 0.07651871317648329, 0.06447016086895019, 0.045256113371578977, 0.005994129187456565, 0.048013262494350784, 0.03701558758621104, 0.08180173594155349, 0.06072254887840245, 0.07766309005091898, 0.03488883354293648, 0.07142468573874794, 0.05752739161835052, 0.0376648814562941, 0.004390481180962524, 0.017662988539086655, 0.04687390995968599, 0.06471940374467522, 0.02086819633404957, 0.025822878124017734, 0.012321954873186769, 0.04551749778329395, 0.04245774165610783, 0.024683597948751412, 0.01969474211364286, 0.029101441650709603, 0.039852443369454704, 0.02038104874372948, 0.027891432946489658, 0.017448036596761085, 0.02564304832048947, 0.05745358132116962, 0.011864415264426498, 0.09202626737533137, 0.03982121379522141, 0.04705414794443641, 0.06020521999744233, 0.03274466500442941, 0.06502140589873306, 0.06319699168670923, 0.03430343858781271, 0.0213602049916517, 0.0306205993911135, 0.10678945487597957, 0.00811928390248795, 0.0456678940099664, 0.087356778094545, 0.044817162706749514, 0.03557406962499954, 0.0696025276556611, 0.028334897724562325, 0.04272894097084645, 0.06316726867225952, 0.051190496888011694, 0.047182535781757906, 0.06880057029775344, 0.01015286037727492, 0.017340475278615486, 0.050458587138564326, 0.049458071880508214, 0.03580014636099804, 0.05371666367864236, 0.018058959576592315, 0.02702390127524268, 0.03334030530822929, 0.0071280607971857535, 0.01554286001919536, 0.007269603665918112, 0.07076092369970866, 0.13379202311625704, 0.02587574130302528, 0.11581662009120919, 0.01860954780568136, 0.0434658787708031, 0.00977535397396423, 0.0343514221458463, 0.047301216327468865, 0.051214538761996664, 0.012439546317182248, 0.04083671301486902, 0.0584584195894422, 0.005846977073815651, 0.02007038758165436, 0.03481699364783708, 0.08626311959233135, 0.022058044596633408, 0.029630353601532988, 0.043135771484230645, 0.03228600289730821, 0.04090946946234908, 0.03159049178066198, 0.07072843989590183, 0.08159887729561888, 0.06217333997483365, 0.038413500660681166, 0.06016678788000718, 0.016051312813942786, 0.020573480214807205, 0.023399782658088952, 0.03267590131144971, 0.040245362324640155, 0.062494044250342995, 0.04982573555025738, 0.006387225794242113, 0.048399824954685755, 0.03149193827994168, 0.03225968262995593, 0.001406357323503471, 0.1332452383940108, 0.03888183295202907, 0.015429682498506736, 0.009022041613206966, 0.06880845932755619, 0.03709532393258996, 0.057430942106293514, 0.050326855925959535, 0.01874015466455603, 0.02340957900742069, 0.09256490331608802, 0.06636700127273798, 0.020575721500790678, 0.048442754487041384, 0.04818031993636396, 0.015110756594367558, 0.00912224082640023, 0.02913470470957691, 0.04110361900529824, 0.012886545573564945, 0.018628095931489952, 0.07124369076336734, 0.009960017014236655, 0.09053846166352741, 0.021528709621634334, 0.04882285284111276, 0.06795375753426924, 0.03837650830973871, 0.021390460497059394, 0.014770881716685835, 0.008029746568354312, 0.033091563382185996, 0.015601404338667635, 0.04507740792178083, 0.022638448608631734, 0.04703004298789892, 0.07527483656303957, 0.0071516286243422655, 0.053611171097145416, 0.07545097047113813, 0.033404575297026895, 0.025178423056786414, 0.026891296183748636, 0.02686482748686103, 0.02643102918227669, 0.019823974143946543, 0.030865279913996346, 0.04485127552470658, 0.027934280842600856, 0.06487060891231522, 0.009159855653706472, 0.055302455148193985, 0.0383111325209029, 0.010094454282807419, 0.06872777303215116, 0.04061003513925243, 0.09965967925381847, 0.03953803621698171, 0.03004011930897832, 0.028186284507683013, 0.056408121599815786, 0.0655480042041745, 0.004351039278844837, 0.030396238871617243, 0.002178997528972104, 0.06226601195521653, 0.07164103662944399, 0.0204161894362187, 0.03191017560311593, 0.07531013310654089, 0.0068826719871140085, 0.04508323749178089, 0.01237253502040403, 0.007999951194506139, 0.010083021497848677, 0.048254794455715455, 0.0950797375116963, 0.06355917459586635, 0.04317301616538316, 0.017412253946531564, 0.013973624936625129, 0.032877023331820965, 0.020094952669751365, 0.03954792162403464, 0.034375445466139354, 0.04373471063445322, 0.02311961263330886, 0.0238473904755665, 0.0693697456154041, 0.05447422205179464, 0.05109382102091331, 0.04007305789855309, 0.018101297246175818, 0.013881816630600952, 0.048699982871767133, 0.03350431623402983, 0.05240786398644559, 0.005216572253630147, 0.0301409122403129, 0.020314107023295946, 0.02703061400097795, 0.01947341883351328, 0.07432449419866316, 0.014876367804390611, 0.014842591735941824, 0.009793038425414125, 0.06053756856999826, 0.09787751550902613, 0.01827353858971037, 0.010206953666056506, 0.01083823932276573, 0.1483088918030262, 0.03706193470861763, 0.036427483792067505, 0.06612368815694936, 0.03934991291316692, 0.007686270882913959, 0.0371714274660917, 0.0057035867212107405, 0.02894487446610583, 0.07042131692287512, 0.03673455481475685, 0.01037779791658977, 0.03742715671251062, 0.043324696307536215, 0.009026569641719107, 0.027479618911456782, 0.025455438953940757, 0.051235025748610497, 0.052549432366504334, 0.020105648873141035, 0.02678248805750627, 0.015764246381877456, 0.027145596795890015, 0.03069517781113973, 0.05769650109868962, 0.07997174820047803, 0.043047533836215734, 0.03792074057855643, 0.09182139750919305, 0.025078134785871953, 0.044478298077592626, 0.03724358648469206, 0.056269562628585845, 0.024213382457674015, 0.026480357882974204, 0.04510101192863658, 0.12719913938781247, 0.0370437483798014, 0.03904877907189075, 0.03556137889972888, 0.01943550436408259, 0.05199075101700146, 0.062269500049296767, 0.016928646400629077, 0.14787464635446668, 0.1526757629471831, 0.10933134035440162, 0.10285758617101237, 0.12361155299004167, 0.1722964405780658, 0.0744446182216052, 0.1786642160732299, 0.13090687949443236, 0.14625703159254044, 0.07732521247817203, 0.13609403162263334, 0.09862105842330493, 0.1634629981708713, 0.25356772646773607, 0.0996001144812908, 0.21964207815472037, 0.12851621402660385, 0.0743131096533034, 0.129248877055943, 0.11976967711234465, 0.2120447569177486, 0.14344409893965349, 0.14534868736518547, 0.09087368234759197, 0.16874484834261239, 0.12026612195768394, 0.20835169649217278, 0.1354251042357646, 0.13165532058337703, 0.15620713907992467, 0.2001372943050228, 0.12063922185916454, 0.09879101024125703, 0.220032432989683, 0.17322228464763612, 0.11845028697280213, 0.10917137042270042, 0.1626151241362095, 0.11810668744146824, 0.11627900035819039, 0.07846507709473372, 0.1464250686694868, 0.05482836008013692, 0.23331920674536377, 0.12438730511348695, 0.16244254511548206, 0.17411660228390247, 0.1283626043004915, 0.10584422590909526, 0.07708319069934078, 0.068116347247269, 0.10275281718350016, 0.12601608177646995, 0.15614322532201186, 0.14899567526299506, 0.20818069082451984, 0.10733197967056185, 0.10974984485073946, 0.17931922076968476, 0.12213493144372478, 0.11927203740924597, 0.1265394443180412, 0.06664552187430672, 0.11065548023907468, 0.11157358370837756, 0.12687683949479833, 0.12140404956880957, 0.15307052613934502, 0.09119566311710514, 0.08633177567389794, 0.10051963545265608, 0.17147559556178749, 0.17594690172700211, 0.14743413717951626, 0.13219757820479572, 0.1633336566737853, 0.2603338868357241, 0.13805808092001826, 0.11672116452245973, 0.22858902462758124, 0.2301642033853568, 0.14652080571977422, 0.15127573104109615, 0.11020632504369132, 0.09797648090170696, 0.21672037633834407, 0.1087049677153118, 0.10755009687272832, 0.1370809247600846, 0.19964294973760843, 0.16727275389712304, 0.10835141598363407, 0.08907606708817184, 0.17164373653940856, 0.1963977754348889, 0.17514719307655469, 0.15178911911789328, 0.1060060660529416, 0.13449491118080914, 0.16012634674552828, 0.09646544596762396, 0.16290549683617428, 0.12145717249950394, 0.15092053916305304, 0.16413066390668973, 0.14123549713985994, 0.10629077616613358, 0.0875864208501298, 0.13994893961353227, 0.22666237957309932, 0.16752594499848783, 0.12882594193797559, 0.10473141257534735, 0.12565630342578515, 0.164445809496101, 0.1252306075184606, 0.2234272687928751, 0.08155951378284954, 0.130848131084349, 0.09645513753639534, 0.13039882003795356, 0.12483821919886395, 0.10919408756308258, 0.19145689759170637, 0.2010634055477567, 0.08328140029334463, 0.14861257863231003, 0.2349583586328663, 0.0557780233793892, 0.1240555131516885, 0.05121203401358798, 0.29027360840700567, 0.14029473590198904, 0.13413401960860938, 0.11260336556006223, 0.1040254149120301, 0.08754731708904728, 0.1324006446520798, 0.09513326120213605, 0.14606819953769445, 0.18459456972777843, 0.1547447222401388, 0.11469346121884882, 0.1431260144454427, 0.11678501148708165, 0.09933392095263116, 0.13981196883833036, 0.1357257631025277, 0.14172774885082617, 0.1360346598085016, 0.15916758100502193, 0.12198375596199185, 0.10614953062031418, 0.08827172001474537, 0.10708237314247526, 0.14680389052955434, 0.1740290882298723, 0.18576017202576622, 0.15285006375052035, 0.18835541792213917, 0.1047432646737434, 0.1356685732025653, 0.10365437075961381, 0.09715366919408552, 0.12647458061110228, 0.13215190643677488, 0.1336988538969308, 0.20438620849745348, 0.1268431608332321, 0.17639079509535804, 0.11469493809272535, 0.11052174522774294, 0.2325468833441846, 0.1909397542476654, 0.11906762767466716], [0.017409929168934468, 0.04269967808795627, 0.039641083421884105, 0.013633919825224439, 0.07624755467986688, 0.03674188723380212, 0.02666850901732687, 0.027653019860736094, 0.031118400511331856, 0.10532510845223442, 0.044098908474552445, 0.03421198001888115, 0.057037084334297106, 0.01964087332453346, 0.03544751489243936, 0.025779440220503602, 0.013940252410975518, 0.032204763701884076, 0.060658015427179635, 0.016091394354589283, 0.008932201853895094, 0.04532295119133778, 0.05456663799122907, 0.029176253847253975, 0.031444184787687846, 0.03081733902945416, 0.010836216042662272, 0.03667609584226739, 0.022656900255242363, 0.045468861135304905, 0.032135105720954016, 0.03300430907984264, 0.0449236423446564, 0.019361471422598697, 0.02124439470208017, 0.022594478214159608, 0.05530105991056189, 0.0408608847646974, 0.07199148618383333, 0.07556541706435382, 0.032127439335454255, 0.05694863146345597, 0.020653374267567415, 0.008530301056453027, 0.017911242503032554, 0.027854396066686604, 0.08307727257488295, 0.051514195729396306, 0.03876334536471404, 0.039578702198923565, 0.0006904091412707203, 0.06953237985726446, 0.047760130764800124, 0.06377637895639054, 0.032894775504246354, 0.008089367001957726, 0.06955385761102661, 0.07520099286921322, 0.034435670750099234, 0.010503848916414427, 0.005696674079445074, 0.031085605005500838, 0.04928266156639438, 0.04977501717803534, 0.08165323961293325, 0.015657026451663114, 0.02233045917819254, 0.04795302607817575, 0.03491625589958858, 0.023344815490418114, 0.06463629804784432, 0.06511723200674169, 0.009513381410215516, 0.05494888115208596, 0.014534152378473664, 0.036283072986407205, 0.05832930815813597, 0.04904062865534797, 0.022023234159860294, 0.030456527238129638, 0.05903722056245897, 0.045025379658909515, 0.07202064516604878, 0.04244774863764178, 0.014432929929171223, 0.04600678461429197, 0.03016686885530362, 0.02017221209825948, 0.051844488552887924, 0.04606893206073437, 0.04757569964567665, 0.03961118600273039, 0.0185822942876257, 0.057726684244698845, 0.04575868464598898, 0.040898882725741714, 0.0034664319491639617, 0.02927146211732179, 0.04649385613447521, 0.002512089640731574, 0.08077913065790199, 0.01875801259302534, 0.022857452677271795, 0.042086118628503755, 0.007270501200764556, 0.008940559364418732, 0.04555722123768646, 0.052641547736129723, 0.016951909019553568, 0.09028515924001113, 0.011449447101767873, 0.018399740802124143, 0.036980914446758106, 0.027591200814640615, 0.09734645689604804, 0.038030129435355775, 0.038132631161715835, 0.024381514158449136, 0.05320821459463332, 0.022267246749834158, 0.0465015373629285, 0.04168287639913615, 0.045002933402429335, 0.025021321525855456, 0.049957967712543905, 0.040228207581094466, 0.017440062219975516, 0.06500841089291498, 0.04213588705169968, 0.02971991041704314, 0.04929147457005456, 0.0302466367429588, 0.022589366672036704, 0.0174710283317836, 0.033206640800926834, 0.046906542193028145, 0.03590314903703984, 0.022984628958511166, 0.02047897327429382, 0.019701762830663938, 0.04026672504551243, 0.045165704941609874, 0.08488744497299194, 0.035420200147200376, 0.07400292161037214, 0.03195740959199611, 0.057843242248054594, 0.10076210994157009, 0.027182067788089626, 0.03984704795584548, 0.0817839169758372, 0.0247687204318936, 0.022707874668412842, 0.02300984528119443, 0.02651534457982052, 0.027433720788394567, 0.006776843583793379, 0.05510414586751722, 0.055673866663710214, 0.04011756449472159, 0.0245634460952715, 0.0452001368830679, 0.022125932555354666, 0.05126685275172349, 0.03993874772277195, 0.05758418075856753, 0.0313044532231288, 0.03829680907074362, 0.053308979695430025, 0.032520046588615514, 0.03676619628095068, 0.030214843136491254, 0.015932320566207636, 0.04191980704490561, 0.039491050847573206, 0.04979077297321055, 0.023183424345916137, 0.05975979409413412, 0.0340100379253272, 0.04037196529679932, 0.04349511938926298, 0.0696970772696659, 0.05538962781429291, 0.07649799983482808, 0.02640953844093019, 0.023415154391841497, 0.09292934977565892, 0.023325903712247964, 0.033623820563661866, 0.05678819397871848, 0.0743625515315216, 0.02360634462093003, 0.09489826014032587, 0.029525734898925293, 0.032353534625144675, 0.03159490384859964, 0.0033082137179007987, 0.027277559929643758, 0.01947958422533702, 0.03431417004321702, 0.04626331909094006, 0.12284921889659017, 0.030484938506560866, 0.019553331439965405, 0.03338317917950917, 0.06649430186371319, 0.021358468366088346, 0.041591317640268244, 0.08482614357490093, 0.01015691250358941, 0.007180196671470185, 0.041839380501187406, 0.05353126034606248, 0.03026287678949302, 0.040962217608466744, 0.018520308258302975, 0.04227752593578771, 0.030227971728891134, 0.04492538268095814, 0.02549178563640453, 0.0029788989058943116, 0.05504445121914614, 0.04620349456672557, 0.0536079650191823, 0.003909603346983204, 0.03155725840770174, 0.02368474510149099, 0.03409036056837067, 0.033665889204712585, 0.038990472239675, 0.026743324924609624, 0.043412484956206754, 0.002649616562848678, 0.035305842611705884, 0.017759996517270338, 0.009694987729744753, 0.03547447340679355, 0.03482164320303127, 0.02315480898687383, 0.041818630052148364, 0.060603805250138976, 0.04576526007440407, 0.02547418189351447, 0.009017481115733972, 0.02301260978128994, 0.03163718029099982, 0.08454721479211003, 0.011904736147698713, 0.03341017109050881, 0.05030790147429798, 0.034668515872908756, 0.03684298259031493, 0.05836943237227388, 0.1069866212492343, 0.033272777291131206, 0.022674828687740956, 0.027433763461885974, 0.009289566369261593, 0.11194485050509684, 0.05481587715621572, 0.018190518239862286, 0.03703037858940661, 0.027206146769458428, 0.02225781776360236, 0.04690991154348012, 0.07544727457570843, 0.026951875843224116, 0.05900309290154837, 0.07292714886716567, 0.021749596890003886, 0.05103900970425457, 0.03847503954602871, 0.04543721224763431, 0.015100618857104564, 0.023863187088863924, 0.009601712754374603, 0.031729254842502996, 0.05884426958800759, 0.01865999529400142, 0.049634651077212766, 0.06664865373750217, 0.03083694100496359, 0.05569438333623111, 0.03620617535489146, 0.0071357443448505364, 0.01847284976975061, 0.04443510879355017, 0.02140611053619068, 0.05363134638173506, 0.04041000778670423, 0.06120556456153281, 0.009433236882614437, 0.027702689949364867, 0.042433536509633996, 0.017292541815550067, 0.005313814008331974, 0.02358003919653129, 0.038769338207202964, 0.03553986403858289, 0.039667982564424165, 0.08016147825401276, 0.023133158683776855, 0.041502300737192854, 0.043084737699246034, 0.042877337109530345, 0.04264495953975711, 0.03531519367243163, 0.01597664533619536, 0.037043247430119663, 0.05023002049711067, 0.018549728847574443, 0.0422777485800907, 0.046458344368147664, 0.009537737769278465, 0.046494483249261975, 0.032493778271600604, 0.0838169117923826, 0.034012653995887376, 0.032999859904521145, 0.03135807710350491, 0.060606339684454724, 0.10967108813929372, 0.047899045966914855, 0.05985606178001035, 0.061140340912970714, 0.028523872642836068, 0.03934101085178554, 0.02967430729768239, 0.06109227200795431, 0.045802552995155565, 0.042128142740693875, 0.021680497375200503, 0.037975837622070685, 0.03568483887647744, 0.026119594331248663, 0.017341113525617402, 0.011075583715864923, 0.038726156344637275, 0.042595354389050044, 0.015479744997719536, 0.012223314170114463, 0.02408157703030156, 0.03523437007970642, 0.025359687060699798, 0.020175043391645886, 0.05068959544587415, 0.02048605150775984, 0.026364612531324383, 0.051065333682345226, 0.026406556862639263, 0.04226882054354064, 0.02266259067255305, 0.15488491393625736, 0.14258917450206354, 0.08239735398092307, 0.09103784541366622, 0.08264917210908607, 0.21186796249821782, 0.09992068517021835, 0.12030799392960034, 0.10349049713113345, 0.21988205902744085, 0.16842400305904448, 0.18515518808271736, 0.13204506685724482, 0.12470697780372575, 0.13044915249338374, 0.14792727946769446, 0.2519077796023339, 0.11860867612995207, 0.18768663896480575, 0.14531540946336463, 0.14178128738421947, 0.1124855421949178, 0.17293103621341288, 0.17125722602941096, 0.11365271784598008, 0.2135258461930789, 0.08814108718070202, 0.13662716082762927, 0.09339219759567641, 0.2123322946135886, 0.14411592070246115, 0.11499601998366416, 0.09601843557902612, 0.13764801464276388, 0.16530560242244974, 0.15625377563992515, 0.17421578289940953, 0.09066853046533652, 0.1403780048713088, 0.15459975111298263, 0.15352285030530766, 0.15059118886711076, 0.10529660998145118, 0.0940990932576824, 0.12790489214239642, 0.09005744606838562, 0.20004005811642855, 0.13458628440275788, 0.17570583731867373, 0.16960608103545383, 0.10003424118622206, 0.23034258600091562, 0.10352115525165573, 0.12951827666256577, 0.11543644010089338, 0.09102417505346239, 0.2026586519787088, 0.169359183346387, 0.0830408776528202, 0.0989372430194635, 0.15055550640681759, 0.12536551512312144, 0.154041062342003, 0.16305469820508733, 0.14533329522237182, 0.10506980965146795, 0.1642608069232665, 0.12216201241244562, 0.04533939347311389, 0.14133023971226066, 0.2446233032969758, 0.1654197002062574, 0.10826857003849, 0.10833895532414317, 0.0630985977477394, 0.12376183789456263, 0.16920947731705382, 0.23369415459455922, 0.13670714950421825, 0.08622327368357219, 0.10641832166584209, 0.11616865784162655, 0.13438263908028603, 0.10736529467976652, 0.08007035736227408, 0.18244686856633052, 0.11883405153639615, 0.12627523974515498, 0.1613722345791757, 0.17335555952740833, 0.16028521087719128, 0.13198861910495907, 0.15910970832919702, 0.14502034639008343, 0.17037420388078317, 0.22579163254704326, 0.1710993712185882, 0.23287737654754892, 0.1784088579006493, 0.09768164789420553, 0.22963235067436472, 0.16960654116701335, 0.11012310802470893, 0.13718804635573179, 0.19321264087921008, 0.1722489728126675, 0.11087072532973252, 0.11453601458924823, 0.07318983203731477, 0.1376075527514331, 0.14896849781507626, 0.14597793953726068, 0.15273348719347268, 0.12825071811676025, 0.2602434338768944, 0.07899216521764174, 0.11880560501595028, 0.19241446105297655, 0.1249577198177576, 0.08232932130340487, 0.1437943332712166, 0.11236315462156199, 0.15744465548777953, 0.12303543859161437, 0.25522393290884793, 0.1439884939463809, 0.08625283342553303, 0.08005676121683791, 0.19905490160454065, 0.11572066781809554, 0.09078164119273424, 0.11247616886976175, 0.12007415061816573, 0.10275855398504063, 0.1107846807281021, 0.12561932962853462, 0.13311509537743405, 0.11018987162970006, 0.09772701538167894, 0.12732472561765462, 0.2178408412146382, 0.10977673286106437, 0.14882054325425997, 0.09131915649049915, 0.1659886899869889, 0.14964452013373375, 0.13636268908157945, 0.12264602628420107, 0.1368467029533349, 0.13962791621452197, 0.1473530798102729, 0.11639450822258368, 0.19145001046126708, 0.23063132597599179, 0.20264005375793204, 0.12212482339236885, 0.14024250354850665, 0.1716081431368366, 0.10137680859770626, 0.1552034734049812, 0.1767391146859154, 0.19127473002299666, 0.1380494423210621, 0.10686697220080532, 0.11013844079570845, 0.11888496286701411, 0.1335032089264132, 0.13760348578216508, 0.17907112080138177, 0.13393930974416435, 0.1482168209622614, 0.14567339181667194, 0.11764340175432153, 0.11714982902049087, 0.1701457708259113, 0.14595842105336487], [0.017612550327612553, 0.014302279469120549, 0.045426777651300654, 0.017444570767111145, 0.11104631004855037, 0.01661406484345207, 0.07492300661397167, 0.060336914102663286, 0.06245598691748455, 0.05888507286726963, 0.03774870703637134, 0.04337785634561442, 0.14007001358550042, 0.023675291995459702, 0.03514341988193337, 0.02738765011599753, 0.05463360568683129, 0.027397383382776752, 0.04588637857523281, 0.03815923344518524, 0.07413512779748999, 0.05242028753855266, 0.0309884541638894, 0.05739661035477184, 0.06375095297698863, 0.06050755240721628, 0.03603611963626463, 0.01575897156726569, 0.02261132867715787, 0.07008712782408111, 0.0342213756084675, 0.050248993502464145, 0.005227832953096367, 0.038281390952761285, 0.03345555342093576, 0.021228058176347986, 0.02588493280200055, 0.01248638604010921, 0.026618106057867408, 0.05134508995979559, 0.018988781557709444, 0.0529416611243505, 0.055446669284719974, 0.0302010892846738, 0.02184495173423784, 0.07189423515228555, 0.0355704479443375, 0.02373793482547626, 0.03345066637848504, 0.03130011165922042, 0.035733430995605886, 0.03903321994584985, 0.0408819320728071, 0.05891003500437364, 0.031527657847618684, 0.03361106304510031, 0.06250406324397773, 0.05516231540241279, 0.0632274271629285, 0.05792530151666142, 0.030066682629694697, 0.02196904068114236, 0.034103196012438275, 0.06790526560507715, 0.029749319874099456, 0.04555201878247317, 0.07833007301087491, 0.045780704167555086, 0.031410639712703414, 0.0599769353721058, 0.04500815812207293, 0.0433111112943152, 0.014094189609750174, 0.042317215993534774, 0.05188569630263373, 0.03401296940864995, 0.04803464005817659, 0.033621605252847075, 0.04311128803237807, 0.048033760613179766, 0.04498391215747688, 0.04657749246689491, 0.06227392324944958, 0.051029847891186364, 0.010037316333182389, 0.02025828081968939, 0.010669331149983918, 0.07320034084841609, 0.0068340831148816505, 0.05159034008102026, 0.04317973260185681, 0.029232256310933735, 0.01077312050256296, 0.06395764110493474, 0.03908420549123548, 0.07337842660490423, 0.010060821077786386, 0.05891258428164292, 0.03404914168640971, 0.05013877715100534, 0.03652520237665158, 0.06990528680034913, 0.032916431373450905, 0.08933910648920573, 0.08543133531929925, 0.025619726329750847, 0.03269586137321312, 0.03276930430729408, 0.08412652838160284, 0.025220204115612432, 0.040128162363544106, 0.019961683356086724, 0.03891045387717895, 0.012138753863837337, 0.05657182453433052, 0.050575649802340195, 0.01989935593883274, 0.007685778282393585, 0.04332310811150819, 0.07113272484275512, 0.05814885123982094, 0.05215846154897008, 0.03310848434921354, 0.026059884839924052, 0.021490889776032418, 0.05482718006533105, 0.03130633085675072, 0.039272781505133025, 0.08369882125407457, 0.006566792599187465, 0.026242169296892826, 0.01409544755006209, 0.05316363007295877, 0.014682136625197018, 0.029783595964545384, 0.04037652208353393, 0.03205120963684749, 0.10980109756928869, 0.028108388687542174, 0.06410872010746971, 0.01788330435374519, 0.06929156035766937, 0.09198154555633664, 0.033663365902611986, 0.06596575170988217, 0.041138370070257224, 0.023361767998721916, 0.08924575915443711, 0.010440760797791881, 0.025505159137537703, 0.014487626212940086, 0.013125512487022206, 0.07115163476555608, 0.0330889287579339, 0.03871018532663584, 0.07146960793761536, 0.02481596740835812, 0.0459736922493903, 0.020167293514532503, 0.01493355677666841, 0.018473226409696508, 0.049621630096226, 0.055717464128974825, 0.020813472219742835, 0.03233492527215276, 0.014588643643946853, 0.044929590658284724, 0.04192468666587956, 0.04585295595461503, 0.06414507050067186, 0.06378326608682983, 0.01818844579247525, 0.054140303836902604, 0.032621308928355575, 0.049099777825176716, 0.0054201878901949385, 0.06096490833442658, 0.010150158959731925, 0.05167955365322996, 0.029491948625945952, 0.09788559007574804, 0.015569195129501168, 0.04601805783750024, 0.004177674045422464, 0.055139820906333625, 0.0301750399012235, 0.036376680072862655, 0.055263414469663985, 0.053424368816195056, 0.048486489249626175, 0.05143366157426499, 0.032005430257413536, 0.012517501509137219, 0.0695570265816059, 0.06304509632172994, 0.037180745130172, 0.10077236642246135, 0.021681796133634634, 0.009655163157731295, 0.009516229401924647, 0.03800237682298757, 0.016175398050108925, 0.03536417170835193, 0.01566155355249066, 0.02756015492195729, 0.022896584268892184, 0.046774217262282036, 0.024437388601654675, 0.021169486026337836, 0.06687002896796912, 0.00940111394811538, 0.04719252508948557, 0.018779800193442497, 0.02912446863774676, 0.01760661500156857, 0.025955271703423932, 0.023123848441173322, 0.024205569498008117, 0.08810991697828285, 0.02886243113607634, 0.028528986040328164, 0.039415437131538056, 0.023498657137679402, 0.0449106955784373, 0.0537581534445053, 0.0477177318680333, 0.06940355786355212, 0.024049827952694613, 0.018689321259444114, 0.024545480555389076, 0.017389737186022103, 0.027642941495287232, 0.049844333771034144, 0.05007177976949606, 0.05417647982540075, 0.06095529010053724, 0.0492570500500733, 0.046977599122328684, 0.03251198315410875, 0.07475109552615322, 0.054121152716106735, 0.07705556796281599, 0.04078314479556866, 0.02038784125033999, 0.06180003969348036, 0.06362477302900515, 0.05168824420252349, 0.056920329661807045, 0.030447849676420446, 0.03907271704520099, 0.007411061187667656, 0.008295823208754882, 0.0861023629840929, 0.006592876770810108, 0.03832589012745302, 0.0255189482413698, 0.02200885133788688, 0.04576441031531431, 0.07421486414386891, 0.023175826609076466, 0.04029281153634656, 0.022930953127797693, 0.025685287655505817, 0.02333349773834925, 0.02709730153583223, 0.03713481732120272, 0.0065667049329931615, 0.0293541670544073, 0.035480952356010675, 0.06588131014723331, 0.049051946407416835, 0.016128666866279673, 0.007395821185127716, 0.050386231450829655, 0.0423069409589516, 0.018728384202404413, 0.05307771534717176, 0.04796673354576342, 0.015774128078192007, 0.038270407167146914, 0.06115178854088299, 0.01432233508239733, 0.04046526439196896, 0.019029425275221, 0.035183028303436004, 0.046883624672773294, 0.024870758315955754, 0.02196504607127281, 0.0670034893846605, 0.10108256930834614, 0.09960661569493823, 0.03617692731495481, 0.022250502042879816, 0.0401773407793371, 0.04882980305410456, 0.029995172990311403, 0.04333825534558855, 0.05882163779460825, 0.11227912124013528, 0.012484806193242548, 0.037199595681158826, 0.08286912983749062, 0.07034834154183045, 0.013641871937579708, 0.11334401409840211, 0.028467738447943702, 0.011681308878905838, 0.05839447243488394, 0.08333009260240942, 0.044111027746112086, 0.04388252789794933, 0.029499384945665952, 0.036815088969888166, 0.0793519509898033, 0.02005970622121822, 0.07544226507889107, 0.025250506005249918, 0.04956053278874606, 0.03635700202721637, 0.03686440839373972, 0.07021515571977943, 0.06760252872481942, 0.04302379995351657, 0.038106203282950446, 0.05268185006571002, 0.02835891176800942, 0.048634918784955516, 0.007851286027289461, 0.03856990457279608, 0.051974486850667745, 0.02361624672630569, 0.004527058617895818, 0.0655257397738751, 0.027276509790681303, 0.017291910990024917, 0.057034720593946986, 0.035416251921560615, 0.014023987077962374, 0.02130941426003119, 0.011704116932378383, 0.04793469503056258, 0.029080887870804872, 0.03267383071943186, 0.011560431576072006, 0.023534289503004402, 0.026417813387524802, 0.04312303994083777, 0.019582351269491483, 0.07112306950148195, 0.01355215741568827, 0.03532896051183343, 0.04829628793231677, 0.12331474586972035, 0.141848451748956, 0.311291022808291, 0.08208179278881289, 0.20069056539796293, 0.09711832812172361, 0.1976718648802489, 0.08982235594885424, 0.12241365242516622, 0.18251769914058968, 0.1696601984440349, 0.1704091441933997, 0.1666159532032907, 0.12044474948197603, 0.08877054715412669, 0.10009281890233979, 0.17279645515372977, 0.17180911672767252, 0.11046423620427959, 0.29434986936394125, 0.22188247356098145, 0.1840016382629983, 0.09102715106564574, 0.14461799844866619, 0.11616863557719626, 0.1108862659020815, 0.1694956494611688, 0.06346043184748851, 0.10471879606484435, 0.16921056085266173, 0.15445099503267556, 0.09344922422314994, 0.11233395853196271, 0.14533034147461876, 0.12708575406577438, 0.1029828235914465, 0.14408668008400127, 0.13752156752161682, 0.13079506752546877, 0.22577296011149883, 0.10228247367194854, 0.1033314029336907, 0.18673293467145413, 0.10841357827303, 0.13497663923772052, 0.13317580305738375, 0.12688483984675258, 0.1313800283242017, 0.11793098397902213, 0.20214613963617012, 0.1465301716234535, 0.11839561295346357, 0.18636713008163497, 0.2128056512447074, 0.08517447800841182, 0.16331629041815177, 0.0881317286984995, 0.1725881639868021, 0.19886039954144508, 0.1627536237356253, 0.1852366462117061, 0.157665474107489, 0.14758877106942236, 0.18494254793040454, 0.14279644150519744, 0.17524294496979564, 0.12417245336109772, 0.11603461112827063, 0.1072844302689191, 0.17198344721691683, 0.23699124954873696, 0.15197768399957567, 0.11659394556772895, 0.12844186567235738, 0.06023176661983598, 0.16111044940771535, 0.15351851616287604, 0.09574230469297618, 0.14185780280968174, 0.19693247799295932, 0.06626930495258421, 0.12032141195959412, 0.10533284905250184, 0.1262852587387897, 0.15563917346298695, 0.0982219833531417, 0.10762320584035479, 0.1977752460516058, 0.12432897972757928, 0.2078485648962669, 0.1458313356852159, 0.12110584721085615, 0.16164504806511104, 0.23962519102497026, 0.12175876647233963, 0.20026209385832772, 0.09690482707810588, 0.13698103168280795, 0.08885116665624082, 0.14145883906167, 0.19364258187124506, 0.17851263983175159, 0.10020342117059045, 0.19071984104812145, 0.1244101781048812, 0.11722264112904668, 0.19457296788459644, 0.11290524154901505, 0.25147252483293414, 0.1349783907062374, 0.09487816278124228, 0.14488456305116415, 0.1912147644907236, 0.2197347130277194, 0.16241564968368039, 0.19358576304512098, 0.14019151800312102, 0.08198218914913014, 0.11482580841402523, 0.21035579207818955, 0.20690079778432846, 0.19127563544316217, 0.28069533174857497, 0.10943663626676425, 0.09859780693659559, 0.23900221742223948, 0.18284007324837148, 0.15864408487686887, 0.2533267956459895, 0.088378255313728, 0.061333273333730176, 0.15351297974120826, 0.14246986684156582, 0.1140596967888996, 0.09372920685564168, 0.1178513366903644, 0.18659206019947305, 0.1683550130110234, 0.08193360074074008, 0.1482380018569529, 0.10435537376906723, 0.16173401672858745, 0.1298925417358987, 0.1677130107418634, 0.15846478199819103, 0.16318395064445212, 0.1102432023617439, 0.14327526034321636, 0.07530540562584065, 0.10015844702138565, 0.12500668672146276, 0.08054713529418223, 0.16562689299462363, 0.08423451086855493, 0.15438093629200011, 0.18640870519448072, 0.11311921756714582, 0.07941410585772246, 0.13731427083257586, 0.07006234009168111, 0.07651162566617131, 0.1334497149218805, 0.15890209993813187, 0.08459731718176045, 0.1538120355689898, 0.1040850167919416, 0.1798616416635923, 0.16392250632634386, 0.11876680553541519, 0.16035072767408565, 0.07641686825081706, 0.14531272288877517, 0.14797292154980823, 0.1384060739655979, 0.16290718893287703, 0.13706847152207047], [0.03188859023794066, 0.013877698638680158, 0.005319895908542094, 0.009396137847943464, 0.04040163265017327, 0.033097081250161864, 0.029573621977760922, 0.04350873037765268, 0.02697023101063678, 0.04898811057501007, 0.06344648689264432, 0.06842629038146697, 0.01570656295371009, 0.05431680881883949, 0.03209339702152647, 0.03864056445308961, 0.08206626705941744, 0.024563459082855843, 0.030540178413502872, 0.015394342353829416, 0.03703488713654224, 0.033487257969682105, 0.04221851777401753, 0.06835877720732242, 0.05827631139254663, 0.038167000020621344, 0.05351600550056901, 0.04866483846853953, 0.040385550310020335, 0.04156762828642968, 0.04367736117274035, 0.079923285957193, 0.029692719981539994, 0.05703991562768351, 0.041352795087732375, 0.04727435429231264, 0.0221860799138085, 0.009733354909258196, 0.024301158118760213, 0.03428421696298756, 0.014074173886911012, 0.01799587145796977, 0.04188530831015669, 0.027104086620965973, 0.012573213607538491, 0.0645812603761442, 0.081360180338379, 0.03509807094815187, 0.05324556688719895, 0.02031285835982999, 0.02815886771713849, 0.05862567370058969, 0.02004593381570885, 0.022351384031935595, 0.014352431953739142, 0.0098201555738342, 0.07213774864794686, 0.020739329811476637, 0.05713989776268136, 0.06096778786741197, 0.0533502171310829, 0.026369584920757916, 0.02840569675754523, 0.07280348479980603, 0.016843514640640933, 0.009468858115724288, 0.03661723982077092, 0.04472083193832077, 0.03201561252353713, 0.04001098837761674, 0.03095333573583048, 0.04992980320821516, 0.015940732810122427, 0.006955959070182871, 0.06478182578575797, 0.008969483642431442, 0.029112137854099274, 0.08820355375064537, 0.009796085869311355, 0.0526208381052129, 0.048705779045121744, 0.07752564430120401, 0.04425950552104041, 0.02487141697201878, 0.05424065704573877, 0.05872252397239208, 0.01565610247780569, 0.04313132601964753, 0.03136783263471443, 0.02326391768292524, 0.04398913370096125, 0.04233060804835986, 0.02870920732675586, 0.038552252590307035, 0.04995522918761708, 0.013050215111434227, 0.06837680397438817, 0.02367966324527515, 0.00909164764379966, 0.05070554791018367, 0.04327892806031741, 0.04002529698482249, 0.053329062211560085, 0.029734415693383198, 0.10495278038433753, 0.059982679595123045, 0.10464055885677226, 0.044050516735296696, 0.05050387670053169, 0.0184350725976401, 0.07588165361084975, 0.013608125555037986, 0.03556312665750738, 0.012658220130106201, 0.04714991096989252, 0.027350288546585944, 0.010109531012858497, 0.0145287439772801, 0.1583447915618308, 0.031557792754028924, 0.04588643052557018, 0.04965034378983546, 0.07113639105227776, 0.07846483960747719, 0.009267577461287146, 0.034330107664573006, 0.03616512716689613, 0.08002680813660845, 0.020014988112961873, 0.04420312456204556, 0.012200133187434403, 0.0686706202395726, 0.011898444590769941, 0.008378777692996664, 0.025245246033591684, 0.024091278755804524, 0.03949362610001117, 0.03498659294564277, 0.03708499323693104, 0.05544346320675686, 0.013671652468474349, 0.019949246816395316, 0.033896207314683124, 0.030536638369085267, 0.02876587586797541, 0.03989279764937237, 0.03645024546131026, 0.01882042535726214, 0.09369725739816204, 0.04610690775734838, 0.0204999593552202, 0.07151230369345285, 0.050857966489274986, 0.06801301060477272, 0.036485067030298524, 0.04825238989724312, 0.01858391402492998, 0.05731866629503202, 0.020607238657248672, 0.048783689708216116, 0.02468598209816264, 0.08519216338754632, 0.0301527086776332, 0.03915344786946662, 0.0615369706065394, 0.04635197976313066, 0.06805808865465224, 0.025129459863819648, 0.022491546042147093, 0.020107589589315467, 0.029293971456354484, 0.020166837093711365, 0.005655400927935261, 0.05692222955985926, 0.047959018920664676, 0.07082808064296842, 0.03342688796692528, 0.044222457509022206, 0.03776523837586865, 0.017945054751180578, 0.08347790615516715, 0.02312400429218542, 0.02054969809250906, 0.05971812250209041, 0.13364121870836243, 0.03195416269591078, 0.03860224736854434, 0.03686665710119996, 0.031153081072261557, 0.06910122174303979, 0.04227900652040262, 0.07575801922939718, 0.07200690059107728, 0.038518158326041885, 0.024456229875795543, 0.04414869916217867, 0.05528133362531662, 0.03853569898637943, 0.025468357889621984, 0.08935458768974058, 0.056465934903826565, 0.007619586594955763, 0.018403108297206927, 0.052307443984318525, 0.04013811456388794, 0.03279663389548659, 0.020360212947707623, 0.089314437500434, 0.021005931521358434, 0.04660445840272587, 0.035677933192346245, 0.04747675651742611, 0.0327257884782739, 0.07125562449800782, 0.04698793723946437, 0.04650425362342503, 0.03004410278663272, 0.07051986671285704, 0.06386900640791282, 0.034310229239054024, 0.030058684133109637, 0.0063458185923082056, 0.029024660907452926, 0.01095442996302154, 0.06589088385226205, 0.0354452253668569, 0.07223931897897273, 0.026465785813343246, 0.03928761332645081, 0.059501270661712624, 0.026867599408433307, 0.07643021948751993, 0.023824454401619732, 0.01733828965370776, 0.05682552400685381, 0.022641354116785806, 0.024951379673439078, 0.006926242085683043, 0.0241058025858365, 0.024468221126880962, 0.06171684122818988, 0.014238931598811178, 0.03943812829675153, 0.03810713838902302, 0.05056800197053235, 0.004424526741786394, 0.06461271259468049, 0.02798803830955876, 0.03496859957522247, 0.08575027328333817, 0.05370349797885865, 0.016123746427183505, 0.03089419027674012, 0.05711372221412603, 0.04959098310791887, 0.035932705068262294, 0.029982298583490774, 0.054360710564651527, 0.039715643288218416, 0.09679235459771007, 0.05195673096750397, 0.01536931249574991, 0.036027759342687204, 0.019982146222901065, 0.05313052286510356, 0.14051819656742737, 0.03167754941387102, 0.05962892377283424, 0.055712462053634226, 0.0370988342911005, 0.040056366997305304, 0.03523480052535888, 0.06846238844445907, 0.027302724301989656, 0.034451289247954264, 0.05584150298091117, 0.044138349912827834, 0.03280054130300414, 0.039346881239907816, 0.05497514946910087, 0.04411751782754436, 0.008478914751322009, 0.039272837166208774, 0.0063737924574525096, 0.03615216184698511, 0.03415565843170043, 0.04920845793094486, 0.03242699611291755, 0.06279270673985593, 0.032622744984109886, 0.06237613924895413, 0.04122745005588513, 0.0065055867526098154, 0.046191753790481016, 0.045581771482829936, 0.027784843841800466, 0.05522876730537973, 0.028310761226748582, 0.06474540859926492, 0.05868310108780861, 0.04549436875095125, 0.014637827625847422, 0.025729120752657764, 0.022443362104240805, 0.01393432728946209, 0.054258999225567095, 0.07526478788349777, 0.07089590551913716, 0.045363732206169516, 0.06903708534082398, 0.02332533782464452, 0.01757640959112905, 0.051659593591466546, 0.061447500993381254, 0.041998181550297886, 0.06576692292583175, 0.010768431984615745, 0.02717709168791771, 0.08198436364182271, 0.037842006131540984, 0.0106652187241707, 0.05408325494499877, 0.03139558153634425, 0.019019666033273097, 0.03511450209771283, 0.037131874705664814, 0.010086169131682254, 0.011701905332301976, 0.042779484938364476, 0.0535497361124726, 0.05745052367274184, 0.018987440125783905, 0.05270240013487637, 0.1078655244782567, 0.020572172179527115, 0.02990458087879233, 0.03655384927697014, 0.033967575946007855, 0.02000017855607439, 0.02310398300323868, 0.028931773704243824, 0.028176593914395198, 0.059309844800736755, 0.01967896219866816, 0.03458761806541588, 0.04666121043555904, 0.06465700396802276, 0.07367310376139358, 0.03788897294725757, 0.0331950299005257, 0.06411617869162001, 0.028803912791772746, 0.21154915069928393, 0.06468272680649534, 0.1026696150074713, 0.07295628558495082, 0.19456760957837105, 0.19401089492021129, 0.16449048678623512, 0.07670122213312425, 0.1674265565816313, 0.10956450831145048, 0.13979659153847024, 0.27218224480748177, 0.095302582194563, 0.11820733750937507, 0.12681405380135402, 0.1766184563166462, 0.20825686486205086, 0.10462337813805789, 0.0766707347065676, 0.09654553112341091, 0.20688947261078283, 0.1137809906504117, 0.06839202542323619, 0.1628292931127362, 0.14919240376912057, 0.12002884250250645, 0.14002673153299838, 0.17241769266547635, 0.1840731961419806, 0.16580972849624231, 0.13177740387618542, 0.2569550962653011, 0.11289623187622055, 0.11910446046385914, 0.1155817971448414, 0.19350503222085536, 0.14829064981313422, 0.17643247410887852, 0.18849249259801582, 0.1207098965824116, 0.07383779375231825, 0.234865382371936, 0.1877581374719739, 0.24447520030662417, 0.10075808750116266, 0.10120758408447728, 0.23053728102240711, 0.12775350885931402, 0.16643694718368351, 0.09204682486597449, 0.2170859879697673, 0.08554865402402356, 0.09128859484917484, 0.17179363552713767, 0.12218343821587041, 0.13165867509087548, 0.13450153113808483, 0.1312860575853847, 0.1455223053926602, 0.09859291618340649, 0.10724664010922424, 0.09357866219943389, 0.0889773688686546, 0.18251339468406513, 0.1384063856676221, 0.11063818819820881, 0.16797433578176424, 0.16149525297805667, 0.12011136932414956, 0.20606188889360055, 0.14045717718545347, 0.11276234101387672, 0.1263919795746915, 0.1614993199473247, 0.1863557900651358, 0.17870424751890823, 0.14641643007053062, 0.14827999257249758, 0.18919837893918157, 0.1580235900473781, 0.1258125255117193, 0.1896106865024194, 0.08544000360416248, 0.12904900184366852, 0.17979483352974057, 0.12287238874705508, 0.12920878623845056, 0.13303221232490614, 0.13559771294239908, 0.22133565915282816, 0.10192630958044901, 0.1134711439954117, 0.15604949207045138, 0.18188552290666848, 0.2651208877796307, 0.13890735019231215, 0.19216774147935212, 0.1521661301376298, 0.19703988160472363, 0.15767225733725354, 0.17128548701293766, 0.18096849555149674, 0.1494235233985819, 0.10901782006840222, 0.19342602317919955, 0.09842726140050218, 0.23186470119981095, 0.15990751708159223, 0.16101039305794984, 0.11488097967230715, 0.1532798117841594, 0.09312837893958203, 0.1206444985291455, 0.14490290894173086, 0.09574429364874959, 0.09843916544923559, 0.06065655339625664, 0.16827872022986412, 0.2324664345360361, 0.1791772330761887, 0.16982544504571706, 0.1343449082924053, 0.15772211481817067, 0.23450944834621623, 0.144869853684213, 0.12227351267938502, 0.08661336134537123, 0.21356832672609016, 0.10705506210797466, 0.17215222644153982, 0.09599140656064264, 0.20787593530258164, 0.08761655204580165, 0.16132473712787032, 0.12503218691563234, 0.08558398025343195, 0.1665634982055053, 0.12077662308001891, 0.11778433559811674, 0.13983700890094042, 0.08131382579449564, 0.16003728902433068, 0.15748992649605498, 0.13575274759205058, 0.15306288201827556, 0.1558689126977697, 0.12806941143935546, 0.14391424949280918, 0.25430981477256864, 0.09035343682626262, 0.08750688488362357, 0.12032061044010334, 0.11253853896050714, 0.1550053496612236, 0.15708536695456132, 0.13954763067886233, 0.16637900029309094, 0.17838374362327158, 0.07200721229310147, 0.13481179339578375, 0.08286035023047589, 0.11687331963912584, 0.1096183288609609, 0.11843588188639842, 0.1495443153544329, 0.12528191960882396, 0.19499654124956578, 0.09369546140078455, 0.14988798910053447, 0.1392027546535246, 0.17857875034678727, 0.17478211579145864, 0.07618353702127934, 0.24790322495391592, 0.14575676468666643, 0.12200713361380622], [0.12492108740843832, 0.05620771575195249, 0.04261774127371609, 0.02211766503023682, 0.040499733440810814, 0.1053801980742719, 0.053685508319176733, 0.032146308440133, 0.039944673771969974, 0.02889374049118487, 0.013190301979193464, 0.03722159664903302, 0.014729338145116344, 0.03679134024423547, 0.022758221966796555, 0.02133857509761583, 0.09014350551296957, 0.03554029077349696, 0.014880614744470222, 0.01506551619968377, 0.09666855694376864, 0.040615155958221294, 0.04106390297238249, 0.03060183604247868, 0.05853035225300118, 0.07217686725198291, 0.05387476339819841, 0.02162212931580143, 0.08993227544124238, 0.0211215117451502, 0.01753219428792363, 0.049577672689338215, 0.04184841985988896, 0.017541677079861984, 0.011693109026964521, 0.037767149406136014, 0.0674830874777399, 0.029544179124059156, 0.02449898314807797, 0.05178555831662379, 0.018341322647756897, 0.05716711231798399, 0.04327612645283807, 0.021358720696298406, 0.04212517414998729, 0.04188763123238459, 0.031028903067635838, 0.04792454245034605, 0.025823119322012644, 0.04241192516929004, 0.055432579611078836, 0.07053892506519333, 0.05213739197643008, 0.03928779515263159, 0.01309495641180547, 0.026148710639972705, 0.03060619801544817, 0.12340371453319676, 0.02433438778098207, 0.036293284938437864, 0.026326538500143215, 0.08260660251835361, 0.028752624821208883, 0.0977905209583696, 0.026266018212481868, 0.039805636115488596, 0.01896759324154118, 0.07853773335227743, 0.010147173670702614, 0.020531465379463043, 0.010173686896450818, 0.009789019695745083, 0.03899134055245668, 0.01784829168173019, 0.03844264479994308, 0.06750131462467834, 0.028856931821792386, 0.05662744850269519, 0.07648113823961467, 0.0450090932281455, 0.039673949431744404, 0.042218974194838665, 0.012757826552842744, 0.02069324800686445, 0.08860806876327842, 0.011023271581507288, 0.04969398578396067, 0.047018821715028025, 0.02604240355140064, 0.0138891759524995, 0.023995537994778715, 0.037431542805279605, 0.08324275666382164, 0.11664258592645638, 0.038047595880925655, 0.03071528444706928, 0.027300798428768758, 0.03355499378812965, 0.010289932270097779, 0.12480647012125701, 0.07644835015526041, 0.03636421941337176, 0.03396831438294612, 0.04043253939016722, 0.03320318981423043, 0.028654590823862236, 0.025071127056435216, 0.02014341120229801, 0.017779778463591356, 0.03727689778315835, 0.03480350140307564, 0.008805786274024285, 0.012145975888415705, 0.04906424379441887, 0.04557313288387377, 0.030722563060407992, 0.02676134983630618, 0.017837307896115817, 0.08240836745244451, 0.03135825150820892, 0.01834901686379453, 0.015196266849670792, 0.047662668221164495, 0.12030495112412609, 0.07776307960739359, 0.029943155859655235, 0.04032695032947231, 0.04660913393308874, 0.03917569003533572, 0.031162432132987306, 0.011803852303273743, 0.022041930715204217, 0.017316429693892132, 0.04869550029980019, 0.020441615415620618, 0.017623179737711325, 0.06100905127823353, 0.05577026051469147, 0.09551691444357857, 0.04934040436637588, 0.01667922355409246, 0.018227273103548214, 0.03373966239450965, 0.04233439300151076, 0.031706084992038086, 0.030687253529322334, 0.06405786814866588, 0.05444744536362123, 0.059431245317682624, 0.05388490484619979, 0.03825803556537721, 0.044624541988014244, 0.021915342585998587, 0.06292339152423665, 0.012078317067789612, 0.02575754129793495, 0.02895226625696523, 0.04460444462893065, 0.016578000177105423, 0.0158921147158253, 0.003069800864068384, 0.04022889777843375, 0.07597457049996592, 0.019407317595323548, 0.07593344067572616, 0.037236947973724455, 0.05967616889392957, 0.035117960505886, 0.056313007953576744, 0.0247646701609483, 0.03501234175928403, 0.05501488776644692, 0.025185731356032193, 0.03821561440418009, 0.043384146047174, 0.03197866099071689, 0.06093955656979233, 0.011787817275035195, 0.05106047261506319, 0.026789262010424864, 0.014706508754898096, 0.03851050678349566, 0.008151092351909028, 0.05148094009200577, 0.051628104265546426, 0.03426682473218534, 0.01228218132382608, 0.017773581530491356, 0.03723375302797649, 0.0041758061524888035, 0.0581808637798531, 0.052723336120834574, 0.08038042666157708, 0.016404549132857937, 0.023375477321678773, 0.04101840931980405, 0.03269232875027228, 0.03531870403094217, 0.019559674947231542, 0.12036394444294274, 0.05981808608339634, 0.08059092200710438, 0.016352882666978985, 0.009542744483042043, 0.07352471875492483, 0.016042570314311888, 0.01215181751831551, 0.04361015970061999, 0.02991932549775811, 0.02054618402326014, 0.007556763794127619, 0.013703581516892882, 0.029885591175116133, 0.08340810716617852, 0.05187341375858523, 0.026102792107849382, 0.019937880824727472, 0.028804885005229153, 0.04727884799649473, 0.07627465049154125, 0.10851493338122964, 0.04727725980046671, 0.09237703605322167, 0.024939638897194527, 0.05057059577666223, 0.03837290147203021, 0.046622826557722874, 0.026014662071247585, 0.06412270216969773, 0.04461812241061125, 0.03384177078260109, 0.030670634987473022, 0.004886645401711576, 0.04798971414857078, 0.03400569636141881, 0.03624275581387337, 0.053488564590224996, 0.014721312745678006, 0.039776039266143925, 0.08403294355957769, 0.04511394756264053, 0.00595343630266143, 0.032831900753080845, 0.04165369886322878, 0.04438846852281131, 0.00897336136404192, 0.028202355715620797, 0.03158445812005084, 0.0835687005019281, 0.04708230131655, 0.022849717643111944, 0.04377431905595586, 0.02072246265015565, 0.07754967504297383, 0.10304955751053058, 0.024904533456719946, 0.0521793715597596, 0.06555560379638337, 0.012301751758059254, 0.04187212405668106, 0.02839103191945469, 0.02828406803018879, 0.04093136281881016, 0.03266847241320647, 0.05943130840023514, 0.051461852053762414, 0.029641432010976132, 0.023358610160357784, 0.015547557813988533, 0.04154128946538549, 0.013534470181184588, 0.032177601096918806, 0.025227055994037073, 0.018473719937901478, 0.027258175032329746, 0.033173177362186834, 0.004903437884422601, 0.020705727220047265, 0.04984112769307103, 0.07289065004442818, 0.029287167817528825, 0.009307705386163434, 0.007053435529087437, 0.06643888569669798, 0.00868648974574171, 0.028831427916884422, 0.024656079112901352, 0.028303682993282564, 0.05101264119730331, 0.019032573836739175, 0.04491759384109173, 0.01265151018742472, 0.05134044411533978, 0.005747774193878286, 0.03073782161663985, 0.05515302000276279, 0.03089039233600488, 0.02229030527814757, 0.03191507748852018, 0.03835235140286386, 0.036587386930477805, 0.013046578587818658, 0.05306564060447272, 0.03035548568732338, 0.016537020637770183, 0.08464526734314859, 0.09943609242327511, 0.008871040536178043, 0.03815604592091404, 0.0593094588839449, 0.004229944897815585, 0.015838088220334612, 0.03496657722280361, 0.0356969321728684, 0.03993416496086866, 0.022512752912007272, 0.03494161137496121, 0.028653794870479032, 0.0642132293432951, 0.03419970489630941, 0.07394316387944855, 0.03874294001434464, 0.02883565815864131, 0.014502827252727002, 0.014800746666878695, 0.020947771263308823, 0.027951277879765257, 0.05056164547568187, 0.010942831122520147, 0.04126453146454878, 0.013622584447148256, 0.04187868093140423, 0.011981544721493265, 0.008058900912146783, 0.012404656099533895, 0.03885215817717835, 0.04531519203737844, 0.04743881421745755, 0.017260249114769977, 0.0036360435387905454, 0.04209010767226573, 0.04881415487034246, 0.030872669849486556, 0.04591699587763287, 0.08222142787417397, 0.022358671922120266, 0.016484014595334884, 0.04382061793876346, 0.09357405346236192, 0.04001610548584722, 0.02692331800062675, 0.04479345108848065, 0.23757809540256858, 0.18852553301258013, 0.20055861154105514, 0.15052452916279435, 0.2121057317708619, 0.14235165755962953, 0.18861197837395594, 0.24274396273540333, 0.11340038021444343, 0.08051649201661348, 0.08258709887741134, 0.08475100112264045, 0.11047777297790162, 0.11180327099282295, 0.09053012734511867, 0.13401999603956938, 0.12661992281209677, 0.11687758698826656, 0.13530561845982447, 0.09440470224944875, 0.18945802672533318, 0.16340205300366506, 0.19189427490346134, 0.25474417896475643, 0.17355445510474965, 0.1576674185344018, 0.0957900173671078, 0.06135777533927467, 0.1858414668822661, 0.05560805671848357, 0.1309079778729938, 0.1407594687771052, 0.10077989179990254, 0.1168129756115377, 0.10743308244855143, 0.1197206434153486, 0.12392263903166167, 0.11459059955086559, 0.1266254295478575, 0.1302064405172132, 0.14035121334018186, 0.08788331702817231, 0.12308918492635712, 0.21242340066237375, 0.15890241164015606, 0.10463650673045777, 0.14359417604282498, 0.3130200784653425, 0.11739228124497458, 0.17342451988952234, 0.12367410119622946, 0.15890147653408349, 0.14671557495603338, 0.13120670715579763, 0.11225813330383971, 0.0979601165454369, 0.08322195426444523, 0.1720206139725633, 0.1371690325322561, 0.2103255272959359, 0.0881218358699698, 0.09192734651151113, 0.1527462076046504, 0.23500737006543204, 0.1336040667956695, 0.08854943909682333, 0.10564766809693538, 0.21774220978841186, 0.09531945121125318, 0.16404932452132925, 0.1309045046218671, 0.11992263374850154, 0.1628952700411901, 0.14731383504113182, 0.1437922997865826, 0.14591613347874954, 0.10532780244830064, 0.16501390869962052, 0.21382698003435507, 0.13159434573026374, 0.16637720429571345, 0.16206857690121979, 0.08283543633297086, 0.18997171166120097, 0.09854715535766445, 0.08751732690143399, 0.11898881159140728, 0.1433473822544329, 0.15478374436497688, 0.0747294322354719, 0.08503967430442572, 0.06365742010530084, 0.15095829963684082, 0.23253540974110365, 0.14574447472114116, 0.0943211438425351, 0.15390674845548347, 0.17111008783103898, 0.12785736500518396, 0.18606544705107808, 0.18677695887163281, 0.07523971813498065, 0.13728903781156987, 0.09614882350433618, 0.16145680972840637, 0.09356039052363485, 0.08797515780315734, 0.11599814941291697, 0.17783065064577386, 0.10745023348135874, 0.11072409921325743, 0.08399667480261996, 0.12518640520283952, 0.08326070921611972, 0.14773329690797254, 0.09532334748655558, 0.15205065195914358, 0.2303718266193755, 0.13055858958978206, 0.18868543615099043, 0.07873937487602234, 0.12360117034404539, 0.10051628094515763, 0.22685063275275752, 0.2315799836651422, 0.13571427465649322, 0.2024481343687512, 0.16818644158774987, 0.09110575934755616, 0.20490235736360773, 0.2028442482696846, 0.0733065050735604, 0.0893402865040116, 0.19285578659037128, 0.06364338609273545, 0.11513236735481769, 0.19041410589125007, 0.1449195627355948, 0.11094234258052893, 0.10754945120424964, 0.11199113083421253, 0.13810777512844652, 0.126279306714423, 0.14283377153333277, 0.16025546559831128, 0.13457549357553944, 0.16938208602368832, 0.1546669748495333, 0.11004970961948857, 0.15133507316932082, 0.1200282339414116, 0.14394504862139001, 0.10200563032412902, 0.12292473984416574, 0.11637326053460129, 0.17694905342068523, 0.10573167179245502, 0.1079919419134967, 0.08414479263592511, 0.11818178536486812, 0.11592199763981625, 0.17748760030372068, 0.23275141924386844, 0.08658395745442249, 0.21967142267385498, 0.13405040925135836, 0.12519553361926228, 0.11871628754306585, 0.233664988190867, 0.07179389678640291, 0.1802632474573329, 0.13410043000476435, 0.11900225930730812, 0.16190911905141547, 0.11768700293032452, 0.17327886598650366], [0.04768079517816659, 0.0331105734949233, 0.06032668359694071, 0.08052262957789935, 0.007364392622548621, 0.14661128836451098, 0.06194891451741569, 0.045915645168861374, 0.030633683454652783, 0.029891289013903588, 0.07655215435079299, 0.03828485307167284, 0.05551682450459339, 0.01352497718471568, 0.05163206733413972, 0.05564984705415554, 0.04189630322798621, 0.04620016974513419, 0.010181391317019006, 0.022087177603680175, 0.05495859957591165, 0.0627816487394739, 0.049456223932793364, 0.05290517714456655, 0.025741470089997165, 0.03297814095276408, 0.030040839192224666, 0.007269002526300028, 0.011944351062993519, 0.029494807749870233, 0.022760118154110387, 0.0273311318596825, 0.046825421741232276, 0.008356577272934373, 0.06609654781641439, 0.07339747753576376, 0.03515232936479151, 0.03746132519154344, 0.016939589368121233, 0.05091872240882367, 0.05221995590545703, 0.059677664321498014, 0.02050572213192936, 0.0525703980383696, 0.03428423180594109, 0.02441378830553731, 0.02924633114162134, 0.04057521357026417, 0.030204197028069757, 0.033788232249207795, 0.08019416243769228, 0.015801578265381977, 0.008388569403905421, 0.010483600344741717, 0.026644780700735282, 0.04714566959592048, 0.06355390534736216, 0.05622452910756692, 0.06068279573810287, 0.045527765396400355, 0.03244274077587761, 0.027731848931580316, 0.046560927730752155, 0.07981914779520594, 0.038953446492087096, 0.031825329569983296, 0.05959039888693951, 0.049250741794821806, 0.04054321216244716, 0.07312032248592004, 0.03708626602019649, 0.08523701879312284, 0.04045795794809237, 0.013059699758741772, 0.03956568492867518, 0.027620281871350016, 0.028904987739224453, 0.037846896884730086, 0.039402286274707876, 0.041330211533932015, 0.04181316042377148, 0.004091934188181767, 0.026607233594404534, 0.08321164583321661, 0.04198162794637028, 0.024018589101615362, 0.05506095658347476, 0.02060504375549499, 0.0597246756660752, 0.08741870289668441, 0.06021937646437436, 0.03312831453513354, 0.06432688183849677, 0.029087582042848226, 0.04812951992789749, 0.031163226231001318, 0.023052001124597155, 0.03269417298724875, 0.015262648248608457, 0.009984772277675802, 0.034112929279217497, 0.058178381295874715, 0.04502886033151299, 0.07898410549387336, 0.02382516315265093, 0.01831103003496537, 0.006400447618943872, 0.02385363564826548, 0.004983798562534503, 0.014750807549717138, 0.057086659799097106, 0.044804312419728376, 0.02030911979090888, 0.06029382500855718, 0.008974315951491008, 0.03590880420233589, 0.0042281758032913785, 0.04056689409480896, 0.04228369318298064, 0.027524799006641842, 0.03513172363454942, 0.0731923924467992, 0.09220731430104934, 0.06549430981976911, 0.029249208819237538, 0.09292178729083389, 0.04653989897633437, 0.0440174503455637, 0.026905858976533636, 0.06265971387620084, 0.10715115538914688, 0.05351705935026985, 0.06642864405876026, 0.03537756376317702, 0.04445673126610927, 0.027219421936024446, 0.04202231619274244, 0.030314910618471913, 0.043890554225072265, 0.08944231696659699, 0.05013690693886019, 0.09228377035469748, 0.05474921745189931, 0.03602524346206337, 0.02250538338557817, 0.015050116635393351, 0.04606135102221742, 0.06400456710252911, 0.03728464580490254, 0.045495886442949995, 0.024400084548688028, 0.03974834973632824, 0.05141459208971355, 0.045930703345220536, 0.02659581008629175, 0.03701950241520535, 0.026396595385449473, 0.00815624192910036, 0.03552634581865277, 0.0325032295222627, 0.11046141604310833, 0.019278041036159266, 0.03887745799147524, 0.038401507554226555, 0.021421012861537747, 0.06062127540644724, 0.008541816405340796, 0.018915219880000222, 0.029796850722050294, 0.08015107334358618, 0.051566365000326186, 0.06698555167531595, 0.03407784424780402, 0.06836397224105895, 0.03845348757749889, 0.03997128347691614, 0.030388184713956434, 0.06884230868308805, 0.028913322057633195, 0.05208094051340595, 0.006965749389564735, 0.08747452724492177, 0.03484305787424091, 0.02065280466922559, 0.03191965653968509, 0.027297171181999147, 0.07663966840482317, 0.03369901125552133, 0.02553881553467363, 0.03009444451890886, 0.02763457378023304, 0.013182209786464227, 0.042251910708728246, 0.011500565306050703, 0.013848060043528676, 0.027963269130850676, 0.054994237507344224, 0.018307521531824023, 0.02002504792471882, 0.031981388383428566, 0.01825115170504432, 0.01453921475331299, 0.02265559964143904, 0.013235450533102266, 0.0673566255136393, 0.014713772525283275, 0.026179938358836807, 0.019328336384205613, 0.023028215291560628, 0.049540502222953364, 0.015675953072786797, 0.06588922144146636, 0.04035633937746752, 0.04728576481284108, 0.03675261868920643, 0.01732207372697303, 0.06469710962846875, 0.07582680889754556, 0.009078891980607295, 0.041362906849826686, 0.04325278219766915, 0.042068262555403635, 0.035566985825425945, 0.07414268286083825, 0.026199501371593215, 0.0788707572792191, 0.027483261001179926, 0.07615917231305502, 0.017000185725919437, 0.006685631315122009, 0.030559470542357303, 0.05908733408432454, 0.0902936197235249, 0.05404675983299967, 0.03889180370606482, 0.01472582685892121, 0.04316234408179298, 0.0299029722737032, 0.028839253864134662, 0.01900984556414187, 0.026181417088082526, 0.014673961868538754, 0.0284319298225455, 0.04780855218996294, 0.028326797182671726, 0.03180528787197545, 0.04895081765425857, 0.0442704855959164, 0.047680216302978806, 0.05584576661931351, 0.05454403959447518, 0.055470974621130154, 0.015975240821717307, 0.04050980067404453, 0.02173409713577712, 0.04304492147639394, 0.02701685458305292, 0.02642196384840645, 0.027472618603496812, 0.06358912025461905, 0.0038095328500276082, 0.06307553179794922, 0.07658535803784616, 0.057876282662618905, 0.0989952715463005, 0.04900073450698983, 0.04507994235609658, 0.017188707934110425, 0.08160381257766858, 0.016676373707014136, 0.022584448088309728, 0.017706749276840128, 0.07917165363323875, 0.00842994320919388, 0.01475249129725853, 0.019124815371469595, 0.01029079316140269, 0.07343367949943058, 0.039090120408218354, 0.060331655986374244, 0.013980920248286566, 0.03928545367671177, 0.06069904877222143, 0.017168488120660186, 0.019539432869351003, 0.07338668670854531, 0.02886300815589493, 0.035231813380960375, 0.0728503440041095, 0.07317924158996902, 0.08525886019924656, 0.03401104353542905, 0.08095908662653528, 0.02770144128589891, 0.028490242220868822, 0.01433708619515528, 0.06521139570395462, 0.03079710808378877, 0.08182941804989241, 0.06624772329814732, 0.02816255990182981, 0.030114256151136942, 0.03534692419634666, 0.005703942024410935, 0.04622443055268377, 0.08012316859094426, 0.04401979182148352, 0.07014767223154195, 0.029567150450020563, 0.03243648447096348, 0.023216056579258293, 0.007760989383314154, 0.03142687419313006, 0.03144010297546629, 0.08408101988607086, 0.014824738445895491, 0.021421421042759903, 0.05661006369336974, 0.08115595614071935, 0.021275524086377118, 0.028743839648086578, 0.005152851917955559, 0.022638289046881255, 0.034332779396208934, 0.03261330486566294, 0.04014273814391345, 0.017341198872600216, 0.005609626650766586, 0.008910064516385319, 0.027040939130529296, 0.027138663281220943, 0.07097201276337728, 0.03176853300828952, 0.034958012838615105, 0.02275866354466416, 0.020451181699172594, 0.049966999649768695, 0.0028661620353886974, 0.054277623421512544, 0.040078264064504765, 0.04950084927259013, 0.07291807240108028, 0.039696351159363985, 0.02503918130969396, 0.02580623175163055, 0.04190135725366417, 0.07203879809821956, 0.04382918603369035, 0.043536171287996694, 0.03587354105548002, 0.06485830410383642, 0.036306643596617505, 0.17291291296714917, 0.13115264911903068, 0.15389787236927077, 0.15718836220912635, 0.08937226564739831, 0.3528415260370821, 0.17801431735279039, 0.1493294636020437, 0.14793777343584225, 0.10802493037772365, 0.1349141207174398, 0.1741150883026421, 0.0904982966312673, 0.13034479168709368, 0.107007668557344, 0.10253775762976147, 0.13230192416813225, 0.13208567717811093, 0.0974237070477102, 0.10452191912918352, 0.21204401477007195, 0.09862459104624577, 0.23126728716306388, 0.1632857881486416, 0.12094245597836562, 0.13320014550117776, 0.1945934511604719, 0.16684379254002124, 0.12571165279950947, 0.08747644940740429, 0.08339097097632475, 0.10475403323653154, 0.07771282136673108, 0.11644852173049003, 0.15975766262272373, 0.1625840726774186, 0.149370162980631, 0.13048729888396338, 0.1341167720966041, 0.12609982572030276, 0.16747908579418436, 0.13883732113754377, 0.08713362913113087, 0.19520029047271237, 0.1303913095034659, 0.12506148690590635, 0.14579863665858284, 0.16482025268487632, 0.13728618796449155, 0.1378101739101112, 0.17414398753317073, 0.15807116171345115, 0.077502318599727, 0.171070204814896, 0.11590925496420823, 0.14568839804269373, 0.26602663449011743, 0.1931925880489871, 0.11527526046847925, 0.15584206179482862, 0.09008749562781304, 0.1138525411079172, 0.09159681620076299, 0.1808944292133674, 0.09730229910928756, 0.18655415129614994, 0.16821685479953885, 0.11286170716630295, 0.0874573465262074, 0.13491887046257034, 0.1123654552793596, 0.2279943268513307, 0.21933637268375605, 0.10219134535873309, 0.16430054150987417, 0.2432597998995334, 0.13883276435080916, 0.10518960712943226, 0.18448415299644694, 0.1527250712388195, 0.1689712330698967, 0.0715144188143313, 0.11213003119337372, 0.25468275882303715, 0.11588615932851098, 0.10775739356176928, 0.16871440544491634, 0.15447446174221113, 0.19746832345845178, 0.27543032832909375, 0.12671085074543953, 0.14414336532354355, 0.13981029158458114, 0.12727731722407043, 0.10724677369580604, 0.14554615801898763, 0.14692116470541805, 0.08396020566578954, 0.16600397822912782, 0.0693062919890508, 0.08200555937946774, 0.19379728997591883, 0.15276412304956466, 0.14151405484881252, 0.09139844012679532, 0.14133449963992462, 0.11153643179568462, 0.16470642207423225, 0.09650154403061606, 0.17303811328019947, 0.10346147915697657, 0.1389721396844834, 0.17319087695796043, 0.24162637739209458, 0.11173831822816283, 0.18960897956276312, 0.11678906361339614, 0.1421942628803663, 0.09372076121508144, 0.09110856466577388, 0.16123055858770385, 0.12699921964667737, 0.2867769350996241, 0.15815112070413306, 0.11201577755855396, 0.1377601086278446, 0.14140360843157396, 0.12272289051907137, 0.09333386478829198, 0.11313888448057696, 0.19919849233701825, 0.11546344685484655, 0.1322925731074065, 0.15185457654297352, 0.12022586786770262, 0.10691791321733035, 0.12288693484151736, 0.1497980853309855, 0.2864461450371891, 0.23840112233301625, 0.1876621480914764, 0.17571011208929121, 0.1992484091897495, 0.09012776456074789, 0.15186462522251531, 0.09080420990358107, 0.1657200770569034, 0.14463027357123792, 0.09074551344383508, 0.15669475978938863, 0.08620898734079674, 0.09555909811751917, 0.12077690509613603, 0.16511126363184303, 0.09193553240038455, 0.14112030097749084, 0.18474527023499832, 0.11165187286678702, 0.15850378928007558, 0.12376688449876383, 0.1559523300966248, 0.1385088317329064, 0.12239883915754035, 0.17571003787452355, 0.07752415258437395, 0.1913133217021823, 0.1375246696989052, 0.11935032656765543, 0.1453105261316523, 0.18632711347891018, 0.13012343872105703, 0.1166503042622935, 0.11803574554505758, 0.09145576361333951, 0.16725176596082747, 0.16221362224314362], [0.032555116777075455, 0.037536430536420085, 0.03765942296013236, 0.025100436323555186, 0.05227673762419727, 0.04047813323268201, 0.0223489924610476, 0.01174557515696506, 0.022370115839294158, 0.04353028976765927, 0.05723573129216675, 0.027579641864576843, 0.022660473696305417, 0.03409903998544905, 0.07004307393799536, 0.06473852146882564, 0.07591481276904233, 0.015577178783132695, 0.011533752294781152, 0.05313527632097248, 0.039440592227037996, 0.053004090586910024, 0.03766106310649775, 0.03760260413400829, 0.06005897237628233, 0.024105845259327907, 0.03417226027522702, 0.025845417148957495, 0.04527693061390892, 0.06357829974149354, 0.057922047199099325, 0.02428907224384602, 0.06624697372899391, 0.06535800697747618, 0.02946201966551598, 0.025722153841343243, 0.039207669178722426, 0.04211981955450028, 0.04289908203645609, 0.02821190715621924, 0.06289487821049988, 0.05038574534410145, 0.034620087026269175, 0.05165311093151104, 0.07473113917512819, 0.007959319536894327, 0.0756951147923246, 0.05528088833671063, 0.021678970406355802, 0.0631807312311139, 0.06839828172815032, 0.08655080571770668, 0.022632175605394877, 0.06544312389451079, 0.03939919522963464, 0.1060422086447943, 0.03353474799951073, 0.05082446965388954, 0.04105556494323537, 0.09045024999068119, 0.04052414638863411, 0.07981582297361456, 0.021977627329761162, 0.040502843039575964, 0.07892395442468114, 0.039987399213714525, 0.044475945469457656, 0.027832452615257353, 0.03311216540168971, 0.00406276360990887, 0.07305405611987226, 0.00860290629134397, 0.015077379430294968, 0.021570435019384604, 0.02916722747613676, 0.061817903188057244, 0.08750574197620153, 0.014360763489094097, 0.0230769113113638, 0.038150223772390746, 0.03715299622854218, 0.015675800932513084, 0.030555090015695896, 0.027833682725031395, 0.048675057842046954, 0.03892766799253877, 0.08781644952250645, 0.0368192858149996, 0.026021031553682406, 0.11918160671484657, 0.03717796949786134, 0.06245407959795557, 0.06633286247961223, 0.08641010193969123, 0.034124599551432766, 0.02502483745047357, 0.04038954677525908, 0.040812596926116385, 0.013349026030482491, 0.020699957021861337, 0.059316316328477114, 0.05736385195632465, 0.061226318721310236, 0.04312635734095238, 0.03572929352230858, 0.062423525378108025, 0.04021851884317584, 0.02976173971546814, 0.03541317200870253, 0.05309025764290709, 0.03800314123509452, 0.04443026256922167, 0.049964854842983186, 0.025027739247889258, 0.013608387162094004, 0.07137348497053608, 0.01949985969986301, 0.03047768957912922, 0.04348159745859448, 0.0198748428010731, 0.014169632631819695, 0.012139994178141933, 0.014375689006556058, 0.05172076140297577, 0.07377172776614316, 0.09849602138274349, 0.023630004288861528, 0.01274693182494957, 0.02017848881223472, 0.04159479831287172, 0.01751183532178402, 0.02859439337044023, 0.027588202538026962, 0.06067505142709706, 0.04786972371221054, 0.020744202010973822, 0.05054819404904265, 0.01784550306183519, 0.05773970522568561, 0.03235098163713701, 0.013049544395471457, 0.05642532458296046, 0.11535371289937757, 0.04286448682250921, 0.07820372979040258, 0.0580356551654404, 0.05251747919828631, 0.013778976299363421, 0.03341805640957318, 0.031405830595758744, 0.018760515486064833, 0.01729580355458893, 0.034010553717962466, 0.03593343608372379, 0.05146040486579295, 0.039965550386114046, 0.021253157610772178, 0.01901134841318708, 0.03269010972871911, 0.05448713171062991, 0.025476115188212134, 0.03678110231703613, 0.0441711788153043, 0.006129404155217344, 0.03383874653081875, 0.046418683996307664, 0.06685681873932481, 0.0304170301387785, 0.01411834744430962, 0.016889991638890933, 0.043522964770090766, 0.058693988394225016, 0.047564070191583596, 0.04019974992843345, 0.0307917015379644, 0.05244455947831739, 0.1096507978218142, 0.06526019933517091, 0.0641744521271903, 0.02994257512909826, 0.08308754389872774, 0.07999804249266163, 0.040515203509130515, 0.09026685045682825, 0.018901519833889324, 0.04374285570520442, 0.03947303521272261, 0.017172560656035785, 0.030117773931124248, 0.016419611019955482, 0.023684797051828355, 0.06879861844936386, 0.009359207651868928, 0.025154036084131803, 0.0680295011261478, 0.053933419039822184, 0.08566054020775482, 0.054641164460917935, 0.03270620320108719, 0.011226516144233756, 0.04549658035102766, 0.1424287963891402, 0.01913416272145696, 0.02957139367936179, 0.02090048903482966, 0.03499215905321762, 0.0438055152335437, 0.03339619273901917, 0.07323637211811729, 0.008458222746412503, 0.042357280835858546, 0.05547201362787746, 0.059237144014332443, 0.06752382396371104, 0.055640907885390334, 0.0017227802186425833, 0.013713591233681655, 0.026165386698266957, 0.01599159590114141, 0.05433877639006823, 0.030618035270890687, 0.03748238734260667, 0.05189167059143074, 0.025919919498846866, 0.02795103853713954, 0.05171375552890822, 0.05673701918567531, 0.08973571020760573, 0.01862309200078016, 0.04999591001251247, 0.0008359807122815255, 0.031434867123607546, 0.0508463221922284, 0.042536817491054535, 0.07343855540966615, 0.033499329001642764, 0.06672433053608984, 0.06281903071794659, 0.018249006898258813, 0.05363815929740667, 0.032553543424000964, 0.03783194631978404, 0.0503605049016187, 0.012648279989662115, 0.054295089867082424, 0.00477920282719424, 0.04941966944898013, 0.04487061218242161, 0.007269659790836158, 0.009023122365761083, 0.01380077874273411, 0.01643839477765141, 0.025889634307532106, 0.029561332012235653, 0.040598171908641234, 0.03259694422013126, 0.05306975952407811, 0.02045899094810011, 0.050519717842689715, 0.02725747926888289, 0.017675785020401236, 0.06525380202219822, 0.026656417576305103, 0.03565271501429379, 0.05619302864943165, 0.05570437264395878, 0.07064685560180806, 0.04772799577040132, 0.07028637963230722, 0.05358785652788356, 0.02680958201381145, 0.09262272404157557, 0.04344475353718735, 0.056909037884906866, 0.013264128974697087, 0.02376330885454081, 0.02099890338286059, 0.033799041630118154, 0.017407598825229798, 0.054403443427872844, 0.021597464037768077, 0.005503793609022978, 0.040141264980775304, 0.02618769936816534, 0.03311705615487881, 0.026242833519063424, 0.04167833074461669, 0.02213816871517338, 0.020532921844278462, 0.035404982409090735, 0.036702119250549003, 0.04411745103425346, 0.010598563658277271, 0.0318345581763424, 0.06218388218258042, 0.047793308476684615, 0.05226353110629134, 0.014559915107383858, 0.03193721204297617, 0.03728471630893182, 0.017845901966211386, 0.027025367016904056, 0.028302074388193432, 0.03761559542908799, 0.013103864039294422, 0.03045749203010928, 0.007832835308363428, 0.04802399766049348, 0.014347842698043678, 0.015992161788744852, 0.012328862412687158, 0.06456281058490276, 0.03922654941561632, 0.05395076303102542, 0.01600332554517081, 0.040547104727011174, 0.031923653004923835, 0.06666540401056409, 0.02237996599433245, 0.05324947429471649, 0.07154392660595477, 0.045551143048214726, 0.008333760870300466, 0.024658047659613658, 0.017630985275900457, 0.02198999522079248, 0.02442828430503141, 0.08799242757959291, 0.060875160415889695, 0.03087040073296521, 0.011425656630308367, 0.06962961604585871, 0.011522918794071302, 0.045027606101939455, 0.03175568643200677, 0.052657340638688765, 0.058391566926729865, 0.025283173490606714, 0.046754134746151976, 0.07003096208791249, 0.0362138899799902, 0.07689352001762018, 0.10987460729666054, 0.07874274422647431, 0.03863386285956949, 0.03725123802723829, 0.02769321272353409, 0.046704878404852934, 0.028844649277743883, 0.050277488262508996, 0.0362733805377502, 0.03332554770167917, 0.18987581133842468, 0.2031268284190446, 0.14631993602961302, 0.1430724759120494, 0.21921010367805138, 0.25902037450578064, 0.08114877957268618, 0.15277835744200274, 0.1047382180695422, 0.12988166185095906, 0.1673704056884162, 0.1282584512955509, 0.07715769490459934, 0.09333833993878216, 0.11706411096383817, 0.19522650312865153, 0.09167868251097389, 0.10629752970999107, 0.13426769524812698, 0.1934834208805114, 0.1561339187901467, 0.13931480410974473, 0.1539896908798255, 0.20364319992950186, 0.19359872094355524, 0.19371039932593703, 0.11673204440739937, 0.11505495393066667, 0.1270003625540994, 0.10793973924592137, 0.19041864783503115, 0.08301951122120954, 0.20030366897117347, 0.145306785707362, 0.2676537190563977, 0.1251540327211842, 0.16469349386170506, 0.13432996143819764, 0.1440996676683426, 0.10418623089208268, 0.1930910028750077, 0.12975758960237727, 0.14077141735469922, 0.21985709317959845, 0.10082466556923464, 0.13643697806401178, 0.16643715498503298, 0.20995451282942668, 0.18384654424153268, 0.11076984519604594, 0.20535129733616486, 0.19371783564565703, 0.11700414543156512, 0.1282011574949138, 0.11020233228919096, 0.21290328819304705, 0.15793018334079534, 0.09533580072456971, 0.12727503140922636, 0.24295562325278297, 0.12555495573906228, 0.21269983582897112, 0.09594069560989738, 0.20781865634489805, 0.22042980854166672, 0.10153945768252015, 0.11349175343639217, 0.10402489540865645, 0.11906480751349591, 0.09654943482019007, 0.229187878430821, 0.10952686658129096, 0.09826616340433247, 0.11539729181095026, 0.11814436627901159, 0.12175383119028993, 0.27249451086390764, 0.06586971037904732, 0.1275246008299291, 0.1545848636305891, 0.12838816386647522, 0.06400673417374492, 0.1184354662836995, 0.11184543982381001, 0.14507867919746786, 0.13221953093307093, 0.10870760976104066, 0.1589257744490169, 0.138806774339173, 0.15948225161992013, 0.14834678586339578, 0.20680854882812127, 0.17114789283368737, 0.21876892657019198, 0.142899451602716, 0.23248060955666006, 0.11544496737769805, 0.2794153644936159, 0.1256336085498333, 0.11721560556907207, 0.20331851032096893, 0.09024857878102921, 0.10817869595484808, 0.13363209029193968, 0.08726631029276177, 0.17926027940120548, 0.1468721532728523, 0.09944202218321152, 0.07725321673206054, 0.1444075847393833, 0.12905661627883092, 0.09446406664210372, 0.10855671629542485, 0.1729969834559597, 0.09582771104760468, 0.12205964798340574, 0.06913633274962194, 0.13099587784381583, 0.12606763135408983, 0.12793022906407714, 0.09898100004647858, 0.08425940992310643, 0.15472956758458167, 0.13276109093567356, 0.13780889741610736, 0.17836655548308045, 0.10577011504210532, 0.22757251979783177, 0.07807787638739683, 0.13980552699649706, 0.13740858295932412, 0.11966075951931998, 0.10638004911015742, 0.16812073183245957, 0.10628752555930987, 0.11352492001606151, 0.12651051540160552, 0.1420759645407088, 0.13806737260892987, 0.14732009876752272, 0.1128104618692305, 0.2045400853967294, 0.20243544364348054, 0.13267135043861344, 0.11248668510233983, 0.08638262763270177, 0.06782082404242828, 0.0995144186890684, 0.09322430152678862, 0.09906648803735152, 0.0710991352389101, 0.3530673764180392, 0.09619623189792037, 0.23472651169868186, 0.13734395673964173, 0.17710977292153984, 0.11786212009610608, 0.13443524250760674, 0.1642610740964301, 0.11299538280582055, 0.16087815718492493, 0.15868653572397307, 0.08923182162106968, 0.15067312197061256, 0.2348567734588869, 0.206558741920162, 0.18314773798920214, 0.17819264059653506, 0.10497454015421681, 0.13786023919237778, 0.18319050053833053, 0.12647211668081582, 0.12140703300246969, 0.1056032654014416, 0.16777731041656807, 0.15685317863244563], [0.008666131707286695, 0.030089804240560625, 0.055863010420580395, 0.03639376060164068, 0.06525726785184816, 0.032968908635666594, 0.010866599568544189, 0.045719822082901374, 0.03601143951527774, 0.004510194239628618, 0.054358621418941766, 0.10413163850898854, 0.014975767353462288, 0.03298369963886216, 0.03171265299897641, 0.006868369409858133, 0.04072559124324471, 0.0637298685614951, 0.03282163685071282, 0.046389079725486226, 0.028860269630968105, 0.038141559198265895, 0.009570761485520052, 0.02752882515778765, 0.009403851545357611, 0.028306653439358342, 0.04467232516617514, 0.020586284117598552, 0.016606736135145184, 0.06491650332463905, 0.06833478357293643, 0.06918873579706997, 0.021480325303855352, 0.0459884758311091, 0.07711371523328125, 0.0129257291155227, 0.05513980606338009, 0.01957344364200253, 0.077229653543327, 0.05533303163247183, 0.027283007293590344, 0.035111626275465824, 0.02409988024737686, 0.06552291961270384, 0.03994081460405141, 0.008191458691726439, 0.002577410232333932, 0.05499225968378596, 0.03356397748575546, 0.07962685733218677, 0.02700767607166199, 0.035810799890896305, 0.0485643219872145, 0.025964878805098124, 0.03482541702396702, 0.04886025708401576, 0.055892251039040275, 0.049622405640548095, 0.03904657489329111, 0.020145880698692054, 0.08374472308787517, 0.04083234918653034, 0.0585817608225625, 0.07411647020489909, 0.030483947739412542, 0.06424343475373462, 0.029629038144776132, 0.010665055451681837, 0.017806720279622823, 0.058379058027639985, 0.02089803252601996, 0.03375747022801079, 0.04550979057967197, 0.07168917974922806, 0.08103667074465193, 0.04009883268736303, 0.023614014717168175, 0.04820520043722354, 0.046778518008068204, 0.07081435091095045, 0.0052216545736882836, 0.015053406204970088, 0.04826227159355767, 0.02181170722906245, 0.028192646568641067, 0.05453497054986656, 0.04959783313097432, 0.05924448385485448, 0.031030830796225928, 0.09430920268641785, 0.02377635766606545, 0.026931117972708307, 0.009417749188287416, 0.0996013538679108, 0.005811937035105075, 0.03623526754381601, 0.037567678664345294, 0.02745948630035855, 0.06213661479705479, 0.04618923048838042, 0.0550008166464977, 0.044283265378908254, 0.026319560456613544, 0.01737404818413779, 0.03545823521562852, 0.06482257711468264, 0.014646769577666419, 0.041813178977463394, 0.06481067306594923, 0.06297691521467641, 0.010276251705363393, 0.050340500310994685, 0.04487386278924532, 0.033042273644241504, 0.040553613362135366, 0.050666882016230375, 0.030903444858267903, 0.05202794745855499, 0.054859307638253085, 0.028747706237481907, 0.05844266379426699, 0.011609956018219236, 0.048845106139197014, 0.01729487401462393, 0.054774420786998235, 0.06784656172385439, 0.07736623840173706, 0.0683187457616441, 0.035121222244924866, 0.03585558479244355, 0.028254025892238133, 0.04365582775790244, 0.045437427470460534, 0.05268084445560817, 0.008859360987116816, 0.049766827578423545, 0.04121010235394351, 0.05963552146567963, 0.017647735548962373, 0.01831662026233971, 0.024169089228962548, 0.0910002927412279, 0.04243684648827184, 0.008709877602086635, 0.13461068621836603, 0.06256572087295353, 0.03997621875896584, 0.013695400266442448, 0.029702501487918198, 0.08505429461365566, 0.024776930440566503, 0.04674646464991383, 0.07467835021088831, 0.030655148220830597, 0.0455713777046185, 0.0351291595143266, 0.029989896320330445, 0.04330910378484987, 0.07089531180099584, 0.025355827892781235, 0.03354360924276989, 0.04936528857797384, 0.025362496089655906, 0.022949258200242184, 0.02876631187973544, 0.1541597762843594, 0.027358624720363878, 0.028098087677790318, 0.027574597115744837, 0.04917016682156827, 0.017747944039001595, 0.040887097420636564, 0.036199013629811816, 0.014748505964234937, 0.1115285353444051, 0.06461554017732851, 0.03579028692911379, 0.015131858635868412, 0.05880404518393334, 0.058029576975968666, 0.051582050291472115, 0.03545854691765271, 0.05082495204987936, 0.043766994058387354, 0.028680261711997446, 0.016496746138727758, 0.0451429692475358, 0.07428365381201729, 0.06044996545824688, 0.007269998395713628, 0.03023974033567356, 0.054277051967801526, 0.03698151187563781, 0.039511786453658715, 0.030819250059721526, 0.02561478177085519, 0.021505278164113406, 0.020991095989302266, 0.05911642998398747, 0.010191766541538527, 0.04166450824413914, 0.017696257164061535, 0.03559095348464325, 0.034463638585293666, 0.030589931993745267, 0.05372632273065392, 0.06424704901291989, 0.014923436665412737, 0.016114738609758206, 0.061899966167402454, 0.06875092061818577, 0.05439759530418087, 0.07761701752315275, 0.05067508274805732, 0.03028554012416862, 0.07333862522500567, 0.042766927799675614, 0.03635404085798655, 0.0486207586072851, 0.03990797085862141, 0.03867078099574428, 0.011896023333974881, 0.029619687084050383, 0.04485378027311526, 0.04792668725713156, 0.016178637524717487, 0.09093935499549843, 0.04225816701364238, 0.036365443957038224, 0.02666529551788699, 0.025945497618522495, 0.058169271433143876, 0.054876210051588714, 0.022668036181130446, 0.03620684699853882, 0.047375854119309224, 0.07409464364172891, 0.022179029510880355, 0.030754011568205897, 0.061914092948427424, 0.05993109291011933, 0.06686814391287044, 0.0562438991619274, 0.06636249643634073, 0.031509746113442816, 0.06294197490205988, 0.061057958810124546, 0.03302124488982372, 0.022216350262169726, 0.021081090671941638, 0.02530226523958845, 0.05859733108081855, 0.04358673751994502, 0.033427080925321206, 0.03785260771110188, 0.07912782239145599, 0.01229194613188156, 0.07883781334385276, 0.04187120379356202, 0.012911474314023508, 0.07283207974978723, 0.03978860753704794, 0.0561764861777192, 0.08769223626586609, 0.03481903826468624, 0.0870361554552801, 0.03490339076961391, 0.059249493351671845, 0.020547050480672624, 0.032924223924055696, 0.07108726829756051, 0.018025360695901327, 0.02358645691856509, 0.030451807178906165, 0.018671136785997078, 0.009392516167281428, 0.02254847433505347, 0.032403213990619406, 0.03360214985150378, 0.03094849322224036, 0.01894672775961226, 0.029434745738399215, 0.04195857312879525, 0.005564649718508008, 0.04926247514958959, 0.1070117206836585, 0.0074621835665311664, 0.023934065902722068, 0.048587796118226834, 0.017519139910291415, 0.03703595953993499, 0.025654770543042105, 0.013055624440312386, 0.04336547732236795, 0.031897922744974494, 0.043176522813155316, 0.040646277921041474, 0.06505695477244444, 0.0647005086648278, 0.050992336036870256, 0.0394955445517553, 0.1351334253558889, 0.04895456550002564, 0.10730924768722616, 0.025339637941215187, 0.04813109328097198, 0.008604296890553087, 0.0378921085211914, 0.023237864588736556, 0.030284545646281913, 0.03569909924408421, 0.006795895906179794, 0.05835878997459076, 0.08544322452507913, 0.04856084502534941, 0.046065655478741974, 0.011988945789198624, 0.024247222536359914, 0.022284180704446044, 0.05175691141630523, 0.07661528143216856, 0.02328330258023925, 0.027795040950877592, 0.06581758934771642, 0.02123373003996676, 0.04012973942735698, 0.035401653876760975, 0.01484806136431871, 0.027252393701928668, 0.016893904612516053, 0.007322755818677251, 0.056132061217795126, 0.054643034673063084, 0.03176204663759563, 0.013952400440757629, 0.015271113370545208, 0.06042465080099646, 0.03047045920538949, 0.061407165267155506, 0.03200104045390617, 0.026422420269227587, 0.16678476211382076, 0.015017632831586525, 0.025443223203183152, 0.09671972060459666, 0.02733967954554828, 0.06958682381082326, 0.1022428875148762, 0.01653921925026225, 0.02691159021196654, 0.03279193610069342, 0.03431761731917504, 0.08442317965091206, 0.062234934521256946, 0.2093218913068995, 0.1316711728577502, 0.21875340084079653, 0.16461205057566985, 0.09741546178702265, 0.13055055955192074, 0.07990067271748558, 0.09363329911138862, 0.11352387358783744, 0.3225863620173186, 0.14999420527601615, 0.09658925846451893, 0.12133406504290178, 0.23029635020066053, 0.14227505307644606, 0.2623151836451143, 0.16277373593766242, 0.09370891653816216, 0.1357920072041452, 0.15571142896078527, 0.1358611456817016, 0.09969300910597667, 0.12961205444298685, 0.13313195697264746, 0.16845986363478005, 0.10035115308710374, 0.09333744936157018, 0.15619869343936443, 0.1276378525653854, 0.16368975397199392, 0.1444848719984293, 0.13999526447150856, 0.1481008974951692, 0.10680344435968436, 0.16882265510503203, 0.126108716649469, 0.11734131796401925, 0.1055797393200919, 0.13705701276194304, 0.12494321825215593, 0.16554001718759537, 0.10223128032521345, 0.11613840048084967, 0.1063618813350331, 0.11309551337035373, 0.11357547511579469, 0.10434065698063932, 0.14300750830443576, 0.2114274533232674, 0.08552249331842177, 0.1257405520300381, 0.10669146911823191, 0.10637290222803131, 0.21670931833796203, 0.17879452236229554, 0.1380789204267785, 0.14558610040694475, 0.1174401497701183, 0.20995040133129805, 0.10414354997919872, 0.1378092833328992, 0.20769810187630355, 0.15113785484572873, 0.17779824847821146, 0.15162118594162166, 0.1412371001788415, 0.08967093555838801, 0.13831416639732197, 0.13172598788514733, 0.1469543980783783, 0.17195174266817048, 0.16642263857647777, 0.18275876354891807, 0.17363126738928258, 0.10956592581351288, 0.14597284840419888, 0.11777172650909051, 0.10775689632282592, 0.062448543176287785, 0.23791856307070702, 0.14637849148130044, 0.14189477660693228, 0.2618771977722645, 0.10947211092570797, 0.13910863548517227, 0.3255395160522312, 0.12471401336370036, 0.2443146292353049, 0.12547962774988264, 0.18173620279412717, 0.11273022086243145, 0.22914985078386962, 0.18000520271016285, 0.1645867433398962, 0.16453753894893453, 0.12450474998331629, 0.11620059245615266, 0.13143163727363572, 0.10946177280857228, 0.10403679945738986, 0.09441976042580791, 0.08201686228858307, 0.0970031987526454, 0.1545745923067443, 0.17980918666580692, 0.08644798115710728, 0.18435400997987017, 0.17385097278747708, 0.0781853319494985, 0.11266192101174966, 0.16732923133531585, 0.13511536148143932, 0.12444399035302922, 0.09723652256070636, 0.08493630797602236, 0.17891531431814656, 0.11964101839112118, 0.11449461759184487, 0.19883757107891142, 0.09285522406571545, 0.10582598391920328, 0.13053227303316817, 0.1702097587985918, 0.2302491941372864, 0.2146238091518171, 0.21669359965017065, 0.10541894560446963, 0.14936508669052273, 0.10718969511799514, 0.180933911469765, 0.14194788469467312, 0.12692485644947737, 0.15839080471778288, 0.09538617770886049, 0.17878298938740045, 0.1692716099205427, 0.08918771578464657, 0.13898399920435622, 0.0946094979008194, 0.2289752382785082, 0.1443109125830233, 0.1406821666751057, 0.23797753412509337, 0.1786958464072086, 0.09011597925564274, 0.07049738705973141, 0.1873454885208048, 0.17019978433381766, 0.0837101909564808, 0.09976147222914733, 0.13016810116823763, 0.17411302513210103, 0.09239770486601628, 0.1741087800473906, 0.1276636347756721, 0.1650492794578895, 0.1620622686459683, 0.13163183903088793, 0.15210131095955148, 0.14401000138605013, 0.10715981625253335, 0.15250449010636657, 0.14483069797279313, 0.29988537076860666, 0.15876124030910432, 0.10126980574568734, 0.14618960005464032, 0.16361616260837764, 0.19697561161592603, 0.19223431212594733, 0.1275104851811193, 0.07873882568674162, 0.20834911381825805, 0.17358610028168187], [0.024476269718434196, 0.029046680429019034, 0.03908249855157919, 0.023102457889763173, 0.022681404116156045, 0.040854554245015606, 0.010950096748274518, 0.010545120676397346, 0.05113677281769924, 0.050197822420159355, 0.08046008879318833, 0.04583707770507317, 0.019986057341156993, 0.041320582167827524, 0.02301643184182467, 0.06717469543218613, 0.0444452613737667, 0.009737539694469888, 0.024598269519628957, 0.012340810062596574, 0.121742483752314, 0.018815454823197797, 0.02444859503157204, 0.07959988768561743, 0.026580358571663965, 0.04984639323083684, 0.05622297801892273, 0.04776668021804653, 0.040669091540621594, 0.02884039862692589, 0.04736228765978012, 0.021475293542607687, 0.02546884770708857, 0.010177097992709605, 0.005402931565186009, 0.030421525698329788, 0.08423664825386368, 0.020372289545775857, 0.06559398767421953, 0.031696592923253775, 0.017417213348380756, 0.04238565314153675, 0.0054548819025512785, 0.025590828954591416, 0.01970337143575307, 0.031979447667254135, 0.048851110113901086, 0.013828163992002374, 0.03468032715318259, 0.0414857137366198, 0.06738464158843271, 0.04419645636517089, 0.01757139452820411, 0.05063298071036115, 0.023407337721437216, 0.03589477390050888, 0.017591957584954798, 0.04499451373703778, 0.05014675894926768, 0.05898611998418346, 0.06209103208675515, 0.027171002366230823, 0.04282359077478759, 0.01430806451026001, 0.040739153992035426, 0.050112820536014624, 0.019114223068754654, 0.04795389068021905, 0.00942925711569842, 0.04317246326536406, 0.0393884711957071, 0.09555128330248408, 0.06342281238175929, 0.00909109659914975, 0.11516331491293386, 0.01061975754055311, 0.016528894120710902, 0.01515214524260955, 0.03014974750840338, 0.021736926573794335, 0.11155464409966953, 0.01675075174716767, 0.014860641695122467, 0.024231019597209524, 0.10028374381363392, 0.04058189289935399, 0.006885571465318208, 0.03618310940510128, 0.013390616913966369, 0.035168868125765584, 0.02353002029849449, 0.03768186921661254, 0.07912713219411671, 0.037319597249734215, 0.07764550115098245, 0.050134546909248456, 0.0348328793188557, 0.02369321486185072, 0.032402995057054795, 0.01932416551426286, 0.03643848613137379, 0.07149770564865321, 0.019726522732526064, 0.07472977362340316, 0.10191151115577668, 0.01868407427537022, 0.08092990537988953, 0.08767642852035351, 0.06630616742768325, 0.023418768651026767, 0.017944216124305967, 0.08844393538311124, 0.0309940091392491, 0.0663833730504848, 0.0696969659475144, 0.05708960241463501, 0.07813994219759479, 0.03764365232200362, 0.045657993759959936, 0.02291133816470392, 0.027540675400814507, 0.03747116606973577, 0.03394895917153917, 0.06529385573230684, 0.026079876442963723, 0.06980086662224494, 0.04096324919373728, 0.024941874617070425, 0.03830135472526308, 0.07855217554606497, 0.01522045065939892, 0.027636115592031274, 0.041112747421720996, 0.06315971360891126, 0.06135587544122245, 0.0470941645471612, 0.023073050288076047, 0.0706278788857162, 0.008515145473211305, 0.01285907219426008, 0.043791150965262204, 0.08201598655432463, 0.027290042853564955, 0.042071234856848605, 0.05412612510554027, 0.025272928141930606, 0.023150977649493143, 0.047264368695323355, 0.0915925191657152, 0.03380995862244163, 0.04338231294241268, 0.030442177812801674, 0.05746572285715956, 0.0271430104112369, 0.0783429789589718, 0.03412841419049073, 0.04627435111615341, 0.058771576223080046, 0.048844935445231386, 0.03161260778142605, 0.049297077785013244, 0.08100374907371588, 0.0184958248064504, 0.04701176017988473, 0.040362989020650275, 0.024036055547185242, 0.04232817009324208, 0.03300155571196228, 0.008761673943809, 0.013966405695100548, 0.015697987437306438, 0.0021301034485077253, 0.10433370305690914, 0.03503865089442115, 0.010155055279028602, 0.027500599426275585, 0.018681588080653455, 0.0402803434553789, 0.017864869405457284, 0.07288739943760447, 0.014512594843836268, 0.036601179745048285, 0.04344883534940891, 0.040168772684410214, 0.044402027560863644, 0.03445501111855265, 0.031191476082312874, 0.004374634008854628, 0.02288270610733889, 0.06161305558634922, 0.018283995450474322, 0.046103894637781195, 0.03713870246428996, 0.026553804527793545, 0.042277544489479624, 0.060318931864458136, 0.019130550317640882, 0.04043597182317171, 0.01714811060082866, 0.05012056484702043, 0.030729747049917933, 0.05146995259565301, 0.022868547785037663, 0.043582466460065916, 0.05245430758805014, 0.02203349806222832, 0.1073686640302185, 0.01859225576481549, 0.029198724223533645, 0.03720663124113344, 0.014965575810492737, 0.025429066736251116, 0.07085992619977333, 0.09959250004612841, 0.07518656551837921, 0.028102316064178012, 0.051482027338352054, 0.06551036989549175, 0.09160905421595089, 0.008274643241747981, 0.01929823116370244, 0.06229219492524862, 0.04124327635508962, 0.03883323341142386, 0.033531233930261806, 0.05072531501355115, 0.028231284632056486, 0.05345284131180961, 0.0275979766229284, 0.008642071279609809, 0.028417192625056487, 0.015564903660560958, 0.011806113998318324, 0.018795492906065192, 0.03585277576348744, 0.04890923140919767, 0.009264364889531862, 0.04309666401240975, 0.026904179867415223, 0.0734378577908501, 0.07563198028947227, 0.03423281952564139, 0.014541535820171703, 0.021970688248984516, 0.023605593196407426, 0.02796364206005819, 0.05887185521714855, 0.04238654742948711, 0.03279518299677875, 0.03256914707890246, 0.05514045544259716, 0.08719609570107423, 0.044560772948898375, 0.030087943305261433, 0.04103248786123004, 0.032286240384564735, 0.03531831069267355, 0.009315646366303554, 0.02183442065870622, 0.017238548716704827, 0.0540251744678244, 0.036117099080001935, 0.050283247328479774, 0.06094404285249766, 0.049981905685854144, 0.04731368811917491, 0.04388585271954071, 0.03003338431881275, 0.02405466675554635, 0.03767959453398362, 0.05815585711388849, 0.024891679458960425, 0.013950771426607389, 0.016346390730177518, 0.013685952726518735, 0.023938546619319823, 0.05210235518461559, 0.048349366334150545, 0.05827835600939579, 0.07280004123458639, 0.0343205488024978, 0.02571697550592944, 0.010514776113268454, 0.02051409912382951, 0.0464649754576385, 0.03814526251517236, 0.03429716743994504, 0.02841049659764394, 0.0351404698449187, 0.03265422688855324, 0.04302585941331927, 0.07490833435440436, 0.02722127544984687, 0.059471503118402325, 0.05299678414303344, 0.033308248239336535, 0.04858267529925797, 0.0605606642056955, 0.0404574421554571, 0.051562598600867204, 0.03010877910128329, 0.04433983558556065, 0.020968464195902925, 0.02401500823907554, 0.04531960039457772, 0.06782736978493631, 0.01867966406280175, 0.010086936326842988, 0.03094329447776545, 0.03184681474522222, 0.07090897473972291, 0.0069468501351366285, 0.018429439696774352, 0.07156782376114279, 0.037060049653518945, 0.04965994718077127, 0.057460149328107946, 0.061050336953485385, 0.019686279774759896, 0.008662933978484944, 0.07651685780729167, 0.009578893568686908, 0.018501591293897945, 0.057675030766404234, 0.07006808431469835, 0.003348569621266506, 0.007526476283601369, 0.03680017180158757, 0.011344607610226376, 0.018711559714574832, 0.028038650925736874, 0.04211995685182046, 0.028073355606466066, 0.03419273241888732, 0.027345713206159417, 0.027691887989931274, 0.027931328950216994, 0.0342000833916245, 0.026122926574316807, 0.05661066112224944, 0.021056610930827446, 0.04917798163660336, 0.022198982151167, 0.025983102241298184, 0.026856014483200852, 0.1019802934024483, 0.030351220193551853, 0.017286617621721234, 0.041729201257112436, 0.05735322069085669, 0.016555019574298058, 0.04482397562242113, 0.10189154738327488, 0.1462697668466717, 0.12979120889212936, 0.1560262034763582, 0.12897993758087978, 0.12018566572805867, 0.07239944476168603, 0.13520032254746184, 0.12863103911513463, 0.122229785338277, 0.1117936527589336, 0.12689846567809582, 0.09451462916331366, 0.14122325170319527, 0.1395233179209754, 0.22060546005377546, 0.11101559997769073, 0.1254715828690678, 0.15105088998097926, 0.15705198515206575, 0.16325426171533763, 0.14152272313367575, 0.14588197984267026, 0.12271789586520754, 0.17166000441648066, 0.17335233860649168, 0.12865002325270325, 0.10404816915979609, 0.11512415920151398, 0.11424530792282894, 0.20356000517494977, 0.10009188379626721, 0.14156910736346617, 0.18103659502230585, 0.09222537817549892, 0.08916820472222753, 0.22827142995083705, 0.11222841771086678, 0.1712404831778258, 0.09375209468998946, 0.10886138275964186, 0.1685149161494337, 0.16201958031160757, 0.1001355740299914, 0.09217046666890383, 0.12910047720652074, 0.14324624236905947, 0.16983038774924353, 0.17480375681770965, 0.08886454757885076, 0.1773866979056038, 0.10560432667261921, 0.07452307065250352, 0.12131484341807663, 0.11277432669885457, 0.15856642654398456, 0.08421094025834464, 0.09061986784217879, 0.11975012894254178, 0.18267718667630106, 0.10367621216573752, 0.078271183592733, 0.270801909500733, 0.15394048648886383, 0.30806250229943544, 0.19047551119001582, 0.15398926043417305, 0.11484439179184847, 0.19308111746795475, 0.11770884433644824, 0.11360096046701074, 0.11923763144295663, 0.13571811898145825, 0.10689396411180496, 0.2227209074771963, 0.12977397622307763, 0.0819266468170099, 0.12701759522315115, 0.12847498030168936, 0.16174986900296062, 0.15161986491875723, 0.0570935877476586, 0.09674183660536073, 0.11930429114727303, 0.2931975811952725, 0.08417713543167338, 0.1608368195593357, 0.12144137217546813, 0.10570255733910017, 0.11444933916209266, 0.13331384252524003, 0.15176793822320178, 0.20614549925085157, 0.10855999658815563, 0.17056545533705503, 0.10744304207037203, 0.20482178981183097, 0.13244397123344243, 0.07203391476650722, 0.14601791161112487, 0.15397410577861592, 0.11984906464931555, 0.18014808098087087, 0.14251120446715504, 0.14534687652485445, 0.08023864676943049, 0.1417772946297191, 0.10750664412626065, 0.1457751402631402, 0.12533251923741773, 0.1447586651192978, 0.10507317900191993, 0.1112123581697233, 0.14305007789516822, 0.11620100805885158, 0.2585815277416259, 0.12535147368907928, 0.12328027311014012, 0.11945237187319435, 0.15210269135423005, 0.08792892942437902, 0.15479680616408587, 0.20483106665778905, 0.16050693491706625, 0.14313018531538546, 0.13727876648772508, 0.06022189605573658, 0.13423851400148124, 0.20113143080379814, 0.15378732205135748, 0.14123576431302354, 0.10653142497176304, 0.06900472770212218, 0.17562990076839924, 0.09564064530422911, 0.17018289305269718, 0.13967532460810617, 0.2610697707859799, 0.11873762428876944, 0.12039331122650765, 0.12764574901666492, 0.19442437507677823, 0.08952388641773723, 0.11044337443308905, 0.25414360337890685, 0.10303028393536806, 0.07169222255470231, 0.1385920264874585, 0.13475203566486016, 0.1145751925650984, 0.11372562643373385, 0.14436747907893732, 0.113285035622539, 0.1310071733314544, 0.12449353613192216, 0.1648044746252708, 0.12901891517685726, 0.13855264813173562, 0.15888807334704325, 0.1250433488166891, 0.17675103357760236, 0.18971338489791378, 0.13713373598875478, 0.14777052303543314, 0.13580091297626495, 0.1914122945163399, 0.20818077988224104, 0.06964431799133308, 0.1254857430467382, 0.20749485731357709, 0.1298295333981514, 0.10147389635676518, 0.22882044111611322, 0.10892874750425108, 0.13917756616137922, 0.08726022468181327], [0.036699666452477686, 0.03844422928523272, 0.018142731350963004, 0.019746924372157082, 0.07373114713118412, 0.045705739830737, 0.04897540500678588, 0.02442920271278126, 0.020224652253091335, 0.023034740625007544, 0.04100523619854357, 0.03846558087388985, 0.05743448215071112, 0.08397968704230152, 0.02456128644553246, 0.05665907512593549, 0.018778165613184683, 0.08291365869808942, 0.061223884476930834, 0.024858353317540605, 0.01708939187665237, 0.009848731970123481, 0.1331863712402992, 0.02752448544924846, 0.0195875704230275, 0.09299361234297976, 0.09700267182779498, 0.029429331771098077, 0.02278899512020871, 0.044911404329468496, 0.060002186946803704, 0.030232984936446883, 0.025435193165321834, 0.027193795576749835, 0.011739931123884162, 0.0029604959627249627, 0.05329663406882901, 0.004213504471408669, 0.011040477347705746, 0.05094906882732175, 0.0594648905826034, 0.02216623859567335, 0.05155510290933307, 0.03670993406558409, 0.028200520755490288, 0.030935509348637424, 0.026497764956729952, 0.07873282171203755, 0.046001381779205985, 0.017746209268807434, 0.03386266966117546, 0.08584019189584069, 0.05945840792264789, 0.03234937488741707, 0.05050938714703079, 0.027260893148195464, 0.045654605855816044, 0.03631117069744505, 0.08231708328821696, 0.06408136454410851, 0.014995761739555746, 0.026890464978350792, 0.02451454598485725, 0.059062357104266994, 0.02560279237513896, 0.017994201625697315, 0.08293279868667014, 0.04310449738113675, 0.016508616790815722, 0.06243388575967401, 0.036607814545277506, 0.06514865453937091, 0.031067103263922036, 0.03687501739477739, 0.008584107690694509, 0.08865480180247687, 0.01234869445397635, 0.022778295206080656, 0.07074211767758243, 0.07775795878842473, 0.03962009919632692, 0.046233592365751974, 0.04752737841045018, 0.03505610620777588, 0.03848192296572961, 0.06830573591287248, 0.02212910523667233, 0.0466751405474497, 0.07478317857021466, 0.05506414039700758, 0.0316349278728012, 0.02792076818877831, 0.046399095008382574, 0.048037857268354855, 0.03455613616097253, 0.03701383240695577, 0.019224504358135164, 0.01696419156360207, 0.08195702292141505, 0.07159622575272806, 0.08332417026394978, 0.02266910672915401, 0.02438110597722698, 0.009669697192293825, 0.014817531264270656, 0.0768528354819864, 0.01735994366754312, 0.05486792026204057, 0.06124461266153958, 0.04264628798409831, 0.025580591027392074, 0.03435200844251085, 0.04902194137685001, 0.059376530480221845, 0.03612192675063852, 0.048787671330501325, 0.045295966701814905, 0.02501244543964276, 0.026772257551783696, 0.053723977543995716, 0.012823958404624136, 0.022649638340226375, 0.043446694253361784, 0.07656490444787778, 0.04013927602500189, 0.03152808087179437, 0.09621088189305738, 0.08276062784716487, 0.03344546763401013, 0.01263147405552445, 0.02073014202323975, 0.02208968606282724, 0.05313488669344224, 0.05834604729898274, 0.028596335941983853, 0.02389179131569108, 0.016351262929674704, 0.09949133047484793, 0.07002261292655021, 0.029075930324324872, 0.022350140934577212, 0.057814346728264354, 0.019436853217484895, 0.043512188785825856, 0.06469239699072205, 0.03475306133623235, 0.13187674776418135, 0.007420969322993187, 0.02651999042427633, 0.03536211224854924, 0.06803000578656793, 0.04035276222566608, 0.02597388291178504, 0.01694931706879288, 0.031660880777053535, 0.04504746597376652, 0.010021141224569874, 0.04340609877544921, 0.09622817393392324, 0.008434489791397937, 0.03033649412827799, 0.02866291586542502, 0.07433263555867597, 0.0707617103762459, 0.04634914846974425, 0.06880367247504182, 0.03363832955074031, 0.0898967710963916, 0.05250224290648475, 0.0067979465529788285, 0.05424150680482853, 0.10556162349530496, 0.07196245336672291, 0.06765487240045331, 0.07345034813624807, 0.04958668978360947, 0.011800627671618713, 0.02639117399667157, 0.03339091235829983, 0.020451434029382654, 0.06845903393696062, 0.014630115783802466, 0.01424161353497766, 0.08149575587594882, 0.06960791564779356, 0.036989267318858765, 0.012026126460114028, 0.06504964461782947, 0.017601069303054828, 0.009257609490305185, 0.08541634393623099, 0.07331603424972855, 0.034327810717513785, 0.039293862209888175, 0.0016654382943670498, 0.0326774301356636, 0.034709679093793966, 0.0270033363631228, 0.024595833419880364, 0.01814216360799037, 0.018161791558668483, 0.05164687318028882, 0.04156134229560848, 0.04906309717625845, 0.05789625756733585, 0.07847294386010617, 0.03386887772649061, 0.01525034900623723, 0.059361702369642444, 0.007043637788228807, 0.007395002503471915, 0.010297914068360114, 0.04930692237394396, 0.0366986014705617, 0.04055885292473249, 0.055879385909065604, 0.03471951626124792, 0.02926710199972149, 0.015626642925781198, 0.01920183731272118, 0.032669196007191204, 0.05106648401124403, 0.06673446827335283, 0.1068778446642682, 0.034801816727849655, 0.021514491927518975, 0.048340026405639946, 0.012381468623061664, 0.022893580426170956, 0.040389290734310634, 0.035873455708497204, 0.015712652275396977, 0.0682367236004211, 0.0325653101754142, 0.08016130013857037, 0.04297152307117358, 0.04623403765435796, 0.05558257136726752, 0.04496715817367658, 0.07298728509340435, 0.05643220429192297, 0.015079156873980537, 0.0255681915950845, 0.03798056881350931, 0.03327997612359468, 0.05967938239336945, 0.057057326412177645, 0.03517235250910744, 0.03272696849307977, 0.020581135468091816, 0.016359007240680512, 0.04988411288650241, 0.03831387104582973, 0.026594678311084863, 0.047856665623839945, 0.06864444469101727, 0.057373666859348305, 0.022366219563991763, 0.0749029463622719, 0.02709385797061259, 0.029741124708380084, 0.06696000695228577, 0.012806165414076531, 0.031455832795472816, 0.06706839762046002, 0.05473495337355416, 0.008741043166082818, 0.039704314403934404, 0.013484653518389678, 0.04552298967610113, 0.0296159429490217, 0.04408183536725119, 0.05838331795530394, 0.002456606216583168, 0.033895680389832705, 0.0966449937550351, 0.010635799990268424, 0.01440051384633989, 0.048031051774160005, 0.03984187147580087, 0.04288350806746166, 0.04222919356834609, 0.01653098141105147, 0.0304226296429988, 0.11184061586391181, 0.10841365248779766, 0.007549993088105111, 0.03812053044384811, 0.07409604630083777, 0.017664710321696475, 0.013646338738908526, 0.033751889277482405, 0.0790830486221239, 0.025506305755698122, 0.051861806568922475, 0.03491483839752618, 0.04591732984408736, 0.011631926372501766, 0.008865205400070408, 0.007365792962445994, 0.07753322162898257, 0.026070757303386927, 0.041083699761657044, 0.0768503789731767, 0.02660106820258079, 0.0318623998464318, 0.052271353342803195, 0.007414087758661481, 0.002395934252490406, 0.03060352257307386, 0.005621472719212761, 0.07940234281704761, 0.024797419282549527, 0.034858461149269715, 0.028295229931245558, 0.004742619585158536, 0.024663070144015364, 0.05486353788000997, 0.02573250309069408, 0.027070246542280074, 0.035324466807651334, 0.026671021187212318, 0.029297303699422628, 0.038862088113091886, 0.02922520590800559, 0.05424831229902338, 0.019486026067170314, 0.04284790724341292, 0.016464533218822908, 0.07687975317821838, 0.015266721711668652, 0.07338108349358663, 0.018673725026019383, 0.015269078030542005, 0.03135002109047491, 0.02316222118679434, 0.029307103759492747, 0.013646632814925397, 0.056082875380525365, 0.05952330131549388, 0.06155375056550838, 0.038748535807826556, 0.07900745345978066, 0.01662610433413647, 0.00523657452504267, 0.029209980748419184, 0.08612054560217075, 0.013822871551383287, 0.04231415092363022, 0.024203330067393836, 0.10911681514699012, 0.026178546831943095, 0.09074387329746969, 0.13642523728776723, 0.0816486679832451, 0.10934728910797276, 0.16398631618358195, 0.14079728862270713, 0.10064461312140338, 0.11760147783206776, 0.11935329515836202, 0.08681777107995003, 0.15033813135232776, 0.14093881618464366, 0.1529634787584655, 0.17329146765405312, 0.17548191652167588, 0.2231428332743235, 0.24140331748640165, 0.18385755771305412, 0.14246384060243145, 0.14759273413801566, 0.10302192735252902, 0.14575379609595984, 0.2699368027970195, 0.08503430857672356, 0.11028737499145791, 0.14242530829505995, 0.18300980242202058, 0.1331264353939332, 0.15341577323852107, 0.32203681650571525, 0.2789821877377108, 0.10185101127717644, 0.15532533405348659, 0.030052761794649996, 0.0576012278907001, 0.12564116361318156, 0.1864184718579054, 0.10204143894952722, 0.1089888540445827, 0.1354562447522767, 0.16500629426445812, 0.10904674156336114, 0.10640664026141167, 0.08350514297490008, 0.11600491779972799, 0.15637294971384108, 0.25133448536507785, 0.1976692525204271, 0.24436233448795974, 0.11182139423908666, 0.1407601367100142, 0.19041492225369439, 0.16065655188867822, 0.0923810139647685, 0.1529915170976892, 0.11424898897530511, 0.15667028375901282, 0.210537618258968, 0.16465242340927944, 0.18227330991066992, 0.12096518054022454, 0.08989141279016621, 0.1726258799317293, 0.19345217646332458, 0.18393116391962394, 0.11077967123128474, 0.20173892320599407, 0.12022580849588849, 0.08654036369989626, 0.19322461914271116, 0.12037022301228717, 0.09966275916667655, 0.11076132534071803, 0.09978339527151547, 0.11570781382033601, 0.15140995586989447, 0.12645145528949797, 0.09635755253839307, 0.1582889078417793, 0.12399702449329197, 0.13704441109439358, 0.14871354040224105, 0.16341456561349332, 0.10795747657539323, 0.13674703252036124, 0.15673568181227893, 0.14110749150859192, 0.08193579749786295, 0.180601533211302, 0.1886643739999272, 0.13309450820088387, 0.16587212827289477, 0.09145183023065329, 0.13267814851133153, 0.069278097798815, 0.09594632851076312, 0.1579652275540866, 0.1454371216823347, 0.09445181378396228, 0.1691900924197398, 0.13307213986990973, 0.13402008509729058, 0.09172457692329772, 0.11453490878921002, 0.12580678128870204, 0.12508974788943306, 0.14173953415593132, 0.1551156328059733, 0.19720909127499908, 0.1928936064359732, 0.11782388464780524, 0.16967049945378676, 0.21100946090882644, 0.10121485713170841, 0.10145516454940662, 0.10915839768131264, 0.20191478251945227, 0.10886450720136054, 0.11409655926399864, 0.1177609950536862, 0.10560647890088148, 0.14633550628786907, 0.16481051570735872, 0.12564716016640887, 0.2186157027608715, 0.1379817139240913, 0.1694557219161652, 0.22645836317678913, 0.10999522855854593, 0.1254678424447775, 0.09899560551275499, 0.10848317688214593, 0.16092964739073068, 0.08486710270517506, 0.07204374822322279, 0.2803076634882018, 0.1411713904235512, 0.18054422456771135, 0.12443650208297186, 0.12016396532999352, 0.1068568641494494, 0.1302553925779648, 0.09927069739205763, 0.08106957015115768, 0.14823659177636728, 0.1142743778473232, 0.14091497840126976, 0.13852354109985754, 0.1389373923302628, 0.13006719877012074, 0.16537051065824926, 0.21236413274891675, 0.157471684506163, 0.16545974649488926, 0.10659929437679239, 0.17486464261310175, 0.14682360197184607, 0.08090648319921456, 0.2475309488363564, 0.09492630590102635, 0.20508664747467265, 0.22157564002554864, 0.16393788362620398, 0.1580063276924193, 0.17989362822845578, 0.12949865427799523, 0.2605329011566937, 0.17090298410039395, 0.1692770721274428, 0.15793632832355797, 0.13619315286632627, 0.15805386967258528, 0.1643695612438023, 0.1667900016764179, 0.2715844596968964, 0.11704398391884752], [0.04555371458991431, 0.04056268240674399, 0.011565418808459071, 0.052281635798863135, 0.02606656231364468, 0.043714676357922144, 0.011112087177025387, 0.05580606171861291, 0.02162938195397146, 0.033659336040727794, 0.01770273611327866, 0.03233655799704138, 0.050401048429193906, 0.05349086153728422, 0.019982949597761035, 0.0035293245582579402, 0.025872635414998513, 0.0177374964550836, 0.06183567762491293, 0.03373446365003474, 0.03416877589188516, 0.050174159041489474, 0.04742564480693545, 0.03372846338606905, 0.04260721390892286, 0.03578522548195906, 0.12751609581755474, 0.02348988866287982, 0.021468131817528047, 0.02419359308987623, 0.028698785718006548, 0.05470524149131961, 0.03334578235808294, 0.06836035798187368, 0.09587477063178085, 0.00488588098960463, 0.010292180049873423, 0.06329392359475605, 0.04351303483417723, 0.05294629212585278, 0.007837672255845973, 0.043480031526996754, 0.07452476274920627, 0.058674054307630286, 0.03050480765523389, 0.04100069054402411, 0.05020875054469798, 0.04329681753006298, 0.09897885523969308, 0.0320847584225703, 0.04247566823323723, 0.03926137840608135, 0.07535871409345418, 0.03291705477749929, 0.06859718472696841, 0.040662631145096384, 0.028985340068174992, 0.01413288797266432, 0.02867210921976948, 0.06623822380788624, 0.062289293127832934, 0.03360550064826384, 0.014492139398498693, 0.04791256047610659, 0.052676732957479544, 0.015266692953446181, 0.03231801914807875, 0.020603670782293193, 0.049087280058301985, 0.018598580718389712, 0.021686388172383886, 0.057765654419199564, 0.014474126546701882, 0.05901802120206412, 0.03895501242368482, 0.09033644906594418, 0.03354131600644905, 0.026003943603427615, 0.055779099493520334, 0.044255713146412745, 0.023702662401774433, 0.007018800424702931, 0.029216647089924663, 0.01762896848958917, 0.04394777010020334, 0.01859893323853612, 0.045496276070480235, 0.046667789574712515, 0.010251674557366641, 0.018307441750948783, 0.04526385026110802, 0.06262190145207569, 0.08054780322709121, 0.018674747334443964, 0.036080834033782594, 0.030307294327940326, 0.04643720058084, 0.02917482521297643, 0.0029900589515818865, 0.013705786623177119, 0.022321661017485894, 0.020316277805250138, 0.03437610597757157, 0.06480236101197079, 0.025834168045548722, 0.07784265268128365, 0.03505689659505151, 0.03552255344402511, 0.012307450524531305, 0.06784604222048074, 0.015457693007192574, 0.0771628825168591, 0.0279137771576643, 0.022567989108210895, 0.01647600125579629, 0.022114021085144486, 0.028187180651002564, 0.03207997157005593, 0.05524828578927554, 0.026751121185952798, 0.038826253512525, 0.03455828096775804, 0.029646326474903617, 0.06702135287923738, 0.046360688866116107, 0.019943780898756813, 0.041567713633412495, 0.0254166988452198, 0.03887260434566997, 0.07565141713712364, 0.07323298792471178, 0.05375562272092793, 0.009113222804444376, 0.024504983412043657, 0.056431243210681714, 0.0444903876632452, 0.06385884640621953, 0.032218523119809106, 0.053764910699101165, 0.06591980534722097, 0.029316946493054274, 0.0068909511082893005, 0.03346344987221528, 0.018496861957828514, 0.054561843717237934, 0.008304535094794119, 0.06944489548914135, 0.02942748753412161, 0.10498625866603106, 0.047187619493342936, 0.01621593786694575, 0.12079008563887328, 0.059392894836491905, 0.039126314950408414, 0.08462441299343482, 0.04648145484679844, 0.01517322130894172, 0.07024945778539404, 0.023790258092049044, 0.01992629775486421, 0.03560428616765421, 0.021840148183400743, 0.0289172164775664, 0.11793626807047985, 0.04162162324064411, 0.06251100974623114, 0.053011307973065414, 0.04961131053278223, 0.008659126760903746, 0.08073538847384043, 0.09738693363033235, 0.04981899313861504, 0.043233441829215735, 0.008164945465978235, 0.07098817673977464, 0.04232515326293651, 0.04181021038675681, 0.01581556960445596, 0.00884529079485219, 0.06470401160186157, 0.03572956069547217, 0.032353798087569885, 0.02282784098497359, 0.041577962692826986, 0.06390442911651917, 0.050655727536650375, 0.030836046717013232, 0.07162490976043046, 0.06375202909111977, 0.033609014717512764, 0.018839481854229234, 0.02177487072913209, 0.04065349159645848, 0.03933415711799171, 0.013935280021541985, 0.022655929897155147, 0.07749998825602233, 0.06497083595604636, 0.044674084056168795, 0.0426682444231119, 0.043174845559406094, 0.03485332548734732, 0.06600617649382912, 0.015705809673818294, 0.005188865561649436, 0.04414079900016077, 0.03352590530994348, 0.018763638072414324, 0.02853546498954529, 0.030958527058828622, 0.09991544560762122, 0.01345865886833053, 0.03577459050575271, 0.0569833936606301, 0.01816133884858573, 0.040459008087054826, 0.06781403339118697, 0.04538631204923149, 0.10715459895436652, 0.08917457234929316, 0.03946004762838129, 0.09216989521519281, 0.026008166423707735, 0.003378780829734751, 0.03233799405279569, 0.05031575710745528, 0.054884128767298535, 0.018287715465703513, 0.044446875544963405, 0.02528774883103324, 0.030530814365192782, 0.06846062213298865, 0.057520511909388006, 0.013652235102199484, 0.05649342405376956, 0.019731845786736812, 0.058233879099134356, 0.05005138926208019, 0.01845635739300633, 0.06378522535669617, 0.040616180122015066, 0.05452773089928087, 0.03535491712682415, 0.057004756381502375, 0.1014421324362047, 0.04866417795710731, 0.03586513252230361, 0.045851920658606105, 0.027370955504011363, 0.05608783663774375, 0.03267549313022755, 0.03609799619880505, 0.01589609448274132, 0.08532614330761135, 0.05346146506781224, 0.052388371477718465, 0.040287672163685784, 0.08819067006697878, 0.035997257073177025, 0.01468769345592591, 0.049516898216097616, 0.02534794999519363, 0.020812084403587505, 0.09406021956237964, 0.05360003517125733, 0.022481324813270476, 0.018424057270749472, 0.047151640173979104, 0.08297330510686152, 0.06987393106101081, 0.042143991304328665, 0.023183613593573682, 0.03329565028252546, 0.020186973415547982, 0.03610842708440032, 0.030169208475854248, 0.030642179190181196, 0.025636686259531416, 0.042972736482624896, 0.026914180307358038, 0.018457350015523843, 0.12867516721598804, 0.053950506990076974, 0.058603283105185255, 0.00536881271727907, 0.06655106131802313, 0.03807373061135877, 0.041187474271282554, 0.027861119924637023, 0.012151895443821559, 0.04997409458155744, 0.016906068412936293, 0.026891131055890583, 0.02234332245279802, 0.016507485015608836, 0.08099567450699396, 0.08348773961188272, 0.03507631117827259, 0.1454764703521505, 0.023785918383509852, 0.03869154999847524, 0.04497289497521706, 0.007356497562795994, 0.022116084255685564, 0.038326161011355, 0.015649014967493713, 0.014590013834094862, 0.011734606214304222, 0.04850563665968366, 0.016379095322918147, 0.008108491219900316, 0.022131164696475025, 0.025536464781907853, 0.059117569180671126, 0.026061550961458124, 0.06452211120631546, 0.03161962107697036, 0.05365274249925278, 0.033630670586717315, 0.05302190955262631, 0.029779823998978827, 0.04324179841205478, 0.048310659622075036, 0.07155545958084986, 0.009300502842961578, 0.05732744590204675, 0.06863734975922853, 0.027243040785833728, 0.1108071010094136, 0.05871664245205466, 0.01784678883268498, 0.020051114006491844, 0.04146696337556932, 0.0592610337480437, 0.05896936600038316, 0.01705398772173794, 0.05179010026040487, 0.02689732613362139, 0.06708147426252253, 0.03228701592888683, 0.05986305281112436, 0.04404330305987969, 0.049088003652286716, 0.010899229946517153, 0.03791772745898925, 0.05175209116714541, 0.02122580390278017, 0.009721489823277807, 0.005912082442591782, 0.06173999252496287, 0.03975118845119141, 0.05626756254059728, 0.16989296564133838, 0.08965577348135412, 0.07571939786430448, 0.1425024471245706, 0.08445253159152344, 0.16398680600104854, 0.09077372247702442, 0.13772059668553993, 0.18944472743896767, 0.1423728681402281, 0.1062924088910222, 0.13598870602436364, 0.09362863100250252, 0.09070876229088753, 0.10056904764496721, 0.06777792048524134, 0.13860692881280556, 0.1709367666626349, 0.21336416190024465, 0.08770189160713926, 0.19941255741287023, 0.1302933756960556, 0.10261534174787812, 0.1838607934769243, 0.09813704455154948, 0.15122593293199316, 0.1679096501902677, 0.08864263800205663, 0.12015422093099914, 0.10653655321220867, 0.08071186239249073, 0.14059925393667072, 0.10927631010417826, 0.13272968324599788, 0.2600091526983306, 0.10755885421531275, 0.07482614149921574, 0.18380974855972454, 0.17962275916943327, 0.19944243627833202, 0.13885352964280173, 0.19401052384637296, 0.17228864802746102, 0.16269710176857188, 0.119813552882988, 0.1885274180676788, 0.12691698968410492, 0.07762755602016114, 0.2207962513784878, 0.07449161101249047, 0.17230313475010917, 0.09437770291697234, 0.17390117165632546, 0.09598534321412444, 0.21714446920668706, 0.09455194434849545, 0.15133537002839148, 0.09133237414062023, 0.10554698092164472, 0.1586001052055508, 0.1472414459567517, 0.1912672640173696, 0.1232311429339461, 0.09514594450592995, 0.15568613656796515, 0.11393641121685505, 0.12317241678829305, 0.13330222049262375, 0.15611250040819868, 0.1321267179446295, 0.08714662413694896, 0.15820997301489115, 0.08355977246537805, 0.09568884779582731, 0.16652889928082004, 0.15700251358794048, 0.18153031618567184, 0.21948242734652013, 0.16747058078180999, 0.20221884042257443, 0.1437902811449021, 0.16005444747861475, 0.0986173031560611, 0.22042589000193402, 0.10440807367558591, 0.12867737881606445, 0.08375679040909745, 0.221924182260409, 0.1131349139905069, 0.12091361611965112, 0.1740743889240548, 0.14321979222586378, 0.15120893775019795, 0.17108601256040856, 0.16932945291046053, 0.128431549819652, 0.11634582333499566, 0.11044207567465492, 0.11404318400309421, 0.0667916210659314, 0.09284890838898718, 0.1308096878346987, 0.10605794959701598, 0.12132684394600801, 0.1025327703973744, 0.20948350138496608, 0.12715842516627163, 0.10068646282888949, 0.08392897609155625, 0.16498279786901549, 0.08343187815626152, 0.2626084804069251, 0.1113697825348936, 0.09864951236522757, 0.14379124593688175, 0.09088347127544694, 0.16251730907242745, 0.13636576157296076, 0.09466268762480468, 0.15783027542056516, 0.1534518416156061, 0.09929852792993188, 0.2166915958514437, 0.11936454611713998, 0.12039112931233831, 0.12180060875834897, 0.2531921403715387, 0.12376340382616036, 0.14152153569739312, 0.12811653781682253, 0.16103820875287056, 0.07422788141411729, 0.21704852435505018, 0.12382056404021569, 0.10745852327090688, 0.19982493919087574, 0.11179123335750774, 0.17803914961405098, 0.10290486839949153, 0.22508500405820087, 0.17022699146764353, 0.07667337675229646, 0.1253890708903782, 0.15637284581316635, 0.10384733657701872, 0.0870546349324286, 0.10799788651638664, 0.134324484388344, 0.1488997897831723, 0.1719210177543573, 0.09009752204292454, 0.16172089555766433, 0.1436198246665299, 0.15061372047057375, 0.19695529161253944, 0.12007113749859855, 0.12273542539332993, 0.20101715490454808, 0.14050175057491288, 0.07698543500737287, 0.09050049338839017, 0.2279745411942713, 0.17320849554380402, 0.16628779034363106, 0.13531179312849417, 0.10047341449535452, 0.20466996124014258, 0.11091620413935743, 0.08134852861985564, 0.2616752445464954, 0.1429233784438111, 0.07772272903821431, 0.09800344312679954, 0.13441058836178854, 0.15466198761714622, 0.14445802109548822], [0.03916136658517644, 0.04089401423698291, 0.03045515426492784, 0.03733533820195589, 0.023203462333185598, 0.07266498520039022, 0.028344308157102205, 0.0698915273824241, 0.09127908051596023, 0.034910916147055104, 0.007050444210108253, 0.07024014383205213, 0.033830119064077735, 0.020862279561697505, 0.011221458407817408, 0.02421642711851746, 0.07426485521136783, 0.030116326743154787, 0.029831625906808767, 0.02526472741010366, 0.0030159459902279195, 0.02785474858683301, 0.06299652275629342, 0.04082329869561363, 0.04360254155471921, 0.03531066657160409, 0.018799903118633665, 0.013651221142936265, 0.06489446153864264, 0.0384908881096635, 0.03541940975992475, 0.026337069575674832, 0.0727799884043634, 0.01929969876073301, 0.07812799362000078, 0.012887366574432235, 0.0179163447683095, 0.02680667650565738, 0.022754930541850626, 0.04629523144103587, 0.039599003648618236, 0.02830433237249963, 0.03342794181662612, 0.01488712430727901, 0.029000414942856878, 0.02070369002467487, 0.03486936700937804, 0.025124491185124498, 0.0230004682453, 0.01998833944526268, 0.01996687838982325, 0.02519834972190438, 0.026330957989557646, 0.05544492152694147, 0.028301838756306097, 0.07444848481100053, 0.02418191168544581, 0.07152138015953824, 0.05355569926905446, 0.025720615740283392, 0.035713760371436365, 0.017496875479992013, 0.07049970998195931, 0.05163662041013595, 0.04715365881565958, 0.08538159658201039, 0.1091682534024585, 0.12278756126761436, 0.018343532392464112, 0.02457315338688204, 0.02952937884401763, 0.04284699811250903, 0.04283239264623262, 0.022955251042731106, 0.01323576409049565, 0.06923357635969296, 0.04249187673849519, 0.05783013592008501, 0.03353925283590797, 0.1040999784891028, 0.02097344029607484, 0.027816273795906454, 0.02319144881766988, 0.03048840990231838, 0.02603884680866031, 0.056946642507682554, 0.10793357199872844, 0.04951287577569019, 0.05186880502151325, 0.008056167953327531, 0.07045590842608362, 0.07541099839727394, 0.021296656741469633, 0.02257438642118359, 0.062201482214732096, 0.010728515571827302, 0.053186900113360025, 0.023012676574580837, 0.038562568443012424, 0.030288647867564578, 0.004774173849000363, 0.044297073036432266, 0.017060212485375814, 0.02391570516920183, 0.027655190642690286, 0.025485161968390457, 0.036421494660316966, 0.014250316144170938, 0.01907178149849642, 0.010782868612295715, 0.018364642783126328, 0.0092603285338555, 0.07625925092725083, 0.046541004776372574, 0.040520550683140755, 0.03965781885199249, 0.018897569752880372, 0.11712818057276309, 0.01828164098697016, 0.03790049107919913, 0.034661662139114924, 0.02495668231858872, 0.03142083682178054, 0.017751339364622254, 0.035820347620756365, 0.02712394834816223, 0.01823339767724974, 0.016155751545738894, 0.04334733181167394, 0.034661294776014984, 0.061790306426701136, 0.07407680983305909, 0.01218790166603867, 0.051697840171982534, 0.12736741395201534, 0.023044609333737753, 0.009086777299671667, 0.027493333800521214, 0.04115009600354824, 0.03476746642263606, 0.03881560369336512, 0.05155421604285948, 0.08481484808726236, 0.03495686993119307, 0.021600731342914514, 0.031958745457814075, 0.05691067060979549, 0.04061306310177315, 0.0197006644521025, 0.012233376764925197, 0.05983161914627999, 0.043504693094291724, 0.07547243338194676, 0.07650855317479, 0.006858285014459398, 0.05690169062290806, 0.033271148276980966, 0.0587174291285919, 0.035055649786954746, 0.010667720689525595, 0.06446780083933845, 0.0316299703263212, 0.03750346804736182, 0.04375301199615933, 0.06381733066518791, 0.030657717907160986, 0.07046144484775141, 0.013541107764467597, 0.02589286264992552, 0.015352057562267873, 0.09918186231516302, 0.048106620961334556, 0.004166855387666146, 0.05795783356006723, 0.05153222620720044, 0.03142695582937449, 0.03733387988177128, 0.04187291815469507, 0.009973311662179185, 0.023913810837257188, 0.015928184948279522, 0.024589970453234855, 0.048019622699939646, 0.05456067112390883, 0.08112893454381265, 0.030132045430946164, 0.03959054687584285, 0.01600342759047635, 0.03245945023081731, 0.02641877446876606, 0.0700763741042465, 0.045492409481084906, 0.044497875933302566, 0.04555051593342796, 0.009858160028670682, 0.010771642701001838, 0.01600141080416506, 0.06275205189012922, 0.0295992780229426, 0.06513896951219067, 0.07476783837773837, 0.05201133819355164, 0.054908230013097636, 0.03793814765231218, 0.04327593349444214, 0.01881317642983049, 0.04950618160364684, 0.046232401218730956, 0.04963988692907151, 0.07990243160747923, 0.04540653186268173, 0.027599713248491753, 0.02973283491883194, 0.00919816438909038, 0.021568826414295472, 0.009336743769381428, 0.040273775448440574, 0.03580340438929852, 0.03732774974196218, 0.033620926187722944, 0.03735188438440673, 0.016431798940175213, 0.012952426022820873, 0.04678420285927132, 0.015095804174052319, 0.018191000635852106, 0.022190067102201283, 0.033910597558133304, 0.030490873832604848, 0.06142161488241982, 0.06118669916759245, 0.07641251926543191, 0.041469572024652734, 0.039877279341453686, 0.027920449065277353, 0.027806425496237352, 0.08466553539619781, 0.020096618791285437, 0.05996569925628137, 0.04048365110065788, 0.05162454937817529, 0.007906825576355914, 0.0157391172615462, 0.009511350708635291, 0.033915681269718334, 0.017524455543025397, 0.028526529531518463, 0.05437805455585476, 0.04327039707277436, 0.008751865534577519, 0.03827926469966769, 0.010323473634343827, 0.04020393935206812, 0.08480292919557542, 0.03713969323143829, 0.07863771548727527, 0.02781203242193442, 0.038908850838197395, 0.009058988507604226, 0.0461273761902703, 0.0595994753530249, 0.019709549815161154, 0.05274823146464769, 0.028578680248756427, 0.04296615734347142, 0.04998569806048181, 0.10576951390248723, 0.026043819198093843, 0.06951827905140817, 0.06477054514107294, 0.060447193536674604, 0.007183854067989159, 0.025875349820125848, 0.09678509639343247, 0.03007149360200856, 0.07441842040861957, 0.011729893576557515, 0.03747227929125074, 0.06165301281725988, 0.04734824622573797, 0.06808847218053415, 0.028600952100532595, 0.08910162665415555, 0.06129737193987239, 0.03793969503021799, 0.02846644896635553, 0.05072099942481145, 0.040812114530126564, 0.014718841393914772, 0.03978088549047243, 0.028289250076340977, 0.038603813300142065, 0.027442042119218968, 0.03221700171707198, 0.06636124962824397, 0.021293810605129693, 0.12015934917144477, 0.018486577646399383, 0.013974765988677973, 0.022170778684085235, 0.011351473403919954, 0.019154662695655134, 0.03371043290826492, 0.08637541395728476, 0.05105548909341451, 0.03652449733635876, 0.031084569709491916, 0.08071342832408845, 0.01000836329694721, 0.017367443069815636, 0.053888975526206195, 0.017068120068870485, 0.03318548588140402, 0.02454171044519171, 0.014801909983361838, 0.07592052730615251, 0.024502135420334525, 0.009968191770894919, 0.04679019199102186, 0.01006800413961173, 0.04511948398430832, 0.03155805250571575, 0.03072046092711389, 0.017524911963846534, 0.0630568148335442, 0.026726884498202708, 0.05766547932580579, 0.04137321528105531, 0.0274895080292481, 0.041192146090907045, 0.021854300939594395, 0.022049367034924217, 0.034084248982253484, 0.03012600434885826, 0.024371738218178507, 0.029363917019509245, 0.05916968279052526, 0.054165069304872304, 0.05768730588897597, 0.08997187644126825, 0.0283413655415643, 0.06847638534964062, 0.03395436942810193, 0.0651028862921521, 0.05350105493562296, 0.04466733422304969, 0.014286770438047824, 0.038432020955951884, 0.02262903260998428, 0.018224208033643663, 0.0618158325960394, 0.03503114407067187, 0.09514339893939905, 0.09532435680739582, 0.09677896625362337, 0.1223931839922443, 0.13150960730854422, 0.15011425508419052, 0.17603913584025577, 0.20780841470696032, 0.21109835535753518, 0.18118986336048692, 0.12674512312514707, 0.11809478339273483, 0.1269229268655181, 0.12005289550870657, 0.18627676618052647, 0.12001757670077495, 0.18444418092258275, 0.10198603762546554, 0.1182159167365171, 0.10424325009807944, 0.16352081147488207, 0.15198543202131987, 0.18177697638748214, 0.09303581085987389, 0.19525230018189177, 0.1597933450830169, 0.19735919806407765, 0.11032195165171288, 0.12853274907683954, 0.15523445064900443, 0.09951874541002326, 0.156311618629843, 0.20375527907162905, 0.19981943245511502, 0.10252755309920758, 0.12415358796715736, 0.17107351479353383, 0.13309009984368458, 0.15827654366148636, 0.09271337738027796, 0.18102605652529746, 0.0983447271573823, 0.08687124282005243, 0.09924153840984218, 0.12035265637678094, 0.056076162654790096, 0.13265493413200602, 0.15812988043762743, 0.1144897416816093, 0.08710598413017578, 0.11335692746797577, 0.057648855217848904, 0.13253881770651788, 0.12829356972360983, 0.07644928526133299, 0.19527708791429177, 0.10739231627667323, 0.14335746061988175, 0.12240180774824694, 0.10227045087958686, 0.15825692127691582, 0.09361180651467294, 0.10663288398063742, 0.10294948631781153, 0.1735182382981293, 0.12897961103590205, 0.19695763679919764, 0.1341653085546568, 0.1113287937187124, 0.13256373902549967, 0.1355050632264465, 0.1509772689314559, 0.2068331732880324, 0.13711246603634208, 0.12331702426308766, 0.09328549902420491, 0.12329630349995568, 0.267923385836184, 0.12441701328498311, 0.23408249078784138, 0.1042360215797089, 0.10949781892122701, 0.15495233063120395, 0.08024652095627971, 0.09633626774302684, 0.2092908398481086, 0.21840702567715198, 0.18826048239134252, 0.2140499063534662, 0.15596126555465162, 0.21449054911499843, 0.17655941104749218, 0.16089764598291367, 0.09434496678295545, 0.15317987417802215, 0.14075215120101348, 0.16062076552771032, 0.13681946613360196, 0.0936293434642721, 0.1200692450220231, 0.07879414537455887, 0.1438354779384099, 0.15092733723577112, 0.23282340756850317, 0.19231152517022565, 0.13056529860477895, 0.1792351799667813, 0.14490759931504726, 0.12228845211211592, 0.18141699023544788, 0.11150099424412474, 0.11531967058544978, 0.11841355808428489, 0.18527357548009604, 0.05191943062527571, 0.11613558031967841, 0.14880679867928848, 0.21580704487860203, 0.11921841723960824, 0.1224341950728558, 0.1879286384792067, 0.11128275829833001, 0.11716155495378189, 0.1730161753948778, 0.16197304765228182, 0.1396257639862597, 0.14314010040834546, 0.22486528381705284, 0.2134799666237086, 0.18881313008023426, 0.18143802270060405, 0.19705326994881034, 0.12750957976095378, 0.10315920240827836, 0.2207391950651072, 0.13738749112235382, 0.08745517203351483, 0.1880100669222884, 0.18025653844233602, 0.20811391237657517, 0.12006246179225855, 0.20442739769350737, 0.15192142920568585, 0.2320741501171142, 0.18164309294661507, 0.13330352667253464, 0.21923098771367222, 0.12693407392362133, 0.12263113138033077, 0.08737666765227914, 0.21963026316370815, 0.09954596738680266, 0.12348223375738598, 0.23292451776796952, 0.13363470265176147, 0.11282723440672271, 0.10580400892649777, 0.17920357931870967, 0.11508826151839457, 0.13443199190078303, 0.16918948385864496, 0.15465930104255676, 0.11015092371962965, 0.22773712815251201, 0.14664593181805685, 0.15231212542857975, 0.1710448827361688, 0.15183093171799555, 0.12478242453653365, 0.0846152103622444, 0.21616630372591317, 0.12242630604305305, 0.12747649481752887, 0.13280012790346518, 0.1814911307883449, 0.054357875560526736], [0.021543328075495083, 0.05270009576634038, 0.0287377707354608, 0.06276867599808611, 0.043806157191284, 0.0033643179949649493, 0.06904204288730398, 0.025110024871537462, 0.03213653435523156, 0.03297500908956863, 0.046079359235591255, 0.06060538602469023, 0.0520809961744817, 0.01768735881341854, 0.010503395278647076, 0.052733080519828945, 0.023649316826777067, 0.037103153590578586, 0.03331502404762432, 0.031500955374212936, 0.05037876544520259, 0.05858936041477136, 0.043272449111100286, 0.02279908090713434, 0.02727920193137834, 0.0325664827687433, 0.0135279828828061, 0.04831027741602156, 0.01582090750162024, 0.029668991664948408, 0.06648831273196265, 0.0434615631820634, 0.028216042774147354, 0.010089712886838242, 0.03549844477674924, 0.012505966678872937, 0.030866222441545688, 0.03929637809051201, 0.032697920833015814, 0.023958851779752877, 0.05980615234875586, 0.08026341223740019, 0.012868554058513837, 0.05896507267607376, 0.07156915962696075, 0.04530905818683095, 0.08298391781863756, 0.03805022679443937, 0.01768736994563369, 0.023425253166351467, 0.08290890153148212, 0.03187358030118048, 0.035565286307246424, 0.04305211659811903, 0.04071737566846423, 0.03504598331346642, 0.06297672967775725, 0.01913688269269187, 0.05272438997053541, 0.05170087555598002, 0.028581077385751996, 0.047725453914608806, 0.018343246665608604, 0.03865495469653979, 0.02373398845520569, 0.04872713805525564, 0.017212577258760575, 0.026256915771227796, 0.03597719311073888, 0.056309234132640995, 0.05416978194261901, 0.04056889418279752, 0.08216629372327588, 0.012652138229896082, 0.03418590466026217, 0.01676540545304306, 0.017722362208587583, 0.012521335629571695, 0.0828436370647978, 0.06893168552778661, 0.012235351805429673, 0.046720519167138264, 0.002586841305856069, 0.05110388825414702, 0.029897330095991492, 0.028155372201581486, 0.050123919354518875, 0.05420340494310949, 0.02560125241870992, 0.0692568501108326, 0.05758422899816651, 0.025013727499754168, 0.02851879078662023, 0.05197725877224002, 0.09077340335352346, 0.04728919724584557, 0.050485590181779116, 0.07333920410019346, 0.004369809585114126, 0.012106168014724972, 0.03219276688469108, 0.042092337826034054, 0.10027520911535248, 0.047682119911769405, 0.025412240393052343, 0.06203602039022371, 0.03325089877762366, 0.048069780750665814, 0.004282290428818669, 0.05601429351372644, 0.022313441731967032, 0.0321938689739909, 0.03966066498833243, 0.08497872171574272, 0.04875225975411013, 0.054055086729931645, 0.059154728514840826, 0.029606547359435353, 0.06182084951433353, 0.03749261042685248, 0.046144827792886645, 0.06291657860856503, 0.05710987046768423, 0.0856119221134577, 0.016561452139285393, 0.0129463116536499, 0.029071735334582627, 0.0060711200512741925, 0.022050626830605324, 0.06393024101271294, 0.038884523237356916, 0.021539556109928526, 0.05299552620272152, 0.07643352204468101, 0.011147938475914998, 0.019843969457724597, 0.023650023722439073, 0.0069144414737820625, 0.016577408314333297, 0.07655589477508329, 0.03490844479529187, 0.04364679582067765, 0.0355204086372396, 0.034341087739448994, 0.0420087348902598, 0.013584334155893885, 0.017961176054086536, 0.046690005765412934, 0.03144497146422509, 0.02549288958107354, 0.023914976009109523, 0.03737050858035218, 0.006385713204508647, 0.038264017275650986, 0.018336671237193514, 0.037165545945754275, 0.007921678734419402, 0.015587904672429431, 0.034805167524609715, 0.0694406132970471, 0.033248620384256355, 0.05516394812730141, 0.019510880592861213, 0.05033667082898319, 0.07715834799455479, 0.04934872384183109, 0.025611597957322374, 0.0703437699121423, 0.069568114267895, 0.03341085757710971, 0.02283977471961407, 0.04150546228629537, 0.036737374975928105, 0.03258112905314192, 0.011569266844162485, 0.04235328808135819, 0.011064397695008665, 0.029458969438564964, 0.03301607212051749, 0.028142384617240168, 0.04837304826651234, 0.07854492476326413, 0.0804454239550978, 0.015968021580192726, 0.03420686291065067, 0.04562482346955221, 0.03577414150640834, 0.015417842460010434, 0.05282198981149122, 0.038281346423900686, 0.007392527440970298, 0.038087898210505955, 0.04260658679413609, 0.05734180645958986, 0.027375838835723698, 0.04121710822801106, 0.036658870594692416, 0.05491637137311045, 0.02398569897195557, 0.01617495647224132, 0.005888631039852044, 0.036843524358118884, 0.027815273751912173, 0.008851563798089046, 0.011419224065321032, 0.0184608121344354, 0.03944691161450464, 0.03888972940330859, 0.013385516504058614, 0.010287141794833587, 0.026636713555490132, 0.04010587937955279, 0.03433742524066474, 0.04374939773697406, 0.013498278422048315, 0.06296701496466994, 0.04482201635255478, 0.08991212613182142, 0.025186180355376564, 0.04423617610882502, 0.024902041695895605, 0.025888463569572195, 0.0624020402028691, 0.08875945946783759, 0.013524279565899633, 0.023604491107107606, 0.016225698964262847, 0.011726160573743982, 0.05396594737248961, 0.03445830996497534, 0.03380080423085019, 0.04086936009116471, 0.08056105798459612, 0.03656179025711026, 0.010762364927359158, 0.016440829022030812, 0.026018174285127316, 0.016463345782540273, 0.07942136406200007, 0.09957060668966733, 0.06634638441028073, 0.03123591588519048, 0.013511794786609244, 0.0677233281021472, 0.015315442778955912, 0.01790416983567411, 0.0214097359275911, 0.04191517975414172, 0.013185654279368464, 0.09411884180735797, 0.027354169978934806, 0.06497096954262815, 0.023900713786133565, 0.031893035702523775, 0.05898692150367424, 0.04129269225813914, 0.01437276494471007, 0.06541528593515977, 0.013890979371353751, 0.043185781105421484, 0.01668888817221159, 0.02191178769862745, 0.046639376450912096, 0.01639523517951602, 0.027828506244986784, 0.020286079816287383, 0.04970299174601678, 0.08054353587795049, 0.033935593091882765, 0.051077059615636244, 0.020886455022264272, 0.023714395756542217, 0.041419436238356866, 0.05378585039579775, 0.03445363814535085, 0.04122819591430016, 0.02912025880505098, 0.030419527465710416, 0.07733218866633251, 0.027394416647439357, 0.04685963474912569, 0.043152102443855256, 0.04422001955390442, 0.047168327364488505, 0.02225247058959212, 0.003920138597095502, 0.029609105913550593, 0.03844098238914739, 0.01565680566272931, 0.05763319961261004, 0.025258343084715307, 0.026633878551365342, 0.04515249471296556, 0.029915380982856732, 0.02884484223613981, 0.017360878773615696, 0.036165353521937504, 0.015768443226988893, 0.015876407160249073, 0.03569819753465708, 0.015784501447342336, 0.04322692948335316, 0.015400789761770284, 0.04573034944769461, 0.05962945069768466, 0.04741206350445282, 0.023593980440637097, 0.028997006629651878, 0.019457392154436093, 0.08225447571021505, 0.024242931067419704, 0.029878145578550175, 0.03544986750057433, 0.009584858580637956, 0.03802624429226853, 0.04585709342791233, 0.021117810283612926, 0.01659726633079117, 0.027027945980080403, 0.024325480153493118, 0.04773458975250833, 0.019190228267689236, 0.034612398376339115, 0.05490813353389967, 0.06433031798223965, 0.05256450538581703, 0.03452819801168516, 0.02855660506611457, 0.0323842929356033, 0.022302992292679846, 0.02217473247583257, 0.03382146191142965, 0.016923996845434885, 0.09603313010302372, 0.016392292563978117, 0.0705486471997574, 0.04227543679007795, 0.06786528610973619, 0.062113968160701916, 0.0667544617317617, 0.049144384611281566, 0.028236570578883402, 0.01498846178947133, 0.027749734690587502, 0.053628522509825416, 0.03365753262187354, 0.023610023818037007, 0.07689917518291622, 0.07434378261677921, 0.0375575631915126, 0.022392526843759697, 0.09078242044779472, 0.1152384870511014, 0.17471714818384498, 0.11837569370982237, 0.2348988235462457, 0.11261531413765624, 0.18768491718219593, 0.15728824044344947, 0.10624386501149274, 0.10401575214928016, 0.12151274451753125, 0.14649345015641302, 0.1658898507594131, 0.19480037677567452, 0.10037399639259093, 0.07646344543900341, 0.08989216235931963, 0.10319216860807501, 0.15189817029749975, 0.14014836953720078, 0.19000734959263355, 0.18530102010117844, 0.10428521854919381, 0.1503991655772552, 0.18669455079361796, 0.1122637587832287, 0.08195785412681289, 0.12927700445288792, 0.18664579169126227, 0.10239499810268171, 0.09130127073149197, 0.19573033234337345, 0.15786380565259606, 0.08275886895717122, 0.03969308942032512, 0.09844272033660673, 0.09259433689294383, 0.10380064806668088, 0.16868679755134508, 0.12376456157653593, 0.11955653229961172, 0.13529782590921968, 0.20689633005531505, 0.13092040142510086, 0.10516062626265921, 0.10705636828788556, 0.08793177184998058, 0.17009005037834868, 0.14333200495457277, 0.09677810536231846, 0.17465362034272403, 0.11353206689818762, 0.0839843180438038, 0.13789406628347933, 0.10944643261609599, 0.10298010733094998, 0.09673382883192971, 0.29770161607302725, 0.18037170491879806, 0.19616178731666878, 0.14059103094041348, 0.2735292725265026, 0.11894849812961183, 0.22698083514114842, 0.15838811814319342, 0.25531542487442493, 0.16907032462768257, 0.1153511376469396, 0.19989447842817754, 0.15254698548233137, 0.09552268093102612, 0.12553116248454899, 0.25591683166567236, 0.15234066842822358, 0.15917285025352612, 0.07077368121827021, 0.10545741854002699, 0.1401493194862269, 0.1291182590648532, 0.17840807122411206, 0.1349873558501713, 0.07336558002862148, 0.12507224804721773, 0.07910500877187587, 0.05820274229336064, 0.1554181321989745, 0.1597856861189939, 0.14481812599115074, 0.11875890908413567, 0.16715454461518675, 0.16032473766244948, 0.10837671579793096, 0.14957989391405135, 0.11341237332089804, 0.07369165003183298, 0.18618702568346635, 0.08267853147117421, 0.11037687057978474, 0.19427109189564362, 0.12887346907518804, 0.11818770770332776, 0.1133555025444366, 0.16626839060336351, 0.15584185399347916, 0.1552445290144533, 0.13215055572800338, 0.15503877599257976, 0.09721681853989139, 0.11911819761735387, 0.10555285873124376, 0.17724965291563421, 0.14916688873199746, 0.06530866157845594, 0.11952672764891759, 0.13963643606984988, 0.10801776865264401, 0.12914049380924553, 0.15336045355070382, 0.06395096177584492, 0.17703186225844547, 0.13397785689448938, 0.07313244917895645, 0.1545364162302576, 0.13415704102953896, 0.1352588483132422, 0.0999595811299514, 0.11684575627441518, 0.1391150031122379, 0.18898667389294133, 0.24437126994598657, 0.10060939079266973, 0.06304531154455617, 0.14118160237558186, 0.14708710892591625, 0.11512969562318176, 0.139066377596464, 0.10889022261835635, 0.09630257423850708, 0.11680348354275338, 0.08175528491847217, 0.18165803980082273, 0.16341995360562578, 0.12140287697548047, 0.1464175432920456, 0.2314081764779985, 0.13532910001231357, 0.09589118693838827, 0.10169163506361656, 0.22342103475239128, 0.22009238367900252, 0.11479705019155517, 0.11940532713197172, 0.13301012601004913, 0.1895784624502994, 0.11804953464888968, 0.13532200508052483, 0.07603458798257634, 0.12478371587349102, 0.15013316500699148, 0.09742061971337534, 0.20713691948913038, 0.07653423890587874, 0.13735869579249993, 0.17927081789821386, 0.1755854015937075, 0.09939857685822062, 0.15476510161533952, 0.14244438149034977, 0.09698481575469486, 0.12104492430808023, 0.13901978556532413, 0.0935364117322024, 0.20315790956374258, 0.1777245383709669, 0.09477310435613617, 0.16831284418003634, 0.22022461955202743], [0.04426080056873616, 0.027998198311252054, 0.0436066604743246, 0.014386859256774187, 0.03184756431437563, 0.016202059705392458, 0.0813922708039172, 0.02564179594628513, 0.04966530919773504, 0.03344870339788031, 0.04898537205008324, 0.025929819748853333, 0.04816558459424414, 0.06145515995740425, 0.06042656554200221, 0.09324861428467557, 0.025255738146370277, 0.06331964643322863, 0.04625587534974329, 0.045752253936370835, 0.053519697685260326, 0.04320980442571454, 0.041160289401886985, 0.035936178319389, 0.13323744584340602, 0.052532426052493975, 0.030337679709191434, 0.01409948019500007, 0.03426005263463594, 0.011138523404952139, 0.010150338002858916, 0.03599127165216487, 0.0650598194624763, 0.0093049241877452, 0.1508261528215371, 0.04211872488667723, 0.02497633067832794, 0.030157020555634517, 0.040464043559040874, 0.07529462222009897, 0.02710710159590235, 0.03078343957895413, 0.04388619781821035, 0.011158356373925926, 0.014442817191593349, 0.006011895738993189, 0.11840663384646177, 0.031524102960247546, 0.02312284839717904, 0.06502495336462744, 0.03919326038158033, 0.024370849496335723, 0.06768115184968337, 0.08115967430057935, 0.014409581035579322, 0.059403177292551845, 0.040881750246626325, 0.05745133261370938, 0.04835853185795713, 0.058245846230420284, 0.0021060309609310934, 0.03448631119681522, 0.010378180122643244, 0.039883543067844585, 0.04241740964062046, 0.025852293147181626, 0.03892007582180668, 0.041703278038767166, 0.053327548230299726, 0.06607426854316145, 0.05126729804032948, 0.04204833589028567, 0.02111240002705017, 0.05275822077237535, 0.03897284252161626, 0.03075310800340958, 0.04326530222897418, 0.006167105257190997, 0.03794793286942877, 0.027735097683034837, 0.025296626772615127, 0.03633360953244846, 0.03398760280106217, 0.04274512721167412, 0.006080716484575532, 0.10044089358416386, 0.05470341580803506, 0.06756200004019774, 0.04409081164340023, 0.004890922955382848, 0.04425619183166418, 0.0727154512424022, 0.021358132544264663, 0.027267399927950464, 0.02369515557802515, 0.021394360483100172, 0.031812130473554134, 0.07518744867411442, 0.08007400872884318, 0.048087592294905335, 0.04501793962845113, 0.04667306253395509, 0.031547799735562876, 0.040809888087096624, 0.0167496162612224, 0.055738967857905664, 0.024619671203254256, 0.032095846108859405, 0.04924529443087522, 0.01636785364098614, 0.01347195815469604, 0.1033781433943659, 0.021076005104987416, 0.024316505732713267, 0.03860424003505614, 0.024734268081374466, 0.02724784062593244, 0.0311155803501606, 0.01658203560509719, 0.03952009108616039, 0.013217123196227476, 0.036406469880603254, 0.03204967339115683, 0.08088917631539516, 0.06088707559683826, 0.04462155484361574, 0.18070777907269076, 0.0665474396373611, 0.035676749466801994, 0.04766418962390162, 0.018652108119567856, 0.009880833567876834, 0.017717085538606625, 0.016465446060465183, 0.05548618493776303, 0.029095960890117567, 0.005922153386563878, 0.10910414668614976, 0.03552866131940391, 0.04498809787037317, 0.04201532887236681, 0.06812831808929332, 0.07780910760629922, 0.027938525927311275, 0.043379173657740466, 0.05487606904353015, 0.008928890947572654, 0.028548528644023463, 0.037535261653829366, 0.08094316755887121, 0.04437371462699957, 0.019672922971949447, 0.1086616337124724, 0.015330993555835448, 0.022342443007801194, 0.029629474156536162, 0.009951617757906206, 0.011203255380678456, 0.074192711035721, 0.041238760386477225, 0.0388807419949444, 0.06305392787908204, 0.006657832318524015, 0.01796878863387974, 0.02003682395297801, 0.014306489301816327, 0.06436086478061043, 0.033137891950900666, 0.01441811758922995, 0.03602496515668463, 0.021920942090218887, 0.0044047485062037595, 0.03794909061980434, 0.005642175856337417, 0.034952183268615045, 0.033849971514428034, 0.033349734294461086, 0.043901675308006816, 0.07325432467041537, 0.05813321789901238, 0.021313577708497178, 0.04306186470785178, 0.08315159124322236, 0.021781518516945653, 0.006530894916068064, 0.017689063897705637, 0.06548280653078109, 0.03347643374581821, 0.03333658343763091, 0.081287056527799, 0.04041205240355339, 0.11436509055783972, 0.005189612347749062, 0.01714303987682797, 0.03932235325919464, 0.05510864699317608, 0.038816319865873083, 0.015682571174693294, 0.06045387657650281, 0.02081014925352065, 0.05144150978594553, 0.04275326857168693, 0.04018756757432129, 0.010445823172631208, 0.01799122561351396, 0.034681184333749115, 0.00505598680319963, 0.05442282461444847, 0.03799805752350949, 0.03857361160044093, 0.022928489197511226, 0.0648339839244727, 0.03991781544755213, 0.039658961759414524, 0.04544526826066431, 0.06375786979333498, 0.014898877143423306, 0.0528519614454126, 0.0379208147933241, 0.03839820870780386, 0.09762689223862253, 0.035889397040591575, 0.0995122961467132, 0.058490257724770345, 0.031783234953763895, 0.060371375730028376, 0.059106025073560886, 0.04369509479147382, 0.037541491983574815, 0.05686257944034878, 0.022986833137110807, 0.017539086984470487, 0.056405791256111115, 0.02131845547410194, 0.04828209064726252, 0.032749733873060904, 0.029167507636884693, 0.030179708010109607, 0.024871068162610754, 0.06788132392102852, 0.054021300456952304, 0.0813055360049475, 0.009882488557195757, 0.033642329726717435, 0.09073325316421688, 0.03993588674347848, 0.028388777645886876, 0.0724351940152701, 0.05416237530880608, 0.02837493288097903, 0.029377691280387808, 0.020750102085003164, 0.029251260857563466, 0.02987532727274811, 0.06726937863277271, 0.022636415123997722, 0.046128522808430716, 0.008413403520535212, 0.05262618527922314, 0.0985415669856593, 0.02213130941527197, 0.06651779083767906, 0.027059034546255134, 0.03814832387433853, 0.07434732266119681, 0.010713586343626957, 0.07036806782707572, 0.019957161821366753, 0.07545710061094724, 0.08297956883325242, 0.0191670194544713, 0.027762451391026843, 0.014732405070390087, 0.03496846598864067, 0.0743330511613749, 0.05139082481036894, 0.003798912484853645, 0.011165072810399579, 0.013006277185922954, 0.01578701732796617, 0.06244513671845198, 0.07159633707487956, 0.050276326801395044, 0.03616844827774912, 0.020155038801021874, 0.01120417749916669, 0.008710869296919554, 0.0671544273791369, 0.04292326862923801, 0.02474315529980231, 0.02228484121587826, 0.01772961113601923, 0.03971256337536033, 0.030365979655471165, 0.04408034736115951, 0.0294152068454423, 0.024709441386221442, 0.0771864753914997, 0.03708810283569619, 0.08322536072228104, 0.03377386055944953, 0.03316718451969791, 0.10386223890236579, 0.04608614617609419, 0.043126958480570465, 0.013510917196981609, 0.013031782018515514, 0.026409278689243365, 0.054052722989581525, 0.045881929399911314, 0.032665871185599826, 0.01968008840776747, 0.02561146808147896, 0.0994675446418114, 0.077622539101867, 0.033436947778682224, 0.030174323728715535, 0.004534449017228326, 0.08629578893305734, 0.03126258496195078, 0.019761548392125405, 0.0806013194960542, 0.03042961696337443, 0.04672992588893976, 0.024382718293054495, 0.03918379057722632, 0.06838261499069631, 0.010239183284284081, 0.032663782039890066, 0.037882056130911224, 0.014259307263273513, 0.027759501354012173, 0.020489205635385588, 0.025559348905517254, 0.08495559639413841, 0.033750661023077555, 0.01722703058476327, 0.046023482937016524, 0.025522651558276266, 0.020228910325386096, 0.0252105394974933, 0.01453240925911814, 0.0688962108688429, 0.04078237296198495, 0.021290109143592417, 0.02104636743752053, 0.012006992037640885, 0.03110931476840051, 0.09622445577406324, 0.09702104740426876, 0.025988096895162016, 0.021471606924023945, 0.17416555434465408, 0.16195951087865978, 0.1519375783391297, 0.14178241544868797, 0.10825249511981383, 0.11908403655979782, 0.23934924567583948, 0.15609207650413737, 0.09741882371599786, 0.14376930805156007, 0.1479253647266887, 0.15799761487869546, 0.08438037999439985, 0.18779422069201246, 0.14394745317986235, 0.2034506422933191, 0.07652604559552856, 0.15458183566806838, 0.17925585620105267, 0.1186944090295583, 0.2121691408683546, 0.11198971333215013, 0.16407158895162866, 0.10686695735785179, 0.21827306802151725, 0.10242988646496087, 0.10203432917478494, 0.1318983145756647, 0.12175453623058274, 0.08669142043800093, 0.08235886620241217, 0.11762187947169878, 0.11239962375839241, 0.1136704180680681, 0.29618478496558964, 0.2688524062978104, 0.12179865690995939, 0.08191176675609313, 0.12109805466025136, 0.1688492388348095, 0.15585276356432587, 0.17861993954284117, 0.09639676020015031, 0.10194792834226973, 0.1705208671046421, 0.15291022224118933, 0.15027583547635004, 0.21521620627027005, 0.15332287119235843, 0.16364856477594003, 0.12176420641480945, 0.20683234208263457, 0.11357420604326762, 0.14848463237285614, 0.0788114448369015, 0.14834544999757782, 0.10039403437986039, 0.13053921953542158, 0.13578972138930112, 0.13972084794659168, 0.10431113434606232, 0.09856431381194852, 0.19813459395663813, 0.165094802796375, 0.14742950617801398, 0.17109466600231826, 0.13623003760585561, 0.14490313158603385, 0.18782303086481988, 0.07642113559995778, 0.07497554324800149, 0.18046518584014848, 0.11965053272433579, 0.13659637654200196, 0.13262898864923045, 0.08160620971466415, 0.13096696377033368, 0.11422486917581409, 0.10781139222672209, 0.07767925402731635, 0.14861928764730692, 0.15366394742159173, 0.18458045407896861, 0.17659819568507373, 0.07541806364315562, 0.1715465003508143, 0.09597747644875199, 0.22169669915456325, 0.17153434397187084, 0.11226683869608678, 0.14412625139812008, 0.11113658489193767, 0.16976737941149622, 0.14842119358945638, 0.08051491124206223, 0.10380873747635633, 0.10174620518228039, 0.21337467071134597, 0.18606785160955042, 0.12453469564206898, 0.10729703935794532, 0.10425660133478232, 0.059285446695866995, 0.07705017254920676, 0.14271709107561037, 0.14855466142762452, 0.13934598915511742, 0.18057662673527375, 0.13065791863482445, 0.08598111831815913, 0.24610344262328, 0.20918444555718452, 0.09994480496970937, 0.09793880206416361, 0.09287095017498359, 0.16317863686708733, 0.20154148223809898, 0.08081355146714486, 0.1590286658029072, 0.15693859983002767, 0.1949776610126719, 0.1639201314537786, 0.08267779674497433, 0.21836445608641952, 0.21088678389787674, 0.10671023061149754, 0.23413889401126653, 0.1729145902208984, 0.10946766546112485, 0.13120044342940673, 0.11889389832504094, 0.0959385879104957, 0.12081243170541711, 0.10031440935563296, 0.12243210963788442, 0.08234879525844008, 0.15143014228669927, 0.12990842369617894, 0.1577703544171527, 0.1554945288808085, 0.1224850544531364, 0.15404616831801832, 0.21467688755365089, 0.07530470058554783, 0.10450708359712735, 0.2160452149109915, 0.10450690548168495, 0.16177357319975272, 0.11415108485380188, 0.18692390411160886, 0.11971364496275783, 0.12150586480856873, 0.18481139559298754, 0.09572533177561127, 0.09322433863417245, 0.11236486898269504, 0.08199165153200738, 0.07240887003717944, 0.19071109854849055, 0.10557293382589705, 0.18720056192250922, 0.17259635729715228, 0.11031999238184653, 0.12357011146377772, 0.10394068391178735, 0.15593171323416755, 0.15721242263680324, 0.11090974003309384, 0.10977783866110258, 0.1067574237822555, 0.11289802045212127, 0.13181451126001775, 0.12051011784933507, 0.1937202105182223, 0.098012326634489, 0.11757764004869387], [0.015468141518795164, 0.008590308334532892, 0.07783251494402066, 0.049574644726817496, 0.027795836904260796, 0.018811552981787827, 0.013322768845682731, 0.034951507914229296, 0.07721192363533191, 0.036535585022647865, 0.015838997351238504, 0.05320682677847799, 0.02024935463850852, 0.03007201125001302, 0.012895985692011891, 0.02687369615159696, 0.033303702584817074, 0.03448653013037983, 0.012058771681040525, 0.007332038694585208, 0.03383205606951378, 0.029914328988525085, 0.03907781559973955, 0.0676776266482193, 0.014280961277108872, 0.022056873858673498, 0.04663940242608078, 0.03850185705232434, 0.014193616989359725, 0.033474107112851925, 0.021538188702834304, 0.029729923844570294, 0.03956833068514243, 0.031881640024948865, 0.08302331101731397, 0.016227634114329703, 0.03925119242921937, 0.045559703721664846, 0.013208152486186009, 0.0347790105297463, 0.01703155259747291, 0.013071398789179511, 0.024595280519861262, 0.01532762698843726, 0.03769481598283164, 0.02064457796222996, 0.04399434728838969, 0.042490845153224654, 0.02402058547886554, 0.06893436468089931, 0.04883081608568318, 0.049438735222793184, 0.09798328639590181, 0.06907733200932853, 0.06340585430734791, 0.018108362492057495, 0.04334741344791837, 0.06648774127825163, 0.04462202610739041, 0.05387002478528302, 0.0719281958299689, 0.049001532315742224, 0.016848115956236143, 0.023059906852722634, 0.02014930756558897, 0.021772915170004126, 0.020468156471906696, 0.018408008327241987, 0.06934564808034338, 0.04551952013571281, 0.08694850781466812, 0.02470378251018701, 0.036148632934782654, 0.08863545401254669, 0.057387437409488484, 0.057188415667042136, 0.021833392784174066, 0.024875552589946892, 0.020819828714593314, 0.06560250010807067, 0.025457700648985337, 0.05112504317366984, 0.04540555593848694, 0.003681409866658214, 0.03169911993609276, 0.053304088942240924, 0.0217934151442023, 0.009829122573137283, 0.015251999357133172, 0.053730586369056255, 0.03407312418858055, 0.03728378862433601, 0.035017573900404386, 0.021454543093568645, 0.007497548294850276, 0.036437042654142715, 0.007218588434625417, 0.08488581966958009, 0.030389674575417303, 0.11015823387424462, 0.01932927334564738, 0.03332211526867468, 0.05844494589837268, 0.06811622108216397, 0.06953869553399272, 0.05590404005488381, 0.041785114663071, 0.042615885904524475, 0.04244828669470735, 0.05093635212688241, 0.018444419947627466, 0.04690168483648449, 0.050654053993639536, 0.049652150919428095, 0.04755884918267839, 0.015138993458094774, 0.001230508794378693, 0.014996857335063396, 0.06894003468914889, 0.0881005213886965, 0.020734886202262715, 0.009974325621442404, 0.015834143705433235, 0.01746531193930423, 0.021265822360874154, 0.08964467837358825, 0.018216487842437346, 0.005775895097031025, 0.005052951883044443, 0.0664395684725605, 0.044378423554007895, 0.04193177788692992, 0.10746463856776245, 0.043542954517761245, 0.0434919281542534, 0.030961016964283772, 0.036616660945583135, 0.04635218014300335, 0.07975510787218809, 0.011454280338512035, 0.045898189855506644, 0.06914901605341583, 0.02065739485260565, 0.013785289193037897, 0.017916498763952404, 0.024222009924415033, 0.05307279119733721, 0.05420150133431889, 0.010415456345072016, 0.056537934360676445, 0.01421865148586221, 0.055108869637479074, 0.04761155279993545, 0.05003314356144983, 0.021421023993752897, 0.08540231734514236, 0.03027921702596359, 0.000733894994482398, 0.03162874578265473, 0.02391472182353027, 0.04473175635212101, 0.013113089862599736, 0.05937925787293352, 0.01592975459061563, 0.05164511429029517, 0.007782111370033817, 0.08685153879923746, 0.07589193235617131, 0.02833475671650376, 0.020037237700307742, 0.04489198232477065, 0.03438149025896564, 0.0388428961741738, 0.03839966702798847, 0.05269330882583745, 0.02952259932499146, 0.015362357644335134, 0.024143483278749045, 0.1003168361785356, 0.04865862298174761, 0.06252853185287677, 0.09712902246974409, 0.0208457927510608, 0.028587780834641308, 0.04144814993196633, 0.03284251346485689, 0.02970466299302643, 0.021511677332455292, 0.00895019151357701, 0.025966960529331118, 0.04661967985157389, 0.02382125017902581, 0.04771906402311288, 0.03371071863512043, 0.03653243831649888, 0.04368927635368891, 0.08422653278103098, 0.050776463831425644, 0.03222683517378755, 0.051695673100766726, 0.03619138435169589, 0.07607070088852197, 0.02086552089167526, 0.048157216879189946, 0.018580270079837646, 0.012695917521341471, 0.02834235259797424, 0.033321491864626296, 0.0569361856469186, 0.03194841105141677, 0.0318282944499515, 0.01778506069967989, 0.05569678047322668, 0.02640277933096513, 0.037811010333825834, 0.005073014453955693, 0.058235749311279505, 0.04347913352830801, 0.00014642657731656072, 0.039025293808663264, 0.012367929066385841, 0.05053577791841235, 0.061541738905361854, 0.07076093854266219, 0.07174142694566399, 0.07935613670269959, 0.06919200866832398, 0.0375179696129635, 0.015597296551277395, 0.01414018050127197, 0.10694660464650951, 0.04542171620414592, 0.04221855859213974, 0.010336459363315953, 0.010547546571615385, 0.03467099093541037, 0.03656103326648008, 0.04995652423531283, 0.0527950164541835, 0.059643811255227774, 0.017721495751175098, 0.03682496324472595, 0.06942586682271212, 0.02907170564867556, 0.11517254723003134, 0.0258901445340598, 0.02172146207158221, 0.06648046080954373, 0.0720668735448271, 0.04328941460698843, 0.01319360917477752, 0.04261558904545382, 0.05983346338325646, 0.02662488928763196, 0.07417484011966735, 0.01705592658254318, 0.026966356999764685, 0.07669886952498928, 0.037643477917299606, 0.010408344714960549, 0.06896752383909188, 0.033168735608342104, 0.019817484062514268, 0.11114036984508857, 0.019137966228299774, 0.027573450497584417, 0.009111171693803044, 0.046914379272493534, 0.07987857155967504, 0.03629262813774403, 0.04770074039697647, 0.02724548987316666, 0.04664040432544425, 0.045351969165494666, 0.040895312995417044, 0.05565244828176219, 0.0032815249278428382, 0.034332367504248396, 0.022148725765873678, 0.02374681833316572, 0.03180824533046689, 0.08321561632328667, 0.012418142778187757, 0.03473907185252756, 0.02134517464583041, 0.005066869935035356, 0.027956482190347742, 0.028746223797497805, 0.05646717057970818, 0.029077375656925142, 0.020540788609650917, 0.04490203100431245, 0.05934809880272951, 0.017265718743146863, 0.07718482782365754, 0.1133087175549008, 0.015635396557627246, 0.013026902397541562, 0.03479626917396672, 0.01841039804276079, 0.015764187010063324, 0.041369883037987165, 0.08064200403168797, 0.04566754891129676, 0.016814984628581442, 0.03142790206766222, 0.06797735040890984, 0.057172808301402256, 0.020147131217527203, 0.029713769145018887, 0.013610317673737882, 0.03787281639233697, 0.034135820824303664, 0.03254976589232683, 0.08517316440702416, 0.036337019701022655, 0.009343994552182266, 0.06104022519139107, 0.04007899136922788, 0.019155694280925673, 0.008906970688258298, 0.04239369431161322, 0.03584945465263445, 0.09816048899665475, 0.016088423908513505, 0.030392767475859728, 0.03942107374314219, 0.07732664482318796, 0.005145101576999878, 0.06808835343690589, 0.003837551012111362, 0.024261028338514734, 0.05857407959410921, 0.013662148339790292, 0.07392066196189262, 0.04599091749696527, 0.023266897405846976, 0.02980180455779191, 0.06792656524339691, 0.04696939096902497, 0.0198584654572187, 0.020868335486738943, 0.015358912223746302, 0.061852561484556645, 0.04615894715243485, 0.023125880070438143, 0.03696534789924044, 0.04865594382863492, 0.09289929279475473, 0.007395186185021885, 0.02374661238718545, 0.03827006206847727, 0.05716519015550148, 0.11577172757824883, 0.25342380919028074, 0.1001407096919138, 0.1247743351268582, 0.20638127956772223, 0.11033666844014078, 0.07397294626571238, 0.1576576370280236, 0.12868395424447954, 0.11303128791041672, 0.28312072972767055, 0.10474877883098088, 0.09302674923674203, 0.1216645805106964, 0.15279719315003604, 0.13154773885617033, 0.11171777558047324, 0.09934871195582673, 0.11704633652698249, 0.19074687006650493, 0.14126681577181444, 0.11886674314155243, 0.10386349313193932, 0.21679585275705904, 0.16190720431040972, 0.18821939709596336, 0.14897744811605662, 0.07346510945353657, 0.09048361695022322, 0.09294414820033126, 0.09033039314090274, 0.18071287020575255, 0.11883633735124022, 0.13567195739597082, 0.12992853589821607, 0.21150828804820776, 0.17381549812853336, 0.07495074067264795, 0.09385217330418527, 0.21358720696298406, 0.108564560796367, 0.11792716933996417, 0.11957060341956094, 0.12649271870031953, 0.1514509817934595, 0.29021195077802986, 0.14612970873713493, 0.14319504902232438, 0.20383415452670306, 0.17476685723522678, 0.15947843698086217, 0.16696409467840567, 0.12776541290804744, 0.2573946851771325, 0.20448972325539216, 0.1641676525468938, 0.1303885635570623, 0.07401654744171537, 0.10818932350957766, 0.16768513567512855, 0.19066309643676504, 0.09726949618197978, 0.11928912907023914, 0.1309849979588762, 0.14111746597336605, 0.1395201712148264, 0.06684339328785427, 0.19111999223241583, 0.1463827068801038, 0.18633172963745892, 0.1521041608066298, 0.09006975087686442, 0.19545045361155644, 0.16056376858614385, 0.1768428520881571, 0.07381595234619454, 0.14855365210678428, 0.15180550573859364, 0.10550349848926999, 0.09706219207146205, 0.2075971697922796, 0.12161815175204538, 0.0782375643029809, 0.2455563165131025, 0.08911057695513591, 0.10453152252011932, 0.19088232686044648, 0.1052959197841119, 0.12953297118656337, 0.11022024031262845, 0.12787614134140313, 0.15030161768663675, 0.06603359885048121, 0.1426018206984736, 0.09386907200678252, 0.15406233229441568, 0.15516497078351676, 0.1376283328863792, 0.21072314033517614, 0.041523897234583274, 0.12246158032212406, 0.18668488803086802, 0.1756637723883614, 0.1414475732599385, 0.22953058738494292, 0.1730731426505372, 0.10431990653160028, 0.10930394026217982, 0.12795068265404552, 0.11738460743799806, 0.08022456080652773, 0.1424968068022281, 0.16732382850022987, 0.08417969584115781, 0.09094742214074358, 0.10885903757298365, 0.10532343861996196, 0.1947849104180932, 0.2092149478266947, 0.08932884258683771, 0.07110537670087069, 0.17113165464252234, 0.10704450134653598, 0.09982157876947895, 0.16621688555460423, 0.2154643804533407, 0.1439886720618233, 0.07431123944115825, 0.1612000711611472, 0.17025643988745287, 0.1808378627174534, 0.1504478949937038, 0.11363061668816954, 0.08548742684070021, 0.20005674159619957, 0.12099187559215352, 0.12861594383139163, 0.10368856892455369, 0.07062445758492686, 0.08388420974370092, 0.15250101685523987, 0.19260087370639667, 0.2629159967182204, 0.1477104684454389, 0.16430454910732806, 0.20631257153581828, 0.22668307065032423, 0.12131203809985891, 0.14575229695765302, 0.08468572923447937, 0.1195227200514637, 0.10704189640819095, 0.1256659216596745, 0.1286282783257775, 0.301526912371628, 0.23529548663645983, 0.09701485789264552, 0.1255209356895648, 0.08961649160482921, 0.10377261714893393, 0.1909266330767423, 0.12021830538287759, 0.09381113995914347, 0.12098830586182885, 0.05339588889910374, 0.20088834775378928, 0.11791466415161267, 0.20997771236579865, 0.1606123347301036, 0.11648618572507985, 0.12836137233534828, 0.20101672445889562, 0.16744646098231897, 0.1263461445341818, 0.11219082050956786]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03636049754277337, 0.06548803125042468, 0.06745351289282553, 0.010109462364198407, 0.031087302668311168, 0.061116955839679576, 0.024426222989859525, 0.07224084038170986, 0.03337727168400306, 0.031143737433012575, 0.011584160820348188, 0.059910312775173225, 0.016092234836833086, 0.021736390372097958, 0.02498182628187351, 0.03977676657086704, 0.035702824825420976, 0.035380617700866424, 0.017031743700499646, 0.041413443395867944, 0.07281870624865405, 0.04074769982253201, 0.042443210404599085, 0.02435395264910767, 0.0364003731374396, 0.02217467310401844, 0.033891995626618154, 0.06210309198650066, 0.04393276016344316, 0.020227969653205946, 0.04072056690347381, 0.0631505851924885, 0.016767498309491202, 0.054090271951281466, 0.06027575371263083, 0.07339303207118064, 0.058637640831875615, 0.0690240903350059, 0.026102576885023154, 0.04982197657227516, 0.025802279815252405, 0.029861955626984127, 0.03122344409348443, 0.02457501061144285, 0.033143135224236175, 0.05346987360098865, 0.030154653104546014, 0.045824056724086404, 0.05489557639521081, 0.029978493221278768, 0.017845384318206925, 0.032524970738450065, 0.03871801498462446, 0.010000880592997419, 0.04882088986050803, 0.025707706081448123, 0.030975442459748592, 0.03189089831721503, 0.09140707872575149, 0.024481774598825723, 0.03908628350473009, 0.03408952565223444, 0.030649971740785986, 0.05691865611879621, 0.0748138441122137, 0.1282226204057224, 0.02598548453534022, 0.02252057514851913, 0.022962535222177394, 0.03868509331368841, 0.016566001504543237, 0.04655972545151599, 0.057469637686153874, 0.014507568648696179, 0.04501719005929772, 0.022084338888817, 0.020492669609666336, 0.023454104157281108, 0.02253799706522841, 0.04502188785409089, 0.02435240527120186, 0.049105985890491866, 0.028571631701197475, 0.0172197649590089, 0.027374794262868818, 0.06739235250279307, 0.0027243167414781055, 0.005233609645074466, 0.0331948072562227, 0.02220476348156808, 0.03367312514455989, 0.03354735337779857, 0.08583560542319901, 0.02503486757632345, 0.028412277752067894, 0.015945966806611978, 0.02564638612966519, 0.022304708509182092, 0.02858194384316448, 0.03826472602668218, 0.034623278261278756, 0.03071635313972365, 0.03511384900775738, 0.005928766386205098, 0.03253698982007336, 0.05346555801224895, 0.046568879843107425, 0.050509364882600494, 0.04095570897334255, 0.03960307803936303, 0.027956244703091215, 0.05131681413331535, 0.044310947487247176, 0.062202053668443114, 0.009494965015619528, 0.048850627717911266, 0.041095922933891416, 0.015346842119470239, 0.026936120048048906, 0.012536154463305138, 0.031271416519302875, 0.018267137565999292, 0.06405249499948695, 0.02667242199095199, 0.06025167844200041, 0.004904088655166561, 0.048401969761471264, 0.030591720569645986, 0.012920074877911247, 0.09037457319209352, 0.048848642472876236, 0.03405091913009528, 0.04555321364023257, 0.06788789192796685, 0.04915908655675594, 0.043972056882921606, 0.0164421370573109, 0.007464114078175044, 0.024593907546659466, 0.04542047681752592, 0.08817456546239555, 0.04452710913028568, 0.024665181554155424, 0.06707714754156768, 0.05074631037132349, 0.07503852189984173, 0.009148625103989616, 0.0416115114785498, 0.018713194294832647, 0.06591157492948696, 0.01816820371459471, 0.08721733596757986, 0.02340444891160587, 0.05273890266835224, 0.04256311178323813, 0.049273117547272705, 0.03354371314344462, 0.027742120255425107, 0.05789071001345292, 0.03507682697090786, 0.04859446060436312, 0.06196989874297287, 0.04814212159544695, 0.019128019594063517, 0.031866915815044194, 0.09799618492252193, 0.01744892717397306, 0.05744175890868064, 0.035657023181556724, 0.005013846730435034, 0.050210019617225043, 0.04780994000611827, 0.017050538590410724, 0.08915417070966214, 0.021759383962489665, 0.011535537159943487, 0.011924806603929028, 0.0220218166577979, 0.02572872555901995, 0.07847235014196485, 0.01723360786854755, 0.06167378553072922, 0.04829271449125372, 0.08128154237056151, 0.02632223033288028, 0.023087212321115658, 0.022641526666120626, 0.04171272928942926, 0.0792315301077906, 0.05004174876376055, 0.03768584341742098, 0.011530518386280164, 0.008396589237236185, 0.0506857548316475, 0.026774908874358516, 0.02722647233895259, 0.05897382630791981, 0.03017950577486772, 0.05745643487898633, 0.02712618777877651, 0.03145843402307946, 0.025398440157005098, 0.04738165400340222, 0.03387159769772552, 0.013680497941095382, 0.0940905734023545, 0.05437747939140536, 0.06201568183314521, 0.06193354092829395, 0.016763837666076142, 0.0056120929002645425, 0.1032507760100998, 0.053629231260856614, 0.028423536132322624, 0.027858386965817772, 0.038873483790666796, 0.018419765801809262, 0.007890167144068982, 0.053140719974180683, 0.021282604175212327, 0.05970192141830921, 0.02388721411989536, 0.02035251873166999, 0.026300214522052556, 0.03485517343506217, 0.010329632532375399, 0.01781309718353441, 0.03283528865722474, 0.05185629241168499, 0.022566493680642452, 0.06621604101383127, 0.03902064054273069, 0.015760377937112935, 0.032357056115870364, 0.04072505318617914, 0.03052094380109338, 0.03142397981719114, 0.026019836695923004, 0.020777251702384092, 0.03754521756491158, 0.021192101121414453, 0.09540745508274995, 0.02961518595839152, 0.07204086126876064, 0.03857435745885596, 0.02429616160952719, 0.03834904884570278, 0.039854165152064525, 0.017518087915959768, 0.03199198625225108, 0.02292584158567479, 0.01741172331094276, 0.03618118724261876, 0.025923129287548363, 0.04325649293605238, 0.010835806006070925, 0.06979433572269045, 0.02924287829955574, 0.07476459519239143, 0.034985464881174266, 0.024187778362829704, 0.019478372669254895, 0.03235923060856294, 0.007197295290097827, 0.041542959297657944, 0.03480330102320295, 0.08002113812835887, 0.0036747996500707814, 0.0854693481232971, 0.044401971899787895, 0.019599235129135195, 0.12275592351215892, 0.08278014633106068, 0.04923540160234552, 0.06339789106277749, 0.04323261804529466, 0.052922613904229365, 0.03576811526727397, 0.029049077566014603, 0.036623318010242656, 0.019093474475084804, 0.02510948310373351, 0.05707184653147124, 0.026939010713249445, 0.04665853128244635, 0.010547468646109337, 0.02684943719941657, 0.05739024643844459, 0.032085827115224674, 0.0451058099133661, 0.05228229631029535, 0.01564633581438102, 0.05684162118996028, 0.04745706362882629, 0.03822841274086386, 0.023629738971067127, 0.08519042676198296, 0.03421468514716253, 0.014207087897375459, 0.058975488718715496, 0.07649686434888281, 0.011899362998519791, 0.0038281503202597378, 0.009081923653866397, 0.02836320138158044, 0.012712178904621396, 0.013633738926728256, 0.012503382149589015, 0.06978888835874386, 0.006501585648948094, 0.03523069644870702, 0.011903461509064073, 0.012309835601627128, 0.03899501789419446, 0.017349117588310037, 0.007138736591514316, 0.03823245002422482, 0.04956801734806504, 0.003224586430405907, 0.0248945181738236, 0.07856299605919048, 0.012917543226649286, 0.022423977206926793, 0.03551303168933373, 0.05478867744386662, 0.05389564743381925, 0.03666619559226092, 0.013315989326656563, 0.07800576189765707, 0.03607035490858834, 0.004986812145943986, 0.029672991840925533, 0.009916047547449125, 0.0047259249731723685, 0.05461053973704111, 0.04639117629267275, 0.03203549837053288, 0.031218022704706527, 0.04517975750786718, 0.06181196600664407, 0.013614295585284708, 0.04259797417034861, 0.060180717991897836, 0.0263494708633516, 0.021656205026374664, 0.036455863519222476, 0.008357184906344628, 0.031374745740322396, 0.01800961974367965, 0.07547031083959155, 0.009980409377021715, 0.04736805785796605, 0.21938726917142048, 0.11759842018363997, 0.19429157517151907, 0.1640188816236332, 0.11772724217735231, 0.1403432575170882, 0.09309583576396108, 0.16868880135007203, 0.11539214130607434, 0.14039262518053874, 0.08320018707308918, 0.13967588864034042, 0.14723273314302787, 0.13309959933394566, 0.09437330198124982, 0.12464839266613126, 0.08856253058183938, 0.15458066307473928, 0.11327583299134858, 0.16016404784750193, 0.1817630833829753, 0.1060162037902046, 0.26580152625683695, 0.1294351412798278, 0.08437728523858823, 0.0857853471825365, 0.16652956721372902, 0.2023952192394063, 0.08899030450265855, 0.13314169395016506, 0.17652353562880307, 0.12705293629551306, 0.1438404354848899, 0.11733463863492943, 0.12053405211190693, 0.24222195090260357, 0.12318768276600167, 0.15958302043145522, 0.0860491806815844, 0.18909055972471833, 0.1062009614543058, 0.1637113801552914, 0.14373107260325924, 0.07472503129974939, 0.10821851959917694, 0.15513443882809952, 0.09478024381678551, 0.1545660724514164, 0.1570417732000351, 0.1326007573516108, 0.1911316587938927, 0.09874444047454745, 0.1432522982941009, 0.09427428463823162, 0.13515632803319022, 0.14788009371841326, 0.11761252098949626, 0.15597478748532012, 0.1507951013627462, 0.10735321251559071, 0.2168126401375048, 0.17043341242242604, 0.15786769450642169, 0.2455949824070558, 0.1597140688681975, 0.1637093021417968, 0.11048867512727156, 0.10352344848797657, 0.09664428129326552, 0.13306565349921584, 0.06385692424373701, 0.15578010730678216, 0.11552145311725326, 0.14831445791060105, 0.11359820709913038, 0.09361306816572323, 0.10317058695363812, 0.14361047360580415, 0.08290407015010715, 0.14430312003241852, 0.2357876641326584, 0.12809780600946397, 0.14689958305098116, 0.06138046650448814, 0.14447436318732798, 0.16880922223208472, 0.1549559077830054, 0.09053351896000095, 0.12999872822547331, 0.11826557383756153, 0.1522940318682231, 0.12422214014804922, 0.1527824837830849, 0.12398239676258527, 0.16785483516287059, 0.17851249140221626, 0.1316408783895895, 0.08157555159414187, 0.13264904147945344, 0.1613577181706205, 0.09244013344869018, 0.10679448663722724, 0.15142613468924537, 0.13697171030798927, 0.17555154481669888, 0.1504844828741625, 0.09736725929542445, 0.1499471382703632, 0.13118423492414877, 0.09898594275000505, 0.14258034294471145, 0.11358800999005325, 0.10936098915408365, 0.20760724815772846, 0.09296964097302407, 0.15675073256716132, 0.20309463405283168, 0.13939111173385754, 0.07783618857502006, 0.08207027465687133, 0.11448884368292056, 0.1101761196332518, 0.18164083681767806, 0.1674539566738531, 0.2193645594525151, 0.1569161721272394, 0.10683174987207167, 0.10885166804655455, 0.12073192352545448, 0.11764306778786704, 0.1294809317914769, 0.07725346164079383, 0.13435577333439142, 0.12059533124556765, 0.11319732861011289, 0.05887723578780424, 0.18157382088247687, 0.10378667342592962, 0.1586358470376581, 0.13405793462879956, 0.1176731767191086, 0.1282685890328139, 0.07837784505682066, 0.1475691783707589, 0.20204709260724485, 0.08441802172455937, 0.17899999336805195, 0.16611721512163058, 0.16222594189457595, 0.23561400157632306, 0.07681188377318904, 0.16568978258874267, 0.1573350402759388, 0.18981612782226875, 0.12268860329641029, 0.1620670035481453, 0.185505659901537, 0.06977547032875009, 0.12143649626523256, 0.11932546462048776, 0.11295800082734786, 0.2373343741055578, 0.09777963365195319, 0.13468645949615166, 0.1524615494417958, 0.18709700263570994, 0.10145730935619213, 0.10236311543849297, 0.19230269361287355, 0.08048428280744702, 0.12587750796228647, 0.12471874826587737, 0.11385449295630679, 0.2224815500085242, 0.12277777976123616, 0.07544535983470269], [0.02243338578409748, 0.08780482006841339, 0.030579230224248022, 0.04081281957041938, 0.03782191619393416, 0.014178993897075998, 0.010762684978544712, 0.06833358129370026, 0.0498217242420651, 0.05885629238036927, 0.042381344974273816, 0.03431071534578223, 0.033429730392526835, 0.0265347591630416, 0.05476642785652075, 0.06506709250970744, 0.029995902150403708, 0.065988097776426, 0.01588977323990548, 0.030819073799648322, 0.04048532464366872, 0.032773178318166174, 0.06805572120356373, 0.01450699719498516, 0.032292173855239525, 0.06769922314560972, 0.054780398786533624, 0.06554755149409175, 0.03667605502414517, 0.02488701320544351, 0.021088237554067746, 0.04228993464494124, 0.034281163025298156, 0.017139748451882042, 0.011127185243822169, 0.0375364713545423, 0.08945166802732274, 0.07279006676981226, 0.012925305163662415, 0.03059023256355431, 0.06340649255434982, 0.06715813069604337, 0.029847780606360175, 0.09822709675063379, 0.052452463351073675, 0.03435820537561085, 0.06987148939515464, 0.05740787986724172, 0.015372243051388068, 0.0665037048747763, 0.07478476676624268, 0.08776557529927231, 0.014062115842534695, 0.04725403799966443, 0.08661071929964237, 0.08342832326889038, 0.07862878002924845, 0.046361835484276526, 0.02878435163438553, 0.015580618637613952, 0.07877060445025563, 0.03815493269939907, 0.04944511398207396, 0.03407715405046474, 0.10761861194623634, 0.03016792456037365, 0.022841849022370297, 0.06606970433495007, 0.03718954700161703, 0.012627114865608746, 0.03620845003752038, 0.062158790169632994, 0.023212236374092754, 0.04302870554965921, 0.02929301408585161, 0.03083781302848365, 0.03637892506958451, 0.023604992056789342, 0.02403326507192105, 0.035344790521776304, 0.05871108376595657, 0.018609798280522227, 0.03068890295253368, 0.058460660875425674, 0.006343549939629156, 0.06176590090035461, 0.016957245061348658, 0.018619125221448485, 0.06667592024314217, 0.03243170132918749, 0.05601992641459219, 0.051719058174057864, 0.06817694360506721, 0.018081314919982105, 0.02516917033062782, 0.02391962185356533, 0.028016191681672353, 0.035723619803320616, 0.0530973822606029, 0.03509985581331421, 0.07254918047692627, 0.03363948730111588, 0.08058635037741624, 0.06345304747810587, 0.09331002700491808, 0.059818850495503284, 0.03593903187720571, 0.04142596713791136, 0.032231258373940364, 0.05803461986943148, 0.06897840372403152, 0.04378479075967334, 0.037304654106264934, 0.06535241118399426, 0.03191991629137192, 0.011921191417059163, 0.04670415852160659, 0.05911703112360556, 0.05684499796188902, 0.02439317886455683, 0.015330939750128891, 0.022262205711740535, 0.0765989616047591, 0.04070335649885237, 0.039801320526748896, 0.0378861342323944, 0.03689981997013092, 0.03130332886939868, 0.027545397315407172, 0.05995180625177454, 0.03077058558119461, 0.04835684347199276, 0.052764799911528826, 0.06140507241070736, 0.03633310858276673, 0.09547457491862588, 0.06995933741563931, 0.024487500268151052, 0.03080362414038973, 0.030438461508310866, 0.049496767460368574, 0.024585621467849705, 0.0067651218250830425, 0.0004474437042745194, 0.009074512381630484, 0.024374144632020034, 0.036175784407532774, 0.035785310828941874, 0.042600460365065373, 0.04433070345839951, 0.04948695997882169, 0.046974444994702935, 0.025153360729746055, 0.014644956881966209, 0.01487890223870636, 0.029590162594104186, 0.014412130312848603, 0.057642591491458006, 0.019842119654640555, 0.05255974079773296, 0.007436639307343285, 0.027089872637588996, 0.03182288048265036, 0.065455161529826, 0.06565601637703367, 0.10417251600301825, 0.018833501999324653, 0.047617579039069824, 0.04221739713102579, 0.017116051676566713, 0.009721565893414663, 0.013077195890218718, 0.014526507329719607, 0.01179346872959286, 0.022113735358288977, 0.011005513842974324, 0.03827431828540284, 0.017978848445636686, 0.051662035257322714, 0.09731140526128002, 0.04804265896382276, 0.004820355379706598, 0.01408308244208456, 0.01665015734033659, 0.010155563650187105, 0.06089062306273263, 0.05119982568430714, 0.010121515770151746, 0.030124828044790775, 0.009638249612180516, 0.015824295405764133, 0.0770822778576985, 0.0061638337774638785, 0.01692786900093779, 0.1073923014337197, 0.052469974325504154, 0.014198132030287525, 0.004570794308165205, 0.07266506683663465, 0.026774079524329863, 0.03974784507590812, 0.029304153722478077, 0.038467699705506675, 0.023563522699987516, 0.06119856610894203, 0.0038041339576011524, 0.04225545075314585, 0.033271400607191026, 0.046688951915712096, 0.0685045424324926, 0.0323264610779006, 0.05389775142248254, 0.04781783645739779, 0.11216089711524546, 0.028381985139276367, 0.02855131540854927, 0.06956102675758302, 0.09275092263123952, 0.014490478843072196, 0.03678118395328056, 0.037568769621429965, 0.043476406135596335, 0.010112207382917404, 0.003917291996913264, 0.008526889032509644, 0.019899919971066993, 0.037883996847085655, 0.07024607359198853, 0.03443293222517241, 0.03226179404009599, 0.002558935625529557, 0.07638346418389119, 0.03147595241898671, 0.037420514490804635, 0.01739038842060836, 0.030032139366085175, 0.038399603945435956, 0.026465409173397347, 0.05054251290857792, 0.03361796872923151, 0.034593610907904804, 0.0659102613280993, 0.020815826683246996, 0.03439457061176654, 0.02996696210175287, 0.00975663886492839, 0.05764295143308118, 0.011151386679557618, 0.06263410978135653, 0.03481788793578744, 0.054609504441032186, 0.022397651373466942, 0.09711749691632576, 0.028058696334483102, 0.060269104069448076, 0.03869455569656566, 0.04693637281889096, 0.04011385746707674, 0.05848861015692819, 0.023243265568453353, 0.08041642082389444, 0.04911188596452121, 0.05438530904939398, 0.017045673812390305, 0.12719894642941654, 0.022123440794530325, 0.04768859886098653, 0.017991240456467494, 0.022960308779147454, 0.08118390542222187, 0.02666149757715175, 0.05799295198812615, 0.04828921897569671, 0.027664018489304, 0.029684604596695863, 0.0553117691015359, 0.07915715206763707, 0.021785639291920234, 0.036923936058883555, 0.06598285079235211, 0.0327276030293433, 0.02757757312792819, 0.01023755241476465, 0.020979414584871847, 0.03989905024354812, 0.04597790764819365, 0.0054199026271817274, 0.12327023185207509, 0.01720433014270384, 0.033399673411622643, 0.041930909574148245, 0.03045828612812329, 0.05267779422865715, 0.07832678529666737, 0.07759475309285335, 0.05350374893168919, 0.03857803480059374, 0.06715236420859583, 0.041662960866233334, 0.04834498766285833, 0.03487244321149774, 0.03571222041500732, 0.051831693926942535, 0.03703983355080709, 0.027138023178849835, 0.005995449746478698, 0.022228376765269786, 0.04162109631579369, 0.02117754575010622, 0.010627295905578649, 0.01918284204293741, 0.027725696527340915, 0.0159513622202212, 0.04511422215728089, 0.015310111375583801, 0.0726472627138719, 0.011020836409443291, 0.05161020737432409, 0.052185238237143494, 0.025869065684673842, 0.07451912984834053, 0.06851987520349212, 0.039851927576819435, 0.028742678186972626, 0.07398450892651454, 0.044926722257514484, 0.022848402186355088, 0.0157068486805656, 0.04173136090685148, 0.03273192975029815, 0.03317721093480941, 0.056349388032685965, 0.030222993773350026, 0.10962294501950964, 0.03974668732553255, 0.01535715518912184, 0.06881487890495919, 0.03233692164940294, 0.018855352682294324, 0.06741046832758002, 0.020782611863978673, 0.02658194862306118, 0.03723417976289056, 0.014910097488609608, 0.05228080088272691, 0.01427337931090733, 0.002982991850331018, 0.026669651924748905, 0.023528140809503384, 0.0554462202853756, 0.06462005243520252, 0.0833868668996729, 0.1542266586329788, 0.12458281649742275, 0.13839039980666712, 0.13401791802607477, 0.10927888535661623, 0.051849642768502235, 0.13486605923390016, 0.11335988863720559, 0.09088750113733113, 0.26049543754197657, 0.09320873126853257, 0.10207418992649764, 0.09856115968432277, 0.15966109436703846, 0.14371480472618714, 0.1672486637835391, 0.09844194850302301, 0.15894864744041115, 0.18692764453589916, 0.16108827403513715, 0.1485274691367522, 0.07759462692774832, 0.18678828404517844, 0.07329227810259908, 0.13201848312746733, 0.17941558122402057, 0.17933456838363782, 0.18163009051932022, 0.11481423833174631, 0.13993819331517443, 0.16649519093334675, 0.28743275615852326, 0.11594160518143326, 0.12280854178243317, 0.11461229252745397, 0.12744980718707666, 0.13985627505462617, 0.10127982473932207, 0.11620966150076129, 0.14985894144047052, 0.14959531574277207, 0.21808117831824347, 0.12277474437723868, 0.17092673282604665, 0.11673740271362476, 0.11268448230111971, 0.16700075677363202, 0.13875149918021634, 0.07968457415699959, 0.13173869345337152, 0.19925761182093993, 0.1791100241825916, 0.09151564750936814, 0.14969894924433902, 0.17241377412574366, 0.14637767511885613, 0.2538415789604187, 0.13096196169499308, 0.14768416673177853, 0.20779751997906715, 0.1832147390814498, 0.11631745845079422, 0.18419401778373867, 0.08816355941235088, 0.2654113940661773, 0.13577901961980388, 0.11752276564948261, 0.13103495934046805, 0.10773181915283203, 0.1502198033267632, 0.18018869130173698, 0.1544445235049352, 0.12306579985306598, 0.13578742073150352, 0.14476531476248056, 0.0987273636565078, 0.15201287664240226, 0.09599651253665797, 0.12844523502280936, 0.09444886003620923, 0.13108526210999116, 0.11968361024628393, 0.16302870819345117, 0.10632052886649035, 0.1496560827945359, 0.2020374298444949, 0.19274924386991188, 0.09742657173774205, 0.29120877385139465, 0.09983680021832697, 0.08868043558322825, 0.13780298992060125, 0.10779153235489503, 0.1554974974715151, 0.1725338981486857, 0.09326385799795389, 0.21486663987161592, 0.10534266024478711, 0.1794837845955044, 0.09486921990173869, 0.1832982900668867, 0.09596373187378049, 0.13386752922087908, 0.1170967060897965, 0.16896964487386867, 0.09640722448239103, 0.10174610870308243, 0.09558600097079761, 0.10344205715227872, 0.20664521696744487, 0.15463951538549736, 0.1992602093378082, 0.13376526127103716, 0.08962583524407819, 0.09636495175072923, 0.1327429380035028, 0.125304703542497, 0.21123796817846596, 0.1427992171375081, 0.13530690979678184, 0.08806037862086669, 0.15657859883503988, 0.1456145543488674, 0.20949276338797063, 0.10643096044077538, 0.1410750299692154, 0.14842149044852704, 0.1527282624738291, 0.12317499204073101, 0.12257705107913353, 0.1463041579700075, 0.14382358873263001, 0.09635888840421103, 0.1568144533666782, 0.11783264941186644, 0.15490915247937664, 0.13404364086454734, 0.11579008831176907, 0.1000649067282211, 0.21678216755390167, 0.16618492867564783, 0.16211831563850865, 0.15442524250829592, 0.11135042732348666, 0.16263768542557955, 0.11551290357601829, 0.16861556621734053, 0.06506963065476157, 0.16826398117700592, 0.14748758665518835, 0.1309935623430647, 0.13694889668840915, 0.18962521775392815, 0.07335295609664172, 0.10781915509141982, 0.2539667347446084, 0.07710450518061407, 0.2736516378354281, 0.12190422741696239, 0.171055109531153, 0.1934424097998999, 0.12260617295396514, 0.11636865921900608, 0.16432089119916782, 0.11030537207261659, 0.21483910619281232, 0.08213567271013744, 0.12746873195283115, 0.16409101837780327, 0.0885606009978801, 0.07541783357737586, 0.07320782911847346, 0.11674815643345937, 0.22595818532863632, 0.1066250543226488, 0.1250674537732266], [0.08716007927432656, 0.03447875613346696, 0.009917545758071356, 0.02631451756315073, 0.07581183235743083, 0.014341629066620953, 0.0621801677334588, 0.021219161681074183, 0.006983386529100244, 0.013766106530965772, 0.059033828947576694, 0.06675859549432062, 0.040788577316561714, 0.027794870256911963, 0.010279837206326192, 0.010281092363584321, 0.022076147433836013, 0.043959982140222564, 0.017217566346516833, 0.04472789718420245, 0.02063637166429544, 0.03214014861441683, 0.029943829358671792, 0.05306643099174835, 0.016248132233158685, 0.0333014835632639, 0.022981491529208142, 0.034145680256187916, 0.052880864386679605, 0.03085943179030437, 0.028454500388761517, 0.04852241661865264, 0.049072752517531626, 0.017144006524176802, 0.005759942168879206, 0.06518827780382708, 0.05057977243268397, 0.09272350769606419, 0.029585058473458048, 0.043052791952504776, 0.0633964958251454, 0.00923162133403821, 0.05530395428650081, 0.03522478153172415, 0.03142895220662467, 0.03682055488752667, 0.027185451981495135, 0.025531392202537972, 0.004503218051468139, 0.03331187734147534, 0.024955105254775845, 0.07102121715433896, 0.0173427740810439, 0.008368308772332966, 0.0963922702067066, 0.06635844431002624, 0.019859088861267082, 0.025764654783415608, 0.026832562616618816, 0.0645033793989569, 0.030938134696043562, 0.06521380768390372, 0.018262630874232855, 0.03373568077222444, 0.03178101593221072, 0.025140362013189588, 0.0051383480331423925, 0.018029652164841536, 0.01551492279759259, 0.05200061044888571, 0.04829994300962426, 0.08293027538456954, 0.029476634408638347, 0.05114097337354906, 0.01390613773764926, 0.03275089533417486, 0.051713113571167924, 0.05102528368297499, 0.04040764404635411, 0.011992288236797322, 0.046716010620002635, 0.05596554183284752, 0.03620826450060122, 0.016719991581339855, 0.04126680243643932, 0.004100480482520652, 0.03457212573266588, 0.026178882653766777, 0.0863519695121795, 0.030867734567436855, 0.07633653818629682, 0.02024065481236903, 0.026871337977354415, 0.01749618157191435, 0.022919561160961166, 0.05923751508817077, 0.04277096508303657, 0.06392026654793881, 0.07874370901845396, 0.029377249702520203, 0.06584631788427942, 0.039910683408379555, 0.040359879421885125, 0.057329887567902915, 0.049170675192726776, 0.03892731176165398, 0.056489909984520636, 0.034244749549543485, 0.014572896197933005, 0.05973024177365005, 0.03257288750319276, 0.005602643504971638, 0.03555391289410181, 0.03462810593191534, 0.02369391433603596, 0.02634890868648654, 0.14329752477351576, 0.024728256685193628, 0.02801156439090846, 0.007763116100250045, 0.08869608747772872, 0.013733998439420247, 0.03212206247553695, 0.013724785603699274, 0.04174588102614507, 0.05771139229182154, 0.03695616753248032, 0.07306696948944591, 0.09983296331483871, 0.04751753753225785, 0.03908420920197386, 0.05719464970752597, 0.029065293492749333, 0.03230781832826324, 0.06166916195070371, 0.07146122166886926, 0.02691822130145738, 0.04016828657768201, 0.024869162698450964, 0.01502339931903407, 0.0841922900872305, 0.02546574924053857, 0.014085804268688662, 0.05461026514240075, 0.06734352660714649, 0.06223045194929, 0.008505759160470916, 0.013202039972384227, 0.04042357795697171, 0.021548944278038107, 0.01734970574034378, 0.02485748686012812, 0.029152659117244184, 0.039776176563464105, 0.06175272777909413, 0.038080691956565715, 0.010717439945437945, 0.04225232631142717, 0.024526949127903208, 0.04892720993666444, 0.032429274506284855, 0.013763050737907179, 0.04983424427337013, 0.03286606181063689, 0.01722606579278363, 0.00769099140597973, 0.026022215279226657, 0.03975554114731494, 0.028265909531910438, 0.04760825766425114, 0.03415637089347001, 0.022399963163479697, 0.060905339851160534, 0.050848166429204866, 0.056605146965011954, 0.026129995530936867, 0.01913563217385672, 0.05909425832214765, 0.014825011185166659, 0.01818454580643447, 0.076876428356627, 0.04522133633145131, 0.012963598128408194, 0.006817941402914585, 0.03677199245430529, 0.03510894712235313, 0.05455363185319584, 0.019838846783386543, 0.0660762500774581, 0.04650310329452623, 0.007720899493506295, 0.01964799979759846, 0.0013177354981053213, 0.037333241634769365, 0.008710783022252144, 0.060069436658523045, 0.12124997971113771, 0.046130838309181854, 0.018969700940942857, 0.060496769001474604, 0.04209952923702076, 0.03206077963113785, 0.01288068817302701, 0.012193380571261514, 0.03447306757152546, 0.01758576436259318, 0.07529538663220592, 0.05225479602813721, 0.04238965702825226, 0.021276774605212267, 0.08108030902803876, 0.02681706471776124, 0.03717270024935715, 0.08073057935689576, 0.046001771406736225, 0.03025775597052416, 0.017270744938286953, 0.07067827813443728, 0.032160728369490243, 0.059168714287807234, 0.017233236794709228, 0.07614339425344951, 0.01545186436487711, 0.04950916503730696, 0.030896837888576556, 0.017244860682694707, 0.030257869148044847, 0.025046179762284737, 0.012587748569785617, 0.031245782738551497, 0.020142850880802143, 0.06292622652836144, 0.026931208885798696, 0.013606088359665591, 0.025234380991605576, 0.04076085067936219, 0.05579419477726333, 0.035653846789500676, 0.029869941135984845, 0.02019825220486382, 0.050233341607963666, 0.048433963747811504, 0.03481649640889373, 0.009674561042629648, 0.005233118436080986, 0.028145883843535557, 0.03591819608118385, 0.03835782474197913, 0.040076427249005064, 0.06438850236008875, 0.053512365266215056, 0.034233765763929114, 0.07075773246469907, 0.05180539592402056, 0.014829182055109413, 0.04915560959489085, 0.029804736041114666, 0.03786343564570416, 0.005037789806010551, 0.024459935048071202, 0.08147358050337061, 0.024222870815719943, 0.0274764276764472, 0.026784527108247858, 0.05079008224129211, 0.05981355898256879, 0.004210767338008736, 0.016231309600698296, 0.012681517073360737, 0.01493870264312136, 0.04765772922837641, 0.07637130780494772, 0.029814927584084217, 0.02484071988874348, 0.05717576204915531, 0.031318568871938623, 0.02419115884549683, 0.043807871552417055, 0.09260353952413425, 0.08376628989935853, 0.08750909648369998, 0.014721411080245161, 0.046128188841976225, 0.08935201243730262, 0.012709901438938687, 0.042189700179733336, 0.026891145898844115, 0.011185800067323726, 0.03214155869500246, 0.06122399208834395, 0.025225566132576205, 0.05109292302222457, 0.03336906724143773, 0.021004727386753075, 0.0449156976537779, 0.06779627379728481, 0.10576693865004927, 0.03481023639324121, 0.07061412688926794, 0.008325963681272697, 0.019693127942446154, 0.05033398425439373, 0.037164351087994874, 0.0843338250706438, 0.09857169075985439, 0.06518916095956229, 0.017046111679519527, 0.06712458562105894, 0.013512687219190411, 0.024485884241585154, 0.017775546366465278, 0.060737072708434425, 0.011113210603070911, 0.04039899431518279, 0.004112589549549739, 0.04596317601681221, 0.019043535357923247, 0.036453945067478344, 0.01936772772751283, 0.05335400579497218, 0.06452705390984192, 0.0341474094602745, 0.0355259190837387, 0.019054812291869894, 0.027960398874711245, 0.04161725941230543, 0.028009350935462862, 0.0413412584020989, 0.015041259102872573, 0.09168982956907712, 0.03505622495140415, 0.03705142960825469, 0.032527289949939586, 0.023679705918766558, 0.0284733824810246, 0.02796123193547828, 0.01820600315113552, 0.02452078930218704, 0.010033948838099604, 0.030856422381475568, 0.01258022968613659, 0.03501350322039798, 0.04957925346388947, 0.058423835507710464, 0.05742657827795483, 0.055736043796059676, 0.03778860489546787, 0.025794375942496117, 0.08060897103860043, 0.052941538669983856, 0.06481803517090157, 0.02848355918104062, 0.17313414718955755, 0.1934937367332168, 0.12242696655448526, 0.07908712301286869, 0.1268858343246393, 0.1529552260763012, 0.14752341754501686, 0.08009038050659001, 0.1371638523414731, 0.08791832413407974, 0.2220814730389975, 0.11144690652145073, 0.19177493755705655, 0.14596364577300847, 0.09469874858041294, 0.12616578780580312, 0.15350543952081352, 0.1234605853096582, 0.1427353182225488, 0.11427195102442056, 0.2769998222356662, 0.09247732989024371, 0.10806364080053754, 0.22210949653526768, 0.1006093982141465, 0.10426597465993837, 0.11402806645492092, 0.13643530081026256, 0.11147262193844654, 0.13309079746250063, 0.10167819476919249, 0.17336024990072474, 0.09513225930277258, 0.16417222417658195, 0.18573574052425101, 0.1217610300227534, 0.1299396384274587, 0.2275657217251137, 0.12496212817495689, 0.10592782884486951, 0.07937270143884234, 0.21431969187688082, 0.16742467152653262, 0.10472172012669034, 0.07523921347456053, 0.16988331772154197, 0.12538386101368815, 0.1782083889702335, 0.07663095559109934, 0.11817934369901195, 0.11120444687549025, 0.12568208563607186, 0.10714469128288329, 0.10501251585083082, 0.16075901279691607, 0.17237583553651348, 0.09774240752449259, 0.12418020138284191, 0.12521678872872144, 0.1243294621235691, 0.16244037804426625, 0.12202084108139388, 0.07581356156151742, 0.1631152574555017, 0.17344136664178222, 0.16244205529801548, 0.19928688212530687, 0.15451674931682646, 0.09009921413962729, 0.10651107528246939, 0.09951652638847008, 0.13665107282577083, 0.07258127836394124, 0.23994619958102703, 0.16902588482480496, 0.11802313645603135, 0.16397951811086386, 0.1058142505644355, 0.08064969268161803, 0.13196452899137512, 0.16402821784140542, 0.07607376595842652, 0.08439815443125553, 0.17110513028455898, 0.1909061349579133, 0.07908736792160198, 0.10758241740404628, 0.07995337262400426, 0.15524806163739413, 0.17908293579239398, 0.2424108423292637, 0.05661470211634878, 0.21829356614034623, 0.07931522952276282, 0.11244098364841193, 0.18556022259872407, 0.1345765622681938, 0.09988670964958146, 0.16120667627546936, 0.06089946204156149, 0.11688852624502033, 0.17890220799017698, 0.1635770217399113, 0.17869546049041674, 0.21303222893038765, 0.12914741062559187, 0.23222084302688017, 0.19131204520817846, 0.10795116832014173, 0.12809716776246205, 0.17060382437193766, 0.12578384892549366, 0.12133146010455675, 0.10542635965975933, 0.11247363072470762, 0.11884367719176225, 0.24881807039491832, 0.08889458229532465, 0.1160179944417905, 0.18619343783939257, 0.16333910403773189, 0.12771089473972097, 0.17804198461817577, 0.05354706067009829, 0.11354388188919984, 0.17836146435001865, 0.18080108187859878, 0.16732701973523945, 0.24612036359030753, 0.2208032869384624, 0.22768462862586603, 0.16684049740433693, 0.06736766124959104, 0.18436419224599376, 0.15205869683995843, 0.14362147223437205, 0.11044944520108402, 0.15182002214714885, 0.14242958306567743, 0.11751684331102297, 0.10394486962468363, 0.12580443610204384, 0.14155015291180462, 0.0826391828013584, 0.1721670397091657, 0.10056003797217272, 0.1648137960000895, 0.10063742171041667, 0.07626822349266149, 0.22580144373932853, 0.21969097084365785, 0.11526288886670955, 0.10517240414628759, 0.20463983004447073, 0.16522012185305357, 0.18096812447765842, 0.10949936258839443, 0.15466354612726718, 0.197995277994778, 0.14928708696970716, 0.10918107771431096, 0.10223908771877177, 0.20229118497809395, 0.08818948263069615, 0.16160749539267272, 0.1779613280086778, 0.11723637828254141, 0.17870141251478344, 0.20096127118449658, 0.1890981593169272, 0.10183819438680075, 0.07764950874843635, 0.1416304087615572, 0.19205644901376218, 0.19303013192256913, 0.0860243706847541], [0.044440964338718913, 0.008635218473500572, 0.09884389568469487, 0.013765121329925023, 0.10232570377411321, 0.01970467947103316, 0.04114064846362453, 0.025851374739431776, 0.016811776695249137, 0.03658347581222188, 0.023817483779566828, 0.02489906568371225, 0.009299108533014078, 0.028299039004195947, 0.08657157843117602, 0.03387078133528121, 0.051646646825247444, 0.04138877440709621, 0.02991010060213739, 0.04613756958860904, 0.022238334531721193, 0.02197188496211311, 0.03692896039865445, 0.030128900580166373, 0.013247128226794302, 0.09164725997834466, 0.02678422097233124, 0.04567651776596904, 0.019703720245161094, 0.05616861570160836, 0.022920384944882244, 0.06088453374104574, 0.06453857204178348, 0.039438365784008056, 0.048312036306015216, 0.018158500133722555, 0.0424210758501431, 0.08207753286114894, 0.0414689820172498, 0.024530752634746023, 0.014123078635748243, 0.10002295312006027, 0.049398444025428034, 0.007354750268859789, 0.048627308060531504, 0.027276578439341392, 0.01896991059766151, 0.03216613120457623, 0.05272499482089188, 0.07981042756000534, 0.032514320919290185, 0.01233509645317099, 0.0837376578419935, 0.0028244243458175333, 0.023195851608761586, 0.05067781385150738, 0.02659304373082705, 0.07256814235006459, 0.018587749073049054, 0.03209561233234126, 0.05299100281263236, 0.016075560633908026, 0.03229498288419563, 0.009120468948822236, 0.025185525410051923, 0.01493452620707103, 0.03715822094818577, 0.043430148070910946, 0.024715100262255874, 0.04930562361550983, 0.0451151275774464, 0.06673615294857882, 0.12928196199936792, 0.025779419811442494, 0.03731874006916769, 0.03549428132828325, 0.05629487357509788, 0.03889414147124626, 0.013158872025087476, 0.02637413428601576, 0.07854642390157096, 0.03865268001391087, 0.017618864148971625, 0.008464972579531604, 0.028513232100522146, 0.02511039965611417, 0.01701483201031806, 0.08722719168872572, 0.08161906371242367, 0.056100594156305306, 0.041250946451327763, 0.02789774862321792, 0.05812303934362717, 0.04929328912112396, 0.008385403216379927, 0.047696098263259046, 0.052889688522554934, 0.059367843641666695, 0.04172412125626579, 0.08387701833271421, 0.06420431614969857, 0.03602916571253445, 0.07602799771120772, 0.03688687320391182, 0.01842494970333064, 0.030604676612711046, 0.033521385630592704, 0.04600233914970886, 0.04338235747127328, 0.01639804606384132, 0.018727276546997018, 0.021953414761810564, 0.05080822033050936, 0.035229553541284986, 0.0049231892171519576, 0.031063693095347844, 0.009639362833695486, 0.04970496956957504, 0.03292093620984815, 0.017643432947807014, 0.04535052939900197, 0.015566016882075928, 0.046329759861691855, 0.012041321006108774, 0.04448494772077538, 0.07250977243529633, 0.06496703615994193, 0.051513609432731755, 0.1006701726873871, 0.01668546872679144, 0.047207564712152816, 0.036345947737572715, 0.04116729898669291, 0.01801159200113034, 0.06574836181243882, 0.03391995604033582, 0.034168011479778215, 0.010655018832039787, 0.009486432172707282, 0.015057320106279803, 0.0299615332914982, 0.06511090148705989, 0.06149746237497311, 0.004159326299486565, 0.036309100105427206, 0.01947657667187741, 0.043784334338852204, 0.02421072742436081, 0.04465864738449454, 0.022791045303165447, 0.03219095975509845, 0.020700875429611187, 0.04274388411431573, 0.026926583450403996, 0.04858278662140947, 0.02299054202012485, 0.05084179880213924, 0.08871535363141447, 0.09923538600560278, 0.05410485144238919, 0.06048309493053239, 0.005573225234911661, 0.048989539209287614, 0.04038720901007764, 0.011484746428322978, 0.05823753046570346, 0.020524973442661576, 0.025699477519083302, 0.08128278175718151, 0.08833919608150609, 0.023291887373488862, 0.0499896833935054, 0.017641865160840098, 0.005050839545219787, 0.040885939670260996, 0.036311590010882355, 0.040103671490214765, 0.03333927001222037, 0.03769662682316266, 0.040429904765915126, 0.050517020135885105, 0.04082553627085872, 0.026757954510685522, 0.07650246014236473, 0.05257345939753577, 0.0563995535048889, 0.021344419510569423, 0.025032772864506114, 0.005486258514793008, 0.05331457548891194, 0.03436894425249193, 0.013060225755907595, 0.0453556799038779, 0.024648533326399047, 0.06387967107002623, 0.053615301148965955, 0.03616140900703613, 0.04196248424705118, 0.07031576868030243, 0.04652428047847934, 0.018714819598244503, 0.07901486751507036, 0.008424331645073835, 0.06282068570726551, 0.01502469622209901, 0.08485066413413733, 0.008519336752215168, 0.03398219996597618, 0.07617711744387634, 0.02399939901806647, 0.051252273260615766, 0.028133087362220977, 0.04392958006064873, 0.039185497516882606, 0.013990469833515817, 0.020869955224043224, 0.04541339301795233, 0.05767277463746723, 0.04142355886870064, 0.031562761432724074, 0.02422193756501656, 0.03363909025210887, 0.02932279276137706, 0.01797166816686513, 0.017807414187700488, 0.027160035278939176, 0.026993200481228996, 0.004702321430158918, 0.011008780220436165, 0.06438234995584935, 0.01843044530687621, 0.07361151292570867, 0.047413610882358626, 0.02813353821693454, 0.044013676524627954, 0.037927698213024996, 0.037226402055239305, 0.04444356927706394, 0.045966690086061135, 0.05024303405662067, 0.044466601830208674, 0.03184569410223048, 0.023444630642188713, 0.04214205429889262, 0.0618549400678603, 0.034572667500469834, 0.02621014376927633, 0.025343745728605427, 0.06410714675439522, 0.04339316314144526, 0.007738947597317747, 0.06627003225730732, 0.018067052697006147, 0.042590927478158846, 0.028161337213532533, 0.017392451591149438, 0.03983829803473782, 0.03428776813962031, 0.03063387641304871, 0.048822786047821864, 0.06208962942764629, 0.06062301945348736, 0.06946148991119117, 0.04826619755476713, 0.01719325915473746, 0.011569526595849311, 0.05290652785333805, 0.09584403087501414, 0.02997467487148242, 0.016979999309114646, 0.018558454648882616, 0.05992007572785951, 0.060204930559848435, 0.009404568645550171, 0.05684171766915824, 0.03594454232370481, 0.029801294331264216, 0.040850145887816325, 0.0476116975187324, 0.05473287164932117, 0.011143100600747857, 0.059321745138731785, 0.027763638827309478, 0.007003380915193702, 0.05834586547280196, 0.03189533636032138, 0.039776900157448836, 0.026831790783035103, 0.024556531134294346, 0.02405354054644704, 0.01652232611377258, 0.07451908531947993, 0.02175825404265197, 0.018827544408850372, 0.03339957693242468, 0.043043815676355734, 0.05321274540619925, 0.040090602269629017, 0.025061798260139767, 0.031536103488178924, 0.047665811216575094, 0.027488782579894178, 0.06908756622578949, 0.037278511954355054, 0.01858314219134627, 0.024422267342742998, 0.0750342768151313, 0.04172107102931477, 0.03325322541058995, 0.017187192097480875, 0.02919447171734646, 0.02826081468811026, 0.02689222015760606, 0.09469705648371018, 0.06375545039190911, 0.04039488281705417, 0.09373770444653928, 0.06213847758772317, 0.05668040073942393, 0.029460976948030293, 0.03778440433961805, 0.07030500753899105, 0.043868052307516336, 0.031203628750517964, 0.0238866964718909, 0.023347938076767605, 0.014368902066053124, 0.02056660050584469, 0.023202553202281706, 0.030225882583181374, 0.0810836190066766, 0.018931979429908097, 0.005045189946031314, 0.027854546351591125, 0.08607324110926129, 0.05792189505882561, 0.03639465488959104, 0.0514331940212287, 0.07684505777433515, 0.03132340396405198, 0.04719564953120425, 0.03726087110408116, 0.045636634749826044, 0.01562661138450494, 0.024256668220914435, 0.020611819563782774, 0.019598726757976692, 0.010452607330080355, 0.025538724621583242, 0.05750644450017717, 0.015584661487082485, 0.05874432456039358, 0.19834984646877274, 0.123560886568157, 0.16135700570885092, 0.15807605988811702, 0.1935928431339562, 0.0932795915286988, 0.1019019226077944, 0.07375158587819897, 0.17618245939956978, 0.1689517591148615, 0.08441962476354092, 0.07198760475148447, 0.08929209885536693, 0.13003228814341128, 0.17327310692053288, 0.07753064637654461, 0.14201003214111552, 0.10802642209455371, 0.18834765505744144, 0.21350160764995962, 0.1821188986650668, 0.13322294427780434, 0.13283468229928985, 0.10824162265635096, 0.1539649476762861, 0.16111142904264852, 0.13305039494298398, 0.18043768184725195, 0.06789940263843164, 0.1696206716587767, 0.1316515207872726, 0.17776934924768284, 0.09776672028237954, 0.08461199686280452, 0.2751741389511153, 0.14947100600693375, 0.11382771626813337, 0.17230984376510605, 0.16161656443728134, 0.11743033857783303, 0.0759865264990367, 0.1899746060371399, 0.0718193524517119, 0.07959286696859635, 0.12251428765011951, 0.18941600632388145, 0.10597226864774711, 0.13450096710585058, 0.08529509184882045, 0.16649621509714052, 0.07229193724924698, 0.10798480987432413, 0.13647487212438136, 0.1581988704856485, 0.06971639537368901, 0.21495217981282622, 0.19433144334470853, 0.21931165916612372, 0.10889264201978222, 0.11109456449048594, 0.11521134671056643, 0.1103842475276906, 0.12024600975564681, 0.1731601223582402, 0.09693047570181079, 0.11726462442311458, 0.23848602402722463, 0.15599629492498934, 0.13055943563813344, 0.09909209213219583, 0.1353525518788956, 0.19030217517865822, 0.2571071474812925, 0.1468671957263723, 0.14169380301609635, 0.2550053258892149, 0.13431719649815932, 0.11879903700901195, 0.1052438432816416, 0.10781500648590736, 0.09326137922471389, 0.12601902068126947, 0.09918330208165571, 0.12725232169032097, 0.08435024879872799, 0.12716878554783762, 0.13162092946004122, 0.15523731533903629, 0.11222678498597816, 0.15239212894812226, 0.13003818079596385, 0.18014673027209938, 0.14583672367734835, 0.11824028886621818, 0.10286324133630842, 0.09589992943801917, 0.08120549449813552, 0.14709083450725302, 0.10452931092004292, 0.2090310733183287, 0.22564428654732183, 0.17514582752482966, 0.28043572849128395, 0.10946531285298988, 0.07271752183442004, 0.2777210116619244, 0.18193331721704453, 0.1352425804361701, 0.1347181195160374, 0.07240946375532076, 0.10356813319958746, 0.07790358300553635, 0.14808664825977758, 0.15508881158893928, 0.06525078148115426, 0.1080814449233003, 0.13086370134260505, 0.06749168154783547, 0.12341445341007784, 0.11037992080673575, 0.11200099397683516, 0.16002868011128157, 0.10936497448710725, 0.1071071757178288, 0.10068350165965967, 0.2550474798772484, 0.20274177251849324, 0.19023584201931953, 0.29812965716701, 0.13913110771682113, 0.09677925569121726, 0.103270695253741, 0.14506687904940918, 0.08288929398986511, 0.17433451168471947, 0.16360197274480015, 0.1844795368378982, 0.1493218491668813, 0.16559737036004663, 0.1800854437169619, 0.25385024724528193, 0.12224557824083604, 0.12834486697101966, 0.0643384519207757, 0.2294354885816574, 0.11739590292563662, 0.1258224406046793, 0.10938506442471407, 0.09253980388166383, 0.14881644659908488, 0.08568235192797147, 0.20517603174084798, 0.09263337386073545, 0.09904031991027296, 0.20260287215933204, 0.11910720641026273, 0.11833416312583722, 0.11536314559634775, 0.24183177418308333, 0.17929290421307087, 0.1259941142052412, 0.11147434372105636, 0.1976494668633677, 0.1666373122134246, 0.09440706227906048, 0.16454881959361956, 0.11053502967115492, 0.09407383055076934, 0.28088181861676276, 0.1645174267468974, 0.145844902144745, 0.09005218424135819, 0.14156705903587863, 0.1374192995717749, 0.10496643590158783, 0.13447260222164914], [0.028020520257996395, 0.06084398279199377, 0.05259190176730044, 0.04480053859879263, 0.021828561402799096, 0.05388068202591967, 0.04707949970907066, 0.025246004879591055, 0.04654135729651898, 0.06580915855010971, 0.03234748241084162, 0.030645828701381106, 0.012461135393095901, 0.09119127702433616, 0.011807128885266138, 0.09044787511811592, 0.05785106448456645, 0.037967781609040685, 0.04820674039365258, 0.021872847210033797, 0.016201794387598056, 0.022697673848597333, 0.004092977833352052, 0.021477354857779574, 0.002805050116876373, 0.033131201489595696, 0.029214687820058316, 0.008254597833001753, 0.015360268498625373, 0.04282471883925609, 0.04940519756928552, 0.01868516152171651, 0.01215962583955843, 0.06319333289866336, 0.02102854476106586, 0.07889746717410162, 0.017206434131367132, 0.029500982418539934, 0.11117803383967839, 0.03047166519536404, 0.014870810973661719, 0.023827063050703146, 0.031373780948342755, 0.028676252259174362, 0.07306785264518112, 0.114445324143162, 0.059013553473050706, 0.02228065364761278, 0.033105909096775576, 0.036877125094179064, 0.01720511125313351, 0.02877962415368529, 0.03975188607000746, 0.058744710477185436, 0.03573617694200948, 0.024364698947465513, 0.028231384821992833, 0.08397269601118751, 0.04853534854191821, 0.013254433742986294, 0.055191622814163566, 0.017392896879755426, 0.030015511547389906, 0.013377928044064902, 0.0839952721435111, 0.052740182873094454, 0.03420701505092438, 0.05193538680032361, 0.025806719713727944, 0.02139867236110149, 0.029007238990743645, 0.05861482350155711, 0.03088650162681006, 0.045108819322194904, 0.02933960611699149, 0.025871503639791626, 0.0755303431651555, 0.051036449294770136, 0.013746306030952837, 0.040819287387421355, 0.043081535332021303, 0.037361621361924335, 0.028524739100248553, 0.02253917893540347, 0.03676873071526643, 0.01271646944587701, 0.0144288406954729, 0.08897470455849543, 0.07613576497533359, 0.027516169684531633, 0.024905461141315755, 0.01664365983742755, 0.0626241575810127, 0.033450718328822404, 0.03669933619676158, 0.05177781771635637, 0.05648503407428507, 0.026226836525893304, 0.031980846615624614, 0.05019461634219624, 0.04866104238317348, 0.009289332592743449, 0.021041921972937416, 0.027848453319165856, 0.03573352376406547, 0.005216105628278456, 0.021064485117676668, 0.034235706480103545, 0.06504617878817953, 0.02710481949179666, 0.05250507419987116, 0.044964375119889155, 0.04791560328158084, 0.0461383080255473, 0.015135418161662528, 0.06953183808946051, 0.12643892783671618, 0.03767002453969326, 0.027005842966900673, 0.023554143808723893, 0.05073546759376768, 0.02521727448765887, 0.04621804066118784, 0.03031977168575395, 0.012899094363092445, 0.01681346879195189, 0.0418706546042813, 0.0464893438766012, 0.07025383645668626, 0.045803365646861494, 0.07040976168354973, 0.04602238826919347, 0.06561117581441067, 0.04241081565851346, 0.031625305928173475, 0.04398986842716113, 0.02573865363956429, 0.027792178116214927, 0.01725283877021866, 0.04950283451762516, 0.049090411921497434, 0.03509914706228301, 0.04973117480403744, 0.03409220480534714, 0.054287976381601766, 0.06227001213119365, 0.0015044999759084021, 0.031244424608303234, 0.027048349475080613, 0.03532508279022295, 0.044705554828397, 0.050866204328485765, 0.08214726505684666, 0.0191875361269922, 0.062025259248912334, 0.039942781295394525, 0.0732199038611725, 0.03962626273278147, 0.04684428342443425, 0.026022547390311956, 0.01634594358620234, 0.025203305413015187, 0.03724432121089194, 0.03010173426446272, 0.00369817127193528, 0.03310284031613264, 0.03852524212561548, 0.012624696391867474, 0.035672975645866245, 0.02761046325758798, 0.0357930514292093, 0.0683001549623441, 0.07030889639281668, 0.04341576153819915, 0.0352619965269696, 0.0587565811292734, 0.06418458244297653, 0.04268849763320759, 0.03446147151407786, 0.010129100519407075, 0.03875666232488584, 0.051942871359642595, 0.0671333355421666, 0.04201191128231585, 0.02898925118643092, 0.06399414734914899, 0.07571095222374424, 0.03699413951835595, 0.02130770546500571, 0.05278405122226104, 0.020604065975931007, 0.064233126322506, 0.05269164641504176, 0.06375297161866911, 0.020100188521610107, 0.01702980855043279, 0.014659415774076479, 0.027006154668924864, 0.03529743778926786, 0.010995001321134623, 0.03050523253477877, 0.018529967310314532, 0.00649818707643135, 0.014769310218980536, 0.0527600687200902, 0.038811651756986976, 0.02869298026780598, 0.005387987030189834, 0.04842777794692665, 0.035067216158495285, 0.041311791428597644, 0.09523989298031665, 0.03450719152169768, 0.09604225851944648, 0.029166715394239873, 0.011650781561911572, 0.049792613499448635, 0.03348280879436061, 0.04572912119328976, 0.03406286770768929, 0.06248533885809593, 0.0642143574077636, 0.08195214701117948, 0.06574238010216504, 0.032072182730189525, 0.010136279870494036, 0.08281137590529397, 0.0707866316952277, 0.027997261349810287, 0.07929036015411839, 0.03081386206758907, 0.06325679394649342, 0.04203695505566429, 0.029261934796522837, 0.0863356571062468, 0.02332031162950443, 0.08065263158641756, 0.010842113333637826, 0.015300302038667724, 0.01930819449626142, 0.03719759559317026, 0.02586578168120468, 0.07174718601163477, 0.006728546004524105, 0.04642173422325868, 0.03251489979447797, 0.025714845542097464, 0.018676756699278485, 0.006974168591113994, 0.028230603711563163, 0.017345108135486953, 0.04932600299071055, 0.09757097883266397, 0.04784050164744258, 0.021433916954265442, 0.011534192944964161, 0.0026105424876732286, 0.023796304740244523, 0.07241552710183896, 0.03607860388001427, 0.01936149739776738, 0.014892877807142213, 0.044866556345368735, 0.05989119876176119, 0.10954452969599515, 0.007640559224455501, 0.024480091778968927, 0.023046036112646107, 0.06879494481836446, 0.059569333025137894, 0.04263394606823567, 0.0622929741803091, 0.035336448781890795, 0.038809885445516557, 0.017786159078241326, 0.031780032586539164, 0.03688433505885769, 0.011816026308224536, 0.026122028575628065, 0.026616690411174204, 0.07499359227949753, 0.03317729628179222, 0.036094582319492474, 0.0531108596624108, 0.026860215039050672, 0.009930018477462, 0.02862318684492493, 0.09024100145325065, 0.07413356186589226, 0.05531151306058746, 0.005433576234281645, 0.021521768685488496, 0.04445712089363951, 0.10798093586345203, 0.04811584956769366, 0.0016764448082540184, 0.07212858312414028, 0.026741144865809474, 0.0535206105269026, 0.016601960414845962, 0.06799180002417415, 0.06971151946345344, 0.10386328533058986, 0.028962756514374632, 0.023600910244567785, 0.043417820998001844, 0.036395259739947505, 0.03390132071217522, 0.014508457370538963, 0.026313593589293305, 0.05594826834567357, 0.046141016864567064, 0.07064197227009572, 0.034410263324389234, 0.02511032173060812, 0.027091099036624655, 0.035006497346330434, 0.04160298049100675, 0.05229073824011721, 0.04801246839633677, 0.029628136435349006, 0.004251370237398078, 0.07060846430249512, 0.054256119692581706, 0.022747060065739788, 0.011811012172984192, 0.048277711975970306, 0.02276187704410404, 0.031718063255539164, 0.008363525630556978, 0.08392137649934739, 0.04223648145853076, 0.08296369429444894, 0.05215613862674218, 0.042815275010070764, 0.02369927264226135, 0.04243240844516549, 0.07120993788703345, 0.045998754576430656, 0.04389888854348101, 0.03327091450046282, 0.029527495644288138, 0.054269396714516915, 0.03551301313564181, 0.011610174024099251, 0.04279557469999418, 0.05157954554306343, 0.05081923009129241, 0.002314567732355499, 0.0439219953113934, 0.052341482587507926, 0.032970010724966414, 0.10944203910185024, 0.1811007907963358, 0.13177922955946997, 0.1016180140140932, 0.15464965312276036, 0.15985111385816708, 0.265418904600665, 0.12989942886633798, 0.1727703760843724, 0.1431778905680403, 0.15303862863220274, 0.12455323449103162, 0.10783749356050976, 0.18050722108455375, 0.2902983664534986, 0.178492765116971, 0.07205355941550806, 0.11279342958005145, 0.12544168916065246, 0.1828867691801861, 0.11535291880136356, 0.17606566019821912, 0.11910372573765926, 0.09830440627411008, 0.07815178687451407, 0.13066679472103715, 0.09892470814520493, 0.10982460138620809, 0.12895798485260457, 0.1488897856324911, 0.08983584819361567, 0.11867635257658549, 0.11911640161997639, 0.20131800672970712, 0.15056855336297303, 0.18446128000505269, 0.07333579022088088, 0.11961521391640417, 0.21441535471240059, 0.10842641000635922, 0.1656947549781762, 0.0661518749257084, 0.13559023209381849, 0.09666949204984121, 0.25193992943968624, 0.20068330719368532, 0.19067923072725534, 0.14196841249940917, 0.08884200113243423, 0.10924065732979216, 0.16242069628788158, 0.09516477279248647, 0.11977354370173998, 0.1738379555172287, 0.1332767351414077, 0.12746522901579738, 0.1948727064882405, 0.11823246662970632, 0.19344049505889416, 0.07123514122213237, 0.2582688757684082, 0.29469725384842604, 0.07852572540286928, 0.0899962114635855, 0.14769047498703003, 0.18087909644236788, 0.20190088951494545, 0.14790409477427602, 0.12298028217628598, 0.13022589962929487, 0.08368889873963781, 0.22033629793440923, 0.1106374386290554, 0.10594718405627646, 0.11962334043346345, 0.12443055748008192, 0.20989799086237326, 0.14939723652787507, 0.07915698879514821, 0.0627403036924079, 0.21678559627616778, 0.12674498953856528, 0.15621497615939006, 0.1501549841486849, 0.22472719982033595, 0.10561752205830999, 0.10095944700879045, 0.14992965327110142, 0.25549327314365655, 0.10787640436319634, 0.12181419748230837, 0.14782113750698045, 0.2050751738715917, 0.11116960304207169, 0.14770487265195698, 0.1846761762863025, 0.1442626878269948, 0.13244732574094087, 0.2102462065522559, 0.1184676903358195, 0.12669246032601222, 0.09497035236563534, 0.10415779921459034, 0.11298376819468103, 0.14074777252972126, 0.13300543563673273, 0.1494716145680286, 0.13186399766709656, 0.16603877011220902, 0.08916647551814094, 0.11463305781944655, 0.21310369775164872, 0.1921511025284417, 0.16040490445448086, 0.10994969037710689, 0.12611511396244168, 0.18955045379698277, 0.19563297741115093, 0.11048434840631671, 0.12418767480994575, 0.16736464662244543, 0.114902435161639, 0.08397594661801122, 0.10809004641487263, 0.13148106430890039, 0.1635781052755192, 0.1922439452027902, 0.0904301526315976, 0.21290503966156393, 0.06809204191085882, 0.18849552056053653, 0.09435025087441318, 0.13996450987178832, 0.18025938828941435, 0.2567589614773169, 0.13086628401651978, 0.12774194619851187, 0.07878231554059312, 0.08201271368307061, 0.1255743851652369, 0.1805693982169032, 0.16193904244573787, 0.19811433332506567, 0.11988132580881938, 0.15004388464149088, 0.1253672962775454, 0.12353994316072203, 0.23708854510914534, 0.1188284854288213, 0.13406847312580794, 0.11923027675948106, 0.1836872793501243, 0.19522984279319644, 0.09647325336118229, 0.16894778120331466, 0.13414184184512123, 0.1922202410059981, 0.15456256951438263, 0.22655543609289452, 0.08367827118490823, 0.0850837207690347, 0.11195670260349289, 0.07821849110769108, 0.1286223263014108, 0.1572869491064921, 0.12637428677408025, 0.13371280627325177, 0.10198056799708866, 0.08668798429425806, 0.10175384930334985, 0.14322099450509995, 0.15048068307805806, 0.1926618634024635, 0.08739266835618764, 0.14193883049301803, 0.16659610817441717], [0.05414357299741823, 0.04059039791172836, 0.052841307915514335, 0.08714208961464465, 0.010438778335810639, 0.05525741049495991, 0.06328537405352108, 0.055715259950375184, 0.0964566069887951, 0.04378840501885861, 0.04220219794660807, 0.05737106563174166, 0.04507693294726778, 0.047440933049074374, 0.04545043731923215, 0.02000224729272304, 0.034055375726893544, 0.06926002650288865, 0.054258895324892364, 0.03014650246768724, 0.02329707313037943, 0.1047629835375119, 0.025934471159416717, 0.03921109047951177, 0.07164078429923393, 0.02328265876712976, 0.0224993794108741, 0.04246380500262603, 0.013346447067306144, 0.04358606216555927, 0.0340478392172372, 0.025397848294232972, 0.030238302424550056, 0.038504261610796675, 0.06107828994572628, 0.058134887731284834, 0.07237972589791752, 0.032001712097553536, 0.031027301884023473, 0.02810264817526331, 0.02210437502071727, 0.09132197665167041, 0.08580319583415985, 0.008116779154079268, 0.010906019670073874, 0.04522325107245706, 0.04237848399498034, 0.029257155365485232, 0.031542233627988026, 0.030403411728912033, 0.067339474480832, 0.034307772730244324, 0.043330778207746334, 0.019823784896289, 0.06729936139890924, 0.013129386497894302, 0.06761908603948541, 0.06127805383584928, 0.052627283657784574, 0.024261067301267758, 0.0051906258431699825, 0.028615568699024152, 0.06036769838829059, 0.04954023133905139, 0.011967377122346079, 0.0415577317471616, 0.014756578675587662, 0.05547175387619063, 0.044944463297724724, 0.013035659740125993, 0.008730526005820138, 0.045295840536709875, 0.0717039336450398, 0.025567696211510338, 0.013598521236417582, 0.007929097428132081, 0.05720774861401878, 0.024213738688558806, 0.05432596321043093, 0.03326619815197773, 0.06344999725115485, 0.01572089568071533, 0.012095161036995705, 0.033687485702103004, 0.08577083077398129, 0.013981881329527823, 0.031680733227403834, 0.008853518429532414, 0.01501797700257157, 0.018325577984796837, 0.01998468993406277, 0.03638273599790409, 0.05409485842392314, 0.020707823787233792, 0.04325228124798741, 0.030724531607120298, 0.06223103824595455, 0.018847584251489025, 0.06525982083985582, 0.01648514822591096, 0.07902242257841863, 0.01840478740632534, 0.015150038470892468, 0.014245038546505384, 0.06362958214594983, 0.02885890964535065, 0.0401246891124174, 0.049531633558217436, 0.0599347071693046, 0.01486508066591341, 0.04904615394480061, 0.021148941523279063, 0.03249129207688384, 0.08652811826323159, 0.033344535549986176, 0.03006073246069718, 0.038134178539621644, 0.02563152833317872, 0.03319400202599354, 0.09220041232765652, 0.04924404762277845, 0.024077018388197757, 0.040724314749240875, 0.006330600390356267, 0.03997147643531207, 0.08292299491586164, 0.02552721020038007, 0.02773203817923786, 0.013945393639005488, 0.026637923256203067, 0.030272587791841943, 0.11169268356752582, 0.08890129131032154, 0.03627484999014996, 0.005201188459977857, 0.015938203941914253, 0.010254874141537584, 0.019503182666085195, 0.0815037710708566, 0.01926419627125142, 0.023666779561608564, 0.031841886884649284, 0.017234589358849917, 0.01605285462574102, 0.020328452737885527, 0.03810581736615859, 0.053967594940331765, 0.026419503628858365, 0.06225582597835455, 0.05683529809175525, 0.0358431130007375, 0.01275930342671927, 0.0360310581891099, 0.022527315704792272, 0.04412457194121089, 0.07428785436786711, 0.009755604496604064, 0.03605286248784978, 0.04986035302863456, 0.07539544298197143, 0.014760968479095027, 0.04413555572682526, 0.013510594362742268, 0.02570486736658495, 0.041539575104252435, 0.08311469908221625, 0.033667150855762884, 0.028975838722544722, 0.0387078698258847, 0.04271765661542304, 0.05043079370807391, 0.06032365192368161, 0.15049577836180106, 0.026878393946390133, 0.028893076269014273, 0.10256442299578339, 0.04863012822170276, 0.015182500010268996, 0.009151490721706068, 0.0341673064394854, 0.029635320424858946, 0.023737884730508085, 0.06620234838919714, 0.081185204180656, 0.042446446168469265, 0.02324971112102503, 0.05313711313647218, 0.05603600504400674, 0.054139721250976436, 0.049982343552983366, 0.008500893454765901, 0.05781809086329304, 0.026743120833998546, 0.023217754242068622, 0.011344610393280163, 0.04080239239556249, 0.03352256193466019, 0.000355471603938895, 0.02763235661404906, 0.12787927320459858, 0.04120855126529932, 0.02465507721353788, 0.06957519435673021, 0.05009192165744025, 0.034474518470233306, 0.04121238074731082, 0.04175984824541956, 0.039556667834403925, 0.02109497811034089, 0.020837454721913673, 0.03221197737730108, 0.02696438845305238, 0.07407348501146771, 0.033224211147171445, 0.045779520442010835, 0.07169853080995381, 0.038607794922427274, 0.012098584193154238, 0.0720560752961319, 0.025520115268591326, 0.019658911223814357, 0.0056670582125661895, 0.07175036240369081, 0.024130978090397548, 0.058791565970750526, 0.007373050702881301, 0.06797409980208613, 0.055785630393074825, 0.02822378522978397, 0.006240617767616641, 0.027837426860060077, 0.03125960152829066, 0.04269711396773346, 0.020020979100081604, 0.0009964191826838942, 0.023484881021431647, 0.0609288065606961, 0.005427051828519325, 0.06135312207334209, 0.03883876612235326, 0.00936246289711562, 0.07290321460459381, 0.0339398344658548, 0.020585666279657744, 0.04370042712253053, 0.005440241648102528, 0.020586734972312115, 0.03992963414930273, 0.05673401348758489, 0.02463297605572734, 0.026655781184672378, 0.03837656397081446, 0.03110539066256024, 0.04674496922234539, 0.061278855355340056, 0.0063165380834107054, 0.03858100339130033, 0.046921359171392396, 0.01916089117003139, 0.04160603813943453, 0.01666167918301653, 0.02050917497399496, 0.05927685633650981, 0.056688816694077104, 0.009457263913645875, 0.09258716774638742, 0.04517199835390784, 0.036098968412261456, 0.09177574800560251, 0.023887457173259463, 0.047357174262288027, 0.08303809459903277, 0.00865640122356126, 0.01901914096379187, 0.014205554434738588, 0.019737538059416693, 0.03980287161539309, 0.07232134114019573, 0.015463010495295748, 0.029622651964018587, 0.013286444427649258, 0.026616256254783366, 0.04714898328529671, 0.05336785427061841, 0.03336576097353827, 0.06282290472881868, 0.011993653788522352, 0.01623709835257614, 0.04895041689451318, 0.043681350216502324, 0.001932859149746946, 0.03366283897776157, 0.030467830147244968, 0.0413215395383304, 0.026575814772513695, 0.08732577858609147, 0.03403274022275582, 0.047908604828990065, 0.05918857787037268, 0.026800865489349235, 0.0367574055417208, 0.0322001549648121, 0.04414594208355993, 0.04755065587232821, 0.0458421836810885, 0.03338134607474785, 0.030122289899736643, 0.02021738106122939, 0.061233870073920116, 0.05150276665517595, 0.03202556101314258, 0.019633433294075076, 0.02959728350106161, 0.050141018436988816, 0.032153269785339944, 0.04711336761829443, 0.04272570149623789, 0.028293220566411037, 0.027769856169470586, 0.02363193572819, 0.02875584574212553, 0.030631221379735507, 0.008984619744296651, 0.01934528332640184, 0.030241126296459697, 0.035477842757245526, 0.02190866511227796, 0.011664248759188922, 0.02213848041719757, 0.024072710220934823, 0.05005272141715977, 0.09024322789628059, 0.01043248585119727, 0.010005807525885757, 0.050536746421130374, 0.0073494068055879325, 0.016303077136399224, 0.04103059909539297, 0.006111963684816146, 0.014069193148316117, 0.017944268074643333, 0.05323283534380607, 0.0020684414130300866, 0.015240783650369849, 0.021223592302703764, 0.07837227894924581, 0.04163737903581932, 0.021126554638613015, 0.04165754318819381, 0.07090749786584638, 0.021904345812799875, 0.08257188485004008, 0.10588847275357693, 0.14541766257025301, 0.12850140075897798, 0.2073355033644475, 0.0896787058445625, 0.20345747005194426, 0.2466472439118661, 0.13600997597677633, 0.16640312009258196, 0.1039967086398974, 0.14538104500388727, 0.09765484152012505, 0.17009457747917622, 0.15683701465604827, 0.15554624173091725, 0.10986841778503731, 0.20988645788747817, 0.12525952159194276, 0.12619410816114396, 0.13942464196588844, 0.159832144563552, 0.1294688496273011, 0.1469554370851256, 0.19248236756538972, 0.1553037969279103, 0.10635180296958424, 0.1588752935640514, 0.13076904782792553, 0.17761615512426943, 0.23405421496136114, 0.14407084265258163, 0.11106598438345827, 0.1492418604902923, 0.19238529464928433, 0.08292300975881517, 0.1569360913708806, 0.1803898875368759, 0.1249791233567521, 0.1268312567844987, 0.1133728539571166, 0.10140466140001081, 0.1324650036985986, 0.15499599860049784, 0.15362198639195412, 0.10797883558552712, 0.17632658447837457, 0.20144443900790066, 0.09252323172404431, 0.08688845322467387, 0.1308884148602374, 0.1995909697143361, 0.12111789226764813, 0.12398900187690742, 0.12756996089592576, 0.1461069396464154, 0.14381083863554522, 0.12642237794352695, 0.12820659001590684, 0.22419611894292757, 0.10365879395976663, 0.20835384872043505, 0.08502779994159937, 0.18159099417971447, 0.11276838951744139, 0.1280551473610103, 0.19264808914158493, 0.07885546903708018, 0.2695217641303316, 0.15523750829743221, 0.13312294729985297, 0.09866885273368098, 0.1220735780952964, 0.1287971911369823, 0.183455269143451, 0.10005591189838015, 0.0966178163071163, 0.08926259848522022, 0.14142611034912989, 0.13471219717757776, 0.13519604777684435, 0.1331023601233028, 0.13607489905552939, 0.11903264283319004, 0.17930730187799782, 0.15148140984820202, 0.12585551070515066, 0.1228220340271946, 0.194090764853172, 0.10591985817882232, 0.1438946567941457, 0.09682395524578169, 0.1451726202503778, 0.1620696159079671, 0.07195875004981644, 0.11346512517775409, 0.1690425831475295, 0.10658694503945298, 0.11262612722930498, 0.1953740866156295, 0.12514212867245078, 0.22785219072829932, 0.21601166983600706, 0.08514602406648919, 0.14984984270995483, 0.12673225428443402, 0.16418025421444327, 0.24401993723586202, 0.23101989965653047, 0.13070842920569703, 0.15709966071881354, 0.13823465269524604, 0.12335208331933245, 0.16114696307340637, 0.11645179460174404, 0.09938988630892709, 0.1772915991023183, 0.12632756115635857, 0.1710300100967288, 0.17327070236206055, 0.1905320628429763, 0.14255925110774115, 0.0797277077799663, 0.13254834688268602, 0.08082344429567456, 0.13567841408075765, 0.1986099692294374, 0.14685085363453254, 0.11446705422713421, 0.11896294774487615, 0.11451307480456308, 0.1682202538358979, 0.19920782855479047, 0.1721149854711257, 0.17078937613405287, 0.1267983647994697, 0.13301316881552339, 0.07334032474318519, 0.09259063357603736, 0.18272694025654346, 0.21278133848682046, 0.16512622532900423, 0.06881902751047164, 0.11369929503416643, 0.128205981454812, 0.11174222934641875, 0.08515758672729135, 0.1193760048772674, 0.0973452026664745, 0.1443520572502166, 0.11205284783500247, 0.1273266552016139, 0.13865974004147574, 0.1760629884665832, 0.08324923561303876, 0.07506507594371215, 0.12318642111495137, 0.17292852775426582, 0.10660920946975239, 0.11749894270906225, 0.13599271362181753, 0.10690146722481586, 0.18181271821958944, 0.12127258552936837, 0.13123289012582973, 0.14021146693266928, 0.11577829558518715, 0.13048341003013775, 0.10151832131668925, 0.09734761464642361, 0.20574910333380103, 0.1695431023836136, 0.0858086060907226, 0.16924443247262388, 0.11928596009965986, 0.1180993476009462, 0.1659791756537743], [0.03313642991997767, 0.05225002772931475, 0.01975331240828382, 0.015802749003341887, 0.04298711188312154, 0.010348352279834216, 0.03391025245946366, 0.06291324636549689, 0.020764484906976577, 0.09158822955214418, 0.05906658734602388, 0.00488641208903573, 0.025815974295255728, 0.035001298601855524, 0.009184032041957835, 0.03324977442389354, 0.015469751051568892, 0.05849673667398747, 0.06286237956373952, 0.022396712556655984, 0.04955264004820492, 0.08578479799325578, 0.041932597960112616, 0.018173094467783812, 0.01273833126106183, 0.04344052700616885, 0.018585661782708485, 0.048549100538366474, 0.03464962079306133, 0.09644331512390636, 0.01827278159908019, 0.023026454546197783, 0.06975463082198985, 0.04377866061986424, 0.03562390113074798, 0.014607729826821014, 0.017598406848264858, 0.017963181708182674, 0.059044501031166874, 0.053571774187730625, 0.03465047055215109, 0.07379875678452663, 0.03964074203395285, 0.0294334210047964, 0.012810883617930813, 0.0611335279972991, 0.02023099390498828, 0.053917332988930866, 0.039293105219257995, 0.028959016090084333, 0.014601651637349278, 0.05162144349014852, 0.043540004480746575, 0.07785345092997886, 0.04763523844303563, 0.06991621121414937, 0.05968423232843634, 0.018578824747237377, 0.005418601549536106, 0.04603055560437497, 0.027413862771936692, 0.014808899159106659, 0.02669265479198657, 0.03517913202813361, 0.058488732611294836, 0.028330604400252923, 0.07343456265516579, 0.012920163935632445, 0.04757551410875749, 0.011753364924516063, 0.05231680246652104, 0.03602987817430403, 0.07132188344257884, 0.028982759249629453, 0.030428227291849907, 0.03530620255332906, 0.02294959773280425, 0.02697173385968199, 0.034123081859434023, 0.02405094674031716, 0.026605138882587198, 0.025335025493404828, 0.0359839837619802, 0.01940094996825792, 0.04032084616483189, 0.0653015443822369, 0.02834659768268466, 0.04222077019221615, 0.11534531178767793, 0.058009561253129505, 0.05170132084458601, 0.023772496642777696, 0.01395595903886715, 0.01792755676433444, 0.019164542536600493, 0.0420944084180519, 0.022226551081985235, 0.03239658661186695, 0.04332798402174376, 0.03195016623067204, 0.05518519210454542, 0.011405408986320253, 0.043164885937585495, 0.044127195433247834, 0.03834263297903817, 0.0735220470232889, 0.017995774978771806, 0.0495225459599169, 0.06717661017319188, 0.021703761849494185, 0.051513609432731755, 0.04063089319970459, 0.013364227070269408, 0.024251788599940483, 0.0776849314570427, 0.023176513095677365, 0.024135356761689764, 0.060616347545874305, 0.05288554362778086, 0.07397148423478939, 0.005249242522040731, 0.03511350019834936, 0.018748548354778904, 0.01913862859510118, 0.04527968769252766, 0.053853571371291764, 0.016140305597218685, 0.02574522906797938, 0.04672905015468132, 0.050249772757524624, 0.0360088382876711, 0.019907693967979867, 0.011803903325926512, 0.04866604816925246, 0.05181338514375966, 0.05046265039709397, 0.10181569989072159, 0.03865602338919416, 0.031240457828971557, 0.030891225396771915, 0.049452516905148514, 0.02415776405541692, 0.07494688892620616, 0.04101711056136992, 0.042499784321989864, 0.031604180694557726, 0.014683403842354892, 0.04416664429299999, 0.043367225080146454, 0.05506402907485608, 0.06010497440001927, 0.01294349427553243, 0.014107751430856297, 0.009338814361399272, 0.026327388259232976, 0.005683646140823839, 0.03749145267647691, 0.053272061559255235, 0.01707760657154722, 0.04866433751885779, 0.01612564446986653, 0.027833439671667293, 0.039498257101513445, 0.04434793612745125, 0.016828814550535753, 0.06645755813224241, 0.037070239341119304, 0.03188817463524174, 0.04615558522345964, 0.061333822523010895, 0.046048478470765986, 0.05219235172262415, 0.018060384500131477, 0.05517839774256572, 0.053726029582321644, 0.058194652883685194, 0.03279020318586845, 0.0638166701537557, 0.024052505250438116, 0.051506469972082414, 0.05112963706778828, 0.030375575624930207, 0.027237554459134117, 0.031129206181503832, 0.037137236722628586, 0.07520372397266328, 0.024996075517265126, 0.017544068650749978, 0.040510910184821114, 0.005417338043116615, 0.0304998259889544, 0.021420812481665052, 0.007238794796649017, 0.08228316713939421, 0.041767143557081, 0.035755417120526545, 0.03674155697808601, 0.023830046484363265, 0.0683830825437326, 0.015559583389403997, 0.03888410392391961, 0.015532915240328293, 0.054244022685452364, 0.029951154356240295, 0.0057601931075623725, 0.0891952782694716, 0.034250738681294024, 0.07737215331871994, 0.03840053534077015, 0.07561293678008951, 0.02911884872446535, 0.03375797488843091, 0.03080308608332416, 0.0936401862418279, 0.031967799659469165, 0.023937553996802308, 0.015805836337676737, 0.048940204942482524, 0.06744767219061032, 0.12443773404811509, 0.07410072183120064, 0.053869868934270926, 0.03280219629232306, 0.015092265985003905, 0.030438793619396165, 0.026299320234102197, 0.09658805618528277, 0.024321622840943746, 0.02789122700050939, 0.06698691722704098, 0.039781924497219734, 0.04648488356906455, 0.04307226961827837, 0.032546177608310245, 0.08535724671673961, 0.014147766178211896, 0.06895550846820697, 0.07959130103699863, 0.012409246282913955, 0.08831773317069747, 0.05650480859912932, 0.04282218811567873, 0.03829132088867482, 0.040415351249976084, 0.1666335717891343, 0.01968578068044735, 0.07050748768961057, 0.03748310722585302, 0.0713123097375501, 0.03246727988880593, 0.05172183380636852, 0.02958720699098194, 0.04910178162390366, 0.058422377187525854, 0.0825585113489069, 0.06636047037318349, 0.04368921698187478, 0.035162352069164626, 0.02378655848588096, 0.046863152529112995, 0.10002408860600553, 0.01647458746447228, 0.04719034688605461, 0.021099388322909363, 0.02812689599522855, 0.058433624435565434, 0.06308515745331533, 0.015469910613319371, 0.08074280252913013, 0.03195830016920809, 0.0709154388459865, 0.05796837205707561, 0.05265159270493314, 0.0138175568463339, 0.06281526802922599, 0.06878304076963104, 0.022093125917308498, 0.04069938600878231, 0.024836296688590664, 0.05860011784534436, 0.00769220203437726, 0.021266664698487148, 0.059102466475451365, 0.046899105873308145, 0.015438929658557754, 0.022074258667998947, 0.019046589295612648, 0.05727119852963369, 0.04830654070246965, 0.055582875647814944, 0.0378824160725344, 0.04641719599021599, 0.05363638927519787, 0.024034018351812847, 0.015800615328771528, 0.06660086684860289, 0.006425582769225002, 0.06405735606676899, 0.0123821467605012, 0.005683634080924094, 0.028373710192681756, 0.0610249035526067, 0.029182152065914124, 0.0181807330227457, 0.008793502802291187, 0.040481981268385425, 0.053997789218556136, 0.04677924531279132, 0.07980515831150115, 0.09670545652625151, 0.05217297424678691, 0.043274111521895975, 0.02427881205221638, 0.06131057103630155, 0.07034918759018183, 0.006065453289920697, 0.03352691092004534, 0.061724548431811854, 0.04191222229565028, 0.025585927069187164, 0.09512385076959617, 0.02930491442384664, 0.13501450361218303, 0.04792627165443264, 0.03698424297908787, 0.026120501606783364, 0.009718907149363076, 0.08846835946314968, 0.04569847049424425, 0.00987762748991372, 0.07002984144492075, 0.03856928116874769, 0.03288277497631498, 0.009983807485696161, 0.01209853966429364, 0.03411392004636582, 0.047391071857418865, 0.0829886675637681, 0.044236446992727, 0.02325793782802066, 0.03912359126843512, 0.05247019696980715, 0.0357912368781399, 0.02878917002817616, 0.07307385661988519, 0.03536696589435451, 0.03485629407805391, 0.056146644419641234, 0.0063274991407524794, 0.06001683323120233, 0.03812034861766733, 0.025844693554972764, 0.09516278383671306, 0.116843982541468, 0.0917388335801661, 0.08258010042482056, 0.11036184208933264, 0.09070949701708741, 0.09583132530678995, 0.11299656282062642, 0.1611069167847745, 0.1907779066823423, 0.18536925315856934, 0.12096242717234418, 0.14282866555731744, 0.19417358853388578, 0.14040822512470186, 0.1800529079628177, 0.1687445811694488, 0.2158685986069031, 0.14779887307668105, 0.07336957278312184, 0.11265111534157768, 0.2102652649045922, 0.13193583756219596, 0.23602915898663923, 0.08303268434247002, 0.126418563304469, 0.09653976463596337, 0.14544304402079433, 0.14124573877779767, 0.30864749278407544, 0.1292996696429327, 0.13170363439712673, 0.1489673845935613, 0.1894102175720036, 0.13952536624856293, 0.12940100248670205, 0.12970229960046709, 0.31788856722414494, 0.06616319267777726, 0.14942879264708608, 0.20726504386402667, 0.1305248515564017, 0.27891664125490934, 0.18643337418325245, 0.1341497531393543, 0.11339908887748607, 0.0774107153119985, 0.1438878438784741, 0.21199402370257303, 0.11694517437717877, 0.207939418614842, 0.19270631804829463, 0.07214730751002207, 0.1707907862146385, 0.18027553742285818, 0.2759700478054583, 0.09203293928294443, 0.08275396336102858, 0.19658297096611932, 0.1532740527181886, 0.13990065548568964, 0.1743059538421221, 0.19348861591424793, 0.1929340386413969, 0.13016384124057367, 0.19683938298840076, 0.18507626809878275, 0.1374598208349198, 0.2400143287377432, 0.15050600515678525, 0.18114524544216692, 0.09952920969226398, 0.17554759659105912, 0.1583798654610291, 0.15646812273189425, 0.20695004670415074, 0.12435522206942551, 0.10514087029150687, 0.17835597245721146, 0.15009727474534884, 0.13557521102484316, 0.09262616018531844, 0.11917549883946776, 0.12563565687742084, 0.22029656334780157, 0.15155777684412897, 0.11039603283279575, 0.08146226275130175, 0.19350902497535571, 0.12251261781784706, 0.1639199978671968, 0.08725006468011998, 0.14172596769640222, 0.09193751393468119, 0.1996057978249155, 0.16681603621691465, 0.15311275434214622, 0.09397798217833042, 0.14342078065965325, 0.13284945103805512, 0.11823919790913351, 0.08674047639942728, 0.12290732163819484, 0.15809545962838456, 0.07931510335765779, 0.1829623049707152, 0.09659252391429618, 0.13568473717896268, 0.10880419285967946, 0.0926215885556303, 0.16640338726574555, 0.12842982803704217, 0.10958410101011395, 0.12271829662495293, 0.17805102397687733, 0.1805364023311995, 0.11310812245937996, 0.22756723570637405, 0.14789054315770045, 0.1254547806456685, 0.11391790947527625, 0.1536303578177467, 0.08276413078419864, 0.06851462079794146, 0.09926110142259859, 0.16750203300034627, 0.08450053370324895, 0.09674988148617558, 0.14054068364202976, 0.07816294877557084, 0.17429854720830917, 0.16845953708980232, 0.17729912447975948, 0.24587496503954753, 0.10737434888142161, 0.13845183479133993, 0.24596982635557652, 0.15891232673311606, 0.23168265237472951, 0.08860755668138154, 0.1344984141178429, 0.19421865174081177, 0.12655691447434947, 0.13655603339429945, 0.24459936161292717, 0.2251331991283223, 0.20882932789390907, 0.1719577837502584, 0.13295122917043045, 0.17314743163296953, 0.28008680033963174, 0.1406716727069579, 0.06829617705079727, 0.1997882770956494, 0.13396194524830207, 0.08818580157821998, 0.1278742859722115, 0.14126610331004485, 0.05844111641636118, 0.10986189430695958, 0.12326539304922335, 0.1738028964609839, 0.14047046162886545, 0.12480422883527353, 0.2179239023826085, 0.1602103133336641, 0.1517043064814061, 0.20145021291682497, 0.14360389817738906, 0.15855219215154648, 0.15302627929486334, 0.20791946968529373, 0.22178243205416948, 0.14191873313393444, 0.13556363352108747, 0.1291087595745921], [0.03503414976876229, 0.03777088611968793, 0.011617388627200853, 0.009758435789990472, 0.04788862250279635, 0.03969616562244482, 0.042044829242513515, 0.12051614408846945, 0.09210123913362622, 0.07523035965277813, 0.04966285268892534, 0.06151750778371934, 0.03826334563200362, 0.05122364491398912, 0.016229875400313176, 0.021519679539778735, 0.024651151252328418, 0.04067364461661782, 0.11071963148424402, 0.06709526336635463, 0.03040022977074841, 0.04868081319727935, 0.05452188277558889, 0.041885753598762676, 0.021154212627152447, 0.02205983688327251, 0.03445331160037313, 0.023314333629969042, 0.007686420240133884, 0.06841668699053116, 0.07213738499558531, 0.005868085145266377, 0.02650283382536145, 0.021458281662489753, 0.024202960848924704, 0.06897932398715056, 0.04574745224090293, 0.009178939053526847, 0.029357219136727508, 0.04813782827113755, 0.04316613274568226, 0.02191769890487194, 0.04134158123633824, 0.003110502098024881, 0.0510211647633696, 0.045079831033945084, 0.01995384071051376, 0.02947335782664595, 0.03539038807502948, 0.059064720844617113, 0.026450640434632078, 0.0259387904588948, 0.022135730760055594, 0.06526465222123079, 0.02892717981012538, 0.03988622222095728, 0.08869625817169435, 0.029232740562292747, 0.029094845813233405, 0.03723029461980332, 0.014706577403558185, 0.03338479335070588, 0.05949322207015939, 0.04507508871029131, 0.027263397896604147, 0.0627543377049733, 0.0766371822101064, 0.03540549449098762, 0.036785952252103016, 0.011420099799579475, 0.03380376540008001, 0.06686361681204289, 0.012451765778678237, 0.007127243043214548, 0.035574982466641814, 0.031101114036573563, 0.021884446978219785, 0.03638201240391936, 0.0867770345939789, 0.03192098498402629, 0.06065817127819173, 0.03316184847790282, 0.018859679403249174, 0.05075262604805175, 0.055736411159159616, 0.03066111879888922, 0.05577137002546806, 0.04820507798285689, 0.026579352961562108, 0.03994642524048686, 0.004781253473993274, 0.045496149905375205, 0.03955162494094111, 0.05807656605611555, 0.07162701003835537, 0.002874675165003282, 0.032997117668855935, 0.016788721877674107, 0.027081931657448877, 0.05323095771018416, 0.12168259243480861, 0.024115172200254165, 0.030153899824654218, 0.032417834299849346, 0.02382478465733584, 0.08207362916436978, 0.04063802523887716, 0.049653356909402646, 0.05737277628213633, 0.011551040624908637, 0.03338836308103055, 0.0270543720034766, 0.017702938348520547, 0.01968223135918379, 0.04288935619115364, 0.04617334110662341, 0.06912629149155691, 0.04221755298203789, 0.051303384971106425, 0.05220765851845499, 0.0021725290162066813, 0.03520868434861768, 0.06425495288567618, 0.04331500385887921, 0.02278951091284398, 0.04732510235044174, 0.008707148354005767, 0.051520529959816486, 0.011942796263610944, 0.06459003998315893, 0.04880050677456893, 0.05742182482208591, 0.0470129179302603, 0.03252877795603126, 0.03840821285848506, 0.06598092120839283, 0.06221821022336371, 0.006363173251884291, 0.044817073649028316, 0.009520763924228959, 0.10418067220598459, 0.03016336962900823, 0.019230701291235164, 0.04212797946820501, 0.06239177630050108, 0.04378694298793562, 0.053905269378446974, 0.019814174083876424, 0.04786193858308252, 0.008249586480815196, 0.048287051904480904, 0.0198918398382375, 0.031059724460646976, 0.06720988807501271, 0.02401660014584195, 0.061356821679510176, 0.03966083568229806, 0.023324378598772455, 0.01215026642967132, 0.026180517234024592, 0.039916891473694704, 0.0553502568800468, 0.02352066738239955, 0.015325398690038128, 0.07408331846818328, 0.039398404842359014, 0.054257644806057215, 0.008124164451146498, 0.05571263645833824, 0.023537187589681707, 0.006307514031504979, 0.04709967128292192, 0.03238145051000174, 0.012440102000255138, 0.007804733886587201, 0.07062607546686195, 0.0624107381736394, 0.021566731702478137, 0.02577819712314522, 0.030445218762906734, 0.04914465178444516, 0.05025353544624522, 0.01565562008181587, 0.07585706625832245, 0.046432398885372095, 0.0393090391298756, 0.0408270020125201, 0.061305672861635685, 0.011874422198161483, 0.016915528940444347, 0.06111001675890293, 0.05049567225796636, 0.015354372135334415, 0.06791307299863547, 0.03175594247295521, 0.03570322929590475, 0.0320359139732318, 0.02737210954364855, 0.039810901653254405, 0.02279578948218841, 0.06516811365145259, 0.03192528944055084, 0.05335886686225422, 0.034747216923278756, 0.05025244077842217, 0.025706557607918512, 0.017134727822849527, 0.0172095400193939, 0.00790456666436512, 0.06414026138372719, 0.03159181651426479, 0.04984360646631103, 0.025815499320742674, 0.04591196040564682, 0.049763625211198814, 0.03018736511876341, 0.022929179394850507, 0.01255116625543451, 0.0409825895621907, 0.04853654339967761, 0.025913924800988752, 0.07528451416874304, 0.028997854533372447, 0.010145031646970892, 0.055014308891259134, 0.07882878882810473, 0.016613734587735962, 0.01951902566361241, 0.037244291524984874, 0.06771702726837248, 0.027385854118620045, 0.03307072758616414, 0.025199077026627492, 0.059106277403770946, 0.0190815463065519, 0.06789696097257547, 0.012350987690297188, 0.03610329513321631, 0.034529244439909235, 0.025335209174954798, 0.027375143072276842, 0.021958283250569366, 0.02990256223711185, 0.00953488606683095, 0.07883187616243958, 0.06177653216582257, 0.06375653392751701, 0.03035100868146401, 0.025379020007676445, 0.05784833338111639, 0.059757445196737535, 0.025257537854486145, 0.028873030860268045, 0.023874742328189313, 0.038422506622737274, 0.07041802920866758, 0.024831695372995455, 0.027430136215116363, 0.05655495922837872, 0.04170136329776142, 0.060951909617870115, 0.013345078732527327, 0.05242749008175451, 0.057152299050358124, 0.013121810097800335, 0.05863666861841921, 0.013010769034735858, 0.04781138719408773, 0.040280662578879856, 0.0771293522848282, 0.08687515393830836, 0.028256118748686276, 0.028858250989287626, 0.06496763729956001, 0.032866648107301444, 0.012139323462179163, 0.08327483970788307, 0.04797570611117408, 0.02592522585473489, 0.035643987357616425, 0.06628880117204972, 0.0650051306001842, 0.04033145887660794, 0.11360892371158116, 0.009000040645332774, 0.022756939906685147, 0.03739193438377697, 0.00858708184750867, 0.019994206122646574, 0.0229756359840394, 0.022583219833904877, 0.03273268674092833, 0.0014993218724157487, 0.026042707831948064, 0.037071742190164514, 0.04886639093456324, 0.07040906406473368, 0.008744747410673881, 0.007583305314255995, 0.02184738783398643, 0.015391442411782918, 0.049335624935338274, 0.010752871930890251, 0.07065593948937021, 0.039399633096763864, 0.04432319663465023, 0.031146201363299042, 0.07485099602490664, 0.10105381108587608, 0.05155714010470547, 0.07669934449950233, 0.0322906079236418, 0.0008237127792654064, 0.026800772720889654, 0.02060682305454975, 0.026585395899019204, 0.08873032275005244, 0.02769674905721331, 0.014332648152048932, 0.0367071435903199, 0.033160623934236355, 0.011175154886586824, 0.021220254493528046, 0.031106203314266168, 0.022084179327066522, 0.0767104173428379, 0.02445529476972297, 0.01715789952868363, 0.040419024880975485, 0.0567763493017992, 0.021667589571734425, 0.05922908429056406, 0.020997805004299153, 0.09542385654640384, 0.013729463917115936, 0.026440070396347437, 0.05606537182757165, 0.1103469768713694, 0.07182146015111357, 0.03342698444612324, 0.12667784001678228, 0.05848129258083645, 0.02907545720518101, 0.037484699132619426, 0.057239698071498424, 0.031922046255203895, 0.029432519295369275, 0.06930868912604637, 0.03590617699956056, 0.028710151709674392, 0.05571538240474183, 0.04002867375675123, 0.09778610517969355, 0.16226766543695703, 0.10006812764913775, 0.0778494359110482, 0.1141739430022426, 0.12414884564350359, 0.1406136664445512, 0.2241064971894957, 0.12022968250676058, 0.13220614258898422, 0.09699699439806864, 0.19579451327444986, 0.12029325487674214, 0.09025766266859137, 0.15979659568984061, 0.15173740626778454, 0.1896733237663284, 0.11385824822355062, 0.15033076924737543, 0.1463143402361311, 0.20266319392248988, 0.14126550959190354, 0.16080732661066577, 0.13579389225924388, 0.13963887031422928, 0.11122189476736821, 0.1223720030975528, 0.12870599603047594, 0.16502655489603058, 0.16691166936652735, 0.10745205916464329, 0.10521320742554963, 0.06948924623429775, 0.16687606112100184, 0.10933987505268306, 0.15171471139183268, 0.08931703501730226, 0.10247685699141584, 0.17451523948693648, 0.08697234559804201, 0.16223278449615464, 0.19417363306274638, 0.20545950246741995, 0.2618633344536647, 0.13407709688181058, 0.2486946215503849, 0.17520809371490031, 0.20473963406402618, 0.16204913263209164, 0.22753501165425405, 0.0781543918128591, 0.11346856132149696, 0.1523946670931764, 0.13409262261120602, 0.10810667052282952, 0.15143211639951915, 0.1631548732984811, 0.09699334303149953, 0.08929096336942166, 0.1384592117392458, 0.07954624525154941, 0.14589189493563026, 0.16572778054978698, 0.08326375944307074, 0.09443884846405126, 0.12291682112845592, 0.08607194235082716, 0.08974776268587448, 0.1421991758979857, 0.18032135762041435, 0.1429256345727481, 0.1407685675076209, 0.07214470999315381, 0.1175389889976941, 0.1544233426102437, 0.11784677248215303, 0.08103770975139923, 0.1144739190931432, 0.18018449074588716, 0.11948084807954729, 0.108464170480147, 0.1508028048556298, 0.1481936065829359, 0.2075373230036348, 0.13303982676006854, 0.10149364490644075, 0.17727947240928188, 0.16124114161357284, 0.14426486974116415, 0.11441375318099745, 0.14536494039930403, 0.0902900351502467, 0.09849874506471679, 0.18145187117625028, 0.20653186133131385, 0.07756647726637311, 0.13527116796467453, 0.10784590951516293, 0.1282096773502417, 0.11656409638817422, 0.24210547824623063, 0.10701442210120149, 0.06909745163284242, 0.22402526170480996, 0.15535895334323868, 0.12844366166973487, 0.12331519115832634, 0.17068222485249862, 0.2622827369486913, 0.10734299314208329, 0.12937324616359547, 0.11056198447477072, 0.15016700694104657, 0.15379881049739197, 0.10262571697239764, 0.2371730312006548, 0.1974860014161095, 0.16686699207639322, 0.11836420526378788, 0.10186298211920075, 0.1310999714769423, 0.12288321668165736, 0.11706507575581782, 0.14103164401603863, 0.06062234038836323, 0.1644377943011932, 0.16302247415296733, 0.1933569143875502, 0.08833561150822788, 0.21152614412130788, 0.12342079877271317, 0.2398181494208984, 0.14238745876355097, 0.14809626649366692, 0.16015469678677619, 0.1350822765380144, 0.12999023805605248, 0.1082807857892476, 0.14802936930209398, 0.1793984672985971, 0.23947189300088212, 0.10419555968837813, 0.18054931570077315, 0.17322360567050055, 0.11845109591376968, 0.08402314721024595, 0.13000212726183236, 0.1006711449008435, 0.1330444577615708, 0.26081144402269274, 0.1103722098923754, 0.17532817320898175, 0.19198486144887283, 0.306303731049411, 0.11071438450017013, 0.15796594001585618, 0.24287354171974584, 0.21040760882897303, 0.07406287972116843, 0.22308148734737188, 0.08865692434483208, 0.1275673633790575, 0.10709793597925454, 0.06146300074760802, 0.20134203747147694, 0.12881163333076984, 0.1659833762096241, 0.13211533339926973, 0.08822321324259974, 0.157122622767929, 0.052319782189442776, 0.13031734706601128, 0.1299668158753775, 0.1144437953189481, 0.12157881050370634, 0.2131575034582056], [0.02863116307707969, 0.029665132497029845, 0.027549373371584807, 0.03399116510991007, 0.07518301805248484, 0.048128273119800724, 0.0075793867745233, 0.04039192164782435, 0.054702733032172546, 0.05664823605911806, 0.020172588738205377, 0.024299551369040273, 0.024698075394553598, 0.02465599747665692, 0.09705232892883942, 0.039476014935644343, 0.00521997778378136, 0.02076322696666466, 0.04270510689821094, 0.023135956580517814, 0.07665311612072401, 0.032113828347064555, 0.08348463001311757, 0.02642630355694564, 0.01208396110087051, 0.07670284001505934, 0.01214711230204557, 0.015608749745297246, 0.03747079499589745, 0.02005277456191834, 0.035066162308794446, 0.049148202961077914, 0.005321878834365634, 0.042546940385363996, 0.04502501971728634, 0.08490645137499087, 0.12089834272046573, 0.02995887269207742, 0.0307594106925535, 0.029441185724863317, 0.05134379491209984, 0.03245777668780647, 0.03589818406908307, 0.03007972216437338, 0.06046493457688484, 0.010567925019131508, 0.018876758076658007, 0.025376621015311684, 0.0003826140027740621, 0.029821968710166402, 0.11695865177898668, 0.042228017264278606, 0.0650228159793187, 0.031090215597942006, 0.020422193410922773, 0.01911686696985271, 0.07062676566420123, 0.01354498919681646, 0.011598285746003967, 0.06256802153075114, 0.02956127078505233, 0.03549392880813684, 0.021104006336827297, 0.057666266002343036, 0.09530129085760564, 0.005440259737952147, 0.02333534383069491, 0.016171332936210092, 0.030913278314983472, 0.009752548703545472, 0.0921928053139709, 0.08310620149131864, 0.022205167952051852, 0.024571550347900484, 0.05214008968323469, 0.043084166245535016, 0.05201550535275601, 0.03682652175484691, 0.02451632342854282, 0.04706115752924234, 0.015178677949734265, 0.026119880058104172, 0.0629658720572479, 0.01722071861877339, 0.052638427005149424, 0.014052503174752928, 0.03877704912156332, 0.0070584454897471005, 0.03736783313797787, 0.04348528222180903, 0.03651091603387613, 0.021445078855322208, 0.03293858819233719, 0.04861190107476432, 0.06137300420959946, 0.03863115402054973, 0.051095283051836304, 0.0026933807794193854, 0.014649465429101838, 0.029909740660514217, 0.0979044109408278, 0.023952654846652877, 0.03273009664553683, 0.013021962477068882, 0.023208121165225748, 0.09790335709112696, 0.01283235209484701, 0.04499737100559287, 0.017853796562121715, 0.03163019668136258, 0.04023336550744716, 0.08504339246428572, 0.011420728769735433, 0.022698777793266345, 0.061981572725926526, 0.018152486882172525, 0.022339049537549727, 0.07290800887858495, 0.05023692247050349, 0.04676386059145443, 0.05502005682501476, 0.04408018408867065, 0.05201361287618056, 0.029321367837837897, 0.022557697375304997, 0.004072668034496019, 0.03629460225056391, 0.04453989262401592, 0.038474505199701525, 0.05438376167148817, 0.02172745491407113, 0.011431309012550628, 0.05560208985116333, 0.050295537294005044, 0.04719554563052952, 0.04380145197501406, 0.02752773420070298, 0.000813306999134511, 0.019857498809869867, 0.039523182131233625, 0.03588019069866277, 0.03820177706074901, 0.01852333065471612, 0.048066281524370424, 0.06132284615887329, 0.016288666483887937, 0.02750979649135843, 0.04854341568716336, 0.08877684056642465, 0.006632181839449913, 0.11698284579324536, 0.013642926714965142, 0.04560219538689125, 0.06602600667974912, 0.09690509425126947, 0.007759035679555382, 0.043709982273867354, 0.05923774886468891, 0.11275801429292187, 0.04268429707735777, 0.029691139206988737, 0.03305498292320408, 0.04902718465018552, 0.08596768544521183, 0.01446613083317061, 0.03104345658357488, 0.03994054743088782, 0.01587041431776015, 0.02134195001417538, 0.07828449772205204, 0.010702564522944158, 0.03321206218970474, 0.044967840949539095, 0.00454103465017397, 0.043913126646657474, 0.0896565527364146, 0.06231774706975557, 0.03472041425993666, 0.01693949474429246, 0.04859971872065216, 0.08602588466601446, 0.11337401912896894, 0.0621187958313385, 0.04673800787713844, 0.08639781939564273, 0.04126056839595549, 0.012626573097804794, 0.07851298272726126, 0.05984943069051951, 0.05961184324405622, 0.021839608270965982, 0.05203462307690643, 0.02866013652237598, 0.035503179678926244, 0.05056206849985756, 0.03955773281631991, 0.09575576725183055, 0.026976298067893367, 0.027205603146285284, 0.050755049160216004, 0.058348462989670224, 0.01864125606516609, 0.03811200316704344, 0.05560329584113788, 0.06047809656593017, 0.035628105397336185, 0.053872117641731165, 0.0197177505469881, 0.030176880427461583, 0.11724844560376368, 0.02571657289081486, 0.04844447998038959, 0.049920797246159054, 0.04345468718383927, 0.007876809413573937, 0.027303264214424416, 0.05576741437835153, 0.037277413575793616, 0.03377845816430636, 0.02565751834481489, 0.053262936853570864, 0.008856601125444286, 0.040209661310655065, 0.03998200008936692, 0.02502140501746908, 0.036506251635728404, 0.07663914890144952, 0.07530803282861598, 0.050321575545240194, 0.013230163658590754, 0.021780004535685293, 0.06223909054824617, 0.03993777550931554, 0.03725415837834589, 0.018242366531922016, 0.015398748855659505, 0.03206646077160258, 0.03162365093885455, 0.06702604325255379, 0.1067489261913579, 0.030061539546295535, 0.02800725993438391, 0.01611325060366653, 0.03432856399740558, 0.04008381532912608, 0.0033875379403980332, 0.08484328718623146, 0.07814246549969539, 0.10124584179720841, 0.01887493610411184, 0.048805560800246894, 0.04248103767167777, 0.0816379365278408, 0.07137818276532926, 0.07809783273842186, 0.015638044169463683, 0.011955382160522277, 0.040527964738430455, 0.0881526424200274, 0.048964673551381566, 0.027217388451390434, 0.050075917242793366, 0.06907584029249847, 0.023013721147435717, 0.0062357798924495, 0.02093322702421574, 0.00975893395661842, 0.04703465543570928, 0.024624779034638777, 0.015822889035916887, 0.026944940473185852, 0.05835521653352771, 0.024663016338308807, 0.030058737938816193, 0.051610808513942175, 0.01138504167101928, 0.06955513410503045, 0.04701579746324569, 0.027730244037229568, 0.03268428386945743, 0.07948840226163156, 0.04639898368623108, 0.06911561198648997, 0.07911192558822222, 0.014682531818834832, 0.026177791696682107, 0.06816247914684936, 0.08226248348364606, 0.007695771300859633, 0.02402866375632584, 0.016388114272558596, 0.019391561800148338, 0.043957332673016936, 0.03829227454843931, 0.059747518971562386, 0.034574745513964444, 0.021361930484999903, 0.05459571162646171, 0.049556888843653724, 0.07844813386327587, 0.04850877223361749, 0.017039226404449437, 0.029030171353952028, 0.05535790842259303, 0.03664688490971457, 0.0390246666938765, 0.08564594958443195, 0.08024927432416007, 0.03944461095670704, 0.012770129505952355, 0.036810109158977866, 0.09565046391799115, 0.03274856870120857, 0.09882972808554769, 0.012803694989997894, 0.04101321428606752, 0.028291580420045648, 0.01130988159275148, 0.09707568431622349, 0.05321008851751685, 0.03140584914945066, 0.11230174190131947, 0.025517129979562014, 0.051002377294935286, 0.04420958866830915, 0.028868373883597087, 0.02789761874737451, 0.019909885158995166, 0.08855622974806465, 0.028473499369283672, 0.025092053765547462, 0.01664648556470638, 0.03707785748702008, 0.047584761268808506, 0.022265450752456672, 0.08693527532159351, 0.014970539850764908, 0.03238681994844228, 0.004964262452631374, 0.0224865643758676, 0.022236041295400355, 0.04892740289506037, 0.03914038235961925, 0.025296472776972223, 0.06171628461743239, 0.0269828196906019, 0.022341986586980056, 0.041538176155881956, 0.07750585122266784, 0.06052258460840676, 0.04503555450355634, 0.03462501488684211, 0.10708882240578532, 0.09134315754636191, 0.09717198539874516, 0.15155917208176106, 0.30861433362588286, 0.1965688107884489, 0.1636804622830823, 0.1732188113965094, 0.1748134641093202, 0.1462272714707069, 0.08384967019082978, 0.18879273586208, 0.1159536353952717, 0.121654709946597, 0.13885305466828868, 0.17495764855993912, 0.0942477305943612, 0.11252923242864199, 0.11756582505768165, 0.08750246168347076, 0.17536620085593313, 0.06576841464266181, 0.22502270818222314, 0.12663550791330636, 0.10480029130121693, 0.1631405350053683, 0.19529145589331165, 0.14038011257071048, 0.17003591812681407, 0.07902263037976809, 0.09386236299178563, 0.12787940679118037, 0.11852432362502441, 0.33680947381071746, 0.09077855385839939, 0.2126265413244255, 0.2996838034596294, 0.11266418456216343, 0.1264243817422539, 0.11872974268044345, 0.15822719084098935, 0.09734516555909067, 0.06972692644922063, 0.14445858512772247, 0.12274502136278898, 0.15858259052038193, 0.18854281021049246, 0.13786380150122568, 0.13209128781454638, 0.19576202204916626, 0.1812306814827025, 0.21893369819736108, 0.1472197604016401, 0.09055662201717496, 0.14717871963512152, 0.1643546440755017, 0.1263114417088218, 0.1178937875374686, 0.13039283832767978, 0.1532480923924595, 0.1289925689343363, 0.09635649126721546, 0.14763049461180344, 0.18900596973253414, 0.23313040437642485, 0.16821406432427466, 0.06303954505710863, 0.12414871947839856, 0.12796273513231426, 0.06778442912036553, 0.1591099755023606, 0.19076279655564576, 0.17813202197430655, 0.12385534108034335, 0.16374449478462338, 0.12355766564724036, 0.21351959730964154, 0.16911549173528329, 0.12613760103704408, 0.14944620343158022, 0.09799156134249642, 0.1423303727642633, 0.1785012404434383, 0.11354858710546978, 0.11570397691684775, 0.13123385491780937, 0.20377656386699528, 0.16874484834261239, 0.20662041439209133, 0.09861016369541176, 0.09018158511025831, 0.09462421468924731, 0.1473789956071414, 0.12741149752400815, 0.08888940952601843, 0.1687933996436186, 0.19459858682239428, 0.15584323438815773, 0.1206045487197116, 0.10370943069574423, 0.19062333216425031, 0.11565716966288164, 0.14918654080247506, 0.07570465138996951, 0.16817761003039777, 0.1273414387833327, 0.12460390833439305, 0.17807410476962104, 0.10076331964228302, 0.11060187491239049, 0.1403608315740712, 0.1453238699468784, 0.10997505698469467, 0.11504143199999817, 0.14511611312627792, 0.1464509844663553, 0.24188056297134608, 0.1521334014250897, 0.23877452651504427, 0.14076908701099455, 0.11805821777670644, 0.11156492284499109, 0.08974794080131687, 0.1549152677762322, 0.1676679030060768, 0.11041223391657695, 0.18691389996092767, 0.15843505156226456, 0.10043036250863224, 0.103587978228461, 0.20415311475517228, 0.13857851939974353, 0.30372141336556524, 0.12875601678388193, 0.15184182644588873, 0.11796437320299447, 0.15129804000025615, 0.18072406179271638, 0.052631324651883915, 0.15394174813991413, 0.12999117316212505, 0.11170385289005935, 0.20589419320458546, 0.10637639032211155, 0.13503755471901968, 0.2098820495302789, 0.07746438743197359, 0.11817743637948297, 0.15909583016764373, 0.15120818075956777, 0.2489268098725006, 0.10053987381979823, 0.2145187952555716, 0.15167390811257064, 0.18133219244191423, 0.19629942602477968, 0.09092549167689867, 0.1393497147364542, 0.17777648870833218, 0.1969180061132647, 0.060375138418748975, 0.08786163889453746, 0.18721438071224838, 0.13117080205120146, 0.18678964959690347, 0.09981391980545595, 0.10803787343320437, 0.07483654640964232, 0.1304901042021811, 0.16157556819962338, 0.13743927818723023, 0.12252231026650406, 0.28391735104378313, 0.11600119963986799, 0.15593689342495054, 0.202916978741996], [0.023888525865913834, 0.027201081611565314, 0.014443229083553888, 0.02725131758779753, 0.04357366829935927, 0.019335772703925613, 0.0746081949910149, 0.06340541644021869, 0.06393510950147174, 0.08060385021963157, 0.015635359450243413, 0.07164223890868016, 0.02443270193907665, 0.10694947675801814, 0.011732996681530494, 0.04655701661249623, 0.021140738936082926, 0.0653820154548157, 0.05808861111290753, 0.03900077696016524, 0.03287614388682414, 0.04553315338853281, 0.04121146790566854, 0.056186237998190336, 0.01371619060591911, 0.06851646132417955, 0.02995123970322311, 0.06175435679324437, 0.04228051308018621, 0.025340665815747343, 0.04709681772510521, 0.026868345266848337, 0.028188536925881635, 0.024766596034169197, 0.038358770980266854, 0.021912066004006192, 0.03959860659961123, 0.024583163103670813, 0.04876201899605803, 0.009628989464545157, 0.049403126977267675, 0.03267412757850252, 0.05263678314804565, 0.016025788499973714, 0.05333175249688793, 0.03153369892970659, 0.024539432051824406, 0.038728108193026856, 0.05093511274026241, 0.010168400021939306, 0.1365115342196077, 0.049545266811037436, 0.02415649127215147, 0.048566704281256534, 0.054746122696087696, 0.009792135788302403, 0.0324555131373927, 0.014899441175657557, 0.019363623650860973, 0.015714639375801198, 0.1263807583018206, 0.002810409350786358, 0.07126844138838351, 0.022551346446562093, 0.04464341480343137, 0.02540600449719932, 0.061728107029921375, 0.04509925674938131, 0.037601257135975175, 0.020977056410629302, 0.038143819037941284, 0.06107046770921443, 0.03917011279554572, 0.05900973512325436, 0.050229508415213786, 0.030072868430579547, 0.015153693548199954, 0.09070790139958262, 0.05324670237314422, 0.020801766695512924, 0.00524605360624264, 0.034396158807794563, 0.03283297686721198, 0.06404275802196935, 0.02500691272871336, 0.04681157326558605, 0.056175358113250695, 0.03267478437919635, 0.017946221778402105, 0.012923817157570738, 0.019207885816285852, 0.050803604171960615, 0.029272419487824664, 0.011922138583031483, 0.0016796877616798156, 0.08670697585330345, 0.10277005727402866, 0.04690423411375377, 0.029044500370218884, 0.018548580374044832, 0.05091499311674852, 0.03460213076323271, 0.01329155875282595, 0.05445862210763153, 0.05401212380093057, 0.022776627229177393, 0.013013943571422715, 0.06073719145206269, 0.018245244209538214, 0.03681888134451583, 0.06869927456136793, 0.024383109775953926, 0.034560986096039414, 0.04167918421444483, 0.018933398787339684, 0.03720714332303032, 0.017257469771720935, 0.045324138627620414, 0.00824687671411084, 0.03207710316928569, 0.03693142061820254, 0.07356287256698124, 0.013029575056862086, 0.07309352353331633, 0.049086890430771746, 0.02059711576293921, 0.06871153484098613, 0.05802441904961597, 0.06564202689332888, 0.022083676522015594, 0.061021359797450714, 0.028796726946893614, 0.0288690789238899, 0.04389779387565795, 0.05260694138996769, 0.07711263911915012, 0.03784912703849841, 0.05446892311738338, 0.023761073134664912, 0.025899695974658243, 0.07974924490554258, 0.025817017012741417, 0.034147435435443185, 0.035663598609971814, 0.09268215522752143, 0.039401848407578655, 0.02166359125112649, 0.04354164091637358, 0.024555026429879945, 0.011407148394937394, 0.014399671508726897, 0.008773778372415109, 0.0881032895995304, 0.05149186079506762, 0.014838177812634967, 0.04652299656299874, 0.047231294884113595, 0.042871244077105075, 0.08963774671428837, 0.03712423800607212, 0.045114307504263707, 0.0075092663428222295, 0.03401149624551181, 0.056259818229591474, 0.06229909689864144, 0.04965852225723211, 0.02691189820325235, 0.04504777767579071, 0.012479714132496156, 0.008060168129304657, 0.007069304037941038, 0.034481275724829175, 0.024708504424779676, 0.05389659738284536, 0.10532889340538532, 0.032006610272219405, 0.016676132509019226, 0.058340844843769446, 0.015068203701957827, 0.051473236599122174, 0.040426001069135964, 0.023325948241108563, 0.02479400354786776, 0.06660350889433175, 0.011233233508392004, 0.040378229023190215, 0.02106522169924574, 0.056893018627306446, 0.00976806793914875, 0.07835182535927743, 0.026149317345698364, 0.04872809542575851, 0.020152996039541904, 0.0849781502620317, 0.010899813460127916, 0.023156877723522484, 0.03013486559211742, 0.01853838883107528, 0.042740433127619326, 0.020446292801352683, 0.048314043815480545, 0.08680703220306896, 0.023194161367428023, 0.018528061846154742, 0.05739271036873106, 0.02238412944279844, 0.11708034173352644, 0.005939133261563256, 0.06635514175286517, 0.04054867436934728, 0.03446121176239103, 0.07086023790179752, 0.009118192410824122, 0.020386726173455827, 0.06735298899002373, 0.019493913241603877, 0.016418868872278836, 0.03586844621167984, 0.0764624509611167, 0.0014271220356931735, 0.017928399101947434, 0.0461508577427594, 0.028906023035233375, 0.06470295775216073, 0.0366173993825214, 0.028160051442682743, 0.05840004225319717, 0.08634831814561039, 0.05089601268991828, 0.05389831174397841, 0.015923589198791888, 0.04466911908821203, 0.011790609605668578, 0.09070068772416562, 0.04298497820855118, 0.025997800476034172, 0.039144423353718594, 0.026280749843863305, 0.048362758388975635, 0.06250638616620563, 0.06070953531889245, 0.037261186516843736, 0.03803325758781284, 0.030229431904444937, 0.039060423368937336, 0.10142187180463225, 0.03512740062433295, 0.03915268345735967, 0.026950580795528367, 0.0587911726324819, 0.023665228472964372, 0.03523108236549888, 0.023531769911642186, 0.04148534637351986, 0.06878831001813523, 0.08274961437564343, 0.08749171538511291, 0.031822116070543416, 0.02314224071596982, 0.022831369897176046, 0.05253374336462002, 0.11037278134608641, 0.046919121596147306, 0.03471937896392774, 0.008496561167703476, 0.0282449587029987, 0.015321150822273921, 0.04251132100762334, 0.031220913369907066, 0.03710413693625014, 0.014146340326988138, 0.03666595439426601, 0.06392694587702863, 0.031208044529194012, 0.03720847918884829, 0.04748196639411617, 0.0137572916719364, 0.015982007353159133, 0.04118699558603112, 0.029816174392180983, 0.022732376673957333, 0.04112928989343345, 0.005276318852338591, 0.053622611303580925, 0.0250614587275777, 0.01851795008406043, 0.04302043802454136, 0.07083211050485261, 0.029950722055218648, 0.03504964210151229, 0.0497393050318351, 0.009700771843199618, 0.04337896956712939, 0.08603663838584907, 0.010083258057420608, 0.05563785023696255, 0.10129299043910578, 0.019342179293744266, 0.038566412767977454, 0.07065155339660123, 0.0993658036168199, 0.019355339427420404, 0.012395073117659194, 0.03205936212907545, 0.01691831199423177, 0.04917779238894582, 0.02739498067967361, 0.0169737021860783, 0.038810479163657874, 0.05204678687732667, 0.09036866569658741, 0.023867124182288535, 0.010401226591056911, 0.01485958970079082, 0.03421419904043432, 0.019507372089719865, 0.018309443694306538, 0.02659782130649546, 0.026463032445462886, 0.0026327176283302833, 0.05273118062177673, 0.0655764655675739, 0.019233974162489176, 0.05056894449808169, 0.049249179573962465, 0.03589615058444906, 0.07787349633872509, 0.022902378586877603, 0.055789508114685304, 0.04542865528492257, 0.02178237569751218, 0.037007835853728466, 0.08025714851100929, 0.10375147336162627, 0.04401672304084059, 0.008964775643107714, 0.08371049523702823, 0.017030072012858, 0.08508100450853817, 0.020797842589672655, 0.0544020370580256, 0.06886744522489607, 0.036890494884573855, 0.12063648333423771, 0.02135249407729134, 0.02336651217774488, 0.02453847097058315, 0.04257733133272268, 0.04423242455231957, 0.051581441730377264, 0.03218105950509198, 0.035226785330451094, 0.13147494901204482, 0.15225717681460083, 0.058839096818701364, 0.11255757504841313, 0.18592270236695185, 0.0998020677070599, 0.16275748290354386, 0.16118454543175176, 0.09517509606666863, 0.16090267774416134, 0.13002678140765056, 0.13681450858712196, 0.12416451980243437, 0.17963452963158488, 0.17508028104202822, 0.11077588627813384, 0.13920327415689826, 0.16850713844178244, 0.10569202626356855, 0.13194420898798853, 0.20382743066875264, 0.15619554673321545, 0.07591527290060185, 0.1856654294533655, 0.10147841603611596, 0.2334345513372682, 0.08691329290741123, 0.15756103908643126, 0.2643867552978918, 0.10411605340777896, 0.27554898289963603, 0.10927274779533036, 0.12070705415681005, 0.09096078079892322, 0.14858513401122764, 0.12931285018566996, 0.1194630513782613, 0.11982545693172142, 0.17207404860528186, 0.10408178102807142, 0.09344214413431473, 0.17777783941710368, 0.20377800363348797, 0.07735231571132317, 0.08522570846253075, 0.15481549344258383, 0.09726953328936361, 0.12140758961322717, 0.10251574552967213, 0.18656961765373126, 0.24265125364763662, 0.1122809543448966, 0.08942504719016142, 0.1828667163499631, 0.13056900934316218, 0.1593220219365321, 0.1793037840980105, 0.14194185845553875, 0.12859207636211067, 0.11097465569037013, 0.2288335474440828, 0.11887516651768237, 0.206578349461779, 0.14646245806943625, 0.08989666719571687, 0.1109556492883712, 0.12063280228176154, 0.1270927450968884, 0.09382276941323653, 0.2067421266110614, 0.13051603484200314, 0.12910818069940433, 0.15912999864667654, 0.25880622037220746, 0.19873960758559406, 0.11941041084355675, 0.1165947322442662, 0.14866886311210692, 0.19606213172664866, 0.1409421261632815, 0.1534969493513927, 0.14610385231208056, 0.13727802434004843, 0.10753130569355562, 0.09693033469375223, 0.17212665203260258, 0.15436248650075868, 0.10558071153354831, 0.1264840058865957, 0.09980455390177667, 0.08346703369170427, 0.18107462266925722, 0.14274340763222426, 0.14632572478149086, 0.1199598895618692, 0.12192477006465197, 0.23759918723953888, 0.1430919795529917, 0.1628542589605786, 0.12167543813120574, 0.18799314595526084, 0.12114446857594885, 0.10567193632596172, 0.1266819515149109, 0.09862315127975307, 0.14971658267313614, 0.14744981133844703, 0.1116410746180918, 0.13462723611155525, 0.19990215223515406, 0.09520770603558049, 0.2212062879698351, 0.11067137704230845, 0.20359895308502018, 0.13008023088332266, 0.13509756478015333, 0.28484794485848397, 0.18875555426348, 0.12380258180201054, 0.14386572787771001, 0.1444007272948511, 0.19375998963369057, 0.12066505601978861, 0.19912236282834783, 0.17211155674885958, 0.17485820077126846, 0.19412111869314685, 0.06259096873691306, 0.19557583204004914, 0.16447617817902938, 0.15599436534103006, 0.14339406334329396, 0.08508579136105254, 0.14926057745469734, 0.17131943284766749, 0.0877351472445298, 0.09887047199299559, 0.14469010551692918, 0.08150478781317361, 0.06056443802663125, 0.1620821433607489, 0.16989296564133838, 0.14085191069170833, 0.13676295900950208, 0.15200106165139005, 0.09976340923458338, 0.146095480886288, 0.114051199198002, 0.17620096856262535, 0.10063739944598638, 0.08577174361562356, 0.10322363566956483, 0.22818504396127537, 0.16561761614866555, 0.11128724829177372, 0.0850553707277868, 0.19387554202694446, 0.19946778804296628, 0.25407731474842876, 0.1407735695829615, 0.14441239385632798, 0.17450210347305983, 0.20685981638962403, 0.16430238203611225, 0.2124422660563141, 0.19628394482424483, 0.09240881481673568, 0.1173187789390795, 0.0938399946608115, 0.06080040016968269, 0.1444864898803644, 0.13872730516595766, 0.0999584975943435, 0.11192926540388726, 0.2261539935716428, 0.12448871217202395], [0.034726971134659834, 0.01690690147370333, 0.013789211443508975, 0.02993317953951191, 0.036830444005317986, 0.03432861965848133, 0.057027547736652195, 0.021420311531983316, 0.056190483082900755, 0.05043327619205229, 0.0822945665277075, 0.039800700833438896, 0.008706318076292519, 0.045504365480155684, 0.0748660987301264, 0.06333031109534204, 0.05229510206845589, 0.031072424462763593, 0.014933618003851734, 0.026402532566862646, 0.03950941529183183, 0.037759393962915055, 0.05051690881373361, 0.040657410136191174, 0.05140708526596427, 0.06350323892547749, 0.02048483438557014, 0.05918701193877496, 0.019654916613944806, 0.023517066110798623, 0.003135986521556333, 0.031545640085823834, 0.007004949629845214, 0.006900058187966351, 0.05046746322477702, 0.07752509511192329, 0.044528893995448016, 0.07345285659539513, 0.05164427937415894, 0.03696424209920224, 0.041645828387117945, 0.013664675352629274, 0.04024510257295333, 0.011296020129520912, 0.07236171397380531, 0.04289996148145292, 0.09783049303223379, 0.01847273473686073, 0.03870799599098973, 0.054293334687827155, 0.07107862227712758, 0.05473207012983039, 0.037397908672573976, 0.068298982369015, 0.05573100832407363, 0.06015805651259143, 0.03010021842783317, 0.022496945166494697, 0.03622896671004128, 0.02378645644057542, 0.033839069365058094, 0.024623812387289945, 0.0512429259106284, 0.026693500840337947, 0.03384931100299582, 0.05833304487168789, 0.030084390273259487, 0.00994576963421423, 0.059396371798356995, 0.020294124697102234, 0.0493531247775536, 0.02368161323829554, 0.041052737360587344, 0.07260577665874735, 0.029716808239754755, 0.01335300115897553, 0.08881316127371974, 0.02251100700959796, 0.0382584363251226, 0.042300280183553696, 0.05261315316602122, 0.029767519190500025, 0.04287190458853729, 0.01823072223487543, 0.0348688215308357, 0.04778931943292264, 0.009664627395977732, 0.028489258875197265, 0.03722820176335517, 0.05304562859237194, 0.06402899118256755, 0.058010629945783876, 0.018720766056503635, 0.01425036438376992, 0.02185572771850275, 0.013093523139104946, 0.04441213190148119, 0.03247283857490402, 0.02832080990629038, 0.01988037180126412, 0.08547826131689362, 0.042589743752614595, 0.08040643893764354, 0.04177094706392381, 0.03643717624072451, 0.051350574431126006, 0.028404822878655978, 0.02264048765937332, 0.018802381891873665, 0.08945153444074094, 0.06533971303724684, 0.024643008036946412, 0.03628906582889613, 0.04663711290049832, 0.05133485574333463, 0.049819375344668515, 0.05634014087263495, 0.04329439812863711, 0.0384555433265632, 0.03272845278843306, 0.05817275581648573, 0.012536007889139, 0.04159024894761387, 0.04311247917939909, 0.006241809378479957, 0.06872925732750446, 0.00476646154311311, 0.030026042622921523, 0.03751201758859679, 0.02441982382151764, 0.01452247190172784, 0.04839989174797665, 0.029149582915124483, 0.0905280864390079, 0.041183388748322614, 0.09735823477967642, 0.07535999800893478, 0.021269221397233196, 0.055436101101804525, 0.02005394529987825, 0.017425610749342013, 0.05814430558530148, 0.05757775004894938, 0.054406337803811766, 0.03829402230621781, 0.06732855006703176, 0.02207338849984808, 0.02344630418519955, 0.010866567099583335, 0.103643750626361, 0.1032347975706216, 0.02178571536205709, 0.05283639860863332, 0.04452236680663191, 0.06100814585806802, 0.020766709494637325, 0.01638778772758087, 0.02081159644149011, 0.06843863971880637, 0.030846702102280688, 0.06381046579917893, 0.04616150014044251, 0.03842305581201799, 0.09751985970069654, 0.055181570423883386, 0.0316598046629224, 0.05743872723542154, 0.011687037331284955, 0.03550133915268816, 0.025494303372397553, 0.025911911725415848, 0.07591777393827215, 0.06218003043613862, 0.02033985027082963, 0.004203497073831386, 0.03254267096053809, 0.029434793977998197, 0.07440903224050999, 0.0030402246557059698, 0.03260854398831725, 0.04254374172887765, 0.056907661200966686, 0.010041677378467284, 0.03360961956786923, 0.10215841626632027, 0.07364032309851609, 0.027205653241253458, 0.03245736108510755, 0.020577907125698403, 0.034423210090608336, 0.020806829998036847, 0.011836990124720614, 0.05062867254309822, 0.07329743602895178, 0.026380726412753575, 0.04919642771710642, 0.04528476398263592, 0.028250044269952923, 0.06500011368189007, 0.02270773551572347, 0.01628538990189554, 0.06201921445608605, 0.04441410972503945, 0.07868229629821144, 0.043749817050411366, 0.025178513969876803, 0.03017668190295808, 0.028993297746637836, 0.022896168666193262, 0.028243793531146366, 0.05520443228306249, 0.03152384320856072, 0.010170543901040219, 0.07818969577783719, 0.10054953658254817, 0.016399517371610273, 0.023329623727477156, 0.04195431691186968, 0.01645014668611111, 0.031980768690118566, 0.0639689588570036, 0.012485789538914105, 0.09927020757459104, 0.010254262797388947, 0.0388075736555038, 0.05953179148491472, 0.023882252862676978, 0.042070028866874054, 0.038691639056196436, 0.020904444681946188, 0.06456965318648145, 0.09346244929474778, 0.03710221477376763, 0.0588422101282049, 0.0034979326392203802, 0.028433035622583702, 0.023189164858195, 0.046977153833722696, 0.06266502023208886, 0.018503103419789113, 0.0464081195241306, 0.07887682062573731, 0.028249303977645468, 0.008816419394861441, 0.03747059090528637, 0.04651685158023611, 0.029746917170996312, 0.0328607925621327, 0.060535984084708616, 0.03552512869646307, 0.025067418173421174, 0.06477054514107294, 0.05975878477329388, 0.03462093307462055, 0.0707681967469398, 0.026363078141002916, 0.06614162586629391, 0.020338160029496066, 0.03549057801137678, 0.04603990295436233, 0.02555298869992839, 0.029491536733985413, 0.023303685666178353, 0.0686496174603235, 0.04488040111027658, 0.03619575931224972, 0.054006498321541585, 0.029102220905770082, 0.02919755905168131, 0.02289805001055356, 0.04554822269710712, 0.041524943662807345, 0.03928481171897147, 0.018835949231288396, 0.030495176433760207, 0.08018959080800414, 0.1047978644783143, 0.016885254881344736, 0.04468254825042095, 0.059829363017342985, 0.01181489453301765, 0.04573805665131658, 0.030715668508491945, 0.026156258281844202, 0.025587066265870817, 0.0828836981963832, 0.03654732208815403, 0.051182144015911035, 0.031714497235952877, 0.02301782151334919, 0.041031025830307044, 0.0458998819522094, 0.09089484097785316, 0.01853352034231648, 0.0704259033955168, 0.049528442323207855, 0.08159134449670091, 0.045981150833540596, 0.04100652382476255, 0.043681958777597174, 0.015471437582164072, 0.08743775382754393, 0.0528667672915617, 0.028265748114790767, 0.025988243469328154, 0.05625770310871303, 0.016295928398903925, 0.04611709373421036, 0.06793698499677703, 0.09994472333346494, 0.041989654273493215, 0.08225753335864283, 0.08871325335348956, 0.03841693680442404, 0.04831675636523869, 0.06775199726689607, 0.06424274455639534, 0.018784306885208935, 0.017541472989250906, 0.06735091097652912, 0.04446479841135442, 0.07107834026101045, 0.05835877142089885, 0.01245396068043192, 0.046309528916026466, 0.04607817922078539, 0.06936833553481847, 0.010129535603482509, 0.029040772933512926, 0.03725523449247703, 0.014378673367900774, 0.03600512754928786, 0.060905087520950474, 0.09075551759451628, 0.019085559470113367, 0.0316267605376197, 0.02208792902820278, 0.07026202234555967, 0.046634418904432096, 0.11439682479249313, 0.027983633663097862, 0.03842702259134967, 0.04545955831417814, 0.011431477851147065, 0.11717693225364201, 0.018799019962898456, 0.013575806879089214, 0.03279965072579216, 0.05511205716175027, 0.031806256374693476, 0.02423023292067228, 0.008793474044068716, 0.10081037922645919, 0.1853882521390915, 0.0858844981121365, 0.11474663609988056, 0.15149635670240968, 0.16164757136721164, 0.14532802597386762, 0.1737399326520972, 0.2112357268924825, 0.2210051511065103, 0.24987859942484647, 0.22316619608318433, 0.04218728448904585, 0.17083795712096617, 0.11399092196370475, 0.11777583058574237, 0.12103555840440094, 0.17304785025771707, 0.12760331301251426, 0.0993100089544896, 0.13611300091724843, 0.10118977996171452, 0.2507053519366309, 0.09481748478719965, 0.08643052584375255, 0.14291347819380462, 0.14416292833629996, 0.16534075053641573, 0.24866918072802946, 0.1485063772997819, 0.10958874685456976, 0.14829468709649518, 0.16891854058485478, 0.0668013357790187, 0.13858991878805682, 0.13951162167359143, 0.1090173154079821, 0.17246122704818845, 0.20313328510383144, 0.2605075790779665, 0.082996393321082, 0.09177429339615628, 0.12699874467216432, 0.12893935694592074, 0.21578895131824538, 0.16716005135094747, 0.3639984398614615, 0.0751103469519876, 0.13862070307368413, 0.10980922408634797, 0.14677163679152727, 0.10554441309068352, 0.16691817058017477, 0.0926513560989406, 0.2704172395169735, 0.20068124402314425, 0.17260101798456162, 0.1973090140381828, 0.1337722226162441, 0.17095094168325886, 0.1344829922891222, 0.08638222687295638, 0.13735718181123957, 0.17072179616661742, 0.10734965762821957, 0.16121378605021164, 0.1498092175461352, 0.03953909377742093, 0.17596567806322128, 0.0627279988839291, 0.13178657682146877, 0.1119774159451481, 0.12841363437473774, 0.17709460342302918, 0.20369304256746545, 0.1778265243046917, 0.21492694679182023, 0.17619854916119948, 0.18469903443474323, 0.12793379137292504, 0.2074844969320111, 0.13145881472155452, 0.13754907151451334, 0.09507386712357402, 0.11193393351277336, 0.12037611566483974, 0.14320647809654474, 0.1693787463591434, 0.17759967944584787, 0.14145088323857635, 0.2214962599100545, 0.19619729166151956, 0.09895268711261451, 0.11838563106721267, 0.21437023213366047, 0.09481510991463438, 0.13392596592893824, 0.23111421178327873, 0.1186163722013589, 0.10663921450031921, 0.14859108603559434, 0.18119519198080525, 0.08991700946353376, 0.17341862723696977, 0.0938945276720915, 0.227306044253055, 0.17002472653985023, 0.12048591641359963, 0.12413086340529844, 0.173171536589507, 0.17132342560216784, 0.09459553810302168, 0.14162925101118162, 0.12454559036996216, 0.13415577937848866, 0.1944334144354798, 0.14356306521221995, 0.1238598904456012, 0.12290798957110383, 0.14845795958535746, 0.13475907122483477, 0.11768660217057914, 0.12089669515262358, 0.2593096042983234, 0.13781654153717682, 0.20819850236875936, 0.10885445110034198, 0.14030684775207192, 0.1202959414513316, 0.10399474937003106, 0.09322542959125713, 0.12554659915622324, 0.13610327878268436, 0.2225902449572459, 0.12483545840950683, 0.1810704221134074, 0.15195869986200705, 0.0960882642539218, 0.14548623701557517, 0.1581447827629745, 0.11259624836384319, 0.21637879544869065, 0.16823901532916352, 0.1742923428537324, 0.1892330075497739, 0.16680824366630986, 0.09307962725870311, 0.05521660721569788, 0.08805126504739746, 0.21395979478256777, 0.21561435365583748, 0.1129552251950372, 0.1359599403804168, 0.09654279259848408, 0.11558083977433853, 0.09499294334091246, 0.13946453982498497, 0.2151800785213709, 0.10257337329676375, 0.1628181163687259, 0.11429518766817637, 0.18057402921840549, 0.08505450241500512, 0.14375501428730786, 0.11014443734893575, 0.11242906475672498, 0.1231172752159182, 0.06755206268280745, 0.19191162631614134, 0.17318508820608258, 0.12593972962349653, 0.1179108049836941, 0.1658843143377453, 0.10615458464599214, 0.07912754037533887, 0.12499035947257653], [0.05826854852784891, 0.06281662615947425, 0.031326613752753474, 0.1107018422044348, 0.07676753302803263, 0.015524232112511527, 0.05053985973063391, 0.10077865983475931, 0.04918044556688983, 0.05867501538887154, 0.048168668217840604, 0.026319948228774592, 0.024945078839664347, 0.08148297609295696, 0.04023365494504105, 0.06528050449560396, 0.04055685283674393, 0.03027598126209341, 0.06523744508740492, 0.03455067395407241, 0.06084069507778622, 0.02997677329403814, 0.029817167014698498, 0.04870217962889001, 0.03476336976746097, 0.057507531746523455, 0.010866348166018724, 0.07705561991315335, 0.02019592371652834, 0.03312318629468791, 0.028146418189862743, 0.08214956571464427, 0.08845966149237938, 0.05486940084665548, 0.01584443172760075, 0.030494966777041554, 0.04556725878501311, 0.03945820339140482, 0.03653410814877134, 0.04497419002291281, 0.02541836496675387, 0.056169172312365845, 0.040431648812955245, 0.05232730385614559, 0.054944387447903864, 0.03448072282481007, 0.060738542160834186, 0.035664530005306005, 0.0231380624245503, 0.03335342276841402, 0.043200620348216034, 0.013023598912695888, 0.036576666607288644, 0.017023433501890395, 0.016498900222359225, 0.07695945241721347, 0.06278863234911114, 0.05773815413704142, 0.026716898901213426, 0.08668282636790536, 0.01535142766442732, 0.044428180844988674, 0.05740560889535118, 0.06081739906221628, 0.04654647069401108, 0.03874165238812566, 0.03952285187551752, 0.08034615428186953, 0.032324052808689885, 0.030177349835867062, 0.07375323344604112, 0.011888279950653668, 0.01052121517204796, 0.07553736388217658, 0.049204342722077854, 0.009582931779732462, 0.06626218775636517, 0.017766686978575308, 0.013235390233603539, 0.011639863641903503, 0.03187117203196976, 0.047821113039390184, 0.06526324956212193, 0.0212347170963767, 0.020228991961630527, 0.008651840726088267, 0.03858914475131314, 0.03454193887591828, 0.05443789763376117, 0.035078656364930794, 0.018594472930999473, 0.016514346170879435, 0.01947715183632681, 0.13853246171493083, 0.0480646487994818, 0.024871519017324317, 0.025234629611077253, 0.015613325085723773, 0.0970345396490302, 0.0764647516189143, 0.021556978026637807, 0.02940606173069682, 0.03952331200707704, 0.025442618352826685, 0.023869384021963924, 0.013581714374595322, 0.029935263119114097, 0.042958379635820165, 0.057653330368339084, 0.015063664541230537, 0.051220208770246245, 0.03956394088163506, 0.04362154795671813, 0.023495412096963264, 0.02115722203598125, 0.02960136902402155, 0.004064203376401565, 0.017669840417511296, 0.02578901021479396, 0.070145891077118, 0.09791192147531547, 0.028092187603760976, 0.02353207419218961, 0.09941667784005404, 0.044993775300099514, 0.040583770532975905, 0.014736662215000251, 0.04509733087616041, 0.06916481637745164, 0.07959417314850725, 0.023736402290523984, 0.011003217823599698, 0.028191110322950408, 0.053733926033601165, 0.030902506041456945, 0.04759798634040635, 0.06733837610227056, 0.049244979018112645, 0.06868895128718577, 0.03582306388125289, 0.03295505644928198, 0.05736353654356208, 0.018532954454713035, 0.0442926387040643, 0.06025710725225508, 0.024349878258362878, 0.05101364309666678, 0.02165789897844661, 0.04301376611692831, 0.018703049136092886, 0.06771763582946733, 0.018824173203029204, 0.03414468577830121, 0.021710465298383497, 0.01815148127207067, 0.009017698193929391, 0.027820283248729538, 0.06464013495133258, 0.025071318159461953, 0.03215475779143162, 0.020003789104521275, 0.060041364922653884, 0.030750460391573142, 0.0455985106236767, 0.03981388137617614, 0.021932578965788707, 0.1158283682889305, 0.04054677818203345, 0.047703775780973956, 0.03946509794332087, 0.018622327588673215, 0.037281773693393916, 0.06218221977178473, 0.04207807003695052, 0.033655090956017375, 0.0745375276892446, 0.007065578456604271, 0.04429775581229478, 0.03327814301883336, 0.03206428998964839, 0.054742026040912606, 0.07130887359380722, 0.02470102543156827, 0.02549309367168462, 0.023120646073948592, 0.02235783886135323, 0.06489805353339761, 0.011389795126888203, 0.05171561089809984, 0.025492056520306505, 0.02359640726353973, 0.02790495302178897, 0.00884683538970421, 0.010278317658958258, 0.03518828270898666, 0.10728991474024951, 0.03620817544288002, 0.08242164447437972, 0.031172699746093713, 0.025654026539996266, 0.046310412071761675, 0.04518922360148281, 0.02437961426039692, 0.02305560054082889, 0.05462215434818063, 0.033863445205497555, 0.010663923676474951, 0.0313528560945997, 0.04832506841921713, 0.0140205286697892, 0.03239029319956899, 0.024468811134283897, 0.08706897322554141, 0.05119500172440894, 0.01811260201066034, 0.070030628121458, 0.05172821998712607, 0.004229953710819245, 0.03870972148433793, 0.018069973048113752, 0.15390912332804874, 0.04061709296365734, 0.026972615160048008, 0.024759206098678987, 0.024650939740240574, 0.0660762500774581, 0.03429351607337594, 0.01633342355489731, 0.03515995864290744, 0.016695022022759076, 0.02489877624611836, 0.07809058195562102, 0.030800508975517005, 0.05486630238010548, 0.02858311458112439, 0.04876928091107402, 0.01623771804588614, 0.07819079415639862, 0.04623381872079335, 0.04647285706596449, 0.05155766702955589, 0.029335995568544604, 0.04519040732702706, 0.02382238752034027, 0.011308486355119385, 0.036275785096222535, 0.06457628798671067, 0.028612221613002475, 0.042003246708191, 0.051718690810957924, 0.01708173476799857, 0.0076628222632280085, 0.04125628991459962, 0.027995185191684868, 0.014652005429525161, 0.048087707327795215, 0.022160373773658648, 0.06002552378049586, 0.0749205872125458, 0.04411162888573017, 0.05064463613962289, 0.0347771959786769, 0.0789477996295318, 0.040641665473231114, 0.04167985956883058, 0.08175573020707816, 0.03768389899050817, 0.014760134490643395, 0.008159063017956214, 0.011211557230126346, 0.015575111901853234, 0.021066498193249572, 0.01459990480725537, 0.025490195585007314, 0.07743704671156593, 0.017229667064384557, 0.028795398502552416, 0.07389202248305082, 0.08752546083997004, 0.029233996647235472, 0.03417475018068217, 0.04019303720269818, 0.02132904777681688, 0.034990741551155224, 0.009859706478891894, 0.030293536765384488, 0.10531278137932532, 0.019209470301575493, 0.034684442362049595, 0.05447498646390159, 0.01934733536472777, 0.023480945783376228, 0.008445912371826125, 0.044617131643462926, 0.03759825514862314, 0.06251968545257114, 0.06398523415555246, 0.041062607924686745, 0.03629472470493056, 0.05574619266553782, 0.006542092069139471, 0.008172584020940121, 0.08079579929471947, 0.014329323330457555, 0.04073374002473429, 0.09042734731337987, 0.035570633481256664, 0.012307941269682487, 0.07955233086249791, 0.012147853522037622, 0.06454557049437426, 0.04415448049257975, 0.05237540615780745, 0.023688639521424193, 0.05427101088571362, 0.03589163090509828, 0.07152885358664207, 0.04454714711755514, 0.06886575312819332, 0.06308793308562599, 0.0663685004110448, 0.026960558971040882, 0.05180393760383595, 0.04311475386202801, 0.049055159906856716, 0.02498329758964246, 0.048242055490845814, 0.04277783365978394, 0.04776627945830114, 0.035086311618215404, 0.035550966567825526, 0.061021166839054786, 0.027609422395471483, 0.0434901358676143, 0.035178415855625644, 0.02673651571967639, 0.038953309194766916, 0.0894868012983352, 0.03946441145671997, 0.012711015588138252, 0.028406609599187505, 0.03447876726568211, 0.06921295207575895, 0.04116566997254267, 0.04255449915945064, 0.025906798327923752, 0.018892595508077648, 0.01433682922652224, 0.0609028907638276, 0.016440491344837938, 0.05559657569392584, 0.04012716046418063, 0.12879549904027954, 0.12880866474006325, 0.15046002168674022, 0.294997853343375, 0.24649918545037508, 0.1268801643163897, 0.11252615993726067, 0.2380828745663166, 0.0835874248878099, 0.1441763760522008, 0.12286623634281568, 0.10407449313788675, 0.14630118937930092, 0.17811259254813194, 0.14080476947128773, 0.12579872156493366, 0.17097402247600257, 0.13177244632970542, 0.11355554845067672, 0.13802618341287598, 0.08397882615099661, 0.1259331393521279, 0.10161572819924913, 0.11736741187633015, 0.09766075643710792, 0.07830511458450928, 0.10782357087009586, 0.2673655579565093, 0.1453148602740839, 0.1012114952027332, 0.10847029319847934, 0.13048094609985128, 0.25853480212390423, 0.15126005688216537, 0.13301812636200339, 0.14300974959041923, 0.30659860116429627, 0.13499011663952842, 0.09253541778889485, 0.159013704105746, 0.14278879738412797, 0.16355573694454506, 0.08951070587499999, 0.2919703657971695, 0.30638937489129603, 0.07878497242927551, 0.15331208036514, 0.09783810004591942, 0.149840684607625, 0.12580160109791905, 0.0965371448546648, 0.144483165058773, 0.1520886944490485, 0.13064089376712218, 0.11894790441147052, 0.17857428261777386, 0.16309422499034554, 0.2062833309173584, 0.08979079240816645, 0.1323418368701823, 0.09584542611264624, 0.13521577406208962, 0.3854076488642022, 0.10697647609049454, 0.16439075698144734, 0.13072664150968194, 0.1147761735774111, 0.23215197172248736, 0.1170866574102547, 0.10548161255428568, 0.1370159423095174, 0.07717488304479048, 0.17581851017894223, 0.11946653947234154, 0.22889094514539465, 0.10612395621137694, 0.17443591874325648, 0.10174955226830207, 0.12035123145324178, 0.11880746780661866, 0.13289098162204027, 0.13173499755794182, 0.16376741230487823, 0.18385314935585484, 0.15220392029732466, 0.12958547071320936, 0.17471686616772786, 0.11150333943078294, 0.13097744289552793, 0.11633913658442907, 0.14710861636558548, 0.16584639059146866, 0.12584586278535426, 0.2341546572279185, 0.14129470568150282, 0.0960562851105351, 0.11083750679972582, 0.12348545467830263, 0.22338272508932278, 0.17550557618960738, 0.06035188693203963, 0.20217221870552748, 0.23039184976369143, 0.15284461638657376, 0.11411489773308858, 0.07478163490304723, 0.14644795650383458, 0.13377324678003788, 0.19676761730806902, 0.14769748086109757, 0.34183298237621784, 0.1489352050703019, 0.0761366258666385, 0.1963129627984017, 0.17723678407492116, 0.1320297786151059, 0.1647159512504004, 0.17660368757788092, 0.16337820037733763, 0.19701515324413776, 0.20110489160288125, 0.20943604846252128, 0.11793152574682608, 0.21710813365643844, 0.09110797094763257, 0.1774778781691566, 0.14267808379372582, 0.19668543187435716, 0.18261402990901843, 0.14567659789463505, 0.1275968414847739, 0.0688083480054047, 0.11794167090556584, 0.16439730272395536, 0.1803611367358826, 0.14351466234074906, 0.12369461415801197, 0.13303063897183165, 0.19179666764102876, 0.1470230022096075, 0.20815382507862523, 0.16518397926120088, 0.14273957815021276, 0.16097033192636445, 0.18704165326198563, 0.11299665929982439, 0.16017121699405834, 0.1367230314644985, 0.10656557118636556, 0.12974209355888888, 0.12107495160307735, 0.13210043107392266, 0.09292814749642275, 0.21391333633800969, 0.1347876142244786, 0.10356404396588914, 0.10857283574296162, 0.2442091255215928, 0.3142427222337574, 0.12725675973342732, 0.1104960817610845, 0.21500254195416346, 0.16410391690442339, 0.1611645519733429, 0.13051220535999164, 0.09434999112272635, 0.2412758462014608, 0.13443800329696387, 0.11147639947012067, 0.1342984350048937, 0.07818107202183455, 0.20074235246283934, 0.0857012247433886, 0.10993391231750138, 0.0870733370538801, 0.19204222946427763], [0.07027777814073488, 0.012968169758096337, 0.005079666416349937, 0.039911336498335004, 0.08335173362866044, 0.020912508116452955, 0.033841963740997016, 0.04553107908577658, 0.10797747003380209, 0.06697882039588876, 0.04850197416089941, 0.006862965183245251, 0.011379688930901466, 0.04650626484362874, 0.05294381706335116, 0.08385338835068978, 0.01976882886083331, 0.033840241958387196, 0.008163202346622711, 0.04217004810925573, 0.03574817375920247, 0.07841121943783946, 0.06413814626284875, 0.07161833433201537, 0.05907847284106538, 0.02724862173636211, 0.023139975310186855, 0.022265246661845595, 0.02791127797536319, 0.022926028977963142, 0.012457853244995931, 0.07597314557642676, 0.021002434150432236, 0.055688327411189675, 0.06271328951697797, 0.036887396418023854, 0.05990052755805664, 0.08074122917605564, 0.019988283784186933, 0.005126362812006846, 0.016177724683075212, 0.012496206509240437, 0.00478280595416436, 0.019892615382559597, 0.061431893627741374, 0.019381468591745943, 0.08451548797893338, 0.04044804285513237, 0.03850528577459045, 0.02220556685642805, 0.07048318977467716, 0.02276620376505889, 0.04706468644144479, 0.06513214917504229, 0.05066678182629403, 0.004010656957689207, 0.01450177433071076, 0.06154422138934024, 0.02895979163440643, 0.06711741647450253, 0.04081541337654926, 0.02910217081080191, 0.11298085155431181, 0.048104862071340904, 0.04975812218617648, 0.03440808883169666, 0.038302438260870986, 0.016601262796029914, 0.06498999820905738, 0.051346325635677204, 0.04975308671419043, 0.019452492124401033, 0.010025704505096655, 0.020440606094780378, 0.02336648991331458, 0.02353417447011452, 0.11079631018219516, 0.04265841096639633, 0.04889041054411791, 0.08573941566282883, 0.050335783962509595, 0.01761433890351327, 0.06268036042456515, 0.024413276223640423, 0.07132771672331728, 0.038379269099095836, 0.08095518292975612, 0.060598168638534844, 0.05175412094104104, 0.04632696938642766, 0.03744489775272086, 0.0535026171564823, 0.03679141816974152, 0.03694478298712056, 0.041410563862882555, 0.03292394190793857, 0.001825483948323381, 0.04422691410582047, 0.043931030959356576, 0.04462028206035029, 0.03298246025224216, 0.05131816855282523, 0.038797261513536796, 0.05350357081624679, 0.03400135479751043, 0.06637627811869606, 0.02299734936968889, 0.044714215691783465, 0.028546396824822295, 0.04359994774858933, 0.06301866844296455, 0.029338760068640113, 0.0542296287312638, 0.09689306403743103, 0.03503159307001624, 0.029636396538990084, 0.08014499515411444, 0.02919726219261065, 0.04895733742159791, 0.054587273407378234, 0.05662101408233866, 0.03944332704122644, 0.02143336405424634, 0.018707411109062377, 0.05615424030111171, 0.03602693555876613, 0.02851446406566538, 0.041127308359136805, 0.0068348141303431476, 0.05303984726197086, 0.03630089937360026, 0.058794582801056094, 0.017690906279312912, 0.02234345047327224, 0.00530686333149788, 0.03141855100693647, 0.046240293959272094, 0.05661479117406998, 0.030570971975976136, 0.03776372439460829, 0.031895707434159704, 0.04744385711092036, 0.039051550993463024, 0.01055542446920299, 0.03768788432353176, 0.04003108202596195, 0.04299895284930244, 0.03067679666855838, 0.02125920796970604, 0.014775837407796644, 0.03781743362196721, 0.02673971808690112, 0.022125361101643648, 0.06237239882466383, 0.04498285830777604, 0.006126621565272217, 0.020319272371125408, 0.032524532871320844, 0.03915425309969578, 0.007317942527151899, 0.022558383861905895, 0.07051914682961069, 0.0729880495055113, 0.0280817140446743, 0.04737825867778156, 0.030774262922932394, 0.043052765977336094, 0.034035352582577616, 0.010309849658369785, 0.026383390722912736, 0.05029833148000762, 0.015831379205337726, 0.039655028376728296, 0.05105534066387918, 0.01962685229955241, 0.054108402619021945, 0.027541473209566902, 0.02495837255992228, 0.05518131438293494, 0.04751341119117569, 0.03961002825235482, 0.025269232246500906, 0.03534325798682403, 0.02019101255427813, 0.04377710953122005, 0.012681649732257938, 0.021314915429684334, 0.023108324567147065, 0.027447880966064986, 0.05410543402831536, 0.019141584198223427, 0.052508476946968585, 0.003687307621476066, 0.013106067290209467, 0.0558937501773471, 0.008400916885875631, 0.017098852404160425, 0.014076921688683797, 0.030089815372775774, 0.060394304382498376, 0.035552974077290855, 0.04591020151565317, 0.029435595497488976, 0.026331256703997497, 0.012048722073814133, 0.022948102305235807, 0.06166709878016263, 0.006715848785461276, 0.007374662554866518, 0.05326639526174404, 0.05224746360909194, 0.0452107161981985, 0.04209036000247579, 0.03082798884861404, 0.025143770326394588, 0.07733193633612245, 0.03168822520819958, 0.040483703050995246, 0.08642228800454177, 0.047964321565814316, 0.03484208195004612, 0.03954784740926698, 0.045582242746604607, 0.03635588138422463, 0.02928647205408197, 0.015383510708488757, 0.047253856173483655, 0.012389849325700197, 0.11112098494777456, 0.025570106336090248, 0.014744233048986644, 0.036903612344758585, 0.02728425410168711, 0.007039433521640603, 0.058658354173530824, 0.03778106467507314, 0.05630411331367213, 0.010602465499687241, 0.021157444680284243, 0.024865908380888868, 0.030132357132970355, 0.006956445640753373, 0.011738829034584342, 0.03062391493585892, 0.02931900595285697, 0.07096347064361908, 0.015024480999272782, 0.02001925175136421, 0.01850693290180061, 0.06329425756121054, 0.0017634388950682478, 0.016664093018334825, 0.05600392571068369, 0.0314414277090691, 0.07666211095056497, 0.04525748263404239, 0.06713183640385978, 0.03346725337905809, 0.011284183801762993, 0.03697636137076188, 0.021998650518071372, 0.029091324322507717, 0.16287674603518099, 0.06659027640125714, 0.031183991522993892, 0.005618856184810284, 0.0417424003535416, 0.01622546333237551, 0.03664191623101942, 0.04850599289056845, 0.054522940336028114, 0.07033298650640063, 0.011868421006511198, 0.0824779066897463, 0.024879755001165904, 0.03648203535703942, 0.08773551831836812, 0.03229440771974623, 0.018666275718715042, 0.01050672752171522, 0.046341489505721256, 0.029598341061500832, 0.030938186646380927, 0.03116377913102042, 0.05189306953980122, 0.1122911143465899, 0.04052828015119303, 0.053042077415739186, 0.02678464399650693, 0.05399502842919901, 0.05822486571560148, 0.006726339970555273, 0.0164957627930562, 0.043633003006107174, 0.07050989966955967, 0.06140313169453293, 0.027525917794264387, 0.03335616871481761, 0.024204168694268446, 0.05768978095147759, 0.022785870678490028, 0.038204433949431404, 0.03987179858086165, 0.0804020454233978, 0.03474445242318325, 0.057454171328572556, 0.01021677506287233, 0.010258557049382944, 0.015150996769079939, 0.08612438250565901, 0.057428029176662676, 0.046080643151071854, 0.037484676868189126, 0.03438884123170283, 0.06316863422398455, 0.06933775905054063, 0.05730840981414076, 0.034799842615029775, 0.02151747165044071, 0.030126731653581373, 0.011716800236172276, 0.040020792148425244, 0.0517481763381511, 0.04304786409193184, 0.046195609247661196, 0.0751359955756925, 0.014403293189388933, 0.06579032284207642, 0.04653400261304341, 0.04669741239922587, 0.0701422174461186, 0.014358829266711837, 0.002346870869587292, 0.04205517107038759, 0.06467934261308983, 0.018841340934159234, 0.06929999115527608, 0.06049688774510287, 0.07590097913634963, 0.03144371723465156, 0.045662261109100655, 0.02147005398001056, 0.035740982348215766, 0.013841770341969095, 0.022007246443536133, 0.054911120678298175, 0.09992376508307643, 0.027947797207161784, 0.015049339235702064, 0.0437478392268531, 0.06952527750399895, 0.04410549874592107, 0.16940801666351035, 0.06263326373300515, 0.10894390958128497, 0.1508539091446437, 0.22200555133167654, 0.1424146510544233, 0.0951822281058412, 0.09960972529370338, 0.22588613763218746, 0.1504755177302286, 0.13104606186971068, 0.15059887751704082, 0.17364070750772953, 0.3771491482621059, 0.10983076121192425, 0.16134588833665475, 0.06566652518813498, 0.1039350287464913, 0.06504793025669642, 0.10838475325726904, 0.2042392484145239, 0.18786327011184767, 0.12988241884158924, 0.1495906847412698, 0.21103313541971147, 0.17861559055745602, 0.13339917466510087, 0.1617247992544435, 0.09207308205077425, 0.176677412528079, 0.22444273461587727, 0.19163441931596026, 0.11834381104563363, 0.14844345801975578, 0.14147210866212845, 0.11267870097071864, 0.1412344432901591, 0.12140580845880322, 0.08624227266409434, 0.15989004692528397, 0.11232161661610007, 0.057206271740142256, 0.1813454323564656, 0.16101594432257116, 0.16270106483716518, 0.09465293580433354, 0.20601654367055744, 0.11826935879071243, 0.15935792704112828, 0.14019332884345204, 0.1628219013218768, 0.1262102127657272, 0.18072890059556812, 0.10511304717510939, 0.11678375725750811, 0.10122511361259967, 0.17039081314578652, 0.1614108114154078, 0.1882336611743085, 0.12480474833864719, 0.1546358788618818, 0.10235392022877932, 0.20196535246213898, 0.1366682312800549, 0.12492929556174204, 0.08894148602848873, 0.08617313418653794, 0.20207798079354689, 0.15434678265592083, 0.21034354664152488, 0.17352920724079013, 0.1148589898366481, 0.16350136720575392, 0.11735328880604357, 0.11727329270797782, 0.10825804638443515, 0.21498234069440514, 0.19399572542170063, 0.16214058006880805, 0.15110540814930573, 0.1802474248688668, 0.10001083384850062, 0.13969558523967862, 0.09154902189038694, 0.14480209560133517, 0.11644656988210045, 0.16377314168494195, 0.14763816841877997, 0.12895066727651283, 0.06619384337682277, 0.20593073655618355, 0.166277845564764, 0.14290743711171672, 0.1233340120234061, 0.12125124136218801, 0.10245093377307057, 0.13204986113123596, 0.21160095260711387, 0.10382576976553537, 0.11422521798522212, 0.19926435052184388, 0.19586228620028123, 0.11204366004676558, 0.10787242645164952, 0.13828442111844197, 0.1597220395342447, 0.08211171618313529, 0.147830844798591, 0.1091026104404591, 0.24319579708389938, 0.1970142626669258, 0.09485988368396647, 0.17854382487712428, 0.2197357520344667, 0.18688887474127114, 0.0859611619671341, 0.13302063482115045, 0.1475993837811984, 0.09652066175476648, 0.20605013327440247, 0.24808892514556646, 0.17450093087973073, 0.07896731811342761, 0.195422088727355, 0.20063542382558808, 0.20988581964047626, 0.12431772876880132, 0.1296579636982642, 0.07629454747075215, 0.14070138829993084, 0.12142268489697017, 0.10590217279968783, 0.13625132240122184, 0.148199959367048, 0.1820902814506553, 0.26021748839411885, 0.08016978288651444, 0.1350389647996053, 0.17998694587731734, 0.21067544992547482, 0.1692389405798167, 0.10609762481180951, 0.10418882840895094, 0.13386395206907764, 0.07485662150429562, 0.14385379414306954, 0.12134251068346202, 0.08166947038262151, 0.09685275799711235, 0.16715383215341717, 0.09500213855062611, 0.17954438837477937, 0.15617914526956156, 0.15238999156281352, 0.11470726516563445, 0.06533165331347845, 0.09333103720564395, 0.18454505363479257, 0.20143493951763958, 0.11182535730767995, 0.11458753448096104, 0.22495128388982266, 0.19641677441541106, 0.05672773491824046, 0.14915260981069878, 0.13699905102839693, 0.1739159255521372, 0.06767876955564134, 0.1579799220780842, 0.17473731975769624, 0.13234784826636314, 0.06704083425574936, 0.09241153107723221, 0.14565696066711098, 0.13580051221651956, 0.13899804063839838], [0.04886529626674019, 0.0416604004567489, 0.04775630870426539, 0.020670541998697445, 0.04442254052264616, 0.022140896107885055, 0.01877783906820696, 0.06867778196465224, 0.02884078825445613, 0.040242954055429436, 0.012116600755689433, 0.06487907681730576, 0.03259896286181174, 0.05087391895358451, 0.03264556602516677, 0.04339707797043957, 0.029727437649853528, 0.04183117605862208, 0.011060559863835806, 0.057868753574439324, 0.08575252199079841, 0.05460506639792584, 0.02221553018898703, 0.024150275785359554, 0.021817074812133797, 0.018720871812547557, 0.12199255783343688, 0.0065381549757148605, 0.03454422469076235, 0.008865611725923372, 0.0596316771407146, 0.03562396792403888, 0.019864436035277322, 0.012552092084661126, 0.06467818486271426, 0.03338107890158426, 0.0713741677463986, 0.014245605361793423, 0.026802908250829205, 0.02179779938160209, 0.047605404106434435, 0.04418674165208358, 0.031597627530572936, 0.02118804713973077, 0.07993864841409959, 0.043850103465956636, 0.027732225571526214, 0.02695252522244118, 0.01601145206223009, 0.026016441370302346, 0.04890451877145097, 0.06443292732001282, 0.012814180608984316, 0.024816767072479706, 0.07122394963516854, 0.042753595116664656, 0.02743906239629723, 0.032897621640586294, 0.0363650951476302, 0.02265238614199916, 0.015335727530327858, 0.026956761030305643, 0.024524314503651112, 0.030860298247716855, 0.03389923156646546, 0.07534378950367682, 0.03717866711667739, 0.05827421853609849, 0.06048724724678323, 0.03544049417541828, 0.04851074263569899, 0.09082586577278562, 0.04843575974518899, 0.02380634414294036, 0.026304776874894742, 0.0061993798681214685, 0.009098089485632954, 0.025747227300598752, 0.005980403630019282, 0.04307145696657244, 0.04225827091431711, 0.04769705563376192, 0.061791798143531196, 0.042827268116525374, 0.03232122522604186, 0.035777933881036006, 0.08336558952578343, 0.011857407534989761, 0.05676942877471447, 0.006543571726069786, 0.06294349630479701, 0.023088210509740748, 0.013543295244744513, 0.022005168430041522, 0.0693873196723871, 0.022117095431894995, 0.04057873877172824, 0.0005543821112041769, 0.07214489553007297, 0.02227501703600865, 0.07901943914475851, 0.02499738911865279, 0.032347452724934556, 0.03761761778150685, 0.04055293800774962, 0.05764885892858729, 0.06923949127667584, 0.036915442178724334, 0.03707187577674631, 0.028146739168732893, 0.02875900358048966, 0.05365167380659841, 0.025342367189296056, 0.030156929642544128, 0.025085066445171833, 0.047266962501453236, 0.04804186857654713, 0.010936409689747961, 0.019280462292954326, 0.03513337120239157, 0.00986494604148902, 0.02594591507659061, 0.059913318473263644, 0.030651287197542842, 0.06793127045966685, 0.034780758287524804, 0.07048391707940027, 0.03968174940382596, 0.06558097782544792, 0.033134871409856714, 0.021382831218943466, 0.038886174515937455, 0.0339850498130545, 0.007794317843945464, 0.04768435377627611, 0.07552252092864364, 0.032678150018909946, 0.03406190291570965, 0.05611215681710746, 0.03279972865129821, 0.022967657896515448, 0.02736355072556762, 0.04979334080417175, 0.008791370055405423, 0.07593716625706293, 0.035462498854030855, 0.06661786945187487, 0.011946558952331543, 0.02127267052856041, 0.025316141545772552, 0.08338496700162068, 0.02974518054543296, 0.11110868756077252, 0.029028846620349213, 0.03825685183983296, 0.027519158684299327, 0.02139309512131149, 0.05552139242354315, 0.05321116463164799, 0.043219096114626154, 0.18707411480136216, 0.03424710957915522, 0.06972921968554147, 0.02923756452219095, 0.02770481434708927, 0.05370891565689817, 0.025038133026100695, 0.023573079706693534, 0.02764725522865774, 0.030594028648920357, 0.06399957244866528, 0.04610190568200778, 0.0027469325323181693, 0.036457180831348523, 0.015424213797814446, 0.0029114423205101048, 0.10111857831361704, 0.057483282071189024, 0.005929245999141131, 0.008179380238289014, 0.034548454932519235, 0.02419958407699596, 0.04260241592419334, 0.04998964628612157, 0.024844812833180185, 0.062057861796347424, 0.028321863755991217, 0.04293032645364292, 0.03794628530158661, 0.01981647474167403, 0.07460006847395562, 0.06047523929737508, 0.04777350797667168, 0.062154719489626586, 0.03704043469042517, 0.03886291931848973, 0.05684498311893549, 0.04270259101758711, 0.026975834225595463, 0.04169124040345196, 0.08895459977793507, 0.014165964566927869, 0.03217039484297857, 0.026106604891538154, 0.05737104336731136, 0.016427383161499165, 0.07878069023718126, 0.0276695066713728, 0.09019965640618466, 0.02873503035516478, 0.02413782069197623, 0.03181158870575018, 0.03081024595303461, 0.03636183711932972, 0.09860300939180888, 0.005006396495446097, 0.012655225564230932, 0.029321664696908556, 0.05784470427897759, 0.042356338308309205, 0.027379291677789297, 0.03682386486616451, 0.061311673125601374, 0.02545569685025839, 0.014654303304268979, 0.021027309085184243, 0.0158428713621106, 0.06142789345176425, 0.01613131262274692, 0.024600711185485125, 0.04300304950447753, 0.042953915617545135, 0.04239699315803591, 0.05053132874309085, 0.016135912082972936, 0.02802134033117909, 0.03290959619334899, 0.014696385860588634, 0.03007705970958341, 0.04235342908941675, 0.03743689369002823, 0.042791303640115075, 0.05322607066773344, 0.028057152667315677, 0.015174933814705582, 0.03271997004048899, 0.03196523182850797, 0.020513878334895708, 0.05136644896992948, 0.07446980671375059, 0.06750927786924876, 0.03664525589556433, 0.018497869423299562, 0.023523387353634462, 0.029465444677043706, 0.04192866828816477, 0.05784011780633591, 0.03247766253480222, 0.028754313207173254, 0.062239031176432036, 0.037569411579170264, 0.039574204784003086, 0.08447152315056883, 0.05322652337781619, 0.01537293974251952, 0.0843397325661499, 0.018442447690176778, 0.004574903950924636, 0.014693061966681853, 0.04842150679905899, 0.017785392810765188, 0.029956160142319277, 0.10601423709886149, 0.014613280163757736, 0.04130486348003615, 0.04147312320128549, 0.05052942142356187, 0.1018413707788568, 0.061554329440696165, 0.005000559040126973, 0.020436737650015857, 0.05502016814716626, 0.04722444115031976, 0.03265717321482953, 0.0636080524418503, 0.03460197120148223, 0.011417697096476331, 0.017849737014330458, 0.0517413819761714, 0.04674022689869162, 0.02618147831526585, 0.05190687719732523, 0.04532328515779227, 0.03110784717136994, 0.020485762070165947, 0.019066413915425073, 0.08223935074056499, 0.021747383434558287, 0.03173615681589581, 0.025592663914721925, 0.02537912947445875, 0.05146108764165547, 0.04359365062555298, 0.06149864238977898, 0.02808691278914921, 0.03900964933563955, 0.010986708748532692, 0.09446824493352324, 0.04096237717021722, 0.026515420649957377, 0.04197451075015124, 0.04165362464846112, 0.026733265112852678, 0.03608504943258595, 0.07894685710198246, 0.02764196371572325, 0.04068884751177393, 0.04054281882417854, 0.06742121462593786, 0.014290919971244875, 0.06128514876763802, 0.004646131110348506, 0.06129008033894934, 0.060336854730849154, 0.016134800716827158, 0.03250926689361222, 0.09293791415984742, 0.012842296873714076, 0.054136426115292124, 0.03413405080209486, 0.06513105079648085, 0.03502127721731085, 0.026255834090989083, 0.03819916470092721, 0.02689257267775247, 0.0354700798925478, 0.07946734011056833, 0.02609969178593019, 0.03069106074690353, 0.052349835459608585, 0.03708724194439128, 0.02860963151761098, 0.012387991173454793, 0.05526263892534189, 0.03125625444226898, 0.043633166278596036, 0.013018260087847011, 0.010214354733761866, 0.009357914459542371, 0.021811966980749276, 0.039847611988079734, 0.0124633711129718, 0.23117460776120424, 0.20345836062915623, 0.12416466081049293, 0.14930461649782956, 0.1533646837924607, 0.08766359678702429, 0.1803466203273274, 0.19100777950370684, 0.15541915636276826, 0.19766049517784268, 0.08903061054297723, 0.10419987156637944, 0.24232709838543087, 0.10771990768262185, 0.10250931853079237, 0.18045714095933363, 0.1194740054779686, 0.09829242058913223, 0.10838755857548676, 0.18374236155068502, 0.21322993707144633, 0.24899575539166108, 0.14130454655969515, 0.11268192931311205, 0.1418952812673524, 0.1082448213128373, 0.16966178664006293, 0.17029010370606557, 0.07604795406223275, 0.16279890958685428, 0.12734339805319905, 0.12469390116166323, 0.14211626315955073, 0.09029283304698765, 0.17712271597702056, 0.12533608154626563, 0.23980222293175757, 0.08926829817937687, 0.17258368141483516, 0.13533739722333848, 0.07352278174948879, 0.2291694880113937, 0.14249057276174426, 0.09214196077664383, 0.25005846633575857, 0.1883078907849267, 0.12936993618495762, 0.10669869021512568, 0.04824084950087126, 0.08536483146599494, 0.10603322123643011, 0.11789827753091231, 0.14919831126462668, 0.06981690443353727, 0.15604799293214455, 0.1676189509453252, 0.09959412534954026, 0.1906528844847344, 0.12543627148261294, 0.08757489529671147, 0.11793024183134548, 0.11161764501594007, 0.06698673169012181, 0.08471848021144979, 0.16176379169337451, 0.1231493211525958, 0.12416797821060754, 0.1429601147538051, 0.16154925164300948, 0.12261940544703975, 0.15019013226265088, 0.11680228868499398, 0.16317559406161308, 0.16530787339434028, 0.30750218080356717, 0.1457115530502051, 0.06845049181720242, 0.15486106130992994, 0.14743219275260344, 0.14838445727946237, 0.13806654140353203, 0.08847451186738908, 0.15564251312753186, 0.14907768258126453, 0.13626043597469106, 0.1383460490615107, 0.2488936804002151, 0.08899731779820286, 0.17545142909511924, 0.1798996693105437, 0.11441122987889685, 0.06760383490473032, 0.08638490602606907, 0.16604445496341214, 0.14997041202150285, 0.10635524653480388, 0.16006927558919415, 0.13183906150516123, 0.14174892974551767, 0.11370330263162032, 0.19257446809206158, 0.15886442852206528, 0.17751865176251158, 0.11508281415444799, 0.12443171523045748, 0.13859253114787862, 0.15378837590105832, 0.14106751943472773, 0.20681605936260894, 0.1551328061032109, 0.09487281189649366, 0.13052578666247427, 0.09836429759161547, 0.11885162559337914, 0.14655251026852056, 0.14535380818415433, 0.10374625606345944, 0.17531469580717385, 0.15667755680624396, 0.1906978734768927, 0.1680032053263858, 0.13928805710747838, 0.14275502966484055, 0.12589592806762084, 0.17881317995488644, 0.1368594530504197, 0.16001352545572445, 0.17124780075391755, 0.17118731571827084, 0.0959619136119727, 0.12167543813120574, 0.16900078539038077, 0.11531712501891889, 0.1402735846932046, 0.16580198047449812, 0.23269558005267754, 0.08377524020033889, 0.10085688962135464, 0.16676077590091154, 0.17816446867072955, 0.11158645254909061, 0.11980491428403184, 0.1760630775243044, 0.1649622106924653, 0.12454649579012766, 0.1363993066479452, 0.12286064054933377, 0.16170928836800158, 0.09317097821622156, 0.1543843947001733, 0.2764316933462396, 0.15257042250595987, 0.24921891919802874, 0.13488403405062854, 0.27520682313479483, 0.07678209396544844, 0.12581962044350803, 0.16072537866421044, 0.09848149755271152, 0.15871887851972133, 0.23864698101533577, 0.10137136123375967, 0.21007965377066284, 0.11256513011176139, 0.09940131538314745, 0.1315359683940187, 0.06996282550971955, 0.19093044771580026, 0.18062744900817052, 0.13896137854317203, 0.08177047668141313, 0.10199177442700602, 0.10935081430943683, 0.21422962483484298, 0.08394907345063984, 0.12642093817703426], [0.028576427830557805, 0.19041628780541942, 0.03779080536332913, 0.022940998096601106, 0.08536803012248129, 0.03185248846421018, 0.06074715107388329, 0.01727778791973833, 0.0594619257026352, 0.12414198819897138, 0.046654742618557066, 0.0943000074767042, 0.059809833401232027, 0.029190517925599124, 0.014118360431893962, 0.023185580284916796, 0.015918397875793744, 0.010187847074121237, 0.0150153145477816, 0.06622675020480528, 0.023671759372518864, 0.012196167335787322, 0.022578722418984398, 0.04167654587945435, 0.0463621063681785, 0.015059366578498157, 0.038020603969926015, 0.06501496405689977, 0.0507360390474787, 0.011371835153113352, 0.056859299147618, 0.010889130244322587, 0.04317580664064735, 0.06954512253287248, 0.056844266946427524, 0.02455961104715243, 0.02931500021077227, 0.057674010313348845, 0.04970504749508109, 0.018262940720887855, 0.05110729100124445, 0.007698571052969783, 0.0094916735906736, 0.05813225310703274, 0.01056585535479826, 0.008775390688242624, 0.04248837009072304, 0.046324768918566406, 0.05461806140374392, 0.01955855987034738, 0.032141796182258986, 0.04690192232374102, 0.043603317099041305, 0.07192406948888674, 0.07188319199485704, 0.03777586964133661, 0.05265443141979631, 0.02597972546936944, 0.04937878453347366, 0.051009364615310915, 0.01756099889462348, 0.012653205067181261, 0.0695223014918156, 0.017483921292296145, 0.04827098069654312, 0.0345292963902466, 0.011727928740583593, 0.028588168606802355, 0.020160089115961455, 0.03175821344484575, 0.02624505625135498, 0.02054526747087948, 0.03175872552674264, 0.03411222423892468, 0.024658236907271203, 0.03808681096415967, 0.025554953535902314, 0.04934727665386163, 0.08402797117014416, 0.0424240629945416, 0.031074736252776347, 0.060643050019280054, 0.05260482997982763, 0.06175662034365814, 0.03554970862751361, 0.018650939236977138, 0.036323523745522834, 0.03440322776441462, 0.021778457157779485, 0.020027509999636095, 0.0538070424227044, 0.06019219901645556, 0.02228042358183302, 0.02215985798102338, 0.05476320322486572, 0.005573415410253801, 0.04172578737779986, 0.026570961126708426, 0.06345314395730384, 0.036439224568312056, 0.025766983271751087, 0.07454016973497346, 0.03962795111874584, 0.026451705416548066, 0.016023157586460002, 0.02138253992598038, 0.017316030789515935, 0.035121886467095464, 0.00954878278207616, 0.013023597985011293, 0.04323294459027238, 0.06663044885499403, 0.018268529092893004, 0.034255640566698276, 0.05920189942116849, 0.039026329104672186, 0.01573814504808979, 0.0512335637176875, 0.016062307731772307, 0.01923747895489214, 0.015144417629926465, 0.04395208939968143, 0.021834055150975473, 0.0544150506175356, 0.02052873242064379, 0.004804052250619861, 0.003928260475731804, 0.035086333882645704, 0.06931487863766961, 0.02979867083922727, 0.038033524760976434, 0.022519794038089458, 0.01990456396015361, 0.05041780612373259, 0.07197870640084147, 0.057426960484008305, 0.06084555985580664, 0.043448152573546395, 0.030143277836032212, 0.023167277067841496, 0.026266511740686838, 0.06786437326809391, 0.029934524682175834, 0.012789290831278777, 0.09081238837097771, 0.057482933261781, 0.05469984236697201, 0.014930110428394983, 0.091162585595157, 0.014851678406557767, 0.02174868219299242, 0.01605819066753611, 0.045136019034544006, 0.036409178719623014, 0.07878225616877899, 0.029019749745202716, 0.026947790320264176, 0.09525930014206097, 0.02936551820312161, 0.056814165436662734, 0.044477767442003824, 0.013763128663413227, 0.029054185397399124, 0.021856069106434006, 0.014674918311357033, 0.05131704419909511, 0.056269069100380875, 0.05183765337278601, 0.0650869078526739, 0.03804143605520949, 0.02229294546850724, 0.038190448176465, 0.03547729727870319, 0.023742510165902786, 0.025740050732565578, 0.05565406987443566, 0.054225754720391706, 0.030804804155195598, 0.020626248769985978, 0.05753552926762495, 0.006891341663504136, 0.048263893186231144, 0.07963836804265156, 0.039868373569333926, 0.035777084121946245, 0.12992378615308553, 0.056484343876945786, 0.02830178309523035, 0.025498598552076146, 0.03093065199209377, 0.020589210034813732, 0.061671050716540776, 0.035066436903434806, 0.17464483331423253, 0.04137088864808902, 0.058151159319095314, 0.015767732620588504, 0.03852327914501075, 0.04072310504852794, 0.06344253866700456, 0.05054383764218073, 0.019217290682718158, 0.04121762030990794, 0.0493587910750648, 0.080498361348873, 0.04388365225167945, 0.060548444744199514, 0.029435892356559634, 0.027670278504956514, 0.03713390447956044, 0.0297848761692876, 0.09223314846167341, 0.029420837890938856, 0.0615839782403782, 0.058997519372496754, 0.07884446298703551, 0.026833981974050403, 0.021915296201768797, 0.028657514885708224, 0.10026487841969356, 0.00830837014291319, 0.03266795290983282, 0.05685277566954028, 0.025579867433407344, 0.05684761032171082, 0.05029334424762055, 0.01911076280521229, 0.030706605029990897, 0.02964196821267251, 0.017499790264992043, 0.04005281582067255, 0.07011627196334302, 0.041961126116802916, 0.028955680136277806, 0.027468980224512052, 0.023882970890554134, 0.0991128351597581, 0.011507794752105838, 0.06417192140361294, 0.026572141141514294, 0.06740052354871295, 0.04829556433833204, 0.038775397842982784, 0.0032550886999160866, 0.028073058747395407, 0.03937425906769931, 0.09076285001356155, 0.021221347305981908, 0.026006780462921597, 0.04173796231043525, 0.014797420917602722, 0.05546735294046812, 0.10879469336941838, 0.050807838124455884, 0.048238396702799946, 0.059860978508368134, 0.015243162233673502, 0.027098893442598637, 0.013609644174721325, 0.0862028868868947, 0.025268679346481804, 0.030806060240138322, 0.05594594171270728, 0.03070841030421434, 0.04849706485401839, 0.029216960647318047, 0.04962399383657612, 0.0664875928487163, 0.018168289061577525, 0.024605546277598478, 0.037226105196168646, 0.040231925740954466, 0.02185264409490628, 0.0626687754993327, 0.06724861334078014, 0.06046439280908089, 0.021241680296952836, 0.021970012894598767, 0.07827670517144725, 0.0136818217470136, 0.04178212009719573, 0.051856355494237505, 0.009446243020647671, 0.04764149103721138, 0.045217083825264126, 0.012298323035793146, 0.03627814512583427, 0.025681682673166506, 0.05846577056217939, 0.01750394258124288, 0.04137890755373519, 0.060894831040059216, 0.020854347858403344, 0.04235966312990058, 0.030386490761884488, 0.004812224224224337, 0.033828490049927495, 0.022389727091649547, 0.05826927583257202, 0.060946491939830594, 0.1127952107344754, 0.028873810115328524, 0.012757706881529884, 0.0433184140274534, 0.051686503866221756, 0.03524341314914636, 0.020881428827124182, 0.06434124981751665, 0.05605459213256836, 0.03261327146901749, 0.019870601427101064, 0.01968334643606795, 0.02521034282835899, 0.048470503388671204, 0.018466439469193574, 0.01613449458091054, 0.057427190549788065, 0.02695353454328142, 0.0829357079055626, 0.03147260162222665, 0.024546937020204496, 0.014827063223492587, 0.0796382715634536, 0.04638582540792413, 0.05172288765606936, 0.014305909498943947, 0.01333690675892285, 0.03048214432055829, 0.07113711835700087, 0.012056706655130256, 0.027975820703431964, 0.09533779710181989, 0.06753949070116505, 0.04396320306113921, 0.04515458756941371, 0.016915892592805903, 0.02738023791607702, 0.05255615622445475, 0.02661422833625693, 0.014197126420185668, 0.03538555669365451, 0.03176056234224234, 0.017348243709420785, 0.03512911869620439, 0.05059917217295151, 0.1095713657559827, 0.06289719371125102, 0.0785389801603742, 0.011271595121797873, 0.0687562269740738, 0.0306975081548444, 0.009200819422403583, 0.14917468128260225, 0.24336325528565794, 0.16823518584715202, 0.12029093195451424, 0.09292928298236802, 0.09216498219757341, 0.25736324780154973, 0.20153947843937203, 0.16871792322490364, 0.29004446289036423, 0.1185988872020971, 0.12741789483698085, 0.18866976199205965, 0.09971300256438553, 0.09408690719283186, 0.13235860940767452, 0.13590813847258687, 0.24833444243995473, 0.17479266913142055, 0.18144256464438513, 0.07126774376956746, 0.11586986918700859, 0.07869101653341204, 0.1183807774214074, 0.15638424520147964, 0.1356155244866386, 0.09809376249904744, 0.21203215525019914, 0.1269995461916551, 0.119648937106831, 0.1384848603629507, 0.07559398232842796, 0.1974443075596355, 0.08497672533849254, 0.12615970219485462, 0.3066497796680778, 0.11589076806558296, 0.20163450302788988, 0.10825720775756054, 0.1181095743959304, 0.17220987647306174, 0.11940386510104872, 0.08053859317442402, 0.13957851886516437, 0.08831935105263256, 0.11509272182593122, 0.15424723096657544, 0.13242388871731237, 0.1251809429959394, 0.13763142022071406, 0.14442897343542427, 0.19638766738353297, 0.11282570558250882, 0.1271533637191169, 0.1832492637913674, 0.23801571020158008, 0.09704587224405259, 0.10106027519213967, 0.20195604593027383, 0.18051210441626608, 0.24445915507385507, 0.062460892513627186, 0.2297219427418895, 0.13243888010038063, 0.12353649217402562, 0.11106450750958174, 0.11834628981887363, 0.11866303102578968, 0.07886753635830246, 0.12273380751139484, 0.22422417212510481, 0.08025376431760378, 0.09991251412429847, 0.10630746706738137, 0.060385777105693705, 0.11562974730622955, 0.20057428569998592, 0.1490831744740717, 0.16968081530649215, 0.13322739716386423, 0.1305753324413672, 0.12073746736859903, 0.1420004732790403, 0.15647829015506431, 0.12093569501303136, 0.13375706796068698, 0.12098599778255448, 0.13473993865773082, 0.14246343984268606, 0.08232535081333481, 0.13470348436385393, 0.13377617084188387, 0.16880905895959586, 0.11345067556248978, 0.11528683797223493, 0.12781629455275834, 0.09856738630332984, 0.1688871774240397, 0.16890366794541478, 0.11696932386257686, 0.15290107898181304, 0.13679775089258328, 0.17364174651447684, 0.09271872826502658, 0.12354162041447125, 0.15771415899507701, 0.08387212015804835, 0.09913607922499068, 0.08692941977642477, 0.11799732455983758, 0.13318684621481225, 0.18643374525709078, 0.07338132840231992, 0.1672978830174543, 0.18263712554471567, 0.18609323306009173, 0.11803405344835483, 0.21641857456415892, 0.0872382645320613, 0.14263842342188582, 0.0945094638154842, 0.09756320112501271, 0.11842987791169435, 0.14418982376810163, 0.253213900141418, 0.08607759009464644, 0.052332806881167926, 0.2584843657677993, 0.12389164694468491, 0.14018135057995096, 0.12171199632575735, 0.11617969357757829, 0.1182443780999165, 0.22090637125074863, 0.159127505030483, 0.16288850165437907, 0.13911249465309083, 0.1281600128277205, 0.16625733260298148, 0.18003248405875638, 0.1489215495530516, 0.13678403600351885, 0.15202730399323627, 0.0860814715269953, 0.19436354865320027, 0.09563513114699163, 0.177696633618325, 0.13416133064310998, 0.15511345089180395, 0.0796852569328621, 0.10566689714323729, 0.11898963537532836, 0.11556218218174763, 0.10342179652070627, 0.13484450726537034, 0.12747640575980768, 0.12718440033495426, 0.1801016225363128, 0.1485939507256262, 0.14803382218815386, 0.11221249122172594, 0.1549819126375951, 0.08844943469739519, 0.15568695293040946, 0.10587927012238652, 0.08706739245099016, 0.09748890472110361, 0.08971546441898681, 0.16012621315894648, 0.17809886281611398, 0.23464123893063515, 0.11775646795285866, 0.10765862854896113, 0.1482888389728032, 0.11933336107176729, 0.13447583798551932], [0.01294430228881538, 0.02195952820329694, 0.01275803992029978, 0.02863618741685059, 0.06885868788231164, 0.08793416898697615, 0.054100873530842364, 0.1139284331293311, 0.05339876101061236, 0.022854862581880298, 0.025562256269040518, 0.044500169169623405, 0.06586845614947379, 0.03822032333118841, 0.08239644856075756, 0.022653298983641434, 0.008857129905663896, 0.07624654535902664, 0.024681835348019376, 0.06804750562878326, 0.030628473577962723, 0.011654432928480674, 0.008673295287735527, 0.052886727353325114, 0.05408669851021841, 0.04600096246576868, 0.030862626736052334, 0.012032375343551394, 0.07295928386156447, 0.028663964149018284, 0.06983498315094039, 0.05915103633014951, 0.06583128939382732, 0.04778110385814216, 0.02801417860609945, 0.03401048692467157, 0.06746146871591918, 0.027293530947645195, 0.04499132621276658, 0.032952269684756175, 0.019263292706455104, 0.01781161845428869, 0.04883513909589965, 0.04755193236633204, 0.029389265073405113, 0.03127383592072874, 0.06488111030193977, 0.029060809065413196, 0.03753896497073583, 0.025805573095567524, 0.020489569287747145, 0.033210221663466655, 0.016679945292708, 0.004940060553053627, 0.046274124761112034, 0.07692403713008389, 0.04498684735153802, 0.010207866507698782, 0.028838990401709452, 0.03527700275299139, 0.07426560478052124, 0.0840276965755038, 0.004823234912691987, 0.042791407540789805, 0.06482980563305318, 0.1109024447214324, 0.05891357133805286, 0.051979949057567865, 0.0363265628402587, 0.026981932824128307, 0.04409314940858167, 0.045345668331719935, 0.024383844502153806, 0.018416682178212795, 0.02095533189276466, 0.0548216807510471, 0.047437433822778985, 0.02823972285113996, 0.027112409807159565, 0.03141384950140491, 0.008233901189669268, 0.13561956176999956, 0.01839851996919606, 0.07101899071130902, 0.049236362683586776, 0.022293650508800056, 0.027955593468504958, 0.0895835179835558, 0.06239543508854695, 0.05276833995594643, 0.03438867424847558, 0.014617194065067451, 0.05426909614470787, 0.04042931475851219, 0.0663862525834702, 0.08760982076637447, 0.057778590053203516, 0.0026693521249399055, 0.04382318948046304, 0.05034146881371271, 0.0689730305748526, 0.07438568427460268, 0.05825353116961196, 0.043484714478836395, 0.04178132599918172, 0.01669828747253632, 0.012293029667489463, 0.01623806314455578, 0.04531634236627724, 0.06255606553168036, 0.08069252202403732, 0.06474994312156923, 0.040847162454156205, 0.020484598753682803, 0.06376975157763809, 0.0664990367658902, 0.02753573455265723, 0.015715956687927246, 0.030565979177481495, 0.06716098796459846, 0.010549897324381163, 0.052653611346613616, 0.03165537033055443, 0.0578827245044522, 0.0424235546233831, 0.05192703763896134, 0.03735842270543799, 0.013369444368436234, 0.017197259330714587, 0.038857542458572425, 0.014302478921308648, 0.01898606715258211, 0.059668565590982325, 0.0329117632645648, 0.024051737127592787, 0.030571704846806824, 0.03530490008415654, 0.03432401834288612, 0.05895207024877891, 0.01468537609980558, 0.027850358783325646, 0.06308192911092192, 0.013592629511549603, 0.04436607792740688, 0.08594025566708297, 0.029990812872711103, 0.02706260984268738, 0.06934329547220841, 0.044398138707038015, 0.014568475780833978, 0.015343906925409101, 0.018541414938226808, 0.019199859489162918, 0.014013195323059335, 0.00737975461561291, 0.04585516013321467, 0.010782222016132437, 0.04747103084810078, 0.018296934795216657, 0.05450908072816674, 0.023336553531407844, 0.005242925453785574, 0.008300319695990765, 0.011528473769431002, 0.040447634673910215, 0.020030944288009778, 0.031786300023668446, 0.07449714743415825, 0.04480569652514532, 0.044503716635517776, 0.08086702320724726, 0.00990429656667402, 0.10338085965486243, 0.10477227522642352, 0.07188810501247644, 0.03218131183530204, 0.030617525044362992, 0.014601294478779892, 0.04567412062897347, 0.06982812570640817, 0.07417884771712124, 0.04631782983778976, 0.02417284449620638, 0.07682159106479958, 0.008520459250576096, 0.031729837428429164, 0.06067831316613592, 0.06109240188379772, 0.08872104590409435, 0.04467034734261688, 0.04810871752852108, 0.058705577030195855, 0.0815981203049887, 0.07454966180375777, 0.04489292114158161, 0.0561533571453765, 0.024561720601923298, 0.05794251563202124, 0.01307712445850484, 0.03669606703624595, 0.05099107067508157, 0.05099698930280283, 0.02877354039810598, 0.0032589808006378007, 0.01000598842438194, 0.018507303975638933, 0.037474587370525114, 0.0449006023700349, 0.04932069292408414, 0.039438892708858475, 0.059858006206923164, 0.026332631532568485, 0.03290758126240689, 0.024004913175303955, 0.04811112208699342, 0.06068109621992335, 0.04920399020193145, 0.030312008821056224, 0.0415551416517701, 0.020526851076283492, 0.031173163588391617, 0.02809759786032373, 0.019444217177806422, 0.06532440995215438, 0.04685993531893473, 0.06354415352689102, 0.053006031303084455, 0.02112537833454553, 0.027982648462057114, 0.010829428174474742, 0.08975774457212538, 0.02121148045262089, 0.04547390031802934, 0.01706306604319252, 0.03091376813245006, 0.028517198879853822, 0.019667265951284207, 0.01809404831874417, 0.03277164949395228, 0.033229788386961445, 0.09056891198270023, 0.07857510048779659, 0.037660413727280684, 0.01747323065501405, 0.010262005253025563, 0.009588378215994453, 0.03504138199787121, 0.0651292696420569, 0.03370913414983079, 0.012921138004458044, 0.09083706478122622, 0.019705662816704717, 0.049179269262822345, 0.019146541744703427, 0.0954602514684666, 0.02945757791167125, 0.015398503946926212, 0.025567692500771955, 0.009419836478627985, 0.06851349273347296, 0.04970877678715624, 0.02838456966856029, 0.11434834770625457, 0.11840749473776668, 0.03824479936156422, 0.04562261929095257, 0.021423307953227777, 0.05329566927684937, 0.061615690210601315, 0.04384946521895472, 0.05515055236173794, 0.06578935062862001, 0.045941765056340955, 0.01584898665896617, 0.01717097060463857, 0.009677660436864244, 0.014981827916926704, 0.07621799493790604, 0.056294821624760516, 0.021153238558326848, 0.024453049773001112, 0.05553529284952674, 0.004086694161742344, 0.017852892997325398, 0.015532517263636691, 0.013792095614917343, 0.04514243490120862, 0.1123752367857378, 0.022995198996795807, 0.0231243401140091, 0.013193352206144482, 0.02071153823635541, 0.017925050160556566, 0.08042390167247504, 0.02294879621331347, 0.05492050142493099, 0.02082746912492439, 0.02802533308567945, 0.03412232857954223, 0.048475609364686534, 0.09032838192069903, 0.04632514370314311, 0.038321671017911285, 0.05444432834337931, 0.024389182399318088, 0.05366138480894733, 0.006012989479131647, 0.018865826241381, 0.0671174906892702, 0.025522616306261625, 0.009117399240494706, 0.05682935348886531, 0.043616171096800826, 0.019682862184708938, 0.024908160703489557, 0.05143175054399762, 0.02988484160596272, 0.07015780996880494, 0.06113457813626155, 0.05186050409974996, 0.07469898933777586, 0.017338423240289558, 0.04029836280096788, 0.058832142894971184, 0.03301296252175234, 0.007056828999338904, 0.04320562242355663, 0.08180984761565924, 0.020204773827572353, 0.009955168006854365, 0.003123618398603867, 0.05051215906860307, 0.027167863081558608, 0.027934932077187113, 0.07326284452574328, 0.094686607044423, 0.0030558000162272947, 0.03139142179861665, 0.02314689954800997, 0.031145526008913293, 0.11201226720004342, 0.040377998957410455, 0.029952109871373978, 0.01557857402076479, 0.07852172522689216, 0.014051630223548273, 0.05129883560584858, 0.021077554338262416, 0.05956475768471137, 0.03107336142420536, 0.07148865144699812, 0.03186017340340186, 0.08166469837306067, 0.080406646738993, 0.14348395226988941, 0.19812898332020268, 0.2740721090231091, 0.16260820731986314, 0.16476533375680447, 0.25101800390984863, 0.07984071460668929, 0.10506971317226999, 0.14271821914007887, 0.12283346310141496, 0.16659266460919753, 0.13681311334948987, 0.2481078647542745, 0.09989247613702901, 0.1440646086120978, 0.2032244356814772, 0.12747466913424432, 0.16597265959717333, 0.136848098190967, 0.13105723861372098, 0.06343144355923869, 0.1013308102847077, 0.15021949162473902, 0.20145174174103886, 0.1710823315079324, 0.1324692042544484, 0.19932980794692412, 0.08160049517755397, 0.1701636120560579, 0.1280545091140084, 0.18690956581849605, 0.15404392703203484, 0.17076858115615323, 0.17778741312213242, 0.14831251348368824, 0.10907184099778533, 0.12019739166134968, 0.1338261619093828, 0.08457659641862847, 0.10511238666367717, 0.10069617012050003, 0.15205078554572538, 0.1436746248509735, 0.23250973143149167, 0.22688551369355991, 0.1259420154383406, 0.15046946180518717, 0.23996329866349697, 0.19926984241465107, 0.08777762777754106, 0.06988967201323248, 0.09549395239446312, 0.20797566510736942, 0.14188609347911552, 0.07415854997816496, 0.12109876712202094, 0.09764172034920193, 0.1256414456292987, 0.14691506425151601, 0.13312547060195357, 0.07761801942251623, 0.11512564349686727, 0.1979512834805064, 0.5124502396211028, 0.22558092197868973, 0.13790408527711406, 0.12122942964197136, 0.09778313658898696, 0.20123058173339814, 0.2615918271476403, 0.12963859364390373, 0.10192243556957692, 0.15752410981804132, 0.10501305019715801, 0.0956545234657824, 0.0903221701446455, 0.12047889569657855, 0.1272216413053684, 0.09287067558034323, 0.21222659794148058, 0.10997739474987611, 0.1881520843016915, 0.13137104833731428, 0.0794746947940439, 0.1997631776612252, 0.25326531613245606, 0.168769235315267, 0.20259022596292198, 0.130332323606126, 0.16560097719775513, 0.15782607486471534, 0.12933150777826086, 0.20446214504772797, 0.14892450330080464, 0.09270745504181832, 0.11041358462534845, 0.06971109643927775, 0.25024234084412456, 0.12307748867897317, 0.1983882748754695, 0.20165198802715167, 0.15657368581742048, 0.09715199936181307, 0.16088399046566337, 0.0919709328445606, 0.1422326170722954, 0.13274327939143404, 0.07129213816369884, 0.27843080169986933, 0.18865472608013079, 0.18936015228973702, 0.14563327131327242, 0.20729959825985134, 0.2501723711611703, 0.14299916656455025, 0.1169528704485856, 0.12101785076083615, 0.13183649367420003, 0.09793558856472373, 0.18098433298291638, 0.17133907007519156, 0.13042920356383547, 0.15377197443740442, 0.11252711730776355, 0.2965788950677961, 0.1087681764329318, 0.08171339810360223, 0.12915403058286756, 0.15698038274422288, 0.10347537958296016, 0.20577196148224175, 0.1165375423443038, 0.10097207836224698, 0.089714759378694, 0.12969444767804816, 0.18622883828356862, 0.20242263417458162, 0.1249801623634994, 0.10628606352838688, 0.16163292137207463, 0.12061387751600705, 0.15869222057517618, 0.1653117622481659, 0.13140618160832673, 0.14659969601780176, 0.21309829491656274, 0.16030449187383056, 0.11956501504755579, 0.11092110973550007, 0.1740869609056972, 0.15728898259112611, 0.09103553733439185, 0.11771248828154057, 0.08287557910080068, 0.22789808514062315, 0.13525062531698495, 0.12643644906347618, 0.27084433066193014, 0.17416680115275085, 0.07936841182527132, 0.14838724775472656, 0.18831624736776575, 0.17217131447978318, 0.14130111783742905, 0.11488863863633014, 0.24224829714512452, 0.13418199203442782, 0.05582199191849213, 0.14216919313184917, 0.1011186302639544, 0.2940106188179925, 0.11964204255491495, 0.15637433010851964, 0.11309493449516594], [0.05455309379613027, 0.06346978290821426, 0.03395177562197205, 0.03511775270453654, 0.014723109670740087, 0.025967884503188543, 0.0303150237959926, 0.05381802991905715, 0.03633365035057068, 0.0554799063684186, 0.018466623150743544, 0.07441148874931969, 0.016827153995109256, 0.03436388651607558, 0.025505450430500787, 0.08371496296604164, 0.01689253720542183, 0.07836523596779443, 0.06429389337426983, 0.0384847802342847, 0.008858914770826232, 0.039044196309987456, 0.02964097002404742, 0.021280297951307148, 0.04196403533569537, 0.020609246166714, 0.02774739321466768, 0.0315135347773321, 0.02178957267460646, 0.017684299309621565, 0.038721187665942125, 0.03841295147140045, 0.04491537853027694, 0.05840481426275801, 0.08874671679222956, 0.039628760059713386, 0.02634621283505112, 0.03453207202255726, 0.05650602572131902, 0.006142665406514425, 0.05171482793230098, 0.030897006727172993, 0.017503473172837403, 0.016112376724777278, 0.036054921947652474, 0.030289332498796284, 0.02024616340349894, 0.015065191510075238, 0.026258702491759323, 0.015810461773071438, 0.03288451160187833, 0.02402667851129081, 0.03153117562760599, 0.020004317884740885, 0.03413274833292235, 0.04390648813568987, 0.060090895858593285, 0.08976011944469064, 0.011031673620891524, 0.003473847859822854, 0.03976576423156075, 0.035438249178696424, 0.05105303258460481, 0.02021753134613391, 0.010563987925706897, 0.04819791254703887, 0.02687561460334109, 0.06703999562887475, 0.08127992448862642, 0.02052631116384873, 0.016359330074919853, 0.03596807211579289, 0.0297000004502479, 0.02863054338376969, 0.026144617695536, 0.03542791477229912, 0.032569199029239826, 0.02189090366300661, 0.033598390873521566, 0.05593640140432399, 0.0764848712424282, 0.02101540689182002, 0.028312265931162983, 0.02798942798108328, 0.04046073729114141, 0.046913024852983654, 0.03206711386155803, 0.06901116954395548, 0.042616746795829386, 0.05053061628132127, 0.035818959804601036, 0.020208870482747443, 0.022333205124596134, 0.058011902729049325, 0.03333772263431456, 0.046135049997246824, 0.02794716081552906, 0.046316976367961615, 0.02999696156621212, 0.06265980293392204, 0.08740404548007064, 0.034626948181539774, 0.06924304616404697, 0.01627674759220099, 0.06004162096360233, 0.015559882103843847, 0.02089173354761442, 0.07182969056884758, 0.03775525277887937, 0.012282882653380511, 0.11765989227569662, 0.05712641293939669, 0.0141214505492826, 0.03151416560285725, 0.01841605506342603, 0.012225016471347772, 0.021433163674373645, 0.03115036481176503, 0.0322905411303509, 0.02797215634927852, 0.030118955801299307, 0.02463379056280246, 0.033562251992407255, 0.05275931172946002, 0.022973335326241795, 0.023001292029221077, 0.05131770099978894, 0.056641263581695966, 0.04155221387918573, 0.045290882990229875, 0.035545756691135466, 0.00822038482510834, 0.04627559050277341, 0.06319536638329737, 0.0972402778279502, 0.018105507078871597, 0.025524924385535996, 0.029448174900608137, 0.031547706967103295, 0.014199504075804725, 0.0666588508465793, 0.0711595534812659, 0.06395159260137007, 0.04436571056430694, 0.03191835407051258, 0.06383094165357761, 0.05277672622469254, 0.09156599480775185, 0.06478475726908073, 0.11395713940146379, 0.030148172299959697, 0.02740614814683795, 0.03907301390427165, 0.019882813467120286, 0.02958036624477245, 0.0019193476555301459, 0.02954478026367724, 0.01268128422452719, 0.010309484150639037, 0.04932229967380408, 0.030946045990276616, 0.033931815560208634, 0.08167908119503409, 0.0563727731059771, 0.10416632649139501, 0.0905439980851952, 0.06332468561595306, 0.03658240340882912, 0.040074442003970034, 0.03312334585643839, 0.043895133276237175, 0.052108867530478165, 0.019388825130590703, 0.04574809790938161, 0.08070913871051744, 0.1016307418467477, 0.017300069048360456, 0.055617244506720454, 0.06525274817249738, 0.0190551648120163, 0.004555629911919823, 0.03756416459509637, 0.057986781030194834, 0.03204572516551707, 0.009107273563131457, 0.08393769632675685, 0.04698566255683545, 0.05322367724147625, 0.05184527522942517, 0.051515720842871815, 0.024389251047978178, 0.07406466087559238, 0.053802300099050626, 0.02575290658569429, 0.05721381938201375, 0.03408601900446229, 0.03233127390558366, 0.04657495803257916, 0.013503078262147028, 0.05224692926276475, 0.06297620275290683, 0.028930619664606638, 0.02379829926212551, 0.03752204400370829, 0.03701430367073044, 0.024077140842564404, 0.0376902220887132, 0.021371146103774663, 0.07097466223058291, 0.09726041971589439, 0.036615755525417626, 0.025704681829665788, 0.05187637863855343, 0.04189783947367687, 0.021860293782083318, 0.006735830183970393, 0.05550105757720303, 0.06303310321527533, 0.021350744464143645, 0.061058107239659876, 0.07896547016571276, 0.043571174683165736, 0.04717838346550707, 0.0705955880403053, 0.04262602364178747, 0.026396205757919233, 0.03730243508471176, 0.07168506082962267, 0.034847570132114924, 0.12284587923204526, 0.03206212662917096, 0.035990785545436665, 0.09661926349508576, 0.059591805256786756, 0.10965833804220892, 0.020705701244878583, 0.10346267401473597, 0.04693050985224545, 0.02407783475064207, 0.02912910520535661, 0.08335637947311625, 0.07242958337883465, 0.036200883841956966, 0.09466013463679701, 0.0397831713053165, 0.022698926222801674, 0.03453125937085133, 0.06331748678348958, 0.028494019752542954, 0.07063352662953548, 0.01871873071650043, 0.04796578359673731, 0.0510451324225869, 0.052666417104774155, 0.06368188871419989, 0.04023022993351333, 0.0067474067600414855, 0.02684432009118609, 0.04220996823278256, 0.012490764711401425, 0.027365205714886542, 0.034432527754688635, 0.05925470693910029, 0.017352076902170666, 0.032397762915934436, 0.01941721413459163, 0.04051358933793381, 0.022612228531215806, 0.01549468535813503, 0.031013099032861646, 0.03365066404512618, 0.012085787711839657, 0.06967644556425512, 0.040626195404911414, 0.015096199367690133, 0.014223702728486387, 0.01480869321312639, 0.005171635211809189, 0.010720206300902646, 0.04379180034447927, 0.015538750376435928, 0.045561941296909936, 0.047432821374968626, 0.09034268310642801, 0.06699217163259163, 0.019785122713074088, 0.022536833748745266, 0.05181139618798625, 0.03306130602140911, 0.008863310140441172, 0.05703001166693866, 0.017199452377099078, 0.015069522869453067, 0.02658136232639663, 0.08149671324645169, 0.00827385563752614, 0.007782603970554192, 0.0502358129597269, 0.008372044558200287, 0.03895533154718578, 0.02855501872545574, 0.02534708724851953, 0.006663943904641201, 0.04048507231345866, 0.0162794898278662, 0.07263912135385908, 0.04127174513996579, 0.06734458787832409, 0.039239121397258714, 0.042542602532193996, 0.1337032177252695, 0.03733225086762104, 0.047847232926869765, 0.03810783600783907, 0.023685908417974133, 0.06982502352911979, 0.09732653023093008, 0.06652029187534936, 0.08528209684300236, 0.030486328178085387, 0.03681825794046745, 0.037968482938595116, 0.015955972812662367, 0.038183134311111644, 0.07980491340276785, 0.07430133919115178, 0.02530336732888827, 0.041834192888927646, 0.04005289745691698, 0.011575571388675598, 0.012084330319339642, 0.06390558686689474, 0.0030464802648566547, 0.030336074814840686, 0.025920873158611357, 0.034337692413828336, 0.061778176022926345, 0.07324718520976603, 0.075050811865367, 0.050685175956459716, 0.003410259487282019, 0.04324321591411717, 0.039151366145233624, 0.052172065115883015, 0.03195268953277264, 0.013190761183068389, 0.0789279694436118, 0.07988600045791827, 0.012748966237268178, 0.0354180924477987, 0.03138798936561216, 0.05040426935011055, 0.11267575464444235, 0.2300076695973985, 0.1953269453952089, 0.10231353997369297, 0.12652564037125558, 0.1537316758185625, 0.14543565222993493, 0.12477369687985629, 0.11302515777060762, 0.18150376214180142, 0.1268857007380575, 0.1519977071438916, 0.10772286885185167, 0.12033013961627148, 0.12743739847792313, 0.2185090264538303, 0.15588285023113713, 0.13128530059475452, 0.17218198656337336, 0.10056437211460434, 0.09466443909332156, 0.09586395011865534, 0.08408588837482966, 0.20320908806752414, 0.14375787897733971, 0.16654516715789214, 0.14344932365929708, 0.1879573892802, 0.17483400675700977, 0.11941114556975663, 0.19375151430722326, 0.1432522092363797, 0.1512835087487474, 0.14420650724787265, 0.1666565635241568, 0.13505138835171238, 0.1587853007367812, 0.14350134821143, 0.13349755376111716, 0.07014672228251584, 0.15357371710706502, 0.1547185392701067, 0.0984612517640926, 0.24031472043134272, 0.19381842634174973, 0.10101277774083428, 0.10833739681402221, 0.09148855169769377, 0.14124182023806497, 0.13487489079125226, 0.10335892919101752, 0.15143906290177256, 0.16360914189135656, 0.23880894732428715, 0.16161096864379942, 0.1793708445620723, 0.2288087151828222, 0.21130447945324704, 0.17070018482627347, 0.10526287936954759, 0.1515042086248286, 0.2858989150263369, 0.1567902890383266, 0.13577354256995022, 0.19344571977853775, 0.19093930895905942, 0.0871798352454789, 0.2558023331221193, 0.17427681712433696, 0.08710093010449782, 0.16509780107298866, 0.20028674800414592, 0.1526574170566164, 0.19252829166362062, 0.09952644890290685, 0.13568283728091046, 0.1570305964560248, 0.12509789667092264, 0.1228927681222558, 0.15386211569420993, 0.11818857601610944, 0.2676582016283646, 0.17104942467994988, 0.10815141460625455, 0.08005690964637324, 0.17597194178961217, 0.1103225008409936, 0.10479433185537346, 0.21642936539137736, 0.10496419461560436, 0.1272872620029375, 0.10401558145531453, 0.07486510425223969, 0.17635834839893505, 0.11627989835687913, 0.09266951645258814, 0.12356293489574455, 0.14516398165142164, 0.08773415276664309, 0.11824121655081399, 0.18185329885454848, 0.10166462830966339, 0.14313122432213277, 0.08103523097815923, 0.1463594479719177, 0.0825786755012814, 0.11454101666458882, 0.16490634181536734, 0.1987189461942762, 0.12587890319991857, 0.25128603796474636, 0.1302306493744254, 0.12351209035841748, 0.2097457615309395, 0.16851249674800783, 0.11781243330915459, 0.13476974330842495, 0.12276077715796418, 0.22791006340412423, 0.13859912141924724, 0.1536911545554176, 0.08695589960552752, 0.08843312971293926, 0.10085816611535847, 0.1367378150462173, 0.13197775406297296, 0.14129026763839647, 0.1266773056704551, 0.09530651557724923, 0.1647898691589944, 0.08086474481387995, 0.16317269968567416, 0.19866506627295166, 0.15854067401960492, 0.36298169754445553, 0.11155445856275037, 0.11898887838469818, 0.10577521359664388, 0.13171248079743236, 0.1827964052790776, 0.17437356349546462, 0.12302469971473329, 0.236312763299793, 0.2511730830883607, 0.10348354320740327, 0.11265426946920343, 0.223436233936809, 0.15684336744016036, 0.1738240773556754, 0.3384915366768837, 0.0871275806275662, 0.20628934231353924, 0.10440407349960878, 0.10868767567444593, 0.14648761687567458, 0.12225269543705508, 0.09980414572055452, 0.07077984846546315, 0.1443785964511335, 0.11444090094300918, 0.1467844462604262, 0.12795411137631163, 0.21073755284305662, 0.283595496439375, 0.21185423276619986, 0.14381135813891888, 0.09070206069736741, 0.1859745488036424, 0.12301155627937987, 0.14719641243573278, 0.19847040093736723, 0.1420561788836494, 0.12301767899771221, 0.10397188380011357, 0.14150057744700462, 0.21119523531524464], [0.09273891468183137, 0.03312573186121881, 0.03644810807600152, 0.04222413212119136, 0.06711183552397415, 0.038332881158567034, 0.026173414880759083, 0.05479108571307734, 0.030599077108490746, 0.014341770074679516, 0.018339853195357136, 0.025344113091705367, 0.029950749885756522, 0.006563118040503468, 0.01103587974284892, 0.00883534694366972, 0.009117441913986113, 0.027526893718459178, 0.01994493679376319, 0.04628568742191419, 0.004952612125634914, 0.01581166961841518, 0.009643783250794513, 0.013341830908757402, 0.034868053407990374, 0.028855258278781548, 0.027740558034565765, 0.02611443826026516, 0.052972612393205054, 0.07794680568622425, 0.035636725442600437, 0.05342855081835296, 0.05266156716970727, 0.0490353556961054, 0.05308617211994715, 0.0474363020475721, 0.03739500687515829, 0.03573151625460014, 0.02591886750451522, 0.002394879475104972, 0.023795174820406828, 0.069082052068552, 0.03804888350714464, 0.03149501819279976, 0.10949250514386222, 0.0354118955146987, 0.05275547111523338, 0.048881278416956775, 0.050557244539959356, 0.05318702998920344, 0.03055034212593455, 0.051932900605606847, 0.1045350254571531, 0.04043304033984896, 0.02250259291031398, 0.028958305483683944, 0.05039557880081702, 0.04229586811561603, 0.01749720388033893, 0.03288844869530294, 0.03386505937669426, 0.008565664393245243, 0.04837656975723803, 0.004064254862896632, 0.03461081760178786, 0.055970781395444646, 0.02257263124192832, 0.028375639776641037, 0.042648121088859625, 0.021880268686800264, 0.019583304929255974, 0.02790690301480936, 0.04371315495518502, 0.10175304036238231, 0.037382861628429964, 0.02470714258379303, 0.09669482155004516, 0.054171128940652125, 0.04419287550263107, 0.03986012830864638, 0.013773600367130712, 0.030890924826962873, 0.03997881256509572, 0.007569655826955568, 0.0271956620781566, 0.07141946844058111, 0.0384321730962256, 0.02352610546950018, 0.012155888198321918, 0.02711514462134801, 0.020784072039532475, 0.01417286932337447, 0.03195822224370204, 0.026545314358372707, 0.025315007915196475, 0.01617906425963156, 0.06843201976153068, 0.02494813277735375, 0.03247362154070288, 0.05725731665734202, 0.08734796880162321, 0.0293014931230573, 0.004351120915089268, 0.03922137664631009, 0.1161064807092771, 0.03742580971447751, 0.04450006155821029, 0.029396705103863496, 0.01199140322569292, 0.06391623668605462, 0.050452353098080494, 0.05374670210585464, 0.018391436169622466, 0.044299893197603524, 0.03349924365465995, 0.03724503367266152, 0.02859603537217481, 0.05550486108404584, 0.08515347522916272, 0.0297923124890076, 0.015329127982113278, 0.013482979047694243, 0.02998896121425787, 0.02574240519606974, 0.032123847340699285, 0.03591144995880313, 0.019145345031574834, 0.04165701997408178, 0.030560904742742423, 0.029616484716825653, 0.01102691830965341, 0.06572403421159834, 0.07738246917142533, 0.038212835061131045, 0.03185957597452216, 0.024293471324199345, 0.03822667982603889, 0.011852515854116064, 0.013944623660790967, 0.02981124838697724, 0.044613261343329214, 0.07173727834015153, 0.08144333056407049, 0.012726628519885708, 0.031244175988831557, 0.029707293906540144, 0.034699047828326, 0.024747363277128898, 0.06404517000191845, 0.019354356081748847, 0.00840623994008638, 0.03962737966503482, 0.10490225497051142, 0.02047644626145484, 0.05443245769129135, 0.036726873586303554, 0.05623147932055872, 0.026916633105429355, 0.05830078000144567, 0.014921464407962048, 0.057033399571082555, 0.03371212871570606, 0.036207333105267026, 0.013756816697423346, 0.012386080143187428, 0.029062801731924992, 0.08330372409545816, 0.05596814306045417, 0.03160152009513695, 0.09280867656343617, 0.0011131229484817595, 0.04474279950954951, 0.026222979213343933, 0.02479377533745719, 0.050071898513124324, 0.028110034400015138, 0.08875019004335627, 0.024163734633475542, 0.016516594878339674, 0.008107988414849387, 0.08792863998678513, 0.0405869357928168, 0.03411383098864462, 0.017283888373640366, 0.10944738998659886, 0.034456521389074624, 0.09103316246182658, 0.04918869453831576, 0.11721580594894476, 0.03287647785327863, 0.02526907639548881, 0.03539668890880421, 0.023038989420456346, 0.06409440407878719, 0.03441178843786474, 0.0460455321444897, 0.03446766844717786, 0.030051427784201223, 0.046488033985951915, 0.012794054491678253, 0.056128090727725066, 0.04547794131212868, 0.043768934774561785, 0.06881044086185284, 0.05159923843166325, 0.017045614440576173, 0.01275117876502918, 0.03695846076880116, 0.03298545110737905, 0.05970421836536843, 0.05252129754808266, 0.03517451215884648, 0.030292336341517512, 0.03379814363142941, 0.017979716758418363, 0.049120903058792464, 0.0335476799227763, 0.036348712237668224, 0.022264940525928978, 0.02699479053262621, 0.06301290937699378, 0.051773338855127804, 0.017828849267971236, 0.04117420096008573, 0.09007157656014897, 0.07145945535739884, 0.020796259959752206, 0.0283131694959593, 0.08249369959230535, 0.013727583500440232, 0.0318921451253118, 0.05097604218462948, 0.028086697566322982, 0.026289388442819472, 0.017260362292290665, 0.01957760894583771, 0.04306786126107909, 0.033893409417942166, 0.051781383735942654, 0.0621293751464691, 0.018463029300619382, 0.03177610291459132, 0.017046202592609916, 0.03066816363570979, 0.03563239130016882, 0.03484695414954331, 0.03416655687033199, 0.01773078187397914, 0.016200701575144194, 0.043031239983974956, 0.013305862721608719, 0.05248185982054565, 0.07869318360462785, 0.051998332055518404, 0.006369167485900107, 0.006354915003612405, 0.03387509692402091, 0.030280128012236673, 0.031884693962638266, 0.0011295176864223322, 0.04271333360520657, 0.045067025275784545, 0.0280506625858834, 0.00626423708126822, 0.042948394038830884, 0.02110919580445625, 0.034091548004653305, 0.042712420763564296, 0.032992928245221265, 0.023269077464647125, 0.04231047729263082, 0.009151213344011921, 0.0584243809862528, 0.03628189297160134, 0.03208430942322593, 0.09168527278234251, 0.03966267620853614, 0.031054779901751317, 0.060656315909000114, 0.042608345684129745, 0.01410394606864429, 0.07956457629916258, 0.06134895120339934, 0.08189958811271936, 0.0732866080943495, 0.0671596520987805, 0.012759955588990124, 0.02713239584409166, 0.006649292054135003, 0.0510527913866099, 0.040743113349890336, 0.017684790982457343, 0.0598516905301949, 0.02601714455522597, 0.03147591160086449, 0.030725754295417573, 0.03101903806964401, 0.04267260825145058, 0.05199053208343685, 0.03474355813523289, 0.03537506272550672, 0.061666597830480896, 0.031586172481183894, 0.03040502775547793, 0.04947516354150139, 0.0070450395196530735, 0.02452309738146141, 0.034933213973999955, 0.047087032507988624, 0.03310641004645731, 0.05816138240334112, 0.025493980538158212, 0.03827682674454991, 0.06540003480040468, 0.018220369274786208, 0.024179377251130063, 0.06562421534908935, 0.08385588938836008, 0.05362835181585979, 0.011704663338605314, 0.05036161812313367, 0.05974044259346556, 0.015842108805372845, 0.03489674112643115, 0.0474913434300106, 0.03344943812408019, 0.021999479868100025, 0.03310597217932809, 0.06458238101913594, 0.025248034653486684, 0.010553172051004367, 0.06961274702916853, 0.009444894167245366, 0.09291820271755569, 0.05230811562796589, 0.08175469862180762, 0.04916992191283498, 0.011861372458952246, 0.07860103854909539, 0.023579382395837456, 0.042167331848759204, 0.02511629973014351, 0.04913030978059396, 0.050085635666619055, 0.02903091906773625, 0.08024477690923959, 0.04016944803879596, 0.09252962161554024, 0.0083791237193509, 0.03125262534013018, 0.0013594215852208436, 0.03860995086142793, 0.19884370121872053, 0.08961481435107999, 0.08837205095915124, 0.12290360347833484, 0.10672693635569885, 0.06217653120984323, 0.15417827060446143, 0.15388298488687724, 0.16210890520596877, 0.13352128764381632, 0.14219107164535671, 0.15328135545132682, 0.20149166928604245, 0.1475739132729359, 0.09593657669029199, 0.07422162510920316, 0.10676519406842999, 0.18878482456784695, 0.08359647908946499, 0.1567591485218145, 0.16924982046475634, 0.1066706221899949, 0.1382735709194094, 0.09264311825972982, 0.2044160576770082, 0.1221615522808861, 0.12792132329195738, 0.1375482403091155, 0.11857691963086836, 0.12937382503878325, 0.18608229380333796, 0.1699730582186021, 0.09819238650379702, 0.17339609563350677, 0.14011892111739144, 0.22733277641236782, 0.17810983175877482, 0.1925811028922908, 0.055736845315550454, 0.22611914231674746, 0.07981265400303528, 0.15194004226941615, 0.1398043247172609, 0.07993756487849168, 0.21835694555193186, 0.15644079685444012, 0.1421089901123196, 0.13393502013059333, 0.14117802522378042, 0.15736659639514983, 0.11065534665249288, 0.1180871763790492, 0.15906278975307941, 0.16677940380759537, 0.11545771747478284, 0.16696191276423633, 0.06795654800953344, 0.09492531884461641, 0.10232916218228638, 0.07380576265859418, 0.08065764850471169, 0.1023978331068065, 0.14865581615595147, 0.1419872185215354, 0.10208582680206746, 0.10487503299373202, 0.08864776624250226, 0.17442036332795396, 0.12599065579706803, 0.1363949428196065, 0.12611644982825965, 0.0855173947638832, 0.10306638199836016, 0.24969704041723162, 0.11329670960549265, 0.10054270882392302, 0.21127203275682405, 0.22648267593467608, 0.11777421270380728, 0.12255019275471568, 0.06898304214701056, 0.08404012754908763, 0.18311117979465052, 0.050959455184056424, 0.1612091698916629, 0.1201189540734049, 0.1446769101312384, 0.12022409413475543, 0.1227629219647497, 0.13403593737166375, 0.10929020310868509, 0.11913367881788872, 0.13461240800097585, 0.12502632394898683, 0.1220463783829473, 0.07490032658097334, 0.19290886499220505, 0.10104578104801476, 0.09597080454113893, 0.21805434225825593, 0.1486977920285426, 0.13327349937753752, 0.143786852422636, 0.15281815140042454, 0.17521542613394558, 0.20011670712847263, 0.17263686371734366, 0.1405421827803366, 0.09419185429578647, 0.14772667695069686, 0.12998532503843307, 0.1374866717378609, 0.13934196671471, 0.10005058327806182, 0.13787799136480317, 0.07224542685435154, 0.10307158445357345, 0.09514873498119414, 0.2628810267196968, 0.12420737883076072, 0.08301315843709745, 0.1370805240003392, 0.1586428825976327, 0.15878924896242097, 0.21897367027122527, 0.14716012141434476, 0.18397308042040095, 0.10286922304658219, 0.10928773175692186, 0.0686197163304314, 0.06274703497183509, 0.1631914611789398, 0.22873932437505573, 0.12108767201425508, 0.1310544926673174, 0.12329415127169341, 0.2103568459278904, 0.16435749392258003, 0.13598554447526112, 0.12786471226718277, 0.12425175184034742, 0.24717275868169963, 0.1612426110659726, 0.13287932990351692, 0.07929782615974545, 0.14342560461955145, 0.07091434046742506, 0.07214664699858986, 0.18432763405144215, 0.13441708957543597, 0.1009896895266138, 0.15763225557748228, 0.20595785463228822, 0.12088099130778573, 0.15278929669875652, 0.12370377968181856, 0.17000872583594173, 0.2109518405632116, 0.14336344233015552, 0.18867847480578348, 0.1483061903854832, 0.0962855938996654, 0.1649657284724526, 0.1333166626864113, 0.13559922692365944, 0.08885345989256166, 0.2066712366649881, 0.2091741593903862, 0.15067493281094357, 0.12395712663419545, 0.09681723880930804, 0.16880793089512736, 0.11851504677906632, 0.10111040726769716, 0.14087625313550234, 0.07428102660924196], [0.0254572664925945, 0.013555993391491938, 0.034671120811253786, 0.0168741523521021, 0.025021857727551833, 0.06033116987964604, 0.04626760128303431, 0.021492839769052807, 0.08067168993875384, 0.04588723575579934, 0.07999289940926246, 0.0688207864004653, 0.03533629664161708, 0.014175519718264695, 0.030900977217243053, 0.045257638485054485, 0.06625703725148924, 0.022752717086405028, 0.05177981038286816, 0.023640676372451708, 0.05129965196829289, 0.03202069623512216, 0.015096913684828905, 0.055909190559759736, 0.050556773276184686, 0.02984275997732766, 0.0676365933031775, 0.05708586199034471, 0.0100965833189548, 0.029535121211665682, 0.03970238481997512, 0.01550888728161226, 0.025013964987010695, 0.02817876469634939, 0.02334101383894449, 0.08811724939732812, 0.022365603581420146, 0.0715674230013974, 0.019534222992660943, 0.02348925598198548, 0.07099382448359393, 0.04359012171335053, 0.03674688559840433, 0.09701036047772504, 0.0366849682177417, 0.009280888807552401, 0.014493383423541673, 0.07654210567125119, 0.01377596874590381, 0.015843242435948923, 0.030235673366405535, 0.03163945126289036, 0.02495833545253845, 0.11294036739855073, 0.01885053985461127, 0.025893146521411836, 0.025552359729772434, 0.014145579625619575, 0.01427784796760534, 0.0520636224973714, 0.016003132586774882, 0.023117002128856257, 0.07245552886161022, 0.024824670945235994, 0.03278010255598929, 0.024840380356181413, 0.09924196143401787, 0.0323159930849215, 0.03436621314904187, 0.006988540744714555, 0.02632418032590067, 0.03162440421874635, 0.02304920693859458, 0.040461382959620096, 0.06468352090450935, 0.04541658054222353, 0.03188987044268288, 0.06501223295344971, 0.040255047351820394, 0.09560491831507534, 0.03514822157740127, 0.04917996688163839, 0.045897525633336045, 0.014249588839447824, 0.0257346015132498, 0.04607774506439455, 0.0411777706904104, 0.0579248413851019, 0.021203370633884333, 0.03146412629575934, 0.024040497301029973, 0.0026117635525224614, 0.020816605938307475, 0.01699431348242797, 0.018997514780494384, 0.029251329506223556, 0.06763476761989295, 0.023781185336702038, 0.05202129410463385, 0.05463615867483895, 0.05852308662724681, 0.01976413663214771, 0.05073777567304205, 0.04462162163690664, 0.0507297307922272, 0.06718869233736768, 0.02686930078198202, 0.027006262280337978, 0.049885623157024384, 0.028878146113129333, 0.06285307303187437, 0.01919448077387642, 0.04088949455763213, 0.008670456572872354, 0.0471859459503321, 0.029026670272287447, 0.021531776546908077, 0.024967317294795066, 0.031274481589207426, 0.043702994953491725, 0.04376048171252478, 0.0570892498944886, 0.026467153220437467, 0.0194781722893822, 0.013980089970573317, 0.010621155561238993, 0.0461172607174376, 0.03180925836204551, 0.04079688937054016, 0.027773585461545736, 0.06373527139658108, 0.012658364848903148, 0.050865195007645525, 0.06335141777526587, 0.04555547347990796, 0.02183684191550128, 0.034092249334207736, 0.022310452732199337, 0.060183642053743824, 0.019591926829889417, 0.040294273567269556, 0.027405983018979896, 0.053169478196650743, 0.04976514290319756, 0.04461592936422676, 0.03568775922758505, 0.06010138982674107, 0.014193335900927195, 0.021195668996369932, 0.04145255828916561, 0.011144277832499938, 0.011131782848678995, 0.06630886884522624, 0.015210508663585642, 0.034623426690814085, 0.040110280315275304, 0.0904037247528322, 0.017792884791560937, 0.03358567788382061, 0.02434399488265626, 0.04239910456817597, 0.039780766746844165, 0.008472395911667263, 0.038094210176495835, 0.04261539979779627, 0.05129679098899942, 0.08017382759135216, 0.05262406273686793, 0.09201488282997161, 0.057365302855032496, 0.050587127116159536, 0.05051756932516582, 0.013535738326027058, 0.03053478114452446, 0.10314941348042339, 0.031656361097702757, 0.05014728958485648, 0.04721329409221653, 0.06537378503708169, 0.046401852087001316, 0.019251151170465164, 0.029813263317919336, 0.08714038267498836, 0.05168856332602445, 0.06398592435289174, 0.04011783908936195, 0.05153707985300571, 0.038293395191431046, 0.03988715361629147, 0.0168233375006821, 0.040499952374375425, 0.02865821992600104, 0.06728696011123247, 0.026794620316650253, 0.03173627927026246, 0.03608730556152295, 0.07719522531260736, 0.09092368083656766, 0.057842900860123336, 0.037820984798599966, 0.0396114272007253, 0.028655208661803044, 0.012710685332422145, 0.08812425527139567, 0.12442979306797497, 0.07159529806813225, 0.02369995170738548, 0.05007813997508492, 0.018178445352532435, 0.013041082984273089, 0.005809692966067814, 0.03287709012511186, 0.053895699384156615, 0.06637964746914804, 0.024692915612831712, 0.02659023470187094, 0.06019190957886167, 0.0436426472151652, 0.09711555248941295, 0.059758098286692984, 0.010925470432994189, 0.0091774000247824, 0.0036348679304865072, 0.05569971566728782, 0.009578255321684992, 0.05255096490145661, 0.05244954299996607, 0.04117963348107878, 0.020771759809576906, 0.02640353446622612, 0.05312542059982661, 0.018862365977838635, 0.009990408889279934, 0.03112970713118557, 0.02732922639552271, 0.011882473572768504, 0.036434493376873434, 0.06300656401435845, 0.013771409176115412, 0.03316577443911228, 0.024163862653949764, 0.02997364143084269, 0.02836097679391969, 0.06320994958514348, 0.011187006984982872, 0.04174106819846202, 0.013322971080924617, 0.09082493808818981, 0.03102874350588536, 0.05896900605875999, 0.037753954020445235, 0.04960487240168732, 0.03358684676641133, 0.12158287747297436, 0.016973034253169317, 0.06594111982849427, 0.04856534615100827, 0.034387564737698995, 0.028481377266871277, 0.10634420337737538, 0.04385365093185101, 0.029767103587801103, 0.017842144843598362, 0.030132722640701104, 0.01921262442920124, 0.016632054503133986, 0.03867112238367554, 0.015928771244944073, 0.10961909327306785, 0.0895210810995195, 0.03240406374970917, 0.052207064800313674, 0.04158593335887417, 0.02276324445119826, 0.026436168554937467, 0.00840318785776617, 0.07763981629977934, 0.01564781639899593, 0.027325402479618788, 0.046099003884592094, 0.05603712568699848, 0.06320643180515617, 0.017598768645257223, 0.01733271241391776, 0.07016041490714997, 0.02253997117804829, 0.03795013704802841, 0.021070079055789392, 0.02829705561453011, 0.018118899133696686, 0.06036700819095131, 0.03564350125088822, 0.029441914884955622, 0.04420630466483999, 0.031086575363588054, 0.022505711785925087, 0.02242110695078736, 0.010743471702880925, 0.06353043121634983, 0.05142280766449403, 0.10189280161284842, 0.026537712910794653, 0.05749890427978244, 0.056287474362761714, 0.04771021020133048, 0.021620162624458317, 0.03133594254904892, 0.07002224927418865, 0.067052953527309, 0.04483957185584586, 0.03248445689678192, 0.048165822081500664, 0.0735815598454792, 0.036167168073006906, 0.03605535610404331, 0.06989123794483021, 0.021974265400785953, 0.02363621606491506, 0.02525339110434288, 0.03380985101102851, 0.020565873201121576, 0.019727313119801693, 0.13221671077189967, 0.06069008362828754, 0.051908064633607864, 0.037063307681819424, 0.036870434632874094, 0.06416159812943079, 0.06514891429105774, 0.05332649438059889, 0.027191797344130464, 0.07888854655902833, 0.06353130695060827, 0.040036778009380214, 0.04724164413346443, 0.021495466971828137, 0.0511351883324096, 0.055602809734409675, 0.002177037099500012, 0.0216340871702414, 0.04265947223757394, 0.06932768810656853, 0.05072083615232259, 0.05318282201187685, 0.03481582476524636, 0.01157817168859765, 0.03176274425641168, 0.046868143472238444, 0.05288119093165733, 0.032622641083435155, 0.08500659678247757, 0.02653334722708678, 0.09462577319936827, 0.1798636157764122, 0.12252851462108083, 0.1286295399768278, 0.12757285527186468, 0.1127133221598342, 0.1678130225627683, 0.08767438761424273, 0.20862476230831817, 0.17658878525253385, 0.11775916194892488, 0.15054499759571627, 0.10816564899869263, 0.07026671271887608, 0.16200179845327511, 0.16622708266368136, 0.11590567039093003, 0.12068494557752274, 0.061828059479012154, 0.0912664268980734, 0.19421405042521656, 0.17318453901680186, 0.23516097979154438, 0.15729444479802623, 0.15233054553391412, 0.12629754870431498, 0.1341020775726065, 0.20240590616595, 0.13029993628151715, 0.18542108475230634, 0.09012987968162633, 0.05547204702452291, 0.09301343510742299, 0.0956053264962975, 0.08916399674490094, 0.16796767129562795, 0.13726493285503238, 0.16762861370807514, 0.13852918142220005, 0.054483246567542665, 0.15790710254805163, 0.16187428263947368, 0.25699255988001823, 0.16731588752008975, 0.119462806469528, 0.07069725485052913, 0.11196316670975648, 0.18638908280991018, 0.1522172344266437, 0.1635333537706174, 0.20503992185695097, 0.13176774111343548, 0.10541320880292915, 0.18468120804755017, 0.11833077893243171, 0.16272889537503943, 0.12185980245703831, 0.0982378282060381, 0.13960740325273946, 0.11134883170598187, 0.13586748362286016, 0.11537274898728356, 0.24244968633865938, 0.09639377676649019, 0.14125262590823695, 0.11110042003565468, 0.16320747672580183, 0.17814505408750847, 0.11581184066017158, 0.10185962761170231, 0.12575288652442396, 0.18407111812848598, 0.09987502082367428, 0.19176557165337726, 0.17803349444875494, 0.13332224363693967, 0.13830977288307622, 0.22989079618128017, 0.09607530635548756, 0.19435401947703212, 0.12430129019776359, 0.1553120496100746, 0.13679156138096005, 0.15215173247270286, 0.0874475872842595, 0.08631407545180991, 0.10580286601907574, 0.262546258745715, 0.07818375117494725, 0.10049011281807907, 0.09816976584261283, 0.16636647284030914, 0.2133280786802061, 0.1746512157842517, 0.15804260387085378, 0.15511980367591605, 0.1601876036147587, 0.11922075500478968, 0.14758231438463554, 0.11934624475543387, 0.18113320780685171, 0.17082633508834988, 0.1313499268144369, 0.19291566306492314, 0.15458294888958335, 0.18620960181578994, 0.1384726891410537, 0.06770564272301272, 0.1280257583130151, 0.08412429451709613, 0.1924611272988841, 0.08755641581956297, 0.09860117628704756, 0.20984523900551721, 0.13357150135561824, 0.13871928997104988, 0.22745297465007752, 0.1581919685122557, 0.11902368511073291, 0.118902603717288, 0.09208334595314227, 0.1533403413486667, 0.1604878914076835, 0.18074260064167902, 0.16107855190057307, 0.15415726782521233, 0.14377316721947864, 0.11794455043855123, 0.12298914341954514, 0.10944318943074904, 0.1477755547966808, 0.14835291600320488, 0.20896736736176535, 0.16060360707342625, 0.2124509640270844, 0.1447609212482348, 0.1393552214722149, 0.1764411572366953, 0.150363928405568, 0.12218939766171388, 0.16110748081700876, 0.07959787646541372, 0.0713345519034192, 0.10754690563771874, 0.16416547063272446, 0.3003764647291973, 0.20251121692126617, 0.08813515742076561, 0.1376561337383464, 0.15796211053384468, 0.12261038093129173, 0.14354529819684103, 0.19096992997219786, 0.10816626498126425, 0.09669794599176385, 0.17809466226026416, 0.10945429195999168, 0.09467351555940695, 0.16567358892643824, 0.1498221606016159, 0.18821390520315617, 0.1431310610496439, 0.12020434558507986, 0.0970716099254787, 0.1057411935471464, 0.132622932724189, 0.16448809707071632, 0.09707412580610253, 0.1543009773013182, 0.08952004951424897, 0.1932503716670908, 0.19274192629382014, 0.21881724038394168, 0.1337423882796429, 0.2693966974038631, 0.15184279123786837], [0.022691881385981105, 0.025258704881707672, 0.015413690143759595, 0.10662347354809754, 0.06932342075742781, 0.029356020568229724, 0.022602541648666374, 0.02567933377576992, 0.01592736673046602, 0.03749319301277865, 0.05193905300984625, 0.04831100843148306, 0.01025951627525501, 0.024473488520015962, 0.04813893778191414, 0.01023563581838971, 0.0496396457310766, 0.05659436355927028, 0.06308207754045725, 0.044176956434966996, 0.021531082638830412, 0.048525140300625935, 0.03845889041258488, 0.015465550495719071, 0.02011676438996801, 0.04182671204034705, 0.029497991563403048, 0.05004152611945756, 0.039718177722534165, 0.08508107130182907, 0.03571724104403984, 0.027170451321580913, 0.020618812450265978, 0.016881571973499376, 0.08877639527781866, 0.006615874071940198, 0.05170614109374583, 0.048662378248991445, 0.05494315548276063, 0.057714416543603875, 0.03890408253937494, 0.03242434664571192, 0.029263988690217957, 0.007228721533465432, 0.047311899543274194, 0.08087986236205325, 0.03336610236146953, 0.03311250307888258, 0.0993152782029938, 0.042542212904663756, 0.01816155778215034, 0.0352822905551875, 0.008461735887976829, 0.023647949419682845, 0.02253449598356383, 0.05545329666347243, 0.06803597265388817, 0.028785873037122656, 0.057762823125813156, 0.07519248785683885, 0.01644676063733641, 0.03755694720894098, 0.03873839807056356, 0.10628104661009274, 0.047468247794313356, 0.011611282607191242, 0.04660497790609952, 0.0137624041417439, 0.03228019930247683, 0.0771328700648155, 0.015422480882989476, 0.10753473441582173, 0.10472491878317669, 0.05214878765400499, 0.04828806493605953, 0.0231817062740447, 0.005979435127301258, 0.03846629704639781, 0.0106889219932782, 0.02553459271439351, 0.04655721328163054, 0.029891597005189396, 0.022135226099635474, 0.02923852560343221, 0.06987957880483009, 0.061038507119519636, 0.05041024363890756, 0.055186342433444224, 0.04616152240487281, 0.06511308340122923, 0.08001041409443133, 0.08828733480186202, 0.06391186543623917, 0.019234742285334505, 0.014063928538234904, 0.031010998754936736, 0.06461162163759582, 0.06630832707742229, 0.007856862339394866, 0.04030548741866369, 0.011264333206781885, 0.057122509242617525, 0.023922210093587637, 0.06337184910080396, 0.04616855796484742, 0.028166226111352444, 0.02566350005508866, 0.030675976595375687, 0.05043564364314079, 0.0264941915156669, 0.026281072678102646, 0.09829288814216852, 0.025089098162425216, 0.050347020078334026, 0.019284635018266272, 0.03621518873842433, 0.03438384286710061, 0.021323624532669783, 0.0320073635521112, 0.055376643940689974, 0.01726880051137414, 0.06462338467827067, 0.0397992165380856, 0.05875033595657442, 0.022690081677865237, 0.03815465068328194, 0.08371951233129948, 0.10019799607107416, 0.02824211071128957, 0.026738675369415432, 0.015508131218666676, 0.033610576938372105, 0.02278892647154862, 0.03560173689038493, 0.020540901787171606, 0.03960278118029237, 0.01773143496393459, 0.030815311110927723, 0.033131958480225876, 0.030537694074155297, 0.10497512645088136, 0.07907323742983863, 0.03021777833055239, 0.03937837427656632, 0.05074141219665762, 0.016685311020410154, 0.05649986589560285, 0.05572408037551213, 0.056072433362714946, 0.06424995081033558, 0.03848056112474296, 0.03763673550565727, 0.02027361359068891, 0.09724046336486936, 0.02809544006595388, 0.06885601615067571, 0.036382695179781877, 0.02083289422444068, 0.025152475718641654, 0.0906354232574813, 0.027769915541284718, 0.01757779740728438, 0.03922114658053033, 0.04151658336922992, 0.048236537622869946, 0.03302708559203893, 0.050920644571306184, 0.0302403507521376, 0.007834935586288339, 0.07299347460502759, 0.012866437082266202, 0.01794566516764462, 0.07319055192056112, 0.05011890614696313, 0.019936413227696903, 0.0734082460985519, 0.06243484313017689, 0.056042836513370275, 0.0830435568059329, 0.042040765983983874, 0.043890038432436995, 0.031422792380908504, 0.016807724568934646, 0.03602111341024283, 0.03483822278212756, 0.04211025698168669, 0.047981294483179227, 0.055540910907438956, 0.04041432337544393, 0.03782538573432248, 0.042831320242839865, 0.033823324702098034, 0.039179196683107875, 0.08647377078887075, 0.03044631714146817, 0.029171190544730052, 0.06791394873289391, 0.05293461443216074, 0.07673683037864976, 0.015798899112269282, 0.040660267404746264, 0.025307196810899768, 0.06456329298089258, 0.040796150933601893, 0.024292771850014105, 0.03491461946396157, 0.043076199290226214, 0.008829220514599001, 0.029070688906358555, 0.014561176758434158, 0.05616463036858477, 0.024631478772789706, 0.07850784706533886, 0.04818951514607761, 0.004121622878301423, 0.07196721053333022, 0.026698729270719923, 0.032815009471960366, 0.031243244593497366, 0.018559540039859712, 0.0540537026245147, 0.022355894434440415, 0.0020230674317645025, 0.05106904442072846, 0.09130435806582682, 0.011264425975241465, 0.04009542622952722, 0.025950636991183273, 0.006477652314060833, 0.035660926878335886, 0.012040910969517427, 0.006998618182478822, 0.14494040224235505, 0.050364738854113966, 0.05186258953472134, 0.08905365422833711, 0.02948123015812598, 0.028980248935113195, 0.03239012621634174, 0.02532357601012336, 0.05007187995943241, 0.04007332507171668, 0.06483539400505833, 0.03563350081094541, 0.023799896734999493, 0.08985011969343759, 0.021753587789135054, 0.06690065740258433, 0.06785737481550314, 0.05579853263043333, 0.09433017577975988, 0.02766745277767768, 0.020888865146844182, 0.0786268430238124, 0.04247089251293801, 0.013248696941445814, 0.013434162428893615, 0.0349489846121287, 0.030243117107602302, 0.0317117698432412, 0.04252834216458723, 0.052395715028978884, 0.030191057303454727, 0.06891655313665979, 0.05392860992287751, 0.029564293181465473, 0.022402955873985775, 0.06303075802861713, 0.0350796953716781, 0.017015787525451742, 0.05949479542323388, 0.08112157243886031, 0.027439648692961782, 0.05866253988642711, 0.029998790960235056, 0.031021338727441616, 0.03214428237697575, 0.04692548180173617, 0.0068032236868020846, 0.0156900946967653, 0.05833930859807879, 0.04500704861129634, 0.011568489444471197, 0.005049689216320985, 0.044457569892983884, 0.030373402987606823, 0.010319762895960594, 0.08106959241558798, 0.09791355420020409, 0.015156686258706031, 0.02940841619420098, 0.060418435314204544, 0.034064775027218275, 0.03457936538325157, 0.02209264537668787, 0.04418261531100143, 0.07158354244893417, 0.050141545361839235, 0.006895148881085333, 0.02901020758145023, 0.06509390630526468, 0.061987825320102274, 0.01263993268366903, 0.03577585215680301, 0.018132378390873782, 0.04016285405668896, 0.028684378776233643, 0.07979292029631324, 0.021791403923998587, 0.040241139504360035, 0.032674442991265096, 0.012225190876051784, 0.03440379921812564, 0.0363185736205196, 0.02730883588810684, 0.017068921588361263, 0.01744271910865791, 0.04873668949585408, 0.05266497362754308, 0.05780070605396759, 0.031256855581887066, 0.021294339385349303, 0.06669891939964145, 0.03655884393083397, 0.05594470974756405, 0.08970007969764993, 0.056186649890150875, 0.030424895048781764, 0.015985109530447517, 0.036047211033292115, 0.06558024309924804, 0.03906665740942117, 0.02340551760426024, 0.0561620773805771, 0.04168893603491597, 0.11220590837183408, 0.08865439362125471, 0.031708574897493236, 0.025187764840666205, 0.032240383079624735, 0.05984305193123873, 0.028221896463946905, 0.005239865949988598, 0.027222668832109775, 0.022335453832056373, 0.010873686151171569, 0.05999489534588065, 0.015865564382693265, 0.028017143486067653, 0.04908449329377618, 0.020199910904921126, 0.017650937916187104, 0.16225761675741524, 0.10359657229855657, 0.1632507736212574, 0.128976879932452, 0.07974049498443492, 0.1352103118551895, 0.09664574332418852, 0.17966559593332931, 0.09812546704779379, 0.11292971757939085, 0.23508091690018773, 0.21188139537116513, 0.1029517721326556, 0.1328224962344393, 0.20179410930722952, 0.048364227841375396, 0.19136464863549918, 0.18846182705601677, 0.15812857425771654, 0.13774891704088077, 0.17835904494859278, 0.07408934470731765, 0.14322099450509995, 0.08603898357250728, 0.12694824894424528, 0.08851446909829974, 0.1320880520506762, 0.20818354067159817, 0.11525254332809709, 0.14767604763619602, 0.09411784732947126, 0.06674505129922181, 0.13936627947259694, 0.13359548756852746, 0.28059143107384443, 0.16411589516792446, 0.13482706679496914, 0.15205761330435053, 0.13533459190512076, 0.22717842453857884, 0.1310884830309078, 0.09699548041680828, 0.14814833557466045, 0.1139492132642772, 0.15377663512481377, 0.13000356702832505, 0.07363550656009465, 0.33508659282233566, 0.3002631536219269, 0.1307827330310829, 0.11778141895774752, 0.1354264994733967, 0.07524292421294376, 0.1563587598502636, 0.07450358185451478, 0.12402552296407521, 0.2542741916840896, 0.1443040996673517, 0.18969104625284672, 0.18703356385231018, 0.1658197771757841, 0.08556753426091745, 0.18456477992003784, 0.1275420413003303, 0.18896599765866995, 0.10642316789017059, 0.16639431822113693, 0.15124908793950453, 0.11206822513486259, 0.18680455192225054, 0.07923015713458881, 0.16788202745374292, 0.23816082975827157, 0.20927329547703266, 0.12649812153540552, 0.14113791956333444, 0.061542956027551554, 0.17332195508060977, 0.0775212656299118, 0.16113655816297978, 0.1000288754585199, 0.156906524207443, 0.19710005493834615, 0.08977637990028597, 0.16987545095616952, 0.14830026804702356, 0.12233686240506358, 0.15666087332647294, 0.12453698145691305, 0.29836678819265217, 0.1461855776142329, 0.2558934094849974, 0.12824340054066852, 0.08766167462454177, 0.08066760812653229, 0.20795852149603888, 0.17799614957766607, 0.16701190383173525, 0.2347052120603621, 0.10179077857173979, 0.08213298613554798, 0.16661768982885405, 0.10704441228881478, 0.14727438247064129, 0.17724864359479398, 0.08679737686179578, 0.16126676055137068, 0.13174865307519212, 0.17466255580075085, 0.10844725693459623, 0.10745751395006664, 0.18696405430091545, 0.15122124255867675, 0.14392121083801612, 0.2128162342705764, 0.14141226187348366, 0.15222487854771316, 0.11675544432364404, 0.18820737430360168, 0.11091856416896917, 0.16110051947180182, 0.1332856112276204, 0.1630723019479774, 0.18584253557492048, 0.147879974974785, 0.168461644789204, 0.21596678474452347, 0.18018695467617363, 0.1092837167379912, 0.11617445401498117, 0.2131519076647237, 0.2160050201928243, 0.128093991370406, 0.16743252344895154, 0.14824947546003386, 0.15789157681865618, 0.08968047957750969, 0.13893307303078473, 0.16010696184821427, 0.0849091231066268, 0.20674165163654834, 0.16473395575303584, 0.1830731818336062, 0.09991012440877967, 0.13311613438418135, 0.15575621015159413, 0.22604458616115153, 0.10943854358629324, 0.16388427087804303, 0.18140165746444836, 0.11566822766326368, 0.11385521283955313, 0.1406494973343797, 0.142426228558179, 0.2573127520736307, 0.214895746903494, 0.09126847522566095, 0.13213228405220434, 0.27062619861681014, 0.23122608312405646, 0.17576271551661193, 0.1964793077786453, 0.14492008223896846, 0.15479336259886622, 0.13769996498012915, 0.11632263864157721, 0.07160988126997836, 0.14296905021183193, 0.09590925081283785, 0.10770015913294628, 0.12942169356392696, 0.13725467637414113, 0.1295675552682951, 0.1303589518647641, 0.15855587320402265, 0.2125441629323177], [0.04178673254500609, 0.008767598137637833, 0.030269021772255655, 0.03665306699986104, 0.03520395315717906, 0.014605145297537092, 0.061135683936299756, 0.060698607194353826, 0.029711128954659216, 0.027097121565020643, 0.028063190038665198, 0.06155517548904754, 0.017966250488825608, 0.019859220592479687, 0.019613020522228908, 0.02257179261505371, 0.07327557977987453, 0.04932751697197091, 0.06864080074592493, 0.013060732271696907, 0.03938654903322458, 0.02845785675162915, 0.08922821478336118, 0.04864751303102821, 0.06245583848794922, 0.053392374829854816, 0.0466199655784294, 0.032804600850795396, 0.027232815846218728, 0.0502629681432154, 0.014420986917684786, 0.042880068212980404, 0.03990308381617069, 0.04586411043419503, 0.01546281104310765, 0.026304526400053874, 0.03875726346450392, 0.09246741479728371, 0.02565137892815983, 0.07948553757159971, 0.061423793085850775, 0.04591885124682449, 0.02350596543692518, 0.02103897750203032, 0.0119427396748506, 0.06199976647621952, 0.038170339685166255, 0.03716245118994266, 0.04763129021739587, 0.037640516748069786, 0.020588881634466816, 0.03862540237605572, 0.033669240001472645, 0.08177640644134954, 0.10822165146237239, 0.010595371495583095, 0.05289220811391715, 0.04000974528025836, 0.05065371260570828, 0.020821813959628344, 0.038093853945611045, 0.012006203505734447, 0.05064004966698121, 0.07792923905071802, 0.05054261680925265, 0.022882496450620238, 0.0126497438759543, 0.0778943210025318, 0.03926431731088087, 0.03832862865237985, 0.05762711771239992, 0.019644979256554507, 0.04494913140661083, 0.06741610864992253, 0.037617807029164396, 0.0394727717502974, 0.0065046808686020086, 0.008621667784609599, 0.040838278946466744, 0.0018513404893383267, 0.003574089050744078, 0.022503346190205775, 0.004983694661859772, 0.05241309612756595, 0.015398899140564026, 0.029743935592705384, 0.012098675106244627, 0.04235541804519016, 0.032140015027835034, 0.03442958142841235, 0.005654329452227103, 0.01600119001523126, 0.07250602458952926, 0.01214340527440072, 0.035828162435791455, 0.10938457460724749, 0.04347874390077777, 0.0475465183990309, 0.05428002055850811, 0.03586209342756774, 0.01706007147731725, 0.01801510421501007, 0.058742242836160585, 0.1266378234140575, 0.001210644052207499, 0.07977124958415516, 0.06591276978724636, 0.07216589088784531, 0.020205887049087323, 0.03512240597046912, 0.08567297860281542, 0.0130067762802355, 0.08210364903789014, 0.033591848841751926, 0.06068282171327155, 0.09124473392148502, 0.05974240557407029, 0.04585884489642922, 0.08342904315213673, 0.034298514437978156, 0.060316464223433286, 0.03677622640680056, 0.050198579410789534, 0.059014722355641425, 0.03428548232477624, 0.021906214169575833, 0.04882487148279324, 0.06057171107386239, 0.04473551904084161, 0.02273466991027817, 0.04652515992347617, 0.05368910402467009, 0.09127950354013592, 0.04265601011866238, 0.050204178915009834, 0.034535407976363786, 0.022422316651500296, 0.019827994728984777, 0.016584087643423118, 0.03117456624750048, 0.06128212822659407, 0.06099882077251095, 0.013433438834908884, 0.07307636507903226, 0.051837441860698164, 0.0891792107722722, 0.037710334290750325, 0.030345620689331554, 0.04755517926241737, 0.03829025219602045, 0.018733070864982437, 0.0011136011698908987, 0.08451300178421661, 0.07915933398180641, 0.06687435568892397, 0.019316953694215044, 0.018606180310598575, 0.011199177279195283, 0.018238902557641268, 0.015916336560621858, 0.023465113918064162, 0.044795866779168136, 0.04557873609883245, 0.017418337702110875, 0.0593235782434931, 0.032729102167650126, 0.0858758446702268, 0.006494292656498146, 0.01863707962911576, 0.0474938667321112, 0.007423609977195156, 0.06996996497036889, 0.036988911087973975, 0.09590174769982696, 0.04956056618539151, 0.04115700539841782, 0.06214111221197527, 0.01947918161022244, 0.0167879927175818, 0.019184523007425014, 0.033533850000821985, 0.029044628390693106, 0.03237669705413282, 0.05082011324702762, 0.03217109988327138, 0.0754038812010549, 0.029386435635387897, 0.02270589870022377, 0.051987626575282775, 0.01610252100363141, 0.015219769738905597, 0.04501270377659239, 0.018357555272814352, 0.027955886616837233, 0.06547456127009355, 0.059363483524066396, 0.042525251119513996, 0.02972702761326218, 0.12953313445905223, 0.0399251256021671, 0.055280328015214764, 0.035098352964269, 0.033375668645021506, 0.059421493497211486, 0.07280810095835477, 0.05173489931621589, 0.009154846156889107, 0.006218085236469051, 0.028842851424997207, 0.037066443255753256, 0.009017119318741607, 0.08830467137158848, 0.06030137636116706, 0.04912800541205797, 0.03701734276546631, 0.023031330456433352, 0.04719774609839078, 0.051661074176081456, 0.014612197555834427, 0.04583867332257796, 0.0524851252703229, 0.008929973555495963, 0.04320214917242993, 0.028840350387326907, 0.02655601241713157, 0.015306069453799864, 0.03881626049405895, 0.09663470758823678, 0.02092377020744607, 0.0231571615950088, 0.03263551363488659, 0.009611804107407806, 0.10120145394466817, 0.0048928581054497045, 0.06503208540380001, 0.04814615887880791, 0.06037841500074137, 0.045785064285155386, 0.004048992595926393, 0.007573285856778966, 0.060448295625974424, 0.03287902341980953, 0.04546045631286688, 0.03991685065557249, 0.028538066217151936, 0.01989043717912864, 0.05536259137443267, 0.01509141715359874, 0.03629564125731122, 0.06517989895655774, 0.05513183539733291, 0.03435563754464965, 0.0056766875786706805, 0.03804159932769835, 0.038526065909536555, 0.06327852403046563, 0.031226813443936408, 0.02330550763872452, 0.083833996031899, 0.02555788501922507, 0.05721671004721429, 0.026194898200628813, 0.07488477116567083, 0.055278929066844285, 0.05207880683883559, 0.01474236376452609, 0.09434720064746216, 0.03749606512428727, 0.0833605726074893, 0.030614866300311405, 0.011491336699691601, 0.022232779556361493, 0.024958168469311204, 0.010880006466322811, 0.07587026164401323, 0.08756432711379603, 0.020676119238487445, 0.012167362729087472, 0.07388574391370639, 0.095233399188146, 0.02873713063308969, 0.04315557569498196, 0.044670124698313884, 0.0281529342464637, 0.03125760886177886, 0.03966588599723764, 0.0787717399362009, 0.03308352221210953, 0.0303209331468679, 0.03834509690932464, 0.01839165881392546, 0.026075210189446807, 0.05931136620347388, 0.061855029125581495, 0.03669715428259224, 0.03405975068744738, 0.04509511556534562, 0.04347357855294831, 0.04952165538270492, 0.1034379901830107, 0.06641359330387786, 0.030063983067520894, 0.04810646139958408, 0.07678127760300413, 0.09747982825501822, 0.06820692637120374, 0.025506300189590547, 0.03280451550381258, 0.06730110544594936, 0.03531649614160415, 0.011892974962393055, 0.05555101153731812, 0.010675457579054637, 0.013133295760781039, 0.0029094343472024775, 0.035617926841950975, 0.06927741502295248, 0.045958897535456344, 0.008076443427853519, 0.027217850438319147, 0.03944866308302153, 0.03008786909049377, 0.026760171676869504, 0.05567911735852249, 0.01691397414106177, 0.008608567022747593, 0.021058482998341788, 0.04707086111011449, 0.024324580299435183, 0.03130987461190671, 0.036746451442013495, 0.009886770749290008, 0.030672291832161136, 0.09304186678491533, 0.0189668807797716, 0.06985272790188901, 0.061484385732910596, 0.019292037941340823, 0.06736423252732493, 0.07781615800922737, 0.017626139051571954, 0.03116668463917449, 0.08345062480657361, 0.009623426140024094, 0.01839471089624567, 0.01693069101747824, 0.025280731824750546, 0.05313288660545368, 0.006950879533178522, 0.022107516160758678, 0.08819316368317232, 0.025702891398395877, 0.14571057341527194, 0.06957299017813057, 0.08566778356907889, 0.10825027609826066, 0.11672894223011099, 0.154214576468803, 0.11415914457757026, 0.1486468213261105, 0.1389686664333567, 0.2625392528716475, 0.07235916098579764, 0.0948353557032533, 0.1365343329962343, 0.11709833881468512, 0.22176430880790576, 0.14579396112821996, 0.1152260041271802, 0.18800959194777533, 0.12607563170604408, 0.11261497274972498, 0.11410389168304391, 0.09097268484765664, 0.26126804295927286, 0.16433378972578794, 0.15736983215902, 0.13737295987084508, 0.09733171042171307, 0.12517916184151545, 0.1993265573401004, 0.14761198544874787, 0.13300757302204147, 0.14820413023699075, 0.15623795305145904, 0.15580801205942407, 0.16542116965865716, 0.21282372996211052, 0.1835678974748589, 0.22035924514057115, 0.11541016065166332, 0.11739035908249207, 0.12138350692111999, 0.08444142164080404, 0.0829641470045317, 0.09324592028860934, 0.16193203657167032, 0.2416034005000256, 0.16711608652258292, 0.31724387838039547, 0.13224356167484075, 0.12957312137586996, 0.12812250468414277, 0.14454222517088056, 0.21292435034411028, 0.150584539223928, 0.19028890557819977, 0.10135818811249919, 0.25825777323916554, 0.16737073223339394, 0.07442679183441214, 0.09959328672266565, 0.10046623792732134, 0.058140980763710104, 0.1005693816114217, 0.16189635411137715, 0.12020716574625112, 0.1065849486622028, 0.11173586171935312, 0.21593476849375293, 0.11526835107360967, 0.08989619222120382, 0.12116605023038574, 0.11544222885277122, 0.1769689132925123, 0.18096560117555782, 0.12441948463674635, 0.11424390526372008, 0.130184265144635, 0.14916835818439722, 0.1640257242252119, 0.1291428686818108, 0.08371085888938978, 0.1410123036475852, 0.2061052600038238, 0.1122650426987093, 0.14643018948845565, 0.13445691321976483, 0.11422752606449649, 0.1276194176170975, 0.15807852381840348, 0.1905573403928429, 0.17448556842282414, 0.2271498370100744, 0.1754542937851511, 0.24228687398135662, 0.13961196003947407, 0.21303072979208082, 0.1561551442136988, 0.12596683285664767, 0.18232374626677483, 0.22943798219785094, 0.13008260575588793, 0.14279697585152462, 0.17212907143402845, 0.2272111235652119, 0.10071344731841236, 0.17506592790596187, 0.162930833757855, 0.15027264424134046, 0.05929124657995999, 0.11001350023434497, 0.2344424620969221, 0.13222992100054398, 0.14824803569354117, 0.06970271017053165, 0.1306971040321514, 0.14545148966135457, 0.12863826763350517, 0.1949077210156247, 0.17556983133545145, 0.13264883367810398, 0.0733562809182331, 0.10175960094784386, 0.09453919425141066, 0.18742127664154395, 0.1355478257755749, 0.07259349411469884, 0.1756016694707796, 0.2521799103124067, 0.23164833546616137, 0.11161529982928187, 0.0847132777562365, 0.20644268486648798, 0.21464614779688418, 0.1053888960450422, 0.1034206165059004, 0.11438507659477182, 0.09283617313485593, 0.1569503702921793, 0.18998840998392552, 0.10256051929900423, 0.14195426716469228, 0.16001303563825786, 0.08991106486064382, 0.22222586529096588, 0.1294338350999169, 0.13729172438615933, 0.07989457226358354, 0.22535783238708973, 0.11870476198964752, 0.11418672278523445, 0.11067409330280498, 0.08692124873050489, 0.1715196791337803, 0.11202969282749109, 0.09149543140665628, 0.10733250659541227, 0.1225060794968158, 0.11097530878032558, 0.07590969195007347, 0.12429352733306587, 0.14727208181284368, 0.188347224611789, 0.19586437905672938, 0.19982611178420484, 0.08625238813692704, 0.12537614267785102, 0.2389530575601384, 0.08476048576994799, 0.11554319062270224, 0.19840820896206424, 0.07750542077701539, 0.1295899532851763, 0.15002006170107052, 0.19776175380684435, 0.20581288350513205, 0.1811165243270807], [0.027871092534041964, 0.04155886352236848, 0.07015555383986793, 0.04605346570315305, 0.0243670701092924, 0.04874328718869947, 0.01214820789755322, 0.06421109195798635, 0.08517297144862823, 0.015778402848809492, 0.01840652032115031, 0.04554706123599317, 0.0739671649353113, 0.01712558641884243, 0.010044902010122314, 0.03437361607211642, 0.04915851510304492, 0.026972637424478307, 0.07469761636457406, 0.04760905176226515, 0.05186527982004918, 0.13825133617501706, 0.039100324938772246, 0.0205414342781296, 0.01719352261716267, 0.05101468581415247, 0.0011576927431633521, 0.060180543587193824, 0.04341953906987328, 0.01333519610852818, 0.025486969097983092, 0.03756376383535098, 0.02293096240464365, 0.030528799434250686, 0.03579753771191463, 0.05929111299337819, 0.01274931319130701, 0.009912635523505742, 0.08212428074330091, 0.016781849590188358, 0.00841982217025361, 0.02435256483295234, 0.02425563106953632, 0.022823979961685836, 0.05653430154779926, 0.023816172033548355, 0.05435077320726123, 0.029456867305270862, 0.02732611494138837, 0.05830381909618154, 0.043221470987191424, 0.02518673696613405, 0.023593418263772037, 0.0901140422502067, 0.03298534720670432, 0.017044616251951084, 0.01784924719686387, 0.031704281573183835, 0.0394944387517171, 0.08651249605463818, 0.03026021247933386, 0.02024848075961927, 0.06564517359947786, 0.028887901644338854, 0.04942506486258935, 0.04087880392035004, 0.07250956463394687, 0.01994408703467343, 0.044940277584828436, 0.04446116559847724, 0.02216607903392287, 0.0021127942454768345, 0.023900826963654254, 0.04382262173749041, 0.00375206023818464, 0.03809748304774985, 0.043456998973852023, 0.05041152755438816, 0.023688435430813115, 0.03692639998917002, 0.04356212048151065, 0.0696709165640641, 0.07112877661711536, 0.08141625701682642, 0.029946228351036552, 0.04416676674736664, 0.06424078528652899, 0.00385021089186921, 0.031530826818197966, 0.052351727936184034, 0.04570905723085161, 0.042425146530149505, 0.05570870307565201, 0.048597139757475816, 0.024279492972709704, 0.01573949946759967, 0.02074189393169945, 0.04967719469277654, 0.028446949036151636, 0.04541590518783778, 0.02042833097220864, 0.01469372897190624, 0.051006117719225585, 0.07362599222688004, 0.051758904082817025, 0.02750262363406364, 0.027841889022965916, 0.05017223687900696, 0.009931396089086775, 0.018179950056946836, 0.06516911555081606, 0.03830354777164757, 0.04382163468108047, 0.05244202875474002, 0.0434157726704143, 0.018877327674999833, 0.01644889616727596, 0.028525453417387325, 0.03343052820127923, 0.08055106125539169, 0.012057600943080615, 0.0991119742684532, 0.031147937988862395, 0.025136183721770067, 0.05795081284304615, 0.004721014738606755, 0.020178865452180617, 0.0319106468668906, 0.01416273065842688, 0.011648217441688757, 0.1901228426140733, 0.04691442009061575, 0.04196689260425046, 0.017745682343957014, 0.02590057727502426, 0.029963327433506493, 0.05171401528059505, 0.07542325867689215, 0.08155391056789085, 0.05646947865898255, 0.02553479866037378, 0.03389208097360097, 0.03918513757525943, 0.07731079254881479, 0.02168860904930625, 0.036860118780168705, 0.04779349030286539, 0.024379130009037908, 0.019195645945728756, 0.02437604638544144, 0.029132632262189873, 0.048472696435055695, 0.03324331031762995, 0.04179245821433142, 0.00741995072530699, 0.031515998707618564, 0.020067515470145736, 0.09145171890850179, 0.045100076822564006, 0.04789213286130689, 0.028670521023741458, 0.07069776693242602, 0.01507704917457886, 0.0368509792315308, 0.029944638299639337, 0.019971680085291155, 0.033226437590201385, 0.00910158500118996, 0.02889623967348598, 0.01929607522470178, 0.009582944767316803, 0.0375718829309335, 0.017882178144645877, 0.03765671783185098, 0.03821728052571416, 0.006376249893946806, 0.023926210269564763, 0.0308831730944803, 0.02055224365903996, 0.06651623974903487, 0.04828395714866929, 0.08640434287372045, 0.049012549498002045, 0.05873252070159651, 0.06699283214402385, 0.05595462855126243, 0.01693761154456297, 0.07770977113978006, 0.06204803205037024, 0.013572368879977148, 0.030400124014704488, 0.05664219497703016, 0.00840454691569903, 0.021668929148290772, 0.014197573564160848, 0.041885764730977826, 0.036705952443298884, 0.03608897910453379, 0.02386249503615545, 0.060613913301494904, 0.10101035091793165, 0.059100815196870826, 0.06920039493707009, 0.05964184456388466, 0.08778133851592429, 0.017983985962928273, 0.0373803531692829, 0.03218626567104366, 0.039750873038428836, 0.06613605975871906, 0.025187937390001025, 0.09386625926708803, 0.09958821785403416, 0.0398897808190668, 0.01418843030478456, 0.05257070231891703, 0.05065957928309217, 0.04239231020619627, 0.03527008222590666, 0.0732918773428537, 0.02471814677846851, 0.0388522583671147, 0.05001758814614732, 0.02615692064864561, 0.05031076987506822, 0.0410172701231204, 0.059898401304963045, 0.011439914214861346, 0.04062872983922716, 0.09406462049810216, 0.07976895634783432, 0.036158366201561876, 0.03130416378553491, 0.03408139913517516, 0.003312889248263673, 0.050481938815210015, 0.006017541163600981, 0.03548906774085481, 0.03683401002490427, 0.05156681771040894, 0.02896095124015119, 0.024280149773403537, 0.09499557054368779, 0.00215428818592045, 0.027325695627951063, 0.052411622964427806, 0.024726347510295454, 0.037050847022328526, 0.033340943555231206, 0.05860463381395675, 0.040292677949764766, 0.03167941962601617, 0.057796731853159145, 0.022410069359466434, 0.04995916999178007, 0.0410066908079898, 0.012928959313285304, 0.011820635972981108, 0.036235505031072535, 0.025043615642061923, 0.038447294355137274, 0.03995483748440165, 0.049491030658828095, 0.05425982300948817, 0.08454112918116152, 0.04553303093416616, 0.020045768687850796, 0.03350748520460911, 0.04812420243979432, 0.08829810336465016, 0.04693116665293928, 0.028277691126277205, 0.015670511274947785, 0.0535769358248217, 0.030847145535517484, 0.043886583735002205, 0.02451764259603806, 0.06626083704759367, 0.05392597529862542, 0.021090534501126967, 0.009131757942668628, 0.04939180922519881, 0.04097809214727022, 0.061682375890086405, 0.007563503886558465, 0.040843110327841714, 0.03233278417610563, 0.04980660669389181, 0.03620262046752032, 0.04069827278726734, 0.012144172469561454, 0.023816151624487247, 0.028691865190921817, 0.0336448827147251, 0.02603525481390534, 0.01540953504445497, 0.06525195407448336, 0.0721588330634404, 0.034696364964474924, 0.05658624446368776, 0.037865324411541224, 0.029763070015178528, 0.008481351778755197, 0.0028627715801121667, 0.05191899275814649, 0.008910696269595064, 0.05501023450051434, 0.031122072286962066, 0.031047684969962575, 0.050077074993168935, 0.05888950348889921, 0.05341844276699703, 0.03417690983042121, 0.023464841178792994, 0.054121037683216855, 0.03790487717196811, 0.049045174309867434, 0.02714128677325789, 0.03149103657051455, 0.018186397464887705, 0.030796640530752484, 0.050683602603385225, 0.06155037750431802, 0.0475535131408833, 0.020723926536447834, 0.024867088395694736, 0.03122795264062006, 0.08290498299174942, 0.013274910525069572, 0.014416910671570804, 0.08214598114136606, 0.02412152498436626, 0.011634407001110958, 0.06733716640155762, 0.04283589558326639, 0.023293234371521976, 0.041468310373602435, 0.023433377828041557, 0.03591959131881595, 0.04169033869402483, 0.02827950011123903, 0.02563302005000878, 0.05301481833157595, 0.028413531981641427, 0.06298761698417366, 0.01320395378570538, 0.037926952354609966, 0.02546596631873399, 0.03874141490086913, 0.05483484645083081, 0.02665630996489199, 0.0299550265117432, 0.06228903337614611, 0.1319543764111586, 0.16704959009075537, 0.13312915165442973, 0.08156973315635696, 0.14708222559420392, 0.11559410937479697, 0.1336457606521435, 0.19909975701011717, 0.13167647179216146, 0.1420073604094796, 0.17026099667418748, 0.1441253162920475, 0.10523736433242448, 0.17563813860761002, 0.2791006938787177, 0.11993229651125148, 0.09100349881919101, 0.17969814653042704, 0.12658965802984312, 0.10263845964800566, 0.2642617776291445, 0.12192515598144382, 0.1442692187265493, 0.12751628877595067, 0.14682290435303003, 0.12372970290016383, 0.2538641699356958, 0.14873552281642333, 0.10065587150165811, 0.19625682674814016, 0.1689807919319719, 0.13639610056998208, 0.15292858297470957, 0.10352081386372447, 0.12370308948447928, 0.16642041213344783, 0.09006308639072813, 0.1077775725570973, 0.24664308788487688, 0.15466032520635054, 0.12597513006767258, 0.12453925242880359, 0.1073178491787985, 0.15580358885927126, 0.15840993728488684, 0.17755721375579014, 0.17424196586944163, 0.2144329436123371, 0.1729130168678239, 0.1654981600586325, 0.08930677111493424, 0.05462966859340668, 0.319178449572064, 0.15380897792056203, 0.12319877787376754, 0.13660836964845657, 0.1285806918167509, 0.18085496179992333, 0.13107968115946278, 0.08629178133560345, 0.08398996578762308, 0.11302543978672475, 0.1540630595991388, 0.18538004398578778, 0.2516839775489643, 0.1978517763200216, 0.1786873710807413, 0.13133368862327188, 0.22412815305870026, 0.10147797816898674, 0.08723325503524393, 0.10059843669296242, 0.11419053000281565, 0.05760132808063645, 0.20821377576794475, 0.1543707837117836, 0.15243426809320226, 0.14040196139831096, 0.15946779458317906, 0.05922758886299562, 0.16656594729283825, 0.19094333139946684, 0.13884552929084748, 0.1220485899830237, 0.07748550895485096, 0.22942374780541286, 0.10553754822467454, 0.21202710864599794, 0.17181180330226198, 0.11769514429033734, 0.1441774595878087, 0.14953422214603052, 0.2137928709271364, 0.09899428448989056, 0.10647142233210616, 0.1670720029505901, 0.20500190905295312, 0.1396479393588379, 0.15018786129076034, 0.12771490233717486, 0.16694987512892112, 0.17139876843430102, 0.14935821440303698, 0.20880872587440535, 0.11863662541145459, 0.17304454027907923, 0.13338315911823884, 0.12905173294711858, 0.18344465643167496, 0.09211466458509676, 0.14078994136070833, 0.23876559105701745, 0.17831573321018368, 0.1446083208429627, 0.15479741472518072, 0.15800264663994312, 0.12320348309003748, 0.1274325596750714, 0.1564450716250576, 0.12757003511069342, 0.21288480871589854, 0.07346801867242903, 0.19405312312301248, 0.20236649812432006, 0.10854542080778629, 0.0815263026743196, 0.1371537591330707, 0.13864103792002425, 0.12415694989613257, 0.22258917626459152, 0.0963675715320278, 0.12261306008440442, 0.1509763189824298, 0.11177924767252989, 0.10539449183852412, 0.17175869521452114, 0.17020641913404688, 0.16833363915793598, 0.15845164598431438, 0.10922944347839803, 0.11652717454126105, 0.18816210329532623, 0.17589931521797553, 0.11253853896050714, 0.23489183251513168, 0.15724267257610336, 0.10099466191604733, 0.07613693014718592, 0.09934322006301954, 0.07526970090111718, 0.15081184421433136, 0.10298608161974698, 0.1255638021393679, 0.16714047349523753, 0.1371281105093658, 0.11237553364480846, 0.17335830547381192, 0.12875080690719187, 0.17330626607872546, 0.1614566019270569, 0.20311922882683575, 0.07986726865055971, 0.093143125413917, 0.07448068659869023, 0.0998815665661823, 0.12899598281364888, 0.1143544926890172, 0.14547139406204224, 0.09862652805168182, 0.08323232948896475, 0.12065433940733783, 0.12495598319219425, 0.10125333006726578, 0.1112110297253821, 0.16423757770098746], [0.0361307397542987, 0.017957192576432135, 0.022708507349307183, 0.019564419126254506, 0.11084902493166737, 0.03638230926299002, 0.058372931598569266, 0.06171067027025856, 0.10175478440942243, 0.03731472876097541, 0.04814606982108671, 0.030864851323713083, 0.10617343519697897, 0.03030037751159398, 0.056816291689756326, 0.044992628681939095, 0.015943842408887576, 0.058138654130743816, 0.043717938096961007, 0.06445394494221546, 0.05944923126662616, 0.039167307477327995, 0.058896294140140526, 0.04368700167105999, 0.00762002538976958, 0.013569443890446564, 0.020295846479712054, 0.02100450288708089, 0.028818956125178374, 0.04672030023357365, 0.04659863996494096, 0.022783197091484908, 0.06136987605714239, 0.027168790766154416, 0.0568134863715386, 0.046686792265973054, 0.023172909968707245, 0.04064679371367674, 0.005591189383267192, 0.08170148663339205, 0.051026040673605166, 0.11585130807361566, 0.021665361273335293, 0.006427509570130496, 0.019932264622184448, 0.06261748567339964, 0.06458185409428552, 0.013893463710701326, 0.05286126055580098, 0.050316343404119834, 0.03562437981599942, 0.026572111455607228, 0.03498840378597379, 0.03839427161437925, 0.040534655199735425, 0.06415634372388013, 0.10070275297039188, 0.03381067108421121, 0.05656073313730303, 0.011049850672861794, 0.05705417599529028, 0.10997665260219947, 0.0025426960428376333, 0.049111882253782824, 0.07845090949558653, 0.05381152128393296, 0.02260289416881278, 0.06135181960416958, 0.02730150161369238, 0.05151147204742301, 0.05536374170333147, 0.011285121690889355, 0.01000676304101944, 0.07933386485092342, 0.006919345214555506, 0.07278317221789621, 0.03739478052011691, 0.014022051927895518, 0.08767445440753363, 0.09465889525017701, 0.023864552640588954, 0.012154086634836858, 0.054227120272116736, 0.04671410330047365, 0.03178140555974096, 0.013886415163142374, 0.06134596776973922, 0.08334183337865397, 0.0794136531476397, 0.030265175591921434, 0.031622871683794074, 0.0555125274695456, 0.012048219268763205, 0.039233510760823265, 0.013225695001892745, 0.018925185067928396, 0.00953962653511553, 0.04513648658758029, 0.055117764277383685, 0.0339653532137163, 0.030726904624316376, 0.0479394930152921, 0.049907086067833006, 0.03249832763685845, 0.010063245117635233, 0.028923270547238644, 0.04709112545242533, 0.04441823606612161, 0.05760611493315082, 0.048429032176500186, 0.01900960436614696, 0.02170497340557631, 0.02439901771140285, 0.04161649871093687, 0.042817616485990584, 0.02608610306197079, 0.0180003354762448, 0.020689811863121577, 0.053812949918210506, 0.026231510200886987, 0.016707670074538328, 0.021332999713195022, 0.011032366601284593, 0.044835456646978855, 0.04007030453067273, 0.08103313070023432, 0.028157529995951336, 0.01577056391397491, 0.006843861838206067, 0.03465994777798187, 0.06307284522335976, 0.03330854138766881, 0.06331618060357869, 0.0405900565237971, 0.04102168961253483, 0.005253040462775971, 0.05511848416063003, 0.08807893231278285, 0.003827422319773177, 0.044053774763597175, 0.0675897637847811, 0.02653887993801618, 0.019355202130100224, 0.05074442160548642, 0.009192079705826472, 0.049804651134763844, 0.013487119304045336, 0.019395532290218398, 0.051096103125019, 0.007887062183726812, 0.0350084751698887, 0.014179576483002165, 0.02941970611573197, 0.04661027684051078, 0.14862250856822357, 0.010909294396697078, 0.019513158986228518, 0.04862067326030228, 0.07179503969382495, 0.04191049680230208, 0.09018729222589172, 0.07039132673526183, 0.10056317725684494, 0.04292936537240166, 0.0074646618759288685, 0.07115693369996734, 0.024817742996674497, 0.0331149336125236, 0.04754476321977563, 0.01742129330523312, 0.05035507238062564, 0.032434807217214257, 0.040238534566015005, 0.09796402024221607, 0.030377698167285416, 0.05709385121008381, 0.03451298769505229, 0.04896587211987935, 0.04610635485732928, 0.014948845946491929, 0.0289630069892155, 0.05788490270788316, 0.040054107157629915, 0.06251227139728144, 0.04253514765878208, 0.03294111149443779, 0.05447771756735165, 0.03953074832679704, 0.003908559237970621, 0.059255608648527414, 0.08756834955420345, 0.061872929727542214, 0.018427803261147346, 0.024179930151149165, 0.015540570493612904, 0.01808566761610564, 0.024356659632758237, 0.06489446153864264, 0.021949379333818797, 0.08077429185505025, 0.03726779905264266, 0.01776010041794507, 0.08297568740090355, 0.047346190476673655, 0.0010211339758825488, 0.07087826466886327, 0.05282374128000811, 0.093172870692797, 0.09142820767010562, 0.05436309285869356, 0.0012633303913389682, 0.007800524053891422, 0.11061607219744474, 0.039567191488458775, 0.0373758594651008, 0.006493054197562742, 0.044654665762209333, 0.03201323765097186, 0.03315071626275312, 0.020121128218306694, 0.008539455448044464, 0.07941360119730234, 0.05349341452529188, 0.056367463039350696, 0.06225539182196371, 0.03282183351984713, 0.058018055133288726, 0.03058361075090943, 0.08195209506084211, 0.011733546798495809, 0.020335670124040917, 0.029181703066569753, 0.055108917877078056, 0.04841912079427857, 0.039589500447618775, 0.044997541699558496, 0.08765883962041698, 0.13505940354662016, 0.04349302653281484, 0.08384251588722691, 0.009442265109100845, 0.09687922298326157, 0.02441775879560737, 0.03334282861032989, 0.02871651748137083, 0.055409832784789614, 0.009351552398584317, 0.042289596967748366, 0.03768659669731278, 0.06971885188249871, 0.0709242704033386, 0.014879765913065057, 0.04154752350586932, 0.026743747948785312, 0.04625151523214299, 0.0568774483690504, 0.030578360056097154, 0.06835244668764062, 0.037983882502885535, 0.0114783454046119, 0.04947887427988462, 0.05711665369744878, 0.06828675177530386, 0.008485424314130796, 0.057297685780213214, 0.022043125572963618, 0.03856257586448919, 0.042590259545249864, 0.02702507386857178, 0.05902071890886873, 0.05173664336325601, 0.033038488691090606, 0.08354746023542248, 0.057557738036848605, 0.08008687756955624, 0.11288377121672966, 0.01684379665675806, 0.014131870302662719, 0.03752377691853326, 0.05600018899713177, 0.08159391974913888, 0.03331379950395785, 0.02386701657087542, 0.020228162611601874, 0.01498215631727362, 0.04260052715835627, 0.024612223751319107, 0.029413434967864305, 0.037300353360478766, 0.030634440445282962, 0.041897858027368784, 0.027284456336928997, 0.031313889630837366, 0.05390320249716751, 0.08632482917164452, 0.052749905007658526, 0.0108934653144388, 0.05198935577936936, 0.02012120428844355, 0.0421545631979825, 0.041404092335142195, 0.09787169707124121, 0.038258369531831704, 0.02758209466264816, 0.032882429877645336, 0.011119543905806495, 0.034211631209473126, 0.03047313650313299, 0.05778563303465489, 0.027024964401789475, 0.10021897658589296, 0.04625292531272862, 0.04381986836961005, 0.04051296222314704, 0.025983033592638094, 0.06650081049883738, 0.043275258140056394, 0.0034274534255018807, 0.012007207260467112, 0.01620339371584123, 0.00974256310655619, 0.02068310284812469, 0.010780186676129233, 0.03021541087946389, 0.04952151808538474, 0.02032497763138963, 0.02611218769743573, 0.04127673237235285, 0.021633656724588946, 0.11056331291911192, 0.06501154275611043, 0.02226607972261263, 0.026319454700569622, 0.02239442488644272, 0.016041674170992337, 0.04798554698936641, 0.013710235798498616, 0.028470783108787145, 0.12494367838371545, 0.02560331929998938, 0.037981815621606074, 0.0607826479972573, 0.0785868709499482, 0.03567829313396942, 0.04339848062954843, 0.034050971080432646, 0.004106256710656453, 0.06368533970089629, 0.011493090023577679, 0.05516505021660123, 0.0671027961652726, 0.0514098015264608, 0.23052751435898244, 0.09974734915886074, 0.11795230588177219, 0.08802836979157291, 0.1690643429174088, 0.1234445178124588, 0.21003350702812895, 0.20952418592059985, 0.23229372192872688, 0.12603181530721486, 0.0852561513602268, 0.0949875998776406, 0.1507621500059031, 0.16604585020104423, 0.19641236605821177, 0.1234282944642473, 0.10584779563941993, 0.08947977315983735, 0.16648478602292016, 0.07525059059844352, 0.17384157719789073, 0.1373881590552628, 0.15463429066585377, 0.14438074867939577, 0.14617334702052176, 0.20684482500655577, 0.16976246639387682, 0.18419622938381508, 0.17228898941539228, 0.17115844617364928, 0.13626494823256508, 0.1172652404056862, 0.14273145905463025, 0.12618595937965438, 0.17883066495414823, 0.1254265196621418, 0.12552773376228288, 0.19767924182815477, 0.1226129339192994, 0.1366905847680755, 0.21158719318918884, 0.1488789651193656, 0.13069146370980889, 0.1520483661442995, 0.09878119162749499, 0.2054355904692784, 0.11546453781193122, 0.21213577390881255, 0.32694463909137994, 0.17296018777415156, 0.1494581371662207, 0.13231724209617823, 0.21769647864857689, 0.12952145305462182, 0.15711410291260108, 0.2056649883161299, 0.1958915268187411, 0.08985452805063687, 0.1324720837874338, 0.18337428598897532, 0.18540552933700383, 0.25151990354061127, 0.12193566479254514, 0.18626827601110563, 0.11020798745448701, 0.20390658813994378, 0.07754723337711766, 0.14241824304917827, 0.1349015042069368, 0.09595282972441055, 0.17463186057284474, 0.11283182830084115, 0.17093348636990413, 0.18652363418368623, 0.1182272715959698, 0.24345825018826872, 0.1838890099315904, 0.15523483656579629, 0.15009826922323555, 0.19224747782573104, 0.10260561961331405, 0.24807161826174706, 0.1336650861776434, 0.17887149791931733, 0.17896413279231638, 0.13769508164841682, 0.15921068494208157, 0.10730705093010329, 0.15214465238386765, 0.08865641226293519, 0.07514424083638005, 0.1217674273357261, 0.07573960654553957, 0.15200033434666693, 0.0846399090369232, 0.0926253512443509, 0.1326229772530496, 0.2078945335233584, 0.1972101302817464, 0.348422066308558, 0.13709051330806687, 0.10799783456604928, 0.10987197267240845, 0.11741843452909961, 0.17967318068258464, 0.23328863026108593, 0.14124769804766402, 0.09330024549853988, 0.09682561765657738, 0.1989268366014585, 0.1051312149502337, 0.08551821112632751, 0.14351029851241037, 0.18748587317531928, 0.09334898975794204, 0.12453030212782323, 0.1353768794797361, 0.17822872381657362, 0.15916057513095438, 0.0903074310917873, 0.12396031786920503, 0.1815351698314771, 0.09811485433601774, 0.09537170582916588, 0.1362554042134434, 0.2400938721257262, 0.13633772323373705, 0.15636968426406384, 0.07665661163628101, 0.1853931651567109, 0.07498212609789334, 0.13987776765134186, 0.17767705576261505, 0.14825554622802883, 0.1873720870935358, 0.13031328009674326, 0.17028820380801335, 0.10081001557409763, 0.0815435205004178, 0.26056086528114974, 0.08800597177469172, 0.08989039604784921, 0.0866688739915844, 0.14119313535047695, 0.0737415965704713, 0.11061717799748294, 0.11792872042860836, 0.2522668900201097, 0.08781140291830525, 0.06990335721638985, 0.25044429406989366, 0.1423835550667718, 0.10929509386187419, 0.22638503898633644, 0.2587990660686046, 0.13150114682503045, 0.11001197141013108, 0.08691685521625914, 0.17804150964366272, 0.18403107183985412, 0.11487868643598631, 0.1423659364809282, 0.17158418660983443, 0.13126164092682302, 0.08802054755506106, 0.157566100533586, 0.1510778596275486, 0.11145080279675312, 0.16454107157187536, 0.18590662744827569, 0.14175629185047, 0.20536360214464366, 0.08383477528695948, 0.28710321290418506, 0.17105369945056736, 0.1752927727648057], [0.03312724955321755, 0.052883276366628706, 0.04413790091348346, 0.06835774562205188, 0.027518911920196842, 0.030674037734570447, 0.03893567576596979, 0.030971959931775928, 0.008616733430244494, 0.014080334640311776, 0.07490863863495179, 0.029959303137729876, 0.03381154681846965, 0.03117740125162527, 0.026255607735947706, 0.032688180144759826, 0.016090924946183804, 0.04739291609439533, 0.044051455552107655, 0.05217086283664685, 0.03430550546909217, 0.04396662065119017, 0.01116750705477898, 0.04422402344061993, 0.03350234212120995, 0.0430204083386343, 0.013236432023404632, 0.014785313705942826, 0.01243604245246388, 0.053507107149926014, 0.03279237396782264, 0.030276344914454967, 0.03542292382917367, 0.020115241131861694, 0.047943882818799466, 0.040118889228324406, 0.0644835937418975, 0.05640053313982207, 0.023850975048844703, 0.07023883023066446, 0.028693674175883643, 0.07341157834162004, 0.038425731254392304, 0.04239785404934082, 0.034577131518744864, 0.05600961798336357, 0.011086243739555357, 0.06033469508111011, 0.04671715352742467, 0.013980103885842254, 0.058493300530244596, 0.0500677202217048, 0.02969637691421667, 0.041831298512988724, 0.03345838842506055, 0.0451541014626855, 0.03868548294121865, 0.04145354534557555, 0.034571372452774085, 0.002958494251288357, 0.025642343280196656, 0.014055715746508213, 0.0665049442613963, 0.02575728896772489, 0.04642532250727527, 0.033018836620613, 0.01586386115377536, 0.040797850451781414, 0.03365637116075959, 0.058336495858384296, 0.009834943793975981, 0.01533119671876193, 0.0366100298560923, 0.01837436306232121, 0.042959767451975495, 0.059564401453826576, 0.043051504326285794, 0.015420444615301676, 0.00816865805973066, 0.02553017136960989, 0.005989893379592104, 0.03485232358798385, 0.03334974171593785, 0.01548444928630488, 0.054475557917612605, 0.031384798130602576, 0.0773399144236464, 0.012338379528955556, 0.002841230048034049, 0.04756518712383695, 0.06931987329153344, 0.016289445738948416, 0.05269507513730787, 0.02740054678724846, 0.035389913100516424, 0.01193835079902783, 0.03633682303188834, 0.011496202405396616, 0.027267847071925644, 0.05442404173663817, 0.006965166803638567, 0.059745337057393044, 0.08964950233348645, 0.07811015981133096, 0.03694091639772523, 0.009817706486501265, 0.026273528746969532, 0.08700178659637459, 0.06049398965842556, 0.06464582722401246, 0.03717447769304272, 0.06303511443547904, 0.024568806256866083, 0.04771412874106318, 0.012519279880507383, 0.0208559954262455, 0.018409865551802795, 0.04034843179397285, 0.04186737431155052, 0.0416015963855898, 0.05191037642362062, 0.04613860488461796, 0.01757353933498962, 0.019815908854070585, 0.09218852312187664, 0.0043054839352407726, 0.09470441858866252, 0.04660740101826377, 0.03917632086086087, 0.013095036192680709, 0.07729243181529455, 0.046031308884266764, 0.06583719688933343, 0.03605279569455888, 0.026220706386084203, 0.02519858164305333, 0.03436555263760965, 0.06270614263485186, 0.03810717178566847, 0.04133955888391938, 0.049170478523592465, 0.029453431161527988, 0.043940140822087415, 0.059760462027043104, 0.022814599215053022, 0.031677909355494194, 0.066516076476546, 0.06370910326950252, 0.015760702626721468, 0.011418355752539355, 0.03273669062764384, 0.0870965959620662, 0.059027116221841425, 0.05408738499681931, 0.02257395226479275, 0.019901539708371274, 0.02149463205569191, 0.00769165980273101, 0.04240543508785777, 0.09340698859887198, 0.042253780920873396, 0.05181154461752158, 0.03823930004728027, 0.012385608879412757, 0.041884261881932616, 0.10252019099425524, 0.02758537866611732, 0.04739494215755258, 0.039135818151407875, 0.01634165397263132, 0.031736160526634194, 0.012134439202782232, 0.018601061346998904, 0.008959589886217145, 0.035536539216991514, 0.05549920962948818, 0.01338472055067541, 0.07789849929395132, 0.04941668601532001, 0.031996223915484734, 0.005459649737531436, 0.016194862728298176, 0.017567060385772493, 0.03108760323812021, 0.007570909128844505, 0.03879089759720955, 0.013058675594948, 0.03125247319985647, 0.02177282982302131, 0.03485731082037091, 0.04234621170326136, 0.04416538264194969, 0.010930765656667063, 0.016107575029309373, 0.0487161913770251, 0.05387380231695715, 0.04824537660169881, 0.05757865546911489, 0.06778444396331906, 0.03330982901388779, 0.009440879148314707, 0.023041796594043262, 0.06587397030671127, 0.0358358102675993, 0.05148639116669074, 0.09988119549234398, 0.03367021963640582, 0.08906585513614118, 0.037078848254168406, 0.05696258755051531, 0.04978039403795265, 0.020715237842523493, 0.09853936280705966, 0.03966777105233632, 0.08937807666370645, 0.03526786320435349, 0.012957456856383942, 0.01725949397950899, 0.01589142451848602, 0.04087911562237423, 0.022013666020939127, 0.013640776342072058, 0.008429201061517233, 0.043261328028165735, 0.03047853006137302, 0.0053383726026368095, 0.05361963529139757, 0.008734438051760662, 0.01603826771315653, 0.012293589061300736, 0.00929522617298062, 0.03963414434110746, 0.0051725434150284855, 0.04181483025604393, 0.030967490347393323, 0.02037627673416864, 0.022657456865999848, 0.038567514857277274, 0.038008681367500685, 0.021324166300473735, 0.03491959556413349, 0.026016843985416926, 0.012307093365961919, 0.034338048644713126, 0.04566164512652904, 0.030788870244577993, 0.047452788858208805, 0.021907572299824096, 0.03168650342558976, 0.05654592729115393, 0.030458657201961614, 0.04142871308431495, 0.03809906011156272, 0.04898677841993049, 0.04849116477998905, 0.016628338198643178, 0.05190535208384972, 0.02678372558875708, 0.040501373587176204, 0.03892616514349356, 0.06264806957915425, 0.05409078403317835, 0.09444434777833521, 0.028941597884113435, 0.03040974410396302, 0.04704562066763174, 0.01873713783425046, 0.014893487295921659, 0.03594502471969463, 0.0371694570640102, 0.05670929254847579, 0.06216850859345868, 0.045312813454074785, 0.040498275120626204, 0.07529536436777562, 0.01763349002430914, 0.020372118851810228, 0.035111878605675884, 0.059854644277947955, 0.05270373971143272, 0.05766372414655052, 0.03630201259511523, 0.018904662829299923, 0.05680191628925968, 0.024675714485056233, 0.03870177679345943, 0.028750518977176398, 0.06017237625201233, 0.005736768143833615, 0.026518517261138186, 0.03169321244058665, 0.05042462275014259, 0.03445992413617205, 0.0453195818408858, 0.10064408619655296, 0.014934015980543336, 0.004299466972952359, 0.05909592073294334, 0.0031022494158605696, 0.05451748183986638, 0.04531717728241347, 0.08918098450521939, 0.02391339894529665, 0.023943773194332607, 0.05476942242239602, 0.023694057199463714, 0.05256303593341727, 0.020371734790387563, 0.0679382095404435, 0.07994997358764522, 0.03682139351440128, 0.032732289691921324, 0.08540661438019015, 0.006274837733144523, 0.023303030720853712, 0.011873356288560899, 0.036702523721032776, 0.03119559129117988, 0.04528507197392173, 0.022779336068197154, 0.05794716147647705, 0.028168741991976276, 0.04655002187064383, 0.019183196418453008, 0.022204746783245355, 0.026278306322637945, 0.009083728000405245, 0.0394843455433147, 0.019593574397731572, 0.022824861262051854, 0.08660657811560668, 0.011697321642714087, 0.045462675334420055, 0.034641765159904025, 0.02865275771910092, 0.03882886216160841, 0.04599873602273874, 0.01801653841539519, 0.011411546547606122, 0.03088039931753883, 0.07960645569255576, 0.11580466409213841, 0.009735400453791954, 0.01797987260943046, 0.044357309452607296, 0.06272376122069545, 0.02309733521542512, 0.017542094537930097, 0.03911201376467943, 0.04400770594656933, 0.009296736443502596, 0.032170417107408866, 0.15430921514052898, 0.17747646808857098, 0.11427144636400044, 0.1568149431841448, 0.13134863547747955, 0.11799605548731051, 0.12712606752756983, 0.11831542389700189, 0.1030015702417586, 0.11848403984913602, 0.17195534950587898, 0.11986375917331316, 0.13289089256431907, 0.17955507530132309, 0.18945324729429558, 0.15017710014944896, 0.1543639411102049, 0.18230977904750034, 0.20383983937790617, 0.14440488332184032, 0.11969663493800908, 0.16100580658530816, 0.15578871621983126, 0.136609468027018, 0.11590201160288416, 0.11864284460898489, 0.08440137535217218, 0.07679443588131107, 0.09432604943867773, 0.18882077420130372, 0.12625588453374803, 0.13900900958105922, 0.09988578196498565, 0.09914612048305571, 0.10656341895810328, 0.07166900075390004, 0.15730009996332228, 0.12080166314262897, 0.16294221830321476, 0.13723036361625418, 0.13712776912143454, 0.22001347853802145, 0.11552298936294392, 0.17766132223187014, 0.2146219537826255, 0.1317913265665993, 0.12075141232344322, 0.14155971177387983, 0.12398699807818048, 0.11624857230344787, 0.13385878672124818, 0.1085657556541264, 0.14220659737475216, 0.1761031089699827, 0.13387986371526495, 0.13055447809165344, 0.15676544193411246, 0.14843998476862907, 0.06553380691912025, 0.16419199499068782, 0.1544659270439297, 0.16940739325946197, 0.21406742103863508, 0.1505430234828964, 0.12437123761628754, 0.0886561673542019, 0.11327501662890427, 0.12229567320900969, 0.11608433502260596, 0.1460278415470384, 0.17826425784733146, 0.09234188051777892, 0.08659408777020872, 0.1803280072635971, 0.14151545008644462, 0.13327924360055476, 0.1284509792458266, 0.0910387359908782, 0.10154914270970039, 0.16093674232251942, 0.1751253887778148, 0.11824756191344932, 0.07368795413640328, 0.1186004382907413, 0.16373487655073404, 0.2014304421027191, 0.2061885586590506, 0.10343885107431561, 0.13992807042086497, 0.14920827088644728, 0.1627533565624617, 0.13162716350052506, 0.18511615111492574, 0.13426005112705752, 0.1284487676457502, 0.14589431433705613, 0.15152089210459962, 0.1330189872533083, 0.20446417853236198, 0.10643179164617322, 0.12506846309406683, 0.17002992157358676, 0.1895830489229411, 0.24791572272079065, 0.12583879753947258, 0.12963345798198134, 0.11897256597876549, 0.2664062281837687, 0.13265395449707285, 0.14443449501413852, 0.13874004042008892, 0.17329329333733767, 0.1259348908206448, 0.1247820831486024, 0.10004134353948757, 0.18858871946576983, 0.1603872561827302, 0.11707380341249518, 0.2236480131978169, 0.11222276254557073, 0.11244013760006055, 0.15889856731519103, 0.11531858704984188, 0.16314455744577572, 0.23130003071855754, 0.18899813265306875, 0.21464093792019412, 0.14769963308935985, 0.12051729441736825, 0.10287868542945944, 0.13262409047456458, 0.15160468057729304, 0.16393025434808806, 0.1643669043551199, 0.10807676197146066, 0.11141267124912702, 0.15864565822994336, 0.10836646673851646, 0.1476174031267874, 0.09992527164286003, 0.22656238259514794, 0.11695375360432081, 0.26278463657945395, 0.16005128592951223, 0.12391044554533437, 0.1217909979459364, 0.1139321958180517, 0.17113241163315251, 0.14444351952988654, 0.05120126545079984, 0.05100948335893918, 0.12311714905081317, 0.09161899899481796, 0.1180970469431486, 0.14398922125110403, 0.09865022482699715, 0.123412160173757, 0.11519527179189026, 0.10482289711944759, 0.14810940250754356, 0.1276313661946915, 0.20892472355626523, 0.13516219099983573, 0.29311858699657023, 0.15664177044527605, 0.20219320664182305, 0.17240158806089312, 0.1494322658982128, 0.13433186133624986, 0.1311608127434738, 0.170988405297976, 0.07172824640292674, 0.12258689195732586, 0.15538106934400275, 0.18179532227804884, 0.12490668974351138], [0.04191112020635046, 0.055825702656875364, 0.01808353579690447, 0.032902018865570426, 0.011532933149283053, 0.03493150703434367, 0.014198569897416746, 0.057110367706627585, 0.04582291381666437, 0.027528416976565495, 0.012977687802049331, 0.06054237026546616, 0.03361749004398007, 0.03360470283951145, 0.05038611270720139, 0.053908438349026255, 0.02610844727314543, 0.020126260169490706, 0.028403444339346606, 0.06895162703585811, 0.03816601667494979, 0.018362754017289262, 0.0428858680970734, 0.04422688070917502, 0.10171900546993129, 0.0037198336349320016, 0.019998477182525676, 0.06166440849483479, 0.026731157413451, 0.024386967088503297, 0.05921800773649011, 0.020125775918131694, 0.017723178571031895, 0.014474734180112137, 0.04150002234382555, 0.02876316888432484, 0.039192024705698714, 0.032346038933610544, 0.081874525785679, 0.021757372742285952, 0.02540108405810315, 0.07790324903908186, 0.02691955345653696, 0.030089806095929816, 0.024394713254878297, 0.051911600967287086, 0.05450370015751105, 0.007336827402468771, 0.003532908667693846, 0.0379758339113323, 0.043907230283366516, 0.0372223536396632, 0.027294816718494985, 0.044813021522713825, 0.06871181685710326, 0.047828757160459645, 0.04291646684578154, 0.011435371343395673, 0.05278229233226739, 0.017848666466306895, 0.047755310515640303, 0.09728036122396588, 0.06215602938027587, 0.020562611462082714, 0.11464850933407433, 0.031224512786138803, 0.044413230280042626, 0.07154268721933477, 0.08411547780269757, 0.014078336407692404, 0.02487940619175788, 0.06296884806943126, 0.01589158779097488, 0.036732428561663255, 0.07219513892778195, 0.035566054430091754, 0.041360138638992794, 0.021568407100858167, 0.043151965146535076, 0.0492807765112957, 0.049174760715686716, 0.01378272785586887, 0.127310921670869, 0.017693891568342224, 0.0444649357086746, 0.015146898258535657, 0.06469846775871702, 0.0345138040574966, 0.0689297188364435, 0.041528157162247226, 0.09998692185035907, 0.05122498449054547, 0.12434008225682192, 0.05325943391653709, 0.008652031829115003, 0.04101938153326046, 0.01188261829156545, 0.026090849096362945, 0.028634137233893853, 0.06136421718110796, 0.018017829752352554, 0.01657566612266237, 0.036917427423759364, 0.05470701893500518, 0.05882455443497747, 0.015025212942418875, 0.05680855851096567, 0.021471358304552268, 0.05889432744879741, 0.04641519219148904, 0.04761141550261527, 0.04238962363160681, 0.012468102304410422, 0.038221692593651824, 0.030000284532434307, 0.027757837087847292, 0.014371838187798858, 0.0499722874519648, 0.035205648964620195, 0.02369122961681569, 0.024876246498024557, 0.07739010587101802, 0.02827749074640451, 0.016983069945126772, 0.05648554986692034, 0.04999193952244241, 0.04397337790578604, 0.03657047709566541, 0.0440137989789946, 0.05190092517295852, 0.07364575561950915, 0.01800665857444983, 0.03473362448858097, 0.04609952709870413, 0.09040643359185196, 0.0409638206474483, 0.059326702685211785, 0.038668847701046616, 0.05835199190187268, 0.02758333590463735, 0.01794690640963381, 0.017093583155656233, 0.07362647462286986, 0.02775337121420307, 0.007110649085007026, 0.040493091219104826, 0.006927014383109054, 0.039595489579369314, 0.0862650788621977, 0.03170526120811701, 0.0216824232484214, 0.024716627231100574, 0.05366509183659218, 0.0690885161748156, 0.020140238520980347, 0.06226573736057617, 0.08368009686819278, 0.014938250860723201, 0.012324231411184883, 0.044679134371108375, 0.04115190313314088, 0.0640471292717848, 0.06495173307484947, 0.017815995270211715, 0.041818848985712975, 0.020102997550566215, 0.021047374902991578, 0.0393107868876541, 0.017553846446389798, 0.022829729750810657, 0.01990011107409373, 0.0501237152639078, 0.030634681643277872, 0.06072562508052215, 0.05756124468462076, 0.09249690774595365, 0.01012414853903465, 0.010867363052966539, 0.018566933686088305, 0.026449972501723096, 0.0474993771786103, 0.013494343183992896, 0.04501107847318053, 0.021269497847242747, 0.0790979657904245, 0.02045948633167427, 0.026126399825443514, 0.054849622611072846, 0.050643014546949416, 0.041613593202782795, 0.050336563217570074, 0.05766385031165555, 0.04530400787189137, 0.05565030347497668, 0.008984364631032804, 0.06310957411187701, 0.042674697397160344, 0.0021603573304673773, 0.062093496017041616, 0.031717755264253356, 0.04659909267502371, 0.028804981484427117, 0.019780426773650106, 0.04127372296352405, 0.02509900768927764, 0.02614179567899555, 0.0273900695174234, 0.04975345036655199, 0.06102698156610131, 0.01425416881829733, 0.04201490584819112, 0.04190440748061519, 0.052799662298639305, 0.08097824145806953, 0.07378500478807837, 0.03178998107614461, 0.06737241099472158, 0.018093022299581207, 0.035296639980515465, 0.05702346592443064, 0.03714317761478014, 0.05434440929093398, 0.04665666478103958, 0.020445892041607294, 0.030492892474285327, 0.03845043363980949, 0.023686635722697247, 0.025104347441811115, 0.035132328484905884, 0.05429629214631859, 0.05081987947050948, 0.06656016747001559, 0.035294265107950196, 0.05183682587812655, 0.04211352614220232, 0.018987358489539474, 0.07190400923718698, 0.12390712814521976, 0.04084512154804543, 0.01995731952774804, 0.11073327958001755, 0.03843284102913458, 0.015867319561948534, 0.03185084089636803, 0.04734070229460485, 0.022354779357556254, 0.01851872933912091, 0.06587812633370049, 0.03934352302167099, 0.023506920952058863, 0.06959719161386602, 0.10525654142838903, 0.02473732572980225, 0.010821882387972437, 0.06149262728285976, 0.016954784841800574, 0.045530644929385744, 0.015682502526033204, 0.048551349245826714, 0.04422060213983059, 0.03434287260461133, 0.05260624748189002, 0.027495380272739567, 0.06962704079342075, 0.056276286486536264, 0.02553200818510959, 0.027275754655420315, 0.0035162117364961887, 0.043772215067292564, 0.0257946672354592, 0.10796046000905335, 0.039438744279323146, 0.011560595776245464, 0.025411529786651954, 0.023151383975346107, 0.04065674962475896, 0.0334682923858054, 0.04939938284223899, 0.029948618066555355, 0.03767836627957877, 0.05411984653619584, 0.027332230238243937, 0.03596875489165541, 0.030951289263612125, 0.01187476358609274, 0.026441799600434024, 0.057239308443968184, 0.04372926698124502, 0.012694047309196321, 0.021625866029353347, 0.03220015125407372, 0.05996174360916484, 0.035796476440737024, 0.05765448811871465, 0.059899262196267955, 0.04098581790458411, 0.0516254770627711, 0.08060431035119109, 0.08146797728841193, 0.04735417227493599, 0.05510195282113273, 0.06790033032302745, 0.08101963103399612, 0.02878349074308062, 0.031365071845357306, 0.04259791108779609, 0.055271184755838476, 0.04296222025004681, 0.025072687421925366, 0.075312099797884, 0.046533924687537365, 0.04051904412335716, 0.01502056431490928, 0.012070257344021229, 0.08819882626994513, 0.026352437598688994, 0.11756546882679686, 0.05028635321650654, 0.018589762148621958, 0.030265040149970446, 0.03288580664957408, 0.0543710301280953, 0.017568132789165247, 0.01780276834324468, 0.03682549016957637, 0.015258969979186077, 0.034126892787753604, 0.02988656338857254, 0.08404210166190751, 0.07511784264352173, 0.009609303069737507, 0.010873242717934772, 0.054263956772047095, 0.03773809061385691, 0.05864751881745178, 0.1029494492104277, 0.07221547377412207, 0.04537360277026892, 0.045169263539719395, 0.021847090974915773, 0.0589641338592628, 0.03182538894179743, 0.015506324089074042, 0.034848315990529954, 0.04127119595068507, 0.030766561285417993, 0.03151974284264725, 0.02497025991033297, 0.031794745664228685, 0.031475362411583774, 0.04411553258250933, 0.01027126818371471, 0.14243491168599576, 0.09487926115980372, 0.16025883494876325, 0.0838599786220584, 0.2018382225651294, 0.20404014503583312, 0.10239705385174602, 0.13229517062427476, 0.18093788938131183, 0.22343464574078098, 0.12022101422189735, 0.154216609953437, 0.10742834754637443, 0.1513045560568571, 0.10851928236661479, 0.08966390741989017, 0.1299787050811574, 0.12519841315224767, 0.10758575706859119, 0.18973444704897702, 0.14213039365131408, 0.1416338820126839, 0.16133674507727847, 0.1280201625195332, 0.21054324373835698, 0.08906907605705783, 0.16045255033532158, 0.15786557196406648, 0.16742332081776112, 0.10377808677731082, 0.10467062325915322, 0.10685003639082424, 0.12287246296182275, 0.07402195027680136, 0.11590333262574859, 0.14127560280030593, 0.1448577269911766, 0.12715299264527857, 0.14936536870663986, 0.14500502846203744, 0.16214748204220086, 0.14529167558066547, 0.16835805581649765, 0.13067834253888577, 0.13967343955300748, 0.14922195608960465, 0.12171704292995855, 0.09638432922656648, 0.11109639017377049, 0.20201601146254689, 0.1545179812819697, 0.11780881162849255, 0.19619531754869968, 0.14736597833689302, 0.0888756501080934, 0.16840092226630077, 0.1369459874695167, 0.14542002259986475, 0.15899224119493738, 0.12081629829481244, 0.18567856546724215, 0.23959615820785984, 0.15607071749400347, 0.12653021200094372, 0.4415653401520103, 0.1698712949291803, 0.08192200097255409, 0.1491649294621311, 0.19712929555680603, 0.1434802563744597, 0.04806974364328198, 0.292563698021695, 0.07382372263236903, 0.1436275281594135, 0.18304322875337675, 0.2572697668801993, 0.11159112807945348, 0.08221485986723565, 0.14065555325942114, 0.1683747986680828, 0.227531389973592, 0.13576653669588268, 0.22708623495418578, 0.07544807609519921, 0.09303405196988024, 0.11884175502927974, 0.1977005711523816, 0.19286878901766613, 0.13902023085393012, 0.14631744241341949, 0.19138085714075714, 0.09740664507262409, 0.2355680923210457, 0.12080743705155328, 0.15458793612197042, 0.07915344132925384, 0.05577593794441782, 0.08556555272662081, 0.1424095599213615, 0.1310967653989792, 0.1649748272029683, 0.14268139377236366, 0.23056686302879825, 0.25778704381082207, 0.09096820227568969, 0.11200373992323875, 0.14276439556851983, 0.18113046186044812, 0.14315230131614953, 0.09028933753143065, 0.4779311700258404, 0.13139313465217128, 0.1445965058519505, 0.11244445689953864, 0.07900914555648342, 0.11420541006373242, 0.11537391415913589, 0.1429077042848803, 0.1328920354717411, 0.16429638548288494, 0.14558773313183337, 0.17142998316558078, 0.16328810364939272, 0.1936699522775598, 0.25264007155783474, 0.2044882538029924, 0.1333339250413701, 0.14536404982209206, 0.11980924100498669, 0.14183834369760007, 0.15283762535545975, 0.18800772173563018, 0.06992539158090949, 0.205882036825642, 0.18913274339865893, 0.12464885279769078, 0.10840301009011455, 0.13699789327802137, 0.17787560995202512, 0.13223891583038494, 0.184097048768308, 0.10683223968953826, 0.1710523190558888, 0.1436776082846336, 0.08113317962852307, 0.17496216081781313, 0.07126057462301105, 0.19167240243405104, 0.2084736610413529, 0.1352264461456798, 0.1432288612704724, 0.08361906264326535, 0.16214043163927272, 0.2609075966756791, 0.15324721665820107, 0.11465302159194835, 0.15043766819871962, 0.10712096482166089, 0.11113820277387276, 0.15635656309314072, 0.16530830383999273, 0.16043785581132397, 0.22311429027467966, 0.08062658220296726, 0.12433376658009365, 0.09196625731419772, 0.07261552847921848, 0.1531221647746861, 0.07831793147488497, 0.07217793594463728, 0.12307700628298335, 0.1338335537002422, 0.11691163672367111, 0.08975252727395855, 0.09928751445841044, 0.21048220951342955], [0.004311525017328677, 0.03667300479719415, 0.05348321741621476, 0.03538171236868948, 0.022480543702840805, 0.06456120012444444, 0.03927737910998985, 0.0499711148586357, 0.06997809148742817, 0.008344640755240107, 0.06330325981252827, 0.07566625266917981, 0.015729795886727516, 0.09460948305786587, 0.037418699939735234, 0.03551024492480792, 0.009212857057718793, 0.045146060292609036, 0.037530534173129126, 0.01988324391277274, 0.0920486134418752, 0.052242524616303854, 0.03597830633225385, 0.029291336832102388, 0.03932383013307117, 0.019114742572128307, 0.03236667806049809, 0.10208265041001141, 0.03512138922815211, 0.03852324945910368, 0.06018120409862604, 0.003195664007762389, 0.07334933441597968, 0.04434806600329466, 0.059487258913577534, 0.0388770238350844, 0.041440505810896866, 0.029614946615765803, 0.05276576099277008, 0.02482393065292854, 0.0034968855152328615, 0.02165310284908628, 0.0445090452558361, 0.04183556586212944, 0.034966183884534985, 0.0375086074200226, 0.039893469293019734, 0.018488002569938544, 0.05719328786653932, 0.04608921866747551, 0.05063407908892259, 0.029806912389176432, 0.04624841305485461, 0.03404654788027983, 0.003917424191968166, 0.0204869235312799, 0.002239807949990791, 0.026995699663530104, 0.06488571161753498, 0.018950694538943935, 0.0463703182322206, 0.048812069435371086, 0.09834715398028493, 0.0525388382084202, 0.07840209844289348, 0.07088733371347189, 0.05065679251856636, 0.06725098079186864, 0.03408299475267995, 0.045878671371610835, 0.028132638362876605, 0.053865449444856495, 0.04547077958704904, 0.042158277647104114, 0.07312966612516902, 0.03784526044910308, 0.04505374454311095, 0.04213875545246992, 0.026363768338342197, 0.02713723835768178, 0.06552687525982037, 0.025166262967104558, 0.03466398506134283, 0.012767435509886127, 0.046321989575517364, 0.040855596962501295, 0.041624851583037525, 0.037455881538335234, 0.009500158193986863, 0.005970348920527613, 0.0363006247789599, 0.05075926826975774, 0.035687826020875946, 0.0068936478874093154, 0.03610700216086116, 0.03390013698663097, 0.036566822018357925, 0.035658793203765526, 0.04369338043034077, 0.05806592365843244, 0.007763226494716946, 0.05667649704264477, 0.030241024251154158, 0.015238476498780074, 0.0062640520081913564, 0.03836122006759979, 0.10006696247728541, 0.061430528076016344, 0.0320172563806409, 0.030293991330836434, 0.07954322471050546, 0.029467223976098467, 0.07793906508595683, 0.07201061132946052, 0.07507477581384592, 0.007798598180670524, 0.035239053031546064, 0.07590209977934137, 0.026313972084608395, 0.03457218510448001, 0.0668955068977084, 0.030527354101650417, 0.023743313540762756, 0.039866941224318, 0.05421220310381614, 0.024258824159915093, 0.01829297914810013, 0.04605725065630395, 0.011342815323587274, 0.011389490846340777, 0.028186290073790587, 0.03553722199285403, 0.02770081046037376, 0.05086074583232403, 0.05621616139251273, 0.06330585732939653, 0.07846929249353707, 0.03734592864930164, 0.03740156374988146, 0.05729802345740609, 0.030371727589226793, 0.0346415276726475, 0.03989801865827758, 0.07581570636830293, 0.02905063607613556, 0.03917329289834015, 0.04744714482512791, 0.05043574754381552, 0.0587546997849131, 0.02439184670947725, 0.02678517277672654, 0.01860949028923642, 0.04232098610373214, 0.045961996002006344, 0.05922686526901089, 0.06168179701489862, 0.008498319130012533, 0.04659087338950485, 0.08099444254185073, 0.015409743773489026, 0.052773130519199185, 0.04944280590279959, 0.021623088541673496, 0.018862323304347228, 0.03917928574082907, 0.014503103702736553, 0.014384603127837181, 0.06351361414999701, 0.007359872015513247, 0.025131613947451115, 0.040538544053561054, 0.01776413027982926, 0.03462456588749774, 0.04463410085008945, 0.10272827435983345, 0.04226468678098172, 0.0470624488661997, 0.029074663107166998, 0.034534432052168995, 0.03453708523011301, 0.008528763883077772, 0.03757341546588577, 0.033659807304502465, 0.07049810694297776, 0.029016532535024453, 0.02478421462001279, 0.04809889149328228, 0.03043487322429428, 0.043766686067101546, 0.07354148387094028, 0.09879509947495535, 0.07282664722879417, 0.05094153602840379, 0.12718877900624648, 0.03360997208801564, 0.0197170863248175, 0.04464615703909658, 0.028355716822261456, 0.0788323585584294, 0.02570865603047423, 0.061127798617235385, 0.027980149279756006, 0.04055229605000932, 0.046560137343476526, 0.021327565336832777, 0.01719534644507803, 0.029894853178120684, 0.09791302727535367, 0.07145793395466171, 0.012357661453279434, 0.04064247441419866, 0.03475080520729534, 0.026469077238289174, 0.027824110875371844, 0.031749096160638146, 0.06537306515383534, 0.030397218506550416, 0.01906417077407241, 0.049777878157328814, 0.04500654024013784, 0.045242832638905384, 0.01565817121445434, 0.02814958344970364, 0.00931423535803333, 0.04918284641462378, 0.04238068817357998, 0.0632377875444945, 0.022140111286717, 0.030456547647190746, 0.015932619280647486, 0.07133859660825692, 0.045599211953231134, 0.04169378225924447, 0.01945347547007259, 0.05809241090901196, 0.05654899978253525, 0.017112246314354707, 0.01488390616941615, 0.04653094496461563, 0.058622987126000226, 0.061417239921865985, 0.03158847684971988, 0.05148051706783008, 0.012100885778636439, 0.059077103578601964, 0.04106774358660914, 0.031069890028447844, 0.03256118383433204, 0.05392788632889278, 0.08823337324429303, 0.004837517544729053, 0.03145467875583563, 0.04802989031304605, 0.017640553414821625, 0.009525013647362357, 0.04350237759354059, 0.014584638829546748, 0.02142039687896613, 0.09817026308155619, 0.014832504093647003, 0.06085806504415814, 0.06619641120778397, 0.062206220827647485, 0.05116010594065301, 0.036427391023607925, 0.015747731740702875, 0.04981435842637438, 0.03461033891653642, 0.024839851575961802, 0.008131475533446064, 0.013375061498663854, 0.026047635692521, 0.06656616402324289, 0.03653847197711002, 0.08788681254372932, 0.057563808804843575, 0.03969168676121626, 0.08036956161959097, 0.034692004846874624, 0.023510872888437007, 0.03148613097437192, 0.05161821885849349, 0.043933346460107714, 0.05621140051516704, 0.07084817058057524, 0.024470141433994286, 0.0551698370691156, 0.0073685305596882245, 0.082453541981522, 0.021071611590741668, 0.11413131403969601, 0.034718848328338936, 0.021334094381018076, 0.05093998865049798, 0.06296692590694875, 0.035424894231255166, 0.008771756019996246, 0.006128959794295952, 0.05990590070723556, 0.05160603279364295, 0.04164389880315866, 0.033524773534736596, 0.050844596698880196, 0.04517690395005047, 0.02928946661995724, 0.05839869896590244, 0.035080148081760854, 0.07376220601145178, 0.020427347626537085, 0.022285867235041223, 0.027701838334905915, 0.027802536642411724, 0.04744708916405216, 0.053302415399230085, 0.05501992694917135, 0.01807506418117555, 0.04426958388648927, 0.051191209349781275, 0.03389569523278624, 0.042327476185164414, 0.03550587367499247, 0.02974560728034703, 0.06528093494125642, 0.03248728819016833, 0.01294376887017279, 0.04847015457926318, 0.015295598677766975, 0.0654005394608248, 0.03014968999195844, 0.03812909111729823, 0.01295614696573466, 0.029884054929425474, 0.13834800833137706, 0.032913722534431145, 0.06099663514760323, 0.032150560946320184, 0.043933428096352145, 0.01221542050188873, 0.046748772729188204, 0.013441480932669947, 0.02291482811415335, 0.009812076368689304, 0.01137243536504684, 0.04165791797277052, 0.04026709240861237, 0.01482864492572844, 0.032982163393171504, 0.04557773419946898, 0.0147554635987035, 0.03879194402543362, 0.08460839002509601, 0.036549207143252715, 0.11615121737122536, 0.20280393480788916, 0.11196154882782139, 0.06957474164664745, 0.07828916583093815, 0.1390726413228549, 0.12279402537387796, 0.12706718553090468, 0.2545205847127363, 0.10998949175700545, 0.14651653094915673, 0.12482166930567473, 0.07712706646998413, 0.17524487455375493, 0.13640099874464795, 0.12786109058652073, 0.23807159392163157, 0.257245750981383, 0.1546347507974133, 0.06149172557343263, 0.1924376012175344, 0.10021672787843272, 0.15447560464963317, 0.127018426428549, 0.1862966112094, 0.11327203319524415, 0.17279210616834462, 0.15195018000667915, 0.16734328761231154, 0.13731081242440268, 0.1343794330023229, 0.16445652610855177, 0.14166175707941875, 0.13080375065328553, 0.13701631338335574, 0.13363222387852147, 0.12646993476664647, 0.18997940031113103, 0.15777627675561234, 0.14888516947394237, 0.06695619973470457, 0.08769605832640082, 0.11192696474608965, 0.10939319094177336, 0.09773761325050145, 0.17808847274864092, 0.202978948072996, 0.10907474279520102, 0.23672556068049744, 0.14223488804418594, 0.3067950624972582, 0.22474018740467727, 0.12447877481463365, 0.10599911955068819, 0.17106293176766485, 0.07023574289632961, 0.18010240921285003, 0.19071764429099858, 0.15123188495635986, 0.0896140573604498, 0.12170742469606921, 0.16013476270018145, 0.13676313712494448, 0.17625328997382894, 0.1585933961905539, 0.256919443490915, 0.11757358050090261, 0.19435051653999835, 0.16327734250808135, 0.13253691780846566, 0.12488067004596815, 0.11487740994198248, 0.22549956775037572, 0.13410886080237105, 0.1873338664881885, 0.15497121086809784, 0.13988550083013251, 0.10821422998560593, 0.09934955058270134, 0.17102849611546844, 0.13076613860903308, 0.1346513707539998, 0.25378467107657343, 0.14698430662974715, 0.17882955173263326, 0.14648651849711314, 0.2076205177581869, 0.1040601622662507, 0.13380888471147045, 0.14130310679320246, 0.10117849189555272, 0.10315215942682698, 0.0773847104574088, 0.08639179315650836, 0.13557354861404747, 0.08813284934149124, 0.14485762309050187, 0.0753768596041482, 0.18495274503948167, 0.2216323697939515, 0.0898348017653916, 0.15072964393766597, 0.17232513200724497, 0.11538770326296799, 0.0967801759543363, 0.10605964169371873, 0.19671777467010543, 0.19249057571869344, 0.28857536672148854, 0.13205915282014757, 0.1363692941959016, 0.09115183929679915, 0.18748370610410348, 0.1943917354219593, 0.26782963774167, 0.11340464756358415, 0.09956462497939356, 0.22122991795185953, 0.15615196782164276, 0.19480012444546446, 0.12476691365009174, 0.13330827641766518, 0.1745283606578596, 0.1827403879724443, 0.4502836457686499, 0.11151009297464043, 0.20478591439314187, 0.1899957424029708, 0.12436547855031677, 0.13034078408963978, 0.11400127492379397, 0.16533625312149525, 0.16342930466635153, 0.08019151297048666, 0.26942308817524463, 0.10130476832273416, 0.14704838366014883, 0.1450389446108602, 0.1728309056488797, 0.11323636557790451, 0.12539245508378372, 0.21633110503898934, 0.15898961399216205, 0.21099665143992752, 0.15736957982880995, 0.09370922824018635, 0.15633637667633593, 0.15886482928181067, 0.12094923920813017, 0.11967569895205088, 0.13039953249972314, 0.11824425935628824, 0.09246066867490299, 0.08015260216780007, 0.0738865602761507, 0.25987277564127, 0.20114382466999814, 0.1319387467810884, 0.1429788168752566, 0.0979937803640496, 0.13025554100750014, 0.14717227779328823, 0.13859560363925993, 0.10052794750663452, 0.17873485368909314, 0.10098102124175057, 0.09323020160081796, 0.19227768323617056, 0.14363404421601444, 0.07586476232972927, 0.10314686791389249, 0.18597051152028143, 0.13732008927036077, 0.11125326534966007, 0.2178064500913024, 0.11705375800374895], [0.008831659397401381, 0.05167174254893325, 0.0675784089253284, 0.02896011632401496, 0.0167619433341315, 0.026478441286599264, 0.011835422337753698, 0.02626004021294648, 0.010324775175831746, 0.03820351368631236, 0.06324253728962503, 0.07041969904094003, 0.07933981687529013, 0.03119854132819455, 0.015023878931970103, 0.02307721002580365, 0.0318822522967821, 0.05627020087558776, 0.020866374361503404, 0.07326916020247154, 0.008528172020305647, 0.04036208731122315, 0.03562792357115541, 0.054010272142477334, 0.03482483443804085, 0.021284173817548435, 0.015960639066179283, 0.05802531333756633, 0.053057350814924575, 0.03458725812379271, 0.03662774121039547, 0.028687454978353344, 0.024840267178660724, 0.05142232526850421, 0.024072402229649015, 0.09688268881291151, 0.02565114886238007, 0.05609467552858405, 0.010216228656645399, 0.04563605958537664, 0.06831693492131308, 0.02641743303684052, 0.041293616231996566, 0.006496894347947091, 0.06023712863679975, 0.03635224486060906, 0.012814542405976681, 0.026600684141158126, 0.02060337021248415, 0.1171401291503571, 0.056142410467145965, 0.06378705846145749, 0.026654584471543785, 0.011045047122024698, 0.04799955502676312, 0.07586785708554089, 0.04106488260731567, 0.049643211750662886, 0.01899515660625184, 0.017773006366041955, 0.028303052167757414, 0.07392000887193717, 0.02186603614973137, 0.037363973970059305, 0.027428082321421243, 0.055524257113575004, 0.0468295332393609, 0.06737865245668218, 0.03335828754643444, 0.058947921643266454, 0.050720246144919656, 0.11741913214791566, 0.056140885353670456, 0.030282840561994817, 0.04206318626529537, 0.028507595488918014, 0.054494812939083204, 0.012989657716389047, 0.03028897070180392, 0.014280708019214217, 0.04243648283591028, 0.037865509948460385, 0.019214082749385852, 0.044006815369357355, 0.05956819011771586, 0.032565684959990904, 0.0953065897920169, 0.054785026077297516, 0.015272379660018487, 0.048547746118856594, 0.0677309648017399, 0.055647104818490334, 0.049303942651022226, 0.03877880430081859, 0.017490838108642492, 0.03605411300668493, 0.036640253820223734, 0.045440021276590414, 0.01715423888526857, 0.11982711192104034, 0.014399136234715115, 0.017501705005997792, 0.02268776803248329, 0.02953413044451736, 0.06072098665754311, 0.027002171191270463, 0.021623520842695143, 0.006430089924833737, 0.03447041068284307, 0.030974687324487604, 0.01446584974473808, 0.07660754083190113, 0.03680723333673086, 0.04132188463700004, 0.08296541607705876, 0.03836856361886021, 0.03219346079276875, 0.04666266875574365, 0.009030259971041232, 0.044693914242088795, 0.040401465666946024, 0.016399797532358207, 0.061116209981264547, 0.06319037172943354, 0.04596135033352766, 0.03960054360504728, 0.0184902030377998, 0.03008153486007359, 0.03844147962809075, 0.03177055164997, 0.03657091125205625, 0.09642873192206025, 0.02214301308413269, 0.03260915997088887, 0.02062555300653912, 0.029351293087529484, 0.022249448193178978, 0.04052414638863411, 0.04190718311292585, 0.03543320999597199, 0.0586134987679543, 0.021266560797812417, 0.0309305796326953, 0.0438713140465552, 0.010031492329289904, 0.03489455921226181, 0.033015329972840846, 0.07967820652993396, 0.03305516474938486, 0.023825330135878175, 0.060821822262369096, 0.03565498598618433, 0.034493929342716, 0.032055187548394315, 0.017765022712410428, 0.01078943198081106, 0.01768936446751468, 0.012113379834772786, 0.0386532477568835, 0.06900351800140925, 0.022123383278085385, 0.04665167012717575, 0.023030636548355687, 0.06691702175885439, 0.04071566501806956, 0.060350662388373166, 0.0506212176696863, 0.045968319100211374, 0.06615542239160277, 0.017748938516888302, 0.01431028445949778, 0.04320698426454328, 0.06513153319247067, 0.03403355658520013, 0.04592150813550688, 0.03935813219868578, 0.030475333260255866, 0.035029058635700494, 0.045723187722614966, 0.06101077306084335, 0.027162990882061422, 0.03884040626871865, 0.03448651157668792, 0.013514375605154783, 0.010230230200249935, 0.037446448841365054, 0.04413744078192394, 0.03769277878745925, 0.015497845051868353, 0.05770774092525244, 0.015879804341238923, 0.013404589699348435, 0.04587540592183359, 0.024282899430545513, 0.1536077371565625, 0.006486056672656559, 0.04888366071099881, 0.039080001224647276, 0.022378778558049817, 0.042435165523784235, 0.031401848973473534, 0.03879889423842542, 0.055425840910174884, 0.031941520210239105, 0.02228975237812847, 0.020178666927677114, 0.06514460241305642, 0.0358741644595284, 0.02706161165406229, 0.042179840747849084, 0.005291632605803898, 0.026497388316784054, 0.060112069331808016, 0.008370708692382323, 0.05841237674758304, 0.030574406264349818, 0.023197308073577005, 0.046446251071756706, 0.007600611734233098, 0.0336726798559539, 0.05488408794917632, 0.042068136390298605, 0.010860460151889129, 0.048847414218471386, 0.05058027709310409, 0.13063966180197895, 0.07708873454248533, 0.0353368458308978, 0.09912039022310637, 0.011424376425566152, 0.0587044823623728, 0.007093596850609174, 0.06552545033628121, 0.06753848138032481, 0.0507429002027493, 0.029156455202610232, 0.01999938816879876, 0.03598682989832014, 0.029447738888848107, 0.047397350426763296, 0.06626696718740277, 0.04135084695008118, 0.08732927410164848, 0.049222796224057674, 0.07553030605777167, 0.03750993957510218, 0.03628514357842505, 0.04000060573162045, 0.05965344433207065, 0.034416575290379114, 0.02223528801550856, 0.03562986799806822, 0.039088732592063025, 0.032533498015254736, 0.05991382313368376, 0.06419751807698049, 0.00998301524305134, 0.007971703198563773, 0.01719488631351851, 0.03822666498308536, 0.11129173828521743, 0.02921115890785586, 0.01763050844601821, 0.017627083434490487, 0.018734729565039743, 0.013357860370888375, 0.029253073553263675, 0.10105910259881057, 0.03490430361125618, 0.060650660743704066, 0.042644748027669266, 0.0527931351098232, 0.06876370040117763, 0.026479795706109144, 0.033427826783736236, 0.0721785519272089, 0.024633348984934855, 0.019066554923483636, 0.0641075920430012, 0.03439601408899762, 0.040320104017155245, 0.05747884773882106, 0.0570496340515092, 0.05288386266329326, 0.023854329556343146, 0.04949889000272378, 0.03132513687887695, 0.05691786944225896, 0.009339676180388778, 0.054552997316932306, 0.03905466801370494, 0.013121326774125919, 0.03352368999912869, 0.049397846596548334, 0.05522054430912249, 0.018433150435157586, 0.0034666455485421466, 0.03868955362122506, 0.055601982239750214, 0.027074252284364775, 0.0075951342205371475, 0.07214286946691573, 0.05140455083164852, 0.06579299457371235, 0.0697950333415065, 0.05826221800816711, 0.009308194275945425, 0.048369619544246234, 0.07212581491330639, 0.02870383788831532, 0.038043992753955536, 0.06001737499900628, 0.03012983939697733, 0.010430887450638693, 0.05848885506566148, 0.025821558956522495, 0.08307373995194212, 0.017548130053910427, 0.027327089010213967, 0.0897766396519728, 0.049679703151923604, 0.061520569142885506, 0.05414538754848763, 0.07628063220181502, 0.0826949329348281, 0.019717622526513878, 0.013312220144143794, 0.02882027158193523, 0.029833369953848887, 0.016673193604219705, 0.0411993263696786, 0.02977131156512769, 0.04095889649761375, 0.040332705684704706, 0.0534284320747247, 0.04801682851393707, 0.03817349010205362, 0.04171546781435609, 0.026724218332674354, 0.029677517086383887, 0.07845539948903024, 0.024220831764978357, 0.053834475911571644, 0.028700871152977925, 0.04395726587972604, 0.033961252847802825, 0.023894318328530062, 0.05182369357498828, 0.06927148526301607, 0.0987931847339496, 0.022712116042384878, 0.005529739555640845, 0.11313806069665588, 0.21541099034948274, 0.23034962156089023, 0.09669437626143917, 0.10280039627104998, 0.12054336606524885, 0.10390247814939357, 0.08983014107798226, 0.10319887020159513, 0.12823918514186516, 0.12527181155746803, 0.15615413489285856, 0.14750591770280153, 0.14191426540492103, 0.11411097919335589, 0.10657023929525167, 0.09573838615324348, 0.17982034856686369, 0.2144013874931261, 0.15402951452415437, 0.12725736829452217, 0.09729135985253379, 0.11538361402926967, 0.15610288217430934, 0.14182872546371073, 0.15474926418391988, 0.10556334527791478, 0.12244054043549113, 0.18794219009578228, 0.08929618808906525, 0.1603163217077963, 0.07707159835263155, 0.1024897703609895, 0.12765722261974588, 0.09433573446585797, 0.15646574785932899, 0.07554925308795646, 0.2288001507986337, 0.09016599258757196, 0.17710995103698224, 0.09116291956161149, 0.13999329035868868, 0.09630325701436959, 0.11497253100969829, 0.30680735246278346, 0.144662082020659, 0.13411110208835453, 0.10666469985153526, 0.13710272905882448, 0.306205025408417, 0.1678990523214452, 0.11949565392569639, 0.1936528828809969, 0.1598320109769702, 0.1273932703770697, 0.16677438688930124, 0.1307344637461938, 0.13697405549464747, 0.1040504252887331, 0.15109375643078238, 0.09144723633653484, 0.2223650476662442, 0.1341914915246889, 0.1464325049892068, 0.17223729140823707, 0.16315732238581404, 0.14400911080883816, 0.09307236163294874, 0.15578145801555365, 0.10903572067036293, 0.1966225719661452, 0.19329371309140697, 0.16879580420209095, 0.13387211569352075, 0.07569377150502987, 0.12845565477618948, 0.1401835770229809, 0.09419903828529641, 0.08437816097284667, 0.15629006666131318, 0.19144008052535355, 0.19593227072618902, 0.12552586355013773, 0.1258168151252903, 0.11935515052755363, 0.11313590104691684, 0.20849819644354284, 0.18025618221145123, 0.20341019524494186, 0.10541572468355298, 0.12674340134253725, 0.18902059004176408, 0.13013786607189104, 0.11058517658966593, 0.13673591514816508, 0.20366589480545372, 0.20542258804198354, 0.10030331424786709, 0.10043394708191045, 0.30203106813132763, 0.17414576868759468, 0.15352623449871317, 0.1426543202251196, 0.11755752784665674, 0.1177549985004589, 0.14421474508708343, 0.16548628569580615, 0.20660085137933493, 0.11649382984614931, 0.08604549962910824, 0.14131643576547503, 0.1517769182100892, 0.13452416664222255, 0.20718615356599912, 0.14437007659580559, 0.18534185306634754, 0.159539204032626, 0.1655048393877223, 0.12691897863987833, 0.1539278551354073, 0.11444737989222631, 0.1316762194619514, 0.14622569811763242, 0.11852164447191171, 0.10658537910785526, 0.1659415487665683, 0.13059559307293966, 0.173935444036033, 0.19522341579431668, 0.15365854458650574, 0.09380437899380922, 0.21232595667243004, 0.1035628342651762, 0.1077914952475112, 0.13346862484468147, 0.1974604418501258, 0.09176631530863233, 0.08634680416435003, 0.15209660574328154, 0.10609971024678089, 0.1239724965125788, 0.1327099569607526, 0.09417862180271186, 0.18092925078235567, 0.14648353506345302, 0.15447333367774263, 0.10692901574657299, 0.2511591900838539, 0.20231981703545898, 0.05014397589548025, 0.12423975131241605, 0.10007698889239691, 0.11417092988267541, 0.10682812819140963, 0.09606856023310684, 0.11438973728218116, 0.1788769304403104, 0.16349885874660686, 0.1487652532523498, 0.1919318424188532, 0.11632010049652308, 0.11867277542478405, 0.12119763603550382, 0.14407010050490499, 0.1460483396658674, 0.10875690320972353, 0.1058983730035834, 0.1301395136397332, 0.1867066478007473, 0.16584751865593717, 0.12295780994463712, 0.1600714129745029, 0.17990980704780668, 0.18804217223078012, 0.08893956386600621, 0.08961819112300873], [0.05077801120933145, 0.020508169363893103, 0.0707889991463162, 0.015175077605817933, 0.028626684215851128, 0.06344718451146036, 0.06467944651376456, 0.05663454343448393, 0.07044276499073021, 0.04246846197929699, 0.03746533649973571, 0.061129668829380535, 0.09978041183785535, 0.05334764558938332, 0.040347956819459796, 0.031158094279817306, 0.03786677902098745, 0.05230544389632996, 0.03770837502088398, 0.028275741133256815, 0.03314036701340228, 0.007930141073302366, 0.024262679617095273, 0.007191468039309257, 0.01723315886920318, 0.04551848855044227, 0.037478168233064935, 0.0012974435571777576, 0.041382380804861896, 0.015809560063644312, 0.03214831594959833, 0.049091662440332584, 0.020359812187962234, 0.05935597298957873, 0.1312428794335574, 0.08048659088672139, 0.04410343928611837, 0.03433424513787031, 0.025418956829525996, 0.10426566295791417, 0.055164044606499374, 0.0368093707220396, 0.061545319767901674, 0.011249539420532528, 0.013410445244517177, 0.016593347791058477, 0.07815474062226713, 0.02483699245203752, 0.04173414024990052, 0.03012889686942799, 0.01716570506687276, 0.04686556079832371, 0.04234913947584573, 0.033238278556382284, 0.04909064569801558, 0.020158840452495497, 0.00903510526768514, 0.022638309455942363, 0.013744597235927358, 0.025809198486967944, 0.05034375462855678, 0.02448737039230764, 0.017156207431980874, 0.03926576449885033, 0.027409721587901004, 0.03634348380728625, 0.024659580194565933, 0.006349857731038355, 0.04846086660108995, 0.031241003307513893, 0.03232488772482611, 0.04316651124099735, 0.03816294789430685, 0.07167614763602614, 0.03559697601303924, 0.05347406302462332, 0.026295520437997766, 0.03043654862267431, 0.057529566111043096, 0.04100429738173261, 0.05957117355137598, 0.04260652742232196, 0.0386062401230447, 0.06264539784751832, 0.04284387738152873, 0.028559835263877176, 0.03529933026584331, 0.007461153836629819, 0.025848369041341357, 0.022354771936079487, 0.00799614212155575, 0.04001715191407129, 0.044527216741698794, 0.023803156618669163, 0.09209751355228946, 0.024441546484013088, 0.0203898969994043, 0.014862063835607842, 0.05131718149641529, 0.020191925395920407, 0.02161713837267598, 0.03556693758582696, 0.018599855357024353, 0.08741858415305614, 0.040162356817745604, 0.05348577040422242, 0.0397100252303062, 0.03952709324948955, 0.04230945683957543, 0.041140080720651895, 0.018724671608651988, 0.02266968003823422, 0.021887719849473797, 0.030033892689971253, 0.030358994190464728, 0.042667539382819086, 0.04998856646125205, 0.039499025224358775, 0.039986241463338956, 0.04205465527775232, 0.027499237585288938, 0.11081111602834426, 0.07522172847529873, 0.015587108719046228, 0.05517826786672231, 0.030409219034481794, 0.004259384968463564, 0.02625145727506606, 0.02717100051086163, 0.02060734997940017, 0.016710143281670753, 0.030281218969321344, 0.07219023333163932, 0.0624542948207818, 0.04454028225154616, 0.06583604656043462, 0.056493936135666445, 0.03218629535695072, 0.04411997062561568, 0.04571062687318772, 0.021194958389969543, 0.010247985155729111, 0.025465511753282044, 0.060786488611483946, 0.06649637245573103, 0.04043898865347728, 0.03602473880164325, 0.06300907989498228, 0.026149877667194232, 0.06331052543828264, 0.023569272489112336, 0.03457005885138642, 0.01428064957508468, 0.04903571192699019, 0.010467041174706537, 0.0436152248585131, 0.023597880426677875, 0.02005318645387888, 0.062438331224257126, 0.07900642929598689, 0.010736966778495116, 0.009422074981557671, 0.0714820611756295, 0.023219871218316257, 0.052383699658093974, 0.008073051812971244, 0.05808308211271651, 0.07119568865164183, 0.057746722231968306, 0.07402724921121262, 0.04295909951906651, 0.10604919967590831, 0.042858527376665734, 0.04636306744941976, 0.0554772049508756, 0.010679547740437556, 0.024950823062681593, 0.05175397622224409, 0.03256936601246707, 0.014921325255272677, 0.03697657288284972, 0.022993427119217813, 0.008083787906798534, 0.05221935847657733, 0.08178213582141325, 0.04341948340879753, 0.046718248195247725, 0.05543527731788345, 0.08229493018006906, 0.0824010647193063, 0.034838757128454745, 0.07685214528464712, 0.04352172167273238, 0.06419106139219366, 0.0058438192354515195, 0.030280209648481105, 0.05027162529586349, 0.03909126331564039, 0.019636544748209417, 0.005498712680491735, 0.04971610920620151, 0.05256198579445481, 0.021411184970929753, 0.038304627596517093, 0.03056950994505314, 0.10004950716393068, 0.017178952402900904, 0.019215118045394775, 0.05469790907227434, 0.06103331208578311, 0.07330965920118615, 0.023879540312918834, 0.06556802734849043, 0.0049819937521533575, 0.03205554749001749, 0.05821423445013352, 0.04336332880484406, 0.020431390476005618, 0.06239789159735665, 0.004669330646720482, 0.008307356183649972, 0.03862247089273296, 0.030837842714390717, 0.050403950226609595, 0.07181374923675321, 0.022385084957932122, 0.022098558438301552, 0.016293275220959913, 0.05793572869151831, 0.011666859263641527, 0.014429269285756163, 0.03236259253753815, 0.05219555408984888, 0.04662572835513856, 0.04469590319786221, 0.022806238921475597, 0.044613239078898914, 0.01537238220407744, 0.03409753342566546, 0.06274834857322276, 0.05518706231669057, 0.009903186128212838, 0.05193942037294619, 0.036934630406904034, 0.025961451938201208, 0.022539321798831224, 0.06052924909454305, 0.03312841843580827, 0.04934240074362606, 0.03219241065380629, 0.03506375403958373, 0.0212167014615261, 0.015176713113760343, 0.009106562029046472, 0.06148263797513209, 0.045094247252563946, 0.04448980878805742, 0.014984355857450282, 0.04863419890170917, 0.025278789253206924, 0.09668490645708516, 0.017204775431309827, 0.053505055111600086, 0.0574656486423919, 0.029485499362635892, 0.04202900665404741, 0.022787254783906974, 0.015624884035787545, 0.038361320257536136, 0.03292403096565977, 0.04749674626509659, 0.01856388531450648, 0.09181659581372514, 0.03791300368902739, 0.03694888706377242, 0.0290689522807952, 0.02351723309402587, 0.005324910507624736, 0.012026461354253115, 0.019104001839878038, 0.0852236601349432, 0.0651095730427187, 0.043372976724640466, 0.05570467321376782, 0.04517506713455077, 0.014969695657782722, 0.05567814514506608, 0.046258955262601376, 0.028975981585972477, 0.048189429799094796, 0.052617483597714454, 0.026086463003593963, 0.02306629303348018, 0.029685821718885563, 0.03706580871948972, 0.07885165439802222, 0.05213455326156691, 0.05058379487309139, 0.06633324839640409, 0.040692881084396504, 0.046960730105638504, 0.0022379945585271344, 0.02183678254368715, 0.0751969926932361, 0.03719067135534715, 0.047451835198444314, 0.007058966384647647, 0.023764459183439612, 0.11539864994119853, 0.058792207928490825, 0.012879099049314391, 0.05000938741432037, 0.05435997954919003, 0.013271747120597865, 0.009097898382606218, 0.026513604243518785, 0.04976801501470618, 0.045347252817009576, 0.014067462088860339, 0.04533492203336209, 0.027828391212096903, 0.05305844548274763, 0.047801973050809465, 0.05788523667433765, 0.02954119940113742, 0.044042230656486936, 0.044232762229512446, 0.0537691075442126, 0.02989966971654212, 0.040054556156974286, 0.03048589773243293, 0.019240653491578996, 0.014356559222505894, 0.048826058919075876, 0.038273231039056554, 0.05694041959941387, 0.010394371001893887, 0.04065939909196459, 0.0462648813117994, 0.05492150332429446, 0.07925674828584306, 0.0518589233251987, 0.06536636356031522, 0.05986736839986406, 0.06153117814392317, 0.059624370696838014, 0.15191184065770358, 0.08019287110073492, 0.029985536202730145, 0.07119032292393968, 0.10571069869911298, 0.046959089959273115, 0.16041214781580493, 0.12910067016491666, 0.22525454027345404, 0.0858693582995329, 0.12340548084466718, 0.1322679634904489, 0.10410653165308759, 0.19006137794349343, 0.2116464017308317, 0.13627953885588795, 0.12900052475742996, 0.21225091069936752, 0.16757770237745717, 0.135025977215264, 0.11600047975662164, 0.15259475010680035, 0.09304108010837808, 0.18834857532056049, 0.12983371911104769, 0.10329120079404674, 0.17449016973841935, 0.1366186112863943, 0.19292252050945535, 0.10533129054238088, 0.07654204629943706, 0.1945255001191981, 0.1622636429965496, 0.11559079939615913, 0.17535837861942127, 0.22720019915141165, 0.13432297040708363, 0.07213814940769225, 0.09758646003319882, 0.19488998368615285, 0.23130820918595418, 0.1759646538994275, 0.1304351259022951, 0.12019351765047759, 0.10439944991958328, 0.19742480391869321, 0.17697820498142391, 0.13187931559514254, 0.15939098229864612, 0.11439031615736894, 0.11447791184764355, 0.15400868986034766, 0.14236513496143743, 0.11302906888886355, 0.1248328757355921, 0.10889674609643407, 0.07971926213940606, 0.15046269341837615, 0.1865571495727636, 0.13408518629148602, 0.11463698378065601, 0.1430243847426027, 0.15543358371360227, 0.10199061667663045, 0.11633466885541566, 0.2176092762965709, 0.14275736000854522, 0.04958251149218995, 0.12257184120244347, 0.20214863325236365, 0.1862851227633655, 0.1096507978218142, 0.16498955141287297, 0.14781315199797973, 0.11129815044114366, 0.1392612952622585, 0.10508569161174819, 0.13203800161136314, 0.15575178695144132, 0.12546759011456743, 0.1048487461230252, 0.18497066048439592, 0.09506202244665474, 0.12641710869502276, 0.16754126292653382, 0.2035955837345682, 0.13145305565558374, 0.14647195755969733, 0.1139209077518899, 0.12668340612435713, 0.09951856729458086, 0.15439064358361065, 0.1364234709762968, 0.10985263230395503, 0.13579849357483909, 0.17173689091578126, 0.11113703760202043, 0.1534457560046576, 0.12848778977058828, 0.17127413215348497, 0.1426981366239488, 0.05950752325588837, 0.24406946817180142, 0.09556153236189857, 0.1583476859377697, 0.0931992317782715, 0.0787433231016621, 0.15484445204492658, 0.2238351383130066, 0.175971184798982, 0.11243748813285492, 0.19898950355127454, 0.10356185463024303, 0.1428680439130403, 0.09257186466129497, 0.1756223160191439, 0.12529232451925054, 0.17096741736168042, 0.1591950107831508, 0.11626747480477206, 0.1236342107586097, 0.11411520943511277, 0.19195855973521248, 0.10072237535496242, 0.15808809752343222, 0.13946753810159862, 0.13126995298080146, 0.2922659780597314, 0.21450016734888777, 0.0968916539568454, 0.17354694457026199, 0.11019537094398402, 0.0897145812632516, 0.16144227847689763, 0.15721301635494456, 0.12020468697301112, 0.09126597418799065, 0.12582944647874683, 0.19374088675249368, 0.1257374053238891, 0.10559329835814424, 0.2140390858403407, 0.1301816082559526, 0.18450652132742107, 0.08327495103003457, 0.15124362573260441, 0.13119508512318134, 0.08503524368279614, 0.11535858880961314, 0.1155348785687238, 0.10372620323323645, 0.2009319860371761, 0.1496430952101946, 0.2308522188104689, 0.20201284991344437, 0.17909855057951063, 0.13668758649146184, 0.16414498735684901, 0.09174926075502299, 0.13545648223953322, 0.1468092339928262, 0.08872455626260489, 0.11812447672127746, 0.09721945316414349, 0.1064339884032961, 0.106653203984024, 0.09749407006893307, 0.17494981148047373, 0.19360174890607595, 0.23511331906775013, 0.2389298431808129, 0.1760318924789317, 0.14853509841486812, 0.1302287494763732, 0.15587971836794168, 0.18412047094898298, 0.22087463701609522, 0.15950537694152445, 0.13205002440372482, 0.18561465170932934, 0.23800805123755708, 0.09272852461435832], [0.02769793278275756, 0.02634166903590085, 0.01587429389473982, 0.08134557487210259, 0.010459902641741792, 0.07341384931351058, 0.03519794176099822, 0.06333850440569222, 0.018546713872638065, 0.05087227880721912, 0.009909773616527673, 0.04529624871793203, 0.028614702241611667, 0.02950555775896646, 0.013278408823680365, 0.0386854940734338, 0.01658599681832129, 0.03029638475709362, 0.06277798995142803, 0.05796974874101579, 0.02811565987940412, 0.0299928500680835, 0.021496018016478047, 0.06354138531605713, 0.020835721807088703, 0.0515671368339099, 0.12252682252437808, 0.04420080535055604, 0.05162631568964571, 0.03255113144405186, 0.04979776400432456, 0.03851037319691386, 0.0380942175979726, 0.02451520093018189, 0.07056564980302937, 0.019908348913304508, 0.03214584830857348, 0.010046802835859125, 0.056556810886831954, 0.022046125704946462, 0.02541500303777866, 0.027698190679075196, 0.07110741760698147, 0.07254224881762639, 0.011886252959811827, 0.02821601679897867, 0.03297055991424713, 0.047162831760942936, 0.04596947685058694, 0.03754734010726679, 0.04500033588556107, 0.04355623896117322, 0.01414729398675263, 0.07296038966160268, 0.03774309268919751, 0.0666090972663369, 0.05186040019907523, 0.030370697859325446, 0.035231364381616004, 0.048282368952641264, 0.02295643847901374, 0.039269979897653684, 0.013634704646392493, 0.060618388451985084, 0.018949199111375492, 0.065566483681323, 0.043523974090931006, 0.1227688294602558, 0.020632892847061157, 0.0401915269321762, 0.0623734897817485, 0.028955071575182956, 0.058781031184480526, 0.1427183230407536, 0.027432744864199776, 0.05268360153422691, 0.03477931852103211, 0.011113569617009489, 0.07133206570870243, 0.025687695924716536, 0.029419869388220832, 0.029873909770685714, 0.06654995551798493, 0.013832597396685742, 0.05865641345735639, 0.04099247125850525, 0.04725747414340731, 0.027509126703080256, 0.02190253682783805, 0.05264828272629529, 0.028577824923559092, 0.007433232849507476, 0.018174682663811836, 0.060619653813773766, 0.026076772410306148, 0.017749432045093272, 0.04432023546542041, 0.04707775566203054, 0.0682935572694987, 0.08039791166083887, 0.02447866128932219, 0.011595654832490254, 0.0376722509827232, 0.09238193422788754, 0.05341686941392254, 0.05539959485759027, 0.0602880436781561, 0.028517245264083613, 0.019229289355280343, 0.02459391125739785, 0.05590993270743638, 0.03756784564757254, 0.032598539837636054, 0.014342592930915998, 0.05162503548490349, 0.08247029225458391, 0.053030748531455174, 0.03408351796679199, 0.06922795830178075, 0.013277084090077551, 0.04129804685362615, 0.03777336860366631, 0.032934242917690426, 0.030809232921455987, 0.010810042349476134, 0.025844083138508722, 0.08880511639290489, 0.028496004997577984, 0.040208629725384526, 0.028459799323172774, 0.007987986846273998, 0.10930601827567443, 0.04337565587775316, 0.06201516975124832, 0.027100225597678218, 0.022171914170030504, 0.02747103040746879, 0.028337927542452235, 0.04489161496167071, 0.05049080747994594, 0.0757659602095373, 0.031937813182594255, 0.10421993923955597, 0.06239010646822862, 0.058418109838385135, 0.044198816394782625, 0.015822770292288624, 0.016382648354920093, 0.03151961667754222, 0.03867651779728476, 0.037638657668139786, 0.037474598502740264, 0.04315690042858478, 0.023153994479798712, 0.014906424785294803, 0.0702151631412562, 0.020819808305532206, 0.01044176826326293, 0.013298184276209213, 0.005416804624474025, 0.007235984376166016, 0.04346106594312005, 0.006945032337171142, 0.018638899746292736, 0.05422224807261955, 0.035074938205070794, 0.039323158489423804, 0.01403246240442968, 0.019212732040614355, 0.030514581740135327, 0.04331194249971304, 0.010509415951673873, 0.030560038285329938, 0.01561249573569512, 0.043354638255550526, 0.05307880259351805, 0.08141027530655265, 0.023481162861571647, 0.015709516701463144, 0.0921715130971279, 0.060629016006714664, 0.05989071636577137, 0.016696662169124465, 0.09450714831473306, 0.03871350272675045, 0.03946186217945069, 0.02156030841433676, 0.079316209157696, 0.03575290866137948, 0.024741004926909227, 0.05045483929279726, 0.03681237270939164, 0.017212449238286354, 0.03995184291852638, 0.036188063240842894, 0.031861639145063236, 0.07475515507394448, 0.149069563485682, 0.01784401134500513, 0.03642942079750355, 0.05871682798897382, 0.03770909861486871, 0.036410844841157086, 0.006660242906946223, 0.05839515150000807, 0.08409574409597553, 0.06675422424450517, 0.051746313547482714, 0.0395581335760653, 0.01516556141723413, 0.06809684360632673, 0.048966117028612643, 0.022604400728596374, 0.07097856592736207, 0.019382240425329655, 0.02072767623758409, 0.019865050162479747, 0.027237521062488668, 0.018148045128327794, 0.10737320597399957, 0.04783975578902755, 0.03197758487658575, 0.019618488295236602, 0.02027524260483915, 0.017694503840175457, 0.04019831387267914, 0.06570315759745426, 0.024865503910405096, 0.023617951810592785, 0.07987984805367887, 0.04264074785169214, 0.011256184425292304, 0.08649990180856548, 0.034521912020863965, 0.024548187539039645, 0.04300257452996448, 0.0013124729753144493, 0.020031504609505646, 0.0883795392292086, 0.039252502319868654, 0.025323819063487463, 0.00997067239950411, 0.04060344486788381, 0.083089124673279, 0.08138674922520295, 0.04355839861091226, 0.021078467179904692, 0.08012338381377049, 0.04918247905152384, 0.07648860424524173, 0.06317775521893054, 0.030487484073091764, 0.05058438859123271, 0.028635988892347086, 0.0738482728775125, 0.04162398698099423, 0.026030508779513184, 0.052893050451530144, 0.06529340302222408, 0.025788358980207704, 0.036177253859932534, 0.0727449516125489, 0.0457697240926791, 0.024964278200059198, 0.011695411540131317, 0.05660960356181022, 0.05372802224883344, 0.044175197544973344, 0.08341313150594942, 0.04198879709292669, 0.02416119463305222, 0.026373247419542167, 0.015497832991968608, 0.02122887824953068, 0.03502658728393726, 0.026055331763927825, 0.05893138288229238, 0.028587871747731697, 0.023873172685853206, 0.05088827951112762, 0.027230266568949446, 0.02968885710288305, 0.07145017851144075, 0.04822991766559426, 0.022271406487561762, 0.10647070987033658, 0.035967040530522354, 0.053728693892480806, 0.04748907987959683, 0.06638061968260445, 0.006187475819388055, 0.043504589193616994, 0.028720094633172266, 0.0796727517445106, 0.03642978073912673, 0.01873826033261139, 0.01756093952280935, 0.033896047752932645, 0.028731050588248763, 0.06161623197840527, 0.03299502110166941, 0.02918394806329161, 0.024256772121589165, 0.04010472905065399, 0.059329214855097234, 0.04920217194012366, 0.06671746567008086, 0.029932808465673588, 0.047150126192718744, 0.048393078832305036, 0.010822415806615027, 0.028700127149932086, 0.031615561529179104, 0.02380876539973542, 0.014677683739137137, 0.03700636269059032, 0.04691006368375383, 0.026250143673678394, 0.11287315108347684, 0.03851684472465422, 0.049902195314643905, 0.12093231824110262, 0.024037478615355212, 0.012850078292103717, 0.034068044187733904, 0.036216431835782714, 0.0640248425770551, 0.0008136564463256946, 0.047468566917814314, 0.02045109635218978, 0.015433303251484176, 0.12042698988807388, 0.008099219940049807, 0.03980142813816201, 0.044782322584069334, 0.07505027751903981, 0.05210615498072002, 0.08345040958374739, 0.039748405397403985, 0.031764462328283116, 0.013029688234382775, 0.052222820595488884, 0.043967934252577834, 0.05937854541116394, 0.04343445994891226, 0.0669983314583078, 0.022022549528628588, 0.02695854960620636, 0.037022088799858466, 0.030332221213029698, 0.0009634034097416588, 0.005022972827646299, 0.09865774278296158, 0.11111331114079803, 0.1260090313735418, 0.24514234653906897, 0.08871238504070789, 0.12980924308067188, 0.1825402455870062, 0.23855743347667158, 0.13462278322549537, 0.23948198620928451, 0.1149548011017032, 0.12445347500033677, 0.12643129855860025, 0.15578298683976755, 0.0952579865406733, 0.0856773424311541, 0.11241058527957648, 0.20937274326570332, 0.13964344194391742, 0.10153514580451883, 0.1556236032047309, 0.28480967972427607, 0.08498603187035769, 0.1800726045621559, 0.12701021827524528, 0.12013289160677232, 0.23039654013700783, 0.0970231625251472, 0.11375304136890918, 0.1594240523991175, 0.1456422809860669, 0.1760762432240881, 0.1005051116226241, 0.08560775124351494, 0.13940827018814161, 0.14042670460185036, 0.09803816079511307, 0.1117591948423069, 0.1636216396582313, 0.13029074849328026, 0.08707120709004812, 0.12684771761996672, 0.14183528604917228, 0.32252440752927214, 0.14306842378573492, 0.10122330277226865, 0.0986595758877229, 0.14469346002442762, 0.08686057815793902, 0.20077463588677347, 0.11175200343132019, 0.22175669437274337, 0.09747411371790804, 0.19151206884998828, 0.06353181161102839, 0.08957752143032849, 0.11176881307619624, 0.11966906415182166, 0.12838816386647522, 0.13077462877845392, 0.1435264031169936, 0.09106172772590071, 0.17709714156808332, 0.1529248128645122, 0.10147760709514841, 0.20284567319322377, 0.10935174199403264, 0.26826979068573564, 0.16684722126228735, 0.11977022630162537, 0.20855422859312966, 0.16601818293565884, 0.15801811299752444, 0.15356813615653664, 0.13385470490902662, 0.1640527235576883, 0.1303760806331411, 0.10590159392450005, 0.16066011419752613, 0.0682318773760926, 0.09889378285151906, 0.17688505060505122, 0.31375186576042324, 0.1290383594459854, 0.264090757118538, 0.15726418001577258, 0.16606090095592663, 0.1814507134258747, 0.177109387004748, 0.20313098444603384, 0.1673415955156088, 0.14872489526169375, 0.10944611349259503, 0.14477803517365828, 0.07564973988337442, 0.08860405374434777, 0.15900616388535127, 0.14524408907163888, 0.16712678829208016, 0.16468800196889788, 0.1702729452517815, 0.18410018063150346, 0.1357708263094537, 0.1615488954121247, 0.2096586927655153, 0.09231974225258455, 0.1441141840768978, 0.15163524221861735, 0.09896464311168529, 0.17060787649825215, 0.11962711054366082, 0.09445913136005402, 0.11340500379446894, 0.09558264646329917, 0.14308911486295983, 0.19648166780825704, 0.16185474931262434, 0.08660026986035518, 0.1357739878585562, 0.11902129539521411, 0.14293353102402762, 0.14197035692632198, 0.13432635460048914, 0.12912323145428672, 0.09713458857731894, 0.15177668072283268, 0.13680879405001178, 0.18052059458568692, 0.07571272595669143, 0.0907026841014158, 0.2589904807973653, 0.13117010443238541, 0.11139516398543492, 0.14000417024362832, 0.11655295675154775, 0.10591325306450017, 0.09911621193168685, 0.16679918946465477, 0.06928771603270434, 0.12509572959970683, 0.1667121800710447, 0.10722171136876568, 0.18077777844155207, 0.09356436101370491, 0.12870584760094061, 0.22895957896253094, 0.11025639774743468, 0.08537894711480476, 0.14498214062768966, 0.10548320817179047, 0.12247300197486766, 0.20283483783714473, 0.205805194855202, 0.12648172007175162, 0.11564916188945062, 0.2812453522346914, 0.14539974712533876, 0.17572728538652882, 0.08193351168301888, 0.15882825624430552, 0.137886704178527, 0.23995234456378967, 0.10336960869608447, 0.11908007349120453, 0.1529608663986437, 0.1324990831199102, 0.08845882286550477, 0.15417435206472874, 0.13694034714717418, 0.10790972679387778, 0.11064629987231456, 0.15874908393016085, 0.13601537881186232, 0.10362488523242064, 0.09790767639060505, 0.11951309439609759], [0.04930927498207893, 0.029539130664488766, 0.0671436291304417, 0.04741913617181126, 0.069007688871352, 0.045933386209071614, 0.017415246657037642, 0.062470874399878085, 0.009818056223593885, 0.014843158551229862, 0.08518819289747626, 0.030068358028074726, 0.03799353784415871, 0.020492966468736995, 0.05263802995614242, 0.07080170471454039, 0.0591364085994428, 0.0373375720664626, 0.006288051672527217, 0.0633331757853739, 0.033123913599411026, 0.008227617981901858, 0.02154962519853143, 0.0961494617513381, 0.06496380039607175, 0.0211727255009464, 0.05634955501591321, 0.02082815746689448, 0.021975022391416132, 0.03704712515173014, 0.017007985698000994, 0.01001944448944414, 0.007015950577624608, 0.046538125243387185, 0.0334261087118648, 0.02537217555072857, 0.040531200502300635, 0.03809455156442709, 0.03598197996325325, 0.024072532105492428, 0.06596932886168361, 0.059041654894826934, 0.03141603141557425, 0.017606262481422164, 0.06839079345809296, 0.036193332489347085, 0.03375622341991402, 0.08049141484661959, 0.014143717762635788, 0.04754057008540258, 0.04860459463088773, 0.06710093337460421, 0.030217164203349967, 0.009452693211642327, 0.026354938636359293, 0.0809867242060136, 0.017400472352164797, 0.0057591132826928515, 0.031456612050533295, 0.011160113408550387, 0.0189535351091763, 0.08607220952399075, 0.030008140165591612, 0.008497620583511889, 0.026512860240472946, 0.01627202938834671, 0.09056592112756334, 0.028620158882404212, 0.1673029741505161, 0.022649042766715866, 0.01611301126104081, 0.05002336576581001, 0.021827297896379605, 0.06198169146955479, 0.029455013791448437, 0.01261384804820409, 0.10461427198606543, 0.016326141230820213, 0.040869449148885906, 0.03412281468627043, 0.06452697969507426, 0.07638718976522796, 0.033772372553357854, 0.06014231556036975, 0.05995735751639586, 0.015357110660261242, 0.024347520084120333, 0.005875143897355883, 0.1904405708773993, 0.02156653874408221, 0.07010504326899536, 0.01689166147116339, 0.07243072628625669, 0.018304280201846268, 0.005822568300573039, 0.060116522217867896, 0.021089404581289273, 0.039752695010975, 0.125981853925623, 0.018213881048723124, 0.04804359778063372, 0.0587242902838625, 0.05223811625910457, 0.05061409676272888, 0.03336113739351276, 0.13548213086323813, 0.046686346977367066, 0.038165267105796374, 0.02550206994783366, 0.050659928092500195, 0.02794101026665885, 0.03566558756574523, 0.032371309062000364, 0.02620708055474097, 0.024825977125146892, 0.03072837964282371, 0.05112716571602505, 0.032259248473565094, 0.07608518761117011, 0.05166132279555313, 0.027019424269383308, 0.042702078935690224, 0.04365661443443969, 0.01778318121068878, 0.011179053944943007, 0.04350206960225478, 0.008699176760273986, 0.03564621751138475, 0.028885703031846788, 0.04887566406978294, 0.03274476890510414, 0.0660202327708248, 0.02490881750418339, 0.049394748129998334, 0.07864817234803922, 0.033166958164656535, 0.10829239297891036, 0.09182501176837832, 0.03168660732626449, 0.03863668302074075, 0.018778267658490222, 0.04479156974412035, 0.08567149430746213, 0.049286542998743244, 0.043992057762807235, 0.03074666987231467, 0.044905096074217, 0.012808985575247789, 0.07409393117995933, 0.1236168593459297, 0.06968194487853907, 0.016797800199128687, 0.0608029865543358, 0.03891780856065452, 0.021165914440643974, 0.029082980727253016, 0.01818862019717926, 0.023404270796163473, 0.02996012135554338, 0.037453747863764875, 0.03373326137079857, 0.006629187737416942, 0.0030410053022933425, 0.02249667428259272, 0.020711718207166996, 0.02501202983694384, 0.011098129234596854, 0.04545948038867209, 0.006016909410391236, 0.03307950348244049, 0.02945995278423652, 0.03405405470402911, 0.04476735717616975, 0.048509269472560845, 0.020127898460486904, 0.02634039439726621, 0.04424108912644442, 0.06267958859098144, 0.02478559315932216, 0.10715171942138113, 0.06679332800558768, 0.046645250549772754, 0.008425752857874613, 0.03902477430528961, 0.01768458132573869, 0.07089746402925812, 0.046608885313617066, 0.08608699310570955, 0.050440820123185404, 0.020248605069355108, 0.043960991461062804, 0.09875520903733559, 0.05302804711391218, 0.10466537627507932, 0.024055937683442608, 0.041811791161308065, 0.09869197063380852, 0.03654236454167403, 0.01761358191288309, 0.05590778047917411, 0.034745231678243726, 0.03780014900257811, 0.036666844971477985, 0.027211857595830224, 0.03995209153799806, 0.11037191303330474, 0.06931571726454422, 0.09766017756192014, 0.023496434405387845, 0.04847121956117917, 0.03621712574386038, 0.018917505694844294, 0.049692430984578095, 0.04908656388579402, 0.00997686283881194, 0.06080947663576808, 0.01147238317571464, 0.033314215106656775, 0.03827192856988404, 0.04210372979287058, 0.04133962938794866, 0.019633479678304866, 0.01618094560399186, 0.03233239083783701, 0.0673864598502405, 0.029171928981668316, 0.031902112168609165, 0.023089939713827334, 0.07321274213609286, 0.030544553374056704, 0.0401657001930289, 0.06046686787158251, 0.04437724724994041, 0.021086239321448375, 0.0182891570875654, 0.06190122781845275, 0.026098446833202615, 0.017646544401941355, 0.03744958812603727, 0.07500767824240029, 0.011093671710113995, 0.04168267973000184, 0.061347478040261194, 0.050181780898128636, 0.06584334929357283, 0.05708373573725112, 0.03235339361708611, 0.06407407665392384, 0.05263902072329074, 0.04230544924212154, 0.05034096786403097, 0.04467954255233053, 0.06994861338171177, 0.035720692030736245, 0.07605661492561921, 0.05796946301416028, 0.044243846205063164, 0.0751744388253428, 0.03922166608390398, 0.021078402241982985, 0.048365248294430785, 0.04336027486715466, 0.02224520310846856, 0.0385491392808035, 0.021003979672968853, 0.04366656663478352, 0.03772404546907637, 0.08114611526252702, 0.02294452515343437, 0.04842008558625821, 0.02873864275898086, 0.05981062749924604, 0.01867097907961579, 0.043598782576736994, 0.14315770415123552, 0.047730066362419166, 0.04835117346374318, 0.010103529821208213, 0.021871272001590114, 0.05242777209787164, 0.03883169345499482, 0.11547667934792116, 0.023470477790397126, 0.0420820368162822, 0.05608774758002255, 0.05029812738939654, 0.016341323716915213, 0.09580547630321234, 0.039018432653392665, 0.03954531668568961, 0.02014550962485373, 0.043139122280990705, 0.00836733841424575, 0.031657069848733954, 0.013332982653082581, 0.030109415492916014, 0.02501142498658737, 0.08040203800192103, 0.04452529828995466, 0.04635018376575317, 0.030936346120142844, 0.028975567838642746, 0.014024953725311207, 0.022298513431451283, 0.013004243701288942, 0.027358160878065974, 0.018189269576396327, 0.06045601396181155, 0.01322112151683541, 0.04030257819977123, 0.015176349461398786, 0.024950849037850276, 0.02007033006520942, 0.04471674641536083, 0.011747065946110524, 0.014519558044412406, 0.04051861738844309, 0.03762801527045667, 0.03959993504395243, 0.005659201651724288, 0.00854086831168388, 0.008242551848525181, 0.06414073635824025, 0.039287286781473085, 0.02789211201161379, 0.04740372176456731, 0.06060112609702628, 0.032701813397579826, 0.03775678160309326, 0.05245242624368984, 0.017782841678126715, 0.021097764874866698, 0.02972638565552188, 0.04750703243189491, 0.029554355824075174, 0.03033495602721814, 0.008191650722437771, 0.01225489719217876, 0.023461696328013204, 0.02779237664071843, 0.036950594003428705, 0.004541068046819419, 0.038950084563111886, 0.041706306001287885, 0.011334848368278472, 0.010094320696225623, 0.030822977496427484, 0.03720364780747332, 0.023710282403044403, 0.021905770736339036, 0.016497787000844255, 0.01944170315255178, 0.143125242611859, 0.12446768712834455, 0.18220259808003902, 0.2755738003179431, 0.20481380430283025, 0.10161998070543632, 0.056335123954340816, 0.17829516087658703, 0.08351460535777733, 0.09848900808719918, 0.2395102323498577, 0.1140511546691414, 0.09218513892847113, 0.12716222496237606, 0.21808698191307485, 0.14767196582397446, 0.118467801657971, 0.22039249335648492, 0.1286559010623023, 0.16329461970599368, 0.21481632225913927, 0.08177121140761301, 0.09408168247318827, 0.21142556826816872, 0.16045299562392756, 0.09838403871981427, 0.1441764205810614, 0.25207779079210013, 0.06820981332566589, 0.1903494054568, 0.20833663089433685, 0.13075454626232386, 0.12272499079699628, 0.1104846378439106, 0.1618312974460423, 0.10432742448756471, 0.12804214493371546, 0.16146737791132182, 0.14976500038756058, 0.14282309944974259, 0.13905499305110425, 0.08709189816727303, 0.0837809027871117, 0.09489435644354671, 0.11320284276735038, 0.14545079204253852, 0.15493309416342527, 0.10454396833665669, 0.13015548465773463, 0.17474382097134367, 0.2538693055976182, 0.18832697882317007, 0.16262538061710075, 0.16655796178383753, 0.22946398705244064, 0.19087910593952984, 0.20058092050021514, 0.164058675582055, 0.09279739591875114, 0.1563439762685448, 0.11966638499870896, 0.1380912697641179, 0.11351358742103912, 0.18059504684060812, 0.10791512962896377, 0.15045355015899986, 0.18294804089237005, 0.1468275353545323, 0.25449244247283787, 0.12920124601805583, 0.08929693765821867, 0.11712442530551925, 0.13644368707900867, 0.16246028244495392, 0.15572830539895222, 0.05946715042227879, 0.31473728944547474, 0.17967490246519446, 0.1536301797023043, 0.16407118819188327, 0.16450470633571967, 0.1499795849667862, 0.1217513153096661, 0.25274453626479954, 0.18450790172209963, 0.11213527075597085, 0.11802834633272141, 0.18759425642201677, 0.22113789163995534, 0.08493485336657614, 0.2026627486338839, 0.17393176298355684, 0.15785028372192755, 0.1003834290895611, 0.10628210788127035, 0.16212471295148134, 0.13020059239352122, 0.14273159264121205, 0.2838108973810449, 0.14596887049265206, 0.0953669412410818, 0.13650595326907933, 0.21078791498439386, 0.17319711099844426, 0.1534812751924619, 0.2084634787752293, 0.1309007641975768, 0.15881848958088085, 0.09217073384206742, 0.1633551047416404, 0.13826741109369323, 0.1266423356719315, 0.09823885979130864, 0.1149023906327784, 0.10944784269668162, 0.12938568455865607, 0.14136899466393515, 0.12376888829749078, 0.18364353716606274, 0.10752554662758484, 0.13343982951482758, 0.2695611276431009, 0.15118671784875914, 0.1240569083893206, 0.085633013950428, 0.1548161613754928, 0.16640475281747058, 0.18427869683364406, 0.09477390587562695, 0.11255543766310439, 0.0994392836582847, 0.19887536123860627, 0.06358334634569474, 0.20191730582155287, 0.12174846546258777, 0.16579098184593022, 0.1991752631147392, 0.21731495537096635, 0.0918330269632861, 0.11684620898449793, 0.0923401587351691, 0.12995795463211834, 0.2281414353637956, 0.0824262086825911, 0.26478680258151144, 0.11788803589297459, 0.15839328349102288, 0.0876597005117219, 0.112563489965396, 0.209216432122048, 0.15060232108226046, 0.07258927129441872, 0.12067630697856657, 0.13114482688251883, 0.10191369306994602, 0.0787754358316306, 0.13584769796580076, 0.16653790895361453, 0.12210796179715544, 0.15086662955582142, 0.07683152100071311, 0.11211575969355181, 0.13840565836289898, 0.09663144213845953, 0.08804834098555148, 0.10294858089764602, 0.20257551659597084, 0.11036397947464138, 0.04935766672133468, 0.24979749752674252, 0.07641761039849371, 0.09034709888510406, 0.1407782599562779, 0.1387771181180142, 0.11900152458110824, 0.09540548096993007], [0.033357649299432524, 0.04344366258010268, 0.08472040979540907, 0.10844888223800808, 0.08126093292958103, 0.03083922125370009, 0.05934754961344879, 0.03184477754984982, 0.04562415553664323, 0.025080177547351923, 0.039385988711728714, 0.015083718299138127, 0.05151078185008373, 0.05772706645075232, 0.031770829955348745, 0.03410766745219007, 0.0333326018153457, 0.03267878455517348, 0.05908350089157466, 0.04045613226480782, 0.011340601868141675, 0.021280561413732357, 0.016814932678244077, 0.013340748300834093, 0.05693994462490082, 0.028236841462785378, 0.0226378140723682, 0.04618512270099018, 0.042590215016389266, 0.03410781217098702, 0.052717873913934454, 0.022940742055652663, 0.03591352426155936, 0.018059707290376537, 0.0891073486127425, 0.05910701584070921, 0.1340255473041907, 0.0190536155787413, 0.024589981585450005, 0.028083600955142174, 0.006554384817718528, 0.008878192984411726, 0.03953510844439734, 0.04926615991280414, 0.05333135173714254, 0.01817660482629435, 0.01651615330047207, 0.015663950689486228, 0.03909447310434189, 0.06916240439750254, 0.043506381480256096, 0.025651145151641686, 0.022548259112227242, 0.018057799970847555, 0.03396257758140564, 0.022409854136640206, 0.06603418514714576, 0.038568145682802424, 0.0348484829737572, 0.06320413114735857, 0.047336115821963176, 0.015690985273977276, 0.04804260330274701, 0.038547985241166316, 0.035392955905990675, 0.04215763197862543, 0.030042625912756193, 0.08016530773602426, 0.05373777406930458, 0.06722991864080541, 0.07458390449755825, 0.05690919373591896, 0.036881967607769184, 0.03918611349945422, 0.029122064079274423, 0.03645308046543505, 0.10537765992921777, 0.018070251353492495, 0.03769942471990362, 0.04984971063095145, 0.035092875914415345, 0.20513815252343193, 0.012854515407525469, 0.1950542803388089, 0.16903628973523155, 0.09837966004852206, 0.0032158165640794323, 0.03888048595399596, 0.10482622936251573, 0.04105901221919339, 0.04983667480701115, 0.054281905613606796, 0.04576538995024748, 0.10953762772260234, 0.11321847981889732, 0.09763162714079954, 0.034385245526209474, 0.030555260709661525, 0.024705751056899317, 0.0128313585446449, 0.0501644369069254, 0.03717221785336733, 0.06672729912679642, 0.04727293679025024, 0.10408529138658196, 0.04324359069869388, 0.006262326514843153, 0.08611914294306189, 0.02468165537720779, 0.030666690472571645, 0.014310063670563977, 0.04057853097037878, 0.1073127357813064, 0.02908726477471646, 0.05028279461839702, 0.008964332209870918, 0.009134755291597685, 0.013981715273985174, 0.10122714709723368, 0.08994733361760154, 0.03179112398356665, 0.04233160252624657, 0.02122585770848673, 0.06594362828764133, 0.05276541218336206, 0.032355909497709945, 0.033766027190722525, 0.009874989154923242, 0.04785784563864581, 0.04709030166850425, 0.017906884240801446, 0.038582446868531406, 0.045984316093381494, 0.06785410194424912, 0.050722621017484926, 0.020732420416607056, 0.061094461343600415, 0.04627046968380455, 0.07572186921606772, 0.01307492677369737, 0.026984463547705673, 0.0552003578923177, 0.033568552826181985, 0.013700432027690113, 0.050772378308465704, 0.034024461565422826, 0.05702631206077058, 0.05436062150693033, 0.02624585962621495, 0.02234535408206284, 0.016899930851650424, 0.015253363981173607, 0.04728835490823258, 0.022188874099811073, 0.047516146005364135, 0.01173515540358494, 0.04269903241947759, 0.05487380920385476, 0.07525944442022592, 0.06061897845938802, 0.029707607463933527, 0.02292474135174416, 0.02395929335762048, 0.021828869394084904, 0.04520166199654341, 0.034528591349953786, 0.02629622362292139, 0.01748641861922806, 0.06177722607390024, 0.04546167343505658, 0.00872657963554957, 0.03883205710735638, 0.08275162559584714, 0.008114497049973579, 0.039464585861423984, 0.059805759010487236, 0.04824595547688659, 0.026791948585014325, 0.061910248623462394, 0.022003749072609935, 0.025959880440495908, 0.021274006394378375, 0.006459270707637188, 0.025446752115385607, 0.0687995609769132, 0.009654580571805127, 0.03530368296196684, 0.10603834947687574, 0.0660189933842048, 0.044751041059498675, 0.015071284542500507, 0.04829766461625695, 0.04832006634387653, 0.09209403287968598, 0.03979637040174566, 0.04130066663492471, 0.020490318856900558, 0.04859574080910534, 0.007307535297513823, 0.027999183512292802, 0.028087823775422294, 0.010050312266685069, 0.038859939595567994, 0.05210224386246409, 0.08617893035989255, 0.013300342998263659, 0.03505906366626732, 0.039846509898779914, 0.07082767246174626, 0.00845271693833638, 0.104443154996261, 0.022274957664194517, 0.07664580596610904, 0.026049235020764172, 0.07150221790652722, 0.004662243136408506, 0.02320697640243452, 0.05803444546472747, 0.04259815970726777, 0.035623548610601574, 0.0005660669944518304, 0.1056415973289404, 0.04585661103192251, 0.03793580617639236, 0.04357820282166358, 0.04766228230437264, 0.03032192020327784, 0.04122509744775016, 0.05620281015580986, 0.0048358500316680875, 0.041820730330073275, 0.013503400168701774, 0.050434612057870254, 0.01370312602375634, 0.05783313048596028, 0.019978413220087532, 0.02359292659093626, 0.03079962025367422, 0.017109732289100066, 0.04025186353828758, 0.017997105278482195, 0.004679802814280265, 0.035254983231425285, 0.032438762864330783, 0.12385863621602766, 0.039171760363387875, 0.030109161307336763, 0.05138719570823014, 0.02849031829100568, 0.028554679192893673, 0.06593332727788948, 0.0029333716247492703, 0.024449691554764286, 0.05085441531264223, 0.02118253669323167, 0.03064496038859943, 0.0447092284593964, 0.20233840041328222, 0.04053535281855147, 0.10977750469464809, 0.03983785645687021, 0.020957126034772955, 0.027796913018391933, 0.06283362876274623, 0.13233650824986398, 0.04240534603013657, 0.012874614621978253, 0.06733921472914517, 0.07231414972920902, 0.043225504559814, 0.03797408986429218, 0.022787993220845237, 0.0245997426827671, 0.01489364871304133, 0.008880014956957893, 0.026513624652579892, 0.06244154472369701, 0.0407668027037289, 0.0657131988555193, 0.026158306609431747, 0.1103263748518657, 0.04371131813968532, 0.035586964440881275, 0.03827788430498913, 0.04354984164820053, 0.041775299760047346, 0.005957118282822194, 0.05262998507532757, 0.05977304514090065, 0.04066911380505189, 0.04180733085377142, 0.07461003551725298, 0.05372834508307278, 0.025601979723433033, 0.05928339836827945, 0.04186538535577711, 0.06083691754611209, 0.06858729189843871, 0.07293444417882711, 0.03716665545653086, 0.026460835688340012, 0.03739849867997691, 0.013443614607240306, 0.02406783987680683, 0.004649490256269928, 0.04658054640458431, 0.023778804898029193, 0.03382651222636923, 0.024547311804781202, 0.02936371478426736, 0.14263407443650067, 0.024063036325969733, 0.06799916955060326, 0.0528945866972208, 0.026607029503793456, 0.030104942197795026, 0.02189489456213778, 0.017329584261460695, 0.04750715117552318, 0.08673643911606632, 0.015897821831458714, 0.01737234681058908, 0.03749622468603775, 0.01892173408123199, 0.02791908165818313, 0.0867906233179383, 0.025269395518989768, 0.026792737116920762, 0.02591899366962025, 0.019697326642926782, 0.13770835124887526, 0.022719591324857902, 0.03406465257285163, 0.04614139907062054, 0.05010479420889169, 0.005792472820758121, 0.05356143978133332, 0.057524641961208545, 0.027865589509019628, 0.05136065650731325, 0.014669288193545071, 0.0025480146905465517, 0.029669559407921042, 0.05051463784184307, 0.04012608806078788, 0.012833972759835888, 0.01676578394835815, 0.07984508585650474, 0.008773062199907145, 0.022858430456835777, 0.025102796353166923, 0.038932881579967216, 0.1370546972611919, 0.15100337768672034, 0.18351605103816837, 0.17243442067410797, 0.1690382935339585, 0.06697411517961882, 0.17303005355643108, 0.17440336814615875, 0.14263554388890043, 0.08970491850050166, 0.13808184448862448, 0.1710262696724385, 0.1391699814121239, 0.13702420983463526, 0.0854965701000765, 0.10133651740034111, 0.19689881417434663, 0.13665139937074855, 0.19440073025180027, 0.10504759717150591, 0.1787032827269286, 0.14510814246023074, 0.12692313466686755, 0.09755395396496169, 0.2122144860913977, 0.08980039579910226, 0.1450626042787917, 0.12601824884768575, 0.22805387678090483, 0.1480993686709553, 0.18304750352399424, 0.10212846318609081, 0.11872497067088261, 0.10695905788452365, 0.1682702894322574, 0.13349084474612027, 0.23015467420918867, 0.07388599624391645, 0.2289845299674198, 0.09600995283108205, 0.10648270297679119, 0.12805458332877606, 0.1556585732032545, 0.15242239373037592, 0.0866158920689486, 0.2040394622599706, 0.12060039269272238, 0.13795526378089562, 0.12698275881120935, 0.2726042893482372, 0.10156442353036255, 0.12610464968020096, 0.135474412527401, 0.11885788931977004, 0.09448650918784551, 0.10434908777824603, 0.1796216014190577, 0.19411567132920027, 0.1704163578688167, 0.08782525139395148, 0.10213724279310554, 0.12812781846150756, 0.12413026968715712, 0.18392092228168622, 0.1902765710838139, 0.1476618874585256, 0.13999159826198593, 0.24701555696083233, 0.20216994773363695, 0.2061601640889421, 0.22034943394828588, 0.2692893531639129, 0.16228939552092925, 0.1657308085123077, 0.15065053099533543, 0.13177404936868697, 0.21169320156332105, 0.11994207059615292, 0.15198902401607484, 0.149290174304042, 0.18880029092542827, 0.4628722812049091, 0.1537470382754691, 0.4647517256671563, 0.28689769736956805, 0.1606240903493017, 0.11229391224333085, 0.2841809025267139, 0.21355783275794238, 0.1796259355614893, 0.1126751015544869, 0.17435226385714486, 0.2013874420663342, 0.2561404259176925, 0.19453471759334207, 0.24121852271491662, 0.19925667671486735, 0.14795727707678452, 0.09386082674609497, 0.13259830826427788, 0.25188094354234636, 0.24439026892650872, 0.20660937123466283, 0.10301210873876698, 0.2541618305258453, 0.09598197386367247, 0.14484475424978882, 0.21269155346089974, 0.10700944971176796, 0.18705422524362803, 0.14475238654995337, 0.23973876930540428, 0.158088899042923, 0.13084390084259212, 0.1255934583605267, 0.21011291682953015, 0.19436654692981392, 0.0949792136088945, 0.23850045137805864, 0.18077029759297147, 0.1155681861564517, 0.17086817737435922, 0.27774787740781903, 0.15197505679680035, 0.11741893176804297, 0.10500008487724699, 0.24011784349568188, 0.07786487258272246, 0.12540075229480863, 0.20527332730125636, 0.15429811261128634, 0.15726823214208707, 0.13161620940081775, 0.11381238349713385, 0.17754658620106056, 0.1689045288367197, 0.1607078788219951, 0.25594832841306925, 0.1483967769308947, 0.08731735520996153, 0.07667339901672676, 0.14521213219268247, 0.10204743550275452, 0.17108245025156066, 0.161279748135712, 0.11137945271912031, 0.15650940098566934, 0.1182468123442959, 0.06665654276730493, 0.12217609837534837, 0.1242675373214297, 0.16191045491723344, 0.1669479307020083, 0.09787678820430301, 0.20238577912095934, 0.07099680049577728, 0.14694365178002045, 0.11750100587960333, 0.15333618532167748, 0.16063315939391032, 0.12790391250746325, 0.14296428562374786, 0.14764193852897733, 0.12503150413976982, 0.08976434226497076, 0.12656286649871618, 0.16111552569782361, 0.19265592622105032, 0.13714840082684532, 0.09409055855940096, 0.15365971717983484, 0.14271581458160654, 0.13071092282189056, 0.1563600660301745, 0.125134336121846, 0.11414161504944786], [0.032869553615455516, 0.07789478855556808, 0.07766660040942952, 0.009750246190378675, 0.028749723023793194, 0.01687797255726764, 0.02770075294392882, 0.028469493627198972, 0.01996403225348331, 0.06164075995911844, 0.04308313466026448, 0.05558494995057117, 0.018054998363368213, 0.03588512226997409, 0.02515521238819929, 0.07958940113894641, 0.03598105970013421, 0.048548009581281804, 0.06925331748789176, 0.03470639880106319, 0.02555505187046947, 0.03916940404451452, 0.04093119212484453, 0.014621824138885131, 0.08585919829783961, 0.0651625327009242, 0.05669426405802369, 0.03565344974049367, 0.011549395840120269, 0.04145296275964938, 0.03174201978254132, 0.13259927305625752, 0.0370804216072429, 0.05228809990512673, 0.05553830967983231, 0.04342766558693256, 0.03062359210161958, 0.07758160223602317, 0.04228062440233771, 0.008453920145257143, 0.013635084997076774, 0.08289780642371625, 0.012672812608798267, 0.03824538194749039, 0.05368059530155733, 0.017518967360956594, 0.038641269493382424, 0.06488165206974372, 0.037267301813699305, 0.06827463250374421, 0.030396966176340356, 0.05886220729735214, 0.05266281026706565, 0.023411983565893024, 0.0668322536512278, 0.014513062396872556, 0.008515973895555362, 0.03326515914523043, 0.03851519344607368, 0.054292692730086856, 0.04090982198249549, 0.025782887496461626, 0.08019258166314103, 0.10509291270864196, 0.0656498788157478, 0.12863520998507738, 0.09377377282362431, 0.030485407914966345, 0.2637722867075354, 0.060638827198999934, 0.007891945515439147, 0.09074318310013041, 0.12939113192260265, 0.2801250061020255, 0.3637866012286395, 0.3930611803662032, 0.31544794037472457, 0.534563212422654, 1.5394611493684351, 4.14639450609684, 10.022516995668411, 19.264816157519817, 28.765529952943325, 31.135949157178402, 31.529245153069496, 28.256775252521038, 8.728014808148146, 6.195190418511629, 5.013859933242202, 3.9441560581326485, 1.9760330230928957, 0.5470008356496692, 0.6413858116138726, 0.44191800872795284, 1.1441335687413812, 1.2657081638462842, 0.6898803531657904, 0.33521732955705374, 0.45149999612476677, 0.2603204984916374, 0.10109863680554554, 0.07884293416282162, 0.04304860623960849, 0.09265849555958994, 0.09397828645887785, 0.054515218289452605, 0.08702772465767339, 0.025673511627246626, 0.01693232374236686, 0.054669084056513384, 0.054611144587397575, 0.02822388727508951, 0.013940768203610787, 0.05251238064374775, 0.04858963664446492, 0.02995538274262799, 0.026907185565505642, 0.026840514728974085, 0.027472496149130166, 0.03265435676439665, 0.04844262090045959, 0.023166998762462754, 0.05909881510888226, 0.10424811116536148, 0.0249561776581686, 0.09792699449462816, 0.023068259724823292, 0.06729309767251834, 0.05130043122335337, 0.044941079104319215, 0.0497301209543366, 0.02094502346153604, 0.01832289512094576, 0.012439314396033296, 0.014505683593597496, 0.091301396896597, 0.08306533884024248, 0.03996599938545842, 0.10467898726346903, 0.055693960312055424, 0.0852611534355674, 0.047176097650662996, 0.055996979208430275, 0.06784213852370158, 0.04729575783130713, 0.02990788714669179, 0.023125733496272005, 0.03908105136360973, 0.032577815363765694, 0.03639837676018942, 0.030824079585727304, 0.033341333182761446, 0.01214034020449617, 0.04154427660978399, 0.029024020805081818, 0.04653225856600329, 0.021788511403428856, 0.06932842283276841, 0.004686593465521582, 0.0368615585466614, 0.06522473209770396, 0.056562020763522014, 0.08063054527156055, 0.02121669218468014, 0.046764747457928024, 0.015693428795202635, 0.036286791146267205, 0.028737418215314392, 0.02298920058819931, 0.07496145728509873, 0.07546925698989071, 0.05784586945082992, 0.08920903768739663, 0.055648496345384046, 0.06236269895453006, 0.06303860252955928, 0.03170978830894455, 0.03305526865005959, 0.0718438062176574, 0.03341676507261582, 0.03275436858530156, 0.027383974629628938, 0.044853702347609214, 0.0665247299184557, 0.018749843402474653, 0.02314368604857009, 0.05929719118284993, 0.03825030980806332, 0.0024423414424745715, 0.08913580255466513, 0.019893231365131214, 0.027394837816245854, 0.049128740138257854, 0.03295529393653851, 0.042633626944734715, 0.027411020346335135, 0.047689474595244974, 0.025880348184728064, 0.038243407834670506, 0.025622010289225727, 0.0702882424229756, 0.006087342935643392, 0.03149564901832491, 0.029009571189817507, 0.058016607945319265, 0.05352474428946152, 0.039454867437598296, 0.08161968711647205, 0.05298046802636236, 0.009998744135373272, 0.09611527100787498, 0.043889852895517834, 0.05819129466544837, 0.03758275168365799, 0.04156886767304968, 0.04064725755597465, 0.07982691065990366, 0.02015359903452918, 0.05200887797400355, 0.013565574517997447, 0.0696335123211611, 0.01467326796046109, 0.028790786054742057, 0.09625409715226851, 0.011198003758181585, 0.028771905817848165, 0.03524708306940738, 0.039765964611433446, 0.01928641246195184, 0.049301727340207435, 0.01666191852564225, 0.07241348619572818, 0.02832894755556481, 0.0522370030375896, 0.0586734086391516, 0.012826359252358088, 0.02653841980645666, 0.11518258848809637, 0.027962671701970976, 0.08422605038504116, 0.059402398037491366, 0.07166888943174854, 0.07715122337685898, 0.08125749678583816, 0.18614476779475808, 0.06019150881911628, 0.03545052430126816, 0.058998346867156215, 0.10710381378885359, 0.15424213983351365, 0.18847692233975977, 0.20491993142059073, 0.21623753505991772, 0.4503533779643476, 1.289633580017835, 3.7354567693546414, 10.488226655870676, 20.323294959962368, 31.965986117720604, 34.88406993448734, 33.95832560956478, 30.546853467822075, 9.419270865619183, 6.276081427931786, 4.621639279648662, 3.2783645717427135, 1.442441192921251, 0.3717590484302491, 0.29407666996121407, 0.4201146005652845, 0.9137919475324452, 1.0890023270621896, 0.5488962214440107, 0.20274052571039647, 0.299148655612953, 0.18515187810407951, 0.21258015709463507, 0.06516455134260468, 0.019825963099719957, 0.12006059900159016, 0.11087995764683001, 0.058855394381680526, 0.04264450311893597, 0.055604657682124525, 0.00965601198913646, 0.00014779394092556686, 0.02474907392752357, 0.03981788155215327, 0.05669863159710076, 0.08599590189987794, 0.025168647116515785, 0.04965726060618181, 0.021793706437165383, 0.13519894215278327, 0.006234075272004702, 0.04399303739774041, 0.03409553704841528, 0.03337543486850336, 0.014009261012688512, 0.08284291718155146, 0.02734422705543693, 0.027805015415651724, 0.015011270770628471, 0.04738302326586563, 0.023968486711964943, 0.06957938749110326, 0.03196262689016294, 0.044712093149428256, 0.04041634201712441, 0.03362599505635444, 0.04921422070765402, 0.04784012315212749, 0.08597372652729973, 0.04261288762791082, 0.02650114915013546, 0.053709390631411225, 0.09194909885991365, 0.03609829305787571, 0.03980716865044087, 0.014633950831921538, 0.004009916201539454, 0.030980173651187215, 0.03298872397863306, 0.12969109317054972, 0.024300620061694644, 0.07512029915233143, 0.05379910515330266, 0.014357562049553962, 0.017998335388256237, 0.07240818726131693, 0.027068077615695074, 0.008209412171709118, 0.05884103011339903, 0.07689060337725095, 0.04633918513718527, 0.021249803103273734, 0.05603907382464968, 0.020761119267262984, 0.0420508740353398, 0.0177492928924039, 0.030938023373892065, 0.015208759050437948, 0.04912179363600444, 0.05836850839841645, 0.0456884774757782, 0.005288789716360043, 0.02039070222963346, 0.04673489456763491, 0.08178608404705301, 0.04642352650989778, 0.026011160989583004, 0.040874347323551774, 0.12394937119097449, 0.23409954534145072, 0.14347139513120055, 0.1014014998509083, 0.14872796775307506, 0.10832651692908257, 0.0865511545271147, 0.15267128037521616, 0.07789855124428868, 0.1331811910495162, 0.19551622273866087, 0.14386268507223576, 0.06849928802694194, 0.16437723505077884, 0.13266496796859428, 0.14092431461904198, 0.16949437296716496, 0.10592607737635262, 0.08963252941612154, 0.12428321148036048, 0.09452501923078671, 0.11137344874441624, 0.20274816983146593, 0.16025332821300253, 0.16205331834498793, 0.17745346151059493, 0.13537901686504483, 0.16075567313237116, 0.14323977084131911, 0.14281480223871768, 0.12023086994304322, 0.22624609409831464, 0.12433859053999186, 0.2117930055828765, 0.167386079847347, 0.1479904362349771, 0.13192731770686805, 0.15404124045744538, 0.1847213730798103, 0.11226919872569852, 0.19631275499705225, 0.19121973688015714, 0.13324454077519476, 0.1059097723918967, 0.17267544055357575, 0.14726013323524967, 0.09774381760507822, 0.24446023860946298, 0.0788434907735791, 0.15066586376633495, 0.12560401170048863, 0.17735756118781865, 0.1315826494828798, 0.15099208219908178, 0.13828793889842927, 0.14894032588927075, 0.11055693044909276, 0.1390745709068142, 0.21169617015402764, 0.11315913026919588, 0.19440697913523763, 0.1601962570566684, 0.20145285496255383, 0.20487869769567624, 0.1938352730940096, 0.2381634124321863, 0.20302736578742042, 0.22852678812341765, 0.48569433158263564, 0.13272263284306973, 0.34762333729304373, 0.2944418363040313, 0.34910347661934793, 0.45214744575787336, 0.5676627019420266, 0.47132477920968086, 0.3412379580549896, 1.0531873488798738, 2.8154536988586187, 6.881141010671854, 16.063047163188457, 29.030166752636433, 46.20230220258236, 48.62691029906273, 49.507794231176376, 42.49818876385689, 15.565548408776522, 10.624073166400194, 8.454858865588903, 5.837449114769697, 3.791962587274611, 1.839982985984534, 1.0954269510693848, 1.521868093404919, 2.215876984409988, 2.749147731810808, 1.5574318100698292, 0.7982782647013664, 0.5754503246862441, 0.31846301921177655, 0.35983502108138055, 0.3576537303160876, 0.16444790235254914, 0.2873948175692931, 0.20085447613382712, 0.23260437010321766, 0.20119060965953395, 0.24585866747656837, 0.1858269950025715, 0.17222228518221527, 0.14029086189111695, 0.16559665789827704, 0.13577545731095597, 0.20129697426455095, 0.1090392236073967, 0.14519381598802283, 0.14193126058671623, 0.23921916203107685, 0.14017378067364916, 0.11544988781679422, 0.13197122316341847, 0.11815431847935542, 0.08165431572706439, 0.3517114429268986, 0.15257684950483963, 0.19212229235563427, 0.12980219267774373, 0.08909016789402813, 0.0870856195979286, 0.20787937886780128, 0.14295797736849636, 0.08908259798772633, 0.10119232552824542, 0.12868906022049487, 0.06823130592238158, 0.16585980862146243, 0.29502071149181575, 0.15008881426183507, 0.19106195628410205, 0.2364478787058033, 0.15270362317096442, 0.14613019855460152, 0.1284518846659921, 0.16808745393063873, 0.1769017637707293, 0.15841885789996013, 0.1098588589229621, 0.1320632197894156, 0.13661650358699262, 0.12979885301319882, 0.13499768654583022, 0.06860594206955284, 0.0973836236516945, 0.17484409996541217, 0.09243409978807904, 0.11479308712296188, 0.13490707031451166, 0.17076585005270317, 0.10291066457284614, 0.05283171194605529, 0.17219283676240593, 0.15916060481686145, 0.12760537618305534, 0.048419332306366414, 0.18477747944416478, 0.17883207503473386, 0.12117029531509615, 0.1345174724701792, 0.11033119139028713, 0.16046938224462792, 0.13752870698226616, 0.10469402317539789, 0.08719633318833075, 0.1398608021554537, 0.11048923173802905, 0.1270756163285114], [0.04211902916722465, 0.15650006476789713, 0.01703029094642261, 0.04227460187394172, 0.02448250375891803, 0.055294191333814524, 0.026154078223044053, 0.03982887646998279, 0.058120063331443816, 0.06261576389078982, 0.048731405404396355, 0.031120890416787006, 0.07341750068007968, 0.019829278644465376, 0.08316810402902775, 0.03851681874948554, 0.043923101111431606, 0.05927199155848939, 0.04533887025900185, 0.038741374082746916, 0.04336467580287717, 0.038084580810391344, 0.053658197284676135, 0.05963870156847406, 0.02154995916498592, 0.04348280715930741, 0.012016182608931558, 0.03092790604569018, 0.024206029629567638, 0.029302704679139424, 0.052962734407628886, 0.024768449547991622, 0.0204332755311043, 0.02792611350741936, 0.04395017836941406, 0.060732816491508856, 0.025616327293391805, 0.07265171559993178, 0.006727204108756268, 0.014174518746585818, 0.05855915500433184, 0.04501357951085083, 0.02677829677850241, 0.028276403500058223, 0.019197824149159715, 0.04734994945465587, 0.016898142275749706, 0.041496931298752315, 0.02134816735633649, 0.028042372796335258, 0.03269000582804438, 0.016652367085043807, 0.04561605499475263, 0.04019643623905722, 0.01671579659159761, 0.05939027134445496, 0.03584204430808313, 0.055765729703125544, 0.053964336912031285, 0.03861749479256105, 0.011284452830295777, 0.05628373022773303, 0.05791775387478992, 0.22485398832941428, 0.34096843970473856, 1.0520692588761449, 4.802666790783405, 8.910004142671824, 12.853321395814419, 16.575607359409332, 18.845134377479553, 19.834899567067623, 24.626862332224846, 23.91142152249813, 23.41851957142353, 22.754649594426155, 34.67082537710667, 54.01455380022526, 73.99238839745522, 81.80696547031403, 102.04796254634857, 96.50411322712898, 96.88515678048134, 94.3430095911026, 110.71704536676407, 101.62468805909157, 92.28972896933556, 81.80947333574295, 75.36884173750877, 75.65368965268135, 58.42785358428955, 53.77686895430088, 53.26775327324867, 57.8781408816576, 70.8720338344574, 56.421648636460304, 52.18055181205273, 36.384738609194756, 19.989992044866085, 9.089575856924057, 5.111569315195084, 2.1016135532408953, 0.7248149660881609, 0.2142945330706425, 0.13794784230412915, 0.13324592116987333, 0.0818706963036675, 0.014242494835343678, 0.01802570764994016, 0.02612460568343522, 0.05186011447221972, 0.09651669868617319, 0.08559840018278919, 0.0559848450939171, 0.020155782804067712, 0.05019685020670295, 0.031202778991428204, 0.037991444987710565, 0.05673923820722848, 0.07240603503305465, 0.018691189616220072, 0.04503299409407191, 0.04248829216521699, 0.03168656650814228, 0.028263614440220408, 0.023077779624145478, 0.06648661321378313, 0.07561027246993035, 0.013462832521327073, 0.05263326907879673, 0.1083562325220555, 0.0995086893090047, 0.04000426080892794, 0.07131996870157309, 0.03310304440674372, 0.016495913077960722, 0.013106716669426532, 0.04874250793363899, 0.10031832789536566, 0.03308058701804839, 0.029842223775631282, 0.03673452512884978, 0.07496380247175694, 0.04826388576475438, 0.036646877488237806, 0.03903018827259075, 0.0034138023147534113, 0.016923069160839077, 0.03102329243120039, 0.04196577567199711, 0.0027396926498113316, 0.10841515162610449, 0.006276671765590436, 0.036756218105438165, 0.05297693169268314, 0.034835016704164445, 0.04815529471670743, 0.010651223674358334, 0.028280604055908043, 0.04358670783403795, 0.015673366688133683, 0.0446918102534255, 0.010139108380826656, 0.05310583161190152, 0.027442808386695106, 0.05450610842672177, 0.03334827226353809, 0.03731222401256673, 0.06524272175738588, 0.011408421178202843, 0.011397664675314445, 0.037912365442025475, 0.013052360845904332, 0.02136022911145119, 0.025191035856551025, 0.02191643725382164, 0.04444152466021478, 0.07401990194921382, 0.030657259630970657, 0.14107238792348653, 0.058387448007124476, 0.0829306167725008, 0.01532216014311416, 0.07813754506059922, 0.04671353555750102, 0.03279280812421348, 0.038265497860265896, 0.04394610397866927, 0.06195006484631449, 0.009903343834594125, 0.07490089803468436, 0.060578178890864365, 0.03944736803532578, 0.012137973681092262, 0.0378716809063917, 0.013782020960206864, 0.03648789832368493, 0.048594200852676295, 0.097292020363966, 0.00848254849188379, 0.016874868524610065, 0.03253544986364432, 0.03372440012753941, 0.13224170630564913, 0.093951650778763, 0.03831652051303536, 0.061726396379526705, 0.07472448211046867, 0.018689601420192048, 0.06667178648058325, 0.011432144856371451, 0.07009830456809141, 0.036436181762837805, 0.022970923346292693, 0.032643922168063, 0.022475639962067362, 0.03591696411604062, 0.04439907381311059, 0.04866273819061462, 0.04604494955856353, 0.03411368255910929, 0.020560236589517444, 0.032044675026554614, 0.03523241823131684, 0.02068679874355439, 0.05436572748294566, 0.08016452848096378, 0.01232606915436918, 0.009160261979559436, 0.03376061693415977, 0.053941775622661225, 0.014627408800151898, 0.06315052582067437, 0.055541311667184345, 0.05761183318099938, 0.026785927911987528, 0.056733215678832494, 0.031268811580957845, 0.10617808846291155, 0.2020819587050937, 0.06612952885916457, 1.056963752489537, 4.337435904890299, 7.240604097023606, 11.141036376357079, 12.857407126575708, 16.403104215860367, 17.516841553151608, 21.862408071756363, 21.40905249863863, 23.581316135823727, 25.094087161123753, 40.959643721580505, 61.86944670975208, 82.71716102957726, 93.07391569018364, 113.94162073731422, 110.96347734332085, 115.5781777203083, 108.86247888207436, 126.66113421320915, 114.43092808127403, 102.33435317873955, 91.87813505530357, 83.99108067154884, 82.63166561722755, 66.395273655653, 58.74604471027851, 60.86587876081467, 66.59477815032005, 79.53407943248749, 64.4659423828125, 57.20961235463619, 38.54599043726921, 21.191531270742416, 9.996228106319904, 5.071958815678954, 1.7009013053029776, 0.6426720425952226, 0.13402263808529824, 0.15421745600178838, 0.05234020980424248, 0.0786998332478106, 0.1380220867577009, 0.04603549459716305, 0.02709742584556807, 0.016462408821098506, 0.02522657174267806, 0.03165789363265503, 0.009037576619448373, 0.036397222720552236, 0.040375256721745245, 0.045313718874240294, 0.0062174530194170075, 0.04320300264225807, 0.01586699301697081, 0.04860254630330019, 0.040184472818509676, 0.036954794559278525, 0.04333120865339879, 0.07022745310678147, 0.0319461252365727, 0.030591212198487483, 0.01368392202493851, 0.04531634236627724, 0.05150631412107032, 0.06453490583226085, 0.06375145021593198, 0.020282730874896515, 0.044117877769167535, 0.030129616752674337, 0.030592410766985267, 0.04458502633497119, 0.02683589671505615, 0.023617471269972157, 0.03762418207770679, 0.025676222321635578, 0.0290199965093052, 0.05801067076390609, 0.008079498293227516, 0.031434110132977366, 0.06659833612502553, 0.021268416167004034, 0.03134294842311647, 0.040695612187846564, 0.04925604815070983, 0.024107631979859434, 0.04057628597365692, 0.020911244610033464, 0.027738116368709598, 0.014375491409737151, 0.026039366312033962, 0.07463937261491083, 0.024604290192655753, 0.024488676572218537, 0.058888846688205376, 0.03393628699996043, 0.03229594396543689, 0.0667590630473569, 0.04927120651700534, 0.03195732053427491, 0.03041974825464422, 0.01936304848641157, 0.060709668905474246, 0.09440439796890132, 0.027329439762979746, 0.024248660447483417, 0.01955199557414744, 0.04433056245034095, 0.011842251024063444, 0.008446882729913341, 0.05453653648146428, 0.09656823342083953, 0.17852816556114703, 0.19655183044960722, 0.17541009146953002, 0.21432987414300442, 0.20906994701363146, 0.09623995181755163, 0.16902543953619897, 0.1586891183978878, 0.15415777248563245, 0.15644833707483485, 0.19105037878034636, 0.1705307821976021, 0.14259566087275743, 0.24167954485164955, 0.16288911021547392, 0.14906215685186908, 0.13209421187639236, 0.13529358082450926, 0.08684578715474345, 0.12559988535940647, 0.12962314212927595, 0.13390195003012195, 0.11621065597864799, 0.13473265076754615, 0.1969751069555059, 0.14491364039713517, 0.2460772596532479, 0.15044148283777758, 0.13569180242484435, 0.16599912458332255, 0.1743866698234342, 0.10745336534455419, 0.13094195339363068, 0.13190589932492003, 0.1475711673265323, 0.10165055718971416, 0.13443138333968818, 0.11975254834396765, 0.10365669368184172, 0.1031951817276422, 0.1183339033741504, 0.1364153073518537, 0.11297466204268858, 0.12801760953152552, 0.22852246882393956, 0.18754475517198443, 0.09144119525444694, 0.1413536470499821, 0.10960773099213839, 0.148695268726442, 0.0764850493578706, 0.12308197125094011, 0.1468811184167862, 0.10363288558437489, 0.10504769365070388, 0.24059118528384715, 0.10157685450394638, 0.23323722911300138, 0.2330911744502373, 0.12381120555801317, 0.12848732963902876, 0.276108265388757, 0.426863839966245, 0.8248198998626322, 2.966622174717486, 8.992591761052608, 16.273850351572037, 21.904669404029846, 24.383306801319122, 28.30890465527773, 31.13793835043907, 34.060699716210365, 37.35299505293369, 34.222521632909775, 38.40420104563236, 54.51893873512745, 78.66663917899132, 102.0898362994194, 113.70290234684944, 137.7436575293541, 132.9091313481331, 131.72014474868774, 128.18633437156677, 145.80478817224503, 133.16649913787842, 127.3657076060772, 113.74829471111298, 105.94210758805275, 101.63065373897552, 88.2219560444355, 82.23056674003601, 79.0639078617096, 88.38182106614113, 103.1811985373497, 83.42307195067406, 74.69836011528969, 54.20436501502991, 34.22045834362507, 16.902467720210552, 8.902522344142199, 4.121950892731547, 1.6432564985007048, 0.4968466440914199, 0.30820912099443376, 0.17474769498221576, 0.18399463238893077, 0.2338259303360246, 0.15808008232852444, 0.12189713990665041, 0.14990798255894333, 0.1665379831683822, 0.1229496240557637, 0.15056778152938932, 0.12917797226691619, 0.3275738615775481, 0.15680758107919246, 0.2094680053414777, 0.14974404213717207, 0.12832178617827594, 0.1460750718251802, 0.11088777988334186, 0.1205549064616207, 0.09891102294204757, 0.23088542249752209, 0.18258563533890992, 0.11643897028989159, 0.12655532627832144, 0.18226511660031974, 0.11626427614828572, 0.1592353539308533, 0.18196058372268453, 0.13331213558558375, 0.2029280664282851, 0.1241594657767564, 0.10616268147714436, 0.1146309649629984, 0.15210800513159484, 0.2755939570488408, 0.20382535265525803, 0.11918569594854489, 0.09349676620331593, 0.1556205455563031, 0.1574134555994533, 0.10000237336498685, 0.16689589130692184, 0.07536673670983873, 0.16179735161131248, 0.1732708211056888, 0.08445545565336943, 0.14251539018005133, 0.18481212289771065, 0.1500782312359661, 0.11765683462726884, 0.08296325642731972, 0.11028721171896905, 0.12464533501770347, 0.09839581660344265, 0.14415782236028463, 0.10444890664075501, 0.10696241981349885, 0.2088632737286389, 0.23260661138920113, 0.2078726698528044, 0.13428247882984579, 0.09217701983288862, 0.13576025812653825, 0.18222095881355926, 0.18644639145350084, 0.08735651834285818, 0.12093800309230573, 0.16065362782683223, 0.15738633752334863, 0.04859394110098947, 0.06297218773397617, 0.14359718916239217], [0.03954058178351261, 0.07169672739109956, 0.0217226810491411, 0.031202894024318084, 0.023959113386808895, 0.009084171433642041, 0.04101206024643034, 0.061695723416050896, 0.023336922749876976, 0.08729451190447435, 0.12148458743467927, 0.08631304386653937, 0.04026514056022279, 0.05096561129903421, 0.021010072705394123, 0.011456314750830643, 0.06362709595123306, 0.015637509823136497, 0.03609978477470577, 0.07054877336486243, 0.013587281409854768, 0.10071864977362566, 0.04771940912178252, 0.013083557951176772, 0.050648740216274746, 0.03129038952465635, 0.01186617415442015, 0.0906430376926437, 0.0354671372770099, 0.046644679096061736, 0.05426794210507069, 0.044995556454523467, 0.011062394823966315, 0.052536671137204394, 0.015730050072306767, 0.039256313248188235, 0.07144942152081057, 0.06229820632142946, 0.07286152816959657, 0.06092630181228742, 0.031348993215942755, 0.04527498247625772, 0.07186351023847237, 0.0407377439114498, 0.028268892965570558, 0.03258811637351755, 0.0795393432781566, 0.03425741429964546, 0.08256095301476307, 0.1264970825286582, 0.045716771855950356, 0.034641189995454624, 0.027955346704402473, 0.012193927905173041, 0.019525133538991213, 0.02509784622816369, 0.04630441922927275, 0.01303319488215493, 0.02810720125125954, 0.009801917294680607, 0.07497995160520077, 0.2156354603357613, 3.482235982082784, 14.807210750877857, 31.46715648472309, 38.378924801945686, 49.075012654066086, 59.541053250432014, 57.4745037406683, 73.65392535924911, 75.2701686322689, 83.48953798413277, 80.05896046757698, 79.99298840761185, 90.30512586236, 94.29741203784943, 98.94066408276558, 98.29285204410553, 92.03847125172615, 91.22634083032608, 77.22062677145004, 73.48449245095253, 62.45378315448761, 78.23574990034103, 73.13347488641739, 87.30298295617104, 87.91120111942291, 92.32837289571762, 98.42452257871628, 84.70460638403893, 104.80640172958374, 105.52992850542068, 101.56095027923584, 100.57409003376961, 97.74976998567581, 107.76132076978683, 103.96168425679207, 96.93701639771461, 76.51702612638474, 81.98370158672333, 77.16649487614632, 65.48336818814278, 46.3413405418396, 38.869767263531685, 25.01275822520256, 10.228947568684816, 2.4903027713298798, 0.7342373917344958, 0.16681933135259897, 0.0526964629534632, 0.06044750152796041, 0.038536381762241945, 0.03204926892067306, 0.030411261795961764, 0.020704625130747445, 0.04716152558103204, 0.024177074737963267, 0.005545435515159625, 0.019922152860090137, 0.04380933729407843, 0.036697725736303255, 0.0883385058841668, 0.04506550387304742, 0.09254224554752, 0.06552051505423151, 0.050044439049088396, 0.01353003677650122, 0.04991819601855241, 0.01583138291607611, 0.07129924793844111, 0.027404869797464926, 0.030026630774955265, 0.009830678300204454, 0.022240965445234906, 0.042828633668250404, 0.013633088619826594, 0.018357510743953753, 0.026433194398123305, 0.06296999839833006, 0.05148379736056086, 0.06489576029707678, 0.006379049182214658, 0.020030680825584568, 0.025496069683867972, 0.030030701454961672, 0.015791290243214462, 0.039119245993788354, 0.018788115958159324, 0.060962707866565324, 0.11107584010460414, 0.08921559085138142, 0.04819811292691156, 0.08180296790669672, 0.04058026388520375, 0.03828808512480464, 0.022451154654845595, 0.044196842281962745, 0.013732298921240726, 0.013433989879558794, 0.03325766716443468, 0.03360908151080366, 0.03152667450194713, 0.01480872846514103, 0.11507181552588008, 0.0494896799500566, 0.030103893914201763, 0.07966770514030941, 0.1284849992953241, 0.053826661096536554, 0.03656650289485697, 0.02117118925525574, 0.045908954707556404, 0.027279029382043518, 0.040952450945042074, 0.0514952524099499, 0.03844147962809075, 0.018933892315544654, 0.04812058075913228, 0.0179129587195348, 0.020264602062525228, 0.03592660461436026, 0.05305766251694877, 0.06730403692927212, 0.0733671682246495, 0.027103982720291242, 0.020494840391620528, 0.029866430777474307, 0.062238433747552335, 0.027882020658580586, 0.015442432595591526, 0.04061102219566237, 0.013687916634808062, 0.07193650046247058, 0.07515854202210903, 0.051536493556341156, 0.06871287812828086, 0.06457596144173294, 0.062169165394152515, 0.0524614656023914, 0.02201018163759727, 0.04360209255537484, 0.04064495318743866, 0.035084155679214746, 0.03536324773449451, 0.033786592102842405, 0.06385863860487007, 0.04378667210403364, 0.04461024822376203, 0.0543444278446259, 0.02650894170074025, 0.027567346332944, 0.03968537479522638, 0.058237942357663997, 0.050946467599715106, 0.05497398800798692, 0.05743385132518597, 0.009898461430566385, 0.029788369829475414, 0.04116458643693477, 0.033578041184227914, 0.011834092038043309, 0.04405427571327891, 0.05920804811466951, 0.03324609337141737, 0.08033856211113743, 0.05895889800740406, 0.03806802720646374, 0.11776314728194848, 0.04049478331580758, 0.06825512144132517, 0.05893373177968897, 0.048254876091959886, 0.029114134231349453, 0.0251742429099977, 0.032710626401240006, 0.0482252829533536, 0.019255067854828667, 0.19261601351900026, 2.2724675852805376, 11.916707754135132, 31.080160550773144, 36.33622281253338, 53.03936652839184, 63.77320155501366, 60.6079638004303, 84.85238805413246, 82.94088542461395, 91.27766847610474, 91.30406185984612, 93.26085045933723, 103.28962191939354, 108.81431266665459, 113.77477169036865, 106.68404817581177, 108.40360790491104, 107.46606141328812, 96.91713586449623, 97.50526070594788, 82.00893223285675, 98.96259650588036, 94.25161689519882, 109.56443041563034, 107.32897236943245, 107.26410984992981, 115.42661905288696, 103.27623903751373, 121.83683708310127, 121.10794499516487, 118.91568303108215, 119.34461921453476, 116.12626791000366, 124.67290610074997, 119.16218340396881, 112.72731989622116, 88.16168367862701, 94.29814159870148, 87.70697727799416, 72.49793618917465, 52.2023968398571, 41.73056535422802, 26.947262920439243, 12.332086265087128, 2.4778254283592105, 0.7125718449242413, 0.11570578775717877, 0.017656401978456415, 0.031089454896573443, 0.05106591255753301, 0.02827539232384879, 0.042775674010044895, 0.020978240136173554, 0.07553182003903203, 0.01731955970171839, 0.045205309652374126, 0.03683640345116146, 0.010092321535921656, 0.029622583315358497, 0.05070785970019642, 0.019917069148505107, 0.10371352735091932, 0.05443737441964913, 0.028289381807553582, 0.024564804225519765, 0.02942395305581158, 0.05615536465484183, 0.04811198297829833, 0.056029537227004766, 0.056837832526071, 0.02429284420941258, 0.0475578509940533, 0.06395528849679977, 0.015027354038466001, 0.030860552433296107, 0.027967096757492982, 0.05440561049908865, 0.1021759829018265, 0.061052255405229516, 0.005194091672819923, 0.03847258303721901, 0.03697059117257595, 0.07085967386956327, 0.06338087361655198, 0.005935631716056378, 0.03137309446174186, 0.039278529438888654, 0.03503118859953247, 0.033523155652801506, 0.06119169753219467, 0.04107201093574986, 0.0486591127992142, 0.028209389420226216, 0.05049634390161373, 0.05498543192516081, 0.033014446817105636, 0.040735766087891534, 0.041383230563951656, 0.0159420445561409, 0.0566876886296086, 0.026543959938862827, 0.039259630648302846, 0.05863030470209196, 0.04400072604767047, 0.07854352952563204, 0.0704727774427738, 0.025729595727170818, 0.033709163835737854, 0.023673508985666558, 0.02213128344010329, 0.08103527550701983, 0.06161806879390497, 0.03349247155711055, 0.008610960449004779, 0.12016967244562693, 0.19905450084479526, 0.07359816911048256, 0.11594705254537985, 0.26277418714016676, 0.09495024758507498, 0.16101426706882194, 0.10738819735706784, 0.058063040414708667, 0.1622373709687963, 0.14788819797104225, 0.15146474121138453, 0.12586073542479426, 0.10042532332590781, 0.16272046457743272, 0.05085128344944678, 0.1666925725294277, 0.18701429769862443, 0.17727084865327924, 0.1909290227922611, 0.16226653737248853, 0.22865161736262962, 0.13610713795060292, 0.09004363470012322, 0.14623647410189733, 0.14355948806041852, 0.1698114036116749, 0.2845813357271254, 0.0929684386937879, 0.28434402658604085, 0.10497975003090687, 0.12608048535184935, 0.1131983453524299, 0.17645791493123397, 0.14370407327078283, 0.10801592812640592, 0.1812003127997741, 0.14658553584013134, 0.16503997292602435, 0.1446500889142044, 0.13823253015289083, 0.16118427825858817, 0.12017368004308082, 0.18924750911537558, 0.16465983004309237, 0.0940296653425321, 0.1546679247985594, 0.12497982097556815, 0.11014111994882114, 0.2630612498614937, 0.1614433026406914, 0.21222965558990836, 0.09460557936108671, 0.1345327458693646, 0.1585933516616933, 0.10333949234336615, 0.1632930018240586, 0.14089136326219887, 0.10361609820392914, 0.15326173306675628, 0.2100303751649335, 0.5264388327486813, 5.043386248871684, 25.353687331080437, 51.08560636639595, 59.351747408509254, 74.8577007651329, 85.44420629739761, 86.37445718050003, 101.60615265369415, 102.18975573778152, 110.36035090684891, 108.63174006342888, 109.35835227370262, 121.98673143982887, 127.07319930195808, 131.9158798456192, 127.88782238960266, 119.277423620224, 120.5114758014679, 104.39319670200348, 99.87002581357956, 86.08634144067764, 102.31315031647682, 98.57609644532204, 116.66711568832397, 116.94624111056328, 121.95681944489479, 127.17903882265091, 114.99906599521637, 134.11834806203842, 133.71430814266205, 133.13573598861694, 128.50652039051056, 127.71056950092316, 138.1168583035469, 137.9817071557045, 130.53796738386154, 109.19392749667168, 113.46064254641533, 108.46044525504112, 92.52700343728065, 72.01032355427742, 60.555773600935936, 40.66513292491436, 19.56998348236084, 5.661088228225708, 1.9665388762950897, 0.2466561199980788, 0.15986551152309403, 0.17046716529875994, 0.1122063462389633, 0.1366902285371907, 0.1326139972661622, 0.18538400705438107, 0.1662302145268768, 0.11109695420600474, 0.12926781666465104, 0.12516213697381318, 0.20586714934324846, 0.11629514949163422, 0.1346116658532992, 0.08431348280282691, 0.19431970256846398, 0.22438256128225476, 0.19504234660416842, 0.10853405852685682, 0.09441086207516491, 0.13353013404412195, 0.15716243156930432, 0.09520920517388731, 0.11820187530247495, 0.1063333754427731, 0.08616050283308141, 0.17810502264183015, 0.07568776010884903, 0.10417700599646196, 0.1278685120632872, 0.2813928318209946, 0.178020907624159, 0.181311352935154, 0.09877141754259355, 0.10353376434068196, 0.17088729509850964, 0.1904351235134527, 0.11376188034773804, 0.2269434160552919, 0.09497782579273917, 0.18233737209811807, 0.20383857772685587, 0.1748124696314335, 0.14766389125725254, 0.15953936730511487, 0.2083730703452602, 0.11103206823463552, 0.09296495802118443, 0.10825539691722952, 0.08074470984865911, 0.13846075540641323, 0.11140991788124666, 0.21043886808911338, 0.1349051555735059, 0.1727459891117178, 0.17785255884518847, 0.19432054861681536, 0.1537752547301352, 0.26360203803051263, 0.2231272481731139, 0.08401060491451062, 0.17027699737809598, 0.15344608254963532, 0.11864107829751447, 0.07743410038528964, 0.10899153319769539, 0.1350632033427246, 0.13464939664117992], [0.008731017678655917, 0.02957368877105182, 0.06930810282938182, 0.015827273273316678, 0.04461551005078945, 0.04051143339893315, 0.06781473101000302, 0.10042864814749919, 0.03949391182686668, 0.037003360703238286, 0.042340248546679504, 0.04481250201934017, 0.063607236079406, 0.021408717329904903, 0.0254724267142592, 0.04058298756717704, 0.02255717416119296, 0.02490991959348321, 0.03768813665374182, 0.037852244058740325, 0.057578785344958305, 0.014718004622409353, 0.04885056092462037, 0.02284815356688341, 0.02830669796821894, 0.030180771136656404, 0.031577129411743954, 0.07113269515684806, 0.019238814820710104, 0.021937844503554516, 0.020067912519152742, 0.1503797509940341, 0.09885939172818325, 0.011383444198145298, 0.06227373771253042, 0.030602242368331645, 0.05491082381922752, 0.027684325505106244, 0.01719324616715312, 0.03867268460453488, 0.01674205377639737, 0.022342452284647152, 0.06557687374879606, 0.017499261484772433, 0.04536369880952407, 0.038524629853782244, 0.03405740179005079, 0.033245302984141745, 0.040412942980765365, 0.03148644638713449, 0.04803655479918234, 0.0384072072483832, 0.09822700027143583, 0.074883494671667, 0.04767473183164839, 0.10338411026168615, 0.07536600940511562, 0.05230663504335098, 0.12700582476099953, 0.17334254225715995, 5.962982978671789, 15.15280980616808, 34.20182414352894, 57.296859472990036, 74.64627251029015, 77.77442425489426, 79.64526146650314, 94.77324530482292, 88.45612987875938, 61.51355780661106, 71.37604638934135, 84.39877599477768, 77.1922042965889, 81.35866552591324, 78.49453121423721, 63.27942945063114, 71.37301415205002, 87.89034023880959, 60.638677552342415, 68.77782180905342, 60.548698380589485, 37.68138103187084, 41.85050591826439, 30.441576316952705, 52.31791064143181, 49.933181405067444, 59.728679582476616, 58.79142947494984, 64.38391238451004, 53.19311007857323, 71.49189457297325, 66.16183698177338, 65.82240119576454, 63.7653511762619, 67.48762384057045, 76.32227897644043, 83.66659328341484, 87.95494437217712, 111.07687085866928, 98.83682325482368, 95.77024340629578, 108.00411254167557, 95.75666293501854, 95.57156726717949, 79.16309773921967, 71.46366208791733, 50.65736174583435, 38.63418750464916, 17.265690229833126, 6.112587600946426, 1.4064811100251973, 0.042123370731133036, 0.026112525374628603, 0.01890978921437636, 0.03579835407435894, 0.06269094345043413, 0.04942200721416157, 0.039470452538807876, 0.0210800145578105, 0.061761867327732034, 0.008916481310734525, 0.02600396030175034, 0.05876310831808951, 0.04665368134737946, 0.04558838401862886, 0.005950197755737463, 0.00940320123845595, 0.0519854743470205, 0.020937490662618075, 0.035042532326770015, 0.05954499800282065, 0.08134852119837888, 0.03625700504926499, 0.00825630477265804, 0.05466778529807925, 0.02345090550079476, 0.004007158659078414, 0.06567874836036935, 0.07173120757215656, 0.05658717956976034, 0.035789912144537084, 0.03220224039978348, 0.026298171760572586, 0.06981251091929153, 0.0035340427621122217, 0.08679597420268692, 0.02481904361047782, 0.0668159635097254, 0.0626005647063721, 0.036118987845839, 0.0244067527455627, 0.0029289120129760704, 0.013893248487875098, 0.08839297210215591, 0.03387115240911953, 0.0957932679739315, 0.05397035201895051, 0.08957300175097771, 0.04123287144466303, 0.04223858173645567, 0.04460272284632083, 0.023553364553663414, 0.035247042251285166, 0.044084173132432625, 0.03137624487862922, 0.06369681330397725, 0.031247675215126947, 0.062284610175993294, 0.013251127475086832, 0.06407583554391749, 0.00599803427576262, 0.01989378983125789, 0.05521714156202506, 0.04154930094955489, 0.051251364129711874, 0.03233715542592108, 0.05023246587370522, 0.04344456800026819, 0.04871635464951396, 0.0560711605794495, 0.05128276810864918, 0.02076493761705933, 0.059924521192442626, 0.08804484546999447, 0.03179703147907276, 0.08316425228258595, 0.09203512119711377, 0.024997556101880036, 0.053629131070920266, 0.038359565078280866, 0.019670557376230136, 0.05872521425771993, 0.03616483401856385, 0.027128236106364056, 0.052178673940943554, 0.04305481430492364, 0.029705230735999066, 0.03117295949778054, 0.09904659105814062, 0.026787863062054384, 0.011437218363425927, 0.02380839803663548, 0.10522337484871969, 0.040664571861270815, 0.009787149483599933, 0.01071945302101085, 0.018671498582989443, 0.02563766774983378, 0.05232656912994571, 0.049160344497067854, 0.01334627544565592, 0.047171184633043595, 0.011241061311011435, 0.033658901884336956, 0.012124762524763355, 0.020758495775226038, 0.05361315263144206, 0.07316318151424639, 0.05969722733425442, 0.08821164316032082, 0.04542731570836622, 0.03825529704045039, 0.041773655902943574, 0.0520171677635517, 0.04216543566144537, 0.04492404681514017, 0.060101304479758255, 0.06008491414831951, 0.05645972312777303, 0.041162033448927104, 0.09833498275838792, 0.05964826043054927, 0.05142385038197972, 0.07751647877739742, 0.11558850615983829, 0.12192384238005616, 4.874148080125451, 14.96848264709115, 38.91897842288017, 71.16434454917908, 86.57060265541077, 90.52935943007469, 92.27328345179558, 102.50310212373734, 99.12875398993492, 79.72892537713051, 90.8628523349762, 99.62166354060173, 94.72244963049889, 98.61241489648819, 95.34269034862518, 87.17698931694031, 96.67577281594276, 110.95026165246964, 87.55637615919113, 99.8178394138813, 79.97791841626167, 54.33124780654907, 64.35863614082336, 55.04939407110214, 69.27501752972603, 67.27754071354866, 75.52511975169182, 83.30888047814369, 84.07974511384964, 77.86208555102348, 101.46643415093422, 92.96489953994751, 86.76167160272598, 82.3513774573803, 81.24208018183708, 93.81437435746193, 101.96869120001793, 103.27539548277855, 125.14823019504547, 112.53777086734772, 108.83092537522316, 121.88836991786957, 111.50709137320518, 111.01649209856987, 94.33390527963638, 82.86403074860573, 56.8921659886837, 41.883001774549484, 18.314196467399597, 6.357018509879708, 0.9502358513418585, 0.08904824397177435, 0.04396639058541041, 0.05004397520679049, 0.038810549667687155, 0.056142859466490336, 0.06754064103006385, 0.017845302681962494, 0.034778795306920074, 0.00829541409984813, 0.03938040405046195, 0.03783496686082799, 0.10197518742643297, 0.02419071170152165, 0.060213398464838974, 0.07457978557795286, 0.022694246981700417, 0.06186146354593802, 0.04125710256630555, 0.039712014186079614, 0.11454187755589373, 0.07412498263875023, 0.011011468650394818, 0.018727363749349024, 0.04289466996851843, 0.028785140166291967, 0.04220236121909693, 0.027467696309031453, 0.03590490792703349, 0.050068261989508756, 0.015775569700053893, 0.03158692205033731, 0.06269020872423425, 0.013813621608278481, 0.03035112371435389, 0.006317944453257951, 0.02951034090074245, 0.05695409738109447, 0.026217713675578125, 0.049339116740156896, 0.015576319747196976, 0.025694935575302225, 0.04371388225990813, 0.05175459591555409, 0.01485604872868862, 0.0714597076876089, 0.04928158916300163, 0.0624714681180194, 0.030134552034724038, 0.047685229510534555, 0.0421073997131316, 0.02724281257542316, 0.051156024128431454, 0.0034128720790249645, 0.02841879009793047, 0.009238715338142356, 0.047552778414683416, 0.021148114028619602, 0.030003997126186732, 0.04445164755452424, 0.03273431575507857, 0.0051181592971261125, 0.04900322441244498, 0.04257609565684106, 0.05338625211152248, 0.034594724129419774, 0.10144358704565093, 0.1696313585853204, 0.23945466033183038, 0.12435134805855341, 0.14377669984241948, 0.1906391844386235, 0.15199963672785088, 0.13163737545255572, 0.10842431714991108, 0.1904238577117212, 0.1411516047664918, 0.17240659013623372, 0.22727631381712854, 0.1939946715719998, 0.15119543066248298, 0.2547000360209495, 0.19290674244984984, 0.07270471978699788, 0.20057701680343598, 0.13634800940053537, 0.10652179189492017, 0.10921804409008473, 0.1914656549342908, 0.1300019194604829, 0.10896362844505347, 0.16772858100011945, 0.19453701825113967, 0.19758896698476747, 0.09046129314810969, 0.20356900000479072, 0.11555938428500667, 0.29358631814830005, 0.20743661356391385, 0.08779680487350561, 0.2576503105228767, 0.14966366754379123, 0.1441511430311948, 0.1187663602468092, 0.11402847463614307, 0.16446801455458626, 0.0999768657493405, 0.2446604848955758, 0.12492733629187569, 0.13921850302722305, 0.1328506087884307, 0.13465190510032699, 0.15204866300337017, 0.17603728047106415, 0.1446733032935299, 0.20262080244719982, 0.33237534924410284, 0.2541296213166788, 0.1916676972177811, 0.14315293956315145, 0.2127760840812698, 0.1894836753490381, 0.15606426080921665, 0.25355522870086133, 0.15849173680180684, 0.6776189454831183, 10.854447204619646, 28.621878661215305, 60.023631155490875, 87.98505395650864, 100.14192402362823, 103.15425798296928, 104.86051082611084, 118.93516078591347, 114.73761722445488, 89.95588660240173, 100.71161225438118, 111.72823950648308, 106.81352242827415, 110.70247694849968, 100.95913857221603, 88.10698181390762, 95.0302255153656, 114.26373705267906, 84.5654958486557, 93.3108101785183, 84.61161017417908, 60.96221499145031, 64.31876108050346, 49.547752887010574, 74.25385996699333, 72.83702999353409, 85.08516356348991, 81.7342221736908, 88.49230393767357, 76.14564165472984, 94.12641361355782, 91.83437660336494, 91.62872403860092, 84.47028815746307, 93.77068430185318, 105.42402818799019, 110.39025530219078, 114.7140584886074, 136.2985646724701, 124.13204312324524, 122.849330753088, 135.45277565717697, 124.10802081227303, 121.81311875581741, 109.86788213253021, 102.34913438558578, 79.57303494215012, 59.52436074614525, 29.565278738737106, 10.406373348087072, 2.084672637283802, 0.2488993207225576, 0.18778421654133126, 0.12070620810845867, 0.24255521973827854, 0.09098545720917173, 0.1910774820134975, 0.10383683518739417, 0.11246485111769289, 0.16454923519631848, 0.11719530783011578, 0.18590192223200575, 0.22957167268032208, 0.15370984183391556, 0.15249203686835244, 0.1507338890223764, 0.11783513560658321, 0.2552345010917634, 0.09102869473281316, 0.08827137120533735, 0.27412919502239674, 0.18558839452452958, 0.16173067706404254, 0.09536545694572851, 0.18728096620179713, 0.09087954531423748, 0.2958140673581511, 0.19742076663533226, 0.16481192578794435, 0.14357231237227097, 0.1673202810343355, 0.07123498537112027, 0.12644585949601606, 0.1562929165083915, 0.11409736078348942, 0.16806680738227442, 0.12461786071071401, 0.23386795073747635, 0.11418771726312116, 0.08983083127532154, 0.06819925998570397, 0.16724030720070004, 0.08115585224004462, 0.16185105341719463, 0.1081827629241161, 0.20437782222870737, 0.11818622340797447, 0.17762175091775134, 0.10818227310664952, 0.12645152950426564, 0.13424975011730567, 0.1174759583955165, 0.1258244740893133, 0.11490362259792164, 0.07060154006467201, 0.2238810178823769, 0.18470081558916718, 0.1330200707889162, 0.14187938446411863, 0.15636733907740563, 0.08267998608062044, 0.212746650504414, 0.21067938330816105, 0.1168897285242565, 0.19926105538615957, 0.08382272280869074], [0.03440936161496211, 0.05708978424081579, 0.041979794841608964, 0.028335509996395558, 0.04669653295422904, 0.05399330293585081, 0.05233950105321128, 0.04161590499279555, 0.03064274507778464, 0.07106160483090207, 0.027827968187921215, 0.03577585957827978, 0.07689210993703455, 0.020696788051282056, 0.051044011779595166, 0.017923790364875458, 0.05340279087249655, 0.02569210613728501, 0.03328159771626815, 0.045949579871376045, 0.046534132488886826, 0.010866621832974488, 0.05663481802912429, 0.03985978692071512, 0.016466698434669524, 0.043406484692241065, 0.01819716973841423, 0.049974803332588635, 0.017502706905361265, 0.03196254896465689, 0.07018389645963907, 0.054302010394167155, 0.024079126087599434, 0.06616348953684792, 0.06865929506602697, 0.004548876831904636, 0.037395611725514755, 0.03220015867555048, 0.0458229286596179, 0.0279636624691193, 0.035766044675256126, 0.04937757483276073, 0.06371538926032372, 0.04775434201292228, 0.03579459880711511, 0.0066035576674039476, 0.05109417354105972, 0.049685751655488275, 0.0027257683359493967, 0.03981199632107746, 0.20635579421650618, 0.0746081727265846, 0.07744008209556341, 0.04592616140143946, 0.03253941293223761, 0.05824314852361567, 0.05382883558922913, 2.5986019475385547, 10.800770334899426, 31.092302799224854, 62.06495001912117, 61.1789021641016, 42.08826296031475, 54.676212295889854, 61.711295396089554, 52.01575085520744, 44.68577317893505, 50.24333216249943, 62.251086831092834, 31.20492495596409, 33.136543706059456, 41.99419140815735, 38.06576080620289, 37.80429303646088, 39.04890485107899, 43.36858905851841, 32.85861901938915, 30.625102669000626, 19.398390389978886, 15.992999821901321, 21.99936792254448, 21.169661544263363, 24.522217847406864, 27.759486436843872, 19.61899135261774, 22.312452122569084, 23.8753804564476, 22.95437067747116, 25.44920850545168, 20.909886583685875, 16.683346778154373, 28.804770447313786, 41.99258029460907, 34.80019323527813, 34.89272587001324, 28.599138781428337, 40.71277856826782, 51.54738798737526, 49.79983136057854, 62.35949881374836, 70.87631240487099, 66.54953017830849, 67.94973984360695, 74.55913558602333, 90.2644756436348, 90.10056003928185, 89.80197966098785, 84.0691588819027, 79.12408903241158, 59.5587033033371, 42.12010145187378, 9.506047759205103, 0.6454950536135584, 0.1036921312334016, 0.050996454956475645, 0.031849070874159224, 0.05902992525079753, 0.04850250108574983, 0.061978930680197664, 0.048010178870754316, 0.034212191530968994, 0.07153759608627297, 0.03214256059436593, 0.05325335201632697, 0.025145944819087163, 0.13037498225457966, 0.05235248492681421, 0.04083082407305483, 0.02338324204174569, 0.0394007314753253, 0.023035454942146316, 0.02059586524410406, 0.05628660976071842, 0.06282042595557868, 0.022796895282226615, 0.02625526634801645, 0.011443896764831152, 0.009082486758416053, 0.05906296195462346, 0.05904919882596005, 0.04314563833759166, 0.05847745567734819, 0.0375989713211311, 0.0066958019851881545, 0.09096435795072466, 0.04889069256023504, 0.0321667137905024, 0.03359080612426624, 0.020235680567566305, 0.022885257239977363, 0.08686073400895111, 0.05898676194192376, 0.012212261735840002, 0.04514344051131047, 0.0678476007306017, 0.0332947337301448, 0.05757698934758082, 0.08956285659223795, 0.05926857025770005, 0.07582676436868496, 0.053621958213625476, 0.08938417711760849, 0.04799235990503803, 0.09161179274087772, 0.04370177040982526, 0.044913857127539814, 0.0021522553970498848, 0.005090293971079518, 0.03212917967175599, 0.017331589915556833, 0.038825110605102964, 0.02409399501630105, 0.07071367857861333, 0.021344595770642627, 0.04896363083389588, 0.06042857305146754, 0.025087535941565875, 0.08435563679086044, 0.009219852727255784, 0.06887482959427871, 0.03818957615294494, 0.03182561158610042, 0.04788150530657731, 0.05432540288893506, 0.051758811314357445, 0.024068556049314793, 0.03510132897645235, 0.056721248547546566, 0.01447392987756757, 0.041275173862231895, 0.02083507428324083, 0.07787173744873144, 0.0013187531681069231, 0.015028267807792872, 0.015595296463288832, 0.027736435404221993, 0.09613024012651294, 0.019275849845143966, 0.0745942500361707, 0.03197099460521713, 0.017108825013565365, 0.059601764878607355, 0.0335643448488554, 0.046191189758246765, 0.039343805037788115, 0.0505147417425178, 0.088063451112248, 0.03295852227893192, 0.007275251409737393, 0.014083088008192135, 0.08144087405526079, 0.06837111912318505, 0.07040896016405895, 0.03460584150161594, 0.03781768595217727, 0.0627865617570933, 0.04258997752913274, 0.048145947366720065, 0.04626371985068545, 0.027089581344625913, 0.07572730173706077, 0.028477646119426936, 0.023737806805002037, 0.016750928007240873, 0.010045968847407494, 0.008972082086984301, 0.14264724013628438, 0.07743301684968174, 0.07829419017070904, 0.015492269667447545, 0.032121505864779465, 0.05806795714306645, 0.09828276524785906, 1.8867967114783823, 10.764525979757309, 30.163336247205734, 68.9654253423214, 69.17343378067017, 52.59923614561558, 65.60714274644852, 73.27326938509941, 65.76964482665062, 62.727235481143, 70.76008424162865, 85.48340499401093, 52.5492612272501, 54.85905848443508, 69.70513164997101, 58.47315855324268, 59.09340687096119, 62.78445661067963, 61.79103031754494, 46.28082498908043, 51.99685446918011, 35.40998071432114, 30.608816742897034, 41.05243854224682, 36.812116876244545, 39.166622534394264, 33.31627406179905, 34.91848088800907, 42.61733137071133, 44.04352404177189, 36.11410193145275, 41.54116451740265, 36.83648496866226, 37.054760456085205, 44.98355180025101, 57.425794154405594, 54.7838681191206, 66.40546470880508, 49.40115675330162, 70.74378311634064, 75.76131507754326, 69.07780051231384, 86.78937211632729, 92.3385639488697, 94.87796008586884, 84.70090538263321, 85.2016045153141, 99.27561610937119, 105.62987074255943, 99.63161900639534, 98.03909406065941, 89.68601748347282, 67.31797054409981, 48.375044614076614, 12.5605908036232, 0.7096768752671778, 0.07153824917622842, 0.06885153357870877, 0.03345500794239342, 0.034609036447363906, 0.10833342632395215, 0.03764310684346128, 0.02632839015859645, 0.036240967237972654, 0.01808933011488989, 0.013993993179610698, 0.03582247758458834, 0.08104219232336618, 0.056553152098786086, 0.049452769235358573, 0.03273670175985899, 0.045973287778906524, 0.04177205286396202, 0.008209032748709433, 0.027980884005955886, 0.06470227497629821, 0.0844043810502626, 0.03598370916733984, 0.04618134145857766, 0.05130866164108738, 0.03200091057806276, 0.015869681446929462, 0.06567434742464684, 0.019852984696626663, 0.04758351817145012, 0.04245516269293148, 0.045940481140860356, 0.03162843408063054, 0.015517377451033099, 0.028446075157262385, 0.02093763538141502, 0.03420377186557744, 0.01038215803419007, 0.10245187630061992, 0.05033782115788199, 0.055724021003698, 0.05526903994905297, 0.016614554660918657, 0.05785875684523489, 0.06261255039134994, 0.06353639808367006, 0.05377820627472829, 0.097752055444289, 0.0357279836316593, 0.0920538381615188, 0.03542560669302475, 0.07739026172203012, 0.07335348302149214, 0.07754221645882353, 0.028021171492582653, 0.08175230890628882, 0.017353958246530965, 0.02397815875156084, 0.008980008224170888, 0.01687894848146243, 0.02386510925134644, 0.03897494279954117, 0.06996194977546111, 0.04661010614654515, 0.1440902127069421, 0.148663044674322, 0.10946939466521144, 0.13259392959298566, 0.24901331460569054, 0.15228359727188945, 0.11228185234358534, 0.17902130784932524, 0.14510784560116008, 0.13464130723150447, 0.11475424311356619, 0.1632916956441477, 0.1157172465173062, 0.14857950853183866, 0.16486913053086028, 0.1306714554084465, 0.09949962768587284, 0.17553993762703612, 0.13780609209788963, 0.11212829456781037, 0.19012074975762516, 0.06381939383572899, 0.1465551820001565, 0.27946369315031916, 0.22079015092458576, 0.15538688778178766, 0.12651673459913582, 0.10532255546422675, 0.09800431886105798, 0.15064864594023675, 0.18559618707513437, 0.15262937871739268, 0.08847685705404729, 0.07272218994330615, 0.2272490769973956, 0.19927727873437107, 0.09342055505840108, 0.14317177527118474, 0.17351798596791923, 0.09320717275841162, 0.18100208515534177, 0.13628599554067478, 0.18287103564944118, 0.11562994026462547, 0.1498232441372238, 0.11757044121623039, 0.143331203435082, 0.1495908183278516, 0.1342410224606283, 0.13776199368294328, 0.3556882560951635, 0.21855388185940683, 0.1520818518474698, 0.16478268516948447, 0.13068612024653703, 0.2422465308336541, 0.18179317004978657, 4.69353474676609, 22.539260052144527, 50.19856296479702, 88.8495759665966, 90.01366630196571, 66.25400483608246, 80.09159311652184, 88.38630482554436, 73.84834572672844, 64.42106679081917, 72.66538560390472, 88.37479904294014, 53.29868741333485, 52.462853863835335, 62.514910474419594, 57.52112343907356, 53.096268475055695, 55.16961582005024, 63.92803564667702, 45.71948491036892, 44.92921091616154, 33.50830435752869, 27.884670719504356, 33.747345730662346, 36.14516906440258, 37.65464186668396, 44.94327776134014, 34.638462513685226, 40.126606822013855, 40.123426392674446, 39.44453962147236, 41.384742110967636, 36.955194398760796, 30.907885394990444, 45.61784416437149, 57.98199310898781, 51.250570714473724, 56.515195816755295, 49.12917494773865, 62.08460636436939, 74.41447734832764, 71.16052955389023, 87.24076509475708, 94.60744500160217, 86.4874555170536, 89.76731792092323, 96.76365450024605, 113.92216578125954, 116.20903506875038, 115.10219246149063, 112.07527488470078, 106.1956375837326, 85.00001013278961, 64.86864477396011, 21.783374212682247, 2.24181747995317, 0.1379502023337409, 0.27228887658566236, 0.13373032095842063, 0.21001385495765135, 0.22506006789626554, 0.1376369863282889, 0.19140144431730732, 0.07575554045615718, 0.17530950077343732, 0.11561527542653494, 0.12455210642656311, 0.09989332218538038, 0.2545125101460144, 0.19168528611771762, 0.10966492831357755, 0.09442592025152408, 0.20187204965623096, 0.11652111861621961, 0.14828587038209662, 0.13593782437965274, 0.18813310016412288, 0.1056705262453761, 0.10471492947544903, 0.14695019752252847, 0.07984579831827432, 0.13575733406469226, 0.19899551494745538, 0.07029755637631752, 0.12502510682679713, 0.13606357388198376, 0.2127782511524856, 0.14722762716701254, 0.1384736836189404, 0.13553526863688603, 0.07045289530651644, 0.10749966793810017, 0.1133580703753978, 0.24287616892252117, 0.1151048782048747, 0.13262088439660147, 0.14051625214051455, 0.14188478729920462, 0.1616093804477714, 0.21818550943862647, 0.13477455242536962, 0.16944632632657886, 0.19636029697721824, 0.21099617646541446, 0.18299607269000262, 0.17355558316921815, 0.12982824206119403, 0.16681103414157405, 0.12582359835505486, 0.08113068601232953, 0.13294164062244818, 0.15166328055784106, 0.06105778811615892, 0.10396927886176854, 0.07496182093746029, 0.17273248202400282, 0.1945222495123744, 0.26250701397657394, 0.08892347410437651], [0.029424236927297898, 0.057168963976437226, 0.030761713205720298, 0.011549651881068712, 0.12389330193400383, 0.09528014707029797, 0.06023552930855658, 0.015104834255907917, 0.020988945616409183, 0.05730344484618399, 0.016182077379198745, 0.06493246692116372, 0.032319128658855334, 0.02925064487499185, 0.027279953355900943, 0.021450364802149124, 0.08713304283446632, 0.037615202090819366, 0.033323510506306775, 0.010393295815447345, 0.08015007886569947, 0.026763463101815432, 0.11340794269926846, 0.04200442672299687, 0.0636863787076436, 0.11229164869291708, 0.023576348867209163, 0.018578809904283844, 0.09057346134795807, 0.029007747361902148, 0.07186217437265441, 0.059989919245708734, 0.04624701781722251, 0.025390554837940726, 0.03762591128179338, 0.01698271371424198, 0.0053284473051462555, 0.045770636934321374, 0.06536248212796636, 0.09960603681975044, 0.030731288861716166, 0.05986566888168454, 0.125672452559229, 0.023486901518481318, 0.008507584843755467, 0.017771460843505338, 0.022301945864455774, 0.06153471076686401, 0.10466939129400998, 0.013633408671012148, 0.02142950859706616, 0.09702463939902373, 0.015828362375032157, 0.0516091646568384, 0.06801193449064158, 1.5530249965377152, 15.439215637743473, 48.652099147439, 64.90675672888756, 72.09733128547668, 68.42792138457298, 57.70191013813019, 51.0200484842062, 29.632187448441982, 37.11001709103584, 38.56650933623314, 25.67248262465, 29.35747168958187, 36.31911613047123, 30.891620367765427, 24.99114878475666, 28.31197679042816, 31.531663723289967, 46.94466456770897, 46.550355926156044, 64.81593400239944, 82.85816386342049, 79.81193572282791, 75.46051561832428, 73.49300399422646, 49.98413287103176, 62.63642035424709, 68.19214403629303, 84.90734830498695, 63.98928076028824, 53.16627211868763, 39.695086777210236, 58.3664944767952, 52.89688557386398, 57.13439159095287, 46.719279661774635, 51.17566533386707, 45.906351283192635, 54.240189492702484, 33.27675238251686, 38.589049726724625, 33.974562138319016, 36.93834610283375, 42.691351398825645, 37.17679850757122, 31.20797049254179, 23.910659663379192, 32.38921120762825, 57.1443622559309, 47.714438661932945, 66.42448648810387, 84.56632420420647, 67.24822908639908, 87.38366782665253, 78.02133500576019, 83.37983787059784, 69.31953594088554, 46.19449742138386, 12.669649701565504, 1.0731757013127208, 0.2269138488918543, 0.19649254769319668, 0.029365007976593915, 0.07286847467184998, 0.08543660456780344, 0.03107417778664967, 0.03590715663449373, 0.0391342633520253, 0.06059177132556215, 0.05970508296741173, 0.09858648176304996, 0.07157580184866674, 0.06939645551028661, 0.023898359322629403, 0.024518635218555573, 0.02535342518967809, 0.039492115829489194, 0.04463598961592652, 0.013386933078436414, 0.04457644339709077, 0.03710627803229727, 0.008923835994210094, 0.06719760553096421, 0.07059440802549943, 0.0003537838267675397, 0.06092429059208371, 0.0915989387431182, 0.03076763739954913, 0.061491729284171015, 0.030400014547922183, 0.15090854605659842, 0.020677952343248762, 0.018998785708390642, 0.029419136517390143, 0.05718360283935908, 0.02362034338148078, 0.032920412995736115, 0.04385714644740801, 0.08006505100638606, 0.0808505029999651, 0.010896979383687722, 0.05346595877199434, 0.03656156390206888, 0.039863208221504465, 0.07289246830623597, 0.014892393555783201, 0.013212871617724886, 0.04112402435566764, 0.015368080530606676, 0.03565580977010541, 0.044394476208253764, 0.05322984819940757, 0.05754088386311196, 0.0807441606593784, 0.04424559767358005, 0.06474177949712612, 0.03546541549440008, 0.020010435036965646, 0.05026421866205055, 0.015411656659125583, 0.06584639952052385, 0.026261908569722436, 0.10361414635553956, 0.06201969685207587, 0.019549659664335195, 0.03037129899894353, 0.022100590067566372, 0.0277913209356484, 0.04319411171309184, 0.1259059619042091, 0.042167023857473396, 0.032136159570654854, 0.027302846756356303, 0.07611410910612904, 0.05916012763918843, 0.006875900353406905, 0.051595995246316306, 0.036211622718838044, 0.05064406097517349, 0.03327892227389384, 0.029015246764174663, 0.025683261592348572, 0.03641439230705146, 0.09282290353439748, 0.02620554245368112, 0.019628959998954087, 0.10307826378266327, 0.059897473620367236, 0.010393550001026597, 0.07657842637854628, 0.012826530874008313, 0.04474547124118544, 0.0444773741037352, 0.045225815192679875, 0.027454547307570465, 0.012471076461224584, 0.051197602952015586, 0.01939780511747813, 0.0362944501102902, 0.053346413624240085, 0.01981308127142256, 0.05016981747758109, 0.06825832009781152, 0.02045099430688424, 0.06032756675267592, 0.04984775878256187, 0.08435521376668476, 0.055750181709299795, 0.034777993787429295, 0.06896318969666027, 0.03863185535010416, 0.08166510655428283, 0.012798140942322789, 0.013250263800728135, 0.06627905677305534, 0.0816685204335954, 1.3514372636564076, 16.597594879567623, 54.76768858730793, 74.82678562402725, 83.61583560705185, 82.29468449950218, 74.09806072711945, 62.53812722861767, 45.63676334917545, 48.166188821196556, 48.11457999050617, 33.68183724582195, 35.1297153532505, 48.61247107386589, 36.05787634849548, 33.40953625738621, 35.728187039494514, 35.90352103114128, 39.45636458694935, 43.39295335114002, 65.20355880260468, 57.306324765086174, 54.57012578845024, 44.91842709481716, 40.43491467833519, 31.57098401337862, 50.73831260204315, 45.232058465480804, 61.50503866374493, 49.35642555356026, 49.63029205799103, 30.39548859000206, 47.690667137503624, 45.12299671769142, 41.00598983466625, 29.97027050703764, 44.462546557188034, 49.14559006690979, 51.67936630547047, 38.67352679371834, 43.52545604109764, 43.21917347609997, 45.212618708610535, 43.29184837639332, 52.74073675274849, 50.84411412477493, 34.146768897771835, 51.39537334442139, 78.70882451534271, 70.19032001495361, 78.2138554751873, 97.46104627847672, 84.08063426613808, 99.75397244095802, 92.33523532748222, 94.6602089703083, 79.13555681705475, 52.51697815954685, 16.265323609113693, 1.1562083708122373, 0.2539413532940671, 0.059655459263012744, 0.05348956648958847, 0.0747929749195464, 0.10883663213462569, 0.040883780020521954, 0.03838875374640338, 0.07024253354757093, 0.035256486080470495, 0.057888112496584654, 0.02907199137553107, 0.06738687545293942, 0.050568651349749416, 0.038299937223200686, 0.06945181230548769, 0.06214382105099503, 0.06998232172918506, 0.008909992156986846, 0.0157620013851556, 0.04677787233958952, 0.042860501489485614, 0.04132739137276076, 0.03354047737957444, 0.016111326585814822, 0.04640845720132347, 0.029511498651118018, 0.09266653301892802, 0.046063443878665566, 0.0798244244651869, 0.023041034037305508, 0.03802440005529206, 0.033997514183283783, 0.016769145877333358, 0.024158778942364734, 0.06140302408311982, 0.030692407744936645, 0.04373577932710759, 0.016390544806199614, 0.00943206336160074, 0.027378115373721812, 0.020797614379262086, 0.024697706176084466, 0.02951220183604164, 0.060314304573694244, 0.07250887443660758, 0.02474034441547701, 0.02589734151115408, 0.07335009140660986, 0.015315879718400538, 0.007149695329644601, 0.04094503317901399, 0.032748149387771264, 0.022347903359332122, 0.006534004978675512, 0.027582293187151663, 0.027151446774951182, 0.04603469307767227, 0.04279945613234304, 0.0386787887691753, 0.04361005579994526, 0.05711840887670405, 0.1192112332500983, 0.14948467636713758, 0.0987945799715817, 0.09063470337423496, 0.31600469956174493, 0.21454374626046047, 0.18383526359684765, 0.13938615418737754, 0.23774040309945121, 0.10162067832425237, 0.0959470187081024, 0.22546775930095464, 0.15727641060948372, 0.13317308679688722, 0.09840334940236062, 0.16178529913304374, 0.1749655746971257, 0.11978764450759627, 0.19618540245573968, 0.17224417853867635, 0.1727354060858488, 0.12892875907709822, 0.19583693443564698, 0.11381831325707026, 0.13532222772482783, 0.17355810647131875, 0.118812128494028, 0.21646127774147317, 0.14025106793269515, 0.21738922951044515, 0.20427117560757324, 0.12174596442491747, 0.14183199091348797, 0.09712413171655498, 0.2527996333083138, 0.21893638477195054, 0.11684560042340308, 0.24619224801426753, 0.1456352008972317, 0.16644184535834938, 0.20952167746145278, 0.22721573972376063, 0.23416296928189695, 0.14765360509045422, 0.12492181471316144, 0.1788260042667389, 0.1071378709457349, 0.1855840752250515, 0.15539255779003724, 0.17689316970063373, 0.26929938700050116, 0.2101210062392056, 0.07018848293228075, 0.36592048360034823, 0.25519878894556314, 3.5560895316302776, 29.533392749726772, 74.12093549966812, 92.70741015672684, 96.41712069511414, 88.82729396224022, 81.28982082009315, 76.96447491645813, 52.607500702142715, 57.87064008414745, 55.55655285716057, 39.55753795802593, 45.72111502289772, 50.566159039735794, 48.11426840722561, 39.40035179257393, 40.589254796504974, 48.82826529443264, 69.82426285743713, 65.33934071660042, 86.65159910917282, 108.4496234357357, 109.88633394241333, 106.91161036491394, 103.77531945705414, 72.86486729979515, 86.7845007777214, 95.49153596162796, 118.43608796596527, 88.5754206776619, 71.5202334523201, 62.257656678557396, 88.0930669605732, 76.14433452486992, 86.95540800690651, 74.89260569214821, 81.04163333773613, 70.11000752449036, 78.22134107351303, 46.40106573700905, 57.145661786198616, 48.29879030585289, 56.05655662715435, 66.28831699490547, 56.794971004128456, 45.535757169127464, 35.522203892469406, 49.82248194515705, 77.31144189834595, 67.05649897456169, 88.68736267089844, 111.7712228000164, 90.99567800760269, 109.81313467025757, 103.37064877152443, 109.00502443313599, 98.76230925321579, 71.32829055190086, 24.55772504210472, 3.123060017824173, 0.5094659747555852, 0.3869706712430343, 0.12480503035476431, 0.22355603141477332, 0.1968444444355555, 0.11567326684598811, 0.11550048744538799, 0.13749011530308053, 0.18746353453025222, 0.1913547929143533, 0.12211507899337448, 0.24778304155915976, 0.16538971744012088, 0.16400610184064135, 0.08807142177829519, 0.12891655816929415, 0.13975985522847623, 0.1957804718404077, 0.11767588555812836, 0.19432023691479117, 0.10086924638017081, 0.11915557959582657, 0.12820028176065534, 0.09109010003157891, 0.08231566578615457, 0.21539121953537688, 0.1644761930219829, 0.12089014198863879, 0.1960381751996465, 0.17062518338207155, 0.2817437192425132, 0.13099952921038494, 0.09875817020656541, 0.10048125157481991, 0.10868172365007922, 0.08872735415934585, 0.12076761340722442, 0.08869587967637926, 0.12514769478002563, 0.13431418337859213, 0.08877131156623363, 0.12261926443898119, 0.11676196780172177, 0.12169356879894622, 0.11394712040782906, 0.0659349154739175, 0.10287332712323405, 0.24317495757713914, 0.12495219823904335, 0.08258353656856343, 0.12198173732031137, 0.11359203243046068, 0.2124608345911838, 0.17180310533149168, 0.18677624640986323, 0.09590093875885941, 0.08667760164826177, 0.07428925702697597, 0.12617846368812025, 0.10313967650290579, 0.19288052979391068], [0.07051904292893596, 0.04815021842659917, 0.018454414821462706, 0.04830186517210677, 0.057314154037158005, 0.03312761691631749, 0.04852836122154258, 0.06489636143669486, 0.04312251301598735, 0.029006025579292327, 0.010004653486248571, 0.04593775374814868, 0.1126677988213487, 0.06221775009180419, 0.07570548259536736, 0.09138606852502562, 0.03931233055482153, 0.03459537350863684, 0.06788923521526158, 0.08513381573720835, 0.034465360367903486, 0.019641708240669686, 0.022592329696635716, 0.03353175343363546, 0.08291347316117026, 0.03077878074691398, 0.05840365651238244, 0.03959913352446165, 0.07782222877722234, 0.03556216928700451, 0.09399888105690479, 0.0240726712581818, 0.05507332818524446, 0.01486130962803145, 0.00963397298619384, 0.04526534568867646, 0.049762638154788874, 0.05315952228556853, 0.050161869075964205, 0.025800558032642584, 0.02650112503033597, 0.011036042087653186, 0.027139986159454565, 0.05180701751669403, 0.048538235496380366, 0.022020443684596103, 0.0776836030127015, 0.018270185937581118, 0.056391252583125606, 0.049836852922453545, 0.015920971272862516, 0.04847926444199402, 0.16050239297328517, 2.461441894993186, 15.685712210834026, 46.723565831780434, 68.7182866036892, 74.39055383205414, 72.10518166422844, 77.5581094622612, 63.76329928636551, 35.98007932305336, 31.206207387149334, 43.12814176082611, 48.871487975120544, 55.50289213657379, 56.32132261991501, 47.76028700172901, 50.107155069708824, 73.51603835821152, 89.12134498357773, 85.46728625893593, 77.67419323325157, 57.58594036102295, 71.95845633745193, 60.441525131464005, 55.8476248383522, 58.18404346704483, 62.15033143758774, 73.24491530656815, 92.37078621983528, 97.55205139517784, 95.42234167456627, 66.18482574820518, 84.34530526399612, 99.67255041003227, 88.58028441667557, 63.42586599290371, 77.33310833573341, 78.29715460538864, 100.17106086015701, 73.98613393306732, 77.91424915194511, 95.65582394599915, 115.60301318764687, 87.13657468557358, 100.47474816441536, 72.6968403160572, 74.47295621037483, 72.61019736528397, 58.02738927304745, 71.77310228347778, 43.702116161584854, 35.37552796304226, 34.684261456131935, 41.583178862929344, 36.864227280020714, 38.468740582466125, 47.85061955451965, 52.27240048348904, 74.6103948354721, 76.42788290977478, 86.03411704301834, 68.75750049948692, 45.73298558592796, 8.355194963514805, 0.6601185689214617, 0.1575634881737642, 0.06587066032807343, 0.03652149905974511, 0.04412129535921849, 0.045377766218734905, 0.023988300199562218, 0.06321427630609833, 0.011433673680585343, 0.023549047109554522, 0.03884982783347368, 0.01892099935503211, 0.05775539422756992, 0.040229903388535604, 0.0034599606533447513, 0.019511901045916602, 0.04861832807364408, 0.0328212880413048, 0.045379706934909336, 0.031859835726208985, 0.024444973350910004, 0.10984367458149791, 0.021616995509248227, 0.027387080517655704, 0.025272343700635247, 0.04010438766272273, 0.02272082700073952, 0.032718285365263, 0.024756013008300215, 0.014278796061262256, 0.05207824651733972, 0.017797118744056206, 0.03480317485809792, 0.01952248963789316, 0.05034747278841678, 0.04437404488271568, 0.006594448268515407, 0.01147750213931431, 0.01875389181805076, 0.061169421969680116, 0.0412366192904301, 0.025972925541282166, 0.025518085494695697, 0.07924812452984042, 0.053817721927771345, 0.07701284252107143, 0.018103751899616327, 0.09896925927023403, 0.037260577955748886, 0.02606365680549061, 0.00938013065024279, 0.07504292283556424, 0.037902220283285715, 0.0434490802581422, 0.059511690415092744, 0.06031722492480185, 0.07497051890823059, 0.03692676735226996, 0.044910554570378736, 0.05198798651690595, 0.04254468796716537, 0.04193110995402094, 0.032700136143830605, 0.019146081613143906, 0.04872408782830462, 0.029646831135323737, 0.04449289983313065, 0.12369973497698084, 0.05831273600051645, 0.09622348356060684, 0.020258297518012114, 0.0410612683481304, 0.029674654251721222, 0.03902615841070656, 0.032973350389511324, 0.05530754628125578, 0.05026924300182145, 0.13253417186206207, 0.017949492794286925, 0.01778964160621399, 0.03899944480508566, 0.023552427592221648, 0.056687232208787464, 0.009399543378094677, 0.01892117190436693, 0.04549762306851335, 0.035992919220007025, 0.062471920828102157, 0.026651487860362977, 0.04357354584499262, 0.04295746308343951, 0.016360088920919225, 0.01694650432909839, 0.013880777623853646, 0.009225780631823, 0.031143121450440958, 0.07012826506979764, 0.004717541951322346, 0.005473808523674961, 0.06351245639962144, 0.042326867624069564, 0.026573258073767647, 0.028840266895713285, 0.028587482120201457, 0.07149194658268243, 0.03474243378150277, 0.05751784388849046, 0.038555328792426735, 0.03356110908498522, 0.07628806852153502, 0.014605313208448933, 0.14705755660543218, 0.07961936164065264, 2.330924361012876, 18.00839077681303, 53.79287749528885, 80.3651936352253, 83.61941501498222, 85.25431528687477, 85.3478054702282, 79.36894789338112, 54.435506612062454, 47.89028562605381, 45.797908902168274, 53.23767028748989, 51.809338331222534, 44.820373356342316, 42.82909780740738, 35.75790524482727, 54.805526956915855, 59.872931241989136, 59.6185576915741, 61.56113125383854, 58.97796146571636, 53.931304067373276, 47.857763171195984, 57.67995871603489, 59.31497298181057, 60.1258684694767, 67.5503508746624, 68.180972635746, 72.06382468342781, 67.18831390142441, 58.78940798342228, 64.56051930785179, 60.95540575683117, 58.82438890635967, 53.72666224837303, 55.442878156900406, 63.16297709941864, 72.64252603054047, 63.187455385923386, 63.8481867313385, 71.45423859357834, 67.86662310361862, 63.42732131481171, 60.91033637523651, 57.21815049648285, 76.57129481434822, 60.71598440408707, 45.02038702368736, 46.3879906386137, 42.246342077851295, 38.93687926232815, 41.463633477687836, 67.96920999884605, 65.6641548871994, 54.97171103954315, 65.45777276158333, 66.88268110156059, 87.829809486866, 84.8711134493351, 97.93169662356377, 78.1750899553299, 54.767494797706604, 13.479380551725626, 1.969645090866834, 0.09280059457523748, 0.09148523429757915, 0.010129184011020698, 0.017136093374574557, 0.07342979806708172, 0.03337609909067396, 0.04936987505061552, 0.033051513382815756, 0.11151985221658833, 0.0396413505950477, 0.02492250827344833, 0.06760302596376278, 0.04621230757038575, 0.07544190884800628, 0.03581953496905044, 0.09501723383436911, 0.03538349352311343, 0.00756976158299949, 0.01419839642039733, 0.017927938970387913, 0.02385891417361563, 0.03925225370039698, 0.04353566291683819, 0.021263803719193675, 0.015095683575054863, 0.11450295191025361, 0.09684581149485894, 0.06572788595804013, 0.03922526550013572, 0.046738011587876827, 0.024428816795989405, 0.04637658938008826, 0.09716484593809582, 0.047044629900483415, 0.04554764382191934, 0.04162672550592106, 0.015264428475347813, 0.06647833084571175, 0.03848237938655075, 0.11416372362873517, 0.022051843952795025, 0.05609906162135303, 0.013716646099055652, 0.08625214322819375, 0.008799573570286157, 0.07788664719555527, 0.005734335754823405, 0.017430557163606863, 0.041757406579563394, 0.03804577390837949, 0.027795777532446664, 0.08686768793268129, 0.02294182930199895, 0.07006068510236219, 0.0202212736257934, 0.035381515699555166, 0.07202032604254782, 0.04349478171207011, 0.07110542122973129, 0.17291276453761384, 0.13576540863141418, 0.1437364160665311, 0.1132155631785281, 0.20658553345128894, 0.1555370242567733, 0.1646933305892162, 0.16916275169933215, 0.23917305981740355, 0.17692870373139158, 0.08960912949987687, 0.12510043481597677, 0.1546128574409522, 0.18789571680827066, 0.1036971555731725, 0.2734618855174631, 0.16291637672111392, 0.22479926235973835, 0.19296681188279763, 0.17845512338681147, 0.1192175637697801, 0.08181495359167457, 0.11445667900261469, 0.13767151103820652, 0.10011540987761691, 0.11786601637140848, 0.1234036848472897, 0.1191877739620395, 0.16676511004334316, 0.1793622801778838, 0.245617157779634, 0.17296947946306318, 0.12095027821487747, 0.1326105833868496, 0.12386314105242491, 0.17765198601409793, 0.14180395257426426, 0.12014909269055352, 0.12089021620340645, 0.18581233016448095, 0.24809915194055066, 0.10928940901067108, 0.10327013864298351, 0.17652276379521936, 0.209245954756625, 0.16807854815851897, 0.10684164270060137, 0.19188881269656122, 0.19658668170450255, 0.17371941969031468, 0.1281332955113612, 0.32167942787054926, 0.20050988212460652, 5.078958040103316, 29.80917815119028, 75.64995065331459, 96.25040084123611, 94.93119522929192, 93.28333005309105, 97.51867398619652, 86.33520528674126, 54.710178673267365, 51.46271713078022, 68.56038987636566, 75.54893687367439, 80.55907443165779, 81.78347513079643, 71.04736402630806, 76.24929249286652, 102.47352451086044, 119.8434716463089, 122.33527913689613, 109.19588059186935, 88.72911483049393, 101.30716189742088, 88.3308582007885, 80.11648178100586, 84.48934033513069, 90.75035557150841, 104.89407822489738, 126.96137130260468, 141.24678075313568, 131.65693134069443, 98.37841585278511, 119.27663326263428, 142.92626023292542, 122.39950329065323, 88.31704214215279, 103.1511801481247, 109.28737208247185, 135.93016684055328, 104.8459044098854, 108.33200454711914, 127.80516922473907, 146.51174783706665, 113.29163521528244, 130.0843933224678, 98.76279562711716, 101.1928716301918, 92.18106999993324, 78.62459063529968, 98.14023703336716, 62.122623324394226, 51.69135466217995, 51.44082270562649, 60.64942717552185, 53.37227426469326, 55.9061075001955, 70.1217868924141, 72.83553287386894, 99.45909306406975, 99.68233868479729, 111.10239788889885, 94.98066857457161, 71.68797165155411, 25.680011920630932, 5.050447694957256, 0.3080646990565583, 0.38480766699649394, 0.12299406385864131, 0.14543148135999218, 0.13679130905075, 0.17674877744866535, 0.2121837908634916, 0.12154718016972765, 0.2644989680266008, 0.12559731752844527, 0.15437035326613113, 0.16328918718500063, 0.17982867546379566, 0.24540184589568526, 0.10417784462333657, 0.13542072556447238, 0.132167283736635, 0.12038500659400597, 0.18932550883619115, 0.07956341854878701, 0.19232765946071595, 0.09437081578653306, 0.1161236094776541, 0.14772326307138428, 0.10791949345730245, 0.20698881649877876, 0.13926758867455646, 0.1666409190511331, 0.11583987157791853, 0.2870561013696715, 0.21245313109830022, 0.20383167575346306, 0.1512705656932667, 0.1019428223662544, 0.13744230614975095, 0.08817325186100788, 0.13971560838399455, 0.10870269674342126, 0.1266607260913588, 0.20889088162221014, 0.10919894863036461, 0.1285214239032939, 0.11125293880468234, 0.178276666556485, 0.18611514125950634, 0.12612289167009294, 0.2327812832663767, 0.08768747167778201, 0.18703961977735162, 0.2024432213511318, 0.1287588814739138, 0.13905865926062688, 0.10729717294452712, 0.17946261854376644, 0.11119128117570654, 0.13372226123465225, 0.19418096548179165, 0.18555205897428095, 0.18632515420904383], [0.016715306774131022, 0.0600078087154543, 0.04846223215281498, 0.046973654607427306, 0.051848666844307445, 0.028906956285936758, 0.05269381348625757, 0.06048849034414161, 0.0278294543386437, 0.02957264419819694, 0.008809144492261112, 0.024042770128289703, 0.044786259677493945, 0.0582260345981922, 0.040771044077700935, 0.013459946494549513, 0.018481395600247197, 0.019463787612039596, 0.027383340093365405, 0.03724822119693272, 0.014015745528013213, 0.03062918232899392, 0.045955891837365925, 0.04725798251456581, 0.03062601335841464, 0.024170211727323476, 0.01527029422504711, 0.03880542513797991, 0.047288777932408266, 0.009632058245188091, 0.05069728409580421, 0.03057167887163814, 0.02345401324419072, 0.054035278808441944, 0.0369085439160699, 0.03540869685821235, 0.03466349153313786, 0.060335006783134304, 0.03693267484777607, 0.05127543940034229, 0.013365455324674258, 0.01279644327951246, 0.031152620940702036, 0.04740617827337701, 0.06462524004746228, 0.10220405092695728, 0.0743294443236664, 0.017476473840360995, 0.023451894412573893, 0.10149069858016446, 0.07686079130508006, 3.76005997415632, 20.931750610470772, 52.512992173433304, 70.8872178196907, 81.63708418607712, 74.2305900156498, 73.79551336169243, 49.91848759353161, 30.720063373446465, 36.58099427819252, 33.34312342107296, 37.718831822276115, 41.327296793460846, 34.04346004128456, 44.444847106933594, 66.15324184298515, 50.518961772322655, 50.2141535282135, 51.61888875067234, 69.12273690104485, 41.953206807374954, 24.962648414075375, 10.798756442964077, 6.784464698284864, 7.630678340792656, 3.0530751356855035, 3.921139743179083, 5.637357551604509, 6.41887491568923, 8.31622140482068, 10.73070589452982, 9.754062350839376, 6.509007979184389, 6.625008154660463, 5.910914372652769, 5.074039679020643, 5.869322279468179, 7.245644051581621, 7.030330980196595, 5.869044894352555, 8.374209143221378, 12.031011320650578, 14.605802558362484, 24.938764795660973, 24.459148831665516, 31.415692046284676, 29.159103333950043, 25.076991878449917, 49.0532436221838, 68.80101576447487, 62.75263711810112, 77.18844249844551, 70.10772004723549, 58.5298553109169, 31.26563809812069, 27.545930296182632, 38.30079719424248, 34.73975747823715, 33.396696746349335, 41.11106559634209, 78.9994253218174, 78.18496182560921, 82.30259567499161, 81.76489412784576, 69.72780883312225, 50.115526020526886, 17.342345416545868, 1.1314176698215306, 0.3634288563625887, 0.12366223425487988, 0.10504535588552244, 0.08002140530152246, 0.04495401473832317, 0.04445315782504622, 0.08024781971471384, 0.05260169069515541, 0.020565413069562055, 0.043351951680961065, 0.026673837637645192, 0.007099600361470948, 0.026273476796632167, 0.04117050506465603, 0.054985276074148715, 0.062002467893762514, 0.02122708781826077, 0.047274213284254074, 0.013359013482840965, 0.03193841432221234, 0.035541337201721035, 0.018095725572493393, 0.019863063062075526, 0.06555224928888492, 0.13017267279792577, 0.03635408167610876, 0.0512571565923281, 0.03786544315516949, 0.07282237987965345, 0.124201649450697, 0.0901176045590546, 0.035820599950966425, 0.03565177248674445, 0.0550104868307244, 0.04787491874594707, 0.0282765630618087, 0.015943339603836648, 0.024264792882604524, 0.012551860163512174, 0.020584310004778672, 0.022816797827545088, 0.03622338947025128, 0.03641689705546014, 0.0484279894590145, 0.08566953503759578, 0.03512392366246786, 0.061798477472621016, 0.01100557878089603, 0.008783577504800633, 0.01836946303228615, 0.019921358762076125, 0.04552008045720868, 0.0347547756973654, 0.024492057054885663, 0.03322994423797354, 0.009611942332412582, 0.014592986135539832, 0.017182668707391713, 0.029143042738724034, 0.013466229702316923, 0.07258703000843525, 0.026505236528464593, 0.039132192760007456, 0.011416079214541242, 0.09397701738635078, 0.04216466382786166, 0.016666386254655663, 0.02456977847032249, 0.04057397789438255, 0.02592599397758022, 0.04121797654079273, 0.020052240215591155, 0.05298913260048721, 0.027159495366504416, 0.07560441692476161, 0.01463784803490853, 0.04182769167528022, 0.021305143200152088, 0.014855077442916809, 0.036896246529067867, 0.051488157478161156, 0.03143675217870623, 0.04631440853700042, 0.029201202996773645, 0.04184103549050633, 0.07012316651525907, 0.04067025671247393, 0.05886811479285825, 0.015352869286289206, 0.00632982948445715, 0.1067674279329367, 0.05429734599601943, 0.034676605282584205, 0.05627512131468393, 0.024034521156863775, 0.03899647250364069, 0.051638316217577085, 0.01052932220773073, 0.030779615663050208, 0.017743559801601805, 0.06147245941974688, 0.02917529462138191, 0.07603519654367119, 0.03964930270740297, 0.032290611634380184, 0.018342695620958693, 0.07270543224876747, 0.10466152452863753, 3.8167595816776156, 21.074231564998627, 62.25023567676544, 81.76433175802231, 92.26259082555771, 80.26652052998543, 87.80804425477982, 71.46880701184273, 60.58353491127491, 52.87988908588886, 33.68189424276352, 37.28540048003197, 52.94763185083866, 43.66264387965202, 50.89226894080639, 58.66744972765446, 51.048429161310196, 54.91256721317768, 51.46022826433182, 63.421515226364136, 43.16574074327946, 27.139956280589104, 10.643954649567604, 9.103439413011074, 7.410588450729847, 4.9344242457300425, 5.587308062240481, 6.947201890870929, 8.275825772434473, 10.409457832574844, 12.964591775089502, 11.534561309963465, 8.16624915227294, 7.107598884031177, 7.357504824176431, 6.409559715539217, 6.5570426266640425, 7.54767369478941, 7.458019880577922, 7.987119164317846, 8.137465696781874, 11.229316089302301, 14.491462893784046, 22.497547790408134, 19.731847196817398, 24.03485979884863, 22.63448104262352, 23.055743537843227, 36.598287150263786, 46.54631294310093, 55.06807006895542, 55.880006700754166, 53.726270869374275, 55.47029368579388, 33.20480324327946, 26.811967380344868, 36.74187384545803, 43.33114966750145, 49.27995465695858, 58.41930404305458, 93.55853408575058, 86.22403085231781, 91.55223414301872, 93.41604933142662, 83.74644979834557, 63.95973354578018, 23.923755660653114, 2.060189601033926, 0.1227106896112673, 0.14883454015944153, 0.12774859584169462, 0.04731938781333156, 0.03654753360024188, 0.047962347452994436, 0.03857895506371278, 0.06110463618824724, 0.05374288004531991, 0.06503835655166768, 0.03825472558673937, 0.059408695160527714, 0.07687438745051622, 0.07125687872758135, 0.06819677379098721, 0.045942373617435805, 0.05664796888595447, 0.03148410491121467, 0.05136535059136804, 0.05260072590317577, 0.037795325042679906, 0.04589853866491467, 0.037766692985314876, 0.10089813818922266, 0.03273604866990354, 0.029592763821710832, 0.047434461521334015, 0.0531740683800308, 0.01809254361432977, 0.033570846062502824, 0.04570123870507814, 0.06784783079638146, 0.03935415799787734, 0.057134008820867166, 0.05841118188982364, 0.02162630760722095, 0.05055436500697397, 0.054942012575338595, 0.03293930436484516, 0.04163170902756974, 0.06214804758201353, 0.029391255884547718, 0.02949674475530628, 0.03343707023304887, 0.08866541451425292, 0.01679399483691668, 0.05528894434974063, 0.02486352237610845, 0.05425185605417937, 0.04378839388664346, 0.03477096193819307, 0.07600660901516676, 0.031884152194834314, 0.021408687643997837, 0.03609553226851858, 0.019956944743171334, 0.0276471754477825, 0.1684243741328828, 0.13514204911189154, 0.07086595986038446, 0.15588862414006144, 0.11228235700400546, 0.22592569410335273, 0.12639938620850444, 0.26258283178322017, 0.101868503697915, 0.09371509120683186, 0.0904375889513176, 0.09903812315315008, 0.07979647518368438, 0.14972194097936153, 0.09765198425156996, 0.20113322680117562, 0.14701811887789518, 0.23048644390655681, 0.08771997032454237, 0.12112017066101544, 0.08360030114999972, 0.13310816371813416, 0.170491982717067, 0.1348110957769677, 0.13061667006695643, 0.09358493334730156, 0.1684023323468864, 0.15455882909009233, 0.14180928119458258, 0.10331262659747154, 0.10197590730967931, 0.16470939066493884, 0.19309548544697464, 0.13125579280313104, 0.0888233954901807, 0.18122925655916333, 0.17833238700404763, 0.14937663450837135, 0.0912258388416376, 0.2030309132533148, 0.13988861785037443, 0.15047134686028585, 0.19062328763538972, 0.10126532317372039, 0.20427588082384318, 0.3075462346896529, 0.1464362899423577, 0.11104567922302522, 0.16916433989536017, 0.3434788284357637, 0.1306671361089684, 6.598011078312993, 33.13136078417301, 80.67663252353668, 95.14503255486488, 103.49910467863083, 93.0939482152462, 94.27636876702309, 67.63393118977547, 45.10468550026417, 50.82526333630085, 50.03848135471344, 56.6455402225256, 66.77419692277908, 54.12817910313606, 70.46588122844696, 92.46182173490524, 75.14776200056076, 74.90557059645653, 73.34776058793068, 92.03469425439835, 59.4732952862978, 34.94954042136669, 15.456428714096546, 10.73110582306981, 10.745676141232252, 6.4702467340976, 6.676781801506877, 9.208322335034609, 11.042821146547794, 12.736250627785921, 15.966129563748837, 14.889522884041071, 11.479503214359283, 11.56622976064682, 11.175299137830734, 7.938180640339851, 10.629628468304873, 11.256372537463903, 11.28982214257121, 9.493092354387045, 12.69229743629694, 18.008719459176064, 21.681222394108772, 34.9778451025486, 33.801660016179085, 43.47147613763809, 37.230911403894424, 35.15945255756378, 60.85833616554737, 91.4561752974987, 80.8701865375042, 99.67890366911888, 93.36553484201431, 81.93946436047554, 45.91654613614082, 41.32268384099007, 52.12748005986214, 48.77373822033405, 46.6515938937664, 59.319487139582634, 104.56896007061005, 99.46822017431259, 103.4941117465496, 104.31934386491776, 98.5650922358036, 82.2425588965416, 35.76832428574562, 4.782361155375838, 0.3388654603622854, 0.42129817768000066, 0.30373759218491614, 0.17146456724731252, 0.12574038875754923, 0.14343927497975528, 0.168300301884301, 0.21550285338889807, 0.1890218665357679, 0.14334861421957612, 0.09765579889062792, 0.1418533202377148, 0.22120685200206935, 0.2000879414845258, 0.1686773425899446, 0.19400195946218446, 0.11058067917474546, 0.10177590593229979, 0.14263423770898953, 0.2225009645917453, 0.13246475136838853, 0.1438828863319941, 0.1082014427811373, 0.2496204210910946, 0.2926279680104926, 0.19962864113040268, 0.15771594014950097, 0.10803940967889503, 0.13397794595221058, 0.18408967182040215, 0.14688009425299242, 0.22381797985872254, 0.17489176068920642, 0.16526613500900567, 0.10162982900510542, 0.09330270942882635, 0.11734652784070931, 0.14780909987166524, 0.181509654794354, 0.12457088276278228, 0.1747943612281233, 0.13642703328514472, 0.18659088760614395, 0.12608654127689078, 0.21214766311459243, 0.22415821003960446, 0.19180514296749607, 0.07743617839878425, 0.0822621643601451, 0.1215937350934837, 0.17077784315915778, 0.13643034326378256, 0.1179559127194807, 0.1030957413604483, 0.1075076089182403, 0.12115670659113675, 0.13133352535078302], [0.021519813126360532, 0.014933700567780761, 0.004694557637776597, 0.031706140653113835, 0.01672520702413749, 0.04237959350575693, 0.01664532595896162, 0.047179010580293834, 0.052283023615018465, 0.025973753035941627, 0.07667319863685407, 0.034626135529833846, 0.08026516370591708, 0.053643576975446194, 0.03249650566431228, 0.03285504091763869, 0.0446850826847367, 0.04651810209907126, 0.04601568296493497, 0.018106215829902794, 0.061171106644906104, 0.03446061062277295, 0.05356165500415955, 0.03893299290211871, 0.032906917040236294, 0.04601882967108395, 0.05705871051759459, 0.03309659143269528, 0.020629703467420768, 0.026881713201873936, 0.017295382385782432, 0.05948124009591993, 0.06141914724139497, 0.03399755871214438, 0.008091398631222546, 0.051450252285576425, 0.06977924786042422, 0.06781875345041044, 0.028244366840226576, 0.07225085195386782, 0.010982874628098216, 0.07058343166136183, 0.027996903263556305, 0.039003077617962845, 0.06831620761658996, 0.031752836584928446, 0.023448224492312875, 0.07576050542411394, 0.43850285292137414, 5.872426712885499, 31.423882506787777, 66.7167516052723, 73.36833268404007, 72.55554869771004, 67.49230518937111, 67.77772307395935, 55.825802609324455, 31.441726349294186, 24.92503423243761, 17.316531501710415, 42.56456360220909, 77.87159264087677, 64.64448720216751, 51.94218300282955, 32.27553270757198, 27.893355153501034, 23.52421659976244, 18.99215418845415, 10.595234613865614, 7.661070059984922, 3.6935929907485843, 1.1270444607362151, 0.46166353044100106, 0.3618492989335209, 0.040970433183247223, 0.14057976513868198, 0.05735903170716483, 0.154621095280163, 0.12984204600797966, 0.17393833841197193, 0.24331157212145627, 0.22740382963092998, 0.07698575413087383, 0.06630931413383223, 0.06619644089369103, 0.020356476234155707, 0.08247047779150307, 0.03152868943288922, 0.07426662894431502, 0.1086814193695318, 0.2234161365777254, 0.1188182586338371, 0.03163843823131174, 0.10618166561471298, 0.07912555141956545, 0.02970696921693161, 0.15103552752407268, 0.7742107124067843, 5.48394980840385, 4.850566545501351, 10.912827271968126, 16.236340664327145, 32.854028865695, 35.19404970109463, 49.19360429048538, 87.1275843679905, 85.76635301113129, 68.96564573049545, 46.68260782957077, 26.526374705135822, 23.64608746021986, 26.933492459356785, 49.605156406760216, 68.1316664814949, 78.19616362452507, 70.11050909757614, 70.562304854393, 69.73193541169167, 53.796468302607536, 18.302506394684315, 1.1376429232768714, 0.3580147703178227, 0.17715890309773386, 0.08862143484293483, 0.04701384561485611, 0.02608106573461555, 0.026355307854828425, 0.007043132663966389, 0.06615039805183187, 0.040854943872545846, 0.055440509459003806, 0.03718843378010206, 0.015767550794407725, 0.06021531320584472, 0.028200570850458462, 0.023174058442236856, 0.035726313799386844, 0.07355258640018292, 0.05069912462204229, 0.0419581204187125, 0.07778541083098389, 0.049820718631963246, 0.025426723404962104, 0.030722115916432813, 0.008881101275619585, 0.06969350011786446, 0.0401568018423859, 0.03827419954177458, 0.0055563098339916905, 0.05621763826638926, 0.019357317250978667, 0.03830549590929877, 0.01283026294913725, 0.05827711662277579, 0.07747824332909659, 0.014420686347875744, 0.02541975463827839, 0.03349178878124803, 0.034246115101268515, 0.0016518146662747313, 0.01912293959321687, 0.05164278765732888, 0.021259200548229273, 0.04761269941809587, 0.011447387641965179, 0.07872105124988593, 0.013586539262178121, 0.0975624960847199, 0.043504693094291724, 0.06363039850839414, 0.05344670746126212, 0.03864636804792099, 0.08204471509088762, 0.03952697821659967, 0.02083302038954571, 0.04660885933844838, 0.051290119081386365, 0.06265701988013461, 0.019037314305023756, 0.035822058271151036, 0.030926581312087364, 0.041249810965382494, 0.007946890418679686, 0.08230509018176235, 0.036637890079873614, 0.0035745123068409157, 0.06161778677778784, 0.021236754291749094, 0.04848471922741737, 0.09226762122125365, 0.043060847965534776, 0.02800957914587343, 0.05752535071223974, 0.025032830380951054, 0.07276592470589094, 0.026724578274297528, 0.009628922671254259, 0.0731975726375822, 0.016790486333775334, 0.05436076993646566, 0.023129327346396167, 0.04091943279490806, 0.05593755544396117, 0.023430726505466737, 0.012487378662626725, 0.00582007375669491, 0.04127884007175453, 0.02229331097623799, 0.03708999902301002, 0.014237602226785384, 0.061625156304216944, 0.016335829968738835, 0.12353393918601796, 0.06863973947474733, 0.010907975229201838, 0.029207375810074154, 0.013026564720348688, 0.06866236755740829, 0.041259221397922374, 0.03703104652231559, 0.06076363046304323, 0.02966483934869757, 0.04574087681248784, 0.18387599266134202, 0.38072045193985105, 6.117239026352763, 33.451166823506355, 73.2483047246933, 84.83865559101105, 84.54376101493835, 76.35834664106369, 88.43017727136612, 76.72017842531204, 53.87079231441021, 38.35817411541939, 21.48724090307951, 40.37065252661705, 59.89780470728874, 62.053961008787155, 49.91063341498375, 39.06379245221615, 35.04759795963764, 34.06165726482868, 27.211339250206947, 17.21623968333006, 10.695540681481361, 6.195701016113162, 1.9858582271263003, 0.5721690226346254, 0.5567046243231744, 0.058421586800250225, 0.06956745375646278, 0.19099042809102684, 0.1799934174050577, 0.3112028556643054, 0.2602325985208154, 0.2750657853903249, 0.16137089871335775, 0.01603784468898084, 0.08198796305805445, 0.12014549327432178, 0.1858160409028642, 0.13477542815962806, 0.1576076162746176, 0.10049791279016063, 0.037609461578540504, 0.13794916332699358, 0.05583702040894423, 0.02292515509907389, 0.05348513957869727, 0.02181268500862643, 0.12530056235846132, 0.1593934907577932, 0.8985383785329759, 3.4055140614509583, 4.407094717025757, 8.86670546606183, 13.445927146822214, 26.812455654144287, 30.399349182844162, 34.19338099658489, 50.15706539154053, 58.442478999495506, 54.19918209314346, 44.88995522260666, 27.19972137361765, 36.90230883657932, 49.65701602399349, 70.63018441200256, 85.91092765331268, 88.41519087553024, 81.10547751188278, 82.64995783567429, 85.89348658919334, 64.67064499855042, 27.441435903310776, 2.5998098077252507, 0.36970107292290777, 0.1163541353889741, 0.011270219365542289, 0.024056553666014224, 0.019263244466856122, 0.0414255812211195, 0.024666426506883, 0.0767217054089997, 0.04010451753856614, 0.08106549576041289, 0.06984902458498254, 0.041862951111397706, 0.03376612366992049, 0.02535466086555971, 0.028300825724727474, 0.044374612625688314, 0.052602095165639184, 0.03824757499387488, 0.020373183833726216, 0.055596809470443986, 0.03111845246166922, 0.04231434017128777, 0.0373035557277035, 0.031132723961491138, 0.03189696908521, 0.043251227398286574, 0.08711844478966668, 0.01811131623981055, 0.106075649819104, 0.018678222440939862, 0.014913715458533261, 0.01841527766373474, 0.03948957768443506, 0.03550648965756409, 0.060688829398714006, 0.029912432801211253, 0.08028782889596187, 0.016602299947408028, 0.024136219508363865, 0.05190305884752888, 0.0420665890123928, 0.018419652624288574, 0.029688909053220414, 0.036618048761738464, 0.0395265514816856, 0.024070604376902338, 0.03202177605999168, 0.05234870739514008, 0.06942085732589476, 0.041274231334682554, 0.05540695696254261, 0.024630797852296382, 0.05957068373390939, 0.04703743106801994, 0.04325368761783466, 0.10122572217369452, 0.1120827192789875, 0.11790612945333123, 0.07253260831930675, 0.08685680062626489, 0.14268733095377684, 0.11267976966337301, 0.1379719324177131, 0.06626363494433463, 0.10806694335769862, 0.1278241167892702, 0.1745427880086936, 0.17134067311417311, 0.2782586234388873, 0.1564371306449175, 0.23467248334782198, 0.17476963286753744, 0.08601457433542237, 0.2875891712028533, 0.08316857158206403, 0.0807797466404736, 0.12471013935282826, 0.15691572683863342, 0.14473830058705062, 0.12145478278398514, 0.12955891666933894, 0.10684905675589107, 0.16300387593219057, 0.20558961579808965, 0.11594423238420859, 0.1899792073527351, 0.11490328120999038, 0.14912951417500153, 0.12239552175742574, 0.12492895417381078, 0.1394891642848961, 0.12422632586094551, 0.11833192926133052, 0.13545864931074902, 0.0826071146002505, 0.15453726227860898, 0.2061806622077711, 0.16984524554573, 0.1809830268030055, 0.17321174615062773, 0.09765483409864828, 0.1069683198875282, 0.43840883765369654, 1.074096558149904, 12.044178564101458, 48.29972505569458, 89.93882551789284, 98.29877212643623, 92.64847531914711, 86.06095120310783, 87.74812147021294, 73.50923672318459, 45.5474529415369, 38.79226662218571, 24.768104553222656, 61.69522225856781, 106.43884733319283, 90.52967101335526, 73.76497820019722, 55.024699196219444, 46.91453978419304, 39.68323141336441, 31.452274583280087, 19.81452126055956, 12.627754099667072, 6.449035797268152, 2.6638895692303777, 0.9956017951481044, 0.9104962775018066, 0.3211033728439361, 0.23657275247387588, 0.4843190428800881, 0.4460013349307701, 0.6004058418329805, 0.8406133367680013, 1.1357154767028987, 1.0852570342831314, 0.41980447189416736, 0.35073082835879177, 0.25378823338542134, 0.14211362111382186, 0.17927013512235135, 0.23619614221388474, 0.18668797536520287, 0.5172623845282942, 0.4571764462161809, 0.18165017303545028, 0.19242991256760433, 0.18915243999799713, 0.18546493083704263, 0.3165050258394331, 0.35277710761874914, 2.0961698703467846, 7.911665663123131, 7.5144117046147585, 14.236412979662418, 20.92901285737753, 42.50468261539936, 44.094878286123276, 63.37549589574337, 113.9657798409462, 114.57375481724739, 92.85662055015564, 66.40930250287056, 41.1286548525095, 37.22427695989609, 42.34369285404682, 70.58995217084885, 88.61363142728806, 97.23425164818764, 91.88825011253357, 94.2580309510231, 98.2617013156414, 81.9231328368187, 38.850620090961456, 4.1307212971150875, 0.38748266408219934, 0.4324199433904141, 0.1059169192740228, 0.17141959309810773, 0.16090833290945739, 0.16990222764434293, 0.1253231384907849, 0.2016539769829251, 0.10509810032090172, 0.15975644550053403, 0.18359740526648238, 0.1146375181269832, 0.17243154114112258, 0.11097002468886785, 0.117428750381805, 0.07621041018865071, 0.206776873965282, 0.15510732075199485, 0.11121077739517204, 0.17933333641849458, 0.11530520612723194, 0.10951704796752892, 0.10409568887553178, 0.06061854430299718, 0.20189115253742784, 0.18414209713228047, 0.10347757634008303, 0.09375006862683222, 0.17334390780888498, 0.12394638775731437, 0.1102962956065312, 0.12442493200069293, 0.17278415034525096, 0.14617711713071913, 0.15283425600500777, 0.13060261378996074, 0.254446073086001, 0.10952277734759264, 0.0821197684854269, 0.13798024447169155, 0.12526428618002683, 0.10136642595170997, 0.16368249576771632, 0.10211349406745285, 0.12750704161589965, 0.243653301440645, 0.17792754544643685, 0.136723714240361, 0.10051036602817476, 0.16093306127004325, 0.22316511254757643, 0.14270812593167648, 0.15054547257022932, 0.12872460909420624, 0.2059673986514099], [0.015392799614346586, 0.012401161511661485, 0.01242832504431135, 0.04788179103343282, 0.019002667140739504, 0.08545489850803278, 0.011705677297868533, 0.06805665630963631, 0.01348853495073854, 0.01910022987431148, 0.05078060130472295, 0.03739813873835374, 0.04508831749262754, 0.014189732773957076, 0.04374237701995298, 0.061265830663614906, 0.011444331848906586, 0.04298428430047352, 0.058366378434584476, 0.0645638866990339, 0.04843828675802797, 0.05724944618123118, 0.039083971714717336, 0.010579997906461358, 0.049435877954238094, 0.029272337851580232, 0.09273697025491856, 0.10322869711671956, 0.08116189332213253, 0.02075691314530559, 0.024736494524404407, 0.05821303217089735, 0.0449496471992461, 0.028692815139947925, 0.06987963075516745, 0.027696207289409358, 0.048374050165875815, 0.019986539737146813, 0.03535434567311313, 0.11282304869382642, 0.03459064973867498, 0.11658370392979123, 0.03691855919896625, 0.06618928659008816, 0.027920864667976275, 0.19731017178855836, 0.021401119593065232, 3.207952925004065, 35.89148707687855, 57.477984353899956, 61.50548703968525, 76.1563266813755, 67.99821004271507, 71.74360066652298, 56.68067693710327, 24.72270268946886, 15.201233457773924, 26.142055727541447, 49.16245736181736, 83.64403009414673, 62.04038053750992, 41.96297988295555, 31.971655413508415, 21.867230013012886, 11.848330423235893, 5.582696534693241, 3.505260134115815, 1.3118655933067203, 0.5743260600138456, 0.11954638714087196, 0.055767050725989975, 0.02839510631019948, 0.06384474560036324, 0.049784787552198395, 0.0652144756168127, 0.09874873008811846, 0.06250372927752323, 0.025681654842628632, 0.038721566161257215, 0.037868114886805415, 0.03236974313040264, 0.0288542285488802, 0.0433797859295737, 0.05080847266071942, 0.1358025160152465, 0.20360520196845755, 0.20606405596481636, 0.1111405850679148, 0.13499865133780986, 0.06721716854372062, 0.08696619319380261, 0.08131915441481397, 0.09914278823998757, 0.09457429041503929, 0.13368061190703884, 0.07168710173573345, 0.11095261390437372, 0.041248801644542255, 0.03853103829897009, 0.15146903082495555, 0.23400735575705767, 1.9555753958411515, 4.965973952785134, 10.005143377929926, 17.69840531051159, 22.384807839989662, 27.286269329488277, 40.479269698262215, 57.04852759838104, 75.58034598827362, 49.39825750887394, 30.71125354617834, 15.966469645500183, 28.838565833866596, 46.30999222397804, 62.141728699207306, 67.61715888977051, 69.69227313995361, 73.8546533882618, 76.27488031983376, 59.85919117927551, 31.598171554505825, 2.2449171636253595, 0.20462362153921276, 0.19966905849287286, 0.03659251888166182, 0.029824768462276552, 0.09400802431628108, 0.034899290403700434, 0.010472851263330085, 0.009669689770817058, 0.05468732604640536, 0.05271774032735266, 0.024555451309424825, 0.06253430576180108, 0.0408745402819477, 0.04198988805001136, 0.02015711124840891, 0.02909373630245682, 0.03508506852085702, 0.024276886178995483, 0.059305299146217294, 0.015519192929787096, 0.029568642166850623, 0.07027327330433764, 0.03606003905588295, 0.0158054021812859, 0.014091071661823662, 0.02803434090310475, 0.02385419782513054, 0.030317112941702362, 0.0869865354616195, 0.06397070290404372, 0.042165736231254414, 0.024466306385875214, 0.025123810264631175, 0.0368714513751911, 0.02453692173730815, 0.02291189848619979, 0.0338351285608951, 0.02403865677479189, 0.08048985633649863, 0.030369354572030716, 0.04264373128535226, 0.10567452642135322, 0.043502537155291066, 0.0776996482454706, 0.04509817692451179, 0.05024136422434822, 0.05392353363276925, 0.029146317465347238, 0.0645752415584866, 0.024353006410819944, 0.03340637500514276, 0.039778736972948536, 0.06732341440510936, 0.08013955521164462, 0.01502332417658181, 0.04163312281889375, 0.06924361019628122, 0.027095559344161302, 0.05209286311583128, 0.043111154445796274, 0.07805995352100581, 0.03126161274849437, 0.08753347603487782, 0.050576763023855165, 0.035341016700840555, 0.012757938802678837, 0.021422333884402178, 0.01794799551134929, 0.024389456993958447, 0.03540083751431666, 0.029374219884630293, 0.03446029521001037, 0.050211099442094564, 0.008700287198735168, 0.0596851043519564, 0.02102580438076984, 0.025743318037712015, 0.03133554550004192, 0.01867148188466672, 0.06616579761612229, 0.05958111461950466, 0.03743131645023823, 0.034328567708143964, 0.02350274080527015, 0.020740795553138014, 0.0463602027593879, 0.007777562004775973, 0.04532674727670383, 0.07801547661074437, 0.05329056701157242, 0.012418672486091964, 0.016920412272156682, 0.052351223275763914, 0.04646461551601533, 0.020955912623321638, 0.07636681039002724, 0.067102528992109, 0.0468504692253191, 0.08849274643580429, 0.10902496695052832, 4.0459658950567245, 39.31295268237591, 66.99486628174782, 70.57215392589569, 83.47595751285553, 76.05860352516174, 86.83325976133347, 77.09152489900589, 42.72653751075268, 32.91634552180767, 31.451596319675446, 39.05192568898201, 48.50945100188255, 52.86880888044834, 49.919479340314865, 39.394807890057564, 31.34723871946335, 17.55783185362816, 9.170369021594524, 4.823624566197395, 2.184195234440267, 0.9302223846316338, 0.12976809841347858, 0.11082690150942653, 0.043562510109040886, 0.08083124426775612, 0.0953420644509606, 0.17941452737431973, 0.16911466052988544, 0.1460978706018068, 0.13066955551039428, 0.2364097026293166, 0.11192049321834929, 0.17718232527840883, 0.06297142332186922, 0.3640161920338869, 0.25363166991155595, 0.7832246006000787, 1.1196063598617911, 0.39943438838236034, 0.856937913922593, 0.32899409474339336, 0.1883330792770721, 0.10325265364372171, 0.3870057302992791, 0.11067038998589851, 0.04298414700315334, 0.17542958026751876, 0.04547529555566143, 0.02788249563309364, 0.044460156277637, 0.10743337188614532, 0.11875413707457483, 0.40018330444581807, 2.097281073220074, 3.345660623162985, 6.968692587688565, 15.932704657316208, 21.840000674128532, 26.654205545783043, 39.800595715641975, 45.37037864327431, 50.651627853512764, 39.69237372279167, 33.3855177462101, 35.14451555907726, 49.62921291589737, 66.46243125200272, 71.8527764081955, 76.43637925386429, 78.61324444413185, 84.54258307814598, 88.30482959747314, 73.23925361037254, 40.10564334690571, 4.607699252665043, 0.10875158201088198, 0.3046657517552376, 0.03539854798873421, 0.09104923738050275, 0.019595125486375764, 0.03015845661138883, 0.023335026562563144, 0.057219801092287526, 0.025937747741409112, 0.040761782074696384, 0.06882460846100003, 0.03668850455142092, 0.031201988604152575, 0.03539649966114666, 0.021905210414843168, 0.02884093668399146, 0.0810871590510942, 0.01844915299443528, 0.06261562288273126, 0.042680322876549326, 0.06411850903532468, 0.0721465727838222, 0.048737190445535816, 0.03517898359859828, 0.04829535653698258, 0.03529859925038181, 0.004089181284143706, 0.023951964649313595, 0.019747545920836274, 0.012319996531005017, 0.034957979441969655, 0.05679926682205405, 0.034993094159290195, 0.04665470551117323, 0.0068675767033710144, 0.036274363883421756, 0.05156912207894493, 0.013352554942684947, 0.03352607229317073, 0.02169200437492691, 0.021531880447582807, 0.03882411612721626, 0.01514243795099901, 0.04244105446559843, 0.0300296327623073, 0.022697529129800387, 0.06622340311878361, 0.007598186302857357, 0.03931163293600548, 0.05746486938733142, 0.042324366586399265, 0.0540214563079644, 0.035808521497529, 0.1920299098128453, 0.0662571782595478, 0.14534159243339673, 0.1410561052034609, 0.07524217464379035, 0.2096453489502892, 0.09764739035745151, 0.32172517385333776, 0.15255789505317807, 0.1470508921192959, 0.11466305542853661, 0.178767686302308, 0.10496550821699202, 0.09304085746407509, 0.12750393943861127, 0.1323633739957586, 0.10357758816098794, 0.15551999938907102, 0.13399090385064483, 0.13100862794090062, 0.145720295549836, 0.20275256334571168, 0.15117433882551268, 0.0745806835766416, 0.14940032386220992, 0.09218669743859209, 0.10688599344575778, 0.19828741700621322, 0.15637361764675006, 0.07910428146715276, 0.11875352109200321, 0.10160162739339285, 0.09249966853531078, 0.1288137855590321, 0.12355444472632371, 0.1762812986271456, 0.1353234745329246, 0.08447318556136452, 0.1848349068313837, 0.27557751105632633, 0.09060772630618885, 0.2103079532389529, 0.15919251716695726, 0.1900138656492345, 0.09582034894265234, 0.34364797873422503, 0.1656030403682962, 9.402330424636602, 56.494220942258835, 83.6901444196701, 83.43020796775818, 91.34865626692772, 88.49132359027863, 89.04531866312027, 76.7246013879776, 34.640305414795876, 24.369089864194393, 37.83942215144634, 70.17850264906883, 113.49567666649818, 87.40381434559822, 59.86996740102768, 47.86217473447323, 35.85779428482056, 19.82714418321848, 10.753138940781355, 6.374091943725944, 2.958509847521782, 1.5408124518580735, 0.4875808709766716, 0.26170769124291837, 0.24845749052474275, 0.5376158736180514, 0.13091894681565464, 0.5114199011586607, 0.4615636373637244, 0.30394613568205386, 0.15040562226204202, 0.27800575888250023, 0.13474597973981872, 0.34674686088692397, 0.253318008617498, 0.5163927655667067, 0.24445379676762968, 0.959776189411059, 0.8418546826578677, 0.5977130925748497, 1.1989605892449617, 0.4369418491842225, 0.473049174179323, 0.19126346422126517, 0.36246602365281433, 0.39772522228304297, 0.2765457169152796, 0.4394201177638024, 0.2718652883777395, 0.4021912591997534, 0.18867137987399474, 0.12435777505743317, 0.3753377735847607, 1.212728675454855, 3.64106722176075, 7.057273909449577, 14.278986845165491, 24.799173586070538, 29.497866556048393, 37.430970668792725, 56.264268681406975, 77.93051987886429, 99.63693872094154, 69.59230050444603, 48.38214263319969, 25.98014071583748, 42.291833236813545, 64.81411010026932, 83.44090059399605, 90.56106492877007, 89.19574499130249, 92.51550525426865, 102.10087850689888, 87.30896383523941, 48.79286639392376, 6.775174671784043, 0.41463573987130076, 0.44940280553419143, 0.13907283428125083, 0.14913145860191435, 0.18404906149953604, 0.17007476213620976, 0.0591923368483549, 0.13804310437990353, 0.148402996128425, 0.15110410196939483, 0.16465239372337237, 0.3214477590518072, 0.21338890510378405, 0.1379217632347718, 0.06944653563550673, 0.08112492694635876, 0.15472098835743964, 0.09026081679621711, 0.13884564803447574, 0.1724937479593791, 0.1718877992243506, 0.20248921966413036, 0.11520206244313158, 0.13370260916417465, 0.19893807271728292, 0.1843049391754903, 0.09929180407198146, 0.11290393536910415, 0.16634745901683345, 0.11801080196164548, 0.12483633414376527, 0.09625552207580768, 0.09666201120126061, 0.12562430201796815, 0.15032134397188202, 0.07963375188410282, 0.14748390560271218, 0.09958387629012577, 0.1571024808799848, 0.10404945307527669, 0.21587803872535005, 0.16299538576276973, 0.18960420013172552, 0.1525992326787673, 0.08316443039802834, 0.0808083638548851, 0.17994464345974848, 0.1427287724800408, 0.1379744111909531, 0.11622472709859721, 0.12172021190053783, 0.15491336787818, 0.22802904451964423], [0.03498791025776882, 0.05121171489008702, 0.03003166439157212, 0.019787736928265076, 0.00791953671068768, 0.11995260167168453, 0.026606882929627318, 0.013939102082076715, 0.03535634205036331, 0.047622699858038686, 0.057563281879993156, 0.022336108777381014, 0.0827112230763305, 0.03165912930853665, 0.035987479277537204, 0.02021345881075831, 0.04297067331208382, 0.043531432675081305, 0.032834943558555096, 0.030917599469830748, 0.022779703431297094, 0.012112990207242547, 0.0432459989679046, 0.0218064287037123, 0.05245919463050086, 0.04806619988812599, 0.03396527528821025, 0.049910804227693006, 0.06123264924099203, 0.016286933569062967, 0.084942230314482, 0.01203020734465099, 0.04174339854216669, 0.05740031738241669, 0.04921293308143504, 0.0362578882050002, 0.031313384970417246, 0.021391380760178436, 0.08144612103933468, 0.010218402221653378, 0.05161308690730948, 0.045941924618091434, 0.13380913704168051, 0.09344570644316263, 0.046442154416581616, 1.8500037607736886, 27.602066583931446, 60.25254987180233, 77.7935828268528, 75.19621700048447, 71.99137777090073, 75.8663946390152, 58.39628867805004, 29.185352325439453, 18.879856914281845, 29.59538072347641, 38.84623512625694, 55.22706113755703, 58.16671259701252, 57.841332256793976, 41.61618389189243, 15.64304145053029, 6.8765974044799805, 1.370834510307759, 0.3486922080628574, 0.02951541533548152, 0.01828449825552525, 0.05527523688215297, 0.026713807856140193, 0.07962856427184306, 0.11256259196670726, 0.04364708896900993, 0.06840597037808038, 0.1643316968693398, 0.051485459771356545, 0.09099051123484969, 0.08967466113972478, 0.04092941839189734, 0.10895052211708389, 0.0462555636477191, 0.10738846453023143, 0.025929697294486687, 0.05666332763212267, 0.048938071267912164, 0.3433564037550241, 0.3469889494590461, 0.3472610207973048, 0.5839350912719965, 0.053674034716095775, 0.09227459740941413, 0.17476081615313888, 0.07824904532753862, 0.04678268887801096, 0.09007594038848765, 0.10712374045397155, 0.009716441363707418, 0.06999872319283895, 0.05547069260501303, 0.12698378297500312, 0.034187106939498335, 0.03760740582947619, 0.013842418793501565, 0.03145492366456892, 0.1356254841084592, 0.1795764936832711, 0.8100297872442752, 4.616629723459482, 7.789470870047808, 19.3726771697402, 40.28363339602947, 67.95125216245651, 58.695951998233795, 37.90269635617733, 24.97448667883873, 17.807581052184105, 29.49687670916319, 42.62287147343159, 73.82057681679726, 77.48814761638641, 74.23283189535141, 81.35193228721619, 74.62141424417496, 62.73162044584751, 18.236013762652874, 1.0557941277511418, 0.10485621212865226, 0.011992894014838384, 0.10554352251347154, 0.06876238679978997, 0.02422344226943096, 0.03136183237074874, 0.07130032405257225, 0.029020102265349124, 0.07048940897220746, 0.017513009770482313, 0.01426410153726465, 0.03966125499573536, 0.10352818339015357, 0.04768606442667078, 0.05187378483242355, 0.016834313864819705, 0.02127778763679089, 0.018554411799414083, 0.042343105815234594, 0.03845415551040787, 0.0510874496831093, 0.06680210019112565, 0.03134883736493066, 0.06466820297646336, 0.05664971293299459, 0.012292128885746934, 0.06365551278577186, 0.034172531159128994, 0.041532231552992016, 0.058072320971405134, 0.0048795973179949215, 0.028173011196486186, 0.04400665951834526, 0.08161357924109325, 0.015288548274838831, 0.03681251000671182, 0.09152267564786598, 0.054687723095412366, 0.05088470607006457, 0.052415018290048465, 0.01966178519069217, 0.07624895733897574, 0.05512102972716093, 0.019364074505574536, 0.03771138814045116, 0.022000845419825055, 0.014540492175001418, 0.023907378272269852, 0.043972491039312445, 0.03978199129051063, 0.01742632877721917, 0.03368934849277139, 0.032732371328165755, 0.0558058873139089, 0.05585086517385207, 0.033460922859376296, 0.06937236539670266, 0.08004122064448893, 0.028694295724562835, 0.019513279585225973, 0.03477781196124852, 0.023397591467073653, 0.027226607780903578, 0.04271209050784819, 0.01138605099185952, 0.024458597326884046, 0.012148361893196125, 0.06271797989029437, 0.06299946166109294, 0.025308627300546505, 0.06648590075201355, 0.01795791988115525, 0.05086580727947876, 0.01605216442840174, 0.03546315565472469, 0.02031384727160912, 0.017613804557186086, 0.09459058797801845, 0.03512508141284343, 0.04828049502975773, 0.012959058967680903, 0.0377100077457726, 0.03895451518474147, 0.0364010150951799, 0.024900238277041353, 0.08063799643423408, 0.018008617844316177, 0.06732247929903679, 0.07410579069983214, 0.03045207620743895, 0.09336975504993461, 0.0433971150778234, 0.07560301426565275, 0.09419489710126072, 0.08723020480829291, 0.07976286331540905, 1.90457702614367, 30.39713580161333, 67.04870939254761, 89.62551712989807, 82.1343483030796, 88.95255044102669, 95.01811176538467, 75.04129931330681, 47.0619984716177, 37.15639740228653, 35.10189324617386, 30.34080382436514, 42.14389577507973, 47.5338039547205, 53.90147186815739, 41.91117346286774, 21.122956350445747, 9.318073745816946, 1.8737355060875416, 0.41236726159695536, 0.06566146374098025, 0.04684829473262653, 0.052321915864013135, 0.013031792223046068, 0.14966972346883267, 0.1392616514931433, 0.40147811465431005, 0.31755403673741966, 0.08485142854624428, 0.1479951711371541, 0.4263037856435403, 0.6342600658535957, 0.35841766744852066, 0.44696262397337705, 0.13464960444252938, 0.5645478784572333, 0.774085734738037, 0.32097824674565345, 0.4951877659186721, 1.56533716712147, 2.48994511552155, 1.0966232931241393, 1.2033289298415184, 0.362000756431371, 0.6185422092676163, 0.4032853926764801, 0.1995130887371488, 0.10452936287038028, 0.14835150592261925, 0.16939130349783227, 0.08372420270461589, 0.12310310761677101, 0.08367930277017877, 0.22752258810214698, 0.04717776377219707, 0.04121052166738082, 0.026500399580982048, 0.03289581822173204, 0.27232743857894093, 0.15793723374372348, 0.9726949024479836, 4.0386859606951475, 7.05940037034452, 19.27444864064455, 37.87846505641937, 54.79893811047077, 47.03686662018299, 32.68263906240463, 28.757398389279842, 25.49822397530079, 47.51214511692524, 58.90037722885609, 82.25572898983955, 88.30186575651169, 83.00907656550407, 91.01493537425995, 86.65359020233154, 78.32020416855812, 26.54417484998703, 3.431472131051123, 0.09806177593418397, 0.09266946450225078, 0.09175711267744191, 0.03052121654036455, 0.01798153687559534, 0.04045658868562896, 0.08704089777893387, 0.08932965152780525, 0.033607330042286776, 0.02556316539994441, 0.0328386171895545, 0.025218614064215217, 0.06792859130655415, 0.04412264977872837, 0.04780592498718761, 0.015292392599803861, 0.040278024243889377, 0.050528701540315524, 0.039772940799593925, 0.036258378022466786, 0.014888199493725551, 0.0638138574140612, 0.035968866213806905, 0.012570586404763162, 0.031978542247088626, 0.04336098732892424, 0.052931964964955114, 0.0549368991778465, 0.03644227850600146, 0.0699696977972053, 0.02362972041737521, 0.043794973025796935, 0.04283669339201879, 0.05410131510870997, 0.06307468574959785, 0.016734838245611172, 0.05164725909708068, 0.04631469797459431, 0.01622513864276698, 0.04261735906766262, 0.04461783297301736, 0.0469458797306288, 0.06460112024797127, 0.017391618530382402, 0.07296605966985226, 0.020608778613677714, 0.017948479762708303, 0.03970884521550033, 0.03341005605761893, 0.09041373632499017, 0.06054092678823508, 0.12952023593243212, 0.1257524560787715, 0.14843633340205997, 0.08721652702661231, 0.08871110112522729, 0.19027024798560888, 0.1558364660013467, 0.14358009007992223, 0.07787371156155132, 0.1626694790320471, 0.16228895023232326, 0.161854600883089, 0.164281765173655, 0.1746096258284524, 0.13414463232038543, 0.09353822999401018, 0.10364946516347118, 0.16070045734522864, 0.1200543055892922, 0.08417546559940092, 0.1409224295639433, 0.19740111456485465, 0.1352914731251076, 0.09071864769794047, 0.16344695293810219, 0.08655171113787219, 0.25925032154191285, 0.19028056383831427, 0.11575626122066751, 0.07761090222629718, 0.1493650718475692, 0.09652161170379259, 0.1297662578872405, 0.11614916904363781, 0.1384830049937591, 0.16076336178230122, 0.15911549708107486, 0.12500870536314324, 0.1791011480963789, 0.26525750232394785, 0.1240281130594667, 0.32360678538680077, 0.4060300922719762, 0.3149019571719691, 0.15565426874672994, 4.886637534946203, 46.053836569190025, 85.78003987669945, 99.02614429593086, 91.92716762423515, 92.06478103995323, 96.27587467432022, 76.19129240512848, 39.787946194410324, 27.996848300099373, 41.27599194645882, 51.914634481072426, 75.72723090648651, 78.98263022303581, 77.60189071297646, 56.17980681359768, 24.75223660469055, 11.744671035557985, 2.618635422550142, 0.7887228461913764, 0.5621117341797799, 0.40438760071992874, 0.19816347834421322, 0.12134700067690574, 0.2955027512507513, 0.1610697351861745, 0.3170496434904635, 0.6136055616661906, 0.46230017440393567, 0.1279866768163629, 0.3344656230183318, 0.33358522807247937, 0.2696178277255967, 0.32974888861645013, 0.33644341689068824, 0.3528710932005197, 0.45360995165538043, 0.18363149953074753, 0.2795017504831776, 0.9881499200128019, 2.072839359752834, 0.7481682160869241, 0.8239544369280338, 0.27872825448866934, 0.4660713829798624, 0.5457590741571039, 0.2950709994183853, 0.16643289505736902, 0.2236314633046277, 0.21672759001376107, 0.2112776433932595, 0.24336358183063567, 0.24566333420807496, 0.48422974767163396, 0.0881491691689007, 0.11083456047344953, 0.13047440035734326, 0.24069979117484763, 0.39440028194803745, 0.3659251146018505, 1.9844080111943185, 7.147026993334293, 10.465431679040194, 27.267764322459698, 52.83116050064564, 95.80374240875244, 82.09027826786041, 52.53059662878513, 39.45430509746075, 31.66871666908264, 45.1854045689106, 57.42377266287804, 95.60165405273438, 98.65260913968086, 95.72711572051048, 99.65348303318024, 99.70698416233063, 93.96348595619202, 39.02522832155228, 5.144500248134136, 0.28702884970698506, 0.2337122184690088, 0.15961184544721618, 0.2039186703041196, 0.1413070401758887, 0.12767222884576768, 0.2327494599740021, 0.14352704136399552, 0.149934877990745, 0.07441076886607334, 0.14394709694897756, 0.07503372020437382, 0.28495068778283894, 0.25191713066305965, 0.13943767407909036, 0.10174125505727716, 0.12232031993335113, 0.1649470263510011, 0.11995303211733699, 0.2218761356198229, 0.0769200072681997, 0.16394508245866746, 0.13053052156465128, 0.11402175077819265, 0.13223165762610734, 0.16513988084625453, 0.1553343585692346, 0.1137959300831426, 0.10526976649998687, 0.14855619025183842, 0.09480500928475522, 0.1304046978475526, 0.21590941672911867, 0.1538099130266346, 0.1634542111423798, 0.08624541937024333, 0.2278264530468732, 0.20702850655652583, 0.1824688509805128, 0.15747595927678049, 0.09057326096808538, 0.13450907135847956, 0.16860817442648113, 0.0857294411980547, 0.13260356266982853, 0.09317743490100838, 0.09733003316796385, 0.12054325474309735, 0.1705563417635858, 0.19346862245583907, 0.12945332389790565], [0.01691622284852201, 0.03736293125257362, 0.04266270057996735, 0.012983163924218388, 0.0285701214306755, 0.040885583439376205, 0.03184508554113563, 0.03224862091883551, 0.034608587448019534, 0.05124834358866792, 0.06884026777697727, 0.030570869930670597, 0.038820728223072365, 0.00808598002549843, 0.044476735856733285, 0.027168386295670643, 0.043344274163246155, 0.0491690758644836, 0.04058912512846291, 0.009556533586874139, 0.024111261081998236, 0.08586365860537626, 0.006749409167241538, 0.02060464114038041, 0.05588427295151632, 0.06785543781006709, 0.05228037043707445, 0.016285660785797518, 0.037441365129780024, 0.03185224726621527, 0.009645778700360097, 0.1016221106692683, 0.026862124213948846, 0.05147555952135008, 0.011369109615770867, 0.024301416015077848, 0.0027847918045154074, 0.0379028882161947, 0.02240209127194248, 0.029001765651628375, 0.03063075382669922, 0.11834954042569734, 0.1430278134648688, 3.744010110385716, 19.64497435837984, 56.20295897126198, 75.34407466650009, 73.40934008359909, 72.26174086332321, 49.40763920545578, 26.001942045986652, 20.149175003170967, 19.069301448762417, 25.114805549383163, 37.9031865298748, 59.88463081419468, 75.37676811218262, 73.54368567466736, 42.08825156092644, 21.214827820658684, 6.628944743424654, 1.4652641932480037, 0.08633947174530476, 0.0722667932859622, 0.02972928745293757, 0.22209970018593594, 0.04337508071330376, 0.09910423366818577, 0.044630980119109154, 0.13360434881178662, 0.20926522091031075, 0.02913984593760688, 0.11241627755225636, 0.3280491626355797, 0.11872117829625495, 0.15258112427545711, 0.28389001032337546, 0.5311971867922693, 0.3394699248019606, 0.3424538631225005, 0.7169198209885508, 0.42889293108601123, 1.2219169386662543, 0.2557586057810113, 1.7919510696083307, 2.464314540848136, 1.8002310628071427, 0.6513782066758722, 0.2113324435777031, 0.1436416883370839, 0.23510479921242222, 0.815382037544623, 0.08243280637543648, 0.055565583606949076, 0.19950761168729514, 0.2036785113159567, 0.07353288980084471, 0.04138009127927944, 0.05368171965528745, 0.041175436635967344, 0.1412926721968688, 0.09219472747645341, 0.06851876198197715, 0.02914331176725682, 0.08728015134693123, 0.06675831347820349, 0.08012000704184175, 0.30753314320463687, 1.2772021908313036, 8.416787758469582, 20.011500790715218, 63.582839369773865, 94.15612801909447, 56.413623467087746, 33.71673457324505, 14.63388305157423, 21.4858615770936, 43.14749412238598, 51.64736822247505, 68.56478244066238, 71.13994225859642, 76.78709283471107, 74.02987718582153, 69.06596034765244, 54.233672842383385, 22.504239231348038, 1.5159841091372073, 0.4322095890529454, 0.021007955729146488, 0.06253340776311234, 0.007919188828964252, 0.016732990297896322, 0.028808397219108883, 0.016443999847979285, 0.04374179072328843, 0.04121288911846932, 0.056165765854530036, 0.019675893418025225, 0.024546617896703538, 0.06356208381475881, 0.050535072878119536, 0.04860109540459234, 0.03071385210205335, 0.0347802944452269, 0.06743080317392014, 0.04597029692376964, 0.11386684229364619, 0.03502003040921409, 0.09613708272809163, 0.0682419260556344, 0.03660846021375619, 0.06893006022437476, 0.0425623881892534, 0.0413226898672292, 0.018570445899968036, 0.032121747062774375, 0.042984544052160345, 0.058644973250920884, 0.04207698650134262, 0.03811733178736176, 0.07183956113294698, 0.04055484903801698, 0.010646660393831553, 0.011326805342832813, 0.048872580446186475, 0.07098439920810051, 0.007132666287361644, 0.05743231136875693, 0.01423869874997763, 0.016403743902628776, 0.03408318771107588, 0.031248461891664192, 0.009782302331586834, 0.031400301595567726, 0.028873010451206937, 0.11828138158307411, 0.04048289039928932, 0.018075220032187644, 0.0825439726759214, 0.023339846811722964, 0.010998838224622887, 0.04018691077362746, 0.020837469564867206, 0.031652067773393355, 0.016080841014627367, 0.016808815526019316, 0.03066337863856461, 0.019938133154937532, 0.02142326713510556, 0.02084634379571071, 0.0543268983165035, 0.0317042667302303, 0.0213930487370817, 0.07623257813975215, 0.019078920959145762, 0.08342335087945685, 0.061573951825266704, 0.031162569430307485, 0.03617629648942966, 0.0689715685439296, 0.011990246403001947, 0.049727478908607736, 0.08352509932592511, 0.06546336226165295, 0.046516699439962395, 0.01394876391714206, 0.0054961453133728355, 0.0507886239211075, 0.03278278170910198, 0.0868995334894862, 0.05705241710529663, 0.05868487853149418, 0.04822644070372917, 0.020842538433498703, 0.04857848216488492, 0.07510061739594676, 0.04827621283766348, 0.13058116572210565, 0.11664562873193063, 4.236186537891626, 24.522090554237366, 63.73615734279156, 87.77573838829994, 82.67516568303108, 80.27228102087975, 68.16296920180321, 45.20925588905811, 34.28852029144764, 36.14716775715351, 27.46261216700077, 27.733499631285667, 38.49568493664265, 43.55998478829861, 53.08365315198898, 41.89314343035221, 25.02953242510557, 9.45767730474472, 2.386803925037384, 0.14000422961544245, 0.0600604826468043, 0.08038665328058414, 0.04622175882104784, 0.31592285551596433, 0.5366656871046871, 0.15115314308786765, 0.5192587024066597, 0.644126117695123, 0.6052176898811013, 0.6535635644104332, 1.346610572654754, 1.472504111006856, 1.7621651804074645, 1.6658009262755513, 1.9644151465035975, 1.4595899102278054, 1.3563802046701312, 2.0036009000614285, 0.9883290447760373, 2.7432281244546175, 1.264891445171088, 3.093616347759962, 4.628176353871822, 5.0671145506203175, 3.5696852020919323, 3.0273341294378042, 1.89942117780447, 0.6644404213875532, 1.1535720247775316, 1.1401599319651723, 0.5076744896359742, 1.1335391434840858, 0.3998452116502449, 0.3021644172258675, 0.0932325393659994, 0.013796299881505547, 0.2702649211278185, 0.2039910148596391, 0.11549635368282907, 0.11059049036703072, 0.06389941219822504, 0.15478522866033018, 0.1338448195019737, 0.08934355937526561, 0.5862335523124784, 0.9808383998461068, 6.930797221139073, 20.635028332471848, 49.49587807059288, 59.74052354693413, 44.699368849396706, 36.43839932978153, 30.690529458224773, 36.011401042342186, 65.66927701234818, 72.10081189870834, 78.51182788610458, 85.34949257969856, 83.55658158659935, 85.01718521118164, 83.43585446476936, 72.55229607224464, 34.162040278315544, 3.4004634199663997, 0.46315958141349256, 0.07265826876391657, 0.04921392013784498, 0.053493566665565595, 0.0963329354999587, 0.0192026518197963, 0.054685518916812725, 0.033714395976858214, 0.021810519792779814, 0.03224024949304294, 0.020446511734917294, 0.024207619680964854, 0.07770341835566796, 0.023563921604363713, 0.03823533326794859, 0.0236946138102212, 0.02510824371711351, 0.051159649519831873, 0.03213894633518066, 0.013090878310322296, 0.04606972615874838, 0.04262977519829292, 0.047563725092913955, 0.04978795652277768, 0.08874499500961974, 0.03133400183287449, 0.013038490105827805, 0.0056237079752463615, 0.028744572518917266, 0.005235478465692722, 0.10197846029768698, 0.013293949396029348, 0.020574997906805947, 0.07319417360122316, 0.059877034873352386, 0.02503439816791797, 0.048345785471610725, 0.04628670787496958, 0.08160189783666283, 0.020142565153946634, 0.05082428040623199, 0.0531618303648429, 0.04304915542888921, 0.04721505298221018, 0.025383530410181265, 0.06593270387384109, 0.047948528663255274, 0.03213846022845246, 0.03248097622417845, 0.12696076155407354, 0.07873630980611779, 0.1683489274000749, 0.09382418691529892, 0.1498919670120813, 0.10052275989437476, 0.1186238530499395, 0.07219954728498124, 0.07300718949409202, 0.09420629648957402, 0.1467082425369881, 0.14554151217453182, 0.10565426578978077, 0.21155979309696704, 0.182014879246708, 0.18177385936724022, 0.18296525871846825, 0.20063955016667023, 0.1229153442545794, 0.1833473311853595, 0.14424052729737014, 0.1452930411323905, 0.07852341732359491, 0.11737823981093243, 0.09120867296587676, 0.13539841660531238, 0.18544288905104622, 0.12764583807438612, 0.21715108916396275, 0.10139286125195213, 0.12176378339063376, 0.22583711135666817, 0.08325558839715086, 0.29104986519087106, 0.12847668724134564, 0.3804548521293327, 0.08704893523827195, 0.13410363608272746, 0.1727466273587197, 0.20281186094507575, 0.2178633282892406, 0.39288431173190475, 0.3557494387496263, 9.493682272732258, 38.76660279929638, 82.31143400073051, 96.95879682898521, 91.28978982567787, 92.54854068160057, 66.99667498469353, 37.1308171749115, 33.18835772573948, 32.52707161009312, 38.436119332909584, 51.51666663587093, 80.1594726741314, 101.91243141889572, 95.75643494725227, 58.31372670829296, 32.24026679992676, 11.2137720733881, 2.9244924103841186, 0.35657616157550365, 0.2682585100410506, 0.20414569327840582, 0.3788460837677121, 0.1727651513647288, 0.3984270564978942, 0.15973676374414936, 0.14732409152202308, 0.527530680410564, 0.2308541483944282, 0.27207178354728967, 0.5345183867029846, 0.6851350015494972, 1.1861108662560582, 0.9161069733090699, 1.6438106750138104, 0.6456975114997476, 0.9421213867608458, 2.0117077650502324, 1.6029327060095966, 4.614410642534494, 2.0856221113353968, 4.775901976972818, 8.483862709254026, 6.412051906809211, 4.733153795823455, 2.821188303641975, 1.4351774076931179, 0.5430436448659748, 1.7921694391407073, 1.1858736164867878, 0.8244233555160463, 1.385136942844838, 0.6362528214231133, 0.2583534806035459, 0.3217553941067308, 0.18536046613007784, 0.27519794704858214, 0.35492191440425813, 0.34723359101917595, 0.272590663516894, 0.30788141826633364, 0.6178441154770553, 0.4499926941934973, 0.2942213590722531, 0.9570647974032909, 1.7039405484683812, 11.106016505509615, 26.7445931956172, 79.26234841346741, 121.86047941446304, 79.92106586694717, 50.91146171092987, 22.66976784914732, 32.78143756091595, 60.657421946525574, 68.67562249302864, 89.42434832453728, 93.60198095440865, 92.56316989660263, 92.07351297140121, 98.70661184191704, 89.65631827712059, 44.100160002708435, 4.422786450013518, 0.5685990548226982, 0.12602210801560432, 0.13423260650597513, 0.15598583064274862, 0.30543149972800165, 0.09923034682287835, 0.1022106189338956, 0.09221731845173053, 0.09508645394816995, 0.14459321071626619, 0.09097186848521233, 0.11128484373330139, 0.13959541014628485, 0.12191813526442274, 0.11351513108820654, 0.06806153964134865, 0.17500624438980594, 0.15294453914975747, 0.09560594990034588, 0.19057093653827906, 0.17857477243524045, 0.1657558634178713, 0.1462261434062384, 0.17200010101078078, 0.2237494647852145, 0.15757767803734168, 0.1106845353206154, 0.0784792001650203, 0.12916672130813822, 0.06684392763418145, 0.28660704265348613, 0.13273395801661536, 0.10841384544619359, 0.14583316136850044, 0.18006438156589866, 0.08059166415478103, 0.1363739400403574, 0.11436032596975565, 0.14909870020346716, 0.17761471535777673, 0.1601550233317539, 0.16396077146055177, 0.19978082593297586, 0.11493442914797924, 0.10803848941577598, 0.12463007646147162, 0.20664207026129588, 0.10660574364010245, 0.1633778738323599], [0.01692202644335339, 0.02760564115305897, 0.010257364046992734, 0.0403818395716371, 0.021738995310442988, 0.040259155139210634, 0.056471052012057044, 0.03239954778109677, 0.04181258897006046, 0.013499657889042282, 0.043817775513161905, 0.04801987131941132, 0.035979000240331516, 0.016355513580492698, 0.022028653693269007, 0.0704567099455744, 0.033664237926132046, 0.04562386609904934, 0.03045286845008377, 0.011975159468420316, 0.011518059582158457, 0.06637076396145858, 0.03334693639772013, 0.10967439811793156, 0.05643938457069453, 0.03056119974644389, 0.06164285652630497, 0.056711975412326865, 0.08463250982458703, 0.03891571941494476, 0.03476960009720642, 0.041308522268082015, 0.01701968565612333, 0.031851334424573, 0.050047318582073785, 0.02204861189966323, 0.020882868593616877, 0.046389892377192155, 0.04510809201747179, 0.06122486782260239, 0.06563093178556301, 2.3673259327188134, 37.621450647711754, 63.04084025323391, 79.61585104465485, 80.23217037320137, 72.07145467400551, 81.56633198261261, 58.83106894791126, 38.98821830749512, 120.03297507762909, 96.89673855900764, 38.17875914275646, 48.096386566758156, 76.94698825478554, 79.22058865427971, 43.25478136539459, 24.85982783138752, 7.149417065083981, 1.8178387242369354, 0.15720278955996037, 0.0436629857722437, 0.019316625293868128, 0.08432372444076464, 0.08261463255621493, 0.14693875360535458, 0.10345792426960543, 0.14500381133984774, 0.05629439860058483, 0.5985702434554696, 0.3178979776566848, 0.9891593002248555, 0.7072669733315706, 0.43232598749455065, 1.9378157425671816, 1.0861723101697862, 3.3221726585179567, 2.0950078452005982, 2.0326686277985573, 0.6182226107921451, 0.9127509815152735, 1.0902408231049776, 0.39212093863170594, 1.720756902359426, 3.72625223826617, 2.9809072706848383, 3.962633991613984, 2.0937339635565877, 1.9965344667434692, 1.8881627381779253, 0.786678793374449, 0.27935516147408634, 0.25478087074588984, 0.32114819856360555, 0.2673791837878525, 0.1677767315413803, 0.14185676380293444, 0.10757999800262041, 0.14486488129477948, 0.0775966678338591, 0.1270588586339727, 0.11562379528186284, 0.03284246151451953, 0.035733590557356365, 0.021286539413267747, 0.04936214187182486, 0.17558776162331924, 0.1020968848024495, 0.10199933691183105, 0.3923360724002123, 3.2466191751882434, 13.432176634669304, 59.37182933092117, 63.94046097993851, 50.503466203808784, 53.95490080118179, 38.90557274222374, 15.39362758398056, 20.90974599123001, 31.44283778965473, 47.29763902723789, 61.986499428749084, 70.6596328318119, 73.26019048690796, 70.97148969769478, 76.06023743748665, 55.0202040374279, 13.64978525787592, 0.368198580108583, 0.12440761027392, 0.05365723991417326, 0.0370597490837099, 0.08088789239991456, 0.02076083725114586, 0.010733934177551419, 0.07862579659558833, 0.009970438622985967, 0.037433001125464216, 0.03186098605510779, 0.01630690661841072, 0.04477829272218514, 0.0722751795547083, 0.04256949796399567, 0.06282555419602431, 0.012857536876254017, 0.03646655044576619, 0.00672992593536037, 0.029582323659269605, 0.05264286504825577, 0.019474459695629776, 0.031089321309991647, 0.04233619642036501, 0.02303512839716859, 0.013219083393778419, 0.024006070925679523, 0.021796726978209335, 0.03516799981298391, 0.07591300935018808, 0.0315065845643403, 0.047130629973253235, 0.0712527301220689, 0.05523049650946632, 0.04375204720417969, 0.05173403842491098, 0.03275456154369749, 0.0690782003221102, 0.02564303718827432, 0.015887999506958295, 0.04073114621860441, 0.0344102930102963, 0.08848401135765016, 0.032235826292890124, 0.08117520745145157, 0.029824096818629187, 0.0355240154749481, 0.06742132594808936, 0.01882038082840154, 0.023648071874049492, 0.06557421686011367, 0.05455082282423973, 0.02332098883925937, 0.07230392293422483, 0.10807650221977383, 0.01977620766410837, 0.023190717802208383, 0.019821393325401004, 0.006368410031427629, 0.07258395751705393, 0.013999117709317943, 0.0386904516199138, 0.02759681701718364, 0.05857869204191957, 0.024162760564649943, 0.05476988626469392, 0.03187402930052485, 0.023004273607512005, 0.08043846260989085, 0.017361782338412013, 0.021130354434717447, 0.038003263689461164, 0.07675635628402233, 0.07518175640143454, 0.0955593801336363, 0.07979976289789192, 0.05574427421379369, 0.05397421118686907, 0.028523653709271457, 0.033356792118866, 0.015372635461972095, 0.06502928008558229, 0.031191123562166467, 0.02890844985813601, 0.04220527414872777, 0.030130323648336343, 0.03320441064715851, 0.07441436828230508, 0.06296193867456168, 2.644094293937087, 42.868026718497276, 72.75905057787895, 92.09597736597061, 88.9156012237072, 80.91912791132927, 86.82386666536331, 74.28328558802605, 47.13494695723057, 83.79345327615738, 64.88682299852371, 35.374426022171974, 38.730599731206894, 50.65040051937103, 61.95938028395176, 45.288671627640724, 27.71805725991726, 9.226595554500818, 2.6171546895056963, 0.4644582507899031, 0.08165122839272954, 0.06476042966824025, 0.07287962172995321, 0.19774377899011597, 0.6118235760368407, 0.6173167156521231, 1.1478434759192169, 0.6744892196729779, 1.9287958578206599, 2.3840300738811493, 4.727729111909866, 3.4714597603306174, 4.55493338406086, 4.972031777724624, 6.30378526635468, 8.167680725455284, 8.064222726970911, 5.251148175448179, 4.9035167042165995, 8.765108417719603, 6.618428332731128, 6.364025808870792, 8.341320008039474, 7.049776911735535, 7.762033017352223, 7.87230072543025, 8.120334316045046, 5.649526873603463, 4.987833229824901, 4.449916044250131, 2.17067698482424, 1.5027525066398084, 0.4137520201038569, 1.0172366467304528, 0.7452859519980848, 1.1580833327025175, 0.7183981197886169, 1.0453296080231667, 0.28197987063322216, 0.22902864322531968, 0.5726900103036314, 0.27178193035069853, 0.0929176238423679, 0.05219005106482655, 0.11544200620846823, 0.06927469876245596, 0.05329050763975829, 0.16673693811753765, 0.47357149771414697, 2.9274268029257655, 14.293448869138956, 50.8324259519577, 50.907494723796844, 39.87863592803478, 32.71638125181198, 32.686036080121994, 29.21724021434784, 37.54377521574497, 56.515332609415054, 60.8440375328064, 72.83405095338821, 80.6719359755516, 84.20260772109032, 81.03384375572205, 91.94330915808678, 71.43687352538109, 21.174857765436172, 0.3682935453252867, 0.04362264633527957, 0.07864209415856749, 0.055392689173459075, 0.03150711148919072, 0.021458068295032717, 0.0780728594691027, 0.10217205694061704, 0.05039389041485265, 0.039750780269969255, 0.03204795160854701, 0.021887385883019306, 0.01252171505257138, 0.025679027639853302, 0.025702327366161626, 0.06812819192418829, 0.043082396223326214, 0.021621205341944005, 0.034386737243039533, 0.011130994316772558, 0.04039270832436159, 0.05687982324161567, 0.04010200536868069, 0.029061759014439303, 0.06055323530745227, 0.037212160241324455, 0.0652806529251393, 0.04422911457368173, 0.07021973477094434, 0.08141404541675001, 0.02351377839659108, 0.05489866001880728, 0.05175962025532499, 0.03338542788696941, 0.04927996014885139, 0.03271397348726168, 0.033066797914216295, 0.06432190944906324, 0.038914932738407515, 0.005460315815071226, 0.0652332445315551, 0.035449681963655166, 0.08985941880382597, 0.03596743757952936, 0.03347136116644833, 0.022265706793405116, 0.01091365173124359, 0.05300377517414745, 0.09061336662853137, 0.1499007540405728, 0.09582723607309163, 0.1299743857816793, 0.2642109850421548, 0.19057970872381702, 0.1880546403117478, 0.17101832869229838, 0.0763222666864749, 0.1010555551329162, 0.08205132762668654, 0.1603095533209853, 0.16096446895971894, 0.13655410381034017, 0.1355532434536144, 0.25946827547159046, 0.12123381573474035, 0.10708609872381203, 0.19531438825652003, 0.09765356502612121, 0.2542122668819502, 0.11466627634945326, 0.05520445825823117, 0.24936856585554779, 0.13548809773055837, 0.11586428081500344, 0.16138911101734266, 0.1844487970811315, 0.21702468657167628, 0.11144821270136163, 0.09388525824761018, 0.20893348089884967, 0.15789010736625642, 0.19080014142673463, 0.16979034146061167, 0.1367569327703677, 0.13777935993857682, 0.14339594839839265, 0.13231912715127692, 0.2426359654054977, 0.17083191603887826, 4.40321322530508, 58.22895705699921, 90.25289386510849, 103.9376163482666, 97.40213423967361, 92.05066099762917, 101.10799178481102, 79.69104140996933, 53.78771357238293, 127.94893831014633, 105.61422318220139, 51.946678161621094, 67.40351915359497, 107.70959794521332, 106.14747136831284, 62.060409262776375, 37.10108757019043, 11.906121522188187, 3.2194406585767865, 0.8695245604030788, 0.20824821142014116, 0.32519314088858664, 0.28084922349080443, 0.4870987421600148, 0.3413353278301656, 0.22242087201448157, 0.3026348497951403, 0.2765568491304293, 1.995998458005488, 1.1015884391963482, 4.228807808831334, 3.3603513473644853, 2.967993188649416, 4.186745015904307, 4.58796976134181, 7.582928203046322, 8.066876884549856, 9.281777143478394, 4.200864108279347, 8.389339931309223, 5.005997680127621, 5.057590361684561, 10.192812457680702, 10.496091283857822, 11.858726665377617, 12.475039344280958, 9.428374227136374, 5.151722235605121, 5.21940752863884, 3.9739243732765317, 1.3975888746790588, 2.079014740884304, 0.8233053842559457, 0.7986902457196265, 0.9339275420643389, 0.6537339021451771, 0.3733262268360704, 0.6509903306141496, 0.2022890030639246, 0.26100505550857633, 0.5560410255566239, 0.38388277287594974, 0.25571018806658685, 0.17361589008942246, 0.25434154900722206, 0.6498941488098353, 0.2544998045777902, 0.42546593060251325, 1.0700451442971826, 4.965118523687124, 18.048653416335583, 72.37525597214699, 85.20988047122955, 71.42835438251495, 71.87419205904007, 56.23488865792751, 27.06542517989874, 33.61239977180958, 48.34343031048775, 60.649035796523094, 81.53149545192719, 91.76465034484863, 94.02389511466026, 90.13810202479362, 104.22577008605003, 86.68480932712555, 26.135090701282024, 0.7632670027669519, 0.22090341750299558, 0.18215149379102513, 0.25246967445127666, 0.20456169673707336, 0.13684100325917825, 0.1944686664501205, 0.16405837872298434, 0.10576685701380484, 0.13776197883998975, 0.07713257320574485, 0.13514727383153513, 0.15035943099064752, 0.21108731220010668, 0.1835840317653492, 0.2115572994807735, 0.13173199928132817, 0.08045782524277456, 0.16821968980366364, 0.09754218350281008, 0.106086804298684, 0.20324779849033803, 0.17634101182920858, 0.06992785551119596, 0.15960282093146816, 0.10479249132913537, 0.1309503841912374, 0.1217004559293855, 0.11749751036404632, 0.25562184280715883, 0.13500062545062974, 0.17327954876236618, 0.19443268713075668, 0.09713356441352516, 0.2527894510421902, 0.09857213604846038, 0.06977443874347955, 0.11751219004509039, 0.09458249114686623, 0.12797719216905534, 0.28465810348279774, 0.19426016748184338, 0.13619805104099214, 0.2028890888323076, 0.15034988697152585, 0.08278350083855912, 0.129511627019383, 0.15858193743042648], [0.012442311744962353, 0.04264173861884046, 0.008900522352632834, 0.019881082407664508, 0.025581741356290877, 0.018400822482362855, 0.030955282018112484, 0.06923912762431428, 0.011557121597434161, 0.03359735186677426, 0.04359338716312777, 0.045698615213041194, 0.08875206025550142, 0.01452342370612314, 0.029818914772477, 0.054816066403873265, 0.026674279215512797, 0.009707080098451115, 0.055632232179050334, 0.07596183524583466, 0.06452271234593354, 0.03553132191882469, 0.06293913989793509, 0.047284874235629104, 0.046939534367993474, 0.012184456245449837, 0.01866804203018546, 0.035839947740896605, 0.021367151493905112, 0.04075484670465812, 0.07483521796530113, 0.017036825556715485, 0.05964372590824496, 0.02695868690352654, 0.031316401800722815, 0.03814537383732386, 0.09119503229157999, 0.052843615994788706, 0.12102314969524741, 0.16890491475351155, 1.7495861928910017, 17.60482583194971, 22.12495308369398, 79.30450335144997, 74.41969826817513, 82.00269296765327, 71.50477588176727, 49.518262669444084, 26.373075731098652, 33.44024620950222, 129.71705943346024, 96.18528753519058, 56.33918546140194, 59.623839408159256, 48.414087519049644, 34.98185008764267, 11.540430095046759, 3.132862066850066, 0.41779527033213526, 0.1457926697912626, 0.016410653297498357, 0.018127190778614022, 0.027816477886517532, 0.08700531179783866, 0.03294731584901456, 0.10490563916391693, 4.717218400910497, 6.304249316453934, 2.0021173171699047, 3.924996773712337, 3.502434748224914, 4.6670430433005095, 4.317916352301836, 10.597069915384054, 6.011084597557783, 6.607924271374941, 8.296424467116594, 6.4976598881185055, 5.267442651093006, 5.0785011146217585, 3.863827418535948, 1.8024950288236141, 4.3246362917125225, 2.3396026203408837, 2.8530814172700047, 5.12586984783411, 4.717577006667852, 3.3048099651932716, 6.261575231328607, 6.450079316273332, 4.430901389569044, 2.519131824374199, 3.057697587646544, 0.4876724223140627, 1.9317436683923006, 0.26026724197436124, 2.4082392873242497, 0.44020424131304026, 0.8892140351235867, 0.6675566697958857, 0.34156848094426095, 0.22976967768045142, 0.27090842253528535, 0.09731110840220936, 0.09658133974880911, 0.051813288664561696, 0.07287608910701238, 0.08360580046428367, 0.0796157622244209, 0.061174271904747, 0.057071271367021836, 0.49224927672185004, 3.110070414841175, 36.25885896384716, 67.03674763441086, 114.2123182117939, 81.7137260735035, 60.53004898130894, 31.56720321625471, 11.789137199521065, 23.240354731678963, 44.59626518189907, 61.26521073281765, 65.190289914608, 65.79343914985657, 63.366110399365425, 71.90489441156387, 82.39067494869232, 35.269604846835136, 1.9842588691972196, 0.10519065355765633, 0.04372547089587897, 0.012233883280714508, 0.03594168505514972, 0.07121708476915956, 0.0503893855784554, 0.03407845651963726, 0.07099366121110506, 0.03689547840622254, 0.04491016123211011, 0.00818683047327795, 0.0024071696725513902, 0.026750328943307977, 0.05949799779045861, 0.033434172146371566, 0.009014442020998104, 0.030756095147808082, 0.015524486298090778, 0.048555998801020905, 0.028983978227188345, 0.041775058562052436, 0.018678318920137826, 0.012312550006754464, 0.011494347963889595, 0.028921845623699483, 0.07405723939882591, 0.011337918076606002, 0.055583012945135124, 0.038542600959772244, 0.05316885108186398, 0.04981779457011726, 0.0881938761449419, 0.02972320555272745, 0.017947093801922165, 0.04749357729451731, 0.021252283731882926, 0.00471327181912784, 0.008402385410590796, 0.09174540158710442, 0.020898683760606218, 0.012818430332117714, 0.03250552275858354, 0.0187245139022707, 0.06919115519849584, 0.061903457972221076, 0.047400322728208266, 0.03223906576749869, 0.01698765641776845, 0.03017548704519868, 0.052204437597538345, 0.04320298779930454, 0.025852979633782525, 0.02650298225489678, 0.03911665960913524, 0.0044623665326071205, 0.044735856718034483, 0.043098875612486154, 0.08449885644949973, 0.07865315215894952, 0.035048191202804446, 0.02880201103835134, 0.006604166228498798, 0.014988368093327153, 0.011012661652785027, 0.02331830040930072, 0.09938665054505691, 0.044422329010558315, 0.03071207280299859, 0.02142606503184652, 0.024499003557139076, 0.05763908113294747, 0.0026346036111135618, 0.05720176690374501, 0.00978692869466613, 0.018689985481614713, 0.034674883499974385, 0.007371025567408651, 0.0038013594848962384, 0.039899840630823746, 0.03714203841809649, 0.06938782433280721, 0.05751268967287615, 0.0500652859773254, 0.07589617744088173, 0.08267312863608822, 0.13060783850960433, 1.952863410115242, 27.339329682290554, 32.93819434940815, 88.75929281115532, 81.04553952813148, 93.36669757962227, 86.9836100935936, 71.81274935603142, 41.88349574804306, 41.14928774535656, 131.85898929834366, 105.01570969820023, 43.85595090687275, 45.8405502140522, 49.40424598753452, 41.33996531367302, 14.693443905562162, 4.42718043923378, 0.5822228081524372, 0.1740673088352196, 0.027797545699286275, 0.09578911936841905, 0.02740287713095313, 0.4083846596768126, 0.3289059572853148, 0.6603216205257922, 7.833570828661323, 7.368518058210611, 5.349472174420953, 3.6605597008019686, 2.4781009135767817, 8.175092227756977, 7.265411540865898, 7.450378965586424, 12.97180948778987, 9.667847827076912, 9.120635390281677, 11.336522586643696, 13.087761215865612, 12.498295996338129, 9.620706606656313, 9.92468174546957, 10.675001833587885, 9.926278609782457, 9.329437986016273, 8.247822225093842, 7.30644078925252, 8.928992673754692, 10.342694465070963, 7.072066990658641, 8.362300582230091, 6.305351257324219, 6.927663339301944, 3.4725861623883247, 4.663556730374694, 3.6648537078872323, 3.8437861064448953, 3.275451553054154, 2.433791016228497, 2.011850494891405, 1.7118849721737206, 0.5862321273889393, 0.12544312892714515, 0.4250544839305803, 0.21509525104193017, 0.06914828874869272, 0.052177345496602356, 0.13749053090577945, 0.04869349279033486, 0.015274272136593936, 0.05907180835492909, 0.26803886401467025, 4.5963977091014385, 33.026361018419266, 58.61077576875687, 85.54547846317291, 68.53160262107849, 48.14453758299351, 34.025156423449516, 22.804027944803238, 39.275391697883606, 55.8313313126564, 70.22694244980812, 75.67312940955162, 73.44633489847183, 73.33830669522285, 82.63553380966187, 98.72471407055855, 50.25562450289726, 2.4670594185590744, 0.1794404728570953, 0.030494404600176495, 0.013053063103143359, 0.07231250958284363, 0.07649425198906101, 0.09336162853287533, 0.07423933275276795, 0.04173603643721435, 0.03456412538071163, 0.03729286137968302, 0.06472203836892731, 0.0434064995351946, 0.029549296232289635, 0.031492724956478924, 0.038273000973276794, 0.04190504943835549, 0.0763460154121276, 0.02905504072259646, 0.00273388116966089, 0.01671659996645758, 0.06253065439523198, 0.023815928980184253, 0.0370715232565999, 0.012651381239265902, 0.03775865552597679, 0.07853682051063515, 0.07409291443764232, 0.07583877973956987, 0.022354354478011373, 0.05800516031740699, 0.09402182826306671, 0.0518076891603414, 0.02945778385765152, 0.023910298623377457, 0.040755447844276205, 0.03267449494160246, 0.03462318178208079, 0.03446766102570109, 0.03336869987833779, 0.04095784264791291, 0.013015738641115604, 0.07056530099362135, 0.03283046840806492, 0.039662312556174584, 0.06450887871324085, 0.09184013673802838, 0.13027780543779954, 0.10525548015721142, 0.1410934649175033, 0.11388903993065469, 0.09024140221299604, 0.11730792874004692, 0.1335888824542053, 0.15697799302870408, 0.19115744100417942, 0.1423851284198463, 0.11762454378185794, 0.18491393071599305, 0.15176786400843412, 0.07724536480964161, 0.11247878122958355, 0.16431240102974698, 0.08291572929010727, 0.10479774573468603, 0.14235219190595672, 0.1755065706674941, 0.07730239143711515, 0.09808345406781882, 0.14597093366319314, 0.07615710914251395, 0.13202727015595883, 0.11204726688447408, 0.22114014776889235, 0.13067224208498374, 0.152136473916471, 0.10413977986900136, 0.1680981705430895, 0.19776522705797106, 0.12451179296476766, 0.13050053879851475, 0.1833178976085037, 0.23629155271919444, 0.1529841698356904, 0.17006524780299515, 0.29914322309195995, 0.2989642764441669, 4.090618724003434, 42.40611970424652, 41.992808282375336, 98.18702772259712, 93.86152222752571, 103.22412103414536, 92.12360948324203, 67.54984930157661, 43.503189235925674, 49.593912810087204, 132.04777836799622, 104.4547002017498, 75.76422572135925, 80.2998599410057, 65.885910987854, 49.429286643862724, 18.420045487582684, 5.402804212644696, 1.0056610428728163, 0.5856046860571951, 0.1524852536385879, 0.2840464253677055, 0.1108281928463839, 0.30431866412982345, 0.19352769741090015, 0.2686250419355929, 8.028653785586357, 12.93044300749898, 5.551045183092356, 14.948838651180267, 11.8252476118505, 21.04816496372223, 15.689860638231039, 24.150147512555122, 20.328360088169575, 19.01767171919346, 22.878640741109848, 17.799761071801186, 14.466373790055513, 14.803827982395887, 10.577670056372881, 9.192098155617714, 8.99386279284954, 8.97783525288105, 10.991941876709461, 15.035567097365856, 15.809218883514404, 17.20309428870678, 16.022056862711906, 17.896306291222572, 11.259822752326727, 7.999130319803953, 9.678737092763186, 5.575458398088813, 5.798096051439643, 2.9643712705001235, 5.614242916926742, 2.9535323521122336, 1.8559929518960416, 4.209600789472461, 1.6299022338353097, 1.3927545840851963, 0.888054562965408, 0.8399916545022279, 0.5266005615703762, 0.25332735967822373, 0.1349776188726537, 0.30776867119129747, 0.164348692051135, 0.1555915572680533, 0.1900700165424496, 0.9784969536121935, 6.265230635181069, 50.69251745939255, 90.85498675704002, 144.59779053926468, 104.44085374474525, 76.93745836615562, 40.44544771313667, 18.397007323801517, 35.093659088015556, 59.21333983540535, 78.02397206425667, 84.43213820457458, 88.54351758956909, 84.31393414735794, 94.61877599358559, 109.33196648955345, 61.44690178334713, 4.475995469838381, 0.4200061282608658, 0.12460889556678012, 0.1147106642019935, 0.21460751158883795, 0.14106667338637635, 0.20540955592878163, 0.16162863175850362, 0.16559094336116686, 0.12759734614519402, 0.12935984297655523, 0.1533946517156437, 0.19867741561029106, 0.11648712825262919, 0.15532514109509066, 0.10961545674945228, 0.10975403798511252, 0.10152601738809608, 0.10261960909701884, 0.15201534057268873, 0.15193881030427292, 0.12130738483392633, 0.10671312498743646, 0.13256485224701464, 0.14599888294469565, 0.1549952564528212, 0.2420041454024613, 0.15719551651272923, 0.23236308305058628, 0.22450452583143488, 0.12194912735139951, 0.2611431840341538, 0.19967061700299382, 0.09536426208796911, 0.09811374853597954, 0.08284855750389397, 0.11397938898880966, 0.1800069838645868, 0.12283661722904071, 0.17263244051719084, 0.11549262068001553, 0.11757372893043794, 0.12176025818916969, 0.14851035521132872, 0.1679647620767355, 0.1795557580771856, 0.21845385519554839], [0.012323409482632997, 0.051286434318171814, 0.0821373648068402, 0.03712331774295308, 0.04084164458618034, 0.02359837952099042, 0.03388672637811396, 0.05273657603538595, 0.08893807214917615, 0.06080512022890616, 0.03142452900647186, 0.029635797254741192, 0.01478142206906341, 0.08353108103619888, 0.0385837975773029, 0.0203232131752884, 0.09131087412242778, 0.04458042873011436, 0.07607752122567035, 0.03980218512879219, 0.018610056176839862, 0.0981078484619502, 0.03338003618409857, 0.024572858383180574, 0.008564901836507488, 0.03759135688596871, 0.038416966490331106, 0.09328037820523605, 0.038927912901272066, 0.029011211336182896, 0.02765167100733379, 0.02701056859223172, 0.03182649474183563, 0.022795667027821764, 0.07108326812158339, 0.126589598658029, 0.06415215058950707, 0.06806032994063571, 0.12721815321128815, 2.302940762601793, 35.081739127635956, 68.0705277621746, 14.694523997604847, 54.42580573260784, 77.44607627391815, 41.385118290781975, 24.688025750219822, 18.84356126189232, 26.551523655653, 24.964379221200943, 22.72705737501383, 27.138381265103817, 47.43746392428875, 42.79371790587902, 23.30309696495533, 8.749036230146885, 1.220621564425528, 0.11187268406501971, 0.04182803306321148, 0.06320562286418863, 0.06429546672734432, 0.08916692080674693, 0.14841724536381662, 0.4091495170723647, 0.6574172107502818, 4.714964646846056, 10.510069783776999, 10.535827651619911, 6.031033527106047, 0.49605216016061604, 7.564480192959309, 6.253696354106069, 4.572834223508835, 7.1619839407503605, 7.937613520771265, 10.839627049863338, 10.88457578793168, 10.959722455590963, 5.951601164415479, 9.738749172538519, 14.454866107553244, 16.9916470348835, 13.131675459444523, 14.319578167051077, 7.112823128700256, 6.479160105809569, 5.663443151861429, 11.488320641219616, 9.894457217305899, 5.325006237253547, 6.248762318864465, 4.214124921709299, 2.3249197332188487, 1.9453887362033129, 2.773085734806955, 1.5612238878384233, 1.9562747958116233, 4.301915410906076, 3.228753483854234, 1.2035750853829086, 1.232959977351129, 0.8312432176899165, 0.5370520194992423, 0.6349192711059004, 0.7715716946404427, 0.25833863765001297, 0.03614783512603026, 0.012528187507996336, 0.05820682039484382, 0.10113310956512578, 0.17271964286919683, 0.054338227200787514, 0.4045262042200193, 1.1834488715976477, 15.856286007910967, 39.400450587272644, 62.97528997063637, 71.2346787750721, 74.98295724391937, 78.69590520858765, 27.697122283279896, 30.528023578226566, 44.994518011808395, 41.4093191921711, 55.6443927437067, 75.652184933424, 74.226995408535, 64.5841920375824, 77.5422491133213, 49.69408683478832, 3.2413958804681897, 0.3672328678658232, 0.04209237864415627, 0.03847047904855572, 0.15296301862690598, 0.023421523874276318, 0.05090537488285918, 0.03994456616055686, 0.04888779076281935, 0.051008574228035286, 0.043502615080797113, 0.03713942234753631, 0.030419764952966943, 0.028089022343920078, 0.03205883149348665, 0.023541961454611737, 0.05680140420736279, 0.01949722322024172, 0.019368365974514745, 0.06653022181126289, 0.012950784021086292, 0.07398505811579525, 0.03643380317953415, 0.001858170335253817, 0.050943573223776184, 0.025488451537967194, 0.014039950674487045, 0.0435309243039228, 0.025896825718518812, 0.03450115043960977, 0.039668591125519015, 0.07099879687302746, 0.040348116381210275, 0.01953719158336753, 0.04777337810082827, 0.016732990297896322, 0.025300350498582702, 0.01955532225110801, 0.0449136827228358, 0.0545023383165244, 0.05400064277637284, 0.031124961096793413, 0.021474920613400172, 0.0195804662143928, 0.017110134904214647, 0.026726437354227528, 0.04268261982360855, 0.01759417475113878, 0.05386690034356434, 0.06123155828390736, 0.09810899136937223, 0.03806394539424218, 0.06913082601386122, 0.039785690896678716, 0.037558305339189246, 0.05617724316834938, 0.02916520883445628, 0.030195359904610086, 0.103759013582021, 0.041909736100933515, 0.0231250488650403, 0.059150605884497054, 0.02244431947474368, 0.010362462362536462, 0.05405234820500482, 0.03274326605605893, 0.060550867856363766, 0.045478086030925624, 0.006456584596890025, 0.06989335306570865, 0.032419578346889466, 0.043689625163096935, 0.043401608782005496, 0.026504696616029833, 0.019557036612241063, 0.08692462550243363, 0.06842078364570625, 0.04652379808248952, 0.027818336966447532, 0.06831846374552697, 0.028062765159120318, 0.22044662560801953, 0.07088797938195057, 0.052612147555919364, 0.03046000605536392, 2.7181316586211324, 43.011393025517464, 73.9552491903305, 17.667207084596157, 65.40691629052162, 86.07144623994827, 62.73646138608456, 40.7433707267046, 28.034555576741695, 31.63127537816763, 22.53831770271063, 33.90934243798256, 40.818025320768356, 46.886717677116394, 47.64277830719948, 27.769590094685555, 11.416286006569862, 1.8073810916393995, 0.19029147340916097, 0.03262693069700617, 0.07028544452623464, 0.01366264001262607, 0.07647344216820784, 0.36332958668936044, 0.7516449701506644, 2.4311354337260127, 4.315219447016716, 6.58402212895453, 5.046295942738652, 0.421133391209878, 2.325085261836648, 2.285686363466084, 2.7279439195990562, 4.934857897460461, 4.477145383134484, 9.218863919377327, 10.562295131385326, 13.62276490777731, 16.390650384128094, 12.876331061124802, 12.293612379580736, 13.561501745134592, 16.719469539821148, 17.296706065535545, 15.928190499544144, 8.151241857558489, 8.02381094545126, 10.964400004595518, 8.52773705497384, 11.7663355730474, 9.500941783189774, 9.773185774683952, 8.43858813866973, 5.792703665792942, 3.100531976670027, 7.021106975153089, 7.106926320120692, 5.760547891259193, 8.61303772777319, 4.95395852252841, 3.161092889495194, 3.715722053311765, 1.2019855831749737, 0.31638485728763044, 0.49928893335163593, 1.2931149057112634, 0.48974464705679566, 0.1369632943533361, 0.03006224458658835, 0.2988708845805377, 0.14162758860038593, 0.08350860880455002, 0.17446762329200283, 0.28980186965782195, 1.6652776231057942, 16.595444194972515, 43.844566717743874, 63.77765491604805, 62.61164948344231, 53.99147763848305, 39.49680581688881, 27.93760757893324, 43.899260982871056, 60.6769946962595, 53.318571746349335, 63.33630479872227, 83.71943324804306, 84.87071067094803, 76.08118191361427, 89.34100359678268, 68.67334261536598, 7.874699821695685, 0.3513439907692373, 0.024197177663154434, 0.07800928709912114, 0.15986938553396612, 0.02155018923076568, 0.06876149622257799, 0.07099828479113057, 0.04583659159834497, 0.0042930756899295375, 0.045886668012826703, 0.011055708073399728, 0.019010606265510432, 0.05933389038546011, 0.03201111510861665, 0.017043642183125485, 0.009040506247401936, 0.017144058474514168, 0.023066337562340777, 0.08190746972104535, 0.028613037975446787, 0.058271576490369625, 0.04107943983399309, 0.03466913927695714, 0.096212514617946, 0.03556320458301343, 0.02400068293354707, 0.05200977226195391, 0.0282072019399493, 0.02387646040006075, 0.04161862867476884, 0.010772447003546404, 0.0193656756891869, 0.015714672772446647, 0.05488369090016931, 0.06121871912910137, 0.056281025099451654, 0.008846623877616366, 0.04261403053533286, 0.01941612317750696, 0.05187546579691116, 0.03157162638672162, 0.020851162189501338, 0.03606462552852463, 0.052553265559254214, 0.0577104720287025, 0.14709844894241542, 0.09569734538672492, 0.2124697997351177, 0.10531642532441765, 0.18107984738890082, 0.09459700755542144, 0.096243276639143, 0.11615157360211015, 0.12411900388542563, 0.15735245106043294, 0.12247136924997903, 0.06770191714167595, 0.14884972450090572, 0.17836281505879015, 0.13348268112167716, 0.1937348159844987, 0.19960756413638592, 0.08683934531291015, 0.14152793301036581, 0.07788714443449862, 0.13237743027275428, 0.18856394657632336, 0.18496295699151233, 0.10167859552893788, 0.1043488280265592, 0.20226388878654689, 0.1623491829377599, 0.1881842192960903, 0.18074386229272932, 0.1167433473165147, 0.18546537612564862, 0.13990877458127216, 0.21275770850479603, 0.30948139959946275, 0.16259855940006673, 0.4225436202250421, 0.1415986448409967, 0.2805108338361606, 0.1814503423520364, 5.573341911658645, 58.916891142725945, 89.4865433871746, 26.237383112311363, 74.3303194642067, 93.40606346726418, 58.73016536235809, 36.126040890812874, 33.75366099178791, 45.67653961479664, 39.106768146157265, 35.47929659485817, 41.53787009418011, 68.01750540733337, 62.08331823348999, 36.29043526947498, 14.757175985723734, 2.687572273425758, 0.478203656966798, 0.19202170165954158, 0.21085798856802285, 0.11398433169233613, 0.32782366848550737, 0.9422800876200199, 2.516790912486613, 2.13599125854671, 10.263318624347448, 22.25426584482193, 24.803117774426937, 24.934421628713608, 12.926701158285141, 21.724323481321335, 24.138193354010582, 20.400124937295914, 25.73820009827614, 25.361693501472473, 27.596663273870945, 28.897656463086605, 28.117955401539803, 20.687300227582455, 26.448220498859882, 26.441912837326527, 31.021770983934402, 29.106301367282867, 29.239615313708782, 17.66951736062765, 22.233695648610592, 17.562667094171047, 28.140182308852673, 20.49320664256811, 17.642430514097214, 18.007855005562305, 13.850729875266552, 13.472418375313282, 8.447363767772913, 11.730145364999771, 6.70326448045671, 8.49440524354577, 16.212992817163467, 9.758953638374805, 6.284150769934058, 6.6072251088917255, 2.6432405272498727, 2.1983136143535376, 1.6949445311911404, 3.1760505493730307, 0.61993382521905, 0.5037573748268187, 0.14405390684260055, 0.7150199229363352, 0.30819027044344693, 0.5753594264388084, 0.31462213781196624, 0.6606061302591115, 2.525600027292967, 22.337194494903088, 55.64621664583683, 81.17253631353378, 90.69790318608284, 100.84717378020287, 100.56191548705101, 36.608052626252174, 42.74896390736103, 59.288222417235374, 59.59490776062012, 71.99070140719414, 92.30035319924355, 98.98609444499016, 86.14448592066765, 99.74492132663727, 81.14165917038918, 11.146930810064077, 0.4470462491735816, 0.12097914033802226, 0.23733728332445025, 0.32261572137940675, 0.09613279311452061, 0.17796031868783757, 0.17003410728648305, 0.11319094614009373, 0.13160414207959548, 0.16110066790133715, 0.1550088229123503, 0.11486397706903517, 0.10042467023595236, 0.09330251647043042, 0.12849981256294996, 0.11895896241185255, 0.06807852740166709, 0.19148691004374996, 0.20930158614646643, 0.084620212437585, 0.1565453060902655, 0.09868680528597906, 0.24370502913370728, 0.22176481346832588, 0.15779456327436492, 0.13607019383925945, 0.09550326634780504, 0.18096913379849866, 0.20389564888319, 0.1512466833810322, 0.19941208243835717, 0.1595261719194241, 0.11647235209238715, 0.10592149090371095, 0.14317575318273157, 0.133597981184721, 0.0910693866899237, 0.16556818911340088, 0.1547729386948049, 0.15856399229960516, 0.09119755559368059, 0.13239179825177416, 0.10048428695881739, 0.12659792555496097, 0.159685229009483], [0.03001822595251724, 0.13213243248173967, 0.05545029467612039, 0.055022216474753805, 0.0720621609070804, 0.011642595673038159, 0.05245812593784649, 0.04834641258639749, 0.03956922497309279, 0.010410186168883229, 0.010536701938690385, 0.04831313468457665, 0.04139843716984615, 0.08468373285722919, 0.02080033991660457, 0.04359605518402532, 0.062119749491102993, 0.04647069741622545, 0.023533259773103055, 0.06998937955358997, 0.052193490919307806, 0.0422754479222931, 0.03972894999606069, 0.03825090723694302, 0.0484763478016248, 0.014241488297557225, 0.03001610155479284, 0.053821339897695, 0.043621310469461605, 0.06607820192584768, 0.02921298273577122, 0.09536432145978324, 0.06618406929192133, 0.0847181017161347, 0.10952937504043803, 0.16255953727522865, 0.15522189351031557, 0.3334263787837699, 13.470479529350996, 76.14950984716415, 88.82846429944038, 81.07046619057655, 48.17782759666443, 41.57770715653896, 32.41330951452255, 12.948639281094074, 29.729692116379738, 44.595729410648346, 32.373153269290924, 38.59651252627373, 47.99006067216396, 46.49446092545986, 35.635259225964546, 17.065503671765327, 4.934487892314792, 0.08678243000758812, 0.04227135126711801, 0.022939595437492244, 0.13676402770215645, 0.03693287151691038, 0.28380582109093666, 0.6627952877897769, 0.255232987110503, 0.8482159569393843, 3.900253688916564, 2.489727814681828, 10.710481479763985, 5.873895334079862, 5.5875735729932785, 2.54182705655694, 0.1142369068111293, 3.1142934132367373, 3.8522993121296167, 1.8304522661492229, 10.179437175393105, 4.886726830154657, 4.577020173892379, 8.160183727741241, 17.383221723139286, 12.913464568555355, 9.583828635513783, 12.734656613320112, 14.560987763106823, 11.943302527070045, 10.701707750558853, 3.556243423372507, 5.972110088914633, 3.9295349176973104, 11.749252639710903, 3.4129003901034594, 7.365425499156117, 4.776075817644596, 4.641086161136627, 2.7230134466663003, 4.455088516697288, 9.423323348164558, 4.289782661944628, 4.085036348551512, 4.318738533183932, 2.7814089506864548, 3.832045686431229, 0.057582570298109204, 0.3724674432305619, 0.0741010632191319, 0.3787520981859416, 0.3632943198317662, 0.18507459084503353, 0.1214068103581667, 0.2548320492496714, 0.15405863639898598, 0.23451810178812593, 0.06762849647202529, 0.00850184989758418, 0.12382468295982108, 0.8080130454618484, 8.6650768853724, 35.79186402261257, 49.963427782058716, 81.28693297505379, 130.10495781898499, 72.65363663434982, 28.772681169211864, 18.77184771001339, 40.26849500834942, 63.1876415759325, 46.375766694545746, 44.164790734648705, 64.59246039390564, 66.96145847439766, 79.76164922118187, 64.6454219520092, 18.657470047473907, 0.27507685823366046, 0.3137705975677818, 0.059970697620883584, 0.044424373627407476, 0.03347769539686851, 0.05025443715567235, 0.024440282977593597, 0.024643742763146292, 0.017950826804735698, 0.014272613043431193, 0.055008045164868236, 0.028557814766827505, 0.04908100891043432, 0.0638771551894024, 0.016753202689869795, 0.07351323773036711, 0.04679128665884491, 0.03309462474135216, 0.03858837291772943, 0.0023197210202852148, 0.04398625787871424, 0.017427195234631654, 0.02808050805469975, 0.0211048022902105, 0.08413951596594416, 0.0250386191328289, 0.01861731994722504, 0.09889922279398888, 0.029735306270595174, 0.009030140299728373, 0.03679187087982427, 0.030147949655656703, 0.022507331523229368, 0.023422954363923054, 0.05362057781894691, 0.0221652311302023, 0.05437130843347404, 0.023079050552041736, 0.07911703156423755, 0.059250792110105976, 0.10678182559786364, 0.042099570055142976, 0.015228388856485253, 0.04900832296698354, 0.018808391432685312, 0.086775728414068, 0.05922767420997843, 0.07209920149762183, 0.032588903050054796, 0.017670651213848032, 0.038154468857101165, 0.07425113290082663, 0.11408246587961912, 0.08507120073772967, 0.021188934006204363, 0.027764779879362322, 0.029830559069523588, 0.03804365507676266, 0.06108622721512802, 0.0018148453773392248, 0.12431497540092096, 0.05539936108107213, 0.01223875176947331, 0.07439444161718711, 0.014559104311047122, 0.022305202037387062, 0.021496082954399753, 0.049848649359773844, 0.044030248682247475, 0.06330147865810432, 0.05761489454016555, 0.0660252571105957, 0.06241542112547904, 0.05183771274460014, 0.06534342377563007, 0.04865173214056995, 0.04177222726866603, 0.06274402927374467, 0.02799811296426924, 0.16674576967488974, 0.2243507676757872, 0.2609004720579833, 19.47667568922043, 87.26572215557098, 98.73917609453201, 93.88609170913696, 58.76239523291588, 49.010587111115456, 43.91016259789467, 14.857141021639109, 24.145072884857655, 39.17862229049206, 30.985824912786484, 36.08261302113533, 45.77545590698719, 47.67243191599846, 36.277170181274414, 19.493865966796875, 6.195834008976817, 0.3672727954108268, 0.022994278733676765, 0.09347971907118335, 0.11125975172035396, 0.08137674507452175, 0.6429911067243665, 1.0173049243167043, 0.5430773680564016, 1.2886914680711925, 2.536773565225303, 7.936522029340267, 6.022060783579946, 0.653851042734459, 1.2836871366016567, 0.36189041391480714, 0.5854701495263726, 0.6715852255001664, 1.96970006916672, 1.653817081823945, 6.087023047730327, 9.466969706118107, 14.073871951550245, 9.514303766191006, 13.999362699687481, 13.221671730279922, 15.393426194787025, 14.94372982531786, 16.259853802621365, 14.386897254735231, 7.738256743177772, 5.569790527224541, 5.713815623894334, 3.3621002035215497, 7.930600047111511, 4.6220705565065145, 5.3606008272618055, 5.2849663607776165, 4.8844099044799805, 2.1683771582320333, 2.407981138676405, 1.987622519955039, 6.1449148412793875, 6.141922501847148, 9.88750359043479, 6.768218195065856, 4.5127523224800825, 0.9186404873616993, 0.1994343617116101, 0.24570436013164, 0.5607297364622355, 1.0376605507917702, 0.11356725211953744, 0.1552344358060509, 0.22957161330850795, 0.3417056001489982, 0.39055476954672486, 0.20888715604087338, 0.043331457272870466, 0.12071564822690561, 0.22927717363927513, 8.799620065838099, 35.865321680903435, 41.761792078614235, 80.4973429441452, 111.2040576338768, 44.866559877991676, 27.223584093153477, 29.393704645335674, 53.96852307021618, 71.96423962712288, 55.08448898792267, 61.08158178627491, 76.16654813289642, 78.82886007428169, 89.92331475019455, 82.35620319843292, 32.551192715764046, 0.8366100734565407, 0.5535791139118373, 0.03354499705892522, 0.03604178964451421, 0.06047606308129616, 0.04694090734119527, 0.045747170224785805, 0.05466446418722626, 0.01170013159935479, 0.03758567945624236, 0.05946523197053466, 0.034009989685728215, 0.044629284311668016, 0.0012435092503437772, 0.09986633769585751, 0.015379636697616661, 0.018947390126413666, 0.016842522018123418, 0.011768080785259372, 0.04479932147660293, 0.05940311049926095, 0.019232983395340852, 0.024708125929464586, 0.03605445810535457, 0.051703625213121995, 0.09935442649293691, 0.02419776767055737, 0.039039962357492186, 0.028288353933021426, 0.017266238246520516, 0.04368866779259406, 0.02591377266071504, 0.011021473728760611, 0.07291714471648447, 0.051687891682377085, 0.05945334647549316, 0.055646002729190513, 0.03819318299065344, 0.01883416436612606, 0.051827022107318044, 0.05901381322473753, 0.07959274822496809, 0.0684597018698696, 0.02100730263919104, 0.11942849698243663, 0.13983720185933635, 0.13090339140035212, 0.0999683458940126, 0.1193835970479995, 0.10182028636336327, 0.09388365520862862, 0.25661332241725177, 0.2185202031978406, 0.1495348900789395, 0.11300043683149852, 0.14044426381587982, 0.22165714268339798, 0.25337969593238086, 0.14459923695540056, 0.13249767303932458, 0.2938691951567307, 0.14087870222283527, 0.1477236341452226, 0.12232309556566179, 0.2270276498165913, 0.09784156587556936, 0.16494803567184135, 0.1326888651237823, 0.15883533633314073, 0.1349049774580635, 0.15343478706199676, 0.15015768556622788, 0.15949004417052492, 0.24622960772830993, 0.187900822784286, 0.32394173147622496, 0.12806065409677103, 0.18514346214942634, 0.29212942288722843, 0.3562618768773973, 0.3163213888183236, 0.7515506283380091, 28.24075721204281, 105.3147080540657, 109.30941849946976, 102.01365798711777, 70.62710657715797, 61.60032615065575, 51.012293100357056, 22.781027778983116, 46.85826860368252, 64.7408652305603, 49.22091722488403, 60.433868542313576, 70.20559519529343, 68.00864428281784, 51.85903586447239, 27.92414680123329, 8.30408200621605, 0.7232610869687051, 0.2595258958172053, 0.2722793474094942, 0.2372263025608845, 0.38327246031258255, 1.561788513790816, 2.9026328958570957, 1.5071621700190008, 5.634912857785821, 13.204079624265432, 18.33295416086912, 30.678989477455616, 18.15771896392107, 17.313763350248337, 9.732753094285727, 4.498081309720874, 15.81291988492012, 16.63263849914074, 15.396484080702066, 28.61849494278431, 22.486452385783195, 23.306816965341568, 23.00459448248148, 31.166873797774315, 30.773334614932537, 22.862516306340694, 24.91648469120264, 30.80615345388651, 28.90516296029091, 24.726187102496624, 19.23988949507475, 22.75609351694584, 15.978239513933659, 30.68327184766531, 18.565978556871414, 20.543647035956383, 15.419877525418997, 13.605180401355028, 8.459649458527565, 13.670703135430813, 21.550351716578007, 17.07032561302185, 14.767174199223518, 14.063347466289997, 10.559806264936924, 10.893829241394997, 2.2681229934096336, 0.8483224699739367, 0.7978792861104012, 1.4646339020691812, 1.540881204418838, 0.7904746115673333, 0.7351334311533719, 0.7713204924948514, 0.8676634915173054, 1.0920840804465115, 0.47382878547068685, 0.2266640865127556, 0.4022923397133127, 1.5878639020957053, 15.035054124891758, 54.451036378741264, 66.89498484134674, 105.88570341467857, 158.4070247411728, 91.78067788481712, 37.910941913723946, 31.726148687303066, 56.84560328722, 79.52887371182442, 60.82212790846825, 60.21276980638504, 87.21808031201363, 89.71262365579605, 97.34436213970184, 97.19567611813545, 37.63587847352028, 1.161401504650712, 0.5659339134581387, 0.16385247727157548, 0.161921973049175, 0.16676709899911657, 0.16056226944783702, 0.18471260089427233, 0.10393090240540914, 0.13650853594299406, 0.132308351167012, 0.21590137184830382, 0.09944162142346613, 0.19199614209355786, 0.13429945916868746, 0.2055057234247215, 0.14959896710934117, 0.14807038038270548, 0.08997231430839747, 0.11093598979641683, 0.15772471233503893, 0.17967322521144524, 0.13869359681848437, 0.10813165863510221, 0.1263988221762702, 0.1900520862545818, 0.18330492486711591, 0.15646009269403294, 0.14758415491087362, 0.08913080047932453, 0.12531795830000192, 0.13752621336607262, 0.11968896113103256, 0.06144876635516994, 0.17973094945773482, 0.2595159213524312, 0.1005656411871314, 0.17349852685583755, 0.1237727771513164, 0.19526009273249656, 0.2597511524800211, 0.20314533758210018, 0.24642020609462634, 0.13384444842813537, 0.1435130147729069], [0.037540712728514336, 0.05001230034395121, 0.007121124499462894, 0.021735392183472868, 0.024875658345990814, 0.04925260829622857, 0.07631673768628389, 0.023303386951738503, 0.059090028080390766, 0.07121767848730087, 0.020168638657196425, 0.03669566256576218, 0.05311247383360751, 0.04369424132164568, 0.01538028329377994, 0.014071103250898886, 0.018383124115644023, 0.10771383691462688, 0.05306023405864835, 0.04782629694091156, 0.009534570654068375, 0.05221397048444487, 0.07958140820846893, 0.021967591637803707, 0.06971650669584051, 0.0438025726180058, 0.018883006960095372, 0.05019015974539798, 0.03311777974886354, 0.0597902963636443, 0.020440374173631426, 0.04276476443919819, 0.03965637166402303, 0.03478791630186606, 0.06620336513151415, 0.21438555006170645, 2.0697363512590528, 33.782262057065964, 96.49391457438469, 82.02356144785881, 68.11471179127693, 74.6936483681202, 61.847616881132126, 48.09995077550411, 26.225360557436943, 34.885263070464134, 49.3808164447546, 37.41381838917732, 51.84684231877327, 46.752242892980576, 40.96767269074917, 26.871988959610462, 11.56251261010766, 2.1720724599435925, 0.03647147459560074, 0.03510825692501385, 0.07441528854542412, 0.0814778107451275, 0.05379850401368458, 0.16842149459989741, 0.5038691125810146, 1.125924945808947, 0.14652462035883218, 0.8240571501664817, 2.9052013205364347, 4.838779103010893, 3.7721385760232806, 1.278915898874402, 0.16711271717213094, 0.3053610253846273, 0.19299296516692266, 1.029574703425169, 0.6897708121687174, 0.05978747249173466, 3.3046268625184894, 7.048560976982117, 8.635221887379885, 11.750274784862995, 9.563535824418068, 7.378540970385075, 10.401483960449696, 11.592720039188862, 15.033498108386993, 11.991718579083681, 5.272632222622633, 5.677036922425032, 8.439061213284731, 3.8335530180484056, 8.893220443278551, 9.67341547831893, 7.63041140511632, 7.839787770062685, 4.2273045144975185, 1.4218939142301679, 4.855576576665044, 6.444717328995466, 5.770567953586578, 6.390389269217849, 3.2399631198495626, 2.4698014464229345, 1.1682997969910502, 1.2224519974552095, 0.020038538314111065, 0.04824199611903168, 0.2663436799775809, 0.29517421731725335, 0.34120892523787916, 0.07240722989081405, 0.03522016166243702, 0.37633370608091354, 0.10525709061766975, 0.25141217338386923, 0.09353544694022276, 0.047574579002684914, 0.032545387221034616, 0.03925263219571207, 4.536835430189967, 29.439368695020676, 53.282306492328644, 53.127354606986046, 48.18180598318577, 56.74310378730297, 54.50477309525013, 31.856789477169514, 47.02771671116352, 36.606981083750725, 21.157891675829887, 53.58046509325504, 67.18626961112022, 63.971269726753235, 67.88670882582664, 80.0766371190548, 36.73466943204403, 3.6569541692733765, 0.3303335822420195, 0.02579032752692001, 0.026792913376993965, 0.0497126804839354, 0.02726463913859334, 0.013142631978553254, 0.057228602963732556, 0.03697893291246146, 0.054116941028041765, 0.0063808368304307805, 0.04585969465551898, 0.0345535757514881, 0.03428101830650121, 0.07655729743419215, 0.10277002758812159, 0.02656685890542576, 0.025031257027876563, 0.0481131184642436, 0.042777911585289985, 0.03819573968939949, 0.03349669437739067, 0.09694511085399427, 0.022002337136655115, 0.02003523761231918, 0.05681859234755393, 0.11848861147882417, 0.02279558353620814, 0.042312258447054774, 0.005831099288116093, 0.036951421498088166, 0.030511195691360626, 0.021694074966944754, 0.03768397691601422, 0.038609264374827035, 0.09442436174140312, 0.048075268932734616, 0.007984815092640929, 0.03921483461454045, 0.05055394198279828, 0.061005752431810834, 0.04746403981698677, 0.04085521104570944, 0.0635015987791121, 0.09760065731825307, 0.042345584588474594, 0.04370047907286789, 0.08304305956698954, 0.019450304644124117, 0.05983687726256903, 0.023712842812528834, 0.018197219833382405, 0.02291433458594838, 0.017725518191582523, 0.09894208182231523, 0.014030163602001267, 0.015415419347846182, 0.014832464203209383, 0.031314197622123174, 0.027431078742665704, 0.05967812074231915, 0.012944325480930274, 0.033507295956951566, 0.04211331091937609, 0.03942054681829177, 0.03221470848075114, 0.013491660320141818, 0.08659068873384967, 0.005813355001009768, 0.024280860379803926, 0.05058147566160187, 0.03373414452653378, 0.06288690012297593, 0.025989482855948154, 0.0873594349832274, 0.013809766151098302, 0.031612774764653295, 0.025588146090740338, 0.1824895865865983, 4.8155713733285666, 47.78750494122505, 109.17093873023987, 92.60084867477417, 77.78045073151588, 82.7412061393261, 72.02344805002213, 55.831745490431786, 28.35730265825987, 23.68825949728489, 44.484209194779396, 39.09853778779507, 48.36815558373928, 45.5400775372982, 45.08694425225258, 29.91311777383089, 14.09395482391119, 2.288039387203753, 0.14958810206735507, 0.07426954558468424, 0.07011801601038314, 0.13246501854155213, 0.08917958926758729, 0.11430920683778822, 0.9800300525967032, 1.2320760497823358, 0.05526265376829542, 0.07347184815444052, 3.6764084128662944, 1.753525275271386, 0.503877840237692, 1.5782504179514945, 0.3416030650259927, 0.5244221503380686, 0.543857691809535, 0.5169477732852101, 0.5125435721129179, 0.5996512260753661, 5.171029474586248, 4.652129793539643, 7.54591153934598, 6.930725974962115, 8.988555427640676, 10.979294255375862, 12.500188294798136, 11.51482516899705, 8.733534961938858, 5.59661328792572, 3.4997858153656125, 2.3289888398721814, 1.8579294229857624, 2.223242176696658, 7.676204647868872, 5.652798498049378, 2.0648265397176147, 3.4236690122634172, 4.0580302476882935, 0.7247430074494332, 1.9138760771602392, 1.412780222017318, 1.827311972156167, 2.1022082213312387, 3.687002481892705, 6.492303125560284, 4.9930142518132925, 2.075336775742471, 0.38125203747767955, 0.08074447978287935, 0.5815897264983505, 0.09569494824972935, 0.830833789659664, 0.08363183500478044, 0.07660794159164652, 0.760233459295705, 0.509954426670447, 0.12731668073683977, 0.13390993553912267, 0.07271728434716351, 0.03562104015145451, 0.05908980172534939, 5.2850808296352625, 28.382354713976383, 49.318400993943214, 60.10529637336731, 44.30308811366558, 49.92485225200653, 47.489133551716805, 35.42179428040981, 54.96576815843582, 45.384920462965965, 38.37839663028717, 64.02597919106483, 79.56162795424461, 74.294054210186, 75.89174687862396, 91.29197090864182, 55.96118554472923, 7.62130044400692, 0.29679619590751827, 0.09624618585803546, 0.030108363498584367, 0.10399598133517429, 0.02969928984384751, 0.0975794690020848, 0.04493153879593592, 0.05413994760601781, 0.02528311226342339, 0.04380227946967352, 0.0544954548968235, 0.0636119264527224, 0.037888965525780804, 0.015140801515372004, 0.025262964809371624, 0.026622558943927288, 0.023104454267013352, 0.015820729386177845, 0.07341650620219298, 0.0455669730581576, 0.02155157704692101, 0.02824756178597454, 0.0028775827604476945, 0.023162974466686137, 0.0833248753042426, 0.04170373074884992, 0.011647945630102186, 0.03527018612658139, 0.04370928836578969, 0.006938115056982497, 0.051857490980182774, 0.020846130428253673, 0.06235201202798635, 0.017591330470168032, 0.00733274651793181, 0.09021941979881376, 0.019367412314750254, 0.04988210908777546, 0.04951782961143181, 0.044127217697678134, 0.02656851203937549, 0.03587252060242463, 0.08300017085275613, 0.13532688841223717, 0.11147897472255863, 0.10801690033986233, 0.2773094759322703, 0.08000662914128043, 0.11724145457264967, 0.11089304171036929, 0.11650852437014692, 0.1319091350887902, 0.11095045425463468, 0.27461058169137686, 0.11758050473872572, 0.09552108531352133, 0.12178016258985735, 0.07820402664947324, 0.052449079157668166, 0.1981675304705277, 0.13622024125652388, 0.1691386170568876, 0.09160304281977005, 0.16668443859089166, 0.16701475367881358, 0.10564173833699897, 0.21144226659089327, 0.1969906475278549, 0.07234485980006866, 0.16150455950992182, 0.1500939202378504, 0.13915325340349227, 0.1482592718093656, 0.25230696599464864, 0.11204554510186426, 0.14058985834708437, 0.18145126261515543, 0.2235823925002478, 8.512886501848698, 63.50069537758827, 123.35624635219574, 101.12694516777992, 87.32111558318138, 96.05492413043976, 84.05800268054008, 69.36187326908112, 41.47404111921787, 54.21710193157196, 74.30503562092781, 54.85861770808697, 73.93325597047806, 64.83320787549019, 58.79638820886612, 41.9246057420969, 19.21734720468521, 4.314671326428652, 0.4277102742344141, 0.20685156370745972, 0.341176864458248, 0.4375738027738407, 0.519849214470014, 0.4701782501069829, 1.2995143560692668, 2.6831174874678254, 0.29630916891619563, 3.7499959766864777, 11.544244140386581, 12.898212186992168, 9.33052757754922, 6.038096398115158, 0.5815135524608195, 0.8967413718346506, 1.1057980195619166, 3.611811879090965, 3.6482690228149295, 6.994080925360322, 14.209214989095926, 22.375538237392902, 23.90792191028595, 28.20362750440836, 25.65592311322689, 19.375895597040653, 29.87183678895235, 30.139585621654987, 31.70938778668642, 28.168781474232674, 19.667892828583717, 15.492506828159094, 19.600359052419662, 14.810323733836412, 23.441795222461224, 24.050524458289146, 18.584312573075294, 17.535851933062077, 14.913049321621656, 7.305748276412487, 11.4935814589262, 18.10859140008688, 17.69501969218254, 16.58746462315321, 12.574583552777767, 10.773029923439026, 9.605396278202534, 4.44929382763803, 0.6707528920378536, 0.536146005615592, 0.8449557912535965, 0.3852330066729337, 1.3860524562187493, 0.462679797783494, 0.7698433811310679, 1.8080396438017488, 1.1073383619077504, 0.599362263455987, 0.31651817669626325, 0.2382181235589087, 0.11929464322747663, 0.3882331238128245, 7.914383467286825, 47.10790000855923, 70.10942235589027, 66.37577310204506, 68.63810330629349, 75.6497910618782, 71.70600548386574, 44.432474970817566, 60.717090144753456, 49.953745901584625, 34.43208418786526, 70.20472884178162, 85.54320618510246, 86.84310123324394, 84.30539980530739, 102.9867173731327, 67.3869976401329, 10.783873591572046, 0.48509835731238127, 0.19532231439370662, 0.16808945772936568, 0.20106499374378473, 0.10007335979025811, 0.20501715276623145, 0.14911793667124584, 0.1670923674828373, 0.12492331385146827, 0.10332358069717884, 0.127387540997006, 0.20532881026156247, 0.07843683095416054, 0.17494393367087469, 0.15172244457062334, 0.06463234982220456, 0.09391542655066587, 0.10178197670029476, 0.24975682783406228, 0.1250067015644163, 0.14882115181535482, 0.16487744258483872, 0.08201914810342714, 0.04917952530377079, 0.20580152864567935, 0.17101449921028689, 0.13436579232802615, 0.12846037483541295, 0.13722634117584676, 0.07447561773005873, 0.10499993644771166, 0.16416694008512422, 0.1658540198695846, 0.1449026120826602, 0.15680446405895054, 0.17414881149306893, 0.06577581385499798, 0.10091452480992302, 0.12223218989674933, 0.16279809322440997, 0.11385842633899301, 0.140006723231636], [0.014049040128156776, 0.03335190507641528, 0.047539200822939165, 0.03752361735678278, 0.025261278278776444, 0.09616840136004612, 0.021042949847469572, 0.02023125736741349, 0.05096448694530409, 0.07855797171941958, 0.03464666704530828, 0.04685300365963485, 0.043511854819371365, 0.04273223239579238, 0.03367052762769163, 0.01767810979799833, 0.07130732250516303, 0.05018053780077025, 0.10763791520730592, 0.05712183388823178, 0.013646529841935262, 0.035302343385410495, 0.06755434849765152, 0.024547278408135753, 0.040473672925145365, 0.06464114427217282, 0.01771042476320872, 0.06835702573880553, 0.08008335978956893, 0.03804605221375823, 0.0072122342589864274, 0.030769958466407843, 0.048245729121845216, 0.13324506027856842, 0.3684152278583497, 12.651954051107168, 63.30764673650265, 87.41187751293182, 75.92456191778183, 80.06524533033371, 76.10226318240166, 45.1183457672596, 42.912324741482735, 35.372206941246986, 36.62561908364296, 51.16927407681942, 28.07718548923731, 52.46404320001602, 53.954011648893356, 44.277880266308784, 19.586278907954693, 5.614044377580285, 0.5162109690718353, 0.09839736769208685, 0.05467680239235051, 0.027725112086045556, 0.06210502157045994, 0.03485713270492852, 0.07804450942785479, 0.10758719683508389, 0.022488286158477422, 0.11837155994726345, 0.28286744956858456, 0.6287210318259895, 0.8624868036713451, 3.5572320828214288, 0.28220655221957713, 0.1793274882948026, 0.5560121708549559, 0.680290914606303, 0.17192904779221863, 0.3239086316898465, 0.3100477473344654, 0.23180507705546916, 2.909521688707173, 3.9787102164700627, 9.39216312021017, 4.109316095709801, 7.560182623565197, 9.234938006848097, 15.714817699044943, 12.647918667644262, 12.254751864820719, 8.52900618687272, 8.310092333704233, 11.383463367819786, 28.98912515491247, 35.950095131993294, 41.17150895297527, 30.649170577526093, 27.458474189043045, 6.2231051456183195, 5.418248008936644, 2.7129938593134284, 2.4692416889593005, 1.2796884449198842, 3.0985681945458055, 6.2234837003052235, 14.439499732106924, 9.69691151753068, 3.571602674201131, 0.8192411460913718, 0.1665984682040289, 0.18102461675880477, 0.5898347496986389, 0.24367286445340142, 0.4083610890666023, 0.295445813680999, 0.20761913736350834, 0.22760391264455393, 0.2235665699117817, 0.21031289594247937, 0.06671443770756014, 0.11472156635136344, 0.1269343262538314, 0.12181600832263939, 0.06242295392439701, 0.6955950683914125, 16.158287152647972, 33.22340704500675, 45.87717644870281, 44.89165373146534, 54.98719900846481, 51.339915320277214, 59.92748871445656, 56.818149760365486, 20.087614506483078, 25.346475318074226, 40.52687354385853, 62.06928178668022, 62.990473955869675, 59.851853772997856, 78.99206131696701, 66.73542380332947, 20.523173734545708, 0.7789444865193218, 0.14768191060284153, 0.15042907412862405, 0.14739101839950308, 0.15979148971382529, 0.05538115990930237, 0.03407162133953534, 0.057884212510543875, 0.05657722365867812, 0.03231214875995647, 0.15724044613307342, 0.14261005853768438, 0.13378022296819836, 0.06252936305827461, 0.07530903472797945, 0.06686531633022241, 0.07600325450766832, 0.0746727766818367, 0.03073751176998485, 0.031699932587798685, 0.022552472655661404, 0.060150924473418854, 0.014231684526748722, 0.06279072520555928, 0.07234649994643405, 0.035179310143576004, 0.03312316031951923, 0.060436992716859095, 0.03454122270341031, 0.06578673826879822, 0.03552450529241469, 0.05025264857977163, 0.014202827042026911, 0.035790717374766245, 0.01260872444618144, 0.018047094490611926, 0.04331749747507274, 0.02799507201416418, 0.041693188541103154, 0.019840251297864597, 0.07112977851647884, 0.017592343501746655, 0.010393809752713423, 0.006060538880774402, 0.003375062206032453, 0.02024694265855942, 0.0784580415347591, 0.035171116833225824, 0.041621237323852256, 0.07073432512697764, 0.06597148851142265, 0.046353285943041556, 0.07430847865180112, 0.043147616161149926, 0.03160866326652467, 0.052758038946194574, 0.02399032069661189, 0.04631162177247461, 0.035334292842890136, 0.08888654483598657, 0.0269310975636472, 0.02888938965043053, 0.043581972931860946, 0.06848483099020086, 0.047873156145215034, 0.026327464329369832, 0.04291048884624615, 0.02748271552263759, 0.025614492333261296, 0.0708909182867501, 0.05634844921587501, 0.028241014188097324, 0.03765307759749703, 0.03336791320180055, 0.1029928054776974, 0.4004206135869026, 24.879586771130562, 84.01181235909462, 102.14682564139366, 82.78143838047981, 92.0038703083992, 86.89627557992935, 65.57241261005402, 67.17479422688484, 50.79354643821716, 41.536923944950104, 46.288941353559494, 31.48566149175167, 43.671691194176674, 48.43798063695431, 45.830393359065056, 24.40273705869913, 7.562909452244639, 0.43568085122387856, 0.10778708689031191, 0.06805146869737655, 0.06881307548610494, 0.03826485961326398, 0.0905825749214273, 0.0770648596517276, 0.17449913488235325, 0.1006337629223708, 0.3134634968591854, 1.0479049198329449, 0.8663698984310031, 1.5069749113172293, 1.5535982907749712, 1.0431999410502613, 0.7423987006768584, 1.1712834681384265, 1.1850788653828204, 0.6110399274621159, 1.0024606646038592, 1.0118268057703972, 0.9964788355864584, 3.3581814263015985, 2.660573534667492, 2.504284121096134, 1.316482701804489, 3.135611694306135, 3.3789162011817098, 6.440045479685068, 5.122375935316086, 3.3249569591134787, 2.6638860069215298, 5.1573259849101305, 11.93367289379239, 26.551434360444546, 37.7393963187933, 42.9539705067873, 34.63992923498154, 27.998077534139156, 8.630400896072388, 4.718266194686294, 3.696336206048727, 3.6068937554955482, 3.723365580663085, 4.303882755339146, 5.818238295614719, 5.200416147708893, 2.9583362443372607, 1.2045901059173048, 1.064843579661101, 0.1576840426423587, 0.3269760764669627, 0.3692458395380527, 0.4949592734919861, 0.80665182787925, 0.26971285231411457, 0.20579286036081612, 0.19806158146820962, 0.5740400066133589, 0.10494961883523501, 0.1387111411895603, 0.047492920493823476, 0.18834265298210084, 0.19862282322719693, 0.08884300303179771, 0.6665643292944878, 14.15824357420206, 36.30465790629387, 45.04925027489662, 41.455957889556885, 46.29255495965481, 39.8031035810709, 55.13710096478462, 55.59769704937935, 32.04823650419712, 42.310269847512245, 53.483463898301125, 69.47177857160568, 72.35846847295761, 69.80587184429169, 91.90157979726791, 86.33697599172592, 35.99853113293648, 0.8636885485611856, 0.25871986406855285, 0.16685563721694052, 0.13123284559696913, 0.0916633868473582, 0.05043475306592882, 0.04066158100613393, 0.0305883753389935, 0.028309607187111396, 0.05413759499788284, 0.1034242678724695, 0.051240714310551994, 0.10856810084078461, 0.08802023585303687, 0.03267224623414222, 0.10796278293128125, 0.028445917450881097, 0.0533322014962323, 0.016335783584509045, 0.023830586396798026, 0.04696196578152012, 0.0707034369406756, 0.08191515094949864, 0.019419479540374596, 0.06596797073143534, 0.062044655278441496, 0.09009421948576346, 0.11696937581291422, 0.01737110742396908, 0.037252165711834095, 0.04049752555147279, 0.07340776370256208, 0.00887500267708674, 0.015906729458947666, 0.048181967504206114, 0.010422493760415819, 0.016681487104506232, 0.03769590693991631, 0.05466541784699075, 0.08919017971493304, 0.007301907962755649, 0.13023741776123643, 0.11308880435535684, 0.15415210247738287, 0.09785548856598325, 0.16694154823198915, 0.2006764052202925, 0.18378650449449196, 0.13047949149040505, 0.16799925710074604, 0.24738162872381508, 0.11132014769827947, 0.10781076882267371, 0.1351952165714465, 0.10879611829295754, 0.10002650058595464, 0.10890567413298413, 0.14828989282250404, 0.11779188323998824, 0.18911635677795857, 0.18067907280055806, 0.12734930554870516, 0.16504846309544519, 0.16271041589789093, 0.11697496418491937, 0.10994677373673767, 0.13892722490709275, 0.1537951294449158, 0.08438640623353422, 0.2144070278154686, 0.11553772841580212, 0.1770071338978596, 0.1213184131484013, 0.15470602666027844, 0.24974572530481964, 0.6357399676926434, 33.65988202393055, 105.08621111512184, 110.76589554548264, 93.71855109930038, 100.34094214439392, 97.57838398218155, 62.66537480056286, 61.63312219083309, 56.50777481496334, 58.03569182753563, 71.3071408867836, 44.33729387819767, 75.8381849527359, 72.55411237478256, 61.242172569036484, 33.15015457570553, 10.619160030037165, 0.990470526739955, 0.23672168666962534, 0.22184830508194864, 0.35285250982269645, 0.1893537401338108, 0.259235508274287, 0.23020361142698675, 0.2524775412166491, 0.12569606769829988, 0.2197215027990751, 1.183598607312888, 1.760929652955383, 5.772038949653506, 11.156401801854372, 2.7744159009307623, 1.154833675827831, 2.23472919780761, 1.9226239202544093, 0.8868167793843895, 1.7271402035839856, 1.837156293913722, 1.9535894086584449, 9.35291312634945, 15.038828272372484, 19.14359886199236, 16.808648854494095, 23.167843222618103, 25.79395640641451, 30.790982767939568, 25.830858126282692, 23.942357562482357, 19.564886055886745, 12.737750597298145, 12.816154640167952, 25.517241954803467, 33.617001324892044, 41.347173526883125, 30.90768590569496, 30.28943058103323, 12.194230612367392, 11.121516823768616, 5.88781826198101, 4.930074429139495, 4.170426316559315, 6.259657759219408, 14.147527199238539, 24.80963632464409, 20.793933905661106, 14.54044796526432, 4.3371950928121805, 0.30891632835846394, 0.3567998151993379, 0.888961348682642, 0.9876757173333317, 1.2262384942732751, 0.6701588176656514, 0.5046829220373183, 0.45911944820545614, 1.221008668653667, 0.48152797389775515, 0.35530797962564975, 0.27760532568208873, 0.46968487033154815, 0.5169112596195191, 0.12989494629437104, 1.3376330793835223, 26.843701377511024, 53.94776478409767, 63.12649145722389, 65.63698634505272, 77.2440867125988, 70.334203094244, 76.98071524500847, 66.19465202093124, 30.5217482149601, 40.69332741200924, 59.20947544276714, 80.32690688967705, 85.07282182574272, 79.49595987796783, 99.56856518983841, 102.3112428188324, 42.6408901065588, 1.2759477831423283, 0.3692064166534692, 0.26516060752328485, 0.2589449129300192, 0.35047297657001764, 0.1936908659990877, 0.15608311136020347, 0.14582839678041637, 0.1561729409149848, 0.09719864334329031, 0.2640786749543622, 0.18279431242262945, 0.19767263671383262, 0.20378812652779743, 0.14402318192878738, 0.17410766682587564, 0.22970712947426364, 0.15094361995579675, 0.11678389084408991, 0.12078566986019723, 0.19387288513826206, 0.13255652535008267, 0.2148275138461031, 0.09450454337638803, 0.1196800998877734, 0.19857740378938615, 0.15173276042332873, 0.2151412345119752, 0.20383550523547456, 0.13682075747055933, 0.15765667223604396, 0.18559422780526802, 0.06760568285244517, 0.14039994275663048, 0.1378318149363622, 0.07114770880434662, 0.12650592892896384, 0.1863796278485097, 0.24039215611992404, 0.1954548916546628, 0.13878367870347574], [0.0915652749245055, 0.02317336267879, 0.03473931305052247, 0.03747289898456074, 0.08892131445463747, 0.07869956607464701, 0.164990916964598, 0.061212559303385206, 0.05039770134317223, 0.2017178462119773, 0.15660513803595677, 0.19821188121568412, 0.10790077649289742, 0.036268085314077325, 0.032091059256345034, 0.08625273694633506, 0.11420016307965852, 0.056935269094537944, 0.04767418635310605, 0.0826578626583796, 0.050539937656139955, 0.0539494382974226, 0.03158932289807126, 0.06022074201609939, 0.12486173043726012, 0.26360957825090736, 0.3605837590293959, 0.3837981977267191, 0.3457189863547683, 0.4478390113217756, 0.12518413423094898, 0.25317358667962253, 0.19907896203221753, 0.1183074532309547, 27.76778519153595, 88.60676899552345, 78.48146751523018, 65.13015434145927, 65.59096321463585, 54.72064711153507, 33.425552397966385, 27.115396298468113, 15.948580205440521, 23.53355649858713, 39.90846052765846, 38.981279879808426, 40.99817365407944, 37.75281339883804, 26.311739422380924, 11.066312436014414, 2.3641645023599267, 0.09225775807863101, 0.1297913573216647, 0.06790914703742601, 0.3496626403648406, 0.03682630653202068, 0.15648974891519174, 0.10845236291061155, 0.04305238006054424, 0.1846722577465698, 0.5567552091088146, 0.5843002279289067, 0.4613475239602849, 0.7938448525965214, 0.9326667815912515, 1.5952781355008483, 2.1460471814498305, 5.737998001277447, 9.511961191892624, 9.414084143936634, 9.7644585929811, 12.648000363260508, 12.141146510839462, 10.725115444511175, 17.394400723278522, 9.52117569744587, 8.19032371044159, 7.43111589923501, 5.907249469310045, 7.085549617186189, 7.189688729122281, 7.360659604892135, 8.472963944077492, 25.184486210346222, 65.2559731900692, 82.93633326888084, 101.2235739827156, 96.20506927371025, 114.76698964834213, 107.37315639853477, 102.01333120465279, 51.1165215075016, 26.98420263826847, 22.003241814672947, 22.260265722870827, 21.989269964396954, 16.43643982708454, 8.937674257904291, 9.610926881432533, 12.327434364706278, 8.143525421619415, 2.0134663581848145, 1.6343995300121605, 0.6718773348256946, 0.534129204461351, 0.19914634904125705, 0.5887299589812756, 0.09054766429471783, 0.2803853218210861, 0.16889528167666867, 0.9081797674298286, 0.2361339799244888, 0.11461075628176332, 0.01362371900540893, 0.13467906770529225, 0.08807851671008393, 0.10605631687212735, 0.06690603797324002, 0.0311910938762594, 1.0004788334481418, 13.458838853985071, 38.20647105574608, 54.36181716620922, 43.074747025966644, 104.85282763838768, 120.27346417307854, 47.48781882226467, 22.669676654040813, 20.430800691246986, 45.4274819791317, 50.556815341115, 69.00511041283607, 68.79295259714127, 69.08390298485756, 73.33090469241142, 38.90518136322498, 2.2258787602186203, 0.5851974547840655, 0.19027860456844792, 0.5866258812602609, 0.12692966556642205, 0.13563594839069992, 0.07808048132574186, 0.18191152776125818, 0.3394978295546025, 0.37345960561651736, 0.6238030863460153, 0.44184913742356, 0.4660624178359285, 0.45856366865336895, 0.37386561976745725, 0.08602812595199794, 0.0860207638470456, 0.06760784992366098, 0.026508116061449982, 0.034991739739780314, 0.12335675884969532, 0.10588453194941394, 0.11490183402202092, 0.06512739942991175, 0.0646890424832236, 0.015850220479478594, 0.050586804281920195, 0.03720956272445619, 0.035664953029481694, 0.1500693551497534, 0.12404923458234407, 0.011192807796760462, 0.07278143559233285, 0.08318894353578798, 0.05018073075916618, 0.03220983257051557, 0.042284798983018845, 0.03499747654132079, 0.1959024215466343, 0.22158956271596253, 0.030965642399678472, 0.08016675492399372, 0.019369132241990883, 0.04066898763994686, 0.025970775168389082, 0.06434132403228432, 0.10569571473752148, 0.04222175353788771, 0.05484561130288057, 0.24719402863411233, 0.06636754304054193, 0.19995279639260843, 0.08043233247008175, 0.048253863060381263, 0.038015805985196494, 0.11837369733257219, 0.03551122084900271, 0.03450872405664995, 0.02534989998821402, 0.06296587947872467, 0.05091461462143343, 0.05870862725714687, 0.17235784587683156, 0.09257110767066479, 0.01822671649279073, 0.14677301718620583, 0.16642119880998507, 0.24054754700046033, 0.19079306133789942, 0.28399569215252995, 0.1267543257563375, 0.17309276503510773, 0.09835223769186996, 0.1707111982977949, 44.865959510207176, 108.92994046211243, 88.27164977788925, 75.53897380828857, 80.76639130711555, 66.76257714629173, 51.98993884027004, 35.16488626599312, 24.7871358320117, 35.10960303246975, 45.76752953231335, 53.61628197133541, 48.12329292297363, 46.32231116294861, 32.98936240375042, 14.22612028196454, 2.780764647759497, 0.21135114569915459, 0.04177459100901615, 0.21862496476387605, 0.37285748636350036, 0.10042203561170027, 0.24032718851231039, 0.2558496524579823, 0.35468516929540783, 0.7451585400849581, 1.5657650004141033, 2.8225469682365656, 3.194708260707557, 2.4006964545696974, 2.396915894933045, 3.1341330986469984, 5.204054927453399, 7.613241076469421, 10.34624157473445, 11.116784177720547, 11.9917774759233, 15.232271142303944, 14.423066563904285, 13.803707398474216, 17.571573816239834, 11.801193952560425, 9.204515889286995, 8.755044657737017, 6.848040986806154, 4.248326411470771, 4.7076015919446945, 4.46468822658062, 8.738315105438232, 25.757128782570362, 66.19433283805847, 90.78120231628418, 111.40948221087456, 106.4029848575592, 125.61416879296303, 115.88367372751236, 109.25082564353943, 58.87110359966755, 29.042745977640152, 25.49270287156105, 24.386445432901382, 24.361828453838825, 19.789051227271557, 13.81982708349824, 13.386929612606764, 13.44218434765935, 9.12358783185482, 4.662704626098275, 1.7324890103191137, 1.2584372540004551, 0.5902878160122782, 0.7036369212437421, 1.2577333417721093, 0.25677989004179835, 0.5231122300028801, 0.539887617342174, 1.091508767567575, 0.3698564489604905, 0.09676119181676768, 0.03059347018279368, 0.059074843738926575, 0.04066618603246752, 0.0834968160779681, 0.03273669062764384, 0.0450395917869173, 1.4812448294833302, 16.92473642528057, 39.53645668923855, 49.06160697340965, 38.37030306458473, 99.97720286250114, 114.59707036614418, 35.72563357651234, 26.076015271246433, 30.364921130239964, 61.97951540350914, 62.929023653268814, 79.35285955667496, 78.25723394751549, 79.55297961831093, 88.30387964844704, 62.14135631918907, 4.073199508711696, 0.42304264032281935, 0.134388709848281, 0.4365352710010484, 0.12090238742530346, 0.08188319407054223, 0.10741045436589047, 0.05754739620897453, 0.2502732438733801, 0.2975005831103772, 0.43716004060115665, 0.25059747335035354, 0.20879281422821805, 0.22223147592740133, 0.21471712680067867, 0.09837789373705164, 0.019161891214025673, 0.008863032762747025, 0.046987354653538205, 0.02786304394248873, 0.0378059934155317, 0.05583231519267429, 0.054917558809393086, 0.07888703257776797, 0.031758265395183116, 0.0251991419645492, 0.04439484728209209, 0.099575638450915, 0.050645274386624806, 0.15554782992694527, 0.05321226672094781, 0.03904957316990476, 0.09010187844978645, 0.03790829476201907, 0.07346228929236531, 0.03698337837704457, 0.04594862992234994, 0.026585408886603545, 0.14574208500562236, 0.09000545862363651, 0.21597708575427532, 0.16136079066200182, 0.11660780888632871, 0.16063471790403128, 0.1928397562005557, 0.160169035079889, 0.3672150563215837, 0.19121405202895403, 0.19358202262083068, 0.35462550062220544, 0.20745009096572176, 0.30186268966645, 0.29796887829434127, 0.13675939670065418, 0.17511535494122654, 0.16129329975228757, 0.15594032214721665, 0.10161308615352027, 0.17747879843227565, 0.23943735344801098, 0.130258183053229, 0.19544932554708794, 0.32546396541874856, 0.1671341058681719, 0.21713329246267676, 0.3456734778592363, 0.49611824098974466, 0.42666550842113793, 0.3411902528023347, 0.4034264897927642, 0.2907198469620198, 0.2894722076598555, 0.3060420200927183, 0.30247715825680643, 59.46688123047352, 122.37917438149452, 95.07098972797394, 87.32800841331482, 91.19828313589096, 72.73850128054619, 49.65834975242615, 38.88096526265144, 24.169735461473465, 40.70019744336605, 60.35307727754116, 60.6643033772707, 62.74666003882885, 58.425455912947655, 43.16627271473408, 19.07939750701189, 4.5866322331130505, 0.556134773651138, 0.1616094695054926, 0.6248848407994956, 0.8130842889659107, 0.18101955531165004, 0.21841459558345377, 0.2739572839345783, 0.3207320615183562, 0.5514086585026234, 1.5316607616841793, 3.0623345263302326, 2.628030893392861, 2.4974634870886803, 3.852344434708357, 5.19258476793766, 5.1147587690502405, 9.211501814424992, 13.94007258117199, 12.971132174134254, 12.82926868647337, 15.943378284573555, 13.912160228937864, 16.407586075365543, 26.545113399624825, 13.415331188589334, 12.207843381911516, 13.917614836245775, 13.334512375295162, 16.084244325757027, 17.58046343922615, 19.108388051390648, 16.572018451988697, 33.062497079372406, 66.74072831869125, 81.67362302541733, 103.3551076054573, 96.25857040286064, 116.80877968668938, 107.30887144804001, 100.99823847413063, 61.38725258409977, 33.87446030974388, 27.910328842699528, 26.44898045808077, 25.74804536998272, 19.99619521200657, 13.388447631150484, 15.910947974771261, 21.507292427122593, 15.894967932254076, 4.715344626456499, 2.119037755765021, 1.3795303436927497, 1.1272501247003675, 1.6039800248108804, 1.3733874983154237, 0.14831545238848776, 0.6745637312997133, 0.7620065391529351, 2.0932651637122035, 0.6195929122623056, 0.5518699181266129, 0.09422169605386443, 0.2288529768702574, 0.1921916237915866, 0.262646745541133, 0.25877136911731213, 0.22199835249921307, 2.247445215471089, 24.848584234714508, 58.117322847247124, 73.79368185997009, 62.33479633927345, 113.07844385504723, 119.91065204143524, 63.02438713610172, 33.474782556295395, 34.016648679971695, 63.025846257805824, 65.86486771702766, 88.98800253868103, 88.93482819199562, 90.22148475050926, 102.47783347964287, 72.36878111958504, 5.4803798999637365, 0.9120984852779657, 0.2481428941246122, 0.7428615633398294, 0.20370724727399647, 0.27085329580586404, 0.3417462995275855, 0.20200581435346976, 0.4916761309141293, 0.492187975323759, 0.799791949102655, 0.5233489454258233, 0.5560654867440462, 0.3588012687396258, 0.36178532580379397, 0.19101628451608121, 0.13676586822839454, 0.2214292439748533, 0.22068190126447007, 0.13634670322062448, 0.2586609375430271, 0.2056335360975936, 0.15969360043527558, 0.20848868211032823, 0.12193329734145664, 0.12292427229112945, 0.19662528822664171, 0.22378732915967703, 0.20685913361376151, 0.23773266992066056, 0.18295507645234466, 0.18556774797616526, 0.1953760310425423, 0.15314306365326047, 0.1639238718780689, 0.059404268249636516, 0.20370674261357635, 0.22719378699548542, 0.23240425740368664, 0.33857290574815124], [0.10985951201291755, 0.03293370857136324, 0.033533404712216, 0.03857660987705458, 0.035828448162646964, 0.016558628267375752, 0.14632075239205733, 0.03728264200617559, 0.06394809708581306, 0.2604372234782204, 0.1502098882338032, 0.04191476786218118, 0.05429421413282398, 0.0416331116866786, 0.0899268503417261, 0.04591052063915413, 0.0033232869691346423, 0.043272942639305256, 0.0424078396463301, 0.03574657814169768, 0.01824315135309007, 0.14173088071402162, 0.14787810476263985, 0.19551804842194542, 0.1846289460081607, 0.3827180463122204, 0.4953493463108316, 0.4987501341383904, 0.2282025883323513, 0.17712307220790535, 0.17373761715134606, 0.2735224150819704, 0.6317712587770075, 28.793475553393364, 65.8300843834877, 65.94809845089912, 71.58029302954674, 68.89819175004959, 33.67302551865578, 23.672598637640476, 19.19209375977516, 27.517057545483112, 60.636131688952446, 58.92060734331608, 40.7245921343565, 42.76004031300545, 36.10725849866867, 18.224764466285706, 9.160733688622713, 0.6994389183819294, 0.08608125630416907, 0.03422827758186031, 0.03206886161933653, 0.06304229842498899, 0.08277527042082511, 0.117653079360025, 0.04815444495761767, 0.20346503995824605, 0.2828863594913855, 0.4530568141490221, 0.9576022904366255, 0.9623472858220339, 1.9036262459121644, 1.5346528636291623, 3.4020854579284787, 10.710311438888311, 22.374850474298, 33.05680878460407, 42.35606499016285, 44.94805030524731, 45.42127311229706, 44.50679898262024, 50.79227730631828, 45.21202974021435, 43.110985681414604, 45.75410105288029, 49.78199511766434, 30.630572475492954, 29.300349354743958, 20.198961831629276, 27.34853658825159, 32.09108680486679, 39.92422208189964, 76.68151929974556, 84.24913242459297, 79.87631186842918, 66.92026868462563, 69.18236330151558, 69.75719645619392, 71.79869771003723, 70.34864231944084, 51.36530935764313, 46.26145742833614, 59.24000300467014, 61.942467391490936, 53.81216146051884, 52.4698530882597, 52.022354900836945, 46.73688031733036, 41.411899253726006, 31.28621779382229, 24.853009097278118, 24.206941165030003, 20.84444459527731, 10.50892984494567, 4.253989057615399, 3.0910719092935324, 1.266177676152438, 0.1100298497476615, 0.7459104841109365, 0.6548701599240303, 0.4244712449144572, 0.08633199089672416, 0.05413408835011069, 0.11903600476216525, 0.10921362831140868, 0.12608527962584049, 0.11445261203334667, 0.06324349466012791, 0.10330239980248734, 0.16508625325514004, 2.544464352540672, 26.15363370627165, 40.88912710547447, 35.04110790789127, 38.509721383452415, 71.12247079610825, 40.681327655911446, 22.943963035941124, 15.317139588296413, 22.872319780290127, 56.15327663719654, 56.58672697842121, 59.73294295370579, 59.1110797226429, 76.18680104613304, 47.46857665479183, 3.1085158232599497, 0.1601178862620145, 0.18984032183652744, 0.2188547039986588, 0.024120396919897757, 0.21502992720343173, 0.5931367725133896, 0.2828262752154842, 0.3727282042382285, 0.2756387827685103, 0.27354082034435123, 0.2550834888825193, 0.6605096510611475, 0.3380170074524358, 0.12902516406029463, 0.10541581374127418, 0.02343500869756099, 0.04840829657041468, 0.052869149585603736, 0.08620832682936452, 0.01710706241283333, 0.13751950435107574, 0.08725042091100477, 0.08601498251664452, 0.012510407505033072, 0.033238979885936715, 0.04145554172282573, 0.04393252638692502, 0.027835838664032053, 0.046346469316631556, 0.05134939441632014, 0.06324491958366707, 0.06648429771303199, 0.05030363783589564, 0.04695654068200383, 0.07360288174822927, 0.05325351899955422, 0.029830017301719636, 0.2008231871877797, 0.09016582189360633, 0.01619576258235611, 0.03217335601220839, 0.15172872313996777, 0.009663297096267343, 0.1217472854477819, 0.058219626153004356, 0.13414819462923333, 0.08725263251108117, 0.17000504478346556, 0.12218513773404993, 0.09600223449524492, 0.03535348107106984, 0.0672363382182084, 0.018514983348723035, 0.02746241221757373, 0.018470745781087317, 0.04832217404327821, 0.11240202089538798, 0.05401174530561548, 0.034192075618193485, 0.11779629901866429, 0.075853711750824, 0.14301363844424486, 0.10620539207593538, 0.2760745125124231, 0.31973565404769033, 0.30545691086445004, 0.15324832987971604, 0.2661191060906276, 0.07375871791737154, 0.16294560249662027, 2.115710321813822, 48.421367928385735, 86.39600202441216, 77.19757720828056, 84.5620608329773, 77.79378801584244, 50.07600054144859, 44.10393700003624, 27.84418199211359, 32.418294847011566, 39.50782522559166, 52.99733318388462, 50.29709927737713, 54.95752640068531, 43.41375723481178, 22.446208745241165, 9.740959703922272, 1.3631820771843195, 0.05538766854442656, 0.04719054726592731, 0.05767785834905226, 0.09467072508414276, 0.23750025895424187, 0.3343011630931869, 0.15462306939298287, 0.9981100168079138, 1.86482023447752, 1.8877550913020968, 3.5065024299547076, 4.4278112053871155, 5.1487507950514555, 3.5591483674943447, 6.0441461484879255, 11.488699670881033, 24.75558042526245, 33.58234338462353, 42.99433954060078, 45.46755462884903, 46.26281015574932, 49.02424357831478, 50.48177696764469, 48.79620261490345, 47.649918124079704, 47.35738702118397, 52.217501029372215, 35.06573438644409, 35.24664267897606, 26.40715040266514, 31.563500314950943, 34.285985827445984, 43.94718401134014, 86.24879792332649, 99.84871655702591, 97.3187743127346, 79.33183148503304, 83.1120054423809, 79.85476702451706, 86.15200191736221, 83.95670771598816, 61.48883633315563, 52.77732498943806, 64.67030301690102, 68.96879196166992, 61.46151959896088, 59.4875331223011, 56.036691293120384, 50.029559433460236, 46.161788776516914, 35.87238170206547, 27.978595979511738, 29.54294353723526, 22.661130912601948, 12.179560549557209, 5.334266340360045, 3.3962931437417865, 1.198138645850122, 0.7451033242978156, 1.0451349872164428, 1.3181229075416923, 0.7234964368399233, 0.6668714003171772, 0.22900434531038627, 1.5097554121166468, 0.28427037585061044, 0.2784845628775656, 0.40136747527867556, 0.03044139113626443, 0.1179731082811486, 0.040893387122196145, 2.374591617844999, 26.47281087934971, 42.869835421442986, 48.37121441960335, 47.196822836995125, 47.65026770532131, 38.9285197108984, 29.78066638112068, 29.8767252266407, 40.64835302531719, 73.67876082658768, 69.26709115505219, 75.05431741476059, 68.30416962504387, 88.55919554829597, 69.7481681406498, 7.407644558697939, 0.45637014729436487, 0.1455673240707256, 0.10767365703941323, 0.044839197071269155, 0.18751722149318084, 0.22490743780508637, 0.09782034045201726, 0.3033892280654982, 0.13720029179239646, 0.18264790152898058, 0.3168264648411423, 0.5383343319408596, 0.2083280516671948, 0.0798438093625009, 0.03981749563536141, 0.02920288396126125, 0.030083722340350505, 0.08454575276118703, 0.03001221270096721, 0.04135133305680938, 0.09137249464401975, 0.06748354760929942, 0.045239322280394845, 0.020800037491426338, 0.029781759149045683, 0.017641024678596295, 0.04289268843422178, 0.012875600750703597, 0.05304300138959661, 0.007291068895938224, 0.023221210794872604, 0.0662854837719351, 0.021435067283164244, 0.09036260235006921, 0.02718746691243723, 0.024191357370000333, 0.04790340979525354, 0.10329184646252543, 0.26667464815545827, 0.05065725636086427, 0.1294368927483447, 0.27945986366830766, 0.1459214324131608, 0.32565923931542784, 0.16016305336961523, 0.1612588789430447, 0.2509752562036738, 0.452927413280122, 0.45016825664788485, 0.28448476747144014, 0.14995978446677327, 0.18718438310315832, 0.1764261955395341, 0.11062124496675096, 0.10685683446354233, 0.2279501096927561, 0.23126872692955658, 0.20322967524407431, 0.16515215596882626, 0.22567211708519608, 0.23959237325470895, 0.28750729747116566, 0.3665552573511377, 0.6144902016967535, 0.8898360142484307, 0.8415912499185652, 0.46574519423302263, 0.6522802426479757, 0.3758992825169116, 0.3584947914350778, 2.9104792373254895, 71.07249587774277, 100.60596272349358, 84.87572640180588, 94.22356680035591, 88.53678435087204, 51.99502296745777, 40.90168923139572, 30.798648856580257, 41.62881061434746, 82.09992974996567, 80.25829777121544, 60.17522782087326, 63.35892118513584, 55.470035299658775, 31.838404163718224, 14.810375981032848, 2.590237408876419, 0.13930439919931814, 0.1849320688052103, 0.2965369785670191, 0.23272817517863587, 0.30994426226243377, 0.30419523012824357, 0.15634926036000252, 0.6913639360573143, 1.6231767134740949, 1.692323146853596, 2.1511778561398387, 6.275009410455823, 7.0888502150774, 2.7989910822361708, 6.255775792524219, 13.542378321290016, 29.057240299880505, 41.290260180830956, 49.38146620988846, 49.48260918259621, 50.60957171022892, 51.79500550031662, 55.538439229130745, 48.22078429162502, 52.049865424633026, 48.86898770928383, 52.72658631205559, 38.55817638337612, 36.22181475162506, 26.777182146906853, 35.379255563020706, 40.362562760710716, 51.0825589299202, 91.6474874317646, 99.54141184687614, 96.66919156908989, 81.27652153372765, 86.25339567661285, 85.89809954166412, 88.12616318464279, 86.5774042904377, 65.40997132658958, 62.34060622751713, 68.95329639315605, 74.72706377506256, 69.24027219414711, 61.248381435871124, 57.8583325445652, 49.274642542004585, 46.03110618889332, 33.970180973410606, 26.962786987423897, 29.19955786317587, 24.56901613622904, 13.064432367682457, 6.665410436689854, 7.6920312736183405, 3.0396326445043087, 1.551194207277149, 2.328450931236148, 1.4635579660534859, 0.9583123179618269, 0.3474728891160339, 0.1524102670373395, 0.9839516202919185, 0.320491754100658, 0.21154653833946213, 0.3785218542907387, 0.21629849507007748, 0.18173422868130729, 0.2761721791466698, 5.169061655178666, 39.176065027713776, 57.59143866598606, 53.43057833611965, 51.821763664484024, 95.81356108188629, 58.531128242611885, 36.27713218331337, 25.493787713348866, 38.67144450545311, 75.45989245176315, 75.94099223613739, 87.52948120236397, 78.93527716398239, 99.58146929740906, 80.22543713450432, 8.339997678995132, 0.6310297048185021, 0.3047761833295226, 0.5834127974230796, 0.2884873776929453, 0.4821681504836306, 0.8463773899711668, 0.40084544860292226, 0.7175050489604473, 0.6117115414235741, 0.560137799475342, 0.5445842840708792, 0.969894512090832, 0.4931000154465437, 0.2220825565746054, 0.2088524680584669, 0.1140759424015414, 0.19698720396263525, 0.27103470638394356, 0.2529333980055526, 0.12740829144604504, 0.32023042906075716, 0.23410217254422605, 0.1904436433687806, 0.1183215317723807, 0.16845980426296592, 0.16042572911828756, 0.14443914085859433, 0.146962383587379, 0.1685337073286064, 0.10246070043649524, 0.1931500481441617, 0.22130673023639247, 0.12378239538520575, 0.25563965435139835, 0.19750462932279333, 0.2715633233310655, 0.1398072042502463, 0.28286807297263294], [0.06191869426402263, 0.008883346272341441, 0.03842386846372392, 0.054693608326488174, 0.08460721743176691, 0.06476005859440193, 0.05508065689355135, 0.02595728848973522, 0.04770468862261623, 0.041014145681401715, 0.07952160594868474, 0.0464329295209609, 0.03661669805296697, 0.06399681908078492, 0.04263154150976334, 0.03513624702463858, 0.035316388530191034, 0.04713385831564665, 0.06207932470715605, 0.13899790705181658, 0.10869520105188712, 0.031794560127309524, 0.036952041191398166, 0.17860944557469338, 0.07075514979078434, 0.13737719011260197, 0.24582359357737005, 0.3482274751877412, 0.2957012312253937, 0.40873875317629427, 0.20541006058920175, 0.6465122709050775, 52.74770937860012, 81.57506391406059, 72.91218996047974, 66.65612205862999, 74.5126260817051, 38.38480308651924, 21.89590897411108, 16.5115237981081, 23.213758058845997, 44.453328251838684, 61.50070309638977, 52.9550376534462, 37.71639995276928, 35.561356991529465, 11.140322014689445, 3.912432985380292, 0.019289180672785733, 0.08532471096259542, 0.06948451875359751, 0.05027640101616271, 0.020394212588144, 0.13975436333566904, 0.08947178022935987, 0.11507567469379865, 0.6449640914797783, 0.17697235685773194, 1.3302294141612947, 2.0971986651420593, 4.005740778520703, 4.252040237188339, 4.488953724503517, 9.09743383526802, 19.354478046298027, 29.11622453480959, 51.97300314903259, 64.71936598420143, 66.24879151582718, 70.85930451750755, 66.67891323566437, 70.54307028651237, 69.13553461432457, 67.87173002958298, 77.17534840106964, 72.7512837946415, 72.99109652638435, 73.9053426682949, 70.97110971808434, 61.53466187417507, 56.49901248514652, 59.89713974297047, 59.528156742453575, 59.936653822660446, 48.208309561014175, 54.18225780129433, 55.23853652179241, 63.065010756254196, 65.80159351229668, 65.08022502064705, 43.530707359313965, 27.334106862545013, 56.31092257797718, 70.59872969985008, 73.2069705426693, 73.03911074995995, 73.99730533361435, 73.66499796509743, 81.617431640625, 84.39936116337776, 85.5288277566433, 82.046709805727, 68.0404181778431, 63.234979435801506, 60.340081974864006, 43.906754180788994, 28.439592942595482, 15.67976363003254, 4.950086055323482, 0.7139945717062801, 0.4165990767069161, 0.33380606153514236, 0.12685133930062875, 0.061876339896116406, 0.09166918302071281, 0.20098973996937275, 0.06861158239189535, 0.12118466329411604, 0.0777220685267821, 0.10894455524976365, 0.019507706056174356, 0.03554378628905397, 0.8521628763992339, 11.17068238556385, 30.557270608842373, 52.534757405519485, 45.89230343699455, 41.51525370776653, 39.63465861976147, 34.467711076140404, 28.777619004249573, 10.152565017342567, 31.784980930387974, 47.49986797571182, 57.23112680017948, 57.90054067969322, 66.78134053945541, 56.12588010728359, 6.822199998423457, 0.35438249178696424, 0.12064387512509711, 0.15655067923944443, 0.08459138742182404, 0.14077674597501755, 0.04758355898957234, 0.041188405666616745, 0.058300668679294176, 0.08787149461568333, 0.2866948238806799, 0.19114614551654086, 0.14794669405091554, 0.1319803812657483, 0.014069709868635982, 0.030588622103095986, 0.04465497375349514, 0.10994795375154354, 0.009852385192061774, 0.04190429244772531, 0.028255669749341905, 0.08177374213119037, 0.050487297121435404, 0.048190988309215754, 0.062003377024666406, 0.04537293854809832, 0.039073470325092785, 0.0981687565217726, 0.08970593524281867, 0.016763974963396322, 0.12294589105295017, 0.04402102007588837, 0.06754938352969475, 0.04045329726068303, 0.032881843580980785, 0.02789965037663933, 0.05552653550694231, 0.058251735172234476, 0.004450678634384531, 0.026636956608854234, 0.07562234721262939, 0.030536211634171195, 0.04442295612534508, 0.0477090561616933, 0.053571648022625595, 0.004206359444651753, 0.045006859363638796, 0.057538379114703275, 0.051056702504865825, 0.01428978355761501, 0.0006872316475892148, 0.13058373355306685, 0.02908179143560119, 0.026166139978158753, 0.031528073450317606, 0.02304457037098473, 0.0438484299229458, 0.11039411809179, 0.04177765978965908, 0.07406555887428112, 0.0332681091822451, 0.10213057088549249, 0.02773254098428879, 0.18524378567235544, 0.2567911706864834, 0.3310428379336372, 0.19143210985930637, 0.35072702856268734, 0.26173449761699885, 0.9093624539673328, 68.98670420050621, 94.44234386086464, 79.71350580453873, 76.70387730002403, 81.71130180358887, 57.47080273926258, 37.57442817091942, 20.328152999281883, 18.993981890380383, 30.857576094567776, 57.956222891807556, 60.66280245780945, 41.46005406975746, 34.31691236793995, 15.140119437128305, 4.9138896726071835, 0.08819573893561028, 0.03535576688591391, 0.1477980418712832, 0.23349232011241838, 0.10235002395347692, 0.2637349715223536, 0.7780445879325271, 0.39388748758938164, 1.1608406784944236, 1.1562980222515762, 3.163125067949295, 2.0456620305776596, 1.9485965953208506, 1.8520390265621245, 3.0916570778936148, 8.211480025202036, 17.79753439128399, 27.561906538903713, 51.61704584956169, 64.27903041243553, 69.5320737361908, 73.34651425480843, 70.94460234045982, 74.3351224064827, 73.19655910134315, 70.75389817357063, 79.65058118104935, 72.84190893173218, 76.52358457446098, 77.21993520855904, 73.67682293057442, 63.592547848820686, 60.465201660990715, 63.30052211880684, 66.01815149188042, 67.75164887309074, 59.672811180353165, 61.64975009858608, 60.987130254507065, 69.08023998141289, 72.04766795039177, 74.22860652208328, 52.37937234342098, 35.702599212527275, 61.97804868221283, 73.71244221925735, 79.17270362377167, 76.12179413437843, 73.85850638151169, 75.41722074151039, 86.19775906205177, 86.2553259730339, 87.93162122368813, 85.09394869208336, 71.97778210043907, 68.21768626570702, 63.133730068802834, 46.360415518283844, 30.889021307229996, 16.002206727862358, 5.663972273468971, 0.7240584504324943, 0.3281429404160008, 0.8891350112389773, 2.2020255401730537, 1.7169005842879415, 1.6469965665601194, 0.8788532379548997, 0.06325306836515665, 0.5371554451994598, 0.10965845678583719, 0.1995054297731258, 0.026654708781279624, 0.08815327324555255, 1.0013747541233897, 11.570645123720169, 31.54170088469982, 40.563674569129944, 42.77161829173565, 34.26675125956535, 37.018597796559334, 36.42460606992245, 39.19592276215553, 26.963837631046772, 47.72600144147873, 62.33147531747818, 63.5410226136446, 69.66562896966934, 75.5702917277813, 77.82567590475082, 15.004263427108526, 0.4260868113487959, 0.11125609293230809, 0.15262934903148562, 0.09821139290579595, 0.14568483573384583, 0.09440178560907952, 0.06037011778971646, 0.07519019462051801, 0.0594892144727055, 0.15999080089386553, 0.1487381648621522, 0.04975145398930181, 0.12593153631314635, 0.04247553464665543, 0.05433453872683458, 0.03408182215935085, 0.0502221574424766, 0.05433654623629991, 0.03990148448792752, 0.05088183766929433, 0.03850998356938362, 0.09219121711794287, 0.034231680328957736, 0.028532409196486697, 0.056756708363536745, 0.011548643487913068, 0.05209733826632146, 0.06333791810902767, 0.02769309769064421, 0.035429825802566484, 0.041123738628812134, 0.03131905868940521, 0.06292239704634994, 0.06091497663874179, 0.051877402802347206, 0.025270848273066804, 0.07998161876457743, 0.1763618810218759, 0.17196801054524258, 0.1902642662753351, 0.14413782890187576, 0.19403786456678063, 0.18292141263373196, 0.16952784382738173, 0.07365315483184531, 0.123536098835757, 0.163137017225381, 0.25163725193124264, 0.20568507083225995, 0.10372968390583992, 0.12737170356558636, 0.1889854419277981, 0.14643032307503745, 0.20667468023020774, 0.17112490109866485, 0.18795213487464935, 0.34896430908702314, 0.15625923784682527, 0.15528015210293233, 0.11408784645027481, 0.25491044973023236, 0.1882004426443018, 0.5456543422769755, 0.47812602831982076, 0.5036729481071234, 0.5124920967500657, 0.5561440950259566, 0.47586051863618195, 2.4585901480168104, 90.02543047070503, 103.404071778059, 92.56007686257362, 87.60093256831169, 97.32339486479759, 55.99799416959286, 38.768468499183655, 30.207647569477558, 39.51076626777649, 62.820368483662605, 80.51068022847176, 75.1159805059433, 58.29835273325443, 55.59263192117214, 22.52045676112175, 7.687130011618137, 0.37039435759652406, 0.19842474401229993, 0.26323265628889203, 0.26950796018354595, 0.16686768969520926, 0.3376388980541378, 0.5564129899721593, 0.3240707761142403, 1.6731772804632783, 2.301386883482337, 5.171354357153177, 10.021591745316982, 11.775188148021698, 12.420328930020332, 13.933458086103201, 17.752681598067284, 26.022086665034294, 34.66129168868065, 62.02742703258991, 71.69025152921677, 72.80167669057846, 77.52034708857536, 73.63233491778374, 74.90350350737572, 76.0835149884224, 73.67746889591217, 82.47230976819992, 79.49364200234413, 82.6401999592781, 82.76652038097382, 76.17576643824577, 72.0169959962368, 67.65109866857529, 70.79731464385986, 73.14109727740288, 75.25554701685905, 65.20089894533157, 68.26414257287979, 67.82006800174713, 74.957255423069, 80.09388819336891, 83.4120525419712, 56.712887808680534, 41.662587001919746, 69.67026472091675, 79.24929231405258, 83.67827385663986, 77.44913890957832, 72.4981489777565, 77.91957646608353, 91.92893072962761, 91.66428253054619, 92.00851365923882, 89.13762331008911, 73.85772362351418, 72.26249322295189, 64.80917036533356, 50.285392105579376, 35.199141427874565, 23.39921660721302, 9.256492350250483, 3.2246637158095837, 1.6726410342380404, 1.1601910321041942, 1.3880776287987828, 1.302066275384277, 1.1780364182777703, 0.5459283431991935, 0.2163445675978437, 0.3394700732314959, 0.1950581988785416, 0.2151575914467685, 0.1496895684977062, 0.3939999081194401, 1.4340365189127624, 18.772159293293953, 48.70602585375309, 79.75849539041519, 65.11400520801544, 58.29491391777992, 55.24591572582722, 50.087285935878754, 42.477365881204605, 20.892700105905533, 47.84499205648899, 64.52498361468315, 78.25350254774094, 79.11949887871742, 86.9571103155613, 90.01857563853264, 17.593536637723446, 0.8390179567504674, 0.3160503861727193, 0.5583297496195883, 0.2173220948316157, 0.509978294139728, 0.2792243950534612, 0.24476656748447567, 0.2942907647229731, 0.3672870446462184, 0.4104137804824859, 0.2953702036757022, 0.32298934820573777, 0.32911230402532965, 0.08987243607407436, 0.09438548804610036, 0.1515096114599146, 0.28686593344900757, 0.31612427439540625, 0.17150943749584258, 0.1569179235957563, 0.18574494315544143, 0.2099758866825141, 0.11470273064333014, 0.07784523535519838, 0.25623230380006135, 0.14162055304041132, 0.22266045212745667, 0.21161337615922093, 0.08867735567037016, 0.19293234654469416, 0.08378430182347074, 0.1946267587481998, 0.17672517715254799, 0.15277250931831077, 0.0869750915444456, 0.26290753623470664, 0.3326265513896942], [0.04395535484945867, 0.009889408156595891, 0.036397337753442116, 0.06554044914082624, 0.03451349235547241, 0.04712593217846006, 0.007675440165257896, 0.042902080313069746, 0.028567475674208254, 0.028184069196868222, 0.020214724172546994, 0.07796578982379287, 0.07537104858784005, 0.053429463659995236, 0.046954087883932516, 0.05532317220058758, 0.029863287782063708, 0.06585625524166971, 0.04745799502416048, 0.029402534673863556, 0.027042983747378457, 0.11037039163056761, 0.023570016492158175, 0.0434609212243231, 0.12238461218657903, 0.07007673775660805, 0.18722126784268767, 0.2732106240000576, 0.22898654860910028, 0.08347343100467697, 1.2089751893654466, 51.03274740278721, 85.643649995327, 83.2422624528408, 77.67809182405472, 68.96984830498695, 47.815300449728966, 23.124962523579597, 28.329533748328686, 57.92604871094227, 66.73040047287941, 79.68650445342064, 56.30997262895107, 42.76219479739666, 34.29498754441738, 9.619282633066177, 0.568036031909287, 0.04594107856974006, 0.08624102585599758, 0.19655422016512603, 0.13179264758946374, 0.0752787254168652, 0.1115186647803057, 0.3924529458163306, 0.09587871143594384, 0.45619595039170235, 0.9351964364759624, 1.1068819114007056, 2.541019362397492, 1.1436284333467484, 6.812200834974647, 7.06862960010767, 16.892928332090378, 29.635362178087234, 41.28855027258396, 52.28206716477871, 70.16716405749321, 74.97186183929443, 81.14196315407753, 76.71283721923828, 77.00404599308968, 77.91803374886513, 76.49165108799934, 76.1710698902607, 72.77093634009361, 74.39594194293022, 75.82110106945038, 80.87068051099777, 75.56242614984512, 74.30521041154861, 74.71349090337753, 79.67795491218567, 55.5980010330677, 35.696929916739464, 54.84225578606129, 53.940659165382385, 57.28999704122543, 59.7379244863987, 67.25690022110939, 57.907463908195496, 31.0432493314147, 36.37194089591503, 60.42757987976074, 75.64147710800171, 69.10012811422348, 73.67256715893745, 76.28816440701485, 81.60960406064987, 78.38345557451248, 71.88704296946526, 73.36850747466087, 75.55408179759979, 82.46289387345314, 77.85731300711632, 81.24091744422913, 79.36038315296173, 72.44337871670723, 57.21465848386288, 36.914008408784866, 14.8844663053751, 6.160443183034658, 0.6940973550081253, 2.8979862201958895, 2.184911733493209, 2.3262420622631907, 0.3293432603823021, 1.140275588259101, 0.2824906463501975, 0.19454970897641033, 0.07737456529866904, 0.04491907813644502, 0.041042859375011176, 0.09916497103404254, 0.24896793969674036, 4.517959943041205, 23.380278423428535, 47.39830702543259, 60.22811718285084, 53.32452602684498, 40.447446405887604, 35.0684018433094, 25.43568693101406, 18.333172649145126, 25.614892914891243, 51.40974797308445, 56.146266013383865, 62.59610831737518, 70.69724321365356, 76.90863311290741, 12.765542306005955, 0.31852215353865176, 0.04595528698700946, 0.12164406754891388, 0.059479492338141426, 0.04753831024572719, 0.06872602156363428, 0.09718857239931822, 0.07150994366384111, 0.10772391528007574, 0.05426662850368302, 0.07845598578569479, 0.027038939042540733, 0.03340240080433432, 0.05994429942802526, 0.020528209206531756, 0.04026708869787399, 0.017802174625103362, 0.055598575781914406, 0.07533126205089502, 0.04980397949111648, 0.09849094509263523, 0.06386062013916671, 0.057573757294449024, 0.03202300060365815, 0.13449213554849848, 0.06894024249049835, 0.1372832787455991, 0.10612442376441322, 0.05609476829704363, 0.0999016193964053, 0.06421242782380432, 0.033275449022767134, 0.053472990621230565, 0.03657655528513715, 0.08473255875287578, 0.05550243797188159, 0.032772102204035036, 0.03472740158031229, 0.03540240344591439, 0.03629734077549074, 0.05204625253099948, 0.022802728562965058, 0.05508485744940117, 0.027330469492881093, 0.04502103809500113, 0.03935460699722171, 0.013900422272854485, 0.040891550306696445, 0.0713407711009495, 0.042749361164169386, 0.046600484201917425, 0.028784449968952686, 0.017880111263366416, 0.07138183413189836, 0.04067969312018249, 0.06837664812337607, 0.044344329289742745, 0.040963583160191774, 0.0825041564530693, 0.1223129132995382, 0.016989704745355994, 0.024367066398554016, 0.12089388241292909, 0.3018540807534009, 0.13721629249630496, 0.04237580855260603, 2.606652765534818, 63.67833964526653, 101.9023771584034, 91.47018894553185, 94.37950283288956, 80.47230988740921, 79.52406316995621, 42.070491313934326, 38.582677468657494, 48.14490236341953, 60.3458234667778, 89.16311234235764, 59.223584085702896, 42.914289236068726, 32.50776864588261, 11.076529137790203, 0.8926663279999048, 0.08494876863551326, 0.08448684850009158, 0.36495408858172596, 0.27046458853874356, 0.29468030319549143, 0.41754558216780424, 1.7249467712827027, 1.3597218878567219, 1.483161470387131, 0.3016237774863839, 0.7492360181640834, 0.28721489128656685, 1.5644540707580745, 3.092325604520738, 5.627024481073022, 10.76479671522975, 25.567621551454067, 39.61810290813446, 55.5830792337656, 68.25006052851677, 75.55463656783104, 83.85963812470436, 79.96303081512451, 77.81213343143463, 80.01693472266197, 75.44174462556839, 77.88134291768074, 74.4199338555336, 78.67860093712807, 77.30999797582626, 83.47815379500389, 74.79607567191124, 76.78853675723076, 76.06168136000633, 81.6958898305893, 59.51833426952362, 45.65423101186752, 62.12629772722721, 61.85869708657265, 64.1856238245964, 67.10451319813728, 75.2789157629013, 70.41529074311256, 39.541761204600334, 42.11388498544693, 64.94205683469772, 77.12320759892464, 72.07027673721313, 72.37297609448433, 77.586410343647, 85.77540412545204, 83.19992512464523, 76.56095936894417, 76.58982262015343, 78.34871783852577, 84.39611613750458, 81.95548430085182, 84.72309619188309, 84.4760562479496, 77.57657647132874, 63.862048387527466, 40.23464262485504, 17.83071231096983, 6.746308095753193, 1.3325196225196123, 3.169280500151217, 4.616741817444563, 5.1190653629601, 2.34230047557503, 2.8368608001619577, 0.9795282420236617, 0.6478486710693687, 0.14537441020365804, 0.16564330930123106, 0.08124554078676738, 0.027567941906454507, 0.1907767786178738, 5.18161665648222, 24.19759176671505, 41.85382694005966, 49.01855148375034, 34.55524317920208, 24.07857835292816, 25.21763753145933, 22.66206756234169, 37.43654876947403, 43.763490468263626, 66.79099962115288, 64.12719815969467, 73.52118328213692, 80.91840595006943, 98.26772779226303, 24.722451902925968, 0.2652563445735723, 0.09017391872475855, 0.13149235979653895, 0.08667658490594476, 0.04414728166011628, 0.030930985958548263, 0.11015480515197851, 0.09151488309726119, 0.052031532031833194, 0.052555239672074094, 0.015591596857120749, 0.06051486256183125, 0.03584043384762481, 0.0632167402363848, 0.025781982076296117, 0.07536232093116269, 0.03593327281123493, 0.04018516672658734, 0.03727843031811062, 0.018910471990238875, 0.009593315353413345, 0.06744328609784134, 0.029144321088097058, 0.12449555477360263, 0.07447618176229298, 0.14297532878117636, 0.13472671358613297, 0.04738495284982491, 0.02812183269270463, 0.08272075225249864, 0.02119792698067613, 0.03533570663421415, 0.055777630041120574, 0.017844532703747973, 0.063582448347006, 0.05206581554375589, 0.1634760302840732, 0.1006177844828926, 0.12620757071999833, 0.13260054955026135, 0.12161740218289196, 0.14056064741453156, 0.1696516340598464, 0.14144343207590282, 0.18846676975954324, 0.25876718340441585, 0.20300763950217515, 0.21706594998249784, 0.17332667513983324, 0.07236990728415549, 0.11122386888018809, 0.25021633598953485, 0.12259250259376131, 0.18177390389610082, 0.19469521444989368, 0.1584852355881594, 0.29218734009191394, 0.17089032306103036, 0.2159218254382722, 0.19606529327575117, 0.23843420727644116, 0.1171559517388232, 0.2530179137829691, 0.5003899242728949, 0.402411469258368, 0.16808283777209, 4.596927305683494, 87.65609800815582, 109.77726459503174, 105.49660429358482, 103.59110534191132, 86.3730588555336, 68.48532870411873, 38.927349373698235, 41.14096999168396, 80.59214025735855, 84.42016884684563, 97.47218728065491, 73.87821212410927, 59.72512297332287, 51.568590849637985, 15.805709771811962, 1.6040985309518874, 0.27599949622526765, 0.18055203196126968, 0.5121621082071215, 0.356816528365016, 0.39659353613387793, 0.38396111398469657, 1.3858001260086894, 1.6667775926180184, 2.6744644017890096, 4.31443146429956, 6.025868179276586, 10.387633703649044, 9.717006739228964, 16.46446142345667, 15.1555285602808, 28.07639893144369, 41.46679110825062, 51.33838400244713, 62.57582500576973, 78.94544541835785, 80.40079772472382, 91.23858377337456, 83.19873958826065, 80.54577514529228, 81.12654358148575, 77.87755832076073, 78.96262049674988, 77.59973242878914, 78.58688145875931, 84.40002232789993, 85.18263593316078, 79.10497605800629, 77.61044785380363, 81.12539604306221, 84.64483559131622, 65.65258830785751, 52.96649783849716, 68.99060279130936, 68.61635327339172, 70.22406220436096, 74.23098519444466, 83.32073584198952, 78.16189706325531, 46.31373502314091, 49.62999947369099, 69.24281805753708, 78.24490740895271, 73.86514842510223, 72.33603447675705, 80.40389835834503, 87.95699626207352, 87.88896471261978, 78.34598198533058, 78.77331465482712, 81.9667848944664, 88.35325419902802, 84.8603904247284, 88.9562514424324, 84.88081812858582, 79.50295150279999, 64.0614540874958, 41.685807555913925, 19.00615643709898, 10.050662085413933, 6.189735811203718, 9.230364002287388, 9.080270156264305, 6.724155284464359, 1.6187671688385308, 2.250861944630742, 0.5940900463610888, 0.4743262619012967, 0.11784955553594045, 0.2392367212451063, 0.1829148075194098, 0.27044380840379745, 0.5205588263925165, 8.182403035461903, 37.498363852500916, 64.36382666230202, 84.89716485142708, 75.58261066675186, 59.16323572397232, 51.122046411037445, 40.14198459684849, 29.307403676211834, 41.72907963395119, 66.7039842903614, 73.80868345499039, 86.44274711608887, 89.57695573568344, 109.9960644543171, 26.500353701412678, 0.6832872913219035, 0.17893564916448668, 0.24249660491477698, 0.28378130053170025, 0.19791508151683956, 0.22484491928480566, 0.2306977630360052, 0.22067024954594672, 0.26100383838638663, 0.19104758830508217, 0.18939766043331474, 0.11862516665132716, 0.10439030666020699, 0.15704958059359342, 0.14600991125917062, 0.15904086671071127, 0.13204684801166877, 0.26021668687462807, 0.15570610034046695, 0.21295799931976944, 0.1568205835064873, 0.19285054702777416, 0.11227817129110917, 0.19079285353654996, 0.3279164666309953, 0.29788765765260905, 0.4094895691378042, 0.17348850786220282, 0.16990201984299347, 0.3044390701688826, 0.17225364834303036, 0.12221742857946083, 0.15133531065657735, 0.09919029311276972, 0.23316424631047994, 0.18005188379902393], [0.027413977804826573, 0.04185337740636896, 0.03882145552779548, 0.03060459126572823, 0.022396552994905505, 0.028109993581892923, 0.019741879623325076, 0.057962223363574594, 0.0674399538547732, 0.01721413205814315, 0.06523403120809235, 0.04420676108566113, 0.030539812905772123, 0.031529943662462756, 0.04714843780675437, 0.04140468234254513, 0.015972910478012636, 0.03965571115259081, 0.04218882444547489, 0.011884748255397426, 0.021060238177597057, 0.024412300299445633, 0.029692489915760234, 0.027366033209546003, 0.028857301040261518, 0.08896383951650932, 0.13159244583221152, 0.13074044545646757, 0.20032452332088724, 0.10391678675659932, 43.93755532801151, 85.47306194901466, 78.99339884519577, 79.5202861726284, 69.52203467488289, 41.96310147643089, 10.717612747102976, 23.855650015175343, 40.24288058280945, 47.3396647721529, 47.883970364928246, 32.752049937844276, 41.54147610068321, 24.051202721893787, 3.6203165352344513, 0.10480477387318388, 0.03440336135099642, 0.10063677604193799, 0.09010869136545807, 0.13640349236084148, 0.3302114544203505, 0.20435594371519983, 0.5953065154608339, 1.798125619534403, 2.712901714257896, 1.4686780725605786, 0.22424495226005092, 0.6490619934629649, 7.504066759720445, 20.877789705991745, 27.927165739238262, 37.44972266256809, 43.23979116976261, 46.397588923573494, 58.637545332312584, 65.62759324908257, 73.4255500137806, 75.4522168636322, 76.54574498534203, 75.98082169890404, 77.28433415293694, 73.72827216982841, 78.33341225981712, 67.08492904901505, 72.5604884326458, 79.03710409998894, 81.78887084126472, 78.06420430541039, 73.22306647896767, 77.88844093680382, 82.37991392612457, 79.11585107445717, 80.39002150297165, 56.90661661326885, 33.53420376777649, 60.080871284008026, 59.70313735306263, 67.64479860663414, 68.81772726774216, 45.69124102592468, 38.16140927374363, 62.92640179395676, 79.02024820446968, 75.83899810910225, 72.47981116175652, 74.78072449564934, 78.90063062310219, 78.62611055374146, 78.58281567692757, 74.40794169902802, 72.58301362395287, 75.12734189629555, 73.43548268079758, 77.56732776761055, 78.9676970243454, 81.6580818593502, 85.73725417256355, 83.2296547293663, 72.52318203449249, 54.45793680846691, 31.016671657562256, 13.994869440793991, 6.297640521079302, 3.365498408675194, 3.3060942962765694, 3.486986202187836, 1.3049066229723394, 2.2551580891013145, 0.5494356737472117, 0.4719682806171477, 0.019901784617104568, 0.0435614228626946, 0.06283960305154324, 0.046026740965317, 0.035624557931441814, 1.0877082590013742, 9.663433413952589, 27.50007625669241, 53.145122453570366, 53.86021368205547, 57.31099471449852, 43.87411393225193, 27.24301055073738, 13.262510038912296, 13.075631316751242, 42.270489782094955, 64.96088102459908, 67.18009114265442, 65.12852042913437, 74.83209773898125, 14.77254331111908, 0.6202742632012814, 0.08284570023533888, 0.07171332181314938, 0.0847501699172426, 0.07621945696882904, 0.07646006866707467, 0.04550994643068407, 0.010406270412204321, 0.02767259215033846, 0.011644495571090374, 0.029859408205084037, 0.006963066061871359, 0.03385846168384887, 0.0442374859994743, 0.0026068340685014846, 0.04529479039774742, 0.05235044773144182, 0.01679628992860671, 0.028473803649831098, 0.0062061575317784445, 0.02868639370717574, 0.06317500185105018, 0.057910903851734474, 0.02100479232467478, 0.11696156099787913, 0.015333332248701481, 0.08279644389403984, 0.041054047251236625, 0.01888854709250154, 0.04396646108943969, 0.037377607222879305, 0.030178398119460326, 0.02413503021671204, 0.056218551108031534, 0.10023216455010697, 0.044029343262081966, 0.0026307511689083185, 0.029771558329230174, 0.04622845670382958, 0.037690941971959546, 0.02448576549795689, 0.02378685534495162, 0.061540180395240895, 0.0652616168372333, 0.08490971682476811, 0.028665249919868074, 0.012514061654655961, 0.05675043721566908, 0.04823859337193426, 0.007540910592069849, 0.008525440916855587, 0.06566302225110121, 0.031225091661326587, 0.009917394545482239, 0.06357907157507725, 0.05941948969848454, 0.010467681277077645, 0.04641362254915293, 0.015779712739458773, 0.09995869055273943, 0.04363444648333825, 0.13036079239100218, 0.0752413211739622, 0.17817622428992763, 1.2349167536012828, 56.821706369519234, 100.11593341827393, 86.80648639798164, 93.33257541060448, 75.40320709347725, 60.85138253867626, 25.476663932204247, 28.460552617907524, 31.61217950284481, 53.42278115451336, 57.161472737789154, 39.41023886203766, 45.279616713523865, 25.054050609469414, 4.085784908384085, 0.008183630889107008, 0.10362707456806675, 0.05462046596221626, 0.33678418141789734, 0.6286714563611895, 0.6272549636196345, 1.2385836755856872, 3.2963010342791677, 7.80208476819098, 4.418428558856249, 0.604563175002113, 0.2653549611568451, 0.7377589715179056, 7.014069752767682, 20.858986414968967, 28.869321383535862, 38.72506342828274, 44.700816571712494, 47.223843187093735, 61.31938822567463, 69.16844084858894, 76.10566779971123, 78.25936183333397, 79.53586533665657, 77.28994265198708, 79.2261591553688, 75.2080799639225, 77.40122348070145, 69.63227435946465, 75.77801138162613, 80.92250972986221, 83.66989150643349, 81.82159468531609, 75.8436718583107, 76.95889681577682, 84.09597024321556, 83.64342212677002, 83.74587222933769, 61.06119208037853, 43.9781029522419, 65.06358191370964, 65.23682221770287, 73.24282541871071, 77.4682442843914, 52.794002294540405, 44.50711436569691, 66.03351786732674, 81.47555485367775, 76.45143404603004, 73.8059476017952, 75.49873396754265, 80.06057158112526, 83.87089312076569, 82.71849855780602, 76.70947059988976, 75.4856550693512, 80.35934194922447, 76.79100662469864, 80.13590633869171, 82.66916200518608, 85.61829015612602, 87.76919513940811, 87.51007944345474, 78.25643599033356, 59.52378697693348, 35.106658190488815, 17.137183025479317, 6.51124938391149, 1.8969755340367556, 2.6470690593123436, 1.8148537469096482, 3.244660380296409, 3.89414694160223, 1.9287951453588903, 0.7763299299404025, 0.3504976158728823, 0.149990078934934, 0.10066278831800446, 0.09725162526592612, 0.11644297788734548, 0.9830647241324186, 10.263591259717941, 29.483558423817158, 51.894594356417656, 45.3862351924181, 41.4235570281744, 30.57105626910925, 21.153559908270836, 16.65590275079012, 25.932331681251526, 57.25248545408249, 74.11819204688072, 79.6380266547203, 71.57007917761803, 92.50613495707512, 30.1370245590806, 0.18480623024515808, 0.06085690729378257, 0.0218801722076023, 0.03799694430199452, 0.03328567210701294, 0.03169878968037665, 0.011927656451007351, 0.05076407367596403, 0.0411819972214289, 0.009755987630342133, 0.05062469092081301, 0.023348502109001856, 0.03544866522133816, 0.09088783510378562, 0.056945840988191776, 0.052678477004519664, 0.05426712945336476, 0.08880530935130082, 0.07953018517582677, 0.04320942593039945, 0.05350670267944224, 0.010930068037851015, 0.04912537449854426, 0.03478150043520145, 0.020729273710458074, 0.013947961469966685, 0.05232612384133972, 0.043080826580990106, 0.006242684648896102, 0.05448305731988512, 0.016575135487073567, 0.024487637565471232, 0.04755884176120162, 0.051818613574141636, 0.09087924103369005, 0.17705620470223948, 0.17081947764381766, 0.08536675362847745, 0.11855914519401267, 0.12396270016324706, 0.1006106598651968, 0.10877622873522341, 0.17009193543344736, 0.39486296649556607, 0.23807383520761505, 0.14705629495438188, 0.12896323925815523, 0.14213204121915624, 0.15005892055341974, 0.06574539322173223, 0.1458115054992959, 0.13871133414795622, 0.08682266183313914, 0.1476006454322487, 0.08610728342318907, 0.1030918896140065, 0.13229984615463763, 0.2242678846232593, 0.1110948613495566, 0.14620024245232344, 0.17172773281345144, 0.3444497653981671, 0.22895362693816423, 0.34445047785993665, 3.358028484508395, 78.46486240625381, 108.06059271097183, 100.69487795233727, 103.16229075193405, 85.33840477466583, 61.74378365278244, 16.65487490594387, 34.73501913249493, 58.183815479278564, 61.11774064600468, 60.57311587035656, 48.66011291742325, 61.04177512228489, 40.0843720883131, 6.420927755534649, 0.3597426088526845, 0.25992882263381034, 0.2744200872257352, 0.35969656601082534, 0.9346556779928505, 0.730705481255427, 2.026248872280121, 3.607517872005701, 8.236948158591986, 8.312883283942938, 5.421397089958191, 3.0703846318647265, 1.9686212833039463, 8.92462195828557, 23.034080900251865, 28.521127067506313, 42.671619057655334, 48.14082898199558, 48.82661618292332, 64.10833597183228, 71.70105814933777, 78.4666483104229, 81.02631255984306, 80.50350621342659, 78.75938460230827, 80.61151921749115, 76.34589090943336, 80.13608112931252, 75.01031577587128, 78.37685152888298, 81.98280483484268, 83.05528968572617, 84.8543943464756, 78.79682779312134, 82.20076113939285, 88.98449912667274, 86.78706184029579, 87.75088772177696, 67.59102389216423, 50.770413279533386, 74.14202436804771, 75.01845493912697, 82.46833518147469, 86.88749805092812, 61.82319559156895, 51.05888620018959, 70.67838862538338, 84.82913330197334, 79.54393610358238, 74.06247183680534, 76.079570800066, 82.39077374339104, 88.61757561564445, 87.45720148086548, 82.4633726477623, 79.31772664189339, 81.58533096313477, 80.71791350841522, 84.5433658361435, 85.42526811361313, 92.37836301326752, 90.08893266320229, 91.13519132137299, 80.730931609869, 60.865430384874344, 35.784294828772545, 19.227150678634644, 15.032006688416004, 13.688321840018034, 14.046985544264317, 10.153113137930632, 4.486675271764398, 7.927954914048314, 2.3018449964001775, 0.7642803608905524, 0.23066749825375155, 0.15684489626437426, 0.3374238533433527, 0.23680924525251612, 0.242503818590194, 1.8352533085271716, 18.729994855821133, 41.954168155789375, 80.4626052081585, 76.6471615433693, 85.3380323946476, 65.84510117769241, 36.75054877996445, 22.310814410448074, 22.81337734311819, 58.69616858661175, 81.85467571020126, 90.17211779952049, 82.58002638816833, 103.57284352183342, 34.140525832772255, 0.6249956286046654, 0.24194282916141674, 0.259584347368218, 0.19830828619888052, 0.16930772282648832, 0.1875450520310551, 0.20035282883327454, 0.13128193124430254, 0.11379021554603241, 0.13672730623511598, 0.11445327996625565, 0.10730924768722616, 0.09915719332639128, 0.23750808119075373, 0.11479396285722032, 0.1563626338611357, 0.24899818963604048, 0.12475023017032072, 0.14551886182744056, 0.129383398743812, 0.10950607160339132, 0.23124230647226796, 0.21639037295244634, 0.1403522226610221, 0.2864411874907091, 0.14366168179549277, 0.16676230472512543, 0.09672308995504864, 0.13889022142393515, 0.1637075506732799, 0.1378232060233131, 0.14337463391711935, 0.10852300052647479, 0.22530101356096566, 0.2752547658747062], [0.06205713078088593, 0.09524344044621103, 0.06310926240985282, 0.010247112204524456, 0.04739885698654689, 0.003556719316293311, 0.03790630951698404, 0.07667506142752245, 0.06339769810438156, 0.1637924968963489, 0.024053384695434943, 0.04133669790462591, 0.02534071776608471, 0.07376893729087897, 0.06843104012659751, 0.06382353501976468, 0.04714105714811012, 0.012198095064377412, 0.021966914428048767, 0.050740948354359716, 0.07482709144824184, 0.026495471720409114, 0.03072193037951365, 0.05661101364239585, 0.033498813209007494, 0.0880721490830183, 0.07792486037942581, 0.16753943724324927, 4.731376441195607, 54.35075595974922, 92.02363684773445, 76.10614657402039, 81.46559938788414, 60.66954329609871, 54.15921203792095, 19.221697971224785, 27.915669456124306, 46.66842699050903, 48.860666155815125, 44.297646805644035, 42.75252811610699, 63.13528798520565, 14.445561356842518, 1.8434666865505278, 0.06334677935228683, 0.1780874188989401, 0.056710220233071595, 0.11302624872769229, 0.13847635535057634, 0.45216086378786713, 1.1039483500644565, 0.6713617499917746, 3.0269795609638095, 4.370555402711034, 1.189804149325937, 0.34265489608515054, 6.310007907450199, 37.04413242638111, 62.11965188384056, 76.83716654777527, 81.7082467675209, 76.35828584432602, 72.69842863082886, 77.45934516191483, 71.00085452198982, 72.91678011417389, 70.735172778368, 75.0963431596756, 71.90799504518509, 72.22997456789017, 69.44330289959908, 72.59053722023964, 63.743452951312065, 66.92647755146027, 76.7341160774231, 78.5501678287983, 78.56837645173073, 77.97342717647552, 73.35958555340767, 72.28446364402771, 71.03088811039925, 73.5476678609848, 75.44549882411957, 87.6426999270916, 55.60791850090027, 37.116450145840645, 57.921956330537796, 63.3034897595644, 53.868276849389076, 37.546541467309, 61.18452966213226, 74.73837196826935, 75.25666415691376, 70.56662902235985, 69.24640506505966, 74.9573466181755, 79.81061339378357, 75.34624814987183, 70.814748108387, 64.5020404458046, 61.467101499438286, 64.77331548929214, 65.87048381567001, 69.12266850471497, 70.2813783288002, 69.34276789426804, 72.38712653517723, 75.20915150642395, 77.42430344223976, 79.23922285437584, 65.75117781758308, 44.03028555214405, 21.063637733459473, 13.812006153166294, 4.793001059442759, 3.865106524899602, 6.240014713257551, 2.064476008526981, 2.172219939529896, 0.7099676190409809, 0.3875879303086549, 0.08573759740102105, 0.08131654205499217, 0.08503484292305075, 0.08675438424688764, 0.013111948810546892, 0.6806255341507494, 8.259971123188734, 21.78561419248581, 35.321019887924194, 50.40168106555939, 49.46874752640724, 73.04148942232132, 44.768680930137634, 26.849454268813133, 16.775719821453094, 41.726659163832664, 52.35658876597881, 59.13798227906227, 67.72236764431, 69.52952787280083, 25.530668534338474, 0.1713626555283554, 0.06011717901856173, 0.06423181272111833, 0.01599862218427006, 0.02459236387949204, 0.04424286657012999, 0.031660042150178924, 0.03880189993651584, 0.0737193544046022, 0.047082557357498445, 0.029618516346090473, 0.030631095214630477, 0.031012087856652215, 0.014206129599187989, 0.008403730553254718, 0.02946924818388652, 0.030691745378135238, 0.04860796769207809, 0.03342756332131103, 0.010717556833697017, 0.05271625232126098, 0.07840188322006725, 0.028786411094188225, 0.044302420210442506, 0.04487277925363742, 0.05661047929606866, 0.0483900323160924, 0.046262120522442274, 0.032552994234720245, 0.00775755092035979, 0.016165347515197936, 0.05966127399005927, 0.039208793532452546, 0.11662228818750009, 0.028023230952385347, 0.045496446764445864, 0.03729248288436793, 0.03340562914672773, 0.05355517605494242, 0.03882085809891578, 0.02973374033899745, 0.08153913440764882, 0.11588385867071338, 0.11075721384258941, 0.05092231811431702, 0.035487642817315646, 0.03782004969252739, 0.027050214121118188, 0.11077514413045719, 0.08535974775440991, 0.03549712375388481, 0.07186066781287082, 0.07127345088520087, 0.02775333596218843, 0.08611355457105674, 0.053154089764575474, 0.06663223743089475, 0.03533329836500343, 0.0350505920505384, 0.09764986913069151, 0.0544025009003235, 0.1549281959887594, 7.176004238426685, 65.84581553936005, 103.88751223683357, 84.87123504281044, 91.28712236881256, 71.16385817527771, 81.56132385134697, 34.53694336116314, 25.952557995915413, 31.42980068922043, 35.45526288449764, 37.580257058143616, 37.52088524401188, 49.46320362389088, 17.70970020443201, 2.7033077040687203, 0.10153888622880913, 0.1722572254948318, 0.028095080124330707, 0.06598604202736169, 0.3825369622791186, 0.9772563795559108, 1.9345771288499236, 2.3399778502061963, 3.6187239456921816, 4.543478898704052, 0.4764869506470859, 0.6180253776255995, 6.8067709263414145, 37.62553922832012, 63.84759396314621, 77.93067187070847, 83.42393070459366, 79.88454982638359, 73.187675178051, 80.13826981186867, 71.88589543104172, 74.21091467142105, 72.24041640758514, 74.02484625577927, 73.53281065821648, 74.46276515722275, 71.87840223312378, 71.59866124391556, 67.24231660366058, 68.64412978291512, 75.74138134717941, 80.22003382444382, 79.10360053181648, 80.66280126571655, 75.03457367420197, 76.08774796128273, 75.21146178245544, 75.56044265627861, 76.69431701302528, 90.07941037416458, 60.12120991945267, 45.11127434670925, 64.92666006088257, 69.42596063017845, 62.43231810629368, 46.55556924641132, 64.65273275971413, 77.56673499941826, 78.18802446126938, 72.50651612877846, 70.43368175625801, 75.38964182138443, 82.13068529963493, 78.21734368801117, 74.28805813193321, 68.42157572507858, 65.25516763329506, 67.51537755131721, 70.01437425613403, 71.7737178504467, 73.85083079338074, 73.81161689758301, 75.43371945619583, 78.75642076134682, 82.83240884542465, 82.80076414346695, 70.33348113298416, 48.615149930119514, 24.96470980346203, 14.998458288609982, 6.506662080064416, 2.4590917211025953, 1.4035951648838818, 0.765094585949555, 2.0754103967919946, 1.125418385490775, 1.0211537615396082, 0.6563184759579599, 0.2832630439661443, 0.02041140072833514, 0.03566937622963451, 0.05785292356449645, 0.48456285323482007, 8.400995805859566, 24.16167799383402, 37.815825417637825, 52.25578397512436, 46.83152563869953, 52.08181411027908, 40.22892013192177, 32.59577952325344, 31.187267303466797, 63.05787093937397, 66.66619911789894, 73.37348520755768, 74.37201082706451, 87.33970418572426, 45.14185510575771, 0.6797252199612558, 0.117589870642405, 0.029734896234003827, 0.026310246503271628, 0.017860856241895817, 0.06163299338368233, 0.06849430821603164, 0.029406861394818407, 0.024638384456920903, 0.0507409520650981, 0.04103683684661519, 0.0375241665460635, 0.06322620261926204, 0.023047525974106975, 0.04067935544298962, 0.038286842027446255, 0.0319082794158021, 0.044857999382657, 0.04720587261545006, 0.05240334059635643, 0.04961362232279498, 0.04934115393552929, 0.0527991984563414, 0.07250513401231728, 0.034092946953023784, 0.08418813406024128, 0.03670361838885583, 0.03781574894674122, 0.0406898271467071, 0.02685096416826127, 0.0749019741488155, 0.08833957457682118, 0.040975691299536265, 0.036824061535298824, 0.17714141809847206, 0.1709164318162948, 0.1391070769750513, 0.09769767086254433, 0.1723565990687348, 0.14056406129384413, 0.1991794933564961, 0.25040163542144, 0.2002003026427701, 0.3434289857978001, 0.1831355519243516, 0.0773413541901391, 0.12862425588537008, 0.268389395205304, 0.1900402712635696, 0.181623010430485, 0.13190499390475452, 0.11187668424099684, 0.13330198300536722, 0.08482243283651769, 0.2197916802833788, 0.1506604757742025, 0.19382921716896817, 0.12080203421646729, 0.09990486258175224, 0.4395890305750072, 0.21383101731771603, 0.292283819289878, 11.387261264026165, 90.84239423274994, 114.72557187080383, 99.89905625581741, 104.59718495607376, 79.06714528799057, 76.08104512095451, 31.536248177289963, 42.17614844441414, 68.22122767567635, 69.235720038414, 61.73618786036968, 61.33305989205837, 87.53249064087868, 25.66520981490612, 3.7404349772259593, 0.35390404402278364, 0.4990080452989787, 0.11523856868734583, 0.27962286898400635, 0.22815498698037118, 1.3577858917415142, 3.1083913799375296, 3.4786743856966496, 8.431150987744331, 11.352683119475842, 7.157751442864537, 2.7847786573693156, 6.935528442263603, 43.066292479634285, 69.6412418782711, 82.91517600417137, 87.51480638980865, 83.38131219148636, 73.62832233309746, 83.38258132338524, 74.31618422269821, 75.73239862918854, 73.05634662508965, 76.2630021572113, 75.09837985038757, 74.2638610303402, 72.44448825716972, 75.0597283244133, 69.74819853901863, 71.37009590864182, 76.13098204135895, 83.51876601576805, 82.29425892233849, 82.27145254611969, 77.28928908705711, 79.67711135745049, 77.01755046844482, 81.02141842246056, 80.75582787394524, 92.08692625164986, 65.94925358891487, 51.524410620331764, 69.73364531993866, 75.28966158628464, 70.45629054307938, 51.80911034345627, 71.62979677319527, 80.25734022259712, 79.82176959514618, 74.58931356668472, 71.63288980722427, 81.62175580859184, 86.27278223633766, 82.55004599690437, 76.92047327756882, 69.9441996216774, 67.07538396120071, 71.61580592393875, 72.25939258933067, 74.70414340496063, 77.29455560445786, 74.37669977545738, 78.91450747847557, 82.72416785359383, 82.82159462571144, 87.11344912648201, 71.32632225751877, 49.01998780667782, 24.87078834325075, 22.404935359954834, 12.711357213556767, 15.302436277270317, 18.681786842644215, 10.70341195911169, 8.067689090967178, 2.2357615549117327, 1.1289696511812508, 0.3638753917766735, 0.15341117192292586, 0.18418692285194993, 0.19030971539905295, 0.17403889942215756, 1.1503331735730171, 14.667882677167654, 34.67411980032921, 54.34490047395229, 70.96297055482864, 72.95724794268608, 104.74399387836456, 62.294632494449615, 41.02091543376446, 26.482401564717293, 58.48856292665005, 68.40179398655891, 83.54970395565033, 84.70268368721008, 101.38337060809135, 47.58057564496994, 0.5601975275203586, 0.1972261309856549, 0.1669312917510979, 0.1873078171047382, 0.15644658560631797, 0.10311221703886986, 0.1945870538474992, 0.104973612469621, 0.14334457693621516, 0.1187241543084383, 0.11309705703752115, 0.14131435775198042, 0.16346130607416853, 0.10815163725055754, 0.08885982009815052, 0.18898141948739067, 0.1195683324476704, 0.21046895475592464, 0.12452345952624455, 0.1052363401686307, 0.12419358230545186, 0.2314860129263252, 0.15774555184179917, 0.1340372732374817, 0.13343004800844938, 0.1503490112372674, 0.09572913899319246, 0.10907337724347599, 0.07260801052325405, 0.15945471794111654, 0.22580108750844374, 0.259657345013693, 0.11663670069538057, 0.2681818016571924], [0.020335681256256066, 0.07040444048470818, 0.07129244986572303, 0.012739053927361965, 0.026264005136908963, 0.025903486493916716, 0.07424937401083298, 0.04058388927660417, 0.05632246291497722, 0.010995531956723426, 0.06054293058696203, 0.02611440300825052, 0.042181607059319504, 0.02249420664156787, 0.039544389001093805, 0.033423693021177314, 0.02184736185881775, 0.0526894236827502, 0.05484584136866033, 0.03862808895064518, 0.08985400112578645, 0.049030657901312225, 0.02735602163738804, 0.01949552184669301, 0.08261111477622762, 0.0521138399199117, 0.05451733341033105, 6.981582446023822, 61.361600160598755, 80.52545383572578, 85.99496394395828, 73.47639888525009, 65.87566673755646, 44.049402326345444, 18.851299546658993, 26.237590201199055, 42.20351457595825, 50.98951332271099, 53.22637729346752, 52.61167287826538, 49.600121676921844, 11.19518917053938, 0.4695465636905283, 0.04680339108745102, 0.05978572844469454, 0.051873168849851936, 0.027281170478090644, 0.11886797510669567, 0.9087440965231508, 1.148764688987285, 1.140227378346026, 1.3545796950347722, 2.6419880194589496, 3.6584878619760275, 0.35887744277715683, 20.66308792680502, 72.6489020884037, 78.25286418199539, 78.7967137992382, 74.07271608710289, 77.90713593363762, 73.2643474638462, 72.35358193516731, 71.82334318757057, 73.17656457424164, 70.4055404663086, 70.79720064997673, 71.30715608596802, 71.05722069740295, 69.21577870845795, 72.17505231499672, 66.35753408074379, 70.42751848697662, 75.11433139443398, 75.90127676725388, 73.80819708108902, 75.17728641629219, 75.93669846653938, 77.90473446249962, 74.14080083370209, 69.9923050403595, 65.07886469364166, 70.83393707871437, 70.53685382008553, 81.70529812574387, 39.44441422820091, 33.807070925831795, 51.49156138300896, 44.748230427503586, 57.82972767949104, 74.41662803292274, 72.78073981404305, 78.84325370192528, 70.58232218027115, 72.9281111061573, 75.74756741523743, 73.52050691843033, 70.55769190192223, 68.69424149394035, 64.3369697034359, 61.28384493291378, 61.76497511565685, 60.46809710562229, 62.026613876223564, 65.32934725284576, 69.22904759645462, 71.86347663402557, 73.5018803179264, 75.17680004239082, 79.71138551831245, 78.39006721973419, 69.8137678205967, 55.93158133327961, 43.71374733746052, 32.34563894569874, 22.421836853027344, 20.209154784679413, 7.558919191360474, 1.9058994739316404, 1.392067652195692, 1.3065899326466024, 0.7581918407231569, 0.07489286057534628, 0.17201396432938054, 0.06256566892261617, 0.09841890481766313, 0.11060581571655348, 0.4496188595658168, 6.045454228296876, 14.987794160842896, 26.50178052484989, 40.01961976289749, 46.44895076751709, 40.64635053277016, 30.705719143152237, 25.63239097595215, 10.800784584134817, 23.49293477833271, 45.89233763515949, 55.24725705385208, 68.7547418475151, 72.01192706823349, 33.060334995388985, 0.8548295020591468, 0.10422609164379537, 0.042503424556343816, 0.10518542141653597, 0.012385761947371066, 0.07298285447177477, 0.032888868008740246, 0.05612154498521704, 0.11086827624239959, 0.02077029406791553, 0.09194302067044191, 0.03873483576171566, 0.020620222530851606, 0.03881541073496919, 0.030789710726821795, 0.005486159252541256, 0.012507823903433746, 0.01858811272541061, 0.0097940839259536, 0.02984014205139829, 0.0053160339575697435, 0.09992267412599176, 0.017540895969432313, 0.03838644937786739, 0.05752422264777124, 0.001631433203783672, 0.03582122706575319, 0.02435375783534255, 0.04012078912637662, 0.07394449232378975, 0.015040663529362064, 0.07822592000593431, 0.03843912701995578, 0.024660227718413807, 0.02325349978491431, 0.028513645847851876, 0.049685499325278215, 0.008889103482943028, 0.00782715138484491, 0.03097507138591027, 0.05224435772106517, 0.06866714698844589, 0.0045052714813209604, 0.036000092077301815, 0.010969953837047797, 0.06799545139074326, 0.038775397842982784, 0.008581569545640377, 0.01669177883741213, 0.049960732212639414, 0.0018684687938730349, 0.0135073558158183, 0.0694019474030938, 0.05947893572738394, 0.057230922175222076, 0.03529234294546768, 0.03964428949984722, 0.05011064975406043, 0.07749092663289048, 0.05592762550804764, 9.472595304250717, 73.45929980278015, 92.58635625243187, 97.37938866019249, 82.31675371527672, 83.3342707157135, 61.37769989669323, 32.541742622852325, 28.481221608817577, 20.415383018553257, 42.27682404220104, 51.967911422252655, 53.04231517016888, 49.971205964684486, 15.482836347073317, 0.7985601620748639, 0.009291216720157536, 0.08289608464110643, 0.07617327311891131, 0.20279940770706162, 0.3761120414128527, 2.332229590974748, 2.7506671752780676, 3.2587246131151915, 2.4035902367904782, 1.6658510360866785, 0.9944121027365327, 2.474689409136772, 25.313732475042343, 74.82208147644997, 83.18920210003853, 82.60448947548866, 76.36248841881752, 80.78604385256767, 78.22159945964813, 74.20260831713676, 72.23767295479774, 72.79913082718849, 73.24138909578323, 73.79664570093155, 74.28672060370445, 70.9270928800106, 69.72310468554497, 72.64339998364449, 69.08752799034119, 72.2035963833332, 76.37634247541428, 76.52579605579376, 76.30226165056229, 79.12988752126694, 77.93561160564423, 80.39808467030525, 78.14700186252594, 72.3171266913414, 70.00998929142952, 74.48102697730064, 73.06785240769386, 83.03905695676804, 44.53664258122444, 40.49936302006245, 58.08293469250202, 51.04405179619789, 61.9434667378664, 76.6240967810154, 75.64571768045425, 79.61294800043106, 74.0662032365799, 73.45082625746727, 78.55804100632668, 77.09241405129433, 74.99173477292061, 71.90576836466789, 68.3498963713646, 64.36656251549721, 64.4975034892559, 64.13993507623672, 65.62498658895493, 68.30407842993736, 71.0965333878994, 72.96811535954475, 76.21033698320389, 79.65891033411026, 81.3974766433239, 81.33399724960327, 76.5377426147461, 61.066621989011765, 47.280045971274376, 39.25980493426323, 28.435979336500168, 22.630489356815815, 8.624600507318974, 2.113530426286161, 2.368871974758804, 1.7387357563711703, 2.086744476109743, 1.0771533753722906, 0.5807096580974758, 0.20737488172017038, 0.16275292611680925, 0.14996388112194836, 0.4643210722133517, 6.568024987354875, 17.969249077141285, 29.13412157446146, 42.46529772877693, 40.845045670866966, 35.84447219967842, 26.233199536800385, 28.33746202290058, 20.657057650387287, 38.35593603551388, 53.89341630041599, 66.45537123084068, 76.33610263466835, 85.33036440610886, 53.30510526895523, 1.9652132224291563, 0.030680323725391645, 0.05748464020143729, 0.03142214671242982, 0.018341793911531568, 0.06509007682325318, 0.07825765424058773, 0.04901248641544953, 0.03079374615481356, 0.036076841279282235, 0.06527171746711247, 0.026183068366663065, 0.047982726828195155, 0.061620866690645926, 0.009239361934305634, 0.020307312661316246, 0.0675549496372696, 0.034710261679720134, 0.009111946310440544, 0.02797991364786867, 0.022958371773711406, 0.041950038430513814, 0.04148058549617417, 0.03510123620799277, 0.026915989292319864, 0.03352006460772827, 0.01581732478371123, 0.013287027013575425, 0.0469825529580703, 0.03706367133418098, 0.013291132945596473, 0.01267014737095451, 0.04964188330632169, 0.1108875498175621, 0.14875634748023003, 0.15574777935398743, 0.14911406266037375, 0.05629355255223345, 0.07720905152382329, 0.14956626808270812, 0.11579487516428344, 0.16849651088705286, 0.16307623533066362, 0.14839818701148033, 0.11034931463655084, 0.10625501206959598, 0.13737393950577825, 0.09446902418858372, 0.16085911367554218, 0.11593530434765853, 0.10527061254833825, 0.08905075985239819, 0.1327968476107344, 0.1358293669181876, 0.16257565672276542, 0.1276068901643157, 0.22094352316344157, 0.21606449590763077, 0.15869274007854983, 0.33945959410630167, 14.273957815021276, 94.14482742547989, 100.97439855337143, 108.16409915685654, 94.0116673707962, 90.48529699444771, 62.64639861881733, 28.231164626777172, 37.62196362018585, 62.164485678076744, 72.26457551121712, 71.17828220129013, 75.63321635127068, 69.15920734405518, 20.322519801557064, 1.3812530762515962, 0.2917671063914895, 0.2853708324255422, 0.33379243570379913, 0.2803420991403982, 0.3707393672084436, 2.3218532977625728, 3.312586722895503, 4.558870447799563, 4.9868623819202185, 8.28669698908925, 16.664302200078964, 8.359127752482891, 27.014036737382412, 83.95676851272583, 86.340471804142, 85.08337765932083, 79.02151733636856, 83.50381761789322, 79.78383243083954, 72.41339072585106, 71.31618440151215, 72.95518845319748, 73.56744199991226, 72.80429854989052, 74.9987643957138, 71.5473259985447, 70.6683723628521, 73.96352514624596, 68.0327045917511, 74.33687031269073, 78.61206650733948, 80.33208981156349, 78.27909037470818, 79.6671786904335, 80.14735132455826, 81.73485293984413, 81.59115225076675, 77.44044497609138, 72.49093696475029, 78.57045114040375, 77.8417794406414, 87.1589706838131, 49.826790913939476, 49.859761744737625, 66.112812012434, 59.12787862122059, 68.86448755860329, 81.12538844347, 78.44042211771011, 84.19713601469994, 75.45284003019333, 75.73119029402733, 83.773572742939, 81.17198914289474, 76.99011594057083, 76.11609444022179, 72.70598262548447, 68.22167605161667, 66.67719572782516, 66.2283182144165, 67.74974897503853, 71.51521772146225, 76.82876139879227, 78.24620693922043, 80.97667202353477, 83.37743639945984, 85.11292487382889, 85.94111323356628, 78.26553270220757, 62.704440504312515, 47.67772503197193, 39.37111236155033, 25.48030413687229, 25.09486421942711, 15.29421541839838, 7.840111227706075, 6.190167563036084, 3.9005783339962363, 2.1582621010020375, 1.4889753959141672, 0.5177374777849764, 0.26915831957012415, 0.29090802592691034, 0.29872456274461, 0.8835750783327967, 11.366418432444334, 27.38413877785206, 43.39849725365639, 60.36012589931488, 65.02068981528282, 59.012007638812065, 45.124543234705925, 37.69743897020817, 17.98921700567007, 37.72737376391888, 60.244973078370094, 76.1277674138546, 84.91423353552818, 99.03720170259476, 57.681919410824776, 1.7127972794696689, 0.2714215434389189, 0.1596184357185848, 0.1955786076723598, 0.09949193161446601, 0.16683648980688304, 0.20107731339521706, 0.12020777430734597, 0.1644723190111108, 0.1429011585423723, 0.13365322665777057, 0.10630476564983837, 0.20497673540376127, 0.12269082973944023, 0.13390888168942183, 0.1633624520036392, 0.11253650547587313, 0.07764508554828353, 0.06450307511840947, 0.08693718264112249, 0.12434352582204156, 0.29878951550927013, 0.2035304083256051, 0.19621247600298375, 0.21414978458778933, 0.26627804443705827, 0.16292654414428398, 0.12588056561071426, 0.18673228158149868, 0.13785238726995885, 0.08987564215203747, 0.14254705019993708, 0.13481922971550375], [0.005023207995691337, 0.04300086016883142, 0.05801509767479729, 0.06426270090742037, 0.0275000205510878, 0.01611557167052524, 0.009531728228466818, 0.025723753169586416, 0.05410661775385961, 0.005343896964404848, 0.06710180168738589, 0.0927419426443521, 0.05330031141056679, 0.05455641119624488, 0.03435923696088139, 0.007710558593316819, 0.04763613273098599, 0.030684533558087423, 0.02739547791861696, 0.10594150662655011, 0.07495212106732652, 0.06093180112657137, 0.07963534750160761, 0.03442583358264528, 0.06957166173378937, 0.026113838976016268, 3.469036677852273, 66.26896843314171, 94.7524756193161, 86.64296597242355, 82.55842834711075, 64.61578354239464, 23.778373561799526, 15.83802418783307, 41.75844065845013, 49.7938846796751, 54.22761596739292, 45.4991689324379, 40.867426469922066, 29.700910560786724, 11.00232481956482, 1.514005484059453, 0.12449453803128563, 0.04376702374429442, 0.0606357806827873, 0.06497424983535893, 0.07583769620396197, 0.0320551467302721, 1.0919164144434035, 1.64667239645496, 2.201085090637207, 1.7307032248936594, 0.41989225312136114, 1.5604074066504836, 32.40415960550308, 82.8464224934578, 78.53268876671791, 74.60193648934364, 69.47816982865334, 72.35455468297005, 80.4873114824295, 81.89162492752075, 74.49246436357498, 74.04496237635612, 70.07331669330597, 71.82947605848312, 71.3046482205391, 71.65353789925575, 69.9207016825676, 69.00018587708473, 71.98971346020699, 76.54999315738678, 73.5635282099247, 69.4693922996521, 72.86424413323402, 73.47376942634583, 73.32998514175415, 72.37961813807487, 76.97186172008514, 71.38523429632187, 72.5264422595501, 63.15692402422428, 61.77542455494404, 69.93398576974869, 77.49677315354347, 70.42556539177895, 25.331278033554554, 38.23425516486168, 37.01646611094475, 73.82089599967003, 68.79810512065887, 70.61001509428024, 71.13277584314346, 71.97766810655594, 73.26437026262283, 72.40767583251, 69.41779106855392, 66.81951329112053, 60.82504615187645, 58.32483731210232, 56.383574679493904, 61.08488380908966, 62.865088284015656, 65.60354813933372, 71.76330640912056, 73.59003558754921, 72.73145645856857, 74.63528349995613, 74.35792878270149, 76.26501604914665, 76.08707919716835, 78.24135839939117, 71.15772530436516, 72.29390233755112, 70.05091309547424, 66.5412238240242, 64.62622538208961, 46.39232620596886, 20.60555711388588, 3.0982658732682467, 0.7397227536421269, 1.971423514187336, 1.983986352570355, 0.8420872420538217, 0.0486738518520724, 0.0732756539946422, 0.04458609502762556, 0.034405695405439474, 0.05856346688233316, 1.8003595434129238, 9.377747643738985, 27.273127734661102, 50.86528278887272, 70.0976049900055, 51.295788288116455, 37.29661367833614, 38.16753834486008, 25.35584181547165, 32.23784253001213, 58.98868829011917, 60.222599878907204, 72.19864144921303, 76.08982264995575, 32.70504646003246, 0.6726592616178095, 0.061162742640590295, 0.02420106095087249, 0.03792312287259847, 0.05134624399943277, 0.05106894052005373, 0.038764187702327035, 0.08848822675645351, 0.03271940971899312, 0.028038433847541455, 0.053198960013105534, 0.01634956155612599, 0.02605974568723468, 0.03533265640726313, 0.05712194892112166, 0.012095636011508759, 0.026056613824039232, 0.04014882004412357, 0.049693106338963844, 0.05340707677532919, 0.022219584170670714, 0.05860279699845705, 0.08276155553176068, 0.06438703290768899, 0.06927002323209308, 0.03071721403102856, 0.037767149406136014, 0.04032640114019159, 0.047294332907767966, 0.007983244522620225, 0.04422436482855119, 0.0327939102135133, 0.06220836192369461, 0.012409367809596006, 0.05566434861975722, 0.0660302591859363, 0.012495299233705737, 0.0032276396723318612, 0.03244393192289863, 0.04250211095495615, 0.013107984814269003, 0.008780124662735034, 0.02296712169481907, 0.050801080869860016, 0.006367237901940825, 0.03810527930909302, 0.02908143706008559, 0.042124034953303635, 0.016286761019728146, 0.09123694137088023, 0.026840045320568606, 0.01899121023598127, 0.10491089356946759, 0.060502015985548496, 0.052421834916458465, 0.009352862289233599, 0.03452780096267816, 0.09858038130914792, 4.822870781645179, 80.85392341017723, 107.16203212738037, 97.89469420909882, 94.25796255469322, 87.30110585689545, 49.91409122943878, 31.40485692769289, 38.58905352652073, 37.62159883975983, 46.6399285197258, 45.79471707344055, 46.88034161925316, 36.297563686966896, 15.175886917859316, 1.012239083647728, 0.04468160943360999, 0.06330328207695857, 0.04891829674306791, 0.08321260320371948, 0.3801129892235622, 0.9413555497303605, 2.938506295904517, 3.2388965645805, 3.572051525115967, 0.856616118689999, 0.2544097672216594, 2.612435817718506, 37.684565261006355, 84.73446518182755, 80.87065011262894, 76.10865443944931, 73.79775524139404, 77.52771869301796, 84.22100633382797, 84.18931603431702, 74.12635400891304, 75.74853256344795, 71.18944600224495, 74.64304268360138, 72.3353885114193, 71.10877633094788, 69.84285145998001, 68.32101032137871, 73.59296903014183, 79.2832624912262, 75.60594141483307, 72.49031379818916, 75.03322094678879, 75.42602106928825, 77.4987642467022, 74.56770792603493, 78.71453180909157, 76.13709971308708, 76.72892555594444, 66.02798536419868, 63.77957001328468, 74.0204992890358, 80.80881223082542, 72.69696190953255, 31.86372220516205, 43.49903225898743, 41.203761622309685, 76.20875626802444, 74.30774107575417, 73.19837540388107, 75.25718092918396, 74.278953820467, 75.04314601421356, 76.1359977722168, 73.91907513141632, 69.99187186360359, 63.85098338127136, 59.937569573521614, 59.616695791482925, 65.78124940395355, 66.19304850697517, 69.31119918823242, 75.34628614783287, 77.63885512948036, 76.84549570083618, 78.57398495078087, 79.63181018829346, 79.45214062929153, 78.63358095288277, 78.6358380317688, 73.93688097596169, 73.4509326517582, 72.65632688999176, 70.22699564695358, 72.61298641562462, 52.23181486129761, 27.53240492194891, 3.4939182177186012, 2.4682259559631348, 3.8641152530908585, 3.6655844561755657, 1.3677243771962821, 0.585478461580351, 0.13422824267763644, 0.044071471274946816, 0.07372985579422675, 0.09320617828052491, 1.5517089609056711, 9.79336554184556, 28.33962980657816, 44.58575874567032, 48.87133978307247, 28.90471078455448, 20.869711339473724, 13.982793688774109, 21.005225367844105, 46.132952123880386, 72.88717970252037, 70.93136385083199, 77.97630742192268, 87.27290377020836, 50.05368813872337, 0.7714679127093405, 0.10146127242478542, 0.07641327625606209, 0.05778459773864597, 0.1037847512634471, 0.029423830601444934, 0.02643991268996615, 0.03527129934809636, 0.06186497019371018, 0.04435258197190706, 0.022608586441492662, 0.005062864656792954, 0.030311060727399308, 0.03331053405418061, 0.0419250985578401, 0.0354378113115672, 0.02880009629734559, 0.01666328407736728, 0.030164926283759996, 0.021675933166989125, 0.05335622110578697, 0.0382293775328435, 0.047861337443464436, 0.04654492702684365, 0.010149852823815309, 0.023435949369741138, 0.01326750574662583, 0.021129166998434812, 0.01789266840205528, 0.028804046378354542, 0.11657780385576189, 0.039348131758742966, 0.10426555163576268, 0.18684706214116886, 0.19559879408916458, 0.16813554510008544, 0.1253434584941715, 0.07120531430700794, 0.08827721190755256, 0.08227813537814654, 0.10285001626471058, 0.12047433148836717, 0.10283637559041381, 0.2463339685346, 0.09856795775704086, 0.13936255389126018, 0.1151949749328196, 0.1520347106270492, 0.17891816416522488, 0.1374383579241112, 0.10274725849740207, 0.13231529766926542, 0.14169920585118234, 0.15158044203417376, 0.18467386078555137, 0.1215381408110261, 0.25081584288273007, 0.21400085039203987, 7.691789036616683, 103.627188205719, 119.30739641189575, 108.27706709504128, 105.08483558893204, 87.40947604179382, 40.60126215219498, 29.028893820941448, 59.24757979810238, 72.32212722301483, 77.87113666534424, 64.19467493891716, 62.96865172684193, 49.54655595123768, 20.38604099303484, 2.644980358891189, 0.17930132016772404, 0.2760937489802018, 0.23776686808560044, 0.1975396735360846, 0.2833884075516835, 0.6758551276288927, 5.482868291437626, 5.903706159442663, 8.868606314063072, 5.864047687500715, 3.7750800931826234, 4.809744860976934, 41.38395555317402, 94.2691795527935, 83.12928691506386, 78.67558389902115, 76.03271931409836, 80.72299003601074, 87.87305116653442, 87.90384471416473, 72.91063964366913, 78.53515863418579, 71.26870974898338, 75.30541554093361, 72.69339010119438, 73.46381396055222, 71.01654008030891, 70.83693891763687, 76.81576609611511, 82.80179768800735, 80.7756096124649, 76.15706384181976, 78.65055084228516, 79.41574618220329, 80.96493825316429, 77.7051767706871, 82.79586240649223, 77.99608916044235, 79.74113032221794, 70.06703943014145, 66.53862476348877, 76.59945130348206, 83.95084843039513, 74.7216908633709, 35.939239114522934, 51.37361191213131, 45.95651239156723, 77.2569528222084, 78.53246837854385, 76.03551596403122, 77.92684927582741, 74.99788284301758, 78.31271857023239, 79.1551485657692, 78.67664784193039, 74.36332449316978, 66.97365581989288, 62.728561609983444, 62.06245355308056, 69.8111079633236, 70.48199996352196, 72.54975020885468, 80.409354865551, 81.77738025784492, 81.1978429555893, 83.03584232926369, 81.05655893683434, 80.8807347714901, 80.39105504751205, 80.89073583483696, 74.6890278160572, 76.28396183252335, 72.85669773817062, 69.68547910451889, 72.83664241433144, 50.52988238632679, 26.942366883158684, 6.480660075321794, 5.971238985657692, 7.336542773991823, 5.913283070549369, 2.270210743881762, 0.5808438977692276, 0.13138649985194206, 0.2906304330099374, 0.15874434902798384, 0.19219868903746828, 3.012671903707087, 17.019060663878918, 44.18547302484512, 76.06743425130844, 93.60638871788979, 68.02214875817299, 53.487107902765274, 52.815079763531685, 37.18393452465534, 50.67792244255543, 75.22738292813301, 83.10889720916748, 89.81109917163849, 97.71655216813087, 55.02186834812164, 1.090158058796078, 0.24345719633856788, 0.18947419070173055, 0.16242348676314577, 0.18703693320276216, 0.08496036098222248, 0.13761858106590807, 0.06826755983638577, 0.09423118070117198, 0.15024671360151842, 0.10046304669231176, 0.06583828042494133, 0.11713194326148368, 0.12621042056707665, 0.17215525440406054, 0.07516615645727143, 0.1640305481851101, 0.15983725053956732, 0.14083340152865276, 0.23220677190693095, 0.10902514506597072, 0.13698946248041466, 0.17280211031902581, 0.207857173809316, 0.1401001596241258, 0.20281281089410186, 0.18617935187648982, 0.10756996416603215, 0.17333207797491923, 0.11866625194670632, 0.2090252994094044, 0.1130422494316008], [0.0014181825190462405, 0.023976520460564643, 0.06636924255872145, 0.04762495598697569, 0.061662545704166405, 0.020105157200305257, 0.02745161396887852, 0.041704172326717526, 0.04054416582221165, 0.026751622135634534, 0.0596304822829552, 0.03260210214648396, 0.03890016771038063, 0.04978120297892019, 0.025284646653744858, 0.03604009383707307, 0.043393745727371424, 0.018636456225067377, 0.15380329306935892, 0.018963802722282708, 0.03868268875521608, 0.010005219373852015, 0.02535721014282899, 0.02313494169357, 0.12093421813915484, 0.6510606862138957, 54.920227602124214, 84.30843964219093, 86.66586354374886, 65.99288284778595, 42.045253068208694, 19.793643280863762, 25.984863862395287, 37.41476833820343, 33.98086220026016, 38.26854832470417, 33.928641602396965, 43.13477240502834, 28.50266195833683, 18.241067491471767, 2.3824700200930238, 0.14566792960977182, 0.10112492367625237, 0.05966488824924454, 0.19459193717921153, 0.16137818660354242, 0.19479911512462422, 0.9060940355993807, 5.201287250965834, 3.216692218557, 2.222165884450078, 1.2114591873250902, 1.4719532593153417, 46.050165966153145, 80.59802234172821, 78.90471920371056, 75.46068280935287, 70.60470297932625, 63.0510351061821, 73.24740797281265, 74.16260406374931, 75.51251962780952, 73.44809800386429, 80.36072507500648, 74.04916495084763, 73.50871995091438, 70.54065361618996, 71.46434605121613, 72.71795958280563, 71.87852382659912, 75.7222531735897, 65.91814085841179, 66.84475913643837, 68.4519512951374, 66.67794808745384, 67.86090061068535, 71.98326140642166, 74.25660341978073, 74.63511630892754, 75.58543011546135, 72.6777957379818, 61.71481020748615, 55.35864807665348, 68.93300548195839, 68.66072729229927, 82.66380429267883, 54.24390189349651, 18.81551306694746, 42.25330330431461, 71.6292268037796, 71.74911797046661, 69.43589329719543, 72.854965031147, 70.15301361680031, 71.01732283830643, 69.81276467442513, 62.315075397491455, 56.44079580903053, 56.749255657196045, 60.1425039768219, 63.63540194928646, 63.81407976150513, 68.02043125033379, 74.66097012162209, 75.67583486437798, 75.53119942545891, 76.45623698830605, 77.14434966444969, 76.25345706939697, 78.11120018362999, 74.82974946498871, 70.39081245660782, 73.66923093795776, 75.5150654911995, 79.50409904122353, 79.16382730007172, 80.55725812911987, 76.20874106884003, 61.25764913856983, 18.182231448590755, 1.4770947396755219, 1.8720535025931895, 1.2117553339339793, 1.1134275351651013, 0.4039578972151503, 0.30929586268030107, 0.04278847605746705, 0.12178066725027747, 0.06741680626873858, 0.04254805731761735, 0.08835579050355591, 2.944478625431657, 17.29989219456911, 38.181684985756874, 63.43747816979885, 64.33908998966217, 90.85176452994347, 124.0138466656208, 48.92560467123985, 15.89000254869461, 39.43473994731903, 52.349695935845375, 64.76524472236633, 75.51221564412117, 15.754525568336248, 0.36572963290382177, 0.06333030367386527, 0.026890824919973966, 0.05841312631673645, 0.05756033555371687, 0.033605652788537554, 0.036853877318208106, 0.05136640444106888, 0.01391253597830655, 0.03306189973955043, 0.02701711062400136, 0.02057814461295493, 0.03244377607188653, 0.04117820113606285, 0.03805380765697919, 0.020378851986606605, 0.0253109966070042, 0.023631954281881917, 0.06772143562557176, 0.028005142958136275, 0.017935729665623512, 0.015583425811200868, 0.061754902271786705, 0.02327090871403925, 0.024693800623936113, 0.009861688013188541, 0.07032112698652782, 0.04559520435577724, 0.010477381147211418, 0.011063007095799549, 0.015608688518113922, 0.03527285785821732, 0.027177891352039296, 0.10058276995550841, 0.017876864367281087, 0.04639526552637108, 0.03449485702731181, 0.00925196916796267, 0.04078724516148213, 0.03432497200265061, 0.025145870604319498, 0.039870403343229555, 0.01128958014305681, 0.02079563284496544, 0.019036946941923816, 0.0320105065475218, 0.06213115259015467, 0.021155873182578944, 0.06398418030585162, 0.0787198860780336, 0.03508234854962211, 0.03913315013051033, 0.04047012174851261, 0.05349288388970308, 0.01967359090485843, 0.08865915820933878, 1.010983013547957, 63.8854855298996, 98.69119986891747, 95.44238939881325, 77.36055806279182, 61.83530934154987, 38.5443489253521, 20.15963964164257, 22.612465023994446, 32.225162610411644, 49.02137093245983, 42.77949906885624, 49.935153499245644, 35.511028692126274, 21.06526404619217, 2.786979926750064, 0.05658757661876734, 0.1083699993614573, 0.04894126992439851, 0.38348441768903285, 0.263877582619898, 1.1714006680995226, 2.3661460960283875, 5.841306857764721, 3.2340990845113993, 1.633924674242735, 0.42723856517113745, 2.2947738133370876, 48.90285909175873, 81.7446032166481, 80.3286623954773, 77.18356356024742, 73.66027861833572, 68.49949434399605, 75.79100668430328, 77.50746577978134, 80.43529987335205, 74.29421380162239, 80.18411815166473, 74.83191534876823, 77.06166610121727, 72.82025769352913, 73.26857283711433, 74.54219609498978, 73.39441448450089, 78.64453196525574, 71.91150605678558, 70.7295186817646, 70.88190570473671, 69.55928787589073, 71.45611569285393, 75.34522980451584, 76.23803749680519, 75.1148709654808, 77.12218925356865, 74.6873027086258, 62.96720400452614, 58.83438616991043, 70.40821552276611, 72.45629042387009, 81.3974766433239, 53.3392920345068, 23.65267440676689, 43.9628391712904, 74.29530054330826, 73.14841568470001, 72.11864814162254, 73.90900567173958, 71.92857474088669, 74.5203548669815, 73.2788322865963, 65.44647976756096, 59.79076065123081, 58.86847034096718, 63.064076006412506, 63.90693157911301, 67.59226262569427, 72.09675371646881, 76.50506436824799, 78.44565823674202, 78.63260060548782, 78.01353022456169, 76.93781554698944, 77.22348421812057, 80.41350424289703, 76.14223703742027, 69.97460559010506, 73.49695578217506, 75.15968576073647, 77.9706609249115, 81.52590215206146, 79.09498259425163, 80.97564607858658, 65.15534698963165, 26.790090054273605, 3.489426146261394, 0.5447859701234847, 2.5039936741814017, 1.8301092158071697, 1.6832656203769147, 1.1841197730973363, 0.04045423607749399, 0.11345713966875337, 0.05864863946044352, 0.0635005375079345, 0.05286700477881823, 3.277743305079639, 19.639318361878395, 39.75818619132042, 55.524307787418365, 48.35229903459549, 75.4069384932518, 109.2991590499878, 57.621977627277374, 29.14832331240177, 49.883445873856544, 62.91133560240269, 72.06108883023262, 90.35776063799858, 28.718478977680206, 0.5390355724375695, 0.03329461869725492, 0.05091223974886816, 0.016065916424850002, 0.02504160256648902, 0.039256773379747756, 0.014259975196182495, 0.029645912727573887, 0.05875446600839496, 0.10762811143649742, 0.02358739759074524, 0.057181142619811, 0.07072717824485153, 0.05189760777284391, 0.023765702280797996, 0.024218581202148926, 0.015091582281456795, 0.021563308546319604, 0.04540393805655185, 0.016540096839889884, 0.04556153682642616, 0.02206163659138838, 0.05763611254224088, 0.028271618502913043, 0.047874900192255154, 0.002439685481476772, 0.02048466369160451, 0.027721418045985047, 0.020467251051741187, 0.09467027237406, 0.033587028592592105, 0.11736859931261279, 0.15838096383959055, 0.13617440621601418, 0.11447220473201014, 0.13417978043435141, 0.14150310074910522, 0.16628069541184232, 0.1322461146628484, 0.1904835709137842, 0.13205882627516985, 0.1272189398878254, 0.1638066570740193, 0.22329617582727224, 0.08122261584503576, 0.10943954548565671, 0.15049312147311866, 0.12940454995259643, 0.13660903758136556, 0.22641227580606937, 0.17992611945373937, 0.1470285386312753, 0.14034282707143575, 0.11482188245281577, 0.21974413830321282, 0.22129865566967055, 1.0673414706252515, 83.18828254938126, 108.97958099842072, 106.92196100950241, 89.2013230919838, 63.75092715024948, 34.26924392580986, 40.090273171663284, 52.12779924273491, 51.96910835802555, 57.88075894117355, 47.203426882624626, 66.08962565660477, 46.725032553076744, 29.386868812143803, 4.456556662917137, 0.22311714012175798, 0.23500977462390438, 0.26511833479162306, 0.4096131515689194, 0.45688077458180487, 1.1670276965014637, 5.025060307234526, 15.671083945780993, 11.201268844306469, 9.179723169654608, 7.201496120542288, 2.310056355781853, 53.941989094018936, 88.48191529512405, 84.70124736428261, 82.85956218838692, 77.40822270512581, 68.67967307567596, 79.34536635875702, 79.81583431363106, 80.91840595006943, 76.4146976172924, 81.05734929442406, 76.97420999407768, 82.70138427615166, 77.31973305344582, 77.0248992741108, 76.2022054195404, 76.29079386591911, 81.59571200609207, 73.51123541593552, 75.49426540732384, 76.11086592078209, 74.41001638770103, 73.88589531183243, 78.12297955155373, 80.10950535535812, 79.16807547211647, 79.30855393409729, 80.73660850524902, 67.95118376612663, 62.78568014502525, 75.49265429377556, 76.92630216479301, 86.4076218008995, 63.645087629556656, 31.219981648027897, 50.900111719965935, 81.55549496412277, 78.08288410305977, 76.52806833386421, 77.99017667770386, 74.48132336139679, 75.7543158531189, 76.67774230241776, 68.26497092843056, 64.12399873137474, 62.782792299985886, 66.98079943656921, 68.34164321422577, 69.8672005534172, 73.99853646755219, 80.86747348308563, 82.75126799941063, 82.14371100068092, 81.02624416351318, 78.46432283520699, 78.48383858799934, 80.91885432600975, 77.5966925919056, 72.40636110305786, 76.4043165743351, 76.51803687214851, 80.32473340630531, 84.67355445027351, 84.34342056512833, 82.59435161948204, 66.9165600836277, 22.68987637013197, 5.437738113105297, 10.209500212222338, 5.422975430265069, 3.591912346892059, 1.9243358471430838, 1.5296273957937956, 0.14886516117257997, 0.36752637242898345, 0.11167536184075288, 0.12891695892903954, 0.2380967527278699, 6.5717250388115644, 28.150690644979477, 59.879523888230324, 84.50622662901878, 82.98953801393509, 103.53058218955994, 138.92629086971283, 59.86139126121998, 29.421199969947338, 55.251349434256554, 74.43916082382202, 80.43881088495255, 101.0387670993805, 31.000507324934006, 0.5795899056829512, 0.16290145955281332, 0.17207329161465168, 0.1497290952829644, 0.16175539058167487, 0.10508124614716507, 0.08049432406551205, 0.16746753797633573, 0.20666791184339672, 0.18675129540497437, 0.1233191171195358, 0.11640708762570284, 0.33974757709074765, 0.1362691933172755, 0.166091269638855, 0.15549507807008922, 0.10855839354917407, 0.18092510959831998, 0.14206836494849995, 0.06537817855132744, 0.11729431775165722, 0.21448229643283412, 0.16305460914736614, 0.10076938298880123, 0.11152773382491432, 0.13652318593813106, 0.23013335972791538, 0.10766668085125275, 0.17500533896964043, 0.11883021463290788, 0.09548111323965713], [0.05429714190540835, 0.03620591189246625, 0.04821734568395186, 0.014563351251126733, 0.06949714268557727, 0.08451166591839865, 0.01179360602691304, 0.008389581507799448, 0.016574734727328178, 0.067009574995609, 0.04365000189864077, 0.06854092993307859, 0.025740965429577045, 0.051889670503442176, 0.014238054009183543, 0.07696901870076545, 0.03636512854427565, 0.0820900232065469, 0.018385044422757346, 0.024878812473616563, 0.09591852023731917, 0.02673614835657645, 0.042312844743719324, 0.12619249027920887, 0.18020892224740237, 19.926199167966843, 93.01789909601212, 83.460583537817, 85.63260018825531, 71.56060248613358, 36.846615225076675, 88.4531432390213, 149.7076803445816, 72.98755511641502, 51.54152110219002, 39.2813915759325, 54.812883362174034, 33.89200396835804, 15.853195823729038, 0.8175943500827998, 0.1662958352244459, 0.04365415792562999, 0.13191637845011428, 0.054874158013262786, 0.08830810751533136, 0.22664624528260902, 1.4881294663064182, 1.2888249359093606, 2.8875344060361385, 1.967984817456454, 2.2738746972754598, 1.9444632483646274, 54.88640181720257, 83.79574835300446, 77.61775866150856, 74.43894803524017, 65.82614779472351, 60.51598213613033, 68.02999913692474, 73.77289697527885, 78.65663811564445, 77.29001864790916, 68.62168818712234, 77.82534912228584, 71.66761994361877, 67.40361034870148, 66.41157478094101, 67.30366051197052, 71.19912788271904, 74.19162690639496, 72.83397495746613, 68.91339853405952, 66.30307540297508, 59.946882873773575, 63.265051022171974, 59.724784791469574, 69.61915746331215, 74.6812154352665, 70.36682814359665, 69.82871621847153, 66.04373931884766, 52.901141345500946, 56.76108442246914, 64.29124295711517, 73.26532021164894, 66.06994271278381, 43.33046190440655, 22.46508613228798, 31.58821228891611, 68.22834849357605, 65.52268847823143, 68.76593604683876, 70.52881345152855, 71.94131925702095, 71.41344398260117, 66.61090448498726, 61.461929976940155, 56.30766615271568, 53.57930235564709, 62.03059986233711, 66.61958321928978, 68.6111855506897, 74.01216253638268, 75.99252507090569, 72.9535773396492, 69.63963836431503, 67.10175454616547, 69.56638589501381, 69.43378061056137, 71.43261015415192, 66.68710559606552, 68.39464277029037, 68.41744914650917, 72.67298519611359, 78.24839562177658, 78.18108603358269, 80.38745284080505, 77.80870601534843, 79.06001687049866, 55.67623883485794, 12.540810965001583, 1.243194965645671, 2.5303338607773185, 0.537930722348392, 1.2333040963858366, 1.1547117261216044, 0.06880624030600302, 0.055339061582344584, 0.020039009577885736, 0.02866963044652948, 0.1677861122880131, 0.0032897010760279954, 0.058134164137300104, 5.674577504396439, 24.709424301981926, 40.66153831779957, 74.6247124671936, 118.84825184941292, 110.7000906765461, 29.45813398808241, 29.81814756989479, 52.84394681453705, 64.45285588502884, 66.96643620729446, 63.93487527966499, 9.58698246628046, 0.2936145494459197, 0.09589696826878935, 0.05090220220154151, 0.06310025273705833, 0.002995271611325734, 0.10343851710786112, 0.03640549766714685, 0.03560831231880002, 0.032202477887040004, 0.03770565504964907, 0.04697283082350623, 0.03284847662143875, 0.020219627913320437, 0.018923173847724684, 0.022872855952300597, 0.06022438596119173, 0.030609751047450118, 0.10700426952098496, 0.012429110793164, 0.05454086320241913, 0.04204024648061022, 0.003659394983515085, 0.03899851712048985, 0.03494933342153672, 0.039810593661968596, 0.13275640056235716, 0.031250725442077965, 0.0935451542318333, 0.11177406006027013, 0.07987949924427085, 0.034423863180563785, 0.02092497805278981, 0.08707623142981902, 0.02916378576628631, 0.012819397907151142, 0.06020692322636023, 0.009004207804537145, 0.02148156283510616, 0.019102858932456, 0.05021023484005127, 0.06071694937418215, 0.07590604058350436, 0.043760567059507594, 0.02355986762268003, 0.044723945247824304, 0.03989411496149842, 0.021548077820625622, 0.009231810581695754, 0.03842995036393404, 0.040102639904944226, 0.07377290035947226, 0.04476944261114113, 0.10024350456660613, 0.08674843222252093, 0.1812059382791631, 26.22390903532505, 108.8140618801117, 93.5019551217556, 94.88074913620949, 79.43054258823395, 45.21323807537556, 74.12835270166397, 118.31147745251656, 60.30753672122955, 43.36893104016781, 31.539799086749554, 50.110586285591125, 39.97692905366421, 20.561236292123795, 0.8183992537669837, 0.07413972169160843, 0.14293486688984558, 0.07329647123697214, 0.42953503725584596, 0.41180750413332134, 1.7138109938241541, 5.049569942057133, 8.562400694936514, 3.316394118592143, 0.5996074096765369, 0.45327862724661827, 3.008459829725325, 56.35840862989426, 88.35906028747559, 80.71847587823868, 77.87065789103508, 70.42390868067741, 63.82249251008034, 70.5544924736023, 78.739253282547, 78.6299179494381, 79.0450456738472, 70.34997224807739, 79.32740092277527, 76.67300015687943, 70.21523907780647, 68.35027635097504, 70.36476105451584, 74.1971518099308, 77.67321288585663, 74.86380323767662, 70.07081642746925, 71.28042072057724, 62.76734232902527, 63.69669646024704, 64.85598385334015, 72.00213879346848, 77.19967469573021, 73.28739702701569, 74.16091695427895, 66.53760641813278, 57.09656082093716, 57.87958100438118, 67.78742775321007, 74.9208989739418, 70.76274409890175, 50.41591130197048, 25.716923139989376, 37.620713487267494, 75.5324837565422, 68.3153486251831, 71.33349627256393, 71.50363594293594, 75.6077653169632, 72.423976957798, 69.96783435344696, 65.43537676334381, 57.350668385624886, 55.67599184811115, 64.02556881308556, 68.0060376226902, 70.87839469313622, 74.87100005149841, 78.82821410894394, 74.0428876876831, 69.92853686213493, 66.29831045866013, 70.03194451332092, 70.19501656293869, 73.44142556190491, 68.5221791267395, 67.79146313667297, 68.84677290916443, 73.42875704169273, 79.70285877585411, 79.59872916340828, 80.53115352988243, 82.31314390897751, 82.41747871041298, 60.64720809459686, 17.600552961230278, 2.3579088505357504, 1.4263487001881003, 0.6990009325090796, 2.866005473770201, 2.3088045604526997, 0.4817047237884253, 0.5856053985189646, 0.21504606149392202, 0.06704118306515738, 0.08293245729873888, 0.12406556925270706, 0.10050016149762087, 5.241546565666795, 25.84937073290348, 44.839307740330696, 76.67372211813927, 127.263493090868, 106.62954390048981, 33.534724339842796, 45.64538508653641, 59.922974556684494, 75.51406994462013, 73.02330359816551, 79.04886826872826, 14.740418884903193, 0.2941512409597635, 0.06795362394768745, 0.050081687440979294, 0.1429995079524815, 0.012649494328798028, 0.016110363649204373, 0.0714657932985574, 0.010677033715182915, 0.07159756904002279, 0.028692147207038943, 0.027747066669689957, 0.0435502015898237, 0.02953485589387128, 0.056823405175236985, 0.010874159270315431, 0.029770341207040474, 0.03855930670397356, 0.06976673525059596, 0.03668167308205739, 0.03200192360964138, 0.020663165050791577, 0.03799485886702314, 0.018206342683697585, 0.04651108509278856, 0.0613937546586385, 0.0022319138179227593, 0.05382729563280009, 0.008048839245020645, 0.10232632717816159, 0.014161033923301147, 0.14386975031811744, 0.16750333918025717, 0.19631587201729417, 0.1617105648620054, 0.1988344095298089, 0.19127468549413607, 0.08779433352174237, 0.07945343226310797, 0.13526120834285393, 0.11168579643708654, 0.1826443540630862, 0.1764219652977772, 0.20997743034968153, 0.11531712501891889, 0.21241851733066142, 0.16081888927146792, 0.16988126939395443, 0.14788873231736943, 0.13911719986936077, 0.13954060996184126, 0.2466712598106824, 0.10336173450923525, 0.2992484299466014, 0.23584552196552977, 0.25732121255714446, 38.9855432510376, 121.03424414992332, 102.88868263363838, 108.94206941127777, 90.82474797964096, 53.37620325386524, 104.70710545778275, 152.04419016838074, 84.07653048634529, 70.4900935292244, 56.01489566266537, 77.98199951648712, 55.90965270996094, 28.118626065552235, 2.739944625645876, 0.24413361941697076, 0.23328650771873072, 0.3978244325844571, 0.30702898744493723, 0.8477167587261647, 2.026981757953763, 5.067700669169426, 6.084036882966757, 7.827304489910603, 7.503328174352646, 8.022822048515081, 2.402985356748104, 59.24206629395485, 91.63212865591049, 83.55352655053139, 81.4695055782795, 71.31834268569946, 66.84158250689507, 73.58628138899803, 81.13890051841736, 82.81090199947357, 81.09444290399551, 70.55668115615845, 80.3007110953331, 81.11572176218033, 74.98205289244652, 72.04382255673409, 75.01810535788536, 79.26408872008324, 81.12652078270912, 78.10026437044144, 73.84836092591286, 74.37565863132477, 65.75964376330376, 65.2961066365242, 66.35302752256393, 74.72200244665146, 79.63608115911484, 76.61234021186829, 77.37740635871887, 70.860885232687, 58.497804030776024, 60.424213260412216, 70.06462275981903, 79.60341051220894, 75.94192698597908, 56.12526834011078, 31.380327343940735, 40.663320422172546, 81.23274028301239, 73.33095028996468, 75.53104743361473, 74.17281791567802, 80.23714810609818, 77.20956176519394, 74.87343952059746, 69.03654232621193, 60.75616344809532, 58.925569877028465, 66.04974299669266, 72.24721804261208, 72.99985125660896, 79.7090296447277, 81.7949429154396, 76.37990668416023, 70.46036392450333, 65.98798871040344, 71.57944947481155, 70.37978544831276, 73.61072927713394, 67.65340894460678, 68.69015291333199, 68.86850774288177, 75.26445373892784, 83.20364132523537, 83.9734648168087, 86.414043456316, 84.88379716873169, 85.24506658315659, 61.628691628575325, 16.18680652230978, 6.385355964303017, 7.587531181052327, 3.4294959995895624, 4.19274584390223, 2.8306037234142423, 0.5437970731873065, 0.8252780127804726, 0.293290201225318, 0.3811204695375636, 0.3034911397844553, 0.20451198768569157, 0.3527662722626701, 10.599151253700256, 41.194782704114914, 60.43098069727421, 79.81705784797668, 119.80662122368813, 115.52937313914299, 41.95962846279144, 47.43790850043297, 69.95875284075737, 83.61758351325989, 84.99723628163338, 87.23454102873802, 14.647463522851467, 0.45346597500611097, 0.2744107658509165, 0.1855614545638673, 0.1335158699657768, 0.06786416546674445, 0.1811116113094613, 0.16532862384337932, 0.10307375894626603, 0.15420194511534646, 0.12807184568373486, 0.14776776224607602, 0.12017834073049016, 0.13414816494332626, 0.17664409009739757, 0.22989636228885502, 0.12385649140924215, 0.12937829276779667, 0.19184901873813942, 0.17182572599267587, 0.1430788732250221, 0.17750903352862224, 0.1186236749344971, 0.27471480891108513, 0.15008459886303172, 0.23404191015288234, 0.32347771106287837, 0.15771012171171606, 0.1432638757978566, 0.1728843105956912, 0.17300020437687635], [0.03506529770675115, 0.03162204047839623, 0.019840856148221064, 0.06253128522075713, 0.008436126227024943, 0.06135351170087233, 0.05415914696641266, 0.008590107026975602, 0.0320265517802909, 0.16406663140514866, 0.06957013290957548, 0.03714863982168026, 0.03831551119219512, 0.09239786813850515, 0.029161704042053316, 0.048990299910656177, 0.08202271041227505, 0.005677458020727499, 0.08928985014790669, 0.056002545316005126, 0.04745420264953282, 0.07706648495513946, 0.01632659579627216, 0.14094552519964054, 10.08803877979517, 89.94761824607849, 85.00189483165741, 81.77529036998749, 59.811154156923294, 55.704585313797, 48.80536012351513, 84.21752572059631, 71.99455440044403, 38.793106377124786, 51.536820754408836, 71.97293356060982, 35.37975713610649, 10.169157776981592, 0.8027794794179499, 0.029779692267766222, 0.24084307020530105, 0.09275006916141137, 0.20922073657857254, 0.26995203166734427, 0.736871303524822, 1.2529708910733461, 1.1262659775093198, 5.71322713047266, 0.7414440612774342, 1.2732045678421855, 4.1140648908913136, 67.0598503947258, 86.02128133177757, 73.89601036906242, 74.03515130281448, 68.64473015069962, 63.5038948059082, 64.79170650243759, 68.88879865407944, 71.94794610142708, 74.99193236231804, 68.969886302948, 68.8326908648014, 70.76963692903519, 68.81946757435799, 62.40016423165798, 58.965908512473106, 61.92322142422199, 64.24734011292458, 69.28200915455818, 68.83430197834969, 59.784753173589706, 57.734922766685486, 56.569502502679825, 57.797083631157875, 56.10516741871834, 62.16098606586456, 66.51043027639389, 69.51109886169434, 60.70528417825699, 55.242723897099495, 49.90509711205959, 63.48518840968609, 60.1423329859972, 74.16621387004852, 62.2153839468956, 66.84443235397339, 19.831018075346947, 41.52579814195633, 79.28833141922951, 58.31499584019184, 68.34402188658714, 66.233029961586, 72.63229697942734, 68.49443301558495, 68.80976289510727, 55.48057593405247, 55.53764887154102, 54.404800459742546, 62.188857570290565, 72.78156816959381, 75.97625434398651, 69.8509906232357, 71.47433191537857, 67.13384762406349, 69.07156124711037, 70.47425597906113, 72.93789938092232, 72.5284181535244, 72.39441454410553, 67.17617735266685, 66.9305357336998, 67.10056141018867, 76.55162706971169, 74.60040137171745, 73.3414301276207, 70.51100760698318, 73.02076533436775, 78.05870220065117, 79.17717218399048, 52.82419927418232, 10.605203378945589, 0.9540187264792621, 1.56513886526227, 2.4771642638370395, 2.065472980029881, 0.42276754102203995, 0.18566833867225796, 0.12046601201291196, 0.08978868470876478, 0.030006468477949966, 0.03599489704356529, 0.11131541279610246, 0.038298764629871584, 4.444524608552456, 20.407971516251564, 32.43371061980724, 51.899841874837875, 47.03869432210922, 32.57122524082661, 23.686564788222313, 45.73675878345966, 54.285604655742645, 61.93338967859745, 71.79613664746284, 43.10845881700516, 2.1338980458676815, 0.07451173805748112, 0.03675405845569912, 0.040741803459241055, 0.0588104276539525, 0.020117961103096604, 0.031913782440824434, 0.10150032423553057, 0.07817363570211455, 0.04494181754125748, 0.03168312294292264, 0.04903492525045294, 0.014265439258451806, 0.05203119435464032, 0.011284789579804055, 0.05564855571719818, 0.11379515824955888, 0.009385811790707521, 0.08312701873364858, 0.032409329287474975, 0.021195871231611818, 0.024185286602005363, 0.003340417129038542, 0.06769319690647535, 0.026021682788268663, 0.02550277869886486, 0.012438796748028835, 0.01059729365806561, 0.03932088380679488, 0.010613547619868768, 0.05435144114017021, 0.02937270219263155, 0.07058774353936315, 0.014057712123758392, 0.0037797715685883304, 0.023242243260028772, 0.052627676996053196, 0.02336427460249979, 0.02361928767641075, 0.08548923025955446, 0.06166021907120012, 0.07597621806780808, 0.0326682015293045, 0.02598184801172465, 0.02899431077821646, 0.008962282954598777, 0.029824373268638737, 0.006267858761930256, 0.051250276883365586, 0.07725505725829862, 0.05660368122335058, 0.04078343052242417, 0.03389478239114396, 0.23536386812338606, 14.110434539616108, 103.30096811056137, 96.85884699225426, 93.14087569713593, 69.78892475366592, 68.48152130842209, 62.19465225934982, 101.9252747297287, 101.98860213160515, 58.69459547102451, 52.570000514388084, 62.09515459835529, 40.870777890086174, 13.81396209821105, 0.9357796458061785, 0.10470254303072579, 0.0445114795002155, 0.0665594104793854, 0.3273524047108367, 0.5583419802132994, 1.8802759051322937, 2.490814793854952, 3.195249969139695, 3.2524651614949107, 0.5508584005292505, 0.3322804137133062, 5.468104183673859, 69.18886095285416, 89.73500445485115, 76.8289589881897, 78.4456430375576, 71.35286763310432, 66.29444986581802, 67.37797692418098, 71.5671381354332, 74.4021812081337, 76.57807365059853, 70.79726904630661, 69.63476702570915, 73.21542888879776, 70.46620041131973, 66.52230083942413, 63.67773547768593, 64.36239033937454, 68.09423089027405, 72.80926868319511, 72.61556267738342, 62.94947035610676, 61.67865514755249, 60.16284428536892, 60.45530319213867, 59.68627765774727, 66.98364928364754, 69.28318709135056, 72.57821828126907, 63.104566633701324, 60.0016987323761, 50.95293648540974, 66.98589116334915, 63.25619749724865, 77.72856831550598, 65.27947872877121, 72.84538954496384, 22.504263930022717, 45.07352337241173, 83.8739937543869, 62.39728018641472, 73.91445457935333, 70.31813755631447, 75.1779855787754, 71.82565346360207, 71.82590425014496, 57.39548698067665, 55.93497075140476, 57.24630318582058, 66.06558054685593, 75.41117146611214, 76.9152295589447, 71.13505572080612, 73.45036268234253, 68.21366608142853, 70.88942170143127, 71.40919581055641, 75.52732363343239, 73.57278451323509, 73.67897361516953, 67.97348096966743, 66.60377606749535, 67.798523157835, 79.8266789317131, 76.98579177260399, 75.68639069795609, 72.3111230134964, 75.35765513777733, 78.56934159994125, 81.97103306651115, 55.170976147055626, 13.165025319904089, 0.4652386636007577, 1.2161501543596387, 1.7235222039744258, 2.8536523366346955, 1.0715350206010044, 0.6461900600697845, 0.21695798233849928, 0.0806285414728336, 0.27700736245606095, 0.05726795905502513, 0.0905304761545267, 0.04032691693282686, 4.1192815359681845, 24.541574008762836, 41.126447170972824, 63.06663326919079, 47.00286604464054, 30.94859831035137, 33.93847167491913, 56.7620799690485, 60.04831463098526, 71.59598618745804, 81.34006932377815, 56.710778921842575, 3.1825641123577952, 0.08109060261631384, 0.031626946074538864, 0.059276667088852264, 0.07524513581302017, 0.05101593633298762, 0.06793238368118182, 0.054599674695055, 0.08797712449450046, 0.05014674039557576, 0.022489835391752422, 0.08162402868038043, 0.014997156977187842, 0.018870550011342857, 0.009909332038660068, 0.013329493631317746, 0.0761305179912597, 0.07028332198387943, 0.06634573874180205, 0.034054299612762406, 0.0464632944931509, 0.02532127906306414, 0.046974971919553354, 0.04652743460610509, 0.07406061617075466, 0.039812656832509674, 0.03642795876658056, 0.015467542234546272, 0.043355751477065496, 0.009807406404434005, 0.15086542727658525, 0.07152230042265728, 0.20918978902045637, 0.12700557243078947, 0.10137598481378518, 0.1387913228245452, 0.11653600609861314, 0.11464916984550655, 0.11999726411886513, 0.2969124756054953, 0.25922615721356124, 0.16973184538073838, 0.09860968129942194, 0.21185225865337998, 0.08669052243931219, 0.2339399984339252, 0.157724742020946, 0.10801102253026329, 0.1590744117856957, 0.1945205425727181, 0.14218400639947504, 0.26983714720699936, 0.14717802201630548, 0.4266710893716663, 22.271594814956188, 121.05242237448692, 105.48800155520439, 103.76783385872841, 84.16318863630295, 74.00668323040009, 65.03734052181244, 93.57571676373482, 79.8968155682087, 51.76229685544968, 69.33898329734802, 99.34849619865417, 55.32038792967796, 18.429138399660587, 1.6446283436380327, 0.2734760456951335, 0.3948649257654324, 0.20533281785901636, 0.7146147103048861, 0.6139676703605801, 3.3409156277775764, 2.736133192665875, 5.9325276128947735, 11.73429474234581, 5.61569538898766, 5.744188344106078, 5.404884601011872, 74.05693173408508, 92.80972346663475, 78.6390070617199, 79.58380356431007, 75.35979822278023, 69.67820629477501, 69.33098092675209, 76.54123842716217, 77.3399555683136, 80.96559181809425, 74.42376405000687, 69.96216505765915, 76.26991018652916, 75.28643175959587, 70.17748430371284, 66.64614379405975, 68.86672183871269, 70.4335069656372, 77.05725833773613, 75.22363632917404, 65.90240970253944, 64.1198493540287, 64.93651673197746, 64.4694609940052, 63.497260361909866, 69.66159358620644, 73.24512049555779, 75.77628627419472, 66.96860209107399, 60.711816027760506, 54.784088507294655, 69.33880090713501, 68.81987035274506, 80.240598320961, 68.89590427279472, 72.39100232720375, 28.08661848306656, 47.73666746914387, 82.76808589696884, 66.43157690763474, 74.31445151567459, 73.62358018755913, 78.53215679526329, 74.5223231613636, 74.35700923204422, 60.98889335989952, 58.61933670938015, 59.176960587501526, 70.67225575447083, 79.89362373948097, 80.75341120362282, 72.1727192401886, 72.22032308578491, 67.38638207316399, 72.05624788999557, 74.01780903339386, 77.82508313655853, 78.31670835614204, 76.43734440207481, 68.92687261104584, 68.32406535744667, 69.20602843165398, 82.63206079602242, 81.20089039206505, 79.2410771548748, 75.49562573432922, 78.99060219526291, 83.78287464380264, 83.09282407164574, 59.50993672013283, 12.142869718372822, 3.8884512847289443, 7.445002729073167, 6.899750987067819, 4.714365229010582, 1.2497383332811296, 0.587889194721356, 0.29194361879490316, 0.31206716084852815, 0.4116116068325937, 0.14913893945049495, 0.39128813019488007, 0.23409703688230366, 7.411088598892093, 36.2034997344017, 52.26906806230545, 63.9955960214138, 57.99790285527706, 44.16822575032711, 33.99424508213997, 65.0629435479641, 73.18417936563492, 83.0652679502964, 91.09165325760841, 67.77738109230995, 3.2391846366226673, 0.22201384854270145, 0.17402482830220833, 0.11427228499087505, 0.1361453882418573, 0.15059216850204393, 0.12922641966724768, 0.18987210060004145, 0.21960728627163917, 0.14649417746113613, 0.19317504367791116, 0.22192342526977882, 0.12425470558810048, 0.14669740718090907, 0.11211905482923612, 0.1561641538864933, 0.18120164866559207, 0.12784216582076624, 0.18015660083619878, 0.11211522534722462, 0.19260758272139356, 0.14805219776462764, 0.0834288056648802, 0.17766320728696883, 0.17506797623354942, 0.14698979852255434, 0.14254207781050354, 0.05349577455490362, 0.16077437525382265, 0.11106892328825779], [0.061207338294479996, 0.06216925074113533, 0.03791870338318404, 0.013221908193372656, 0.033610150203458034, 0.021718051903008018, 0.023210664876387455, 0.08487177081406116, 0.03704152564750984, 0.11263310341746546, 0.014188342174747959, 0.01208342768222792, 0.08230471168644726, 0.031531721106148325, 0.08092792384559289, 0.06396151511580683, 0.03412901161937043, 0.08777109687798657, 0.04571418547129724, 0.03336511530505959, 0.033114837133325636, 0.02761104955425253, 0.1046800114272628, 0.43033676454797387, 60.39242036640644, 95.86644664406776, 83.7827530503273, 73.23065847158432, 67.4796898663044, 31.938684582710266, 24.820556938648224, 37.529286593198776, 24.334336929023266, 38.05498078465462, 53.27156446874142, 30.022969879209995, 5.034445328637958, 0.115515137440525, 0.07167228104663081, 0.03291166307462845, 0.03387700424354989, 0.23615851532667875, 0.04569334225379862, 0.8512810862157494, 0.9886932314839214, 1.216004693415016, 5.621227417141199, 7.417021030560136, 1.3913133926689625, 11.044502556324005, 72.58593946695328, 81.64184153079987, 72.96950608491898, 75.77082216739655, 67.85862073302269, 61.67636387050152, 57.867357060313225, 62.99466513097286, 67.24383652210236, 72.6124620437622, 70.53120732307434, 74.72676739096642, 67.27048069238663, 69.77151408791542, 68.48231926560402, 62.09357388317585, 53.013398721814156, 52.59161375463009, 56.87671601772308, 58.602439016103745, 60.47446936368942, 58.11265669763088, 56.85648590326309, 53.96119326353073, 54.86526735126972, 56.611444652080536, 57.24565342068672, 58.54488730430603, 55.148732140660286, 49.84194450080395, 51.265260726213455, 56.67064167559147, 67.38366141915321, 69.51191201806068, 71.69832989573479, 61.780299693346024, 69.67730194330215, 19.85872618854046, 44.29038539528847, 74.42710027098656, 61.00329838693142, 70.53249925374985, 63.63949812948704, 70.79935133457184, 65.26311680674553, 65.87594792246819, 54.41191367805004, 52.998647913336754, 53.45031067728996, 66.00774765014648, 67.61649012565613, 70.73244452476501, 64.51887354254723, 68.6862163245678, 67.70415142178535, 71.73097774386406, 67.3944528400898, 67.2494526207447, 65.86583286523819, 70.02717956900597, 66.70135483145714, 64.55741107463837, 66.49699419736862, 75.60814529657364, 73.01825746893883, 71.29554390907288, 66.42669796943665, 74.66739937663078, 69.14767876267433, 79.63001668453217, 75.9723025560379, 55.16967661678791, 6.523955902084708, 0.41260715341195464, 1.890094222035259, 3.1544954935088754, 0.50883449614048, 0.22321225376799703, 0.210205017356202, 0.059703669176087715, 0.14470763504505157, 0.08132395611028187, 0.021192917483858764, 0.10501263459445909, 0.157689371262677, 3.74806544277817, 26.259969100356102, 35.743143036961555, 28.85168842971325, 50.29987692832947, 28.488080240786076, 21.93023443222046, 46.787922978401184, 53.58936421573162, 68.4450812637806, 59.96500790119171, 25.676962584257126, 0.7158673368394375, 0.030978880458860658, 0.10214111680397764, 0.017342193350486923, 0.03044740809855284, 0.05247801178484224, 0.05123263974383008, 0.12201798381283879, 0.024214321274484973, 0.08790178166236728, 0.038374905270757154, 0.10413466647150926, 0.014043320024939021, 0.006004187607686617, 0.06413768613128923, 0.02719261741731316, 0.03928231068130117, 0.027369905365048908, 0.015484355590160703, 0.0659610093862284, 0.047986136996769346, 0.021686178515665233, 0.043197269551455975, 0.0061067728256603004, 0.031944986039889045, 0.03794933181779925, 0.039424710266757756, 0.07394947213470004, 0.009478502324782312, 0.10936586506431922, 0.028443607516237535, 0.013896156779082958, 0.08589954144554213, 0.021840908884769306, 0.011216482307645492, 0.01473170281315106, 0.08369055372895673, 0.026272851537214592, 0.0352780862885993, 0.07369940547505394, 0.008513525735907024, 0.03977037296863273, 0.02172783340938622, 0.0791637200745754, 0.034467115547158755, 0.03251760863349773, 0.022935869856155477, 0.05346802936401218, 0.06990119014517404, 0.029171962378313765, 0.10693660049582832, 0.06032917350239586, 0.5732723884284496, 73.72854575514793, 107.38798320293427, 91.99210613965988, 82.86353677511215, 79.49568629264832, 47.18879386782646, 34.20152775943279, 40.332916751503944, 32.51229040324688, 44.925794899463654, 48.01051877439022, 36.76159478724003, 6.067933347076178, 0.19251911871833727, 0.11422639057855122, 0.032131628759088926, 0.12929462303873152, 0.6110894435551018, 0.8301336178556085, 1.9592841155827045, 1.9915613648481667, 1.929973557125777, 1.9366828096099198, 1.1571390833705664, 0.7113903458230197, 11.50481840595603, 77.97591224312782, 83.4819383919239, 77.2596050798893, 80.10217934846878, 71.80084839463234, 62.56352886557579, 61.693443953990936, 64.49670553207397, 71.00463151931763, 75.95692858099937, 74.51065018773079, 74.63255524635315, 68.76705318689346, 73.27517688274384, 72.39913389086723, 65.24020403623581, 54.36832621693611, 55.15856981277466, 60.89012525975704, 63.57625052332878, 61.73425376415253, 61.16260103881359, 60.71253798902035, 55.70110470056534, 57.93399028480053, 58.671690300107, 59.69473980367184, 62.24940352141857, 57.556678131222725, 52.07886926829815, 54.698376506567, 59.39962863922119, 70.6335586309433, 72.91823163628578, 75.1014956831932, 62.61560507118702, 74.91736516356468, 24.904635027050972, 44.790256172418594, 77.99255535006523, 63.38561475276947, 72.19708353281021, 65.96666425466537, 73.87327998876572, 68.60629141330719, 67.49955520033836, 56.2333345413208, 56.001242995262146, 56.44009664654732, 70.19174113869667, 71.48518413305283, 74.08091604709625, 64.28593084216118, 68.85388612747192, 69.59111496806145, 74.4943718612194, 70.68332836031914, 71.06198564171791, 68.64162191748619, 71.02447405457497, 70.8292405307293, 65.51996782422066, 66.97494015097618, 77.65695735812187, 75.14717683196068, 72.10588082671165, 70.11138305068016, 77.51063480973244, 72.4641864001751, 80.93748092651367, 76.42587661743164, 57.96330191195011, 8.76156035810709, 0.2929217694327235, 0.31477104232180864, 1.8938418896868825, 2.495842161588371, 1.0572184575721622, 0.9010606119409204, 0.21838677988853306, 0.14178231154801324, 0.09130023914622143, 0.12442760373232886, 0.12436422432074323, 0.14200829551555216, 3.6888175969943404, 29.48079977184534, 34.17956493794918, 26.513909474015236, 40.66715821623802, 26.36032361537218, 37.19227887690067, 57.2506083548069, 60.34996524453163, 73.7592101097107, 73.8291035592556, 31.596165262162685, 0.7977708138059825, 0.04778323753271252, 0.09717269043903798, 0.07151303099817596, 0.027765807753894478, 0.028134658859926276, 0.012786796287400648, 0.05794674958451651, 0.04221832852635998, 0.05708136457542423, 0.07973409024998546, 0.02697679345146753, 0.0562921907112468, 0.012397759692248655, 0.02360532045713626, 0.020653788014897145, 0.03130152173980605, 0.028949444240424782, 0.03228426256100647, 0.10330968769267201, 0.07922053890069947, 0.04469312756555155, 0.010169039196625818, 0.022517484103445895, 0.016980344407784287, 0.042367915812064894, 0.017738535461830907, 0.030161974391376134, 0.03330093437398318, 0.15276974852895364, 0.16518144111614674, 0.1233119702374097, 0.23347102047409862, 0.24400304595474154, 0.07603746009408496, 0.11125654564239085, 0.27071101125329733, 0.11763549788156524, 0.21777885704068467, 0.16514912800630555, 0.08905476744985208, 0.1673270939500071, 0.18084942537825555, 0.1373965453240089, 0.20447954098926857, 0.15154912340221927, 0.28006094391457736, 0.15097237075679004, 0.18661156384041533, 0.14115724508883432, 0.1821035213652067, 0.16733004769776016, 1.2242250773124397, 89.6342034637928, 119.41195920109749, 104.98898193240166, 95.03008872270584, 90.12690022587776, 48.88238579034805, 35.73492027819157, 50.14862984418869, 37.5077835470438, 55.58737300336361, 74.04959052801132, 45.198513865470886, 10.053001809865236, 0.5793780670501292, 0.2904424915323034, 0.1626022849814035, 0.12340858302195556, 0.7077012781519443, 0.7055805763229728, 3.025369397364557, 2.6350443670526147, 4.935735650360584, 12.904304210096598, 20.76075028628111, 6.043143952265382, 12.671259865164757, 82.79365092515945, 83.86339992284775, 80.33632278442383, 83.15568789839745, 75.61799436807632, 65.86062714457512, 64.44967925548553, 68.25945362448692, 74.22894850373268, 78.77550333738327, 77.00639426708221, 76.5688705444336, 68.9770071208477, 75.56766986846924, 76.76496282219887, 68.27311009168625, 57.464270889759064, 58.75087805092335, 65.18885359168053, 65.50142481923103, 66.11884608864784, 64.54066157341003, 64.77064803242683, 58.98869588971138, 61.5140213817358, 64.49539840221405, 62.99909949302673, 67.33624756336212, 59.15348544716835, 56.093707233667374, 57.09285221993923, 61.758477464318275, 72.48132348060608, 74.90541860461235, 76.40384539961815, 64.57085475325584, 76.74859330058098, 30.572374798357487, 47.51645788550377, 81.37842446565628, 65.14771699905396, 76.19218915700912, 68.42867374420166, 75.8813126385212, 71.04963630437851, 71.49076983332634, 61.26081816852093, 60.03986768424511, 57.322815880179405, 73.65378856658936, 72.4713072180748, 78.19039553403854, 68.12793508172035, 69.578727632761, 72.28165939450264, 77.291249781847, 72.67657220363617, 73.89732509851456, 72.59157076478004, 76.9407793879509, 74.04580593109131, 66.8691386282444, 68.53905782103539, 82.6209881901741, 79.00289833545685, 76.54875442385674, 72.85260155797005, 82.47287973761559, 75.06709232926369, 86.70627817511559, 77.86941915750504, 63.52295458316803, 7.969196476042271, 2.980601149611175, 9.295696746557951, 7.288625445216894, 3.7933936854824424, 1.2195375538431108, 0.5227597989141941, 0.32045093597844243, 0.3167169535299763, 0.3284541971515864, 0.15817152976524085, 0.31649166718125343, 0.2326415220159106, 6.708926176652312, 44.363102093338966, 56.02420516312122, 43.8886633515358, 68.44927623867989, 41.30670189857483, 35.933820605278015, 65.51659360527992, 71.9250637292862, 88.69915723800659, 83.34494814276695, 36.396571174263954, 1.1559930886141956, 0.19699054362718016, 0.15830005489988253, 0.12941160035552457, 0.18954616418341175, 0.15931099362205714, 0.16818034113384783, 0.2762656006962061, 0.09962755168089643, 0.27877310989424586, 0.14922384114470333, 0.21341464278521016, 0.08863561728503555, 0.10820686788065359, 0.2090301233693026, 0.14931568934116513, 0.1578091093688272, 0.10203100435319357, 0.14602353709051386, 0.165211750427261, 0.17652068578172475, 0.1232648735458497, 0.15226633491693065, 0.13746081531280652, 0.07269850058946759, 0.19046198925934732, 0.14786075334995985, 0.17946346459211782, 0.13659636169904843], [0.057050866016652435, 0.030521086664521135, 0.035648384582600556, 0.03348246369569097, 0.07181063963798806, 0.03641594339569565, 0.054056485678302124, 0.06631112497416325, 0.06643536791671067, 0.11341453297063708, 0.00875376636031433, 0.06149771470518317, 0.053599578750436194, 0.062042670033406466, 0.019636932520370465, 0.05290882851113565, 0.020790174348803703, 0.0233319596372894, 0.02483112948539201, 0.01365235755656613, 0.0355421201675199, 0.09000623045722023, 0.1506315023289062, 18.604276701807976, 92.46299967169762, 82.88651794195175, 74.91590604186058, 63.694351986050606, 29.466913416981697, 21.734332144260406, 26.95982314646244, 48.097990080714226, 63.075247406959534, 55.50485663115978, 33.12185749411583, 4.215928874909878, 0.1509951546904631, 0.038174989240360446, 0.1309875657898374, 0.1372720574727282, 0.24165873503079638, 0.5009335919748992, 0.426700240932405, 1.5234724385663867, 1.4080676436424255, 1.9572351942770183, 1.9417196768335998, 1.8406354822218418, 19.681912176311016, 77.81546965241432, 79.03505221009254, 70.91506272554398, 75.55196911096573, 64.72179025411606, 62.64969304203987, 57.26096659898758, 59.880348443984985, 58.984250128269196, 66.25230252742767, 68.26730400323868, 72.3708026111126, 69.11739438772202, 69.22305911779404, 68.99839997291565, 68.83055537939072, 60.11567361652851, 52.694204449653625, 49.886189326643944, 51.94955840706825, 49.43882033228874, 53.01534041762352, 49.0991223603487, 51.15233078598976, 49.04888525605202, 50.956158712506294, 48.329526856541634, 53.5922596603632, 48.31240877509117, 50.56910768151283, 49.530619606375694, 54.88704398274422, 60.687033757567406, 74.16727021336555, 68.91103506088257, 73.02637383341789, 65.52520394325256, 70.03822177648544, 30.313863269984722, 42.260215133428574, 75.31066685914993, 63.366676568984985, 67.88105472922325, 63.32527779042721, 68.75682413578033, 68.87883558869362, 65.92867389321327, 52.399036288261414, 50.836047157645226, 55.3055839240551, 65.65406262874603, 70.39025768637657, 57.00457155704498, 62.706986367702484, 69.64314177632332, 66.62915870547295, 65.32675579190254, 62.11087055504322, 60.036998838186264, 62.20573626458645, 64.35946449637413, 71.17255970835686, 64.73318964242935, 65.43874338269234, 75.42876452207565, 70.25080516934395, 65.43593913316727, 62.4610635638237, 69.80085611343384, 69.70961540937424, 71.77789002656937, 67.96095684170723, 75.22311955690384, 51.75911262631416, 10.51026452332735, 0.900618766900152, 1.0248002596199512, 1.7762469872832298, 1.3155717006884515, 0.2249221471720375, 0.14566604455467314, 0.08057748913415708, 0.16795505478512496, 0.04453458255738951, 0.06883035268401727, 0.2594979020068422, 0.15136510046431795, 8.133135829120874, 45.48490449786186, 53.82757343351841, 61.49313010275364, 42.2391452640295, 19.907745458185673, 38.935830518603325, 53.26302632689476, 55.483695566654205, 62.99092233181, 49.160261079669, 9.51461249962449, 0.3057999908924103, 0.08108125897706486, 0.05474011501064524, 0.02544906390539836, 0.07266284039360471, 0.05884245132619981, 0.06657060206634924, 0.037726791415479966, 0.05061389638285618, 0.05001587749575265, 0.01896648929687217, 0.03293761968961917, 0.03866191233100835, 0.021042688240413554, 0.012018631696264492, 0.0299462840121123, 0.08040612723561935, 0.03515406970109325, 0.04023156208859291, 0.018942020687973127, 0.032487844800925814, 0.05431379941001069, 0.04200938798021525, 0.06234238637262024, 0.03919484115613159, 0.09117662702919915, 0.031174518007901497, 0.04814361331227701, 0.03264946601120755, 0.009578294284438016, 0.07108041827450506, 0.025732508656801656, 0.06330531556159258, 0.06902421650011092, 0.07829528112779371, 0.04753963126859162, 0.005063538619651808, 0.07112490260624327, 0.031418536163982935, 0.059405574429547414, 0.06053275203157682, 0.047068994608707726, 0.03750718620722182, 0.04121288911846932, 0.061046607661410235, 0.05437951287603937, 0.06704297906253487, 0.042569338402245194, 0.08954878547228873, 0.0922497280407697, 0.20927711011609063, 22.848884537816048, 108.16074013710022, 91.78328454494476, 86.41926437616348, 78.50024610757828, 43.262586146593094, 29.155694916844368, 33.446751460433006, 49.98123362660408, 48.351755663752556, 49.21330623328686, 37.29188673198223, 4.663969008252025, 0.13677907845703885, 0.03623692624387331, 0.037170974756008945, 0.18860572949051857, 0.7421474391594529, 1.1029609967954457, 2.2597477678209543, 2.702908725477755, 1.3089785794727504, 2.3834631917998195, 0.5985243490431458, 3.175991652533412, 22.089958861470222, 79.78786781430244, 81.21471405029297, 73.46072092652321, 78.99255529046059, 68.01351562142372, 65.02300009131432, 60.55587239563465, 62.52230867743492, 61.90128520131111, 71.31790190935135, 70.93086987733841, 75.91594398021698, 72.5446204841137, 69.60666373372078, 70.52650317549706, 72.41196200251579, 62.34107360243797, 55.042801424860954, 53.71166065335274, 55.26131249964237, 52.55041256546974, 55.34181497991085, 52.793143540620804, 53.88113535940647, 52.746577039361, 54.853290393948555, 51.64532773196697, 55.635998994112015, 50.70397384464741, 54.64626230299473, 50.77598378062248, 56.356744319200516, 62.886671125888824, 77.077556848526, 70.76200693845749, 76.32609397172928, 66.42596080899239, 74.08238276839256, 32.965974658727646, 44.154124706983566, 78.4936648607254, 65.46028062701225, 70.55348932743073, 68.03402692079544, 70.31089514493942, 71.24772727489471, 68.0890479683876, 55.40521837770939, 53.06137874722481, 57.351705729961395, 69.04829889535904, 72.14996606111526, 60.89791104197502, 64.94348555803299, 71.136834025383, 70.54354906082153, 67.87849366664886, 65.35989761352539, 63.965995609760284, 64.38023418188095, 68.58514174818993, 74.21261698007584, 65.65756604075432, 67.50486731529236, 77.97238603234291, 74.53622281551361, 68.66537064313889, 64.67594191431999, 75.12775227427483, 73.12873274087906, 75.57974562048912, 73.36023151874542, 76.8291337788105, 56.88286788761616, 12.880157455801964, 1.0723828501068056, 0.4231219907524064, 2.1694638999179006, 1.534529726486653, 1.3453767076134682, 0.8644208998885006, 0.3479948564199731, 0.5020602908916771, 0.08999294601380825, 0.1002670603338629, 0.368589335703291, 0.13328645727597177, 8.894177991896868, 45.93793898820877, 50.36757789552212, 61.21571458876133, 37.4265743046999, 29.56736482679844, 46.397246941924095, 59.37153674662113, 62.88540579378605, 70.85940331220627, 63.88654947280884, 13.483190797269344, 0.2690318279201165, 0.05094895379443187, 0.042382124229334295, 0.10982961088302545, 0.07684364769374952, 0.10204782141954638, 0.044791068794438615, 0.08236833600676619, 0.06414524119463749, 0.06224641554581467, 0.014924439492460806, 0.11967028127401136, 0.1189359113050159, 0.034280175968888216, 0.021062050873297267, 0.07789800947648473, 0.06537531386129558, 0.0752426718827337, 0.036594318589777686, 0.04070127848535776, 0.07644242781680077, 0.023784727236488834, 0.034544302616268396, 0.04862173453147989, 0.02812316484778421, 0.04477316077100113, 0.08216006710426882, 0.007936983674881049, 0.25446174724493176, 0.07678754875087179, 0.20480590785155073, 0.08240042647230439, 0.1510734364273958, 0.14226089289877564, 0.1603273203363642, 0.15761183167342097, 0.0986926608311478, 0.17501457128673792, 0.08491331624099985, 0.11493626967421733, 0.15035776857985184, 0.1581489239470102, 0.15511561796301976, 0.212074457667768, 0.1373090609558858, 0.24822458974085748, 0.1688667238340713, 0.12125707464292645, 0.15974831156199798, 0.19821703172056004, 0.5293980427086353, 27.854912616312504, 121.2089055776596, 104.14652913808823, 97.63164192438126, 86.91675648093224, 48.854886665940285, 33.21711078286171, 38.82884345948696, 65.58540791273117, 82.9669064283371, 78.24869200587273, 51.91489666700363, 7.402116805315018, 0.3297976031899452, 0.19770472717937082, 0.24127108161337674, 0.33016618341207504, 1.1390450480394065, 1.8691892875358462, 2.98670647200197, 5.521635236218572, 8.029391895979643, 7.576962523162365, 7.349898582324386, 6.233109533786774, 22.93127741664648, 84.05650556087494, 83.66688206791878, 75.5182421207428, 81.63778334856033, 70.26879340410233, 69.12855818867683, 63.488760218024254, 65.1509240269661, 65.02038583159447, 73.48218217492104, 74.53018873929977, 78.94555941224098, 74.16298404335976, 70.70308730006218, 73.1453986465931, 74.39568355679512, 64.86359104514122, 57.52539061009884, 54.35398578643799, 58.975107818841934, 55.37091761827469, 58.44502866268158, 55.659512132406235, 56.45616598427296, 55.75425624847412, 57.40729294717312, 53.40011157095432, 58.638540878891945, 53.776975348591805, 57.2332014888525, 55.878247395157814, 60.29158517718315, 67.26223513484001, 79.34786662459373, 74.47071433067322, 80.07836982607841, 71.16499051451683, 75.48620223999023, 34.78676475584507, 48.05564135313034, 80.82874596118927, 69.0431159734726, 71.59687533974648, 70.86829483509064, 72.61681661009789, 74.09496769309044, 72.79421389102936, 57.981810718774796, 55.70332758128643, 62.64974623918533, 72.43901655077934, 74.95973289012909, 64.92909952998161, 67.15628921985626, 75.09470164775848, 73.94303664565086, 72.03890562057495, 67.78267040848732, 66.91919714212418, 67.91836872696877, 73.38160917162895, 79.14712339639664, 66.38976395130157, 68.24927017092705, 81.01209372282028, 76.37245148420334, 71.60863190889359, 67.08400189876556, 76.30285441875458, 73.45278695225716, 79.49262365698814, 75.93590050935745, 78.15539181232452, 59.75751243531704, 14.793735723942518, 3.7644831743091345, 7.333015613257885, 6.68743452988565, 4.254142474383116, 1.36742502450943, 0.5810214788652956, 0.4764206917025149, 0.46228835941292346, 0.42071648233104497, 0.16305002267472446, 0.5721192096825689, 0.3206040558870882, 13.73194919899106, 70.04047885537148, 70.77844485640526, 81.49365708231926, 55.85504584014416, 31.00250981748104, 54.41662162542343, 70.2187728881836, 75.52670046687126, 80.62287300825119, 73.64827126264572, 13.378121685236692, 0.4582425858825445, 0.1574276009341702, 0.1736182055901736, 0.14227612176910043, 0.20553036272758618, 0.2148722208221443, 0.21303503424860537, 0.2233880091807805, 0.17068287794245407, 0.11662973192869686, 0.11035318864742294, 0.2325517518329434, 0.2637832408072427, 0.08892996789654717, 0.07292192414752208, 0.2511608228087425, 0.17907778528751805, 0.09368549435748719, 0.098581427737372, 0.16116318642161787, 0.12173425333457999, 0.14283445430919528, 0.10932259043329395, 0.13639084616443142, 0.15645694598788396, 0.13200966641306877, 0.11579574347706512, 0.23261553200427443], [0.00953220598603366, 0.07385222852462903, 0.014510813689412316, 0.021816514490637928, 0.03620088755269535, 0.01673748585744761, 0.03771341420360841, 0.036747816993738525, 0.022318313931464218, 0.09539489794406109, 0.04251492784533184, 0.03650196944363415, 0.05320966549334116, 0.041442453948548064, 0.030194012906576972, 0.024208295035350602, 0.038960329911787994, 0.05487138238095213, 0.056384550989605486, 0.07899853284470737, 0.06166435283375904, 0.03968400553276297, 0.31676186830736697, 45.106380209326744, 90.4294703900814, 76.70174181461334, 63.50422538816929, 35.09066104888916, 57.28479892015457, 33.69498074054718, 36.73837423324585, 40.151123106479645, 46.0581911355257, 42.728695794939995, 5.9998419508337975, 0.04388688430481125, 0.06462301360443234, 0.0721871831046883, 0.14102201093919575, 0.10922742483671755, 1.2109234160743654, 0.7677739171776921, 1.6945438901893795, 2.0914870966225863, 2.0044131064787507, 1.98354427004233, 12.319090012460947, 46.82728126645088, 89.5041972398758, 76.50194853544235, 74.35798197984695, 72.54208981990814, 63.81666362285614, 60.42697571218014, 58.30153316259384, 60.70614293217659, 56.03604152798653, 56.962006241083145, 61.10981047153473, 70.21906927227974, 72.31058344244957, 71.13284423947334, 67.27777630090714, 70.6953889131546, 67.77172699570656, 62.02963091433048, 52.80357778072357, 49.68684822320938, 50.42535379528999, 49.557305574417114, 50.46984180808067, 47.91640542447567, 48.09960499405861, 50.096128061413765, 49.43616807460785, 45.186559706926346, 49.565957710146904, 47.161887511610985, 48.77550512552261, 47.49305114150047, 52.35547162592411, 54.85896348953247, 68.34445506334305, 66.71825632452965, 70.23909419775009, 62.357967495918274, 79.73222360014915, 38.78946617245674, 42.14639604091644, 67.45727106928825, 61.21717371046543, 65.14043658971786, 61.08304850757122, 68.68731826543808, 65.76704576611519, 61.14235192537308, 51.036235615611076, 49.51409809291363, 51.585233956575394, 62.064775228500366, 68.72904002666473, 64.54590529203415, 66.52579665184021, 71.37055188417435, 64.0980613231659, 60.65177544951439, 54.41979445517063, 51.06971561908722, 53.02266642451286, 66.23183682560921, 68.86948049068451, 66.68680921196938, 64.53971922397614, 74.13586109876633, 67.13294327259064, 63.96882265806198, 56.81313022971153, 71.59426108002663, 72.69011467695236, 75.07362797856331, 71.70946329832077, 62.7187505364418, 63.166092932224274, 59.535231962800026, 12.375837117433548, 0.5784099502488971, 1.7211200203746557, 1.7296062712557614, 2.6364139560610056, 0.506441337056458, 0.2990762813715264, 0.08802612108411267, 0.2754468930652365, 0.06984618958085775, 0.18491275812266394, 0.17951341113075614, 0.03383614901395049, 12.100909519940615, 30.010225363075733, 26.946601755917072, 37.13277027010918, 25.90079717338085, 28.195277452468872, 31.72324374318123, 47.89194233715534, 62.57066108286381, 73.5352349281311, 44.19846832752228, 2.908589313738048, 0.2061073380173184, 0.07437475986080244, 0.0077288933516683755, 0.05048066974268295, 0.0016302290691783128, 0.07423015238600783, 0.03579960830393247, 0.06772813721909188, 0.029314836938283406, 0.08604952206951566, 0.033608510057092644, 0.036688649270217866, 0.03924663193174638, 0.05311165004968643, 0.057907645823433995, 0.04841755857341923, 0.047353374466183595, 0.08886114112101495, 0.051617866338347085, 0.03454112622421235, 0.022962798684602603, 0.03221087528800126, 0.02659072637470672, 0.09500518135610037, 0.04847917538427282, 0.03235003910958767, 0.032005797620513476, 0.014134375978755997, 0.04950652670231648, 0.02838846037775511, 0.02175255249312613, 0.049824269808596, 0.0345007237046957, 0.0143101694266079, 0.03823670624115039, 0.02376452412136132, 0.02707936568185687, 0.04893835328402929, 0.015690100262872875, 0.013408064805844333, 0.034368825508863665, 0.0494591145979939, 0.04545152827631682, 0.05566657506278716, 0.03240197831473779, 0.015743369767733384, 0.048050102705019526, 0.0420113917789422, 0.09687766447314061, 0.45052145957015455, 56.18463635444641, 104.05688434839249, 86.49149090051651, 71.79802894592285, 46.13763727247715, 60.3964177519083, 29.403872899711132, 29.377110935747623, 30.981890223920345, 42.99724638462067, 41.39430619776249, 7.407290227711201, 0.08724251703824848, 0.01482085237512365, 0.22631729574641213, 0.37853607384022325, 0.9869684802833945, 2.252135588787496, 1.657551450189203, 1.988449925556779, 1.3531404035165906, 0.9638547361828387, 3.117255116812885, 13.676807507872581, 49.18721683323383, 92.83168628811836, 80.6685845553875, 77.30254277586937, 76.39968082308769, 68.2520592212677, 61.43395587801933, 62.002963945269585, 64.51622128486633, 60.28541050851345, 59.39014434814453, 63.76266852021217, 73.09926152229309, 77.25749999284744, 73.1000442802906, 69.21988248825073, 71.77751004695892, 69.74224045872688, 65.16789391636848, 54.158862456679344, 51.70887932181358, 53.012908548116684, 52.06932798027992, 54.85451392829418, 50.42231395840645, 52.45605982840061, 51.723269149661064, 52.055386528372765, 48.81610594689846, 50.97987323999405, 49.876097068190575, 51.972782760858536, 50.83937577903271, 55.80374479293823, 57.159063667058945, 70.08720114827156, 68.59937578439713, 73.88181433081627, 65.82495465874672, 78.99089857935905, 40.31850412487984, 44.593996703624725, 69.77935686707497, 64.61671069264412, 68.20929631590843, 62.83050253987312, 70.52163183689117, 67.75124609470367, 64.29403960704803, 53.55531804263592, 51.660808101296425, 53.38300108909607, 64.24515143036842, 70.85039019584656, 66.95401847362518, 69.35786068439484, 73.79718527197838, 67.58881241083145, 62.509260177612305, 58.639202043414116, 53.39492864906788, 54.95616987347603, 69.60987836122513, 74.12513807415962, 67.27953940629959, 65.23359999060631, 75.20529851317406, 68.86418357491493, 65.11484876275063, 58.48921649158001, 72.87341684103012, 75.15212416648865, 76.65552109479904, 73.54799464344978, 69.73878264427185, 69.11024317145348, 64.9049936234951, 16.518840305507183, 1.2337556784041226, 0.8646461565513164, 0.3136218711733818, 1.6583900176919997, 1.1137071764096618, 0.734150530770421, 0.6323900911957026, 0.3240787913091481, 0.24223145039286464, 0.29856277455110103, 0.20307478902395815, 0.009714640727906954, 13.114015907049179, 35.266713201999664, 27.318751886487007, 33.06370161473751, 24.884100928902626, 41.67215868830681, 40.99078305065632, 55.02028003334999, 68.38185265660286, 83.87145549058914, 55.40609613060951, 3.3205451583489776, 0.1960049566696398, 0.04546229312836658, 0.01242856624230626, 0.061809550315956585, 0.09728394579724409, 0.060492501652333885, 0.06146425868791994, 0.027727279157261364, 0.04465165635338053, 0.07204286506748758, 0.028407928766682744, 0.014540160991600715, 0.01588613486092072, 0.05924717042944394, 0.012439511992852204, 0.029287095458130352, 0.02131493398337625, 0.03757566046260763, 0.10339994027162902, 0.07162557769333944, 0.053570683230645955, 0.05688945631845854, 0.0070822220459376695, 0.002127460938936565, 0.059928810806013644, 0.06191382577526383, 0.06162513775052503, 0.0590943139832234, 0.2240921143675223, 0.052079845845582895, 0.11104587960289791, 0.20424300368176773, 0.1911000136169605, 0.06350269715767354, 0.1776507985778153, 0.14562394993845373, 0.11980030554695986, 0.11967223312240094, 0.09371556618134491, 0.11666379650705494, 0.05952033643552568, 0.1053246705851052, 0.13753712293691933, 0.0945181617862545, 0.16485497035318986, 0.13410293846391141, 0.1252430459135212, 0.16673297504894435, 0.2516977518098429, 0.890424745157361, 65.1856541633606, 115.59425085783005, 98.3794417977333, 83.18457394838333, 52.100695297122, 70.59245243668556, 46.37025699019432, 50.85830636322498, 59.53208193182945, 68.16567465662956, 65.5260019004345, 10.422765668481588, 0.33026794670149684, 0.18840192089555785, 0.5343139101751149, 1.0056067770347, 1.152267863508314, 3.4897450916469097, 4.79402937926352, 5.72599159553647, 6.859289333224297, 8.152947966009378, 7.326835719868541, 15.027883909642696, 51.820384338498116, 97.65215322375298, 82.57172003388405, 81.39534115791321, 76.81332662701607, 69.6836020052433, 64.84761670231819, 62.89115108549595, 68.34140002727509, 63.74997720122337, 61.993000879883766, 66.74067512154579, 77.24334195256233, 79.97835919260979, 74.90189999341965, 69.46366980671883, 74.3201208114624, 73.73698130249977, 69.79571878910065, 57.77647353708744, 54.23760183155537, 57.48880997300148, 56.057837158441544, 58.3964254707098, 53.788431733846664, 54.20390523970127, 55.41366532444954, 54.95869293808937, 50.355141162872314, 54.971182867884636, 52.2355804592371, 53.315269723534584, 53.095470517873764, 56.85338906943798, 60.141094252467155, 73.28195571899414, 73.00164476037025, 76.49690240621567, 70.52123665809631, 82.03818306326866, 43.93692456185818, 47.171003222465515, 73.44720885157585, 67.64668330550194, 70.6242947280407, 65.1362644135952, 74.21458527445793, 72.53138959407806, 65.86949586868286, 57.006992027163506, 56.0415094345808, 56.51003569364548, 68.03147345781326, 74.50373455882072, 68.99465337395668, 71.39200553297997, 76.49370297789574, 71.78355932235718, 65.69788947701454, 60.177374705672264, 56.44332267343998, 59.20735515654087, 73.9344035089016, 77.67253652215004, 67.8346212208271, 66.25484079122543, 79.5688247680664, 72.63247936964035, 69.95163202285767, 61.267015635967255, 77.87718594074249, 80.45552238821983, 79.36989784240723, 77.99397647380829, 72.97709807753563, 70.85024580359459, 69.15158495306969, 17.914598509669304, 2.8411985049024224, 5.828553792089224, 5.6200941279530525, 7.097862856462598, 1.795438094995916, 0.7684557430911809, 0.4312211670912802, 0.4528245812980458, 0.4109653446357697, 0.2999997208826244, 0.5492437246721238, 0.11893398172105663, 20.81721905618906, 47.76950530707836, 40.45089662075043, 52.350828275084496, 37.0322048664093, 43.09652365744114, 47.02035270631313, 67.9889765381813, 79.76542621850967, 93.65080833435059, 59.99256022274494, 3.4172703931108117, 0.4535368352662772, 0.17293709213845432, 0.08906748043955304, 0.19080898782704026, 0.16196399345062673, 0.14944298251066357, 0.14033053710591048, 0.2503313688794151, 0.31513047928456217, 0.22614204499404877, 0.11352755464031361, 0.07813958596671, 0.171010491612833, 0.12570199003675953, 0.18006089347181842, 0.139676823746413, 0.2216041088104248, 0.25235784763935953, 0.13881342398235574, 0.1262930512893945, 0.1556635752785951, 0.13550752715673298, 0.13191988138714805, 0.1481873873854056, 0.13659483287483454, 0.23456249706214294, 0.12082789806299843], [0.03485147753963247, 0.08303943046485074, 0.06144591279735323, 0.1011322189879138, 0.02817820251948433, 0.012649145519390004, 0.014559921601176029, 0.03007857740158215, 0.013897446260671131, 0.04261735164618585, 0.022208557711564936, 0.044615409860853106, 0.027226570673519745, 0.024802469597489107, 0.014292923769971821, 0.060630507723544724, 0.02210226175520802, 0.13221495930338278, 0.07781846608850174, 0.090925862750737, 0.07283837316208519, 0.14119944360572845, 6.358409710228443, 81.00719958543777, 88.71135458350182, 78.47149685025215, 72.79520943760872, 41.639689430594444, 44.03140649199486, 37.65071667730808, 42.48819150030613, 67.94629722833633, 38.164536505937576, 16.822577007114887, 0.19154041889123619, 0.09613635542336851, 0.1683931445586495, 0.06352082782541402, 0.579450085060671, 0.5144564725924283, 0.6980945623945445, 0.7257422350812703, 1.4168303296901286, 1.649648705497384, 6.6721949726343155, 31.99854277074337, 66.57257214188576, 78.71589213609695, 74.15105268359184, 74.51029300689697, 72.40547955036163, 65.40808662772179, 57.666853219270706, 58.93486797809601, 60.93161903321743, 58.635231256484985, 57.71717011928558, 54.38768617808819, 56.983015313744545, 66.36432811617851, 70.08139505982399, 69.87915471196175, 66.36091589927673, 66.43272444605827, 67.67818361520767, 60.7637782394886, 52.077159360051155, 48.731283098459244, 48.913962095975876, 49.8828949034214, 51.32066175341606, 49.2838304489851, 49.18725863099098, 45.75929917395115, 48.997508212924004, 48.59034866094589, 48.537288308143616, 45.10383054614067, 47.585089802742004, 47.940480932593346, 49.61035452783108, 45.46306326985359, 52.956382781267166, 51.441943645477295, 58.89245845377445, 57.57301725447178, 68.84858161211014, 47.97426111996174, 41.26604028046131, 66.97672605514526, 60.28788037598133, 66.64051249623299, 63.685699850320816, 67.19522953033447, 61.67022719979286, 56.85347646474838, 49.19054925441742, 48.601884841918945, 47.974515706300735, 60.450048074126244, 65.55573910474777, 66.67009010910988, 67.58463263511658, 67.92973771691322, 61.46038345992565, 57.99408785998821, 47.115803584456444, 49.19995374977589, 51.61089777946472, 61.338626593351364, 66.1945304274559, 64.43450286984444, 61.633543968200684, 71.86330184340477, 67.30654075741768, 62.3963188380003, 53.22322726249695, 61.53044790029526, 68.75669494271278, 71.95582687854767, 70.73000505566597, 75.05180954933167, 63.0187102407217, 57.87043109536171, 61.33010745048523, 27.0834856107831, 1.8543244851753116, 1.2934889481402934, 2.5533625250682235, 1.4213143265806139, 0.3366811713203788, 0.4433928639627993, 0.04493514934438281, 0.014190916499501327, 0.03731682532816194, 0.04701352649135515, 0.05755315156420693, 0.6685421231668442, 23.676565624773502, 55.553307831287384, 51.3045734167099, 42.09626913070679, 13.608965948224068, 26.491207592189312, 43.435856848955154, 58.038887456059456, 59.84476715326309, 65.3717377781868, 27.229509875178337, 0.775215164758265, 0.04112159753276501, 0.02799400332150981, 0.03888661980454344, 0.04367268564237747, 0.03220242964744102, 0.06160167104098946, 0.04185970792605076, 0.021657902689184994, 0.05927922007685993, 0.038725169288227335, 0.06653370990534313, 0.021986661122355144, 0.01671703597821761, 0.03571095505321864, 0.04278255742974579, 0.08639944469905458, 0.021143592493899632, 0.02975573945150245, 0.020657135100918822, 0.026160184243053664, 0.08174559246981516, 0.06854029910755344, 0.06441222882131115, 0.017792504440876655, 0.04072821102454327, 0.04340334911830723, 0.045583871760754846, 0.07450187491485849, 0.10105697263497859, 0.05224522974458523, 0.019965243809565436, 0.02239280700450763, 0.04992429276171606, 0.039658104578848, 0.02931069760961691, 0.01217697725223843, 0.07690137936151586, 0.05830078000144567, 0.11763850357965566, 0.02351071518205572, 0.0658293227024842, 0.046196640832931735, 0.031762692306074314, 0.08570021542254835, 0.12250708881765604, 0.10492476430954412, 0.13561785483034328, 0.24301682075019926, 8.693784344941378, 96.43846794962883, 98.8420669734478, 87.16213971376419, 79.69545677304268, 45.72265014052391, 65.60021191835403, 54.52681191265583, 33.33471067249775, 59.022700265049934, 38.73347617685795, 20.728212632238865, 0.09218418155796826, 0.19971710513345897, 0.4310995736159384, 0.8466049621347338, 1.4720993139781058, 2.2563799610361457, 1.803061910904944, 1.2048627412877977, 1.1179679352790117, 1.6502437298186123, 8.606170546263456, 36.70101463794708, 69.97197613120079, 84.8350989818573, 74.37055930495262, 77.86856040358543, 73.41626331210136, 69.33604225516319, 62.43810899555683, 61.0814867913723, 61.613359451293945, 60.96299774944782, 60.953961834311485, 59.699804931879044, 59.961048513650894, 69.87327262759209, 73.59418496489525, 71.73217847943306, 66.97070717811584, 68.62030506134033, 69.92767810821533, 64.67076659202576, 53.82217772305012, 51.23682305216789, 51.06752313673496, 51.554672196507454, 53.212318047881126, 52.1284756064415, 51.441616863012314, 49.15568992495537, 51.34245738387108, 51.69639319181442, 51.693334355950356, 49.03155818581581, 49.924863651394844, 50.927227064967155, 50.99141702055931, 49.65176850557327, 54.862303510308266, 54.55846041440964, 62.331471517682076, 60.329662933945656, 73.44610691070557, 51.11869879066944, 44.23090718686581, 71.79736778140068, 62.8082737326622, 69.27282884716988, 65.83152830600739, 71.22935146093369, 65.6476865708828, 59.997382164001465, 51.59104384481907, 49.92384150624275, 50.59559226036072, 62.17087313532829, 68.24354767799377, 69.76902902126312, 68.01736861467361, 69.76761549711227, 63.60905796289444, 59.63636353611946, 50.59773914515972, 53.059034273028374, 55.80292783677578, 63.98078441619873, 69.99984383583069, 65.86749717593193, 61.990375220775604, 74.8962838947773, 69.7442315518856, 66.38749167323112, 54.62470605969429, 65.91760888695717, 71.32623106241226, 75.0206284224987, 72.06320911645889, 76.60699009895325, 66.29152402281761, 64.18726533651352, 65.89386776089668, 31.308809481561184, 2.7483015647158027, 0.1788031609612517, 1.2029417068697512, 0.5089024174958467, 2.0573801267892122, 1.0176428686827421, 0.5436610523611307, 0.39132033940404654, 0.30760293477214873, 0.048471457048435695, 0.0920847115048673, 0.4351038462482393, 26.13704189658165, 59.52584266662598, 45.36446616053581, 38.228737860918045, 22.43399240076542, 32.14525669813156, 52.02252969145775, 64.1432636976242, 68.79622042179108, 79.61164087057114, 37.75996841490269, 1.0798767604865134, 0.06490206113085151, 0.06012842626660131, 0.026882457204919774, 0.016840462558320723, 0.042598074360284954, 0.05796824589197058, 0.05824849198688753, 0.05581982484727632, 0.045149329453124665, 0.05060830058937427, 0.0661010600742884, 0.019459939576336183, 0.043345951416995376, 0.06095564633142203, 0.004630246367014479, 0.10696275377995335, 0.05087541438115295, 0.011651080276351422, 0.018356744476477616, 0.028654006382566877, 0.05735163991630543, 0.027727811648219358, 0.03315926580398809, 0.013668513183802133, 0.04205254757835064, 0.03514808056934271, 0.08216446061851457, 0.2318602631567046, 0.1569927914533764, 0.1879067748086527, 0.06408916451619007, 0.11094232031609863, 0.11746543474146165, 0.1740059777512215, 0.06723460901412182, 0.08668586917337961, 0.09915151589666493, 0.14572455547749996, 0.1745875395135954, 0.18886310630477965, 0.13929809094406664, 0.11056708302930929, 0.09732183985761367, 0.30643877224065363, 0.22356076631695032, 0.2594165626214817, 0.2743333450052887, 0.5422801233362406, 10.895082224160433, 110.04536300897598, 108.91934663057327, 99.81142535805702, 93.54518920183182, 59.43249687552452, 53.38946454226971, 46.70659974217415, 61.66180305182934, 91.6813588142395, 58.48373718559742, 26.315978094935417, 0.43874054797925055, 0.4474758933065459, 0.8257629023864865, 1.7323918780311942, 2.6169105526059866, 3.6358657758682966, 3.3412533346563578, 3.0639853002503514, 5.101368287578225, 5.957852778956294, 8.898461312055588, 34.04002882540226, 72.01735317707062, 86.08239725232124, 76.76313132047653, 81.47409573197365, 76.69386863708496, 72.18688488006592, 64.70782220363617, 65.33566251397133, 64.59964200854301, 64.35404598712921, 64.31743875145912, 62.89166025817394, 62.88311071693897, 71.72187343239784, 74.80774104595184, 73.4553936123848, 68.8885098695755, 70.19111037254333, 73.0908639729023, 67.43371233344078, 57.36578017473221, 53.541133403778076, 54.3328171223402, 54.37219820916653, 57.287819758057594, 54.466326758265495, 52.46465876698494, 51.568666845560074, 53.11761572957039, 54.53212022781372, 54.60655063390732, 50.842503011226654, 52.135471031069756, 54.4245669990778, 53.25559012591839, 50.817473754286766, 58.52803520858288, 57.89882317185402, 64.80570495128632, 64.41719099879265, 75.7833842933178, 53.52998100221157, 50.244118720293045, 72.08294525742531, 65.97042605280876, 71.0779219865799, 69.062160551548, 73.76908957958221, 68.98505508899689, 62.44994916021824, 55.276382490992546, 53.936790972948074, 52.80383996665478, 66.37939810752869, 72.83612564206123, 73.48444685339928, 70.61875462532043, 72.57288336753845, 67.45257452130318, 62.85995855927467, 51.860962361097336, 56.0637154430151, 58.21983374655247, 67.56957024335861, 73.88730883598328, 66.56174272298813, 62.9264397919178, 79.56994190812111, 74.01445001363754, 68.21959376335144, 58.560721054673195, 69.07717734575272, 74.75617781281471, 78.96790981292725, 76.19608014822006, 80.71624159812927, 70.72005718946457, 68.92893970012665, 68.36474597454071, 32.05754600465298, 2.8294830210506916, 4.75142796523869, 9.687323682010174, 6.508308341726661, 2.326850504614413, 0.9669551916886121, 1.2756157759577036, 0.5274118180386722, 0.5386386718600988, 0.2544535242486745, 0.3119482391048223, 1.2383692245930433, 38.246144726872444, 80.32373026013374, 70.52615359425545, 55.98771572113037, 21.13595735281706, 39.80254881083965, 60.64979575574398, 74.35469135642052, 76.80044531822205, 89.76999297738075, 41.006069630384445, 1.197434733621776, 0.11057816329412162, 0.11979400471318513, 0.12676492362516, 0.1744988380232826, 0.2173394017154351, 0.14177109027514234, 0.15678674157243222, 0.23059859726345167, 0.166164044640027, 0.09535030971164815, 0.10579633511952125, 0.11345157356117852, 0.16013238782761618, 0.11918956995941699, 0.24543453007936478, 0.22053160151699558, 0.11386025944375433, 0.11769855816964991, 0.14168275985866785, 0.1593025034526363, 0.20449521514819935, 0.12872446066467091, 0.23600438609719276, 0.09463594062253833, 0.10430728259962052, 0.12034820349072106], [0.03581366087018978, 0.050639741675695404, 0.07557107965112664, 0.03940239017538261, 0.08385190405533649, 0.04453541747352574, 0.021810196958540473, 0.08811943873297423, 0.026660822222766, 0.04103325598407537, 0.06328971561742947, 0.08076799102127552, 0.06761934579117224, 0.04657105804653838, 0.05028915482398588, 0.03214109856344294, 0.02675270752661163, 0.018071149352181237, 0.035812440037261695, 0.10544045304413885, 0.12120746207074262, 0.25219389237463474, 25.791499838232994, 89.26042512059212, 81.38202667236328, 84.12865608930588, 56.819863468408585, 29.132985435426235, 15.602173693478107, 25.157323367893696, 50.405306071043015, 41.667344346642494, 24.827983640134335, 1.2539786682464182, 0.04165978818491567, 0.08045428519835696, 0.6435093039181083, 0.9318384260404855, 0.6347178819123656, 1.5360310021787882, 1.3911268464289606, 0.38606531044933945, 1.1208918783813715, 15.385355427861214, 55.59320569038391, 79.68809276819229, 71.72395572066307, 76.4802061021328, 78.88021051883698, 72.31208816170692, 64.81334254145622, 58.40489901602268, 56.843866780400276, 60.138065814971924, 62.793614119291306, 60.44527553021908, 56.92691892385483, 53.664820566773415, 55.91115362942219, 63.971269726753235, 67.54069179296494, 70.01518741250038, 63.6133973300457, 63.99656876921654, 65.96530392765999, 61.22908607125282, 50.54378964006901, 47.7897772192955, 50.98825938999653, 54.58701208233833, 57.530387341976166, 56.81648924946785, 52.70785711705685, 47.70034521818161, 54.53323356807232, 49.28787723183632, 47.4664031714201, 47.30575539171696, 47.426414117217064, 47.91228264570236, 50.93331053853035, 46.84726059436798, 50.20362809300423, 47.90171541273594, 53.49470369517803, 56.9327250123024, 71.77160516381264, 50.604764968156815, 41.02175898849964, 66.28605991601944, 59.46983367204666, 65.84664389491081, 63.74859407544136, 64.68800246715546, 55.244122222065926, 51.77504897117615, 47.37051911652088, 48.34411047399044, 46.46473132073879, 49.981811195611954, 57.128167524933815, 65.61620905995369, 61.15316994488239, 62.401402965188026, 54.91058371961117, 51.5515411645174, 50.1579849421978, 49.244354367256165, 49.36977803707123, 59.98035907745361, 67.47203707695007, 64.76594388484955, 58.9045874029398, 70.12131571769714, 66.22116699814796, 64.20408323407173, 56.2389050424099, 54.903755486011505, 62.44037367403507, 72.09090203046799, 68.16789373755455, 67.11734890937805, 65.71638688445091, 64.58238333463669, 61.93371646106243, 70.13170436024666, 55.35151205956936, 10.914097353816032, 0.7718221843242645, 0.5132704018615186, 1.7216134001500905, 1.3459171098656952, 0.09625772625440732, 0.12605072523001581, 0.621518874540925, 0.04386743632494472, 0.0537277216790244, 0.06505331824882887, 2.8491246420890093, 27.06837572157383, 35.76362393796444, 36.50871455669403, 22.49604307115078, 24.088486321270466, 47.105582132935524, 56.851652562618256, 68.06527644395828, 65.56616574525833, 68.62521439790726, 14.967450052499771, 0.19797587825451046, 0.04798185851541348, 0.08306159099447541, 0.030483031187031884, 0.05609419313259423, 0.029605410018120892, 0.04755315319926012, 0.035009655184694566, 0.039140326698543504, 0.0353950970020378, 0.01301271624470246, 0.03714006059453823, 0.08432218077359721, 0.048059271939564496, 0.022117989719845355, 0.04252734397596214, 0.10055318794911727, 0.011425175162003143, 0.05976129323244095, 0.02022273936745478, 0.02995596903929254, 0.01890330655442085, 0.04911948926746845, 0.032564976208959706, 0.030100533840595745, 0.06297730855294503, 0.04747960265376605, 0.08463801656034775, 0.049802057328633964, 0.018261551049363334, 0.04394887218950316, 0.0338054946041666, 0.0797872206021566, 0.07107586148777045, 0.04007232317235321, 0.041124050330836326, 0.02084750340145547, 0.022431957149819937, 0.08106472392682917, 0.012822406388295349, 0.007214598463178845, 0.06334616336971521, 0.04048175491334405, 0.060016350835212506, 0.03242652855988126, 0.09560218721162528, 0.10204006597632542, 0.2108087544911541, 35.07733516395092, 103.40059116482735, 90.27841329574585, 91.61547794938087, 67.79226869344711, 44.86751362681389, 23.370587043464184, 27.67415251582861, 41.441431269049644, 40.7257092744112, 30.415479317307472, 1.3582003070041537, 0.06188126033521257, 0.20276485331123695, 0.9670694230590016, 3.093939092941582, 2.325266939587891, 2.4177494645118713, 1.9127793610095978, 0.3706026042345911, 1.3939579320140183, 18.43744095414877, 61.13630644977093, 82.86137089133263, 74.68952178955078, 77.20963776111603, 82.64170467853546, 76.70714512467384, 67.52768889069557, 61.777377650141716, 60.58081805706024, 62.88972236216068, 64.91464510560036, 64.58185896277428, 59.32679794728756, 55.38590021431446, 58.91927741467953, 67.87163883447647, 70.62917366623878, 71.50481387972832, 64.02648076415062, 67.1434535086155, 70.61077505350113, 65.43556675314903, 54.51973669230938, 49.74372737109661, 53.66910673677921, 58.17323684692383, 59.878589138388634, 60.955838933587074, 55.75568497180939, 50.10347306728363, 54.73243407905102, 51.17333605885506, 49.74812753498554, 49.152900874614716, 49.546115174889565, 50.294523015618324, 52.26016514003277, 49.331882670521736, 50.80897741019726, 49.62445177137852, 54.85952965915203, 58.33019882440567, 74.45933014154434, 53.15151751041412, 45.660132095217705, 68.85293617844582, 60.99142022430897, 68.38358536362648, 64.79460194706917, 66.58825010061264, 56.30504049360752, 55.37593714892864, 50.571828335523605, 50.570023432374, 49.38181199133396, 52.634350061416626, 61.52644671499729, 66.52736976742744, 65.50314232707024, 64.32263687252998, 56.96072190999985, 52.91886739432812, 52.30800837278366, 52.12975233793259, 51.6546106338501, 62.24495016038418, 71.34184822440147, 65.46983331441879, 60.965684205293655, 72.45692119002342, 70.0189720094204, 67.81863927841187, 60.55093266069889, 55.674965903162956, 64.09003615379333, 73.56032118201256, 71.0304245352745, 70.19972071051598, 68.61743241548538, 67.00143992900848, 66.28913775086403, 75.11073678731918, 61.39100298285484, 14.062722399830818, 0.10504187521291897, 0.5184116447344422, 1.1635830625891685, 2.159213712438941, 0.8625899325124919, 0.6545421306509525, 0.9503548324573785, 0.1196081264060922, 0.034577031328808516, 0.14434929646085948, 2.914731209166348, 30.88675282895565, 37.179804146289825, 31.336823478341103, 21.52276709675789, 34.568865448236465, 59.024356976151466, 65.473952293396, 74.1867707669735, 72.6725672185421, 80.33450648188591, 21.059805639088154, 0.15250766649842262, 0.027302874586894177, 0.04855681516346522, 0.012117921778553864, 0.020402559894137084, 0.014423521352000535, 0.022536371761816554, 0.027586130090639926, 0.05709344302886166, 0.05764002366049681, 0.06093556010455359, 0.06889359108754434, 0.02038086506217951, 0.12433956275344826, 0.06829084843047895, 0.014305372369562974, 0.08813754713628441, 0.035515480776666664, 0.013955651975265937, 0.08701559796463698, 0.06569728720933199, 0.052033769607078284, 0.029926915813121013, 0.028566787332238164, 0.022360916918842122, 0.035899449430871755, 0.11381147065549158, 0.19632747920695692, 0.13963763834908605, 0.09380014133057557, 0.2283782250015065, 0.1891810423694551, 0.2497456659330055, 0.2328280237270519, 0.1362504466669634, 0.14482792234048247, 0.1285156945232302, 0.14868986589135602, 0.2143413625890389, 0.0930501268885564, 0.10531268490012735, 0.1219158420281019, 0.08883809743565507, 0.1964228303404525, 0.21360389044275507, 0.2490322245284915, 0.23265213472768664, 0.4287037724861875, 42.65448197722435, 115.0386218726635, 98.88704136013985, 105.89445054531097, 76.61778911948204, 46.03742524981499, 28.496310599148273, 35.87613210082054, 67.61446863412857, 61.565098240971565, 37.96258494257927, 2.709650038741529, 0.15123259741812944, 0.30300153011921793, 2.1396934473887086, 5.49375613220036, 2.705853092484176, 5.246721412986517, 4.985510129481554, 3.5342340543866158, 4.088833294808865, 16.827889122068882, 63.95654931664467, 88.4685780107975, 79.02011141180992, 81.17062121629715, 85.94346910715103, 79.01249662041664, 70.87642639875412, 63.283411636948586, 62.24689945578575, 66.18826076388359, 69.1744065284729, 68.47560122609138, 61.758355870842934, 58.42715062201023, 61.36248171329498, 71.52762025594711, 73.28819498419762, 72.83432453870773, 63.855246752500534, 68.70098993182182, 73.3012130856514, 68.27756345272064, 57.7812384814024, 52.337680980563164, 56.04570060968399, 62.20779575407505, 62.684305384755135, 62.96664163470268, 57.46864825487137, 52.125112786889076, 57.35314965248108, 52.49036818742752, 52.79895722866058, 52.50992573797703, 51.91025331616402, 53.832372575998306, 55.78119680285454, 53.58576200902462, 53.025231286883354, 53.49781192839146, 58.481297716498375, 64.16819795966148, 77.35803499817848, 56.84115372598171, 50.00624008476734, 72.02744543552399, 64.60680082440376, 71.34959980845451, 69.55307900905609, 68.7305523455143, 59.19617995619774, 56.92837044596672, 52.98939920961857, 53.788465932011604, 51.53881184756756, 53.965878412127495, 63.468404710292816, 72.51005753874779, 69.06325489282608, 67.87130445241928, 61.630800515413284, 58.18098463118076, 55.34105122089386, 54.78169463574886, 54.047239646315575, 64.22212466597557, 74.79979187250137, 67.97881588339806, 59.83188584446907, 76.48563221096992, 74.21569481492043, 70.26898339390755, 62.49367721378803, 59.80308338999748, 68.77208411693573, 77.77141481637955, 74.33390647172928, 74.27512362599373, 71.13867312669754, 70.96649676561356, 66.77535966038704, 78.08193415403366, 61.11419543623924, 12.53283804282546, 1.766299121081829, 6.046986021101475, 6.107310634106398, 4.439829960465431, 0.6688379729166627, 0.7362469495274127, 1.764734792523086, 0.28539885592181236, 0.1599431995418854, 0.27721454040147364, 5.42075777426362, 41.665535643696785, 54.09483589231968, 51.28567323088646, 32.710818350315094, 38.127834275364876, 62.866152226924896, 75.5785296857357, 86.61873087286949, 81.541967689991, 88.46745327115059, 23.91731120646, 0.21250853984383866, 0.09095045752474107, 0.1541914214612916, 0.11991082617896609, 0.26707377517595887, 0.08117492543533444, 0.15559090417809784, 0.20218910998664796, 0.11640808210358955, 0.11852203038870357, 0.15271727868821472, 0.17696866096230224, 0.21734579902840778, 0.30402738600969315, 0.145189615432173, 0.1109212359006051, 0.2477647698833607, 0.1174955436727032, 0.1115707190183457, 0.13346844672923908, 0.18666611169464886, 0.0897306264960207, 0.1381832515471615, 0.1065393140015658, 0.18456510646501556, 0.14379967673448846], [0.06490286265034229, 0.04868095420533791, 0.10303369039320387, 0.0719406787538901, 0.05565701620071195, 0.025497531714790966, 0.05027828236052301, 0.03719956228451338, 0.01707557308691321, 0.05165022397704888, 0.014601570001104847, 0.0621281802887097, 0.029963665110699367, 0.01066728375008097, 0.04626940470188856, 0.013872297658963362, 0.10876641754293814, 0.030021615712030325, 0.06198953225975856, 0.07011391935520805, 0.14158249570755288, 1.2008330575190485, 69.67420130968094, 83.513742685318, 77.44780138134956, 72.47494742274284, 48.47929202020168, 21.421977505087852, 32.979866713285446, 60.28914950788021, 53.219237476587296, 43.527937307953835, 8.689958900213242, 0.1044952760275919, 0.24219924118369818, 0.45690054539591074, 0.3497509559383616, 0.805882012937218, 1.3984752958640456, 0.8730505930725485, 0.38643772015348077, 1.0360455187037587, 14.925270415842533, 64.31521967053413, 77.2410848736763, 74.93619695305824, 76.75270467996597, 76.34499415755272, 71.10703602433205, 66.74800112843513, 58.54887709021568, 57.1807225048542, 62.323727533221245, 63.68787333369255, 65.3135097026825, 60.30837267637253, 58.71664188802242, 50.79831138253212, 57.026260793209076, 62.94336788356304, 67.74412527680397, 70.65758854150772, 61.861174553632736, 63.333242163062096, 67.3903338611126, 59.25476901233196, 50.73152616620064, 47.14878961443901, 53.3010508865118, 62.22059726715088, 64.717967659235, 59.97813239693642, 56.90140329301357, 49.768942818045616, 51.54632784426212, 46.04934521019459, 48.48427355289459, 47.85721220076084, 54.36638072133064, 58.563259318470955, 61.40176020562649, 55.94936817884445, 58.84823262691498, 55.87439440190792, 63.91645386815071, 59.013679549098015, 69.23898786306381, 47.6916778832674, 37.587400674819946, 66.83785110712051, 57.4233128875494, 67.3736983537674, 61.25570744276047, 61.133019626140594, 53.13783444464207, 52.102473601698875, 45.14281265437603, 47.267430648207664, 45.64857691526413, 48.21196876466274, 47.706284299492836, 51.850516721606255, 51.49636052548885, 51.0889045894146, 47.86325387656689, 49.10599619150162, 46.92927539348602, 49.093662053346634, 47.48873457312584, 58.550362810492516, 63.594835326075554, 66.70789808034897, 60.01036986708641, 67.76055559515953, 66.31155654788017, 65.33519133925438, 60.387115851044655, 58.7501522898674, 53.20223718881607, 62.20814533531666, 66.66884377598763, 73.51665392518044, 65.50470024347305, 67.02305316925049, 69.56785261631012, 68.57099130749702, 70.0524254143238, 76.00615873932838, 18.75303491950035, 0.16031881532398984, 2.8176457062363625, 1.5398736647330225, 0.15012912772363052, 0.5338211241178215, 0.5243095813784748, 0.07830368966097012, 0.1008201829972677, 0.05054157409176696, 0.10800820236909203, 15.608234368264675, 32.12220333516598, 37.12563805282116, 45.18561355769634, 16.096584163606167, 24.654792733490467, 41.90038204193115, 53.92614774405956, 57.972197234630585, 66.75865575671196, 55.91319032013416, 5.2683892752975225, 0.1233651302754879, 0.025141209916910157, 0.01173294658656232, 0.008845083921187324, 0.036797667053178884, 0.08860358619131148, 0.03320418058137875, 0.052932814724044874, 0.027296757434669416, 0.019397296746319626, 0.06419832701794803, 0.05311104148859158, 0.015236667513818247, 0.023180142197816167, 0.039296077520702966, 0.05394618769059889, 0.05572981717705261, 0.08011078214622103, 0.013772191214229679, 0.007378580166914617, 0.027935520229220856, 0.04942139123158995, 0.038229488854995, 0.026856955155381, 0.05827773631608579, 0.024379848036915064, 0.025158639255096205, 0.03688159653393086, 0.054894871354917996, 0.05366944082197733, 0.01257550684385933, 0.05525631582713686, 0.014923341113899369, 0.011369576241122559, 0.009735745552461594, 0.045186436836957, 0.07181696273619309, 0.047158193337963894, 0.00877848544405424, 0.029483113357855473, 0.03312603243102785, 0.13118128117639571, 0.02941099701274652, 0.03343475102155935, 0.04925630048091989, 0.09649282379541546, 2.402992956340313, 86.26470386981964, 90.51527738571167, 86.66089341044426, 78.80483776330948, 57.10438460111618, 30.524651259183884, 35.568542405962944, 46.72804579138756, 48.64963307976723, 49.671364054083824, 9.684211649000645, 0.06427951797377318, 0.08100884762825444, 0.5973609583452344, 1.4341486128978431, 1.6786500555463135, 2.6091171707957983, 3.170965234749019, 1.9218818913213909, 0.9835680190008134, 18.883784003555775, 66.09193593263626, 82.0092286169529, 76.68537989258766, 80.18955945968628, 80.17999157309532, 74.06925827264786, 69.70336854457855, 61.08363747596741, 59.22669231891632, 65.20362719893456, 66.64137125015259, 68.21543678641319, 63.17262478172779, 62.35045529901981, 53.12748000025749, 58.87606993317604, 66.68884590268135, 70.23989215493202, 71.55639231204987, 62.65607289969921, 65.85533022880554, 70.57230591773987, 61.66944444179535, 54.002314656972885, 49.55865450203419, 55.36140292882919, 65.44628977775574, 68.4120686352253, 63.33103448152542, 59.47143338620663, 51.821482479572296, 53.758838921785355, 48.174145594239235, 50.92634931206703, 50.078284218907356, 57.97665819525719, 59.07679796218872, 65.46094939112663, 59.94415462017059, 63.46748895943165, 57.64362506568432, 66.93641021847725, 60.64516380429268, 73.66332605481148, 48.55863556265831, 41.9403824955225, 70.78298181295395, 59.396235421299934, 69.75067600607872, 64.09113809466362, 64.77694809436798, 56.217816174030304, 54.23103578388691, 46.62072815001011, 50.23652672767639, 47.450527623295784, 49.96028155088425, 49.267464727163315, 53.843973353505135, 54.721730053424835, 53.02571386098862, 50.56764855980873, 50.24576783180237, 49.491132125258446, 51.16630643606186, 50.05716875195503, 62.428206726908684, 68.77224370837212, 68.97754669189453, 61.03868588805199, 69.71418276429176, 66.69681027531624, 68.59835743904114, 63.63062180578709, 61.252755001187325, 57.43397131562233, 64.64849978685379, 70.99044308066368, 76.05117112398148, 70.54209753870964, 68.14633369445801, 72.43574872612953, 73.00947993993759, 72.46569871902466, 78.70913609862328, 23.732555620372295, 0.1719092027633451, 0.14629312965553254, 0.37894668930675834, 1.131979445926845, 1.1710874224081635, 0.9247760300058872, 0.28381181764416397, 0.20338251313660294, 0.1981379633070901, 0.03924681746866554, 16.40337400138378, 38.02807442843914, 35.56544177234173, 40.71408569812775, 28.775111138820648, 39.937171787023544, 51.60461291670799, 61.05079963803291, 66.94026321172714, 74.5143435895443, 69.49922069907188, 8.061602767556906, 0.1933890048530884, 0.0385782203375129, 0.10370936390245333, 0.040072983683785424, 0.09151037083938718, 0.04257842600054573, 0.05506755056558177, 0.037177216217969544, 0.11000463156960905, 0.010285015541739995, 0.03148138493997976, 0.041885397367877886, 0.05622807286272291, 0.03385077303391881, 0.013770552923233481, 0.01615843255422078, 0.052249916407163255, 0.04927624198899139, 0.02323547116247937, 0.0437330556451343, 0.031530552223557606, 0.019707282554008998, 0.020311164407758042, 0.02204806085501332, 0.037355402164394036, 0.10271701597957872, 0.19263560621766374, 0.17508796969195828, 0.20818812714423984, 0.10894134175032377, 0.08198270123102702, 0.1303797765285708, 0.10848046804312617, 0.11170345955179073, 0.18600000446895137, 0.12258629823918454, 0.23589070391608402, 0.08796829293714836, 0.07808445181581192, 0.15766599361086264, 0.1818142322008498, 0.25562270369846374, 0.15312102186726406, 0.09775118713150732, 0.27892899059224874, 0.298958903294988, 3.0318257259204984, 99.62143555283546, 101.51177331805229, 97.36071646213531, 90.08125707507133, 66.60406485199928, 35.77880032360554, 44.74367067217827, 84.25005957484245, 76.48196160793304, 67.43234440684319, 13.371289651840925, 0.1926614626427181, 0.4790585220325738, 1.9482189905829728, 3.4424442797899246, 2.886336757801473, 4.7177807707339525, 4.514897307381034, 5.794853400439024, 3.4898776095360518, 18.409901931881905, 70.6308151781559, 84.3589237332344, 79.2687776684761, 82.55399778485298, 83.85276809334755, 77.90992498397827, 71.95930749177933, 61.69243320822716, 62.13184542953968, 68.86401638388634, 68.84916678071022, 71.5405547618866, 65.54377734661102, 64.73544672131538, 55.957431346178055, 61.94068528711796, 69.61152747273445, 74.08072605729103, 74.22976925969124, 63.551335260272026, 68.75663414597511, 74.250827729702, 65.9716647863388, 57.18786992132664, 52.583189606666565, 59.34933453798294, 69.40672606229782, 71.04552492499352, 66.09379023313522, 62.47625894844532, 54.714442044496536, 57.69890829920769, 50.836525931954384, 52.54890784621239, 53.85023921728134, 59.33519549667835, 63.95355507731438, 69.05973628163338, 62.606424763798714, 64.64555114507675, 61.7289986461401, 70.32111659646034, 63.75467374920845, 76.58557444810867, 55.32204084098339, 46.19994252920151, 72.29870527982712, 63.17432329058647, 71.10559970140457, 66.97690844535828, 67.18966662883759, 59.414493441581726, 56.34431518614292, 50.94473272562027, 52.826973125338554, 50.69411717355251, 52.491048350930214, 54.21287655830383, 56.57012186944485, 57.65147164463997, 54.013394862413406, 54.11986134946346, 53.18939007818699, 52.281797379255295, 55.190225914120674, 51.333459466695786, 64.35837015509605, 73.01695793867111, 71.00068733096123, 63.00679408013821, 72.29875087738037, 70.90973541140556, 72.83525168895721, 66.74942225217819, 63.4983167052269, 60.37033975124359, 68.15669193863869, 74.38283264636993, 78.15312713384628, 73.5452663898468, 69.76997897028923, 74.37709495425224, 76.02269545197487, 74.97761473059654, 81.2603572010994, 23.53454254567623, 0.46720894693862647, 8.028159812092781, 7.512531755492091, 2.997758178971708, 1.4744737115688622, 1.4660145342350006, 0.8840328943915665, 0.4468019341584295, 0.3762253525201231, 0.19479083275655285, 24.69411112368107, 51.52462340891361, 57.221524715423584, 60.21448731422424, 26.136300936341286, 37.6430980861187, 57.563582360744476, 72.35254839062691, 76.7401197552681, 81.0514748096466, 76.53376802802086, 8.86123850941658, 0.20874801819445565, 0.12956345861312002, 0.26362792414147407, 0.1040577948151622, 0.19935627293307334, 0.13160069851437584, 0.09843715422903188, 0.15152442472754046, 0.2069232106441632, 0.09694852473330684, 0.10892244667047635, 0.20148576179053634, 0.20409118995303288, 0.11548732916708104, 0.1665406400570646, 0.09747231029905379, 0.13158420799300075, 0.25963891006540507, 0.23796859866706654, 0.14713137061335146, 0.15924633771646768, 0.12051099358359352, 0.13720835151616484, 0.1266967796254903, 0.1691927047795616], [0.0626041492796503, 0.10033000929979607, 0.03271381763624959, 0.03491324278002139, 0.017241736240976024, 0.07101572526153177, 0.08396938603254966, 0.03796581120695919, 0.023868753196438774, 0.03934754175134003, 0.02048914069746388, 0.06340398409520276, 0.04348518945334945, 0.03914371089194901, 0.04490155231906101, 0.00946201458646101, 0.06540137066622265, 0.01716079390462255, 0.08553876861697063, 0.18623205920448527, 0.2493076800601557, 12.669061683118343, 86.90906569361687, 77.28947147727013, 73.14637139439583, 61.12527184188366, 50.425217002630234, 31.288640163838863, 36.41954094171524, 47.37099029123783, 45.082088112831116, 20.801389105618, 0.489670432289131, 0.04563237482216209, 0.11277030425844714, 0.47904961626045406, 0.28256192221306264, 1.527166434098035, 0.8121308963745832, 1.6531229065731168, 0.08772647895966657, 9.4662344455719, 61.789540797472, 77.57986709475517, 77.28740438818932, 72.35420510172844, 71.3070496916771, 67.327401638031, 68.38990822434425, 60.52586540579796, 61.2475910782814, 58.237985372543335, 64.79596227407455, 66.90762296319008, 66.38305351138115, 60.636800453066826, 54.487085044384, 49.98783007264137, 57.39383406937122, 61.786808744072914, 69.48206081986427, 66.80514246225357, 62.4290768802166, 64.36161518096924, 66.79542258381844, 54.17672149837017, 49.25375506281853, 47.77274653315544, 56.16826303303242, 67.62940183281898, 63.982349932193756, 64.29725423455238, 57.85742439329624, 50.42439244687557, 48.21063503623009, 48.20369280874729, 50.93966759741306, 54.27160620689392, 62.281238213181496, 62.28142820298672, 63.05509328842163, 61.367052868008614, 66.75886854529381, 62.56892837584019, 66.36922225356102, 60.86898699402809, 70.5233645439148, 43.084953278303146, 34.890434592962265, 65.71202471852303, 57.67103299498558, 65.58231487870216, 62.50686630606651, 60.85001461207867, 53.7558750808239, 49.48033690452576, 45.481879860162735, 46.10709451138973, 45.851280838251114, 47.03973166644573, 44.07750181853771, 47.128814086318016, 46.14626280963421, 48.82310897111893, 46.655891463160515, 48.053483068943024, 46.75669625401497, 48.306614086031914, 47.63040617108345, 54.406084790825844, 61.48223988711834, 65.99133253097534, 62.27765880525112, 64.33659732341766, 65.89736357331276, 65.81929296255112, 63.80029410123825, 65.05161255598068, 55.75555957853794, 54.801556169986725, 62.17545568943024, 68.25400471687317, 69.87055957317352, 69.66616854071617, 68.07183489203453, 73.2670833170414, 68.4299124777317, 67.84978240728378, 76.45901843905449, 22.790080793201923, 0.2219050348503515, 1.3112383894622326, 1.6084572533145547, 0.771989137865603, 0.22152486228151247, 0.07122492184862494, 0.19057601282838732, 0.14707345340866596, 0.04425285216711927, 0.5750508117489517, 24.62238237261772, 41.43934138119221, 40.80598756670952, 23.119927793741226, 13.561248108744621, 22.23008394241333, 42.41199038922787, 57.67382964491844, 61.87516160309315, 66.7611788213253, 31.140075735747814, 0.4074815846979618, 0.03160737564030569, 0.04786114819580689, 0.04618144164851401, 0.05842317870701663, 0.012581878181663342, 0.029509257365134545, 0.037298379247658886, 0.03461980501015205, 0.028041430268785916, 0.025840300040727016, 0.019812526516034268, 0.003904446348315105, 0.03398153945454396, 0.04326369918999262, 0.024131948448484764, 0.033078193591791205, 0.038247400589170866, 0.04748808169097174, 0.01348678440990625, 0.05723025053157471, 0.02698805183172226, 0.01802809736545896, 0.011765876606659731, 0.002903509921452496, 0.009935862890415592, 0.00526739545421151, 0.038390753834391944, 0.04650197894079611, 0.05778763683338184, 0.054080149056972004, 0.03288720930868294, 0.06823339135735296, 0.051800412402371876, 0.04418145013914909, 0.027626857299765106, 0.06956597688258626, 0.043539774414966814, 0.02734463709202828, 0.013502600504580187, 0.1283585818600841, 0.044495270994957536, 0.027639388463285286, 0.10830563289346173, 0.1937212940538302, 0.27343504945747554, 17.962019965052605, 100.62042474746704, 84.14836183190346, 81.7428021132946, 68.64751160144806, 59.02460016310215, 32.3150809854269, 26.817556880414486, 39.98670972883701, 50.6563775986433, 27.034019865095615, 0.49151935963891447, 0.1708866420085542, 0.08986123706563376, 1.195312428753823, 1.4557438041083515, 3.253360250964761, 2.062668730504811, 1.51712107937783, 0.5147248925641179, 12.493448406457901, 66.12168833613396, 79.35831606388092, 81.58143997192383, 75.25205880403519, 76.08434334397316, 70.34288942813873, 72.02670827507973, 63.057832941412926, 63.64854544401169, 60.75199507176876, 67.41993427276611, 68.83775979280472, 69.55903708934784, 62.629854306578636, 56.9088888913393, 52.82798007130623, 59.151619747281075, 66.87540829181671, 72.97585174441338, 67.46531903743744, 63.13341088593006, 66.29173681139946, 71.20087578892708, 57.86445401608944, 51.026793122291565, 49.18352723121643, 60.35553194582462, 70.16315147280693, 67.23825842142105, 67.03719601035118, 61.41726337373257, 53.79044562578201, 49.35669533908367, 48.15768487751484, 52.874797359108925, 55.91628335416317, 64.5652462542057, 65.92631801962852, 65.50527781248093, 64.91281360387802, 70.5294518172741, 66.69528275728226, 70.06457716226578, 63.163452073931694, 72.81113058328629, 45.056249499320984, 38.96220490336418, 68.29489052295685, 60.02181865274906, 67.61622413992882, 64.25629243254662, 63.2332581281662, 55.12133181095123, 53.217375576496124, 47.45708227157593, 49.596435874700546, 47.84404590725899, 48.4769931435585, 46.89781688153744, 48.42361360788345, 48.969245329499245, 51.31127245724201, 49.07370552420616, 50.480013862252235, 49.281083196401596, 50.872749388217926, 49.44137379527092, 58.08898016810417, 65.49276128411293, 68.51447314023972, 64.34187904000282, 64.44718658924103, 71.17172375321388, 68.030736297369, 67.72514149546623, 66.52480110526085, 59.21407699584961, 56.94834977388382, 66.58489868044853, 69.44475442171097, 72.42750316858292, 71.29017099738121, 71.09629020094872, 76.72324106097221, 72.34523758292198, 69.73069667816162, 77.71202400326729, 28.11415560543537, 0.31290638144128025, 0.7500602176878601, 0.08724736326257698, 2.1250050980597734, 0.929997127968818, 0.617099889786914, 0.6796980870421976, 0.15754765074234456, 0.0497156898927642, 0.5212751473300159, 28.02438162267208, 42.09162577986717, 34.472187235951424, 18.81769984960556, 20.63793707638979, 34.40808467566967, 51.80363483726978, 66.53617769479752, 67.63196289539337, 77.98876315355301, 41.68324649333954, 0.6979044538456947, 0.12242670680279844, 0.02377805347350659, 0.07139937108149752, 0.0322855613194406, 0.04607187096553389, 0.036196727814967744, 0.027852379280375317, 0.047384759891428985, 0.01034008753777016, 0.02899549264839152, 0.031734312578919344, 0.026397127876407467, 0.035337331937626004, 0.051465021024341695, 0.04775086505105719, 0.024391737242694944, 0.05111292761284858, 0.03109111359663075, 0.05417861721070949, 0.013649509564856999, 0.030013695140951313, 0.09071268083062023, 0.008095382108876947, 0.019665596119011752, 0.12366706563625485, 0.1394668107968755, 0.1817730430047959, 0.1526816259138286, 0.10779289790662006, 0.21141439152415842, 0.08237439193180762, 0.14981159241870046, 0.10979616970871575, 0.1027722837170586, 0.1353239346644841, 0.13385556580033153, 0.13119680690579116, 0.160419391177129, 0.20651404978707433, 0.20054684107890353, 0.12794277135981247, 0.13721620343858376, 0.18518525990657508, 0.37174969736952335, 0.4749045433709398, 22.410323470830917, 115.0677815079689, 93.30027714371681, 94.98604148626328, 79.24454256892204, 67.31284841895103, 43.803251534700394, 53.02219904959202, 66.51535481214523, 65.32991722226143, 34.14074622094631, 0.9483132732566446, 0.19720002223039046, 0.5688470508903265, 2.0167783554643393, 2.118801693432033, 5.300913630053401, 5.280607519671321, 5.898736976087093, 3.808827744796872, 12.0661242865026, 70.92611253261566, 81.59156262874603, 85.2519442141056, 79.41214397549629, 77.97734096646309, 73.61659616231918, 73.78332361578941, 65.41593700647354, 66.68023556470871, 62.720304653048515, 70.68770572543144, 72.44720131158829, 72.50937357544899, 65.71902394294739, 60.57862177491188, 54.670201018452644, 61.77263930439949, 67.922852486372, 75.78108161687851, 70.15649423003197, 64.83440101146698, 69.05415058135986, 75.91900661587715, 60.04748247563839, 54.61874417960644, 51.81622736155987, 63.61349232494831, 71.82145848870277, 69.05505493283272, 70.4176314175129, 64.13993507623672, 55.54981581866741, 50.91481693089008, 51.973519921302795, 54.68730770051479, 59.32633437216282, 67.69392997026443, 68.8116703927517, 68.48833054304123, 68.80214050412178, 72.29732975363731, 67.85491973161697, 72.06570938229561, 67.04751625657082, 75.06098985671997, 49.27385598421097, 43.788990899920464, 72.22701832652092, 62.17450954020023, 72.26715937256813, 67.90554821491241, 67.49222159385681, 59.00460563600063, 54.13511373102665, 50.542740896344185, 51.732445657253265, 50.51858939230442, 51.49242013692856, 49.07321535050869, 51.01007781922817, 50.9519599378109, 53.58261577785015, 50.79036980867386, 52.72425703704357, 52.24226430058479, 53.715517446398735, 51.77796721458435, 58.531436026096344, 68.91760870814323, 73.31704303622246, 67.01357647776604, 64.7987513244152, 73.00998151302338, 72.18202114105225, 70.27535945177078, 70.82699865102768, 62.57040649652481, 61.71552836894989, 68.51983845233917, 73.09363022446632, 74.96841162443161, 76.08922228217125, 73.54136779904366, 79.27839875221252, 75.75461983680725, 72.25226417183876, 81.9282853603363, 29.854978993535042, 0.4237635328900069, 7.380650332197547, 7.919577788561583, 4.211494037881494, 0.6302166671957821, 1.1562733235768974, 1.2240684544667602, 0.38680903147906065, 0.17658841417869553, 0.8553381997626275, 38.53613756597042, 59.72031243145466, 53.34534130990505, 34.55666430294514, 22.20076661556959, 34.267009645700455, 56.76399126648903, 75.19259959459305, 78.47957521677017, 86.90157249569893, 45.089512914419174, 0.9038214606698602, 0.24682258372195065, 0.23197079863166437, 0.15461309492820874, 0.09661926349508576, 0.18405618611723185, 0.11793421974289231, 0.12283618678338826, 0.10680993073037826, 0.0928544151247479, 0.16759027435909957, 0.15682491764891893, 0.10784246594994329, 0.1037291792454198, 0.1653541685664095, 0.2408755911164917, 0.1293947090744041, 0.15723306918516755, 0.15730959945358336, 0.09233600270817988, 0.14688154886243865, 0.11668386418023147, 0.22467253322247416, 0.09287175169447437, 0.11994279047939926], [0.03486125533527229, 0.04692676942795515, 0.016388138392358087, 0.04620955420250539, 0.027829003483930137, 0.04103521154320333, 0.0620872360013891, 0.01629633658012608, 0.05304104583046865, 0.05473344310303219, 0.032727814541431144, 0.03231620830774773, 0.12230497231939808, 0.07183473717304878, 0.06777524875360541, 0.02342887113627512, 0.01662720271269791, 0.061756794748362154, 0.04702495185483713, 0.01831099663831992, 0.06923353183083236, 43.079154789447784, 90.42874082922935, 75.21298170089722, 68.90378504991531, 42.91561156511307, 35.852957144379616, 35.81166855990887, 69.82168659567833, 49.54867623746395, 44.08552698791027, 7.2721837274730206, 0.15431889274623245, 0.1761288763373159, 0.18792975170072168, 0.21696602721931413, 1.0656360746361315, 2.4239067966118455, 2.229636046104133, 2.7476014522835612, 6.152382865548134, 52.165903598070145, 83.4815888106823, 75.74186012148857, 70.45110002160072, 66.51282414793968, 65.82903563976288, 64.36400145292282, 62.204052954912186, 58.8678053766489, 62.34645031392574, 63.57082821428776, 69.18728023767471, 67.0011131465435, 66.05158969759941, 56.17655038833618, 52.70797111093998, 50.18917366862297, 55.95721855759621, 63.88113856315613, 67.79801398515701, 64.85292881727219, 61.928009167313576, 65.63434168696404, 62.978409603238106, 51.99031122028828, 46.73565298318863, 47.88522429764271, 59.87133152782917, 65.7126858830452, 62.00114764273167, 64.54858034849167, 59.880648627877235, 54.36982333660126, 50.475742891430855, 47.497185319662094, 50.40381275117397, 54.606204852461815, 61.36458680033684, 61.72410070896149, 65.19122466444969, 55.70824831724167, 62.506448328495026, 60.710915476083755, 66.84688702225685, 61.341354846954346, 63.439720049500465, 40.17212077975273, 35.713120847940445, 59.76947419345379, 56.78049378097057, 67.37742215394974, 59.223994463682175, 58.99756461381912, 50.32643370330334, 51.252003237605095, 44.56562742590904, 49.075491428375244, 46.53924912214279, 47.17166058719158, 47.40347854793072, 47.69288621842861, 44.94516246020794, 49.535430148243904, 48.41928943991661, 47.39510379731655, 45.088543966412544, 47.92364023625851, 47.475895062088966, 50.53193807601929, 57.30693653225899, 64.29509595036507, 64.31919425725937, 61.62481963634491, 65.77375620603561, 66.4735646545887, 64.72815871238708, 64.68679413199425, 61.41172707080841, 52.82177120447159, 56.00710988044739, 67.73016482591629, 68.22806730866432, 68.0152103304863, 69.44891139864922, 67.5271113216877, 67.58035406470299, 70.13082280755043, 67.2449916601181, 71.85150727629662, 18.69022998958826, 0.04170620952208992, 0.6040256225969642, 1.3440676778554916, 1.0366233251988888, 0.16298882517730817, 0.3727153205545619, 0.27662928274367005, 0.02898112466937164, 0.10238409595331177, 4.322755867615342, 31.937730833888054, 44.26981709897518, 61.975043043494225, 38.183014914393425, 16.22741114348173, 19.731115736067295, 49.400833770632744, 59.03058864176273, 66.17575943470001, 66.20019972324371, 13.872765842825174, 0.6181666231714189, 0.06597715109819546, 0.06965098247746937, 0.06538528832606971, 0.031367776973638684, 0.05000680102966726, 0.015242946083162678, 0.04254283630871214, 0.021677174408978317, 0.01830395922297612, 0.04093185634701513, 0.07646683705388568, 0.08171560970367864, 0.03357879075338133, 0.0695210843696259, 0.14825063321040943, 0.03257804171880707, 0.031415827324963175, 0.021398297576524783, 0.07459916305379011, 0.026611977773427498, 0.06496429021353833, 0.04739822987176012, 0.05113226055982523, 0.024422597598459106, 0.03439026986598037, 0.03660028174635954, 0.04659678459574934, 0.08586874231696129, 0.02388808428804623, 0.022487592250399757, 0.051037195153185166, 0.011195604765816825, 0.019800923037109897, 0.04313552657549735, 0.010556354936852586, 0.10788494648295455, 0.012623621205420932, 0.0807788634847384, 0.04012696008430794, 0.056785110355122015, 0.042902492205030285, 0.008592203594162129, 0.06369442358845845, 0.23871098383096978, 55.70538707077503, 101.86688706278801, 84.60085675120354, 79.48198422789574, 57.2266848385334, 50.85528552532196, 36.367578729987144, 60.12682601809502, 44.92615967988968, 48.20465035736561, 9.07382095232606, 0.269845548318699, 0.07752609701128677, 0.9389271237887442, 1.4003189094364643, 2.0099114114418626, 3.1131686735898256, 2.1397879673168063, 1.2940006144344807, 7.160587040707469, 57.780858501791954, 82.3771096765995, 79.160817861557, 72.95219421386719, 70.88555350899696, 68.48389998078346, 66.39293298125267, 66.46699860692024, 62.47602716088295, 63.94177570939064, 66.68661922216415, 72.11066856980324, 70.82827538251877, 68.86258766055107, 58.657175078988075, 53.806423768401146, 52.13040970265865, 59.89658497273922, 67.41064757108688, 70.48002406954765, 65.91631695628166, 62.59760923683643, 67.80248254537582, 65.48241823911667, 55.206724628806114, 49.79758568108082, 49.06693048775196, 62.17563048005104, 68.02211076021194, 65.51334097981453, 68.33931773900986, 61.28453269600868, 58.652972504496574, 52.616624012589455, 49.755263552069664, 52.23822511732578, 58.0119127035141, 63.63156035542488, 66.41097441315651, 67.89503797888756, 60.573214665055275, 64.80837240815163, 63.7220449000597, 67.31502950191498, 62.02702805399895, 64.23179134726524, 43.376678824424744, 39.2732448130846, 63.931326270103455, 59.84721042215824, 68.8653539121151, 64.38354760408401, 61.55278690159321, 52.24435418844223, 51.69175744056702, 46.8862920999527, 49.17321838438511, 49.28628511726856, 49.8700287938118, 48.9714340120554, 49.532884284853935, 48.881340846419334, 51.32880091667175, 49.12578172981739, 49.99740555882454, 47.232624515891075, 47.93398708105087, 49.80921305716038, 51.61299146711826, 59.99273121356964, 65.86534649133682, 69.0135383605957, 62.74330481886864, 66.30325019359589, 68.30473959445953, 68.33345845341682, 67.0002543926239, 63.86388748884201, 55.34319810569286, 58.30283269286156, 70.7337136566639, 72.16666996479034, 72.36743599176407, 71.36962473392487, 70.56276842951775, 70.17578959465027, 74.08999755978584, 69.9435992538929, 77.34412774443626, 24.312659092247486, 0.07730870711384341, 0.2717523038154468, 0.40721749886870384, 2.9624063009396195, 1.13107853801921, 0.8447450213134289, 0.6110623700078577, 0.5471734888851643, 0.061910538061056286, 4.155769078060985, 35.43317846953869, 34.392353519797325, 44.62067507207394, 31.689096875488758, 22.63830553740263, 31.121530830860138, 56.62225507199764, 66.3099530339241, 72.55082175135612, 79.11427035927773, 21.02426614612341, 0.5767558515071869, 0.055531006946694106, 0.05279028897348326, 0.0583909398119431, 0.08355202444363385, 0.0727353259571828, 0.059509764541871846, 0.04171343804046046, 0.07189533353084698, 0.0711742925341241, 0.02351599370740587, 0.04902773383946624, 0.03766185349377338, 0.014778928452869877, 0.02441035772790201, 0.021448438928928226, 0.07244476029882208, 0.036306966430856846, 0.02197200185037218, 0.0772830139612779, 0.0479755688138539, 0.051189224104746245, 0.023443671416316647, 0.024535311276849825, 0.07292698559467681, 0.17327589739579707, 0.16717410762794316, 0.16430598887382075, 0.27003049151971936, 0.1053803984541446, 0.10134634343557991, 0.13605527667095885, 0.207207957864739, 0.12348460862995125, 0.1260049347183667, 0.11777557083405554, 0.3029699146281928, 0.10326211602659896, 0.1667832036036998, 0.10829947306774557, 0.1714008316048421, 0.17211875558132306, 0.10208152234554291, 0.15701208729296923, 0.3407381661236286, 66.6900010406971, 110.91591149568558, 93.73750448226929, 90.2448458969593, 61.34678095579147, 52.41715371608734, 52.544686272740364, 93.79542857408524, 66.61924883723259, 67.21975341439247, 13.42398427426815, 0.3594498464372009, 0.28051044791936874, 1.4027261990122497, 2.4385846965014935, 3.932315893471241, 7.311874972656369, 8.37768405675888, 10.437381584197283, 7.37041225656867, 60.95216453075409, 86.60468682646751, 81.82107791304588, 74.88417014479637, 72.59999111294746, 70.1102963089943, 69.07831728458405, 69.77032855153084, 65.6458930671215, 66.34830057621002, 68.46297830343246, 73.99155244231224, 74.1526485979557, 72.37514197826385, 62.344968393445015, 56.193926855921745, 54.67425540089607, 63.23916681110859, 70.41994169354439, 73.23250517249107, 67.52367630600929, 62.28843882679939, 71.60971105098724, 68.18313091993332, 57.64446102082729, 50.64449563622475, 52.91620373725891, 66.3786381483078, 71.8745568394661, 68.1397296488285, 70.59964165091515, 63.19353125989437, 61.4985828101635, 55.4599392414093, 52.617258578538895, 52.99838572740555, 60.77206179499626, 65.61535030603409, 69.44859981536865, 70.61112463474274, 62.67433471977711, 67.58608415722847, 65.9000614285469, 68.6307393014431, 64.00693461298943, 64.7904297709465, 45.704175531864166, 44.26327005028725, 65.37038505077362, 63.11801791191101, 72.61038735508919, 66.10777348279953, 63.008139207959175, 55.12011967599392, 55.41576661169529, 49.98847983777523, 53.04177939891815, 52.600554674863815, 51.34335793554783, 52.808392122387886, 53.148268684744835, 50.98089538514614, 53.49645160138607, 52.32569642364979, 53.95232833921909, 50.9841176122427, 52.25844383239746, 52.27020040154457, 53.96311596035957, 61.571117118000984, 70.7338048517704, 73.24897348880768, 63.595754876732826, 68.95898848772049, 71.13647684454918, 72.00410708785057, 69.53649669885635, 66.97111755609512, 56.85544855892658, 62.23452731966972, 74.42865818738937, 76.29166021943092, 73.51562798023224, 76.23853906989098, 73.54441523551941, 72.8240954875946, 74.40416470170021, 72.84663587808609, 80.40883809328079, 27.902755849063396, 0.20556598581606522, 5.620850762352347, 6.329641453921795, 4.821324739605188, 0.8223404141608626, 1.124355630017817, 1.0404247837141156, 0.6899479182902724, 0.19175348948920146, 7.151277540251613, 50.83669312298298, 61.396869868040085, 80.44454857707024, 48.69824007153511, 24.83375933021307, 32.099982127547264, 63.456028774380684, 77.95417740941048, 80.46153366565704, 87.91003078222275, 21.293160617351532, 0.7694455306045711, 0.224569033307489, 0.11796128586865962, 0.14396438898984343, 0.20319357718108222, 0.16220471647102386, 0.11017247568815947, 0.09862138496828265, 0.17637005948927253, 0.12394347111694515, 0.11967093436396681, 0.17149468360003084, 0.11429041565861553, 0.09988588586566038, 0.13922855170676485, 0.23459305870346725, 0.16168450063560158, 0.11901877951459028, 0.14174201292917132, 0.2236759031075053, 0.1650834924657829, 0.14344163500936702, 0.24511689087375998, 0.16030133032472804], [0.043946326622972265, 0.019236601365264505, 0.08174775954103097, 0.038659860292682424, 0.060589299973798916, 0.030366011196747422, 0.017688433072180487, 0.05028232335462235, 0.06451133522205055, 0.07841316386475228, 0.005715435572710703, 0.05083747579192277, 0.0829293773858808, 0.04192166241409723, 0.10098518469021656, 0.02217445602582302, 0.010751831068773754, 0.05263386650767643, 0.02597220751340501, 0.055420976132154465, 4.781324760988355, 80.4637223482132, 75.55364102125168, 72.43892535567284, 60.468298494815826, 33.65916766226292, 16.701150722801685, 33.25772300362587, 35.82501344382763, 46.27247303724289, 30.30735231935978, 0.23226329387398437, 0.05826738335599657, 0.11503771384013817, 0.4059494653483853, 0.6497408507857472, 1.0366160818375647, 1.5827201656065881, 0.9582862537354231, 0.485346561181359, 35.96069276332855, 76.91938653588295, 78.35589945316315, 73.4493139386177, 72.91626334190369, 68.4631758928299, 61.84218317270279, 62.542196810245514, 63.098589554429054, 61.69567063450813, 68.19592863321304, 69.02104675769806, 72.7359326183796, 67.44412377476692, 66.07089266180992, 52.192711159586906, 49.78182032704353, 48.25502425432205, 61.151927411556244, 65.16091749072075, 68.86650905013084, 62.62483857572079, 62.26214423775673, 65.44494464993477, 59.24664504826069, 49.5246235281229, 49.303061217069626, 48.39874014258385, 60.027807131409645, 62.477102503180504, 60.04698850214481, 62.95885965228081, 61.81901961565018, 57.64747425913811, 54.80283670127392, 51.079469695687294, 55.59208855032921, 59.39520187675953, 61.297440603375435, 61.7093612998724, 64.90153580904007, 60.76317027211189, 65.77647686004639, 60.287678986787796, 60.84162466228008, 58.11381943523884, 63.783962577581406, 41.41837030649185, 36.78749419748783, 61.499772146344185, 55.26084512472153, 64.29518714547157, 61.85023494064808, 59.45279158651829, 51.36345885694027, 48.613136038184166, 44.943786934018135, 48.29917408525944, 48.88669855892658, 52.90334902703762, 47.930225282907486, 46.387994438409805, 43.938414081931114, 45.22352032363415, 47.244647070765495, 49.43494074046612, 45.33746860921383, 46.73626095056534, 46.52402713894844, 47.92881555855274, 50.2136367559433, 58.8148932158947, 60.04678711295128, 65.24805441498756, 61.090959683060646, 64.27288234233856, 62.81340345740318, 66.65507331490517, 64.474256336689, 59.84186790883541, 48.34552399814129, 62.57329434156418, 68.9421933889389, 68.7755799293518, 66.55396074056625, 67.15669959783554, 62.9405902326107, 66.64128005504608, 67.07835540175438, 73.1331405043602, 67.85747319459915, 14.09432815387845, 0.022355369364959188, 2.6678912295028567, 1.5114011988043785, 0.5261794372927397, 0.6772608740720898, 0.1643312961095944, 0.06961891427636147, 0.12447326807887293, 0.04384629995911382, 12.902176324278116, 36.905071288347244, 39.71457213163376, 85.44605299830437, 69.92046609520912, 31.278118528425694, 33.62367756664753, 53.735728561878204, 52.418700233101845, 68.93177434802055, 51.05741187930107, 3.0669517535716295, 0.20770043222000822, 0.025906009796017315, 0.07561105172499083, 0.025648323135101236, 0.02668688459380064, 0.01659238856518641, 0.0487775632791454, 0.12183707789517939, 0.02820141875417903, 0.040038006263785064, 0.04928305861540139, 0.017950487272173632, 0.01806829579436453, 0.032075889757834375, 0.02051764473435469, 0.04811757135030348, 0.029213572743174154, 0.04385709820780903, 0.02689879373065196, 0.006354917322823894, 0.07587343061459251, 0.04376582146505825, 0.04835292122152168, 0.05284416889480781, 0.007132102718969691, 0.0385070224001538, 0.023813095831428654, 0.07866636238759384, 0.05655198321619537, 0.030732711929886136, 0.05681194270437118, 0.09257658472051844, 0.040543572104070336, 0.015686511978856288, 0.07490894291549921, 0.07297641262994148, 0.08226124409702606, 0.042286598691134714, 0.04248726800142322, 0.01016095164231956, 0.03790255796047859, 0.038150142136146314, 0.13085555256111547, 6.888382472097874, 94.00528371334076, 83.69935512542725, 78.92657563090324, 67.69538149237633, 44.627225920557976, 27.803429178893566, 33.13495919108391, 36.23078987002373, 48.14594350755215, 32.41636075079441, 0.17361445032292977, 0.11697160967742093, 0.38265205454081297, 0.8882117795292288, 1.3607164844870567, 2.525008446536958, 2.971511324867606, 1.102535657119006, 1.343317930586636, 40.13438880443573, 77.04276591539383, 79.50563415884972, 75.3709164261818, 74.17728647589684, 70.336604565382, 65.11307805776596, 65.39363980293274, 66.58278599381447, 65.71773961186409, 70.07441103458405, 71.97196081280708, 74.10483196377754, 70.91132372617722, 67.92092978954315, 55.40862679481506, 52.64014855027199, 49.73701313138008, 63.731137812137604, 67.22495913505554, 70.11148184537888, 63.75728040933609, 64.72364455461502, 67.26391464471817, 61.35965846478939, 51.30520798265934, 50.456132143735886, 50.4678925126791, 63.088592290878296, 64.73051458597183, 62.12224334478378, 64.24948319792747, 63.691023364663124, 60.292721316218376, 58.03159564733505, 53.2892981171608, 57.59435310959816, 61.946992948651314, 64.71305832266808, 64.41567108035088, 65.70209205150604, 59.92739371955395, 66.20347514748573, 61.80535554885864, 62.76331074535847, 59.44909818470478, 65.1714201271534, 42.11096674203873, 39.8270270973444, 64.78784590959549, 57.645920142531395, 65.08431360125542, 63.09877574443817, 60.794480592012405, 55.340473651885986, 51.51928469538689, 46.79724767804146, 50.67435443401337, 52.87607029080391, 54.338102638721466, 49.87190589308739, 48.16787213087082, 45.8740796148777, 47.32228830456734, 49.44240354001522, 50.9714262932539, 47.00148671865463, 49.45167504251003, 46.787622794508934, 50.77729091048241, 52.86996401846409, 62.64579825103283, 63.266415148973465, 68.69595140218735, 62.518778666853905, 63.17413330078125, 65.73882088065147, 70.06355121731758, 66.38846442103386, 61.79136469960213, 51.38803593814373, 63.044685646891594, 71.60576686263084, 71.81551560759544, 68.37970197200775, 69.70121026039124, 64.98694762587547, 69.06847581267357, 69.55477371811867, 74.20222073793411, 70.77044248580933, 20.45654620975256, 0.03586762242775876, 0.4650386399589479, 2.2068242076784372, 2.6011067256331444, 2.1638136031106114, 1.1997309979051352, 0.5335466482210904, 0.2392151692765765, 0.030700673414685298, 13.288849275559187, 37.144097462296486, 40.47521531581879, 68.98976683616638, 58.541718274354935, 33.35157796740532, 40.711828619241714, 59.55308720469475, 58.94963398575783, 75.3668886423111, 64.08285453915596, 4.695599460974336, 0.3447220742236823, 0.04182079712336417, 0.023218080787046347, 0.02440199001284782, 0.06746063008904457, 0.04597094259224832, 0.07964495089254342, 0.07209689341834746, 0.001362075111046579, 0.0315234721347224, 0.02083880357531598, 0.0469199194048997, 0.015475555574084865, 0.015175584121607244, 0.01709774474875303, 0.14080582332098857, 0.009389272981934482, 0.06009229851770215, 0.026764672802528366, 0.06942473133676685, 0.025890990582411177, 0.0250587146365433, 0.08864238567184657, 0.14354382874444127, 0.10130519134690985, 0.18306604237295687, 0.16404314985265955, 0.17547112569445744, 0.211682811495848, 0.10454849543748423, 0.11754127481253818, 0.17082375241443515, 0.20795359363546595, 0.10196991075645201, 0.17081351077649742, 0.14443866588408127, 0.2559893543366343, 0.08295723760966212, 0.24244446161901578, 0.11841593295685016, 0.15883530664723366, 0.19962962076533586, 0.19917461002478376, 8.24188219383359, 106.84037938714027, 91.99976652860641, 91.69313818216324, 77.60170072317123, 50.33315934240818, 25.498203076422215, 50.05107767879963, 51.638769283890724, 65.92898547649384, 47.57501274347305, 0.4793826030800119, 0.1887541590258479, 0.5618528730701655, 1.6705968626774848, 2.597391474992037, 3.787843845784664, 7.063967250287533, 5.367099428549409, 1.336930829565972, 44.146851897239685, 77.92423501610756, 84.27383869886398, 78.48965227603912, 78.0625855922699, 74.816624969244, 67.86891058087349, 67.42821782827377, 69.26722034811974, 67.61368587613106, 73.98373246192932, 75.04253804683685, 76.82971134781837, 71.18968918919563, 70.47395959496498, 58.144567385315895, 54.92157652974129, 53.475746512413025, 67.68361732363701, 72.10469529032707, 74.76749360561371, 64.4599387049675, 64.97266039252281, 71.81182220578194, 65.02906456589699, 54.40663956105709, 53.62354338169098, 54.465433806180954, 65.58729261159897, 68.20368021726608, 65.68202912807465, 65.77261626720428, 65.52136614918709, 62.716565653681755, 59.8731554299593, 56.76283612847328, 60.854361578822136, 64.80158597230911, 66.96239322423935, 66.17068290710449, 66.67745411396027, 62.35914543271065, 68.07730659842491, 63.119461834430695, 63.95041644573212, 63.06730583310127, 66.15147113800049, 45.9108692407608, 43.8593403249979, 65.33422619104385, 59.81005601584911, 68.66158604621887, 66.26987278461456, 62.935266718268394, 57.363188713788986, 53.82800281047821, 48.886717557907104, 54.386740028858185, 55.63291355967522, 56.34846456348896, 52.00029328465462, 51.08491100370884, 48.38324077427387, 49.055838882923126, 52.57796868681908, 53.63795980811119, 49.547418504953384, 50.16914874315262, 49.70982179045677, 54.09263961017132, 54.55751806497574, 63.244007751345634, 67.22497433423996, 71.52984693646431, 64.35269325971603, 67.01366007328033, 67.50180467963219, 73.26715171337128, 69.52662482857704, 65.88990837335587, 55.209863260388374, 68.51898729801178, 75.88242217898369, 76.37137234210968, 71.70583069324493, 73.84340599179268, 69.6009336411953, 71.39081239700317, 71.87253534793854, 76.50098338723183, 75.78348308801651, 21.370281279087067, 0.18245694693177938, 9.697502385824919, 8.11083197593689, 3.8758392864838243, 2.2035813191905618, 0.791859399760142, 0.8567785006016493, 0.37652001483365893, 0.13529277930501848, 20.336590446531773, 55.08250169456005, 53.80900762975216, 94.3420672416687, 81.68493881821632, 40.482811108231544, 46.347253024578094, 70.67285612225533, 69.28878039121628, 83.50229769945145, 70.8267630636692, 4.444519383832812, 0.525893383892253, 0.06863030677777715, 0.15300425235182047, 0.06500006915302947, 0.1630760423722677, 0.07799940911354497, 0.16901261522434652, 0.1856492951628752, 0.10725049927714281, 0.11268831920460798, 0.16661893663695082, 0.10143609877559356, 0.09994115360314026, 0.13133803760865703, 0.1566548619302921, 0.27022122347261757, 0.0753891866770573, 0.1161124104692135, 0.1357981373439543, 0.14229794091079384, 0.14285180572187528, 0.11028098509996198, 0.11552625481272116], [0.06788465616409667, 0.03516728735121433, 0.04109606394194998, 0.02029858500463888, 0.021061254919914063, 0.04925355824525468, 0.09510110394330695, 0.02763305794360349, 0.033154657066916116, 0.027304470204398967, 0.0192559899733169, 0.02791490336676361, 0.02228360182925826, 0.01905231682030717, 0.10477371499291621, 0.06462817153078504, 0.07297816409845836, 0.039037138485582545, 0.07484896996174939, 0.06336568185361102, 27.74994134902954, 87.48306289315224, 68.13960805535316, 74.06576246023178, 58.610825166106224, 41.55616231262684, 25.73526855558157, 43.422025591135025, 40.23034505546093, 45.087833404541016, 8.484982699155807, 0.11935953662032261, 0.05052772190538235, 0.36792585568036884, 0.5781759659294039, 0.6335530069191009, 1.585883020889014, 1.4112143497914076, 0.5557743273675442, 17.20457810908556, 70.58882743120193, 74.83672589063644, 78.75260576605797, 72.00865924358368, 70.58246657252312, 66.9675001502037, 68.20877954363823, 68.8469249010086, 65.79862207174301, 65.47492504119873, 69.26695436239243, 74.79263305664062, 71.13159790635109, 67.74010509252548, 60.617995262145996, 49.78992909193039, 47.93385408818722, 51.723732724785805, 63.160974606871605, 63.572249338030815, 65.87833419442177, 60.88335782289505, 66.68120071291924, 63.36084008216858, 57.344991490244865, 47.73633688688278, 47.37290918827057, 47.04113379120827, 61.09056830406189, 64.07305866479874, 61.91889725625515, 57.81578242778778, 63.72303284704685, 60.60773581266403, 56.03863678872585, 52.79829226434231, 59.83782112598419, 59.676892161369324, 59.932314455509186, 64.8483082652092, 60.674308240413666, 56.765085607767105, 64.10339623689651, 62.72186636924744, 64.8911851644516, 58.85270498692989, 63.25824938714504, 41.90345987677574, 39.41648572683334, 62.526119872927666, 56.3326346129179, 58.63491967320442, 59.79780167341232, 61.27488501369953, 54.118406027555466, 48.151027634739876, 45.694467052817345, 51.88693016767502, 56.32732629776001, 58.60410712659359, 54.61320407688618, 52.210023030638695, 51.05576656758785, 52.79577299952507, 54.216566160321236, 56.977380216121674, 50.87482027709484, 47.456892281770706, 45.2814482152462, 48.10467392206192, 47.23922096192837, 53.72087135910988, 60.694519355893135, 62.75366686284542, 65.00134125351906, 58.86470474302769, 58.547334372997284, 64.01466339826584, 64.82933968305588, 60.73581553995609, 47.44103193283081, 51.24842382967472, 60.291623175144196, 65.83387657999992, 65.38255959749222, 65.218416005373, 60.80385848879814, 63.59654903411865, 64.922746270895, 70.34301102161407, 69.13540542125702, 69.34356585144997, 15.74626861140132, 0.25794022309128195, 3.4341830480843782, 2.8622735990211368, 0.5374862055759877, 0.23410775349475443, 0.41059064911678433, 0.19351220136741176, 0.10611401143250987, 0.9751516487449408, 20.037763081490993, 37.98548251390457, 36.930590718984604, 90.71349754929543, 49.188573360443115, 24.27368078380823, 51.207910403609276, 53.82114797830582, 56.673613116145134, 66.93926006555557, 31.810578256845474, 0.5976398871280253, 0.1460185943869874, 0.051012566982535645, 0.1040339792962186, 0.019446616170171183, 0.0360391142021399, 0.04642440966563299, 0.010727355966082541, 0.02989791082654847, 0.0901099901238922, 0.039899770126794465, 0.06337426850222982, 0.0642340540071018, 0.039885988444439135, 0.03100236015598057, 0.05832419847138226, 0.1111875259084627, 0.10910654382314533, 0.023287139483727515, 0.017677011419436894, 0.05277139389363583, 0.07757896019029431, 0.03754580386157613, 0.052619721172959544, 0.10713438285165466, 0.060738449392374605, 0.05357247922802344, 0.014376917260960909, 0.02963792907394236, 0.060173808597028255, 0.06998133467277512, 0.05056774964032229, 0.02492062692908803, 0.04159028976573609, 0.020387049007695168, 0.04722395875432994, 0.024926050173235126, 0.11250463023316115, 0.04875182559771929, 0.06758418283425272, 0.02153846886358224, 0.08383005522773601, 0.08242898431490175, 35.264646112918854, 101.12873867154121, 74.76237148046494, 83.08979943394661, 67.58650973439217, 53.08873347938061, 27.14029636234045, 35.47051526606083, 45.119056329131126, 48.45990926027298, 10.624514892697334, 0.03447710114414804, 0.022296899260254577, 1.0524966171942651, 1.9266544352285564, 1.513260011561215, 4.011360676959157, 1.505258115939796, 0.23321941756876186, 20.393291004002094, 71.62455305457115, 75.20143032073975, 80.90823009610176, 74.10137414932251, 73.57357487082481, 69.26859587430954, 71.0864183306694, 69.90044116973877, 69.30527910590172, 69.57473024725914, 70.84456890821457, 76.56326204538345, 75.42062535881996, 69.91961494088173, 63.98203834891319, 51.28434330224991, 51.35886490345001, 53.156860023736954, 66.37559071183205, 66.26709893345833, 69.13132444024086, 62.419349402189255, 67.78358995914459, 65.45736998319626, 60.20111583173275, 49.24054317176342, 50.97566306591034, 50.56875430047512, 62.11401678621769, 65.97181677818298, 63.39214280247688, 60.295628160238266, 66.26041129231453, 63.454090878367424, 58.65491420030594, 55.97026705741882, 61.82873569428921, 63.31245727837086, 64.20902296900749, 68.42627987265587, 63.11075650155544, 59.054926335811615, 64.78859066963196, 63.97665023803711, 67.3099073767662, 61.076072081923485, 65.02368405461311, 44.088069051504135, 43.4341811388731, 64.44597065448761, 57.571143954992294, 62.75232933461666, 61.57908909022808, 64.1048401594162, 58.960505202412605, 50.950774401426315, 47.84409150481224, 54.04030881822109, 59.23707716166973, 62.65728123486042, 58.14438499510288, 56.05513550341129, 52.880010679364204, 54.83199253678322, 57.872741371393204, 58.33399102091789, 53.064410984516144, 50.78400894999504, 48.060885071754456, 50.12944087386131, 49.401494935154915, 55.29454171657562, 61.3904520124197, 66.04807108640671, 66.97172552347183, 59.39084351062775, 59.45119567215443, 66.92765548825264, 65.88717252016068, 62.213271260261536, 49.72926154732704, 54.348856061697006, 62.9104882478714, 69.24202010035515, 67.10525035858154, 67.50504970550537, 63.28523553907871, 66.61322236061096, 67.16407880187035, 74.29492816329002, 70.59947445988655, 74.03554648160934, 22.546861544251442, 0.21394134499132633, 1.195906384382397, 0.29557500674854964, 2.2474523400887847, 1.5527049824595451, 0.7105879951268435, 0.1754358143080026, 0.2785960037726909, 0.9793202625587583, 25.08558701723814, 36.259231343865395, 30.831093415617943, 83.77995640039444, 46.071372628211975, 33.15867371857166, 61.95374518632889, 63.11562404036522, 63.690913170576096, 74.20151397585869, 44.11595955491066, 0.55859733838588, 0.22629302751738578, 0.06147525360574946, 0.06775233123335056, 0.02632372204971034, 0.01407020617989474, 0.032742045223130845, 0.029928648727945983, 0.024736949089856353, 0.008103527179628145, 0.027021543101000134, 0.10419713304145262, 0.02742197259067325, 0.04430603075888939, 0.07225237335660495, 0.0604584148095455, 0.07821225706720725, 0.055269462973228656, 0.022459782121586613, 0.011817210033768788, 0.04147988416661974, 0.0723709240264725, 0.04905836969555821, 0.14561633550329134, 0.13626935658976436, 0.16368399490602314, 0.09397813802934252, 0.08792414999334142, 0.12257024558493868, 0.19752395484829322, 0.15538997511612251, 0.13249296782305464, 0.12554382352391258, 0.11266492670984007, 0.12268071426660754, 0.10044437425676733, 0.12467233435017988, 0.29616676562000066, 0.149652297841385, 0.13799260865198448, 0.12542885000584647, 0.16203892068006098, 0.3299687127582729, 43.37705500423908, 112.42980346083641, 88.2661172747612, 94.89145696163177, 76.12309366464615, 58.01619507372379, 38.264015167951584, 60.810181349515915, 55.646779015660286, 70.41928812861443, 14.270532298833132, 0.2952492336044088, 0.32025871973019093, 2.013391787186265, 2.2699043853208423, 3.261954439803958, 4.82758822850883, 6.525926571339369, 3.259034533984959, 21.052044555544853, 74.27733510732651, 77.3343014717102, 83.08954104781151, 76.5711960196495, 76.88291609287262, 72.54560843110085, 73.18806275725365, 74.64799761772156, 72.99668982625008, 71.40297174453735, 74.26010683178902, 77.4859057366848, 78.2266303896904, 75.44305175542831, 66.7492550611496, 56.62374459207058, 52.81221091747284, 57.1000262349844, 70.31749919056892, 69.85387846827507, 71.10141232609749, 62.983664721250534, 72.97419503331184, 70.47701463103294, 63.08608442544937, 52.54835307598114, 52.1687838435173, 52.26254761219025, 64.49348330497742, 68.04432436823845, 65.98057150840759, 61.91297337412834, 68.14523935317993, 66.03834360837936, 62.42226764559746, 58.58571991324425, 64.46481004357338, 66.26749411225319, 66.86209380626678, 70.25629967451096, 65.62167316675186, 61.447171568870544, 66.37901052832603, 65.03452107310295, 67.92695626616478, 63.605854734778404, 65.995322316885, 46.9175074249506, 48.00867207348347, 66.46277323365211, 59.88314129412174, 64.78086188435555, 65.3880313038826, 67.16158613562584, 60.470114797353745, 52.7986304461956, 49.81455937027931, 58.391310945153236, 63.572815507650375, 64.41710740327835, 61.5300527215004, 56.61676436662674, 56.43540769815445, 57.50661961734295, 58.865381106734276, 62.0416534692049, 57.188443690538406, 53.152676448225975, 49.59346063435078, 53.46947684884071, 52.95920602977276, 59.09395784139633, 66.11498549580574, 69.0603594481945, 69.7887347638607, 61.60953305661678, 61.752302795648575, 68.72166082262993, 69.85209256410599, 66.29162281751633, 52.63274274766445, 57.323382049798965, 65.77208429574966, 71.42285227775574, 69.78742003440857, 70.69314703345299, 66.78396239876747, 71.54968187212944, 71.34856626391411, 77.88194328546524, 73.75219568610191, 76.62284284830093, 23.06022919714451, 0.5143210454843938, 11.361416950821877, 8.062791153788567, 4.218034436926246, 2.268534558825195, 0.8484524942468852, 0.9087615518365055, 0.24849465728038922, 2.040882599540055, 33.83219137787819, 55.97173757851124, 49.074112102389336, 97.1941713988781, 55.633384734392166, 37.56768733263016, 66.63060262799263, 73.05513828992844, 71.98515370488167, 82.80139490962029, 47.379783019423485, 0.7303523377049714, 0.34223608730826527, 0.3800337575376034, 0.17397967603756115, 0.21494827611604705, 0.1528495442471467, 0.17548792791785672, 0.13384615536779165, 0.13218442734796554, 0.20901140640489757, 0.20017508446471766, 0.310721795540303, 0.15081890946021304, 0.10092233220348135, 0.14468008652329445, 0.26663979690056294, 0.25573809281922877, 0.20546152110910043, 0.1393740126513876, 0.1428296897211112, 0.1623520624707453, 0.13756717991782352, 0.0716865822323598], [0.030332573733176105, 0.0801911938469857, 0.052449008653638884, 0.071785376931075, 0.04208716134598944, 0.023573473044962157, 0.03488773145363666, 0.0745931887649931, 0.03475278674159199, 0.03357440837135073, 0.025603482572478242, 0.03240108773752581, 0.031607702185283415, 0.026272730938217137, 0.035491750604705885, 0.018835973351087887, 0.04582769324770197, 0.03546632833604235, 0.037090217956574634, 0.6226517481263727, 59.93797615170479, 75.97252294421196, 69.62189331650734, 56.676451563835144, 30.045061893761158, 15.332699753344059, 35.22194020450115, 33.146274983882904, 36.694387793540955, 37.565662041306496, 0.7011327962391078, 0.06951050876523368, 0.23472936154576018, 0.8582781732548028, 0.5650283151771873, 0.5330481624696404, 2.882185005582869, 1.3948683394119143, 4.688240680843592, 57.884851321578026, 69.55766156315804, 75.96662566065788, 72.90929451584816, 73.05127009749413, 74.54355642199516, 72.54620119929314, 72.32502266764641, 67.78396233916283, 71.06622621417046, 69.06346768140793, 72.88610056042671, 70.90152785181999, 64.57542210817337, 68.12196180224419, 54.76039297878742, 47.813069969415665, 47.39215515553951, 57.15480029582977, 64.0823681652546, 65.43096899986267, 63.598076552152634, 62.07254201173782, 63.663053065538406, 59.754172414541245, 53.83647255599499, 46.39871746301651, 46.024775728583336, 47.82858073711395, 58.433302491903305, 62.729215174913406, 64.16174590587616, 57.30904921889305, 60.38385562598705, 61.78300514817238, 64.47994843125343, 58.694219291210175, 63.75133752822876, 61.99458919465542, 66.35279193520546, 60.99329352378845, 58.56648914515972, 56.378764137625694, 61.92322142422199, 58.11155095696449, 63.365209847688675, 54.68330651521683, 64.36165317893028, 37.92640708386898, 36.24855391681194, 65.67105531692505, 58.72627817094326, 63.89161080121994, 60.370016768574715, 64.47771415114403, 55.1756688952446, 48.35334777832031, 43.932387605309486, 49.121233373880386, 54.703738018870354, 61.49368107318878, 61.533996909856796, 60.57221531867981, 60.251824110746384, 59.02806557714939, 61.63018494844437, 60.01052565872669, 59.87091355025768, 48.8417811691761, 45.650879591703415, 46.098856553435326, 46.67435847222805, 46.64512664079666, 53.96723113954067, 60.148416459560394, 63.38122598826885, 61.15610718727112, 57.06676661968231, 65.34896939992905, 65.19047990441322, 60.985595136880875, 50.02207763493061, 48.04965667426586, 52.18617171049118, 65.07115110754967, 62.76070788502693, 62.059140130877495, 64.04037281870842, 58.45618486404419, 62.70736634731293, 68.31108525395393, 67.99574017524719, 68.32246944308281, 76.4551654458046, 17.903132624924183, 0.8534008974675089, 3.178272480145097, 2.4261949863284826, 1.5762722678482533, 0.40553816710598767, 0.27011313708499074, 0.17004718392854556, 0.1506622866145335, 6.654363954439759, 35.300671979784966, 31.343387626111507, 70.92836201190948, 79.45251300930977, 22.72033553570509, 33.61898101866245, 41.682376340031624, 50.18625162541866, 59.533172473311424, 68.71369644999504, 11.47989934310317, 0.7795186119619757, 0.06779599920264445, 0.04381461396405939, 0.061658838676521555, 0.01347471801636857, 0.02585607438959414, 0.04846662195632234, 0.05168934629182331, 0.045261827908689156, 0.052662561647593975, 0.04049519520776812, 0.03856437928334344, 0.02303531022334937, 0.0789787620306015, 0.026141903290408663, 0.0775137402524706, 0.005847940474268398, 0.03832002345006913, 0.058984943680115975, 0.06273934632190503, 0.014065187406231416, 0.01684148115600692, 0.011744494404410943, 0.04908693124889396, 0.07926610676804557, 0.016537159790459555, 0.017654886141826864, 0.05895067130040843, 0.038549373057321645, 0.05201331230637152, 0.007167222074713209, 0.028418764122761786, 0.07549983347416855, 0.04465663616429083, 0.020392210644786246, 0.04765345074702054, 0.021540671186812688, 0.046597445107181557, 0.041447630428592674, 0.012860779133916367, 0.019762928786803968, 1.1223626369610429, 72.32924804091454, 86.71929627656937, 75.59309810400009, 66.96274280548096, 42.348712384700775, 26.287498623132706, 30.750710628926754, 35.324614495038986, 39.217490404844284, 38.60622100532055, 1.142885573208332, 0.0713826653372962, 0.4320863331668079, 2.1795096108689904, 2.229356998577714, 1.9625522964634001, 3.665032060816884, 1.5607240959070623, 6.267275400459766, 59.38192538917065, 74.09429132938385, 74.85605925321579, 73.74734714627266, 73.7681396305561, 77.22683563828468, 76.85463041067123, 72.68187671899796, 71.13276824355125, 71.96661069989204, 72.67785653471947, 74.52126681804657, 72.67987802624702, 68.453828394413, 71.61000743508339, 58.14792260527611, 50.63573710620403, 48.54308679699898, 59.547957479953766, 67.17936918139458, 67.32589691877365, 65.02155616879463, 62.36652843654156, 65.85492745041847, 62.48853608965874, 56.39679417014122, 49.303908571600914, 49.545746594667435, 48.872190937399864, 60.29184356331825, 64.39171716570854, 65.68512976169586, 57.905465215444565, 62.317674458026886, 65.42457774281502, 67.44214028120041, 62.13817968964577, 67.53413334488869, 65.05769982933998, 66.84569388628006, 63.482270166277885, 61.59928500652313, 60.24792551994324, 65.10123789310455, 62.58218966424465, 65.78362047672272, 55.562415942549706, 65.78122660517693, 40.03093935549259, 40.94837732613087, 67.21922904253006, 60.99742770195007, 63.82599592208862, 62.004867643117905, 65.71172833442688, 58.103388994932175, 50.67328289151192, 46.7970272898674, 50.33355072140694, 57.71994777023792, 63.59086453914642, 64.21973079442978, 62.47719369828701, 64.71349909901619, 62.952802777290344, 65.01889631152153, 63.94284725189209, 63.02258983254433, 50.71364812552929, 47.793979793787, 48.02495799958706, 49.011666253209114, 47.677060067653656, 56.00693129003048, 62.283681482076645, 67.24311456084251, 60.86165338754654, 58.50686654448509, 68.99232789874077, 67.58432105183601, 63.23618397116661, 51.147565841674805, 50.663950592279434, 54.63881090283394, 66.5112966299057, 65.75639873743057, 65.10029554367065, 66.34640827775002, 61.66254781186581, 64.92232829332352, 69.22976195812225, 72.83979624509811, 67.38173112273216, 81.30232214927673, 22.101951017975807, 0.6730507593601942, 1.5780015313066542, 1.6144628310576081, 2.4533846648409963, 1.252077107783407, 0.8451458998024464, 0.3053362376522273, 0.26116749679204077, 7.619565837085247, 39.77741315960884, 31.461536586284637, 68.50967779755592, 67.75938525795937, 33.21902967989445, 47.48137056827545, 48.40163938701153, 58.151813596487045, 63.658417314291, 79.06890839338303, 18.1390942633152, 0.9347378485836089, 0.1660671943682246, 0.04093992720299866, 0.07343694494920783, 0.07373142172582448, 0.04738934265333228, 0.09655995105276816, 0.08226896243286319, 0.04075798227859195, 0.018894369241024833, 0.012889024346804945, 0.07493212018744089, 0.03773712582187727, 0.031017678084026556, 0.045253805292304605, 0.04915400655590929, 0.028203084875713103, 0.05410316305642482, 0.03336410969495773, 0.043410937578300945, 0.07706980977673084, 0.09444628478377126, 0.09223884815583006, 0.18007667153142393, 0.185897083429154, 0.2005539508536458, 0.14743189589353278, 0.13717725552851334, 0.08338137500686571, 0.22148925403598696, 0.15776573825860396, 0.1372400560649112, 0.23444035439752042, 0.13101962656946853, 0.1442530399071984, 0.1485668623354286, 0.12152319395681843, 0.1287903930642642, 0.10252577194478363, 0.09553474825224839, 0.18234264134662226, 1.2043863418512046, 82.74451956152916, 95.70069193840027, 90.40308460593224, 74.63712260127068, 48.46473880112171, 25.01150619238615, 49.37580071389675, 49.190211072564125, 52.6453048735857, 54.619032964110374, 1.6597750433720648, 0.1493653390207328, 0.4563066194532439, 2.6115523651242256, 2.913934914395213, 2.880096542648971, 8.108140770345926, 5.624990640208125, 4.7890084236860275, 63.92593055963516, 73.42624917626381, 79.78938773274422, 77.41251647472382, 77.7224126458168, 79.68752279877663, 78.75209659337997, 76.88079580664635, 74.48524475097656, 74.9813537299633, 75.46205833554268, 76.22076362371445, 74.21941101551056, 69.66215595602989, 73.26160401105881, 60.9303954988718, 52.75801822543144, 52.05937251448631, 63.77465307712555, 69.65473115444183, 71.58448800444603, 66.52255162596703, 63.559333831071854, 69.60500702261925, 68.50599199533463, 59.01497907936573, 51.81389808654785, 50.755054503679276, 52.84077398478985, 63.23644995689392, 68.15843984484673, 68.62488761544228, 60.22655546665192, 64.00428235530853, 67.78778493404388, 69.46652725338936, 64.81385171413422, 69.96256023645401, 67.34902247786522, 70.671207010746, 64.9420416355133, 64.19801115989685, 62.51345135271549, 68.35819512605667, 63.521381467580795, 68.38809192180634, 58.466710299253464, 64.8094591498375, 43.33504445850849, 47.39573076367378, 71.19524449110031, 64.07616689801216, 66.42246499657631, 65.39104074239731, 69.39089611172676, 60.3940124809742, 52.11390718817711, 49.232134222984314, 54.23927754163742, 59.83475849032402, 65.8826431632042, 65.95882147550583, 65.96432358026505, 65.23559868335724, 67.0354101061821, 69.13862004876137, 66.36015594005585, 65.12489542365074, 53.29668112099171, 51.12186022102833, 50.30369192361832, 51.463811472058296, 50.52000671625137, 58.48136991262436, 65.39159551262856, 69.51007291674614, 63.663231655955315, 58.68264511227608, 71.40683233737946, 72.46334284543991, 66.44153997302055, 55.31758368015289, 52.64816612005234, 58.31161022186279, 72.23482310771942, 68.33655908703804, 68.24767425656319, 69.98511582612991, 65.2027228474617, 68.85392412543297, 73.25002983212471, 75.11455178260803, 70.74733972549438, 83.40598046779633, 23.200378976762295, 1.8315597879700363, 10.345815047621727, 8.27032271772623, 5.653397440910339, 1.7531202407553792, 0.8707532600965351, 0.49318052362650633, 0.28790695883799344, 10.883519444614649, 55.54389953613281, 46.40993446111679, 77.48312428593636, 87.10801541805267, 34.413225799798965, 47.94630981981754, 56.14185445010662, 69.43300545215607, 71.93454802036285, 88.09313535690308, 18.78222305327654, 1.2510943855158985, 0.2317181567195803, 0.20894888788461685, 0.20139183558057994, 0.10148251269129105, 0.15785023919306695, 0.1641469169408083, 0.15188788413070142, 0.15145331213716418, 0.12713026808341965, 0.13924428523750976, 0.15325790358474478, 0.11712081846781075, 0.11040098295779899, 0.2147047923062928, 0.19789079844485968, 0.08333559191669337, 0.27357299986761063, 0.15782565926201642, 0.12431533905328251, 0.18662612477783114, 0.23556363943498582], [0.036812346734222956, 0.028113539192418102, 0.03242112943553366, 0.05885362064873334, 0.032485184201505035, 0.018035435350611806, 0.04792559630004689, 0.03248079068725929, 0.006084681872380315, 0.018609633152664173, 0.10068969859275967, 0.005589888305621571, 0.04832798134884797, 0.03908782346115913, 0.04731704633741174, 0.0829568220069632, 0.04280241730157286, 0.06096519035054371, 0.03433555502851959, 6.109865996986628, 77.33368590474129, 67.14435786008835, 79.45973262190819, 57.06156089901924, 33.869919553399086, 25.93048308044672, 47.66262464225292, 35.324732288718224, 58.66340674459934, 14.349964186549187, 0.13029137189732864, 0.10241034571663477, 0.3522390505531803, 1.074692769907415, 1.5713463071733713, 0.9647631249390543, 3.1391333928331733, 0.038705042243236676, 32.550094574689865, 71.80675327777863, 74.43063408136368, 71.10928550362587, 71.84925779700279, 73.74578163027763, 73.12368661165237, 70.43359816074371, 72.19456806778908, 67.89449080824852, 70.41063979268074, 70.0421279668808, 70.07594615221024, 61.127642914652824, 66.0177031159401, 65.03915682435036, 51.710311844944954, 46.45045928657055, 53.360745683312416, 60.57929053902626, 65.47774448990822, 64.00565028190613, 60.24762533605099, 63.08095470070839, 61.528559401631355, 54.43390689790249, 48.23143891990185, 45.38978800177574, 44.68002408742905, 46.73709310591221, 53.78834813833237, 61.03800192475319, 61.040768176317215, 58.452605456113815, 58.00469309091568, 59.0417942404747, 61.55272230505943, 61.38713099062443, 61.1170756816864, 59.59230110049248, 57.365210205316544, 51.750008314847946, 61.111900359392166, 59.964316338300705, 61.35441854596138, 59.4145542383194, 62.81018503010273, 55.8044895529747, 61.35770156979561, 35.64054474234581, 38.58091056346893, 66.76917359232903, 52.26951643824577, 61.2406412512064, 57.616232335567474, 62.85512901842594, 51.06060370802879, 47.09009416401386, 42.206159234046936, 46.923317313194275, 54.466421753168106, 61.980085372924805, 60.64022786915302, 60.75139470398426, 57.26771883666515, 62.755642756819725, 61.85732915997505, 57.517293244600296, 63.44654828310013, 50.603666827082634, 46.178785264492035, 45.10637640953064, 45.57695455849171, 46.89059726893902, 48.92493210732937, 57.02960841357708, 61.923711597919464, 62.58354239165783, 57.31359377503395, 66.30575805902481, 60.56597985327244, 58.94248276948929, 49.448711201548576, 49.140380546450615, 49.12208452820778, 56.695857122540474, 60.2779059112072, 58.00287678837776, 59.88637492060661, 60.74263237416744, 60.134258419275284, 63.08394514024258, 65.19386172294617, 69.97381523251534, 66.98705390095711, 74.13019180297852, 18.07756796479225, 1.1274432018399239, 1.4758954290300608, 0.598401390016079, 0.5807315662968904, 0.44810921244788915, 0.13798866042634472, 0.0656164599058684, 0.6550376478116959, 17.755797430872917, 30.159428156912327, 59.431231543421745, 62.02211111783981, 19.498402923345566, 16.31215039640665, 46.54610775411129, 55.70133648812771, 55.82342013716698, 57.00516052544117, 54.37139645218849, 4.174845479428768, 0.24175905855372548, 0.031108186703932006, 0.006100749369579717, 0.04294840888178442, 0.06434466369682923, 0.030736856824660208, 0.019708405052369926, 0.041448008923907764, 0.048256204536301084, 0.03656464752566535, 0.03910313025698997, 0.012443567829905078, 0.08128133456921205, 0.03449022973654792, 0.01989633725315798, 0.02529405894165393, 0.05492123244039249, 0.018021837349806447, 0.017103375794249587, 0.04982238475349732, 0.017562062021170277, 0.07409722631564364, 0.12452342984033749, 0.028013807532261126, 0.05894945417821873, 0.030633562855655327, 0.03645163698820397, 0.017361426107527222, 0.04733837937237695, 0.020973677783331368, 0.032218085252679884, 0.04375555756269023, 0.01875319048849633, 0.0985141223645769, 0.03050193925446365, 0.06952060197363608, 0.04110271358513273, 0.07700450078118593, 0.05895549897104502, 0.16561838798224926, 9.077143874019384, 93.82116839289665, 76.08983024954796, 89.33256804943085, 64.2189784348011, 41.34452506899834, 23.025692850351334, 42.33306102454662, 36.690709590911865, 55.54078750312328, 18.01853623241186, 0.0928779857349582, 0.05085772158054169, 1.1627276334911585, 2.2925193468108773, 2.6341243414208293, 3.469270127825439, 2.009670836851001, 1.498287389986217, 35.12214995920658, 76.12186253070831, 75.64945667982101, 74.83031943440437, 73.65101471543312, 75.51876649260521, 75.71762502193451, 74.94677558541298, 74.97786551713943, 71.98465213179588, 72.08217769861221, 72.1159578859806, 70.21999642252922, 64.35466915369034, 69.87777918577194, 67.96854883432388, 54.2138759046793, 50.02383314073086, 56.443026289343834, 63.662631288170815, 68.35164427757263, 65.61611786484718, 61.790745332837105, 66.62567049264908, 64.00629624724388, 57.51676507294178, 50.95927074551582, 47.46142543852329, 46.28377743065357, 48.80447097122669, 56.8668669462204, 63.54564696550369, 63.60443741083145, 61.3595786690712, 58.34578558802605, 61.438158452510834, 62.979291155934334, 63.824514001607895, 62.69485741853714, 61.171291172504425, 58.22046831250191, 57.179001197218895, 61.06286779046059, 60.94712980091572, 62.82254956662655, 62.445127218961716, 64.76588308811188, 57.77164399623871, 63.449040949344635, 37.05871224403381, 42.59304687380791, 69.15790781378746, 54.346625581383705, 63.3419094979763, 59.741412699222565, 64.86652448773384, 53.9665699750185, 49.53152395784855, 45.262586027383804, 47.81480647623539, 56.136318147182465, 63.14512185752392, 62.947452664375305, 63.09596009552479, 59.52670522034168, 64.84769269824028, 62.633293122053146, 62.574818059802055, 65.00821128487587, 53.27590003609657, 48.77872355282307, 48.54537047445774, 47.04353526234627, 48.69755610823631, 52.444478049874306, 60.58512702584267, 63.948364555835724, 63.85732144117355, 57.95502595603466, 68.43063443899155, 62.367744371294975, 62.39693820476532, 51.067268550395966, 52.42081671953201, 50.72966806590557, 57.840097323060036, 63.32208976149559, 59.76984277367592, 62.396033853292465, 64.34354335069656, 62.473211511969566, 64.03258323669434, 67.77784466743469, 73.05953845381737, 69.14688840508461, 79.67553824186325, 23.780535645782948, 0.7541025476530194, 0.19861583219608292, 0.6985979760065675, 2.5298178009688854, 0.9835375612601638, 0.528218918479979, 0.12626257870579138, 0.16688921197783202, 27.00295463204384, 32.33787216246128, 54.402133002877235, 56.295035630464554, 17.874679751694202, 24.88907676190138, 53.99862505495548, 62.45972603559494, 64.18285757303238, 63.229568526148796, 68.40450704097748, 6.1245659831911325, 0.3618884249590337, 0.05617659007839393, 0.03852585439744871, 0.022114891253295355, 0.0899330472748261, 0.02092686867399607, 0.024566034335293807, 0.06752898189006373, 0.04975320916855708, 0.0741752705653198, 0.04361730287200771, 0.030882353021297604, 0.06978833174798638, 0.059093549571116455, 0.0669551755709108, 0.04452925393707119, 0.022953907755436376, 0.02698813346796669, 0.032320000682375394, 0.029132222225598525, 0.03071653682127362, 0.1334823842626065, 0.21301797969499603, 0.10134027266758494, 0.1477891657850705, 0.1735046273097396, 0.081566935259616, 0.1584921227185987, 0.12480459990911186, 0.10850332619156688, 0.09356016787933186, 0.27607985597569495, 0.0950635141634848, 0.23646669957088307, 0.09135509870247915, 0.14517119532683864, 0.1338179685990326, 0.1669030901393853, 0.2043412343482487, 0.25380666833370924, 11.588914543390274, 104.88444194197655, 85.14705464243889, 100.22916734218597, 72.75270491838455, 50.5986662954092, 37.08884082734585, 67.07559674978256, 48.27398903667927, 84.17153298854828, 23.242609910666943, 0.3020493546500802, 0.2334308554418385, 1.4849681546911597, 3.421739428304136, 4.168699784204364, 6.25699077732861, 7.500396156683564, 3.085338966920972, 35.73364354670048, 78.52722465991974, 76.19063884019852, 78.54749277234077, 74.9813461303711, 80.06599009037018, 78.55028182268143, 76.78157553076744, 76.4811484515667, 72.48198464512825, 74.22149330377579, 74.78602901101112, 69.86206322908401, 67.6653403043747, 73.09079557657242, 71.40517562627792, 56.694014221429825, 53.16648110747337, 58.677481189370155, 65.23797735571861, 72.62902155518532, 66.2133926153183, 61.863925606012344, 71.70719102025032, 65.8925910294056, 60.536212250590324, 52.06110902130604, 49.297821298241615, 47.35085517168045, 51.39553293585777, 57.38342262804508, 65.61642944812775, 65.8098466694355, 62.00050547719002, 59.124572798609734, 62.97839820384979, 65.96272766590118, 65.06349831819534, 64.3826812505722, 63.41288208961487, 59.76241037249565, 58.67721140384674, 63.292071372270584, 63.05114910006523, 64.64909255504608, 63.98699328303337, 67.13053420186043, 60.90480387210846, 64.76943969726562, 40.237997844815254, 47.7427813410759, 71.5257279574871, 58.82884606719017, 67.15112909674644, 64.20929655432701, 68.52316707372665, 56.43729619681835, 51.20631828904152, 47.475841864943504, 51.871347203850746, 59.16752949357033, 65.43286889791489, 64.0590450167656, 64.60008278489113, 62.46579051017761, 65.59927716851234, 66.06574013829231, 66.87068894505501, 66.95467203855515, 54.879771173000336, 51.577619165182114, 50.86429864168167, 50.20634114742279, 51.62058725953102, 54.988787323236465, 64.17153418064117, 69.06643152236938, 65.40293410420418, 58.7117363512516, 73.88888195157051, 65.29486030340195, 63.70312191545963, 53.52559983730316, 54.810269102454185, 55.07129609584808, 62.01657101511955, 66.26642256975174, 62.65017941594124, 65.47740250825882, 66.39498487114906, 67.28528469800949, 67.05570101737976, 70.89534938335419, 76.38944417238235, 72.08957970142365, 80.76250791549683, 24.33790873736143, 2.401093770749867, 9.72885925322771, 6.765671856701374, 4.322294192388654, 1.3937591551803052, 0.664645372889936, 0.39392777136527, 1.1329957726411521, 35.86873769760132, 48.331115171313286, 70.18826052546501, 66.38771206140518, 27.09145948290825, 26.97830345481634, 60.93595080077648, 71.88850969076157, 73.02901849150658, 72.71542891860008, 77.29359805583954, 6.470566391944885, 0.4408637137385085, 0.19466264900984243, 0.0834672043856699, 0.10208886960754171, 0.2211006951984018, 0.10276418688590638, 0.14059322769753635, 0.09167068215901963, 0.07885116458055563, 0.11291383561911061, 0.12563763099024072, 0.10978245481965132, 0.16481697239214554, 0.07869556589866988, 0.24483554268954322, 0.13773686456261203, 0.17006593057885766, 0.11727790886652656, 0.10790689921122976, 0.15685628080973402, 0.10686320209060796], [0.04988669927115552, 0.01740902374876896, 0.08902118526748382, 0.03208758600521833, 0.06699812365695834, 0.06154102273285389, 0.05118143526487984, 0.033798837539507076, 0.017126393504440784, 0.09567488057655282, 0.049839491257444024, 0.04597459024807904, 0.0456117022986291, 0.04578283413138706, 0.03985209456004668, 0.012781096593244001, 0.02683677801542217, 0.10863084200536832, 0.024964183576230425, 33.66908133029938, 72.39531889557838, 66.08515709638596, 58.62112641334534, 43.57848219573498, 28.761825151741505, 39.9750367552042, 45.31553618609905, 40.6511040776968, 40.19148454070091, 1.5306433662772179, 0.06906513110152446, 0.11640448268735781, 0.501627114135772, 1.2724712071940303, 0.9045187826268375, 1.8161213351413608, 1.4337378786876798, 4.564402950927615, 62.46770180761814, 79.33465093374252, 72.01123550534248, 73.10942217707634, 73.51076424121857, 68.78597617149353, 69.78808119893074, 68.47123146057129, 70.23583397269249, 68.12418848276138, 70.71145445108414, 64.80976313352585, 68.99308785796165, 58.04058596491814, 67.91361138224602, 59.04258839786053, 48.76385115087032, 47.81906604766846, 62.112075090408325, 62.58628964424133, 67.7796533703804, 62.20178447663784, 63.26979696750641, 61.86658166348934, 57.03057736158371, 47.55647733807564, 46.72562152147293, 45.04323519766331, 45.5659731477499, 46.39899104833603, 53.85273568332195, 58.42216908931732, 60.43282359838486, 59.58660900592804, 58.31966198980808, 57.61237174272537, 61.404450461268425, 58.84452402591705, 59.646854773163795, 55.68945072591305, 54.30346369743347, 56.17005653679371, 58.01964148879051, 58.520203828811646, 60.86689330637455, 59.14561986923218, 61.44727796316147, 54.285114482045174, 59.511692225933075, 35.65853677690029, 35.92282399535179, 63.83381590247154, 48.313115537166595, 51.14338606595993, 46.97643086314201, 50.141585022211075, 43.26352849602699, 44.91114668548107, 43.49692337214947, 43.662070110440254, 45.13461649417877, 59.45878006517887, 58.90597052872181, 64.62326154112816, 56.9748305529356, 46.8473631888628, 47.93058626353741, 61.207370236516, 58.19912485778332, 51.47078029811382, 45.25209479033947, 46.01080007851124, 46.49520568549633, 44.93472062051296, 48.367559015750885, 56.698961555957794, 61.0320058465004, 61.5543220192194, 60.64705230295658, 62.80685640871525, 60.360095500946045, 58.39280426502228, 48.82574982941151, 47.99414165318012, 49.15244109928608, 51.62032127380371, 56.82332128286362, 60.568062141537666, 56.860278099775314, 56.7263238877058, 57.94810652732849, 60.396265760064125, 60.15513449907303, 63.224267810583115, 68.36245089769363, 65.16204223036766, 73.92687991261482, 10.06575582548976, 1.53281839331612, 2.115878937765956, 1.5476606343872845, 1.289542147424072, 0.5136824422515929, 0.07012672140263021, 0.09515632715192623, 4.973504673689604, 20.543316453695297, 31.008788980543613, 34.602060467004776, 41.15554220974445, 22.835528254508972, 24.16114792227745, 38.14341723918915, 50.60454457998276, 53.553395345807076, 68.05247873067856, 32.9380689561367, 0.8187115495093167, 0.07728841679636389, 0.04295547412766609, 0.0382163639733335, 0.08638599698315375, 0.036484632873907685, 0.0393622659612447, 0.010966519548674114, 0.008787571186985588, 0.048939585249172524, 0.03475815989077091, 0.034892384719569236, 0.05951274426479358, 0.0321126668859506, 0.07069341794704087, 0.07045263555482961, 0.11265958324656822, 0.03533080103807151, 0.04914750905300025, 0.008326513798238011, 0.05660109112795908, 0.07243140164064243, 0.01532798321932205, 0.02335215533094015, 0.02207997506047832, 0.12040276618790813, 0.057578763080528006, 0.04830237725400366, 0.03718778440088499, 0.011923740694328444, 0.06248953941394575, 0.05625191806757357, 0.004411314657772891, 0.0348844474501675, 0.029873932035116013, 0.05087957040814217, 0.0648639963765163, 0.07338646406424232, 0.16071620571892709, 0.054607678757747635, 44.99357186257839, 84.76964369416237, 74.52461823821068, 68.72530102729797, 53.45558099448681, 43.603553250432014, 36.7770029604435, 43.73742766678333, 45.52345722913742, 41.15987777709961, 1.9748510490171611, 0.12566541699925438, 0.22057719907024875, 1.7523609939962626, 2.7358458330854774, 4.230949943885207, 1.5520718414336443, 0.767325481865555, 5.379776023328304, 65.05341365933418, 80.01969337463379, 74.75751534104347, 75.81709608435631, 75.83156570792198, 72.25068345665932, 71.68666452169418, 69.84708443284035, 72.02043861150742, 70.79861417412758, 73.38208794593811, 64.4848881661892, 69.06795904040337, 64.24141243100166, 69.64985221624374, 62.0660899579525, 50.78586705029011, 50.97343638539314, 63.16258952021599, 66.30993023514748, 68.70657563209534, 63.64430867135525, 64.42519336938858, 64.35632586479187, 59.45934243500233, 51.12788289785385, 48.54914367198944, 48.002881184220314, 46.06886476278305, 48.70121531188488, 56.05344459414482, 59.83793132007122, 62.842148914933205, 61.42092637717724, 59.367467164993286, 57.83572755753994, 62.7473895996809, 61.1622628569603, 62.15908236801624, 56.35025046765804, 56.80869206786156, 56.19231574237347, 58.70283342897892, 59.26885485649109, 61.3954221457243, 59.48953941464424, 63.87182906270027, 55.094569846987724, 61.30030184984207, 37.77766406536102, 39.914619997143745, 66.69019103050232, 49.94381323456764, 52.597989812493324, 48.83592948317528, 52.007330507040024, 45.85450306534767, 46.943881809711456, 43.789842054247856, 44.909622967243195, 48.2314009219408, 60.01232296228409, 62.94235713779926, 64.7920560836792, 58.67689982056618, 47.53894507884979, 49.254138842225075, 63.32615174353123, 61.35746978223324, 55.63462346792221, 47.28193446993828, 49.01014633476734, 47.1959412842989, 47.22378619015217, 49.501919746398926, 59.0775503218174, 65.74602529406548, 63.2219385355711, 61.47022493183613, 65.5537024140358, 63.167620450258255, 59.9359280616045, 51.46944656968117, 50.455444380640984, 51.40493743121624, 53.686730191111565, 60.610148683190346, 62.24821038544178, 59.09960053861141, 58.952924609184265, 60.930387899279594, 61.74918696284294, 63.5414519906044, 67.166358679533, 71.74638971686363, 65.77060997486115, 79.29890245199203, 12.84919386729598, 1.2949817930348217, 1.1832297896035016, 1.7520809965208173, 2.9008507914841175, 0.7943606155458838, 0.3225343523081392, 0.40615691046696156, 6.645236844196916, 32.64853969216347, 35.21663948893547, 39.149892032146454, 29.77035753428936, 24.156324081122875, 36.06687806546688, 46.97683744132519, 56.53868995606899, 59.95137043297291, 76.32356330752373, 43.00143375992775, 0.8977975370362401, 0.14738907397259027, 0.027466135943541303, 0.03101861133472994, 0.05564252205658704, 0.02376102675043512, 0.03640113754954655, 0.02123179117916152, 0.026841366343433037, 0.013289952930790605, 0.05093460807984229, 0.017380972421960905, 0.0043841140177391935, 0.027708630841516424, 0.03542628946888726, 0.02544874292652821, 0.07638934199349023, 0.13363127392949536, 0.037738472819910385, 0.03775065517402254, 0.005714259732485516, 0.15388439496746287, 0.10069678610307164, 0.1593461714219302, 0.11957294860621914, 0.22030391060980037, 0.10599760556942783, 0.12197355143143795, 0.09235894991434179, 0.10843495212611742, 0.24502897605998442, 0.10351389704737812, 0.08041092150961049, 0.17591847747098655, 0.15547232382232323, 0.15490895952098072, 0.10788612649776042, 0.17726995807606727, 0.30555534933228046, 0.1527082541724667, 55.1340801268816, 95.05281910300255, 85.8742444217205, 77.69741758704185, 59.97013762593269, 41.12054608762264, 56.11090511083603, 60.61679072678089, 55.81637531518936, 58.47473546862602, 2.830769489519298, 0.2289758765255101, 0.3362039109924808, 3.133072955533862, 4.096725471317768, 7.218638425692916, 7.056944277137518, 6.365510104224086, 5.585305569693446, 69.28988993167877, 81.88543885946274, 78.27939435839653, 78.77301827073097, 79.93606746196747, 71.51502013206482, 74.74479362368584, 74.10346403717995, 75.08423700928688, 72.03206598758698, 73.98699268698692, 67.45481640100479, 70.36134123802185, 65.97909718751907, 72.78340727090836, 63.82880017161369, 54.86595131456852, 53.82223851978779, 66.83607280254364, 68.25379952788353, 71.47937804460526, 63.62584926187992, 66.09249830245972, 67.2678816318512, 61.72315835952759, 53.79114858806133, 51.28106027841568, 49.31110538542271, 50.966277569532394, 50.92942714691162, 59.32079806923866, 63.13358187675476, 63.75902071595192, 62.50997073948383, 60.2478951215744, 59.12223972380161, 64.45103198289871, 62.631123438477516, 63.84567126631737, 58.399035930633545, 58.29964466392994, 57.78076730668545, 59.525816068053246, 61.438827216625214, 62.43429400026798, 62.50765286386013, 64.80258151888847, 58.312658965587616, 60.20356670022011, 40.78842870891094, 43.835838586091995, 68.7666504085064, 53.407874554395676, 56.574415639042854, 51.5385040640831, 54.09314498305321, 48.86112593114376, 49.41965036094189, 47.51098617911339, 46.951477602124214, 50.54752103984356, 63.37056376039982, 65.19649118185043, 67.83580675721169, 58.834188580513, 49.83536705374718, 50.580206885933876, 64.13201630115509, 63.46612863242626, 57.277453914284706, 49.8485903441906, 51.68983854353428, 50.13319507241249, 48.61008860170841, 53.968424275517464, 61.8058343231678, 70.20646154880524, 66.36162266135216, 63.08657839894295, 68.79334017634392, 67.10413321852684, 62.69606955349445, 54.80630211532116, 52.89918065071106, 54.93520259857178, 56.79034285247326, 64.77230474352837, 66.09592571854591, 61.7793345451355, 61.82448372244835, 64.53867807984352, 64.99669790267944, 67.03560769557953, 69.51033130288124, 75.72219237685204, 68.52487698197365, 82.60327354073524, 11.167718544602394, 3.851440795697272, 10.884613785892725, 4.435647334903479, 5.884666806086898, 1.3304853066802025, 0.4368716123281047, 0.5924685427453369, 8.629594389349222, 38.06403569877148, 43.34310382604599, 46.46292641758919, 54.50248181819916, 33.454510644078255, 37.16369301080704, 51.9050057977438, 68.40888440608978, 65.9646275639534, 86.47134438157082, 46.9556649774313, 1.1369299865327775, 0.22397158958483487, 0.09615228191250935, 0.15065848681842908, 0.2046556377899833, 0.09640869393479079, 0.2257470740005374, 0.0988971818878781, 0.08856404456309974, 0.08673304007970728, 0.11286287975963205, 0.11315671086777002, 0.10524452605750412, 0.06323483379674144, 0.12337407315499149, 0.19273336190963164, 0.18814488546922803, 0.15619652636814862, 0.17855903890449554, 0.18934326100861654, 0.13616745971376076], [0.0909890937327873, 0.06459069307311438, 0.04874510545050725, 0.037530831032199785, 0.06450877481256612, 0.03197247518983204, 0.04400187266583089, 0.043330574117135257, 0.03905504279828165, 0.004307611116018961, 0.035440097126411274, 0.054698209642083384, 0.0617903138481779, 0.03982265727245249, 0.0462988531216979, 0.07202929860795848, 0.011183178430655971, 0.03663754498120397, 3.0231726402416825, 66.41090601682663, 69.73089426755905, 67.20026805996895, 43.887641206383705, 35.58438755571842, 14.08832922577858, 55.777070224285126, 54.60344620049, 40.47485813498497, 19.92168501019478, 0.08576457446906716, 0.10042152352980338, 0.08694939097040333, 1.1099533340893686, 0.42201485484838486, 3.094030050560832, 1.84273760067299, 0.21842016169102862, 28.90778671950102, 75.14824837446213, 71.46159499883652, 79.50205475091934, 69.17816832661629, 74.00349900126457, 71.38053774833679, 70.16679927706718, 68.9385835826397, 69.84994947910309, 66.41461461782455, 64.14756506681442, 66.09039321541786, 61.238384172320366, 60.31140871345997, 70.38580432534218, 52.69448183476925, 45.88729530572891, 52.38156482577324, 63.40923048555851, 64.51030120253563, 61.92589648067951, 56.12421199679375, 64.40666556358337, 56.846473440527916, 51.553824841976166, 45.02336606383324, 46.49481050670147, 42.33830854296684, 46.76717609167099, 43.96274037659168, 53.77445608377457, 55.213492065668106, 62.48433731496334, 58.038758262991905, 62.19619497656822, 59.832087233662605, 62.789491340518, 59.83777552843094, 62.92886786162853, 59.968560710549355, 60.83672292530537, 51.19770795106888, 59.53224152326584, 53.290153071284294, 60.7907871901989, 56.48516222834587, 59.171222895383835, 49.13917601108551, 60.88981747627258, 30.159760639071465, 38.35914306342602, 68.55471298098564, 47.3153118789196, 49.22204576432705, 39.78075698018074, 45.45050874352455, 45.171501114964485, 48.82853887975216, 44.355795085430145, 44.542836248874664, 43.41075919568539, 47.34255261719227, 54.24904301762581, 58.80010440945625, 60.4204286634922, 55.26230424642563, 47.70623870193958, 55.650962591171265, 60.05619540810585, 54.73019979894161, 44.7572435438633, 44.66733276844025, 42.77240864932537, 46.6844317317009, 46.47087559103966, 55.61817415058613, 60.545928329229355, 61.208001002669334, 61.21872402727604, 61.683237701654434, 59.3688540905714, 58.196540996432304, 49.27807755768299, 48.059315755963326, 48.05356666445732, 48.306264504790306, 49.903607591986656, 53.25503155589104, 56.813973784446716, 56.512684151530266, 59.459220841526985, 58.408356830477715, 58.33265349268913, 59.54331032931805, 65.67062214016914, 65.58647945523262, 69.95383590459824, 68.04734900593758, 3.644127007573843, 1.2073630071245134, 2.253606109879911, 1.4574676053598523, 0.3263635077746585, 0.10791469176183455, 0.11418319758377038, 1.1827809386886656, 15.643398631364107, 27.66244724392891, 21.961725242435932, 22.313913144171238, 33.578053414821625, 9.53535083681345, 23.252198696136475, 40.51489278674126, 52.67262540757656, 53.116908967494965, 67.09369897842407, 9.22667060047388, 0.3679366613505408, 0.031145848843152635, 0.029938482184661552, 0.03626929872552864, 0.050279621937079355, 0.05237889796262607, 0.007691622695347178, 0.0161552858480718, 0.02622998879814986, 0.01124401042034151, 0.026503804183448665, 0.007211739339254564, 0.06798998918384314, 0.017670918387011625, 0.03834249197097961, 0.04666059816372581, 0.008526783276465721, 0.04324995090428274, 0.03410992358112708, 0.05650507206155453, 0.09276195094571449, 0.05474347693962045, 0.010931563465419458, 0.09207022478221916, 0.06700763056869619, 0.030721626098966226, 0.06497274327557534, 0.027628551251837052, 0.03343488831887953, 0.07121613482013345, 0.014347053238452645, 0.07463936519343406, 0.003972659924329491, 0.06522751515149139, 0.051564227615017444, 0.059864997238037176, 0.06357622172799893, 0.05002753663575277, 4.438849138095975, 83.36311116814613, 76.77598223090172, 79.02814418077469, 53.095858097076416, 50.071611776947975, 22.643300369381905, 46.804987862706184, 42.190329283475876, 38.124669045209885, 21.70123592019081, 0.051374994800426066, 0.09247632799088024, 0.8358941681217402, 2.228899598121643, 3.1774030392989516, 4.406507648527622, 1.3150201365351677, 0.3076934174168855, 31.64532132446766, 78.63435611128807, 73.76142159104347, 80.42557999491692, 72.22118943929672, 75.43260231614113, 75.56564837694168, 73.27648401260376, 69.98962238430977, 70.0237749516964, 67.91055634617805, 64.8032958805561, 66.15341663360596, 62.48827390372753, 62.897416949272156, 72.31892019510269, 54.650153294205666, 50.42729929089546, 53.804383277893066, 68.28853726387024, 66.77496448159218, 62.64684699475765, 56.59697122871876, 66.39957502484322, 60.25453336536884, 54.495026618242264, 45.251935198903084, 48.81739027798176, 44.293444231152534, 49.72038522362709, 46.062986478209496, 56.15489535033703, 59.413703083992004, 63.2500646263361, 63.215505480766296, 62.55923509597778, 60.722945630550385, 64.35726061463356, 62.60649316012859, 64.52483922243118, 62.45415933430195, 60.17602577805519, 52.17468872666359, 59.98697832226753, 53.50929111242294, 62.085320726037025, 58.401703387498856, 60.66849075257778, 52.15570114552975, 61.40593998134136, 32.891643047332764, 42.02708624303341, 70.18556267023087, 51.41771234571934, 50.12532189488411, 43.01616556942463, 46.833079755306244, 46.67336292564869, 50.845094472169876, 47.10064239799976, 45.634114891290665, 45.867068991065025, 49.16363909840584, 56.62580028176308, 61.17508336901665, 63.46232123672962, 56.89507283270359, 48.55224050581455, 58.72315093874931, 61.84377148747444, 56.78143993020058, 45.86470551788807, 47.25940927863121, 46.31625048816204, 47.71367870271206, 50.03080956637859, 57.197095826268196, 62.88977175951004, 63.220528811216354, 61.24026507139206, 65.75965896248817, 62.16272257268429, 60.96722312271595, 51.802453100681305, 49.656168669462204, 49.90142650902271, 51.10547550022602, 51.12311415374279, 56.56231328845024, 59.12911355495453, 60.1251845061779, 61.17300868034363, 62.465467527508736, 60.85133694112301, 63.35827901959419, 68.54276642203331, 68.76541167497635, 70.4814375936985, 74.11820724606514, 4.473779713734984, 0.5020636750850827, 2.1845094300806522, 3.299956675618887, 1.505531701259315, 0.46440627076663077, 0.037514811774599366, 0.4926344513660297, 20.006420463323593, 34.483902007341385, 23.61722230911255, 19.69887636601925, 27.391221597790718, 14.906843304634094, 31.923375204205513, 48.12711551785469, 58.92311900854111, 58.4078286588192, 76.64111226797104, 13.569619059562683, 0.4766930005280301, 0.05920264156884514, 0.12529922649264336, 0.030632525704277214, 0.02413596161204623, 0.015633264738426078, 0.01824365786887938, 0.08662280146381818, 0.04434705297171604, 0.06500088551547378, 0.0265431250227266, 0.0798564481374342, 0.10167830609134398, 0.04913344906526618, 0.023087412700988352, 0.016132121563714463, 0.04287929266865831, 0.009229194511135574, 0.06493870096164756, 0.02412274025118677, 0.17712572909658775, 0.14081695553613827, 0.15023393381852657, 0.21225951961241663, 0.14522713841870427, 0.12653413054067641, 0.1886787568219006, 0.1549901653197594, 0.08764494661591016, 0.12861347990110517, 0.12205721373902634, 0.19462530413875356, 0.10948903189273551, 0.14041805115994066, 0.16077428619610146, 0.13745385396759957, 0.1489442741149105, 0.19992135901702568, 5.949744964018464, 98.57517689466476, 85.37839382886887, 88.82171586155891, 61.07244327664375, 53.607580438256264, 24.452088810503483, 75.83036497235298, 68.76993343234062, 58.48144210875034, 29.94357693940401, 0.22365464799804613, 0.2187033207155764, 1.128924647346139, 4.100004695355892, 3.7163133965805173, 11.832099594175816, 7.939220834523439, 2.2883329214528203, 34.67818558216095, 83.31555292010307, 74.69228804111481, 83.72773200273514, 73.88411700725555, 78.81682991981506, 77.12501630187035, 75.58388739824295, 71.41310200095177, 72.72239774465561, 69.19688612222672, 67.82711282372475, 65.13328537344933, 65.96992447972298, 68.34854364395142, 73.73571217060089, 57.67264410853386, 52.72524878382683, 57.22567029297352, 71.45241469144821, 68.54094251990318, 65.53037166595459, 57.83817082643509, 69.485944211483, 63.1614837795496, 57.2144190967083, 48.693965300917625, 50.13883017003536, 47.31324099004269, 50.38947232067585, 49.97864216566086, 58.46120059490204, 62.28313811123371, 65.5917839705944, 63.36413070559502, 64.4627733528614, 64.13576290011406, 67.32458218932152, 67.4276402592659, 67.27386251091957, 64.59788650274277, 62.3479550331831, 53.496626392006874, 60.775983184576035, 56.77118808031082, 62.82720431685448, 61.2672284245491, 61.74700208008289, 52.34958194196224, 61.921063140034676, 36.42191581428051, 45.34178897738457, 71.62443146109581, 54.68493662774563, 53.44965711236, 45.24386823177338, 49.61823530495167, 49.97075378894806, 54.018581584095955, 49.63760286569595, 49.10860285162926, 48.615716099739075, 51.156423166394234, 59.22803744673729, 64.90506961941719, 64.42225232720375, 59.00799125432968, 50.7201723754406, 59.85111281275749, 66.1958147585392, 59.19788606464863, 48.438535407185555, 51.349965780973434, 47.22696661949158, 50.51379784941673, 51.24801345169544, 59.72734585404396, 65.66894263029099, 64.9764221906662, 62.041398882865906, 69.68117773532867, 64.85098332166672, 64.77064803242683, 53.44200052320957, 52.187212854623795, 53.01589518785477, 53.58964540064335, 54.901148825883865, 59.43270966410637, 62.74102494120598, 62.95194022357464, 64.97485667467117, 65.74010521173477, 64.97412711381912, 66.7802082002163, 72.84079179167747, 71.44204884767532, 74.62589040398598, 76.49371817708015, 3.924389756284654, 4.17054696008563, 10.408801417797804, 5.8673364110291, 2.2141742007806897, 0.45954472851008177, 0.17998865281697363, 1.4793336507864296, 27.548939734697342, 40.78087851405144, 32.19881482422352, 34.38887670636177, 48.34939979016781, 18.693406619131565, 36.18933409452438, 56.64419889450073, 68.57183486223221, 66.61804810166359, 84.64852899312973, 15.405467748641968, 0.5005306948442012, 0.2019012309028767, 0.23031917866319418, 0.23396342061460018, 0.21495804277947173, 0.15734676620922983, 0.06419118013582192, 0.1767504695453681, 0.15701367548899725, 0.13698996714083478, 0.11266331624938175, 0.15562146581942216, 0.24110797239700332, 0.19118452939437702, 0.08088494607363828, 0.13176331791328266, 0.1845180691452697, 0.11638339827186428, 0.202200390631333, 0.16817084164358675], [0.0535672211117344, 0.040343537330045365, 0.037714442078140564, 0.04093011601071339, 0.03407204436371103, 0.03150797609123401, 0.029903740396548528, 0.025778455019462854, 0.07919109048089013, 0.06256819222471677, 0.06509304541395977, 0.03717278559633996, 0.011564895594347036, 0.08656055011670105, 0.07302302692551166, 0.02228251087217359, 0.029183486076362897, 0.0829677538422402, 18.88203989714384, 79.82600256800652, 63.91926571726799, 60.074928402900696, 42.69956275820732, 27.754831686615944, 25.83509109914303, 62.88917899131775, 84.61100980639458, 43.45063425600529, 1.9459096645005047, 0.09873704126221128, 0.19573876314098015, 0.82185884937644, 0.6781780498567969, 2.579592280089855, 2.6556167006492615, 1.0271256160922348, 2.9691115161404014, 71.35431915521622, 72.5507153570652, 61.74213834106922, 67.0950897037983, 72.08331763744354, 69.52005118131638, 70.07743567228317, 69.01466310024261, 70.21180406212807, 67.90512263774872, 67.96346470713615, 64.68837484717369, 61.00084751844406, 56.275527477264404, 66.64392471313477, 61.149886921048164, 49.42905105650425, 44.54470194876194, 56.22820861637592, 63.724089190363884, 62.21965491771698, 62.98263497650623, 63.79788503050804, 61.18108704686165, 56.456583961844444, 50.90143024921417, 46.57446563243866, 46.674635857343674, 46.38012886047363, 43.00829619169235, 44.693623557686806, 48.62938776612282, 56.17068350315094, 60.296802297234535, 61.545236706733704, 64.73534032702446, 60.98730504512787, 58.33400622010231, 53.46889168024063, 56.49197146296501, 60.1909513771534, 57.471680492162704, 58.55740763247013, 58.75137962400913, 53.736397325992584, 58.05465281009674, 54.47676859796047, 59.13982518017292, 50.19531413912773, 57.317499965429306, 29.03197355568409, 36.59050136804581, 68.75298634171486, 51.32986105978489, 50.85740201175213, 44.56208221614361, 50.43958403170109, 50.11136904358864, 59.44300331175327, 53.43141809105873, 48.21237534284592, 43.187631368637085, 44.98365819454193, 44.70881134271622, 55.41751831769943, 58.005924224853516, 61.59795127809048, 53.327360674738884, 53.9636555314064, 58.93638029694557, 51.886360198259354, 44.325396716594696, 46.032227128744125, 43.008041605353355, 44.75832648575306, 45.7503392547369, 54.32333283126354, 59.59748022258282, 62.60191060602665, 58.78746248781681, 61.06389753520489, 58.23835015296936, 57.760673984885216, 50.58322012424469, 46.99821129441261, 46.22162036597729, 51.4512949436903, 48.07405896484852, 51.082935109734535, 51.29202648997307, 55.53341589868069, 58.52192133665085, 57.775303199887276, 55.359354838728905, 58.99718463420868, 59.3784561753273, 65.22011071443558, 62.406760677695274, 75.2760811150074, 44.458507373929024, 0.2793578925775364, 1.407817688304931, 1.6349210520274937, 1.0641984455287457, 0.2860830567078665, 0.060598547133849934, 0.11180483692442067, 5.658769877627492, 20.14540370553732, 25.03786537796259, 20.43884865939617, 25.25775007903576, 18.36412388831377, 20.866188928484917, 33.706440925598145, 53.023996353149414, 52.2811172157526, 66.84643104672432, 38.92992943525314, 0.8110386331100017, 0.08891286881407723, 0.04472038664971478, 0.026316660514567047, 0.02560731390985893, 0.03698050626553595, 0.028255701290618163, 0.024338191287824884, 0.06360100946039893, 0.024328220533789136, 0.015995874382497277, 0.07477873310563155, 0.029529395542340353, 0.021872618999623228, 0.06480195283074863, 0.03095423187915003, 0.054439467276097275, 0.01589405172126135, 0.02061035567749059, 0.04728542342490982, 0.03174410892825108, 0.10250090999761596, 0.039676773303654045, 0.04820541937078815, 0.014768933579034638, 0.010882679125643335, 0.038693691094522364, 0.042716402385849506, 0.013041014335613, 0.054600643197773024, 0.02924261112639215, 0.05605209480563644, 0.021129254200786818, 0.029568831414508168, 0.0563065995083889, 0.02950836678792257, 0.03698577180330176, 0.18541513272793964, 25.958555974066257, 92.01251104474068, 70.78796714544296, 67.04031944274902, 51.008888483047485, 40.21464429795742, 25.51133517175913, 59.17040213942528, 76.78637087345123, 41.19906887412071, 2.781142252497375, 0.1996953008347191, 0.17266309121623635, 2.227445226162672, 2.676710793748498, 3.9003788447007537, 4.438382713124156, 2.0087733725085855, 3.1075639743357897, 75.54787293076515, 75.06231218576431, 65.66777989268303, 70.59909448027611, 72.97172516584396, 73.20505544543266, 72.28546679019928, 73.2142661511898, 73.52249041199684, 70.77018409967422, 69.29824188351631, 66.31745383143425, 62.34382085502148, 59.23863507807255, 69.27948608994484, 63.79254251718521, 51.91519305109978, 47.27941520512104, 57.28252284228802, 68.56926620006561, 64.65038448572159, 66.28548994660378, 63.95540177822113, 64.77109640836716, 60.09789817035198, 53.218063339591026, 48.886280581355095, 48.25044929981232, 47.751809656620026, 47.01290510594845, 46.68917007744312, 50.62917485833168, 58.07839393615723, 63.334313705563545, 63.66753302514553, 67.97332137823105, 63.650137558579445, 59.32501204311848, 58.62532898783684, 58.45872312784195, 63.41551534831524, 59.241230338811874, 58.05820181965828, 58.44356954097748, 54.80728626251221, 61.03541046380997, 57.48498737812042, 62.052467688918114, 52.2067704051733, 59.024964943528175, 31.935409158468246, 39.78506214916706, 70.7168273627758, 54.1468209028244, 53.37674282491207, 47.482221722602844, 52.86683298647404, 53.42845804989338, 61.154860854148865, 56.782082095742226, 50.619515776634216, 44.298444762825966, 47.18455709517002, 47.573337033391, 57.38033339381218, 60.20431146025658, 63.27257841825485, 53.72030518949032, 55.288317650556564, 60.961808413267136, 54.78589341044426, 46.04903742671013, 46.821015402674675, 44.6955880522728, 47.406392991542816, 49.0242625772953, 57.53501549363136, 62.44672693312168, 63.83584499359131, 60.65373234450817, 62.18581013381481, 60.99922500550747, 59.708107486367226, 52.97297269105911, 48.72771888971329, 49.35219258069992, 52.56840080022812, 50.83287052810192, 54.08968336880207, 54.73808817565441, 56.592031493783, 59.78709764778614, 60.602397099137306, 59.17684659361839, 61.58654049038887, 61.36296808719635, 69.08978506922722, 63.41135457158089, 79.20945525169373, 51.115066185593605, 0.3266995819285512, 0.4964065208332613, 2.198154260404408, 2.7194518502801657, 0.7325426826719195, 0.23333379736868665, 0.12862765492172912, 3.5630046855658293, 29.510576874017715, 25.683840215206146, 23.047999553382397, 25.05197212100029, 19.183984994888306, 31.853814236819744, 42.613736763596535, 61.50273598730564, 59.99024234712124, 72.82647415995598, 48.99942710995674, 0.8976865117438138, 0.01757713318511378, 0.019624091510195285, 0.06097963996580802, 0.02061027775198454, 0.07948044643853791, 0.039219762475113384, 0.02382048020081129, 0.06581562265637331, 0.02430203941912623, 0.050061259826179594, 0.08629291682154872, 0.04211575258523226, 0.020815262651012745, 0.01202737883431837, 0.048333918530261144, 0.02358445868594572, 0.07244263775646687, 0.05358609763788991, 0.02521071204682812, 0.1136346317071002, 0.20923733100062236, 0.18918876070529222, 0.10191320325247943, 0.08379884049645625, 0.10965795212541707, 0.1582870227866806, 0.11876469041453674, 0.1421386463334784, 0.12323830465902574, 0.2619184908689931, 0.18160665349569172, 0.19906895788153633, 0.16603405005298555, 0.35454929689876735, 0.30638916708994657, 0.1684169378131628, 0.4030583845451474, 33.9973609149456, 103.46176788210869, 82.88906380534172, 75.66372111439705, 59.00447644293308, 40.91358259320259, 38.568967804312706, 81.80802181363106, 95.9923566877842, 63.547440469264984, 3.8096040906384587, 0.20128017204115167, 0.7992448378354311, 2.843507593497634, 3.3567947382107377, 10.53309179842472, 11.43843311816454, 6.612190017476678, 3.092365264892578, 79.05851975083351, 76.77822411060333, 69.360740929842, 72.7492243051529, 77.67225533723831, 74.36420604586601, 76.38337969779968, 74.41368699073792, 76.85069382190704, 71.85871928930283, 71.64890974760056, 68.21144700050354, 63.512060567736626, 63.96354094147682, 72.32828289270401, 64.83881637454033, 54.95527692139149, 48.10785435140133, 62.59503677487373, 70.65410032868385, 67.74172380566597, 69.77556467056274, 64.66116830706596, 68.77709224820137, 62.254096269607544, 55.42489372193813, 51.706428453326225, 51.27192936837673, 50.91494232416153, 47.991212010383606, 50.30215300619602, 53.9061114192009, 62.2973645478487, 64.43511843681335, 67.35427379608154, 70.70123299956322, 67.29617491364479, 63.745356649160385, 62.080741971731186, 60.91163970530033, 65.86065754294395, 62.175026312470436, 58.69087167084217, 60.739212557673454, 58.22604261338711, 62.666598334908485, 60.4837940633297, 63.16770404577255, 54.42412622272968, 58.440351113677025, 35.76413311064243, 45.0536922365427, 73.93517106771469, 57.8998377174139, 55.19322395324707, 52.08915911614895, 56.84211507439613, 55.84118038415909, 64.14018586277962, 59.680289179086685, 53.743438348174095, 47.967596277594566, 49.232502803206444, 50.241485461592674, 59.59688365459442, 61.801190972328186, 66.85857519507408, 55.55765099823475, 57.24227540194988, 62.967724576592445, 58.446628376841545, 49.242887645959854, 50.32970532774925, 47.34860949218273, 50.03726162016392, 50.43975122272968, 60.56842312216759, 66.57285332679749, 67.7725325524807, 61.76353499293327, 65.6880784034729, 64.15538504719734, 63.459820970892906, 56.38703249394894, 51.396254897117615, 52.002409771084785, 57.39116281270981, 53.43486450612545, 56.951963379979134, 57.739577516913414, 61.20970331132412, 64.1444644331932, 64.11354929208755, 61.76010377705097, 65.78728348016739, 65.42276903986931, 72.19485685229301, 65.89734077453613, 81.90011367201805, 50.82239829003811, 0.5583274934906512, 7.930482728406787, 7.471269769594073, 3.7514470238238573, 1.334192007780075, 0.3022828936809674, 0.34373555216006935, 7.978633269667625, 37.69650042057037, 38.45098793506622, 28.496549986302853, 37.52115122973919, 29.445113986730576, 34.26067158579826, 48.586655259132385, 70.04034206271172, 68.29584047198296, 82.09105342626572, 55.9327744692564, 1.1252092779614031, 0.30382840137463063, 0.12150372000178322, 0.0995444979344029, 0.1375737553462386, 0.17698236100841314, 0.14110237068962306, 0.09712938612210564, 0.1295609649969265, 0.15843395318370312, 0.12524654885055497, 0.33811586152296513, 0.12907473952509463, 0.0835723963973578, 0.13972023938549682, 0.14845990401227027, 0.12303812516620383, 0.16459037986351177, 0.16500589350471273, 0.13135644287103787], [0.05180299136554822, 0.08625773902167566, 0.014910353529558051, 0.07026461986242794, 0.008188115316443145, 0.057181561933248304, 0.029701174898946192, 0.013693059718207223, 0.04374973170342855, 0.05194562843826134, 0.047770275923539884, 0.05004420527257025, 0.0611997906526085, 0.03741067732335068, 0.019133606110699475, 0.017417502785974648, 0.03008371677424293, 0.20266911626094952, 46.58449329435825, 73.20828527212143, 70.9478397667408, 67.11604177951813, 52.538830786943436, 24.16461143642664, 40.39877101778984, 37.78076469898224, 43.11797730624676, 16.45198479294777, 0.04776813482749276, 0.0663018629711587, 0.2120635035680607, 0.4389149823691696, 1.329387640580535, 3.812431376427412, 1.3725045206956565, 1.0357804829254746, 28.122237771749496, 87.71415129303932, 66.39267459511757, 73.84514629840851, 60.35320647060871, 66.70049607753754, 66.98611155152321, 71.59206479787827, 64.56304997205734, 66.44656330347061, 67.27709233760834, 68.39544832706451, 66.41402184963226, 63.1588239222765, 64.97819289565086, 62.66778007149696, 52.609704583883286, 48.20222228765488, 44.28865648806095, 53.613823503255844, 62.86396734416485, 60.510898008942604, 67.71184220910072, 62.32049770653248, 61.06737054884434, 57.90151722729206, 52.58225105702877, 52.31887198984623, 50.51809921860695, 47.761062160134315, 44.52962435781956, 42.95237459242344, 46.66415981948376, 51.65078803896904, 58.34507882595062, 59.97249349951744, 61.32851533591747, 56.60870119929314, 52.10456728935242, 49.19455423951149, 56.175224259495735, 59.199546575546265, 61.6874972730875, 55.477691888809204, 55.670770928263664, 57.56166346371174, 61.78031109273434, 55.607211738824844, 61.266947239637375, 53.87354716658592, 61.25767953693867, 31.748810671269894, 40.97724437713623, 66.27000197768211, 48.26515831053257, 56.53208591043949, 51.25926084816456, 57.31956705451012, 58.56109343469143, 62.001653015613556, 54.844174683094025, 54.75470468401909, 45.79792410135269, 46.07910141348839, 45.41837386786938, 48.00850108265877, 55.95818370580673, 61.13229766488075, 56.01636618375778, 54.23095218837261, 57.70300827920437, 53.80486585199833, 45.63830986618996, 44.00068134069443, 44.660059958696365, 45.10188885033131, 45.41783809661865, 51.12396910786629, 60.83281293511391, 59.90132711827755, 60.148203670978546, 62.37528696656227, 59.90783616900444, 57.15092070400715, 48.009793013334274, 45.90258948504925, 47.55225956439972, 45.3651425242424, 48.22365313768387, 47.28561267256737, 49.48093727231026, 49.69632871448994, 53.24140548706055, 50.17861023545265, 53.9668283611536, 51.743575260043144, 58.19605462253094, 56.6043808311224, 67.89968132972717, 63.45654554665089, 76.77376314997673, 15.34459501504898, 1.2467386317439377, 2.722443714737892, 1.262913888785988, 0.4599046701332554, 0.1398466419777833, 0.05528379013412632, 0.8732765621971339, 13.75032976269722, 29.380724541842937, 19.989701360464096, 17.64839429408312, 48.81028465926647, 18.79287578165531, 34.65777687728405, 40.646358132362366, 50.18943965435028, 52.27859415113926, 58.57929065823555, 6.37974176555872, 0.11026548163499683, 0.04222118208417669, 0.054398200154537335, 0.020386794822115917, 0.048779741482576355, 0.06024937036272604, 0.07408102523186244, 0.020555677947413642, 0.0651451144949533, 0.04698621545685455, 0.026867055785260163, 0.02860508771846071, 0.01702908681181725, 0.029896886662754696, 0.036445855657802895, 0.003102372565990663, 0.041268171698902734, 0.018403746544208843, 0.0653398763097357, 0.07191050302935764, 0.0191246372560272, 0.048720458726165816, 0.024922059274103958, 0.11004778745700605, 0.030949971951486077, 0.036697577306767926, 0.0642727421654854, 0.031050644283823203, 0.09399775299243629, 0.05278819240629673, 0.013199276399973314, 0.021149531530681998, 0.006867770589451538, 0.01581272346811602, 0.030409406426770147, 0.059947932240902446, 0.6281463126651943, 59.44613814353943, 81.93414464592934, 77.9559937119484, 73.52711096405983, 54.606866016983986, 26.794849298894405, 35.35316616296768, 46.06259509921074, 55.635220035910606, 18.8326121494174, 0.17711839667754248, 0.06883745503728278, 0.34092494985088706, 1.5115594840608537, 3.7928754882887006, 5.523764546960592, 1.802151147276163, 1.8018450262024999, 31.121880412101746, 91.93239614367485, 70.83314672112465, 77.27189362049103, 65.1323202252388, 69.86460149288177, 69.71797496080399, 73.80764991044998, 68.04389119148254, 69.4320023059845, 69.00880381464958, 70.61256095767021, 67.5755663216114, 66.51997536420822, 66.89061507582664, 66.45923182368279, 55.8977859467268, 49.44592595100403, 48.04244466125965, 56.91108517348766, 65.6613278388977, 63.3373649418354, 70.03613948822021, 61.73370659351349, 63.853042870759964, 59.31961253285408, 55.005928203463554, 54.877240508794785, 52.13562682271004, 49.38534960150719, 48.69456946849823, 45.57785890996456, 49.37570571899414, 53.518270030617714, 61.247705072164536, 63.15869092941284, 62.69692450761795, 59.21161852777004, 54.182197004556656, 51.17528535425663, 57.63933889567852, 60.890307649970055, 62.97919996082783, 55.06520502269268, 57.989604100584984, 58.42827536165714, 64.04183954000473, 59.790000692009926, 64.66517329216003, 55.22528663277626, 63.44997949898243, 34.302313551306725, 44.352664053440094, 69.36512589454651, 51.72344394028187, 58.03173243999481, 54.72458370029926, 59.95392009615898, 59.413171112537384, 63.31640146672726, 56.852807700634, 57.108598574995995, 48.07716339826584, 47.571927309036255, 49.81752701103687, 52.315805554389954, 58.153356313705444, 62.01072312891483, 56.72071538865566, 56.634159833192825, 61.56558461487293, 55.6996987760067, 47.28486031293869, 46.259185150265694, 46.897429302334785, 48.161617666482925, 47.640487030148506, 54.92378041148186, 62.07218863070011, 62.54161164164543, 59.002435952425, 65.59268072247505, 63.00531975924969, 59.507421255111694, 51.546122655272484, 48.35121989250183, 49.785243943333626, 46.99497766792774, 50.45825242996216, 50.491033270955086, 52.40983910858631, 52.93091654777527, 55.12170419096947, 54.83508177101612, 54.86943572759628, 54.254503324627876, 59.89820368587971, 59.24756459891796, 71.2202775478363, 66.33714437484741, 78.81981655955315, 18.477234318852425, 1.1390259303152561, 0.9864991460926831, 3.4747957438230515, 3.6536547588184476, 0.4512025136500597, 0.05894571375392843, 0.4438410617876798, 14.157323073595762, 33.54733966290951, 23.64026617258787, 18.923510871827602, 42.65205770730972, 20.91495171189308, 44.51553471386433, 47.641995549201965, 55.547022968530655, 58.51624444127083, 68.4129349887371, 9.908117484301329, 0.2911618404323235, 0.017018394319165964, 0.06547214929014444, 0.017552237841300666, 0.0582582586503122, 0.025727289503265638, 0.07098897825926542, 0.027435036245151423, 0.031674317360739224, 0.027459363845991902, 0.06310401542577893, 0.05324263169313781, 0.04793483603862114, 0.03156229759042617, 0.04112483700737357, 0.08922807377530262, 0.009315729857917177, 0.03287159823230468, 0.03036602975043934, 0.12795930641004816, 0.17563197878189385, 0.1658423978369683, 0.18401606561383232, 0.18372796388575807, 0.16328889032592997, 0.1537798115168698, 0.18061505514197052, 0.12972198135685176, 0.24038299801759422, 0.1319010605220683, 0.17555268772412091, 0.1607715550926514, 0.10950394906103611, 0.14766237727599218, 0.11047801788663492, 0.08202793513191864, 1.1530601209960878, 75.40011405944824, 90.52256539463997, 88.99108037352562, 81.79000318050385, 70.57443380355835, 34.336074739694595, 59.58279401063919, 51.97812907397747, 61.52564875781536, 25.920472517609596, 0.3765117918374017, 0.21542820817558095, 0.856193391373381, 4.02769030071795, 5.018292395398021, 12.284760754555464, 9.154002349823713, 6.071417760103941, 33.22170473635197, 96.16571098566055, 71.74286350607872, 80.45334130525589, 67.55868762731552, 73.41095119714737, 71.22570365667343, 77.15967804193497, 71.16853192448616, 71.0246716439724, 72.20657542347908, 73.7509873509407, 70.20132422447205, 69.74292442202568, 69.73018750548363, 68.27944055199623, 57.55452364683151, 52.9486957937479, 49.93262283504009, 61.83590590953827, 67.62269899249077, 66.33244782686234, 69.9418893456459, 63.24850291013718, 67.3264592885971, 62.40698106586933, 59.01883207261562, 57.11461745202541, 55.2530213445425, 51.582243517041206, 49.56519015133381, 46.86572000384331, 52.40951232612133, 56.53805159032345, 63.78341540694237, 66.37274086475372, 65.61945408582687, 64.22942787408829, 57.36517980694771, 55.83473972976208, 59.082839637994766, 65.6666399538517, 64.70846056938171, 57.50187747180462, 60.20052306354046, 60.636868849396706, 65.17171651124954, 61.86418019235134, 66.46981805562973, 59.09268870949745, 63.45824785530567, 39.19457383453846, 46.98605954647064, 71.7634280025959, 54.84685353934765, 59.97943192720413, 56.7228926718235, 60.98588392138481, 63.152786046266556, 67.23304510116577, 58.48184488713741, 59.26138065755367, 51.4542967826128, 50.078189224004745, 52.366734221577644, 54.29336003959179, 61.37217499315739, 65.77947109937668, 59.43801037967205, 58.131233900785446, 62.47592456638813, 57.60020859539509, 50.28139851987362, 48.446286991238594, 49.037873446941376, 49.837354347109795, 50.62179945409298, 56.96079410612583, 67.42037504911423, 64.18807849287987, 61.19991883635521, 68.68766784667969, 64.6041713654995, 62.70602881908417, 52.919881939888, 49.75256949663162, 53.08727815747261, 50.72942487895489, 53.83214458823204, 54.038013741374016, 57.061762288212776, 53.83997976779938, 58.2603395730257, 58.77555012702942, 59.65952709317207, 55.48237703740597, 64.4302698969841, 61.92668303847313, 74.59601640701294, 69.96841952204704, 82.48048692941666, 19.011303260922432, 2.9446759773418307, 10.948573853820562, 5.9348459634929895, 4.077710816636682, 0.5340009019710124, 0.16160436352947727, 1.8884820397943258, 20.9740062430501, 45.35756193101406, 29.558904580771923, 25.201281309127808, 62.88676232099533, 29.037251472473145, 49.829329177737236, 55.960896760225296, 67.10208132863045, 66.40414997935295, 78.41625541448593, 11.982225738465786, 0.40036839607637376, 0.13382267381530255, 0.205472371308133, 0.11710319246049039, 0.24832743656588718, 0.10263405129080638, 0.1878373691579327, 0.1343828023527749, 0.20945423108059913, 0.11029461093130521, 0.09808976974454708, 0.1334045032854192, 0.23398277582600713, 0.1344283256912604, 0.09928923624102026, 0.18155348603613675, 0.11350105254678056, 0.12806705140974373, 0.1726466155378148], [0.020790432245121337, 0.043002767488360405, 0.02138824147550622, 0.08735728275496513, 0.03865812366711907, 0.03799086611252278, 0.0345033360645175, 0.012545465633593267, 0.02800241742079379, 0.029788876345264725, 0.0327332915912848, 0.04590983044181485, 0.029680520929105114, 0.019342439045431092, 0.05843067068781238, 0.15245617629261687, 0.07450385644915514, 12.652362529188395, 77.49399170279503, 65.79757332801819, 69.00621995329857, 55.28110943734646, 37.209704741835594, 28.01621586084366, 41.63749694824219, 39.747387170791626, 33.47432658076286, 7.029076097533107, 0.2361287403618917, 0.09078420902369544, 0.1476646334049292, 0.6855126062873751, 3.3741049468517303, 1.802741065621376, 2.787057110108435, 1.2648367043584585, 73.29645574092865, 73.90032693743706, 68.59320491552353, 64.67298567295074, 67.8431935608387, 61.888582482934, 67.3567208647728, 64.88314479589462, 66.29767209291458, 63.313734009861946, 65.01306742429733, 62.99683101475239, 65.25608718395233, 66.27149909734726, 62.622847482562065, 55.2874892950058, 46.61442048847675, 47.11410127580166, 45.46913154423237, 50.32827280461788, 56.20962381362915, 62.62806460261345, 60.200184881687164, 57.75983422994614, 61.278164237737656, 59.80174586176872, 57.34327778220177, 55.582456067204475, 57.00849674642086, 49.93689000606537, 46.70276194810867, 43.41432720422745, 44.78977359831333, 45.69415546953678, 52.18980431556702, 58.31896662712097, 57.82565049827099, 48.7970195710659, 45.78287310898304, 51.35628864169121, 56.96615941822529, 61.82636082172394, 59.70634438097477, 53.61514963209629, 60.164170414209366, 56.401034742593765, 60.54225392639637, 58.868956714868546, 63.810682743787766, 53.97800736129284, 60.02418592572212, 33.02653580904007, 37.11179539561272, 66.83613359928131, 56.67805127799511, 59.85861361026764, 54.78391371667385, 59.67221461236477, 51.03987202048302, 56.15175671875477, 59.75118197500706, 54.89599250257015, 51.388571709394455, 50.659166648983955, 49.52902369201183, 51.88508726656437, 52.30892412364483, 58.73010836541653, 56.75137214362621, 58.63737814128399, 57.5812704116106, 53.612949550151825, 46.4189475774765, 43.87360475957394, 44.4928727298975, 43.292000368237495, 45.64418435096741, 52.60314233601093, 58.64918410778046, 60.58700032532215, 57.903356328606606, 62.25689671933651, 61.40807546675205, 56.096545681357384, 46.86028629541397, 44.4096951931715, 45.87808080017567, 45.053840428590775, 47.66326680779457, 46.22502498328686, 47.31831751763821, 47.92186193168163, 50.08908323943615, 51.0027290135622, 49.81258347630501, 49.10778969526291, 52.85523220896721, 55.559087321162224, 62.50940836966038, 62.75486379861832, 71.02048426866531, 50.4666917771101, 0.9524853306356817, 1.3722792640328407, 3.2773141656070948, 0.22085630596848205, 0.42641623585950583, 0.14545882208039984, 0.1330712196067907, 5.018507083877921, 25.658345483243465, 24.94884755462408, 86.46015778183937, 131.69842511415482, 75.60266599059105, 19.3737069144845, 35.31205236911774, 51.04057498276234, 47.82700762152672, 60.56268163025379, 30.93257836997509, 0.8007573941722512, 0.16295247478410602, 0.0268021790907369, 0.024658860311319586, 0.10353708916227333, 0.02784590033115819, 0.04403724342409987, 0.05882177509192843, 0.026589449880702887, 0.028010339847241994, 0.009150618698186008, 0.02999492808157811, 0.010451688922330504, 0.060785946843679994, 0.045508120747399516, 0.04241533904860262, 0.019966598229075316, 0.06576793966814876, 0.0519260728469817, 0.026872688686125912, 0.029918850523245055, 0.018971174104081, 0.05800116756290663, 0.08873908009263687, 0.011156462969665881, 0.04427808889886364, 0.008874785598891322, 0.055502452814835124, 0.017767037643352523, 0.02035040732152993, 0.04313375655328855, 0.028202147914271336, 0.031840372903388925, 0.0068000820829183795, 0.061664553213631734, 0.0893328279198613, 16.120123900473118, 89.24217090010643, 75.06322413682938, 78.61104056239128, 62.52727501094341, 51.310976073145866, 31.947549507021904, 37.133610025048256, 40.63500814139843, 40.249119848012924, 11.127382759004831, 0.33287264755927026, 0.07117453002138063, 0.8308021444827318, 2.3157541500404477, 5.5417808052152395, 3.004673570394516, 2.685304507613182, 1.5628745430149138, 75.12307092547417, 76.27041935920715, 71.60741597414017, 67.49861285090446, 70.15635743737221, 64.55639272928238, 71.01046800613403, 68.51767256855965, 67.45591834187508, 66.4622412621975, 65.92340737581253, 65.48095151782036, 68.16958844661713, 70.1981095969677, 64.09848690032959, 58.29535089433193, 49.549561589956284, 49.18633908033371, 49.14012975990772, 53.49780432879925, 59.96425174176693, 65.50349190831184, 63.60082380473614, 57.66506731510162, 64.11956816911697, 61.74748845398426, 60.73534816503525, 57.529684379696846, 58.68734925985336, 53.26764687895775, 50.57231090962887, 45.426672622561455, 47.442441657185555, 46.64966739714146, 55.01515410840511, 58.98898467421532, 59.6374236792326, 53.64549480378628, 48.70240844786167, 54.36684809625149, 58.18919979035854, 63.953897058963776, 60.483174696564674, 55.0370979309082, 62.179133892059326, 59.040194526314735, 61.92736700177193, 60.57233311235905, 65.4684729874134, 55.52473336458206, 62.46805138885975, 36.33916765451431, 39.174305722117424, 67.16990768909454, 57.86464020609856, 63.26529040932655, 57.762946262955666, 60.1305840164423, 53.70293632149696, 58.24758365750313, 61.57577186822891, 58.25964041054249, 53.32323029637337, 52.68184371292591, 50.548391193151474, 54.92254547774792, 55.50970897078514, 61.14868238568306, 58.088227808475494, 58.553835824131966, 60.471076145768166, 54.96295250952244, 48.78050945699215, 45.770117193460464, 44.90476302802563, 44.98280704021454, 47.91901968419552, 55.48187546432018, 60.491629242897034, 62.37509697675705, 58.941760808229446, 62.10931643843651, 64.460029900074, 59.451313465833664, 51.56950280070305, 46.52778133749962, 48.03465127944946, 49.06955614686012, 49.038181230425835, 48.11677627265453, 49.720354825258255, 50.51640070974827, 52.17579826712608, 54.0849944204092, 52.11697742342949, 52.10687376558781, 54.829218685626984, 58.45857113599777, 64.65904042124748, 66.29918441176414, 70.64083144068718, 56.589747816324234, 1.2909840513020754, 0.7328455382958055, 2.014417969621718, 3.3499220944941044, 1.54293178813532, 0.3349888668162748, 0.05453275894979015, 2.437897170893848, 33.6968008428812, 21.98268111795187, 71.82331278920174, 109.87707763910294, 68.34478184580803, 30.413537621498108, 41.52059622108936, 58.133547976613045, 53.41896615922451, 69.87375140190125, 40.884962528944016, 0.9075529198162258, 0.11100005198386498, 0.06278440210735425, 0.03538424309226684, 0.09888387518003583, 0.02152027140255086, 0.05084955795609858, 0.04455103597138077, 0.053562604953185655, 0.06000642089929897, 0.03643572905275505, 0.0262641739755054, 0.05555277042731177, 0.018974068480019923, 0.025939400875358842, 0.04650052433134988, 0.028996546498092357, 0.04304365240386687, 0.04631421928934287, 0.22305726364720613, 0.21774131921119988, 0.12136302364524454, 0.16244953614659607, 0.21351125556975603, 0.13258716120617464, 0.1403711919556372, 0.08673424235894345, 0.1653813905431889, 0.16488453751662746, 0.1390154959517531, 0.1493572347681038, 0.12631587975192815, 0.1284525525989011, 0.09961760690202937, 0.33099453896284103, 0.2885329455602914, 19.122603088617325, 100.82154795527458, 82.25970357656479, 91.46204978227615, 71.01882755756378, 53.61774869263172, 39.83583502471447, 54.39471200108528, 55.916245356202126, 55.2149473875761, 13.50258780643344, 0.5850929010193795, 0.3147690533660352, 1.5825140266679227, 3.5186335165053606, 10.232220143079758, 7.230963539332151, 10.9986855648458, 1.4144835993647575, 83.17613080143929, 78.69871705770493, 73.70859682559967, 71.03775054216385, 72.66719430685043, 68.4128437936306, 73.83232578635216, 69.64099869132042, 71.8823692202568, 67.86340087652206, 69.96542528271675, 68.22833329439163, 70.52104666829109, 71.8421445786953, 67.61503860354424, 61.57800994813442, 51.5278722345829, 51.14419922232628, 50.78207865357399, 54.25665780901909, 62.58518390357494, 69.77592945098877, 65.64520910382271, 58.76921586692333, 65.3821188211441, 64.86953392624855, 62.75630012154579, 59.930384159088135, 63.5339891910553, 54.51374441385269, 51.563924700021744, 46.83711513876915, 49.26686055958271, 49.3375139683485, 59.16242636740208, 61.23955450952053, 62.9254974424839, 54.39062722027302, 50.66806957125664, 57.915257290005684, 62.50690430402756, 67.79749721288681, 61.22357256710529, 57.39665351808071, 63.62767316401005, 61.695818826556206, 65.36708682775497, 64.27582338452339, 68.56168180704117, 58.66841487586498, 64.17562276124954, 40.34238964319229, 43.14834527671337, 67.14579418301582, 61.15899883210659, 64.83196914196014, 60.55710352957249, 63.48481982946396, 55.290479734539986, 60.058327093720436, 64.68946158885956, 59.29698474705219, 57.044712603092194, 55.56384086608887, 53.034578785300255, 56.72206051647663, 57.53845430910587, 64.5894205570221, 59.89996299147606, 61.68841302394867, 63.75899791717529, 58.09716112911701, 50.352192521095276, 48.24265591800213, 47.06042155623436, 48.161461874842644, 50.60201771557331, 59.06259812414646, 64.86345425248146, 65.40633112192154, 60.61952278017998, 64.3139961361885, 67.44068115949631, 61.43552139401436, 52.28530079126358, 49.18782480061054, 49.91778463125229, 52.40188613533974, 52.91063703596592, 51.13173969089985, 53.53073716163635, 53.50528232753277, 55.588801726698875, 57.270823270082474, 55.86926847696304, 55.006589367985725, 58.318848833441734, 60.846788585186005, 67.43428230285645, 69.68457475304604, 74.90716651082039, 57.59694457054138, 1.4306797552853823, 7.117941454052925, 9.205341394990683, 2.6109755085781217, 1.6653217957355082, 0.4770296684000641, 0.12555056222481653, 7.084021624177694, 41.18964917957783, 38.71925354003906, 90.78137710690498, 130.12851655483246, 85.62885358929634, 30.307114832103252, 48.760036155581474, 65.33811718225479, 61.421146765351295, 78.05674910545349, 46.73253335058689, 1.310733372811228, 0.2860171243082732, 0.2450199070153758, 0.13650632434291765, 0.22991231846390292, 0.12690541218034923, 0.11169044228154235, 0.1371941319666803, 0.12991495459573343, 0.14452531904680654, 0.1699873074539937, 0.06524897806230001, 0.16653669183142483, 0.119456609536428, 0.12106871756259352, 0.06959941805689596, 0.09025476829265244, 0.13797978434013203, 0.10530449158977717], [0.05500478713656776, 0.023179568888735957, 0.062057427639956586, 0.0569467649620492, 0.10034638849901967, 0.02752267275354825, 0.08048889896599576, 0.02051206749456469, 0.035638799745356664, 0.07545294458395801, 0.0883067271206528, 0.08352028278750367, 0.027468249209050555, 0.06905513437232003, 0.05470700409205165, 0.027954324395977892, 0.010908799013122916, 42.086636647582054, 69.76915821433067, 64.85075533390045, 59.69203434884548, 46.388492211699486, 19.849925860762596, 29.52225174754858, 56.23334214091301, 36.355985552072525, 30.30851125717163, 0.6893318763468415, 0.05520120765140746, 0.0823444536945317, 0.3637209360022098, 0.6637255847454071, 4.519263273105025, 1.405132538639009, 1.703577192965895, 20.869728438556194, 87.54910334944725, 66.90934047102928, 73.26333671808243, 59.85184237360954, 67.44138032197952, 61.72231860458851, 68.40468183159828, 64.62437108159065, 65.81958174705505, 60.7613767683506, 63.80933001637459, 56.28473438322544, 58.8687477260828, 55.17373479902744, 54.67742063105106, 46.17721974849701, 47.40678817033768, 45.93312844634056, 48.53089705109596, 45.882374569773674, 58.775417134165764, 58.48668582737446, 64.1050073504448, 58.735766261816025, 62.49056898057461, 60.140889063477516, 61.39342725276947, 60.91666683554649, 59.44993793964386, 53.80824767053127, 48.79257760941982, 42.272925451397896, 45.83236165344715, 42.592153921723366, 44.718808606266975, 47.076718881726265, 46.46618664264679, 44.65178020298481, 49.79299172759056, 53.13053883612156, 61.298572942614555, 57.95026861131191, 52.31157258152962, 57.85223767161369, 60.6728795170784, 56.32944278419018, 59.094440415501595, 54.97701935470104, 59.46608707308769, 56.92892521619797, 64.30716410279274, 35.795717015862465, 32.88606494665146, 51.72785170376301, 52.020614594221115, 59.28614392876625, 56.522742211818695, 56.656479835510254, 53.18473532795906, 49.65507432818413, 50.80990456044674, 56.95045106112957, 56.911214366555214, 56.47624030709267, 55.65548814833164, 53.57233352959156, 53.72839495539665, 58.58475096523762, 56.85212753713131, 57.27634437382221, 57.976544201374054, 55.159861743450165, 47.11853563785553, 43.83522681891918, 43.55135925114155, 42.652642875909805, 45.3452467918396, 51.44943684339523, 58.50145563483238, 60.07232554256916, 58.038594871759415, 59.82325650751591, 59.10146623849869, 56.379467099905014, 45.147361010313034, 45.904310792684555, 45.011377707123756, 46.113649159669876, 45.813860446214676, 46.367783322930336, 45.757957845926285, 49.277507588267326, 49.16516661643982, 49.02274265885353, 47.90654115378857, 53.50631587207317, 55.075164288282394, 60.18187366425991, 60.361406430602074, 64.99707788228989, 65.37488400936127, 77.41710662841797, 14.651013482362032, 0.4922967148013413, 2.6589106488972902, 4.740012902766466, 0.21437634743051603, 0.20923713804222643, 0.05522240709979087, 0.3422072919784114, 24.173037484288216, 37.58794404566288, 46.783549413084984, 61.01783640682697, 29.555028788745403, 19.479719325900078, 29.921680614352226, 34.434003084897995, 49.115305691957474, 55.9263452142477, 52.93997526168823, 7.688662754371762, 0.31698638282250613, 0.04987366344721522, 0.12099792409571819, 0.026548344176262617, 0.026177123763773125, 0.08362646185560152, 0.05483302076754626, 0.04980761972547043, 0.049279418381047435, 0.0478210870642215, 0.01631189756153617, 0.055716362039675005, 0.09408729310962372, 0.014048220982658677, 0.03247339147492312, 0.044188945830683224, 0.03152967648929916, 0.05917726753978059, 0.020942346163792536, 0.053516758780460805, 0.05315832742780913, 0.051373239621170796, 0.043208746865275316, 0.04579381049552467, 0.05224033899139613, 0.02258138487377437, 0.03881765944242943, 0.06400587328244, 0.013756766602455173, 0.054066608572611585, 0.02673528932064073, 0.01872039498266531, 0.04786440251336899, 0.07847619446692988, 0.1025838969508186, 48.398094177246094, 82.84315466880798, 71.69299498200417, 68.40625494718552, 52.586396634578705, 31.487291604280472, 25.373676158487797, 43.10787744820118, 38.55295166373253, 39.19913738965988, 1.7104612360708416, 0.158493607013952, 0.12017566899885423, 1.7883253516629338, 2.8928047232329845, 5.053821438923478, 1.8042480410076678, 1.4106354746036232, 24.03447411954403, 90.56937128305435, 68.31009730696678, 75.03731712698936, 63.18235985934734, 70.65011814236641, 65.20573228597641, 70.77053368091583, 67.74083465337753, 67.09350898861885, 63.88781860470772, 66.78305044770241, 59.50273610651493, 59.958434253931046, 58.036485984921455, 56.479264944791794, 49.399317651987076, 50.33455766737461, 48.59857901930809, 51.31937362253666, 47.82541550695896, 59.77648861706257, 60.63678525388241, 64.63278383016586, 60.40105350315571, 66.03175476193428, 61.18948079645634, 63.71958643198013, 62.57526643574238, 61.721433252096176, 57.047646045684814, 50.0050051510334, 45.90608909726143, 48.004553094506264, 45.985311046242714, 46.41647391021252, 49.20884907245636, 49.13471885025501, 48.538135662674904, 51.956892013549805, 56.78374260663986, 62.0578557997942, 60.87516166269779, 54.23746883869171, 59.43535052239895, 62.41958498954773, 59.439275711774826, 62.05804578959942, 58.25902484357357, 60.82501955330372, 59.194941222667694, 65.78989773988724, 38.82763512432575, 36.279966831207275, 51.872950717806816, 52.62218691408634, 60.7474011182785, 59.546885937452316, 59.36612203717232, 56.17869347333908, 48.860631957650185, 53.39748211205006, 60.53592726588249, 59.1614156216383, 58.56661833822727, 56.77926264703274, 56.59774638712406, 55.88665634393692, 58.85246179997921, 57.853020429611206, 57.52254456281662, 61.63786433637142, 57.73719124495983, 49.58449311554432, 45.07861889898777, 45.97194716334343, 46.33519247174263, 48.07609185576439, 52.59633310139179, 60.87244860827923, 60.356212109327316, 58.58455717563629, 62.095371186733246, 61.774486005306244, 58.77937652170658, 48.31083945930004, 48.443133160471916, 47.762133702635765, 48.611965700984, 47.241584435105324, 48.07297222316265, 48.47395330667496, 52.039719969034195, 51.92984886467457, 51.88482128083706, 51.653417497873306, 54.8601034283638, 57.48181454837322, 61.258671283721924, 63.46810072660446, 65.5807189643383, 67.6215286552906, 77.16638088226318, 17.964714020490646, 0.2919017319800332, 0.5299112526699901, 3.3613955788314342, 2.904463210143149, 0.34876755089499056, 0.15303362655686215, 0.30096846108790487, 25.05042750388384, 41.61561392247677, 49.16442945599556, 81.41980424523354, 34.57760497927666, 25.878433473408222, 40.58420866727829, 40.6592508405447, 54.600125178694725, 61.215573996305466, 62.9208654910326, 10.14216497540474, 0.3560452291276306, 0.06496129935840145, 0.10954681551083922, 0.05537211683986243, 0.027038566113333218, 0.02577946062956471, 0.06691616828902625, 0.023932525946293026, 0.02355380798690021, 0.037420744556584395, 0.024439704102405813, 0.027007245626009535, 0.03663052797492128, 0.03389618133951444, 0.055994556096266024, 0.013378969833865995, 0.03198515849362593, 0.09199518623063341, 0.11695664798025973, 0.11774650833103806, 0.2704263827763498, 0.1678948220796883, 0.22344671306200325, 0.08353321100003086, 0.17436510301195085, 0.15547380811767653, 0.16674378071911633, 0.16309147904394194, 0.2745799161493778, 0.2281984471483156, 0.0947784107120242, 0.16813014226499945, 0.12925552669912577, 0.1303428621031344, 0.3493732918286696, 57.24587380886078, 90.93456968665123, 83.33474189043045, 76.49976745247841, 62.98641577363014, 32.88316570222378, 40.269794538617134, 73.33721995353699, 52.13998518884182, 46.85131497681141, 1.8350690184161067, 0.2727485034847632, 0.1791333276196383, 1.2838381784968078, 2.850542441010475, 10.506729763001204, 9.840088784694672, 3.850734271109104, 26.07219647616148, 93.31362202763557, 70.80629736185074, 78.71783763170242, 64.73051458597183, 74.2156720161438, 66.20469108223915, 72.58427515625954, 69.63880240917206, 71.33610293269157, 66.83317735791206, 70.53028777241707, 60.48710748553276, 65.10339617729187, 61.02656073868275, 58.87748725712299, 51.9664902985096, 53.73069383203983, 51.836658865213394, 52.984406277537346, 49.66836601495743, 63.07246595621109, 64.56218361854553, 67.62513846158981, 60.238122045993805, 68.39360162615776, 62.91016146540642, 65.77002480626106, 66.19549557566643, 64.97705295681953, 59.67296317219734, 53.34331601858139, 47.55911819636822, 50.49808569252491, 47.64187395572662, 48.805785700678825, 53.24034534394741, 50.94342939555645, 50.6438534706831, 55.60525864362717, 60.3155504912138, 67.84191682934761, 61.92516312003136, 54.33893479406834, 64.30501341819763, 64.72420692443848, 61.79420314729214, 64.82905089855194, 61.407125517725945, 62.78093799948692, 63.63298907876015, 69.32819947600365, 43.01600977778435, 39.69388224184513, 53.00679847598076, 54.441707879304886, 61.45261287689209, 60.73507457971573, 63.102149963378906, 56.42989419400692, 50.07338248193264, 55.46390622854233, 62.07737535238266, 63.00527036190033, 61.34185642004013, 60.090621560812, 59.59817178547382, 58.32821533083916, 60.966824144124985, 59.07165303826332, 59.571212232112885, 64.43909302353859, 60.46738654375076, 51.88109368085861, 47.729178071022034, 48.05102080106735, 47.41594187915325, 49.56774741411209, 56.22524857521057, 64.44841772317886, 62.861391082406044, 60.63868135213852, 64.3825900554657, 66.22761145234108, 63.40472772717476, 48.29190507531166, 50.923024490475655, 51.091724038124084, 50.62235042452812, 50.58133542537689, 51.0035003721714, 50.80427706241608, 55.081665739417076, 55.48155628144741, 54.26509715616703, 53.515663370490074, 58.345329612493515, 60.03509894013405, 64.01663929224014, 66.61532744765282, 70.24968802928925, 68.27519237995148, 80.79367384314537, 19.54657293856144, 1.0210026009008288, 9.448474198579788, 9.66559549793601, 2.580673322081566, 0.9296444593928754, 0.24882255296688527, 0.47454207844566554, 31.52227632701397, 55.13505667448044, 54.269208535552025, 70.84149107336998, 36.98694929480553, 29.205343052744865, 44.73762519657612, 47.569613233208656, 64.75723475217819, 69.97556313872337, 72.07587763667107, 11.16715332493186, 0.424769053934142, 0.12212943212944083, 0.2412492921575904, 0.13879629521397874, 0.12976465484825894, 0.14122568594757468, 0.18094024941092357, 0.1263628131709993, 0.1467485263128765, 0.1599384646397084, 0.1312656485242769, 0.17508503078715876, 0.21819236688315868, 0.18229846871690825, 0.13228151510702446, 0.0799158273730427, 0.11793802696047351, 0.17364367609843612], [0.02339178045076551, 0.03867398336296901, 0.0888989312807098, 0.012868434387200978, 0.04232389161188621, 0.01942904396855738, 0.025687543784442823, 0.03389819627045654, 0.10240512099699117, 0.03088481509621488, 0.04248333090799861, 0.03436485130805522, 0.043257346405880526, 0.025233045125787612, 0.10277531910105608, 0.02395540079305647, 3.390482780523598, 69.31917116045952, 64.8716390132904, 68.81692931056023, 60.68647898733616, 33.67565877735615, 21.402180567383766, 53.15502852201462, 55.70335038006306, 40.439428836107254, 23.073173202574253, 0.3779982542619109, 0.06402821192750707, 0.08386599001823924, 0.7215749868191779, 2.6325419638305902, 3.2605691766366363, 2.087359093129635, 0.37926682212855667, 58.93670707941055, 76.5134771168232, 68.73279422521591, 64.47781294584274, 60.402740612626076, 66.42862066626549, 66.89151182770729, 66.9719535112381, 63.866258561611176, 65.54129987955093, 67.29246631264687, 63.38179595768452, 59.682021886110306, 54.33331489562988, 50.28710201382637, 47.377845123410225, 44.39128898084164, 47.046293914318085, 47.49291814863682, 47.21050590276718, 47.67864838242531, 56.86001971364021, 60.903804525732994, 60.92843480408192, 58.8342721760273, 61.1250514537096, 60.04970155656338, 59.58755515515804, 59.26729694008827, 59.96142849326134, 55.64770996570587, 48.73323619365692, 42.93745659291744, 44.80219513177872, 42.89812110364437, 46.21581427752972, 45.38908503949642, 45.32058231532574, 44.15823608636856, 51.42147034406662, 54.984884932637215, 60.87809510529041, 51.87052644789219, 55.666499957442284, 58.117607831954956, 56.71403914690018, 52.82589018344879, 57.11402468383312, 51.92778177559376, 61.03180065751076, 53.48911039531231, 63.668300583958626, 38.96521054208279, 34.00474011898041, 55.693075731396675, 47.56148546934128, 53.65731216967106, 49.57096204161644, 57.650533095002174, 56.678416058421135, 58.279627338051796, 53.79950053989887, 58.05370286107063, 56.628308147192, 57.49803587794304, 57.850523963570595, 59.04128506779671, 55.39895251393318, 56.1968033015728, 52.96281963586807, 53.84692199528217, 57.187182158231735, 55.533225908875465, 46.79868400096893, 43.33040490746498, 43.57459120452404, 44.327969178557396, 43.947263807058334, 50.898113027215004, 55.7198490947485, 59.67033751308918, 59.00711350142956, 62.789935916662216, 58.64841274917126, 51.7336767911911, 44.66085031628609, 44.49780486524105, 43.575324565172195, 45.46218931674957, 45.18718667328358, 45.184165835380554, 48.6764520406723, 47.24851906299591, 47.238669991493225, 48.66842307150364, 54.01003584265709, 59.42911505699158, 61.1367966234684, 60.81550486385822, 64.5896789431572, 70.23150220513344, 62.69088663160801, 59.964221343398094, 52.31806643307209, 0.8225035679060966, 0.20386070857057348, 5.422193147242069, 3.220051950775087, 0.45313530368730426, 0.2358348498819396, 0.3849321696907282, 5.005912184715271, 36.78881652653217, 24.083219803869724, 9.609927535057068, 31.198873780667782, 40.82281306385994, 7.5030873622745275, 25.81590972840786, 43.983692452311516, 55.659116953611374, 64.9923737347126, 25.982819572091103, 0.9189027326647192, 0.039399621964548714, 0.09280190817662515, 0.10216373746516183, 0.0780750265403185, 0.04866248586040456, 0.04258358392689843, 0.08015724059077911, 0.05021520351874642, 0.05327913793735206, 0.019094465242233127, 0.029757223746855743, 0.008537427529518027, 0.020866732447757386, 0.0009220586525771068, 0.040929715250968, 0.03436037244682666, 0.04210129554849118, 0.04899795887467917, 0.046627821211586706, 0.019109556815237738, 0.06773126908228733, 0.09520827006781474, 0.04014974030724261, 0.012217064358992502, 0.005144899805600289, 0.05436626925074961, 0.057309207622893155, 0.04743296609376557, 0.008830881997710094, 0.026702610703068785, 0.044471848814282566, 0.08317930303746834, 0.053673448419431224, 4.827691297978163, 82.0500460267067, 71.97731852531433, 80.03760561347008, 66.16355448961258, 50.41250668466091, 28.64297892898321, 44.96934436261654, 58.73393855988979, 43.643420711159706, 25.94846371561289, 0.08996035088784993, 0.11747796219424345, 0.7189436873886734, 2.4202910531312227, 5.433197831735015, 6.404724949970841, 1.938167936168611, 0.0696698775573168, 61.43626235425472, 81.36173576116562, 69.66077283024788, 67.92104378342628, 62.869066670536995, 69.17626842856407, 70.29800623655319, 70.57378023862839, 66.85667529702187, 67.87553742527962, 69.32021990418434, 65.23826614022255, 61.09996140003204, 58.35186526179314, 51.564859449863434, 49.923415929079056, 45.89172966778278, 48.74472677707672, 49.52932007610798, 50.067675188183784, 49.9812488257885, 60.78208565711975, 64.61203694343567, 63.519477769732475, 59.94315527379513, 62.87974789738655, 63.928522020578384, 61.48296944797039, 61.53525464236736, 63.377205803990364, 57.77116522192955, 51.61726623773575, 44.452222511172295, 47.2925890982151, 45.73072470724583, 45.98284497857094, 46.96331016719341, 49.000475853681564, 46.346884444355965, 56.04291155934334, 58.212028965353966, 62.774713933467865, 53.26060965657234, 57.52906121313572, 60.466565787792206, 58.76049533486366, 56.74764074385166, 58.343562707304955, 54.99694548547268, 61.75135284662247, 55.77358581125736, 66.08847811818123, 40.34159168601036, 36.96621000766754, 56.6111596673727, 49.34889815747738, 55.302912667393684, 51.27187617123127, 59.25661951303482, 59.810838773846626, 60.6017929315567, 56.14325277507305, 58.913942500948906, 58.69896523654461, 59.21256087720394, 60.443523824214935, 60.1491916179657, 56.54927998781204, 57.3040334880352, 55.09714990854263, 56.558019518852234, 61.11745186150074, 57.814311906695366, 48.91688413918018, 46.191852763295174, 46.167328879237175, 46.273601576685905, 46.33829690515995, 53.61377790570259, 58.268049359321594, 61.18663854897022, 62.15957634150982, 61.049017533659935, 61.72075688838959, 55.01559488475323, 47.17418745160103, 47.49549821019173, 46.4604527503252, 47.1354903280735, 47.945504263043404, 48.39924931526184, 50.07271371781826, 49.876226261258125, 49.27387498319149, 50.262992307543755, 55.86966745555401, 62.048945277929306, 62.56823681294918, 63.82215812802315, 65.25703713297844, 72.22384169697762, 66.2992300093174, 61.169550865888596, 57.77316391468048, 1.347864386625588, 0.3979231679113582, 3.0666425451636314, 3.7378850765526295, 1.0985244973562658, 0.4608905391069129, 0.28968802420422435, 3.8711292017251253, 45.90605489909649, 28.426168262958527, 15.889212191104889, 32.29190602898598, 43.35670709609985, 14.732296820729971, 30.869925431907177, 52.174445539712906, 60.725305303931236, 75.1515693962574, 31.92086733877659, 0.78767707105726, 0.042077409525518306, 0.04255379782989621, 0.13520054519176483, 0.015000684034021106, 0.054243128397502005, 0.014264132150856312, 0.035481605445966125, 0.05799566824862268, 0.01584999597980641, 0.09992969484301284, 0.05461887034471147, 0.04437791147211101, 0.045663467099075206, 0.027993550611427054, 0.04252924758475274, 0.027778659896284807, 0.020029667794005945, 0.19727471197256818, 0.10983851665514521, 0.16229972621658817, 0.11799377709394321, 0.1370063834474422, 0.11608754110056907, 0.15094259579200298, 0.17397485207766294, 0.1783747784793377, 0.13280885556014255, 0.18523774459026754, 0.13013369520194829, 0.17797672015149146, 0.18010922212852165, 0.2047775874962099, 0.17041993502061814, 6.590896910056472, 92.55215808749199, 81.04892134666443, 89.58074033260345, 76.05567768216133, 48.8591880351305, 31.368375085294247, 74.03014317154884, 72.4103432893753, 59.43513013422489, 32.9587322473526, 1.1048497329466045, 0.16466581175336614, 0.7943707087542862, 3.5269211092963815, 9.815862234681845, 9.96630186215043, 8.34114046767354, 0.467358356108889, 66.4656762778759, 79.9589878320694, 73.49488109350204, 68.93639490008354, 65.88543221354485, 72.60544762015343, 73.845055103302, 72.26012974977493, 68.71621191501617, 70.2136279642582, 75.9124405682087, 68.99974510073662, 65.1037609577179, 60.640315264463425, 54.74963195621967, 51.294177174568176, 50.46794191002846, 51.42276607453823, 53.9453899115324, 52.2094264626503, 52.13743172585964, 63.52339155972004, 66.12527534365654, 66.59187510609627, 62.58730039000511, 65.03841206431389, 66.34758621454239, 64.07438859343529, 63.40357258915901, 66.47465899586678, 59.96493190526962, 52.626682072877884, 46.79437503218651, 49.53504636883736, 48.29018376767635, 48.78656633198261, 50.38050480186939, 50.952909886837006, 51.09558843076229, 56.98907978832722, 61.888031512498856, 64.40234899520874, 55.38321755826473, 60.18582545220852, 62.27396920323372, 59.56329345703125, 59.35799427330494, 62.16360792517662, 55.94524160027504, 63.788180351257324, 58.2551072537899, 66.41253232955933, 44.24082465469837, 39.44548577070236, 58.29815894365311, 51.209384724497795, 57.61531658470631, 52.90289685130119, 61.02575898170471, 62.728314623236656, 63.01263056695461, 57.88273483514786, 62.29061231017113, 60.02325117588043, 59.57760348916054, 64.02248337864876, 62.65686705708504, 59.61031213402748, 59.87722501158714, 56.517338901758194, 57.71810866892338, 62.83392995595932, 61.624310463666916, 51.215171813964844, 48.130523934960365, 48.73400755226612, 48.193877935409546, 47.88524329662323, 56.53725743293762, 61.81137442588806, 63.4010761231184, 62.33413137495518, 66.72518715262413, 64.8485666513443, 56.63878418505192, 48.580583184957504, 50.32378524541855, 48.6872548609972, 50.01728989183903, 49.22190897166729, 51.66351355612278, 53.76842960715294, 52.7070477604866, 52.951743230223656, 55.29150187969208, 58.84031765162945, 65.87923094630241, 64.91797372698784, 66.94375902414322, 69.19218957424164, 73.35035964846611, 70.66312104463577, 63.37469033896923, 60.399343594908714, 1.6623041639104486, 2.9926602775231004, 17.469959668815136, 8.563047610223293, 1.325684383045882, 0.8110130438581109, 0.41791965428274125, 6.128713460639119, 51.45855255424976, 35.61133950948715, 16.45617786794901, 45.04212565720081, 56.76082603633404, 16.173967011272907, 37.34397813677788, 59.72192354500294, 68.68224933743477, 83.926210552454, 36.63221552968025, 1.1128276423551142, 0.25151384761556983, 0.12825705605791882, 0.2242022639256902, 0.16232668102020398, 0.1722556076128967, 0.09799720166483894, 0.1179655161104165, 0.20666224183514714, 0.1671536688809283, 0.234223157458473, 0.11774518730817363, 0.12066153081832454, 0.09088190534384921, 0.13029460766119882, 0.14187138411216438, 0.17054188472684473, 0.08517372843925841], [0.0737355332239531, 0.04613896853697952, 0.042133571550948545, 0.042334073878009804, 0.02448118459142279, 0.024338315597560722, 0.12095720987417735, 0.022061634736019187, 0.018601777519506868, 0.059389258312876336, 0.11840269304229878, 0.09588787695975043, 0.09469901575357653, 0.01645631949941162, 0.1515687012579292, 0.224063363566529, 18.850062713027, 79.32934641838074, 65.53648173809052, 70.92027604579926, 43.6515598744154, 26.136789210140705, 22.99049723893404, 37.58425444364548, 26.208179779350758, 55.303383842110634, 21.133707873523235, 0.28776405088137835, 0.11125271616037935, 1.1394379707053304, 3.0757107585668564, 3.913217643275857, 2.4715956626459956, 1.367467890959233, 8.870039787143469, 82.89528787136078, 67.77097463607788, 69.91802662611008, 58.73200446367264, 58.12758229672909, 64.00438115000725, 67.08847805857658, 64.32832136750221, 67.37505868077278, 65.94958037137985, 64.82769817113876, 64.02246057987213, 62.62363404035568, 53.508880734443665, 50.00336363911629, 46.99951462447643, 44.79932628571987, 46.66964292526245, 45.85190400481224, 44.017693027853966, 48.44459608197212, 58.81977595388889, 60.12941747903824, 62.347343266010284, 60.863743275403976, 60.12561768293381, 60.92498458921909, 58.96674446761608, 59.8385126888752, 59.26667757332325, 56.894666254520416, 49.34232831001282, 45.39743699133396, 43.352755308151245, 43.855251744389534, 43.42426747083664, 45.25146022439003, 43.163149282336235, 46.03395223617554, 53.22744123637676, 59.043196365237236, 57.17066824436188, 54.13220688700676, 59.89307016134262, 54.37293916940689, 53.87904927134514, 46.97915531694889, 54.580392837524414, 50.43497867882252, 55.637575909495354, 53.674141466617584, 63.40972065925598, 41.83221749961376, 38.91764089465141, 61.279304176568985, 54.32576850056648, 58.65600474178791, 52.76613458991051, 54.82047915458679, 55.04683680832386, 55.500338673591614, 58.65766145288944, 58.816416934132576, 51.12668216228485, 54.09361995756626, 53.70111241936684, 55.9516404569149, 55.663509517908096, 54.59434948861599, 51.19094431400299, 55.884653851389885, 57.917917147278786, 53.76476280391216, 46.69501416385174, 42.56844699382782, 42.859777361154556, 42.46570810675621, 43.60595852136612, 48.32628183066845, 54.857998341321945, 58.81039045751095, 59.89342734217644, 58.01520332694054, 59.39487509429455, 52.092894315719604, 45.203939974308014, 44.47995342314243, 44.71940517425537, 44.31961342692375, 46.540058478713036, 43.01658354699612, 45.70609822869301, 46.11321218311787, 49.17394034564495, 52.238776087760925, 59.95146922767162, 59.037261083722115, 64.99596074223518, 61.83732323348522, 72.13520765304565, 63.52833889424801, 67.73872956633568, 53.00114057958126, 64.02083426713943, 24.3157996237278, 0.3257941617630422, 1.9068851647898555, 3.4537740843370557, 0.7217719231266528, 0.3908381809014827, 0.25863751536235213, 0.14726664929185063, 28.824354596436024, 52.349403351545334, 35.87311886250973, 21.217160895466805, 35.70942744612694, 25.824077390134335, 26.43796294927597, 38.28888103365898, 49.834284111857414, 58.75886142253876, 46.53283506631851, 3.631365392357111, 0.12682649219641462, 0.019178053335053846, 0.023989235305634793, 0.028281066042836756, 0.052688291907543316, 0.04895417958323378, 0.027505210018716753, 0.05628737046208698, 0.03154023353999946, 0.0545675397006562, 0.05070691717264708, 0.027970453120360617, 0.04720397642813623, 0.039741128639434464, 0.005889118074264843, 0.07219657127279788, 0.02232504335552221, 0.03396468157006893, 0.017272258919547312, 0.04373823954665568, 0.0225374014917179, 0.0414014799753204, 0.002389761439189897, 0.05225620239798445, 0.037928659294266254, 0.03329225866764318, 0.058820943886530586, 0.06325812239083461, 0.18391734512988478, 0.04066172943566926, 0.020255956042092294, 0.12860487098805606, 0.15311894385376945, 24.397706128656864, 92.86279901862144, 70.0686277449131, 79.01316538453102, 55.00376611948013, 32.071316465735435, 28.501364327967167, 42.406055107712746, 29.651235826313496, 63.63107018172741, 19.178490489721298, 0.4189249378396198, 0.07157177940825932, 1.6226516291499138, 2.225581663660705, 4.1150775365531445, 2.692848527804017, 1.1378749483264983, 10.031076986342669, 87.1088969707489, 71.16708040237427, 74.00808155536652, 61.28293298184872, 60.724849328398705, 64.9009582400322, 69.3637427687645, 66.80278658866882, 69.06726747751236, 68.73670041561127, 68.29361379146576, 67.26269111037254, 65.66710352897644, 54.40481185913086, 52.65588350594044, 48.04176449775696, 46.837179735302925, 47.33754448592663, 48.23183789849281, 48.28060828149319, 51.229922622442245, 61.27243794500828, 62.394274547696114, 63.05844470858574, 62.688507959246635, 61.49325929582119, 63.83040368556976, 62.62000523507595, 61.852693408727646, 63.09860475361347, 60.13774663209915, 52.669600769877434, 47.639825865626335, 45.517286360263824, 45.511267483234406, 44.65966857969761, 47.27866284549236, 46.00915476679802, 47.7853998541832, 54.790213778615, 59.96284581720829, 60.177108719944954, 55.214358419179916, 62.09437943994999, 58.34210358560085, 56.39314256608486, 49.620317593216896, 55.79594001173973, 51.76376357674599, 59.37812179327011, 57.311804071068764, 65.46879217028618, 44.67078298330307, 39.685765877366066, 63.8267482817173, 57.680228501558304, 61.510464772582054, 54.92042899131775, 57.80411325395107, 57.28145129978657, 58.61110635101795, 60.188481509685516, 60.73020704090595, 53.034852370619774, 56.87763936817646, 55.618831515312195, 58.96292567253113, 56.87662862241268, 56.84496872127056, 53.75668823719025, 57.77538679540157, 59.977266043424606, 56.1536680161953, 48.61051417887211, 44.697970524430275, 44.412415847182274, 44.91613581776619, 46.22939094901085, 49.25704188644886, 57.11418427526951, 60.49236260354519, 61.262471079826355, 61.973412930965424, 61.8012859672308, 54.00938227772713, 47.49245457351208, 48.895362094044685, 45.45404255390167, 46.671121045947075, 49.04019512236118, 46.67693853378296, 48.56157660484314, 49.05308783054352, 52.35310435295105, 54.911438673734665, 63.77285197377205, 63.79758104681969, 68.0718044936657, 64.60000678896904, 72.63875663280487, 64.5884858071804, 68.7411005795002, 58.11364084482193, 65.99125653505325, 30.04404164850712, 0.1591421995544806, 1.5450323629193008, 3.668563971295953, 2.8528170939534903, 0.877460790798068, 0.2639629296027124, 0.19364891981240362, 31.056037545204163, 60.62143787741661, 22.189475521445274, 25.354078710079193, 39.78853516280651, 28.11729423701763, 32.1097020059824, 46.20361313223839, 54.37216401100159, 66.36154666543007, 57.45559595525265, 5.48413029871881, 0.1666720595676452, 0.03869573942210991, 0.07380276438198052, 0.032609386325930245, 0.14382127323187888, 0.07728932963800617, 0.048067498646560125, 0.031550575367873535, 0.007954001121106558, 0.029946172689960804, 0.07185260808910243, 0.06728512700647116, 0.047964366094674915, 0.02027947841270361, 0.02558142408815911, 0.025901143162627704, 0.026834894815692678, 0.1677987287985161, 0.17439860355807468, 0.14374842401593924, 0.1285480966907926, 0.2219506324036047, 0.10276538916514255, 0.1435899903299287, 0.10522017619223334, 0.14080568973440677, 0.2616747695719823, 0.22993214864982292, 0.2319110112148337, 0.2008554557687603, 0.27365594229195267, 0.3277525707380846, 0.2786706341430545, 28.44437498599291, 101.36091381311417, 80.96538662910461, 88.57091411948204, 61.272316351532936, 39.15149174630642, 34.80818420648575, 52.711869701743126, 39.1214619576931, 73.99396911263466, 26.33317407220602, 0.587500249966979, 0.23784975113812834, 2.9888562066480517, 8.787065539509058, 12.662502285093069, 8.953490909188986, 5.751477777957916, 11.451220382004976, 92.34949216246605, 73.76592814922333, 75.40791884064674, 63.358503207564354, 63.20784129202366, 68.67221027612686, 72.83100351691246, 67.21731394529343, 71.4267660677433, 68.61316904425621, 69.86061930656433, 68.59818264842033, 67.40111768245697, 56.73887841403484, 54.52702850103378, 49.86311696469784, 48.286395370960236, 50.204646438360214, 51.107257604599, 49.71563547849655, 54.93945837020874, 64.48201552033424, 64.34599041938782, 65.21291390061378, 63.839204013347626, 65.23365318775177, 66.44804522395134, 64.50501948595047, 63.90859588980675, 63.61781649291515, 62.339333295822144, 56.235850006341934, 50.60360223054886, 47.03972026705742, 48.21293391287327, 47.892983481287956, 48.955053091049194, 47.58136600255966, 50.512950494885445, 56.3197723031044, 64.29274007678032, 59.842882454395294, 57.29231111705303, 65.90556353330612, 62.10573323071003, 60.52222520112991, 52.93036177754402, 60.30719093978405, 53.94060976803303, 61.82979203760624, 61.44136928021908, 67.16137334704399, 47.78034992516041, 43.297943249344826, 64.60997745394707, 60.0979133695364, 63.99073228240013, 58.26340600848198, 60.449063926935196, 59.03341569006443, 60.96691533923149, 64.56647738814354, 62.34203115105629, 54.65494863688946, 57.933781296014786, 58.094831854104996, 60.28457835316658, 59.913817048072815, 58.205793499946594, 53.585055246949196, 61.351405307650566, 64.4679182767868, 58.3283369243145, 49.69631351530552, 47.140346467494965, 48.06374251842499, 47.83366106450558, 48.988118916749954, 50.517316460609436, 59.01730075478554, 61.35516710579395, 63.57937775552273, 63.78525450825691, 64.38082695007324, 57.344733104109764, 50.55518142879009, 51.82709477841854, 48.54983903467655, 48.066193386912346, 51.68427184224129, 48.7308157235384, 51.35277383029461, 51.20391681790352, 54.62835006415844, 57.561488673090935, 64.91732776165009, 65.47632336616516, 71.05118662118912, 67.28780776262283, 72.5930754840374, 69.28810402750969, 71.64681985974312, 58.80594849586487, 69.20297339558601, 30.268115624785423, 0.24505747453076765, 8.59182346612215, 9.766570329666138, 3.174127615056932, 0.7942187169101089, 0.36867827468086034, 0.26813733216840774, 36.72613888978958, 73.08583304286003, 56.35560818016529, 33.182779625058174, 48.3742618560791, 35.054760575294495, 36.036536693573, 52.403128668665886, 64.99345287680626, 73.04000750184059, 65.78922137618065, 6.538046021014452, 0.2522720256820321, 0.10988772104610689, 0.14185226638801396, 0.1927558341412805, 0.2253090584417805, 0.14615431835409254, 0.18073820712743327, 0.11389550403691828, 0.1371269379160367, 0.11439903639256954, 0.21354371710913256, 0.21514219930395484, 0.13931250345194712, 0.1543426711577922, 0.13367890496738255, 0.17531966819660738, 0.08689376700203866], [0.04635543817130383, 0.03355839282448869, 0.02938550795079209, 0.040945393120637164, 0.05016365394112654, 0.015490483874600613, 0.05749021001975052, 0.010836434976226883, 0.08635022546513937, 0.027696639590431005, 0.06602050736546516, 0.03862070087052416, 0.08178304124157876, 0.06614114347030409, 0.06616653234232217, 0.24535221105907112, 36.68331898748875, 70.55391490459442, 58.43152418732643, 63.867390900850296, 45.27943052351475, 60.86175978183746, 29.736368358135223, 40.441564321517944, 45.47189399600029, 53.016818538308144, 3.8126444024965167, 0.19124065060168505, 0.08354353427421302, 1.41649654135108, 1.4262452744878829, 3.6149281868711114, 3.191596227698028, 1.7418253468349576, 31.165967546403408, 81.90636053681374, 66.77861988544464, 64.8116022348404, 54.63196747004986, 58.45194049179554, 58.036725372076035, 64.78098347783089, 65.34174218773842, 65.96271246671677, 65.43221533298492, 63.45311053097248, 60.84613502025604, 61.61685146391392, 52.595873326063156, 47.29445479810238, 45.82487605512142, 45.73959723114967, 45.554965138435364, 45.35953402519226, 42.65018820762634, 48.020314648747444, 58.60066071152687, 60.60021601617336, 59.93286542594433, 60.12501731514931, 58.870628625154495, 56.93360656499863, 59.64493587613106, 60.91340661048889, 57.7017505466938, 59.00494761765003, 49.31800961494446, 44.115955755114555, 43.33206161856651, 44.60530109703541, 42.99416095018387, 43.77374231815338, 45.15382066369057, 50.26434123516083, 55.341355204582214, 59.54806387424469, 56.55559524893761, 55.18162317574024, 57.46386431157589, 51.94732792675495, 50.46141766011715, 46.0795421898365, 45.792319402098656, 47.87599079310894, 53.75590167939663, 54.116931706666946, 63.20171982049942, 42.082597464323044, 41.684074848890305, 62.721539586782455, 53.7175427377224, 59.85596515238285, 53.19753684103489, 57.757413759827614, 55.239782854914665, 54.743742272257805, 53.046909123659134, 57.18983821570873, 56.8920823931694, 51.53641417622566, 50.33839926123619, 56.01712994277477, 55.938360169529915, 51.40614956617355, 47.507733553647995, 56.089060083031654, 55.62439441680908, 56.19275651872158, 47.99348048865795, 43.913331627845764, 41.263813599944115, 43.55351373553276, 41.520014852285385, 45.603287145495415, 51.67816177010536, 59.709315821528435, 58.31153802573681, 61.53435409069061, 57.76790879666805, 50.01562178134918, 41.51298142969608, 46.9414309412241, 42.2943677008152, 47.91251443326473, 43.74989099800587, 45.90570151805878, 45.820069313049316, 49.593741819262505, 52.17177428305149, 60.95738545060158, 58.57529707252979, 63.78720760345459, 58.25723893940449, 67.16630548238754, 60.043010115623474, 63.054831102490425, 63.454280868172646, 69.05961468815804, 51.35504610836506, 65.76759293675423, 14.013762027025223, 1.0827128333039582, 3.909086314961314, 1.347190160304308, 0.4547987534897402, 0.2229370060376823, 0.09932793182088062, 4.854245698079467, 54.983213022351265, 37.66291402280331, 27.121510170400143, 28.830401971936226, 23.45302551984787, 15.784502159804106, 35.16616679728031, 53.16227473318577, 57.70109698176384, 58.80796238780022, 16.09024230390787, 1.0608574748039246, 0.13815637095831335, 0.06821417715400457, 0.032726897989050485, 0.013525938265956938, 0.02786149656458292, 0.025823891155596357, 0.02858986070350511, 0.014150682818581117, 0.04765417434100527, 0.054697051891707815, 0.04857665648160037, 0.024886918581614736, 0.006828430268797092, 0.0552616852655774, 0.04563837508612778, 0.005266425559966592, 0.06531016813823953, 0.04121580204810016, 0.019589551957324147, 0.01836933872255031, 0.03071467588597443, 0.04387163688079454, 0.05336350528523326, 0.03029879673704272, 0.01136340992161422, 0.028447225486161187, 0.012924913680762984, 0.025700112055346835, 0.022891526532475837, 0.01332866057055071, 0.022635340865235776, 0.5954665224999189, 48.218067437410355, 79.02560591697693, 67.03718081116676, 70.11823788285255, 53.343859389424324, 61.76010377705097, 23.369673192501068, 37.27547161281109, 46.94590710103512, 62.34311789274216, 3.678510175086558, 0.27030012861359864, 0.08618494917755015, 1.898335861042142, 2.116270079277456, 3.653277629055083, 0.7255132973659784, 0.9037714102305472, 33.958602994680405, 85.02222374081612, 68.33946973085403, 66.88172355294228, 56.49674020707607, 61.754799261689186, 61.52912937104702, 65.99091455340385, 66.76609575748444, 67.14506462216377, 67.10930094122887, 66.45968019962311, 65.49263209104538, 63.397948890924454, 55.575673431158066, 48.537554293870926, 48.740364611148834, 48.26937608420849, 47.85444214940071, 48.39725062251091, 45.135133266448975, 49.53363664448261, 60.11027030646801, 63.16428802907467, 63.11373554170132, 62.35060729086399, 61.527487859129906, 58.84538657963276, 60.31048536300659, 62.049253061413765, 61.76587946712971, 61.17854878306389, 52.85780467092991, 45.497117042541504, 46.02252244949341, 46.11403673887253, 44.25787054002285, 44.39359925687313, 46.200105920434, 52.715015932917595, 58.43071863055229, 61.48748740553856, 58.55479717254639, 54.74326729774475, 58.952590227127075, 53.82624350488186, 51.84308812022209, 49.87496092915535, 47.24634177982807, 49.052631855010986, 55.54332196712494, 58.06437648832798, 64.37386572360992, 43.70913818478584, 42.19573639333248, 65.39745479822159, 55.859313011169434, 62.07979962229729, 56.592913046479225, 60.691912695765495, 56.81152291595936, 57.199968472123146, 55.0766272097826, 60.54006524384022, 57.314874306321144, 51.89348861575127, 51.67569190263748, 57.047148272395134, 57.15712197124958, 54.32266406714916, 48.92159588634968, 56.98613114655018, 58.08590233325958, 56.89246617257595, 50.44931910932064, 45.86605064570904, 42.940348237752914, 44.79344420135021, 42.90390059351921, 48.02061103284359, 54.78300176560879, 60.8734517544508, 57.91274182498455, 64.0220881998539, 60.08877485990524, 52.403265461325645, 44.70003001391888, 48.399150520563126, 45.292566418647766, 51.480017602443695, 46.11279420554638, 47.67786182463169, 47.572535276412964, 51.44782952964306, 54.6140818297863, 64.67701345682144, 61.6143473982811, 66.22175216674805, 60.70736646652222, 67.34288200736046, 62.024470791220665, 64.2382737994194, 64.29821938276291, 70.42325511574745, 56.90415434539318, 70.4394118487835, 17.488052397966385, 1.12181784119457, 1.175002281088382, 3.0442940443754196, 2.687213192693889, 0.20499632810242474, 0.1372019393602386, 3.5954915173351765, 60.5955346673727, 41.22526466846466, 23.227606415748596, 20.874692872166634, 23.580292090773582, 23.63973420113325, 41.98150008916855, 60.7242451608181, 61.68800264596939, 71.00819572806358, 22.69112840294838, 0.9894622152205557, 0.16117529827170074, 0.08576376552809961, 0.05933234671829268, 0.03874076923239045, 0.02293335768627003, 0.039132548990892246, 0.083595017058542, 0.03294194641057402, 0.035646855758386664, 0.019922945102734957, 0.03265636427386198, 0.022848938388051465, 0.05640250354190357, 0.029055977684038226, 0.027081284133601002, 0.03814419011177961, 0.21641664498019964, 0.09008490553242154, 0.10258528476697393, 0.18264508136780933, 0.12908517412142828, 0.19389568391488865, 0.09694424254121259, 0.11496557708596811, 0.14877898298436776, 0.07781948283081874, 0.15850813826546073, 0.12245685284142382, 0.14841113006696105, 0.11957874477957375, 0.14179970748955384, 0.793548587244004, 55.470206290483475, 89.85155180096626, 76.26046389341354, 82.65884175896645, 59.89592380821705, 70.45164719223976, 40.985197350382805, 55.85755370557308, 63.73858921229839, 68.51688221096992, 4.605974620208144, 0.411802398157306, 0.23253297549672425, 2.971995798870921, 5.809773299843073, 8.773771952837706, 11.144691780209541, 3.2872254587709904, 39.647038355469704, 86.00977554917336, 72.28486642241478, 69.5411628484726, 59.98479723930359, 64.31408733129501, 64.25119310617447, 69.69307869672775, 72.16161623597145, 67.66827374696732, 70.92164397239685, 68.97620916366577, 67.42460042238235, 64.82880011200905, 57.83443182706833, 51.244156658649445, 51.173754036426544, 50.010754242539406, 49.12972591817379, 50.71797989308834, 49.02998507022858, 53.01148362457752, 63.256330490112305, 66.19532838463783, 64.395881742239, 64.64612871408463, 64.25539568066597, 59.548155069351196, 62.933397218585014, 65.81044703722, 61.69122487306595, 64.18745532631874, 55.43206013739109, 47.396281734108925, 49.5262498408556, 48.41428130865097, 47.34653480350971, 47.346185222268105, 48.38967002928257, 55.573838129639626, 62.24621929228306, 64.67216491699219, 60.27299277484417, 58.93590912222862, 62.88991995155811, 58.235842287540436, 53.25596630573273, 52.012236043810844, 50.154139548540115, 50.87206542491913, 58.17927472293377, 60.370677933096886, 66.02845653891563, 48.746771067380905, 44.66298580169678, 67.07632631063461, 60.45427344739437, 64.63960066437721, 60.348802506923676, 61.946153193712234, 60.998510643839836, 59.61743675172329, 59.33049134910107, 62.51597061753273, 59.0523386746645, 53.44156734645367, 51.745212972164154, 60.350740402936935, 60.47173351049423, 54.94638539850712, 49.11227345466614, 57.85368159413338, 60.358723774552345, 59.3739078193903, 52.924456894397736, 48.1746319681406, 45.494312793016434, 48.06908503174782, 46.49367816746235, 50.02167105674744, 56.51644594967365, 64.14161458611488, 60.99418647587299, 66.9743549823761, 61.697068959474564, 55.15864580869675, 46.658292934298515, 51.31510265171528, 46.28104917705059, 54.67740163207054, 48.697309121489525, 49.749503061175346, 51.29767678678036, 54.33065503835678, 56.662156730890274, 67.64145478606224, 62.62824319303036, 66.4164537191391, 65.01714840531349, 67.5027622282505, 65.01673802733421, 68.1149473786354, 67.15733796358109, 74.98257726430893, 57.62265779078007, 72.2087337076664, 18.527425825595856, 2.248838790692389, 13.47128888592124, 5.4906735476106405, 2.0038996590301394, 0.5430229241028428, 0.25172473629936576, 5.368861109018326, 69.39454391598701, 53.33527185022831, 39.73463885486126, 40.41017420589924, 34.820427149534225, 24.96193215250969, 47.75554105639458, 69.66718688607216, 69.2182257771492, 80.12575328350067, 27.049657925963402, 1.467200901824981, 0.31835107365623116, 0.19094392511760816, 0.12517461989773437, 0.2835451194550842, 0.17072515067411587, 0.16028010490117595, 0.1590123088681139, 0.10040888475487009, 0.1502545952098444, 0.1539710778160952, 0.10433825984364375, 0.09759220425621606, 0.0815286701254081, 0.12422204366885126, 0.129380252037663, 0.14962353219743818], [0.06468860461609438, 0.021749570914835203, 0.03005111237143865, 0.06456458431784995, 0.07072242107824422, 0.014013987565704156, 0.04908795912342612, 0.048912860511336476, 0.11518894127220847, 0.10781686927657574, 0.044759623997379094, 0.02860493001207942, 0.04167056416918058, 0.0935970526188612, 0.0722279715409968, 2.541037411428988, 69.33655142784119, 62.701936438679695, 65.2954150736332, 48.98820251226425, 34.08291332423687, 14.904106501489878, 48.476882949471474, 42.5257258862257, 42.51151464879513, 45.55864714086056, 0.1830056167091243, 0.05332808257662691, 0.21484197088284418, 1.3320596097037196, 1.3324065785855055, 1.189693717751652, 1.8979991041123867, 0.5034314829390496, 61.265902295708656, 77.7194944024086, 66.70665934681892, 65.49077019095421, 55.88097184896469, 53.24447192251682, 50.365621000528336, 56.18622466921806, 60.75178228318691, 65.12919679284096, 62.79065027832985, 61.35343439877033, 64.04655128717422, 57.81336955726147, 50.10657750070095, 46.115096881985664, 48.17235969007015, 46.44449360668659, 44.79953907430172, 44.26249869167805, 45.03900222480297, 43.32739166915417, 51.41039773821831, 58.031519651412964, 56.425676420331, 55.549321845173836, 54.27483983337879, 55.089614912867546, 58.03623139858246, 59.13047768175602, 59.20293219387531, 57.08771109580994, 51.9728397578001, 43.425491005182266, 42.84196011722088, 41.670285388827324, 43.05946424603462, 42.71704562008381, 43.22915934026241, 51.03328317403793, 56.80261239409447, 58.97308632731438, 51.55010864138603, 53.30572463572025, 55.854236483573914, 51.630656719207764, 46.13552838563919, 44.17472720146179, 45.980793088674545, 49.31656949222088, 58.545689061284065, 55.68724684417248, 62.096640318632126, 39.98640954494476, 46.11271061003208, 60.76179474592209, 53.621027916669846, 56.073625311255455, 52.324047312140465, 54.34098668396473, 52.842932268977165, 49.587996527552605, 53.67169439792633, 55.06691873073578, 56.72047980129719, 55.32664619386196, 52.44990035891533, 53.90245981514454, 53.5142270475626, 53.64892601966858, 50.54674208164215, 51.486560851335526, 55.9218842536211, 54.18339014053345, 48.884718865156174, 43.50541211664677, 43.13072942197323, 43.575092777609825, 43.54637771844864, 42.513878121972084, 49.48908783495426, 56.18543431162834, 58.42530012130737, 58.11158135533333, 57.567541748285294, 45.39582207798958, 44.82441633939743, 43.22394981980324, 45.2024694532156, 44.68472063541412, 45.7549712061882, 44.40264277160168, 49.37508635222912, 53.07848922908306, 59.082718044519424, 61.330061852931976, 61.49942256510258, 59.104422479867935, 61.14702947437763, 61.02537140250206, 60.69870673120022, 64.01185914874077, 62.8272271156311, 64.4607974588871, 64.45065960288048, 61.712849512696266, 69.36875849962234, 8.449537251144648, 2.2191072860732675, 4.929593754932284, 1.4008531370200217, 0.1773533012601547, 0.2386492965160869, 0.08445296945865266, 34.16171729564667, 45.670858919620514, 33.62723037600517, 48.06738272309303, 34.71646472811699, 21.73176158219576, 24.182459078729153, 44.76810336112976, 50.54728165268898, 60.605003759264946, 40.25761619210243, 3.845772687345743, 0.15967884653946385, 0.09607481653802097, 0.07212423413875513, 0.057050454124691896, 0.048822188618942164, 0.06454363348893821, 0.018587294507597107, 0.005571128667725134, 0.04078333775396459, 0.08731091336812824, 0.009207989496644586, 0.062038102114456706, 0.05525231194042135, 0.017967315470741596, 0.04526484102825634, 0.05454308593471069, 0.0292521384471911, 0.040804826639941894, 0.014226766870706342, 0.04220697737764567, 0.02800288682919927, 0.050418707833159715, 0.06668218396953307, 0.015354635597759625, 0.014499545104627032, 0.10636000370141119, 0.031182540624286048, 0.05406595919339452, 0.06396740034688264, 0.04744712256069761, 0.16652938909828663, 4.444509884342551, 85.66995218396187, 71.43984496593475, 72.66067385673523, 58.756364956498146, 48.979029804468155, 26.7475513368845, 39.51556161046028, 39.35415007174015, 50.0018323212862, 48.48619244992733, 0.09683139156550169, 0.1432021736400202, 0.6810816877987236, 2.3613106179982424, 2.6227301778271794, 3.1699905870482326, 1.068509432952851, 0.45738873013760895, 66.68585926294327, 80.46359315514565, 70.6136628985405, 67.58302912116051, 60.122870430350304, 56.05129770934582, 53.36607679724693, 60.35312667489052, 63.693588227033615, 67.53710478544235, 67.96303912997246, 64.65185880661011, 66.08025535941124, 59.57850404083729, 52.9586398601532, 48.27780403196812, 48.56893680989742, 46.562002301216125, 49.17866349220276, 46.91924013197422, 48.02774704992771, 46.87868870794773, 54.09551985561848, 61.780086904764175, 59.214947149157524, 58.53666454553604, 57.02001392841339, 59.10727992653847, 61.155453622341156, 60.960144102573395, 61.45145393908024, 59.56072859466076, 54.26972530782223, 44.88212004303932, 44.68141861259937, 45.171801298856735, 45.20504951477051, 44.792023077607155, 47.70026542246342, 53.48792865872383, 61.014424189925194, 59.31740865111351, 53.660215213894844, 56.87201946973801, 58.42427417635918, 54.642751291394234, 48.34899701178074, 45.435719937086105, 48.3999864757061, 51.124345287680626, 61.862656474113464, 58.217937648296356, 63.83215919137001, 41.659790351986885, 47.78596982359886, 63.376495242118835, 57.709471732378006, 58.28207440674305, 53.672906532883644, 55.80452375113964, 54.670588597655296, 51.98246844112873, 55.30727103352547, 55.89957945048809, 59.34031002223492, 57.8014799952507, 54.43465165793896, 56.386515721678734, 56.2089778482914, 55.57588241994381, 51.43738389015198, 54.44335699081421, 59.13229778409004, 55.51453471183777, 50.76928474009037, 45.1250334084034, 44.13474194705486, 45.1199796795845, 46.58060610294342, 44.503477960824966, 50.755757465958595, 59.693520069122314, 60.607010051608086, 60.47150172293186, 59.097373858094215, 46.48359350860119, 46.80819869041443, 45.4107628762722, 48.182052969932556, 46.97929970920086, 48.41543264687061, 47.10829518735409, 51.68032005429268, 54.45288687944412, 62.05964170396328, 64.13729801774025, 63.78317981958389, 59.12381663918495, 62.26886987686157, 63.06661807000637, 63.01972098648548, 66.18771359324455, 65.60556203126907, 65.33887714147568, 66.94320425391197, 63.29550638794899, 74.79166030883789, 12.476858496665955, 1.1809565615840256, 1.7850455339066684, 3.3316410379484296, 0.7321257737930864, 0.10047310279333033, 0.09916306371451356, 33.56039576232433, 56.14461310207844, 32.26699456572533, 35.17290383577347, 35.30503034591675, 23.933766223490238, 31.361292265355587, 50.41039399802685, 56.70372650027275, 66.22194215655327, 51.40654854476452, 5.288163414224982, 0.18875729088904336, 0.07427404299960472, 0.03286482242401689, 0.022355582732416224, 0.004945215232510236, 0.02727034254348837, 0.04382317092677113, 0.024935048713814467, 0.04023323934234213, 0.05205017478147056, 0.09711179722216912, 0.04695945361163467, 0.04282618087017909, 0.03755219375307206, 0.027252297222730704, 0.02603849057777552, 0.13514501770259812, 0.2151260946993716, 0.11495278988149948, 0.1659437158377841, 0.13247116352431476, 0.10431526810862124, 0.10824036842677742, 0.11130232873256318, 0.14119680155999959, 0.21066743473056704, 0.20348210935480893, 0.18160500592784956, 0.14136151381535456, 0.1510874630184844, 0.29719464015215635, 5.5040336307138205, 95.50045788288116, 78.95494490861893, 82.94839382171631, 65.3419017791748, 49.61109548807144, 24.053792282938957, 65.99513232707977, 61.670230999588966, 57.13728703558445, 55.0575902312994, 0.4886810603784397, 0.13228651718236506, 0.9022757154889405, 5.717585496604443, 5.235439818352461, 6.868093935772777, 7.790321549400687, 0.5073963920585811, 72.01012596487999, 81.43398508429527, 75.24807661771774, 68.76963704824448, 63.20725232362747, 56.639373153448105, 56.395563036203384, 61.159010231494904, 67.92418241500854, 70.40196865797043, 70.82803219556808, 66.42069429159164, 69.98509302735329, 62.5282097607851, 55.86807154119015, 51.13488972187042, 53.51447783410549, 51.142884492874146, 50.79719044268131, 49.61446590721607, 50.96318453550339, 49.39589783549309, 56.08625203371048, 64.08913180232048, 62.74648904800415, 61.189161613583565, 60.0392597168684, 60.13176575303078, 63.18672962486744, 62.360764145851135, 64.45054560899734, 61.151311844587326, 56.27979464828968, 47.427675649523735, 46.85817740857601, 46.208704859018326, 47.70722284913063, 47.14881621301174, 48.865605890750885, 56.807764917612076, 63.34243766963482, 62.53930516541004, 54.151437655091286, 56.60708628594875, 62.3054239153862, 57.44201548397541, 51.116430312395096, 49.14531268179417, 50.803684294223785, 54.10704843699932, 64.23997610807419, 61.92676283419132, 66.04516044259071, 45.02311907708645, 52.02337324619293, 65.66712632775307, 60.39272055029869, 60.81561505794525, 56.12670086324215, 59.756600484251976, 58.43906678259373, 53.68844389915466, 60.909447222948074, 59.25732247531414, 62.16917082667351, 60.93769870698452, 56.21488653123379, 58.027104288339615, 59.11185868084431, 57.073868438601494, 51.937349662184715, 54.76119093596935, 61.566032990813255, 57.950682789087296, 54.26440939307213, 48.00364874303341, 47.155842036008835, 49.44857060909271, 49.569183737039566, 47.79338322579861, 54.56447549164295, 61.31519325077534, 62.54288837313652, 64.73629027605057, 61.79677940905094, 50.33341772854328, 49.04179863631725, 47.95993208885193, 51.50434769690037, 49.38186518847942, 51.0636967420578, 49.362151846289635, 55.18142558634281, 56.90894968807697, 63.67717690765858, 65.6259973347187, 65.70716857910156, 60.181740671396255, 63.157809376716614, 65.24699047207832, 65.63275337219238, 68.4690123796463, 69.63548138737679, 69.74211126565933, 68.76973584294319, 67.02445149421692, 75.87516456842422, 12.451170925050974, 4.085964923724532, 11.687998976558447, 5.2459457796067, 0.6839705421589315, 0.4235902562504634, 0.16113379737362266, 40.691043734550476, 62.580255568027496, 48.119094148278236, 63.13814163208008, 45.74912331998348, 29.96812552213669, 34.78472426533699, 60.093228220939636, 64.48132395744324, 74.64977592229843, 60.52390471100807, 6.126765590161085, 0.3546580660622567, 0.1503816805779934, 0.2549155557062477, 0.12810089334379882, 0.1830227454775013, 0.1754016161430627, 0.1669247608515434, 0.10670234900317155, 0.12079996362444945, 0.24555799376685172, 0.11834420438390225, 0.13400622177869081, 0.14171768532833084, 0.09747460353537463, 0.15331251081079245, 0.061313406040426344], [0.03318835428217426, 0.048187477950705215, 0.052751979310414754, 0.045703034702455625, 0.03829860135738272, 0.018302050048077945, 0.040349893824895844, 0.06810856953961775, 0.054384359100367874, 0.0746019757934846, 0.061768145897076465, 0.05863126578333322, 0.018943809263873845, 0.12217266965308227, 0.020347238350950647, 20.920178331434727, 69.56705465912819, 57.733695432543755, 62.10348755121231, 34.79874171316624, 16.449469327926636, 19.259447045624256, 44.416645020246506, 29.1275517269969, 66.38070523738861, 21.646537855267525, 0.30605683336034417, 0.1990986437886022, 0.6031409825664014, 1.6224210290238261, 2.3813381558284163, 1.1610078695230186, 0.8444682299159467, 9.340375699102879, 76.58403933048248, 72.7488063275814, 69.8413011431694, 64.53201323747635, 62.85994715988636, 56.43394477665424, 52.22360350191593, 51.145422756671906, 54.3949855864048, 59.16564479470253, 61.42811559140682, 59.77648861706257, 58.79142567515373, 53.432592228055, 49.66331608593464, 46.47419661283493, 48.92954505980015, 43.73961254954338, 44.53198783099651, 43.9929411560297, 44.817268922924995, 42.44783766567707, 45.174639746546745, 50.856600254774094, 52.112892642617226, 49.682873636484146, 53.08813311159611, 52.51431830227375, 57.183450758457184, 57.272882759571075, 59.47530537843704, 55.70498809218407, 52.341841757297516, 43.59715439379215, 41.41197144985199, 42.978919968008995, 43.08269239962101, 42.35566981136799, 47.611931562423706, 50.9938944876194, 58.38374935090542, 56.02057255804539, 50.34603305160999, 54.90740709006786, 57.43362173438072, 49.42295238375664, 44.38310422003269, 42.42198385298252, 47.11814045906067, 53.40019516646862, 59.33569326996803, 57.54158914089203, 62.01195426285267, 42.710764557123184, 42.47086443006992, 60.461557656526566, 52.96128071844578, 54.071816727519035, 54.73772719502449, 54.4029575586319, 52.246200889348984, 48.74214291572571, 47.19043157994747, 55.7252562046051, 54.5871526747942, 54.99488979578018, 55.66938020288944, 55.72166919708252, 53.41407582163811, 57.11168400943279, 55.41385531425476, 55.859768986701965, 55.46164155006409, 54.23509396612644, 51.12763971090317, 45.87917514145374, 43.353150486946106, 42.421216294169426, 43.07645693421364, 40.873437747359276, 46.02866291999817, 53.82247030735016, 58.39115135371685, 57.10617050528526, 54.678416177630424, 43.80757190287113, 44.82449233531952, 43.79821680486202, 44.71767246723175, 44.35137592256069, 44.9747970700264, 46.20566122233868, 51.5689480304718, 55.07862590253353, 61.64184272289276, 60.96578299999237, 58.642675057053566, 58.09570960700512, 64.12906005978584, 59.712788835167885, 62.907201424241066, 59.07631538808346, 62.65856556594372, 59.60215777158737, 64.06362757086754, 58.79641480743885, 66.89832106232643, 56.26661695539951, 4.7704943921417, 2.5227254815399647, 6.575970835983753, 0.6731145840603858, 0.14452613540925086, 0.5108043341897428, 6.995595144107938, 62.08774499595165, 37.01536796987057, 29.66284990310669, 47.797779589891434, 42.359063029289246, 15.276067592203617, 37.53841370344162, 46.80544763803482, 53.076357543468475, 55.09715750813484, 12.038013394922018, 0.4015608492773026, 0.025240017603209708, 0.11346724029863253, 0.08613613070338033, 0.11884366977028549, 0.05017718329327181, 0.004713205025836942, 0.07066085250698961, 0.10411037597805262, 0.021978248878440354, 0.029202499899838585, 0.026598789809213486, 0.07282558595761657, 0.04765187739394605, 0.03900249503203668, 0.04612169504980557, 0.08463322228635661, 0.011148873581987573, 0.009428760804439662, 0.10909532255027443, 0.018228751832793932, 0.026097949594259262, 0.01709695250610821, 0.041352461121277884, 0.020359515328891575, 0.01224976245794096, 0.026841240178328007, 0.06416297110263258, 0.08733189388294704, 0.04437391129613388, 0.07546946479124017, 28.313926085829735, 81.07292085886002, 62.88036346435547, 69.61512967944145, 41.755351424217224, 25.552570559084415, 24.607002697885036, 42.11112253367901, 34.66953344643116, 73.96927043795586, 24.090543910861015, 0.4135858087101951, 0.11081263000960462, 2.2519275499507785, 3.6213676538318396, 2.781960633583367, 2.065919693559408, 0.8833744609728456, 10.414160080254078, 78.06443989276886, 73.61401990056038, 72.05674186348915, 66.85029923915863, 66.82639852166176, 58.416917771101, 54.053053334355354, 52.28028506040573, 56.941099762916565, 61.062875390052795, 64.91632461547852, 62.171834483742714, 61.2517898529768, 57.15614542365074, 53.149503618478775, 49.27606746554375, 49.95172820985317, 45.88178560137749, 47.57348522543907, 46.548608019948006, 47.10682846605778, 45.84010183811188, 48.710103034973145, 53.046498745679855, 53.88745442032814, 53.05127888917923, 54.81401950120926, 55.6040009111166, 59.75838638842106, 60.230765640735626, 62.20120690762997, 60.36954939365387, 55.34551978111267, 45.689348727464676, 44.408163875341415, 44.366692900657654, 45.85832566022873, 44.90593336522579, 48.31720791757107, 52.79371351003647, 59.421051889657974, 58.75087045133114, 53.24236683547497, 59.32307794690132, 61.665257066488266, 51.83951251208782, 46.11591763794422, 44.87570978701115, 51.747348457574844, 56.67098365724087, 60.941475704312325, 58.3117850124836, 63.1526530534029, 43.05311478674412, 44.499651566147804, 62.45423913002014, 54.54331062734127, 58.522004932165146, 56.73722930252552, 56.15447737276554, 55.181205198168755, 50.01920498907566, 49.80441011488438, 56.63480579853058, 57.912084460258484, 58.62386226654053, 56.566759049892426, 58.587209433317184, 55.94202317297459, 58.664599880576134, 57.91700899600983, 56.232232600450516, 57.91082672774792, 56.75331763923168, 50.90783290565014, 48.11204932630062, 45.17710581421852, 42.51982480287552, 46.30588844418526, 43.94494213163853, 47.60145552456379, 57.07878157496452, 59.42109368741512, 57.48578153550625, 57.616232335567474, 45.51517367362976, 47.597241550683975, 45.675962045788765, 48.158623427152634, 46.951435804367065, 48.29520709812641, 49.27142411470413, 52.741591706871986, 57.24335454404354, 63.83562460541725, 63.77953961491585, 60.417601615190506, 58.328625708818436, 67.05057889223099, 61.94777570664883, 66.2466636300087, 61.92342661321163, 64.55841422080994, 61.14769443869591, 66.27434134483337, 62.46805138885975, 67.92805060744286, 62.703205570578575, 5.854573370888829, 1.2062968080863357, 0.652504846220836, 1.3611314934678376, 0.5490233364980668, 0.6030094146262854, 6.534076659008861, 68.6427466571331, 41.31255738437176, 32.14975945651531, 42.25677631795406, 36.63318447768688, 23.152435049414635, 43.83899621665478, 54.923769012093544, 57.150453329086304, 63.09704303741455, 17.321906313300133, 0.4573277849704027, 0.022057178139220923, 0.11282936437055469, 0.056536168049206026, 0.09887147389235906, 0.01672223472269252, 0.005679862579199835, 0.01623254342121072, 0.08344186746398918, 0.043904131816816516, 0.040100918122334406, 0.05123975694004912, 0.0070803527614771156, 0.07715461499174125, 0.045786463233525865, 0.03202153486199677, 0.11123456322820857, 0.15316702018026263, 0.1640616887016222, 0.26674954569898546, 0.16057639993960038, 0.0774615524278488, 0.18084353272570297, 0.22233346186112612, 0.21745286125224084, 0.17543389956699684, 0.12667240749578923, 0.12428215020918287, 0.12618716165889055, 0.17279301158851013, 0.12267363417777233, 33.827418833971024, 91.8616895377636, 73.02473992109299, 78.98259222507477, 49.78053219616413, 25.658079497516155, 28.13673209398985, 62.72934816777706, 44.047551825642586, 84.17220175266266, 27.84231249243021, 0.5459057819098234, 0.3734268026892096, 2.5102733122184873, 7.685049148276448, 7.0631973166018724, 8.895129840821028, 2.6350626535713673, 14.377406314015388, 81.7459711432457, 76.41833022236824, 77.18853369355202, 69.02329623699188, 70.36915361881256, 61.71325609087944, 55.66074326634407, 57.58989974856377, 59.501470774412155, 63.94520312547684, 67.77871862053871, 66.11965924501419, 66.01819708943367, 59.50801782310009, 55.6367589533329, 51.327911764383316, 54.807662442326546, 47.40053370594978, 49.82680991292, 50.10837480425835, 48.9836997538805, 48.11591751873493, 52.028700560331345, 54.85618203878403, 57.714582458138466, 56.3093076646328, 59.195575788617134, 57.74723030626774, 62.69299931824207, 63.17912623286247, 65.3431861102581, 62.39944986999035, 58.392382487654686, 47.706816270947456, 45.8769066631794, 46.41713887453079, 47.935070022940636, 47.96988755464554, 52.98041649162769, 55.95027633011341, 61.08778305351734, 58.57783533632755, 52.995809465646744, 62.046380415558815, 64.32439997792244, 55.32207503914833, 49.60853062570095, 47.71687813103199, 52.43833377957344, 58.300815001130104, 64.3506109714508, 63.17228280007839, 63.92782285809517, 47.58435644209385, 47.21601940691471, 65.66407889127731, 57.82163791358471, 59.418882206082344, 59.64641399681568, 58.66331174969673, 57.89685107767582, 54.45094518363476, 52.50327989459038, 60.84964603185654, 60.187630355358124, 60.2477241307497, 59.213001653552055, 59.64743994176388, 58.86894531548023, 61.707119420170784, 59.601963981986046, 59.44222815334797, 59.31957073509693, 59.15827319025993, 55.33071957528591, 50.713746920228004, 47.56155006587505, 45.1488733291626, 48.7486557662487, 45.51967263221741, 52.27677784860134, 60.659815818071365, 62.536504715681076, 62.7164326608181, 59.733497723937035, 48.237609788775444, 50.24983361363411, 48.61764259636402, 49.87050376832485, 48.77366602420807, 50.82475036382675, 50.86936376988888, 54.98881012201309, 60.662327483296394, 66.28075540065765, 65.0796626508236, 61.53128385543823, 60.66307224333286, 69.30309042334557, 64.9265992641449, 68.1537888944149, 65.11500835418701, 68.19595143198967, 64.07683566212654, 69.5653447508812, 64.04656648635864, 71.55760064721107, 62.69667752087116, 6.597898984327912, 6.14788580685854, 19.316162802278996, 1.627050011884421, 0.7115637708920985, 0.7488155469764024, 10.195852294564247, 73.64744290709496, 52.571991607546806, 43.741512447595596, 57.452335730195045, 49.876587241888046, 24.9697882309556, 51.201093569397926, 63.533130437135696, 65.72542279958725, 73.46130609512329, 20.43340165168047, 0.5740997346583754, 0.0744211366691161, 0.2712134155444801, 0.19807606819085777, 0.21379615121986717, 0.13893660565372556, 0.09590531743015163, 0.12221731725730933, 0.13502446323400363, 0.1253462489694357, 0.101126333756838, 0.11698315749526955, 0.15342080499976873, 0.1437868969514966, 0.10976246878271922, 0.12687878392171115], [0.03197552912752144, 0.015046610915305791, 0.02623190168378642, 0.021088660578243434, 0.046300634276121855, 0.03498627011140343, 0.042609655574779026, 0.10019696448580362, 0.024152774967660662, 0.00605514578637667, 0.04237796449160669, 0.025031882287294138, 0.045152795282774605, 0.03975667663326021, 0.017853499703051057, 40.401810854673386, 71.23670026659966, 64.08369049429893, 61.966888681054115, 29.497625268995762, 24.349435418844223, 44.74212795495987, 50.10088160634041, 36.99608400464058, 69.10032570362091, 5.139392847195268, 0.2280857297591865, 0.16739869635784999, 1.1123198946006596, 1.6873842431232333, 1.9223130494356155, 1.305732959881425, 0.42255133856087923, 37.45165675878525, 76.54707491397858, 67.83893778920174, 70.67094102501869, 66.72103017568588, 68.41399893164635, 65.33202230930328, 61.3938794285059, 52.249571308493614, 48.56656953692436, 49.841917902231216, 55.207427591085434, 54.30301912128925, 55.87661728262901, 50.72209507226944, 47.608165964484215, 46.37455075979233, 45.22062107920647, 44.52628433704376, 45.241181775927544, 43.30722615122795, 43.661401346325874, 43.58252137899399, 44.21238698065281, 44.80797082185745, 49.39249321818352, 46.213359609246254, 50.187900736927986, 53.84338058531284, 55.94414345920086, 57.400901690125465, 59.12490338087082, 56.77653059363365, 52.50143699347973, 44.29377481341362, 42.18019142746925, 42.77146629989147, 43.017465099692345, 42.56796821951866, 49.62836176156998, 52.40632049739361, 56.75460956990719, 52.207708954811096, 50.008592158555984, 59.015241265296936, 56.344695165753365, 46.63747765123844, 42.53630831837654, 42.77486331760883, 49.54761989414692, 53.159888461232185, 57.56927825510502, 54.93578016757965, 62.105729430913925, 39.727757424116135, 41.611152961850166, 61.2643937766552, 50.354233011603355, 51.932751908898354, 51.02303512394428, 54.340906888246536, 51.85134507715702, 49.8443041741848, 43.570916801691055, 50.105988532304764, 54.0818177908659, 57.14171759784222, 55.63417129218578, 54.90687131881714, 55.20369999110699, 53.067112639546394, 55.359947606921196, 56.80398032069206, 55.988620072603226, 55.49874655902386, 53.68613742291927, 48.65557596087456, 44.71589036285877, 41.00672319531441, 42.1117153018713, 43.45093064010143, 42.87570610642433, 48.59864741563797, 53.595455288887024, 55.27180373668671, 49.741230905056, 44.01165895164013, 44.00455713272095, 43.63599590957165, 44.13367040455341, 44.9875757843256, 45.38560822606087, 48.81118901073933, 53.41691806912422, 58.88999618589878, 60.90736873447895, 60.147952884435654, 59.83350835740566, 62.11082875728607, 58.520504012703896, 61.97152443230152, 59.20758694410324, 63.184248358011246, 56.003291085362434, 58.5299389064312, 59.13928180932999, 66.19952335953712, 59.76112604141235, 70.56164368987083, 39.14628602564335, 0.5695117183495313, 3.728279904462397, 1.9521041633561254, 0.15698238654294983, 0.15757134009618312, 0.13760134839685634, 30.105714239180088, 58.76980483531952, 23.69744550436735, 56.515932977199554, 50.23338429629803, 15.746774934232235, 24.862396493554115, 41.31234459578991, 48.86602006852627, 57.112972140312195, 38.84200595319271, 1.3415270391851664, 0.00961145808105357, 0.07493315919418819, 0.04889366857241839, 0.03414102699025534, 0.09681573967100121, 0.03838842349068727, 0.04573581907607149, 0.001665699205659621, 0.0710929160413798, 0.038854811355122365, 0.04599548541591503, 0.08541984687326476, 0.009901711109705502, 0.04930608003633097, 0.05907986807869747, 0.039747121481923386, 0.08602927628089674, 0.08051365701248869, 0.07052583358017728, 0.04535415479040239, 0.06257229630136862, 0.047344364793389104, 0.052694589030579664, 0.027651392701955047, 0.059159775119042024, 0.02612271135149058, 0.02669517994945636, 0.055560741093358956, 0.07866735686548054, 0.13079506752546877, 53.13348367810249, 79.7259995341301, 70.98534375429153, 70.8835244178772, 41.205897107720375, 32.0394741743803, 37.408992648124695, 44.62046228349209, 43.68279039859772, 74.35348302125931, 6.022887239232659, 0.43459969048853964, 0.2939669508486986, 2.6053634472191334, 7.4720819760113955, 5.2362206764519215, 2.0261693140491843, 0.37482129817362875, 40.63503094017506, 79.87052857875824, 68.75579059123993, 74.34139207005501, 71.01330265402794, 71.97869405150414, 68.39636787772179, 67.17359349131584, 54.23080399632454, 49.995600655674934, 52.12025664746761, 57.16415539383888, 57.3126058280468, 59.01038512587547, 53.453897684812546, 50.06864793598652, 48.199364840984344, 47.25603885948658, 45.30304625630379, 47.51055680215359, 45.69195918738842, 46.377541199326515, 46.1214729398489, 47.493472918868065, 47.3528690636158, 50.96308574080467, 48.94732050597668, 50.88359780609608, 55.16428090631962, 59.67262499034405, 58.846876099705696, 62.50386446714401, 59.44468282163143, 54.21249657869339, 46.52139388024807, 45.089315325021744, 45.2391716837883, 45.01342959702015, 44.00809854269028, 50.78596964478493, 55.71454457938671, 59.31616611778736, 54.054383262991905, 53.006296902894974, 60.44307164847851, 58.133403584361076, 48.837548196315765, 45.61614565551281, 45.578805059194565, 52.98970319330692, 54.634133353829384, 59.29110266268253, 57.44538590312004, 64.4005174934864, 42.711254730820656, 45.61136931180954, 64.49785307049751, 53.033507242798805, 55.25169521570206, 54.430198296904564, 56.89494363963604, 53.26150640845299, 51.33527956902981, 46.142675802111626, 52.75548376142979, 55.56294411420822, 60.278844460844994, 57.724906504154205, 57.07125797867775, 56.34963870048523, 56.04198440909386, 57.01938696205616, 59.396630600094795, 57.50471591949463, 58.42588149011135, 55.849460139870644, 51.10603407025337, 47.807032093405724, 42.704411298036575, 44.435450211167336, 45.032420977950096, 46.19116500020027, 52.4373534321785, 54.72475089132786, 57.276766151189804, 51.83538593351841, 47.13188052177429, 47.23365046083927, 45.68022161722183, 45.16467668116093, 48.26276443898678, 47.89238691329956, 51.53851546347141, 56.311963722109795, 62.27337643504143, 63.87069672346115, 60.27110427618027, 60.73323927819729, 65.20509392023087, 62.273923605680466, 64.4565948843956, 60.31757578253746, 64.14131060242653, 59.795753583312035, 61.50292977690697, 60.364210680127144, 68.95778015255928, 62.34167017042637, 73.14175844192505, 45.289135202765465, 0.6619537516962737, 0.75543865095824, 3.2561808871105313, 1.1914401990361512, 0.2375088381813839, 0.10218077717581764, 31.226186715066433, 71.01965591311455, 27.04570423811674, 46.11681059002876, 45.27963191270828, 18.85070487856865, 33.16612131893635, 48.2305383682251, 56.109263598918915, 64.25519049167633, 48.06410729885101, 2.2441094694659114, 0.08583051429013722, 0.02207585799624212, 0.020939657733833883, 0.012557199916045647, 0.02718354095122777, 0.014342672711791238, 0.05290628665534314, 0.02375386502535548, 0.01995524336962262, 0.06248165780561976, 0.03437096660491079, 0.07962843810673803, 0.029562118688772898, 0.08277581218862906, 0.015296847341232933, 0.1727817754726857, 0.16477529337862507, 0.18848363135475665, 0.15213718637824059, 0.2105312209459953, 0.1265544950729236, 0.12196207040688023, 0.14569528517313302, 0.11433149353251792, 0.13458235102007166, 0.16978651197860017, 0.11815147605375387, 0.16733068594476208, 0.16450636874651536, 0.39893504173960537, 62.299838215112686, 89.01071012020111, 79.68025758862495, 79.87857654690742, 41.42189271748066, 34.927949979901314, 59.57155421376228, 70.36801367998123, 52.51152165234089, 82.79656916856766, 7.259485283866525, 0.47770950535777956, 0.31732756295241416, 4.82043843716383, 4.3886457569897175, 6.513748224824667, 8.044347893446684, 0.9231029916554689, 48.65808002650738, 75.710329413414, 72.0890249311924, 73.45872983336449, 74.68797147274017, 74.35508653521538, 71.54672563076019, 68.19944724440575, 57.698881700634956, 52.604259476065636, 54.94866527616978, 59.92819547653198, 59.89368572831154, 62.35990159213543, 55.74828676879406, 51.55863158404827, 51.627639681100845, 48.72190520167351, 49.4705980271101, 49.67568822205067, 48.59973415732384, 48.29293102025986, 49.105471819639206, 49.21660825610161, 50.082707181572914, 52.69384726881981, 52.46193811297417, 55.27328945696354, 58.89571487903595, 60.55492624640465, 62.14435815811157, 65.46333566308022, 62.42882989346981, 55.95300458371639, 48.32981564104557, 46.76698990166187, 48.173237442970276, 46.69465318322182, 46.428606659173965, 54.14480321109295, 56.813947185873985, 61.36111378669739, 54.701397344470024, 53.08499068021774, 65.6519803404808, 61.53274677693844, 51.78506143391132, 45.60191161930561, 49.137181118130684, 54.014105424284935, 58.87057922780514, 59.55097831785679, 59.5663370937109, 66.74593403935432, 44.44087632000446, 47.335758581757545, 68.15106064081192, 54.995227977633476, 57.48211093246937, 56.53568051755428, 59.9042871594429, 56.638833582401276, 54.227429777383804, 47.364519238471985, 54.55807663500309, 58.44464108347893, 62.91065163910389, 60.41650727391243, 59.721167385578156, 61.10767498612404, 58.391462936997414, 59.023600816726685, 61.96453660726547, 60.80008149147034, 60.45260913670063, 57.999244183301926, 53.70063744485378, 50.699254497885704, 45.4757621884346, 47.24351853132248, 47.639757469296455, 47.450820207595825, 55.18660090863705, 58.20140853524208, 60.592954605817795, 55.275998711586, 48.772146105766296, 49.61528666317463, 48.379186391830444, 48.233555406332016, 50.854293778538704, 50.06289504468441, 53.47016841173172, 58.83399099111557, 63.1986989825964, 66.83015272021294, 63.15287724137306, 63.17178122699261, 68.90935555100441, 65.32385274767876, 68.42229008674622, 62.539787739515305, 69.65553671121597, 61.15692414343357, 63.868599236011505, 63.09722542762756, 71.32826015353203, 65.15639573335648, 77.79716983437538, 45.81458620727062, 0.8443823782727122, 10.004984736442566, 6.597505230456591, 0.6856549205258489, 0.30881839455105364, 0.1936236719484441, 37.51004442572594, 75.70661321282387, 37.951432541012764, 69.67550843954086, 59.442292749881744, 25.3759940341115, 38.78615655004978, 57.774744629859924, 63.80237638950348, 71.01523295044899, 54.651893600821495, 3.101887791417539, 0.17902492952998728, 0.15346809464972466, 0.20170263218460605, 0.1265086155035533, 0.22010243235854432, 0.10455907846335322, 0.19996943534351885, 0.07535858792834915, 0.1621183453244157, 0.12274979337234981, 0.1413043832872063, 0.22859182994579896, 0.21619346633087844, 0.1851327603799291, 0.1579170918557793], [0.12892421713331714, 0.019160000592819415, 0.011817853846878279, 0.025463886449870188, 0.01685942628682824, 0.019103862687188666, 0.02273917660204461, 0.024042415752774104, 0.05030465828895103, 0.06807399287936278, 0.06781455289456062, 0.017891219358716626, 0.06579056775080971, 0.07925813610199839, 1.853822199627757, 58.77779200673103, 66.71504929661751, 56.66367664933205, 47.214780673384666, 21.626277342438698, 22.47500739991665, 59.770131558179855, 42.69060663878918, 56.26944400370121, 52.508903592824936, 0.1661772548686713, 0.03239604855480138, 0.39295083784963936, 1.7299482529051602, 7.165475003421307, 3.758280244655907, 2.7625534124672413, 6.425301795825362, 77.20373287796974, 74.09020274877548, 68.98919686675072, 68.63406792283058, 67.57992088794708, 66.1110109090805, 64.5252799987793, 63.41458439826965, 59.72038082778454, 55.7700178027153, 47.96909719705582, 48.03835608065128, 48.066998943686485, 49.43624027073383, 48.48451294004917, 46.87564507126808, 45.81805922091007, 44.525300189852715, 44.05163660645485, 44.43333752453327, 42.42691978812218, 43.271994441747665, 43.13737906515598, 42.43175692856312, 45.27637168765068, 45.36336421966553, 44.992116540670395, 49.81992468237877, 52.91891299188137, 55.107724741101265, 57.3099497705698, 57.38968849182129, 56.214293763041496, 52.475613579154015, 45.205596685409546, 42.52661883831024, 41.977647095918655, 41.42842836678028, 44.567044749855995, 49.707397520542145, 53.72928410768509, 58.971893191337585, 55.25002330541611, 51.802890077233315, 55.6177219748497, 55.097442492842674, 43.829622119665146, 45.987207144498825, 43.22651468217373, 52.95093387365341, 52.15294249355793, 56.57576456665993, 52.851918786764145, 64.49548959732056, 39.39677618443966, 43.14953461289406, 62.08698123693466, 49.43450756371021, 50.536866411566734, 48.914931043982506, 56.01953901350498, 53.02837751805782, 49.8828911036253, 42.58421614766121, 43.6751414090395, 48.43871779739857, 52.71619386970997, 51.94599039852619, 53.40041175484657, 49.091621562838554, 54.45548214018345, 52.42082051932812, 54.96813163161278, 57.022419199347496, 56.21639885008335, 53.9765178412199, 50.672199949622154, 45.438436791300774, 41.96544215083122, 41.22455790638924, 43.08912545442581, 42.51827448606491, 46.01249098777771, 51.188812628388405, 50.482396334409714, 47.83433362841606, 43.19238491356373, 44.23123396933079, 43.82768042385578, 44.57686722278595, 43.996459767222404, 46.33573964238167, 53.84181126952171, 58.69619518518448, 60.10067582130432, 60.13543635606766, 59.49609026312828, 61.010840982198715, 59.71553608775139, 57.44676522910595, 56.17863267660141, 56.748089119791985, 54.15579982101917, 56.689101085066795, 54.49348770081997, 57.06208147108555, 57.52532221376896, 64.87070426344872, 58.89808975160122, 73.58005732297897, 19.284993074834347, 0.715586330043152, 1.6047511459328234, 0.6808425975032151, 0.3101821057498455, 0.28239146573469043, 9.847988560795784, 61.75455987453461, 41.509303227066994, 29.322747252881527, 33.83080065250397, 23.05947683751583, 18.169057555496693, 36.40940688550472, 46.138876006007195, 49.539237543940544, 49.231397062540054, 4.154885150492191, 0.051438040245557204, 0.07429103075992316, 0.051506332674762234, 0.03851465538900811, 0.009323974190920126, 0.13065851235296577, 0.08525791025022045, 0.07411883765598759, 0.025747542713361327, 0.04357121550128795, 0.03801493025093805, 0.017750949737092014, 0.031838250361033715, 0.021001170644012745, 0.025311002173111774, 0.009535880544717656, 0.08883990827598609, 0.013097915725666098, 0.010210821183136432, 0.010302754726581043, 0.04191863445157651, 0.04807108321983833, 0.0512120748317102, 0.03973197424784303, 0.04044713743496686, 0.0442289884085767, 0.046321611080202274, 0.05563980579609051, 0.07844919513445348, 2.4003796465694904, 70.60138955712318, 72.94287711381912, 64.54828396439552, 54.55436423420906, 26.846938803792, 24.892941154539585, 48.51684920489788, 44.57396797835827, 65.70614263415337, 55.4307796061039, 0.20274411770515144, 0.15529112104559317, 0.9018905705306679, 2.4355097115039825, 8.06092070415616, 6.038334360346198, 1.8923020223155618, 8.500950392335653, 81.28967642784119, 75.93881115317345, 72.3267325758934, 70.79869776964188, 67.98985049128532, 68.68069142103195, 68.84003967046738, 66.21619686484337, 64.28326338529587, 57.116042375564575, 49.36886228621006, 51.52719587087631, 51.65911339223385, 50.76763562858105, 50.46542264521122, 48.754830434918404, 47.36268013715744, 48.042053282260895, 46.33504427969456, 45.58081895112991, 45.690728053450584, 46.64114825427532, 45.01017317175865, 44.330154061317444, 47.19609707593918, 49.07059349119663, 46.83694414794445, 50.69675423204899, 54.33370627462864, 59.00958336889744, 59.32272456586361, 60.08669637143612, 59.347864016890526, 55.4646547883749, 47.699079886078835, 44.387230798602104, 43.551013469696045, 45.80991245806217, 47.397927045822144, 50.88339261710644, 56.3304041326046, 60.53466573357582, 56.683792769908905, 53.01426887512207, 60.46592362225056, 57.96734869480133, 44.54161271452904, 46.69162094593048, 45.441130846738815, 55.087221041321754, 55.65438240766525, 59.21128414571285, 54.72897246479988, 65.84436401724815, 42.78973191976547, 45.11059418320656, 62.8048425167799, 52.69485041499138, 53.959525153040886, 51.75114445388317, 56.535030752420425, 53.54093201458454, 51.80231250822544, 45.37939555943012, 45.609625205397606, 49.41620394587517, 55.65500557422638, 53.99873524904251, 55.62639690935612, 50.724758729338646, 55.62214493751526, 53.598020151257515, 56.99477568268776, 57.706933468580246, 58.24064902961254, 56.14251181483269, 53.515648171305656, 48.24987173080444, 43.98504517972469, 42.88574516773224, 45.467448234558105, 45.786239728331566, 47.62911804020405, 51.9233588129282, 52.637325301766396, 50.173571705818176, 45.625428557395935, 45.852508172392845, 46.18714861571789, 46.23073227703571, 45.45558527112007, 49.16882961988449, 57.004427164793015, 60.793656036257744, 61.508758664131165, 61.94342873990536, 60.79234130680561, 63.70640113949776, 62.00007990002632, 59.213765412569046, 58.604000732302666, 58.01922731101513, 58.06305415928364, 59.231806844472885, 56.884315609931946, 59.66200076043606, 61.68061964213848, 67.10566073656082, 60.15343219041824, 76.16068124771118, 22.074389196932316, 0.47856282675638795, 2.2435948345810175, 2.007719879038632, 0.7377872918732464, 0.21208232443314046, 9.223877750337124, 69.25268232822418, 45.39335981011391, 33.05186904966831, 36.20721213519573, 24.859924726188183, 27.63130411505699, 43.97409036755562, 53.311196342110634, 54.23799321055412, 58.99893634021282, 7.069452255964279, 0.05906685451918747, 0.05550713947741315, 0.11627696687355638, 0.04762940516229719, 0.06748002982931212, 0.056726951952441595, 0.014322613387776073, 0.03397287488041911, 0.05985209500067867, 0.11142269024276175, 0.0038313506001941278, 0.03392147002159618, 0.04285500959667843, 0.07237706900923513, 0.014290148137661163, 0.19213792198570445, 0.10833638749318197, 0.10247355443425477, 0.08071861593634821, 0.15544198482530192, 0.1944354033912532, 0.1029047422343865, 0.18567712570074946, 0.16970434138784185, 0.2068296109791845, 0.20053115207701921, 0.1761615159921348, 0.20051999017596245, 0.1613615921814926, 4.160620467737317, 82.81768083572388, 82.18434602022171, 75.18688470125198, 61.58169575035572, 31.831560730934143, 32.93867692351341, 79.69154298305511, 61.54025137424469, 72.50630334019661, 63.83758530020714, 0.805475078523159, 0.18899934977525845, 1.6793210757896304, 5.234215334057808, 13.699201606214046, 13.489465210586786, 5.411137165501714, 9.678864385932684, 85.04939988255501, 79.04810070991516, 73.02730098366737, 71.89041718840599, 70.07777005434036, 69.8774828016758, 72.10122987627983, 66.73850923776627, 66.30368337035179, 60.68064630031586, 52.7628705650568, 54.05961938202381, 54.02984797954559, 53.73287871479988, 54.75107587873936, 52.00016029179096, 51.485094130039215, 48.960919976234436, 49.696936681866646, 48.904948979616165, 47.289530262351036, 48.39703783392906, 48.109419867396355, 46.269364804029465, 50.398721024394035, 51.1244972795248, 50.28130352497101, 54.668753296136856, 57.20960855484009, 60.90580701828003, 61.73244506120682, 62.89243921637535, 62.031158432364464, 58.624975606799126, 50.254647955298424, 47.27894023060799, 46.943999603390694, 46.846637427806854, 50.68491406738758, 55.2809726446867, 60.13208493590355, 65.03175482153893, 57.11118243634701, 54.192847833037376, 62.09448963403702, 61.40698492527008, 47.48780742287636, 49.87436056137085, 47.47641563415527, 57.6629014313221, 58.19740355014801, 60.06168991327286, 56.9294647872448, 67.82574489712715, 43.906617388129234, 48.3089167624712, 66.54255375266075, 55.66784888505936, 55.71935512125492, 54.44367617368698, 59.339116886258125, 56.56662605702877, 54.46672573685646, 47.61842541396618, 47.884517535567284, 52.90200389921665, 58.88664476573467, 56.81698702275753, 59.87940229475498, 53.65894228219986, 58.48776496946812, 57.01092481613159, 58.43575716018677, 60.500668957829475, 61.67526192963123, 58.22827309370041, 56.03928655385971, 51.126651763916016, 46.21380798518658, 46.04727432131767, 48.10528188943863, 46.890175491571426, 50.38420960307121, 56.518041864037514, 56.14124268293381, 52.09259033203125, 48.42815816402435, 48.46080221235752, 47.90340252220631, 49.651076942682266, 48.1099708378315, 51.758641451597214, 58.570763915777206, 62.09504060447216, 64.78625759482384, 63.1328409165144, 62.58396036922932, 66.89278855919838, 64.6637749671936, 63.12405578792095, 61.12921603024006, 60.95358945429325, 60.40883548557758, 62.37468659877777, 60.46885326504707, 61.77512437105179, 65.38663297891617, 70.29831022024155, 62.16545082628727, 79.21971470117569, 22.684879638254642, 0.7278559310361743, 9.220184348523617, 2.0107704028487206, 0.9571448306087404, 0.35365509800612926, 12.521349359303713, 72.52427637577057, 56.88581272959709, 42.64648340642452, 45.04370257258415, 34.45231430232525, 32.14775316417217, 50.73099039494991, 62.028517574071884, 62.76885464787483, 70.2124272286892, 10.990574900060892, 0.314025332336314, 0.3067863645264879, 0.19137278257403523, 0.20223910105414689, 0.15747405937872827, 0.22111034311819822, 0.1708870130823925, 0.1578401608276181, 0.14354834100231528, 0.13643408368807286, 0.1432486914563924, 0.09639565440011211, 0.15964776539476588, 0.16182366816792637, 0.07689708974794485], [0.05762388194852974, 0.04036561993416399, 0.026318651325709652, 0.04204786833724938, 0.0512150174472481, 0.06815533968620002, 0.03972990365582518, 0.018226761021651328, 0.015541446227871347, 0.054382652160711586, 0.026301255384169053, 0.03309574167360552, 0.10364447050960734, 0.10610428187646903, 10.563803650438786, 72.01321139931679, 57.78687357902527, 60.49548603594303, 39.79477442800999, 28.18147089332342, 40.63208229839802, 47.62694075703621, 34.203458055853844, 73.68235543370247, 23.400941714644432, 0.0725242962653283, 0.07058139817672782, 0.5828729295171797, 0.6899344408884645, 8.91217952594161, 6.236363109201193, 0.5079197546001524, 51.09337694942951, 78.54332059621811, 67.90411949157715, 68.7122069299221, 67.43685856461525, 69.53427001833916, 63.61821927130222, 63.39148923754692, 64.09994602203369, 62.75438502430916, 62.96179309487343, 54.031075313687325, 47.613276690244675, 45.991759300231934, 47.367855459451675, 44.70214270055294, 44.88532707095146, 44.70809318125248, 47.92864836752415, 43.300462514162064, 43.71562063694, 41.29923149943352, 42.32081048190594, 41.81504622101784, 41.99791140854359, 43.15201587975025, 45.4492662101984, 43.76431502401829, 45.978931188583374, 53.02042454481125, 54.55771565437317, 57.42216154932976, 58.81144680082798, 55.24609051644802, 51.42200991511345, 43.77690754830837, 43.362376391887665, 39.01627220213413, 43.53961408138275, 44.537159353494644, 50.08576221764088, 53.79282049834728, 56.75411559641361, 52.06035666167736, 55.0489304959774, 55.84450140595436, 50.19466057419777, 44.04486157000065, 46.00025564432144, 43.52829068899155, 50.481978356838226, 50.39488323032856, 56.62621445953846, 52.87250608205795, 61.72130785882473, 41.25894986093044, 42.640757113695145, 64.40275937318802, 51.774634793400764, 50.0144362449646, 45.36746419966221, 53.221380561590195, 52.37445920705795, 52.03812025487423, 44.49622415006161, 41.35542668402195, 41.62814565002918, 45.023544654250145, 46.54272973537445, 47.53459431231022, 43.73121120035648, 49.15962651371956, 51.73319801688194, 56.012501791119576, 53.96002672612667, 56.489015221595764, 54.13691483438015, 51.896600648760796, 46.36693976819515, 43.61157841980457, 40.60583330690861, 43.85979250073433, 43.64070765674114, 44.27616275846958, 46.664604395627975, 46.15261226892471, 44.29913252592087, 42.065429985523224, 43.9829058945179, 43.61637756228447, 43.22175353765488, 45.33146493136883, 51.21424086391926, 58.05015005171299, 57.54669226706028, 59.881093204021454, 61.035554856061935, 60.121498703956604, 59.01591382920742, 59.95666354894638, 56.38459302484989, 55.52556551992893, 54.37311016023159, 54.48855556547642, 51.94884404540062, 54.748047441244125, 55.863637179136276, 59.32386830449104, 58.9882855117321, 63.773087561130524, 63.22595112025738, 58.59953597187996, 3.7089586537331343, 1.025197694543749, 3.3315783413127065, 0.10015691819717176, 0.08836193548631854, 0.15211887017358094, 40.18507428467274, 55.1167568564415, 30.68148024380207, 28.50437566637993, 22.01363045722246, 13.698516692966223, 19.07334443181753, 39.44016985595226, 43.80504883825779, 52.309478893876076, 12.958985175937414, 0.29049064207356423, 0.05989696153847035, 0.05436245090095326, 0.027752643909479957, 0.026679310976760462, 0.1280392802436836, 0.04421122881467454, 0.04299186904972885, 0.04170651009189896, 0.02201998355303658, 0.05113888793857768, 0.0363532096525887, 0.0758689851500094, 0.06916138765518554, 0.05220693121373188, 0.04976809294021223, 0.026745050417957827, 0.03093254261330003, 0.0012205986877233954, 0.05501687672222033, 0.014427614296437241, 0.0644435548747424, 0.026833102529053576, 0.04726554128865246, 0.04434400274476502, 0.04778669594088569, 0.08850847254507244, 0.08093600583379157, 0.06590289922314696, 16.70524500310421, 82.03849464654922, 64.96725708246231, 68.62788185477257, 47.6928786188364, 37.622104212641716, 35.09233295917511, 41.829151064157486, 42.51366913318634, 79.53405663371086, 25.880097784101963, 0.23428601736668497, 0.0722948316251859, 1.697252788580954, 2.5876813335344195, 8.325380813330412, 3.938387492671609, 0.21795995591674, 52.92031891644001, 81.6529293358326, 69.78656888008118, 73.25904294848442, 71.17176175117493, 71.98863431811333, 64.19912070035934, 65.66692113876343, 68.40395227074623, 65.46304687857628, 64.27966117858887, 56.997712925076485, 49.66227114200592, 49.2896631360054, 48.939960300922394, 47.29482337832451, 48.63825649023056, 46.183451414108276, 49.46613326668739, 47.105240151286125, 46.00572735071182, 44.74022425711155, 45.33270366489887, 45.009010434150696, 45.00020630657673, 47.68870264291763, 47.75255061686039, 45.751304402947426, 48.03257659077644, 55.019812658429146, 58.65905977785587, 58.88416349887848, 59.64511826634407, 59.17313039302826, 54.51845236122608, 45.77461235225201, 44.46225017309189, 41.84181198477745, 45.59313029050827, 46.08808793127537, 53.57482239603996, 55.2535305172205, 57.68691994249821, 53.804759457707405, 56.52202025055885, 59.219449907541275, 53.33991900086403, 45.61923488974571, 47.931125834584236, 46.58932663500309, 53.36882404983044, 54.004347547888756, 57.15481549501419, 55.66972218453884, 62.849395126104355, 44.49984535574913, 44.020865857601166, 66.632289737463, 55.03930941224098, 50.25076076388359, 48.2089327275753, 55.26672720909119, 53.17416049540043, 54.175927340984344, 47.62986660003662, 44.940325319767, 43.73382925987244, 47.19784118235111, 48.18728148937225, 49.49449494481087, 47.16139733791351, 50.754632726311684, 54.50312398374081, 57.5520271807909, 57.227220609784126, 58.359529450535774, 57.09494970738888, 54.296358078718185, 48.8794219493866, 47.066505029797554, 42.718181759119034, 44.548437148332596, 46.6442146897316, 47.45108239352703, 49.49093833565712, 49.22760106623173, 44.803213477134705, 44.53188143670559, 46.53804458677769, 45.128780007362366, 46.259238347411156, 46.50317005813122, 53.38541015982628, 59.541646018624306, 60.8334930986166, 62.33134612441063, 62.10207782685757, 63.69864955544472, 58.84406045079231, 63.140299916267395, 58.619332909584045, 57.73722164332867, 56.020553559064865, 58.009207248687744, 55.459357872605324, 57.8731669485569, 56.904500126838684, 61.49794444441795, 60.7373658567667, 67.15319618582726, 64.04743283987045, 63.29290732741356, 4.801453705877066, 0.3333339368691668, 3.9069807529449463, 0.6617338978685439, 0.17015574529068545, 0.38043517037294805, 42.31980733573437, 62.34532557427883, 35.09124621748924, 30.596022829413414, 26.646573655307293, 22.29283757507801, 23.223242349922657, 46.05910308659077, 51.174852177500725, 61.77837699651718, 20.452674217522144, 0.2386355519411154, 0.03917004600225482, 0.05680397945980076, 0.034310091941733845, 0.11586175009142607, 0.11390399420633912, 0.052481473903753795, 0.01556340266688494, 0.04869826108915731, 0.05784736858913675, 0.0422287482797401, 0.017986188286158722, 0.07313926951610483, 0.03288333900854923, 0.009098377067857655, 0.13215766550274566, 0.1323412876809016, 0.27980647631920874, 0.1534767184057273, 0.18050870537990704, 0.17059192032320425, 0.19126906001474708, 0.10421052880701609, 0.16222640202613547, 0.11741106500267051, 0.20919838309055194, 0.19712107256054878, 0.29687222151551396, 0.2655548066832125, 21.756866835057735, 95.59913858771324, 74.69385355710983, 78.82891327142715, 53.29069644212723, 40.800128281116486, 53.76504398882389, 68.95635142922401, 48.36630888283253, 88.60731616616249, 28.317796178162098, 0.36965802835766226, 0.1903123129159212, 3.310406827367842, 3.0826667603105307, 28.571428768336773, 18.754159659147263, 0.6293487700168043, 60.080818086862564, 82.95126646757126, 72.98164263367653, 75.25271236896515, 74.59141105413437, 74.30347010493279, 66.3483689725399, 65.85479825735092, 69.41722109913826, 67.5063568353653, 66.31361603736877, 59.458251893520355, 54.178260415792465, 50.98954752087593, 52.05697864294052, 49.15662847459316, 50.022723600268364, 49.032147154212, 52.40429900586605, 49.43232648074627, 48.43392625451088, 47.3250013589859, 47.83904917538166, 46.57511919736862, 47.34050452709198, 50.07877439260483, 51.69576242566109, 49.18670006096363, 50.59222184121609, 59.608412235975266, 60.46558924019337, 61.805401146411896, 63.44328045845032, 61.533179953694344, 56.93430192768574, 49.542178586125374, 48.39190810918808, 43.958317413926125, 49.24011379480362, 48.357747942209244, 55.7918818295002, 59.37052980065346, 59.29625138640404, 56.40858493745327, 61.75768330693245, 61.30260452628136, 56.39680176973343, 48.13735976815224, 49.954517260193825, 48.8118539750576, 55.848776176571846, 56.286246702075005, 60.83987295627594, 59.4379685819149, 64.854995906353, 46.89466305077076, 46.83773830533028, 70.19187033176422, 57.099612057209015, 54.20548215508461, 51.66559584438801, 58.790631517767906, 57.43415750563145, 56.22771464288235, 49.94200833141804, 47.711661010980606, 46.49325639009476, 50.53333640098572, 51.291775703430176, 52.190609872341156, 49.02724161744118, 53.74335095286369, 57.75433212518692, 60.524052903056145, 58.91029849648476, 61.17491997778416, 59.257599860429764, 56.787063628435135, 52.369143292307854, 48.068629056215286, 44.2656335234642, 47.3201110213995, 46.97319343686104, 49.42328296601772, 52.33279824256897, 52.67675958573818, 47.03752398490906, 46.42707534134388, 48.91906902194023, 46.999260038137436, 48.3123479783535, 49.9490911513567, 56.461284309625626, 62.65037700533867, 63.4512410312891, 62.95271918177605, 65.14448717236519, 66.23782530426979, 61.37995317578316, 66.05332240462303, 61.672552675008774, 61.49040184915066, 60.15396036207676, 60.57205192744732, 58.97999435663223, 60.104863196611404, 60.351804345846176, 65.16642719507217, 63.54354187846184, 70.95931515097618, 66.84510111808777, 66.02368399500847, 4.492397764697671, 4.789610216394067, 12.871525269001722, 0.6961489480454475, 0.2698669518576935, 0.4706705908756703, 50.79876735806465, 69.79383409023285, 44.26431879401207, 41.418115720152855, 32.74943187832832, 22.956365570425987, 28.51966604590416, 55.5523806810379, 59.338326528668404, 71.15196481347084, 28.48538998514414, 0.4512652102857828, 0.18379235261818394, 0.14277379115810618, 0.1175824120582547, 0.16960815904894844, 0.23803614894859493, 0.07038258423563093, 0.12303126772167161, 0.17659829958574846, 0.10709975424106233, 0.1963422924745828, 0.11587662273086607, 0.19644760322989896, 0.12819761002901942, 0.15244548936607316], [0.008982784784166142, 0.048915120351011865, 0.03759875980904326, 0.03383154027687851, 0.008604970389569644, 0.018798032906488515, 0.023206007899716496, 0.06573838734766468, 0.009911973156704335, 0.0055448306648031576, 0.1061428216053173, 0.05167823634110391, 0.04121703401324339, 0.0415259715373395, 27.528565227985382, 71.18886843323708, 59.79927979409695, 56.435745880007744, 34.70368981361389, 20.4989842325449, 35.218881368637085, 46.635543555021286, 41.46237954497337, 74.96416345238686, 8.236688822507858, 0.08550762810045853, 0.07082962431013584, 0.45667980099096894, 2.556086266413331, 7.499505579471588, 4.681511241942644, 3.6269497917965055, 82.20609605312347, 64.44634303450584, 70.72638764977455, 62.511635050177574, 69.32096466422081, 63.51131960749626, 71.17553114891052, 58.479557409882545, 62.186414301395416, 62.5239197909832, 63.323465287685394, 58.359616845846176, 53.00595112144947, 45.43390743434429, 46.06116257607937, 44.236694276332855, 47.223242819309235, 44.831966534256935, 46.73692971467972, 43.641627207398415, 44.17459420859814, 43.006799072027206, 43.90159785747528, 43.62433433532715, 43.12542870640755, 41.245684772729874, 44.07686725258827, 42.79260836541653, 43.61705772578716, 47.10989870131016, 56.07328712940216, 55.38216881453991, 58.18249695003033, 53.69889713823795, 48.2038713991642, 42.947028279304504, 43.00705745816231, 40.79876035451889, 43.69352102279663, 44.95113953948021, 48.96019421517849, 53.86370189487934, 54.602036476135254, 51.36776402592659, 58.53121943771839, 52.78410002589226, 46.17820769548416, 41.218854412436485, 43.899500370025635, 41.64334483444691, 48.46942774951458, 47.902551367878914, 52.661602199077606, 49.7370321303606, 61.005369275808334, 42.82008849084377, 41.87320590019226, 60.69443196058273, 52.88747347891331, 48.148128390312195, 43.10078322887421, 48.87955114245415, 49.52552028000355, 50.65310597419739, 45.12172758579254, 44.16089214384556, 43.344171568751335, 41.117555648088455, 41.596307158470154, 40.931259244680405, 42.16542162001133, 45.91844603419304, 46.77881486713886, 52.35183522105217, 55.44121004641056, 54.54670384526253, 55.266138240695, 50.07427543401718, 47.03726939857006, 42.70365513861179, 39.75657507777214, 43.33151064813137, 41.67217768728733, 43.76899637281895, 43.851109966635704, 44.30479422211647, 42.81498536467552, 43.116518184542656, 43.33431489765644, 44.41823713481426, 45.459198877215385, 45.997987166047096, 53.481020629405975, 59.475453570485115, 59.058501943945885, 58.4601404517889, 58.97488363087177, 58.382229432463646, 56.26147203147411, 51.70308083295822, 52.432284504175186, 51.101003140211105, 51.83934532105923, 52.42566145956516, 51.39794960618019, 53.71696516871452, 54.647615030407906, 55.433625653386116, 58.27194035053253, 61.96697607636452, 62.107659727334976, 67.76588290929794, 30.00828556716442, 0.07264873216627166, 3.7886289786547422, 1.2037767120637, 0.30209922697395086, 0.06713052280247211, 11.355247031897306, 65.58756619691849, 45.03078706562519, 37.0917134732008, 30.653416849672794, 20.871677733957767, 23.357529044151306, 36.75056017935276, 48.34132522344589, 53.70832823216915, 30.58612246066332, 0.6336347619071603, 0.028551936957228463, 0.03219694146537222, 0.052084721755818464, 0.0515899096353678, 0.026237144957121927, 0.05817675970320124, 0.01599743660335662, 0.0846235966309905, 0.06594558013603091, 0.01741255822707899, 0.019782627241511364, 0.02736599610216217, 0.029353753307077568, 0.042599992812029086, 0.06301294648437761, 0.03513025047141127, 0.022033529603504576, 0.025999308891186956, 0.06279860681388527, 0.05115876265335828, 0.08107186338747852, 0.031619947621948086, 0.010732025002653245, 0.09555164695484564, 0.011708961301337695, 0.021485306970134843, 0.020342867101135198, 0.052038085195817985, 37.217475324869156, 80.37671461701393, 64.01839479804039, 63.95956635475159, 42.77996264398098, 28.47527302801609, 29.030846916139126, 45.75314350426197, 51.275052800774574, 79.98987257480621, 8.332120701670647, 0.1440237311180681, 0.4156713030533865, 0.7900606712792069, 3.3278949139639735, 5.242997137829661, 2.4917742423713207, 4.1757650300860405, 85.33078998327255, 66.05469033122063, 73.8470233976841, 64.11730349063873, 71.76585987210274, 65.39392858743668, 72.11714342236519, 58.80742281675339, 63.76043424010277, 64.54649806022644, 67.02645778656006, 59.53002244234085, 55.32799892127514, 49.17789973318577, 48.39868314564228, 47.32761561870575, 49.916040524840355, 46.189614683389664, 48.74849617481232, 46.021979078650475, 46.28494776785374, 45.49952611327171, 46.25290788710117, 46.583972722291946, 45.22212579846382, 42.70773231983185, 46.934910491108894, 44.260910376906395, 46.38003766536713, 49.912996888160706, 59.39062312245369, 57.50642962753773, 61.41048073768616, 55.414554476737976, 50.07064662873745, 43.54795843362808, 44.676383882761, 43.171337842941284, 45.383316949009895, 46.672526970505714, 50.5841700732708, 54.56053510308266, 56.82812802493572, 55.34447483718395, 61.5247406065464, 55.269539058208466, 47.47132770717144, 43.829397931694984, 45.620762407779694, 43.52658078074455, 49.94671247899532, 49.612615406513214, 54.470666125416756, 51.18171840906143, 63.15790057182312, 43.41813459992409, 42.49284625053406, 62.94197715818882, 53.97421136498451, 50.17463564872742, 45.262681022286415, 50.90594440698624, 51.26310244202614, 51.428822949528694, 47.374003529548645, 47.270603477954865, 44.260602593421936, 43.65483909845352, 44.66948725283146, 43.20444166660309, 43.53520251810551, 48.47984679043293, 51.232263296842575, 54.40609619021416, 57.278962433338165, 55.9801085293293, 55.69763548672199, 54.25727337598801, 48.942217379808426, 45.79419270157814, 42.95420989394188, 44.507000371813774, 44.62374150753021, 45.698247849941254, 44.44619223475456, 46.046521961688995, 44.52309250831604, 45.23734778165817, 45.31179338693619, 46.012623980641365, 47.25818194448948, 48.007547333836555, 57.36579917371273, 61.871669590473175, 62.717158421874046, 59.633726477622986, 60.47517992556095, 59.43725802004337, 59.311659559607506, 54.34683836996555, 55.14092355966568, 52.529536485672, 53.357778042554855, 52.987655103206635, 55.14992527663708, 56.63766324520111, 56.84662163257599, 58.31825606524944, 61.00281201303005, 64.3942554295063, 62.95663297176361, 69.43486735224724, 34.76876512169838, 0.09176566221867688, 1.1689424375072122, 3.0569050926715136, 1.074805457610637, 0.09691840095911175, 10.869759432971478, 73.13573196530342, 49.29161623120308, 36.780852153897285, 31.22993901371956, 23.46394043415785, 26.863732002675533, 41.61804959177971, 52.845162749290466, 62.00744390487671, 40.37417493760586, 1.2014505243860185, 0.17022605636157095, 0.0906072290672455, 0.03984734481491614, 0.05093732434033882, 0.06422200152883306, 0.046704180786036886, 0.02689052063942654, 0.005269271696306532, 0.04945473592670169, 0.006727214313286822, 0.02246493077109335, 0.02125127997715026, 0.042268835386494175, 0.04984136518032756, 0.13085972343105823, 0.16347349213901907, 0.09744275797856972, 0.08620789638371207, 0.07757962812320329, 0.23455379909137264, 0.09344270074507222, 0.11974989145528525, 0.10208038685959764, 0.13794401282211766, 0.25811148108914495, 0.19535801169695333, 0.11770328565035015, 0.4803272383287549, 47.894286811351776, 89.0033309161663, 76.38207256793976, 72.49714583158493, 47.95777380466461, 27.949806824326515, 50.91795936226845, 68.94695073366165, 55.15061303973198, 85.5891989171505, 10.382993202656507, 0.2409008686663583, 0.6749351019971073, 3.543946333229542, 6.634967420250177, 17.55676031112671, 9.056423585861921, 5.084950318560004, 90.71801170706749, 67.65255019068718, 79.14171248674393, 66.41131639480591, 74.14054244756699, 68.60452070832253, 73.0834011733532, 58.84618453681469, 67.02857047319412, 68.04040297865868, 69.58913147449493, 62.79797248542309, 58.16545486450195, 51.32937468588352, 50.473873391747475, 49.39589403569698, 53.11284698545933, 48.58913652598858, 52.46722362935543, 48.169411048293114, 48.62828202545643, 48.4275121986866, 48.914965242147446, 48.79848249256611, 48.992082104086876, 45.79403690993786, 49.48498785495758, 46.52438051998615, 48.48244585096836, 52.157791033387184, 62.1039929240942, 59.14305500686169, 61.61901734769344, 57.72562466561794, 52.07938224077225, 47.08917461335659, 47.31864430010319, 45.07179446518421, 47.74438865482807, 49.70002971589565, 53.70385207235813, 57.21456728875637, 59.54079486429691, 58.24677050113678, 61.88890926539898, 58.30525316298008, 48.03495146334171, 46.02526590228081, 48.13157267868519, 46.262692362070084, 53.851743936538696, 51.69334575533867, 56.675604209303856, 55.03701813519001, 65.02892017364502, 45.41913382709026, 45.12265853583813, 64.69552606344223, 56.92842744290829, 52.883354499936104, 47.202431336045265, 54.13595728576183, 54.96894858777523, 54.628019481897354, 49.771530479192734, 50.531292110681534, 47.34038293361664, 45.20987905561924, 46.615039855241776, 44.32789698243141, 46.33486568927765, 51.08705788850784, 52.83508948981762, 58.32427114248276, 61.01608470082283, 59.07241299748421, 59.71474193036556, 55.88081605732441, 53.12874913215637, 47.24987179040909, 44.225082099437714, 47.2677194327116, 46.323876678943634, 49.372871071100235, 47.464548870921135, 49.681372717022896, 47.55901180207729, 46.397444531321526, 48.13167527318001, 47.649773731827736, 49.82587516307831, 51.362261921167374, 60.39237096905708, 65.31724870204926, 64.26899135112762, 62.46032640337944, 65.29334038496017, 62.543260753154755, 62.63108164072037, 56.66125997900963, 57.556180357933044, 56.039822325110435, 56.71668380498886, 56.73411726951599, 57.539845034480095, 60.180615931749344, 61.69012673199177, 61.32158450782299, 65.56911438703537, 69.11847352981567, 66.26991838216782, 69.41724389791489, 36.11747235059738, 0.3004644834436476, 11.433057356625795, 2.7358990302309394, 0.5755376606248319, 0.2647745719878003, 14.637830089777708, 78.89642804861069, 58.83799597620964, 53.02410654723644, 40.15213765203953, 31.037456542253494, 33.36646556854248, 50.42221896350384, 62.72746726870537, 69.19647574424744, 48.2124437391758, 1.579960088711232, 0.20627164951292798, 0.1833797333529219, 0.2064195298589766, 0.16049198806285858, 0.11901597419637255, 0.19731110689463094, 0.17982701305299997, 0.3203696559648961, 0.1882102686795406, 0.08086193207418546, 0.09192310884827748, 0.15493966959184036, 0.15690414933487773, 0.19738138827960938], [0.05182987195439637, 0.024441954665235244, 0.07511040632380173, 0.048866762008401565, 0.02293317586008925, 0.06847176919109188, 0.03227484099625144, 0.04750251646328252, 0.0643704533285927, 0.04492161257076077, 0.008676036595716141, 0.034765084128594026, 0.07344070763792843, 0.9533492499031126, 47.59910345077515, 62.04544186592102, 60.678886994719505, 42.73730233311653, 16.68264001607895, 30.750117860734463, 51.56900882720947, 35.98771311342716, 57.55903780460358, 54.943140372633934, 0.3324204124510288, 0.03779165883315727, 0.23520577582530677, 0.22213216172531247, 5.329906074330211, 27.646598294377327, 0.5171377037186176, 26.329609863460064, 86.78220570087433, 61.11653991043568, 64.32336643338203, 52.58243344724178, 66.19609594345093, 62.304948940873146, 67.35709324479103, 66.42959341406822, 62.15430982410908, 61.570440754294395, 65.00179722905159, 60.11221960186958, 57.46672935783863, 48.88541802763939, 50.97124770283699, 45.25788187980652, 45.628601387143135, 43.530030995607376, 46.50187432765961, 43.74935142695904, 44.466087967157364, 44.00626704096794, 44.94240380823612, 43.06854195892811, 45.12787185609341, 41.28103047609329, 43.72562550008297, 43.27211983501911, 43.25706124305725, 41.480113193392754, 51.063012778759, 55.389548018574715, 55.102845802903175, 51.88817650079727, 46.673017144203186, 42.18662068247795, 40.52080526947975, 41.40843003988266, 42.34696067869663, 42.995179295539856, 48.85720074176788, 54.131739512085915, 56.593881994485855, 55.12831203639507, 57.57700704038143, 47.23393924534321, 42.28296831250191, 41.251285672187805, 44.8303934186697, 43.220457807183266, 51.20499216020107, 48.451963886618614, 54.20630671083927, 52.41150721907616, 60.68524405360222, 40.98023861646652, 40.84196403622627, 60.882898047566414, 51.4801923930645, 48.13943065702915, 42.09770925343037, 45.09717710316181, 44.93382006883621, 45.88004909455776, 44.49386827647686, 42.246950045228004, 41.91933922469616, 43.2743389159441, 43.951774165034294, 43.52856047451496, 41.70398958027363, 40.182893201708794, 45.05550093948841, 49.062819108366966, 52.244650572538376, 56.16041265428066, 53.90591382980347, 49.38799045979977, 45.21065801382065, 42.630501464009285, 42.38035708665848, 42.07412011921406, 42.70596921443939, 45.585675090551376, 42.65226289629936, 42.66376867890358, 43.68511587381363, 44.03531648218632, 43.28397139906883, 43.5222490131855, 45.45107491314411, 42.78897576034069, 53.93635019659996, 58.10607545077801, 57.34616182744503, 60.21185785531998, 58.346002176404, 55.11972829699516, 49.803285375237465, 48.27061861753464, 48.07897210121155, 48.63784231245518, 49.40483495593071, 50.84735535085201, 51.849847957491875, 52.24301666021347, 52.07387253642082, 52.82551020383835, 54.88770514726639, 61.008610501885414, 58.6804374307394, 62.932530865073204, 57.245991602540016, 6.423610411584377, 1.060727450530976, 1.7797829350456595, 0.29614663857501, 0.06589181895833462, 0.9709475305862725, 46.14679478108883, 53.7247471511364, 36.03818200528622, 43.94252926111221, 35.7580154389143, 19.11525048315525, 21.799931824207306, 44.17382284998894, 48.529920503497124, 48.24738286435604, 5.6621412467211485, 0.3166371874976903, 0.1307422562967986, 0.07226600660942495, 0.024564566738263238, 0.02772759457002394, 0.026240128390782047, 0.12277556073968299, 0.0785312098741997, 0.0721067120321095, 0.019878855964634567, 0.014086758856137749, 0.06538494693813846, 0.015426182344526751, 0.012726578424917534, 0.053527111740550026, 0.02707113711949205, 0.0671039242297411, 0.0052417955339478794, 0.014131427797110518, 0.054072690472821705, 0.0015689733595536381, 0.023914940757094882, 0.035189262343919836, 0.038766770376241766, 0.022784401226090267, 0.049621121725067496, 0.018384181676083244, 2.5657334737479687, 62.88213036954403, 67.35564172267914, 69.18410360813141, 50.476685240864754, 26.37600537389517, 24.26760111004114, 32.61033654212952, 45.31890660524368, 63.56525391340256, 59.73030969500542, 0.6952906691003591, 0.1221282224287279, 0.6132360314950347, 1.918678900692612, 5.643199738115072, 33.87676678597927, 0.26440002489835024, 29.634036049246788, 88.5970339179039, 64.55271452665329, 66.5597440302372, 55.96631146967411, 68.87267991900444, 65.49494236707687, 69.34765443205833, 67.96342670917511, 61.39862157404423, 64.86174434423447, 67.70312547683716, 62.968503534793854, 58.31154182553291, 52.327049151062965, 51.897303611040115, 48.6318614333868, 46.859321147203445, 46.95560798048973, 46.993358954787254, 45.83962686359882, 46.571228206157684, 45.61335660517216, 46.316983848810196, 44.28790032863617, 46.49245463311672, 43.299151584506035, 46.70734070241451, 45.06442666053772, 46.160143464803696, 43.01770828664303, 53.506000488996506, 58.46319928765297, 57.49364331364632, 53.6979965865612, 48.75967517495155, 44.78780150413513, 44.04373303055763, 43.17299835383892, 46.22919335961342, 45.049098283052444, 51.756695955991745, 55.64657382667065, 59.45534884929657, 58.550233617424965, 60.34401096403599, 50.588688030838966, 43.93776051700115, 43.836575746536255, 46.28822319209576, 46.62119932472706, 52.40200012922287, 50.85810877382755, 56.41175016760826, 54.22260783612728, 65.40742546319962, 42.016199827194214, 43.161006197333336, 65.79539984464645, 53.59740078449249, 51.02417126297951, 42.8283454477787, 48.33727464079857, 47.08322033286095, 48.770952969789505, 45.77770538628101, 44.15341034531593, 44.54897291958332, 45.29093250632286, 45.06026968359947, 45.45093052089214, 43.860115483403206, 43.645939975976944, 48.4573557972908, 51.52466140687466, 54.73118394613266, 58.87377865612507, 56.595090329647064, 50.31911909580231, 48.38152326643467, 44.353898987174034, 43.56348060071468, 43.6754035949707, 45.49194172024727, 47.2019449621439, 44.621587023139, 45.40718726813793, 45.92286519706249, 45.62026463449001, 46.66825219988823, 45.37739306688309, 47.77287192642689, 45.81117019057274, 57.0819316059351, 59.87371399998665, 60.636808052659035, 62.32000753283501, 59.82709050178528, 56.706705540418625, 53.749122843146324, 50.33929221332073, 50.7332094758749, 49.93001617491245, 53.29337149858475, 51.75231859087944, 55.193520337343216, 55.0796290487051, 55.70948325097561, 56.31955571472645, 58.056997284293175, 62.978314608335495, 62.476733922958374, 66.03627651929855, 62.63224057853222, 7.292117932811379, 0.23073086282238364, 4.436452416703105, 1.021351469680667, 0.05111435995786451, 0.7209604885429144, 48.677500784397125, 60.63621148467064, 40.38866735994816, 36.3286080211401, 31.3702654838562, 24.592952951788902, 28.242476619780064, 51.443471163511276, 54.07312385737896, 59.8496612906456, 9.875210300087929, 0.3680087981047109, 0.10090893643791787, 0.057657015131553635, 0.05219863771344535, 0.04584051755955443, 0.042954524178639986, 0.04243967036018148, 0.05769656789198052, 0.029508145998988766, 0.08175211594789289, 0.031199613731587306, 0.04273428443411831, 0.04755982881761156, 0.06197350186994299, 0.14435639139264822, 0.1289520476711914, 0.21305959933670238, 0.11486852643429302, 0.301528277923353, 0.16331958555383608, 0.06451500143157318, 0.1279787952080369, 0.10220989162917249, 0.21312142023816705, 0.17476685723522678, 0.1240990252699703, 0.26728095312137157, 4.574253922328353, 75.88804587721825, 74.5670847594738, 77.16343224048615, 58.32503870129585, 28.97948507219553, 40.97582325339317, 74.02632057666779, 52.9811080545187, 73.068657964468, 64.99514758586884, 1.0807953611947596, 0.14859044778859243, 1.2622892973013222, 3.03608363494277, 13.638569209724665, 44.38881531357765, 2.306021209806204, 32.55297102034092, 92.45079472661018, 66.48887783288956, 69.83470469713211, 56.90945506095886, 70.982486307621, 69.90015238523483, 72.21934273838997, 70.45051485300064, 63.55827748775482, 67.14023888111115, 70.57137876749039, 66.75084337592125, 61.15291155874729, 53.90168085694313, 56.71111710369587, 51.26884013414383, 50.923058688640594, 48.626572117209435, 50.39641074836254, 48.132967203855515, 48.367456421256065, 48.77710863947868, 50.586362555623055, 47.165026143193245, 49.4964100420475, 45.41079327464104, 48.336499482393265, 46.76237314939499, 47.100558802485466, 44.69270020723343, 57.59079650044441, 62.883600890636444, 61.562559977173805, 56.31406880915165, 51.159398406744, 46.75814777612686, 45.206831619143486, 45.10079450905323, 48.01608927547932, 47.90110744535923, 53.15934129059315, 59.10350292921066, 60.8728551864624, 58.48892390727997, 64.49665993452072, 53.532523065805435, 46.674020290374756, 46.3811282068491, 49.50724706053734, 48.613348826766014, 56.4280740916729, 52.20620043575764, 58.97592477500439, 57.54924952983856, 68.36995929479599, 43.97834233939648, 46.584447696805, 66.83863386511803, 54.794378355145454, 53.144856467843056, 46.89136482775211, 51.71936295926571, 50.06279245018959, 51.507262140512466, 48.91592279076576, 47.49078646302223, 47.73275747895241, 48.84086921811104, 48.99962469935417, 48.85808989405632, 45.97988113760948, 45.020261630415916, 51.735747680068016, 53.51587235927582, 57.65028230845928, 61.73240706324577, 59.82489801943302, 52.83766195178032, 51.25211343169212, 48.845770955085754, 47.00871393084526, 45.533313900232315, 46.586450189352036, 50.53493991494179, 46.7917949706316, 46.1863848567009, 47.68228858709335, 47.91723757982254, 48.69682654738426, 47.44877211749554, 50.62234662473202, 47.98809617757797, 59.50652450323105, 61.80672347545624, 62.37310968339443, 63.534080386161804, 63.293503895401955, 58.775717318058014, 55.53478762507439, 52.0231718569994, 53.623668774962425, 52.45645500719547, 55.823967307806015, 54.22229245305061, 58.89309301972389, 58.38375695049763, 60.36682114005089, 58.23569409549236, 60.0931978225708, 67.18455970287323, 65.77694043517113, 68.09008151292801, 63.74475248157978, 7.8050158359110355, 3.6321642994880676, 9.529634043574333, 0.9961778204888105, 0.10498849253053777, 1.748152244836092, 54.97581101953983, 67.36237496137619, 51.673526018857956, 55.4891786724329, 46.17296777665615, 30.39271093904972, 33.23943838477135, 62.39256463944912, 61.35073274374008, 68.8825061917305, 11.621070317924023, 0.6967210548464209, 0.20669577206717804, 0.23751612607156858, 0.131000004184898, 0.17857423808891326, 0.09760862056282349, 0.23340265383012593, 0.2706007577944547, 0.1518935096100904, 0.16915207961574197, 0.18130848824512213, 0.17967537743970752, 0.19398974371142685, 0.11809955540229566], [0.03285320781287737, 0.036837524094153196, 0.03707188690896146, 0.035609789192676544, 0.018261220793647226, 0.024528140274924226, 0.07391356703010388, 0.08553651248803362, 0.02412191275652731, 0.020119695873290766, 0.05694442348612938, 0.05575391471211333, 0.19790106976870447, 17.948143109679222, 74.28111210465431, 59.02692563831806, 58.568696826696396, 29.276078157126904, 24.578635320067406, 50.18749035894871, 40.65613880753517, 36.33622281253338, 74.63502511382103, 30.03130093216896, 0.04897353850537911, 0.1555715044378303, 0.41526620916556567, 3.34090375341475, 2.1605334291234612, 1.2284639873541892, 0.44374787772540003, 56.78182750940323, 74.55174118280411, 63.428700640797615, 61.55293509364128, 47.49167561531067, 52.75976613163948, 61.96716986596584, 64.78051230311394, 63.44640389084816, 69.11280423402786, 58.69675375521183, 64.49291333556175, 59.45826329290867, 60.32297529280186, 56.82695768773556, 51.60553626716137, 48.88125725090504, 45.468983352184296, 42.72826261818409, 45.209685266017914, 43.63991729915142, 44.580146446824074, 43.151195123791695, 44.54184830188751, 44.278602227568626, 46.14958003163338, 42.50100441277027, 42.654409781098366, 42.56176695227623, 44.38701421022415, 42.40289747714996, 44.230477809906006, 46.27851091325283, 48.384718894958496, 48.010625168681145, 44.58399564027786, 41.735774874687195, 43.05290959775448, 41.750601679086685, 44.0723492950201, 42.41199038922787, 47.251395508646965, 51.836343482136726, 54.49487462639809, 54.545689299702644, 52.58168488740921, 40.86322009563446, 44.23717685043812, 40.747854486107826, 47.09340758621693, 48.811249807477, 55.872502103447914, 51.22959963977337, 58.91624137759209, 52.05446317791939, 64.43479165434837, 37.34961323440075, 35.778078362345695, 60.52914083003998, 52.25091643631458, 51.989718452095985, 42.02671006321907, 42.50777184963226, 42.39926867187023, 42.70078629255295, 42.33376778662205, 40.70443421602249, 39.673906713724136, 43.50880913436413, 40.41845016181469, 44.839022755622864, 43.1357641518116, 43.97365719079971, 42.945314571261406, 44.545427709817886, 45.58464154601097, 45.93395300209522, 45.61910189688206, 45.02207413315773, 41.63940064609051, 41.524688601493835, 41.62257134914398, 42.6693581789732, 40.86503639817238, 44.390491023659706, 42.894686087965965, 43.5050131380558, 43.80794808268547, 42.956907749176025, 44.734551161527634, 43.820753395557404, 46.0888858884573, 44.674799367785454, 49.16628755629063, 58.58024820685387, 58.70403416454792, 56.96336276829243, 53.24031114578247, 48.8830241560936, 45.72301112115383, 46.397889107465744, 46.873015612363815, 45.96589408814907, 46.8369859457016, 46.79185576736927, 46.899530589580536, 49.6779453009367, 50.96317693591118, 51.0066732019186, 55.258595645427704, 57.04054422676563, 63.723078444600105, 60.19948951900005, 67.08274036645889, 28.419248834252357, 0.17583482258487493, 5.967212626710534, 2.438223953358829, 0.45489508425816894, 0.09552038769470528, 17.327207028865814, 61.44857369363308, 41.38936646282673, 52.719131112098694, 81.08596175909042, 26.16968024522066, 26.146537587046623, 51.00620202720165, 47.34448291361332, 53.56836274266243, 14.651018232107162, 0.12963681248947978, 0.06326218193862587, 0.07159315326134674, 0.06995327406912111, 0.07112453895388171, 0.02853552436135942, 0.05512472191185225, 0.09405406715814024, 0.06613666089833714, 0.03198086145857815, 0.059757615890703164, 0.031107299837458413, 0.07226206580526195, 0.01835931972891558, 0.04256655905919615, 0.013549359518947313, 0.022713819271302782, 0.04369117996247951, 0.029515777132473886, 0.06216157322342042, 0.10009779871325009, 0.020540514015010558, 0.037059259266243316, 0.06280415065702982, 0.014109271905908827, 0.12262960997759365, 0.15710525651229545, 26.204723864793777, 87.12786555290222, 65.08811339735985, 67.15733796358109, 36.75735421478748, 32.6389642059803, 41.799592450261116, 41.81533880531788, 45.51446311175823, 81.39614671468735, 30.546538084745407, 0.06209697668964509, 0.14789830602239817, 0.5553496407810599, 9.57336874678731, 8.508068360388279, 1.1200305121019483, 0.46864580421242863, 58.80998767912388, 78.45167711377144, 66.49300441145897, 63.73665131628513, 51.04240268468857, 57.432098016142845, 63.6873147636652, 67.99149200320244, 65.71633368730545, 68.33538115024567, 59.3546162545681, 67.01876699924469, 61.43946938216686, 62.49494254589081, 58.76210264861584, 55.37532918155193, 51.113238483667374, 47.88169048726559, 44.896167889237404, 47.78753153979778, 45.812572315335274, 47.653014957904816, 45.97065903246403, 49.62198570370674, 47.30241157114506, 47.20137879252434, 44.41276542842388, 44.61264610290527, 44.076415076851845, 47.15956203639507, 44.41864751279354, 46.291434019804, 49.05292063951492, 52.406670078635216, 48.89264523983002, 46.02933928370476, 43.50091315805912, 44.5958586037159, 44.48825217783451, 45.968033373355865, 44.43832665681839, 49.07008811831474, 54.30739268660545, 56.54053285717964, 56.96310058236122, 54.08587597310543, 44.46209438145161, 44.985504895448685, 41.4832404255867, 47.88209326565266, 49.89247418940067, 58.47233019769192, 54.04385022819042, 59.55727078020573, 53.948916122317314, 66.93270921707153, 38.8874439150095, 37.466266974806786, 64.3228268623352, 53.746310994029045, 53.53404298424721, 43.70253033936024, 46.09374202787876, 42.951694428920746, 45.224348679184914, 44.7809162735939, 41.33903056383133, 43.11750993132591, 44.595300033688545, 43.183747977018356, 46.954380646348, 45.992557257413864, 45.46722784638405, 46.069427132606506, 46.32327251136303, 47.883609384298325, 50.51895037293434, 47.717508897185326, 45.11472836136818, 43.62049274146557, 42.77801714837551, 42.98711612820625, 45.60372032225132, 44.66323658823967, 45.35023972392082, 44.343396350741386, 45.5450476706028, 45.94637833535671, 45.534541234374046, 46.7847653478384, 44.84975337982178, 47.82627426087856, 44.96937856078148, 50.899211168289185, 59.25923377275467, 59.03745487332344, 57.952647283673286, 53.94144952297211, 50.12154869735241, 47.98358961939812, 47.909223809838295, 49.02103655040264, 48.349114805459976, 49.50925715267658, 49.36660520732403, 50.8537770062685, 53.002421110868454, 53.27700577676296, 54.80391964316368, 57.19791278243065, 58.306689485907555, 65.82595020532608, 62.73198142647743, 68.07845413684845, 33.06191571056843, 0.1967422803863883, 2.452221689745784, 3.9404916297644377, 0.5869866837747395, 0.1929145646863617, 17.584392428398132, 68.15391048789024, 45.607900097966194, 41.88177444040775, 64.00270164012909, 31.303183883428574, 33.503398820757866, 58.9922297000885, 51.85202144086361, 63.26162740588188, 23.101466484367847, 0.16630613623419777, 0.03688317730848212, 0.053775055857840925, 0.020645418444473762, 0.05768081951828208, 0.0348113459040178, 0.025700388505356386, 0.08082492859102786, 0.007107693945727078, 0.08399220707360655, 0.03019698335265275, 0.039510376373073086, 0.05290781547955703, 0.048548848208156414, 0.14680669584777206, 0.13083760743029416, 0.1289242913480848, 0.10489722320926376, 0.10945849993731827, 0.16991297394270077, 0.17469296901253983, 0.1464088007924147, 0.14784650411456823, 0.18196120712673292, 0.11272924864897504, 0.26719548739492893, 0.37577697657980025, 32.664521634578705, 93.9904037117958, 74.16605427861214, 76.74352437257767, 42.905405312776566, 33.348473533988, 62.667035311460495, 59.15572352707386, 53.5122549533844, 87.80224576592445, 36.98944956064224, 0.11050437155063264, 0.547629464417696, 1.081526584457606, 7.428344897925854, 15.170231871306896, 1.5855598007328808, 0.749177715042606, 63.02569806575775, 79.96007457375526, 69.44535478949547, 65.34170418977737, 53.177390322089195, 57.96866722404957, 66.51818186044693, 69.72465500235558, 68.64887192845345, 70.9861721098423, 58.84858600795269, 69.8643659055233, 64.80888918042183, 64.58669990301132, 62.74179250001907, 56.93874008953571, 54.62191320955753, 49.38428945839405, 47.59559243917465, 49.44820582866669, 48.47021050751209, 49.78810139000416, 49.781900122761726, 52.42048993706703, 50.221616327762604, 50.55106244981289, 48.141919523477554, 47.585545778274536, 46.59340761601925, 50.24089649319649, 47.6174982637167, 48.66343013942242, 52.00578399002552, 53.95144298672676, 51.7775834351778, 49.06908497214317, 45.62784522771835, 47.4717190861702, 47.40700475871563, 49.11659762263298, 47.10632309317589, 50.881572514772415, 56.80064029991627, 59.914649203419685, 60.50887651741505, 57.949911430478096, 46.26157522201538, 48.35072971880436, 44.536577984690666, 51.07349641621113, 52.32145205140114, 59.371985122561455, 54.627343118190765, 62.59430721402168, 57.74423606693745, 69.56684947013855, 42.35120125114918, 39.497797563672066, 64.83779042959213, 58.220388516783714, 57.749430388212204, 46.86218999326229, 48.84640172123909, 46.93255081772804, 47.90756329894066, 47.02382951974869, 45.14980047941208, 45.50481542944908, 48.03809769451618, 44.63667221367359, 49.72243331372738, 48.863060027360916, 50.04617974162102, 48.63167904317379, 48.87186035513878, 50.569195076823235, 53.71434710919857, 51.32823474705219, 47.92872816324234, 46.43280543386936, 45.882032588124275, 46.55865468084812, 47.7130251377821, 46.38537637889385, 49.13482524454594, 47.24179722368717, 48.14392201602459, 47.65092507004738, 50.04386946558952, 49.63770925998688, 48.111160174012184, 49.86278638243675, 47.72006995975971, 54.05034027993679, 62.72059343755245, 62.181387171149254, 61.215703189373016, 57.61296831071377, 53.60473059117794, 52.035080417990685, 50.68009592592716, 52.56738245487213, 51.468124240636826, 53.526382595300674, 51.665816232562065, 52.07557484507561, 55.86746737360954, 55.72829224169254, 56.11770674586296, 60.470536574721336, 60.76476238667965, 69.43842396140099, 64.60848793387413, 70.4720064997673, 34.053385108709335, 0.41519769409205765, 13.64324675872922, 5.713879270479083, 0.705120979109779, 0.2729079168057069, 22.324244789779186, 72.92672798037529, 57.245288640260696, 68.16439032554626, 88.49348947405815, 39.14535507559776, 36.139461770653725, 67.19820857048035, 60.087353736162186, 71.6924250125885, 29.286987371742725, 0.6071327871177346, 0.2164442974026315, 0.11516924467287026, 0.12956378515809774, 0.23048349015880376, 0.04504103526414838, 0.051719978437176906, 0.1940748086781241, 0.15478890971280634, 0.14730078808497638, 0.18503503437386826, 0.11997777532087639, 0.15397584240417928, 0.13335774798179045], [0.03961613241699524, 0.023797601643309463, 0.014867682821204653, 0.07700939153437503, 0.024313980575243477, 0.02648503526870627, 0.0248108373125433, 0.10169431421672925, 0.048293363870470785, 0.09179845030303113, 0.09605731669580564, 0.08622358538559638, 0.06363951208186336, 38.89476612210274, 75.81005126237869, 50.41484735906124, 54.35932829976082, 20.261930152773857, 22.35566720366478, 62.580639347434044, 35.32131627202034, 49.50680248439312, 72.9063306748867, 8.017834816128016, 0.10341914705350064, 0.07275905241840519, 0.5545589269604534, 2.4853794230148196, 1.683091304730624, 0.9665201744064689, 4.951603598892689, 79.71787557005882, 64.70254048705101, 70.23847103118896, 62.54499725997448, 61.525686755776405, 46.32593996822834, 52.39273622632027, 59.82598856091499, 66.04041069746017, 64.42295908927917, 63.79555955529213, 59.63825583457947, 62.08849735558033, 58.69423449039459, 60.51583394408226, 54.152140617370605, 55.84482058882713, 51.3576527684927, 49.04798470437527, 41.93014204502106, 43.48193317651749, 43.61438646912575, 44.99644070863724, 44.45791840553284, 44.047852009534836, 43.527800515294075, 45.04577346146107, 42.20267862081528, 43.577406853437424, 44.48188751935959, 42.52213127911091, 42.117817774415016, 42.916690707206726, 41.65604755282402, 42.00783647596836, 41.46736487746239, 42.08561070263386, 40.85735701024532, 40.03049477934837, 41.44129067659378, 41.23941890895367, 45.66528081893921, 49.67234060168266, 49.627544805407524, 48.729003220796585, 42.32367932796478, 39.79927338659763, 43.15082274377346, 43.00886616110802, 48.04095134139061, 49.72317427396774, 55.12939877808094, 53.3967449516058, 57.64162637293339, 52.44820944964886, 62.63382509350777, 29.617826119065285, 36.045048236846924, 62.16214120388031, 50.42603395879269, 52.21258029341698, 39.26958940923214, 42.82803386449814, 40.60269847512245, 42.67526686191559, 40.630322992801666, 41.254656091332436, 39.353682696819305, 42.91530758142471, 43.539633080363274, 43.53315822780132, 42.71195009350777, 45.2900205552578, 43.634878769516945, 44.873152524232864, 42.05924391746521, 43.78893010318279, 41.923735588788986, 43.16421702504158, 39.28303688764572, 41.46873280405998, 40.8798898011446, 41.54976345598698, 43.03958751261234, 41.57028615474701, 41.63726896047592, 43.11023332178593, 41.48562669754028, 45.49228750169277, 41.57213665544987, 44.34404991567135, 43.2747682929039, 44.06725376844406, 43.12271185219288, 46.86311714351177, 49.53982651233673, 48.146559074521065, 45.27121156454086, 45.18272951245308, 43.04041966795921, 45.61603166162968, 43.41809660196304, 47.75368295609951, 47.184097319841385, 52.62689106166363, 53.232871145009995, 53.80749151110649, 56.87708839774132, 58.47049109637737, 60.55997997522354, 61.50139845907688, 61.13626845180988, 65.23192048072815, 61.60837411880493, 50.534784123301506, 12.87625601515174, 2.6113685499876738, 2.444172534160316, 0.11690562532749027, 0.05721218294638675, 2.2653386928141117, 52.283967062830925, 54.20079320669174, 39.35314692556858, 87.21894666552544, 38.97124461829662, 16.872073151171207, 40.801405012607574, 45.02618931233883, 53.65651421248913, 30.26614923030138, 0.5100732890423387, 0.039118867498473264, 0.10291208207490854, 0.048325999814551324, 0.060612206361838616, 0.005528849906113464, 0.0867036436102353, 0.08984433094155975, 0.04517589833994862, 0.023866194642323535, 0.0212705479862052, 0.02779662172542885, 0.05519938196812291, 0.007153587894208613, 0.04230830279993825, 0.020299614734540228, 0.039992679594433866, 0.027246799763815943, 0.01344543750747107, 0.052417300394154154, 0.0215801293234108, 0.08912658508052118, 0.007034266318441951, 0.0933344139775727, 0.028412348256097175, 0.009749336131790187, 0.16388327640015632, 49.71812814474106, 83.72532293200493, 59.75063860416412, 59.46677103638649, 31.0958157107234, 24.847980067133904, 51.21704511344433, 39.85731527209282, 56.266514360904694, 77.06504791975021, 8.830053582787514, 0.49251107673626393, 0.07412710518110543, 1.91198805347085, 2.890734546817839, 0.695347428554669, 0.9985576802864671, 6.38927735388279, 81.4634183049202, 68.0489069223404, 71.48734241724014, 63.57465460896492, 63.56358200311661, 49.113667979836464, 56.03397063910961, 62.677017375826836, 67.38779559731483, 66.84209167957306, 64.89769041538239, 62.693850472569466, 65.65330266952515, 60.521051064133644, 63.38312208652496, 54.88264001905918, 58.528384789824486, 53.90754394233227, 49.36408594250679, 45.81522457301617, 46.25767283141613, 45.34572176635265, 47.245718613266945, 44.39334087073803, 47.43704594671726, 46.747029572725296, 46.81235186755657, 44.50152866542339, 45.31031906604767, 47.16382920742035, 44.26012381911278, 44.237895011901855, 43.39202620089054, 44.57958407700062, 43.722825050354004, 44.019133150577545, 44.25952725112438, 43.85541133582592, 42.260868698358536, 44.34711255133152, 45.63703693449497, 49.03324909508228, 51.69832728803158, 51.95753797888756, 51.56811587512493, 45.10877028107643, 42.19545900821686, 45.315342396497726, 44.757817313075066, 50.62711536884308, 50.98490796983242, 57.89578713476658, 55.91051146388054, 61.28967382013798, 54.24232877790928, 64.71555858850479, 31.87097791582346, 38.74848157167435, 64.93601515889168, 52.51326955854893, 52.88436524569988, 41.95536129176617, 45.782173946499825, 42.334546744823456, 44.23192173242569, 41.65018826723099, 44.82513830065727, 42.510165721178055, 44.63780835270882, 45.6834514439106, 46.39815129339695, 45.6942542642355, 46.222919896245, 46.42281197011471, 45.95028452575207, 43.991607427597046, 46.08813352882862, 43.53619426488876, 43.97108852863312, 42.055862098932266, 44.466243758797646, 43.509800881147385, 43.45924839377403, 44.1781660169363, 45.7783779501915, 45.40380544960499, 45.027644634246826, 42.89371334016323, 45.88572978973389, 44.459263533353806, 45.889810770750046, 44.9079966545105, 47.65109986066818, 44.96184356510639, 48.94525721669197, 50.14022849500179, 50.55695213377476, 47.83755965530872, 46.72584570944309, 44.291745722293854, 47.49978817999363, 47.02369652688503, 50.11170722544193, 51.427417024970055, 56.49667181074619, 54.407638907432556, 56.306655406951904, 59.62013840675354, 60.85531912744045, 62.984899654984474, 64.27234277129173, 64.0100048482418, 67.30727031826973, 62.212507501244545, 54.363082498312, 15.267740339040756, 2.289145840331912, 3.1068467628210783, 0.30186797375790775, 0.016628095145279076, 2.175127496011555, 55.58031678199768, 61.345777809619904, 40.03281645476818, 74.76816236972809, 36.92197658121586, 24.838332384824753, 47.24012151360512, 50.19023001194, 58.818601816892624, 45.72256274521351, 2.5497850170359015, 0.14666138333268464, 0.07535466938861646, 0.018715934675128665, 0.034988262777915224, 0.02317897702596383, 0.05187956245208625, 0.03271445217251312, 0.1070141326636076, 0.1198705869319383, 0.013528059880627552, 0.03912561362085398, 0.061034833488520235, 0.02742792832577834, 0.08960610895883292, 0.15877229830948636, 0.11387366263079457, 0.21293318190146238, 0.1520264579448849, 0.10324510600185022, 0.14882780145853758, 0.19739467272302136, 0.21735185495344922, 0.17950282810488716, 0.21542099450016394, 0.20001052063889802, 0.4601815209025517, 56.85387544333935, 93.82029443979263, 66.55079931020737, 70.1833663880825, 31.56553890556097, 32.99897588789463, 75.28167441487312, 52.22799986600876, 64.96477201581001, 85.55424839258194, 9.762888327240944, 0.4592576954746619, 0.1111233004485257, 2.4550708243623376, 4.455606238916516, 4.995339252054691, 4.241870082914829, 7.824352998286486, 85.65996631979942, 69.45227801799774, 76.34690165519714, 67.27559521794319, 69.31794762611389, 51.51049956679344, 58.441422656178474, 65.54677918553352, 69.34818640351295, 68.47782790660858, 66.1533710360527, 62.45230883359909, 70.22265627980232, 63.04055906832218, 66.28754943609238, 57.94642701745033, 61.37049928307533, 58.02505619823933, 52.5251667201519, 46.431118324398994, 50.14120124280453, 47.887272387742996, 49.76568639278412, 48.383825942873955, 49.428583681583405, 49.54206459224224, 49.85957555472851, 45.9661790728569, 48.426615446805954, 49.98893961310387, 46.313750222325325, 46.67387589812279, 46.68278641998768, 46.44526116549969, 46.39215521514416, 45.693334713578224, 47.023517936468124, 45.70911906659603, 45.135099068284035, 46.66525416076183, 46.6834931820631, 51.35136030614376, 56.050644144415855, 55.30087597668171, 54.45349484682083, 46.91026881337166, 44.31563504040241, 47.81023532152176, 48.534047082066536, 51.89604967832565, 54.93951536715031, 60.14054708182812, 58.14040660858154, 61.6615104675293, 57.33123242855072, 67.10582032799721, 35.74664644896984, 40.81075631082058, 66.16774186491966, 54.992431327700615, 56.429024040699005, 44.669456854462624, 48.243982046842575, 45.585321709513664, 46.82610332965851, 45.04965305328369, 47.1604397892952, 43.876055628061295, 48.19609321653843, 48.13756875693798, 49.587532952427864, 48.018144965171814, 50.837624073028564, 48.26301522552967, 48.79969462752342, 46.634984984993935, 47.96809785068035, 45.21337106823921, 48.673795983195305, 43.362934961915016, 47.69816413521767, 46.1076644808054, 45.33048078417778, 47.60948069393635, 46.900275349617004, 46.74712456762791, 48.1393014639616, 44.25202265381813, 48.30908015370369, 45.28838664293289, 47.69802734255791, 46.58515825867653, 49.64893385767937, 47.55268134176731, 50.372901409864426, 54.75206382572651, 53.15155170857906, 48.716672882437706, 50.39298713207245, 45.681331157684326, 50.27309216558933, 48.993229642510414, 52.157585844397545, 53.23156401515007, 59.10126104950905, 57.8068833053112, 59.63843062520027, 61.746884286403656, 64.37407091259956, 66.71354457736015, 67.80429124832153, 65.12645334005356, 71.18007570505142, 63.85492756962776, 55.124018266797066, 18.254030495882034, 4.798431443050504, 6.439529657363892, 0.30446557968389243, 0.13093959336401895, 3.6427586060017347, 61.953494399785995, 68.21808904409409, 52.853187918663025, 91.77330628037453, 48.601284474134445, 25.491851717233658, 53.974864929914474, 58.36254268884659, 65.49461558461189, 54.23752583563328, 3.371378118172288, 0.3431404387811199, 0.1904165995074436, 0.09905425002216361, 0.18312458298169076, 0.10254016218823381, 0.20058624912053347, 0.16049743542680517, 0.23966906679561362, 0.21507758792722598, 0.11320340679958463, 0.1426997545058839, 0.18162835389375687, 0.1343139904201962], [0.030404884892050177, 0.0024371904737563455, 0.04259112785803154, 0.06284164395765401, 0.0377336228848435, 0.0867396080866456, 0.04861167100898456, 0.020900863819406368, 0.013216712231951533, 0.05928372120251879, 0.030487523035844788, 0.06931226627784781, 2.6203270442783833, 60.6781080365181, 67.00675964355469, 59.797049313783646, 42.45491288602352, 18.955379761755466, 38.797460943460464, 67.58638814091682, 37.06031575798988, 62.360437363386154, 55.51866888999939, 1.0576581652276218, 0.058252814997104, 0.012082443408871768, 0.316833084798418, 7.186359157785773, 2.612918629311025, 0.5472843954339623, 34.98493932187557, 76.08341619372368, 66.41584575176239, 70.3486043214798, 64.92203950881958, 63.73322010040283, 55.320672914385796, 46.631614565849304, 51.124558076262474, 59.45358194410801, 61.693690940737724, 64.12932604551315, 60.46335496008396, 59.58813652396202, 61.556514501571655, 58.99333544075489, 57.721064910292625, 58.05858179926872, 53.64356450736523, 50.88253006339073, 46.469465866684914, 41.30113139748573, 42.829918563365936, 44.28468570113182, 45.86744897067547, 43.910793364048004, 42.614200338721275, 43.947556391358376, 43.15498732030392, 41.61347083747387, 43.734315633773804, 41.269688084721565, 43.36511604487896, 42.64373995363712, 43.27367015182972, 41.11032083630562, 43.44235070049763, 40.82539692521095, 41.06063470244408, 40.799638107419014, 43.05230922996998, 41.29198908805847, 42.56932474672794, 44.612706899642944, 45.04269182682037, 41.50947041809559, 41.55687667429447, 40.117217525839806, 43.24400134384632, 46.70268215239048, 51.06671757996082, 49.48353633284569, 56.29823125898838, 54.45171274244785, 56.16312950849533, 49.44312550127506, 51.89835995435715, 27.344117425382137, 41.630942299962044, 61.3119900226593, 49.86748293042183, 48.48365418612957, 40.5886772274971, 43.50035838782787, 40.14416567981243, 43.70419085025787, 40.07975913584232, 38.89611504971981, 40.773940086364746, 42.03686311841011, 40.35527095198631, 43.213184997439384, 42.64280900359154, 45.415755808353424, 44.713200107216835, 44.12649258971214, 42.675050273537636, 41.37992776930332, 41.87740847468376, 41.53686314821243, 38.85913923382759, 40.943589583039284, 40.952671095728874, 42.8244848549366, 40.28993345797062, 42.764334082603455, 41.31117045879364, 42.32861906290054, 42.83635161817074, 43.251095563173294, 42.93023318052292, 43.611107245087624, 43.64911660552025, 45.840914994478226, 43.91675904393196, 46.334329918026924, 45.26942566037178, 45.22626757621765, 43.30026492476463, 44.916405603289604, 43.89313191175461, 45.402988493442535, 49.20848809182644, 53.882613480091095, 56.163828670978546, 58.21645572781563, 55.94592556357384, 58.47793489694595, 61.247765868902206, 60.32117798924446, 60.00475376844406, 61.85592703521252, 62.23491869866848, 61.97914682328701, 59.703578129410744, 58.142165914177895, 21.12807657569647, 1.7603517277166247, 2.30789165943861, 0.4049441817915067, 0.08590684417868033, 0.055646922992309555, 27.511561140418053, 65.1129412651062, 40.00898793339729, 56.916290894150734, 33.76717306673527, 14.021856542676687, 25.932439975440502, 41.299657076597214, 49.56777021288872, 52.81964331865311, 11.04830140247941, 0.5051329603884369, 0.13466674805385992, 0.07433912192936987, 0.10314237049897201, 0.01265377837626147, 0.04502201030845754, 0.027622589950624388, 0.023687956745561678, 0.08392410018132068, 0.04235607855662238, 0.10099268038175069, 0.06154622518806718, 0.03143774294585455, 0.05696474348951597, 0.039937434121384285, 0.07952275627758354, 0.0813527662830893, 0.06988775727222674, 0.02553347763750935, 0.05657419198541902, 0.014728777823620476, 0.05570798690314405, 0.010170292498514755, 0.03933038700779434, 0.08534705702913925, 4.350961754098535, 73.26684013009071, 72.6046496629715, 63.96854907274246, 47.81659238040447, 25.724243447184563, 31.466225534677505, 59.28359426558018, 45.12996934354305, 68.7563605606556, 60.59898868203163, 0.8186768169980496, 0.026773734425660223, 0.17636945092817768, 1.9553621322847903, 5.19856327213347, 1.7852807650342584, 0.5321812746115029, 36.92595116794109, 80.02967163920403, 69.19697731733322, 72.18446061015129, 66.11440032720566, 68.09502124786377, 58.09872284531593, 50.144894644618034, 54.26825858652592, 63.00636850297451, 63.773741126060486, 66.2998379766941, 62.42934666574001, 61.4178067445755, 61.97620578110218, 63.251698538661, 60.216683596372604, 60.79971671104431, 55.83978585898876, 51.995068565011024, 47.942050248384476, 44.02457445859909, 44.00028236210346, 46.39763072133064, 45.85422948002815, 46.28628149628639, 46.13374248147011, 47.32394881546497, 45.24455979466438, 43.845562264323235, 45.81090420484543, 44.3109916895628, 44.18076507747173, 45.07098510861397, 45.56689269840717, 42.57248617708683, 46.39742933213711, 43.55085767805576, 44.292612075805664, 43.66391681134701, 44.49032686650753, 44.03237923979759, 45.33597908914089, 46.97794318199158, 47.134859561920166, 43.1654367595911, 44.52981434762478, 42.67279699444771, 43.10177117586136, 48.495809733867645, 52.663950473070145, 51.410447135567665, 57.83130079507828, 55.54524466395378, 58.29740658402443, 50.75347758829594, 53.21224965155125, 29.541292525827885, 42.64931045472622, 62.62360744178295, 51.45046278834343, 52.50886179506779, 42.092674523591995, 47.32245169579983, 42.87954390048981, 45.541099682450294, 41.721335649490356, 44.003105610609055, 42.50030145049095, 42.59886056184769, 42.63470023870468, 46.747063770890236, 46.455000042915344, 47.78962142765522, 47.13521674275398, 47.17259533703327, 44.33890879154205, 43.71111787855625, 43.4161739051342, 44.26062539219856, 41.633438766002655, 43.19319427013397, 43.12090314924717, 44.435852989554405, 42.19133622944355, 45.94218336045742, 44.38224546611309, 45.42443074285984, 43.98168995976448, 46.31112836301327, 44.467022716999054, 44.86081078648567, 45.623464062809944, 47.4234464764595, 45.11831536889076, 47.09023095667362, 47.714670449495316, 47.57529392838478, 45.251456424593925, 46.99170224368572, 45.93191251158714, 46.8000253289938, 51.42736382782459, 57.38211169838905, 57.692004069685936, 60.42876161634922, 58.21982614696026, 62.18503877520561, 63.137590661644936, 63.16396504640579, 62.937968373298645, 64.35930490493774, 64.6906167268753, 64.50004175305367, 59.188416972756386, 60.115137845277786, 24.448617696762085, 1.2477379781194031, 1.3528544688597322, 1.61520735360682, 0.1148816327622626, 0.10760560209746473, 27.013557963073254, 71.8465143442154, 42.64747895300388, 58.271085396409035, 32.65929311513901, 21.507664807140827, 30.58783996850252, 47.98162132501602, 55.2773704379797, 65.73750615119934, 16.194210425019264, 0.6063034222461283, 0.12306538425036706, 0.08450865279883146, 0.03275490293162875, 0.0837114080786705, 0.0581263307685731, 0.021876240680285264, 0.02754882603767328, 0.05701843787392136, 0.04377792218292598, 0.06872571728308685, 0.03225483640562743, 0.03132341138552874, 0.22447234630817547, 0.13212112215114757, 0.19806840922683477, 0.13461372902384028, 0.11430548867792822, 0.1593545131618157, 0.11865393229527399, 0.10049293297925033, 0.07470693031791598, 0.1756317709805444, 0.132466992654372, 0.32932948612142354, 5.926371468231082, 88.15767109394073, 79.5193362236023, 74.27291974425316, 57.59017713367939, 28.374956510961056, 52.951655834913254, 82.27256968617439, 53.20252597332001, 77.18893647193909, 65.58959528803825, 1.586664947681129, 0.2652917301747948, 0.46402465843129903, 2.619560672901571, 16.17217730730772, 13.825481180101633, 1.1199914454482496, 42.600935250520706, 80.54306969046593, 72.48123988509178, 74.75371554493904, 69.37511175870895, 69.2627289891243, 60.25730341672897, 51.244456842541695, 56.470768600702286, 65.89940786361694, 66.38097882270813, 69.39509108662605, 63.07397447526455, 63.00882317125797, 65.22092387080193, 65.10841950774193, 63.50977309048176, 62.488946467638016, 59.27337281405926, 55.508341044187546, 51.763907968997955, 46.356858909130096, 45.485710054636, 49.701876416802406, 47.53634221851826, 48.56716990470886, 46.5377976000309, 48.340477868914604, 48.49799081683159, 46.37328162789345, 47.404580488801, 44.806618094444275, 48.56759548187256, 48.35310459136963, 49.78690065443516, 44.82204906642437, 49.01040852069855, 45.013254806399345, 47.04082600772381, 47.09031455218792, 47.567580342292786, 46.14772953093052, 48.55449378490448, 50.08610799908638, 49.89231459796429, 45.29144547879696, 47.22418136894703, 45.567873045802116, 46.948794946074486, 50.70012845098972, 54.93739128112793, 54.93613734841347, 61.19495250284672, 57.540677189826965, 59.684138372540474, 51.51265025138855, 53.79720166325569, 31.202608980238438, 46.50494456291199, 65.89633762836456, 54.085803776979446, 54.128171503543854, 44.377575516700745, 49.262053817510605, 46.6429303586483, 48.95576365292072, 43.89740288257599, 44.88618582487106, 45.810706615448, 47.094262540340424, 44.2203513532877, 49.493970572948456, 48.24988313019276, 50.91219127178192, 48.632275611162186, 49.88192215561867, 47.111088037490845, 45.42286902666092, 46.85837119817734, 46.82897977530956, 44.20409582555294, 45.48694118857384, 44.27307352423668, 47.929632514715195, 43.24128828942776, 48.387899324297905, 45.31876601278782, 46.47747963666916, 46.8871508538723, 48.61681804060936, 46.86728172004223, 47.3304882645607, 48.28815467655659, 50.490835681557655, 48.3619125187397, 50.072744116187096, 51.23789839446545, 51.21282733976841, 48.2849096506834, 50.23509040474892, 48.67476873099804, 50.55183760821819, 53.23105104267597, 60.75081333518028, 60.27871146798134, 64.22991424798965, 62.17521630227566, 64.122843593359, 65.45333459973335, 66.63903057575226, 64.75348055362701, 67.40787371993065, 67.02416270971298, 67.1949103474617, 60.410518795251846, 61.05772286653519, 26.71041212975979, 3.4830301394686103, 8.618286196142435, 2.649514703080058, 0.2471972198691219, 0.2895258797798306, 33.027535155415535, 79.63301092386246, 52.50875920057297, 68.48474353551865, 40.73529236018658, 23.45966376364231, 36.7036858946085, 58.065049052238464, 61.99533015489578, 74.37385752797127, 19.277566373348236, 0.8451641863211989, 0.39529890404082835, 0.20080873015103862, 0.1809876726474613, 0.1559847322641872, 0.21980630059260875, 0.0983519630972296, 0.10508816296351142, 0.2236036179237999, 0.11527985436259769, 0.1673497591400519, 0.19928106368752196, 0.10589766054181382], [0.06171892295242287, 0.05666745397320483, 0.03457014048763085, 0.043852144372067414, 0.00425557914240926, 0.013198298620409332, 0.04592047283949796, 0.027711098482541274, 0.031103273686312605, 0.031226037899614312, 0.13207108655478805, 0.197764752083458, 10.30191695317626, 69.57267835736275, 58.366228491067886, 57.10166774690151, 40.427467077970505, 23.08407101780176, 41.28701135516167, 58.56303133070469, 35.975462570786476, 71.96996212005615, 26.100873537361622, 0.07900371303549036, 0.04675786032748874, 0.17978089599637315, 0.9810136060696095, 1.8936849106103182, 0.17730681312968954, 19.04760081321001, 77.80047565698624, 66.4501503109932, 72.63644635677338, 68.31833526492119, 68.32099512219429, 65.14522433280945, 62.12985433638096, 48.98782633244991, 45.40249451994896, 53.141793832182884, 59.67691496014595, 60.117622911930084, 63.48747968673706, 59.1980304569006, 57.80702009797096, 59.77606683969498, 58.212002366781235, 54.949417635798454, 56.23611219227314, 50.76412081718445, 48.39473515748978, 44.08322051167488, 42.549584805965424, 42.65266567468643, 43.430206552147865, 47.14116722345352, 42.314084842801094, 42.982685565948486, 43.66566091775894, 41.86327323317528, 43.303901329636574, 43.82162354886532, 43.680043146014214, 42.83398054540157, 43.35808642208576, 43.15870352089405, 43.43422673642635, 41.560558676719666, 42.483042776584625, 40.42373187839985, 41.21232256293297, 41.032079234719276, 41.92175969481468, 41.201162561774254, 40.855172127485275, 39.615268260240555, 41.12206220626831, 40.199958086013794, 45.94192877411842, 49.866749569773674, 52.402167320251465, 52.03121982514858, 56.77278019487858, 53.654428124427795, 55.59882938861847, 50.660033002495766, 55.04705339670181, 28.764861188828945, 45.983734130859375, 59.803907945752144, 50.58210678398609, 47.21720114350319, 41.949118226766586, 44.673925414681435, 44.07066598534584, 44.77209314703941, 42.49551750719547, 40.991311222314835, 40.46082928776741, 40.043334290385246, 39.83867347240448, 43.54519598186016, 42.01313719153404, 44.855316281318665, 42.98371531069279, 43.548536002635956, 43.204225078225136, 43.06674845516682, 42.223224118351936, 43.689227253198624, 41.66194103658199, 39.40155252814293, 42.56507657468319, 42.96554088592529, 41.22764714062214, 43.685644045472145, 42.53500118851662, 45.230823531746864, 43.2701363414526, 42.48081609606743, 43.02913807332516, 41.40208438038826, 45.073770359158516, 42.482081428170204, 44.99367445707321, 44.77350287139416, 44.85372416675091, 43.89983855187893, 43.76530297100544, 43.751741498708725, 48.01208809018135, 52.4486768245697, 54.585769549012184, 56.39876626431942, 60.544617399573326, 64.94660139083862, 64.52321290969849, 59.091567769646645, 59.941737949848175, 64.08410087227821, 61.568373665213585, 60.89462801814079, 61.5065623819828, 61.13509811460972, 58.35577145218849, 57.13369242846966, 48.918582648038864, 3.1175619503483176, 1.6976945148780942, 1.3584423065185547, 0.18650187441380695, 0.07772086624754593, 7.993876151740551, 61.52555376291275, 50.0456515699625, 41.781095042824745, 31.01235318928957, 20.278578959405422, 25.90629357844591, 44.17384944856167, 46.386295929551125, 55.57224601507187, 16.261639706790447, 0.6614338327199221, 0.13166620046831667, 0.09444681170862168, 0.046226775739341974, 0.03776173172809649, 0.05906412341573741, 0.006785777186451014, 0.025265063231927343, 0.03157692161039449, 0.03240275756979827, 0.057890097741619684, 0.13309201458469033, 0.009410970596945845, 0.04942280131217558, 0.043998896653647535, 0.037996150203980505, 0.029645062968484126, 0.026130086444027256, 0.06795118970330805, 0.03329776169266552, 0.0233568141629803, 0.05513283729669638, 0.037087739183334634, 0.200977464846801, 0.1124570363026578, 15.015934500843287, 82.64707759022713, 64.0594781935215, 64.29533913731575, 44.87640134990215, 30.119062922894955, 45.60213960707188, 57.82910071313381, 40.377397164702415, 79.80082511901855, 28.149393014609814, 0.11786484377807938, 0.04068284353706986, 0.9726212220266461, 2.84226814750582, 0.3854865540051833, 0.42160278477240354, 21.677675284445286, 81.09953463077545, 69.32489365339279, 73.78666743636131, 70.25954470038414, 72.02927693724632, 67.98249408602715, 64.93038386106491, 50.59829391539097, 48.909854516386986, 55.62926195561886, 62.89259120821953, 64.59291636943817, 65.26390716433525, 61.818195059895515, 60.14705613255501, 60.98349004983902, 60.24147726595402, 57.26922735571861, 58.413003981113434, 53.073458299040794, 49.10954140126705, 48.202906250953674, 44.43739950656891, 44.56031531095505, 45.60062728822231, 48.52751903235912, 45.706797391176224, 45.17052836716175, 45.10828010737896, 45.19650377333164, 44.82991844415665, 44.22953546047211, 45.69976016879082, 43.99052448570728, 46.71910107135773, 45.05825959146023, 46.12572491168976, 43.37923228740692, 44.02488984167576, 42.04606242477894, 44.02213118970394, 43.060041815042496, 43.52634519338608, 43.702750727534294, 43.84414494037628, 41.60444252192974, 43.18759337067604, 41.98232464492321, 49.4606539607048, 52.19779908657074, 54.85695719718933, 52.14383438229561, 57.51393422484398, 55.46700306236744, 57.74084284901619, 53.74800190329552, 56.30722917616367, 31.00554395467043, 46.441632360219955, 61.25911965966225, 53.960528299212456, 50.405378267169, 44.00611124932766, 46.77366994321346, 46.55255600810051, 45.64144089818001, 44.47980523109436, 43.89134220778942, 43.12892831861973, 43.6710262298584, 43.03121656179428, 44.660420939326286, 44.519710689783096, 46.58130146563053, 46.36890046298504, 45.73437251150608, 45.33845655620098, 45.60615599155426, 43.85639548301697, 45.564183443784714, 42.94435702264309, 40.88259905576706, 43.369561806321144, 44.8414546251297, 43.10264892876148, 43.94529551267624, 44.046461284160614, 45.84020063281059, 46.242568641901016, 45.24449519813061, 45.15406385064125, 44.748272225260735, 47.25549168884754, 45.39200708270073, 46.4205776900053, 45.74908532202244, 46.11496388912201, 47.19196669757366, 46.9647540897131, 46.77043251693249, 49.0134559571743, 55.64749717712402, 57.46174782514572, 59.972694888710976, 63.75969707965851, 64.19452294707298, 65.52293926477432, 62.30290085077286, 62.526359260082245, 66.22484520077705, 64.33777526021004, 63.360767886042595, 63.14678616821766, 61.525420770049095, 61.17689207196236, 58.094170689582825, 51.74261011183262, 4.515463477000594, 0.642427965067327, 2.126528578810394, 0.4101464885752648, 0.09634255373384804, 6.919128522276878, 68.8785620033741, 54.44276802241802, 48.70147369801998, 32.37072139978409, 24.773108884692192, 35.15805043280125, 50.04991494119167, 51.831472143530846, 60.96434287726879, 23.77837736159563, 0.5637353158090264, 0.19965743646025658, 0.04701501449744683, 0.03960028385336045, 0.06920769024873152, 0.04761323747516144, 0.08103111948003061, 0.06900893567944877, 0.05650828927173279, 0.053346732747741044, 0.03281345096183941, 0.05585295431956183, 0.030469754165096674, 0.14254702051403, 0.1582414994481951, 0.19702088262420148, 0.16061257221736014, 0.18291943852091208, 0.2798558439826593, 0.18361624097451568, 0.27286353637464345, 0.10110842573340051, 0.29036278487183154, 0.3585573990130797, 0.47561750980094075, 18.266330435872078, 92.77076795697212, 71.38223245739937, 74.26602691411972, 53.507801592350006, 35.04607044160366, 55.47972857952118, 72.29589343070984, 49.26141545176506, 85.86375698447227, 32.818698361516, 0.1955875728162937, 0.15845831047045067, 2.0452499901875854, 4.9739687237888575, 12.69757630303502, 2.2039553616195917, 25.89416842907667, 82.86147728562355, 69.83862608671188, 80.33225700259209, 72.60959699749947, 73.34799617528915, 70.37432134151459, 68.01594749093056, 54.04120177030563, 51.21611416339874, 58.84630613029003, 64.75807830691338, 66.10309973359108, 67.54583671689034, 62.13336534798145, 60.23277573287487, 62.363275811076164, 62.28262513875961, 59.06567595899105, 61.94734252989292, 56.86747871339321, 52.46133774518967, 50.58767348527908, 47.24329814314842, 47.774619832634926, 48.330222219228745, 51.91424310207367, 46.327019110322, 48.056313917040825, 48.05846080183983, 48.260841742157936, 47.39475801587105, 46.301298290491104, 49.73410628736019, 48.7056040763855, 49.97768461704254, 46.84288702905178, 48.1685446947813, 45.332456678152084, 46.95659592747688, 44.86791640520096, 45.73592282831669, 45.14882393181324, 46.595163121819496, 47.184397503733635, 45.57015672326088, 43.30964282155037, 45.67227624356747, 45.70743955671787, 51.36206053197384, 55.160530507564545, 58.58328804373741, 56.14000774919987, 59.77877989411354, 59.34204272925854, 60.36949619650841, 55.11302165687084, 57.653930112719536, 33.655573055148125, 51.58304527401924, 63.53168651461601, 55.932219699025154, 52.4784330278635, 45.33071257174015, 48.60751233994961, 48.544002547860146, 48.0414567142725, 48.701777681708336, 45.965229123830795, 45.49289166927338, 47.013535872101784, 46.2256633490324, 48.04408237338066, 49.25599314272404, 49.90148350596428, 49.24579069018364, 47.3941196501255, 47.33590677380562, 49.15633209049702, 46.51820585131645, 50.26380926370621, 45.797129943966866, 42.0767305791378, 45.84167495369911, 47.72058293223381, 44.539021253585815, 47.57827676832676, 46.32208697497845, 50.533951967954636, 47.874391078948975, 48.19393113255501, 48.28334793448448, 45.07130429148674, 48.95268961787224, 47.21262998878956, 49.00262273848057, 48.897995352745056, 48.683778047561646, 49.1492834687233, 48.20426657795906, 50.03333643078804, 52.901346534490585, 57.38247647881508, 59.5427555590868, 62.84891255199909, 64.72978502511978, 68.01757380366325, 66.37486115098, 65.03587380051613, 65.09274914860725, 68.36065739393234, 66.7239560186863, 64.89930152893066, 63.72160792350769, 61.855539456009865, 62.573780715465546, 59.90864932537079, 53.86914700269699, 5.347508154809475, 7.585140159353614, 5.154803870245814, 0.3859447262948379, 0.1970756085938774, 9.566123485565186, 75.12000069022179, 60.843247175216675, 56.44528716802597, 40.53342819213867, 33.14785949885845, 37.50766575336456, 59.6600666642189, 60.08243300020695, 71.79227605462074, 31.48256655782461, 0.843902297783643, 0.26759277388919145, 0.12394291450618766, 0.1331153031787835, 0.16807163134217262, 0.11002124825608917, 0.1765847479691729, 0.19185222481610253, 0.16412054101238027, 0.15220947156194597, 0.08733945636777207, 0.16080841014627367, 0.13845323002897203], [0.02975999566842802, 0.05270311259664595, 0.06676865901681595, 0.026939365088765044, 0.022852047986816615, 0.08277022381662391, 0.020072055558557622, 0.052944462731829844, 0.04163854420767166, 0.07084212949848734, 0.05919599934713915, 0.28436335211154073, 22.4018632248044, 75.3609761595726, 60.30415490269661, 50.03178991377354, 26.680591329932213, 21.828073114156723, 28.237599581480026, 39.35036547482014, 49.109347611665726, 68.97578358650208, 11.366235092282295, 0.2452412896673195, 0.5232261051423848, 0.37936303415335715, 2.5780091900378466, 3.0179695319384336, 14.452662225812674, 69.8997800052166, 69.44807544350624, 66.96059212088585, 64.61811661720276, 66.69022142887115, 65.33502414822578, 65.63550442457199, 61.99111618101597, 54.926960840821266, 46.76458463072777, 46.97600908577442, 51.85154266655445, 59.515704810619354, 59.56801280379295, 60.66787138581276, 59.75749343633652, 57.57402800023556, 55.913612097501755, 56.3727642595768, 53.694303184747696, 51.68052904307842, 47.483346462249756, 45.52898973226547, 43.86548459529877, 43.21826912462711, 43.32742966711521, 44.04143035411835, 43.56625445187092, 44.05881442129612, 42.41713531315327, 41.68592154979706, 43.810558542609215, 41.56318433582783, 42.90366120636463, 42.42344677448273, 44.05059166252613, 43.34604486823082, 43.279670029878616, 41.728015691041946, 42.77530409395695, 42.55232825875282, 42.61597864329815, 43.41158755123615, 43.44570592045784, 40.80338090658188, 43.88432778418064, 40.22113434970379, 42.59598031640053, 42.20558926463127, 50.04451163113117, 52.9294840246439, 53.83337952196598, 53.66659887135029, 55.377996638417244, 51.872126162052155, 55.564954206347466, 50.70024624466896, 52.35502704977989, 26.04316223412752, 46.11550725996494, 58.43984954059124, 50.16077399253845, 48.21413844823837, 43.32477740943432, 46.19669370353222, 44.55224834382534, 43.499381840229034, 41.377777084708214, 41.44109308719635, 41.36626750230789, 41.868577748537064, 39.107102528214455, 40.29278330504894, 40.47791697084904, 42.06082843244076, 43.660595789551735, 41.92937068641186, 41.8206737190485, 40.877818912267685, 43.72789777815342, 42.00168460607529, 41.698662266135216, 41.60446152091026, 41.28739133477211, 43.23607116937637, 41.401290223002434, 42.59028822183609, 42.17261843383312, 42.316075935959816, 41.35511890053749, 42.517772912979126, 42.106874361634254, 44.120576307177544, 46.151362136006355, 41.9005074352026, 44.27007168531418, 42.21291147172451, 43.60505796968937, 43.464883491396904, 44.18821267783642, 47.27270856499672, 55.662855952978134, 56.345622316002846, 58.101675286889076, 59.09415923058987, 59.10427048802376, 53.46180126070976, 60.660055205225945, 63.42471845448017, 60.809056609869, 58.25416870415211, 62.50058904290199, 57.983140647411346, 63.680691719055176, 60.03875434398651, 62.81973011791706, 55.75831823050976, 67.2519300878048, 24.588674381375313, 0.11497280560433865, 1.4542444283142686, 0.09027447973494418, 0.05335764974006452, 0.6847520533483475, 40.77246196568012, 64.75350335240364, 37.35921151936054, 34.485076144337654, 26.125300526618958, 13.172091990709305, 29.861372150480747, 41.59115083515644, 50.529217422008514, 32.6890417188406, 1.7157430713996291, 0.3219316393369809, 0.07401945666060783, 0.04626879243005533, 0.032911473826970905, 0.06329235766315833, 0.06857143962406553, 0.04346128858742304, 0.040720882316236384, 0.03330170991830528, 0.027371977812435944, 0.04327945127442945, 0.027847443998325616, 0.029901931411586702, 0.009554634616506519, 0.06511107960250229, 0.04403130995342508, 0.030268719347077422, 0.06280481116846204, 0.0193479921654216, 0.070597027806798, 0.03270996588980779, 0.033483584338682704, 0.04691996022302192, 0.24391156883211806, 31.372036188840866, 86.1417880654335, 66.99933484196663, 59.42232482135296, 37.691355496644974, 20.112980045378208, 30.58914139866829, 47.85061955451965, 53.16508658230305, 79.74861592054367, 11.426452361047268, 0.15692479588324204, 0.4444555303780362, 1.8495530099608004, 3.9375467877835035, 3.610019087791443, 17.81471136957407, 71.38656422495842, 71.44041493535042, 68.917927891016, 67.07973852753639, 68.92216086387634, 67.2663389146328, 66.26233398914337, 62.78792962431908, 56.76292732357979, 48.925555273890495, 49.84159491956234, 55.24481378495693, 63.294678032398224, 62.451146095991135, 64.0493555366993, 61.95378698408604, 60.28902031481266, 58.446601778268814, 57.966820523142815, 56.77165925502777, 54.440248757600784, 50.277758315205574, 47.89361044764519, 45.934804156422615, 45.2315378934145, 44.30836983025074, 46.50798439979553, 45.96169151365757, 45.66489323973656, 44.54983167350292, 44.25715997815132, 44.92675244808197, 44.09840829670429, 44.753873124718666, 43.893291503190994, 44.803418666124344, 46.48175060749054, 45.720184072852135, 43.97125951945782, 44.29507814347744, 44.15646918118, 44.219492599368095, 43.423655703663826, 45.24715505540371, 43.105342984199524, 45.615541487932205, 42.75964513421059, 45.057948008179665, 44.87688772380352, 51.667693331837654, 53.963974714279175, 57.52093344926834, 55.47902561724186, 58.387845531105995, 54.863143265247345, 58.77823658287525, 52.04088270664215, 54.72514986991882, 28.862574845552444, 47.73157574236393, 59.59378682076931, 51.129000037908554, 48.77527713775635, 45.19830487668514, 47.265450954437256, 47.939641177654266, 45.39700761437416, 44.045621529221535, 44.27112802863121, 43.770554289221764, 44.00942847132683, 40.456888899207115, 43.27084690332413, 43.78084793686867, 42.65165112912655, 46.28434360027313, 44.50892686843872, 44.54652585089207, 43.96999418735504, 45.91400407254696, 44.31727275252342, 42.80589625239372, 44.629574194550514, 42.153395265340805, 44.2783210426569, 42.853868678212166, 45.09935438632965, 44.08053405582905, 42.98191040754318, 44.454760774970055, 43.63357923924923, 43.20990577340126, 45.89736096560955, 45.87562993168831, 44.52644772827625, 45.164015516638756, 44.06726896762848, 44.04366463422775, 46.114633306860924, 45.727320089936256, 49.63351048529148, 58.57795313000679, 60.37906788289547, 59.5119734108448, 61.02871522307396, 62.614366337656975, 56.541942581534386, 59.25903618335724, 64.17070582509041, 63.27131308615208, 58.93095798790455, 62.56890557706356, 58.60773213207722, 66.72859936952591, 62.71968528628349, 64.80705007910728, 60.267714858055115, 68.44733074307442, 28.54277640581131, 0.5635481758508831, 1.7906786128878593, 0.8242261223495007, 0.12287164659937844, 0.300004055025056, 41.83218710124493, 68.03378373384476, 44.91659179329872, 34.09932844340801, 22.941097989678383, 20.594541504979134, 34.10431757569313, 47.951675131917, 55.71852296590805, 46.267316713929176, 2.8857019543647766, 0.063721259648446, 0.05798982754640747, 0.022913685206731316, 0.02881451993744122, 0.07579308570711873, 0.0033336939668515697, 0.0512746415915899, 0.019311651049065404, 0.010152745344385039, 0.023396300130116288, 0.016593817199463956, 0.05010118737118319, 0.0902834597218316, 0.1034365949453786, 0.2755811921088025, 0.1894328827620484, 0.24128225835738704, 0.17810126737458631, 0.1756552080041729, 0.14507100539049134, 0.1557776433764957, 0.16275090747512877, 0.21071272058179602, 0.3791085665579885, 40.02044811844826, 94.18279498815536, 74.51085537672043, 68.03077429533005, 39.505644142627716, 31.759987771511078, 37.81544543802738, 52.98092946410179, 63.76228854060173, 83.32927778363228, 15.386274978518486, 0.36830663681030273, 0.9600744734052569, 1.6902494081296027, 11.81205851957202, 9.564935099333525, 18.43771453946829, 74.9597404897213, 70.86368188261986, 75.5048668384552, 67.53624603152275, 73.63839939236641, 71.74677729606628, 68.65447282791138, 66.05239525437355, 60.026040226221085, 51.325639486312866, 51.74771323800087, 57.0364024490118, 66.61915764212608, 65.26902928948402, 66.24590367078781, 62.42355577647686, 63.768603801727295, 61.1950208991766, 60.72677202522755, 58.12091365456581, 57.42116220295429, 53.40976685285568, 51.812442764639854, 48.996524065732956, 46.536387875676155, 45.67682459950447, 49.25168797373772, 48.10152389109135, 50.37341058254242, 47.106140702962875, 45.00306375324726, 47.58974455296993, 45.7174976170063, 47.92655847966671, 45.95012113451958, 47.45411843061447, 48.05150717496872, 48.467185869812965, 46.203799322247505, 46.864173486828804, 46.90298080444336, 47.63309262692928, 46.98987074196339, 47.336100563406944, 44.84026528894901, 47.71184720098972, 45.18387705087662, 48.250422701239586, 48.44649598002434, 53.17436568439007, 57.871403843164444, 59.19092483818531, 57.96319551765919, 60.26013806462288, 55.88722251355648, 60.87289698421955, 56.487567499279976, 53.87160927057266, 30.775185115635395, 50.12292802333832, 61.57161109149456, 53.82414221763611, 52.59379863739014, 47.618885189294815, 50.12383617460728, 50.96866004168987, 47.32154354453087, 45.76683796942234, 46.63340426981449, 46.13121181726456, 46.12472556531429, 43.748610466718674, 44.42634969949722, 46.827095076441765, 44.99408483505249, 48.79352755844593, 46.798334419727325, 47.67327547073364, 46.17977701127529, 48.42932850122452, 46.101394817233086, 46.1122964322567, 46.380440443754196, 44.49468143284321, 47.24247358739376, 46.11323118209839, 46.36499427258968, 46.70811206102371, 45.24015583097935, 46.3959664106369, 47.20094181597233, 45.51502928137779, 46.44057221710682, 49.60197977721691, 46.18167690932751, 48.675372898578644, 46.76544338464737, 46.23290956020355, 47.86342866718769, 49.354134276509285, 51.07287324965, 60.30129745602608, 62.13832788169384, 61.907908245921135, 62.89392493665218, 65.81792503595352, 59.65478114783764, 62.184347212314606, 63.97395238280296, 64.88231644034386, 61.9423533976078, 64.44640383124352, 60.48845261335373, 68.95096331834793, 65.76952323317528, 68.99018481373787, 62.0688334107399, 71.44960284233093, 29.147605150938034, 1.3327425043098629, 6.6292924247682095, 0.9447747131343931, 0.2525762468576431, 0.8014140464365482, 49.749974235892296, 74.31756734848022, 51.428446769714355, 45.361217334866524, 36.123966202139854, 24.003992155194283, 45.45302040874958, 57.775310799479485, 65.87546914815903, 54.11764606833458, 3.8843551045283675, 0.5240874120499939, 0.13120023562805727, 0.1916553924093023, 0.1764925435418263, 0.2546807104954496, 0.19492192572215572, 0.1078569823584985, 0.13579144317191094, 0.07862715472583659, 0.12936762068420649, 0.14537077368004248, 0.07928129853098653], [0.03852726447803434, 0.03737754042958841, 0.0393171174073359, 0.04620147963578347, 0.00891991281605442, 0.06580064611625858, 0.004811120743397623, 0.02824782524839975, 0.011459245306468802, 0.035968821684946306, 0.04485701603698544, 0.5806472583208233, 39.30674761533737, 72.42376416921616, 53.6957661062479, 44.49361369013786, 15.57429363951087, 37.48379543423653, 49.02356721460819, 32.46224328875542, 59.5965226739645, 58.79938244819641, 2.3579544480890036, 0.1851490727858618, 0.08352152959560044, 1.077904428821057, 1.4209978748112917, 1.1110768862999976, 55.24594612419605, 75.5361695587635, 69.00344610214233, 65.235735476017, 65.31940698623657, 63.72526332736015, 63.24482850730419, 61.16816394031048, 60.3665741533041, 54.60144370794296, 46.63637951016426, 46.506331488490105, 45.50829604268074, 51.47502847015858, 59.03758406639099, 59.91085700690746, 61.196073442697525, 55.13773933053017, 58.80377881228924, 55.55365361273289, 53.42067986726761, 49.294887855648994, 44.56506125628948, 42.42298319935799, 43.444938361644745, 42.91717708110809, 44.594228491187096, 43.85324165225029, 44.596774354577065, 41.73635244369507, 42.818830758333206, 44.450292214751244, 45.270603597164154, 42.26267360150814, 43.82521815598011, 42.79467925429344, 43.81979964673519, 42.70242780447006, 43.23564559221268, 41.64603129029274, 42.520558163523674, 41.77457079291344, 43.360643684864044, 41.0738617926836, 38.85270997881889, 41.80148094892502, 42.93526791036129, 40.60646027326584, 43.13065342605114, 42.94010505080223, 53.41283328831196, 53.33127826452255, 55.96471555531025, 55.85229478776455, 56.773410961031914, 55.34100562334061, 55.6526231020689, 52.41735130548477, 53.73996913433075, 26.11182264983654, 48.32093171775341, 57.06496171653271, 51.2616129219532, 48.508364260196686, 45.68839117884636, 47.40649938583374, 46.733635291457176, 45.24840518832207, 41.94025330245495, 41.95239745080471, 40.04230834543705, 39.7866390645504, 40.093841180205345, 39.63917277753353, 40.80612055957317, 42.776022255420685, 42.64202244579792, 41.55719205737114, 41.524088233709335, 43.10666911303997, 40.36075405776501, 41.91808149218559, 41.02370448410511, 41.6405975818634, 40.843586549162865, 43.832023590803146, 42.068302631378174, 41.614872962236404, 42.048194110393524, 42.823553904891014, 42.31920696794987, 43.02219204604626, 43.57808701694012, 46.16453982889652, 41.53764210641384, 42.604845240712166, 43.65163207054138, 43.219523057341576, 44.55079302191734, 44.87126402556896, 46.62113472819328, 53.76864619553089, 61.10682003200054, 64.59169283509254, 56.22425302863121, 59.11460593342781, 57.18889966607094, 60.79693146049976, 51.22187465429306, 57.851363718509674, 61.51578828692436, 61.27719148993492, 61.72368273139, 61.73515051603317, 59.01784032583237, 62.57243938744068, 62.880257070064545, 63.13969574868679, 63.1160344183445, 56.473268866539, 5.064297001808882, 1.221116844099015, 0.4700579331256449, 0.44202559045515954, 0.10460471312399022, 10.875546522438526, 67.30837985873222, 48.980941101908684, 46.870074570178986, 38.10798414051533, 22.275398410856724, 33.039515912532806, 44.07759681344032, 50.92725366353989, 45.96141032874584, 5.5344652477651834, 0.2065532054984942, 0.05807974986964837, 0.041055987967411056, 0.016072877770056948, 0.0391124850284541, 0.05389126505178865, 0.08747794112423435, 0.036062209837837145, 0.019994953836430795, 0.04802743009349797, 0.06310060154646635, 0.02106076881318586, 0.010558329049672466, 0.044395270306267776, 0.1564119421527721, 0.02984275997732766, 0.036000366671942174, 0.04433062924363185, 0.012998871479794616, 0.025881979054247495, 0.04250440790201537, 0.09056776907527819, 0.043802580039482564, 0.5968397331889719, 56.179236844182014, 78.19883108139038, 61.460961028933525, 52.03804425895214, 22.64239601790905, 36.57782904803753, 39.48605239391327, 40.313708782196045, 65.92248782515526, 65.16879826784134, 2.5540187023580074, 0.2552532032132149, 0.24247229215689003, 2.3938903072848916, 2.628721031360328, 1.7821189784444869, 55.502329766750336, 77.04619333148003, 71.52901098132133, 67.24031791090965, 66.36774033308029, 65.14774739742279, 65.30847117304802, 64.704250395298, 61.6862927377224, 57.55184479057789, 47.76495315134525, 48.15760128200054, 48.400659039616585, 54.712572544813156, 60.7978206127882, 63.64694193005562, 61.71074442565441, 59.33071553707123, 60.11701874434948, 58.78838583827019, 55.318279042840004, 51.52935415506363, 47.24385291337967, 45.84281109273434, 45.92812031507492, 45.01370698213577, 46.71605743467808, 46.359507367014885, 45.872111320495605, 44.06544126570225, 45.77860973775387, 45.08364222943783, 46.02782316505909, 44.94653418660164, 46.96883127093315, 44.16670583188534, 45.073538571596146, 42.88799464702606, 46.06319546699524, 42.97504797577858, 45.37304230034351, 45.17498552799225, 44.56746272742748, 44.300451055169106, 44.53598901629448, 43.695059940218925, 44.635688066482544, 42.29400672018528, 45.96066176891327, 46.57025545835495, 54.99008305370808, 54.87100504338741, 59.9477606266737, 57.76854336261749, 58.3434297144413, 58.2285200804472, 57.5851234048605, 56.17868587374687, 56.07382670044899, 28.833979479968548, 48.9649211615324, 59.18744422495365, 51.45838536322117, 50.349088087677956, 47.69475191831589, 49.322200790047646, 49.805755242705345, 47.779635563492775, 44.90048065781593, 44.37577061355114, 43.545138984918594, 41.57306380569935, 41.900872215628624, 42.346945479512215, 42.18975551426411, 45.00861905515194, 45.26046194136143, 43.3816147595644, 44.59823727607727, 43.901772648096085, 42.990805730223656, 43.802943751215935, 41.99756942689419, 44.29597109556198, 43.2061667740345, 45.35568103194237, 44.000229164958, 42.172398045659065, 44.248192459344864, 45.83756357431412, 45.04197746515274, 44.062781408429146, 44.51312944293022, 47.26381704211235, 43.25634688138962, 44.37973000109196, 45.02439960837364, 43.82536254823208, 45.661530420184135, 47.337730675935745, 47.40014232695103, 56.517924070358276, 61.45448997616768, 63.959984332323074, 59.541858807206154, 60.640075877308846, 59.117516577243805, 62.23736196756363, 53.74636799097061, 58.39318424463272, 60.905674025416374, 64.50978443026543, 62.43128836154938, 65.34991934895515, 61.455645114183426, 64.72875148057938, 63.21338899433613, 65.8580356836319, 65.42710080742836, 60.49370773136616, 7.287074653431773, 0.813489620340988, 1.9439321081154048, 0.554796711076051, 0.16241585748502985, 11.403618436306715, 73.21327820420265, 53.689895421266556, 45.25462165474892, 27.37371403723955, 25.328029207885265, 39.7593679279089, 51.43180578947067, 57.509849444031715, 56.967956721782684, 8.771388530731201, 0.38305239868350327, 0.0876730220625177, 0.04986532912880648, 0.04422279518621508, 0.02275347778777359, 0.0345379720965866, 0.029417372061288916, 0.07056081100017764, 0.03350236438564025, 0.020407634328876156, 0.019161252967023756, 0.04012784324004315, 0.11188516698894091, 0.13984548422740772, 0.32790396886412054, 0.22932640771614388, 0.1156093753525056, 0.1783679804066196, 0.07868900531320833, 0.05358486196200829, 0.09557966302963905, 0.12413265940267593, 0.13923065940616652, 1.5111925662495196, 67.11285755038261, 88.3803391456604, 69.17309179902077, 62.160834074020386, 25.61878200620413, 52.49907732009888, 64.98852834105492, 48.43263052403927, 72.38731652498245, 70.31195908784866, 3.1882761558517814, 0.19491549872327596, 0.7527304056566209, 3.647941527888179, 10.209336820989847, 2.220935937948525, 58.53686213493347, 77.02235341072083, 75.33342763781548, 69.12234172224998, 70.47506153583527, 69.33864891529083, 69.04602661728859, 65.92027634382248, 66.16253614425659, 58.891413509845734, 50.715255439281464, 50.30757911503315, 51.13178908824921, 56.701518818736076, 63.63536015152931, 66.59645766019821, 64.87054467201233, 61.96586653590202, 62.70098268985748, 59.450431913137436, 59.5736251026392, 54.24623116850853, 50.438276901841164, 46.74563504755497, 48.4782774746418, 47.21808649599552, 49.94483157992363, 49.309175089001656, 49.69247192144394, 46.06224171817303, 47.88178168237209, 49.18709523975849, 48.844938799738884, 46.35149359703064, 49.30138170719147, 47.28294521570206, 47.84400790929794, 45.43136917054653, 47.85517930984497, 44.03764955699444, 47.1528135985136, 45.342370346188545, 47.072010934352875, 45.73099449276924, 45.26651121675968, 47.05183021724224, 48.820148929953575, 44.31324876844883, 49.132465571165085, 47.466247379779816, 56.718488708138466, 58.948619440197945, 61.8128677457571, 60.13229392468929, 60.61481483280659, 59.4723529368639, 59.85084682703018, 58.52229751646519, 60.09984366595745, 33.43261621892452, 50.94117991626263, 60.934366285800934, 55.18052503466606, 53.69572050869465, 50.81982962787151, 52.34403423964977, 52.44954697787762, 51.363550052046776, 46.17603421211243, 47.94502168893814, 44.49915759265423, 44.69492308795452, 45.5591107159853, 45.588460341095924, 45.3455013781786, 46.94247588515282, 47.41364300251007, 46.08958125114441, 47.665037512779236, 44.665907844901085, 45.01050755381584, 48.09507943689823, 45.05825959146023, 46.34156472980976, 45.8130206912756, 48.67043316364288, 45.88609077036381, 44.151867628097534, 47.166698053479195, 46.882594898343086, 48.71613331139088, 46.663643047213554, 46.610871478915215, 50.20761027932167, 46.29872962832451, 46.18511952459812, 45.908813551068306, 46.267426908016205, 48.371203020215034, 49.60138700902462, 49.630744233727455, 58.2437876611948, 64.1895604133606, 68.78521621227264, 63.4977163374424, 61.22905187308788, 62.16207280755043, 64.14676710963249, 57.19489574432373, 62.7032245695591, 62.3808004707098, 65.9969562292099, 65.02215653657913, 66.98197737336159, 65.39356380701065, 67.78346076607704, 65.45081153512001, 69.51951161026955, 67.49398469924927, 63.03317226469517, 7.2111879754811525, 3.3474529394879937, 3.569573820568621, 0.8310089958831668, 0.20049506885698065, 14.236136544495821, 79.81461077928543, 59.595625922083855, 64.55593675374985, 48.441434651613235, 35.86713418364525, 45.27445659041405, 59.45865847170353, 65.46945333480835, 67.93834045529366, 10.962623599916697, 0.4739003878785297, 0.14580748305888847, 0.23946564411744475, 0.10240566276479512, 0.18092724698362872, 0.1644691574620083, 0.25738402793649584, 0.23078990809153765, 0.1406313295592554, 0.2726616128347814, 0.12172669084975496, 0.12328016178798862], [0.028428079931472894, 0.008446753781754524, 0.038861123321112245, 0.008926562459237175, 0.04209886501485016, 0.01852700428571552, 0.08239735398092307, 0.03819712750555482, 0.05414894985733554, 0.01778455603925977, 0.055932334435055964, 3.1752744410187006, 58.24128359556198, 65.77409818768501, 51.901247799396515, 38.44727173447609, 30.581691898405552, 22.781343162059784, 33.89386586844921, 47.43249759078026, 68.23837235569954, 43.921649381518364, 0.08073747390881181, 0.04250051533745136, 0.33013507258147, 2.266224520280957, 1.3204128784127533, 11.285076197236776, 74.23451140522957, 66.76430225372314, 66.49415194988251, 60.82629628479481, 60.83970196545124, 56.42602980136871, 56.39464348554611, 54.456747472286224, 58.5003536939621, 55.4071980714798, 47.95714683830738, 44.65626396238804, 45.174879133701324, 44.52607534825802, 49.89548362791538, 57.56776973605156, 63.4046783298254, 60.8025361597538, 59.78795260190964, 58.58768440783024, 52.13411830365658, 44.99484859406948, 44.74100321531296, 42.66218036413193, 41.48299723863602, 43.89263413846493, 44.46424126625061, 43.6755745857954, 43.79020683467388, 43.09359401464462, 42.03820064663887, 43.29605475068092, 43.46249341964722, 42.146285846829414, 43.412602096796036, 41.97432607412338, 43.372119069099426, 43.58543202280998, 42.304798141121864, 43.49045991897583, 43.190796598792076, 41.582236513495445, 42.866362407803535, 43.23531500995159, 44.13261406123638, 40.75603924691677, 41.05606734752655, 41.21402867138386, 44.76591467857361, 50.16642428934574, 56.03065721690655, 54.13759499788284, 55.82802169024944, 52.784989178180695, 55.78780844807625, 52.74461254477501, 56.6450272500515, 53.26524540781975, 51.694371700286865, 31.939273551106453, 47.44271904230118, 56.94219030439854, 51.663019582629204, 52.91814923286438, 50.555360019207, 53.820228427648544, 51.922359466552734, 51.88292138278484, 46.12767420709133, 42.89964862167835, 41.221761256456375, 40.533637180924416, 39.89853546023369, 41.04121774435043, 40.616962909698486, 41.84179298579693, 41.68800763785839, 40.57054840028286, 41.556348502635956, 41.504158303141594, 40.42248174548149, 40.927117466926575, 41.878525614738464, 44.8365642875433, 40.580526664853096, 45.31683951616287, 43.649781569838524, 43.82222771644592, 43.25769200921059, 43.148596063256264, 43.66358242928982, 43.738776594400406, 42.95375391840935, 42.462846860289574, 43.224367797374725, 42.67471969127655, 43.760788813233376, 41.210373267531395, 42.55550868809223, 43.327004089951515, 49.26374092698097, 59.41457323729992, 54.63403455913067, 51.28180883824825, 49.026493057608604, 61.91116847097874, 55.40214814245701, 62.695229798555374, 59.24311503767967, 55.01630924642086, 60.32281190156937, 61.265704706311226, 57.04466700553894, 61.44431792199612, 60.42373448610306, 61.29529371857643, 58.62826623022556, 64.3763355910778, 60.81111989915371, 68.78358229994774, 29.166744723916054, 0.23752939567202702, 1.1417455156333745, 0.10397380596259609, 0.04052690346725285, 0.9167504450306296, 41.78435906767845, 63.865057826042175, 43.936331793665886, 34.57786336541176, 18.93635418266058, 27.573691606521606, 40.25864973664284, 47.162693068385124, 50.2459654211998, 17.722119837999344, 0.8154128515161574, 0.18490946298697963, 0.08049346317420714, 0.028874568961327896, 0.018652954167919233, 0.04778455484483857, 0.07540836377302185, 0.010334871167287929, 0.02649739388289163, 0.01183584907266777, 0.011444017363828607, 0.03809333073149901, 0.056317438575206324, 0.05890790875128005, 0.040271296675200574, 0.04379326608614065, 0.15525385038927197, 0.06009583485138137, 0.09132316408795305, 0.022911996820766944, 0.04009871023299638, 0.0749615537642967, 0.16203035629587248, 5.233711861073971, 70.63155233860016, 70.54242432117462, 58.54135349392891, 42.061280608177185, 35.712227895855904, 34.65718410909176, 34.45749722421169, 51.753830909729004, 74.95037019252777, 47.42392145097256, 0.10545301760430448, 0.01344590227745357, 1.3295765616931021, 4.712593574076891, 1.5085856686346233, 10.439541768282652, 75.24732425808907, 70.16352385282516, 70.00784620642662, 62.15480379760265, 64.1820140182972, 58.968427777290344, 59.64047871530056, 58.016343265771866, 61.42814978957176, 56.63317948579788, 50.709460750222206, 46.18710681796074, 47.01345607638359, 45.83644263446331, 52.97342486679554, 60.83092823624611, 63.27086091041565, 61.27800464630127, 62.74941489100456, 57.955998703837395, 54.991659969091415, 48.36913213133812, 47.29942873120308, 44.795769676566124, 44.56506885588169, 44.91514787077904, 48.14413100481033, 46.17406591773033, 45.77751539647579, 44.23349104821682, 44.79440554976463, 44.52762186527252, 45.48010915517807, 44.01775002479553, 46.25920794904232, 45.31009867787361, 45.232883021235466, 43.94060276448727, 44.460901245474815, 46.41387104988098, 45.26053033769131, 42.85798005759716, 46.21002718806267, 45.24666868150234, 45.271994322538376, 45.41371151804924, 44.650017097592354, 43.37245725095272, 46.02334700524807, 49.90569368004799, 58.63630659878254, 57.21319176256657, 58.75207118690014, 55.82498945295811, 56.95677772164345, 55.315508991479874, 58.196730986237526, 53.342255875468254, 54.892994463443756, 34.96683329343796, 49.65043097734451, 57.798858135938644, 53.142325803637505, 53.344630748033524, 52.82301753759384, 56.253712847828865, 53.948881924152374, 54.485561326146126, 48.71008783578873, 45.13426311314106, 42.33640104532242, 43.17013330757618, 41.6151237487793, 42.15138517320156, 42.026387080550194, 43.3710703253746, 42.22445905208588, 44.055345207452774, 43.52769032120705, 44.44255582988262, 42.77811974287033, 43.47596749663353, 44.40142683684826, 44.57364119589329, 42.568511590361595, 46.42988719046116, 44.449650049209595, 44.96866039931774, 45.9022057056427, 45.24917654693127, 43.92387606203556, 45.397019013762474, 45.84865517914295, 43.96562822163105, 45.14169551432133, 44.7101716697216, 46.29310593008995, 43.19666348397732, 46.44795902073383, 45.155412778258324, 51.084968000650406, 60.32946154475212, 58.087517246603966, 53.214005157351494, 53.57102259993553, 62.31950595974922, 57.867554649710655, 62.40019842982292, 61.575258895754814, 57.361087426543236, 59.07631538808346, 62.92422831058502, 58.998757749795914, 61.5899945050478, 62.40343205630779, 62.810318022966385, 61.876377537846565, 65.41276037693024, 63.56942608952522, 70.44998288154602, 35.28122462332249, 0.5100550618954003, 1.211001668125391, 0.2705661440268159, 0.1379567926051095, 0.7961187337059528, 45.785810351371765, 67.28583186864853, 46.344251185655594, 30.706712789833546, 27.421933449804783, 38.34030747413635, 45.870002433657646, 53.57559375464916, 60.420987233519554, 26.298164650797844, 0.8124723436776549, 0.131762798409909, 0.04352294992713723, 0.038831674901302904, 0.07862293190555647, 0.01206911721965298, 0.017305633300566114, 0.017165365534310695, 0.026754065656859893, 0.033571053863852285, 0.030749131947231945, 0.027988591209577862, 0.10619759210385382, 0.1045386545592919, 0.19516998116159812, 0.17932447517523542, 0.2448928661760874, 0.13464725925587118, 0.21130127337528393, 0.15833633107831702, 0.22655778127955273, 0.2837457665009424, 0.4134785832138732, 7.048699194565415, 82.61512130498886, 79.61088091135025, 70.29258012771606, 50.910203978419304, 41.89901031553745, 32.740696147084236, 49.53026242554188, 62.42449812591076, 80.04839703440666, 52.82775588333607, 0.31299359863623977, 0.13621675316244364, 1.7596421157941222, 9.01100842282176, 7.355535579845309, 11.542258746922016, 78.4619365632534, 75.03003671765327, 71.46032586693764, 67.52014249563217, 66.75775900483131, 62.8313384950161, 62.415234223008156, 60.55876024067402, 63.71135227382183, 59.477794244885445, 53.547847643494606, 48.99252288043499, 49.21001560986042, 48.75845164060593, 55.04191227257252, 63.970798552036285, 67.5414365530014, 64.11289572715759, 63.915557116270065, 61.567188128829, 58.46951834857464, 50.13280749320984, 50.872954577207565, 47.233319878578186, 45.94735108315945, 46.541996374726295, 48.90767343342304, 48.16240802407265, 48.973592296242714, 46.80922843515873, 46.92603416740894, 47.81304717063904, 46.97159752249718, 46.65562927722931, 47.95298606157303, 46.38782724738121, 46.565638706088066, 47.16175451874733, 47.008759528398514, 48.621727377176285, 46.92466244101524, 44.78498585522175, 47.598142102360725, 48.010590970516205, 48.94300393760204, 47.842096611857414, 46.052472442388535, 44.673154056072235, 47.95165613293648, 52.89161525666714, 61.49013966321945, 61.08388066291809, 61.27962715923786, 57.64113999903202, 58.19891206920147, 56.824700608849525, 60.4530993103981, 59.01970602571964, 54.82000418007374, 36.91630348563194, 52.94572055339813, 59.31475639343262, 56.47656328976154, 55.79015292227268, 55.06973817944527, 59.23553824424744, 58.1463722884655, 56.123113855719566, 50.426239147782326, 47.702853083610535, 46.252231523394585, 44.8200997710228, 44.900070279836655, 44.78392191231251, 44.53540004789829, 46.215392500162125, 46.015333235263824, 45.51556885242462, 45.76472528278828, 46.401122733950615, 45.36739580333233, 45.11625587940216, 46.672314181923866, 49.03872840106487, 44.9759978055954, 48.94386649131775, 46.997063755989075, 47.83607393503189, 48.71930234134197, 46.67187340557575, 46.63182735443115, 48.365792110562325, 47.88712039589882, 46.19896598160267, 47.6639773696661, 46.38339288532734, 49.199471175670624, 46.09788380563259, 48.41583162546158, 47.14700751006603, 52.693782672286034, 65.36970868706703, 60.64533479511738, 59.253450483083725, 57.71834045648575, 64.52040106058121, 60.36884643137455, 66.77685678005219, 63.041942194104195, 59.27131712436676, 63.41819800436497, 64.0988440811634, 63.755517303943634, 64.13055717945099, 64.10154953598976, 65.37926137447357, 64.65738371014595, 68.61949190497398, 65.51749795675278, 73.0497957766056, 34.46344010531902, 0.6913680920843035, 3.409235249273479, 0.6455746712163091, 0.19145884201861918, 1.416489772964269, 52.1612336486578, 73.12308624386787, 59.76189360022545, 44.17478419840336, 28.37654672563076, 40.38506895303726, 56.656540632247925, 61.50422550737858, 71.65730729699135, 32.38357990980148, 1.1648223898373544, 0.46084102301392704, 0.2984805149026215, 0.13000825740164146, 0.15613687253789976, 0.12855398934334517, 0.1938929973402992, 0.1600045751547441, 0.14291482890257612, 0.1356037985533476, 0.0884315044095274, 0.12268480350030586], [0.017880808882182464, 0.031683968991274014, 0.08132308037602343, 0.04654958029277623, 0.04312256496632472, 0.04054689321492333, 0.018719253930612467, 0.03645718454208691, 0.0438035893603228, 0.06307570249191485, 0.04257320128090214, 7.382950158789754, 66.15786239504814, 57.445157915353775, 49.90410536527634, 29.40947949886322, 19.51168891042471, 30.185057781636715, 39.34120796620846, 47.91562266647816, 73.76278951764107, 17.79817085713148, 0.3562615206465125, 0.02567964362242492, 0.7863115787040442, 2.2353257657960057, 0.937745327828452, 32.232306227087975, 66.60649672150612, 65.33286586403847, 68.8614173233509, 56.03740565478802, 52.07863748073578, 51.83778740465641, 53.6540063470602, 51.74348786473274, 52.00460225343704, 49.69748005270958, 49.02560390532017, 46.53931371867657, 43.82374003529549, 44.093772545456886, 44.03120510280132, 45.81129178404808, 55.31116962432861, 58.49225252866745, 59.67041350901127, 53.11940923333168, 45.86806833744049, 43.73426243662834, 44.319917410612106, 42.86004334688187, 44.74633052945137, 43.689580634236336, 43.11960741877556, 41.484710946679115, 42.054361179471016, 42.46242128312588, 42.960114777088165, 40.644085854291916, 44.25026714801788, 41.99293367564678, 43.84969264268875, 43.16523917019367, 43.783811777830124, 41.32053315639496, 42.89506986737251, 43.46777893602848, 43.60570773482323, 41.85896806418896, 42.59653888642788, 44.000369757413864, 43.05848769843578, 41.15692913532257, 43.510025069117546, 40.26189096271992, 44.19853292405605, 51.98571726679802, 56.579647958278656, 54.73380580544472, 54.96666111052036, 53.92001487314701, 57.01095141470432, 52.801126912236214, 57.80758246779442, 55.32528206706047, 55.86507350206375, 29.90204516798258, 43.55418249964714, 58.97969037294388, 51.72531723976135, 52.59691447019577, 53.35158817470074, 53.89970876276493, 54.313369765877724, 53.54223154485226, 50.58561399579048, 45.12740448117256, 39.75179873406887, 42.23852589726448, 41.21245935559273, 40.69721080362797, 41.02685831487179, 41.19830511510372, 40.4583366215229, 40.665642097592354, 41.23513273894787, 42.246520668268204, 42.89365254342556, 42.26123347878456, 42.023731023073196, 44.0936129540205, 43.78121271729469, 42.993446588516235, 41.102960631251335, 43.913050442934036, 41.18857763707638, 41.71863779425621, 42.94880658388138, 41.783941090106964, 43.574055433273315, 42.43530973792076, 43.80199380218983, 42.48740114271641, 42.40276448428631, 40.77734850347042, 42.382739558815956, 43.734437227249146, 50.55409848690033, 58.66369552910328, 50.58395728468895, 44.42698046565056, 57.86432482302189, 54.07114416360855, 58.40947397053242, 53.883324041962624, 58.87918196618557, 56.31709724664688, 55.774729549884796, 60.72791576385498, 59.43682484328747, 58.383266776800156, 57.39223815500736, 57.79803358018398, 57.83991493284702, 61.02976776659489, 62.97813221812248, 62.008036673069, 63.201792016625404, 7.891747131943703, 1.6025631758384407, 0.4283816210227087, 0.15609900816343725, 0.05428591692179907, 14.86577320843935, 63.33147145807743, 51.06912285089493, 40.91294422745705, 17.082678750157356, 15.059784147888422, 32.64587223529816, 44.978832453489304, 50.377875342965126, 31.644777953624725, 1.1655246396549046, 0.08239557282649912, 0.011053247853851644, 0.03969214689277578, 0.02285873288201401, 0.0348539488913957, 0.03814348136074841, 0.021163595229154453, 0.0381339892919641, 0.0401965958008077, 0.03743630739336368, 0.030299503632704727, 0.05483747736434452, 0.020768754111486487, 0.035597844325820915, 0.04412760361446999, 0.034468080339138396, 0.027547935460461304, 0.05205014138482511, 0.0067422247138893, 0.019255112383689266, 0.14184005063725635, 0.13038471923209727, 11.400133073329926, 77.90071427822113, 62.96049356460571, 55.66600978374481, 35.13147085905075, 27.249627895653248, 29.13932539522648, 42.94984392821789, 54.944059923291206, 79.83585923910141, 19.567390121519566, 0.4064062424004078, 0.14889520331053063, 2.0059339748695493, 3.301574676297605, 1.3508960301987827, 34.9220184981823, 70.8932138979435, 67.48617231845856, 69.77026015520096, 59.21182371675968, 55.372384339571, 55.2575659006834, 57.242731377482414, 56.164068058133125, 56.72043800354004, 52.47335650026798, 50.33413968980312, 47.54853196442127, 46.19920536875725, 46.663798838853836, 45.5535402148962, 48.7597169727087, 57.789332047104836, 59.52991224825382, 60.31914509832859, 55.01228146255016, 47.941028103232384, 44.3620191514492, 47.90194720029831, 45.058582574129105, 46.63716986775398, 45.79796589910984, 45.94445563852787, 46.21524050831795, 45.532603338360786, 44.42558974027634, 45.1745181530714, 44.26559552550316, 45.8613882958889, 42.691146209836006, 46.07484944164753, 46.85723885893822, 44.82362598180771, 43.25866095721722, 46.5656653046608, 45.6872246414423, 44.47797752916813, 41.50395691394806, 44.04594071209431, 45.11831156909466, 46.490072160959244, 43.89486841857433, 45.70954464375973, 42.3422185331583, 45.689363926649094, 53.59443314373493, 58.750832453370094, 56.75700344145298, 57.20219135284424, 55.31404227018356, 58.607773929834366, 56.57649412751198, 59.919930920004845, 56.43581807613373, 57.4230583012104, 32.2638863325119, 46.469731852412224, 61.32303223013878, 54.74451743066311, 55.15572376549244, 55.298668295145035, 56.98423124849796, 57.82375819981098, 54.91490788757801, 52.93670743703842, 45.86692839860916, 42.39939406514168, 44.99352626502514, 42.84974969923496, 44.02536861598492, 43.51336129009724, 43.59652742743492, 43.203427121043205, 42.617912739515305, 43.41460458934307, 43.97689841687679, 44.58751805126667, 45.251619815826416, 44.65551920235157, 45.946233943104744, 44.94524985551834, 45.26860490441322, 43.880353197455406, 45.87831638753414, 42.660892233252525, 43.2936342805624, 42.83843390643597, 44.015831127762794, 46.23806968331337, 43.69565270841122, 45.26923947036266, 44.1255122423172, 42.442935928702354, 43.737754449248314, 43.48020426928997, 46.45879603922367, 52.50173717737198, 61.79934047162533, 53.95419783890247, 50.29554136097431, 61.02408327162266, 57.71559700369835, 61.580491214990616, 57.255491092801094, 62.334104776382446, 58.31418268382549, 58.37838023900986, 61.35553188621998, 62.195606008172035, 60.69811396300793, 60.22487975656986, 58.64156931638718, 59.926713556051254, 62.409428134560585, 66.1556889116764, 63.99396970868111, 65.18176317214966, 9.939009826630354, 0.5854020500555634, 1.2773598823696375, 0.29259305738378316, 0.13649155560415238, 15.915107801556587, 72.054044008255, 55.03309674561024, 40.984289199113846, 21.705603785812855, 20.70448860526085, 38.705980852246284, 50.67294090986252, 56.58289298415184, 43.37874211370945, 1.7773238732479513, 0.03574474874767475, 0.033750375296222046, 0.04518555368122179, 0.037326206074794754, 0.10773014189908281, 0.05565066712733824, 0.024056770744209643, 0.026329317843192257, 0.030402394986595027, 0.034979735501110554, 0.030436841771006584, 0.23205402307212353, 0.12632260360987857, 0.22774074983317405, 0.1509565333253704, 0.1608919314458035, 0.14430307550355792, 0.1814738684333861, 0.1610687407082878, 0.24015082453843206, 0.33745630003977567, 0.2894320129416883, 16.251786835491657, 89.49379339814186, 70.62046453356743, 66.08505070209503, 43.81073333323002, 31.070898547768593, 38.45452934503555, 57.9789000749588, 60.23076184093952, 86.69581353664398, 22.749160788953304, 0.3854096675058827, 0.33795425144489855, 2.317848550155759, 10.786420404911041, 3.972260537557304, 37.79697082936764, 77.33260676264763, 68.36317285895348, 74.61788043379784, 60.11003091931343, 59.388955011963844, 57.248271480202675, 60.119458213448524, 58.28742451965809, 57.94227384030819, 55.43004624545574, 54.18886564671993, 50.04474721848965, 49.82969395816326, 49.20555844902992, 48.90100859105587, 50.38070619106293, 60.80079585313797, 63.27991962432861, 65.13732075691223, 57.41015799343586, 50.87890885770321, 46.91556952893734, 49.07651737332344, 46.74956023693085, 50.920022651553154, 48.68469759821892, 48.038975447416306, 46.60478040575981, 47.25412756204605, 47.682178393006325, 46.69167794287205, 45.17849273979664, 48.50969798862934, 45.299915224313736, 47.53951504826546, 48.0975417047739, 47.40700475871563, 46.66082739830017, 46.7932540923357, 48.11397962272167, 47.0854926109314, 44.17199894785881, 46.3124430924654, 49.25966754555702, 48.08824360370636, 46.55801631510258, 49.45591181516647, 43.10825362801552, 48.37040886282921, 56.61865286529064, 60.63784159719944, 59.43665385246277, 57.893442660570145, 56.84642784297466, 60.639608502388, 59.201321080327034, 65.31918659806252, 59.56301607191563, 60.7121542096138, 36.108299642801285, 49.28704507648945, 62.4597754329443, 57.23857440054417, 56.071345433592796, 57.396965101361275, 59.507010877132416, 60.00224970281124, 58.15500542521477, 57.663011625409126, 49.80455830693245, 45.54048791527748, 46.41089580953121, 46.30893588066101, 46.967307552695274, 46.392462998628616, 46.34979888796806, 47.11772248148918, 43.60163435339928, 45.126823112368584, 46.715464666485786, 47.52667933702469, 45.95910765230656, 46.21694281697273, 48.383149579167366, 49.02178891003132, 46.35339729487896, 45.68810999393463, 47.964841425418854, 45.199919790029526, 45.59351027011871, 46.74050152301788, 46.753485426306725, 48.39449197053909, 47.084299474954605, 48.967280834913254, 46.07112564146519, 45.28267554938793, 45.82352712750435, 45.648546516895294, 48.79519186913967, 56.58995680510998, 64.00154650211334, 57.160762175917625, 51.02422446012497, 62.14178189635277, 61.089090183377266, 66.2109987437725, 58.884022906422615, 66.12310945987701, 59.99828651547432, 61.88282199203968, 63.161977753043175, 64.6331562101841, 62.320315316319466, 63.70572857558727, 62.50165298581123, 63.04584838449955, 66.16293892264366, 69.68046337366104, 67.89146617054939, 68.5026253759861, 9.420966524630785, 3.7993954634293914, 2.029509097337723, 0.4766646208008751, 0.22200387407792732, 19.848269149661064, 74.5970955491066, 67.21902385354042, 51.86228089034557, 25.173913277685642, 28.679726757109165, 44.99473080039024, 59.98957358300686, 64.10052359104156, 54.26698565483093, 2.5390180572867393, 0.14981077605625615, 0.11476188723463565, 0.1706330946763046, 0.09383840646478347, 0.19447527156444266, 0.12855563691118732, 0.16651344776619226, 0.19564446585718542, 0.1850944507168606, 0.25394075957592577, 0.13744416151894256], [0.03437748637225013, 0.056627604353707284, 0.020283443336666096, 0.040077017256408, 0.07975423955940641, 0.07110476813977584, 0.008041404780669836, 0.04577000239805784, 0.03372562838194426, 0.09451213554712012, 0.24047594459261745, 20.00247247517109, 73.92219096422195, 51.08331888914108, 53.30068230628967, 22.26008903235197, 28.66698034107685, 47.692897617816925, 40.81566944718361, 57.10965111851692, 67.73997589945793, 6.056478386744857, 0.28192587196826935, 0.10861251837923191, 0.9478036849759519, 2.1576360845938325, 4.074826771393418, 60.71328654885292, 70.41879415512085, 68.24894338846207, 60.344489738345146, 53.797007873654366, 49.0286323428154, 50.95439940690994, 49.158155992627144, 51.53645597398281, 49.557734951376915, 49.30822893977165, 45.06965138018131, 46.08795873820782, 43.192666098475456, 43.60913135111332, 44.85507309436798, 42.81641408801079, 44.183698520064354, 47.0098614692688, 44.89226929843426, 45.171862095594406, 43.065399527549744, 45.99665343761444, 41.58050760626793, 43.171964809298515, 42.7045176923275, 43.10196876525879, 42.43815578520298, 42.98477925360203, 44.47600543498993, 42.52207428216934, 42.60900601744652, 41.79440952837467, 40.49150884151459, 43.24788473546505, 40.907651111483574, 43.11904884874821, 41.95562347769737, 41.44526146352291, 42.34582833945751, 43.40115711092949, 43.05282220244408, 44.04363423585892, 42.698175832629204, 42.799235209822655, 44.476225823163986, 41.04476675391197, 42.525395303964615, 41.59391708672047, 45.81166036427021, 54.240155294537544, 55.109662637114525, 53.59943747520447, 57.746086567640305, 53.25991049408913, 55.435305163264275, 54.33258913457394, 58.68251591920853, 51.360213831067085, 55.084887966513634, 31.15296084433794, 32.42497868835926, 53.15254345536232, 49.852515533566475, 56.237985491752625, 51.57934807240963, 56.350630447268486, 53.390748873353004, 54.82087813317776, 50.839466974139214, 45.977627858519554, 39.7583419829607, 44.21858824789524, 40.266332924366, 41.86681844294071, 39.64173004031181, 40.379008278250694, 40.512540712952614, 42.949490547180176, 45.708735287189484, 45.10348096489906, 41.66852608323097, 43.40732038021088, 41.928124353289604, 42.804570123553276, 43.0001912266016, 43.52221481502056, 42.674852684140205, 43.55414070188999, 40.94373397529125, 42.114120572805405, 41.25785931944847, 44.292235895991325, 43.967672511935234, 42.18615710735321, 40.77831745147705, 41.96350425481796, 43.44774641096592, 42.89836049079895, 43.29796604812145, 43.481013625860214, 47.59344935417175, 56.116468012332916, 56.97084456682205, 59.102879762649536, 57.63092614710331, 56.434898525476456, 53.408550918102264, 51.92256085574627, 54.25196886062622, 54.74678210914135, 50.75460992753506, 56.7186065018177, 60.09510152041912, 56.65671542286873, 60.33486865460873, 55.645449087023735, 58.02124500274658, 57.11848184466362, 61.86720862984657, 60.870499312877655, 67.83400565385818, 34.478122517466545, 0.36430874664802104, 0.29317528707906604, 0.2734245406463742, 0.12190104360342957, 2.792700044810772, 47.30082705616951, 52.9139656573534, 42.87494994699955, 31.40889421105385, 17.500092051923275, 36.2845303863287, 54.554360434412956, 47.597686126828194, 40.052491798996925, 3.1770952558144927, 0.1783957367297262, 0.12979972874745727, 0.07758227016893215, 0.13891733950003982, 0.03463284454483073, 0.015045833515614504, 0.07951673003844917, 0.06625233945669606, 0.023628139642823953, 0.04866013325226959, 0.011650614578684326, 0.07484233516152017, 0.04884246409346815, 0.017051304857886862, 0.01354615993477637, 0.05064961966127157, 0.03903851888026111, 0.01436461616322049, 0.09327033694717102, 0.06845178315415978, 0.1586770807625726, 0.13017035729717463, 28.772536776959896, 82.93704763054848, 57.88301222026348, 61.19121350347996, 29.565947502851486, 29.239199236035347, 30.196438170969486, 45.75451523065567, 63.37386958301067, 74.46160241961479, 6.422544568777084, 0.15217105799820274, 0.38395731418859214, 3.497330197133124, 2.146947020664811, 4.78910056874156, 65.73313638567924, 71.63873389363289, 73.85948672890663, 63.73512759804726, 56.54991075396538, 51.139814257621765, 52.66039006412029, 51.17051661014557, 54.25415754318237, 51.518657729029655, 51.84963516891003, 47.80170477926731, 49.56320285797119, 44.641357362270355, 44.6497967094183, 46.19407944381237, 44.61054861545563, 47.084257677197456, 50.7392967492342, 46.40361160039902, 47.41294004023075, 45.22242218255997, 47.74805165827274, 44.054642245173454, 45.60709834098816, 45.76685696840286, 46.059152483940125, 44.42315027117729, 45.01983605325222, 46.56895972788334, 43.14817048609257, 43.72827395796776, 44.90335710346699, 44.55833941698074, 46.29747949540615, 42.6959415525198, 43.70753847062588, 43.39694693684578, 43.812496438622475, 44.119907543063164, 47.10636109113693, 45.51048472523689, 44.1642739623785, 45.84052361547947, 45.95993600785732, 47.54523754119873, 43.38913455605507, 43.96267578005791, 43.24500069022179, 49.402197897434235, 56.027636379003525, 58.5217959433794, 56.36978901922703, 58.0917464196682, 56.33449271321297, 57.36563578248024, 55.30994608998299, 60.3069781512022, 54.31814230978489, 57.33231917023659, 33.3836330473423, 32.60761968791485, 54.824107959866524, 52.91914477944374, 59.0475395321846, 54.68530520796776, 57.123391181230545, 54.503602758049965, 56.45176202058792, 53.312792256474495, 46.35547958314419, 41.652433946728706, 44.09742034971714, 42.33596786856651, 43.90332296490669, 41.617137640714645, 42.46982328593731, 43.36934521794319, 46.017708107829094, 47.1203101426363, 45.67029654979706, 43.34214627742767, 45.127476677298546, 44.46840964257717, 44.78570021688938, 45.254028886556625, 45.29158227145672, 45.02525456249714, 45.102633610367775, 43.64258095622063, 43.525220453739166, 43.731169402599335, 45.772560462355614, 45.32518766820431, 44.91195984184742, 42.780635207891464, 43.226039707660675, 44.55357827246189, 44.3715376406908, 46.60047143697739, 43.897794261574745, 49.154375195503235, 57.213309556245804, 59.54366751015186, 60.874606892466545, 60.08604280650616, 58.93012583255768, 55.3608937561512, 54.4046750664711, 57.58909039199352, 56.46468512713909, 55.46804040670395, 58.45376059412956, 61.351789087057114, 59.1584175825119, 61.762379854917526, 56.53769060969353, 59.89072568714619, 60.90841747820377, 64.91164326667786, 63.53696063160896, 72.2534117102623, 38.61768119037151, 0.7291913812514395, 1.1231292458251119, 0.5172010534442961, 0.17265237460378557, 2.5799610977992415, 51.91323235630989, 60.27083829045296, 40.55704012513161, 23.691825605928898, 22.506091631948948, 40.490091517567635, 62.29652859270573, 54.97829608619213, 53.188075348734856, 5.815211283043027, 0.4111005342565477, 0.08114971467875876, 0.05230414142715745, 0.07248295863973908, 0.06339643645333126, 0.009718965593492612, 0.046402527441387065, 0.022922058487893082, 0.006991454138187692, 0.04362321778899059, 0.0374695667414926, 0.12444438369129784, 0.15380584605736658, 0.07941469957586378, 0.0922345214348752, 0.120882126793731, 0.18727719609159976, 0.07243189145810902, 0.15004499786300585, 0.2343783702235669, 0.36882845568470657, 0.3762724046828225, 36.949354112148285, 95.25634378194809, 65.1330877840519, 71.35099053382874, 34.85425293445587, 42.35831826925278, 58.520074635744095, 58.472121208906174, 70.08473888039589, 82.22099125385284, 8.240855298936367, 0.4015379317570478, 0.44770679029170424, 5.078054638579488, 10.642844159156084, 5.997088998556137, 68.96385982632637, 72.65210911631584, 75.4940678179264, 65.95372214913368, 60.61141021549702, 54.06946465373039, 55.57205222547054, 54.27425466477871, 58.68827261030674, 53.876165226101875, 55.95012053847313, 49.076650366187096, 51.115803346037865, 46.333531960844994, 48.40969875454903, 48.929757848381996, 46.119170263409615, 49.50704947113991, 53.4893573820591, 48.67118552327156, 51.242819130420685, 47.50372476875782, 49.888609796762466, 45.24976171553135, 47.39715948700905, 48.325814455747604, 48.00183244049549, 46.34917192161083, 48.30431900918484, 50.27646258473396, 47.45327487587929, 46.73521600663662, 47.8706406801939, 44.83505956828594, 48.873505666852, 44.36908297240734, 46.34585849940777, 45.38364753127098, 46.43687881529331, 46.16572916507721, 50.23767426609993, 49.16431926190853, 48.40156339108944, 48.25150944292545, 47.35704883933067, 48.81986014544964, 45.60904383659363, 46.581913232803345, 46.4348991215229, 51.06107868254185, 59.21431638300419, 59.51719053089619, 57.53478370606899, 62.10170924663544, 59.3217708170414, 59.44819003343582, 60.16679987311363, 63.852640092372894, 55.90377822518349, 59.319711327552795, 37.70014062523842, 35.343495681881905, 55.64125411212444, 54.865020364522934, 59.408626556396484, 55.90040400624275, 59.274227768182755, 57.48114198446274, 59.598566964268684, 55.119154527783394, 47.78979241847992, 43.59969645738602, 47.80852921307087, 44.88845810294151, 45.559597089886665, 44.11924637854099, 44.343548342585564, 45.66297434270382, 46.55512847006321, 49.40184071660042, 48.252892568707466, 46.37575149536133, 47.74745889008045, 46.62037096917629, 47.46553681790829, 47.28453733026981, 48.34496162831783, 48.15051846206188, 46.87306880950928, 46.44923195242882, 46.144587099552155, 46.68631263077259, 48.752079382538795, 49.91469919681549, 47.38044798374176, 45.5538821965456, 45.69000609219074, 46.97906032204628, 47.38944970071316, 48.91976438462734, 45.81637591123581, 52.384631261229515, 60.668004378676414, 61.98929227888584, 62.99154929816723, 62.02117256820202, 62.68588989973068, 58.50883483886719, 56.535072550177574, 59.78176653385162, 57.753632962703705, 57.79792718589306, 60.34941807389259, 62.68344283103943, 62.25448004901409, 64.68644455075264, 59.340762197971344, 63.367018550634384, 62.507690861821175, 67.82293304800987, 66.81490033864975, 76.1245147883892, 39.180670380592346, 1.102026840671897, 3.310505859553814, 0.7643245928920805, 0.2364951535128057, 3.987961057573557, 56.39430530369282, 66.32617056369781, 57.984595969319344, 42.42823451757431, 29.703091643750668, 47.867540046572685, 70.71276918053627, 63.877490758895874, 68.48718300461769, 8.594388328492641, 0.7215521880425513, 0.21412239933852106, 0.2807448775274679, 0.2692970121279359, 0.16038476256653666, 0.130721713649109, 0.24044565012445673, 0.14409111812710762, 0.11619798009633087, 0.1306675368687138, 0.20275147981010377], [0.015938868164084852, 0.013508744559658226, 0.025517586400383152, 0.05109022902615834, 0.06396764525561593, 0.02019166378886439, 0.06554945881362073, 0.03837769203528296, 0.026182459805568215, 0.02768520309473388, 0.2748592011630535, 41.09499245882034, 70.9348900616169, 47.45180055499077, 33.050611317157745, 15.922839436680079, 53.60988311469555, 53.86191599071026, 42.96832613646984, 65.688845962286, 47.94167406857014, 1.1074249260127544, 0.07572102316771634, 0.087411756394431, 2.744117514230311, 1.9544112333096564, 17.32898723334074, 85.25616198778152, 62.07949563860893, 67.36235216259956, 54.093604758381844, 53.06836277246475, 49.84685383737087, 48.17155413329601, 45.87042421102524, 49.70796748995781, 49.508941769599915, 46.01965360343456, 44.0467044711113, 44.38130311667919, 45.14616407454014, 43.50133873522282, 42.98664875328541, 43.61602038145065, 41.749701127409935, 43.7741868942976, 43.498884066939354, 45.28202198445797, 44.80025723576546, 45.82886964082718, 43.827923610806465, 45.341769978404045, 43.23466144502163, 43.74174803495407, 42.19786807894707, 43.01059126853943, 45.39403237402439, 41.23170532286167, 42.660291865468025, 42.17284642159939, 42.02233649790287, 43.40246424078941, 41.549581065773964, 41.19419373571873, 42.913096100091934, 42.161842212080956, 40.952424108982086, 42.82715231180191, 43.360704481601715, 43.78686301410198, 44.406301975250244, 43.118919655680656, 44.64374363422394, 41.84352569282055, 42.16062247753143, 42.67991401255131, 45.95967002213001, 55.573298558592796, 55.53693450987339, 55.55284425616264, 57.00866773724556, 50.41073217988014, 53.84873069822788, 53.04090544581413, 56.00010685622692, 52.23204284906387, 56.03499658405781, 34.80284929275513, 26.425815001130104, 60.159409269690514, 52.82385729253292, 55.97619093954563, 51.22084490954876, 54.152406603097916, 51.656126752495766, 57.096963599324226, 51.460954025387764, 46.20592340826988, 41.998956352472305, 43.44218730926514, 43.78532409667969, 42.67911605536938, 40.264075845479965, 43.430609330534935, 40.5490605533123, 42.986439764499664, 44.25252802670002, 42.86318197846413, 39.90378677845001, 43.64400587975979, 42.516279593110085, 42.30801656842232, 42.443167716264725, 42.05849915742874, 42.5162947922945, 42.782660499215126, 41.11466400325298, 44.14028584957123, 40.62461569905281, 43.16170156002045, 40.07348947227001, 41.00161626935005, 41.498500406742096, 43.111217468976974, 40.68288937211037, 42.266013622283936, 41.52080520987511, 43.86896900832653, 42.14277483522892, 47.760598585009575, 51.128494665026665, 51.18654415011406, 51.26338742673397, 50.18871769309044, 46.17362894117832, 49.74455952644348, 47.26126737892628, 55.492020919919014, 53.30502167344093, 51.9667486846447, 59.85321410000324, 59.57490183413029, 54.775231182575226, 58.123919293284416, 54.09761354327202, 58.93367864191532, 56.754890754818916, 62.766498774290085, 61.77034042775631, 65.44881284236908, 6.1245389096438885, 2.109237131662667, 0.1857030563405715, 0.06942593361600302, 0.2113490379997529, 37.12525047361851, 66.31363123655319, 48.94624896347523, 53.09629887342453, 13.989411033689976, 26.422165296971798, 46.737123504281044, 47.82677963376045, 42.45208203792572, 12.786406986415386, 0.6416741211432964, 0.04788225116499234, 0.035212673392379656, 0.03457339851593133, 0.06559190966072492, 0.03423090478463564, 0.0701656989986077, 0.08012365098693408, 0.06649810908129439, 0.043032535031670704, 0.057413705726503395, 0.01928633082570741, 0.077712220227113, 0.02612244788906537, 0.06855598810943775, 0.02927526005805703, 0.06050747448171023, 0.010576822442089906, 0.023151174318627454, 0.035724020563066006, 0.0534444773074938, 0.6325313961133361, 53.10429744422436, 77.30260357260704, 53.480462059378624, 44.01818700134754, 28.189364969730377, 47.388058975338936, 45.20235925912857, 49.187733605504036, 70.83731889724731, 54.15152125060558, 1.1184824514202774, 0.13863780215615407, 0.6025860935915262, 4.5651287119835615, 1.1964820534922183, 19.299430400133133, 86.06396064162254, 63.4550978243351, 68.39221850037575, 55.24124577641487, 55.303839817643166, 52.38219939172268, 50.479386895895004, 49.325347021222115, 54.18419949710369, 52.64269441366196, 48.403736874461174, 46.08337238430977, 48.293109610676765, 45.97734287381172, 45.744863748550415, 46.36790111660957, 47.26628690958023, 44.1832235455513, 45.061310827732086, 45.17613306641579, 45.57067349553108, 47.652011811733246, 47.73542493581772, 46.129931285977364, 47.301765605807304, 45.61242565512657, 45.36443196237087, 44.95364360511303, 46.13083943724632, 46.835268437862396, 44.76246066391468, 43.895993158221245, 45.40528357028961, 44.18457247316837, 44.69460770487785, 43.48846882581711, 43.62594544887543, 45.9138672798872, 42.487545534968376, 43.419282138347626, 45.26591844856739, 44.91555444896221, 45.87423920631409, 45.10020174086094, 44.779924526810646, 45.99894091486931, 43.07803764939308, 44.72550764679909, 43.83965738117695, 47.321771532297134, 56.334602907299995, 57.428222224116325, 56.666066721081734, 58.00433970987797, 52.69021466374397, 55.140448585152626, 53.36238719522953, 59.28200215101242, 53.26561778783798, 59.2659518122673, 36.42689734697342, 27.79090505093336, 60.934788063168526, 54.566622376441956, 58.204592764377594, 53.27148087322712, 56.87662482261658, 54.19156730175018, 57.510913386940956, 51.66347175836563, 47.62004792690277, 42.281182408332825, 46.68331079185009, 45.41973799467087, 45.30436858534813, 43.38998191058636, 45.157669857144356, 42.70362474024296, 45.223235338926315, 45.69432646036148, 44.986063465476036, 41.172736287117004, 47.17220015823841, 44.48088437318802, 43.74367073178291, 44.164722338318825, 44.2665758728981, 44.511176347732544, 45.10802172124386, 43.643135726451874, 45.343571081757545, 41.20781220495701, 47.30635955929756, 42.952241599559784, 43.2376404851675, 44.01167035102844, 46.11364156007767, 42.82463684678078, 44.982366263866425, 43.5305667668581, 45.36743760108948, 45.323625952005386, 50.40753275156021, 54.24975357949734, 54.457674622535706, 54.28776293992996, 52.28465862572193, 49.361543878912926, 52.55572468042374, 50.44126354157925, 57.00430557131767, 55.45484371483326, 55.04110671579838, 61.05948977172375, 60.43793052434921, 57.34465330839157, 59.66746486723423, 56.23254798352718, 60.30238039791584, 59.329374209046364, 65.09812206029892, 64.75563123822212, 67.50115111470222, 7.7807926107198, 1.007088697515428, 0.6433725112583488, 0.20990628807339817, 0.308300256729126, 36.67441226541996, 74.99506339430809, 48.34375709295273, 41.675627902150154, 19.494156651198864, 34.493051916360855, 53.400430753827095, 55.20500332117081, 54.728075712919235, 20.249444022774696, 0.774088881444186, 0.11593327828450128, 0.02294655492733, 0.03929642633011099, 0.05987774733512197, 0.02403655649686698, 0.04157157280133106, 0.02755854817223735, 0.016612623221590184, 0.06854642182588577, 0.018800932848535012, 0.12483575526857749, 0.19114034192170948, 0.15693468129029498, 0.17298522783676162, 0.19092207629000768, 0.18351211765548214, 0.14756379037862644, 0.14296581444796175, 0.07453271857229993, 0.1936311973258853, 1.403841320425272, 65.69491043686867, 85.21059483289719, 63.9140447974205, 47.90212199091911, 27.62604519724846, 65.80314382910728, 66.79658532142639, 58.52857857942581, 75.51666900515556, 59.34417821466923, 1.7944544227793813, 0.19017756858374923, 0.655579415615648, 9.996594786643982, 6.218996616080403, 20.059579610824585, 90.57763203978539, 68.05301830172539, 72.88676172494888, 59.3553876131773, 58.812016770243645, 55.22996798157692, 53.296852111816406, 49.74618583917618, 54.994942992925644, 53.47497895359993, 52.30372220277786, 47.759036868810654, 51.06859847903252, 50.55533342063427, 46.03408142924309, 47.55566418170929, 49.6950101852417, 47.17827223241329, 48.66253338754177, 48.02111640572548, 49.50988411903381, 49.68593247234821, 50.93065828084946, 48.13362456858158, 49.373429641127586, 47.667822763323784, 48.28556701540947, 46.47869177162647, 47.55082704126835, 50.73627971112728, 46.68492570519447, 45.4427457600832, 49.46231447160244, 46.52889087796211, 48.692224994301796, 46.24835953116417, 46.46248184144497, 46.99407711625099, 44.71817784011364, 45.36736540496349, 48.914209082722664, 48.88832867145538, 48.43721307814121, 48.316588550806046, 46.38589695096016, 49.27221067249775, 47.53636881709099, 46.55737794935703, 47.278689444065094, 49.3731864541769, 59.53729145228863, 60.44768460094929, 59.574943631887436, 59.015522450208664, 53.748856857419014, 55.341115817427635, 56.630952805280685, 60.87980501353741, 56.586559787392616, 60.497701317071915, 37.97784872353077, 29.651190228760242, 63.5235321521759, 57.74072505533695, 60.66025659441948, 54.977897107601166, 57.70287528634071, 57.890501618385315, 60.76435200870037, 55.35666458308697, 51.221646666526794, 45.86574666202068, 48.23985546827316, 49.05345641076565, 47.29674607515335, 45.59902757406235, 48.86370599269867, 44.986439645290375, 47.33229696750641, 47.86555655300617, 45.555850490927696, 43.20818066596985, 49.71561647951603, 46.6226926445961, 46.30484730005264, 46.853180676698685, 46.715643256902695, 47.91847251355648, 47.11277514696121, 46.78468935191631, 49.369424656033516, 43.78231845796108, 50.09307682514191, 45.166451185941696, 46.08184106647968, 45.8894307911396, 46.92424826323986, 45.409299954771996, 47.97460310161114, 46.29129342734814, 48.926421627402306, 47.35438138246536, 53.282401487231255, 56.85270890593529, 58.11037302017212, 58.11600811779499, 56.25303268432617, 51.57524809241295, 54.433922097086906, 53.3244614303112, 61.62198878824711, 56.57598875463009, 58.628912195563316, 62.81486637890339, 62.2778981924057, 59.79807525873184, 63.31653445959091, 59.450036734342575, 63.60743165016174, 62.042907401919365, 69.34886276721954, 69.68269765377045, 72.96098694205284, 7.412086045369506, 4.545359322801232, 1.5266576176509261, 0.2950550284003839, 0.4226420883787796, 43.379612267017365, 80.18930107355118, 65.0421890616417, 66.90351158380508, 24.775050580501556, 40.2971188724041, 60.3538828343153, 65.37050664424896, 65.96878454089165, 27.266430594027042, 1.565654925070703, 0.21971436333842576, 0.126606727426406, 0.16425022389739752, 0.13982756878249347, 0.16922562645049766, 0.20419186970684677, 0.2790783403906971, 0.1764255276066251, 0.1380031174630858, 0.13340249948669225], [0.06637692378717475, 0.02608950024296064, 0.04392263355839532, 0.0165630663104821, 0.007854759278416168, 0.06048749215551652, 0.0898460675671231, 0.005190463034523418, 0.041104780466412194, 0.05383518466260284, 1.289011719636619, 54.20533776283264, 59.81574811041355, 50.73842279613018, 27.16460555791855, 13.661309089511633, 59.67004872858524, 46.504496186971664, 44.48696404695511, 70.75708240270615, 32.91071802377701, 0.10131230112165213, 0.07772076976834796, 0.291910192463547, 2.5405287137255073, 0.33609229198191315, 44.589364752173424, 74.72136408090591, 64.1997666656971, 63.63758683204651, 54.462295174598694, 55.999305099248886, 50.83076164126396, 51.532659977674484, 48.205942288041115, 51.71099200844765, 49.70547862350941, 48.80222149193287, 46.965137869119644, 45.13308897614479, 42.947723641991615, 44.332753121852875, 43.76429222524166, 43.61719071865082, 43.581301644444466, 44.17259931564331, 43.10164958238602, 43.107178285717964, 43.48642833530903, 42.195139825344086, 42.81612530350685, 44.26080018281937, 42.476765513420105, 43.68572384119034, 42.59534195065498, 42.628563567996025, 43.103397488594055, 43.71508486568928, 43.26606675982475, 43.66551272571087, 39.93806093931198, 40.20765647292137, 42.318321615457535, 41.72507084906101, 41.57737277448177, 41.2659452855587, 42.559388279914856, 42.07785151898861, 41.17763042449951, 40.216149017214775, 43.20618957281113, 42.85162299871445, 42.81197592616081, 42.43566691875458, 39.92889583110809, 40.10648690164089, 45.751570388674736, 52.43130415678024, 54.205383360385895, 53.8850187510252, 55.20391657948494, 51.02317571640015, 53.456006571650505, 50.12656442821026, 57.15767294168472, 52.1100427955389, 60.12849032878876, 41.992515698075294, 32.45151646435261, 60.77532961964607, 49.915801137685776, 55.82584820687771, 52.897033765912056, 54.00900609791279, 53.253804221749306, 53.71688537299633, 47.71945059299469, 43.28510753810406, 41.62648133933544, 43.90972942113876, 40.923044085502625, 42.36226245760918, 40.65222881734371, 40.977685153484344, 41.363345459103584, 43.52256439626217, 43.51236954331398, 42.67361395061016, 41.033526957035065, 42.32891924679279, 42.99353398382664, 41.96838699281216, 42.41278454661369, 41.39530174434185, 40.54637409746647, 41.8181886523962, 38.495263159275055, 40.92175215482712, 40.127077996730804, 41.230705976486206, 40.55043987929821, 41.399884298443794, 42.310809418559074, 41.79452732205391, 41.54113031923771, 42.59623110294342, 42.46225029230118, 43.79220552742481, 44.28309738636017, 43.487556874752045, 42.6067603379488, 44.19456593692303, 43.07772606611252, 45.03288835287094, 45.38925223052502, 48.713978826999664, 50.36477364599705, 50.79150974750519, 54.93863381445408, 51.854297518730164, 51.438504830002785, 61.982015669345856, 59.84043538570404, 56.71423673629761, 55.45390136539936, 55.48683799803257, 54.26179513335228, 60.19182153046131, 61.599733382463455, 69.360740929842, 28.246956579387188, 0.24156926170689985, 0.40045875997748226, 0.06144285143818706, 0.10758640273706988, 19.141930751502514, 58.84438343346119, 51.16450913250446, 45.201367512345314, 25.577548518776894, 18.96268866956234, 41.945079043507576, 54.35984127223492, 49.48309935629368, 26.295191310346127, 1.6900910041294992, 0.04161035001743585, 0.029487844549294095, 0.11608924804022536, 0.05057081099948846, 0.043110490223625675, 0.03081946157180937, 0.01120138424084871, 0.0257057857743348, 0.018686567891563755, 0.04733774112537503, 0.021901406908000354, 0.10796995207783766, 0.015766129581606947, 0.02479239679814782, 0.018871455431508366, 0.04740912831039168, 0.008755088310863357, 0.017604241984372493, 0.013822871551383287, 0.013206119001551997, 2.08826819434762, 67.13627189397812, 65.83915829658508, 59.86232601106167, 30.93519452959299, 20.266767293214798, 61.71325609087944, 48.2447762042284, 53.01690213382244, 75.87680608034134, 36.73518620431423, 0.02446235259412788, 0.023245633019541856, 1.9418998109176755, 3.5179925383999944, 0.7052759395446628, 48.33608150482178, 76.09145656228065, 66.68997824192047, 66.23187482357025, 57.90440507233143, 58.28786909580231, 54.26420420408249, 55.152341946959496, 50.57612970471382, 52.58412815630436, 50.489292964339256, 51.636884585022926, 49.01898846030235, 47.844463884830475, 46.94187931716442, 46.49859130382538, 46.21387638151646, 47.44523070752621, 46.36645719408989, 46.090212017297745, 45.98378352820873, 45.11653706431389, 45.413175746798515, 45.03315433859825, 43.26143480837345, 45.24876616895199, 44.522625133395195, 44.870245680212975, 43.885505720973015, 44.52183477580547, 44.00591365993023, 44.28568124771118, 44.54470954835415, 45.11951610445976, 43.38099919259548, 42.58346378803253, 44.8174437135458, 41.60940505564213, 44.45712424814701, 45.28340891003609, 44.67881575226784, 45.09677432477474, 45.46099238097668, 43.22899974882603, 44.06618982553482, 44.521397799253464, 45.03588639199734, 43.49145546555519, 42.78330646455288, 42.297202348709106, 48.059144765138626, 53.778578862547874, 55.951275676488876, 56.315539330244064, 56.61017172038555, 55.32044492661953, 55.868516117334366, 53.251600340008736, 59.14997823536396, 53.681319281458855, 62.175866067409515, 43.294607028365135, 33.95893357694149, 63.18480312824249, 52.25046806037426, 57.33348570764065, 54.228964895009995, 55.625245571136475, 54.910059347748756, 55.75191557407379, 50.44803477823734, 45.00071927905083, 44.21869084239006, 46.192874908447266, 43.46576124429703, 45.23539088666439, 42.99480311572552, 42.46752440929413, 43.75151731073856, 44.443733766674995, 46.02140910923481, 43.36587980389595, 43.58540162444115, 46.84682361781597, 45.44890522956848, 43.14598560333252, 43.14532823860645, 43.70794124901295, 43.05387854576111, 44.03505429625511, 40.93467526137829, 42.546043395996094, 42.36421935260296, 44.61836859583855, 42.359568402171135, 44.165128916502, 44.60737198591232, 44.305493384599686, 41.99666507542133, 43.6287496984005, 46.47616110742092, 46.81414917111397, 45.168902054429054, 46.37875333428383, 44.84571039676666, 46.37465715408325, 45.10254621505737, 47.24284216761589, 47.44309902191162, 50.488046631217, 51.11517257988453, 52.264261320233345, 55.935213938355446, 54.72765013575554, 54.75377753376961, 63.13374146819115, 61.66795492172241, 60.461033284664154, 57.422552928328514, 57.42788404226303, 56.53925612568855, 63.84957745671272, 63.09165112674236, 73.15632686018944, 32.34902076423168, 0.2941407321486622, 1.0158320283517241, 0.37862913915887475, 0.1953430351568386, 19.3050616979599, 64.6607655286789, 57.82758079469204, 44.32569310069084, 29.82535008341074, 28.434888795018196, 49.42153126001358, 62.01698899269104, 59.16782967746258, 38.09984877705574, 2.4592833733186126, 0.07057156472001225, 0.04199612209049519, 0.053818686719750986, 0.051934414586867206, 0.053459401897271164, 0.03468293209152762, 0.022601730852329638, 0.026774710349855013, 0.03643021860625595, 0.03970724959799554, 0.12224350022734143, 0.21238135057501495, 0.0898165671969764, 0.20674680214142427, 0.1112374576041475, 0.20946848031599075, 0.19028482376597822, 0.12496094073867425, 0.16827178857056424, 0.23707643325906247, 4.032306103035808, 80.09143352508545, 74.36092302203178, 69.52280983328819, 36.96142606437206, 22.755251862108707, 72.81605511903763, 60.35804361104965, 58.22046831250191, 83.98365586996078, 41.657829657197, 0.30688512953929603, 0.18312106520170346, 2.509894520044327, 10.562256183475256, 1.6877901088446379, 52.88272753357887, 79.78737384080887, 68.28165203332901, 68.93821120262146, 59.445457980036736, 61.612192913889885, 55.719925090670586, 57.4566674977541, 53.21003817021847, 56.364488303661346, 54.8835139721632, 57.02479787170887, 52.257710471749306, 50.78844331204891, 47.806211337447166, 49.08195488154888, 49.75414641201496, 49.71089333295822, 47.868938371539116, 48.8681061565876, 47.0018856972456, 49.19740028679371, 48.294344544410706, 48.36244449019432, 46.63371205329895, 49.47572015225887, 46.77457809448242, 48.59331250190735, 45.00663176178932, 46.617878302931786, 46.22630551457405, 47.95303925871849, 47.76509374380112, 48.773286044597626, 46.03292629122734, 44.83088739216328, 47.50013016164303, 44.9337212741375, 46.21581047773361, 47.626123800873756, 46.84335820376873, 46.85042582452297, 47.29694366455078, 44.59755331277847, 46.23945280909538, 45.23419015109539, 46.696632876992226, 46.37548170983791, 44.94543984532356, 44.69022274017334, 51.028370037674904, 56.74113929271698, 60.33204920589924, 59.24642466008663, 59.60294432938099, 57.23501019179821, 57.860547825694084, 54.899005740880966, 62.111877501010895, 57.75304399430752, 64.68961358070374, 46.62186048924923, 36.064643785357475, 65.28438806533813, 55.16910284757614, 59.2756374925375, 56.10417187213898, 57.77409106492996, 57.96232916414738, 58.298166543245316, 54.45504516363144, 47.56747014820576, 47.260606214404106, 49.07513044774532, 45.276607275009155, 49.18777160346508, 46.412244737148285, 44.782033413648605, 46.741892248392105, 47.74764887988567, 46.932372227311134, 45.26948645710945, 44.40106585621834, 49.636231139302254, 47.6878172904253, 45.78406624495983, 46.29310593008995, 45.84004484117031, 45.10152027010918, 45.37391625344753, 42.23417513072491, 44.927090629935265, 45.08866176009178, 46.9227359443903, 43.89523319900036, 46.70530781149864, 47.09002956748009, 47.08164721727371, 44.93806444108486, 45.38944222033024, 48.44342574477196, 47.6471708714962, 47.148690819740295, 49.066109731793404, 46.38167157769203, 48.78714010119438, 47.75486469268799, 49.961729273200035, 49.83193203806877, 53.95651191473007, 53.590576350688934, 55.154492631554604, 58.7226227670908, 57.6792823523283, 59.45390112698078, 65.45649603009224, 64.17971134185791, 60.66510133445263, 59.931345507502556, 61.0561079531908, 59.77177307009697, 67.37720936536789, 66.80255100131035, 74.34168085455894, 33.51574815809727, 0.469655065680854, 3.9319542003795505, 0.5567911884281784, 0.3815803042380139, 25.029251240193844, 68.66129726171494, 66.17612421512604, 61.36089339852333, 36.09648607671261, 31.794759705662727, 58.04439336061478, 70.79727664589882, 70.72734519839287, 48.611969500780106, 2.9766343999654055, 0.18469590257154778, 0.13182396622141823, 0.1720219646813348, 0.13991643354529515, 0.1531017557135783, 0.21687554457457736, 0.12049563112668693, 0.12205293154693209, 0.11174787709023803, 0.1580380619270727], [0.039189364106277935, 0.09086307705729268, 0.03226711523893755, 0.04117449039767962, 0.05378007277613506, 0.05319452196999919, 0.04629053364624269, 0.07974200896569528, 0.08201892545912415, 0.051252306657261215, 3.05735869333148, 57.89166435599327, 60.24083890020847, 50.101428776979446, 33.738374412059784, 27.959057427942753, 50.687087550759315, 52.66259394586086, 50.35403922200203, 74.21425089240074, 14.908724203705788, 0.14512498921249062, 0.0525754669070011, 0.9810732747428119, 1.5179406479001045, 1.8805462843738496, 63.50590489804745, 68.45198929309845, 65.51359176635742, 62.80632823705673, 62.112751454114914, 59.03199836611748, 59.187782406806946, 53.36644917726517, 52.67724595963955, 51.05187937617302, 51.70153051614761, 49.61647979915142, 48.11793901026249, 46.012521386146545, 43.2003340870142, 43.98171275854111, 43.94370719790459, 43.13115119934082, 41.88769832253456, 41.20398201048374, 43.57932575047016, 43.822220116853714, 43.60175594687462, 44.21499744057655, 44.335127994418144, 42.87069037556648, 43.33669736981392, 43.38332086801529, 43.39141063392162, 40.31241685152054, 41.62784166634083, 41.44958183169365, 41.66765972971916, 41.094718873500824, 42.05178111791611, 41.5788546949625, 40.98756842315197, 41.905264779925346, 41.35177507996559, 42.527469992637634, 41.436920911073685, 43.36712993681431, 42.614036947488785, 41.588745564222336, 41.12086147069931, 41.16468071937561, 41.92661203444004, 42.05772779881954, 41.93064361810684, 40.80162160098553, 43.29394206404686, 49.29881304502487, 53.513562083244324, 53.30221742391586, 54.13272745907307, 49.50956113636494, 49.123976826667786, 48.34871582686901, 53.46330977976322, 51.22373655438423, 56.62259705364704, 49.82614494860172, 40.3274792432785, 59.89251159131527, 50.05358934402466, 52.21158094704151, 49.20171685516834, 50.33567100763321, 47.808327823877335, 48.42912711203098, 43.44467617571354, 43.93598601222038, 42.58990064263344, 42.79174581170082, 45.1151729375124, 43.59455153346062, 42.650936767458916, 41.67336322367191, 42.02970430254936, 42.81715884804726, 42.073766738176346, 41.19138568639755, 41.607163175940514, 42.241470739245415, 43.36693614721298, 42.068937197327614, 41.92799136042595, 41.79724037647247, 42.16232858598232, 39.91746224462986, 41.2594286352396, 40.76135516166687, 43.10030825436115, 39.987728074193, 40.55976077914238, 40.917127802968025, 40.05889445543289, 41.001027300953865, 41.944417878985405, 43.36684115231037, 43.4400100260973, 43.84075552225113, 43.224633783102036, 41.65499120950699, 40.80191418528557, 39.94865857064724, 42.695287987589836, 44.22547347843647, 45.26203505694866, 45.10090470314026, 46.24793015420437, 51.28627359867096, 52.988563254475594, 56.36222742497921, 51.63033373653889, 53.57611432671547, 54.64092738926411, 57.024064511060715, 55.738893672823906, 54.673263654112816, 52.09741607308388, 55.76252080500126, 59.45055350661278, 68.80555272102356, 52.267700135707855, 1.6463141469284892, 0.6624287855811417, 0.29041087604127824, 0.026561780759948306, 4.778302973136306, 54.19591046869755, 55.05045421421528, 42.82682552933693, 20.566347017884254, 17.69430723041296, 44.50588323175907, 44.786653965711594, 44.383313208818436, 36.90884068608284, 4.096026783809066, 0.3169512643944472, 0.04365071807114873, 0.05382212657423224, 0.023771292508172337, 0.08146805892465636, 0.04027280323498417, 0.10606313720927574, 0.0448901566414861, 0.047903717786539346, 0.06841863141744398, 0.02778319441858912, 0.06705696112476289, 0.0076644925593427615, 0.037290412292350084, 0.05509475769940764, 0.0578132965893019, 0.008180160421034088, 0.10998588491929695, 0.03698180502397008, 0.17399888281943277, 6.023595426231623, 70.09346321225166, 65.00238999724388, 58.304348811507225, 35.12477941811085, 29.411869570612907, 51.48030638694763, 56.05303041636944, 56.15413539111614, 78.48816275596619, 17.208125218749046, 0.13912408699980006, 0.019191894389223307, 1.8193404749035835, 3.027780605480075, 2.5472268043085933, 66.00329428911209, 70.17445206642151, 68.42330083251, 64.53338876366615, 63.71471129357815, 61.924965530633926, 61.462332755327225, 55.685255751013756, 54.63192567229271, 53.68296459317207, 52.7386012673378, 53.18325720727444, 51.080062463879585, 47.197818383574486, 45.64968645572662, 46.639290153980255, 45.20354099571705, 45.727156698703766, 45.162480399012566, 44.12263199687004, 44.736489057540894, 44.756384789943695, 43.57273310422897, 46.0050205886364, 45.388222485780716, 43.976111859083176, 45.67100711166859, 45.32705336809158, 46.98175057768822, 42.49470055103302, 44.49856482446194, 43.79895016551018, 44.30132880806923, 41.802712082862854, 44.820217564702034, 43.065692111849785, 42.41444505751133, 42.41669073700905, 42.24352642893791, 44.15446288883686, 44.13870133459568, 46.235124841332436, 45.544572696089745, 42.739012241363525, 41.64892293512821, 45.05181893706322, 44.068055525422096, 43.315391913056374, 44.018901363015175, 43.346785828471184, 44.811120852828026, 52.86132328212261, 55.189446955919266, 56.44244872033596, 55.16993500292301, 50.85910812020302, 51.95138990879059, 51.255176067352295, 55.07414974272251, 54.073796421289444, 58.53898622095585, 50.50462894141674, 43.60044501721859, 59.75231431424618, 52.92745113372803, 51.170736998319626, 51.41671299934387, 52.33869172632694, 49.34310346841812, 48.932999074459076, 45.25471284985542, 45.19620358943939, 44.23594951629639, 46.611411049962044, 46.577205285429955, 45.63599959015846, 43.75800736248493, 43.35459440946579, 43.56174789369106, 44.00320440530777, 43.11274118721485, 44.249222204089165, 43.411579951643944, 44.80892837047577, 44.21886183321476, 43.31608347594738, 45.03017149865627, 43.13438102602959, 44.46885421872139, 43.32717128098011, 43.31220008432865, 43.08327376842499, 42.83860869705677, 43.371355310082436, 42.64622502028942, 42.9377605766058, 42.53230333328247, 42.01388955116272, 43.103192299604416, 44.601174518465996, 44.25616443157196, 45.60233719646931, 45.47248296439648, 43.678405433893204, 43.32117900252342, 43.664000406861305, 44.447351172566414, 46.43629364669323, 48.03169123828411, 47.45461620390415, 49.64831829071045, 51.96740984916687, 55.744407176971436, 58.92087712883949, 55.084428191185, 55.996877029538155, 56.11563205718994, 58.98526467382908, 57.87572421133518, 57.373820543289185, 54.1174902766943, 58.77999968826771, 60.84917105734348, 70.65217763185501, 58.714852184057236, 2.483144667930901, 0.5889854358974844, 0.40672183327842504, 0.026981411465385463, 4.504219880327582, 57.37500607967377, 62.470475658774376, 45.662894546985626, 22.391603775322437, 26.797440759837627, 53.484638035297394, 51.18573099374771, 53.20126824080944, 49.40926171839237, 6.453163800761104, 0.45495291240513325, 0.04260358109604567, 0.05675777334545273, 0.06590666191186756, 0.03843534206680488, 0.024487665396009106, 0.22515479562571272, 0.03677337655972224, 0.08719890101929195, 0.041839974219328724, 0.09558925899909809, 0.22253841336350888, 0.12386674789013341, 0.24262416525743902, 0.20529648230876774, 0.10889331737416796, 0.17668014363152906, 0.40946516732219607, 0.15859179315157235, 0.28441942878998816, 9.247822165489197, 85.49478158354759, 71.8211317062378, 68.86485233902931, 46.05366177856922, 41.60533547401428, 60.30964180827141, 69.26441609859467, 62.173198610544205, 88.64390060305595, 18.714016713202, 0.2508916606893763, 0.18093916587531567, 4.988529542461038, 10.42314374819398, 2.620295458473265, 72.69584476947784, 70.17467245459557, 72.09512740373611, 67.04701468348503, 68.59965696930885, 64.29584071040154, 64.81439888477325, 58.31013210117817, 57.55146101117134, 56.66453920304775, 57.08497904241085, 57.22011499106884, 53.78841273486614, 51.814578250050545, 48.05753365159035, 50.97669281065464, 48.18722829222679, 49.02672104537487, 46.885133162140846, 46.98868900537491, 49.01722155511379, 48.6174526065588, 46.72997988760471, 49.27913770079613, 48.22646498680115, 45.28305932879448, 48.14266428351402, 48.358169719576836, 49.28286150097847, 44.47526067495346, 46.81859873235226, 45.43033182621002, 46.84033736586571, 45.01919008791447, 49.04014192521572, 45.58673523366451, 44.59146223962307, 44.97864246368408, 45.79500965774059, 46.676805540919304, 46.77056550979614, 49.23424690961838, 47.19043157994747, 45.146091878414154, 43.84589284658432, 47.43302196264267, 45.76171204447746, 44.87677372992039, 45.39212107658386, 45.19615799188614, 48.737689554691315, 55.247963815927505, 57.701769545674324, 58.611778914928436, 58.02586555480957, 53.748780861496925, 54.44191686809063, 53.624508529901505, 59.03623513877392, 56.41173116862774, 62.18721225857735, 53.07888820767403, 46.55602902173996, 62.880952432751656, 55.32826870679855, 55.53684711456299, 54.254852905869484, 55.16852147877216, 53.09461176395416, 52.49713182449341, 46.649845987558365, 47.51187153160572, 46.179454028606415, 47.64869458973408, 50.47562129795551, 47.903375923633575, 47.27936580777168, 45.6993193924427, 45.755788162350655, 46.82274430990219, 45.666382759809494, 45.500350669026375, 45.19225940108299, 46.959350779652596, 47.44064435362816, 46.03042222559452, 46.87127150595188, 45.202363058924675, 46.215160712599754, 44.364378824830055, 46.95693790912628, 44.74294491112232, 46.53224229812622, 44.68217857182026, 44.84975337982178, 44.09037932753563, 44.551807567477226, 43.469253256917, 45.9130123257637, 46.94381341338158, 46.79432563483715, 47.567348554730415, 49.0831708163023, 45.13397052884102, 44.978258684277534, 45.84023863077164, 46.59912250936031, 49.003553688526154, 50.427018105983734, 50.51504798233509, 53.40742617845535, 54.35114733874798, 58.92528489232063, 62.25262574851513, 57.100751996040344, 60.394035279750824, 59.30062875151634, 62.30774559080601, 61.572317853569984, 59.16735090315342, 58.553106263279915, 60.870601907372475, 63.573415875434875, 73.8125516474247, 60.39354130625725, 2.5837855925783515, 2.8694176906719804, 1.1836677161045372, 0.12041654787026346, 6.8961715791374445, 65.76127767562866, 67.56643921136856, 58.20610508322716, 29.442195743322372, 27.477005794644356, 58.67352560162544, 60.9919635951519, 60.650415122509, 63.616995736956596, 8.493320401757956, 0.48801891622133553, 0.266464501619339, 0.2667984977597371, 0.2154275996144861, 0.18862199736759067, 0.18858247058233246, 0.22926853504031897, 0.16428651491878554, 0.20964944560546428, 0.1896522319293581], [0.02128245760104619, 0.038275698680081405, 0.029085401984048076, 0.05199530780373607, 0.038933983669267036, 0.04375150543637574, 0.02622153017000528, 0.07109532059985213, 0.05377961635531392, 0.09559475089190528, 7.344986395910382, 62.37500958144665, 49.80607442557812, 44.86328825354576, 22.537990920245647, 25.8881913498044, 46.52692638337612, 49.6979284286499, 57.205660566687584, 65.9266372025013, 4.901325171813369, 0.10096756610437296, 0.05088674326543696, 1.7364236991852522, 1.9287807773798704, 7.998682893812656, 75.24330407381058, 60.50976186990738, 67.83840581774712, 62.812058329582214, 63.33272539079189, 59.31500717997551, 61.91483527421951, 55.65093219280243, 57.28281922638416, 49.71649043262005, 51.89277805387974, 48.31193380057812, 47.76982069015503, 44.055337607860565, 44.730994552373886, 44.06129948794842, 44.92235608398914, 43.76876838505268, 45.09910359978676, 44.22214865684509, 44.21608418226242, 42.340436428785324, 42.17700719833374, 42.06275872886181, 43.70996654033661, 41.98832832276821, 42.54036270081997, 41.17372043430805, 43.61643075942993, 41.34950280189514, 42.220195680856705, 39.667010083794594, 40.60653246939182, 40.30310735106468, 40.26116520166397, 40.923378467559814, 41.33245311677456, 43.34674023091793, 41.844551637768745, 41.905074790120125, 40.613900274038315, 41.342336386442184, 42.906416058540344, 39.66991312801838, 42.80104011297226, 41.76542088389397, 41.1910855025053, 39.407894387841225, 42.396776005625725, 38.395404517650604, 41.90307229757309, 45.641402900218964, 52.22362630069256, 53.06475676596165, 51.75330273807049, 48.26917089521885, 49.40284766256809, 47.08846405148506, 47.35376201570034, 51.319506615400314, 56.44337587058544, 51.207891404628754, 44.640114828944206, 57.23265431821346, 51.90679930150509, 46.607998833060265, 43.86571638286114, 43.06321084499359, 44.62778449058533, 43.10998633503914, 42.64135368168354, 45.72505921125412, 43.41982550919056, 45.53006127476692, 44.75681036710739, 42.60158881545067, 41.895214319229126, 39.96475450694561, 43.99227999150753, 41.71198055148125, 41.83751821517944, 41.824374720454216, 42.23105929791927, 40.19315265119076, 40.714222490787506, 41.45726501941681, 42.70730294287205, 40.759892240166664, 42.94691048562527, 40.484038442373276, 41.13910809159279, 39.70238618552685, 40.808085054159164, 40.12384817004204, 40.5161277204752, 39.90213766694069, 41.02012887597084, 41.4538262039423, 40.385346338152885, 42.154056429862976, 42.542494386434555, 42.20164507627487, 41.27810463309288, 41.31789989769459, 43.200459480285645, 42.72624492645264, 42.20009855926037, 43.15219447016716, 44.208446592092514, 45.54277539253235, 48.347484692931175, 49.19577397406101, 50.49245059490204, 51.47702716290951, 56.59849874675274, 56.11326478421688, 55.99250726401806, 56.092293709516525, 56.273015812039375, 51.765040308237076, 52.41384029388428, 55.63115045428276, 62.42978744208813, 65.39198309183121, 65.1163762807846, 10.231448784470558, 0.47129007638432086, 0.4110639909049496, 0.053378945667645894, 0.9979733428917825, 39.8843090236187, 62.366482838988304, 49.94578152894974, 42.06277392804623, 15.901585277169943, 33.793144673109055, 44.02658075094223, 44.68599356710911, 46.28412701189518, 10.470063630491495, 0.5758341634646058, 0.11924267804715782, 0.07367637663264759, 0.0416202094493201, 0.003948099938497762, 0.05117196174978744, 0.04216647466819268, 0.05381703915190883, 0.044638705876423046, 0.05764809080574196, 0.019008971685252618, 0.08267680226708762, 0.029895276202296373, 0.10678418562747538, 0.024474867059325334, 0.06831156919361092, 0.018909648206317797, 0.073777739162324, 0.14032372419023886, 0.11147553857881576, 12.450055684894323, 72.77668163180351, 57.1171785145998, 51.205911710858345, 29.595283828675747, 27.064733617007732, 42.53845140337944, 56.059657260775566, 62.786033526062965, 73.41674208641052, 5.250871265307069, 0.19234423903981224, 0.21122949285199866, 3.6244818242266774, 2.4091882864013314, 8.920332938432693, 80.24804592132568, 63.01720552146435, 71.38211846351624, 64.9042184650898, 67.235127389431, 64.10205870866776, 63.75829875469208, 58.44690956175327, 60.911377519369125, 52.72930696606636, 53.721494525671005, 49.45099487900734, 48.9546313136816, 47.49432407319546, 47.04619511961937, 45.833547189831734, 47.05252557992935, 45.52822217345238, 47.80267372727394, 44.988179951906204, 45.90015381574631, 43.936339393258095, 44.65160921216011, 44.265420734882355, 44.94386672973633, 44.542904645204544, 44.67048279941082, 43.82321186363697, 44.86864596605301, 43.91424357891083, 43.963694125413895, 42.51276858150959, 43.605061769485474, 41.325564086437225, 42.7367589622736, 44.02147762477398, 44.09914165735245, 46.17516785860062, 42.901210337877274, 44.3037910759449, 44.692988991737366, 43.00361484289169, 46.113854348659515, 43.01385149359703, 43.494708091020584, 44.39509637653828, 42.75737665593624, 41.99017122387886, 42.48957082629204, 41.93985812366009, 44.08032886683941, 47.158087715506554, 52.98844166100025, 54.84189860522747, 55.341450199484825, 50.14514923095703, 51.426011100411415, 48.43023285269737, 51.2097343057394, 51.409751772880554, 57.14952237904072, 52.341146394610405, 47.85541109740734, 58.62599015235901, 54.038245528936386, 47.90636256337166, 44.58835780620575, 44.97050330042839, 46.264212280511856, 44.8241351544857, 44.15239579975605, 47.800637036561966, 46.25375144183636, 47.655587419867516, 45.76121427118778, 46.48949459195137, 43.64998675882816, 42.50729687511921, 45.2778460085392, 44.0254370123148, 45.01798175275326, 44.48776200413704, 44.29602809250355, 43.206573352217674, 42.295838221907616, 43.44435319304466, 42.74163410067558, 43.014087080955505, 44.367483258247375, 43.37392017245293, 41.97440966963768, 41.459491699934006, 43.87215703725815, 40.66172070801258, 44.147813245654106, 42.402787283062935, 42.60860323905945, 43.83282154798508, 43.28972049057484, 43.384122624993324, 44.418651312589645, 43.085029274225235, 44.311607256531715, 43.64938259124756, 45.212816298007965, 44.26165133714676, 43.98414082825184, 45.550154596567154, 47.220335975289345, 46.88940793275833, 49.57737609744072, 50.453696474432945, 52.25245155394077, 53.39224599301815, 58.59747268259525, 57.39604935050011, 57.40347035229206, 58.86092774569988, 59.31665629148483, 55.43932154774666, 55.0885471701622, 57.638613134622574, 65.33771440386772, 65.58801457285881, 68.92396196722984, 12.103906609117985, 0.6103027076460421, 0.6702364166267216, 0.0919456998235546, 0.8151542278937995, 41.619580909609795, 66.5018579363823, 54.64682847261429, 37.53897987306118, 21.30874928086996, 41.554649993777275, 51.634593307971954, 53.00779402256012, 60.0256260484457, 17.290780283510685, 0.7458061678335071, 0.15882542124018073, 0.1314200894557871, 0.034837462080758996, 0.042898729516309686, 0.07744749615085311, 0.025749500127858482, 0.07191367942141369, 0.08054308316786774, 0.11334094902849756, 0.12861487513873726, 0.2810701756970957, 0.1636598602635786, 0.1555518968962133, 0.11694868473568931, 0.22404788236599416, 0.09641112075769342, 0.16178191493963823, 0.2704924636054784, 0.2112576796207577, 17.448454722762108, 84.68901962041855, 63.21140930056572, 62.394962310791016, 33.87211583554745, 39.25095520913601, 59.21153873205185, 63.14643658697605, 69.56703186035156, 80.267014503479, 7.245472585782409, 0.26898278680164367, 0.2096520728082396, 6.923857843503356, 8.972789123654366, 8.740676678717136, 84.03049975633621, 64.0049435198307, 73.25932413339615, 67.30799227952957, 69.55728158354759, 65.52610829472542, 65.06930440664291, 60.25929071009159, 63.86253476142883, 54.92522433400154, 55.5714176595211, 53.52058790624142, 51.097967103123665, 50.05704715847969, 48.98482069373131, 49.487890899181366, 49.2346952855587, 47.58958116173744, 51.49215795099735, 47.409402430057526, 50.15328459441662, 47.47663602232933, 47.9204636067152, 46.674198880791664, 47.07746744155884, 46.381743773818016, 47.79081076383591, 45.50771467387676, 47.828763127326965, 46.57056324183941, 46.77446790039539, 45.318754613399506, 44.93991494178772, 44.3879983574152, 46.46546848118305, 45.98808489739895, 46.805991008877754, 48.42470794916153, 45.29095530509949, 46.27739757299423, 46.497569158673286, 45.46294167637825, 49.22812923789024, 44.46112543344498, 46.529012471437454, 47.379038259387016, 46.47577352821827, 42.76501804590225, 46.46245524287224, 43.289093524217606, 45.911032631993294, 49.18468236923218, 55.57801030576229, 59.96974244713783, 58.005529046058655, 51.96372024714947, 54.1706608235836, 52.89606861770153, 52.52669803798199, 55.791897028684616, 58.97337131202221, 55.144255980849266, 49.3106684088707, 62.62576572597027, 57.76204191148281, 52.536265924572945, 48.107747957110405, 46.8986452370882, 50.054949671030045, 48.64693142473698, 47.164459973573685, 50.65849408507347, 49.1087282449007, 49.82658192515373, 48.73108550906181, 48.2516348361969, 47.25649103522301, 46.24713219702244, 48.60436990857124, 46.522701010107994, 46.36485368013382, 45.53255774080753, 46.038777977228165, 45.267198979854584, 44.27748888731003, 45.2097574621439, 45.40877938270569, 44.627826288342476, 48.095356822013855, 46.04166962206364, 44.90347869694233, 44.03812453150749, 46.04149483144283, 43.728520944714546, 45.610738545656204, 43.67070324718952, 47.01916716992855, 47.04770363867283, 45.95366634428501, 45.70466570556164, 46.83583080768585, 47.02249959111214, 46.29746429622173, 45.119569301605225, 48.59508700668812, 46.13248474895954, 46.955087408423424, 49.08353939652443, 50.2644058316946, 50.44076196849346, 53.10555137693882, 54.81016270816326, 55.95573663711548, 56.170010939240456, 61.055670976638794, 60.56741617619991, 62.921230271458626, 62.42597244679928, 63.19057881832123, 59.10658836364746, 58.78221116960049, 61.086430326104164, 69.16988477110863, 69.2899127304554, 72.97237113118172, 12.849104572087526, 1.241607719566673, 1.8606062605977058, 0.17636817443417385, 1.3652511849068105, 47.87867724895477, 73.38210314512253, 67.63359680771828, 55.399666875600815, 25.465908609330654, 45.19273817539215, 61.713149696588516, 61.26271426677704, 76.56937211751938, 22.389688678085804, 0.895627437857911, 0.32723416574299335, 0.29398969025351107, 0.10205788494204171, 0.12012318431516178, 0.11090686792158522, 0.16720465442631394, 0.30055021634325385, 0.16685640905052423, 0.18880054325563833], [0.009643139437685022, 0.006732032707077451, 0.05715611740015447, 0.0344177515944466, 0.04529744357569143, 0.1273903314722702, 0.023332547789323144, 0.011818823277280899, 0.06892255711136386, 0.09081990632694215, 14.442948047071695, 63.02264682948589, 54.17490519583225, 43.18715259432793, 23.84889777749777, 30.419801585376263, 39.36795853078365, 49.04070049524307, 67.72861450910568, 41.55145816504955, 0.7855415856465697, 0.07111372586223297, 0.038471670195576735, 0.4227474139770493, 0.921792893204838, 28.360312096774578, 78.5929687321186, 62.57626958191395, 68.4214237332344, 61.06954403221607, 63.49263980984688, 59.77415554225445, 62.77746118605137, 57.819095849990845, 56.21182769536972, 52.51789391040802, 50.21314278244972, 45.49692325294018, 44.77373085916042, 41.59131422638893, 43.26437585055828, 41.49039924144745, 44.40342552959919, 40.816490203142166, 43.71637299656868, 41.64670005440712, 43.34113933146, 41.659250780940056, 42.43055619299412, 44.226172640919685, 41.257106959819794, 43.45891401171684, 45.20208187401295, 40.778363049030304, 41.59435786306858, 40.6050581485033, 40.0665358453989, 40.01267373561859, 41.074773743748665, 41.06372393667698, 40.381367951631546, 40.462805181741714, 42.43056759238243, 40.79274907708168, 41.07290804386139, 40.98825238645077, 42.33667083084583, 42.78519496321678, 43.37735518813133, 42.39549167454243, 40.71407429873943, 40.470651760697365, 39.10055547952652, 40.70680148899555, 41.055968552827835, 39.90211486816406, 41.713420674204826, 45.54579623043537, 51.99043281376362, 49.95164081454277, 52.22095504403114, 49.10813927650452, 47.320236414670944, 45.441130846738815, 46.22749485075474, 49.54601638019085, 55.60421749949455, 51.777841821312904, 44.91328217089176, 55.299036875367165, 52.77078174054623, 49.065159782767296, 42.87952110171318, 45.083828419446945, 44.255336076021194, 44.4608860462904, 46.04195840656757, 45.614040568470955, 45.65461479127407, 44.75694335997105, 45.78793823719025, 43.9311982691288, 38.95324118435383, 42.56080560386181, 42.41268955171108, 42.45392493903637, 41.91583201289177, 42.01803132891655, 42.60295674204826, 40.534853115677834, 41.27026945352554, 41.33493818342686, 41.915098652243614, 42.707147151231766, 42.18280948698521, 39.9998190253973, 39.94953632354736, 40.5242744833231, 41.428131982684135, 40.499370619654655, 40.14712192118168, 40.805170610547066, 41.56809367239475, 41.56968578696251, 42.89138786494732, 41.03862628340721, 42.27625787258148, 42.06747427582741, 43.265785574913025, 42.43990749120712, 41.25440530478954, 39.66463901102543, 41.93795442581177, 42.62503735721111, 42.85310871899128, 43.57079140841961, 43.76745745539665, 45.26833891868591, 47.32164613902569, 49.52278822660446, 52.8303549438715, 54.63452473282814, 56.47499397397041, 55.077702552080154, 54.540741965174675, 50.01633994281292, 51.12163603305817, 53.99672895669937, 61.01250909268856, 62.856933921575546, 70.22713243961334, 25.55556859821081, 0.14956807892303914, 0.18466957117198035, 0.04327013732108753, 0.08797814865829423, 28.48006647080183, 68.11436980962753, 43.99884603917599, 43.18367198109627, 19.189701788127422, 31.33996970951557, 41.07345141470432, 41.374604254961014, 40.91823734343052, 18.045528084039688, 1.4604796562343836, 0.059042779248557054, 0.031816078699193895, 0.0776278306148015, 0.11244001143495552, 0.03457484570390079, 0.02260658820887329, 0.02373846546106506, 0.04271648773283232, 0.10277631357894279, 0.006875825674796943, 0.035236448093201034, 0.07666409248486161, 0.027302646376483608, 0.03008906580362236, 0.03355418113642372, 0.04785567485669162, 0.015760157148179132, 0.13553230004617944, 0.04511520921369083, 20.791918113827705, 73.15264105796814, 58.948851227760315, 56.11779034137726, 31.81086514145136, 28.131292685866356, 38.00028271973133, 53.821550756692886, 73.04150462150574, 50.155237689614296, 0.9481726214289665, 0.05216514829953667, 0.327107822522521, 1.5312733012251556, 0.6860053329728544, 30.643221996724606, 80.44676005840302, 65.01919269561768, 70.61288014054298, 62.76943601667881, 64.522285759449, 63.32969695329666, 65.43539956212044, 59.45686876773834, 59.10210840404034, 55.68411581218243, 53.27046252787113, 48.32885429263115, 47.234304025769234, 43.36102366447449, 45.51447831094265, 43.76737006008625, 45.15268072485924, 43.252801671624184, 46.36625200510025, 43.62628363072872, 44.81691174209118, 42.97844119369984, 44.79367978870869, 44.91305038332939, 44.929191917181015, 46.108709424734116, 46.07856184244156, 44.314016327261925, 43.62052693963051, 43.112273812294006, 42.247037440538406, 41.781087443232536, 43.04395727813244, 42.79613837599754, 42.228008061647415, 42.241736724972725, 44.919434040784836, 42.88367047905922, 43.32946255803108, 43.11994560062885, 43.79131257534027, 44.36103880405426, 44.48545552790165, 44.3591845035553, 43.434545919299126, 42.90766999125481, 43.203924894332886, 43.0478672683239, 43.28584469854832, 42.56902076303959, 44.26216810941696, 45.952435210347176, 53.478052988648415, 54.795183911919594, 53.9502764493227, 51.94497585296631, 50.47793537378311, 47.950831577181816, 49.568617567420006, 52.71199129521847, 57.13817238807678, 53.885090947151184, 47.74759568274021, 58.057905435562134, 55.89456371963024, 51.21414206922054, 45.48578605055809, 46.937536150217056, 46.369033455848694, 45.99039137363434, 47.03528970479965, 48.729208409786224, 47.879923582077026, 46.33005894720554, 48.55498015880585, 45.49598850309849, 43.504321575164795, 43.670619651675224, 44.24998216331005, 46.00945495069027, 43.263779282569885, 44.84203219413757, 45.227513909339905, 42.65260107815266, 42.9318480938673, 41.938740983605385, 43.559186831116676, 44.20965872704983, 44.26050379872322, 42.14582987129688, 42.40553453564644, 42.09545977413654, 42.9976187646389, 41.801727935671806, 41.28202602267265, 42.72780284285545, 43.17836366593838, 43.62421654164791, 43.99136424064636, 42.724356427788734, 44.30041305720806, 44.22288581728935, 44.92677144706249, 42.97426901757717, 43.186962604522705, 43.39786268770695, 43.89013007283211, 45.88666453957558, 45.69129802286625, 46.888613775372505, 46.82805262506008, 47.789625227451324, 48.8461547344923, 51.26012720167637, 53.875298872590065, 56.70362010598183, 58.020382449030876, 56.795620769262314, 57.20503360033035, 52.271678522229195, 53.38250711560249, 57.72236444056034, 64.8363921046257, 66.48615717887878, 72.14027658104897, 29.9256457015872, 0.319197389180772, 0.5872346798423678, 0.14702600048622116, 0.11834794480819255, 30.767330937087536, 74.37673777341843, 51.33070841431618, 43.065923899412155, 22.933297008275986, 39.097842425107956, 46.68038874864578, 50.522024407982826, 52.70904265344143, 26.01877324283123, 2.084288620389998, 0.12493812711909413, 0.05068027036031708, 0.04965703425114043, 0.024392544328293297, 0.04811892948055174, 0.012221642482472816, 0.04017580453364644, 0.03330944680783432, 0.05970083046122454, 0.10288811812642962, 0.09055032118340023, 0.32364427868742496, 0.10154765099287033, 0.10495260226889513, 0.20162406843155622, 0.19099692930467427, 0.06790237865061499, 0.22555493196705356, 0.24529332906240597, 29.268292374908924, 84.99070063233376, 69.26948502659798, 60.60559272766113, 35.23822233080864, 43.64013008773327, 51.51091754436493, 62.42725297808647, 78.9150470495224, 53.43656301498413, 1.8107810779474676, 0.15568637405522168, 0.9006195981055498, 6.225468618795276, 3.395705600269139, 33.60167674720287, 83.03265050053596, 66.08618304133415, 75.22735252976418, 64.80344787240028, 67.90406629443169, 64.989805072546, 68.26390698552132, 61.652976125478745, 61.380732133984566, 57.41759419441223, 55.11611469089985, 51.01298466324806, 49.83939863741398, 46.92198358476162, 48.92591245472431, 46.715514063835144, 48.84943015873432, 45.27826018631458, 49.215935692191124, 45.71465536952019, 48.99149693548679, 45.10989502072334, 47.15475529432297, 49.97849777340889, 45.815239772200584, 48.098153471946716, 47.5972643494606, 47.01368786394596, 46.40968747437, 45.528134778141975, 41.874186247587204, 44.539663419127464, 45.69722190499306, 45.027644634246826, 43.86802665889263, 44.91393953561783, 48.76384735107422, 45.10549105703831, 45.315194204449654, 45.010355561971664, 46.02039456367493, 47.604453563690186, 46.771511659026146, 46.21303282678127, 45.56503839790821, 45.61830393970013, 45.52566111087799, 44.830097034573555, 46.025718078017235, 44.43680293858051, 46.28497816622257, 50.91675102710724, 56.92251116037369, 56.68840952217579, 57.016578912734985, 55.72234936058521, 54.40706893801689, 50.3005076944828, 51.12461507320404, 55.97819343209267, 61.2940663844347, 57.28157289326191, 49.76447805762291, 59.47128899395466, 58.270648419857025, 53.88048179447651, 46.461079716682434, 50.715848207473755, 48.658661395311356, 48.84189896285534, 51.55613511800766, 49.708168879151344, 51.140517219901085, 48.13002236187458, 51.72876365482807, 48.23300063610077, 43.71319256722927, 47.37284459173679, 47.50565506517887, 48.56062665581703, 44.13587808609009, 45.948426425457, 46.77073270082474, 44.5988604426384, 45.15873000025749, 45.474257469177246, 46.12659886479378, 48.178621754050255, 45.42563147842884, 44.85726177692413, 45.90398021042347, 44.829188883304596, 47.6383363455534, 44.33821342885494, 44.11944016814232, 45.96298344433308, 46.374144181609154, 45.569176375865936, 48.05737026035786, 46.0677932202816, 45.701310485601425, 45.11497914791107, 46.55925504863262, 45.665379613637924, 46.05547808110714, 44.91484768688679, 46.72424599528313, 48.92772875726223, 49.33774195611477, 50.4790373146534, 48.952233642339706, 50.56250363588333, 52.29709915816784, 53.971460312604904, 57.89378844201565, 60.48038184642792, 61.39895975589752, 58.995584920048714, 60.67640572786331, 56.31382182240486, 57.60154992341995, 60.40872149169445, 67.78214603662491, 70.32658830285072, 73.59006598591805, 31.076039671897888, 0.660669895587489, 2.325672567822039, 0.45887887361459434, 0.4124578332994133, 34.894439578056335, 79.25217255949974, 58.645391911268234, 57.61352688074112, 28.243791349232197, 42.94892057776451, 57.25000038743019, 59.95971478521824, 67.25797936320305, 36.23092666268349, 3.153613703325391, 0.30083193560130894, 0.1488666603108868, 0.14043461589608341, 0.22578293457627296, 0.12929465272463858, 0.10637161831255071, 0.09306307736551389, 0.09262098741601221, 0.10237357229925692], [0.06796704197768122, 0.060327203100314364, 0.041607418534113094, 0.038591178235947154, 0.08345398673554882, 0.04864812901359983, 0.11628726046183147, 0.01489964433858404, 0.04564988579659257, 0.18515817151637748, 29.389914348721504, 61.26881293952465, 49.15287047624588, 34.3070062994957, 40.604723766446114, 42.56505757570267, 34.241250827908516, 53.29687871038914, 65.1769146323204, 41.234855353832245, 0.4604871373157948, 0.057530471531208605, 0.23788491409504786, 2.486910978332162, 0.3422462992602959, 50.12970305979252, 70.4139456152916, 62.00356051325798, 62.258606627583504, 60.614503249526024, 58.173259645700455, 60.61198778450489, 58.21846581995487, 56.445556953549385, 52.893826737999916, 49.89201061427593, 45.0564356893301, 43.98197114467621, 44.31872807443142, 41.494256034493446, 41.36827379465103, 42.91977994143963, 41.513274013996124, 40.510298833251, 42.15178035199642, 42.99206346273422, 41.60019055008888, 42.38133743405342, 42.61228904128075, 43.35231073200703, 40.962018594145775, 41.831921115517616, 42.323664128780365, 42.63102203607559, 41.88290297985077, 41.70546010136604, 39.886740893125534, 39.40037079155445, 39.07345153391361, 40.91741278767586, 41.215388998389244, 41.46071903407574, 40.28580687940121, 39.64696615934372, 43.20300914347172, 42.03450724482536, 41.51683062314987, 42.321262657642365, 41.9073698669672, 42.60479584336281, 40.23437283933163, 40.82977809011936, 39.764186069369316, 38.869090899825096, 37.982818856835365, 39.36192825436592, 40.70895977318287, 42.79300734400749, 47.25899510085583, 48.54371376335621, 48.38188424706459, 49.48161743581295, 47.26717226207256, 45.7444191724062, 43.89954976737499, 49.93120551109314, 54.89092357456684, 53.19972552359104, 39.01780351996422, 52.627943605184555, 51.53463587164879, 51.74887977540493, 42.79176481068134, 44.7485838085413, 45.875455141067505, 45.70770554244518, 46.12238109111786, 46.563400626182556, 46.785050332546234, 45.87121456861496, 45.54795831441879, 42.95472286641598, 41.8783014267683, 43.598605915904045, 42.186187505722046, 43.18722479045391, 41.66951023042202, 42.10892625153065, 41.74740985035896, 41.40010088682175, 40.81514127552509, 43.14951941370964, 41.8351661413908, 40.69369979202747, 40.686343386769295, 40.66805496811867, 40.51101319491863, 38.690116703510284, 39.03334088623524, 40.097580179572105, 41.26061797142029, 39.808054715394974, 41.649242118000984, 40.83889380097389, 41.47600561380386, 41.50315135717392, 42.05748461186886, 41.73532649874687, 41.97075426578522, 40.95419101417065, 40.879798606038094, 41.21980436146259, 40.62645860016346, 41.380949914455414, 42.22116842865944, 43.060076013207436, 44.03141029179096, 42.87714242935181, 45.363018438220024, 47.502398639917374, 50.44216029345989, 50.970556139945984, 51.530250906944275, 50.66901192069054, 50.401935651898384, 48.42424437403679, 50.26269972324371, 55.47178700566292, 61.65286973118782, 61.36390283703804, 69.4747956097126, 44.848001673817635, 1.1780666979029775, 0.63334621489048, 0.396114939940162, 0.01940322465088684, 14.75889254361391, 68.17671686410904, 52.72769205272198, 44.851843267679214, 28.742531687021255, 24.4132149964571, 46.56386040151119, 41.87245354056358, 41.15541681647301, 31.192246936261654, 4.198651676997542, 0.23657293058931828, 0.037439175794133916, 0.027502972443471663, 0.007219923372758785, 0.0504180473217275, 0.0265508043958107, 0.020480719176703133, 0.027807830010715406, 0.027600323664955795, 0.030549497932952363, 0.0618778019270394, 0.01449756913643796, 0.07335467787925154, 0.09251431853044778, 0.031948359101079404, 0.05487727132276632, 0.03943146381061524, 0.043966858138446696, 0.5858069064561278, 38.97710770368576, 69.8853787779808, 54.19945187866688, 39.45991359651089, 41.324663534760475, 39.36926566064358, 39.82388846576214, 60.10294429957867, 71.4160430431366, 45.11736921966076, 0.2994319482240826, 0.07855118848965503, 1.1687094625085592, 2.9063148982822895, 0.38912325573619455, 53.28679785132408, 73.61483305692673, 63.40354599058628, 64.96063023805618, 62.260400131344795, 61.21900141239166, 62.46777780354023, 60.261961966753006, 57.296430096030235, 54.144354835152626, 51.72635838389397, 47.66906909644604, 45.826285779476166, 46.629410684108734, 44.86708804965019, 44.847462102770805, 44.692833200097084, 43.54321248829365, 43.50766159594059, 44.71016027033329, 44.22433353960514, 43.05882208049297, 45.64422994852066, 44.34527724981308, 44.5041923224926, 42.894446700811386, 43.63359823822975, 43.950402438640594, 44.859594851732254, 44.601611495018005, 44.20166015625, 42.91421703994274, 42.219732105731964, 42.05428898334503, 43.38158056139946, 43.32543857395649, 44.516477063298225, 42.47016526758671, 42.26553864777088, 45.680635794997215, 43.69678884744644, 44.767514392733574, 45.00642277300358, 45.16540624201298, 44.59535323083401, 42.10932523012161, 42.10345074534416, 42.873186841607094, 41.41321778297424, 41.14302948117256, 40.615211203694344, 42.85995215177536, 46.52525447309017, 50.10763384401798, 50.10978452861309, 51.21112883090973, 51.02766327559948, 50.39279334247112, 46.65105052292347, 46.2613320350647, 52.3476592451334, 57.39709809422493, 54.494023472070694, 41.121636629104614, 56.69704645872116, 56.13859802484512, 54.66661401093006, 44.736584052443504, 47.85771757364273, 47.36721709370613, 47.120975106954575, 48.23291704058647, 49.910595417022705, 48.03010292351246, 47.10954152047634, 47.5895431637764, 44.648139998316765, 43.57391484081745, 43.817496970295906, 43.918769136071205, 44.48054999113083, 42.79933400452137, 43.96124325692654, 42.825157418847084, 42.01803132891655, 41.674978137016296, 42.68327683210373, 43.94950568675995, 42.747493386268616, 42.28089362382889, 43.89366388320923, 44.07714083790779, 42.374626994132996, 41.43600516021252, 41.488218158483505, 42.44500681757927, 42.61364936828613, 43.05375315248966, 43.37053835391998, 42.4499237537384, 42.31807462871075, 44.466783329844475, 44.540753960609436, 42.83976763486862, 43.51623393595219, 43.72874893248081, 43.97423475980759, 44.79056015610695, 44.4006060808897, 45.06067246198654, 45.56842401623726, 46.919981092214584, 45.56369327008724, 46.89111404120922, 50.71034990251064, 53.07572677731514, 52.99919508397579, 54.731985703110695, 52.497112825512886, 53.51783685386181, 51.437072306871414, 53.202240988612175, 56.47128917276859, 64.10139754414558, 64.96131420135498, 70.23649513721466, 48.854442089796066, 2.010972504504025, 0.8946686424314976, 0.6034027528949082, 0.0701395382930059, 15.530521888285875, 72.90977329015732, 58.90104599297047, 42.91097201406956, 27.151137180626392, 32.3536679148674, 52.54031650722027, 50.45387886464596, 53.054987490177155, 45.18402524292469, 6.092646270990372, 0.09324198690592311, 0.04724116173747461, 0.07837680605007336, 0.09283375373343006, 0.07455899802152999, 0.09092049702303484, 0.0262599029156263, 0.032789820979814976, 0.07182658097008243, 0.10810911218868569, 0.14216895564459264, 0.08994248739327304, 0.07692558821872808, 0.3153054480208084, 0.12239546238561161, 0.1860699147800915, 0.09466374889598228, 0.10427356683067046, 1.187373585999012, 52.13596120476723, 78.2203683257103, 66.33158147335052, 46.346344873309135, 49.06778924167156, 50.12152589857578, 47.10430160164833, 67.91092872619629, 77.37189665436745, 48.84992033243179, 1.0919267451390624, 0.1786720086238347, 1.7284872313030064, 9.319296330213547, 1.0910899587906897, 58.84409844875336, 75.68251490592957, 68.77966091036797, 68.44920784235, 66.18731081485748, 63.04571159183979, 65.93653947114944, 63.91614228487015, 60.81072472035885, 58.21601115167141, 54.65837225317955, 49.11237984895706, 48.86729680001736, 49.99919146299362, 47.39168398082256, 46.036539897322655, 48.439625948667526, 46.552518010139465, 45.87530694901943, 46.37936510145664, 47.5751381367445, 45.793588533997536, 48.31999696791172, 47.423131093382835, 46.31773240864277, 43.63109037280083, 47.59167864918709, 47.18339055776596, 46.361813843250275, 45.47520361840725, 47.71896801888943, 44.83950912952423, 44.486014097929, 43.78075674176216, 45.73543265461922, 46.524836495518684, 47.543345242738724, 43.99799108505249, 43.446731865406036, 46.949608102440834, 47.16460816562176, 46.638150215148926, 47.75594383478165, 46.97146832942963, 48.10853451490402, 45.24239771068096, 45.3885492682457, 45.86566686630249, 43.577304258942604, 41.05638653039932, 44.55843821167946, 43.65770414471626, 48.813940063118935, 50.68013392388821, 52.61180207133293, 53.46717797219753, 54.799625873565674, 53.031371757388115, 48.36126655340195, 48.576502203941345, 56.234770864248276, 59.85910378396511, 57.394734621047974, 43.939580619335175, 58.26430656015873, 57.029331028461456, 58.14416840672493, 46.761605590581894, 49.561439752578735, 50.08143424987793, 50.25057077407837, 51.78966298699379, 51.69092148542404, 49.90193948149681, 48.41299697756767, 50.45555077493191, 47.464290484786034, 45.6718734651804, 47.7938088029623, 46.62474073469639, 48.36213290691376, 46.55159465968609, 46.57164238393307, 45.34983694553375, 44.94574382901192, 45.63453286886215, 46.03000424802303, 46.710927709937096, 45.08683405816555, 44.71954956650734, 46.603686064481735, 45.82758530974388, 42.92156204581261, 42.62018121778965, 43.384559601545334, 45.80252565443516, 44.92829516530037, 46.39502786099911, 45.976556316018105, 44.873692095279694, 45.314954817295074, 45.21150916814804, 47.36737288534641, 46.264193281531334, 46.10942758619785, 46.73002928495407, 47.123049795627594, 48.006707578897476, 46.597545593976974, 47.51737363636494, 50.1455520093441, 50.006080493330956, 48.27064521610737, 50.239935144782066, 53.300195932388306, 56.44440941512585, 55.2773742377758, 57.12114170193672, 56.59531831741333, 55.46300947666168, 53.251934722065926, 56.85490898787975, 59.46395918726921, 66.58128887414932, 69.12815541028976, 74.30851623415947, 50.89993692934513, 2.4649272579699755, 2.231786730699241, 0.9906457923352718, 0.1893820901750587, 19.140148647129536, 80.12739479541779, 65.01139551401138, 58.37313272058964, 39.45087008178234, 34.07380521297455, 59.35228317975998, 61.15031249821186, 62.91159778833389, 57.48759403824806, 8.574120216071606, 0.4197746078716591, 0.1444596835062839, 0.19843669258989394, 0.13041820493526757, 0.18704067362705246, 0.13676735252374783, 0.1064512507582549, 0.16504533123224974, 0.15724008990218863], [0.01590411709912587, 0.08983932886621915, 0.04270041281415615, 0.08517529437085614, 0.021851131969015114, 0.018161440893891267, 0.04820825066417456, 0.032228033742285334, 0.026639285097189713, 1.0180913633666933, 45.13915345072746, 59.2570298910141, 55.72605416178703, 47.7701360732317, 26.862894147634506, 29.269143529236317, 36.559962406754494, 58.20206969976425, 66.54795706272125, 31.903354078531265, 0.2708978543523699, 0.08827684083371423, 0.04995196373783983, 0.03418400476220995, 11.018242165446281, 67.52484664320946, 65.88275715708733, 63.66592951118946, 59.80641581118107, 50.92082440853119, 50.071421787142754, 51.89022459089756, 48.76046173274517, 48.159189596772194, 43.62414054572582, 45.681802332401276, 43.4790263324976, 43.29698570072651, 43.508223965764046, 41.092583388090134, 40.45338548719883, 43.121697306632996, 39.69498798251152, 40.945493280887604, 38.94118443131447, 41.481872498989105, 42.44394287467003, 41.25013813376427, 42.7882120013237, 39.44890558719635, 41.65202736854553, 43.23882222175598, 41.52407303452492, 40.696257054805756, 41.527663841843605, 41.37573279440403, 40.631907507777214, 38.97016927599907, 40.33138543367386, 42.598096802830696, 41.45520552992821, 40.65122567117214, 42.3645993322134, 40.41008681058884, 42.473968863487244, 42.76727892458439, 41.32966786623001, 43.51499140262604, 43.2743389159441, 42.60423347353935, 42.24315024912357, 41.0159756988287, 41.549839451909065, 40.76167054474354, 40.8349534124136, 41.62313371896744, 40.08691035211086, 45.370291247963905, 46.661705151200294, 46.68787054717541, 47.720628529787064, 45.04998743534088, 44.40173462033272, 44.43962998688221, 43.17662715911865, 51.816337555646896, 54.63204726576805, 53.8326271623373, 34.22676220536232, 54.430696070194244, 54.23792861402035, 52.54427209496498, 46.1240454018116, 42.68235348165035, 44.82366017997265, 45.55857874453068, 47.07054041326046, 45.25884322822094, 44.21734191477299, 45.07885828614235, 45.26581585407257, 41.73412576317787, 41.131079122424126, 41.438429430127144, 42.142531648278236, 42.1512483805418, 41.60215124487877, 42.02671006321907, 40.78563205897808, 40.757456570863724, 39.74780514836311, 42.14016817510128, 41.64257727563381, 41.67582929134369, 40.004306584596634, 40.121762081980705, 39.95730310678482, 39.75679166615009, 40.21291919052601, 40.53950406610966, 40.290195643901825, 41.103055626153946, 41.46680250763893, 39.02796417474747, 40.31068034470081, 41.10528990626335, 43.386592492461205, 43.61329212784767, 43.74217361211777, 42.430537194013596, 40.593225583434105, 39.89920422434807, 41.258531883358955, 41.78007289767265, 42.2899067401886, 44.449023082852364, 41.86788618564606, 41.58110797405243, 43.7508599460125, 47.67824560403824, 46.709753572940826, 49.20705556869507, 45.76208062469959, 46.579640954732895, 45.49294866621494, 45.276915058493614, 47.46960259974003, 49.79993395507336, 59.90480773150921, 60.49570642411709, 68.41800391674042, 58.21240894496441, 5.523051610216498, 0.2514139545382932, 2.321872771717608, 0.09506111702648923, 5.4914838541299105, 61.56906142830849, 58.03335875272751, 50.19135095179081, 35.78815922141075, 14.576340839266777, 37.22601726651192, 40.527204126119614, 45.17326042056084, 40.58579698204994, 7.551420293748379, 0.4110490588936955, 0.037513513016165234, 0.04135793446039315, 0.04612089353031479, 0.0593861450033728, 0.03283305108197965, 0.022662527590000536, 0.018758587757474743, 0.037834031754755415, 0.021745268313679844, 0.03644242693553679, 0.024293920323543716, 0.06186006459756754, 0.014148994432616746, 0.028245769499335438, 0.05313061563356314, 0.0203297199550434, 0.031667215007473715, 2.1137712383642793, 58.69120605289936, 63.95976394414902, 65.13887107372284, 48.62237334251404, 40.32751344144344, 39.16659213602543, 40.61885140836239, 63.63207332789898, 71.45066678524017, 36.43761657178402, 0.14924448769306764, 0.07524112821556628, 0.6760856683831662, 1.003599059768021, 12.949866615235806, 69.06596794724464, 68.98011535406113, 66.83362573385239, 61.794852912425995, 54.525178000330925, 53.10454823076725, 53.733011707663536, 50.722433254122734, 50.76078839600086, 46.50677226483822, 47.65203461050987, 45.626629292964935, 46.73393927514553, 44.952233880758286, 44.28494028747082, 44.141980558633804, 45.108781680464745, 41.82397574186325, 40.30682735145092, 42.3527667671442, 43.22489596903324, 43.77389430999756, 44.39051002264023, 43.92903618514538, 42.00184039771557, 44.74016346037388, 44.53791171312332, 43.775554820895195, 42.69273832440376, 43.92520599067211, 42.50706888735294, 43.2633651047945, 40.20000368356705, 42.33677722513676, 43.68899166584015, 43.424837440252304, 42.669380977749825, 44.191142320632935, 43.19328546524048, 44.996018931269646, 43.80720712244511, 43.66192951798439, 45.32796531915665, 44.06263701617718, 45.20428575575352, 43.11864607036114, 44.30519700050354, 43.97853992879391, 43.83578158915043, 43.44497635960579, 43.10679450631142, 42.61708438396454, 46.58374473452568, 48.17419499158859, 50.531208515167236, 50.00681385397911, 47.60170251131058, 47.270869463682175, 46.14856168627739, 45.688911750912666, 53.332205414772034, 56.25501997768879, 56.82280831038952, 37.761279344558716, 55.92190325260162, 56.11081771552563, 55.739243254065514, 49.62398059666157, 46.056538224220276, 47.52131022512913, 47.21577621996403, 49.261582642793655, 47.89431340992451, 48.32927606999874, 48.60394433140755, 47.80557297170162, 44.978087693452835, 43.38851138949394, 43.82112197577953, 43.15132811665535, 41.79644621908665, 43.57244051992893, 44.980052188038826, 42.33776517212391, 42.594570592045784, 41.86761260032654, 44.48752261698246, 42.98965819180012, 44.621188044548035, 41.42037279903889, 43.03122416138649, 42.0004952698946, 42.52293303608894, 41.6909296810627, 42.52680882811546, 42.65743441879749, 43.16392444074154, 43.24783153831959, 41.86250567436218, 41.93694368004799, 44.15019191801548, 45.36746799945831, 45.756593719124794, 43.95637571811676, 43.773487731814384, 42.340907603502274, 42.86387354135513, 43.19520056247711, 43.62016215920448, 44.90980535745621, 46.06133736670017, 44.89603869616985, 43.425756990909576, 46.36489927768707, 48.69100145995617, 49.41694490611553, 50.9270940721035, 47.95268587768078, 48.87377545237541, 47.84693755209446, 47.76315204799175, 49.585089683532715, 53.498666882514954, 60.72677202522755, 63.3033187687397, 70.05807191133499, 62.43306666612625, 6.8492236733436584, 0.8423716924153268, 4.3458757270127535, 0.1986318180570379, 6.311594797298312, 64.96569156646729, 64.78008672595024, 52.928332686424255, 33.34845833480358, 17.60874342173338, 44.362570121884346, 47.82980427145958, 54.4557823240757, 52.09738187491894, 10.935186222195625, 0.5168997414875776, 0.07210608120658435, 0.031150821232586168, 0.028229839299456216, 0.07471100470866077, 0.10281489783665165, 0.03954890125896782, 0.013468194538290845, 0.010372150172770489, 0.09606309802620672, 0.21768130915006623, 0.13630437111714855, 0.1360123953782022, 0.14284610602771863, 0.17295117810135707, 0.10458693126565777, 0.11424052107031457, 0.1559690581052564, 3.867175276391208, 71.85092970728874, 73.23958799242973, 74.92279887199402, 58.92151929438114, 40.615203604102135, 37.543494030833244, 51.85580983757973, 69.61109429597855, 79.09653291106224, 42.26837329566479, 0.6742961425334215, 0.1943560381187126, 1.06165578821674, 4.902844140306115, 13.620307389646769, 74.36590075492859, 69.30610746145248, 70.07157638669014, 63.55112247169018, 56.53188832104206, 58.08210253715515, 57.46587820351124, 52.01671600341797, 53.18843632936478, 49.005278795957565, 50.66607467830181, 47.7579615265131, 48.67648243904114, 48.52699086070061, 45.41574440896511, 46.20099887251854, 48.321596682071686, 43.95227573812008, 44.31094989180565, 43.47357362508774, 46.691419556736946, 45.69910280406475, 45.016898810863495, 47.05606319010258, 43.46620962023735, 46.42655476927757, 47.813962921500206, 45.29893107712269, 45.34518599510193, 46.55260540544987, 44.808951169252396, 45.29359996318817, 42.58066713809967, 44.585055783391, 47.125014290213585, 45.64175248146057, 45.553920194506645, 47.306944727897644, 45.28612956404686, 46.98016606271267, 47.969583570957184, 45.698213651776314, 48.81032645702362, 46.78943529725075, 47.823918387293816, 46.110183745622635, 46.96426011621952, 47.61366046965122, 46.26767389476299, 46.19981333613396, 44.9717952311039, 44.182851165533066, 49.73946399986744, 50.883913189172745, 51.69385492801666, 52.22706891596317, 49.61994141340256, 49.897193536162376, 48.6078505218029, 47.60945029556751, 55.409759134054184, 59.0361325442791, 57.51706525683403, 38.983286172151566, 56.62287063896656, 58.31341132521629, 58.73517729341984, 52.881838381290436, 48.44447448849678, 50.599243864417076, 50.305010452866554, 53.37243765592575, 51.041011959314346, 50.07497079670429, 50.39678692817688, 49.71552528440952, 46.033735647797585, 46.31133735179901, 46.12356662750244, 45.88808186352253, 44.56268638372421, 46.88014782965183, 45.54844468832016, 44.48701724410057, 44.67627368867397, 44.26739662885666, 47.10194572806358, 45.987473130226135, 47.68290415406227, 43.69625687599182, 45.47472104430199, 44.45084698498249, 45.804676339030266, 45.067656487226486, 45.90423099696636, 45.49177832901478, 46.22238792479038, 46.9926255941391, 44.57778297364712, 44.507422149181366, 46.494814306497574, 48.93341325223446, 48.50801467895508, 48.106649816036224, 46.759865283966064, 44.36523757874966, 46.67112484574318, 45.50099663436413, 46.18690922856331, 47.388659343123436, 49.653250426054, 46.61764271557331, 46.08248323202133, 47.70710505545139, 52.54323475062847, 51.903083100914955, 55.767422541975975, 50.302342996001244, 53.72925750911236, 50.25063917040825, 49.31139416992664, 51.94430708885193, 55.99021598696709, 63.77787530422211, 68.5181513428688, 73.39043989777565, 66.31865456700325, 7.329359734430909, 2.167321527376771, 4.146916503086686, 0.24488088791258633, 7.349098725244403, 72.49095976352692, 68.81495341658592, 68.95560666918755, 46.395153254270554, 20.897879227995872, 52.53055103123188, 58.57605703175068, 63.87658640742302, 68.59595596790314, 15.292246174067259, 0.7012032705824822, 0.17252252844627947, 0.21094220748636872, 0.1859555795090273, 0.19773132575210184, 0.22158830106491223, 0.15968021209118888, 0.08279011337435804, 0.08390036629862152], [0.015103670939424774, 0.016611476603429765, 0.03092632341576973, 0.08444837556453422, 0.03204106818884611, 0.04287160772946663, 0.03995223254605662, 0.03915449800842907, 0.08472496658214368, 4.836835982277989, 56.51632435619831, 54.75784331560135, 49.35932859778404, 21.26023918390274, 11.009894963353872, 27.998581007122993, 43.307058960199356, 54.04335245490074, 68.56729790568352, 23.077238984405994, 0.04510665596171748, 0.1907283312175423, 1.3390026683919132, 0.7642070960719138, 24.422729685902596, 65.89069873094559, 66.70273795723915, 64.29483756422997, 59.307532981038094, 54.236735478043556, 46.96469709277153, 46.50305226445198, 45.95158405601978, 45.993811190128326, 45.440557077527046, 43.650872111320496, 43.551374450325966, 43.561242520809174, 42.54351653158665, 43.41886796057224, 42.648364305496216, 44.167268201708794, 45.85361771285534, 47.2244967520237, 44.69338417053223, 43.85610289871693, 41.80062219500542, 40.124239549040794, 40.98431199789047, 42.89367914199829, 40.037904381752014, 40.50560228526592, 40.45580975711346, 41.33192494511604, 41.95922948420048, 40.521040856838226, 38.859538212418556, 40.55651195347309, 40.24797610938549, 39.84864413738251, 41.477164551615715, 41.88675977289677, 41.8725523352623, 40.87730973958969, 40.95515996217728, 41.98966205120087, 42.43356943130493, 41.72836147248745, 43.52885685861111, 43.65168146789074, 41.4882979542017, 40.51223672926426, 41.80081978440285, 40.413328036665916, 40.30194081366062, 40.70758044719696, 40.12542128562927, 42.137462720274925, 43.28049838542938, 42.97304928302765, 44.76332701742649, 44.52301651239395, 42.573158740997314, 43.040704652667046, 42.53313548862934, 50.280957743525505, 53.571136593818665, 53.69390420615673, 41.23876914381981, 53.23032908141613, 51.76598645746708, 50.28923749923706, 44.166428446769714, 42.278841733932495, 43.59336979687214, 43.151803091168404, 47.00063556432724, 45.58298863470554, 44.61941733956337, 44.876747131347656, 44.96731907129288, 41.76341459155083, 40.951504558324814, 41.877796053886414, 41.08290530741215, 41.138891503214836, 40.55007129907608, 39.95626576244831, 41.488126963377, 39.78157013654709, 40.77179320156574, 41.00614942610264, 41.72619178891182, 39.995973631739616, 40.59754975140095, 40.08264318108559, 38.03981579840183, 39.18297305703163, 39.49331380426884, 39.87494632601738, 40.37160247564316, 39.819108322262764, 41.67362540960312, 41.755017042160034, 42.33534090220928, 43.713325560092926, 41.89376279711723, 41.79613843560219, 41.0994116216898, 42.055561915040016, 42.57554121315479, 45.691962987184525, 45.76548144221306, 45.84444120526314, 44.28042232990265, 46.24942347407341, 46.05403795838356, 44.16224107146263, 45.279255732893944, 44.43828485906124, 44.125208258628845, 43.42960238456726, 42.88497380912304, 44.06374655663967, 46.26405268907547, 51.72316275537014, 52.438808754086494, 53.54567036032677, 56.67125724256039, 62.265845239162445, 64.85187247395515, 68.84814083576202, 11.341826152056456, 0.1896624141954817, 4.956910964101553, 0.21844874921953306, 1.5983157162554562, 45.807077810168266, 66.78354442119598, 47.284856513142586, 45.548714473843575, 28.418276086449623, 29.57306072115898, 51.2152212113142, 45.58292783796787, 44.97637018561363, 21.449400633573532, 0.8109080151189119, 0.0813478755299002, 0.04116118740057573, 0.03690725628985092, 0.046444243562291376, 0.024589280255895574, 0.10063658308354206, 0.08231617786805145, 0.01815552041080082, 0.022946122626308352, 0.022215387325559277, 0.029649115094798617, 0.03928330886992626, 0.07069991173921153, 0.0759668966929894, 0.03276936738984659, 0.03615255147451535, 0.11448908859165385, 7.851399471983314, 69.72840160131454, 60.72472773492336, 58.04671123623848, 28.555359430611134, 16.184178963303566, 23.626486212015152, 49.6163734048605, 61.5650450438261, 74.24622997641563, 24.56543292850256, 0.06654793687630445, 0.15179496724158525, 0.6408854853361845, 0.1322911333409138, 29.666457809507847, 69.12642270326614, 68.81688371300697, 66.59463375806808, 62.80599385499954, 55.98506726324558, 49.86628979444504, 48.97825464606285, 48.19413632154465, 47.194926738739014, 47.1824786067009, 46.20072528719902, 45.38664177060127, 46.11757434904575, 43.559357821941376, 44.98297043144703, 44.075472727417946, 45.949372574687004, 46.58689096570015, 49.530790597200394, 46.84029556810856, 45.70770174264908, 42.33783736824989, 43.28185871243477, 42.28383846580982, 44.01964232325554, 43.491425067186356, 44.31400492787361, 43.08228202164173, 42.586040049791336, 43.451926186680794, 43.309734016656876, 41.069400832057, 41.599103808403015, 40.784127339720726, 42.28760786354542, 42.518722862005234, 42.535187378525734, 42.064822018146515, 42.211851328611374, 45.03739111125469, 45.06024308502674, 44.16040197014809, 43.368524461984634, 46.201337054371834, 44.617483243346214, 43.05187225341797, 41.682429537177086, 43.35519477725029, 42.828786224126816, 41.221031695604324, 42.25734628736973, 42.33596786856651, 43.84564585983753, 46.674286276102066, 45.61366058886051, 47.58819803595543, 47.16477915644646, 43.3839326351881, 45.68001642823219, 44.701709523797035, 52.48414792120457, 56.232403591275215, 56.497583761811256, 43.67544539272785, 55.436239913105965, 53.5434702783823, 52.75751285254955, 45.92826850712299, 43.23685772716999, 46.35648272931576, 47.663509994745255, 46.403824388980865, 48.11080299317837, 46.018996238708496, 46.311641335487366, 47.04970993101597, 44.546936228871346, 43.85750122368336, 44.371100664138794, 42.99763776361942, 43.213606774806976, 42.732427194714546, 42.24452577531338, 43.25718283653259, 41.43188238143921, 43.1331042945385, 44.18466366827488, 42.45880387723446, 43.01362730562687, 40.626720786094666, 43.061379343271255, 41.02651633322239, 41.819013208150864, 40.71247458457947, 41.423450633883476, 41.97629056870937, 42.221970185637474, 45.212687104940414, 42.492329478263855, 43.89839842915535, 44.91701357066631, 43.089368641376495, 41.95995904505253, 43.760161846876144, 43.38027723133564, 43.9685844630003, 47.51660227775574, 48.43209855258465, 48.19099009037018, 46.853978633880615, 48.94083045423031, 48.357979729771614, 47.657327726483345, 47.0637159794569, 47.653178349137306, 46.60888038575649, 46.26076966524124, 46.10633075237274, 46.28517955541611, 49.21373941004276, 53.66477116942406, 53.92594255506992, 56.49017035961151, 57.823142632842064, 65.41592940688133, 64.3402299284935, 74.04164895415306, 12.280406188219786, 0.4870501166442409, 7.256044093519449, 0.2921203093137592, 1.5861266828142107, 50.0050887465477, 72.73711055517197, 54.99117739498615, 41.64314724504948, 26.395543925464153, 39.81248527765274, 59.46490153670311, 55.47903701663017, 55.84254831075668, 28.877891823649406, 1.4955419185571373, 0.09798868180951104, 0.05434975275420584, 0.04017713297798764, 0.0441489811782958, 0.03720859793247655, 0.04057010017277207, 0.025694822397781536, 0.027153561895829625, 0.16707020695321262, 0.13434281543595716, 0.17161416937597096, 0.15002625121269375, 0.08731581896427087, 0.14978974359109998, 0.16169680544408038, 0.2208297816105187, 0.278622632031329, 11.654392629861832, 81.60147249698639, 67.59486928582191, 69.09318968653679, 35.01737058162689, 19.095062166452408, 38.8813566416502, 62.73715674877167, 64.94954243302345, 82.15358287096024, 28.83499402552843, 0.1279690137016587, 0.6237982772290707, 7.0894429832696915, 2.668255534954369, 33.016386553645134, 71.36998951435089, 71.34612679481506, 69.11351099610329, 65.9367598593235, 58.765161484479904, 52.50294931232929, 50.6003800034523, 50.284996926784515, 48.66484746336937, 50.296179726719856, 47.90629416704178, 48.071079924702644, 48.28529343008995, 48.15189778804779, 49.35672573745251, 47.4381060898304, 48.81667211651802, 51.49290271103382, 51.35438494384289, 50.22081837058067, 47.782344818115234, 46.747895926237106, 43.712835386395454, 45.37431143224239, 46.534013003110886, 44.54317823052406, 47.52818785607815, 43.65376375615597, 44.81220759451389, 47.20818042755127, 45.570221319794655, 44.374892860651016, 44.86009642481804, 44.18209120631218, 45.18868759274483, 44.71767246723175, 46.26405268907547, 44.1645323485136, 46.31786160171032, 46.181030943989754, 45.46798400580883, 45.876648277044296, 46.23857885599136, 50.015264600515366, 48.81238214671612, 45.408862978219986, 42.61154428124428, 47.64959134161472, 46.01157903671265, 44.63208205997944, 44.59998898208141, 45.499757900834084, 47.94554226100445, 49.27284523844719, 47.96788886189461, 50.01758627593517, 50.10215453803539, 47.04231172800064, 48.192137628793716, 47.65795849263668, 55.24995110929012, 59.416765719652176, 58.22650998830795, 46.555234864354134, 57.190989553928375, 55.738369300961494, 55.702069848775864, 47.53561645746231, 46.09422080218792, 49.816945642232895, 48.48634824156761, 48.89621704816818, 49.83119487762451, 48.303597047924995, 49.09791022539139, 49.42361354827881, 45.290997102856636, 46.76876820623875, 47.168730944395065, 45.16678176820278, 45.19916743040085, 44.930297657847404, 42.42690458893776, 46.05746537446976, 43.62053453922272, 46.295587196946144, 45.14423757791519, 46.40369139611721, 43.616571351885796, 44.383210614323616, 46.193148493766785, 43.72637405991554, 45.48259802162647, 46.21104933321476, 43.747960701584816, 45.81916116178036, 44.48364682495594, 47.337875068187714, 45.61732359230518, 45.96848554909229, 48.47487285733223, 46.05749577283859, 45.956808775663376, 47.751938849687576, 45.68963371217251, 47.18821629881859, 49.34580512344837, 50.291874557733536, 52.241641134023666, 49.33460712432861, 51.45236648619175, 51.51554189622402, 49.158722162246704, 49.750453010201454, 49.537086859345436, 50.4377069324255, 48.66963520646095, 48.0073307454586, 49.31958273053169, 51.199607849121094, 56.876503229141235, 57.45575934648514, 58.842483535408974, 61.5940260887146, 69.40226510167122, 68.38933065533638, 77.0833021402359, 14.30688589811325, 0.35386358213145286, 7.623387007042766, 0.30670526262838393, 2.2169585013762116, 56.59707002341747, 76.59287765622139, 64.23442080616951, 60.54601572453976, 37.580488845705986, 46.15833476185799, 68.74836578965187, 65.25167182087898, 66.39614760875702, 35.868733897805214, 1.9033831777051091, 0.16617536981357262, 0.17652200680458918, 0.13553612952819094, 0.08906361385015771, 0.13078334159217775, 0.1602310489397496, 0.10830927683855407, 0.11218774059670977], [0.06843010502052493, 0.04687002110586036, 0.057774608430918306, 0.05955476466624532, 0.0207803705779952, 0.04670442940550856, 0.030453788713202812, 0.06678769510472193, 0.09097774629481137, 8.246038220822811, 60.78946866095066, 52.612406238913536, 51.318093091249466, 23.657006174325943, 28.61594907939434, 42.65680745244026, 46.78092375397682, 61.49959355592728, 64.09298479557037, 25.264789201319218, 0.03430097465752624, 0.11898132332134992, 0.45540954102762043, 0.12722596060484648, 28.1146951764822, 67.83808663487434, 63.59496831893921, 68.19567024707794, 60.50065755844116, 55.767053961753845, 45.60372792184353, 48.90549995005131, 43.93932603299618, 47.59708575904369, 44.824249148368835, 46.31245829164982, 45.52424378693104, 47.27619297802448, 48.04055616259575, 50.547080263495445, 49.59500715136528, 53.706025555729866, 54.617197662591934, 56.02237746119499, 56.29428327083588, 53.98770064115524, 47.71410048007965, 40.0962882488966, 39.940542206168175, 41.87577076256275, 41.56311973929405, 42.57207579910755, 42.017134577035904, 41.3823976367712, 40.90636298060417, 41.60687059164047, 40.27458608150482, 41.42166092991829, 39.64176043868065, 40.006810650229454, 41.50256998836994, 41.29354700446129, 39.224626421928406, 39.81480695307255, 42.822843343019485, 40.937270522117615, 40.406397208571434, 41.817170307040215, 42.09792964160442, 43.69128294289112, 40.75902208685875, 41.416751593351364, 42.33833134174347, 41.345064640045166, 41.22695177793503, 40.91713920235634, 39.36299219727516, 39.74769875407219, 42.09286831319332, 41.311740428209305, 41.97570540010929, 42.776664420962334, 41.83839596807957, 42.52400077879429, 43.34838554263115, 50.3395240008831, 52.549789398908615, 53.376644030213356, 43.053129985928535, 53.07919219136238, 51.6998054087162, 52.2522159665823, 44.00949686765671, 43.93263839185238, 40.65469108521938, 42.94655330479145, 42.834504917263985, 44.030752927064896, 42.017803341150284, 44.28057812154293, 42.9228425770998, 41.01457357406616, 40.53749777376652, 39.99332897365093, 40.805478394031525, 42.52854533493519, 41.12331993877888, 42.493762001395226, 40.43015733361244, 42.9610039293766, 41.39889635145664, 42.306394055485725, 39.35606896877289, 40.93070067465305, 40.414870753884315, 41.21408186852932, 40.844015926122665, 39.160037487745285, 39.1439301520586, 39.93564426898956, 40.41784219443798, 41.047111228108406, 41.95500411093235, 42.40330405533314, 39.59099896252155, 41.215407997369766, 42.30154171586037, 41.53130404651165, 39.94517795741558, 45.313719883561134, 45.57318136096001, 49.50393743813038, 49.15399141609669, 49.380649253726006, 47.83114179968834, 48.856816962361336, 47.44340680539608, 46.18164271116257, 45.50394527614117, 48.07291902601719, 46.15923911333084, 47.92853057384491, 48.939694315195084, 53.455801382660866, 55.84118038415909, 61.52893178164959, 58.735302686691284, 60.52893944084644, 59.9025734513998, 63.39924082159996, 62.702468410134315, 73.18317621946335, 15.795513018965721, 2.108195750042796, 6.095778252929449, 0.26133415347430855, 0.4643250204389915, 30.874916464090347, 72.20121011137962, 51.2628098577261, 58.1789593398571, 27.275816090404987, 29.490344859659672, 49.29168462753296, 41.06359474360943, 52.46061198413372, 30.642534233629704, 2.4934886628761888, 0.14628272474510595, 0.03932239778805524, 0.048279225957230665, 0.03600078598537948, 0.02919990980444709, 0.07532954768976197, 0.023825272619433235, 0.06075832781789359, 0.037526044179685414, 0.05789765651570633, 0.033487751497887075, 0.06560111229191534, 0.040577729450888, 0.0448865943326382, 0.0071964362541621085, 0.03577095027139876, 0.05549568071728572, 11.988088823854923, 69.68316122889519, 59.165238216519356, 58.61210949718952, 29.806506894528866, 29.398866668343544, 43.083133175969124, 53.73352847993374, 63.882362097501755, 70.87250500917435, 26.204480677843094, 0.20552472240524366, 0.04258435947122052, 2.276455946266651, 0.13955313741462305, 32.746722623705864, 70.7386077940464, 65.7447637617588, 67.77138501405716, 62.75188095867634, 57.789366245269775, 47.7329208701849, 50.08881725370884, 46.20515204966068, 48.65787483751774, 46.57941296696663, 49.423104375600815, 46.93638861179352, 48.441305458545685, 49.15111117064953, 53.540840819478035, 52.66404926776886, 56.13435745239258, 55.160169526934624, 57.40783631801605, 58.0057418346405, 56.12942911684513, 48.97185958921909, 41.450839564204216, 41.33775383234024, 44.24272835254669, 43.30628000199795, 43.93558323383331, 43.3405427634716, 42.68693223595619, 42.48395852744579, 43.13542976975441, 44.13999706506729, 42.71285444498062, 41.615678519010544, 42.08718381822109, 43.44693325459957, 43.23829784989357, 43.96727733314037, 43.51794384419918, 45.12655332684517, 44.16955567896366, 44.39286969602108, 43.673150315880775, 44.84163701534271, 44.8855322599411, 43.55353653430939, 43.39613378047943, 44.10671845078468, 44.864937365055084, 43.52728374302387, 43.530065193772316, 41.48930869996548, 41.59357510507107, 44.73634086549282, 44.63826432824135, 45.66143922507763, 44.4976756721735, 44.93675351142883, 44.81645956635475, 45.64410075545311, 53.077729269862175, 53.638826161623, 56.7520485073328, 46.18116773664951, 55.41991598904133, 55.72157420217991, 52.30068236589432, 45.8917410671711, 45.199482813477516, 43.09059217572212, 46.81084714829922, 45.57514205574989, 45.36868013441563, 45.6761634349823, 47.04269550740719, 44.76754479110241, 42.75402143597603, 41.931897550821304, 42.8734490275383, 42.71341301500797, 45.462098121643066, 43.24001915752888, 43.89147140085697, 44.417724162340164, 43.4159991145134, 44.41081993281841, 44.16560389101505, 43.471563532948494, 42.669578567147255, 42.03190818428993, 43.292308151721954, 43.066292479634285, 41.1015585064888, 40.31008377671242, 42.471415400505066, 41.54848672449589, 43.53128492832184, 44.022898748517036, 44.70469996333122, 40.92262230813503, 43.71097728610039, 42.241273149847984, 43.32794263958931, 43.034127205610275, 46.44305348396301, 47.34142407774925, 53.08596722781658, 51.47214062511921, 51.96145176887512, 50.942122265696526, 51.52802802622318, 50.19009321928024, 48.508508652448654, 48.703020215034485, 50.42779326438904, 48.23635205626488, 51.02591536939144, 52.0942622423172, 55.704266130924225, 58.20301204919815, 62.58641503751278, 60.693850591778755, 63.302292823791504, 60.201419815421104, 66.4086565375328, 63.8451012969017, 75.85605159401894, 17.59042840451002, 2.079392345622182, 3.285740213468671, 0.2258968839305453, 0.3494337620213628, 33.763114884495735, 77.4704709649086, 56.954501643776894, 58.24989393353462, 34.63333658874035, 40.933755710721016, 56.32606476545334, 50.095535293221474, 61.85713157057762, 40.402958393096924, 3.392099356278777, 0.09199266292853281, 0.0358675036841305, 0.017179724236484617, 0.011826728077721782, 0.08026272204006091, 0.008389309696212877, 0.03438288920733612, 0.032789164179121144, 0.19603599328547716, 0.16890774975763634, 0.18079217610647902, 0.14342949347337708, 0.13358963944483548, 0.1311318838270381, 0.08606956005678512, 0.15597502497257665, 0.17151786829344928, 17.638417929410934, 81.69630020856857, 67.0016223192215, 67.79738321900368, 35.40229372680187, 40.855377316474915, 58.75869043171406, 64.89509135484695, 70.7922001183033, 76.7228838801384, 30.051373355090618, 0.34628390916623175, 0.20741158834425732, 3.9998316206038, 1.8107828591018915, 37.61115700006485, 71.94130405783653, 67.92811140418053, 70.47644466161728, 65.87739944458008, 60.13320967555046, 50.70213854312897, 52.92057350277901, 48.453062027692795, 51.529084369540215, 49.87006299197674, 51.08432203531265, 51.381849870085716, 52.042224034667015, 52.368896305561066, 57.613747268915176, 54.60580587387085, 58.62288951873779, 56.863374933600426, 59.86722394824028, 61.322789043188095, 59.701074063777924, 52.55680002272129, 44.198981299996376, 43.98507937788963, 45.934598967432976, 47.40624099969864, 45.75420744717121, 45.95765233039856, 45.369896069169044, 45.62621891498566, 45.954551696777344, 44.7316937148571, 44.75931063294411, 45.396281853318214, 45.29112629592419, 47.23820261657238, 45.59276171028614, 45.603929311037064, 46.344501972198486, 48.37001368403435, 44.56816948950291, 46.782831251621246, 45.94881780445576, 45.62515877187252, 48.12460385262966, 46.44691027700901, 45.7641477137804, 47.38915711641312, 47.10801400244236, 46.524631306529045, 46.70433506369591, 42.64701157808304, 42.910421043634415, 48.51620323956013, 46.165721565485, 46.78693503141403, 47.1552986651659, 48.200538977980614, 45.86151368916035, 48.9715214073658, 54.94804970920086, 57.186950370669365, 57.611953765153885, 47.93706491589546, 57.38175071775913, 58.392424285411835, 57.70035222172737, 49.75066959857941, 47.36149460077286, 46.16060324013233, 48.23305383324623, 49.60775166749954, 48.45908470451832, 47.07790061831474, 49.49344240128994, 48.10140609741211, 44.80469539761543, 44.065300673246384, 43.994290083646774, 44.93489921092987, 47.356733456254005, 44.414870515465736, 45.5022581666708, 44.271295219659805, 47.52768248319626, 46.82812102138996, 46.16239294409752, 44.846603348851204, 45.900237411260605, 45.36245986819267, 46.28257289528847, 46.429507210850716, 42.47184857726097, 43.45597296953201, 46.57046064734459, 43.79066661000252, 45.29616482555866, 47.34553165733814, 47.10147075355053, 43.18880930542946, 46.919741705060005, 44.215780198574066, 45.197723507881165, 45.11116415262222, 50.549489334225655, 51.20523154735565, 55.35886466503143, 54.686133563518524, 53.46941985189915, 52.64790393412113, 54.293553829193115, 53.091423735022545, 51.56758010387421, 52.48509407043457, 53.3696524053812, 51.08497180044651, 53.146425783634186, 54.1406462341547, 59.33942846953869, 60.38215331733227, 65.37794664502144, 63.22644129395485, 66.23535543680191, 65.07342338562012, 69.99706238508224, 65.81042423844337, 80.4975937306881, 19.112113751471043, 3.6793162068352103, 9.224313776940107, 0.39444098132662475, 0.7410006131976843, 37.857816964387894, 83.049825578928, 64.75410372018814, 75.1828721165657, 37.35086716711521, 44.87097904086113, 67.15266421437263, 60.904363095760345, 72.35421270132065, 51.35758817195892, 4.329849136993289, 0.23584276117617264, 0.12182124788523652, 0.09689845945104025, 0.1597114565083757, 0.22254711133427918, 0.14196827891282737, 0.14897023444063962, 0.13646188454004005], [0.01447165055651567, 0.06757895069313236, 0.03672696264402475, 0.019068517904088367, 0.025900371329043992, 0.044858073597424664, 0.0655268455739133, 0.018814903778547887, 0.05487379436090123, 14.712314642965794, 62.6955109834671, 48.47183682024479, 45.44134363532066, 24.486621357500553, 24.427198246121407, 26.802530586719513, 50.98363123834133, 61.135645285248756, 66.60659551620483, 15.85114298388362, 0.21610522497212514, 0.0523132698435802, 0.5313646153081208, 0.4068829386960715, 43.8177515566349, 71.67024180293083, 62.96814635396004, 62.220388278365135, 59.46365140378475, 48.95352177321911, 45.09754568338394, 45.869907438755035, 48.41421291232109, 53.21968585252762, 53.31067197024822, 53.517103493213654, 54.53834429383278, 55.03365531563759, 53.87784093618393, 54.49850343167782, 55.61278983950615, 55.381864830851555, 53.42482544481754, 58.733896762132645, 54.71336290240288, 58.425577506423, 56.37643106281757, 46.901141703128815, 40.95184274017811, 39.809985011816025, 40.28274804353714, 40.97813732922077, 41.24731868505478, 42.22333051264286, 41.41176626086235, 40.421550795435905, 39.14188206195831, 41.413278579711914, 39.25510838627815, 40.092245265841484, 39.41585876047611, 39.14980083703995, 41.56617097556591, 41.96818180382252, 40.68933382630348, 41.07079915702343, 41.18288554251194, 42.297586128115654, 42.70131826400757, 42.68245607614517, 42.71025538444519, 40.645267590880394, 41.35623224079609, 41.62965416908264, 40.0473240762949, 41.22758634388447, 41.25113748013973, 40.04005126655102, 40.72540909051895, 42.7125808596611, 41.53817027807236, 41.62625715136528, 41.26505233347416, 43.46169166266918, 45.82420349121094, 50.262889713048935, 50.83369508385658, 55.19691735506058, 44.72675397992134, 51.41490429639816, 53.53493973612785, 50.02355195581913, 43.92329089343548, 41.58146135509014, 41.229110062122345, 41.61702744662762, 41.26224808394909, 42.320559695363045, 43.2764858007431, 42.67125427722931, 39.21620987355709, 40.88510312139988, 40.684344694018364, 41.31258398294449, 41.961627155542374, 41.27553217113018, 40.30787229537964, 44.85022455453873, 42.67535425722599, 44.764041379094124, 43.00185173749924, 41.85236781835556, 41.102067679166794, 41.19037114083767, 40.025205463171005, 39.97448578476906, 38.842207342386246, 40.07177576422691, 39.541385024785995, 40.72732798755169, 41.455581709742546, 41.45829476416111, 40.803608894348145, 40.01783385872841, 40.38401260972023, 41.57385416328907, 40.54884776473045, 41.14425301551819, 40.27386412024498, 46.82967893779278, 50.00424899160862, 51.81782327592373, 51.48898132145405, 51.805952712893486, 51.11046463251114, 53.85081298649311, 52.34265871345997, 50.904158502817154, 49.82705309987068, 51.860061809420586, 52.14474633336067, 56.84158310294151, 56.343631222844124, 61.38152249157429, 60.98401062190533, 60.48365727066994, 64.99098300933838, 66.85922116041183, 63.02909128367901, 65.71358263492584, 60.812316834926605, 73.49734336137772, 18.339746296405792, 1.3194098509848118, 2.141794259659946, 0.05879804491996765, 0.026884178987529594, 19.78401079773903, 72.08539232611656, 55.84836579859257, 46.78864873945713, 19.914651587605476, 23.514859601855278, 36.06141395866871, 39.3179190158844, 50.6116957962513, 47.4660611897707, 7.79107010923326, 0.24599363445304334, 0.06736996190738864, 0.05539645928365644, 0.026598741569614504, 0.016470051086798776, 0.03104133218585048, 0.03651768070994876, 0.022049884682928678, 0.030822919979982544, 0.03859583521261811, 0.07959956114063971, 0.06747375868144445, 0.02749379949818831, 0.07872829461121, 0.046505110803991556, 0.14425909583223984, 0.03231472772313282, 21.022470742464066, 73.73696610331535, 54.5039751380682, 53.57889577746391, 30.871242061257362, 26.312734968960285, 28.24257541447878, 56.41910657286644, 65.8641305565834, 73.24098631739616, 18.21572095155716, 0.33826945640612394, 0.12246399972354993, 1.3681510230526328, 0.5668589263223112, 45.24066120386124, 72.51595482230186, 64.4667175412178, 67.22468554973602, 61.19860790669918, 51.93559415638447, 47.08671234548092, 48.134528920054436, 48.781679794192314, 54.81466546654701, 56.34102836251259, 55.754807218909264, 54.953415021300316, 56.918452978134155, 55.4165455698967, 57.75497809052467, 57.06246145069599, 57.91189447045326, 56.1890023201704, 60.21468870341778, 56.877213791012764, 59.57458645105362, 57.63447895646095, 47.597807720303535, 44.36548836529255, 41.718831583857536, 41.627161502838135, 42.583980560302734, 44.90308731794357, 42.78251230716705, 43.65469850599766, 42.23662979900837, 41.593898087739944, 42.541517838835716, 40.44749580323696, 43.69338423013687, 41.33225932717323, 42.518757060170174, 43.67064245045185, 43.529404029250145, 41.776694878935814, 43.521884232759476, 42.780430018901825, 44.30312231183052, 45.7793202996254, 45.03658175468445, 44.92140233516693, 45.0179323554039, 43.45177419483662, 41.801864728331566, 42.94260151684284, 42.21123196184635, 42.710095793008804, 42.08969168365002, 42.969443276524544, 45.42564667761326, 43.03902894258499, 44.18239139020443, 43.030954375863075, 45.50507381558418, 48.135361075401306, 52.289936542510986, 52.95470327138901, 58.00535425543785, 48.097936883568764, 53.84221784770489, 55.16130946576595, 53.518657609820366, 46.242671236395836, 44.15703535079956, 44.44425813853741, 44.33976374566555, 43.97200047969818, 44.56847347319126, 45.7777813822031, 44.590626284480095, 42.49229148030281, 42.38599218428135, 42.30149231851101, 42.97325447201729, 43.579903319478035, 44.046119302511215, 42.821179032325745, 45.78801803290844, 46.66890576481819, 46.10281214118004, 44.70482915639877, 45.348089039325714, 42.694197446107864, 42.7229543030262, 43.77031110227108, 42.35020950436592, 42.58045434951782, 40.92598132789135, 41.78442746400833, 41.170388013124466, 43.08000594377518, 43.792026937007904, 42.46157392859459, 43.58927361667156, 42.02071398496628, 43.484615832567215, 42.036395743489265, 43.69510933756828, 43.7058399617672, 49.08971406519413, 51.99297867715359, 53.41497257351875, 53.37378278374672, 54.25619803369045, 54.20595332980156, 56.10431246459484, 54.893363043665886, 52.22878262400627, 51.12812228500843, 53.497226759791374, 53.38412202894688, 59.19565178453922, 57.86907456815243, 63.28810058534145, 62.41494923830032, 65.4733595252037, 66.76266074180603, 69.03742387890816, 66.05833053588867, 68.39545592665672, 62.25086264312267, 76.80483028292656, 19.964567609131336, 0.6386015110183507, 1.460682232864201, 0.08829243335640058, 0.029023651586612687, 20.328308790922165, 76.04142844676971, 62.30453476309776, 51.92334361374378, 21.77167274057865, 31.059673950076103, 44.520850628614426, 50.40184065699577, 59.65729281306267, 57.820262387394905, 9.956634230911732, 0.3799714765045792, 0.04703137143224012, 0.1137758995173499, 0.02208461348345736, 0.045185605631559156, 0.05711409328796435, 0.025888957097777165, 0.06386382621712983, 0.157838542945683, 0.1653578644618392, 0.1550516448332928, 0.11251556206843816, 0.12027884236886166, 0.20757777005201206, 0.15987677732482553, 0.2251596938003786, 0.366603170405142, 29.136312156915665, 84.64802742004395, 63.89791086316109, 63.70005168020725, 40.21131947636604, 33.45590516924858, 38.5493266582489, 65.025135576725, 71.28696396946907, 78.99315565824509, 20.566614903509617, 0.4948764498112723, 0.19833724480122328, 3.235904462635517, 1.0253735538572073, 50.176767334342, 74.85991224646568, 68.0977874994278, 68.86900171637535, 65.4746362566948, 53.95410664379597, 50.555166229605675, 49.888917580246925, 52.96409636735916, 57.178469225764275, 58.358450308442116, 56.92742429673672, 59.61688578128815, 61.13476373255253, 58.855467438697815, 59.737844690680504, 60.47623626887798, 61.0958082228899, 60.10564215481281, 63.89911159873009, 58.24724167585373, 60.4594411700964, 62.29097329080105, 51.65684871375561, 46.487184315919876, 43.812599033117294, 44.351326525211334, 44.221738278865814, 45.78044503927231, 45.45640602707863, 45.01871511340141, 44.68654453754425, 45.49886494874954, 45.34178137779236, 43.94660264253616, 44.78191941976547, 44.592263996601105, 44.192001074552536, 44.4955325871706, 46.54812924563885, 43.891877979040146, 46.096230894327164, 44.31283079087734, 46.07973977923393, 49.133871495723724, 47.63369299471378, 49.22333389520645, 46.66218392550945, 46.88223771750927, 44.85712878406048, 45.336769446730614, 47.656856551766396, 46.12392000854015, 43.054159730672836, 45.73571763932705, 49.00315470993519, 46.6434433311224, 45.91241955757141, 46.27959385514259, 48.61525632441044, 51.58457659184933, 56.08557567000389, 55.88276155292988, 60.55939860641956, 51.92610986530781, 55.39590887725353, 58.25846627354622, 54.30817924439907, 48.31352211534977, 46.14595502614975, 46.707564890384674, 47.7947511523962, 45.277207642793655, 46.89767248928547, 48.83424237370491, 46.5112142264843, 45.44569060206413, 46.36733874678612, 43.72079595923424, 45.444045290350914, 45.61568208038807, 45.693737491965294, 44.31085489690304, 48.87800082564354, 50.21350376307964, 48.57973203063011, 46.98338828980923, 46.65366478264332, 44.650317281484604, 45.816235318779945, 46.18546910583973, 43.82933713495731, 44.363075494766235, 43.36378991603851, 44.20071020722389, 43.640297278761864, 46.99147805571556, 46.43890030682087, 44.67418000102043, 45.81324487924576, 46.188964918255806, 46.844433546066284, 45.18927276134491, 45.46034261584282, 43.98662209510803, 52.27680824697018, 53.65287020802498, 56.10349930822849, 56.05335719883442, 58.009070456027985, 56.62724420428276, 58.92829053103924, 56.93965204060078, 54.99156877398491, 53.07383447885513, 56.71214684844017, 57.89926394820213, 62.61588625609875, 60.64891800284386, 68.1984668970108, 65.50287634134293, 66.32879242300987, 69.18695345520973, 73.04835185408592, 68.58945831656456, 73.57685789465904, 63.5971911996603, 79.66698870062828, 21.45848784595728, 3.592649269849062, 6.226960513740778, 0.24762074870523065, 0.09826264562434517, 23.880485482513905, 81.94854587316513, 69.00297492742538, 62.33729660511017, 27.951626926660538, 36.83445207774639, 53.29132720828056, 58.67392838001251, 69.79855343699455, 68.28058049082756, 12.827672772109509, 0.5351363879162818, 0.19219114881707355, 0.19123092846712098, 0.13703005795832723, 0.14706313755596057, 0.13125706929713488, 0.13533252873457968, 0.10868204277358018], [0.04300382133806124, 0.05213708398514427, 0.07157782791182399, 0.08429005320067517, 0.11686918587656692, 0.03190407885995228, 0.06799983006203547, 0.09215482961735688, 0.33473757561296225, 25.18188714981079, 59.91957373917103, 46.98369227349758, 39.19686131179333, 14.421000424772501, 44.994662404060364, 47.78904765844345, 51.374919041991234, 63.066329285502434, 60.753526389598846, 12.445366736501455, 0.31708404945675284, 0.2671476633986458, 1.6441680933348835, 1.6542800632305443, 52.47341349720955, 69.30776417255402, 59.999947026371956, 62.83234924077988, 50.603856816887856, 46.14230342209339, 49.59868535399437, 57.36919619143009, 60.24061471223831, 59.10598039627075, 58.1018690764904, 55.662574768066406, 54.760677963495255, 56.06678947806358, 56.57893359661102, 57.863017693161964, 53.77422049641609, 58.99232089519501, 53.9887759834528, 50.657905116677284, 53.64299453794956, 54.38977226614952, 54.771799966692924, 50.19577391445637, 43.30363914370537, 41.63489408791065, 40.175065621733665, 39.82756666839123, 38.46658609807491, 40.53855411708355, 41.685275584459305, 39.68310981988907, 40.027736127376556, 40.39524860680103, 39.66584354639053, 41.450102403759956, 39.745852053165436, 42.5616529583931, 40.0167129188776, 41.91275417804718, 41.73702120780945, 43.11309836804867, 42.99383416771889, 41.75495244562626, 41.298441141843796, 45.73317177593708, 41.84379927814007, 42.00505502521992, 40.00014200806618, 40.612186565995216, 40.23748867213726, 40.313271805644035, 40.147581696510315, 41.821578070521355, 39.85826522111893, 39.56526294350624, 39.877883568406105, 40.50870671868324, 40.678926184773445, 43.87132488191128, 47.16173931956291, 51.49534597992897, 49.5157016068697, 55.47767288982868, 46.71106070280075, 53.49921025335789, 53.16868498921394, 48.4226256608963, 47.00719781219959, 44.02194879949093, 42.23867028951645, 41.371116042137146, 41.11909456551075, 37.62203201651573, 41.653117910027504, 40.79647287726402, 41.66712775826454, 42.806215435266495, 40.44901952147484, 42.786517292261124, 42.91291370987892, 42.701633647084236, 44.575362503528595, 42.27474935352802, 43.0428097397089, 42.0090714097023, 42.438064590096474, 41.52101419866085, 41.61462977528572, 41.784644052386284, 42.62681946158409, 40.796062499284744, 40.26843801140785, 41.453427225351334, 40.05080848932266, 40.20299792289734, 39.96761575341225, 40.91928988695145, 42.228350043296814, 40.25911331176758, 42.38536901772022, 43.5202769190073, 43.298380225896835, 40.86190156638622, 42.68186330795288, 46.75842136144638, 48.66953261196613, 52.99304701387882, 54.13419418036938, 52.98516243696213, 53.58571261167526, 54.5432498306036, 56.56069837510586, 56.75684005022049, 54.96892958879471, 58.159755170345306, 57.949808835983276, 59.63893599808216, 59.264796674251556, 62.48441331088543, 65.42434975504875, 61.86293765902519, 56.411419585347176, 59.38132882118225, 60.70922836661339, 66.48286655545235, 64.6389850974083, 69.8149685561657, 13.626383263617754, 0.7044339284766465, 0.5050395685248077, 0.0393332962266868, 0.20127767842495814, 10.429021082818508, 67.66536310315132, 57.83377446234226, 58.31480585038662, 57.17354089021683, 33.377283588051796, 19.402250982820988, 35.408487394452095, 50.891322791576385, 58.409128189086914, 10.487843826413155, 0.39731549739371985, 0.08722381491679698, 0.04943158091919031, 0.07260606609634124, 0.06849498357041739, 0.011986230456386693, 0.02037708010902861, 0.07690028098295443, 0.04770298539369833, 0.03143449233903084, 0.022609809129789937, 0.039957230910658836, 0.051707699603866786, 0.014692046152049443, 0.11325477826176211, 0.121162228169851, 0.32738600915763527, 34.501027688384056, 69.45696696639061, 55.17113953828812, 48.25611099600792, 26.071352921426296, 41.632306426763535, 43.9503226429224, 60.23352809250355, 65.63286736607552, 68.63517746329308, 12.959999721497297, 0.3636917844414711, 0.2331783322733827, 1.4131654263474047, 1.5384741523303092, 54.239262342453, 72.27810278534889, 62.688937336206436, 64.50080931186676, 53.74971941113472, 46.79612293839455, 49.776941388845444, 60.27127526700497, 59.79861482977867, 62.74384059011936, 59.92505304515362, 59.928180277347565, 57.47189708054066, 59.13038268685341, 58.27286370098591, 59.55230824649334, 58.719636127352715, 60.48446282744408, 57.19835355877876, 52.656430676579475, 55.61925329267979, 56.84539809823036, 55.9714487940073, 53.31199809908867, 45.789085775613785, 41.91436529159546, 42.79971018433571, 41.07448495924473, 41.45868994295597, 43.32486480474472, 43.40752936899662, 40.28703801333904, 43.66774320602417, 42.422466427087784, 42.3061166703701, 42.120622023940086, 42.88922198116779, 43.942274674773216, 42.58372217416763, 42.8105928003788, 42.88129560649395, 45.090808644890785, 43.96261118352413, 44.07356142997742, 43.5464309155941, 46.545374393463135, 44.62058387696743, 43.11609260737896, 41.614477783441544, 41.923803985118866, 42.494138181209564, 42.43622548878193, 40.96790447831154, 41.95973485708237, 42.470077872276306, 42.23659560084343, 41.73334680497646, 43.704707622528076, 43.42307813465595, 44.70407299697399, 50.71023590862751, 53.73192876577377, 51.812176778912544, 56.78793378174305, 47.08371050655842, 54.6081655472517, 56.112402230501175, 51.95751138031483, 50.73910295963287, 45.76884426176548, 44.49308931827545, 42.95100286602974, 44.52757626771927, 41.65819063782692, 44.345315247774124, 42.778689712285995, 42.691317200660706, 43.813199400901794, 41.70453295111656, 44.78643737733364, 43.34595367312431, 43.92816223204136, 45.09843863546848, 43.09976868331432, 45.34017786383629, 42.333251014351845, 44.56897124648094, 43.58643516898155, 44.810756072402, 42.55506791174412, 43.35157737135887, 43.00561733543873, 42.77653902769089, 43.881956711411476, 42.79561400413513, 41.660793498158455, 42.69620753824711, 42.64751315116882, 43.70780825614929, 42.668936401605606, 43.523119166493416, 43.13664190471172, 44.61293488740921, 42.95369692146778, 43.814597725868225, 47.56545625627041, 51.51433356106281, 55.607504323124886, 54.322648867964745, 57.01165817677975, 56.876632422208786, 57.629421427845955, 56.725484132766724, 58.84201996028423, 57.20883719623089, 60.06219528615475, 60.842836797237396, 61.2541039288044, 61.53941921889782, 63.58201861381531, 65.24732485413551, 62.57027730345726, 56.65982745587826, 61.479192450642586, 62.34654910862446, 69.6066789329052, 66.39777392148972, 71.33424863219261, 15.545958559960127, 1.3360020169056952, 0.8588454115670174, 0.18922531889984384, 0.20126860938034952, 11.86961593106389, 73.08367475867271, 62.028707563877106, 61.62907920777798, 44.18755531311035, 35.61057575047016, 27.787863314151764, 46.37727901339531, 58.81155699491501, 68.05674210190773, 13.960050959140062, 0.5947087006643414, 0.04020261832920369, 0.05430453740700614, 0.05449708020023536, 0.05550516536459327, 0.031974972516763955, 0.023582592184538953, 0.08022066453122534, 0.13255637692054734, 0.1533300700248219, 0.1545972574967891, 0.16600191505858675, 0.2224580684560351, 0.06276824555243365, 0.15539545216597617, 0.18053237989079207, 0.6401464249938726, 44.83869597315788, 80.45864582061768, 65.0192990899086, 58.05536337196827, 24.897314719855785, 55.13927064836025, 63.518843203783035, 65.79224601387978, 72.22929820418358, 73.93450230360031, 15.901716370135546, 0.41336191759910434, 0.4075219278456643, 5.598711725324392, 1.7929101618938148, 57.284399941563606, 74.5393006503582, 67.07951053977013, 67.46419429779053, 57.399537563323975, 49.476913288235664, 54.795734882354736, 62.642329037189484, 64.20704707503319, 64.51783999800682, 63.74261699616909, 61.53358273208141, 61.281576454639435, 60.791615545749664, 61.22734576463699, 63.67600657045841, 59.84817557036877, 63.65856930613518, 58.56708951294422, 54.5802940428257, 54.14448022842407, 59.66508999466896, 59.343859031796455, 56.39396332204342, 48.47637377679348, 46.266226172447205, 43.813465386629105, 43.68519946932793, 43.833805695176125, 45.838239938020706, 46.95792205631733, 41.822805404663086, 45.85857264697552, 45.59879198670387, 43.383514657616615, 45.37187576293945, 44.502292424440384, 47.521652206778526, 42.835337072610855, 46.43810614943504, 44.76406417787075, 46.87713839113712, 47.09744676947594, 46.834751665592194, 46.21200688183308, 49.66005966067314, 46.815475299954414, 46.40828914940357, 44.272256568074226, 43.954365625977516, 45.08301146328449, 45.811466574668884, 43.946929425001144, 44.63642902672291, 45.33051498234272, 44.93884339928627, 42.45490528643131, 45.40983572602272, 45.49956031143665, 47.37309157848358, 53.99276576936245, 55.294716507196426, 54.00286562740803, 59.590876176953316, 50.887044221162796, 56.59869633615017, 58.287112936377525, 54.55271512269974, 52.795313224196434, 50.625542253255844, 45.476358756423, 45.35761892795563, 47.875721007585526, 43.305531442165375, 48.09030309319496, 45.74619747698307, 45.63959039747715, 47.9828866571188, 44.388028755784035, 47.04075761139393, 45.167017355561256, 46.68207585811615, 47.8563192486763, 45.49301706254482, 46.834671869874, 45.66542901098728, 47.42375046014786, 45.04564806818962, 45.920619517564774, 45.72998374700546, 48.02838921546936, 44.58416283130646, 44.57594007253647, 46.29081465303898, 45.48054613173008, 43.508926928043365, 44.60470452904701, 45.06500042974949, 47.230420634150505, 43.43491069972515, 46.701511815190315, 47.51247189939022, 46.46417275071144, 45.3880400955677, 46.12740062177181, 48.971612602472305, 53.03978070616722, 58.03346134722233, 57.31450952589512, 59.957301914691925, 59.252447336912155, 60.391926392912865, 59.480032324790955, 60.46872027218342, 59.74407255649567, 62.53593094646931, 63.04777108132839, 64.73809137940407, 63.53686943650246, 66.69181734323502, 67.00315743684769, 65.87151736021042, 59.822295159101486, 63.41528736054897, 65.75463563203812, 71.70821696519852, 69.63839203119278, 74.62348893284798, 17.350205294787884, 2.16777631547302, 1.8033516453579068, 0.24078151647699997, 0.26137434819247574, 13.460834696888924, 80.67917078733444, 67.84133926033974, 75.76484128832817, 68.0428272485733, 45.27716964483261, 30.743236429989338, 56.24177008867264, 69.01914685964584, 79.9931176006794, 19.403723403811455, 0.9126147232018411, 0.2072831819532439, 0.15464853990124539, 0.13357399497181177, 0.15313494455767795, 0.10896379171754234, 0.10892140766372904, 0.17459144321037456], [0.011554999982763547, 0.007835201831767336, 0.05032593566284049, 0.009021895039040828, 0.009100681436393643, 0.012345570012257667, 0.06912217257195152, 0.09455108345719054, 0.9973639505915344, 26.558175198733807, 55.36866053938866, 47.15371415019035, 37.337906062603, 13.40286310762167, 47.952537685632706, 43.51088382303715, 54.411651492118835, 61.7170824855566, 59.33355778455734, 10.90837201103568, 0.33486436412204057, 0.2621868217829615, 1.102655113209039, 2.8498720144852996, 63.03678587079048, 66.00292190909386, 63.007067665457726, 56.656901612877846, 46.55429631471634, 53.32369767129421, 58.260461166501045, 58.22932943701744, 59.943444058299065, 59.55820932984352, 59.655670300126076, 58.012604266405106, 58.8465341180563, 56.94671206176281, 55.43965592980385, 56.66566774249077, 55.14555171132088, 50.904371291399, 48.608093708753586, 51.01697064936161, 44.790487959980965, 51.53380751609802, 55.685118958353996, 51.211280822753906, 46.89940519630909, 42.25606955587864, 40.49148604273796, 38.97203877568245, 39.79493401944637, 40.61687931418419, 39.832031428813934, 41.1537829041481, 38.643983379006386, 39.67671096324921, 41.298346146941185, 41.96762703359127, 40.06150871515274, 40.664038583636284, 40.22436797618866, 42.69267372786999, 40.540514811873436, 41.657955050468445, 41.285457238554955, 40.05534164607525, 42.24590130150318, 41.64101555943489, 41.65818303823471, 39.717501774430275, 42.76464566588402, 40.29994212090969, 41.48647405207157, 40.76963871717453, 40.28607666492462, 40.928386598825455, 40.12019656598568, 39.515041038393974, 40.545640736818314, 40.6034242361784, 40.508930906653404, 44.05450165271759, 49.274786934256554, 53.17427068948746, 53.401202112436295, 56.08749836683273, 44.07768040895462, 45.818078219890594, 53.8226792961359, 48.800872564315796, 47.22026377916336, 43.094555363059044, 43.75265344977379, 41.400613859295845, 40.308624655008316, 41.50264598429203, 40.510492622852325, 40.329607129096985, 40.249439030885696, 41.331541165709496, 41.79474011063576, 42.96181708574295, 43.41872736811638, 41.59107103943825, 41.12401910126209, 41.59849964082241, 42.77248464524746, 42.8686498850584, 42.92885385453701, 41.402817741036415, 40.9067315608263, 40.03998667001724, 41.374699249863625, 43.152661845088005, 39.1705971211195, 39.68197748064995, 39.16643634438515, 39.48269337415695, 39.489213824272156, 41.714397221803665, 41.771508157253265, 42.192669957876205, 41.59685432910919, 43.25755521655083, 43.04857403039932, 43.326745703816414, 41.07027478516102, 43.70913818478584, 47.36158959567547, 51.85944244265556, 53.298573419451714, 57.171694189310074, 54.323488622903824, 56.5680243819952, 58.02745386958122, 61.997708827257156, 57.83079922199249, 58.7166228890419, 59.742871820926666, 59.9096866697073, 59.327660501003265, 59.73837286233902, 55.034818053245544, 51.03936284780502, 48.019201308488846, 53.8849351555109, 55.022917091846466, 61.76494091749191, 57.776579931378365, 62.11492493748665, 12.214099746197462, 0.16422162152593955, 0.5131485115271062, 0.2459683717461303, 0.017852097043942194, 5.77886575832963, 63.056598007678986, 61.7995760589838, 57.62933403253555, 48.734653517603874, 36.90382495522499, 14.799945540726185, 40.52531182765961, 47.62129805982113, 56.6136409342289, 17.186650671064854, 0.763768635224551, 0.06485114237875678, 0.042677165038185194, 0.07680378694203682, 0.04078385354659986, 0.03178205122821964, 0.09030985791468993, 0.050819359967135824, 0.09475308863329701, 0.042533752421149984, 0.07377543850452639, 0.005370303970266832, 0.05428537515399512, 0.07771096599753946, 0.10482704572496004, 0.03200411294528749, 1.4263745862990618, 38.382549807429314, 67.47442334890366, 56.37796998023987, 46.141269877552986, 16.197881028056145, 42.51947522163391, 47.996486127376556, 59.10477206110954, 67.55526021122932, 64.39580574631691, 11.95672245696187, 0.4105642583454028, 0.24412260594544932, 3.1009497167542577, 2.537558935582638, 66.81096374988556, 67.23030924797058, 63.814490139484406, 58.42517092823982, 47.117733880877495, 54.5249880105257, 61.10765978693962, 61.213373914361, 61.04856535792351, 62.74056136608124, 60.928586795926094, 60.257956981658936, 61.18644095957279, 59.82807844877243, 56.79785504937172, 58.939727917313576, 55.76380513608456, 52.24716603755951, 49.013562351465225, 50.86619094014168, 47.92934373021126, 54.67389442026615, 57.54734583199024, 53.018080070614815, 49.2282622307539, 44.564438089728355, 43.290507048368454, 42.4490612000227, 42.16607138514519, 42.37918674945831, 42.862794399261475, 43.185222297906876, 42.08909131586552, 42.29236140847206, 42.41461604833603, 43.678390234708786, 42.723843455314636, 41.99930973351002, 43.72991926968098, 44.915801435709, 41.507616117596626, 41.02777786552906, 43.96595120429993, 41.494803205132484, 44.00467112660408, 45.018802508711815, 41.89773738384247, 42.338559329509735, 43.26366908848286, 42.079082652926445, 42.8087043017149, 43.04192818701267, 42.09510639309883, 43.76984752714634, 43.51496480405331, 41.87811903655529, 43.85006122291088, 45.24256870150566, 43.93467888236046, 46.252839490771294, 50.25587908923626, 54.46410767734051, 54.68374729156494, 58.13656881451607, 46.66881836950779, 47.402790784835815, 55.199831798672676, 52.43593230843544, 48.24456721544266, 45.78534297645092, 44.54467535018921, 43.81718538701534, 42.3225811868906, 43.165489956736565, 44.2854418605566, 43.558369874954224, 43.31699922680855, 42.77794115245342, 42.490478977561, 44.02262896299362, 44.4421112537384, 44.3942566215992, 42.740915939211845, 44.77607533335686, 44.190363362431526, 45.64472012221813, 44.98305022716522, 44.66189906001091, 43.52325975894928, 41.27439983189106, 44.02900882065296, 43.69468376040459, 42.85899080336094, 41.87363527715206, 41.53351552784443, 42.90997266769409, 42.01460391283035, 44.27993215620518, 43.22988510131836, 44.37448628246784, 42.716631442308426, 44.52351048588753, 45.309312120079994, 45.13878487050533, 43.82610350847244, 46.41287550330162, 50.44149152934551, 53.07681731879711, 54.43912781774998, 58.62660951912403, 57.91072033345699, 58.93881596624851, 60.285148322582245, 63.06168973445892, 59.53888736665249, 59.21502314507961, 61.40856184065342, 61.52773104608059, 61.97051748633385, 62.30605088174343, 55.826573967933655, 52.370465621352196, 46.40397258102894, 52.59629510343075, 55.00543802976608, 61.745957136154175, 58.11532035470009, 62.53837041556835, 14.472049735486507, 0.5738713312894106, 1.725281747058034, 0.7962568325456232, 0.1381878973916173, 6.285267909988761, 66.9954514503479, 65.58415398001671, 63.16038563847542, 46.60267531871796, 44.34373453259468, 22.042028233408928, 46.349320113658905, 56.8091556429863, 65.24523496627808, 23.472478576004505, 0.9513898612931371, 0.033918853951036, 0.012637116233236156, 0.0014542491567226534, 0.029643571251654066, 0.06439630233217031, 0.06682167804683559, 0.04603093781042844, 0.11204109221580438, 0.10614326689392328, 0.24643412878504023, 0.10801388722029515, 0.1853019106783904, 0.08670266397530213, 0.29529391089454293, 0.3333488688804209, 2.002288307994604, 53.05740416049957, 76.19516059756279, 66.72840178012848, 52.5527760386467, 22.12053582072258, 60.078845992684364, 58.564752638339996, 66.96735575795174, 72.9110500216484, 70.76959133148193, 14.22288665547967, 0.631021095905453, 0.6225670245476067, 3.880931963212788, 3.0958848260343075, 70.77975958585739, 70.22601529955864, 67.3425780236721, 60.87823189795017, 49.638720005750656, 58.78216177225113, 64.07197952270508, 64.3110778927803, 64.03228685259819, 64.3854171037674, 63.726612254977226, 63.06333504617214, 64.91909846663475, 61.22342437505722, 58.44016872346401, 59.16652254760265, 56.243252009153366, 53.21916148066521, 50.9466478228569, 49.32513803243637, 49.5130455493927, 56.706713140010834, 60.64585156738758, 55.916784927248955, 52.32958361506462, 48.43286991119385, 45.27848817408085, 44.428169801831245, 45.5113472789526, 44.83680747449398, 43.23101744055748, 44.82858471572399, 44.45033401250839, 44.179419949650764, 45.27758002281189, 47.761225551366806, 45.97037024796009, 44.06827971339226, 44.90803845226765, 47.432193607091904, 43.754553347826004, 43.611563220620155, 44.160914942622185, 42.74145171046257, 46.144115924835205, 47.40034371614456, 45.75547657907009, 44.95245806872845, 46.580590903759, 43.09620067477226, 44.30839642882347, 44.87970717251301, 44.51134353876114, 45.6685334444046, 46.02382957935333, 43.05863969027996, 45.466589480638504, 48.09474505484104, 45.7233265042305, 48.893997967243195, 53.83956179022789, 58.13312999904156, 57.92400822043419, 60.68930983543396, 49.53804440796375, 52.50684030354023, 59.44515399634838, 54.75935563445091, 51.37524962425232, 48.005377650260925, 47.35531233251095, 46.54768846929073, 44.75529044866562, 46.84438414871693, 48.36006961762905, 44.74328689277172, 45.97165837883949, 44.49978455901146, 44.12672817707062, 45.867540165781975, 47.579131722450256, 46.99441149830818, 45.94263173639774, 46.50182493031025, 45.935480520129204, 47.3153954744339, 47.64465920627117, 46.58275678753853, 45.24670667946339, 44.61895376443863, 46.27328999340534, 47.69462652504444, 45.4229412227869, 43.41577872633934, 44.235056564211845, 44.01444800198078, 43.44253309071064, 46.183261424303055, 46.49267882108688, 46.684986501932144, 44.14452642202377, 47.3160794377327, 47.86207593977451, 48.578679487109184, 45.79310216009617, 48.3518772572279, 53.31619307398796, 55.231909677386284, 58.376081362366676, 62.04775594174862, 58.61947350203991, 62.0727813988924, 62.837133184075356, 66.8832890689373, 63.21510270237923, 64.90265294909477, 63.32550197839737, 64.13282185792923, 63.03447559475899, 64.232437312603, 59.34371083974838, 52.84091077744961, 47.4780647456646, 54.001421704888344, 56.270751133561134, 64.76138412952423, 59.49237406253815, 66.62332981824875, 15.757240522652864, 1.608154575806111, 4.200702141970396, 1.3349018571898341, 0.26184564165305346, 7.437019357457757, 74.93944197893143, 72.2775936126709, 73.73549178242683, 62.24357083439827, 47.86424182355404, 25.336348861455917, 59.46896351873875, 66.60111621022224, 76.04838207364082, 31.592724546790123, 1.3113775569945574, 0.13164040341507643, 0.10254559470922686, 0.21259554923744872, 0.10709178357501514, 0.1503221009625122, 0.20595503447111696, 0.16161427862243727], [0.040638785940245725, 0.03756745230930392, 0.04192039334157016, 0.07539694212027825, 0.024469625641359016, 0.02225721847935347, 0.07035590402665548, 0.039519864731119014, 1.3107845513150096, 35.59003405272961, 54.46574918925762, 47.70229071378708, 32.281391993165016, 25.792043209075928, 45.218766778707504, 34.38265644013882, 60.197217240929604, 57.88879930973053, 61.611592546105385, 8.698045816272497, 0.4013872757786885, 0.08456854411633685, 1.2802419089712203, 3.7326734187081456, 64.27273035049438, 66.3397890329361, 58.73982064425945, 51.070680767297745, 53.1067331135273, 60.88936150074005, 58.36665786802769, 60.58259256184101, 61.10010579228401, 56.97217829525471, 57.64767564833164, 54.10309664905071, 55.517563149333, 53.57850439846516, 53.633631840348244, 53.505981490015984, 53.412384912371635, 55.84008604288101, 61.37766569852829, 50.02020813524723, 49.21655125916004, 53.91370341181755, 54.48650747537613, 52.836286425590515, 48.8737678527832, 44.201964139938354, 40.72704300284386, 40.02179704606533, 39.67834107577801, 40.02855688333511, 41.20621629059315, 41.80018901824951, 40.27915723621845, 41.98286421597004, 40.9232796728611, 40.63855715095997, 40.393493101000786, 42.72323548793793, 41.657259687781334, 42.36050695180893, 40.53435154259205, 41.25921204686165, 41.01631388068199, 41.14389203488827, 41.466737911105156, 42.03815124928951, 42.059152722358704, 44.15682636201382, 43.10144819319248, 40.439387038350105, 40.68666256964207, 40.920798406004906, 39.27261404693127, 42.15094059705734, 38.606353998184204, 41.32813274860382, 40.86671210825443, 42.214784771203995, 41.15925841033459, 42.389468997716904, 45.192776173353195, 53.214024156332016, 48.820756897330284, 56.20379872620106, 34.948343485593796, 46.037767231464386, 54.86245170235634, 48.826099410653114, 45.135536044836044, 42.16229818761349, 41.11295789480209, 40.833589285612106, 42.55618505179882, 40.50460293889046, 40.104423612356186, 42.058031782507896, 42.75309048593044, 42.13288776576519, 42.10156984627247, 42.30047397315502, 40.76245330274105, 42.28089742362499, 41.87276892364025, 43.02235923707485, 43.47349002957344, 43.19006323814392, 41.27876579761505, 43.55365812778473, 41.739643067121506, 40.91390937566757, 40.123433992266655, 42.38530062139034, 40.15738137066364, 43.17586340010166, 40.77850744128227, 39.91508737206459, 41.21305972337723, 41.994085013866425, 40.25122873485088, 41.797095984220505, 40.05119226872921, 39.85144078731537, 42.891349866986275, 43.2667051255703, 40.762593895196915, 42.66999274492264, 43.45258355140686, 46.28549873828888, 51.39815479516983, 54.948748871684074, 56.776276007294655, 56.969921216368675, 53.284939751029015, 57.32260309159756, 55.50820805132389, 57.738711163401604, 56.421150863170624, 58.40918518602848, 55.763478353619576, 60.001858323812485, 57.08189740777016, 66.44230753183365, 63.82493957877159, 66.53123795986176, 59.39838230609894, 63.89614775776863, 56.8170478194952, 57.07028903067112, 11.685401815921068, 0.5910208798013628, 0.7087004464119673, 0.30961552052758634, 0.08266777032986283, 2.3081671446561813, 52.364393547177315, 66.0412010550499, 58.48436415195465, 55.47463685274124, 21.298601925373077, 12.34525540843606, 35.92241361737251, 48.94813746213913, 57.17667192220688, 31.973806098103523, 1.5900372667238116, 0.05840566402184777, 0.05971454535028897, 0.03865098791720811, 0.12982883577933535, 0.026631468426785432, 0.05124389070260804, 0.03060030721826479, 0.060728604803443886, 0.028255554716452025, 0.018453897173458245, 0.021664927116944455, 0.045528522387030534, 0.043684563715942204, 0.043866545747732744, 0.05133242149895523, 1.727286851964891, 46.95953696966171, 60.93929082155228, 56.57224215567112, 39.04213361442089, 29.34109076857567, 51.8704504519701, 39.8554951697588, 66.66538596153259, 61.73587627708912, 68.15047547221184, 9.397551231086254, 0.4558747785631567, 0.21947908768197522, 3.911020173691213, 4.207514226436615, 64.80885118246078, 68.96769002079964, 62.57320694625378, 53.06903913617134, 54.7369634360075, 62.094307243824005, 61.44777573645115, 62.24705524742603, 61.61645248532295, 57.63301223516464, 59.27751459181309, 55.21646350622177, 54.4931723177433, 55.021879747509956, 57.25315801799297, 54.060994908213615, 54.98462654650211, 58.29785875976086, 59.56541754305363, 53.640228286385536, 51.48116894066334, 56.46330580115318, 56.15451157093048, 54.13021579384804, 50.530786737799644, 46.17187723517418, 42.68795058131218, 42.99687780439854, 42.027356028556824, 41.89688242971897, 43.9217633754015, 44.2790924012661, 42.393834963440895, 43.1256452947855, 43.14172983169556, 41.761320903897285, 43.67991395294666, 43.36005471646786, 44.25907887518406, 43.50334882736206, 41.51842653751373, 42.747903764247894, 42.86665499210358, 43.83221358060837, 43.75106133520603, 44.43283975124359, 44.38149310648441, 45.11863075196743, 43.932300209999084, 42.84588150680065, 41.76135890185833, 44.32558670639992, 40.348739102482796, 42.84719243645668, 41.17615610361099, 44.01477098464966, 44.15453128516674, 45.63782349228859, 43.52020852267742, 44.51685704290867, 47.688197270035744, 55.961101949214935, 52.33764298260212, 58.663364946842194, 39.25063982605934, 48.604157119989395, 56.35329410433769, 51.604571118950844, 47.511575147509575, 44.2553398758173, 43.51258993148804, 44.31378833949566, 44.887473955750465, 44.28971283137798, 42.610187754034996, 44.659923166036606, 43.146916553378105, 43.88550952076912, 44.0522825717926, 42.92486026883125, 42.5966414809227, 43.36724393069744, 42.984365075826645, 42.90364220738411, 44.68480043113232, 45.051575750112534, 44.243381917476654, 45.706018432974815, 42.90724441409111, 42.43536673486233, 42.252463549375534, 42.51341454684734, 41.73498831689358, 45.19770830869675, 44.4650886207819, 42.795120030641556, 43.434758707880974, 43.97059075534344, 44.05308052897453, 42.62487396597862, 41.0827799141407, 42.485421448946, 44.10127714276314, 43.90546225011349, 43.81645582616329, 44.73974168300629, 45.49324885010719, 48.77118855714798, 53.30333836376667, 56.9716577231884, 58.781652599573135, 59.12562534213066, 56.53264448046684, 59.68117073178291, 57.51082979142666, 59.269812405109406, 56.42993979156017, 60.316815823316574, 56.04582220315933, 59.943444058299065, 60.99941499531269, 66.85363546013832, 65.46655789017677, 68.43334749341011, 61.788370460271835, 65.19511565566063, 57.17097222805023, 60.26630513370037, 14.122161660343409, 0.7046467170584947, 1.2461637938395143, 0.7715285907033831, 0.20654674881370738, 2.8370021050795913, 55.4262388497591, 72.12056323885918, 63.54184716939926, 57.99689590930939, 22.92504195123911, 19.833476543426514, 45.21383084356785, 56.83132365345955, 67.17327430844307, 40.365435406565666, 2.365077640861273, 0.10981457497109659, 0.04473801265703514, 0.025701314334583003, 0.03160831816785503, 0.03517673489113804, 0.014374970978678903, 0.029975205507071223, 0.1423392043216154, 0.19057571596931666, 0.13178472145227715, 0.2603398833889514, 0.16423293185653165, 0.1432004667003639, 0.11940377604332753, 0.17072993010515347, 3.3375304844230413, 61.10572949051857, 70.88002100586891, 64.90616396069527, 46.843130216002464, 38.04558768868446, 58.22236441075802, 49.14896048605442, 71.55450761318207, 67.79305145144463, 74.43096086382866, 10.745623894035816, 0.5969798506703228, 0.9004594129510224, 4.738710047677159, 4.563128594309092, 69.33506190776825, 72.33598127961159, 65.32136768102646, 55.787352472543716, 57.92417921125889, 64.29179012775421, 64.46788027882576, 64.18159604072571, 64.72360655665398, 59.228694811463356, 60.484041050076485, 55.22066228091717, 55.76254740357399, 55.20280323922634, 58.08842159807682, 55.01275643706322, 56.694614589214325, 56.3412069529295, 58.28466586768627, 55.623471066355705, 53.35697628557682, 58.73000957071781, 60.50940848886967, 56.71756915748119, 52.95786090195179, 48.70739758014679, 45.091435611248016, 43.63816559314728, 44.568306282162666, 44.30485121905804, 47.082893550395966, 46.37695223093033, 43.8924403488636, 45.70022754371166, 45.891490280628204, 43.778720051050186, 46.03595852851868, 46.244343146681786, 47.77675911784172, 47.04174555838108, 44.09032993018627, 46.135790571570396, 45.791726633906364, 45.720324665308, 44.22359637916088, 45.6097088009119, 45.81675209105015, 48.630835488438606, 48.429138511419296, 45.332183092832565, 45.99728800356388, 46.71475030481815, 42.699129581451416, 45.79394571483135, 42.646426409482956, 45.33397659659386, 47.29734644293785, 48.46707567572594, 45.980956479907036, 45.998690128326416, 50.367422103881836, 57.41528391838074, 54.7569427639246, 59.54388789832592, 42.49855354428291, 51.8011649698019, 58.474575877189636, 52.67665699124336, 48.25219340622425, 46.586389392614365, 46.550975292921066, 46.720248609781265, 46.92786566913128, 47.26169295608997, 45.42594686150551, 47.81751953065395, 46.55224822461605, 45.82103066146374, 47.08094045519829, 46.038838773965836, 45.68140335381031, 48.20691503584385, 44.12933863699436, 44.579401686787605, 47.68976278603077, 49.5297646522522, 45.977380871772766, 47.89221212267876, 45.530699640512466, 44.340573102235794, 43.35615232586861, 44.94046211242676, 43.291597589850426, 47.67644450068474, 47.488696575164795, 44.470856711268425, 45.61119072139263, 46.94410599768162, 43.485592380166054, 45.495832711458206, 43.21517989039421, 44.004967510700226, 46.48193679749966, 47.9403555393219, 46.53324544429779, 45.38446448743343, 47.46184341609478, 50.87320156395435, 55.69780267775059, 60.108233615756035, 61.85544826090336, 61.77355885505676, 59.09241132438183, 61.029353588819504, 58.21902438998222, 60.82470417022705, 59.15086358785629, 62.328899055719376, 57.215540036559105, 62.643419578671455, 59.3580436706543, 71.17993891239166, 66.94720923900604, 72.16770350933075, 63.33155885338783, 66.67771250009537, 57.5871866941452, 62.643822357058525, 16.556463986635208, 2.1590828569605947, 2.7176075242459774, 1.7362894001416862, 0.26808131486177444, 3.097022627480328, 62.03854523599148, 76.2702901661396, 74.07124936580658, 69.05056357383728, 29.29856915026903, 23.177105225622654, 49.043618738651276, 65.62722086906433, 76.85703948140144, 52.03806705772877, 2.9837623424828053, 0.21156399365281686, 0.15647578169591725, 0.1266972249140963, 0.18438929168041795, 0.13229589792899787, 0.13132116117049009, 0.11959012190345675], [0.048898767126956955, 0.0787034178210888, 0.02132250760041643, 0.024015761518967338, 0.050616928056115285, 0.08546922195819207, 0.12321077840169892, 0.08876135194441304, 7.707360126078129, 47.76222489774227, 54.89909693598747, 46.999241039156914, 35.41340813040733, 15.93526666983962, 25.912179462611675, 41.09525844454765, 62.02695205807686, 59.287321865558624, 57.062396854162216, 5.9767258912324905, 0.3882777417311445, 0.2329092740546912, 3.4039962803944945, 1.6320271510630846, 60.31525790691376, 66.24000638723373, 62.6642082631588, 56.22563235461712, 58.71440000832081, 56.787793189287186, 63.145634829998016, 55.05217172205448, 47.55134381353855, 52.10606440901756, 50.51605112850666, 54.08640414476395, 57.05461487174034, 57.42409564554691, 55.91295853257179, 54.02949459850788, 49.91459660232067, 46.86023309826851, 53.12480874359608, 57.66955867409706, 49.39526326954365, 52.644168734550476, 52.695576176047325, 53.52569103240967, 49.63888719677925, 44.953400418162346, 40.38777060806751, 40.63595809042454, 37.125497460365295, 40.75782135128975, 40.0524728000164, 39.58073951303959, 38.79684157669544, 41.13481052219868, 41.08127139508724, 41.45688124001026, 40.39425686001778, 41.9595068693161, 41.55934654176235, 41.454662159085274, 40.19452437758446, 40.83345629274845, 41.92482613027096, 42.58692920207977, 43.548243418335915, 43.72494533658028, 40.037801787257195, 43.018863424658775, 40.34083932638168, 42.574291080236435, 39.87046256661415, 40.08346013724804, 40.642995312809944, 42.67071470618248, 40.44446736574173, 41.40095964074135, 41.06422930955887, 41.47808410227299, 42.41471104323864, 42.25213296711445, 44.85917687416077, 52.27556951344013, 49.84224088490009, 58.270777612924576, 37.788246497511864, 50.03401279449463, 53.50559391081333, 50.0370754301548, 45.727027505636215, 42.219732105731964, 42.27183111011982, 40.58132842183113, 41.80542513728142, 39.68506671488285, 41.057100892066956, 41.870405450463295, 41.3012719899416, 43.7003568559885, 40.91029576957226, 42.422622218728065, 42.6497208327055, 41.39212891459465, 42.07757033407688, 42.74005338549614, 44.06635321676731, 42.464716359972954, 43.15089873969555, 41.5904288738966, 42.03584857285023, 42.1175441890955, 40.682775378227234, 39.732157588005066, 41.102333664894104, 42.73946061730385, 39.71351198852062, 41.33007064461708, 40.975386276841164, 40.751779675483704, 42.546267583966255, 41.869907677173615, 39.881090596318245, 42.06694230437279, 40.9341736882925, 40.2182275056839, 40.54550014436245, 42.48509846627712, 42.85238295793533, 42.31963254511356, 44.0086305141449, 51.92523591220379, 55.07223844528198, 58.58866095542908, 57.140482664108276, 54.57177110016346, 56.95036366581917, 59.7197500616312, 58.001353070139885, 59.3387521058321, 60.609992891550064, 61.62562899291515, 61.45071677863598, 61.04440078139305, 59.43602688610554, 60.343733578920364, 63.287097439169884, 63.957841247320175, 63.81734758615494, 63.676215559244156, 17.055109329521656, 0.30488676333334297, 0.673500916454941, 0.35990597039926797, 0.06575424704351462, 0.6107525085099041, 44.66219164431095, 65.3249242901802, 62.446643337607384, 47.66364298760891, 45.10438531637192, 24.19379387050867, 24.651182927191257, 45.1498194783926, 51.18544600903988, 40.22588409483433, 4.408269803971052, 0.2641186024993658, 0.04849819291848689, 0.013613326154882088, 0.030594780073442962, 0.02812923747114837, 0.06022022993420251, 0.02037246580584906, 0.023430503861163743, 0.05047591999755241, 0.0870485938503407, 0.029268474972923286, 0.06407924942323007, 0.032916201307671145, 0.08465135295409709, 0.10066112590720877, 10.28672156855464, 58.96891415119171, 62.325623631477356, 55.08443959057331, 39.57983136177063, 18.29416774213314, 33.08002173900604, 44.17685888707638, 68.59204977750778, 64.72154706716537, 61.4579401910305, 6.958087356761098, 0.4496044619008899, 0.2551488869357854, 5.183487106114626, 1.8274418776854873, 62.56767064332962, 69.59994569420815, 62.67704397439957, 58.99316065013409, 59.839401841163635, 59.84507493674755, 63.77311035990715, 56.57941237092018, 49.25280511379242, 52.253732085227966, 49.768718630075455, 54.047308042645454, 58.134980499744415, 57.660283371806145, 56.61107987165451, 56.23738892376423, 52.15142637491226, 50.19035920500755, 56.05208806693554, 54.806564301252365, 51.44945204257965, 55.477657690644264, 53.5147438198328, 55.50816245377064, 52.95326694846153, 48.35731856524944, 41.54377497732639, 42.591732144355774, 41.12045869231224, 41.053730472922325, 41.20228350162506, 43.90316717326641, 42.06175938248634, 44.1070756316185, 41.210631653666496, 43.0494099855423, 41.48065656423569, 42.7897585183382, 44.74824942648411, 44.83782202005386, 41.7649345099926, 43.14000852406025, 44.72828149795532, 46.14063151180744, 44.999423548579216, 44.73140113055706, 43.182459846138954, 44.779571145772934, 42.448012456297874, 43.006069511175156, 41.6809856146574, 42.08139292895794, 41.62912219762802, 43.03025521337986, 42.240159809589386, 44.48536813259125, 44.743134900927544, 43.980956599116325, 45.76810710132122, 44.82511170208454, 46.18807576596737, 54.06031854450703, 50.959555730223656, 58.029007986187935, 39.85905937850475, 52.36160829663277, 55.578618273139, 53.01707312464714, 46.95613615214825, 45.62403403222561, 43.794128224253654, 43.537319004535675, 43.12069796025753, 42.403946220874786, 42.545359432697296, 44.72000174224377, 44.13370840251446, 44.97650697827339, 42.99610264599323, 42.80620023608208, 44.79437135159969, 42.58846811950207, 43.868209049105644, 44.668043330311775, 44.300663843750954, 43.65626402199268, 44.951975494623184, 45.54117947816849, 43.07000108063221, 43.32757405936718, 43.52818809449673, 42.575096637010574, 43.24112109839916, 43.1692099571228, 43.639681711792946, 43.918734937906265, 43.86209137737751, 44.087898060679436, 43.898067846894264, 43.5982259362936, 43.2763946056366, 43.13304729759693, 41.833281442523, 41.9422671943903, 43.44602510333061, 43.76959674060345, 45.03197640180588, 42.87262827157974, 46.91247269511223, 53.5061676800251, 57.5565717369318, 59.24023859202862, 58.46350707113743, 58.668707460165024, 58.21232154965401, 59.692809507250786, 58.61899092793465, 60.427925661206245, 60.35449460148811, 61.486754044890404, 62.11939349770546, 63.1334412842989, 60.8772287517786, 62.79183201491833, 66.10921740531921, 66.67777329683304, 65.66543161869049, 65.39825275540352, 19.89868864417076, 0.31218709191307425, 1.1770836194045842, 1.71443558530882, 0.20680746529251337, 0.3895337227731943, 46.18998326361179, 69.98070806264877, 66.95534840226173, 50.99926359951496, 35.586697831749916, 18.731554672122, 28.397388607263565, 52.03745909035206, 59.245809093117714, 50.374444127082825, 5.751505326479673, 0.09066436701687053, 0.02615454392071115, 0.034313580035814084, 0.002840794268195168, 0.020302195553085767, 0.04669142326747533, 0.05787087240605615, 0.10137784760445356, 0.16531348403077573, 0.21360797225497663, 0.12874832813395187, 0.16883613250683993, 0.1868012419436127, 0.20062167925061658, 0.24700853624381125, 13.55174196884036, 73.61244678497314, 71.78242698311806, 63.076782524585724, 51.12567901611328, 24.21540331095457, 35.99253885447979, 55.57010293006897, 73.81796255707741, 68.2895328104496, 66.65259584784508, 7.961930315941572, 0.6956607929896563, 1.0686439694836736, 8.496566377580166, 2.1205325005576015, 65.52310645580292, 71.09900325536728, 67.21248060464859, 61.38301961123943, 63.38759444653988, 60.43413832783699, 65.42355179786682, 62.48486548662186, 49.72851298749447, 52.86100409924984, 50.26605114340782, 55.3884232789278, 61.14385664463043, 59.50998991727829, 58.456652238965034, 59.145361483097076, 55.524436980485916, 53.33013452589512, 57.18566983938217, 54.589774534106255, 51.231396943330765, 59.35506083071232, 56.632161140441895, 58.08098539710045, 55.231138318777084, 49.329944774508476, 44.255123287439346, 45.78582555055618, 42.97105059027672, 44.03882369399071, 42.33139291405678, 45.94820223748684, 42.94515497982502, 46.95105962455273, 43.90509366989136, 47.381945103406906, 44.81884963810444, 44.7355543076992, 47.551279217004776, 45.9013507515192, 43.82941693067551, 43.740695491433144, 48.28686274588108, 47.3481535166502, 48.44339534640312, 46.96701116859913, 44.60126951336861, 47.66062594950199, 43.004773780703545, 46.887147054076195, 44.62323993444443, 44.536995962262154, 43.83024908602238, 45.694071874022484, 45.578333884477615, 46.70256815850735, 46.87933847308159, 45.76623760163784, 47.97261580824852, 47.86353126168251, 48.7861293554306, 56.741933450102806, 53.389582335948944, 61.629094406962395, 43.38654689490795, 57.00480714440346, 58.183876276016235, 55.822397992014885, 50.460239723324776, 48.975112214684486, 44.65172700583935, 43.89262653887272, 45.92389114201069, 44.664045944809914, 44.86531734466553, 47.877590507268906, 46.498845890164375, 48.42357560992241, 44.28096570074558, 46.362543404102325, 47.50863030552864, 44.53022852540016, 44.99537296593189, 47.200888618826866, 47.77043625712395, 45.21699607372284, 47.08445526659489, 46.898877024650574, 45.51361955702305, 46.38638332486153, 45.11830776929855, 43.04173059761524, 46.09516315162182, 47.32516095042229, 45.8524701744318, 45.588692128658295, 44.84584338963032, 44.49147440493107, 46.51934579014778, 45.206333845853806, 44.42992530763149, 46.154029592871666, 45.02754583954811, 44.61710326373577, 44.83815640211105, 47.084573060274124, 47.43255838751793, 45.76493427157402, 49.97514255344868, 56.5967508405447, 59.17094171047211, 62.13463447988033, 60.57476498186588, 61.25847369432449, 60.65566264092922, 62.23710358142853, 60.872642397880554, 63.85238930583, 63.81410256028175, 65.14190331101418, 66.77765473723412, 66.77143827080727, 65.54961383342743, 67.52389669418335, 69.19305592775345, 70.46956703066826, 69.24315243959427, 68.08242872357368, 22.263943925499916, 0.9072964929509908, 6.370616080239415, 4.978122375905514, 0.5974193208385259, 0.8006169798318297, 52.319229170680046, 75.82550123333931, 75.77362641692162, 61.41188286244869, 56.744042336940765, 32.43337243795395, 37.769262716174126, 61.6304699331522, 68.4105259180069, 63.43884229660034, 7.770481389015913, 0.4028154647676274, 0.19451313593890518, 0.08842268027365208, 0.14645574905443937, 0.11637344607152045, 0.21055807184893638, 0.10998997415299527], [0.03064617565541994, 0.048632989200996235, 0.06524764219648205, 0.0490407770848833, 0.026675780209188815, 0.12261330499313772, 0.07217683756607585, 0.053848662064410746, 9.207144398242235, 52.694109454751015, 51.661716252565384, 45.832441449165344, 24.99757044017315, 23.765309862792492, 42.677732929587364, 40.52536502480507, 64.23898816108704, 57.87752911448479, 59.885356575250626, 4.554254645481706, 0.09916614362737164, 0.16397779632825404, 2.813901244662702, 0.15322714898502454, 43.002509102225304, 73.30446571111679, 56.83206461369991, 62.881199419498444, 55.94459943473339, 66.69658228754997, 41.550215631723404, 48.56869362294674, 56.31932392716408, 56.41498379409313, 57.159766629338264, 59.25075262784958, 57.77349829673767, 58.685635551810265, 57.33258135616779, 55.81433482468128, 57.42592714726925, 53.08051072061062, 38.6551433801651, 51.644301787018776, 56.57469302415848, 51.29888892173767, 50.141053050756454, 53.516229540109634, 51.39472357928753, 46.65429934859276, 42.1944672614336, 39.96447332203388, 39.9507674574852, 39.746049642562866, 38.71992610394955, 40.173899084329605, 40.081210657954216, 38.85823108255863, 40.65715715289116, 40.14497883617878, 40.76781861484051, 40.91944567859173, 40.69688782095909, 41.36170394718647, 38.017461597919464, 38.97486962378025, 42.04472869634628, 40.530969724059105, 40.26533357799053, 42.923807725310326, 41.789720579981804, 40.461228266358376, 39.27948407828808, 40.516211315989494, 40.71760430932045, 42.02142454683781, 40.838681012392044, 39.596026092767715, 41.08230493962765, 43.11924263834953, 41.92195728421211, 43.416341096162796, 42.75546915829182, 44.49688911437988, 44.89450357854366, 52.3011839389801, 50.42094983160496, 55.48082672059536, 40.818025320768356, 49.720715805888176, 54.488741755485535, 48.809266313910484, 43.7743578851223, 42.34368905425072, 41.607790142297745, 42.13668376207352, 44.918130710721016, 40.830861032009125, 39.66361306607723, 42.51232020556927, 42.51966141164303, 41.310368701815605, 41.809555515646935, 40.92298708856106, 41.34561561048031, 40.69815315306187, 42.44637854397297, 42.499902471899986, 43.51440243422985, 42.21739903092384, 42.84238189458847, 41.7879156768322, 40.28242126107216, 41.11787103116512, 42.58340299129486, 42.48503006994724, 40.766564682126045, 42.49886512756348, 39.105069637298584, 42.06411525607109, 39.45295996963978, 40.91219186782837, 41.451808512210846, 41.546769216656685, 41.25031292438507, 40.59420593082905, 40.06532371044159, 40.402308627963066, 42.069640159606934, 41.0632261633873, 39.71734218299389, 42.48436130583286, 41.16646662354469, 42.85294912755489, 47.73887135088444, 52.944831401109695, 58.87957714498043, 60.2733613550663, 58.889870792627335, 59.63481321930885, 59.38847243785858, 59.61687058210373, 56.92315332591534, 59.40287746489048, 57.922701090574265, 59.75123517215252, 57.76879034936428, 61.25432051718235, 58.17133694887161, 62.99526169896126, 62.28333570063114, 67.21862867474556, 25.997965559363365, 0.6878147483803332, 0.060329707848723046, 0.5564712337218225, 0.08154535360517912, 0.130292663234286, 34.71658252179623, 67.82386779785156, 60.49688436090946, 55.40641911327839, 59.128072410821915, 35.66113583743572, 25.606704354286194, 36.779092848300934, 49.788561165332794, 47.92276628315449, 6.1336166225373745, 0.2702464861795306, 0.05783557215181645, 0.03214338808902539, 0.05825239568366669, 0.04973162751412019, 0.016726793364796322, 0.029810001578880474, 0.042018583189928904, 0.07044894708087668, 0.03593471999920439, 0.03009564123203745, 0.0570961555786198, 0.07388137266389094, 0.14523185847792774, 0.07566612650407478, 11.185337249189615, 63.43508429825306, 59.721535965800285, 54.58532877266407, 37.48058460652828, 29.09536935389042, 38.63243579864502, 48.403900265693665, 71.01083278656006, 62.63331972062588, 64.18703734874725, 4.891236238181591, 0.11589933987124823, 0.4025888425530866, 7.591911870986223, 0.20378186280140653, 45.904352590441704, 75.19433230161667, 59.4443104416132, 65.03178521990776, 58.19125548005104, 69.28381025791168, 43.90094429254532, 48.44122186303139, 56.09155274927616, 57.789134457707405, 56.91585771739483, 61.97383090853691, 61.3435473293066, 59.54012230038643, 58.090568482875824, 57.31795594096184, 57.88286782801151, 55.18660470843315, 41.832434087991714, 53.178659453988075, 57.391949370503426, 54.05773848295212, 53.01913641393185, 55.30055299401283, 53.915086537599564, 49.77083511650562, 44.182824566960335, 42.845550924539566, 41.64956510066986, 41.5172827988863, 40.140472277998924, 43.6688831448555, 40.5957106500864, 42.09617033600807, 43.354366421699524, 42.21023641526699, 42.84131795167923, 42.612957805395126, 43.94073575735092, 42.6095911860466, 41.26939930021763, 42.23056152462959, 45.533811673521996, 43.84153828024864, 42.344167828559875, 45.493131056427956, 42.82460644841194, 42.950657084584236, 41.60137228667736, 43.007441237568855, 42.51434929668903, 43.99275116622448, 42.318921983242035, 42.270565778017044, 41.246038153767586, 43.62237364053726, 44.57988806068897, 46.53326824307442, 45.71471996605396, 45.234433338046074, 47.45533436536789, 53.79548795521259, 51.28486767411232, 57.2055047750473, 43.02878089249134, 50.87452009320259, 56.91395781934261, 52.427086383104324, 46.040047109127045, 43.79611171782017, 44.18079547584057, 45.436320304870605, 46.07952319085598, 42.796962931752205, 42.164414674043655, 44.58427682518959, 44.21491764485836, 43.22621449828148, 43.473330438137054, 42.703886926174164, 43.39778669178486, 42.25253574550152, 43.49578343331814, 44.32247847318649, 43.99854205548763, 43.2955227792263, 44.05325911939144, 44.04443599283695, 43.42598497867584, 43.791418969631195, 44.41879190504551, 44.33523818850517, 42.688022777438164, 43.4367536008358, 42.47990794479847, 44.682106375694275, 41.345896795392036, 43.09869334101677, 43.3926797658205, 43.0135665088892, 43.88907752931118, 41.30288690328598, 42.12576314806938, 41.734129562973976, 43.22646148502827, 42.336621433496475, 43.01756389439106, 44.76157911121845, 43.38345006108284, 45.051457956433296, 50.67400485277176, 54.356983825564384, 61.12502485513687, 61.19087532162666, 59.70227859914303, 62.50975415110588, 61.98776476085186, 62.89859488606453, 60.1174671202898, 60.80422706902027, 60.272722989320755, 63.32982614636421, 60.028681084513664, 60.92917196452618, 60.272852182388306, 64.81026470661163, 63.36049810051918, 69.5201575756073, 27.515815012156963, 0.3223627677652985, 0.8523525099735707, 2.5011929869651794, 0.2015675464645028, 0.15877679572440684, 36.92934438586235, 72.05434799194336, 66.80884346365929, 58.96475337445736, 57.97034673392773, 36.330827102065086, 31.729800291359425, 44.92750480771065, 57.65598200261593, 60.53970046341419, 9.244239907711744, 0.35661781090311706, 0.06542834773426875, 0.039828253065934405, 0.020244710649421904, 0.07379578819382004, 0.05688085853762459, 0.019227348639105912, 0.13278078753501177, 0.17318557802354917, 0.291111582191661, 0.1785557734547183, 0.13619202480185777, 0.2416762794018723, 0.2778084366582334, 0.18443913431838155, 16.273686960339546, 75.32449051737785, 67.39044785499573, 62.41642355918884, 38.23283404111862, 33.270178735256195, 54.76248286664486, 57.686695754528046, 76.45272597670555, 69.05794277787209, 70.3740705549717, 5.460069989785552, 0.301276333630085, 0.9159838361665606, 9.474740289151669, 0.4759076895425096, 46.29636995494366, 79.38816726207733, 60.67278832197189, 68.81840363144875, 59.341826140880585, 72.56440982222557, 46.286995857954025, 49.54877123236656, 55.96435457468033, 57.22351960837841, 59.25665371119976, 65.08942052721977, 63.56047376990318, 63.683108389377594, 61.17070220410824, 60.263041108846664, 60.566405430436134, 56.8646364659071, 45.81832520663738, 56.20878025889397, 57.71348811686039, 56.4936737716198, 54.19962666928768, 58.596625328063965, 55.90354263782501, 51.456196680665016, 47.18057110905647, 45.73238901793957, 44.19130191206932, 44.890156611800194, 42.955441027879715, 45.78005366027355, 43.28542672097683, 45.27108617126942, 46.64084047079086, 45.55784158408642, 44.72404092550278, 45.49327164888382, 46.718565300107, 44.84839305281639, 43.063678219914436, 43.347370997071266, 48.18069264292717, 46.067428439855576, 45.0649244338274, 48.17744001746178, 46.177276745438576, 46.24639883637428, 44.9623679369688, 45.12205436825752, 44.37569461762905, 46.59616246819496, 44.74675230681896, 42.77227185666561, 46.35218895971775, 47.09789514541626, 47.50660881400108, 48.310052901506424, 49.47010785341263, 48.49973112344742, 51.24447964131832, 56.4899917691946, 55.2876602858305, 57.97584883868694, 47.025216445326805, 57.15230382978916, 60.13835459947586, 54.84002150595188, 48.62054944038391, 46.83131664991379, 46.15081496536732, 47.6800999045372, 49.28432062268257, 44.740820825099945, 42.23354436457157, 45.802601650357246, 46.28022462129593, 46.28327965736389, 45.158072635531425, 45.99425196647644, 47.70004503428936, 44.28112909197807, 46.57528258860111, 47.271599024534225, 45.79798489809036, 46.328003257513046, 46.9022436439991, 46.152460277080536, 45.194645673036575, 45.04557967185974, 47.572786062955856, 45.58091014623642, 46.01852506399155, 47.290343418717384, 44.20179694890976, 48.17421019077301, 43.28792318701744, 45.398812517523766, 44.98314142227173, 44.193304404616356, 47.088448852300644, 44.86419640481472, 45.43547295033932, 43.87544006109238, 46.13783486187458, 45.56120440363884, 44.85573425889015, 46.529210060834885, 44.88872788846493, 47.298687770962715, 53.42630736529827, 57.27673575282097, 64.9315693974495, 64.99448642134666, 63.73289331793785, 63.98379385471344, 65.19271418452263, 65.97161158919334, 63.0022419244051, 65.12569338083267, 63.522152826189995, 65.4965914785862, 63.10221455991268, 63.3815261721611, 65.41971400380135, 67.29046761989594, 68.42871934175491, 70.76481878757477, 32.87384480237961, 0.9547389065846801, 6.221797540783882, 5.1837302930653095, 0.27383548265788704, 0.23913739220006391, 39.89945501089096, 80.45388847589493, 72.35086888074875, 68.243737667799, 71.85497269034386, 48.50985378026962, 36.95184677839279, 56.00109100341797, 66.70004770159721, 74.14437264204025, 13.542290925979614, 0.5540762341115624, 0.1328799087787047, 0.11368114952347241, 0.13125668338034302, 0.08711656715604477, 0.14233877387596294, 0.09514681281871162], [0.01321296160313068, 0.06141566285805311, 0.02279658172483323, 0.04076043136592489, 0.044733355680364184, 0.07189437616034411, 0.23752301320200786, 0.08940117972088046, 12.327237725257874, 56.246329843997955, 50.6305655837059, 41.724155098199844, 17.96063493937254, 16.83240707963705, 46.2786591053009, 37.42268331348896, 66.87318921089172, 53.77983279526234, 58.77569071948528, 2.21144855953753, 0.07786482805386186, 0.1911591479438357, 4.26924666389823, 1.0107566881924868, 17.63554908335209, 76.66726246476173, 59.584994092583656, 62.30890452861786, 63.878759890794754, 44.89228829741478, 41.65896199643612, 66.82920277118683, 55.24068720638752, 60.59142708778381, 55.045031905174255, 59.00497801601887, 54.775865748524666, 58.16149167716503, 51.61770321428776, 54.571208730340004, 52.86751314997673, 57.52694092690945, 48.3270113915205, 37.68476665019989, 45.21621711552143, 54.42072160542011, 52.24781960248947, 50.43136887252331, 50.89807502925396, 46.65183328092098, 41.111586168408394, 40.20009107887745, 38.680024445056915, 39.40480515360832, 38.22819449007511, 38.70986804366112, 39.452579990029335, 39.72731664776802, 37.49550640583038, 40.48246532678604, 40.55254876613617, 39.83151465654373, 42.79304154217243, 41.127210929989815, 39.96798813343048, 40.54507836699486, 43.48530739545822, 42.75627851486206, 39.65486213564873, 41.19214564561844, 40.68992279469967, 40.72725959122181, 41.16586625576019, 42.063887268304825, 39.5550224930048, 41.84808164834976, 39.81142893433571, 40.9797066450119, 39.455247446894646, 42.85914659500122, 44.5649054646492, 43.013152331113815, 42.14787036180496, 44.31984141469002, 42.60293014347553, 48.0851923674345, 47.88336239755154, 54.32416118681431, 46.75241768360138, 50.07238693535328, 53.67127262055874, 50.18494829535484, 43.519182577729225, 42.053339034318924, 42.654485777020454, 42.47431464493275, 43.083801940083504, 42.21652127802372, 41.82160086929798, 39.88951474428177, 42.01932705938816, 40.28814755380154, 40.33646196126938, 40.67541517317295, 41.458488553762436, 41.37637495994568, 41.73645503818989, 42.26768933236599, 38.39768059551716, 42.6104499399662, 41.5687358379364, 42.027253434062004, 41.693798527121544, 40.86660951375961, 41.96107238531113, 41.91449448466301, 41.408604830503464, 40.879688411951065, 41.71651750802994, 40.40865808725357, 41.78234897553921, 41.36108458042145, 41.16820313036442, 40.52866704761982, 40.92640310525894, 39.578961208462715, 40.03753960132599, 40.107501447200775, 40.47551549971104, 41.01398080587387, 41.19200885295868, 42.673135176301, 42.744552344083786, 41.79578885436058, 40.99075645208359, 43.88462796807289, 45.97203075885773, 47.27418288588524, 49.32039588689804, 49.31497737765312, 50.567557364702225, 52.56951794028282, 52.123817056417465, 49.6820642799139, 44.326263070106506, 47.9641080647707, 44.88525487482548, 50.317298993468285, 54.77717287838459, 61.62407487630844, 57.0625526458025, 69.81873795390129, 38.12379889190197, 0.4271753638749942, 0.41409910772927105, 0.8395065274089575, 0.5648015742190182, 0.16445256303995848, 25.174745433032513, 70.25129914283752, 61.099551022052765, 59.940871596336365, 40.85701122879982, 15.972809605300426, 22.033364698290825, 34.371439442038536, 46.398877054452896, 53.77224840223789, 12.169898618012667, 0.3016570850741118, 0.08917687300709076, 0.015689695792389102, 0.04661038074118551, 0.0614043339737691, 0.03887778824719135, 0.028767788753611967, 0.022467815870186314, 0.06440490382374264, 0.011740047084458638, 0.10693265969166532, 0.07439808556227945, 0.136793342535384, 0.17648877343162894, 0.06923448177985847, 16.288694255053997, 65.46765983104706, 56.51402547955513, 48.42128053307533, 22.895867116749287, 20.770314373075962, 46.35504640638828, 45.929666832089424, 74.40918043255806, 59.37371402978897, 64.24438387155533, 2.8205815237015486, 0.18007582548307255, 0.4371265845838934, 9.70024773851037, 1.6655513271689415, 18.720159083604813, 77.6071572303772, 61.49210795760155, 64.45339545607567, 63.34462635219097, 48.64907830953598, 44.875253811478615, 65.8227963745594, 56.651353910565376, 61.13193668425083, 57.04108379781246, 62.169049233198166, 55.77529191970825, 58.501235246658325, 54.450701996684074, 57.80049964785576, 53.33788990974426, 58.04048337042332, 49.88468840718269, 40.563359186053276, 45.78531637787819, 56.60535737872124, 53.34793657064438, 54.42702166736126, 52.393051609396935, 48.669319823384285, 45.029419139027596, 43.39963719248772, 40.96548780798912, 42.09411844611168, 41.08334608376026, 41.48379899561405, 42.339364886283875, 41.74747824668884, 39.889674335718155, 42.94286370277405, 42.56620891392231, 42.47394986450672, 43.94988566637039, 43.14931422472, 43.088160306215286, 43.485713973641396, 44.42116677761078, 43.691047355532646, 43.09756100177765, 42.22694791853428, 42.652008309960365, 41.61686785519123, 41.25600881874561, 44.73968468606472, 41.40739269554615, 43.16343806684017, 42.19449006021023, 42.184154614806175, 41.66499227285385, 46.54544658958912, 47.196154072880745, 45.35756193101406, 42.990083768963814, 46.86015710234642, 46.070342883467674, 50.17834424972534, 50.671033412218094, 56.44586853682995, 50.13207793235779, 52.79558300971985, 55.34407585859299, 51.29684083163738, 45.610423162579536, 43.67596976459026, 44.64005023241043, 44.71301771700382, 46.589588820934296, 45.0713574886322, 43.895863965153694, 43.89545738697052, 44.06494729220867, 42.87395440042019, 41.78031228482723, 41.458393558859825, 43.62864710390568, 43.965453431010246, 43.75981226563454, 43.56888011097908, 42.07316257059574, 43.64969037473202, 42.76136264204979, 42.884506434202194, 42.37757943570614, 42.530342638492584, 42.77510270476341, 44.85323019325733, 43.00484977662563, 41.884776279330254, 44.090280532836914, 42.928413078188896, 41.94984018802643, 43.43869149684906, 42.888435423374176, 44.17421042919159, 43.39709132909775, 40.18458791077137, 41.065547838807106, 41.374862641096115, 44.12901185452938, 43.28143313527107, 42.32368692755699, 44.8064699023962, 43.5729268938303, 43.336556777358055, 43.08864668011665, 45.39252005517483, 47.34199024736881, 50.11049509048462, 52.15781383216381, 52.745098918676376, 53.03592011332512, 54.99646671116352, 54.1237523406744, 50.81101790070534, 49.354297667741776, 49.11310561001301, 48.15204218029976, 53.05660240352154, 56.779946610331535, 64.14464682340622, 61.3925115019083, 71.29263326525688, 42.16981418430805, 0.8261492347810417, 0.45109332888387144, 2.160517517477274, 0.9298454923555255, 0.1528486388269812, 27.531720958650112, 76.13220557570457, 66.44237592816353, 65.54595082998276, 48.66267777979374, 27.08873502910137, 29.70781859010458, 42.247645407915115, 53.38607892394066, 65.04299461841583, 16.473987512290478, 0.370485374587588, 0.11568626927328296, 0.03433400022913702, 0.021447279323183466, 0.05864338134415448, 0.030897364813426975, 0.03438849984377157, 0.1232262076518964, 0.26062210730742663, 0.21709717955673113, 0.23193563567474484, 0.15712624444859102, 0.23457336210412905, 0.334920440800488, 0.3087577462429181, 23.4225245565176, 78.32863211631775, 66.45895063877106, 57.71693453192711, 28.694568760693073, 23.98095779120922, 59.48689855635166, 53.074092864990234, 76.81898832321167, 64.29698064923286, 69.90770637989044, 3.599718790501356, 0.25199559051543474, 0.6006787740625441, 12.174318730831146, 1.6815133206546307, 19.838976748287678, 83.21118772029877, 62.675790041685104, 67.04972013831139, 67.09504410624504, 50.735109373927116, 43.850897178053856, 65.78517839312553, 57.81830929219723, 62.90855415165424, 59.01912085711956, 64.90175619721413, 59.03600335121155, 62.15988032519817, 55.13920985162258, 60.909671410918236, 57.33450025320053, 63.13015826046467, 50.73884457349777, 45.48817612230778, 51.193254590034485, 58.48228186368942, 56.88167855143547, 54.54318903386593, 55.8449649810791, 50.7795175909996, 46.20737113058567, 45.17582908272743, 43.56144391000271, 44.12927404046059, 43.01714971661568, 43.30168604850769, 44.89858075976372, 45.47471344470978, 41.94048509001732, 45.460240021348, 45.13080909848213, 44.785875007510185, 48.43978933990002, 47.031288519501686, 44.166189059615135, 46.086533814668655, 46.528446301817894, 46.24597325921059, 44.80791762471199, 43.623551577329636, 44.50714096426964, 42.787083461880684, 45.313712283968925, 46.73257514834404, 43.51729027926922, 45.318488627672195, 45.253272727131844, 44.39279370009899, 44.0790369361639, 47.6163849234581, 49.64530125260353, 47.97640040516853, 45.09452864527702, 50.69823615252972, 47.95067958533764, 50.87263539433479, 54.12439450621605, 59.393286779522896, 52.17288762331009, 55.02490818500519, 58.851257264614105, 53.25867936015129, 47.28931367397308, 46.88681647181511, 47.62642398476601, 45.86586445569992, 49.7534054517746, 48.200497180223465, 46.86942860484123, 43.82169954478741, 47.624562084674835, 44.15983200073242, 45.392337664961815, 45.62283709645271, 47.285190895199776, 46.137641072273254, 45.46193093061447, 46.729337722063065, 42.538557797670364, 47.63917990028858, 46.29717171192169, 44.977445527911186, 46.36660918593407, 44.67834457755089, 46.9903951138258, 47.90205739438534, 45.06533861160278, 44.3397219479084, 48.01060616970062, 45.65329626202583, 45.70213884115219, 45.82198441028595, 45.72203457355499, 45.73223702609539, 46.78469315171242, 42.15917855501175, 42.71404758095741, 42.90960408747196, 45.57230740785599, 46.657426580786705, 45.43500937521458, 47.18094348907471, 45.948757007718086, 45.79170763492584, 46.00125879049301, 48.48600625991821, 50.0495919585228, 52.09789864718914, 54.87084925174713, 54.03383396565914, 55.30767001211643, 57.69969865679741, 57.44171530008316, 53.34947928786278, 50.70450961589813, 52.63354830443859, 50.63006401062012, 57.49280355870724, 58.62364947795868, 67.60294765233994, 63.669398725032806, 74.3686594069004, 44.29426498711109, 1.2877864041365683, 2.8535229060798883, 6.85893215239048, 1.1794649041257799, 0.22012012515915558, 30.92682547867298, 83.47930133342743, 72.31062144041061, 74.12424132227898, 54.390239641070366, 27.710628658533096, 32.0602210611105, 51.12239219248295, 63.99347573518753, 76.2049412727356, 24.04483236372471, 0.5391847738064826, 0.16554301546420902, 0.20865758007857949, 0.10892810925724916, 0.10889946977840737, 0.12049710057908669, 0.2182789013022557], [0.015367387550213607, 0.056865095320972614, 0.02856553310266463, 0.02691856825549621, 0.04207504949590657, 0.045896642477600835, 0.07936880516353995, 0.0634025369072333, 12.352839801460505, 50.93562841415405, 48.018874526023865, 45.79096667468548, 27.469392903149128, 33.09050917625427, 43.03651727735996, 48.25095847249031, 65.15940517187119, 56.90470151603222, 52.928803861141205, 1.887247224804014, 0.1723820250481367, 0.5063604726456106, 6.374023072421551, 1.7347340960986912, 0.7324652618262917, 49.60508041083813, 65.03256037831306, 62.247081845998764, 56.33352756500244, 57.29270629584789, 70.37907868623734, 60.54735325276852, 57.53231003880501, 60.105524361133575, 59.092605113983154, 56.33746035397053, 53.90306398272514, 51.87390446662903, 49.895631819963455, 53.894328251481056, 54.78707514703274, 52.49922551214695, 48.80897752940655, 49.83839929103851, 48.04062835872173, 56.12763561308384, 49.393819347023964, 51.01251728832722, 47.55127161741257, 45.008710250258446, 42.20632642507553, 38.00606980919838, 38.450638353824615, 38.714291006326675, 39.190591648221016, 38.17367121577263, 39.817079231143, 37.859849855303764, 39.99217763543129, 39.76038247346878, 39.014687687158585, 41.991238966584206, 39.69465360045433, 42.202659621834755, 38.82912464439869, 41.12099826335907, 41.29532150924206, 41.12031430006027, 41.297479793429375, 41.725355833768845, 38.47149543464184, 37.62644737958908, 39.93983544409275, 40.64324609935284, 40.29450461268425, 40.347409173846245, 40.71981579065323, 42.12430402636528, 39.13422927260399, 43.54910597205162, 46.82101920247078, 46.45745851099491, 44.093985334038734, 43.59373837709427, 42.83604383468628, 47.32031621038914, 49.2237214744091, 52.26815991103649, 46.59458175301552, 50.480279847979546, 53.89701850712299, 48.50425288081169, 43.89635033905506, 43.672986924648285, 43.24837490916252, 44.908483028411865, 44.74393665790558, 40.69434195756912, 40.21720916032791, 42.82041147351265, 39.58365775644779, 39.05375339090824, 39.70726132392883, 40.69675862789154, 41.40827424824238, 40.84517486393452, 41.763456389307976, 39.591686725616455, 40.77199459075928, 40.82271046936512, 41.528401002287865, 39.82186317443848, 39.081153720617294, 41.19472570717335, 40.0613871216774, 38.696967735886574, 41.599745973944664, 39.926281571388245, 41.07459515333176, 40.88425576686859, 40.60937091708183, 41.28022111952305, 40.58536760509014, 40.964359268546104, 39.05426636338234, 40.003425031900406, 40.145446211099625, 39.460065588355064, 39.916523694992065, 40.10247051715851, 42.53623992204666, 41.272363141179085, 42.323588132858276, 43.75629745423794, 43.03492896258831, 39.70856465399265, 41.20631128549576, 41.788348853588104, 42.792555168271065, 42.87943750619888, 42.875341325998306, 42.7525395154953, 42.68869914114475, 43.34147371351719, 45.02370424568653, 50.030862763524055, 53.57229173183441, 54.15277898311615, 54.69716437160969, 57.0208764821291, 61.485785096883774, 64.87237617373466, 52.19016909599304, 1.9974309811368585, 0.41193681594450027, 1.8978816666640341, 0.7841937860939652, 0.32369281514547765, 13.885877039283514, 68.75848084688187, 60.88747680187225, 62.27127514779568, 38.912313580513, 17.502081245183945, 13.526460975408554, 31.896271258592606, 47.3687370121479, 59.62616868317127, 20.990185774862766, 0.41001693927682936, 0.007606751150888158, 0.0354788891854696, 0.03760112726013176, 0.07615976603119634, 0.018108019248757046, 0.027424655454524327, 0.025694811265566386, 0.048069075710373, 0.08084653250989504, 0.021862377361685503, 0.024587274601799436, 0.08153943868819624, 0.07370181745500304, 0.029403393709799275, 16.67885921895504, 63.50931331515312, 56.588900461792946, 50.64837142825127, 25.287272594869137, 23.669724091887474, 44.62549701333046, 55.050176829099655, 69.9142724275589, 62.73568242788315, 58.868534937500954, 2.35841351095587, 0.27949091512709856, 1.7689219303429127, 15.91581741347909, 3.5156606510281563, 0.6509241904132068, 53.4979373216629, 66.54376968741417, 64.5779299736023, 55.10980702936649, 58.50451447069645, 70.44471636414528, 61.78744710981846, 58.30470599234104, 61.28292918205261, 61.62720210850239, 58.67734059691429, 55.8537121117115, 53.67538020014763, 51.63713537156582, 55.14922611415386, 57.329241335392, 53.67588937282562, 51.58207632601261, 53.33034731447697, 50.3377190977335, 55.54410472512245, 52.01893508434296, 52.23301559686661, 48.910318091511726, 47.93919280171394, 44.082984924316406, 41.88694976270199, 39.83041271567345, 41.64864555001259, 42.128381207585335, 41.637417152523994, 41.813533902168274, 41.80174693465233, 41.55935414135456, 42.75872938334942, 41.37188360095024, 42.59367763996124, 41.101623103022575, 44.18352372944355, 41.68686389923096, 42.68629767000675, 43.00418861210346, 42.94199734926224, 43.82653288543224, 43.572862297296524, 40.09572967886925, 39.63513359427452, 41.05868920683861, 42.521082535386086, 41.4937886595726, 41.840512454509735, 43.28658565878868, 43.474831357598305, 41.77876956760883, 44.08697851002216, 48.076422438025475, 48.5638602823019, 47.10817739367485, 46.58196642994881, 46.01091027259827, 50.37602484226227, 51.039552837610245, 54.37206141650677, 50.11127024888992, 52.44005128741264, 56.83287777006626, 51.73175409436226, 47.487632632255554, 45.35889185965061, 45.03635756671429, 47.61249013245106, 46.34602189064026, 41.968231201171875, 43.35174076259136, 45.06745509803295, 40.859013721346855, 41.32549189031124, 40.63358701765537, 42.305603697896004, 42.52117373049259, 41.903634667396545, 43.725021332502365, 41.60603083670139, 42.63000749051571, 42.71548770368099, 43.40136609971523, 42.47968755662441, 41.94820247590542, 42.8901719301939, 42.356722354888916, 40.8785180747509, 42.83866189420223, 42.81007222831249, 43.435378074645996, 43.76672029495239, 42.622518092393875, 41.01233929395676, 41.84396646916866, 43.29102762043476, 40.906967148184776, 41.99997469782829, 42.54372552037239, 42.383450120687485, 42.65373721718788, 42.578596249222755, 43.73370386660099, 43.7715270370245, 43.14661256968975, 45.501585602760315, 45.01430734992027, 41.18989996612072, 42.69664451479912, 43.76133218407631, 44.656921327114105, 44.66316059231758, 44.894495978951454, 43.26948657631874, 44.59090746939182, 45.213416665792465, 47.98746161162853, 52.141584903001785, 57.37887807190418, 56.802430003881454, 57.04072281718254, 59.04092788696289, 65.10541766881943, 66.62579208612442, 55.59553876519203, 1.8165192450396717, 0.7079886377323419, 2.3853136925026774, 1.1400851234793663, 0.2548343053786084, 14.562434535473585, 75.31268075108528, 66.18806317448616, 67.01748266816139, 50.66298544406891, 26.67304303497076, 18.268847800791264, 39.756586477160454, 55.48288621008396, 71.28763273358345, 27.175301983952522, 0.43979122128803283, 0.019055684315389954, 0.04298354957427364, 0.03916579720680602, 0.05940162249316927, 0.03702500915096607, 0.0026856733438762603, 0.07422882394166663, 0.17005574831273407, 0.18410399527056143, 0.1168981147930026, 0.2074035137775354, 0.25548638601321727, 0.20440716674784198, 0.11638880110695027, 22.14428834617138, 75.89938446879387, 64.64185774326324, 62.725457176566124, 38.623540475964546, 42.130843475461006, 57.05096326768398, 61.25998981297016, 74.61026564240456, 67.43976160883904, 65.58655545115471, 2.9740897240117192, 0.27115377655718476, 1.4677803707309067, 18.369496800005436, 4.834745144471526, 1.336709966417402, 55.149416103959084, 70.58083266019821, 65.7533361017704, 58.869598880410194, 58.15174899995327, 69.99130189418793, 65.7304385304451, 60.20315632224083, 65.23803055286407, 65.49586191773415, 61.66730135679245, 57.706701681017876, 57.08890043199062, 54.998081624507904, 58.279874324798584, 60.366802141070366, 56.629793867468834, 51.89679063856602, 54.84382130205631, 53.517019897699356, 59.7573072463274, 53.80095586180687, 56.646026596426964, 51.323948577046394, 50.897299870848656, 47.53668799996376, 43.08159425854683, 42.68391139805317, 44.27217297255993, 44.59779649972916, 43.59463892877102, 45.75070783495903, 43.314905539155006, 44.77460861206055, 44.01412881910801, 42.24585950374603, 46.31349563598633, 42.7527979016304, 46.43877871334553, 43.965119048953056, 44.170570224523544, 46.6691679507494, 45.316885113716125, 46.24661922454834, 46.27781555056572, 42.976389303803444, 41.28985360264778, 43.012190982699394, 44.86464858055115, 44.427637830376625, 44.98154930770397, 46.14863008260727, 45.52772060036659, 44.79964926838875, 47.97035112977028, 52.70160265266895, 51.32002718746662, 49.41570617258549, 48.014390766620636, 48.28047148883343, 52.40686386823654, 54.57171410322189, 55.52085757255554, 51.87819443643093, 55.910971239209175, 57.92072519659996, 53.99211220443249, 50.4195287078619, 48.28767590224743, 46.16043604910374, 50.82538492977619, 51.81701771914959, 45.3667688369751, 45.9159229695797, 47.599445432424545, 42.52440735697746, 44.08862382173538, 41.569286808371544, 45.78813962638378, 45.59001825749874, 44.4991347938776, 45.82748271524906, 42.3572239279747, 44.84380289912224, 43.97594466805458, 45.37041664123535, 43.79293128848076, 43.23593817651272, 45.34987114369869, 45.10290339589119, 42.088608741760254, 45.165052860975266, 43.5179590433836, 45.45671001076698, 46.29290074110031, 44.77663390338421, 44.39244031906128, 44.81980338692665, 45.71539252996445, 41.74019403755665, 45.884939432144165, 44.870504066348076, 44.10868674516678, 44.5209988206625, 45.72570897638798, 46.862535774707794, 46.456071585416794, 45.85617117583752, 48.24887998402119, 47.42929816246033, 43.01953598856926, 44.813229739665985, 47.71859563887119, 46.39112167060375, 47.24592760205269, 47.86251671612263, 45.73396973311901, 46.61979340016842, 48.99506874382496, 50.383920818567276, 55.49352943897247, 59.89583641290665, 60.1702044904232, 59.74522389471531, 63.023539781570435, 69.47666510939598, 69.85816463828087, 59.45836588740349, 2.5599577836692333, 1.8351001292467117, 9.141732808202505, 1.981404391117394, 0.3731920168502256, 16.412438414990902, 81.81863084435463, 71.52641952037811, 75.71330845355988, 54.14633832871914, 26.73562377691269, 24.689992144703865, 48.611642718315125, 66.51888102293015, 80.36672115325928, 36.67823486030102, 0.6765743577852845, 0.17416666756616905, 0.11772243306040764, 0.12010805192403495, 0.21082441380713135, 0.1900684877182357, 0.09853469469817355], [0.06469831932918169, 0.041036525144590996, 0.05843266706506256, 0.05135793653607834, 0.020762438434758224, 0.08570411169785075, 0.10138571436982602, 0.11206989496713504, 9.888067860156298, 55.56588135659695, 44.962147548794746, 42.28636533021927, 21.27130039036274, 30.318882800638676, 31.74573663622141, 46.289841905236244, 63.19656729698181, 59.07370112836361, 49.408938735723495, 1.586040356196463, 0.10803018478327431, 2.115222285501659, 9.35057720169425, 3.5396416392177343, 0.26521347812376916, 13.62902982160449, 63.92749607563019, 52.20150388777256, 65.22225379943848, 63.08012634515762, 58.34931179881096, 56.331962049007416, 55.88654614984989, 55.18010325729847, 57.60754980146885, 51.47896125912666, 49.96190786361694, 48.161883652210236, 48.20271626114845, 50.855479314923286, 53.05246062576771, 55.19330754876137, 53.429913371801376, 52.792672365903854, 54.400795474648476, 51.73312582075596, 47.936285957694054, 47.514945566654205, 46.147949919104576, 44.19268123805523, 42.479296177625656, 40.11719852685928, 38.391023352742195, 38.4870707988739, 38.299938440322876, 37.629323825240135, 38.83902311325073, 37.32455737888813, 39.69320967793465, 40.29369905591011, 38.92131149768829, 39.903874173760414, 40.63242048025131, 40.09205907583237, 40.87591141462326, 38.2946415245533, 41.260006204247475, 41.67949989438057, 38.55028420686722, 39.30466152727604, 38.712660893797874, 39.87653084099293, 38.79171185195446, 38.96522954106331, 39.62124153971672, 38.556774258613586, 41.93623311817646, 42.422151044011116, 39.243397414684296, 39.69707027077675, 47.828257754445076, 46.11101970076561, 46.01069748401642, 45.68789720535278, 44.67674106359482, 48.45089994370937, 49.64982680976391, 51.60852670669556, 51.77498817443848, 49.79065105319023, 52.45539106428623, 46.823819652199745, 46.42832167446613, 42.55645103752613, 47.0222982019186, 45.484254732728004, 44.45801720023155, 37.92441599071026, 40.750803127884865, 43.274129927158356, 40.12815713882446, 39.09797541797161, 38.78704950213432, 39.75021041929722, 40.680993273854256, 38.95617462694645, 40.90142324566841, 40.98335064947605, 38.413928523659706, 39.446002542972565, 42.468645349144936, 41.578239127993584, 39.911473765969276, 39.61777612566948, 40.28423376381397, 39.24813576042652, 39.10537742078304, 38.4252443164587, 42.06199496984482, 40.926619693636894, 39.5914701372385, 41.48979127407074, 40.352459102869034, 40.90071268379688, 39.669179767370224, 39.5849496871233, 39.00410905480385, 38.44341494143009, 41.69365793466568, 41.670980751514435, 45.79137325286865, 46.49228364229202, 48.00033152103424, 44.463705494999886, 45.32581463456154, 43.54581914842129, 43.13509538769722, 42.319564148783684, 42.18667007982731, 41.16089232265949, 44.252034053206444, 45.9190957993269, 51.922625452280045, 53.97731959819794, 57.113880291581154, 55.777351409196854, 59.3035925924778, 57.951780930161476, 61.76063574850559, 61.060302928090096, 64.08369809389114, 64.9597030878067, 59.449675753712654, 3.0803569592535496, 0.3052676632069051, 1.0497564892284572, 0.9736957331188023, 0.11754772407584824, 8.769688121974468, 64.97908964753151, 61.952935829758644, 63.10584336519241, 51.352428048849106, 32.06388786435127, 19.666209518909454, 36.471176370978355, 45.99441535770893, 62.28462763130665, 22.231389172375202, 0.628922717878595, 0.0180151413223939, 0.053754836044390686, 0.06979144876822829, 0.039398200751747936, 0.09823942382354289, 0.05131879937835038, 0.0428982396988431, 0.07065997677273117, 0.05545924126636237, 0.0287913964712061, 0.04654556527384557, 0.06023449772328604, 0.08342523593455553, 0.08590614655986428, 16.77961841225624, 68.6943706870079, 53.4237577021122, 53.210231959819794, 28.594358637928963, 34.616731479763985, 39.152859672904015, 53.616354167461395, 68.115623742342, 64.11873981356621, 52.27417878806591, 1.5848371270112693, 0.3371840505860746, 2.9172089137136936, 15.726819355040789, 3.4351840568706393, 0.22854706359794363, 15.550070889294147, 65.19267618656158, 51.151365637779236, 65.53522780537605, 65.06635576486588, 60.36541521549225, 59.001786187291145, 58.08290049433708, 57.389821484684944, 59.043511748313904, 54.957822784781456, 51.49222634732723, 49.86914724111557, 49.11117911338806, 53.07988375425339, 55.96729941666126, 58.45616586506367, 57.249001041054726, 56.30397655069828, 56.143264174461365, 52.89555564522743, 49.98753748834133, 49.836248606443405, 49.0192886441946, 46.649082228541374, 45.412670373916626, 42.4816482514143, 40.52613638341427, 41.67819656431675, 41.51675082743168, 40.24945802986622, 42.230572924017906, 39.557940736413, 41.97421967983246, 42.71665424108505, 40.09145110845566, 43.0538709461689, 41.790605932474136, 41.18368349969387, 42.172424644231796, 41.02108642458916, 42.655283734202385, 43.024479523301125, 40.31866751611233, 40.95556654036045, 41.07914350926876, 41.90334588289261, 39.97368782758713, 41.78237557411194, 41.60851590335369, 40.403798148036, 43.45280773937702, 42.658217176795006, 41.222000643610954, 44.34910364449024, 47.18414671719074, 49.65787097811699, 48.92164908349514, 49.50603112578392, 45.96717081964016, 49.55785274505615, 51.49786524474621, 56.03398583829403, 54.479189068078995, 52.27953650057316, 54.758774265646935, 49.866639375686646, 48.214423432946205, 46.785016134381294, 49.42364014685154, 48.22017252445221, 46.60332128405571, 40.47809936106205, 44.524536430835724, 43.733981251716614, 40.43410152196884, 41.48095294833183, 41.20018981397152, 41.512742042541504, 42.523088827729225, 41.19606703519821, 42.40547753870487, 42.52151571214199, 42.03253895044327, 41.33395403623581, 43.03467057645321, 42.609397396445274, 41.58710025250912, 40.839976742863655, 42.95061908662319, 41.33727505803108, 41.86025619506836, 40.62814190983772, 41.84110902249813, 43.66772040724754, 42.956770956516266, 42.33143091201782, 41.24986454844475, 42.3789169639349, 41.708849519491196, 41.38143628835678, 41.62743128836155, 40.134563595056534, 42.70025432109833, 42.7549409866333, 48.77871215343475, 48.43755505979061, 48.709692656993866, 47.85722739994526, 46.98939196765423, 45.488901883363724, 46.370492577552795, 44.81269396841526, 44.192240461707115, 43.198377192020416, 45.885266214609146, 47.66250304877758, 55.34176178276539, 56.462982818484306, 58.97837944328785, 58.78741309046745, 60.662920251488686, 59.50355686247349, 64.41330000758171, 63.28423619270325, 65.49773901700974, 66.08642622828484, 63.1334412842989, 3.919345526956022, 0.8990209526382387, 1.9985189102590084, 1.4566149073652923, 0.20462743617827073, 9.569638296961784, 71.22349977493286, 68.53354811668396, 71.14573314785957, 52.23711937665939, 29.90933507680893, 19.745326973497868, 41.379809975624084, 54.86025162041187, 70.3034095466137, 29.55317258834839, 0.7487476256210357, 0.035789077228400856, 0.08156559939379804, 0.014963221346988576, 0.006070318995625712, 0.052358329339767806, 0.07428674114635214, 0.17464035074226558, 0.1611744225374423, 0.14418333739740774, 0.1340195507509634, 0.09276079319533892, 0.19174762652255595, 0.1760564130381681, 0.2745962730841711, 25.602676570415497, 79.59290027618408, 61.782051399350166, 59.896391183137894, 36.05738617479801, 41.493070498108864, 43.37605185806751, 60.67881099879742, 73.557098954916, 72.15182796120644, 59.55916687846184, 2.1765806805342436, 0.24282950267661363, 5.23305544629693, 27.075815722346306, 9.588794969022274, 0.3790065657813102, 17.19487152993679, 66.72188133001328, 52.41882182657719, 67.5330314040184, 66.005619764328, 63.67596477270126, 60.80534040927887, 60.39140202105045, 59.38479423522949, 62.342969700694084, 57.75100350379944, 54.326080083847046, 53.761806562542915, 51.91449388861656, 57.225651293992996, 57.72345118224621, 60.381104573607445, 57.57977709174156, 58.53674814105034, 59.07452568411827, 55.650962591171265, 52.494718953967094, 54.492575749754906, 51.145901530981064, 49.71599265933037, 48.738384917378426, 45.60135304927826, 42.90827035903931, 45.48180006444454, 43.25087517499924, 43.14509645104408, 44.53893385827541, 42.016819193959236, 44.228308126330376, 45.68716384470463, 40.80741249024868, 44.77246932685375, 43.92042964696884, 44.45491276681423, 45.46799160540104, 43.34769777953625, 44.311177879571915, 47.1640457957983, 41.570753529667854, 45.012764632701874, 43.910690769553185, 44.9504479765892, 42.632268369197845, 42.38891422748566, 43.97568628191948, 41.752402782440186, 47.25375518202782, 46.15249827504158, 45.25225818157196, 45.51900006830692, 50.0520808249712, 51.43771447241306, 52.83457271754742, 50.831046625971794, 49.80773873627186, 53.71083989739418, 54.996668100357056, 58.15187819302082, 55.64493611454964, 54.38131392002106, 56.30426533520222, 52.03134901821613, 49.460517168045044, 49.31318387389183, 52.44994595646858, 50.47760099172592, 50.234368443489075, 40.680822283029556, 45.32592482864857, 46.712763011455536, 43.57119418680668, 42.62026481330395, 44.42459799349308, 44.24227997660637, 45.60117065906525, 42.84854896366596, 43.64524841308594, 44.46648694574833, 43.397988080978394, 42.42936685681343, 45.38036450743675, 45.08108116686344, 43.547677248716354, 43.36709953844547, 45.6761634349823, 44.01053041219711, 43.760120049118996, 42.00277894735336, 45.099160596728325, 45.32973602414131, 45.46361804008484, 43.92308950424194, 43.44148054718971, 44.36714507639408, 44.57103453576565, 43.57896476984024, 43.717569932341576, 42.95147404074669, 46.41527317464352, 44.8143544793129, 52.447985261678696, 50.432729199528694, 51.963632851839066, 50.65766952931881, 49.13047067821026, 47.239897325634956, 47.42354907095432, 47.34444111585617, 47.71385729312897, 45.311705991625786, 49.51181821525097, 50.36443166434765, 56.61824628710747, 59.71881911158562, 62.47447304427624, 60.33452667295933, 65.3143684566021, 64.01175275444984, 66.94128155708313, 67.08369791507721, 70.84228903055191, 70.7830274105072, 62.48270720243454, 4.114239206537604, 2.1943129040300846, 4.99614623375237, 2.728125359863043, 0.32167916069738567, 10.744260717183352, 77.44185090065002, 72.95722514390945, 76.96113869547844, 62.14097633957863, 43.21176767349243, 29.41440023481846, 52.39821933209896, 63.858392983675, 82.13239520788193, 37.192134484648705, 1.0763880726881325, 0.13289628055645153, 0.2134296193253249, 0.10129134287126362, 0.11480144370580092, 0.199313985358458, 0.1782405684934929], [0.022529453090101015, 0.027459081829874776, 0.06552025530254468, 0.0800844730110839, 0.07751816345262341, 0.027274767599010374, 0.04397056145535316, 0.08794908615527675, 15.983492732048035, 55.11586770415306, 44.38590846955776, 31.220502220094204, 14.217221159487963, 42.1697685867548, 42.75123618543148, 48.221164271235466, 64.50482189655304, 55.65967172384262, 50.25345861911774, 1.2525664502754807, 0.334625244140625, 1.8561723735183477, 14.93497984483838, 1.4482808858156204, 0.4010600480251014, 9.690451864153147, 62.55867272615433, 55.744019597768784, 62.240265011787415, 52.094961404800415, 59.29251618683338, 51.7140394449234, 55.12057185173035, 52.62431100010872, 49.95034508407116, 50.02542145550251, 48.502387180924416, 46.344448775053024, 46.52931645512581, 45.76625660061836, 49.717447981238365, 47.72531367838383, 51.65487661957741, 49.69339907169342, 47.846496775746346, 47.522260174155235, 46.803220957517624, 45.084189400076866, 44.917005971074104, 41.94667115807533, 40.882378667593, 39.878681525588036, 39.260770082473755, 37.1145236492157, 38.37624974548817, 37.579922676086426, 39.95712831616402, 39.12048161029816, 37.2172549366951, 40.162837877869606, 40.92752784490585, 39.87330101430416, 40.11132024228573, 39.381869584321976, 39.85749006271362, 38.13401274383068, 38.46052922308445, 38.8894198089838, 38.84179696440697, 39.70821127295494, 41.18778347969055, 40.390635654330254, 39.04292397201061, 39.39351215958595, 39.157480224967, 37.845558822155, 39.61431451141834, 38.56388747692108, 39.9397898465395, 42.12321348488331, 46.17910824716091, 48.882199600338936, 47.304140478372574, 45.74136793613434, 43.75350460410118, 49.15438659489155, 51.450432389974594, 54.00883890688419, 57.027195543050766, 54.22189727425575, 50.140882059931755, 49.33089092373848, 48.746581077575684, 45.4713050276041, 46.961125284433365, 48.319502994418144, 44.18583020567894, 39.94979090988636, 38.70381496846676, 40.35330645740032, 38.22352834045887, 39.675552025437355, 38.5591871291399, 37.343829944729805, 38.38226482272148, 38.602349013090134, 39.65272285044193, 41.3201379776001, 42.327805906534195, 42.54086047410965, 42.03078344464302, 39.419042989611626, 42.19890922307968, 38.66221480071545, 40.74110984802246, 40.041111409664154, 40.3623803704977, 39.653813391923904, 39.43409778177738, 40.63693463802338, 39.908050149679184, 38.92402455210686, 39.42484527826309, 39.92025889456272, 38.7708243727684, 40.33131703734398, 40.14600858092308, 38.9962662756443, 42.035358399152756, 45.44167801737785, 51.379619389772415, 50.17992876470089, 53.42068366706371, 52.3034106194973, 51.604700312018394, 46.037406250834465, 47.41738960146904, 44.46007288992405, 43.2780247181654, 47.60724641382694, 55.4266682267189, 55.36281265318394, 57.42609053850174, 57.00084775686264, 60.52290536463261, 60.89247353374958, 64.67195212841034, 59.91972953081131, 62.39037595689297, 60.23860841989517, 69.93346139788628, 66.63719907402992, 58.58483076095581, 2.660484239459038, 0.2811576006934047, 0.8337436022702605, 0.8792037097737193, 0.1590869392384775, 6.029117004945874, 62.343528270721436, 65.78614354133606, 65.06036728620529, 67.29093879461288, 43.00642669200897, 18.458332233130932, 36.709507182240486, 43.580613881349564, 60.10539136826992, 25.381211154162884, 0.7333038293290883, 0.07392501094727777, 0.06783337375964038, 0.03761772168218158, 0.031015128806757275, 0.08380638813832775, 0.022124416718725115, 0.0077222608706506435, 0.04698300937889144, 0.04785903678566683, 0.12658967287279665, 0.08318786742165685, 0.058763828201335855, 0.11542133739567362, 0.06038001061824616, 22.952324487268925, 69.00767147541046, 53.14908184111118, 38.7783707678318, 22.353014945983887, 36.02346919476986, 40.753915160894394, 58.30676928162575, 66.88253670930862, 63.524683490395546, 54.1381573677063, 1.2656084191985428, 0.16113820573082194, 7.161422045901418, 21.9083609059453, 9.410726074129343, 0.5426201457157731, 10.887495931237936, 62.930592969059944, 57.30140782892704, 64.40602719783783, 53.586685359478, 60.811621472239494, 54.410021379590034, 58.21493960916996, 55.34020386636257, 53.32816623151302, 51.195055693387985, 50.77502243220806, 48.32920767366886, 49.25466701388359, 47.74815045297146, 51.13999664783478, 50.01445524394512, 53.922727927565575, 52.17360578477383, 50.37409074604511, 48.669019639492035, 49.95884142816067, 46.992511600255966, 47.13092677295208, 45.44507883489132, 43.43657121062279, 41.910117119550705, 40.039029121398926, 39.589087665081024, 40.571923926472664, 40.402152836322784, 42.16678574681282, 41.83706983923912, 40.66039077937603, 41.762168258428574, 42.00026348233223, 42.28646032512188, 42.43756681680679, 41.85933284461498, 42.06384167075157, 39.92799527943134, 40.47051876783371, 43.68616081774235, 42.24713243544102, 39.98560018837452, 43.47430698573589, 41.83554232120514, 41.41859069466591, 40.632097497582436, 42.280274257063866, 39.79547739028931, 41.24842442572117, 41.621879786252975, 41.13353759050369, 43.862900733947754, 48.327976539731026, 50.83700090646744, 48.61122854053974, 48.969484716653824, 45.890943109989166, 51.503830924630165, 54.12871867418289, 55.56093782186508, 56.597594395279884, 54.492454156279564, 53.65561746060848, 51.7379629611969, 51.265192329883575, 48.36126275360584, 49.473295882344246, 49.84342262148857, 45.13662278652191, 41.59851484000683, 41.07606187462807, 42.97312147915363, 39.457151144742966, 39.901601895689964, 39.90633264183998, 38.09759549796581, 41.300755217671394, 40.57247869670391, 41.13811634480953, 43.59387896955013, 43.06517533957958, 43.43866489827633, 43.11097048223019, 42.04759754240513, 42.02230229973793, 40.912480652332306, 41.52860999107361, 43.45797546207905, 43.43598984181881, 41.347834691405296, 41.66848428547382, 42.13515244424343, 42.950725480914116, 41.442837193608284, 40.97700119018555, 41.830879971385, 40.74689693748951, 42.29133166372776, 42.444368451833725, 41.72098986804485, 44.045518934726715, 48.372293561697006, 54.60926368832588, 51.54796175658703, 57.835868149995804, 56.519915163517, 53.30858588218689, 49.73229378461838, 49.74487490952015, 46.44300788640976, 46.70842744410038, 50.47521471977234, 55.61066575348377, 58.30281749367714, 59.88230533897877, 60.5240149050951, 63.543367087841034, 64.48954671621323, 66.8524119257927, 61.83737263083458, 64.65535461902618, 63.106709718704224, 70.89680850505829, 67.3700961470604, 61.03945344686508, 3.5522018652409315, 0.9681989718228579, 0.8459215331822634, 1.0090132942423224, 0.15415106347063556, 6.297234892845154, 68.82812350988388, 69.85586956143379, 71.99184894561768, 65.88005930185318, 45.553148835897446, 33.53174529969692, 44.639453664422035, 51.379387602210045, 67.88705080747604, 35.21467499434948, 0.8208014373667538, 0.058558746823109686, 0.03418370419240091, 0.027174191745871212, 0.019871851945936214, 0.06263140094233677, 0.06097673816839233, 0.14537291106535122, 0.11200245600775816, 0.1993255183333531, 0.28471934550907463, 0.17414044006727636, 0.17159984592581168, 0.28659721661824733, 0.20610805047908798, 30.801599398255348, 78.57202425599098, 61.69176824390888, 47.17028506100178, 24.27115961909294, 50.63029579818249, 52.007193714380264, 65.67356318235397, 72.9314549267292, 69.03784945607185, 59.05761279165745, 2.0057145366445184, 0.659731108462438, 10.762344896793365, 33.46855469048023, 10.001702662557364, 1.6121105197817087, 13.690404128283262, 65.51405534148216, 58.0572746694088, 66.36847749352455, 56.3410359621048, 63.53327102959156, 58.611847311258316, 61.214415058493614, 57.930806055665016, 53.51541258394718, 54.75432090461254, 54.31607522070408, 50.98533734679222, 52.12888218462467, 49.24381859600544, 53.06732922792435, 52.457948327064514, 57.090933322906494, 54.56750772893429, 51.46507300436497, 51.844471246004105, 52.553691789507866, 48.94233137369156, 49.219461902976036, 49.24086235463619, 46.289610117673874, 43.68263080716133, 43.94183769822121, 42.44733989238739, 43.344471752643585, 41.688003838062286, 44.70886453986168, 45.628274604678154, 41.09379552304745, 44.409311413764954, 44.385080114006996, 43.85030061006546, 45.224709659814835, 43.56338940560818, 44.58209194242954, 42.680563777685165, 42.29327715933323, 44.99257631599903, 43.346839025616646, 41.42745181918144, 45.93745641410351, 44.07693564891815, 43.88359822332859, 43.39054428040981, 43.62988963723183, 42.42400914430618, 42.779753655195236, 42.86849409341812, 43.93795430660248, 46.85839019715786, 50.65357334911823, 54.42334346473217, 52.36812874674797, 51.977559104561806, 49.73767809569836, 55.16677737236023, 56.86848945915699, 60.3228422999382, 55.47294594347477, 55.32182425260544, 55.60475707054138, 55.21612152457237, 53.35420623421669, 50.98027601838112, 52.48324356973171, 52.93031617999077, 49.315425753593445, 44.49687011539936, 41.119793727993965, 44.6729526668787, 40.562758818268776, 41.849506571888924, 41.02399706840515, 40.37166707217693, 43.476966843008995, 41.48182310163975, 42.41995856165886, 46.772978380322456, 45.705228075385094, 46.440526619553566, 45.8610425144434, 43.774962052702904, 44.642523899674416, 43.17513383924961, 43.50064717233181, 44.89623248577118, 46.237492114305496, 42.360237166285515, 44.45463538169861, 44.11228895187378, 46.26349791884422, 44.69105489552021, 42.82527141273022, 43.67687791585922, 42.639856562018394, 45.61539709568024, 45.670079961419106, 43.5190761834383, 46.3486285507679, 50.48543617129326, 57.7309899777174, 55.16630619764328, 59.37421940267086, 57.62239560484886, 56.658307537436485, 51.25993721187115, 52.46824957430363, 47.88616664707661, 48.34516681730747, 52.899347841739655, 58.68618652224541, 60.99457025527954, 63.84043514728546, 62.80468292534351, 66.36058151721954, 67.10271969437599, 71.15344673395157, 61.617862209677696, 69.18050140142441, 66.77279099822044, 75.29850751161575, 69.79592397809029, 63.66110377013683, 3.6807860154658556, 1.2560387514531612, 4.432272640988231, 3.817719267681241, 0.3017688822001219, 7.2183349169790745, 75.36146253347397, 76.77402913570404, 77.51984551548958, 79.8588328063488, 58.16556125879288, 32.60448105633259, 55.36744840443134, 61.893681809306145, 80.11215001344681, 45.10078690946102, 1.6099777654744685, 0.23365440516499802, 0.15727646998129785, 0.09929680614732206, 0.11039315329981036, 0.1912296816590242, 0.21604910376481712], [0.03298375158919953, 0.04913708187814336, 0.02780779846943915, 0.10706058368668891, 0.016236968476732727, 0.021278550193528645, 0.018389343313174322, 0.10286516349879093, 21.42320293933153, 60.62290079891682, 45.594498217105865, 38.107030391693115, 13.329603988677263, 45.90470977127552, 60.63325524330139, 47.61626332998276, 63.32978434860706, 56.20253339409828, 48.549318462610245, 0.6074118346441537, 0.04692075432103593, 2.186877653002739, 11.233257427811623, 2.1158152911812067, 0.31508838466834277, 20.717143826186657, 66.02813735604286, 50.764975771307945, 62.16114945709705, 57.04445041716099, 59.232802391052246, 50.20051226019859, 48.01184870302677, 45.59347987174988, 48.436529114842415, 44.230690598487854, 46.06946513056755, 42.00406327843666, 42.07982741296291, 45.102067440748215, 45.62913715839386, 43.48354049026966, 45.95435030758381, 42.95769810676575, 46.52080491185188, 46.551712453365326, 47.68403269350529, 44.96764585375786, 45.538151040673256, 40.563059002161026, 40.011913776397705, 38.55426639318466, 38.30811180174351, 37.698989287018776, 39.16718490421772, 37.41207428276539, 40.36468684673309, 39.32434447109699, 40.84290638566017, 38.936233296990395, 39.78889234364033, 41.11521117389202, 40.129582062363625, 39.08286742866039, 38.83926250040531, 39.919061958789825, 39.8590137809515, 38.785335794091225, 40.38242809474468, 38.1397770345211, 39.71274442970753, 40.50581507384777, 38.774411380290985, 37.78523325920105, 39.98482123017311, 39.02976907789707, 39.946279898285866, 39.31898295879364, 38.48517470061779, 40.25728181004524, 44.999594539403915, 48.03935922682285, 48.80227468907833, 47.415721490979195, 44.976457580924034, 49.736511558294296, 51.4097023755312, 47.07130417227745, 39.152293503284454, 49.054216369986534, 50.4630895704031, 53.62443633377552, 47.22308322787285, 43.79281349480152, 47.80965015292168, 46.39711394906044, 41.36976711452007, 38.21445822715759, 41.65622614324093, 40.003706216812134, 41.46075703203678, 39.79694411158562, 40.25380119681358, 39.55765575170517, 40.263201892375946, 39.06413823366165, 41.13818474113941, 39.662286937236786, 43.2833444327116, 41.779388934373856, 39.9489663541317, 41.591591611504555, 40.92547595500946, 38.1809364259243, 39.47701647877693, 41.2110610306263, 39.92959879338741, 39.088821709156036, 40.86521118879318, 39.55346457660198, 37.53358416259289, 38.69398109614849, 39.300208166241646, 39.094867184758186, 38.26064094901085, 37.955676913261414, 39.84216928482056, 40.86084142327309, 41.61265008151531, 46.619952991604805, 54.99776244163513, 49.09925155341625, 54.31344576179981, 55.32889187335968, 54.95629146695137, 53.132472932338715, 52.97057121992111, 52.435240745544434, 55.40809102356434, 55.039560198783875, 56.32366709411144, 55.553832203149796, 59.6677802503109, 59.06232833862305, 61.62824705243111, 61.218644231557846, 58.69315914809704, 65.3512492775917, 62.3386113345623, 62.036622539162636, 72.73395672440529, 78.97899761795998, 45.465715527534485, 3.4009041963145137, 0.5429420003201813, 0.1113931750296615, 1.7930228495970368, 0.21105792315211147, 3.707706620916724, 57.176170349121094, 64.66081112623215, 61.93922236561775, 57.815315052866936, 35.46425700187683, 6.50687581859529, 18.124256059527397, 40.980155020952225, 57.11238317191601, 37.82160110771656, 0.8640260773245245, 0.06532260653330013, 0.05578630203672219, 0.08642676315503195, 0.061145766012487, 0.037082288108649664, 0.02765147619356867, 0.011285354539722903, 0.05076791800092906, 0.033067280310206115, 0.024038215196924284, 0.0227327162065194, 0.01772070536389947, 0.05731305936933495, 0.1570708505460061, 29.530041329562664, 70.07510259747505, 54.98266965150833, 42.3772906512022, 17.18906544148922, 51.11902937293053, 58.04364860057831, 54.656035378575325, 67.1172197163105, 63.05638141930103, 52.51978240907192, 0.5497988511342555, 0.1472222391748801, 5.936310309916735, 13.62940315157175, 6.076202653348446, 0.4912474367301911, 21.767888143658638, 64.50968563556671, 51.39651708304882, 63.911210149526596, 58.27282950282097, 61.11547216773033, 52.78684347867966, 51.93235293030739, 47.45505318045616, 49.82478842139244, 48.9195591956377, 47.47927688062191, 46.10479563474655, 44.74405065178871, 48.06304715573788, 46.76299251616001, 47.51036301255226, 46.629300490021706, 46.64352312684059, 49.374911561608315, 48.671223521232605, 48.67186188697815, 46.718413308262825, 49.12369564175606, 43.161743357777596, 41.65700130164623, 40.70609852671623, 40.68440929055214, 39.52167168259621, 42.24113255739212, 39.94279928505421, 42.340907603502274, 41.01779580116272, 43.30663338303566, 41.982115656137466, 39.674282893538475, 42.81384542584419, 42.079512029886246, 41.017655208706856, 40.91610185801983, 41.49281211197376, 41.714423820376396, 40.89907117187977, 42.94183395802975, 39.901438504457474, 42.91179656982422, 44.20245811343193, 40.03133453428745, 39.81609508395195, 41.386877596378326, 40.25871813297272, 41.47717975080013, 40.339828580617905, 42.01062932610512, 43.13829481601715, 50.21238662302494, 51.104517951607704, 50.88043637573719, 49.12519656121731, 46.02979525923729, 52.46009901165962, 53.65233063697815, 50.364883840084076, 40.95846578478813, 49.784138202667236, 51.977334916591644, 56.251406371593475, 49.86970581114292, 46.69576272368431, 49.35533121228218, 49.584154933691025, 46.11351236701012, 40.72516590356827, 43.16454380750656, 42.52198688685894, 42.955501824617386, 42.2648660838604, 40.956896468997, 40.60310125350952, 42.408403381705284, 41.675156727433205, 42.27531932294369, 40.43739594519138, 43.71524825692177, 43.22512395679951, 42.16693393886089, 41.97410948574543, 43.00225831568241, 39.5018557459116, 41.14536635577679, 42.06118941307068, 41.18950478732586, 41.28476947546005, 42.68470175564289, 41.85635760426521, 40.21348536014557, 40.46815149486065, 42.96096973121166, 41.5155690908432, 40.31861811876297, 40.809346586465836, 42.89549924433231, 44.17961373925209, 44.08801205456257, 49.154717177152634, 56.938519701361656, 51.467497274279594, 56.32773667573929, 57.03593887388706, 57.86668449640274, 55.43303668498993, 54.34225581586361, 54.49095703661442, 57.77320571243763, 57.22628965973854, 56.97094336152077, 59.27459254860878, 63.11540365219116, 61.735503897070885, 66.30899548530579, 61.69960342347622, 53.817484974861145, 65.98088309168816, 66.10175460577011, 65.08604630827904, 72.15252712368965, 75.45961886644363, 50.631219148635864, 3.3227110421285033, 0.46504781290423125, 2.5337600894272327, 0.8032909675966948, 0.1258789625717327, 4.082411164417863, 62.73077689111233, 71.0968753695488, 67.89725705981255, 63.730366453528404, 36.10230356454849, 11.194033082574606, 25.546893663704395, 48.61062057316303, 64.95762079954147, 46.899511590600014, 1.2607147567905486, 0.09134532461757772, 0.1179877582762856, 0.03172477227053605, 0.03228826644772198, 0.02380243116931524, 0.05466501337650698, 0.13230995420599356, 0.13224491238361225, 0.12388703078613617, 0.17090368171921, 0.18553113040979952, 0.12343108493951149, 0.15912201313767582, 0.3214306302834302, 39.931597486138344, 81.85510128736496, 62.33574628829956, 52.208092734217644, 22.03427854925394, 55.146140679717064, 71.00137889385223, 62.84593351185322, 73.19469720125198, 70.93289896845818, 56.042539179325104, 0.7814036076888442, 0.35666720825247467, 11.900101695209742, 20.74768278747797, 9.23598675057292, 1.9620927586220205, 27.148612216114998, 66.08764976263046, 53.35676349699497, 66.47936314344406, 59.359130412340164, 64.84795868396759, 56.27411775290966, 51.63124568760395, 50.2136405557394, 53.254883363842964, 50.422644540667534, 50.34556187689304, 46.39790050685406, 46.497181579470634, 49.6142303198576, 49.897543117403984, 49.7757900506258, 49.52849172055721, 48.47212180495262, 52.36106492578983, 51.74291029572487, 51.30382485687733, 49.77487429976463, 51.10261045396328, 43.72450456023216, 44.734235778450966, 43.195607140660286, 43.69934231042862, 41.685583367943764, 45.28220437467098, 41.8064358830452, 44.88908886909485, 45.43330326676369, 46.976647451519966, 43.740482702851295, 43.08632880449295, 46.420554891228676, 44.3334598839283, 41.66951783001423, 42.74026237428188, 44.531406462192535, 43.91784578561783, 41.7344943434, 45.61265364289284, 42.33624145388603, 45.09456664323807, 44.87706631422043, 42.08972968161106, 40.19157573580742, 42.54264257848263, 42.662092968821526, 42.87475235760212, 42.664597034454346, 44.10482995212078, 45.2791303396225, 52.67417572438717, 52.666454538702965, 53.74169424176216, 52.914733216166496, 48.961869925260544, 55.72057485580444, 58.36265668272972, 51.00373595952988, 43.71965602040291, 53.4795843064785, 56.71875849366188, 59.05297324061394, 52.81694546341896, 48.43204915523529, 51.672135293483734, 52.38491244614124, 47.14219696819782, 42.01626442372799, 45.19867725670338, 45.09189918637276, 46.15779519081116, 45.307856798172, 43.23323272168636, 42.19633296132088, 44.22355838119984, 43.31628866493702, 44.88215044140816, 42.680803164839745, 46.55304618179798, 46.72282487154007, 43.53721261024475, 44.33693289756775, 44.7635892033577, 41.095653623342514, 43.346512243151665, 45.11485755443573, 44.71553698182106, 43.189440071582794, 44.25462171435356, 43.57003524899483, 42.142983824014664, 42.17770256102085, 44.16451334953308, 43.958891183137894, 42.293847128748894, 42.66091123223305, 44.88136388361454, 46.296780332922935, 44.844828844070435, 50.78908547759056, 59.50038023293018, 52.56497338414192, 60.0589844584465, 58.300199434161186, 59.38654974102974, 57.660249173641205, 57.03266724944115, 56.77742354571819, 59.879558086395264, 59.41665932536125, 60.00299446284771, 60.63964270055294, 63.63064080476761, 63.39388690888882, 68.3011069893837, 64.09610822796822, 57.38620027899742, 66.23248279094696, 66.25107899308205, 65.74918672442436, 75.62823101878166, 74.08527821302414, 53.3134800195694, 4.729623310267925, 1.578767190221697, 5.867245215922594, 6.058753989636898, 0.4400127672124654, 4.570395704358816, 67.89908856153488, 77.52667754888535, 73.53071317076683, 72.80521050095558, 42.594221010804176, 13.880622871220112, 33.62269341945648, 59.057422801852226, 76.78305745124817, 58.50177101790905, 1.9134486000984907, 0.21854172548046336, 0.18390465440461412, 0.1297983928816393, 0.14430824085138738, 0.17605592322070152, 0.08644697183626704], [0.09002916282042861, 0.05391019723901991, 0.05135497536684852, 0.008390215116378386, 0.0759962857409846, 0.013535148318624124, 0.2289745258167386, 0.40735654765740037, 23.59219115227461, 65.32096490263939, 45.387492924928665, 38.00019532442093, 18.03973339498043, 17.419621869921684, 41.47081509232521, 54.15458008646965, 63.13066363334656, 58.85952182114124, 45.52833616733551, 0.1841622538631782, 0.07302330894162878, 6.952931983396411, 24.299065321683884, 13.549065962433815, 0.08607411684351973, 38.488172739744186, 63.27448211610317, 57.20449022948742, 62.433781027793884, 58.45312982797623, 57.970996499061584, 52.31534577906132, 45.10763794183731, 44.683941677212715, 42.49838635325432, 41.330819204449654, 43.0694767087698, 42.369128689169884, 42.1629973500967, 43.24340857565403, 41.87187597155571, 42.444744631648064, 41.15689113736153, 46.019835993647575, 41.98188006877899, 44.96779404580593, 46.00370965898037, 43.0206873267889, 40.91732159256935, 38.04043136537075, 38.42136092483997, 37.79767379164696, 38.61126333475113, 38.22894684970379, 38.43867279589176, 39.54771168529987, 36.87368877232075, 39.552472829818726, 37.81977720558643, 40.23444123566151, 38.33841897547245, 40.21615281701088, 38.685640543699265, 40.67243993282318, 38.34136761724949, 38.31669934093952, 38.24641831219196, 42.231747061014175, 37.44792155921459, 39.85622473061085, 41.36555694043636, 42.55748078227043, 40.9473779797554, 38.166189417243004, 37.6412133872509, 40.682870373129845, 38.79583463072777, 39.07702714204788, 40.20648993551731, 39.22691009938717, 45.17889551818371, 50.47606587409973, 50.50612226128578, 48.18422645330429, 43.81661921739578, 49.98726390302181, 51.97139963507652, 54.419197887182236, 43.1710110604763, 43.542026951909065, 52.530881613492966, 48.41674357652664, 47.93182119727135, 47.31515608727932, 47.697176188230515, 47.58340269327164, 44.277340695261955, 39.78988789021969, 40.18517687916756, 38.715791925787926, 40.46244040131569, 38.824181109666824, 39.3341289460659, 38.95901307463646, 40.364071279764175, 40.65537504851818, 42.77815394103527, 41.78264915943146, 43.39320033788681, 41.391068771481514, 41.42130374908447, 39.81971628963947, 39.75867256522179, 39.82845962047577, 37.83287510275841, 40.38866735994816, 38.44332754611969, 40.0461233407259, 37.27823406457901, 40.85688963532448, 39.85041104257107, 39.79620695114136, 40.0544448941946, 39.24221187829971, 40.74964039027691, 39.21798437833786, 39.70519043505192, 39.919191151857376, 41.200349405407906, 47.846135795116425, 52.44042746722698, 52.51738853752613, 50.96533142030239, 51.39786221086979, 56.93814732134342, 55.03614418208599, 53.84477511048317, 55.868421122431755, 58.18657033145428, 57.740375474095345, 56.00520618259907, 60.25404319167137, 58.60450990498066, 56.179692819714546, 55.785558968782425, 57.443349212408066, 33.49529765546322, 44.17092740535736, 64.73330363631248, 55.36352701485157, 62.533347085118294, 61.626692935824394, 47.374706491827965, 3.8417211547493935, 0.7186048524454236, 0.37609399238135666, 0.1484636592795141, 0.11858854908496141, 3.160109454765916, 58.71365524828434, 63.081011697649956, 65.709767639637, 57.32016362249851, 52.268479093909264, 25.873353146016598, 14.0044173784554, 30.869212970137596, 53.739691749215126, 42.36980505287647, 2.699426687322557, 0.04555908031761646, 0.04858147673076019, 0.04099295736523345, 0.024465272945235483, 0.052228397835278884, 0.027670977979141753, 0.08666373090818524, 0.04023709479952231, 0.0266639429537463, 0.060667344223475084, 0.044393604184733704, 0.05752169934567064, 0.1591736072441563, 0.6597488012630492, 31.40205267816782, 74.24918621778488, 50.93948520720005, 43.968804851174355, 19.56341553479433, 25.558051764965057, 47.31721557676792, 58.23925070464611, 68.53862464427948, 62.80040815472603, 49.95897062122822, 0.38146589475218207, 0.23372088675387204, 7.554804012179375, 21.37328501790762, 2.6790319941937923, 0.2271813337574713, 39.36340257525444, 64.59346354007721, 56.419410556554794, 67.11205959320068, 59.33869890868664, 61.01277507841587, 54.2101027071476, 47.04991891980171, 47.055744007229805, 44.769813269376755, 42.067284286022186, 45.655484944581985, 45.26446312665939, 44.19751077890396, 45.621218383312225, 43.80927041172981, 45.60273997485638, 44.18801888823509, 46.917340233922005, 44.69243802130222, 47.16754160821438, 48.598438426852226, 44.59595739841461, 42.89338655769825, 41.137090399861336, 42.05608628690243, 41.013992205262184, 40.19407220184803, 39.792380556464195, 41.398949548602104, 42.34086960554123, 39.465708285570145, 40.97757875919342, 39.95649375021458, 41.26141972839832, 39.17486809194088, 41.309057772159576, 41.33645810186863, 41.605080887675285, 39.52682800590992, 40.2289467304945, 40.117080733180046, 41.37176960706711, 39.372563883662224, 41.219093799591064, 44.08910259604454, 43.805311024188995, 40.660934150218964, 40.50120212137699, 40.005993694067, 42.413445711135864, 41.043987795710564, 40.93274496495724, 41.516602635383606, 41.565095633268356, 49.02690343558788, 50.977030992507935, 51.86853535473347, 51.16518549621105, 47.40675397217274, 52.98850245773792, 54.81530383229256, 55.18732286989689, 43.756217658519745, 45.30334264039993, 54.936813712120056, 51.6950024664402, 51.35808974504471, 49.519224017858505, 50.909630209207535, 49.53017883002758, 45.69368049502373, 41.62694491446018, 41.64181351661682, 39.89521823823452, 41.73976846039295, 42.2590371966362, 42.365940660238266, 39.46895711123943, 41.05595335364342, 43.03180173039436, 44.23616610467434, 45.24677887558937, 44.585618153214455, 42.503158897161484, 42.919878736138344, 40.72838433086872, 42.11545430123806, 41.00013054907322, 39.47617672383785, 41.75890043377876, 41.21747508645058, 42.54683755338192, 38.953632563352585, 42.108272686600685, 42.31596574187279, 41.0218121856451, 41.3233108073473, 41.97293534874916, 41.35798394680023, 41.819366589188576, 42.489225044846535, 42.7761210501194, 44.16663743555546, 49.804296121001244, 54.2790462076664, 55.295985639095306, 52.28554777801037, 55.073055401444435, 59.192155972123146, 57.010997012257576, 55.955390855669975, 56.11503928899765, 62.15730406343937, 59.45856727659702, 58.074662536382675, 61.48397259414196, 58.41982461512089, 57.98451617360115, 55.719434916973114, 57.99288712441921, 34.30956356227398, 45.121062621474266, 64.38025698065758, 56.882343515753746, 65.824855864048, 60.48352807760239, 51.03001534938812, 4.413043772801757, 0.3840004774974659, 1.6837025969289243, 0.06750760803697631, 0.14887172175804153, 3.393069254234433, 62.436741068959236, 70.565215498209, 71.30822762846947, 65.55291965603828, 51.469625160098076, 23.73338397592306, 18.937412425875664, 38.30915294587612, 64.03300121426582, 52.39115931093693, 3.7071561254560947, 0.09539263439364731, 0.02892428543418646, 0.04503250056586694, 0.049559530889382586, 0.0940805692516733, 0.08958409685874358, 0.2848942845594138, 0.2040834864601493, 0.12335237275692634, 0.16070755227701738, 0.34017950703855604, 0.2234601162490435, 0.26330063701607287, 0.9821927302982658, 44.246623143553734, 84.32983249425888, 59.68350760638714, 54.62349392473698, 27.211612835526466, 24.347009249031544, 55.056324899196625, 64.75626960396767, 74.1534161567688, 69.92325514554977, 57.01921597123146, 0.3999050287529826, 0.34885610395576805, 15.748232156038284, 39.77141708135605, 22.88943026214838, 0.3519988025072962, 44.48759101331234, 64.42661449313164, 58.55443239212036, 68.17683085799217, 63.90383094549179, 63.679456785321236, 57.50195346772671, 50.030972957611084, 48.849243968725204, 48.87729026377201, 43.35387244820595, 48.66977199912071, 47.55026087164879, 47.02275037765503, 48.221703842282295, 46.79345168173313, 47.70754963159561, 46.05999983847141, 49.607101902365685, 47.00290024280548, 50.876932963728905, 52.732156813144684, 48.015238121151924, 45.13704836368561, 43.87301579117775, 44.093780145049095, 44.26911413669586, 42.919031381607056, 43.196078315377235, 44.20123837888241, 45.33834636211395, 41.9800029695034, 44.49135661125183, 41.90289370715618, 43.5475442558527, 41.84770546853542, 43.80681574344635, 41.741280779242516, 43.60616751015186, 42.00304873287678, 42.416721135377884, 41.55453599989414, 45.73515146970749, 42.707489132881165, 42.72024504840374, 45.84047041833401, 46.33544705808163, 44.02940779924393, 42.047791332006454, 40.654546692967415, 44.423435255885124, 42.62733243405819, 42.17728078365326, 45.71442738175392, 42.13789589703083, 51.16862431168556, 54.435575008392334, 57.85678222775459, 55.037622302770615, 49.81346882879734, 54.68743309378624, 57.91893549263477, 58.237058222293854, 46.2912592291832, 48.618581146001816, 59.10381831228733, 52.606060579419136, 52.658205181360245, 52.634220868349075, 53.36542323231697, 53.211219906806946, 49.30805414915085, 42.780129835009575, 44.39891517162323, 41.5546689927578, 42.55898170173168, 43.174784258008, 44.48339223861694, 41.74965173006058, 42.0797324180603, 43.94321322441101, 47.13611729443073, 48.1512214243412, 46.09652727842331, 43.20083186030388, 45.99824175238609, 42.86497928202152, 44.215685203671455, 44.07906353473663, 42.71793857216835, 43.16596873104572, 42.62549713253975, 44.393568858504295, 39.43005859851837, 44.53844368457794, 44.150788486003876, 43.27239342033863, 43.504758551716805, 42.53703407943249, 44.78482626378536, 43.91318343579769, 45.15314429998398, 44.264725372195244, 47.40811429917812, 51.20061859488487, 57.19919711351395, 55.55451616644859, 56.09102077782154, 57.09127530455589, 59.67991299927235, 60.889897271990776, 57.368983402848244, 60.023235976696014, 63.08069251477718, 62.576858550310135, 60.65591722726822, 64.4099409878254, 59.73136603832245, 59.71319921314716, 58.47690895199776, 58.75464364886284, 36.50802679359913, 48.36679905653, 64.8752412199974, 57.58467122912407, 66.98392286896706, 61.929012313485146, 55.87496057152748, 5.207101413980126, 1.792403245344758, 3.9659543009474874, 2.0179539173841476, 0.2907953382236883, 3.72954951133579, 67.2662553191185, 75.78084602952003, 76.85721427202225, 76.39031812548637, 68.41924265027046, 37.274669855833054, 28.153855875134468, 49.43771459162235, 73.20535182952881, 63.126681447029114, 5.41452088393271, 0.20012580585898831, 0.13663462683325633, 0.12446632157661952, 0.15437643887707964, 0.1571069040801376, 0.27017610089387745], [0.07800484163453802, 0.015305173310480313, 0.036208123492542654, 0.01842423909693025, 0.030852186573611107, 0.023190573083411437, 0.1678949556662701, 0.3091212798608467, 27.979029156267643, 55.984178110957146, 46.39579921960831, 33.03345903754234, 15.822062194347382, 37.39033184945583, 37.51514375209808, 55.27003303170204, 62.608879432082176, 60.04666551947594, 47.499381601810455, 0.23312124627409503, 0.15863491193158552, 7.95378022827208, 20.21935723721981, 0.7034447346813977, 1.2137322966009378, 48.3938992023468, 54.45966571569443, 53.32638032734394, 54.35058876872063, 60.713563933968544, 55.55676184594631, 57.04665809869766, 45.53023226559162, 44.547339007258415, 40.125371888279915, 42.73148104548454, 42.773320600390434, 45.24640649557114, 42.43938311934471, 40.80786846578121, 42.121024802327156, 44.40210320055485, 41.78342431783676, 42.10505425930023, 42.06764526665211, 40.96282035112381, 40.07134638726711, 38.901905938982964, 37.879677191376686, 38.96653287112713, 38.69033709168434, 39.65507872402668, 38.41427430510521, 39.66129519045353, 36.82816341519356, 38.45082454383373, 37.59111687541008, 38.08348685503006, 38.70112091302872, 37.232704907655716, 38.22864666581154, 40.22705063223839, 38.32559086382389, 39.40436817705631, 38.04380938410759, 40.731196179986, 38.908905163407326, 40.49695774912834, 38.239027708768845, 40.767731219530106, 42.453347370028496, 41.08118399977684, 40.36692872643471, 39.76049646735191, 37.49874763190746, 35.70729576051235, 38.216038942337036, 38.870743811130524, 38.13386455178261, 38.76751855015755, 45.198255479335785, 47.20179297029972, 51.33497178554535, 50.603454038500786, 44.53679837286472, 47.587286084890366, 49.79633554816246, 53.056496009230614, 47.867866829037666, 46.68926887214184, 51.3008876144886, 50.417397022247314, 51.49694189429283, 49.34996210038662, 48.95469211041927, 47.44276463985443, 42.839942425489426, 38.42511512339115, 40.90002492070198, 40.686635971069336, 40.3972776979208, 38.772199898958206, 38.09026189148426, 39.83203522861004, 40.923078283667564, 41.27553977072239, 45.14265686273575, 44.89202231168747, 45.77780798077583, 39.79493021965027, 39.828292429447174, 37.88120090961456, 40.211380273103714, 39.936674013733864, 38.4095511585474, 41.22190564870834, 38.55727583169937, 41.4329045265913, 37.50673480331898, 40.47114573419094, 39.70840506255627, 38.62978354096413, 36.985687762498856, 36.13957956433296, 41.29666283726692, 38.813849464058876, 39.06759224832058, 39.18706163764, 40.454555824398994, 43.637990802526474, 54.598685055971146, 52.18462899327278, 55.40940195322037, 53.71451810002327, 52.33369119465351, 56.655495688319206, 55.867083594202995, 56.16562977433205, 57.06623464822769, 57.64633432030678, 58.514021560549736, 54.49612855911255, 58.5025841742754, 62.97215893864632, 59.94302608072758, 61.47473528981209, 63.13381366431713, 62.52025678753853, 63.27670879662037, 62.14599587023258, 47.7048783749342, 43.631405755877495, 54.44520369172096, 4.229739708825946, 0.16162174462806433, 1.417023881804198, 0.4071703279623762, 0.07340915894019417, 1.5580168599262834, 55.47739930450916, 65.09224757552147, 66.10342651605606, 62.4614055454731, 39.04515065252781, 14.869433362036943, 17.49905090779066, 33.38636890053749, 48.83144572377205, 48.18109542131424, 4.465821040794253, 0.10780498007079586, 0.030592956245527603, 0.054156519763637334, 0.042830437087104656, 0.12561808282043785, 0.04175909867626615, 0.05006813953514211, 0.05150931981916074, 0.037369907440734096, 0.02622158768645022, 0.052326242584967986, 0.020656660126405768, 0.16386052215239033, 0.2604964765487239, 36.854993775486946, 68.22749733924866, 52.312058955430984, 40.39613775908947, 19.202144220471382, 34.638401716947556, 45.95262140035629, 58.62673111259937, 68.17141994833946, 64.06287521123886, 54.12233501672745, 0.22663336159894243, 0.17906303139170632, 5.960485087707639, 26.467871144413948, 1.820084759965539, 1.5797592932358384, 52.8327564150095, 55.20186468958855, 57.1317545324564, 56.28931313753128, 62.41648055613041, 58.25668416917324, 60.767726227641106, 47.62717254459858, 45.100167542696, 41.90893158316612, 45.376610308885574, 45.1011098921299, 46.910967975854874, 44.57155130803585, 43.02267462015152, 44.32820476591587, 45.759424567222595, 43.798072412610054, 44.98851053416729, 43.697127029299736, 43.32928016781807, 41.341428235173225, 40.42424865067005, 39.37366962432861, 41.43321990966797, 40.42595475912094, 40.86173437535763, 40.06416477262974, 39.972441494464874, 37.839843928813934, 41.592860743403435, 40.601277351379395, 40.044037252664566, 41.677987575531006, 40.6198051571846, 40.582095980644226, 42.15281769633293, 40.951367765665054, 41.251088082790375, 38.78489501774311, 43.524388298392296, 40.264246836304665, 42.185792326927185, 39.08806174993515, 42.55814574658871, 43.29001687467098, 41.6381923109293, 41.91367752850056, 41.75792768597603, 40.6337808072567, 38.06106045842171, 39.62488554418087, 39.92771029472351, 41.19645841419697, 41.16065293550491, 47.39191956818104, 50.642565339803696, 51.00326858460903, 51.14450320601463, 46.64625898003578, 49.8162616789341, 51.03470429778099, 55.40431782603264, 49.71295662224293, 47.44884051382542, 52.14631944894791, 50.796206295490265, 52.63957478106022, 49.3284210562706, 51.399583518505096, 49.74579446017742, 43.766123726964, 39.576191157102585, 41.58249869942665, 42.6271728426218, 41.02679371833801, 40.7537517696619, 41.27181977033615, 41.70011758804321, 43.003839030861855, 44.179446548223495, 46.69584631919861, 45.72656773030758, 46.14692397415638, 43.277241960167885, 42.284560427069664, 39.18884374201298, 42.29493387043476, 41.23200550675392, 41.26645065844059, 41.1329448223114, 40.927478447556496, 43.970571756362915, 38.60804870724678, 42.01673939824104, 40.758322924375534, 41.63696877658367, 39.81295645236969, 41.002923399209976, 42.16473005712032, 41.644062995910645, 40.701933950185776, 41.76968425512314, 43.85422959923744, 46.72116816043854, 56.78975008428097, 55.441248044371605, 57.421713173389435, 53.31310763955116, 54.548793733119965, 57.504875510931015, 57.900647073984146, 57.887157797813416, 60.844896286726, 59.341354966163635, 58.54651361703873, 55.70101350545883, 59.84268106520176, 66.03256791830063, 62.39917628467083, 63.00881177186966, 65.99830895662308, 62.652869671583176, 66.10047787427902, 64.12545025348663, 53.50922651588917, 43.53627026081085, 57.672530114650726, 4.6356510277837515, 0.11142844188725576, 4.20238877646625, 0.8947690401691943, 0.05655217988532968, 1.8114027008414268, 61.56278796494007, 69.58809033036232, 72.10341855883598, 70.46525806188583, 45.011187717318535, 21.535619907081127, 24.310426712036133, 41.250377520918846, 57.29654788970947, 57.851131930947304, 6.118221273645759, 0.2174953863141127, 0.028795674952561967, 0.04118951517739333, 0.0445003250206355, 0.08466566898277961, 0.07363670883933082, 0.1716932377894409, 0.18906865152530372, 0.1454855245538056, 0.11917816314962693, 0.13525806163670495, 0.12906761490739882, 0.24750338547164574, 0.6725763785652816, 47.135467529296875, 77.67384365200996, 62.16586500406265, 47.99793004989624, 24.413564577698708, 49.36540067195892, 50.950884595513344, 67.27030590176582, 71.82703658938408, 71.21430426836014, 58.51811394095421, 0.3772075998131186, 0.5155998549889773, 15.131023675203323, 37.160276994109154, 3.798929275944829, 2.142019160091877, 58.01391139626503, 56.30542807281017, 60.52224040031433, 56.83996059000492, 64.95164752006531, 60.6841117143631, 63.826451897621155, 50.31228706240654, 48.43674190342426, 44.288470298051834, 47.189747616648674, 47.40447789430618, 48.33608530461788, 46.72426879405975, 46.01049989461899, 47.9724258184433, 48.91879923641682, 48.27986352145672, 47.76224009692669, 46.54290072619915, 46.638826578855515, 44.629498198628426, 42.695287987589836, 43.014284670352936, 44.26967270672321, 43.84213864803314, 44.45006422698498, 43.50827716290951, 44.011552557349205, 40.042148754000664, 44.13791097700596, 42.05620788037777, 43.843848556280136, 44.92235608398914, 42.226336151361465, 42.84955590963364, 44.04994189739227, 42.14380457997322, 44.390335232019424, 41.7026786506176, 46.61195442080498, 43.36357332766056, 44.65200439095497, 42.29146085679531, 45.19999958574772, 47.21366733312607, 45.08691385388374, 44.714476838707924, 44.37274217605591, 43.1994791328907, 39.07132364809513, 41.972141191363335, 41.743621453642845, 42.02995888888836, 42.48765952885151, 51.20526194572449, 51.2513230741024, 53.98659490048885, 54.14027005434036, 48.058381006121635, 53.08113768696785, 55.31057685613632, 55.704539716243744, 52.252641543745995, 49.457500129938126, 55.48407554626465, 54.24388289451599, 54.802449122071266, 53.77093367278576, 53.327189683914185, 52.08046518266201, 45.05892835557461, 42.85728469491005, 42.50375546514988, 45.01539409160614, 43.17568860948086, 44.01983991265297, 43.40524949133396, 43.62441033124924, 45.60810528695583, 45.12724868953228, 50.37433013319969, 47.82273665070534, 48.219070583581924, 44.616419300436974, 43.336283192038536, 42.50450402498245, 45.03286175429821, 43.51697489619255, 43.47998388111591, 44.420820996165276, 41.64504714310169, 45.9773238748312, 40.24304777383804, 44.513843804597855, 43.58843766152859, 43.596497029066086, 42.223668694496155, 41.559384539723396, 45.58233506977558, 43.85483756661415, 44.40745331346989, 42.38236717879772, 45.658220797777176, 48.15112642943859, 56.73013128340244, 58.515530079603195, 57.937432900071144, 56.11014895141125, 58.01997967064381, 59.398431703448296, 60.5889268219471, 59.992032051086426, 63.50988708436489, 62.2585192322731, 61.88240401446819, 55.761050283908844, 61.424722373485565, 67.26192355155945, 64.96808543801308, 65.69635435938835, 68.85906144976616, 63.36869426071644, 69.2622122168541, 66.13786026835442, 55.958005115389824, 47.37936124205589, 61.093463748693466, 5.73176633566618, 0.3949808789184317, 5.841102143749595, 2.4283212097361684, 0.37617916124872863, 2.1776871336624026, 66.25927895307541, 77.78262421488762, 77.20538958907127, 79.13230419158936, 47.7660246938467, 24.56702884286642, 32.230068147182465, 53.772559985518456, 66.22225373983383, 70.6285808980465, 7.8927327040582895, 0.2779243601253256, 0.11848278561956249, 0.14093020727159455, 0.18247260624775663, 0.23155065398896113, 0.13617609831271693], [0.030863548854540568, 0.07192422533989884, 0.05547838496568147, 0.044037822299287654, 0.045011241745669395, 0.046115368240862153, 0.1656691063544713, 0.3630752378376201, 25.416104681789875, 60.20157940685749, 47.339763566851616, 44.12803530693054, 23.809328600764275, 24.226561412215233, 35.47523461282253, 60.20764768123627, 61.612451300024986, 59.67882625758648, 45.12760207056999, 0.28471637691836804, 0.24160513712558895, 6.225495217368007, 17.070629596710205, 0.9559322206769139, 2.8306101355701685, 53.00964452326298, 46.320035085082054, 57.19637766480446, 56.11185505986214, 57.2489782422781, 58.01929950714111, 56.13225236535072, 46.93796932697296, 44.63819593191147, 43.103123903274536, 42.39913187921047, 43.01928140223026, 42.740691751241684, 42.3299527913332, 43.82570073008537, 40.37643201649189, 42.49330222606659, 41.75573520362377, 41.983658373355865, 39.31692346930504, 39.95080545544624, 37.322889268398285, 37.23636791110039, 35.53665831685066, 36.05957865715027, 36.9290442019701, 38.77174012362957, 37.141335010528564, 37.982879653573036, 37.916599810123444, 38.21736127138138, 36.96127787232399, 38.41845028102398, 38.358660489320755, 38.91700252890587, 37.18620300292969, 37.679291144013405, 38.70060794055462, 39.59203250706196, 37.0020192861557, 38.43105800449848, 37.21779450774193, 39.77336257696152, 38.54447811841965, 40.329899713397026, 41.221784055233, 39.015390649437904, 39.876382648944855, 39.31322626769543, 38.01708161830902, 35.89078791439533, 38.014383763074875, 38.992667868733406, 40.486147329211235, 37.88364037871361, 42.5427907705307, 48.190009742975235, 48.26199308037758, 49.59992788732052, 48.64499732851982, 46.228118017315865, 48.8019935041666, 51.38004116714001, 49.357280507683754, 46.29238396883011, 49.77745436131954, 50.095466896891594, 50.12118011713028, 50.66559970378876, 50.75934447348118, 45.189713537693024, 40.826213881373405, 36.863087341189384, 38.475728407502174, 40.09459733963013, 39.808408096432686, 39.30858671665192, 38.499670922756195, 38.925848454236984, 42.83295840024948, 41.97561800479889, 45.347344279289246, 45.46199172735214, 44.81649376451969, 41.51629865169525, 39.66938875615597, 39.793110117316246, 40.297441855072975, 38.15033286809921, 41.45296365022659, 39.27695341408253, 39.90477852523327, 39.3530785292387, 40.322763696312904, 38.62573675811291, 40.00091336667538, 38.35229583084583, 37.880353555083275, 37.37214222550392, 40.41609428822994, 38.69464226067066, 38.49524796009064, 39.348279386758804, 39.08760957419872, 41.342997550964355, 48.81675951182842, 55.7361426204443, 54.3220940977335, 58.45168210566044, 57.4485207349062, 56.52148447930813, 55.35100668668747, 53.93384613096714, 54.3639412522316, 53.294348046183586, 56.34504474699497, 58.88200901448727, 60.458289831876755, 57.30553440749645, 61.154089495539665, 56.04835666716099, 59.73181441426277, 60.158056542277336, 65.02180695533752, 61.99195593595505, 53.77018131315708, 39.61651839315891, 44.18271817266941, 4.372567869722843, 0.1532284848508425, 1.6573745221830904, 0.41823468112852424, 0.095524432399543, 1.6172422631643713, 54.45960111916065, 66.04467406868935, 65.91994196176529, 63.973405212163925, 54.762771651148796, 23.954336419701576, 17.805238477885723, 31.441530659794807, 48.92446853220463, 56.07464365661144, 6.661468623206019, 0.19726648897631094, 0.0367953404202126, 0.09743728092871606, 0.026693257786973845, 0.08277049841126427, 0.04567262891214341, 0.05933970882324502, 0.11991535327979364, 0.0811765062098857, 0.05984567542327568, 0.028818954269809183, 0.056829739405657165, 0.0823453145858366, 0.4752743407152593, 35.08388601243496, 70.67509800195694, 55.42282283306122, 49.75678727030754, 24.353782385587692, 27.621736228466034, 39.47496458888054, 64.00784656405449, 66.49556547403336, 65.91276794672012, 50.76933033764362, 0.3096620680298656, 0.41972515115048736, 3.5690043261274695, 14.12026271224022, 1.1195636121556163, 4.349153526127338, 58.83111074566841, 49.66697908937931, 61.380800530314445, 57.455550357699394, 59.97204892337322, 60.32244332134724, 58.21511059999466, 48.93560953438282, 46.31056599318981, 45.928827077150345, 43.9916568249464, 45.59594213962555, 44.769608080387115, 44.05985936522484, 46.486291363835335, 42.74681322276592, 44.4171541929245, 44.614097625017166, 43.56452934443951, 42.42481850087643, 42.16797508299351, 39.253147691488266, 41.104427352547646, 37.652871161699295, 38.841169998049736, 39.92713652551174, 40.321460366249084, 40.80553159117699, 39.25888538360596, 39.35741409659386, 40.68757452070713, 39.68328841030598, 40.655508041381836, 40.998747423291206, 40.42748607695103, 39.862790778279305, 39.1644262522459, 41.890882551670074, 42.140703946352005, 40.24373173713684, 41.505549028515816, 39.17826130986214, 42.881633788347244, 40.61938717961311, 41.94900423288345, 44.59289476275444, 42.38729551434517, 41.96017183363438, 41.83338403701782, 40.62549725174904, 37.74913139641285, 40.30484765768051, 40.60383841395378, 41.071008145809174, 41.114675402641296, 44.95819956064224, 47.971738055348396, 51.427512019872665, 51.46037645637989, 50.41064478456974, 50.8661225438118, 50.99690392613411, 52.26866528391838, 50.80396927893162, 48.789252787828445, 51.36272929608822, 51.342438384890556, 52.52405717968941, 51.827030181884766, 52.04155147075653, 47.34145067632198, 42.940846011042595, 38.44116546213627, 39.79677692055702, 42.14033916592598, 41.89665824174881, 41.14530175924301, 40.94597205519676, 40.41632607579231, 42.223197519779205, 41.82244062423706, 47.55247235298157, 46.93461410701275, 45.80341100692749, 42.65014261007309, 40.8840087801218, 42.182045727968216, 42.981192246079445, 39.506913274526596, 40.75296141207218, 40.97530648112297, 40.77756509184837, 41.44910305738449, 40.98196752369404, 40.662701055407524, 41.17254249751568, 40.203286707401276, 39.89504724740982, 39.912777096033096, 43.11439409852028, 39.613322764635086, 42.420764118433, 42.66458563506603, 42.549843192100525, 43.43473210930824, 51.19749516248703, 57.137488424777985, 55.69915920495987, 60.05642719566822, 60.28753459453583, 56.941194757819176, 56.73790566623211, 54.91299659013748, 55.26998743414879, 52.81528875231743, 57.060698345303535, 58.15517261624336, 62.12755925953388, 59.05412457883358, 62.276993840932846, 57.622536197304726, 61.91754832863808, 61.63263201713562, 68.05099681019783, 63.885895907878876, 59.23553444445133, 39.66890998184681, 48.22167344391346, 4.8861901089549065, 0.01993440200749319, 5.251184273511171, 1.4920567930676043, 0.026728823359007947, 1.6317928698845208, 59.252918511629105, 73.34755539894104, 70.58239817619324, 69.99260142445564, 40.958606377243996, 20.41136473417282, 27.318444103002548, 40.47245666384697, 57.6638475805521, 63.99708554148674, 8.415615521371365, 0.23942852189065889, 0.07576302872621454, 0.03386885917279869, 0.03666804353997577, 0.07930749634397216, 0.05140433189808391, 0.14210041088517755, 0.2593804051866755, 0.1493925164686516, 0.17657763819443062, 0.2068524988135323, 0.20725594513351098, 0.3166706138290465, 0.7199385215062648, 45.665979981422424, 80.80980017781258, 63.90937104821205, 59.591723531484604, 35.72110801935196, 32.122621312737465, 46.39445409178734, 70.18050894141197, 72.91111081838608, 70.1420322060585, 57.06566467881203, 0.3458636754658073, 0.7024604093749076, 14.426082652062178, 37.152517810463905, 2.8940584184601903, 5.2916644513607025, 61.095933616161346, 48.458807319402695, 64.08552199602127, 57.6521822065115, 61.879694759845734, 61.73554949462414, 60.63544012606144, 52.53627352416515, 49.7829944640398, 48.60538065433502, 45.90482376515865, 47.290882989764214, 48.06777410209179, 46.987203285098076, 50.70947214961052, 46.15357741713524, 47.50951185822487, 46.78831435739994, 46.188440546393394, 44.94420491158962, 43.86330731213093, 41.386653408408165, 42.699935138225555, 39.42426010966301, 39.96950425207615, 41.70981466770172, 44.01738904416561, 43.164821192622185, 41.54564447700977, 42.89435550570488, 42.30801276862621, 40.82578830420971, 43.31338182091713, 43.64120922982693, 43.34495052695274, 42.60699972510338, 40.38562372326851, 43.87075111269951, 43.740585297346115, 40.98618909716606, 43.95253412425518, 41.20691165328026, 44.73439536988735, 43.59589286148548, 44.30135540664196, 45.535559579730034, 43.663837015628815, 44.655325412750244, 44.106935039162636, 42.9185526072979, 40.24816609919071, 42.54259318113327, 45.19786410033703, 44.145609363913536, 42.1461034566164, 46.703115329146385, 50.77418267726898, 53.35169456899166, 54.124022126197815, 53.38377244770527, 50.58256275951862, 52.68884673714638, 56.01341754198074, 52.65461437404156, 48.79223942756653, 55.21404683589935, 54.714012667536736, 53.57209414243698, 56.36218562722206, 55.16985520720482, 49.35289554297924, 44.66827131807804, 40.43065130710602, 42.36612305045128, 44.09004494547844, 43.12618866562843, 44.524855613708496, 43.077441081404686, 44.50930304825306, 45.29058672487736, 43.55587720870972, 50.086506977677345, 49.184739366173744, 47.9249207675457, 46.8441067636013, 43.54155957698822, 44.506092220544815, 44.93478141725063, 42.02002242207527, 44.903706684708595, 42.733745723962784, 43.85117456316948, 43.543432876467705, 44.14169557392597, 43.16272370517254, 43.6503629386425, 42.26655699312687, 41.997653022408485, 41.19438372552395, 45.42352259159088, 43.75214047729969, 44.854320734739304, 45.27420960366726, 43.04191678762436, 46.09271988272667, 51.36199973523617, 61.09641619026661, 57.6629014313221, 61.269622296094894, 63.21132950484753, 59.869268238544464, 59.045879021286964, 57.3174961656332, 57.22367540001869, 54.628217071294785, 58.256353586912155, 62.50884220004082, 64.5945730805397, 61.67568750679493, 65.68272069096565, 59.24688823521137, 63.57665330171585, 66.68889909982681, 70.28010919690132, 66.79845482110977, 62.502906918525696, 45.130683705210686, 53.42559300363064, 7.023152690380812, 0.39224279928021133, 7.247323086485267, 1.8894236767664552, 0.24769609153736383, 2.310305004939437, 65.19093587994576, 78.70713740587234, 75.53151860833168, 80.06803438067436, 68.7284928560257, 38.19962002336979, 31.99483796954155, 51.0976555198431, 68.2375667989254, 76.22954115271568, 11.297347638756037, 0.386673544999212, 0.2840637322515249, 0.21834968734765425, 0.1317569799721241, 0.1448872496257536, 0.12977029517060146], [0.04733532543468755, 0.007371944902843097, 0.04731825603812467, 0.029288071382325143, 0.0402982255036477, 0.026917536670225672, 0.03486678804620169, 0.3407151298597455, 31.2895730137825, 56.2740645557642, 49.20876927673817, 38.10150928795338, 20.665757283568382, 35.53732708096504, 42.44291692972183, 56.00225754082203, 64.16312143206596, 55.898150727152824, 45.793641731143, 0.271471623564139, 0.2430103046935983, 2.2184123983606696, 8.862443994730711, 0.37197210418526083, 7.225999105721712, 47.46813967823982, 37.50562526285648, 51.215403601527214, 49.03238654136658, 61.11275151371956, 56.456971541047096, 55.586077272892, 47.60653965175152, 47.58133180439472, 45.29285900294781, 45.218595787882805, 43.54273371398449, 43.892185762524605, 39.51745770871639, 40.709229558706284, 39.22014646232128, 40.705004185438156, 39.04562562704086, 39.4233101606369, 37.429066970944405, 38.706710413098335, 38.673754781484604, 38.00599001348019, 36.69433459639549, 37.6599957793951, 38.26979845762253, 36.74807891249657, 37.80314549803734, 38.2794651389122, 37.70126536488533, 38.93931873142719, 37.58999973535538, 38.07757057249546, 36.55059210956097, 35.43957732617855, 37.80713148415089, 38.465035781264305, 39.23932783305645, 38.85464407503605, 37.83984012901783, 39.55987483263016, 36.11833490431309, 40.6145728379488, 38.82281318306923, 42.20918387174606, 41.90192475914955, 41.59956358373165, 39.1753126680851, 39.14752095937729, 39.23135586082935, 37.48595751821995, 36.431943476200104, 37.27738671004772, 37.57256247103214, 38.03307496011257, 42.2208758443594, 45.493507236242294, 46.87673561275005, 51.211896389722824, 48.22605460882187, 48.85367453098297, 50.42305111885071, 53.05148787796497, 47.83766224980354, 44.87821385264397, 51.5579704195261, 50.83476282656193, 51.967611238360405, 49.86043430864811, 50.26507079601288, 46.837077140808105, 41.689383164048195, 37.187529131770134, 37.72237703204155, 39.35524821281433, 38.89668121933937, 39.585968032479286, 37.41204008460045, 38.181669786572456, 42.07201883196831, 40.814620703458786, 42.13400110602379, 43.2104529440403, 42.90159031748772, 41.24096542596817, 40.50022177398205, 39.078668653964996, 40.27878485620022, 39.76967677474022, 37.48091138899326, 38.863326609134674, 39.500704407691956, 41.541631892323494, 39.1483911126852, 40.19051179289818, 38.143869414925575, 37.78839468955994, 37.557754665613174, 37.8296984732151, 36.99493266642094, 37.84806288778782, 39.11492630839348, 38.36611568927765, 39.06511478126049, 38.86477433145046, 42.18135416507721, 48.45868952572346, 52.082878053188324, 51.14074520766735, 57.54357263445854, 57.370742708444595, 55.75890339910984, 55.40169596672058, 55.47407828271389, 55.047098994255066, 57.66635164618492, 54.85956385731697, 56.99835509061813, 58.08182135224342, 54.34477888047695, 54.77431543171406, 57.58815564215183, 59.03639853000641, 63.042181581258774, 62.390296161174774, 59.09300409257412, 42.3591960221529, 49.34866636991501, 3.0004066368564963, 0.06834676925791427, 4.970211675390601, 0.4986166663002223, 0.1389436560566537, 1.2529400177299976, 54.661104306578636, 64.95193630456924, 68.51079493761063, 60.69785177707672, 84.60703521966934, 52.03671433031559, 13.753312602639198, 33.47550831735134, 47.939006611704826, 56.1161944270134, 5.983677143231034, 0.19087046734057367, 0.04993972943339031, 0.07265031294082291, 0.043861762605956756, 0.037956500964355655, 0.015471306778636063, 0.08157146978192031, 0.032542711778660305, 0.05405588453868404, 0.03503239087876864, 0.061609790136571974, 0.026567818131297827, 0.08744927195948549, 0.28197574429214, 37.69795574247837, 66.64482906460762, 57.966847121715546, 46.950166672468185, 23.53799846023321, 31.07846774160862, 46.618151888251305, 61.975267231464386, 67.47519090771675, 62.70685717463493, 51.75001971423626, 0.29346377472393215, 0.13203926326241344, 1.3371453993022442, 8.162998426705599, 0.7635494938585907, 8.966538459062576, 48.69734711945057, 41.65469862520695, 52.15529076755047, 52.28973515331745, 63.1301012635231, 57.97475829720497, 58.220217525959015, 49.56091918051243, 48.718386590480804, 46.78878553211689, 48.072136268019676, 44.948665872216225, 47.14462123811245, 42.48330116271973, 44.17212054133415, 41.61703884601593, 43.65944445133209, 40.349913239479065, 41.39380842447281, 38.694482669234276, 41.4034067094326, 40.311204716563225, 40.76486997306347, 38.89362998306751, 40.062105283141136, 39.73393589258194, 39.419616758823395, 40.25597847998142, 40.433949530124664, 39.48155723512173, 40.790207013487816, 40.85966348648071, 38.1290578097105, 38.30568753182888, 37.37990140914917, 39.959081411361694, 39.971533343195915, 40.22151052951813, 41.42243608832359, 39.570084884762764, 40.269247367978096, 38.12038667500019, 41.02071784436703, 39.57126662135124, 43.45549799501896, 43.59311141073704, 43.373053818941116, 40.27515985071659, 40.9777307510376, 40.712995156645775, 38.87222193181515, 39.905401691794395, 39.038303419947624, 40.205437391996384, 39.82032425701618, 44.65608537197113, 46.257144659757614, 48.639768809080124, 52.12366126477718, 52.24842756986618, 51.598894223570824, 50.61994895339012, 54.59854446351528, 50.442384481430054, 47.00550690293312, 52.52134032547474, 51.383829563856125, 52.15537056326866, 51.047897189855576, 52.77149610221386, 48.469621539115906, 43.08301918208599, 39.92396369576454, 40.44261306524277, 40.942871421575546, 41.05191797018051, 42.41419427096844, 40.23622713983059, 40.012042969465256, 42.62450538575649, 42.849502712488174, 43.089608028531075, 44.929621294140816, 44.9471003562212, 42.6218531280756, 41.61755941808224, 40.12863591313362, 41.92426756024361, 40.83034805953503, 40.112809762358665, 40.6947485357523, 40.93760870397091, 42.85426765680313, 41.07084855437279, 42.174130752682686, 41.617772206664085, 39.408057779073715, 40.14612637460232, 39.850160256028175, 38.799459636211395, 39.931358098983765, 40.36193959414959, 40.5343097448349, 42.42678299546242, 40.360529869794846, 43.10174457728863, 50.620431527495384, 54.84434187412262, 53.47770340740681, 59.02695223689079, 57.928472980856895, 58.51831912994385, 57.164679765701294, 55.8982153236866, 56.312195509672165, 59.85248073935509, 57.086088582873344, 58.576475009322166, 59.659519493579865, 58.234402164816856, 55.90226210653782, 61.53870865702629, 60.0267393887043, 65.64483672380447, 64.09975603222847, 64.71764087677002, 44.57809455692768, 52.17229105532169, 2.961396505124867, 0.08718344950466417, 6.265702284872532, 4.082458661869168, 0.09582886137650348, 1.147061192896217, 59.42349515855312, 70.8829240500927, 73.12083676457405, 66.90673381090164, 71.87235295772552, 41.83054938912392, 17.02751711010933, 41.7255762219429, 60.22257708013058, 66.02230846881866, 8.443548772484064, 0.1503552304347977, 0.0333268019312527, 0.08587928823544644, 0.04617128906829748, 0.06611786229768768, 0.041489643408567645, 0.11827780443127267, 0.14746373402886093, 0.16684972972143441, 0.11159106870763935, 0.24316952505614609, 0.1417863043025136, 0.34513271937612444, 0.5158350267447531, 50.43991081416607, 77.81638160347939, 65.75313851237297, 54.97333735227585, 31.84694230556488, 47.750084549188614, 57.57566191256046, 65.99200889468193, 73.47411900758743, 68.2183626294136, 56.187273412942886, 0.45385824458207935, 0.6094377196859568, 3.901979746297002, 28.84216234087944, 1.8380748946219683, 9.186049830168486, 54.35050517320633, 45.642022266983986, 56.9337547570467, 54.57200288772583, 66.43513351678848, 61.19643062353134, 59.8465758562088, 52.080658972263336, 52.00535461306572, 50.94906449317932, 49.32657815515995, 48.29940587282181, 51.11176036298275, 44.79532890021801, 46.048152074217796, 44.039568454027176, 45.61643823981285, 42.88506880402565, 45.038215667009354, 40.786536410450935, 44.62557300925255, 43.71837168931961, 43.81992883980274, 42.16121144592762, 42.72016525268555, 43.69464196264744, 39.96310539543629, 44.19939927756786, 42.87236228585243, 42.77853772044182, 43.68796192109585, 43.278750479221344, 41.12692594528198, 40.47748379409313, 39.428405687212944, 42.20277741551399, 43.25632408261299, 43.29231575131416, 43.25603909790516, 42.039781361818314, 42.96364478766918, 40.56332878768444, 44.2374162375927, 43.60078699886799, 46.080488339066505, 43.304228112101555, 46.26590698957443, 43.02056573331356, 44.263517037034035, 43.99610638618469, 41.759314611554146, 40.64779445528984, 41.17768742144108, 40.62346436083317, 42.361240312457085, 48.07161569595337, 50.37757135927677, 52.78275869786739, 56.00895658135414, 54.45195592939854, 52.60493203997612, 56.6417670249939, 58.195461854338646, 52.92789191007614, 47.57843255996704, 54.01734285056591, 54.673966616392136, 54.57152411341667, 53.74140165746212, 56.03616692125797, 51.84776946902275, 46.10565438866615, 41.69713854789734, 41.39670766890049, 43.235394805669785, 44.19564127922058, 43.668810948729515, 42.76738911867142, 40.94263583421707, 46.68208725750446, 45.186035335063934, 45.177307203412056, 47.21756212413311, 46.72016121447086, 44.13721941411495, 42.95966640114784, 43.308411687612534, 43.78417655825615, 43.093784004449844, 42.66371928155422, 42.79640056192875, 43.73650811612606, 44.70256827771664, 42.647171169519424, 47.304159477353096, 42.540659084916115, 41.95214666426182, 43.30084629356861, 41.58100537955761, 40.93251697719097, 42.63264074921608, 42.79369130730629, 43.507118225097656, 44.20830599963665, 43.319697082042694, 44.715498983860016, 51.974283680319786, 56.95318691432476, 55.70389375090599, 61.05845242738724, 60.39454445242882, 59.259058982133865, 58.69205720722675, 58.62983174622059, 57.985675111413, 62.21983350813389, 58.59934978187084, 61.79236404597759, 63.98160517215729, 60.38424700498581, 59.76233817636967, 63.569042310118675, 63.02519649267197, 68.44375893473625, 68.37784007191658, 67.57270887494087, 48.64665023982525, 57.27718412876129, 5.441700350493193, 0.32074821065180004, 10.300474930554628, 3.3398597594350576, 0.32140147872269154, 1.8243778171017766, 64.02888983488083, 77.71367311477661, 79.94871318340302, 74.68806266784668, 99.73303556442261, 59.05193589627743, 25.400479920208454, 52.22630515694618, 67.86822661757469, 79.42016154527664, 13.052293919026852, 0.7027014589402825, 0.16794300230685622, 0.21430397318908945, 0.14306744415080175, 0.3661728138104081, 0.13076665811240673], [0.06347712274873629, 0.1131362201704178, 0.05317162300343625, 0.059407329608802684, 0.06794590561185032, 0.02997421659529209, 0.12054433827870525, 0.12473804410547018, 28.408974185585976, 55.77742740511894, 45.524593368172646, 34.24351170659065, 19.618273191154003, 25.264544114470482, 32.472970113158226, 59.69983533024788, 62.12924636900425, 58.08524116873741, 45.52448317408562, 0.43503794353455305, 0.02214985383034218, 1.2304074643179774, 6.465215804055333, 0.29007192235440016, 14.294201228767633, 50.244118720293045, 38.95837090909481, 50.378517508506775, 55.22725112736225, 60.58185160160065, 54.32219289243221, 56.029042303562164, 46.0682225972414, 46.29901461303234, 42.83244922757149, 44.09648559987545, 41.96090139448643, 43.12447875738144, 39.56332504749298, 39.685963466763496, 38.90337646007538, 38.638948649168015, 38.4922993183136, 38.55207771062851, 37.248439863324165, 39.71427574753761, 37.91554346680641, 38.685005977749825, 37.25199267268181, 38.30376863479614, 36.919624507427216, 37.4198866635561, 37.084345668554306, 38.58401879668236, 38.41405391693115, 36.53511933982372, 37.664954513311386, 36.983879059553146, 38.97989295423031, 37.56038412451744, 36.35541558265686, 37.68540121614933, 37.86675788462162, 38.18373307585716, 37.152825593948364, 39.111449494957924, 37.82520331442356, 39.60489481687546, 37.76854835450649, 42.282280549407005, 46.79117940366268, 45.13631880283356, 41.50837607681751, 42.25968696177006, 37.36880600452423, 38.341595605015755, 37.27995537221432, 37.004424557089806, 38.35050232708454, 37.36202336847782, 38.860290572047234, 42.755723744630814, 45.738320499658585, 46.88359424471855, 46.29757069051266, 50.70322148501873, 51.29480414092541, 51.03170245885849, 48.31340052187443, 46.93970963358879, 47.144917622208595, 51.46197997033596, 50.235945358872414, 46.21624745428562, 47.68325373530388, 43.17314654588699, 41.45446076989174, 39.95589338243008, 39.764056876301765, 37.21120186150074, 39.760925844311714, 40.214484706521034, 36.39811389148235, 39.066148325800896, 39.37012821435928, 40.80336190760136, 42.09659591317177, 40.71505464613438, 41.691245064139366, 41.31114386022091, 39.634510427713394, 38.1381431221962, 38.59217695891857, 39.8579840362072, 38.856304585933685, 38.49894896149635, 40.1036636531353, 39.771903455257416, 39.89996038377285, 38.4221550822258, 39.632572531700134, 39.581465274095535, 38.29571686685085, 40.62139347195625, 39.161667600274086, 37.47096732258797, 41.346975937485695, 38.98876927793026, 39.56941232085228, 38.83950188755989, 39.61354695260525, 41.00399874150753, 44.88971583545208, 49.0349780023098, 50.32272890210152, 52.81229451298714, 54.14506159722805, 54.014310613274574, 56.553645953536034, 57.859442085027695, 58.33496376872063, 52.717622593045235, 54.45930473506451, 48.7485683709383, 48.436468318104744, 45.11633187532425, 48.61621767282486, 47.96251215040684, 60.06511352956295, 58.86661984026432, 65.2688392996788, 52.14029677212238, 63.53121913969517, 3.688029614277184, 0.04851434947340749, 6.200830265879631, 1.8240998382680118, 0.03431234807067085, 1.4126174245029688, 49.725370556116104, 65.71274667978287, 66.77488088607788, 61.388723105192184, 60.69178730249405, 60.757751762866974, 25.38249548524618, 31.142372712492943, 41.084953397512436, 49.90320481359959, 4.908247925341129, 0.555685447761789, 0.02046907859039493, 0.05127378441102337, 0.07696562708588317, 0.05023062905820552, 0.027305062067171093, 0.050933131205965765, 0.032309213565895334, 0.017026730492943898, 0.03814470961515326, 0.07367820231593214, 0.04172376873611938, 0.04840321285882965, 0.17499417706858367, 38.55162553489208, 66.14844650030136, 52.90292724967003, 42.147186398506165, 30.381566137075424, 33.56689341366291, 37.77379207313061, 65.03221079707146, 67.07856059074402, 63.03717724978924, 48.69976758956909, 0.5138089042156935, 0.12187456377432682, 0.9742081712465733, 5.631905319169164, 0.44583212526049465, 16.24284401535988, 51.815718188881874, 43.15569028258324, 52.98168562352657, 58.54293420910835, 62.585715875029564, 55.644590333104134, 58.76124769449234, 46.484353467822075, 47.87577420473099, 44.30278792977333, 45.9320493042469, 44.21839065849781, 45.54559484124184, 42.879019528627396, 43.58296975493431, 40.73986351490021, 40.58148421347141, 40.610959231853485, 40.41321784257889, 38.880562484264374, 42.00587958097458, 39.524947106838226, 41.459799483418465, 40.12400396168232, 40.12533389031887, 38.59222635626793, 41.31375811994076, 40.24976581335068, 41.915193647146225, 39.240258783102036, 38.722281977534294, 39.623422622680664, 39.861289858818054, 40.5966529995203, 40.82159332931042, 38.138021528720856, 39.56366702914238, 40.06133012473583, 39.51929681003094, 37.938175052404404, 40.29198154807091, 40.0771676748991, 40.938885435462, 39.836465790867805, 44.69532206654549, 48.98453190922737, 47.49056987464428, 42.02075578272343, 42.689508497714996, 39.19832423329353, 39.243465811014175, 38.71205672621727, 37.96976275742054, 41.279438361525536, 39.36357356607914, 40.84019333124161, 44.64415021240711, 46.780034601688385, 47.94642001390457, 48.06054688990116, 51.65622174739838, 53.403576985001564, 53.25566612184048, 50.26036664843559, 47.37000994384289, 48.942756950855255, 52.9074490070343, 50.64750887453556, 50.333258137106895, 50.07747486233711, 46.31057359278202, 41.267810985445976, 40.77336631715298, 41.06953762471676, 38.30156855285168, 41.79320499300957, 41.96006163954735, 39.07744511961937, 40.05443349480629, 41.72343313694, 42.54451967775822, 44.099662229418755, 43.62296640872955, 42.43964910507202, 44.037364572286606, 41.87271572649479, 39.87468034029007, 40.76818339526653, 42.25808724761009, 41.016701459884644, 42.098959386348724, 41.319560408592224, 42.14525990188122, 41.62499941885471, 40.436616986989975, 41.28638058900833, 42.28076823055744, 40.62634460628033, 43.545370772480965, 42.14117892086506, 40.206767320632935, 42.74086274206638, 41.75098545849323, 42.283747270703316, 40.6238329410553, 41.005032286047935, 43.23788367211819, 46.547570675611496, 50.377575159072876, 53.04504342377186, 56.171793043613434, 55.58383919298649, 56.20692975819111, 57.45637111365795, 59.49917949736118, 60.421409010887146, 55.415968000888824, 57.28035695850849, 53.02300080657005, 51.978596448898315, 47.910861521959305, 49.44360427558422, 49.65215228497982, 60.09752579033375, 62.77320921421051, 68.20260867476463, 56.9930961728096, 64.46648195385933, 4.602092653512955, 0.18366847332799807, 6.133939130231738, 7.221706286072731, 0.054179184953682125, 1.1715502850711346, 55.456185042858124, 71.9345024228096, 72.84285128116608, 64.80272591114044, 74.33780506253242, 63.44536654651165, 23.996094278991222, 35.84490157663822, 49.7613850235939, 62.32323355972767, 8.042881172150373, 0.46510041633155197, 0.03320469266327564, 0.08676381694385782, 0.03865040162054356, 0.07567695443867706, 0.04007036019174848, 0.10821634510648437, 0.1812821123166941, 0.1875186909455806, 0.12500312441261485, 0.17636081232922152, 0.19394337432458997, 0.2286519735935144, 0.38293736579362303, 47.95702524483204, 75.01280844211578, 60.91012358665466, 48.0611814558506, 31.723232343792915, 33.30143205821514, 46.04700453579426, 70.98769962787628, 72.39271983504295, 67.44863033294678, 54.28443431854248, 0.7859157468192279, 0.2592006867052987, 4.346574414521456, 14.708790332078934, 0.43095577508211136, 18.340415060520172, 57.79173731803894, 45.5826922506094, 58.83674204349518, 60.27209982275963, 66.25482559204102, 58.65825042128563, 60.40406294167042, 48.714544996619225, 49.06067222356796, 47.325331941246986, 48.11577692627907, 46.046290174126625, 48.8944311439991, 43.901138082146645, 44.5122516900301, 44.92416098713875, 42.76905342936516, 43.81578706204891, 43.16122278571129, 42.84588150680065, 44.40914802253246, 42.232981994748116, 44.57651384174824, 42.95035310089588, 42.62531854212284, 40.664828941226006, 43.260838240385056, 42.68679544329643, 43.71040731668472, 42.998222932219505, 41.670243591070175, 42.29519225656986, 42.53428302705288, 42.956402376294136, 42.28660471737385, 40.996646136045456, 40.78277461230755, 40.54908715188503, 41.27897098660469, 40.8309256285429, 43.53326462209225, 41.37754149734974, 44.65997636318207, 41.50837987661362, 46.388963386416435, 50.367068722844124, 49.1350532323122, 44.42763403058052, 45.72510100901127, 41.31091967225075, 42.47130520641804, 40.84286838769913, 40.887842774391174, 43.88932831585407, 41.67835995554924, 43.3094148337841, 47.00612246990204, 49.719214886426926, 51.600429341197014, 50.46687796711922, 54.74907338619232, 56.640881672501564, 58.13988983631134, 51.92582868039608, 46.90546207129955, 49.11905989050865, 54.4887987524271, 53.11518386006355, 51.19845651090145, 51.83496795594692, 48.04130472242832, 44.57038477063179, 44.26665186882019, 43.57074201107025, 40.91184988617897, 43.3775831758976, 44.74928677082062, 40.213017985224724, 41.130455955863, 43.35737586021423, 44.92529332637787, 46.99225701391697, 44.91444490849972, 46.70178920030594, 44.65308353304863, 44.21128123998642, 40.45596554875374, 42.82243296504021, 44.38914209604263, 42.71779417991638, 43.935963213443756, 44.55637112259865, 44.71923038363457, 44.52832482755184, 42.682193890213966, 44.577395394444466, 46.08798533678055, 43.351622968912125, 46.67797967791557, 44.71870981156826, 42.09314189851284, 47.31096491217613, 45.12714609503746, 43.96792709827423, 43.191157579422, 42.559832856059074, 45.03456026315689, 49.0337772667408, 53.2522539049387, 56.900460943579674, 58.111140578985214, 57.93395608663559, 58.71784642338753, 61.34339913725853, 62.45005555450916, 63.20233538746834, 58.44433329999447, 60.71345753967762, 55.21570734679699, 54.129167050123215, 48.49641390144825, 53.34126032888889, 52.726533114910126, 64.96065303683281, 65.20858213305473, 73.83181661367416, 59.694591611623764, 68.94457966089249, 5.548583390191197, 0.20853672875091434, 13.811378236860037, 6.455670716241002, 0.14001938427099958, 1.4082956314086914, 58.874838799238205, 78.94603058695793, 79.60653394460678, 73.31722542643547, 75.67732438445091, 71.99091419577599, 36.113075986504555, 52.54168063402176, 57.899556532502174, 75.35952463746071, 12.306677978485823, 0.6711393431760371, 0.19795772532233968, 0.21061874984297901, 0.19257798587204888, 0.11769737073336728, 0.10073873228975572], [0.07850850015529431, 0.008960419236245798, 0.06716895120916888, 0.03765656569157727, 0.0497746275505051, 0.1085648947628215, 0.21108919725520536, 0.101877179404255, 30.439361035823822, 59.69767324626446, 43.01625296473503, 30.712921656668186, 11.751593314111233, 35.05616270005703, 42.60837525129318, 55.229895785450935, 64.12735775113106, 55.739064663648605, 52.56737105548382, 0.8410759025719017, 0.11019543773727491, 0.6804186233785003, 2.7161821257323027, 0.28123356692958623, 21.564217172563076, 54.490835443139076, 43.87724116444588, 61.512839645147324, 55.51921606063843, 57.9584913700819, 53.17388691008091, 49.32229198515415, 39.97372582554817, 41.47778771817684, 41.209978088736534, 41.35471612215042, 38.950828313827515, 41.416204422712326, 38.66395890712738, 38.631763234734535, 38.30506056547165, 38.96733082830906, 39.19259414076805, 40.02279259264469, 39.06760364770889, 39.37895514070988, 38.50338712334633, 39.31707166135311, 39.11098591983318, 39.59050878882408, 38.29745717346668, 37.89660528302193, 38.84960174560547, 38.96360702812672, 36.739031597971916, 37.2326935082674, 36.01626858115196, 38.20156931877136, 37.479361072182655, 36.447363048791885, 35.90974509716034, 37.53366395831108, 35.57850167155266, 35.972795113921165, 36.94301225244999, 37.485113963484764, 37.817299738526344, 40.747227519750595, 36.74544185400009, 43.72997246682644, 49.77631442248821, 44.73459675908089, 45.40696308016777, 40.91711640357971, 39.05145451426506, 36.69583931565285, 36.20697274804115, 38.40110041201115, 37.22575508058071, 38.399280309677124, 39.29281756281853, 41.529309153556824, 44.66125689446926, 45.54217502474785, 47.05995798110962, 47.505366280674934, 47.92921453714371, 50.31624265015125, 46.69299267232418, 45.8120821416378, 44.37542863190174, 45.549539029598236, 46.15472875535488, 44.42371644079685, 44.43165801465511, 42.309274300932884, 36.96832649409771, 37.69992023706436, 39.666565507650375, 39.36119869351387, 38.38462449610233, 38.125174418091774, 38.45493212342262, 39.65690262615681, 39.112635031342506, 38.28048348426819, 40.59942685067654, 42.085428312420845, 42.2798752784729, 40.72149910032749, 38.76802772283554, 39.30007517337799, 38.26328180730343, 39.09268230199814, 39.271428510546684, 38.039971590042114, 36.95962876081467, 39.822771325707436, 38.53746749460697, 39.518935829401016, 40.47040097415447, 39.05417896807194, 37.87578999996185, 38.48772436380386, 37.807534262537956, 37.6345257461071, 37.88905888795853, 38.05627651512623, 38.49073380231857, 39.068952575325966, 39.723307862877846, 39.552275240421295, 41.48931249976158, 40.96387289464474, 44.978688061237335, 45.480352342128754, 51.052415147423744, 49.723991230130196, 52.488973662257195, 51.04277886450291, 53.46281960606575, 47.611202001571655, 46.41892857849598, 40.174225866794586, 46.24082453548908, 43.94374519586563, 52.471574395895004, 48.973592296242714, 57.757843136787415, 56.3668479770422, 63.41626010835171, 57.47644163668156, 71.22764155268669, 4.018970243632793, 0.11714714986737818, 5.457497527822852, 8.744731061160564, 0.17301532934652641, 0.7596427691169083, 51.10890291631222, 62.28613995015621, 62.75800622999668, 63.603704050183296, 32.75531016290188, 20.508405826985836, 30.10118868201971, 31.741471365094185, 48.30234691500664, 58.791247084736824, 8.433356769382954, 0.31103919725865126, 0.07062177843181416, 0.11398673625080846, 0.06632196775171906, 0.08325833434355445, 0.054566675098612905, 0.04773637090693228, 0.04072784366144333, 0.0654143730935175, 0.03606976861192379, 0.062060307172941975, 0.07950756451464258, 0.09623675316106528, 0.1539187564048916, 39.941590949893, 67.54858776926994, 48.503485321998596, 39.70546782016754, 17.194685339927673, 20.267675444483757, 42.38768309354782, 62.237152978777885, 68.93972352147102, 61.15152843296528, 55.80613486468792, 0.8495374547783285, 0.09544280357658863, 2.2312321979552507, 3.7286681961268187, 0.24338954215636477, 22.815514728426933, 56.62434495985508, 47.53066912293434, 65.02625271677971, 58.44683736562729, 59.54937480390072, 55.783662870526314, 50.12115731835365, 42.3389583081007, 44.282048642635345, 42.41067185997963, 42.105673626065254, 41.50916263461113, 43.34121912717819, 40.70557415485382, 40.51151856780052, 40.68054489791393, 42.67048291862011, 41.44793651998043, 42.05621547996998, 40.07794663310051, 41.65605515241623, 38.93345184624195, 39.71258103847504, 39.66633751988411, 40.78424893319607, 40.91245025396347, 40.11391930282116, 41.40145741403103, 41.781034246087074, 39.38893720507622, 41.51184909045696, 37.65071287751198, 40.1118940114975, 40.11430308222771, 39.81832556426525, 39.135958179831505, 39.398299902677536, 38.55094537138939, 37.960650846362114, 38.9072522521019, 39.76575918495655, 38.76016974449158, 40.37426993250847, 40.32985031604767, 45.176345854997635, 51.23566031455994, 48.94672013819218, 46.048425659537315, 42.92536184191704, 41.97709612548351, 38.38886506855488, 40.31210906803608, 39.49184328317642, 39.44513238966465, 39.32190500199795, 41.872377544641495, 43.374562337994576, 45.541555657982826, 47.29439400136471, 47.655397430062294, 49.36970964074135, 47.7848868817091, 52.195830792188644, 48.77632588148117, 50.582285374403, 44.654770642519, 49.22045364975929, 48.805751502513885, 45.675532668828964, 46.87596045434475, 42.865127474069595, 40.08804649114609, 39.24251206219196, 40.135266557335854, 41.74988351762295, 40.15392355620861, 39.44795563817024, 40.07344767451286, 41.80296666920185, 40.0456939637661, 40.42748987674713, 41.57493330538273, 45.270766988396645, 43.834295868873596, 42.57330693304539, 39.04606260359287, 40.73796361684799, 40.506951212882996, 41.23482495546341, 41.16917587816715, 39.67798389494419, 41.33447840809822, 42.73036390542984, 40.67478820681572, 41.04519233107567, 42.12001025676727, 40.231678783893585, 40.137557834386826, 41.7334645986557, 38.75777967274189, 40.2936876565218, 39.65271905064583, 41.40825144946575, 41.088460609316826, 41.44069790840149, 41.69597961008549, 41.3968900591135, 42.59722284972668, 42.62738183140755, 46.07646055519581, 49.20565724372864, 51.306583508849144, 51.81358650326729, 53.94716441631317, 54.66009736061096, 55.39546050131321, 50.192281901836395, 47.96501241624355, 42.47550778090954, 46.762300953269005, 45.389294028282166, 53.773973509669304, 50.73309928178787, 58.10370817780495, 58.53665314614773, 64.6049465239048, 61.892773658037186, 71.83642968535423, 5.4820632096379995, 0.24000528937904164, 4.597583720460534, 4.105328684672713, 0.3071937442291528, 1.4069148804992437, 53.95831301808357, 70.28194829821587, 70.38354724645615, 68.44981580972672, 45.900305807590485, 35.85006169974804, 32.62883014976978, 42.25471682846546, 55.3360240906477, 72.02141895890236, 10.077428799122572, 0.28816665115300566, 0.05993615435727406, 0.057016727223526686, 0.09111995663261041, 0.10745972555014305, 0.0497325997275766, 0.09987286117393523, 0.1303254216327332, 0.19566328672226518, 0.1320483471499756, 0.2553063409868628, 0.20870348933385685, 0.28888270491734147, 0.5444031406659633, 52.418229058384895, 79.42482009530067, 57.38773159682751, 43.61454986035824, 18.239076398313046, 45.34969635307789, 58.54656681418419, 67.42490440607071, 74.34641540050507, 65.14916852116585, 63.42150762677193, 1.1732651805505157, 0.27042955916840583, 3.4958703629672527, 10.349315609782934, 0.42925447574816644, 26.468346118927002, 62.15673789381981, 54.084618240594864, 68.49257871508598, 61.43073745071888, 62.368139550089836, 58.47597800195217, 55.38449048995972, 44.19331580400467, 46.675604805350304, 46.60568855702877, 45.34621573984623, 45.112847462296486, 45.67931346595287, 43.010990247130394, 42.05121494829655, 43.77511024475098, 43.97819794714451, 43.43518428504467, 45.32301418483257, 42.63464704155922, 43.83434146642685, 42.45149306952953, 42.96607285737991, 42.55307301878929, 42.81895235180855, 44.17890317738056, 42.43590630590916, 43.83429206907749, 45.03682494163513, 42.6284571737051, 43.400552943348885, 41.101699098944664, 43.83252136409283, 42.817827612161636, 40.92839039862156, 39.878989309072495, 41.808054596185684, 40.71458347141743, 39.20286878943443, 39.35397908091545, 42.2111027687788, 40.94547048211098, 44.53302897512913, 41.50818608701229, 47.33937218785286, 52.97297269105911, 51.52004845440388, 48.08247551321983, 46.93618342280388, 44.31307777762413, 40.27567282319069, 41.513900980353355, 42.65648066997528, 40.38269028067589, 43.343947380781174, 44.97256278991699, 46.10909320414066, 49.27812695503235, 50.1624459028244, 48.73863570392132, 52.01882869005203, 50.49836687743664, 56.27931207418442, 50.00600829720497, 49.46303643286228, 48.43901418149471, 49.73168581724167, 50.9523057192564, 47.55533739924431, 48.6616176366806, 46.17707155644894, 41.50962620973587, 40.526991337537766, 44.60220046341419, 44.27359029650688, 42.537691444158554, 41.46908238530159, 43.34082394838333, 43.925072997808456, 41.70409977436066, 40.87656117975712, 42.97529116272926, 46.56139053404331, 47.18658998608589, 44.718018248677254, 42.20753476023674, 41.62443704903126, 43.05408373475075, 43.55612799525261, 42.42755815386772, 40.61908699572086, 43.20138283073902, 46.79487660527229, 43.22703905403614, 43.1679218262434, 44.175851941108704, 42.75541216135025, 42.51529164612293, 44.656526148319244, 42.48845748603344, 43.086864575743675, 42.71316222846508, 43.223003670573235, 43.81715878844261, 43.960452899336815, 43.821604549884796, 44.715662375092506, 44.64009203016758, 45.30562251806259, 48.63674037158489, 51.081141605973244, 55.10924465954304, 54.02192160487175, 56.21790736913681, 56.169220581650734, 58.05631712079048, 52.77776576578617, 51.80227071046829, 43.48150759935379, 49.72763143479824, 48.08507837355137, 58.786831721663475, 53.55284437537193, 63.209965378046036, 60.54072640836239, 69.25842002034187, 64.32755380868912, 75.06394609808922, 5.635122796520591, 0.19188706122804433, 13.63861195743084, 15.779467429965734, 0.4400258290115744, 1.084697989281267, 60.272886380553246, 74.94417652487755, 77.27124005556107, 76.14612802863121, 47.34663739800453, 35.51450930535793, 43.578900173306465, 54.10772480070591, 64.6996222436428, 82.06969857215881, 16.31487675011158, 0.57836530264467, 0.2181054762331769, 0.22919105482287705, 0.18784064945066348, 0.2604525117203593, 0.1779061122215353], [0.13513354409951717, 0.08189898697310127, 0.06111187583883293, 0.03058006514038425, 0.03334959699714091, 0.020935978536726907, 0.09991040642489679, 0.46118576545268297, 41.56628496944904, 52.72087901830673, 46.952910125255585, 18.382875882089138, 44.23658788204193, 87.00804278254509, 46.36962242424488, 56.444588005542755, 60.20837724208832, 57.315098494291306, 57.34247222542763, 2.4106953805312514, 0.2325425937306136, 1.088299483526498, 2.341522704809904, 0.1447971974266693, 23.06545201689005, 65.03093406558037, 48.76078471541405, 58.237324208021164, 55.3933972120285, 57.828922122716904, 46.82244412600994, 43.92517939209938, 44.55085001885891, 47.87400729954243, 43.38134877383709, 42.07085609436035, 37.44383677840233, 41.27558156847954, 38.87661449611187, 41.20691545307636, 37.89581872522831, 39.424761682748795, 37.24688194692135, 37.95585170388222, 37.05927461385727, 39.52045954763889, 37.749933153390884, 37.5893347710371, 37.82469794154167, 39.022568464279175, 37.64530196785927, 37.23098360002041, 35.75358487665653, 38.4766061604023, 35.80153450369835, 38.21024805307388, 37.139028534293175, 38.617741987109184, 36.57178737223148, 37.45480298995972, 36.54975235462189, 39.19988214969635, 37.83061422407627, 38.339665308594704, 36.341614723205566, 37.59579062461853, 35.141088142991066, 39.602972120046616, 37.943399772048, 41.162685826420784, 48.80680784583092, 49.83523786067963, 42.91644372045994, 40.553042739629745, 38.63163024187088, 38.60041871666908, 36.03640750050545, 37.649971917271614, 36.27797953784466, 37.48227171599865, 39.0878489613533, 41.765135899186134, 44.01946373283863, 45.12221775949001, 44.82016056776047, 46.909725442528725, 48.17460536956787, 47.1540941298008, 47.1298286318779, 44.351763501763344, 44.150134921073914, 45.08217550814152, 45.71742162108421, 44.20687347650528, 41.58413641154766, 41.148744374513626, 38.13838630914688, 38.05895157158375, 38.2357332855463, 38.2955876737833, 38.70450273156166, 41.04927331209183, 40.50944767892361, 38.57109948992729, 37.348948270082474, 39.72021482884884, 39.982689544558525, 43.42601537704468, 42.85659313201904, 41.77765242755413, 40.22391580045223, 38.243066892027855, 38.23767498135567, 39.3596787750721, 38.58742721378803, 37.2942616045475, 38.76186825335026, 40.25185950100422, 39.05341900885105, 39.43305283784866, 39.04609680175781, 40.159543454647064, 37.2959753125906, 37.991368398070335, 37.61855900287628, 39.71301041543484, 39.653513208031654, 37.72220604121685, 38.800060003995895, 40.33364251255989, 39.94098678231239, 40.78112930059433, 39.09684307873249, 40.123897567391396, 40.306101590394974, 41.788177862763405, 43.290738835930824, 44.924373775720596, 45.55287525057793, 44.60592806339264, 44.4535980373621, 42.09237813949585, 41.42727702856064, 42.28630073368549, 50.09333901107311, 55.81009805202484, 56.26633197069168, 58.62917058169842, 60.71007192134857, 57.39593915641308, 64.14243534207344, 61.17972671985626, 68.71629551053047, 5.213850326836109, 0.4340766544919461, 2.0734233409166336, 10.221416372805834, 0.4267959186108783, 0.9456851799041033, 48.729964569211006, 65.50837084650993, 63.03177393972874, 61.48301884531975, 50.505225509405136, 28.505867086350918, 17.056547552347183, 29.477647840976715, 51.541802287101746, 55.29620222747326, 5.400720974430442, 0.21698982047382742, 0.02518118384614354, 0.062421610637102276, 0.11086288825026713, 0.11359752432326786, 0.05365729928598739, 0.09291944952565245, 0.007447447760569048, 0.02877884304325562, 0.05042049269832205, 0.013026315173192415, 0.010103304393851431, 0.11729279634892009, 0.5341153114568442, 48.98629881441593, 62.915063202381134, 51.8898294121027, 29.379837289452553, 29.253074191510677, 68.86156171560287, 50.67153878509998, 61.526028737425804, 65.10743156075478, 60.285646095871925, 62.30874113738537, 2.5164441810920835, 0.2550212969072163, 1.3436800986528397, 2.9080409556627274, 0.24534416617825627, 23.59101701527834, 65.52607789635658, 53.22852037847042, 61.07712462544441, 57.90342092514038, 61.23418539762497, 50.71376211941242, 46.20435029268265, 47.617445066571236, 50.48330448567867, 44.79453854262829, 42.65978269279003, 40.16466177999973, 43.777519315481186, 41.034659296274185, 42.9652900993824, 40.17597757279873, 40.64376287162304, 38.060406893491745, 39.9113217741251, 39.11216765642166, 40.767001658678055, 39.336883798241615, 40.6132885068655, 40.435777232050896, 41.0371557623148, 40.87911084294319, 38.808153569698334, 37.98308104276657, 40.99057026207447, 37.871340438723564, 38.99907052516937, 39.36526067554951, 41.25107288360596, 38.49676787853241, 38.63416850566864, 39.606281742453575, 41.03940524160862, 38.352010846138, 38.685271963477135, 38.30332785844803, 39.05576728284359, 38.28564740717411, 41.41175866127014, 39.862258806824684, 43.056739792227745, 51.745034381747246, 50.78516788780689, 43.609264343976974, 43.43343257904053, 41.88177444040775, 40.119121223688126, 37.866332307457924, 40.160649195313454, 40.492929965257645, 40.32548055052757, 41.293645799160004, 45.06785787642002, 45.658767968416214, 46.693296656012535, 47.12396554648876, 48.35862189531326, 51.94809548556805, 50.190078020095825, 48.01914431154728, 47.18271419405937, 47.04842559993267, 48.78326050937176, 47.481887340545654, 48.282416984438896, 44.16985206305981, 42.91406884789467, 41.04233868420124, 38.88849265873432, 40.81443831324577, 40.151947662234306, 41.33340686559677, 42.92991399765015, 41.57771475613117, 40.04075042903423, 40.29814101755619, 41.04375600814819, 41.72738492488861, 44.58853259682655, 44.515276327729225, 41.92755438387394, 42.48011693358421, 41.890840753912926, 40.72978265583515, 41.17528215050697, 40.07849380373955, 39.71292681992054, 41.811691001057625, 41.28450348973274, 40.36398388445377, 40.09660363197327, 40.85304044187069, 41.69888265430927, 39.32863064110279, 41.18817865848541, 39.970461800694466, 40.399853959679604, 42.05428138375282, 41.345714405179024, 43.15549649298191, 42.09556616842747, 42.92289957404137, 43.342233672738075, 41.42312005162239, 42.06276252865791, 43.90874907374382, 43.11747953295708, 44.973045364022255, 46.59005619585514, 47.4253311753273, 46.463268399238586, 47.280612140893936, 43.57070401310921, 43.93391132354736, 44.93048004806042, 53.17375771701336, 57.098772302269936, 59.17629562318325, 59.21310044825077, 63.712659403681755, 60.89639112353325, 67.41079196333885, 62.57911942899227, 71.09195843338966, 6.305299010127783, 0.41275510797277093, 6.98460565879941, 5.8112594950944185, 0.122893873922294, 0.9740477486047894, 52.91434943675995, 70.64433485269547, 67.83471241593361, 66.96948364377022, 51.90910577774048, 29.85273901373148, 23.823974914848804, 39.673587530851364, 58.335518538951874, 64.34553444385529, 8.08527359738946, 0.2776382176671177, 0.030021847633179277, 0.03716226194228511, 0.07318482254049741, 0.0388534532248741, 0.028768141273758374, 0.24052980967098847, 0.1940367661882192, 0.22539293597219512, 0.146746952959802, 0.12031235033646226, 0.14289415266830474, 0.30743785144295543, 0.9268780297134072, 62.394156754016876, 70.17839625477791, 62.81404562294483, 32.281426191329956, 58.02550457417965, 95.41698396205902, 57.286045253276825, 70.75101032853127, 69.19148281216621, 66.99230521917343, 68.22217002511024, 3.2169636664912105, 0.6740637612529099, 3.692133156582713, 8.748274371027946, 0.20358776149805635, 27.381247133016586, 67.54724264144897, 56.86864525079727, 63.20812627673149, 59.739767387509346, 63.3846990019083, 52.915382981300354, 49.89495925605297, 49.975723922252655, 52.61294960975647, 48.230390176177025, 45.46722024679184, 43.068503960967064, 45.94953216612339, 41.989206075668335, 45.97244493663311, 42.36923508346081, 45.03992557525635, 40.21836809813976, 42.56871297955513, 41.06920704245567, 44.25827331840992, 42.10162304341793, 41.89166150987148, 43.0212876945734, 43.79325047135353, 43.82908254861832, 41.29290483891964, 40.9627291560173, 43.00462558865547, 40.91818794608116, 41.58473677933216, 42.260104939341545, 44.21657435595989, 41.330408826470375, 40.13791881501675, 39.95314612984657, 43.76744605600834, 40.3027767688036, 41.377229914069176, 41.14301048219204, 40.58298133313656, 38.49080599844456, 43.428166061639786, 42.37680047750473, 45.095311403274536, 52.39392176270485, 54.24978017807007, 46.1703535169363, 44.72453489899635, 41.74995571374893, 42.72406384348869, 40.33196680247784, 42.62506775557995, 41.60367876291275, 40.50945907831192, 44.487948194146156, 47.44281403720379, 47.86101199686527, 51.09523504972458, 49.424932077527046, 52.779304683208466, 55.18680989742279, 52.79651015996933, 47.07316607236862, 49.86979700624943, 47.6724661141634, 49.27392058074474, 50.10009124875069, 50.479474291205406, 46.65349379181862, 45.20300902426243, 43.30879166722298, 40.874551087617874, 43.15064415335655, 41.45465075969696, 43.997660502791405, 46.16692990064621, 45.30134774744511, 42.0991987735033, 41.1545504629612, 43.671220019459724, 43.72991167008877, 47.80412904918194, 48.09126824140549, 45.20205907523632, 46.36796571314335, 43.63409981131554, 42.316220328211784, 43.354016840457916, 42.57764250040054, 41.761689484119415, 44.95715841650963, 42.50624433159828, 42.81194172799587, 43.10845501720905, 45.57500906288624, 45.457055792212486, 42.83567525446415, 42.597830817103386, 43.34715820848942, 44.27989415824413, 44.29633967578411, 42.933402210474014, 43.83963078260422, 46.21570408344269, 43.59063774347305, 44.82369437813759, 43.810265958309174, 43.25726643204689, 46.74908526241779, 46.96145586669445, 47.249784395098686, 49.26673896610737, 49.41077783703804, 47.128726691007614, 50.82938611507416, 46.17936283349991, 45.74080936610699, 47.27739371359348, 55.7180517911911, 61.0663940012455, 62.38308794796467, 63.47360283136368, 65.46151176095009, 64.00400876998901, 70.7646743953228, 65.23314401507378, 74.3010838329792, 7.253836411982775, 0.5536324891727418, 11.710474770516157, 21.863282024860382, 0.7287957274820656, 1.230354504659772, 57.96522460877895, 78.58517915010452, 73.98186296224594, 78.5921023786068, 62.83955365419388, 40.53673021495342, 31.69844627380371, 49.03690829873085, 67.74419367313385, 76.00832462310791, 12.19382593408227, 0.4719653120264411, 0.11439652793342248, 0.1325587963219732, 0.17323384730843827, 0.13831381016643718, 0.14034759165951982], [0.07801771047525108, 0.08378766375244595, 0.03520029436913319, 0.03144848553347401, 0.020890913474431727, 0.019511366699589416, 0.0661779911024496, 0.7918167707975954, 44.8165887594223, 57.62355074286461, 44.757885709404945, 20.990698747336864, 62.57544122636318, 93.25451239943504, 58.75945799052715, 47.87096366286278, 61.415298879146576, 54.72609981894493, 59.32601898908615, 1.9975079270079732, 0.1453140439116396, 0.9859906265046448, 0.6999987352173775, 0.341129990410991, 24.440267644822598, 71.10036358237267, 50.27530364692211, 61.16211846470833, 52.7783889323473, 50.887291207909584, 43.75024437904358, 53.588706851005554, 50.42929798364639, 55.33952750265598, 52.152338325977325, 48.9805269241333, 39.730132296681404, 39.55439172685146, 39.34127256274223, 38.913886696100235, 37.014490216970444, 39.7357863932848, 39.01537545025349, 38.29407535493374, 39.12022702395916, 40.260663628578186, 40.73827140033245, 36.75689443945885, 38.419020250439644, 41.02800965309143, 39.88960973918438, 37.89421521127224, 36.948385164141655, 37.96239495277405, 37.33635954558849, 37.531600669026375, 36.11679598689079, 39.34528134763241, 35.66693812608719, 37.46590979397297, 36.86918221414089, 37.99352668225765, 36.55634880065918, 36.47887855768204, 35.30620828270912, 38.14244829118252, 37.936837524175644, 37.53769554197788, 39.162739142775536, 38.63669157028198, 47.76547372341156, 51.97133503854275, 44.47642721235752, 39.97656807303429, 39.84774358570576, 38.55750001966953, 37.6437858492136, 36.713922545313835, 37.870493084192276, 38.091329634189606, 38.54961544275284, 40.276843160390854, 40.36152921617031, 43.568739518523216, 44.56041790544987, 45.5646888166666, 45.54839909076691, 51.397094652056694, 47.90632836520672, 42.22038947045803, 45.91967336833477, 40.952234119176865, 44.01156395673752, 43.143082559108734, 40.99109843373299, 39.71618324518204, 39.93506669998169, 37.55470722913742, 38.576160818338394, 38.62272351980209, 38.26355159282684, 38.15813384950161, 38.84643271565437, 36.97678864002228, 37.54580430686474, 35.98373852670193, 40.390894040465355, 41.37016609311104, 42.0870166271925, 39.9076321721077, 38.95251922309399, 38.56494382023811, 37.49174080789089, 38.696249574422836, 37.702162116765976, 36.89032047986984, 39.1084248572588, 39.181388542056084, 39.67338614165783, 37.4226301163435, 39.00019906461239, 39.28609572350979, 37.69611284136772, 37.4043644964695, 38.965484127402306, 38.622902110219, 38.05142417550087, 38.456322848796844, 39.48372311890125, 41.90759405493736, 40.169396325945854, 40.14424927532673, 40.37868909537792, 38.36969889700413, 42.078816667199135, 42.68176071345806, 41.15325853228569, 41.89670383930206, 42.573656514286995, 40.960852056741714, 43.92287291586399, 43.735945746302605, 44.43741850554943, 53.78612145781517, 59.86195743083954, 59.91652250289917, 63.7910757958889, 61.52964234352112, 61.53341554105282, 63.83323833346367, 61.84257835149765, 64.54250827431679, 66.7494298517704, 5.336483521386981, 0.5346750689204782, 1.0029235272668302, 0.5597365647554398, 0.09362331722513773, 0.802342799725011, 48.133130595088005, 64.6607731282711, 65.2563987672329, 62.23252482712269, 53.597412183880806, 38.233821988105774, 18.118569664657116, 37.265535145998, 51.521093398332596, 59.55333039164543, 4.805377470329404, 0.2865190536249429, 0.010199706593994051, 0.03952133047278039, 0.013567447513196385, 0.1143087912350893, 0.030237970313464757, 0.03121405592537485, 0.03424761423957534, 0.008056275564740645, 0.00289840765617555, 0.038779565002187155, 0.036349116708151996, 0.022176862439664546, 0.7821616670116782, 54.935510382056236, 66.64148524403572, 54.51751001179218, 26.149294339120388, 66.05211406946182, 93.92879381775856, 60.1728605479002, 55.98040871322155, 66.842380464077, 60.35529635846615, 66.06472179293633, 2.4911950109526515, 0.393078665365465, 1.1141233728267252, 2.6628510374575853, 0.2229378224001266, 26.322449147701263, 73.516965508461, 54.52076643705368, 61.968853175640106, 54.79622505605221, 54.63976465165615, 45.040936321020126, 55.6100007891655, 53.26583057641983, 57.058030888438225, 54.00830313563347, 51.80417060852051, 39.772218838334084, 41.29640445113182, 41.17172174155712, 41.98893629014492, 39.278838112950325, 41.53793849050999, 40.58853663504124, 40.704943388700485, 40.45526258647442, 41.353245601058006, 43.451344817876816, 40.75562126934528, 40.655378848314285, 43.03324565291405, 42.155333161354065, 39.606950506567955, 37.63569988310337, 41.20946131646633, 38.39761219918728, 40.70282310247421, 38.371959775686264, 41.27668350934982, 38.1139612197876, 39.508566185832024, 38.09429347515106, 41.31402030587196, 38.30506816506386, 38.011039942502975, 36.62302382290363, 39.513464123010635, 39.52985644340515, 40.80895520746708, 40.32676488161087, 39.45482946932316, 50.371229499578476, 51.566557958722115, 43.82380083203316, 40.190697982907295, 40.35665027797222, 40.65405651926994, 38.264307752251625, 38.21888118982315, 39.540184289216995, 39.85631972551346, 39.304786920547485, 42.81048260629177, 42.88585916161537, 45.16573302447796, 46.5869365632534, 48.09469185769558, 47.539632841944695, 50.946932807564735, 49.588357508182526, 44.74386066198349, 47.31981083750725, 43.48493881523609, 45.2832455188036, 45.10663479566574, 41.58570572733879, 42.00779467821121, 40.61561018228531, 40.367673486471176, 39.54708091914654, 39.60936337709427, 40.4467548429966, 41.06714375317097, 40.53528629243374, 40.65560303628445, 38.711657747626305, 37.18954682350159, 42.08540931344032, 43.52508746087551, 45.34522019326687, 41.113892644643784, 40.8088032156229, 39.416443929076195, 39.135547801852226, 40.87512105703354, 39.24873232841492, 39.56798359751701, 40.18915146589279, 42.95596159994602, 40.916063860058784, 40.12867011129856, 42.460156604647636, 41.31282337009907, 39.88768704235554, 39.69027243554592, 40.3048362582922, 40.6623400747776, 41.07061676681042, 42.14295342564583, 42.058939933776855, 42.48575963079929, 43.504287376999855, 41.53767250478268, 41.88667617738247, 40.74026249349117, 44.77110520005226, 43.671356812119484, 43.10753546655178, 43.088844269514084, 46.060216426849365, 43.594669327139854, 45.83236925303936, 44.50738415122032, 46.44482798874378, 54.74358268082142, 61.56942620873451, 61.12132005393505, 65.577033162117, 62.21798300743103, 66.33420333266258, 64.62417349219322, 67.00386419892311, 63.88581231236458, 69.33829933404922, 5.886222822591662, 0.7107509113848209, 4.9820684641599655, 2.510912627913058, 0.09777549988939427, 0.9591494605410844, 54.3288691341877, 68.39699104428291, 72.07283779978752, 68.77216011285782, 58.11537355184555, 40.327027067542076, 22.938920706510544, 44.484319388866425, 59.61921885609627, 68.19361075758934, 7.679108642041683, 0.30706383869983256, 0.020476004683587234, 0.04506272452999838, 0.06778963899705559, 0.04478276416193694, 0.018038042144326027, 0.17621842387598008, 0.19219232141040266, 0.13883917650673538, 0.12125453649787232, 0.1665891765151173, 0.14804807142354548, 0.2846033626701683, 0.9674549242481589, 64.63612765073776, 75.13953924179077, 63.26449245214462, 31.741220578551292, 71.97179362177849, 94.55823004245758, 66.9680093228817, 61.82345777750015, 72.8104618191719, 66.25398963689804, 71.63378655910492, 2.9233277728781104, 0.4971323412610218, 2.6795687153935432, 6.589832967147231, 0.37998593354132026, 28.895488679409027, 75.84042683243752, 58.199482038617134, 65.16531005501747, 57.13519334793091, 57.35178552567959, 48.34585838019848, 58.1913922727108, 56.09349824488163, 60.8427532017231, 57.19218648970127, 54.22727778553963, 43.14950421452522, 42.92099207639694, 44.30862441658974, 43.94805796444416, 41.584269404411316, 45.29144927859306, 43.56546029448509, 43.426209166646004, 44.197651371359825, 44.070103615522385, 44.30530719459057, 44.19914849102497, 44.068473502993584, 47.276804745197296, 45.30004821717739, 42.93650284409523, 39.77667599916458, 45.1425276696682, 41.14455699920654, 43.479144126176834, 40.409801825881004, 43.36444728076458, 39.89831127226353, 41.482951641082764, 39.76833164691925, 42.15187534689903, 39.741075709462166, 39.169856160879135, 39.05490092933178, 42.18804560601711, 41.8569465726614, 42.459666430950165, 43.25826957821846, 41.632872596383095, 51.62032887339592, 54.595512226223946, 46.75385780632496, 42.78651349246502, 42.60597378015518, 41.27675950527191, 42.596801072359085, 40.838665813207626, 41.42265647649765, 43.67937058210373, 42.61305660009384, 44.96698088943958, 45.12111581861973, 47.09146209061146, 49.49133351445198, 50.97130469977856, 51.096029207110405, 52.593084275722504, 50.86779065430164, 49.72687907516956, 49.374748170375824, 45.94537138938904, 45.839858651161194, 48.3103758841753, 44.64363344013691, 43.47330383956432, 41.80705524981022, 42.81423680484295, 40.45009486377239, 42.00598977506161, 41.35748237371445, 43.162925094366074, 43.00445079803467, 42.69386686384678, 40.93869164586067, 37.68969118595123, 43.77664916217327, 44.224971905350685, 48.135410472750664, 43.835648596286774, 43.97138871252537, 42.32109546661377, 41.64244808256626, 42.03682132065296, 39.53609190881252, 40.678162425756454, 42.90095955133438, 45.93114875257015, 43.75271424651146, 40.86537458002567, 44.58352066576481, 43.02227944135666, 42.486686781048775, 43.041783794760704, 43.16490478813648, 44.404622465372086, 42.63088144361973, 45.68736523389816, 44.32261526584625, 45.58765098452568, 44.6095834672451, 44.42528195679188, 44.374231696128845, 41.726092994213104, 46.478068605065346, 46.6376980394125, 47.13729903101921, 46.125816106796265, 48.97370629012585, 44.76881392300129, 48.95480990409851, 47.40551143884659, 51.27866640686989, 58.581661731004715, 64.26273688673973, 64.31820631027222, 69.94501277804375, 65.21234393119812, 67.99779206514359, 67.32528135180473, 68.19421112537384, 68.39661866426468, 70.76548755168915, 7.7666611690074205, 1.2856953288428485, 11.069291476160288, 4.963382491841912, 0.20911839441396296, 1.2567058531567454, 57.898219004273415, 76.84071555733681, 75.90540334582329, 77.13304907083511, 67.83209815621376, 54.25197646021843, 31.744112223386765, 56.87712639570236, 68.03447529673576, 81.23606130480766, 11.13188836723566, 0.5202451057266444, 0.09987364785047248, 0.11540417151991278, 0.23953887925017625, 0.18799805897288024, 0.1757344396901317], [0.060491893091239035, 0.010427596025692765, 0.049215660474146716, 0.015035141022963217, 0.05495242490724195, 0.15306558343581855, 0.1643516606418416, 0.22269604553002864, 37.040397226810455, 65.3032198548317, 46.96097329258919, 36.1906336247921, 43.20845805108547, 72.62115597724915, 46.35872840881348, 52.1132156252861, 65.55212929844856, 53.18741038441658, 62.83481150865555, 3.023785832338035, 0.3071158187231049, 0.6487354484852403, 1.8713093362748623, 0.35525024053640664, 20.949801541864872, 74.08247396349907, 55.736704990267754, 60.793443247675896, 51.08814463019371, 53.37247185409069, 53.39565820991993, 57.0076721906662, 59.027898386120796, 59.53395903110504, 53.536467254161835, 56.60340428352356, 43.843563571572304, 41.19041673839092, 39.80412572622299, 39.84309263527393, 38.91879603266716, 39.868631064891815, 39.40278746187687, 40.742002800107, 37.833456471562386, 41.171432957053185, 39.96065832674503, 41.42304785549641, 39.66291390359402, 39.15570192039013, 37.14139960706234, 38.73080492019653, 36.202842369675636, 36.01607099175453, 36.570347249507904, 36.46468251943588, 37.80111260712147, 38.90424661338329, 36.0777834802866, 36.35172218084335, 36.94578990340233, 39.502144530415535, 36.3162624835968, 35.730212330818176, 35.20085893571377, 36.32561758160591, 36.035256162285805, 39.81712102890015, 38.2798907160759, 38.083996027708054, 47.04757824540138, 52.715521305799484, 41.79424233734608, 38.159801959991455, 37.71655574440956, 38.33500675857067, 38.66278477013111, 37.352721467614174, 37.6424977183342, 36.95220775902271, 37.362730130553246, 38.443084359169006, 39.32630896568298, 43.59134830534458, 42.44099423289299, 48.02083522081375, 51.27962775528431, 46.58463768661022, 39.01300057768822, 42.313476875424385, 42.28863760828972, 42.4161359667778, 41.51464954018593, 39.62420918047428, 40.73074400424957, 39.120230823755264, 37.640043050050735, 39.85612213611603, 37.515272945165634, 37.237359657883644, 39.033956453204155, 40.614671632647514, 37.58285991847515, 36.579257771372795, 38.095782995224, 38.25330354273319, 40.212805196642876, 44.430252090096474, 44.36553776264191, 39.27814655005932, 37.55838543176651, 38.30438420176506, 39.38997834920883, 37.55653493106365, 36.58745393157005, 38.23409557342529, 37.31085531413555, 37.696082442998886, 38.35438571870327, 37.61918216943741, 38.424689546227455, 38.71041141450405, 37.85665422677994, 38.08304987847805, 38.98457430303097, 37.68132783472538, 39.41429324448109, 40.00140734016895, 40.304251089692116, 39.94152635335922, 40.438254699110985, 42.69867740571499, 41.08478240668774, 40.07521837949753, 40.95433160662651, 39.275828674435616, 44.24933239817619, 44.24582898616791, 45.11803038418293, 42.62150354683399, 43.93075369298458, 41.939744129776955, 48.13483290374279, 56.36764593422413, 59.7090270370245, 59.65499393641949, 57.91580446064472, 54.79873672127724, 63.80939841270447, 61.77253670990467, 66.59406378865242, 59.48097087442875, 61.943314746022224, 4.924267390742898, 0.535019722301513, 5.6325907073915005, 2.5840085931122303, 0.14907603501342237, 0.435520161408931, 44.36806082725525, 66.9634647667408, 62.62325406074524, 68.71959373354912, 52.87687584757805, 29.771752059459686, 23.038555160164833, 33.71918544173241, 49.46233347058296, 58.01723621785641, 4.750701729208231, 0.276975836022757, 0.07130874000722542, 0.0957268086494878, 0.02645170912728645, 0.07424557421472855, 0.03621182680944912, 0.024108318466460332, 0.019976867697550915, 0.03472843687632121, 0.05443171183287632, 0.03450121352216229, 0.10284595671691932, 0.060015397175448015, 0.3220091195544228, 45.75577296316624, 71.24446704983711, 54.635831862688065, 31.106806620955467, 45.94858981668949, 86.78308725357056, 56.489573791623116, 58.50493624806404, 69.96311500668526, 58.11442360281944, 65.68111717700958, 4.0199140179902315, 0.2961351501289755, 0.9475568763446063, 1.6349715180695057, 0.36025118781253695, 22.419480979442596, 74.00838553905487, 58.11571553349495, 61.67857155203819, 52.315189987421036, 55.15416584908962, 55.072447434067726, 61.353992968797684, 60.66691763699055, 61.11174836754799, 54.876632541418076, 57.520097494125366, 45.8965440094471, 42.19194799661636, 42.223026528954506, 43.08153726160526, 40.834668427705765, 39.91076320409775, 40.902696177363396, 44.153797924518585, 39.63664211332798, 44.23344925045967, 40.78167267143726, 43.601942136883736, 41.4030647277832, 41.28473527729511, 39.552214443683624, 41.527671441435814, 37.71734230220318, 39.69002164900303, 38.237397596240044, 39.404394775629044, 38.403885662555695, 41.04617267847061, 38.90461139380932, 38.43761645257473, 38.30660328269005, 41.33310288190842, 38.21014545857906, 38.03003512322903, 36.069925501942635, 37.95347303152084, 38.05855259299278, 41.74288049340248, 39.07749831676483, 41.084531620144844, 48.064468279480934, 53.76383185386658, 42.7647140622139, 39.416968300938606, 40.015994757413864, 40.22634766995907, 39.19331230223179, 39.79458823800087, 38.77899393439293, 38.06440427899361, 38.98290619254112, 41.72271877527237, 42.405720725655556, 45.62254071235657, 44.6009237319231, 50.2451104670763, 52.76970259845257, 52.60468125343323, 42.57205680012703, 44.019828513264656, 44.63174767792225, 44.17868658900261, 42.35404349863529, 42.971460968256, 41.816433146595955, 40.597709342837334, 39.661188796162605, 39.65439476072788, 39.74128469824791, 39.96289260685444, 39.48911502957344, 41.67169131338596, 37.44949467480183, 38.32909047603607, 40.45272812247276, 38.7030778080225, 40.29182195663452, 45.89530907571316, 45.64432114362717, 39.57564778625965, 40.192601680755615, 41.048627346754074, 40.86417764425278, 39.14511188864708, 38.39218609035015, 39.22054924070835, 39.17881228029728, 39.00743767619133, 40.54043881595135, 40.622457414865494, 40.0564169883728, 41.789017617702484, 40.96122443675995, 40.2497848123312, 39.9649178981781, 39.84091155230999, 40.917933359742165, 40.9845095872879, 44.39067341387272, 41.97357751429081, 43.03364843130112, 43.94767798483372, 43.924309238791466, 42.55403056740761, 43.246121630072594, 42.09650091826916, 45.10337837040424, 44.612733498215675, 47.071144580841064, 43.92541117966175, 46.398215889930725, 44.55956295132637, 50.88880352675915, 58.79596263170242, 61.76613785326481, 60.35629950463772, 59.73839946091175, 56.154256984591484, 66.59904152154922, 64.5745861530304, 67.82290264964104, 62.56772384047508, 68.26051756739616, 5.783333368599415, 0.7144792238250375, 3.9094109600409865, 2.1069570165127516, 0.17398994736140594, 0.4152197210351005, 47.512133717536926, 71.835548132658, 68.98538187146187, 74.18893665075302, 54.011791348457336, 40.83684951066971, 30.07604543119669, 42.25466363132, 56.184279173612595, 69.16855484247208, 7.74530821479857, 0.41565500549040735, 0.01663619197643129, 0.0829826487461105, 0.11568160116439685, 0.03910690407792572, 0.025364431239722762, 0.21123210521182045, 0.07266674409038387, 0.2173090775613673, 0.1881064719054848, 0.13849750655936077, 0.19894329743692651, 0.28049809858202934, 0.48766176507342607, 56.27977564930916, 81.38958066701889, 64.08919259905815, 48.22656378149986, 52.91811503469944, 78.36982190608978, 57.58588336408138, 66.61440789699554, 75.71052700281143, 63.277278766036034, 73.37181329727173, 4.748806580901146, 0.7693822402507067, 3.3868565876036882, 8.85098285973072, 0.5001805198844522, 24.178963266313076, 75.35510927438736, 60.13883717358112, 65.90466678142548, 56.2124090641737, 59.00847762823105, 59.42273899912834, 63.034148812294006, 63.98019924759865, 63.30515407025814, 56.146531999111176, 60.739212557673454, 48.159364387393, 45.8987744897604, 44.3904834240675, 45.004009902477264, 42.92545683681965, 43.34433875977993, 43.83317492902279, 45.39221227169037, 42.44511321187019, 47.82139912247658, 44.51523073017597, 46.13614395260811, 45.53676411509514, 43.363447934389114, 41.564065888524055, 44.829276278615, 39.68068554997444, 41.72138124704361, 40.49810528755188, 41.92326821386814, 41.65241874754429, 44.42430540919304, 42.365150302648544, 41.5045078843832, 40.56100711226463, 44.038914889097214, 39.744924902915955, 39.413407891988754, 38.81354168057442, 39.79890860617161, 40.00456117093563, 43.79634350538254, 42.072695195674896, 43.63031901419163, 53.17451387643814, 56.53470017015934, 42.42477290332317, 39.407320618629456, 40.796833857893944, 41.51627965271473, 42.13353753089905, 42.07753233611584, 41.2150052189827, 40.85703402757645, 42.35168382525444, 42.9668328166008, 43.77080887556076, 47.78180904686451, 47.305136024951935, 52.994703724980354, 52.44363069534302, 52.00757369399071, 45.11661686003208, 45.594505816698074, 44.957789182662964, 48.45811955630779, 45.951629653573036, 44.96805243194103, 45.86120590567589, 42.861464470624924, 41.439090594649315, 41.94757550954819, 42.02650107443333, 42.271869108080864, 42.097013890743256, 43.26118782162666, 40.084296092391014, 38.3493509888649, 42.068534418940544, 40.31674861907959, 41.477825716137886, 47.826832830905914, 50.470829755067825, 42.028009593486786, 41.30771264433861, 43.663776218891144, 43.885729908943176, 41.20244689285755, 38.938676565885544, 42.01638601720333, 41.52751944959164, 41.777580231428146, 41.9332654774189, 43.05061832070351, 41.22404873371124, 44.74134899675846, 43.9129326492548, 43.41966591775417, 43.01704332232475, 41.46734967827797, 43.78612205386162, 42.94792503118515, 44.85207125544548, 45.99436596035957, 45.22018410265446, 48.41446749866009, 45.53343549370766, 44.94709275662899, 47.84850686788559, 44.30938817560673, 49.24838975071907, 48.405632972717285, 49.429389238357544, 47.17566557228565, 48.37382107973099, 46.40917830169201, 53.23640875518322, 62.356348782777786, 63.93929064273834, 65.57158425450325, 61.64724983274937, 56.666032522916794, 70.43138667941093, 65.06990477442741, 71.31718754768372, 65.07824912667274, 73.49871888756752, 7.987709082663059, 0.8491911983583122, 11.971558760851622, 8.013963773846626, 0.6986165000125766, 0.42553109116852283, 53.23378689587116, 76.46765157580376, 72.80896469950676, 81.18485525250435, 65.34041225910187, 42.71441236138344, 34.709351509809494, 50.723265409469604, 65.27073919773102, 81.34335234761238, 11.58655297011137, 0.49138969159685075, 0.2832888113334775, 0.19000352011062205, 0.29079278523568064, 0.1438226387836039, 0.12134895994677208], [0.1167521566094365, 0.04023774046800099, 0.06969787136767991, 0.13618041761219501, 0.016026061239244882, 0.10890873178141192, 0.20483939355472103, 0.13838887098245323, 33.76303128898144, 63.82062301039696, 46.78039938211441, 39.02745880186558, 25.257936269044876, 21.892806440591812, 34.484878554940224, 58.384870290756226, 64.64750424027443, 52.904295176267624, 60.37821292877197, 3.3365475246682763, 0.32932001631706953, 0.47167626034934074, 0.5983326968271285, 0.28630374174099416, 12.846981436014175, 71.66822791099548, 53.15195068717003, 62.78748504817486, 52.03259155154228, 61.970764473080635, 56.90387316048145, 57.43963681161404, 47.66312621533871, 57.559543177485466, 53.76624092459679, 55.37084922194481, 44.619953110814095, 41.602721214294434, 38.303821831941605, 37.818663865327835, 38.85267578065395, 41.97429947555065, 38.39538931846619, 41.68985813856125, 40.42348489165306, 42.303855791687965, 38.43336068093777, 40.786312222480774, 36.07891581952572, 38.121686205267906, 35.33195190131664, 37.83491179347038, 38.02605673670769, 39.78495955467224, 36.70440785586834, 35.95324516296387, 35.331541523337364, 37.9498328268528, 36.090968772768974, 37.276763543486595, 37.53672659397125, 38.16557765007019, 36.186222061514854, 36.4886212348938, 35.3694748878479, 36.512020379304886, 37.54730902612209, 39.94607090950012, 37.26881816983223, 37.888827100396156, 45.19429989159107, 47.791897505521774, 42.60517582297325, 37.42175996303558, 37.44894750416279, 37.723444774746895, 40.330139100551605, 39.763224720954895, 36.50404080748558, 38.89867231249809, 37.409163638949394, 38.980858102440834, 38.12887541949749, 42.44514361023903, 46.25575393438339, 48.190678507089615, 41.78468585014343, 40.03218188881874, 41.297301203012466, 42.700945883989334, 43.24428252875805, 42.94833920896053, 40.030821561813354, 40.24337835609913, 38.9115422219038, 39.45715494453907, 37.596368193626404, 37.35423758625984, 38.39921571314335, 36.70416846871376, 39.15004022419453, 41.566740944981575, 36.72132074832916, 38.87545935809612, 38.078585118055344, 37.95605309307575, 40.06660804152489, 47.41286024451256, 40.857049226760864, 38.02406944334507, 40.59079751372337, 37.37347595393658, 38.37811544537544, 36.4340827614069, 36.66900895535946, 36.131778582930565, 37.359333112835884, 40.48761785030365, 40.002566277980804, 36.50353163480759, 39.57051046192646, 37.76234708726406, 38.45627345144749, 36.58197842538357, 38.716004714369774, 37.09543727338314, 37.51765541732311, 38.4077462553978, 38.79032492637634, 38.84042523801327, 41.126918345689774, 41.513798385858536, 41.30438782274723, 39.52987164258957, 41.42951890826225, 43.291931971907616, 40.598663091659546, 43.73186856508255, 45.91768607497215, 43.583117946982384, 45.02572953701019, 41.733160614967346, 49.71546828746796, 54.48968790471554, 60.74191801249981, 59.36255402863026, 61.732004284858704, 56.86723552644253, 65.81841140985489, 62.7508208155632, 66.91915914416313, 47.89351925253868, 55.97860760986805, 5.398217858746648, 0.713588468497619, 2.5013088807463646, 1.3526059384457767, 0.33117924467660487, 0.8093675540294498, 50.220107808709145, 64.5904541015625, 67.15301379561424, 65.8547754585743, 57.88203947246075, 35.153893455863, 20.10814480483532, 34.46355029940605, 52.43765361607075, 55.54867208003998, 3.3896522875875235, 0.19275774888228625, 0.05459424959553871, 0.044098897342337295, 0.019923720647057053, 0.04890009186055977, 0.05908922656089999, 0.03376322929398157, 0.056036743480945006, 0.07504855573642999, 0.038480334769701585, 0.07962336923810653, 0.07137276508728974, 0.2526696090353653, 0.06327162205707282, 39.66940015554428, 70.06942570209503, 55.60943081974983, 45.088699758052826, 33.41291047632694, 42.313237488269806, 40.13524755835533, 61.20365023612976, 69.63610455393791, 57.92781941592693, 65.02498358488083, 4.024818604812026, 0.49259532534051687, 0.4713288164930418, 2.7154808258637786, 0.3511741873808205, 13.782364893704653, 75.51076412200928, 55.73306858539581, 65.97892999649048, 54.760582968592644, 63.64962838590145, 59.0467643737793, 60.37130489945412, 50.48724487423897, 59.558486714959145, 56.182436272501945, 56.307624354958534, 48.175217136740685, 44.560664892196655, 40.63653565943241, 41.70527771115303, 41.554513201117516, 44.356163665652275, 39.86866906285286, 44.323937594890594, 43.43038894236088, 44.061459079384804, 41.71367906033993, 43.13315749168396, 40.00501334667206, 39.52514089643955, 38.42022478580475, 40.88257245719433, 39.31528575718403, 40.99731110036373, 38.631668239831924, 39.76955138146877, 37.999762147665024, 41.43885500729084, 37.478255331516266, 38.637447729706764, 38.613695204257965, 39.67823848128319, 36.24411575496197, 38.77473436295986, 37.082210183143616, 38.193578347563744, 38.70508790016174, 42.185252755880356, 39.82071943581104, 41.59571059048176, 45.959088653326035, 51.24049365520477, 43.31333242356777, 39.008976593613625, 38.378639817237854, 39.30690720677376, 40.758015140891075, 41.96423381567001, 39.31765303015709, 38.16504567861557, 37.834501415491104, 40.50606586039066, 41.407499089837074, 43.39128144085407, 45.84043622016907, 50.50512291491032, 46.35459043085575, 42.5769167393446, 41.71978533267975, 45.37642411887646, 44.79493372142315, 44.26388941705227, 41.00527547299862, 40.74123524129391, 41.39855816960335, 40.6910665333271, 39.439227506518364, 38.91564220190048, 41.91224120557308, 39.263980910182, 41.41848810017109, 40.22381700575352, 37.42834880948067, 39.40061017870903, 38.154862225055695, 38.18588376045227, 40.673386082053185, 49.587764739990234, 43.516412526369095, 38.880649879574776, 41.936073526740074, 39.442392736673355, 39.1749706864357, 38.52581351995468, 38.11817519366741, 38.37889060378075, 39.59077097475529, 40.49238659441471, 41.40413247048855, 39.00393806397915, 40.67026264965534, 39.63223434984684, 41.04301504790783, 40.1580311357975, 42.74785816669464, 40.144142881035805, 39.79904159903526, 41.79058313369751, 40.624995678663254, 40.58386288583279, 43.31122733652592, 44.829394072294235, 44.103298634290695, 41.53673775494099, 44.24842804670334, 44.53942783176899, 44.10791918635368, 45.81213913857937, 47.64979273080826, 44.14809063076973, 47.26484678685665, 45.579971596598625, 51.47887386381626, 56.27647362649441, 62.782628908753395, 61.85661479830742, 62.810584008693695, 59.63156819343567, 66.80787831544876, 63.74621920287609, 65.78576356172562, 53.27841930091381, 62.461865320801735, 6.887528942897916, 0.9570731094572693, 4.453350584954023, 1.9351917458698153, 0.22993694292381406, 0.826965537853539, 52.29926884174347, 72.28218376636505, 69.15856137871742, 72.96868532896042, 61.31572522222996, 33.96782509982586, 24.6059425547719, 42.25027486681938, 58.689735531806946, 65.68291068077087, 5.3693783562630415, 0.2616458258125931, 0.023278185472008772, 0.019324942913954146, 0.04360242652182933, 0.005338265455065994, 0.03144406604405958, 0.23712387133855373, 0.16837469476740807, 0.16021421703044325, 0.3405582101549953, 0.1461400542757474, 0.2826509502483532, 0.27546476398129016, 0.25479016243480146, 45.703521966934204, 79.21401500701904, 64.5743277668953, 55.70139728486538, 38.84031504392624, 34.087427482008934, 46.478307992219925, 69.26329135894775, 77.70978212356567, 61.95340320467949, 71.40003070235252, 4.277360178530216, 0.5297787941526622, 3.052559313364327, 6.262512831017375, 0.40069752372801304, 14.589559379965067, 76.72101438045502, 58.28582860529423, 68.01397159695625, 56.95423185825348, 67.35958591103554, 61.92843854427338, 61.23005121946335, 53.32152798771858, 61.62321612238884, 58.38933125138283, 60.0321388989687, 50.56419834494591, 45.96959128975868, 41.51512451469898, 42.65325844287872, 43.8296677172184, 46.787041425704956, 41.9723691791296, 46.782067492604256, 46.874147951602936, 46.68913207948208, 44.02203619480133, 46.61915123462677, 41.20053939521313, 42.366772815585136, 39.535244554281235, 44.173442870378494, 42.98598758876324, 45.88254556059837, 42.1663411706686, 43.60772542655468, 40.03587909042835, 43.42081345617771, 39.38199497759342, 41.92110612988472, 40.44088415801525, 41.1497513204813, 40.54925814270973, 42.06698790192604, 39.563097059726715, 41.26505233347416, 41.36166974902153, 43.407301381230354, 41.17069199681282, 41.5990886092186, 49.58097070455551, 52.3613803088665, 44.7567343711853, 39.358337447047234, 39.03156258165836, 41.04722902178764, 43.918161168694496, 43.057332560420036, 39.87349860370159, 41.547764763236046, 40.059213638305664, 43.872419223189354, 43.07178318500519, 46.075043231248856, 47.964267656207085, 51.5799256414175, 47.494483664631844, 46.41701728105545, 44.101170748472214, 45.993681997060776, 47.99487121403217, 46.14183984696865, 44.0601671487093, 44.012726694345474, 44.10585589706898, 44.680871441960335, 40.14049507677555, 40.77078625559807, 42.734536081552505, 40.68117946386337, 43.40700499713421, 44.71937097609043, 38.291001319885254, 41.45460516214371, 40.08320555090904, 38.702644631266594, 41.323686987161636, 53.105376586318016, 45.62623791396618, 41.72263517975807, 44.396209716796875, 40.192765071988106, 40.658183097839355, 39.96921166777611, 39.899732396006584, 39.49882730841637, 40.59454031288624, 43.97251345217228, 44.68958057463169, 41.50667376816273, 43.938611671328545, 41.39329545199871, 44.52143579721451, 43.91906552016735, 44.20147396624088, 42.75236092507839, 41.43066264688969, 44.73362401127815, 43.16082380712032, 41.76415555179119, 46.14752434194088, 47.422891706228256, 47.14356109499931, 44.52948376536369, 46.894366666674614, 47.37185664474964, 47.23949834704399, 48.26018437743187, 50.72527550160885, 45.79289697110653, 50.61545379459858, 47.135843709111214, 54.524501636624336, 58.89092713594437, 66.09084159135818, 64.48323905467987, 64.31880667805672, 59.66596394777298, 69.57933560013771, 65.21297469735146, 70.3670485317707, 55.242047533392906, 65.65117478370667, 9.228048976510763, 0.944621890084818, 11.379505880177021, 5.824203500524163, 0.8212534943595529, 1.215095235966146, 59.93903249502182, 77.11930900812149, 78.14488157629967, 78.80474656820297, 73.0387231707573, 46.39093928039074, 31.756744645535946, 52.00086325407028, 69.33164209127426, 80.63110336661339, 8.564218897372484, 0.30041591729968786, 0.1547494571423158, 0.18311805208213627, 0.12213585912832059, 0.09845932960161008, 0.13408187631284818], [0.0714656374475453, 0.020274287089705467, 0.08223063050536439, 0.02498723097232869, 0.06282864153035916, 0.05670007878507022, 0.2985705522587523, 0.0458322463236982, 23.91128282994032, 65.46071380376816, 48.51867310702801, 39.8679319024086, 19.754851162433624, 19.884988479316235, 37.03487232327461, 57.56050832569599, 64.72381934523582, 52.31397405266762, 59.403215646743774, 3.9694057032465935, 0.4110464465338737, 0.041333963090437464, 0.4215814999770373, 0.33688760711811483, 7.651078971102834, 69.7729504108429, 54.664911702275276, 61.08069643378258, 57.04829201102257, 54.931152015924454, 47.4558587372303, 57.94437512755394, 45.39863392710686, 54.08948577940464, 53.77621918916702, 51.22743755578995, 45.01980945467949, 42.2819347679615, 39.72514696419239, 40.33408708870411, 40.71366012096405, 41.70034557580948, 40.78817792236805, 41.32999464869499, 39.44160997867584, 40.31685121357441, 38.42931389808655, 38.95041033625603, 37.20432423055172, 37.17259593307972, 36.46537788212299, 37.87452466785908, 35.98940022289753, 36.76041305065155, 35.75808763504028, 36.240718737244606, 36.527379155159, 38.528397381305695, 36.62884511053562, 40.32639630138874, 37.88351498544216, 37.19032198190689, 37.28425294160843, 36.47082298994064, 34.974470883607864, 37.138530761003494, 38.20573389530182, 37.4000783264637, 38.44792149960995, 37.24061228334904, 40.140301287174225, 51.3531956076622, 45.743552818894386, 37.948149517178535, 36.50617629289627, 36.91204011440277, 40.47300383448601, 40.40887087583542, 40.56064613163471, 38.858979642391205, 36.61950521171093, 39.27601106464863, 42.05059178173542, 44.322934448719025, 39.28017944097519, 40.0589020550251, 40.654254108667374, 46.46295301616192, 40.55084265768528, 42.20961704850197, 42.02165633440018, 41.72793589532375, 38.7856587767601, 38.93776461482048, 38.04805375635624, 36.92857302725315, 36.36695556342602, 38.85755471885204, 38.778553158044815, 39.93611164391041, 38.76698277890682, 39.53533574938774, 38.333312049508095, 37.45864078402519, 39.36469830572605, 38.1989436596632, 42.96040736138821, 48.80441777408123, 39.24242466688156, 38.69623817503452, 38.92770275473595, 37.92525574564934, 36.9919840246439, 36.877047792077065, 36.71302579343319, 35.77906250953674, 36.502482891082764, 37.407381534576416, 38.162837997078896, 36.54494181275368, 38.39834935963154, 39.55384835600853, 38.50698933005333, 36.841382905840874, 36.15082696080208, 37.76287145912647, 37.43504025042057, 38.84093441069126, 37.781517058610916, 39.957382902503014, 38.59938517212868, 39.82320450246334, 40.815802440047264, 40.112353786826134, 43.779901787638664, 44.88569185137749, 45.089170932769775, 45.28308592736721, 45.91241575777531, 43.29190917313099, 44.12416711449623, 42.24842056632042, 45.553224831819534, 48.70756097137928, 57.05271117389202, 58.05192455649376, 62.75110960006714, 60.528597459197044, 64.38448995351791, 62.496424466371536, 67.14065685868263, 55.421644896268845, 69.86679017543793, 8.952253125607967, 0.9835937269963324, 3.5620858473703265, 0.9229220857378095, 0.06532519662869163, 1.67006109142676, 52.54564382135868, 66.18745520710945, 66.76903679966927, 66.04847386479378, 57.50051334500313, 34.75405231118202, 22.46732421219349, 39.975709319114685, 49.32614117860794, 53.36823508143425, 3.247039527632296, 0.24667497054906562, 0.05706047682906501, 0.022414216109609697, 0.051294687000336125, 0.025716255622683093, 0.026022328456747346, 0.04178117014816962, 0.017566659626027104, 0.0698963068134617, 0.013277382804517401, 0.07818299418431707, 0.06212148611666635, 0.30522850749548525, 0.01442729795599007, 28.706431724131107, 73.75769779086113, 55.79818569123745, 46.16130620241165, 21.232992745935917, 23.123980276286602, 48.26651483774185, 62.6758698374033, 68.55391502380371, 56.24472253024578, 65.75570717453957, 4.378037676215172, 0.3517025074688718, 0.33743023581337184, 2.088037356734276, 0.5892174609471112, 8.837839365005493, 71.83927953243256, 56.96045212447643, 62.64099910855293, 59.02321323752403, 58.47389571368694, 48.96005742251873, 57.725848853588104, 48.79057511687279, 57.881917878985405, 54.573104828596115, 52.448258846998215, 47.18577302992344, 44.961596578359604, 42.01013535261154, 42.61733517050743, 42.42879308760166, 44.76787157356739, 42.98796348273754, 45.067971870303154, 43.34115073084831, 41.81516021490097, 40.42354188859463, 40.89503958821297, 37.33289793133736, 40.08075848221779, 38.97433765232563, 39.23630319535732, 38.042563050985336, 39.2956256121397, 38.35119768977165, 39.08156409859657, 37.42193475365639, 41.37111984193325, 36.446135714650154, 40.3885305672884, 38.57703097164631, 39.6606720238924, 39.41265173256397, 37.54655286669731, 37.692385241389275, 39.57984656095505, 39.341435953974724, 39.47370305657387, 40.690006390213966, 39.80302378535271, 42.17765316367149, 52.10466988384724, 46.928899213671684, 38.59671771526337, 37.167576402425766, 37.55008287727833, 41.83171592652798, 42.46464416384697, 42.20889508724213, 40.3484883159399, 39.39173765480518, 41.27651631832123, 42.79929980635643, 45.81705987453461, 43.964898660779, 42.31943875551224, 41.08734726905823, 46.96274399757385, 45.111483335494995, 43.76279890537262, 42.719367295503616, 42.98471465706825, 40.91069094836712, 40.621720254421234, 40.54509736597538, 40.75365677475929, 38.73217284679413, 40.12979485094547, 40.586116164922714, 42.082958444952965, 39.5273257791996, 40.129848048090935, 40.32391503453255, 38.95708657801151, 39.63077902793884, 38.28016050159931, 43.1620017439127, 50.33732391893864, 42.7079489082098, 39.92082506418228, 39.92085926234722, 39.300850331783295, 38.79189804196358, 38.28453786671162, 38.03741432726383, 36.63713626563549, 39.988598227500916, 38.73738996684551, 40.03904052078724, 38.51429633796215, 38.9290326833725, 42.61172667145729, 39.92051728069782, 38.17252367734909, 39.68214847147465, 39.66781184077263, 38.57276000082493, 40.15214145183563, 41.43456123769283, 41.03433631360531, 42.590721398591995, 42.842678278684616, 42.83922806382179, 41.91306196153164, 47.05150343477726, 46.54413565993309, 47.01782964169979, 46.56148932874203, 48.57253901660442, 46.7021843791008, 46.87218725681305, 43.365385830402374, 46.63951434195042, 50.72734259068966, 58.995413929224014, 60.29864139854908, 64.00020897388458, 63.12311343848705, 67.01631233096123, 65.22900223731995, 69.43473055958748, 58.44719834625721, 72.3945589363575, 10.330928396433592, 0.6200143333990127, 3.446172592230141, 1.2625575391575694, 0.28551846044138074, 2.049978361465037, 55.54971322417259, 70.5732786655426, 72.830441147089, 70.66776439547539, 63.8775135576725, 37.37945683300495, 27.348730377852917, 49.52414095401764, 58.07729199528694, 65.12466743588448, 4.398561324924231, 0.13103602803312242, 0.05986641474009957, 0.004344156786828535, 0.06441997684305534, 0.035843665900756605, 0.032537294100620784, 0.19400681310798973, 0.15182147675659508, 0.1589083785074763, 0.19686259736772627, 0.18927657161839306, 0.2168744313530624, 0.46161719074007124, 0.15484514966374263, 34.78758171200752, 83.82853299379349, 62.686372473835945, 55.661013051867485, 30.207885056734085, 31.05253793299198, 50.857151225209236, 68.68180096149445, 73.86163741350174, 61.69741854071617, 73.40847373008728, 5.314512625336647, 0.8869044715538621, 0.6537051661871374, 3.6982261296361685, 0.9126393031328917, 10.307210069149733, 74.05287355184555, 57.44627505540848, 65.33069238066673, 60.33086746931076, 61.25150106847286, 50.88848814368248, 59.05562549829483, 47.79662825167179, 57.941266894340515, 56.893378123641014, 56.74493528902531, 49.54463705420494, 47.3625623434782, 44.77029584348202, 45.36399878561497, 44.68973256647587, 48.16234342753887, 45.386326387524605, 48.194915279746056, 45.79616479575634, 44.03227284550667, 42.925779819488525, 43.71098108589649, 41.13691560924053, 43.037436828017235, 41.84987135231495, 42.70756512880325, 40.78438192605972, 43.04151400923729, 42.914391830563545, 41.308370009064674, 39.70495864748955, 43.207698091864586, 39.08067874610424, 44.371959418058395, 40.73084659874439, 41.27497740089893, 41.53498224914074, 39.43050317466259, 38.93641948699951, 41.113379672169685, 42.60102644562721, 40.370629727840424, 44.196424037218094, 41.490722224116325, 41.549402475357056, 56.04315474629402, 49.80222523212433, 39.267955496907234, 38.263665586709976, 38.019528687000275, 43.951295390725136, 43.744058310985565, 44.474793300032616, 41.774217411875725, 41.82527147233486, 44.36820521950722, 45.72824344038963, 46.84021197259426, 44.600247368216515, 47.28268302977085, 46.410572826862335, 49.91281069815159, 45.601014867424965, 45.74101075530052, 44.81018990278244, 46.46129250526428, 43.87401893734932, 43.652183040976524, 43.706748113036156, 42.40456558763981, 40.565502271056175, 42.88018226623535, 43.3805888146162, 43.68572764098644, 40.73989771306515, 42.610890716314316, 40.75240284204483, 39.36523027718067, 41.173697635531425, 40.18046893179417, 45.390958338975906, 53.78052815794945, 44.0624014288187, 43.06012161076069, 42.44632534682751, 41.25975541770458, 41.172333508729935, 40.60601569712162, 40.307123735547066, 38.92658941447735, 40.79460337758064, 41.63071811199188, 41.068051904439926, 41.079276502132416, 41.61175712943077, 44.96769145131111, 43.28620187938213, 40.030042603611946, 41.449217051267624, 43.080028742551804, 42.089767679572105, 43.025535866618156, 44.45156894624233, 43.68364155292511, 44.65208798646927, 45.147045627236366, 48.01701262593269, 45.43012663722038, 48.80581609904766, 48.421162739396095, 50.58749109506607, 49.51683774590492, 50.84508307278156, 48.40362288057804, 50.03098055720329, 45.38774751126766, 50.06267845630646, 52.858667224645615, 61.920865550637245, 62.34007805585861, 67.17611655592918, 67.14615896344185, 68.04304763674736, 67.64524698257446, 71.80948913097382, 59.653234630823135, 73.2730869948864, 13.43277795240283, 1.1727932933717966, 9.191684927791357, 3.910918291658163, 0.778424508171156, 2.337803179398179, 61.51466354727745, 77.44708701968193, 77.9521407186985, 77.303257137537, 73.911422342062, 50.20464263856411, 35.322710797190666, 58.79848189651966, 66.9587454199791, 77.51739844679832, 6.958858240395784, 0.4638725478434935, 0.24965812219306827, 0.13698643451789394, 0.1460939520620741, 0.1174214253842365, 0.1268081908347085], [0.16313315805746242, 0.054379553694161586, 0.016030157894419972, 0.07714256993494928, 0.05181814973184373, 0.02522815251722932, 0.1623477431712672, 0.20793499541468918, 12.649291343986988, 57.29655168950558, 49.152076318860054, 40.11933021247387, 30.207360684871674, 34.59727272391319, 36.677383705973625, 57.63866253197193, 63.425569608807564, 53.40382777154446, 62.21670247614384, 5.430916529148817, 0.4514622950227931, 0.22437067207647488, 1.1715695215389132, 0.502770080929622, 2.005285397171974, 58.1574372947216, 49.35498543083668, 65.38195922970772, 56.10232517123222, 57.98302665352821, 41.186867728829384, 61.33077621459961, 57.73454658687115, 57.50125430524349, 51.21587857604027, 50.327117666602135, 44.36828501522541, 42.473334297537804, 41.94081947207451, 44.25755895674229, 38.74006502330303, 42.086028680205345, 40.44528812170029, 41.814692839980125, 39.518061876297, 39.196515530347824, 35.167705714702606, 36.77496246993542, 37.183345556259155, 35.03071166574955, 34.399128556251526, 37.68344432115555, 36.6887678951025, 36.96752853691578, 35.67767634987831, 36.94930091500282, 35.68968750536442, 37.2225708514452, 34.77276250720024, 36.65572486817837, 36.61022610962391, 37.15377554297447, 34.78197321295738, 36.65776155889034, 35.515504851937294, 37.26376824080944, 36.65124870836735, 36.75714522600174, 37.52250395715237, 36.98064923286438, 39.26122605800629, 50.29921196401119, 45.79262338578701, 38.24592053890228, 36.58424690365791, 36.44595332443714, 38.98062251508236, 38.89188587665558, 38.62374946475029, 38.895176500082016, 36.62578247487545, 38.21633532643318, 39.42565083503723, 35.948886796832085, 37.85614885389805, 42.58924327790737, 45.67617483437061, 45.58480113744736, 41.09993979334831, 42.767731100320816, 41.50411270558834, 40.94949446618557, 39.88493598997593, 37.99243614077568, 35.5202279984951, 37.604651749134064, 37.620200514793396, 38.74850817024708, 37.950866371393204, 41.29062496125698, 38.07883970439434, 36.265698596835136, 36.72652646899223, 36.71198084950447, 37.37654998898506, 37.06172548234463, 43.24542246758938, 47.31017455458641, 37.77346149086952, 37.8628820925951, 36.70508801937103, 38.506187573075294, 36.22831620275974, 38.034731671214104, 36.19190275669098, 35.27618609368801, 37.86391943693161, 37.208238020539284, 37.055866196751595, 36.97237327694893, 39.628533348441124, 38.064316883683205, 36.24795354902744, 37.594928070902824, 36.684173941612244, 37.655702009797096, 37.78751313686371, 37.68602058291435, 39.57888521254063, 38.523845225572586, 38.274571001529694, 39.54269215464592, 40.724656730890274, 39.9197269231081, 40.98232850432396, 41.17638789117336, 43.02733696997166, 43.22034001350403, 44.2098905146122, 41.55017003417015, 43.41641329228878, 41.230337396264076, 43.88766400516033, 41.96680627763271, 48.29068534076214, 51.14898696541786, 57.55094423890114, 54.448429718613625, 61.862227097153664, 59.3770844489336, 67.04133778810501, 61.64183132350445, 70.90203702449799, 18.470597974956036, 0.4981422855053097, 1.5391431539319456, 0.6980832223780453, 0.11646523489616811, 1.6180226462893188, 51.9673490524292, 65.47136843204498, 65.5404107272625, 66.51562839746475, 59.815185740590096, 32.49847814440727, 15.914478935301304, 38.93435999751091, 52.957256734371185, 48.02213855087757, 2.495627710595727, 0.17718284478178248, 0.03998107240477111, 0.12221946206409484, 0.02813548820995493, 0.15046877902932465, 0.03497164980217349, 0.017357194010401145, 0.048628387885401025, 0.08610345394117758, 0.030029358167666942, 0.07544428372057155, 0.08980055165011436, 0.14794485352467746, 0.10721184822614305, 15.349236465990543, 67.03770518302917, 57.77315251529217, 46.336602196097374, 34.11118380725384, 36.565160527825356, 45.41266657412052, 63.1420212239027, 66.8218007683754, 58.43271352350712, 67.01483801007271, 5.8129798527807, 0.5186381482053548, 0.3743792453315109, 4.257852025330067, 0.5466276244260371, 2.904990194365382, 62.017729952931404, 54.30290512740612, 65.86064994335175, 56.023699790239334, 58.768858686089516, 45.18639251589775, 59.46365900337696, 60.4939129203558, 59.673514142632484, 53.997564911842346, 52.36679121851921, 46.34404219686985, 47.58451223373413, 43.59325960278511, 45.29752895236015, 41.94210760295391, 44.391836151480675, 42.76795908808708, 44.64445799589157, 41.30703628063202, 40.98141275346279, 37.641175389289856, 38.8104372471571, 38.43790523707867, 38.192164823412895, 37.31793433427811, 40.39994515478611, 39.05107073485851, 38.937760815024376, 37.783048376441, 39.331636279821396, 38.975815773010254, 39.03464801609516, 38.64640384912491, 38.73029574751854, 38.514334335923195, 39.39496748149395, 37.219386622309685, 39.59332823753357, 35.61265803873539, 39.469010308384895, 36.54257073998451, 38.55512894690037, 39.43521112203598, 38.935503736138344, 41.330606415867805, 52.831285893917084, 47.910595536231995, 38.72153341770172, 36.27919167280197, 36.97949789464474, 41.24392166733742, 40.27759552001953, 40.790856778621674, 40.421155616641045, 39.80369254946709, 40.030479580163956, 42.4679309874773, 39.63164538145065, 40.09509891271591, 44.29057918488979, 47.70211972296238, 45.52745081484318, 43.86347070336342, 44.00135390460491, 43.85489836335182, 41.73470713198185, 41.424966752529144, 40.831290408968925, 38.201219737529755, 38.355248272418976, 38.6421062797308, 39.58826690912247, 39.47948254644871, 42.62933112680912, 39.636269733309746, 36.43910609185696, 37.355483919382095, 37.425996735692024, 37.56759233772755, 37.58702449500561, 43.938372284173965, 50.168229192495346, 39.19969975948334, 40.280840545892715, 38.30331265926361, 40.06669923663139, 39.00545798242092, 40.02315357327461, 37.619934529066086, 38.08365784585476, 40.09338140487671, 38.52763742208481, 39.252459928393364, 39.830351918935776, 40.29992312192917, 40.409562438726425, 38.430537432432175, 39.34294447302818, 41.035635843873024, 40.25703102350235, 39.84837055206299, 40.22339902818203, 41.15328513085842, 40.81457130610943, 40.44879153370857, 43.40981304645538, 44.118425622582436, 43.713625743985176, 44.326339066028595, 42.88788065314293, 44.40264657139778, 45.01868471503258, 46.34930111467838, 42.691856771707535, 46.56566150486469, 44.60834853351116, 44.58158276975155, 43.39799948036671, 51.55881017446518, 53.67267854511738, 59.81599509716034, 57.08890803158283, 66.26986518502235, 61.09556503593922, 68.64710882306099, 63.41836519539356, 75.2500069141388, 22.008128352463245, 0.5647242127452046, 3.2317168498411775, 1.5990471770055592, 0.4302066215313971, 1.5787524660117924, 58.70824433863163, 70.9844546020031, 70.1590932905674, 74.55117881298065, 64.52011987566948, 39.07538183033466, 23.189152479171753, 46.00241392850876, 59.74974945187569, 60.20595297217369, 3.8824271829798818, 0.29788792482577264, 0.009230486775777536, 0.0567651725577889, 0.0635835318826139, 0.03263237806095276, 0.04137648815230932, 0.22025429061613977, 0.12255830442882143, 0.19925122935092077, 0.11529703508131206, 0.19761924660997465, 0.23142932768678293, 0.43982832867186517, 0.35948425240349025, 18.700225353240967, 76.45518824458122, 65.11562392115593, 53.776032999157906, 43.13138298690319, 44.94286358356476, 51.66034832596779, 68.20674285292625, 74.35308784246445, 63.257497027516365, 74.99847561120987, 6.164069613441825, 0.6794198113493621, 0.7394827133975923, 6.2629227340221405, 1.159526186529547, 3.328088941052556, 66.97131514549255, 55.78350707888603, 67.29363664984703, 57.816496789455414, 59.41979415714741, 45.9343595802784, 62.108043506741524, 59.66260872781277, 63.60384464263916, 56.44510097801685, 55.22758170962334, 49.09924775362015, 47.47620664536953, 46.28636509180069, 49.06170576810837, 44.85736057162285, 47.226073667407036, 45.857892483472824, 45.75733847916126, 44.124539494514465, 45.80964267253876, 40.09530410170555, 41.60410813987255, 42.73355193436146, 40.225135535001755, 38.872278928756714, 42.43152514100075, 40.328679978847504, 43.75877112150192, 40.89737266302109, 42.029088735580444, 40.031543523073196, 42.92693875730038, 38.78429464995861, 40.30330114066601, 39.405724704265594, 41.335527151823044, 39.45355273783207, 40.60533553361893, 37.579322308301926, 42.93078415095806, 38.81471201777458, 39.707812294363976, 40.761951729655266, 42.2532919049263, 43.21462891995907, 56.02433815598488, 50.59407614171505, 40.55325172841549, 37.22718000411987, 38.54076191782951, 42.245973497629166, 40.7728723436594, 42.611456885933876, 42.1780901402235, 41.01129435002804, 44.47527967393398, 42.268646880984306, 40.05637899041176, 45.24425581097603, 44.96979273855686, 50.29768064618111, 47.98185311257839, 44.45043660700321, 47.451059594750404, 45.624467208981514, 44.53048691153526, 45.23661822080612, 43.24872829020023, 39.63170237839222, 40.2517569065094, 42.17228025197983, 41.58496096730232, 42.24003441631794, 44.95769038796425, 40.224527567625046, 37.0305747538805, 38.12724530696869, 38.431027606129646, 39.01539824903011, 38.89856971800327, 45.68975530564785, 53.47962990403175, 41.085656359791756, 42.52364359796047, 39.407252222299576, 41.5313458442688, 40.370914712548256, 41.59487463533878, 39.221761375665665, 38.183109909296036, 41.34935840964317, 40.55723391473293, 40.853200033307076, 42.3086891323328, 43.30749973654747, 42.9156381636858, 41.48363560438156, 41.8641471862793, 41.98430813848972, 42.452822998166084, 40.98621189594269, 43.28727342188358, 43.9149085432291, 42.74752378463745, 41.91471107304096, 44.64248590171337, 44.24311973154545, 45.775425508618355, 47.59496547281742, 46.14725075662136, 48.37336890399456, 46.587392538785934, 51.23552352190018, 45.601322650909424, 48.80103215575218, 47.095128893852234, 49.04467888176441, 45.69851003587246, 54.37244139611721, 56.426717564463615, 63.220631405711174, 58.05835761129856, 69.21894773840904, 63.55832688510418, 72.48798832297325, 64.37291577458382, 77.45084881782532, 25.55009499192238, 0.47452869010157883, 12.867898363620043, 3.5779445338994265, 0.8836384874302894, 2.0028753764927387, 63.26486483216286, 78.54029595851898, 74.7711718082428, 79.47169438004494, 73.71593803167343, 47.441396713256836, 28.040129877626896, 56.560086607933044, 67.33522921800613, 74.94083270430565, 5.935146622359753, 0.3972474572947249, 0.11297216842649505, 0.26002892351243645, 0.1417755283182487, 0.37591448170132935, 0.18151030788430944], [0.08583139744587243, 0.018936833075713366, 0.07309167558560148, 0.021086478664074093, 0.06510972147225402, 0.016241235825873446, 0.10698391983169131, 0.1614241997594945, 5.304333921521902, 56.04972839355469, 51.73659883439541, 35.183638259768486, 16.145077161490917, 23.213856853544712, 49.99414153397083, 53.0907017737627, 62.549838200211525, 50.16811139881611, 61.649461314082146, 6.500994684174657, 0.5174197792075574, 0.31306754623074085, 2.2197568137198687, 0.915267396485433, 0.9540202107746154, 47.772921323776245, 52.81803220510483, 63.90843629837036, 56.36481508612633, 63.16312909126282, 51.71731486916542, 57.71797187626362, 53.123178631067276, 54.75855387747288, 49.08321641385555, 48.38942304253578, 42.566478699445724, 41.322459653019905, 39.904827922582626, 40.61458803713322, 38.43775324523449, 41.65228575468063, 40.75396075844765, 40.20734868943691, 36.8447495251894, 35.88670313358307, 37.20487520098686, 37.590847089886665, 36.17001973092556, 36.72055318951607, 36.19599133729935, 38.218645602464676, 36.85362584888935, 37.2940906137228, 37.04458460211754, 36.637645438313484, 36.00421942770481, 38.501943200826645, 37.40624159574509, 36.943814009428024, 36.434508338570595, 36.848826706409454, 34.2012769728899, 36.53705343604088, 37.25762777030468, 37.45002664625645, 36.71305999159813, 37.47743837535381, 39.396274611353874, 39.296811148524284, 39.08053815364838, 49.66349847614765, 47.77314931154251, 39.026649445295334, 37.22169689834118, 35.922577008605, 35.73628820478916, 38.470773473381996, 37.84566521644592, 38.78416545689106, 37.17921517789364, 36.57426483929157, 34.593450129032135, 36.94278046488762, 40.233187302947044, 38.84272791445255, 41.7476986348629, 43.504329174757004, 41.25396452844143, 39.5966112613678, 40.62981761991978, 39.222935512661934, 37.714887633919716, 37.41216167807579, 38.346345350146294, 36.05141669511795, 41.07152871787548, 38.564807027578354, 40.227468609809875, 37.39324249327183, 39.52664941549301, 34.66667599976063, 37.26995810866356, 37.75510087609291, 38.43622952699661, 35.440626069903374, 45.34082382917404, 47.646232321858406, 38.139537647366524, 38.30446019768715, 37.41602227091789, 37.580162063241005, 38.43732386827469, 37.308184057474136, 35.50362288951874, 36.60959914326668, 36.08920946717262, 38.177467212080956, 40.054087713360786, 38.19867007434368, 37.66074053943157, 39.382967725396156, 37.33193278312683, 35.95714375376701, 36.70182019472122, 37.00500972568989, 36.79299250245094, 37.09910787642002, 38.448966443538666, 37.02373132109642, 39.98066425323486, 39.09032642841339, 39.77800592780113, 40.16139775514603, 41.98404975235462, 40.72858951985836, 40.6893490254879, 39.485706612467766, 41.63814291357994, 40.20745508372784, 42.90565609931946, 41.87922477722168, 42.95712053775787, 40.93975938856602, 44.12020392715931, 43.67824964225292, 51.17702566087246, 50.64065404236317, 56.15904472768307, 58.035095259547234, 62.25528180599213, 58.380599319934845, 72.75173217058182, 29.121812134981155, 0.2378156123450026, 1.23201216571033, 1.186281619593501, 0.2255766323651187, 1.7842918680980802, 58.351306691765785, 67.001021951437, 66.63917496800423, 64.26398321986198, 59.61734175682068, 37.36739628016949, 20.17535749822855, 42.418153658509254, 50.90577721595764, 45.49725383520126, 2.293165074661374, 0.242751027981285, 0.0725393247557804, 0.012114807541365735, 0.0428795153129613, 0.015316784210881451, 0.006364755417962442, 0.05301140816300176, 0.04024333626148291, 0.025901224798872136, 0.05243255895038601, 0.10457700132974423, 0.06391215487383306, 0.130840472120326, 0.16306223842548206, 6.554770348593593, 63.74373033642769, 58.85161444544792, 42.57576920092106, 21.789041608572006, 28.246608898043633, 54.23782221972942, 60.696198865771294, 67.47278943657875, 55.511855855584145, 68.86739060282707, 7.240150971338153, 0.42452304682228714, 0.13968743645818904, 3.873524498194456, 0.4611483315238729, 1.0489236214198172, 54.652269780635834, 54.54297624528408, 66.37995287775993, 55.94176098704338, 65.03416389226913, 54.9656617641449, 59.80499088764191, 55.63630297780037, 57.14825704693794, 51.526777893304825, 51.86236068606377, 44.76097114384174, 43.84148508310318, 41.68864220380783, 42.72453121840954, 42.69273452460766, 43.15424636006355, 41.11441321671009, 42.73649297654629, 39.32254336774349, 39.37982529401779, 39.316630885005, 40.36550760269165, 39.778412505984306, 39.22884039580822, 38.86079974472523, 40.25490313768387, 36.918697357177734, 39.873380810022354, 38.95365156233311, 37.51655347645283, 37.24224619567394, 40.72286702692509, 39.744248539209366, 39.3465580791235, 38.08023422956467, 36.89399488270283, 36.94665625691414, 38.961889520287514, 37.230877205729485, 38.22652257978916, 38.38332116603851, 41.16496190428734, 40.243674740195274, 40.422417148947716, 41.037771329283714, 51.77305407822132, 50.083109959959984, 39.75460298359394, 38.2612869143486, 37.283040806651115, 37.60823115706444, 39.8658762127161, 38.885057643055916, 41.357668563723564, 38.341458812355995, 39.53295707702637, 38.55581670999527, 39.49022836983204, 43.16549755632877, 41.889788210392, 42.945553958415985, 45.03623977303505, 44.03896428644657, 42.21165753901005, 41.840770840644836, 42.42034614086151, 40.49136824905872, 39.964758306741714, 40.67249312996864, 38.52971591055393, 41.708051562309265, 40.48514798283577, 41.3397791236639, 38.718235194683075, 40.708990171551704, 36.46045334637165, 38.092811554670334, 37.918625101447105, 39.68899950385094, 36.01545162498951, 44.82940547168255, 52.00323052704334, 39.09758023917675, 39.688965305686, 38.73911887407303, 39.863793924450874, 39.27989445626736, 39.54474784433842, 38.12194839119911, 40.04969894886017, 40.465575233101845, 40.825180336833, 40.52730292081833, 38.649360090494156, 38.73881869018078, 41.307059079408646, 38.96751321852207, 37.98561550676823, 40.76229751110077, 38.71272549033165, 38.37252974510193, 38.9340940117836, 40.39852023124695, 39.87871952354908, 41.92036896944046, 41.480930149555206, 41.32650263607502, 41.680894419550896, 44.01930034160614, 41.73197127878666, 43.662560284137726, 42.274038791656494, 43.919608891010284, 42.1823763102293, 44.346105605363846, 43.52515205740929, 44.68929938971996, 44.87471804022789, 46.39780551195145, 45.020406022667885, 52.852948531508446, 52.65929952263832, 58.53909641504288, 60.69891571998596, 66.01405531167984, 61.83146394789219, 75.23211747407913, 34.957364201545715, 0.18396997824311256, 0.5760897591244429, 1.6317790956236422, 0.2827428578166291, 2.2413797909393907, 62.60587379336357, 72.19383090734482, 71.9037164747715, 69.91395324468613, 65.3526172041893, 37.02907383441925, 20.28264284133911, 46.50911673903465, 57.90488764643669, 55.628908574581146, 3.31520383246243, 0.25487078935839236, 0.01137768049375154, 0.11214565340196714, 0.021008089315728284, 0.022935175948077813, 0.05201507490710355, 0.22619683033553883, 0.16683862719219178, 0.1551744999596849, 0.14152545423712581, 0.19485817523673177, 0.14831735228653997, 0.25442461017519236, 0.2743290108628571, 7.3979636281728745, 76.1070129275322, 67.34747976064682, 48.62819463014603, 26.91421989351511, 32.456034421920776, 61.63543626666069, 66.07776269316673, 72.66721710562706, 58.77404160797596, 75.68263649940491, 8.272921778261662, 0.5902710137888789, 0.9744081948883832, 10.622172318398952, 2.3439557617530227, 2.208579475991428, 59.37050320208073, 55.289989560842514, 69.33908969163895, 58.24454762041569, 67.06054955720901, 54.49513681232929, 62.28134460747242, 55.1292771846056, 61.24408386647701, 52.03640274703503, 54.43389929831028, 48.44961181282997, 46.64844386279583, 45.3996142745018, 45.499149933457375, 43.48284512758255, 46.16566076874733, 44.45063039660454, 45.74962489306927, 40.68492226302624, 39.981488808989525, 41.474326103925705, 43.49050551652908, 41.44321337342262, 40.60707204043865, 40.27548283338547, 43.5657224804163, 39.0487452596426, 42.937999963760376, 41.48082755506039, 39.942977875471115, 39.79646533727646, 43.05931605398655, 41.79514288902283, 40.942046865820885, 39.67937082052231, 40.524255484342575, 38.12448285520077, 41.273005306720734, 40.16628049314022, 41.99788101017475, 41.935233771800995, 42.55108952522278, 44.05852943658829, 44.79983925819397, 43.622385039925575, 53.89597736299038, 52.48612001538277, 39.06811662018299, 38.6745223402977, 37.913575172424316, 38.092727959156036, 41.46052524447441, 39.437821581959724, 43.41318726539612, 41.12687274813652, 40.783526971936226, 40.73040582239628, 42.005412206053734, 43.15486952662468, 43.55493485927582, 47.1673022210598, 47.13798679411411, 47.810368314385414, 44.33232754468918, 43.774517476558685, 45.21578013896942, 42.7982434630394, 41.449585631489754, 43.4035661816597, 41.64782099425793, 45.08822478353977, 43.73549357056618, 44.013437256217, 40.52574880421162, 42.50079162418842, 36.75284385681152, 38.04537110030651, 37.83842280507088, 39.12711605429649, 35.724372044205666, 48.54295000433922, 54.19177249073982, 41.53917722404003, 43.12455095350742, 40.734699591994286, 42.090641632676125, 43.78230705857277, 41.49937815964222, 38.81447263062, 41.470594704151154, 41.76650382578373, 42.06236355006695, 43.807978481054306, 40.267480462789536, 42.041833251714706, 43.44355143606663, 40.591029301285744, 40.67984953522682, 44.08771947026253, 40.82817457616329, 41.3786244392395, 41.04774199426174, 43.078315034508705, 41.05955556035042, 42.94445961713791, 42.4398010969162, 44.62498024106026, 43.98645110428333, 48.331491351127625, 45.47380909323692, 45.03160402178764, 43.63357923924923, 46.23474486172199, 45.00171482563019, 48.6131626367569, 46.71879708766937, 47.09800533950329, 47.70127236843109, 50.95660328865051, 49.03279311954975, 57.10299387574196, 57.85854533314705, 59.38022308051586, 63.77271518111229, 67.73879036307335, 64.64898616075516, 76.72096118330956, 39.45416830480099, 1.0035417065955698, 6.835928186774254, 3.3841233467683196, 0.8116422069724649, 3.033154704608023, 67.98872575163841, 76.5379250049591, 77.72802114486694, 76.79667592048645, 74.80399444699287, 49.531949535012245, 32.35307514667511, 58.945720195770264, 66.64957880973816, 70.01270234584808, 4.999873358756304, 0.4195487278047949, 0.1325195812387392, 0.1567601429997012, 0.11395112058380619, 0.10728367327828892, 0.17476675333455205], [0.062425833457382396, 0.028859364210802596, 0.023267834367288742, 0.006888650450491696, 0.07702365561272018, 0.037955361767672, 0.08449199158349074, 0.01015938014461426, 1.496689694467932, 43.08910645544529, 54.192821234464645, 44.15695175528526, 32.51233220100403, 29.57253634929657, 36.466795206069946, 44.61655229330063, 60.46569563448429, 52.93093554675579, 62.67319858074188, 12.400641236454248, 0.4720841150265187, 0.06793823922635056, 2.6265024254098535, 0.1730062603019178, 1.281138185877353, 54.57879692316055, 61.461834982037544, 64.65929120779037, 56.29544980823994, 59.04292277991772, 57.47826173901558, 55.71124255657196, 54.570866748690605, 52.04961083829403, 46.7435185611248, 45.50359949469566, 42.06081323325634, 41.21290773153305, 39.023100435733795, 40.629403442144394, 40.0318057090044, 38.22486586868763, 37.6090557128191, 36.24554827809334, 37.221453711390495, 38.00352394580841, 37.88775935769081, 39.001293405890465, 36.49628922343254, 36.355426982045174, 36.5557674318552, 35.85620976984501, 36.7459624260664, 36.39374792575836, 37.441021129488945, 34.854271933436394, 37.04551935195923, 36.759577095508575, 37.66684301197529, 35.27790740132332, 37.169761285185814, 36.801587641239166, 34.59595039486885, 37.94305019080639, 37.1916139125824, 34.8003414273262, 36.22757904231548, 36.39921963214874, 37.346865981817245, 37.3812161386013, 40.1908765733242, 47.36709550023079, 48.502763360738754, 43.58782209455967, 37.082825750112534, 38.347812071442604, 36.3236378878355, 38.69396589696407, 39.69135917723179, 39.0861314535141, 37.19020798802376, 38.14856976270676, 34.58513617515564, 37.64201894402504, 36.99591301381588, 40.02892546355724, 38.82332615554333, 40.78663520514965, 39.52437333762646, 39.34558913111687, 40.91612845659256, 39.64504346251488, 38.12034487724304, 37.26298548281193, 37.66140550374985, 38.11670087277889, 37.69400015473366, 39.33080792427063, 39.75631669163704, 36.835759207606316, 35.828079879283905, 35.50296172499657, 37.56087429821491, 38.04552689194679, 38.53935979306698, 37.239099964499474, 44.612038135528564, 43.63178193569183, 36.457052528858185, 38.115674927830696, 37.14198477566242, 38.93827758729458, 36.6975150257349, 37.01643951237202, 35.37949115037918, 36.16311550140381, 35.43625630438328, 38.07618744671345, 39.44281071424484, 38.54442112147808, 35.664559453725815, 37.84954860806465, 38.12053486704826, 36.46734617650509, 38.16189184784889, 37.29850597679615, 35.7964313775301, 36.961281672120094, 36.524084731936455, 37.42326848208904, 37.77748167514801, 38.37282232940197, 38.15036326646805, 38.50686393678188, 39.230842888355255, 40.90514324605465, 41.0737743973732, 40.076476112008095, 41.13369718194008, 41.122366189956665, 41.84690751135349, 41.66982941329479, 44.057746678590775, 42.44780346751213, 44.67627368867397, 44.61633950471878, 48.82664658129215, 47.147516682744026, 53.15688282251358, 54.55531418323517, 64.47981163859367, 59.69764284789562, 71.89221069216728, 31.29219677299261, 0.3931673668557778, 1.0396649432368577, 1.8821803154423833, 0.2875409316038713, 2.481993092224002, 58.945237621665, 67.00748160481453, 67.30639636516571, 61.93464361131191, 57.875838205218315, 38.84289130568504, 24.42561373114586, 38.358865678310394, 60.87635859847069, 41.46875560283661, 1.3916220073588192, 0.06892072400660254, 0.029796106719004456, 0.03679082074086182, 0.028501561828306876, 0.044764410849893466, 0.055068485671654344, 0.06287213880568743, 0.03726409573573619, 0.04573541460558772, 0.07359631374129094, 0.01367573335301131, 0.018810812689480372, 0.11882168735610321, 0.11160691356053576, 2.4231280758976936, 50.54913975298405, 61.71092301607132, 48.89612965285778, 31.47707775235176, 22.669815346598625, 46.31650507450104, 52.008831426501274, 69.18711304664612, 57.30217158794403, 70.30856966972351, 13.521584887057543, 0.474750503199175, 0.5640755756758153, 3.4010739997029305, 0.39492690993938595, 1.2049238942563534, 59.265131056308746, 63.140934482216835, 66.50397062301636, 57.7796995639801, 61.85073271393776, 57.01604314148426, 58.727114126086235, 57.01156698167324, 52.30922810733318, 48.89498211443424, 47.01953575015068, 42.5811231136322, 43.07827703654766, 41.35908588767052, 43.14642257988453, 41.55722625553608, 40.60793079435825, 39.90062914788723, 38.19966942071915, 39.30905029177666, 40.494491681456566, 39.44762125611305, 41.903231889009476, 39.96210224926472, 39.851121604442596, 39.42160785198212, 38.13036873936653, 39.65473294258118, 38.87400023639202, 38.80907692015171, 37.1626290678978, 38.53026308119297, 38.13417233526707, 39.07952360808849, 36.823539063334465, 38.73719997704029, 38.62947955727577, 36.843681782484055, 40.13926014304161, 38.44197101891041, 36.707371696829796, 38.587583005428314, 38.40481661260128, 39.12387102842331, 38.388724476099014, 43.50473955273628, 50.81324838101864, 50.462287813425064, 45.965434312820435, 37.744678035378456, 37.61555336415768, 37.27536901831627, 39.48636397719383, 41.05608634650707, 40.70365905761719, 39.29418928921223, 40.31526669859886, 38.095779195427895, 39.89269517362118, 37.83990852534771, 41.671288534998894, 40.21947003901005, 42.34443001449108, 41.9818040728569, 41.1065324395895, 41.460304856300354, 41.30939595401287, 39.46539290249348, 39.84387159347534, 39.82313230633736, 41.61454997956753, 40.134316608309746, 40.7655843347311, 41.146582290530205, 38.77115495502949, 36.487948670983315, 36.33517026901245, 39.09434661269188, 38.390764966607094, 38.52255329489708, 37.61328488588333, 45.96460975706577, 46.30475990474224, 37.59137526154518, 42.14312061667442, 39.587803333997726, 38.67570027709007, 38.60522925853729, 39.46759298443794, 37.67867937684059, 38.55022720992565, 38.111232966184616, 39.27086994051933, 41.38143628835678, 39.949752911925316, 37.95742481946945, 40.233555883169174, 40.082882568240166, 38.661527037620544, 41.04893513023853, 39.18406739830971, 39.312470108270645, 40.45076362788677, 38.70251923799515, 40.80443724989891, 40.75078032910824, 40.81410773098469, 40.73635630309582, 40.80104023218155, 41.5416394919157, 41.948320269584656, 41.882238015532494, 43.14119026064873, 43.35898697376251, 43.365781009197235, 43.65520007908344, 44.287185966968536, 45.52627667784691, 45.63210479915142, 48.447350934147835, 47.94377915561199, 51.8653055280447, 50.19189052283764, 55.66464185714722, 57.44559109210968, 66.87188968062401, 61.90592095255852, 75.03437608480453, 41.089197769761086, 1.4101572940126061, 1.578938893508166, 2.5350201968103647, 0.09872770504443906, 2.1717392653226852, 64.62661296129227, 70.46452090144157, 72.64330878853798, 66.79482221603394, 64.30957317352295, 40.13892576098442, 31.89358100295067, 46.10215097665787, 66.66936054825783, 52.1364513784647, 1.7781730089336634, 0.2155899815261364, 0.058762874541571364, 0.029673223762074485, 0.0398426173342159, 0.017209630932484288, 0.05423838236310985, 0.20370346232084557, 0.10975438679452054, 0.22122739464975893, 0.19415591057622805, 0.1711912639439106, 0.06466475198976696, 0.26246708643157035, 0.18471274932380766, 2.2592402575537562, 58.94521862268448, 72.30600088834763, 58.5403161495924, 45.81232912838459, 39.97716464102268, 48.46557475626469, 60.03483675420284, 74.08160760998726, 62.45469130575657, 76.42029851675034, 15.704463254660368, 0.762062348658219, 1.3957534544169903, 10.065618082880974, 1.1829449236392975, 2.285755234770477, 62.813764438033104, 64.3560066819191, 69.42726776003838, 61.97896063327789, 64.59128245711327, 59.37316685914993, 60.11482626199722, 59.913440868258476, 57.374755293130875, 50.53537309169769, 49.52094912528992, 45.19576661288738, 45.89464411139488, 44.14479240775108, 45.98585061728954, 45.02614751458168, 42.78828799724579, 42.22649194300175, 40.87375693023205, 40.89001625776291, 42.36412815749645, 42.8965175896883, 44.924320578575134, 41.68993413448334, 40.84805890917778, 41.85461729764938, 40.811052694916725, 43.38816940784454, 41.957177594304085, 42.41694912314415, 39.95395548641682, 41.65810704231262, 41.53711773455143, 41.25361494719982, 38.376264944672585, 41.96433261036873, 42.284845411777496, 37.79637426137924, 42.280555441975594, 40.68233460187912, 38.82679916918278, 39.55384835600853, 39.97877575457096, 41.44748814404011, 41.86591409146786, 44.68445084989071, 53.082471415400505, 52.783009484410286, 46.18968307971954, 37.56049431860447, 39.88815441727638, 38.3083625882864, 41.363140270113945, 43.862566351890564, 42.26777672767639, 41.88254959881306, 42.34349526464939, 38.86190928518772, 41.93394564092159, 41.34890243411064, 44.52396646142006, 42.22215257585049, 46.2076523154974, 42.57818587124348, 43.25707644224167, 45.35247400403023, 41.92082114517689, 42.53893777728081, 41.55126817524433, 41.66193723678589, 43.460494726896286, 42.16199800372124, 41.731462106108665, 42.91610173881054, 39.37489315867424, 38.09809327125549, 36.67469345033169, 39.11268062889576, 38.04492652416229, 38.41465048491955, 39.03963714838028, 47.793425023555756, 48.9122673869133, 42.396502420306206, 44.30911839008331, 41.729395017027855, 42.55824074149132, 39.266249388456345, 41.692761182785034, 38.85752812027931, 39.80203963816166, 38.7145721912384, 41.70346900820732, 43.38356025516987, 41.974569261074066, 39.86822068691254, 42.35711373388767, 42.498169764876366, 40.48243872821331, 42.794021889567375, 43.06884594261646, 40.100984796881676, 42.7798068523407, 40.27367413043976, 43.29273372888565, 43.686548396945, 44.45964351296425, 43.13658870756626, 43.3751817047596, 42.83006675541401, 44.42812040448189, 46.01546622812748, 45.62046222388744, 45.55971868336201, 45.996889024972916, 46.60274751484394, 47.32837177813053, 48.03868666291237, 48.097484707832336, 50.11799968779087, 51.081829369068146, 52.42788054049015, 52.826475352048874, 56.94254368543625, 61.216877326369286, 68.34780648350716, 65.39190709590912, 73.81749138236046, 49.91109699010849, 1.7777132336050272, 3.922029845416546, 6.878613671287894, 1.040166278835386, 2.844667243771255, 69.45742294192314, 78.36381062865257, 76.67095586657524, 71.25161066651344, 72.090575248003, 53.70908819139004, 36.53447337448597, 56.14413432776928, 76.12428680062294, 63.91686424612999, 3.3307167375460267, 0.44065392343327403, 0.15325549902627245, 0.17317799327429384, 0.1473541188170202, 0.10648634692188352, 0.18715532060014084], [0.04091295013495255, 0.017484162490291055, 0.05621630611130968, 0.015168755435297498, 0.07056291869957931, 0.0243617136584362, 0.05952038838586304, 0.11185804891283624, 0.298313531675376, 31.121920309960842, 64.87375169992447, 44.19427715241909, 30.24197682738304, 29.571402110159397, 35.02873197197914, 41.46361827850342, 63.978884518146515, 51.23454697430134, 62.63795927166939, 18.50401148200035, 0.4105388472089544, 0.0659549015108496, 3.1463005207479, 0.060547112589119934, 3.901684074662626, 66.14802092313766, 58.79267580807209, 57.996740117669106, 54.0739294141531, 55.80711901187897, 57.066246047616005, 55.27301587164402, 49.21502374112606, 49.33497950434685, 43.67463603615761, 43.67946557700634, 40.91539889574051, 41.30294390022755, 39.650906547904015, 39.210631772875786, 38.94709691405296, 38.42270605266094, 36.865796595811844, 38.37115041911602, 37.84006051719189, 38.852497190237045, 37.45106019079685, 38.02009865641594, 36.59427456557751, 37.84993998706341, 35.44805847108364, 35.36516971886158, 35.99578768014908, 36.431970074772835, 35.92980422079563, 36.935120075941086, 34.91389833390713, 36.41742445528507, 37.92870596051216, 37.20654711127281, 35.90447098016739, 35.957215949893, 36.94677785038948, 35.09235955774784, 35.25356210768223, 36.859409138560295, 37.25950486958027, 38.40396925806999, 37.55250334739685, 37.64130838215351, 39.40449737012386, 48.56216177344322, 48.33748362958431, 44.852135851979256, 38.47497224807739, 36.09077498316765, 36.754629760980606, 38.90106998383999, 37.586009949445724, 38.27908135950565, 36.62670582532883, 38.14786680042744, 34.855560064315796, 34.544596150517464, 37.20693089067936, 37.745491191744804, 36.81206367909908, 38.03609199821949, 39.512434378266335, 37.72659480571747, 38.386391401290894, 37.1200143545866, 37.249606400728226, 37.93237276375294, 39.060148447752, 37.29418180882931, 40.24662338197231, 40.44044718146324, 37.97522686421871, 37.08713851869106, 36.86016149818897, 37.91196785867214, 39.2701555788517, 37.641448974609375, 39.21983487904072, 37.6225221902132, 47.20077462494373, 43.484444841742516, 35.73223762214184, 38.82966421544552, 37.87812687456608, 37.32257768511772, 37.065521478652954, 38.0758910626173, 37.405082657933235, 39.06313128769398, 36.842260658741, 36.25289708375931, 38.54141168296337, 38.138800486922264, 37.282767221331596, 37.60104574263096, 37.0332346111536, 36.4303969591856, 37.23145477473736, 36.53643786907196, 37.312025651335716, 39.037026688456535, 38.29803854227066, 38.222563192248344, 39.05221067368984, 38.936499282717705, 39.611118882894516, 39.45239380002022, 39.28348906338215, 37.53098890185356, 39.767966866493225, 41.210278272628784, 40.70927135646343, 42.21183232963085, 42.75522977113724, 41.19133248925209, 44.63128790259361, 44.23658028244972, 46.306709200143814, 45.60528963804245, 49.9416359513998, 46.09565332531929, 54.80523817241192, 52.665090411901474, 64.21930521726608, 57.63611666858196, 75.94415366649628, 30.127749256789684, 3.0072085093706846, 1.1527127958834171, 1.4068696391768754, 0.09966746438294649, 3.256295118480921, 62.68072597682476, 64.83924195170403, 66.72565072774887, 61.2738286703825, 53.35009105503559, 35.304726362228394, 18.142502680420876, 33.85560192167759, 59.115381091833115, 36.44903875887394, 1.1547247879207134, 0.13606421212898567, 0.07129573757993057, 0.06420268342480995, 0.027743380051106215, 0.12587979377713054, 0.011969990409852471, 0.062424824136542156, 0.027919209678657353, 0.12450310241547413, 0.06375162833137438, 0.07031273329630494, 0.06914161684107967, 0.10595748506602831, 0.0596737272280734, 0.5004848598036915, 38.58369581401348, 71.59970998764038, 50.8061807602644, 36.91569171845913, 32.07018792629242, 38.143698424100876, 50.16448639333248, 69.25515219569206, 56.632617115974426, 69.68568429350853, 19.562636576592922, 0.41057592490687966, 0.1849543777643703, 3.2133536227047443, 0.3728885675081983, 4.643642473965883, 68.4215073287487, 62.709114253520966, 61.580593809485435, 56.8001539260149, 59.00825724005699, 59.38452064990997, 58.27830880880356, 50.1248849183321, 51.72399491071701, 44.14887718856335, 46.98507159948349, 44.15762051939964, 42.43578091263771, 41.74147456884384, 41.53351552784443, 42.128973975777626, 40.42959116399288, 38.86696681380272, 39.363569766283035, 40.00586450099945, 41.063241362571716, 38.70477631688118, 39.8770210146904, 39.42153185606003, 40.40403373539448, 38.579763025045395, 38.81912358105183, 38.11993829905987, 38.88697274029255, 37.50836491584778, 37.732267901301384, 37.51036740839481, 38.54676179587841, 39.58208844065666, 39.20614421367645, 39.10340532660484, 37.96573117375374, 37.80648171901703, 36.92671112716198, 37.13862955570221, 40.13324126601219, 38.93336825072765, 39.90542829036713, 39.7862134873867, 39.32604677975178, 40.97888208925724, 51.253298968076706, 50.15421934425831, 45.520588383078575, 39.84912671148777, 36.10130421817303, 36.87519729137421, 39.22991953790188, 38.687966018915176, 40.10792322456837, 37.871435433626175, 39.686297848820686, 36.50087557733059, 37.22427695989609, 37.9481191188097, 39.806648790836334, 40.17323412001133, 39.38501961529255, 42.389461398124695, 40.54424241185188, 40.916998609900475, 39.82031665742397, 38.3404366672039, 39.60104942321777, 38.976169154047966, 38.52451778948307, 40.62292478978634, 41.50657117366791, 38.207633793354034, 37.309536784887314, 38.36149513721466, 37.48006023466587, 38.54841090738773, 38.179500102996826, 40.092306062579155, 38.21950815618038, 49.89038810133934, 47.410508170723915, 37.83917896449566, 40.892037749290466, 39.98246915638447, 38.467137068510056, 38.71478118002415, 38.81437383592129, 39.65637065470219, 39.537919610738754, 37.844722867012024, 38.287110328674316, 39.06052462756634, 40.84359414875507, 39.187700003385544, 40.1599158346653, 39.45125386118889, 36.6181904822588, 39.71159689128399, 37.83399984240532, 38.47550421953201, 41.44008994102478, 40.54791681468487, 40.740581676363945, 41.506354585289955, 42.53522917628288, 41.75014950335026, 42.49388359487057, 42.13471546769142, 40.08998438715935, 41.96933314204216, 44.02716211974621, 43.94341841340065, 43.956447914242744, 43.85803699493408, 43.87976422905922, 47.420258447527885, 47.13794879615307, 49.02646265923977, 49.54093985259533, 50.15581525862217, 49.873961582779884, 56.85867078602314, 55.84306128323078, 65.7827541232109, 59.52964626252651, 74.99881759285927, 40.23062624037266, 2.9537648521363735, 1.512497083749622, 1.02487898664549, 0.5524614395108074, 4.024180714040995, 67.5163123011589, 70.32955214381218, 73.49050372838974, 65.0274458527565, 60.655271261930466, 42.9401620477438, 21.912951059639454, 42.69544757902622, 67.44099274277687, 46.20166003704071, 1.6845175344496965, 0.10472200214280747, 0.04779500057338737, 0.10146741740754806, 0.05952474479272496, 0.02290268657816341, 0.010517839327803813, 0.18713081488385797, 0.11050119515857659, 0.328668529400602, 0.13409792154561728, 0.19880469393683597, 0.18731617368757725, 0.21007938659749925, 0.19798043504124507, 0.628403986338526, 46.01236179471016, 84.21651497483253, 58.647459000349045, 44.524426236748695, 37.51980610191822, 46.230922266840935, 57.11329512298107, 74.533471763134, 59.64516006410122, 74.6228201687336, 22.156856171786785, 0.5940130411181599, 0.9228590328712016, 10.816676281392574, 0.8792136842384934, 5.93468589708209, 71.54097273945808, 65.08247449994087, 64.11951497197151, 57.91982464492321, 62.17266283929348, 60.597130581736565, 61.99688047170639, 53.14028911292553, 55.16101688146591, 45.95783092081547, 48.76174986362457, 46.43735758960247, 46.454821452498436, 46.04707673192024, 44.43193539977074, 44.35502752661705, 44.07932572066784, 40.97492650151253, 42.431806325912476, 42.01227843761444, 45.196788758039474, 42.05174311995506, 43.79293508827686, 42.0725280046463, 43.03448058664799, 41.05135940015316, 40.63883073627949, 41.18143782019615, 41.796317026019096, 40.4889477789402, 40.6280393153429, 39.89069648087025, 42.576168179512024, 42.56926774978638, 42.02435038983822, 40.272667184472084, 40.95927894115448, 39.85827662050724, 38.825142458081245, 38.47822107374668, 40.81804811954498, 39.67260718345642, 40.834094658493996, 40.789887830615044, 41.76747277379036, 44.62540961802006, 53.21476511657238, 52.86563605070114, 47.82126612961292, 41.17665007710457, 37.90143862366676, 39.35738369822502, 40.77567279338837, 39.71475452184677, 42.38642916083336, 40.38770981132984, 42.68165051937103, 38.62998493015766, 39.9325056374073, 40.207170099020004, 43.052503019571304, 41.903129294514656, 41.88238240778446, 44.65732030570507, 42.346937879920006, 43.15546989440918, 42.53803722560406, 40.632192492485046, 42.19793647527695, 42.73108206689358, 40.228676944971085, 41.740019246935844, 44.176718294620514, 39.21489514410496, 39.03217434883118, 37.76370741426945, 38.381197080016136, 39.672789573669434, 37.909235805273056, 40.40939524769783, 38.56040686368942, 50.42555518448353, 49.80374135077, 39.71574626863003, 43.79299208521843, 42.29114547371864, 40.869903936982155, 40.2067369222641, 42.28290371596813, 41.66619300842285, 42.89559803903103, 39.02157671749592, 41.338452994823456, 41.305086985230446, 44.850308150053024, 40.835337191820145, 42.77634143829346, 41.948552057147026, 39.83132466673851, 42.880999222397804, 40.62042072415352, 40.17341651022434, 44.699437245726585, 43.23286034166813, 42.18214452266693, 43.89704570174217, 44.787151739001274, 43.79347465932369, 46.96457549929619, 43.8463032245636, 41.328531727194786, 43.61183300614357, 47.54652567207813, 44.55742746591568, 46.39379672706127, 46.067230850458145, 46.98339208960533, 48.79751354455948, 51.324301958084106, 52.5935098528862, 52.164797857403755, 53.290187269449234, 51.779342740774155, 60.05917064845562, 60.28670243918896, 69.56855177879333, 64.22112911939621, 78.31588000059128, 50.49255318939686, 4.060735227540135, 4.296563873067498, 4.8243047297000885, 0.7081085094250739, 4.367577312514186, 71.16695120930672, 75.75395107269287, 79.36119630932808, 70.73125898838043, 70.10346427559853, 49.51772689819336, 26.743491254746914, 53.033302053809166, 75.62137618660927, 59.83385033905506, 3.2629497488960624, 0.3853791207075119, 0.19128287880448624, 0.18279941839864478, 0.15969417931046337, 0.20973911188775674, 0.07696216867771], [0.031102984248718712, 0.01240953943124623, 0.06022719870088622, 0.05797429439553525, 0.0294173312431667, 0.06321726716123521, 0.04094276962860022, 0.028133656960562803, 0.11995921420748346, 21.484636142849922, 62.917654663324356, 45.19352853298187, 36.999177038669586, 27.140188068151474, 37.450839802622795, 43.06076377630234, 62.117220014333725, 52.02472597360611, 63.972546458244324, 26.30656599998474, 0.25089638074859977, 0.1510875520762056, 2.490160991437733, 0.12040484420140274, 12.976943012326956, 72.03530341386795, 58.594858422875404, 58.21610614657402, 49.53004203736782, 52.33857773244381, 48.6407795548439, 51.258151307702065, 48.13176266849041, 44.99788463115692, 43.49127687513828, 42.843989208340645, 40.821076557040215, 39.13468524813652, 40.10127738118172, 38.948058262467384, 37.58278772234917, 37.012339532375336, 37.95539952814579, 39.15006682276726, 38.089767917990685, 37.893276661634445, 37.337552681565285, 35.287885665893555, 36.489517986774445, 37.36214876174927, 35.3635586053133, 37.85052515566349, 33.836158365011215, 35.05549393594265, 35.75250193476677, 36.71455331146717, 34.749595150351524, 36.79125979542732, 36.28969430923462, 37.86904156208038, 37.33575537800789, 36.49523667991161, 35.2644257247448, 36.14119067788124, 36.16025425493717, 36.39324635267258, 35.80687701702118, 37.760576382279396, 37.99642212688923, 37.79612347483635, 38.95114749670029, 46.98959335684776, 49.300591349601746, 45.3501333296299, 38.84772464632988, 37.55316451191902, 36.4887922257185, 37.88250803947449, 35.376063734292984, 37.48341545462608, 36.71271041035652, 36.4418039470911, 36.02272443473339, 35.63262976706028, 33.93043130636215, 35.90658746659756, 37.87563420832157, 37.0590428262949, 38.10259982943535, 38.66550922393799, 38.65045063197613, 37.017948031425476, 36.39268398284912, 36.97235807776451, 36.913449838757515, 37.12782293558121, 39.3557345867157, 38.76238502562046, 39.42696176469326, 38.00301097333431, 36.512328162789345, 38.04941028356552, 38.386057019233704, 38.642182275652885, 36.58282957971096, 41.57804913818836, 47.01803483068943, 45.06388708949089, 39.400013610720634, 37.357524409890175, 38.064978048205376, 39.05688442289829, 37.07313247025013, 37.08070546388626, 36.443950831890106, 37.31508068740368, 37.689170613884926, 37.62115806341171, 39.05794456601143, 36.12561911344528, 37.92494036257267, 36.128932535648346, 37.27432407438755, 35.630954056978226, 37.383583411574364, 34.64132755994797, 36.80568382143974, 36.471974328160286, 37.62707054615021, 36.921228021383286, 39.176878184080124, 37.964355647563934, 39.42973181605339, 38.75845983624458, 39.74001556634903, 38.9202019572258, 41.17711745202541, 40.118726044893265, 41.97535201907158, 42.208910286426544, 43.88265587389469, 44.20700266957283, 47.33106203377247, 47.083406522870064, 46.30254082381725, 48.19189824163914, 49.680479764938354, 45.938106179237366, 52.75754325091839, 52.859430983662605, 68.90224233269691, 57.166876047849655, 76.4098946750164, 30.91681681573391, 1.1883573769591749, 0.3656521823722869, 0.8746548788622022, 0.2550938492640853, 6.4305925369262695, 65.75758427381516, 63.01089406013489, 67.7862574160099, 67.09005877375603, 50.929662734270096, 27.828783318400383, 27.648131512105465, 43.23487803339958, 54.73341062664986, 38.38259160518646, 1.4599348604679108, 0.206927411200013, 0.036478962865658104, 0.08512626809533685, 0.06336406397167593, 0.0924105811282061, 0.04090363989234902, 0.06628230737987906, 0.024358928749279585, 0.06418090139050037, 0.03261541998654138, 0.07706007279921323, 0.054110870260046795, 0.10878854838665575, 0.04822676353796851, 0.11102955235401168, 27.676713578402996, 71.13952428102493, 51.21587097644806, 40.58025307953358, 25.347037687897682, 42.3646829277277, 50.29239133000374, 68.11779722571373, 55.27908034622669, 70.8828404545784, 28.096870332956314, 0.24533784308005124, 0.2552491659298539, 2.0021610148251057, 0.13904647319577634, 14.625217616558075, 75.12938618659973, 61.26070037484169, 61.46191857755184, 51.02208137512207, 56.426683366298676, 51.54355779290199, 53.13124939799309, 48.34638275206089, 47.896764278411865, 46.21661223471165, 46.14779032766819, 42.422485426068306, 42.96409696340561, 41.38480670750141, 41.57009996473789, 39.43388119339943, 40.49441568553448, 40.441351532936096, 41.203400641679764, 39.34319905936718, 39.63088542222977, 40.55927440524101, 38.63412670791149, 38.131751865148544, 38.540359139442444, 36.91266708076, 40.52022770047188, 36.66948392987251, 37.17981934547424, 36.486269161105156, 38.91496583819389, 38.109678849577904, 38.128278851509094, 37.95198351144791, 39.63698789477348, 39.64059770107269, 37.772598937153816, 37.66861371695995, 37.11972177028656, 37.24940501153469, 39.10251997411251, 37.68591798841953, 39.7939270734787, 40.6306953728199, 38.887664303183556, 41.368475183844566, 49.89319995045662, 51.64126195013523, 45.142884850502014, 37.92692005634308, 38.11024121940136, 37.241623029112816, 38.66848826408386, 37.686598151922226, 40.21285079419613, 38.60821969807148, 37.8966660797596, 38.53222377598286, 37.7510616928339, 35.521371737122536, 38.03871765732765, 40.52143223583698, 39.15618449449539, 40.050588101148605, 41.178850159049034, 40.48893637955189, 38.382378816604614, 37.68121004104614, 38.82432550191879, 37.13232569396496, 38.52354884147644, 39.945953115820885, 40.88668383657932, 40.959985703229904, 39.44189116358757, 36.202352195978165, 38.645024523139, 38.84413003921509, 39.052161276340485, 37.60237567126751, 41.47854007780552, 50.03659285604954, 46.924149468541145, 41.38795293867588, 40.40494188666344, 40.25517672300339, 38.70142109692097, 38.03846687078476, 39.545002430677414, 37.59458988904953, 37.88206346333027, 38.5115946829319, 39.07322354614735, 39.356958121061325, 38.95517908036709, 38.34762208163738, 38.67654003202915, 39.24337841570377, 37.40046210587025, 39.52291041612625, 37.40846827626228, 40.419810488820076, 40.38216970860958, 40.405591651797295, 40.24778991937637, 42.13650897145271, 41.80409900844097, 41.71121299266815, 42.068226635456085, 42.734741270542145, 41.68597474694252, 43.445314541459084, 42.2201918810606, 43.44562992453575, 43.40186387300491, 45.63385270535946, 44.80686508119106, 49.66833561658859, 50.01749508082867, 49.47076141834259, 49.51154462993145, 50.981662943959236, 50.13254910707474, 55.324487909674644, 56.3009899109602, 71.2598106265068, 59.00488302111626, 77.90430888533592, 38.17417658865452, 0.3471451567020267, 1.6254481603391469, 1.0682725394144654, 0.09378753224154934, 6.359332110732794, 71.03764414787292, 68.8787367939949, 75.13054132461548, 71.29994407296181, 62.29699596762657, 37.08952099084854, 26.74344375729561, 47.84102886915207, 64.31283339858055, 47.120230346918106, 2.0422011287882924, 0.20712574274512008, 0.0896451978769619, 0.16989940748317167, 0.06230118975508958, 0.09688134552561678, 0.014020798626006581, 0.170628760533873, 0.08351254960871302, 0.17115463153459132, 0.12238249706570059, 0.14525998587487265, 0.14775717922020704, 0.13978520699311048, 0.28261330851819366, 0.1962093441397883, 32.17652142047882, 83.47319886088371, 58.492009341716766, 51.04595549404621, 37.453712448477745, 52.6467639952898, 56.698558777570724, 71.12047210335732, 62.232650220394135, 77.66321942210197, 32.06032745540142, 0.43727528129238635, 0.8188897836953402, 7.15574705041945, 0.1865516131510958, 17.73596439510584, 77.19088956713676, 62.877384424209595, 63.25825698673725, 53.77195581793785, 58.021324798464775, 51.949338018894196, 55.08920833468437, 51.34245738387108, 50.48335388302803, 49.24949549138546, 47.82062016427517, 46.3590057939291, 43.96985359489918, 44.49606455862522, 44.94992360472679, 42.05150753259659, 41.65961556136608, 42.955072447657585, 44.76156771183014, 42.237868532538414, 43.122742250561714, 42.67732635140419, 40.334888845682144, 41.988366320729256, 42.20805153250694, 39.187760800123215, 44.18838746845722, 39.568610563874245, 40.31854972243309, 40.16556613147259, 42.329778000712395, 40.10344326496124, 40.765569135546684, 40.75549587607384, 41.58589571714401, 42.76881404221058, 41.31150484085083, 39.31505396962166, 39.2355128377676, 39.68282863497734, 39.94987830519676, 39.90675061941147, 42.287501469254494, 41.78675293922424, 40.28092414140701, 44.028385654091835, 51.35387197136879, 52.607542499899864, 47.30608597397804, 38.97950157523155, 39.05290223658085, 37.57092095911503, 39.79184478521347, 38.152145370841026, 42.69411005079746, 41.69053830206394, 40.45354887843132, 40.73946073651314, 40.54387383162975, 38.429226502776146, 40.23015506565571, 41.57189726829529, 41.053635478019714, 44.07190091907978, 43.751707300543785, 44.52114701271057, 41.03368654847145, 39.680723547935486, 41.43004707992077, 38.958880081772804, 41.329071298241615, 42.712322473526, 40.40630221366882, 42.013980746269226, 40.70078261196613, 36.909300461411476, 38.73761035501957, 39.621853306889534, 39.499374479055405, 37.110036090016365, 42.861327677965164, 52.31568016111851, 49.73507143557072, 44.27012488245964, 43.85519854724407, 42.312439531087875, 39.87053096294403, 40.25988467037678, 41.60750515758991, 39.388713017106056, 39.74140629172325, 42.55410276353359, 43.11289317905903, 43.4017688781023, 41.471016481518745, 40.12094132602215, 40.034450367093086, 42.701812237501144, 38.82386192679405, 42.854115664958954, 39.334345534443855, 42.50019125640392, 41.34512163698673, 43.79842199385166, 41.16356737911701, 43.58787149190903, 42.82272554934025, 42.48974181711674, 44.02058467268944, 44.83251370489597, 43.855483531951904, 45.94301551580429, 44.08283293247223, 45.21854259073734, 45.09317211806774, 48.92160348594189, 48.35941985249519, 52.50341668725014, 54.14790764451027, 52.63476803898811, 53.929229378700256, 53.816208243370056, 51.8978925794363, 55.950040742754936, 60.139551535248756, 74.13318604230881, 61.40381209552288, 80.08913084864616, 43.56193408370018, 1.2620893330313265, 3.329819510690868, 3.5953442752361298, 0.41375139669980854, 7.174688559025526, 76.84244826436043, 72.81132817268372, 78.75753030180931, 79.1391210258007, 65.30025601387024, 40.88919170200825, 40.29813341796398, 59.636264741420746, 73.52737694978714, 60.341248512268066, 3.692611693404615, 0.3186658036429435, 0.1775071187876165, 0.31633813166990876, 0.1932469874736853, 0.21303331246599555, 0.16101955116027966], [0.008155191790137906, 0.05068748403573409, 0.018903484669863246, 0.012868429748777999, 0.022031783701095264, 0.05492949625477195, 0.036474328153417446, 0.2741632447578013, 0.10344507027184591, 16.325599774718285, 67.1975702047348, 47.29288928210735, 33.176855742931366, 21.18245355784893, 37.176038548350334, 42.61097811162472, 59.68400917947292, 55.29746375977993, 60.5445110052824, 35.64601644873619, 0.07149822515202686, 0.47187474032398313, 0.8415742695797235, 0.055126324950833805, 32.71993786096573, 71.00900888442993, 57.91087992489338, 54.50067311525345, 51.76896929740906, 51.77779622375965, 46.848712116479874, 45.74504613876343, 44.15075808763504, 43.38931314647198, 44.17960233986378, 43.85622829198837, 41.288732662796974, 38.070901930332184, 38.86421196162701, 38.49729984998703, 39.19450543820858, 38.25369492173195, 38.709309473633766, 37.687601298093796, 36.99379652738571, 35.74563570320606, 36.89355790615082, 34.86486196517944, 36.92188918590546, 37.713557705283165, 35.83260543644428, 36.63956053555012, 36.6336290538311, 35.7320324331522, 35.23474931716919, 35.376466512680054, 34.313230365514755, 37.85033516585827, 36.950254663825035, 37.867764830589294, 36.88989110291004, 36.1205729842186, 36.691986322402954, 36.1564202606678, 38.12957838177681, 36.88335545361042, 36.54112681746483, 37.44412176311016, 37.74088203907013, 36.37867413461208, 35.663883090019226, 44.12292838096619, 48.339379727840424, 48.06141324341297, 37.61855140328407, 36.312363892793655, 37.09718897938728, 38.00464108586311, 36.37723781168461, 38.338449373841286, 35.83677001297474, 37.913780361413956, 38.377389684319496, 35.72387807071209, 35.91152720153332, 35.61768516898155, 38.03897984325886, 39.07093986868858, 37.516260892152786, 37.058233469724655, 36.97017699480057, 36.55591182410717, 37.509991228580475, 36.626686826348305, 36.53485715389252, 38.07464852929115, 39.84644025564194, 41.18707671761513, 39.98414106667042, 36.0866180062294, 36.196040734648705, 36.92539639770985, 39.39562104642391, 39.052119478583336, 39.02297504246235, 42.99327179789543, 45.04396855831146, 47.01614253222942, 40.41397400200367, 37.52620115876198, 37.75315918028355, 37.39998713135719, 38.593799471855164, 36.37557350099087, 36.76634073257446, 37.68023729324341, 38.60419951379299, 35.66965878009796, 37.10034281015396, 37.22236566245556, 38.08012783527374, 37.83585414290428, 37.91569545865059, 35.19531883299351, 36.18683382868767, 36.36551544070244, 36.15447096526623, 36.77276238799095, 38.63897144794464, 36.692579090595245, 40.34086972475052, 39.85840201377869, 39.665835946798325, 39.14025954902172, 39.32608097791672, 38.6750391125679, 39.88719306886196, 40.607227832078934, 42.315654158592224, 40.47076195478439, 43.068059384822845, 42.59405381977558, 49.280748814344406, 46.418461203575134, 47.89177134633064, 45.11987328529358, 48.04076515138149, 48.15292373299599, 55.202480256557465, 54.8312059789896, 64.29308965802193, 59.097476452589035, 74.94666159152985, 30.85681613534689, 0.14149808383081108, 1.0178038850426674, 0.5730723054148257, 0.4390248202253133, 8.664648458361626, 69.0851417183876, 59.85328249633312, 69.57262516021729, 64.25834432244301, 52.60430887341499, 23.856421373784542, 30.39240885525942, 41.250780299305916, 61.60392835736275, 33.951683565974236, 0.9467015659902245, 0.16210206260439008, 0.0905081004020758, 0.03471474425168708, 0.05079208604001906, 0.04369206311821472, 0.059221299161436036, 0.07177986277383752, 0.09413306877831928, 0.0353182772960281, 0.07562633254565299, 0.030257039798016194, 0.043848760178661905, 0.030292649898910895, 0.16485385713167489, 0.16318053676513955, 21.402703039348125, 74.36844661831856, 53.811644688248634, 41.843043118715286, 24.543109126389027, 42.808685302734375, 48.680639415979385, 64.22105312347412, 59.32015210390091, 67.49735891819, 38.157503083348274, 0.07169884993345477, 0.3582194249611348, 0.9438347979448736, 0.04580030799843371, 35.49071118235588, 72.8607103228569, 59.68910090625286, 56.6965638846159, 53.912061899900436, 52.90984287858009, 49.93750177323818, 49.196556732058525, 45.97922757267952, 46.51793606579304, 45.826027393341064, 46.33387014269829, 43.609667122364044, 41.57397195696831, 40.85232228040695, 41.916831359267235, 39.71418455243111, 41.52074061334133, 41.22486189007759, 40.45727647840977, 39.55096811056137, 37.34387554228306, 39.73581679165363, 37.165072336792946, 38.3102510869503, 40.378768891096115, 39.051853492856026, 39.1928905248642, 38.308829963207245, 36.8771655857563, 37.545963898301125, 38.21772985160351, 37.036228850483894, 39.2956256121397, 39.90285582840443, 39.31810140609741, 37.88983404636383, 37.53892667591572, 38.34303952753544, 37.04447440803051, 39.3109729886055, 38.30700226128101, 37.97429971396923, 39.66164857149124, 40.525688007473946, 38.97726349532604, 37.24604979157448, 46.75669625401497, 51.26991927623749, 47.6845570653677, 37.96350449323654, 37.872567772865295, 37.40151084959507, 39.42788131535053, 38.9130013436079, 40.53195767104626, 38.938532173633575, 38.865583688020706, 39.550097957253456, 39.11547727882862, 37.61147618293762, 38.840706422924995, 40.23120000958443, 40.3887053579092, 40.55722251534462, 38.8564907759428, 38.252824768424034, 38.11469458043575, 38.64991866052151, 38.338380977511406, 38.61908331513405, 39.20136786997318, 41.23073637485504, 42.95925982296467, 41.604446321725845, 37.69488550722599, 36.148516684770584, 37.860108241438866, 39.79985475540161, 37.865313962101936, 38.50307174026966, 44.6829879283905, 48.02007146179676, 48.67592766880989, 41.51529170572758, 39.198343232274055, 39.52820733189583, 39.77582864463329, 40.48381045460701, 37.95945771038532, 38.44585821032524, 39.465263709425926, 39.52635683119297, 39.2051562666893, 40.052567794919014, 39.47039723396301, 39.10987637937069, 40.09652383625507, 40.07303349673748, 37.692221850156784, 39.25803042948246, 38.39322343468666, 39.05523531138897, 39.08233925700188, 40.03113694489002, 40.88010638952255, 43.03528234362602, 41.48894011974335, 42.412769347429276, 43.14422249794006, 41.210802644491196, 40.297039076685905, 41.74106799066067, 42.6129350066185, 43.505890890955925, 43.37670162320137, 44.70729902386665, 46.3331101834774, 51.61009602248669, 48.16591143608093, 49.90118332207203, 47.22395718097687, 50.04404805600643, 51.02761007845402, 57.63971887528896, 58.37166219949722, 67.1271675825119, 60.93594320118427, 74.27323132753372, 35.862046256661415, 0.0692864172742702, 0.8597197209019214, 0.4927586275152862, 0.4500891733914614, 9.192560780793428, 74.15774792432785, 65.60869306325912, 74.8456934094429, 69.09869939088821, 59.77008976042271, 28.4288889169693, 32.86049231886864, 50.05506366491318, 68.81610095500946, 42.79485024511814, 1.1205601086840034, 0.11139676702441648, 0.07019876909907907, 0.046737584852962755, 0.054646511634928174, 0.039429805110557936, 0.028619528056879062, 0.21641866362188011, 0.2138333031325601, 0.2055094638490118, 0.2507434686413035, 0.2247662516310811, 0.11982544208876789, 0.19601643027272075, 0.2559978741919622, 0.3059607103932649, 25.183646455407143, 83.48478063941002, 61.0637379437685, 48.628870993852615, 31.394226998090744, 49.5000122487545, 55.65679147839546, 70.66025599837303, 63.89493942260742, 71.65722370147705, 43.53460215032101, 0.13867928821127862, 0.9859392698854208, 4.23224757425487, 0.1539839614997618, 39.34247709810734, 73.27044233679771, 64.09303039312363, 59.61479589343071, 56.34651146829128, 56.013033762574196, 50.496907755732536, 50.299565345048904, 48.94264675676823, 48.769007474184036, 48.09236258268356, 50.502934232354164, 46.19005545973778, 44.43864583969116, 44.756916761398315, 43.85629288852215, 44.025041833519936, 44.32999446988106, 45.27658827602863, 42.64284320175648, 41.033253371715546, 39.25450041890144, 41.75428748130798, 40.013217106461525, 41.506791561841965, 42.86047272384167, 40.885023325681686, 41.456900238990784, 41.8286494910717, 39.71988804638386, 38.716605082154274, 42.158832773566246, 38.49725425243378, 42.30859033763409, 41.87025345861912, 40.93374811112881, 40.06454475224018, 40.01879520714283, 40.95560073852539, 40.323329865932465, 43.3817857503891, 40.29128238558769, 39.647125750780106, 41.17368623614311, 42.39689759910107, 40.86939476430416, 39.37308445572853, 46.95813864469528, 52.64387235045433, 49.3585230410099, 37.666162848472595, 37.99970135092735, 37.5455117225647, 40.70863299071789, 40.42558237910271, 42.08027958869934, 39.74944666028023, 41.01978309452534, 41.72697834670544, 41.81665353477001, 39.78508494794369, 39.05718840658665, 42.875941693782806, 44.18709173798561, 42.75319308042526, 40.85993327200413, 41.227103769779205, 40.78082151710987, 41.69620379805565, 40.18344797194004, 40.388758555054665, 42.69767425954342, 43.8742621243, 44.34569142758846, 42.48685397207737, 39.06140238046646, 36.96784012019634, 39.24911990761757, 40.82334503531456, 38.3508937060833, 38.20299804210663, 46.4506758749485, 50.01977115869522, 51.31305456161499, 45.8378903567791, 41.61534033715725, 41.21515341103077, 41.347112730145454, 43.21699999272823, 38.855438232421875, 40.37259802222252, 41.43659792840481, 41.14484578371048, 40.007608607411385, 42.25293852388859, 43.24766054749489, 42.430974170565605, 43.768977373838425, 42.034758031368256, 40.40893167257309, 42.564609199762344, 40.61285153031349, 41.33441001176834, 41.76427334547043, 44.75714094936848, 43.13534997403622, 46.32452644407749, 43.35298329591751, 45.354624688625336, 45.83646923303604, 43.738613203167915, 43.43373276293278, 43.240896910429, 45.61190888285637, 45.72288192808628, 45.3862351924181, 46.97459556162357, 47.4819253385067, 54.69261221587658, 50.286429449915886, 52.72004686295986, 50.796977654099464, 53.893830478191376, 53.6356533318758, 59.933617785573006, 60.17309233546257, 70.55850505828857, 63.31564150750637, 77.91359558701515, 41.255332455039024, 0.20320926618296653, 2.3218278866261244, 4.90447947755456, 0.716541800647974, 10.349008776247501, 80.82403421401978, 70.52677676081657, 80.89682310819626, 75.877885222435, 67.3514087498188, 37.66639083623886, 44.21986497938633, 57.703673243522644, 78.19234862923622, 53.67176279425621, 1.52005594689399, 0.3149348491569981, 0.1889276731526479, 0.17100879951613024, 0.09482713270699605, 0.11655342430458404, 0.18131341610569507], [0.05237604440480936, 0.03863539910526015, 0.11195526283700019, 0.06237665133085102, 0.03489651848212816, 0.007773873994665337, 0.1125883444910869, 0.19779687223490328, 0.1280452322680503, 11.972951386123896, 64.51919272542, 45.40593333542347, 30.71146823465824, 22.045814730226994, 38.25684495270252, 45.023502856492996, 62.0218451321125, 58.413315564394, 55.61352699995041, 48.44348654150963, 1.1398434801958501, 0.6754540116526186, 0.3188573964871466, 0.9629912918899208, 53.44594091176987, 64.80291590094566, 58.278460800647736, 54.523935467004776, 51.49004526436329, 50.63743941485882, 47.977449148893356, 44.84710872173309, 47.67140977084637, 44.01050761342049, 44.12176564335823, 39.655709490180016, 40.88527411222458, 38.703381791710854, 37.92182072997093, 39.637983441352844, 39.05702121555805, 38.44108186662197, 37.35273286700249, 38.07126671075821, 35.82920081913471, 36.95875860750675, 35.88439665734768, 35.555904284119606, 35.741049349308014, 35.772101283073425, 36.57562516629696, 35.26389755308628, 36.519676968455315, 34.43645395338535, 36.91204011440277, 35.54673917591572, 37.675476148724556, 36.25036261975765, 36.605008989572525, 36.85251250863075, 35.827403515577316, 35.64946286380291, 35.16454428434372, 36.590911746025085, 37.5768980383873, 37.18429550528526, 36.68300360441208, 36.722764670848846, 38.58960069715977, 35.91127261519432, 36.07892341911793, 43.12254846096039, 49.911495968699455, 47.935275211930275, 39.07279036939144, 36.70511841773987, 36.887801215052605, 36.828649789094925, 39.423629343509674, 39.373491033911705, 40.05878426134586, 37.24259577691555, 38.22899244725704, 37.44702860713005, 35.140692964196205, 36.87222205102444, 39.228904992341995, 37.95418359339237, 38.843715861439705, 37.911147102713585, 36.88341625034809, 39.653076231479645, 37.11271874606609, 36.78660124540329, 38.2221794128418, 38.48726078867912, 39.87061455845833, 39.865990206599236, 38.47316354513168, 35.658198595047, 37.091626077890396, 37.91560806334019, 39.03469741344452, 37.85261884331703, 41.4991919696331, 42.77550168335438, 49.49807055294514, 44.97706174850464, 35.73390953242779, 39.136216565966606, 38.15930798649788, 36.99839048087597, 37.42288090288639, 37.13025100529194, 36.05973444879055, 35.80944947898388, 37.53738775849342, 38.5414382815361, 38.242063745856285, 36.2366833537817, 38.21425303816795, 36.200706884264946, 37.77552857995033, 37.634058371186256, 37.76119574904442, 34.99899096786976, 36.28166154026985, 35.53769566118717, 39.31506536900997, 35.87091498076916, 38.39124374091625, 37.87620037794113, 38.637603521347046, 37.5811006128788, 40.824120193719864, 36.80201701819897, 39.856505915522575, 37.657750099897385, 40.44141612946987, 39.592914059758186, 43.27144347131252, 42.97008164227009, 48.374163061380386, 45.63235178589821, 48.71650569140911, 45.919137597084045, 48.01655285060406, 47.111920192837715, 59.04540404677391, 60.16431860625744, 65.5201730132103, 58.27924735844135, 72.45385095477104, 29.73063636571169, 0.1672262657666579, 0.4126823478145525, 0.6317192490678281, 0.2145350186037831, 9.621015340089798, 72.71675124764442, 58.064106702804565, 66.6942872107029, 62.77042396366596, 53.16586174070835, 31.62278663367033, 25.897449553012848, 38.18028286099434, 59.41808804869652, 31.316572465002537, 0.7885704387445003, 0.07826892004231922, 0.06391990289557725, 0.08975294287665747, 0.02171538202674128, 0.05042588811193127, 0.030932587142160628, 0.017412298475392163, 0.013260788382467581, 0.1043044995458331, 0.028555265489558224, 0.0376741545915138, 0.020540176337817684, 0.05859219170815777, 0.16814985370729119, 0.17267489136429504, 14.286358449608088, 72.31434524059296, 51.95073254406452, 34.574671536684036, 22.085775285959244, 37.714655846357346, 49.30797055363655, 67.16627508401871, 65.63480526208878, 60.70281811058521, 51.92012898623943, 1.2163731548935175, 0.6981187860947102, 0.10708258836530149, 1.0732986009679735, 56.1328337341547, 65.50901681184769, 61.734192967414856, 57.82129593193531, 56.010202914476395, 52.89172925055027, 49.50484558939934, 47.05028370022774, 48.048740923404694, 46.03916935622692, 46.155511513352394, 43.368756249547005, 41.748105213046074, 40.4854291677475, 39.79388527572155, 41.55552014708519, 40.76393902301788, 40.7070142775774, 40.11375971138477, 39.79758247733116, 38.285685405135155, 38.70968945324421, 37.06893749535084, 38.27095739543438, 38.07101212441921, 37.16432377696037, 38.49668428301811, 38.25101986527443, 37.41612486541271, 36.65015056729317, 37.81383812427521, 37.28806793689728, 41.11637771129608, 39.13464345037937, 38.265569284558296, 38.37895520031452, 38.383811339735985, 37.74357229471207, 36.72891654074192, 38.28473165631294, 38.64902190864086, 38.40790584683418, 39.51187200844288, 40.08581221103668, 40.49749732017517, 37.27211259305477, 39.60679851472378, 45.74729181826115, 51.56235918402672, 49.13458965718746, 39.58545506000519, 36.820871606469154, 36.43217146396637, 38.11686426401138, 40.70053182542324, 41.039735823869705, 41.50406710803509, 39.29944060742855, 39.21525612473488, 39.01114247739315, 36.829455345869064, 37.93329231441021, 40.384924560785294, 39.56125795841217, 39.50850538909435, 39.92028929293156, 40.171068236231804, 40.95868997275829, 38.70584025979042, 39.928306862711906, 40.08844166994095, 41.169153079390526, 41.860389187932014, 40.7834205776453, 38.21634292602539, 37.68599398434162, 36.332472413778305, 38.00971381366253, 39.34306986629963, 38.00273738801479, 40.634411573410034, 44.82639603316784, 53.436395823955536, 47.4691504240036, 38.46110299229622, 40.39996035397053, 39.68879051506519, 39.819932878017426, 39.64063949882984, 37.54824757575989, 37.67955332994461, 37.083889693021774, 38.68046522140503, 39.106057584285736, 38.62851820886135, 38.64234186708927, 40.72546608746052, 38.46924975514412, 40.633229836821556, 39.67566981911659, 40.3880175948143, 37.18890465795994, 39.08301942050457, 39.11971405148506, 40.771417021751404, 38.542631417512894, 40.20341970026493, 39.94632929563522, 41.33712686598301, 40.34131050109863, 42.75615692138672, 39.335348680615425, 42.79439426958561, 40.26141218841076, 43.109442964196205, 41.53663896024227, 46.47670067846775, 44.0114651620388, 52.37720265984535, 48.00769932568073, 51.22802272439003, 47.110822051763535, 50.729713663458824, 49.28808242082596, 61.06050431728363, 62.17075914144516, 68.52493777871132, 62.82894842326641, 73.98519918322563, 31.233237236738205, 0.2790994173847139, 1.5175594808533788, 1.8382362672127783, 0.31687903858255595, 10.68685244768858, 77.02469408512115, 64.69497129321098, 72.27887034416199, 68.26196148991585, 61.80670827627182, 31.66041601449251, 30.961891897022724, 44.91352155804634, 69.29112106561661, 39.80920225381851, 0.7172761706169695, 0.07841455910238437, 0.009551267121423734, 0.0359571810986381, 0.03492455682135187, 0.0164663718896918, 0.009182835328829242, 0.13558647682657465, 0.10027308657299727, 0.28996659675613046, 0.11470592929981649, 0.12228583233081736, 0.16898766421945766, 0.30230928445234895, 0.35328562720678747, 0.38278193038422614, 18.93684435635805, 81.49386987090111, 58.7246860563755, 44.24859143793583, 33.90727914869785, 49.86621379852295, 56.59781098365784, 74.86477598547935, 70.5302345752716, 66.35099083185196, 57.91954725980759, 1.5982334269210696, 1.290450298693031, 1.3909892225638032, 1.4091555727645755, 59.14887249469757, 67.06646203994751, 64.08186659216881, 60.26327669620514, 58.0545312166214, 55.776982828974724, 52.688706144690514, 50.02459689974785, 52.76945561170578, 47.89673388004303, 50.776800736784935, 44.56620119512081, 45.47033987939358, 42.422553822398186, 41.281152069568634, 44.08398047089577, 43.56950327754021, 42.730804681777954, 43.214951902627945, 42.160846665501595, 40.870074927806854, 41.85184344649315, 39.38310831785202, 40.222555473446846, 39.837605729699135, 41.250290125608444, 41.64276726543903, 41.431399807333946, 40.606627464294434, 38.941807597875595, 41.03537365794182, 38.93852837383747, 44.58269611001015, 41.13275483250618, 41.017328426241875, 40.30290216207504, 39.4105314463377, 38.846957087516785, 38.21548417210579, 39.67011071741581, 41.53359532356262, 40.8702877163887, 41.12029530107975, 41.29165470600128, 41.717870235443115, 39.2970809340477, 41.56072586774826, 46.42119325697422, 54.502873197197914, 51.62582717835903, 39.21311303973198, 36.64911322295666, 37.953131049871445, 38.40218335390091, 42.26347155869007, 44.18537423014641, 44.73505273461342, 41.84367008507252, 40.442962646484375, 42.9039765894413, 40.22286705672741, 40.60896433889866, 43.12558449804783, 41.37297034263611, 42.00876362621784, 41.61250948905945, 41.653117910027504, 44.10073757171631, 42.2415429353714, 40.329702123999596, 41.220191940665245, 43.1237605959177, 43.29479321837425, 42.90786758065224, 39.81280446052551, 38.49141776561737, 37.4571018666029, 37.79134713113308, 38.88669155538082, 39.03710648417473, 41.89353480935097, 48.60083229839802, 55.92788413167, 48.34011308848858, 39.36595983803272, 42.94802002608776, 42.384240478277206, 42.32657477259636, 41.26065976917744, 40.341895669698715, 40.01651532948017, 39.682232066988945, 41.02028846740723, 42.5421068072319, 40.20591616630554, 39.13053207099438, 43.07970196008682, 40.302047207951546, 43.42287294566631, 42.73330494761467, 43.903676345944405, 39.20915365219116, 41.618174985051155, 42.37167075276375, 44.2155522108078, 42.677691131830215, 42.62151874601841, 41.79106190800667, 43.674282655119896, 41.81909680366516, 44.84882242977619, 41.642983853816986, 44.43090945482254, 41.34187661111355, 46.31163753569126, 43.87787193059921, 48.88702534139156, 47.73405320942402, 54.04973991215229, 51.40531361103058, 53.6141312867403, 50.96598498523235, 52.676949575543404, 51.87493421137333, 63.14059630036354, 65.86454093456268, 70.70263892412186, 65.06682693958282, 73.75500753521919, 34.517834186553955, 0.3700115578249097, 2.725293799303472, 6.17179412394762, 0.5775609333068132, 11.942352578043938, 85.7391844689846, 70.20224377512932, 75.34174159169197, 73.00020083785057, 67.54287287592888, 44.87435705959797, 39.172162637114525, 53.74545603990555, 77.25393578410149, 52.53824181854725, 1.5306185488589108, 0.21931149589363486, 0.12457147648092359, 0.1342666710843332, 0.13768356351647526, 0.16709630086552352, 0.1106139793409966], [0.0796939103747718, 0.02456951315252809, 0.04386675725982059, 0.09469302662182599, 0.024433065591438208, 0.015977496950654313, 0.13507583469618112, 0.0938958561164327, 0.03229906469641719, 5.037648556753993, 58.25243219733238, 50.91662563383579, 41.69894725084305, 41.50078408420086, 40.823101848363876, 45.30539073050022, 60.632734671235085, 58.80836136639118, 52.37680748105049, 54.463093131780624, 3.072243919596076, 0.7320132642053068, 0.1070088188862428, 2.419762881472707, 62.46992468833923, 62.007208317518234, 59.32854205369949, 52.23919026553631, 49.11479651927948, 48.26548129320145, 48.736944794654846, 43.780673146247864, 43.22008162736893, 41.70639485120773, 41.72541283071041, 40.13186953961849, 39.72967252135277, 38.87472599744797, 37.83318288624287, 38.32811772823334, 38.75160500407219, 35.94755306839943, 37.15632140636444, 37.06004597246647, 38.35155867040157, 35.63228398561478, 35.95424450933933, 34.37293276190758, 34.996768087148666, 35.906500071287155, 37.24532023072243, 35.318713411688805, 36.408164352178574, 35.326784178614616, 36.82980112731457, 34.49573837220669, 37.192727252840996, 36.97258226573467, 36.6458036005497, 36.399838998913765, 34.93257433176041, 36.46745257079601, 36.68869189918041, 35.84223031997681, 35.229668989777565, 36.69711224734783, 37.461034655570984, 37.66987144947052, 39.190538451075554, 37.44718819856644, 38.92935186624527, 43.97109232842922, 48.17280426621437, 46.86826966702938, 43.34702521562576, 36.776915565133095, 38.2839222997427, 36.72663286328316, 39.13066126406193, 39.86323915421963, 39.537406638264656, 37.574887946248055, 38.22230100631714, 37.00113393366337, 38.29648442566395, 37.293767631053925, 36.45436227321625, 38.01907271146774, 37.874349877238274, 37.14614935219288, 38.101087510585785, 38.232921436429024, 37.753261774778366, 37.14516520500183, 38.568812012672424, 39.067364260554314, 39.507452845573425, 39.271884486079216, 38.35095450282097, 36.23683154582977, 36.12841576337814, 36.57125920057297, 39.23630699515343, 39.833532348275185, 38.207436203956604, 44.7552752494812, 50.64497821033001, 43.50343242287636, 37.21911683678627, 38.40366147458553, 38.3118811994791, 37.98089995980263, 36.93279840052128, 37.0976335555315, 36.5951257199049, 35.60654416680336, 36.254986971616745, 36.66872017085552, 39.044284299016, 36.523089185357094, 37.76502974331379, 37.023925110697746, 38.38465869426727, 36.65218345820904, 37.91890248656273, 35.81337466835976, 35.33710442483425, 37.22981706261635, 38.06583300232887, 35.812781900167465, 36.67502783238888, 37.85717099905014, 38.32266882061958, 37.46088266372681, 39.19135920703411, 38.29898089170456, 41.173158064484596, 38.42332161962986, 39.10883143544197, 38.844187036156654, 43.3165318518877, 44.5184301584959, 47.23870038986206, 42.72939495742321, 46.29874862730503, 42.41397388279438, 49.22143779695034, 54.974389895796776, 59.94726285338402, 58.52552354335785, 69.35029149055481, 52.77834713459015, 58.51337179541588, 37.57097415626049, 0.12639465130632743, 0.7615309115499258, 0.6372318032663316, 0.4889833222841844, 11.258159391582012, 71.99662908911705, 59.549036622047424, 69.86118167638779, 59.20363135635853, 52.88954816758633, 23.45411416143179, 21.70838713645935, 40.420315861701965, 60.718161687254906, 33.245198875665665, 0.9052271477412432, 0.11445880896644667, 0.026261218372383155, 0.020259800367057323, 0.08553223771741614, 0.03267142987169791, 0.061746927895001136, 0.05835005118569825, 0.029320744433789514, 0.011593839353736257, 0.16949955315794796, 0.018691775912884623, 0.08812022540951148, 0.12545218312880024, 0.19970110442955047, 0.07402002811431885, 7.393032442778349, 66.37954249978065, 57.53010615706444, 46.82087101042271, 40.869732946157455, 41.28723554313183, 51.34980618953705, 65.84205374121666, 65.09293913841248, 57.166575863957405, 61.876035556197166, 3.4129315009340644, 0.4397181642707437, 0.12554803892271593, 2.46210899669677, 65.92485129833221, 64.768907725811, 62.18179754912853, 53.20266276597977, 53.50936710834503, 50.543082877993584, 51.85197964310646, 46.683253794908524, 48.116563484072685, 44.55901198089123, 45.31082823872566, 42.534921392798424, 42.81134136021137, 40.02449110150337, 39.51009750366211, 40.759694650769234, 38.708606511354446, 37.95095756649971, 39.712527841329575, 38.72239597141743, 39.92275536060333, 37.80471481382847, 38.96517254412174, 37.18159385025501, 38.112467899918556, 37.474155351519585, 38.4085214138031, 37.534944489598274, 38.420745357871056, 36.44117318093777, 37.14896500110626, 37.44116172194481, 38.51762495934963, 38.173230439424515, 38.003835529088974, 38.40706989169121, 37.71705351769924, 37.79694423079491, 37.89035461843014, 39.094301015138626, 37.44985565543175, 38.25001671910286, 38.94542120397091, 38.3572393655777, 41.72491505742073, 39.974440187215805, 40.00879034399986, 46.22312888503075, 50.93957260251045, 48.35120849311352, 43.156461641192436, 36.15932710468769, 37.926718667149544, 36.653570383787155, 41.69954761862755, 40.46120926737785, 41.70018598437309, 39.631227403879166, 39.72027562558651, 38.29081512987614, 41.132857427001, 39.68260444700718, 38.62396605312824, 38.88422928750515, 39.256001338362694, 39.70659635961056, 39.979113936424255, 40.34151948988438, 39.28558275103569, 40.29599033296108, 39.95632275938988, 39.544968232512474, 40.740718469023705, 40.69141611456871, 40.445166528224945, 37.038466930389404, 36.19950234889984, 37.74619035422802, 39.46968287229538, 39.61270719766617, 39.72915194928646, 46.84372678399086, 52.23642021417618, 46.138446629047394, 39.93938326835632, 40.699437484145164, 40.04259712994099, 37.753508761525154, 38.94248776137829, 38.498462587594986, 38.692054599523544, 37.969937548041344, 37.96240255236626, 40.00648766756058, 40.728353932499886, 39.459860399365425, 41.496912091970444, 39.788231179118156, 39.52451013028622, 38.86725179851055, 39.19024586677551, 38.369474709033966, 38.63204821944237, 39.89478126168251, 39.14717137813568, 39.27222266793251, 39.18516553938389, 39.30984444916248, 41.78109884262085, 41.85421071946621, 41.29144951701164, 40.95796041190624, 43.31921450793743, 40.59359796345234, 42.875356525182724, 42.634103670716286, 45.92328317463398, 46.30208104848862, 49.336339831352234, 46.23290576040745, 49.31527756154537, 45.64942426979542, 52.38305054605007, 57.11081385612488, 63.11650559306145, 60.67252993583679, 71.9303910434246, 53.80281776189804, 58.07073354721069, 38.5728207975626, 0.1007382721581962, 0.8444172295276076, 0.6012152577750385, 0.3342292638262734, 12.478276770561934, 79.00672852993011, 63.497172966599464, 75.07856771349907, 63.29001188278198, 56.55660219490528, 21.85004163533449, 23.58890052884817, 47.84214220941067, 68.3244301378727, 40.478935316205025, 0.9497789258603007, 0.05051477884990163, 0.03769677525269799, 0.03867205377900973, 0.04104487430595327, 0.1348129808320664, 0.03455446632870007, 0.20809115812880918, 0.11023780694813468, 0.12821818236261606, 0.22440041735535488, 0.1381013629725203, 0.175618976354599, 0.22388895886251703, 0.29700684710405767, 0.17917657998623326, 8.243498057126999, 73.6615401506424, 66.20349034667015, 57.375511452555656, 55.24827539920807, 53.131701573729515, 59.696863889694214, 70.63129395246506, 70.89807003736496, 60.88260546326637, 68.10984045267105, 3.7991332774981856, 1.0591618157923222, 0.48047643969766796, 3.2472964888438582, 68.45866933465004, 66.18905112147331, 64.30878281593323, 55.14400899410248, 54.7200695425272, 52.534860000014305, 55.02238132059574, 49.12781082093716, 50.88890232145786, 47.31133349239826, 47.38824516534805, 45.03215119242668, 44.99797582626343, 44.84006389975548, 42.003003135323524, 43.311466723680496, 41.70253045856953, 40.09791076183319, 42.99131490290165, 41.49573415517807, 44.16914530098438, 39.66340407729149, 42.31090821325779, 39.76601757109165, 39.69246491789818, 40.00199630856514, 42.51849867403507, 39.80020813643932, 41.542798429727554, 39.83006693422794, 41.487386003136635, 39.6845081448555, 41.86299204826355, 41.84535339474678, 40.32506637275219, 40.287725776433945, 40.76411761343479, 40.76052300632, 40.15635922551155, 39.871838092803955, 38.42099614441395, 40.8137771487236, 42.014554515480995, 41.37168601155281, 42.6007604598999, 41.997721418738365, 43.62716518342495, 48.979896157979965, 54.49500761926174, 49.16996955871582, 44.450429007411, 37.350217401981354, 39.36598263680935, 37.25792035460472, 43.15374098718166, 43.79690207540989, 44.81097266077995, 42.5433911383152, 44.085933566093445, 40.04162818193436, 44.07562471926212, 42.45295599102974, 40.200524255633354, 41.8134731054306, 41.49036884307861, 40.74595458805561, 42.489122450351715, 41.09251119196415, 41.50042310357094, 42.34756864607334, 42.42158867418766, 41.45623527467251, 41.59332811832428, 41.0723152756691, 40.53935207426548, 38.11865396797657, 36.9846086204052, 39.16081264615059, 40.58515481650829, 40.48720747232437, 41.80585451424122, 49.30601745843887, 55.15883959829807, 46.41024224460125, 42.05171652138233, 42.53128878772259, 42.37818360328674, 40.78438192605972, 41.565730199217796, 42.756890282034874, 40.20902819931507, 40.49521364271641, 39.986436143517494, 41.39478497207165, 44.54608127474785, 41.1428052932024, 43.104795813560486, 42.16754570603371, 41.94834306836128, 41.328839510679245, 42.05162912607193, 41.53106465935707, 39.304650127887726, 42.48660698533058, 43.30965042114258, 40.16144335269928, 41.35316960513592, 42.44849123060703, 43.94657224416733, 44.37891684472561, 44.040450006723404, 44.38901290297508, 46.88048601150513, 42.79761269688606, 43.35280850529671, 44.93002027273178, 49.10567320883274, 49.80467990040779, 52.02289827167988, 48.93043041229248, 51.994228810071945, 47.14573457837105, 53.85650508105755, 60.660628974437714, 66.97471976280212, 64.10147354006767, 75.37613734602928, 56.852955892682076, 59.29020971059799, 43.236698135733604, 0.19668379914946854, 2.1817932883277535, 2.0634134905412793, 0.8518121077213436, 13.757826760411263, 84.27614897489548, 69.42876487970352, 82.24455758929253, 71.14864379167557, 68.17138195037842, 33.78878250718117, 33.73436562716961, 57.932656556367874, 78.4323513507843, 50.273779928684235, 1.399838828947395, 0.1619552361080423, 0.1284942019265145, 0.11524692527018487, 0.13812199467793107, 0.3313164826249704, 0.2408876732806675], [0.05650617415085435, 0.04889044023002498, 0.023820968162908684, 0.02736046153586358, 0.06429191926144995, 0.052776032316614874, 0.0892202218528837, 0.05811078277474735, 0.08699278434505686, 2.128593767993152, 51.66116528213024, 53.717755526304245, 45.47906041145325, 18.559572100639343, 18.301691338419914, 45.54418511688709, 59.328595250844955, 63.3813551813364, 48.71433600783348, 58.9246579259634, 7.090000128373504, 0.8937468356452882, 0.14215279166819528, 3.5482503147795796, 62.998286336660385, 61.66937604546547, 61.15902543067932, 50.89919596910477, 49.26794350147247, 47.64061622321606, 45.84723025560379, 42.08169311285019, 41.40628695487976, 40.33054567873478, 39.609093591570854, 37.63501591980457, 39.449714943766594, 40.40290519595146, 39.98092643916607, 35.92792332172394, 38.13975803554058, 37.33806185424328, 37.9289111495018, 36.491790264844894, 35.903053656220436, 36.27429373562336, 36.82609632611275, 35.56942015886307, 37.088590040802956, 35.6478251516819, 35.72102442383766, 34.337070286273956, 36.71541966497898, 34.59259897470474, 34.92078736424446, 35.04616543650627, 36.46965645253658, 35.80596886575222, 36.68541267514229, 36.72532953321934, 35.86637422442436, 36.88220791518688, 36.33425451815128, 35.634024292230606, 35.63038408756256, 38.07141110301018, 37.78762333095074, 39.503447860479355, 38.93545813858509, 35.42380057275295, 37.26803541183472, 42.90119893848896, 46.44535236060619, 49.431011751294136, 45.66568359732628, 38.153163716197014, 38.103762567043304, 36.57029405236244, 35.979003980755806, 36.80463507771492, 39.45804789662361, 39.89593259990215, 39.596763253211975, 36.96013033390045, 37.21846327185631, 37.525520995259285, 38.98197144269943, 38.101224303245544, 37.76265487074852, 37.18209162354469, 37.35135734081268, 37.399842739105225, 36.663328260183334, 37.36101642251015, 38.76890167593956, 38.96002382040024, 38.534332662820816, 40.123331397771835, 38.79360415041447, 37.055034041404724, 37.0605893433094, 37.55653493106365, 38.70958685874939, 38.25294256210327, 40.2767139673233, 44.75211761891842, 49.41282592713833, 45.25380089879036, 37.28857330977917, 35.867327973246574, 38.11423860490322, 38.679595068097115, 39.01648499071598, 37.33605936169624, 36.664426401257515, 36.49281620979309, 36.273586973547935, 36.455654203891754, 38.59180077910423, 37.57882073521614, 36.94341883063316, 36.59071035683155, 38.72809946537018, 35.992595851421356, 36.69830158352852, 35.82779109477997, 36.81725800037384, 35.084543377161026, 37.36570157110691, 36.54752567410469, 38.139119669795036, 37.68431827425957, 37.96386927366257, 39.251141399145126, 38.698620647192, 38.48560407757759, 38.24878938496113, 36.87404215335846, 39.458686262369156, 39.774475917220116, 42.90195509791374, 41.96056321263313, 45.417883694171906, 43.253333643078804, 45.53801044821739, 44.695474058389664, 54.32233728468418, 55.90204931795597, 61.135755479335785, 60.463168770074844, 69.15027022361755, 57.617338076233864, 43.08030612766743, 38.227400332689285, 1.1213021376170218, 0.761193442158401, 0.8219786616973579, 0.19917888479540125, 11.64212878793478, 72.8827415406704, 59.961109310388565, 70.5707024037838, 59.995470866560936, 62.93601147830486, 48.784313052892685, 31.095570623874664, 39.62598368525505, 57.778905406594276, 27.359540797770023, 0.6361357995774597, 0.0661022326676175, 0.0965720480598975, 0.06557507032994181, 0.062255258235381916, 0.04676326316257473, 0.05800316394015681, 0.11467016520327888, 0.07924913385068066, 0.035576856389525346, 0.02486095268977806, 0.017826379771577194, 0.07831815411918797, 0.06417874916223809, 0.06192697292135563, 0.08058186038397253, 2.866622465662658, 59.72183234989643, 60.39349190890789, 51.92142091691494, 29.209235943853855, 31.168990284204483, 54.45546314120293, 62.173506394028664, 67.81088009476662, 54.53331716358662, 63.1884129345417, 7.95735583640635, 0.7030499714892358, 0.11490463934023865, 4.437273647636175, 66.67484745383263, 63.87677639722824, 62.40833759307861, 52.58698560297489, 51.44751034677029, 49.18709523975849, 51.08227014541626, 43.51288251578808, 45.94119541347027, 42.02042520046234, 42.44916759431362, 40.72901889681816, 41.03597402572632, 41.68378986418247, 42.876344472169876, 40.08112706243992, 39.624915942549706, 38.79690237343311, 39.501912742853165, 36.822345927357674, 39.35416907072067, 38.30209292471409, 38.16010594367981, 36.90727137029171, 38.71497496962547, 39.13227237761021, 39.535818323493004, 37.55843862891197, 38.23205888271332, 38.33378702402115, 38.30968111753464, 36.298677027225494, 38.40027205646038, 36.45911581814289, 39.78112556040287, 37.1712926030159, 38.58208850026131, 37.469147220253944, 37.56919965147972, 38.85618679225445, 37.30825625360012, 39.45994399487972, 41.26566790044308, 40.87206222116947, 40.30042089521885, 37.35816277563572, 39.42851588129997, 44.46279354393482, 48.98521967232227, 49.93796914815903, 44.21264536678791, 37.609789073467255, 37.697727754712105, 36.78906351327896, 37.412131279706955, 38.63880805671215, 40.893021896481514, 42.0487754791975, 41.06416091322899, 39.130212888121605, 39.26946401596069, 38.454111367464066, 40.25628246366978, 40.29912896454334, 40.501171723008156, 39.200915694236755, 39.412336349487305, 39.0899882465601, 38.71621750295162, 40.574712976813316, 40.585652589797974, 40.511358976364136, 41.17896035313606, 40.89954234659672, 40.14014929533005, 37.517476826906204, 37.14158959686756, 36.99148625135422, 38.352641612291336, 37.70823799073696, 40.83845302462578, 46.36353515088558, 51.59468024969101, 46.65766976773739, 39.44467641413212, 38.01482833921909, 40.45317269861698, 41.3240859657526, 40.169989094138145, 38.091071248054504, 38.69914881885052, 37.69981004297733, 38.71982730925083, 38.43198895454407, 40.09589686989784, 39.67432089149952, 37.235911935567856, 38.399717286229134, 38.984562903642654, 38.59354108572006, 40.533937364816666, 40.11329233646393, 39.997877329587936, 39.17820431292057, 39.349274933338165, 38.71187433600426, 41.047126427292824, 39.81516793370247, 40.89507758617401, 42.03477323055267, 41.98721498250961, 41.22861988842487, 40.98188392817974, 39.09520536661148, 40.94304621219635, 41.01741202175617, 45.38009852170944, 44.345934614539146, 47.82301403582096, 45.124604031443596, 48.59941877424717, 47.56849989295006, 56.96236342191696, 59.30684521794319, 63.01963359117508, 62.30170391499996, 69.78447899222374, 60.538218542933464, 45.29826611280441, 42.51478627324104, 1.0993877635337412, 1.0809607710689306, 1.5401757485233247, 0.3122093266574666, 13.041038922965527, 78.26079055666924, 66.15811318159103, 75.24227052927017, 63.924448639154434, 65.52898094058037, 43.3829864859581, 34.50493387877941, 47.378008514642715, 65.74993148446083, 33.06208670139313, 0.744562684558332, 0.0361859815166099, 0.0642253783007618, 0.06401452672434971, 0.04527413271716796, 0.01900983443192672, 0.02391948084550677, 0.22858708020066842, 0.14690538664581254, 0.20233696064678952, 0.17616654775338247, 0.13495476072421297, 0.15507531934417784, 0.17413128196494654, 0.2604743605479598, 0.13818319217534736, 3.5532415844500065, 67.34102010726929, 69.40657407045364, 61.1273655295372, 29.526553116738796, 27.919816933572292, 60.496561378240585, 68.16162407398224, 77.68303915858269, 58.66411730647087, 70.89579775929451, 9.170255977660418, 1.0073384153656662, 0.4026290075853467, 5.241782627999783, 70.97436994314194, 66.47801041603088, 65.28280735015869, 55.079366862773895, 55.15513479709625, 51.043257638812065, 53.304235115647316, 46.49984523653984, 48.343472108244896, 44.48783040046692, 45.45959025621414, 42.14720539748669, 43.655089884996414, 45.93151733279228, 45.66688433289528, 41.468778401613235, 42.65239588916302, 42.205095291137695, 41.80791400372982, 40.49506925046444, 41.76275722682476, 41.76269643008709, 41.50600500404835, 40.665600299835205, 43.754709139466286, 40.01533359289169, 42.48315677046776, 40.07963754236698, 42.67987221479416, 41.174092814326286, 40.9193354845047, 39.80343796312809, 41.220552921295166, 38.95730696618557, 40.81267140805721, 40.5038695782423, 39.76321332156658, 39.83460009098053, 38.45813915133476, 39.80672858655453, 38.8672935962677, 41.82558685541153, 42.449642568826675, 42.43784800171852, 42.27682404220104, 40.83655692636967, 41.17077179253101, 46.93342477083206, 52.124261632561684, 52.851926386356354, 47.09265522658825, 40.45410744845867, 39.629597291350365, 37.40819089114666, 38.68765443563461, 39.7134055942297, 42.79879443347454, 44.52598795294762, 43.88301305472851, 42.8370051831007, 42.26786032319069, 40.737982615828514, 42.316376119852066, 41.83974489569664, 42.14496351778507, 42.91050843894482, 42.681095749139786, 42.563127279281616, 41.056834906339645, 43.48142020404339, 43.70814263820648, 41.88702955842018, 42.78878577053547, 42.412005588412285, 41.94618858397007, 38.73015135526657, 36.62467673420906, 36.906066834926605, 38.96910913288593, 38.407814651727676, 42.29627899825573, 47.90632836520672, 54.160363376140594, 50.13799421489239, 40.38282327353954, 39.601642191410065, 40.73313407599926, 42.72551916539669, 42.7966133505106, 40.68073868751526, 40.125029906630516, 39.511062651872635, 41.06426350772381, 41.55008263885975, 42.31721967458725, 40.997854471206665, 38.108907490968704, 41.0299551486969, 42.99310080707073, 40.13462819159031, 42.84484036266804, 42.50131979584694, 42.65193231403828, 40.16469217836857, 42.69759826362133, 42.580629140138626, 43.03233750164509, 43.35665389895439, 42.230519726872444, 45.326076820492744, 44.070730581879616, 44.4524846971035, 42.741045132279396, 41.22884787619114, 42.78971292078495, 44.660360142588615, 48.31439606845379, 46.561299338936806, 50.080537497997284, 47.28878550231457, 50.21882347762585, 50.29727026820183, 57.94122129678726, 61.54451094567776, 66.42124906182289, 65.44635817408562, 72.97952994704247, 61.932492926716805, 43.521515652537346, 45.503147318959236, 1.6008707229048014, 2.6614949852228165, 4.636300792917609, 0.3709870367310941, 13.983050175011158, 85.7183463871479, 70.56767776608467, 80.4589270055294, 70.26777505874634, 81.67860075831413, 60.301742032170296, 44.08367268741131, 56.92664913833141, 74.38664764165878, 40.167819410562515, 0.8249650045763701, 0.16975621751043946, 0.13368233368964866, 0.198318186448887, 0.14846538106212392, 0.1800977485254407, 0.2574777166591957], [0.04843070200877264, 0.04766512101923581, 0.12344951246632263, 0.03822773367573973, 0.006382451929312083, 0.040386066102655604, 0.05538413592148572, 0.054760524071753025, 0.08763709469349124, 0.7668183872010559, 38.95792633295059, 58.448171094059944, 49.1697795689106, 22.060385048389435, 15.628949906677008, 38.96837957203388, 56.85522437095642, 61.709152311086655, 51.820779517292976, 61.41777254641056, 14.043728169053793, 0.602515263017267, 0.08705758868018165, 2.049008463509381, 53.375279903411865, 64.67477917671204, 58.22241760790348, 51.30283311009407, 48.24344627559185, 45.32486088573933, 45.584858134388924, 42.847994193434715, 41.73936188220978, 41.163905560970306, 40.282854437828064, 39.695831537246704, 40.7427741587162, 38.97476322948933, 36.82195074856281, 36.02175548672676, 37.16333582997322, 37.129380851984024, 39.100061506032944, 39.6404343098402, 38.97117242217064, 38.59637573361397, 37.76909552514553, 35.94879940152168, 35.39083354175091, 35.86036294698715, 36.67757369577885, 34.95420277118683, 34.68458063900471, 35.74499733746052, 34.79627184569836, 35.403874441981316, 35.9188038110733, 35.98313815891743, 35.80490492284298, 35.96161611378193, 37.07153655588627, 35.90768940746784, 36.64182901382446, 35.13418771326542, 37.05642856657505, 38.25837627053261, 37.52353370189667, 39.78079877793789, 39.7193218767643, 37.92928732931614, 36.15658365190029, 42.263973131775856, 45.410964265465736, 49.26451228559017, 43.73395465314388, 35.63657395541668, 37.9238536208868, 37.53967523574829, 35.22376790642738, 36.921235620975494, 38.81504260003567, 36.90589964389801, 37.642683908343315, 36.478061601519585, 36.05993963778019, 35.58972626924515, 36.69710844755173, 38.894139155745506, 37.6189199835062, 36.430795937776566, 37.50946305692196, 36.724033802747726, 38.095083832740784, 36.660216227173805, 38.903475254774094, 38.09101805090904, 38.41845788061619, 38.62430803477764, 36.985231786966324, 37.07463338971138, 38.573956936597824, 38.57763893902302, 37.93470963835716, 41.20489776134491, 41.59465044736862, 47.550249472260475, 48.115035966038704, 46.48358590900898, 37.642623111605644, 38.53866063058376, 37.92477697134018, 35.71751341223717, 39.67346593737602, 36.079071611166, 37.08042427897453, 35.92528246343136, 36.81464374065399, 36.6008710116148, 38.36082637310028, 38.957268968224525, 37.084326669573784, 37.58328929543495, 37.86618031561375, 37.209172770380974, 35.2441082149744, 35.65542094409466, 37.34047472476959, 36.7624269425869, 36.57202675938606, 35.461490750312805, 37.85458333790302, 37.246980741620064, 38.33819478750229, 39.010880291461945, 39.74717438220978, 38.03081028163433, 39.33058753609657, 40.15094071626663, 38.916964530944824, 39.27904710173607, 40.22858954966068, 43.59665662050247, 42.66726829111576, 43.384278416633606, 42.35721632838249, 51.92064955830574, 55.2656214684248, 59.58111830055714, 61.33701927959919, 63.910548985004425, 60.97450353205204, 64.57544490695, 62.535113990306854, 42.211748734116554, 1.2702511763200164, 0.5618402268737555, 0.1978427666472271, 0.4423626442439854, 12.111101523041725, 71.67591869831085, 59.15340185165405, 69.25748527050018, 57.38543651998043, 53.25255788862705, 34.02220398187637, 29.52976394444704, 45.16243100166321, 57.371118888258934, 24.04352903366089, 0.7318037410732359, 0.060893602785654366, 0.11774582555517554, 0.0671707843139302, 0.04265819203283172, 0.10800348230986856, 0.010687575922929682, 0.03494831296848133, 0.029686660345760174, 0.08940607789554633, 0.06235230146558024, 0.048270939878420904, 0.009718194687593495, 0.04033752222312614, 0.046079244202701375, 0.030179238601704128, 0.9475275466684252, 46.65838412940502, 65.0720402598381, 55.939184725284576, 25.145352110266685, 21.687854938209057, 50.7701700925827, 60.0236539542675, 68.05955395102501, 55.86907848715782, 66.92326292395592, 15.02815654501319, 0.5043463432230055, 0.09313386341091245, 2.0041646948084235, 56.87635883688927, 65.38279518485069, 60.69780997931957, 52.46581010520458, 48.98597203195095, 46.78147852420807, 47.85527430474758, 45.169992595911026, 43.88658106327057, 44.01087999343872, 42.02726103365421, 42.59655028581619, 43.528777062892914, 40.858842730522156, 40.39557158946991, 37.66303941607475, 38.263965770602226, 37.921961322426796, 40.49447648227215, 40.832130163908005, 40.47884792089462, 41.61646127700806, 38.17342422902584, 37.693088203668594, 38.0619116127491, 37.38028138875961, 38.4320155531168, 36.834566071629524, 36.89136542379856, 38.07763136923313, 38.347865268588066, 38.02480660378933, 37.1433375030756, 38.22401091456413, 37.9333683103323, 37.28668861091137, 37.153881937265396, 37.49708712100983, 38.45476873219013, 36.46529048681259, 38.296431228518486, 39.96188186109066, 37.483768835663795, 40.634179785847664, 41.23711623251438, 37.780247926712036, 37.855134308338165, 45.40572814643383, 47.71402448415756, 50.31126871705055, 44.54956568777561, 35.89026354253292, 38.11684146523476, 38.21227714419365, 36.591778099536896, 37.73338124155998, 39.71822753548622, 39.183474630117416, 41.449646428227425, 38.47625657916069, 37.383199632167816, 38.02362486720085, 38.6191289126873, 41.03040732443333, 40.11134684085846, 40.071897357702255, 38.25494885444641, 37.56165325641632, 39.08120311796665, 39.5184950530529, 39.378943741321564, 40.62396213412285, 40.28416156768799, 39.171357080340385, 37.613588869571686, 37.81637638807297, 39.93898048996925, 37.458249405026436, 37.40827068686485, 40.84329016506672, 42.00091704726219, 49.04333755373955, 49.46705661714077, 47.212945371866226, 41.24235615134239, 39.1453018784523, 38.80726061761379, 36.6735003143549, 42.43334524333477, 39.15840357542038, 38.258057087659836, 38.05158756673336, 38.175365924835205, 38.93685266375542, 39.5039152354002, 38.666405975818634, 39.223467484116554, 39.28530916571617, 38.98110128939152, 39.17174085974693, 37.76721082627773, 38.525019362568855, 38.55381801724434, 38.51148448884487, 39.5436193048954, 38.453579396009445, 38.31918440759182, 39.173431769013405, 40.65216422080994, 40.643116906285286, 42.22789026796818, 40.89473940432072, 42.00973257422447, 42.24388740956783, 41.58779561519623, 42.23220303654671, 42.41381049156189, 44.52024646103382, 44.19665202498436, 46.283462047576904, 46.36317417025566, 52.12217174470425, 58.390459790825844, 62.919995337724686, 63.425733000040054, 64.21654656529427, 62.315185591578484, 65.83207547664642, 64.95733201503754, 46.93016454577446, 1.241552266292274, 0.5037451442331076, 0.7673542771954089, 0.26839129510335624, 12.9600871168077, 76.15377321839333, 64.66141149401665, 75.61620086431503, 63.53709742426872, 65.26251643896103, 43.25565531849861, 34.571198523044586, 52.28444963693619, 65.83875551819801, 30.12891959398985, 0.7634737947955728, 0.058748439769260585, 0.1033696012746077, 0.0628989451797679, 0.0507389593985863, 0.055320081155514345, 0.05535671727557201, 0.23030623560771346, 0.10497264767764136, 0.24492565426044166, 0.18136866157874465, 0.1783309323946014, 0.12700236635282636, 0.10208379331743345, 0.16047655139118433, 0.27975384320598096, 1.1249202559702098, 53.68463270366192, 72.91402146220207, 63.88170853257179, 32.20830291509628, 23.972370252013206, 54.84307274222374, 64.71597656607628, 73.4630236029625, 60.27890145778656, 76.28192514181137, 17.669460363686085, 0.6750328280031681, 0.18473587464541197, 2.9953469708561897, 60.541949942708015, 66.38625293970108, 62.977011278271675, 57.0442908257246, 52.24943071603775, 49.75354224443436, 51.030942499637604, 48.00830349326134, 47.65339493751526, 46.349627897143364, 45.23155689239502, 45.43179094791412, 47.05070547759533, 44.04028281569481, 42.298376485705376, 39.593195244669914, 40.913157016038895, 41.545302495360374, 43.18971745669842, 43.69425818324089, 44.08686451613903, 43.57945114374161, 41.0615998506546, 40.59557765722275, 39.63941216468811, 39.738115668296814, 41.32534749805927, 39.269749000668526, 40.343635976314545, 40.82956150174141, 40.47257445752621, 40.19389361143112, 39.00639273226261, 40.53726598620415, 40.37673220038414, 39.892573580145836, 40.20954117178917, 40.06350360810757, 39.47517357766628, 38.08677367866039, 40.69256365299225, 41.925878673791885, 41.28673776984215, 42.97651469707489, 43.59176628291607, 40.98577491939068, 40.15531428158283, 48.223702535033226, 49.704027101397514, 53.09784539043903, 46.59245766699314, 36.14288918673992, 38.23665663599968, 39.13945019245148, 37.1480568498373, 37.9206807911396, 42.51361973583698, 40.10230712592602, 44.120158329606056, 40.38226090371609, 39.485243037343025, 37.73908093571663, 41.83261267840862, 43.03282767534256, 42.598902359604836, 41.27317249774933, 41.695736423134804, 39.81634587049484, 42.866491600871086, 40.81869028508663, 40.95212012529373, 41.455847695469856, 40.690082386136055, 42.41217277944088, 39.34327885508537, 38.71867977082729, 40.56555166840553, 37.46146023273468, 36.783451214432716, 40.93028649687767, 41.57266102731228, 51.06131047010422, 52.71850414574146, 50.04457622766495, 43.2306944578886, 42.22925439476967, 39.09365884959698, 38.00751373171806, 45.4767919331789, 40.19285246729851, 40.11420048773289, 40.85130773484707, 40.347648561000824, 39.98447924852371, 42.50551477074623, 41.78642235696316, 40.254496559500694, 41.57590985298157, 41.739684864878654, 42.96290382742882, 41.221590265631676, 39.93776075541973, 41.78438946604729, 41.692882776260376, 41.677797585725784, 40.87665997445583, 42.4536969512701, 41.70544110238552, 43.05270440876484, 42.99057774245739, 44.357569590210915, 42.97379784286022, 43.44586931169033, 44.650868251919746, 42.57809467613697, 43.83561819791794, 43.14105346798897, 48.54949705302715, 46.25625170767307, 49.310786202549934, 48.75059366226196, 56.81854113936424, 59.41211476922035, 65.00021651387215, 64.87730070948601, 67.36979216337204, 64.55833822488785, 68.51310521364212, 65.50024688243866, 49.22160118818283, 1.6028880584053695, 0.7924158917739987, 4.875946333631873, 0.4616573260864243, 14.696307051926851, 80.62958344817162, 69.888806194067, 80.78944846987724, 68.77855896949768, 70.20523801445961, 44.33630973100662, 41.949323415756226, 61.60726837813854, 75.30271768569946, 36.93515047430992, 0.7755297760013491, 0.1683345000492409, 0.21420464414404705, 0.16120721062179655, 0.1802913154824637, 0.18801509868353605, 0.07933616550872102], [0.08486400794936344, 0.0440287829405861, 0.027039788801630493, 0.02198546440922655, 0.05608937288343441, 0.03429344928008504, 0.052762425038963556, 0.016825844104459975, 0.13815533195156604, 0.21887698327191174, 28.153151012957096, 65.4892198741436, 41.193916350603104, 36.5488214045763, 34.33335788547993, 41.642280891537666, 57.00013339519501, 64.20686468482018, 50.976259633898735, 58.24312649667263, 21.8356841057539, 0.3054835688089952, 0.1856667356332764, 0.06169286243675742, 35.14652945101261, 68.63464549183846, 62.0290457457304, 57.26822040975094, 50.15157088637352, 48.07563968002796, 47.32383482158184, 44.631177708506584, 43.787106201052666, 41.18206098675728, 42.033188715577126, 39.480310901999474, 37.58764386177063, 36.04077726602554, 36.63677528500557, 40.537539571523666, 40.521280243992805, 43.21560926735401, 42.2988248616457, 41.157206520438194, 41.90478980541229, 41.706440448760986, 38.68529096245766, 37.06718198955059, 35.966593846678734, 35.73166385293007, 36.06756202876568, 35.405090376734734, 36.5820050239563, 35.17676442861557, 34.152806773781776, 35.29765494167805, 35.05346104502678, 37.08086505532265, 36.98530398309231, 35.21740324795246, 36.50355823338032, 38.170528784394264, 34.916827976703644, 38.65459240972996, 37.97852888703346, 36.82570494711399, 38.36335323750973, 37.8920379281044, 39.792555347085, 37.74602696299553, 34.042939469218254, 41.037292554974556, 45.214678198099136, 46.81422896683216, 46.13473042845726, 36.79713808000088, 37.571536526083946, 37.02349953353405, 37.3256479203701, 37.66870491206646, 37.778427824378014, 38.9140272885561, 36.570905819535255, 36.58399611711502, 36.08542487025261, 36.48582458496094, 37.9803641885519, 36.62563808262348, 37.13140234351158, 38.7619024515152, 37.65471026301384, 36.34186930954456, 37.13298685848713, 34.748489409685135, 38.309703916311264, 37.8136595338583, 40.57097017765045, 39.74690459668636, 38.24049063026905, 36.85348905622959, 39.062743708491325, 37.390358448028564, 39.08035956323147, 37.954202592372894, 43.300086334347725, 49.2244890332222, 47.03194208443165, 44.00816693902016, 37.42506958544254, 36.03085219860077, 36.12903892993927, 37.05819547176361, 38.05828280746937, 37.501776069402695, 36.471871733665466, 38.25567081570625, 36.349073722958565, 36.10223896801472, 37.63902470469475, 36.69573292136192, 37.14508540928364, 37.7996800839901, 35.98476827144623, 36.08081191778183, 36.03203773498535, 36.76216095685959, 36.41081660985947, 36.72381341457367, 36.8696191906929, 37.57942110300064, 37.035518288612366, 35.69475643336773, 36.9745771586895, 37.029514610767365, 37.64990732073784, 38.01911070942879, 38.62991653382778, 39.75655987858772, 39.51559580862522, 39.308438524603844, 40.661295130848885, 41.35617144405842, 42.2340839356184, 40.42316570878029, 43.644439056515694, 47.93773368000984, 58.05455781519413, 57.45783023536205, 61.81069426238537, 60.39459764957428, 62.80211426317692, 55.90780980885029, 63.84298101067543, 53.53466235101223, 1.433066502213478, 0.9161005017813295, 1.159319335129112, 0.2466549028758891, 15.728955790400505, 71.29973128437996, 59.43041458725929, 67.52443626523018, 56.843779385089874, 49.16768208146095, 36.06659308075905, 41.9971514493227, 46.36812910437584, 58.60889866948128, 13.703626468777657, 0.796828226884827, 0.06690473179332912, 0.12361073662759736, 0.04502083029365167, 0.0877686329477001, 0.054835852060932666, 0.04422576748766005, 0.021663196057488676, 0.04784313256095629, 0.058911842133966275, 0.027734246068575885, 0.08058147446718067, 0.11736127431504428, 0.06683022016659379, 0.0240354451307212, 0.10885417650570162, 0.22429396369261667, 34.78548042476177, 72.00619697570801, 48.19892406463623, 36.73842363059521, 30.81916205585003, 47.07081779837608, 61.938162222504616, 69.95086446404457, 56.39701835811138, 64.36588615179062, 25.270008221268654, 0.2820556587539613, 0.12384273199131712, 0.05324899189872667, 39.07551862299442, 68.78616616129875, 63.54517959058285, 58.53602237999439, 53.140859082341194, 49.88954454660416, 48.91682714223862, 45.99020518362522, 45.505119413137436, 43.842879608273506, 43.63229490816593, 41.57754756510258, 40.60179032385349, 37.666668221354485, 39.651275128126144, 41.720606088638306, 42.171824276447296, 43.321703374385834, 42.48118847608566, 42.47897319495678, 43.57243672013283, 43.178637251257896, 40.891118198633194, 39.07885484397411, 37.81260319054127, 37.07759343087673, 37.63991765677929, 36.83423548936844, 38.46394523978233, 38.73407654464245, 36.56886152923107, 37.47881770133972, 38.73875789344311, 37.459165155887604, 38.67323040962219, 38.04610066115856, 38.12721870839596, 39.861943423748016, 36.496524810791016, 39.24244366586208, 39.52553987503052, 39.91621971130371, 39.05942648649216, 38.749739304184914, 41.24332509934902, 40.29258571565151, 35.73273539543152, 43.33732433617115, 46.49907007813454, 49.310820400714874, 47.64893777668476, 38.61516572535038, 38.5382654517889, 36.58095248043537, 37.46033549308777, 37.89400242269039, 40.80089583992958, 40.3565476834774, 38.4854406863451, 38.41969661414623, 38.601209074258804, 38.64514611661434, 40.073945447802544, 38.54607403278351, 39.75157834589481, 38.454916924238205, 39.05881091952324, 38.888196274638176, 38.72583858668804, 38.059730529785156, 39.22613874077797, 39.997523948550224, 40.44999226927757, 39.73415248095989, 39.79175738990307, 38.0607944726944, 38.83591867983341, 37.83421643078327, 39.79877941310406, 37.57326923310757, 43.10020945966244, 50.173279121518135, 49.4099722802639, 47.71336331963539, 39.27174009382725, 40.18559105694294, 38.48075933754444, 38.23955588042736, 38.52646328508854, 38.248075023293495, 38.31626236438751, 39.014843478798866, 38.36942531168461, 38.19334276020527, 40.12332759797573, 39.093142077326775, 38.31872083246708, 40.072942301630974, 40.17885781824589, 38.34234796464443, 37.75591403245926, 39.306835010647774, 39.084516540169716, 38.03640358150005, 38.9798017591238, 40.2734499424696, 40.4337253421545, 38.61489973962307, 40.40517747402191, 38.987564742565155, 40.500518158078194, 40.19288666546345, 40.56490570306778, 43.74891445040703, 41.762221455574036, 42.15061381459236, 42.914760410785675, 42.62428119778633, 45.46590931713581, 42.76311434805393, 45.56435443460941, 50.998211055994034, 61.47283919155598, 60.34291282296181, 64.38753738999367, 62.40787781774998, 65.6096202135086, 60.068719536066055, 66.45379811525345, 56.56417138874531, 1.9146705907769501, 0.7501857890747488, 0.7440389064140618, 0.2703823585761711, 17.210036516189575, 77.02398732304573, 65.14754980802536, 75.72652414441109, 61.86664246022701, 58.93400922417641, 35.66818445920944, 45.24244710803032, 53.094801753759384, 68.68294849991798, 19.381931573152542, 0.8346098370384425, 0.021047495501989033, 0.13383992132730782, 0.02106412146531511, 0.05477448386955075, 0.026495690653973725, 0.034867207359638996, 0.18733141740085557, 0.155252737167757, 0.11593868854106404, 0.1295840012608096, 0.1449641361250542, 0.16012048377888277, 0.1342505367938429, 0.09894254937535152, 0.22212285519344732, 0.3434393758652732, 40.93719832599163, 79.70963761210442, 55.52256368100643, 50.08245259523392, 43.65127868950367, 55.179069712758064, 68.03584322333336, 73.10635194182396, 62.71524332463741, 67.74583518505096, 28.66230469197035, 0.3694538783747703, 0.22089224075898528, 0.19441803713561967, 42.02022761106491, 70.15914648771286, 68.29053595662117, 60.172700956463814, 55.88704772293568, 53.88843476772308, 51.30839221179485, 49.61694337427616, 47.24841266870499, 45.93468636274338, 48.13413754105568, 44.00832653045654, 42.026387080550194, 40.197822600603104, 41.23056538403034, 45.31143240630627, 43.76990832388401, 47.82380819320679, 46.364644691348076, 44.25318159162998, 45.78270971775055, 46.674962639808655, 44.53070729970932, 42.179781049489975, 40.41372701525688, 39.727217853069305, 40.66882632672787, 37.86643490195274, 41.72321654856205, 41.85565464198589, 39.673211351037025, 40.40110029280186, 40.409862622618675, 39.92833346128464, 40.9163336455822, 39.75982390344143, 40.502756237983704, 43.56124632060528, 39.132724553346634, 42.21931412816048, 40.99620535969734, 41.039272248744965, 42.0950797945261, 40.74543781578541, 42.76845686137676, 42.80063733458519, 37.91321039199829, 45.89706838130951, 48.84170137345791, 51.786554753780365, 49.131625816226006, 38.956512808799744, 40.471955090761185, 38.540993705391884, 40.608447566628456, 39.662055149674416, 42.53381185233593, 42.58396156132221, 40.614835023880005, 41.54624484479427, 40.751840472221375, 40.950201228260994, 42.89696216583252, 40.431042686104774, 43.40284042060375, 43.490060940384865, 41.123034954071045, 41.17671847343445, 40.49740232527256, 39.02826435863972, 42.69404545426369, 41.7231709510088, 42.115518897771835, 41.36462599039078, 40.41763700544834, 39.40759800374508, 41.143580451607704, 38.65811102092266, 39.73956719040871, 37.09588944911957, 44.5181679725647, 54.307540878653526, 51.05647712945938, 48.289378210902214, 42.440663650631905, 42.08635926246643, 39.26806569099426, 41.08838461339474, 40.268825590610504, 40.19402280449867, 39.96169567108154, 42.508398815989494, 40.78540027141571, 40.21535865962505, 42.74847753345966, 40.864082649350166, 40.80225616693497, 43.00995670258999, 40.65383993089199, 40.68816348910332, 40.91835133731365, 43.00923474133015, 41.60810932517052, 41.349548399448395, 42.92193442583084, 42.99955666065216, 42.964100763201714, 41.55999630689621, 41.405990570783615, 42.38845445215702, 42.13557042181492, 43.394712656736374, 41.657217890024185, 46.029852256178856, 43.72338742017746, 44.223402589559555, 46.06604151427746, 46.51856683194637, 47.8891608864069, 43.603040277957916, 48.50560940802097, 53.04760828614235, 63.77599820494652, 61.67734421789646, 68.23120594024658, 65.42982906103134, 68.58815878629684, 60.828256979584694, 67.7852314710617, 58.81867781281471, 2.814442478120327, 1.5863063419237733, 5.1389506459236145, 0.42634567245841026, 17.538886070251465, 83.27820092439651, 71.1859729886055, 82.38209500908852, 68.12930300831795, 65.63118025660515, 47.07567013800144, 56.17234021425247, 62.75951474905014, 79.14433434605598, 25.484662503004074, 0.7767793152015656, 0.19565913069527596, 0.1659130651387386, 0.15952790854498744, 0.21920995524851605, 0.20454443438211456, 0.24373416585149243], [0.06776571957743727, 0.015687771774537396, 0.017830613724072464, 0.06306606199359521, 0.029184124323364813, 0.0378055295732338, 0.04939095575537067, 0.0636800259235315, 0.2089208792313002, 0.07113398649380542, 13.552958853542805, 60.93472346663475, 44.52759146690369, 35.505309998989105, 25.24252239614725, 39.48738992214203, 52.28455223143101, 55.39893351495266, 53.86729650199413, 55.83688281476498, 36.378297954797745, 0.24667215038789436, 0.28256218938622624, 0.1411537718377076, 9.576419983059168, 65.586456656456, 59.23755593597889, 57.92822599411011, 52.2175732254982, 50.293117091059685, 48.6646992713213, 49.87223647534847, 43.77789929509163, 43.525889217853546, 40.20642913877964, 38.629593551158905, 36.71685978770256, 39.4994542747736, 41.661169677972794, 44.35829535126686, 46.3530021160841, 46.97991527616978, 45.66718831658363, 46.180688962340355, 43.58359292149544, 41.752402782440186, 38.844323828816414, 37.414601147174835, 35.86181066930294, 37.1845006942749, 35.92639200389385, 36.763882264494896, 35.25811426341534, 35.7052780687809, 36.50045000016689, 34.6898927539587, 37.174271643161774, 37.40675836801529, 36.81172549724579, 35.937061831355095, 36.22694827616215, 36.64616838097572, 36.180115789175034, 36.0588338971138, 36.64999857544899, 36.9927553832531, 37.56843589246273, 37.874308079481125, 36.586177200078964, 37.4049686640501, 34.65463064610958, 40.49579881131649, 43.88535372912884, 46.1538016051054, 45.15019565820694, 37.70683966577053, 35.971491783857346, 36.23242758214474, 36.5031972527504, 36.387824043631554, 37.5661826133728, 38.108025938272476, 36.40429615974426, 37.005940675735474, 36.09978809952736, 38.39047618210316, 37.63248145580292, 38.737142980098724, 37.921197563409805, 38.090258091688156, 37.49549500644207, 35.655899718403816, 36.75228528678417, 38.7068510055542, 37.98601448535919, 38.44024211168289, 39.520957320928574, 36.794820204377174, 35.73708616197109, 36.03493317961693, 36.81716300547123, 38.64932969212532, 39.11907188594341, 38.418104499578476, 45.700436532497406, 47.373308166861534, 47.22117193043232, 44.09734055399895, 38.441754430532455, 36.174628883600235, 37.681563422083855, 37.99766086041927, 36.37404978275299, 37.156393602490425, 36.70245096087456, 37.42720127105713, 36.20949201285839, 36.99477307498455, 36.7287303507328, 37.17190057039261, 36.179044246673584, 36.07725150883198, 35.3196557611227, 36.858200803399086, 35.551899299025536, 36.5641725808382, 36.596527844667435, 36.16265572607517, 36.03571213781834, 36.63753904402256, 37.265204563736916, 38.73193345963955, 38.359868824481964, 39.02423657476902, 38.369216322898865, 38.00277538597584, 38.02900157868862, 38.88321094214916, 38.98610562086105, 39.46603126823902, 40.55669054389, 41.19772754609585, 41.43363408744335, 40.81579104065895, 43.422394171357155, 42.215309143066406, 49.45054650306702, 55.8206120878458, 58.16377155482769, 56.37453876435757, 55.00025510787964, 57.57574550807476, 62.32584401965141, 55.42951047420502, 1.59739984665066, 0.5652062525041401, 0.4160295525798574, 0.35055063490290195, 18.12851183116436, 72.96804696321487, 60.089162439107895, 67.52981677651405, 59.50242832303047, 49.027488604187965, 30.34426923841238, 47.20458962023258, 44.26390841603279, 57.551806792616844, 7.734826477244496, 0.6697179819457233, 0.06546915101353079, 0.030103504286671523, 0.060630277657764964, 0.09183678223052993, 0.053818835149286315, 0.03572380905097816, 0.041369126047356986, 0.09293576193158515, 0.039007025843602605, 0.03840462086373009, 0.02419675834971713, 0.03626088277087547, 0.04060579747601878, 0.03152569857775234, 0.10843017269507982, 0.014858605427434668, 19.50231671333313, 70.09337961673737, 50.58594837784767, 40.22921271622181, 28.296407125890255, 45.181695967912674, 59.2956168204546, 62.860748916864395, 57.88481332361698, 62.74577088654041, 40.10533556342125, 0.2982097497442737, 0.23598267085617408, 0.11373053945135325, 11.152085233479738, 68.35550487041473, 61.01894214749336, 57.516829669475555, 55.02461560070515, 53.4406515955925, 49.81691524386406, 51.880839094519615, 45.046696811914444, 46.681547686457634, 44.11066263914108, 40.574412792921066, 38.006442189216614, 40.18287040293217, 43.632982671260834, 46.372301280498505, 48.82888466119766, 49.3786695599556, 47.41605967283249, 46.57486841082573, 46.15744560956955, 45.34508720040321, 43.35525557398796, 39.46707621216774, 37.63612546026707, 40.08624538779259, 37.98632986843586, 39.30903509259224, 37.591291666030884, 37.93467923998833, 38.3922278881073, 35.858634039759636, 39.71704199910164, 39.963257387280464, 39.98181939125061, 38.345042020082474, 37.944383919239044, 38.581571727991104, 38.71617190539837, 38.18443983793259, 38.783302903175354, 39.453119561076164, 39.07128185033798, 40.13219632208347, 39.05394338071346, 40.13924114406109, 36.16884559392929, 42.188030406832695, 46.11992262303829, 48.65816742181778, 48.24251152575016, 38.34021247923374, 36.83471046388149, 36.92033126950264, 38.974580839276314, 38.64309802651405, 40.31248524785042, 42.044052332639694, 39.115386083722115, 38.01806576550007, 39.074131697416306, 40.952028930187225, 38.970021083950996, 39.98290233314037, 39.951527416706085, 39.78425279259682, 39.023529812693596, 38.51971484720707, 38.78684811294079, 38.33942212164402, 40.416352674365044, 40.27365133166313, 41.18596337735653, 38.09777028858662, 39.031042009592056, 36.14677257835865, 37.92443498969078, 37.986565455794334, 38.98157626390457, 39.10668455064297, 45.41155703365803, 49.80401113629341, 48.99136394262314, 45.021975338459015, 39.77316118776798, 37.62064129114151, 39.23533044755459, 39.602671936154366, 37.95417979359627, 39.26985539495945, 38.149709701538086, 38.88485625386238, 38.22272278368473, 38.92024375498295, 38.72089505195618, 38.24205234646797, 39.911808148026466, 38.32832671701908, 38.28771069645882, 39.116560220718384, 38.14508154988289, 40.034226179122925, 39.360560327768326, 38.63074108958244, 37.58138559758663, 38.63243579864502, 39.427790120244026, 40.79061359167099, 40.87028011679649, 41.276109740138054, 39.223003908991814, 39.8350028693676, 41.247375681996346, 40.987777411937714, 41.68365307152271, 42.20160327851772, 42.079048454761505, 44.00719419121742, 45.20345360040665, 44.4220407307148, 44.773715659976006, 45.16346454620361, 52.39384576678276, 58.604616299271584, 62.98402190208435, 59.57052066922188, 57.51485377550125, 59.75231811404228, 66.13615795969963, 59.44728568196297, 2.034144136123359, 1.06585978763178, 0.675556012429297, 0.3659679810516536, 20.093819573521614, 77.63744160532951, 66.45942941308022, 74.91431772708893, 64.07159954309464, 57.895578145980835, 36.51999235153198, 53.137070685625076, 50.10603033006191, 68.29463213682175, 11.981762163341045, 0.7522253296338022, 0.028372205488267355, 0.07641729869646952, 0.06781703166780062, 0.03261410638515372, 0.08045966576901264, 0.08074518482317217, 0.13933442649431527, 0.27258496382273734, 0.1500943209975958, 0.14464434469118714, 0.07753411962767132, 0.10726721986429766, 0.13490436889696866, 0.1342202423256822, 0.4729766515083611, 0.18790897156577557, 22.436371073126793, 78.43679711222649, 59.68148231506348, 46.72565571963787, 35.39029397070408, 54.37353573739529, 65.06152242422104, 64.48269188404083, 63.57556276023388, 65.9911197423935, 46.85119718313217, 0.291025047772564, 0.3517529438249767, 0.18895113986218348, 12.642996981739998, 70.9233994781971, 64.31372255086899, 61.657881662249565, 56.18673384189606, 55.28237096965313, 51.6190255433321, 55.32473109662533, 46.93146787583828, 49.00548778474331, 45.09324811398983, 42.80155308544636, 39.932232052087784, 44.44419354200363, 46.38096481561661, 49.72060561180115, 51.226688995957375, 50.751186311244965, 49.03164178133011, 49.41893219947815, 47.51651868224144, 47.119766771793365, 44.403748512268066, 42.46025539934635, 40.22373341023922, 43.00131596624851, 40.22660605609417, 42.72566355764866, 40.506563633680344, 39.78681765496731, 41.40217177569866, 38.15751828253269, 42.33949027955532, 41.681057810783386, 41.52218073606491, 40.25110334157944, 40.73287948966026, 39.773309379816055, 40.66008299589157, 38.94205458462238, 40.41791059076786, 40.9267944842577, 41.52623891830444, 42.898896262049675, 40.35387642681599, 40.764900371432304, 39.75272208452225, 44.56211261451244, 49.0310338139534, 50.57074919342995, 49.31175135076046, 39.502402916550636, 36.9825529307127, 39.413100108504295, 39.483175948262215, 40.60405120253563, 40.637086629867554, 42.040415927767754, 41.08627572655678, 41.862532272934914, 40.91569907963276, 43.11293497681618, 42.3268673568964, 41.4645454287529, 43.779164627194405, 41.20373122394085, 41.6971043497324, 39.166288152337074, 43.00081439316273, 41.70490153133869, 41.49555176496506, 41.599833369255066, 43.05653840303421, 38.877245262265205, 38.30333545804024, 36.948977932333946, 38.26593026518822, 40.24581402540207, 39.346409887075424, 38.361859917640686, 47.626028805971146, 50.73145776987076, 51.85879647731781, 49.12742704153061, 42.314016446471214, 39.989669770002365, 40.57577311992645, 43.13303589820862, 39.576061964035034, 42.08566389977932, 40.96707612276077, 41.48059956729412, 40.53420715034008, 42.5783758610487, 40.74467785656452, 40.31165689229965, 41.55028782784939, 38.69265116751194, 40.686445981264114, 41.90516218543053, 40.45812003314495, 42.96577267348766, 41.785039231181145, 41.2367058545351, 41.13949567079544, 43.15237306058407, 41.521755158901215, 43.32566276192665, 43.131325989961624, 44.35386098921299, 41.13781996071339, 41.792011857032776, 43.77232499420643, 43.83123703300953, 43.946887627243996, 43.01714211702347, 44.26320545375347, 47.23674349486828, 46.43258884549141, 45.20311541855335, 47.34486669301987, 48.68951573967934, 53.584367483854294, 61.574992910027504, 65.19871786236763, 63.25780101120472, 59.08457614481449, 64.09219443798065, 66.41381666064262, 62.25901700556278, 2.677346309646964, 1.1209947103634477, 2.1042218757793307, 0.4632847965694964, 20.776458643376827, 82.67952024936676, 70.19310906529427, 79.3148235976696, 71.42684206366539, 65.57090029120445, 41.19420513510704, 62.508325427770615, 60.34144230186939, 79.23733815550804, 15.344614963978529, 0.9964442811906338, 0.11506418624776416, 0.16831081069540232, 0.08218108472647145, 0.19012823060620576, 0.17105228936998174, 0.16687534865923226], [0.06076937839679886, 0.0616312307829503, 0.027358877050573938, 0.021814998654008377, 0.05237886085524224, 0.0902850553393364, 0.041155265062116086, 0.05578122574661393, 0.0740492984186858, 0.12393390483339317, 6.06431451626122, 54.86105337738991, 51.37054167687893, 38.561995178461075, 23.430065251886845, 34.56545703113079, 52.785213366150856, 60.0384883582592, 56.627077013254166, 52.08084516227245, 44.95395138859749, 0.8943457785062492, 0.23189232393633574, 0.1528321037767455, 0.05531470800633542, 37.514228001236916, 65.09048447012901, 57.518262192606926, 56.3636789470911, 52.52286784350872, 50.78008756041527, 50.52674375474453, 46.34379900991917, 41.34281516075134, 40.162537693977356, 40.59689238667488, 47.83485800027847, 49.442604929208755, 52.078831270337105, 53.009032756090164, 50.07115580141544, 46.997056156396866, 47.62602120637894, 47.18006193637848, 44.43347431719303, 42.89877086877823, 38.612794652581215, 37.22090654075146, 35.11261627078056, 36.350076869130135, 36.152882650494576, 35.79710774123669, 35.93170031905174, 35.29869608581066, 35.56880459189415, 35.741744711995125, 35.266173630952835, 37.54546992480755, 34.62544821202755, 35.761450454592705, 37.11970277130604, 36.73234775662422, 36.10022507607937, 35.561828166246414, 36.1304372549057, 37.55067564547062, 37.486136108636856, 40.528526455163956, 40.407495349645615, 38.09542961418629, 34.30308870971203, 40.12288302183151, 43.77164103090763, 43.90373334288597, 46.47000163793564, 39.214275777339935, 37.242892161011696, 35.41718892753124, 36.86603978276253, 35.85989937186241, 37.97295838594437, 38.941970989108086, 35.67969024181366, 37.176357731223106, 36.16222254931927, 37.563423961400986, 38.268149346113205, 38.17902892827988, 36.82452321052551, 37.346744388341904, 38.78761947154999, 35.9519000351429, 36.667557433247566, 36.99346214532852, 39.3463034927845, 38.87985572218895, 39.6928296983242, 37.73034520447254, 35.307652205228806, 35.150177255272865, 36.670156493783, 37.64648750424385, 38.54694418609142, 40.134624391794205, 46.534947752952576, 46.61784790456295, 46.75130054354668, 45.003933906555176, 38.915721997618675, 37.42566615343094, 37.94302359223366, 35.801694095134735, 37.15338796377182, 36.1785464733839, 35.35817429423332, 37.11105823516846, 36.88023202121258, 36.12701743841171, 37.051758617162704, 37.41451375186443, 34.852497428655624, 35.60909762978554, 35.65923973917961, 36.94611668586731, 36.29988916218281, 35.65996930003166, 34.31068830192089, 36.706668734550476, 36.52107149362564, 36.289758905768394, 37.19814956188202, 36.88687406480312, 37.38904371857643, 36.20792269706726, 37.29042001068592, 36.518673822283745, 37.39592134952545, 38.119018748402596, 39.35518741607666, 38.15680392086506, 39.13296774029732, 40.17487943172455, 40.42693890631199, 40.29304549098015, 41.716129928827286, 41.208845749497414, 45.057921409606934, 43.956611305475235, 44.858781695365906, 44.89797279238701, 52.775375694036484, 55.81654630601406, 64.3092767894268, 54.452761486172676, 1.5651708072982728, 0.42661563609726727, 0.47157517983578146, 0.2850261493586004, 20.760938376188278, 72.27334544062614, 59.52681161463261, 67.1934512257576, 55.05255930125713, 46.75318144261837, 28.07878140360117, 46.06752723455429, 50.3794826567173, 46.777256950736046, 3.458678196184337, 0.45925380662083626, 0.0380328679602826, 0.12058481501298957, 0.0699326052563265, 0.020724533242173493, 0.03273084250395186, 0.046288366575026885, 0.07315604947507381, 0.06606453156564385, 0.026053780675283633, 0.02642695850227028, 0.007213805292849429, 0.06288865901296958, 0.048361726803705096, 0.018967463365697768, 0.10076344580738805, 0.0724537625501398, 8.412394244223833, 63.64728391170502, 56.386971697211266, 40.65018452703953, 23.566679321229458, 43.19773502647877, 60.55740371346474, 62.416347563266754, 60.748525857925415, 57.85865552723408, 49.19296592473984, 1.0132964956574142, 0.27328875730745494, 0.5411216604989022, 0.13548487680964172, 39.80514407157898, 67.06669762730598, 59.300510957837105, 56.86833746731281, 55.29977783560753, 52.29585662484169, 52.775960862636566, 45.71450337767601, 43.15014258027077, 41.521249786019325, 43.14111426472664, 49.87631365656853, 52.0628759264946, 53.91957029700279, 55.531990975141525, 52.06808544695377, 49.25602734088898, 50.84622301161289, 49.41810764372349, 45.96392199397087, 45.70479489862919, 41.09388671815395, 38.48700240254402, 36.9782629609108, 40.17541900277138, 38.407031893730164, 38.67772936820984, 37.28373236954212, 37.228528931736946, 37.225527092814445, 37.11877562105656, 36.98335088789463, 38.315912783145905, 38.07532489299774, 38.16513307392597, 39.306835010647774, 38.98267820477486, 37.919867634773254, 37.32317045331001, 38.43459561467171, 38.869003504514694, 38.948058262467384, 41.86718322336674, 40.90094067156315, 40.474022179841995, 36.060733795166016, 42.710217386484146, 46.90536327660084, 45.18541596829891, 46.95630334317684, 38.94048146903515, 37.42054022848606, 36.049148216843605, 37.946716994047165, 37.32409380376339, 39.10252757370472, 41.37306533753872, 38.29915948212147, 38.87793682515621, 37.69005596637726, 39.34712044894695, 40.931426435709, 39.42926824092865, 39.63459022343159, 39.13140222430229, 40.957918614149094, 38.08941073715687, 39.40918251872063, 37.95197211205959, 40.24422951042652, 39.78370942175388, 40.85237927734852, 38.51331599056721, 37.0157403498888, 35.77912710607052, 36.716365814208984, 38.75405967235565, 38.482579439878464, 40.78054793179035, 46.063533648848534, 47.91579745709896, 49.3636641651392, 47.823952585458755, 40.260998010635376, 38.248048424720764, 40.04030965268612, 39.295709207654, 39.457664117217064, 37.46625937521458, 37.3914185911417, 38.03151324391365, 38.05775463581085, 37.97235041856766, 37.28245563805103, 38.43692108988762, 37.465434819459915, 38.875539153814316, 37.1255848556757, 39.297616705298424, 37.311064302921295, 37.63284623622894, 37.3211869597435, 39.004458636045456, 38.591173812747, 39.29554961621761, 39.48923662304878, 38.49266789853573, 40.99869042634964, 38.287896886467934, 39.77701798081398, 37.856901213526726, 39.49417255818844, 39.238184094429016, 42.538025826215744, 40.69314122200012, 41.91076308488846, 41.32207207381725, 41.75630897283554, 41.99347324669361, 44.31098408997059, 45.01824013888836, 45.38544483482838, 46.33206523954868, 48.70460852980614, 48.87383244931698, 53.95566076040268, 58.94836105406284, 67.4152909219265, 58.91190581023693, 2.6083469996228814, 0.7927939121145755, 0.1486401419970207, 0.3239945130189881, 22.946032024919987, 78.22219222784042, 64.39422503113747, 73.03808480501175, 61.94101966917515, 54.174563214182854, 30.11676974594593, 52.983213141560555, 55.48885188996792, 57.577064037323, 5.636436576023698, 0.4890837793936953, 0.06164764337881934, 0.07554188356152736, 0.05167270363017451, 0.035844560188706964, 0.06413911847630516, 0.021962559876556043, 0.2299751783721149, 0.17935004958417267, 0.15736079280031845, 0.08777397641097195, 0.1719770795898512, 0.22093622043030336, 0.11957488561165519, 0.12249524414073676, 0.24090561841148883, 0.20294949965318665, 10.154142882674932, 75.26834473013878, 65.10119989514351, 52.148994505405426, 33.87489728629589, 48.35406593978405, 65.25663435459137, 70.56330800056458, 69.05711442232132, 63.29670712351799, 55.355813428759575, 1.442669180687517, 0.5168635246809572, 0.4620406305184588, 0.15071716101374477, 42.176513224840164, 66.78042858839035, 62.69883580505848, 59.640072137117386, 56.6106390953064, 55.02691827714443, 54.98816795647144, 49.36890788376331, 46.54582656919956, 46.23927041888237, 45.72147600352764, 55.25120884180069, 53.13033364713192, 54.57558989524841, 57.96785406768322, 54.12746474146843, 51.90736927092075, 52.835059091448784, 53.03914234042168, 48.54077272117138, 47.0359280705452, 43.69701683521271, 40.44954389333725, 38.070062175393105, 42.63412646949291, 40.59206664562225, 40.473155826330185, 40.923739448189735, 38.8546858727932, 41.24569617211819, 40.086697563529015, 41.08804643154144, 42.183185666799545, 39.05444875359535, 39.82763506472111, 41.0161504894495, 41.926976814866066, 39.50486518442631, 38.778511360287666, 39.76363889873028, 40.988643765449524, 41.89881652593613, 44.707549810409546, 44.12221021950245, 41.13399736583233, 37.973942533135414, 45.01007057726383, 49.77009795606136, 46.720522195100784, 49.23816829919815, 40.98024621605873, 36.702431961894035, 38.16710516810417, 39.46994885802269, 38.58686864376068, 41.22672379016876, 44.442130252718925, 38.962071910500526, 41.595999374985695, 40.54377503693104, 43.03822718560696, 42.598970755934715, 42.532265335321426, 41.45079396665096, 40.618171244859695, 43.56563128530979, 40.825647711753845, 41.320263370871544, 40.31258404254913, 44.181221053004265, 42.00277894735336, 41.80631808936596, 40.61855122447014, 35.50495281815529, 38.27109798789024, 37.735159546136856, 39.01077389717102, 38.74628908932209, 41.41685038805008, 47.81228721141815, 50.34541368484497, 52.96851933002472, 51.57894529402256, 42.96071134507656, 41.750377491116524, 42.68482334911823, 39.68272604048252, 41.940507888793945, 39.751065373420715, 37.76076637208462, 40.073166489601135, 39.769878163933754, 39.71545748412609, 38.43213714659214, 40.754249542951584, 37.68898822367191, 40.64873680472374, 38.91227178275585, 40.62146566808224, 41.192578822374344, 40.45390605926514, 39.407928586006165, 43.01263935863972, 41.556990668177605, 42.48529225587845, 43.00962992012501, 42.57647216320038, 44.97489966452122, 40.78174866735935, 42.20239743590355, 40.150024965405464, 40.823580622673035, 42.15029463171959, 45.602584183216095, 42.65065558254719, 43.229949697852135, 44.517240822315216, 42.870067209005356, 44.562576189637184, 45.17493233084679, 46.99667997658253, 48.9060091227293, 47.99570716917515, 48.617843985557556, 50.300055518746376, 56.07621677219868, 61.70716881752014, 68.3859184384346, 62.03374609351158, 3.098307908512652, 0.6389344087801874, 2.0601962506771088, 0.4153490625321865, 25.34392185509205, 83.25464218854904, 68.7608215212822, 77.19288066029549, 66.28324046730995, 62.51386933028698, 37.880053371191025, 60.76603151857853, 66.98171138763428, 69.27671983838081, 8.03824257105589, 0.6426320853643119, 0.11557384132174775, 0.23707839252892882, 0.09960636336472817, 0.11985373275820166, 0.12586984899826348, 0.09772603574674577], [0.02910972401878098, 0.042665620931074955, 0.010527446429478005, 0.022636235153186135, 0.1270864813704975, 0.0070556327500526095, 0.06141600424598437, 0.016659311731928028, 0.10973049706080928, 0.016389004849770572, 4.162402572110295, 49.311052188277245, 53.50592069327831, 45.13555124402046, 33.32263492047787, 34.132937639951706, 51.665721237659454, 62.887898460030556, 55.15750586986542, 51.79352357983589, 52.401927933096886, 4.061456713825464, 0.533332850318402, 0.5188151949550956, 0.027366979447833728, 5.713267978280783, 58.484873324632645, 58.190917298197746, 55.418627858161926, 54.05964978039265, 53.004925176501274, 48.40549238026142, 42.48617380857468, 39.86808009445667, 43.66704784333706, 48.255575224757195, 55.70669800043106, 53.78574147820473, 49.46229547262192, 47.28486031293869, 47.946431413292885, 49.16775427758694, 50.76550394296646, 49.57724690437317, 45.23702099919319, 41.287060752511024, 38.295359686017036, 37.01950594782829, 35.52145913243294, 38.40456962585449, 35.31323030591011, 35.51357455551624, 35.4886668920517, 36.72131694853306, 37.08176180720329, 34.41808953881264, 36.78174130618572, 36.93440951406956, 37.89840638637543, 36.75747960805893, 36.84784635901451, 36.77171364426613, 37.184458896517754, 36.506480276584625, 38.51929686963558, 38.35539646446705, 38.29492650926113, 39.10033129155636, 39.79063645005226, 38.69243457913399, 35.212547108531, 40.64852401614189, 43.01240757107735, 42.72907577455044, 49.434621557593346, 40.00815577805042, 36.96709915995598, 36.45218499004841, 38.141141161322594, 37.51434959471226, 38.56847383081913, 38.40035945177078, 37.261963337659836, 35.941203609108925, 37.21388831734657, 37.35687084496021, 37.381105944514275, 38.96794259548187, 38.22171963751316, 35.7441233843565, 38.1060766428709, 37.7328834682703, 36.81601166725159, 37.83668629825115, 37.11123302578926, 38.132686614990234, 39.61574323475361, 37.1513132750988, 36.13442324101925, 35.172489657998085, 37.10608810186386, 38.74867536127567, 38.01316782832146, 41.126971542835236, 49.034632220864296, 45.20843133330345, 46.2290907651186, 45.00281676650047, 37.86606252193451, 36.77087388932705, 38.03244039416313, 40.69678142666817, 38.492983281612396, 36.92970536649227, 37.11366109549999, 36.53607688844204, 37.282337844371796, 37.772245556116104, 36.305486261844635, 36.721544936299324, 35.92207543551922, 36.84657342731953, 36.18487313389778, 35.474953427910805, 36.876816004514694, 35.62842719256878, 36.688813492655754, 35.61698220670223, 35.882428362965584, 35.8890476077795, 37.295568734407425, 35.57976320385933, 37.31522887945175, 38.042202070355415, 37.08556540310383, 37.8243787586689, 38.74021701514721, 39.22731287777424, 39.855768755078316, 43.27919125556946, 42.81566172838211, 43.108876794576645, 43.562975227832794, 42.2087886929512, 42.39218205213547, 42.29352414608002, 43.7884247303009, 44.83078099787235, 46.71180546283722, 44.961547181010246, 55.585070326924324, 56.9756855070591, 65.93960970640182, 49.834147319197655, 0.9356997907161713, 0.5438552575651556, 0.4235008719842881, 0.38437389652244747, 25.07080391049385, 72.79474586248398, 58.872729912400246, 64.47615623474121, 55.735264867544174, 44.486325681209564, 25.805726274847984, 43.861829191446304, 47.71471604704857, 38.69835466146469, 1.5445468202233315, 0.18958719010697678, 0.1003375049913302, 0.05703332535631489, 0.028604178587556817, 0.04913415410555899, 0.046039962326176465, 0.028766269206244033, 0.049130521292681806, 0.06405931533663534, 0.05339680916222278, 0.038360893522622064, 0.029554945831478108, 0.10521532996790484, 0.035713025645236485, 0.029134749238437507, 0.08575941654271446, 0.018743110267678276, 4.909673798829317, 57.24874645471573, 58.52949433028698, 49.234794080257416, 33.78455713391304, 40.515964329242706, 58.82923364639282, 67.67218753695488, 60.22214010357857, 57.5296463817358, 56.725605726242065, 4.552233628928661, 0.8236213016789407, 1.0791756981052458, 0.09297380442149006, 7.127731628715992, 61.151361241936684, 60.0017025321722, 59.71489392220974, 55.62321648001671, 54.075719118118286, 51.21591277420521, 45.32639600336552, 39.897118136286736, 45.19471026957035, 49.750616401433945, 56.26909822225571, 55.067610293626785, 51.68714448809624, 50.07225014269352, 49.83923904597759, 51.486234068870544, 52.697289884090424, 51.66702076792717, 46.88132956624031, 43.450778648257256, 41.06007993221283, 38.384472504258156, 37.94829770922661, 40.071365386247635, 37.91029594838619, 38.16911146044731, 37.47431494295597, 38.086116313934326, 37.845304235816, 37.52389468252659, 38.60750913619995, 39.48946461081505, 38.85034270584583, 37.914654314517975, 37.67093539237976, 38.269323483109474, 38.63304376602173, 37.3486290872097, 40.23694910109043, 40.39645694196224, 40.25583788752556, 40.098788514733315, 40.12174308300018, 40.09519010782242, 37.336541935801506, 43.27066831290722, 47.560444325208664, 45.04282481968403, 49.025645703077316, 40.75943246483803, 38.93787480890751, 36.59942328929901, 37.99102261662483, 39.58668999373913, 39.785734713077545, 40.669210106134415, 40.693718791007996, 38.50219018757343, 39.23569142818451, 39.912716299295425, 39.00534398853779, 40.1788654178381, 39.98248055577278, 39.285415560007095, 39.38409246504307, 38.753409907221794, 39.13511082530022, 40.47854393720627, 38.40239614248276, 40.6934680044651, 40.21203763782978, 40.41307345032692, 36.21840253472328, 37.31879688799381, 39.58938404917717, 38.92936706542969, 38.72680373489857, 41.99770621955395, 50.936779752373695, 47.9236364364624, 48.25117126107216, 46.905644461512566, 38.87957453727722, 39.49403956532478, 39.739643186330795, 42.450706511735916, 40.10603092610836, 38.935556933283806, 39.75446619093418, 39.30496171116829, 38.938300386071205, 38.4843235462904, 38.71885076165199, 38.377458080649376, 38.51537548005581, 39.74463991820812, 37.994514629244804, 38.19315657019615, 38.46427582204342, 39.200007542967796, 37.94436112046242, 39.17601563036442, 37.613562270998955, 38.49745564162731, 40.171189829707146, 38.560657650232315, 39.711593091487885, 40.160941779613495, 40.714940652251244, 40.55950999259949, 40.575260147452354, 42.13215060532093, 43.25422279536724, 43.353655859827995, 44.315859228372574, 45.337928384542465, 43.70322570204735, 42.73591920733452, 43.937969505786896, 43.85301746428013, 45.744802951812744, 46.55924744904041, 48.414114117622375, 47.363113313913345, 58.16444031894207, 59.99810412526131, 67.75316119194031, 52.37907215952873, 1.3886512792669237, 1.2533848313614726, 0.4293157474603504, 0.26462439098395407, 27.14645393192768, 79.41708371043205, 63.63357424736023, 69.49225187301636, 61.970756873488426, 55.2196591347456, 30.205515883862972, 53.12142692506313, 54.13059577345848, 49.107880890369415, 2.2779392916709185, 0.15191227110335603, 0.025425821695534978, 0.08600672983448021, 0.051074536313535646, 0.045649707681150176, 0.032112577828229405, 0.037821051591890864, 0.13407245103735477, 0.14296866429504007, 0.1544447461492382, 0.10483000689418986, 0.26417901332024485, 0.17829608113970608, 0.12153771036537364, 0.19987451465567574, 0.3006918774917722, 0.08773430861765519, 5.545564452186227, 67.3575796186924, 67.0271797478199, 58.23138512670994, 44.794656336307526, 48.89972046017647, 65.28299733996391, 71.92222908139229, 64.47722777724266, 63.08194264769554, 63.26175279915333, 6.089706178754568, 1.1352868122048676, 2.103439592756331, 0.1767890909104608, 7.45274243876338, 61.724537685513496, 61.44521087408066, 61.26489154994488, 58.09662535786629, 56.5094543248415, 52.676334008574486, 48.88866305351257, 42.45004914700985, 48.28832186758518, 51.93676069378853, 59.238897264003754, 56.56457416713238, 54.04426820576191, 52.92332075536251, 54.00723159313202, 54.488870948553085, 55.43543055653572, 53.71329456567764, 49.92835186421871, 45.84328606724739, 43.199395537376404, 41.67977727949619, 39.85969394445419, 42.40786761045456, 40.240923687815666, 41.33871518075466, 41.21756248176098, 42.12588094174862, 41.253789737820625, 39.43801537156105, 41.268479749560356, 41.10063895583153, 40.88752739131451, 40.17378889024258, 41.93304508924484, 41.11540876328945, 41.44492708146572, 38.130585327744484, 42.00304873287678, 42.1818595379591, 44.08485822379589, 42.38319553434849, 43.78502011299133, 42.03799165785313, 39.80236642062664, 46.46813593804836, 50.82857295870781, 46.92484863102436, 51.39590531587601, 41.77967771887779, 38.97371828556061, 36.97191350162029, 41.20234049856663, 40.74248157441616, 41.57183647155762, 42.56481058895588, 43.32220494747162, 40.299706533551216, 41.97570160031319, 41.226647794246674, 41.49865619838238, 42.96761937439442, 42.347447052598, 40.37194065749645, 39.997782334685326, 42.205908447504044, 43.27014394104481, 44.253553971648216, 39.96392995119095, 42.97118358314037, 43.59223745763302, 40.617597475647926, 37.906629145145416, 37.85402096807957, 38.888545855879784, 39.46559049189091, 37.074097618460655, 42.148850709199905, 54.11650612950325, 49.92081306874752, 50.46185843646526, 50.70992052555084, 42.66947217285633, 41.87101721763611, 42.55783036351204, 46.429408416152, 40.590816512703896, 40.82619868218899, 41.97700493037701, 40.930529683828354, 40.65073549747467, 41.47355854511261, 40.10221593081951, 40.93242198228836, 39.232985973358154, 42.15091399848461, 40.582703948020935, 39.61356595158577, 41.09883785247803, 41.37791387736797, 40.387979596853256, 40.84024652838707, 40.82529813051224, 40.648698806762695, 42.044721096754074, 41.4852125197649, 42.333156019449234, 42.486447393894196, 42.3347557336092, 42.966639026999474, 42.901195138692856, 43.752539455890656, 43.70825283229351, 46.85393303632736, 46.94633647799492, 47.79378980398178, 46.56208589673042, 46.2333807349205, 46.30639761686325, 46.832403391599655, 48.07175248861313, 50.68931043148041, 50.73604412376881, 50.66855974495411, 60.33164642751217, 64.11283493041992, 68.70014637708664, 55.30622988939285, 1.9518393650650978, 1.1085656960494816, 2.2380012972280383, 0.5075436341576278, 29.101281836628914, 87.67175316810608, 68.51794615387917, 76.83582901954651, 68.08709487318993, 61.362793296575546, 33.975926265120506, 60.129945650696754, 61.56848385930061, 60.86191177368164, 4.113851152360439, 0.2906612469814718, 0.16307089186739177, 0.2427994753816165, 0.17651323461905122, 0.19519451656378806, 0.20056932815350592, 0.12278904556296766], [0.028688497695839033, 0.06867890260764398, 0.018965335257234983, 0.024287151936732698, 0.10695661621866748, 0.027991025453957263, 0.09725031908601522, 0.03544239036273211, 0.1310180829023011, 0.05362922383937985, 2.28118313010782, 49.23982121050358, 55.620271638035774, 40.427501276135445, 33.40972624719143, 33.38709466159344, 55.92545986175537, 60.99679693579674, 60.56875370442867, 46.84550888836384, 60.74486665427685, 11.227091308683157, 0.5343222816009074, 1.748601095750928, 0.3248232544865459, 0.5831586860585958, 34.8875467479229, 66.92863583564758, 54.98283304274082, 54.384501948952675, 48.18188197910786, 50.01165859401226, 41.339292749762535, 43.2770823687315, 47.39956095814705, 55.00468946993351, 50.82695044577122, 44.87041287124157, 45.172409266233444, 47.29372903704643, 48.98889407515526, 52.47790485620499, 47.669547870755196, 46.0159146040678, 42.304524555802345, 38.39910551905632, 34.164981320500374, 36.11512407660484, 36.214880123734474, 36.75923511385918, 37.27765269577503, 36.65410615503788, 34.953701198101044, 36.25301867723465, 36.25722885131836, 37.16541811823845, 34.60384637117386, 36.95934757590294, 35.21472819149494, 38.265474289655685, 36.44209273159504, 37.038056552410126, 36.04959659278393, 38.500579074025154, 36.578881591558456, 38.29486571252346, 37.784636691212654, 38.83314482867718, 39.41543698310852, 37.48441480100155, 35.38314275443554, 39.043482542037964, 42.355118840932846, 43.13406564295292, 48.33711884915829, 43.362083807587624, 38.022674918174744, 37.57147952914238, 35.65416321158409, 37.39631272852421, 37.892737090587616, 38.374893218278885, 37.71055966615677, 35.535947754979134, 37.899690717458725, 36.624988317489624, 36.136247143149376, 38.21944735944271, 37.343392968177795, 35.526877641677856, 37.52962477505207, 37.54075437784195, 37.23012484610081, 37.17084802687168, 36.67031228542328, 38.131580874323845, 41.60128489136696, 37.95355282723904, 37.31107950210571, 37.34564244747162, 37.28032015264034, 38.51423554122448, 48.94278734922409, 43.11314016580582, 47.672181129455566, 45.77480994164944, 43.74568462371826, 41.79510869085789, 37.13383421301842, 37.15026073157787, 37.95535773038864, 37.080416679382324, 38.633264154195786, 38.07274103164673, 36.602497324347496, 37.15042792260647, 35.38689315319061, 35.70692718029022, 36.23435027897358, 36.71388454735279, 37.05911122262478, 35.13787731528282, 36.80128365755081, 36.13122381269932, 35.099609568715096, 35.232507437467575, 36.254420801997185, 35.57524524629116, 36.07606217265129, 35.966415256261826, 36.961574256420135, 35.85812486708164, 36.96339815855026, 36.3917226344347, 38.46156656742096, 38.67745578289032, 40.56277021765709, 41.302290335297585, 43.39487984776497, 47.29098178446293, 50.39720870554447, 51.15744911134243, 54.070957973599434, 55.71055859327316, 56.675440818071365, 53.556028604507446, 47.56753094494343, 41.08024924993515, 45.79204201698303, 47.86980092525482, 59.58294980227947, 56.847647577524185, 66.18845075368881, 42.95840106904507, 0.6466867646668106, 1.0800369456410408, 0.7612598792184144, 0.203997055941727, 29.918946661055088, 69.01210963726044, 59.277693182229996, 64.60496172308922, 56.37247547507286, 41.34324453771114, 26.922017075121403, 48.89979645609856, 52.66012027859688, 28.09864293783903, 0.9331037581432611, 0.09946227539330721, 0.026880201075982768, 0.03336813584610354, 0.07553469215054065, 0.05692563601769507, 0.055856791223050095, 0.060078720925957896, 0.039969966164790094, 0.038151693224790506, 0.05381070121075027, 0.02336454919714015, 0.013957505489088362, 0.023051244133966975, 0.072265464841621, 0.052586580568458885, 0.07246820474392734, 0.01585719481226988, 2.980753853917122, 55.23292042315006, 61.778046414256096, 45.43318547308445, 37.77726508677006, 38.26878011226654, 60.55843725800514, 65.49802020192146, 66.32664173841476, 52.10396692156792, 65.97634613513947, 10.8696074411273, 0.3988105687312782, 1.408787111286074, 0.6975040503311902, 0.7699738803785294, 36.99754312634468, 70.04142880439758, 54.85884569585323, 57.44533650577068, 49.87537890672684, 51.87110781669617, 42.98113904893398, 45.217900425195694, 48.57411213219166, 56.34542092680931, 51.72825828194618, 47.89604991674423, 48.74300926923752, 49.2039093375206, 51.56806267797947, 55.16461528837681, 50.62301158905029, 49.005183801054955, 45.34039445221424, 40.53058214485645, 37.924507185816765, 38.57392653822899, 37.81179763376713, 38.21198835968971, 39.13161501288414, 39.31144796311855, 38.342933133244514, 38.593860268592834, 37.749701365828514, 39.350851848721504, 37.868589386343956, 38.69547061622143, 37.34858348965645, 39.249914065003395, 37.68660955131054, 39.47899617254734, 37.770961225032806, 40.430845096707344, 40.12747697532177, 41.146118715405464, 38.67457553744316, 41.306055933237076, 41.88385292887688, 40.25881692767143, 36.95301711559296, 40.38240909576416, 46.851216182112694, 44.51577790081501, 49.42887246608734, 43.042349964380264, 38.85438568890095, 39.256191328167915, 38.584512770175934, 39.59012120962143, 40.54866537451744, 40.87710455060005, 39.175130277872086, 37.49197259545326, 39.79146860539913, 38.338551968336105, 38.506521955132484, 39.34602230787277, 38.34718890488148, 40.041799172759056, 39.61749494075775, 38.712094724178314, 37.987070828676224, 38.95001135766506, 38.632998168468475, 40.06262585520744, 40.945075303316116, 39.034986197948456, 38.30289468169212, 38.0886659771204, 37.51475617289543, 40.69616585969925, 47.88780815899372, 44.41720739006996, 49.905294701457024, 49.46366339921951, 47.0955278724432, 45.18032044172287, 39.08669762313366, 39.32565160095692, 38.930712193250656, 38.50460305809975, 40.18674239516258, 40.180989503860474, 39.00917798280716, 38.69541361927986, 37.1323598921299, 37.10460618138313, 39.15602870285511, 37.895317152142525, 38.63555163145065, 35.89103490114212, 38.920703530311584, 38.03356893360615, 37.33547039330006, 38.589118123054504, 37.198730930686, 37.685199826955795, 38.40837322175503, 39.2341373115778, 39.658726528286934, 38.088696375489235, 39.55377236008644, 37.82776817679405, 40.266682505607605, 41.532098203897476, 43.17411929368973, 43.48984055221081, 44.96728487312794, 49.380288273096085, 52.433827221393585, 52.53362886607647, 56.852260529994965, 55.346929505467415, 60.307065546512604, 56.00697688758373, 50.180156752467155, 42.568716779351234, 49.34481717646122, 49.876971021294594, 61.76123231649399, 59.154689982533455, 67.85873472690582, 45.155747160315514, 0.8720693551003933, 1.6304433485493064, 0.5872637126594782, 0.23440839751856402, 31.970272287726402, 73.86596158146858, 65.01366779208183, 66.7585189640522, 64.62748691439629, 44.37426209449768, 24.08861741423607, 54.75554823875427, 59.575490802526474, 36.41522437334061, 1.2304601864889264, 0.19443996017798781, 0.008755234885029495, 0.020190660034131724, 0.030201529007172212, 0.04854987237195019, 0.051072217102046125, 0.05393218336394057, 0.11000547761796042, 0.12674967991188169, 0.2099229715531692, 0.19416779978200793, 0.1381923651206307, 0.14460987935308367, 0.20575471397023648, 0.12536190828541294, 0.18512378039304167, 0.18445289373630658, 3.4030021587386727, 63.08038853108883, 69.06263932585716, 53.26815225183964, 45.7012914866209, 45.60759611427784, 69.36527028679848, 69.98884722590446, 73.55810970067978, 55.750494450330734, 72.97842800617218, 14.497590065002441, 0.5557724868413061, 4.945831233635545, 0.9940844296943396, 1.2615695921704173, 37.85247825086117, 70.7285687327385, 58.38563784956932, 59.20607842504978, 52.907399609684944, 54.70107436180115, 45.78665770590305, 48.598419427871704, 50.94796635210514, 57.77318671345711, 54.27757188677788, 49.5486306399107, 50.02055011689663, 51.39798380434513, 53.33931103348732, 56.65890030562878, 52.16981738805771, 50.365491807460785, 47.14375488460064, 42.1348712593317, 38.37672472000122, 41.255332455039024, 41.59160301089287, 39.80659179389477, 42.259728759527206, 41.24829523265362, 39.378267377614975, 41.146247908473015, 40.53231105208397, 42.158103212714195, 38.958211317658424, 42.06106781959534, 39.99811291694641, 41.65663652122021, 40.06733380258083, 41.434530839324, 39.17013354599476, 42.21539653837681, 41.56617857515812, 44.318363294005394, 42.86002814769745, 41.95645943284035, 43.69027599692345, 42.66955956816673, 40.005678310990334, 42.86138467490673, 49.32668834924698, 49.40753661096096, 52.444075271487236, 45.34720368683338, 39.07219760119915, 40.26544377207756, 39.33907628059387, 41.38907007873058, 42.00161620974541, 42.853180915117264, 42.1445569396019, 39.6025313436985, 43.71641859412193, 41.87094882130623, 38.966084495186806, 42.723619267344475, 41.80368863046169, 40.95851518213749, 42.53479219973087, 41.04287065565586, 40.13881556689739, 40.82139194011688, 41.64943590760231, 41.65753707289696, 44.262608885765076, 41.493336483836174, 40.036293268203735, 39.6789338439703, 38.31683233380318, 40.39842523634434, 50.01789405941963, 47.47065894305706, 52.481761649250984, 52.352971360087395, 49.96068432927132, 46.954540237784386, 43.34229066967964, 40.15023395419121, 41.159600391983986, 39.42904785275459, 42.5085736066103, 43.513243496418, 40.70502698421478, 40.33436447381973, 38.8929346203804, 38.31987217068672, 40.19376061856747, 40.22885553538799, 39.85495179891586, 39.076130390167236, 40.30928581953049, 41.916420981287956, 40.13046361505985, 40.98414480686188, 40.746969133615494, 40.945014506578445, 40.82824297249317, 41.016367077827454, 42.985771000385284, 40.39794646203518, 42.13677875697613, 40.56263342499733, 42.05307684838772, 43.77352952957153, 45.876758471131325, 45.50677232444286, 48.06773230433464, 52.00323812663555, 55.02156816422939, 56.572109162807465, 59.62526433169842, 60.847354754805565, 62.42105171084404, 59.261475652456284, 52.98767030239105, 45.9732922911644, 50.466790571808815, 52.699512764811516, 64.19219747185707, 61.31919823586941, 69.14973825216293, 48.52662608027458, 1.645427963230759, 2.586937523446977, 2.730629900470376, 0.26386348181404173, 34.78969819843769, 80.12092754244804, 69.82192978262901, 75.92691779136658, 69.65749740600586, 55.70718437433243, 36.37200549244881, 63.57454441487789, 67.63893932104111, 48.31994377076626, 1.68017721734941, 0.28209261770825833, 0.12230679800268263, 0.16666469746269286, 0.0896492277388461, 0.13888637709897012, 0.19068954657996073, 0.16939069493673742], [0.023484519224439282, 0.02942131286545191, 0.02836486750311451, 0.11869584137457423, 0.05054532193753403, 0.051065712177660316, 0.051175282860640436, 0.09500101048615761, 0.16967796545941383, 0.016846980470290873, 1.2619695207104087, 39.91616651415825, 56.69904515147209, 36.37616626918316, 27.712515257298946, 31.058494113385677, 51.74161076545715, 56.18495933711529, 58.06949481368065, 49.20403093099594, 59.50062341988087, 22.60354120284319, 0.37427771952934563, 0.19976841722382233, 0.6737367413006723, 0.07340152224060148, 20.111237838864326, 67.15996742248535, 52.4324706941843, 56.45393930375576, 44.998120218515396, 46.36179864406586, 41.462440341711044, 46.61907523870468, 51.14940494298935, 50.712572783231735, 47.59848788380623, 50.066869631409645, 49.02208149433136, 53.00015263259411, 51.03442311286926, 50.768209397792816, 46.42565421760082, 42.662495747208595, 36.33910305798054, 36.045245826244354, 35.47908000648022, 36.05039454996586, 36.90484330058098, 36.259634122252464, 35.240790992975235, 35.82990378141403, 37.74904020130634, 35.463223457336426, 36.425058245658875, 37.23917596042156, 36.25701606273651, 37.00111873447895, 35.813716650009155, 37.163415625691414, 36.530738174915314, 36.30994722247124, 37.511267960071564, 36.350111067295074, 37.13497035205364, 38.52781601250172, 36.79951295256615, 37.834896594285965, 37.738932743668556, 36.92977376282215, 34.697123765945435, 39.63806323707104, 42.34103299677372, 42.29643478989601, 47.41714261472225, 44.197924956679344, 40.366909727454185, 35.56180536746979, 37.65672795474529, 39.75035101175308, 37.515694722533226, 38.884157091379166, 38.96996408700943, 36.76715008914471, 37.39765025675297, 37.9565242677927, 37.73849196732044, 38.336089700460434, 37.49541141092777, 37.647726237773895, 39.83857087790966, 36.41387924551964, 37.283819764852524, 35.810973197221756, 35.681316554546356, 38.076768815517426, 39.871898889541626, 36.5512190759182, 37.84292936325073, 35.73327116668224, 38.13425213098526, 33.974071964621544, 45.849301144480705, 49.22678790986538, 45.789309963583946, 46.83659836649895, 42.51743093132973, 41.55263610184193, 34.58569474518299, 37.43594840168953, 37.20331348478794, 38.44084247946739, 38.473946303129196, 38.148911744356155, 36.39623299241066, 37.16334342956543, 35.93733921647072, 38.29173848032951, 37.67660088837147, 37.38277405500412, 36.12478315830231, 37.60038837790489, 36.08959324657917, 35.490354001522064, 34.204780384898186, 34.85775254666805, 36.51336170732975, 36.03535495698452, 36.41356386244297, 36.19976453483105, 38.624353632330894, 36.46301820874214, 38.557013645768166, 38.73498849570751, 39.23951022326946, 39.84507232904434, 39.97091017663479, 43.2980040460825, 45.9102650731802, 49.56436939537525, 54.14173677563667, 54.56915684044361, 56.0777784883976, 56.96910046041012, 50.511168390512466, 55.280934646725655, 61.01564772427082, 47.2407066822052, 42.79276415705681, 44.64195393025875, 60.61163820326328, 56.360019743442535, 69.65934410691261, 38.44804689288139, 0.2352728956611827, 0.8969802840147167, 0.8650117088109255, 0.10225700316368602, 35.68132035434246, 69.99396175146103, 60.43001554906368, 65.70520028471947, 53.77434588968754, 46.81692682206631, 34.78728912770748, 56.85972712934017, 58.149377927184105, 18.769153654575348, 0.7501447631511837, 0.08737338735954836, 0.1003649941412732, 0.04095706339285243, 0.06991944697801955, 0.046163489096215926, 0.03707724521518685, 0.06966920220293105, 0.021220655253273435, 0.05332954089681152, 0.02036229652730981, 0.03295670772786252, 0.01314286761044059, 0.050620957917999476, 0.0799355907656718, 0.04978919962013606, 0.12830967432819307, 0.05035294612753205, 1.8475311622023582, 48.20680484175682, 63.30049552023411, 41.769570261240005, 33.25788639485836, 36.08805812895298, 60.317074209451675, 61.30805343389511, 64.05868023633957, 53.197840824723244, 65.10687679052353, 24.290175698697567, 0.2679089881712571, 0.7585665362421423, 0.6824700976721942, 0.02632692441693507, 22.464257776737213, 69.73739951848984, 54.33891959488392, 58.88085387647152, 48.15188638865948, 49.90440174937248, 43.27723056077957, 48.06372731924057, 51.59291714429855, 55.06191439926624, 50.05530305206776, 49.62878353893757, 50.85494354367256, 53.19958113133907, 51.78563520312309, 53.89390267431736, 47.743370309472084, 45.056439489126205, 38.249214962124825, 38.23652744293213, 38.239886462688446, 37.36947476863861, 38.42580668628216, 39.273187816143036, 38.15480902791023, 38.62493880093098, 39.11448933184147, 38.607683926820755, 39.112574234604836, 37.71740309894085, 37.33256354928017, 38.33121836185455, 37.276189774274826, 39.00221295654774, 38.68071220815182, 40.00277906656265, 39.38416466116905, 38.61189790070057, 39.428261294960976, 39.233381152153015, 36.76632933318615, 40.37605203688145, 41.35798394680023, 39.028553143143654, 36.10671512782574, 42.0731245726347, 44.403053149580956, 45.58898851275444, 48.184606432914734, 44.59674775600433, 40.40968023240566, 37.04002484679222, 38.1441505998373, 40.95746263861656, 40.41786499321461, 42.31734126806259, 39.32440526783466, 38.826008811593056, 38.84443782269955, 39.43003959953785, 39.22407165169716, 41.0206950455904, 40.17581418156624, 38.402779921889305, 41.50017611682415, 38.19859027862549, 37.96085983514786, 36.877845749258995, 36.4235383272171, 38.89769956469536, 40.73321387171745, 38.56019787490368, 40.19779980182648, 35.89552246034145, 37.52045586705208, 36.03055961430073, 46.75797678530216, 51.66684217751026, 47.36854702234268, 47.844893261790276, 44.00857351720333, 44.25516128540039, 36.87590405344963, 38.72488483786583, 40.55790267884731, 38.52924093604088, 39.90341059863567, 40.7459469884634, 36.65773116052151, 38.93059439957142, 38.431361988186836, 40.19650027155876, 37.98921771347523, 39.467148408293724, 39.31521736085415, 39.02489773929119, 38.496908470988274, 37.03326500952244, 37.63473853468895, 37.54318244755268, 39.4096726924181, 38.6881560087204, 37.93902240693569, 38.55692245066166, 39.929386004805565, 40.588525235652924, 41.20538793504238, 42.389351204037666, 42.94414043426514, 43.055710047483444, 43.812823221087456, 46.472125723958015, 47.69940286874771, 51.2349459528923, 55.3281357139349, 56.324020475149155, 57.64166437089443, 56.37022219598293, 53.533184230327606, 57.177998051047325, 63.85788381099701, 50.12818694114685, 46.42715513706207, 47.88302801549435, 62.74744279682636, 57.825278118252754, 70.69048717617989, 39.53142575919628, 0.2649576746625826, 1.2156839668750763, 0.16481011494761333, 0.0885790136817377, 37.77887620031834, 76.74253642559052, 63.89373108744621, 71.51588648557663, 59.48615379631519, 56.856094524264336, 36.8721042573452, 59.89806309342384, 65.99785298109055, 26.449989303946495, 0.6674407166428864, 0.053964759936206974, 0.10126581299118698, 0.028504758629424032, 0.07654114830074832, 0.11359201758750714, 0.02823486920533469, 0.012483602058637189, 0.09116897548665293, 0.15281558356946334, 0.1310178157291375, 0.18076108011882752, 0.09401836985489354, 0.16760992642957717, 0.1488030285690911, 0.13955098518636078, 0.33430861425586045, 0.1736742674256675, 2.1346366312354803, 52.62991949915886, 74.01893377304077, 51.48496873676777, 38.726252764463425, 42.414380460977554, 66.13418966531754, 65.93026220798492, 71.40131503343582, 58.83878253400326, 70.5449777841568, 28.98066870868206, 0.5138162663206458, 2.132760719396174, 2.031216393224895, 0.17325471650110558, 26.114911884069443, 71.62629336118698, 56.14353395998478, 62.10053130984306, 50.38072519004345, 52.625397741794586, 46.040005311369896, 50.401103496551514, 53.30174244940281, 57.16472536325455, 51.99194513261318, 52.15837240219116, 51.77819520235062, 57.478584721684456, 55.41548162698746, 56.605030596256256, 51.28278158605099, 47.5641605257988, 39.609986543655396, 40.71303315460682, 40.17752029001713, 40.595421865582466, 40.46309396624565, 41.041202545166016, 41.304957792162895, 40.39168819785118, 41.98875389993191, 40.082494989037514, 43.40346738696098, 42.25375548005104, 42.065798565745354, 41.31158083677292, 39.887128472328186, 41.84096083045006, 40.9628127515316, 42.09407664835453, 41.18622176349163, 40.774221271276474, 41.147448644042015, 41.61204971373081, 38.18224735558033, 41.838034987449646, 42.85299092531204, 41.584037616848946, 39.454251900315285, 44.20831739902496, 47.503299191594124, 48.63635279238224, 50.82022860646248, 45.44908381998539, 41.016659662127495, 38.295838460326195, 39.80942264199257, 43.94896611571312, 41.37442946434021, 43.64283934235573, 42.194581255316734, 41.995046362280846, 40.168495774269104, 42.521116733551025, 41.23560771346092, 42.97571673989296, 41.73615865409374, 41.755480617284775, 45.791418850421906, 41.30313768982887, 41.02331690490246, 39.12887156009674, 39.34962451457977, 42.64250122010708, 43.61595958471298, 40.01857481896877, 40.44849134981632, 37.49504663050175, 37.44901590049267, 38.0439917743206, 46.645738407969475, 52.24221870303154, 50.569468662142754, 51.12947501242161, 45.7694636285305, 46.20297856628895, 38.74443098902702, 41.355320289731026, 41.86315543949604, 42.38160341978073, 42.312146946787834, 42.31903977692127, 38.21001626551151, 41.99606090784073, 39.821509793400764, 42.36651062965393, 41.330785006284714, 40.66601447761059, 40.729417875409126, 41.06299437582493, 40.38303226232529, 39.00407485663891, 38.84212754666805, 39.756176099181175, 40.82788199186325, 40.57127796113491, 40.68987339735031, 42.44995795190334, 43.67230676114559, 41.32998704910278, 42.93267264962196, 44.78025130927563, 45.24712085723877, 44.71555978059769, 44.069134667515755, 50.74929021298885, 48.55071298778057, 54.07680965960026, 58.13863590359688, 60.09729020297527, 58.966208696365356, 61.26143753528595, 55.416739359498024, 58.226304799318314, 66.40034258365631, 53.449858501553535, 49.04036611318588, 50.255806893110275, 65.4107616841793, 61.92737080156803, 72.85566419363022, 44.247953072190285, 0.7653706055134535, 1.8438725522719324, 1.661563916131854, 0.08370886993361637, 42.79086425900459, 82.13851287961006, 69.59144175052643, 77.54872396588326, 63.814094960689545, 64.70052659511566, 44.14110280573368, 69.09907937049866, 75.06212219595909, 35.902255699038506, 1.000812384299934, 0.1118980729370378, 0.1658266643062234, 0.17815171857364476, 0.1831505136215128, 0.26903604331891984, 0.09318320138845593, 0.09979760739952326], [0.020785725173482206, 0.032904668332776055, 0.04477904971281532, 0.07906376762548462, 0.019562561901693698, 0.03108015764155425, 0.06901008600834757, 0.039649978061788715, 0.07969668600708246, 0.10711531707784161, 0.14259105955716223, 23.124394454061985, 60.494175106287, 44.08471003174782, 35.916079357266426, 23.859598003327847, 46.39033131301403, 57.202385142445564, 57.978045120835304, 51.19464911520481, 56.305207684636116, 33.935621827840805, 0.10026995470980182, 0.8347910398151726, 0.665191593579948, 0.024481628024659585, 17.436308674514294, 68.50963979959488, 52.42985263466835, 53.34670923650265, 44.39394883811474, 44.46986496448517, 44.95759159326553, 50.87233141064644, 47.77765206992626, 51.03091590106487, 51.31320275366306, 49.5093597471714, 48.99558171629906, 51.95907689630985, 49.111859276890755, 48.77226769924164, 39.5373610407114, 37.68119864165783, 36.33259020745754, 36.96976661682129, 36.95917658507824, 37.160938158631325, 35.313439294695854, 36.17023631930351, 36.170392110943794, 37.74029687047005, 36.342367082834244, 36.846280843019485, 36.80536463856697, 37.99644112586975, 37.77886480093002, 38.42755079269409, 35.51304258406162, 37.98307724297047, 36.500100418925285, 39.22792084515095, 37.030715346336365, 37.18186363577843, 36.68282501399517, 37.9197346419096, 37.2103089094162, 39.421049281954765, 39.409619495272636, 36.18934169411659, 33.92874039709568, 38.481097519397736, 41.19944505393505, 41.20485216379166, 42.54838787019253, 49.023757204413414, 41.494598016142845, 36.61317095160484, 38.52243170142174, 39.495171904563904, 39.426125809550285, 38.59986774623394, 37.199449092149734, 36.797358468174934, 37.087518498301506, 35.553005039691925, 39.20330956578255, 37.446895614266396, 37.16276966035366, 38.09425927698612, 39.41449083387852, 37.23696447908878, 38.836625441908836, 35.93386620283127, 39.062812104821205, 38.04609306156635, 40.091295316815376, 38.56668792665005, 38.46264570951462, 36.26528061926365, 38.74999389052391, 35.918598622083664, 37.38266006112099, 52.78029263019562, 42.15654529631138, 45.70348396897316, 44.20147016644478, 40.495802611112595, 34.463656693696976, 37.02246978878975, 37.07932613790035, 37.089524790644646, 36.14673838019371, 38.25198881328106, 37.24174842238426, 39.09175515174866, 38.17547991871834, 36.578399017453194, 37.230200842022896, 37.21128545701504, 35.89508168399334, 35.887702479958534, 36.908080726861954, 35.07358096539974, 35.382872968912125, 35.78244052827358, 36.65316000580788, 36.368103101849556, 36.93680338561535, 35.953321158885956, 35.872541293501854, 38.457694575190544, 37.4212621897459, 36.98736347258091, 37.1905841678381, 37.56910465657711, 41.4119790494442, 40.89047223329544, 47.09127590060234, 49.32301014661789, 54.995227977633476, 55.497295036911964, 53.39818127453327, 52.78778962790966, 51.52458541095257, 43.2277762144804, 56.640813276171684, 53.00889976322651, 48.077383786439896, 42.215008959174156, 58.05962294340134, 54.66640882194042, 69.55491811037064, 27.506074234843254, 0.16789479239378124, 1.7904943227767944, 0.4752758250106126, 0.30113817541860044, 40.92620551586151, 62.20651522278786, 59.35772828757763, 64.87907901406288, 55.99218808114529, 27.35220719128847, 15.632908344268799, 41.43209137022495, 55.125560984015465, 14.424912314862013, 0.8031432505231351, 0.08674656201037578, 0.08172363974153996, 0.014706608944834443, 0.034158968410338275, 0.055738281371304765, 0.06430040200939402, 0.039344228061963804, 0.00920149755984312, 0.05154447164386511, 0.0053043126627017045, 0.015438824830198428, 0.12469980865716934, 0.06276830492424779, 0.04530207457719371, 0.038919489525142126, 0.09412129831616767, 0.19073187868343666, 0.13843049062415957, 30.878235585987568, 68.01159292459488, 47.8413100540638, 37.425818145275116, 31.756640151143074, 55.765313655138016, 60.785988047719, 63.599965050816536, 55.93432858586311, 61.646432876586914, 35.42606525123119, 0.10988797337631695, 0.767925315303728, 1.5818400378338993, 0.021834645158378407, 19.07643746584654, 69.85174298286438, 54.97651018202305, 56.36451870203018, 44.56273578107357, 48.07681001722813, 45.22640436887741, 52.53387585282326, 50.121871680021286, 53.414262011647224, 51.71720467507839, 50.99643275141716, 50.82014121115208, 53.94493393599987, 50.86245954036713, 51.0588102042675, 41.16620063781738, 39.70566540956497, 37.59107127785683, 37.821878492832184, 39.48459707200527, 39.10872124135494, 36.86664015054703, 36.57202295958996, 38.48769776523113, 38.79035912454128, 39.0548325330019, 37.984559163451195, 38.07895369827747, 39.8776213824749, 40.3849321603775, 40.466612577438354, 38.07969085872173, 38.211767971515656, 40.01593016088009, 40.022864788770676, 37.90993496775627, 39.09406542778015, 38.39260406792164, 39.25867639482021, 38.80104035139084, 39.56767961382866, 41.40746109187603, 38.73922906816006, 36.04138143360615, 40.73988251388073, 43.67185838520527, 44.37054969370365, 45.22621437907219, 50.03739841282368, 42.78935953974724, 37.43936061859131, 38.0727182328701, 40.81533506512642, 40.36446265876293, 39.29295815527439, 39.37296666204929, 36.97000980377197, 39.60035786032677, 37.950953766703606, 39.67673376202583, 39.21992987394333, 39.29167002439499, 39.39157426357269, 41.187186911702156, 39.36375595629215, 39.88411903381348, 37.288193330168724, 39.299554601311684, 39.85448822379112, 41.24522879719734, 40.66258326172829, 39.747060388326645, 35.330530777573586, 37.930457666516304, 36.173162162303925, 41.965366154909134, 52.93372459709644, 44.68705751001835, 47.95110136270523, 47.23627991974354, 42.586724013090134, 36.59436956048012, 39.433269426226616, 39.383636489510536, 39.36171926558018, 38.02925996482372, 39.94669407606125, 37.913609370589256, 39.8296869546175, 39.00917798280716, 39.075898602604866, 39.89635817706585, 38.83918650448322, 39.162199571728706, 37.74474263191223, 38.70048254728317, 36.59115873277187, 37.99380026757717, 38.42774838209152, 39.635410979390144, 36.70832544565201, 39.16623495519161, 37.530468329787254, 38.95759955048561, 39.090364426374435, 38.8070934265852, 38.565905168652534, 40.74549101293087, 40.10875537991524, 44.50077250599861, 43.87361615896225, 49.41018506884575, 50.38698345422745, 56.686692014336586, 58.00638400018215, 55.56542158126831, 56.38756066560745, 52.94302649796009, 44.42040301859379, 58.89247365295887, 55.98624140024185, 49.36853550374508, 44.205300360918045, 61.192060858011246, 56.85087740421295, 70.75672522187233, 29.724972769618034, 0.08105510569293983, 1.8386228964664042, 0.4962239821907133, 0.18971348879858851, 45.43521076440811, 68.14051240682602, 65.93517914414406, 69.42688018083572, 60.65951943397522, 38.75432945787907, 19.016679972410202, 46.26842625439167, 64.461230635643, 21.193520464003086, 0.902778891613707, 0.06508366466732696, 0.07560011246823706, 0.0044285969579505036, 0.06540859918459319, 0.03525282729242463, 0.08159783828887157, 0.02735358924837783, 0.09883247403195128, 0.12415490156854503, 0.1679576374590397, 0.1222708409477491, 0.17024962697178125, 0.11286326567642391, 0.18271831650054082, 0.10520904397708364, 0.25633240467868745, 0.2189801269560121, 0.2861291292356327, 35.48737496137619, 78.88050690293312, 56.5791691839695, 48.23085755109787, 35.813245475292206, 62.36469313502312, 66.66689828038216, 70.19655928015709, 59.42995861172676, 67.79596969485283, 42.039397582411766, 0.3186658927006647, 1.8469608365558088, 2.893850617110729, 0.16905335913179442, 21.0016630589962, 69.91962254047394, 57.12554186582565, 57.19070456922054, 48.95338878035545, 50.380147621035576, 49.175870642066, 55.332668870687485, 54.0473460406065, 55.26125930249691, 54.84843045473099, 54.285038486123085, 53.060330003499985, 56.4681201428175, 53.0744082480669, 53.637070655822754, 42.37090319395065, 40.53085193037987, 41.172557696700096, 40.71077607572079, 41.374630853533745, 41.04883633553982, 37.853975370526314, 39.44631412625313, 39.90127891302109, 41.98070593178272, 40.245681032538414, 40.04282131791115, 40.48625752329826, 42.395446076989174, 43.439956828951836, 42.937380596995354, 40.897851437330246, 42.73759111762047, 42.12585814297199, 42.748428136110306, 39.91562694311142, 41.59665673971176, 41.185685992240906, 41.64276726543903, 41.29522271454334, 42.16257557272911, 44.584451615810394, 40.95512576401234, 38.64853173494339, 44.00317020714283, 46.56676344573498, 48.11570852994919, 46.47932633757591, 51.35647863149643, 44.588980972766876, 38.52058880031109, 40.148858428001404, 43.608397990465164, 43.17301735281944, 42.79214859008789, 42.278207167983055, 41.136566027998924, 44.11439783871174, 41.43619894981384, 42.84166373312473, 41.35540768504143, 41.267115622758865, 43.25028620660305, 42.781664952635765, 41.38233684003353, 43.07763107120991, 40.03935590386391, 42.76621878147125, 41.85217022895813, 43.06574910879135, 42.37416721880436, 41.685138791799545, 37.29518875479698, 39.11112651228905, 38.07312861084938, 43.567588180303574, 57.95263208448887, 47.65890084207058, 50.14231838285923, 51.6388338804245, 45.41507564485073, 38.27238991856575, 40.560418143868446, 42.18119457364082, 40.35153195261955, 39.852090552449226, 40.91047815978527, 39.837947711348534, 43.169297352433205, 41.89698122441769, 41.357987746596336, 41.389852836728096, 41.70341581106186, 42.36020676791668, 39.0773843228817, 42.04941384494305, 38.731321692466736, 39.82263833284378, 40.36304533481598, 42.63387568295002, 40.741489827632904, 42.34866298735142, 39.757205843925476, 39.83718015253544, 42.58553087711334, 41.75632417201996, 41.40480883419514, 42.33058735728264, 41.58027961850166, 45.892212241888046, 44.60617125034332, 51.47738054394722, 52.622661888599396, 59.24162931740284, 60.052380412817, 57.50703379511833, 57.704307809472084, 53.75884272158146, 46.32661633193493, 60.017483085393906, 57.83376306295395, 52.16340713202953, 47.23889417946339, 64.53322157263756, 60.19227370619774, 74.1913229227066, 33.7156630307436, 0.5131888843607157, 9.682855121791363, 1.3296054163947701, 0.35698484745807946, 49.02373440563679, 73.19057062268257, 70.67037105560303, 75.52498295903206, 70.12758538126945, 39.841876700520515, 25.131916031241417, 55.45364297926426, 72.30605408549309, 29.53355424106121, 1.251468665432185, 0.12149213507655077, 0.12330083802226, 0.09577811331837438, 0.17022898042341694, 0.12603427923750132, 0.1333260434330441, 0.08233004860812798], [0.06410985559341498, 0.05791031384433154, 0.046150223206495866, 0.02981929326779209, 0.0380824879539432, 0.055808317847549915, 0.037216876589809544, 0.032334197967429645, 0.054077109962236136, 0.08549605801817961, 0.13111674401443452, 12.847325317561626, 54.2440614849329, 45.811485573649406, 36.02722339332104, 26.633251570165157, 39.158141389489174, 53.8065529614687, 57.901589423418045, 51.784453466534615, 51.285411044955254, 44.08024527132511, 0.947369736386463, 0.6654419051483274, 1.3380121090449393, 0.18420893495203927, 18.80404718220234, 65.47473505139351, 53.157255202531815, 50.30013531446457, 42.24272847175598, 42.52248466014862, 48.317618295550346, 50.66187970340252, 50.453772470355034, 53.64014469087124, 48.64210948348045, 52.97788202762604, 50.614583641290665, 51.06310777366161, 44.99000385403633, 41.69234320521355, 35.99648304283619, 35.66015549004078, 36.25920094549656, 36.836857348680496, 35.32912865281105, 36.36072389781475, 35.1651256531477, 37.77609474956989, 36.64016470313072, 37.03821234405041, 37.44237385690212, 37.287927344441414, 37.92281247675419, 36.15779958665371, 34.73882652819157, 35.58281444013119, 37.51170873641968, 36.34083576500416, 37.090071961283684, 36.18770398199558, 37.52558559179306, 37.52033047378063, 35.99844753742218, 36.523723751306534, 36.78315483033657, 39.810326993465424, 37.75709196925163, 35.25095924735069, 36.19668669998646, 37.720803916454315, 40.976617410779, 40.20423285663128, 44.948795065283775, 50.71061588823795, 38.164707496762276, 35.48804372549057, 36.92631974816322, 40.92813581228256, 38.69908042252064, 38.32611903548241, 34.834387600421906, 36.46818593144417, 37.43713013827801, 37.36966095864773, 37.58846841752529, 37.95785799622536, 38.20824936032295, 39.87824834883213, 39.16529640555382, 37.41343080997467, 35.86002856492996, 37.95838996767998, 36.26879163086414, 37.83401124179363, 36.93213723599911, 39.25341747701168, 37.317436560988426, 36.53366021811962, 36.3491877168417, 38.51132869720459, 35.23263283073902, 46.12590350210667, 44.46969397366047, 41.24432064592838, 45.290077552199364, 38.489954844117165, 35.437540635466576, 35.04208065569401, 39.024506360292435, 37.491296231746674, 36.80290997028351, 37.099077478051186, 37.41365499794483, 37.86724805831909, 37.81935162842274, 38.41059610247612, 37.66858711838722, 37.1650305390358, 38.24298329651356, 38.04374098777771, 36.28879755735397, 36.423652321100235, 37.36477442085743, 35.93010060489178, 36.56074516475201, 34.5208740234375, 36.77141346037388, 36.64070047438145, 37.228604927659035, 35.97278751432896, 37.404140308499336, 36.18041977286339, 38.23974967002869, 37.08894722163677, 40.20341970026493, 38.30903135240078, 43.40078853070736, 46.82131178677082, 51.37596018612385, 51.49061903357506, 53.5875479131937, 53.71955282986164, 56.655769273638725, 51.929579079151154, 54.38739739358425, 53.058616295456886, 51.569096222519875, 41.75676494836807, 56.259165555238724, 54.325042739510536, 69.90000799298286, 15.236563012003899, 0.1846762208151631, 0.27885801158845425, 0.2663616993231699, 0.6591600109823048, 48.45621585845947, 66.57617434859276, 60.41992709040642, 65.6557497382164, 48.99514473974705, 35.48440732061863, 41.452287286520004, 40.428797006607056, 50.007547214627266, 9.806272499263287, 0.7680136011913419, 0.04553641512757167, 0.22323956480249763, 0.036331134469946846, 0.09179882137686945, 0.007910917593108024, 0.035007632832275704, 0.01828294716688106, 0.07130061349016614, 0.01588878432812635, 0.03126574280031491, 0.03223883941245731, 0.0466490021062782, 0.041974711130023934, 0.05134222526976373, 0.014618147724831942, 0.024955901208159048, 0.14224714832380414, 0.09850498652667738, 16.773191057145596, 63.74488927423954, 51.087445467710495, 41.69713094830513, 31.27801973372698, 51.88085049390793, 60.24495787918568, 65.06067886948586, 56.146273612976074, 58.26051816344261, 46.366411596536636, 1.0781998629681766, 0.6009832920972258, 1.7503117164596915, 0.12183344137156382, 19.403415620326996, 66.34490355849266, 54.96019005775452, 52.49442256987095, 43.77647437155247, 44.84757609665394, 49.33334559202194, 52.34688028693199, 51.859906017780304, 53.58910582959652, 49.41766306757927, 53.02949845790863, 52.83341757953167, 52.54980459809303, 51.22723996639252, 44.79391157627106, 36.78853914141655, 37.5817845761776, 38.90934593975544, 39.994814693927765, 38.07967185974121, 38.4111774712801, 38.59753467142582, 38.11007022857666, 39.66553956270218, 39.12221051752567, 40.01176938414574, 38.119018748402596, 39.22843761742115, 38.183288499712944, 37.679093554615974, 37.34004534780979, 40.58924339711666, 38.06476525962353, 40.61727449297905, 39.278898909687996, 39.07060168683529, 38.707645162940025, 38.05915296077728, 38.74643348157406, 39.256096333265305, 41.3056493550539, 39.2056692391634, 38.209400698542595, 38.00497926771641, 40.4789999127388, 44.358409345149994, 43.824047818779945, 45.01308001577854, 50.43649099767208, 38.16281899809837, 37.789815813302994, 40.093575194478035, 42.50430263578892, 40.08932322263718, 39.58251401782036, 37.069765850901604, 38.260473757982254, 38.79527226090431, 39.214268177747726, 40.553187131881714, 39.281805753707886, 39.86758232116699, 41.0244682431221, 40.49535423517227, 37.071817740798, 38.16071771085262, 40.411336943507195, 39.34480257332325, 38.9493577927351, 38.178709745407104, 41.32010377943516, 40.38409240543842, 38.065122440457344, 36.45680174231529, 38.794356510043144, 40.21995261311531, 49.01974841952324, 45.620154440402985, 44.759523421525955, 47.504484727978706, 37.76828616857529, 37.20566935837269, 37.77818463742733, 41.6014900803566, 39.9542822688818, 38.15461523830891, 38.38582523167133, 38.534203469753265, 39.039401561021805, 39.96424913406372, 40.09290263056755, 40.216285809874535, 39.74596604704857, 40.36404088139534, 40.23805484175682, 39.05227147042751, 37.67951153218746, 39.12208132445812, 38.6999087780714, 38.71468998491764, 36.48371949791908, 37.6080297678709, 37.70846977829933, 39.17039193212986, 38.43979373574257, 40.59144347906113, 38.24103780090809, 39.970796182751656, 38.52251149713993, 42.41385608911514, 39.84710521996021, 46.03029303252697, 48.551856726408005, 54.44681100547314, 55.518167316913605, 57.39996314048767, 55.39467014372349, 59.983148127794266, 52.74009458720684, 56.26131623983383, 55.54293438792229, 53.48641254007816, 44.93692450225353, 58.420937955379486, 57.00280845165253, 73.11895206570625, 16.13605834543705, 0.10092433600220829, 4.3491459265351295, 0.15755532454932109, 0.5851388548035175, 52.24815018475056, 70.45947477221489, 65.58779418468475, 69.63048085570335, 57.992408350110054, 34.8090011626482, 35.655683130025864, 45.60011811554432, 59.648431688547134, 15.178540125489235, 0.7626305962912738, 0.041099893423961475, 0.15878491481998935, 0.021300035368767567, 0.03303757584944833, 0.03413549427932594, 0.05607878243608866, 0.03379763526027091, 0.160694089718163, 0.08269588288385421, 0.2096727045136504, 0.174017243552953, 0.219618923147209, 0.1538360514678061, 0.08130017027724534, 0.11125828968943097, 0.0883236777735874, 0.34694890317041427, 0.14777297212276608, 21.07702251523733, 73.04740950465202, 56.168688610196114, 47.96690471470356, 36.311231553554535, 53.80565620958805, 62.16543562710285, 71.40654355287552, 60.659625828266144, 62.71467715501785, 53.39028149843216, 2.0293711172416806, 1.5544113283976912, 4.204859118908644, 0.2224219258641824, 22.506175227463245, 69.58757355809212, 57.12874889373779, 54.83526036143303, 46.17526665329933, 46.957112699747086, 50.73778823018074, 56.12075798213482, 54.380565360188484, 56.44369885325432, 51.358937099575996, 54.16217587888241, 54.76340241730213, 56.52747295796871, 51.987514570355415, 47.18558304011822, 39.34064939618111, 39.65730920433998, 40.9625543653965, 41.800766587257385, 38.57621021568775, 40.85290364921093, 42.62856736779213, 41.71111039817333, 42.571581825613976, 41.057830452919006, 41.66534565389156, 41.38448752462864, 42.015052288770676, 39.5172943174839, 39.519072622060776, 40.54450459778309, 42.187566831707954, 41.06364034116268, 41.36299587786198, 39.680738747119904, 41.88321076333523, 40.00900313258171, 38.79133567214012, 40.31740218400955, 41.36315926909447, 43.29518459737301, 39.701432436704636, 38.81299830973148, 41.357258185744286, 41.94206960499287, 46.58287078142166, 45.887219309806824, 49.07095827162266, 53.36177542805672, 40.14395289123058, 36.94703623652458, 40.843886733055115, 43.344676941633224, 42.64647960662842, 43.270930498838425, 39.09285709261894, 40.73315687477589, 40.77635295689106, 41.83703564107418, 43.6842343211174, 41.38148568570614, 42.53669589757919, 44.26170073449612, 43.7325145304203, 40.25374040007591, 39.278974905610085, 41.53884284198284, 41.362881883978844, 43.14169943332672, 40.69354020059109, 43.29558737576008, 41.539127826690674, 39.779962822794914, 38.18537078797817, 39.94992010295391, 42.62735143303871, 51.483156234025955, 48.46877038478851, 48.39926831424236, 50.53380757570267, 41.20464317500591, 40.61132401227951, 39.18373301625252, 43.78177508711815, 40.854803547263145, 39.671547040343285, 41.80903494358063, 40.259744077920914, 41.1940873414278, 40.79738102853298, 43.00381623208523, 42.76665195822716, 39.79454264044762, 43.517510667443275, 42.28938616812229, 40.445759296417236, 40.10861098766327, 40.428394228219986, 41.01570211350918, 41.401814594864845, 38.40024545788765, 40.6890944391489, 41.76989704370499, 40.16494296491146, 41.358268931508064, 41.74483358860016, 39.634073451161385, 42.90160931646824, 41.4938722550869, 45.4864814132452, 42.83844530582428, 48.319924771785736, 53.28298285603523, 55.95379114151001, 57.635998874902725, 57.640003859996796, 57.51719444990158, 59.4443104416132, 55.272187516093254, 56.932987198233604, 57.25830674171448, 57.999578565359116, 48.609096854925156, 61.196563616395, 60.201670601964, 73.16614553332329, 18.810637928545475, 0.20491246541496366, 2.120567886158824, 0.6605230690911412, 0.7574520085472614, 57.16426178812981, 77.60959669947624, 70.72544530034065, 74.328693151474, 62.86584824323654, 49.12963852286339, 54.8971476405859, 53.82744424045086, 70.287556797266, 21.73828963190317, 0.9333895146846771, 0.12547789112431929, 0.41750330943614244, 0.10162715727346949, 0.18232582428026944, 0.13305795000633225, 0.15226534043904394, 0.20562243356835097], [0.07041868972009979, 0.029456943375407718, 0.053262432193150744, 0.09249105962226167, 0.02389393797784578, 0.03794533164182212, 0.09385645549627952, 0.0957326270872727, 0.0951202365104109, 0.15594351338222623, 0.013346108462428674, 7.845448516309261, 54.08843323588371, 50.093658193945885, 30.57555142790079, 20.038355849683285, 38.543748557567596, 52.57205620408058, 57.46845446527004, 54.12754453718662, 48.25203761458397, 51.14189274609089, 3.779938369989395, 0.8725851180497557, 1.394579792395234, 0.18134927668143064, 13.749574553221464, 65.84368765354156, 53.61458346247673, 48.03989499807358, 43.12752239406109, 48.73712718486786, 50.285107120871544, 50.05378693342209, 52.14129611849785, 47.87450887262821, 53.25343944132328, 53.60131077468395, 49.69607412815094, 47.37958163022995, 40.918362736701965, 37.36941397190094, 37.48705565929413, 35.491486340761185, 36.43320120871067, 36.012240797281265, 39.27228346467018, 36.24564707279205, 38.24521757662296, 37.222388461232185, 38.37300091981888, 37.54166632890701, 37.114554047584534, 37.54547752439976, 37.15224802494049, 38.45513731241226, 36.560760363936424, 36.30384474992752, 35.78839860856533, 37.70986810326576, 38.5537002235651, 36.62249945104122, 37.769562900066376, 37.38364800810814, 38.21013405919075, 37.11931899189949, 37.07478918135166, 38.830845952034, 38.93233850598335, 36.57763905823231, 35.38592800498009, 40.65922424197197, 41.366689279675484, 43.79163175821304, 44.28856149315834, 39.68278683722019, 38.36879074573517, 36.28847077488899, 39.59730662405491, 41.41414873301983, 38.56474623084068, 37.41555109620094, 36.50332644581795, 35.42488731443882, 36.83202400803566, 35.052488297224045, 36.44063740968704, 37.60527491569519, 39.442966505885124, 38.74440059065819, 38.63333635032177, 37.755841836333275, 37.54702404141426, 37.569401040673256, 37.79199689626694, 38.2910431176424, 38.71435560286045, 38.54147247970104, 37.08216838538647, 37.006130665540695, 36.632595509290695, 40.72411336004734, 46.10576078295708, 37.79853634536266, 41.17662347853184, 41.090276911854744, 46.05609364807606, 35.60362972319126, 33.058096915483475, 36.89201518893242, 38.00512745976448, 36.67956478893757, 37.593358755111694, 35.66604517400265, 36.520851105451584, 37.37760253250599, 36.87267802655697, 37.49686673283577, 38.180218264460564, 37.138701751828194, 36.935488656163216, 36.96011893451214, 37.71139942109585, 35.82266516983509, 37.50836871564388, 36.52159586548805, 38.44861686229706, 37.71107263863087, 34.89474356174469, 34.96591754257679, 37.816099002957344, 36.09257608652115, 37.91182726621628, 35.07453091442585, 38.92369017004967, 35.82119844853878, 37.74888060986996, 37.81232960522175, 39.56307426095009, 40.86601294577122, 48.0875900387764, 48.41787971556187, 52.166108787059784, 53.39012190699577, 55.669672787189484, 53.68109129369259, 54.45237770676613, 54.68924939632416, 55.53870141506195, 43.41899335384369, 52.993761375546455, 57.686600759625435, 65.95619961619377, 5.764834061264992, 0.05103302428324241, 5.725468173623085, 0.23540115362266079, 1.137712150812149, 52.96716280281544, 60.695419907569885, 63.93182784318924, 56.76206476986408, 48.24581354856491, 34.94025371968746, 30.540488809347153, 43.63636828958988, 49.78493995964527, 4.5876377541571856, 0.664444814901799, 0.08967740708612837, 0.08896463361452334, 0.07130747093469836, 0.049007706984411925, 0.041880885110003874, 0.004421958910825197, 0.05552826100029051, 0.03709228854859248, 0.09266610257327557, 0.05884869649889879, 0.018207684115623124, 0.017599147140572313, 0.02162471013434697, 0.040601088549010456, 0.04630379582522437, 0.046019364017411135, 0.11146216507768258, 0.050202987767988816, 9.664795640856028, 62.96797536313534, 54.55364607274532, 36.69778101146221, 26.877259276807308, 49.346416890621185, 58.22189703583717, 64.0013337135315, 59.51050288975239, 53.40340219438076, 55.749696493148804, 4.01140152476728, 0.7454661454539746, 2.1809243224561214, 0.31995984201785177, 16.21938217431307, 67.4847511947155, 55.942638739943504, 49.461786299943924, 44.64211732149124, 48.69997277855873, 53.11115987598896, 51.606406420469284, 55.31381048262119, 48.51833872497082, 54.435293823480606, 56.52509048581123, 51.14226892590523, 50.03583289682865, 43.94539810717106, 37.91568785905838, 39.891342446208, 37.441226318478584, 38.41997019946575, 37.118061259388924, 39.880627021193504, 39.80474889278412, 40.79380542039871, 39.39752854406834, 38.59173618257046, 38.3598156273365, 38.51505629718304, 38.44487406313419, 39.47607792913914, 40.17973557114601, 38.38576443493366, 38.42834115028381, 37.56494387984276, 39.767298102378845, 39.80501487851143, 38.93841437995434, 38.738738894462585, 38.64864572882652, 39.57831144332886, 39.269722402095795, 40.65497986972332, 39.90130551159382, 39.27612125873566, 37.77953736484051, 37.11190178990364, 42.684979140758514, 44.030756726861, 44.35922250151634, 46.07128903269768, 42.53003865480423, 39.383951872587204, 37.98461236059666, 41.33915215730667, 41.533082351088524, 39.721008986234665, 39.77671019732952, 38.74357223510742, 37.329808697104454, 37.81099587678909, 38.96825797855854, 38.57995301485062, 39.29003991186619, 39.32733491063118, 41.18139982223511, 40.32955013215542, 39.07231919467449, 39.14560966193676, 38.398045375943184, 40.52198700606823, 39.33953605592251, 40.05995459854603, 40.41898973286152, 39.7410187125206, 39.179716631770134, 36.294672042131424, 41.021531000733376, 46.98923237621784, 42.83645041286945, 45.504766032099724, 44.91446390748024, 48.90796981751919, 38.38947683572769, 36.5267825871706, 37.5225343555212, 40.07388085126877, 36.94595329463482, 38.650070652365685, 37.04592972993851, 37.80451342463493, 39.52684700489044, 40.28910510241985, 38.37925158441067, 39.77974243462086, 37.49338611960411, 39.27905470132828, 37.80147738754749, 39.44803163409233, 37.923838421702385, 38.55947591364384, 38.96405540406704, 39.888636991381645, 38.887493312358856, 37.20970094203949, 37.78617560863495, 39.813252836465836, 39.33561846613884, 39.616571590304375, 38.864690735936165, 40.17978496849537, 36.91144734621048, 39.41898599267006, 40.2090547978878, 41.59011349081993, 44.412039667367935, 49.39002335071564, 49.869341030716896, 54.291384145617485, 54.53897885978222, 56.78704842925072, 55.97236454486847, 58.35773594677448, 56.46026976406574, 57.58620634675026, 45.4515764862299, 55.16458109021187, 58.047110214829445, 69.72094640135765, 7.470679376274347, 0.14166175707941875, 4.612774355337024, 0.2090228206361644, 1.3602494657970965, 56.44480459392071, 65.20586147904396, 70.13298109173775, 66.0970276594162, 57.23741926252842, 38.44939202070236, 39.95973117649555, 50.26310630142689, 58.57126548886299, 7.770535061135888, 0.623614996438846, 0.06959606354939751, 0.06579162160051055, 0.13811538956360891, 0.06629720228374936, 0.018435237725498155, 0.0221225390851032, 0.04402869017212652, 0.155465911666397, 0.17471328901592642, 0.20131932775257155, 0.13862631371011958, 0.1155557700258214, 0.14824715995928273, 0.16393862577388063, 0.2282757789362222, 0.32412631844636053, 0.3628295275848359, 0.14418676611967385, 11.237078122794628, 73.67713451385498, 61.904161646962166, 44.238624572753906, 29.15448658168316, 51.00613743066788, 66.25471919775009, 69.99311819672585, 64.61236372590065, 57.64848880469799, 61.26031279563904, 5.300405407324433, 1.493762070313096, 4.669302497059107, 0.28255895362235606, 17.836438603699207, 68.1500194966793, 58.4749748557806, 52.313962653279305, 46.58228941261768, 51.76175348460674, 56.224230229854584, 54.53792631626129, 56.96843549609184, 50.68815529346466, 58.19674998521805, 59.08855453133583, 54.3148098886013, 52.99304321408272, 45.34318350255489, 40.105365961790085, 41.17102637887001, 38.1954288482666, 41.51064835488796, 39.78299506008625, 42.47090242803097, 40.86738087236881, 43.516917899250984, 42.21865676343441, 41.41381435096264, 41.42292246222496, 42.27951429784298, 41.77981071174145, 41.9729695469141, 42.97595992684364, 40.48132538795471, 41.007072776556015, 40.17546460032463, 43.48981775343418, 43.2760526239872, 41.30227513611317, 40.51336146891117, 41.24598115682602, 42.32280157506466, 40.86279071867466, 42.58418954908848, 42.80288681387901, 42.03492522239685, 40.960278287529945, 40.821977108716965, 46.2241168320179, 48.08764323592186, 48.700987324118614, 49.883867651224136, 46.00201115012169, 40.22583469748497, 38.745753318071365, 42.75578834116459, 44.23120357096195, 42.25907139480114, 41.564366072416306, 40.56672960519791, 39.31386463344097, 39.340596199035645, 40.74189640581608, 40.939501002430916, 41.04589909315109, 43.470245003700256, 43.302685394883156, 43.21453392505646, 41.40990436077118, 41.64801858365536, 41.19244582951069, 42.80113510787487, 42.88852661848068, 43.21120150387287, 41.377898678183556, 41.731606498360634, 40.75047254562378, 39.57273714244366, 42.80572906136513, 50.37418194115162, 46.21593967080116, 50.595493465662, 48.459605276584625, 51.339307352900505, 40.79767741262913, 36.72297365963459, 41.33693687617779, 41.65583096444607, 38.38983781635761, 40.54001323878765, 39.49745938181877, 38.87442201375961, 42.70319536328316, 42.329382821917534, 41.626732125878334, 43.34173209965229, 41.254097521305084, 40.60596629977226, 42.360005378723145, 41.07042297720909, 39.84021618962288, 40.94297781586647, 41.170919984579086, 42.05500714480877, 41.57359957695007, 38.28821986913681, 39.76308032870293, 41.54745697975159, 41.70322582125664, 42.4461467564106, 40.76126776635647, 43.37090313434601, 39.15368042886257, 42.70513705909252, 42.58977144956589, 44.00926128029823, 45.30741222202778, 51.21197998523712, 52.72470921278, 56.318138390779495, 57.913585379719734, 59.6462582051754, 58.826174810528755, 58.036185801029205, 58.60829070210457, 60.299313962459564, 49.28356446325779, 58.459087908267975, 63.82028102874756, 71.58834099769592, 9.560780972242355, 0.3567235224181786, 14.835430886596441, 0.2888187317876145, 1.25529280398041, 62.57072947919369, 69.09765064716339, 75.40620133280754, 68.5330693423748, 63.59591826796532, 46.61149464547634, 43.452157974243164, 57.79134213924408, 68.8821642100811, 12.071194164454937, 0.7791005750186741, 0.25578535278327763, 0.28867876273579895, 0.23488907172577456, 0.17388359759934247, 0.16181261016754434, 0.12170548769063316, 0.1161484194744844], [0.07313394089578651, 0.017213829632964917, 0.03327749735035468, 0.04299093394365627, 0.024854473740560934, 0.10211864457232878, 0.029998310419614427, 0.024327782666659914, 0.05423734706710093, 0.10760224758996628, 0.023162280558608472, 2.4905148474499583, 41.6523427516222, 55.41119545698166, 31.605596356093884, 22.954689860343933, 38.188311830163, 48.6576734483242, 57.25508451461792, 56.77186444401741, 46.926653534173965, 55.72170339524746, 10.159951820969582, 0.7379375619348139, 1.0959707968868315, 0.2951274026418105, 6.9470669981092215, 54.96560096740723, 59.748161137104034, 49.55854430794716, 50.00176392495632, 51.1858943849802, 50.39454124867916, 52.648781687021255, 52.98512443900108, 54.20862838625908, 56.33868768811226, 49.406639859080315, 49.274281561374664, 41.601976454257965, 38.1195393204689, 36.92845903337002, 37.997885048389435, 35.34257233142853, 36.63222312927246, 34.9988579750061, 38.61623726785183, 36.261195838451385, 36.50883235037327, 37.07722865045071, 37.86461099982262, 37.97027572989464, 38.49508456885815, 38.70085872709751, 38.337343633174896, 37.119622975587845, 37.12346076965332, 36.081271693110466, 36.81616745889187, 38.09807427227497, 35.446158573031425, 37.10270628333092, 35.77377699315548, 37.3775265365839, 35.14910191297531, 35.13328716158867, 39.50706146657467, 39.20751594007015, 38.47644656896591, 35.70713236927986, 36.28850497305393, 40.30235879123211, 41.587054654955864, 43.53129632771015, 38.313511312007904, 42.295051664114, 40.15157908201218, 35.804361552000046, 37.859583869576454, 38.90197433531284, 37.89335645735264, 35.3439174592495, 36.57812923192978, 37.52166040241718, 38.16067971289158, 35.46955391764641, 38.38215462863445, 36.29667453467846, 38.719899505376816, 38.70048254728317, 38.20327162742615, 37.39977054297924, 37.285655066370964, 37.47452013194561, 37.46337153017521, 35.72116121649742, 39.5964440703392, 38.76671299338341, 39.267252534627914, 39.25337187945843, 40.082548186182976, 45.2829073369503, 48.5990159958601, 39.8915134370327, 39.60522539913654, 38.73234383761883, 44.953768998384476, 37.092526629567146, 33.19744683802128, 36.84306241571903, 37.77006447315216, 37.58391626179218, 38.03783230483532, 36.0498321801424, 37.04665929079056, 36.88657768070698, 36.21891550719738, 35.83387076854706, 37.56649039685726, 36.322148367762566, 37.49821946024895, 35.365097522735596, 35.96126653254032, 35.86026415228844, 36.219211891293526, 37.53554865717888, 36.23114325106144, 36.41045942902565, 37.46744491159916, 36.112365424633026, 37.955163940787315, 36.38943135738373, 37.241870015859604, 36.17569662630558, 37.42543816566467, 36.81269824504852, 36.580637097358704, 34.984050169587135, 37.41061516106129, 36.90602503716946, 40.72103552520275, 42.75621011853218, 46.44699387252331, 50.696879625320435, 52.974887788295746, 52.86844030022621, 58.03457848727703, 54.96327169239521, 59.1753950715065, 50.66180370748043, 52.840659990906715, 56.428218483924866, 55.37122160196304, 0.2948469005059451, 0.914648148464039, 7.4127966072410345, 0.31339578330516815, 2.3766154842451215, 53.239004015922546, 62.074559703469276, 50.03831036388874, 49.30249124765396, 42.05731742084026, 24.904034659266472, 27.22253154963255, 43.40732418000698, 43.24519068002701, 2.111015673726797, 0.5225261114537716, 0.03039754319615895, 0.10942594934022054, 0.04859065709752031, 0.10475608156411909, 0.008742838235775707, 0.023605480018886738, 0.027663793989631813, 0.07297169999219477, 0.015338465127570089, 0.07153971120715141, 0.05235621421888936, 0.01238422941241879, 0.08953924145316705, 0.030036582975299098, 0.06776675858418457, 0.02733199275098741, 0.2557857980718836, 0.053407878294819966, 3.679832029156387, 51.91983640193939, 60.67756466567516, 34.8469877243042, 19.872946925461292, 41.99930213391781, 57.29762703180313, 59.228926599025726, 62.07349196076393, 51.58198893070221, 60.59898868203163, 10.39349203929305, 0.78452134039253, 1.7474908428266644, 0.30904748069588095, 7.317807404324412, 58.496903479099274, 60.975776463747025, 51.807031854987144, 52.15915895998478, 53.67692671716213, 52.227825075387955, 54.44496430456638, 52.58603945374489, 53.90795812010765, 57.520766258239746, 52.724226638674736, 51.69364593923092, 45.06607197225094, 40.955235958099365, 37.91824132204056, 38.787007704377174, 38.14571611583233, 38.87449041008949, 36.71300299465656, 39.84169811010361, 38.756438344717026, 37.83755265176296, 38.60177904367447, 38.56473483145237, 38.54173466563225, 40.39040386676788, 39.56972770392895, 40.84942303597927, 38.47144603729248, 39.449270367622375, 37.678246200084686, 39.49866011738777, 38.97923558950424, 38.420015797019005, 38.7823985517025, 39.44926656782627, 39.799060598015785, 36.61106966435909, 37.388010174036026, 39.471943750977516, 41.06473848223686, 40.62731355428696, 38.465677946805954, 37.173595279455185, 42.01748415827751, 43.77320654690266, 45.1215185970068, 42.80469171702862, 43.500981554389, 40.34231744706631, 36.98577515780926, 39.93216745555401, 40.03057457506657, 40.09583607316017, 38.323056399822235, 38.34113582968712, 39.290252700448036, 40.550211891531944, 38.581339940428734, 39.271865487098694, 38.932726085186005, 41.61507435142994, 40.01841902732849, 39.68422695994377, 38.85284297168255, 39.76373769342899, 40.92625491321087, 39.68027517199516, 38.5585031658411, 38.89733858406544, 40.58931939303875, 40.83749547600746, 38.81145179271698, 40.18271841108799, 46.60272091627121, 49.07823488116264, 40.88876612484455, 42.65730902552605, 42.84749262034893, 47.76167392730713, 38.303624242544174, 35.12148879468441, 37.97936864197254, 39.507992416620255, 38.632002621889114, 39.02530051767826, 37.52212397754192, 37.408023700118065, 38.8504870980978, 39.5466211438179, 37.17370167374611, 39.464070573449135, 37.6616220921278, 39.3703979998827, 36.70649774372578, 38.054388016462326, 37.84302435815334, 38.99376600980759, 39.88948054611683, 38.70139069855213, 37.669362276792526, 40.012958720326424, 37.229068502783775, 39.153289049863815, 38.33182632923126, 39.158475771546364, 39.16971556842327, 39.36811052262783, 38.05101379752159, 38.782189562916756, 37.674788385629654, 39.56061579287052, 38.444019109010696, 43.7164755910635, 45.15535198152065, 49.71234865486622, 51.505495235323906, 56.86338633298874, 55.841427370905876, 57.79269486665726, 58.19981262087822, 62.20901168882847, 53.229759112000465, 55.11288106441498, 58.47041890025139, 57.33174540102482, 0.4400098283076659, 1.4142267568968236, 3.5134703060612082, 0.08323227753862739, 1.9965548906475306, 58.42565730214119, 66.47892996668816, 56.60812363028526, 53.76406744122505, 51.24741688370705, 27.379514425992966, 26.641782112419605, 50.246922969818115, 54.916017428040504, 3.655175152234733, 0.43873131566215307, 0.05659763643052429, 0.058161605047644116, 0.035448613271000795, 0.06164616650494281, 0.04300256339774933, 0.026057773429783992, 0.033954150494537316, 0.12023700750432909, 0.14730294031323865, 0.1299162014038302, 0.14150339760817587, 0.09398728871019557, 0.18230422778287902, 0.238254533323925, 0.28631618013605475, 0.17473178333602846, 0.4218022443819791, 0.17081423808122054, 4.303303761407733, 59.802802205085754, 67.65262618660927, 43.87166306376457, 32.32403710484505, 53.55417050421238, 62.261095494031906, 64.5075273513794, 69.6122494339943, 55.97514219582081, 65.25436207652092, 13.112333547323942, 1.083349536638707, 5.362142119556665, 0.4695449012797326, 8.589903619140387, 60.39850004017353, 64.00941208004951, 56.239984184503555, 54.58719827234745, 57.04562835395336, 56.60602614283562, 55.66653795540333, 56.53182752430439, 57.2079898416996, 61.34307995438576, 55.25525562465191, 53.412985280156136, 47.07706466317177, 42.12859399616718, 39.37339223921299, 41.416983380913734, 40.25284744799137, 41.15681894123554, 38.73535707592964, 41.7288364470005, 40.54643489420414, 40.49627758562565, 40.66355600953102, 41.23444117605686, 41.39008842408657, 43.27921025454998, 43.049786165356636, 43.980432227253914, 40.592883601784706, 42.03094683587551, 39.94961231946945, 41.6415361315012, 42.808445915579796, 39.73156861960888, 40.48668310046196, 40.316623225808144, 42.56265990436077, 39.128111600875854, 38.2326440513134, 42.96891510486603, 42.91588135063648, 42.43114896118641, 41.60068832337856, 40.56411914527416, 46.358880400657654, 46.79578095674515, 49.02585469186306, 45.007114335894585, 47.27986738085747, 41.00833050906658, 37.95951850712299, 41.15217939019203, 42.78674528002739, 41.232624873518944, 40.04101261496544, 40.59054672718048, 40.487990230321884, 42.27839715778828, 39.83214162290096, 44.64520275592804, 41.15072026848793, 44.589862525463104, 43.77393990755081, 42.434173598885536, 41.91789150238037, 41.25868007540703, 45.098415836691856, 42.61909067630768, 40.80187998712063, 41.2315609306097, 43.37196707725525, 43.30840788781643, 40.60371682047844, 40.58296613395214, 48.983695954084396, 50.50385378301144, 44.08505581319332, 47.050640881061554, 45.86615703999996, 50.56837812066078, 40.26369586586952, 36.66078619658947, 41.03842109441757, 41.33494198322296, 40.32736524939537, 41.12560361623764, 40.439284443855286, 38.395909890532494, 41.030046343803406, 39.82287771999836, 40.54283648729324, 41.32970966398716, 40.48996992409229, 42.003972083330154, 39.45142865180969, 40.74530862271786, 41.91066429018974, 40.975283682346344, 42.978919968008995, 40.80329351127148, 41.56878903508186, 42.838475704193115, 40.23279592394829, 42.83855549991131, 40.53030475974083, 39.90665182471275, 40.42228415608406, 42.44698651134968, 40.93504764139652, 41.40163980424404, 39.091941341757774, 41.38503469526768, 40.358060002326965, 45.18357686698437, 46.115560457110405, 51.85523986816406, 53.32285791635513, 57.52890162169933, 56.65693961083889, 60.835658982396126, 59.10086207091808, 63.878083527088165, 55.63083127140999, 57.26642310619354, 58.55770021677017, 61.04283906519413, 0.6656652619130909, 1.9482390582561493, 22.828755117952824, 1.1857465608045459, 2.9225409775972366, 63.921363204717636, 70.28923630714417, 61.60423994064331, 61.632704213261604, 66.16144180297852, 36.85841739177704, 38.87472599744797, 57.51531355082989, 65.33643007278442, 7.430465184152126, 0.783798904158175, 0.2164367720251903, 0.21812137303641066, 0.06070875606383197, 0.24520759616279975, 0.1326531678205356, 0.15069317480083555, 0.08932343975175172], [0.045528500122600235, 0.13106581784086302, 0.09789674455532804, 0.0759904450387694, 0.022182499051268678, 0.041387026649317704, 0.05708691584004555, 0.06337765269563533, 0.027967900132352952, 0.09303762912168168, 0.04572728808852844, 0.5722827196586877, 35.30926711857319, 56.127768605947495, 35.856034979224205, 30.60299165546894, 32.48069129884243, 51.494004651904106, 58.56954038143158, 57.242184206843376, 48.76140408217907, 57.000543773174286, 16.697909496724606, 0.5054513120558113, 0.66380710224621, 0.25471965840552, 1.2298847548663616, 40.04044644534588, 63.985959738492966, 47.20531918108463, 55.631059259176254, 48.626401126384735, 55.71707524359226, 53.69201950728893, 56.93417273461819, 49.8478189855814, 53.36663156747818, 49.06699128448963, 44.62199740111828, 35.035244822502136, 39.1316682100296, 35.91966636478901, 37.093632370233536, 35.52850775420666, 37.55386367440224, 35.098408833146095, 36.49399034678936, 37.60983467102051, 37.861521765589714, 39.49453353881836, 39.32480424642563, 37.98581689596176, 38.8079559803009, 38.449703603982925, 39.129114747047424, 37.50197745859623, 36.06867156922817, 37.040226235985756, 37.10025541484356, 35.68784460425377, 38.38668018579483, 35.30960910022259, 36.82069681584835, 37.846577167510986, 37.907810881733894, 37.68038168549538, 37.51730963587761, 37.93480083346367, 39.360062554478645, 39.00836482644081, 36.5035430341959, 39.88427862524986, 41.1389485001564, 41.12046629190445, 41.79163567721844, 43.34007538855076, 41.79776094853878, 36.72382481396198, 39.44086901843548, 38.63156944513321, 39.35116343200207, 34.619672521948814, 37.38465875387192, 36.3504758477211, 39.061577171087265, 36.7053160071373, 37.52275854349136, 37.1680361777544, 37.80970774590969, 36.843218207359314, 38.78533959388733, 37.36965715885162, 38.447868302464485, 37.19969227910042, 36.17567382752895, 37.73405000567436, 38.25190141797066, 38.617263212800026, 40.881394520401955, 39.16752688586712, 40.01747287809849, 44.2008052021265, 48.61131973564625, 40.91032236814499, 44.48456637561321, 36.09612889587879, 43.317816182971, 39.08778816461563, 34.4657351821661, 36.30564205348492, 38.84566895663738, 37.596018612384796, 37.112247571349144, 36.94737821817398, 35.75791284441948, 36.91648967564106, 36.7796666175127, 36.30930885672569, 37.81711734831333, 36.74626260995865, 36.577817648649216, 35.35487227141857, 34.20072220265865, 36.2699543684721, 37.28138789534569, 35.50907179713249, 36.90767414867878, 36.43595606088638, 35.37103660404682, 37.10780940949917, 38.34210477769375, 37.568344697356224, 36.1171455681324, 37.75435611605644, 36.45349591970444, 36.53629347681999, 35.737234354019165, 35.562728717923164, 36.011974811553955, 38.498872965574265, 37.878750041127205, 38.91413368284702, 39.5999550819397, 47.626302391290665, 48.70973065495491, 52.155313566327095, 56.49647422134876, 58.63612800836563, 56.231571435928345, 59.11088213324547, 51.810368075966835, 68.819649964571, 22.24871624261141, 0.19429323758231476, 0.6000022916123271, 0.9559794806409627, 0.028664507772191428, 3.2491826126351953, 56.57221935689449, 56.835366636514664, 59.74799394607544, 52.04347796738148, 43.14441628754139, 21.145679131150246, 34.460396468639374, 43.52474927902222, 46.78526692092419, 1.1035904567688704, 0.22835639101685956, 0.04138196149142459, 0.01807029031624552, 0.13029588415520266, 0.08246619559940882, 0.06820271839387715, 0.05223281361395493, 0.08332270081155002, 0.03548766137100756, 0.0902228188351728, 0.027118706930195913, 0.10164836785406806, 0.025874681887216866, 0.025281221642217133, 0.03617646718339529, 0.07909334963187575, 0.025416776770725846, 0.17218532622791827, 0.03635599641711451, 1.0701902490109205, 42.91721507906914, 62.2937623411417, 40.312679037451744, 33.04310292005539, 38.956797793507576, 56.56556971371174, 62.74731360375881, 63.313768208026886, 52.088247165083885, 62.9594524204731, 18.841657564044, 0.46171895402949303, 1.7286594095639884, 0.8117246150504798, 1.3473615073598921, 45.212018340826035, 65.48954665660858, 50.838361233472824, 58.13116170465946, 52.519706413149834, 57.357777804136276, 54.11875560879707, 57.70726405084133, 53.0365926772356, 54.93897579610348, 51.56590819358826, 46.64864145219326, 38.04923169314861, 39.70330573618412, 37.1680323779583, 39.412841722369194, 37.75240682065487, 39.369744434952736, 36.426749154925346, 39.54578138887882, 39.700942263007164, 40.65172344446182, 42.152228727936745, 43.15032497048378, 39.89263817667961, 42.42255762219429, 40.21473929286003, 42.08035558462143, 38.451675698161125, 37.69464232027531, 39.72856678068638, 39.22973334789276, 37.68953159451485, 39.90513950586319, 38.168393298983574, 38.99191550910473, 37.828775122761726, 37.68765449523926, 38.676825016736984, 39.572007581591606, 39.513464123010635, 40.508759915828705, 39.48512904345989, 37.52359829843044, 41.99511095881462, 43.75516511499882, 42.98236258327961, 43.64562079310417, 46.633073687553406, 42.77558907866478, 39.4707278162241, 41.034153923392296, 40.50840653479099, 39.9296747893095, 36.517575681209564, 37.462467178702354, 37.89324626326561, 39.887231066823006, 39.10943940281868, 39.61662858724594, 40.41069097816944, 39.50593672692776, 38.831556513905525, 40.853260830044746, 41.10911250114441, 39.53953452408314, 39.128936156630516, 39.39378194510937, 38.39421898126602, 39.44712348282337, 39.93132770061493, 42.588217332959175, 39.994438514113426, 40.652608796954155, 45.30275747179985, 50.990546867251396, 42.75760844349861, 46.210505962371826, 41.11067421734333, 46.3276194781065, 40.738146007061005, 35.81549495458603, 37.57491834461689, 40.87849147617817, 40.035993084311485, 39.28312428295612, 38.45861032605171, 37.85815514624119, 37.19004839658737, 39.354617446660995, 39.94760602712631, 37.800329849123955, 38.82388852536678, 38.886341974139214, 38.19732874631882, 36.25090219080448, 39.11515049636364, 38.622871711850166, 37.84617818892002, 37.280434146523476, 38.69968079030514, 37.60782837867737, 37.58746527135372, 40.81682078540325, 40.252988040447235, 38.498109206557274, 40.37736676633358, 39.37825217843056, 38.35887707769871, 38.88601519167423, 37.823611199855804, 38.281182646751404, 39.832134023308754, 39.91235911846161, 41.25357314944267, 43.31374280154705, 49.543474316596985, 51.78918041288853, 55.20382158458233, 56.902930811047554, 58.681425377726555, 58.183036521077156, 59.99661460518837, 53.900217935442924, 68.99751842021942, 25.416190177202225, 0.20987672090996057, 2.0124527625739574, 1.879543256945908, 0.21384851715993136, 3.524165782146156, 60.420618653297424, 61.800222024321556, 62.75102600455284, 54.76829655468464, 53.64617496728897, 26.98842991143465, 39.247144013643265, 49.576969519257545, 54.63685020804405, 2.0964018953964114, 0.3723492339486256, 0.012642636884265812, 0.06035567188519053, 0.032182328577619046, 0.07075753950630315, 0.037811125366715714, 0.035355544241610914, 0.04186750047665555, 0.10357268998632208, 0.17262356443097815, 0.14490253786789253, 0.2345573910861276, 0.14599407382775098, 0.22199280123459175, 0.09773356854566373, 0.2417126891668886, 0.1123938053206075, 0.3045710833976045, 0.14453961281105876, 1.5186411165632308, 51.29349701106548, 73.6207227408886, 49.61383134126663, 41.96325346827507, 45.426467433571815, 64.99767825007439, 68.43735247850418, 69.91931095719337, 59.34133976697922, 68.9523920416832, 22.604489251971245, 0.5997082230169326, 4.421877823770046, 0.8442883926909417, 2.0177340041846037, 46.002744510769844, 68.16895768046379, 51.16642042994499, 61.54786616563797, 53.77101346850395, 57.96860262751579, 56.8053862452507, 61.586099714040756, 54.4635035097599, 58.90218213200569, 54.057882875204086, 48.54399114847183, 39.35112923383713, 43.913590013980865, 39.490061178803444, 41.88641399145126, 39.93285521864891, 41.798304319381714, 38.37606355547905, 41.20779700577259, 42.960886135697365, 42.451656460762024, 44.80028763413429, 45.821973010897636, 42.34202094376087, 45.10541506111622, 43.39737631380558, 44.83312167227268, 40.510500222444534, 40.355248153209686, 41.53775990009308, 42.22376748919487, 41.623680889606476, 42.03982695937157, 39.26098667085171, 42.38372750580311, 42.37749584019184, 40.618300437927246, 40.687373131513596, 42.79448166489601, 41.63391754031181, 42.838175520300865, 43.24703358113766, 39.203522354364395, 45.744958743453026, 47.060372158885, 46.07332572340965, 46.95053145289421, 47.78181664645672, 44.91373434662819, 40.34277342259884, 43.36002431809902, 41.19067892432213, 42.898269295692444, 38.868437334895134, 40.557382106781006, 40.73595732450485, 41.606376618146896, 40.098343938589096, 40.885331109166145, 41.76434174180031, 42.27448336780071, 41.65012367069721, 43.877917528152466, 43.54337587952614, 43.931433856487274, 42.17252343893051, 42.40203872323036, 41.230979561805725, 40.304824858903885, 41.73904649913311, 44.786980748176575, 43.388864770531654, 41.93336047232151, 47.82934069633484, 52.52075895667076, 46.598514541983604, 50.576080307364464, 45.02253770828247, 48.11701565980911, 43.6633126437664, 38.83497253060341, 39.09837059676647, 42.12739706039429, 41.52132958173752, 40.929211154580116, 41.272997707128525, 39.80862848460674, 39.819093123078346, 41.11676529049873, 41.04706183075905, 40.759223476052284, 41.20979569852352, 40.75970605015755, 40.5670677870512, 37.23699487745762, 40.81467770040035, 41.351410299539566, 39.463477805256844, 41.026915311813354, 41.144746989011765, 37.93429546058178, 40.976621210575104, 42.87693724036217, 42.27776639163494, 39.69058021903038, 43.41846898198128, 40.89514218270779, 39.95544120669365, 40.5998220294714, 41.18570499122143, 40.30641697347164, 42.3804634809494, 42.694102451205254, 42.680605575442314, 44.83966112136841, 52.25974716246128, 54.391611367464066, 55.87267309427261, 59.00932878255844, 60.87983161211014, 59.13589999079704, 64.09719496965408, 57.94658660888672, 72.77622565627098, 26.75165131688118, 0.2532811980927363, 1.478470740839839, 4.071887154132128, 0.2658045245334506, 3.7500999961048365, 67.0715157687664, 68.97594317793846, 71.79002657532692, 59.73651096224785, 59.796190559864044, 34.211270436644554, 47.62638978660107, 57.63313762843609, 68.09998378157616, 3.434214871376753, 0.2765708608785644, 0.16339059424353763, 0.1937882654601708, 0.18841950979549438, 0.14896791893988848, 0.1434674914344214, 0.2031692347372882, 0.17022038635332137], [0.03340282382851001, 0.04073694239195902, 0.07739143431535922, 0.022953885491006076, 0.07003581573371775, 0.04914884120807983, 0.016959924214461353, 0.19585358822951093, 0.04176543661742471, 0.03675927575386595, 0.08606610907008871, 0.45679495262447745, 27.140590846538544, 60.40117509663105, 34.0251412242651, 21.122783459722996, 26.940565779805183, 49.85341228544712, 58.466729298233986, 54.37900744378567, 48.68823520839214, 54.17752705514431, 28.720870949327946, 0.24572638707468286, 0.9823850949760526, 1.3308313256129622, 0.0598189135780558, 8.058963809162378, 58.870757818222046, 56.931281089782715, 56.29763089120388, 55.163927525281906, 56.614986062049866, 53.770226910710335, 52.444975823163986, 50.11621758341789, 46.01297736167908, 42.05557331442833, 37.35844396054745, 37.377891317009926, 37.15440630912781, 36.09796799719334, 36.09153874218464, 36.562132090330124, 36.9192711263895, 34.52964395284653, 37.047977820038795, 37.21866086125374, 39.99456390738487, 40.57686746120453, 40.6404684484005, 39.279472678899765, 40.66796377301216, 41.957675367593765, 40.43098948895931, 38.38739834725857, 39.757608622312546, 36.35020986199379, 36.93743795156479, 36.31457917392254, 37.72958144545555, 37.81439669430256, 37.58372247219086, 35.77987566590309, 37.53969423472881, 37.07519955933094, 39.43418137729168, 37.79500633478165, 39.37784940004349, 38.98865528404713, 36.44595332443714, 38.779180124402046, 44.63202126324177, 38.40673170983791, 40.19659146666527, 46.115552857518196, 43.69137413799763, 40.41416399180889, 40.280335173010826, 39.59962449967861, 38.18643853068352, 36.72921672463417, 37.41856433451176, 35.39454594254494, 37.43840306997299, 36.711581870913506, 37.88137570023537, 39.17321138083935, 39.37310725450516, 37.26488538086414, 37.07527935504913, 37.3449394851923, 37.800588235259056, 36.04388929903507, 35.008205473423004, 34.95948828756809, 38.950433135032654, 37.989977672696114, 38.67679841816425, 37.9826744645834, 39.94407221674919, 40.752243250608444, 46.70063406229019, 40.8260390907526, 38.8337641954422, 42.40274928510189, 38.84389825165272, 38.75889681279659, 33.21331858634949, 35.681419149041176, 37.99189656972885, 41.029582768678665, 37.34160326421261, 38.64170730113983, 35.818603187799454, 37.10198812186718, 37.49300234019756, 36.573341488838196, 36.21412396430969, 36.441746950149536, 35.93454636633396, 35.270049422979355, 34.62710492312908, 36.24575346708298, 36.92872881889343, 35.12683890759945, 36.92893400788307, 36.51888661086559, 37.07611531019211, 38.33752982318401, 38.34207057952881, 38.80866654217243, 36.761556789278984, 38.960004821419716, 37.41086594760418, 40.773845091462135, 41.763232201337814, 40.37613943219185, 36.93736955523491, 37.60762698948383, 36.13824583590031, 38.35944704711437, 38.67060475051403, 40.037364810705185, 46.86726652085781, 51.7807524651289, 52.643344178795815, 58.9642708003521, 55.97918897867203, 57.51144155859947, 56.22835300862789, 58.11848558485508, 2.9571540327742696, 0.30919549462851137, 0.6351949938107282, 2.034696056507528, 0.07225107459817082, 2.8849118342623115, 56.47656328976154, 55.87139256298542, 63.31074357032776, 49.36568185687065, 26.605482660233974, 24.3845322355628, 28.928052932024002, 45.17363280057907, 30.060243979096413, 1.1096622934564948, 0.014269341099861776, 0.09388940685312264, 0.07354151355684735, 0.08611664932686836, 0.030208097014110535, 0.020720828069897834, 0.024460363638354465, 0.09203426772728562, 0.046459594886982813, 0.0452836841577664, 0.019041950872633606, 0.03341235300467815, 0.027309501965646632, 0.02902982996602077, 0.038069515212555416, 0.06365018416545354, 0.06098813013522886, 0.03511727773002349, 0.03516742835927289, 0.44789865030907094, 34.67081397771835, 67.92793661355972, 38.47341053187847, 26.345648802816868, 36.27577945590019, 58.188789412379265, 62.21980310976505, 61.88604801893234, 53.47766540944576, 61.184324473142624, 29.91733554750681, 0.2810037386370823, 1.6613766574300826, 2.9105842066928744, 0.1889164964086376, 9.48934005573392, 63.979895263910294, 58.74874256551266, 57.9109825193882, 55.21888017654419, 59.41278353333473, 54.01389263570309, 55.27223311364651, 51.75484925508499, 47.9880315810442, 44.490938633680344, 40.12043975293636, 39.39548045396805, 39.69230532646179, 36.727685406804085, 38.82353514432907, 38.50947819650173, 39.08798575401306, 35.787365064024925, 39.10203740000725, 38.76594163477421, 42.483479753136635, 42.19022288918495, 43.662826269865036, 41.47287078201771, 41.82678759098053, 43.14105726778507, 41.845064610242844, 40.267077684402466, 42.064917013049126, 39.700436890125275, 39.14168067276478, 38.04433375597, 39.25160117447376, 38.84270891547203, 40.2095677703619, 37.642718106508255, 37.868786975741386, 37.58966915309429, 40.258657336235046, 40.059874802827835, 40.631804913282394, 40.61739228665829, 37.87962019443512, 41.249484568834305, 46.03778623044491, 41.142904087901115, 43.517750054597855, 47.02780790627003, 44.517780393362045, 41.06352634727955, 40.22015780210495, 40.173667296767235, 39.076882749795914, 37.093244791030884, 39.513034746050835, 38.22142705321312, 39.316722080111504, 39.11742277443409, 39.83786031603813, 41.696868762373924, 40.05683496594429, 39.18238028883934, 38.43267671763897, 37.557180896401405, 39.343339651823044, 37.213139757514, 38.16829830408096, 37.502273842692375, 41.68585695326328, 40.67466281354427, 40.93721732497215, 38.97010087966919, 41.13715499639511, 41.00752115249634, 49.15592551231384, 42.59327866137028, 42.84724183380604, 43.53613346815109, 41.62741608917713, 41.944007501006126, 34.97984379529953, 37.683596312999725, 39.893189147114754, 41.588392183184624, 39.42571543157101, 39.82977814972401, 37.93933779001236, 38.15120682120323, 39.41519379615784, 38.19504886865616, 38.60100768506527, 38.47781829535961, 37.140092477202415, 37.74635374546051, 37.56019413471222, 37.008805721998215, 39.64089408516884, 38.333167657256126, 38.005294650793076, 38.49699206650257, 39.85968254506588, 40.43642319738865, 40.50336800515652, 40.17976216971874, 37.84357912838459, 40.82815557718277, 39.95609097182751, 42.781569957733154, 42.577593103051186, 41.94953240454197, 40.37830151617527, 40.346303433179855, 38.76954764127731, 41.85403972864151, 40.01383267343044, 42.7070027589798, 49.395191073417664, 55.86339399218559, 55.13994701206684, 61.283343359827995, 56.8365141749382, 61.19626723229885, 55.85207059979439, 59.73622217774391, 3.8262118119746447, 0.42604302463587373, 4.639107892289758, 3.8013221975415945, 0.041097091816482134, 3.6621748516336083, 62.22932539880276, 62.057441622018814, 69.70290496945381, 54.96310070157051, 34.260466396808624, 28.581435531377792, 34.29384380578995, 53.56179289519787, 38.655618354678154, 1.384929260239005, 0.08636322047095746, 0.10181679826928303, 0.04205894860206172, 0.04073420386703219, 0.02178835555241676, 0.03132117009954527, 0.06116530676081311, 0.01961125606612768, 0.10567818520939909, 0.14636401960160583, 0.1149557955795899, 0.14963117631850764, 0.1622325470088981, 0.12909738987218589, 0.09326538682216778, 0.35370372352190316, 0.18016817833995447, 0.09531286836136132, 0.225268047361169, 0.8095476881135255, 40.410557985305786, 77.83758446574211, 46.900944113731384, 32.09784284234047, 38.42519871890545, 63.557585924863815, 65.69500163197517, 68.00872787833214, 57.34663300216198, 68.14017042517662, 36.75723262131214, 0.41923741169739515, 3.932052757591009, 4.023927077651024, 0.13359422591747716, 10.703054778277874, 63.98697808384895, 60.80740749835968, 59.68301363289356, 59.328165873885155, 61.925607696175575, 56.36503927409649, 56.56446777284145, 55.06531901657581, 50.094532147049904, 46.421934217214584, 41.0670031607151, 41.98067553341389, 41.674693152308464, 39.31906275451183, 39.985691383481026, 41.641061156988144, 40.047449469566345, 37.82433696091175, 39.669445753097534, 41.36937193572521, 45.02370424568653, 46.0556148737669, 46.25839479267597, 44.0481635928154, 43.139465153217316, 46.01567521691322, 43.40113431215286, 41.890418976545334, 45.75482681393623, 42.011149898171425, 42.724124640226364, 41.18526041507721, 43.07977415621281, 42.74736039340496, 42.92671076953411, 38.99946950376034, 41.78150162100792, 40.58291673660278, 43.40274542570114, 40.07386565208435, 42.622191309928894, 43.651274889707565, 41.57882809638977, 43.89411985874176, 48.61414298415184, 44.30749587714672, 45.99815055727959, 49.95143562555313, 44.93187077343464, 43.443198055028915, 41.936544701457024, 44.76232387125492, 40.438015311956406, 40.854845345020294, 42.41368509829044, 40.64951576292515, 42.032322362065315, 40.96539281308651, 43.11359994113445, 44.18674595654011, 42.57713332772255, 42.31954514980316, 40.52318774163723, 39.83518525958061, 40.654022321105, 39.942445904016495, 38.93262729048729, 39.79952037334442, 43.890418857336044, 43.28559011220932, 42.719511687755585, 40.70643670856953, 40.22839576005936, 44.049102142453194, 51.791673079133034, 45.1113161444664, 46.88299387693405, 48.525634333491325, 43.071395605802536, 42.73792929947376, 37.913445979356766, 38.545367270708084, 41.41880728304386, 44.208480790257454, 40.63338942825794, 41.56031548976898, 39.12879556417465, 39.714670926332474, 42.20222644507885, 39.42734554409981, 38.0317260324955, 41.173139065504074, 38.83596047759056, 39.77040633559227, 40.420718640089035, 40.83860881626606, 41.09688475728035, 40.61335310339928, 39.971293956041336, 39.97265808284283, 41.529643535614014, 42.67251580953598, 42.83488109707832, 41.979592591524124, 39.131774604320526, 44.24022048711777, 43.12380239367485, 46.145487651228905, 45.33677704632282, 45.313807278871536, 42.25713349878788, 41.25332996249199, 40.31702220439911, 44.47998762130737, 42.84915313124657, 45.06438486278057, 52.181604355573654, 57.36530900001526, 56.367444545030594, 63.77631738781929, 57.98422358930111, 62.76644177734852, 58.347765281796455, 62.472550347447395, 5.083159189671278, 0.34766531316563487, 4.756606612354517, 11.679330691695213, 0.40794747532345355, 3.593204990029335, 68.5431843996048, 66.86360612511635, 76.38950496912003, 60.6887436658144, 39.07817468047142, 35.212664902210236, 42.11054876446724, 61.713491678237915, 49.9230245500803, 1.8046045093797147, 0.2314170525642112, 0.2818374376511201, 0.21825590956723318, 0.17575628851773217, 0.08887018047971651, 0.1038397295633331, 0.10574626241577789, 0.14124637702479959], [0.03784370936045889, 0.06259959249291569, 0.03076742032135371, 0.07062572665745392, 0.07400937829515897, 0.020121716370340437, 0.07147084732423536, 0.05077139867353253, 0.0490167871612357, 0.04787915640918072, 0.17077016935218126, 0.1482503957231529, 23.37185237556696, 54.21650916337967, 44.99676749110222, 28.022396229207516, 21.67027898132801, 47.02313035726547, 59.81471076607704, 57.08575800061226, 49.475970938801765, 49.1983388364315, 41.72877185046673, 0.4544303216971457, 1.7380463308654726, 1.1718553374521434, 0.5314176937099546, 0.05524091255210806, 18.51861409842968, 59.16189059615135, 58.00837129354477, 56.294720247387886, 52.2043651342392, 52.703491151332855, 50.049059987068176, 45.23926667869091, 39.55501489341259, 36.91555492579937, 37.070229426026344, 37.253284603357315, 35.8369942009449, 35.535366386175156, 37.300972044467926, 35.170361772179604, 36.925309002399445, 37.51046620309353, 37.81347714364529, 40.246102809906006, 41.080279648303986, 40.85765339434147, 42.30887912213802, 40.05858287215233, 40.91126851737499, 44.340736493468285, 43.36305275559425, 42.423959746956825, 42.12676629424095, 38.89543488621712, 38.51169727742672, 37.2639924287796, 37.684306874871254, 36.517438888549805, 37.074424400925636, 36.65778435766697, 37.008478939533234, 37.619444355368614, 38.02414923906326, 37.938399240374565, 41.73316441476345, 36.84248864650726, 37.955935299396515, 40.00741861760616, 40.305220037698746, 39.99773673713207, 41.74570374190807, 43.8280376046896, 43.72695542871952, 40.29108099639416, 38.545504063367844, 38.63906644284725, 37.19141252338886, 35.77823795378208, 37.1860396116972, 36.18688702583313, 36.38715907931328, 36.1327513307333, 37.42582194507122, 38.37017387151718, 36.79026424884796, 37.51382902264595, 39.18616108596325, 36.790507435798645, 36.85608811676502, 35.93501374125481, 36.720712780952454, 36.589281633496284, 37.88357578217983, 37.87736311554909, 38.44203181564808, 40.36749109625816, 39.5843493193388, 39.063720256090164, 45.58296963572502, 42.343069687485695, 39.54786367714405, 42.27060377597809, 39.36459191143513, 41.48513272404671, 33.64568218588829, 34.13298703730106, 38.055930733680725, 39.38989855349064, 36.44175834953785, 36.24880850315094, 36.21798075735569, 36.848853304982185, 37.46440887451172, 36.09143614768982, 36.83003291487694, 36.75242207944393, 36.82346686720848, 35.46244829893112, 35.62967352569103, 35.0972118973732, 36.81771397590637, 36.940941363573074, 37.45076760649681, 36.6244525462389, 36.85170315206051, 38.36237668991089, 39.02648605406284, 37.9326843470335, 39.96702678501606, 45.08711904287338, 48.16190645098686, 47.34697178006172, 44.87883321940899, 46.82080261409283, 42.90959648787975, 39.680020585656166, 37.40291677415371, 37.6424141228199, 38.486740216612816, 38.439292162656784, 41.624159663915634, 47.152559012174606, 52.02283747494221, 55.477315708994865, 58.698661252856255, 54.75365214049816, 58.20054218173027, 33.30869346857071, 0.32860541716217995, 0.13593395036878064, 2.5944547075778246, 1.830579440575093, 0.36157835565973073, 4.365624692291021, 58.69634337723255, 58.64916890859604, 58.84091801941395, 52.00092025101185, 28.54014314711094, 29.58145447075367, 36.3983228802681, 49.24940049648285, 26.357230581343174, 0.6923357932828367, 0.11429340651375242, 0.10094919052789919, 0.031699910323368385, 0.062248452741187066, 0.05426579729828518, 0.07392679210170172, 0.07979732123203576, 0.01346820010439842, 0.05014906702854205, 0.05534578915103339, 0.02076089847832918, 0.043300275938236155, 0.023123124847188592, 0.0075950423797621625, 0.018507239037717227, 0.07772935641696677, 0.036427758386707865, 0.03768523114558775, 0.05455729435198009, 0.1806498470250517, 27.486805468797684, 62.317321076989174, 47.70831719040871, 28.875547349452972, 30.028304792940617, 54.64645229279995, 64.33732688426971, 63.034783378243446, 55.19134305417538, 55.12050345540047, 44.74817343056202, 0.5437946983147413, 2.15039343573153, 1.7852764902636409, 1.5885406220331788, 0.18525962310377508, 20.605887696146965, 60.85572570562363, 57.317412570118904, 59.150574803352356, 54.507402554154396, 54.42712806165218, 51.717877238988876, 48.411404862999916, 43.437657952308655, 40.58212257921696, 38.08778062462807, 38.81530098617077, 38.35377775132656, 37.67719365656376, 40.74477665126324, 37.24201820790768, 37.69629143178463, 38.76437611877918, 39.911686554551125, 41.64475455880165, 42.52142071723938, 43.088931664824486, 43.59411835670471, 43.4813442081213, 43.76395784318447, 45.12182638049126, 45.616225451231, 45.16647398471832, 44.14142958819866, 41.7733396589756, 39.52263683080673, 39.48185361921787, 39.72245670855045, 38.96354243159294, 38.84234793484211, 39.196773916482925, 37.87717692553997, 40.44027999043465, 39.530023634433746, 41.253196969628334, 43.04757848381996, 39.4145592302084, 39.55465771257877, 42.54051849246025, 44.797528982162476, 43.93404811620712, 41.76314100623131, 46.61675736308098, 44.437783285975456, 42.42957964539528, 41.351307705044746, 40.221020355820656, 38.285009041428566, 38.00037771463394, 37.6046821475029, 37.332346960902214, 37.587913647294044, 37.63646364212036, 38.43379385769367, 40.24779371917248, 40.317782163619995, 38.20663824677467, 41.13841272890568, 39.3899517506361, 39.1784892976284, 37.59098768234253, 38.68681848049164, 38.37128721177578, 39.513559117913246, 39.51688013970852, 40.07688648998737, 43.20605657994747, 40.80636374652386, 40.36963798105717, 47.252706438302994, 45.00251658260822, 42.09718868136406, 45.71690484881401, 43.286923840641975, 43.52908484637737, 35.980409905314445, 37.51431539654732, 40.105023980140686, 41.8999944627285, 37.78945483267307, 38.35188165307045, 38.00120607018471, 38.49261090159416, 40.107775032520294, 39.497968554496765, 38.72573599219322, 38.30023102462292, 38.02719667553902, 37.61499099433422, 37.88315400481224, 37.27815426886082, 38.219226971268654, 39.10063147544861, 38.95462051033974, 37.9551487416029, 38.88223059475422, 40.750932320952415, 41.3897730410099, 39.40407559275627, 41.14509277045727, 46.32252775132656, 50.59741996228695, 49.72238391637802, 47.872377187013626, 47.54774160683155, 44.65345211327076, 41.684443429112434, 39.426691979169846, 39.97784100472927, 40.242705792188644, 40.39398327469826, 43.30680437386036, 49.670026525855064, 55.22950820624828, 56.29758909344673, 59.219373911619186, 58.6075459420681, 58.22048731148243, 38.09913821518421, 0.18031392130069435, 1.1025016964413226, 7.535425527021289, 5.39046342484653, 0.1675393630284816, 4.665087573230267, 64.591563642025, 61.229146867990494, 63.51763866841793, 57.64720447361469, 38.17952670156956, 32.12946094572544, 37.77496241033077, 56.75795719027519, 34.54124853014946, 0.9373451618012041, 0.08179211770766415, 0.04579870495945215, 0.05098615394672379, 0.08297960594063625, 0.06109567475505173, 0.09574094656272791, 0.014065087216295069, 0.0392533557896968, 0.17627316468860954, 0.16724692715797573, 0.14461433223914355, 0.13426009565591812, 0.18959263747092336, 0.11320209319819696, 0.16246268700342625, 0.159001532883849, 0.19092078495305032, 0.14387552422704175, 0.2884083241224289, 0.286258144187741, 33.62578645348549, 70.11997818946838, 57.73517355322838, 38.427364602684975, 32.03236475586891, 59.34594891965389, 70.66513493657112, 66.23307555913925, 60.623303577303886, 60.09626425802708, 50.74539542198181, 0.9647144400514662, 4.237646134570241, 4.93827486410737, 1.1549304518848658, 0.21555657003773376, 22.706073001027107, 60.16252510249615, 59.26636219024658, 60.93457147479057, 55.98598301410675, 57.0104156434536, 55.64451053738594, 49.496406242251396, 43.73989373445511, 41.61362662911415, 40.35435140132904, 40.353412851691246, 41.54507830739021, 38.60615260899067, 43.15385118126869, 38.871739357709885, 41.08759805560112, 41.181251630187035, 42.24144034087658, 44.29371401667595, 46.813142225146294, 44.906389340758324, 47.04542376101017, 44.665341675281525, 46.56861014664173, 47.977730333805084, 48.28476145863533, 46.149492636322975, 47.87396930158138, 43.579629734158516, 42.256590127944946, 41.31941221654415, 42.67588622868061, 40.776778534054756, 40.965430811047554, 40.913054421544075, 39.65479373931885, 42.7783477306366, 42.29081489145756, 42.951230853796005, 45.70216163992882, 41.41940765082836, 42.54498325288296, 45.08446678519249, 45.243875831365585, 47.49676734209061, 44.86511595547199, 47.13729903101921, 48.18600095808506, 43.80130983889103, 41.79480470716953, 42.49250806868076, 39.966764599084854, 40.906150192022324, 41.71222373843193, 40.86019925773144, 39.32549960911274, 41.07820875942707, 41.80404581129551, 42.589262276887894, 40.93653716146946, 40.5484601855278, 44.7737992554903, 41.680294051766396, 41.27467341721058, 40.19856736063957, 40.93709193170071, 40.978912487626076, 41.89248226583004, 42.313716262578964, 42.57577300071716, 43.97542029619217, 42.39630863070488, 40.71753591299057, 48.74374642968178, 47.01401084661484, 45.21801061928272, 50.53693860769272, 46.54666252434254, 45.242975279688835, 39.58325877785683, 38.594863414764404, 42.42422953248024, 43.57400603592396, 39.39893066883087, 40.78415393829346, 39.72235411405563, 41.20997428894043, 41.263171434402466, 39.424890875816345, 39.9943283200264, 40.149477794766426, 40.365367010235786, 40.169430524110794, 40.7572665810585, 37.922432497143745, 40.194402784109116, 40.9722438454628, 40.671584978699684, 39.32411268353462, 39.5555354654789, 42.29568623006344, 42.61412814259529, 40.746266171336174, 43.81602644920349, 48.15453104674816, 53.893271908164024, 51.29901051521301, 49.82069604098797, 50.74341952800751, 47.88278102874756, 44.85218904912472, 41.87421664595604, 41.50448128581047, 41.90176896750927, 42.64641121029854, 45.30875734984875, 51.63475289940834, 57.10012122988701, 60.79320766031742, 62.334378361701965, 60.127802565693855, 58.10125730931759, 41.83100916445255, 0.5102039664052427, 0.8969137875828892, 10.483641251921654, 7.822815980762243, 0.8402249263599515, 5.186750181019306, 69.24344882369041, 68.38855549693108, 71.46996214985847, 63.78346860408783, 39.84114333987236, 41.30820281803608, 44.73179630935192, 65.80600887537003, 43.615602403879166, 1.3430378143675625, 0.15986245387466624, 0.18690658238483593, 0.12482695339713246, 0.1871392605244182, 0.16354378836695105, 0.21831471734913066, 0.17683459940599278, 0.13011787261348218], [0.009540816754451953, 0.039023264034767635, 0.09187894364004023, 0.10385596033302136, 0.027143084626004566, 0.04876851278822869, 0.007854255545680644, 0.006264991288844612, 0.04829619145311881, 0.04153302936174441, 0.08768401326960884, 0.03362912691954989, 18.20494282990694, 53.76666270196438, 46.07890382409096, 25.45483410358429, 20.932081192731857, 33.610055297613144, 57.594410106539726, 56.28766022622585, 51.768444925546646, 47.021108865737915, 52.51500226557255, 2.491434635594487, 1.7920831125229597, 1.3126482325606048, 1.5103055513463914, 0.20391635480336845, 2.3869898775592446, 48.1274650990963, 57.707309648394585, 55.06108604371548, 50.32093919813633, 48.31357531249523, 42.36534409224987, 41.39450378715992, 37.458925768733025, 38.3959136903286, 36.84091553092003, 38.12885642051697, 35.728255435824394, 37.13377721607685, 35.46702325344086, 37.07035481929779, 37.445934265851974, 39.92260716855526, 40.860712230205536, 42.32124745845795, 40.95319926738739, 40.2894052863121, 43.7668114900589, 44.039602652192116, 43.1547175347805, 41.854533702135086, 43.8618253916502, 42.45410352945328, 43.18502090871334, 42.71353840827942, 36.483567506074905, 36.634841188788414, 36.237587705254555, 39.185883700847626, 38.369121327996254, 37.32317805290222, 37.65067107975483, 36.92546099424362, 37.02229879796505, 37.181115075945854, 37.97621101140976, 38.0096910148859, 37.6670216023922, 41.31279677152634, 43.00287388265133, 40.444531962275505, 42.205205485224724, 43.01849864423275, 44.322368279099464, 40.083714723587036, 38.468201011419296, 37.70957171916962, 36.25890836119652, 36.87300480902195, 36.384575217962265, 36.341983303427696, 36.74710236489773, 38.06816607713699, 39.35602717101574, 36.07698172330856, 38.89840632677078, 40.660462975502014, 35.66138282418251, 37.14624434709549, 36.610446497797966, 36.2399435788393, 34.863380044698715, 36.40273064374924, 38.1853973865509, 39.901791885495186, 37.50762015581131, 39.79579657316208, 39.39769193530083, 41.495369374752045, 44.33790944516659, 45.63420608639717, 39.368106722831726, 39.889142364263535, 39.82586055994034, 38.04557628929615, 34.946071207523346, 34.68935698270798, 39.3231513351202, 39.04129005968571, 38.74247409403324, 34.81989897787571, 36.17373213171959, 37.35016040503979, 35.52235208451748, 38.39815557003021, 38.134145736694336, 36.99544943869114, 36.257935613393784, 35.34026585519314, 35.440025702118874, 36.63473479449749, 35.92443510890007, 37.38569609820843, 38.200550973415375, 37.366298139095306, 37.41372339427471, 39.798828810453415, 37.792251482605934, 41.39472037553787, 47.514371797442436, 51.351861879229546, 47.278955429792404, 45.45188046991825, 49.79608476161957, 50.35737544298172, 47.487058863043785, 44.115097001194954, 41.506388783454895, 38.54250982403755, 37.83911816775799, 37.40555763244629, 39.206805378198624, 40.96076086163521, 46.93977043032646, 52.48822130262852, 55.16816809773445, 53.3724794536829, 61.14299029111862, 21.281356550753117, 0.3229586232919246, 1.038280155044049, 6.499417293816805, 4.0940675139427185, 0.17756735149305314, 7.621128028258681, 60.74654996395111, 56.32435105741024, 58.65090921521187, 52.95202061533928, 21.89045436680317, 28.481381200253963, 38.85258838534355, 48.188835605978966, 14.257866628468037, 0.5058494594413787, 0.14114072488155216, 0.16831820248626173, 0.07782452201354317, 0.11428786267060786, 0.05133418038894888, 0.06360986328218132, 0.05969836282019969, 0.013633256530738436, 0.039593103574588895, 0.0561459876189474, 0.023036542188492604, 0.04588969597534742, 0.05422077119874302, 0.03366991535585839, 0.0487298468942754, 0.025317325271316804, 0.07967230645590462, 0.04382542705570813, 0.12692785472609103, 0.091157628048677, 23.649807460606098, 62.16190941631794, 52.10049770772457, 28.056191615760326, 22.693465277552605, 45.23525409400463, 63.07562738656998, 60.91026797890663, 55.865411683917046, 54.07173693180084, 55.8278127014637, 3.257625284604728, 1.9178232341073453, 3.373332400806248, 2.8592791222035885, 0.44355067424476147, 2.6824914710596204, 51.03160746395588, 58.69699314236641, 59.803839549422264, 51.74729526042938, 49.797479286789894, 42.86882467567921, 44.36323508620262, 38.8666932284832, 40.711391642689705, 39.82482701539993, 39.27899390459061, 39.26349833607674, 38.87319087982178, 36.281973123550415, 39.02392499148846, 39.47987772524357, 42.2287642210722, 42.13610239326954, 45.30387841165066, 42.112456262111664, 42.75052182376385, 44.23918314278126, 46.07723951339722, 44.58662509918213, 44.14677210152149, 45.84542915225029, 44.714442640542984, 45.221563428640366, 44.261244758963585, 38.57716016471386, 39.16111662983894, 39.24902491271496, 39.747265577316284, 40.12078173458576, 39.80705916881561, 38.82923863828182, 38.63047510385513, 38.19148845970631, 38.69993917644024, 41.274764612317085, 39.020269587635994, 39.56746302545071, 43.979429081082344, 43.95979553461075, 42.64627441763878, 43.227719217538834, 44.92312364280224, 46.04662835597992, 42.04829290509224, 41.508558467030525, 39.2548082023859, 38.679887652397156, 38.992367684841156, 38.10434393584728, 37.92973190546036, 40.41161432862282, 41.260743364691734, 40.50940588116646, 39.98629555106163, 41.95866331458092, 40.42705290019512, 39.251122400164604, 37.91428193449974, 38.195877224206924, 38.604906275868416, 38.192472606897354, 39.59937371313572, 39.24469314515591, 40.491524040699005, 39.22497220337391, 40.93575060367584, 39.03171457350254, 42.61289320886135, 44.70255687832832, 47.81992860138416, 41.189356595277786, 43.812352046370506, 42.30725280940533, 40.28062775731087, 35.75061723589897, 37.253960967063904, 41.419092267751694, 40.626633390784264, 39.436442255973816, 37.57761999964714, 38.18763926625252, 38.13390634953976, 36.97412118315697, 40.04472881555557, 39.402107298374176, 38.15003648400307, 38.57347056269646, 37.68227398395538, 37.75128588080406, 37.60670363903046, 37.08372250199318, 39.32634696364403, 38.3796201646328, 39.147874340415, 39.786608666181564, 40.65293937921524, 39.90755997598171, 40.864356234669685, 49.34414841234684, 52.53978073596954, 49.545602202415466, 49.18709523975849, 51.719161570072174, 51.2214794754982, 50.49543723464012, 47.10973910987377, 43.101227805018425, 39.97241869568825, 39.50149476528168, 40.66875413060188, 40.275095254182816, 42.79371790587902, 49.71860311925411, 55.01832693815231, 57.07955293357372, 56.688200533390045, 62.494931146502495, 24.301829673349857, 0.211900498252362, 4.123364891856909, 7.093086512759328, 3.2628587912768126, 0.25829639460425824, 7.397538525983691, 66.53777360916138, 62.695093005895615, 64.08885061740875, 59.948391392827034, 30.941631384193897, 32.00831964612007, 45.77731020748615, 55.826068595051765, 20.178689919412136, 0.7398229138925672, 0.028870804417238105, 0.2684034069534391, 0.005833451432408765, 0.07518672879086807, 0.02097954446071526, 0.05174400546820834, 0.06877906285808422, 0.027701216786226723, 0.12321593632805161, 0.1875402280711569, 0.18448393035214394, 0.15274271951057017, 0.21710319095291197, 0.11437057502917014, 0.120137255435111, 0.14653619786258787, 0.17920159036293626, 0.15172280080150813, 0.20725046808365732, 0.20109312114072964, 26.654908508062363, 70.29447242617607, 59.77576665580273, 37.51154914498329, 32.08736300468445, 45.17749719321728, 68.71988251805305, 65.2783539891243, 62.83428333699703, 58.161126896739006, 63.478094190359116, 4.011454721912742, 2.718044025823474, 6.272138664498925, 4.863850632682443, 0.4262354486854747, 3.8811240904033184, 55.69123663008213, 60.28701402246952, 61.442095041275024, 55.462952479720116, 52.334929928183556, 44.61410902440548, 45.64721658825874, 42.155025377869606, 44.91573303937912, 41.67603828012943, 43.47822457551956, 40.742546170949936, 41.51070915162563, 38.57309438288212, 41.44352115690708, 41.63438871502876, 44.482313096523285, 44.15713794529438, 47.01053403317928, 44.5074487477541, 45.524559170007706, 47.53730736672878, 47.7655953168869, 45.833334401249886, 45.253257527947426, 48.42484474182129, 46.68425314128399, 48.25910143554211, 47.35256128013134, 41.71006925404072, 40.961623415350914, 40.927976220846176, 42.07324996590614, 41.29059076309204, 40.91751158237457, 40.376994386315346, 41.797035187482834, 40.88017858564854, 40.486181527376175, 42.5155196338892, 41.39207951724529, 41.93608112633228, 46.551153883337975, 47.77106702327728, 44.626754745841026, 45.63110925257206, 46.96461729705334, 49.28887277841568, 43.610465079545975, 43.423089534044266, 41.28801450133324, 39.373456835746765, 41.40215277671814, 39.975735917687416, 39.680020585656166, 42.53345847129822, 43.18592146039009, 42.66592316329479, 40.874551087617874, 44.688881412148476, 42.4460593611002, 40.96457585692406, 41.207124441862106, 40.119584798812866, 40.64126640558243, 38.893470391631126, 40.74451446533203, 41.83017320930958, 43.759048506617546, 40.86017645895481, 44.58405643701553, 41.20555892586708, 44.44745756685734, 48.18095862865448, 49.528810903429985, 42.96697720885277, 44.40113045275211, 46.17810510098934, 41.217961460351944, 38.81050564348698, 41.327631175518036, 42.64207944273949, 43.685944229364395, 41.50959961116314, 38.5822518914938, 40.46839848160744, 39.870029389858246, 40.07109560072422, 42.94721446931362, 40.73307327926159, 40.00178351998329, 41.41984462738037, 40.21714836359024, 39.403615817427635, 40.412906259298325, 39.613132774829865, 41.421315148472786, 42.143405601382256, 40.93025989830494, 41.389339864254, 43.57776403427124, 42.0122442394495, 44.66555826365948, 51.97921201586723, 55.68470858037472, 52.587935552001, 51.2859658151865, 53.12667064368725, 55.01811034977436, 52.09333889186382, 48.1828623265028, 45.58574728667736, 42.58887089788914, 42.22057566046715, 42.06227235496044, 42.273875400424004, 44.96019825339317, 50.74167162179947, 57.96549439430237, 60.09464934468269, 58.98584604263306, 62.96933948993683, 29.701393134891987, 0.44753134658094496, 3.2083077309653163, 12.205979581922293, 14.173740092664957, 0.4931043792748824, 8.54678163304925, 72.93491274118423, 66.70320153236389, 67.6858440041542, 63.681470677256584, 32.4569995701313, 38.76056872308254, 51.84098303318024, 66.07918381690979, 28.15433654934168, 0.7289533596485853, 0.2315268458914943, 0.31149172922596335, 0.24993099505081773, 0.30842820298857987, 0.0813429179834202, 0.17649570509092882, 0.13593357929494232, 0.1354175343294628], [0.08362294407561421, 0.03953667066525668, 0.03118039581750054, 0.05253522394923493, 0.05137203734193463, 0.05821073893457651, 0.02155211695935577, 0.045763501184410416, 0.07087378209689632, 0.01731385629682336, 0.03454594647337217, 0.05234291122178547, 11.863415613770485, 55.956367403268814, 44.86127056181431, 30.473920181393623, 55.31992435455322, 37.93063625693321, 48.08717966079712, 59.26682196557522, 54.289317056536674, 47.42886498570442, 51.84912219643593, 8.35242111235857, 1.6260022181086242, 1.0761730279773474, 2.307291766628623, 2.4941096920520067, 0.36664541345089674, 43.0776272714138, 62.60282255709171, 50.29948174953461, 48.721791207790375, 42.77542568743229, 38.07334519922733, 37.86774583160877, 37.82478913664818, 37.21351593732834, 38.7874598801136, 37.68918961286545, 36.25377103686333, 38.372696936130524, 37.47049614787102, 38.863311409950256, 40.28122052550316, 43.36202681064606, 42.756058126688, 41.10899090766907, 41.13405816257, 42.269589230418205, 44.287535548210144, 43.305394649505615, 44.67334024608135, 45.23037135601044, 44.551290795207024, 45.7247856259346, 43.113592341542244, 43.65774214267731, 39.45447228848934, 38.71758922934532, 36.02368578314781, 36.904334127902985, 36.23746611177921, 37.782227620482445, 36.49746336042881, 37.54831977188587, 36.34270526468754, 38.62757205963135, 37.937559485435486, 36.05281502008438, 36.238564252853394, 38.25433328747749, 42.17935927212238, 40.802803337574005, 39.808639883995056, 43.363618925213814, 42.8138530254364, 39.98503401875496, 38.97744208574295, 37.58217975497246, 36.94746561348438, 36.36148005723953, 36.56872093677521, 37.44259424507618, 36.66818059980869, 38.102349042892456, 38.52638728916645, 39.527827352285385, 38.58074717223644, 45.37201255559921, 38.143120855093, 36.76230534911156, 36.679158210754395, 37.629255428910255, 37.140829637646675, 36.860780864953995, 36.703932881355286, 35.73536105453968, 36.637938022613525, 38.39287385344505, 40.82885853946209, 40.41058078408241, 42.37792521715164, 44.65773828327656, 41.73940367996693, 37.387356609106064, 40.73852218687534, 39.10301394760609, 35.311938375234604, 34.46417726576328, 40.291533172130585, 40.232415944337845, 37.06236384809017, 35.55824115872383, 36.838544458150864, 37.153091579675674, 38.29246424138546, 37.26702846586704, 40.166086703538895, 38.64799216389656, 37.156735584139824, 34.930317252874374, 37.468581050634384, 37.14846722781658, 38.794158920645714, 38.4544837474823, 41.508524268865585, 38.51507909595966, 39.66231353580952, 36.891874596476555, 43.370059579610825, 48.54512728750706, 50.81509508192539, 46.402460262179375, 47.64028184115887, 53.63517455756664, 50.02662219107151, 51.09919063746929, 50.51880978047848, 48.48720319569111, 47.18538165092468, 43.905074670910835, 39.69273470342159, 38.300770595669746, 41.48452475667, 39.65031757950783, 42.9641767591238, 47.58950136601925, 55.97662411630154, 53.6726139485836, 61.03084310889244, 14.593117889016867, 0.2544455387396738, 3.803948094137013, 6.522528128698468, 5.072581507265568, 0.33612925093621016, 13.632962610572577, 66.2508662045002, 53.37135471403599, 59.012573808431625, 50.5183120071888, 31.919313222169876, 26.325059607625008, 36.003752052783966, 41.14737264811993, 3.9766526268795133, 0.5095257028006017, 0.07873305177781731, 0.13123955461196601, 0.01158922876129509, 0.07934715671581216, 0.08091475072433241, 0.09498864630586468, 0.05780927043815609, 0.10330522738513537, 0.04161497359746136, 0.05609735097095836, 0.044040267675882205, 0.021765118908660952, 0.04318066028645262, 0.06470106527558528, 0.05543424573261291, 0.03539166827977169, 0.05931314364715945, 0.07936127978609875, 0.0581857322686119, 0.15386272425530478, 15.745306313037872, 63.51403646171093, 48.431118205189705, 31.82030003517866, 40.50018757581711, 36.40551969408989, 56.70183800160885, 66.92326292395592, 59.88076262176037, 52.05365762114525, 57.06258684396744, 8.679878041148186, 1.7697367491200566, 0.7988354098051786, 7.180644739419222, 2.169529921375215, 0.7344602735247463, 45.452423840761185, 63.39549042284489, 53.55450488626957, 49.880041256546974, 46.48727171123028, 41.367487236857414, 39.31866377592087, 38.720241487026215, 40.53455673158169, 39.99259561300278, 40.24190403521061, 39.00274112820625, 39.51476365327835, 39.16139021515846, 41.003797352313995, 43.95499639213085, 43.80289055407047, 43.81281942129135, 44.22773435711861, 44.09402713179588, 44.39736105501652, 46.707264706492424, 45.89183986186981, 46.50541193783283, 47.615351378917694, 46.612999364733696, 46.97673484683037, 45.65383963286877, 46.733445301651955, 42.1131706237793, 38.89343619346619, 38.67809794843197, 39.06108699738979, 38.325131088495255, 38.86012718081474, 40.03767639398575, 39.36708837747574, 39.53855037689209, 41.50695115327835, 40.855001136660576, 38.565563187003136, 40.042912513017654, 40.274931862950325, 45.182433128356934, 42.150051444768906, 42.131485641002655, 46.817971765995026, 43.92178997397423, 41.74964793026447, 39.838137701153755, 40.281516909599304, 40.23693010210991, 38.12968857586384, 37.166873440146446, 38.83535251021385, 37.97577403485775, 38.173891603946686, 41.15932300686836, 40.52206680178642, 41.21788166463375, 43.918742537498474, 40.4024264216423, 39.73485164344311, 37.932756543159485, 38.89580346643925, 39.55594964325428, 37.733263447880745, 37.79661364853382, 38.60296458005905, 39.353827089071274, 39.565730318427086, 42.18010023236275, 40.13731084764004, 43.84971924126148, 46.98031805455685, 44.795366898179054, 39.60230715572834, 44.75438229739666, 41.12494245171547, 37.809479758143425, 36.52980722486973, 40.52986018359661, 40.85323803126812, 39.79123681783676, 37.40973360836506, 38.71281288564205, 37.77692690491676, 38.596501126885414, 39.471453577280045, 40.49341253936291, 40.07972493767738, 38.861859887838364, 38.72247576713562, 37.79182590544224, 39.57604296505451, 41.94608598947525, 40.00665105879307, 42.22977876663208, 40.80705150961876, 40.47747999429703, 37.68054127693176, 44.41864371299744, 51.24418705701828, 51.522936299443245, 48.97584177553654, 48.88309635221958, 54.64779742062092, 52.12600953876972, 53.13489340245724, 51.82021714746952, 51.026185154914856, 50.32720506191254, 45.11394180357456, 41.686100140213966, 39.51494984328747, 42.043546959757805, 41.29880212247372, 45.08752942085266, 51.128118485212326, 56.68993704020977, 55.379060581326485, 62.859145402908325, 18.21748025715351, 0.31896349391900003, 8.16821364685893, 6.982483472675085, 3.2353805657476187, 0.5191945214755833, 14.386624619364738, 69.99063313007355, 58.4886921197176, 62.21107877790928, 57.673130482435226, 31.32478192448616, 26.732395850121975, 42.95086607336998, 50.08255518972874, 7.886972213163972, 0.6420813524164259, 0.06219004200829659, 0.13640383374877274, 0.03817816192167811, 0.16144083871040493, 0.0300271539890673, 0.11421297997003421, 0.05621842123218812, 0.07617702096467838, 0.2275019118678756, 0.17746943252859637, 0.12156528857303783, 0.1465787526103668, 0.19346986926393583, 0.19839626038447022, 0.13758229004452005, 0.16189059504540637, 0.21213293890468776, 0.12165691412519664, 0.2797824307344854, 0.21100477053551003, 18.95795602351427, 73.83598119020462, 57.68717832863331, 43.816235437989235, 62.86471590399742, 50.42835183441639, 58.39186571538448, 69.45818290114403, 66.71609804034233, 57.63934649527073, 61.99853718280792, 11.764659862965345, 4.2967780865728855, 3.8837993843480945, 14.564069397747517, 4.851070968434215, 1.9820902543142438, 49.31086979806423, 65.04105672240257, 54.37720254063606, 53.24390955269337, 47.430153116583824, 42.053639218211174, 42.21786640584469, 40.81129588186741, 43.4247500449419, 42.45722696185112, 41.649169921875, 39.58939924836159, 41.31222680211067, 41.79473251104355, 42.59872756898403, 47.17882700264454, 48.098092675209045, 47.28033475577831, 45.61913229525089, 46.47416241466999, 47.10402421653271, 49.59546312689781, 49.8413061350584, 49.25048343837261, 49.39249321818352, 49.14533548057079, 49.99232903122902, 46.950827836990356, 49.61497128009796, 44.163928180933, 42.766974940896034, 41.60969004034996, 41.14302948117256, 39.29178401827812, 41.8806117027998, 41.50460287928581, 42.101585045456886, 40.74520982801914, 42.41552419960499, 41.89864553511143, 41.05849541723728, 42.216414883732796, 42.472631335258484, 47.35300585627556, 44.01698626577854, 43.09005260467529, 47.64668069779873, 45.56916117668152, 42.433117255568504, 43.453712090849876, 41.54570147395134, 43.24431672692299, 39.6404343098402, 39.12010543048382, 41.59410707652569, 39.89397190511227, 40.43546564877033, 43.61007370054722, 44.39360685646534, 43.79089839756489, 47.2066605091095, 41.869212314486504, 41.65282912552357, 41.1418591439724, 41.19340717792511, 42.48969241976738, 41.18915520608425, 38.92017535865307, 40.43760493397713, 41.202089712023735, 41.38469651341438, 43.69180731475353, 41.59889481961727, 46.17598481476307, 49.96775574982166, 46.68049894273281, 43.50579209625721, 48.05606313049793, 42.63436585664749, 40.30470326542854, 38.85839067399502, 43.247941732406616, 44.7612751275301, 41.69597961008549, 39.84060376882553, 40.89639611542225, 39.98023487627506, 40.672553926706314, 41.48870453238487, 44.451511949300766, 42.07024432718754, 39.659919664263725, 40.23046664893627, 40.15110410749912, 41.09935462474823, 43.270166739821434, 41.973102539777756, 45.65896935760975, 42.36397996544838, 42.530832812190056, 39.77115109562874, 46.9955438375473, 53.76988872885704, 53.51303391158581, 51.11846700310707, 52.50819303095341, 55.950150936841965, 51.81244656443596, 55.05635529756546, 54.25588645040989, 53.52610141038895, 53.22033181786537, 48.55360843241215, 43.961722031235695, 41.67913131415844, 45.823918506503105, 43.577870428562164, 49.38474923372269, 53.07509981095791, 59.63867001235485, 57.128125727176666, 64.67651188373566, 20.663143023848534, 0.25656882324256003, 10.882363356649876, 14.89812372252345, 9.730584360659122, 0.5587914248462766, 16.89700361341238, 76.06263890862465, 63.805332630872726, 67.71036028862, 64.1179570555687, 42.288728803396225, 37.08250276744366, 50.079602748155594, 59.62392680346966, 11.550775039941072, 0.638664742000401, 0.1767188688972965, 0.1743635890306905, 0.13194321451010182, 0.1999535979120992, 0.12877305649453774, 0.15087041450897232, 0.14089808712014928, 0.2303292867145501], [0.0384792029944947, 0.05010010383557528, 0.003768609899452713, 0.01629077047255123, 0.04955347867507953, 0.015167090241448022, 0.04170781256107148, 0.01664330546191195, 0.016940862151386682, 0.09146046882960945, 0.17604498396394774, 0.06293385580647737, 11.249836888164282, 59.70322094857693, 46.237328723073006, 45.493009462952614, 84.81166183948517, 66.69207572937012, 31.27937626093626, 46.45917221903801, 55.685358345508575, 48.04435595870018, 55.886154770851135, 17.508026026189327, 1.4119424857199192, 2.3370052222162485, 2.0919563714414835, 1.9653301849029958, 0.4835602710954845, 44.17728066444397, 58.20756420493126, 54.38772797584534, 46.122799068689346, 39.84416037797928, 37.85098113119602, 40.447465404868126, 41.8379095941782, 41.89131572842598, 41.00729316473007, 39.32794287800789, 35.40623411536217, 36.98825262486935, 41.43226996064186, 44.83304187655449, 43.847595155239105, 45.73599502444267, 41.92030817270279, 43.43046873807907, 41.570411548018456, 44.52562317252159, 43.306697979569435, 43.74698035418987, 45.44325493276119, 44.28598143160343, 44.41628783941269, 45.86810253560543, 44.99871298670769, 44.48025740683079, 41.81831784546375, 38.13710197806358, 36.710810512304306, 37.83469520509243, 36.71718657016754, 37.6445572078228, 36.493420377373695, 37.82496392726898, 37.639237493276596, 38.684644997119904, 39.528693705797195, 35.972897708415985, 36.272789016366005, 40.302449986338615, 41.176099106669426, 40.648862197995186, 41.704905331134796, 42.442593947052956, 43.40414755046368, 39.6615269780159, 36.7449364811182, 38.19160245358944, 39.77672919631004, 36.24261103570461, 36.92756228148937, 35.657579228281975, 37.83918656408787, 40.30710093677044, 40.130877792835236, 42.24695764482021, 38.42029698193073, 43.57595533132553, 44.2460797727108, 38.425992876291275, 36.990505903959274, 35.91307371854782, 36.19551636278629, 37.33107402920723, 37.348701283335686, 37.418374344706535, 37.34885707497597, 38.64633545279503, 41.44407972693443, 40.52291415631771, 42.89386913180351, 42.899994403123856, 42.43951231241226, 36.43852852284908, 38.931988924741745, 39.647057354450226, 35.91647833585739, 35.38744032382965, 36.063906624913216, 40.15141949057579, 38.69734771549702, 37.10570812225342, 34.17869858443737, 36.30346097052097, 37.61681109666824, 35.62678188085556, 38.829052448272705, 36.820803210139275, 37.2540445625782, 35.515573248267174, 34.605609476566315, 35.745525509119034, 37.66572207212448, 40.60038819909096, 42.04453490674496, 40.689113438129425, 42.06894479691982, 42.21004642546177, 47.69269622862339, 49.47632811963558, 51.61278247833252, 44.410094171762466, 51.981313303112984, 48.685655146837234, 48.720077499747276, 50.989182740449905, 52.67319157719612, 52.06962816417217, 50.3483547270298, 48.76212604343891, 42.20918387174606, 37.36955836415291, 40.303616523742676, 40.524665862321854, 41.17123916745186, 50.51962673664093, 55.44126704335213, 53.642937541007996, 59.381032437086105, 16.998108588159084, 0.19195290456991643, 8.887652792036533, 5.121804066002369, 1.7369892750866711, 0.267199584050104, 26.660182625055313, 66.52983203530312, 54.50347736477852, 59.95858624577522, 43.86641934514046, 30.405141972005367, 25.237835347652435, 43.19154895842075, 40.70228733122349, 3.142665303312242, 0.47002023202367127, 0.02738016555667855, 0.11676593087031506, 0.016681284869264346, 0.061474103276850656, 0.03817608019744512, 0.03568853106116876, 0.07200809544883668, 0.011795643222285435, 0.04222216914058663, 0.05668105754011776, 0.04038789920741692, 0.05600811884505674, 0.0539593756548129, 0.022575803923245985, 0.011508758616400883, 0.05294045513437595, 0.05191844356886577, 0.0756827877194155, 0.19612481351941824, 0.019147844213875942, 14.716707207262516, 67.56806552410126, 50.639229118824005, 48.10898669064045, 73.9619368314743, 60.56007117033005, 39.133720099925995, 53.42889882624149, 59.826417937874794, 52.41213038563728, 59.40954230725765, 19.12600200623274, 1.0407409979961812, 0.40900960739236325, 4.623728692531586, 4.139576721936464, 0.9069575392641127, 45.87882936000824, 60.518607795238495, 57.71217338740826, 48.099095821380615, 42.321049869060516, 39.20707896351814, 41.61960370838642, 42.9029506444931, 44.41773936152458, 43.42033468186855, 40.70903576910496, 38.454590141773224, 38.22941802442074, 43.602249920368195, 45.89821211993694, 46.76939137279987, 46.172344610095024, 44.46753188967705, 45.20678982138634, 44.04591791331768, 46.23290956020355, 44.84876923263073, 46.21226906776428, 46.73589617013931, 45.77729880809784, 47.10946552455425, 47.59161025285721, 48.05947534739971, 46.45260237157345, 45.06463184952736, 38.72893922030926, 38.22742313146591, 39.136634543538094, 37.574811950325966, 39.80575583875179, 38.91587778925896, 38.365348130464554, 38.311607614159584, 40.653817132115364, 41.05735167860985, 38.13795693218708, 39.56476517021656, 42.85722389817238, 44.06363636255264, 43.767708241939545, 43.77159923315048, 43.26149180531502, 44.29694764316082, 39.96221624314785, 39.658726528286934, 40.85916951298714, 41.982518434524536, 38.55118855834007, 36.96245580911636, 38.05924795567989, 38.91404248774052, 41.35120131075382, 41.72054149210453, 42.30761758983135, 41.42795719206333, 44.12906885147095, 44.61064361035824, 40.89195415377617, 39.399534836411476, 37.677687630057335, 38.64534370601177, 39.63799104094505, 39.29127484560013, 39.456216394901276, 38.74791160225868, 40.24595081806183, 41.8415991961956, 42.05731742084026, 43.26675832271576, 45.426775217056274, 43.27641740441322, 40.33343732357025, 42.9664072394371, 41.733244210481644, 38.526220098137856, 37.050816267728806, 37.6424141228199, 41.86345562338829, 40.383647829294205, 39.17525567114353, 36.657541170716286, 38.65163616836071, 39.49541509151459, 38.96497495472431, 42.01623022556305, 38.99316944181919, 38.45026597380638, 37.44821794331074, 37.97583483159542, 36.69283747673035, 39.95511442422867, 42.48032212257385, 44.91308078169823, 43.598100543022156, 43.293501287698746, 43.90308737754822, 49.2051100730896, 50.87407931685448, 52.44543939828873, 48.75346630811691, 52.14938588440418, 50.94996504485607, 50.93784749507904, 52.70742014050484, 53.799014165997505, 53.36631238460541, 54.202313125133514, 50.559573993086815, 43.391156047582626, 41.27728387713432, 41.45609848201275, 43.2181741297245, 43.00376683473587, 52.10425190627575, 56.91346384584904, 56.537113040685654, 61.42253749072552, 20.040888413786888, 0.1583950052736327, 6.6593720857053995, 7.333599831908941, 1.907368570100516, 0.3985834418563172, 27.55055844783783, 71.13005518913269, 58.02645072340965, 65.2573411166668, 51.00566245615482, 30.46390201896429, 28.745343536138535, 47.94445551931858, 48.18482682108879, 5.169618325307965, 0.37214211537502706, 0.017644032232055906, 0.1277313186437823, 0.04755820722493809, 0.07784430024912581, 0.02656199227203615, 0.07591020403197035, 0.06116863158240449, 0.03868602841976099, 0.17508549091871828, 0.15047581458929926, 0.054456922589452006, 0.1321661111433059, 0.1130667031975463, 0.05443012363684829, 0.13520483480533585, 0.08082823114818893, 0.13665476872120053, 0.17944544524652883, 0.27771801338531077, 0.21644932916387916, 16.026470325887203, 76.367526948452, 59.085590690374374, 58.62656772136688, 84.92730483412743, 71.44560545682907, 45.06353750824928, 58.34353610873222, 65.29269441962242, 59.2948492616415, 65.7124350965023, 23.511291593313217, 2.0491918036714196, 6.001723324880004, 5.64590091817081, 5.489617204293609, 1.662518021184951, 47.89086699485779, 59.356379359960556, 61.05614975094795, 50.63088856637478, 44.68483842909336, 40.97727857530117, 44.139708280563354, 45.98759092390537, 45.88047847151756, 45.34609414637089, 43.2839410007, 39.69324007630348, 40.999097004532814, 45.88557779788971, 48.427003026008606, 48.77818018198013, 49.09181535243988, 46.6394117474556, 48.115773126482964, 45.970081463456154, 49.62502174079418, 46.34420558810234, 48.48127171397209, 48.37439864873886, 48.01500253379345, 48.30889396369457, 49.820255264639854, 50.86244434118271, 50.470571368932724, 48.26670862734318, 43.200254291296005, 40.596124827861786, 40.86705408990383, 39.28809441626072, 41.21165379881859, 41.96176774799824, 41.21169179677963, 41.23854115605354, 42.81595431268215, 44.89802598953247, 39.71915848553181, 41.578858494758606, 44.98305782675743, 46.71210564672947, 46.10616356134415, 46.40307582914829, 46.076783537864685, 48.174179792404175, 44.13044437766075, 41.332988888025284, 42.5359283387661, 46.12146534025669, 40.26016965508461, 41.18661694228649, 39.173895344138145, 42.92899064719677, 44.705680310726166, 44.39693547785282, 44.729372039437294, 43.748295083642006, 47.125607058405876, 44.6922442317009, 43.91806237399578, 41.77692286670208, 39.84853774309158, 39.68495272099972, 43.3297361433506, 41.43977455794811, 41.07614926993847, 41.03855028748512, 41.774981170892715, 43.50302964448929, 44.088669419288635, 45.03253877162933, 46.44985891878605, 46.742602810263634, 42.96025536954403, 45.24400882422924, 43.45649354159832, 40.635380521416664, 41.31022810935974, 39.34815399348736, 43.806941136717796, 42.0019505918026, 39.963945150375366, 36.16118520498276, 39.73547101020813, 41.93116419017315, 40.39340190589428, 43.200691267848015, 41.608895882964134, 41.67709842324257, 39.63062323629856, 39.58861269056797, 39.092028737068176, 42.20153488218784, 44.94496487081051, 46.879156082868576, 44.65423487126827, 46.30093351006508, 46.04348212480545, 52.492344081401825, 55.1385372877121, 56.007786244153976, 50.132666900753975, 54.17017064988613, 51.520002856850624, 52.490516379475594, 55.73026813566685, 56.38885259628296, 54.95591148734093, 56.021359115839005, 54.437463507056236, 45.79985819756985, 42.525900676846504, 44.77558895945549, 45.524635165929794, 46.76385886967182, 54.93365228176117, 60.20073585212231, 58.75732250511646, 61.49149999022484, 21.450424678623676, 0.2109787953668274, 16.488571129739285, 14.382614884525537, 5.908290138468146, 0.6840175646357238, 31.163685768842697, 75.89363157749176, 64.4416768848896, 67.36267894506454, 58.43996733427048, 41.56305514276028, 37.11460344493389, 56.39492467045784, 55.93536213040352, 6.852778382599354, 0.6869827711489052, 0.08240660856245086, 0.27109090180601925, 0.17928803572431207, 0.12039394947350956, 0.18101064953953028, 0.09505563255515881, 0.21295152779202908, 0.09419857815373689], [0.017951247973542195, 0.04129534543608315, 0.06435838600737043, 0.04357393176178448, 0.019965917308581993, 0.09781140499399044, 0.03543926592101343, 0.003245752482143871, 0.020281250290281605, 0.036801155147259124, 0.10063775567687117, 0.060838253411930054, 3.419025423936546, 47.33882121741772, 45.034598261117935, 35.83180747926235, 75.85517764091492, 72.19025149941444, 41.87657251954079, 48.08635510504246, 59.525078907608986, 49.47655990719795, 55.54286599159241, 26.864944137632847, 0.21290800825227052, 0.48214324400760233, 6.949663683772087, 1.7636887799017131, 0.9251671121455729, 45.164262503385544, 57.885991260409355, 53.831616416573524, 45.83119511604309, 41.460631638765335, 41.0616834461689, 43.6797733604908, 45.49054339528084, 45.458898693323135, 44.3007892370224, 38.91150802373886, 35.80645523965359, 41.908205822110176, 46.840344965457916, 45.18817462027073, 45.73529966175556, 46.62308782339096, 45.66243477165699, 47.309885770082474, 46.880098432302475, 47.621621042490005, 47.165086939930916, 46.999662816524506, 47.90998376905918, 47.70567253232002, 47.91751116514206, 48.25448848307133, 46.4919226616621, 46.44267350435257, 43.70096482336521, 38.56778606772423, 37.21157044172287, 38.537547290325165, 37.4706519395113, 36.6618425399065, 37.037885561585426, 38.170726373791695, 35.89407853782177, 39.816725850105286, 39.208325296640396, 38.557192236185074, 37.970503717660904, 41.28620579838753, 39.01730954647064, 39.5251788944006, 41.21563978493214, 43.45024287700653, 40.19289806485176, 37.272895351052284, 35.752129554748535, 36.1283815652132, 36.680890917778015, 35.7237184792757, 36.23972699046135, 36.13332509994507, 37.54224769771099, 39.40278746187687, 40.67079462110996, 45.443513318896294, 41.59899741411209, 38.75192418694496, 47.782234624028206, 42.062257155776024, 38.97713050246239, 37.01475240290165, 37.17370927333832, 35.39264224469662, 36.04068607091904, 36.60110279917717, 35.96325382590294, 37.83812262117863, 38.11839558184147, 39.98220697045326, 40.40802352130413, 42.06672951579094, 41.36054880917072, 36.81959867477417, 40.2797120064497, 42.28680230677128, 38.283850103616714, 36.892250776290894, 36.78056336939335, 38.59515219926834, 38.41141685843468, 38.24569635093212, 37.158160507678986, 36.45607218146324, 37.2050803899765, 37.18396112322807, 35.879179537296295, 37.62480206787586, 35.5216871201992, 34.564697071909904, 33.34395557641983, 36.4627256244421, 39.09810461103916, 42.65449337661266, 45.329002663493156, 44.45135995745659, 46.2040501087904, 49.189276322722435, 50.25329142808914, 51.4434027671814, 49.052932038903236, 46.76613874733448, 50.833911672234535, 50.48582375049591, 50.3695347905159, 50.80226317048073, 52.01977863907814, 54.22539308667183, 52.786965072155, 50.93268737196922, 50.876606181263924, 42.147855162620544, 38.25427249073982, 38.88774409890175, 43.50107654929161, 51.86846695840359, 53.92845422029495, 55.27480557560921, 53.29293072223663, 20.187266059219837, 0.6117929995525628, 4.336413284763694, 4.929150603711605, 1.529380171559751, 0.7351200131233782, 38.444858863949776, 60.87154045701027, 54.38237406313419, 57.19391539692879, 37.20496639609337, 27.86102268844843, 25.978630296885967, 42.20344237983227, 30.615213699638844, 0.5996567476540804, 0.13584380911197513, 0.06969580077566206, 0.005029593248764286, 0.06795410634367727, 0.10214257883490063, 0.08902210553060286, 0.061930412775836885, 0.053410160398925655, 0.05196245292609092, 0.020662740171246696, 0.03705758943397086, 0.040599285130156204, 0.022767647242289968, 0.03440050779317971, 0.03141372333629988, 0.03255923198594246, 0.009796434678719379, 0.08640570842544548, 0.028534633784147445, 0.051872512049158104, 0.036159857918391936, 5.733543215319514, 58.80643106997013, 49.720989391207695, 44.751581847667694, 83.29596877098083, 72.22606837749481, 42.232013046741486, 51.396152302622795, 64.56422790884972, 53.79615671932697, 59.853404089808464, 29.06393364071846, 0.21591302356682718, 0.2443712402600795, 9.199694897979498, 3.024407336488366, 1.421005711890757, 47.86920055747032, 60.03614008426666, 55.58463715016842, 48.510180562734604, 42.202796414494514, 41.84482902288437, 46.944155395030975, 45.98972640931606, 47.64881618320942, 44.46847803890705, 41.334919184446335, 37.28920787572861, 43.784902319312096, 49.21199910342693, 46.14827290177345, 47.5218041986227, 46.473436653614044, 47.551476806402206, 49.49778936803341, 49.004241451621056, 48.97748328745365, 47.942582219839096, 48.23900431394577, 49.83445130288601, 49.71772536635399, 47.96718969941139, 49.496182054281235, 48.5148087143898, 47.980260998010635, 45.079359859228134, 39.35255415737629, 39.13730710744858, 39.90376777946949, 39.277827367186546, 38.81823442876339, 38.55271227657795, 39.560592994093895, 38.803198635578156, 41.604282930493355, 41.62563018500805, 39.88321088254452, 38.82786311209202, 42.77786135673523, 42.322968766093254, 41.777029260993004, 43.725963681936264, 44.88504208624363, 42.72476680576801, 40.12721098959446, 39.61541645228863, 39.925707802176476, 39.32054467499256, 37.754933685064316, 37.469652593135834, 40.19732102751732, 38.55056919157505, 40.2336660772562, 43.76820221543312, 45.73605962097645, 43.66567611694336, 42.358470261096954, 47.569647431373596, 43.7953707575798, 41.34974978864193, 39.09921035170555, 38.854777067899704, 39.080021381378174, 37.93740749359131, 38.92188526690006, 38.52984130382538, 38.629954531788826, 39.666394516825676, 41.95071794092655, 42.358272671699524, 44.874653443694115, 44.21471245586872, 40.28745599091053, 43.049501180648804, 44.47367995977402, 39.47197414934635, 38.8511710613966, 38.70799094438553, 39.61421571671963, 39.88566555082798, 38.85104186832905, 38.19275379180908, 37.564005330204964, 38.79235781729221, 38.204092383384705, 38.25037769973278, 38.93185593187809, 37.859637066721916, 36.98166377842426, 36.87672860920429, 38.488009348511696, 40.96159681677818, 44.97348994016647, 48.52813459932804, 45.854419469833374, 48.987510949373245, 50.93342833220959, 52.53775544464588, 51.90807983279228, 52.14158870279789, 48.99428978562355, 54.81276176869869, 52.82748609781265, 53.37250605225563, 53.91529932618141, 53.82177874445915, 55.05454659461975, 54.247291311621666, 54.40402910113335, 52.24779300391674, 43.68964143097401, 42.09753826260567, 39.94419761002064, 44.47800412774086, 52.54646077752113, 56.386739909648895, 56.02308042347431, 56.3165120780468, 21.771150268614292, 0.4474298207787797, 7.445141421630979, 6.005330756306648, 1.9621232757344842, 0.8738927822560072, 43.829485327005386, 66.82963594794273, 59.7861211001873, 60.363405123353004, 44.81415309011936, 33.82540114223957, 28.401821069419384, 49.12385143339634, 38.32706518471241, 1.380221787840128, 0.16204684681724757, 0.05513097079528961, 0.09893638954963535, 0.025795947440201417, 0.11142813018523157, 0.02846966246579541, 0.012650024036702234, 0.02234065999800805, 0.05743890164012555, 0.16768411151133478, 0.12245948004419915, 0.1547507187933661, 0.12553488806588575, 0.17031781550031155, 0.19776513800024986, 0.17272391763981432, 0.1089132514607627, 0.14667603332782164, 0.19496673659887165, 0.24675348977325484, 0.2358664505300112, 6.093003451824188, 64.62658256292343, 56.61955341696739, 48.161127492785454, 79.61883008480072, 78.96480157971382, 52.0296923071146, 59.71539169549942, 71.1099922657013, 60.3246396034956, 66.29067286849022, 33.87478329241276, 0.458466803538613, 2.6913782441988587, 18.104181736707687, 5.52071426063776, 1.8718899926170707, 50.33157482743263, 61.83645687997341, 60.589815974235535, 49.76330392062664, 46.19588054716587, 46.8890393525362, 49.107956886291504, 47.985576912760735, 51.47402532398701, 46.8749725073576, 43.02681639790535, 39.83862787485123, 46.047817692160606, 51.8117967993021, 49.42186564207077, 49.186962246894836, 49.41459283232689, 50.60193412005901, 52.735356241464615, 51.821892857551575, 53.62803474068642, 51.276751309633255, 52.564821392297745, 54.29207190871239, 52.621829733252525, 52.34668269753456, 53.814688324928284, 51.77446760237217, 49.79709170758724, 47.41681583225727, 42.08159051835537, 41.834808960556984, 42.69941456615925, 39.81392540037632, 41.301716566085815, 40.550933852791786, 40.31537689268589, 40.5518040060997, 43.769482746720314, 44.805725142359734, 40.80366209149361, 42.01065592467785, 45.50053305923939, 42.58683420717716, 43.270254135131836, 47.046989277005196, 48.479440212249756, 44.13670264184475, 40.449806079268456, 41.34708993136883, 41.74604572355747, 40.33422768115997, 40.01553118228912, 40.10819301009178, 43.03168773651123, 41.15308754146099, 44.2111786454916, 47.07387663424015, 50.20616635680199, 45.17742119729519, 46.81816555559635, 49.14048694074154, 45.65271869301796, 43.30677017569542, 41.14405922591686, 40.789150670170784, 40.28681002557278, 40.190405398607254, 39.91701006889343, 41.01904213428497, 41.37337692081928, 42.48535305261612, 43.20982977747917, 43.771755024790764, 45.71882374584675, 45.829287618398666, 41.82262681424618, 46.15758240222931, 46.09329365193844, 41.93340606987476, 41.4062375575304, 41.554186418652534, 41.58280648291111, 40.935222432017326, 42.493830397725105, 40.3221595287323, 40.5392836779356, 40.34563086926937, 40.86345188319683, 39.997387155890465, 42.044823691248894, 40.26902697980404, 40.676163733005524, 37.20182776451111, 41.42285406589508, 44.08253654837608, 47.124508917331696, 51.714043244719505, 48.60436610877514, 49.68895711004734, 54.109031930565834, 53.519858345389366, 56.61378152668476, 55.027659237384796, 50.734345614910126, 55.50430566072464, 54.98630225658417, 54.569590017199516, 54.80724446475506, 54.82959866523743, 57.817062959074974, 55.33185571432114, 56.548459231853485, 54.43931020796299, 46.07169181108475, 44.41925548017025, 43.22207272052765, 47.604958936572075, 57.16493435204029, 58.46976153552532, 57.84913703799248, 56.66999951004982, 25.6796832382679, 0.5881853413302451, 12.1509756334126, 18.334789462387562, 5.239664716646075, 0.7779256661888212, 47.55857862532139, 70.61638355255127, 65.92187985777855, 64.58799943327904, 50.3122528642416, 40.17041087150574, 36.13336689770222, 56.945602521300316, 44.82341319322586, 1.9343042559921741, 0.2879078494152054, 0.1643343092291616, 0.19366370339412242, 0.16549378138734028, 0.2120512878173031, 0.1989012473495677, 0.12022629831335507, 0.21552496938966215, 0.1916635560337454], [0.009629430114728166, 0.03102058544754982, 0.025562551272741985, 0.06471479500760324, 0.02633349984535016, 0.042379003498353995, 0.041232229486922733, 0.06395548887667246, 0.021159830685064662, 0.10146183645701967, 0.020936564833391458, 0.18415760801872239, 0.6473087437916547, 31.11255381256342, 54.84522722661495, 29.588788077235222, 31.659177280962467, 42.42603063583374, 39.46311302483082, 56.222223937511444, 56.15031659603119, 50.50517611205578, 49.5356847345829, 42.459134459495544, 0.44221181015018374, 0.04715283132100012, 3.233369286172092, 3.608366888947785, 0.9745435032527894, 33.83249916136265, 63.28143194317818, 51.173678040504456, 49.05513592064381, 39.851171001791954, 46.37647345662117, 48.3226378262043, 51.85473449528217, 47.8210723400116, 43.85172553360462, 35.98694175481796, 39.02831755578518, 48.471764624118805, 48.811770379543304, 49.49140951037407, 50.55010870099068, 48.64589788019657, 50.007057040929794, 49.381918385624886, 48.11097398400307, 48.67365159094334, 47.83288590610027, 47.32889614999294, 48.95409174263477, 48.40195097029209, 51.404838636517525, 50.4547718167305, 50.20870842039585, 46.74736015498638, 44.295845702290535, 39.46715600788593, 36.31355322897434, 35.770129188895226, 38.23844254016876, 37.49101884663105, 36.524084731936455, 38.98953303694725, 39.990931302309036, 40.13376943767071, 40.735102370381355, 38.423823192715645, 39.02542971074581, 39.877188205718994, 41.266051679849625, 39.28776003420353, 40.1435387134552, 40.8942986279726, 40.69060295820236, 38.61404478549957, 38.441222459077835, 37.44522750377655, 38.86193208396435, 36.476097106933594, 36.72345623373985, 38.70701439678669, 41.562891751527786, 41.535005047917366, 44.36155937612057, 44.13531191647053, 45.93913592398167, 38.45539189875126, 45.323606953024864, 45.76322056353092, 41.89513832330704, 39.20045591890812, 40.56417994201183, 38.8867561519146, 36.0510329157114, 37.16169051826, 37.75239922106266, 37.858367934823036, 38.28800328075886, 39.65478613972664, 41.68293870985508, 41.26780718564987, 40.37628002464771, 37.77299031615257, 37.87810407578945, 44.41047415137291, 37.51902714371681, 36.17496706545353, 37.004268765449524, 37.38385699689388, 36.99144825339317, 37.49453745782375, 36.73789165914059, 35.83659902215004, 37.28743337094784, 37.27594278752804, 36.254257410764694, 35.66607937216759, 34.62496943771839, 35.03978557884693, 34.378959238529205, 36.13878160715103, 39.59607549011707, 41.84523940086365, 43.98476779460907, 47.122913002967834, 50.536300241947174, 51.03769093751907, 51.3754016160965, 49.40217509865761, 46.556162014603615, 50.05162864923477, 50.850144401192665, 53.110297322273254, 50.21033093333244, 48.26659843325615, 52.53975033760071, 49.81610208749771, 53.95076662302017, 50.23703970015049, 54.79131571948528, 46.089911833405495, 41.38667620718479, 36.042228788137436, 43.29583816230297, 50.76231591403484, 58.579081669449806, 52.28975035250187, 56.95159859955311, 12.328406162559986, 0.17829269694630057, 3.030235036276281, 4.232452288269997, 0.47930856642778963, 1.5152108506299555, 47.48427361249924, 56.84379458427429, 54.26578871905804, 54.67595770955086, 29.047319032251835, 19.97146613895893, 28.234417252242565, 47.375614643096924, 17.195443399250507, 0.4095032543409616, 0.02554548002080992, 0.10111382114700973, 0.020148602525296155, 0.08740266508539207, 0.026414009880681988, 0.07580101926578209, 0.021009406627854332, 0.048195600757026114, 0.04370246060716454, 0.017938956152647734, 0.005997403450237471, 0.07151256344513968, 0.06878384971059859, 0.0649284890096169, 0.007820501741662156, 0.02191225896240212, 0.12184468490886502, 0.05667446355801076, 0.0779316139232833, 0.044657411708612926, 0.14809221436735243, 1.4767134538851678, 39.86881725490093, 59.787838608026505, 33.55113945901394, 49.18525233864784, 62.488688081502914, 47.2160080075264, 57.75601163506508, 58.9460963755846, 55.45863591134548, 56.559349447488785, 44.644761979579926, 0.3753204963868484, 0.10958476152154617, 7.6794021762907505, 6.104340143501759, 1.091912614647299, 34.64784421026707, 65.69101184606552, 53.85453298687935, 51.10666863620281, 40.9332275390625, 46.52234382927418, 51.493069902062416, 54.240755662322044, 49.53228771686554, 46.241204515099525, 39.77435052394867, 42.544329687952995, 48.730914518237114, 51.297691985964775, 52.25391827523708, 51.490007266402245, 49.51173461973667, 51.70509472489357, 52.1448565274477, 50.60384541749954, 49.459411427378654, 50.14419928193092, 48.24321448802948, 51.642595678567886, 51.59074366092682, 51.628703624010086, 50.779031217098236, 52.61088252067566, 49.87615026533604, 46.39606140553951, 41.491132602095604, 39.02484834194183, 39.27807055413723, 40.28549909591675, 39.201044887304306, 39.79793205857277, 39.16973076760769, 40.42085163295269, 40.384255796670914, 41.16300880908966, 39.19642053544521, 39.37006361782551, 44.252395033836365, 43.61639656126499, 40.89115999639034, 43.00488777458668, 42.454529106616974, 42.22602836787701, 39.69160996377468, 38.79857428371906, 39.847526997327805, 40.85174471139908, 38.08947153389454, 39.773085191845894, 41.237667202949524, 42.7742325514555, 43.823447450995445, 46.49402394890785, 46.05374917387962, 46.58930383622646, 41.8481158465147, 47.44198948144913, 48.784571439027786, 44.1018433123827, 41.41197144985199, 40.07011525332928, 41.65132440626621, 38.72687593102455, 39.21660125255585, 39.12869296967983, 40.29808022081852, 40.80115422606468, 39.759744107723236, 43.55742372572422, 42.52694182097912, 42.93288163840771, 38.82915124297142, 40.38524754345417, 46.48884102702141, 40.51523096859455, 37.703438848257065, 38.86801935732365, 39.41091142594814, 38.66550162434578, 39.48898583650589, 38.74448798596859, 37.70182013511658, 38.32826592028141, 37.80616633594036, 37.119212597608566, 37.488545179367065, 36.93329617381096, 37.00103133916855, 36.33964642882347, 38.35340537130833, 44.678967744112015, 45.083064660429955, 47.21710614860058, 48.62368047237396, 52.83066272735596, 52.68779419362545, 52.656472474336624, 52.67004914581776, 50.68290777504444, 52.43868716061115, 53.94042357802391, 53.16451281309128, 53.34837354719639, 51.147033870220184, 54.84746150672436, 51.78522102534771, 56.289959102869034, 53.61272156238556, 56.95020027458668, 48.52259449660778, 43.78120891749859, 38.41447189450264, 45.70267081260681, 53.55275318026543, 60.75169488787651, 53.936619982123375, 58.29552188515663, 13.86793915182352, 0.5577583552803844, 6.938283294439316, 7.515185438096523, 1.858052322641015, 1.709580395836383, 53.303136974573135, 62.99294002354145, 60.003420040011406, 57.91135109961033, 40.8224330842495, 26.316363774240017, 31.395480930805206, 55.2657962590456, 23.52396011352539, 0.41593393427319825, 0.04372080278699286, 0.07985371703398414, 0.011630986628006212, 0.11682418946293183, 0.04745921956782695, 0.04438058320374694, 0.06858549590106122, 0.014933707989257528, 0.03639816524810158, 0.07354782181209885, 0.08625575006590225, 0.22665393393253908, 0.31296501110773534, 0.12130442366469651, 0.129249099700246, 0.13566330395406112, 0.2892037876881659, 0.18769174494082108, 0.19429178297286853, 0.1443683251272887, 0.2873291226569563, 1.5346597507596016, 47.12866589426994, 67.60399639606476, 42.5727179646492, 42.52313822507858, 51.70151151716709, 50.069210305809975, 64.9468369781971, 66.34619548916817, 60.86859941482544, 58.29894170165062, 51.40708431601524, 0.7063338265288621, 0.835137830581516, 11.695336382836103, 7.544733602553606, 1.75232287729159, 36.80097967386246, 66.93805173039436, 56.03563494980335, 54.956321865320206, 43.071429803967476, 50.25260366499424, 52.89435490965843, 57.706333100795746, 52.473968267440796, 48.311675414443016, 41.22330777347088, 43.04480083286762, 51.80655688047409, 53.53588968515396, 54.19407896697521, 53.73885579407215, 53.030478805303574, 54.88774694502354, 54.229025691747665, 53.69288966059685, 51.81055046617985, 53.12665544450283, 50.40874108672142, 53.499989211559296, 53.60711306333542, 53.909858018159866, 53.4675807505846, 55.364036187529564, 51.18009589612484, 49.161328822374344, 44.32550311088562, 39.986762925982475, 39.21207569539547, 43.948225155472755, 42.30086535215378, 41.36075019836426, 42.66611695289612, 43.28717082738876, 42.712770849466324, 43.086856976151466, 41.55436500906944, 41.48607887327671, 45.59147737920284, 45.28151661157608, 42.56687007844448, 44.343077167868614, 44.89303305745125, 43.280053809285164, 43.06039899587631, 40.76678887009621, 40.22389680147171, 43.198719173669815, 39.961851462721825, 40.765595734119415, 42.15134717524052, 44.81723852455616, 46.47463358938694, 49.00482662022114, 47.223364412784576, 48.18471282720566, 43.240600526332855, 50.2192984521389, 48.60988341271877, 45.07227323949337, 42.26092949509621, 44.251923859119415, 44.786577969789505, 40.08436068892479, 39.486804753541946, 41.28065049648285, 40.4519871622324, 42.407871410250664, 42.30090335011482, 46.47102378308773, 44.56712834537029, 43.17304775118828, 40.57914353907108, 41.50216720998287, 50.69280244410038, 42.538394406437874, 40.81799492239952, 40.02257600426674, 41.32983885705471, 40.739312544465065, 40.59838190674782, 40.55536441504955, 39.307993948459625, 40.74209399521351, 39.97793599963188, 40.353044271469116, 39.41077843308449, 38.89186307787895, 38.55206251144409, 39.08293202519417, 40.46406291425228, 46.29181019961834, 47.08353951573372, 49.06798303127289, 50.59886008501053, 55.55833876132965, 54.37133185565472, 55.23470252752304, 56.252675503492355, 52.20148108899593, 54.323610216379166, 56.88584692776203, 57.22159691154957, 54.9151548743248, 52.10552103817463, 56.25073380768299, 53.71114768087864, 58.40247854590416, 55.69201558828354, 60.67831702530384, 49.65460695326328, 47.474762722849846, 41.35449953377247, 48.09417888522148, 55.685255751013756, 64.30726289749146, 55.08225090801716, 57.52067506313324, 18.370475247502327, 0.46850052138324827, 9.119843132793903, 13.586731441318989, 2.59568655397743, 1.8411192437633872, 57.53778554499149, 67.22453355789185, 63.17548982799053, 63.84425774216652, 41.23658426105976, 28.308256790041924, 38.99870574474335, 64.25678640604019, 29.678254276514053, 0.6124624761287123, 0.16900473361602053, 0.1629618406877853, 0.17790185229387134, 0.2682969532907009, 0.16945539537118748, 0.16990944131975994, 0.23636587138753384, 0.09471886078245007, 0.11380512529285625], [0.08101583865936846, 0.06727921208948828, 0.09192878627800383, 0.030523125715262722, 0.05525244923774153, 0.027244747725490015, 0.0214605730434414, 0.011820712043117965, 0.008738965152588207, 0.04738159834232647, 0.0335873402946163, 0.186150586232543, 0.11346411585691385, 17.042418010532856, 58.71030382812023, 37.023795917630196, 22.301235124468803, 15.670938603579998, 29.851467981934547, 53.64949978888035, 55.79575002193451, 50.75654022395611, 47.20891758799553, 50.92327527701855, 2.987608923576772, 0.3517953649861738, 4.998003384098411, 9.19815693050623, 1.8863491667434573, 24.90381047129631, 66.99252560734749, 51.65010027587414, 54.366160333156586, 44.5160248875618, 51.49515599012375, 49.6820604801178, 53.25550653040409, 46.76028326153755, 43.86144921183586, 35.61704680323601, 45.98073989152908, 49.33723658323288, 52.40029402077198, 48.53086665272713, 49.26928482949734, 48.095964789390564, 51.252998784184456, 49.16534520685673, 53.067447021603584, 49.45296697318554, 49.97594051063061, 49.248857125639915, 52.93786257505417, 51.35510690510273, 52.926736772060394, 51.090986877679825, 52.41207718849182, 50.96098065376282, 48.86802636086941, 40.58125622570515, 38.17755080759525, 39.01532985270023, 37.240019515156746, 36.94220669567585, 38.97959277033806, 38.60693916678429, 38.52756902575493, 38.84406924247742, 39.34224911034107, 37.97056071460247, 39.19310711324215, 40.642497539520264, 42.61068932712078, 38.166086822748184, 39.324990436434746, 38.89452673494816, 39.92734931409359, 37.642391324043274, 38.25372152030468, 36.53909772634506, 37.788444086909294, 36.28029361367226, 39.78412739932537, 41.02854162454605, 43.80868524312973, 43.457758873701096, 46.22809521853924, 45.47102004289627, 47.29779861867428, 40.50469033420086, 40.73057681322098, 48.58317844569683, 45.08200831711292, 42.95325234532356, 38.34664933383465, 35.7094806432724, 35.59066101908684, 35.92068091034889, 37.710016295313835, 37.583635076880455, 37.54027180373669, 37.90405288338661, 38.38732995092869, 40.752269849181175, 43.12498793005943, 40.014820620417595, 40.373194590210915, 41.588076800107956, 39.04393091797829, 37.03481912612915, 36.612863168120384, 38.399580493569374, 38.72730530798435, 37.544968351721764, 36.63357585668564, 36.37964308261871, 37.18014992773533, 36.15648865699768, 36.6069582849741, 36.28279387950897, 34.58705127239227, 34.24425646662712, 34.681593999266624, 34.89036239683628, 39.19960476458073, 43.85878175497055, 45.91922119259834, 47.82911650836468, 50.03330983221531, 49.84344162046909, 48.658995777368546, 48.59749607741833, 46.308502703905106, 48.27423982322216, 52.99245044589043, 49.10656236112118, 53.301430866122246, 49.98263195157051, 53.94043877720833, 51.689834743738174, 55.61957627534866, 51.214237064123154, 55.02143517136574, 51.845010817050934, 47.44293563067913, 34.856057837605476, 43.812659829854965, 48.73585045337677, 58.37375208735466, 52.8509346395731, 55.91256335377693, 6.065699541941285, 0.34508305485360324, 6.44633699208498, 2.531241774559021, 1.364270718768239, 3.5580419143661857, 53.74845027923584, 55.83914369344711, 54.69220943748951, 49.949406534433365, 33.46425712108612, 28.29407975077629, 29.69192784279585, 43.794762790203094, 7.809339053928852, 0.4336456744931638, 0.039522677470813505, 0.1258062617853284, 0.01961238227522699, 0.08164620405295864, 0.04773670487338677, 0.016912139180931263, 0.029385320558503736, 0.032009319111239165, 0.03456890852248762, 0.026855365103983786, 0.09827013389440253, 0.06398966477718204, 0.05169788099010475, 0.023799382797733415, 0.043980810514767654, 0.07508430499001406, 0.020949181343894452, 0.019261010602349415, 0.041409027617191896, 0.06504528821096756, 0.19682099256897345, 0.11861927399877459, 24.41788874566555, 65.74699804186821, 38.281501829624176, 22.542457580566406, 28.51251482963562, 39.776250422000885, 56.69741503894329, 62.07664579153061, 56.164600029587746, 51.880975887179375, 55.49648568034172, 3.1504325615242124, 0.21798634668812156, 3.463971787132323, 9.938760939985514, 2.39456192124635, 26.171956323087215, 70.056362003088, 52.19521142542362, 55.89475370943546, 44.77902777493, 54.055086225271225, 51.958031952381134, 55.73514707386494, 48.28427888453007, 44.24734130501747, 37.03072674572468, 46.73896640539169, 51.63338877260685, 54.446552619338036, 50.54530195891857, 52.41851024329662, 49.905929267406464, 53.718519285321236, 51.83636628091335, 55.70246882736683, 51.551320776343346, 53.64218898117542, 51.35151229798794, 52.532321736216545, 52.65792779624462, 54.53702196478844, 53.22363764047623, 53.412856087088585, 52.71309323608875, 50.54967552423477, 40.94729818403721, 40.129574462771416, 41.10222727060318, 38.21201875805855, 39.79694031178951, 39.68745678663254, 39.85195375978947, 39.23783831298351, 40.19502595067024, 41.423465833067894, 39.97331544756889, 40.52259497344494, 43.04796606302261, 43.51045824587345, 41.01706624031067, 41.77798680961132, 40.31883470714092, 42.33343720436096, 40.25217868387699, 40.903877913951874, 38.880718275904655, 39.268084689974785, 37.487154453992844, 40.85809037089348, 42.72728607058525, 45.02456679940224, 43.29010047018528, 47.2144690901041, 47.77577117085457, 48.78188118338585, 42.31779724359512, 43.29055264592171, 49.01329256594181, 46.8158058822155, 45.2543480694294, 41.99733383953571, 37.86015763878822, 38.581495732069016, 38.400834426283836, 39.44077782332897, 38.900690004229546, 39.67940881848335, 40.36480464041233, 41.143838837742805, 41.83296225965023, 45.32637320458889, 42.56186954677105, 41.785046830773354, 43.644670844078064, 41.477396339178085, 37.56085529923439, 38.610488176345825, 40.471354722976685, 39.83923204243183, 38.70198726654053, 37.32500195503235, 39.120025634765625, 38.77246208488941, 38.2064026594162, 37.72046573460102, 37.532098442316055, 37.0577584952116, 37.262844890356064, 38.01327042281628, 38.82171504199505, 42.12494619190693, 46.56677104532719, 48.17358702421188, 49.704388082027435, 51.88995860517025, 51.41694858670235, 51.25305198132992, 50.089189633727074, 48.31223018467426, 49.98143881559372, 55.70099450647831, 51.87185637652874, 53.64298313856125, 51.88469208776951, 54.86939772963524, 53.45072105526924, 55.59556916356087, 51.93275950849056, 56.74639821052551, 53.19146476686001, 49.3640061467886, 36.38758085668087, 45.61902970075607, 51.063803136348724, 60.094246566295624, 52.711311131715775, 56.24226026237011, 7.634652452543378, 0.5575820803642273, 6.4407717157155275, 6.331741316244006, 1.401134915649891, 3.409090144559741, 59.01010014116764, 61.040069013834, 59.098316207528114, 56.29036948084831, 37.73223750293255, 24.123765528202057, 32.60247476398945, 50.5204588919878, 11.627965047955513, 0.469853367540054, 0.03115559695288539, 0.03928097110474482, 0.05308231295202859, 0.04521228212979622, 0.027117896133859176, 0.06466066275606863, 0.008961625226220349, 0.05809690090245567, 0.06607190109207295, 0.11814090044936165, 0.20675008243415505, 0.18552495574112982, 0.17786196927772835, 0.15979184594471008, 0.1515993964858353, 0.14301976858405396, 0.15951827546814457, 0.1667713886126876, 0.15281062602298334, 0.20785583794349805, 0.32150321232620627, 0.2611332689411938, 27.160433381795883, 74.84507024288177, 52.020956575870514, 32.496996223926544, 27.76243507862091, 40.69949068129063, 64.15182083845139, 66.29346951842308, 61.03611342608929, 56.338246911764145, 60.773581713438034, 3.916798713617027, 0.5595976347103715, 11.279626339673996, 15.445928927510977, 3.49022030364722, 26.171920225024223, 71.19864150881767, 55.177621990442276, 59.36240963637829, 48.48880670964718, 58.3382847905159, 54.428621381521225, 57.810641303658485, 50.56195646524429, 47.27925181388855, 39.42197643220425, 50.38435019552708, 53.27358216047287, 58.52117657661438, 51.973493322730064, 54.38473753631115, 51.25969022512436, 57.46839366853237, 52.989121824502945, 57.85447955131531, 53.64188499748707, 54.795039519667625, 53.77301596105099, 55.78226074576378, 55.42097993195057, 58.16237322986126, 55.65445080399513, 56.00858420133591, 54.53521326184273, 53.047794476151466, 43.81019376218319, 42.009117007255554, 43.10209795832634, 39.91524316370487, 42.0887341350317, 43.02767515182495, 43.86226236820221, 41.24169118702412, 41.497470661997795, 43.48808504641056, 41.044588163495064, 42.78753183782101, 44.80697527527809, 45.93904472887516, 43.204962238669395, 41.93674989044666, 41.76795534789562, 44.145514369010925, 42.10148625075817, 42.34579034149647, 41.24409265816212, 41.12767070531845, 39.721343368291855, 44.05164800584316, 45.264345332980156, 48.04477013647556, 46.42348073422909, 51.50324955582619, 49.532618299126625, 51.5650000423193, 42.918928787112236, 44.36517298221588, 51.119834929704666, 50.956895872950554, 49.255312979221344, 44.04992289841175, 39.63699169456959, 39.93798494338989, 39.50318947434425, 42.17558607459068, 41.43656373023987, 40.762791484594345, 43.08314837515354, 43.37399236857891, 44.10190410912037, 48.887918293476105, 45.056078508496284, 44.72725175321102, 45.438497588038445, 43.05840030312538, 41.056998297572136, 43.04553039371967, 41.15617677569389, 41.61082997918129, 42.131983414292336, 39.35183219611645, 40.01963496208191, 41.068188697099686, 40.10668069124222, 39.8373207449913, 40.92313528060913, 40.163179859519005, 39.624984338879585, 40.22820197045803, 40.35543814301491, 43.670946434140205, 48.34839664399624, 49.67621639370918, 52.696168944239616, 54.445781260728836, 52.45297819375992, 53.755065724253654, 51.992290914058685, 51.17720805108547, 51.11706867814064, 57.277469113469124, 53.66704344749451, 56.01198881864548, 54.8437225073576, 56.68829932808876, 55.76049171388149, 57.768364772200584, 52.981267645955086, 60.24417892098427, 54.42181594669819, 51.749442145228386, 38.55344943702221, 48.32120530307293, 52.66808845102787, 64.60815355181694, 54.596918150782585, 59.18236769735813, 9.568424262106419, 1.294414910953492, 14.361233431845903, 10.01522708684206, 4.443025588989258, 3.9320841059088707, 66.4580462872982, 66.24696761369705, 64.53086569905281, 61.10196389257908, 44.63309280574322, 39.37681965529919, 41.14227332174778, 58.203574419021606, 17.05158121883869, 0.6258543231524527, 0.37427204952109605, 0.2632701495895162, 0.16822771984152496, 0.1458360260585323, 0.12743146129650995, 0.24003496044315398, 0.08193950081476942, 0.1674812231794931, 0.10795833746669814], [0.03441069377004169, 0.008713250663276995, 0.01257686126336921, 0.03832744863757398, 0.011680871011776617, 0.010939867170236539, 0.019247008131060284, 0.08494067180436105, 0.057860044471453875, 0.05951624349108897, 0.0725974423403386, 0.15369348489912227, 0.048464673818671145, 1.8415708257816732, 42.90933810174465, 48.00728514790535, 39.15684185922146, 34.39286269247532, 25.536638014018536, 52.43875555694103, 55.07091611623764, 55.97193896770477, 46.6352129727602, 54.62772689759731, 9.366399552673101, 0.09910024091368541, 4.25253801047802, 6.554404143244028, 1.5657183341681957, 21.05720467865467, 68.16948965191841, 50.14736831188202, 53.36015671491623, 47.29125536978245, 55.197559520602226, 51.865267530083656, 53.62945206463337, 46.49967044591904, 40.324135422706604, 38.71695466339588, 50.77327452600002, 49.66094881296158, 52.022613286972046, 46.70249596238136, 51.81433506309986, 51.401794999837875, 53.369576409459114, 50.06361320614815, 51.24590836465359, 50.238236635923386, 50.307575315237045, 48.8961448520422, 52.31112040579319, 51.27876900136471, 54.91204284131527, 48.740364611148834, 52.148401737213135, 50.05058370530605, 49.93458352982998, 41.19527667760849, 37.79804617166519, 37.21275217831135, 38.184850215911865, 36.498975679278374, 37.41096094250679, 37.22549669444561, 37.03013777732849, 38.73800553381443, 38.9228618144989, 37.20597334206104, 39.577597081661224, 41.68310210108757, 40.966665744781494, 40.724383145570755, 40.903843715786934, 39.48967359960079, 38.29208806157112, 37.07875996828079, 37.99856901168823, 37.266283705830574, 37.489050552248955, 35.67329898476601, 38.08692567050457, 42.327847704291344, 45.39427936077118, 46.17930203676224, 47.92741723358631, 48.52723024785519, 50.04457242786884, 41.518616527318954, 41.37574799358845, 45.977190881967545, 47.03392557799816, 44.13492053747177, 45.06850764155388, 38.287813290953636, 36.63489818572998, 36.39291197061539, 37.56255000829697, 37.47126370668411, 36.58259779214859, 37.45998591184616, 37.673785239458084, 39.51067507266998, 40.72934187948704, 37.938338443636894, 38.45230646431446, 39.758687764406204, 40.01547418534756, 36.53315484523773, 36.98853760957718, 37.51013562083244, 37.878510653972626, 37.28635422885418, 37.067554369568825, 36.04281395673752, 37.69581265747547, 35.94239294528961, 37.08920560777187, 36.42635017633438, 34.7239351272583, 34.089889749884605, 34.30588535964489, 34.03888128697872, 39.1056852042675, 42.03295312821865, 46.740915700793266, 47.20431603491306, 51.216330751776695, 49.22120600938797, 50.83545818924904, 47.97509327530861, 47.79400259256363, 52.45211564004421, 50.75768016278744, 50.56221105158329, 50.45904278755188, 49.05536390841007, 52.4517622590065, 52.967470586299896, 50.218264907598495, 52.0307220518589, 50.8942486345768, 50.426949709653854, 50.78667640686035, 41.57973624765873, 39.9138068407774, 49.284297823905945, 55.35704456269741, 55.54386153817177, 50.14973558485508, 3.790778713300824, 0.8866583160124719, 5.561963897198439, 7.081466261297464, 1.1478055967018008, 6.247282298281789, 60.60131035745144, 49.47449281811714, 59.55429174005985, 44.96666930615902, 34.45836737751961, 29.831074476242065, 35.571380853652954, 40.47560669481754, 3.6668913485482335, 0.18823422520654276, 0.050457956313039176, 0.0558770629868377, 0.03432442281336989, 0.03723734502273146, 0.03537549688189756, 0.05762811590102501, 0.04169655789155513, 0.043098831083625555, 0.024493125747540034, 0.01848656280344585, 0.06897248880704865, 0.02322510892554419, 0.021121491336089093, 0.05617808550596237, 0.13437763700494543, 0.09148880402790383, 0.08192186738597229, 0.022415006496885326, 0.09279968173359521, 0.024029233354667667, 0.31253385299351066, 0.05627144768368453, 4.050643444061279, 52.987518310546875, 53.050306141376495, 38.07461433112621, 29.5949000492692, 35.82189381122589, 55.14630027115345, 61.35914549231529, 61.8739228695631, 51.86326123774052, 61.180190294981, 9.22601893544197, 0.1663696937612258, 2.5621205801144242, 11.108601316809654, 2.848872668109834, 21.327624768018723, 70.5809086561203, 52.27710843086243, 57.9548891633749, 49.20244261622429, 56.95158340036869, 52.17265583574772, 54.6084201335907, 49.16714631021023, 41.9452728331089, 39.50711086392403, 52.91621133685112, 52.42435812950134, 53.14705274999142, 48.630919083952904, 53.9934953302145, 52.569495141506195, 55.266134440898895, 52.08899572491646, 55.04706099629402, 51.15679554641247, 52.3544342815876, 50.39209417998791, 53.325251787900925, 50.69284804165363, 55.53331330418587, 50.854981541633606, 53.17219220101833, 52.597081661224365, 52.10783511400223, 42.91541777551174, 39.13896381855011, 39.440481439232826, 39.112752825021744, 38.760450929403305, 38.16152706742287, 38.31903621554375, 40.61617635190487, 41.90028704702854, 40.719245821237564, 40.478163957595825, 42.19332732260227, 44.55592654645443, 42.453320771455765, 41.978787034749985, 42.49689303338528, 39.6558652818203, 39.76890541613102, 39.24212068319321, 41.3377196341753, 40.4148555546999, 39.964621514081955, 37.861118987202644, 39.80345316231251, 44.30514380335808, 46.60923756659031, 48.38834770023823, 48.78457523882389, 50.49678236246109, 51.18871383368969, 43.57969053089619, 42.332445457577705, 46.35548338294029, 47.905218824744225, 45.69049246609211, 45.35584822297096, 40.16794100403786, 38.65650750696659, 37.708849757909775, 39.88215073943138, 38.436738699674606, 38.0509340018034, 42.00538940727711, 40.18957704305649, 40.51648110151291, 42.9574853181839, 40.446846038103104, 42.086526453495026, 41.13010637462139, 41.384244337677956, 38.92576485872269, 39.88780103623867, 39.43646885454655, 39.177068173885345, 39.05908450484276, 39.400811567902565, 37.209826335310936, 39.429393634200096, 38.24178256094456, 39.187453016638756, 38.054498210549355, 37.83283330500126, 36.711152493953705, 37.44343400001526, 36.57074622809887, 40.96661254763603, 44.45541054010391, 48.4719318151474, 49.08630184829235, 53.62233504652977, 51.08981654047966, 52.37228952348232, 47.362341955304146, 49.2081955075264, 54.54492934048176, 53.057818338274956, 51.4374028891325, 53.3419518917799, 51.480420380830765, 53.04935239255428, 54.58528317511082, 53.80107365548611, 53.25041480362415, 53.56328621506691, 53.207876086235046, 53.10011766850948, 42.61504389345646, 42.072900384664536, 51.43755868077278, 57.98005901277065, 56.8612090498209, 52.1096134185791, 4.827097104862332, 1.1291672405786812, 5.854348232969642, 7.1933678817003965, 1.1869090609252453, 7.7436230052262545, 62.7755992859602, 57.56723016500473, 62.75216594338417, 55.613591596484184, 41.37415207922459, 32.45160385966301, 40.163575038313866, 47.8339384496212, 6.28270304761827, 0.28123335912823677, 0.025197947106789798, 0.09235002187779173, 0.06603175832424313, 0.05106301076011732, 0.03819150573690422, 0.08620495005743578, 0.09015002156957053, 0.04511566192377359, 0.036322926316643134, 0.12207060950458981, 0.23266731906915084, 0.11977798174484633, 0.11426449244027026, 0.20296208647778258, 0.2829101082170382, 0.15342625236371532, 0.1931648762547411, 0.10187579158809967, 0.21041072584921494, 0.16161656443728134, 0.5580205412115902, 0.24000871810130775, 4.002156620845199, 60.263417288661, 61.37660175561905, 50.774201676249504, 44.81040269136429, 38.44155304133892, 61.99329726397991, 65.64365118741989, 67.43822649121284, 55.369078516960144, 67.33686313033104, 11.041374374181032, 0.18099500506650656, 11.358068380504847, 12.252536583691835, 3.355344641022384, 24.07279696315527, 71.28757193684578, 53.86507362127304, 63.29592436552048, 51.94395750761032, 58.9141096919775, 54.25636902451515, 58.19248281419277, 51.35018236935139, 44.01710785925388, 42.380303889513016, 54.130675569176674, 53.59287142753601, 55.77020779252052, 50.350296422839165, 55.53812764585018, 55.03165662288666, 57.48682647943497, 53.0187526345253, 55.326950177550316, 51.19963064789772, 53.954764008522034, 51.48086495697498, 55.118580758571625, 52.18668848276138, 57.934518456459045, 51.58434860408306, 54.95526932179928, 55.43793462216854, 54.630044773221016, 45.82805648446083, 42.579409405589104, 41.83395020663738, 41.26938410103321, 41.20278127491474, 39.4026430696249, 39.54488843679428, 41.66616640985012, 44.554182440042496, 42.35183201730251, 42.195345014333725, 42.76498764753342, 46.694941967725754, 44.62658375501633, 44.30811144411564, 44.75032031536102, 42.06291452050209, 41.83074317872524, 39.541848599910736, 41.60393334925175, 42.0502308011055, 41.95382237434387, 39.252862706780434, 41.51609346270561, 46.63753844797611, 48.8875725120306, 51.410842314362526, 52.124014645814896, 51.340002715587616, 53.95614333450794, 42.55509451031685, 43.51453922688961, 48.47037769854069, 51.54097393155098, 46.915193349123, 49.22601655125618, 42.66237795352936, 41.60452991724014, 39.16365869343281, 42.52908110618591, 41.18136562407017, 39.1145995259285, 42.72347867488861, 41.30222573876381, 42.72029064595699, 43.593700379133224, 41.810558661818504, 43.30514766275883, 42.85943157970905, 44.603446796536446, 40.60741402208805, 41.860620975494385, 42.31668010354042, 40.875273048877716, 41.903573870658875, 41.59796006977558, 39.94993530213833, 40.80260194838047, 39.59862135350704, 40.39287753403187, 39.65005159378052, 39.21820476651192, 39.752205312252045, 39.39280919730663, 37.56407752633095, 44.339930936694145, 47.78555564582348, 51.345387026667595, 50.89684009552002, 55.5971422791481, 52.25412726402283, 53.50384220480919, 50.22800758481026, 51.20772421360016, 56.012535989284515, 54.72902946174145, 52.54066988825798, 55.00299856066704, 53.052776008844376, 56.12377122044563, 56.82273231446743, 54.745474979281425, 55.87830439209938, 57.057628110051155, 52.660013884305954, 56.26058287918568, 45.50339050590992, 45.552255883812904, 54.46766808629036, 61.76200747489929, 57.59330436587334, 53.968819454312325, 6.856391513720155, 1.3869547890499234, 14.60638677701354, 19.26271677017212, 2.5769685208797455, 8.91854703426361, 67.73494496941566, 61.32094994187355, 66.54049426317215, 57.524839639663696, 47.83662870526314, 39.976051300764084, 49.15615350008011, 58.20863574743271, 8.547393400222063, 0.40273777674883604, 0.3343984141247347, 0.18771632487187162, 0.11666091697406955, 0.10631928947987035, 0.14498856762656942, 0.14051835983991623, 0.1389230095082894, 0.14071820536628366, 0.09139578323811293], [0.05880470198462717, 0.05411667014413979, 0.045158602588344365, 0.019513032821123488, 0.0598367288330337, 0.029377628197835293, 0.02427823688776698, 0.04212164523778483, 0.04423312217113562, 0.0498402927769348, 0.05183212066185661, 0.025939656916307285, 0.07360662959399633, 0.005320820346241817, 16.13797154277563, 60.067116022109985, 30.507354587316513, 25.753032602369785, 32.040032744407654, 47.40745313465595, 56.78830996155739, 56.06031082570553, 46.15890093147755, 55.30746482312679, 20.267534852027893, 0.2641621814109385, 1.368704130873084, 8.766953218728304, 0.31434754317160696, 13.860917128622532, 63.7210987508297, 54.20893996953964, 55.982016026973724, 49.057723581790924, 54.25189666450024, 52.30974107980728, 54.416796416044235, 44.88972343504429, 37.66872011125088, 43.171364441514015, 52.7849055826664, 51.52278810739517, 50.7452130317688, 46.83602839708328, 48.766047433018684, 50.43948143720627, 49.375572726130486, 45.983760729432106, 49.78886514902115, 46.51634395122528, 50.48794783651829, 48.996565863490105, 51.52746945619583, 51.90891578793526, 51.9397359341383, 51.04272186756134, 52.15844079852104, 50.45724928379059, 47.699919641017914, 37.73933172225952, 36.62673242390156, 36.74645259976387, 38.10582585632801, 36.12377241253853, 37.151222079992294, 36.501145362854004, 38.45472693443298, 38.4732623398304, 37.212714180350304, 37.72806912660599, 40.38616329431534, 41.86350882053375, 38.246874287724495, 39.69599112868309, 38.70309300720692, 38.83767418563366, 38.765356466174126, 38.83621886372566, 39.811459332704544, 38.146039098501205, 36.793106496334076, 37.85784736275673, 36.70419506728649, 42.11327701807022, 46.48908041417599, 46.1612606048584, 48.063955307006836, 50.6010677665472, 49.14755076169968, 46.21257305145264, 44.58516977727413, 45.809486880898476, 48.13285320997238, 46.11260041594505, 44.99700307846069, 38.487948551774025, 36.615564823150635, 35.04478231072426, 37.38128833472729, 37.093278989195824, 38.83902311325073, 38.827775716781616, 37.87067547440529, 39.15795139968395, 40.34948766231537, 38.18684130907059, 37.14883580803871, 39.2701555788517, 41.36269189417362, 36.92155480384827, 36.732024773955345, 36.78614526987076, 37.798315957188606, 37.22360819578171, 36.608721390366554, 34.951352924108505, 38.445303440093994, 35.846721678972244, 34.87225256860256, 35.68823218345642, 35.63834086060524, 34.7188737988472, 34.8113988339901, 33.932954370975494, 35.91387927532196, 38.09351831674576, 43.20927120745182, 46.32745608687401, 48.06114345788956, 50.40300339460373, 51.82059332728386, 50.535050109028816, 51.61389201879501, 48.38460110127926, 49.84645485877991, 49.67785030603409, 48.709373474121094, 48.496942073106766, 51.10706381499767, 50.01625254750252, 51.08529858291149, 47.9829740524292, 52.70531125366688, 50.44890873134136, 52.79561720788479, 44.552544727921486, 39.660983607172966, 47.68633157014847, 52.60370850563049, 57.095401883125305, 43.04025247693062, 7.676163325086236, 1.8197746016085148, 2.6966440491378307, 5.4458763264119625, 0.4511196899693459, 9.094057716429234, 58.70132490992546, 50.62858588993549, 51.98746517300606, 37.100722789764404, 26.298576928675175, 21.078227050602436, 40.78869089484215, 31.375771388411522, 0.8868240227457136, 0.1567478381912224, 0.014872343508613994, 0.06247609911952168, 0.09796200902201235, 0.02703945297980681, 0.04187274746072944, 0.16791024390840903, 0.04502346862864215, 0.06255708969547413, 0.05812161813082639, 0.06482447701273486, 0.030813565208518412, 0.022534104500664398, 0.03701704219565727, 0.022569883440155536, 0.03026627397048287, 0.06670836693956517, 0.06947812144062482, 0.08303397567942739, 0.03696437939652242, 0.04838872984691989, 0.10637304323608987, 0.05352595399017446, 0.08732643909752369, 24.94239930063486, 63.10391686856747, 34.36820961534977, 29.90999434143305, 37.83000625669956, 55.00184342265129, 62.84569412469864, 61.02157160639763, 49.349734112620354, 62.63558439910412, 22.598046697676182, 0.09285279724281281, 2.0965334633365273, 10.24769101291895, 0.6982122967019677, 15.754340328276157, 68.06855946779251, 55.9820806235075, 58.94725151360035, 51.57115191221237, 58.36548753082752, 53.42995896935463, 56.90267242491245, 45.69980576634407, 40.06577968597412, 44.72153685986996, 53.83794687688351, 52.86145627498627, 54.11298371851444, 47.3183137178421, 50.541068986058235, 51.13010577857494, 49.923545122146606, 48.45171310007572, 50.86055584251881, 47.56690017879009, 50.549762919545174, 51.19535967707634, 54.267563223838806, 51.19966484606266, 54.519425109028816, 52.20459312200546, 52.995999455451965, 52.23964624106884, 49.82017546892166, 39.699904918670654, 38.75449664890766, 39.21482294797897, 39.31458659470081, 37.15789072215557, 39.63780105113983, 38.80001820623875, 40.406287014484406, 38.75799626111984, 39.60131160914898, 39.75295007228851, 42.63875462114811, 41.806785464286804, 41.993416249752045, 40.728395730257034, 41.31236359477043, 40.371952056884766, 39.98770907521248, 40.51356665790081, 40.509899854660034, 39.6443746984005, 38.18657152354717, 38.287494108080864, 38.53913560509682, 44.86582651734352, 48.711501359939575, 49.10662315785885, 51.00112549960613, 52.543983310461044, 51.851573064923286, 48.73042054474354, 46.59955948591232, 49.07228820025921, 49.71878170967102, 46.430783942341805, 44.92292605340481, 40.49013711512089, 37.29394242167473, 35.77557809650898, 38.84349927306175, 38.73712778091431, 40.621583461761475, 40.974573120474815, 39.63037244975567, 42.09084302186966, 42.34411463141441, 40.43151006102562, 40.64162738621235, 42.20706358551979, 43.64215537905693, 39.30121511220932, 39.00885500013828, 39.259063974022865, 39.53338265419006, 38.3965140581131, 38.82383532822132, 37.04341806471348, 38.4356177598238, 37.67540395259857, 37.266868874430656, 38.06055888533592, 36.1673104763031, 37.492626160383224, 38.98510627448559, 35.997243002057076, 37.46333733201027, 39.41271632909775, 45.061987191438675, 48.92393656075001, 50.75396776199341, 51.14911615848541, 51.66075490415096, 50.47539331018925, 54.075589925050735, 50.6435988843441, 52.92388692498207, 52.76382811367512, 50.52055008709431, 49.45969261229038, 53.48640874028206, 50.98782621324062, 53.01639676094055, 49.92935501039028, 53.91495734453201, 53.640604466199875, 57.17496961355209, 45.84641709923744, 41.23681604862213, 50.68476967513561, 55.30917473137379, 57.39164158701897, 45.54943263530731, 9.204725828021765, 1.5146135701797903, 6.637706598266959, 5.812920005992055, 1.0902607720345259, 9.37780749052763, 64.27919760346413, 58.036090806126595, 56.88369244337082, 46.611901223659515, 32.543190345168114, 24.05098233371973, 45.89279741048813, 39.00108441710472, 1.3523932686075568, 0.20534828421659768, 0.0655729923164472, 0.12737269804347306, 0.13611216971185058, 0.06759076568414457, 0.017651706039032433, 0.0020287024199205916, 0.008670674578752369, 0.04279266548110172, 0.014303344451036537, 0.19751193205593154, 0.0852707790909335, 0.1431760797277093, 0.11626412771875039, 0.24528647161787376, 0.15494952531298622, 0.12429030641214922, 0.12204036698676646, 0.1075307342398446, 0.1792336066137068, 0.09431184473214671, 0.1716329308692366, 0.1490601382101886, 0.17859892192063853, 28.635263442993164, 74.39020425081253, 41.68421544134617, 36.860043704509735, 44.63697239756584, 60.65476208925247, 65.91898441314697, 67.9919783771038, 53.89807105064392, 68.87545377016068, 24.493757374584675, 0.3251317504327744, 6.619945401325822, 18.09346441179514, 0.9236746828537434, 16.14633869379759, 68.70060995221138, 57.059592604637146, 62.38973379135132, 53.48311051726341, 58.6934707313776, 56.190427243709564, 59.08845193684101, 49.05568689107895, 42.882500141859055, 47.41548590362072, 56.99672497808933, 54.52066384255886, 54.411282911896706, 48.767521753907204, 52.26026773452759, 52.15444341301918, 51.79064333438873, 48.46302509307861, 53.17418709397316, 49.093688651919365, 54.53183524310589, 51.914566084742546, 56.86419568955898, 55.51555685698986, 57.32911594212055, 54.589595943689346, 56.44378624856472, 55.866680815815926, 52.970058247447014, 41.158262863755226, 40.17674893140793, 40.90896584093571, 41.55453979969025, 39.04846407473087, 43.34073655307293, 40.57100437581539, 41.685275584459305, 41.43096283078194, 41.41576744616032, 42.581563889980316, 43.755890876054764, 44.616917073726654, 43.309775814414024, 42.919844537973404, 44.05875742435455, 41.64688244462013, 41.88864067196846, 42.93868012726307, 43.74658137559891, 41.29548490047455, 40.44772759079933, 40.647121891379356, 41.161082312464714, 45.983228757977486, 52.790058106184006, 50.88697962462902, 52.32837527990341, 53.74653898179531, 53.45091104507446, 51.10049016773701, 47.35734522342682, 50.725290700793266, 52.094737216830254, 50.423545092344284, 49.11107651889324, 41.454380974173546, 42.676182612776756, 36.852060332894325, 42.039275988936424, 41.03370554745197, 43.93254719674587, 43.21967124938965, 41.74194574356079, 43.513634875416756, 43.191077783703804, 41.776763275265694, 42.12045103311539, 44.868471175432205, 45.831996873021126, 40.65761312842369, 41.045310124754906, 40.606920048594475, 41.72740012407303, 40.68530224263668, 40.05484767258167, 37.21791610121727, 42.511966824531555, 38.29179547727108, 38.83791737258434, 40.00482335686684, 41.50321215391159, 39.429032653570175, 39.779259860515594, 36.74603082239628, 39.97463017702103, 42.710266783833504, 47.5379229336977, 51.70446015894413, 53.17980699241161, 52.57084786891937, 55.53267113864422, 52.69638553261757, 53.15399877727032, 51.108188554644585, 54.048645570874214, 52.53378085792065, 52.348331809043884, 52.35079787671566, 56.29491023719311, 51.855327263474464, 54.51911352574825, 50.608511567115784, 54.78947661817074, 55.31449444591999, 60.39854943752289, 48.286600559949875, 42.704152911901474, 52.29497887194157, 56.66546255350113, 59.400282204151154, 49.55530308187008, 12.631960473954678, 2.7958845114335418, 11.124815046787262, 19.034803099930286, 1.7490665707737207, 12.063192743808031, 68.48131611943245, 61.104832738637924, 64.12093609571457, 50.60819238424301, 36.67593978345394, 29.30334359407425, 52.83817492425442, 46.857212260365486, 2.4014946492388844, 0.3265725262463093, 0.11874605508637615, 0.3323581611039117, 0.1784165168646723, 0.14027313940459862, 0.11880523394211195, 0.18509344139602035, 0.07618485804414377, 0.1471761369612068, 0.13315033254912123], [0.054696361694368534, 0.04970646870788187, 0.025154371905955486, 0.014647153639089083, 0.06878450280055404, 0.03823560786258895, 0.0418924106634222, 0.036706872706417926, 0.023853182938182727, 0.02090167090500472, 0.032274284385493957, 0.03549165412550792, 0.10611903577228077, 0.0350460983463563, 4.36848783865571, 52.505308985710144, 47.55868881940842, 31.450653970241547, 24.680287465453148, 36.10506981611252, 49.45204362273216, 58.773274049162865, 49.49274703860283, 51.74877718091011, 33.508919924497604, 0.11468232900369912, 1.1176305846311152, 10.809008292853832, 5.232916753739119, 3.404246116988361, 53.678051456809044, 57.79348902404308, 54.64211292564869, 51.760343760252, 52.552772238850594, 53.05479750037193, 52.73000992834568, 43.74732233583927, 43.437513560056686, 48.45831714570522, 49.22966055572033, 50.96052847802639, 46.469519063830376, 49.12122577428818, 53.14824968576431, 48.85072968900204, 50.16431540250778, 48.9130425453186, 50.90776830911636, 49.61486488580704, 47.93479643762112, 48.62091422080994, 50.60815438628197, 49.20359395444393, 51.36857718229294, 49.66613173484802, 49.74875830113888, 48.36095876991749, 44.87159080803394, 36.103850081562996, 38.06060068309307, 37.6562187820673, 36.364234909415245, 38.242337331175804, 38.692715764045715, 37.20486760139465, 39.27269384264946, 38.72229717671871, 39.79534059762955, 37.327126041054726, 39.0985681861639, 39.763764292001724, 39.88869398832321, 39.295397624373436, 39.50720585882664, 37.17702269554138, 38.68331886827946, 38.54901507496834, 38.829310834407806, 36.71708017587662, 37.381945699453354, 34.42553713917732, 37.16036058962345, 42.51095987856388, 45.881508216261864, 47.341013699769974, 47.968033254146576, 49.594212993979454, 54.97060149908066, 47.35024720430374, 45.0527498871088, 47.53004975616932, 49.94350545108318, 48.663616329431534, 45.56940816342831, 37.408023700118065, 35.066251158714294, 36.28549553453922, 36.165881752967834, 36.99152424931526, 38.45356039702892, 36.69271968305111, 39.02757279574871, 38.074025362730026, 39.556743800640106, 38.62559616565704, 37.45985671877861, 39.41148519515991, 39.03494819998741, 38.30202452838421, 36.2492872774601, 37.18199662864208, 37.46028229594231, 36.163780465722084, 35.92035412788391, 36.51088424026966, 37.64888517558575, 36.17804870009422, 36.39606960117817, 36.45617477595806, 36.01854845881462, 35.38441948592663, 34.74322289228439, 35.20109832286835, 35.72368808090687, 35.33770099282265, 37.85839453339577, 42.22723290324211, 43.97677302360535, 45.55051937699318, 47.066926807165146, 47.49542981386185, 47.035662084817886, 46.39097347855568, 49.83862727880478, 47.80118800699711, 46.38351447880268, 47.85424456000328, 46.49013675749302, 49.8009143024683, 53.28431278467178, 51.31670616567135, 49.92213919758797, 50.12575887143612, 54.05464164912701, 49.0637044608593, 41.30811542272568, 45.452750623226166, 53.49477969110012, 59.13893982768059, 39.93270702660084, 10.773446001112461, 1.0723486519418657, 3.874162626452744, 2.6394834788516164, 1.0116840759292245, 12.79245151206851, 63.720050007104874, 44.28447671234608, 48.05573634803295, 32.871458530426025, 25.781546272337437, 24.193062409758568, 46.67965538799763, 16.407774165272713, 0.16670214623445645, 0.08289465971756727, 0.05108090765133966, 0.009564031133777462, 0.06120238445873838, 0.04550995756289922, 0.03512288094498217, 0.0368164099927526, 0.02521374186471803, 0.014982328866608441, 0.02556978721258929, 0.08504453537170775, 0.050950942750205286, 0.019949337729485705, 0.030561812018277124, 0.014769024492125027, 0.06449737542425282, 0.09770386037416756, 0.009944870707840892, 0.08332762125064619, 0.052032530220458284, 0.019712154753506184, 0.051139960341970436, 0.022378524372470565, 0.008976032167993253, 6.984127834439278, 61.86360642313957, 48.883065953850746, 28.659927919507027, 35.689539313316345, 47.81070649623871, 55.67851111292839, 68.43209356069565, 52.34433822333813, 57.52109684050083, 34.110059067606926, 0.23417355230776593, 1.8605438014492393, 8.513804152607918, 3.9261435996741056, 4.698961330577731, 56.883122473955154, 59.89916883409023, 57.380295395851135, 53.56001079082489, 56.452597975730896, 54.670896381139755, 54.39042963087559, 45.21874777972698, 44.96898718178272, 50.16794800758362, 52.00617916882038, 52.46964029967785, 48.74015562236309, 48.76719497144222, 54.474986493587494, 49.08341020345688, 52.308825328946114, 50.92788062989712, 51.86850495636463, 52.10409991443157, 52.184674590826035, 51.65200017392635, 53.44510495662689, 51.31698735058308, 53.23381349444389, 52.527682185173035, 52.706998363137245, 50.83491101861, 45.76190963387489, 37.08724111318588, 40.16192212700844, 39.39478889107704, 38.40700909495354, 40.16134075820446, 40.40389694273472, 38.876979276537895, 41.493355482816696, 39.66181956231594, 40.557294711470604, 38.13587464392185, 40.775258615612984, 42.187430039048195, 40.808050855994225, 38.76885987818241, 40.996209159493446, 39.54467184841633, 40.68247139453888, 40.17693892121315, 41.343939900398254, 38.93665887415409, 40.10149396955967, 36.81652083992958, 39.97131675481796, 42.96090893447399, 49.068777188658714, 49.586529806256294, 50.72337940335274, 51.24968536198139, 56.654834523797035, 49.099262952804565, 47.32541173696518, 50.166093707084656, 51.37705072760582, 50.19112676382065, 46.50714084506035, 40.35674147307873, 37.72990442812443, 38.73177766799927, 39.83386293053627, 38.42821575701237, 40.322729498147964, 38.73124569654465, 41.09814628958702, 40.27440369129181, 42.03819304704666, 39.42441590130329, 38.868577927351, 39.61414352059364, 41.35313540697098, 39.93440933525562, 38.03563602268696, 40.07154777646065, 40.73503777384758, 37.976617589592934, 37.55841962993145, 37.97751434147358, 38.58135133981705, 38.206254467368126, 38.17391060292721, 36.96548044681549, 37.20433942973614, 35.72852902114391, 36.771607249975204, 38.03906723856926, 37.24596619606018, 37.625121250748634, 39.4725289195776, 43.46384234726429, 45.387998297810555, 48.43256592750549, 48.742921873927116, 50.06675943732262, 49.37101297080517, 48.569590374827385, 49.679974392056465, 49.15252469480038, 48.638765662908554, 48.64619426429272, 48.885646015405655, 50.37961184978485, 53.977574184536934, 53.61779808998108, 50.70134438574314, 52.08936050534248, 55.545677840709686, 50.00698484480381, 44.172834903001785, 46.68681800365448, 55.68386882543564, 59.92542542517185, 42.52859093248844, 12.5007582642138, 1.2702090223319829, 5.696170795708895, 0.7966256502550095, 0.7701820379588753, 13.023841045796871, 68.10738578438759, 50.05126766860485, 53.093696013092995, 40.12343019247055, 26.78066845983267, 24.217654690146446, 52.18228831887245, 22.884615920484066, 0.20417346444446594, 0.02826834563165903, 0.07333411296713166, 0.053598766098730266, 0.055593547731405124, 0.02407279742328683, 0.042528108388069086, 0.10025771669461392, 0.13755990687059239, 0.031220212040352635, 0.03564099650247954, 0.14035197033081204, 0.12041400230373256, 0.16728350019548088, 0.11471116144093685, 0.2382600400596857, 0.18212084309197962, 0.1771673932671547, 0.16065125295426697, 0.17837652994785458, 0.14018792600836605, 0.0978337881679181, 0.10016929722041823, 0.1738129451405257, 0.10653737699612975, 8.266524821519852, 70.9883987903595, 57.803995460271835, 41.68773405253887, 34.83153775334358, 48.63371193408966, 58.518539518117905, 72.15989872813225, 55.59399604797363, 64.21064928174019, 40.68564422428608, 0.5518792395014316, 4.539770297706127, 18.677591867744923, 7.6140708569437265, 6.430564038455486, 57.29511916637421, 60.81639401614666, 59.20016974210739, 56.23238459229469, 57.416807636618614, 57.42293290793896, 58.49479839205742, 47.9730261862278, 48.09713892638683, 51.83569371700287, 52.79930301010609, 53.3527585119009, 47.46167242527008, 51.85280799865723, 56.794439032673836, 52.478178441524506, 56.135854572057724, 52.84446358680725, 54.79422636330128, 53.609518334269524, 53.81973825395107, 53.699748292565346, 57.05687575042248, 52.846979051828384, 55.8904105424881, 53.194857984781265, 55.2432406693697, 51.45733281970024, 48.93238350749016, 38.83692182600498, 43.06289546191692, 41.760218963027, 38.52595791220665, 41.782972142100334, 42.72807262837887, 39.6808185428381, 43.68896126747131, 41.78546100854874, 43.95622752606869, 41.26683443784714, 42.4786502122879, 43.620523139834404, 45.747702196240425, 40.86485020816326, 42.818796560168266, 41.73960506916046, 42.56655849516392, 42.398979887366295, 43.19318667054176, 40.122088864445686, 42.88068383932114, 38.15909139811993, 40.96908621490002, 45.28142161667347, 50.39493642747402, 51.9737783074379, 52.31808543205261, 51.90655991435051, 59.83350455760956, 49.77146588265896, 48.017871379852295, 51.251463666558266, 52.65852436423302, 51.95575587451458, 49.15618769824505, 44.243210926651955, 39.23489727079868, 39.12537954747677, 41.540826335549355, 41.92218907177448, 43.18821653723717, 39.67824228107929, 42.301883697509766, 41.037026569247246, 43.59684281051159, 41.97115704417229, 40.24147465825081, 41.964887380599976, 43.687916323542595, 41.62783786654472, 38.22829708456993, 41.81781247258186, 42.52310782670975, 39.74674500524998, 39.26057629287243, 39.97157894074917, 41.34435787796974, 38.793011382222176, 39.509535133838654, 40.81468150019646, 38.25357332825661, 38.103052005171776, 39.047350734472275, 40.26962734758854, 39.45506125688553, 39.01832789182663, 40.83484701812267, 44.71593216061592, 47.438033893704414, 50.955087170004845, 52.47758187353611, 51.22584544122219, 52.56237052381039, 50.86525619029999, 53.860464468598366, 51.53218500316143, 50.64332149922848, 51.39906294643879, 50.46618640422821, 52.953312546014786, 57.02514745295048, 55.35843908786774, 51.53801769018173, 53.70718449354172, 58.738407120108604, 52.91882939636707, 46.90345957875252, 48.809859082102776, 59.3263191729784, 62.31686130166054, 45.68479277193546, 15.421622581779957, 2.320755156688392, 10.073801893740892, 10.517271347343922, 1.7486737668514252, 16.02340769022703, 74.05421867966652, 55.1515743881464, 57.541516944766045, 46.508774757385254, 36.386239528656006, 34.58540976047516, 60.939796194434166, 29.423743933439255, 0.4166404588613659, 0.12721913284622133, 0.15640316996723413, 0.07242338644573465, 0.1637148979352787, 0.14428015798330307, 0.26767322269733995, 0.12129441209253855, 0.2003853942733258, 0.1730963125010021, 0.06654813725617714], [0.02365974214626476, 0.04222707844746765, 0.11562403276911937, 0.08220649586291984, 0.05331259024387691, 0.032807595416670665, 0.046803858640487306, 0.022427398507716134, 0.01424700245479471, 0.03455706755630672, 0.04368873458588496, 0.06443548030802049, 0.06997147895162925, 0.021660088314092718, 0.2670489577576518, 26.727961488068104, 48.25468987226486, 27.262746691703796, 23.969590701162815, 33.442951664328575, 47.1697036921978, 49.55790214240551, 45.58720640838146, 51.54998704791069, 43.87609362602234, 2.9893853282555938, 2.6384382974356413, 5.785679267719388, 14.456695709377527, 0.8135079068597406, 46.24713979661465, 52.519957199692726, 55.78508019447327, 45.91424725949764, 53.35597313940525, 53.189283683896065, 48.56098763644695, 47.24960200488567, 48.72320473194122, 48.48337680101395, 53.793595656752586, 50.503492802381516, 51.7248422652483, 51.25198423862457, 50.74561960995197, 48.03667277097702, 50.042414143681526, 50.30639357864857, 50.01121401786804, 49.558745697140694, 50.23777686059475, 49.70851466059685, 48.54445852339268, 49.14460211992264, 49.17937785387039, 47.9256921261549, 45.16684636473656, 43.029890432953835, 39.27747018635273, 35.73265939950943, 37.603477612137794, 38.323785960674286, 37.58291691541672, 39.272028878331184, 37.77814283967018, 38.05295929312706, 38.26558828353882, 38.43890458345413, 39.14518788456917, 36.22837319970131, 40.279168635606766, 39.04979020357132, 36.4785897731781, 37.54458837211132, 39.55180026590824, 36.62349119782448, 36.72799699008465, 37.78264939785004, 38.16639080643654, 38.22760932147503, 36.697184443473816, 35.23933567106724, 37.42944315075874, 41.37015849351883, 48.04681062698364, 49.273981377482414, 47.1147396415472, 51.83428019285202, 51.89071096479893, 49.61480408906937, 48.33940252661705, 46.318826749920845, 51.64033479988575, 48.16790632903576, 45.51950924098492, 37.23600693047047, 37.55092643201351, 35.950380116701126, 36.70251175761223, 38.54243382811546, 37.28049874305725, 37.76254467666149, 39.08747658133507, 37.36233115196228, 38.277941420674324, 36.59103713929653, 36.98369286954403, 39.294531270861626, 40.165151953697205, 38.66364352405071, 35.816999673843384, 35.95685876905918, 37.695516273379326, 37.62973800301552, 34.8746008425951, 35.090938434004784, 35.32309837639332, 36.45983777940273, 36.140689104795456, 35.49023620784283, 34.658749625086784, 36.604347825050354, 35.74883133172989, 36.58582381904125, 36.62447154521942, 35.201919078826904, 35.97485460340977, 35.97081542015076, 39.76016968488693, 41.533967703580856, 41.90368786454201, 39.66575615108013, 40.25811016559601, 42.166679352521896, 44.32503193616867, 43.70115101337433, 43.75314362347126, 44.06664960086346, 47.195527106523514, 48.11985790729523, 52.4076846241951, 49.499062299728394, 52.117771580815315, 50.62406413257122, 52.56211593747139, 50.4891599714756, 48.80827076733112, 45.96561670303345, 54.89827238023281, 54.65448126196861, 36.969120651483536, 0.9035737614613026, 3.8968025241047144, 6.646923953667283, 4.5016654673963785, 0.1556854834780097, 12.89399441331625, 62.37099699676037, 50.201929584145546, 53.147968500852585, 24.64474607259035, 22.880903519690037, 28.73370286077261, 46.67096145451069, 6.040163962170482, 0.145780454040505, 0.03132431309495587, 0.023811763676349074, 0.05599043346592225, 0.024113682338793296, 0.0004821220619533051, 0.027592219412326813, 0.026352827226219233, 0.03139965592708904, 0.009704685744509334, 0.034292258133064024, 0.02140213819075143, 0.060627112397924066, 0.04418015880219173, 0.010220359636150533, 0.10351532939239405, 0.016400114800489973, 0.07408781588310376, 0.030932778245187365, 0.043293860071571544, 0.06741827572113834, 0.03240140686102677, 0.06466585036832839, 0.040236790518974885, 0.05111759572173469, 0.613213173346594, 36.36414371430874, 54.12282519042492, 27.624054104089737, 25.35116996616125, 40.857007429003716, 48.53790767490864, 58.241956159472466, 51.53539203107357, 56.70944519340992, 44.6127524971962, 2.3085715854540467, 1.8075487576425076, 7.906900718808174, 15.025840569287539, 1.7892482271417975, 49.70532663166523, 52.54288136959076, 56.902683824300766, 49.87964987754822, 53.86800706386566, 56.44837640225887, 50.9279528260231, 46.798060834407806, 50.78558586537838, 51.30782224237919, 56.15824677050114, 52.26360395550728, 51.933378875255585, 53.692665472626686, 52.031360417604446, 50.61253935098648, 51.96995951235294, 52.385926991701126, 52.01334938406944, 50.62108129262924, 50.8373998850584, 52.578310668468475, 50.82884654402733, 50.281865894794464, 51.80541314184666, 50.10784663259983, 47.75983862578869, 45.701481476426125, 42.277530804276466, 37.06543408334255, 39.19151119887829, 40.43739214539528, 39.2901387065649, 40.779392793774605, 38.660455495119095, 39.98540259897709, 41.05153799057007, 41.04560650885105, 40.26328548789024, 38.543756157159805, 41.27569556236267, 39.64717134833336, 39.44858260452747, 40.44791378080845, 40.45930176973343, 39.08525750041008, 38.954232931137085, 39.68886651098728, 40.57390362024307, 40.280316174030304, 38.91556240618229, 37.93310612440109, 39.90462273359299, 43.1280467659235, 48.77202071249485, 49.43622127175331, 48.864610344171524, 52.80292421579361, 52.452659010887146, 49.525201097130775, 53.05647701025009, 50.897478461265564, 53.5044501721859, 49.52598385512829, 47.65358492732048, 39.76498782634735, 41.19898147881031, 37.81894125044346, 38.52284587919712, 40.08650757372379, 39.61841829121113, 40.01133620738983, 40.38292206823826, 38.715989515185356, 41.352094262838364, 39.275030717253685, 38.94555799663067, 40.74672594666481, 42.61889308691025, 39.731591418385506, 39.34963211417198, 39.007639065384865, 40.30748851597309, 40.388956144452095, 37.21274837851524, 36.399010643363, 37.59454049170017, 37.220724150538445, 38.108797296881676, 37.7677845954895, 36.25269569456577, 37.83114619553089, 36.50326564908028, 36.92782446742058, 38.93695525825024, 36.997049152851105, 37.75545045733452, 38.47038969397545, 41.898018568754196, 42.770653143525124, 43.935602232813835, 42.10813969373703, 42.80164048075676, 44.754876270890236, 45.2998848259449, 46.089113876223564, 47.90338732302189, 44.857846945524216, 50.06739780306816, 48.70660342276096, 55.32389514148235, 50.19373722374439, 51.9453140348196, 50.139236748218536, 55.43539635837078, 52.07407012581825, 52.60500803589821, 46.97819396853447, 59.05057556927204, 55.07614843547344, 40.1771555095911, 1.3710753223858774, 5.186464246362448, 3.9629792980849743, 4.018445396795869, 0.25224747543688864, 13.560183215886354, 70.8802641928196, 54.30626034736633, 56.3762828707695, 33.86263534426689, 25.86428113281727, 28.52671466767788, 55.65902195870876, 8.787593711167574, 0.04556295803922694, 0.03940475020499434, 0.02302400545886485, 0.08633803940028884, 0.021633541691699065, 0.10209460640908219, 0.03957146254833788, 0.02643699790496612, 0.09621186152799055, 0.0324448670289712, 0.01710411423118785, 0.10075269950903021, 0.14085217786487192, 0.2222071631695144, 0.10822569616721012, 0.16020850249333307, 0.10103971770149656, 0.15461076458450407, 0.08337214268976822, 0.10009493402321823, 0.2058473785291426, 0.18757120531518012, 0.178033746778965, 0.21033303783042356, 0.1823321176925674, 0.8849019196350127, 40.863755866885185, 63.85305047035217, 38.24254631996155, 30.910499654710293, 45.671888664364815, 58.05810682475567, 63.062609285116196, 54.63209666311741, 62.36232966184616, 50.44147253036499, 4.735519168898463, 4.319265754893422, 15.374828092753887, 24.00420304387808, 2.5228420877829194, 53.33392292261124, 52.12484300136566, 58.00457529723644, 50.00688225030899, 56.64226099848747, 57.08666235208511, 52.287808656692505, 50.049933940172195, 53.200405687093735, 54.00924928486347, 57.888065949082375, 53.006407096982, 53.495691642165184, 54.76822815835476, 55.04339799284935, 50.80037847161293, 54.175866544246674, 54.182934165000916, 52.83948205411434, 53.37270364165306, 54.40052568912506, 54.70226749777794, 53.268004059791565, 53.08893486857414, 53.40275622904301, 52.811306565999985, 49.02210429310799, 47.731632739305496, 43.96877445280552, 41.051135212183, 41.63415692746639, 42.240775376558304, 41.06965161859989, 43.97426515817642, 41.52046322822571, 42.16272756457329, 41.85262620449066, 43.183121010661125, 42.613265588879585, 40.70236712694168, 44.14002746343613, 43.01671274006367, 39.867722913622856, 41.40113443136215, 42.50757046043873, 40.57207211852074, 40.17618656158447, 41.104222163558006, 42.195208221673965, 43.21650601923466, 40.694790333509445, 41.31270557641983, 41.68723627924919, 44.71278972923756, 52.49657325446606, 52.8680033236742, 50.73215313255787, 55.40080301463604, 55.51163166761398, 51.049413308501244, 52.32650198042393, 52.05485075712204, 57.76637747883797, 52.067777663469315, 49.789366722106934, 42.0606080442667, 42.13447608053684, 40.71845166385174, 39.97489236295223, 43.66278827190399, 41.13213546574116, 42.300185188651085, 42.535187378525734, 39.71067354083061, 42.766667157411575, 40.9368297457695, 40.46896085143089, 42.38611377775669, 44.891315549612045, 41.569837778806686, 39.99258801341057, 39.89573121070862, 42.33447454869747, 41.80124916136265, 37.70776301622391, 38.600566908717155, 39.01466868817806, 40.19110456109047, 39.09889496862888, 40.29498338699341, 39.18902613222599, 40.471423119306564, 38.878692984580994, 40.852375477552414, 40.71560941636562, 39.00885500013828, 40.29168516397476, 40.3619509935379, 44.081654995679855, 43.996820747852325, 45.47942899167538, 43.53068456053734, 45.77336221933365, 46.77037172019482, 46.552115231752396, 47.77572177350521, 48.66350993514061, 47.23945654928684, 52.591180577874184, 51.51513151824474, 58.118626177310944, 52.3123325407505, 53.149932995438576, 50.73293209075928, 58.69826227426529, 55.40920436382294, 54.62910622358322, 49.562845677137375, 61.59210719168186, 57.52345651388168, 44.91267040371895, 1.6927980026230216, 6.5373900812119246, 16.241588182747364, 13.116870503872633, 0.30851265939418226, 15.282946173101664, 74.63683381676674, 58.46921816468239, 60.405860245227814, 37.13183552026749, 33.637033849954605, 37.872902154922485, 64.76732701063156, 12.056706491857767, 0.23436382412910461, 0.13322969782166183, 0.11865806605783291, 0.18794385250657797, 0.17018964659655467, 0.23427519685355946, 0.20412777783349156, 0.08341485328855924, 0.2712123468518257, 0.14090855140239, 0.24220011691795662], [0.053995425478206016, 0.05188028604607098, 0.03354883396241348, 0.025545444768795278, 0.004461733851712779, 0.04253468010574579, 0.022986988988122903, 0.013628990109282313, 0.05267733409709763, 0.03265708786784671, 0.024318132891494315, 0.03961039190471638, 0.048334953826270066, 0.05274251692753751, 0.05925581273913849, 8.74427318572998, 47.6854158192873, 40.104792192578316, 32.076959162950516, 34.04982469975948, 44.57260385155678, 52.89778612554073, 49.510769471526146, 52.46150493621826, 50.06317622959614, 8.884873241186142, 2.433161912485957, 5.538373813033104, 19.971333146095276, 0.7604903017636389, 31.839621998369694, 45.287258103489876, 56.11283540725708, 45.12804664671421, 47.48641289770603, 52.42060773074627, 53.88388641178608, 52.24110536277294, 49.69273790717125, 53.85591611266136, 52.715589702129364, 49.890752881765366, 52.30069376528263, 48.92209365963936, 49.03157718479633, 47.95175112783909, 52.143891379237175, 49.41470302641392, 50.3258865326643, 49.9616114795208, 52.037071511149406, 49.70033369958401, 50.406377613544464, 49.568872153759, 46.668685376644135, 45.71347363293171, 45.023886635899544, 38.97214896976948, 36.08124889433384, 35.521250143647194, 37.67850458621979, 37.32063218951225, 39.42505046725273, 38.540275543928146, 37.979250848293304, 39.0249889343977, 39.20280419290066, 39.91779662668705, 38.93267288804054, 38.79632480442524, 39.99449171125889, 39.43147212266922, 36.92852362990379, 38.50239537656307, 37.21002772450447, 35.98435789346695, 38.07613804936409, 38.904900178313255, 37.76320964097977, 38.7954318523407, 36.096269488334656, 35.11765480041504, 37.553449496626854, 41.37517422437668, 46.1700077354908, 47.48607471585274, 49.622202292084694, 52.30562970042229, 54.36319649219513, 45.96899092197418, 37.61964954435825, 52.637522891163826, 51.69893525540829, 46.21077574789524, 43.98375324904919, 36.6090177744627, 35.6821259111166, 37.08720691502094, 36.85318127274513, 38.764729499816895, 37.69687660038471, 38.49017523229122, 37.411891892552376, 37.99637272953987, 37.98450216650963, 37.891030982136726, 39.063344076275826, 39.43555310368538, 40.712858363986015, 38.74695785343647, 37.69931226968765, 35.455342680215836, 39.56682845950127, 34.761119931936264, 35.53035445511341, 35.843917429447174, 37.11882121860981, 36.77223801612854, 36.58871926367283, 34.781760424375534, 37.4174851924181, 36.15176171064377, 35.559624284505844, 35.676023438572884, 35.17174489796162, 35.732921585440636, 36.60153217613697, 35.65952852368355, 36.96931064128876, 35.48507608473301, 36.24608784914017, 35.34701429307461, 37.66094572842121, 36.01034089922905, 39.48838546872139, 39.933691173791885, 41.75544261932373, 40.92091999948025, 43.047057911753654, 46.974656358361244, 48.90334166586399, 53.44252109527588, 52.7837960422039, 48.116092309355736, 51.41156047582626, 51.79775655269623, 50.36169961094856, 50.74736751616001, 54.019010961055756, 56.726635470986366, 25.990605354309082, 0.21598673367407173, 4.9702411238104105, 3.879442918114364, 1.5662054205313325, 0.28552819741889834, 25.520247593522072, 55.58643065392971, 52.701861038804054, 46.39220841228962, 29.290847964584827, 30.65492156893015, 38.177011236548424, 36.49199925363064, 1.632325672544539, 0.19761175091844052, 0.08981781400507316, 0.010551290706644068, 0.05243339386652224, 0.03624252574809361, 0.06037909035512712, 0.02548154028772842, 0.046897421198082156, 0.027710797912732232, 0.06671507595456205, 0.06422284015570767, 0.06355948629789054, 0.02462313146679662, 0.05895248214073945, 0.02360460057388991, 0.06449494117987342, 0.07001880570896901, 0.033368057920597494, 0.04601855507644359, 0.010704981141316239, 0.06309445656370372, 0.009989665813918691, 0.04477391776163131, 0.10330419579986483, 0.07710437901550904, 0.036103384190937504, 13.326477706432343, 58.2515012472868, 40.39152480661869, 31.77223451435566, 44.68729309737682, 50.2558296918869, 54.82164949178696, 51.99210472404957, 58.194508105516434, 53.660678789019585, 8.574131615459919, 2.6245802035555243, 9.238189682364464, 29.071424938738346, 1.0781694645993412, 35.49634627997875, 44.34228301048279, 57.375614047050476, 46.30061812698841, 49.00365248322487, 52.63075925409794, 56.23973719775677, 54.952993243932724, 51.77613191306591, 55.54943963885307, 54.0578942745924, 52.196868136525154, 54.708438366651535, 51.99908494949341, 52.57127344608307, 51.5378163009882, 53.60131077468395, 51.67297504842281, 53.66053059697151, 51.66080430150032, 55.082102715969086, 51.89452975988388, 53.141657039523125, 52.304546758532524, 49.3292798101902, 48.575206473469734, 47.93579958379269, 41.34751930832863, 39.02979947626591, 37.294934168457985, 39.58497628569603, 38.401339799165726, 38.797297552227974, 41.8158707767725, 39.31888036429882, 39.733168333768845, 40.20985655486584, 40.916390642523766, 41.46808683872223, 39.795382395386696, 42.14903309941292, 41.00764274597168, 38.774076998233795, 40.293934643268585, 40.01002907752991, 39.67753931879997, 40.398037657141685, 41.280509904026985, 39.67286936938763, 41.841378808021545, 39.13129203021526, 37.30088844895363, 39.47847560048103, 44.826358035206795, 47.416682839393616, 49.27810035645962, 51.963872238993645, 53.08171145617962, 54.19605106115341, 51.47800751030445, 42.90744200348854, 52.42980323731899, 54.88473750650883, 48.6193373054266, 45.997219607234, 38.5144255310297, 36.703530102968216, 38.58947150409222, 39.01237741112709, 39.79382827877998, 40.29397264122963, 39.64333735406399, 40.35628169775009, 39.41263273358345, 39.926642552018166, 39.52213145792484, 41.06380373239517, 41.615431532263756, 40.75604684650898, 40.90589940547943, 38.673952370882034, 36.64282836019993, 40.59842750430107, 37.4956090003252, 37.29602091014385, 37.365344390273094, 38.542289435863495, 39.029856473207474, 38.40133599936962, 37.34481409192085, 39.18882854282856, 37.38834075629711, 37.96616055071354, 38.45121972262859, 37.144713029265404, 37.986421063542366, 37.99094282090664, 37.945345267653465, 38.79444770514965, 37.31161147356033, 38.537049517035484, 37.62870065867901, 39.99976962804794, 37.57159352302551, 39.336359426379204, 43.05791772902012, 44.015420749783516, 43.474120795726776, 46.15811437368393, 49.27832834422588, 51.38493150472641, 56.62184089422226, 52.212853878736496, 50.0483950227499, 54.08761627972126, 54.60200987756252, 53.062328696250916, 53.23533721268177, 57.11732670664787, 58.70509810745716, 29.217544198036194, 0.1366090524243191, 4.637265466153622, 5.076772207394242, 1.225932848174125, 0.026302311089239083, 25.528814233839512, 63.00170995295048, 56.8704729527235, 56.546357944607735, 33.09514492750168, 25.958863757550716, 41.831833720207214, 44.79008898139, 2.710907058790326, 0.13128350459737703, 0.07769472780637443, 0.07745871000224724, 0.03288723157311324, 0.06864744296763092, 0.013979238356114365, 0.010990580904035596, 0.021093182112963405, 0.08417391451075673, 0.08803190983599052, 0.0648934299533721, 0.15111182030523196, 0.1300633544451557, 0.22143768961541355, 0.08397140467423014, 0.19836360588669777, 0.13481553382007405, 0.09429100522538647, 0.11322095859213732, 0.10676206962671131, 0.15307591413147748, 0.11105669269454665, 0.14329385856399313, 0.16323361516697332, 0.2772381703834981, 0.1598356178146787, 16.599390283226967, 66.7378480732441, 51.04758560657501, 43.334755674004555, 45.40163956582546, 54.24163341522217, 64.34690237045288, 60.342969819903374, 63.23810666799545, 60.52276477217674, 11.319188866764307, 4.264188185334206, 10.914054606109858, 30.850371681153774, 4.061619630083442, 39.664498418569565, 44.651784002780914, 58.208563551306725, 45.37123739719391, 50.70934295654297, 56.30155988037586, 60.17067186534405, 58.22486847639084, 53.01505923271179, 57.47487612068653, 54.962511733174324, 52.60549820959568, 56.74148507416248, 53.755502700805664, 53.4536848962307, 51.142713502049446, 57.51444719731808, 54.918126314878464, 55.56449443101883, 53.132070153951645, 57.83456102013588, 52.73823268711567, 55.11008821427822, 56.091788336634636, 51.611612141132355, 49.95964698493481, 49.535232558846474, 42.97498717904091, 40.77236697077751, 38.97605136036873, 40.948400124907494, 40.30515544116497, 42.65603989362717, 43.48502621054649, 41.43345929682255, 43.24613682925701, 43.11927683651447, 44.23660688102245, 45.694664642214775, 41.899869069457054, 44.77024644613266, 44.76388178765774, 39.27074454724789, 41.7001897841692, 40.68477787077427, 40.25069676339626, 42.76504844427109, 42.63979956507683, 42.39014156162739, 43.94878752529621, 40.3987368196249, 38.88475365936756, 43.26635554432869, 46.03196494281292, 50.96253477036953, 51.79959185421467, 53.80119524896145, 53.79657469689846, 59.457993507385254, 48.30850638449192, 42.23381035029888, 56.89152002334595, 56.680053770542145, 50.88254526257515, 47.91192166507244, 39.77194905281067, 37.79524952173233, 40.91594606637955, 41.340425089001656, 43.189706057310104, 42.03921899199486, 41.576517820358276, 40.7998812943697, 42.34708607196808, 41.554813385009766, 40.82635447382927, 43.834174275398254, 42.66779266297817, 43.34090754389763, 42.33332701027393, 41.908103227615356, 38.32347817718983, 42.33980946242809, 37.97781452536583, 36.69293627142906, 39.058411940932274, 40.84436170756817, 40.25686763226986, 40.178838819265366, 38.73196765780449, 42.69033305346966, 39.51064467430115, 38.872932493686676, 39.475732147693634, 37.897486835718155, 39.85553316771984, 39.1033711284399, 38.929682448506355, 40.45556657016277, 39.17101889848709, 38.74016001820564, 38.79246041178703, 41.98655761778355, 40.12629143893719, 42.08053797483444, 45.209385082125664, 45.75453422963619, 46.67998977005482, 47.418833523988724, 50.951914340257645, 53.782644644379616, 60.206659734249115, 54.98550049960613, 50.507471188902855, 53.21047514677048, 56.55877187848091, 55.094003677368164, 55.534160658717155, 60.126328244805336, 60.73781043291092, 30.68233709782362, 0.32604331558104604, 8.769330941140652, 12.853646278381348, 5.446776878088713, 0.5294596112798899, 32.23495468497276, 68.27031344175339, 60.836327746510506, 58.219282776117325, 41.93012684583664, 41.15097105503082, 49.06343087553978, 52.98861265182495, 3.778540757484734, 0.41108150559011847, 0.2182272626669146, 0.16191915288800374, 0.21292092162184417, 0.3067473869305104, 0.123144452663837, 0.14777871634578332, 0.2078815014101565, 0.16074647050118074, 0.14662751171272248, 0.20948485209373757], [0.059011256525991485, 0.03777830017497763, 0.033860127805382945, 0.014784467657591449, 0.017006991220114287, 0.09635466558393091, 0.05136541367392056, 0.043462464891490526, 0.040412312155240215, 0.10845450771739706, 0.038072739844210446, 0.022405321469705086, 0.01906613561004633, 0.07434427985572256, 0.07194093108410016, 2.0644676964730024, 32.88954176008701, 44.351045340299606, 26.991218961775303, 20.082311891019344, 39.466069266200066, 52.41870403289795, 53.756034672260284, 45.69111183285713, 53.97268384695053, 15.353421941399574, 0.30297656427137554, 2.338913669809699, 4.725997829809785, 31.595813781023026, 26.36654768139124, 38.490855395793915, 53.78347299993038, 52.21215471625328, 44.46001969277859, 49.35019388794899, 51.792463436722755, 51.87016926705837, 51.350224167108536, 53.203149139881134, 51.76168888807297, 51.38377636671066, 48.89716699719429, 48.200102001428604, 47.337635681033134, 47.602918446063995, 49.89377751946449, 51.43180578947067, 49.587928131222725, 50.43447710573673, 49.37947131693363, 50.896528512239456, 51.72007352113724, 50.510704815387726, 48.12078885734081, 45.89479610323906, 39.53468598425388, 37.86667048931122, 36.41663409769535, 36.09849616885185, 38.015747889876366, 40.588510036468506, 39.73101764917374, 41.27387925982475, 38.106061443686485, 40.12477532029152, 38.528963550925255, 39.74403575062752, 38.16776633262634, 37.739248126745224, 40.19793279469013, 38.09743210673332, 38.28573100268841, 39.468736723065376, 37.99652852118015, 37.85073794424534, 36.72319404780865, 39.33414414525032, 38.70262183248997, 39.331248700618744, 36.45803667604923, 35.99717080593109, 36.05181947350502, 39.349985495209694, 44.21650975942612, 45.26640862226486, 48.5994453728199, 53.19724425673485, 50.01996874809265, 39.11033995449543, 44.22276422381401, 51.892603263258934, 48.87327387928963, 46.16527698934078, 43.768669590353966, 37.45611771941185, 37.44187988340855, 36.79970294237137, 37.07791641354561, 37.29444779455662, 36.655234694480896, 37.089027017354965, 38.75889301300049, 36.379825472831726, 38.06018650531769, 37.82159350812435, 37.353040650486946, 37.79278725385666, 37.17481501400471, 37.73578651249409, 37.170954421162605, 36.44370764493942, 38.212797716259956, 36.731226816773415, 35.70240922272205, 36.00571274757385, 34.896343275904655, 35.65464958548546, 35.626382902264595, 35.456843599677086, 35.528754740953445, 34.716392531991005, 35.14752119779587, 35.797054544091225, 37.70362123847008, 36.131512597203255, 36.59287244081497, 36.69590771198273, 35.897889733314514, 35.43099358677864, 35.419301614165306, 35.79046569764614, 35.73614381253719, 35.27429759502411, 35.63118204474449, 36.576453521847725, 36.3780053704977, 36.71006195247173, 40.186392813920975, 42.50413924455643, 48.340143486857414, 47.722653821110725, 51.108085960149765, 50.832479149103165, 51.21347330510616, 56.10262915492058, 53.86858843266964, 53.76664750277996, 55.66032528877258, 50.05059510469437, 8.458994943648577, 0.42900208616629243, 2.2505498863756657, 7.3418506141752005, 0.43919542513322085, 0.25384537875652313, 36.01686894893646, 56.798117235302925, 52.701853439211845, 35.745620504021645, 32.08670184016228, 32.10154004395008, 45.86889289319515, 24.222763516008854, 0.5362478876486421, 0.11760762281483039, 0.06976038988796063, 0.012913578302686801, 0.015762878974783234, 0.046318468084791675, 0.006876869783809525, 0.019572118908399716, 0.045218746236059815, 0.0267727436585119, 0.038086603162810206, 0.005690491989298607, 0.0998630870890338, 0.036087409462197684, 0.09846299581113271, 0.07213283563032746, 0.048123248780029826, 0.09202933244523592, 0.0868996225472074, 0.07639779505552724, 0.03094872328802012, 0.046377509643207304, 0.04055602905282285, 0.03794875665334985, 0.04142226382100489, 0.05992919301206712, 0.04490178980631754, 3.415140132419765, 44.80122238397598, 49.04112607240677, 28.18296041339636, 30.70714596658945, 47.21282757818699, 56.25016763806343, 59.496960416436195, 49.206151217222214, 59.07404690980911, 16.08620312064886, 0.5282294272910804, 4.365038573741913, 8.382728286087513, 33.270752504467964, 29.00341048836708, 41.34279616177082, 53.676337748765945, 54.055291414260864, 46.58483907580376, 52.02813819050789, 54.263102263212204, 53.577345460653305, 53.64529341459274, 53.0099219083786, 52.33412057161331, 53.999442011117935, 51.375135630369186, 48.50036568939686, 48.20332422852516, 50.85258387029171, 51.94293536245823, 52.91678510606289, 51.971247643232346, 51.6548690199852, 52.69959636032581, 53.30387033522129, 53.70330110192299, 50.69643124938011, 50.82954950630665, 48.892850428819656, 42.65650346875191, 40.347982943058014, 40.00329203903675, 37.64922335743904, 39.2671537399292, 42.47662112116814, 40.72833113372326, 42.19906881451607, 40.40367275476456, 39.963686764240265, 40.436719581484795, 42.060216665267944, 39.56216610968113, 40.06099954247475, 40.95191493630409, 42.11364559829235, 39.4347969442606, 40.37787213921547, 39.544326066970825, 39.7954697906971, 38.37716169655323, 41.00043833255768, 40.1197861880064, 40.17693892121315, 39.98410686850548, 38.54301519691944, 37.310190349817276, 41.99779361486435, 46.19195535778999, 46.24908909201622, 49.92784269154072, 55.02916395664215, 52.810869589447975, 43.04062105715275, 45.19692935049534, 54.32677924633026, 50.47352381050587, 48.4952549636364, 44.40271116793156, 39.20785032212734, 39.55975703895092, 39.06483359634876, 38.40040124952793, 39.057298600673676, 38.028576001524925, 39.05587747693062, 39.77850750088692, 38.735273480415344, 38.87808121740818, 39.63410384953022, 38.710662201046944, 39.728916361927986, 40.70923715829849, 39.25531357526779, 38.227510526776314, 39.65194769203663, 39.79896940290928, 38.33118416368961, 37.53108009696007, 37.2501003742218, 36.9514250010252, 38.16110149025917, 37.21950821578503, 38.24128098785877, 37.28734217584133, 37.79245667159557, 36.71407833695412, 39.21159692108631, 37.563936933875084, 37.32054479420185, 36.926270350813866, 38.41962821781635, 36.52357175946236, 36.9294697791338, 35.82101225852966, 37.66577526926994, 37.09095351397991, 36.31318464875221, 36.96363754570484, 39.0852764993906, 38.220420107245445, 39.85197655856609, 43.010108694434166, 44.976560175418854, 50.88234007358551, 51.56851105391979, 53.2507985830307, 51.070543974637985, 49.89718593657017, 56.268684044480324, 56.339474245905876, 57.574138194322586, 54.31020453572273, 52.603727504611015, 9.357641022652388, 1.5210590930655599, 6.916471514850855, 5.661173723638058, 1.1536588263697922, 0.5445012229029089, 41.232541278004646, 62.626518085598946, 54.543143436312675, 43.63155774772167, 36.49616003036499, 32.125725746154785, 50.68880505859852, 30.229813680052757, 0.5584016488865018, 0.08958027479820885, 0.06512284264317714, 0.021084332001919392, 0.024774501762294676, 0.06047723196388688, 0.013169729645596817, 0.045461012923624367, 0.03893593551765662, 0.06916935832123272, 0.008968381553131621, 0.06149099826870952, 0.26842148567084223, 0.09151966994977556, 0.15201850212179124, 0.12915483210235834, 0.13850333984009922, 0.2342862548539415, 0.1291833454160951, 0.1443579202168621, 0.11748424818506464, 0.14212401118129492, 0.12578717374708503, 0.1099160933517851, 0.1613697558059357, 0.16258882242254913, 0.1386609423207119, 3.9388266066089272, 54.40179482102394, 59.406981244683266, 34.459085538983345, 30.04163447767496, 53.33599381148815, 61.19541987776756, 64.14903178811073, 53.24630342423916, 61.069734022021294, 19.332298636436462, 0.5767018825281411, 6.849525757133961, 8.317534234374762, 41.38566926121712, 35.73106728494167, 40.70891037583351, 55.646760016679764, 53.303471356630325, 47.39224635064602, 52.368774712085724, 54.00381937623024, 57.15978182852268, 55.61970166862011, 54.6341485530138, 53.66359323263168, 56.556640192866325, 52.34631411731243, 51.40827365219593, 50.37224404513836, 52.18176394701004, 53.56306962668896, 55.207188203930855, 51.65933758020401, 54.70888294279575, 55.15853941440582, 54.594851061701775, 56.38061843812466, 54.699725434184074, 54.11632753908634, 51.30651891231537, 43.861460611224174, 43.56544889509678, 42.4673268198967, 40.33329673111439, 41.633814945816994, 45.09954057633877, 43.662636280059814, 45.00359192490578, 41.36977471411228, 44.3276309967041, 42.746326848864555, 43.46232242882252, 42.3843202739954, 41.35949246585369, 44.03975084424019, 42.8420665115118, 41.60192705690861, 44.970731288194656, 41.8312181532383, 42.256099954247475, 39.06880058348179, 42.57605418562889, 41.328273341059685, 42.839554846286774, 42.01832011342049, 40.802563950419426, 39.919137954711914, 43.21104571223259, 47.30006329715252, 49.52103652060032, 53.23977917432785, 58.942847549915314, 53.658072128891945, 45.42027376592159, 50.30175022780895, 52.89711356163025, 52.673168778419495, 50.934815257787704, 46.66591912508011, 41.96908615529537, 42.84640967845917, 40.212683603167534, 40.744696855545044, 40.30677795410156, 39.643496945500374, 41.12881824374199, 40.259660482406616, 39.64025191962719, 40.12299321591854, 40.71254298090935, 42.09666050970554, 40.858755335211754, 40.716973543167114, 40.82387700676918, 40.391152426600456, 41.181912794709206, 42.661560997366905, 40.751137509942055, 40.6002552062273, 39.5292142778635, 38.74075658619404, 39.51401889324188, 39.002433344721794, 39.81816217303276, 39.58157166838646, 40.306823551654816, 40.02041012048721, 41.96262650191784, 40.053160563111305, 39.8539562523365, 40.85809797048569, 40.68166583776474, 38.3310853689909, 38.50467525422573, 38.37548218667507, 39.84566509723663, 38.501403629779816, 37.68800027668476, 38.916048780083656, 40.93879044055939, 39.506818279623985, 39.644192308187485, 44.78812448680401, 46.692464500665665, 53.10490541160107, 52.57238298654556, 55.710672587156296, 51.778932362794876, 50.88805116713047, 58.873835653066635, 60.222626477479935, 59.79840584099293, 57.26075001060963, 54.629949778318405, 12.043191567063332, 1.5205581136979163, 5.681524481624365, 18.317399695515633, 5.399837046861649, 0.6338471348863095, 44.902281761169434, 70.00245809555054, 58.725449815392494, 48.445344641804695, 45.91675512492657, 41.44037872552872, 58.301141783595085, 35.41401609778404, 0.8985256729647517, 0.21686444204533473, 0.10410380797111429, 0.18170000083046034, 0.18325781333260238, 0.16839667718159035, 0.08664420500281267, 0.15328551147831604, 0.12643441557884216, 0.16487150540342554, 0.11768317344831303, 0.15170991711784154], [0.019828007716569118, 0.03360541901201941, 0.05323326950019691, 0.04081498664163519, 0.042594586266204715, 0.03611184838518966, 0.09763363093952648, 0.012230117808940122, 0.07684197786147706, 0.033667084062471986, 0.04021663007733878, 0.044756826100638136, 0.06904408379341476, 0.06811081082560122, 0.07632654887856916, 0.07094122847774997, 18.17153312265873, 49.40176472067833, 27.733856812119484, 25.846042111516, 37.8671682626009, 48.62931177020073, 57.28743597865105, 48.214199244976044, 53.114336505532265, 25.03038927912712, 0.19475230044918135, 8.159831296652555, 0.9776664606761187, 8.733781948685646, 17.979770712554455, 40.0333484262228, 50.02160646021366, 53.29171098768711, 52.061971575021744, 43.275741040706635, 50.115499421954155, 50.41830897331238, 51.38562686741352, 51.83148354291916, 51.925422102212906, 51.160747334361076, 49.38460484147072, 46.94782219827175, 46.574537828564644, 48.064057901501656, 49.624166786670685, 49.71312001347542, 51.46139860153198, 50.97514629364014, 50.39249315857887, 49.66475620865822, 49.907988756895065, 49.99527387320995, 48.09661075472832, 43.212550431489944, 37.27091185748577, 38.5317450016737, 37.7692399173975, 36.77092708647251, 40.707189068198204, 41.69387452304363, 42.29883626103401, 39.51531462371349, 38.692552372813225, 38.11980530619621, 40.82880534231663, 39.548638835549355, 39.305934458971024, 38.84606413543224, 38.78663532435894, 39.52831752598286, 38.83097894489765, 36.698898151516914, 39.803871139883995, 38.27438481152058, 37.69644342362881, 38.764687702059746, 38.28611098229885, 39.72102038562298, 37.71935619413853, 36.296043768525124, 34.405652806162834, 38.96861135959625, 42.34764464199543, 45.090037286281586, 45.36644585430622, 51.852754801511765, 49.604024067521095, 51.00535847246647, 50.12322820723057, 50.92199094593525, 49.34165574610233, 45.88748909533024, 41.69090308248997, 40.48165217041969, 39.25024464726448, 39.098621383309364, 39.18718323111534, 40.9900838881731, 38.71600851416588, 38.356156423687935, 37.99098081886768, 37.25103132426739, 37.8954691439867, 38.36539752781391, 37.51675486564636, 35.5695341527462, 37.63159990310669, 38.19502606987953, 37.94865868985653, 37.126010432839394, 37.334775030612946, 36.99903644621372, 34.81489084661007, 34.77763004601002, 36.2252801656723, 36.033652648329735, 35.64579986035824, 36.1878901720047, 35.57008892297745, 36.05314940214157, 35.50808385014534, 35.41806288063526, 36.11591823399067, 37.756081223487854, 36.53478115797043, 36.19956314563751, 39.005564376711845, 40.145670399069786, 42.89741814136505, 43.19309547543526, 42.575165033340454, 41.4307614415884, 41.60758875310421, 39.13491703569889, 38.31190399825573, 35.84160715341568, 39.024563357234, 38.44321735203266, 46.65763556957245, 48.09748090803623, 50.78081712126732, 51.733859181404114, 50.01496061682701, 52.56324827671051, 53.40994544327259, 51.740721613168716, 56.747488752007484, 26.83598019182682, 1.386849582195282, 2.9912078054621816, 6.1828116327524185, 3.4926203498616815, 0.717555396258831, 0.8677827101200819, 48.333463445305824, 51.309019178152084, 52.00193099677563, 32.58110471069813, 23.208037465810776, 27.43940681219101, 43.717045560479164, 10.351810175925493, 0.030506295661325566, 0.03088131586991949, 0.01740220897772815, 0.01715856560622342, 0.05654230189975351, 0.034740949486149475, 0.01994885904423427, 0.10203518264461309, 0.035767569788731635, 0.021881496941205114, 0.0425455228833016, 0.07834097516024485, 0.03803602579864673, 0.038068884387030266, 0.046379565392271616, 0.06584896735148504, 0.093016707978677, 0.06951630493858829, 0.023738645431876648, 0.03840714416583069, 0.09560978680383414, 0.055943444385775365, 0.0408381787565304, 0.015111052525753621, 0.06357283753459342, 0.015610562440997455, 0.07059392562950961, 0.1363079037400894, 25.256982520222664, 57.238008230924606, 24.90968495607376, 24.568729251623154, 50.69163590669632, 52.42765635251999, 63.07031147181988, 51.13018177449703, 58.833223432302475, 26.76164288073778, 0.1842843074700795, 7.026185877621174, 3.47172147128731, 13.44721432775259, 20.0429555028677, 42.35206380486488, 51.63074031472206, 51.154382675886154, 54.55047704279423, 45.44993117451668, 50.96637636423111, 51.082300543785095, 51.85864448547363, 53.631925731897354, 56.07638396322727, 52.7535230666399, 51.65108822286129, 47.824089378118515, 47.832836508750916, 50.59655740857124, 52.556864619255066, 52.34241932630539, 52.66518160700798, 54.119177386164665, 52.53201775252819, 51.29319302737713, 53.10355268418789, 51.807605624198914, 49.52636003494263, 44.58087980747223, 40.53835652768612, 40.59564605355263, 39.47226673364639, 39.28812861442566, 41.82103469967842, 44.42692346870899, 43.04628275334835, 41.9959507137537, 39.69937674701214, 39.00320090353489, 40.722711235284805, 40.51031023263931, 40.039792880415916, 41.991941928863525, 41.06543384492397, 41.09274297952652, 41.37677013874054, 38.70595045387745, 39.40310284495354, 40.49193061888218, 39.070366099476814, 41.15531802177429, 40.07019504904747, 40.82743361592293, 38.604511097073555, 38.63998979330063, 38.10422994196415, 40.29013864696026, 43.5309961438179, 46.71331778168678, 48.16089570522308, 52.70183444023132, 53.3024226129055, 50.97009256482124, 53.12553070485592, 51.937057077884674, 50.894510820508, 45.84320247173309, 44.173640459775925, 42.51972980797291, 41.03344336152077, 40.1053811609745, 40.36174960434437, 42.172842621803284, 39.597690403461456, 39.504948779940605, 39.71655562520027, 38.30487437546253, 40.70193015038967, 39.57407467067242, 38.68508957326412, 37.6336669921875, 39.629194512963295, 40.16443379223347, 39.26579721271992, 38.55922132730484, 38.6382494866848, 38.468884974718094, 38.439694941043854, 38.02164897322655, 37.51144655048847, 38.26792895793915, 37.59613640606403, 37.90014289319515, 37.02612139284611, 37.413392812013626, 37.47998803853989, 36.75228908658028, 37.66005277633667, 38.82936403155327, 38.34325231611729, 37.5650654733181, 39.902228862047195, 41.775178760290146, 43.662757873535156, 44.61683727800846, 43.89934077858925, 43.85485276579857, 40.6294946372509, 40.969694182276726, 38.88261817395687, 38.14310945570469, 40.62092609703541, 40.93765810132027, 47.54773400723934, 50.02639040350914, 54.14380386471748, 53.625374883413315, 50.888982117176056, 52.90353521704674, 54.93795745074749, 53.30409072339535, 56.8945674598217, 30.894956588745117, 2.6622269209474325, 4.602569527924061, 3.772962181828916, 2.55895487498492, 0.27220721065532416, 0.9194516844581813, 50.59797093272209, 55.89659281075001, 56.86185881495476, 42.635851576924324, 28.6268487945199, 30.333853997290134, 51.035684645175934, 13.844663500785828, 0.13222640322055668, 0.0223428400568082, 0.055045030094333924, 0.07737269508652389, 0.024583877420809586, 0.08510689804097638, 0.0367597952572396, 0.06252028659218922, 0.02165888417948736, 0.06229965350939892, 0.018273495916218963, 0.05897426788578741, 0.1249267574166879, 0.09450633937376551, 0.0873916367709171, 0.18936144362669438, 0.2713426679838449, 0.13467678189044818, 0.11460528665338643, 0.06140720237453934, 0.21989161788951606, 0.10695380347897299, 0.20999632542952895, 0.15415524918353185, 0.19574124191422015, 0.08900751490727998, 0.16289607156068087, 0.1865109583013691, 31.599970757961273, 65.24480938911438, 36.01184941828251, 37.043706849217415, 52.85001128911972, 57.1656297147274, 68.31081166863441, 57.26422682404518, 64.88790974020958, 32.040549516677856, 0.24044119723839685, 17.89450328797102, 3.2339613419026136, 10.522150285542011, 23.838972710072994, 42.572858557105064, 49.62736241519451, 54.02601018548012, 52.073591351509094, 47.324473187327385, 52.50508099794388, 52.34898157417774, 52.55740039050579, 54.9249317497015, 57.292725294828415, 54.668589904904366, 53.348586335778236, 52.40616090595722, 50.54283209145069, 53.35791863501072, 54.14737567305565, 54.46383789181709, 54.63079713284969, 56.77172005176544, 53.44701245427132, 54.070220813155174, 55.00953420996666, 54.27846483886242, 52.83991903066635, 46.53864875435829, 41.353321596980095, 42.19323992729187, 42.13103726506233, 40.09610965847969, 43.78912389278412, 44.75297637283802, 44.96847040951252, 43.52674417197704, 42.39435933530331, 42.20297880470753, 44.2693193256855, 42.29417771100998, 42.70017832517624, 43.40587645769119, 42.79941380023956, 43.76848340034485, 43.756593838334084, 40.15644662082195, 42.51077748835087, 42.06627734005451, 41.28419190645218, 42.482450008392334, 41.773719638586044, 43.706147745251656, 41.8467403203249, 40.860419645905495, 39.35229577124119, 41.98084272444248, 45.011932477355, 50.57282768189907, 49.26698215305805, 54.78267878293991, 53.24612483382225, 56.22874818742275, 54.74458582699299, 56.148872673511505, 53.024923503398895, 49.43463295698166, 45.315289199352264, 46.7558678984642, 43.20837065577507, 44.08882901072502, 43.832631558179855, 45.23298181593418, 41.42631947994232, 41.05234354734421, 41.66763313114643, 40.06437376141548, 42.01333098113537, 41.48760639131069, 40.909288823604584, 39.09558154642582, 41.19549326598644, 41.81019388139248, 41.460836827754974, 41.429769694805145, 39.43139612674713, 42.278336361050606, 38.930309414863586, 39.05653104186058, 39.81277406215668, 39.32382769882679, 38.41284938156605, 39.60642993450165, 39.47535216808319, 40.749697387218475, 39.80277679860592, 40.59173606336117, 39.97493036091328, 41.79257422685623, 39.31030422449112, 39.86058309674263, 42.04357735812664, 44.310414120554924, 47.284221947193146, 48.25244419276714, 46.59457415342331, 47.17917658388615, 44.028112068772316, 43.986230716109276, 41.33447080850601, 40.41713543236256, 43.239331394433975, 42.46331803500652, 50.93418449163437, 52.60830245912075, 55.77278785407543, 55.75531259179115, 50.98629869520664, 52.81219191849232, 55.86703039705753, 54.730047807097435, 57.632955238223076, 33.78969445824623, 3.6927741346880794, 4.27515534684062, 13.843809496611357, 12.930047828704119, 6.040201960131526, 1.4188678516075015, 56.67729511857033, 61.00267142057419, 60.33451907336712, 44.31933604180813, 34.93014246225357, 37.57803797721863, 58.11552554368973, 18.613988980650902, 0.237465392856393, 0.14932409045286477, 0.145033675362356, 0.12517479801317677, 0.11358136776834726, 0.15380798344267532, 0.09958461843780242, 0.19214626372558996, 0.0682231126120314, 0.1372299183276482, 0.15072296460857615, 0.21639964979840443], [0.06641249492531642, 0.0008177467816494755, 0.03881356278725434, 0.039835759889683686, 0.018623266405484173, 0.06213077409483958, 0.03569446082110517, 0.030337139796756674, 0.04933859352604486, 0.06329936353722587, 0.03433134334045462, 0.05972105769615155, 0.03015339887497248, 0.0786046453868039, 0.08438561955699697, 0.10722668375819921, 5.614820010960102, 38.25925022363663, 44.00459133088589, 25.314367040991783, 26.319090127944946, 45.92095009982586, 54.97291937470436, 50.55594898760319, 50.36594018340111, 32.41056986153126, 0.33327777113299817, 4.4739483296871185, 4.450139282271266, 0.08554701387765817, 4.219110254198313, 47.438524067401886, 55.754567831754684, 52.5476349145174, 54.88587744534016, 52.17586666345596, 47.61285871267319, 52.23085731267929, 53.29644553363323, 54.1997292637825, 50.17198719084263, 49.208054915070534, 47.18491427600384, 46.294508054852486, 47.140707448124886, 48.40834982693195, 48.88717733323574, 49.08322021365166, 50.294325426220894, 52.14905150234699, 50.58564059436321, 49.87057976424694, 47.45341546833515, 50.704718604683876, 46.39996759593487, 39.23721134662628, 37.385882288217545, 38.36689464747906, 39.2789027094841, 42.9080917686224, 42.44898900389671, 40.214005932211876, 38.02480660378933, 36.58358573913574, 37.87565320730209, 37.08770468831062, 39.176699593663216, 39.95327912271023, 38.30343805253506, 40.02686597406864, 38.820168524980545, 37.01347567141056, 38.85394871234894, 40.39898760616779, 38.24959494173527, 38.662590980529785, 38.021398186683655, 38.92192706465721, 38.18988114595413, 40.110092908144, 36.28777541220188, 35.52106395363808, 35.193430334329605, 37.5010085105896, 39.6153062582016, 41.874976605176926, 45.410132110118866, 50.97878269851208, 52.24034160375595, 53.64606857299805, 54.12954322993755, 52.12364986538887, 48.22023332118988, 42.13102966547012, 41.4115534722805, 41.60885028541088, 40.69662183523178, 39.58062171936035, 40.11724792420864, 39.20325256884098, 39.03973214328289, 35.92641860246658, 37.45389483869076, 37.38004960119724, 38.83270405232906, 37.15618081390858, 38.212949708104134, 39.269688203930855, 37.71896481513977, 40.05167104303837, 37.471856474876404, 37.322950065135956, 37.367479875683784, 37.13381141424179, 35.03489904105663, 34.40766289830208, 35.94783425331116, 35.85845544934273, 36.08511708676815, 36.03874817490578, 35.90215690433979, 36.15637846291065, 34.38748978078365, 37.16812737286091, 35.28583377599716, 38.25344033539295, 35.8903319388628, 36.28863036632538, 42.66609035432339, 47.35291466116905, 50.980469807982445, 49.0605316311121, 47.0999014377594, 46.417397260665894, 46.18659384548664, 47.81941942870617, 44.88854929804802, 42.52853013575077, 42.15811461210251, 38.44233199954033, 41.96943573653698, 46.289541721343994, 48.45005638897419, 53.498450294137, 48.759169802069664, 51.69118747115135, 53.50912392139435, 52.82258056104183, 43.321566581726074, 6.325537199154496, 0.3288647235604003, 1.3929588231258094, 6.06640487909317, 0.45478922431357205, 1.1518369428813457, 2.8349200543016195, 52.06120781600475, 53.966273590922356, 46.01938381791115, 23.371120914816856, 18.985692635178566, 31.966073513031006, 29.86851006746292, 0.9615454694721848, 0.09914490336086601, 0.05960657028481364, 0.07699987720116042, 0.04725401202449575, 0.05111479040351696, 0.05494588658621069, 0.03290294283942785, 0.01834339323977474, 0.04562544316286221, 0.05633671586110722, 0.0792900039232336, 0.059329730647732504, 0.04724860547867138, 0.00742391889616556, 0.057836436753859743, 0.027141221835336182, 0.038895792749826796, 0.05310806918714661, 0.04300248547224328, 0.07831674403860234, 0.11093781547970138, 0.020451582458917983, 0.0350548631104175, 0.046588539335061796, 0.051597828351077624, 0.05245451167866122, 0.11797059240052477, 0.09561187966028228, 8.432857096195221, 52.79791608452797, 42.92486406862736, 29.36378315091133, 39.975067153573036, 52.59769342839718, 60.37021055817604, 53.24313819408417, 56.88210032880306, 35.466506481170654, 0.3441059432225302, 3.8618574617430568, 6.386442705988884, 0.15227117371978238, 6.790623217821121, 49.02490854263306, 56.289575323462486, 51.92414537072182, 56.190822422504425, 51.9337322562933, 49.20762933790684, 53.2927293330431, 54.32091236114502, 56.49400435388088, 51.39463618397713, 51.888317093253136, 49.90342520177364, 47.93896101415157, 48.65706168115139, 48.81886839866638, 50.53543008863926, 51.81335471570492, 52.26671978831291, 53.686335012316704, 52.45989002287388, 51.487108021974564, 51.9182974845171, 52.762608379125595, 48.57098489999771, 40.33332332968712, 38.792604804039, 40.38927532732487, 40.47019958496094, 44.64779421687126, 44.77039083838463, 42.86688677966595, 40.12944146990776, 37.54275307059288, 41.93006984889507, 38.53871762752533, 40.69572128355503, 41.208142787218094, 41.51021137833595, 41.994909569621086, 40.978722497820854, 39.99809391796589, 41.193274185061455, 42.48350255191326, 40.57589091360569, 41.313514932990074, 39.298270270228386, 41.164540126919746, 39.883252680301666, 41.215654984116554, 38.46865698695183, 37.1466851234436, 37.319340258836746, 41.070571169257164, 40.53095832467079, 44.63524729013443, 49.49730299413204, 53.80581200122833, 55.53055465221405, 54.9346212297678, 54.340355917811394, 54.14657011628151, 49.2188311368227, 44.74924877285957, 42.6157620549202, 44.04569752514362, 42.9085211455822, 42.125447764992714, 41.415113881230354, 41.07899911701679, 40.41055418550968, 37.67612971365452, 40.97149148583412, 38.631561845541, 38.55387881398201, 38.27722325921059, 40.040837824344635, 39.77422133088112, 39.722285717725754, 41.818903014063835, 39.90816794335842, 39.489787593483925, 39.14258122444153, 39.38136801123619, 36.8089896440506, 37.033831179142, 37.81422570347786, 38.90136256814003, 38.23507972061634, 38.50579619407654, 37.7804721146822, 38.536912724375725, 37.53390334546566, 39.117023795843124, 38.597823455929756, 38.94797466695309, 39.35064285993576, 38.136657401919365, 43.071840181946754, 49.20146606862545, 54.963644072413445, 50.18690899014473, 49.572937935590744, 49.62699003517628, 48.22610400617123, 49.76997256278992, 46.67789988219738, 44.29608888924122, 45.1183457672596, 40.04005126655102, 46.06301307678223, 47.76395380496979, 52.156385108828545, 53.670068085193634, 51.37458086013794, 50.3739957511425, 53.52039031684399, 51.29864953458309, 46.54367208480835, 7.337195863947272, 1.1501566017977893, 7.005896391347051, 1.6006800206378102, 1.3687355979345739, 1.4874536963179708, 3.2924033934250474, 57.16810718178749, 58.12457665801048, 52.09839642047882, 35.13457149267197, 24.1429677978158, 34.14564035832882, 38.14722463488579, 2.1531850984320045, 0.24176435748813674, 0.01758560109010432, 0.02454990375554189, 0.03844119761197362, 0.04499370108533185, 0.05780352250440046, 0.04122576538065914, 0.041642729920567945, 0.045519089690060355, 0.03388150165847037, 0.0338283564633457, 0.0522730565717211, 0.15572208620142192, 0.12705933360848576, 0.16560851741814986, 0.09311151734436862, 0.1386902274680324, 0.18936485750600696, 0.2938751323381439, 0.1180422244942747, 0.22184805275173858, 0.17890473129227757, 0.1816911544301547, 0.13056896481430158, 0.16421964741311967, 0.2268225498846732, 0.12318826164118946, 0.20251325040590018, 10.62534799799323, 59.67596121132374, 54.75905165076256, 36.62868171930313, 40.0494671612978, 55.88954038918018, 65.70555746555328, 59.734432473778725, 59.93140250444412, 41.76032915711403, 0.36459141585510224, 8.920313939452171, 9.439877159893513, 0.33237490395549685, 8.54787977412343, 48.90489958226681, 54.09643940627575, 51.606562212109566, 56.87263123691082, 51.13475672900677, 50.053406953811646, 55.93471996486187, 56.42513304948807, 58.944211676716805, 54.354985132813454, 53.94185230135918, 51.680719032883644, 50.60313865542412, 50.41523493826389, 51.276048347353935, 53.38357485830784, 53.094193786382675, 55.94185218214989, 56.84077374637127, 57.23505958914757, 54.47899907827377, 53.00402082502842, 55.914820432662964, 51.79903708398342, 42.11516931653023, 41.49077922105789, 42.158008217811584, 42.74186208844185, 46.072007194161415, 45.77996626496315, 45.41373051702976, 42.15749904513359, 39.87354800105095, 42.983962297439575, 41.97482764720917, 42.18295007944107, 43.857714012265205, 43.71541164815426, 44.644701182842255, 42.85493642091751, 41.276238933205605, 44.29637387394905, 46.02957107126713, 42.71521791815758, 42.10173323750496, 41.96016043424606, 44.175270572304726, 42.20557786524296, 43.59672121703625, 40.264915600419044, 38.53547640144825, 40.02800591289997, 43.27469989657402, 43.306405395269394, 47.84442588686943, 51.12863905727863, 54.20265510678291, 57.61554077267647, 56.55655659735203, 56.343015655875206, 55.70455111563206, 52.03868642449379, 46.858128011226654, 43.76133978366852, 45.80121472477913, 45.586925223469734, 46.26876063644886, 44.50994521379471, 43.85582931339741, 42.556249648332596, 38.59905458986759, 42.60209798812866, 42.41479843854904, 41.705615893006325, 40.05698695778847, 42.38268256187439, 43.852481693029404, 42.49913491308689, 46.17150865495205, 40.78212484717369, 41.445238664746284, 41.517503187060356, 40.64026705920696, 38.335189148783684, 38.97833503782749, 39.16974596679211, 39.690166041255, 40.82322344183922, 39.61725175380707, 39.17076051235199, 41.146213710308075, 39.0870776027441, 42.01588064432144, 40.740855261683464, 41.351075917482376, 40.55269695818424, 39.169882759451866, 46.54666252434254, 51.1638555675745, 57.116015776991844, 51.523236483335495, 50.89211694896221, 50.391148030757904, 49.112159460783005, 53.584352284669876, 50.015006214380264, 46.883503049612045, 47.66453213989735, 41.667868718504906, 46.60393685102463, 49.34853337705135, 54.09775793552399, 56.83270297944546, 51.05319030582905, 51.05416685342789, 54.03751976788044, 51.15297295153141, 48.035380840301514, 9.96258756145835, 1.0671714297495782, 5.181951513513923, 16.759185008704662, 9.80475353077054, 5.105657782405615, 4.809705438092351, 62.981555834412575, 63.8143153488636, 55.079401060938835, 35.623012483119965, 27.989999167621136, 43.99831026792526, 45.48790253698826, 3.2620313856750727, 0.2727136522298679, 0.12015358268399723, 0.1404291536891833, 0.13141571078449488, 0.19842504087137058, 0.1975729811238125, 0.23555906780529767, 0.11458860317361541, 0.11646469312836416, 0.18986638606293127, 0.15324329811846837, 0.13054809562163427], [0.017954149770957883, 0.03639825059508439, 0.050440972263459116, 0.01840289492974989, 0.061928520299261436, 0.03296034425147809, 0.0923573320324067, 0.01549437087305705, 0.035410340715316124, 0.06480580457719043, 0.0144808726690826, 0.026950842402584385, 0.05661101364239585, 0.0345113920775475, 0.09948879975127056, 0.030749647739867214, 1.052648015320301, 25.93915991485119, 49.42699536681175, 24.13947008550167, 30.355127155780792, 35.61774596571922, 54.18622478842735, 50.868607610464096, 51.58530615270138, 37.6677093654871, 0.5125409597530961, 3.677017567679286, 8.335703909397125, 0.16627276927465573, 2.4845370557159185, 43.355456963181496, 57.97464430332184, 52.91309170424938, 49.87060636281967, 55.43401703238487, 55.935343131423, 54.58091340959072, 52.1992202103138, 49.48996938765049, 48.489532470703125, 44.90692511200905, 44.12287138402462, 47.894431203603745, 46.33804231882095, 49.68505471944809, 49.463389813899994, 50.76135836541653, 49.46661964058876, 53.55932302772999, 50.023677349090576, 48.87801602482796, 49.68989185988903, 50.02534545958042, 40.65049611032009, 37.92415380477905, 40.14912061393261, 42.811231166124344, 42.246976643800735, 39.885627552866936, 37.694828510284424, 40.583536103367805, 38.330070823431015, 37.32895754277706, 38.181206211447716, 38.035822212696075, 39.31376203894615, 39.35990296304226, 38.723285123705864, 39.596333876252174, 38.188794404268265, 39.1059397906065, 39.26824048161507, 36.978536546230316, 38.407062292099, 39.080177173018456, 37.832924500107765, 39.72473658621311, 37.0738810300827, 38.16823750734329, 36.87861330807209, 35.84982991218567, 35.79616539180279, 36.591124534606934, 38.961752727627754, 42.69895099103451, 45.06113983690739, 51.957784965634346, 51.581118777394295, 53.93402472138405, 58.2916384935379, 52.38064147531986, 47.142310962080956, 45.07130429148674, 45.63902422785759, 44.225264489650726, 42.74059295654297, 43.02125349640846, 42.054402977228165, 41.11318588256836, 38.124908432364464, 39.127169251441956, 38.73091131448746, 37.079652920365334, 38.62846501171589, 38.25304515659809, 37.73208171129227, 37.36548498272896, 35.850282087922096, 37.57630906999111, 38.35845910012722, 37.73926332592964, 37.378833666443825, 37.99763426184654, 36.36451229453087, 36.91863656044006, 36.403209418058395, 37.85404376685619, 35.308089181780815, 36.628529727458954, 34.666535407304764, 35.3686161339283, 34.06247802078724, 36.414073035120964, 35.31141400337219, 36.567303612828255, 35.55893272161484, 37.944345921278, 43.64715211093426, 46.997569128870964, 46.20798669755459, 48.494308814406395, 47.15931884944439, 47.38366261124611, 44.38654683530331, 46.919072940945625, 48.92851531505585, 48.82926844060421, 44.92668405175209, 48.075590282678604, 45.09036406874657, 49.019075855612755, 46.39550283551216, 52.66051925718784, 47.49291434884071, 55.876130908727646, 36.83501824736595, 52.711379528045654, 20.12230284512043, 0.27024933602660894, 0.40676155302207917, 5.176295042037964, 1.7668341798707843, 0.7083147671073675, 0.491254145745188, 6.473266622051597, 54.38254125416279, 50.18160827457905, 40.339486598968506, 25.161620937287807, 21.940351389348507, 40.16147755086422, 21.328800804913044, 0.2778018463868648, 0.09587503038346767, 0.05535154450626578, 0.059409303721622564, 0.06524678130517714, 0.05730593475163914, 0.03457791819528211, 0.001899044698348007, 0.019662317681650165, 0.05429627730336506, 0.07244535401696339, 0.05596977207460441, 0.036349665897432715, 0.03443382651312277, 0.06004772883898113, 0.02170840212784242, 0.036173836269881576, 0.047668037659605034, 0.020175297577225138, 0.06206440753885545, 0.04444537640665658, 0.057774434026214294, 0.02823943897965364, 0.05864852442755364, 0.08001357564353384, 0.03359035341418348, 0.03342449454066809, 0.1555818202905357, 0.13610848865937442, 1.6678971075452864, 33.99962559342384, 58.26818235218525, 23.297670856118202, 35.58749578893185, 48.589022532105446, 59.51450027525425, 57.94519208371639, 55.941567197442055, 43.235429003834724, 0.4930519836489111, 1.602779170498252, 9.143804647028446, 0.9920941083692014, 3.456357470713556, 45.15905678272247, 57.93641455471516, 53.23893941938877, 50.13417921960354, 58.24302390217781, 56.678750440478325, 56.34536772966385, 54.926710054278374, 53.75243626534939, 50.6772118806839, 48.70333939790726, 47.011092603206635, 48.643997982144356, 46.487191915512085, 51.36191613972187, 49.57378908991814, 52.08779878914356, 51.67980708181858, 55.08949711918831, 51.24700650572777, 51.90104641020298, 51.82713657617569, 50.38036800920963, 42.090900018811226, 38.96898373961449, 41.3118202239275, 44.58375625312328, 43.66326704621315, 42.132815569639206, 39.64100427925587, 43.34115453064442, 39.76898141205311, 39.63136039674282, 40.52979178726673, 41.22845269739628, 40.96347011625767, 39.855099990963936, 40.071125999093056, 41.049261912703514, 40.36853983998299, 39.49552908539772, 40.28893791139126, 38.90059120953083, 40.88187329471111, 40.58684192597866, 40.789770036935806, 40.90732052922249, 40.02199083566666, 40.50849013030529, 39.17519107460976, 37.56853848695755, 36.73316851258278, 39.47701647877693, 39.225397780537605, 43.96741792559624, 47.681817412376404, 54.89089697599411, 53.66028741002083, 58.62817123532295, 55.828709453344345, 54.93617534637451, 49.41801644861698, 46.36741854250431, 45.466410890221596, 45.82190081477165, 44.76510912179947, 44.87645834684372, 43.28356482088566, 42.12371505796909, 40.472255274653435, 41.1975983530283, 39.75399121642113, 39.09896716475487, 40.575130954384804, 38.78889240324497, 39.94480557739735, 39.36383955180645, 37.85321541130543, 40.041138008236885, 40.187627747654915, 41.73479452729225, 38.85600060224533, 40.781638473272324, 37.790442779660225, 38.275593146681786, 39.18078437447548, 39.65211868286133, 36.91019721329212, 38.12346450984478, 37.095182687044144, 38.06553281843662, 36.23058848083019, 37.013350278139114, 38.385278061032295, 38.024297431111336, 37.21103087067604, 38.841709569096565, 45.068796426057816, 49.05214548110962, 47.461083456873894, 51.250107139348984, 47.99749307334423, 50.8102123439312, 46.18883192539215, 49.71896789968014, 51.39516435563564, 51.35349579155445, 47.32940912246704, 51.58920094370842, 46.53440058231354, 50.45866660773754, 49.10111725330353, 54.16195549070835, 47.16130994260311, 56.18768759071827, 36.347401812672615, 54.50658939778805, 22.676480188965797, 0.5882714304607362, 0.8545535418670624, 3.0259970761835575, 1.0912445629946887, 0.4858947411412373, 0.3304863756056875, 6.015339894220233, 59.94526796042919, 53.12804616987705, 48.884650468826294, 30.183169282972813, 20.744205974042416, 44.78776730597019, 27.52130761742592, 0.38106801453977823, 0.047583967170794494, 0.0639690924435854, 0.04999176882847678, 0.04524280295299832, 0.09201950640999712, 0.013941104953119066, 0.039307057595578954, 0.008868203676684061, 0.054936939995968714, 0.07608889092807658, 0.05994624014419969, 0.07033962130662985, 0.14566537662176415, 0.1837334706215188, 0.13047511281911284, 0.12717632576823235, 0.2164168527815491, 0.11761079178540967, 0.25579446635674685, 0.08572134436690249, 0.09993189160013571, 0.18434569792589173, 0.14933580154320225, 0.13343764760065824, 0.1783748675370589, 0.14692540979012847, 0.2621197316329926, 0.17950558889424428, 2.08341799210757, 46.16597235202789, 64.96114701032639, 32.461418733000755, 40.99136061966419, 50.01168519258499, 64.2386157810688, 62.91595995426178, 60.197559222579, 48.91404189169407, 0.7758478901814669, 8.633838761597872, 20.063668191432953, 1.2202457408420742, 4.756340151652694, 48.24914216995239, 55.890064761042595, 52.900582775473595, 49.60134141147137, 57.77708910405636, 57.7588614821434, 58.43297950923443, 56.573541685938835, 55.665481612086296, 51.48065596818924, 48.78884240984917, 48.9289028942585, 52.8977557271719, 49.03362147510052, 53.786030262708664, 53.726407662034035, 55.15239894390106, 55.11128894984722, 55.11531673371792, 53.21576826274395, 53.256874457001686, 52.51242980360985, 52.012692019343376, 45.208708718419075, 42.194881439208984, 43.37948687374592, 47.823815792798996, 45.42354539036751, 43.7473451346159, 41.71482279896736, 44.52234394848347, 42.50595934689045, 41.15992337465286, 41.05412185192108, 43.134198635816574, 43.19680027663708, 43.342241272330284, 42.07516506314278, 43.49660038948059, 41.92199528217316, 43.34602206945419, 43.4251794219017, 40.87578982114792, 43.04614216089249, 43.06731082499027, 42.56632670760155, 44.035297483205795, 40.56825332343578, 41.585948914289474, 40.94311460852623, 40.41021980345249, 39.831062480807304, 42.822079584002495, 41.54139630496502, 45.028245002031326, 48.70455913245678, 57.64607593417168, 54.16181489825249, 59.55802693963051, 56.85494318604469, 56.267407312989235, 51.61536633968353, 50.76834999024868, 48.55878375470638, 47.846333384513855, 47.27639056742191, 47.049493342638016, 46.94602109491825, 43.48133660852909, 42.434017807245255, 43.30601781606674, 41.0243808478117, 40.948316529393196, 41.920494362711906, 40.568150728940964, 40.16715444624424, 41.468117237091064, 40.16579411923885, 40.472566857934, 41.083194091916084, 43.05838130414486, 39.89823907613754, 43.57082560658455, 40.19372642040253, 40.05579002201557, 40.239190980792046, 41.409436985850334, 38.5807965695858, 39.87510971724987, 39.72649589180946, 38.688042014837265, 38.33159454166889, 40.07740706205368, 39.115891456604004, 40.02562344074249, 40.208671018481255, 41.503842920064926, 46.96592062711716, 51.46336309611797, 49.13373850286007, 51.75761170685291, 50.46284258365631, 50.82173712551594, 47.41111233830452, 51.99688866734505, 53.57404723763466, 54.52733628451824, 48.77838917076588, 54.05844144523144, 50.4818719625473, 53.19693647325039, 51.48690663278103, 55.89880049228668, 47.93007329106331, 56.60999692976475, 38.631865829229355, 53.38472619652748, 27.36749567091465, 1.0887125926092267, 0.5205322278197855, 11.666546277701855, 9.599517993628979, 1.379382151644677, 1.8834695150144398, 8.26568791642785, 65.03202840685844, 57.542983666062355, 51.03193424642086, 35.4467399418354, 30.406682789325714, 53.834454864263535, 34.71138060092926, 0.8113047375809401, 0.3171753929927945, 0.19289102376205847, 0.07804999389918521, 0.16614572843536735, 0.22596553259063512, 0.1301645685452968, 0.1997373063932173, 0.07515689445426688, 0.1644145799218677, 0.12178114222479053, 0.12751088594086468, 0.1716625425615348], [0.03088364435825497, 0.04093819428817369, 0.04043475099024363, 0.042420040554134175, 0.003077477686019847, 0.014040450696484186, 0.054585425459663384, 0.06973493422265165, 0.050085257171303965, 0.079784474655753, 0.0371491630357923, 0.03360815011546947, 0.07543209023424424, 0.04811925231479108, 0.021982484686304815, 0.051477036395226605, 0.13183334696805105, 14.280856344848871, 50.84598742425442, 37.57236868143082, 33.086488991975784, 32.043593153357506, 41.13557048141956, 55.12006267905235, 48.93260009586811, 45.74384920299053, 1.913981402758509, 1.7082816967740655, 5.553032951429486, 0.6390172918327153, 1.3150861579924822, 38.459256291389465, 57.11898721754551, 53.83879043161869, 54.98032137751579, 53.12074676156044, 49.91461180150509, 49.13433127105236, 48.36340203881264, 46.957918256521225, 43.59162949025631, 43.16172435879707, 47.03892230987549, 50.05137786269188, 50.75255423784256, 51.022822335362434, 50.76702766120434, 51.35134890675545, 53.31547871232033, 49.931501895189285, 48.200033605098724, 48.57366755604744, 49.762194380164146, 44.711254611611366, 38.93728584051132, 40.827353820204735, 40.70091560482979, 39.55042473971844, 37.592389807105064, 36.658586114645004, 37.45536535978317, 39.763783290982246, 40.544869378209114, 38.51395435631275, 39.96816672384739, 38.679424077272415, 40.3172691911459, 41.04415878653526, 41.20418339967728, 38.7673057615757, 38.177672401070595, 39.09349925816059, 37.630866542458534, 39.17176365852356, 37.86059461534023, 39.1591939330101, 37.96468622982502, 37.987697795033455, 35.46108037233353, 38.91740530729294, 36.04345232248306, 36.64556801319122, 35.69523900747299, 35.53104601800442, 37.109804302453995, 40.28735339641571, 46.485451608896255, 51.659668162465096, 53.9037099480629, 49.30846452713013, 58.23764719069004, 54.111357405781746, 47.235204577445984, 44.8734413087368, 47.55488522350788, 45.71512654423714, 44.727194756269455, 45.52582070231438, 44.98343400657177, 43.83357010781765, 39.90736998617649, 39.58909146487713, 37.142630741000175, 38.999055325984955, 36.79760545492172, 40.33474065363407, 37.03285463154316, 37.54833497107029, 38.90329286456108, 39.248139560222626, 38.75479303300381, 38.84326368570328, 37.59060010313988, 37.93194338679314, 37.44942627847195, 37.492823749780655, 36.0373118519783, 35.10113708674908, 33.94728720188141, 37.13381141424179, 35.72536759078503, 34.64451938867569, 34.26832817494869, 35.86059853434563, 37.38763399422169, 36.02269023656845, 37.118988409638405, 35.2212942391634, 38.88511843979359, 44.552081152796745, 47.93175280094147, 46.69766262173653, 47.55452424287796, 46.09827138483524, 44.463447108864784, 44.61448520421982, 48.80838856101036, 50.543573051691055, 50.99555879831314, 47.79494494199753, 48.956580609083176, 47.70694926381111, 49.909687265753746, 53.08769233524799, 49.303627386689186, 50.10466620326042, 48.014071583747864, 39.88874338567257, 2.6313419407233596, 0.10346336421207525, 1.3562460243701935, 8.394550401717424, 0.40420850564260036, 0.5713916674721986, 0.5352635029703379, 14.08420929685235, 59.16312173008919, 44.91123788058758, 31.50519624352455, 20.469986088573933, 32.27921091020107, 44.38451774418354, 7.296432126313448, 0.2053413525572978, 0.034370614084764384, 0.09912706955219619, 0.024313772773894016, 0.02389096382103162, 0.059165834754821844, 0.03437447696342133, 0.09618317752028815, 0.10136073367903009, 0.044550583261298016, 0.045695127118960954, 0.09501779786660336, 0.022792661329731345, 0.07164699607528746, 0.010940261436189758, 0.01791742459317902, 0.05225967564911116, 0.07228015194414183, 0.01612664265849162, 0.03705185263243038, 0.026742280351754744, 0.0407997355068801, 0.057155134054482915, 0.05523768792045303, 0.024195127480197698, 0.09847650289884768, 0.10686363253626041, 0.009343682850158075, 0.025934113073162735, 0.2658779971534386, 20.605277828872204, 58.16409073770046, 35.890335738658905, 35.27232930064201, 39.686066061258316, 47.34436891973019, 59.11890350282192, 54.126484394073486, 49.35311213135719, 1.4014214440248907, 1.011748791206628, 5.816744025796652, 1.6922602127306163, 1.737160503398627, 40.17317712306976, 57.210626900196075, 55.995436906814575, 55.736989974975586, 54.68265675008297, 53.11876706779003, 54.11334849894047, 51.03001914918423, 50.24827189743519, 45.996167063713074, 46.14790812134743, 49.472102746367455, 51.46922618150711, 53.43788534402847, 52.907752990722656, 52.51526825129986, 53.804801255464554, 54.3634282797575, 51.602686420083046, 51.19390055537224, 51.91117286682129, 51.04177951812744, 46.73904240131378, 41.149686723947525, 42.35292635858059, 42.45168685913086, 41.89543470740318, 40.69227486848831, 38.75322371721268, 39.0842429548502, 41.64006561040878, 41.83760181069374, 41.09920263290405, 40.283276215195656, 40.70271670818329, 41.48045517504215, 41.5472099930048, 41.13945387303829, 40.62592662870884, 39.66338127851486, 40.8630795031786, 38.51672820746899, 40.46740673482418, 39.60053265094757, 39.49026256799698, 40.98189912736416, 39.18547332286835, 37.85328760743141, 41.18621036410332, 37.99848161637783, 39.64061290025711, 37.92475797235966, 37.92701505124569, 39.75672326982021, 43.58969159424305, 47.568617686629295, 54.48617309331894, 53.58211040496826, 53.82247030735016, 60.57177074253559, 54.97270658612251, 50.68528264760971, 46.03050582110882, 47.63620086014271, 46.86255857348442, 45.93756660819054, 45.62928155064583, 45.85816226899624, 45.43764263391495, 41.23196750879288, 40.75121730566025, 39.9090950936079, 39.94920574128628, 38.831282928586006, 41.24514900147915, 39.035620763897896, 38.71477738022804, 38.24158877134323, 40.51040902733803, 39.75701205432415, 38.75434845685959, 39.74482610821724, 39.324595257639885, 36.63720466196537, 38.36811438202858, 37.723486572504044, 37.68245257437229, 38.29399935901165, 38.81732627749443, 38.04963827133179, 36.99265658855438, 36.47184133529663, 38.187662065029144, 38.3557004481554, 38.576016426086426, 37.36752927303314, 38.623677268624306, 41.686305329203606, 47.76108875870705, 48.80183391273022, 49.46934789419174, 49.59836237132549, 46.91336564719677, 46.49769455194473, 45.9036610275507, 48.71003843843937, 52.52425096929073, 54.2465503513813, 49.870959743857384, 50.351060181856155, 51.26371420919895, 51.17156535387039, 53.95426623523235, 48.59681971371174, 52.49012500047684, 45.471719205379486, 42.64280520379543, 4.362200601026416, 0.1660420058760792, 0.9168611734639853, 0.9458690544124693, 0.566898052347824, 0.2738251816481352, 0.7296333450358361, 14.235661569982767, 67.27651476860046, 50.617422088980675, 43.80129463970661, 27.16326992958784, 31.677499897778034, 52.335796281695366, 10.062317959964275, 0.1276154545485042, 0.04559391672955826, 0.05423122063803021, 0.04091321359737776, 0.027072038828919176, 0.04332603588409256, 0.04867180723522324, 0.09466423871344887, 0.03444796442636289, 0.01009386520308908, 0.048452302216901444, 0.023343655884673353, 0.011939423202420585, 0.14148064336040989, 0.143923630239442, 0.10891927769989707, 0.16908757213968784, 0.20734494348289445, 0.17463119263993576, 0.12287475619814359, 0.18787352659273893, 0.14519653224851936, 0.20298893738072366, 0.1744620274985209, 0.0806474662385881, 0.2150809721206315, 0.19751729036215693, 0.08540651047951542, 0.17809255456086248, 0.40535218489822, 24.69995141029358, 67.51277849078178, 46.62715740501881, 43.69293585419655, 42.96069994568825, 50.55276095867157, 63.61619397997856, 58.38569104671478, 55.75682111084461, 2.6520356303080916, 3.687557727098465, 15.65396586433053, 2.47710679192096, 2.9569930164143443, 42.49444216489792, 58.06022331118584, 56.92846544086933, 57.363435700535774, 56.470141634345055, 54.62178021669388, 53.54609213769436, 53.28787699341774, 51.23795919120312, 47.88467712700367, 47.485755532979965, 52.08859674632549, 55.24662248790264, 56.777184158563614, 55.202883034944534, 54.51603189110756, 55.42790696024895, 56.446723490953445, 53.700793236494064, 53.24172466993332, 54.37549643218517, 55.37983573973179, 48.817945048213005, 42.741987481713295, 45.31595416367054, 43.948696330189705, 44.54058296978474, 41.9278659671545, 41.25169984996319, 42.069803550839424, 44.92098055779934, 44.10589389503002, 43.27478349208832, 43.13189975917339, 41.787269711494446, 44.40220959484577, 44.32220868766308, 44.27355609834194, 43.08295078575611, 41.79068572819233, 42.48246520757675, 39.69732865691185, 43.42583678662777, 41.288827657699585, 43.28071117401123, 43.64718250930309, 41.148744374513626, 39.54299993813038, 43.38827200233936, 40.09993225336075, 39.643952921032906, 40.97956225275993, 40.1178102940321, 42.178435921669006, 44.71909359097481, 51.93997152149677, 57.34904207289219, 57.99898959696293, 54.14517179131508, 61.164234951138496, 53.986743092536926, 52.43877075612545, 47.34205864369869, 51.31970040500164, 47.55080424249172, 50.44551931321621, 49.224470034241676, 49.22008126974106, 46.9168196618557, 44.49645973742008, 44.753683134913445, 41.67623586952686, 42.50264972448349, 39.4652409106493, 43.274008333683014, 41.00879408419132, 41.5154816955328, 40.537573769688606, 42.946488708257675, 41.11787863075733, 41.274000853300095, 40.38056619465351, 41.220663115382195, 39.385855570435524, 40.934268683195114, 40.59150047600269, 38.3646147698164, 39.09560054540634, 40.289029106497765, 41.95224925875664, 39.159326925873756, 39.409737288951874, 41.29785217344761, 41.7321764677763, 41.58945992588997, 38.93680326640606, 39.5848622918129, 43.21506589651108, 48.28241318464279, 52.13916443288326, 52.07471989095211, 52.25756987929344, 47.9182293266058, 48.15766967833042, 47.83563315868378, 50.67287631332874, 53.40130090713501, 54.87795487046242, 51.88316836953163, 53.08731235563755, 52.90189370512962, 53.19058321416378, 55.67964345216751, 49.89925302565098, 51.94288216531277, 46.67556680738926, 43.807849287986755, 6.997792851179838, 0.23449849424650893, 4.12357815541327, 21.713946238160133, 1.8235912593081594, 0.5471833446063101, 1.086940225213766, 17.895272746682167, 70.35754144191742, 53.16224053502083, 42.85644493997097, 30.455221384763718, 41.55833579599857, 61.73678822815418, 15.800030026584864, 0.6125866819638759, 0.15602163184667006, 0.22762274835258722, 0.2290342390188016, 0.14691405493067577, 0.0982588309852872, 0.1724656205624342, 0.1725215933402069, 0.1042235386557877, 0.1987457970972173, 0.11258983620791696, 0.18300451833056286, 0.11749124663765542], [0.007425852190863225, 0.02037130805547349, 0.045609060252900235, 0.011852380412165076, 0.019455167566775344, 0.058601665223250166, 0.052217094926163554, 0.02254008621093817, 0.05676942506397609, 0.0019478124977467814, 0.01200512739160331, 0.05855333656654693, 0.10822162919794209, 0.033265110905631445, 0.04046556867251638, 0.033006505836965516, 0.04880432883510366, 2.730117877945304, 41.722346395254135, 39.261397048830986, 37.20574155449867, 35.67477710545063, 38.40238854289055, 54.79280523955822, 42.985926792025566, 54.93842862546444, 5.182289695367217, 0.923244534060359, 4.691146574914455, 1.6614337731152773, 0.3122317692032084, 25.382058508694172, 57.342316433787346, 53.05954344570637, 57.34892047941685, 52.41717271506786, 51.887450739741325, 48.7575738877058, 48.646414652466774, 44.97437909245491, 46.262076795101166, 49.02643606066704, 49.564069211483, 52.319191172719, 51.956971809268, 52.818313390016556, 53.83335292339325, 50.51597513258457, 51.14409662783146, 49.19978275895119, 51.33472099900246, 50.767650827765465, 47.31150448322296, 39.10680994391441, 38.39147932827473, 39.144234135746956, 39.39624421298504, 38.64260025322437, 37.81484127044678, 37.99883499741554, 38.051230385899544, 38.07328060269356, 38.184542432427406, 38.47777269780636, 39.42614480853081, 39.45501945912838, 39.995312467217445, 40.801978781819344, 40.00111095607281, 40.081476643681526, 39.367308765649796, 39.13545660674572, 39.739111214876175, 39.40227448940277, 38.883359134197235, 36.301352083683014, 37.9848213493824, 37.10058219730854, 39.40465696156025, 37.97931544482708, 36.273149996995926, 35.95037631690502, 36.65141209959984, 35.12731768190861, 37.25556068122387, 39.97642748057842, 47.66903109848499, 49.2940329015255, 55.86656302213669, 48.08683767914772, 50.4342795163393, 56.925535798072815, 49.83275279402733, 47.54635848104954, 46.77741654217243, 53.963701128959656, 48.27629171311855, 46.15439437329769, 45.69682292640209, 46.88050501048565, 42.85662733018398, 39.24430936574936, 38.54638181626797, 37.770832031965256, 37.43159003555775, 37.61563315987587, 38.937570825219154, 38.59600715339184, 37.502342239022255, 37.80805483460426, 40.18900707364082, 37.180172726511955, 40.055664628744125, 36.90505988895893, 37.67787002027035, 35.38201041519642, 37.63717420399189, 35.55029958486557, 35.84169074892998, 36.165171191096306, 34.70533512532711, 35.25242976844311, 35.320617109537125, 34.62115824222565, 34.902749732136726, 35.0619687885046, 36.38912357389927, 34.7151044011116, 36.4455771446228, 39.837734922766685, 43.57925735414028, 45.10507307946682, 50.789199471473694, 49.26250599324703, 46.1768701672554, 46.74554765224457, 44.64301787316799, 46.366445794701576, 48.138697296381, 49.79836463928223, 50.62639340758324, 49.07012231647968, 45.32592862844467, 47.25524850189686, 48.81439223885536, 47.368516623973846, 52.50915437936783, 28.737709745764732, 1.2304798979312181, 2.5107485242187977, 1.4764713356271386, 0.5667631595861167, 0.16171025315998122, 0.23698943870840594, 0.11979904389590956, 16.532622165977955, 58.23399938642979, 33.73675189912319, 26.125249229371548, 18.652433417737484, 34.33811902999878, 31.897221207618713, 0.6281588401179761, 0.07451812052750029, 0.08516557223629206, 0.00866165099068894, 0.04031861972180195, 0.021835248153365683, 0.04768149650772102, 0.05429630327853374, 0.033794785413192585, 0.032606863023829646, 0.010696027129597496, 0.010851295555767138, 0.04202640171570238, 0.04663640043872874, 0.06234127315110527, 0.022311413813440595, 0.05645392695441842, 0.00295300931611564, 0.022886071747052483, 0.09194618221954443, 0.05966059863567352, 0.02926275115896715, 0.10971428113407455, 0.019021892476303037, 0.029786314080411103, 0.040942294654087164, 0.0800971563148778, 0.06829357211245224, 0.008793752349447459, 0.022649796046607662, 0.07700068614212796, 4.921876369044185, 48.898808509111404, 45.64821593463421, 35.93336462974548, 43.011111840605736, 47.475302293896675, 60.80815605819225, 50.39450325071812, 57.78427831828594, 5.851627578958869, 0.8362309844233096, 4.614650029689074, 3.0874497536569834, 0.25766512379050255, 28.416383787989616, 59.95658375322819, 55.65953113138676, 57.98473656177521, 55.06741650402546, 54.37901124358177, 51.07671104371548, 50.65515786409378, 46.17153525352478, 49.04315896332264, 51.14989511668682, 51.95240445435047, 52.371236979961395, 53.6937902122736, 54.22127030789852, 54.262467697262764, 52.16421268880367, 53.81400816142559, 49.86701175570488, 52.31865160167217, 52.91736647486687, 48.44737373292446, 42.08234667778015, 40.27083568274975, 40.67967854440212, 40.61101622879505, 41.04446657001972, 38.98858688771725, 39.978958144783974, 38.96545372903347, 40.119284614920616, 40.73786102235317, 40.303890109062195, 42.447909861803055, 39.33904208242893, 41.189440190792084, 42.37872317433357, 41.28891505300999, 40.89701548218727, 41.04584589600563, 40.86466781795025, 41.259345039725304, 42.43822418153286, 40.32779462635517, 39.583361372351646, 40.67150138318539, 39.20145906507969, 38.91798287630081, 40.91222986578941, 39.94072459638119, 37.816699370741844, 39.962014853954315, 37.321893721818924, 39.919035360217094, 42.40651108324528, 49.1565752774477, 52.657228633761406, 57.681851014494896, 49.15765441954136, 56.95000268518925, 57.83937156200409, 52.7476067841053, 48.53980377316475, 51.63282260298729, 51.95746958255768, 49.821250811219215, 48.425304517149925, 48.43457221984863, 46.13814264535904, 44.67283487319946, 40.38406580686569, 40.240357518196106, 38.44021551311016, 39.66732546687126, 40.56493990123272, 40.7338560372591, 40.99065765738487, 40.0019621104002, 39.80028793215752, 41.96373604238033, 39.07060548663139, 40.69619245827198, 37.87113904953003, 38.70958685874939, 37.93714910745621, 38.7874560803175, 37.66544088721275, 37.91409954428673, 37.27033048868179, 36.14714115858078, 37.64520697295666, 36.327437683939934, 35.89109569787979, 37.34007574617863, 36.57335668802261, 38.85559782385826, 35.55132552981377, 39.34559293091297, 40.78480750322342, 47.379885613918304, 47.329283729195595, 53.34261305630207, 49.51166242361069, 49.136196970939636, 48.478813245892525, 46.173666939139366, 48.22315156459808, 50.25576889514923, 52.457484751939774, 51.6458673030138, 50.716657564044, 47.47411675751209, 49.559980630874634, 49.583322778344154, 46.750551983714104, 52.78529316186905, 30.27120105922222, 1.662163333967328, 4.6695461589843035, 3.6487544467672706, 0.6092711817473173, 0.15594857482938096, 0.07872330737882294, 0.1386692692176439, 20.37706397473812, 63.02494950592518, 38.2280120998621, 34.68361549079418, 18.533701188862324, 36.91223010420799, 39.87772397696972, 1.6531943902373314, 0.11291413247818127, 0.05190898860746529, 0.0570446097117383, 0.055453923778259195, 0.003834705571534869, 0.05152297904714942, 0.05426270996395033, 0.05691086356819142, 0.027008613033103757, 0.03120034103631042, 0.003141870361105248, 0.027578190965869, 0.036451169435167685, 0.07112472449080087, 0.11240303763770498, 0.12465939129469916, 0.06220367526111659, 0.19617263751570135, 0.1664550555869937, 0.17583118606125936, 0.06718625067151152, 0.19856860191794112, 0.10279005073243752, 0.09512582488241605, 0.15471751510631293, 0.21778141002869233, 0.16538758005481213, 0.26181580731645226, 0.059743615274783224, 0.23062819411279634, 5.34160659648478, 57.31829032301903, 51.56193360686302, 46.492808014154434, 46.34101375937462, 52.247333228588104, 64.09176126122475, 53.92040625214577, 64.24534142017365, 7.767617292702198, 1.7938415869139135, 14.668842125684023, 5.319896461442113, 0.6317869329359382, 30.08267417550087, 58.669429421424866, 56.097130849957466, 60.622205436229706, 56.395221054553986, 56.44895017147064, 54.79848973453045, 53.89897160232067, 49.77290980517864, 52.27951370179653, 54.44837272167206, 54.241758808493614, 56.4080111682415, 56.3204562664032, 55.99456675350666, 57.8798583894968, 55.05012363195419, 56.73537500202656, 52.37421602010727, 53.85151594877243, 57.50980004668236, 49.83305297791958, 42.875185534358025, 42.18176834285259, 44.252334237098694, 44.84243117272854, 43.42215858399868, 41.6108375787735, 42.28039585053921, 40.40683798491955, 42.04038932919502, 42.96625144779682, 42.36971765756607, 44.282785803079605, 43.339190036058426, 43.29292751848698, 45.835941061377525, 43.2606216520071, 43.87316018342972, 42.794930040836334, 41.73270083963871, 43.05393174290657, 44.93288531899452, 43.00445459783077, 40.5111575871706, 44.60766077041626, 41.05086922645569, 43.49870927631855, 42.16466166079044, 42.3609971255064, 39.69431921839714, 41.803468242287636, 38.95781993865967, 42.020170614123344, 44.55688789486885, 50.366221368312836, 54.68480363488197, 60.270211324095726, 50.24580962955952, 57.159090265631676, 55.432424917817116, 53.33488807082176, 50.24267099797726, 54.83019903302193, 54.22212526202202, 51.32530130445957, 50.375036895275116, 49.07706454396248, 48.702359050512314, 46.508064195513725, 43.91335442662239, 43.80379490554333, 42.447738870978355, 40.38804039359093, 42.05175831913948, 42.645533457398415, 42.74691581726074, 40.77500402927399, 40.77108643949032, 43.4812568128109, 40.74352651834488, 42.99713999032974, 40.969770178198814, 42.34332427382469, 38.85819688439369, 41.6678611189127, 38.873164281249046, 40.20303972065449, 39.72915954887867, 37.06731878221035, 40.325594544410706, 38.47046189010143, 39.08409096300602, 38.874585404992104, 38.98632600903511, 40.43428011238575, 38.2455063611269, 39.99483369290829, 43.28799158334732, 48.26588027179241, 48.90075780451298, 55.10145507752895, 52.00496323406696, 50.89653231203556, 49.9300541728735, 47.163388431072235, 49.54173021018505, 51.18661254644394, 52.76516184210777, 53.73441383242607, 53.79505857825279, 49.35655474662781, 50.2534282207489, 48.21320369839668, 49.28118199110031, 52.0839723944664, 35.46057119965553, 2.4811329133808613, 6.705454112961888, 8.495983108878136, 4.197996687144041, 0.4695332347182557, 0.8335571747738868, 0.2680371719179675, 21.8160904571414, 67.26919636130333, 43.535920679569244, 36.49877429008484, 25.186669193208218, 46.04634717106819, 49.38574478030205, 2.6763923233374953, 0.3376032452797517, 0.2861868980107829, 0.18175837816670537, 0.14435251738177612, 0.17928405781276524, 0.19703456782735884, 0.287739114719443, 0.11737409120541997, 0.1061610784381628, 0.1685570552945137, 0.18438590748701245, 0.09483936330070719, 0.20343431504443288], [0.0316211832978297, 0.020480364801187534, 0.10113264943356626, 0.09503037726972252, 0.06948023656150326, 0.030146539575071074, 0.04165347621892579, 0.04667308479838539, 0.09297545198933221, 0.08003434093552642, 0.06732630878104828, 0.023941179388202727, 0.024385840879403986, 0.038701713710906915, 0.03754234916414134, 0.04270718862244394, 0.028458524684538133, 0.06870276265544817, 21.901409178972244, 46.893990486860275, 26.720810271799564, 24.284257516264915, 32.560069039464, 43.79610411822796, 46.20416410267353, 56.99101008474827, 12.862540651112795, 0.16486513777635992, 2.215019892901182, 2.391320220194757, 0.17586630448931828, 15.452102646231651, 55.29600843787193, 56.12905293703079, 57.22107633948326, 51.970879063010216, 51.38434253633022, 48.27178135514259, 49.87127512693405, 50.91161750257015, 49.166010171175, 51.54944367706776, 51.19475930929184, 51.00630842149258, 53.30786772072315, 52.51177243888378, 52.18662768602371, 50.51519237458706, 51.293611004948616, 51.53283476829529, 51.18487983942032, 48.965806514024734, 43.43803033232689, 37.62563042342663, 40.783842355012894, 37.718866020441055, 38.89098532497883, 37.54503674805164, 37.03907489776611, 38.41002233326435, 37.80563436448574, 38.618813529610634, 40.02078250050545, 38.13009135425091, 40.383416041731834, 39.206429198384285, 39.737671092152596, 40.28405137360096, 40.9455768764019, 38.776056692004204, 37.34465450048447, 39.46829974651337, 37.63565428555012, 38.06783929467201, 38.68176095187664, 39.715632274746895, 37.380334585905075, 37.621348053216934, 38.202557265758514, 38.54069732129574, 37.57971368730068, 38.48821833729744, 38.13984543085098, 37.258703112602234, 37.819834202528, 39.61772672832012, 46.19987793266773, 49.50665809214115, 52.459654435515404, 53.41764762997627, 41.89317762851715, 57.600121200084686, 47.40335315465927, 50.31237065792084, 44.5932025462389, 55.95577843487263, 55.24441100656986, 47.36379347741604, 48.82016412913799, 47.72504009306431, 45.41855625808239, 38.292091861367226, 37.621914222836494, 38.859606608748436, 36.88249669969082, 38.14180612564087, 38.74694645404816, 39.878442138433456, 38.829918801784515, 39.35922659933567, 39.77357156574726, 38.59120801091194, 38.5537876188755, 38.14742602407932, 37.442442253232, 36.71932965517044, 36.61979399621487, 36.441796347498894, 36.19571775197983, 35.190170109272, 34.7547172755003, 34.85137268900871, 35.5523856729269, 33.48276972770691, 35.662484765052795, 34.43422347307205, 34.828554913401604, 36.63375064730644, 32.92039230465889, 37.16240867972374, 41.19075872004032, 45.0853331387043, 45.450185760855675, 47.459848523139954, 45.03341272473335, 47.444311156868935, 44.69408333301544, 44.53661598265171, 45.355722829699516, 43.26470643281937, 44.02517482638359, 46.147562339901924, 47.428542003035545, 47.158475294709206, 48.81550557911396, 47.36577697098255, 48.9024069160223, 18.226185590028763, 0.04394162511744071, 1.1836915835738182, 1.2839724775403738, 0.1475095096975565, 0.2097395868622698, 0.2368705763365142, 0.04262961934728082, 24.36392594128847, 56.606246531009674, 36.75777979195118, 31.395159848034382, 27.42012284696102, 43.43596324324608, 11.103116311132908, 0.10504715930437669, 0.05480574684042949, 0.026927295912173577, 0.07878115779021755, 0.030994940534583293, 0.02673076778592076, 0.03075829376030015, 0.040073284253594466, 0.021707396517740563, 0.031011297469376586, 0.03452990866207983, 0.05710520978027489, 0.02852375018846942, 0.08856169937644154, 0.026623750090948306, 0.03012113957083784, 0.06501048890640959, 0.026539254722592887, 0.09549839785904624, 0.046828060076222755, 0.020861741504631937, 0.07510316296247765, 0.03447979885095265, 0.11714912398019806, 0.04026783455628902, 0.061978299854672514, 0.040617957565700635, 0.03993168989836704, 0.018620834016473964, 0.07290259120054543, 0.01597625385329593, 0.21465211466420442, 28.899810947477818, 52.211953327059746, 31.56061626970768, 33.33154924213886, 39.81710582971573, 51.0593231767416, 50.301134660840034, 61.84854403138161, 13.846818935126066, 0.2930255513638258, 2.4817869532853365, 1.901958491653204, 0.012978162776562385, 16.410869099199772, 57.49240458011627, 57.052749171853065, 58.56720730662346, 53.82414981722832, 54.498792216181755, 50.690070390701294, 51.65831923484802, 51.19228184223175, 51.95733278989792, 53.86555999517441, 53.17538022994995, 52.44854383170605, 55.79568922519684, 53.27457010746002, 54.678476974368095, 50.95002964138985, 53.11339035630226, 53.482890129089355, 51.04566290974617, 51.68106481432915, 46.15652225911617, 40.35505436360836, 40.342169255018234, 38.303977623581886, 38.42157371342182, 38.76740835607052, 39.51650395989418, 40.34348778426647, 40.99644474685192, 40.88335521519184, 41.32325381040573, 39.68066655099392, 42.08236187696457, 41.44043572247028, 41.710384637117386, 43.478596955537796, 41.913255751132965, 40.43499067425728, 39.71462532877922, 42.38737531006336, 39.27985645830631, 39.43699322640896, 39.550173953175545, 41.511028334498405, 41.04380540549755, 40.99793426692486, 40.74007250368595, 38.174225986003876, 40.53115591406822, 39.24711361527443, 40.541225373744965, 39.56192672252655, 40.239122584462166, 40.40210723876953, 49.642261415719986, 52.1332785487175, 56.57421424984932, 51.94198541343212, 47.20324449241161, 61.156559363007545, 53.60848478972912, 50.64043365418911, 49.44846421480179, 57.118238657712936, 53.43444652855396, 51.577379778027534, 49.49956767261028, 48.30196313560009, 46.674920842051506, 41.670809760689735, 40.97169287502766, 40.922968089580536, 38.312044590711594, 41.24530479311943, 42.04711116850376, 40.84606781601906, 41.31178222596645, 41.38154648244381, 42.82614156603813, 40.450946018099785, 39.06851939857006, 39.514030292630196, 37.495346814394, 37.9124466329813, 38.13935525715351, 38.34312692284584, 39.670217111706734, 38.18334549665451, 37.34769053757191, 37.60025538504124, 34.76454734802246, 36.625976264476776, 38.80742400884628, 36.240916326642036, 37.23786883056164, 37.365180999040604, 36.19516298174858, 39.5467085391283, 43.29319350421429, 45.848092809319496, 48.99846576154232, 48.68573114275932, 47.35994428396225, 49.60768327116966, 47.642037346959114, 47.02818028628826, 46.65104292333126, 44.95675563812256, 46.030323430895805, 46.81119292974472, 48.57617162168026, 46.718781888484955, 49.09330107271671, 47.625660225749016, 49.21894133090973, 20.411739014089108, 0.09631581415305845, 3.0829579196870327, 4.3856505677104, 0.23518603469710797, 0.16964857641141862, 0.24019493779633194, 0.060574520102818497, 25.41277226060629, 60.75550988316536, 41.901464983820915, 35.712520480155945, 21.062302105128765, 47.54363402724266, 17.401261255145073, 0.22828021697932854, 0.05901793956581969, 0.024251771901617758, 0.016994396974041592, 0.01882646458398085, 0.032965042046271265, 0.019243622082285583, 0.06457717856392264, 0.04173867106146645, 0.09437176573555917, 0.04960796344676055, 0.018609942999319173, 0.10174550014198758, 0.10953033983241767, 0.1684069781913422, 0.11849422953673638, 0.20689008117187768, 0.26520062412600964, 0.2811866928823292, 0.10185927880229428, 0.10718572462792508, 0.21770044171717018, 0.19278169056633487, 0.1704116674955003, 0.1842788452631794, 0.17992614913964644, 0.15192358143394813, 0.10381926855188794, 0.13824354362441227, 0.19402790494496003, 0.15770218073157594, 0.5946876236703247, 34.1819854080677, 61.834659576416016, 35.74967488646507, 34.7587526589632, 43.35013344883919, 56.41365006566048, 55.8331324160099, 66.05952367186546, 18.12578547745943, 0.7135112851392478, 9.261567927896976, 7.078927047550678, 0.28131294704508036, 20.147945769131184, 57.19396859407425, 59.666328728199005, 60.03423638641834, 55.066048577427864, 56.886937469244, 53.05743835866451, 56.52521587908268, 54.84105885028839, 54.60899770259857, 57.82098054885864, 56.00160017609596, 54.477479159832, 57.82227247953415, 57.398439422249794, 55.60815408825874, 53.817792758345604, 53.9729118347168, 54.54722061753273, 52.79135763645172, 54.42706346511841, 49.64152805507183, 41.546708419919014, 44.80769343674183, 40.218523889780045, 41.26449756324291, 40.88736779987812, 42.250149473547935, 42.241960912942886, 42.92860306799412, 43.701603189110756, 44.11988094449043, 40.9373465180397, 45.01057595014572, 43.57390724122524, 44.10932131111622, 45.17625845968723, 44.27040986716747, 41.397904604673386, 40.434207916259766, 44.83780302107334, 40.368349850177765, 40.850190594792366, 42.5014603883028, 43.24326038360596, 41.327160000801086, 42.14770697057247, 43.62803153693676, 40.294645205140114, 42.390833124518394, 43.015956580638885, 44.09808911383152, 41.95665702223778, 43.2056538015604, 44.32278245687485, 51.24524340033531, 54.06411454081535, 58.41697856783867, 54.06195245683193, 47.19506733119488, 57.06062234938145, 50.59569865465164, 54.171606972813606, 50.879608020186424, 59.623178243637085, 52.51785971224308, 52.27700583636761, 52.12901137769222, 52.83917427062988, 48.44516985118389, 43.20212759077549, 43.531984090805054, 43.3511745929718, 38.779514506459236, 42.58015796542168, 42.05298565328121, 43.881793320178986, 43.61860044300556, 43.50925751030445, 45.64498230814934, 41.30213834345341, 41.45456336438656, 41.50530584156513, 40.07409363985062, 40.630957558751106, 39.84448716044426, 38.88845846056938, 40.37715397775173, 40.67489840090275, 39.71989944577217, 40.05116567015648, 38.36051099002361, 38.3034722507, 40.050363913178444, 38.06444227695465, 38.46208713948727, 40.241197273135185, 36.4772180467844, 41.20829477906227, 45.78049823641777, 47.97683358192444, 50.11153623461723, 50.48755645751953, 47.4731782078743, 51.81468844413757, 49.4986367225647, 49.54696632921696, 49.6258120983839, 47.2488534450531, 48.483521193265915, 48.28126184642315, 47.58479721844196, 48.34518201649189, 50.881302729249, 50.208651423454285, 48.42797577381134, 25.812415815889835, 0.21467642742209136, 2.183774644508958, 4.476212058216333, 0.5374762311112136, 0.3144482377683744, 0.6223006232175976, 0.16863486205693334, 29.37684115022421, 67.00284585356712, 48.16559225320816, 42.481819242239, 32.73276597261429, 58.60680118203163, 25.62940053641796, 0.6696962518617511, 0.16508183005498722, 0.11019976445822977, 0.2794502454344183, 0.07321289798710495, 0.18670455494429916, 0.12377638398902491, 0.21348048612708226, 0.07835818556486629, 0.19638092868262902, 0.10792543806019239, 0.15402703575091437, 0.12881632370408624, 0.17707260616589338], [0.012201053450553445, 0.06152578273031395, 0.09318228112533689, 0.026027558742498513, 0.11811396791017614, 0.031310653866967186, 0.024719289685890544, 0.03123051305010449, 0.10526670885155909, 0.1055524728144519, 0.053420914118760265, 0.012678964085353073, 0.0049398054397897795, 0.04320550739066675, 0.04341148305684328, 0.034258464438607916, 0.020981279230909422, 0.049083457997767255, 7.619991414248943, 48.865263909101486, 30.009165219962597, 25.29564544558525, 28.111319057643414, 40.676380321383476, 51.347093135118484, 56.11192345619202, 21.692105010151863, 0.21915856894338503, 2.2914910269901156, 1.5302782296203077, 0.11772663361625746, 5.184297887608409, 49.73829746246338, 53.75712141394615, 56.7563346773386, 51.840466260910034, 53.094387575984, 50.641243010759354, 53.05500268936157, 51.15747570991516, 52.7318300306797, 54.36498619616032, 52.72375546395779, 51.035316064953804, 54.98627565801144, 52.52963148057461, 53.519170582294464, 50.45275032520294, 52.481187880039215, 49.9204520881176, 50.66091075539589, 44.50412392616272, 39.3073707818985, 38.96449238061905, 38.43888558447361, 38.51652301847935, 39.932353645563126, 39.32912081480026, 37.36777625977993, 38.75073105096817, 39.77683939039707, 38.75362649559975, 38.6580578237772, 36.81740239262581, 40.448715537786484, 37.443559393286705, 38.45709800720215, 38.96866835653782, 39.86638158559799, 39.87777337431908, 39.819476902484894, 40.19595310091972, 38.23435015976429, 39.986265152692795, 40.56104131042957, 39.83173884451389, 34.97419349849224, 38.609211444854736, 38.197146356105804, 40.21089389920235, 38.783458694815636, 39.42612200975418, 37.3623463511467, 38.26449014246464, 36.573846861720085, 40.257703587412834, 46.43514230847359, 52.5845917314291, 48.59237775206566, 57.24665656685829, 43.3333383500576, 50.045662969350815, 53.52127946913242, 51.56302034854889, 49.103473126888275, 48.110578805208206, 59.81162913143635, 47.8046952188015, 52.147596180438995, 48.795039877295494, 49.93163488805294, 40.23064523935318, 38.87164056301117, 37.34512947499752, 39.2188773304224, 37.54582330584526, 37.23085440695286, 36.96535885334015, 38.652730509638786, 38.20086255669594, 39.03673030436039, 37.726515009999275, 38.16572204232216, 36.35801464319229, 36.57819762825966, 36.67542681097984, 39.314810782670975, 35.583293214440346, 37.02244699001312, 35.753972455859184, 35.73813870549202, 34.844069480895996, 36.03038102388382, 34.26140874624252, 35.56475780904293, 35.33913731575012, 35.08409880101681, 33.4722974896431, 34.725603237748146, 35.045276284217834, 39.49588626623154, 41.851710453629494, 44.95723821222782, 45.58786377310753, 49.07891124486923, 48.141455948352814, 48.64364840090275, 42.48891346156597, 43.12588468194008, 42.80252203345299, 41.56910061836243, 50.27226381003857, 46.91060699522495, 47.46159642934799, 48.993925005197525, 47.85783536732197, 42.49208249151707, 6.3531602919101715, 0.3086408134549856, 1.4796459465287626, 0.8575175609439611, 0.043543974970816635, 0.023353548713203054, 0.3010476630879566, 0.14204586303094402, 32.09073722362518, 52.89288818836212, 29.714014157652855, 22.544002197682858, 33.97899270057678, 41.77967771887779, 5.267980322241783, 0.15530707722064108, 0.011775467010011198, 0.08916992650483735, 0.03903856711986009, 0.020594111920217983, 0.014848328537482303, 0.06113599563832395, 0.11474276208900847, 0.025355746256536804, 0.05457135062897578, 0.06631088748690672, 0.08771113134571351, 0.04488411184865981, 0.043030319720855914, 0.06462389676016755, 0.053857003804296255, 0.038218044937821105, 0.08399234808166511, 0.013379386364249513, 0.05291437606501859, 0.025645495552453212, 0.03312061475298833, 0.07211803720565513, 0.08001056252396666, 0.032326234722859226, 0.028345523423922714, 0.020111992380407173, 0.06725285100401379, 0.0063954487904993584, 0.023179253475973383, 0.039958410925464705, 0.03942339666537009, 12.001189570873976, 57.37670458853245, 30.858322754502296, 25.357118546962738, 40.05814589560032, 44.1525249928236, 54.785084053874016, 62.50671811401844, 22.731463238596916, 0.2975064015481621, 2.607883899472654, 1.5848069661296904, 0.24775481026154011, 5.962808663025498, 53.903212174773216, 54.679848700761795, 60.17927460372448, 53.44360023736954, 54.18321155011654, 52.72984653711319, 55.91085724532604, 52.74428956210613, 55.921922251582146, 55.353875532746315, 56.73029087483883, 53.66319425404072, 56.10430486500263, 52.9685041308403, 54.59140084683895, 53.37036296725273, 55.18789283931255, 51.75386130809784, 52.148838713765144, 47.4527733027935, 42.125379368662834, 40.92104159295559, 40.29838040471077, 41.37430027127266, 42.122533321380615, 40.8277527987957, 38.88035349547863, 39.73317973315716, 41.615062952041626, 39.71807174384594, 40.97218304872513, 39.86733913421631, 41.8575469404459, 41.316851153969765, 41.16318739950657, 40.826213881373405, 41.38167567551136, 41.06333635747433, 39.852500930428505, 42.457230761647224, 40.64134620130062, 40.6571039557457, 41.662423610687256, 42.78046041727066, 39.58531826734543, 41.82446591556072, 42.90310263633728, 41.29409417510033, 40.91580167412758, 41.24552898108959, 40.68071588873863, 40.737006068229675, 38.618403151631355, 41.285715624690056, 48.85500825941563, 55.17517872154713, 53.14664237201214, 57.03720040619373, 44.9273794144392, 56.112934201955795, 57.69502870738506, 54.17233653366566, 50.16929693520069, 51.69305317103863, 59.575585797429085, 52.39128090441227, 53.260286673903465, 50.52391290664673, 50.19676186144352, 41.62341110408306, 41.257999911904335, 39.84095714986324, 39.38823044300079, 38.8750945776701, 40.72083793580532, 40.12434974312782, 40.68983159959316, 40.67666530609131, 40.207006707787514, 40.76627969741821, 39.787809401750565, 38.07671561837196, 37.79007039964199, 38.34311932325363, 39.84875813126564, 37.69971884787083, 38.34675192832947, 36.814491748809814, 37.57002420723438, 36.64135783910751, 36.53935231268406, 36.12421318888664, 37.27705232799053, 36.63886897265911, 37.312272638082504, 34.76606346666813, 36.36129766702652, 36.7299272865057, 41.508087292313576, 44.059486985206604, 45.780775621533394, 48.26467953622341, 50.80968417227268, 49.696412310004234, 49.62973348796368, 45.00156283378601, 47.45210073888302, 45.98648138344288, 45.85920341312885, 49.39566224813461, 47.68940560519695, 48.87611612677574, 48.42919930815697, 47.680077105760574, 44.66075152158737, 7.476872093975544, 0.5707299686037004, 3.774325833655894, 1.94585254881531, 0.09137260596617125, 0.2463139602332376, 0.5109232559334487, 0.1769010809948668, 34.99249331653118, 55.446229577064514, 40.189968422055244, 27.867014966905117, 29.565451629459858, 50.954779386520386, 7.384659117087722, 0.09028431319165975, 0.08410446433117613, 0.07328746156417765, 0.019978993950644508, 0.07384008698863909, 0.039381572933052666, 0.10608143857098185, 0.0839248274860438, 0.06196569447638467, 0.028900802026328165, 0.06902492154040374, 0.03947486089600716, 0.062445374205708504, 0.07937760703498498, 0.14949945994885638, 0.20572851615725085, 0.2620450418908149, 0.17724908888339996, 0.17444906960008666, 0.14657778781838715, 0.12724185740808025, 0.11255200894083828, 0.1887890399666503, 0.1893079496221617, 0.17148044920759276, 0.13537342107156292, 0.07393042862531729, 0.13513814541511238, 0.09348119594505988, 0.08858549263095483, 0.17272504570428282, 0.14478999859420583, 14.02824779972434, 66.28188773989677, 39.24575328826904, 34.062679409980774, 40.334592461586, 49.732753559947014, 59.12811420857906, 66.42970740795135, 27.75901336222887, 0.6634483183734119, 7.234364356845617, 5.031988760456443, 0.605528085725382, 7.5036335829645395, 53.63246910274029, 55.26792034506798, 61.97721652686596, 54.243559911847115, 57.433906719088554, 54.48134735226631, 57.144065871834755, 54.700994566082954, 57.378999665379524, 57.20523878931999, 56.275424882769585, 54.71990995109081, 58.058627396821976, 55.0852907449007, 57.269219756126404, 55.897774547338486, 59.309102296829224, 55.093532502651215, 55.177226811647415, 49.928697645664215, 43.932763785123825, 42.09520138800144, 42.876610457897186, 43.96733433008194, 46.187076419591904, 44.51255187392235, 40.50668902695179, 42.92823448777199, 44.669012278318405, 43.92997093498707, 42.2243070602417, 41.08914837241173, 44.168719723820686, 42.280376851558685, 42.77753837406635, 42.345866337418556, 43.015534803271294, 44.06487889587879, 42.21707984805107, 43.97252485156059, 42.124144434928894, 44.971837028861046, 44.995213374495506, 44.48910713195801, 40.792452692985535, 44.82380837202072, 45.427067801356316, 45.597310066223145, 43.503379225730896, 43.8980982452631, 41.69941082596779, 41.501270458102226, 39.41488601267338, 43.837879076600075, 52.17280022799969, 58.02835062146187, 54.22152869403362, 59.297733306884766, 46.3943362981081, 53.94636645913124, 53.80253657698631, 59.12585332989693, 52.517760917544365, 54.568902254104614, 58.031675443053246, 51.854726895689964, 55.45361638069153, 52.753013893961906, 53.36530163884163, 44.224576726555824, 42.86567464470863, 42.65215650200844, 41.945181638002396, 40.31332120299339, 42.39369057118893, 40.25095894932747, 42.20770575106144, 42.20868989825249, 42.71334461867809, 41.84033766388893, 40.620451122522354, 39.68024477362633, 40.02454049885273, 39.8731642216444, 42.68861934542656, 39.53536234796047, 40.30685395002365, 39.783025458455086, 39.904010966420174, 38.60096588730812, 41.366955265402794, 37.851490303874016, 39.6544973552227, 38.463603258132935, 39.747660756111145, 36.949449107050896, 39.370884373784065, 40.126530826091766, 44.13783498108387, 45.7797534763813, 47.96294912695885, 50.74849605560303, 53.44486936926842, 52.37119898200035, 52.635550796985626, 45.77373839914799, 49.518718644976616, 49.70621578395367, 47.43825048208237, 50.6523460149765, 50.355973318219185, 50.37469491362572, 49.48695234954357, 50.180833116173744, 46.99616700410843, 9.251486118882895, 0.7773667993023992, 3.19147368427366, 3.2264299085363746, 0.2656416973331943, 0.4613753693411127, 1.266028534155339, 0.2669096417957917, 39.959742575883865, 61.13534890115261, 42.833638563752174, 35.58756038546562, 38.07291202247143, 59.39754255115986, 12.364311385899782, 0.30520075117237866, 0.284416193026118, 0.20484000211581588, 0.13431823550490662, 0.10636226725182496, 0.15264860034221783, 0.2805063215782866, 0.21952925686491653, 0.16076238214736804, 0.13291532406583428, 0.258130895672366, 0.21190299186855555, 0.18563308665761724, 0.20504789252299815], [0.034415142945363186, 0.013648588374053361, 0.05573409936914686, 0.029456917400239035, 0.059542285453062505, 0.10990286085871048, 0.09302278616814874, 0.048873474734136835, 0.024169992793758865, 0.020543712671496905, 0.010914113718172302, 0.066537368693389, 0.023166356804722454, 0.06952260577236302, 0.028973719890927896, 0.0430767559009837, 0.048465467916685157, 0.0348782505170675, 0.738026857143268, 33.57036642730236, 43.322767317295074, 26.06447909027338, 20.21005153656006, 33.175054639577866, 45.83662882447243, 57.80146859586239, 27.668526917696, 0.012546232828754, 1.7857378092594445, 0.8567388402298093, 0.20016142894746736, 0.35586984478868544, 24.14936665445566, 56.84449374675751, 55.17140932381153, 54.71591256558895, 53.228619173169136, 55.69966837763786, 53.85373882949352, 54.21629637479782, 48.445979207754135, 47.295214757323265, 50.65965682268143, 50.34553147852421, 53.00826899707317, 51.165367886424065, 49.98543240129948, 47.64566995203495, 47.42366686463356, 46.60463981330395, 41.61727823317051, 37.632204070687294, 39.31462459266186, 40.02578303217888, 39.1183765232563, 39.250658825039864, 38.19029912352562, 38.24410043656826, 36.79997652769089, 37.61465661227703, 39.463796988129616, 37.37728714942932, 39.55262862145901, 38.17386880517006, 39.03791584074497, 37.65145003795624, 38.68450440466404, 40.159030482172966, 40.090626552700996, 41.114280223846436, 38.7799096852541, 40.34959025681019, 39.35263395309448, 40.12197487056255, 40.411139354109764, 39.35781687498093, 37.712588757276535, 39.86886665225029, 40.618547424674034, 40.14055207371712, 40.83902679383755, 40.98315306007862, 39.1813999414444, 40.98924033343792, 39.234084114432335, 39.9008609354496, 43.079652562737465, 52.60778188705444, 50.96822306513786, 57.45360106229782, 46.72084137797356, 43.28618288040161, 52.850151881575584, 50.3821425139904, 52.60759189724922, 43.371853083372116, 56.15481935441494, 48.69884043931961, 52.482027634978294, 49.57380808889866, 51.7069224268198, 41.26352481544018, 36.7547095566988, 36.22394263744354, 39.363269582390785, 37.242101803421974, 38.171961307525635, 38.48194107413292, 40.114086493849754, 40.16813099384308, 39.153752624988556, 36.696017906069756, 38.24322268366814, 35.70148967206478, 37.40449368953705, 38.79600182175636, 37.45244711637497, 35.505120009183884, 35.279362723231316, 36.16134859621525, 35.38169503211975, 33.7035758793354, 35.060342475771904, 34.66221123933792, 34.059491381049156, 34.23989810049534, 34.82484631240368, 34.70633827149868, 36.60994492471218, 37.673287466168404, 41.495095789432526, 43.71765352785587, 44.831442162394524, 45.76692536473274, 47.95731782913208, 46.74967423081398, 46.943889409303665, 45.99406577646732, 42.5018023699522, 42.76120685040951, 44.11861181259155, 45.58936469256878, 50.61662793159485, 47.09841571748257, 50.08056789636612, 48.22813309729099, 28.512647822499275, 0.6304195406846702, 1.2917881831526756, 4.724492160603404, 1.380626941099763, 0.043539099060581066, 0.24745652626734227, 1.9815728883258998, 0.6688554282300174, 40.75812913477421, 46.51314452290535, 26.568626537919044, 22.592536993324757, 34.09176304936409, 37.32960730791092, 1.5372566739097238, 0.10753018505056389, 0.02939533027529251, 0.039617249349248596, 0.02546306081057992, 0.010659616436896613, 0.03598227311158553, 0.044406320885173045, 0.04271592741133645, 0.10860250680707395, 0.031055445979291108, 0.06288894102908671, 0.023591215940541588, 0.04726921491965186, 0.027481977085699327, 0.036789418081752956, 0.01382864731567679, 0.04731910208647605, 0.007217512320494279, 0.0397812454320956, 0.005517892095667776, 0.014252434048103169, 0.03390792953723576, 0.01888644866994582, 0.04220133334456477, 0.03834859613562003, 0.01077170856660814, 0.05567328036704566, 0.06023198555340059, 0.004555502355287899, 0.025644727429607883, 0.023468281033274252, 0.09655910500441678, 1.9413629709742963, 42.108743861317635, 46.04602038860321, 26.086506508290768, 30.646265633404255, 43.73706288635731, 49.943429455161095, 62.69754007458687, 29.60400626063347, 0.03324567405798007, 0.5327098618727177, 0.4448729142313823, 0.29791924345772713, 0.264732061768882, 26.738293133676052, 59.337650164961815, 56.42673656344414, 58.46028484404087, 54.25753176212311, 55.74826397001743, 54.55196276307106, 55.06402708590031, 50.56700639426708, 51.42838217318058, 54.28332477807999, 52.36398696899414, 55.72233036160469, 52.30366140604019, 51.65674611926079, 49.1100999712944, 50.50173729658127, 48.851276859641075, 44.50089409947395, 40.37187986075878, 39.736314564943314, 40.6611393392086, 41.6552571952343, 41.57495230436325, 40.6131175160408, 40.36231577396393, 40.52337393164635, 40.03491014242172, 41.488423347473145, 40.67182436585426, 40.870572701096535, 39.75366063416004, 41.052495539188385, 40.31029276549816, 41.30658030509949, 41.86775699257851, 42.008448243141174, 41.69274978339672, 39.20584782958031, 40.030316188931465, 39.8485491424799, 41.02178558707237, 41.76808074116707, 40.65246060490608, 40.13039521872997, 40.34018576145172, 43.869265392422676, 41.6748109459877, 43.894792422652245, 42.544234693050385, 41.62403807044029, 42.094251438975334, 41.45764879882336, 41.600570529699326, 47.48382903635502, 52.35049769282341, 52.23468370735645, 57.451796159148216, 48.7953894585371, 49.61936004459858, 58.25730733573437, 52.01692119240761, 54.195066913962364, 48.242017552256584, 59.235948622226715, 51.65554158389568, 54.46868263185024, 50.31863272190094, 52.11669623851776, 43.386824280023575, 39.76576678454876, 39.35189299285412, 40.073911249637604, 40.27350693941116, 40.45286871492863, 42.04228162765503, 41.18783287703991, 41.12364672124386, 38.7654172629118, 39.84635666012764, 39.26787190139294, 38.82388472557068, 39.32876743376255, 38.35765354335308, 38.6091810464859, 37.35139533877373, 37.44284503161907, 36.50314785540104, 37.043767645955086, 36.5087753534317, 37.85500891506672, 34.60968665778637, 37.11362309753895, 36.30637541413307, 37.295808121562004, 37.594483494758606, 38.991999104619026, 40.29603213071823, 44.378141686320305, 45.38793370127678, 46.36299937963486, 47.43223920464516, 50.32907836139202, 49.15200412273407, 48.31226818263531, 46.26994997262955, 44.07210610806942, 47.1233955770731, 45.428534522652626, 46.993256360292435, 51.23436078429222, 48.866343051195145, 49.49947267770767, 48.0822779238224, 30.8997880294919, 1.0949942492879927, 2.2956950264051557, 4.1832116805016994, 2.7293389197438955, 0.06533612846396863, 0.14158558304188773, 2.329171705059707, 1.1594962631352246, 43.96723173558712, 54.52433444559574, 35.97238473594189, 21.842514239251614, 34.85302560031414, 43.96665036678314, 2.3341838736087084, 0.024865138402674347, 0.07395283406367525, 0.032715903071220964, 0.05831633912748657, 0.05581062963756267, 0.0023706935780865024, 0.042049705152749084, 0.030642004785477184, 0.02355652610276593, 0.043017536227125674, 0.014726565295859473, 0.06104906045948155, 0.02476467201631749, 0.006333803685265593, 0.1455123457708396, 0.12572228035423905, 0.14051423349883407, 0.10476768133230507, 0.14649165415903553, 0.2193817327497527, 0.16318625130224973, 0.13207501993747428, 0.07483323643100448, 0.12053840109729208, 0.0919134757714346, 0.0929286224709358, 0.08563856521504931, 0.12542790005682036, 0.15942118770908564, 0.14364792237756774, 0.13274394732434303, 0.23898605344584212, 1.976916950661689, 47.95432738959789, 58.036630377173424, 35.6867578625679, 31.492603719234467, 45.35349614918232, 53.061599135398865, 68.93325626850128, 34.757700115442276, 0.12254601446329616, 6.06055224314332, 2.6467750500887632, 0.7354117068462074, 0.7147195609286427, 28.70796874165535, 59.01456490159035, 59.13092605769634, 60.56874230504036, 55.421181321144104, 57.41955108940601, 55.27973771095276, 54.354050382971764, 51.82180166244507, 53.04427966475487, 56.03529676795006, 54.34083849191666, 57.01205715537071, 56.774630695581436, 53.95729847252369, 51.68662391602993, 52.58440174162388, 51.82958744466305, 45.523590222001076, 41.8330230563879, 43.48333530128002, 44.80710826814175, 43.14298376441002, 44.3548983335495, 42.88495101034641, 41.679135113954544, 42.58366517722607, 43.017533496022224, 42.996931001544, 41.14756263792515, 42.453294172883034, 41.57321959733963, 44.01287488639355, 41.68178737163544, 42.277633398771286, 44.436487555503845, 44.10283125936985, 44.58937615156174, 42.732237204909325, 43.937027156353, 40.72358138859272, 43.05475249886513, 42.870074808597565, 43.95836301147938, 41.91811189055443, 42.98556961119175, 45.301834121346474, 44.06313098967075, 47.06941947340965, 46.70119263231754, 42.70329035818577, 45.90891994535923, 44.013361260294914, 44.98138211667538, 48.054410219192505, 55.38278058171272, 53.051598072052, 60.82279287278652, 48.141079768538475, 48.93939793109894, 53.587908893823624, 54.441707879304886, 55.80468714237213, 49.24302063882351, 60.2815081179142, 51.75620578229427, 58.051894158124924, 53.08983162045479, 54.87132042646408, 45.725499987602234, 41.33028343319893, 40.57776801288128, 43.35227653384209, 41.483620405197144, 41.686837300658226, 42.22504802048206, 43.26819844543934, 43.53468954563141, 43.52837048470974, 42.077213153243065, 41.73833593726158, 39.919362142682076, 42.289465963840485, 41.8884164839983, 41.24272473156452, 37.94413313269615, 37.35534332692623, 39.92411568760872, 39.36749115586281, 38.96653287112713, 40.37874609231949, 37.52665713429451, 39.49224226176739, 37.30179660022259, 37.86543935537338, 39.51244577765465, 41.24658152461052, 40.73018163442612, 46.47128976881504, 47.763900607824326, 48.89627784490585, 48.955740854144096, 52.35428608953953, 49.55006696283817, 49.61704596877098, 47.94461131095886, 49.149401262402534, 46.72391541302204, 50.2133783698082, 49.267354533076286, 51.605798453092575, 50.67908897995949, 50.44222488999367, 50.71090467274189, 34.61740404367447, 1.6123994230292737, 2.8607712546363473, 9.97308924794197, 5.146308951079845, 0.13609795016236603, 0.8208504191134125, 3.3990738820284605, 2.195020616054535, 50.25972068309784, 57.09835812449455, 38.75842943787575, 30.13563573360443, 42.66206257045269, 53.578040823340416, 3.551011816598475, 0.278435165528208, 0.15464137075468898, 0.13499283290002495, 0.1374985312577337, 0.1930736069334671, 0.18363440874964, 0.12913369573652744, 0.08688655332662165, 0.22513891366543248, 0.1335047822794877, 0.15976888389559463, 0.10400352897704579, 0.15345212363172323, 0.09398676920682192], [0.03685491632495541, 0.032951479297480546, 0.019963946906500496, 0.043827531044371426, 0.03364263029652648, 0.06482596872956492, 0.012328011725912802, 0.04344100569142029, 0.01397604804878938, 0.03346608820720576, 0.028951108506589662, 0.08367219299543649, 0.010211625485680997, 0.003331421139591839, 0.0340874773246469, 0.013434788615995785, 0.04877003048022743, 0.04912180105748121, 0.005438578773464542, 12.151955030858517, 46.029688864946365, 29.035642258822918, 28.418148793280125, 32.735798209905624, 35.604370683431625, 55.65565533936024, 31.5740979462862, 0.12005121825495735, 0.8031939540524036, 0.33699159685056657, 0.2406193275237456, 0.02799896086798981, 8.018530178815126, 42.074313908815384, 59.125055372714996, 54.282739609479904, 54.64353024959564, 51.69579282402992, 52.64304019510746, 49.554364532232285, 52.29719415307045, 49.272248670458794, 51.232837066054344, 51.500399708747864, 50.70762164890766, 46.97365701198578, 45.661709010601044, 42.64578424394131, 39.93463732302189, 37.978350296616554, 37.296142503619194, 38.509360402822495, 37.77540698647499, 38.09018589556217, 38.267153799533844, 38.343499302864075, 39.933254197239876, 39.13164161145687, 38.99158492684364, 37.13555932044983, 40.079272761940956, 37.62148104608059, 38.16090390086174, 37.440713346004486, 39.85371306538582, 39.237781316041946, 38.955494463443756, 38.28668475151062, 40.84200583398342, 39.67600040137768, 38.117122650146484, 39.29653376340866, 38.868102952837944, 41.28003112971783, 39.93199646472931, 38.64358440041542, 39.97402600944042, 42.953974306583405, 44.92884613573551, 44.760268181562424, 42.049128860235214, 40.79561412334442, 41.466452926397324, 40.002456083893776, 41.64401739835739, 42.80843071639538, 45.67866750061512, 52.22375549376011, 52.235010489821434, 54.73110035061836, 50.059691816568375, 37.87469565868378, 50.87029092013836, 49.530087634921074, 52.29307137429714, 47.830727621912956, 51.89076416194439, 48.82973961532116, 51.832688078284264, 50.98372623324394, 53.94632086157799, 42.46519513428211, 35.25624096393585, 38.15016947686672, 39.37474876642227, 38.93624469637871, 37.23465420305729, 38.4030307084322, 39.33427333831787, 39.537406638264656, 38.811052814126015, 37.20964394509792, 37.162370681762695, 36.33485868573189, 37.12657280266285, 37.48585872352123, 38.97083044052124, 35.16468867659569, 36.13375827670097, 35.736968368291855, 34.69583183526993, 34.26933892071247, 34.68044266104698, 35.44145442545414, 34.31351915001869, 34.07468296587467, 34.4387262314558, 35.221206843853, 39.6843371540308, 40.065209716558456, 44.85906668007374, 45.79258918762207, 47.4612582474947, 46.09092257916927, 47.476503029465675, 48.56439985334873, 46.380619034171104, 48.243013098835945, 46.32516860961914, 41.57786674797535, 43.5986515134573, 43.13434302806854, 51.556165516376495, 46.14046052098274, 48.22793550789356, 42.06938557326794, 12.8526839800179, 0.09643363751820289, 3.3399538043886423, 3.947081188671291, 0.762278224574402, 0.08479533702484332, 0.5359497817698866, 2.157693556509912, 2.318933866918087, 43.74969340860844, 34.244894832372665, 27.350107803940773, 25.795341432094574, 40.662093088030815, 18.466344103217125, 0.0786453447653912, 0.12050901947077364, 0.032390200431109406, 0.06565338917425834, 0.0713986437767744, 0.08917021594243124, 0.03896484959113877, 0.08400123158935457, 0.09407857287442312, 0.04479782975977287, 0.025053840581676923, 0.03128982920316048, 0.04545236319245305, 0.02545507715694839, 0.021675116804544814, 0.04030607371532824, 0.03607147926231846, 0.015592852942063473, 0.04016296908957884, 0.04032923614431638, 0.006524830641865265, 0.06725600513163954, 0.0229718510308885, 0.014092421442910563, 0.029844914060959127, 0.06575085542863235, 0.02896635778597556, 0.035084671471850015, 0.021951180897303857, 0.06128510052803904, 0.03803592931944877, 0.1698441620101221, 0.07093539519701153, 0.0657293554104399, 18.50853893905878, 52.70647019147873, 28.60911514610052, 27.273129634559155, 43.53424496948719, 41.32842533290386, 61.874207854270935, 34.27817344665527, 0.15907104243524373, 0.402056782040745, 0.2731131948530674, 0.24695823347428814, 0.025642055697971955, 9.772707000374794, 46.29638135433197, 60.953464061021805, 57.09587685763836, 56.23151443898678, 54.346986562013626, 53.73483180999756, 49.543003141880035, 53.66639748215675, 52.04131208360195, 53.64959478378296, 53.030934780836105, 51.92968547344208, 49.45391312241554, 47.693045809865, 43.760230243206024, 42.742895632982254, 40.3452242910862, 38.636049404740334, 38.8695202767849, 38.465677946805954, 39.586910381913185, 39.683208614587784, 40.04318609833717, 41.11229293048382, 41.49256132543087, 41.280114725232124, 39.15230110287666, 41.87622673809528, 38.99932511150837, 40.002402886748314, 40.001589730381966, 40.740881860256195, 40.08521184325218, 40.545538142323494, 40.63845835626125, 42.10925683379173, 41.948552057147026, 40.620169937610626, 41.2104644626379, 41.66484788060188, 41.77048981189728, 40.845319256186485, 40.81350736320019, 42.60174460709095, 44.56446848809719, 47.145886570215225, 45.9365938603878, 44.65176120400429, 43.79430301487446, 43.9760472625494, 41.99577212333679, 44.775414168834686, 42.18755163252354, 47.30258256196976, 53.31006780266762, 55.09785667061806, 54.83217492699623, 50.80356650054455, 43.99489425122738, 55.64572647213936, 54.68041107058525, 54.5538854598999, 52.532082349061966, 56.59928910434246, 53.23282174766064, 54.055986776947975, 52.14061215519905, 54.84048128128052, 42.3242948949337, 36.751437932252884, 39.92370530962944, 39.51517403125763, 41.36722885072231, 39.77706737816334, 41.12362392246723, 41.13802134990692, 40.30109345912933, 39.74277421832085, 39.832665994763374, 40.21082930266857, 38.8638661801815, 39.63913477957249, 40.038367956876755, 38.34998935461044, 37.72152967751026, 37.81967841088772, 38.08286368846893, 37.25729338824749, 35.842367112636566, 36.6481214761734, 36.85202233493328, 36.23540282249451, 36.07951998710632, 36.61292776465416, 36.7657707631588, 40.823436230421066, 42.378913164138794, 46.784803345799446, 47.36623674631119, 48.61553370952606, 49.120667204260826, 48.9623448997736, 50.29391124844551, 47.22054496407509, 51.28823049366474, 46.55707776546478, 46.39389172196388, 47.66206607222557, 45.72587616741657, 50.578303188085556, 46.57696209847927, 48.35962504148483, 43.336093202233315, 14.017737563699484, 0.20905445097014308, 7.318188808858395, 3.427787278778851, 1.306520823854953, 0.08274033010820858, 0.6711381557397544, 3.3526002382859588, 3.136631939560175, 50.021739453077316, 42.91423603892326, 37.855263501405716, 25.2658037468791, 43.85295666754246, 22.788773663342, 0.15782142902025953, 0.009033698897837894, 0.0826257276639808, 0.068462136114249, 0.08865436393534765, 0.06305395014351234, 0.029912367863289546, 0.056295682516065426, 0.006916199899933417, 0.025461734221607912, 0.05915256144362502, 0.02319458253623452, 0.0335413271386642, 0.038249627032200806, 0.039805955238989554, 0.1471496868180111, 0.10898941065534018, 0.09805724883335643, 0.0870544345525559, 0.1375391861074604, 0.10963605134747922, 0.2537427842617035, 0.14446753542870283, 0.11888920795172453, 0.10706340384786017, 0.13637129799462855, 0.2083153757848777, 0.09604104139725678, 0.18382056907285005, 0.13540034618927166, 0.14364314294653013, 0.24807963345665485, 0.2461303974268958, 0.17256358405575156, 20.43272338807583, 63.09395380318165, 40.120534747838974, 39.53583352267742, 46.56210869550705, 45.3678859770298, 65.35387113690376, 39.721506759524345, 0.32791527919471264, 4.448070768266916, 1.4250846742652357, 0.6170856999233365, 0.12689941562712193, 11.67504072189331, 47.21353054046631, 61.822131648659706, 58.51061314344406, 58.30618791282177, 55.632560178637505, 54.97568562626839, 49.386333748698235, 53.36327254772186, 51.71011425554752, 55.04031255841255, 55.94610795378685, 54.99871999025345, 51.151768416166306, 51.733612194657326, 46.37519672513008, 43.46789672970772, 41.96598932147026, 40.9394022077322, 39.48898583650589, 40.29148757457733, 42.88360968232155, 41.94902703166008, 42.240330800414085, 42.73877665400505, 43.69107015430927, 43.100182861089706, 41.548080146312714, 44.014683589339256, 41.295241713523865, 42.36942507326603, 40.227981582283974, 43.78288462758064, 42.339665070176125, 41.79618023335934, 42.37532235682011, 43.262114971876144, 44.50538545846939, 41.25038132071495, 43.554452285170555, 43.907483741641045, 44.13013659417629, 42.54052609205246, 44.40382070839405, 44.41737078130245, 47.04581134021282, 49.526306837797165, 49.22265373170376, 47.266959473490715, 46.037999019026756, 46.55086129903793, 43.50214809179306, 46.818750724196434, 45.607455521821976, 47.07403242588043, 55.251220241189, 56.184982135891914, 58.54136869311333, 51.93744085729122, 41.758258268237114, 49.00421865284443, 54.96639892458916, 57.01913997530937, 53.09332363307476, 57.96977296471596, 52.03004948794842, 54.93455283343792, 53.86367529630661, 58.58778320252895, 44.725796431303024, 38.52110557258129, 41.927087008953094, 43.67946557700634, 42.96281263232231, 41.84624254703522, 41.45818457007408, 43.66812318563461, 44.06680919229984, 41.932995691895485, 41.529575139284134, 42.25814804434776, 40.15994243323803, 41.71461381018162, 41.797654554247856, 41.484076380729675, 39.62520472705364, 39.46064315736294, 39.39007714390755, 38.96964110434055, 37.711346223950386, 40.178504437208176, 39.50704246759415, 38.1410613656044, 37.2451264411211, 38.408867195248604, 39.26605939865112, 43.881303146481514, 43.4987510740757, 47.434450685977936, 49.175616055727005, 50.79432539641857, 50.631811916828156, 52.4961818754673, 50.02693757414818, 48.28592799603939, 53.24675180017948, 49.81022760272026, 47.63920269906521, 48.58329623937607, 46.70700252056122, 52.7879948168993, 49.651829302310944, 48.89344319701195, 44.152194410562515, 16.60564284771681, 0.3352272149641067, 7.129432987421751, 9.937980081886053, 3.87703622225672, 0.2323424958740361, 1.1902657058089972, 4.674546690657735, 4.1329071298241615, 55.60462407767773, 46.83366112411022, 41.28250099718571, 32.50595234334469, 55.001254454255104, 27.296238094568253, 0.4266300634481013, 0.15065400424646214, 0.12294210609979928, 0.15580692852381617, 0.30670778593048453, 0.2272977915708907, 0.09574548850650899, 0.21266795316478238, 0.12298886882490478, 0.14070083911065012, 0.14874583866912872, 0.07339042713283561, 0.15586907597025856, 0.08496009380905889, 0.11488932883366942], [0.04759073184686713, 0.07637903356226161, 0.10329995813663118, 0.015893142590357456, 0.057199362345272675, 0.043700664609787054, 0.044112552859587595, 0.09031269291881472, 0.01508927049144404, 0.030955137299315538, 0.034314956719754264, 0.04091762937605381, 0.0223456064122729, 0.035381148336455226, 0.04023446759674698, 0.01905882360006217, 0.15090007073013112, 0.0831997417844832, 0.06297826592344791, 1.4369628368876874, 37.66295202076435, 41.84317231178284, 26.72804318368435, 31.748031713068485, 36.88040681183338, 48.159474581480026, 40.69332741200924, 0.7681178580969572, 0.2928924100706354, 0.07437490829033777, 0.10977858080877922, 0.05381856797612272, 0.6708083453122526, 18.405509367585182, 53.459471985697746, 54.31751914322376, 53.09458136558533, 49.54353891313076, 52.470829635858536, 50.45799024403095, 49.95816506445408, 54.49666813015938, 54.31339256465435, 51.23358182609081, 45.2458593249321, 42.92476907372475, 41.20547533035278, 37.83195935189724, 39.06917296350002, 39.902073070406914, 39.547593891620636, 36.72689884901047, 39.59883414208889, 39.97588410973549, 40.621104687452316, 41.83248348534107, 39.66214254498482, 38.46455700695515, 38.24181295931339, 39.934804514050484, 39.42985720932484, 37.82108053565025, 40.7695247232914, 38.746087700128555, 38.977787867188454, 38.824070915579796, 38.35206784307957, 38.24793443083763, 39.129517525434494, 39.42069210112095, 39.16238196194172, 38.108504712581635, 40.397950261831284, 39.65606667101383, 41.11059062182903, 38.62973414361477, 44.01426941156387, 46.92555919289589, 49.19746108353138, 46.12793639302254, 46.01876065135002, 43.32736887037754, 43.471514135599136, 42.65422739088535, 42.00407087802887, 42.221438214182854, 44.77184236049652, 53.24366256594658, 50.487457662820816, 57.11168020963669, 52.80032895505428, 40.88883452117443, 46.777838319540024, 53.04538920521736, 53.203734308481216, 47.81699515879154, 50.70745445787907, 47.378848269581795, 53.19401063024998, 48.66904243826866, 53.639935702085495, 41.025775372982025, 36.479820907115936, 36.23300515115261, 39.48178142309189, 38.73770534992218, 37.52182759344578, 35.92326857149601, 40.01049645245075, 38.12455125153065, 39.309160485863686, 36.751137748360634, 36.28877475857735, 36.55005633831024, 37.53601223230362, 38.667359724640846, 36.95858761668205, 35.40586553514004, 37.35902152955532, 35.770566165447235, 34.643048867583275, 32.9360094666481, 34.77835200726986, 34.504154920578, 34.406443163752556, 32.47957795858383, 34.08886760473251, 33.52472707629204, 36.16970434784889, 37.24172942340374, 42.93043836951256, 44.136596247553825, 47.19632126390934, 43.82370583713055, 48.16126808524132, 45.39253905415535, 49.5971692353487, 47.26553075015545, 48.621924966573715, 40.24779751896858, 45.74492834508419, 42.2786745429039, 51.95597246289253, 45.30044339597225, 53.21091212332249, 28.911797404289246, 4.632739434018731, 0.5362243764102459, 2.8891369700431824, 1.9615839421749115, 0.9911027178168297, 0.10541892334003933, 0.7014574413187802, 1.0950014926493168, 6.83343599550426, 53.18248204886913, 28.35304118692875, 23.182989209890366, 23.80254026502371, 44.46387268602848, 4.988314853981137, 0.057587724513723515, 0.00801694173787837, 0.037794612580910325, 0.04299586551496759, 0.05515599230420776, 0.050640684203244746, 0.05133295213454403, 0.0925570736580994, 0.03409740354982205, 0.03491060073429253, 0.017271746837650426, 0.06251365921343677, 0.021086506494611967, 0.06262576061999425, 0.01789392077625962, 0.01653367911785608, 0.02071805800369475, 0.04346797904872801, 0.006783482094760984, 0.05834536081238184, 0.028172692072985228, 0.02908056318119634, 0.08029844160773791, 0.02396222855168162, 0.05080328133772127, 0.024953088468464557, 0.026594923219818156, 0.08879257409716956, 0.07669121056096628, 0.03832838745438494, 0.03730328484380152, 0.06790690575144254, 0.06310081676929258, 0.07098720452631824, 4.030380081385374, 50.02177745103836, 44.28366735577583, 27.657862789928913, 39.50486898422241, 42.54938341677189, 55.155058801174164, 43.311003148555756, 0.5847126245498657, 0.19819356501102448, 0.0781237188493833, 0.4625036712968722, 0.03631945677625481, 1.0517219337634742, 21.88776221126318, 55.42139790952206, 56.020758748054504, 54.7160417586565, 52.41995796561241, 52.49683544039726, 52.02241949737072, 51.016913652420044, 56.31846137344837, 56.45481325685978, 52.5000386685133, 49.468500539660454, 44.90072764456272, 42.81745903193951, 40.44516272842884, 40.82445077598095, 40.382010117173195, 42.10115946829319, 37.787262350320816, 41.74706406891346, 42.97886677086353, 42.623494639992714, 43.28941270709038, 41.93484239280224, 41.13598845899105, 40.29610052704811, 40.823854207992554, 40.825039744377136, 40.18776074051857, 42.28524439036846, 40.52664935588837, 41.508216485381126, 40.47223627567291, 40.27577921748161, 40.86065523326397, 40.7683277875185, 41.76855951547623, 39.985535591840744, 40.55353291332722, 42.28523299098015, 41.44042432308197, 44.876857325434685, 40.28898350894451, 44.78292256593704, 49.20767493546009, 50.28719320893288, 49.18687105178833, 48.22112627327442, 46.41436502337456, 44.97358873486519, 43.71562443673611, 45.137910917401314, 44.52808924019337, 47.905021235346794, 53.60536515712738, 53.00797261297703, 56.570676639676094, 52.920391112565994, 44.39728885889053, 54.213796108961105, 55.09357810020447, 53.2981326431036, 50.31861752271652, 54.00842472910881, 50.67327529191971, 55.0485847145319, 51.58090598881245, 53.35539177060127, 45.175650492310524, 37.512358501553535, 38.26955907046795, 40.518286004662514, 41.19850650429726, 39.389852955937386, 39.071772024035454, 43.46138387918472, 39.98407267034054, 40.23050084710121, 39.0471987426281, 39.77675959467888, 37.95628488063812, 39.677482321858406, 38.94727170467377, 37.9464890062809, 36.9412225484848, 37.70736023783684, 37.346041426062584, 37.17823103070259, 35.33296264708042, 36.671638414263725, 36.913955211639404, 37.00066655874252, 35.192795768380165, 36.05264022946358, 35.93106955289841, 37.93252095580101, 40.333311930298805, 45.55063337087631, 46.59193329513073, 47.52412207424641, 46.69016942381859, 49.71913129091263, 47.181859239935875, 50.66407598555088, 48.61339822411537, 48.678177148103714, 42.99085512757301, 49.88007925450802, 43.94233547151089, 52.48447850346565, 44.978448674082756, 53.630675598978996, 30.040842220187187, 5.5185664258897305, 1.7216166062280536, 4.405084624886513, 4.563160892575979, 1.7958350549452007, 0.30405695317313075, 0.8707792055793107, 0.9248083282727748, 6.6718515660613775, 56.10646694898605, 38.86884391307831, 29.650299176573753, 22.677762620151043, 52.06816144287586, 6.577951479703188, 0.11864991727634333, 0.03284232421719935, 0.015669973217882216, 0.059747277773567475, 0.0065897356307687005, 0.08500014009769075, 0.04804292613698635, 0.019607189096859656, 0.014526440536428709, 0.02698898322705645, 0.04202910313324537, 0.02728338022279786, 0.024481568652845453, 0.017236229505215306, 0.04208271588140633, 0.18548351421486586, 0.09850843751337379, 0.1488726123352535, 0.15790541045134887, 0.15619343903381377, 0.14406288682948798, 0.12173412716947496, 0.21197285765083507, 0.1022044665296562, 0.1846775715239346, 0.12345938303042203, 0.10972145028063096, 0.14497672294965014, 0.19068947236519307, 0.10504453952307813, 0.16774556133896112, 0.2714479935821146, 0.24630397092550993, 0.224819612049032, 4.446983551606536, 57.09485091269016, 53.76538597047329, 36.488070264458656, 43.28965589404106, 49.772928804159164, 57.42754966020584, 49.932934418320656, 0.9028500784188509, 0.696123061934486, 0.3075391100719571, 0.8857736166100949, 0.14476682874374092, 1.3683469500392675, 22.343950532376766, 56.116072833538055, 57.24471107125282, 56.88371144235134, 52.41118423640728, 54.24468845129013, 51.99644409120083, 52.08912871778011, 58.24558116495609, 58.10323320329189, 55.96980348229408, 51.241113021969795, 47.08447426557541, 45.36560229957104, 41.51887111365795, 44.30665612220764, 42.55313001573086, 44.708226174116135, 39.29136984050274, 44.051066637039185, 45.49664206802845, 45.14361821115017, 47.05689914524555, 45.187407061457634, 43.27748514711857, 42.55952887237072, 43.60865257680416, 43.61685633659363, 41.83846436440945, 45.57991839945316, 43.36874105036259, 43.98670569062233, 42.88308911025524, 42.06496261060238, 42.37863577902317, 43.3846165984869, 43.524198308587074, 41.82171866297722, 42.664794623851776, 45.03543421626091, 43.26733209192753, 46.058973893523216, 42.93053716421127, 47.75964483618736, 52.498286962509155, 54.68582957983017, 49.21546071767807, 50.4924201965332, 46.97820156812668, 47.20218054950237, 46.18825815618038, 47.76972949504852, 47.22445495426655, 48.10366317629814, 56.41665570437908, 54.00079093873501, 60.59503309428692, 54.292379692196846, 43.422633558511734, 50.54286628961563, 57.08772249519825, 55.648656114935875, 47.73241929709911, 57.74207778275013, 51.37760929763317, 56.65314741432667, 54.07162293791771, 56.14776313304901, 46.60867519676685, 39.23196002840996, 38.5314030200243, 42.11101233959198, 42.02115476131439, 40.39538539946079, 39.24472354352474, 45.882176980376244, 40.47779157757759, 43.14807929098606, 40.791346952319145, 42.14144490659237, 40.21401733160019, 41.00462190806866, 42.42214724421501, 40.703450068831444, 38.68854358792305, 40.488111823797226, 38.99778999388218, 39.05241586267948, 36.43461473286152, 38.75385448336601, 38.46054442226887, 39.16498862206936, 36.72060638666153, 38.44768211245537, 38.18887799978256, 41.555079370737076, 40.934268683195114, 46.582179218530655, 48.9777834713459, 49.959054216742516, 46.94854415953159, 51.988627910614014, 48.784681633114815, 52.677910923957825, 49.9056176841259, 51.00065812468529, 44.78482626378536, 51.130535155534744, 45.655579939484596, 52.98953600227833, 46.27054654061794, 55.26418514549732, 31.134898513555527, 6.875949064269662, 1.0746458661742508, 4.525765674188733, 7.4604137521237135, 3.172556161880493, 0.34534247999545187, 1.5071093291044235, 1.5307815838605165, 8.856941889971495, 64.84532922506332, 39.79556858539581, 33.55680115520954, 31.06776561588049, 60.419683903455734, 8.489417061209679, 0.4031225654762238, 0.18224746832856908, 0.1617878075921908, 0.19150850654114038, 0.11496562903630547, 0.2041524468222633, 0.20599463547114283, 0.1857229310553521, 0.07757483384921215, 0.1167035088292323, 0.15551149437669665, 0.1611358011723496, 0.17202938615810126, 0.12461774196708575, 0.06809863960370421], [0.007667787231184775, 0.0512689307652181, 0.045457268788595684, 0.020791872011614032, 0.008096645615296438, 0.028905945109727327, 0.03820052654191386, 0.09349592015496455, 0.06033863217453472, 0.034122428769478574, 0.07402090384857729, 0.016463347637909465, 0.024095483022392727, 0.06468951745773666, 0.029857777335564606, 0.004858009633608162, 0.07808810318238102, 0.0708164660318289, 0.05505568733497057, 0.15138599934289232, 9.770932495594025, 46.482879146933556, 33.29534098505974, 33.35229232907295, 36.45366311073303, 32.77247004210949, 49.11771096289158, 2.117572221904993, 0.18452773190801963, 0.2516053692670539, 0.09506422662525438, 0.06098736201238353, 0.07469051401130855, 3.7307034619152546, 31.061212867498398, 52.22184419631958, 54.79739539325237, 51.840937435626984, 51.80229730904102, 49.66666370630264, 51.3234394043684, 50.836244747042656, 52.22270295023918, 52.33180269598961, 46.37582749128342, 44.61780242621899, 42.1177189797163, 39.61120627820492, 38.23386758565903, 38.519084081053734, 40.713302940130234, 41.71027824282646, 45.232446044683456, 45.613823980093, 45.987883508205414, 47.39657051861286, 42.382883951067924, 39.60163839161396, 41.075366511940956, 41.45137533545494, 40.03001220524311, 41.15562580525875, 38.634996861219406, 38.513236194849014, 38.71647208929062, 38.51604424417019, 40.40046192705631, 39.44810763001442, 37.060771733522415, 39.63855341076851, 40.949190482497215, 39.205699637532234, 38.71715985238552, 37.47917868196964, 43.184458538889885, 38.775809705257416, 47.53422953188419, 51.477152556180954, 50.80820985138416, 51.11310929059982, 50.120309963822365, 46.56462416052818, 44.8701810836792, 43.09149272739887, 43.80903862416744, 44.69804272055626, 47.96031206846237, 52.596340700984, 53.21157328784466, 54.39897157251835, 50.69700501859188, 43.070666044950485, 48.62882919609547, 49.84622307121754, 51.618455573916435, 50.07666930556297, 45.078083127737045, 49.584113135933876, 53.45708191394806, 50.031497329473495, 49.576034769415855, 40.447841584682465, 36.58179223537445, 37.138762548565865, 39.81783539056778, 39.24710601568222, 36.42617158591747, 37.14450404047966, 38.44992019236088, 37.58267752826214, 39.78105716407299, 37.02317275106907, 37.47081533074379, 36.14613801240921, 38.08445580303669, 37.34594263136387, 37.28179447352886, 36.176608577370644, 37.42815501987934, 35.61130151152611, 36.488473042845726, 33.919362500309944, 33.98545615375042, 34.458811953663826, 35.40699027478695, 32.29528784751892, 33.8671039044857, 32.338149547576904, 33.62613223493099, 33.36461886763573, 38.7693652510643, 38.94786827266216, 44.445747658610344, 42.335644885897636, 44.84266296029091, 45.25238737463951, 48.40544678270817, 46.04979358613491, 50.722433254122734, 41.812686547636986, 45.54063230752945, 43.24923746287823, 50.25013379752636, 45.248222798109055, 46.673153936862946, 14.452834166586399, 0.6755579716991633, 1.1632579425349832, 5.1301640924066305, 3.392147091217339, 0.7146204693708569, 0.031056164007168263, 0.7648420182522386, 0.7825952593702823, 20.684281289577484, 49.71678301692009, 29.31377023458481, 24.80888396501541, 33.41307386755943, 30.880770049989223, 0.6109930831007659, 0.05120473128044978, 0.07854709183447994, 0.0628012785455212, 0.023485506280849222, 0.03252074420743156, 0.052820468408754095, 0.04950250055117067, 0.024077751259028446, 0.06242210045456886, 0.04863161622779444, 0.0445487056276761, 0.14165530039463192, 0.06981691927649081, 0.03405727191420738, 0.06745156846591271, 0.07672995066968724, 0.06360080908052623, 0.08817710360744968, 0.0391962549474556, 0.04180033611191902, 0.0028609523906197865, 0.025454253373027314, 0.06571854231879115, 0.06085894077841658, 0.05359028706152458, 0.03832294009043835, 0.047583874402334914, 0.049068355292547494, 0.018130645476048812, 0.049955592839978635, 0.06074857970816083, 0.01803077095246408, 0.04208906124404166, 0.011840539445984177, 0.1441749808145687, 20.90066447854042, 53.89057405292988, 32.22708150744438, 37.88712479174137, 47.59737454354763, 39.0639254450798, 55.84684208035469, 1.534182163886726, 0.1576686356565915, 0.36084161081817, 0.10306321302778088, 0.017139362535090186, 0.04174366571533028, 4.559007715433836, 34.344194903969765, 54.23798941075802, 56.24468073248863, 54.614917784929276, 52.189819514751434, 50.535829067230225, 53.33755552768707, 52.293280363082886, 53.13801683485508, 54.55057583749294, 47.899534329771996, 46.008645594120026, 42.88026966154575, 40.35930633544922, 39.633294492959976, 41.04635886847973, 42.5761453807354, 42.243879809975624, 46.09721504151821, 46.69964611530304, 48.08308348059654, 47.62483187019825, 45.65893515944481, 40.58192878961563, 41.541392505168915, 43.61512742936611, 41.678827330470085, 41.37715771794319, 42.6425202190876, 39.87233966588974, 39.189124926924706, 41.31412290036678, 41.666094213724136, 42.679731622338295, 39.38001908361912, 40.36816745996475, 42.342039942741394, 41.68222814798355, 41.47499866783619, 39.51306514441967, 44.112079963088036, 39.9723768979311, 48.661594837903976, 52.89690837264061, 52.2846320271492, 52.53607213497162, 52.10180103778839, 49.5316531509161, 48.764436319470406, 46.76686070859432, 48.221145272254944, 44.93486501276493, 50.568157732486725, 54.26220551133156, 54.457708820700645, 56.19160898029804, 51.636025831103325, 44.05457764863968, 51.80211491882801, 53.379129096865654, 52.58524909615517, 53.168282210826874, 51.2625552713871, 50.907357931137085, 54.34390492737293, 51.89391799271107, 50.62014654278755, 43.34566108882427, 39.08505991101265, 39.81199510395527, 41.06857247650623, 40.35184733569622, 39.17748615145683, 39.87639404833317, 39.60677571594715, 38.16793352365494, 40.29485799372196, 38.65251012146473, 38.724599853158, 37.327373027801514, 39.94729824364185, 38.635734021663666, 39.36669699847698, 37.82419636845589, 39.21877473592758, 37.49336712062359, 38.361791521310806, 36.20875485241413, 36.129069328308105, 36.92486062645912, 37.5504894554615, 34.771375581622124, 34.24555219709873, 35.02213552594185, 36.030419021844864, 35.966517850756645, 40.69673962891102, 41.352987214922905, 44.79182168841362, 45.723615288734436, 48.36538553237915, 47.336590737104416, 50.345751866698265, 47.784575298428535, 51.213921681046486, 44.57904450595379, 48.977889865636826, 43.49815830588341, 51.13653503358364, 44.73369240760803, 48.34335431456566, 14.896555356681347, 1.918366129975766, 4.536969847977161, 6.364938234910369, 8.452613186091185, 2.4426782643422484, 0.4582338285399601, 1.623605852946639, 0.8014171337708831, 21.67726870626211, 57.430057525634766, 37.770668640732765, 23.60748153179884, 32.88019426167011, 40.13562373816967, 0.9853174688760191, 0.14736657205503434, 0.045008614542894065, 0.03848490639938973, 0.030028820110601373, 0.05009833381336648, 0.03867869600071572, 0.06842917733592913, 0.011626633004198084, 0.034955166702275164, 0.020372020517243072, 0.03318037990538869, 0.09763598354766145, 0.06747859748429619, 0.06488134036771953, 0.0038859673350088997, 0.15550681884633377, 0.20621408853912726, 0.2633802843047306, 0.1405364682432264, 0.11803232424426824, 0.11265591703704558, 0.13806232600472867, 0.19032334123039618, 0.1657480263384059, 0.08692035815329291, 0.14046661730390042, 0.12192119291285053, 0.13274742057546973, 0.16430671617854387, 0.1366827031597495, 0.155179041903466, 0.17795242223655805, 0.11995431603281759, 0.1636078950832598, 0.32479870424140245, 26.493286080658436, 61.724150106310844, 42.28203736245632, 43.1297642737627, 48.4722775965929, 42.23607882857323, 62.18850038945675, 2.7674038521945477, 0.3771624178625643, 0.9201633743941784, 0.6583270244300365, 0.1756671565817669, 0.1697228357079439, 4.761726837605238, 35.185446962714195, 54.61052142083645, 58.04620586335659, 55.516666397452354, 52.1697223931551, 51.36869117617607, 53.561405315995216, 53.027400970458984, 54.409781992435455, 56.95580877363682, 51.38341538608074, 48.83119873702526, 45.93108035624027, 43.41849938035011, 41.799600049853325, 44.25424933433533, 45.17188869416714, 45.900400802493095, 48.79605442285538, 49.94885936379433, 50.438105911016464, 51.51326961815357, 47.30775408446789, 44.28446151316166, 43.66354823112488, 45.48700578510761, 43.46776753664017, 45.20440734922886, 43.07223156094551, 40.778613835573196, 40.59335097670555, 43.93293857574463, 43.22488076984882, 45.63965879380703, 40.356532484292984, 42.488822266459465, 45.07517248392105, 44.00249004364014, 43.70516359806061, 39.62778478860855, 46.53181292116642, 42.421565875411034, 50.61292313039303, 55.71219250559807, 54.14059303700924, 55.82839027047157, 52.37400323152542, 51.740668416023254, 49.590132012963295, 48.953502774238586, 48.015393912792206, 46.385258585214615, 52.8716017305851, 56.52469150722027, 56.671865209937096, 58.964012414216995, 53.318579345941544, 41.945926398038864, 50.76652608811855, 53.271435275673866, 55.85309274494648, 52.3733838647604, 51.545738875865936, 52.616616412997246, 56.66222132742405, 54.325882494449615, 52.95497305691242, 44.40939500927925, 39.14122849702835, 42.34458580613136, 43.55429269373417, 41.68976694345474, 39.08795915544033, 41.831130757927895, 42.06499680876732, 39.93842951953411, 43.75321961939335, 39.577555283904076, 41.663134172558784, 39.31283488869667, 41.783264726400375, 39.93340618908405, 41.794325932860374, 39.17353816330433, 42.69223295152187, 38.685332760214806, 41.467741057276726, 37.51392401754856, 38.18220175802708, 38.98000314831734, 39.39745634794235, 36.20621278882027, 36.0765827447176, 36.75956949591637, 37.43903383612633, 35.85211358964443, 43.336366787552834, 42.84716583788395, 47.049356549978256, 47.614804208278656, 48.51315200328827, 48.40377867221832, 52.248989939689636, 50.43708376586437, 52.863884344697, 48.58733542263508, 50.68101167678833, 46.90794333815575, 52.27884493768215, 45.689698308706284, 49.47942495346069, 18.13845969736576, 1.3598040584474802, 3.260037205182016, 11.5879512950778, 7.557193608954549, 3.6353884264826775, 0.735124466009438, 2.685722247697413, 1.9189247000031173, 25.437317043542862, 61.08323849737644, 42.938600331544876, 34.86377142369747, 42.141912281513214, 49.24269385635853, 1.3536430452950299, 0.2243936192826368, 0.16201488993829116, 0.14965952635975555, 0.2654074161546305, 0.14740163111127913, 0.08959819766459987, 0.2104492433136329, 0.13667473249370232, 0.16570778709137812, 0.11639956966973841, 0.08611877186922356, 0.20347296609543264, 0.2422977687092498, 0.12581647373735905, 0.1448769189300947], [0.030562557876692154, 0.083898666780442, 0.06486705402494408, 0.02729944771999726, 0.06032286895788275, 0.09865389103651978, 0.05022202014515642, 0.0788920049672015, 0.020694398335763253, 0.03967434648075141, 0.02165480051189661, 0.026009659995906986, 0.02634987347846618, 0.0741941285377834, 0.016035690605349373, 0.02773365420580376, 0.05948666519543622, 0.1490725320763886, 0.13306379813002422, 0.10849054640857503, 3.0118924705311656, 34.9462004005909, 41.749932914972305, 24.896395169198513, 34.38812054693699, 30.2232913300395, 52.242085710167885, 11.098530907183886, 0.7946449471637607, 0.6921079836320132, 0.13268850889289752, 0.04766335470776539, 0.018402672285446897, 0.18489368492737412, 9.38737252727151, 35.69178119301796, 51.03629261255264, 54.23450879752636, 50.87599441409111, 52.03072965145111, 49.218207970261574, 53.008724972605705, 51.08218275010586, 50.15690200030804, 47.40420810878277, 45.91177359223366, 42.21199952065945, 40.971339493989944, 38.91296714544296, 40.587643682956696, 42.22592957317829, 45.37688389420509, 45.53392566740513, 48.64532791078091, 48.19258600473404, 49.120298624038696, 48.26375238597393, 43.291210010647774, 41.476161405444145, 41.14195413887501, 39.33115750551224, 40.838434025645256, 40.065319910645485, 39.47711147367954, 38.862255066633224, 39.801701456308365, 38.158301040530205, 39.33591865003109, 37.418701127171516, 42.18873716890812, 38.58145393431187, 39.22943316400051, 39.70205560326576, 41.325529888272285, 42.17625103890896, 41.19673199951649, 48.36793139576912, 51.326855421066284, 53.53150092065334, 52.96525150537491, 50.5312655121088, 52.03761488199234, 49.310907796025276, 45.08989289402962, 45.370618030428886, 46.861498430371284, 47.54610389471054, 50.95380663871765, 54.10500034689903, 55.351610854268074, 55.41364252567291, 53.18638823926449, 40.294930189847946, 49.66487020254135, 53.13480220735073, 50.31029976904392, 42.50973254442215, 49.85172517597675, 51.82008035480976, 49.87698242068291, 48.64559769630432, 42.33073174953461, 35.96637725830078, 37.51586951315403, 41.009010672569275, 37.49308593571186, 38.228696063160896, 37.27888382971287, 37.86185994744301, 36.40229746699333, 37.897076457738876, 36.33364275097847, 37.2494962066412, 35.554308369755745, 37.17631593346596, 36.8291437625885, 36.69904634356499, 35.45533128082752, 36.853226870298386, 37.96439364552498, 36.943171843886375, 36.23336613178253, 34.91255320608616, 34.370880872011185, 33.85375902056694, 34.65506002306938, 35.85210978984833, 33.870185539126396, 34.73301284015179, 34.87404607236385, 35.60692794620991, 36.44355945289135, 38.63562382757664, 41.028416231274605, 45.46158514916897, 43.800010308623314, 47.49885343015194, 47.79814437031746, 47.133005261421204, 43.08958902955055, 43.99786949157715, 43.62887889146805, 47.72171527147293, 48.5240688174963, 34.59530062973499, 4.347385196015239, 0.697352058487013, 6.1628408543765545, 5.8185826521366835, 6.505586737766862, 0.4551740427268669, 0.18844656849978492, 0.6850138236768544, 0.5134709598496556, 39.792072772979736, 37.51089558005333, 27.556153647601604, 18.689625822007656, 33.79587672650814, 8.054246362298727, 0.04753165318106767, 0.10987928282702342, 0.07004480314208195, 0.053517860869760625, 0.04551555335638113, 0.0456580679747276, 0.019615772034740075, 0.01542443644211744, 0.07792054107994772, 0.05420322311692871, 0.03887408864102326, 0.07173802048782818, 0.04683789724367671, 0.03670892845548224, 0.01843807829573052, 0.032028952628024854, 0.13514133665012196, 0.04980027246347163, 0.039156887723947875, 0.05987238902889658, 0.038090332454885356, 0.04010732285678387, 0.06746038518031128, 0.08814557717414573, 0.017936293697857764, 0.03127245923678856, 0.027018396394851152, 0.031552709042443894, 0.06058512539311778, 0.03153845238557551, 0.006172487683215877, 0.004850177192565752, 0.046121646810206585, 0.04756456743052695, 0.05774096316599753, 0.0381929492141353, 4.815275464206934, 51.380493342876434, 44.396517500281334, 28.47807727754116, 44.21790808439255, 34.25119869410992, 59.99211944639683, 10.61219310387969, 0.6323940691072494, 0.5758965632412583, 0.1899694258463569, 0.041033114976016805, 0.036293388839112595, 0.34730489656794816, 10.80432504415512, 39.566140696406364, 54.318206906318665, 54.72849369049072, 50.98216071724892, 53.40147189795971, 51.837662011384964, 54.78242039680481, 52.6286693662405, 51.79345518350601, 48.501752614974976, 47.74912320077419, 44.67948451638222, 42.647995725274086, 40.84894046187401, 42.204734310507774, 43.41295927762985, 45.852774158120155, 46.79456502199173, 50.71787729859352, 50.21868668496609, 50.855726301670074, 49.43531692028046, 44.38095733523369, 41.29766218364239, 41.987009793519974, 41.62607856094837, 42.830321341753006, 41.47667437791824, 40.576392486691475, 39.93941366672516, 41.95776276290417, 41.07777938246727, 41.22151046991348, 38.36946710944176, 42.17905528843403, 39.60642993450165, 42.935906276106834, 41.28479987382889, 42.86049172282219, 44.23110097646713, 43.240292742848396, 49.89060088992119, 52.667001709342, 53.73904958367348, 54.32566210627556, 52.17625044286251, 53.35017845034599, 50.45913778245449, 48.53060446679592, 47.06091172993183, 48.07506211102009, 47.98939570784569, 53.32647152245045, 54.180874675512314, 57.45651550590992, 54.04624029994011, 52.07644499838352, 47.734178602695465, 51.96557454764843, 54.49988275766373, 53.630554005503654, 48.24951454997063, 51.356140449643135, 52.58443593978882, 51.01260848343372, 49.9505540728569, 43.74328315258026, 37.329003140330315, 37.87945680320263, 41.42533913254738, 38.09846945106983, 40.10370925068855, 40.08663296699524, 38.91547501087189, 38.43237653374672, 40.19789479672909, 38.21662791073322, 38.545804247260094, 39.645985811948776, 38.599673956632614, 37.85763077437878, 36.988655403256416, 37.43572801351547, 38.25898043811321, 38.59745867550373, 38.89266103506088, 37.18340255320072, 36.07556439936161, 36.067679822444916, 36.33496128022671, 36.5839771181345, 36.92030847072601, 36.469941437244415, 37.99866400659084, 36.213010624051094, 37.65521943569183, 38.49728085100651, 41.806116700172424, 43.62039014697075, 47.12509788572788, 45.32471649348736, 48.63154225051403, 48.03532004356384, 48.98047752678394, 45.28066545724869, 48.179127126932144, 44.42199893295765, 47.3063899576664, 48.44897344708443, 36.87172807753086, 5.044768424704671, 1.8909779121167958, 7.293263571336865, 6.8387276865541935, 7.936809863895178, 3.549648877233267, 0.07546026216004975, 1.1706282407976687, 0.40623397508170456, 41.601075902581215, 45.10715916752815, 36.17045670747757, 20.80276843160391, 40.29562935233116, 14.509086348116398, 0.038144668797031045, 0.12873994186520576, 0.08717906341189519, 0.06969982321606949, 0.10379952742368914, 0.06263917122851126, 0.0844774825964123, 0.04444219630386215, 0.0675299615249969, 0.01766768818924902, 0.0480751390568912, 0.07727367774350569, 0.0747917355329264, 0.023976316369953565, 0.020372582694108132, 0.029584789444925264, 0.18676673207664862, 0.14773074391996488, 0.1856075567775406, 0.15572006755974144, 0.1919791617547162, 0.23408870998537168, 0.20249463734216988, 0.21469346713274717, 0.0959272107866127, 0.12806944112526253, 0.14301930845249444, 0.12506280792877078, 0.13658695126650855, 0.2046874610823579, 0.19387413194635883, 0.07102049727109261, 0.1732874006847851, 0.31529217842034996, 0.30631055880803615, 0.25358150072861463, 7.245888188481331, 61.57179348170757, 52.089987471699715, 34.73338522017002, 44.62703213095665, 40.09405396878719, 64.77389305830002, 15.488252956420183, 0.9319650661200285, 1.6690313466824591, 0.6201677501667291, 0.1935859114746563, 0.1905144887859933, 0.39576414157636464, 11.210646741092205, 40.40625661611557, 53.93503166735172, 56.575616374611855, 52.50779405236244, 55.64793035387993, 51.472676396369934, 56.80460348725319, 54.28602643311024, 55.6529650837183, 50.10715886950493, 51.27703629434109, 45.83779536187649, 44.557055085897446, 42.93267264962196, 44.757714718580246, 45.966840237379074, 48.693991899490356, 51.198521107435226, 54.0300265699625, 51.84842683374882, 53.988380804657936, 52.19616137444973, 48.09613198041916, 45.0620935857296, 44.762627854943275, 42.91197896003723, 44.002892822027206, 43.83928880095482, 43.96560162305832, 42.72610813379288, 43.990148305892944, 42.796199172735214, 45.12860141694546, 40.86554557085037, 45.351030081510544, 42.969032898545265, 43.34912270307541, 44.23469178378582, 46.38963595032692, 46.226643696427345, 45.60564301908016, 51.18481904268265, 55.483395382761955, 55.90076878666878, 57.545624524354935, 54.2464629560709, 55.64383037388325, 54.510548785328865, 50.5469586700201, 48.80205050110817, 52.637127712368965, 50.17634175717831, 55.26263862848282, 55.319335386157036, 59.6432563662529, 56.61564722657204, 48.17478395998478, 46.97954669594765, 53.56378398835659, 54.753218963742256, 52.800123766064644, 49.55736257135868, 51.47031672298908, 55.86881250143051, 53.75880092382431, 52.460383996367455, 45.92804811894894, 39.415182396769524, 39.430670365691185, 44.08697851002216, 39.11626763641834, 42.37585052847862, 41.28954581916332, 39.84656564891338, 40.184059739112854, 41.32977806031704, 39.51873064041138, 41.60058572888374, 40.547441840171814, 40.778260454535484, 39.17074151337147, 39.39875207841396, 39.21465575695038, 40.225906893610954, 41.16300120949745, 41.45727641880512, 40.09853772819042, 38.358884677290916, 37.967254891991615, 38.02316129207611, 38.8431952893734, 39.20856088399887, 39.69464600086212, 39.80542525649071, 37.64332987368107, 40.02890266478062, 39.846121072769165, 43.05683098733425, 44.919141456484795, 50.72308301925659, 46.506658270955086, 49.05765138566494, 51.05269253253937, 50.1917727291584, 46.854381412267685, 49.15703125298023, 48.18148300051689, 47.91237384080887, 49.43701542913914, 38.45446094870567, 5.6414926797151566, 1.5387687552720308, 9.069302044808865, 10.911993216723204, 11.811327058821917, 3.519178074784577, 0.7646177709102631, 2.216278100386262, 1.0472178691998124, 50.070471838116646, 49.85556676983833, 41.90739646553993, 27.119807861745358, 50.7348357886076, 20.489471442997456, 0.1181740447646007, 0.2776357240509242, 0.1651954825501889, 0.19669481262098998, 0.21484784869244322, 0.11907820327905938, 0.08376314319320954, 0.07895744012785144, 0.23045905865728855, 0.10716507807956077, 0.10872608923818916, 0.18835896538803354, 0.15442556905327365, 0.13875583332264796, 0.1988249397254549, 0.1371589838527143], [0.03138590764137916, 0.025361954321851954, 0.008025139686651528, 0.02835518247593427, 0.09502677043201402, 0.02242321836092742, 0.07544764564954676, 0.05322554374288302, 0.047285746259149164, 0.08332548386533745, 0.007447435236827005, 0.03693416656460613, 0.06631583019043319, 0.05008523119613528, 0.021213760701357387, 0.07061639786115848, 0.0636381316871848, 0.13170801306841895, 0.04146076644246932, 0.05183147870411631, 0.140258890169207, 9.371639471501112, 43.51056084036827, 27.461284138262272, 29.562267400324345, 31.06437049806118, 40.71822367608547, 28.894073255360126, 0.6647468393202871, 1.2853852892294526, 0.37522989499848336, 0.06889693075208925, 0.07852600741898641, 0.04509318598138634, 0.5293403926771134, 12.79082614928484, 39.12672467529774, 53.763170689344406, 50.86857721209526, 49.108986631035805, 50.21018274128437, 51.26051478087902, 51.632081642746925, 51.053315699100494, 49.523065611720085, 46.738556027412415, 45.82120545208454, 43.91745060682297, 42.43231549859047, 42.89276719093323, 43.26727129518986, 44.981218725442886, 48.05354006588459, 50.16804680228233, 50.59479430317879, 50.885611698031425, 50.285331308841705, 49.466349855065346, 43.05462710559368, 38.593225702643394, 39.90349039435387, 39.690523222088814, 40.62781512737274, 39.73669074475765, 39.30563807487488, 39.602645337581635, 39.77471150457859, 38.0161202698946, 37.49130003154278, 38.243469670414925, 40.52189961075783, 38.15496861934662, 39.64412771165371, 40.930427089333534, 42.42476910352707, 40.354989767074585, 50.47493353486061, 50.528248474001884, 53.3380077034235, 53.00533935427666, 52.4450746178627, 51.77708186209202, 51.49143598973751, 48.77056159079075, 49.737427309155464, 47.920721992850304, 52.391345500946045, 52.54853166639805, 54.33912478387356, 49.660637229681015, 57.68573820590973, 53.61189320683479, 42.53129258751869, 51.674399971961975, 52.81151555478573, 48.203198835253716, 41.55594192445278, 54.752428606152534, 49.546004980802536, 51.624896228313446, 44.889651238918304, 41.795348078012466, 36.32477402687073, 39.505625143647194, 39.57735389471054, 38.70698019862175, 35.24299867451191, 36.77325256168842, 36.87914527952671, 37.71992236375809, 36.50880195200443, 39.517503306269646, 36.049072220921516, 37.73164853453636, 35.47294333577156, 37.643044888973236, 36.79385505616665, 39.19180378317833, 39.425362050533295, 38.68651069700718, 36.622313261032104, 36.094544380903244, 34.746156334877014, 36.78212508559227, 34.0834528952837, 34.40664455294609, 35.07578864693642, 35.9140844643116, 35.845821127295494, 37.66441494226456, 36.07942499220371, 37.15073570609093, 37.897220849990845, 42.88261413574219, 40.10908216238022, 45.69524981081486, 44.34796370565891, 46.08101651072502, 47.56549805402756, 44.33664411306381, 43.98257151246071, 45.15689469873905, 45.546134412288666, 48.88473026454449, 18.48235074430704, 1.0764064779505134, 1.8540741736069322, 8.373238295316696, 3.925710660405457, 12.044297307729721, 4.63279215618968, 0.038237886255956255, 0.3848675137851387, 6.526806699112058, 43.75870652496815, 29.329450093209743, 21.684326827526093, 22.97665648162365, 29.960514530539513, 0.30432795581873506, 0.1316369598498568, 0.018877626389439683, 0.0276717201268184, 0.035336185319465585, 0.050479300480219536, 0.027117803365399595, 0.03623208373028319, 0.018204630177933723, 0.012221482920722337, 0.07466431619832292, 0.030216247650969308, 0.13716713263420388, 0.06935240162420087, 0.035043782845605165, 0.02030041068792343, 0.05730862503696699, 0.018081580237776507, 0.045268633402884007, 0.05247610817605164, 0.01821002188080456, 0.06668317844741978, 0.03773776406887919, 0.09101817850023508, 0.06021407381922472, 0.025305337730969768, 0.11027115164324641, 0.030551264244422782, 0.03528472108882852, 0.04022274908493273, 0.04697319818660617, 0.049642981684883125, 0.050484476960264146, 0.11854830983793363, 0.1126936032960657, 0.0945549426251091, 0.09041533194249496, 0.3291716461535543, 20.239735543727875, 52.65081837773323, 25.545523837208748, 35.665589198470116, 38.70117790997028, 48.110981583595276, 31.270330846309662, 0.7172956445720047, 2.2054149582982063, 0.22228263958822936, 0.06822787720011547, 0.118491350003751, 0.08237877060309984, 0.9520548256114125, 15.294434856623411, 41.0027714073658, 54.287363961339, 50.714586675167084, 49.761309027671814, 52.30704702436924, 54.25674520432949, 53.94197389483452, 53.103643879294395, 50.43540045619011, 48.347777277231216, 48.29483091831207, 46.01878724992275, 43.543364480137825, 45.24770602583885, 46.19867339730263, 47.19485454261303, 49.21163812279701, 50.92185415327549, 51.900974214076996, 52.93690882623196, 53.02885249257088, 50.80110423266888, 44.57029737532139, 41.76243804395199, 40.57138815522194, 39.93023715913296, 41.64378561079502, 41.327467784285545, 41.76859751343727, 40.33460386097431, 41.38364017009735, 40.61108082532883, 40.9064731746912, 40.55062226951122, 40.92262990772724, 39.73173961043358, 40.831829980015755, 41.82636581361294, 42.51675456762314, 41.22484669089317, 51.342822164297104, 51.54633544385433, 55.33951610326767, 53.443239256739616, 54.36622112989426, 53.61351951956749, 53.53244327008724, 51.17533855140209, 50.918951109051704, 49.64517205953598, 52.72842161357403, 55.1434276252985, 57.00373940169811, 52.16581620275974, 53.301609456539154, 52.197426706552505, 48.32570046186447, 53.66152234375477, 53.11919644474983, 54.981643706560135, 44.96220074594021, 54.575608894228935, 52.89842069149017, 53.33878666162491, 46.60639151930809, 41.19946025311947, 36.71718657016754, 39.5981539785862, 41.88401252031326, 40.01895859837532, 37.21398711204529, 40.74689693748951, 38.79999540746212, 38.78714829683304, 37.8985545784235, 40.201048627495766, 37.350973561406136, 39.9481076002121, 38.94199378788471, 40.593115389347076, 39.97615769505501, 40.546697080135345, 42.34952934086323, 39.21466335654259, 37.75334917008877, 38.25843706727028, 35.25089845061302, 37.89977811276913, 36.00754804909229, 36.98750026524067, 37.01374165713787, 38.449213430285454, 37.10704185068607, 39.58706237375736, 37.420285642147064, 38.51728297770023, 40.51742345094681, 44.281550869345665, 42.210969775915146, 48.26040476560593, 44.37176562845707, 48.965996503829956, 50.22342883050442, 47.11640775203705, 47.422906905412674, 47.789959609508514, 44.43083345890045, 50.27845747768879, 20.668056160211563, 1.6973309218883514, 4.711582353338599, 10.052278898656368, 7.436479786410928, 10.048691891133785, 7.067258348688483, 0.10281945462338626, 0.17859984218375757, 6.800854643806815, 49.44010466337204, 39.923545718193054, 29.03301849961281, 22.614188231527805, 39.824675023555756, 1.8831062782555819, 0.1406276781926863, 0.044465800310717896, 0.03239793732063845, 0.09200559856253676, 0.05217717851337511, 0.05177101964363828, 0.10558375433902256, 0.0410370557801798, 0.031861052848398685, 0.08353423516382463, 0.04290652948839124, 0.02649347163242055, 0.08879431072273292, 0.022074345870350953, 0.04473635395697784, 0.047714332831674255, 0.17144515266409144, 0.15154171676840633, 0.14038820198038593, 0.08875652798451483, 0.14738476951606572, 0.1422615459887311, 0.2337424090364948, 0.15067672880832106, 0.1724442615523003, 0.20569137908751145, 0.12188461245386861, 0.09148772791377269, 0.09785493937670253, 0.18241011741338298, 0.12307836441323161, 0.17493951047072187, 0.2190083434106782, 0.24175065744202584, 0.1278694174834527, 0.13612643379019573, 0.3441147896228358, 25.824607461690903, 62.611322700977325, 36.52056612074375, 41.29211448132992, 42.40827418863773, 52.30519272387028, 37.58191376924515, 0.7918771519325674, 3.180665639229119, 0.8521369902882725, 0.2195293310796842, 0.17184923723107204, 0.20308611419750378, 1.1741190659813583, 15.754180736839771, 43.407943546772, 57.16282546520233, 52.61101171374321, 50.14009170234203, 53.8534614443779, 54.59781490266323, 56.06604851782322, 54.74405765533447, 52.77278423309326, 49.3230215460062, 51.71615973114967, 49.60501581430435, 46.75588309764862, 47.844000309705734, 49.169031009078026, 49.79032427072525, 50.2308764308691, 53.00308607518673, 54.16455455124378, 55.21196074783802, 55.579249039292336, 53.15205708146095, 47.46163062751293, 45.00393770635128, 42.50259652733803, 43.25310565531254, 44.9342380464077, 43.196241706609726, 43.889940083026886, 43.00811380147934, 43.1791540235281, 41.95823013782501, 42.377473041415215, 42.797966077923775, 43.726788237690926, 41.706413850188255, 43.10534678399563, 44.24552880227566, 45.982704386115074, 43.63121576607227, 53.74168284237385, 54.327520206570625, 56.05448953807354, 55.6049470603466, 56.16100162267685, 57.48906075954437, 55.07356837391853, 53.64537701010704, 51.89167231321335, 53.2096391916275, 53.732092157006264, 57.9596883058548, 58.137321174144745, 56.758671551942825, 49.303300604224205, 51.482726857066154, 49.07960280776024, 54.3831530213356, 51.615419536828995, 50.80043166875839, 47.06369698047638, 56.30263142287731, 55.220643281936646, 54.823302403092384, 48.83885532617569, 42.55883350968361, 38.952534422278404, 42.68669284880161, 44.25063952803612, 42.38691933453083, 38.11838038265705, 40.647327080368996, 40.04567116498947, 40.234817415475845, 39.4338583946228, 43.26588436961174, 39.21652525663376, 41.569013223052025, 40.108504593372345, 41.943809911608696, 42.581552490592, 42.783576250076294, 43.495566844940186, 41.40915960073471, 41.14405922591686, 40.22314444184303, 38.05485159158707, 41.26196309924126, 37.3470863699913, 37.41949148476124, 39.08684961497784, 40.971297696232796, 38.751996383070946, 42.79710732400417, 39.58528406918049, 41.005944237113, 41.949194222688675, 47.1111336350441, 43.128977715969086, 49.84715402126312, 46.896433755755424, 49.98947158455849, 49.930361956357956, 50.16179233789444, 49.45056930184364, 48.50010350346565, 48.53944279253483, 51.15888923406601, 22.183620035648346, 1.4961340930312872, 4.2510470654815435, 16.143884025514126, 10.92599831521511, 25.45732866972685, 12.485000509768724, 0.17030975577654317, 0.44413447729311883, 9.754645619541407, 54.74025405943394, 41.451481729745865, 33.753235414624214, 31.419850923120975, 52.15014584362507, 4.353932244703174, 0.25105997978243977, 0.17791461723390967, 0.0602768891985761, 0.16134817415149882, 0.15880903461948037, 0.11465643547126092, 0.1391278867959045, 0.16685290611349046, 0.13338740420294926, 0.2485916411387734, 0.18248690001200885, 0.171872659411747, 0.28407824866008013, 0.12156584518379532, 0.1402172408415936, 0.15762268187245354], [0.04024281304737087, 0.02580396077974001, 0.04776719229994342, 0.05581301564234309, 0.06885116992634721, 0.04687018437834922, 0.049225033799302764, 0.06329940806608647, 0.07358871414908208, 0.03758235463465098, 0.02130320619471604, 0.041126206269836985, 0.008091932977549732, 0.030016335331310984, 0.024895568312786054, 0.13849750655936077, 0.06353713280986995, 0.029263478463690262, 0.09322194891865365, 0.03331647865707055, 0.036758592978003435, 1.0965598840266466, 26.601918451488018, 39.64816689491272, 26.314743161201477, 34.824500530958176, 32.743139415979385, 48.79135027527809, 2.538209413178265, 0.03594067573430948, 0.6543137272819877, 0.059468553081387654, 0.013390640106081264, 0.03672507758892607, 0.3278369380859658, 0.8185687602963299, 17.384283766150475, 44.62349832057953, 53.1057945638895, 48.85829508304596, 50.4898439347744, 50.725127309560776, 55.16209602355957, 51.03916525840759, 52.03305132687092, 50.72796195745468, 47.13738642632961, 43.35512638092041, 44.210582077503204, 42.17219665646553, 44.77256052196026, 46.69268108904362, 49.29526783525944, 49.06708627939224, 51.679149717092514, 49.80303078889847, 50.91223306953907, 52.752025946974754, 50.63849575817585, 41.88000373542309, 40.81199884414673, 39.19449023902416, 38.97437945008278, 38.710293620824814, 40.39140701293945, 39.41471502184868, 40.09799435734749, 41.16881109774113, 39.80983301997185, 39.62359741330147, 39.78561691939831, 39.46315862238407, 40.34834772348404, 40.46456068754196, 38.637808710336685, 38.682365119457245, 45.52726462483406, 49.65323142707348, 50.803418308496475, 51.07509233057499, 49.856699109077454, 52.7232500910759, 54.75104548037052, 49.835021272301674, 51.13037556409836, 48.884213492274284, 51.191924661397934, 51.397292241454124, 54.05801206827164, 55.118280574679375, 65.54482609033585, 48.48447874188423, 42.48589262366295, 54.856026247143745, 56.34285606443882, 36.15094855427742, 50.01041226089001, 52.40887776017189, 49.813807010650635, 48.391733318567276, 43.31737920641899, 39.465476498007774, 36.97858974337578, 41.3235691934824, 39.155124351382256, 38.05575214326382, 35.52790738642216, 39.130642265081406, 37.255591079592705, 38.6231604963541, 37.12180785834789, 38.18717569112778, 36.79782584309578, 36.94848395884037, 35.931977704167366, 37.54050739109516, 39.124543592333794, 44.04999889433384, 44.47830431163311, 43.608151003718376, 39.425567239522934, 37.271763011813164, 36.93066671490669, 36.250621005892754, 34.232169315218925, 33.09341602027416, 35.50759367644787, 40.800265073776245, 43.309775814414024, 45.52584730088711, 45.46136476099491, 42.90522292256355, 43.318317756056786, 42.721723169088364, 43.695755302906036, 43.415242955088615, 49.3550880253315, 44.7593904286623, 44.89692024886608, 44.680176079273224, 43.795800134539604, 45.682615488767624, 45.23139350116253, 41.624083667993546, 7.64926029369235, 1.749026554170996, 4.26980048418045, 6.372600998729467, 8.029779475182295, 6.716175237670541, 5.79359139315784, 0.398321048123762, 0.04976294614607468, 24.608288928866386, 43.656222224235535, 23.357468247413635, 22.637667171657085, 34.71296511590481, 20.056211091578007, 0.033417188096791506, 0.07291528192581609, 0.014391596014320385, 0.02850554716133047, 0.028122893963882234, 0.02618984417495085, 0.05046802354627289, 0.03663617571874056, 0.057840225417749025, 0.04101006757991854, 0.07811922143446282, 0.05989634555589873, 0.06473089219070971, 0.14004763041157275, 0.03155515070830006, 0.03328761653392576, 0.12307514349231496, 0.031828060673433356, 0.04852849851886276, 0.02756438887445256, 0.036586893402272835, 0.07540871258242987, 0.011294717660348397, 0.028983538504689932, 0.01956877367774723, 0.06333635959890671, 0.06489195307949558, 0.07595867369673215, 0.00927316954403068, 0.030550035990017932, 0.024256773976958357, 0.011264348977420013, 0.06914604004123248, 0.03369453981576953, 0.03956493535952177, 0.09432545572053641, 0.06482885568402708, 0.06807990779634565, 2.389385411515832, 41.27778545022011, 38.59590455889702, 26.674996130168438, 44.04321625828743, 38.88192281126976, 50.10531596839428, 1.6573425801470876, 0.4189039202174172, 0.9695349563844502, 0.08375443037948571, 0.039269901972147636, 0.10007514094468206, 0.17392297595506534, 2.0328075578436255, 20.335699394345284, 47.82504312694073, 52.71672584116459, 49.31634910404682, 51.776340901851654, 50.64587116241455, 55.19759751856327, 52.88697190582752, 54.04519535601139, 49.66026484966278, 49.88870479166508, 45.42013697326183, 46.24666482210159, 44.00968685746193, 46.30458511412144, 47.5192279368639, 50.024714693427086, 51.25525586307049, 52.65689045190811, 52.63310752809048, 53.13124559819698, 53.550727888941765, 52.04825051128864, 42.67054371535778, 41.09428569674492, 41.28457568585873, 41.794865503907204, 39.94860537350178, 42.08763599395752, 42.53388024866581, 42.48126447200775, 41.77971191704273, 41.95591226220131, 41.507965698838234, 41.707109212875366, 41.4255291223526, 43.60367104411125, 42.49994806945324, 42.271500527858734, 39.559126272797585, 46.93821631371975, 52.09626853466034, 53.80666695535183, 52.34366945922375, 52.96475753188133, 53.41250650584698, 56.2459384649992, 52.69016906619072, 52.990098372101784, 50.22985428571701, 53.938447684049606, 52.436365485191345, 57.75003835558891, 53.13041344285011, 59.89240899682045, 53.847746551036835, 44.62871544063091, 51.31433129310608, 62.035668790340424, 42.712170481681824, 49.29937161505222, 53.96393671631813, 50.397786274552345, 49.63075943291187, 44.12058010697365, 40.98968870937824, 38.10766875743866, 41.4978164434433, 39.22844521701336, 39.70747411251068, 38.279503136873245, 40.152950808405876, 38.896023854613304, 39.914198219776154, 38.73518988490105, 39.05555069446564, 36.72843776643276, 38.06539222598076, 39.22895818948746, 38.44825208187103, 41.40907980501652, 44.3121924251318, 45.59133678674698, 44.26145754754543, 41.07198849320412, 39.12001423537731, 37.88412295281887, 37.210692688822746, 35.39617605507374, 34.74208675324917, 37.88684740662575, 42.10085928440094, 43.19768562912941, 46.29643075168133, 46.611927822232246, 46.03787362575531, 43.70572216808796, 44.67750482261181, 44.44362737238407, 45.97086802124977, 50.32900236546993, 47.479417473077774, 48.19076590240002, 45.70405013859272, 45.63390210270882, 46.501752734184265, 46.74211263656616, 41.917868703603745, 7.818364519625902, 2.9551052302122116, 4.479523105546832, 8.959217201918364, 8.76511411741376, 8.181171901524067, 7.472173171117902, 0.3367816284298897, 0.09641351047321223, 25.234415531158447, 48.091815412044525, 34.77739825844765, 25.809565968811512, 34.95304003357887, 27.888649106025696, 0.28569390415214, 0.07224154542200267, 0.06342289401800372, 0.015139529659791151, 0.018936949963972438, 0.033867760794237256, 0.04042507709527854, 0.013155613069102401, 0.01879505503893597, 0.01758568087097956, 0.019229547251597978, 0.0209133170574205, 0.017914285308506805, 0.09639201045501977, 0.030209442156774458, 0.08781644952250645, 0.009976781202567508, 0.21539090783335268, 0.17033543408615515, 0.14212128007784486, 0.14302202471299097, 0.1388708216836676, 0.1716160841169767, 0.059741273798863403, 0.16502717830007896, 0.16913404542719945, 0.1782416965579614, 0.17281597363762558, 0.06339542713249102, 0.10867166012758389, 0.19964673469075933, 0.08692798743140884, 0.1932354544987902, 0.06914391749887727, 0.14418269915040582, 0.191564449633006, 0.22284977399976924, 0.27452232548967004, 4.215475274249911, 47.37927004694939, 50.25115594267845, 35.2039747685194, 47.41608627140522, 42.511605843901634, 58.66702415049076, 3.2578853331506252, 0.6909415649715811, 1.3491918216459453, 0.11271020513959229, 0.24934357032179832, 0.445256307721138, 1.1097959987819195, 1.8920153751969337, 19.943585135042667, 48.495414555072784, 54.99288730323315, 49.67694215476513, 53.48014287650585, 52.60889522731304, 60.307434126734734, 56.077637895941734, 57.815683633089066, 54.10670265555382, 51.938345208764076, 48.044925928115845, 49.23515506088734, 45.457029193639755, 48.31910401582718, 51.14086680114269, 54.17356766760349, 54.90336410701275, 56.41205035150051, 55.527378022670746, 55.85762970149517, 56.282397508621216, 56.37001320719719, 45.04260443150997, 44.30834703147411, 43.68086390197277, 44.33507859706879, 41.31329454481602, 44.11703109741211, 43.2461292296648, 43.36423449218273, 45.62310308218002, 44.124512895941734, 43.174476474523544, 42.82305233180523, 44.33095581829548, 47.44717240333557, 44.48840416967869, 42.16898202896118, 43.670448660850525, 50.83600915968418, 53.92323710024357, 55.594915598630905, 54.248841628432274, 53.51162798702717, 54.88429673016071, 57.20166698098183, 52.813734635710716, 56.45973019301891, 53.97875592112541, 55.221175253391266, 54.09640520811081, 59.580498933792114, 53.78335900604725, 60.681125074625015, 62.77175769209862, 46.1604930460453, 53.36914323270321, 56.9051992893219, 45.29595963656902, 53.198175206780434, 57.42686949670315, 51.57125450670719, 52.1529158949852, 46.04416988790035, 43.17070707678795, 40.20621635019779, 43.50677244365215, 42.369797453284264, 42.459571436047554, 39.79715310037136, 42.670410722494125, 39.98770907521248, 41.885540038347244, 40.968159064650536, 41.14612631499767, 40.23404985666275, 39.64997559785843, 40.68456508219242, 41.60336717963219, 43.46233382821083, 48.00344355404377, 48.25659357011318, 48.08726325631142, 43.48963536322117, 41.691081672906876, 39.62400399148464, 40.199718698859215, 37.36651472747326, 36.412454321980476, 39.56764541566372, 45.49364022910595, 46.42189621925354, 48.76195885241032, 50.02204343676567, 47.35628508031368, 46.93953484296799, 46.91073998808861, 47.096561416983604, 47.13378421962261, 51.770398020744324, 50.070916414260864, 49.332627430558205, 47.50983864068985, 48.54356177151203, 50.048064440488815, 45.38281537592411, 43.07998314499855, 9.809602070599794, 2.9577228147536516, 8.280941247940063, 12.085400652140379, 13.922508973628283, 11.966090854257345, 11.565169617533684, 0.9868239692877978, 0.15332600305555388, 32.67145626246929, 56.95881821215153, 35.14833815395832, 32.702766582369804, 45.97690969705582, 34.87375728785992, 0.7579184928908944, 0.1668728402000852, 0.10542084550252184, 0.07384695927612484, 0.09211438256897964, 0.1590889281942509, 0.13873641873942688, 0.08128169080009684, 0.16312217427184805, 0.08393072756007314, 0.17200620146468282, 0.13257945771329105, 0.1456489454722032, 0.20314357127062976, 0.18867629289161414, 0.1493452416616492, 0.27816071931738406], [0.014938034710212378, 0.016927286415011622, 0.03870082684443332, 0.04502342409978155, 0.024513310308975633, 0.08049908865359612, 0.04223824777000118, 0.02813353821693454, 0.057564543531043455, 0.05611732958641369, 0.03326160796859767, 0.03249103974667378, 0.06452029294450767, 0.07140427667764015, 0.009907361636578571, 0.0436982192331925, 0.018075104999297764, 0.011841034829558339, 0.05927210659137927, 0.059680822159862146, 0.03769145034311805, 0.09565084241330624, 5.101950131356716, 46.12196311354637, 27.862732596695423, 34.490806236863136, 29.459933191537857, 52.61737257242203, 13.047889955341816, 0.1633916184073314, 0.9116976661607623, 0.2376479611848481, 0.3432596573838964, 0.31363807967863977, 0.03582564655516762, 0.01711462675302755, 3.5308375116437674, 29.75715134292841, 51.384190544486046, 50.802517756819725, 50.30339553952217, 53.12629446387291, 50.687197744846344, 51.193889155983925, 51.16190627217293, 50.75853891670704, 46.75847455859184, 43.069792091846466, 42.75889277458191, 42.90132813155651, 47.7878887206316, 46.20334714651108, 49.1693501919508, 49.21166852116585, 53.91914092004299, 50.89329108595848, 51.942296996712685, 53.36025170981884, 52.01381675899029, 47.5371477752924, 39.41126860678196, 38.70867110788822, 38.82000133395195, 40.59618942439556, 41.83960810303688, 41.4860712736845, 41.207664012908936, 39.30878050625324, 39.39198084175587, 39.101957604289055, 39.29005891084671, 38.920068964362144, 40.39105363190174, 40.26138938963413, 38.78258854150772, 36.69959731400013, 43.56767177581787, 52.82786227762699, 50.44419318437576, 50.82374341785908, 51.08523018658161, 52.71332502365112, 58.23868453502655, 51.38455532491207, 48.83100874722004, 53.689534440636635, 54.67859096825123, 54.93234135210514, 53.80524203181267, 48.6567272990942, 25.210241228342056, 35.7742253690958, 72.09132760763168, 68.12119424343109, 36.70155040919781, 44.12714995443821, 51.78600758314133, 50.65255120396614, 50.07833741605282, 45.20130671560764, 40.77997796237469, 36.958538219332695, 38.96336004137993, 38.12590017914772, 37.8414436429739, 36.52799852192402, 38.1920850276947, 38.79744574427605, 37.7358815073967, 36.37012839317322, 36.13486021757126, 36.79968014359474, 36.978217363357544, 37.30644755065441, 36.71727396547794, 37.13148973882198, 45.78700348734856, 49.3498595058918, 49.413946866989136, 44.50142987072468, 47.32572712004185, 38.91767509281635, 35.71168452501297, 35.33893972635269, 35.44327072799206, 36.197446659207344, 38.87539856135845, 40.426756516098976, 46.762103363871574, 43.090029805898666, 45.941320806741714, 47.82891891896725, 48.05145777761936, 47.9083688557148, 47.7154266089201, 47.90488064289093, 47.011092603206635, 46.00025184452534, 47.819218039512634, 45.98865106701851, 45.29886648058891, 42.15929254889488, 46.66378363966942, 26.68637651950121, 1.019716013688594, 3.5157679952681065, 2.91124917101115, 9.153148345649242, 10.326742921024561, 6.915607061237097, 4.333818973973393, 0.4730055062100291, 2.0956642599776387, 50.238802805542946, 32.61430352926254, 18.767901621758938, 21.034122817218304, 37.379194647073746, 10.03892831504345, 0.009834748980210861, 0.012544267992780078, 0.062194595084292814, 0.11397304362617433, 0.05035143956774846, 0.05114207917358726, 0.05568512133322656, 0.04672675691836048, 0.054955705199972726, 0.07739149368717335, 0.02259613134810934, 0.01729819141473854, 0.08097388505120762, 0.06295237981248647, 0.032911989619606175, 0.030669191510241944, 0.06106340617407113, 0.0617662126023788, 0.056921361247077584, 0.06628795512369834, 0.02785124564979924, 0.06639392639044672, 0.057483226410113275, 0.01456338743082597, 0.01986940100323409, 0.039311696018557996, 0.030916653231543023, 0.07376062523690052, 0.015283561042451765, 0.033847425947897136, 0.03088700628723018, 0.0776847756060306, 0.05599304582574405, 0.007511373578381608, 0.028639922275033314, 0.0722031838085968, 0.040755024820100516, 0.03341285395435989, 0.06630648655118421, 12.318584639579058, 53.364955857396126, 25.985563024878502, 38.56811664998531, 38.094244077801704, 62.069866955280304, 12.978685218840837, 0.12826161284465343, 1.187645390164107, 0.32573829288594425, 0.33626031421590596, 0.9696611808612943, 0.7457153289578855, 0.14906389347743243, 3.6302349530160427, 33.068447560071945, 52.49295584857464, 51.06063410639763, 52.20315299928188, 54.49872002005577, 52.91253313422203, 53.483224511146545, 52.874033600091934, 52.41440266370773, 49.93104211986065, 44.503717347979546, 44.680597856640816, 44.91899326443672, 49.169646576046944, 48.74435439705849, 50.077980235219, 52.150647416710854, 54.92978788912296, 52.58871830999851, 52.915375381708145, 56.58477008342743, 54.23031382262707, 48.1514798104763, 41.147756427526474, 40.0064230710268, 39.41982574760914, 40.924176424741745, 40.747820287942886, 43.68816331028938, 41.66738614439964, 40.67978113889694, 40.97289741039276, 42.310638427734375, 40.36215238273144, 41.60230703651905, 40.885236114263535, 42.75050662457943, 40.623787343502045, 38.35181325674057, 43.319271504879, 54.474473521113396, 52.17078633606434, 52.937482595443726, 50.94939507544041, 55.73220603168011, 57.05570921301842, 53.767449259757996, 49.67942722141743, 55.71435458958149, 52.76499845087528, 56.975864097476006, 57.13079698383808, 53.299302980303764, 30.176232755184174, 39.99830290675163, 56.31075918674469, 71.95978626608849, 46.89648315310478, 43.71543824672699, 52.613124400377274, 51.267457008361816, 52.886090353131294, 46.72941371798515, 42.396209836006165, 38.677254393696785, 39.62335042655468, 41.05314530432224, 39.971328154206276, 37.22774237394333, 39.03441242873669, 39.27707880735397, 40.27985639870167, 38.64830754697323, 37.33509041368961, 38.23286443948746, 38.646118864417076, 37.99488700926304, 40.35158894956112, 38.48916068673134, 47.20359407365322, 52.149363085627556, 50.93940921127796, 46.14326477050781, 46.116905584931374, 39.56836737692356, 39.88785803318024, 36.02781616151333, 36.68905287981033, 37.80772805213928, 40.31646363437176, 41.69464588165283, 47.83713407814503, 45.654466599226, 47.50625163316727, 50.84457390010357, 50.26968754827976, 49.87391598522663, 48.600049540400505, 48.84184196591377, 49.44077342748642, 48.48285622894764, 48.596344739198685, 47.24800229072571, 49.4222342222929, 44.757551327347755, 47.27856405079365, 29.17810421437025, 1.5231000585481524, 3.348300294019282, 7.42276537232101, 9.131973031908274, 10.683154296129942, 6.23226597905159, 3.3723824517801404, 0.31818224990274757, 2.131388043053448, 50.864207446575165, 44.95183490216732, 27.284078747034073, 20.75185876339674, 45.361148938536644, 13.558149375021458, 0.15839846368180588, 0.10118207646883093, 0.05839464683958795, 0.11426267417846248, 0.022384090480045415, 0.0820630016096402, 0.026770110889628995, 0.06020077082212083, 0.01925948919961229, 0.023060493149387185, 0.0602638311102055, 0.1090169146482367, 0.038573426063521765, 0.032481258240295574, 0.03548804728779942, 0.015522981593676377, 0.03733681507583242, 0.18274451431352645, 0.23713871429208666, 0.1582089636940509, 0.1758942982996814, 0.18838226882508025, 0.16267819184577093, 0.12029432356939651, 0.10569206337095238, 0.09776310602319427, 0.23678907367866486, 0.08512243861332536, 0.1394179032649845, 0.135080732870847, 0.13039709825534374, 0.17652127949986607, 0.16625307267531753, 0.1040007162373513, 0.17651468922849745, 0.20879679213976488, 0.1971480718930252, 0.0932438942254521, 0.16733485681470484, 16.54333759099245, 61.24010547995567, 36.98773205280304, 46.77570663392544, 39.3287256360054, 65.57595402002335, 17.170949913561344, 0.2792450861306861, 1.831803449895233, 0.2925986086484045, 0.6833355606067926, 0.8039429294876754, 0.5567658366635442, 0.20599387848051265, 5.025566155090928, 35.55743180215359, 54.251167103648186, 53.43857690691948, 52.96298302710056, 56.273916363716125, 52.560406029224396, 55.81916056573391, 54.27439525723457, 56.75615608692169, 51.510545164346695, 47.46153563261032, 46.68501690030098, 47.39167258143425, 53.067344427108765, 50.220142006874084, 53.448684364557266, 54.50769513845444, 59.5751716196537, 56.43190048635006, 55.327824130654335, 57.60585509240627, 54.5594597607851, 52.22467504441738, 43.36510844528675, 41.89342841506004, 41.86618007719517, 42.827824875712395, 44.40817907452583, 45.00087507069111, 43.978615924715996, 42.66554698348045, 42.361798882484436, 43.235197216272354, 42.35400930047035, 43.38725745677948, 43.27555105090141, 43.238096460700035, 42.82707631587982, 41.10708720982075, 45.576669573783875, 59.368375316262245, 53.312416076660156, 54.16301183402538, 52.50026285648346, 56.35014407336712, 61.43295273184776, 54.17109780013561, 51.29950448870659, 56.261069253087044, 57.22363360226154, 58.146763667464256, 58.76556806266308, 52.917571663856506, 37.37320616841316, 50.7508709281683, 57.37156346440315, 63.5047497600317, 46.108777821063995, 49.833581149578094, 54.80714187026024, 52.76061728596687, 53.355076387524605, 49.594771564006805, 44.41605985164642, 42.12993912398815, 42.23933905363083, 42.33299642801285, 41.05245754122734, 40.17922639846802, 41.74444600939751, 42.28226915001869, 41.32651783525944, 40.29322028160095, 38.52366283535957, 39.441799968481064, 41.18340611457825, 40.32842539250851, 41.45126894116402, 40.67633092403412, 48.315585404634476, 54.66359697282314, 51.8881157040596, 49.12470258772373, 49.5367144793272, 42.32841767370701, 41.06259159743786, 39.199448972940445, 38.22537124156952, 40.3769525885582, 41.83189831674099, 44.66654621064663, 49.071281254291534, 47.50524468719959, 48.75082924962044, 53.73550817370415, 52.41066746413708, 53.96635338664055, 51.007756143808365, 50.6099820882082, 50.84281839430332, 49.21594329178333, 50.754093155264854, 50.96046008169651, 50.207021310925484, 47.73584671318531, 48.41450549662113, 31.09424639493227, 1.7772630765102804, 6.430668532848358, 9.403458964079618, 18.162476308643818, 18.070420548319817, 13.408905733376741, 12.764057535678148, 1.1189147969707847, 3.140607476234436, 58.64677883684635, 42.49237507581711, 28.1966719776392, 30.355170853435993, 52.88272373378277, 18.24445690959692, 0.41491327341645956, 0.21296944323694333, 0.21596475125988945, 0.24277943739434704, 0.1065961254062131, 0.12260544564924203, 0.12404848501319066, 0.20456481375731528, 0.1437879804871045, 0.0997626745083835, 0.169478164461907, 0.22279871423961595, 0.16935939114773646, 0.14980817853938788, 0.13999763934407383, 0.10372943899710663, 0.1702879514778033], [0.01165680409030756, 0.0881443897378631, 0.08564829477109015, 0.025217691945726983, 0.020305440593801904, 0.0884951584157534, 0.04004811060440261, 0.07750166550977156, 0.06834523301222362, 0.06371904062689282, 0.04923215841699857, 0.014499544176942436, 0.037697517400374636, 0.014047612421563827, 0.008863743369147414, 0.09664543162216432, 0.01848368141509127, 0.011357344719726825, 0.06467344996053725, 0.14512329711578786, 0.0214834571670508, 0.01884654524474172, 0.4095377790508792, 29.756999351084232, 35.60511164367199, 27.67341535538435, 36.15798957645893, 38.63835208117962, 32.30055816471577, 0.5466329085174948, 1.326328448485583, 0.014191760692483513, 0.11799512038123794, 0.1080282403563615, 1.147174711804837, 0.23339647916145623, 0.07170915094320662, 9.58266019821167, 38.645081520080566, 51.375519409775734, 50.340416952967644, 51.30542457103729, 52.57474645972252, 54.457477033138275, 53.95411044359207, 50.376347824931145, 46.20054289698601, 44.23206992447376, 42.38529682159424, 42.29216381907463, 49.21391040086746, 46.40451595187187, 48.403436690568924, 50.651327669620514, 53.17373871803284, 52.24233649671078, 52.24447958171368, 50.49839347600937, 55.67699119448662, 49.881063401699066, 39.961319491267204, 36.966829374432564, 41.85706056654453, 38.370219469070435, 38.85883904993534, 38.8631784170866, 41.27257972955704, 39.99698057770729, 41.44877627491951, 39.88170236349106, 40.64227715134621, 39.689041301608086, 41.26795157790184, 40.60447297990322, 39.77016694843769, 36.60214014351368, 45.020098239183426, 49.98273454606533, 51.29413917660713, 50.14102265238762, 54.00911629199982, 48.81368547677994, 53.14264118671417, 53.20113144814968, 50.591165497899055, 48.01931530237198, 51.47396072745323, 49.70447927713394, 57.78545245528221, 34.94186483323574, 16.044194474816322, 69.05218988656998, 60.922628715634346, 37.69487790763378, 41.21348910033703, 53.78811255097389, 47.05176182091236, 50.829572305083275, 45.731879845261574, 43.966798558831215, 37.44854472577572, 36.86621077358723, 35.595691949129105, 37.248618453741074, 35.26658780872822, 35.71975149214268, 37.79766619205475, 37.167147025465965, 36.838373467326164, 37.985459715127945, 37.27236717939377, 36.75394959747791, 36.629688665270805, 38.02185796201229, 35.3348321467638, 38.53862643241882, 46.244096159935, 49.166956320405006, 48.362645879387856, 47.86491438746452, 46.34152673184872, 44.365818947553635, 37.34315738081932, 35.248181596398354, 37.626895755529404, 34.762784242630005, 35.80652363598347, 40.72510130703449, 45.41872724890709, 45.24653188884258, 42.67010673880577, 43.962861970067024, 47.8958485275507, 47.824887335300446, 48.6424894630909, 49.235006868839264, 49.84805837273598, 44.31240141391754, 49.6664547175169, 46.14269860088825, 45.473356917500496, 44.13287624716759, 44.421250373125076, 9.856898132711649, 0.41246338456403464, 2.9913141997531056, 4.347970364615321, 5.583541989326477, 7.066795248538256, 6.268831416964531, 3.654842432588339, 0.32080787932500243, 21.04609027504921, 45.67200645804405, 24.331361688673496, 25.876206792891026, 21.974009983241558, 26.079043708741665, 1.106174080632627, 0.05092264837003313, 0.024161177934729494, 0.02861585442587966, 0.031040269059303682, 0.02946675827843137, 0.05164258727745619, 0.024604099089629017, 0.014360638251673663, 0.07912313201813959, 0.035738032311201096, 0.024097342102322727, 0.025447228945267852, 0.07818770682206377, 0.049909850567928515, 0.051502811184036545, 0.036907983594574034, 0.051608236972242594, 0.006793275661038933, 0.02002966222789837, 0.051020107202930376, 0.05687913675501477, 0.03666232529212721, 0.011754042134271003, 0.03011087010236224, 0.05666265969921369, 0.03507124230964109, 0.05911523141548969, 0.05549428919039201, 0.040891550306696445, 0.018327505713386927, 0.023411660731653683, 0.02931854767666664, 0.01508867955635651, 0.048434631680720486, 0.09782077089766972, 0.08824255361105315, 0.052782633720198646, 0.0739401878672652, 0.011324603019602364, 1.878749574534595, 40.626488998532295, 37.627693712711334, 30.153219290077686, 44.53547224402428, 47.894621193408966, 34.94797870516777, 0.3018533089198172, 1.853182171471417, 0.04418789569172077, 0.7968996511772275, 0.6229978858027607, 2.6927143475040793, 1.3748389016836882, 0.5942840140778571, 10.210631601512432, 43.09298984706402, 51.278294026851654, 51.42465837299824, 51.55800461769104, 54.17276971042156, 55.49699105322361, 56.078101471066475, 51.45581670105457, 47.599506229162216, 44.935142397880554, 44.53511506319046, 44.8869913816452, 50.21544925868511, 48.463739454746246, 51.11621372401714, 52.29547664523125, 54.79593627154827, 52.63901621103287, 53.616627752780914, 52.095303386449814, 55.97554497420788, 50.67722707986832, 42.798163667321205, 38.48263643682003, 43.45361329615116, 41.682668924331665, 41.41423612833023, 39.565806314349174, 42.4122753739357, 43.04154820740223, 42.91901618242264, 40.64011126756668, 42.25928418338299, 42.16602958738804, 43.410766795277596, 41.06362894177437, 41.60892628133297, 38.20701062679291, 47.58942537009716, 52.5175329297781, 51.52861699461937, 51.714343428611755, 52.78572253882885, 48.21255773305893, 58.631150275468826, 52.655169144272804, 51.75757370889187, 51.165402084589005, 54.244194477796555, 50.98659127950668, 57.041421979665756, 38.80934290587902, 20.554039478302002, 58.48151050508022, 66.14892527461052, 50.46475388109684, 40.46739153563976, 53.60193394124508, 49.358241856098175, 52.46194951236248, 48.700489550828934, 45.90459577739239, 38.81126180291176, 38.401981964707375, 37.663848772645, 38.39646466076374, 37.13926412165165, 37.23530396819115, 39.18128214776516, 39.63425204157829, 38.78369428217411, 39.45713594555855, 39.105601608753204, 38.33345264196396, 37.68071606755257, 40.56077532470226, 37.43395730853081, 40.69043576717377, 49.107219725847244, 51.59352131187916, 50.69903410971165, 48.48501071333885, 49.230823293328285, 44.965525567531586, 40.253261625766754, 36.11244522035122, 39.68660943210125, 36.885958313941956, 37.902536764740944, 43.29299971461296, 47.634373158216476, 45.47590658068657, 45.50447724759579, 46.69576272368431, 49.79007348418236, 49.996774792671204, 51.51182949542999, 50.8363701403141, 52.3371148109436, 46.254074424505234, 50.25710642337799, 47.1184254437685, 48.163582161068916, 45.48997722566128, 45.19757531583309, 11.598311439156532, 1.2763542425818741, 6.253983238711953, 10.403622295707464, 7.192611722275615, 7.793305814266205, 6.449977671727538, 1.7644804436713457, 0.15171208418905735, 20.66499162465334, 53.7273196130991, 27.388966418802738, 21.443778835237026, 23.768380098044872, 38.64638105034828, 2.613983997143805, 0.04410814079164993, 0.007985577649378683, 0.09096336347283795, 0.015063382525113411, 0.05353069260308985, 0.009290238012908958, 0.09324321887106635, 0.08228212071117014, 0.12425585591699928, 0.1019377757620532, 0.029093639823258854, 0.047759559311089106, 0.027855084408656694, 0.06725218307110481, 0.03334767112392001, 0.03410953395359684, 0.053286451802705415, 0.14104057947406545, 0.14929968863725662, 0.18925355019746348, 0.16505141684319824, 0.25601069850381464, 0.10542936535784975, 0.1313308090902865, 0.17148509505204856, 0.2393561031203717, 0.1694297170615755, 0.10491413675481454, 0.10286631382768974, 0.1466767309466377, 0.1083480243687518, 0.07847945249523036, 0.18343569128774107, 0.16026129887904972, 0.18610712606459856, 0.17106049752328545, 0.3556745412060991, 0.24870039545930922, 0.13835832418408245, 2.7631884533911943, 47.05406069755554, 48.4694467484951, 36.74308978021145, 47.72911347448826, 51.73520430922508, 40.224029794335365, 1.1399401375092566, 2.821809807792306, 0.12301666967687197, 0.6696070160251111, 0.42617580969817936, 3.708377522416413, 1.6450783819891512, 0.30122776748612523, 11.647473201155663, 43.579610735177994, 54.05390828847885, 52.59838879108429, 53.895133808255196, 55.52165932953358, 56.84542089700699, 58.914653062820435, 55.52204690873623, 48.64484153687954, 47.17943876981735, 47.54090577363968, 47.60324902832508, 53.936783373355865, 49.45464268326759, 53.35075601935387, 54.64196093380451, 56.67905442416668, 55.97672291100025, 56.2375333160162, 53.25970530509949, 59.6667543053627, 53.29298011958599, 44.85049054026604, 41.05077803134918, 46.15006260573864, 42.86148726940155, 43.380007445812225, 42.80026875436306, 44.386725425720215, 44.93939436972141, 44.99620132148266, 43.34124192595482, 44.22829672694206, 43.73595334589481, 44.99578334391117, 42.86201924085617, 42.98907682299614, 40.03824636340141, 51.49998553097248, 54.794834330677986, 54.45161014795303, 54.64489437639713, 55.65022923052311, 49.72575053572655, 61.54802955687046, 54.47770714759827, 51.77794821560383, 54.07480336725712, 56.32452204823494, 54.16332721710205, 58.562058582901955, 42.26420871913433, 23.65503028035164, 62.845245748758316, 69.05024439096451, 53.33755552768707, 45.28245896100998, 55.85161082446575, 49.54402528703213, 53.92852261662483, 50.413452833890915, 48.513706773519516, 39.54823225736618, 39.372290298342705, 40.13571493327618, 41.087054684758186, 38.682992085814476, 39.50917415320873, 41.0453025251627, 41.48174710571766, 40.13301707804203, 41.50312475860119, 40.26619613170624, 39.73194099962711, 39.53002743422985, 42.773210406303406, 39.77204404771328, 42.135954201221466, 49.72263850271702, 53.09116534888744, 50.74256457388401, 50.608530566096306, 50.72790116071701, 47.81705595552921, 41.53127744793892, 38.46456080675125, 43.80687274038792, 39.182574078440666, 40.27128025889397, 44.992640912532806, 48.80740441381931, 46.653721779584885, 46.13094203174114, 48.3950999379158, 52.62114576995373, 50.435294061899185, 53.39139103889465, 52.640095353126526, 54.72391873598099, 47.897725626826286, 51.71019405126572, 49.05960828065872, 48.26035536825657, 45.59294790029526, 46.89557880163193, 11.730267908424139, 1.1645868024788797, 8.619222845882177, 9.972738716751337, 14.572234209626913, 14.668009020388126, 12.937233243137598, 12.446920853108168, 0.37431761738844216, 26.483423709869385, 58.77172753214836, 35.45986443758011, 38.82676877081394, 31.62656933069229, 46.04180261492729, 2.9206417920067906, 0.2440965417190455, 0.10457450029207394, 0.2056144183734432, 0.14599512767745182, 0.14272032683948055, 0.16424216417362913, 0.18614795902976766, 0.2090833056718111, 0.2103689726209268, 0.15795234387042, 0.11816416677902453, 0.10261657371302135, 0.1943668586318381, 0.1550320372916758, 0.08205170612200163, 0.11988773054326884, 0.1605474264943041], [0.01725439913570881, 0.07620140793733299, 0.04358903817774262, 0.04234750675095711, 0.008235313125624089, 0.0503423779446166, 0.020179737475700676, 0.04999162039894145, 0.03630535597039852, 0.13775451283436269, 0.044139978926978074, 0.07393584630335681, 0.08477459399728104, 0.04451284505194053, 0.009794349243748002, 0.044538556758197956, 0.046052207762841135, 0.039618626033188775, 0.08374127210117877, 0.024623584176879376, 0.03183231317962054, 0.05469485513458494, 0.01835688919527456, 7.211939385160804, 41.48853734135628, 23.968940936028957, 32.399892434477806, 35.669259801506996, 45.42067654430866, 6.328651607036591, 0.025453793241467793, 0.47074361820705235, 0.8636683027725667, 1.5669219195842743, 2.1113308193162084, 1.5320967882871628, 0.3463905112585053, 1.5544334147125483, 18.194852471351624, 50.275417640805244, 51.38691879808903, 52.16126784682274, 51.69161684811115, 53.9482169598341, 52.24150434136391, 50.5800586938858, 44.58927735686302, 44.292672872543335, 40.76434180140495, 45.592799708247185, 44.50138807296753, 49.652482867240906, 50.938193276524544, 53.161286786198616, 52.465528920292854, 49.65293884277344, 51.33277930319309, 51.773795038461685, 51.77481718361378, 49.13181200623512, 39.27419476211071, 41.202321499586105, 39.93142269551754, 39.748903289437294, 41.53367131948471, 41.591686606407166, 39.94249150156975, 41.347583904862404, 39.48936201632023, 39.86461468040943, 39.612068831920624, 40.27058109641075, 41.635676845908165, 41.1091922968626, 40.20534239709377, 39.43155191838741, 47.90336072444916, 52.8240092843771, 52.69333429634571, 50.77762149274349, 48.8470096886158, 51.66569843888283, 48.25349673628807, 52.42776654660702, 53.434533923864365, 52.83171147108078, 53.69239188730717, 51.32774077355862, 52.15994171798229, 47.80177317559719, 51.763839572668076, 49.809760227799416, 27.948372401297092, 44.42980371415615, 53.40704619884491, 52.702719792723656, 49.7712454944849, 47.034932523965836, 42.33367279171944, 41.30386725068092, 37.37933523952961, 34.62080106139183, 36.20258018374443, 36.365941017866135, 36.08072452247143, 36.413731053471565, 36.17868326604366, 36.46875210106373, 36.704670041799545, 35.454886704683304, 36.15183770656586, 36.25162415206432, 35.674077942967415, 37.16876573860645, 35.56084021925926, 39.39847469329834, 48.34149241447449, 48.76411333680153, 49.00403246283531, 48.96490976214409, 49.53047141432762, 47.59838528931141, 43.675190806388855, 39.24333281815052, 35.35911284387112, 34.984221160411835, 35.76510205864906, 34.21545401215553, 40.6363570690155, 49.752288311719894, 49.10158462822437, 47.82326862215996, 47.54347823560238, 48.93060900270939, 48.95276561379433, 48.343487307429314, 49.465844482183456, 47.87879504263401, 48.05832400918007, 47.968538627028465, 44.997759237885475, 49.96983803808689, 30.762854777276516, 2.5367348548024893, 2.641917960718274, 2.2372325509786606, 9.481335785239935, 13.250119853764772, 3.592913830652833, 4.506597127765417, 0.32333646551705897, 0.4676557198399678, 31.067058853805065, 36.19182676076889, 50.26023365557194, 37.20218874514103, 25.54508116096258, 9.071796610951424, 0.2734048885758966, 0.09645821002777666, 0.046952113771112636, 0.0238780875588418, 0.03904918354237452, 0.02820776226144517, 0.02542888676543953, 0.08151741916663013, 0.07269798108609393, 0.055426104372600093, 0.14406218921067193, 0.07043598176096566, 0.04758524366479833, 0.12316585620283149, 0.026053877154481597, 0.02226673466793727, 0.012130761861044448, 0.017921595463121776, 0.07134564701118506, 0.020585321180988103, 0.030346674539032392, 0.031762120852363296, 0.10489098916877992, 0.002718151813496661, 0.045924127916805446, 0.061606647141161375, 0.03701362460560631, 0.07647190592251718, 0.01137992270741961, 0.061683696912950836, 0.10740709243691526, 0.023712685106147546, 0.03337590242153965, 0.07249026879435405, 0.08248359154094942, 0.0479594567877939, 0.10020650108344853, 0.03492613017442636, 0.07152073449105956, 0.013788976739306236, 0.0717409148637671, 14.457762502133846, 46.96066550910473, 25.346387922763824, 38.44044730067253, 42.525190114974976, 47.88874290883541, 5.3412118926644325, 0.09106629935558885, 0.3817972488468513, 0.23681760183535516, 2.3402333864942193, 3.2272335654124618, 3.9547864627093077, 0.3706737910397351, 2.1455857437103987, 21.550845690071583, 50.92704847455025, 51.0221953690052, 51.66907645761967, 52.46435098350048, 56.396927163004875, 54.22516509890556, 53.78402017056942, 47.39517979323864, 45.81815801560879, 43.34603726863861, 46.11468270421028, 45.74935130774975, 50.22949330508709, 53.707800060510635, 53.92902038991451, 54.133738204836845, 51.98516249656677, 53.573872447013855, 54.23515476286411, 53.00202213227749, 50.627901926636696, 40.843757539987564, 42.79047288000584, 42.18907915055752, 42.08240747451782, 41.972741559147835, 41.9488712400198, 42.46550291776657, 41.58596031367779, 41.89134232699871, 42.04472489655018, 39.80109728872776, 42.37563394010067, 43.416846469044685, 41.64701543748379, 42.9754089564085, 41.365317553281784, 50.49102187156677, 54.54469375312328, 55.23556888103485, 52.90843315422535, 51.40428766608238, 53.217394575476646, 49.074841663241386, 57.751790061593056, 54.62693274021149, 52.30720281600952, 53.179655000567436, 53.184062764048576, 52.32212081551552, 47.274274080991745, 54.96604934334755, 53.14307816326618, 33.056261613965034, 43.22165094316006, 53.539161309599876, 53.97157430648804, 52.483296766877174, 47.608097568154335, 45.92800632119179, 43.42275135219097, 40.74107564985752, 37.31886528432369, 38.45306262373924, 38.66932041943073, 39.10751290619373, 39.66836281120777, 37.46283195912838, 38.0582220107317, 37.9032701253891, 37.94692598283291, 37.804361432790756, 38.9690787345171, 37.890901789069176, 38.78140680491924, 36.9569157063961, 40.02704456448555, 49.9392344802618, 50.836286544799805, 50.06961688399315, 49.39483009278774, 50.13906195759773, 49.26434889435768, 44.69470649957657, 41.22699737548828, 36.58022291958332, 37.84159183502197, 36.20594300329685, 37.35527493059635, 44.4427952170372, 51.848784014582634, 49.52048934996128, 48.94831985235214, 49.46280464529991, 51.11630491912365, 50.22182911634445, 50.76205372810364, 50.25869093835354, 48.18904459476471, 49.755366146564484, 49.887811839580536, 47.19429597258568, 51.20431199669838, 31.961468160152435, 3.1942717591300607, 4.143811594694853, 5.7366566732525826, 8.096463046967983, 11.833709757775068, 7.051331028342247, 7.2841250617057085, 0.3874681773595512, 0.3076384391169995, 37.70839758217335, 41.55727945268154, 47.28221945464611, 34.54984366893768, 30.8370590955019, 18.782620131969452, 0.022015350696165115, 0.09090040708542801, 0.016128898787428625, 0.030825205794826616, 0.03943551593692973, 0.05394918596721254, 0.03636987828940619, 0.0546419474267168, 0.02292152785230428, 0.09881924153887667, 0.027475149327074178, 0.05434666913060937, 0.07008693486568518, 0.10774017573567107, 0.04219909576931968, 0.06002608410199173, 0.032040233272709884, 0.045575804615509696, 0.18449519615387544, 0.1411438567447476, 0.15533518977463245, 0.12616693071322516, 0.15053962444653735, 0.11192726160516031, 0.07718245295109227, 0.09795045378268696, 0.10974189644912258, 0.22112137143267319, 0.14463696774328128, 0.2530690922867507, 0.2454544641659595, 0.12000660775811411, 0.11439888796303421, 0.17712163244141266, 0.11661790209473111, 0.2099476256989874, 0.11062023564591072, 0.13218844978837296, 0.1693757183966227, 0.12952467397553846, 0.25192271161358804, 17.781873531639576, 58.19656379520893, 33.536130264401436, 41.11297309398651, 46.352743729949, 56.88053861260414, 8.832497801631689, 0.2801098662894219, 0.6129801389761269, 2.1105661103501916, 3.953531817533076, 4.276771685108542, 4.284706134349108, 0.699801561422646, 2.6605702098459005, 21.141467057168484, 53.416370898485184, 52.16870404779911, 53.11227321624756, 54.33739587664604, 59.24517072737217, 58.31290975213051, 56.22882038354874, 48.78099203109741, 48.951606675982475, 45.34659571945667, 48.47782909870148, 48.91616217792034, 52.922724187374115, 56.207115948200226, 55.97505860030651, 56.98613114655018, 55.0690808147192, 55.21793782711029, 55.81430442631245, 54.71948057413101, 52.34250292181969, 42.637911066412926, 44.8490846157074, 45.62697507441044, 44.554429426789284, 44.18388091027737, 45.46240970492363, 41.98632203042507, 44.7494425624609, 42.794888243079185, 43.754716739058495, 42.9437680542469, 44.71742928028107, 45.47554939985275, 44.974907264113426, 45.22256277501583, 44.46582958102226, 51.4900566637516, 54.616597294807434, 57.05343313515186, 55.898557305336, 53.54583375155926, 54.01747204363346, 51.77813820540905, 59.05152551829815, 53.62686440348625, 53.374953120946884, 56.79199196398258, 55.51394194364548, 54.40775290131569, 52.289370372891426, 51.492366939783096, 54.398128017783165, 41.178971752524376, 47.82680243253708, 56.19624473154545, 55.28696112334728, 54.40260037779808, 49.010381922125816, 48.48784156143665, 44.62023049592972, 41.822068244218826, 39.16811965405941, 42.46125094592571, 39.04689475893974, 41.08597554266453, 41.14594392478466, 39.289162158966064, 41.060976684093475, 41.74788102507591, 38.18828143179417, 40.224474370479584, 40.86140759289265, 39.67853486537933, 41.04634366929531, 39.367882534861565, 43.448179587721825, 51.64742521941662, 51.47355034947395, 51.81602217257023, 50.07918857038021, 52.650917172431946, 50.56352958083153, 47.1571871638298, 43.391239643096924, 38.564069867134094, 40.14001630246639, 37.91653901338577, 38.11612330377102, 45.5785770714283, 53.46270941197872, 51.59270815551281, 49.71091613173485, 50.52313394844532, 51.82065412402153, 51.06972701847553, 51.37341812252998, 52.10417591035366, 49.31915335357189, 50.88760279119015, 49.847902581095695, 47.80079662799835, 51.730849742889404, 34.55252632498741, 3.716945112682879, 5.547606842592359, 6.777384728193283, 16.243953555822372, 22.655471116304398, 11.678071059286594, 17.26402971893549, 2.3032352467998862, 0.5821771512273699, 40.613068118691444, 48.88515964150429, 58.04942049086094, 47.18665458261967, 42.55772016942501, 29.16964966803789, 0.3640212683239952, 0.21642848965711892, 0.1622159971157089, 0.12000807721051387, 0.11507461342262104, 0.12426456130924635, 0.12096149948774837, 0.16171316237887368, 0.1166638039285317, 0.19292253535240889, 0.26265885739121586, 0.11547985573997721, 0.19997948402306065, 0.33488743007183075, 0.11029143453924917, 0.06931738709681667, 0.11697091205860488, 0.2037381799891591], [0.053755489134346135, 0.030040193523745984, 0.022746972863387782, 0.029364332622208167, 0.02961151232739212, 0.039639383903704584, 0.025383046158822253, 0.011892927650478669, 0.0606158391747158, 0.0026077492293552496, 0.043641426382237114, 0.008597790110798087, 0.03672085847938433, 0.06213107095391024, 0.046447694548987783, 0.02703366979403654, 0.1293948426609859, 0.07484853209462017, 0.13145220960723236, 0.07154006001655944, 0.05750786200223956, 0.055416007453459315, 0.08431046968325973, 0.575296136084944, 28.9214051887393, 35.19840806722641, 29.187529608607292, 35.0008300691843, 38.54276821017265, 25.369963757693768, 0.23159037373261526, 0.35358726570848376, 0.3512748522916809, 1.0692427936010063, 2.6156670693308115, 2.976573365740478, 0.5857686710078269, 0.23316139646340162, 4.126741485670209, 33.59650522470474, 54.557248279452324, 52.46727682650089, 52.95468807220459, 53.93915444612503, 52.51663237810135, 49.07367892563343, 45.63868224620819, 42.81795300543308, 42.90789417922497, 44.55596834421158, 50.961793810129166, 50.984474793076515, 54.63013976812363, 55.35713955760002, 49.83580403029919, 50.13133317232132, 53.612675964832306, 55.187037885189056, 52.45813071727753, 47.04855099320412, 39.25661310553551, 40.005541518330574, 38.83656844496727, 40.67098081111908, 40.01921318471432, 40.21596662700176, 40.858971923589706, 42.97990411520004, 39.834235310554504, 40.80298952758312, 40.82878254354, 40.96087485551834, 39.68815594911575, 40.42907439172268, 37.96400986611843, 43.33160184323788, 51.94854386150837, 53.86027067899704, 52.14790016412735, 51.58802680671215, 50.306803956627846, 55.28730310499668, 55.00200681388378, 47.78086669743061, 49.774129539728165, 53.146262392401695, 53.55387032032013, 52.15282469987869, 49.293842911720276, 61.41224004328251, 49.97866876423359, 36.416166722774506, 49.50534716248512, 54.95059177279472, 50.52352912724018, 51.095470637083054, 46.792699322104454, 43.804520666599274, 40.973965153098106, 37.69794434309006, 39.020964950323105, 38.42644885182381, 39.156222492456436, 38.061178252100945, 36.71012654900551, 37.958500161767006, 36.53525613248348, 37.92372442781925, 36.3215745985508, 37.070529609918594, 35.845418348908424, 35.44464245438576, 37.68999136984348, 36.040606275200844, 35.602071806788445, 36.820202842354774, 44.492595344781876, 49.30154129862785, 48.42205949127674, 48.04688282310963, 47.18792371451855, 48.60675238072872, 46.50277867913246, 44.80047382414341, 39.14739176630974, 34.7812170535326, 33.908498883247375, 35.20634204149246, 35.00858165323734, 40.16173213720322, 45.67407354712486, 48.70675541460514, 48.77942651510239, 49.629285112023354, 46.9828525185585, 48.74910034239292, 49.54126663506031, 48.287425115704536, 50.79002022743225, 52.30001360177994, 42.71765738725662, 51.013691425323486, 17.342628501355648, 0.28858979407232255, 3.449889742769301, 7.252993807196617, 12.572593409568071, 8.581423424184322, 4.455216759815812, 2.308568973094225, 0.7420112995896488, 6.237610867246985, 42.731929421424866, 28.102408535778522, 25.860960111021996, 34.073220044374466, 15.0124092400074, 1.9406188046559691, 0.038986186336842366, 0.06530552229378372, 0.03029183910257416, 0.027023908696719445, 0.03790045768255368, 0.058095527929253876, 0.03307433442387264, 0.079372998297913, 0.03879123898514081, 0.023940372302604374, 0.07155803483328782, 0.03081652452237904, 0.02878126430005068, 0.02526489810406929, 0.06242290197405964, 0.0760585445095785, 0.024453814185108058, 0.09589672336005606, 0.028368726671033073, 0.038115027418825775, 0.12204344689962454, 0.07550983762484975, 0.027216106391279027, 0.028065529659215827, 0.07315628696233034, 0.045696700472035445, 0.1076213430496864, 0.022936558198125567, 0.00364035379334382, 0.025750260829227045, 0.02877775208617095, 0.0908231049834285, 0.037800638820044696, 0.023689687805017456, 0.0578294754086528, 0.03186355759680737, 0.13257613289169967, 0.03520620557537768, 0.041523967738612555, 0.014027599481778452, 0.11272892210399732, 2.0624564168974757, 39.794979616999626, 32.57089085876942, 30.449346899986267, 43.050169944763184, 46.80430009961128, 24.50357034802437, 0.18394370621535927, 0.28583286388311535, 0.2016778741381131, 2.631853250786662, 4.8314260225743055, 7.396429935470223, 2.8455580584704876, 0.7406028814148158, 4.392967550083995, 37.770060673356056, 54.99997392296791, 54.99347627162933, 54.55785244703293, 57.2615859657526, 55.06195239722729, 50.84389753639698, 47.39007666707039, 44.80395443737507, 43.36378611624241, 47.08713412284851, 51.61547273397446, 53.6197853833437, 56.21247746050358, 57.578511759638786, 50.024961680173874, 52.04901807010174, 53.669125735759735, 56.377426609396935, 55.01990005373955, 49.44085702300072, 40.77800586819649, 41.62711210548878, 41.16258703172207, 41.13523229956627, 41.23718462884426, 41.52794502675533, 40.74039548635483, 45.07525987923145, 40.53300641477108, 42.478627413511276, 41.79095171391964, 42.453210577368736, 41.56004570424557, 42.10435889661312, 40.067694783210754, 45.5976976454258, 52.24932052195072, 55.72294972836971, 54.29841376841068, 54.99102160334587, 51.3034562766552, 56.18961028754711, 53.26559118926525, 50.68711414933205, 54.118269234895706, 56.29752829670906, 53.85455198585987, 54.51036639511585, 51.60095751285553, 59.98874142765999, 52.57085546851158, 34.83362004160881, 48.52846898138523, 56.25558614730835, 53.322303146123886, 52.05366142094135, 50.26527598500252, 46.534354984760284, 43.16756084561348, 39.36966083943844, 40.825784504413605, 40.86991913616657, 41.27487100660801, 39.22728627920151, 37.29962691664696, 39.35674153268337, 38.829721212387085, 39.3632847815752, 36.89488783478737, 39.60747107863426, 37.610397040843964, 37.55987495183945, 38.430906012654305, 37.21062809228897, 37.13780879974365, 39.62059177458286, 47.008580937981606, 51.5614890307188, 50.663376823067665, 50.51914416253567, 49.79547679424286, 51.277085691690445, 47.2323053330183, 45.38900904357433, 41.14877477288246, 36.95799104869366, 37.242531180381775, 36.90332718193531, 35.75162038207054, 42.04619541764259, 48.52645508944988, 51.69068209826946, 49.631849974393845, 51.030231937766075, 47.79587209224701, 50.34395456314087, 51.39132656157017, 49.91542115807533, 52.83499829471111, 53.16807322204113, 43.832202181220055, 51.998370587825775, 18.304468989372253, 0.2850026678061113, 5.9099572990089655, 3.9182998705655336, 6.680394457653165, 12.23365729674697, 7.732882406562567, 1.1432773084379733, 0.39419755688868463, 6.306845052167773, 44.63994383811951, 39.521713480353355, 37.935560792684555, 37.24214740097523, 27.001170627772808, 9.289589524269104, 0.009608085947547806, 0.012448333345673745, 0.070197500026552, 0.051305199522175826, 0.08321965360664763, 0.04718805736047216, 0.0751397582644131, 0.011553121421457035, 0.09601012352504767, 0.03576301671273541, 0.0027610683582679485, 0.04435073402419221, 0.06274342071264982, 0.052422064982238226, 0.020807562868867535, 0.06507436555693857, 0.05115599815326277, 0.031025837997731287, 0.10696125464164652, 0.1308672784944065, 0.1771266938885674, 0.13345501385629177, 0.12951263634022325, 0.10232629749225453, 0.1488934815279208, 0.11758643449866213, 0.19809971301583573, 0.09632801506086253, 0.15960553719196469, 0.09698917958303355, 0.1556975211133249, 0.15286743000615388, 0.06440045093768276, 0.13119979033945128, 0.19179268972948194, 0.2108978567412123, 0.24200430867495015, 0.20207464112900198, 0.10073519224533811, 0.11322881793603301, 0.21863351430511102, 1.9987433357164264, 45.400845408439636, 45.87657608091831, 38.113349452614784, 46.34739741683006, 48.403926864266396, 32.613824754953384, 0.31871526036411524, 0.5704254505690187, 0.8471397240646183, 5.28172560967505, 7.639245456084609, 10.381629075855017, 2.2408266831189394, 1.0855873790569603, 6.245741955935955, 38.791244477033615, 55.60058109462261, 54.42193754017353, 57.18947343528271, 58.762281239032745, 58.90655189752579, 52.60696493089199, 50.777093321084976, 46.5516060590744, 45.36075755953789, 47.97964543104172, 55.69334551692009, 55.156122744083405, 60.046654120087624, 59.50566574931145, 52.50074923038483, 53.029065281152725, 55.826171189546585, 58.04772958159447, 58.01540471613407, 50.914664939045906, 44.99230273067951, 44.1933424025774, 42.992040663957596, 44.45370443165302, 43.6961504817009, 42.89964482188225, 43.818104937672615, 47.33016528189182, 43.42156581580639, 45.43155916035175, 44.717136695981026, 44.50129687786102, 43.18610765039921, 44.024775847792625, 41.75506263971329, 46.8451327085495, 56.718667298555374, 57.57678285241127, 56.16763986647129, 56.53014421463013, 54.094334319233894, 58.231407925486565, 56.686304435133934, 52.502770721912384, 58.16448211669922, 54.99127998948097, 55.02264730632305, 55.50558999180794, 58.83684463799, 63.20338413119316, 49.939055889844894, 41.99564293026924, 50.91140851378441, 58.50418768823147, 55.74946090579033, 53.928173035383224, 51.422606483101845, 48.63259099423885, 45.09887181222439, 41.52754604816437, 43.617015928030014, 43.16466920077801, 43.32418084144592, 41.430943831801414, 39.21325743198395, 39.863030165433884, 40.104860588908195, 42.0981652289629, 38.57450790703297, 41.96924574673176, 39.224231243133545, 39.3968141824007, 42.463063448667526, 39.58061031997204, 39.40817557275295, 40.88813155889511, 48.305998519062996, 53.66992749273777, 54.323876202106476, 52.707727923989296, 51.16050414741039, 52.96001918613911, 48.73749956488609, 47.126959785819054, 44.331381395459175, 38.93163554370403, 38.35879348218441, 39.92502003908157, 37.5624930113554, 42.78828799724579, 50.32946594059467, 53.50969009101391, 51.65180638432503, 51.94103546440601, 49.67912703752518, 51.135406494140625, 53.70724529027939, 50.49782730638981, 56.61230720579624, 55.29345877468586, 46.31643667817116, 50.03550611436367, 20.636122673749924, 0.6066270580049604, 6.729694437235594, 14.194148797541857, 22.020350396633148, 14.41229984164238, 13.712835274636745, 11.695709712803364, 1.1549830553121865, 8.493454344570637, 54.53729934990406, 37.48490497469902, 39.90139290690422, 42.64381594955921, 37.73885674774647, 17.17964194715023, 0.16117301245685667, 0.13065129867754877, 0.14926976524293423, 0.12023937495541759, 0.20808474597288296, 0.14729626098414883, 0.18368310848018155, 0.2629459497984499, 0.20220407168380916, 0.1414350012782961, 0.1827456126920879, 0.14720861334353685, 0.11894221213879064, 0.22412335878470913, 0.17084867373341694, 0.15937593154376373, 0.15980015799868852, 0.18010824249358848], [0.0002828041272096016, 0.065658420935506, 0.0637035297404509, 0.036297459519119, 0.05451731114590075, 0.04835489533434156, 0.0633949892653618, 0.008925163510866696, 0.04438088377355598, 0.05790748255094513, 0.060101052149548195, 0.02356413682718994, 0.037875035413890146, 0.03208924099453725, 0.06708421278744936, 0.040530729238525964, 0.05529800968361087, 0.028825776462326758, 0.046393621669267304, 0.01615739911358105, 0.04042215303343255, 0.14134077820926905, 0.03208318506949581, 0.04783535114256665, 5.1508919801563025, 43.81421394646168, 34.201976135373116, 37.03582227230072, 35.32883606851101, 39.65988926589489, 3.7282219575718045, 0.2636721561430022, 0.2780686039477587, 1.8766897288151085, 3.0285510141402483, 4.7645453363657, 1.513916663825512, 0.5656778428237885, 0.38223737210500985, 11.55517615377903, 47.40485027432442, 51.38057313859463, 55.8257570117712, 54.051081240177155, 51.651848182082176, 47.47888930141926, 46.32051765918732, 41.916025802493095, 43.449646309018135, 48.0221613496542, 53.19356605410576, 53.183564990758896, 54.3086352199316, 52.4172031134367, 50.80740809440613, 51.3032852858305, 54.370978474617004, 51.84642054140568, 50.45341528952122, 41.64558671414852, 41.785897985100746, 39.67003472149372, 39.871203526854515, 39.94907654821873, 40.25343641638756, 39.3107184022665, 39.917219057679176, 40.475891679525375, 39.181817919015884, 39.199680760502815, 40.87086908519268, 40.18270701169968, 40.065088123083115, 40.01186057925224, 41.9687669724226, 43.08220222592354, 51.51667423546314, 51.44242621958256, 52.398401722311974, 52.96220026910305, 52.54997938871384, 52.88545958697796, 52.53700688481331, 52.581722885370255, 46.70121543109417, 49.37288247048855, 51.33437141776085, 52.938527539372444, 58.07216987013817, 61.54001198709011, 52.1966515481472, 51.92213527858257, 51.17252290248871, 53.29196177423, 52.19901122152805, 48.13563846051693, 43.78204107284546, 39.874505549669266, 37.607072219252586, 38.007164150476456, 37.78291538357735, 40.483909249305725, 40.014091059565544, 38.50475884974003, 38.48744697868824, 38.0493076890707, 36.885924115777016, 38.04370678961277, 36.868635043501854, 37.50698558986187, 37.59694576263428, 37.6840028911829, 35.14812536537647, 35.96688263118267, 35.224763453006744, 37.277071326971054, 41.60855770111084, 47.59529985487461, 47.50802233815193, 49.96254242956638, 49.278210550546646, 48.65246392786503, 49.94447819888592, 48.381287679076195, 45.298653692007065, 41.596736535429955, 35.98854526877403, 34.18905682861805, 36.12554311752319, 34.72141206264496, 37.28297621011734, 42.23822571337223, 45.40575474500656, 44.1499487310648, 46.2537856400013, 46.993480548262596, 48.52471098303795, 48.779544308781624, 49.00855042040348, 48.510944321751595, 48.49906615912914, 46.792015358805656, 7.13809272274375, 0.489630326628685, 4.9441455490887165, 2.9743763711303473, 5.692270305007696, 5.367246195673943, 6.513988086953759, 2.1611356968060136, 0.2566207735799253, 19.420959278941154, 46.000894010066986, 25.486007630825043, 48.34572158753872, 38.53266455233097, 8.570683300495148, 0.5574232607614249, 0.20448531489819288, 0.06788554674130864, 0.06983370665693656, 0.05201924577704631, 0.04741119519167114, 0.022899914656591136, 0.029503667137760203, 0.010995158099831315, 0.022113536833785474, 0.0407030410860898, 0.03347362100612372, 0.006649166816714569, 0.027883933544217143, 0.028578388955793343, 0.017794890445657074, 0.03906010795617476, 0.02162048731406685, 0.07138116619898938, 0.023729702552373055, 0.021981798199703917, 0.047501021035714075, 0.0582410185597837, 0.057530679332558066, 0.047908664200804196, 0.03951895560021512, 0.003124717009086453, 0.05544301791815087, 0.04100810459931381, 0.07357027920079418, 0.049699407172738574, 0.05584333608567249, 0.04418198448547628, 0.07004432074609213, 0.023757826238579582, 0.07190720789367333, 0.09602116668247618, 0.012257503058208385, 0.03712772981089074, 0.04560051442240365, 0.09450644327444024, 0.04474544526601676, 0.05297626004903577, 10.918234381824732, 49.3914482742548, 33.07188257575035, 42.365743070840836, 40.194402784109116, 44.20973852276802, 3.1257806718349457, 0.3190804267069325, 0.3667909634532407, 1.98756433557719, 4.609870361164212, 6.85417290776968, 5.486479522660375, 0.9891547879669815, 0.5811766174156219, 14.746859539300203, 48.98771993815899, 52.18435540795326, 55.86727358400822, 55.0316072255373, 54.97750572860241, 50.205015018582344, 47.129919826984406, 44.12707395851612, 44.664699509739876, 51.78475745022297, 53.49813111126423, 55.96386440098286, 56.36805631220341, 51.84769347310066, 50.87043531239033, 51.59825585782528, 57.16249108314514, 53.95869679749012, 52.68934831023216, 44.88498888909817, 42.31707148253918, 42.13343873620033, 43.144119903445244, 43.22626389563084, 42.00556419789791, 40.33746510744095, 41.14874057471752, 42.77129530906677, 41.611426547169685, 42.209339663386345, 41.95480652153492, 40.3700065612793, 41.586051508784294, 42.74801775813103, 41.84911139309406, 44.30291712284088, 53.47141854465008, 53.9991570264101, 54.34302717447281, 55.50945058465004, 53.315767496824265, 53.42472285032272, 53.60288389027119, 52.806188240647316, 48.17547172307968, 53.18812094628811, 54.45973791182041, 54.76065516471863, 57.45797462761402, 62.48268060386181, 51.96208633482456, 51.57244384288788, 55.20634464919567, 53.43386135995388, 53.490402325987816, 50.00945471227169, 44.64137256145477, 42.07563243806362, 39.503782242536545, 39.59291785955429, 40.801629200577736, 40.57620249688625, 42.06951856613159, 40.686240792274475, 41.6094658523798, 40.33561460673809, 38.22207681834698, 40.137831419706345, 38.03383111953735, 37.99084782600403, 39.04777251183987, 38.49365584552288, 36.882390305399895, 38.333817422389984, 38.04993085563183, 39.252425730228424, 43.24391394853592, 49.096553698182106, 50.28638385236263, 50.49195282161236, 50.51610432565212, 49.938542917370796, 51.41960844397545, 50.92280030250549, 45.99837474524975, 41.09516344964504, 37.74933658540249, 35.57045370340347, 37.59209722280502, 37.116989716887474, 40.61659812927246, 44.19108912348747, 47.18688257038593, 47.28494010865688, 49.01284039020538, 49.28860679268837, 49.32095445692539, 50.94179168343544, 51.29446975886822, 49.30211126804352, 50.6536303460598, 48.764975890517235, 7.739804210141301, 1.3099841005168855, 5.948350913822651, 8.41528968885541, 8.44887513667345, 7.021945305168629, 5.656414479017258, 1.325717275030911, 0.3967578773153946, 20.507290586829185, 53.96247759461403, 28.99035058915615, 47.93038107454777, 46.05155289173126, 18.95145457237959, 2.189082484692335, 0.3365436661988497, 0.0651316370931454, 0.04768332961248234, 0.05323331773979589, 0.09806251808186062, 0.04367534253105987, 0.04334665274654981, 0.06346029083942994, 0.02315332840225892, 0.025766025901248213, 0.0359937652683584, 0.05679315152519848, 0.03449238938628696, 0.05235323078522924, 0.026084654018632136, 0.009352457818749826, 0.05007835148717277, 0.028578962264873553, 0.13567439164035022, 0.23083813284756616, 0.14304721320513636, 0.16887349222088233, 0.20894554822007194, 0.10535869805607945, 0.12932704004924744, 0.10610812620143406, 0.1783151988638565, 0.1378458712133579, 0.248480363516137, 0.14709540613694116, 0.1733487911405973, 0.16636157466564327, 0.16283941600704566, 0.12773620197549462, 0.14516478317091241, 0.25657360267359763, 0.11303896913887002, 0.17001773550873622, 0.10522877026232891, 0.1964940913603641, 0.13057114672847092, 0.1709845312871039, 11.781857740134, 59.00011047720909, 42.763391733169556, 47.983243837952614, 45.251422226428986, 51.16604804992676, 5.1953372452408075, 0.5215260526165366, 0.9618233889341354, 6.7271271999925375, 11.151983588933945, 16.29096083343029, 4.693692913278937, 0.9375527256634086, 0.6996493320912123, 14.687380380928516, 51.782678961753845, 53.31759139895439, 58.542584627866745, 58.44751372933388, 58.52038621902466, 52.9709891974926, 50.29950074851513, 46.01604379713535, 48.135068491101265, 54.304307252168655, 56.10744349658489, 58.061834424734116, 58.653109297156334, 54.171306788921356, 51.09024591743946, 53.72321583330631, 57.88880690932274, 56.202578991651535, 54.64544154703617, 46.01060628890991, 46.05047754943371, 44.723987728357315, 44.744027853012085, 43.360438495874405, 43.51482421159744, 41.66128367185593, 44.807552844285965, 45.0438279658556, 43.45635674893856, 43.530509769916534, 45.378179624676704, 42.44618475437164, 42.477871254086494, 44.114420637488365, 44.91950623691082, 47.15970262885094, 55.59496499598026, 57.78283819556236, 56.48515842854977, 57.18666538596153, 54.67018201947212, 56.900555938482285, 55.69122903048992, 54.89348463714123, 51.39509215950966, 57.65700414776802, 56.89504623413086, 57.18691997230053, 56.940123215317726, 59.72165755927563, 54.343220964074135, 51.67195290327072, 56.8355680257082, 56.385265588760376, 54.37126725912094, 50.592237040400505, 48.13181206583977, 45.17685502767563, 40.747166723012924, 42.51067869365215, 43.39192360639572, 43.38088519871235, 44.39698487520218, 43.15161310136318, 43.40937227010727, 42.26483188569546, 40.78254662454128, 42.114523351192474, 40.42704150080681, 40.417287424206734, 42.42129608988762, 40.95190733671188, 39.04326595366001, 39.78845916688442, 38.641718700528145, 41.668890863657, 45.661359429359436, 49.81370061635971, 52.362394854426384, 52.997868955135345, 52.731412053108215, 51.725499629974365, 53.324814811348915, 54.34708535671234, 47.535054087638855, 45.839208886027336, 40.16928233206272, 37.7893902361393, 39.49561648070812, 39.71505470573902, 40.455695763230324, 46.164619624614716, 50.3369477391243, 50.24224542081356, 51.57885029911995, 50.598179921507835, 52.78572253882885, 53.748009502887726, 51.748514994978905, 52.871179953217506, 50.58651454746723, 47.8855586796999, 9.648396670818329, 1.8403959763236344, 7.277399422600865, 10.967935714870691, 14.285171963274479, 10.067168399691582, 17.000675350427628, 8.734285421669483, 0.41614292305894196, 24.01037961244583, 60.49911864101887, 33.968087285757065, 58.196738585829735, 49.376473277807236, 33.139553144574165, 5.971271758899093, 0.5316122551448643, 0.1668275543488562, 0.21230946615105495, 0.20569461485138163, 0.1843843935057521, 0.11810805299319327, 0.14176450000377372, 0.15943893988151103, 0.1108667251537554, 0.1357070164522156, 0.16765731998020783, 0.17871913500130177, 0.10022532194852829, 0.13886466185795143, 0.23646560119232163, 0.12048605742165819, 0.176566090376582, 0.2128066011937335], [0.014517148847517092, 0.07522205502027646, 0.03508700923703145, 0.033983572939177975, 0.0457176698546391, 0.02093740531563526, 0.03367272067407612, 0.019475363260426093, 0.03228580993891228, 0.051551618525991216, 0.007286449026651098, 0.03290262371592689, 0.020284530583012383, 0.07248780486406758, 0.06384338747011498, 0.03068835190788377, 0.015364714890893083, 0.06153853282739874, 0.07522544663515873, 0.07117454486433417, 0.04419739147124346, 0.07966561970533803, 0.04162711884418968, 0.03827020678727422, 0.3855163586558774, 21.468051932752132, 43.387348651885986, 29.926567152142525, 34.71950076520443, 37.17093162238598, 17.808730490505695, 0.036751720690517686, 0.6672776816412807, 1.128845801576972, 4.301812341436744, 3.4278338262811303, 9.590996000915766, 0.49642575730104, 0.269270918215625, 2.7051510801538825, 27.610703520476818, 56.34942211210728, 55.90189352631569, 55.199478417634964, 53.00235651433468, 50.82557871937752, 43.95338147878647, 44.8202745616436, 49.179621040821075, 56.579526364803314, 53.26671972870827, 57.696822211146355, 54.14099581539631, 52.63193339109421, 51.45428158342838, 50.95083899796009, 53.759990260005, 50.69716461002827, 44.40093666315079, 38.97659853100777, 41.288288086652756, 40.098720118403435, 41.18604697287083, 40.97406014800072, 39.77783873677254, 40.56925646960735, 40.07358446717262, 39.943388253450394, 39.735938385128975, 40.310912132263184, 40.992538556456566, 40.64373627305031, 37.89616070687771, 38.600703701376915, 40.0402944535017, 40.68041190505028, 48.09361271560192, 50.522073805332184, 52.59639389812946, 50.41741982102394, 50.545852929353714, 52.06702150404453, 49.6891774982214, 48.75058986246586, 51.85765653848648, 49.969936832785606, 51.30940295755863, 52.56618171930313, 54.10840876400471, 51.1607663333416, 50.74397049844265, 50.14628157019615, 53.31267446279526, 52.45898947119713, 49.765469804406166, 45.907593816518784, 41.10608406364918, 38.23241986334324, 38.82158204913139, 41.26137413084507, 45.91615855693817, 47.75842510163784, 48.48194047808647, 45.326206013560295, 39.80574443936348, 35.68090617656708, 35.97083821892738, 37.5178150087595, 37.95023560523987, 36.93875268101692, 36.85611851513386, 35.34732587635517, 35.590410232543945, 35.03820486366749, 35.58015838265419, 36.00251331925392, 38.46449241042137, 44.155701622366905, 47.49559700489044, 48.70756857097149, 51.676045283675194, 49.99999701976776, 49.35422167181969, 46.42916522920132, 47.79529072344303, 47.749613374471664, 43.3237324655056, 38.55589270591736, 36.63162276148796, 35.83023056387901, 36.09736382961273, 35.78838720917702, 36.49025894701481, 38.897380381822586, 39.50489558279514, 42.48761013150215, 44.40743051469326, 45.25055967271328, 48.23211528360844, 44.608686715364456, 52.31737866997719, 34.56338234245777, 2.3546035028994083, 0.980822725687176, 4.587074909359217, 2.505904259160161, 2.3459789156913757, 5.394933884963393, 3.0198216950520873, 1.015039652120322, 0.795841229846701, 24.25825361162424, 36.3513308018446, 31.51099093258381, 31.13995984196663, 23.487235084176064, 4.704978307709098, 0.3961977636208758, 0.1525827421573922, 0.06170645858219359, 0.04690578149165958, 0.03625997363997158, 0.06611072283703834, 0.06743756413925439, 0.014629318902734667, 0.011888472909049597, 0.0458261161838891, 0.027478505689941812, 0.07684226729907095, 0.040790425264276564, 0.05171093165699858, 0.03502481726172846, 0.03801146442128811, 0.0454472609271761, 0.023291191610042006, 0.03257224554545246, 0.051531075878301635, 0.037664580886485055, 0.024799964849080425, 0.044306620766292326, 0.019673509268613998, 0.025870167773973662, 0.08947119393269531, 0.07794019315042533, 0.07687624281970784, 0.04634651013475377, 0.01288397032112698, 0.03937142406357452, 0.04645279681426473, 0.06122616287029814, 0.011818928105640225, 0.04930475159198977, 0.028348529122013133, 0.03762665714020841, 0.005807341749459738, 0.029914607293903828, 0.09195105070830323, 0.029901337693445385, 0.02923036754509667, 0.027774752488767263, 0.7335351419169456, 31.23107325285673, 45.106045827269554, 32.0069745182991, 43.26792486011982, 45.840390622615814, 18.72436735779047, 0.07315096576348878, 0.6385471858084202, 0.560864272993058, 4.0398315992206335, 6.984727252274752, 9.517336003482342, 4.077371209859848, 1.0330452234484255, 4.579443968832493, 32.12264031171799, 55.98052650690079, 56.601530984044075, 57.47697740793228, 55.024133026599884, 51.5755482763052, 46.61996439099312, 46.0225984454155, 50.3235724568367, 57.56652720272541, 54.414592534303665, 57.7194119989872, 54.669995829463005, 53.986784890294075, 52.938630133867264, 54.93280492722988, 55.54861128330231, 50.61725489795208, 45.65819039940834, 41.54174588620663, 42.909322902560234, 43.17866764962673, 43.061858117580414, 43.71153965592384, 41.710282042622566, 42.99396716058254, 41.82609222829342, 41.170824989676476, 39.451234862208366, 42.032888531684875, 42.742827236652374, 41.707109212875366, 40.999621376395226, 41.354700922966, 41.56356431543827, 44.240098893642426, 51.60939306020737, 51.32093533873558, 53.59435334801674, 51.921287924051285, 51.99174374341965, 52.482867389917374, 50.4271624982357, 51.29563629627228, 54.60972346365452, 52.70160645246506, 51.84879921376705, 55.13797491788864, 57.59684577584267, 54.076429679989815, 51.53232179582119, 51.398253589868546, 53.70521999895573, 54.81303155422211, 51.891318932175636, 47.708788365125656, 42.93090954422951, 40.54123677313328, 40.21448850631714, 42.95846566557884, 46.59375339746475, 48.5970439016819, 49.4519068300724, 45.40879838168621, 41.93507798016071, 38.28797288239002, 37.945748046040535, 39.26195941865444, 38.50920081138611, 39.35551419854164, 38.754378855228424, 38.29219065606594, 38.5086764395237, 36.050778329372406, 37.66944967210293, 36.05148509144783, 41.417085975408554, 47.225602492690086, 50.59158727526665, 49.83348995447159, 53.51110361516476, 51.593107134103775, 49.885208979249, 47.81477227807045, 50.60101076960564, 48.92682060599327, 44.52297851443291, 38.32803413271904, 39.087552577257156, 36.517043709754944, 36.3502212613821, 38.15016947686672, 40.175160616636276, 41.49696908891201, 43.119322434067726, 44.54591788351536, 46.84093773365021, 44.62923601269722, 49.37563732266426, 45.827923491597176, 51.540130376815796, 35.72896599769592, 3.3053899090737104, 3.142270124517381, 8.493301402777433, 7.372833676636219, 6.424023639410734, 8.795877266675234, 3.3716357918456197, 0.7897166709881276, 0.9619716997258365, 28.220071122050285, 43.15523810684681, 36.50986969470978, 38.37450563907623, 39.05040957033634, 16.44933443516493, 0.5078257096465677, 0.1725671166786924, 0.06166977051179856, 0.07622493401868269, 0.0978398737788666, 0.06216225971002132, 0.061962970794411376, 0.043779068801086396, 0.007899635093053803, 0.04255551961250603, 0.0722380202205386, 0.19018801802303642, 0.030481676767522004, 0.029000665417697746, 0.025301018431491684, 0.01114733826398151, 0.07285374304046854, 0.04229139296512585, 0.0695075401745271, 0.07111689483281225, 0.11741030801204033, 0.1620815199567005, 0.15138353541260585, 0.10468322492670268, 0.20567770872730762, 0.1678890036419034, 0.15912575356196612, 0.17345163796562701, 0.128332398890052, 0.10770253400551155, 0.1759856566786766, 0.1089466258417815, 0.15661670069675893, 0.3274735528975725, 0.13040891324635595, 0.09264959720894694, 0.20126890623942018, 0.11878449833602645, 0.17703261924907565, 0.17982060089707375, 0.13608577894046903, 0.13151529215974733, 0.14200351608451456, 0.9679481259081513, 34.98491272330284, 56.35772466659546, 37.78843268752098, 45.329120457172394, 47.60427117347717, 24.45267777889967, 0.08864922827342525, 1.784285455942154, 4.318980295211077, 11.588015891611576, 10.686507616192102, 16.7327194288373, 4.346636161208153, 0.3176647057989612, 4.279916016384959, 30.409762524068356, 59.03849221765995, 59.12990391254425, 60.430995896458626, 58.234117180109024, 57.064600735902786, 48.06303195655346, 49.08378638327122, 53.42500023543835, 61.26097775995731, 57.89149336516857, 60.980518609285355, 54.76313263177872, 56.39931723475456, 53.14927563071251, 55.72761207818985, 59.11998264491558, 55.78769825398922, 48.45957487821579, 43.1157012283802, 46.535092145204544, 46.44110418856144, 44.87202778458595, 45.61450034379959, 43.16090740263462, 45.292566418647766, 43.64669993519783, 44.084501042962074, 42.11793936789036, 44.43178340792656, 44.9026807397604, 43.52334335446358, 42.46499374508858, 42.62817598879337, 44.025854989886284, 45.3517634421587, 53.36042270064354, 54.25887688994408, 56.56644746661186, 55.61651363968849, 53.95680829882622, 56.82657390832901, 52.19789408147335, 52.69472502171993, 55.7035593688488, 53.82693126797676, 55.058965757489204, 56.86897203326225, 59.1017360240221, 56.33584164083004, 52.04651400446892, 54.01211813092232, 56.824461221694946, 55.27255989611149, 54.13101375102997, 50.583087131381035, 44.814137890934944, 43.51452402770519, 43.01487363874912, 44.45365883409977, 50.22232308983803, 50.236374735832214, 51.542007476091385, 47.69667461514473, 44.263775423169136, 39.01439890265465, 39.94273468852043, 42.521846294403076, 41.165611669421196, 41.6058674454689, 40.13306647539139, 38.96598570048809, 40.08339174091816, 38.42566229403019, 40.69521211087704, 38.33783000707626, 44.012255519628525, 48.737191781401634, 49.886079132556915, 52.87366881966591, 54.01599772274494, 54.43181701004505, 50.53099952638149, 50.48574775457382, 52.297026962041855, 51.23053438961506, 46.79263472557068, 41.45670644938946, 42.40445539355278, 40.244533494114876, 39.12010923027992, 40.29206894338131, 41.204559579491615, 42.10975840687752, 44.03786614537239, 46.95039086043835, 49.154265001416206, 47.900332286953926, 51.416329219937325, 46.28102257847786, 53.08564804494381, 37.07081079483032, 3.873072322458029, 3.059891019947827, 10.496008638292551, 10.873325541615486, 6.347873825579882, 13.718287982046604, 15.207589566707611, 2.792073553428054, 1.2534206919372082, 29.729125946760178, 49.79162760078907, 42.73188002407551, 39.82749827206135, 46.3440877944231, 27.97201283276081, 1.2988224369473755, 0.36687108571641147, 0.1788607070920989, 0.16967477422440425, 0.2477780988556333, 0.14284854027209803, 0.17197795532410964, 0.16882648458704352, 0.16469402820803225, 0.1342612088774331, 0.13032809336436912, 0.20481704006670043, 0.13816606340697035, 0.19118304509902373, 0.14880813454510644, 0.11946211627218872, 0.16663814341882244, 0.1054360595298931, 0.17285263573285192], [0.03289055639470462, 0.054729539406253025, 0.07656331625184976, 0.034174483007518575, 0.048179707664530724, 0.053139079827815294, 0.06472940047387965, 0.00784529318480054, 0.06814040767494589, 0.025668116213637404, 0.05464512010803446, 0.06869593489682302, 0.04660967199015431, 0.029152484712540172, 0.017133876208390575, 0.03990116536442656, 0.05921526921156328, 0.07320821503526531, 0.02488726553565357, 0.13183931383537129, 0.04266899028152693, 0.016315471002599224, 0.03742463712114841, 0.021167784652789123, 0.06118097349826712, 3.842236027121544, 37.933520302176476, 25.724467635154724, 30.664983429014683, 32.945866137742996, 28.23420636355877, 1.6492163599468768, 0.36875548772513866, 0.5081356305163354, 3.132208976894617, 4.695152509957552, 7.805494610220194, 4.158752867951989, 3.0209958320483565, 0.6876464886590838, 4.783370476216078, 44.74596954882145, 55.05817539989948, 56.597389206290245, 54.688056260347366, 51.96370504796505, 44.76747639477253, 49.621560126543045, 53.624595925211906, 55.37778005003929, 55.20029537379742, 56.92660354077816, 52.93927229940891, 55.474150478839874, 53.972687646746635, 54.550670832395554, 48.58567491173744, 44.4185259193182, 40.10298348963261, 41.91112406551838, 39.68437135219574, 42.161344438791275, 40.396312549710274, 40.92152796685696, 40.77511042356491, 39.98511761426926, 38.5092768073082, 38.245194777846336, 41.215449795126915, 42.61678799986839, 40.92388764023781, 39.24859933555126, 39.74330238997936, 39.50394183397293, 39.12015862762928, 43.50947789847851, 53.480222672224045, 52.26147226989269, 49.68160070478916, 50.39242096245289, 49.53088939189911, 50.63679724931717, 48.59664112329483, 51.99241630733013, 50.176691338419914, 48.984767496585846, 52.02038660645485, 52.382066398859024, 53.684260323643684, 52.79861144721508, 51.621525809168816, 53.886652663350105, 52.13337354362011, 52.127426862716675, 47.80607834458351, 43.00673447549343, 40.37263981997967, 42.615613862872124, 43.985003381967545, 48.641923293471336, 49.65276025235653, 51.60685859620571, 53.09494234621525, 48.74491676688194, 41.908418610692024, 36.45960219204426, 36.72819837927818, 37.56383813917637, 38.09701032936573, 37.47328519821167, 36.964173316955566, 37.04899616539478, 36.617331728339195, 33.58564920723438, 36.42527863383293, 37.29539394378662, 39.35854643583298, 42.07915484905243, 46.27900488674641, 48.004708886146545, 47.61450782418251, 49.41624194383621, 46.783739402890205, 50.07589794695377, 50.017175897955894, 45.66786848008633, 49.46867913007736, 47.236036732792854, 45.64451493322849, 42.634267061948776, 41.50931462645531, 40.642250552773476, 40.84504187107086, 38.599434569478035, 39.70144763588905, 38.297278583049774, 41.08228974044323, 44.4752112776041, 47.42222674190998, 48.06523583829403, 53.48083823919296, 23.15257754176855, 0.23753212677547708, 2.095892485231161, 6.0013404954224825, 12.677131500095129, 10.29458524659276, 5.6090067978948355, 1.5580648323521018, 0.39884868543595076, 2.2334201680496335, 27.121373377740383, 32.72482819855213, 23.36766880005598, 27.249181419610977, 20.687881596386433, 2.049182066693902, 0.11313257622532547, 0.037746781163150445, 0.07500059815356508, 0.043741345434682444, 0.01666083870077273, 0.01818099648517091, 0.04170197556959465, 0.03129935466859024, 0.023149983171606436, 0.06866120238555595, 0.025635971942392644, 0.017151411302620545, 0.047112510437727906, 0.013333692331798375, 0.047847566893324256, 0.028325524399406277, 0.03366915094375145, 0.028233817211003043, 0.041146541116177104, 0.03920941693650093, 0.011181814734300133, 0.03697454681969248, 0.03960714500863105, 0.037673438419005834, 0.03741242879186757, 0.06769212821382098, 0.04842871305299923, 0.0016393736041209195, 0.045474323342205025, 0.027021609894291032, 0.08626449998700991, 0.05190705160202924, 0.03673576451546978, 0.039742382869008, 0.0332123367843451, 0.021327101494534872, 0.01387978314596694, 0.01298446917644469, 0.038548007505596615, 0.043980765985907055, 0.03758703016501386, 0.034928909517475404, 0.0474865417345427, 0.027377874175726902, 7.0636300183832645, 45.966205671429634, 25.55253066122532, 35.80544449388981, 40.00219389796257, 33.330591693520546, 1.700310199521482, 0.49579784099478275, 0.9661508817225695, 3.2142997719347477, 5.595721285790205, 7.980281431227922, 9.234987404197454, 4.267998430877924, 2.4711475241929293, 8.145423419773579, 47.219872400164604, 56.968017518520355, 59.943402260541916, 54.97171103954315, 54.768019169569016, 46.704924032092094, 49.78880815207958, 55.01312501728535, 58.01042318344116, 55.746250078082085, 56.93571165204048, 52.29777552187443, 55.197301134467125, 55.40244832634926, 55.269736647605896, 51.545575484633446, 45.740463584661484, 42.703837528824806, 42.917135283350945, 41.705684289336205, 42.44459643959999, 41.309563145041466, 42.47996874153614, 41.643618419766426, 42.09956735372543, 40.57467497885227, 39.8206852376461, 41.85962922871113, 43.210912719368935, 43.01575519144535, 41.99392922222614, 41.31960600614548, 40.71734592318535, 41.378901824355125, 46.13151200115681, 54.399431347846985, 54.05896581709385, 52.69708089530468, 52.2607047110796, 50.98479017615318, 52.53960594534874, 50.978900492191315, 52.960136979818344, 52.43539273738861, 51.83944031596184, 52.66778066754341, 54.590982869267464, 53.77376452088356, 53.86079125106335, 53.166378512978554, 55.60190722346306, 53.41070160269737, 53.35439622402191, 49.971084371209145, 44.68299172818661, 43.426999524235725, 43.89229215681553, 47.02497325837612, 49.26699735224247, 50.79163894057274, 52.70765572786331, 54.64349985122681, 50.99375009536743, 42.15034782886505, 38.67510750889778, 38.56367088854313, 39.2112435400486, 38.72205398976803, 38.74241329729557, 37.92618289589882, 38.50538581609726, 38.816729709506035, 36.116138622164726, 38.002824783325195, 38.94554279744625, 41.05179637670517, 44.18701574206352, 47.70159915089607, 50.0953871011734, 49.09950613975525, 50.09265884757042, 49.83051471412182, 51.63788013160229, 50.66189870238304, 47.64508098363876, 51.058050245046616, 48.33805739879608, 45.56302830576897, 43.69741581380367, 43.64357650279999, 40.38444198668003, 41.49070702493191, 39.55400414764881, 41.96699246764183, 39.35470104217529, 43.34921769797802, 45.99247746169567, 50.37642762064934, 49.87026438117027, 54.00093913078308, 25.167370028793812, 0.5362545372918248, 2.825680375099182, 10.167952291667461, 12.186814360320568, 14.371416885405779, 5.223612478002906, 1.2663353676907718, 1.0203363304026425, 2.7103131031617522, 28.330417200922966, 44.42458659410477, 27.327109538018703, 28.05275470018387, 30.208795107901096, 6.2085277028381824, 0.17897548765176907, 0.08357281200005673, 0.09842113126069307, 0.09466703661018983, 0.10093309334479272, 0.025704726358526386, 0.08843586823786609, 0.03825906715064775, 0.10958297294564545, 0.012420809871400706, 0.05818747631565202, 0.011794223864853848, 0.09402250361745246, 0.03275698094512336, 0.06887177936732769, 0.10360806074459106, 0.015821992892597336, 0.011032846214220626, 0.0040105145581037505, 0.09811138108489104, 0.16315183049300686, 0.15534834063146263, 0.12787722487701103, 0.0933455684571527, 0.1926996387192048, 0.18414546648273245, 0.07963240117533132, 0.13016692857490852, 0.1381106991902925, 0.218162992678117, 0.24139594053849578, 0.11280322592938319, 0.14310493745142594, 0.1027513477311004, 0.16524425649549812, 0.08460610421025194, 0.18660283618373796, 0.11898381693754345, 0.20179547485895455, 0.11345889113727026, 0.09070632062503137, 0.11319775163428858, 0.1208713062806055, 0.13896324875531718, 7.351186238229275, 53.71106028556824, 33.62053133547306, 41.51709660887718, 43.058111518621445, 40.843510553240776, 2.9058057256042957, 0.8180368482135236, 2.423753379844129, 8.455660622566938, 14.69535045325756, 17.61423982679844, 9.537882450968027, 5.047899931669235, 1.3750255666673183, 7.1186059433966875, 48.637462332844734, 58.915777802467346, 62.48238041996956, 59.01509307324886, 57.853335812687874, 49.92152363061905, 53.17562721669674, 58.98889347910881, 60.98475158214569, 58.17316845059395, 58.04916590452194, 53.10877740383148, 58.00687037408352, 57.558555230498314, 60.02528786659241, 53.11944343149662, 47.29038901627064, 47.02320635318756, 45.23619644343853, 45.00354252755642, 45.569449961185455, 42.99555167555809, 44.977411329746246, 44.47659060359001, 43.841276094317436, 41.3223684579134, 41.532364189624786, 45.73763653635979, 47.061816081404686, 45.467155650258064, 42.986568957567215, 42.389453798532486, 43.423036336898804, 43.43306019902229, 48.16192165017128, 56.98363088071346, 57.0616140961647, 55.2200885117054, 55.702157244086266, 52.378319799900055, 54.85803633928299, 52.77923248708248, 55.327626541256905, 54.56670217216015, 53.450021892786026, 56.1827402561903, 56.63822941482067, 57.63080455362797, 54.85210865736008, 55.646057054400444, 57.744046077132225, 56.122616082429886, 55.975164994597435, 52.258310839533806, 46.91863976418972, 45.86012676358223, 46.2572168558836, 49.701146855950356, 52.807825952768326, 54.050686061382294, 54.130907356739044, 57.91336879134178, 53.00549514591694, 45.41210800409317, 40.182011649012566, 38.61892752349377, 40.81117428839207, 42.11743399500847, 41.12556181848049, 40.93595199286938, 40.621439069509506, 40.649565160274506, 37.01941095292568, 39.30043235421181, 41.08991593122482, 42.23891727626324, 46.09887555241585, 50.304634273052216, 51.01716063916683, 50.509048104286194, 51.72923482954502, 51.194592118263245, 52.82772548496723, 54.371031671762466, 49.368087127804756, 54.80759784579277, 50.460186526179314, 48.7215556204319, 46.187437400221825, 45.49997068941593, 43.586609959602356, 45.45959025621414, 42.605460807681084, 43.859378322958946, 42.3164027184248, 44.75787051022053, 47.19636686146259, 51.88679337501526, 52.32769891619682, 54.9158426374197, 26.03453479707241, 0.8131221088115126, 5.051307398825884, 13.349086493253708, 22.69803263247013, 14.8872753046453, 13.96362466737628, 8.785710912197828, 1.3137189438566566, 3.0827864538878202, 37.06554427742958, 45.52637167274952, 35.1347690820694, 36.805676221847534, 44.16276544332504, 10.68893663585186, 0.27550433529540896, 0.18642679875483736, 0.19220133108319715, 0.15796314954059198, 0.13678923103725538, 0.1363989058881998, 0.19229824072681367, 0.17067438777303323, 0.1450144240516238, 0.09764130474650301, 0.1561826333636418, 0.08808529993984848, 0.23340612708125263, 0.08240860493970104, 0.20387372584082186, 0.18377583241090178, 0.08985597523860633, 0.15693030261900276, 0.1991150452522561], [0.03652772196801379, 0.04057483507494908, 0.06331949058221653, 0.05704008261091076, 0.0460937569005182, 0.04581441622576676, 0.053572119286400266, 0.07303844875423238, 0.04413048314745538, 0.0588512828835519, 0.02866815913876053, 0.02874442594475113, 0.06112211376603227, 0.03075166267080931, 0.025898239509842824, 0.015299026472348487, 0.030918996562832035, 0.05765007605077699, 0.03738335144589655, 0.05705373070668429, 0.01659087087318767, 0.04120177174627315, 0.030646517043351196, 0.027539276452444028, 0.05760953252320178, 0.1697046382469125, 16.1085744202137, 38.73999662697315, 32.042495012283325, 40.19628748297691, 33.75415116548538, 11.574478168040514, 0.22139221080578864, 0.5696552200242877, 1.218408183194697, 5.030421819537878, 6.618011305108666, 12.060824520885944, 5.112480316311121, 4.65752312913537, 0.18625200813403353, 17.55295291543007, 57.861338183283806, 56.153478026390076, 54.75056290626526, 53.44676546752453, 49.085405096411705, 53.552202209830284, 55.819183364510536, 58.199850618839264, 56.34417839348316, 54.374177902936935, 57.32143275439739, 53.54838341474533, 54.60560828447342, 52.53378465771675, 42.15440981090069, 39.02461275458336, 39.82181377708912, 39.63039144873619, 41.451379135251045, 45.69483943283558, 45.61746038496494, 45.24606071412563, 42.274160385131836, 42.401791736483574, 39.72759023308754, 40.912393257021904, 39.83853667974472, 41.59226417541504, 40.50820134580135, 39.24069955945015, 39.68801535665989, 41.142543107271194, 39.34816159307957, 43.87203924357891, 55.154055655002594, 53.71553264558315, 51.27431184053421, 49.95168261229992, 50.34143149852753, 54.08622935414314, 51.85940824449062, 49.52340379357338, 49.025790095329285, 50.6526044011116, 48.92240524291992, 48.910694271326065, 53.37704300880432, 50.290708020329475, 49.250521436333656, 50.26787884533405, 52.49809317290783, 51.807795614004135, 44.37727153301239, 41.826552003622055, 45.766343995928764, 47.4009744822979, 50.89509218931198, 52.503405287861824, 52.96324901282787, 55.00990279018879, 51.578751504421234, 52.670364528894424, 40.62479428946972, 37.1358785033226, 37.90774628520012, 36.56267926096916, 35.4537657648325, 37.74894140660763, 35.96276745200157, 38.28054428100586, 35.954502895474434, 34.99478839337826, 35.60394510626793, 37.10418440401554, 40.12669041752815, 44.60213206708431, 46.42956420779228, 47.72813692688942, 47.95242749154568, 47.643572464585304, 48.51085312664509, 46.470598205924034, 50.95119997859001, 48.46487559378147, 48.5159220546484, 48.643439412117004, 49.35441926121712, 47.708993554115295, 47.775022611021996, 46.46827273070812, 46.7211339622736, 45.81850379705429, 47.211091071367264, 43.59465032815933, 44.06620882451534, 45.15572056174278, 47.145005017519, 47.66187988221645, 47.47312121093273, 9.338643942028284, 0.6493525591213256, 2.6438059844076633, 10.20095732063055, 9.837086945772171, 7.277588462457061, 5.750693120062351, 1.3179083378054202, 0.6860973592847586, 7.501037372276187, 40.555983781814575, 32.10891544818878, 29.50249470770359, 29.977835901081562, 16.760539636015892, 0.03591268934542313, 0.06050801996025257, 0.029711975003010593, 0.07024816644843668, 0.012934546757605858, 0.024146605865098536, 0.04781016265042126, 0.0805654440773651, 0.05514858195965644, 0.08430487388977781, 0.016700320957170334, 0.013470843077811878, 0.06368099071551114, 0.06364484812365845, 0.06291850077104755, 0.035168500762665644, 0.029311311736819334, 0.027973375326837413, 0.04599677675287239, 0.007658730710318196, 0.030617239317507483, 0.06492095621069893, 0.06892254968988709, 0.018631734310474712, 0.053130886517465115, 0.0940345560957212, 0.038077593490015715, 0.050318421417614445, 0.03337492649734486, 0.07247213812661357, 0.017037649340636563, 0.013666597515111789, 0.054985402239253744, 0.03562926685845014, 0.03371563165273983, 0.038561455221497454, 0.03271247805969324, 0.03983846501796506, 0.07357217909884639, 0.07967117839143611, 0.03855721384752542, 0.027741225967474747, 0.05740248074289411, 0.09713679275591858, 0.09837252058787271, 0.21191923005972058, 23.674958311021328, 39.986599534749985, 31.036347001791, 42.534305825829506, 41.380813121795654, 11.39430133625865, 0.3116612951271236, 0.9426838753279299, 1.3080963143147528, 3.965350608341396, 7.067132005468011, 8.82169023156166, 4.918330209329724, 5.268233483657241, 0.2592766232555732, 20.455558262765408, 57.909599393606186, 57.105923518538475, 56.27800494432449, 54.22329939901829, 49.362683817744255, 54.00632344186306, 56.925140619277954, 58.759887367486954, 56.67515203356743, 55.17435796558857, 57.774478644132614, 54.80482019484043, 55.72112962603569, 54.497891664505005, 45.705444663763046, 41.989179477095604, 41.90804623067379, 42.58525729179382, 44.15171943604946, 47.46109865605831, 46.33768513798714, 47.00886212289333, 43.38321067392826, 44.95271645486355, 42.77074433863163, 42.78737224638462, 41.22652240097523, 43.833102732896805, 42.13842786848545, 41.25448890030384, 40.89426442980766, 41.65361948311329, 41.14970952272415, 45.27264788746834, 56.785418316721916, 55.814346224069595, 53.89785826206207, 52.006619945168495, 52.083634212613106, 54.36139538884163, 52.6259259134531, 52.97017224133015, 50.97634702920914, 52.38909602165222, 49.632853120565414, 52.12149158120155, 56.248294338583946, 52.70183444023132, 50.99914200603962, 54.23054940998554, 54.627316519618034, 52.60976158082485, 45.827931091189384, 43.15058335661888, 46.69445179402828, 49.988054260611534, 51.364226415753365, 52.550389766693115, 53.81413355469704, 57.23591074347496, 52.681391537189484, 54.79967147111893, 42.98336572945118, 37.86673128604889, 39.22613114118576, 37.43632838129997, 37.73592330515385, 40.300287902355194, 37.98237048089504, 39.549531787633896, 39.07491445541382, 37.34564624726772, 36.48943819105625, 38.279434740543365, 41.73686541616917, 47.11702711880207, 48.71982291340828, 48.76983962953091, 50.07201835513115, 49.22436743974686, 47.83305309712887, 49.10342752933502, 51.801408156752586, 47.713203728199005, 49.652919843792915, 49.106250777840614, 49.86160084605217, 50.01120641827583, 49.100402891635895, 47.83375985920429, 48.430476039648056, 47.50004656612873, 48.213522881269455, 45.30140474438667, 45.15920117497444, 47.55073964595795, 50.005651116371155, 48.089938312768936, 49.19855922460556, 10.519362185150385, 1.1501509021036327, 3.4457828756421804, 9.68672901391983, 14.045905452221632, 14.714239239692688, 5.590206831693649, 0.40421791607514024, 0.5465886171441525, 8.636245932430029, 43.0216296762228, 40.281611904501915, 27.760533280670643, 36.7664585262537, 23.95930465310812, 0.32699837058316916, 0.13441303744912148, 0.040761266282061115, 0.04541086971585173, 0.03616331632656511, 0.03425761839025654, 0.03337904541695025, 0.03351281011418905, 0.09129483631113544, 0.056724335881881416, 0.007678776582906721, 0.04650595314160455, 0.09714497864479199, 0.048146852786885574, 0.1271523247123696, 0.05515843768080231, 0.012716180935967714, 0.05889496940653771, 0.04289920820156112, 0.027534678847587202, 0.17894529708428308, 0.16251208435278386, 0.16799930162960663, 0.1780506974318996, 0.15765814168844372, 0.15337810182245448, 0.1497009678860195, 0.147857443371322, 0.13663701654877514, 0.1263108034618199, 0.12810024025384337, 0.09619437652872875, 0.2569178998237476, 0.07488041475880891, 0.1599136323784478, 0.11836436853627674, 0.1356016017962247, 0.19743249256862327, 0.15033605333883315, 0.31083670968655497, 0.14226576138753444, 0.08234495093347505, 0.16890832863282412, 0.149496580415871, 0.13439469155855477, 0.3031848999671638, 25.50008587539196, 52.88479842245579, 42.425871044397354, 50.38017801940441, 47.751612067222595, 16.229122951626778, 0.41424252034630626, 1.5558410016819835, 4.014832740649581, 16.016112081706524, 14.572203811258078, 19.578998498618603, 10.518499631434679, 8.564855363219976, 0.47529387404210865, 21.34913921356201, 60.64129181206226, 59.803934544324875, 58.430258855223656, 57.98911392688751, 53.7498714029789, 55.26930347084999, 59.10974979400635, 60.01153640449047, 56.95203557610512, 56.09849877655506, 60.97535088658333, 56.27203166484833, 59.586897790431976, 56.77676618099213, 46.746668592095375, 43.90691377222538, 43.98962773382664, 45.096827521920204, 47.03688181936741, 51.91927783191204, 49.979470521211624, 49.968143329024315, 46.505370140075684, 46.5852190554142, 44.29784819483757, 44.379711002111435, 42.41837024688721, 46.24947287142277, 44.850334748625755, 42.10813969373703, 42.926414385437965, 43.278837874531746, 43.68216723203659, 47.968314439058304, 58.15326511859894, 57.69423454999924, 56.31086178123951, 54.52900439500809, 53.62932667136192, 58.311021253466606, 54.93226155638695, 54.16483573615551, 53.10574136674404, 55.635364428162575, 53.58328454196453, 53.34370739758015, 57.04943574965, 53.376891016960144, 52.74436555802822, 54.7283910959959, 55.65455339848995, 55.2979539334774, 47.48156435787678, 44.558897987008095, 49.252235144376755, 52.06663392484188, 55.57297557592392, 54.7530859708786, 56.65804535150528, 58.09993878006935, 54.22595165669918, 57.43666157126427, 43.95213134586811, 40.98534174263477, 42.69536778330803, 38.433607667684555, 38.09665694832802, 42.758588790893555, 39.723710641264915, 42.63958677649498, 40.55884502828121, 39.8292575776577, 40.268734395504, 39.82643812894821, 44.091686457395554, 48.22787471115589, 51.16043195128441, 51.73152230679989, 52.94118359684944, 50.84496147930622, 51.20388261973858, 49.861323460936546, 52.742902636528015, 51.38017416000366, 50.70895537734032, 51.55674688518047, 53.17350693047047, 52.8252138197422, 51.95581667125225, 49.4376689940691, 51.05629473924637, 49.66169357299805, 49.4742838293314, 47.931741401553154, 48.05966913700104, 50.41564151644707, 51.68875180184841, 48.264964520931244, 47.54465997219086, 11.255124304443598, 1.9506506226025522, 6.842166027054191, 20.55831804871559, 15.132104717195034, 13.383766282349825, 14.09244915470481, 6.064018607139587, 1.4403232815675437, 11.7020857706666, 50.75074553489685, 44.81686234474182, 38.598389625549316, 46.7998543381691, 30.764260701835155, 0.4341332061449066, 0.22736357554094866, 0.26287203188985586, 0.12144552078098059, 0.12713927775621414, 0.15037216624477878, 0.1417032876634039, 0.12600868998561054, 0.22738916479283944, 0.17512249440187588, 0.13871933449991047, 0.09235167686711065, 0.12789389351382852, 0.2296501919045113, 0.2665975835407153, 0.09478893436607905, 0.09171394194709137, 0.15365885628852993, 0.08407442219322547, 0.08034813581616618], [0.05928356906224508, 0.03734682664799038, 0.04959381440130528, 0.026133895516977645, 0.03880496871715877, 0.04758960007166024, 0.009182520843751263, 0.04915920158964582, 0.05742033310525585, 0.012789070042344974, 0.07112973398761824, 0.05158887433935888, 0.048901546470005997, 0.07598583630169742, 0.04417358708451502, 0.014990606596256839, 0.062038914766162634, 0.013408520298980875, 0.03366908786119893, 0.04358179110568017, 0.04880798762314953, 0.03258827964600641, 0.0238795922632562, 0.051780166613752954, 0.043254923293716274, 0.039683129798504524, 0.810878329211846, 32.136847749352455, 29.548056162893772, 29.861541241407394, 41.26459255814552, 22.13844045996666, 0.9426147071644664, 0.9303217136766762, 1.2827712669968605, 2.4425196228548884, 4.24098995514214, 6.116236355155706, 3.9858778193593025, 3.5056662373244762, 0.2074248727876693, 2.3684701463207603, 43.94249506294727, 59.19830024242401, 54.24708992242813, 53.78208987414837, 52.47755907475948, 54.97574262320995, 57.98199690878391, 55.74476815760136, 53.713655546307564, 54.651232436299324, 53.34200128912926, 51.51062496006489, 52.19928860664368, 44.82416555285454, 41.493936851620674, 40.72145730257034, 42.0595782995224, 47.147421687841415, 49.15779121220112, 50.09011298418045, 47.84775070846081, 45.699414387345314, 42.53984592854977, 41.98223724961281, 42.07749053835869, 38.755032420158386, 39.99014474451542, 41.66295178234577, 39.81916531920433, 39.31355305016041, 39.055539295077324, 40.621454268693924, 37.5201290845871, 41.83064438402653, 53.397926688194275, 55.37561036646366, 54.53076370060444, 52.14303262531757, 53.348096162080765, 55.73027193546295, 52.86712557077408, 53.920687437057495, 51.438428834080696, 52.08812557160854, 52.84151874482632, 52.93429836630821, 52.7061852067709, 53.1094803661108, 50.88470734655857, 54.05125983059406, 52.21209391951561, 48.056853488087654, 45.601957216858864, 48.61914351582527, 48.97005848586559, 54.38996605575085, 53.906821981072426, 51.37559920549393, 52.96952247619629, 52.735063657164574, 51.62501782178879, 49.83319737017155, 39.41301271319389, 36.348363161087036, 39.098989963531494, 36.75698183476925, 36.14688277244568, 38.196770176291466, 36.31709463894367, 36.59878112375736, 35.61263523995876, 35.640780329704285, 36.27082832157612, 36.28630489110947, 41.250761300325394, 46.90740376710892, 48.32035794854164, 48.88580180704594, 49.72781762480736, 47.98089936375618, 49.163293316960335, 47.44182229042053, 49.55792494118214, 50.45067943632603, 48.76037433743477, 49.05964247882366, 48.923146203160286, 48.9680065959692, 50.037987381219864, 48.92756536602974, 49.58314038813114, 51.0481745749712, 48.127761483192444, 46.40472874045372, 44.698605090379715, 48.24843540787697, 46.464571729302406, 53.71905505657196, 35.53975895047188, 2.89685245603323, 1.1013725632801652, 0.5339432519394904, 12.707014996558428, 11.003906484693289, 18.829690106213093, 3.0547916935756803, 0.6261695874854922, 0.5979790783021599, 15.24212496355176, 41.93233832716942, 26.935059875249863, 23.77265676856041, 28.036774657666683, 1.2103218608535826, 0.2138779655797407, 0.07039543081191368, 0.028345699683995917, 0.03590115637052804, 0.038110504028736614, 0.014391607146535534, 0.07880465418566018, 0.022450336437032092, 0.010822857384482631, 0.04847668176807929, 0.018815634794009384, 0.04574269136355724, 0.024775830206635874, 0.010376388763688738, 0.07983525982126594, 0.04210880237224046, 0.06833334380644374, 0.02738494313234696, 0.04042399727040902, 0.06580620480235666, 0.03870464890496805, 0.09441954520298168, 0.040188454440794885, 0.10543916170718148, 0.03549291206581984, 0.02520807000109926, 0.10990620794473216, 0.016791016969364136, 0.026393521038698964, 0.031209573353407905, 0.04050670220749453, 0.03181454616424162, 0.035377485837670974, 0.020075916581845377, 0.04317024795454927, 0.07778554441756569, 0.002357725707042846, 0.0354664953192696, 0.03364801828865893, 0.0883907382376492, 0.06720162054989487, 0.0859553212649189, 0.06101768245571293, 0.0894395710201934, 0.048976343823596835, 0.04121202822716441, 2.4253445444628596, 40.651620849967, 32.283303290605545, 38.1074445694685, 47.051104456186295, 24.485644809901714, 0.5539567780215293, 0.21177571354201064, 0.8045673428568989, 2.6410817680880427, 5.789016438648105, 6.754233045503497, 5.215222053229809, 3.423509420827031, 0.7003271207213402, 3.0983062461018562, 47.87734352052212, 60.423293709754944, 57.87142664194107, 56.34145773947239, 54.748226031661034, 55.82161903381348, 59.887070283293724, 56.192862913012505, 55.005149245262146, 56.26487284898758, 55.94368748366833, 54.56346854567528, 54.38651584088802, 47.808054238557816, 43.48697550594807, 42.543033957481384, 43.34068715572357, 48.50732311606407, 52.096557319164276, 50.9240086376667, 49.73843805491924, 47.09002956748009, 44.14033904671669, 42.418890818953514, 42.60870203375816, 41.20637588202953, 43.293311297893524, 43.56062315404415, 42.632747143507004, 40.32592132687569, 42.45582863688469, 41.34772449731827, 39.633226096630096, 44.418419525027275, 55.62157116830349, 56.14796832203865, 55.359784215688705, 54.768763929605484, 54.53891046345234, 56.65093593299389, 53.06743182241917, 53.26363429427147, 52.764246091246605, 55.154355838894844, 54.15459528565407, 55.423472598195076, 53.81154589354992, 54.12323176860809, 53.21128450334072, 55.06038688123226, 55.4397851228714, 49.25864540040493, 45.99450655281544, 48.80557671189308, 51.29644565284252, 52.97394163906574, 54.56315316259861, 53.324507027864456, 54.70179632306099, 55.282838344573975, 54.1018883138895, 51.15130104124546, 40.68014591932297, 38.08551214635372, 40.83502180874348, 38.25361132621765, 38.812546133995056, 39.46715600788593, 38.60581062734127, 38.80973428487778, 38.241387382149696, 37.70485997200012, 38.75898040831089, 37.88389876484871, 42.52527751028538, 48.313012942671776, 50.47396458685398, 50.344756320118904, 51.24588556587696, 49.96699199080467, 49.22696650028229, 48.169696033000946, 51.100034192204475, 50.52772410213947, 50.89970514178276, 49.19912539422512, 49.24021638929844, 50.74762590229511, 52.291745245456696, 49.528244733810425, 50.53767576813698, 52.444006875157356, 49.466923624277115, 48.553657829761505, 45.83238825201988, 50.188516303896904, 48.369899690151215, 54.68247435986996, 37.32917793095112, 2.803779300302267, 2.227838267572224, 4.1509119886904955, 9.6555744856596, 11.25796940177679, 9.697492886334658, 3.3402900863438845, 0.06469048967119306, 0.350122059462592, 16.40829473733902, 50.921249985694885, 34.43278335034847, 25.70184174925089, 34.50777992606163, 4.031581291928887, 0.23284141207113862, 0.0431572492379928, 0.02204617951065302, 0.024036469294514973, 0.04017918872705195, 0.013782815058220876, 0.07764550857245922, 0.017455597226216923, 0.02131680605089059, 0.02569029529695399, 0.022366714947565924, 0.021392638700490352, 0.011040150802728022, 0.05733875252190046, 0.05534384101338219, 0.04063375417899806, 0.05392749299062416, 0.05325430567609146, 0.04998809890821576, 0.03340151764859911, 0.15167567442404106, 0.23704361548880115, 0.17365976586006582, 0.09935663809301332, 0.15213924954878166, 0.11344408529112116, 0.12039078050293028, 0.10181475736317225, 0.18304034922039136, 0.12919156841235235, 0.21519177476875484, 0.1349796078284271, 0.09640907243010588, 0.1360933785326779, 0.13242283486761153, 0.1395688412594609, 0.1196315189008601, 0.16100683074910194, 0.11133152482216246, 0.25871698453556746, 0.18429275311063975, 0.18582076096208766, 0.13328478002222255, 0.13003343105083331, 0.12451553338905796, 0.19713020097697154, 2.369819786399603, 46.47104658186436, 41.42812058329582, 42.1465328335762, 53.53404298424721, 31.227554641664028, 1.3766804966144264, 1.8459732457995415, 5.302237858995795, 7.63972470536828, 12.577023021876812, 16.74444369971752, 11.806658059358597, 8.298944681882858, 0.5722197261638939, 3.3493758738040924, 47.08408288657665, 63.25707525014877, 60.4024214297533, 60.34871131181717, 55.967257618904114, 58.16552706062794, 61.60070613026619, 58.394130393862724, 54.88650441169739, 57.68579140305519, 57.745478600263596, 57.141998782753944, 57.089595794677734, 49.96478050947189, 45.32623641192913, 44.32557910680771, 45.91355189681053, 52.018178924918175, 53.8677828758955, 55.07091611623764, 52.16121844947338, 50.24012513458729, 46.03687807917595, 44.56230640411377, 46.39017552137375, 43.17574940621853, 43.781642094254494, 45.95498487353325, 44.233084470033646, 43.0127077549696, 45.396840423345566, 44.01491537690163, 41.16485930979252, 44.655462205410004, 57.55023367702961, 60.471083745360374, 57.72679880261421, 57.374755293130875, 58.13730217516422, 57.48437561094761, 55.48758275806904, 55.52419759333134, 55.05680747330189, 56.967040970921516, 58.3954793214798, 56.231905817985535, 55.71636088192463, 55.282838344573975, 53.874063938856125, 56.99365094304085, 56.01837247610092, 51.7515966296196, 48.73564526438713, 53.2375904917717, 54.307780265808105, 57.441274523735046, 56.245756074786186, 56.35740168392658, 56.26761630177498, 58.39617468416691, 56.20489686727524, 53.462257236242294, 42.67372414469719, 40.26647351682186, 41.84951037168503, 39.862919971346855, 40.07517658174038, 41.071429923176765, 39.552670419216156, 41.877024695277214, 39.77593883872032, 38.60109128057957, 40.34813113510609, 40.407556146383286, 44.252824410796165, 49.45504926145077, 52.21042200922966, 52.228588834404945, 52.6998395472765, 51.41983263194561, 51.96294128894806, 51.484535560011864, 52.41937659680843, 52.82790407538414, 53.68072651326656, 50.79062059521675, 51.833622828125954, 51.813282519578934, 53.64169120788574, 50.82414239645004, 54.2255412787199, 54.20683488249779, 51.3784072548151, 49.26742672920227, 48.545305877923965, 52.26665139198303, 50.79484596848488, 54.567503929138184, 38.051652163267136, 4.033293100073934, 3.4092696849256754, 6.143252430483699, 23.436640799045563, 19.690091237425804, 31.764587424695492, 11.654206439852715, 2.7221974404528737, 1.275249570608139, 21.389314457774162, 56.64313115179539, 36.942210495471954, 31.928873509168625, 44.89412359893322, 4.885354153811932, 0.28033969458192587, 0.18851178843760863, 0.11522826025611721, 0.21861531684407964, 0.15588319161906838, 0.15531334094703197, 0.24856529489625245, 0.16946704708971083, 0.10691075891372748, 0.15951165551086888, 0.1044813978660386, 0.1209021128306631, 0.08820736096822657, 0.18336079374421388, 0.22376993321813643, 0.25376377219799906, 0.1328715225099586, 0.13302482053404674, 0.12368462485028431, 0.10516614041989669], [0.05493259843206033, 0.010929946511168964, 0.050758745055645704, 0.02169382820284227, 0.055547185766045004, 0.032927437423495576, 0.01731848173221806, 0.05333406799763907, 0.03645785247499589, 0.03922720621631015, 0.0060204058536328375, 0.036581876483978704, 0.057207166028092615, 0.07013873677351512, 0.022204778324521612, 0.10704207452363335, 0.035000337520614266, 0.04338780854595825, 0.03551762558345217, 0.12393676952342503, 0.03317077651445288, 0.022207366564543918, 0.05358787137083709, 0.044316409694147296, 0.03521707432810217, 0.04999989163479768, 0.0686358951497823, 7.893903516232967, 37.82136172056198, 20.453523471951485, 38.86493772268295, 31.977898478507996, 4.247614424675703, 0.21414595510577783, 0.26826771267224103, 1.3298318604938686, 6.686364412307739, 3.0183677980676293, 2.3745816433802247, 2.2751851519569755, 0.44458326883614063, 0.16062046866863966, 26.66207492351532, 58.718127608299255, 55.35348795354366, 55.620674416422844, 57.03110933303833, 57.05331914126873, 57.022255808115005, 56.75200290977955, 57.45893597602844, 54.16934609413147, 54.425019174814224, 51.116259321570396, 47.91364677250385, 42.35997498035431, 39.0683826059103, 44.270428866147995, 48.49749304354191, 50.201731994748116, 51.29132732748985, 50.53285002708435, 48.28446127474308, 46.047361716628075, 43.69290545582771, 41.30637511610985, 40.64415045082569, 42.346234917640686, 41.68942116200924, 40.6023944914341, 39.28769163787365, 39.94232431054115, 38.82847107946873, 39.650374576449394, 37.832700312137604, 39.86679956316948, 47.120032757520676, 53.34159851074219, 51.408931016922, 53.0647149682045, 50.8325931429863, 50.767453238368034, 54.33093622326851, 53.32745186984539, 53.87297719717026, 53.948642536997795, 52.9155957698822, 52.23871909081936, 54.58103120326996, 47.597602531313896, 50.40069691836834, 52.68077217042446, 52.44072385132313, 50.65914385020733, 48.9939022064209, 52.63360530138016, 51.19384355843067, 57.409417033195496, 55.082566291093826, 50.444383174180984, 54.57997485995293, 52.28715129196644, 50.73204293847084, 46.05082333087921, 39.093769043684006, 36.38710968196392, 37.91449472308159, 36.450304090976715, 37.6199459284544, 37.474789917469025, 37.587305679917336, 37.37021952867508, 38.741782531142235, 37.34909646213055, 36.04623757302761, 36.50358863174915, 40.40633261203766, 45.157582461833954, 49.415987357497215, 51.773255467414856, 47.22896911203861, 47.587415277957916, 47.15529106557369, 51.180692464113235, 47.3247429728508, 46.82135358452797, 48.73017355799675, 48.8697362691164, 47.372666001319885, 49.741888269782066, 48.907323852181435, 50.79382382333279, 49.120047837495804, 48.38837429881096, 45.9242445230484, 46.20759151875973, 44.8006372153759, 47.66472212970257, 48.77140514552593, 52.958936244249344, 14.510535020381212, 0.049886484048329294, 1.7205580067820847, 3.2879804307594895, 7.794320834800601, 7.020814390853047, 14.20154320076108, 2.881558514200151, 0.2817456785123795, 0.26527056412305683, 23.66895653307438, 38.412708789110184, 13.97674061357975, 33.818835094571114, 17.675042264163494, 0.2598190144635737, 0.04807661593076773, 0.05244508269242942, 0.03461490683548618, 0.04929533744871151, 0.11843174070236273, 0.024723859460209496, 0.0321587245707633, 0.1373717575916089, 0.04081037790456321, 0.032164424264919944, 0.03771665367821697, 0.04046930909680668, 0.032367776439059526, 0.033285813115071505, 0.035767020599450916, 0.04448351166502107, 0.039936491593834944, 0.03120442655927036, 0.019724736011994537, 0.03082746192376362, 0.049690972664393485, 0.028541756546474062, 0.04076254277606495, 0.04935550707159564, 0.046107475500321016, 0.05563326376432087, 0.07948845421196893, 0.05231529961747583, 0.03804153995588422, 0.035843057339661755, 0.05797703292046208, 0.029758244199911132, 0.07206704423879273, 0.006276997382883565, 0.05410350815509446, 0.06516812107292935, 0.04894446858088486, 0.06050012721971143, 0.05096318818686996, 0.036091105357627384, 0.02612110645713983, 0.038575032813241705, 0.060042181285098195, 0.05452707038784865, 0.020102745220356155, 0.021374582247517537, 0.16225384664721787, 14.872722085565329, 42.37177334725857, 25.199256017804146, 49.08762037754059, 37.70980730652809, 4.586197156459093, 0.11639901305898093, 0.669558746740222, 2.4635918671265244, 2.8956521954387426, 5.895470576360822, 5.7531900610774755, 4.629740444943309, 1.5724508604034781, 0.36400657379999757, 29.81710072606802, 59.877775982022285, 59.818753749132156, 57.858096957206726, 58.89568828046322, 59.39739055931568, 58.78640614449978, 56.27250663936138, 59.736560359597206, 57.91214905679226, 56.40216328203678, 53.65455351769924, 51.48026078939438, 43.09560790657997, 41.723881512880325, 46.24245464801788, 50.12312941253185, 52.02344164252281, 53.207617700099945, 51.71541877090931, 52.79641896486282, 47.317964136600494, 45.03695413470268, 44.062447026371956, 42.400856986641884, 43.88438478112221, 44.55730967223644, 42.914562821388245, 40.806652531027794, 40.51129437983036, 41.41267441213131, 41.70718140900135, 40.058605670928955, 42.24991388618946, 50.03632307052612, 55.70427753031254, 54.03172887861729, 54.732088297605515, 51.542881429195404, 53.72652165591717, 55.939731895923615, 54.04461398720741, 54.398128017783165, 55.08733503520489, 54.84629116952419, 55.0258619338274, 57.80230455100536, 50.110061913728714, 52.47725889086723, 54.07236009836197, 52.73243799805641, 52.260195538401604, 50.40970243513584, 53.7669362872839, 53.9513897895813, 56.94889314472675, 56.045601814985275, 51.16743877530098, 54.22744117677212, 54.37206141650677, 52.858006060123444, 49.260150119662285, 39.60700370371342, 38.406553119421005, 40.078110024333, 38.34895201027393, 40.3477967530489, 38.904463201761246, 40.151620879769325, 40.293497666716576, 38.76969203352928, 38.9936900138855, 38.76403793692589, 37.78614521026611, 42.49353401362896, 47.72945165634155, 51.2943709641695, 53.18454533815384, 48.45705561339855, 48.55455078184605, 48.5457656532526, 51.56004510819912, 48.70550528168678, 48.29450413584709, 50.19376002252102, 50.57108357548714, 49.85155798494816, 51.27865120768547, 50.25440476834774, 52.27884493768215, 51.398751363158226, 51.7070098221302, 47.5141666084528, 48.04072715342045, 46.76626414060593, 49.30256724357605, 48.69169682264328, 53.46459411084652, 16.014417372643948, 0.25553649582434446, 3.7819228135049343, 7.592263827100396, 8.898388165980577, 8.843900989741087, 6.091526756063104, 1.2725776014849544, 0.10346648123231716, 0.23161623015766963, 25.78942134976387, 48.974150866270065, 14.94624624028802, 35.79226680099964, 22.501691468060017, 0.46309611294418573, 0.15315631841076538, 0.02721887645748211, 0.013639092594530666, 0.013727698533330113, 0.03550596273271367, 0.02165944821172161, 0.06547716620843858, 0.06263975752517581, 0.012410439285304165, 0.02118463882652577, 0.03299145508208312, 0.05254315008642152, 0.014675261554657482, 0.027562062241486274, 0.05565295294218231, 0.06342633016174659, 0.06611493081436493, 0.010566937035036972, 0.0008329951333507779, 0.019283293586340733, 0.14425302506424487, 0.1261011022143066, 0.1733018725644797, 0.14836879796348512, 0.14782682235818356, 0.2058159263106063, 0.17650631780270487, 0.2927714993711561, 0.10382335778558627, 0.13030587346293032, 0.15246791706886142, 0.1573778473539278, 0.21621537453029305, 0.09638841103878804, 0.14455386204645038, 0.2179793853429146, 0.1668202961445786, 0.11428853060351685, 0.15068196837091818, 0.15907604451058432, 0.08835320782964118, 0.23672918236115947, 0.18504778447095305, 0.22473527438705787, 0.18478170968592167, 0.2295003819745034, 0.21589205047348514, 15.66561983898282, 53.956701904535294, 30.043758563697338, 48.21695029735565, 42.63851523399353, 6.282033333554864, 0.5804342916235328, 0.810633598593995, 4.341465588659048, 16.316485963761806, 9.546544086188078, 8.785517122596502, 8.740785922855139, 1.7363820201717317, 0.35898639005608857, 29.398423992097378, 61.50176323950291, 61.812054589390755, 59.528817906975746, 62.848726361989975, 60.11882744729519, 59.56630289554596, 58.96006442606449, 61.5968569368124, 59.995151683688164, 60.05718715488911, 56.92517101764679, 53.719317242503166, 47.02541783452034, 43.595167100429535, 48.13154228031635, 53.17640997469425, 55.16739673912525, 55.944637432694435, 55.44684134423733, 53.45805466175079, 50.418536961078644, 47.336795926094055, 44.77677829563618, 44.5331771671772, 46.79561756551266, 45.92597343027592, 43.51351708173752, 42.501186802983284, 42.60868303477764, 43.95645931363106, 43.49083609879017, 42.206691205501556, 44.29706163704395, 51.52575954794884, 56.63732886314392, 55.470514073967934, 55.53184658288956, 55.060991048812866, 55.44797748327255, 58.664299696683884, 55.95709316432476, 57.81911104917526, 57.557080909609795, 55.78516758978367, 56.30809172987938, 58.54264922440052, 51.436000764369965, 53.747690320014954, 56.35272033512592, 54.790426567196846, 55.48562206327915, 54.23263169825077, 57.7108396589756, 55.35026952624321, 58.136386424303055, 58.41337636113167, 53.034434393048286, 55.710706785321236, 56.275227293372154, 53.907619938254356, 51.352169662714005, 42.0696097612381, 41.439964547753334, 41.99897915124893, 40.30854105949402, 41.352618634700775, 40.20675212144852, 42.14166909456253, 42.13416449725628, 42.70593881607056, 42.12589994072914, 40.44367700815201, 41.22478969395161, 44.53473888337612, 49.479573145508766, 52.83356197178364, 54.813027754426, 50.134365409612656, 49.66850660741329, 49.16662193834782, 52.1667243540287, 50.65850928425789, 49.77468051016331, 52.32731893658638, 52.45814211666584, 52.349901124835014, 52.91097141802311, 52.379828318953514, 54.73072797060013, 53.24780434370041, 52.531189396977425, 48.87778423726559, 50.6563775986433, 48.860700353980064, 53.26086424291134, 51.34650036692619, 52.89144046604633, 15.880055632442236, 0.272710564895533, 4.541053678840399, 10.607105176895857, 17.493208721280098, 17.296274788677692, 23.431731462478638, 8.959769122302532, 1.0981637542136014, 0.4455200076336041, 33.59966665506363, 50.99068745970726, 20.65031111240387, 48.3417584002018, 25.929517932236195, 0.5888632487040013, 0.24753010278800502, 0.16773258859757334, 0.24139939894666895, 0.1386329485103488, 0.19055569282500073, 0.1675394075573422, 0.15102743811439723, 0.20156364276772365, 0.12440456746844575, 0.141154172597453, 0.11950690488447435, 0.18881326366681606, 0.11347534455126151, 0.06394213021849282, 0.21012458339100704, 0.13087281491607428, 0.16258612100500613, 0.21187829319387674, 0.12600935791851953, 0.1305206658435054], [0.04739691998111084, 0.028323867554718163, 0.058584243306540884, 0.0629547621065285, 0.00579266345994256, 0.01659968758758623, 0.036603350527002476, 0.032001181461964734, 0.00824281994937337, 0.051540705244406126, 0.01333817304839613, 0.025219176241080277, 0.019219467030779924, 0.04616563019226305, 0.01403647278493736, 0.008960862669482594, 0.027264082527835853, 0.052317177251097746, 0.02492413914296776, 0.07000775513006374, 0.05821536993607879, 0.06970948597881943, 0.06306636627414264, 0.0348119210684672, 0.0864114600699395, 0.014873958607495297, 0.08758259878959507, 0.34631202172022313, 28.436767794191837, 29.453369043767452, 23.9372069388628, 42.17152029275894, 12.731699422001839, 0.27259119786322117, 0.5309427785687149, 1.2939401739276946, 1.843799406196922, 4.0635475516319275, 4.960958221927285, 2.51490930095315, 2.380603370256722, 0.003655435857581324, 12.117921207100153, 52.994969710707664, 58.369982689619064, 57.37896166741848, 57.569745630025864, 58.08490678668022, 57.86132678389549, 58.057666048407555, 56.62625625729561, 53.027324974536896, 50.33950500190258, 44.33806523680687, 41.97059087455273, 41.36160895228386, 47.6496597379446, 51.46173298358917, 52.14590907096863, 53.81634123623371, 51.46838262677193, 50.07088601589203, 46.56668744981289, 40.45116260647774, 42.88346529006958, 43.25802639126778, 43.49592782557011, 41.71647571027279, 40.47747239470482, 41.003660559654236, 38.881694823503494, 39.93112251162529, 39.25533637404442, 38.108797296881676, 40.27004912495613, 37.94542886316776, 42.150222435593605, 49.31694567203522, 52.956785559654236, 51.07110254466534, 50.53113631904125, 50.547825023531914, 51.32776357233524, 49.336271435022354, 50.18642641603947, 52.16237358748913, 55.31509481370449, 51.30110040307045, 51.19224764406681, 43.128548339009285, 49.51847925782204, 54.95670944452286, 50.62401473522186, 53.66430379450321, 53.99886064231396, 54.10245068371296, 51.24026566743851, 64.35587748885155, 52.440780848264694, 52.41948679089546, 51.915079057216644, 50.324776992201805, 50.218333303928375, 42.284826412796974, 36.89659774303436, 37.052488178014755, 38.14698524773121, 36.755100935697556, 37.58782625198364, 36.37641705572605, 39.65224027633667, 38.85826148092747, 37.70142115652561, 37.724972292780876, 37.42445021867752, 37.75924265384674, 40.587043315172195, 46.296548545360565, 47.7414970099926, 51.1368428170681, 50.136379301548004, 47.93946258723736, 50.14462485909462, 47.08734691143036, 47.389293909072876, 45.13047851622105, 43.69541712105274, 44.07322704792023, 47.04826220870018, 46.72450438141823, 45.38050130009651, 43.18288542330265, 47.14817024767399, 46.764204651117325, 44.86595571041107, 45.197457522153854, 47.436251789331436, 47.63394758105278, 50.78622043132782, 36.52607962489128, 0.9449693933129311, 0.12469222390791401, 2.3764276318252087, 6.334682358428836, 1.8270413554273546, 7.545417565852404, 2.760894326493144, 1.0014741425402462, 0.10774183072499, 1.0134002775885165, 33.11399571597576, 34.46697011590004, 25.568603798747063, 34.31347355246544, 5.450583323836327, 0.10959829087369144, 0.07218912753160112, 0.03885636244376656, 0.014569264312740415, 0.036956939366064034, 0.014591137260140385, 0.015839253392186947, 0.0253940132461139, 0.03306797421828378, 0.04730317188659683, 0.05642380318022333, 0.04698958480730653, 0.013459515121212462, 0.0360552930214908, 0.008496953578287503, 0.021251728976494633, 0.02091475125780562, 0.06414287374354899, 0.07048301908071153, 0.03722636494785547, 0.05601031189144123, 0.02588327039120486, 0.05539647783734836, 0.030555446246580686, 0.04844741888518911, 0.023995077863219194, 0.049052725662477314, 0.0330214267160045, 0.013323938655958045, 0.02894865199777996, 0.02189366630773293, 0.03486943751340732, 0.022568460371985566, 0.0064445942734892014, 0.009797970924410038, 0.07449361481121741, 0.025075485318666324, 0.04040190724481363, 0.05554371622565668, 0.03334779728902504, 0.042552551021799445, 0.07446375821018592, 0.08830378821585327, 0.05774016535724513, 0.056399111927021295, 0.058175490630674176, 0.007126808422981412, 0.13152103638276458, 1.2579600233584642, 36.23390570282936, 28.491975031793118, 29.995444156229496, 52.46950350701809, 13.986041564494371, 0.16627927048830315, 0.2316351846093312, 0.5778105917852372, 1.8920090817846358, 4.595193648710847, 6.165039986371994, 4.907822823151946, 3.0974118690937757, 0.22557128890184686, 14.972044955939054, 54.52397346496582, 58.51814053952694, 58.99867795407772, 59.75432440638542, 59.732787162065506, 58.339591920375824, 58.87507438659668, 59.04061250388622, 56.603871658444405, 52.89018653333187, 47.243856713175774, 44.513099044561386, 42.842309698462486, 50.01849822700024, 52.56587013602257, 54.22997184097767, 55.07275901734829, 53.06211970746517, 52.30676203966141, 48.5662579536438, 43.314054384827614, 43.793459460139275, 46.32424145936966, 45.05804680287838, 42.20454432070255, 43.71975481510162, 42.35313534736633, 40.61494141817093, 41.03635400533676, 41.03945083916187, 40.28079494833946, 40.807640478014946, 40.045621767640114, 43.63433159887791, 51.644772961735725, 54.66578185558319, 54.48644667863846, 54.35019738972187, 52.425612062215805, 52.76429928839207, 51.131694093346596, 53.541509583592415, 53.475317135453224, 55.82444228231907, 53.83823566138744, 52.15997591614723, 45.85837505757809, 52.38593079149723, 54.712606742978096, 53.56069095432758, 53.748043701052666, 55.12802705168724, 55.272841081023216, 52.095500975847244, 59.44896899163723, 56.10612116754055, 54.45702865719795, 53.37000198662281, 51.09530724585056, 52.06957496702671, 44.85130749642849, 39.78060498833656, 39.54134322702885, 39.71919268369675, 37.637744173407555, 39.35786247253418, 37.263198271393776, 41.161846071481705, 40.636873841285706, 39.95146282017231, 39.65038597583771, 38.961315751075745, 39.387390688061714, 42.633108124136925, 47.72819772362709, 49.38795246183872, 52.02308066189289, 49.56628829240799, 49.467387199401855, 51.731415912508965, 50.23373007774353, 48.31691533327103, 46.25170335173607, 48.0218231678009, 46.34224109351635, 48.19927744567394, 48.432926908135414, 47.86435581743717, 44.89131174981594, 48.16369615495205, 48.39995227754116, 48.245783150196075, 46.64135344326496, 48.97042706608772, 49.21464756131172, 52.217466831207275, 37.78768412768841, 2.16571397613734, 2.218219321221113, 6.74926433712244, 11.24739171937108, 5.216322569176555, 6.172267198562622, 2.803476504050195, 0.32134451146703213, 0.2078450916451402, 1.3827472273260355, 36.707535088062286, 40.0655023008585, 21.490024253726006, 41.05812303721905, 7.28909756988287, 0.01790833513950929, 0.05658994035911746, 0.05347574769984931, 0.07405541371554136, 0.01854853398981504, 0.032759500536485575, 0.06590303280972876, 0.0625559245236218, 0.013087082224956248, 0.02346080946153961, 0.02893541950470535, 0.040250802267109975, 0.024856954369170126, 0.09285210704547353, 0.030529840296367183, 0.03257651660533156, 0.06473838046076708, 0.07883819183916785, 0.036100942525081336, 0.01400049717631191, 0.048501350756851025, 0.13367488252697513, 0.29962202708702534, 0.228090004529804, 0.14216989075066522, 0.12335695922956802, 0.13853657321305946, 0.17745399585692212, 0.11017254248145036, 0.09319540971773677, 0.1778116961941123, 0.13327441964065656, 0.06865202201879583, 0.13284851593198255, 0.09587955748429522, 0.09257151585188694, 0.13568329741246998, 0.09932894114172086, 0.19807669159490615, 0.14736257930053398, 0.23597211751621217, 0.15395528491353616, 0.2829425845993683, 0.15023960382677615, 0.13722202187636867, 0.191136289795395, 0.09085751094971783, 0.22823231876827776, 1.0428409790620208, 41.27605654299259, 41.723687723279, 31.52397483587265, 54.32746700942516, 20.62384743243456, 0.5932352703530341, 1.9161705602891743, 5.0449850130826235, 5.617209132760763, 14.845940172672272, 11.564538851380348, 8.643397148698568, 6.278076320886612, 0.2641603408847004, 14.084611125290394, 55.674270540475845, 59.6801333874464, 60.585537403821945, 62.06196717917919, 58.98329637944698, 60.442247092723846, 60.88093735277653, 63.30613061785698, 58.4721440076828, 54.2368570715189, 49.956310763955116, 46.40332281589508, 47.33812965452671, 53.41335006058216, 56.85320287942886, 55.71276627480984, 58.39528173208237, 55.965114533901215, 52.786197513341904, 50.70166356861591, 45.643238201737404, 46.658729910850525, 49.304638132452965, 46.6709690541029, 45.17465874552727, 43.764208629727364, 45.01818314194679, 42.14999444782734, 44.08107742667198, 43.46079111099243, 42.92034611105919, 43.676562532782555, 42.55349099636078, 45.03555200994015, 52.53789223730564, 56.96450650691986, 56.11746735870838, 54.8504139482975, 55.00632718205452, 54.68466304242611, 51.96324907243252, 52.47295752167702, 55.02981372177601, 55.95445230603218, 55.1871594786644, 53.44715304672718, 45.565342381596565, 51.447517946362495, 58.720707669854164, 54.394081234931946, 57.78548665344715, 56.870860531926155, 57.94525288045406, 53.20683874189854, 63.33600461483002, 56.50060459971428, 56.47556014358997, 54.708765149116516, 54.434237480163574, 54.76385839283466, 46.27684660255909, 40.891368985176086, 40.46658597886562, 41.502547189593315, 38.38345415890217, 40.976252630352974, 39.85411964356899, 42.51206561923027, 43.23330491781235, 42.26263180375099, 40.70002265274525, 40.281345918774605, 42.154588401317596, 44.93220895528793, 50.6728421151638, 52.15816721320152, 53.73010106384754, 50.14209419488907, 49.52867791056633, 52.60531201958656, 51.70287944376469, 51.50326855480671, 48.180928230285645, 49.24243167042732, 47.31860250234604, 51.18815906345844, 50.95617011189461, 48.72036248445511, 47.536699399352074, 49.81616288423538, 50.621392875909805, 48.49273569881916, 48.950440138578415, 51.04798838496208, 52.03952997922897, 52.69871860742569, 37.68486924469471, 1.9295555795542896, 2.16420141980052, 6.976455096155405, 17.282874807715416, 9.1456294991076, 17.2436286136508, 8.696748185902834, 2.4263446033000946, 0.41324198653455824, 2.855523261241615, 45.0257333368063, 46.259443536400795, 33.64010028541088, 48.405298590660095, 8.809460587799549, 0.231795993167907, 0.1318553590681404, 0.17440256662666798, 0.22317394410492852, 0.07980972994118929, 0.17009022849379107, 0.23933431366458535, 0.1266128575662151, 0.12881011934950948, 0.110384648287436, 0.1845771144144237, 0.151090654253494, 0.08313675571116619, 0.13226618233602494, 0.16072475526016206, 0.09833761738264002, 0.10700591708882712, 0.12161483435193077, 0.17081181867979467, 0.16547994775464758, 0.13049700617557392], [0.014794635080761509, 0.07879584489273839, 0.06121851132775191, 0.05805849104945082, 0.03609259336371906, 0.04716405259387102, 0.07626924765645526, 0.016147602764249314, 0.028223993031133432, 0.04252528822689783, 0.01285163587454008, 0.03524367661157157, 0.08448068125289865, 0.015611653398082126, 0.02040559527813457, 0.03983115857408848, 0.05872996771358885, 0.05020310651161708, 0.01800646190531552, 0.031940544286044315, 0.04948225847329013, 0.014121932017587824, 0.060958989706705324, 0.01072528259101091, 0.03652919884189032, 0.07351317835855298, 0.04293359932489693, 0.11598930301261134, 8.971554189920425, 42.37294368445873, 26.677832677960396, 47.69000977277756, 32.62000322341919, 2.8837027866393328, 0.2982351608807221, 0.7947481947485358, 0.7408537273295224, 4.100539516657591, 3.7873883452266455, 3.8757212553173304, 1.2670338177122176, 0.17703346529742703, 6.155901476740837, 38.41091148555279, 58.55642728507519, 55.56801684200764, 58.68976213037968, 58.14906254410744, 58.50960239768028, 55.00586360692978, 54.22410495579243, 50.85160352289677, 46.7258533090353, 42.08079256117344, 42.91380286216736, 50.68562462925911, 52.75423362851143, 53.467189371585846, 53.553068563342094, 50.536490231752396, 50.52122265100479, 43.99066507816315, 41.50171123445034, 42.409064546227455, 46.73075504601002, 49.91506777703762, 53.02854470908642, 47.755427062511444, 40.22929631173611, 37.71475464105606, 38.5634732991457, 38.898828104138374, 39.754633381962776, 39.53018702566624, 39.90773856639862, 39.33425433933735, 39.1025085747242, 41.44745014607906, 49.061918556690216, 54.013410061597824, 52.73663677275181, 51.91930443048477, 52.78151996433735, 53.684389516711235, 55.42189568281174, 54.2890814691782, 54.80319768190384, 54.80132058262825, 55.13285279273987, 46.13942697644234, 45.742967650294304, 50.498594865202904, 52.77123771607876, 50.74639096856117, 51.207412630319595, 47.928655967116356, 53.475609719753265, 51.283628940582275, 49.99091550707817, 53.11961442232132, 54.40568961203098, 49.36506249010563, 46.36223942041397, 39.21309784054756, 38.267685770988464, 39.66426283121109, 38.6613180488348, 34.94267798960209, 37.512461096048355, 37.74410046637058, 40.16518235206604, 38.14164273440838, 37.30319872498512, 38.16973462700844, 37.90862023830414, 37.74921119213104, 39.33016195893288, 44.258440509438515, 49.810007214546204, 49.545336216688156, 50.560105964541435, 49.56129916012287, 51.64429038763046, 48.64703021943569, 46.852280125021935, 42.721544578671455, 41.86898432672024, 37.03077994287014, 42.140411362051964, 40.602751672267914, 41.65675051510334, 40.30490085482597, 44.34264779090881, 41.59678213298321, 46.56216949224472, 45.946389734745026, 49.47392664849758, 45.102428421378136, 49.9229371547699, 5.8093999698758125, 0.3965731122298166, 1.796682053245604, 6.610329067334533, 6.889678202569485, 2.3644632613286376, 5.191977750509977, 1.63439478026703, 0.4663393279770389, 0.068148571299389, 7.343758586794138, 44.02633756399155, 23.442182801663876, 26.476741768419743, 26.472313106060028, 0.39648568723350763, 0.04490983468713239, 0.057206041674362496, 0.012641483772313222, 0.11511154269101098, 0.06963172374526039, 0.04464510318939574, 0.06857394066173583, 0.02740659714618232, 0.037306524318410084, 0.028236665202712175, 0.06467491941293702, 0.049586096065468155, 0.06373550146236084, 0.06281080772168934, 0.0273298702086322, 0.010507472452445654, 0.07319666721741669, 0.05461255837872159, 0.06635514175286517, 0.029168613436922897, 0.05707168696972076, 0.04242084578436334, 0.036660533005488105, 0.04467831429792568, 0.07302756886929274, 0.023379874546662904, 0.026003292368841358, 0.0051504951352399075, 0.023262470494955778, 0.011803614816017216, 0.07285504922037944, 0.008447466243524104, 0.07282531136297621, 0.018718765968515072, 0.01931821163452696, 0.009871519614534918, 0.06907406655955128, 0.031752124123158865, 0.04463865392608568, 0.01809092387702549, 0.03341126204759348, 0.050432812349754386, 0.031949116091709584, 0.09766057090018876, 0.07076985173625872, 0.04952906943799462, 0.06374642587616108, 0.10663583772839047, 0.18996984144905582, 13.221936766058207, 45.70562705397606, 23.09633295983076, 49.20113168656826, 35.42492911219597, 2.181217144243419, 0.24254901538370177, 0.9151917567942291, 1.0685457685030997, 3.846687488257885, 8.818961028009653, 5.845083380118012, 4.431730695068836, 0.9130657708737999, 6.546939918771386, 41.11155577003956, 59.27420876920223, 58.02482061088085, 59.58334118127823, 60.05687177181244, 58.85833628475666, 57.339793369174004, 55.315706580877304, 52.98373371362686, 49.44338008761406, 44.43573899567127, 44.763194024562836, 51.02066785097122, 54.600356966257095, 54.70842696726322, 55.311986580491066, 53.662308901548386, 51.148663982748985, 49.24933210015297, 43.874015137553215, 44.67259168624878, 46.69741563498974, 51.184473261237144, 55.39718180894852, 47.021477445960045, 41.07235327363014, 40.78855410218239, 42.08167411386967, 40.87769351899624, 41.876192539930344, 41.72871485352516, 41.85198783874512, 41.76369957625866, 41.163639575242996, 44.72450450062752, 52.02273108065128, 54.601291716098785, 55.05189433693886, 55.24723805487156, 53.37338000535965, 53.74726094305515, 56.21861033141613, 55.77626086771488, 57.065353095531464, 56.47507756948471, 55.578040704131126, 47.072816491127014, 48.32482650876045, 52.52567209303379, 55.42050875723362, 52.26425752043724, 54.08325031399727, 51.91129446029663, 54.93739888072014, 53.186547830700874, 51.27586215734482, 54.27203558385372, 56.83921582996845, 49.862531796097755, 49.57061626017094, 40.718603655695915, 39.49655883014202, 40.431924238801, 38.681954741477966, 37.77465082705021, 38.89356158673763, 39.965761452913284, 42.13691934943199, 39.496106654405594, 39.08169709146023, 39.037224277853966, 40.2147126942873, 38.25426869094372, 41.75952360033989, 46.5377102047205, 51.34420908987522, 52.33524911105633, 50.640771836042404, 49.35356430709362, 52.10184283554554, 50.075555965304375, 48.15926559269428, 45.26340298354626, 44.43921580910683, 38.647798374295235, 45.17439655959606, 43.30249160528183, 42.55847632884979, 41.56363271176815, 46.1842455714941, 43.512563332915306, 47.795104533433914, 48.82343955338001, 51.487803384661674, 46.3002647459507, 51.26440957188606, 7.636600323021412, 1.33966822642833, 3.3040766045451164, 8.858257569372654, 8.832461703568697, 5.240855477750301, 3.419232275336981, 1.6164046456106007, 0.5782163981348276, 0.04684467305196449, 8.30299336463213, 51.07212848961353, 29.625311717391014, 31.318801045417786, 32.422820404171944, 0.8092646626755595, 0.09397806381457485, 0.019565059228625614, 0.061842843060730956, 0.10002638926380314, 0.0608905191620579, 0.06387777859345078, 0.040543512732256204, 0.03951756778405979, 0.013664342313859379, 0.031901459078653716, 0.035271611050120555, 0.017927721892192494, 0.04301373643102124, 0.011960637493757531, 0.009667765752965352, 0.03196375124389306, 0.0752305006608367, 0.05103749572299421, 0.058115458305110224, 0.07943771357531659, 0.05823548955959268, 0.15180509013589472, 0.15467398072360083, 0.1498038147110492, 0.11339349308400415, 0.15503886505030096, 0.13993814878631383, 0.13005768443690613, 0.14780501805944368, 0.08464404279948212, 0.10512587890843861, 0.08054634119616821, 0.15663031168514863, 0.15263666660757735, 0.12171895024948753, 0.18712418008362874, 0.14557729853549972, 0.060594361420953646, 0.10177618052694015, 0.15316136501496658, 0.16622346098301932, 0.15159912931267172, 0.12650260410737246, 0.24240514263510704, 0.16291763837216422, 0.25687850662507117, 0.24145269999280572, 0.2670222701271996, 0.28909172338899225, 15.144708640873432, 55.80223627388477, 34.70771759748459, 56.1362611502409, 45.24357944726944, 4.471323620527983, 0.6486376631073654, 3.845695978961885, 4.50896012596786, 11.317004933953285, 11.078390087932348, 10.286570526659489, 3.9737215591594577, 2.261056797578931, 8.561723381280899, 41.501551643013954, 60.85634887218475, 58.5999121516943, 60.214738100767136, 60.33981218934059, 61.73955827951431, 60.83637714385986, 58.00217382609844, 54.68055546283722, 51.11273691058159, 47.076392099261284, 47.98742361366749, 54.81957100331783, 56.25401683151722, 56.81994326412678, 57.963674291968346, 54.475176483392715, 53.344813138246536, 48.86188589036465, 46.111829057335854, 46.154595762491226, 49.974462389945984, 53.810778334736824, 58.44345934689045, 51.294313967227936, 45.29803812503815, 43.19271169602871, 43.035704120993614, 42.81657747924328, 45.077345967292786, 44.40384730696678, 44.62774649262428, 43.15210707485676, 43.36820907890797, 45.14546491205692, 53.39213199913502, 56.61125846207142, 57.726346626877785, 57.40962602198124, 57.102792486548424, 57.08720192313194, 59.26171883940697, 58.41000214219093, 59.793310314416885, 58.8445620238781, 57.18807131052017, 49.28985692560673, 47.76111915707588, 54.11985754966736, 60.4338039457798, 56.41276091337204, 56.7084002494812, 53.91868494451046, 55.69556459784508, 57.12638542056084, 52.912244349718094, 55.190662890672684, 60.7387375831604, 52.89280839264393, 51.456280276179314, 43.45821864902973, 42.31362126767635, 43.23955558240414, 41.007904931902885, 39.286376908421516, 41.1546378582716, 42.625500932335854, 44.4469939917326, 40.51770083606243, 41.617411226034164, 41.92739479243755, 42.335454896092415, 41.707443594932556, 43.884768560528755, 48.73146928846836, 52.82099224627018, 52.8847262263298, 52.84850277006626, 49.78312745690346, 54.97120566666126, 52.015496268868446, 50.99417947232723, 47.181300669908524, 46.81388318538666, 40.41892893612385, 46.46846652030945, 45.5816663056612, 46.56200610101223, 43.997497111558914, 47.626758366823196, 45.73225602507591, 50.538667514920235, 51.45160652697086, 54.00788515806198, 47.14996375143528, 50.68745233118534, 6.633403804153204, 1.1150499293580651, 5.262711429968476, 13.036808799952269, 17.73062188178301, 7.873222650960088, 14.748941827565432, 5.319562079384923, 1.3809930277056992, 0.22478330618469045, 11.912751216441393, 57.253089621663094, 33.17308634519577, 37.272389978170395, 38.09035688638687, 0.8734409627504647, 0.1935382655938156, 0.12410692172124982, 0.17726033984217793, 0.24177639512345195, 0.20051630912348628, 0.22002078127115965, 0.20849513879511505, 0.08056759630562738, 0.1974682937725447, 0.07141359063098207, 0.1656194863608107, 0.13344270904781297, 0.116611994599225, 0.18866971746319905, 0.0622279063827591, 0.11493747937493026, 0.2934930450282991, 0.16422000364400446, 0.197853765275795, 0.1542380580212921, 0.14384919282747433], [0.05823904444696382, 0.00568630627640232, 0.03956913962610997, 0.034906107030110434, 0.010019832261605188, 0.016727314723539166, 0.017910969763761386, 0.06267670905799605, 0.03615981338953134, 0.09146972341113724, 0.03436475482885726, 0.04086943059519399, 0.02709522352233762, 0.030964809338911436, 0.07828679095837288, 0.05077448600786738, 0.07464394424459897, 0.026714214181993157, 0.03290263484814204, 0.020665413758251816, 0.028399837501638103, 0.08218751914682798, 0.027806392099591903, 0.0476970593445003, 0.04065382185217459, 0.03839564829831943, 0.036617818695958704, 0.07916049173218198, 0.6832571898121387, 33.74419949948788, 28.838524036109447, 41.08558416366577, 51.589736714959145, 12.858169935643673, 0.15302010462619364, 0.24346307414816692, 1.1640684865415096, 0.7686447235755622, 6.434174319729209, 4.332789704203606, 4.267578553408384, 0.6767926085740328, 0.47937604249455035, 18.355568647384644, 50.98602131009102, 54.447563365101814, 57.722873613238335, 58.12434107065201, 56.59446716308594, 55.751326605677605, 50.23277632892132, 45.15143059194088, 44.08053785562515, 47.22476653754711, 53.37864652276039, 55.74507974088192, 56.12466037273407, 56.21465474367142, 51.29022918641567, 52.38697573542595, 47.265929728746414, 42.86610022187233, 42.53006525337696, 48.07419575750828, 52.117478996515274, 53.95585834980011, 54.235774129629135, 54.57503132522106, 42.34995111823082, 38.174757957458496, 40.49038030207157, 39.420646503567696, 39.14393775165081, 39.89423029124737, 39.627127423882484, 37.928607165813446, 39.299554601311684, 40.37891708314419, 41.314312890172005, 48.36847476661205, 49.04700815677643, 53.26121382415295, 54.316493198275566, 50.867414474487305, 52.64346957206726, 51.18166521191597, 51.53580620884895, 51.02875001728535, 54.996880888938904, 49.242416471242905, 46.46690480411053, 49.695770144462585, 49.52335439622402, 51.702757850289345, 46.891949996352196, 55.69347470998764, 43.630763590335846, 31.563538312911987, 55.02134397625923, 51.33985072374344, 52.40272209048271, 47.61166177690029, 43.506267070770264, 37.017526254057884, 37.678519785404205, 36.35643392801285, 37.89662428200245, 36.5065448731184, 37.741881385445595, 36.768821999430656, 37.449243888258934, 38.79704296588898, 37.76193290948868, 37.660778537392616, 36.37585088610649, 37.28399075567722, 38.56109842658043, 44.14005406200886, 48.113029673695564, 49.09553915262222, 49.648846462368965, 46.7510649561882, 49.473200887441635, 47.603731602430344, 46.52815751731396, 42.0123316347599, 39.725184962153435, 41.11431062221527, 45.37118420004845, 45.404162630438805, 43.5152193903923, 44.92910832166672, 44.227570965886116, 45.69205418229103, 45.79830788075924, 46.64023630321026, 46.50337524712086, 50.69030977785587, 17.563126869499683, 0.0984781801525969, 1.3650106103159487, 2.24542657379061, 9.229570794850588, 5.167670929804444, 6.295151654630899, 2.3607100127264857, 1.275076917372644, 0.0747148045047652, 0.1587200362700969, 19.38075553625822, 41.480029597878456, 17.95983888208866, 37.70839378237724, 9.615085758268833, 0.10997476012562402, 0.07456260485923849, 0.05225512257311493, 0.031088093055586796, 0.04424731574545149, 0.02991936074977275, 0.06255483356653713, 0.03811532056715805, 0.023463408833777066, 0.04551670739601832, 0.020436685699678492, 0.03182932974596042, 0.032855048339115456, 0.06595829312573187, 0.024674933374626562, 0.02232422513770871, 0.08390638511627913, 0.03253381342801731, 0.0127357708515774, 0.034677981966524385, 0.01716045993816806, 0.021508363643079065, 0.011780154600273818, 0.07390936647425406, 0.03561341829481535, 0.021284934518916998, 0.044653337317868136, 0.027464143277029507, 0.042661869374569505, 0.014969140902394429, 0.030642752499261405, 0.01289378151341225, 0.05521536040760111, 0.01651848364417674, 0.07348865779931657, 0.017181818948301952, 0.050959811414941214, 0.017893434669531416, 0.051055771109531634, 0.036561957240337506, 0.07249115195008926, 0.029490644301404245, 0.02358077577810036, 0.025776345464691985, 0.07799533472280018, 0.022373965730366763, 0.0643594101711642, 0.011593712260946631, 0.056271076609846205, 0.05086142489744816, 1.1998880957253277, 40.56942746043205, 31.126443967223167, 40.8491076529026, 61.22176006436348, 13.515980187803507, 0.09180383087368682, 0.4338136373553425, 1.2685552798211575, 1.5142302657477558, 10.557253751903772, 5.857533887028694, 4.755045371130109, 3.0522793158888817, 0.8730279130395502, 22.068966887891293, 52.06855282187462, 57.29734964668751, 58.96319165825844, 62.21511036157608, 58.70464213192463, 57.33491063117981, 51.690959483385086, 46.85306668281555, 45.71451477706432, 47.472156062722206, 54.15415070950985, 58.01272965967655, 57.670102044939995, 57.83747546374798, 54.63884510099888, 54.61979292333126, 50.90811789035797, 45.159641951322556, 43.17174822092056, 50.27956701815128, 52.2502476722002, 56.5070566534996, 57.74654634296894, 56.721703335642815, 44.107816591858864, 40.37333518266678, 42.89942443370819, 40.93257017433643, 41.296716034412384, 42.19876103103161, 42.05104015767574, 40.54761663079262, 42.213074862957, 41.857672333717346, 44.718242436647415, 50.96712492406368, 52.63816125690937, 54.44141909480095, 56.62763558328152, 54.49140541255474, 54.35196049511433, 55.9086799621582, 54.73723702132702, 53.81299741566181, 55.09303852915764, 51.632811203598976, 45.60677155852318, 51.0148161649704, 52.12682269513607, 53.278518095612526, 50.36871783435345, 56.58953122794628, 47.613071501255035, 32.38098464906216, 55.917343497276306, 53.866148963570595, 55.256144776940346, 51.1403576284647, 44.63298261165619, 38.53441245853901, 38.91029208898544, 37.64530196785927, 40.15547387301922, 38.31312753260136, 40.418214574456215, 38.36282506585121, 39.172033444046974, 37.945755645632744, 39.755769520998, 39.43760499358177, 39.14100430905819, 38.630725890398026, 39.01523105800152, 45.718504562973976, 49.555865451693535, 51.248127445578575, 50.058251693844795, 48.13466191291809, 49.884141236543655, 49.318659380078316, 47.91572146117687, 44.081715792417526, 41.12915262579918, 41.92938208580017, 45.24558573961258, 46.55263960361481, 45.37574015557766, 45.43289288878441, 44.58007425069809, 46.22449301183224, 50.008789747953415, 49.18723963201046, 47.97230422496796, 51.72300696372986, 22.75556344538927, 0.16464191459817812, 3.2973944256082177, 3.5185411339625716, 12.596780061721802, 3.75040540471673, 7.03312668018043, 1.6088144341483712, 0.5005302198696882, 0.15599184203892946, 0.04010133743577171, 22.114938721060753, 51.23427338898182, 19.177147261798382, 39.94998849928379, 14.660244137048721, 0.11553176154848188, 0.1227501496032346, 0.04971091417246498, 0.05089305152068846, 0.05909562387387268, 0.06839522407972254, 0.04351641902758274, 0.02909581431595143, 0.043738718231907114, 0.04327535461925436, 0.03959332621889189, 0.03667014752863906, 0.010251577150484081, 0.04448865474842023, 0.048142032537725754, 0.0035104522066831123, 0.019863484230882023, 0.04795132284925785, 0.03324244200484827, 0.018941180205729324, 0.0624641876493115, 0.014471770227828529, 0.12745567015372217, 0.22690142533974722, 0.10194271104410291, 0.10751196532510221, 0.20992448553442955, 0.04695780233305413, 0.20248059590812773, 0.10600792884360999, 0.1153226094902493, 0.17477577785030007, 0.2228843283955939, 0.1452250752481632, 0.13591888477094471, 0.1229273150966037, 0.19105932908132672, 0.07902573255705647, 0.1686269507627003, 0.19566754664992914, 0.15476826316444203, 0.14508632331853732, 0.09364181896671653, 0.16761984152253717, 0.13468196208123118, 0.17967638676054776, 0.21911665244260803, 0.09139144909568131, 0.07960968403494917, 0.10154691626667045, 1.1623665341176093, 48.135642260313034, 40.748462453484535, 47.17647112905979, 63.310071006417274, 20.050925575196743, 0.3804886940633878, 1.3775121769867837, 1.989578464999795, 7.971482053399086, 21.020418852567673, 9.325277209281921, 9.896698147058487, 1.9351146812550724, 0.7602565549314022, 21.064196303486824, 53.15147951245308, 56.33127048611641, 59.74911868572235, 62.5360943377018, 60.53789556026459, 60.75197607278824, 55.263896360993385, 48.560672253370285, 48.62710788846016, 49.29907903075218, 57.906605154275894, 59.982745349407196, 60.39389468729496, 59.858446419239044, 56.00536197423935, 56.993707939982414, 52.27617748081684, 46.855050176382065, 46.98681190609932, 54.87681873142719, 54.77809242904186, 58.59241135418415, 58.425292521715164, 59.94782902300358, 47.93412387371063, 43.23107063770294, 43.77048969268799, 43.97586867213249, 44.38360579311848, 44.27663393318653, 44.859492257237434, 41.84276573359966, 43.20182740688324, 44.65630955994129, 47.09478311240673, 51.53443068265915, 53.371214121580124, 57.32750482857227, 59.60142821073532, 55.21524377167225, 56.045172438025475, 57.88266263902187, 57.809835746884346, 54.14431303739548, 57.24686935544014, 53.0303306132555, 46.307507157325745, 50.56321419775486, 52.58026756346226, 54.94578883051872, 50.642109364271164, 55.74122674763203, 47.526299357414246, 38.560391664505005, 57.02972240746021, 54.699752032756805, 56.9068294018507, 53.19326967000961, 46.40801556408405, 40.26685729622841, 40.94524249434471, 40.20234055817127, 40.62867388129234, 40.05704015493393, 42.489757016301155, 39.81325663626194, 41.109899058938026, 41.69638238847256, 40.98881475627422, 39.998192712664604, 39.30009797215462, 40.36591038107872, 41.41409933567047, 47.69181847572327, 53.0250146985054, 53.57985332608223, 51.17573752999306, 49.31577153503895, 51.44883647561073, 50.37812992930412, 50.54794281721115, 44.47852469980717, 43.672610744833946, 44.76160570979118, 49.00279372930527, 49.138571843504906, 46.906879395246506, 48.552818074822426, 47.41289064288139, 48.108279928565025, 50.87746873497963, 49.883343279361725, 49.50880877673626, 52.561177387833595, 20.7314158603549, 0.14007434772793204, 5.624395497143269, 5.7685065641999245, 17.281598076224327, 14.630830865353346, 10.177925806492567, 7.582947677001357, 3.110982128418982, 0.2716847386909649, 0.28248669812455773, 29.672911763191223, 53.75302903354168, 24.954013377428055, 51.34838506579399, 16.502035707235336, 0.17689181899186224, 0.4357005626661703, 0.21489976934390143, 0.08680658691446297, 0.11280958613497205, 0.1668565723230131, 0.12146348075475544, 0.11473914040834643, 0.16546136437682435, 0.1211365350172855, 0.10266398210660554, 0.1208091810985934, 0.12521422089776024, 0.18244718026835471, 0.13933251175330952, 0.10991362942149863, 0.11900870114914142, 0.14374699909240007, 0.10904922033660114, 0.13826580805471167, 0.10501623401069082, 0.09305727377068251], [0.06134792332886718, 0.048541927681071684, 0.0650894534192048, 0.04190804029349238, 0.06205307123309467, 0.04768669525219593, 0.007569974486614228, 0.01777060366293881, 0.023236076012835838, 0.0029721172995778034, 0.08962723048171028, 0.017490116370026954, 0.005245879665380926, 0.05042369506554678, 0.08846577678923495, 0.03634149856225122, 0.014225417089619441, 0.07570321162347682, 0.11448134056990966, 0.052901818926329724, 0.04622610409569461, 0.0652359014202375, 0.027897097388631664, 0.044512392341857776, 0.02228556666523218, 0.039977139022084884, 0.0360316778824199, 0.10985810935380869, 0.11018785298801959, 10.437264740467072, 45.80220267176628, 23.22110876441002, 43.71651738882065, 32.749682664871216, 1.396030008327216, 0.5130181310232729, 0.6075217318721116, 0.9020624519325793, 7.166786408051848, 4.251272203400731, 4.21542065218091, 2.56766923237592, 0.09992256280384026, 2.152548157609999, 27.563073076307774, 52.49940790235996, 58.646421656012535, 60.17075926065445, 58.30907195806503, 54.1222932189703, 48.52260209619999, 48.13630722463131, 50.798641964793205, 57.709350138902664, 57.07451440393925, 57.97201864421368, 59.37383942306042, 54.90534760057926, 50.92294469475746, 47.44800455868244, 42.48061850667, 44.080093279480934, 48.60518306493759, 52.88170538842678, 55.30453518033028, 58.554272800683975, 55.96689663827419, 53.37440975010395, 45.598484203219414, 39.868862852454185, 41.83895833790302, 39.27286483347416, 40.75568586587906, 39.50869917869568, 40.11877924203873, 39.616761580109596, 40.060877948999405, 39.336576014757156, 37.91411854326725, 40.2533034235239, 42.51031011343002, 45.02619691193104, 46.87924727797508, 50.84459289908409, 50.73283709585667, 47.81664937734604, 49.934640526771545, 51.37608177959919, 52.89224602282047, 47.642671912908554, 42.452917993068695, 55.42007178068161, 47.87760570645332, 54.35685843229294, 52.26274900138378, 48.26086834073067, 39.02184650301933, 50.172351971268654, 53.280326798558235, 50.63181571662426, 50.78219264745712, 42.75472819805145, 38.53794626891613, 37.319621443748474, 36.74057051539421, 37.78400972485542, 37.23787263035774, 39.224360436201096, 35.698757618665695, 37.99240194261074, 44.18184421956539, 44.00256983935833, 40.524882450699806, 38.30181173980236, 37.370439916849136, 38.05566854774952, 38.46959173679352, 43.17864865064621, 47.97072730958462, 50.31474173069, 51.2609251588583, 48.40540498495102, 49.74390596151352, 47.74144761264324, 47.87128284573555, 42.601277232170105, 40.43949343264103, 45.75349688529968, 50.94272643327713, 49.584645107388496, 48.49286109209061, 48.028556406497955, 48.18394906818867, 49.58637021481991, 48.38868208229542, 47.242845967411995, 50.76615370810032, 29.294385574758053, 0.5133319704327732, 1.440486554056406, 1.9967729039490223, 2.160462182946503, 11.872192192822695, 1.0912106023170054, 5.816548336297274, 0.010239946768706432, 0.4387417947873473, 0.21902285981923342, 1.1553428485058248, 37.762685269117355, 33.21790874004364, 25.032619759440422, 28.805209323763847, 1.9705255748704076, 0.059570572411757894, 0.07831157126929611, 0.03390404068341013, 0.06750903296051547, 0.062171714671421796, 0.07061575219267979, 0.09033955866470933, 0.03771751456952188, 0.049553745848243125, 0.03292233515821863, 0.011214044352527708, 0.01768726604495896, 0.06546828270074911, 0.0735249265562743, 0.03627999307354912, 0.02105636416672496, 0.04169809784798417, 0.0813575011852663, 0.08809994993498549, 0.009355452384625096, 0.012594643121701665, 0.015381715638795868, 0.03833313719951548, 0.029244477627798915, 0.042536520631983876, 0.040740415643085726, 0.05412071113823913, 0.04609550094755832, 0.01862637043814175, 0.03161051121423952, 0.0220388359593926, 0.05018146177462768, 0.02755311750661349, 0.01012751696180203, 0.021027906514063943, 0.0923513577436097, 0.07286195861524902, 0.04916554695228115, 0.010916118444583844, 0.050650324701564386, 0.036134038600721397, 0.040593077064841054, 0.025874002822092734, 0.013919866541982628, 0.04792680229002144, 0.0409589744231198, 0.013887576624256326, 0.04377497585664969, 0.04843162227189168, 0.08794449968263507, 0.03071286319027422, 16.434528529644012, 48.227456733584404, 28.703361488878727, 52.628714963793755, 36.288907751441, 1.0367548931390047, 0.27436392148956656, 0.6664464168716222, 0.9647754742763937, 2.958937562070787, 5.721134031191468, 6.9917150773108006, 8.539689313620329, 0.6129131081979722, 2.698066122829914, 31.302190236747265, 54.07689705491066, 59.24611307680607, 61.225373670458794, 60.43976962566376, 54.470631927251816, 50.866213738918304, 48.72217498719692, 51.64619408547878, 57.86816641688347, 58.65989573299885, 60.37584945559502, 60.52094466984272, 57.14853823184967, 53.75668823719025, 50.23547798395157, 44.9452992528677, 44.32679884135723, 51.148929968476295, 54.876632541418076, 58.615962490439415, 58.45154531300068, 57.292022332549095, 56.19855880737305, 46.42041429877281, 42.39552967250347, 43.46975103020668, 40.05284897983074, 42.134555876255035, 42.39505469799042, 41.15305334329605, 40.49594320356846, 42.60907061398029, 41.172128319740295, 39.463204219937325, 41.112110540270805, 46.1412812769413, 49.25310529768467, 49.56743583083153, 53.36183242499828, 52.72686369717121, 51.79325379431248, 51.67398199439049, 53.543637469410896, 55.99569909274578, 50.24951063096523, 44.21266436576843, 55.37800423800945, 49.92204800248146, 55.27135156095028, 53.05332697927952, 48.86142611503601, 39.99153546988964, 49.208647683262825, 54.791942685842514, 52.87550412118435, 51.27791404724121, 45.25584898889065, 40.38307026028633, 38.71207572519779, 38.274665996432304, 39.08961586654186, 40.32305248081684, 41.80766701698303, 39.002364948391914, 39.96806412935257, 43.633438646793365, 45.50857722759247, 42.442601546645164, 40.102827697992325, 38.45289923250675, 39.976704865694046, 39.57587957382202, 45.30941851437092, 49.74739417433739, 51.00695438683033, 53.50468955934048, 50.12492671608925, 50.695507898926735, 50.36977797746658, 48.99737522006035, 45.77491253614426, 42.372252121567726, 45.886740535497665, 52.83686779439449, 50.58526061475277, 49.319027960300446, 49.87012378871441, 50.47581508755684, 50.43677218258381, 49.790464863181114, 47.80536778271198, 51.65780246257782, 31.71559665352106, 1.117307839449495, 1.5084082656539977, 5.284941187128425, 4.637552350759506, 12.65538526698947, 4.41257924772799, 6.336112981662154, 1.692235276568681, 0.23580225475598127, 0.1395326541387476, 1.1868766439147294, 42.10531644523144, 41.08648091554642, 25.55295053869486, 36.33893206715584, 3.285626694560051, 0.08333168079843745, 0.09811009716941044, 0.06393743984517641, 0.017984802325372584, 0.06528994461405091, 0.006640424317083671, 0.02879526677133981, 0.01108565651520621, 0.03648105572210625, 0.03818374658294488, 0.03319676281535067, 0.011577867408050224, 0.04179920433671214, 0.0937234700541012, 0.02809034336678451, 0.0628448574570939, 0.021887339498789515, 0.04332718992372975, 0.03926690369553398, 0.051913159477408044, 0.04673187773732934, 0.03936551285733003, 0.11784010799601674, 0.12355158745776862, 0.18206017994089052, 0.13768507749773562, 0.15898664540145546, 0.14959959051338956, 0.10644434878486209, 0.18307643244042993, 0.1048557148897089, 0.15249438205501065, 0.1680811753612943, 0.12130345887271687, 0.12117359787225723, 0.14553364540915936, 0.3053899691440165, 0.1429131961776875, 0.10528201193665154, 0.17755279055563733, 0.279221159289591, 0.13421574491076171, 0.17337530065560713, 0.181923164636828, 0.21081562677863985, 0.1065728219691664, 0.16462922387290746, 0.1559145250939764, 0.22910735540790483, 0.27113560878206044, 0.25224720826372504, 20.166376680135727, 59.04731534421444, 35.135023668408394, 53.937330543994904, 43.06697264313698, 3.1448264373466372, 1.0005899774841964, 2.4305927753448486, 4.0007801447063684, 16.739617958664894, 11.039213240146637, 10.457678195089102, 5.596998492255807, 0.37761788873467594, 3.1163590773940086, 32.20606483519077, 53.66162873804569, 61.035923436284065, 63.60273130238056, 64.53576743602753, 57.26548835635185, 53.96625459194183, 51.469366773962975, 56.55084930360317, 61.7936597764492, 59.98006269335747, 63.529125452041626, 61.90022125840187, 58.64088915288448, 55.59532977640629, 50.5563859641552, 46.17465868592262, 47.783743143081665, 53.617862686514854, 58.1125845015049, 61.45265847444534, 61.49285651743412, 58.80223989486694, 58.33949692547321, 50.25688223540783, 44.686540737748146, 45.72000168263912, 43.31337422132492, 44.45840857923031, 43.28244008123875, 44.053878486156464, 44.42557834088802, 45.08848316967487, 44.01871517300606, 42.01562225818634, 42.694265842437744, 47.36497141420841, 50.661609917879105, 50.51844500005245, 55.43821960687637, 54.11529019474983, 53.78502331674099, 54.452503100037575, 56.09330825507641, 58.100580945611, 56.827083081007004, 46.40524171292782, 55.330104008316994, 48.97339090704918, 56.031968146562576, 53.92775885760784, 50.08677676320076, 42.55900450050831, 50.569958835840225, 56.74032613635063, 54.09837730228901, 54.01575833559036, 46.32248595356941, 42.14461773633957, 40.88273964822292, 40.849297642707825, 40.24427890777588, 41.84927098453045, 44.35714781284332, 40.28015658259392, 41.95181228220463, 47.72756315767765, 48.63206282258034, 45.18468260765076, 42.40643508732319, 41.94023050367832, 41.56465105712414, 42.22261235117912, 47.64859579503536, 50.89508458971977, 53.136546313762665, 54.870784655213356, 51.782249584794044, 52.32014112174511, 50.77681973576546, 51.173985823988914, 47.725860849022865, 44.589896723628044, 48.62838841974735, 55.46915754675865, 54.25634242594242, 52.59487397968769, 51.213834285736084, 53.32848161458969, 51.59431926906109, 51.74923315644264, 49.564954563975334, 52.10231401026249, 30.21914955228567, 1.2749276566319168, 2.5659063644707203, 6.858083372935653, 5.537043884396553, 21.930760703980923, 5.893742619082332, 17.327419817447662, 5.103602092713118, 1.2469251779839396, 0.5207061872351915, 2.145992321893573, 49.420060738921165, 44.58996891975403, 35.06678692996502, 42.75234192609787, 4.405984226614237, 0.2851332857972011, 0.23167273728176951, 0.10705644992412999, 0.1872241622186266, 0.20195892546325922, 0.11081756529165432, 0.15417096787132323, 0.25851372512988746, 0.1413856039289385, 0.11498480613227002, 0.09857537923380733, 0.08348037750693038, 0.12823277298593894, 0.2221517395810224, 0.1914801268139854, 0.22438906249590218, 0.13954255438875407, 0.17711778811644763, 0.14185248903231695, 0.14212110196240246, 0.1104723330354318, 0.14747669192729518], [0.04172233268036507, 0.04425443294167053, 0.021116142306709662, 0.044429409099393524, 0.03026808666618308, 0.021082053608552087, 0.02185989673307631, 0.0371838658611523, 0.06818826135713607, 0.05448253781651147, 0.03132956007902976, 0.039661039772909135, 0.04936121418722905, 0.021715695584134664, 0.015039580921438755, 0.041863901060423814, 0.024718048443901353, 0.04237629837007262, 0.05400724046921823, 0.009810239553189604, 0.050975741614820436, 0.042043200228363276, 0.033657339663477615, 0.05197384860366583, 0.034533237194409594, 0.060227799840504304, 0.04576442515826784, 0.077813404641347, 0.06468863430200145, 0.8715967554599047, 31.989039480686188, 32.20430172979832, 34.62108984589577, 50.98808079957962, 10.844079460948706, 0.19470487721264362, 0.3039315895875916, 0.5153335130307823, 3.588681095279753, 3.017122414894402, 4.859241480007768, 13.324116133153439, 0.3293165727518499, 0.2178798633394763, 2.9951885668560863, 32.76935800909996, 60.346967205405235, 58.57848510146141, 55.78350327908993, 57.15131588280201, 52.21362143754959, 54.569529220461845, 53.39853845536709, 56.95194058120251, 57.08293855190277, 58.16241502761841, 57.163976803421974, 55.61655543744564, 45.7888425886631, 43.572185933589935, 42.85267934203148, 48.948741629719734, 54.00560148060322, 56.065144166350365, 56.74810811877251, 55.739630833268166, 57.513664439320564, 54.832110330462456, 44.157939702272415, 39.40737001597881, 41.14109918475151, 41.09655037522316, 40.43744154274464, 39.54188659787178, 39.79798525571823, 39.64299917221069, 39.99701477587223, 40.32023303210735, 40.05551263689995, 40.569944232702255, 40.877150148153305, 39.76471044123173, 41.38494350016117, 42.00953498482704, 42.13301695883274, 44.923138841986656, 48.672963827848434, 53.469974622130394, 51.473911330103874, 50.751254707574844, 48.81836302578449, 47.64561675488949, 52.49917231500149, 51.315893009305, 51.12573221325874, 51.85917645692825, 53.77650037407875, 53.714343309402466, 54.03994023799896, 51.9993357360363, 46.73708550632, 38.31315413117409, 37.796780839562416, 36.10861502587795, 37.70197972655296, 36.46462932229042, 38.12397748231888, 37.52276234328747, 39.94660288095474, 47.62317135930061, 50.95043621957302, 50.46315036714077, 45.734205320477486, 40.56621663272381, 36.784925535321236, 37.635468095541, 38.745958507061005, 41.8716099858284, 49.01446670293808, 50.167036056518555, 48.034598082304, 49.86063189804554, 49.71228405833244, 49.358713030815125, 48.84879179298878, 45.830359160900116, 42.395738661289215, 46.646939143538475, 51.00994102656841, 47.76726342737675, 48.408273831009865, 50.94274543225765, 51.08450822532177, 48.09024229645729, 49.05113473534584, 48.72775308787823, 36.42343573272228, 2.340064770542085, 0.08710997688467614, 2.680858508683741, 2.176220412366092, 4.825525414198637, 24.612155221402645, 2.508499282412231, 5.360261695459485, 0.7852095190901309, 0.3110953333089128, 0.03927836245566141, 5.8869994059205055, 47.5340661406517, 19.700297489762306, 28.84722176939249, 19.418200626969337, 0.05667167679348495, 0.09852523231529631, 0.042213682681904174, 0.051096670867991634, 0.0852879746526014, 0.05140085122548044, 0.04206185411021579, 0.016452848103654105, 0.035611707644420676, 0.0440658754814649, 0.004160097205385682, 0.021740268093708437, 0.07374731110758148, 0.03462147855316289, 0.06704815925331786, 0.03551752168277744, 0.0748412887332961, 0.02098216053127544, 0.05194665260205511, 0.04598131781676784, 0.04381887018098496, 0.03270265202445444, 0.054268591484287754, 0.02412359186564572, 0.03996857463789638, 0.01993972506170394, 0.03445445450779516, 0.02400268116616644, 0.04810401973372791, 0.016381698405893985, 0.04742258715850767, 0.020506735163507983, 0.05605836966424249, 0.03802658568019979, 0.048975241734297015, 0.01049100048476248, 0.067344432027312, 0.009510672571195755, 0.028077522765670437, 0.0066418153801350854, 0.02346291901631048, 0.04552789527224377, 0.026090873216162436, 0.04034069861518219, 0.03849334090773482, 0.041588311942177825, 0.010041922287200578, 0.03894231056619901, 0.03361376075190492, 0.020805787280551158, 0.0891558182775043, 0.12896037456812337, 1.9150487892329693, 40.73592312633991, 35.7135084271431, 38.39481174945831, 60.11838287115097, 10.481933243572712, 0.07631313827005215, 0.3420196770457551, 0.7646256079897285, 0.3713039041031152, 4.742420548573136, 8.990233987569809, 7.827077452093363, 2.245815577916801, 1.1141176731325686, 4.84532805159688, 36.835029646754265, 60.24314917623997, 59.42655399441719, 57.507482171058655, 58.265039920806885, 53.858689963817596, 55.108059123158455, 54.75799150764942, 59.34965752065182, 58.86212848126888, 59.795316606760025, 57.9672347009182, 57.29975111782551, 48.8784795999527, 45.68239510059357, 43.82303707301617, 50.45924037694931, 54.85420994460583, 57.482958287000656, 57.918688505887985, 58.29687461256981, 58.89045216143131, 56.95934638381004, 48.2555790245533, 41.60105690360069, 43.737283274531364, 42.73862086236477, 41.55464619398117, 41.17863357067108, 42.74247765541077, 41.345448419451714, 40.93762770295143, 42.371332570910454, 41.03033132851124, 43.17015990614891, 41.3531544059515, 43.15241485834122, 42.69729807972908, 45.87175793945789, 45.20549029111862, 46.145358458161354, 52.41713471710682, 56.71231023967266, 52.44800046086311, 51.60356417298317, 49.531976133584976, 48.20506453514099, 53.1848569214344, 52.3070128262043, 52.30341821908951, 51.10036477446556, 55.60795649886131, 53.7605944275856, 54.31580163538456, 53.31398919224739, 49.619861617684364, 40.88852293789387, 39.78875935077667, 38.620082661509514, 38.932916074991226, 38.5697353631258, 40.80943398177624, 41.543220207095146, 41.413700357079506, 48.68800342082977, 52.491169944405556, 50.466156005859375, 48.29208366572857, 42.03327991068363, 39.051553308963776, 40.215085074305534, 40.374756306409836, 43.51760186254978, 50.61451904475689, 50.85355281829834, 50.51623351871967, 49.08345200121403, 49.02052357792854, 49.27280344069004, 49.72515396773815, 46.5411414206028, 43.209445998072624, 47.78570383787155, 51.47953502833843, 48.30517016351223, 50.62362715601921, 51.421842724084854, 52.694804817438126, 50.01972936093807, 51.42469257116318, 49.09507177770138, 39.33278761804104, 4.288553902879357, 0.5358937347773463, 3.2593541918322444, 4.321884764358401, 4.721994269639254, 18.447033539414406, 4.326476817950606, 2.3429587902501225, 0.6798443791922182, 0.17737360642058775, 0.033001088158925995, 5.945611260831356, 58.545088693499565, 24.765456095337868, 31.52711346745491, 25.58989405632019, 0.1978450673050247, 0.04523609393800143, 0.04280548979295418, 0.032331155161955394, 0.01673652106546797, 0.07856507407268509, 0.02246572115836898, 0.06475308982771821, 0.020208067107887473, 0.0227370540596894, 0.01457206499253516, 0.07962449730257504, 0.03622622818511445, 0.05114805717312265, 0.05551534763071686, 0.031078430292836856, 0.03483372907794546, 0.022242481281864457, 0.06742980869603343, 0.036156748319626786, 0.02995542727148859, 0.06884351096232422, 0.01984206770430319, 0.13566459529101849, 0.15440809889696538, 0.08339520121808164, 0.13471458689309657, 0.07203197776107118, 0.13011597271542996, 0.08984047177364118, 0.1442290240083821, 0.15997292997781187, 0.12294052532524802, 0.1519254664890468, 0.11081424789153971, 0.14519930788083002, 0.17950311012100428, 0.07955567052704282, 0.10516798836761154, 0.10207544415607117, 0.11823245178675279, 0.09086044243304059, 0.11497745887027122, 0.31816889124456793, 0.11664004778140225, 0.1165016446611844, 0.19945448875660077, 0.09936249363818206, 0.15004122775280848, 0.1415324749541469, 0.1986744173336774, 0.27081823674961925, 2.418872066773474, 47.26901516318321, 45.06202518939972, 44.63466212153435, 64.57622766494751, 16.08033623546362, 0.1792224743985571, 1.3348255050368607, 1.2649003509432077, 10.1629470102489, 14.28619695827365, 14.26046758890152, 21.602608412504196, 1.9325815234333277, 0.700727702351287, 5.133324097841978, 37.088202461600304, 61.47760413587093, 62.28545978665352, 61.229800432920456, 62.04665020108223, 56.06351025402546, 59.69204194843769, 56.91285587847233, 62.30560250580311, 61.06123387813568, 61.482072696089745, 60.740835070610046, 61.13054595887661, 49.21275146305561, 47.74793766438961, 46.498545706272125, 53.815246894955635, 59.86583702266216, 60.0184216350317, 60.873611345887184, 58.06277297437191, 61.22176006436348, 58.62847901880741, 48.49905475974083, 42.827114313840866, 46.49510309100151, 45.30559591948986, 44.480170011520386, 42.837111577391624, 44.83558014035225, 42.17164948582649, 44.79170769453049, 44.63960185647011, 44.19756017625332, 44.011628553271294, 43.807180523872375, 44.07786279916763, 45.09587377309799, 47.82212868332863, 46.062131524086, 47.644868195056915, 54.83003944158554, 58.83331082761288, 54.23026442527771, 53.87159787118435, 52.29890786111355, 51.852618008852005, 53.80829706788063, 53.376959413290024, 54.079773500561714, 53.818085342645645, 54.6236839145422, 54.41957026720047, 58.34697872400284, 55.72347790002823, 52.432033717632294, 41.88300937414169, 41.268187165260315, 39.32996816933155, 41.31634958088398, 40.7332556694746, 43.57742965221405, 41.96658968925476, 43.20860244333744, 52.926831766963005, 56.244923919439316, 53.05591084063053, 50.0675155967474, 44.92961369454861, 40.81135667860508, 41.8354245275259, 42.41454005241394, 45.76147645711899, 53.538937121629715, 53.241549879312515, 51.74368925392628, 50.964700654149055, 49.702689573168755, 50.2347332239151, 52.714905738830566, 48.88037949800491, 47.13084697723389, 50.37696719169617, 53.585560619831085, 50.07967494428158, 51.450010612607, 54.71880801022053, 54.469336196780205, 51.18849344551563, 51.09320215880871, 49.06255692243576, 38.52799080312252, 3.177874214015901, 0.35410478012636304, 6.345039652660489, 8.219889923930168, 12.160629015415907, 40.42567737400532, 7.524162456393242, 12.864269558340311, 3.814109223894775, 0.732147207017988, 0.12152936120401137, 10.178707614541054, 61.29527851939201, 26.8643456697464, 39.716240242123604, 30.7206941395998, 0.31814582529477775, 0.2345696068368852, 0.17164259363198653, 0.18728326685959473, 0.15043958293972537, 0.16117540217237547, 0.19278249208582565, 0.1462413722765632, 0.09373207154567353, 0.11217839695746079, 0.1344190488453023, 0.16239598277024925, 0.2635630307486281, 0.17738730646669865, 0.22173451900016516, 0.15667954576201737, 0.19487785699311644, 0.08804534270893782, 0.2435589744709432, 0.12041151610901579, 0.07958977221278474, 0.13209018943598494, 0.09352896799100563], [0.027137221659359057, 0.02168304108636221, 0.021908371963945683, 0.007852694252505898, 0.05299298805766739, 0.018207791727036238, 0.03615210618590936, 0.02913833381171571, 0.05181001950404607, 0.02112152287736535, 0.05540871585253626, 0.011656057304207934, 0.027091831907455344, 0.05891437656828202, 0.07338840849115513, 0.01988732758036349, 0.03853443362459075, 0.06260091351578012, 0.015162048275669804, 0.051403062825556844, 0.006009510198055068, 0.0068390504020499066, 0.07202713895821944, 0.040532566054025665, 0.04412201524246484, 0.06104936845076736, 0.02421263103315141, 0.02633434589370154, 0.08937033606343903, 0.12865420896559954, 13.600403107702732, 42.97750644385815, 26.32560297846794, 45.26638962328434, 31.76387496292591, 0.6282471853774041, 0.2875829965341836, 0.8200045488774776, 0.2850739733548835, 3.739143996499479, 4.8101424146443605, 14.74232543259859, 3.3197168027982116, 0.3310421551577747, 0.1336079853354022, 4.407725483179092, 43.67630034685135, 62.1587897837162, 59.726114720106125, 57.16490015387535, 57.59235821664333, 58.89373518526554, 57.173632085323334, 60.47017939388752, 60.084017515182495, 59.11282002925873, 55.97605034708977, 51.19561046361923, 45.325871631503105, 43.59748877584934, 48.35168346762657, 55.77815316617489, 56.738509833812714, 60.287488996982574, 55.86007297039032, 56.81022718548775, 57.11022108793259, 52.80897729098797, 47.03802935779095, 42.116788029670715, 41.96263410151005, 41.57627083361149, 39.592252895236015, 39.39463309943676, 39.788348972797394, 40.7193636149168, 39.3124321103096, 39.795184805989265, 40.363239124417305, 38.79998780786991, 39.95310053229332, 42.590482011437416, 41.66077069938183, 42.82860763370991, 45.26355877518654, 44.1351143270731, 49.72100839018822, 51.351029723882675, 55.99517472088337, 51.6864263266325, 51.41010895371437, 59.52199727296829, 56.52810372412205, 53.6877903342247, 52.5200179964304, 56.59836955368519, 50.81309638917446, 54.408976435661316, 52.45795212686062, 50.03294125199318, 40.469109043478966, 38.4587699174881, 38.451778292655945, 38.00447389483452, 37.91079372167587, 37.54277586936951, 38.89951966702938, 39.986527338624, 49.14541147649288, 51.62852883338928, 52.024421989917755, 51.52525037527084, 48.48056495189667, 43.36796209216118, 39.725458547472954, 37.97225922346115, 39.55344557762146, 43.55796329677105, 48.11374023556709, 49.70142424106598, 50.850049406290054, 49.702457785606384, 49.353286921978, 49.01545085012913, 51.805534735322, 46.685252487659454, 42.737005949020386, 45.68212531507015, 51.18645675480366, 50.841089487075806, 51.38253003358841, 51.222083643078804, 50.14489844441414, 50.75873650610447, 49.71377357840538, 40.68204581737518, 10.65736223012209, 0.24942799704149365, 1.23082508565858, 1.268269345164299, 4.501579497009516, 3.755710395053029, 36.35079503059387, 5.2093941159546375, 2.062679179944098, 0.42030788550619036, 0.2938419138081372, 0.07162827168940566, 22.63749238103628, 37.26995050907135, 15.110803060233593, 38.36662106215954, 5.492599094286561, 0.13032122107688338, 0.00968712931353366, 0.09233687844243832, 0.0739422213518992, 0.03289509462774731, 0.05170144700969104, 0.058733945625135675, 0.04007945521152578, 0.07518541518948041, 0.023102194427337963, 0.035611407074611634, 0.03984119983215351, 0.012259630238986574, 0.008265850647148909, 0.0058949494996340945, 0.020539768156595528, 0.06149951441329904, 0.04326742477132939, 0.044715718540828675, 0.01942480816069292, 0.07565471227280796, 0.037337130488594994, 0.04864691189141013, 0.024467454859404825, 0.03402779380849097, 0.040688339140615426, 0.03154471982270479, 0.03530831396346912, 0.010484318372618873, 0.03269119326432701, 0.057320833366247825, 0.026623302946973126, 0.010099933188030263, 0.03332828993734438, 0.021093332397867925, 0.08990103102405556, 0.013154514690540964, 0.010475863455212675, 0.04487855687330011, 0.04233504609146621, 0.02196198471210664, 0.045021524201729335, 0.024874005212041084, 0.037802323495270684, 0.04520549518929329, 0.058940934322890826, 0.0426590380811831, 0.041843143189908005, 0.04306939379603136, 0.03223639774660114, 0.022180567611940205, 0.08008091812371276, 0.13648125459440053, 18.537219800055027, 48.0202766507864, 29.38694480806589, 57.67780423164368, 34.165832474827766, 0.44154904258903116, 0.023578794243803713, 0.4029962222557515, 0.18884440418332815, 1.0371697833761573, 7.761085918173194, 13.222217001020908, 7.054472034797072, 2.78672581538558, 0.4550307191675529, 7.207040973007679, 46.93505868315697, 62.75826461613178, 59.1003604978323, 58.29133830964565, 57.91091792285442, 59.58226963877678, 57.679525539278984, 62.19433307647705, 61.855094879865646, 61.261999905109406, 58.460030257701874, 54.46008749306202, 47.54274867475033, 45.426775217056274, 49.18255068361759, 56.51213318109512, 58.18171039223671, 59.96767155826092, 57.340310141444206, 57.60218068957329, 58.219822347164154, 53.17677855491638, 48.348278850317, 42.67242081463337, 43.24282340705395, 42.67374314367771, 42.93157450854778, 40.60580290853977, 40.63319943845272, 43.797240257263184, 41.990441009402275, 40.766169503331184, 40.37621922791004, 39.94677387177944, 41.25851288437843, 43.20391349494457, 43.80330853164196, 45.29780633747578, 46.42748571932316, 45.323831140995026, 50.62341436743736, 53.97969827055931, 56.7984402179718, 53.309953808784485, 52.641733065247536, 61.30640052258968, 58.45288664102554, 55.458776503801346, 53.67408446967602, 58.78840483725071, 53.92284572124481, 54.54463675618172, 54.03632663190365, 52.17515230178833, 42.374600395560265, 39.732902348041534, 38.85076828300953, 38.423420414328575, 39.740216955542564, 38.25173042714596, 39.37389761209488, 39.26893964409828, 49.350661262869835, 53.31019699573517, 54.67451758682728, 52.46615208685398, 50.13021983206272, 45.69385528564453, 40.892121344804764, 38.89968305826187, 41.32503591477871, 45.345603972673416, 49.56016682088375, 52.43522934615612, 51.47812530398369, 49.90785576403141, 51.34032569825649, 51.2604121863842, 51.64322264492512, 48.6474671959877, 43.24888788163662, 47.64549136161804, 54.07653607428074, 51.09670177102089, 51.31540283560753, 53.684165328741074, 51.738593727350235, 49.8358154296875, 49.35470424592495, 42.09057703614235, 13.172401674091816, 0.5444906547199935, 2.9496392235159874, 3.397186095826328, 7.4237685184925795, 7.258280273526907, 48.00687097012997, 9.626777730882168, 1.573958785738796, 0.38213872583583, 0.28466792951803654, 0.02475510202202713, 23.41609340161085, 51.00198805332184, 16.731110215187073, 40.5631235986948, 8.964914996176958, 0.14467472821706906, 0.09536825484246947, 0.022338565286190715, 0.03825098887318745, 0.06229157152120024, 0.07567694701720029, 0.03998349551693536, 0.04517036191828083, 0.042612386678229086, 0.07164930415456183, 0.02698666216019774, 0.08769838867010549, 0.06981775048188865, 0.014321270100481343, 0.03823903658485506, 0.015435822842846392, 0.02658762790815672, 0.04310796321078669, 0.03237118660763372, 0.06394509880919941, 0.06175141046696808, 0.025139323006442282, 0.046693356562172994, 0.1506577743566595, 0.08948361748480238, 0.2088269975502044, 0.1459026412339881, 0.1514192030299455, 0.13392445194767788, 0.2825883129844442, 0.13775543309748173, 0.22238805424422026, 0.1344912449712865, 0.18625353695824742, 0.11554628537851386, 0.15168009762419388, 0.12595979729667306, 0.12163020423031412, 0.19755481334868819, 0.2228297063265927, 0.17733556393068284, 0.13576667028246447, 0.15020153165096417, 0.1712024852167815, 0.1316853627213277, 0.177446500165388, 0.16828085761517286, 0.10322673784685321, 0.15349901252193376, 0.13012817362323403, 0.11723293471732177, 0.23424644605256617, 0.22001272154739127, 22.32834666967392, 58.32045994699001, 36.34456716477871, 57.14448764920235, 43.56960967183113, 1.1461669346317649, 0.5609498277772218, 1.8307544686831534, 1.2735927407629788, 11.844714917242527, 12.152597196400166, 27.189897000789642, 7.254382632672787, 1.0963291651569307, 0.1970834456733428, 6.475880881771445, 45.551845505833626, 65.88365390896797, 62.55491852760315, 62.88045085966587, 61.5797084569931, 63.872467428445816, 60.62122128903866, 65.74783399701118, 65.27642369270325, 63.310637176036835, 61.047072038054466, 54.89201411604881, 49.979668110609055, 47.635459899902344, 53.163661658763885, 60.749434009194374, 60.44921211898327, 63.90048712491989, 58.14922973513603, 58.35760675370693, 61.670572981238365, 56.19882479310036, 50.72228126227856, 45.277979001402855, 46.25692427158356, 45.392869636416435, 45.38357153534889, 42.91070982813835, 43.22243370115757, 47.281664684414864, 43.63687366247177, 44.44318279623985, 43.70110921561718, 42.79333412647247, 44.342169016599655, 47.4965013563633, 46.00449241697788, 48.80126014351845, 49.6848077327013, 48.8524129986763, 53.39009910821915, 55.71307025849819, 60.00565432012081, 55.842867493629456, 54.09893587231636, 62.818696573376656, 58.538306057453156, 57.26449280977249, 57.145129814743996, 60.02701677381992, 54.53471548855305, 57.68006511032581, 54.216307774186134, 52.32585221529007, 44.33259733021259, 42.68679924309254, 41.75491824746132, 40.40690258145332, 42.00711831450462, 40.04994213581085, 42.40293927490711, 43.37328560650349, 52.894392907619476, 55.49571432173252, 56.11467070877552, 53.681387677788734, 53.647808879613876, 48.74907374382019, 42.33550049364567, 42.278815135359764, 43.10439683496952, 47.22325421869755, 50.0628000497818, 56.02073214948177, 53.231472820043564, 50.66920191049576, 52.8318140655756, 50.43565884232521, 54.7782976180315, 50.33381290733814, 44.51649986207485, 51.84766307473183, 54.84142363071442, 54.13414478302002, 53.592901825904846, 54.872566759586334, 51.914547085762024, 50.64355328679085, 49.166439548134804, 42.84389801323414, 11.71764213591814, 0.5544423207174987, 3.22982597630471, 4.048876063898206, 10.840923730283976, 8.483395334333181, 54.636595621705055, 10.211627148091793, 3.4231883380562067, 0.9884196461644024, 0.7682022848166525, 0.23177322407718748, 30.559358596801758, 48.017966374754906, 21.68863009661436, 51.45762540400028, 11.003270018845797, 0.19276390870800242, 0.15061927173519507, 0.1673134829616174, 0.09283046601922251, 0.12283224597922526, 0.1274852521601133, 0.17867721850052476, 0.1336758176330477, 0.22212692216271535, 0.16475719981826842, 0.18875273410230875, 0.19441220385488123, 0.12739873258396983, 0.10451598936924711, 0.16320433001965284, 0.13929668086348101, 0.10698976795538329, 0.15907032997347414, 0.07479852618416771, 0.09030650340719149, 0.21435466187540442, 0.1126814766030293, 0.09777221959666349], [0.018400007975287735, 0.04411169938975945, 0.041013065856532194, 0.00872502576385159, 0.0077643378608627245, 0.043712175320251845, 0.05263994840788655, 0.011267059671808966, 0.020692344442068134, 0.03621409407060128, 0.026032686982944142, 0.05519157828530297, 0.02710635759285651, 0.046981202249298804, 0.06637894985033199, 0.055862676454125904, 0.04165845602983609, 0.05210603994783014, 0.0421334490965819, 0.04564718437904958, 0.056915646709967405, 0.07417459521093406, 0.07988740311702713, 0.06051085496437736, 0.0702933335560374, 0.02686511135834735, 0.05837557364429813, 0.08795330897555687, 0.05682972456270363, 0.03373398867552169, 1.964022342581302, 36.52197204530239, 35.27200251817703, 29.37663786113262, 51.34759470820427, 9.223115891218185, 0.12450105408788659, 0.24132003367412835, 0.09396196663146839, 1.9257699139416218, 8.463870082050562, 4.0746348816901445, 8.183799460530281, 9.40136432647705, 1.0423481930047274, 0.15960700664436445, 9.281438011676073, 55.137480944395065, 56.214111372828484, 61.69640399515629, 56.583257764577866, 61.241503804922104, 56.0911575704813, 60.88143892586231, 58.36467057466507, 59.38757188618183, 53.154990524053574, 47.172538340091705, 42.574693858623505, 49.61253181099892, 55.349330976605415, 56.07226498425007, 55.95011293888092, 52.16079667210579, 55.40689028799534, 56.129801496863365, 53.9946960657835, 52.33332261443138, 45.436046719551086, 43.74152384698391, 42.614979296922684, 41.54143430292606, 41.19469530880451, 39.42239820957184, 41.22378654778004, 40.845429450273514, 40.725952461361885, 40.56664980947971, 41.155603006482124, 39.948088601231575, 41.54028296470642, 40.16900114715099, 43.53556349873543, 44.849734380841255, 44.96909737586975, 45.58687962591648, 50.093924179673195, 52.52453215420246, 54.8429511487484, 52.459483444690704, 55.0947218388319, 56.586198806762695, 54.265203550457954, 50.74048608541489, 51.65521860122681, 51.837114840745926, 55.57063490152359, 53.890133276581764, 52.17742457985878, 45.837217792868614, 38.63400511443615, 36.82693988084793, 37.75353915989399, 37.29349784553051, 39.16120022535324, 39.13326032459736, 38.57276380062103, 47.20873899757862, 52.572360187768936, 50.731712356209755, 52.611908465623856, 51.93988412618637, 48.12587298452854, 46.66189134120941, 40.11432588100433, 38.001890033483505, 38.94509442150593, 45.450759530067444, 50.13245411217213, 52.972056940197945, 49.22549977898598, 49.11147549748421, 50.68361833691597, 52.44293533265591, 51.6775956004858, 48.469199761748314, 44.01313327252865, 42.71864153444767, 47.09113150835037, 47.87395030260086, 47.57294185459614, 48.9876439422369, 52.53140598535538, 48.78201797604561, 48.535031229257584, 21.572816111147404, 1.9101899187080562, 0.815909318625927, 1.6940945643000305, 3.49668494425714, 4.965174570679665, 3.4746451769024134, 5.60629041865468, 3.134041428565979, 0.6331283797044307, 0.09633612673496827, 0.1796761789591983, 1.401220173574984, 35.76361633837223, 26.603037491440773, 28.09136062860489, 31.16865400224924, 1.0991937364451587, 0.10898211534367874, 0.019801806192845106, 0.06120674457633868, 0.05698106331692543, 0.03911841107765213, 0.0465730247378815, 0.04679781384766102, 0.06377384081133641, 0.05011728826502804, 0.01291307828068966, 0.049100913311121985, 0.03485686924250331, 0.04914212848234456, 0.016965217582765035, 0.01795968990336405, 0.042738514675875194, 0.06820746071753092, 0.0410567078506574, 0.04338075814303011, 0.0605204286694061, 0.010155599829886341, 0.018318204747629352, 0.03362770199601073, 0.07086927726049908, 0.059627951559377834, 0.05038401242927648, 0.05463209541630931, 0.01288883046072442, 0.012791469034709735, 0.050347910655546, 0.046442659077001736, 0.027645494483294897, 0.009784386838873615, 0.026676067791413516, 0.028548565751407295, 0.014756473847228335, 0.004680451729655033, 0.07175801394623704, 0.01953234721440822, 0.036027380847372115, 0.04600246531481389, 0.03638878450146876, 0.09123643671046011, 0.02958368364488706, 0.026286410575266927, 0.03246032967581414, 0.0605174192605773, 0.04987899948901031, 0.018489292051526718, 0.05476173377246596, 0.12336925661657006, 0.06172180248540826, 0.042029199612443335, 3.2585956575348973, 46.04302614927292, 35.17093554139137, 35.46160474419594, 60.971554890275, 8.10093255713582, 0.028457617409003433, 0.1375924129388295, 0.18341856251936406, 0.8605751499999315, 3.0731487460434437, 12.04151775687933, 13.37078332901001, 5.3657125029712915, 3.298785863444209, 0.17741771967848763, 13.663517720997334, 57.0749855786562, 56.79877460002899, 63.37902970612049, 58.42134453356266, 62.073134779930115, 60.43092370033264, 63.45532201230526, 60.0376296043396, 60.108928978443146, 55.253306329250336, 49.58725556731224, 44.262316301465034, 50.34716919064522, 59.546798542141914, 58.10029976069927, 59.552338644862175, 56.05751797556877, 54.83296528458595, 59.145676866173744, 55.66483564674854, 55.03068007528782, 46.79079942405224, 44.766632840037346, 43.78231465816498, 43.2177409529686, 41.90540537238121, 41.302917301654816, 41.8311383575201, 42.84710504114628, 40.611457005143166, 43.20760689675808, 43.567117005586624, 40.535377487540245, 43.61973658204079, 41.52417942881584, 45.57574242353439, 46.54682971537113, 47.461600229144096, 46.54557578265667, 51.590827256441116, 53.468956276774406, 56.21114753186703, 54.995030388236046, 54.431193843483925, 58.92694540321827, 54.51639287173748, 54.203874841332436, 53.75951908528805, 53.25636148452759, 58.70844952762127, 55.24836279451847, 53.59874211251736, 48.15963037312031, 40.56853070855141, 38.830579966306686, 39.71481531858444, 39.822512939572334, 39.62246887385845, 41.61763921380043, 40.07016845047474, 48.42008739709854, 55.71769081056118, 53.27100969851017, 53.62311780452728, 53.622494637966156, 50.83798885345459, 46.62127152085304, 43.80446746945381, 39.3879796564579, 40.50338700413704, 48.172827064991, 50.96437007188797, 53.52156825363636, 49.20145086944103, 49.42974641919136, 50.426649525761604, 51.667446345090866, 53.309281244874, 50.840933695435524, 47.48210772871971, 45.220902264118195, 48.13368156552315, 50.55864304304123, 50.80039367079735, 50.08018031716347, 52.20009036362171, 50.04190497100353, 48.949729576706886, 24.108034372329712, 3.4446890093386173, 1.5569250122644007, 3.5346738807857037, 2.8340142779052258, 5.987495938315988, 6.736931148916483, 14.347419273108244, 1.7344702477566898, 0.0386272206378635, 0.13545725407311693, 0.33543780678883195, 1.0535762342624366, 44.324762150645256, 29.310734197497368, 24.094119518995285, 37.50849790871143, 1.8654752243310213, 0.07101787006831728, 0.031310078702517785, 0.05857001633557957, 0.016597077083133627, 0.01661601669184165, 0.06697822667774744, 0.030352450303325895, 0.0180126625491539, 0.06573603473952971, 0.025804129618336447, 0.022143742244224995, 0.008751363657211186, 0.06567174990777858, 0.00552149197574181, 0.012700259085249854, 0.02490003975253785, 0.03382943257747684, 0.015010772604000522, 0.01807210672268411, 0.06652838870650157, 0.012600006066350034, 0.012188525997771649, 0.008057411050685914, 0.14386209135409445, 0.18815849645761773, 0.19555429491447285, 0.1424627867527306, 0.20691777812317014, 0.12784479302354157, 0.12612045742571354, 0.10844202479347587, 0.10637846091412939, 0.056500203572795726, 0.1575934560969472, 0.1281434332486242, 0.08655697296489961, 0.06252030885661952, 0.10900560431764461, 0.15989717154297978, 0.1533424193621613, 0.14383261324837804, 0.11564173299120739, 0.16504598432220519, 0.2251293251174502, 0.1721905212616548, 0.18449402356054634, 0.2599354722769931, 0.27736264339182526, 0.09082713484531268, 0.13063154270639643, 0.2725061180535704, 0.17774172651115805, 0.1276735053397715, 3.753057662397623, 52.55748778581619, 45.55603288114071, 38.35597023367882, 66.17610141634941, 14.600857123732567, 0.1929378235945478, 1.0646239039488137, 0.24897690484067425, 5.097036045044661, 17.56986390799284, 9.434663839638233, 12.753188218921423, 17.898861654102802, 2.3266115924343467, 0.3195362538099289, 12.481748834252357, 57.65893444418907, 58.54242503643036, 66.17254480719566, 59.97272148728371, 63.7080692499876, 61.50059290230274, 63.48045766353607, 63.00237491726875, 65.13596042990685, 57.14892961084843, 52.36899130046368, 46.00214034318924, 54.31610181927681, 61.42128735780716, 59.328405261039734, 60.861615389585495, 55.99959388375282, 56.88090339303017, 61.1730732768774, 57.10717745125294, 58.85582081973553, 48.351102098822594, 47.13854156434536, 46.32649853825569, 45.589300096035004, 43.61532501876354, 43.37885610759258, 46.165801361203194, 46.852211728692055, 43.054209128022194, 45.431654155254364, 46.19505599141121, 43.221673741936684, 45.44174641370773, 43.220465406775475, 47.918578907847404, 50.16591511666775, 48.823716938495636, 48.75490643084049, 52.6134891808033, 57.127095982432365, 58.27103979885578, 56.4351949095726, 58.635976016521454, 62.103928327560425, 57.67705947160721, 53.7865774333477, 54.33408625423908, 56.227722242474556, 59.6206209808588, 58.20917531847954, 55.31331270933151, 51.4891143143177, 42.70432390272617, 40.05897805094719, 40.93862324953079, 42.05234348773956, 41.012312695384026, 42.97299988567829, 42.874619364738464, 52.00941279530525, 58.572785407304764, 54.67585511505604, 55.0516739487648, 55.37637412548065, 51.18731930851936, 49.90386217832565, 45.8107104152441, 41.30795583128929, 42.01517388224602, 51.798216328024864, 54.043303057551384, 55.35262539982796, 52.129930928349495, 50.66750340163708, 51.58620670437813, 52.646304219961166, 54.405176639556885, 51.759902983903885, 49.62290905416012, 47.23116919398308, 50.95409542322159, 53.86239476501942, 51.49927496910095, 52.2860873490572, 55.69215998053551, 52.95737072825432, 51.85610622167587, 23.029817529022694, 3.0232284497469664, 1.511994085740298, 6.157868346199393, 9.521771315485239, 13.014311157166958, 8.461649101227522, 12.992555424571037, 9.36683177947998, 1.9666930055245757, 0.6653121777344495, 0.5489175952970982, 2.6495120907202363, 48.73025715351105, 35.25535561144352, 35.74473135173321, 42.85418026149273, 2.223459715023637, 0.23569611279526725, 0.1481659393175505, 0.33606889948714525, 0.13707512116525322, 0.08805489414953627, 0.1643995736958459, 0.10255839675664902, 0.1103160144702997, 0.2710088202729821, 0.08955933139077388, 0.12043566559441388, 0.11754922321415506, 0.11584163788938895, 0.1097449244116433, 0.10444535175338387, 0.1949780320865102, 0.13332933856872842, 0.07569201261503622, 0.127268559881486, 0.15423541597556323, 0.07039589836494997, 0.14690813259221613, 0.11468849625089206], [0.03296327202406246, 0.10070379197713919, 0.005350274332158733, 0.018233388400403783, 0.020066606339241844, 0.010889803743339144, 0.021183542303333525, 0.04069660295499489, 0.043354649387765676, 0.011360085100022843, 0.13145017612259835, 0.07433848368236795, 0.01683194270299282, 0.051182188544771634, 0.08962596140918322, 0.010172261972911656, 0.0667333698947914, 0.0744334860064555, 0.050043025257764384, 0.05135907944350038, 0.054900563627597876, 0.023451738561561797, 0.04459429575945251, 0.06410703543224372, 0.0323229655623436, 0.02215581884229323, 0.018505871630623005, 0.030665406557091046, 0.06069688170100562, 0.062451148114632815, 0.11259329461609013, 12.393694259226322, 41.245772168040276, 26.964348703622818, 40.2436937391758, 34.19457793235779, 1.328580896370113, 0.13033291732426733, 0.3301497671054676, 0.06041324028046802, 3.701695343479514, 11.623175404965878, 13.128930106759071, 4.722399897873402, 4.898117668926716, 0.9448969596996903, 0.15179315640125424, 15.761290155351162, 49.99013274908066, 57.65746772289276, 58.67302782833576, 57.56230562925339, 61.421610340476036, 60.47524832189083, 57.290924191474915, 57.8636484593153, 49.282394126057625, 46.63259111344814, 48.30738544464111, 56.35342709720135, 57.74598017334938, 58.415774032473564, 56.463453993201256, 55.78284591436386, 58.60101029276848, 56.866581961512566, 54.66301180422306, 50.71115925908089, 45.8733044564724, 46.326183155179024, 43.68665099143982, 41.60279341042042, 41.131557896733284, 40.82823917269707, 40.26931956410408, 40.11675015091896, 39.4682427495718, 40.07745645940304, 41.41108229756355, 40.384111404418945, 43.87344516813755, 45.2167034894228, 46.703989282250404, 46.75101175904274, 49.09267030656338, 48.45001079142094, 50.164634585380554, 53.56500372290611, 57.259461879730225, 55.64560107886791, 57.82064616680145, 54.52600635588169, 51.82213604450226, 48.8851672410965, 46.48362010717392, 48.28100726008415, 48.1627956032753, 47.082749158144, 42.541198655962944, 39.74423334002495, 39.643515944480896, 37.32207991182804, 38.68132397532463, 38.811455592513084, 39.91075560450554, 38.84409584105015, 49.48863945901394, 51.88477948307991, 53.6421699821949, 52.86505468189716, 51.36350065469742, 52.864404916763306, 50.45749247074127, 45.80627225339413, 42.717444598674774, 36.780696362257004, 39.734395667910576, 46.922450959682465, 50.06173990666866, 51.444345116615295, 50.24864047765732, 50.43478488922119, 49.30757537484169, 51.934879794716835, 51.22386194765568, 51.560151502490044, 45.756886303424835, 43.936829566955566, 44.850395545363426, 45.39718620479107, 47.68255457282066, 48.38517107069492, 49.15004722774029, 50.170501470565796, 35.17612986266613, 8.86597115546465, 0.6295959942508489, 1.889701180625707, 1.8893625237978995, 2.401052685454488, 4.280591430142522, 11.824019327759743, 5.277928188443184, 0.6021291681099683, 0.17151820968138054, 0.08116824610624462, 0.03979868961323518, 13.365816045552492, 44.301522597670555, 19.495891258120537, 36.035727337002754, 12.433247286826372, 0.09884129816782661, 0.03771603027416859, 0.024943238313426264, 0.024385929937125184, 0.01094765972084133, 0.055948988228919916, 0.06286675823503174, 0.04271991645509843, 0.05919652998272795, 0.03582308614568319, 0.09003714832942933, 0.05257563017948996, 0.02056473029369954, 0.011680150200845674, 0.04295919228752609, 0.05767101945821196, 0.001633864201266988, 0.0429366829484934, 0.0013674571891897358, 0.05603309953585267, 0.03488477770588361, 0.028154984429420438, 0.012090967902622651, 0.015908839013718534, 0.0254746401697048, 0.07992036931682378, 0.03589612460928038, 0.007827131903468398, 0.025233291889890097, 0.007022727777439286, 0.056694579470786266, 0.06575828432687558, 0.04725514379970264, 0.020131471901549958, 0.05094718006148469, 0.038800968541181646, 0.027797098555311095, 0.036926518732798286, 0.0771490043553058, 0.0305930453032488, 0.012087628238077741, 0.0656103742949199, 0.05768037422967609, 0.08175524038961157, 0.026289861561963335, 0.027044301059504505, 0.07723513059318066, 0.06855875632027164, 0.12917676998768002, 0.0671001392765902, 0.0030784065302214003, 0.036523087255773135, 0.10721699873101898, 0.060251429822528735, 0.2518413128564134, 21.905398964881897, 47.32822358608246, 26.22379694133997, 54.11689750850201, 36.454616859555244, 1.155344748403877, 0.103026313445298, 0.1612531198770739, 0.04747262646560557, 1.153440100606531, 3.5596029181033373, 6.677272925153375, 3.7234631879255176, 5.13184217736125, 1.9325886480510235, 0.13997636939166114, 20.00068847090006, 54.78982239961624, 60.578564777970314, 61.547930762171745, 58.439758345484734, 62.44032047688961, 62.338425144553185, 58.08121718466282, 60.189902633428574, 53.42454046010971, 48.41019652783871, 48.88135604560375, 58.693523928523064, 59.70372632145882, 61.400141492486, 57.870598286390305, 55.14764539897442, 59.641854241490364, 58.83046098053455, 56.87308341264725, 51.64344683289528, 48.42990227043629, 46.04460306465626, 46.48136302828789, 43.220499604940414, 43.46451871097088, 42.14408956468105, 42.239567041397095, 42.24887274205685, 41.689690947532654, 40.97613103687763, 44.21462506055832, 42.00174160301685, 44.708131179213524, 47.87317514419556, 46.500046625733376, 49.51988898217678, 51.93592093884945, 50.11701174080372, 51.62047706544399, 54.88087311387062, 59.61836390197277, 56.57520219683647, 58.040361776947975, 56.574134454131126, 54.50979262590408, 51.23090296983719, 49.67401251196861, 51.287041157484055, 51.056857109069824, 49.963332787156105, 45.39294943213463, 41.27818822860718, 41.071334928274155, 40.139556527137756, 40.98542533814907, 38.73981423676014, 42.062344551086426, 39.70558941364288, 49.46573808789253, 52.16922082006931, 55.190244913101196, 54.32923011481762, 54.07237529754639, 54.89524394273758, 52.28980354964733, 48.35615582764149, 43.33326995372772, 37.51928173005581, 41.759683191776276, 48.43244433403015, 52.23256342113018, 53.42338152229786, 52.95693375170231, 51.56855285167694, 49.07326854765415, 53.37529890239239, 53.65156687796116, 52.24821478128433, 46.680932119488716, 45.517689138650894, 47.771051824092865, 47.3873408138752, 50.79587571322918, 51.30238473415375, 51.13024637103081, 52.22682572901249, 37.70794540643692, 11.699742246419191, 1.2359771342016757, 2.7631753915920854, 3.3196018589660525, 4.962306674569845, 3.2695875177159905, 8.72815540060401, 3.296410753391683, 0.7459451572503895, 0.10219463307294063, 0.17772145103663206, 0.05896794478758238, 12.784756924957037, 53.26026387512684, 19.017660319805145, 36.485478803515434, 17.820099480450153, 0.11852870971779339, 0.0192774361858028, 0.05291153363941703, 0.011469501787360059, 0.0397522534331074, 0.018827809726644773, 0.05359651368053164, 0.026198299092357047, 0.08101342667941935, 0.0739772581437137, 0.060762561770388857, 0.05206492125580553, 0.016348938152077608, 0.022111276994110085, 0.005956201730441535, 0.023192062944872305, 0.017777359062165488, 0.07751942510367371, 0.05294805101584643, 0.03525732099660672, 0.04281778717995621, 0.10218161580269225, 0.006428470651371754, 0.02888989616621984, 0.11914858114323579, 0.22385726915672421, 0.13254947494715452, 0.08284508425276726, 0.10203984333202243, 0.13377493887674063, 0.1034255295235198, 0.2091779443435371, 0.09195683946018107, 0.09700798560515977, 0.19356961391167715, 0.13684967154404148, 0.21077520941616967, 0.1014226139523089, 0.2337160924798809, 0.10919969077804126, 0.28176809137221426, 0.13320351485162973, 0.1609639049274847, 0.13347392377909273, 0.1398806768702343, 0.08085031746304594, 0.17923779232660308, 0.14854379638563842, 0.29353056801483035, 0.23671776812989265, 0.1317581080365926, 0.1733690666151233, 0.23656448494875804, 0.17617911973502487, 0.2842625981429592, 26.04656495153904, 58.500745072960854, 34.38507691025734, 50.87470628321171, 45.99348060786724, 2.696349802426994, 0.34609858004841954, 0.8693370642140508, 0.09328867541626096, 9.25804266706109, 24.619625620543957, 23.349251188337803, 14.151479937136173, 10.819778814911842, 2.177689508534968, 0.4568321193801239, 19.53544143587351, 53.472315296530724, 61.9561542570591, 64.08069625496864, 60.15907868742943, 64.47475790977478, 64.5461256802082, 60.963541120290756, 62.70520806312561, 55.15794664621353, 49.66358967125416, 52.39011436700821, 60.18386475741863, 63.11745174229145, 62.97604613006115, 58.551031574606895, 57.22287744283676, 61.554120630025864, 61.9820536673069, 59.12756323814392, 54.26458798348904, 50.736059322953224, 50.50058215856552, 48.92347298562527, 45.6268572807312, 46.210281774401665, 45.170608162879944, 44.70449857413769, 44.212915152311325, 43.58045428991318, 43.43944005668163, 45.94410225749016, 42.39295341074467, 46.443296670913696, 49.68820855021477, 50.05452409386635, 51.12794369459152, 54.7862733900547, 52.1221337467432, 53.902448415756226, 57.67742045223713, 62.077276557683945, 59.919193759560585, 61.810546070337296, 59.331262707710266, 56.68183967471123, 53.296491131186485, 51.08331888914108, 52.46380381286144, 51.0322268307209, 53.29548038542271, 47.08699353039265, 43.44529554247856, 43.27883027493954, 41.18143022060394, 41.69043190777302, 41.29110373556614, 43.49305137991905, 41.799524053931236, 54.30046185851097, 54.74495820701122, 56.69757463037968, 56.41591474413872, 55.28683952987194, 55.58572769165039, 55.69127842783928, 51.43768027424812, 46.32732309401035, 38.90475578606129, 44.68893080949783, 50.88803976774216, 54.3871808052063, 54.75662738084793, 53.59299302101135, 51.5925295650959, 49.54913981258869, 53.94261986017227, 54.076859056949615, 55.63411429524422, 49.67690795660019, 47.2964458912611, 49.05790977180004, 48.5822094976902, 52.85383388400078, 51.2200241535902, 52.45015874505043, 51.38746216893196, 38.12281854450703, 10.577291026711464, 1.7201378918252885, 4.597002351656556, 6.793688703328371, 6.586285857483745, 14.11768265068531, 22.036923207342625, 15.737314391881227, 4.651248715817928, 0.25502266245894134, 0.4399818938691169, 0.13653319008881226, 19.760322868824005, 58.47905583679676, 25.862939804792404, 47.104134410619736, 21.03273779153824, 0.26854925381485373, 0.21734069305239245, 0.08702345730853267, 0.14814518886851147, 0.10956530983094126, 0.1901331139379181, 0.13132246735040098, 0.08308210395625792, 0.1813114865217358, 0.15594903496094048, 0.246737340639811, 0.14703330321935937, 0.07481159540475346, 0.11905350460438058, 0.14378217689227313, 0.15700989053584635, 0.09893432637909427, 0.22751647280529141, 0.11353004083503038, 0.09326509738457389, 0.14118332415819168, 0.16616487584542483, 0.16155303659616038, 0.08334523241501302], [0.01060959661117522, 0.037993370860931464, 0.0396158763760468, 0.057042294210987166, 0.03394833947822917, 0.07676043809624389, 0.03789620517636649, 0.17631994967814535, 0.01898909882584121, 0.012576020781125408, 0.054170590883586556, 0.02073648738587508, 0.11323479964630678, 0.03876200949889608, 0.053829759563086554, 0.02284963415149832, 0.040828538258210756, 0.010173809350817464, 0.04404806393722538, 0.036217500528437085, 0.07395759123028256, 0.03674660729302559, 0.03699318956932984, 0.013854111330147134, 0.07192132354248315, 0.06050320342183113, 0.011851969447889132, 0.026247531313856598, 0.0727982229727786, 0.03334237961098552, 0.0362962423969293, 1.4183224621228874, 31.399124935269356, 36.08513988554478, 25.802234262228012, 48.349380791187286, 19.176626689732075, 0.33199753670487553, 0.03168197632476222, 0.04151968925725669, 0.3530629235319793, 5.713894469663501, 4.647664083167911, 0.6737553246784955, 3.3531364845111966, 1.4687249762937427, 0.2898911648662761, 0.19310353032778949, 16.206308975815773, 45.02274289727211, 53.17165642976761, 58.442118018865585, 59.76934880018234, 57.528293654322624, 57.81463488936424, 53.135037794709206, 50.239247381687164, 47.80999593436718, 53.23040507733822, 58.56805846095085, 59.29280497133732, 58.28606799244881, 54.5110047608614, 55.82041069865227, 56.524072140455246, 57.102750688791275, 54.739239513874054, 49.41161759197712, 49.34004083275795, 49.05008219182491, 46.43971346318722, 44.400153905153275, 41.79931506514549, 40.974546521902084, 42.1749173104763, 40.15938386321068, 40.804482847452164, 42.30721861124039, 43.05073991417885, 42.04633221030235, 46.178743466734886, 47.37656459212303, 50.57138755917549, 48.69870364665985, 48.37667092680931, 48.83651465177536, 51.98050394654274, 53.20463486015797, 54.44647662341595, 55.63128724694252, 55.211759358644485, 55.0135163962841, 52.82245896756649, 46.977821588516235, 43.076350539922714, 41.94979839026928, 43.5862185806036, 40.68402551114559, 39.246946424245834, 40.153722167015076, 38.85628938674927, 38.88330973684788, 38.0616570264101, 38.93480837345123, 40.38472317159176, 48.32972064614296, 53.01882103085518, 53.62926207482815, 55.83529070019722, 53.66631768643856, 54.88295920193195, 52.02969990670681, 48.88246938586235, 47.287341579794884, 42.78082899749279, 38.54440972208977, 39.243826791644096, 48.71419161558151, 51.135543286800385, 50.52297055721283, 48.90355445444584, 51.29476994276047, 50.51035903394222, 50.74953339993954, 51.88688077032566, 51.373171135783195, 46.32013387978077, 44.49170619249344, 44.442274644970894, 45.873654037714005, 45.90884014964104, 48.724166080355644, 51.147204861044884, 42.7116385102272, 21.778014600276947, 3.089765729382634, 0.6365182134322822, 2.3205998400226235, 1.7694515269249678, 2.858082423917949, 0.5440732114948332, 8.091786447912455, 2.250958364456892, 0.17651274480158463, 0.3055433859117329, 0.06773866087314673, 2.861406058073044, 34.79307621717453, 26.399792097508907, 23.226582370698452, 34.79369178414345, 1.790424264036119, 0.07185389200458303, 0.028285758271522354, 0.02805899319355376, 0.03761009982554242, 0.05381559196393937, 0.04418531672854442, 0.06120195772382431, 0.039796144046704285, 0.02937881934485631, 0.0857604926568456, 0.01614515553228557, 0.027134852352901362, 0.06780202544177882, 0.0065717204597603995, 0.03304776924778707, 0.02571897002781043, 0.0683185231173411, 0.055851351280580275, 0.01986531919101253, 0.023041100830596406, 0.04097335353435483, 0.013034771945967805, 0.02517395347240381, 0.10074249497847632, 0.04061505947902333, 0.03526264590618666, 0.03834173869108781, 0.009454583832848584, 0.04219017886498477, 0.019367289860383607, 0.03917069538147189, 0.09223121887771413, 0.014083870973990997, 0.08351494674570858, 0.038584855137742124, 0.05797486584924627, 0.02042824933596421, 0.005144721690157894, 0.07058147239149548, 0.06615873237024061, 0.02348136138607515, 0.02137409243005095, 0.023096229415386915, 0.016763529674790334, 0.022713906473654788, 0.04816466062038671, 0.027448832770460285, 0.02863429679564433, 0.08767493680352345, 0.0649087701458484, 0.007345822232309729, 0.15591210569255054, 0.026085706012963783, 0.07362606644164771, 0.031579700953443535, 2.9169844882562757, 41.70427456498146, 36.89302213490009, 29.581167586147785, 63.36267538368702, 17.007342092692852, 0.1686313294339925, 0.11276499048108235, 0.08553283885703422, 0.15903392020845786, 1.48027932504192, 5.489411540329456, 3.507198505103588, 5.052004186436534, 2.6222326420247555, 0.3719143057242036, 0.7321925077121705, 22.042366415262222, 48.86156290769577, 56.87445893883705, 59.449907541275024, 63.284688368439674, 59.823340103030205, 58.63912604749203, 54.89040680229664, 52.830506935715675, 48.55033680796623, 54.89606089890003, 58.89930188655853, 62.45350196957588, 60.40089391171932, 55.71801759302616, 55.04368677735329, 57.58727788925171, 59.4410540163517, 57.07069180905819, 51.86765380203724, 51.59542880952358, 51.430487260222435, 47.880428954958916, 45.81631511449814, 43.432573825120926, 43.72988887131214, 43.804015293717384, 41.754435673356056, 41.38022035360336, 43.90078090131283, 44.25995282828808, 44.61552634835243, 47.170710638165474, 48.78549858927727, 51.59025348722935, 50.88754579424858, 52.3106150329113, 50.612850934267044, 53.96258398890495, 53.603833839297295, 55.19787110388279, 56.81637905538082, 56.879383474588394, 58.09029869735241, 53.0543415248394, 48.458997309207916, 45.172074884176254, 43.97471733391285, 43.48109722137451, 43.36094006896019, 40.52894063293934, 41.22034013271332, 40.467402935028076, 41.7237713187933, 38.61431837081909, 41.444604098796844, 42.00221657752991, 48.8396380841732, 54.534464702010155, 54.84005570411682, 56.62371799349785, 55.710304006934166, 56.44933395087719, 53.45654994249344, 50.416754856705666, 48.66477146744728, 45.60754671692848, 41.051218807697296, 40.65165884792805, 50.012794733047485, 53.32331769168377, 51.57664641737938, 49.27736319601536, 52.43087857961655, 50.91966927051544, 50.75289621949196, 53.70126821100712, 52.40409001708031, 48.46787743270397, 46.39731153845787, 44.9862914532423, 48.109370470047, 48.27048942446709, 51.19736596941948, 51.24668352305889, 45.62942214310169, 24.37496244907379, 4.118504952639341, 2.080293372273445, 4.296017177402973, 3.0819317372515798, 4.423521710559726, 4.250173112377524, 3.163366592489183, 0.9962062002159655, 0.10423513100249693, 0.1443959033349529, 0.09616034163627774, 1.7894202866591513, 40.34899368882179, 35.52973888814449, 23.178076073527336, 41.030551716685295, 3.802003310993314, 0.09210376243572682, 0.07031740882666782, 0.05216740071773529, 0.006331606928142719, 0.03703399655933026, 0.05110374724608846, 0.05493757453223225, 0.09059569609235041, 0.010729698369686957, 0.08275069048977457, 0.02521719656215282, 0.04069821341545321, 0.03712926234584302, 0.038662350198137574, 0.07128050128812902, 0.03704340699187014, 0.09529462637146935, 0.05568133266933728, 0.019437946029938757, 0.02428513515042141, 0.062126625489327125, 0.05884229176444933, 0.014422125186683843, 0.06159695840324275, 0.17180280847242102, 0.0962409537169151, 0.10781638688058592, 0.07936228168546222, 0.14415437879506499, 0.24115634558256716, 0.1363171509001404, 0.21994650713168085, 0.09888433531159535, 0.12091722295735963, 0.11664228164590895, 0.1287809677887708, 0.14814631693297997, 0.17049052810762078, 0.10466292718774639, 0.15455654327524826, 0.059158628500881605, 0.14554728608345613, 0.13501959474524483, 0.16587503749178723, 0.17515268496936187, 0.1446811403729953, 0.1022366237884853, 0.09905486600473523, 0.16608972597168759, 0.24494229321135208, 0.12254375091288239, 0.23230829770909622, 0.2347595669561997, 0.23228487552842125, 0.12641489709494635, 3.6338682705536485, 50.4842696338892, 48.916044384241104, 35.291514471173286, 62.77528390288353, 26.635939925909042, 0.6784592941403389, 0.3661816008388996, 0.39344145683571696, 1.0963244154118001, 12.779484707862139, 14.535622224211693, 6.8332897033542395, 12.108868192881346, 3.354866341687739, 0.72430799016729, 0.7414580136537552, 19.742004051804543, 48.97356569766998, 55.17314203083515, 60.127829164266586, 63.383388072252274, 60.187459364533424, 61.984827518463135, 57.23278731107712, 55.097176507115364, 52.04842530190945, 58.624846413731575, 61.566032990813255, 65.96823737025261, 61.09050750732422, 54.29928012192249, 55.448699444532394, 59.04163084924221, 62.06053085625172, 59.597795605659485, 54.483938813209534, 54.464191272854805, 52.88207396864891, 51.05767786502838, 49.469264298677444, 46.30475230515003, 45.88352210819721, 46.40303783118725, 42.94567175209522, 43.78361038863659, 46.51095204055309, 46.57751306891441, 47.06253804266453, 50.19179932773113, 51.60327918827534, 54.793770387768745, 53.50725442171097, 53.82076419889927, 53.0184980481863, 54.764614552259445, 57.61662371456623, 57.297665029764175, 56.633962243795395, 59.952232986688614, 59.06283751130104, 54.33728568255901, 49.77451331913471, 46.66218012571335, 46.51700511574745, 46.1187294870615, 44.43980097770691, 42.161473631858826, 44.51649606227875, 42.663191109895706, 43.688155710697174, 42.74695001542568, 43.40520769357681, 44.67172533273697, 52.78112858533859, 57.28614404797554, 56.127924397587776, 58.52887116372585, 57.04814001917839, 56.808646470308304, 53.932854384183884, 52.367224395275116, 50.75396776199341, 48.41083109378815, 43.10557097196579, 42.446538135409355, 51.22195065021515, 55.92536486685276, 53.063597828149796, 50.45800544321537, 52.87964589893818, 51.215061619877815, 52.59636729955673, 55.477992072701454, 53.70650053024292, 50.37333458662033, 48.18877100944519, 48.15360389649868, 50.6662380695343, 49.026458859443665, 52.25944697856903, 53.32579515874386, 45.39126232266426, 23.079887442290783, 4.08616061322391, 1.9577520852908492, 6.539726480841637, 6.808725446462631, 7.025979263707995, 4.482309306040406, 16.64444636553526, 9.807031508535147, 0.7468983717262745, 0.7210158230736852, 0.15572015661746264, 5.168172977864742, 45.259610787034035, 38.45524750649929, 32.50439062714577, 49.484417885541916, 4.248625170439482, 0.18675294297281653, 0.18932904145913199, 0.10856971130124293, 0.12444002728443593, 0.16613729763776064, 0.1397138717584312, 0.09526874768198468, 0.14199271041434258, 0.1105726565583609, 0.2156940900022164, 0.16797878866782412, 0.09298920398578048, 0.1965554224443622, 0.09086865800782107, 0.21285825467202812, 0.1388420708826743, 0.20246033527655527, 0.15063914644997567, 0.10441809266922064, 0.10756359653896652, 0.1833849580725655, 0.10080081294290721, 0.18747960944892839, 0.26547474379185587], [0.061638411061721854, 0.007994379520823713, 0.0034680540056797327, 0.017639740763115697, 0.050116609199903905, 0.048165569751290604, 0.07107128985808231, 0.05883495192392729, 0.056353172985836864, 0.004930311979478574, 0.023437884519807994, 0.005295155951898778, 0.023246089440362994, 0.027138824698340613, 0.03395825086045079, 0.06708968241582625, 0.029544910139520653, 0.06062752057914622, 0.034602208688738756, 0.00935178431973327, 0.04532619066594634, 0.06659616905380972, 0.031111446587601677, 0.06617474791710265, 0.021139935561222956, 0.05512371259101201, 0.09194956641294993, 0.02736191057920223, 0.05390760714362841, 0.02467231544869719, 0.06659462538664229, 0.056984020775416866, 12.575646545737982, 44.672477692365646, 30.416887141764164, 34.25909847021103, 46.28232590854168, 14.444398619234562, 0.8422138821333647, 0.2294744216487743, 0.09643970086472109, 0.29636664083227515, 2.9171516792848706, 1.6840762831270695, 2.875357484444976, 2.12267701048404, 0.3469500906066969, 0.07899653646745719, 1.6442303149960935, 21.089020371437073, 42.553342804312706, 57.29066580533981, 63.64356771111488, 62.065048813819885, 58.86390678584576, 54.651430025696754, 50.3818803280592, 49.45754952728748, 56.53506875038147, 60.14397069811821, 60.01192398369312, 55.70314519107342, 55.533233508467674, 59.06996592879295, 59.298006892204285, 57.96825684607029, 53.98961193859577, 52.70882986485958, 50.79603910446167, 50.02694517374039, 50.80032907426357, 46.18902571499348, 42.92210541665554, 43.657088577747345, 41.99384182691574, 39.861719235777855, 39.9023162573576, 40.54575473070145, 41.491330191493034, 42.643466368317604, 45.96080996096134, 49.21993687748909, 49.74591605365276, 53.34865853190422, 53.072557747364044, 55.3823322057724, 54.68498982489109, 53.428693637251854, 58.6510194092989, 54.833645448088646, 52.672234028577805, 55.549827218055725, 54.51137714087963, 53.10192257165909, 47.80237354338169, 43.12604047358036, 42.37064480781555, 41.02372348308563, 39.5214968919754, 39.3823179602623, 40.63762240111828, 39.42457929253578, 38.843047097325325, 37.57176831364632, 46.377575397491455, 52.690131068229675, 53.70922118425369, 53.696187883615494, 53.55844147503376, 56.88831679522991, 53.26489582657814, 52.15997591614723, 47.70156495273113, 45.849969908595085, 44.73267786204815, 39.2199070751667, 41.81340470910072, 49.991895854473114, 51.53045229613781, 52.135710418224335, 50.25504693388939, 51.19750656187534, 52.73316375911236, 52.311253398656845, 51.562682166695595, 50.10697267949581, 46.107276901602745, 44.64252009987831, 47.854324355721474, 49.88282270729542, 49.68981206417084, 50.66496893763542, 49.348996952176094, 32.249405309557915, 8.669504597783089, 0.9487852791789919, 1.3143245363608003, 3.0585860274732113, 1.4023547689430416, 4.810905223712325, 2.3248104890808463, 1.6206414182670414, 0.8366208197548985, 0.05722806861740537, 0.034774758023559116, 0.30894414405338466, 17.545258328318596, 43.47391180694103, 21.16525188088417, 34.884081333875656, 13.7710434012115, 0.038474067332572304, 0.07909876730991527, 0.02142266785085667, 0.04528265999397263, 0.06415344192646444, 0.012819189178117085, 0.017139943265647162, 0.07237129510031082, 0.04752511114929803, 0.04288226868084166, 0.0766347034368664, 0.030187027441570535, 0.00700013912137365, 0.0665288265736308, 0.05728981901484076, 0.1090803237457294, 0.03548623273673002, 0.021181043121032417, 0.09319631513790227, 0.02636796147271525, 0.034929484681924805, 0.011765532435674686, 0.04896229496807791, 0.027109389266115613, 0.0353677637031069, 0.03822867991402745, 0.02326030342373997, 0.030297217817860655, 0.03409211574762594, 0.030327974272950087, 0.05340250143490266, 0.02179575847549131, 0.024171599543478806, 0.013065753828414017, 0.08143872924847528, 0.024691666949365754, 0.05262199956632685, 0.011252174044784624, 0.03455861493421253, 0.07291451751370914, 0.015326180728152394, 0.05599540956609417, 0.018577316332084592, 0.021715630646212958, 0.05088484707812313, 0.013403324337559752, 0.04368263413198292, 0.02487930414645234, 0.06349990668240935, 0.03636322493548505, 0.038513408580911346, 0.031217621944961138, 0.03261769095843192, 0.0829166940820869, 0.054662716429447755, 0.04757217444421258, 0.10708649948355742, 18.734275326132774, 49.28755044937134, 29.430868551135063, 43.971506506204605, 58.0711705237627, 12.165418658405542, 0.5629974429029971, 0.10233765235170722, 0.040639669095980935, 0.08716103664482944, 0.3184826415963471, 3.127708830870688, 5.5130766704678535, 3.983448324725032, 2.1155326813459396, 0.12885792850283906, 2.6342262234538794, 25.438462682068348, 46.10859923064709, 61.071690917015076, 65.7636259496212, 62.803645581007004, 58.48548889160156, 57.12507829070091, 52.0370639115572, 49.65600907802582, 56.945773512125015, 62.8467770665884, 60.965923592448235, 57.491789013147354, 54.60666462779045, 58.030603900551796, 60.429768562316895, 59.79760408401489, 55.09457364678383, 53.319540694355965, 53.56160670518875, 50.33414348959923, 53.921964168548584, 47.55418226122856, 44.83011983335018, 44.476267620921135, 43.51395785808563, 42.98554681241512, 41.3397791236639, 43.167085871100426, 42.48228281736374, 45.31266734004021, 48.05203914642334, 51.846108958125114, 51.9001192599535, 53.53084355592728, 54.97098907828331, 56.78504213690758, 55.874964371323586, 55.75627014040947, 61.27851381897926, 56.27103231847286, 55.214366018772125, 57.554147467017174, 56.32888421416283, 54.06488969922066, 50.11503964662552, 44.46125842630863, 44.67804439365864, 42.341637164354324, 40.692696645855904, 41.84447184205055, 41.427558213472366, 41.128335669636726, 40.351558551192284, 39.70756910741329, 47.03622445464134, 54.23409461975098, 55.60432009398937, 54.88122649490833, 53.852728083729744, 58.302015736699104, 56.68566606938839, 54.11888100206852, 50.37010855972767, 48.970883041620255, 44.90185238420963, 41.88615560531616, 42.19416707754135, 51.58202312886715, 54.61394123733044, 53.61917361617088, 50.07829561829567, 53.52156065404415, 54.08455364406109, 53.48864682018757, 52.507281079888344, 52.08621047437191, 46.16637893021107, 46.51462264358997, 50.99663034081459, 49.894431084394455, 51.050469651818275, 50.987279042601585, 52.546719163656235, 34.257396161556244, 10.44739119708538, 1.5556275006383657, 2.759989737533033, 3.8199043879285455, 3.2564212242141366, 4.1671632416546345, 2.4811668740585446, 0.8327855193056166, 0.19920721999369562, 0.0447791202168446, 0.031650357122998685, 0.7361871027387679, 20.079500041902065, 50.25953829288483, 22.834314219653606, 35.88290333747864, 20.47351609915495, 0.09567202330799773, 0.053274688762030564, 0.06191991509695072, 0.036188100348226726, 0.024518796635675244, 0.08601913112215698, 0.023012580095382873, 0.05227910878602415, 0.02880329680920113, 0.04696287491242401, 0.05550041933020111, 0.033668954274617136, 0.06287199779762886, 0.06992551774601452, 0.03039475643163314, 0.05077576992334798, 0.06737333125784062, 0.0680965838546399, 0.016194263444049284, 0.043808814079966396, 0.06139977718703449, 0.02703953276068205, 0.05208636190218385, 0.01592806620465126, 0.01823508420784492, 0.11000564831192605, 0.11375144575140439, 0.10103096035891213, 0.12394371602567844, 0.09863414990832098, 0.22780159109970555, 0.14079760032473132, 0.14237910218071193, 0.13303145533427596, 0.16511040274053812, 0.10988712732796557, 0.12227594692376442, 0.09965009812731296, 0.15210196404950693, 0.16149746457813308, 0.12773624650435522, 0.15453000407433137, 0.20522262377198786, 0.08892011959687807, 0.10088705050293356, 0.09494108206126839, 0.19466071942588314, 0.11206736424355768, 0.18592721462482587, 0.16729078808566555, 0.14411759795621037, 0.18383924150839448, 0.12118569487938657, 0.1817773177754134, 0.1551075285533443, 0.17962915648240596, 0.168803715496324, 20.62881376594305, 59.68893751502037, 40.2897472679615, 44.66734416782856, 57.203886061906815, 21.919475309550762, 1.8040419020690024, 0.429676579660736, 0.1595391595037654, 0.8713766047731042, 6.83473932556808, 6.689337277784944, 9.096677675843239, 7.144105425104499, 1.7304253648035228, 0.16419355350080878, 2.2225306648761034, 24.118016436696053, 45.73359355330467, 62.190658673644066, 68.12361091375351, 68.34011569619179, 63.34986247122288, 59.23166245222092, 55.06265535950661, 52.87552312016487, 60.1884701102972, 66.5992771089077, 63.26137661933899, 56.194132044911385, 56.13268934190273, 61.66561804711819, 62.15814381837845, 62.90103055536747, 58.100489750504494, 56.621563509106636, 56.0974196344614, 51.62785246968269, 56.76725909113884, 51.213028728961945, 47.37557664513588, 48.046461045742035, 46.2348398566246, 45.06160721182823, 43.523924723267555, 45.58936849236488, 44.18525643646717, 47.65433728694916, 50.01120641827583, 53.834078684449196, 54.70135934650898, 57.98831216990948, 57.95664466917515, 61.27643533051014, 61.3703016936779, 56.96717016398907, 63.71358275413513, 57.093103006482124, 56.64128065109253, 59.607287496328354, 59.33358818292618, 58.14642548561096, 52.39102631807327, 47.07144096493721, 46.57372087240219, 46.34275406599045, 43.04857783019543, 43.18651422858238, 43.924438431859016, 43.63550193607807, 42.653638422489166, 41.560532078146935, 51.26525692641735, 55.17424017190933, 58.28142084181309, 55.91642774641514, 54.58779104053974, 59.80251342058182, 58.76700058579445, 58.21245454251766, 52.31775104999542, 50.938193276524544, 48.74310806393623, 44.39842499792576, 44.884137734770775, 53.32464002072811, 55.167081356048584, 55.37985473871231, 53.09787958860397, 54.16665963828564, 55.75776346027851, 53.872665613889694, 54.85214285552502, 54.29735742509365, 48.16486269235611, 49.48477506637573, 52.36284703016281, 51.77697166800499, 54.13672864437103, 53.66517394781113, 51.923320814967155, 32.791898399591446, 10.195912141352892, 1.8155359290540218, 4.5631366688758135, 7.379808202385902, 6.342237778007984, 12.771915514022112, 8.904470689594746, 8.1440269947052, 2.0872503239661455, 0.19608712726039812, 0.19625476357759908, 1.257135111372918, 26.25501036643982, 55.03180481493473, 29.34768721461296, 46.93695858120918, 21.351781971752644, 0.18477905279723927, 0.1826533192070201, 0.22328829421894625, 0.13818331091897562, 0.12933389749377966, 0.25203673518262804, 0.09893304246361367, 0.13128157501341775, 0.10867638760828413, 0.10999035264831036, 0.15870813222136348, 0.12987621448701248, 0.15887409128481522, 0.10777458912343718, 0.16628768644295633, 0.2606712077977136, 0.1444515198818408, 0.14911005506291986, 0.11764067807234824, 0.17986128543270752, 0.09077088747289963, 0.17191040504258126, 0.08070757277891971, 0.08827492609270848, 0.12700773950200528], [0.07768680909066461, 0.04106035550648812, 0.05107980927277822, 0.062032684436417185, 0.021575683858827688, 0.02949128069303697, 0.05328140519850422, 0.041492927412036806, 0.04916384372336324, 0.03480025079625193, 0.020169534800515976, 0.00257449150467437, 0.06890267497510649, 0.06373029158567078, 0.01214261952554807, 0.025980525133491028, 0.016736918114474975, 0.033745978071237914, 0.063716302101966, 0.08954414704930969, 0.04504552525759209, 0.042740900680655614, 0.03242310725909192, 0.03188857539498713, 0.01621561503270641, 0.04045654415676836, 0.027710274698620196, 0.015546013219136512, 0.0937968165089842, 0.01634592132177204, 0.02283701949636452, 0.060221087114769034, 0.20219601196004078, 25.09326260536909, 40.624045729637146, 30.125682167708874, 37.39651031792164, 43.40764716267586, 17.33255334198475, 1.644395962357521, 0.08623584566521458, 0.1783343165880069, 0.542999590979889, 3.0155994091182947, 4.637203719466925, 2.156328479759395, 1.9411693001165986, 0.2496577362762764, 0.13118337403284386, 2.573888311162591, 20.896439105272293, 44.508767277002335, 65.10231703519821, 59.57660414278507, 59.48171563446522, 57.246394380927086, 54.45763282477856, 51.94559521973133, 57.229793071746826, 60.49139745533466, 61.46166019141674, 57.261194586753845, 55.9523244202137, 58.65735366940498, 58.86492893099785, 59.122197926044464, 56.59373380243778, 55.423514395952225, 53.088885471224785, 53.30699756741524, 52.66299672424793, 46.5670370310545, 44.697130769491196, 44.1250828653574, 43.672823533415794, 42.977487444877625, 40.27571082115173, 41.57585285604, 41.32310941815376, 42.2328832000494, 48.42308163642883, 49.9067310243845, 51.04446977376938, 53.88219930231571, 55.301970317959785, 53.68227303028107, 57.119222804903984, 56.76734268665314, 56.16492681205273, 53.23126383125782, 55.79337514936924, 54.6599605679512, 53.818195536732674, 53.14825348556042, 53.71136426925659, 47.10797980427742, 42.06462062895298, 40.1020373404026, 41.182478964328766, 41.19575925171375, 38.43055263161659, 41.109101101756096, 38.34132581949234, 44.27312292158604, 56.23040109872818, 53.16528417170048, 53.71513366699219, 52.47206076979637, 55.961633920669556, 54.462792947888374, 52.53280431032181, 49.25514578819275, 47.9824610799551, 45.03842085599899, 43.25945131480694, 40.30520483851433, 40.52777409553528, 52.24193371832371, 53.04488003253937, 52.799815982580185, 52.74446055293083, 54.0074747800827, 54.180369302630424, 52.3299065977335, 51.114807799458504, 48.05806942284107, 47.02160283923149, 47.74462044239044, 48.07032756507397, 50.02446010708809, 50.047524869441986, 47.54537433385849, 35.85224658250809, 15.94853650778532, 1.7381923855282366, 0.7543350476771593, 3.4798451978713274, 3.3633598359301686, 1.9988497300073504, 1.3053475180640817, 3.2014650106430054, 0.7706942979712039, 0.04128748238144908, 0.05113833503855858, 0.7964671868830919, 12.511973362416029, 41.38716258108616, 30.87989989668131, 26.243079006671906, 32.102915570139885, 2.2870015678927302, 0.08852177925291471, 0.08630891010398045, 0.10830877959961072, 0.05261419588350691, 0.07894311667769216, 0.03835485615127254, 0.049495357379782945, 0.01017375276205712, 0.048701222258387133, 0.05325268779415637, 0.027190285218239296, 0.04883127250650432, 0.03166521120874677, 0.013648817512148526, 0.0464881044899812, 0.043488399242050946, 0.028116550456616096, 0.03686259013193194, 0.03531146438035648, 0.10268001991789788, 0.035704316542251036, 0.03906952581019141, 0.027476802461023908, 0.054134578167577274, 0.01349853631836595, 0.03700088564073667, 0.0040038329098024406, 0.03551610789145343, 0.033930475983652286, 0.01909457285364624, 0.024797614096314646, 0.023920590356283356, 0.022385843803931493, 0.05748418378061615, 0.04011441036709584, 0.017265319838770665, 0.11705633325618692, 0.02224889900389826, 0.05831578993820585, 0.05881858756765723, 0.031295217195292935, 0.020919912894896697, 0.020241062993591186, 0.07826443004887551, 0.06731827874318697, 0.02373387342231581, 0.022754813653591555, 0.026687728786782827, 0.0093125154307927, 0.027671484494931065, 0.0823006298742257, 0.049886417255038396, 0.047846130837569945, 0.048955470920191146, 0.033075967148761265, 0.025341977561765816, 0.038898854108992964, 0.9973944677039981, 35.65439119935036, 42.603351920843124, 30.25156371295452, 45.385528430342674, 53.358891382813454, 16.370568461716175, 1.3382101734168828, 0.004518515106610721, 0.3118616156280041, 0.17005880596116185, 0.5963662429712713, 3.0710780946537852, 8.159225229173899, 4.708254206925631, 0.8938269875943661, 0.13135291024809703, 4.263550769537687, 24.817855283617973, 47.22970247268677, 65.12440145015717, 61.1542908847332, 61.10517472028732, 57.783199176192284, 56.166537925601006, 53.8080120831728, 58.33559073507786, 61.45196691155434, 63.137769252061844, 58.020390048623085, 56.337619945406914, 58.74993570148945, 60.448429360985756, 59.323260337114334, 59.397375360131264, 57.02586941421032, 55.45585446059704, 55.34156799316406, 54.29540432989597, 49.5791620016098, 46.92517541348934, 45.740980356931686, 44.95255686342716, 44.960996210575104, 43.09560030698776, 43.69080416858196, 43.181517496705055, 44.22274902462959, 49.507836028933525, 52.237514555454254, 52.87702403962612, 55.4118338227272, 56.461215913295746, 56.6277039796114, 59.76815186440945, 58.67698721587658, 56.907904744148254, 53.579678535461426, 55.568640008568764, 57.41137772798538, 56.81408017873764, 55.25269836187363, 54.33017246425152, 49.15738843381405, 43.33746872842312, 41.73205487430096, 41.923872381448746, 41.49965174496174, 41.31943881511688, 42.85276673734188, 39.028887525200844, 45.20257584750652, 56.94733142852783, 55.55248707532883, 55.75581036508083, 52.61760056018829, 55.80848693847656, 56.814676746726036, 53.79552215337753, 51.041851714253426, 49.90032836794853, 47.5525027513504, 46.32108002901077, 43.690446987748146, 42.13724233210087, 53.898572623729706, 54.107584208250046, 53.5365242511034, 52.278829738497734, 54.22016076743603, 54.84117664396763, 54.744711220264435, 50.99040247499943, 50.16560733318329, 49.87472914159298, 49.7510077804327, 49.312724098563194, 53.018080070614815, 50.89525558054447, 49.29577320814133, 39.62349481880665, 19.360880702733994, 3.367650043219328, 1.7929793894290924, 4.282928304746747, 4.638596344739199, 3.6295080045238137, 4.829007452353835, 1.2778808106668293, 0.5133759649470448, 0.08623286223155446, 0.06657190824626014, 0.6257164024282247, 11.689388751983643, 44.31548684835434, 36.149649024009705, 25.85473984479904, 37.45546415448189, 3.6732213338837028, 0.12553132575703785, 0.03983630536822602, 0.0476712103409227, 0.013845422636222793, 0.03228642221074551, 0.04007767034636345, 0.07434815386659466, 0.01869249394076178, 0.03399477936909534, 0.03027589962584898, 0.019682385354826692, 0.03099716512224404, 0.03048868635232793, 0.03569031221559271, 0.02573757567006396, 0.023898823164927308, 0.014864661352476105, 0.005054103603470139, 0.015140098330448382, 0.0536372241913341, 0.08307595897349529, 0.033415729776606895, 0.0680482255120296, 0.08032932237256318, 0.07519409089582041, 0.15336165582994, 0.11397219757782295, 0.08968076159362681, 0.09669189006672241, 0.11430776707129553, 0.11163437302457169, 0.12208183077746071, 0.14612684404710308, 0.12455143849365413, 0.19347352063050494, 0.11730499725672416, 0.11987478748778813, 0.11234882374992594, 0.13232591038104147, 0.11057091993279755, 0.11364503661752678, 0.17644330946495757, 0.17299958097282797, 0.22868016036227345, 0.22747697570594028, 0.10829024817212485, 0.15585993271088228, 0.14200424338923767, 0.07902802579337731, 0.15559222520096228, 0.1377800278714858, 0.18384160153800622, 0.14593096158932894, 0.20079793932382017, 0.1055105785781052, 0.16372289828723297, 0.1561796202440746, 0.7233984139747918, 39.93911348283291, 54.92113575339317, 41.084033846855164, 47.546202689409256, 57.42113180458546, 24.498463422060013, 2.470032759010792, 0.3189013316296041, 0.632528190035373, 1.784934508614242, 8.868632912635803, 8.919707871973515, 10.482783447951078, 5.569009194150567, 1.1479482077993453, 0.24583297432400286, 3.1366172153502703, 22.376841567456722, 47.90206499397755, 67.18711316585541, 63.53249967098236, 63.920975625514984, 63.71266320347786, 59.19974036514759, 56.73181839287281, 60.86872860789299, 64.47506949305534, 66.17950603365898, 58.60195644199848, 57.19570130109787, 59.531287774443626, 61.83304086327553, 62.84080758690834, 60.12013457715511, 60.719028040766716, 57.22576528787613, 58.21844682097435, 58.71648609638214, 51.2513192743063, 49.430909156799316, 48.29970225691795, 47.750498726964, 48.412484005093575, 44.562465995550156, 46.502816677093506, 45.20669102668762, 47.00388818979263, 52.629942297935486, 55.96108295023441, 56.387735456228256, 57.42172457277775, 59.66013126075268, 57.23034784197807, 59.985591396689415, 61.4856369048357, 59.512668773531914, 55.144426971673965, 55.64561627805233, 58.81957836449146, 58.679814264178276, 57.45501458644867, 58.368139788508415, 50.84328956902027, 45.330511182546616, 43.505119532346725, 44.42741744220257, 44.1166777163744, 42.87295505404472, 45.228585451841354, 42.55683481693268, 48.9818150550127, 61.8364492803812, 56.928750425577164, 55.82720473408699, 54.27590757608414, 58.646961227059364, 58.52266609668732, 54.83725145459175, 52.38664895296097, 53.2298769056797, 49.32043008506298, 48.091652020812035, 46.801283061504364, 44.422466307878494, 55.76215602457523, 55.99549010396004, 56.55265800654888, 54.688337445259094, 56.35229475796223, 57.64199875295162, 55.842909291386604, 54.28630381822586, 51.56764470040798, 51.07963688671589, 51.1664242297411, 52.89814330637455, 55.437699034810066, 52.72216334939003, 50.70055402815342, 37.796017080545425, 18.59855990856886, 2.717148936353624, 1.9391308282501996, 9.336850438266993, 9.599707033485174, 5.163816511631012, 9.304240588098764, 10.33089704811573, 2.0426153065636754, 0.18799250770825893, 0.13232703844550997, 1.8486308469437063, 18.45286812633276, 53.611482828855515, 42.72410564124584, 34.25774194300175, 44.552012756466866, 4.081952814012766, 0.21040089981397614, 0.1512134203221649, 0.23091401002602652, 0.19646554836072028, 0.13401533535216004, 0.08701596161699854, 0.10585781463305466, 0.1312385601340793, 0.2206783537985757, 0.16805920779006556, 0.15899068268481642, 0.240564527339302, 0.15539399755652994, 0.1883729622932151, 0.11677702597808093, 0.10980338338413276, 0.05724317132262513, 0.10616500439937226, 0.13353172224014997, 0.18223023565951735, 0.19671468733577058, 0.11421894683735445, 0.17419906973373145, 0.13830094132572412, 0.14179605612298474], [0.044265650503803045, 0.017784376068448182, 0.026395413515274413, 0.03551503919879906, 0.07450568213243969, 0.012629601060325513, 0.017927950102603063, 0.01597666574525647, 0.01890314513730118, 0.07454651509760879, 0.02770663075352786, 0.024854189869074617, 0.008554153682780452, 0.06987199405557476, 0.03841842481051572, 0.0451993613387458, 0.09986935823690146, 0.02960756595712155, 0.07039896343485452, 0.05130122532136738, 0.04092898794624489, 0.015153866097534774, 0.04594100435497239, 0.03324922152387444, 0.016253880166914314, 0.039119579960242845, 0.06594854130526073, 0.056348849975620396, 0.02312327327672392, 0.05188251248910092, 0.0324548711796524, 0.06221153831575066, 0.00743082179724297, 2.191749941557646, 38.025676757097244, 38.0963833630085, 29.961795061826706, 34.676312282681465, 46.368896663188934, 16.757551096379757, 1.0552201210521162, 0.002909481195274566, 0.16081817680969834, 0.4613370745209977, 4.241347135975957, 6.880831327289343, 5.380539307370782, 1.5418286598287523, 0.24553647148422897, 0.3178370028035715, 5.755023462697864, 32.90586568415165, 61.67747341096401, 64.70721423625946, 59.80358876287937, 61.257128566503525, 55.269941836595535, 51.36822760105133, 55.41017331182957, 59.20239642262459, 62.27699764072895, 59.73057188093662, 59.067214876413345, 58.18404346704483, 58.037462532520294, 57.75996722280979, 57.34566405415535, 55.34490421414375, 56.66100539267063, 53.99584740400314, 55.03568820655346, 49.948676973581314, 46.38236314058304, 42.40784861147404, 44.61244851350784, 42.22878322005272, 42.985968589782715, 40.127283185720444, 40.77863283455372, 42.66913779079914, 47.56951443850994, 47.867171466350555, 52.105217054486275, 54.53941963613033, 59.057969972491264, 61.47858448326588, 55.50168000161648, 55.3530053794384, 61.34622998535633, 52.06569917500019, 51.64565831422806, 56.11327238380909, 56.6581479460001, 57.204254642128944, 55.15573896467686, 51.051814779639244, 45.85229158401489, 42.51266598701477, 41.0808078199625, 38.89928787946701, 41.07217848300934, 39.42198023200035, 39.96899127960205, 51.68550297617912, 54.68967877328396, 57.453072890639305, 53.937144353985786, 55.143423825502396, 54.81750011444092, 51.71624332666397, 49.751190170645714, 46.275615468621254, 47.35041059553623, 43.60935553908348, 43.53450335562229, 37.711182832717896, 42.18088299036026, 52.04424932599068, 53.32275912165642, 51.736431643366814, 51.35185427963734, 55.91230496764183, 53.26569378376007, 52.511457055807114, 51.323238015174866, 49.41520839929581, 48.57144467532635, 48.987708538770676, 50.82683265209198, 50.71785070002079, 51.68533958494663, 38.60906325280666, 14.016597624868155, 1.4292350015603006, 0.3046384110348299, 1.685716607607901, 0.5572837963700294, 1.9517422327771783, 1.5659489342942834, 2.3930762009695172, 0.7478157849982381, 0.10649402815033682, 0.06249304235097952, 0.7679545262362808, 14.34922892600298, 36.25396862626076, 35.92649459838867, 21.85862347483635, 35.234145149588585, 12.417721319943666, 0.023783478573022876, 0.06925518770003691, 0.04619649611413479, 0.06358509039273486, 0.02282704688695958, 0.005908947332500247, 0.04171330816461705, 0.028311176829447504, 0.054129817290231586, 0.050624869036255404, 0.044403946012607776, 0.003425809800319257, 0.023657463752897456, 0.06661919789621606, 0.02682551035832148, 0.03140171538689174, 0.06746017737896182, 0.0235405087005347, 0.04218817506625783, 0.016796974559838418, 0.006771139251213754, 0.016905966367630754, 0.02937146095064236, 0.022336624570016284, 0.03727507952135056, 0.037366026008385234, 0.01527825283119455, 0.08897066727513447, 0.035852467772201635, 0.05126939089677762, 0.043376141984481364, 0.039632763946428895, 0.0711782110738568, 0.0539285023114644, 0.04141913195780944, 0.015135365283640567, 0.016127280905493535, 0.03989516510046087, 0.01697504732874222, 0.02608326991321519, 0.03518312478263397, 0.035964687922387384, 0.04679116049373988, 0.019495967135298997, 0.030286555011116434, 0.057245138013968244, 0.03457955092017073, 0.08998362463898957, 0.11330522203934379, 0.0780839916842524, 0.028507215138233732, 0.0731566060858313, 0.050242726065334864, 0.04751604581542779, 0.021133567934157327, 0.04764812212670222, 0.025172675123030785, 0.08449034401564859, 0.08418455690843984, 4.851575391367078, 47.43005812168121, 39.21135753393173, 30.22535651922226, 43.54261212050915, 55.60678616166115, 17.20398724079132, 0.7493322005029768, 0.12107361573725939, 0.12199353746837005, 0.4991547530516982, 0.7850954064633697, 5.6797409523278475, 7.77159757912159, 1.643138942308724, 1.1184172611683607, 0.45709291007369757, 7.815041122958064, 34.244602248072624, 62.46505334973335, 64.63228985667229, 63.55978220701218, 61.66447430849075, 55.700682923197746, 53.31643246114254, 58.68327967822552, 62.07636080682278, 61.17302767932415, 61.12122505903244, 59.44247893989086, 59.37706544995308, 58.77112336456776, 57.77662932872772, 58.26193168759346, 58.40684071183205, 57.49961279332638, 55.81149637699127, 56.890532076358795, 51.195382475852966, 47.32193872332573, 45.009310618042946, 46.06611751019955, 43.84123809635639, 44.575833678245544, 43.483244106173515, 42.92540363967419, 44.20979931950569, 48.4561512619257, 51.00563585758209, 53.54081802070141, 57.35310025513172, 60.35386383533478, 59.58119049668312, 58.01086775958538, 57.28532329201698, 62.66867682337761, 53.28390620648861, 51.39554813504219, 57.70615451037884, 58.674642741680145, 58.21259133517742, 56.97166532278061, 53.65146808326244, 46.221943348646164, 44.789047837257385, 44.23661828041077, 40.70519797503948, 42.199623584747314, 41.5182289481163, 42.150351628661156, 52.32480727136135, 57.32924893498421, 57.888666316866875, 53.97148311138153, 55.8004579693079, 56.642177402973175, 54.2073592543602, 51.28164924681187, 47.71281234920025, 48.663677126169205, 46.749043464660645, 44.88646700978279, 39.97438319027424, 44.41854111850262, 52.30784498155117, 55.3150150179863, 53.626985996961594, 52.34402284026146, 55.90714484453201, 53.55903044342995, 53.320175260305405, 52.894898280501366, 51.480925753712654, 48.96210551261902, 51.010586991906166, 53.29824283719063, 52.22429506480694, 52.52270445227623, 41.64684444665909, 16.97597287595272, 1.8364481069147587, 1.6947440919466317, 3.771146354265511, 4.369070157408714, 2.409806465730071, 4.45179789327085, 1.4498048415407538, 0.25145426800008863, 0.07049252599244937, 0.13564857974415645, 0.3762198012555018, 13.83842708542943, 40.23446023464203, 43.38836319744587, 25.8596358820796, 38.88486385345459, 18.39158121496439, 0.05317726703651715, 0.09773435522220097, 0.11526170143042691, 0.04132838956138585, 0.02798183952108957, 0.005730666298404685, 0.010808480128616793, 0.02415925577224698, 0.0019238966729062668, 0.024371014624193776, 0.10040203473181464, 0.03105879863142036, 0.032966385333565995, 0.03676348744193092, 0.08879280416294932, 0.07041906079393812, 0.07197748185717501, 0.01908880080009112, 0.10656395330443047, 0.015756605971546378, 0.0369712665269617, 0.0407421040290501, 0.04805967641004827, 0.029791366250719875, 0.038333857082761824, 0.06340542386169545, 0.16136347723659128, 0.22445929935202003, 0.1653937398805283, 0.15465229516848922, 0.1428126054815948, 0.1292668073438108, 0.16209124209126458, 0.11446830103523098, 0.1723870271234773, 0.14047294040210545, 0.22348790225805715, 0.21230370708508417, 0.10825377903529443, 0.09762138550286181, 0.20494341297307983, 0.13027032458921894, 0.16613461106317118, 0.18893607426434755, 0.12518552946858108, 0.1485651108669117, 0.15310168149881065, 0.12536642054328695, 0.19476224522804841, 0.16246249404503033, 0.10023160793934949, 0.09695119646494277, 0.26929757616017014, 0.1177238579839468, 0.18723165791016072, 0.12502381548983976, 0.10314824088709429, 0.20593426917912439, 0.1824336583376862, 4.336616573855281, 54.378448873758316, 51.2902557849884, 40.87298557162285, 46.20773211121559, 58.20068657398224, 24.779207557439804, 1.7059055180288851, 0.26038865733426064, 0.30679770454298705, 1.5432577393949032, 11.16674579679966, 14.027230404317379, 9.317085798829794, 3.282906753011048, 1.1659595975652337, 1.1898288480006158, 7.546758418902755, 37.22550809383392, 66.2536096572876, 67.64428943395615, 64.37577322125435, 64.69771474599838, 58.826516792178154, 56.397337540984154, 60.36335952579975, 64.92688044905663, 64.3825900554657, 63.84045794606209, 60.439990013837814, 62.43786200881004, 60.58664694428444, 61.56094506382942, 60.73392704129219, 60.26999853551388, 61.111273393034935, 58.48860092461109, 59.37543913722038, 53.07445764541626, 50.65146066248417, 48.06287996470928, 48.52825619280338, 46.82628571987152, 48.79146806895733, 45.59639051556587, 45.59177756309509, 45.864333137869835, 49.91032563149929, 52.61831872165203, 57.19167731702328, 59.04635399580002, 61.45254448056221, 63.84085312485695, 58.50239038467407, 57.270678877830505, 62.45522327721119, 54.29640747606754, 52.443809285759926, 58.313608914613724, 61.738015562295914, 61.230537593364716, 58.825042471289635, 54.83519196510315, 49.57147501409054, 46.689781844615936, 46.30674719810486, 41.54201187193394, 44.23970751464367, 43.55002172291279, 45.17332881689072, 56.06797121465206, 59.17304299771786, 60.29137998819351, 54.29449237883091, 58.34016568958759, 58.773745223879814, 56.949109733104706, 53.526606783270836, 51.65138080716133, 52.64711357653141, 49.96273621916771, 48.273916840553284, 42.17358738183975, 46.557689532637596, 55.98386652767658, 57.362337559461594, 55.9851698577404, 53.29544998705387, 56.73863522708416, 55.28441525995731, 54.80066701769829, 55.99981427192688, 52.783875837922096, 52.06932418048382, 54.49295572936535, 54.86203372478485, 54.01247911155224, 55.414459481835365, 39.92134563624859, 16.165457367897034, 1.2180735636502504, 0.9917539078742266, 6.156147038564086, 4.1237234976142645, 6.408395078033209, 5.558189274743199, 8.907245490700006, 1.673513799905777, 0.37059868569485843, 0.4548242536839098, 1.1908784229308367, 21.9555239751935, 47.83829681575298, 46.59153051674366, 32.138690650463104, 47.52001449465752, 18.045248799026012, 0.16228244901867583, 0.1679621497169137, 0.1321339761489071, 0.13458649220410734, 0.0980790531320963, 0.07583944025100209, 0.11965545316343196, 0.09219857180141844, 0.10387924892711453, 0.11376281545381062, 0.21329475624952465, 0.12958279898157343, 0.15356129355495796, 0.12997631536563858, 0.16250841814326122, 0.2205171444802545, 0.1944289170205593, 0.1100198678614106, 0.12216837261803448, 0.11008845714968629, 0.20543695602100343, 0.08406157561694272, 0.1594735388061963, 0.2899612532928586, 0.11102362259407528, 0.12703985965345055], [0.05722659916500561, 0.061881056244601496, 0.133496351481881, 0.02348192356294021, 0.02092612281558104, 0.020289881467761006, 0.11082762881414965, 0.06028896394127514, 0.03158958636049647, 0.017761028102540877, 0.04152076908212621, 0.039055027955328114, 0.0652668638213072, 0.05495800214703195, 0.03640396142145619, 0.03770349911064841, 0.053340572922024876, 0.06450159082305618, 0.02518469606002327, 0.020866890154138673, 0.05391367791162338, 0.02835615840012906, 0.032167066310648806, 0.03199852457328234, 0.04995375231374055, 0.06084833919885568, 0.08403929634368978, 0.026384823067928664, 0.03861098986817524, 0.03822232341917697, 0.042225972647429444, 0.023698293007328175, 0.09844462023465894, 0.019684097860590555, 4.108937541022897, 36.788774728775024, 34.94292877614498, 29.408345259726048, 37.02101446688175, 52.537139877676964, 19.46529719978571, 1.853333213366568, 0.16650547710014507, 0.21202099334914237, 0.2106853947043419, 5.915436604991555, 6.759013663977385, 0.4014507739339024, 0.7759616465773433, 0.2781500027049333, 0.8069780759979039, 9.275293741375208, 40.86858540773392, 62.380846068263054, 64.08399447798729, 60.37628263235092, 61.19849771261215, 56.17606021463871, 55.18272891640663, 57.65872545540333, 63.340651765465736, 64.18005332350731, 62.158595994114876, 59.1549863666296, 58.05176116526127, 58.67147371172905, 58.5405745357275, 56.004047244787216, 57.76985429227352, 58.1393388658762, 53.948384150862694, 54.18978899717331, 47.27257177233696, 43.50343622267246, 45.00407449901104, 43.750267177820206, 42.589117884635925, 43.789241686463356, 42.91910357773304, 42.893211767077446, 44.02634136378765, 46.944155395030975, 50.45697569847107, 56.84008598327637, 57.19605088233948, 59.593790620565414, 58.62322010099888, 54.52178858220577, 43.05546686053276, 46.252463310956955, 53.49205143749714, 56.89783528447151, 54.79829214513302, 56.070623472332954, 57.555013820528984, 54.782287403941154, 49.74004916846752, 42.031395211815834, 39.97355103492737, 39.383317306637764, 40.93815587460995, 40.099312886595726, 45.140278190374374, 54.38816115260124, 54.24463905394077, 56.100087091326714, 56.277294382452965, 57.43416130542755, 54.65638875961304, 50.7612519711256, 44.060680121183395, 48.259416818618774, 45.823447331786156, 47.15149886906147, 43.133298084139824, 39.58102449774742, 39.696663692593575, 51.83596730232239, 52.245566323399544, 53.248256519436836, 50.801883190870285, 55.46985290944576, 53.46427112817764, 55.323081985116005, 51.62138521671295, 51.61252409219742, 51.2301392108202, 52.229325994849205, 51.18202619254589, 53.79850119352341, 37.38954909145832, 14.016597624868155, 1.5434366860426962, 0.1620751226437278, 2.848499813117087, 1.8650485784746706, 5.36759577691555, 2.0991930831223726, 5.660236598923802, 1.6792024509049952, 0.13591322960564867, 0.05886397360882256, 0.6900518189650029, 18.2935331761837, 39.0141861140728, 37.92358383536339, 21.61115225404501, 27.935012318193913, 23.66242278367281, 1.2494912277907133, 0.07646295562153682, 0.017257067156606354, 0.016774355754023418, 0.12310048041399568, 0.03145329836115707, 0.04082069004653022, 0.019705904014699627, 0.020195986799080856, 0.017562692846695427, 0.07775009202305228, 0.010296425134583842, 0.09489364398177713, 0.038687252963427454, 0.09717344000819139, 0.10197201103437692, 0.027350746822776273, 0.118230633524945, 0.07428932382026687, 0.06628132032346912, 0.026331538720114622, 0.027062626541010104, 0.010549880626058439, 0.014219911281543318, 0.056921799114206806, 0.04093314768397249, 0.12558974762214348, 0.027642889544949867, 0.04329447605414316, 0.047089236686588265, 0.01181947822260554, 0.061617341489181854, 0.029491427267203107, 0.11590755544602871, 0.03821528414846398, 0.037974679871695116, 0.07874376096879132, 0.0358959427830996, 0.020264347876945976, 0.030357548857864458, 0.05426532974524889, 0.08373094882699661, 0.04214915294141974, 0.053062237857375294, 0.04056393663631752, 0.04883390342001803, 0.013897921235184185, 0.029111889234627597, 0.023389630077872425, 0.05603186757070944, 0.04323487417423166, 0.056539426077506505, 0.06290774705121294, 0.040094146024785005, 0.01688141426711809, 0.08689770038472489, 0.07326409875531681, 0.053259563792380504, 0.05906814585614484, 0.06927430542418733, 0.11549053524504416, 10.474206358194351, 46.19319789111614, 35.04920907318592, 29.300913624465466, 44.87589217722416, 59.293203949928284, 17.625116743147373, 1.8485845369286835, 0.018266543847857974, 0.1400951575487852, 0.20406945986906067, 3.1845378689467907, 6.31771151907742, 2.239220319315791, 1.885821707546711, 0.8852614753413945, 1.4310421608388424, 13.658138159662485, 46.66192553937435, 66.64131045341492, 64.8232752084732, 61.430365070700645, 62.28636413812637, 56.00053623318672, 57.61842101812363, 59.83665078878403, 65.46268969774246, 61.80346705019474, 63.0105634778738, 59.969058483839035, 58.45778077840805, 59.47657071053982, 60.9940230846405, 58.177340626716614, 59.186247289180756, 59.68709461390972, 56.3934351503849, 55.29233783483505, 49.087437987327576, 44.82406295835972, 46.260454282164574, 45.583642199635506, 45.21684028208256, 45.31871281564236, 44.215290024876595, 43.61043468117714, 47.658091485500336, 48.69585379958153, 54.3431031703949, 57.35516734421253, 59.25738327205181, 60.77857084572315, 60.05300357937813, 52.98536762595177, 45.00328794121742, 48.662168607115746, 54.00600805878639, 56.48010849952698, 56.51834964752197, 58.14264848828316, 58.22420731186867, 55.52366562187672, 51.34852185845375, 43.85766841471195, 42.3203507065773, 40.885809883475304, 43.28129634261131, 42.185955718159676, 47.38474555313587, 55.12434504926205, 57.62924663722515, 57.18071490526199, 56.35366648435593, 58.11129257082939, 57.53716617822647, 52.3637817800045, 47.77008667588234, 49.535430148243904, 47.54374422132969, 48.750741854310036, 44.92139853537083, 42.14339420199394, 42.47775726020336, 52.06426665186882, 54.98834274709225, 54.1077172011137, 51.06891766190529, 55.73478989303112, 54.21938180923462, 55.83571247756481, 53.93177904188633, 52.42437332868576, 52.9855652153492, 53.89930218458176, 51.86303324997425, 55.58754399418831, 42.98481345176697, 16.618590652942657, 2.259371825493872, 1.309685935266316, 4.197243377566338, 3.734934297390282, 2.587701282463968, 3.5544779431074858, 1.2046773824840784, 0.13296902587171644, 0.0373467784083914, 0.059762194941868074, 0.718900702195242, 16.241624280810356, 43.574044033885, 42.26034052670002, 27.016766890883446, 30.813981033861637, 30.84824949502945, 2.3386956565082073, 0.06354859899147414, 0.03305000682303216, 0.037087408927618526, 0.027572391081776004, 0.04693261755164713, 0.03641669296484906, 0.0355650710844202, 0.027849820726260077, 0.014344012288347585, 0.07378592505119741, 0.010095641719090054, 0.05401941169111524, 0.07578357879538089, 0.03516825214319397, 0.031039987043186557, 0.04964675921655726, 0.03103391070908401, 0.023381106511806138, 0.019587217902881093, 0.012441259750630707, 0.03627010766649619, 0.029653872261405922, 0.08433839670033194, 0.041137338484986685, 0.0608819102490088, 0.0690847980149556, 0.10771161047159694, 0.10294198320480064, 0.27029716002289206, 0.08221952797612175, 0.1682663560495712, 0.20329989725723863, 0.4356023913715035, 0.18613077088957652, 0.06554951818543486, 0.15149650513194501, 0.13081871235044673, 0.12670743686612695, 0.1514439907623455, 0.1667222287505865, 0.15539674350293353, 0.13887269189581275, 0.17620469414396212, 0.22337767848512158, 0.21971673821099102, 0.09227944363374263, 0.16096245031803846, 0.21872867248021066, 0.11307340479106642, 0.17113119451096281, 0.30183840659447014, 0.17455481080105528, 0.16329000354744494, 0.11527828843099996, 0.1850846246816218, 0.18126995593775064, 0.13217074214480817, 0.15753023995785043, 0.26598436175845563, 0.22935306566068903, 8.112294897437096, 56.759914085268974, 46.80943742394447, 38.971373811364174, 47.18335635960102, 65.08310526609421, 26.649565994739532, 2.917268523015082, 0.3183865483151749, 0.34963164827786386, 0.8934910024981946, 10.991877280175686, 17.785888016223907, 4.353197459131479, 2.2612102143466473, 1.4235904044471681, 1.1993912723846734, 12.079756055027246, 44.3575581908226, 66.66811421513557, 68.17357063293457, 63.60351786017418, 64.61850419640541, 60.053463354706764, 60.27214542031288, 61.94506265223026, 68.26752439141273, 67.21548244357109, 65.23242965340614, 61.41111150383949, 60.81992022693157, 61.08887739479542, 61.70069396495819, 60.2005610615015, 62.36703380942345, 64.8760923743248, 58.03479127585888, 59.18963670730591, 51.11366406083107, 47.34431952238083, 48.4767347574234, 48.27956713736057, 46.71445772051811, 48.53256896138191, 47.045727744698524, 46.40564829111099, 48.80968429148197, 51.75334833562374, 55.93020960688591, 60.50867132842541, 60.295400172472, 61.95684961974621, 61.32634185254574, 55.69561779499054, 44.2814064770937, 49.89177882671356, 55.676869601011276, 55.81800162792206, 58.37591417133808, 58.9919713139534, 61.38315260410309, 59.34860497713089, 54.07871715724468, 46.08876049518585, 43.691818714141846, 43.524551689624786, 44.68330331146717, 45.590117052197456, 50.38229450583458, 57.396972700953484, 60.243464559316635, 59.28441882133484, 56.91455438733101, 60.93576841056347, 60.443960800766945, 54.523870870471, 48.18719029426575, 52.02778480947018, 49.361817464232445, 51.7721763253212, 46.6324657201767, 46.43103092908859, 43.71294558048248, 54.706473872065544, 56.629622876644135, 55.08916273713112, 52.26290859282017, 56.21167190372944, 54.18682515621185, 57.47543469071388, 55.31615875661373, 54.18421849608421, 55.63390530645847, 55.76097808778286, 54.76290084421635, 57.32752002775669, 39.27625425159931, 16.659275069832802, 1.9679744867607951, 1.0223992634564638, 6.905644470825791, 7.712702639400959, 10.93865068629384, 6.785591812804341, 13.221645131707191, 3.784129307605326, 0.5586963705718517, 0.14392328885151073, 1.37853265972808, 26.195098981261253, 51.280562505126, 48.44874545931816, 33.23863662779331, 39.27797555923462, 34.34093087911606, 2.0790009666234255, 0.3120584035059437, 0.11604086001170799, 0.16152363270521164, 0.13638174743391573, 0.10835888198926114, 0.11785090624471195, 0.06812734587583691, 0.07718240842223167, 0.08639847990707494, 0.17597163008758798, 0.12543244200060144, 0.1992681503179483, 0.1401514865574427, 0.18411509779980406, 0.27954013436101377, 0.14167594694299623, 0.22702911926899105, 0.18516968964831904, 0.173098063969519, 0.1440616845502518, 0.16028690297389403, 0.10353599820518866, 0.14362957648700103, 0.09704030613647774, 0.2565403841435909, 0.18491626105969772], [0.047060407960088924, 0.012884126172139077, 0.01919382582855178, 0.006695858110106201, 0.015000483654148411, 0.005507297937583644, 0.09397475383593701, 0.023620807223778684, 0.04947809131408576, 0.06579436754691415, 0.1463602198055014, 0.05226563138421625, 0.01927996134327259, 0.06717350799590349, 0.007943610125948908, 0.043777209721156396, 0.015138531471166061, 0.058840725832851604, 0.022007040497555863, 0.04155980976065621, 0.03701093060954008, 0.022400606976589188, 0.05819063415401615, 0.1175824120582547, 0.027543497417354956, 0.04425440696650185, 0.04131671186769381, 0.12665671849390492, 0.04366409899375867, 0.02168701157643227, 0.04897158665698953, 0.06195479603775311, 0.0996223343827296, 0.05257151868136134, 0.1829270232701674, 7.066148333251476, 42.170596942305565, 37.12518587708473, 29.0730569511652, 36.52421772480011, 48.98999981582165, 25.949449762701988, 3.797432156279683, 0.3894547582603991, 0.15657291398383677, 2.4269395088776946, 6.872801883146167, 2.847733204253018, 1.2422676966525614, 0.3062771027907729, 0.06816838664235547, 0.1800822970108129, 11.412887088954449, 49.61061671376228, 65.51790073513985, 61.05321630835533, 60.29223874211311, 58.30807641148567, 58.385143876075745, 55.10853789746761, 58.965015560388565, 63.173323944211006, 63.62548068165779, 60.11113665997982, 59.10998538136482, 57.695157900452614, 60.58762349188328, 59.425212666392326, 58.8772364705801, 59.740546345710754, 58.1097574532032, 56.2605182826519, 48.743434846401215, 43.33811089396477, 45.2602681517601, 43.6796897649765, 44.737742990255356, 41.959183886647224, 43.0912571400404, 43.31992506980896, 42.1758558601141, 43.784533739089966, 45.42752377688885, 53.519531562924385, 56.96072570979595, 58.78692291676998, 55.569643154740334, 67.16465637087822, 52.49057337641716, 36.15008220076561, 47.202507331967354, 57.38962009549141, 58.069886192679405, 56.276895403862, 58.59951697289944, 55.011810287833214, 53.26937198638916, 44.02701772749424, 41.343803107738495, 40.52810087800026, 43.10968615114689, 39.230166524648666, 49.110787734389305, 55.184043645858765, 55.17049357295036, 55.80492652952671, 56.06248810887337, 55.26278302073479, 51.01204231381416, 47.24644437432289, 48.31259496510029, 49.721494764089584, 49.661400988698006, 47.34494648873806, 46.37206569314003, 43.50559450685978, 39.754580184817314, 45.821490436792374, 54.42051641643047, 53.97942088544369, 51.69716075062752, 51.55046962201595, 53.09494234621525, 53.46427112817764, 53.198030814528465, 56.050549149513245, 55.159793347120285, 54.91165146231651, 50.196150094270706, 39.761218428611755, 15.695294346660376, 0.4919962934218347, 0.2629328583134338, 1.1287432070821524, 2.896879054605961, 2.428133594803512, 2.286909422837198, 1.4919148944318295, 1.3114054617471993, 0.17549577984027565, 0.03317409020382911, 0.7615336426533759, 22.015946432948112, 39.23840448260307, 34.83406461775303, 42.51482427120209, 26.03978231549263, 30.355448238551617, 5.073463534936309, 0.08301828667754307, 0.04258962129824795, 0.032508743679500185, 0.012557096943055512, 0.03527134387695696, 0.020741417101817206, 0.009154391591437161, 0.08118740093777888, 0.026367768514319323, 0.04620405117748305, 0.01851564386015525, 0.058455840626265854, 0.05819862708449364, 0.015056006504892139, 0.042028420357382856, 0.04279402732208837, 0.07693944411585107, 0.018883632219512947, 0.10838041169336066, 0.018714112702582497, 0.01601608491910156, 0.024183971145248506, 0.05166668110177852, 0.018505021871533245, 0.025158457428915426, 0.06817820525611751, 0.0350400795286987, 0.042558577260933816, 0.048923554859356955, 0.018824429243977647, 0.032594858785159886, 0.0662606515106745, 0.028147449775133282, 0.018662500042410102, 0.093348863592837, 0.078783050266793, 0.023986619235074613, 0.014229473854356911, 0.08707600136403926, 0.009677178040874423, 0.06280007626628503, 0.0038395640876842663, 0.03533104223606642, 0.04029867450299207, 0.043330366315785795, 0.010976112735079369, 0.06055505727999844, 0.03326831698359456, 0.014482068454526598, 0.09894588903989643, 0.04587352086673491, 0.03848563370411284, 0.037357958863140084, 0.06114258590969257, 0.04491179766773712, 0.045366140475380234, 0.07268241082783788, 0.07533880969276652, 0.04192357344436459, 0.10544165532337502, 0.0879286474082619, 0.17061366525013, 15.49734776839614, 50.57635389268398, 38.39903712272644, 30.21702166646719, 46.83188281953335, 58.67129512131214, 23.25622458010912, 3.2534979935735464, 0.21047743008239195, 0.016672919009579346, 0.28642613673582673, 2.0865072263404727, 3.383517754264176, 2.6285020681098104, 1.0332663240842521, 0.08266334712971002, 0.43147067714016885, 14.862045608460903, 54.18485686182976, 68.5894963145256, 63.56012038886547, 63.9789605140686, 60.67615494132042, 58.47369812428951, 58.1365118175745, 61.42025761306286, 64.6534775197506, 65.39718121290207, 60.88252566754818, 60.706549510359764, 60.331779420375824, 60.2466943860054, 61.80776461958885, 61.06096789240837, 61.39811620116234, 60.72836793959141, 58.22233781218529, 50.348651111125946, 46.55917525291443, 47.6664624363184, 46.594270169734955, 45.15125200152397, 43.80235098302364, 44.34435769915581, 45.32632760703564, 44.405454620718956, 46.65584586560726, 48.92945386469364, 56.64360612630844, 59.75221171975136, 61.05931498110294, 58.669007644057274, 67.74081945419312, 51.592274978756905, 37.34414152801037, 49.543208330869675, 55.26499830186367, 59.57475744187832, 58.49010184407234, 61.51395298540592, 55.53133741021156, 54.22084853053093, 44.28615242242813, 42.132925763726234, 43.42820405960083, 43.887177631258965, 41.92572668194771, 51.581719145178795, 57.77097903192043, 55.74037939310074, 57.06931248307228, 56.87678821384907, 58.63680437207222, 54.09584283828735, 48.348548635840416, 49.81392100453377, 49.701659828424454, 52.297824919223785, 49.825734570622444, 47.780646309256554, 44.42085139453411, 41.52708247303963, 47.12252922356129, 56.13906919956207, 56.9107735902071, 53.707260489463806, 53.612417578697205, 54.343323558568954, 54.80193614959717, 54.566322192549706, 55.78129179775715, 55.48692539334297, 54.59965780377388, 54.35318782925606, 43.16413342952728, 17.939302884042263, 1.4266034052707255, 0.5647319904528558, 2.5054717948660254, 4.795775385573506, 4.470567461103201, 5.412480868399143, 1.8820051685906947, 0.1684682202176191, 0.2978329168399796, 0.027988145920971874, 0.6307900208048522, 17.72683158516884, 48.21208655834198, 42.500544637441635, 44.39164616167545, 27.617666646838188, 35.769399628043175, 8.886540401726961, 0.07234164630062878, 0.10939737665466964, 0.036291908254497685, 0.04787485937413294, 0.009347622726636473, 0.01810834393836558, 0.039071188220987096, 0.07439510212861933, 0.07589989560074173, 0.04892123193712905, 0.04261779693479184, 0.06609649586607702, 0.049729004022083245, 0.08548117795726284, 0.0033729336337273708, 0.11315046198433265, 0.11609763430897146, 0.0143676459811104, 0.05054620138253085, 0.023376319659291767, 0.002468695106472296, 0.018192603674833663, 0.032664090031175874, 0.07395946144242771, 0.05898132571019232, 0.10006618322222494, 0.05546592059545219, 0.14036964828846976, 0.189658050367143, 0.1347479983814992, 0.07975469226948917, 0.09925718288286589, 0.14866702258586884, 0.28923991543706506, 0.1586458957171999, 0.1458115054992959, 0.15084568614838645, 0.15152093663346022, 0.28960870346054435, 0.11608180429902859, 0.14319224370410666, 0.09221368934959173, 0.20586812897818163, 0.17306937254033983, 0.20249028835678473, 0.12607189128175378, 0.10323378824978136, 0.15382959478301927, 0.15521729219472036, 0.15683290315791965, 0.14226197643438354, 0.1250251810415648, 0.1695008741808124, 0.0865326082566753, 0.22866064187837765, 0.13314632495166734, 0.18773989548208192, 0.1443632785230875, 0.20181083731586114, 0.21390208537923172, 0.16924297786317766, 0.3269796387758106, 15.70019418373704, 59.71735239028931, 49.719720259308815, 38.85247439146042, 47.11120583117008, 60.508325546979904, 34.52623933553696, 5.378602836281061, 0.3587788558797911, 0.39369058096781373, 3.7904201075434685, 16.166369318962097, 7.5095028430223465, 6.039159866049886, 0.9111200971528888, 0.4979580547660589, 0.707981038140133, 13.771278038620949, 55.06527341902256, 68.27200815081596, 65.73484629392624, 66.26225799322128, 62.316542118787766, 64.80161637067795, 59.656612649559975, 63.82595032453537, 70.21371155977249, 67.42770865559578, 63.670033290982246, 60.761388167738914, 61.87385067343712, 62.641994655132294, 64.70936492085457, 64.12763893604279, 65.25012150406837, 63.16553056240082, 60.39060406386852, 53.944371566176414, 48.833816796541214, 48.80882553756237, 48.76567505300045, 48.381226882338524, 45.21545335650444, 46.80685356259346, 48.11374023556709, 46.68324239552021, 48.05692948400974, 49.998807683587074, 58.892238065600395, 61.327762976288795, 64.72736835479736, 59.917214065790176, 72.5701779127121, 54.19047676026821, 38.40244933962822, 51.1828887462616, 56.55539385974407, 61.41321279108524, 59.516346976161, 61.85982182621956, 58.85587401688099, 57.43025131523609, 47.506669610738754, 44.87174279987812, 44.61999490857124, 45.983365550637245, 43.24177086353302, 53.6287073045969, 59.02678124606609, 57.56032593548298, 56.82337827980518, 59.06488940119743, 61.15887723863125, 57.043770253658295, 50.91775797307491, 53.64936299622059, 53.321949765086174, 54.015176966786385, 51.67925611138344, 51.1532199382782, 47.25623644888401, 43.97769637405872, 49.051480516791344, 58.76453831791878, 59.08180609345436, 53.971179127693176, 55.78489400446415, 53.57275150716305, 56.99741654098034, 54.66714598238468, 58.63570623099804, 56.714859902858734, 58.1325676292181, 53.542820513248444, 42.61266142129898, 17.503496669232845, 1.09701027860865, 0.3787646850105375, 2.5594106130301952, 6.024532075971365, 8.41146994382143, 7.201335104182363, 6.209992999210954, 4.148510517552495, 0.6665461615193635, 0.325784157612361, 1.316798678599298, 28.766308911144733, 50.8567750453949, 47.0262385904789, 52.42991343140602, 35.80267824232578, 43.47325824201107, 8.269007988274097, 0.17705948499497026, 0.2547735976986587, 0.10747993423137814, 0.13124471995979548, 0.10013595994678326, 0.18583408993436024, 0.12575983302667737, 0.1987273621489294, 0.2073304567602463, 0.09607920263078995, 0.09419409558176994, 0.1705848699202761, 0.14187886496074498, 0.26122689829207957, 0.09816713121836074, 0.11690549916238524, 0.1893845689482987, 0.13251766649773344, 0.15629229310434312, 0.1977592898765579, 0.09532771131489426, 0.09781266664504074, 0.11538890554220416, 0.12744179199216887, 0.11994441578281112, 0.19911111186956987, 0.07401992421364412], [0.0057680459576658905, 0.06669442940619774, 0.02639364349306561, 0.0658916259999387, 0.07443645459716208, 0.07453769096173346, 0.06604710593819618, 0.06957075631362386, 0.04694668867159635, 0.049943840931518935, 0.0323848681000527, 0.025605439986975398, 0.0672585358552169, 0.03435086182435043, 0.03564353093679529, 0.023172266155597754, 0.0243394269637065, 0.017147797043435276, 0.013134360742697027, 0.034036784927593544, 0.11969649392995052, 0.054987457988318056, 0.07349836509092711, 0.02704540685954271, 0.037468976734089665, 0.09091812957194634, 0.02828248168952996, 0.047382121556438506, 0.02233026250905823, 0.046332813799381256, 0.04717602343589533, 0.012714371023321291, 0.04372974937723484, 0.08908237534342334, 0.10326025323593058, 0.020238964571035467, 7.032794198021293, 40.01329690217972, 37.63180509209633, 28.18710409104824, 35.46163894236088, 48.378038853406906, 32.46998727321625, 6.563970604911447, 0.0357365702802781, 0.3972233523381874, 0.5101973761338741, 1.5664738998748362, 1.720575224608183, 0.8569525193888694, 0.22997704858426005, 0.15328736684750766, 0.12090148200513795, 8.281722106039524, 48.66722613573074, 66.78678184747696, 67.60941490530968, 63.58856186270714, 61.965817138552666, 60.01759707927704, 60.86695410311222, 60.06115414202213, 65.48428013920784, 61.75471566617489, 57.69680701196194, 58.653067499399185, 59.70679275691509, 58.32212805747986, 63.421686217188835, 60.18233723938465, 59.92020830512047, 59.11917708814144, 52.095937952399254, 42.20193766057491, 47.07619450986385, 46.321159824728966, 47.404299303889275, 44.986344650387764, 45.05062200129032, 43.16781923174858, 44.45561572909355, 42.822303771972656, 43.87911446392536, 46.222030743956566, 52.63995096087456, 55.90560592710972, 56.49270482361317, 52.3055575042963, 68.50837826728821, 44.38717760145664, 42.72534057497978, 58.49254131317139, 58.44021052122116, 59.820733442902565, 58.17128375172615, 54.66050773859024, 51.170839592814445, 43.050162345170975, 42.469219118356705, 43.955376371741295, 39.727594032883644, 44.03543807566166, 55.00767610967159, 55.779650285840034, 58.209969475865364, 55.01539349555969, 57.39920698106289, 56.2784381210804, 50.72912469506264, 46.4210070669651, 50.588197857141495, 51.46590895950794, 52.88865901529789, 51.02672852575779, 49.709491208195686, 44.9164853990078, 41.50855466723442, 43.403862565755844, 53.65273721516132, 53.72908651828766, 55.15469782054424, 54.1742592304945, 52.24500775337219, 53.0651443451643, 52.234710305929184, 53.70501860976219, 57.226266860961914, 48.96177113056183, 38.13769094645977, 13.250071406364441, 1.5199767448939383, 0.33876138157211244, 1.1737662786617875, 2.125577204860747, 3.434594376012683, 1.7671349574811757, 2.7142347302287817, 1.7214340972714126, 0.10001587303122506, 0.14915016072336584, 1.6109455260448158, 18.19159034639597, 47.43489906191826, 24.79492161422968, 34.06850449740887, 42.325507029891014, 27.70067509263754, 9.799645654857159, 0.03400328438146971, 0.022885055004735477, 0.012318439876253251, 0.05170643053133972, 0.09282064740546048, 0.01007768916679197, 0.060502335109049454, 0.0376882962154923, 0.055032465534168296, 0.013239025829534512, 0.05268068489385769, 0.09787577888346277, 0.02168100018025143, 0.08242701762355864, 0.01742801716318354, 0.032444974640384316, 0.046697122961631976, 0.05582999227044638, 0.06639132145210169, 0.0756554321560543, 0.013159086320229108, 0.04942873478285037, 0.09883183578494936, 0.033818048032117076, 0.048345922768930905, 0.023559973378723953, 0.04237101798935328, 0.055208925987244584, 0.009386225538037252, 0.019165787489328068, 0.030213039717637002, 0.034971716595464386, 0.07554197261924855, 0.06302834604866803, 0.04502219955611508, 0.12914825667394325, 0.05566374376940075, 0.032849378330865875, 0.03685296447656583, 0.023224598699016497, 0.007353547989623621, 0.08017207612283528, 0.014682050350529607, 0.02007897423027316, 0.024168844320229255, 0.019662560735014267, 0.040402523227385245, 0.016614181731711142, 0.014627144410042092, 0.026677501991798636, 0.05028191517340019, 0.04115615563932806, 0.05631696360069327, 0.06627410664805211, 0.02188875514548272, 0.026760427717817947, 0.04043496250233147, 0.016032132007239852, 0.06467258906923234, 0.1010866956494283, 0.01670973881118698, 0.023990318841242697, 0.08514776811352931, 0.2886588731780648, 14.336313419044018, 48.39752420783043, 38.13962124288082, 28.13733246177435, 41.08760945498943, 64.21865165233612, 32.380752861499786, 5.239567821845412, 0.10184433936956339, 0.28671729611232877, 0.20376149826915935, 1.2926832726225257, 2.7381525468081236, 3.0392984999343753, 1.083158478140831, 0.3476475609932095, 0.47708470607176423, 13.635296635329723, 52.8755459189415, 68.67064476013184, 68.50235179066658, 64.31738555431366, 63.72025899589062, 59.85504560172558, 62.29291498661041, 61.85697577893734, 65.92482849955559, 61.921028941869736, 59.782230108976364, 60.01122482120991, 61.584108620882034, 60.601443350315094, 63.578089624643326, 61.83147914707661, 61.61737963557243, 59.92746211588383, 54.18722793459892, 45.03005750477314, 48.26611965894699, 47.520124688744545, 49.053084030747414, 46.96111388504505, 46.65046535432339, 45.0177613645792, 45.32199203968048, 45.19333474338055, 47.05335393548012, 49.53355684876442, 55.18738366663456, 58.39709423482418, 57.587213292717934, 56.54082164168358, 68.82586643099785, 45.79618379473686, 45.45267842710018, 59.66757886111736, 60.11646397411823, 60.88627226650715, 59.64302457869053, 55.17267845571041, 53.18834513425827, 44.494369849562645, 45.401985347270966, 46.11836850643158, 42.58468732237816, 44.20194894075394, 56.22915476560593, 58.538682237267494, 59.916647896170616, 56.76913619041443, 59.68710221350193, 56.5116012096405, 52.1260741353035, 49.254705011844635, 53.32732267677784, 53.621825873851776, 55.14785058796406, 52.24929392337799, 50.636166483163834, 46.00701168179512, 42.79246397316456, 45.778168961405754, 55.726183354854584, 54.23441760241985, 56.00001186132431, 55.08817479014397, 53.214863911271095, 54.654139280319214, 53.96517924964428, 54.922389686107635, 59.21308144927025, 51.5169820189476, 38.9959204941988, 17.692452929913998, 2.67872991040349, 0.4525998589815572, 2.0850409800186753, 5.295957271009684, 5.974949961528182, 3.7900876253843307, 2.6175401313230395, 0.4250890086404979, 0.10499143143533729, 0.1985423150472343, 1.2154699908569455, 16.281058564782143, 57.581099420785904, 34.33267392218113, 37.70907014608383, 43.99956800043583, 32.161037251353264, 16.65568996220827, 0.14074226579396054, 0.06771342043066397, 0.039475235680583864, 0.03840999401290901, 0.06155405855679419, 0.03502817919070367, 0.04781603303854354, 0.07648444821825251, 0.04885517337243073, 0.10307076809112914, 0.035004122473765165, 0.028042986923537683, 0.04011558667116333, 0.08342714325408451, 0.03645512137154583, 0.05479724182805512, 0.04406048377859406, 0.022339186834869906, 0.022374988038791344, 0.013150790036888793, 0.06129702313046437, 0.057489928003633395, 0.03348370308231097, 0.029948033625259995, 0.07720508845523, 0.03155612292175647, 0.06056264945073053, 0.013660366257681744, 0.10975792683893815, 0.09346809703856707, 0.12393036478897557, 0.12549424805911258, 0.11891457455931231, 0.2642336650751531, 0.16085604118416086, 0.16668578929966316, 0.09418930872925557, 0.0999458588194102, 0.0928133372508455, 0.12657551269512624, 0.14454851858317852, 0.14006904879352078, 0.17071342474082485, 0.09311573274317198, 0.0815346444142051, 0.09546418485115282, 0.13345621613552794, 0.16734915057895705, 0.15146618097787723, 0.13519969914341345, 0.12627176649402827, 0.08078077822574414, 0.14648401003796607, 0.16060371097410098, 0.21517225628485903, 0.11561702689505182, 0.11031775851733983, 0.14906055381288752, 0.15805228147655725, 0.24771589203737676, 0.10423979168990627, 0.14878637477522716, 0.1802993900491856, 0.4449648514855653, 12.406143341213465, 57.23882518708706, 49.05396558344364, 39.647254943847656, 44.377514719963074, 60.74749991297722, 42.260705307126045, 9.276715815067291, 0.19722440920304507, 0.808137726271525, 1.4788954867981374, 7.192209418863058, 8.381394557654858, 3.840830340050161, 0.9334520332049578, 0.4583346418803558, 0.5626558768562973, 10.496779046952724, 52.676580995321274, 71.2716355919838, 72.11999326944351, 69.6017923951149, 66.12013041973114, 63.261597007513046, 65.71165233850479, 64.29140254855156, 68.01456436514854, 63.7892746925354, 59.696084931492805, 61.521913558244705, 64.15340155363083, 63.703809678554535, 68.16920846700668, 64.38466474413872, 63.976870626211166, 62.47387267649174, 55.58491073548794, 45.702545419335365, 52.17696100473404, 49.90062095224857, 51.181300431489944, 50.55495344102383, 48.04103873670101, 47.38623887300491, 49.775588661432266, 47.74452544748783, 49.819012731313705, 50.71482226252556, 55.71510314941406, 60.951089188456535, 60.585769191384315, 57.281295508146286, 71.79163008928299, 50.259184911847115, 46.48169361054897, 58.769706040620804, 61.105638295412064, 62.17029556632042, 60.092369467020035, 56.74848049879074, 55.300537794828415, 46.90165467560291, 47.22899571061134, 48.38118888437748, 44.267024248838425, 48.51397655904293, 59.458612874150276, 59.51637737452984, 61.72447308897972, 56.945575922727585, 62.91541278362274, 60.710683688521385, 54.34354394674301, 51.18508502840996, 55.008759051561356, 54.864146411418915, 57.49053128063679, 54.63146589696407, 53.27401153743267, 48.54826211929321, 46.2802854180336, 47.571592926979065, 58.591643795371056, 56.3681361079216, 57.95731723308563, 55.8813252300024, 55.5179887264967, 54.83843319118023, 54.401395842432976, 54.38374198973179, 59.1801106184721, 51.51292763650417, 38.98806631565094, 15.670048501342535, 2.0149649027734995, 0.46061941771768034, 3.1729299668222666, 7.085162987932563, 10.326650775969028, 7.020451985299587, 8.72701071202755, 6.734984703361988, 0.6669961998704821, 0.3027431439841166, 2.6096752658486366, 25.479209795594215, 58.13304640352726, 37.24952280521393, 44.7193443775177, 49.00964476168156, 42.207272574305534, 16.868999116122723, 0.2270438286359422, 0.2725515078054741, 0.0950372198713012, 0.18854940048186108, 0.22718391643138602, 0.1711739125312306, 0.19769420352531597, 0.1931501372018829, 0.1474812487140298, 0.2165654455893673, 0.16137809754582122, 0.21005100687034428, 0.15722000738605857, 0.19933679897803813, 0.11095260648289695, 0.13823759160004556, 0.1080108444148209, 0.1391820635762997, 0.08743363490793854, 0.15332382114138454, 0.16116965794935822, 0.10896604784647934, 0.1514044639770873, 0.1320382984704338, 0.1619103064876981, 0.07371910207439214, 0.1873047446133569, 0.1879253433435224], [0.027790499007096514, 0.043381893628975376, 0.07224895205581561, 0.06930138639290817, 0.03985747513070237, 0.03135530147119425, 0.0988008659624029, 0.058872745794360526, 0.01963610131497262, 0.016190465503314044, 0.049366197708877735, 0.0703194497327786, 0.0061528922014986165, 0.024904294114094228, 0.0674395976238884, 0.02044788470811909, 0.03931680570531171, 0.016305292447214015, 0.06343514687614515, 0.03148853182210587, 0.086922198679531, 0.04229377896990627, 0.02589211864687968, 0.0454653878841782, 0.02132709778379649, 0.042789225626620464, 0.0319169773865724, 0.05559168494073674, 0.04198041082418058, 0.03935217275284231, 0.03114195256785024, 0.07032012508716434, 0.014487792268482735, 0.08192382665583864, 0.0361860705743311, 0.07283103332156315, 0.11262947431532666, 10.15396524220705, 38.220788687467575, 38.18887040019035, 29.45636138319969, 22.370832189917564, 46.95663772523403, 42.00557179749012, 5.732770906761289, 0.31494230031967163, 0.06631092459429055, 1.3000191352330148, 1.3075985410250723, 1.855062476824969, 0.8244932955130935, 0.21989712462527677, 0.2442832660744898, 0.39974600134883076, 9.626424349844456, 44.28849309682846, 64.99322488904, 65.93042179942131, 63.73311370611191, 61.231970116496086, 62.539453357458115, 58.26277144253254, 62.879949286580086, 62.88223296403885, 58.66858206689358, 58.28996658325195, 60.598639100790024, 62.3708526045084, 60.320459827780724, 59.59503315389156, 58.7587284296751, 60.97079113125801, 52.03703351318836, 45.811234787106514, 50.68934842944145, 53.408756107091904, 55.46264469623566, 52.26307198405266, 50.99860243499279, 48.60603801906109, 47.64284670352936, 41.876675114035606, 44.57393378019333, 44.78944681584835, 49.72328066825867, 50.07096201181412, 60.33860005438328, 55.94625994563103, 64.06259402632713, 45.4333982616663, 42.18757823109627, 63.0866239964962, 58.63827109336853, 60.71611359715462, 58.289180025458336, 57.66754098236561, 50.59864729642868, 42.73431949317455, 42.93136551976204, 44.86316666007042, 49.38161060214043, 53.98479379713535, 54.57248166203499, 57.10747003555298, 57.795951291918755, 56.465296894311905, 56.91325105726719, 54.17079381644726, 49.064335227012634, 53.09267766773701, 53.5360074788332, 55.319616571068764, 53.18503551185131, 54.03554007411003, 51.657699868083, 49.79786306619644, 46.44833140075207, 42.9662324488163, 48.664843663573265, 54.441141709685326, 57.5170386582613, 57.76627108454704, 56.13455504179001, 51.448418498039246, 56.32276274263859, 51.34977199137211, 47.643393874168396, 38.050261437892914, 12.72868998348713, 1.159010126721114, 0.5091381829697639, 0.8629241958260536, 1.3775663240812719, 3.6996985506266356, 4.064012551680207, 4.5177086815238, 4.68627143651247, 0.10285431329975836, 0.11905291830771603, 0.8301499451044947, 20.51143616437912, 42.615313678979874, 28.179907277226448, 23.541665263473988, 33.114539086818695, 29.831349961459637, 10.507944747805595, 0.22059189359424636, 0.06149624525278341, 0.020560451812343672, 0.01870765416242648, 0.029123600324965082, 0.0809372823277954, 0.026884900726145133, 0.019534028178895824, 0.0411894112767186, 0.05189219009480439, 0.026852331575355493, 0.02023006436502328, 0.09170585995889269, 0.0833542420878075, 0.05192310054553673, 0.06437358519178815, 0.05374375206883997, 0.05926199854002334, 0.01759419887093827, 0.05772785312728956, 0.03142318571917713, 0.08043033609283157, 0.06267637509154156, 0.04239986898028292, 0.015204357187030837, 0.04341907151683699, 0.10739684337750077, 0.01819604167394573, 0.012860843144153478, 0.017525839648442343, 0.03485178924165666, 0.09235904639353976, 0.028274824580876157, 0.031257152440957725, 0.03073470088565955, 0.067298352078069, 0.13306943845236674, 0.024965007360151503, 0.02939610025350703, 0.06742126657627523, 0.06272251441259868, 0.03453206460108049, 0.01886680216557579, 0.09550711809424683, 0.006830672946307459, 0.04046045898576267, 0.027312537349644117, 0.022909519902896136, 0.058902925229631364, 0.041016049290192313, 0.019100818026345223, 0.01836823848861968, 0.030545562694896944, 0.027710332215065137, 0.05514855969522614, 0.04753814326249994, 0.02999395215738332, 0.03580071039323229, 0.05913166627578903, 0.04411682763020508, 0.06766202670405619, 0.026184766029473394, 0.02717578550800681, 0.029937348554085474, 0.09683183685410768, 0.30360207601916045, 16.538867130875587, 47.80045464634895, 40.88180109858513, 31.89175710082054, 29.920856058597565, 61.3083878159523, 43.01959678530693, 4.154743133112788, 0.19971832225564867, 0.231599724793341, 0.3899226081557572, 0.47510513104498386, 3.7908955570310354, 2.7652676543220878, 0.9381222794763744, 0.7965303584933281, 0.7496241910848767, 15.50493311136961, 51.65876001119614, 67.77912899851799, 67.52493783831596, 65.03138244152069, 63.420246094465256, 65.23217886686325, 59.95490424335003, 64.87119823694229, 64.15130406618118, 58.81355568766594, 58.24852220714092, 62.670850306749344, 62.485971227288246, 62.66197018325329, 61.979253217577934, 61.5688144415617, 62.45006315410137, 55.2250662446022, 47.62040130794048, 52.21424460411072, 53.88439938426018, 56.54225416481495, 53.50126974284649, 50.712299197912216, 49.25807163119316, 48.41378353536129, 44.35222327709198, 47.64788903295994, 48.06367412209511, 51.16708919405937, 54.54125493764877, 61.99827879667282, 57.71973878145218, 65.55187091231346, 46.188562139868736, 42.94072061777115, 61.348137483000755, 58.90762723982334, 62.36961767077446, 60.799025148153305, 59.328633248806, 53.024767711758614, 44.79276403784752, 44.20285329222679, 46.24009497463703, 48.19877587258816, 55.15242554247379, 57.820630967617035, 59.29226540029049, 58.68844360113144, 57.3629455268383, 58.01910951733589, 56.47443540394306, 50.52000291645527, 54.29486855864525, 56.21385678648949, 57.196176275610924, 55.38259819149971, 54.64513376355171, 53.04935239255428, 50.11728532612324, 46.037132665514946, 46.616118997335434, 50.580541267991066, 58.081718757748604, 58.82345795631409, 58.24333168566227, 56.12323924899101, 53.77634838223457, 57.81283378601074, 52.700489312410355, 50.22683344781399, 41.29334941506386, 15.903866104781628, 1.8941969331353903, 1.4318429678678513, 1.5994582674466074, 2.2849204670637846, 9.2372340336442, 6.473149778321385, 1.9118256121873856, 0.15610396570991725, 0.25860515772365034, 0.0443924761202652, 0.20917499059578404, 19.122354201972485, 51.00269481539726, 36.20050169527531, 23.611079938709736, 37.175833359360695, 38.86701621115208, 16.412901990115643, 0.5199899850413203, 0.09049601823789999, 0.05058089678641409, 0.044034378734068014, 0.020972996862838045, 0.044642965804087, 0.008611768462287728, 0.06680302045424469, 0.04728807289211545, 0.018649132107384503, 0.03678137691167649, 0.053260369022609666, 0.06724321792717092, 0.030914176313672215, 0.01642274288315093, 0.06948934271349572, 0.05231049421126954, 0.05154972976015415, 0.04298909712815657, 0.07862908430979587, 0.0817950269265566, 0.028519920706457924, 0.09273057294194587, 0.039296845643548295, 0.003517245640978217, 0.04563906157272868, 0.04623847569746431, 0.04298218402254861, 0.06444485363317654, 0.16314592299750075, 0.14117996965069324, 0.18379527668002993, 0.19561393390176818, 0.13990178355015814, 0.08591364967287518, 0.14482639351626858, 0.28825781657360494, 0.12115048739360645, 0.17206199612701312, 0.07764640657114796, 0.1964606501860544, 0.20781168015673757, 0.1853028903133236, 0.1331573087372817, 0.17770453006960452, 0.10468748485436663, 0.13551193551393226, 0.1787328498903662, 0.15978779381839558, 0.18233688228065148, 0.1728733564959839, 0.09656050766352564, 0.1357361234840937, 0.068574920296669, 0.18831783556379378, 0.12148990863352083, 0.1969671214465052, 0.21752167318481952, 0.20215026597725227, 0.11431315506342798, 0.18084347335388884, 0.12872622697614133, 0.19886443682480603, 0.11075696893385611, 0.12510825705248863, 0.47460225177928805, 15.080454088747501, 55.45012816786766, 51.87186777591705, 41.16172827780247, 30.227539502084255, 58.84360447525978, 52.522700652480125, 8.45813523977995, 0.44755144394002855, 0.2782405150355771, 3.4657942643389106, 5.543693527579308, 6.5980505011975765, 3.1169033981859684, 1.152395869139582, 1.1591599811799824, 1.2408995325677097, 13.672603983432055, 48.99938151240349, 67.7417466044426, 69.2689074575901, 67.5273697078228, 66.18967428803444, 67.44875192642212, 62.9946119338274, 64.70222890377045, 67.27279856801033, 58.95100951194763, 59.93811294436455, 64.68405067920685, 67.17927038669586, 66.35212317109108, 63.83351191878319, 63.41145716607571, 66.5032410621643, 55.95520466566086, 50.959624126553535, 54.5423948764801, 56.9947224855423, 59.134718254208565, 58.22597801685333, 54.236306101083755, 53.87753315269947, 51.66697897017002, 46.58877186477184, 50.046324133872986, 49.77811172604561, 54.03511829674244, 56.71243943274021, 64.61251571774483, 62.461359947919846, 66.20933443307877, 49.4433306902647, 46.03615611791611, 61.59326232969761, 60.999282002449036, 63.82849618792534, 65.03075927495956, 61.627129912376404, 56.178260296583176, 47.380812764167786, 46.78507313132286, 49.86938662827015, 53.84205065667629, 58.57213944196701, 59.484930261969566, 61.85603342950344, 59.88812282681465, 58.56586217880249, 61.00341618061066, 60.143229737877846, 53.57935555279255, 58.691878616809845, 59.10076327621937, 58.14490556716919, 57.19725921750069, 56.602997705340385, 56.814908534288406, 52.39935167133808, 51.05000987648964, 47.7749428153038, 52.81600311398506, 58.78194898366928, 61.07763759791851, 59.44746807217598, 55.82704894244671, 55.25081366300583, 59.311640560626984, 55.93170292675495, 50.74655815958977, 39.003162905573845, 15.526123624294996, 1.356547751929611, 1.1888803238980472, 2.3059687251225114, 4.329599775373936, 7.019921438768506, 8.922960497438908, 12.088754922151566, 8.955040276050568, 0.6024932360742241, 0.2501545596169308, 1.6650992701761425, 27.081182934343815, 54.10951070487499, 38.23523551225662, 33.52153904736042, 44.073474034667015, 43.76297369599342, 17.570804357528687, 0.5607102031353861, 0.22502684936625883, 0.17192023107782006, 0.12212978836032562, 0.16140870371600613, 0.1641383970854804, 0.11184650109498762, 0.21776500856503844, 0.10957604128634557, 0.15657717391150072, 0.12877672270406038, 0.12375149977742694, 0.18813376809703186, 0.14519810560159385, 0.11305877706035972, 0.18865944613935426, 0.13541438762331381, 0.16439690196420997, 0.1835796085651964, 0.22532961593242362, 0.22880374279338866, 0.18997953389771283, 0.13694845139980316, 0.13028402463532984, 0.10918777188635431, 0.1272860894096084, 0.2006993821123615, 0.0760931805416476, 0.08943527398514561], [0.03442491703026462, 0.008546201570425183, 0.04926311710732989, 0.020258460790500976, 0.011626821324171033, 0.022890287145855837, 0.013099451043672161, 0.02664609986823052, 0.02586309510661522, 0.034896882134489715, 0.050908551274915226, 0.025248645069950726, 0.01477216192142805, 0.0824733499030117, 0.02447906390443677, 0.07100509028532542, 0.01947830773133319, 0.027744220533350017, 0.024141603789757937, 0.01600602139660623, 0.029512045985029545, 0.021852883437532, 0.0389222837111447, 0.03659730944491457, 0.04827044263947755, 0.06610706404899247, 0.0567552129359683, 0.03350084298290312, 0.02906301881012041, 0.02725142148847226, 0.01089755733119091, 0.055767889352864586, 0.026132082821277436, 0.06958488680538721, 0.02514306157536339, 0.0853525563434232, 0.05737217143177986, 0.04190145744360052, 7.521749585866928, 33.33151884377003, 34.75027911365032, 36.99500486254692, 26.50193441659212, 42.90512412786484, 36.16856060922146, 7.3539781384170055, 0.17596380785107613, 0.03971880483732093, 0.2634844521526247, 3.6565580405294895, 3.0977096781134605, 0.5276660481467843, 0.0655234168516472, 0.517348354915157, 0.08182939578546211, 6.065001329407096, 38.91601078212261, 62.797896489501, 67.14481383562088, 65.97899839282036, 64.42025363445282, 66.76018327474594, 61.572439447045326, 62.263272777199745, 58.27917896211147, 60.36037668585777, 62.669847160577774, 60.96406169235706, 63.32747407257557, 59.58218224346638, 59.316717088222504, 57.97295339405537, 52.02261708676815, 49.81113575398922, 57.281276509165764, 57.63124532997608, 62.03202098608017, 61.65365248918533, 59.83908645808697, 59.32319574058056, 58.40963736176491, 52.53024324774742, 46.18294984102249, 44.22950506210327, 48.736078441143036, 50.77682353556156, 61.1925358325243, 53.262927532196045, 67.27424249053001, 47.765735909342766, 41.668681874871254, 59.970654398202896, 57.60770559310913, 59.55342538654804, 57.36217796802521, 55.933325439691544, 47.83191695809364, 42.4114204198122, 45.41798248887062, 56.19224734604359, 58.47647577524185, 57.75270961225033, 56.58578082919121, 58.83062817156315, 60.18820412456989, 57.32582911849022, 58.63705895841122, 54.709209725260735, 54.51171152293682, 52.83900327980518, 58.36082898080349, 57.34136648476124, 54.92693044245243, 53.916184678673744, 52.00115963816643, 51.42105996608734, 49.179115667939186, 47.944425120949745, 48.10055494308472, 53.091123551130295, 56.56921371817589, 57.69500210881233, 57.184541299939156, 58.335681930184364, 50.35842038691044, 51.242142766714096, 27.993557676672935, 9.038002174347639, 0.39554894843604416, 0.3628957865294069, 1.4317993889562786, 0.6178542680572718, 1.1840336839668453, 7.33953938819468, 6.304049352183938, 1.1973790428601205, 0.27469619584735483, 0.12487869593314826, 1.5190309518948197, 26.372403167188168, 44.18096646666527, 26.259112246334553, 24.879030101001263, 30.27331944555044, 24.165183305740356, 5.763408662751317, 0.23376771627226844, 0.03746879861864727, 0.013965469661343377, 0.019411135945119895, 0.031256417714757845, 0.0739151997549925, 0.015175906955846585, 0.056195188299170695, 0.02203243122494314, 0.0671236653579399, 0.03254588445997797, 0.021069229296699632, 0.049708888109307736, 0.022813812538515776, 0.03236421413021162, 0.07735167004284449, 0.022882668999955058, 0.011257101905357558, 0.015289783023035852, 0.017254946469620336, 0.057061549232457764, 0.04821905262360815, 0.06991638932959177, 0.01944397226907313, 0.05218468162638601, 0.057072258423431776, 0.044321344976197, 0.0020675907262557303, 0.016905773409234826, 0.02442759225232294, 0.04431826135260053, 0.032792882338981144, 0.07217571692308411, 0.10536629764828831, 0.029628147567564156, 0.014494087536149891, 0.04796530120074749, 0.020012028799101245, 0.013795972408843227, 0.04845492199820001, 0.051584161701612175, 0.06195743437274359, 0.06605304311960936, 0.016661350782669615, 0.0514865321747493, 0.021658399928128347, 0.058266054911655374, 0.052758417441509664, 0.011132759700558381, 0.06661009916570038, 0.06236229819478467, 0.03360737828188576, 0.004387122962725698, 0.02797201905195834, 0.014043566789041506, 0.0838252980611287, 0.05395937194407452, 0.04259712812199723, 0.022827145221526735, 0.039886893864604644, 0.030882160062901676, 0.05345809200662188, 0.050030241764034145, 0.03534790012054145, 0.013116606714902446, 0.02417799500108231, 0.07269414418260567, 0.2800131496042013, 13.208659328520298, 41.50914363563061, 38.24021704494953, 28.94161630421877, 32.145199701189995, 60.423020124435425, 43.21150168776512, 5.923504522070289, 0.3674679802497849, 0.10086779177072458, 0.2606536040548235, 1.8776833754964173, 2.511170539073646, 3.295732014812529, 1.1429050471633673, 0.4332095885183662, 0.1955193842877634, 10.373507961630821, 45.21367125213146, 65.98902985453606, 67.89072141051292, 65.93817338347435, 66.08954966068268, 65.60191422700882, 64.63231265544891, 63.5020063072443, 59.42970022559166, 62.27234289050102, 64.9675914645195, 63.24042834341526, 65.54891467094421, 61.83916233479977, 62.51876346766949, 59.72911275923252, 54.517365619540215, 50.55040888488293, 58.189484775066376, 59.74787995219231, 63.500904366374016, 61.606147438287735, 61.12998738884926, 58.664060309529305, 57.78554365038872, 51.63981042802334, 47.03082874417305, 45.56252293288708, 50.01401826739311, 53.498264104127884, 60.95949813723564, 57.35941171646118, 68.31571340560913, 49.870344176888466, 41.97478964924812, 60.42281113564968, 56.90852411091328, 60.85762180387974, 58.230009600520134, 59.21990588307381, 49.20625761151314, 44.43006969988346, 47.186335399746895, 56.52816832065582, 59.592608883976936, 58.396531865000725, 58.86593967676163, 60.63645087182522, 61.718002036213875, 58.84418584406376, 60.168817564845085, 56.31105937063694, 55.71507275104523, 55.34489281475544, 58.43061983585358, 58.87865759432316, 55.40832281112671, 55.678241327404976, 54.4803100079298, 52.21966691315174, 50.27249939739704, 47.730766385793686, 50.27362793684006, 55.072413235902786, 58.879656940698624, 58.29251244664192, 56.262596771121025, 56.63155697286129, 52.58125551044941, 50.703989043831825, 32.09541097283363, 12.011083289980888, 0.5153259134385735, 1.298167328350246, 3.1337766302749515, 3.121337997727096, 2.947723651304841, 9.118841886520386, 2.674691677093506, 0.6651007547043264, 0.22686584678012878, 0.04983844111848157, 0.9529709327034652, 24.16189458221197, 53.275660648941994, 33.72728280723095, 25.423436388373375, 33.01011309027672, 33.33344914019108, 13.182611726224422, 0.7283953239675611, 0.040346186797250994, 0.07829222347936593, 0.05635829751554411, 0.03404547918762546, 0.07548906491138041, 0.03280923185229767, 0.06191297230543569, 0.045752565638395026, 0.05673543470038567, 0.04967110537108965, 0.026053552464873064, 0.054549345950363204, 0.07721840258454904, 0.045027123705949634, 0.04360069731774274, 0.023965135915204883, 0.06610411772271618, 0.03187414062267635, 0.009931025942933047, 0.019320705250720493, 0.05453761259559542, 0.06355308156344108, 0.05903140583541244, 0.028744476039719302, 0.05826209926453885, 0.02485981720383279, 0.017435206718801055, 0.030454710831691045, 0.05097353001474403, 0.1800376345636323, 0.15977796778315678, 0.2586385840550065, 0.14579265494830906, 0.18639794405316934, 0.08984285406768322, 0.13730169885093346, 0.20027500722790137, 0.1145246671512723, 0.18089333083480597, 0.1609044588985853, 0.1160044057178311, 0.16905200842302293, 0.18587688216939569, 0.18074080464430153, 0.11849914997583255, 0.11866738001117483, 0.14734536147443578, 0.15464753058040515, 0.12866687000496313, 0.14432925847359002, 0.12935089267557487, 0.08622935929452069, 0.18185687600634992, 0.17528153664898127, 0.24256887525552884, 0.25305362592916936, 0.10091698874020949, 0.07908079991466366, 0.09297563752625138, 0.12350603443337604, 0.15487982280319557, 0.17983330646529794, 0.1792163887876086, 0.12010483842459507, 0.18909713515313342, 0.1753204845590517, 0.3706867340952158, 11.813202258199453, 49.580271542072296, 49.51306074857712, 47.0871227234602, 37.30678953230381, 52.62364603579044, 48.112782686948776, 10.448473189026117, 0.5691368447151035, 0.27508077677339315, 1.4717351272702217, 11.436774507164955, 11.672628801316023, 1.2200265401042998, 0.36658782279118896, 0.6166196311824024, 0.22574823175091296, 10.17027111724019, 45.81004165112972, 68.61039519309998, 69.00057345628738, 70.69219708442688, 67.92377963662148, 69.72523257136345, 66.43935889005661, 63.97863373160362, 59.51491065323353, 63.43564286828041, 65.04729598760605, 65.87915495038033, 67.61759966611862, 64.86128076910973, 64.16758239269257, 62.76563622057438, 56.293090134859085, 54.0634685754776, 61.354353949427605, 63.04817005991936, 64.87613037228584, 65.21697208285332, 63.59135091304779, 63.33437070250511, 63.006072118878365, 56.356451734900475, 51.60246983170509, 49.13635656237602, 53.07818524539471, 54.905488193035126, 64.57156911492348, 59.238958060741425, 70.62358036637306, 52.19860464334488, 44.92972768843174, 60.52987039089203, 58.81653472781181, 61.066811978816986, 60.803527906537056, 62.070269733667374, 52.1128698438406, 46.36508546769619, 49.51097846031189, 61.46449863910675, 62.91530638933182, 63.45773108303547, 60.33556021749973, 63.592924028635025, 63.10112401843071, 61.691882237792015, 62.059105932712555, 57.901882007718086, 58.837957978248596, 56.72861896455288, 62.17755317687988, 62.14940428733826, 55.79512305557728, 57.536877393722534, 55.88388629257679, 55.696506947278976, 52.453738152980804, 51.566652953624725, 52.61215925216675, 57.77593396604061, 60.80318972468376, 60.299845933914185, 57.68915042281151, 58.16115729510784, 51.419289261102676, 50.00847056508064, 32.20489449799061, 10.592565257102251, 0.7024918764363974, 1.1540969903580844, 1.995614916086197, 2.663241229020059, 5.159622961655259, 21.16028744727373, 17.223886772990227, 3.972659041173756, 0.5888173542916775, 0.26697934430558234, 2.3203618777915835, 33.47550831735134, 53.73358927667141, 34.27331730723381, 36.458751037716866, 43.274300917983055, 38.9498745650053, 12.597359530627728, 0.7315771782305092, 0.24060700787231326, 0.16342226910637692, 0.20226957363775, 0.14094435260631144, 0.2598460583249107, 0.07890930442954414, 0.1898746981169097, 0.13114530185703188, 0.20524509600363672, 0.18581394804641604, 0.12044877192238346, 0.13526906026527286, 0.15712832246208563, 0.14521704521030188, 0.15929621004033834, 0.22691877675242722, 0.15946877421811223, 0.13625703693833202, 0.08266224132967182, 0.12430917180608958, 0.14600894646719098, 0.19142327830195427, 0.1265388951287605, 0.13369018561206758, 0.09039359443704598, 0.16948966775089502, 0.13555331766838208, 0.10807795682922006, 0.1704058490577154], [0.02509893904061755, 0.06413182316464372, 0.00866679221871891, 0.05481557658640668, 0.025946091336663812, 0.052976768420194276, 0.017322804742434528, 0.07982877345057204, 0.12955802609212697, 0.02735432397457771, 0.08038271989789791, 0.023837126573198475, 0.044117098514107056, 0.05111415215651505, 0.027970876144536305, 0.03517394441587385, 0.010922063047473785, 0.010741718378994847, 0.007504863087888225, 0.04219270958856214, 0.08806844576611184, 0.00782453531428473, 0.04158968491537962, 0.030982758180471137, 0.05336566122423392, 0.045533171942224726, 0.0047398147307831096, 0.03337765760079492, 0.05836600365000777, 0.015690959298808593, 0.0602644062746549, 0.019176121895725373, 0.13623308041132987, 0.03588576793845277, 0.02574230129539501, 0.017998904986598063, 0.061263763782335445, 0.029143514002498705, 0.11520030355313793, 6.76122467033565, 35.42360678315163, 44.095391258597374, 33.23903940618038, 30.189771428704262, 45.65493777394295, 43.31727661192417, 11.130473893135786, 0.6615815497934818, 0.07126386975869536, 0.7955320808105171, 1.6216438519768417, 5.267599392682314, 11.261005438864231, 1.54378448612988, 0.05758795086876489, 0.7347798126284033, 3.0074882693588734, 28.643083423376083, 56.59470655024052, 61.84764347970486, 66.50982990860939, 66.50124236941338, 67.68255338072777, 57.92970031499863, 62.203065007925034, 56.71396695077419, 63.09796638786793, 63.066621869802475, 62.24438779056072, 61.234447583556175, 61.26455716788769, 59.78613629937172, 54.807008877396584, 56.19996853172779, 63.41806501150131, 61.34121045470238, 62.023870423436165, 60.23190177977085, 62.990713343024254, 60.53638704121113, 62.21976511180401, 59.0075808763504, 56.857492849230766, 47.628095895051956, 49.01683397591114, 53.82365204393864, 63.33579942584038, 59.027229622006416, 65.78100621700287, 44.89310525357723, 39.87222567200661, 63.6432371288538, 60.30977480113506, 64.50620502233505, 58.45403037965298, 56.27119570970535, 44.18522983789444, 48.71260330080986, 53.40447373688221, 62.09654152393341, 59.80742655694485, 62.61821553111076, 58.726889938116074, 60.25838255882263, 57.64376565814018, 59.42292518913746, 58.972672149538994, 56.12021841108799, 55.96880793571472, 58.11485297977924, 57.393682077527046, 58.0612188577652, 60.59831991791725, 57.37303778529167, 56.4117805659771, 54.88535687327385, 53.93863007426262, 54.79910530149937, 51.53797209262848, 54.12207283079624, 55.767354145646095, 61.88943363726139, 57.40053690969944, 55.31626895070076, 43.33534464240074, 21.149501726031303, 5.008397726342082, 0.3446058835834265, 0.1312374765984714, 1.617077684495598, 5.656896578148007, 2.5770829897373915, 0.7304339145775884, 12.307355292141438, 2.918457384221256, 0.07678370442590676, 0.22757634927984327, 2.040523993782699, 25.28931498527527, 37.45086260139942, 19.222437031567097, 23.964451476931572, 29.343554936349392, 21.30079060792923, 2.2696215379983187, 0.07935146859381348, 0.09948039121809416, 0.05674862266459968, 0.05250040238024667, 0.0581138033157913, 0.007389839938696241, 0.039281193749047816, 0.03680382316815667, 0.020563286816468462, 0.017758766407496296, 0.04087010966031812, 0.011790895332524087, 0.04119175275263842, 0.05067261510703247, 0.0429807479667943, 0.008350563093699748, 0.04861222390900366, 0.07476110709831119, 0.037545484738075174, 0.038912509626243263, 0.04088963185495231, 0.012835178749810439, 0.042645824141800404, 0.051915686490247026, 0.01871347260021139, 0.018019909621216357, 0.01049735234118998, 0.08861119320499711, 0.027815223656944, 0.010192276768066222, 0.017848514326033182, 0.07189668423961848, 0.020188376074656844, 0.03396438842173666, 0.02527331034798408, 0.02894892659242032, 0.0355691640288569, 0.04052373449667357, 0.03424994087254163, 0.050919568457175046, 0.061281642119865865, 0.03138359956210479, 0.013941166180302389, 0.04139239237701986, 0.05069792234280612, 0.02698054871871136, 0.03353351232362911, 0.04485271158046089, 0.028830912124249153, 0.031063943570188712, 0.04428171057952568, 0.09128178193350323, 0.016098031010187697, 0.023073349002515897, 0.10063164780149236, 0.02539230445108842, 0.07700150250457227, 0.04150118009420112, 0.03843910475552548, 0.04125014864257537, 0.026101428411493544, 0.04250568810675759, 0.04686449952714611, 0.026778714236570522, 0.027177692827535793, 0.06277211956330575, 0.0414070126862498, 0.06058889550331514, 0.023678908110014163, 0.21296512393746525, 11.937784273177385, 43.890411257743835, 47.05199360847473, 28.71067989617586, 29.292517974972725, 56.397861912846565, 45.74075236916542, 9.656020011752844, 0.6836891791317612, 0.10137464152649045, 0.6622916960623115, 1.7266021762043238, 3.836671463213861, 6.395142814144492, 1.8490482307970524, 0.45341084827668965, 0.329136794898659, 6.178583409637213, 35.92749394476414, 59.53501917421818, 66.7517477273941, 67.61116281151772, 67.87133485078812, 66.86794549226761, 59.254685416817665, 61.15404389798641, 59.67231720685959, 64.60826754570007, 63.72302524745464, 63.68546426296234, 62.64974623918533, 62.260536924004555, 59.93500091135502, 56.99883386492729, 55.601895824074745, 63.98143798112869, 62.77358919382095, 63.597400188446045, 61.83587171137333, 64.28822591900826, 62.30375960469246, 65.27589172124863, 60.76424181461334, 58.02746146917343, 50.38868956267834, 52.023753225803375, 56.4822743833065, 64.10188391804695, 59.77278381586075, 67.69206807017326, 46.53547212481499, 42.629171535372734, 64.16882872581482, 62.71000720560551, 65.55908292531967, 61.620047092437744, 58.50806728005409, 46.370887756347656, 50.325875133275986, 55.297193974256516, 62.88581237196922, 61.63966543972492, 63.10180798172951, 61.480993553996086, 61.93270191550255, 58.292151466012, 61.09244920313358, 61.70208089053631, 57.60914571583271, 57.82624326646328, 59.11058954894543, 60.29009185731411, 58.707108199596405, 59.90911290049553, 59.80346716940403, 57.602974846959114, 56.43352299928665, 54.42153476178646, 54.48184512555599, 53.48214536905289, 55.46874336898327, 58.66804629564285, 61.93441562354565, 56.7852321267128, 56.36291138827801, 44.155211448669434, 25.48825141042471, 6.590318866074085, 0.954210200579837, 1.9169180514290929, 1.7428942769765854, 3.5761854657903314, 5.888925427570939, 6.708705313503742, 6.628171959891915, 0.41255573742091656, 0.2014628442702815, 0.1818428048864007, 1.5477547980844975, 24.447226971387863, 46.660694405436516, 27.724021039903164, 22.01939094811678, 32.52489812672138, 31.09278727322817, 7.6527162082493305, 0.09258008765755221, 0.07273337410879321, 0.01845423670602031, 0.058881926161120646, 0.03779154380026739, 0.03858870688418392, 0.0100655541245942, 0.03223963351047132, 0.018352015140408184, 0.050540008160169236, 0.006931532670932938, 0.01769629798218375, 0.06647068672464229, 0.06098921367083676, 0.015292198713723337, 0.012147129000368295, 0.05876911229279358, 0.029499217962438706, 0.022297685936791822, 0.03211407696653623, 0.019021478728973307, 0.04317047802032903, 0.01747282803989947, 0.060190814911038615, 0.023557097556476947, 0.08238739435910247, 0.04581395238346886, 0.09149849647656083, 0.029503344303520862, 0.046802515353192575, 0.01326778219663538, 0.1511201323592104, 0.09325600607553497, 0.11272941934294067, 0.1364189587184228, 0.1060571703419555, 0.18945430114399642, 0.1400284087867476, 0.11251220756093971, 0.2275169180938974, 0.12776150921126828, 0.25939685117919, 0.14662978268461302, 0.10656006445060484, 0.12134491524193436, 0.07637230228283443, 0.11926552877412178, 0.11040759549359791, 0.08455495539237745, 0.1262066059280187, 0.11176205211086199, 0.19780491711571813, 0.11716242326656356, 0.2321318446774967, 0.07846090622479096, 0.1431433213292621, 0.10255296423565596, 0.17204768751980737, 0.12938837113324553, 0.21415264927782118, 0.20685025752754882, 0.22830218455055729, 0.1136889866029378, 0.17082366335671395, 0.09252666044631042, 0.13686593942111358, 0.07533966316259466, 0.14083108602790162, 0.10016034691943787, 0.20531902875518426, 10.247508622705936, 50.1103051006794, 58.079431280493736, 43.947168812155724, 38.15018467605114, 57.519136145710945, 55.59545896947384, 14.75232269614935, 1.148135585244745, 0.1612141719670035, 2.338892058469355, 7.877770056948066, 15.05079098045826, 24.00594525039196, 3.255877853371203, 0.29580320231616497, 0.9756937727797776, 4.287219699472189, 33.31378519535065, 60.41983209550381, 65.5990719795227, 70.84774553775787, 68.78784567117691, 68.95215645432472, 58.96544113755226, 63.410837799310684, 61.4274962246418, 68.03197503089905, 66.46052375435829, 66.65571168065071, 66.52585744857788, 64.78903904557228, 64.57514092326164, 60.92966593801975, 59.90134611725807, 67.20314830541611, 65.0286465883255, 66.35552778840065, 63.3266457170248, 67.41466015577316, 64.61028143763542, 67.11631536483765, 64.05076146125793, 60.99029928445816, 54.0253072232008, 54.46267135441303, 59.19594056904316, 68.05264592170715, 63.855170756578445, 70.13897716999054, 49.57722790539265, 45.40574334561825, 62.5617353618145, 64.63511690497398, 68.57169806957245, 65.08210971951485, 60.16743063926697, 49.41095642745495, 54.83351245522499, 59.07602280378342, 64.84855905175209, 64.73831176757812, 65.02660989761353, 62.17177748680115, 65.63056468963623, 57.844014912843704, 61.919132843613625, 62.21262909471989, 59.716562032699585, 60.274926871061325, 61.35008677840233, 62.433036267757416, 60.762186124920845, 63.95980954170227, 62.74176970124245, 60.89635692536831, 58.368303179740906, 58.258386477828026, 58.06346833705902, 56.625275909900665, 58.81517820060253, 60.26408985257149, 64.63208466768265, 58.538503646850586, 55.71146294474602, 46.434427946805954, 24.297005832195282, 5.892761796712875, 0.720460518496111, 0.91688581276685, 2.9349672608077526, 11.674258913844824, 5.320507753640413, 9.867194630205631, 31.997794210910797, 8.074199091643095, 0.5092870874796063, 0.39833918621297926, 3.4838257217779756, 33.21412794291973, 47.77803584933281, 29.53599750995636, 32.21502095460892, 41.45197190344334, 35.210236832499504, 6.367097944021225, 0.11272881820332259, 0.16253645648248494, 0.09567699569743127, 0.2422365266829729, 0.1708591973874718, 0.15736971341539174, 0.1207444435567595, 0.131896652164869, 0.09516650941804983, 0.12211392124299891, 0.0650607916759327, 0.09758202941156924, 0.17265952890738845, 0.14563392440322787, 0.10764003774966113, 0.07631566899362952, 0.1891858218004927, 0.1757106464356184, 0.19870266347425058, 0.1764058755361475, 0.12262674528756179, 0.1195012051903177, 0.1591044687665999, 0.07606672297697514, 0.1009327890642453, 0.22320299176499248, 0.1089811505516991, 0.18519345321692526, 0.12386051384964958, 0.1319034502375871, 0.12684345769230276], [0.027910945864277892, 0.025305035305791534, 0.02011870325077325, 0.06426595151424408, 0.027661662170430645, 0.021962322389299516, 0.04442319361260161, 0.0573764128057519, 0.03313670451461803, 0.0306717240891885, 0.04652182768040802, 0.07917218055808917, 0.03320762414659839, 0.08574969440815039, 0.008810391300357878, 0.024549013178329915, 0.05510739647434093, 0.04819227964617312, 0.0690363951434847, 0.03909686281986069, 0.02923771109635709, 0.057911731346393935, 0.06214681932760868, 0.0384662562282756, 0.0031887708473732346, 0.056986039417097345, 0.03649318612588104, 0.04455681730178185, 0.055420323042199016, 0.039479228435084224, 0.026221567277389113, 0.018582173688628245, 0.007257341067088419, 0.016986455993901473, 0.04850627861742396, 0.029424901149468496, 0.0635028381657321, 0.049705110577633604, 0.022828074761491735, 0.05677126187947579, 5.016234805807471, 36.61839947104454, 43.77141684293747, 33.76821041107178, 32.59217731654644, 44.301161617040634, 45.86415074765682, 15.039970111101866, 1.0757643124088645, 0.10733660325058736, 0.5603513598907739, 6.327983317896724, 19.162375554442406, 14.78259852156043, 6.701044924557209, 0.6914985319599509, 0.07786250513163395, 1.705426387488842, 17.322542779147625, 35.91653153300285, 55.45215725898743, 60.503720194101334, 64.94689777493477, 63.524364307522774, 57.10812360048294, 59.72937874495983, 60.30652977526188, 65.03204360604286, 65.1402997970581, 65.4854428768158, 63.262634351849556, 59.29559022188187, 57.63059936463833, 60.58530941605568, 64.03303161263466, 62.74883732199669, 66.40775218605995, 63.628588914871216, 63.980761617422104, 62.71415278315544, 63.87900307774544, 62.48364195227623, 58.21422904729843, 54.839664325118065, 47.38069497048855, 52.91968435049057, 58.73702019453049, 57.40606561303139, 66.93390995264053, 48.40882480144501, 39.517115727066994, 63.900129944086075, 60.98340265452862, 61.76119811832905, 59.21335883438587, 51.78932100534439, 44.82350438833237, 51.91909924149513, 55.936034694314, 61.26889653503895, 61.20655708014965, 61.04420319199562, 62.71517872810364, 58.12387749552727, 61.11083261668682, 59.71167169511318, 58.67819935083389, 60.29060862958431, 57.68938221037388, 59.30151790380478, 58.593957871198654, 58.25834468007088, 58.7567525357008, 58.1199599057436, 57.03750059008598, 56.56453996896744, 56.70745030045509, 56.757128834724426, 56.38103261590004, 57.9325919598341, 56.22126638889313, 59.817131236195564, 56.537371426820755, 36.82784803211689, 13.23175448924303, 1.9490481773391366, 0.13810557837132365, 0.6281736236996949, 1.9760739896446466, 0.5768213386181742, 3.0020450614392757, 7.056569522246718, 5.69340311922133, 2.53412202000618, 0.3117212309734896, 0.13043693674262613, 4.139584796503186, 25.498581156134605, 49.5443444699049, 47.32743322849274, 36.79225534200668, 31.05507429689169, 20.12853641062975, 3.2636178005486727, 0.10234355242573656, 0.1143573722220026, 0.0596967894671252, 0.07666570294531994, 0.0476927882846212, 0.05239973004790954, 0.03391240839846432, 0.08910607954021543, 0.008392428571823984, 0.08625295216916129, 0.08942619009758346, 0.01603364413313102, 0.03567494233720936, 0.061739146476611495, 0.03128229269350413, 0.024952444655355066, 0.032591942144790664, 0.06316330560366623, 0.048635171115165576, 0.04892223754723091, 0.053857634629821405, 0.010427502329548588, 0.07227429639897309, 0.02710454304178711, 0.010020280333264964, 0.004580080430969247, 0.01767219859175384, 0.016566144367970992, 0.04919435341435019, 0.030124182376312092, 0.018916598419309594, 0.0835513268248178, 0.017612303563510068, 0.01679390021308791, 0.02983360187499784, 0.01768339760019444, 0.0393419941974571, 0.012076141647412442, 0.09602774211089127, 0.03763067586987745, 0.03841255442239344, 0.025098150508711115, 0.011504626709211152, 0.02115605129802134, 0.04192498352495022, 0.08026343450183049, 0.01929529411427211, 0.04313846548029687, 0.029350465592870023, 0.018496015909477137, 0.05606306374829728, 0.052293272674432956, 0.036576792772393674, 0.07951361301820725, 0.027947671042056754, 0.0268625769240316, 0.04165456717601046, 0.03837582182313781, 0.0396003395144362, 0.05826739077747334, 0.05255585194390733, 0.04899932071566582, 0.028014861381961964, 0.02597902413981501, 0.005216453046159586, 0.0163690132467309, 0.02763638462056406, 0.03317770817375276, 0.03899525538145099, 0.05315883579896763, 0.08857617867761292, 0.21466590376803651, 9.767893608659506, 44.37209241092205, 46.248097345232964, 28.161064088344574, 31.695849113166332, 57.67441101372242, 49.94187533855438, 12.466573398560286, 0.5298079457134008, 0.11008415269316174, 0.39570343389641494, 0.9618846012745053, 18.732833303511143, 23.564779423177242, 5.159954493865371, 1.1471358826383948, 0.069969898177078, 4.217093512415886, 22.534044831991196, 42.262438014149666, 59.71093453466892, 63.55317436158657, 66.45258978009224, 62.77221366763115, 60.27869626879692, 61.838303580880165, 62.526735439896584, 67.17432305216789, 66.18527412414551, 65.80644205212593, 64.18343514204025, 62.88065604865551, 60.88375300168991, 61.83812119066715, 65.65220832824707, 64.76733461022377, 68.70274543762207, 64.23033982515335, 66.13369569182396, 63.20543982088566, 64.31768953800201, 62.06104002892971, 60.027575343847275, 54.839690923690796, 50.04871800541878, 55.33612288534641, 60.078743398189545, 60.31235486268997, 67.54392921924591, 51.39527454972267, 43.311079144477844, 63.062521889805794, 60.95171235501766, 64.74483981728554, 60.4573854804039, 54.62961159646511, 47.19507873058319, 53.61621357500553, 56.991899237036705, 62.73946702480316, 63.25484097003937, 62.659713104367256, 62.66634754836559, 58.88241559267044, 60.778977423906326, 62.35484026372433, 62.62480817735195, 60.53908109664917, 59.644153118133545, 60.8013354241848, 59.390687718987465, 60.34275323152542, 61.113116294145584, 59.4816130399704, 60.15610344707966, 58.21398206055164, 58.997412621974945, 57.94380895793438, 57.791311740875244, 59.04814749956131, 57.43756592273712, 58.737962543964386, 56.445967331528664, 38.846425116062164, 16.843019910156727, 2.920143543742597, 0.6014081567991525, 1.922138852532953, 4.654773026704788, 3.0141250882297754, 5.644496893510222, 8.937162235379219, 1.441374875139445, 0.20750909170601517, 0.12788224179530516, 0.2751413360238075, 3.0243826378136873, 26.75365950912237, 56.07155442237854, 42.165178433060646, 27.656966038048267, 31.954138353466988, 27.796439453959465, 7.237664004787803, 0.04375822187284939, 0.05331651249434799, 0.04612255594111048, 0.056073327650665306, 0.06890166565426625, 0.07465143251465634, 0.046971083065727726, 0.05596515962679405, 0.0409527106967289, 0.0979951088083908, 0.06845208001323044, 0.06389616901287809, 0.04325666363001801, 0.07717837856034748, 0.007007018366493867, 0.023284547532966826, 0.015617239914718084, 0.031157166595221497, 0.012033843868266558, 0.02365192547586048, 0.02498361856851261, 0.05805605309433304, 0.018861495809687767, 0.02361007391300518, 0.024729445976845454, 0.016247065395873506, 0.05401471760706045, 0.037829408174729906, 0.001029322995691473, 0.013333556889847387, 0.06724560022121295, 0.08229218423366547, 0.27788633247837424, 0.10151426919037476, 0.0820022048719693, 0.1712359263910912, 0.11722974348231219, 0.07516130281146616, 0.1827561215031892, 0.10928313786280341, 0.18579929805127904, 0.14092812925809994, 0.11750689111067913, 0.2348746740608476, 0.1503207057248801, 0.19418354815570638, 0.10758266973425634, 0.10179025906836614, 0.13205608032876626, 0.15633621340384707, 0.12107115180697292, 0.09063747900654562, 0.16880730749107897, 0.13749409321462736, 0.16073087055701762, 0.16687010909663513, 0.12896537664346397, 0.10583672279608436, 0.147629618877545, 0.19087698339717463, 0.17017787613440305, 0.09052424211404286, 0.1075767028669361, 0.07963054580613971, 0.11952705419389531, 0.078445937106153, 0.11860563332447782, 0.09083597382414155, 0.21327096299501136, 0.19423609221121296, 0.15927116997772828, 0.19406682316912338, 8.49269438534975, 51.770329624414444, 60.295430570840836, 46.888777166604996, 42.811960726976395, 55.745486319065094, 56.30350537598133, 20.8894132822752, 1.561097544617951, 0.3836866084020585, 1.2896316801197827, 13.193746078759432, 34.47781093418598, 23.986972868442535, 10.02621989697218, 1.5888549364171922, 0.16881551564438269, 3.258000514470041, 20.08428778499365, 40.358291789889336, 58.71461279690266, 61.93050563335419, 65.28882622718811, 64.9796824157238, 60.78896328806877, 62.78136357665062, 64.69049513339996, 69.39354076981544, 68.6734490096569, 69.96131390333176, 68.81421625614166, 64.47627782821655, 64.73597869277, 65.2218510210514, 66.67303115129471, 64.77836921811104, 69.0899370610714, 67.36350730061531, 67.85044357180595, 64.6405354142189, 66.61191523075104, 68.20295825600624, 62.94068902730942, 59.78348024189472, 52.23586164414883, 57.65189342200756, 60.85588149726391, 63.87052193284035, 67.92518556118011, 52.341370582580566, 46.252265721559525, 60.62630921602249, 62.13219881057739, 66.40254646539688, 63.210736736655235, 55.01872591674328, 49.70265917479992, 54.75678317248821, 59.38182279467583, 66.37562870979309, 66.83085188269615, 63.2433769851923, 64.37505885958672, 59.642876386642456, 62.844842970371246, 63.943204432725906, 64.10145074129105, 62.978006824851036, 61.69400632381439, 62.8057012706995, 59.56897795200348, 61.07674844563007, 60.96489004790783, 61.363040283322334, 61.03077091276646, 60.48819802701473, 60.94782896339893, 60.93900203704834, 60.295506566762924, 61.22138008475304, 58.811287209391594, 62.14439235627651, 58.61692003905773, 39.53558653593063, 14.115198533982038, 2.427353449165821, 0.2707964472938329, 0.7982156868092716, 2.9028634959831834, 3.6044552363455296, 7.580825965851545, 14.935028292238712, 13.860073573887348, 5.00133628025651, 0.45953404158353806, 0.41634193737991154, 6.443636761978269, 32.67048351466656, 60.502048283815384, 52.23070912063122, 43.956618905067444, 44.70826417207718, 32.626481875777245, 6.071963030844927, 0.272904354496859, 0.23059046332491562, 0.11311449008644558, 0.1827640476403758, 0.1204918981238734, 0.16808448533993214, 0.1158870870131068, 0.1393909633043222, 0.12757934164255857, 0.2377718998468481, 0.16002352960640565, 0.17048519948730245, 0.21928270056378096, 0.18744564877124503, 0.13083784491755068, 0.09543108506477438, 0.1283955853432417, 0.2078750595683232, 0.12240257958183065, 0.09625013408367522, 0.16706907888874412, 0.12819916853914037, 0.15424016572069377, 0.10411401992314495, 0.10696524739614688, 0.12210905275424011, 0.17665142251644284, 0.14319700829219073, 0.12137253055698238, 0.21289392228936777, 0.12121710256906226, 0.1416086044628173], [0.03665647345769685, 0.03859880751406308, 0.10374595920438878, 0.010229028848698363, 0.04552965416223742, 0.041945804478018545, 0.02038566304690903, 0.03940536247682758, 0.014415325258596567, 0.03982705078669824, 0.07761600820231251, 0.05814890690089669, 0.08979994308901951, 0.02869466679840116, 0.05905782258196268, 0.04382769431686029, 0.04478741000639275, 0.06816397828515619, 0.04478709459363017, 0.029300676760612987, 0.01453837612643838, 0.05287272302666679, 0.026843236555578187, 0.0069517404244834324, 0.034431759631843306, 0.07244286782224663, 0.054064864525571465, 0.04691239773819689, 0.08398930527619086, 0.07373214160907082, 0.032714778717490844, 0.026574929761409294, 0.011731903869076632, 0.021187054517213255, 0.0204314387156046, 0.09156767948297784, 0.08698551129782572, 0.04620196945325006, 0.023711119174549822, 0.05409315890574362, 0.0639083847636357, 3.5987733537331223, 31.272517628967762, 46.33212223649025, 30.466085001826286, 33.46450790762901, 54.20560374855995, 52.72268772125244, 24.089204482734203, 3.382619102485478, 0.27529116079676896, 0.20400357199832797, 2.4863452836871147, 2.1520900446921587, 4.938757913187146, 1.9596174289472401, 2.254070872440934, 0.23067588452249765, 0.5696437018923461, 7.085000546649098, 20.23727137595415, 40.624824687838554, 52.19232738018036, 60.09286344051361, 62.47794605791569, 56.43873631954193, 61.685433983802795, 60.65726235508919, 66.31991609930992, 66.2592713534832, 66.02287843823433, 63.99265497922897, 64.75935503840446, 63.13717268407345, 65.98834589123726, 61.81827865540981, 62.84919373691082, 60.48294670879841, 60.48032484948635, 61.02702051401138, 66.49608984589577, 62.74191789329052, 62.15473160147667, 55.71489796042442, 55.61210587620735, 53.49731035530567, 64.56410631537437, 58.622615933418274, 73.67151081562042, 38.938258588314056, 29.114212542772293, 67.78552785515785, 63.16827781498432, 63.450515270233154, 58.772312700748444, 50.424643233418465, 47.98987828195095, 54.762779250741005, 55.05109637975693, 57.988859340548515, 62.3495015501976, 62.293070778250694, 60.14278896152973, 59.00642953813076, 58.469943925738335, 59.851204007864, 59.265165254473686, 60.6234859675169, 57.66757518053055, 60.11376991868019, 60.668125972151756, 60.52662156522274, 60.01943998038769, 61.36260710656643, 60.302274003624916, 59.3321518599987, 58.86298343539238, 57.20898538827896, 56.81112013757229, 57.06553168594837, 57.63855613768101, 52.015013694763184, 33.578190207481384, 9.498963989317417, 0.8719900343567133, 0.4896677902434021, 0.8347625413443893, 1.9133367436006665, 11.903455965220928, 4.568432159721851, 1.7521060514263809, 9.57974860444665, 1.907725513447076, 0.9280854149255902, 0.3741538996109739, 6.664637178182602, 38.781528398394585, 36.62215746939182, 29.117427170276642, 38.00447769463062, 40.40624141693115, 25.68239439278841, 3.3134093787521124, 0.005194509594730334, 0.014949631695344578, 0.07431726568029262, 0.02846967359801056, 0.03963480856327806, 0.021375719588832, 0.024538112884329166, 0.01576576778461458, 0.017373317168676294, 0.0212720972194802, 0.04167948478425387, 0.038942507235333323, 0.03027714086783817, 0.09558729972923175, 0.06298752050497569, 0.007209683590190252, 0.009498628442088375, 0.0998020677070599, 0.030905007079127245, 0.079474628000753, 0.016862886550370604, 0.030917393523850478, 0.009204869693348883, 0.02428884032269707, 0.01724712608847767, 0.04414015704242047, 0.021946705746813677, 0.008299700930365361, 0.05480591382365674, 0.09065395468496718, 0.03163935849443078, 0.09308439926826395, 0.038480464645545, 0.039159481530077755, 0.06588226751773618, 0.01800395159079926, 0.05894187685044017, 0.041010943314176984, 0.03610962194215972, 0.00801713840701268, 0.04699023047578521, 0.03229137975722551, 0.025742995203472674, 0.017539257678436115, 0.029233093082439154, 0.025205687707057223, 0.11572243412956595, 0.07484331479645334, 0.06388413879903965, 0.029174795527069364, 0.06493321649031714, 0.07552416107500903, 0.04369619317003526, 0.021313744691724423, 0.06315693055512384, 0.00978505848252098, 0.005131215066285222, 0.01730465181026375, 0.011446336575318128, 0.006510110606541275, 0.06871137898997404, 0.02251061552669853, 0.048475323637831025, 0.0013999700991007558, 0.03647000514320098, 0.03621051691879984, 0.02791500541206915, 0.02634844113345025, 0.06679228157736361, 0.04481200478039682, 0.04441464778210502, 0.05876594703295268, 0.010864730284083635, 0.04478614835534245, 8.138273153454065, 40.691112130880356, 48.83790157735348, 31.10305242240429, 31.970739662647247, 60.81434212625027, 61.9014485925436, 24.14725586771965, 2.6882229885086417, 0.16106250666780397, 0.3765718167414889, 1.982048931531608, 3.6549117788672447, 6.06943616643548, 2.208152711391449, 2.2381285903975368, 0.365101033821702, 2.0491488184779882, 10.996247995644808, 25.6618469953537, 46.22797742486, 56.16315230727196, 60.76744884252548, 61.80049180984497, 57.846374586224556, 61.18611037731171, 63.34705822169781, 68.12206819653511, 67.86679029464722, 68.05180236697197, 65.1183445751667, 66.07272416353226, 65.70463791489601, 68.00679758191109, 63.67132142186165, 63.87283980846405, 63.07076744735241, 62.85476043820381, 63.55108827352524, 69.26644518971443, 65.79843968153, 64.55985054373741, 57.36107222735882, 58.03928263485432, 56.57579496502876, 66.41109600663185, 61.08463302254677, 73.51214736700058, 43.197818621993065, 33.242162838578224, 66.00618973374367, 64.94635060429573, 64.38531070947647, 61.00492089986801, 52.56834760308266, 52.24403500556946, 56.42106346786022, 58.070813342928886, 60.58562859892845, 65.34540519118309, 64.96402725577354, 61.957396790385246, 59.24227528274059, 58.4934988617897, 59.72410462796688, 60.00938571989536, 62.737711519002914, 59.164877235889435, 61.47508107125759, 61.30870319902897, 61.40847444534302, 59.245303720235825, 61.682124361395836, 59.88770104944706, 57.95567952096462, 59.478189423680305, 58.26292723417282, 58.569597378373146, 58.835351318120956, 58.482806235551834, 53.33424590528011, 39.412761926651, 13.831671997904778, 2.227407703176141, 1.6696339705958962, 2.233492601662874, 3.837218158878386, 12.49511556699872, 11.211642287671566, 3.7958324421197176, 2.7553487615659833, 0.5668897996656597, 0.5512176593765616, 0.09393028434715234, 4.52806550078094, 41.458454355597496, 46.13117381930351, 35.2292700111866, 43.94604027271271, 46.39677956700325, 33.686039820313454, 6.505727330222726, 0.1276934245834127, 0.060991224891040474, 0.04518930894846562, 0.09891321227769367, 0.08977075442089699, 0.0918382071540691, 0.05647236561344471, 0.02515911608497845, 0.018602143027237616, 0.027478292322484776, 0.03920048889995087, 0.01209037511216593, 0.06785597215639427, 0.032785193689051084, 0.06350316471070983, 0.010523997298150789, 0.034178327332483605, 0.015649944507458713, 0.03776598423428368, 0.038332654803525656, 0.03217978672182653, 0.03005561164172832, 0.04264034709194675, 0.025304211521870457, 0.03442198925768025, 0.08014979684958234, 0.024920335636124946, 0.028911277440784033, 0.12121053456212394, 0.02667900855158223, 0.03306308717583306, 0.06436033785576001, 0.004945178125126404, 0.09417620982276276, 0.11922842881176621, 0.27300519752316177, 0.17955758376047015, 0.15461066068382934, 0.12901380920084193, 0.18960133544169366, 0.1772424392402172, 0.10295112646417692, 0.12591872684424743, 0.17199242720380425, 0.13392701977863908, 0.2158379479078576, 0.15194120001979172, 0.16697248094715178, 0.14297754038125277, 0.15450867475010455, 0.1376965214149095, 0.13323980587301776, 0.17619854916119948, 0.13304666936164722, 0.15345268766395748, 0.12870468985056505, 0.0858300986874383, 0.1215864546247758, 0.15936601645080373, 0.13864071137504652, 0.21751132764620706, 0.1570412388537079, 0.14171879854984581, 0.14857230969937518, 0.14668145100586116, 0.17056031967513263, 0.1531418168451637, 0.10871754711843096, 0.19041937513975427, 0.16315488814143464, 0.18943368428153917, 0.1183636486530304, 0.10935079204500653, 0.10610455647110939, 6.197342053055763, 45.90896554291248, 59.81036759912968, 43.52393992245197, 44.28267940878868, 63.58796149492264, 63.266054168343544, 30.39666462689638, 4.882666748017073, 0.37374856823589653, 0.6481041479855776, 4.875848963856697, 8.297670800238848, 14.037470854818821, 8.069398999214172, 3.5604661842808127, 0.2683122712187469, 1.4641100051812828, 9.280744548887014, 23.657008074223995, 44.19206187129021, 55.04073053598404, 59.797091111540794, 63.17169763147831, 59.12464119493961, 64.69588324427605, 66.7315936088562, 68.44375893473625, 70.0894658267498, 69.93906989693642, 70.68172484636307, 68.80594030022621, 69.09912496805191, 70.16511976718903, 66.04934021830559, 65.8648145198822, 65.60563042759895, 64.08165380358696, 65.75107902288437, 70.79514876008034, 68.77587631344795, 66.34719103574753, 60.61772547662258, 61.28457069396973, 60.07745146751404, 68.46436142921448, 64.01261150836945, 74.50870469212532, 43.90541285276413, 35.71093216538429, 65.72517201304436, 67.67566055059433, 66.44367545843124, 64.51933711767197, 54.74178537726402, 55.49695685505867, 59.577858075499535, 59.91417042911053, 62.099075987935066, 66.34518474340439, 66.62067756056786, 62.37412042915821, 60.500178784132004, 56.83774150907993, 61.808847561478615, 62.11729221045971, 62.27428078651428, 61.53449468314648, 64.12690177559853, 62.463871613144875, 63.36065389215946, 61.64523974061012, 62.49683104455471, 63.160442635416985, 60.69694362580776, 62.09599055349827, 61.196563616395, 60.32519817352295, 61.212427765131, 59.785205349326134, 55.469898506999016, 36.7998169362545, 11.226776875555515, 1.3063913933001459, 1.5502030542120337, 1.4725428214296699, 5.180904669687152, 17.54682384431362, 11.752927042543888, 9.580554161220789, 19.131306521594524, 5.629009399563074, 1.568156259600073, 0.4438524611759931, 10.364646837115288, 47.5955468416214, 46.262874752283096, 39.06544156372547, 47.240505293011665, 49.578744024038315, 39.39530186355114, 6.011411380022764, 0.27586258482187986, 0.1883196464041248, 0.19961160141974688, 0.200055806490127, 0.15569397364743054, 0.11069337429944426, 0.21379698242526501, 0.19940963335102424, 0.06243380412342958, 0.12213352136313915, 0.09475392726017162, 0.16694870253559202, 0.12739791622152552, 0.25490148458629847, 0.10367734023020603, 0.06865279385237955, 0.0940011817147024, 0.17304869630606845, 0.08918816107325256, 0.33539256546646357, 0.10982131367200054, 0.14876808825647458, 0.10834844739292748, 0.0926633492053952, 0.13071145716821775, 0.19205006654374301, 0.0833619233162608, 0.14414057484827936, 0.19662426406284794, 0.18432934099109843, 0.08503453864250332, 0.17969025007914752, 0.06814588472479954], [0.08537795263691805, 0.05406955118814949, 0.030160657079250086, 0.0697304071218241, 0.014417164857150055, 0.08032853569602594, 0.04991872665414121, 0.04347263602539897, 0.03601777374569792, 0.04539760011539329, 0.05665327524184249, 0.006153203903522808, 0.025949189803213812, 0.061177719180705026, 0.02001778600970283, 0.03303599136415869, 0.030114853580016643, 0.061274825493455864, 0.022099744019214995, 0.04738366522360593, 0.0194158708472969, 0.04936861339956522, 0.046494746711687185, 0.07518286962294951, 0.02202995430707233, 0.04028907111205626, 0.04515621287282556, 0.032670275832060724, 0.08770719054155052, 0.043010088775190525, 0.017083723723771982, 0.0548096839338541, 0.012600394766195677, 0.005231156847003149, 0.003156442894578504, 0.03300053154816851, 0.007349531115323771, 0.10585218173218891, 0.08605414564954117, 0.0250307839087327, 0.07887909159762785, 0.05017206618504133, 3.267192696221173, 22.920269407331944, 44.835602939128876, 35.61062894761562, 28.64158060401678, 28.89934167265892, 39.04707334935665, 34.4456684589386, 8.145802449434996, 0.4954627761617303, 1.188142925966531, 2.7428279584273696, 0.5983559705782682, 0.8552186843007803, 1.9058802374638617, 0.6218049279414117, 0.03943643991078716, 0.12575296073919162, 1.5201554540544748, 6.381575167179108, 19.125709421932697, 35.58868892490864, 52.50327609479427, 59.16916720569134, 58.69931101799011, 60.80924279987812, 60.95671288669109, 61.24029166996479, 65.99266245961189, 64.81111586093903, 67.04661950469017, 65.65460979938507, 64.27336871623993, 63.31722982227802, 64.87614557147026, 61.64846196770668, 65.33151313662529, 65.91449305415154, 66.81642785668373, 66.91400662064552, 61.301145404577255, 57.17157259583473, 58.65733467042446, 61.916381791234016, 61.365380957722664, 62.81377963721752, 64.3969076871872, 29.96224343776703, 33.599054887890816, 58.18977355957031, 67.74221017956734, 60.03743201494217, 61.05623334646225, 54.589671939611435, 52.303201630711555, 49.39459070563316, 58.864556550979614, 55.661552622914314, 62.061344012618065, 61.71520918607712, 66.84650704264641, 60.72713300585747, 61.645832508802414, 59.882362335920334, 61.27308011054993, 59.531371369957924, 62.59808801114559, 62.58496731519699, 62.98666276037693, 60.41075058281422, 60.37045754492283, 60.14937020838261, 61.75034210085869, 61.641990914940834, 63.885105550289154, 60.100858211517334, 61.8718595802784, 53.089280650019646, 47.51148775219917, 20.32108347862959, 5.528273480013013, 0.3458290913840756, 1.6775476397015154, 1.7354889493435621, 4.244589786976576, 6.236398257315159, 9.677161127328873, 14.74530827254057, 9.125584624707699, 2.466355743817985, 0.16609294689260423, 0.05771705116785597, 10.936294812709093, 38.307123854756355, 36.240889728069305, 30.78362636268139, 27.193337716162205, 32.627811804413795, 24.804772585630417, 3.2938957633450627, 0.07157563857617788, 0.07852545822970569, 0.059704448431148194, 0.019299331397633068, 0.014939721240807557, 0.0030433685788011644, 0.04239908972522244, 0.024322274075530004, 0.03129423756035976, 0.02190809180319775, 0.0435961034236243, 0.057418399810558185, 0.020513963681878522, 0.08472530054859817, 0.026864820065384265, 0.05113947052450385, 0.022933276050025597, 0.029864176503906492, 0.039995329061639495, 0.05798848796985112, 0.052904939657310024, 0.05453351594042033, 0.018485824366507586, 0.017030628623615485, 0.059943720552837476, 0.07875413619331084, 0.0500957622716669, 0.07298354466911405, 0.01300017858739011, 0.04305480317270849, 0.0296259248352726, 0.058592759451130405, 0.026344914076616988, 0.0193521314940881, 0.039826163920224644, 0.13145931938197464, 0.048936167659121566, 0.018518161596148275, 0.012070703560311813, 0.043165917522856034, 0.043173929007025436, 0.029978383754496463, 0.0489684288186254, 0.03637416419223882, 0.06801168958190829, 0.050401987246004865, 0.05670742233633064, 0.04065297209308483, 0.06352577052894048, 0.028174395301903132, 0.03273541784437839, 0.06723972983309068, 0.01826536754379049, 0.01085648502339609, 0.023873560458014254, 0.026080995230586268, 0.07078735899995081, 0.04677363838709425, 0.02145198825019179, 0.03573195412172936, 0.02830305773386499, 0.01606091063877102, 0.17727445549098775, 0.07457456827978604, 0.051567441114457324, 0.026047240498883184, 0.023794770349923056, 0.05739328553318046, 0.0308341282652691, 0.027098130885860883, 0.03499491613183636, 0.04198418835585471, 0.031751997958053835, 0.015392818168038502, 0.05092044790217187, 0.10176978321396746, 6.845377329736948, 36.219375282526016, 50.7993221282959, 36.06821559369564, 35.90448997914791, 43.092883452773094, 62.15185895562172, 37.35988028347492, 5.909237237647176, 0.4850447445642203, 0.3647374111460522, 1.0566262830980122, 1.148861227557063, 1.7377763078548014, 2.6599947782233357, 2.017781501635909, 0.06444522470701486, 0.3232643287628889, 3.4846692765131593, 10.883413050323725, 25.8488729596138, 40.75138449668884, 57.63201668858528, 60.76569713652134, 62.975434362888336, 61.125070452690125, 62.42588885128498, 64.57421377301216, 69.07106727361679, 69.02758240699768, 69.47406604886055, 64.90820825099945, 65.48669680953026, 65.3323794901371, 67.3413696885109, 63.48352409899235, 66.27692520618439, 65.26896849274635, 67.93489024043083, 65.56178078055382, 63.15660484135151, 56.80628299713135, 59.35222238302231, 62.16385871171951, 63.282442688941956, 64.56365793943405, 68.75117003917694, 31.92557528614998, 32.83994682133198, 63.11165325343609, 67.25726500153542, 63.82053941488266, 63.5465133190155, 56.0614887624979, 52.006429955363274, 52.15894237160683, 58.90379324555397, 56.868956834077835, 64.0931747853756, 62.76978939771652, 68.05176436901093, 62.59223252534866, 61.53989799320698, 61.34428448975086, 61.88337676227093, 62.103286162018776, 62.24988229572773, 64.14637193083763, 62.381207048892975, 60.784988701343536, 61.28877706825733, 60.23630574345589, 61.703665405511856, 61.84666693210602, 63.314334377646446, 62.17887930572033, 60.23729749023914, 57.228128761053085, 49.93866831064224, 26.776224598288536, 7.435823371633887, 0.8178527362179011, 3.145011914893985, 2.379335188306868, 8.930937219411135, 3.6279828613623977, 8.936291132122278, 19.027982465922832, 7.311642235144973, 1.7000223649665713, 0.21517779270652682, 0.25137482851278037, 10.240662340074778, 45.55223688483238, 48.79660539329052, 31.8246641010046, 27.117858566343784, 35.68383201956749, 32.5013317912817, 7.8377387300133705, 0.06702488550217822, 0.09568661393132061, 0.051946715684607625, 0.018517710741434712, 0.03682462927827146, 0.022685205767629668, 0.06371492170728743, 0.05528080298972782, 0.03859761265630368, 0.03890728490659967, 0.028536745194287505, 0.03620077251980547, 0.06780254494515248, 0.06888311938382685, 0.033292399675701745, 0.040889828524086624, 0.05941813527897466, 0.03294528607511893, 0.014529218951793155, 0.03813432696915697, 0.01702569890767336, 0.08198848998290487, 0.03938507587008644, 0.06853847342426889, 0.015113463578018127, 0.04788644801010378, 0.09672003230662085, 0.03791206116147805, 0.03577706556825433, 0.04242427821736783, 0.034031393224722706, 0.025898697786033154, 0.050595287029864267, 0.0310356399131706, 0.16101453424198553, 0.2066187816672027, 0.11743822018615901, 0.13311312126461416, 0.09900559482048266, 0.23333948221988976, 0.18729913397692144, 0.137343407550361, 0.1264493030612357, 0.08120125683490187, 0.13048666063696146, 0.09325822509708814, 0.1615138363558799, 0.18207192071713507, 0.16914810170419514, 0.1045696837536525, 0.07692940285778604, 0.14679473242722452, 0.13272055482957512, 0.11552358308108523, 0.14923700684448704, 0.2359993543359451, 0.18627707788255066, 0.09767296476638876, 0.06812926803831942, 0.15722569223726168, 0.17095778428483754, 0.08016432810109109, 0.24246734945336357, 0.09760582266608253, 0.23932790150865912, 0.19173382257577032, 0.11260435261647217, 0.07793680895701982, 0.09417681838385761, 0.15147415164392442, 0.13045501546002924, 0.22299336473224685, 0.19201949005946517, 0.0912320135103073, 0.1517766955657862, 0.20561179117066786, 5.251875836402178, 39.43589888513088, 61.84669733047485, 47.656427174806595, 42.04930745065212, 37.81587481498718, 51.531151458621025, 45.04485011100769, 11.525511145591736, 0.8491271955426782, 2.973526641726494, 9.253831543028355, 1.9775530602782965, 2.6157594518736005, 3.987646149471402, 1.7889206134714186, 0.27229505125433207, 0.33644837443716824, 2.5972625194117427, 8.691751454025507, 22.372238114476204, 38.790685907006264, 56.49365857243538, 61.21945358812809, 61.17430441081524, 63.51688630878925, 62.80744157731533, 63.37566688656807, 70.50646305084229, 69.03332769870758, 69.77812573313713, 68.84877920150757, 65.58368280529976, 66.44052162766457, 65.67527309060097, 64.74322870373726, 66.634182035923, 66.93875849246979, 70.47386839985847, 69.71322521567345, 69.22425225377083, 60.92145457863808, 63.549876138567924, 65.0945046544075, 65.16716435551643, 68.0374163389206, 66.18539571762085, 35.329930409789085, 39.812781661748886, 60.015989765524864, 69.65028539299965, 65.12985795736313, 65.4671810567379, 59.54186260700226, 56.45657256245613, 53.91153372824192, 62.5119162350893, 60.474188178777695, 67.75563105940819, 65.85103645920753, 69.40780520439148, 63.87092471122742, 63.45015808939934, 63.26251655817032, 62.57123865187168, 62.29682497680187, 63.8470695912838, 64.57303583621979, 63.28204371035099, 59.30386617779732, 61.45274206995964, 59.24269326031208, 60.90687096118927, 60.78508369624615, 65.69955378770828, 62.471007630228996, 64.8294460773468, 55.90271808207035, 50.006046295166016, 23.578187003731728, 8.005416132509708, 0.6949203670956194, 3.354798420332372, 2.529698107391596, 9.318923000246286, 13.788837846368551, 17.924118898808956, 26.080392636358738, 15.53112605586648, 7.4193707294762135, 0.3747376729734242, 0.614205157617107, 15.968227051198483, 48.81598435342312, 47.19523452222347, 41.781497821211815, 36.28103457391262, 45.50187058746815, 36.35312810540199, 6.816380610689521, 0.16278001450700685, 0.18967085983604193, 0.1394836130202748, 0.13247710070572793, 0.21801383583806455, 0.12802056327927858, 0.19943173450883478, 0.10026948715676554, 0.1094362280855421, 0.1523041250766255, 0.14411744952667505, 0.2938926767092198, 0.15779592882608995, 0.12388792878482491, 0.10801251424709335, 0.14671800920041278, 0.1532274013152346, 0.13842097629094496, 0.11981552699580789, 0.11920115488464944, 0.12921923567773774, 0.1258866660646163, 0.10969217997626401, 0.2184418324031867, 0.16073274076916277, 0.22385303891496733, 0.1810529816430062, 0.14556116424500942, 0.13904308900237083, 0.169438058801461, 0.15968758903909475, 0.11914220609469339, 0.18037060654023662, 0.06543318653712049], [0.03167003516864497, 0.10530056562856771, 0.01840278917370597, 0.08509385108482093, 0.027002874376194086, 0.01973413902305765, 0.061564968127640896, 0.013202177269704407, 0.032363011850975454, 0.05406005169788841, 0.01039369100908516, 0.01001339598587947, 0.0996954581933096, 0.06447862877394073, 0.03129348056972958, 0.04556200066872407, 0.016413855664723087, 0.021018358784203883, 0.03507549852656666, 0.09401285569765605, 0.04485313460463658, 0.014626403190050041, 0.03839335506199859, 0.03169725714542437, 0.03553503265720792, 0.04643453627068084, 0.08347007649717852, 0.06168532221636269, 0.0460015784483403, 0.055636662800679915, 0.04816245273104869, 0.05748683695856016, 0.07168484560679644, 0.11373690707841888, 0.021555208004429005, 0.00854777121276129, 0.039507025576313026, 0.03303476682049222, 0.027386327237763908, 0.04475328605622053, 0.012690117637248477, 0.11542179010575637, 0.025058890896616504, 0.6118107517249882, 16.160409338772297, 40.39568938314915, 32.24444657564163, 26.4732763543725, 28.875919729471207, 42.29255899786949, 42.806686609983444, 15.894317217171192, 1.168466038070619, 0.08690831309650093, 1.299613150767982, 1.3099394529126585, 4.459563726559281, 6.236834758892655, 0.2279208690742962, 0.023705304447503295, 0.08505111822159961, 0.16819644573843107, 0.48568103229627013, 8.55788178741932, 18.646019361913204, 37.971867844462395, 53.58582280576229, 57.240827679634094, 56.50134935975075, 59.61930625140667, 61.31199762225151, 66.91130116581917, 65.67839652299881, 65.98099708557129, 63.88407960534096, 66.71725317835808, 65.30046880245209, 63.10336969792843, 62.919702753424644, 64.13567170500755, 64.23862338066101, 66.80029392242432, 62.939039915800095, 65.73448911309242, 61.49496540427208, 64.73423838615417, 63.80408629775047, 70.71738213300705, 53.5431244969368, 38.09615917503834, 42.508569806814194, 51.34759470820427, 74.03469532728195, 67.39439964294434, 65.12481182813644, 58.42713162302971, 58.806632459163666, 56.39653958380222, 56.5014785528183, 55.41721053421497, 63.56957048177719, 61.28258340060711, 66.1718912422657, 64.52703550457954, 61.53869345784187, 64.97397512197495, 62.13339954614639, 63.82795661687851, 63.64544481039047, 68.24054583907127, 66.18259146809578, 59.89778570830822, 63.288651555776596, 66.68036475777626, 62.00908161699772, 61.29845894873142, 58.283750116825104, 54.682679548859596, 39.62092995643616, 25.12352418154478, 7.413851050660014, 0.6197631312534213, 0.2714549994561821, 1.0533653455786407, 1.9059860380366445, 0.8512541907839477, 6.293782778084278, 2.425178778357804, 9.65768527239561, 8.163316659629345, 0.5063988862093538, 0.1823180020437576, 0.3077709866920486, 16.902931295335293, 42.22314052283764, 31.545073203742504, 30.424889512360096, 31.422569677233696, 36.96898005902767, 21.867211014032364, 1.5942380600608885, 0.11227037131902762, 0.050216940144309774, 0.10448216227814555, 0.05604917445452884, 0.044501178490463644, 0.0531301814771723, 0.0054675276351190405, 0.08791206782916561, 0.04360765124147292, 0.053460426061064936, 0.05723805050365627, 0.025430191089981236, 0.043194434547331184, 0.01538930409878958, 0.015821636661712546, 0.012604548010131111, 0.03183606102538761, 0.06518038877402432, 0.06764336911146529, 0.07996713204192929, 0.026454549697518814, 0.022782686864957213, 0.07001725462032482, 0.11257287813350558, 0.020487342844717205, 0.033985535919782706, 0.04733439775009174, 0.006504989323730115, 0.06423830651328899, 0.04200819312245585, 0.05298282434523571, 0.04236264285282232, 0.06666481771389954, 0.034298492173547857, 0.019796446031250525, 0.01274973807085189, 0.035656841355375946, 0.022291926870821044, 0.017694134621706326, 0.04515108092164155, 0.013940145727247, 0.05304518330376595, 0.04223080031806603, 0.08105735440040007, 0.02998003132233862, 0.005987826962154941, 0.03588659172237385, 0.08579666493460536, 0.06074929216993041, 0.02086107913783053, 0.05316793452948332, 0.09430328776943497, 0.025401314123882912, 0.02261394289234886, 0.024602466364740394, 0.04219699549139477, 0.06475773567217402, 0.040096075608744286, 0.03385725569387432, 0.03628377060522325, 0.0755872213630937, 0.008674371401866665, 0.05071193409094121, 0.06003743896144442, 0.03769917610043194, 0.03979958019044716, 0.07857654767576605, 0.04923931272060145, 0.038527453725691885, 0.04001127781521063, 0.07367585712927394, 0.0671792151115369, 0.022970732243265957, 0.012258973438292742, 0.025950859635486268, 0.03865460959787015, 0.10068255171063356, 0.05768237431766465, 3.0261341063305736, 30.02545114606619, 47.22286283969879, 33.53893831372261, 21.552606895565987, 24.752555787563324, 61.65737248957157, 55.363299027085304, 12.278549037873745, 0.8735563221853226, 0.14352497819345444, 0.505358810769394, 0.7025653787422925, 2.220232975669205, 3.1266940478235483, 1.5117510175332427, 0.2993592177517712, 0.05145789640664589, 0.22257602540776134, 1.945337438955903, 11.477108392864466, 24.767038710415363, 42.881428599357605, 54.22375537455082, 60.84534466266632, 59.364928901195526, 60.386371091008186, 64.91506308317184, 67.09589526057243, 66.29996716976166, 66.00143998861313, 64.83249351382256, 67.84086808562279, 65.29168367385864, 63.339200243353844, 63.06232430040836, 64.92225989699364, 66.81652665138245, 69.43282306194305, 65.38112327456474, 65.87511956691742, 64.35476794838905, 68.66895765066147, 66.35699450969696, 70.07327869534492, 57.984417378902435, 39.56923373043537, 42.47027926146984, 54.50565084815025, 74.79267865419388, 66.77315577864647, 67.53780394792557, 60.956310108304024, 60.32391004264355, 57.802657932043076, 57.9263336956501, 59.139186814427376, 64.00080174207687, 63.83101925253868, 67.72263363003731, 64.8017455637455, 62.86859929561615, 65.94313591718674, 61.80101618170738, 62.67601042985916, 63.19097399711609, 66.917335242033, 66.11721217632294, 62.13315635919571, 63.40772956609726, 65.04775196313858, 61.28663398325443, 60.57644069194794, 60.59352457523346, 55.913346111774445, 48.53989876806736, 30.9689462184906, 12.194524146616459, 1.7419797135517001, 0.6335369765292853, 2.9080739663913846, 2.6451242761686444, 4.031085893511772, 6.82314139790833, 2.964213816449046, 1.313608274795115, 0.3952308342559263, 0.4258395277429372, 0.19198794878320768, 0.24119698558934033, 12.266728822141886, 51.293557807803154, 38.24752405285835, 30.203847773373127, 33.52373152971268, 40.63812017440796, 29.272107370197773, 3.8474854454398155, 0.19508166558807716, 0.07248901456478052, 0.020681492387666367, 0.06292500198469497, 0.059459224285092205, 0.030318393146444578, 0.0542010560457129, 0.07396763248834759, 0.012113687826058595, 0.06797597001423128, 0.015132617481867783, 0.034429176957928576, 0.04786727833561599, 0.027729986140911933, 0.02343838361412054, 0.05971933962428011, 0.045191078970674425, 0.044748595682904124, 0.08177657713531516, 0.034414452748023905, 0.01225871275892132, 0.05942989831964951, 0.034803160015144385, 0.07897323303041048, 0.06332482662401162, 0.06091236798965838, 0.06983991101151332, 0.04111760477826465, 0.05120415611600038, 0.08544685362721793, 0.06913031393196434, 0.011475706141936826, 0.08051380544202402, 0.023412809205183294, 0.00880769730429165, 0.11996296947472729, 0.2707819902570918, 0.15441480791196227, 0.21687070577172562, 0.13086505205137655, 0.10566492303041741, 0.17788752884371206, 0.17179014743305743, 0.14512933819787577, 0.1703399166581221, 0.09825311644817702, 0.12151216564234346, 0.18544469989137724, 0.22737534600310028, 0.11919916592887603, 0.13845014269463718, 0.10707817258662544, 0.14237172523280606, 0.07939475806779228, 0.13967189588584006, 0.17550038115587085, 0.25588379125110805, 0.10274705069605261, 0.1052747388894204, 0.1528667620732449, 0.13073713547782972, 0.23788657650584355, 0.168173661804758, 0.20793495088582858, 0.12595895124832168, 0.15789833036251366, 0.1336633347091265, 0.12684106797678396, 0.21931045688688755, 0.12022399765555747, 0.21956148091703653, 0.17497293680207804, 0.07200877080322243, 0.10681164509151131, 0.1917335405596532, 0.12972977390745655, 0.2202894090441987, 0.1615200110245496, 2.510553072206676, 31.932935491204262, 58.006224408745766, 47.91311480104923, 37.539112865924835, 33.504470363259315, 55.05479738116264, 55.273893624544144, 21.128946729004383, 1.6655874252319336, 0.21579555643256754, 5.95197924412787, 6.439842190593481, 11.819593515247107, 9.618064798414707, 1.1451021605171263, 0.43382830219343305, 0.2251737203914672, 0.4218454076908529, 1.6267431783489883, 10.59058841317892, 21.593055725097656, 40.96877083182335, 55.856322571635246, 59.108967036008835, 59.597434625029564, 65.19617959856987, 64.23164695501328, 68.8386033475399, 67.46449828147888, 68.10249164700508, 66.77638560533524, 69.0060755610466, 67.78760254383087, 64.4579704105854, 65.54559364914894, 65.67779615521431, 66.29933640360832, 71.6857297718525, 68.72135683894157, 70.19480377435684, 65.89701399207115, 69.73004311323166, 71.0276734828949, 69.86055850982666, 59.54984597861767, 44.974455088377, 46.56663425266743, 60.76357305049896, 73.08748215436935, 73.39003711938858, 69.32487845420837, 64.58885818719864, 62.56075121462345, 64.28880348801613, 61.44472450017929, 61.19372136890888, 67.04336687922478, 66.08010336756706, 68.78279194235802, 67.39379927515984, 62.73000553250313, 66.23739212751389, 60.56609384715557, 63.032826483249664, 63.03274668753147, 69.55898389220238, 67.49159842729568, 62.090773433446884, 62.24103257060051, 66.9895389676094, 61.813050135970116, 59.6188160777092, 58.65274831652641, 55.63630297780037, 43.28363701701164, 27.982175387442112, 9.198425766080618, 1.1813322664238513, 0.30247202259488404, 2.61679133400321, 4.550689486786723, 6.499733626842499, 12.853745073080063, 8.890603333711624, 22.547216825187206, 14.982500094920397, 1.3018207135610282, 0.2189279391313903, 0.6386945466510952, 21.496368013322353, 53.55043910443783, 41.48044757544994, 42.00422666966915, 42.03641094267368, 50.790229216217995, 31.508680656552315, 3.1982142850756645, 0.39143062254879624, 0.18291305605089292, 0.3250825311988592, 0.1709867428871803, 0.21108959801495075, 0.11843580767163076, 0.15167116216616705, 0.09107447040150873, 0.16931478807237, 0.1857329352060333, 0.16348167060641572, 0.118869140278548, 0.1866167737171054, 0.09408189027453773, 0.08373282646061853, 0.16581101983319968, 0.20046395802637562, 0.19504003110341728, 0.20644125994294882, 0.13055159855866805, 0.08537684683687985, 0.13763904949883, 0.1568284651148133, 0.26125135947950184, 0.19093184295343235, 0.09303879429353401, 0.11155368672916666, 0.09085304322070442, 0.16274047287879512, 0.11885029714903794, 0.1568111582309939, 0.08836635868647136, 0.2297940943390131, 0.1874453667551279, 0.09807457798160613], [0.08745510524022393, 0.05480424399138428, 0.04043461369292345, 0.11107284182799049, 0.03610149913583882, 0.04341868931078352, 0.032557803351664916, 0.03758457365620416, 0.06571022284333594, 0.04974013252649456, 0.09640241536544636, 0.019869647767336573, 0.018989421660080552, 0.06692756025586277, 0.06468257095548324, 0.043333531575626694, 0.04225655284244567, 0.07077958871377632, 0.03993498503405135, 0.02985330589581281, 0.022496596357086673, 0.004914996834486374, 0.023893917568784673, 0.026324653445044532, 0.0527068418887211, 0.035967812364106067, 0.010027884563896805, 0.04871515979175456, 0.04598297651682515, 0.020766798552358523, 0.04801307695743162, 0.10215820846497081, 0.056848367312341, 0.026557661840342917, 0.04401729078381322, 0.03777453748625703, 0.04561880836263299, 0.007121477947293897, 0.04652762756450102, 0.060048927407478914, 0.04994348841137253, 0.07869041539379396, 0.10686172521673143, 0.06132087204605341, 0.4659404681297019, 15.810682754963636, 38.151491805911064, 42.74958707392216, 31.35543867945671, 15.7203976996243, 27.3832743242383, 48.82063150405884, 30.498233176767826, 3.831638633273542, 0.17643538332777098, 0.8350283489562571, 1.1754613439552486, 1.775311406236142, 0.8373169542755932, 0.5691591091454029, 0.23562323389342055, 0.2950498036807403, 0.10074590143631212, 0.08910337812267244, 1.1093769525177777, 6.0522895865142345, 22.177958339452744, 40.57921953499317, 54.414402544498444, 56.23248338699341, 58.96813899278641, 56.17395132780075, 65.04808634519577, 65.34816384315491, 64.6159203350544, 64.79375839233398, 69.95196640491486, 64.54427137970924, 66.57727628946304, 66.0663253068924, 69.38417807221413, 68.69435548782349, 68.59027907252312, 62.74673603475094, 63.42240057885647, 64.31864708662033, 60.34883290529251, 60.24031452834606, 37.76917912065983, 25.6773254647851, 35.50631694495678, 47.187665328383446, 64.5479267835617, 65.75171738862991, 61.95123732089996, 65.61003059148788, 63.448072001338005, 61.04857675731182, 58.1468016654253, 62.294298112392426, 62.111277133226395, 63.588413670659065, 70.41749462485313, 66.44054442644119, 64.08894181251526, 65.33259987831116, 64.56108927726746, 66.23247519135475, 64.95950549840927, 63.47814358770847, 63.51040005683899, 58.855064660310745, 56.30338758230209, 51.648622155189514, 48.146619871258736, 44.24260675907135, 31.551983132958412, 18.1890881806612, 6.189917251467705, 0.7754743820987642, 0.29966709029395133, 0.23623872664757073, 1.3829226116649806, 1.1543625011108816, 3.4300491074100137, 3.4131298027932644, 7.3393303994089365, 0.6093287724070251, 1.2411143397912383, 2.010773252695799, 0.13203740789322183, 2.141838907264173, 25.52954949438572, 39.531524553895, 31.60202644765377, 35.27346923947334, 30.797079540789127, 33.39660555124283, 12.148474417626858, 0.17122877208748832, 0.1873624837026, 0.0635538311325945, 0.08581810558098368, 0.023205148863780778, 0.024773149198153988, 0.028629472835746128, 0.0544677468133159, 0.030626017069153022, 0.02497209672583267, 0.036501891518128105, 0.05014086258597672, 0.035402837602305226, 0.05796914760139771, 0.0319819338619709, 0.03681828762637451, 0.10183817954384722, 0.05903869001485873, 0.07181892200605944, 0.06681404134724289, 0.018835765549738426, 0.03321971002151258, 0.0537963740498526, 0.004016420198240667, 0.049627660046098754, 0.019362310049473308, 0.0529683969944017, 0.028705324039037805, 0.02098343516991008, 0.03378600209543947, 0.023364441585727036, 0.07898959738668054, 0.050687161201494746, 0.033196944641531445, 0.01825216102588456, 0.03889303938194644, 0.027873604703927413, 0.053658278920920566, 0.02565213591879001, 0.06088824819016736, 0.10628449759678915, 0.022762895641790237, 0.012961147185706068, 0.07392147090286016, 0.019228168712288607, 0.017747624915500637, 0.05462524168251548, 0.08015729254111648, 0.04426773593877442, 0.04211213832604699, 0.09197002000291832, 0.0660811630950775, 0.06548555247718468, 0.052296244975877926, 0.06751629858626984, 0.0174279819111689, 0.031562613003188744, 0.018122342698916327, 0.008230352796090301, 0.03344261407619342, 0.03983232374594081, 0.031197257412713952, 0.06010078126564622, 0.044127150904387236, 0.04174867150140926, 0.03559613738616463, 0.025019725908350665, 0.050526167105999775, 0.10476342140464112, 0.06470301712397486, 0.03869557986035943, 0.06946916371816769, 0.03825296298600733, 0.04655447104596533, 0.02793300063785864, 0.011384739245841047, 0.015197884731605882, 0.02504886819224339, 0.07048577987006865, 0.07749326439807191, 0.051744009178946726, 1.280302230734378, 24.778314605355263, 46.5302512049675, 40.22942170500755, 24.304415434598923, 18.842561915516853, 44.564943462610245, 71.42932713031769, 28.285680301487446, 2.3542104614898562, 0.13795852923067287, 0.615355724003166, 0.6170485925395042, 1.5500726737082005, 1.276014398317784, 1.7253034771420062, 0.7215040968731046, 0.5309936602134258, 0.029398668084468227, 0.28867425047792494, 2.7967173792421818, 9.72163014113903, 29.782100804150105, 47.77637153863907, 56.33556425571442, 61.79712899029255, 61.3606122136116, 60.98943293094635, 65.43666109442711, 64.36144798994064, 65.4860508441925, 66.52923166751862, 70.31472533941269, 66.02424636483192, 68.43530058860779, 66.5082947909832, 69.23728555440903, 68.0744643509388, 68.8738502562046, 63.9971387386322, 62.55031697452068, 64.72982302308083, 63.31363521516323, 63.050088956952095, 44.386896416544914, 30.902799367904663, 37.487352043390274, 52.72852040827274, 65.90661227703094, 66.23403310775757, 65.79930603504181, 67.03299343585968, 65.63538283109665, 62.14493952691555, 57.96156920492649, 62.333607003092766, 63.521742448210716, 63.68995562195778, 69.4354297220707, 67.45862379670143, 64.71628814935684, 66.47388383746147, 65.3078556060791, 65.564334243536, 64.43437367677689, 67.5964044034481, 64.6679699420929, 61.72529384493828, 60.97981184720993, 55.718853548169136, 53.976924419403076, 48.70291382074356, 37.7757603675127, 24.784097895026207, 9.715530518442392, 1.7653997568413615, 0.8916412736289203, 1.5495841624215245, 2.682094629853964, 3.2437790650874376, 2.845078334212303, 4.704528506845236, 5.25540204718709, 2.2676351945847273, 0.8160650508943945, 0.82497937255539, 0.09123815107159317, 0.9465797943994403, 25.424029156565666, 55.776203870773315, 37.94472210109234, 30.34134339541197, 33.225553929805756, 39.043379947543144, 20.41972428560257, 0.44628620089497417, 0.1962392230052501, 0.12939635664224625, 0.04665361455408856, 0.020453074175748043, 0.014640835179307032, 0.03108017805061536, 0.0514761087106308, 0.007432620577674243, 0.045948385013616644, 0.07274183459230699, 0.018976322753587738, 0.06471676912042312, 0.07000638957833871, 0.04730501241283491, 0.02604111778055085, 0.10517235961742699, 0.04930046197841875, 0.03532198061293457, 0.034407509956508875, 0.01128595939007937, 0.03794716845732182, 0.050273309971089475, 0.03842053993139416, 0.017846128321252763, 0.06433798436773941, 0.07494140445487574, 0.027423607170931064, 0.0028506975331765716, 0.06144336723082233, 0.04436486080521718, 0.056906844838522375, 0.03954928717575967, 0.09516687307041138, 0.05039653246058151, 0.07327614381210878, 0.05243628824246116, 0.1414601452415809, 0.1954081215080805, 0.21720565186114982, 0.2228539893985726, 0.1259384531294927, 0.11503953210194595, 0.2241693125688471, 0.08825824261293747, 0.10996850382070988, 0.1369592867558822, 0.25287218566518277, 0.13856698642484844, 0.18193918018369004, 0.17571661330293864, 0.2252897180733271, 0.24953551939688623, 0.20202668354613706, 0.1551177553483285, 0.13439277681754902, 0.11470182522316463, 0.10096519865328446, 0.12915343686472625, 0.20049150654813275, 0.12827794009353966, 0.12026368771330453, 0.1636867260094732, 0.1879460344207473, 0.13159768539480865, 0.11451630314695649, 0.11097808441263624, 0.15280072577297688, 0.204994636005722, 0.16766539454692975, 0.13209732889663428, 0.1907554641366005, 0.11076058319304138, 0.13819827261613682, 0.06835816864622757, 0.1847186716622673, 0.1788640912855044, 0.11748329823603854, 0.21559118380537257, 0.32615247066132724, 0.17891666502691805, 1.052662383299321, 25.213883332908154, 55.367406606674194, 57.85911910235882, 40.91629944741726, 23.409561552107334, 36.887903809547424, 60.73372185230255, 37.56990261375904, 5.20949718542397, 0.36386265652254224, 1.815640542190522, 4.250371176749468, 4.917980628088117, 2.159272846765816, 1.8528926745057106, 0.6381933891680092, 0.9403630311135203, 0.14661574125057086, 0.3056216082768515, 2.248568767681718, 7.237446941435337, 26.47651758044958, 44.55580495297909, 56.90602384507656, 60.545122772455215, 64.74322110414505, 62.80939847230911, 66.72774821519852, 63.12269166111946, 65.94947397708893, 65.27887836098671, 70.82755342125893, 65.17653465270996, 69.49754878878593, 67.66784816980362, 69.88626793026924, 70.76047942042351, 74.47949185967445, 67.11025848984718, 67.26707607507706, 68.2969956099987, 64.15352314710617, 65.9055407345295, 51.77403822541237, 30.523701310157776, 37.859002500772476, 56.527518555521965, 64.37918543815613, 65.97998633980751, 66.9109819829464, 69.06691789627075, 68.48105013370514, 64.36443462967873, 61.26776039600372, 66.81287884712219, 65.67635223269463, 67.75206685066223, 71.47048652172089, 71.08749747276306, 67.1226154267788, 66.58206403255463, 67.41590648889542, 64.1315907239914, 63.87724757194519, 64.57593888044357, 64.29134175181389, 58.838858529925346, 59.67077448964119, 51.42341583967209, 49.79628995060921, 47.03906670212746, 35.76798990368843, 20.832176953554153, 7.9274471662938595, 1.0881214868277311, 0.45466492942068726, 0.7221524370834231, 3.3879122184589505, 5.820941375568509, 6.061019618064165, 10.033390112221241, 16.358243823051453, 7.559622153639793, 5.852133426815271, 4.875534055754542, 0.39274217560887337, 3.4166671754792333, 31.939607933163643, 51.562853157520294, 42.112980633974075, 45.57104967534542, 43.20650115609169, 47.57379300892353, 21.951015517115593, 0.505938398418948, 0.30093628156464547, 0.2000853736535646, 0.1652404121705331, 0.10090705138281919, 0.0990473257843405, 0.13787576492177323, 0.19142001285217702, 0.09984785079723224, 0.14995329809607938, 0.21182156342547387, 0.12541672331281006, 0.1613628538325429, 0.21156253904337063, 0.206451932026539, 0.1931625755969435, 0.19228575780289248, 0.19457641144981608, 0.15588641253998503, 0.1531316791079007, 0.10680514387786388, 0.11801528453361243, 0.1344198948936537, 0.10229940206045285, 0.10832147032488137, 0.13403170712990686, 0.2446938815410249, 0.13348389824386686, 0.06292284233495593, 0.12564156437292695, 0.09996568158385344, 0.15234871330903843, 0.10689438713598065, 0.1563250515027903, 0.17246367613552138, 0.13383092649746686, 0.1253146631643176], [0.01592142398294527, 0.06126174142991658, 0.03731439108378254, 0.03565784325473942, 0.053375939969555475, 0.0663577466912102, 0.05538894503843039, 0.043828506968566217, 0.020748463794006966, 0.023078146987245418, 0.016291373467538506, 0.03576501308998559, 0.06917087230249308, 0.026905918348347768, 0.07550209702458233, 0.07171102115535177, 0.026234343349642586, 0.09750745099154301, 0.011880146939802216, 0.07948133701574989, 0.0552908776444383, 0.05982477654470131, 0.035623262883746065, 0.0028664078718065866, 0.00987065594017622, 0.0315412428608397, 0.034946765590575524, 0.048610004887450486, 0.01923815616464708, 0.051715410518227145, 0.06471878034062684, 0.09181686298688874, 0.0165088654102874, 0.023680117810727097, 0.005489932145792409, 0.01691645291430177, 0.05705588664568495, 0.019164167752023786, 0.05138504347996786, 0.036245524024707265, 0.006698689403492608, 0.08850706988596357, 0.05067003243311774, 0.06073506890970748, 0.027159790370205883, 0.10801416923641227, 8.988337889313698, 40.94256743788719, 46.484224274754524, 33.29893559217453, 26.77554253488779, 27.847780399024487, 42.63316512107849, 38.70729938149452, 9.665583148598671, 0.8716840320266783, 0.021647894827765413, 0.7624412002041936, 1.3516453024931252, 0.6397872848901898, 0.601014937274158, 0.2951039804611355, 0.2925359713844955, 0.40202543372288346, 0.11056685296352953, 0.022855354254716076, 2.1716041350737214, 8.22383126243949, 25.39230465888977, 38.868258744478226, 52.81458958983421, 59.21745501458645, 62.45408333837986, 60.326524302363396, 61.68879680335522, 62.82564640045166, 61.953889578580856, 62.33794257044792, 61.045381128787994, 57.71775908768177, 62.6666135340929, 65.15860721468925, 67.46472626924515, 67.93593898415565, 71.91748693585396, 68.41512367129326, 58.6602833122015, 52.07474268972874, 29.52116120606661, 30.79164583235979, 37.99392946064472, 41.6449673473835, 62.05283626914024, 78.55225011706352, 69.73483085632324, 70.52505165338516, 65.87329566478729, 69.7257873415947, 64.36519458889961, 64.89107877016068, 67.21766352653503, 66.8330405652523, 67.88612365722656, 67.55310192704201, 64.1015875339508, 64.7269731760025, 59.048873260617256, 52.87824757397175, 45.28696931898594, 43.21647182106972, 37.585211992263794, 31.98652781546116, 26.268264055252075, 25.03007959574461, 19.0512790158391, 11.763917952775955, 4.585481369867921, 0.5907567939721048, 0.22868398984428495, 0.42158642783761024, 1.100337237585336, 1.9100849493406713, 2.7495065750554204, 3.902554465457797, 1.166898978408426, 3.690422298386693, 4.049614649266005, 1.876428136602044, 0.512773934751749, 0.03646201592346188, 5.428324118256569, 34.72304977476597, 29.957533590495586, 21.46740596741438, 28.414677679538727, 32.87150792777538, 33.59850771725178, 8.201766796410084, 0.1638094920781441, 0.09723030336317606, 0.14041756134247407, 0.08573159342631698, 0.11058282398153096, 0.05134068902407307, 0.024598085838078987, 0.06595660102902912, 0.042264727599103935, 0.01729978517687414, 0.07553301489679143, 0.04833722108742222, 0.01415849485056242, 0.06956327546504326, 0.05820750317070633, 0.03322370277601294, 0.0337136686721351, 0.10727207351010293, 0.04925327993987594, 0.046082160843070596, 0.024172445591830183, 0.042217745940433815, 0.04831650403502863, 0.04729910120659042, 0.04596788123308215, 0.021746941856690682, 0.031736884120618924, 0.06616941187530756, 0.06046510527085047, 0.05311412882292643, 0.013855801571480697, 0.0865092825551983, 0.0670928142790217, 0.1277359644882381, 0.052982071065343916, 0.049117118105641566, 0.06803550510085188, 0.03275804592703935, 0.027081927946710493, 0.014445028791669756, 0.04803963100130204, 0.0924729512189515, 0.014981365002313396, 0.07068451959639788, 0.013228308289399138, 0.02332794276298955, 0.04425638479006011, 0.0016677120493113762, 0.03956280168495141, 0.09765988070284948, 0.03478887738310732, 0.03914463486580644, 0.0574474771565292, 0.08698830177308992, 0.0467372212006012, 0.013384133326326264, 0.012452763967303326, 0.08250503960880451, 0.04020821783342399, 0.06079738333937712, 0.06396855067578144, 0.027549074657144956, 0.019033421740459744, 0.08696449367562309, 0.030360847704287153, 0.01689327193162171, 0.06401748047210276, 0.06150201545096934, 0.04678105244238395, 0.10722059814725071, 0.03166339665767737, 0.010517444134165999, 0.018569668500276748, 0.021318167891877238, 0.05327904516889248, 0.10027440017438494, 0.03702077148773242, 0.007898176772869192, 0.0038962456164881587, 0.0692183623323217, 0.04526785414782353, 0.04918053833534941, 0.10911323057371192, 0.8599866565782577, 16.010009609162807, 49.70874264836311, 43.23774307966232, 21.637492440640926, 16.54670801013708, 35.975606963038445, 66.79622814059258, 45.371362790465355, 6.737381899729371, 0.47972595028113574, 0.13823944696923718, 0.23199644725536928, 0.9606465802062303, 1.1058160685934126, 1.7270702635869384, 2.1825819835066795, 0.7314083247911185, 1.187084682751447, 0.22009063221048564, 0.30492627527564764, 3.421265403740108, 12.623864058405161, 32.06479601562023, 45.35200282931328, 59.66494180262089, 61.41816392540932, 65.12856602668762, 63.49767453968525, 64.82525110244751, 64.8732653260231, 66.97465896606445, 65.99077016115189, 62.48586103320122, 62.767270132899284, 66.58349275588989, 71.35523110628128, 70.10178476572037, 69.31622251868248, 70.38825899362564, 69.9007299542427, 61.90352328121662, 56.95824444293976, 36.79135859012604, 29.886703491210938, 38.970431461930275, 49.719078093767166, 63.59705060720444, 75.47867104411125, 70.37001237273216, 72.19341292977333, 68.62651392817497, 72.33079075813293, 66.16423845291138, 67.14276194572449, 67.73295387625694, 68.59835743904114, 70.90488687157631, 67.45755225419998, 66.359943151474, 64.76977407932281, 60.81834711134434, 57.01381266117096, 49.60354529321194, 48.40516559779644, 43.383111879229546, 38.296438828110695, 30.29018674045801, 30.28955217450857, 21.843057610094547, 16.393532529473305, 7.221923349425197, 1.7580846743658185, 0.8121471048798412, 1.100567956455052, 3.379133502021432, 4.798064287751913, 3.071049121208489, 4.445018582046032, 4.42145842127502, 2.168048000894487, 1.0025161178782582, 0.7828563766088337, 0.15136036556214094, 0.12036666070343927, 4.36623265966773, 40.25607727468014, 48.749267533421516, 25.476054064929485, 28.113663531839848, 36.532600075006485, 38.57089050114155, 14.699484631419182, 0.510304186027497, 0.10997202160069719, 0.09826476816670038, 0.12478196440497413, 0.08953770520747639, 0.05367257268517278, 0.02820064877596451, 0.050972895478480496, 0.02233735373010859, 0.017538532229082193, 0.028435872482077684, 0.04654228127037641, 0.11112187552498654, 0.1297695975517854, 0.06017970124958083, 0.11974267035839148, 0.02086971959215589, 0.07762848370475695, 0.01958696186193265, 0.015259144383890089, 0.05452615754620638, 0.06029097887221724, 0.06265658201300539, 0.02607496156997513, 0.08027902702451684, 0.011836087487608893, 0.02470324259775225, 0.012235131944180466, 0.030192222475307062, 0.024692713377589826, 0.06349005838274024, 0.032758250017650425, 0.08349286785232835, 0.03070730821491452, 0.01818558852392016, 0.007602882706123637, 0.01848808791692136, 0.016096270264824852, 0.1304928056197241, 0.14592462364817038, 0.09833395859459415, 0.13812129705911502, 0.10196270450251177, 0.1579639659030363, 0.13452361745294183, 0.08242203039117157, 0.10778409603517503, 0.08138931705616415, 0.12919792119646445, 0.19987650361144915, 0.2527015213854611, 0.1347439017263241, 0.28842637315392494, 0.1823264328413643, 0.16238069452811033, 0.1223596314957831, 0.10312263679224998, 0.17337225785013288, 0.15309849026380107, 0.15615458018146455, 0.15119955700356513, 0.116708666755585, 0.12827957281842828, 0.18094122904585674, 0.15297125646611676, 0.2511089318431914, 0.14466292806901038, 0.1530206241295673, 0.21387811400927603, 0.26836980250664055, 0.10099380102474242, 0.07433124774252065, 0.07010936256847344, 0.09949527870048769, 0.15416835551150143, 0.1052164877182804, 0.14072371210204437, 0.09538569531287067, 0.07803374828654341, 0.15358732809545472, 0.1811855292180553, 0.14141186111373827, 0.21025708643719554, 0.5997731757815927, 15.850343126803637, 59.0909294039011, 62.46211610734463, 42.44143880903721, 37.612448930740356, 36.145568042993546, 56.11686699092388, 49.19325090944767, 11.648956071585417, 1.4811448473483324, 0.22902068740222603, 2.8949304716661572, 6.023190747946501, 1.3510556216351688, 2.7149531291797757, 2.0953816501423717, 1.1752888094633818, 0.8103581133764237, 0.3024704789277166, 0.19984698097687215, 3.1985698034986854, 10.489068310707808, 28.56559418141842, 42.51673936843872, 56.494152545928955, 64.77077722549438, 71.30736127495766, 67.9366685450077, 69.408770352602, 69.37061280012131, 69.5440810918808, 70.42874962091446, 68.10563787817955, 65.02969533205032, 67.50177428126335, 71.61994010210037, 70.25224909186363, 70.55993378162384, 72.57595360279083, 68.42223688960075, 65.16992300748825, 61.1949373036623, 42.38499663770199, 35.24756222963333, 45.94113081693649, 53.281356543302536, 65.35235121846199, 78.08238252997398, 74.86748903989792, 74.32437658309937, 71.27733528614044, 75.39332002401352, 68.78267034888268, 69.38186779618263, 68.36272448301315, 71.62458345293999, 71.22210904955864, 66.86627358198166, 66.259955316782, 63.42685393989086, 60.6486976146698, 52.316063940525055, 47.08974078297615, 46.8084342777729, 40.109002366662025, 35.603033155202866, 28.518442511558533, 27.886300832033157, 21.20373621582985, 13.440691027790308, 6.330469809472561, 0.8261820080224425, 0.5693474365398288, 0.8637302275747061, 3.1976977502927184, 4.825836047530174, 5.894891582429409, 11.18072809651494, 7.008066074922681, 9.421709384769201, 10.759303160011768, 4.670098554342985, 1.1334259808063507, 0.35889178107026964, 7.626962615177035, 42.506187334656715, 39.0852726995945, 29.21072356402874, 39.84997406601906, 44.73599508404732, 47.290541008114815, 15.260572973638773, 0.46231923275627196, 0.22245575295528397, 0.20367837772937492, 0.277152496855706, 0.16576923691900447, 0.14286212157458067, 0.11952799672144465, 0.17393574089510366, 0.09351604719995521, 0.094743618828943, 0.1782993317465298, 0.20535143092274666, 0.14639256260124967, 0.2497175830649212, 0.1463006847188808, 0.36416794639080763, 0.14059106062632054, 0.2052729413844645, 0.12406904250383377, 0.1108541309076827, 0.13816150662023574, 0.13898897159378976, 0.10484176993486471, 0.11006560642272234, 0.23271503916475922, 0.1016826624982059, 0.18272337794769555, 0.1324218255467713, 0.17815918457927182, 0.10365852678660303, 0.11417968722525984, 0.22526576154632494, 0.17471097351517528, 0.13893944065785035, 0.22072972526075318, 0.07228717266116291, 0.11586382810492069, 0.15553019649814814], [0.11098017726908438, 0.031959168481989764, 0.045280567137524486, 0.025306873976660427, 0.024276268341054674, 0.026117577544937376, 0.027052722580265254, 0.03680223868286703, 0.02060457434708951, 0.02497612287697848, 0.06459490847191773, 0.05595925584202632, 0.018626518867677078, 0.05326583865098655, 0.04705791063315701, 0.0296817194976029, 0.07739884837064892, 0.020833005546592176, 0.0517963120364584, 0.08039123975322582, 0.014807004827162018, 0.0344611523905769, 0.054682613408658653, 0.044470861757872626, 0.015563939796265913, 0.028713966348732356, 0.026436224216013215, 0.060540136400959454, 0.07269590307259932, 0.02795520569634391, 0.006825926911915303, 0.057185925761586986, 0.045320546632865444, 0.07080596464220434, 0.035807230160571635, 0.024232882387877908, 0.032522250767215155, 0.026893774956988636, 0.018145291760447435, 0.040856342820916325, 0.04280876637494657, 0.05863492828211747, 0.022161887754919007, 0.04962173028616235, 0.042665620931074955, 0.028634222580876667, 0.07594809809233993, 5.391471795737743, 37.65435308218002, 51.89639925956726, 48.674593940377235, 36.47273048758507, 24.018222391605377, 39.5046029984951, 46.555793434381485, 22.260949686169624, 3.1648981478065252, 0.5617902951780707, 0.13136531895725057, 0.6148977298289537, 1.4686658419668674, 0.9862356539815664, 1.2630822672508657, 1.6723378817550838, 0.30710715043824166, 0.10052580269984901, 0.10361839886172675, 0.2864733966998756, 1.772144038695842, 8.317368943244219, 19.669844023883343, 29.89772479981184, 39.58358556032181, 43.46644140779972, 46.267419308423996, 45.637192726135254, 43.84966604411602, 45.27884915471077, 51.33513517677784, 56.00323028862476, 60.127863362431526, 63.53936970233917, 67.0722833275795, 64.77244153618813, 64.6251006424427, 59.30089473724365, 56.86443507671356, 51.248598620295525, 35.473976880311966, 54.79015298187733, 51.25436291098595, 33.94766718149185, 58.44092108309269, 71.60193666815758, 66.72365963459015, 68.90547215938568, 69.04765293002129, 65.80871433019638, 64.99773904681206, 71.01255029439926, 72.84396082162857, 72.6704241335392, 75.28365030884743, 64.47027415037155, 63.38740445673466, 56.207157745957375, 37.682900950312614, 24.890205301344395, 16.002858392894268, 10.645289327949286, 8.488806243985891, 5.938900820910931, 3.086057840846479, 2.816821150481701, 1.7042416823096573, 0.921289895195514, 0.1606473047286272, 0.45859742152970284, 0.22994708066107705, 1.3268994865939021, 4.192175874486566, 6.178735876455903, 1.6101171704940498, 2.2469434048980474, 2.707025329582393, 1.4648984628729522, 1.7199184536002576, 0.17608983936952427, 1.7284652637317777, 17.59265698492527, 41.78892642259598, 27.21938531845808, 24.994832687079906, 32.23929025232792, 33.011104837059975, 25.364936627447605, 4.911982649937272, 0.10032333739218302, 0.16346553631592542, 0.0716569482756313, 0.04243994124408346, 0.06580932182259858, 0.03974278733949177, 0.08163949503796175, 0.08507906008162536, 0.06691129980026744, 0.009850817405094858, 0.0258201191900298, 0.02580296259111492, 0.0657773797865957, 0.04277528067177627, 0.03665800599264912, 0.06840253423433751, 0.02040550436504418, 0.03322381409816444, 0.053300270592444576, 0.053417975213960744, 0.03132618330710102, 0.02190341256209649, 0.06589265016373247, 0.057708861568244174, 0.022067200843594037, 0.028411073617462534, 0.01982182377105346, 0.027686017601809, 0.04108122840989381, 0.04750855754537042, 0.02888392558816122, 0.030544451328751165, 0.07976120832609013, 0.03609938772569876, 0.06282709786319174, 0.039668913959758356, 0.07978402194567025, 0.0765692385903094, 0.03773018303036224, 0.013253328870632686, 0.0451014497957658, 0.08948012196924537, 0.07365604178630747, 0.06506231307866983, 0.018668815719138365, 0.05119753615872469, 0.06645203655352816, 0.08964676380855963, 0.0752627024485264, 0.032487158314324915, 0.011364789388608187, 0.013425816978269722, 0.06349007322569378, 0.07716814434388652, 0.016590807790635154, 0.05222682077146601, 0.0065715172968339175, 0.0262455609117751, 0.04710073255409952, 0.03896744339726865, 0.0353652626654366, 0.023382511026284192, 0.05040599484345876, 0.01975735340238316, 0.021985169405525085, 0.036055025848327205, 0.0058123595954384655, 0.042535945467534475, 0.05996935804432724, 0.02435639802570222, 0.04356980542070232, 0.07222415690193884, 0.09880892568617128, 0.023870578879723325, 0.024185828369809315, 0.0756121426820755, 0.007012462947386666, 0.04390746405988466, 0.01951518133864738, 0.011227986524318112, 0.05376822067773901, 0.040949192916741595, 0.03937433699320536, 0.0280377380840946, 0.08290505720651709, 0.5055753991473466, 11.424941942095757, 48.82539264857769, 53.60347665846348, 40.26327408850193, 21.719951815903187, 24.830024130642414, 55.99962808191776, 58.13621163368225, 20.757925137877464, 2.0775511069223285, 0.2763004816370085, 0.3747531690169126, 0.3800324216717854, 1.3887620670720935, 1.886157039552927, 1.6900450503453612, 3.628513407893479, 2.2377706971019506, 0.5161087308079004, 0.13071843335637823, 0.498574631055817, 3.6759465001523495, 11.467685848474503, 25.102023035287857, 39.11704279482365, 47.662970423698425, 50.04184417426586, 52.3143008351326, 52.82761909067631, 52.844372391700745, 53.14865246415138, 57.3901292681694, 61.309805139899254, 61.613735631108284, 62.872771471738815, 65.93469277024269, 62.1909436583519, 63.47601190209389, 56.22992232441902, 53.999168425798416, 53.574301823973656, 37.554205656051636, 54.41140450537205, 52.02379882335663, 41.57774515450001, 56.84529170393944, 71.95866912603378, 68.5607698559761, 70.72970867156982, 71.03260561823845, 69.04237881302834, 68.1766028702259, 70.97661942243576, 72.94794604182243, 71.79595425724983, 75.05825400352478, 66.19788944721222, 65.91839164495468, 58.59609715640545, 42.471430599689484, 29.2228240147233, 20.402456112205982, 15.876497123390436, 11.363596133887768, 8.378809746354818, 5.526858530938625, 5.232517775148153, 4.387630261480808, 2.136145862750709, 0.6051216856576502, 2.436980945058167, 1.2040710775181651, 2.2896922985091805, 4.508517924696207, 6.909581059589982, 3.326360508799553, 3.486297489143908, 1.5189899853430688, 0.47815716883633286, 0.46707571658771485, 0.1238943483622279, 0.8488424483221024, 17.49275654554367, 51.212755143642426, 39.019190445542336, 19.477266557514668, 23.72713901102543, 36.388941183686256, 33.24978142976761, 10.080188401043415, 0.05804566673759837, 0.11183402559254318, 0.040106424858095124, 0.0510724434570875, 0.0371002072643023, 0.047043665108503774, 0.01164042860182235, 0.02387400574662024, 0.030460653579211794, 0.05276670723105781, 0.04324609544710256, 0.03978566863224842, 0.0435830230708234, 0.012368455063551664, 0.0137433485724614, 0.05406135045632254, 0.01861598779214546, 0.07890740453149192, 0.025480640433670487, 0.06722255653585307, 0.04880651817074977, 0.06150759269075934, 0.008900150351109914, 0.0465548309875885, 0.032102833429235034, 0.04207736870739609, 0.05957216060778592, 0.016285647798213176, 0.04494231478020083, 0.056711300057941116, 0.1075321294774767, 0.039961783986655064, 0.05655268825648818, 0.024395110303885303, 0.0906032437342219, 0.07632222957909107, 0.03391720267245546, 0.05946956611296628, 0.057087657987722196, 0.13617032440379262, 0.08965152097516693, 0.14375366357853636, 0.11248973532929085, 0.14119236351689324, 0.06945343760889955, 0.1211081181827467, 0.14415903948247433, 0.13716331799514592, 0.13343813741812482, 0.13257838902063668, 0.1748655183473602, 0.1043280478916131, 0.20888298517093062, 0.24668718629982322, 0.0971498026046902, 0.10623465495882556, 0.2872646745527163, 0.2963802666636184, 0.1740324278944172, 0.11851981878862716, 0.12909170502098277, 0.1581743944552727, 0.18963737413287163, 0.10715357479057275, 0.12904299044748768, 0.1515668904175982, 0.17025682580424473, 0.13522233464755118, 0.09374304048833437, 0.10473467060364783, 0.20218044170178473, 0.23148757143644616, 0.17373653361573815, 0.10820893105119467, 0.11458284410764463, 0.2368519632727839, 0.11863657346111722, 0.14557572518242523, 0.20744783483678475, 0.1606916554737836, 0.11467392789199948, 0.11912506990483962, 0.13570191047620028, 0.17131339176557958, 0.1171410790993832, 0.37755388591904193, 9.803668688982725, 55.24430461227894, 70.81066712737083, 59.728918969631195, 47.510906383395195, 31.441633254289627, 50.7866308093071, 56.637005880475044, 28.364676162600517, 4.065364329144359, 0.7219610223546624, 1.388518048916012, 4.092891002073884, 5.665797125548124, 6.340774381533265, 3.7549335742369294, 6.073830630630255, 1.48791940882802, 0.6617527781054378, 0.4149012506240979, 0.6155300396494567, 2.426922172307968, 8.80253640934825, 21.399986185133457, 33.733993247151375, 43.604685589671135, 46.49061553180218, 48.37849862873554, 50.5563897639513, 50.29590614140034, 51.290985345840454, 58.90808701515198, 65.96399679780006, 66.37440517544746, 68.2966536283493, 71.17855578660965, 67.60827496647835, 65.27369543910027, 58.05895417928696, 58.65318529307842, 54.55565996468067, 47.64570415019989, 61.246067360043526, 57.42293290793896, 44.20444540679455, 59.617691338062286, 67.98508554697037, 66.99908405542374, 69.14659202098846, 73.2992447912693, 68.65331009030342, 69.6144001185894, 74.1524738073349, 76.03517398238182, 75.76119348406792, 76.35874941945076, 70.38988530635834, 66.30244463682175, 59.18875515460968, 41.58641628921032, 26.99405360966921, 16.712899692356586, 11.856916062533855, 9.367130063474178, 6.519155809655786, 4.20476839877665, 3.9001130964607, 2.4412780394777656, 1.4791794028133154, 0.4376995225902647, 1.5769127709791064, 1.0170183959417045, 2.634741570800543, 6.828620228916407, 12.421054691076279, 5.9849657490849495, 9.358373433351517, 10.175306797027588, 7.137202620506287, 4.299855921417475, 0.36141012562438846, 2.5890364358201623, 22.86075510084629, 51.746482104063034, 36.56071476638317, 34.07926931977272, 42.487416341900826, 47.79906392097473, 38.3372638374567, 7.526099877431989, 0.1645046766498126, 0.35747018235269934, 0.1278829394141212, 0.1823720897664316, 0.2143506839638576, 0.106560472631827, 0.14774854062125087, 0.20861705881543458, 0.18854812398785725, 0.1160482295381371, 0.12824295525206253, 0.1725802823784761, 0.1071973392390646, 0.16030795028200373, 0.15533618425251916, 0.17211538623087108, 0.20878473966149613, 0.20304683974245563, 0.1114651039824821, 0.11842133579193614, 0.12888765893876553, 0.16705756075680256, 0.18722468172200024, 0.19618651567725465, 0.1803569361800328, 0.18726987851550803, 0.2782262658001855, 0.09879113640636206, 0.13206859293859452, 0.1194160660088528, 0.262778343167156, 0.12584866810357198, 0.26555442076642066, 0.22951083141379058, 0.14760336169274524, 0.1593702466925606, 0.20067123987246305, 0.14669865398900583, 0.14125802874332294], [0.026236705234623514, 0.028451580037653912, 0.0342547945183469, 0.03832991256786045, 0.02967531847389182, 0.031060012042871676, 0.0061644196102861315, 0.057239378947997466, 0.04194254273897968, 0.0368502927449299, 0.01848357009293977, 0.08127758672344498, 0.02748360795521876, 0.023827025943319313, 0.020740715772262774, 0.03467135829851031, 0.06251679107663222, 0.012783285001205513, 0.0204283625134849, 0.04593643272528425, 0.04333230332122184, 0.06004008471791167, 0.05729000084102154, 0.06476279711932875, 0.016210432986554224, 0.019831642384815495, 0.04590668744640425, 0.041871348512358963, 0.03783446962188464, 0.08571762620704249, 0.033198733217432164, 0.022067108075134456, 0.06026911891240161, 0.004919879238514113, 0.032617408942314796, 0.04523478404735215, 0.0148346071546257, 0.06444673126679845, 0.032872603842406534, 0.012344514307187637, 0.09431732920347713, 0.02148423642211128, 0.08227927828556858, 0.04038674887851812, 0.040553843427915126, 0.038501920134876855, 0.12871551036369056, 0.015807864256203175, 2.667941339313984, 25.19893493503332, 50.223470628261566, 41.2485346198082, 31.239968575537205, 27.729621939361095, 33.20490963757038, 44.59739752113819, 33.00851337611675, 8.631963562220335, 1.3770185597240925, 0.23794643813744187, 0.3549097431823611, 1.1369673907756805, 0.8356414816807956, 2.6261248206719756, 2.821342432871461, 0.2672118740156293, 0.35062030772678554, 0.1501017573173158, 0.10008809142163955, 0.10320271452656016, 0.9185878245625645, 2.7096084784716368, 4.519418589770794, 6.401874152943492, 6.491450546309352, 7.309384681284428, 6.599175240844488, 9.709552489221096, 11.780950538814068, 19.28098998963833, 33.25876034796238, 44.58396904170513, 56.91295847296715, 58.365730717778206, 58.502204194664955, 76.67327374219894, 59.47419583797455, 52.11336761713028, 48.6996003985405, 55.17667584121227, 51.992625296115875, 40.63629247248173, 59.81336563825607, 73.20073127746582, 72.51561284065247, 69.60104003548622, 72.91476622223854, 73.98196175694466, 76.3752481341362, 73.79182755947113, 74.88628283143044, 70.69266825914383, 60.8462680131197, 58.76330718398094, 46.56823396682739, 24.85822431743145, 14.015652425587177, 4.903136249631643, 1.753427074290812, 0.8380083984229714, 0.3320372861344367, 0.011377737082511885, 0.1354506638017483, 0.29394510202109814, 0.6354439398273826, 0.9320499084424227, 1.2155690230429173, 2.6194694777950644, 1.4395230682566762, 2.6311191776767373, 4.23441868275404, 6.629496663808823, 2.5746812811121345, 3.2528052432462573, 1.7511882819235325, 0.29531849082559347, 0.10321436624508351, 8.791917879134417, 30.11202000081539, 34.97536763548851, 23.596027046442032, 23.884663358330727, 36.43160529434681, 42.49329462647438, 21.048394851386547, 2.265704423189163, 0.0628062360920012, 0.054560422504437156, 0.06803767217206769, 0.09357708142488264, 0.08093979078694247, 0.024354071392735932, 0.05777189588116016, 0.004230407348586596, 0.09869884292129427, 0.09094144785194658, 0.022887268460181076, 0.019072868744842708, 0.05780894760391675, 0.06304606111370958, 0.04372549687104765, 0.030721099174115807, 0.027252710970060434, 0.03836692347249482, 0.056210543334600516, 0.04231530867400579, 0.10314293453120627, 0.03658939072920475, 0.07179526975960471, 0.03113277220109012, 0.06542438466567546, 0.04048552502354141, 0.02118313412211137, 0.011595367250265554, 0.14743170293513685, 0.020037807298649568, 0.052590424893423915, 0.09623327990993857, 0.019438597264525015, 0.0549913431314053, 0.053081886217114516, 0.06484200654085726, 0.016207315966312308, 0.11640604861895554, 0.06392016264726408, 0.031681215623393655, 0.017172655279864557, 0.020055971363035496, 0.052933850020053796, 0.023899242478364613, 0.07507133224862628, 0.046761719495407306, 0.06881906461785547, 0.051413174587651156, 0.049021121303667314, 0.07194916892331094, 0.03119164306554012, 0.03499626684060786, 0.15938770200591534, 0.034316047676838934, 0.05843958759214729, 0.02713161473366199, 0.03746621594473254, 0.04247158271027729, 0.04177614209766034, 0.07946456447825767, 0.01942762090038741, 0.04709524066129234, 0.09428968420252204, 0.026746480907604564, 0.0445226785086561, 0.02043764678091975, 0.04941910912748426, 0.010686657515179832, 0.05520367900317069, 0.07420972106046975, 0.04772238142322749, 0.03283767837274354, 0.0583847206144128, 0.06132706155767664, 0.05007109328289516, 0.06118933750258293, 0.01361432619887637, 0.0702386669581756, 0.020264114100427832, 0.024108216421154793, 0.027424282525316812, 0.05501054991327692, 0.027394531680329237, 0.03669829719001427, 0.0654318135639187, 0.1042944953951519, 0.14605160511564463, 0.09802777814911678, 6.823309538885951, 37.59259879589081, 57.40606941282749, 43.786703422665596, 25.483165383338928, 22.846790850162506, 42.1454156935215, 60.47092795372009, 38.755416199564934, 8.547311704605818, 0.2510942076332867, 0.3548323520226404, 0.4429701069602743, 1.2023851554840803, 1.28958537010476, 2.4176775058731437, 4.369478635489941, 1.2984317704103887, 0.727081960067153, 0.7158388977404684, 0.38501282630022615, 0.6028970831539482, 2.181050665676594, 4.755842853337526, 8.679644353687763, 11.836637500673532, 12.126143965870142, 11.898123901337385, 10.314274840056896, 14.498565662652254, 17.343563251197338, 27.684653252363205, 42.71500512957573, 55.16391232609749, 66.69795021414757, 65.58527871966362, 65.71552813053131, 78.37766468524933, 64.94350075721741, 60.048557817935944, 59.23801191151142, 61.83806039392948, 57.494285479187965, 46.619918793439865, 65.56865841150284, 74.76099595427513, 71.64309605956078, 69.60426986217499, 72.83280462026596, 74.86780062317848, 73.04065346717834, 75.19908964633942, 74.33769106864929, 73.17803889513016, 63.516700118780136, 61.9066771119833, 49.885642156004906, 29.91255920380354, 17.039963342249393, 7.101027136668563, 3.2646570447832346, 2.2831632988527417, 1.4951791567727923, 0.8292280195746571, 1.2910630158148706, 1.4879555068910122, 2.692313943989575, 2.133690482005477, 1.6848728153854609, 3.651487687602639, 3.922335491515696, 6.891783764585853, 3.184587503783405, 2.43836407084018, 1.5975893614813685, 0.7275396573822945, 0.5584867880679667, 0.16743276093620807, 0.20942417409969494, 5.760095240548253, 37.98690363764763, 48.45996245741844, 30.36992736160755, 17.54294615238905, 30.416098684072495, 45.54711855947971, 28.994425870478153, 5.443859584629536, 0.07888072432251647, 0.05831663227581885, 0.008067928210948594, 0.03293981644674204, 0.052915474443580024, 0.0357726015499793, 0.05974001956928987, 0.019649111163744237, 0.10171735790208913, 0.05777461214165669, 0.015789373646839522, 0.05340392635844182, 0.0392749337333953, 0.08759969045058824, 0.0567433942342177, 0.11868887260789052, 0.02662918261194136, 0.030280838618637063, 0.07701000009546988, 0.08400091246585362, 0.034410389489494264, 0.007128112747523119, 0.0565521316457307, 0.032626370375510305, 0.06926269823452458, 0.025923932662408333, 0.03851130088150967, 0.06585575800272636, 0.09287770371884108, 0.03320398391224444, 0.04843670598347671, 0.0915132429508958, 0.048175139745580964, 0.04632064999896102, 0.006974171374167781, 0.0641659545362927, 0.029831568390363827, 0.006785810583096463, 0.08361036467249505, 0.0418005624669604, 0.14381477201823145, 0.11415829852921888, 0.14000547642353922, 0.12068807001924142, 0.12431431488948874, 0.12098533727112226, 0.2192738838493824, 0.1700853303191252, 0.09924856654834002, 0.14540382893756032, 0.1120667408395093, 0.11538145437953062, 0.20263128157239407, 0.17574226192664355, 0.1747744865133427, 0.09660904412157834, 0.15726906334748492, 0.08166713261744007, 0.06588801174075343, 0.17882910644402727, 0.17369302891893312, 0.1788092020433396, 0.17886045476188883, 0.13744082185439765, 0.21587230934528634, 0.2040361671242863, 0.16208989138249308, 0.11882900493219495, 0.1586744684027508, 0.15816651284694672, 0.15077533054864034, 0.12961601751158014, 0.31225459766574204, 0.1383200887357816, 0.23047382739605382, 0.2078379670274444, 0.1653024705592543, 0.21320789528544992, 0.13341860409127548, 0.10689399379771203, 0.1268558664014563, 0.14204195933416486, 0.16036800487199798, 0.15984099096385762, 0.1699141613789834, 0.12307498764130287, 0.19787752884440124, 0.17545840528327972, 5.336459297686815, 40.9100715816021, 71.14278450608253, 57.49922141432762, 41.93734645843506, 36.551773846149445, 46.01431488990784, 57.2598684579134, 42.591165974736214, 12.245766296982765, 1.5995080210268497, 0.6782426463905722, 2.157571013085544, 6.293709157034755, 5.3371427860111, 8.466664832085371, 7.298328224569559, 1.2696217163465917, 0.5949273076839745, 0.9432505792938173, 0.39586486585903913, 0.6102663127239794, 1.6841434920206666, 3.2620890950784087, 6.280242679640651, 8.565351236611605, 9.11486255005002, 8.187521360814571, 7.257696054875851, 11.342557612806559, 13.900969829410315, 20.939935371279716, 37.079884707927704, 48.85469287633896, 60.619545578956604, 62.76137664914131, 63.476600870490074, 81.47072151303291, 67.5432376563549, 62.34098240733147, 66.61036491394043, 69.40794199705124, 61.76240265369415, 53.61200340092182, 68.92977565526962, 76.75404220819473, 75.81097081303596, 69.5633764564991, 73.85128676891327, 76.50453239679337, 79.00435745716095, 75.4789674282074, 75.27896136045456, 71.62951558828354, 67.63405278325081, 60.735971331596375, 46.27466931939125, 25.39518490433693, 14.298991821706295, 5.466680210083723, 1.8105666269548237, 1.2040017312392592, 0.7590605691075325, 0.5254609789699316, 0.9027667797636241, 1.2906623748131096, 1.3101427420042455, 1.9205056526698172, 3.0733240116387606, 5.467550838366151, 4.919995469972491, 7.934689577668905, 10.184122323989868, 14.673684015870094, 10.296979118138552, 7.614979483187199, 3.7946542678400874, 0.4050615895539522, 0.6366798235103488, 11.686489507555962, 38.618163764476776, 41.73219546675682, 32.596691474318504, 34.604579731822014, 47.407772317528725, 58.177306428551674, 30.783861950039864, 4.107952443882823, 0.13672478293301538, 0.20223758707288653, 0.10664000117685646, 0.17627295688726008, 0.2722951996838674, 0.23239527741679922, 0.18112307006958872, 0.18769597518257797, 0.16869171056896448, 0.24171672645024955, 0.16373110644053668, 0.19210318947443739, 0.1453310390934348, 0.27144045336171985, 0.1433526663458906, 0.16178485384443775, 0.1631133575574495, 0.09122574236243963, 0.21797944471472874, 0.15955352748278528, 0.11501926404889673, 0.09203576686559245, 0.18632223014719784, 0.10598739361739717, 0.13101745949825272, 0.13504025613656268, 0.10193864407483488, 0.13813887111609802, 0.3007695358246565, 0.07936512411106378, 0.1069101355096791, 0.17670533212367445, 0.21609257877571508, 0.284854267956689, 0.15573761193081737, 0.1485228381352499, 0.14672661811346188, 0.21752853062935174, 0.17287733440753073, 0.1957457244861871], [0.024944251345004886, 0.022530991191160865, 0.06054822209989652, 0.025846463577181567, 0.01483397447373136, 0.06336736652883701, 0.014372826171893394, 0.0212037101664464, 0.03326342994114384, 0.04284936927433591, 0.026272050017723814, 0.04892692420980893, 0.04233938394463621, 0.03910818057192955, 0.0492769025004236, 0.011735227762983413, 0.011323665130476002, 0.00909356238480541, 0.050032720537274145, 0.03765213878068607, 0.03361826929904055, 0.07188768198830076, 0.034051175171043724, 0.02472405984008219, 0.04180176474619657, 0.03786925779422745, 0.015033041672722902, 0.03516127595503349, 0.027311617086525075, 0.012388496761559509, 0.047370863176183775, 0.07801146901329048, 0.023465757731173653, 0.041942409152397886, 0.018685718132473994, 0.07700416681473143, 0.035635486055980437, 0.052775286458199844, 0.039550355868414044, 0.020676035746873822, 0.04662595099944156, 0.05317848415870685, 0.04737037335871719, 0.04094561576494016, 0.07030439155641943, 0.014181655424181372, 0.08268630917882547, 0.04579412590828724, 0.07511235817219131, 1.0566982417367399, 18.90334915369749, 41.99731104075909, 46.72358863055706, 41.70254185795784, 26.913142651319504, 21.108395531773567, 32.95046009123325, 43.87176185846329, 26.360790990293026, 5.450688768178225, 0.30339341377839446, 0.23946083500050008, 0.510516440263018, 1.644534773658961, 5.96855727955699, 1.5242208796553314, 0.33776055090129375, 0.6444087869022042, 1.0612756898626685, 0.17677859694231302, 0.2584352355916053, 0.06556765627465211, 0.14565667865099385, 0.16005057346774265, 0.0703144921862986, 0.08106791516183876, 0.07152159538236447, 0.07285994739504531, 0.09749801829457283, 0.3591929445974529, 1.1477032396942377, 3.508930974639952, 4.888436263427138, 4.3980588018894196, 5.91483861207962, 6.724099712446332, 4.3470660131424665, 3.9558005332946777, 9.505988862365484, 33.407320976257324, 26.86064276844263, 18.808753229677677, 8.207607083022594, 32.527250200510025, 51.37163981795311, 62.378566190600395, 68.01714822649956, 72.41204559803009, 69.43422138690948, 68.71276929974556, 57.36483782529831, 53.5663678497076, 45.44409468770027, 29.121434055268764, 11.161212343722582, 4.150816518813372, 0.8909384300932288, 0.12590976170031354, 0.7502961019054055, 1.0119086201302707, 0.6767799623776227, 1.0071787051856518, 2.0534706115722656, 1.8093534233048558, 5.315666338428855, 3.0767699517309666, 0.4959883354604244, 3.7510152719914913, 3.7080830382183194, 5.75643983669579, 2.035727226175368, 1.5006159525364637, 0.7636969140730798, 0.3985762281809002, 0.1493083272362128, 5.881983675062656, 24.433853588998318, 32.14598245918751, 21.0503688454628, 22.26396482437849, 30.73413211852312, 35.612490847706795, 36.940641179680824, 11.729843281209469, 0.973579779965803, 0.06966530592762865, 0.059050445634056814, 0.0569461007398786, 0.032258343053399585, 0.04452457469596993, 0.009225060748576652, 0.07800777311786078, 0.05702410046069417, 0.0018138002246814722, 0.07709393699769862, 0.028228436640347354, 0.03406188065127935, 0.04750280219013803, 0.03422576541197486, 0.06560123845702037, 0.04569805118080694, 0.03167174210830126, 0.05790021692519076, 0.045834305783500895, 0.06760647695045918, 0.008348452611244284, 0.06896659615449607, 0.08106494657113217, 0.02164901732612634, 0.012797219751519151, 0.11674674635287374, 0.12159156802226789, 0.023086438632162753, 0.07366199381067418, 0.026520830906520132, 0.01172379961644765, 0.034760044945869595, 0.09663363147410564, 0.058028486018883996, 0.03009336840477772, 0.056043511867756024, 0.05051074156654067, 0.030891683672962245, 0.03571516303054523, 0.023731661822239403, 0.07271986702107824, 0.031593746098224074, 0.037027250436949544, 0.0124162521569815, 0.06959941063541919, 0.02890800271416083, 0.05501531450136099, 0.016917247012315784, 0.008105491087917471, 0.014043614100955892, 0.033042722643585876, 0.04955450654961169, 0.015043391849758336, 0.04893426776106935, 0.036092151785851456, 0.061293141698115505, 0.0842727611598093, 0.01689771183009725, 0.045659081006306224, 0.0030321324629767332, 0.06735822855262086, 0.04355829099949915, 0.06716296207741834, 0.05495515972143039, 0.03169816998706665, 0.015964012127369642, 0.04227999728755094, 0.029124066022632178, 0.029481181918527, 0.0888059550197795, 0.036186456491122954, 0.045241663756314665, 0.046814059460302815, 0.014869758051645476, 0.0342714817088563, 0.0475812657532515, 0.07228464193758555, 0.011278290221525822, 0.01713131208816776, 0.057918663005693816, 0.03372408100403845, 0.05375083215767518, 0.04218859437969513, 0.0380819573183544, 0.019961200960096903, 0.1433199376333505, 0.055423351004719734, 0.02819539437041385, 0.028857655415777117, 0.09832227719016373, 3.325783177278936, 30.16328115016222, 51.44613102078438, 45.23468792438507, 35.99329501390457, 24.36020214110613, 25.257731080055237, 45.356194004416466, 52.66179598867893, 25.122144855558872, 2.739799520932138, 0.24040033458732069, 0.25218578812200576, 0.4406384867615998, 0.5541974119842052, 1.673729200847447, 0.9023871563840657, 1.8009374686516821, 0.9908164269290864, 2.162956749089062, 0.6511693366337568, 0.9388721454888582, 0.21899016079260036, 0.41011481371242553, 0.35055342537816614, 0.15743867377750576, 0.38047952111810446, 0.7569329801481217, 0.7607785519212484, 0.6399616005364805, 0.7276578072924167, 2.989738234318793, 6.939978003501892, 10.324953217059374, 9.226192776113749, 12.505724597722292, 16.23686123639345, 9.991097431629896, 10.257970411330462, 19.272968620061874, 46.109469383955, 40.331879407167435, 27.18629479408264, 15.316588617861271, 43.49945783615112, 59.71025437116623, 65.28520122170448, 69.35171261429787, 73.08444991707802, 72.61049374938011, 70.43856829404831, 61.37791268527508, 58.64212408661842, 49.87335741519928, 37.46770329773426, 14.667840879410505, 8.088652566075325, 4.014220023527741, 0.4685318103292957, 1.7169816861860454, 2.2739651799201965, 2.753668539226055, 2.6219343580305576, 3.195030768401921, 4.467342384159565, 11.997781153768301, 8.356234207749367, 2.962721446529031, 3.5097643174231052, 3.453260874375701, 3.8077657017856836, 1.377931460738182, 0.6409592845011503, 0.32271166623104364, 0.20976066385628656, 0.02059363694570493, 2.729731248691678, 24.232838675379753, 51.933344677090645, 33.665015548467636, 20.150620825588703, 23.621740266680717, 33.861685395240784, 44.15845647454262, 20.001965202391148, 2.0639255130663514, 0.05375583052227739, 0.021703622696804814, 0.060885097773279995, 0.08782249060459435, 0.06531598657602444, 0.041946205237763934, 0.06100321057601832, 0.0377744335855823, 0.015320812217396451, 0.056425714210490696, 0.043648554710671306, 0.022221272556635085, 0.0818457081913948, 0.026551179180387408, 0.060696254586218856, 0.04250502759532537, 0.01845292681537103, 0.04089099740667734, 0.015966162500262726, 0.08074914789176546, 0.027568635814532172, 0.02220047386799706, 0.0718622634303756, 0.03049512262805365, 0.015704215911682695, 0.030920221106498502, 0.04177560032985639, 0.053014877703390084, 0.036279113628552295, 0.055096316209528595, 0.009110066821449436, 0.05494413882843219, 0.03192137461155653, 0.033440484112361446, 0.0833830374176614, 0.026581058045849204, 0.13595131662441418, 0.052877090565743856, 0.06949085669475608, 0.05726290131860878, 0.034215442137792706, 0.16026735480409116, 0.06949426315259188, 0.13616291776997969, 0.13408980245003477, 0.08796628913842142, 0.1408647943753749, 0.106794716703007, 0.08932266791816801, 0.11984566561295651, 0.12034838902764022, 0.0968184633529745, 0.22374538297299296, 0.1979198312619701, 0.18488874222384766, 0.1435878232587129, 0.17660149082075804, 0.09531214847811498, 0.18167605914641172, 0.10004849042161368, 0.14111290918663144, 0.14258647308452055, 0.16785536950919777, 0.11546284571522847, 0.2663760376162827, 0.1524771048570983, 0.17396533774444833, 0.09875430361717008, 0.09117889057961293, 0.1667089739930816, 0.13959297590190545, 0.17543995549203828, 0.12454336392693222, 0.06963957566767931, 0.14804588950937614, 0.15335000411141664, 0.2288652371498756, 0.1388910081004724, 0.1390058035030961, 0.11833966986159794, 0.06888303032610565, 0.12654590100282803, 0.20616003050236031, 0.179116748040542, 0.12589561636559665, 0.21870326134376228, 0.11762273294152692, 0.18682307592825964, 0.17257026338484138, 0.1817500512697734, 2.889828532934189, 29.589681029319763, 63.65911267697811, 63.64318773150444, 53.57288829982281, 38.81461322307587, 27.939661368727684, 40.66818796098232, 55.71060799062252, 33.3109125494957, 7.012730799615383, 0.5606658523902297, 1.4653949299827218, 2.335114348679781, 5.923486948013306, 11.28304235637188, 4.943985482677817, 2.6614888105541468, 1.7838256806135178, 2.3883274057880044, 0.5446375999599695, 0.6254219776019454, 0.14043900941032916, 0.32068382191937417, 0.41311899782158434, 0.5572428891900927, 0.16339420108124614, 0.33448411733843386, 0.417955158627592, 0.2047822333406657, 0.574821992777288, 2.3198372684419155, 4.667449621483684, 6.437358548864722, 5.5382199212908745, 7.928815092891455, 9.0261135622859, 5.91294108889997, 6.434436030685902, 16.24178197234869, 45.312655940651894, 38.57341356575489, 25.54108377546072, 11.273021344095469, 36.41213893890381, 53.8569800555706, 66.91385462880135, 70.05735754966736, 71.25158026814461, 69.71526950597763, 70.50181210041046, 61.78755730390549, 58.54566626250744, 47.819286435842514, 30.613853372633457, 12.534854784607887, 5.898558860644698, 2.1443137619644403, 0.34827918803784996, 1.386478627100587, 3.405755111016333, 2.408382254652679, 2.784739234484732, 3.5439363587647676, 4.013100508600473, 9.65657763183117, 7.8119314648211, 3.761544032022357, 10.113401468843222, 9.303805511444807, 12.723958287388086, 10.377060770988464, 7.593827918171883, 3.5682056564837694, 1.014023800380528, 0.5217808170709759, 8.175973780453205, 31.77163414657116, 42.36924648284912, 28.253695517778397, 32.8011205047369, 43.31598848104477, 46.27850331366062, 51.38383336365223, 18.681074380874634, 1.4374112128280103, 0.25019843538757414, 0.14931160752894357, 0.19726145721506327, 0.18553613248514012, 0.12082558998372406, 0.21107854001456872, 0.18879031646065414, 0.10572942308499478, 0.12787983723683283, 0.1556300450465642, 0.16003479540813714, 0.16238591924775392, 0.19133181602228433, 0.08961548970546573, 0.130723969778046, 0.11882982129463926, 0.08714368523214944, 0.13963904842967167, 0.16405478672822937, 0.22729845950379968, 0.08907956260372885, 0.08279383895569481, 0.1830851155682467, 0.11924222533707507, 0.07954720262205228, 0.1572947861859575, 0.1384080183925107, 0.12457312404876575, 0.17394311784300953, 0.15924964769510552, 0.23588093725265935, 0.2232343697687611, 0.21565678965998814, 0.14994937955634668, 0.1788075247895904, 0.1358825046918355, 0.24130569538101554, 0.15993358130799606, 0.15462433104403317, 0.1507147861411795, 0.12165629072114825], [0.03491525028948672, 0.06813078944105655, 0.03901055475580506, 0.03754342898901086, 0.03331184394482989, 0.00479345577332424, 0.00637837150861742, 0.051371332301641814, 0.06577608102816157, 0.041624254154157825, 0.09426361997611821, 0.02547488136769971, 0.02235627849586308, 0.03543545499269385, 0.0312351588945603, 0.033651361663942225, 0.03842078484012745, 0.039382741815643385, 0.0514294090680778, 0.04536773238214664, 0.013464622024912387, 0.06214958382770419, 0.022168526265886612, 0.02670690959348576, 0.045685638760915026, 0.01992372806853382, 0.022203726330189966, 0.08573804268962704, 0.059092562514706515, 0.02451068867230788, 0.04922469983284827, 0.028355887516227085, 0.03901259566191584, 0.07948240570840426, 0.08206323167541996, 0.0395180316263577, 0.06913799516041763, 0.014607390294258948, 0.02951658607344143, 0.07344597688643262, 0.007340817373915343, 0.057566380346543156, 0.048813342218636535, 0.04951841961883474, 0.0673453374474775, 0.019292546312499326, 0.02821539710566867, 0.0517673423019005, 0.043953970744041726, 0.10529292892897502, 0.07803530679666437, 8.039031978696585, 37.59938903152943, 51.27773925662041, 34.62606757879257, 32.07645758986473, 37.01178476214409, 26.61697704344988, 33.749230429530144, 38.296636417508125, 17.43965819478035, 5.101572526618838, 0.6245992030017078, 0.22817949269665405, 0.8867032604757696, 0.714746693847701, 2.4551983550190926, 1.6114651481620967, 1.4225897518917918, 0.4338652017759159, 0.6799271435011178, 0.6132281350437552, 0.8542681415565312, 0.20935919164912775, 0.4929289949359372, 1.7670987406745553, 1.1468311864882708, 0.31020695285405964, 0.7694812724366784, 0.3015669883461669, 0.1506550729391165, 0.18794429779518396, 0.1011930825188756, 0.24589111417299137, 0.1090096119150985, 0.4809892934281379, 0.03819731304247398, 0.058294802001910284, 0.4898946202592924, 2.0090365083888173, 2.4412785144522786, 0.08084562708972953, 0.057276297084172256, 1.3620933168567717, 11.805179938673973, 15.257004015147686, 30.092705637216568, 38.73882628977299, 34.55125339329243, 29.755365438759327, 18.15827753394842, 16.046185567975044, 6.994475154206157, 1.5034722117707133, 0.03127072632196359, 0.15541289263637736, 1.1304991878569126, 0.2059047613875009, 1.323563028126955, 1.5488175535574555, 5.323296329006553, 3.1461295299232006, 3.71370792388916, 4.125630045309663, 15.842684637755156, 8.885485958307981, 2.2951378813013434, 0.8941524638794363, 3.3822070620954037, 4.351556897163391, 0.9180941479280591, 0.37675545376259834, 0.06265818505198695, 3.549040434882045, 24.794659428298473, 40.08160963654518, 27.049067057669163, 17.231129184365273, 29.901923574507236, 32.21725903451443, 37.89119817316532, 25.394005067646503, 3.874629526399076, 0.1178951827751007, 0.1672552095260471, 0.08945352339651436, 0.009971319923351984, 0.047449415797018446, 0.026331195476814173, 0.04848719800065737, 0.0645042848191224, 0.08562837552744895, 0.0517834097990999, 0.05104701005620882, 0.021806217191624455, 0.033872098647407256, 0.05547602122533135, 0.016308646954712458, 0.03772873584239278, 0.04469009960303083, 0.0171248405604274, 0.016450124421680812, 0.03811952112300787, 0.03364080090250354, 0.049602323124418035, 0.03474638571788091, 0.04618242870492395, 0.05552110669668764, 0.08316437844769098, 0.021536214590014424, 0.003677076419990044, 0.02322128686500946, 0.02346075194509467, 0.007970401657075854, 0.08194096284569241, 0.06279226145124994, 0.06203319651831407, 0.024540680715290364, 0.04205392426229082, 0.08169318200089037, 0.026011326117441058, 0.027264553791610524, 0.08148154374794103, 0.019335512952238787, 0.04907779170025606, 0.039875201327959076, 0.03971005491621327, 0.066806538234232, 0.055374625299009494, 0.021681374964828137, 0.022835614981886465, 0.09129787911660969, 0.017124983423855156, 0.026120974725927226, 0.05631531232211273, 0.03896038557286374, 0.05313619658409152, 0.027814689310616814, 0.041693210805533454, 0.034042673869407736, 0.035948416334576905, 0.026300704339519143, 0.040181567310355604, 0.01984381175134331, 0.008527994832547847, 0.010435346830490744, 0.01415158731106203, 0.04505461656663101, 0.01911611183459172, 0.006916032452863874, 0.03814133284322452, 0.03489614369755145, 0.019470856568659656, 0.04203952288662549, 0.05391288381360937, 0.024666400531714316, 0.012086882379662711, 0.019783784991886932, 0.07631595100974664, 0.03477323662082199, 0.02807909611874493, 0.07029927073745057, 0.05555690418987069, 0.015468671226699371, 0.017943997190741356, 0.0513692988170078, 0.03699226559547242, 0.0709551660111174, 0.0625063713232521, 0.030605238789576106, 0.04240352034685202, 0.06399482270353474, 0.046866596094332635, 0.007324091684495215, 0.00047511407160527597, 0.11847946821944788, 0.6055129459127784, 16.868571639060974, 49.765648394823074, 55.17280764877796, 34.61474038660526, 25.6343649700284, 31.079672276973724, 40.56398615241051, 56.61877825856209, 49.13636416196823, 15.834105648100376, 1.9871977739967406, 0.45048482716083527, 0.2497315948130563, 0.6459168309811503, 0.5303070251829922, 0.8631213696207851, 0.7970417873002589, 3.2499466091394424, 2.594582950696349, 1.0868610232137144, 1.0061594098806381, 1.2894609267823398, 3.4034486347809434, 1.9474177085794508, 4.341237125918269, 6.924808267503977, 4.0911768190562725, 3.1356912525370717, 0.8443719882052392, 1.1739198141731322, 0.8462353725917637, 0.16847105522174388, 0.6289740151260048, 0.04118364478927106, 0.48985772067680955, 0.12405378394760191, 0.12453859933884814, 0.8302984933834523, 6.1322239972651005, 5.431018648669124, 0.47833406715653837, 0.00478171035865671, 2.8441573586314917, 17.444208450615406, 25.49434818327427, 38.75939458608627, 47.22618766129017, 43.09208929538727, 39.4048735499382, 27.640826404094696, 22.192899137735367, 11.926478929817677, 3.669659262523055, 0.1679543571663089, 1.5136355976574123, 3.8832600507885218, 1.674633789807558, 3.6587222618982196, 3.7305141845718026, 7.2355560678988695, 4.829799709841609, 6.881893370300531, 4.679459827020764, 19.197865650057793, 11.0068104788661, 2.7562046656385064, 1.592221911996603, 1.234371007885784, 0.7206573954317719, 0.4662986285984516, 0.22086120414314792, 0.1619776341249235, 1.0995896277017891, 20.068153850734234, 51.86997167766094, 44.409835785627365, 20.43983280658722, 16.62703949958086, 27.03264433890581, 40.94083093106747, 36.27992503345013, 9.419306013733149, 0.26285831700079143, 0.257977211731486, 0.05625876066915225, 0.07227493464597501, 0.025777883565751836, 0.06766188569599763, 0.02287417883053422, 0.055833703008829616, 0.09592659480404109, 0.0510856128676096, 0.08411253147642128, 0.01707342642475851, 0.02911829767981544, 0.03701176923641469, 0.04267577351129148, 0.02131455734343035, 0.025453290436416864, 0.018033231172012165, 0.07067980695865117, 0.02490589158696821, 0.01321063775321818, 0.05558192940952722, 0.02648909852723591, 0.02183461361710215, 0.024672974104760215, 0.024918888448155485, 0.02970881716464646, 0.01816692907596007, 0.037684997369069606, 0.028323116130195558, 0.04048184768180363, 0.06192965207446832, 0.008444752766081365, 0.019487647659843788, 0.06261997928959318, 0.015500887857342605, 0.06273366147070192, 0.01437731523765251, 0.03014283996890299, 0.017492732440587133, 0.009320638237113599, 0.030984017976152245, 0.03096239179285476, 0.14354826678754762, 0.12779137323377654, 0.1913624073495157, 0.1791999427950941, 0.09820720719289966, 0.19760492315981537, 0.08044196554692462, 0.12410036855726503, 0.2995836432091892, 0.15331687463913113, 0.14485226478427649, 0.0901943129429128, 0.11314799063256942, 0.1536776326247491, 0.13351362867979333, 0.21885332360398024, 0.21689161949325353, 0.10441731341416016, 0.20494654483627528, 0.10881956273806281, 0.11816123529570177, 0.1506991416681558, 0.17333498719381168, 0.13013878633501008, 0.10510618973057717, 0.08313456637552008, 0.07813481395714916, 0.10435804550070316, 0.10956513171549886, 0.13966214406536892, 0.17421566415578127, 0.19874180434271693, 0.15615245763910934, 0.2001221990212798, 0.15364490391220897, 0.14559264614945278, 0.13080924254609272, 0.09251285649952479, 0.08900919958250597, 0.12923238653456792, 0.13545833760872483, 0.1954212723649107, 0.1581735335639678, 0.1456819858867675, 0.2435970466467552, 0.11217388469958678, 0.1626930496422574, 0.08979644015198573, 0.11458194610895589, 0.20158626342890784, 0.3233216522494331, 14.441145043820143, 56.00381925702095, 69.79843944311142, 48.15292373299599, 42.72099360823631, 44.361240193247795, 33.982313722372055, 44.079527109861374, 49.87357400357723, 24.015501737594604, 6.289367889985442, 1.1116239381954074, 0.6414790847338736, 2.843438247218728, 4.583400506526232, 5.789290498942137, 5.01710400916636, 6.144863069057465, 3.95900946110487, 1.2434947933070362, 1.0268355254083872, 1.7325336579233408, 1.4172607753425837, 1.228090301156044, 5.0720504857599735, 4.241215568035841, 1.9391272659413517, 1.3523587142117321, 0.5977023462764919, 0.7541099097579718, 0.7323352375533432, 0.24443784059258178, 0.6386504927650094, 0.1929564366582781, 0.7499342900700867, 0.10685238899895921, 0.21203582145972177, 1.1016107629984617, 4.3283904902637005, 4.304053271189332, 0.34700293152127415, 0.13843994558556005, 2.3196560656651855, 13.3661437779665, 20.79535312950611, 33.51521238684654, 46.38981454074383, 40.30137464404106, 34.843647703528404, 22.063858062028885, 17.76029448956251, 7.915143426507711, 2.9349406622350216, 0.26096040790434927, 1.1432093870826066, 3.9064440317451954, 1.3336622924543917, 3.1409525452181697, 3.4140505408868194, 14.896191526204348, 7.722934065386653, 13.389079347252846, 15.303679760545492, 26.503688022494316, 17.903599999845028, 6.701393555849791, 10.421553533524275, 9.720155820250511, 9.592554867267609, 2.8218397311866283, 1.280292731244117, 0.43780087027698755, 5.39791957475245, 30.984931960701942, 51.74542956054211, 34.55358266830444, 26.714548207819462, 41.31875865161419, 42.65614628791809, 52.31724187731743, 41.52598813176155, 7.814562823623419, 0.2615713141858578, 0.5367605038918555, 0.20916927605867386, 0.1605472929077223, 0.09858277102466673, 0.09939668438164517, 0.10146069354959764, 0.25393998774234205, 0.13999075221363455, 0.17963570222491398, 0.20430154429050162, 0.19564412446925417, 0.13643650308949873, 0.17552246747072786, 0.11670450330711901, 0.17183570045745, 0.1820307908928953, 0.16367084404919297, 0.20628874859539792, 0.16677984909620136, 0.08487015293212608, 0.12344818402198143, 0.12044752511428669, 0.11715961794834584, 0.10790708474814892, 0.22225814871490002, 0.12833698536269367, 0.14457905053859577, 0.14707241440191865, 0.10567206991254352, 0.1350495478254743, 0.14662435016361997, 0.2044928996474482, 0.11723225936293602, 0.1667329898918979, 0.19282464607385918, 0.1302612407016568, 0.10267420890158974, 0.11667923317872919, 0.1902305133990012, 0.12226551974890754, 0.14694604149553925, 0.09627920400816947], [0.05647279234835878, 0.05210032541071996, 0.02017091519519454, 0.014499862372758798, 0.019892511481884867, 0.12168752771685831, 0.07098279616911896, 0.009588729808456264, 0.11118102469481528, 0.029927396353741642, 0.06605095768463798, 0.011852405459649162, 0.09024984043207951, 0.07209211398730986, 0.017751580562617164, 0.01910959392262157, 0.026938689734379295, 0.03259509627241641, 0.005447457178888726, 0.08841256480081938, 0.10414527176180854, 0.08710054418770596, 0.03375258689629845, 0.03265606370405294, 0.018412147655908484, 0.03460214189544786, 0.033961193475988694, 0.0020251069463483873, 0.024998313092510216, 0.008678748217789689, 0.04190169864159543, 0.03670096521091182, 0.08475583250401542, 0.07990764148416929, 0.05698785767890513, 0.022647330260952003, 0.07027771876892075, 0.09938242772477679, 0.024230346098192967, 0.049822061919257976, 0.04647726171242539, 0.047690346618765034, 0.08820417715469375, 0.027998959012620617, 0.038323151602526195, 0.07603999081766233, 0.05387872275605332, 0.0177964341128245, 0.0290203954136814, 0.061353010751190595, 0.03269921588071156, 0.038868099509272724, 3.014332177117467, 22.568016909062862, 51.64584070444107, 41.97698973119259, 38.63766051828861, 28.857464119791985, 18.59229974448681, 22.07487367093563, 47.0615690946579, 35.33352501690388, 19.58925224840641, 5.852029407396913, 0.95553929801099, 0.1558092440245673, 0.5810547864530236, 0.5625750124454498, 4.663265570998192, 4.948526713997126, 4.937194772064686, 6.094181863591075, 2.6462361915037036, 7.833072105422616, 1.6241479176096618, 5.2404156513512135, 13.062549568712711, 8.669384904205799, 10.453722607344389, 1.7101299413479865, 1.0066171665675938, 1.5365299629047513, 1.2708095088601112, 0.3919894597493112, 0.37569626059848815, 0.44372264470439404, 0.1919709239155054, 0.24655811197590083, 0.14470540860202163, 0.06636462640017271, 0.23455559508875012, 0.057051415205933154, 0.10732380862464197, 0.24074905493762344, 0.03376695116457995, 0.07481775523046963, 0.30205000774003565, 2.2087946394458413, 3.784557734616101, 2.0011474192142487, 0.8448659616988152, 0.2937799593200907, 0.38301891298033297, 0.18929990474134684, 0.3926910267909989, 1.8224498955532908, 3.9224114874377847, 1.2723379768431187, 5.912828994914889, 3.418012303300202, 2.830122811719775, 4.627576461061835, 3.9950343780219555, 2.2927425848320127, 24.147464856505394, 15.208123438060284, 2.9086745716631413, 1.4164445316419005, 0.4878338542766869, 0.15986589743988588, 0.6377321295440197, 4.5494593027979136, 22.92343843728304, 41.26830495893955, 35.57232700288296, 25.166121795773506, 24.049692302942276, 40.63318803906441, 39.07996438443661, 37.81741753220558, 21.304926685988903, 1.3845464307814837, 0.15208753669867292, 0.11860072030685842, 0.051609832589747384, 0.07567841646960005, 0.013684194764209678, 0.02510320453438908, 0.07003341117524542, 0.03928963196813129, 0.03839493954728823, 0.05656070716213435, 0.07204597466625273, 0.04449312618817203, 0.004363160869615967, 0.023629763090866618, 0.038352080518961884, 0.05070939594588708, 0.0394839262298774, 0.0725107965990901, 0.04175498346739914, 0.05333521461579949, 0.03166999063978437, 0.0646804558346048, 0.01442088858311763, 0.009625041238905396, 0.042452862035133876, 0.0443186658230843, 0.010971303618134698, 0.0598318380798446, 0.010792506327561568, 0.023436895608028863, 0.009659764473326504, 0.01818997090595076, 0.06795313413022086, 0.06842233473435044, 0.02277559007779928, 0.05255320618744008, 0.012052481051796349, 0.05948191916104406, 0.01213171737617813, 0.04249656340107322, 0.015618976540281437, 0.01718470961350249, 0.024974822263175156, 0.008869202792993747, 0.04384011044749059, 0.044421742713893764, 0.044762459001503885, 0.021944028449070174, 0.07075865272781812, 0.03412424703128636, 0.052510681125568226, 0.04523380070168059, 0.024139316119544674, 0.0671124663494993, 0.08902554167434573, 0.0059298953783581965, 0.036105280378251337, 0.01149090996477753, 0.1051027090579737, 0.027084766661573667, 0.022872794725117274, 0.04015419319330249, 0.052266718630562536, 0.0948501615494024, 0.03683100803755224, 0.03745964051631745, 0.050381882465444505, 0.025273577521147672, 0.05019428608648013, 0.054651561949867755, 0.0433295239781728, 0.03737805993296206, 0.037676930223824456, 0.0751227185537573, 0.0761797594896052, 0.029943476838525385, 0.014014815988048213, 0.030660645679745357, 0.018861608987208456, 0.01461873494918109, 0.01864387399109546, 0.0411298539256677, 0.03068922207603464, 0.022631195970461704, 0.06937667727470398, 0.02017778006120352, 0.1300578922382556, 0.048177124990615994, 0.05558464567002375, 0.05956538479949813, 0.04961993428878486, 0.006928708335181, 0.04461858254217077, 0.033925355164683424, 0.05308048355800565, 0.21608238166663796, 6.819569589570165, 37.41929769515991, 57.83711068332195, 42.4752151966095, 34.6814002096653, 19.611790738999844, 20.169583708047867, 35.987492725253105, 62.197638899087906, 47.43609219789505, 20.63153062015772, 4.064278062433004, 0.6525654648430645, 0.19719730596989393, 0.40164684935007244, 0.4996709316037595, 2.329248650930822, 2.6398613210767508, 3.853596467524767, 4.101462392136455, 2.9451906122267246, 8.235873766243458, 5.264346292242408, 4.338760133832693, 6.0534257255494595, 4.857872128486633, 8.919979557394981, 5.513297533616424, 3.8639710983261466, 2.6286949077621102, 2.90892013348639, 1.1499877483583987, 0.7130272267386317, 0.4368464386789128, 0.39427138573955745, 0.9354004974011332, 0.7578582304995507, 0.2436222945107147, 0.38235748128499836, 0.09595762399840169, 0.448228134191595, 0.45134509506169707, 0.3143597737653181, 0.5314333084970713, 1.713185808621347, 5.000495100393891, 6.269777091220021, 3.69281237013638, 1.9211976905353367, 1.0545990918762982, 0.48968465183861554, 0.4665084189036861, 0.7232674397528172, 4.269221015274525, 3.6012182850390673, 4.882423561066389, 4.636562503874302, 5.8795437309890985, 6.7835399229079485, 4.106567418202758, 6.072610896080732, 1.075531099922955, 3.340063998475671, 5.887407884001732, 0.560314905596897, 0.17963748337933794, 0.32662032055668533, 0.17082568199839443, 0.1364334305981174, 3.585449606180191, 15.713210385292768, 48.62959675490856, 56.038933172822, 34.427950009703636, 16.136694811284542, 23.46481628715992, 40.54535575211048, 44.93431404232979, 30.638058073818684, 3.4491701563820243, 0.103265515062958, 0.05257819801045116, 0.03705370058014523, 0.026361586424172856, 0.03194749078829773, 0.02395840649114689, 0.07823061780072749, 0.03749710784177296, 0.04410878274939023, 0.04114291943551507, 0.04707249012426473, 0.018938803477794863, 0.04486631885811221, 0.015605400803906377, 0.06976724733249284, 0.055772984196664765, 0.04605908747180365, 0.03466159163508564, 0.05669536243658513, 0.04746934617287479, 0.023231161139847245, 0.030272823423729278, 0.06505906247184612, 0.05981960377539508, 0.0472546651144512, 0.09088479229831137, 0.04563179594697431, 0.039071978608262725, 0.03260067351220641, 0.0432459321746137, 0.04532775288680568, 0.013963830442662584, 0.053557680803351104, 0.039942862931638956, 0.06842707705800422, 0.08173448994057253, 0.021844647453690413, 0.060039416785002686, 0.005043094770371681, 0.08515464040101506, 0.02897078655223595, 0.018830609478754923, 0.06991358401137404, 0.08792962704319507, 0.12876419525127858, 0.10582000220892951, 0.11334940209053457, 0.11177087624673732, 0.13076247239951044, 0.2617344679310918, 0.16908962046727538, 0.11265906374319457, 0.17008923401590437, 0.13519379164790735, 0.20585588354151696, 0.15569153940305114, 0.1345299553941004, 0.10506252176128328, 0.32527706294786185, 0.12027921344269998, 0.14913101331330836, 0.13880306360078976, 0.14494494418613613, 0.23690795089351013, 0.22692265076329932, 0.25228033773601055, 0.17588606046047062, 0.17072136572096497, 0.14551019354257733, 0.11743830182240345, 0.14329938014270738, 0.11562195475562476, 0.10591064812615514, 0.13446377066429704, 0.1483175897737965, 0.17154222558019683, 0.17916697659529746, 0.2513688913313672, 0.1232388018979691, 0.1333031852846034, 0.1353840486262925, 0.10938004008494318, 0.12171755501185544, 0.10736869371612556, 0.13458616565912962, 0.11845187516883016, 0.25191113410983235, 0.20353413390694186, 0.10992451672791503, 0.14562908560037613, 0.23509368184022605, 0.07075175817590207, 0.110556923027616, 0.12275760076590814, 0.08946023983298801, 0.2794109709793702, 5.160460341721773, 36.36230081319809, 72.50482141971588, 58.806100487709045, 47.5955506414175, 37.63119712471962, 27.833791449666023, 30.13251230120659, 58.87592934072018, 45.169965997338295, 25.129793845117092, 7.9202294535934925, 1.6265220777131617, 0.2676386683015153, 1.7845330364070833, 2.1365161053836346, 10.584829822182655, 12.704602126032114, 11.45555404946208, 15.025643929839134, 7.217223001644015, 14.890183098614216, 7.6375136990100145, 9.362568408250809, 20.297019369900227, 15.18954148516059, 17.519298121333122, 6.201165122911334, 2.283571301959455, 3.8647251203656197, 3.8931397581472993, 1.1379630560986698, 1.1798151978291571, 0.6208986765705049, 1.040970291942358, 0.5497912515420467, 0.6892163981683552, 0.3112503234297037, 0.2539622224867344, 0.28300427191425115, 0.3830349136842415, 0.21119481971254572, 0.1467630427214317, 0.3057505935430527, 0.8645503304433078, 2.8370842756703496, 4.81578653678298, 2.513977400958538, 1.2062985892407596, 0.6710670283064246, 0.7585845852736384, 0.4113054263871163, 0.7393246656283736, 4.065748108550906, 6.296455934643745, 6.859691636636853, 13.142745215445757, 11.760971210896969, 13.86442244052887, 11.58096631988883, 13.097972217947245, 11.599797159433365, 34.530088528990746, 28.826218396425247, 8.784759063273668, 4.669883865863085, 1.3711133203469217, 0.524540834594518, 0.8280640351586044, 6.7447444796562195, 28.57309117913246, 53.46284620463848, 47.507862746715546, 37.3692961782217, 32.694654017686844, 51.85352995991707, 51.25910125672817, 55.68170294165611, 33.904193714261055, 3.029064224101603, 0.41612439905293286, 0.3067431418458, 0.13950929132988676, 0.16157677047885954, 0.13411237858235836, 0.20700039400253445, 0.19298012601211667, 0.10511210464756005, 0.06273829989368096, 0.1445421064272523, 0.17676989897154272, 0.1787389355013147, 0.16824918275233358, 0.12156647600932047, 0.10499232201254927, 0.19687758875079453, 0.1445475686341524, 0.12725480046356097, 0.23231246857903898, 0.1723379414761439, 0.22350862302118912, 0.09392912659677677, 0.11683657590765506, 0.12682952015893534, 0.1382284631836228, 0.11281412065727636, 0.1735512787126936, 0.11212092504138127, 0.19872197415679693, 0.08301272799144499, 0.12032910060952418, 0.13362446101382375, 0.20730900869239122, 0.2341173865715973, 0.14670424978248775, 0.23012510704575107, 0.06525401724502444, 0.2431839078781195, 0.08161297810147516, 0.19998855306766927, 0.09930848755175248, 0.11094740402768366, 0.21623380947858095, 0.1873380522010848], [0.012879671430710005, 0.00965942679613363, 0.03923018593923189, 0.021136339855729602, 0.10239618553896435, 0.05608956213109195, 0.017031493225658778, 0.025803367061598692, 0.06150849811092485, 0.05188954062759876, 0.02481616407749243, 0.03264564395067282, 0.03706754534505308, 0.02968609260278754, 0.02081966544210445, 0.016724617016734555, 0.018051525112241507, 0.0103366922121495, 0.028051690460415557, 0.0015425164906446298, 0.06887907467898913, 0.047219131083693355, 0.005992869391775457, 0.021011798198742326, 0.09265769404009916, 0.007217764650704339, 0.04212419080431573, 0.016075436324172188, 0.0278954071472981, 0.05921098330873065, 0.033132693206425756, 0.04965959466062486, 0.031023346236906946, 0.02423339075903641, 0.11543203916517086, 0.01647251130634686, 0.04939169048157055, 0.012969985236850334, 0.11001695122104138, 0.028501159213192295, 0.08411240531131625, 0.0817470025504008, 0.03906643847585656, 0.03680222012917511, 0.0563561749731889, 0.014061650144867599, 0.028587090637302026, 0.011880826004926348, 0.03140565248031635, 0.06766549253370613, 0.03550585141056217, 0.07624203310115263, 0.02657318200363079, 0.26091338542755693, 10.83547292277217, 47.91543647646904, 54.6603861451149, 42.77609825134277, 35.387907698750496, 38.26972246170044, 22.945627346634865, 24.067482948303223, 34.89435218274593, 38.03874805569649, 26.17095697671175, 14.786991085857153, 4.095437815412879, 0.7358141883742064, 0.3628823981853202, 0.22019650699803606, 0.808461302658543, 0.3738330246414989, 0.9396911796648055, 13.019495978951454, 6.774547705426812, 3.095819754526019, 9.50547019019723, 7.1687176544219255, 5.723841385915875, 5.372715052217245, 6.8082604464143515, 2.953410283662379, 2.572010261937976, 1.4812822337262332, 0.3633231745334342, 0.6861282326281071, 0.7481842464767396, 1.5437410259619355, 0.870426477631554, 0.5434740905184299, 0.0952334437170066, 0.036765535769518465, 0.23563494498375803, 3.064936911687255, 0.6662108295131475, 0.09683887241408229, 0.21276276995195076, 0.20879697025520727, 0.07132534927222878, 0.0777169996581506, 0.06874298705952242, 0.05774524906883016, 0.21181650197831914, 0.6387657928280532, 1.191002510022372, 4.485550532117486, 2.16609348077327, 3.9184556622058153, 3.760974300093949, 3.5057051852345467, 4.046715404838324, 1.8273428454995155, 3.781403903849423, 0.5688715714495629, 1.8973410269245505, 1.7734151892364025, 0.7535886252298951, 0.6269338808488101, 2.185719427652657, 13.900596499443054, 25.969493687152863, 48.06634917855263, 57.97554865479469, 21.744147017598152, 21.122639067471027, 29.985078312456608, 44.23166334629059, 39.811527729034424, 33.82793180644512, 9.019482918083668, 0.08606264324043877, 0.00897389942110749, 0.12106158552342094, 0.030065840292081703, 0.027185889848624356, 0.02295838661666494, 0.011269591323070927, 0.009319233722635545, 0.015772690167068504, 0.04015679071017075, 0.04151106550125405, 0.010874317904381314, 0.08009822500753216, 0.02345636585232569, 0.038955958661972545, 0.035869347921106964, 0.04205209857900627, 0.05716894913348369, 0.03526030071952846, 0.027561717142816633, 0.03957753702707123, 0.031925671646604314, 0.010217122944595758, 0.03938692752853967, 0.036081019570701756, 0.060424012553994544, 0.05632175045320764, 0.02449554329359671, 0.02609060418762965, 0.01728905557683902, 0.02344339867704548, 0.019228944256610703, 0.07655256253201514, 0.06467241095378995, 0.08622693247161806, 0.030512813573295716, 0.04154822112468537, 0.04952157374646049, 0.06758169663953595, 0.043735512153944, 0.054258223681245, 0.0344333329849178, 0.019511327736836392, 0.02343449476029491, 0.029234560679469723, 0.038736026908736676, 0.012195133895147592, 0.022072813335398678, 0.02919785776612116, 0.022098343215475325, 0.098159590997966, 0.006624181487495662, 0.03024746609298745, 0.027385614775994327, 0.030036692442081403, 0.005046760979894316, 0.02077732962789014, 0.018879628332797438, 0.07897046481957659, 0.020515472097031306, 0.02442016892018728, 0.016431583717348985, 0.02294556787092006, 0.023767403654346708, 0.06417132768547162, 0.028406893470673822, 0.021371472648752388, 0.03576805589545984, 0.055785192525945604, 0.04228758945828304, 0.045941798452986404, 0.027308026947139297, 0.06277456122916192, 0.04323832516092807, 0.027749487926485017, 0.054618053982267156, 0.043927312799496576, 0.0548767666623462, 0.07076732101268135, 0.021952385031909216, 0.029849122038285714, 0.05411157901107799, 0.04879544903815258, 0.05007412124541588, 0.05054430519521702, 0.07486530463211238, 0.022422452093451284, 0.05190121089981403, 0.02668612574780127, 0.01592270789842587, 0.03237214026739821, 0.07564149462268688, 0.014257206985348603, 0.078051812160993, 0.06205301186128054, 0.06666527784545906, 0.04615795267454814, 0.06606210474274121, 0.049045920168282464, 1.8623845651745796, 23.674363642930984, 57.73661747574806, 50.52849926054478, 38.23045916855335, 23.655925132334232, 22.074569687247276, 28.78129530698061, 39.71225805580616, 52.962933629751205, 48.02343808114529, 28.55586290359497, 12.123829890042543, 1.3817721046507359, 0.16932626167545095, 0.16283908946206793, 0.12073904814315028, 0.8475103823002428, 0.7822854572441429, 0.6802989298012108, 1.86515734763816, 0.3029634431004524, 1.9420698517933488, 2.057094192132354, 3.0121610686182976, 3.8005335023626685, 2.36311053391546, 1.4686423307284713, 5.058287149295211, 2.8045803448185325, 2.768533816561103, 1.5066396980546415, 1.145359834190458, 1.5997548890300095, 2.5493506528437138, 2.654940099455416, 0.9038382628932595, 0.8666505489964038, 0.749805987579748, 1.8879963783547282, 2.999052247032523, 3.1774502992630005, 1.3643201161175966, 1.0095217544585466, 1.1035340535454452, 0.30971737287472934, 0.2618300565518439, 0.31564781558699906, 0.37618046742863953, 0.4362504940945655, 1.338585284538567, 2.933799773454666, 2.609461764805019, 2.846503732725978, 2.0169669203460217, 1.8340367800556123, 3.089679521508515, 1.9741455931216478, 0.5151566443964839, 1.5088748093694448, 0.5747572774998844, 1.244538549799472, 0.9532956965267658, 0.1979011291405186, 0.40897196566220373, 1.2154987268149853, 8.4745142608881, 29.494309946894646, 47.41517812013626, 72.13690996170044, 38.361498937010765, 18.698219060897827, 24.31795220822096, 36.670935451984406, 46.37162111699581, 41.27227574586868, 17.042117826640606, 0.5986194033175707, 0.11076790819060989, 0.010940702086372767, 0.031657908475608565, 0.03980966597737279, 0.004150024869886693, 0.04699081677244976, 0.03164004869177006, 0.05704981587768998, 0.06471854285337031, 0.042248066383763216, 0.0671644760586787, 0.0795959543029312, 0.024745222181081772, 0.06666820190730505, 0.03735788464837242, 0.04649282454920467, 0.026242631283821538, 0.03209035421605222, 0.062269945337902755, 0.03307735867565498, 0.034346724351053126, 0.040685823259991594, 0.03679462424770463, 0.05794123913801741, 0.006505524597741896, 0.03725602859049104, 0.03153826684865635, 0.040251789323519915, 0.025700544356368482, 0.06068507784220856, 0.051568680501077324, 0.03739895510079805, 0.03837720592855476, 0.09866120861261152, 0.048816737544257194, 0.02084756091790041, 0.05380806287575979, 0.054308745384332724, 0.03550516863469966, 0.028894753522763494, 0.06279653622186743, 0.05402005735959392, 0.04681597049057018, 0.04226049735734705, 0.020933533160132356, 0.18236092786537483, 0.08691468814504333, 0.08958530655945651, 0.07329476429731585, 0.2136786247137934, 0.1323559822048992, 0.13478494249284267, 0.08953654003562406, 0.1451495394576341, 0.20125352893956006, 0.14351160469232127, 0.10237801034236327, 0.14935613638954237, 0.12490713503211737, 0.11544944252818823, 0.08455336719634943, 0.09421978131285869, 0.11229219046072103, 0.18591960018966347, 0.19319981656735763, 0.16819453099742532, 0.1506210825755261, 0.16394150530686602, 0.11874837800860405, 0.13532457291148603, 0.0425101335713407, 0.14717800717335194, 0.24027606938034296, 0.12371828124742024, 0.12136398843722418, 0.14946585550205782, 0.16033505351515487, 0.1908949136850424, 0.1636505834176205, 0.14665200258605182, 0.10752448535640724, 0.1222224603407085, 0.12832327047362924, 0.2726132544921711, 0.1632691640406847, 0.2331881583086215, 0.14608644152758643, 0.15807426389073953, 0.1327538921032101, 0.11543500033440068, 0.16224857739871368, 0.1542213893844746, 0.09402916068211198, 0.11223979483474977, 0.15945020568324253, 0.13368562882533297, 0.10224119541817345, 0.1469353842549026, 1.0941058094613254, 19.791937172412872, 66.50953352451324, 71.8801349401474, 56.47684447467327, 49.66388985514641, 49.15723644196987, 32.698495611548424, 31.43028136342764, 45.66236637532711, 54.21675615012646, 34.91476468741894, 18.883567415177822, 5.83494077436626, 1.3566163857467473, 0.49528623407240957, 0.3464401757810265, 2.1692943340167403, 3.260179222561419, 5.356068620458245, 26.01532492786646, 18.17353181540966, 16.04535721242428, 21.526595391333103, 18.561794981360435, 13.639010936021805, 15.474243108183146, 16.297488883137703, 7.228888375684619, 7.044507069513202, 6.611780114471912, 2.6803607353940606, 1.953103628475219, 4.269515974447131, 4.98288257047534, 2.062874869443476, 1.644112046342343, 0.6111727422103286, 0.631598902400583, 1.7102186428382993, 6.080250861123204, 3.053423766978085, 0.6900256953667849, 0.5795219843275845, 0.7623626512940973, 0.3458601428428665, 0.20109534758375958, 0.2933688391931355, 0.6359336979221553, 0.4974384029628709, 1.2746913568116724, 4.016813859343529, 11.334371902048588, 11.735733915120363, 13.124790228903294, 11.336871217936277, 17.568906359374523, 14.840303175151348, 9.206173550337553, 9.243900775909424, 5.217970730736852, 5.599318742752075, 3.773426706902683, 1.4225238491781056, 0.8142106316518039, 3.0488936975598335, 17.21858035773039, 34.948590472340584, 58.31578999757767, 67.34862729907036, 30.62981441617012, 29.682464450597763, 42.340273037552834, 55.406415313482285, 54.7159543633461, 50.641759783029556, 17.147898450493813, 0.3986005112528801, 0.11434846644988284, 0.16652377846185118, 0.051938785836682655, 0.08696965902345255, 0.09902352510835044, 0.12680954154348, 0.0792587743490003, 0.11887912958627567, 0.20139931642916054, 0.21980168443406, 0.1243405943387188, 0.27491560438647866, 0.1043712928367313, 0.2410880828392692, 0.18000508396653458, 0.21523116796743125, 0.18192421848652884, 0.10953988385153934, 0.25127386674284935, 0.1539913978194818, 0.12049447337631136, 0.11474101804196835, 0.22675361920846626, 0.11677735252305865, 0.15237427287502214, 0.12396483012707904, 0.15122755081392825, 0.12199632052215748, 0.11550314433407038, 0.17104669357649982, 0.15144068078370765, 0.10245733850752003, 0.2014121852698736, 0.26907003368251026, 0.2835157897789031, 0.13016888784477487, 0.13830245530698448, 0.19267068011686206, 0.1728998066391796, 0.1686372814583592, 0.18991887074662372, 0.286523150280118, 0.16935421095695347, 0.07978347275638953, 0.1686659432016313], [0.012734558367810678, 0.039297821567743085, 0.03990845325461123, 0.031156639670371078, 0.0698419296531938, 0.03788336231082212, 0.03630557119322475, 0.01608261289220536, 0.04969662782968953, 0.01057200775903766, 0.021258825763652567, 0.07450585282640532, 0.027999163103231695, 0.0803573384473566, 0.030537430611730088, 0.05785018132883124, 0.05232625000644475, 0.02796577387925936, 0.03589278494473547, 0.019664874380396213, 0.10276386034092866, 0.045145392359700054, 0.017488726698502433, 0.018305963021703064, 0.0449614659009967, 0.0852759370172862, 0.01832629230193561, 0.011751013244065689, 0.051695661968551576, 0.046344276270247065, 0.05695942229067441, 0.03189774834027048, 0.03585906917578541, 0.0844715751009062, 0.04221514842356555, 0.03871799272019416, 0.09601548925274983, 0.029079307096253615, 0.015329972175095463, 0.09360071140690707, 0.0061239887963893125, 0.03120994813798461, 0.013077937110210769, 0.04453697969438508, 0.0822822171903681, 0.03490778799459804, 0.025547682344040368, 0.044016582032782026, 0.01533194721559994, 0.006790424422433716, 0.09565813772496767, 0.02418905856757192, 0.10218065843218938, 0.03835315663309302, 0.12818487477488816, 4.930195547640324, 31.35516509413719, 54.4056212157011, 47.59661838412285, 39.602850526571274, 27.768615446984768, 27.36614864319563, 30.076108127832413, 21.140853390097618, 31.146919168531895, 38.030624091625214, 35.78021764755249, 27.63292472809553, 17.97823179513216, 9.612968321889639, 3.3991627022624016, 0.4252952663227916, 0.09550429793307558, 0.2337022143183276, 0.2002798905596137, 0.8341937593650073, 0.7603904383722693, 1.167790861800313, 2.388574630022049, 2.9888607189059258, 2.361103054136038, 3.578316676430404, 2.473955098539591, 2.369564725086093, 0.9947360353544354, 0.9930776024702936, 1.653268130030483, 1.7149188718758523, 3.1577602308243513, 0.787858689436689, 1.8428052845411003, 1.8978125578723848, 2.5172428507357836, 1.9350344105623662, 2.8239859035238624, 2.7648043166846037, 1.694463025778532, 0.6920908251777291, 0.6569780374411494, 0.7333465770352632, 1.6755798202939332, 1.1343141831457615, 0.9881585882976651, 3.1495293974876404, 4.189323177561164, 1.4027739339508116, 0.9846699004992843, 0.7546917535364628, 1.3032676046714187, 1.886759188491851, 1.3448887900449336, 1.092511082533747, 0.6066483131144196, 0.2810355322435498, 1.2313169217668474, 4.703703001141548, 10.317863747477531, 23.19029811769724, 36.06597751379013, 39.01048131287098, 31.616986244916916, 49.49415676295757, 26.301637664437294, 31.22350785881281, 39.90620344877243, 41.00461430847645, 40.834702625870705, 21.78125962615013, 2.354480721987784, 0.056654585132491775, 0.0458787901152391, 0.025838522597041447, 0.010705477452574996, 0.027556592613109387, 0.12972233758773655, 0.07306120300199836, 0.017765464290278032, 0.04260843103111256, 0.03179061190166976, 0.021448908337333705, 0.046348213363671675, 0.03236746844777372, 0.03713365214935038, 0.06947831439902075, 0.02051770410616882, 0.016447463822260033, 0.05120492052810732, 0.04830989149922971, 0.06389596121152863, 0.028846384047938045, 0.013656853116117418, 0.13324201747309417, 0.02060448157862993, 0.02345120421523461, 0.04638747668650467, 0.009987416178773856, 0.01612419913726626, 0.04311021191824693, 0.02460863732267171, 0.05427593503554817, 0.09511632539215498, 0.020508963461907115, 0.07778175946441479, 0.10874914776650257, 0.04946210545313079, 0.039027316161082126, 0.039029850595397875, 0.0447853839432355, 0.015554701913060853, 0.03191469528246671, 0.017998997755057644, 0.037110578778083436, 0.03470141899015289, 0.03271747271355707, 0.05195927653403487, 0.10428784575196914, 0.008814401680865558, 0.07610590095282532, 0.02584019985079067, 0.013026548022025963, 0.03471526004432235, 0.04247351229423657, 0.010464050319569651, 0.002987073894473724, 0.030363671576196793, 0.05882094759726897, 0.008988956669782056, 0.056689736957196146, 0.04319213760027196, 0.013349830333027057, 0.01433103305316763, 0.07334442139836028, 0.0364864882430993, 0.0167378198239021, 0.043456312487251125, 0.01750782030285336, 0.13940408447524533, 0.03330472674861085, 0.012421360916050617, 0.02750784464296885, 0.061678509300691076, 0.02455646805174183, 0.024019615120778326, 0.06749977095751092, 0.02984318485687254, 0.08151085858116858, 0.049986314043053426, 0.039112692829803564, 0.04179806885076687, 0.035035084874834865, 0.07293151269550435, 0.06214071516296826, 0.01823579481424531, 0.05106908152811229, 0.0369372501882026, 0.016016276022128295, 0.07791757248924114, 0.022778291495342273, 0.024134455052262638, 0.055062990068108775, 0.039154590776888654, 0.029093869889038615, 0.09428704957826994, 0.08763644160353579, 0.006243085872483789, 0.05683219962520525, 0.06814333915826865, 0.02327361569768982, 0.10868539728107862, 0.04633704404113814, 0.5093041865620762, 13.046398535370827, 46.962584406137466, 60.187998935580254, 50.93810208141804, 40.49351893365383, 21.88980270177126, 13.057322949171066, 21.8920673802495, 33.70898678898811, 47.93148681521416, 56.936418414115906, 48.81540298461914, 29.75260678678751, 15.647347569465637, 4.774030102416873, 0.42487494356464595, 0.05139679538842756, 0.18529278226196766, 0.2022374831722118, 0.16835228190757334, 0.7234347495250404, 0.6283243687357754, 0.741889231139794, 0.6416452070698142, 1.435748445801437, 0.5945739860180765, 1.434932320844382, 0.7543504843488336, 0.983061755541712, 0.8359965845011175, 1.147609194740653, 0.8394613454584032, 1.058517750352621, 1.9173213047906756, 0.9200174978468567, 1.2006488861516118, 1.945674552116543, 2.437071902677417, 2.395244697108865, 1.828810041770339, 2.2166815912351012, 3.063792698085308, 1.4436858636327088, 1.2383270706050098, 0.8640467980876565, 1.0682649398222566, 3.0422875145450234, 1.1007702955976129, 2.1017759945243597, 1.0967907216399908, 0.9240603621583432, 0.787005100864917, 1.688094804994762, 0.6790052773430943, 1.127179590985179, 0.20800356986001134, 0.066779271728592, 0.8491181710269302, 0.046820119096082635, 0.4865893616806716, 2.2279240004718304, 5.039460584521294, 16.878426410257816, 38.46718266606331, 63.5264427959919, 51.71322628855705, 59.97256189584732, 37.359025329351425, 17.57655154913664, 29.292567372322083, 41.76263943314552, 48.63372713327408, 30.19322544336319, 5.972622111439705, 0.2331666211830452, 0.05341776741261128, 0.03397640750335995, 0.02267048341309419, 0.07301400240976363, 0.10449406632687896, 0.19409060158068314, 0.030478233202302363, 0.014557556933141313, 0.04649380047339946, 0.012782394423993537, 0.03966125499573536, 0.03652591854915954, 0.01599214880116051, 0.04108447530597914, 0.03272721711255144, 0.00966214027357637, 0.03505596519971732, 0.03448161711276043, 0.04666131062549539, 0.03402795337024145, 0.047009125555632636, 0.009121187904383987, 0.021089948204462416, 0.02259273787785787, 0.011820456929854117, 0.022245396066864487, 0.02611535481264582, 0.004269867340553901, 0.04186721103906166, 0.08278090332169086, 0.09644370104069822, 0.02955499407107709, 0.02157256683858577, 0.059990045410813764, 0.039880652402644046, 0.03255316863942426, 0.04048818191222381, 0.053142133765504695, 0.03091971459070919, 0.039220738399308175, 0.04522198942140676, 0.06550814345246181, 0.03741337874089368, 0.051863988483091816, 0.038129028034745716, 0.0827324484998826, 0.13037565018748865, 0.16830321110319346, 0.10977895188261755, 0.10062086439575069, 0.1257629500469193, 0.10780221185996197, 0.28878738346975297, 0.08915470505598933, 0.18439095409121364, 0.16576030146097764, 0.0899169797776267, 0.15278913342626765, 0.06230136044905521, 0.12978176877368242, 0.14084290101891384, 0.317889042198658, 0.15238726045936346, 0.10223807839793153, 0.07509273578762077, 0.08519512455677614, 0.21882948582060635, 0.1647201963351108, 0.05572796180786099, 0.16586356388870627, 0.10820516836247407, 0.12028186290990561, 0.13899896090151742, 0.15810690354555845, 0.1546752275316976, 0.20986732532037422, 0.19894311932148412, 0.1395530186709948, 0.11444630377809517, 0.21604745619697496, 0.16629611724056304, 0.10186504528974183, 0.10152054775971919, 0.12815349677111953, 0.12265305442269892, 0.12450188529328443, 0.2163364930311218, 0.1686639097169973, 0.12710792943835258, 0.12948293559020385, 0.17461428651586175, 0.09603796148439869, 0.11732258615666069, 0.2737982268445194, 0.1085793889069464, 0.15759450994664803, 0.2700536168413237, 0.09515246798400767, 0.28453330392949283, 0.12683970242505893, 0.5389205098617822, 8.422729689627886, 46.75713703036308, 77.53775015473366, 66.1146131157875, 56.26887783408165, 40.44388219714165, 39.41648572683334, 40.65129026770592, 30.717986784875393, 41.83023400604725, 52.746117264032364, 47.089015021920204, 36.38295270502567, 23.55205960571766, 12.654234878718853, 4.650085978209972, 0.7248841342516243, 0.6058967253193259, 0.6151285080704838, 0.8793925121426582, 2.255205111578107, 3.2142807729542255, 2.5884631415829062, 9.97998682782054, 9.377112127840519, 7.503805048763752, 12.363800313323736, 8.067580796778202, 8.512393478304148, 4.348939787596464, 3.204749934375286, 3.8923726743087173, 8.589418195188046, 8.72604176402092, 3.6261805705726147, 5.444233864545822, 7.122203400358558, 5.470070103183389, 8.920066952705383, 9.777021668851376, 7.7422218304127455, 6.847167983651161, 2.931265071965754, 3.149353419430554, 3.313755397684872, 5.52262413315475, 6.290511153638363, 4.6739885956048965, 12.554390486329794, 15.843278355896473, 8.326135072857141, 6.200920986011624, 8.129972498863935, 6.690688580274582, 4.962699003517628, 3.504637205041945, 2.0920131308957934, 1.932237760629505, 0.490740817040205, 1.7815814260393381, 6.519212806597352, 14.775570798665285, 30.86234673857689, 44.71100762486458, 49.748971089720726, 40.26352107524872, 54.699588641524315, 36.96641519665718, 43.65171566605568, 50.968078672885895, 55.55067837238312, 57.35501155257225, 34.011743143200874, 4.6116353664547205, 0.3335966571466997, 0.24257288285298273, 0.14071162993786857, 0.13908220018493012, 0.15017623925814405, 0.3004142548888922, 0.3390986134763807, 0.20130724558839574, 0.2012150114751421, 0.13476293039275333, 0.11304584142635576, 0.2621587389148772, 0.12981770356418565, 0.10345891132601537, 0.13214185775723308, 0.2063430441194214, 0.08680566665134393, 0.09105320044909604, 0.26405813230667263, 0.12368307376164012, 0.1809947082074359, 0.1719879891606979, 0.19933279138058424, 0.16917755012400448, 0.10891962650930509, 0.11463822316727601, 0.09080136005650274, 0.057909653332899325, 0.08821872324915603, 0.09578885961673222, 0.14075755403609946, 0.26304287428501993, 0.08953709664638154, 0.1674119065864943, 0.11250268580624834, 0.20655218133470044, 0.10265702818287537, 0.14775538322282955, 0.159001087595243, 0.14549315383192152, 0.15790052711963654, 0.08698006393387914, 0.12079623804311268, 0.16565485711907968, 0.11068067615269683, 0.1537786389235407, 0.1943899245816283], [0.0339764631644357, 0.019097001531918067, 0.05491859781614039, 0.04641164843633305, 0.02511704744392773, 0.0607597193447873, 0.036773636311409064, 0.064995126449503, 0.04358353886345867, 0.10545009354245849, 0.016588837388553657, 0.04052719290484674, 0.06856982916360721, 0.006807691415815498, 0.024320416850969195, 0.050992369433515705, 0.0430487138510216, 0.05660854229063261, 0.023832901897549164, 0.044149033128633164, 0.05467145150760189, 0.0937162118498236, 0.02308657221874455, 0.043816788456751965, 0.07536644727224484, 0.09107680816669017, 0.06514409033115953, 0.07237607453134842, 0.02831420293659903, 0.04906366491923109, 0.025655264071247075, 0.015457408208021661, 0.07253861229401082, 0.005555428069783375, 0.07486402813810855, 0.07590586246806197, 0.009288630335504422, 0.06496720685390756, 0.06142832018667832, 0.014846210633550072, 0.06971281822188757, 0.05494276214449201, 0.023157775722211227, 0.02791597020404879, 0.041020628341357224, 0.041163491769111715, 0.052708177754539065, 0.06176611983391922, 0.12079703956260346, 0.020676993117376696, 0.03702357680595014, 0.01796704458683962, 0.054941463386057876, 0.03265038256358821, 0.03476933292404283, 0.012751743724948028, 1.0790980397723615, 13.849778976291418, 41.13531209528446, 44.5517847687006, 40.21586023271084, 29.57151610404253, 28.745387233793736, 29.967850036919117, 27.179164476692677, 17.513702921569347, 21.80927362293005, 33.66236709058285, 36.851554960012436, 36.91313445568085, 36.330063343048096, 32.220371067523956, 25.51921594887972, 16.21985524892807, 9.744123984128237, 5.7105520740151405, 2.4830817338079214, 1.161785046570003, 0.05984499635815155, 0.2739525638753548, 0.4760699823964387, 1.6315483767539263, 1.2050204328261316, 0.7262802624609321, 0.4337151988875121, 0.7196931377984583, 0.4696342261740938, 0.4508326866198331, 2.3251270595937967, 1.3482402102090418, 0.430114179616794, 0.38270382676273584, 2.685476210899651, 0.8896507741883397, 2.013568002730608, 3.9843436516821384, 3.7114591570571065, 2.261056322604418, 0.5999477882869542, 2.740133428014815, 1.3738041697070003, 2.2260943986475468, 0.3576395701384172, 1.3512317184358835, 1.1504438426345587, 1.0913198464550078, 0.19927677407395095, 0.057926466688513756, 0.14306089840829372, 1.3377525354735553, 4.315906260162592, 9.115455318242311, 15.69095117971301, 22.67992090433836, 37.735759913921356, 33.86368788778782, 50.25513052940369, 81.78345993161201, 37.93534800410271, 17.2181623801589, 24.02466494590044, 35.20446114242077, 32.435599118471146, 45.703643560409546, 48.99007961153984, 40.231693983078, 11.26945998519659, 0.36937292490620166, 0.26591765752527863, 0.0797447474906221, 0.06023165529768448, 0.02114380957209505, 0.046844457829138264, 0.019285800190118607, 0.0448448745009955, 0.02655033313203603, 0.027282912669761572, 0.004138381036682404, 0.010326950596208917, 0.02261379446281353, 0.03746270187548362, 0.037577489856630564, 0.05226042150752619, 0.030766032505198382, 0.04156098606472369, 0.03674779844004661, 0.03733278521394823, 0.016842980294313747, 0.0333381122618448, 0.07265689579071477, 0.0393685742164962, 0.09634174479288049, 0.03889853869623039, 0.08358440434676595, 0.06505828321678564, 0.0050144552915298846, 0.04430109547683969, 0.05568886917899363, 0.030700979550601915, 0.06403065359336324, 0.020702743786387146, 0.044340184394968674, 0.03751196934899781, 0.03143845540762413, 0.002988946889672661, 0.09057568779098801, 0.062246500892797485, 0.09491133678238839, 0.040154935340979137, 0.029014391438977327, 0.023203755481517874, 0.05483879467647057, 0.003140668545711378, 0.04390504465845879, 0.04491000538109802, 0.054725168156437576, 0.028100314120820258, 0.012918645315949107, 0.00904249520317535, 0.06625274021644145, 0.020453467514016666, 0.10371962780482136, 0.02217934677901212, 0.03747699192899745, 0.04235123975377064, 0.05934668872214388, 0.034819212669390254, 0.014391541280929232, 0.03658564659417607, 0.04874645615927875, 0.06323484121821821, 0.04276240440958645, 0.04655968092265539, 0.028404123404470738, 0.03204214430297725, 0.051159697759430856, 0.02160698022635188, 0.020854140057053883, 0.016497627439093776, 0.030932605695852544, 0.05781127423688304, 0.01531136653284193, 0.011170614798174938, 0.007841411752451677, 0.027300945002934895, 0.0227630811787094, 0.02708133979467675, 0.020162627261015587, 0.02432931705698138, 0.01275543498195475, 0.010538562873989576, 0.06810753053287044, 0.02090310325002065, 0.06353927019517869, 0.0591105595958652, 0.05896431939618196, 0.01281036411455716, 0.0707963241438847, 0.03465333895292133, 0.03486974550469313, 0.06925124689587392, 0.0213980062835617, 0.010846854729607003, 0.042044565780088305, 0.007955389864946483, 0.021646414243150502, 0.016299794988299254, 0.06074441254895646, 0.0663179304683581, 0.011753615399356931, 0.01790124391845893, 0.16372136946301907, 3.349955817684531, 27.998126931488514, 56.351736187934875, 49.451367259025574, 42.24001921713352, 30.730704702436924, 28.486176542937756, 19.825766757130623, 22.846114486455917, 22.72593643516302, 33.36369551718235, 49.23722214996815, 60.44053718447685, 53.966554775834084, 43.51449742913246, 33.27714376151562, 19.10554200410843, 11.280357800424099, 6.365787964314222, 1.846677870489657, 0.30149075493682176, 0.6612142163794488, 0.0411213785992004, 0.2756621752632782, 0.20496267912676558, 0.49799151078332216, 0.6276447395794094, 0.5113031168002635, 0.786271383985877, 0.4966107598738745, 0.4564508335897699, 0.014944026625016704, 0.9753940044902265, 0.3156156954355538, 0.5732830753549933, 0.557589145610109, 0.6176997232250869, 0.6179820362012833, 0.7460458518471569, 1.4314729627221823, 0.3107047558296472, 1.136913956142962, 1.179638507310301, 0.8615266426932067, 0.9674777823965997, 1.326004397124052, 0.7261113496497273, 1.0418172902427614, 0.3201858705142513, 0.6286986486520618, 0.37027157668489963, 0.19521027978044003, 0.1934314557001926, 0.8667739236261696, 1.864746732171625, 6.185304773971438, 13.505256213247776, 17.780192121863365, 37.29059100151062, 45.22716052830219, 58.28531563282013, 78.32843452692032, 45.856942534446716, 23.28436776995659, 21.638822369277477, 35.23719638586044, 25.410264395177364, 40.0821378082037, 52.62630969285965, 49.284693002700806, 19.036526307463646, 0.9416860132478178, 0.18395612976746634, 0.11263822423643433, 0.038750988605897874, 0.050872757492470555, 0.036214494830346666, 0.033494030067231506, 0.034919109457405284, 0.0468295332393609, 0.08887382442480884, 0.01375437688693637, 0.062285723397508264, 0.05799733437015675, 0.01715786613203818, 0.0729583042266313, 0.038768915183027275, 0.017037294965120964, 0.06616265833145007, 0.02524269304558402, 0.017886857385747135, 0.06098709112848155, 0.013250522624730365, 0.052874058892484754, 0.02954114374006167, 0.023530092657892965, 0.01628408001124626, 0.034142006625188515, 0.032394341615145095, 0.015149153459788067, 0.038465072502731346, 0.11225524634937756, 0.029297290711838286, 0.04941357270581648, 0.045042456476949155, 0.03474569552054163, 0.04358331621915568, 0.08046098679187708, 0.02263258007587865, 0.04482045413169544, 0.05271383291983511, 0.027813080705527682, 0.03404374256206211, 0.0403941889089765, 0.021469694038387388, 0.03617054855567403, 0.009584583058313001, 0.035513165275915526, 0.02593301840533968, 0.01802923285140423, 0.23801801085937768, 0.08775206821155734, 0.16440625302493572, 0.13906410662457347, 0.10355248872656375, 0.11141646362375468, 0.09453870443394408, 0.12745755520882085, 0.15825226058950648, 0.18714341655140743, 0.15207345073577017, 0.11749670884455554, 0.25464360311161727, 0.0689433966181241, 0.20440387161215767, 0.15715637564426288, 0.12183157115941867, 0.14060308341868222, 0.12807496270397678, 0.1825105893658474, 0.1465573045425117, 0.2975967654492706, 0.08635835940367542, 0.14973616052884609, 0.16205891413846985, 0.12104703942895867, 0.17544630827615038, 0.14235293405363336, 0.16697166458470747, 0.15586719091515988, 0.11992962477961555, 0.1413687868625857, 0.15766229771543294, 0.11175973661011085, 0.15742862509796396, 0.19981828954769298, 0.08070958399912342, 0.16290224622935057, 0.1166938163805753, 0.13872564275516197, 0.1796932186698541, 0.2588790695881471, 0.11747773954994045, 0.12851355713792145, 0.20397430169396102, 0.12764882150804624, 0.1146434701513499, 0.14950898912502453, 0.20198831451125443, 0.10848456469830126, 0.13750960410106927, 0.1689316617557779, 0.1723475003382191, 0.17562072782311589, 0.16827043786179274, 0.16117255232529715, 1.7938716290518641, 21.993121057748795, 63.46134088933468, 66.33127748966217, 62.33362220227718, 44.139613285660744, 47.43901804089546, 42.615477070212364, 39.911610558629036, 26.295122914016247, 33.89810264110565, 44.76866573095322, 52.06731788814068, 49.49449114501476, 47.77463883161545, 43.27357515692711, 32.09626592695713, 20.094285048544407, 13.208540584892035, 7.3768562357872725, 3.755159662105143, 1.7730247601866722, 0.20944676507497206, 0.5164165736641735, 0.771401475649327, 3.738688020966947, 3.8546554232016206, 2.719547557644546, 4.058456774801016, 4.118630820885301, 3.9196362113580108, 6.0878238547593355, 9.781717266887426, 4.732694970443845, 6.451876619830728, 5.977863455191255, 12.027043383568525, 6.495269341394305, 10.617935545742512, 17.076570577919483, 17.265885919332504, 8.578485231846571, 5.395394135266542, 8.986554834991693, 4.791561411693692, 6.239905944094062, 3.035114211961627, 3.918581767939031, 2.5508715212345123, 2.1416408428922296, 0.5216246098279953, 0.24110378668410704, 0.4785192775307223, 2.0170514658093452, 5.518234893679619, 13.016247153282166, 21.33772272616625, 31.214783526957035, 49.3271367251873, 47.63911910355091, 59.639840349555016, 90.4670275747776, 48.289731591939926, 21.748429387807846, 33.56083653867245, 46.734304055571556, 42.627286836504936, 58.16894307732582, 65.7982648909092, 56.3470396399498, 16.31997987627983, 0.6011161068454385, 0.33840114308986813, 0.2397437416948378, 0.12291579696466215, 0.11967891245149076, 0.10357381062931381, 0.16963169997325167, 0.14290858001913875, 0.10528599726967514, 0.11960834162891842, 0.0981512492580805, 0.2076976269017905, 0.14566013705916703, 0.13309032248798758, 0.19657722674310207, 0.2420594947761856, 0.13738389912759885, 0.14071280253119767, 0.06544507574290037, 0.09753694394021295, 0.12884894851595163, 0.09420517584658228, 0.16191262198844925, 0.11240296342293732, 0.19322411448229104, 0.11885839398019016, 0.1345644355751574, 0.12065507413353771, 0.0905429368140176, 0.1360620599007234, 0.22507117042550817, 0.09487525356234983, 0.09327018851763569, 0.10518620067159645, 0.11563997410121374, 0.19750243256567046, 0.18635564163560048, 0.154486350947991, 0.18098890461260453, 0.23249134101206437, 0.13457374210702255, 0.1322114118374884, 0.1485479375696741, 0.12060542445397004, 0.14071030891500413, 0.11013795839971863, 0.191924539685715, 0.20867945859208703, 0.18156593927415088], [0.02571864904894028, 0.10289220736012794, 0.017593367665540427, 0.03510944436129648, 0.021907583432039246, 0.03116961983323563, 0.048951385397231206, 0.08361180443898775, 0.02599460924102459, 0.052063147522858344, 0.07176277111284435, 0.04960702091921121, 0.0717582440120168, 0.020906689678668045, 0.025874741259030998, 0.07702953342231922, 0.020044275115651544, 0.051481478149071336, 0.02953195038571721, 0.029502427751140203, 0.06775826841476373, 0.0319868914084509, 0.04320041625760496, 0.11958248520386405, 0.02502865765563911, 0.042507094476604834, 0.02244286300992826, 0.02593591092590941, 0.01006745958875399, 0.03494523305562325, 0.057073356801993214, 0.026664490287657827, 0.0007897839907400339, 0.050587687437655404, 0.09660896990681067, 0.06817384142777883, 0.09660154100856744, 0.044166811276227236, 0.009267635905416682, 0.08282814102130942, 0.01313938601015252, 0.038263442111201584, 0.009763855323399184, 0.06885807189974003, 0.02441119635477662, 0.041207363829016685, 0.06257999979425222, 0.046231618252932094, 0.042584511611494236, 0.06939506769413128, 0.08609805852756836, 0.04555400773824658, 0.019672308844747022, 0.006025684842825285, 0.03969852936279494, 0.06581551875569858, 0.016323927775374614, 0.07012951929937117, 2.8084148140624166, 21.09325524419546, 36.21188208460808, 46.85637250542641, 45.53723908960819, 42.6155074685812, 38.83071295917034, 30.353371649980545, 28.67013417184353, 22.567395642399788, 33.708166033029556, 31.386769898235798, 24.802188724279404, 29.544258266687393, 34.08539459109306, 42.73943021893501, 40.25136172771454, 39.23678196966648, 36.079014614224434, 30.67607693374157, 29.45307455956936, 22.209762632846832, 13.089622166007757, 8.258011378347874, 3.1081714667379856, 0.7599210448097438, 0.349809288745746, 0.10330849283491261, 0.09539527643937618, 0.29096576501615345, 0.6584401871077716, 0.8050145313609391, 0.7013625057879835, 0.7472475967369974, 0.8896909095346928, 0.6619649729691446, 0.45978340320289135, 0.6324486911762506, 0.4672432044753805, 0.47821918269619346, 0.12950920761795714, 0.04483535645704251, 0.21887591457925737, 0.39661327726207674, 1.6940774652175605, 4.46550328284502, 8.216136675328016, 14.296246469020844, 19.852849803864956, 26.403897777199745, 32.13529743254185, 31.45281035453081, 30.132012628018856, 29.86436638981104, 40.87273858487606, 40.889670476317406, 28.28760489821434, 25.129970535635948, 27.845447324216366, 62.17828653752804, 49.711729288101196, 40.33315993845463, 41.43282473087311, 46.37832395732403, 52.29606181383133, 43.80299314856529, 19.031759463250637, 1.4275746094062924, 0.026290687201253604, 0.026903493380814325, 0.07978437075507827, 0.045989652135176584, 0.02025962596235331, 0.10644822279573418, 0.02121175504726125, 0.03445472539169714, 0.06578831162187271, 0.08323373956955038, 0.010082596618303796, 0.01571055756357964, 0.04097992896276992, 0.10125810949830338, 0.01860701151599642, 0.049822885703179054, 0.04772788815898821, 0.05860746881808154, 0.040662976243766025, 0.06856607389636338, 0.033522224257467315, 0.023226643315865658, 0.06252407154534012, 0.023768309074512217, 0.017171807376143988, 0.03260255114582833, 0.007306442485059961, 0.0389624969830038, 0.0373283211956732, 0.019952467737311963, 0.05469049501698464, 0.044864708397653885, 0.09701528091682121, 0.054271381959551945, 0.06823230040026829, 0.026508416631259024, 0.027580174355534837, 0.04854059181525372, 0.08093259937595576, 0.0659211486345157, 0.03788671310758218, 0.028485551847552415, 0.034042284241877496, 0.06655970733845606, 0.02264604263473302, 0.012097543331037741, 0.03442314329731744, 0.020594907873601187, 0.1083327287051361, 0.05930238250584807, 0.05067898644483648, 0.07859262259444222, 0.03502343315631151, 0.04370232330984436, 0.022349421051330864, 0.029912677709944546, 0.037687212679884396, 0.14008004742208868, 0.02485811768565327, 0.01575979906192515, 0.032409652121714316, 0.023748590210743714, 0.038200463459361345, 0.04632855758245569, 0.02397317708528135, 0.012425581880961545, 0.0289277067349758, 0.012355674352875212, 0.02747268354141852, 0.013914296723669395, 0.027967710884695407, 0.015822052264411468, 0.051680295800906606, 0.03267577885708306, 0.06512301333714277, 0.03188333583239, 0.028786514994862955, 0.031812338274903595, 0.025286327618232463, 0.03233237970562186, 0.015677674855396617, 0.03820958074356895, 0.016707176546333358, 0.02378956418397138, 0.07286186213605106, 0.01684234019194264, 0.04091827133379411, 0.01688081683823839, 0.06521301358588971, 0.012168500070401933, 0.0803376195835881, 0.08804748009424657, 0.026808212751348037, 0.0538225347554544, 0.03411349331145175, 0.017793868137232494, 0.04091490198334213, 0.03050279829039937, 0.03625501238275319, 0.08259434966021217, 0.07724657451035455, 0.04258109773218166, 0.01518647606644663, 0.023605800997756887, 0.04831991049286444, 0.048263021162711084, 0.06352997850626707, 0.10786123486468568, 8.498974498361349, 33.45889940857887, 49.61412772536278, 51.14475019276142, 46.68513849377632, 41.14402882754803, 32.34210513532162, 21.859246641397476, 21.735439784824848, 23.44967219978571, 32.877614200115204, 35.9370656311512, 41.03217422962189, 50.813373774290085, 59.60889860987663, 62.65479616820812, 59.608241245150566, 55.32566964626312, 44.133450016379356, 36.70619376003742, 26.501714028418064, 14.502875581383705, 7.371435826644301, 2.925189435482025, 0.3330816957168281, 0.35375721752643585, 0.5018765351269394, 0.20518958335742354, 0.11880012054461986, 0.38932998839300126, 0.2820808324031532, 0.2596479345811531, 0.18979994900291786, 0.4154799476964399, 0.121420465875417, 0.2555232559097931, 0.2278091461630538, 0.3057728579733521, 0.34317526035010815, 0.4134860937483609, 0.21588109637377784, 0.1555391913279891, 0.28162571776192635, 0.6114630110096186, 0.4641001793788746, 1.726052868179977, 3.7824659468606114, 7.471777992323041, 15.389089677482843, 22.59842097759247, 31.211698092520237, 40.74722371995449, 44.7487585991621, 50.9144901484251, 56.749692633748055, 58.28138664364815, 49.69531036913395, 34.85243283212185, 41.02972716093063, 80.15520930290222, 43.55096027255058, 18.751119822263718, 27.666115947067738, 41.60120889544487, 53.92913818359375, 55.54326497018337, 30.89844100177288, 4.205238148570061, 0.015112340151972603, 0.06198484930791892, 0.037598355338559486, 0.02474042234098306, 0.031118869919737335, 0.026051548666146118, 0.04128088097786531, 0.011174616829521256, 0.03730093223566655, 0.06273708277149126, 0.011565518070710823, 0.019437521150393877, 0.013804314148728736, 0.015682736302551348, 0.07164462862419896, 0.04189408049569465, 0.033690458003547974, 0.03734452970093116, 0.053603827545885, 0.02496805573173333, 0.023976557567948475, 0.0371502911002608, 0.051084518199786544, 0.10672806442016736, 0.018639795889612287, 0.06417385098757222, 0.0220701304715476, 0.01026166757583269, 0.029136387529433705, 0.01805981490178965, 0.040980199846671894, 0.028597335985978134, 0.01645086656935746, 0.045514922530855983, 0.07517403064412065, 0.0372025234537432, 0.016963942944130395, 0.06985976346186362, 0.02856685041479068, 0.005149402322786045, 0.02090970094286604, 0.05896511720493436, 0.04712605834356509, 0.04163509322097525, 0.02374877945840126, 0.0093312834178505, 0.020223043648002204, 0.06785495541407727, 0.071729604533175, 0.07158275577239692, 0.13845481822500005, 0.319063090137206, 0.14897704735631123, 0.07960164657561108, 0.14120598934823647, 0.17143817647593096, 0.16906247270526364, 0.18082140188198537, 0.08281343907583505, 0.09668453538324684, 0.1366187448729761, 0.1626269836560823, 0.12912951002363116, 0.11061863260692917, 0.11902675760211423, 0.11849837814224884, 0.14078041218454018, 0.19613472861237824, 0.17844056244939566, 0.0862053433957044, 0.17918566387379542, 0.13831121264956892, 0.11194328457349911, 0.18487670458853245, 0.11014476389391348, 0.17008598340908065, 0.11629938715486787, 0.10369129260652699, 0.13360069744521752, 0.1026542302861344, 0.25964778615161777, 0.08299936191178858, 0.11508766037877649, 0.11636731593171135, 0.19854856393067166, 0.15392421861179173, 0.15478589659323916, 0.09684889140771702, 0.17952047637663782, 0.10523030650801957, 0.15850432362640277, 0.1486259521334432, 0.10736873824498616, 0.1443468770594336, 0.1365454206825234, 0.13307815126609057, 0.1713929945253767, 0.1270863923127763, 0.15943220118060708, 0.10203567246207967, 0.21440575132146478, 0.15712520544184372, 0.24812705669319257, 0.20416142680915073, 0.12469139270251617, 0.17406773928087205, 0.08548560857889242, 0.11786707022110932, 5.133897867053747, 30.330605171620846, 59.36368636786938, 72.01843231916428, 65.21229073405266, 62.380298897624016, 55.5933652818203, 43.092309683561325, 40.544132217764854, 33.84494349360466, 41.630497723817825, 42.58727118372917, 35.21376684308052, 40.41586250066757, 46.074047684669495, 55.561842173337936, 52.20832072198391, 51.356098651885986, 46.58835008740425, 41.861160546541214, 40.26910677552223, 27.726867087185383, 18.54118298739195, 11.027788203209639, 4.681868422776461, 1.0573186771944165, 0.8352585334796458, 0.37715021695476025, 0.2398805195116438, 0.6381824647542089, 1.4823377458378673, 1.4259946066886187, 1.2553555006161332, 1.5792528516612947, 1.7560781445354223, 1.678299168124795, 0.8684457745403051, 0.9794740355573595, 1.0527636716142297, 0.7996708899736404, 0.2037013100925833, 0.2311995587660931, 0.4432436329079792, 0.9596560802310705, 2.3030452569946647, 6.616494236513972, 10.936824884265661, 18.87397103011608, 24.750376604497433, 34.408217668533325, 40.52955240011215, 40.71753591299057, 41.352276653051376, 39.52186167240143, 54.26111496984959, 55.02373404800892, 41.42749361693859, 35.32426871359348, 37.509580850601196, 72.57555842399597, 60.997575893998146, 50.20345330238342, 55.38976080715656, 60.040867030620575, 70.01861482858658, 62.26404033601284, 29.846811331808567, 2.486989824101329, 0.1801864945446141, 0.1701858319574967, 0.20383053284604102, 0.16243596968706697, 0.06049675044778269, 0.19852805096888915, 0.17522284761071205, 0.0846956814348232, 0.19888627080945298, 0.16237630101386458, 0.25680634018499404, 0.06072671603760682, 0.2231164276599884, 0.23111069400329143, 0.1842131800367497, 0.16012088453862816, 0.12914470920804888, 0.09061097691301256, 0.1493883307557553, 0.12990774092031643, 0.08941858308389783, 0.1132976076041814, 0.21849350072443485, 0.17347581713693216, 0.14195457886671647, 0.18326412158785388, 0.09729378667543642, 0.059252016653772444, 0.09234953206032515, 0.1525552530074492, 0.16834772512083873, 0.1631790227838792, 0.10582961302134208, 0.11784482805524021, 0.19765322213061154, 0.10703044506954029, 0.10266231227433309, 0.14880886184982955, 0.19856407481711358, 0.12260393908945844, 0.12701805535471067, 0.10632783159962855, 0.1230626754113473, 0.1908182498300448, 0.10746109852334484, 0.10412205738248304, 0.12454058829462156, 0.12673207616899163, 0.1865827536676079, 0.14218801399692893], [0.01988103787880391, 0.06559967252542265, 0.012321754493314074, 0.04478261944313999, 0.02806985823553987, 0.02938592355349101, 0.0332202592107933, 0.01844925503974082, 0.04020092623250093, 0.042209103630739264, 0.022111772377684247, 0.05730236131057609, 0.044530523009598255, 0.01935335047164699, 0.06242347342777066, 0.03844543898594566, 0.05851448142493609, 0.07575068681035191, 0.054911454644752666, 0.006857185244371067, 0.11400703398976475, 0.011664153207675554, 0.11282342718914151, 0.032617980396025814, 0.06796230707550421, 0.04638957696442958, 0.019900563784176484, 0.03418899199459702, 0.06521746647194959, 0.062003377024666406, 0.027226934325881302, 0.04950091606588103, 0.041435340463067405, 0.010609578057483304, 0.04758950359246228, 0.04673191113397479, 0.09068277227925137, 0.054187756759347394, 0.006910856436661561, 0.023557305357826408, 0.012727425400953507, 0.055045616390998475, 0.041854594528558664, 0.07087700301781297, 0.07143071197788231, 0.028162127600808162, 0.023507883888669312, 0.03400969653739594, 0.03386608725122642, 0.03356076769705396, 0.03175656216626521, 0.03257909185776953, 0.011056252624257468, 0.04521149174252059, 0.019050420632993337, 0.014994321045378456, 0.045598525466630235, 0.024786031026451383, 0.074557535990607, 0.07453916783560999, 3.3158165495842695, 14.879431575536728, 41.11095920205116, 61.3618129491806, 57.426060140132904, 57.93925680220127, 45.3072564303875, 43.36680315434933, 44.544261172413826, 38.06677535176277, 34.876705929636955, 35.43692506849766, 24.755137749016285, 25.718861036002636, 28.234571143984795, 29.335772953927517, 27.8451756387949, 41.11272230744362, 36.553240567445755, 35.15539437532425, 49.01076950132847, 39.829717352986336, 40.96308633685112, 40.06397098302841, 28.21968924254179, 22.6237029209733, 19.721595346927643, 13.740119710564613, 13.972879070788622, 12.07728523761034, 9.957544282078743, 8.373989704996347, 9.274816866964102, 9.437668528407812, 10.183881986886263, 11.097816545516253, 15.077892076224089, 15.639678630977869, 20.120600536465645, 19.807081259787083, 26.445767730474472, 35.776911824941635, 39.53481897711754, 39.52280402183533, 37.89927273988724, 33.09283845126629, 34.74680610001087, 29.835816621780396, 30.102471113204956, 37.403349950909615, 49.10715892910957, 46.33076190948486, 35.9494985640049, 15.997840762138367, 28.585535511374474, 37.11944058537483, 33.37466552853584, 38.06500844657421, 41.88576802611351, 47.33841463923454, 53.429157212376595, 43.07725489139557, 21.084046438336372, 2.3574041901156306, 0.0005064253400632879, 0.04882062268734444, 0.058331111576990224, 0.06255967979086563, 0.0676504046714399, 0.06326512826490216, 0.0873299791419413, 0.08017305575776845, 0.07014842180069536, 0.05701211848645471, 0.01965886855032295, 0.04464493991690688, 0.041225000968552195, 0.013400569114310201, 0.08996678530820645, 0.01103952925404883, 0.07317150841117837, 0.049023106548702344, 0.020170404968666844, 0.03934629123250488, 0.010053546175186057, 0.016784085310064256, 0.06977796394494362, 0.012152610688644927, 0.11530280899023637, 0.024777911930868868, 0.0008551564167191827, 0.03202940533810761, 0.052054828047403134, 0.07457317304215394, 0.008080293318926124, 0.10024847695603967, 0.04395297626615502, 0.039090242862585, 0.02047559835773427, 0.04698218559497036, 0.057168103085132316, 0.0491475201852154, 0.011363517533027334, 0.023152140965976287, 0.09676842775661498, 0.05618970753857866, 0.05125584299094044, 0.05164266891370062, 0.04196938250970561, 0.07661229057703167, 0.048603507384541444, 0.049981159827439114, 0.09466803108807653, 0.04441704120836221, 0.0447804263967555, 0.027439719196991064, 0.02784916949167382, 0.0553049970039865, 0.03793485993810464, 0.008873202041286277, 0.02296852064318955, 0.036675876908702776, 0.015302674128179206, 0.0023226179473567754, 0.06762566888937727, 0.04029185416584369, 0.007326670647671563, 0.03535499876306858, 0.03433676472923253, 0.026725138595793396, 0.1047816411301028, 0.04996359690267127, 0.04723120953713078, 0.08953645097790286, 0.0450611474661855, 0.011406548183003906, 0.03667437777039595, 0.049735315988073125, 0.03426469847909175, 0.04133051581447944, 0.0778766356233973, 0.03452848002780229, 0.02120344670402119, 0.023707094878773205, 0.0867671862943098, 0.018039034766843542, 0.04300952103221789, 0.05107730823510792, 0.03001972880156245, 0.032194091618293896, 0.06754314206773415, 0.015057966702443082, 0.022483553111669607, 0.010807263934111688, 0.045562468221760355, 0.07318584670429118, 0.008231697011069627, 0.03292753761343192, 0.004176142438154784, 0.06676370147033595, 0.02545244624343468, 0.055444364916183986, 0.01544700422527967, 0.03931171457224991, 0.06003656322718598, 0.023160835226008203, 0.062268639157991856, 0.014466783923126059, 0.019909931543224957, 0.02774313514237292, 0.03052699230465805, 0.015277875263564056, 0.02716568673349684, 0.09795982710784301, 0.10178527183597907, 0.46396377263590693, 9.034775197505951, 27.628106586635113, 54.30934578180313, 65.84390804171562, 59.90182489156723, 55.175030529499054, 40.58315232396126, 34.464891627430916, 34.7036100178957, 31.39356393367052, 25.382637977600098, 23.203888088464737, 23.186770007014275, 28.99389009922743, 31.049845777451992, 33.81358377635479, 43.54521878063679, 54.14922997355461, 58.49304288625717, 64.57006439566612, 57.6320318877697, 45.57505466043949, 45.54040811955929, 41.30696028470993, 30.132417306303978, 20.138222090899944, 15.591571312397718, 10.519859958440065, 5.375050501897931, 4.563557971268892, 3.489311677403748, 3.5034566558897495, 3.498356379568577, 3.44937012065202, 4.628857942298055, 6.339787859469652, 7.388445138931274, 12.365725859999657, 15.885428544133902, 16.711377874016762, 24.532412700355053, 39.58782233297825, 48.30228991806507, 55.214058235287666, 59.61185485124588, 60.634330585598946, 61.028145253658295, 54.826140850782394, 56.20195962488651, 47.26293168962002, 44.40558761358261, 35.55412217974663, 32.5825372338295, 22.37221911549568, 22.88170527666807, 28.717867210507393, 26.764097549021244, 44.54481214284897, 45.769585222005844, 44.317660331726074, 55.580073595047, 55.68369783461094, 34.73815396428108, 8.168198447674513, 0.06771865257178433, 0.055867348273750395, 0.08907185911084525, 0.04837336367927492, 0.08722575192223303, 0.035175076191080734, 0.04893247547443025, 0.03526614513248205, 0.013903932631365024, 0.07902700162958354, 0.02977700383780757, 0.04085954889887944, 0.037779647173010744, 0.016007750600692816, 0.03500058242934756, 0.030886418135196436, 0.007506830706915935, 0.06282603659201413, 0.01617662259377539, 0.027753241338359658, 0.02543288323067827, 0.07535424636444077, 0.016147317037393805, 0.060042834375053644, 0.06817266141297296, 0.049615314419497736, 0.02686367715796223, 0.08340008454979397, 0.040240761009044945, 0.0486689833633136, 0.03531128626491409, 0.02005937411013292, 0.04361883911769837, 0.04247991702868603, 0.012684318680840079, 0.008317347346746828, 0.02148683022824116, 0.07845141415600665, 0.012843104886997025, 0.026470010488992557, 0.005661481900460785, 0.05468509589263704, 0.03874857291521039, 0.06620801839744672, 0.07757671890431084, 0.03000361677550245, 0.02549519580497872, 0.07881329278461635, 0.09031631459947675, 0.041695622785482556, 0.03377520384674426, 0.0064237756396323675, 0.06226594516192563, 0.15390700078569353, 0.08333299439982511, 0.1078100637823809, 0.09273298492189497, 0.1270487654255703, 0.08998458943096921, 0.13691713276784867, 0.09359993215184659, 0.11831744996015914, 0.09136808628682047, 0.12963185494299978, 0.14541739539708942, 0.06651198724284768, 0.18941968737635761, 0.2067204113700427, 0.19846807059366256, 0.17304972046986222, 0.14489888650132343, 0.07904168873210438, 0.13511126482626423, 0.17437727423384786, 0.20076908462215215, 0.16980451648123562, 0.22091984865255654, 0.2535804914077744, 0.0712824976653792, 0.1025762379867956, 0.2173547790152952, 0.27417669247370213, 0.12605474767042324, 0.13622545113321394, 0.09090900857700035, 0.08905752081773244, 0.14844537276076153, 0.1412178043392487, 0.24346322257770225, 0.10203040321357548, 0.0994215314858593, 0.16766401415225118, 0.1259060064330697, 0.15211386809824035, 0.16020646900869906, 0.22461005923105404, 0.16306535544572398, 0.0863157155981753, 0.08156027077347971, 0.17601430357899517, 0.10501589262275957, 0.09587940163328312, 0.0865230271301698, 0.1689143548719585, 0.10109828057466075, 0.13349817716516554, 0.148775034758728, 0.11618588308920152, 0.11690684244967997, 0.208229212439619, 0.18486920889699832, 0.22931625513592735, 6.14406606182456, 24.769481979310513, 59.02680404484272, 80.60883656144142, 74.2445656657219, 74.22517910599709, 61.071956902742386, 56.614480689167976, 57.80971795320511, 49.374501183629036, 50.44443257153034, 45.42726919054985, 37.56208263337612, 35.81053242087364, 38.322292640805244, 37.44935028254986, 40.14266476035118, 50.58627136051655, 47.21110627055168, 48.529878705739975, 62.80926167964935, 53.57221953570843, 55.419904589653015, 54.57845114171505, 42.46282026171684, 34.185287430882454, 30.336819738149643, 20.747464299201965, 19.584358111023903, 17.741869278252125, 15.55197173729539, 12.325881198048592, 12.738350965082645, 14.147669691592455, 14.939632695168257, 16.75840985029936, 20.921130180358887, 23.294790610671043, 28.774886950850487, 29.32129193097353, 37.13419899344444, 48.7763524800539, 51.63306958973408, 51.96498937904835, 52.902425676584244, 44.860727190971375, 46.05838492512703, 40.729417875409126, 43.748808056116104, 44.66322138905525, 61.65969416499138, 55.78304350376129, 49.5309653878212, 26.442152224481106, 41.42524033784866, 50.35334385931492, 42.66208536922932, 55.090093687176704, 52.284259647130966, 62.05561012029648, 69.83155846595764, 64.09971803426743, 31.306326314806938, 5.601695040240884, 0.09380935880471952, 0.16107899718917906, 0.1877037825761363, 0.19429702253546566, 0.2034839053521864, 0.16921363334404305, 0.14618970395531505, 0.1478016932378523, 0.1251314565888606, 0.19787901313975453, 0.145839276665356, 0.11490783799672499, 0.26851591654121876, 0.07570980931632221, 0.13484397291904315, 0.1972131582442671, 0.13406027981545776, 0.15035343443742022, 0.11001117731211707, 0.12595144071383402, 0.13255348254460841, 0.1751059593516402, 0.10013587088906206, 0.14756664022570476, 0.2253901306539774, 0.1299211589503102, 0.08294322586152703, 0.14014120039064437, 0.11649411186226644, 0.12877520872280002, 0.11169493969646282, 0.15026427281554788, 0.10187801060965285, 0.09578477780451067, 0.08454946349957027, 0.1546236631111242, 0.18801921018166468, 0.1563822859316133, 0.1399749147822149, 0.10356929094996303, 0.15273920173058286, 0.14558624883648008, 0.10992437571985647, 0.12195194751257077, 0.13192660524509847, 0.12459010438760743, 0.1457809141720645, 0.25291552708949894, 0.20368609606521204, 0.14034772524610162, 0.15012923162430525, 0.13962701079435647], [0.030528535971825477, 0.06629657145822421, 0.031278748938348144, 0.024022296129260212, 0.041188747054548, 0.04942930623656139, 0.042302584552089684, 0.029253337015688885, 0.010826042125700042, 0.04442812889465131, 0.05833856645040214, 0.06675245793303475, 0.05120355497638229, 0.023914148514450062, 0.02569698390288977, 0.04335524310590699, 0.029675390833290294, 0.012946987008035649, 0.05435917431896087, 0.011343244841555133, 0.023135821138566826, 0.03878412549966015, 0.07156035775551572, 0.02872945126000559, 0.031918268723529764, 0.040473305562045425, 0.03989294978964608, 0.009282172723033, 0.022581588964385446, 0.006724834802298574, 0.07768884999677539, 0.02736291990004247, 0.014216380513971671, 0.02287632549268892, 0.04674743686337024, 0.01920043465361232, 0.023013157115201466, 0.045480382977984846, 0.0865651885396801, 0.02772470204945421, 0.06885737428092398, 0.04323048808146268, 0.040713516500545666, 0.004828916053156718, 0.04068509595526848, 0.038495058979606256, 0.014033367824595189, 0.020671885285992175, 0.03370180173078552, 0.04957531265972648, 0.020468273360165767, 0.05246810782409739, 0.02535182771680411, 0.006791919850002159, 0.03820748046564404, 0.02326340374565916, 0.029922869252914097, 0.05072614992968738, 0.023040425476210658, 0.03430692297115456, 0.05059563212853391, 0.07562474434962496, 0.8947851893026382, 8.401515427976847, 22.712449058890343, 33.13288450241089, 52.030931040644646, 56.208795458078384, 60.10232873260975, 58.869530484080315, 61.93376585841179, 55.95873087644577, 52.45001435279846, 43.810319155454636, 39.61778752505779, 43.242272436618805, 42.55015857517719, 40.61979375779629, 39.84140932559967, 18.047684468328953, 43.3458548784256, 72.67559185624123, 32.477624863386154, 21.671139635145664, 22.99773585051298, 26.68352097272873, 26.22428711503744, 26.398253180086613, 25.678626894950867, 28.127855770289898, 30.956676676869392, 29.340247213840485, 29.630965813994408, 33.053620755672455, 37.7146178483963, 33.3543898165226, 30.897397957742214, 33.63414980471134, 22.11816854774952, 61.56741611659527, 63.88654947280884, 28.136323615908623, 30.481842756271362, 27.140942327678204, 31.4913896843791, 26.378393545746803, 35.710377395153046, 33.141285851597786, 34.36794362962246, 57.29106858372688, 59.851390197873116, 43.49491328001022, 31.562565565109253, 41.37378349900246, 43.45093443989754, 48.30892436206341, 50.13896316289902, 60.92672869563103, 50.898903384804726, 39.75441299378872, 16.84397365897894, 2.564063463360071, 0.14440553641179577, 0.016548761414014734, 0.061429184788721614, 0.015614145158906467, 0.03174388999468647, 0.04729566506284755, 0.01900990308058681, 0.060691386097460054, 0.047352903202408925, 0.04736183494969737, 0.030935128997953143, 0.07126899057766423, 0.032641506477375515, 0.033266257523791865, 0.045019308890914544, 0.03047338697797386, 0.007788736893417081, 0.05118488996231463, 0.01583573190146126, 0.0584162581799319, 0.05006708197470289, 0.06677113779005595, 0.04464775636733975, 0.002390967197243299, 0.046773515932727605, 0.019097201911790762, 0.03444583075179253, 0.05336102651199326, 0.04666133288992569, 0.02346427529118955, 0.02544973740441492, 0.016427121554443147, 0.04437594107002951, 0.040950432303361595, 0.004470681369639351, 0.05866430619789753, 0.03317175243864767, 0.05807224675663747, 0.028658043665927835, 0.019202785406378098, 0.04951787042955402, 0.14549441548297182, 0.10836428482434712, 0.10618089378112927, 0.014011046805535443, 0.06636042584432289, 0.037073085477459244, 0.03653709529316984, 0.02618136513774516, 0.01700538632576354, 0.09662751617725007, 0.025444891180086415, 0.02749932107690256, 0.040072059709928, 0.04707149935711641, 0.03653924009995535, 0.03885474827256985, 0.04149942491494585, 0.08746364735998213, 0.03723025009094272, 0.016528346786799375, 0.08742161953705363, 0.05190478805161547, 0.06664883927442133, 0.01903412863612175, 0.05074769076600205, 0.09979696173104458, 0.03950010133848991, 0.02379336398007581, 0.038348651796695776, 0.04103167520952411, 0.02281832479638979, 0.06506370831630193, 0.054907999947317876, 0.08290182886412367, 0.05221941784839146, 0.07181224267696962, 0.025480456752120517, 0.07869062319514342, 0.01588924445968587, 0.0405547117406968, 0.014250474778236821, 0.012660653446801007, 0.01968603301065741, 0.03946512391848955, 0.08201890319469385, 0.014169566766213393, 0.05609309104329441, 0.02460831448843237, 0.06284329894697294, 0.040488512167939916, 0.040094825089909136, 0.01919774807902286, 0.05337317175872158, 0.06798054164391942, 0.10628852745867334, 0.08332175828400068, 0.029710911876463797, 0.041973312181653455, 0.02927962203102652, 0.026870790643442888, 0.02436478800518671, 0.015058000099088531, 0.018365967516729143, 0.04211573032080196, 0.07734597777016461, 0.05179667568881996, 0.017601688996364828, 0.061345882422756404, 0.034141535361413844, 0.01659726447542198, 0.05999001943564508, 0.073864273581421, 0.06145109669887461, 0.12270965060452, 0.22160096210427582, 3.85184642393142, 19.91813600063324, 38.239901661872864, 50.97503609955311, 63.72989907860756, 62.33790457248688, 61.194545924663544, 57.18469329178333, 55.9948555380106, 49.94230851531029, 39.90879110991955, 31.23606998473406, 28.583639413118362, 31.99867196381092, 30.497915893793106, 32.88639932870865, 32.44988635182381, 17.063286490738392, 54.044496193528175, 67.26604253053665, 44.66519348323345, 44.089011400938034, 45.415714010596275, 51.27950616180897, 50.251991897821426, 49.052297472953796, 55.531451404094696, 52.89512626826763, 52.352560982108116, 49.84823316335678, 57.54313185811043, 56.840625554323196, 60.25075636804104, 59.17117349803448, 56.461823880672455, 54.209259152412415, 38.40432643890381, 60.54702267050743, 64.71305832266808, 41.82057872414589, 42.21369042992592, 36.66572593152523, 31.288735158741474, 24.016833566129208, 23.929768837988377, 22.118653021752834, 18.73238492757082, 37.32551112771034, 50.548041611909866, 41.076951026916504, 35.01012057065964, 35.869436860084534, 42.15946353971958, 46.092784479260445, 51.880865693092346, 57.79379680752754, 56.892830953001976, 51.172169521450996, 30.753731466829777, 7.376947905868292, 0.14839937444776297, 0.17384087957907468, 0.1525181159377098, 0.041001659046742134, 0.05414896098955069, 0.037626950288540684, 0.07671838800888509, 0.03834591698250733, 0.004282745921955211, 0.05383381540013943, 0.02516469518013764, 0.05447220341011416, 0.06399698977475055, 0.022553561757376883, 0.05777119455160573, 0.034810332872439176, 0.04822841481654905, 0.06458080024458468, 0.0218826509808423, 0.039480215491494164, 0.023547533128294162, 0.02960426154459128, 0.016403571353293955, 0.008800632058409974, 0.014630841233156389, 0.01693784161034273, 0.0973490766773466, 0.0031042794216773473, 0.05393838771851733, 0.05326482561940793, 0.01610433369933162, 0.08072316530160606, 0.0160433421478956, 0.022221009094209876, 0.011196813538845163, 0.05376310356950853, 0.007694413634453667, 0.040143881051335484, 0.04162103323324118, 0.031241396645782515, 0.11981113348156214, 0.08930639261961915, 0.07303099017008208, 0.03523451850924175, 0.03545536681485828, 0.04664145817514509, 0.025631014395912644, 0.04598938125127461, 0.010118629743374186, 0.05030648397223558, 0.04540508467471227, 0.02813306880852906, 0.07762259847368114, 0.02309599378349958, 0.15722695388831198, 0.13636237737955526, 0.06811651051975787, 0.08286866228445433, 0.1946126134134829, 0.1592595924739726, 0.14488319749943912, 0.0935785731417127, 0.10650565760442987, 0.21544263552641496, 0.1290685054846108, 0.10863484218134545, 0.18668454664293677, 0.13376119430176914, 0.1416620539384894, 0.19506360171362758, 0.14825587277300656, 0.1847623396315612, 0.10415408847620711, 0.10089638672070578, 0.15983870514901355, 0.15097936178790405, 0.15489981626160443, 0.09690106438938528, 0.15237942337989807, 0.1714736214489676, 0.1112434096285142, 0.14685806730994955, 0.09163544498733245, 0.10861886374186724, 0.17284105822909623, 0.118595235835528, 0.12522931618150324, 0.16584575234446675, 0.18965591298183426, 0.17468672012910247, 0.09956150053767487, 0.16034053056500852, 0.16932044323766604, 0.1447616337100044, 0.18632231920491904, 0.24710327881621197, 0.20925027405610308, 0.08723223087145016, 0.10869074074435048, 0.13839362072758377, 0.059874255530303344, 0.1861021833610721, 0.1272329071070999, 0.12636481696972623, 0.12991378200240433, 0.12929049669764936, 0.10894727893173695, 0.14620200876379386, 0.16044164076447487, 0.12484316190239042, 0.12002152492641471, 0.11183188078575768, 0.18924596544820815, 0.18964391987537965, 0.16507955908309668, 0.1958654774352908, 2.1433994360268116, 13.936039097607136, 33.67453783750534, 51.00677579641342, 71.06874167919159, 74.55152079463005, 79.58805173635483, 75.35425052046776, 79.3226207792759, 72.5373324751854, 66.45835787057877, 58.04354980587959, 52.28010267019272, 57.02823668718338, 51.48143112659454, 51.46909698843956, 50.36880902945995, 22.142211757600307, 55.220445692539215, 78.95634323358536, 44.23890195786953, 33.54923576116562, 36.13846242427826, 41.65233515202999, 38.996558859944344, 41.87826722860336, 42.7923271805048, 44.19323220849037, 46.22185215353966, 43.13450641930103, 45.694733038544655, 46.05375297367573, 54.511544331908226, 47.85204827785492, 44.789519011974335, 47.680867463350296, 35.22431127727032, 77.96424686908722, 81.12661197781563, 38.90037082135677, 40.58458484709263, 35.75075022876263, 39.05975706875324, 34.63108330965042, 44.63575266301632, 45.81385664641857, 43.40025655925274, 73.43528509140015, 68.2921014726162, 55.31161420047283, 46.0064797103405, 57.56968103349209, 57.70402282476425, 65.87160095572472, 68.07014018297195, 78.74000564217567, 70.57280749082565, 54.477912336587906, 27.00576838105917, 4.358850605785847, 0.24002593592740595, 0.2191018540179357, 0.24848196655511856, 0.10966030473355204, 0.20968707249267027, 0.12911180238006637, 0.13691487663891166, 0.1301557815168053, 0.09833399570197798, 0.09356136273709126, 0.1769563858397305, 0.16755146003561094, 0.13983130920678377, 0.13697306101676077, 0.16194165480555966, 0.10940834559733048, 0.0790732671157457, 0.1050391663738992, 0.0580853864812525, 0.11948870742344297, 0.08586470503360033, 0.17858082836028188, 0.09727173004648648, 0.08406621403992176, 0.18697175779379904, 0.0866640722961165, 0.22097142791608348, 0.18530391447711736, 0.16251046647084877, 0.17868360097054392, 0.07392914470983669, 0.2073039027163759, 0.10569323596428148, 0.11553789910976775, 0.10868007608223706, 0.16881312592886388, 0.11240506370086223, 0.1009612504276447, 0.12535929592559114, 0.1882112631574273, 0.14656331593869254, 0.20020368683617562, 0.2906884392723441, 0.18159287923481315, 0.12223811223520897, 0.10710709408158436, 0.16168224450666457, 0.10316321000573225, 0.08056360355112702, 0.13686708232853562, 0.21601760701742023, 0.09363692079205066, 0.1462873409036547, 0.10718163539422676], [0.05564556486206129, 0.16444604698335752, 0.028530490744742565, 0.1010182176833041, 0.034098858159268275, 0.006441092264140025, 0.019921208477171604, 0.04026680297101848, 0.03223199681087863, 0.033536087576067075, 0.02519830704841297, 0.0777725494117476, 0.11432166749727912, 0.04581112851155922, 0.06328164105070755, 0.02869907701096963, 0.05830131434777286, 0.02050045473879436, 0.027593757513386663, 0.035538134834496304, 0.013064795530226547, 0.03755236444703769, 0.02880493881093571, 0.021503636162378825, 0.04564384100376628, 0.02965118568681646, 0.02182593976613134, 0.06713672715704888, 0.02744548568443861, 0.031181468220893294, 0.03873490997648332, 0.036891827039653435, 0.03025042540684808, 0.052587441459763795, 0.02792799485177966, 0.04778686292411294, 0.03496959776384756, 0.09522166583337821, 0.05504698936420027, 0.06371933006448671, 0.0831125394324772, 0.06643097440246493, 0.11607119900872931, 0.0394397944182856, 0.012293751406105002, 0.01426550048563513, 0.05102969575091265, 0.03405299714358989, 0.023297872794501018, 0.03213259355106857, 0.02828071352269035, 0.018819766701199114, 0.03624783581472002, 0.03548349421180319, 0.08367344722501002, 0.03762621185160242, 0.04447646868356969, 0.05233295902144164, 0.03895991430908907, 0.038535372441401705, 0.03164994894177653, 0.08108808673569001, 0.13679614785360172, 0.1358594832709059, 0.20193434553220868, 0.675823719939217, 3.4489184198901057, 10.485115572810173, 21.43133830279112, 29.138913117349148, 41.780870854854584, 50.05847208201885, 53.37193988263607, 55.463381856679916, 55.227870494127274, 59.454554691910744, 58.06339234113693, 54.031831473112106, 62.39975765347481, 47.360438257455826, 39.289488941431046, 60.95436841249466, 39.31229151785374, 39.88505758345127, 54.53858748078346, 36.967395544052124, 35.60359172523022, 28.82575862109661, 24.163182713091373, 25.214648991823196, 26.477410532534122, 34.35289263725281, 24.736815132200718, 29.075633212924004, 24.926333762705326, 32.4395889043808, 28.092274479568005, 38.44514384865761, 23.282253183424473, 79.42220583558083, 72.34488040208817, 34.41268242895603, 47.45879977941513, 55.118238776922226, 61.65636174380779, 65.64355239272118, 60.71772091090679, 61.426223292946815, 63.32744747400284, 66.25130698084831, 43.12203548848629, 45.92099189758301, 53.06018941104412, 44.5507550239563, 41.035970225930214, 38.245939537882805, 28.47616598010063, 18.35286509245634, 8.68980310857296, 1.4236276899464428, 0.05330426705768332, 0.03269841807195917, 0.0810115564672742, 0.09197604624205269, 0.02380385238211602, 0.054616283960058354, 0.044262633673497476, 0.04173972862190567, 0.047458388362429105, 0.02611091305880109, 0.05399025641963817, 0.05231998256931547, 0.012474738960008835, 0.049835936370072886, 0.040116855743690394, 0.052825678285444155, 0.033311127772321925, 0.034727935926639475, 0.049979541945504025, 0.05775416226242669, 0.06947347559616901, 0.03932305458874907, 0.05188535120396409, 0.06510705716209486, 0.04829685938602779, 0.03015852711541811, 0.05398238223278895, 0.04311066462832969, 0.015661102697777096, 0.0659992967848666, 0.07998263550689444, 0.021535756313824095, 0.0005650319303640572, 0.036272801662562415, 0.038010265852790326, 0.04332464435719885, 0.04495887209486682, 0.03651243001513649, 0.020730709766212385, 0.03827662265393883, 0.07273266164702363, 0.070117162540555, 0.03442124339926522, 0.07269398833159357, 0.027182375779375434, 0.08355837722774595, 0.04718157841125503, 0.04295588601962663, 0.03764572291402146, 0.0342367120902054, 0.0561187879065983, 0.015375530765595613, 0.08528005593689159, 0.032402638826170005, 0.047132407416938804, 0.010425736945762765, 0.022192573705979157, 0.024617112649139017, 0.057711904373718426, 0.025492696622677613, 0.06640784908086061, 0.04956215438141953, 0.08302390473545529, 0.0562198201805586, 0.03519371151924133, 0.021331005191314034, 0.056972565726027824, 0.049025941552827135, 0.0759295815078076, 0.046355731319636106, 0.029672546552319545, 0.04754946472530719, 0.047801776381675154, 0.07917635142803192, 0.01356778055196628, 0.0079624903628428, 0.028645501370192505, 0.10520772295421921, 0.10358881685533561, 0.021150388711248524, 0.003974472156187403, 0.04178946735919453, 0.0019143744543725916, 0.0645120551052969, 0.043532293566386215, 0.043318328680470586, 0.051202649556216784, 0.06434133145376109, 0.043756206941907294, 0.06966495711822063, 0.04649738875741605, 0.027532248313946184, 0.04777530026331078, 0.030318105564219877, 0.013551316933444468, 0.06448136729886755, 0.05110212936415337, 0.05234012445725966, 0.018852413777494803, 0.012585259592015063, 0.04687832573836204, 0.03183424276357982, 0.08610807752120309, 0.10555929315160029, 0.04254666950146202, 0.043301032928866334, 0.01040707842548727, 0.015588938113069162, 0.008496249465679284, 0.03355250017193612, 0.0699088787951041, 0.039021382690407336, 0.03761987762118224, 0.0467160403059097, 0.05341373755072709, 0.09418313406058587, 0.0894789642188698, 0.06494757704786025, 0.13316404743818566, 0.09257950136088766, 0.5377223272807896, 2.902323924936354, 10.827329959720373, 22.92711663991213, 37.154353111982346, 47.917036190629005, 59.385550394654274, 61.29334822297096, 63.728147372603416, 64.25692319869995, 60.47680243849754, 58.06822948157787, 51.36469379067421, 45.76442509889603, 51.58735044300556, 23.195834420621395, 36.839395612478256, 69.76485684514046, 30.91516200453043, 20.95172043889761, 29.461246021091938, 26.94098375737667, 24.632653221488, 21.246520020067692, 22.500735819339752, 28.620096556842327, 28.388060107827187, 32.35802248120308, 23.347142301499844, 29.874359853565693, 30.365301109850407, 27.451811246573925, 23.395192623138428, 29.297277219593525, 18.066466860473156, 80.78798934817314, 73.84944006800652, 23.679981641471386, 28.58941700309515, 31.340896859765053, 37.874900847673416, 35.582768842577934, 43.90850208699703, 47.61044964194298, 54.703954607248306, 68.1681065261364, 58.36759641766548, 52.071706652641296, 56.19751386344433, 55.255654603242874, 53.97557929158211, 50.107789635658264, 42.60734170675278, 31.560593470931053, 18.002527691423893, 4.968145061284304, 0.02126161994965514, 0.12161352817201987, 0.07228061949717812, 0.07309169042855501, 0.0667084263113793, 0.06532317798701115, 0.020903316617477685, 0.04226736222335603, 0.038413419024436735, 0.06117707351222634, 0.005316176820997498, 0.026291241956641898, 0.04476351285120472, 0.06324934278381988, 0.06383718311553821, 0.0744359647796955, 0.02388725864875596, 0.05422389935120009, 0.05124864044773858, 0.03845815939712338, 0.05878253774426412, 0.008907623778213747, 0.04835144063690677, 0.08723499166080728, 0.04118052405829076, 0.05013416470319498, 0.06622546628932469, 0.005355658149710507, 0.029807893879478797, 0.028155450127087533, 0.08644176938105375, 0.05278125703625847, 0.0169878883389174, 0.06886923380079679, 0.05970897924271412, 0.04081073042470962, 0.05409788638644386, 0.03357972214871552, 0.006664108104814659, 0.0684539279609453, 0.08709113375516608, 0.054615148474113084, 0.07353672670433298, 0.05614737172436435, 0.05641987721901387, 0.04573841659293976, 0.07827539157005958, 0.07586264720885083, 0.07977409943123348, 0.036498989720712416, 0.03558986252755858, 0.02114051258104155, 0.04620710140443407, 0.04773578832100611, 0.046297201843117364, 0.04213435451674741, 0.20720740867545828, 0.2166177224717103, 0.16617547371424735, 0.1732462560175918, 0.12444320367649198, 0.14748752728337422, 0.2853327157208696, 0.17628413363127038, 0.14414412231417373, 0.08139919504174031, 0.11012753864633851, 0.15076786454301327, 0.22798218531534076, 0.14899319648975506, 0.08262102244771086, 0.1090806354477536, 0.1581529909162782, 0.13302078325068578, 0.1329022622667253, 0.15373664820799604, 0.0773661641869694, 0.1742951333289966, 0.12182366728666238, 0.12507401435868815, 0.11287526620435528, 0.14806171209784225, 0.09660291398176923, 0.18034448294201866, 0.16286369907902554, 0.07276677075424232, 0.1296209602151066, 0.15153049549553543, 0.1746511267265305, 0.12051144629367627, 0.11561054052435793, 0.2233644385705702, 0.14628750417614356, 0.1695888483664021, 0.12516492744907737, 0.17048899928340688, 0.19795961037743837, 0.13851521420292556, 0.14985267771407962, 0.12844447803217918, 0.1657616818556562, 0.13946096267318353, 0.27059027866926044, 0.133241037838161, 0.16889409424038604, 0.1471341314027086, 0.19162585493177176, 0.0767527791322209, 0.12825056968722492, 0.31481922254897654, 0.14519832824589685, 0.19991475390270352, 0.07713134866207838, 0.1303169463062659, 0.24422949005383998, 0.17705902486341074, 0.22839302342617884, 0.26186888571828604, 0.22427817079005763, 0.2331260108621791, 0.3655207925476134, 1.381155587732792, 6.563567826524377, 17.089904062449932, 32.63900600373745, 46.76302291452885, 59.77416694164276, 70.15389516949654, 72.73286238312721, 78.06222841143608, 75.80692023038864, 78.36412221193314, 74.8792152106762, 67.19324603676796, 82.40375384688377, 53.821600154042244, 53.12678083777428, 69.48944762349129, 50.588498041033745, 56.99335835874081, 66.42665237188339, 52.806176841259, 49.63740527629852, 39.68233086168766, 33.61920900642872, 35.51714636385441, 37.19542130827904, 46.350665241479874, 32.03350469470024, 40.95909655094147, 37.05097205936909, 41.53021350502968, 37.56033092737198, 51.44761674106121, 36.5942669659853, 90.08546724915504, 80.13704627752304, 47.744297459721565, 57.034183368086815, 70.72808235883713, 73.23130443692207, 80.15779316425323, 74.23734605312347, 78.35365757346153, 80.42371809482574, 85.70244044065475, 66.46689221262932, 68.47050189971924, 76.78778439760208, 66.51638075709343, 64.41309481859207, 53.29036965966225, 40.86776465177536, 26.13749597221613, 12.044846378266811, 2.564888494089246, 0.14139995706500486, 0.15301180741516873, 0.2010363616864197, 0.24910445034038275, 0.22304420184809715, 0.23666302731726319, 0.07401170863886364, 0.14501096564345062, 0.122846999875037, 0.09361974007333629, 0.08909978612791747, 0.16090643301140517, 0.11136688073747791, 0.26174981554504484, 0.22123435599496588, 0.18210623762570322, 0.06717217213008553, 0.15334357711253688, 0.13547564449254423, 0.1306115195620805, 0.16443457338027656, 0.10628668693243526, 0.10806078353198245, 0.23582747293403372, 0.09115592853049748, 0.10391788513516076, 0.16378059284761548, 0.09439456451218575, 0.11136301414808258, 0.10765660990728065, 0.23443320009391755, 0.13225902803242207, 0.07544069914729334, 0.10159844357986003, 0.11658002287731506, 0.1771810933132656, 0.16305861674482003, 0.1886029093293473, 0.07018100208370015, 0.1819905813317746, 0.11950459680519998, 0.13400804746197537, 0.14129440882243216, 0.19004853878868744, 0.1167197767063044, 0.14396668964764103, 0.1218639881699346, 0.1706658085458912, 0.13208509830292314, 0.10855438595172018, 0.10154204035643488, 0.060722496928065084, 0.149852855829522, 0.112665119668236, 0.2502761234063655, 0.09692266830825247], [0.02182446845836239, 0.03257455362472683, 0.02728149887843756, 0.02834210954461014, 0.030434927030000836, 0.04532799779553898, 0.039583808174938895, 0.053178168745944276, 0.022800312872277573, 0.016880416078493, 0.001965059082067455, 0.07761473170830868, 0.03865469123411458, 0.0504247748904163, 0.024235700693679973, 0.024671829341968987, 0.034774101222865283, 0.05243881525530014, 0.029163334911572747, 0.04498874724959023, 0.03705951530719176, 0.02240725476440275, 0.02249114342703251, 0.019592247808759566, 0.06041718108463101, 0.04093126633961219, 0.00782242854256765, 0.06548991630552337, 0.0773179839598015, 0.026260348204232287, 0.04210885803331621, 0.09518463266431354, 0.033857671296573244, 0.07683201823965646, 0.015566358270007186, 0.048438279336551204, 0.02863972189516062, 0.040502223346265964, 0.08569565863581374, 0.06207687561982311, 0.03982953327067662, 0.037006481434218585, 0.06021148001309484, 0.03691567966598086, 0.03384158524568193, 0.038509196892846376, 0.05443249850941356, 0.019387036554689985, 0.021052991105534602, 0.008574694475100841, 0.14204402250470594, 0.022750668758817483, 0.05967407603748143, 0.007041743456284166, 0.04810296588402707, 0.03592948785808403, 0.08807997131953016, 0.1014221686637029, 0.021067967645649333, 0.03378539353434462, 0.0742932349385228, 0.027500849901116453, 0.05460367116029374, 0.0404923008318292, 0.044424050793168135, 0.022544221828866284, 0.052001430522068404, 0.10139050864381716, 0.10613324790028855, 0.4363564430968836, 1.0961288446560502, 3.394576348364353, 9.83688460662961, 7.4287134781479836, 13.211832158267498, 33.327187076210976, 44.105399921536446, 53.12380939722061, 53.58120605349541, 66.1159810423851, 71.42352104187012, 55.9902273863554, 60.95674708485603, 63.26058626174927, 57.81634479761124, 62.838470712304115, 59.49648164212704, 56.35155759751797, 62.0830674469471, 63.93701836466789, 65.2949970960617, 62.198220267891884, 64.6531431376934, 55.76887786388397, 61.51388838887215, 62.804272547364235, 64.12552624940872, 59.29195001721382, 56.66877597570419, 53.83769989013672, 53.000544011592865, 64.58533197641373, 64.49357450008392, 62.67941124737263, 64.76645305752754, 53.711485862731934, 50.134802386164665, 41.41615502536297, 33.66083577275276, 28.52454498410225, 20.76587051153183, 19.439823366701603, 16.05552736669779, 8.031785767525434, 4.394366824999452, 1.1637557158246636, 0.10211393935605884, 0.03583853023883421, 0.1256162126082927, 0.004523874804363004, 0.05567623411479872, 0.012701503110292833, 0.013369499101827387, 0.010181480374740204, 0.06079465223592706, 0.03105630872596521, 0.05670174119586591, 0.04968053435732145, 0.08176961579010822, 0.013687834070879035, 0.06036538659827784, 0.043765353912021965, 0.08324323163833469, 0.025605215487303212, 0.016365539995604195, 0.047445192976738326, 0.04554803716018796, 0.04199782903015148, 0.026713902479968965, 0.03158735249598976, 0.01797685577912489, 0.04480445713852532, 0.032962392579065636, 0.02807060780469328, 0.07178218569606543, 0.05371229242882691, 0.059348432769184, 0.07332182300160639, 0.07763036133837886, 0.04680970676417928, 0.04365936038084328, 0.030678904367960058, 0.038187542668310925, 0.05078417103504762, 0.038783858326496556, 0.04704655577370431, 0.058511338429525495, 0.07841574653866701, 0.026612868350639474, 0.013203478811192326, 0.020778745274583343, 0.03289561042038258, 0.019083401675743517, 0.043057563962065615, 0.018749234841379803, 0.053222693895804696, 0.07179187072324567, 0.09880017576506361, 0.021039374551037326, 0.04305796843254939, 0.04589546617353335, 0.007778986000630539, 0.018754979064397048, 0.04273141974408645, 0.06827100340160541, 0.03040041345229838, 0.08125691791065037, 0.04813075560377911, 0.045813889300916344, 0.03138410051178653, 0.002207205402555701, 0.05981763708405197, 0.04912629105092492, 0.010778047435451299, 0.05235756121692248, 0.01466278605221305, 0.05612639863102231, 0.04810325161088258, 0.01073811896276311, 0.07163366710301489, 0.050079093634849414, 0.057272337726317346, 0.03150832490064204, 0.034141798823839054, 0.0803164164244663, 0.015465484630112769, 0.02768553891655756, 0.06579968132427894, 0.0290906860755058, 0.016866307851159945, 0.04225377721013501, 0.027816181027446873, 0.08578106499044225, 0.03394267689145636, 0.04387465371110011, 0.006036202930772561, 0.04652461444493383, 0.05229191083344631, 0.06147716463601682, 0.05688937468221411, 0.04600217958795838, 0.038263189780991524, 0.01929064641444711, 0.08889578457456082, 0.04436090515810065, 0.05165277325431816, 0.060029008163837716, 0.0774255434225779, 0.007830791619198862, 0.04153891459282022, 0.02891459113016026, 0.04712425121397246, 0.03689687364385463, 0.02126215800672071, 0.03114250546786934, 0.026687155477702618, 0.051575062971096486, 0.018584695135359652, 0.055067420689738356, 0.06357898251735605, 0.05128502794832457, 0.029713481562794186, 0.07854329203837551, 0.057747731552808546, 0.022034537068975624, 0.04960765174473636, 0.03659725007310044, 0.0574656486423919, 0.05714695929782465, 0.01662564234720776, 0.023469923035008833, 0.11839148661238141, 0.1463865808909759, 0.36473046464379877, 1.1485960730351508, 3.193631493486464, 7.035162420943379, 12.808251064270735, 19.995705038309097, 20.708011016249657, 28.757810667157173, 48.336199298501015, 58.549127876758575, 69.4235211610794, 66.4542692899704, 69.72418382763863, 62.509294375777245, 56.916746869683266, 57.80531778931618, 57.10617430508137, 54.006612226367, 50.38490116596222, 49.425874426960945, 41.625197008252144, 38.290051370859146, 41.386626809835434, 42.06036865711212, 43.74147064983845, 37.466377168893814, 35.040294751524925, 38.94297793507576, 44.68974016606808, 45.073667764663696, 52.37648829817772, 54.101006761193275, 64.07373502850533, 66.18353381752968, 62.03526981174946, 67.76470497250557, 69.53500717878342, 74.79276984930038, 68.94121304154396, 63.73591795563698, 58.01282085478306, 51.976168379187584, 47.03706040978432, 33.27303618192673, 33.56530509889126, 28.455436192452908, 15.677675642073154, 10.111628863960505, 4.4510602578520775, 0.7903681579045951, 0.04985003346519079, 0.05870830071216915, 0.1089923272957094, 0.0411281506967498, 0.030210113800421823, 0.05435938583104871, 0.05524631167645566, 0.0913088109518867, 0.0584577998961322, 0.04228056131978519, 0.05961590650258586, 0.0519037638878217, 0.019718780276889447, 0.010222286437056027, 0.027761675846704748, 0.09881239893729798, 0.030311236987472512, 0.016684322108631022, 0.03168778734107036, 0.047539623847114854, 0.0061815534809284145, 0.01297856446399237, 0.00850953854751424, 0.050447937319404446, 0.05146275376318954, 0.037251969042699784, 0.01483348743931856, 0.11586859269300476, 0.043220509905950166, 0.035899278736906126, 0.07451964935171418, 0.02704804890527157, 0.02552609883423429, 0.035296513815410435, 0.026237382444378454, 0.06551838509039953, 0.029433367199089844, 0.006413790970327682, 0.05169621857930906, 0.042902503337245435, 0.11089853360317647, 0.08162735350197181, 0.0410098115389701, 0.0411540219647577, 0.045770076612825505, 0.11071324159274809, 0.034043557025142945, 0.03190564479155, 0.07455254875821993, 0.07298603828530759, 0.09433983854250982, 0.07527691457653418, 0.05424410061095841, 0.07331446089665405, 0.049293511765426956, 0.04326952875999268, 0.039864069112809375, 0.027368276350898668, 0.052356306987348944, 0.12240943702636287, 0.14802824123762548, 0.11376322363503277, 0.2743545110570267, 0.16035739216022193, 0.12385543755954131, 0.16937899868935347, 0.13742707727942616, 0.09995624888688326, 0.10121907253051177, 0.11569930880796164, 0.1423599399277009, 0.05519842088688165, 0.20461826323298737, 0.130504249536898, 0.15094264032086357, 0.12529426894616336, 0.12556378729641438, 0.14208026899723336, 0.11674063847749494, 0.0734008320432622, 0.16653805738314986, 0.10348904994316399, 0.12244272977113724, 0.13811130775138736, 0.10008988741901703, 0.1925913742161356, 0.12967200513230637, 0.10514682231587358, 0.14292872190708295, 0.17184456170070916, 0.1668897908530198, 0.142743288888596, 0.12462228391086683, 0.16716257465304807, 0.18642972281668335, 0.13201135850977153, 0.1620044998708181, 0.14121602318482473, 0.13412156637059525, 0.27897123363800347, 0.14806767896516249, 0.1762171770678833, 0.11906265528523363, 0.08009911558474414, 0.1341504359152168, 0.12282525494811125, 0.1042125845560804, 0.1078480394789949, 0.07716791427810676, 0.24458586936816573, 0.15519548789598048, 0.20042223448399454, 0.11779167543863878, 0.1316019453224726, 0.12965143279870972, 0.2658796001924202, 0.2920223755063489, 0.15291871241061017, 0.10733623217674904, 0.20477783982641995, 0.11397126247175038, 0.1899946588673629, 0.17970519693335518, 0.1255471631884575, 0.09138096254901029, 0.09496419253991917, 0.28383538825437427, 0.44616819941438735, 1.3987628929316998, 3.741215360350907, 7.265173578634858, 13.399322647601366, 15.030740406364202, 24.390703104436398, 45.306834653019905, 62.25188098847866, 76.39080449938774, 78.00395473837852, 91.59348472952843, 86.53003603219986, 75.91627076268196, 76.76221936941147, 80.21669000387192, 75.4553934931755, 76.66087880730629, 78.09720173478127, 72.09958076477051, 73.49616542458534, 81.61480978131294, 79.84314724802971, 76.93914547562599, 78.79802092909813, 69.11259904503822, 76.34244829416275, 78.25983300805092, 80.0530631840229, 77.09544628858566, 72.10582002997398, 70.36359071731567, 71.88016533851624, 82.94665351510048, 88.55174034833908, 86.13735750317574, 87.27117106318474, 75.18040984869003, 69.32067587971687, 59.38409507274628, 52.79519163072109, 45.001866817474365, 34.45513375103474, 30.01574456691742, 22.00403407216072, 11.539012771099806, 6.521095130592585, 1.9526274665258825, 0.2924268163042143, 0.12942942674271762, 0.2008873235899955, 0.172498200845439, 0.1018089018180035, 0.08786899357801303, 0.12452727416530252, 0.14655311882961541, 0.16403841495048255, 0.1921090524410829, 0.17167894402518868, 0.12465237057767808, 0.1920643009361811, 0.1393787920824252, 0.1369024976156652, 0.20570291206240654, 0.12223256839206442, 0.09298676231992431, 0.09392660329467617, 0.1312619971577078, 0.17243528156541288, 0.142877142643556, 0.1678411796456203, 0.08136445510899648, 0.11225429640035145, 0.16315941524226218, 0.12275268032681197, 0.0566283093940001, 0.26299692050088197, 0.0839967341744341, 0.23620494408532977, 0.28515706420876086, 0.1333955826703459, 0.09315212024375796, 0.14701558073284104, 0.2676321077160537, 0.23080794228008017, 0.10238173592370003, 0.1112766949518118, 0.19564872578484938, 0.2210327738430351, 0.15432064421474934, 0.1507529176888056, 0.13633209775434807, 0.16744275024393573, 0.12196906143799424, 0.17159626877401024, 0.13802711851894855, 0.14644552225945517, 0.15520868328167126, 0.25952761759981513, 0.16734264936530963, 0.17670420405920595, 0.22731132834451273, 0.21621908526867628, 0.13738241483224556, 0.11961949610849842, 0.17462209390942007, 0.32964712532702833, 0.16092661942820996], [0.018482299165043514, 0.07347892082179897, 0.025770629072212614, 0.027494998066686094, 0.03288400694145821, 0.06663564388873056, 0.021996370269334875, 0.018303200376976747, 0.034796447289409116, 0.06356272948323749, 0.04325849673477933, 0.022550819521711674, 0.03605083271395415, 0.007115832522686105, 0.019676281190186273, 0.029802439094055444, 0.060503459462779574, 0.03179381797963288, 0.033437096208217554, 0.022572816778847482, 0.027133557305205613, 0.03479103703284636, 0.011736342839867575, 0.040272858896059915, 0.07462529407348484, 0.029203581580077298, 0.07691520557273179, 0.030848405331198592, 0.051264184730825946, 0.00908441077626776, 0.04365649198007304, 0.04440540804353077, 0.043563025901676156, 0.07435392777551897, 0.038133788912091404, 0.058651277795434, 0.03557245545380283, 0.055191348219523206, 0.04579283457132988, 0.010941924774670042, 0.03773859527427703, 0.007469277106793015, 0.07354860106715932, 0.009011236870719586, 0.05913502078328747, 0.06297549771261401, 0.03979470799094997, 0.011477465959615074, 0.06311640187050216, 0.011101550535386195, 0.031906082658679225, 0.0590182030282449, 0.047413540378329344, 0.006839765183030977, 0.041791675248532556, 0.07030427281279117, 0.021316028651199304, 0.030590948736062273, 0.024007590473047458, 0.052368530159583315, 0.07322500983718783, 0.02450914129440207, 0.042122220402234234, 0.045772863377351314, 0.03611185951740481, 0.01992207493458409, 0.011896681990037905, 0.0473259966383921, 0.20521774044027552, 0.046719580350327305, 0.0406862871022895, 0.043310179898981005, 0.10093932738527656, 0.057811916194623336, 0.002065510857391928, 0.2670266933273524, 1.5788205061107874, 1.2021901784464717, 7.4324676766991615, 18.512853607535362, 39.37922112643719, 61.02728649973869, 60.74882984161377, 60.0174792855978, 63.29580657184124, 59.45379093289375, 58.64225707948208, 63.798454999923706, 61.33377805352211, 61.73925429582596, 62.371927946805954, 61.38726398348808, 63.59272263944149, 61.74948714673519, 54.43169541656971, 51.72860026359558, 52.072158828377724, 50.63801698386669, 48.65388885140419, 47.295522540807724, 41.26398839056492, 37.3225586861372, 22.384080179035664, 15.362410359084606, 11.574579812586308, 6.300449995324016, 3.1104739056900144, 2.1839765086770058, 0.7611710589844733, 0.2794240030925721, 0.08403252795687877, 0.047608617605874315, 0.10976663223118521, 0.08875677289324813, 0.12358958541881293, 0.06274310901062563, 0.0501324132346781, 0.036372160393511876, 0.058309685773565434, 0.02725635677052196, 0.04797275236342102, 0.04218080925056711, 0.04754097455588635, 0.039663540810579434, 0.02448420513246674, 0.07293290051165968, 0.02934898129751673, 0.03306082362541929, 0.12068084892234765, 0.02073584542813478, 0.06569353936356492, 0.002555696614763292, 0.017368415283272043, 0.05278458556858823, 0.00608505480158783, 0.03536401585733984, 0.07055015375954099, 0.028862702019978315, 0.028660513162321877, 0.023391789727611467, 0.018719170438998844, 0.0240127817960456, 0.04579124266456347, 0.03252349757531192, 0.06257450790144503, 0.11807811475591734, 0.060224185581319034, 0.07193595127318986, 0.0958118587732315, 0.0760296823864337, 0.0196567107559531, 0.04038583232613746, 0.07820738857844844, 0.060479844323708676, 0.05026201077271253, 0.033162620311486535, 0.020425623988558073, 0.004174899340796401, 0.0217807114313473, 0.02777470239379909, 0.015516010971623473, 0.026331449662393425, 0.014180710113578243, 0.02425274968118174, 0.042189882005914114, 0.01235791007275111, 0.050933339007315226, 0.03284425751189701, 0.042404514824738726, 0.05461671440571081, 0.04273779479262885, 0.03004819758643862, 0.01674387945968192, 0.06980293721426278, 0.031897648150334135, 0.01190327411677572, 0.008499362775182817, 0.057570098506403156, 0.018400948647467885, 0.100274652504595, 0.032478734938194975, 0.00731592388547142, 0.013640011002280517, 0.02277534887980437, 0.014634432300226763, 0.057940111073548906, 0.030455005835392512, 0.06797504232963547, 0.09499101375695318, 0.060906464204890653, 0.028985343778913375, 0.041266590924351476, 0.06922904183738865, 0.052105769063928165, 0.02429582949844189, 0.02821104626491433, 0.054243425256572664, 0.010199745556747075, 0.022817009339632932, 0.014693509110657033, 0.01455427107430296, 0.06339039537124336, 0.06714382951031439, 0.016442368978459854, 0.06672271265415475, 0.07608718398842029, 0.05672282932209782, 0.0359096428292105, 0.05849253611813765, 0.05735545826610178, 0.03562210884410888, 0.08055725818849169, 0.016103660200315062, 0.04854689264902845, 0.031214597693178803, 0.07693482795730233, 0.030803972949797753, 0.013848085091012763, 0.05672999475791585, 0.0739981496008113, 0.08718514160136692, 0.060192673990968615, 0.06490874045994133, 0.031792552617844194, 0.035423710505710915, 0.014265181362134172, 0.030564910484827124, 0.05727681658754591, 0.060558519398909993, 0.029904964940214995, 0.056074611566145904, 0.055959040619200096, 0.032457884299219586, 0.012650477674469585, 0.02266880801471416, 0.011878188597620465, 0.009203826048178598, 0.013575531356764259, 0.09278044526581652, 0.06567727148649283, 0.036710349668283015, 0.038997433584881946, 0.07313149922993034, 0.025733803704497404, 0.057437075956841, 0.060588943742914125, 0.2464929810957983, 0.0818828897899948, 0.19164583354722708, 0.10789880238007754, 0.12038798260618933, 1.6291214944794774, 5.793039472773671, 9.20318216085434, 18.41434009373188, 33.8177939504385, 57.43589021265507, 72.05046460032463, 71.99172735214233, 71.92605167627335, 71.97230279445648, 72.40028902888298, 68.20130914449692, 73.24818313121796, 72.73143365979195, 75.61237826943398, 76.7068563401699, 73.8657183945179, 77.50204727053642, 74.13801178336143, 72.88982436060905, 66.372459679842, 68.33959892392159, 65.22792309522629, 64.53562304377556, 60.48264652490616, 56.251432970166206, 54.7650895267725, 38.91435407102108, 30.3858333081007, 24.220063760876656, 15.954171605408192, 10.557554885745049, 7.09167156368494, 2.6556694228202105, 1.6848179558292031, 0.6977312662638724, 0.18593843589769676, 0.22165591071825475, 0.11880779435159639, 0.057972505819634534, 0.19242537062382326, 0.07118746565538459, 0.03434300990193151, 0.04146618040977046, 0.11650096188532189, 0.06201670599693898, 0.0007991260065409733, 0.026577007774903905, 0.06744596525095403, 0.011485661125334445, 0.06556147418450564, 0.07895339542301372, 0.02324004835827509, 0.03916170426236931, 0.019674284812936094, 0.06227911828318611, 0.06281000620219857, 0.026366770325694233, 0.03408496886549983, 0.011467924723547185, 0.04153404610406142, 0.06500847026472911, 0.032309287780663, 0.029777560448565055, 0.08972416981123388, 0.012088405637769029, 0.016908511934161652, 0.047837904130574316, 0.0662695275968872, 0.04545393283478916, 0.08214391054934822, 0.03602211159886792, 0.0899355483124964, 0.0500796947744675, 0.0684436566371005, 0.02468508595484309, 0.007652482290723128, 0.07526021625380963, 0.038792303967056796, 0.03463713415840175, 0.030799462547292933, 0.044220379495527595, 0.04303490248275921, 0.07954740300192498, 0.046164394516381435, 0.09109355101827532, 0.06413626120775007, 0.05413943923485931, 0.04677156037359964, 0.04217586654704064, 0.06856694963062182, 0.0468535899562994, 0.04804822136065923, 0.019642819606815465, 0.036657330638263375, 0.04397653574415017, 0.021201138624746818, 0.0108258742147882, 0.050728554488159716, 0.0484117215819424, 0.022914559085620567, 0.06100975260778796, 0.16133196564624086, 0.12422674146364443, 0.1692768940120004, 0.12495313334511593, 0.20534705225145444, 0.14914526254869998, 0.11797208411735483, 0.14068592194234952, 0.13588189613074064, 0.167633511882741, 0.1610405242536217, 0.13472709950292483, 0.12886689364677295, 0.15920324862236157, 0.20341522700618953, 0.134073460358195, 0.13128111488185823, 0.07053804933093488, 0.12805872451281175, 0.1857372248196043, 0.16132816585013643, 0.12488280743127689, 0.09750601864652708, 0.07731349396635778, 0.1271096512209624, 0.14334794628666714, 0.12364575115498155, 0.1917260597110726, 0.10928850359050557, 0.14082244742894545, 0.1927117505692877, 0.13674384128535166, 0.1713536903844215, 0.1193264516768977, 0.140365922707133, 0.1000539303640835, 0.15338580531533808, 0.15784136310685426, 0.20172792457742617, 0.10129438567673787, 0.09692125822766684, 0.17617600271478295, 0.12447824788978323, 0.24609600630356, 0.1326503328164108, 0.1800663853646256, 0.11995785607723519, 0.09174972088658251, 0.25833534251432866, 0.12062648660503328, 0.09989121448597871, 0.09408252852153964, 0.11087260296335444, 0.10951787917292677, 0.20722018845845014, 0.17443320248275995, 0.15815043792827055, 0.08625910457340069, 0.16131690004840493, 0.1461673207813874, 0.11352208501193672, 0.17357401811750606, 0.10866724434890784, 0.13798149127978832, 0.08792956024990417, 0.19151842163410038, 0.11045985753298737, 0.24461978551698849, 0.10588842822471634, 0.28852605842985213, 0.1516893893131055, 0.2365499536972493, 0.25883857801090926, 0.10644503898220137, 0.5726057616993785, 2.8165613394230604, 6.311580548062921, 14.586951769888401, 30.0903744623065, 54.50409673154354, 74.13680344820023, 78.80284667015076, 80.1599970459938, 85.41174843907356, 82.60848686099052, 80.56246384978294, 85.92023715376854, 85.42108833789825, 85.14127895236015, 88.50909143686295, 84.68705892562866, 85.36546692252159, 83.7840373814106, 77.47440755367279, 76.05361819267273, 72.22340852022171, 73.0966168642044, 70.87056711316109, 69.65931370854378, 63.344611153006554, 53.112303614616394, 35.38160003721714, 24.927737787365913, 17.58944995701313, 11.069067288190126, 5.876218434423208, 3.7332201143726707, 1.0379097936674953, 0.6813512952066958, 0.35961576097179204, 0.13855652214260772, 0.20903444266878068, 0.1725371487555094, 0.2541380818001926, 0.27957629179582, 0.24125595664372668, 0.13244518835563213, 0.14708874165080488, 0.23053891374729574, 0.17179421440232545, 0.10131831993930973, 0.17148242332041264, 0.18318177288165316, 0.09608057560399175, 0.14314896165160462, 0.23761935881339014, 0.11655792914098129, 0.1871409229352139, 0.08576337218983099, 0.1409088631044142, 0.12109395800507627, 0.12098915191018023, 0.1124212054128293, 0.12155692456872202, 0.1021324707835447, 0.1733622091705911, 0.13434403255814686, 0.11917621872271411, 0.16055241372669116, 0.08872954349499196, 0.10051161283627152, 0.1300901162903756, 0.14617711713071913, 0.14064452494494617, 0.21913100557867438, 0.13282191735925153, 0.21610927709843963, 0.2635064790956676, 0.17348815163131803, 0.20046406192705035, 0.13748918019700795, 0.18124737980542704, 0.235038896498736, 0.18717230093898252, 0.1258811741718091, 0.17065507709048688, 0.1383318443549797, 0.1171187701402232, 0.1794195591355674, 0.1127360764076002, 0.09630811066017486, 0.13602985069155693, 0.07917362032458186, 0.18454992212355137, 0.16512753150891513, 0.16392507415730506, 0.12261248120921664, 0.10875024614506401, 0.16772176808444783, 0.1517346454784274, 0.09844459797022864, 0.13476275227731094, 0.15444756631040946, 0.17040555219864473, 0.10992715135216713], [0.04259789624484256, 0.04439445765456185, 0.0639403861714527, 0.02333486329007428, 0.0232647006487241, 0.09774790683877654, 0.0520592846442014, 0.018125691640307195, 0.016987101662380155, 0.04366476692666765, 0.05169841162569355, 0.06805148354033008, 0.011715687942341901, 0.027485574646561872, 0.06923331660800613, 0.03737141400051769, 0.041407465396332555, 0.011789382278948324, 0.017581131505721714, 0.022137892265163828, 0.03414959879592061, 0.06619231455260888, 0.015137575956032379, 0.0638238393003121, 0.034223932307213545, 0.034821416847989894, 0.06895289610838518, 0.004236806516928482, 0.018949306722788606, 0.027748923894250765, 0.04043409790028818, 0.05288545828079805, 0.05114971958391834, 0.06231688617845066, 0.06106623746745754, 0.027584603121795226, 0.043650758889270946, 0.037036386274849065, 0.009651031250541564, 0.025069151088246144, 0.022587529856537003, 0.008446414249192458, 0.013329606808838435, 0.05163075002201367, 0.053402657285914756, 0.03025517700734781, 0.036360705344122835, 0.06673262774711475, 0.05673284089425579, 0.01669562130700797, 0.04887894065177534, 0.02013429762882879, 0.08650986143038608, 0.08366443013073877, 0.09997361514251679, 0.037777869729325175, 0.0170375305970083, 0.07627932602190413, 0.043293333146721125, 0.06377920653903857, 0.02461524429236306, 0.06142057216493413, 0.06571097983396612, 0.029493132351490203, 0.04841927293455228, 0.018626194178068545, 0.04030890871945303, 0.06936165620572865, 0.033856409645522945, 0.06317500185105018, 0.0497195639036363, 0.018988414194609504, 0.032057677453849465, 0.1216009932977613, 0.07823553823982365, 0.044035918690497056, 0.033004635624820367, 0.068340676225489, 0.13121697847964242, 0.25125552085228264, 0.1197318201593589, 0.8212243427988142, 2.660540761426091, 5.636087469756603, 7.741640936583281, 6.817903853952885, 7.8324242401868105, 8.118325173854828, 9.865500871092081, 10.423934105783701, 9.278711657971144, 7.952500646933913, 8.418091088533401, 6.914804354310036, 4.445035206153989, 4.449736503884196, 4.844031846150756, 2.933883131481707, 2.5363902607932687, 1.6086158948019147, 1.0458508925512433, 0.41211564384866506, 0.137581369781401, 0.20781736500794068, 0.26039029005914927, 0.1847074503893964, 0.044509086073958315, 0.07709682395216078, 0.1630686505814083, 0.04654298259993084, 0.011431164293753682, 0.06526887504151091, 0.07312651199754328, 0.007959001341077965, 0.01587647209817078, 0.04245625365001615, 0.04545286785287317, 0.0882073980756104, 0.02273599835461937, 0.03094953779509524, 0.05781569372629747, 0.022652165353065357, 0.07719061657553539, 0.02545537216064986, 0.03132201614789665, 0.04974808092811145, 0.051437260990496725, 0.05858970180270262, 0.04316207690862939, 0.05462784662086051, 0.03369290709088091, 0.042355191690148786, 0.008668243117426755, 0.08897060790332034, 0.059752866145572625, 0.033921674112207256, 0.04943521744280588, 0.039841533798608, 0.0036791609272768255, 0.014200916011759546, 0.0043354578883736394, 0.02177080747060245, 0.06423072176403366, 0.06599755273782648, 0.0670466452720575, 0.10884460280067287, 0.0474710048729321, 0.019250050936534535, 0.033814960697782226, 0.07267848486662842, 0.01761688632541336, 0.02994025777297793, 0.021270310498948675, 0.007070220590321696, 0.01910960319946753, 0.018014603265328333, 0.05041963551775552, 0.060287234737188555, 0.0523875885119196, 0.03646789373306092, 0.03533717979735229, 0.004057080614074948, 0.05147559291799553, 0.02759629194770241, 0.03619591145252343, 0.038272770907497033, 0.009936059559549903, 0.07871639798395336, 0.0681786950735841, 0.03284055790572893, 0.05652106905472465, 0.05029196756368037, 0.018088465512846597, 0.057046572692343034, 0.10387995396740735, 0.043678826914401725, 0.07649421488167718, 0.029514454254240263, 0.037977603933541104, 0.009388772032252746, 0.012527557610155782, 0.09114174608839676, 0.014738308855157811, 0.06407342356396839, 0.009819258502830053, 0.022963915616855957, 0.03321883428725414, 0.011454751602286706, 0.021956457567284815, 0.03265110244683456, 0.035314325359649956, 0.026748490272439085, 0.03715180137078278, 0.0873087091895286, 0.04636091893189587, 0.06082991538278293, 0.04444104226422496, 0.037707202427554876, 0.015231572670018068, 0.04397522956423927, 0.026611866451276, 0.044248978156247176, 0.019526474970916752, 0.024576370597060304, 0.0591079695004737, 0.0032109496987686725, 0.037238061195239425, 0.0482214312069118, 0.04889431795163546, 0.009588716820871923, 0.055129044922068715, 0.015660778008168563, 0.01877985028841067, 0.013707416565011954, 0.048538187256781384, 0.03318895171105396, 0.024368697268073447, 0.011785526821768144, 0.030222793393477332, 0.047517923449049704, 0.046685426714248024, 0.02794128486129921, 0.07329813364776783, 0.027666564055834897, 0.023579026164952666, 0.049663865720503964, 0.04515578242717311, 0.030453022445726674, 0.06575686682481319, 0.03228327550459653, 0.046598751287092455, 0.04559073662676383, 0.051580432409537025, 0.07672472595004365, 0.06177761570143048, 0.07384606869891286, 0.01220174086483894, 0.03735117192263715, 0.03907766717020422, 0.03221676422981545, 0.005935649805905996, 0.09391072133439593, 0.07675666798604652, 0.08176194940460846, 0.0695803522830829, 0.012583099014591426, 0.06690177804557607, 0.045766989278490655, 0.03058428981603356, 0.048031556434580125, 0.10665300360415131, 0.04782082360179629, 0.1719782521831803, 0.25928217452019453, 0.3163461171789095, 0.47453718027099967, 0.9262268396560103, 4.380489969626069, 8.649415075778961, 12.924464978277683, 18.526694364845753, 17.654703855514526, 19.940323010087013, 18.862489946186543, 21.462156549096107, 19.97391890734434, 19.030756317079067, 18.577400743961334, 19.01661917567253, 15.183750595897436, 11.82535495609045, 10.458311811089516, 11.820596661418676, 8.999265152961016, 7.792125027626753, 6.413163347169757, 4.150331569835544, 2.761947107501328, 0.6215925549622625, 0.3158033697400242, 0.25234288594219834, 0.1796961872605607, 0.07871359266573563, 0.06397228367859498, 0.17840232700109482, 0.13181039976188913, 0.1514500318444334, 0.08689715861692093, 0.05980626738164574, 0.059409385357866995, 0.05742172463214956, 0.04462940676603466, 0.07064566816552542, 0.04297563085856382, 0.032600617851130664, 0.015433922944794176, 0.09924292622599751, 0.02165530702768592, 0.030063619415159337, 0.04604160618328024, 0.028010434471070766, 0.027400567196309566, 0.015771166908962186, 0.04667276567488443, 0.08302368951262906, 0.04274835926480591, 0.014499963490379741, 0.01039160835716757, 0.020616756701201666, 0.04133276823267806, 0.09334385409601964, 0.02304711964825401, 0.07504991386667825, 0.04931753137498163, 0.009587924578227103, 0.01786744465789525, 0.02770868464722298, 0.017686902392597403, 0.014501439436571673, 0.04417683398060035, 0.08684322674525902, 0.007303514248633292, 0.06874945858726278, 0.027658368890115526, 0.03300619042420294, 0.04171977227088064, 0.04296507380786352, 0.06861754183773883, 0.015839835978113115, 0.06347984643070959, 0.048549375133006833, 0.030464086012216285, 0.03817800235992763, 0.039172094329842366, 0.0148477756374632, 0.028679616043518763, 0.014330693520605564, 0.05463142748340033, 0.0849026812647935, 0.06274788844166324, 0.04751029046019539, 0.0469923789933091, 0.023887846800789703, 0.02331310537556419, 0.04134559254453052, 0.09170208984869532, 0.009783140958461445, 0.048019759997259825, 0.037137155086384155, 0.013528338186006295, 0.0769511255202815, 0.058718824366224, 0.2056001839810051, 0.14378110819961876, 0.09584334067767486, 0.11835802317364141, 0.11601042453548871, 0.2239781353273429, 0.13059780467301607, 0.15640150755643845, 0.1883732294663787, 0.09098993978113867, 0.1584444916807115, 0.1626551110530272, 0.08940924686612561, 0.1441057978081517, 0.19171480875229463, 0.10105397435836494, 0.08633976118289866, 0.15535867132712156, 0.13441774266539142, 0.22318755509331822, 0.12815576774301007, 0.18293396977242082, 0.14219594013411552, 0.12369005737127736, 0.11769362288760021, 0.11146066593937576, 0.0805208484234754, 0.16105122602311894, 0.14257597911637276, 0.12587216449901462, 0.19479959009913728, 0.21147115097846836, 0.17051265895133838, 0.14183985767886043, 0.14657161314971745, 0.20623963326215744, 0.10345666261855513, 0.10394673241535202, 0.07621295575518161, 0.1331486107665114, 0.15625146013917401, 0.08510297950124368, 0.07247673944220878, 0.11343405887600966, 0.13358754658838734, 0.0808543992752675, 0.27302618545945734, 0.14972498378483579, 0.22134276892757043, 0.1145900206756778, 0.16173149342648685, 0.10974767777952366, 0.21070826769573614, 0.10012663115048781, 0.2244605906889774, 0.11888807988725603, 0.12440918362699449, 0.2521452371729538, 0.13627459615236148, 0.17295886675128713, 0.05683025148755405, 0.1466322020860389, 0.17152347892988473, 0.17948899447219446, 0.16714923083782196, 0.11080559444963001, 0.22662359493551776, 0.1688781677512452, 0.21137054543942213, 0.10322947637178004, 0.12650364311411977, 0.11569087801035494, 0.09743278351379558, 0.16107254050439224, 0.28616466326639056, 0.12264177377801389, 0.18915235094027594, 0.25878187792841345, 0.40867979696486145, 0.3047062730183825, 0.30457716900855303, 1.6833138302899897, 4.291306855157018, 8.484794609248638, 12.451504357159138, 11.983643062412739, 14.109889268875122, 13.982902932912111, 15.124176442623138, 15.1896583288908, 14.147899579256773, 13.96795453503728, 13.769340142607689, 10.430023279041052, 8.010103181004524, 6.337744519114494, 7.26023574359715, 5.10481090284884, 4.506561979651451, 3.3269064920023084, 1.9365005381405354, 1.2784574297256768, 0.27295945154037327, 0.37594143650494516, 0.38417562434915453, 0.2817677945131436, 0.28964872006326914, 0.31535760615952313, 0.3572687931591645, 0.21561960806138813, 0.3156392660457641, 0.20080230315215886, 0.14520687778713182, 0.15715109155280516, 0.17006987880449742, 0.14147252426482737, 0.299546595197171, 0.12850016879383475, 0.15568968403385952, 0.10783229852677323, 0.18417656247038394, 0.08700085891177878, 0.09387190701090731, 0.09771150449523702, 0.13785820570774376, 0.12579226488014683, 0.2531813347013667, 0.12096592268790118, 0.17317493562586606, 0.13840631145285442, 0.20890590269118547, 0.10383241198724136, 0.07381158851785585, 0.20411018893355504, 0.15328260225942358, 0.07491108030080795, 0.14332262420793995, 0.14849882223643363, 0.16734503908082843, 0.08755824150284752, 0.16881018702406436, 0.11314272880554199, 0.12487741943914443, 0.12340945133473724, 0.14821811229921877, 0.11614827104494907, 0.16794778173789382, 0.14442685089306906, 0.11734626066754572, 0.09347390805487521, 0.08960300678154454, 0.24692345643416047, 0.22457206127000973, 0.10829851569724269, 0.12947530631208792, 0.14938570355297998, 0.08671166622661985, 0.18318204005481675, 0.10893456594203599, 0.1410839060554281, 0.21305847127223387, 0.14913827151758596, 0.13605987798655406, 0.25280880625359714, 0.1991101322346367, 0.16609110636636615, 0.19849248725222424, 0.15675830247346312, 0.12826282996684313, 0.13365088147111237, 0.08829387312289327, 0.23660460545215756, 0.14283754164353013, 0.08197114599170163, 0.21159664815058932, 0.13461032998748124], [0.06526842233142816, 0.05968128229142167, 0.034306637244299054, 0.02982191861519823, 0.04905685942503624, 0.04420112818479538, 0.029507992003345862, 0.03977157895860728, 0.02462744334479794, 0.029850751052435953, 0.05441833091026638, 0.031588881320203654, 0.04791728795680683, 0.040965798471006565, 0.011352061555953696, 0.014109383228060324, 0.023278439657588024, 0.035789774847216904, 0.03091732858592877, 0.02745621899521211, 0.04896298145467881, 0.01634003609069623, 0.10106415662448853, 0.040862550886231475, 0.022992232261458412, 0.015097340419742977, 0.03932807521778159, 0.04323649947764352, 0.01773837775544962, 0.018372570775682107, 0.05371447063225787, 0.05119024084706325, 0.056463433866156265, 0.037412436213344336, 0.0070328200581570854, 0.0045377186415862525, 0.005962816585451947, 0.025338346604257822, 0.021613926728605293, 0.06916649363120086, 0.027986756249447353, 0.0272874212168972, 0.016525522914889734, 0.0056568471882201266, 0.059470586566021666, 0.04025289512355812, 0.044719848592649214, 0.04038386934553273, 0.011804732675955165, 0.05449205214972608, 0.03038459828530904, 0.045811629461240955, 0.021937545789114665, 0.03803141706157476, 0.031244762285496108, 0.03203023283276707, 0.04889448122412432, 0.09330967819551006, 0.06409205889212899, 0.04599952641001437, 0.08639568201033399, 0.018906249169958755, 0.05196381847781595, 0.03557757998351008, 0.04038483042677399, 0.04961578939401079, 0.0556142684945371, 0.016786102096375544, 0.041470833675703034, 0.057851220335578546, 0.05144511291291565, 0.029782464189338498, 0.06421538157155737, 0.12209233958856203, 0.07120170746929944, 0.08108737427392043, 0.014684056004625745, 0.07549195928731933, 0.030094077155808918, 0.10472367197507992, 0.07936715759569779, 0.02361172704695491, 0.09669845065218396, 0.2250520230154507, 0.21568592637777328, 0.18498361838283017, 0.12947221897775307, 0.1352352331741713, 0.36569006158970296, 0.3212213149527088, 0.1402352750301361, 0.3400996222626418, 0.36574026045855135, 0.21534501342102885, 0.2098295500036329, 0.1682314305799082, 0.21221458999207243, 0.11225870475755073, 0.11650045722490177, 0.09805700392462313, 0.04650179711461533, 0.05300473625538871, 0.07049496765830554, 0.018891064828494564, 0.07373436805210076, 0.12008032528683543, 0.04191600724880118, 0.03918529713700991, 0.025882337140501477, 0.03636603767517954, 0.06825656120781787, 0.1319277926813811, 0.06744050304405391, 0.15442358009750023, 0.004363752732388093, 0.07629446583450772, 0.05124224684550427, 0.10017010616138577, 0.06822401061072014, 0.02001812925300328, 0.02669662528205663, 0.030833031742076855, 0.011318461747578112, 0.02667595646926202, 0.03541281206707936, 0.04079382801137399, 0.01900157247291645, 0.03921377705410123, 0.0347264924494084, 0.016991990560200065, 0.0036118316666033934, 0.003916841142199701, 0.05199872910452541, 0.07485104055376723, 0.055872858720249496, 0.03499123879009858, 0.04614873891114257, 0.05698429165931884, 0.06339538260363042, 0.026912811044894625, 0.054540729615837336, 0.021608308670693077, 0.02710187873162795, 0.07140159752452746, 0.08749213098781183, 0.05869444852578454, 0.030342640966409817, 0.022400716443371493, 0.02373005136178108, 0.035296606583870016, 0.01937478740728693, 0.032844684246811084, 0.026601129429764114, 0.06388794601662084, 0.07231942639918998, 0.016871154075488448, 0.027284738353046123, 0.023341728156083263, 0.025767018523765728, 0.09341327458969317, 0.08042692221351899, 0.04848038137424737, 0.10047860210761428, 0.05896962946280837, 0.04318295352277346, 0.07097112960764207, 0.019312331969558727, 0.029689563998545054, 0.0323296486021718, 0.05630005005514249, 0.014777632477489533, 0.05927357233304065, 0.06989415458519943, 0.02127915133314673, 0.02330124771106057, 0.06261044269194826, 0.03760327206691727, 0.04232999206578825, 0.02411064695479581, 0.04829273675568402, 0.01041808262016275, 0.03637472080299631, 0.036440404583117925, 0.019586024900490884, 0.02393926650256617, 0.040100595288095064, 0.0256927276859642, 0.05917497430345975, 0.07026760329608805, 0.012288653779251035, 0.04905015783151612, 0.03602916200179607, 0.02651511451404076, 0.08558404704672284, 0.01746311147144297, 0.00974603357462911, 0.07754715916235, 0.033186239161295816, 0.04610123403836042, 0.06745894541381858, 0.05166892980923876, 0.03273060130595695, 0.04310615608119406, 0.022510012531711254, 0.05404036623076536, 0.029524081764975563, 0.07341217948123813, 0.08961744897533208, 0.05707903423171956, 0.048658719460945576, 0.03442614157393109, 0.056297070332220756, 0.02196205150539754, 0.03680476569570601, 0.03883538563968614, 0.013424525641312357, 0.026160770539718214, 0.06363246910041198, 0.0193942038458772, 0.016041520175349433, 0.064016233664006, 0.057022015025722794, 0.05463616609631572, 0.07359583876677789, 0.02953490042273188, 0.012953905679751188, 0.006043532102921745, 0.02599595067295013, 0.03284208672994282, 0.04416451061842963, 0.03557118267053738, 0.021314381083357148, 0.04729145708552096, 0.013218658514233539, 0.027410506409069058, 0.06496665024315007, 0.021688375272788107, 0.019933522562496364, 0.11016687247320078, 0.020725444228446577, 0.053321729792514816, 0.020541196790873073, 0.05161271212273277, 0.055789908874430694, 0.07926897145807743, 0.06885599388624541, 0.008111450533760944, 0.05109978046675678, 0.023034970690787304, 0.061486738341045566, 0.03470063973509241, 0.0356918855686672, 0.0063460801993642235, 0.07390810482320376, 0.059702923317672685, 0.08057963394094259, 0.051909270623582415, 0.0730451503477525, 0.07961540599353611, 0.11696648885845207, 0.19506763899698853, 0.062001644109841436, 0.06511246741865762, 0.07852981463656761, 0.1699128551990725, 0.30130088387522846, 0.12332501719356515, 0.17086562438635156, 0.11742176677216776, 0.0718846169183962, 0.1214126733248122, 0.09970991523005068, 0.10819094139151275, 0.09714639614685439, 0.11844691762235016, 0.0772323104320094, 0.09430240461369976, 0.11306340064038523, 0.08661363594001159, 0.05357911031751428, 0.15385396691272035, 0.10906959971180186, 0.059880753033212386, 0.02622629104735097, 0.01680385241343174, 0.07721607224084437, 0.059427805463201366, 0.08213801789679565, 0.03324298006191384, 0.11091359177953564, 0.058482958702370524, 0.015091907898749923, 0.02914162709203083, 0.06375581404427066, 0.025465192629781086, 0.00755637184738589, 0.029952798213344067, 0.0975710827333387, 0.036696657043648884, 0.03547942353179678, 0.05021827972086612, 0.021841728957952, 0.006352933933158056, 0.01950901780219283, 0.05406386262620799, 0.006303433610810316, 0.01739806408295408, 0.03735826685442589, 0.06174780362925958, 0.09125087890424766, 0.062113508029142395, 0.020471024872676935, 0.002260664155073755, 0.050018423062283546, 0.06226158875506371, 0.021197934402152896, 0.03422609937842935, 0.0844254283583723, 0.021677942531823646, 0.06149700224341359, 0.09018263895995915, 0.039367546341964044, 0.030649014370283112, 0.012229540789121529, 0.03853968431940302, 0.048868160956772044, 0.03406609233934432, 0.009455683139094617, 0.0415334969147807, 0.00884934755958966, 0.027606041912804358, 0.03540814024745487, 0.031159827194642276, 0.03458647886873223, 0.0412478182988707, 0.022620386589551345, 0.025001608228194527, 0.055373961076838896, 0.029257064452394843, 0.05221332852670457, 0.022983361741353292, 0.06648050533840433, 0.04578300482535269, 0.01674217066465644, 0.044493790410342626, 0.056361013776040636, 0.03465423324087169, 0.0994365377118811, 0.07517508449382149, 0.03795616328716278, 0.061127097287680954, 0.04313262106734328, 0.151222029235214, 0.1452965589123778, 0.1167531065584626, 0.15516532701440156, 0.11817896520369686, 0.12093923505744897, 0.12379835156025365, 0.09254991935449652, 0.09363174060126767, 0.15221757581457496, 0.11195190090802498, 0.18525344843510538, 0.15535009209997952, 0.08197984396247193, 0.12704753346042708, 0.13440995011478662, 0.12271617408259772, 0.13867870933609083, 0.10371518234023824, 0.10572570492513478, 0.20529962901491672, 0.161528070748318, 0.1862144109327346, 0.2314522600499913, 0.1958324815495871, 0.05450850927445572, 0.1786252681631595, 0.10848246442037635, 0.1409468165365979, 0.20921110350172967, 0.30288088659290224, 0.1971851199050434, 0.1949254286591895, 0.13044330436969176, 0.09827802292420529, 0.09256998702767305, 0.09190354583552107, 0.14241539320209995, 0.09716230779304169, 0.15409025189001113, 0.12334442435530946, 0.10307870164979249, 0.11453532439190894, 0.04594058875227347, 0.1563445254578255, 0.1607639851863496, 0.10782206431031227, 0.15084852115251124, 0.085805066046305, 0.09837456149398349, 0.13744894094998017, 0.2225478831678629, 0.11724893542123027, 0.16655644780257717, 0.17984840174904093, 0.16606379533186555, 0.1474027443327941, 0.16409009811468422, 0.15872699761530384, 0.31812563887797296, 0.2673441544175148, 0.1293448219075799, 0.17916792654432356, 0.21098302560858428, 0.22359738388331607, 0.10704891712521203, 0.07982560447999276, 0.25020294764544815, 0.14143068197881803, 0.13030385482124984, 0.1314771902980283, 0.15472211642190814, 0.2442993558361195, 0.1792803916032426, 0.18175419245380908, 0.22144833201309666, 0.07444413582561538, 0.18214664014521986, 0.19459266448393464, 0.2184275386389345, 0.13343896862352267, 0.14598773588659242, 0.17109221691498533, 0.2767718641553074, 0.29757856798823923, 0.19423346500843763, 0.3032330208225176, 0.24553029681555927, 0.44255637447349727, 0.5220441310666502, 0.38952116563450545, 0.498006769339554, 0.4296244215220213, 0.5747586430516094, 0.3626538463868201, 0.27155872201547027, 0.28260573861189187, 0.3962257277453318, 0.2453805907862261, 0.19683102640556172, 0.15282527601812035, 0.15452639723662287, 0.16642176284221932, 0.2405324368737638, 0.31426326488144696, 0.18896418681833893, 0.1570136012742296, 0.14889643527567387, 0.11651033521047793, 0.12122973392251879, 0.22502388077555224, 0.21137946605449542, 0.28323353617452085, 0.2884294604882598, 0.14318710804218426, 0.175534252775833, 0.12682983186095953, 0.14485440216958523, 0.17143439152278006, 0.11672612206893973, 0.1012044373783283, 0.1389510923763737, 0.0599309890094446, 0.10184042082983069, 0.17626261134864762, 0.0726584617223125, 0.10504555626539513, 0.09701348491944373, 0.10815230518346652, 0.036014816287206486, 0.11130031751235947, 0.07281899568624794, 0.33444178523495793, 0.2450837317155674, 0.16033983294619247, 0.22610489308135584, 0.12982613436179236, 0.13127333717420697, 0.17650955356657505, 0.1547469338402152, 0.11105177225545049, 0.15621059748809785, 0.12867138226283714, 0.18710632401052862, 0.12007478886516765, 0.1813553474494256, 0.19868016155669466, 0.24074133660178632, 0.13359763979678974, 0.10048931129858829, 0.08067938601016067, 0.12183238752186298, 0.08543360629118979, 0.14118782157311216, 0.09638969495426863, 0.09570704525685869, 0.12858146365033463, 0.10572329294518568, 0.15950813773088157, 0.09720083267893642, 0.1727802021196112, 0.173159588011913, 0.23944965825648978, 0.11950961372349411, 0.08395786047913134, 0.1816354488255456, 0.1164148208044935, 0.1320371258771047, 0.16738958278438076, 0.14800429955357686, 0.09342491888673976, 0.15332868963014334, 0.15527976618614048, 0.14599769550841302, 0.18180268438300118, 0.1361760834697634], [0.032966741564450786, 0.03871024840918835, 0.07737383799394593, 0.04801891765964683, 0.04789825186890084, 0.04775054221681785, 0.005977441996947164, 0.01895600275020115, 0.01856599672464654, 0.050354890554444864, 0.028962587675778195, 0.011088216924690641, 0.03203061132808216, 0.02943531348137185, 0.02109813409333583, 0.05363812961149961, 0.03415452294575516, 0.01047582263709046, 0.03940523631172255, 0.015977192670106888, 0.004830262123505236, 0.02695632316317642, 0.03733204306627158, 0.036761828741873614, 0.029799687581544276, 0.020030747618875466, 0.0038862064457134693, 0.009800032239581924, 0.033969275464187376, 0.03574304922949523, 0.05997593718348071, 0.054155532707227394, 0.019153914981870912, 0.029105267421982717, 0.07873748239944689, 0.05999314016662538, 0.021911108633503318, 0.04394645649881568, 0.03944104493712075, 0.02790831495076418, 0.03190220122633036, 0.041791270778048784, 0.033395394930266775, 0.023489055602112785, 0.02688528664293699, 0.05482926178956404, 0.06544399962876923, 0.036114813265157863, 0.04454228976101149, 0.04954801275744103, 0.013803095171169844, 0.010352829285693588, 0.03750189098354895, 0.03228648900403641, 0.06363255073665641, 0.10350865006330423, 0.02552773898059968, 0.017898459009302314, 0.032468430217704736, 0.07212418960989453, 0.015773491686559282, 0.07043647899990901, 0.06278237604419701, 0.04192933251033537, 0.009161871512333164, 0.006670046213912428, 0.056926456090877764, 0.017774409025150817, 0.010429902249597944, 0.03841846562863793, 0.07672615829505958, 0.0546313458471559, 0.08416497163125314, 0.026404801683383994, 0.014908793164067902, 0.0018299029738955142, 0.05974886968033388, 0.0608540240500588, 0.03919329748896416, 0.12291440172703005, 0.026029868677142076, 0.051684815480257384, 0.06335360711091198, 0.056303118835785426, 0.05453333411423955, 0.08845249234582298, 0.03704298025695607, 0.026508667106099892, 0.07601325123687275, 0.06402363287634216, 0.057287655654363334, 0.046902631074772216, 0.13978565228171647, 0.07585911458590999, 0.04180739022558555, 0.049184616436832584, 0.00592662575400027, 0.035584704601205885, 0.07469656251487322, 0.030488046249956824, 0.05140148205100559, 0.09689697515568696, 0.08457686359179206, 0.12196825991850346, 0.028331663816061337, 0.06366191009874456, 0.04085541142558213, 0.03210602095350623, 0.05512307063327171, 0.05679808680724818, 0.05374870961531997, 0.07628066188772209, 0.02762439522484783, 0.14699481544084847, 0.10438330820761621, 0.03366651631949935, 0.05746338880271651, 0.08247355028288439, 0.013218919193604961, 0.030587006076530088, 0.04973379829607438, 0.021937382516625803, 0.04467479280719999, 0.14479848876362666, 0.0366991321061505, 0.03539669261954259, 0.022561404402949847, 0.009114878721447894, 0.06780908326618373, 0.056456535603501834, 0.042377111021778546, 0.03893903398420662, 0.06112697854405269, 0.09288132539950311, 0.052691857927129604, 0.007700639325776137, 0.02256277366541326, 0.024719165376154706, 0.05683628514816519, 0.06899265295942314, 0.021184531215112656, 0.031650357122998685, 0.022508478141389787, 0.03545087682141457, 0.034397836061543785, 0.013357640509639168, 0.059863457281608135, 0.021407247877505142, 0.03532288974383846, 0.029393235563475173, 0.023194380300992634, 0.018883815901062917, 0.010298591278115055, 0.07252948387758806, 0.03197191486833617, 0.028238362865522504, 0.03720288339536637, 0.021212074170762207, 0.050606693839654326, 0.041877512048813514, 0.04258005130395759, 0.019217973458580673, 0.03388684883248061, 0.007162205156419077, 0.015973094159562606, 0.017471783467044588, 0.009196512182825245, 0.04658744466723874, 0.016850928695930634, 0.010562584338913439, 0.03491727635264397, 0.062316537369042635, 0.054595307155977935, 0.03137529121886473, 0.025996217846113723, 0.050807678562705405, 0.06061638465325814, 0.05258769750071224, 0.0845136474526953, 0.05241086597379763, 0.036951510555809364, 0.029105874127708375, 0.05229455287917517, 0.08865324329235591, 0.02926680328528164, 0.03310378655442037, 0.035657735643326305, 0.0042950317128997995, 0.04999827375286259, 0.04017503270006273, 0.045278674660949036, 0.04876329920080025, 0.026488000148674473, 0.010610157860355685, 0.004887899167442811, 0.028157791603007354, 0.07622843695571646, 0.15296336001483724, 0.025246830518881325, 0.017810187964641955, 0.02401603982434608, 0.018340370843361598, 0.04751763030071743, 0.0376647478697123, 0.04408195411087945, 0.08707656539627351, 0.07531661205575801, 0.03050108949537389, 0.03458510589553043, 0.05058214359451085, 0.05612586057395674, 0.03250835776270833, 0.03485108791210223, 0.03121632689726539, 0.043220658335485496, 0.12322097551077604, 0.03408795972063672, 0.01956884232640732, 0.0297095834321226, 0.033217049422091804, 0.03127814408799168, 0.12628041993593797, 0.04389865105622448, 0.07888370775617659, 0.015564465793431737, 0.041428983968216926, 0.04039643761643674, 0.02300200634635985, 0.029842329531675205, 0.05317950461176224, 0.05384583077102434, 0.017538812389830127, 0.036980465447413735, 0.03793197298364248, 0.027103925203846302, 0.042528338453848846, 0.11664726145681925, 0.06538508794619702, 0.05082920455606654, 0.024208987088059075, 0.041181232809321955, 0.06375497541739605, 0.05902403630898334, 0.09183520145597868, 0.01949425091879675, 0.021076426273793913, 0.07206267298897728, 0.06446785278967582, 0.08161871490301564, 0.012884041752840858, 0.047585963548044674, 0.023479361298086587, 0.05198670260142535, 0.07956309200380929, 0.09129101425060071, 0.024333977744390722, 0.06870920449728146, 0.006731787798344158, 0.07321056764340028, 0.06710506713716313, 0.062188019655877724, 0.10973169934004545, 0.022181281929078978, 0.02825224288244499, 0.022801758204877842, 0.10291172584402375, 0.0845507399935741, 0.07092581407050602, 0.09410209153429605, 0.03507733163132798, 0.04140575845667627, 0.05777214821137022, 0.08587445685407147, 0.030476596766675357, 0.015155681576288771, 0.00877027914611972, 0.013146169239917072, 0.06141742916952353, 0.01736803493258776, 0.053721691729151644, 0.058452883167774417, 0.0704855498042889, 0.04550859201117419, 0.05979371024295688, 0.03217730794858653, 0.02217353761807317, 0.015043465136841405, 0.019563270652724896, 0.05141172368894331, 0.06970469912630506, 0.027465275052236393, 0.015576946861983743, 0.017669471199042164, 0.052246691775508225, 0.013239904346846743, 0.03545986794051714, 0.04615383375494275, 0.014925309660611674, 0.048277185051119886, 0.08344427202246152, 0.015502440801355988, 0.05036173686676193, 0.05240715152467601, 0.032097820221679285, 0.040623375243740156, 0.05805850218166597, 0.04589669071719982, 0.07670289938687347, 0.013283653952385066, 0.01062620216544019, 0.0644227079465054, 0.022150879849505145, 0.06563462025951594, 0.046974374490673654, 0.035950334786321037, 0.03822607497568242, 0.02331761206733063, 0.029206216204329394, 0.004858355659962399, 0.030707362020621076, 0.0333071275963448, 0.06380585706210695, 0.023549277175334282, 0.012855209315603133, 0.0035586386957220384, 0.03385389376489911, 0.009780201125977328, 0.048579706708551385, 0.04178060611593537, 0.03356554341735318, 0.07425572679494508, 0.0384525116533041, 0.06438824260840192, 0.059841448892257176, 0.011349584638082888, 0.05932024600042496, 0.022876711409480777, 0.05295481940265745, 0.017663543294474948, 0.029764227765554097, 0.03981473855674267, 0.05821390419441741, 0.03778741003770847, 0.06930568342795596, 0.04598667241225485, 0.08257727284217253, 0.037469919261639006, 0.030014110743650235, 0.02962717535410775, 0.06770077423425391, 0.04286082061298657, 0.006594967308046762, 0.1521464335382916, 0.13809290248900652, 0.21368276589782909, 0.19204490119591355, 0.11155255124322139, 0.11411254512495361, 0.15750272112200037, 0.14368836942594498, 0.11313939656247385, 0.1165576174389571, 0.10603907678159885, 0.079562624450773, 0.191162665723823, 0.09938993083778769, 0.1702581616700627, 0.11065926519222558, 0.1326991364476271, 0.18942758382763714, 0.16907575714867562, 0.1380970436730422, 0.18737533770035952, 0.20756962127052248, 0.11824562490801327, 0.10019481225754134, 0.08611064535216428, 0.26043716410640627, 0.08080955129116774, 0.11689304592437111, 0.1817030436359346, 0.1495398921542801, 0.12078624873538502, 0.19636164768598974, 0.1348004533792846, 0.1168869603134226, 0.13925099425250664, 0.20025102101499215, 0.09056123075424694, 0.07008709813817404, 0.07639365387149155, 0.15147902013268322, 0.14162080537062138, 0.10514362365938723, 0.0883030534896534, 0.09228997470927425, 0.10168066612095572, 0.24530284339562058, 0.1774922461481765, 0.14052996702957898, 0.13294903241330758, 0.10416056000394747, 0.08732407906791195, 0.13319161080289632, 0.11660657692118548, 0.24433690850855783, 0.11072132358094677, 0.11666614169371314, 0.13151677645510063, 0.17170141625683755, 0.12602982635144144, 0.13220529654063284, 0.1742390269646421, 0.2086159901227802, 0.16912433813558891, 0.12835585075663403, 0.09272902927477844, 0.09733861239510588, 0.12678657949436456, 0.14218722732039168, 0.10127306377398781, 0.15654168440960348, 0.2804131672019139, 0.18580636329716071, 0.12199135555420071, 0.10531938649364747, 0.10578965579043142, 0.18129897391190752, 0.06433740549255162, 0.15527581796050072, 0.2032409410458058, 0.20382652524858713, 0.16419625491835177, 0.0857915441156365, 0.215145880356431, 0.17822562163928524, 0.09773341269465163, 0.2024629624793306, 0.19681089936057106, 0.11971114392508753, 0.2297861682018265, 0.20767052366863936, 0.3020269417902455, 0.18490924034267664, 0.29323127469979227, 0.23616463062353432, 0.12177835174952634, 0.20164660003501922, 0.20269224158255383, 0.16168706846656278, 0.1460653348476626, 0.14295726490672678, 0.16404922062065452, 0.17532569443574175, 0.26274254196323454, 0.23993128241272643, 0.41957321867812425, 0.3363805718254298, 0.21973972994601354, 0.16004665492800996, 0.1558849134016782, 0.08468106854707003, 0.10747112493845634, 0.1364578027278185, 0.06337803861242719, 0.24665470991749316, 0.16587932710535824, 0.23704037972493097, 0.12995788041735068, 0.1263956309412606, 0.17422765726223588, 0.21475942921824753, 0.12074028752977028, 0.13592991308541968, 0.10294414285453968, 0.1834633288672194, 0.1443930683308281, 0.07771371936541982, 0.06433244794607162, 0.11405218625441194, 0.1539675600361079, 0.14159681915771216, 0.2856780815636739, 0.11937223476707004, 0.23523520940216258, 0.14926228439435363, 0.12125749024562538, 0.09001139580504969, 0.19458911701804027, 0.0805530947400257, 0.1533402077620849, 0.325516895391047, 0.07221581516205333, 0.08267781900940463, 0.11314767893054523, 0.08598585322033614, 0.1287595197209157, 0.13456508866511285, 0.11344891667249613, 0.053240972993080504, 0.0882683061354328, 0.08894156766473316, 0.07608800777234137, 0.1528588804649189, 0.11890505280462094, 0.1682879970758222, 0.135824364842847, 0.10851307059056126, 0.17175118468003348, 0.13010622089495882, 0.17216761858435348, 0.17334245319943875, 0.20536511612590402, 0.1443348394241184, 0.13063519407296553, 0.11107658225228079, 0.1358669195906259, 0.11375427333405241, 0.08997208424261771, 0.16242601006524637, 0.12703978543868288, 0.18973325961269438, 0.12660432286793366, 0.10293891813489608, 0.15523609821684659, 0.1788142041186802, 0.1116623000416439, 0.11363679135683924], [0.06437532923882827, 0.05921866453718394, 0.03330846346216276, 0.06139224067737814, 0.011903632203029701, 0.046189490240067244, 0.021600872350973077, 0.028965764067834243, 0.054847774663357995, 0.024170623619284015, 0.011675701025524177, 0.04790623366716318, 0.0531482861697441, 0.019950350761064328, 0.03667665245302487, 0.021006345268688165, 0.030284662534540985, 0.020895544475934003, 0.004412627795318258, 0.027541534436750226, 0.021320757987268735, 0.03691514903039206, 0.044943569009774365, 0.053646308078896254, 0.04983853017620277, 0.058012247827718966, 0.012848710885009496, 0.08317418963997625, 0.03014713329321239, 0.01378622244374128, 0.036380995661602356, 0.0296373001037864, 0.05570181965595111, 0.07352070373599418, 0.04226032295264304, 0.06410851972759701, 0.10027315336628817, 0.04660042483010329, 0.02030686922807945, 0.02331603129277937, 0.01479980506701395, 0.021626997804560233, 0.016652103622618597, 0.03563106285582762, 0.04616700316546485, 0.05321802949765697, 0.042332801094744354, 0.050680333442869596, 0.0386643577076029, 0.04593514509906527, 0.04090894253749866, 0.03708664822624996, 0.08925167407141998, 0.06361847219523042, 0.057450453168712556, 0.029900432273279876, 0.05865399776666891, 0.027850883852806874, 0.02165591373341158, 0.02185510988056194, 0.02908092126745032, 0.01669976620178204, 0.02629242568218615, 0.06057197824702598, 0.05496855919773225, 0.09229715127730742, 0.04777745249157306, 0.009652014596213121, 0.018211185197287705, 0.017072662012651563, 0.031687620357843116, 0.0368050328688696, 0.027596189902396873, 0.014438967300520744, 0.01314143990384764, 0.04101407517737243, 0.011377635037206346, 0.0198716998056625, 0.09878217126242816, 0.01183527576358756, 0.01467969032091787, 0.03493544783850666, 0.07407705474179238, 0.05244822197710164, 0.02791210175928427, 0.13241761014796793, 0.07389870923361741, 0.1294267550110817, 0.1088620358495973, 0.15082900266861543, 0.12196974421385676, 0.0692618076573126, 0.08351254218723625, 0.05832790549902711, 0.0855125040106941, 0.08809673643554561, 0.06579978522495367, 0.04837450287595857, 0.03169509378494695, 0.07706571312155575, 0.02773837055428885, 0.0625300532556139, 0.07550941460067406, 0.058136850711889565, 0.06769684827304445, 0.07711668382398784, 0.03436731523834169, 0.04856734252825845, 0.03613953791500535, 0.006189428595462232, 0.019393764123378787, 0.055650503854849376, 0.05019268675823696, 0.06208509119460359, 0.03538317068887409, 0.016225112667598296, 0.037268826927174814, 0.051320127822691575, 0.06753075562301092, 0.024276500262203626, 0.019380461126274895, 0.06097843397583347, 0.03622239499236457, 0.040472604232490994, 0.032340372636099346, 0.0650882140325848, 0.02095334664772963, 0.02262005818920443, 0.054793297313153744, 0.07773671110044234, 0.024748611940594856, 0.047534072582493536, 0.05393877363530919, 0.07399795664241537, 0.02400424338702578, 0.0076747903221985325, 0.009590394074621145, 0.026508151313464623, 0.05940253162407316, 0.011758454202208668, 0.06910905140102841, 0.026250303235428873, 0.05397792934672907, 0.044183910358697176, 0.029592882565339096, 0.05013545975089073, 0.013213564598117955, 0.016237922136497218, 0.0195718127724831, 0.03448481947998516, 0.05271044501569122, 0.016934462983044796, 0.026862628874368966, 0.06503003707621247, 0.0271154785878025, 0.060459680171334185, 0.024063988130365033, 0.04186602731351741, 0.03249924418923911, 0.046471532332361676, 0.08784456207649782, 0.03494783057249151, 0.028302938990236726, 0.03976204607170075, 0.04367061505035963, 0.00613597819210554, 0.04594723468471784, 0.037025231795269065, 0.04385804815683514, 0.03832138158031739, 0.022603083416470326, 0.009966606357920682, 0.02125934526702622, 0.09822662177612074, 0.04336291691288352, 0.024308100910275243, 0.010034830138465622, 0.03876278504321817, 0.041542135513736866, 0.02381348174822051, 0.09181462170090526, 0.021969641820760444, 0.018469857059244532, 0.08753242960665375, 0.07140408371924423, 0.07977651141118258, 0.03348097197886091, 0.0529808799183229, 0.08977699588285759, 0.03988074888184201, 0.03455787278653588, 0.028128951744292863, 0.02680060944840079, 0.03771228242840152, 0.025124175772361923, 0.024334367371920962, 0.03463662578724325, 0.014591393301088829, 0.025925795453076717, 0.07099320850102231, 0.04909302428131923, 0.014319555739348289, 0.05083520482003223, 0.01149115116277244, 0.05388223682530224, 0.08633456614916213, 0.12878332781838253, 0.008424224961345317, 0.03758738639589865, 0.03583804042136762, 0.005452007007988868, 0.03317990864161402, 0.01218326046000584, 0.028747930737154093, 0.025271390040870756, 0.07580246645375155, 0.03928314188669901, 0.05513917152711656, 0.01418573909177212, 0.054608068385277875, 0.05251674818282481, 0.018303393335372675, 0.03192394244251773, 0.020173308621451724, 0.03628382255556062, 0.019534762905095704, 0.022065774064685684, 0.02064232739940053, 0.0535032591142226, 0.024109574551403057, 0.06820173133746721, 0.03381233720574528, 0.0639056833460927, 0.020102643175050616, 0.04352283118350897, 0.026308890228392556, 0.0364455884846393, 0.002253594502690248, 0.023177869370556436, 0.05308699961460661, 0.014398294824786717, 0.03114044971880503, 0.014867291338305222, 0.046011285739950836, 0.05113043858727906, 0.019442625271040015, 0.017445155208406504, 0.035948323566117324, 0.0466256986692315, 0.006001867468512501, 0.0799665754311718, 0.05213345488300547, 0.007295117311514332, 0.03021770597115392, 0.06361991938319989, 0.005684228262907709, 0.011891640951944282, 0.036895315133733675, 0.07208930866909213, 0.09696672219433822, 0.11241351676289923, 0.05667565841577016, 0.032887283523450606, 0.05104275383928325, 0.024148943630279973, 0.09462417016038671, 0.028023013874189928, 0.05819765487103723, 0.023658137251914013, 0.0716853873746004, 0.04144537429965567, 0.021441369972308166, 0.023249443947861437, 0.10340617431211285, 0.10474190654349513, 0.11840842242236249, 0.06593936835997738, 0.049322062186547555, 0.04736827308079228, 0.031005835262476467, 0.031644230693927966, 0.09420493835932575, 0.049624665480223484, 0.04858549546042923, 0.03371700462594163, 0.015073851445777109, 0.02680126253835624, 0.10173991176998243, 0.04843076138058677, 0.06389624322764575, 0.017786390999390278, 0.02233508275821805, 0.023036716593196616, 0.09862733699264936, 0.020307757949922234, 0.02673570121260127, 0.035783615021500736, 0.040082750347210094, 0.057305927330162376, 0.08950336603447795, 0.01027303449518513, 0.030657844072266016, 0.024388011661358178, 0.04482528180233203, 0.019288429248263128, 0.046370051059057005, 0.020511557268036995, 0.03331485335365869, 0.06620715008466505, 0.028197830470162444, 0.04075858712894842, 0.056503428204450756, 0.08884204566129483, 0.03333739980007522, 0.013258754897833569, 0.059370930976001546, 0.040281315668835305, 0.015015026965556899, 0.027489942185638938, 0.09943814817233942, 0.044113643816672266, 0.032213242739089765, 0.019053610012633726, 0.01938646881171735, 0.0717792022624053, 0.12849589402321726, 0.009010854664666113, 0.05309699634381104, 0.049357050738763064, 0.026417483131808694, 0.03110511606791988, 0.045565670588985085, 0.03452390468737576, 0.03422654095629696, 0.04783141404914204, 0.03486768975562882, 0.0289977543434361, 0.02307712653419003, 0.038822104907012545, 0.06380864011589438, 0.03273400405305438, 0.040005819319048896, 0.012369935648166575, 0.07996615982847288, 0.02979678763949778, 0.027934271565754898, 0.038608978647971526, 0.08240090144681744, 0.02519676709198393, 0.044765019410988316, 0.0373146434139926, 0.02204052248998778, 0.16815078881336376, 0.10059633641503751, 0.1753177386126481, 0.22813729417975992, 0.1595913027995266, 0.11019570491043851, 0.06201383388543036, 0.16397255676565692, 0.23946577770402655, 0.12315329906414263, 0.09055660717422143, 0.13658586773090065, 0.16751459013903514, 0.1010305670206435, 0.15200273890513927, 0.10063212277600542, 0.18113993166480213, 0.12250967149157077, 0.08240643786848523, 0.07991033548023552, 0.0934322364628315, 0.18249162007123232, 0.14651780744316056, 0.24393795960349962, 0.08526046323822811, 0.1676334228250198, 0.19572040240745991, 0.1284684197162278, 0.14244675636291504, 0.14585299155442044, 0.17936895950697362, 0.10999059013556689, 0.13054469658527523, 0.16906487726373598, 0.11039794015232474, 0.12898713641334325, 0.17205727606778964, 0.08257542489445768, 0.16592165920883417, 0.15255314530804753, 0.13506939285434783, 0.15907194785540923, 0.15819870721315965, 0.06144659928395413, 0.14696848404128104, 0.12192507434519939, 0.09265425047487952, 0.23194984038127586, 0.12371252960292622, 0.0882891975925304, 0.18386658222880214, 0.13325265987077728, 0.14105807931628078, 0.16772568662418053, 0.14555806206772104, 0.1238954986911267, 0.12430108239641413, 0.12768579530529678, 0.10020060100941919, 0.09797406892175786, 0.23334351950325072, 0.05207579000853002, 0.20641954470193014, 0.1704240613617003, 0.1100783639412839, 0.14301823975984007, 0.10031026817159727, 0.0895658326044213, 0.10412823205115274, 0.0835872913012281, 0.13278388971230015, 0.13101293239742517, 0.1565541821764782, 0.08296848114696331, 0.22728701558662578, 0.17164905031677336, 0.13667394581716508, 0.12260718227480538, 0.16046448406996205, 0.2510104636894539, 0.19417971867369488, 0.13589329551905394, 0.15225208568153903, 0.11822048094472848, 0.1894814637489617, 0.2652352675795555, 0.14095526217715815, 0.16904993040952832, 0.22692202735925093, 0.32860339852049947, 0.18436408834531903, 0.2637214050628245, 0.2419319047476165, 0.38699679484125227, 0.1973984279902652, 0.18414280959405005, 0.10012664599344134, 0.18801974452799186, 0.15234051999868825, 0.19883099565049633, 0.15255998790962622, 0.1751094771316275, 0.17755206325091422, 0.1893660449422896, 0.15127081802347675, 0.33963667054194957, 0.14652234938694164, 0.24815237877191976, 0.13978330709505826, 0.1445948434411548, 0.14244081918150187, 0.19823285430902615, 0.11493219528347254, 0.22996032057562843, 0.1258946070447564, 0.14734231866896152, 0.16717931750463322, 0.18362726928899065, 0.19746731413761154, 0.16485740459756926, 0.15071716101374477, 0.10253395783365704, 0.2074901817832142, 0.15025659900857136, 0.13568356458563358, 0.1540835280320607, 0.07822323343134485, 0.11130570550449193, 0.09903790050884709, 0.09826041918131523, 0.10639778643962927, 0.13535088946809992, 0.13777973101241514, 0.19691517110913992, 0.15763342817081138, 0.08461738485493697, 0.16022346419049427, 0.11270270944805816, 0.10684924229281023, 0.06909578922204673, 0.18204361520474777, 0.14534344780258834, 0.17462761548813432, 0.15907890920061618, 0.11798958395957015, 0.11001801249221899, 0.10962648506392725, 0.08540550115867518, 0.1447144924895838, 0.394291928387247, 0.14730705181136727, 0.11882249629707076, 0.18034399312455207, 0.10822500596987084, 0.16929133620578796, 0.2139427699148655, 0.10254543885821477, 0.0908598635578528, 0.1386836520396173, 0.09448985627386719, 0.1958753925282508, 0.17546487681102008, 0.13712773943552747, 0.16394287085859105, 0.16110859403852373, 0.15439583861734718, 0.128636620065663, 0.18735262798145413, 0.0926088384585455, 0.18413506157230586, 0.07095731081790291, 0.1471026346553117, 0.15722443058621138, 0.15915802214294672, 0.15192931081401184, 0.10975064637023024], [0.03931903585908003, 0.026934420529869385, 0.07079062444972806, 0.036702234283438884, 0.03830028974334709, 0.06391386923496611, 0.027791910943051334, 0.018424751178827137, 0.014816229722782737, 0.07557835269835778, 0.006667005727649666, 0.0020225064145051874, 0.019593418546719477, 0.023247878016263712, 0.07146217161789536, 0.10192243556957692, 0.05212062314967625, 0.042624090347089805, 0.021833893733855803, 0.020402832633408252, 0.03899690666003153, 0.03059195434616413, 0.025917737584677525, 0.0200589362430037, 0.061173425856395625, 0.07540167702245526, 0.0242790068659815, 0.027003978320863098, 0.025617498031351715, 0.010582407103356672, 0.036612289695767686, 0.013892591687181266, 0.05423811890068464, 0.012171539165137801, 0.03799919300945476, 0.05831107358972076, 0.011714757474692306, 0.019659434437926393, 0.019152636632497888, 0.03135438862955198, 0.057182701129931957, 0.009879945773718646, 0.043346099846530706, 0.018667589320102707, 0.08581289570429362, 0.042412236871314235, 0.024095434782793745, 0.031430529270437546, 0.020368823716125917, 0.06405192354577594, 0.015271823049261002, 0.0548520679876674, 0.011826104673673399, 0.02702354875509627, 0.019154894616804086, 0.061126525833969936, 0.025474771900917403, 0.02679594876099145, 0.04114698269404471, 0.023897309183666948, 0.0330455502262339, 0.02868402996682562, 0.0374545827799011, 0.011004752213921165, 0.03746289854461793, 0.0263307910063304, 0.07270227812114172, 0.06381310042343102, 0.024006831627048086, 0.03969555706134997, 0.04404539962706622, 0.09283663326641545, 0.12051653742673807, 0.05449590018542949, 0.051948563632322475, 0.04815445608983282, 0.042583454051055014, 0.05828943998494651, 0.022418767330236733, 0.04819767134904396, 0.05103637136926409, 0.10123541462235153, 0.04146865918301046, 0.02038472051935969, 0.052223395759938285, 0.0402975835459074, 0.1160950813209638, 0.06330145639367402, 0.056913375738076866, 0.052613182851928286, 0.014932578069419833, 0.07323781930608675, 0.059439438628032804, 0.0661060176207684, 0.046711984468856826, 0.06594875652808696, 0.084538412920665, 0.03073748950555455, 0.04110073947231285, 0.03369816891790833, 0.07383009768091142, 0.04327796326833777, 0.05414874205598608, 0.023988231550902128, 0.011140944661747199, 0.06764676072634757, 0.04509392812906299, 0.01618673250050051, 0.048686639056541026, 0.08049532596487552, 0.0010865431613638066, 0.04662658924644347, 0.055764698117855005, 0.03908649872755632, 0.04270573772373609, 0.08299689056002535, 0.03481022155028768, 0.023611649121448863, 0.04532683262368664, 0.009153866521955933, 0.06452500558225438, 0.02784922886348795, 0.011921753593924223, 0.017423822173441295, 0.09845367443631403, 0.06189043328049593, 0.016165508932317607, 0.015795529761817306, 0.02108877004502574, 0.008266701333923265, 0.011119457631139085, 0.015124912133614998, 0.10900588633376174, 0.020305062098486815, 0.054833521717227995, 0.04834134000702761, 0.041343937555211596, 0.027039436281484086, 0.03468846480245702, 0.07286247069714591, 0.018221677310066298, 0.041494968318147585, 0.08041830587899312, 0.010949534571409458, 0.07237836776766926, 0.0036141882173978956, 0.03293824309366755, 0.02298423005413497, 0.06930618808837608, 0.043772241042461246, 0.06825705102528445, 0.023200395407911856, 0.006958407693673507, 0.009948028546205023, 0.027691444556694478, 0.11030233668861911, 0.011064134232583456, 0.031796270777704194, 0.03390676065464504, 0.01945773354236735, 0.055656058830209076, 0.09338710646261461, 0.03568809319403954, 0.06781470132409595, 0.01979811586352298, 0.018849894186132587, 0.017491784346930217, 0.03888343599101063, 0.02553070200519869, 0.027782500510511454, 0.020758378886966966, 0.021198897338763345, 0.022861220932099968, 0.019399576995056123, 0.072181186551461, 0.06679744692519307, 0.03346356490510516, 0.06602237757761031, 0.004321576479924261, 0.08395548560656607, 0.02226808537670877, 0.0415347363014007, 0.024227140020229854, 0.0456295398180373, 0.00965068893492571, 0.03417248291953001, 0.02560450302553363, 0.031750988637213595, 0.044143077393528074, 0.039695100640528835, 0.05991634643578436, 0.09224398381775245, 0.04846092968364246, 0.02768435333564412, 0.020315621004556306, 0.008705211348569719, 0.013085250975564122, 0.05554095172556117, 0.06596136561711319, 0.034377430711174384, 0.07568371540401131, 0.06434381022700109, 0.046241696618380956, 0.026210737487417646, 0.010891373385675251, 0.03402331865800079, 0.02499215512216324, 0.06162445126392413, 0.018014924244198482, 0.034032528710667975, 0.08716149677638896, 0.047549884038744494, 0.014721463958267123, 0.03901884083461482, 0.003388560248822614, 0.04948551650159061, 0.026408326884848066, 0.022236245386011433, 0.0437993628293043, 0.05991573787468951, 0.015662546175008174, 0.015834616824577097, 0.02111308651365107, 0.007993232902663294, 0.029398285878414754, 0.049698984148562886, 0.08043731970246881, 0.03739837993634865, 0.0321585687197512, 0.07187072391388938, 0.044545577475219034, 0.07417273242026567, 0.07885912040364929, 0.045263056163094006, 0.037792753500980325, 0.03321303811389953, 0.015604326545144431, 0.041259280769736506, 0.024249886846519075, 0.014213168869900983, 0.06237444715225138, 0.04981320809747558, 0.030416304689424578, 0.015067158201418351, 0.101646653492935, 0.025980556674767286, 0.06075931487430353, 0.08214783651055768, 0.11715117972926237, 0.027460469646030106, 0.03391310972801875, 0.08443776285275817, 0.021662780454789754, 0.039549598877783865, 0.0579131340055028, 0.016727602305763867, 0.04257672277162783, 0.04292969933885615, 0.05325578626070637, 0.03292397530458402, 0.11596148731769063, 0.030979633738752455, 0.050827727682190016, 0.05777711317932699, 0.025695315925986506, 0.0436104008986149, 0.02278588552144356, 0.0060322723311401205, 0.01916023622470675, 0.05402029484685045, 0.11140070782857947, 0.026062265278596897, 0.05929399994784035, 0.037401853187475353, 0.09021182762808166, 0.0366557535744505, 0.03275518123700749, 0.05703302478650585, 0.0571749011578504, 0.036572892786352895, 0.07347578153712675, 0.028627931023947895, 0.040193801614805125, 0.03366234173881821, 0.0786428437277209, 0.04109877649170812, 0.04350389899627771, 0.03718392523296643, 0.05228519068623427, 0.03695706924190745, 0.024944661381596234, 0.06126836880866904, 0.008635635931568686, 0.038907255220692605, 0.07863421997171827, 0.020121968700550497, 0.023034762889437843, 0.01353684227069607, 0.05537446202652063, 0.10288764315191656, 0.019415826318436302, 0.026181470893789083, 0.025949167538783513, 0.041276940173702314, 0.023616942489752546, 0.01468784837925341, 0.002884653108594648, 0.022514715892612003, 0.09452885613427497, 0.028451995640352834, 0.04176941823970992, 0.10106454996275716, 0.010813151020556688, 0.014751379003428156, 0.061426557585946284, 0.020461601452552713, 0.01104685054087895, 0.037619755166815594, 0.06305740855168551, 0.038491077357321046, 0.0742983706004452, 0.07510655457735993, 0.046536633526557125, 0.03220148711989168, 0.06780408119084314, 0.03797813456912991, 0.06883842725073919, 0.02455420450132806, 0.06287843221798539, 0.05673946456226986, 0.019257949243183248, 0.06605627888347954, 0.002434248322060739, 0.01960538011189783, 0.06298919033724815, 0.0712490787554998, 0.035773777854046784, 0.02011791100812843, 0.052781542763113976, 0.03480586514342576, 0.010095599045598647, 0.031214293412631378, 0.02357436176680494, 0.02192636347899679, 0.03865227925416548, 0.01821347286750097, 0.03237591408833396, 0.019253676327934954, 0.05672311133821495, 0.036837891457253136, 0.07407359633361921, 0.039543183011119254, 0.15263717126799747, 0.1648524173651822, 0.14437590987654403, 0.15950758854160085, 0.1382555515738204, 0.16174277407117188, 0.14316997927380726, 0.16876638546818867, 0.10309073186363094, 0.15581268758978695, 0.12150689639383927, 0.05624172837997321, 0.10943785338895395, 0.12129799666581675, 0.18981841363711283, 0.173110457835719, 0.15665291750337929, 0.18910596671048552, 0.10805328784044832, 0.17129152809502557, 0.07926481543108821, 0.14329805911984295, 0.09800556566915475, 0.16609196725767106, 0.18133171746740118, 0.20063969859620556, 0.15896816592430696, 0.13765580719336867, 0.08020848588785157, 0.07242742372909561, 0.12734074116451666, 0.11919298383872956, 0.16576493246247992, 0.14120107633061707, 0.1261545516899787, 0.16810628963867202, 0.06047815964848269, 0.08731696187169291, 0.07806746405549347, 0.1818894117604941, 0.11765011819079518, 0.07757352024782449, 0.10914370315731503, 0.13306534179719165, 0.14154144009808078, 0.10966513611492701, 0.04240212881995831, 0.24288976506795734, 0.06388852489180863, 0.11096459958935156, 0.12226373859448358, 0.13729598431382328, 0.15916191099677235, 0.11390498868422583, 0.1708305356441997, 0.08701721584657207, 0.16914158564759418, 0.09827339934417978, 0.14166580920573324, 0.1373868083464913, 0.15279035054845735, 0.12861572118708864, 0.0889645074494183, 0.12497967254603282, 0.26973069354426116, 0.11306918939226307, 0.12699135288130492, 0.21264631213853136, 0.1807532281964086, 0.16747994668548927, 0.10605383809888735, 0.15316942473873496, 0.2364293546997942, 0.1823879568837583, 0.18342558323638514, 0.1945659620105289, 0.10308336233720183, 0.12058725667884573, 0.2034506868221797, 0.1507260074140504, 0.11891329064383171, 0.16333707055309787, 0.19517125765560195, 0.2638790075434372, 0.15704730962170288, 0.15539356711087748, 0.17488221667008474, 0.21441571094328538, 0.2650379453552887, 0.24021591088967398, 0.16093711339635774, 0.15132981876377016, 0.1753836264833808, 0.19593970704590902, 0.17821926885517314, 0.1489915934507735, 0.14839585666777566, 0.12879365851404145, 0.14837031194474548, 0.1150512506137602, 0.10282139162882231, 0.12075326769263484, 0.11004262210917659, 0.15839585132198408, 0.15768218727316707, 0.16536188690224662, 0.12667645962210372, 0.09370425585075282, 0.23098797246348113, 0.18128475436242297, 0.13294244214193895, 0.13594373187515885, 0.17680672433925793, 0.08262753850431181, 0.14916757150785998, 0.21019479056121781, 0.09279559992137365, 0.14476825366728008, 0.12298866102355532, 0.15741468756459653, 0.20356757508125156, 0.11965886704274453, 0.2221252300660126, 0.1534526579780504, 0.14642379217548296, 0.18610216851811856, 0.09023724618600681, 0.11746474454412237, 0.12074123747879639, 0.07173238758696243, 0.10014891784521751, 0.1299311631009914, 0.22944650205317885, 0.1574620811152272, 0.14580589486286044, 0.1497357597691007, 0.09700904687633738, 0.11218355488381349, 0.1265051422524266, 0.14912890561390668, 0.2170919845229946, 0.1719904679339379, 0.19117792428005487, 0.18049458973109722, 0.15130105311982334, 0.13128577556926757, 0.14482845668680966, 0.13342422957066447, 0.13829096686095, 0.11893601520569064, 0.16193843388464302, 0.13910974870668724, 0.09536147903418168, 0.17853904544608667, 0.0822637822420802, 0.1869167943368666, 0.04599315507221036, 0.12178704972029664, 0.15435594075825065, 0.21549197350395843, 0.15093455091118813, 0.197271698853001, 0.15283663087757304, 0.1767973435926251, 0.12178663411759771, 0.1297158215311356, 0.2401293467846699, 0.12039619075949304, 0.07986083423020318, 0.1267635283875279, 0.10769606989924796, 0.06962578656384721, 0.1542628457536921, 0.1984060715767555, 0.16273085464490578, 0.1263947700499557], [0.03898539594956674, 0.03200341161573306, 0.043054569396190345, 0.036445317600737326, 0.06687352448352613, 0.010720288864831673, 0.035905728000216186, 0.07745380440610461, 0.03318779024994001, 0.02725044370890828, 0.04591292890836485, 0.03903854114469141, 0.02184804092394188, 0.04874310536251869, 0.015037250577734085, 0.031815240072319284, 0.011818268521892605, 0.057063122585532255, 0.060326494349283166, 0.06296581268543378, 0.03770808929402847, 0.047073777750483714, 0.014284457720350474, 0.03300088406831492, 0.037308602331904694, 0.04910381139779929, 0.037755768571514636, 0.05159867068869062, 0.04910210074740462, 0.01979644974198891, 0.030069506501604337, 0.0754673793562688, 0.05387367615185212, 0.05567559215705842, 0.04482701842789538, 0.02441167689539725, 0.02283135134348413, 0.01974512095330283, 0.04497258327319287, 0.0448816145217279, 0.01782809598807944, 0.026069399173138663, 0.06326650865958072, 0.056132391473511234, 0.014585401386284502, 0.03446667025855277, 0.0417074971483089, 0.02077106404613005, 0.04590026044752449, 0.019298028928460553, 0.024538938523619436, 0.012690656621998642, 0.03275782699347474, 0.030231487653509248, 0.03159620631777216, 0.02458017595927231, 0.033603174015297554, 0.005823337351102964, 0.01614245597011177, 0.017163022203021683, 0.052523772610584274, 0.15668070351239294, 0.042056466118083335, 0.040156527247745544, 0.054366699696402065, 0.017151986467069946, 0.08222462653066032, 0.03563047655916307, 0.03979281180363614, 0.05996903149934951, 0.03421485213038977, 0.050635529987630434, 0.023242020615725778, 0.044581393522094004, 0.034463924312149175, 0.016156258061528206, 0.03627612648415379, 0.02425546965241665, 0.06559100424055941, 0.003926823492292897, 0.024776794998615514, 0.05924481782130897, 0.06402469414751977, 0.05582955440331716, 0.029674288743990473, 0.04191053762042429, 0.06387423112755641, 0.015192041246336885, 0.17659157572779804, 0.05744069392676465, 0.04945470624079462, 0.05631834399537183, 0.055957111035240814, 0.02317300644790521, 0.06653920179815032, 0.07402459974400699, 0.07647331600310281, 0.04280507790099364, 0.07584290608065203, 0.01022629403450992, 0.016246792656602338, 0.0399660476250574, 0.04402513899549376, 0.06775918125640601, 0.054134841630002484, 0.06691063186735846, 0.030992810570751317, 0.007939099723444087, 0.02284447993588401, 0.025648792543506715, 0.0723659442155622, 0.040666052445885725, 0.007093155736583867, 0.0400391046423465, 0.041242489678552374, 0.041435559396632016, 0.0183634980203351, 0.02514116724341875, 0.05114192703331355, 0.02078279183479026, 0.03115407183940988, 0.04663976978918072, 0.05083474097773433, 0.031312776409322396, 0.0099853038409492, 0.0030667469263789826, 0.06112809918704443, 0.06170659216877539, 0.03246421481890138, 0.04781319061294198, 0.03780467239266727, 0.06118450983194634, 0.037383859817055054, 0.025692378876556177, 0.028026201398461126, 0.032605070737190545, 0.07728121054242365, 0.08005313211469911, 0.039056694076862186, 0.02006227405217942, 0.017739793402142823, 0.07628304418176413, 0.10721578903030604, 0.015419969640788622, 0.012021924048895016, 0.006213397646206431, 0.019271107521490194, 0.05538295219594147, 0.055153947687358595, 0.02308232713403413, 0.028895395480503794, 0.06214244065631647, 0.04090071583050303, 0.06824749216320924, 0.010298236902599456, 0.013487407813954633, 0.006788986975152511, 0.0029140289370843675, 0.039025041478453204, 0.022809758556832094, 0.0698294689937029, 0.0315790441527497, 0.041471868971711956, 0.023334191646426916, 0.053960410950821824, 0.035545088758226484, 0.0809717847732827, 0.030841113730275538, 0.05134409548190888, 0.008619456184533192, 0.045280303675099276, 0.022848146145406645, 0.0758970680180937, 0.06207409256603569, 0.05032051798480097, 0.02436956187011674, 0.04069140792125836, 0.031196504132822156, 0.02568795382103417, 0.025262371091230307, 0.043257713768980466, 0.026446402771398425, 0.0472236359200906, 0.057668926601763815, 0.029539987845055293, 0.03195867866452318, 0.009431210819457192, 0.027954534052696545, 0.03990231198258698, 0.039993629543459974, 0.015753952793602366, 0.03462882952590007, 0.010955845609714743, 0.043868634893442504, 0.05520038757822476, 0.030319515644805506, 0.018297632414032705, 0.05229992231761571, 0.02303807657881407, 0.014275523190008244, 0.05415761443146039, 0.019725533820746932, 0.012605715037352638, 0.023838974520913325, 0.04544136085314676, 0.06191687600221485, 0.033253704095841385, 0.02581186650786549, 0.015295671037165448, 0.04598561856255401, 0.033443341380916536, 0.09070238724234514, 0.010928144947683904, 0.04697508324170485, 0.04354813841928262, 0.00962911934038857, 0.03180170700943563, 0.11943559933570214, 0.08022705442272127, 0.09950171312084422, 0.03228331632271875, 0.027180067700101063, 0.09647477476391941, 0.04290717886760831, 0.027668937073030975, 0.019279701591585763, 0.08353876968612894, 0.029849099773855414, 0.02725174061197322, 0.06325598500552587, 0.02159934909286676, 0.06315827384241857, 0.027056396211264655, 0.04730925378680695, 0.024132044927682728, 0.026467045609024353, 0.03330634834128432, 0.02488260670361342, 0.049427350677433424, 0.0877402606420219, 0.014336691929202061, 0.0803534644364845, 0.033773957038647495, 0.027008384822693188, 0.07491339580155909, 0.03751543517864775, 0.029236009722808376, 0.13405257632257417, 0.04037976897961926, 0.013917463838879485, 0.042715771560324356, 0.00947334161537583, 0.03881112854287494, 0.08571948899771087, 0.015190821341093397, 0.02169405826862203, 0.03870874556014314, 0.016917699722398538, 0.004479351973714074, 0.037735374353360385, 0.03274726994277444, 0.0513297720317496, 0.02848493957571918, 0.05633117943943944, 0.14456299046287313, 0.03763812703255098, 0.044267301782383583, 0.03174989025865216, 0.036163884069537744, 0.01115541654144181, 0.06254500753129832, 0.0515603202074999, 0.038250016659731045, 0.03902025091520045, 0.06870738623547368, 0.040020539818215184, 0.04011638447991572, 0.07472633005818352, 0.04254766397934873, 0.03133081059786491, 0.01029182660204242, 0.018902172923844773, 0.05297430820064619, 0.008960953582572984, 0.049195462925126776, 0.0407681088836398, 0.021109848894411698, 0.05045531055657193, 0.05012279871152714, 0.014195467720128363, 0.026668228856578935, 0.0483294359582942, 0.03732882585609332, 0.01896305871923687, 0.020451434029382654, 0.024951526247605216, 0.03326403850223869, 0.044880798159283586, 0.07214789380668662, 0.03628374091931619, 0.03403419854294043, 0.029970340729050804, 0.018774453019432258, 0.01662985403527273, 0.018595977635413874, 0.046070535099715926, 0.10595622341497801, 0.011300514761387603, 0.0056030155064945575, 0.016092821133497637, 0.0227357256153482, 0.05841246951604262, 0.039989351062104106, 0.05162482397281565, 0.02999111900862772, 0.07445203969837166, 0.010073905141325668, 0.06174870162794832, 0.0755316048162058, 0.017256057835766114, 0.035127853334415704, 0.023911894240882248, 0.02306381426024018, 0.06666833549388684, 0.04846595773415174, 0.022521710634464398, 0.048854357009986416, 0.02888479761168128, 0.08670423732837662, 0.05321217395248823, 0.08828023244859651, 0.0419510588835692, 0.042206268626614474, 0.014700254305353155, 0.043853027527802624, 0.02074839885608526, 0.05388348734413739, 0.022056560301280115, 0.0751732662320137, 0.03605347104894463, 0.07405010735965334, 0.02043456130195409, 0.03743987712368835, 0.019447547565505374, 0.03163053435855545, 0.03732259923708625, 0.029090092357364483, 0.03303773912193719, 0.03342928510392085, 0.06417949130991474, 0.08475932059809566, 0.04822678580239881, 0.16508703993167728, 0.19473950582323596, 0.10444619038025849, 0.20696506777312607, 0.11844043125165626, 0.1468162695528008, 0.11640237498795614, 0.18247901840368286, 0.1655751801445149, 0.12254404035047628, 0.1578972616698593, 0.07317927869735286, 0.08306835195980966, 0.10648417242919095, 0.10074133722810075, 0.12247590377228335, 0.05931350358878262, 0.10726045147748664, 0.15107162558706477, 0.11032701309886761, 0.07466021954314783, 0.11468499331385829, 0.08555914057069458, 0.11928238294785842, 0.12866354518337175, 0.13533616525819525, 0.10738902856246568, 0.08442339487373829, 0.14876510482281446, 0.1416290135239251, 0.1086836977628991, 0.1721390162128955, 0.12052332065650262, 0.16182672581635416, 0.17867784190457314, 0.18092110200086609, 0.06471656131907366, 0.15804313821718097, 0.09746007228386588, 0.1819461860577576, 0.08898620784748346, 0.2571364474715665, 0.17611728399060667, 0.1710317170363851, 0.1147958033834584, 0.18929043493699282, 0.18398244632408023, 0.12086939896107651, 0.06471211585449055, 0.1335258295875974, 0.1862568617798388, 0.13325706822797656, 0.1023546549549792, 0.16147407208336517, 0.09887905122013763, 0.24260291014797986, 0.10350512486184016, 0.08725259540369734, 0.08700984632014297, 0.15179125650320202, 0.08554260552045889, 0.23071134433848783, 0.1181241575977765, 0.20263462123693898, 0.11938919284148142, 0.18575617927126586, 0.18446224479703233, 0.12598431785590947, 0.1585784790222533, 0.1279883095412515, 0.14439219259656966, 0.26812602183781564, 0.09898917109239846, 0.11684655779390596, 0.09882078520604409, 0.0902735446288716, 0.14394825469935313, 0.19742026197491214, 0.24838403274770826, 0.10539213923038915, 0.14997179241618142, 0.12588494428200647, 0.13662845216458663, 0.10360527026932687, 0.14283191616414115, 0.11589591114898212, 0.1542538806097582, 0.15755229658680037, 0.37578481365926564, 0.19889045652234927, 0.11969702085480094, 0.16742351377615705, 0.15041114384075627, 0.10872992614167742, 0.14964885427616537, 0.19418224197579548, 0.16668250900693238, 0.173811728018336, 0.18817097938153893, 0.13873401418095455, 0.11544106368091889, 0.16084872360806912, 0.09984258897020482, 0.129276143561583, 0.09872041715425439, 0.10775564209325239, 0.15940137236611918, 0.06439746750402264, 0.18851594446459785, 0.09488430034252815, 0.1874011495965533, 0.1323033045628108, 0.12895280466182157, 0.11317628130200319, 0.14837146969512105, 0.1117729394172784, 0.12785678612999618, 0.11372339999070391, 0.08907177005312406, 0.2067156764678657, 0.13970438711112365, 0.14696740050567314, 0.15993004868505523, 0.1269081432837993, 0.1144823053618893, 0.21400910307420418, 0.22934595588594675, 0.09763965717866085, 0.1879233098588884, 0.16078014916274697, 0.16299247654387727, 0.1442215431598015, 0.07740809553069994, 0.06668530098977499, 0.14248469495214522, 0.12471033231122419, 0.1477299424004741, 0.15214411803754047, 0.1791130076162517, 0.1682003345922567, 0.09162927774013951, 0.18863633566070348, 0.15651311172405258, 0.09583565944922157, 0.12512678105849773, 0.07980256079463288, 0.10401705090771429, 0.1411416896735318, 0.12778481264831498, 0.15649835782824084, 0.14058922010008246, 0.1816436421358958, 0.114570502191782, 0.19506459619151428, 0.13077715208055452, 0.07921756288851611, 0.13422085088677704, 0.06670467104413547, 0.07450484350556508, 0.11240574647672474, 0.15383051504613832, 0.11461782152764499, 0.2114457546849735, 0.12001841532764956, 0.27285056363325566, 0.11108654187410139, 0.19807336677331477, 0.19940022291848436, 0.10259866568958387, 0.09853923664195463, 0.11515830541611649, 0.14750660047866404, 0.13739319081651047, 0.14140628016320989, 0.13202033849665895, 0.13777553045656532], [0.0858264027920086, 0.04340832892921753, 0.04714043374406174, 0.019975734066974837, 0.029153358591429424, 0.020855715265497565, 0.032188570039579645, 0.056686200623516925, 0.0183814913907554, 0.03506767257931642, 0.020116094601689838, 0.08754590700846165, 0.01747324364259839, 0.014262737840908812, 0.10290048230672255, 0.042867054653470404, 0.010287808800057974, 0.03699136017530691, 0.046722619445063174, 0.04642520005290862, 0.017310947077930905, 0.0016207097496589995, 0.026687118370318785, 0.011781995126511902, 0.028749748998961877, 0.046191327055566944, 0.0768816530762706, 0.01028815946483519, 0.04969821231497917, 0.012770843823091127, 0.04751031272462569, 0.047283898311434314, 0.07770022712065838, 0.009909481395879993, 0.019851324141200166, 0.032653911475790665, 0.083352097281022, 0.02809141020406969, 0.037729452014900744, 0.03548294131178409, 0.027512911656231154, 0.04955733413225971, 0.05804841639474034, 0.03874357083986979, 0.07371716506895609, 0.019848773008561693, 0.05086482022306882, 0.05738203828514088, 0.01855698890722124, 0.059464664227562025, 0.05441326575237326, 0.02453734661685303, 0.03835922369034961, 0.0341697629482951, 0.01761588813678827, 0.04031645265058614, 0.0530360994162038, 0.03900115916621871, 0.09252677176846191, 0.042961912258761004, 0.04300007720303256, 0.09236143610905856, 0.04307145325583406, 0.028031259134877473, 0.02096869797242107, 0.06615059843170457, 0.060362262156559154, 0.018911047154688276, 0.008901426845113747, 0.06643066270044073, 0.018565017089713365, 0.03915631998097524, 0.037333148866309784, 0.02301113105204422, 0.032449312493554316, 0.031656980791012757, 0.02281502038385952, 0.031140616702032275, 0.008013284805201693, 0.030072922236286104, 0.02743444809311768, 0.032486390191479586, 0.04787538629898336, 0.02599434392323019, 0.04935392629704438, 0.02492934716428863, 0.01701378929283237, 0.018957153079099953, 0.02074175477901008, 0.0589579369261628, 0.041857752366922796, 0.026103714226337615, 0.06920512983924709, 0.05196531019464601, 0.035691748271347024, 0.030924573802622035, 0.048843521653907374, 0.023590800337842666, 0.09533856151392683, 0.02254723309306428, 0.024058043527475093, 0.03421209876250941, 0.048675655270926654, 0.026933388944598846, 0.038754996203351766, 0.031048634918988682, 0.024136653664754704, 0.013084027359582251, 0.08497318529407494, 0.09162092115730047, 0.017068042143364437, 0.011174276369274594, 0.03377991648449097, 0.04218283902446274, 0.06354168217512779, 0.02667139226105064, 0.04144508115132339, 0.07875200622947887, 0.03914942171832081, 0.018268666390213184, 0.04076729994267225, 0.0724660450941883, 0.027917857114516664, 0.08590363067924045, 0.023750794389343355, 0.03757988328288775, 0.055063450199668296, 0.09519200961221941, 0.03624050339567475, 0.029513756635424215, 0.03444052068516612, 0.018787345979944803, 0.0485705189203145, 0.010473162965354277, 0.012421017672750168, 0.01725976115267258, 0.012106038138881559, 0.042102334555238485, 0.03603584133088589, 0.05161465654964559, 0.029961377440486103, 0.01263543990717153, 0.06312938945484348, 0.0109476439502032, 0.021376710355980322, 0.041508430877001956, 0.04658885103708599, 0.02480668499629246, 0.01311436821197276, 0.049101384574896656, 0.043047110812040046, 0.011081287120759953, 0.04050787480082363, 0.04468583225389011, 0.06264079653192312, 0.0292952961899573, 0.008578884826420108, 0.06682333303615451, 0.0777973816730082, 0.038011998767615296, 0.023368276633846108, 0.03969683726609219, 0.01691957364528207, 0.04929643953801133, 0.063848916470306, 0.03286288170784246, 0.03751521995582152, 0.02174673219997203, 0.061265233234735206, 0.0396604052366456, 0.13874501280952245, 0.0863420544192195, 0.028749210941896308, 0.07120091337128542, 0.04044225410325453, 0.10631541546899825, 0.015539236483164132, 0.07929565908852965, 0.031800564102013595, 0.034282907072338276, 0.0692071855883114, 0.007943937598611228, 0.01785728094546357, 0.08199050862458535, 0.04986488384020049, 0.0418081101088319, 0.03557519768946804, 0.023352732350758743, 0.05726938397856429, 0.010256970708724111, 0.052532277622958645, 0.025912709534168243, 0.08940397019614466, 0.03526894673996139, 0.020133199250267353, 0.031004441880213562, 0.03840636491077021, 0.0582061821478419, 0.01541284595077741, 0.01955931500560837, 0.027775704293162562, 0.005565881219808944, 0.010954054250760237, 0.04811336337297689, 0.012031301084789447, 0.059683126528398134, 0.0307646780856885, 0.024859306977305096, 0.07368914157268591, 0.04449416519491933, 0.024071452280622907, 0.019785723852692172, 0.060986382377450354, 0.03318247647257522, 0.009261255290766712, 0.0503350752114784, 0.023471142012567725, 0.08027971722185612, 0.12490216264268383, 0.008794459245109465, 0.04402358419611119, 0.035834162699757144, 0.04908762886771001, 0.02452370223181788, 0.03851393921650015, 0.07273954135598615, 0.06146589512354694, 0.03865487677103374, 0.0159342538609053, 0.06585029579582624, 0.03394995364942588, 0.03535271294822451, 0.013058380591246532, 0.11236727354116738, 0.04990395791537594, 0.04987040170817636, 0.02668564520718064, 0.0511487993207993, 0.05638132264721207, 0.03550764740793966, 0.08081916210358031, 0.09143595569184981, 0.040056333600659855, 0.02272022029501386, 0.00806522029961343, 0.08452339185168967, 0.055316214566119015, 0.020104567192902323, 0.014369917880685534, 0.025441414218221325, 0.03953736828407273, 0.07315221257158555, 0.05973485422146041, 0.024470751850458328, 0.011202702480659354, 0.0221739068365423, 0.04456447626580484, 0.005458093546621967, 0.057306443122797646, 0.04150496133661363, 0.08517084148479626, 0.10964230023091659, 0.07881756755523384, 0.03088264616962988, 0.024318158866662998, 0.031075996048457455, 0.07280110992724076, 0.018946931850223336, 0.05578382326348219, 0.08660711246193387, 0.007624966701769154, 0.012551237687148387, 0.04972104819898959, 0.011811343356384896, 0.057183409880963154, 0.016449348877358716, 0.02406588988378644, 0.052938117369194515, 0.025895174439938273, 0.054405855407821946, 0.05275417977827601, 0.07737817213637754, 0.0590583940356737, 0.030734144274902064, 0.08810609491774812, 0.08210641724872403, 0.07099029928212985, 0.015815693914191797, 0.017822557711042464, 0.04292197358154226, 0.038313878467306495, 0.03510315094899852, 0.012125196681154193, 0.05897572991671041, 0.07454103062627837, 0.018814720096997917, 0.036135333648417145, 0.0647040709736757, 0.00976863011601381, 0.03122784873994533, 0.021241459508019034, 0.04329752628109418, 0.04690007437602617, 0.04400597303174436, 0.03866228711558506, 0.053123876932659186, 0.05739251369959675, 0.052101754044997506, 0.09435772430151701, 0.005693388684449019, 0.036252719146432355, 0.009446653057239018, 0.030551438649126794, 0.03638806090748403, 0.041158382082358, 0.023028703253658023, 0.047528287541354075, 0.020688372096628882, 0.032129517348948866, 0.027436095660959836, 0.04690833819040563, 0.06373138996423222, 0.07174510057666339, 0.0706614091177471, 0.012719893529720139, 0.017757328496372793, 0.043379607814131305, 0.0084170799345884, 0.03549194356310181, 0.023983342653082218, 0.04571708726871293, 0.034222967515233904, 0.05451967488625087, 0.05239344776782673, 0.021089950059831608, 0.05227454086707439, 0.026124034229724202, 0.05430989200249314, 0.0145189838076476, 0.030696012727275956, 0.09121132985455915, 0.01153596389485756, 0.024298443713632878, 0.054573376692133024, 0.03364937270816881, 0.06735282571753487, 0.06655477205640636, 0.04889646275842097, 0.035490522350301035, 0.02807240565743996, 0.011978592829109402, 0.052558349270839244, 0.1224365179950837, 0.21277633641147986, 0.2560833696043119, 0.22456811304436997, 0.23403870407491922, 0.09943140947143547, 0.07402215065667406, 0.16583168122451752, 0.08518720584106632, 0.1742335202288814, 0.13239994703326374, 0.18252733221743256, 0.1112283811380621, 0.1278618475771509, 0.17391781060723588, 0.23210155020933598, 0.22419064189307392, 0.10375473881140351, 0.18492777919163927, 0.10133133720955811, 0.11441176422522403, 0.09833411444560625, 0.12840976036386564, 0.09176833395031281, 0.10472392430528998, 0.10890391524299048, 0.15406316349981353, 0.14069499098695815, 0.11782417408539914, 0.11569038077141158, 0.1083092026237864, 0.1444239862030372, 0.1366103140753694, 0.12932086538057774, 0.14503584243357182, 0.11003984647686593, 0.1627498387824744, 0.10829502760316245, 0.10899100627284497, 0.14552990498486906, 0.11662300064926967, 0.18980309570906684, 0.1771273321355693, 0.09535495555610396, 0.14389667543582618, 0.1893729023868218, 0.12877085973741487, 0.14269571722252294, 0.1058750473021064, 0.1660391263430938, 0.11332510417560115, 0.19419286953052506, 0.12004812349914573, 0.14453222102019936, 0.09294457122450694, 0.09048228850588202, 0.11650959306280129, 0.29213078843895346, 0.14707290421938524, 0.18167340225772932, 0.14322094997623935, 0.13994107284815982, 0.16808156127808616, 0.1022887002909556, 0.1353339388151653, 0.17963338672416285, 0.10663817549357191, 0.1262275196495466, 0.1121680143114645, 0.1793784589972347, 0.11542900378117338, 0.17101573117543012, 0.0914796013967134, 0.16852186265168712, 0.16791877860669047, 0.12529486266430467, 0.09092471984331496, 0.04688727232860401, 0.10558258174569346, 0.20248911576345563, 0.1116489339619875, 0.15614611969795078, 0.14215580478776246, 0.1019280165201053, 0.17538252810481936, 0.278220625477843, 0.16303690150380135, 0.1353343395749107, 0.1516725870897062, 0.1300361324683763, 0.15742617601063102, 0.1856056271935813, 0.1808378627174534, 0.15459669346455485, 0.1291128562297672, 0.09215197234880179, 0.14857711881631985, 0.1066918253491167, 0.20601853262633085, 0.12150271068094298, 0.12890722195152193, 0.16242712328676134, 0.13398140436038375, 0.14144962158752605, 0.08736301213502884, 0.12620811990927905, 0.16970397031400353, 0.1743160915793851, 0.20996920735342428, 0.208246341207996, 0.22686072596115991, 0.1763871288858354, 0.112098719982896, 0.16132791351992637, 0.1814384531462565, 0.10671409720089287, 0.08989494541310705, 0.21066323417471722, 0.16741475643357262, 0.10810153486090712, 0.24936224275734276, 0.19185701909009367, 0.08521709954948165, 0.14220874960301444, 0.10879617024329491, 0.11591407892410643, 0.09735145897138864, 0.1711846439866349, 0.10474387323483825, 0.2854630962247029, 0.16767128719948232, 0.08026174240512773, 0.18575690657598898, 0.14522939454764128, 0.12302132294280455, 0.18817486823536456, 0.11737464039470069, 0.12731212395010516, 0.19524473027558997, 0.0855747850437183, 0.12170035945018753, 0.09621533477911726, 0.09346139544504695, 0.11757536165532656, 0.14683382876683027, 0.12835190253099427, 0.14671037992229685, 0.17580746702151373, 0.19604571542004123, 0.1360759380622767, 0.14470045105554163, 0.12026284166495316, 0.1567705033812672, 0.15273684170097113, 0.12282315467018634, 0.10633150523062795, 0.12168605084298179, 0.1900912864948623, 0.17699367133900523, 0.08627552088000812, 0.16127015958772972, 0.09152242331765592, 0.08890961820725352, 0.056779418082442135, 0.15936775307636708, 0.13762824382865801, 0.11891808491782285, 0.15281702333595604, 0.1466070135938935, 0.13841043779393658, 0.24120506015606225, 0.15698390052421018, 0.1204113379935734, 0.16616641951259226, 0.16004183096811175, 0.14361746463691816], [0.011464617527963128, 0.025725012965267524, 0.06843663592007942, 0.011307508575555403, 0.01146265176430461, 0.023053195982356556, 0.043364011580706574, 0.024849152541719377, 0.051347579865250736, 0.033725045796018094, 0.0708809809293598, 0.039059859336703084, 0.05651953651977237, 0.058850047207670286, 0.058370278420625255, 0.005766172962466953, 0.02783085514238337, 0.08494907291606069, 0.03331557694764342, 0.008582859027228551, 0.027192726884095464, 0.07266079948749393, 0.07263442355906591, 0.036871180491289124, 0.06791077234083787, 0.04822337563382462, 0.009341066779597895, 0.0545780967513565, 0.021229334670351818, 0.028119405869801994, 0.08346915623405948, 0.016686014205333777, 0.01856661827332573, 0.000503448690096775, 0.03412017264054157, 0.022286659477686044, 0.012629986049432773, 0.05807330060633831, 0.05487221358634997, 0.05634618937619962, 0.04112762748263776, 0.024964758740679827, 0.07111644954420626, 0.09266454406315461, 0.023409725581586827, 0.04018391620775219, 0.03202419917215593, 0.02515835909434827, 0.025066228881769348, 0.06614748141146265, 0.02967562646517763, 0.050239122938364744, 0.029571351005870383, 0.03967374163039494, 0.06873827442177571, 0.06008629083225969, 0.0787307956488803, 0.07788793111103587, 0.06800962641136721, 0.009792805576580577, 0.060090391198173165, 0.02245817166112829, 0.014356546234921552, 0.02914221338869538, 0.04635583893104922, 0.01797367567633046, 0.017337456592940725, 0.04932827396260109, 0.03832665825029835, 0.04596982565999497, 0.04606703216268215, 0.08998755060019903, 0.03441090899286792, 0.04741849050333258, 0.020815672687604092, 0.006969938349357108, 0.014245891088648932, 0.011130949787911959, 0.03801226594077889, 0.04306012066081166, 0.015381846442323877, 0.05963821917248424, 0.061391891867970116, 0.028729547739203554, 0.03882768956827931, 0.011867617631651228, 0.009354719513794407, 0.02179937273467658, 0.031673378543928266, 0.09407184159499593, 0.010419701429782435, 0.016950400604400784, 0.07663615804631263, 0.03159361622238066, 0.04255412066413555, 0.03494470984151121, 0.040412185990135185, 0.06362224230542779, 0.044037020779796876, 0.04794791639142204, 0.08214054862037301, 0.02330393614101922, 0.026747390038508456, 0.06909771880600601, 0.051688270177692175, 0.06263880015467294, 0.025647326801845338, 0.06436125811887905, 0.02460036052070791, 0.1247659043292515, 0.02813149731082376, 0.01210275784615078, 0.03250443551223725, 0.04894219389825594, 0.009538939120830037, 0.026218170096399263, 0.017058288467524108, 0.02499036469089333, 0.09142921699094586, 0.030337110110849608, 0.09033339883899316, 0.07245932123623788, 0.026717368309618905, 0.058459892752580345, 0.01942991784744663, 0.03163907276757527, 0.019171628191543277, 0.055417373005184345, 0.03569149965187535, 0.044439086705097, 0.030589390225941315, 0.010094265035149874, 0.023498762893723324, 0.02147699306078721, 0.018936282031063456, 0.03654005275166128, 0.02428482530376641, 0.04724394479126204, 0.048496300441911444, 0.04282082627469208, 0.07468450261512771, 0.0290410660818452, 0.04624184875865467, 0.0891420069092419, 0.022280006123764906, 0.05856853204022627, 0.025971649047278333, 0.05042004369897768, 0.012741391692543402, 0.029899677138018887, 0.016300572387990542, 0.014695522186229937, 0.03269448097853456, 0.05493078759172931, 0.056851105837267824, 0.07023473357548937, 0.0210344893639558, 0.029524918536480982, 0.05767089700384531, 0.028315746603766456, 0.07412787701468915, 0.0863778407801874, 0.014345234048960265, 0.026060716045321897, 0.025086582281801384, 0.05629009043332189, 0.06615161517402157, 0.043414666870376095, 0.07709619312663563, 0.007156448873502086, 0.04176666116109118, 0.023178630071925, 0.0646294628677424, 0.03566873427189421, 0.06911089934874326, 0.03388504912436474, 0.03889797837473452, 0.0327609328815015, 0.04818744084332138, 0.022065007797209546, 0.01828809210564941, 0.031166254193522036, 0.03897571463312488, 0.022460359141405206, 0.07361619587754831, 0.021613713361148257, 0.006789137260057032, 0.00931430586206261, 0.0690114738245029, 0.04643197957193479, 0.053246001043589786, 0.022013250418240204, 0.017048050540324766, 0.039892437707749195, 0.0472782357246615, 0.02813302242429927, 0.004599234334818902, 0.05689614306902513, 0.006359087265082053, 0.01510673693701392, 0.03704566312080715, 0.04056224453961477, 0.04601219487085473, 0.06392267110641114, 0.02576667713583447, 0.0286459893322899, 0.069899253139738, 0.056890272680902854, 0.06293722515692934, 0.05912700929911807, 0.012891633923572954, 0.03209596856322605, 0.0426564925146522, 0.06661589533905499, 0.06202924458193593, 0.07615058566443622, 0.07839515194064006, 0.019590238443925045, 0.05881870260054711, 0.09774593272595666, 0.03845065628411248, 0.0672138956724666, 0.033469205227447674, 0.060462838009698316, 0.008234366887336364, 0.06585958006326109, 0.030126353158266284, 0.03839767807221506, 0.03180681298545096, 0.029616063548019156, 0.047481409783358686, 0.023815457716409583, 0.03024807094334392, 0.046186610707081854, 0.040795212116790935, 0.007374987244475051, 0.02277630068419967, 0.03462207969278097, 0.08437534823315218, 0.0344790789677063, 0.033785029881983064, 0.02067240664473502, 0.04274323473509867, 0.037226205386104994, 0.02457913324178662, 0.0418998469831422, 0.015105317579582334, 0.08890117998817004, 0.029687142741749994, 0.05465629314130638, 0.06317814855719917, 0.06342503140331246, 0.029810331834596582, 0.04677636577980593, 0.02773121253994759, 0.047433589497813955, 0.020537697564577684, 0.03693605161970481, 0.02644050826347666, 0.043203729946981184, 0.02632267747685546, 0.16023355739889666, 0.028706038356176578, 0.05626664969895501, 0.06507654747110792, 0.052736431316589005, 0.018362447881372645, 0.07904844969743863, 0.05177421830012463, 0.062079090930637904, 0.06743275502230972, 0.007988074048626004, 0.030821892105450388, 0.011639763451967156, 0.024341644129890483, 0.03880799667967949, 0.022166409289638977, 0.02124719259882113, 0.04343892396718729, 0.03193463679053821, 0.051008986119995825, 0.031648657604819164, 0.03814993433479685, 0.03163971472531557, 0.032880763756111264, 0.0351726048393175, 0.04100750345969573, 0.05159895641554613, 0.016343448114639614, 0.06367515001329593, 0.047866614113445394, 0.022405996824090835, 0.014204215785866836, 0.035689707365236245, 0.050637941967579536, 0.014429850943997735, 0.047469361015828326, 0.037453621698659845, 0.07894710943219252, 0.047659707051934674, 0.041654826927697286, 0.02838847336533945, 0.040981762067531236, 0.022550364956259727, 0.057033366174437106, 0.05082420619146433, 0.011214749392820522, 0.008078626269707456, 0.022062093012209516, 0.012018868255836423, 0.017104581784224138, 0.02140118453098694, 0.041808648165897466, 0.038584799476666376, 0.02393167062109569, 0.02346810848393943, 0.06991549133090302, 0.022654078238701914, 0.04943697633279953, 0.016808088221296202, 0.04727812069177162, 0.08502626369590871, 0.046615390238002874, 0.04340413950558286, 0.013638049877044978, 0.02815165775245987, 0.04093008261406794, 0.06930104500497691, 0.03243102226406336, 0.04327415234001819, 0.0583016594464425, 0.047067536288523115, 0.050588043668540195, 0.012539602666947758, 0.029187458421802148, 0.029355206061154604, 0.04891769560344983, 0.012393384731694823, 0.05349821993149817, 0.06140266043075826, 0.056653438514331356, 0.052616095781559125, 0.033573280306882225, 0.08003042239579372, 0.03347000674693845, 0.017103685640904587, 0.046329956530826166, 0.043896394927287474, 0.023679527803324163, 0.06801201612688601, 0.05564611034060363, 0.05524239313672297, 0.23954866075655445, 0.18444548710249364, 0.1528990751830861, 0.16689526790287346, 0.14436158642638475, 0.10615428036544472, 0.16573177330428734, 0.10399897961178795, 0.19513843988534063, 0.07776401471346617, 0.1487577724037692, 0.09608318054233678, 0.11592340029892512, 0.17167374899145216, 0.21272054174914956, 0.08450045206700452, 0.0981498317560181, 0.19998435251181945, 0.1048457997967489, 0.16709906165488064, 0.14023699681274593, 0.2248787463759072, 0.10429485904751346, 0.18426668888423592, 0.14829865016508847, 0.09390265418915078, 0.12161636317614466, 0.12343320006038994, 0.13298015808686614, 0.1407921826466918, 0.19504133728332818, 0.08784095523878932, 0.15224264556309208, 0.24750552285695449, 0.10357911698520184, 0.11566610512090847, 0.13741861679591238, 0.2005740036838688, 0.23198034265078604, 0.1205924665555358, 0.1696346834069118, 0.16249311505816877, 0.12592194776516408, 0.22004080441547558, 0.08300503934151493, 0.20043341122800484, 0.0883784556936007, 0.1367638644296676, 0.08547078046831302, 0.15702731616329402, 0.14987985516199842, 0.0850737388827838, 0.16186441207537428, 0.08995871074148454, 0.1576713370741345, 0.13877977500669658, 0.14332001184811816, 0.14632855978561565, 0.11386561774997972, 0.08237264046329074, 0.10321175388526171, 0.12854483124101534, 0.2320626171422191, 0.11165537580382079, 0.1963028102181852, 0.12968246941454709, 0.07493849523598328, 0.1939259486971423, 0.0797870202222839, 0.11192339501576498, 0.22060865128878504, 0.22834475414128974, 0.18979019718244672, 0.19008226197911426, 0.11973346030572429, 0.1439315712195821, 0.1638125051977113, 0.20676499960245565, 0.17123303201515228, 0.12033601000439376, 0.173407465335913, 0.16376426559872925, 0.0897466939932201, 0.09576311451382935, 0.14965983806177974, 0.2817166753811762, 0.1254573484766297, 0.1658477561431937, 0.20176136575173587, 0.2759429148864001, 0.13613079761853442, 0.1933743103290908, 0.1814719388494268, 0.14938496140530333, 0.1307642535539344, 0.12419403501553461, 0.12478211283450946, 0.1352620098623447, 0.10933029392617755, 0.1103645509283524, 0.1897273669601418, 0.12631469231564552, 0.11010262474883348, 0.15007958194473758, 0.13822527194861323, 0.23873603873653337, 0.16441826097434387, 0.11236463891691528, 0.1342435012338683, 0.16348411969374865, 0.21388412540545687, 0.11599558900343254, 0.11250255964114331, 0.17414088535588235, 0.14323568902909756, 0.07820875413017347, 0.10192648027441464, 0.12665965739870444, 0.21376949327532202, 0.14872030878905207, 0.1266056884196587, 0.2641753025818616, 0.12628229014808312, 0.11366018385160714, 0.10329350145184435, 0.09226598107488826, 0.1398716523544863, 0.11303099847282283, 0.21276290353853256, 0.12114353346987627, 0.14267849939642474, 0.05512175332114566, 0.10303002418368123, 0.07581512007163838, 0.07408437231788412, 0.1592695966246538, 0.13476781372446567, 0.12249833889654838, 0.07919035575469024, 0.11775030070566572, 0.15532707067904994, 0.16160697588929906, 0.11012485207174905, 0.11085633508628234, 0.10774724098155275, 0.16052784863859415, 0.08993929615826346, 0.11509955700603314, 0.0776823858905118, 0.1202551307505928, 0.16284391342196614, 0.11155417654663324, 0.26369845785666257, 0.14184248488163576, 0.17568832263350487, 0.18004854413447902, 0.1084889136836864, 0.16080051369499415, 0.15703472279710695, 0.13285010412801057, 0.20013065950479358, 0.17137145739980042, 0.19743978045880795, 0.08146762105752714, 0.1302501530153677, 0.2082864913973026, 0.11008504327037372, 0.2745212271111086, 0.1926419886876829, 0.11328213382512331, 0.14002465351950377, 0.11151836792123504, 0.12084185786079615, 0.10808917810209095, 0.22530608985107392, 0.1269229268655181], [0.05557817414228339, 0.033758004574337974, 0.09776608203537762, 0.028611464622372296, 0.11866751359775662, 0.021095280535519123, 0.050618683235370554, 0.07289067230885848, 0.024186783884942997, 0.022488518079626374, 0.021083979481772985, 0.032527174917049706, 0.021553775659413077, 0.06504349221359007, 0.06998138662311248, 0.001981041232284042, 0.07891872228356078, 0.026224747380183544, 0.07269410707522184, 0.04480749623326119, 0.025968448535422795, 0.04875660131801851, 0.05211559880990535, 0.027523296157596633, 0.003385161444384721, 0.015884513268247247, 0.022915830013516825, 0.038989262538962066, 0.06713548777042888, 0.0344134582701372, 0.036362093160278164, 0.04918140664813109, 0.03769122027733829, 0.020073157647857442, 0.026779762520163786, 0.02225281197752338, 0.056336752968491055, 0.06254745661863126, 0.03817527867795434, 0.07029397922451608, 0.06167410836496856, 0.05318501134752296, 0.03380827765795402, 0.06824392985436134, 0.022114991443231702, 0.009565900418238016, 0.02958049426524667, 0.05383049057854805, 0.0265012734598713, 0.027688893424056005, 0.0171695475364686, 0.0427488045534119, 0.025575509171176236, 0.04251502803526819, 0.07340279873460531, 0.02732983495661756, 0.038362340710591525, 0.067188046668889, 0.03392076127056498, 0.05011787827243097, 0.008588208056607982, 0.09194608574034646, 0.10027981043094769, 0.015788321652507875, 0.028605276966118254, 0.09587229928001761, 0.06385942528140731, 0.07181422421126626, 0.030516095721395686, 0.02709727927140193, 0.08218144837883301, 0.0830694058095105, 0.013164572646928718, 0.021090254340379033, 0.06609524163650349, 0.017155060813820455, 0.018863236145989504, 0.04472232365515083, 0.0234704610920744, 0.05089756377856247, 0.04703609891294036, 0.008085915087576723, 0.023101854894775897, 0.012071230485162232, 0.05888059771677945, 0.018951241872855462, 0.05855184484971687, 0.0141104287285998, 0.0827893712266814, 0.023281172616407275, 0.04231577993778046, 0.05567076077568345, 0.021198873218963854, 0.0060609336105699185, 0.015543451881967485, 0.018945865012938157, 0.06503234515548684, 0.04978701770596672, 0.049070789536926895, 0.028827860041928943, 0.01762684780260315, 0.058304316335124895, 0.050555830748635344, 0.03904213313944638, 0.011252968142798636, 0.024416239248239435, 0.038438080591731705, 0.07715920146438293, 0.03374185173015576, 0.01011983944408712, 0.027955317018495407, 0.05437310072011314, 0.054113152364152484, 0.06312562676612288, 0.038964426566963084, 0.017807547774282284, 0.059953301679342985, 0.04871230623393785, 0.0238910788539215, 0.022821350903541315, 0.04299878957681358, 0.07739156048046425, 0.04294570375350304, 0.06253791259950958, 0.04050442381412722, 0.04294686150387861, 0.06305382397840731, 0.04880523054453079, 0.030368736734089907, 0.01359488564048661, 0.030970772495493293, 0.05302334560838062, 0.07279796322109178, 0.06438376003643498, 0.026408712801639922, 0.018804561950673815, 0.05581894169154111, 0.01962279089639196, 0.009053273042809451, 0.06424013219657354, 0.03561039404303301, 0.022296951210591942, 0.0323295595444506, 0.05640069270157255, 0.002893900732487964, 0.043934344648732804, 0.027212696222704835, 0.008708283839951036, 0.07779580089845695, 0.01144377338277991, 0.02970249035570305, 0.04284570677555166, 0.10883686962188222, 0.008653907607367728, 0.03835293398879003, 0.013613597038784064, 0.012974131059309002, 0.058578369207680225, 0.01570513803017093, 0.04194388602627441, 0.016314573003910482, 0.06542321207234636, 0.07413644139887765, 0.09112468411331065, 0.01355972453893628, 0.08245790580986068, 0.08796811482170597, 0.040654014810570516, 0.008057452796492726, 0.10858617213671096, 0.026766852861328516, 0.032621368300169706, 0.0355557088914793, 0.005742933535657357, 0.03477857637335546, 0.04258786611899268, 0.011377013488527155, 0.023464839323423803, 0.05939387818216346, 0.09135121727013029, 0.06748559593688697, 0.008914571208151756, 0.06092934090702329, 0.03820725411060266, 0.056824436760507524, 0.03676765460113529, 0.021195236695348285, 0.059278689441271126, 0.041760946623981, 0.06576978019438684, 0.018112646539520938, 0.03657328612462152, 0.03794249292695895, 0.013069038759567775, 0.07067802580422722, 0.06846523087006062, 0.03176249563694, 0.016787057611509226, 0.05800613995234016, 0.09491080985753797, 0.042836689681280404, 0.016486658496432938, 0.015239107324305223, 0.022843995684524998, 0.07570475529064424, 0.03385375275684055, 0.02962364273116691, 0.07542885447037406, 0.027679907871061005, 0.02125213901308598, 0.028460795656428672, 0.015690636464569252, 0.03971653015469201, 0.029224543541204184, 0.028112058607803192, 0.018361898692091927, 0.07198245424660854, 0.025192501598212402, 0.0406440143706277, 0.06012985861161724, 0.0114656416917569, 0.030087677987467032, 0.049654433023533784, 0.08402520295931026, 0.07145676136133261, 0.008621806009614374, 0.09398087655426934, 0.01195652135720593, 0.03525299056491349, 0.06883996349642985, 0.06232629661099054, 0.01890628998808097, 0.04851297278946731, 0.015113984009076376, 0.1008780556730926, 0.04038642604427878, 0.058342919146525674, 0.04686576488893479, 0.0274154546787031, 0.08780271979048848, 0.012819731873605633, 0.049855317556648515, 0.029002428018429782, 0.04174407760729082, 0.07237506521050818, 0.034860342493630014, 0.014857429123367183, 0.0437720517948037, 0.05158116342499852, 0.10223490942735225, 0.01775263070157962, 0.019002828557859175, 0.057266660296591, 0.016355407824448776, 0.04026458023872692, 0.05837395576236304, 0.0676515550003387, 0.030854696888127364, 0.0498038644582266, 0.012062578898621723, 0.0882184634974692, 0.03951933409553021, 0.03377109605935402, 0.03467847920546774, 0.11228707706322894, 0.027022211033909116, 0.08685719396453351, 0.03367213437741157, 0.03095869589742506, 0.045571659720735624, 0.04562196249025874, 0.0899405281234067, 0.0957177544478327, 0.010586133612378035, 0.02110816236381652, 0.041374599386472255, 0.026864671635848936, 0.048456640070071444, 0.013221596491348464, 0.02407618532743072, 0.06579905049875379, 0.04236440174281597, 0.01829361182899447, 0.0598567593988264, 0.03981803740316536, 0.05159120097232517, 0.05558806697081309, 0.03883541161485482, 0.0612201514741173, 0.07668919934076257, 0.038588113166042604, 0.04120877019886393, 0.043196868791710585, 0.034768984114634804, 0.016571767991990782, 0.05358496586268302, 0.03025273163075326, 0.04626104811904952, 0.004856088398810243, 0.012551849031297024, 0.059179686941206455, 0.04553959151962772, 0.013512290170183405, 0.010209780321019934, 0.04810250204172917, 0.039943297088029794, 0.03411580139072612, 0.07614896036102436, 0.05186212569242343, 0.015781926194904372, 0.05496674835740123, 0.016293848530040123, 0.07070682113408111, 0.04848158736422192, 0.04651841380109545, 0.028639397205552086, 0.01789153291611001, 0.07774268538923934, 0.05395506748754997, 0.041009429332916625, 0.07919353214674629, 0.03329692677652929, 0.018508192697481718, 0.013258231683721533, 0.043767684255726635, 0.04119399774936028, 0.02328726193809416, 0.041940984228858724, 0.04699179269664455, 0.047217947358149104, 0.03094306626735488, 0.04998587988666259, 0.01542525094919256, 0.04675590847909916, 0.03862618905259296, 0.0514349863078678, 0.02958196186227724, 0.03327832113427576, 0.052379992630449124, 0.06818645051680505, 0.021573073354375083, 0.05697381995560136, 0.015349821842391975, 0.03149131858663168, 0.024916888360166922, 0.03979373948823195, 0.010558348531048978, 0.010907674659392796, 0.04916670099191833, 0.023489328341383953, 0.028417044195521157, 0.053228122706059366, 0.21026444854214787, 0.09924852944095619, 0.1617008278844878, 0.13510270044207573, 0.32669622742105275, 0.09388646052684635, 0.09599041208275594, 0.16093625250505283, 0.21610057912766933, 0.23170617845607921, 0.14622918621171266, 0.14172804570989683, 0.167234874679707, 0.14646507042925805, 0.19290850876132026, 0.0967120764835272, 0.13315116375451908, 0.10967821275698952, 0.16645838040858507, 0.1970928709488362, 0.1233514079649467, 0.20466448419028893, 0.14277328649768606, 0.24852838047081605, 0.14676374034024775, 0.09521065236185677, 0.1547223242232576, 0.09176992214634083, 0.16780307778390124, 0.08157405245583504, 0.1264674263074994, 0.16175948723684996, 0.11389282488380559, 0.14353838138049468, 0.10703457883209921, 0.08564429459511302, 0.16128929215483367, 0.10268974947393872, 0.08542496769223362, 0.19334360025823116, 0.12573329382576048, 0.1269700680859387, 0.13017449848121032, 0.1597871258854866, 0.10179549863096327, 0.12729107664199546, 0.10941532178549096, 0.15796081919688731, 0.18825812236173078, 0.1110362094186712, 0.1753176050260663, 0.14763226092327386, 0.15097801107913256, 0.26772915094625205, 0.23029134812531993, 0.11176088693900965, 0.17112840403569862, 0.13121022493578494, 0.16907140816329047, 0.10049919670564122, 0.08561586291762069, 0.14943280024453998, 0.17753313848515972, 0.1423631311627105, 0.11678423965349793, 0.20159745501587167, 0.20537189935566857, 0.17357694217935205, 0.23868416261393577, 0.1411392109002918, 0.17199466848978773, 0.1889861247036606, 0.15520786691922694, 0.15463540388736874, 0.1740541134495288, 0.10814511377247982, 0.1412223165971227, 0.11221869557630271, 0.102388029335998, 0.14624956558691338, 0.1405388134298846, 0.11295672433334403, 0.13457224296871573, 0.1169799811032135, 0.16793877206509933, 0.08705018946784548, 0.14972691336879507, 0.07571663707494736, 0.19751976913539693, 0.132315787486732, 0.14301326737040654, 0.16061337373685092, 0.16096786799607798, 0.22933415573788807, 0.17954514536540955, 0.18722181703196838, 0.12162272338173352, 0.1671051324228756, 0.19115755974780768, 0.07459649132215418, 0.11631347311777063, 0.1466368034016341, 0.12032585000270046, 0.10719589205109514, 0.16128342918818817, 0.10290535821695812, 0.07568445013021119, 0.30095394467934966, 0.1250300495303236, 0.11954206784139387, 0.19914896140107885, 0.16503137885592878, 0.12764594197506085, 0.18812363035976887, 0.1411520945839584, 0.10201383105595596, 0.21421221405034885, 0.11789893062086776, 0.10861782473511994, 0.18607426376547664, 0.12844891607528552, 0.1823512651026249, 0.09205203474266455, 0.13055553194135427, 0.1411020293016918, 0.12013180807116441, 0.17476071225246415, 0.14319098205305636, 0.10650990268914029, 0.14701437845360488, 0.13943285011919215, 0.1953167186002247, 0.18361101625487208, 0.08064918059972115, 0.14363760652486235, 0.16876542067620903, 0.192333314626012, 0.1455951842945069, 0.1315880226320587, 0.12029264631564729, 0.14396551705431193, 0.14737000077730045, 0.22176033089635894, 0.09950412510079332, 0.11364068021066487, 0.16047589830122888, 0.11993905747658573, 0.12935326754814014, 0.11875830052304082, 0.14410443225642666, 0.07077146219671704, 0.1247358918772079, 0.2283082256326452, 0.11738955756300129, 0.14757055876543745, 0.21677137672668323, 0.1029161861515604, 0.12407837130012922, 0.1111407186544966, 0.13032107264734805, 0.08430086629232392, 0.15381515258923173, 0.23086560715455562, 0.28785147587768734, 0.12622570880921558, 0.18236259027617052, 0.19904197339201346, 0.1028564284206368, 0.1070374806295149, 0.1786991415428929, 0.12304878240684047, 0.0813724406179972, 0.18219781864900142, 0.07549378497060388, 0.10909809818258509, 0.16521696030395105], [0.02210482030932326, 0.024506287736585364, 0.05864073558768723, 0.02555748611484887, 0.015139853421715088, 0.014214856328180758, 0.02991570010635769, 0.0371211432502605, 0.009646078342484543, 0.07502772365114652, 0.051702960990951397, 0.02900932257034583, 0.09296451273257844, 0.02379110228503123, 0.042737208495964296, 0.0408077692554798, 0.12089797164662741, 0.038658197881886736, 0.011283647600066615, 0.03347000674693845, 0.018599120630824473, 0.017131890963355545, 0.004417953632582794, 0.03748862509382889, 0.047619842589483596, 0.030903867882443592, 0.05596831746515818, 0.0404401798004983, 0.08107329573249444, 0.04338407554314472, 0.038482457312056795, 0.06384415188222192, 0.022143272835819516, 0.012761544712702744, 0.0304403354311944, 0.02541812562412815, 0.009492204226262402, 0.10942276552668773, 0.025132727168966085, 0.02570281347288983, 0.06468491614214145, 0.06839922425569966, 0.06628772505791858, 0.008874529557942878, 0.04982962069334462, 0.062245146473287605, 0.10339872314943932, 0.06460132804932073, 0.03287707528215833, 0.04904806126432959, 0.020833942508033942, 0.023012980855128262, 0.029397590114967898, 0.05250107773463242, 0.028291968192206696, 0.04273416197975166, 0.04084462059836369, 0.018824963590304833, 0.04704836290329695, 0.04203518132271711, 0.0678278596024029, 0.030634084214398172, 0.02775941600702936, 0.02709910495468648, 0.0392019212449668, 0.022299023657978978, 0.030665415833937004, 0.02137914088962134, 0.04249702724337112, 0.03319569041195791, 0.04451135333511047, 0.10704463493311778, 0.022132452322694007, 0.06055790712707676, 0.019136862283630762, 0.01169357843537, 0.019683400241774507, 0.01135813603468705, 0.020009193794976454, 0.03757233564101625, 0.022749898780602962, 0.032278035941999406, 0.04918577047646977, 0.04047224429086782, 0.05420457382570021, 0.030545464360329788, 0.011317797525407514, 0.01953546794538852, 0.08519738810718991, 0.01697261493973201, 0.016507336586073507, 0.0612574889237294, 0.02502991188521264, 0.01231441001436906, 0.0201385668333387, 0.034232596881338395, 0.07084210723405704, 0.031928655080264434, 0.0384871476853732, 0.031263980199582875, 0.06652622905676253, 0.04945678425428923, 0.012505295035225572, 0.02991057001054287, 0.02468951843184186, 0.0014408536230803293, 0.018834262700693216, 0.04836673258978408, 0.055405379898729734, 0.04751551889057737, 0.02133104600943625, 0.09482873574597761, 0.016198026132769883, 0.07586669191368856, 0.015781230431457516, 0.026318886957596987, 0.06314743848633952, 0.004292899429856334, 0.010281192553520668, 0.0370127191854408, 0.04838650711462833, 0.02242940045107389, 0.07077339920215309, 0.03422476351261139, 0.0309903800371103, 0.07943064090795815, 0.020261763347662054, 0.023551245722046588, 0.0345137149997754, 0.05551191519771237, 0.029837880356353708, 0.0572751801519189, 0.06932765842066146, 0.0029609083185277996, 0.0579024878970813, 0.01214580426676548, 0.0701134221162647, 0.05076730201835744, 0.014289620285126148, 0.016380078668589704, 0.04313285484386142, 0.02640141006850172, 0.08790903244516812, 0.028593801507668104, 0.09926653394359164, 0.04500687791733071, 0.05374552209104877, 0.06633420576690696, 0.1204598076583352, 0.09115698238019831, 0.06166668317746371, 0.021720150325563736, 0.048903802598943, 0.006453953683376312, 0.04880036576651037, 0.03542038568411954, 0.03393231650989037, 0.04670256661484018, 0.06882535060867667, 0.013983296976221027, 0.04760129260830581, 0.02799104586301837, 0.004455455746210646, 0.022660254762740806, 0.04904783490928821, 0.031173976240097545, 0.016104153728520032, 0.025858742410491686, 0.036204635398462415, 0.025207220242009498, 0.02281132448842982, 0.03149950447550509, 0.08341504624695517, 0.010993982723448426, 0.02819158158672508, 0.03662537375930697, 0.02749912626313744, 0.054415058039012365, 0.012440806112863356, 0.013251524524093838, 0.073143173212884, 0.11426102661062032, 0.08730626010219567, 0.009056341823452385, 0.03201765714038629, 0.059099297504872084, 0.024492301963618957, 0.035030012295464985, 0.051644594786921516, 0.05143302332726307, 0.0044326105853542686, 0.02944411535281688, 0.05393117404310033, 0.01405823069944745, 0.044050642900401726, 0.0441520573804155, 0.07282611288246699, 0.05751482705818489, 0.057984268860309385, 0.031971035423339345, 0.013017420533287805, 0.0243536576454062, 0.06551914208102971, 0.023029311814752873, 0.016260030715784524, 0.022362558920576703, 0.045129384234314784, 0.028046853512933012, 0.04585387992847245, 0.06644632201641798, 0.05892321925784927, 0.02834363651345484, 0.0061885347713541705, 0.07361875628703274, 0.027444999577710405, 0.08872241145581938, 0.016519639539183117, 0.04955124852131121, 0.03937442976166494, 0.01109233584429603, 0.029248874852783047, 0.030257123289629817, 0.07344984347582795, 0.026168015756411478, 0.08430931193288416, 0.0546560890506953, 0.011767853502533399, 0.04567064366710838, 0.03823423488938715, 0.0702509049733635, 0.05247350694844499, 0.06772583656129427, 0.025594164908397943, 0.03517395925882738, 0.029481476922228467, 0.052090183962718584, 0.06701775346300565, 0.07229397815535776, 0.04328863535192795, 0.02627184036100516, 0.038869865820743144, 0.010011206650233362, 0.05241260259936098, 0.07350049505475909, 0.0392836539685959, 0.03443156667344738, 0.028743702350766398, 0.06328791219857521, 0.01364477095194161, 0.0596956391382264, 0.02407409618172096, 0.030884809530107304, 0.053770706872455776, 0.03339371396577917, 0.03878942814480979, 0.018772762778098695, 0.0181707288720645, 0.0367432639177423, 0.07015275594312698, 0.018980749664478935, 0.06480682131950743, 0.01974728987988783, 0.011532645567058353, 0.07542566323536448, 0.006233271433302434, 0.04602241424436215, 0.04045192057674285, 0.06334283854812384, 0.019904126093024388, 0.01733497225359315, 0.042324229289079085, 0.02122850903106155, 0.011772414000006393, 0.052018206770299, 0.02391288315266138, 0.021162268640182447, 0.031206782878143713, 0.011282992654741975, 0.09188756739604287, 0.08420015685260296, 0.02851469598681433, 0.038931000235606916, 0.024272791379189584, 0.05750574688136112, 0.07323027908569202, 0.03638331858383026, 0.011083144345320761, 0.091845487622777, 0.0022538983193953754, 0.019276629100204445, 0.0747927522752434, 0.012963736353412969, 0.007552162478532409, 0.02508747285901336, 0.03605983125453349, 0.042393349212943576, 0.0294786808808567, 0.03664852134534158, 0.046561087292502634, 0.038864693051436916, 0.09167808879283257, 0.038966723514022306, 0.05769052680989262, 0.037154725432628766, 0.02814872255839873, 0.06424909734050743, 0.09704106312710792, 0.02833102371369023, 0.03548048851371277, 0.028840339255111758, 0.052995244186604396, 0.0573001014709007, 0.022357833295245655, 0.05001319463190157, 0.02004827714699786, 0.0360360602644505, 0.06029282681993209, 0.038760836905566975, 0.03970479308918584, 0.01865639402240049, 0.019015994257642888, 0.07945811521494761, 0.030248905859480146, 0.02352860836253967, 0.08413865507463925, 0.04665749969717581, 0.07112299528671429, 0.044751293389708735, 0.01800472899049055, 0.009938748917193152, 0.09366376427351497, 0.015407957980642095, 0.07596824740176089, 0.024990704223455396, 0.019309780836920254, 0.011354586713423487, 0.012192805406812113, 0.037772830546600744, 0.01957961645530304, 0.015343192608270328, 0.029307248478289694, 0.0739215748035349, 0.04216264518618118, 0.05904701320105232, 0.029095582394802477, 0.02450570886139758, 0.018786396030918695, 0.015860948224144522, 0.19472783926175907, 0.0769570552802179, 0.05448859003081452, 0.02146637849364197, 0.1303161002579145, 0.11066000733990222, 0.09711052072816528, 0.05925956429564394, 0.11574727381230332, 0.2005407851538621, 0.13847582100424916, 0.23764963843859732, 0.12016677064821124, 0.15183602285105735, 0.10245859273709357, 0.09877132848487236, 0.16978290514089167, 0.1368960112449713, 0.14427505200728774, 0.08126013883156702, 0.1306267929612659, 0.15847781411139295, 0.12072255020029843, 0.11228781178942882, 0.09362189230159856, 0.10721291691879742, 0.18353570310864598, 0.12728157715173438, 0.1848917405004613, 0.1956407105899416, 0.15775177103932947, 0.0878183419990819, 0.1957461252459325, 0.1661734699155204, 0.13954340043710545, 0.18169807124650106, 0.13445686869090423, 0.1278784271562472, 0.1149658442591317, 0.07010971137788147, 0.08553352163289674, 0.3063315467443317, 0.0917563853727188, 0.12723030959023163, 0.20255804643966258, 0.22795067372499034, 0.12141567902290262, 0.21067556866910309, 0.1191270440176595, 0.09929608626407571, 0.23555002844659612, 0.15997252921806648, 0.11498609746922739, 0.18228491710033268, 0.14714153803652152, 0.19589474773965776, 0.13096267415676266, 0.1788809974095784, 0.1151803026732523, 0.09519425831967965, 0.13048781838733703, 0.07254756259499118, 0.1670589708373882, 0.13050549634499475, 0.21667148364940658, 0.14180264639435336, 0.12889631238067523, 0.1811775882379152, 0.20577074436005205, 0.07451266574207693, 0.2712020755279809, 0.17922379542142153, 0.15822060056962073, 0.08704998908797279, 0.12666362046729773, 0.17145448888186365, 0.10330850025638938, 0.1696589367929846, 0.10578148474451154, 0.07714829931501299, 0.1316179460263811, 0.19031661737244576, 0.1924718142254278, 0.07255316580994986, 0.09476281076786108, 0.16684725094819441, 0.17024420929374173, 0.2054265807964839, 0.112463099649176, 0.14327999524539337, 0.13300573249580339, 0.1471943937940523, 0.196205381071195, 0.11865043677971698, 0.18077348882798105, 0.1212344910891261, 0.1957506820326671, 0.10895706785959192, 0.1217671824269928, 0.14356012630742043, 0.24643822544021532, 0.13478207780281082, 0.09854974545305595, 0.11010465081199072, 0.2121860915212892, 0.1376936715678312, 0.26779986277688295, 0.17777751287212595, 0.11762564958189614, 0.13592764211352915, 0.1410360078443773, 0.153696067573037, 0.128567659703549, 0.18430090189212933, 0.16028311802074313, 0.26911405788268894, 0.08500828887918033, 0.13939042895799503, 0.14082519337534904, 0.1540096991811879, 0.13008915149839595, 0.12443319952581078, 0.11843596352264285, 0.0795429501158651, 0.18612098938319832, 0.15746319433674216, 0.21479788731085137, 0.18486429587937891, 0.2760909585049376, 0.16245863487711176, 0.15887265151832253, 0.12310964593780227, 0.07044614918413572, 0.12991136260097846, 0.17284632747760043, 0.11705537588568404, 0.13166483491659164, 0.10345283313654363, 0.14570479950634763, 0.10477886549779214, 0.14795493189012632, 0.14029442419996485, 0.08263579118647613, 0.10859967922442593, 0.2142631699098274, 0.17130746942711994, 0.23475860216422006, 0.09755412465892732, 0.23856766027165577, 0.09888003827654757, 0.12221654542372562, 0.10041401299531572, 0.3110195748740807, 0.25860524678137153, 0.16006690071662888, 0.1335684140212834, 0.1102738753252197, 0.2554747788235545, 0.23570917459437624, 0.13025145919527858, 0.1334100545500405, 0.1443562429631129, 0.16106933442642912, 0.19635287550045177, 0.10224092824500985, 0.09929529958753847, 0.11900502751814201, 0.07499169238144532, 0.11915846655028872, 0.1008300980902277, 0.17397240299033, 0.17070300498744473, 0.1193429421982728, 0.0851246205274947, 0.12937725376104936, 0.06771687883883715, 0.3745461691869423, 0.23235054075485095, 0.06868907003081404, 0.11537102720467374], [0.0030284567446869914, 0.04927470574330073, 0.04917401856801007, 0.0456891862268094, 0.0062548238656745525, 0.02529404780943878, 0.05017285657231696, 0.0179290039523039, 0.030208610951376613, 0.04200589988613501, 0.09553906755172648, 0.02731653567025205, 0.029030303085164633, 0.018318440379516687, 0.005429862249002326, 0.03351791609020438, 0.0541880870150635, 0.019586440503189806, 0.034820912187569775, 0.004947762654410326, 0.012055715887981933, 0.064239323255606, 0.0075033161738247145, 0.022261135163716972, 0.033927251351997256, 0.02454067514918279, 0.024216813035309315, 0.040056700963759795, 0.013337292675714707, 0.03774488126509823, 0.0663401058409363, 0.0253144049202092, 0.012450509693735512, 0.0325925544166239, 0.07522843749029562, 0.03358186695550103, 0.02712317836994771, 0.04414259128679987, 0.0446683954942273, 0.011417484656703891, 0.029427925401250832, 0.03746186695934739, 0.08214817047701217, 0.06038733932655305, 0.06243001917027868, 0.06393950301571749, 0.027893355108972173, 0.009809214461711235, 0.03590498585253954, 0.012752134280162863, 0.03523328654409852, 0.09989806450903416, 0.07389478327240795, 0.05998465741868131, 0.010669483290257631, 0.035610512786661275, 0.0668993586441502, 0.02103130926116137, 0.02569819916971028, 0.04649703623726964, 0.02485527154931333, 0.011487236333778128, 0.013070316181256203, 0.04022731329314411, 0.010735176347225206, 0.030513385027006734, 0.03368720739672426, 0.013370387823670171, 0.05806331129861064, 0.1493687232141383, 0.09040338336490095, 0.06494592205854133, 0.05202313092013355, 0.023139116274251137, 0.03112385529675521, 0.035386001982260495, 0.03500814862491097, 0.04009212367236614, 0.027419354664743878, 0.03882222736137919, 0.0866849414887838, 0.01613885284314165, 0.04064373606524896, 0.04231670391163789, 0.030613441376772244, 0.039278173208003864, 0.024949479775386862, 0.03254448180086911, 0.028836168385169003, 0.016656107509334106, 0.02461396037688246, 0.014909099299984518, 0.0173674727557227, 0.02241975253127748, 0.009158339817076921, 0.04616100661223754, 0.0493495402042754, 0.05968998397293035, 0.012212470464874059, 0.010572155260888394, 0.07007198801147752, 0.007671366238355404, 0.038948440706008114, 0.02854365829989547, 0.0655989526421763, 0.1142357119533699, 0.03244978746806737, 0.05542157727177255, 0.061730860397801735, 0.020324723445810378, 0.029207858206063975, 0.017893340045702644, 0.02017092818277888, 0.04805924225365743, 0.012715084412775468, 0.0437107689504046, 0.01315573923420743, 0.03983725902799051, 0.01769255570252426, 0.020900874951621518, 0.04616281374183018, 0.020941438888257835, 0.03731392353074625, 0.014281781350291567, 0.03082744708081009, 0.02444993831886677, 0.028846398890891578, 0.012773271573678358, 0.0788893480785191, 0.08931595148169436, 0.07936840440379456, 0.008884354665497085, 0.015615085831086617, 0.04192965534457471, 0.019256342493463308, 0.012577930883708177, 0.05163292080396786, 0.03123741873423569, 0.022300812233879697, 0.020416862935235258, 0.025862792681436986, 0.021585984868579544, 0.03631016137660481, 0.02761396433925256, 0.008701713977643522, 0.05450006734463386, 0.0635858993337024, 0.02557094681833405, 0.009035945749928942, 0.05121977832459379, 0.021795771463075653, 0.022057341411709785, 0.04610205411154311, 0.07263477236847393, 0.049335179646732286, 0.08275002255686559, 0.08673304750118405, 0.03587210871046409, 0.045286110980669037, 0.06390316746546887, 0.04092722163477447, 0.06931403258931823, 0.012632510279217968, 0.05080631672171876, 0.04039796272991225, 0.06214605120476335, 0.04771619933308102, 0.0067355500232224585, 0.04844745228183456, 0.03736213344382122, 0.09814830293180421, 0.051487478413037024, 0.023559676519653294, 0.02388099121162668, 0.016083043337857816, 0.05187682392715942, 0.038318836013786495, 0.03975144820287824, 0.01584835768881021, 0.02925972319644643, 0.031131822252064012, 0.058801354898605496, 0.058222082661814056, 0.06665796769084409, 0.055263366230065, 0.01453420618418022, 0.03770010007428937, 0.032486594282090664, 0.036585171619663015, 0.03731374912604224, 0.04473404958844185, 0.019186821809853427, 0.033788703512982465, 0.050340203451924026, 0.04114432209462393, 0.07253435236634687, 0.0361872431676602, 0.07388361394987442, 0.02361393864703132, 0.05444263624667656, 0.010493549762031762, 0.03814975993009284, 0.11952375163673423, 0.07174743092036806, 0.031041649453982245, 0.04149147280259058, 0.03566106046491768, 0.029997353049111553, 0.02354279266000958, 0.03541680482157972, 0.042281091955373995, 0.04366202469100244, 0.09136965963989496, 0.024354052839044016, 0.059399262463557534, 0.028961428070033435, 0.01761260413331911, 0.03815435753494967, 0.05991183417791035, 0.02141543933248613, 0.10518481285544112, 0.06626894130022265, 0.02950466161564691, 0.03728918403794523, 0.021085732805659063, 0.02278673342516413, 0.06738337251590565, 0.022896083319210447, 0.02123560396285029, 0.08228776845498942, 0.011593029485084116, 0.018943488285003696, 0.11410682316636667, 0.05624698649626225, 0.015354077131632948, 0.014555031775671523, 0.009710376161820022, 0.0532901291444432, 0.03290031192591414, 0.02963617389468709, 0.04485452242079191, 0.016106207622215152, 0.08905364680686034, 0.07964500284288079, 0.02225080632342724, 0.09046268096426502, 0.059166339415241964, 0.026231139127048664, 0.037382334703579545, 0.014918005999788875, 0.03372646700881887, 0.020852444249612745, 0.02051112496701535, 0.04309185118472669, 0.040141324352589436, 0.07609611202497035, 0.04297132640203927, 0.06571812671609223, 0.07317766081541777, 0.016097624684334733, 0.040924119457486086, 0.04547588185232598, 0.009757427396834828, 0.018514478688302916, 0.045709253899985924, 0.055378172764903866, 0.03368837999005336, 0.04609706316841766, 0.01595114328665659, 0.012011620256089373, 0.014436061792366672, 0.02683826973225223, 0.022660366084892303, 0.04570446333673317, 0.026035594346467406, 0.027629349060589448, 0.03959249130275566, 0.02350664264668012, 0.07502916341763921, 0.02413192247331608, 0.05153925434569828, 0.0420552341529401, 0.027133674193464685, 0.05266295869660098, 0.02519042358471779, 0.016485372725583147, 0.027461202516860794, 0.06469351021223702, 0.045643336343346164, 0.021106004569446668, 0.028300502890488133, 0.0332922994857654, 0.05226456640230026, 0.017319312937615905, 0.05396661530539859, 0.022762708249501884, 0.014940920736989938, 0.010373984205216402, 0.06568298602360301, 0.030266544854384847, 0.05425943709269632, 0.03395877778530121, 0.03729407108039595, 0.06444562546676025, 0.0673217000439763, 0.02760837411187822, 0.006368991689669201, 0.03382423012226354, 0.056260233832290396, 0.025519870359858032, 0.059571674501057714, 0.056558740470791236, 0.020651778650062624, 0.041029923741007224, 0.04505425662500784, 0.034489216704969294, 0.041951656312448904, 0.04160423472058028, 0.028974886918149423, 0.052067611541133374, 0.07566012252937071, 0.028881339203508105, 0.07983327828696929, 0.05509052745765075, 0.03588526327803265, 0.014235335893317824, 0.023779003422532696, 0.0032191564605454914, 0.055047612768248655, 0.04583287343848497, 0.06640150371822529, 0.06962430226849392, 0.032715940178604797, 0.07090380197041668, 0.01697333667834755, 0.014942019115551375, 0.03472957236226648, 0.11095023903180845, 0.022253476199693978, 0.07154893610277213, 0.052525253195199184, 0.05223799009399954, 0.09708077544928528, 0.06661872292170301, 0.03267422776843887, 0.020453562137845438, 0.015805352086317725, 0.0543833794654347, 0.01677751544775674, 0.02740486423135735, 0.03382697977940552, 0.040661759121576324, 0.11988966012722813, 0.1520573312882334, 0.11992148341960274, 0.17844682617578655, 0.11171538586495444, 0.19598270708229393, 0.19607085938332602, 0.22103590570623055, 0.13214795821113512, 0.09421971451956779, 0.13599192694528028, 0.09948538587195799, 0.13703219534363598, 0.06406510408851318, 0.1329223596258089, 0.1573590561747551, 0.1852409209823236, 0.12958618317497894, 0.10927470706519671, 0.14954185142414644, 0.20171931566437706, 0.20989856973756105, 0.11304632382234558, 0.14769580360734835, 0.0965422137232963, 0.1051264355191961, 0.16836929193232208, 0.21069523558253422, 0.12014699983410537, 0.11982401716522872, 0.08603112422861159, 0.14322458649985492, 0.09502328233793378, 0.16527762345504016, 0.10618538377457298, 0.11205634335055947, 0.13660841417731717, 0.12205650869873352, 0.10507384693482891, 0.11159630827023648, 0.13987683254526928, 0.11486218107165769, 0.1260237704264, 0.11367070008418523, 0.17777151631889865, 0.2224656383623369, 0.07347484643105417, 0.1427014614455402, 0.07562659229733981, 0.14871109131490812, 0.26774844678584486, 0.17838507948908955, 0.22667063225526363, 0.1473804799024947, 0.08796690512099303, 0.09121905561187305, 0.20832668611546978, 0.10525656369281933, 0.10977752695907839, 0.16413765493780375, 0.14765338244615123, 0.1459280078415759, 0.09013272952870466, 0.13221142668044195, 0.12475763680413365, 0.05461410204588901, 0.08766631304752082, 0.2395887515740469, 0.15044145315187052, 0.20755814766744152, 0.14515740622300655, 0.23246707278303802, 0.1264370427816175, 0.14971866068663076, 0.09534216835163534, 0.07959575392305851, 0.13466517470078543, 0.13997096655657515, 0.09875329429632984, 0.18825972540071234, 0.10322556525352411, 0.09991315979277715, 0.10384907320258208, 0.10866081735002808, 0.0867124083742965, 0.105100029904861, 0.15904143074294552, 0.08967784495325759, 0.14175819174852222, 0.19408513937378302, 0.14076749881496653, 0.15560838917735964, 0.1491480678669177, 0.12846782599808648, 0.08140565172652714, 0.10124032021849416, 0.07020350400125608, 0.17277045029914007, 0.08341545442817733, 0.1373197478824295, 0.17912569834152237, 0.09570267400704324, 0.11278138452325948, 0.10687691697967239, 0.2133942930959165, 0.18700889486353844, 0.1356815904728137, 0.15723560733022168, 0.18811856891261414, 0.11012993578333408, 0.184511671832297, 0.15854595811106265, 0.15164416283369064, 0.1617306176922284, 0.19515449996106327, 0.12131217910791747, 0.11252091295318678, 0.18625162221724167, 0.146235880383756, 0.1712684621452354, 0.13484766881447285, 0.11254969344008714, 0.10171891641221009, 0.14843590295640752, 0.20886259095277637, 0.2245979622239247, 0.16197318123886362, 0.10507585815503262, 0.1686846007942222, 0.22289348649792373, 0.3185820596991107, 0.09237750360625796, 0.11018550780136138, 0.22403110982850194, 0.18726186332060024, 0.13347779778996482, 0.18165334942750633, 0.09366924874484539, 0.11387084989110008, 0.08411061673541553, 0.18086413474520668, 0.14865779026877135, 0.08928427661885507, 0.14358852087752894, 0.2416984547744505, 0.12464119383366778, 0.25192775821778923, 0.14343047310831025, 0.08113164338283241, 0.0807266979245469, 0.08428853921941482, 0.16191055881790817, 0.12005881042568944, 0.152521129057277, 0.1373295739176683, 0.20486453751800582, 0.21835085994098336, 0.13328010449185967, 0.15393346577184275, 0.1858346094377339, 0.21451070584589615, 0.30004748550709337, 0.10901287736487575, 0.19600210682256147, 0.1642012273077853, 0.21209238795563579, 0.1402194079128094, 0.14958921528887004, 0.13977924012579024, 0.1846144741284661, 0.17848283518105745, 0.18385542032774538, 0.12819419614970684, 0.10416620032628998, 0.12244785801158287, 0.14156198274577036], [0.05935388013313059, 0.10959449107758701, 0.03978747205110267, 0.009299293142248644, 0.07275614319951274, 0.01357222230581101, 0.02870249460102059, 0.021485952638613526, 0.05556660777074285, 0.09772651814273559, 0.03569274274923373, 0.08539908900274895, 0.01956517055077711, 0.057702701742528006, 0.06933841956197284, 0.029001559705648106, 0.022878370109538082, 0.035694468242581934, 0.015581490661134012, 0.01615392215171596, 0.011166534841322573, 0.018692764824663755, 0.08283132483484223, 0.03619002993218601, 0.05521469247469213, 0.024495133257005364, 0.04023938061436638, 0.03589759777241852, 0.03410881407035049, 0.038339241364155896, 0.06631048672716133, 0.01603621381946141, 0.06001882589771412, 0.03310051739390474, 0.013335710973478854, 0.011672968066704925, 0.03619884293584619, 0.08073322882410139, 0.07274596835486591, 0.013546919708460337, 0.10649647723766975, 0.0053853588997299084, 0.05583238940744195, 0.03635430803115014, 0.06569339835550636, 0.043604545353446156, 0.061674791140831076, 0.015366027564596152, 0.020547824169625528, 0.033156697973026894, 0.045914680376881734, 0.009700250484456774, 0.03993365287897177, 0.04085958600626327, 0.04872848505328875, 0.010946157799480716, 0.012424497417669045, 0.04865061891905498, 0.041833068535197526, 0.01464499862777302, 0.057858114887494594, 0.02297200873726979, 0.02315243225893937, 0.014348801923915744, 0.004001745155619574, 0.04346944479038939, 0.024717992782825604, 0.03689092533022631, 0.09636716335080564, 0.09427701574168168, 0.050451826173230074, 0.08351618613232858, 0.07904657206381671, 0.038722104218322784, 0.08035008024307899, 0.08814815984806046, 0.03291770786745474, 0.010895207506109728, 0.05828737310366705, 0.030271901305241045, 0.02993213496665703, 0.028696518456854392, 0.04163175355643034, 0.10549566883128136, 0.06721738376654685, 0.032338086821255274, 0.06623381545068696, 0.057358037229278125, 0.0063314733415609226, 0.01435256739569013, 0.009028284930536756, 0.12157815741375089, 0.03678208937344607, 0.03720752181834541, 0.03507404762785882, 0.01969147295312723, 0.05718403699574992, 0.01392609408867429, 0.03523521983879618, 0.037829660504939966, 0.06304905939032324, 0.04233840430970304, 0.006358541786539718, 0.06614916608668864, 0.07609765569213778, 0.022478820064861793, 0.023852194026403595, 0.04368134279502556, 0.017749289181665517, 0.09400960509083234, 0.04991212525055744, 0.014702485386806075, 0.09393498214194551, 0.0582141491031507, 0.06220318544365, 0.07749488970148377, 0.03053957912925398, 0.010455025803821627, 0.09038369418703951, 0.08083413122221828, 0.061541119212051854, 0.06061600615794305, 0.038515438354806975, 0.01537176251076744, 0.08823132491670549, 0.02970054221805185, 0.004318228930060286, 0.019582640707085375, 0.00542892528756056, 0.037936945373076014, 0.05089761201816145, 0.07650899846339598, 0.04524218325968832, 0.07601830526255071, 0.04942865685734432, 0.008361368763871724, 0.032098773881443776, 0.025679317077447195, 0.01591923279192997, 0.043107172823511064, 0.05344696721294895, 0.08303416121634655, 0.022077288485888857, 0.010943778288492467, 0.056031704298220575, 0.07154776350944303, 0.014608065648644697, 0.019624206543085165, 0.10215537346084602, 0.020595742789737415, 0.036225096409907565, 0.09584501050994731, 0.06738627431332134, 0.03493270189210307, 0.03914967404853087, 0.014199730430846103, 0.0299463508054032, 0.06369335489580408, 0.013529634161386639, 0.03064517932216404, 0.04075592281878926, 0.03724720445461571, 0.018380739966232795, 0.011059826993005117, 0.020604937999451067, 0.023182179393188562, 0.0766312079213094, 0.02576410559413489, 0.08578910244978033, 0.07895030808867887, 0.01277003302675439, 0.07298750773770735, 0.04413432747242041, 0.0451685325242579, 0.024678172849235125, 0.032015504912124015, 0.03823861727141775, 0.05324251666024793, 0.020133249345235527, 0.007672905730942148, 0.045862054685130715, 0.031416688216268085, 0.03765311099414248, 0.01677371379628312, 0.06293693571933545, 0.03691798774525523, 0.01700409313343698, 0.029385940251813736, 0.021031177529948764, 0.023908044349809643, 0.05880465003428981, 0.026956651563523337, 0.06846888965810649, 0.0995218772732187, 0.07961549505125731, 0.015562337684968952, 0.044354678539093584, 0.06013104604789987, 0.08099338127067313, 0.012116088673792547, 0.040565799426985905, 0.014587106470571598, 0.03812158800428733, 0.03163125795254018, 0.043989738551317714, 0.033653528735158034, 0.025009354394569527, 0.044310190496617, 0.03673957544378936, 0.027790745771199, 0.022313079934974667, 0.012294609514356125, 0.07207238770206459, 0.0460089257103391, 0.03012133252923377, 0.03258456890762318, 0.11275989934802055, 0.010503492685529636, 0.06180933880386874, 0.04804153832083102, 0.029374271834967658, 0.009617458345019259, 0.03973862389102578, 0.031864344273344614, 0.04736987240903545, 0.11220568572753109, 0.0307635054923594, 0.04691892121627461, 0.02830055669619469, 0.053302059168345295, 0.04680607766204048, 0.050553548644529656, 0.0060595685226871865, 0.07525237175286748, 0.04612484546669293, 0.011197257899766555, 0.07315363749512471, 0.06315678954706527, 0.03557580625056289, 0.03499313126667403, 0.03822007100097835, 0.04989846973330714, 0.04665490960178431, 0.003021530187652388, 0.03317941511340905, 0.10530417988775298, 0.020093483217351604, 0.07430012206896208, 0.046195906106731854, 0.03049302235012874, 0.03883880694047548, 0.059655277436831966, 0.07198725594207644, 0.028878563571197446, 0.02449751740641659, 0.047420898772543296, 0.0802058215776924, 0.04889845542493276, 0.004868112118856516, 0.11713903077179566, 0.03653465733805206, 0.050175973592558876, 0.12061146553605795, 0.020486322391661815, 0.03299446078017354, 0.04561647801892832, 0.037546646199189126, 0.058781294646905735, 0.03614423199906014, 0.0432441176235443, 0.07484729270800017, 0.03171695374476258, 0.029348582393140532, 0.03841207944788039, 0.0277885100513231, 0.04475281479244586, 0.06173207380925305, 0.07236899444251321, 0.045867171793361194, 0.023923182307044044, 0.031853271430009045, 0.02961191308713751, 0.041726043418748304, 0.01799523877707543, 0.03224899199267384, 0.03255532086768653, 0.012893453113065334, 0.02392144568148069, 0.12825612095184624, 0.016320460090355482, 0.034978622279595584, 0.015266979607986286, 0.03839331795461476, 0.04580916924169287, 0.0781720771919936, 0.08038269763346761, 0.006876110473967856, 0.01328082915279083, 0.04000847249699291, 0.007550846094090957, 0.1100445888005197, 0.017083289567381144, 0.015040946473163785, 0.03502426065097097, 0.050340741508989595, 0.06798552887630649, 0.055165410158224404, 0.003563221225704183, 0.03900864743627608, 0.04225880154990591, 0.005332318069122266, 0.001965200090126018, 0.07000510566285811, 0.03021048858499853, 0.04723305377410725, 0.027845297336170916, 0.016301563155138865, 0.018680508255783934, 0.03468899172730744, 0.038717447241651826, 0.013792908266623272, 0.0416127286007395, 0.013310130070749437, 0.02912110856414074, 0.013462423412420321, 0.053802838156116195, 0.04055673780385405, 0.040033553377725184, 0.03850663277262356, 0.02304196728800889, 0.024922181728470605, 0.032929181470535696, 0.016689750918885693, 0.04635368299204856, 0.011002800365531584, 0.05672763101756573, 0.005095434271424892, 0.03694392951729242, 0.019565773545764387, 0.03594145870010834, 0.013271950283524347, 0.014842422897345386, 0.03836052244878374, 0.05753338446083944, 0.004797713381776703, 0.0023705470039203647, 0.02452084681863198, 0.06627107868553139, 0.0635696091922, 0.05160045184311457, 0.011011641199729638, 0.026078739101649262, 0.16353629267541692, 0.13649168919073418, 0.11020468489732593, 0.04856406965700444, 0.16203038598177955, 0.0795378144539427, 0.12849858059780672, 0.11742066097212955, 0.17769903817679733, 0.21943895233562216, 0.11668632811051793, 0.14231281355023384, 0.1159413973800838, 0.12351043536909856, 0.19128743559122086, 0.08191103945137002, 0.16761966340709478, 0.20003937534056604, 0.17765488039003685, 0.14308403857285157, 0.0974311433674302, 0.19694479764439166, 0.16632935061352327, 0.18737441743724048, 0.19571017561247572, 0.1544935497804545, 0.11283791391178966, 0.15331552393035963, 0.1261960674310103, 0.17777954635675997, 0.14779338118387386, 0.15165011485805735, 0.1690972942742519, 0.09267313813325018, 0.08660421066451818, 0.19174164481228217, 0.16338542889570817, 0.15042721875943244, 0.08841174843837507, 0.2441867275047116, 0.19249413802754134, 0.1143410820805002, 0.2238565863808617, 0.18426752008963376, 0.17215664964169264, 0.1793922926299274, 0.1379837325657718, 0.13786736381007358, 0.1541612160508521, 0.16725712426705286, 0.15604750311467797, 0.18991242890479043, 0.12906988587928936, 0.15681139571825042, 0.13042345934081823, 0.2843328646849841, 0.06178169380291365, 0.16027848701924086, 0.09200528686051257, 0.10025540119386278, 0.18343680450925604, 0.1926296393503435, 0.09472004079725593, 0.1438110019080341, 0.1295112114166841, 0.15008079906692728, 0.17458194372011349, 0.07879099124693312, 0.23396952106850222, 0.23483317316276953, 0.2511993848020211, 0.16478859266499057, 0.15246549766743556, 0.15666859166231006, 0.15022039704490453, 0.1805705708102323, 0.13217669416917488, 0.10747977838036604, 0.12902737566037104, 0.13006872759433463, 0.1658410025993362, 0.1509482361143455, 0.06853701881482266, 0.24047904676990584, 0.14200185367371887, 0.1425149300484918, 0.19427639083005488, 0.1401999784866348, 0.14528328931191936, 0.12189164801384322, 0.1689439665642567, 0.24139530229149386, 0.23417129617882892, 0.16533871705178171, 0.201146466715727, 0.15863017702940851, 0.1479585684137419, 0.13878314435714856, 0.18373578612226993, 0.12948271294590086, 0.12132325195125304, 0.16282386059174314, 0.08755502058193088, 0.14617220411309972, 0.1450359760201536, 0.1674636045936495, 0.08282204056740738, 0.1598876275238581, 0.12406674926751293, 0.2228895085863769, 0.10048568961792625, 0.10025496332673356, 0.20083817857084796, 0.12031422797008418, 0.1573454006575048, 0.16137987870024517, 0.2412534481845796, 0.1032790592580568, 0.16313131753122434, 0.15041469130665064, 0.08333910227520391, 0.15980517491698265, 0.09131138620432466, 0.13651574961841106, 0.2732848090818152, 0.08009271085029468, 0.23611909244209528, 0.12775315262842923, 0.10835445136763155, 0.21327234338968992, 0.09172538586426526, 0.123606743873097, 0.11475055463961326, 0.109369368001353, 0.11756957290344872, 0.11846320776385255, 0.12754533643601462, 0.13654362468514591, 0.14652453130111098, 0.11590370369958691, 0.16967847011983395, 0.08180819262634031, 0.12105578192858957, 0.11137306282762438, 0.19797083165030926, 0.1338219761964865, 0.1089203760784585, 0.12788975232979283, 0.1531467298627831, 0.14943996939109638, 0.12933787540532649, 0.13703019154490903, 0.09718745175632648, 0.11017490993253887, 0.08247231089626439, 0.13436255656415597, 0.10156630116398446, 0.14548824081430212, 0.13001432816963643, 0.11473885097075254, 0.0891558182775043, 0.1537318539340049, 0.09784971465705894, 0.08561391106923111, 0.09724499788717367, 0.0857097445987165, 0.19867334864102304, 0.09840766128036194, 0.1693872216856107, 0.10729118381277658, 0.11856198019813746, 0.17137687507783994, 0.09044697711942717, 0.18793190392898396, 0.11040309807867743, 0.11254089156864211], [0.03210015427612234, 0.03541309779393487, 0.0445988339924952, 0.03034427554666763, 0.06059374914912041, 0.01835533810663037, 0.016997783022816293, 0.07794784469297156, 0.04995854658773169, 0.020270476161385886, 0.048010557366069406, 0.026017109303211328, 0.015921924932627007, 0.09323354126536287, 0.06004545415635221, 0.016139787949214224, 0.07950985032948665, 0.04085906650288962, 0.01593988861714024, 0.016945469033089466, 0.02802227172651328, 0.017238296386494767, 0.031973618097254075, 0.02209607595432317, 0.032342587946914136, 0.026379095543234143, 0.029369243784458376, 0.013751097521890188, 0.05542892082303297, 0.005878453875993728, 0.05673139741702471, 0.016540853830520064, 0.06315232181805186, 0.10685941713745706, 0.050665471935644746, 0.014421261512325145, 0.02897590551583562, 0.03149531505187042, 0.025873134509311058, 0.03841085490421392, 0.05101858951093163, 0.054791508737253025, 0.024485630056005903, 0.022138975800771732, 0.04265577263140585, 0.05725221439206507, 0.025118151388596743, 0.04731463806820102, 0.014305516160675324, 0.017276670987484977, 0.07330908032599837, 0.05539779886021279, 0.047462188158533536, 0.029385491252469365, 0.02752490105194738, 0.027068166673416272, 0.023518593079643324, 0.04996106988983229, 0.013030901645834092, 0.021479499664565083, 0.032252431847155094, 0.02295523434440838, 0.05791137882624753, 0.01871908323664684, 0.01089852026780136, 0.02557207117206417, 0.01636061027966207, 0.08418158089625649, 0.032099634772748686, 0.0952554632385727, 0.024322942008438986, 0.03899649476807099, 0.038384293438866735, 0.011413621778046945, 0.060009693770552985, 0.021766289646620862, 0.1381899754051119, 0.03425002621952444, 0.09560789432725869, 0.04235873173456639, 0.03755459460080601, 0.03706704068463296, 0.1392431274871342, 0.045001578982919455, 0.03356822257046588, 0.05128152872202918, 0.054334509040927514, 0.021675059288099874, 0.08354914491064847, 0.01708561620034743, 0.003277792852713901, 0.04050544055644423, 0.07920492411358282, 0.03589991327316966, 0.06529375925310887, 0.06031538068782538, 0.03022002518264344, 0.023513761698268354, 0.012180845697002951, 0.029215274116722867, 0.08006819771253504, 0.03818862991465721, 0.0962150824489072, 0.007786399128235644, 0.002160553071917093, 0.04379685065941885, 0.045186258721514605, 0.0433586718281731, 0.03712131023348775, 0.06331363503704779, 0.07606538711115718, 0.013063745391264092, 0.028271737246541306, 0.057531332422513515, 0.010990297960233875, 0.041645668825367466, 0.07359484428889118, 0.042041649139719084, 0.005585164071817417, 0.02101096513797529, 0.04570372118905652, 0.036103844322497025, 0.031900186295388266, 0.02794302890833933, 0.0394578991108574, 0.056241999263875186, 0.02304749628819991, 0.07520658866269514, 0.04851340694585815, 0.013400233292486519, 0.023029660624160897, 0.015231564320856705, 0.06709049877827056, 0.020379985617182683, 0.0465042165160412, 0.08776431364822201, 0.10402493993751705, 0.04140201803238597, 0.04009541138657369, 0.007868316461099312, 0.07496551683288999, 0.04548116594378371, 0.02622328534926055, 0.0329483251698548, 0.050684508023550734, 0.02814906580169918, 0.05223230524279643, 0.009494719179201638, 0.06282544287387282, 0.0018998532914338284, 0.023960161670402158, 0.049595610398682766, 0.06822021823609248, 0.028603315840882715, 0.030446801392827183, 0.010467105184943648, 0.0558448166702874, 0.019797846834990196, 0.0687473731522914, 0.09667921418440528, 0.03054857581446413, 0.021649713089573197, 0.02016101123444969, 0.048924070651992224, 0.06315923121292144, 0.021802558403578587, 0.022784421635151375, 0.04880302265519276, 0.07479593608877622, 0.029120095532562118, 0.046986998422653414, 0.028216148530191276, 0.04138529002375435, 0.016962902082013898, 0.059753140740212984, 0.04936372264637612, 0.01805503918149043, 0.04050517709401902, 0.033722693187883124, 0.06898942461702973, 0.03920147966709919, 0.02185117464250652, 0.051304026928846724, 0.03147605631966144, 0.056247368702315725, 0.049049616063712165, 0.07417423898004927, 0.021005098460591398, 0.00028432726935534447, 0.08800521478406154, 0.012962708478880813, 0.06842223083367571, 0.009513479744782671, 0.05912011103646364, 0.029719585727434605, 0.030078247145866044, 0.023475522539229132, 0.04670656308007892, 0.03037933274754323, 0.02396644209511578, 0.042321394284954295, 0.033539393843966536, 0.030230244556150865, 0.03328122664242983, 0.04118217904760968, 0.012038037002639612, 0.08280324938823469, 0.03817540484305937, 0.04597671650117263, 0.045524633533204906, 0.035340946196811274, 0.004745835867652204, 0.02989406650158344, 0.03804949577897787, 0.017615390897844918, 0.07019440527074039, 0.008873038768797414, 0.01309662717176252, 0.08437108830548823, 0.011266231249464909, 0.044597817250178196, 0.05301207238517236, 0.07477728591766208, 0.010962145515804878, 0.05225885928666685, 0.026754423743113875, 0.015317921552195912, 0.08928669602028094, 0.0007555244826562557, 0.019825781273539178, 0.01733595931000309, 0.020780958730028942, 0.035708287032321095, 0.03597819872084074, 0.03735926504305098, 0.07881949713919312, 0.08139679790474474, 0.032502012400073, 0.043214023535256274, 0.08221733864047565, 0.04593002056935802, 0.0228178795077838, 0.025590932855266146, 0.03775226934521925, 0.01096708914701594, 0.0380038536968641, 0.04221538591082208, 0.03894540532201063, 0.05718261207221076, 0.01775788881786866, 0.05282510683173314, 0.03082931914832443, 0.0903061917051673, 0.04935275370371528, 0.09225512345437892, 0.036582407119567506, 0.04996646901417989, 0.015335916777985403, 0.06761282231309451, 0.023312179546337575, 0.03160686726914719, 0.005319218698787154, 0.020849954344157595, 0.038338573431246914, 0.05090422826469876, 0.01466269977754564, 0.0338996211939957, 0.03736192193173338, 0.12570822407724336, 0.03604653938964475, 0.03296140181191731, 0.051841724052792415, 0.03787346577155404, 0.0376702583162114, 0.03951456950744614, 0.01730969099298818, 0.01266748491616454, 0.09224480018019676, 0.009273465475416742, 0.028623685939237475, 0.07806969792000018, 0.060291208937997, 0.021565030328929424, 0.008408687172050122, 0.020164163506706245, 0.020018119976157323, 0.0217258017801214, 0.05198813865717966, 0.024370521095988806, 0.059646991358022206, 0.07190409087343141, 0.0621176455024397, 0.03961993963457644, 0.05378589492465835, 0.024979226909636054, 0.026642567245289683, 0.09407216071849689, 0.05231764851487242, 0.039230390029842965, 0.021026668982813135, 0.009464262366236653, 0.04499781258346047, 0.06290158722549677, 0.06471512155258097, 0.03048128157388419, 0.0191716894187266, 0.04941868610330857, 0.03940663897083141, 0.034754857333609834, 0.02574052385170944, 0.06393372910679318, 0.01740044266625773, 0.0295338335854467, 0.011544346452865284, 0.05153044876351487, 0.06033739278791472, 0.09417091830982827, 0.03793118259636685, 0.024142551883414853, 0.04430108063388616, 0.044411942653823644, 0.011988248170382576, 0.022841294266982004, 0.0458248322684085, 0.007385787348539452, 0.03156843515171204, 0.011637835723377066, 0.06582759349839762, 0.02283877838635817, 0.004977262096872437, 0.03276274001109414, 0.014210455392458243, 0.026986304073943757, 0.058626315658329986, 0.03696806415973697, 0.07583194455946796, 0.03011944190802751, 0.03323547694890294, 0.03390818186744582, 0.034788699267664924, 0.05238002231635619, 0.05221212995820679, 0.07712846170761622, 0.013123825956427027, 0.07767081580823287, 0.02900756739109056, 0.033186536020366475, 0.06151453548227437, 0.043636101472657174, 0.03565764658560511, 0.013158134515833808, 0.01467458898332552, 0.1748849923023954, 0.16131468844832852, 0.09497714301687665, 0.18737130041699857, 0.1375061011640355, 0.08409097950789146, 0.12300432033953257, 0.1572053722338751, 0.1070872787386179, 0.14973866898799315, 0.1663605505018495, 0.09498232320765965, 0.08307003663503565, 0.23359495913609862, 0.07375481422059238, 0.16479990299558267, 0.16498598910402507, 0.13564299879362807, 0.09640609641792253, 0.09379959956277162, 0.10227169026620686, 0.15457613597391173, 0.07337879025726579, 0.09029345645103604, 0.14596913766581565, 0.11740311660105363, 0.11516724829562008, 0.17307762522250414, 0.1427826375584118, 0.17027337569743395, 0.16117921681143343, 0.13036618038313463, 0.12973924371181056, 0.17136966140242293, 0.15903924882877618, 0.1172811965807341, 0.06037406601535622, 0.15304881089832634, 0.13254589779535308, 0.13564613065682352, 0.07671524872421287, 0.10287604338373058, 0.14436400582781062, 0.07537913057603873, 0.13110538915498182, 0.13151132909115404, 0.21369928610511124, 0.12921616318635643, 0.15738090500235558, 0.11530742514878511, 0.08263219177024439, 0.15029336500447243, 0.11729190577170812, 0.09957822112482972, 0.0753942555456888, 0.08533707514288835, 0.12404446257278323, 0.13099222647724673, 0.1114539495029021, 0.17607717833016068, 0.17331505310721695, 0.15626266656909138, 0.1850722308154218, 0.13352300942642614, 0.09240613566362299, 0.0624951500503812, 0.13876745535526425, 0.2415007763192989, 0.17312108539044857, 0.15490627294639125, 0.20247142296284437, 0.13541538210120052, 0.1290798158152029, 0.13734235370066017, 0.23513812164310366, 0.1102962288132403, 0.31872657069470733, 0.13676227623363957, 0.25885781447868794, 0.1165908359689638, 0.06680794089334086, 0.13508917851140723, 0.3803678130498156, 0.11553229589480907, 0.1302910305093974, 0.1594404538627714, 0.1896189688704908, 0.09677925569121726, 0.2098272938746959, 0.09653476998209953, 0.19466618163278326, 0.09144465366262011, 0.4223186307353899, 0.16530754684936255, 0.166435819119215, 0.1659715166897513, 0.1600800664164126, 0.10107411624630913, 0.16279686125926673, 0.09006981767015532, 0.13181501592043787, 0.17156005196738988, 0.11781058536143973, 0.08952947478974238, 0.08234080232796259, 0.15423222474055365, 0.16666768089635298, 0.25231287349015474, 0.15853190183406696, 0.27160820842254907, 0.16216204297961667, 0.14513903064653277, 0.1105963162262924, 0.1438003743533045, 0.22721591783920303, 0.1553359319223091, 0.13306602457305416, 0.23474907298805192, 0.12141964209149592, 0.1594639354152605, 0.11038501936127432, 0.1291827962268144, 0.12402786072925664, 0.14567232312401757, 0.15174724714597687, 0.13565542234573513, 0.15378053882159293, 0.17428633145755157, 0.17859066923847422, 0.10154753224924207, 0.1726523894467391, 0.09495921272900887, 0.14983087341533974, 0.09589535780833103, 0.13377223745919764, 0.17865477595478296, 0.2630795957520604, 0.17869835486635566, 0.14144570304779336, 0.06397353048669174, 0.28169096738565713, 0.11589551038923673, 0.09579138291883282, 0.11977205198490992, 0.1132166912429966, 0.11079415053245611, 0.11721277056494728, 0.10491564331459813, 0.2088190714130178, 0.11293979594483972, 0.07030646214843728, 0.1871950106578879, 0.12193851463962346, 0.12287149074836634, 0.08394442760618404, 0.09708822661195882, 0.11576474396861158, 0.1031628018245101, 0.13097132759867236, 0.21016403596149758, 0.09930036845616996, 0.11694751956383698, 0.10096795944264159, 0.11491929675685242, 0.279892684193328, 0.15965555794537067, 0.1709384290734306, 0.08116629425785504, 0.15673925896408036, 0.10615705599775538, 0.146524308656808, 0.1555710591492243, 0.14637561194831505, 0.12077899053110741, 0.08460427110549062, 0.08412980125285685], [0.006871876521472586, 0.016515060488018207, 0.016412805525760632, 0.03169692317896988, 0.02304085221112473, 0.06888825504574925, 0.018288429782842286, 0.043992666323902085, 0.014411866850423394, 0.0212012536576367, 0.049625481842667796, 0.01753288262989372, 0.023259299669007305, 0.03812994087638799, 0.05734523889259435, 0.0590651438687928, 0.024591154178779107, 0.02716533977945801, 0.033810244349297136, 0.03728529889485799, 0.007295442001122865, 0.05361047718906775, 0.05540350226510782, 0.031395767073263414, 0.013056154148216592, 0.0702137679036241, 0.05239081314357463, 0.05855093571881298, 0.030738009008928202, 0.020113174250582233, 0.028754012637364212, 0.005553962328121997, 0.03015433769178344, 0.05651759209285956, 0.08206630416680127, 0.024139123161148746, 0.024191208940465003, 0.02026337566348957, 0.01711681794404285, 0.019038583377550822, 0.028383614153426606, 0.015853779077588115, 0.03642423318524379, 0.04253839826560579, 0.03413365004234947, 0.05636135145323351, 0.0668746599694714, 0.019294702251499984, 0.045844072446925566, 0.02748430000792723, 0.026653974055079743, 0.07073405795381404, 0.012651324650505558, 0.03839329569018446, 0.042214899804093875, 0.06055238554836251, 0.012104691140848445, 0.049154425869346596, 0.029697376958210953, 0.0190298241795972, 0.0151882089812716, 0.011536443507793592, 0.04892774057225324, 0.052601085844798945, 0.006980680473134271, 0.03292574532679282, 0.03434612321143504, 0.02364230909734033, 0.030983019787527155, 0.052265501508372836, 0.02297587718203431, 0.07063977551297285, 0.052610956408898346, 0.025599192958907224, 0.07407761135254987, 0.002793576745716564, 0.05633834116451908, 0.037863880934310146, 0.013872577819711296, 0.046463223989121616, 0.011592817045311676, 0.02843511178070912, 0.03673408355098218, 0.057649326481623575, 0.04823307550395839, 0.07753864672849886, 0.040752750137471594, 0.045073166547808796, 0.029051216806692537, 0.03549919063516427, 0.025614824444346596, 0.03042267788259778, 0.045004573548794724, 0.04790288287040312, 0.07112410850822926, 0.032746843207860366, 0.019364991057955194, 0.01017100403259974, 0.07516266836319119, 0.02412097208434716, 0.03200814280717168, 0.02455677604302764, 0.03704945178469643, 0.05307135885232128, 0.02752762102318229, 0.0635116919875145, 0.010420526141388109, 0.021925224282313138, 0.06588067190023139, 0.07163193047745153, 0.049408681952627376, 0.052542894045473076, 0.008683433024998521, 0.06146217325294856, 0.0337409797066357, 0.0545562738989247, 0.026249791153531987, 0.040195972396759316, 0.035268019055365585, 0.018417483697703574, 0.018711069897108246, 0.02818385954014957, 0.06399579491699114, 0.08231615560362116, 0.03366596713021863, 0.027309140168654267, 0.03902775402821135, 0.026599351986078545, 0.017254829581361264, 0.03876280359691009, 0.03756766382139176, 0.05923029770201538, 0.011040379940823186, 0.14149447699310258, 0.04896028003713582, 0.04943201507558115, 0.021374546995502897, 0.034389976717648096, 0.04013866746390704, 0.02624362205096986, 0.11455372965428978, 0.10043963935459033, 0.012852188774559181, 0.026540186117927078, 0.03208295500371605, 0.05063003067334648, 0.027758009637182113, 0.046103330605546944, 0.017955871553567704, 0.03501028229948133, 0.024051228756434284, 0.07872435380704701, 0.024758194922469556, 0.036176556241116486, 0.01633383915759623, 0.04004084868938662, 0.04365535278338939, 0.07509610513807274, 0.05071276529633906, 0.024970669946924318, 0.046735807409277186, 0.013501656121661654, 0.011349795222486136, 0.040957330566016026, 0.03143755740893539, 0.03587084334867541, 0.016031697850849014, 0.033897468965733424, 0.0258259840120445, 0.01998084189835936, 0.01865282429207582, 0.029609970515593886, 0.021074910437164363, 0.09658699491410516, 0.010099434093717718, 0.03199682505510282, 0.03189518422004767, 0.017990756205108482, 0.02899852432165062, 0.017174503227579407, 0.05233853997197002, 0.04450006897968706, 0.04944468353642151, 0.06338440623949282, 0.08246678931755014, 0.06668817310128361, 0.009903009868139634, 0.040569139091530815, 0.024178633248084225, 0.028659865638474002, 0.010375200399721507, 0.03442298373556696, 0.017472848448960576, 0.005799525542897754, 0.03578921081498265, 0.07005338979070075, 0.0389389263727935, 0.02245218252937775, 0.005199246352276532, 0.031025431671878323, 0.010996433666150551, 0.04919287282973528, 0.020646813682105858, 0.021068192145321518, 0.07178490937803872, 0.05079344045952894, 0.04079644408193417, 0.0375650885689538, 0.03622764939791523, 0.07288725842954591, 0.02899543698731577, 0.008054064892348833, 0.01927618566696765, 0.013468456145346863, 0.00562018277378229, 0.04983084523701109, 0.05384784941270482, 0.1171721305581741, 0.019963041486334987, 0.05436136736534536, 0.06784094366594218, 0.04176046422799118, 0.047830215480644256, 0.03761938409297727, 0.06101626124291215, 0.09369006598717533, 0.07961936164065264, 0.037774311131215654, 0.007187784203779302, 0.03753035605768673, 0.09232705982867628, 0.058141715489909984, 0.025299179760622792, 0.061953319163876586, 0.018710813856159803, 0.052550638356478885, 0.037786419270560145, 0.024409044126514345, 0.02794419036945328, 0.05833104849443771, 0.049826273607322946, 0.01591780972376, 0.06082922889618203, 0.027796222821052652, 0.06876608269521967, 0.0099425227381289, 0.009492867520748405, 0.0836198493198026, 0.017292677257501055, 0.05011323984945193, 0.01665118707023794, 0.05544127016037237, 0.02751841653662268, 0.028853788826381788, 0.03042305266717449, 0.014245404981920728, 0.042773161840159446, 0.0486007503059227, 0.02649021174875088, 0.02752037951722741, 0.04960764061252121, 0.04563802998745814, 0.032722088872105815, 0.038483778334921226, 0.050397627128404565, 0.06552772130817175, 0.06176228664116934, 0.06317629318800755, 0.014034362302481895, 0.06071974727092311, 0.02444384343107231, 0.026989229991158936, 0.02346806209970964, 0.03526032298395876, 0.028351076543913223, 0.019788644203799777, 0.025587546806491446, 0.029885630137869157, 0.03754192985070404, 0.060269078094279394, 0.0047794324291317025, 0.048144077154574916, 0.03971689751779195, 0.010187665247940458, 0.0806546131207142, 0.12277468500542454, 0.06384730600984767, 0.0695520912995562, 0.054397580461227335, 0.02594638819573447, 0.025872349688143004, 0.07445241077220999, 0.03810035144852009, 0.07569702211185358, 0.02933731102530146, 0.02321029194717994, 0.04034550402138848, 0.04315939775551669, 0.08384299828321673, 0.037495519645744935, 0.03507694571453612, 0.020594438465195708, 0.05423972936114296, 0.03459821222350001, 0.04126907340832986, 0.02632935495057609, 0.040644396576681174, 0.027157838521816302, 0.05025875274441205, 0.048932735226117074, 0.005241915669103037, 0.09105176068260334, 0.026239610742777586, 0.03383414892596193, 0.10785293765366077, 0.020857333147432655, 0.03306101658381522, 0.018596242953208275, 0.02658650540979579, 0.019128075255139265, 0.039681203925283626, 0.008887237909220858, 0.05879297234059777, 0.005020138287363807, 0.04226584453135729, 0.027116610363009386, 0.040400756915914826, 0.10379003535490483, 0.043163739319425076, 0.0832811182772275, 0.033655617880867794, 0.04437816751305945, 0.0672511885932181, 0.03645746284746565, 0.05114542997034732, 0.022193705481186043, 0.040913733100751415, 0.03399769229872618, 0.013870587936253287, 0.023193133492895868, 0.04173130524577573, 0.03536438322043978, 0.033946346811717376, 0.022063638534746133, 0.009701179096737178, 0.03107072123384569, 0.02738739593041828, 0.02192862331867218, 0.013849387560185278, 0.04747060411318671, 0.014797812400502153, 0.05489837800269015, 0.12884341209428385, 0.09120510323555209, 0.15085410210303962, 0.1316625639447011, 0.1554973193560727, 0.13313173432834446, 0.1568050280911848, 0.177637365704868, 0.14239010080927983, 0.10417958867037669, 0.071105176320998, 0.09269523929106072, 0.13463719573337585, 0.11124534663395025, 0.21465220372192562, 0.15122290496947244, 0.06808897684095427, 0.13796639599604532, 0.13392823690082878, 0.1347054584766738, 0.10356178783695213, 0.16777877986896783, 0.09855341908405535, 0.19078234472544864, 0.24168140022084117, 0.181028327497188, 0.06398337136488408, 0.14909843303030357, 0.14204452716512606, 0.14214551862096414, 0.18418788764392957, 0.14387795847142115, 0.13508635835023597, 0.09921318836859427, 0.2208461830741726, 0.16935811465373263, 0.2199989027576521, 0.08007934477063827, 0.10502758144866675, 0.09356760419905186, 0.20779449201654643, 0.16215830255532637, 0.11124973272671923, 0.18749163224129006, 0.2591970353387296, 0.18391220946796238, 0.1417965310974978, 0.11248874085140415, 0.17053340940037742, 0.13423990923911333, 0.12945296766702086, 0.2138147345976904, 0.12206602303194813, 0.10498473726329394, 0.15985737758455798, 0.14938669803086668, 0.11915957235032693, 0.17279247724218294, 0.1896319564548321, 0.09169653116259724, 0.16104833164718002, 0.13596841570688412, 0.08067164540989324, 0.21957831282634288, 0.1128054375294596, 0.07568733708467335, 0.14654304046416655, 0.13194468396250159, 0.07231996816699393, 0.13077301089651883, 0.11808771814685315, 0.14560750394593924, 0.1357309432933107, 0.08682604602654465, 0.14537059556460008, 0.13621463062008843, 0.11100051953690127, 0.09209809242747724, 0.13697622256586328, 0.08713480914593674, 0.15815630089491606, 0.12362012479570694, 0.09508292132522911, 0.09423776355106384, 0.13257021055324003, 0.17783339659217745, 0.16939912573434412, 0.14675810001790524, 0.22505134023958817, 0.1590878001297824, 0.24882149911718443, 0.20292871951824054, 0.16289003047859296, 0.118322348134825, 0.16016622976167127, 0.11159886867972091, 0.12819768424378708, 0.14490497211227193, 0.28296921285800636, 0.1119402788754087, 0.11345777791575529, 0.08609851865912788, 0.15197477478068322, 0.15087084495462477, 0.09003600542200729, 0.11161692513269372, 0.12836938753025606, 0.09358128198073246, 0.1637485172250308, 0.1654895066167228, 0.1452224183594808, 0.20894249057164416, 0.18903305812273175, 0.14574984787032008, 0.11644493715721183, 0.19232031219871715, 0.16193133895285428, 0.13463290611980483, 0.11609040579060093, 0.16738613921916112, 0.09973842854378745, 0.08490089268889278, 0.16835047106724232, 0.14965682494221255, 0.19894098193617538, 0.11198995824088342, 0.11051298788515851, 0.14200759789673612, 0.09622415149351582, 0.16402213223045692, 0.10433998162625358, 0.10208319217781536, 0.16068157710833475, 0.2505977702094242, 0.11274751290329732, 0.18062427261611447, 0.21482132433447987, 0.10323864189558662, 0.14198214223142713, 0.11517224294948392, 0.15207177348202094, 0.194502018566709, 0.13174506108043715, 0.09513311277260073, 0.09584084706148133, 0.08947502341470681, 0.0791285496961791, 0.07855150761315599, 0.13157000328646973, 0.2185039353207685, 0.1242066292616073, 0.1315462842467241, 0.13513290585251525, 0.13830989162670448, 0.11646202139672823, 0.15314607677282766, 0.16070784913608804, 0.13911403832025826, 0.1575536176096648, 0.0722961823339574, 0.20228230889188126, 0.16730295930756256, 0.1029679064231459, 0.09350987253128551, 0.12704075023066252, 0.09617863557650708, 0.15446168195921928, 0.17974200745811686, 0.10419749669381417, 0.08282503884402104, 0.15614969684975222, 0.12966667651198804, 0.16624939162284136, 0.18647655233507976, 0.14272313215769827, 0.14735720615135506], [0.06612770317588001, 0.1159291816293262, 0.02264923015900422, 0.035804717990686186, 0.04131913126911968, 0.0995319927460514, 0.02993119243910769, 0.06510255232569762, 0.036255565282772295, 0.031056214102136437, 0.09355942573165521, 0.035313163898536004, 0.002023456595452444, 0.12100209496566094, 0.0405200089153368, 0.05742769892094657, 0.060241837563808076, 0.06764739155187272, 0.058862222140305676, 0.040769288898445666, 0.027372473196010105, 0.02785652603051858, 0.0243546094498015, 0.03683033268316649, 0.051350366629776545, 0.06326689457637258, 0.04314634337788448, 0.042563442038954236, 0.03181114712788258, 0.018272698107466567, 0.00965127337622107, 0.0042463843965379056, 0.017973094945773482, 0.03268854379712138, 0.039012855413602665, 0.07268753906828351, 0.05608010716969147, 0.025338739942526445, 0.011843581323773833, 0.06366104178596288, 0.056406021321890876, 0.008725020197744016, 0.014684530979138799, 0.052032830790267326, 0.027880803536390886, 0.07768792973365635, 0.03627273486927152, 0.049389230262022465, 0.041130740792141296, 0.025673867858131416, 0.09608355903765187, 0.018820820550899953, 0.007902754896349506, 0.06208630460605491, 0.09067080143722706, 0.02688429030968109, 0.029786306658934336, 0.10682603533496149, 0.03836090465483721, 0.05080862480099313, 0.07718348453636281, 0.08623451722087339, 0.07134527593734674, 0.037922017072560266, 0.008158761520462576, 0.012983547985641053, 0.038815930238342844, 0.0643087734351866, 0.024933087588578928, 0.0639802469231654, 0.061120978280087, 0.02060032926237909, 0.04687565400672611, 0.02476928631949704, 0.04100362573808525, 0.03675220679724589, 0.0419183041958604, 0.003675948355521541, 0.0639368015981745, 0.00155829431832899, 0.0181710164542892, 0.06758048693882301, 0.022874343958392274, 0.03923291704268195, 0.046090420946711674, 0.045722486393060535, 0.008797237660473911, 0.052551350818248466, 0.06852732636616565, 0.06589564101886936, 0.04024418973131105, 0.037700693792430684, 0.062344746402231976, 0.02475831552146701, 0.0105242162317154, 0.024905618847697042, 0.0683185453817714, 0.1385901859612204, 0.0698717194609344, 0.04011121542134788, 0.0063384940585820004, 0.025395278607902583, 0.020790500893781427, 0.0746739492751658, 0.024054327222984284, 0.01857947041571606, 0.02932867984782206, 0.00624504653387703, 0.015219994238577783, 0.035789500252576545, 0.05241402752290014, 0.05926642916165292, 0.02645732161909109, 0.011639907243079506, 0.07610232380102389, 0.035032665473409, 0.04049589282658417, 0.029566224620793946, 0.05775049976364244, 0.04516132998105604, 0.005043763167122961, 0.04284989248844795, 0.0835897923388984, 0.06148689419205766, 0.08724078783416189, 0.02146234121028101, 0.04209910621284507, 0.0406211302470183, 0.040979591285577044, 0.020583380464813672, 0.03134396145469509, 0.045275093798409216, 0.013631032870762283, 0.05991768972307909, 0.09241068502888083, 0.053917652112431824, 0.03473002136161085, 0.02149322197510628, 0.017199964458995964, 0.06248669698834419, 0.045201669418020174, 0.0473222784785321, 0.045705765805905685, 0.020874680849374272, 0.0469559506746009, 0.05443129251943901, 0.027083824134024326, 0.03006722625286784, 0.06776643203920685, 0.06296419480349869, 0.05304064878146164, 0.033617163499002345, 0.014369601540238364, 0.027140802521898877, 0.010788833624246763, 0.05826776927278843, 0.059876630402868614, 0.019763362943194807, 0.02776321765850298, 0.030663135585200507, 0.029183576989453286, 0.04339214639912825, 0.020494964701356366, 0.035156875019310974, 0.012881425682280678, 0.023269478224392515, 0.00869287036039168, 0.025513059299555607, 0.03243179038690869, 0.01811169659049483, 0.02334055556275416, 0.037159267376409844, 0.019805594856734388, 0.07029438740573823, 0.010407642457721522, 0.06462207849835977, 0.01778531488525914, 0.09904522550641559, 0.026767296294565313, 0.05905735131818801, 0.029613768456329126, 0.06994565963395871, 0.0669003753864672, 0.0292047319089761, 0.04500761264353059, 0.0258266704986454, 0.0983929741778411, 0.020427844865480438, 0.021430317538033705, 0.026060773561766837, 0.046903729453333654, 0.04702813566836994, 0.057106901876977645, 0.05467394141305704, 0.07040605836664326, 0.051737582180066966, 0.06240548376808874, 0.05675623338902369, 0.04889434021606576, 0.008971580209617969, 0.008662834716233192, 0.02592722408735426, 0.07845841260859743, 0.030217691128200386, 0.03257620119256899, 0.0659462925978005, 0.11163478120579384, 0.05779614184575621, 0.024642056232551113, 0.05470400952617638, 0.05686513984983321, 0.1259627955732867, 0.0579223626118619, 0.03164455723890569, 0.031121868196350988, 0.020030738342029508, 0.015362470821855823, 0.022966618889768142, 0.045376708658295684, 0.012723034669761546, 0.05297859781421721, 0.03402691065275576, 0.02309948187757982, 0.08920644017052837, 0.02803361916448921, 0.01901582356367726, 0.04115098658076022, 0.047517511557089165, 0.010988175417878665, 0.006405834683391731, 0.054754694501752965, 0.030326855485327542, 0.004357861007520114, 0.03517481643939391, 0.06746120154275559, 0.0429460451414343, 0.03072227176744491, 0.08038485728320666, 0.03284872895164881, 0.06715266848914325, 0.02755572430032771, 0.06287413518293761, 0.022499778315250296, 0.04094659168913495, 0.03679322901007254, 0.07998340734047815, 0.05403835872130003, 0.005948904563410906, 0.0143397375177301, 0.005478613002196653, 0.05190452829992864, 0.037642835959559307, 0.021467244951054454, 0.027748220709327143, 0.05056336725829169, 0.04433213209267706, 0.025100514249061234, 0.05321992197423242, 0.030417182279052213, 0.047415963490493596, 0.069846976257395, 0.04370234557427466, 0.009950780058716191, 0.0682788627455011, 0.0018276511354997638, 0.05755269143264741, 0.04462508004507981, 0.05256434582406655, 0.07496867096051574, 0.035284591212985106, 0.025233102642232552, 0.008636571965325857, 0.03818509358097799, 0.026632416520442348, 0.03255257863202132, 0.023757829949317966, 0.03674592822790146, 0.028483707610575948, 0.025365882138430607, 0.029473396789398976, 0.0387649929325562, 0.046058738662395626, 0.04793639083800372, 0.030694543274876196, 0.013227439976617461, 0.10720559192122892, 0.024302996789629105, 0.05437812505988404, 0.012973294287803583, 0.05387721619626973, 0.03688855787913781, 0.049043248436646536, 0.028259697755856905, 0.031640787128708325, 0.05944584707322065, 0.042094382442883216, 0.03447934614086989, 0.04228786776366178, 0.0557796820794465, 0.03296533890534192, 0.05484918103320524, 0.06377880577929318, 0.03769668248423841, 0.037814613460795954, 0.029900291265221313, 0.058074228290934116, 0.05251962400507182, 0.06518211797811091, 0.019073840958299115, 0.055832348589319736, 0.010470989400346298, 0.0885546267090831, 0.06062065942387562, 0.010657654383976478, 0.009025705967360409, 0.014518583047902212, 0.08058437626459636, 0.020805661115446128, 0.05091279264888726, 0.005819635425723391, 0.06565899238921702, 0.0681464487570338, 0.022424465169024188, 0.04408601736940909, 0.05941501083725598, 0.0031366045914182905, 0.0487521335890051, 0.06521788949612528, 0.034300889310543425, 0.04437319512362592, 0.023643821223231498, 0.05588415791862644, 0.07443712253007106, 0.006595912154807593, 0.041493064709356986, 0.03321209558635019, 0.008483678411721485, 0.02216837598098209, 0.10035407714894973, 0.004539765577646904, 0.053127031060284935, 0.0945813037105836, 0.010013510091084754, 0.019545587128959596, 0.03514380208798684, 0.029404083907138556, 0.058178025064989924, 0.039548177664983086, 0.04508331170654856, 0.011211041437491076, 0.006718694921801216, 0.024045287864282727, 0.20346913661342114, 0.286465025274083, 0.19840816443320364, 0.17027514200890437, 0.10924819012871012, 0.2678760071285069, 0.1948853675276041, 0.12088171119103208, 0.1277318233042024, 0.10182939251535572, 0.3194311953848228, 0.06881395122036338, 0.048839588271221146, 0.1709293748717755, 0.17466981400502846, 0.15541865170234814, 0.20725300622871146, 0.12015511892968789, 0.17587328067747876, 0.10279698981321417, 0.15266374015482143, 0.11135777458548546, 0.15666638006223366, 0.16567916987696663, 0.12342754489509389, 0.1725110548431985, 0.15563844615826383, 0.08945603927713819, 0.08947460781200789, 0.12701403291430324, 0.20631837513064966, 0.12976032070582733, 0.13563373679062352, 0.12526872422313318, 0.14015573164215311, 0.17281146137975156, 0.14719491329742596, 0.08464622471365146, 0.10520988260395825, 0.16930880636209622, 0.12100804699002765, 0.10435413438244723, 0.13698570721317083, 0.15455226850463077, 0.10806762613356113, 0.2235015874612145, 0.16488422581460327, 0.1495890668593347, 0.1163245904899668, 0.11143146242829971, 0.15899550664471462, 0.14556699752574787, 0.1266241678968072, 0.17454744869610295, 0.18709916970692575, 0.11862944884342141, 0.08791427200776525, 0.17540209111757576, 0.21070080169010907, 0.12782417616108432, 0.18337582965614274, 0.11990880753728561, 0.10365312395151705, 0.18797615077346563, 0.0861139850167092, 0.1281385647598654, 0.26595331029966474, 0.15292361058527604, 0.07324299207539298, 0.1550149530521594, 0.16859834839124233, 0.10316598563804291, 0.1109643027302809, 0.14322041562991217, 0.17701868171570823, 0.09783036686712876, 0.1939747523283586, 0.1300384776550345, 0.11406196033931337, 0.1391881046583876, 0.11922859208425507, 0.12438663718057796, 0.11563588486751541, 0.11797905288403854, 0.1503574420348741, 0.1417527740704827, 0.1127628976246342, 0.20891424443107098, 0.13743301446083933, 0.1782172205275856, 0.19320564984809607, 0.28402377502061427, 0.19724360114196315, 0.29334417020436376, 0.12455951306037605, 0.08379168619285338, 0.23800019931513816, 0.17255542043130845, 0.1497179630678147, 0.23231272090924904, 0.09482261302764527, 0.15449101163540035, 0.13141419680323452, 0.1557648487505503, 0.15924804465612397, 0.13117624941514805, 0.1295912594650872, 0.11451491533080116, 0.10921874170890078, 0.1907473153551109, 0.12036288317176513, 0.13166579970857129, 0.07162105801398866, 0.06781568838050589, 0.17665922991000116, 0.14289447921328247, 0.1158249618310947, 0.08371371615794487, 0.15408321633003652, 0.10182622354477644, 0.14936695690266788, 0.13178363791666925, 0.24499581690179184, 0.13319368881639093, 0.21295961720170453, 0.14848985709249973, 0.12639754568226635, 0.12759663368342444, 0.13007928093429655, 0.12497248855652288, 0.18151384050725028, 0.17477534740464762, 0.11003136372892186, 0.07683848976739682, 0.13294452015543357, 0.22950783313717693, 0.1984311264823191, 0.14779820514377207, 0.1110365211206954, 0.16133019933477044, 0.17444670957047492, 0.18715045211138204, 0.13861121842637658, 0.18964883289299905, 0.1674877540790476, 0.13876178534701467, 0.07179118052590638, 0.18010548170423135, 0.18303001852473244, 0.11991654813755304, 0.1370761898579076, 0.2050243367557414, 0.14468232780927792, 0.15898091602139175, 0.1052738334692549, 0.16779549303464592, 0.24227094749221578, 0.07800610328558832, 0.12440847858670168, 0.2220135071547702, 0.08545380755094811, 0.13725679891649634, 0.21921531355474144, 0.12766004278091714, 0.1685026558698155, 0.13267602596897632, 0.0958631411776878, 0.07720284716924652, 0.16049589175963774, 0.1426720872404985, 0.16467676585307345, 0.08871619967976585, 0.1094658843067009, 0.13644263322930783, 0.066199016146129, 0.17766230186680332], [0.045980646173120476, 0.02893356042477535, 0.0699781953881029, 0.022278835385804996, 0.03567339495930355, 0.06948293055756949, 0.01343988902590354, 0.04497545167396311, 0.03283042387920432, 0.03808356777881272, 0.07705439536948688, 0.04088820322067477, 0.010026370582636446, 0.07745591952698305, 0.020852293964708224, 0.03801714185101446, 0.029911171150160953, 0.06502893869765103, 0.06380250255460851, 0.05590321256022435, 0.035846133541781455, 0.028202706380398013, 0.039989762954064645, 0.038731585154891945, 0.05029453168390319, 0.061249072969076224, 0.025813471402216237, 0.054463015621877275, 0.0593204797769431, 0.03836120151390787, 0.051260340405860916, 0.004455606031115167, 0.03644897267804481, 0.023323230125242844, 0.019295147540105972, 0.06629401104873978, 0.04719223936263006, 0.05945221098954789, 0.012314021314523416, 0.023725809987809043, 0.006399805197361275, 0.03990391873230692, 0.03214226002455689, 0.05816064396640286, 0.0376993616373511, 0.056993947000592016, 0.04750100619276054, 0.06385089058312587, 0.0221587688793079, 0.034500126275816, 0.012533231329143746, 0.014769439167139353, 0.036350159425637685, 0.03411729310755618, 0.03846441199129913, 0.016179917729459703, 0.05153922094905283, 0.03408274242246989, 0.003053067289329192, 0.04404187813634053, 0.03630805738794152, 0.047324638508143835, 0.055575461592525244, 0.037265613427734934, 0.012509901916928357, 0.022891283479111735, 0.0704731336736586, 0.02670103363925591, 0.05622124139335938, 0.040318875762750395, 0.04016860941192135, 0.05366121040424332, 0.008668360005685827, 0.03838043056020979, 0.006151683428470278, 0.008493569384881994, 0.013654884569405112, 0.04701180099800695, 0.01565650694828946, 0.04170545995293651, 0.04878237610682845, 0.0668607595434878, 0.06162206896988209, 0.0335790616372833, 0.04336355887062382, 0.02859918949980056, 0.07615704234922305, 0.026039314361696597, 0.03455878933891654, 0.04359765080153011, 0.07208369803265668, 0.06961745966691524, 0.034789148267009296, 0.024709337485546712, 0.02250024030217901, 0.02421292974759126, 0.028574147581821308, 0.060357753609423526, 0.05000111246772576, 0.011740214067685883, 0.036012337513966486, 0.032156279194168746, 0.04983468214049935, 0.017319190483249258, 0.040479732560925186, 0.03377654342330061, 0.04023567358672153, 0.09214321500621736, 0.052265490376157686, 0.018720740081334952, 0.009142049675574526, 0.02537827971536899, 0.03346954661537893, 0.04057325430039782, 0.03272610389103647, 0.03061058967432473, 0.019367863169463817, 0.05536945995118003, 0.017708602790662553, 0.04589962220052257, 0.07655579087440856, 0.08521058349288069, 0.06543222916661762, 0.04989421722711995, 0.02649178324645618, 0.039395343483192846, 0.060062735065002926, 0.012408854800014524, 0.011264382374065462, 0.003166678270645207, 0.06797445603297092, 0.05229556220001541, 0.026616159775585402, 0.07157431755331345, 0.06277268359554, 0.13375353533774614, 0.05478099250467494, 0.05807672561786603, 0.021334035009203944, 0.03211442206520587, 0.04386218191939406, 0.04933301257551648, 0.028506463713711128, 0.00613247247201798, 0.026853378003579564, 0.040136470706784166, 0.041748226212803274, 0.013551474639825756, 0.029164143852540292, 0.041655813984107226, 0.01640548238356132, 0.05432211146398913, 0.029543596538132988, 0.02101470741763478, 0.007772862354613608, 0.032023983949329704, 0.044329523443593644, 0.08365715708350763, 0.02427510502457153, 0.014487564058072167, 0.03282295416283887, 0.011929136107937666, 0.017091614608943928, 0.014932789581507677, 0.06747424849891104, 0.018010326639341656, 0.028865585263702087, 0.029992538366059307, 0.025242496376449708, 0.06202437980391551, 0.010282759412802989, 0.017710621432343032, 0.012928984360769391, 0.011500584787427215, 0.04961059064953588, 0.004851161465921905, 0.04601442502462305, 0.03781135914323386, 0.029853884771000594, 0.012176725849712966, 0.0436370031820843, 0.009013504131871741, 0.06872060388559476, 0.041111816026386805, 0.09644583842600696, 0.017811082252592314, 0.06020573950081598, 0.012807645071006846, 0.02896357844292652, 0.034191433660453185, 0.042555040927254595, 0.01744684916047845, 0.040831955848261714, 0.08450796260149218, 0.034239561937283725, 0.0643608054087963, 0.08621866494650021, 0.01733181441522902, 0.07695898486417718, 0.06760108153684996, 0.030418024616665207, 0.0710669111867901, 0.05978128669084981, 0.008403751890000422, 0.05852680478710681, 0.02452979897498153, 0.026314124224882107, 0.036685847662738524, 0.02341277209779946, 0.049802977591753006, 0.03836556905298494, 0.03482542815618217, 0.0697764870710671, 0.02885059016989544, 0.028323516889940947, 0.05030252090364229, 0.04031045609735884, 0.0326879426575033, 0.006664440215899958, 0.012681703537964495, 0.06959744394407608, 0.035576670852606185, 0.04292169527616352, 0.03905359932105057, 0.02437422997900285, 0.06278941160417162, 0.058539855454000644, 0.05841684076585807, 0.028635823764489032, 0.07534162243246101, 0.024896254799386952, 0.03760049272386823, 0.08514701112289913, 0.01782536488462938, 0.013782769601675682, 0.02649147339980118, 0.0729397134273313, 0.08235157089075074, 0.05290851680911146, 0.05760117594036274, 0.022408455188269727, 0.0655049151100684, 0.05859949073055759, 0.01840410834120121, 0.03552852773282211, 0.013739880887442268, 0.02124207549059065, 0.03360354508913588, 0.010728728939284338, 0.05434669510577805, 0.04444306832738221, 0.026130821170227136, 0.0720892715617083, 0.030175748652254697, 0.02153732410079101, 0.052859301285934635, 0.039935241074999794, 0.061642370419576764, 0.06125425315985922, 0.01504516372733633, 0.03206738845619839, 0.015584841457894072, 0.026720238565758336, 0.027339664702594746, 0.023005984257906675, 0.020379388188302983, 0.06603589208680205, 0.08595871287980117, 0.05023065132263582, 0.04813789506442845, 0.029750464636890683, 0.07125785094103776, 0.03557152405846864, 0.02717981165915262, 0.07292605048860423, 0.04366777262475807, 0.06634618403040804, 0.05722285874071531, 0.018910381077148486, 0.03476898040389642, 0.05158716368896421, 0.06017226121912245, 0.05363671953091398, 0.027062125591328368, 0.023991762318473775, 0.039679986803093925, 0.019163739161740523, 0.048223809790215455, 0.043910603344556876, 0.02818178152665496, 0.04178410905296914, 0.02440426284010755, 0.060806237161159515, 0.05690999154467136, 0.03603997509344481, 0.03238833764044102, 0.057000841552508064, 0.053128418876440264, 0.02571512941358378, 0.042726718238554895, 0.011002258597727632, 0.04093023104360327, 0.04283270063751843, 0.021018644511059392, 0.05911831132834777, 0.041549430825398304, 0.04314156394684687, 0.07685391901759431, 0.023870202239777427, 0.006456122609961312, 0.032965732243610546, 0.020373575316625647, 0.012244467234268086, 0.0629871642740909, 0.02989226679346757, 0.07197688813903369, 0.025638764273026027, 0.023849127101129852, 0.0075531973106990336, 0.05290167420753278, 0.02685161911358591, 0.04517265144386329, 0.04581247179885395, 0.038154906724230386, 0.011161101392644923, 0.011954449837503489, 0.020743541499541607, 0.02013288569287397, 0.057245022981078364, 0.09274071810068563, 0.008001248097571079, 0.037064409771119244, 0.018658969274838455, 0.13059363380307332, 0.02635398126585642, 0.025155281036859378, 0.023370434428215958, 0.03904123143001925, 0.0054614856253465405, 0.09257167170289904, 0.03236361299059354, 0.028305540217843372, 0.010739061490312451, 0.024425530937151052, 0.05827389941259753, 0.03647374556749128, 0.027411493465478998, 0.07746342263999395, 0.05272599300951697, 0.029133918033039663, 0.057969466724898666, 0.03497714540571906, 0.17502662376500666, 0.12273114320123568, 0.15364520077127963, 0.07894351743743755, 0.19926150067476556, 0.17230159108294174, 0.12442332896171138, 0.11791258613811806, 0.1523316142265685, 0.11244131019338965, 0.14803184807533398, 0.11419460439356044, 0.13093151879729703, 0.2871791197685525, 0.12157590870629065, 0.23649274895433336, 0.1815551781328395, 0.19597731909016147, 0.21861254121176898, 0.17553405981743708, 0.21949802729068324, 0.0878566739265807, 0.14157510391669348, 0.16761057951953262, 0.1625948486616835, 0.17910629860125482, 0.1581539260223508, 0.1027760909346398, 0.23268694145372137, 0.17042330437107012, 0.186162980098743, 0.18074874562444165, 0.07382549636531621, 0.10792753091664053, 0.0826625975605566, 0.11975035158684477, 0.19090070243692026, 0.15313363837776706, 0.08430082918494008, 0.22390389087377116, 0.1970595633611083, 0.16311510902596638, 0.09916846654959954, 0.20129051757976413, 0.11247962727793492, 0.15098995965672657, 0.1190475896873977, 0.18314944492885843, 0.07197077284217812, 0.15350940258940682, 0.12099243962438777, 0.18453151686117053, 0.06811619139625691, 0.17171746148960665, 0.1326247287215665, 0.1313953462522477, 0.19409401545999572, 0.15589398244628683, 0.09380082410643809, 0.11953624940360896, 0.14604222436901182, 0.13332959089893848, 0.18151879805373028, 0.09582617480191402, 0.11296506607322954, 0.15262219472788274, 0.11812101831310429, 0.12660304637392983, 0.13545523543143645, 0.09093876127735712, 0.07375105153187178, 0.11827953363535926, 0.06957097153645009, 0.15503997827181593, 0.11315293333609588, 0.13269554445287213, 0.24755728023592383, 0.1576916125486605, 0.0841873993340414, 0.1741713282535784, 0.10280526475980878, 0.13293356605572626, 0.16334597632521763, 0.10592540202196687, 0.06743441001162864, 0.10551737665082328, 0.11020705234841444, 0.09849511596257798, 0.1587663165992126, 0.1389748411020264, 0.23090510425390676, 0.2309111601789482, 0.1351436521508731, 0.16093507991172373, 0.08752680412726477, 0.16326739772921428, 0.11835757046355866, 0.10562925541307777, 0.1549644276383333, 0.12878991808975115, 0.15963537152856588, 0.0888666404352989, 0.18758551392238587, 0.09874583571217954, 0.26045830047223717, 0.21739890711614862, 0.17408375482773408, 0.21414203656604514, 0.13845526351360604, 0.13622963684611022, 0.15673149609938264, 0.11819198989542201, 0.13885936292354017, 0.07289042740012519, 0.18134374025976285, 0.1963226404041052, 0.11412271996960044, 0.14515468996251002, 0.08578651235438883, 0.10604125127429143, 0.14829281688435003, 0.14752714312635362, 0.19245682284235954, 0.13645676372107118, 0.08240211114753038, 0.15804763563210145, 0.17158889182610437, 0.15819894470041618, 0.1652721018763259, 0.13964057725388557, 0.10006927797803655, 0.16812031622976065, 0.10572106650215574, 0.11078465104219504, 0.07795112498570234, 0.1600950726424344, 0.1289619182352908, 0.15194072504527867, 0.10829138365807012, 0.15433352789841592, 0.09305514380685054, 0.20240831072442234, 0.09974147877073847, 0.1334274950204417, 0.16919712797971442, 0.09788066963665187, 0.15436622692504898, 0.09671503765275702, 0.11137505920487456, 0.13502658577635884, 0.08047156981774606, 0.1891673423233442, 0.17128373554442078, 0.11145020165713504, 0.07047245831927285, 0.10491837441804819, 0.09902381454594433, 0.24328421655809507, 0.06717728552757762, 0.11385841891751625, 0.17236283310921863, 0.09166736475890502, 0.043434805047581904, 0.21869293064810336, 0.1458389055915177, 0.06928359711309895, 0.14698516752105206, 0.10410555943963118, 0.1040810537233483, 0.12249583785887808, 0.08912185017834418, 0.12472648144466802, 0.11600331476074643, 0.11507945222547278, 0.16866980236954987, 0.11329951492371038], [0.07985301941516809, 0.05310809145157691, 0.03427290663239546, 0.08445173749350943, 0.0034155584216932766, 0.03868380568746943, 0.007767667320877081, 0.03132803496555425, 0.005582523417615448, 0.02577686682343483, 0.01957597993168747, 0.04362307307019364, 0.0179268572901492, 0.10544522505369969, 0.06658537080511451, 0.0058581644861988025, 0.06986279142438434, 0.09851787763182074, 0.03102312173723476, 0.03766915622691158, 0.06354356723022647, 0.017496977525297552, 0.05129115808813367, 0.014342365648190025, 0.07195846061222255, 0.07914846151834354, 0.024405645090155303, 0.012767098760377849, 0.07401084032608196, 0.019999948490294628, 0.007079196866470738, 0.022692042803100776, 0.021408524371508975, 0.019777948000410106, 0.048343800226575695, 0.06850789693999104, 0.035450806317385286, 0.04796431414433755, 0.015005125787865836, 0.02699152879358735, 0.0563840611721389, 0.0201738893520087, 0.030158053996274248, 0.04202193769742735, 0.0031860267563388334, 0.011694638778863009, 0.035697362618520856, 0.04818886947759893, 0.005536054304684512, 0.028960557901882567, 0.03544187085935846, 0.0449812292936258, 0.055535389328724705, 0.02094400300848065, 0.01749007926264312, 0.03211539427866228, 0.036831097095273435, 0.05447153547720518, 0.03188641574524809, 0.0215231843321817, 0.013229299056547461, 0.0261327544649248, 0.019124876598652918, 0.024576149808126502, 0.048258341921609826, 0.032249255455099046, 0.008232701693486888, 0.04346702167822514, 0.036965295948903076, 0.013175497988413554, 0.02241246464109281, 0.0457825595367467, 0.035167194582754746, 0.028612152964342386, 0.028477544074121397, 0.039670071710133925, 0.047240178391803056, 0.019894060715159867, 0.04628202492312994, 0.018333095940761268, 0.018531596324464772, 0.05262581049464643, 0.03601332085963804, 0.08317469430039637, 0.06670636314083822, 0.02970652207295643, 0.03324204866657965, 0.013803467172692763, 0.03960117814131081, 0.044482198063633405, 0.02275244620250305, 0.047420943301403895, 0.01766138921084348, 0.027410287475504447, 0.03313864523079246, 0.027544575386855286, 0.021262809241306968, 0.04198682298010681, 0.031111836215131916, 0.021335645469662268, 0.07557044882560149, 0.15504428272834048, 0.02427763945888728, 0.013017228502576472, 0.04356135235866532, 0.01975210827367846, 0.05959505586361047, 0.05860757271875627, 0.08301440524519421, 0.01817401102016447, 0.036046602472197264, 0.09989437603508122, 0.035250600849394687, 0.06387378583895043, 0.022066857600293588, 0.023867350537329912, 0.037807143744430505, 0.04827452816243749, 0.046228634819271974, 0.030246519854699727, 0.008845552401908208, 0.04557318854494952, 0.07078539973008446, 0.05104824944282882, 0.010854220545297721, 0.044432199574657716, 0.034903561463579535, 0.036594856646843255, 0.06415946074412204, 0.017167961195809767, 0.005076035458841943, 0.043365848396206275, 0.05411464037024416, 0.03652618943306152, 0.12153374729678035, 0.02194318425608799, 0.05481577325554099, 0.007836863314878428, 0.018941250709758606, 0.03113030456006527, 0.06766319929738529, 0.07156413528718986, 0.018496162483643275, 0.021281674635247327, 0.01471377159759868, 0.00628125220828224, 0.035132398988935165, 0.021447604012792, 0.03124774942989461, 0.039832798720453866, 0.06219768612936605, 0.03316077978524845, 0.03562878446246032, 0.04948273715854157, 0.010806747213791823, 0.06582812042324804, 0.03238146164221689, 0.03560651632142253, 0.020753267344844062, 0.028711795566778164, 0.047932980669429526, 0.006812308038206538, 0.025593326281523332, 0.037099858454894274, 0.023163193400250748, 0.009369876024720725, 0.05730658784159459, 0.08418828248977661, 0.044664020533673465, 0.07412982144160196, 0.03085567837842973, 0.05439516105980147, 0.029633253543579485, 0.10852930878172629, 0.021793431842525024, 0.047370473548653536, 0.039629446546314284, 0.06327158494968899, 0.010394405326223932, 0.011269173865002813, 0.048122695880010724, 0.05219006590778008, 0.04003638467111159, 0.024537272402085364, 0.017699298114166595, 0.04737620292871725, 0.027398166348575614, 0.0316540715721203, 0.005294607226460357, 0.05245601823844481, 0.024304017242684495, 0.024903628036554437, 0.13663027784787118, 0.042749312924570404, 0.003843990070890868, 0.025614891237637494, 0.041359990209457465, 0.04055726472870447, 0.021227965407888405, 0.056359314257861115, 0.04524886629951652, 0.004005792179668788, 0.04923184671497438, 0.040464332996634766, 0.037730027179350145, 0.03376862470759079, 0.015039989102660911, 0.036426403967197984, 0.038764773998991586, 0.033881230774568394, 0.04345163695688825, 0.049378547046217136, 0.06608079202123918, 0.03086306831391994, 0.03325296565890312, 0.04724531405372545, 0.06780335388612002, 0.006705503246848821, 0.09566651657223701, 0.06169110354676377, 0.016966503353614826, 0.05015261078369804, 0.04298360894608777, 0.03316294685646426, 0.03397389162273612, 0.036127852799836546, 0.039526395630673505, 0.08941862019128166, 0.019898456084774807, 0.018544121921877377, 0.0455782165954588, 0.025141289697785396, 0.048740723068476655, 0.025509098086331505, 0.027224346085858997, 0.019346943881828338, 0.04218867972667795, 0.009759576842043316, 0.037339965492719784, 0.06509509374154732, 0.04354177450295538, 0.010576661952654831, 0.03260485551436432, 0.0499853010114748, 0.017288536073465366, 0.049354720395058393, 0.02697061878279783, 0.0459134706761688, 0.017307549896941055, 0.03795022610574961, 0.02357940837100614, 0.07824401356629096, 0.04081317951204255, 0.04639348066120874, 0.046426053522736765, 0.020242493483237922, 0.02038565191469388, 0.08308920630952343, 0.0419857839733595, 0.01613139425899135, 0.06603074900340289, 0.04789024038473144, 0.008209904772229493, 0.02476781686709728, 0.02589176427136408, 0.028274511023482773, 0.08216116548283026, 0.033568163198651746, 0.016168165821000002, 0.003276567613283987, 0.02753060445684241, 0.050042361035593785, 0.014280716368375579, 0.03848064647172578, 0.04476936468563508, 0.00797795857579331, 0.06047356946510263, 0.036164826597087085, 0.022683632414555177, 0.01711340777546866, 0.01151414382547955, 0.09317354604718275, 0.0520900689298287, 0.0311171073190053, 0.045360091971815564, 0.01312082396907499, 0.026591407295200042, 0.08403337400523014, 0.023192662229121197, 0.02283081143104937, 0.025204980811395217, 0.03249692868848797, 0.030304459323815536, 0.06636139063630253, 0.018055347172776237, 0.011629321434156736, 0.051977229086332954, 0.03788918074860703, 0.07342124852584675, 0.03751910509890877, 0.04599299922119826, 0.015658670308766887, 0.06737868214258924, 0.04011958313640207, 0.027145654312334955, 0.029202694713603705, 0.03908472128387075, 0.031857768844929524, 0.042393783369334415, 0.032327759836334735, 0.05506122746737674, 0.03408564421988558, 0.039541520600323565, 0.01415345752320718, 0.021152626286493614, 0.07533806754508987, 0.019182205651304685, 0.06366901245201007, 0.10891213823924772, 0.018654251070984174, 0.05544450592424255, 0.0628200919891242, 0.03598085189878475, 0.019380347948754206, 0.021823180832143407, 0.008924188514356501, 0.03791301482124254, 0.027426171291153878, 0.06648915135883726, 0.06651220246567391, 0.07710800811764784, 0.032016792538343, 0.02742372776992852, 0.05373815256461967, 0.012607249427674105, 0.058381581329740584, 0.02356440028961515, 0.007271453005159856, 0.03355401044245809, 0.052660966030089185, 0.035485152911860496, 0.014809627391514368, 0.04915979159704875, 0.07876955802203156, 0.10064577087177895, 0.013667449129570741, 0.027950990297540557, 0.05593661291641183, 0.0031243893045029836, 0.024729403303354047, 0.03970227720856201, 0.012852150739490753, 0.12005985685391352, 0.13268788548884913, 0.07842883802368306, 0.14371099008712918, 0.1552766194799915, 0.1147153991041705, 0.10278583533363417, 0.10954604367725551, 0.15301128791179508, 0.13293058262206614, 0.062194654456106946, 0.08637828606879339, 0.11906706364243291, 0.16099578759167343, 0.20146116701653227, 0.11273748648818582, 0.2310413625673391, 0.14400317362742499, 0.11572275325306691, 0.07810224109562114, 0.15289180213585496, 0.11691950348904356, 0.09961465315427631, 0.11826041591120884, 0.14714133023517206, 0.1410005777142942, 0.1792126483633183, 0.07710803038207814, 0.13051557471044362, 0.17138523166067898, 0.07140931586036459, 0.13211281009716913, 0.12519627576693892, 0.09611749745090492, 0.1280395474168472, 0.11563384396140464, 0.16964781942078844, 0.12495484028477222, 0.14927758747944608, 0.16616920998785645, 0.14781600184505805, 0.10460141798830591, 0.1318371170782484, 0.09803862092667259, 0.06590327771846205, 0.0667928159236908, 0.11933612928260118, 0.12378947547404096, 0.19479804643196985, 0.07558769633760676, 0.11031424073735252, 0.19862513872794807, 0.11095371970441192, 0.1569489750545472, 0.10938925013761036, 0.14844523917417973, 0.12147418994572945, 0.12655024998821318, 0.17021516163367778, 0.1135082142718602, 0.10844869670108892, 0.12786244129529223, 0.09960548763046972, 0.11611289286520332, 0.09722313421661966, 0.1522466234746389, 0.09707744320621714, 0.14463692321442068, 0.1470618016901426, 0.19829391821986064, 0.0980867120961193, 0.11617854324867949, 0.26434798550326377, 0.12552709551528096, 0.15759017580421641, 0.14495356794213876, 0.1437456632265821, 0.142272099328693, 0.10459017445100471, 0.06123775150626898, 0.09341720055090263, 0.13373921188758686, 0.16910205886233598, 0.2335472687263973, 0.19583408458856866, 0.11160793772432953, 0.13204255839809775, 0.09762917063198984, 0.12017874149023555, 0.18476011318853125, 0.1295565121108666, 0.15757037530420348, 0.13371770444791764, 0.10024784613051452, 0.12137800760683604, 0.0982911218306981, 0.1898579255794175, 0.1769319988670759, 0.21677909506252035, 0.12234866997459903, 0.24261349317384884, 0.27798815513961017, 0.0931483501335606, 0.11545950605068356, 0.12107040223781951, 0.2170249240589328, 0.183219563041348, 0.18112237245077267, 0.12933557474752888, 0.16894815227715299, 0.16520569450221956, 0.30436491477303207, 0.07771253935061395, 0.1199663981969934, 0.11225149108213373, 0.09052272071130574, 0.12423351727193221, 0.17156132846139371, 0.11835047553176992, 0.15526890114415437, 0.14618867979152128, 0.138303583371453, 0.15543419227469712, 0.12327620614087209, 0.1239996071672067, 0.13315006537595764, 0.2912259323056787, 0.20792582246940583, 0.0796247273683548, 0.19972345791757107, 0.13739587739109993, 0.15513313264818862, 0.1269464084180072, 0.13501463719876483, 0.21391787828179076, 0.16318225854774937, 0.10023524446296506, 0.0868365696805995, 0.18660503294086084, 0.14683887537103146, 0.14381275337655097, 0.1552004157565534, 0.2052157514845021, 0.1419371087104082, 0.0848914822563529, 0.1895537637756206, 0.1317744204425253, 0.07670848775887862, 0.09651688422309235, 0.09970377766876481, 0.10774842099635862, 0.07568978617200628, 0.10202078497968614, 0.17653046728810295, 0.19485194119624794, 0.1418741449015215, 0.08329173841048032, 0.12963924673385918, 0.10765442057163455, 0.08227596088545397, 0.08713734729099087, 0.09166028467006981, 0.09388207443407737, 0.11237847997108474, 0.07762930006720126, 0.08925936272135004, 0.14774542360100895, 0.21042108623078093, 0.1622540841344744, 0.21298688370734453, 0.07552176393801346, 0.1744202891131863, 0.08750381239224225, 0.20354137726826593, 0.10097813428728841, 0.11665811165585183], [0.06493171735201031, 0.04596755839884281, 0.020015036352560855, 0.011499290667416062, 0.035615195738500915, 0.04690758491051383, 0.03837762895273045, 0.0788127287523821, 0.0359951605059905, 0.05522340157767758, 0.07698217697907239, 0.06757261275197379, 0.03329486360598821, 0.0351162795413984, 0.09643022363889031, 0.03946762495615985, 0.045051740744384006, 0.0062967171743366634, 0.01424607755325269, 0.026860467369260732, 0.04423088459589053, 0.03252233982493635, 0.059140943121747114, 0.024601904187875334, 0.01627275298233144, 0.006315818664006656, 0.07638318216777407, 0.01982229503482813, 0.016408951923949644, 0.019541568399290554, 0.01093064227461582, 0.048434780110255815, 0.04641547420760617, 0.017591252544661984, 0.011832963973574806, 0.05551119160372764, 0.03592503497202415, 0.013150938466424122, 0.05425623843620997, 0.044857201573904604, 0.011811938002210809, 0.06278047614614479, 0.055255610786844045, 0.03094865463936003, 0.0923849102400709, 0.023567827156512067, 0.01873756271379534, 0.030848858041281346, 0.1033711968921125, 0.06105265245423652, 0.02286832514073467, 0.02423865629680222, 0.015282588828995358, 0.037475355493370444, 0.015200266097963322, 0.012263841927051544, 0.02580251730250893, 0.05070393373898696, 0.06306070368736982, 0.03395005012862384, 0.02738116374530364, 0.040693582413950935, 0.009227987593476428, 0.020780389131687116, 0.04425162391271442, 0.01544801354611991, 0.020571135028149, 0.027807186197605915, 0.04317051141697448, 0.04147421415837016, 0.036643604616983794, 0.026341483498981688, 0.08053975092479959, 0.059771742671728134, 0.05304728358169086, 0.02729265521338675, 0.03232486546039581, 0.027692771145666484, 0.11183916867594235, 0.020688826662080828, 0.045388174839899875, 0.02549580436607357, 0.017585734676686116, 0.03902597658452578, 0.08465995444566943, 0.06901433109305799, 0.03967914075474255, 0.05013773814425804, 0.03716463681485038, 0.04821518603421282, 0.03609342085837852, 0.03540649267961271, 0.030692593281855807, 0.07550765571068041, 0.06260832014959306, 0.0374975419981638, 0.05545737105421722, 0.041673165396787226, 0.11238268052693456, 0.02000867243623361, 0.02001187294808915, 0.046442852035397664, 0.005193034112380701, 0.030137014109641314, 0.010594805607979652, 0.01441228152543772, 0.02626364519528579, 0.07700084941461682, 0.09297784912632778, 0.01879626102891052, 0.05681669987097848, 0.03794576208747458, 0.042345803522039205, 0.05514132004464045, 0.038591167103732005, 0.047319866498582996, 0.03168999151967, 0.03909713741450105, 0.03587836501537822, 0.04372996831079945, 0.05455356134916656, 0.024431970923615154, 0.06320240936474875, 0.002335284552827943, 0.04181458534731064, 0.03687480588268954, 0.011344936938257888, 0.02287063322000904, 0.05513388372492045, 0.06683276573312469, 0.016744272797950543, 0.06557210173923522, 0.020820760109927505, 0.022810344853496645, 0.020558102914947085, 0.020580261589202564, 0.11312660935800523, 0.0702709355391562, 0.03670348851301242, 0.05663060634105932, 0.0421698996797204, 0.023340431253018323, 0.0621294196753297, 0.04299227352021262, 0.021363106789067388, 0.013716769481106894, 0.007438457105308771, 0.05937202935456298, 0.08448931243037805, 0.059638864840962924, 0.03949328100134153, 0.0718783754564356, 0.013589082973339828, 0.03368626115843654, 0.052496977368718944, 0.025417949364054948, 0.030555811754311435, 0.03252821392379701, 0.07233779455418698, 0.027150162859470583, 0.051992721419082955, 0.02621117906528525, 0.033864202196127735, 0.05354864515538793, 0.021153602210688405, 0.008901139262889046, 0.022562354351975955, 0.06675391996395774, 0.03829918394330889, 0.04127677319047507, 0.08318486172356643, 0.10900812019826844, 0.07619025345775299, 0.04618138227669988, 0.02335009030502988, 0.027340995002305135, 0.01379186833219137, 0.06767301791114733, 0.010034723454737104, 0.013205924187786877, 0.05920611853071023, 0.050003331489278935, 0.10455297058797441, 0.045562917221104726, 0.10899523651460186, 0.05523661180632189, 0.06612944722292013, 0.06536536908242851, 0.024247760593425483, 0.02106683958118083, 0.06371928553562611, 0.02645827527885558, 0.07086551457177848, 0.0023843497911002487, 0.04181159820291214, 0.012770230623573298, 0.07629394633113407, 0.011385306988813682, 0.02749831175606232, 0.05371112725697458, 0.01929622365423711, 0.02947566219518194, 0.021785179160360713, 0.03162897213769611, 0.010114553497260204, 0.031612774764653295, 0.019088657936663367, 0.03833540074992925, 0.03142738998576533, 0.06508418417070061, 0.04538384069746826, 0.02569590593338944, 0.04573126228933688, 0.00493970571369573, 0.01293791054195026, 0.05958288093097508, 0.03879408512148075, 0.02090289915940957, 0.010244084242003737, 0.01085795911421883, 0.05222588937613182, 0.055932070972630754, 0.027625154070847202, 0.022491664785775356, 0.07059812618535943, 0.03932164821890183, 0.01681940226262668, 0.029769663997285534, 0.01009265271932236, 0.014380214252014412, 0.0341109143482754, 0.02875981623219559, 0.03048346348805353, 0.05629616491205525, 0.02736344868026208, 0.04732889843580779, 0.025969391062972136, 0.03952176833990961, 0.03595039786887355, 0.05313651941833086, 0.011542982756509446, 0.04106743188458495, 0.02049452312348876, 0.017324175860267133, 0.03413301550608594, 0.07288768887519836, 0.02080837180983508, 0.05318783893017098, 0.019138302050123457, 0.01592699936736608, 0.058364782817079686, 0.024687677905603778, 0.031085655100469012, 0.09132755018072203, 0.07936385503853671, 0.053107063577044755, 0.04206132347462699, 0.029032770726189483, 0.03225625019695144, 0.08169088134309277, 0.0707284250529483, 0.029423695159493946, 0.026592969516059384, 0.03281035620602779, 0.07721440983004868, 0.04891040029178839, 0.0648451829329133, 0.0301805503477226, 0.02190742758102715, 0.011362173318048008, 0.07585456522065215, 0.017368955195706803, 0.029817211543559097, 0.0448134259931976, 0.03412680744077079, 0.04239949048496783, 0.002251238183816895, 0.015179749425442424, 0.017527503914607223, 0.013508046013157582, 0.05296532821375877, 0.023182967925095, 0.02763085376500385, 0.05850995803484693, 0.0820068729808554, 0.028760133500327356, 0.09723671551910229, 0.0872320230701007, 0.018348606827203184, 0.06573631675564684, 0.03500390725093894, 0.02784390209853882, 0.029792685418215115, 0.016181158971448895, 0.07263800813234411, 0.02177879669034155, 0.04660180151404347, 0.014393649908015504, 0.03304433681478258, 0.021032693366578314, 0.0552858087758068, 0.03898839793691877, 0.02458650091284653, 0.0792364208609797, 0.09767916169948876, 0.01406037272317917, 0.014071161695028422, 0.051052672642981634, 0.02340233750146581, 0.01655298052355647, 0.02720461052376777, 0.0336157126002945, 0.008754757127462653, 0.06761720098438673, 0.020161085449217353, 0.029591576385428198, 0.030647459570900537, 0.029442180202750023, 0.06356767218676396, 0.06230606566532515, 0.05405868614616338, 0.016886609300854616, 0.05574698305281345, 0.03159177198540419, 0.04953112518705893, 0.007204809535323875, 0.031526143866358325, 0.05254428557236679, 0.08686431858222932, 0.025979463862313423, 0.07436474828864448, 0.008126099601213355, 0.036332051022327505, 0.021560189670708496, 0.03623997276008595, 0.02172815438825637, 0.0546913002472138, 0.04008335519756656, 0.05997756990836933, 0.027213197172386572, 0.06461845681769773, 0.03513479983666912, 0.023456659000657964, 0.05317309245583601, 0.044856767417513765, 0.04927037902234588, 0.050738684803945944, 0.07919791081803851, 0.027574446830840316, 0.029787362364004366, 0.06801630574045703, 0.017781409333110787, 0.15468281228095293, 0.10488230604096316, 0.09928723986377008, 0.08749394182814285, 0.21181149990297854, 0.11107048921985552, 0.22514084324939176, 0.11728107041562907, 0.23538743873359635, 0.14921354013495147, 0.16217939439229667, 0.13114311994286254, 0.12586239783558995, 0.07646998376003467, 0.2527250623097643, 0.11883586237672716, 0.2170295550604351, 0.1312212977791205, 0.151068345294334, 0.09410167593159713, 0.21879977022763342, 0.07385481119854376, 0.1277317342464812, 0.08563202689401805, 0.1351610926212743, 0.1716805322212167, 0.13004215870751068, 0.08888145370292477, 0.17182621581014246, 0.12008339035673998, 0.12662415305385366, 0.16531245986698195, 0.10662630113074556, 0.20500082551734522, 0.1278273673960939, 0.09533575619570911, 0.14133086311630905, 0.08762047058553435, 0.10555120374192484, 0.21064612024929374, 0.08262500035925768, 0.21693359536584467, 0.15694729780079797, 0.08916249760659412, 0.14890458405716345, 0.1553535950370133, 0.1139256426540669, 0.16933960549067706, 0.2898944600019604, 0.2435892095672898, 0.08755838251090609, 0.07933674438390881, 0.10537542606471106, 0.18779459176585078, 0.16681156848790124, 0.08247671925346367, 0.1742152782389894, 0.11329403787385672, 0.1250857551349327, 0.13532224256778136, 0.07310162036446854, 0.07013317808741704, 0.13890116068068892, 0.21167071448871866, 0.13510902354028076, 0.1538636296754703, 0.13899790705181658, 0.14246605220250785, 0.140154559048824, 0.22033260203897953, 0.11523013788973913, 0.13098556199111044, 0.1543371644220315, 0.15816765575436875, 0.12370927157462575, 0.1090988700161688, 0.10544198928982951, 0.140578651917167, 0.20614340639440343, 0.08505845806212164, 0.14741282269824296, 0.08955680066719651, 0.11453643019194715, 0.19990783708635718, 0.1773783116368577, 0.18574920308310539, 0.16652691032504663, 0.15677960211178288, 0.22607016057008877, 0.15205552044790238, 0.1760407685651444, 0.1538167110993527, 0.11336595940520056, 0.20361655682791024, 0.23855713661760092, 0.14305220043752342, 0.12075144200935028, 0.07982575290952809, 0.23038810933940113, 0.25343927554786205, 0.16810471628559753, 0.18689748365432024, 0.13780722016235813, 0.0672028079861775, 0.08447433589026332, 0.15007840935140848, 0.12499960663262755, 0.11100363655714318, 0.23056861449731514, 0.10119500468135811, 0.23079841310391203, 0.11781582492403686, 0.16329037462128326, 0.13067719963146374, 0.1314101743628271, 0.10728658249718137, 0.1232050712860655, 0.09292002840084024, 0.12708038091659546, 0.12479594646720216, 0.09547689041937701, 0.10011683480115607, 0.12095702433725819, 0.1011485313938465, 0.11147293364047073, 0.15744881151476875, 0.17141968215582892, 0.18708796327700838, 0.18264053942402825, 0.19478384172543883, 0.06525524921016768, 0.1645686646224931, 0.15022658655652776, 0.1424378209048882, 0.08470573753584176, 0.14223411621060222, 0.19882211956428364, 0.13403697637841105, 0.10477003394044004, 0.14092744648223743, 0.09977625581086613, 0.11134353277157061, 0.189970821083989, 0.10619581837090664, 0.15773588907904923, 0.09078964154468849, 0.15944922604830936, 0.10632651799824089, 0.15044871135614812, 0.09651911808759905, 0.1718948347843252, 0.2161490562139079, 0.1455256895860657, 0.13653660396812484, 0.16813153750263155, 0.118001347000245, 0.12278275957214646, 0.0883340604195837, 0.1993731939001009, 0.14467085420619696, 0.0990189534786623, 0.0988315166614484, 0.09534159689792432, 0.10929311974905431, 0.08093299271422438, 0.07739982058410533, 0.229247146344278, 0.12151362767326646, 0.10675832178094424, 0.12344744929578155, 0.13471136597217992, 0.23968736815731972, 0.10403701468021609, 0.13712059997487813, 0.17092254711315036, 0.08108688445645384], [0.03353048436110839, 0.05033401394030079, 0.08141279118717648, 0.036591023454093374, 0.07046770857414231, 0.04394479408801999, 0.0240456923347665, 0.058294631307944655, 0.02847143248800421, 0.021080205660837237, 0.02937212888355134, 0.05397025182901416, 0.0379474393412238, 0.06578011831152253, 0.020679496010416187, 0.02439944444631692, 0.030322213351610117, 0.015043899293232244, 0.04772172091179527, 0.07676387423998676, 0.040774487642920576, 0.0308322691853391, 0.007990316262294073, 0.06338986844639294, 0.021556391729973257, 0.02719763433560729, 0.06599867338081822, 0.016545661092095543, 0.014133204313111492, 0.01837424060795456, 0.03429354947002139, 0.01829501077736495, 0.05801605875603855, 0.009791070806386415, 0.030188643468136434, 0.02038045131484978, 0.020352173633000348, 0.08303725597215816, 0.04540108820947353, 0.03229851179639809, 0.047663529112469405, 0.014251716020226013, 0.056160337044275366, 0.026758952699310612, 0.03001767305249814, 0.02625724046083633, 0.07273170427652076, 0.010214589437964605, 0.01052418283506995, 0.007293963271877146, 0.07809522780007683, 0.02220715134171769, 0.043767224124167114, 0.11408841790398583, 0.05997778884193394, 0.0452627927006688, 0.03233414972783066, 0.025599792243156116, 0.01704651800537249, 0.01206208815347054, 0.02848264077329077, 0.07340913667576388, 0.06932861579116434, 0.020190075592836365, 0.06114867894211784, 0.030790219097980298, 0.05221327657636721, 0.0189073902220116, 0.018999153071490582, 0.03850866996799596, 0.04093255767656956, 0.04034221259644255, 0.03500309459923301, 0.03210006521840114, 0.03441409280640073, 0.023145997838582844, 0.028119121998315677, 0.05577076146437321, 0.070024431188358, 0.01434366811736254, 0.020348049147287384, 0.0892607876448892, 0.012322945640335092, 0.04194513654510956, 0.03634913155110553, 0.047063357997103594, 0.0856353368726559, 0.023775545014359523, 0.01323906386460294, 0.047686502293800004, 0.05372515013732482, 0.04669019501307048, 0.011134317282994743, 0.028414771368261427, 0.029446852022374514, 0.02737393708230229, 0.052327333542052656, 0.02308301362063503, 0.0382497828832129, 0.005731119472329738, 0.01640009995753644, 0.05847229404025711, 0.03365512064192444, 0.03216606812202372, 0.06567708594957367, 0.09128358535235748, 0.06706539934384637, 0.0875009254377801, 0.09811401570914313, 0.01578785595484078, 0.010268625210301252, 0.07241595012601465, 0.020089477475266904, 0.041331209722557105, 0.013819813902955502, 0.05764260633441154, 0.03355145003297366, 0.044935457335668616, 0.051855884230462834, 0.019708050676854327, 0.057710034161573276, 0.06095136785006616, 0.06572106562089175, 0.033434825236327015, 0.02395965700998204, 0.030090804284554906, 0.022865644132252783, 0.08307131312903948, 0.03839370016066823, 0.07778609360684641, 0.05291278786899056, 0.015515880168095464, 0.04075456097780261, 0.02261590772832278, 0.027864400217367802, 0.056872535351431, 0.022469687937700655, 0.023825671523809433, 0.07598129435791634, 0.02054574801150011, 0.09233451841282658, 0.044970364251639694, 0.05289719163556583, 0.0353324189200066, 0.08564568983274512, 0.007810508723196108, 0.06001686291710939, 0.029101107684255112, 0.043108631143695675, 0.02510004855139414, 0.051498770189937204, 0.10522491109441034, 0.06588863514480181, 0.010208260773652, 0.009563793646520935, 0.027610453980742022, 0.03820553232799284, 0.027401940169511363, 0.0314149812766118, 0.030296471959445626, 0.04116567368328106, 0.030076048533373978, 0.05320332384144422, 0.02612979144032579, 0.01812193266232498, 0.03158239494950976, 0.06680792605038732, 0.08151047266437672, 0.06555294690770097, 0.05886143175303005, 0.02734548685111804, 0.0749586964957416, 0.032206760079134256, 0.049827512993942946, 0.03335823188535869, 0.04702550846559461, 0.04090892027306836, 0.008763081241340842, 0.030931984147173353, 0.017065804568119347, 0.01693158716079779, 0.01584419052960584, 0.021143399535503704, 0.06099257559981197, 0.014697666993015446, 0.052939022789360024, 0.05615273374132812, 0.026030109875136986, 0.046474801492877305, 0.070931439549895, 0.04748625600768719, 0.053433478678925894, 0.021738496216130443, 0.001349978219877812, 0.036163691111141816, 0.014775881936657242, 0.00800285020886804, 0.02957526212412631, 0.00563553780921211, 0.02630766754009528, 0.09251535011571832, 0.01150676966062747, 0.11250930576352403, 0.05272143993352074, 0.03452235359873157, 0.011838056962005794, 0.02492549170710845, 0.032196110259974375, 0.02314319437573431, 0.008962278316175798, 0.031026646938698832, 0.03608742059441283, 0.0046081540222076, 0.0029525375884986715, 0.05829074616485741, 0.04892381461104378, 0.09555362106766552, 0.02892814274673583, 0.025357180456921924, 0.06604130976484157, 0.03973351420427207, 0.03781107341637835, 0.04625240580935497, 0.07986477503436618, 0.02560633798566414, 0.023572070385853294, 0.03450419695582241, 0.04104346051462926, 0.061277074200916104, 0.02374509840592509, 0.10046988187241368, 0.03426018622121774, 0.0025363175154780038, 0.016737090663809795, 0.037166922629694454, 0.020345054581412114, 0.0720535742584616, 0.08535029279300943, 0.06059695893782191, 0.02408222084341105, 0.060891765970154665, 0.045255330405780114, 0.11680700874421746, 0.06617874067160301, 0.026099430178874172, 0.018586274054541718, 0.03565438855730463, 0.059173616173211485, 0.060479992753244005, 0.027974169424851425, 0.015218309563351795, 0.01578054580022581, 0.02229134985100245, 0.03483988890366163, 0.022234963325900026, 0.034630243317224085, 0.03287007311882917, 0.02634233325807145, 0.032110466418089345, 0.0162540824021562, 0.01904532764456235, 0.0877413887064904, 0.012959022787981667, 0.015496960968448548, 0.02414244427200174, 0.031012034050945658, 0.03549274508259259, 0.015218727949104505, 0.04831157246371731, 0.06499473311123438, 0.027698500525730196, 0.04051501426147297, 0.040943396743386984, 0.06561333546414971, 0.031400587322423235, 0.01577541570441099, 0.032952911642496474, 0.06125468360551167, 0.07109116457286291, 0.04848899399803486, 0.08888143143849447, 0.04659981626900844, 0.06643451444688253, 0.046041008754400536, 0.03282718811533414, 0.019586462767620105, 0.0189689829130657, 0.04876881335803773, 0.006279632934820256, 0.053325147382565774, 0.03850397217320278, 0.06619460778892972, 0.030515978833136614, 0.0242914007321815, 0.04378468314826023, 0.015815962942724582, 0.06716815711115487, 0.025270939186157193, 0.07982693292433396, 0.038901848674868234, 0.012728495021292474, 0.06992570328293368, 0.033242757417610846, 0.028404776494426187, 0.012719912083412055, 0.03074750849918928, 0.009318082466052147, 0.017572201613802463, 0.022750967473257333, 0.07651525476831011, 0.015943745929689612, 0.077395731350407, 0.03222041930712294, 0.007595500655952492, 0.042910444317385554, 0.02488571630237857, 0.032835169913596474, 0.03902641074091662, 0.05317226125043817, 0.048029411627794616, 0.05717489373637363, 0.016758523888711352, 0.032628459521220066, 0.03591305670852307, 0.02974341608933173, 0.04404315463034436, 0.05519427599210758, 0.040939645186881535, 0.023613979465153534, 0.020398248016135767, 0.03405311217647977, 0.02880879426811589, 0.05254599622276146, 0.056213582429336384, 0.013961355380160967, 0.06156132418254856, 0.03601950666052289, 0.03164549605571665, 0.0836618548783008, 0.0662844892940484, 0.04591197153786197, 0.04544758005067706, 0.015090202814462828, 0.06493982160463929, 0.05493623866641428, 0.0601770517823752, 0.06131114991148934, 0.021970168745610863, 0.042486485035624355, 0.041357812006026506, 0.033978912251768634, 0.04149294225499034, 0.15266648610122502, 0.1331808348186314, 0.1754723725025542, 0.13572862779255956, 0.1433046642341651, 0.11077431292505935, 0.1666688683326356, 0.19153317552991211, 0.08974897980806418, 0.2181148569798097, 0.15565575304208323, 0.1408520294353366, 0.18040238530375063, 0.14916840271325782, 0.10528506216360256, 0.16613548679742962, 0.06445794511819258, 0.11743134789867327, 0.16951454454101622, 0.16525920334970579, 0.1434142646030523, 0.21610715455608442, 0.10470570457982831, 0.12825260317185894, 0.1841992573463358, 0.12093178389477544, 0.16578353068325669, 0.14580525661585853, 0.14480887883109972, 0.20557480253046378, 0.15769805439049378, 0.14673305995529518, 0.1272847387008369, 0.0688043181435205, 0.10655501784640364, 0.1811507373349741, 0.08540087757864967, 0.17419817915651947, 0.08858944827807136, 0.19684092665556818, 0.22080064489273354, 0.13891299051465467, 0.10576603322988376, 0.1302003549062647, 0.10524575802264735, 0.1567601429997012, 0.12982828659005463, 0.1589500278350897, 0.14666978444438428, 0.135122649371624, 0.11330364126479253, 0.10003262330428697, 0.0864508977974765, 0.20401409565238282, 0.29222605051472783, 0.13594946125522256, 0.14736251992871985, 0.10510970751056448, 0.08619711297797039, 0.09104268421651796, 0.15873527998337522, 0.16308395366650075, 0.19464936456643045, 0.09464891336392611, 0.2549259754596278, 0.12275837259949185, 0.18366554926615208, 0.14987690141424537, 0.14626898017013445, 0.13503001449862495, 0.09476485909544863, 0.15667363826651126, 0.19322265987284482, 0.26744395843707025, 0.06971982409595512, 0.21549311641138047, 0.14577751513570547, 0.17033001640811563, 0.08798447175649926, 0.10585636002360843, 0.12378037674352527, 0.12982099869986996, 0.09551590512273833, 0.21635759971104562, 0.23153008165536448, 0.16700253792805597, 0.19994816539110616, 0.12559357710415497, 0.3053921362152323, 0.18227238964755088, 0.1557373596006073, 0.166998500644695, 0.22807109460700303, 0.07942767973872833, 0.19844170950818807, 0.14944992901291698, 0.2001498662866652, 0.2119986992329359, 0.12933624268043786, 0.14007305639097467, 0.12105054236599244, 0.15770923113450408, 0.13009614252950996, 0.08584412527852692, 0.3009030333487317, 0.18824026628863066, 0.1987863183603622, 0.1647430841694586, 0.2504792343825102, 0.1400585993542336, 0.10998736179317348, 0.16645092924591154, 0.04822519018489402, 0.1222195140144322, 0.10441559163155034, 0.14166365697747096, 0.08985040913103148, 0.14067057432839647, 0.22224262298550457, 0.09773151279659942, 0.12421471867128275, 0.0908215538947843, 0.13610936439363286, 0.11270897317444906, 0.09815898985834792, 0.20662001363234594, 0.1088339307170827, 0.14364854578161612, 0.1268180613988079, 0.1305107062216848, 0.09561420258251019, 0.10222385884844698, 0.12024285562802106, 0.1786120282486081, 0.1257201429689303, 0.09620630284189247, 0.09736497348058037, 0.09666571451816708, 0.14697543054353446, 0.09669258768553846, 0.11647569917840883, 0.10338538675568998, 0.09688769088825211, 0.09702769704745151, 0.1334716973360628, 0.18205017579020932, 0.1271429588086903, 0.14093109784880653, 0.2599829400423914, 0.15554880956187844, 0.1672267258982174, 0.17824451671913266, 0.11975296394666657, 0.08243593081715517, 0.09661987947765738, 0.12411951596732251, 0.09187711053527892, 0.19136450020596385, 0.07703415700234473, 0.1313109343755059, 0.10186067403992638, 0.16962269030045718, 0.14789060252951458, 0.1488421397516504, 0.10568022611550987, 0.08866014526574872, 0.17192419414641336, 0.20995265746023506, 0.13178973837057129, 0.14745744061656296, 0.1249468993046321, 0.1866670319577679, 0.09282170867663808, 0.08240038936492056, 0.1095611834898591, 0.19407660467550159], [0.008244423916039523, 0.01883257988083642, 0.04907805516268127, 0.012850649745814735, 0.04394230418256484, 0.05743490888562519, 0.020023606302856933, 0.019157497699779924, 0.058277060961700045, 0.03180246028932743, 0.014876397490297677, 0.015145217294048052, 0.07151511643314734, 0.05722372705349699, 0.06213977263541892, 0.011430980612203712, 0.01357629020276363, 0.03843427708488889, 0.024255267417174764, 0.04243312090693507, 0.023163456862675957, 0.022177385653776582, 0.016269971783913206, 0.012339032618911006, 0.05500568884599488, 0.02609486040455522, 0.06466018778155558, 0.039621494433959015, 0.03173936660459731, 0.02364780655625509, 0.018105197232216597, 0.01343961906968616, 0.06006996729411185, 0.09132099701673724, 0.02957689113827655, 0.021932827585260384, 0.006527965751956799, 0.029309636338439304, 0.06551049606059678, 0.059232783896732144, 0.03645390424935613, 0.01573651417857036, 0.03790625756664667, 0.01778263016603887, 0.009985737997340038, 0.02290042302774964, 0.07841116006602533, 0.039760706495144404, 0.05328746854502242, 0.017564034278620966, 0.08472879606415518, 0.07919564726762474, 0.04892712087894324, 0.025404911684745457, 0.025436868563701864, 0.023892097451607697, 0.01483866206399398, 0.04272992802725639, 0.04066705805598758, 0.02598174411104992, 0.013053008369752206, 0.08704154344741255, 0.02850678654795047, 0.02841221466951538, 0.0178310924093239, 0.06424962426535785, 0.028547328220156487, 0.020960591864422895, 0.08639015301014297, 0.03338441856612917, 0.04679244811995886, 0.04718563795904629, 0.04986956308130175, 0.04250878657330759, 0.007018403375695925, 0.06416070013074204, 0.056802576800691895, 0.03645395248895511, 0.06276523243286647, 0.058420681380084716, 0.04344610795669723, 0.042307085677748546, 0.03371457409230061, 0.027092349555459805, 0.062237869715318084, 0.05456027407490183, 0.01937572622409789, 0.026751186123874504, 0.017141668758995365, 0.025693848328955937, 0.03960377194744069, 0.049450119768152945, 0.08044560207054019, 0.07803566302754916, 0.052812434660154395, 0.007189732341430499, 0.03351318489876576, 0.021437687064462807, 0.031202931131701916, 0.04492985783144832, 0.019496117420203518, 0.031353204904007725, 0.010232100412395084, 0.04129949775233399, 0.009201950269925874, 0.04306881863158196, 0.054804945320938714, 0.06821457791374996, 0.01878885625046678, 0.018797379816533066, 0.02520914982596878, 0.051411475069471635, 0.040906285648816265, 0.06118937089922838, 0.1256572236889042, 0.032706125275581144, 0.03925804987375159, 0.029169630179239903, 0.04904685898509342, 0.05830637579492759, 0.031724742584628984, 0.0016135374721670814, 0.03389170247828588, 0.002960653437185101, 0.05394791689468548, 0.0435447579366155, 0.05423018905275967, 0.016962430818239227, 0.03039068204088835, 0.04153566769673489, 0.04646713139663916, 0.0488251460774336, 0.05886333165108226, 0.02042859257926466, 0.034019021622953005, 0.0631369519396685, 0.019597750833781902, 0.024414220606558956, 0.06136636198789347, 0.012800763506675139, 0.03517935096169822, 0.019230309808335733, 0.0034525027649578988, 0.04799665322934743, 0.068182257382432, 0.06461827870225534, 0.016848820996528957, 0.03373569932591636, 0.016069359990069643, 0.02522369963116944, 0.007929638268251438, 0.03668302750156727, 0.04596067126840353, 0.04614254939951934, 0.03743668959941715, 0.04882405512034893, 0.027483591256896034, 0.055786469019949436, 0.040873119069146924, 0.04098673445696477, 0.0346190851269057, 0.0627084804000333, 0.023667881650908384, 0.0420415786356898, 0.01063302992406534, 0.0671808775223326, 0.04969708053977229, 0.03520805352309253, 0.04493706037465017, 0.024077649213722907, 0.05239546640950721, 0.04088835536094848, 0.017800545610953122, 0.06232969564734958, 0.053523289680015296, 0.07522517946199514, 0.02461447616951773, 0.03191726682416629, 0.05724707130866591, 0.022925286830286495, 0.01631349317904096, 0.07001863501500338, 0.034240203895024024, 0.03891492902766913, 0.05721232395444531, 0.05940746690612286, 0.05659820046275854, 0.03441566615947522, 0.08048377072555013, 0.03688387863803655, 0.024559030316595454, 0.04873687503277324, 0.013762684302491834, 0.034222303293063305, 0.042963151645381004, 0.031777487020008266, 0.05182634304219391, 0.1204669100116007, 0.04074342876265291, 0.014744454765605042, 0.04189451094134711, 0.03684247792989481, 0.005472590009958367, 0.057979975535999984, 0.08708352674148045, 0.023595765305799432, 0.04608954150171485, 0.05422063761216123, 0.04991499736206606, 0.023556338710477576, 0.0751757450052537, 0.04413219008711167, 0.023717355070402846, 0.02893885008234065, 0.033915351014002226, 0.07730366793111898, 0.050685279857134447, 0.053089734428795055, 0.025128053493972402, 0.03989998163888231, 0.05617866809188854, 0.015637728756701108, 0.05671771592460573, 0.037622946401825175, 0.039864644277258776, 0.031549209816148505, 0.10356399201555178, 0.11244121371419169, 0.027368858936824836, 0.022638366972387303, 0.04251385915267747, 0.04264646238880232, 0.015969329615472816, 0.08779451163718477, 0.03763744796742685, 0.02307258273503976, 0.0243871878774371, 0.016435762008768506, 0.04658308083890006, 0.021599428873742, 0.038256558691500686, 0.004729514184873551, 0.02301907203218434, 0.03772076146560721, 0.011519605104695074, 0.021571479592239484, 0.023352014322881587, 0.053056226461194456, 0.07860621131840162, 0.0676321033097338, 0.03634171749581583, 0.075766954687424, 0.04090584407094866, 0.0573584194353316, 0.043524100256036036, 0.029220829092082568, 0.025718552569742315, 0.0482079538051039, 0.055591287891729735, 0.055452958986279555, 0.07927453756565228, 0.04880410990153905, 0.048833940527401865, 0.03333156280859839, 0.02855346949218074, 0.029312037186173256, 0.05330625601345673, 0.017576851168996654, 0.07580323828733526, 0.10603904709569179, 0.03759116763831116, 0.025515263478155248, 0.03336930101795588, 0.015167600467975717, 0.08279452915303409, 0.037410840595839545, 0.01825719649787061, 0.03999444961664267, 0.023303231100726407, 0.03472549426078331, 0.034142351723858155, 0.046505099671776406, 0.09263613465009257, 0.020581283897627145, 0.07485941940103658, 0.017826231342041865, 0.06097090488765389, 0.09564018517266959, 0.07149337892769836, 0.05112295773869846, 0.027284209572826512, 0.012833404089178657, 0.09174303413601592, 0.028538053229567595, 0.05765944195445627, 0.07590453402372077, 0.01074794128726353, 0.02662753133336082, 0.04503966229094658, 0.09055403934326023, 0.0040721605910221115, 0.027022198046324775, 0.043576028328971006, 0.03246309788664803, 0.06333497178275138, 0.05033760222431738, 0.04180960553640034, 0.01746554386045318, 0.07325957165448926, 0.02251998143037781, 0.01989608492294792, 0.06343204469885677, 0.016570016523473896, 0.01782177103450522, 0.021472156113304663, 0.05809996226162184, 0.03378310771950055, 0.06339164960081689, 0.052761679180548526, 0.04486068595724646, 0.0076459305182652315, 0.03860417695250362, 0.017254213598789647, 0.0019043831753151608, 0.03336836220114492, 0.09360632204334252, 0.08214434099500068, 0.04470519859751221, 0.03348632286360953, 0.029394371049420442, 0.07118171401089057, 0.016406154027208686, 0.0064480471155548, 0.026452772253833245, 0.07506955851567909, 0.031547959297313355, 0.06050781215890311, 0.07670297360164113, 0.036070035785087384, 0.013166222070140066, 0.015251310087478487, 0.0843549169076141, 0.0402530324208783, 0.023746246879454702, 0.009216422149620485, 0.008151248202921124, 0.02260943434521323, 0.044687535482808016, 0.06015754443069454, 0.11196692939847708, 0.05625140969641507, 0.0583220647968119, 0.15060500765684992, 0.11486264120321721, 0.16721728577977046, 0.07645272882655263, 0.10339494561776519, 0.1574385105050169, 0.2494904858758673, 0.0772188552946318, 0.1300798004376702, 0.11545511253643781, 0.17504183779237792, 0.13356474781176075, 0.1840140321291983, 0.17653223359957337, 0.13997541944263503, 0.14572589134331793, 0.0893909009755589, 0.18160171079216525, 0.1770484566804953, 0.09945938843884505, 0.18447279813699424, 0.246571262832731, 0.08364759079995565, 0.15793491824297234, 0.11814106372185051, 0.144218158966396, 0.14603507006540895, 0.1591526935226284, 0.25973138166591525, 0.1153140228416305, 0.12941111053805798, 0.1405686477664858, 0.15661331650335342, 0.25176196242682636, 0.15966682374710217, 0.13343439699383453, 0.09312019305070862, 0.09736187872476876, 0.11670374631648883, 0.1408838972565718, 0.19968105159932747, 0.13886022381484509, 0.14364266797201708, 0.05087840152555145, 0.27845469885505736, 0.20491837291046977, 0.1829395061940886, 0.09599810815416276, 0.1130596231087111, 0.10943515939288773, 0.22308021085336804, 0.17017223581206053, 0.11773679361795075, 0.10285196811310016, 0.12010198115603998, 0.10233157416223548, 0.13916977361077443, 0.24133351107593626, 0.09462852656724863, 0.14648135314928368, 0.06909213043400086, 0.11169901408720762, 0.10367034919909202, 0.13672846398549154, 0.11710904800565913, 0.10161934987991117, 0.1855156195233576, 0.14915738924173638, 0.1455979302409105, 0.11188354910700582, 0.10806514736032113, 0.14083484129514545, 0.15292270516511053, 0.17012315016472712, 0.09732345031807199, 0.1505117939086631, 0.14805546321440488, 0.1363363873679191, 0.15842687309486791, 0.1564783792127855, 0.11788128977059387, 0.09708372919703834, 0.07390014157863334, 0.1319513187627308, 0.20032869419083, 0.1870640364359133, 0.17945942730875686, 0.1414181396830827, 0.1481865264941007, 0.1015911260037683, 0.08426775166299194, 0.15037143894005567, 0.15857457532547414, 0.2171532265492715, 0.0943706525140442, 0.11462660113465972, 0.08610583623521961, 0.11345374063239433, 0.11131939070764929, 0.13964370911708102, 0.11874974356032908, 0.1697345616412349, 0.13462489092489704, 0.08149813816999085, 0.0864634252502583, 0.10878883040277287, 0.12351266923360527, 0.12240560754435137, 0.15941137651680037, 0.10101893756655045, 0.18759624537779018, 0.1128761716245208, 0.1560179062653333, 0.1801843274733983, 0.2749509899877012, 0.13044351217104122, 0.12218350500916131, 0.2908992092125118, 0.18669610930373892, 0.2110039838589728, 0.12411374947987497, 0.07294781025848351, 0.14282712189015, 0.1613082762924023, 0.1073437427112367, 0.11592814262257889, 0.18818476848537102, 0.15033483621664345, 0.1782318705227226, 0.188299905275926, 0.10296868567820638, 0.13959253061329946, 0.33533420297317207, 0.069149201590335, 0.15960006014211103, 0.22132115758722648, 0.09401648479979485, 0.08837841858621687, 0.1242292721872218, 0.059917908656643704, 0.10722807157435454, 0.17258096515433863, 0.15051556401886046, 0.1339521340560168, 0.15368912107078359, 0.08915762169635855, 0.0524800564016914, 0.13309787755133584, 0.1266662625130266, 0.3320884646382183, 0.1381878083338961, 0.13157548033632338, 0.12290052356547676, 0.13939421391114593, 0.2206846620538272, 0.09591223424649797, 0.10172450478421524, 0.17878126760479063, 0.1764982580789365, 0.07588010994368233, 0.16702172986697406, 0.14324011222925037, 0.12144986234488897, 0.08865282768965699, 0.09193266028887592, 0.1477112848078832, 0.12505785038229078, 0.23978178418474272, 0.136456229374744, 0.15240768436342478, 0.12570911465445533, 0.18790496396832168, 0.207503154524602, 0.13672552508069202, 0.14422149863094091, 0.13787509698886424], [0.09704165684524924, 0.06927086185896769, 0.01956240419531241, 0.035933450926677324, 0.07290626483154483, 0.0197189231403172, 0.05649221806379501, 0.020217330966261216, 0.039542184822494164, 0.04303906222048681, 0.01547819483675994, 0.033395072096027434, 0.045329396743909456, 0.055774108550394885, 0.04283422575099394, 0.0992806421709247, 0.0761886801046785, 0.009777060913620517, 0.07221820487757213, 0.061398259495035745, 0.02511721999326255, 0.021687326989194844, 0.053712181106675416, 0.043749000687967055, 0.061486118647735566, 0.04398454722831957, 0.017612676492717583, 0.03774956792767625, 0.0414938810718013, 0.016022630661609583, 0.019859754938806873, 0.02566582854342414, 0.0425294776505325, 0.01939091984240804, 0.03600972886488307, 0.013578926682384918, 0.09087179729249328, 0.06138224394817371, 0.046908482909202576, 0.04765111669257749, 0.06375148732331581, 0.014048272005311446, 0.023410432477248833, 0.02438482413708698, 0.052815165763604455, 0.05226671491982415, 0.1149301246914547, 0.040576126411906444, 0.0714632032031659, 0.07739046210190281, 0.01733174576656893, 0.01380248289933661, 0.026539839163888246, 0.023612923760083504, 0.04735735237773042, 0.01617574685951695, 0.054562968070968054, 0.03207935187674593, 0.025514619665045757, 0.019727819635591004, 0.03644742158940062, 0.018164086650358513, 0.036571608870872296, 0.04701937832578551, 0.10091931908391416, 0.008050343949435046, 0.045574505857075565, 0.04198440728941932, 0.016909215119085275, 0.04365635097201448, 0.010790599935717182, 0.057979047851404175, 0.023198870294436347, 0.04850491677643731, 0.04308404379116837, 0.054143944071256556, 0.00905977332877228, 0.04427744323038496, 0.06926767804543488, 0.014853906704956898, 0.04439435375388712, 0.037422855966724455, 0.022842079088150058, 0.04839711240492761, 0.04149592568865046, 0.029814443332725205, 0.06800860224757344, 0.05518817182746716, 0.057335557576152496, 0.028013555202051066, 0.020306741207605228, 0.023025753216643352, 0.030995550951047335, 0.007047813296594541, 0.013766844967904035, 0.04304932983359322, 0.03559690921974834, 0.05208895199757535, 0.09786719223484397, 0.022399157933250535, 0.013825632340740412, 0.022269937035162002, 0.006327962983050384, 0.020173226985207293, 0.023608825249539223, 0.05045852405601181, 0.07598052252433263, 0.033436283556511626, 0.08589653574745171, 0.06309490927378647, 0.025117051154666115, 0.04022289751446806, 0.07017951036687009, 0.07315593073144555, 0.00881548336110427, 0.02267917210701853, 0.01680112130998168, 0.023636486948817037, 0.025547815930622164, 0.030512642879330087, 0.026249421935062855, 0.06061895619495772, 0.007853959614294581, 0.024321129312738776, 0.07749748721835203, 0.003581255878088996, 0.0192129658171325, 0.03912918706191704, 0.05786676090792753, 0.116531434468925, 0.047243963344953954, 0.05201045503781643, 0.023400439458782785, 0.0070089275413920404, 0.011541528147063218, 0.05170915421331301, 0.019448738712526392, 0.007619491043442395, 0.013274843731778674, 0.01993665071495343, 0.033751110022421926, 0.04482839140109718, 0.06000209046760574, 0.07467901072232053, 0.06879144188133068, 0.006921331387275131, 0.00833337495350861, 0.03378264016646426, 0.03307154394860845, 0.053957382988301106, 0.05432467929495033, 0.016110224496515002, 0.030302381310320925, 0.03311417291115504, 0.04190696789009962, 0.03503768610244151, 0.05948041260126047, 0.02909341717895586, 0.058561362893669866, 0.05083274460048415, 0.05076869725598954, 0.06338575694826432, 0.0025414601350348676, 0.04763978038681671, 0.018932894126919564, 0.032195078674703836, 0.0285527032247046, 0.06749240143108182, 0.03884988349454943, 0.013934858852735488, 0.030880308404448442, 0.061476845512515865, 0.0185661599971354, 0.056208992245956324, 0.015857866455917247, 0.030186394760676194, 0.02957894317660248, 0.018379674984316807, 0.019766186815104447, 0.031205766135826707, 0.0736856237926986, 0.07039080723188818, 0.05229525049799122, 0.05265770058031194, 0.03651018501841463, 0.08652478602016345, 0.028025533465552144, 0.013943604135420173, 0.045178685104474425, 0.0423006327037001, 0.0450048221682664, 0.052040163209312595, 0.06505719225970097, 0.027679772429110017, 0.02342891752050491, 0.026595001145324204, 0.1161569393298123, 0.04764765086292755, 0.07855149277020246, 0.026779395157063846, 0.02028105918725487, 0.056743453606031835, 0.09575175965437666, 0.061967512738192454, 0.10674156408640556, 0.02171711308619706, 0.1253804619773291, 0.002595338432911376, 0.05707966505724471, 0.04504628224822227, 0.03779715072596446, 0.019219969835830852, 0.02343070795177482, 0.07683844523853622, 0.04264174604031723, 0.014670947821286973, 0.04465616118977778, 0.017461198585806414, 0.020146684073552024, 0.0381971534807235, 0.04618266619218048, 0.06525044751469977, 0.056769985385471955, 0.039369279256789014, 0.013137112255208194, 0.050902651200885884, 0.05202277097851038, 0.01244389066414442, 0.003378922069714463, 0.05402786104241386, 0.012208385869598715, 0.020197124140395317, 0.033649216857156716, 0.07413777726469561, 0.024053065571933985, 0.04304230911657214, 0.016484155603393447, 0.02773330910713412, 0.05899567513552029, 0.021196841589699034, 0.035931421152781695, 0.036440059484448284, 0.06761472221114673, 0.08248593672760762, 0.005565139999816893, 0.03470889983873349, 0.03898947034031153, 0.021847909192729276, 0.0620724078908097, 0.061198465919005685, 0.017028140573529527, 0.040483083357685246, 0.023050134623190388, 0.05145731382071972, 0.019250614968768787, 0.03658994733996224, 0.00251085118179617, 0.024143286609614734, 0.021202652606007177, 0.040204128599725664, 0.05264149949653074, 0.029826069076079875, 0.06358286394970492, 0.04281657747924328, 0.022488516224257182, 0.05676970336935483, 0.038874170277267694, 0.014712606425746344, 0.0390468865953153, 0.05939203023444861, 0.03280679760791827, 0.029107271220709663, 0.03267459884227719, 0.04389952307974454, 0.0025010404533531982, 0.028921584016643465, 0.01711953791527776, 0.024797096448310185, 0.022555207469849847, 0.07142663758713752, 0.032864399399841204, 0.060792741205659695, 0.012590752412506845, 0.032482004098710604, 0.0076947369325353066, 0.030489745768136345, 0.08544847893062979, 0.025389808979525696, 0.17640507401665673, 0.01708242310996866, 0.055564307112945244, 0.03645533288363367, 0.05011321016354486, 0.04109484681976028, 0.05831482514622621, 0.07119798188796267, 0.08374041863135062, 0.0056792150553519605, 0.048876951696001925, 0.05562096637731884, 0.018419196203467436, 0.05053119144577067, 0.03424463080591522, 0.02584607580502052, 0.056624691424076445, 0.037675483035854995, 0.041667851619422436, 0.03040486448298907, 0.028479432839958463, 0.011470234658190748, 0.01414914193446748, 0.06729056694894098, 0.031179245488601737, 0.02747351103607798, 0.0804416835308075, 0.04809527352335863, 0.016201486396312248, 0.016526404215255752, 0.04796542365511414, 0.03339115726703312, 0.06655785196926445, 0.049084033162216656, 0.02567099018051522, 0.04585659989970736, 0.02546654148318339, 0.01683215978118824, 0.02098245924571529, 0.0061289755649340805, 0.01322946511209011, 0.03313669338240288, 0.07084006632794626, 0.059020058397436514, 0.07219276405521668, 0.0033105287548096385, 0.054701734843547456, 0.07993939056177624, 0.06047655289876275, 0.06802279953262769, 0.05279807410261128, 0.06696316850138828, 0.00842282786834403, 0.0191974734843825, 0.013936191935499664, 0.03271765082899947, 0.07374545573838986, 0.008323554484377382, 0.05167161267308984, 0.06166319137264509, 0.008668243117426755, 0.05654119981045369, 0.02642077270138543, 0.04932016228849534, 0.26628353632986546, 0.21365143242292106, 0.08151249872753397, 0.07573529466753826, 0.13582041661720723, 0.1866805093595758, 0.10914300553849898, 0.09372472428367473, 0.12407897986122407, 0.13288801303133368, 0.10118494115886278, 0.15809357457328588, 0.1626515042153187, 0.28093661880120635, 0.154635522630997, 0.1676100303302519, 0.13865697925211862, 0.06852860286016949, 0.19915531418519095, 0.14218329393770546, 0.19465216988464817, 0.06908767754794098, 0.13456868065986782, 0.11400043629691936, 0.17008191643981263, 0.14682247390737757, 0.12786159524694085, 0.23318055871641263, 0.1936594137805514, 0.0720209271821659, 0.18773385439999402, 0.061325206188485026, 0.2150890021584928, 0.10048427211586386, 0.13273214717628434, 0.10168931956286542, 0.1739691078546457, 0.21937162469839677, 0.18208014371339232, 0.13508104457287118, 0.19653066439786926, 0.20988956006476656, 0.08022946640267037, 0.11599571516853757, 0.19306683854665607, 0.17279457009863108, 0.2232710615498945, 0.1332895742962137, 0.21175071800826117, 0.20433838450117037, 0.18905702949268743, 0.06115660507930443, 0.16849664447363466, 0.16313784843077883, 0.10110067029017955, 0.0888506619958207, 0.15066803083755076, 0.279614141327329, 0.1463487758883275, 0.08044884525588714, 0.09835323959123343, 0.11167004064191133, 0.15499256987823173, 0.10260440991260111, 0.1354083020123653, 0.0899860069330316, 0.17426564038032666, 0.20453855657251552, 0.13891172886360437, 0.11855625823955052, 0.07782660002703778, 0.1052500624791719, 0.16707507544197142, 0.22009072126820683, 0.08887875228538178, 0.16679297026712447, 0.16593106964137405, 0.16873824322829023, 0.18658972985576838, 0.11470737648778595, 0.14566675701644272, 0.1115002075675875, 0.12500689452281222, 0.10768931635539047, 0.11742233822587878, 0.06504586708615534, 0.2533846831647679, 0.12603119190316647, 0.09360978787299246, 0.17036501609254628, 0.15152406849665567, 0.1328835601452738, 0.16423964087152854, 0.2293061767704785, 0.10283339215675369, 0.1607937749940902, 0.13323507097084075, 0.15929972782032564, 0.15473921550437808, 0.08793945307843387, 0.12479726749006659, 0.15717273257905617, 0.11622371777775697, 0.15158210444496945, 0.19372009177459404, 0.10249733284581453, 0.1578820773283951, 0.11900763987796381, 0.12883398681879044, 0.09893530601402745, 0.29842752555850893, 0.13230637705419213, 0.22701964946463704, 0.13653483765665442, 0.13043194951023906, 0.12022036855341867, 0.0759913727233652, 0.12517781113274395, 0.28442257549613714, 0.19168181286659092, 0.17670687579084188, 0.12600575108081102, 0.11119131828309037, 0.12330452649621293, 0.14662843197584152, 0.0909693748690188, 0.10424460080685094, 0.09367709324578755, 0.1577949195052497, 0.17443726945202798, 0.12021656133583747, 0.198416892089881, 0.10948729526717216, 0.10063578898552805, 0.07441671346896328, 0.1423354638973251, 0.09084203717065975, 0.10148232715437189, 0.2176074802991934, 0.14779210468987003, 0.0944732321659103, 0.09877661257633008, 0.08775644688284956, 0.15863920154515654, 0.17055464966688305, 0.16810593340778723, 0.12016714172204956, 0.12062467576470226, 0.11651521854219027, 0.14388526120455936, 0.17201144102727994, 0.12014478823402897, 0.1837252773111686, 0.08955790646723472, 0.10716030606999993, 0.23861880908953026, 0.1384670488187112, 0.10378964943811297, 0.12467407097574323, 0.24685047363163903, 0.14235003967769444, 0.17316770710749552, 0.16772408358519897, 0.10921040739049204, 0.0909842475084588, 0.10508128325454891, 0.11789559837779962, 0.20042529213242233, 0.22564550366951153, 0.09397384099429473, 0.24633291468489915, 0.11831042924313806, 0.09213735946104862, 0.2007961878553033, 0.15399994736071676, 0.12070208918885328], [0.022390472950064577, 0.0822026738023851, 0.07411151265841909, 0.03371664468431845, 0.017198723217006773, 0.01636391654756153, 0.11401418087189086, 0.029441369406413287, 0.025115889693552162, 0.051844559056917205, 0.03773889584408607, 0.01208072997542331, 0.026678913927753456, 0.05225106673606206, 0.02834695391356945, 0.03466739522991702, 0.039306393373408355, 0.03065665663598338, 0.03993305173935369, 0.07620706310262904, 0.05958486988674849, 0.011663642053463263, 0.05609814506897237, 0.037727630042354576, 0.05500027858943213, 0.017191667247971054, 0.05300233911839314, 0.028959704432054423, 0.03127757263428066, 0.03312331988126971, 0.06084530752559658, 0.042561649752315134, 0.07783468943671323, 0.06607571573113091, 0.0580940621875925, 0.07465443079126999, 0.02817164007865358, 0.02165861144021619, 0.02403035028692102, 0.07346808546571992, 0.07283620609086938, 0.03865194899844937, 0.04440466218511574, 0.04145675142353866, 0.08021423011086881, 0.024027465187828057, 0.012583142615767429, 0.04139902717724908, 0.007742725128991879, 0.012538899482024135, 0.04812244726053905, 0.07781661814078689, 0.052613858206314035, 0.06923236665898003, 0.035068032520939596, 0.010509701678529382, 0.04008180781966075, 0.01687738626060309, 0.05267704837024212, 0.0124727769070887, 0.039882121855043806, 0.009281102175009437, 0.050953558820765465, 0.01921922026667744, 0.011012260893039638, 0.05999429049552418, 0.019641600629256573, 0.061749944725306705, 0.01950379493791843, 0.009793775006983196, 0.03765595341974404, 0.09323158199549653, 0.01426794586222968, 0.02439149047859246, 0.08921583576011471, 0.045537498663179576, 0.010607375734252855, 0.03116139312624, 0.037318072136258706, 0.02868531573767541, 0.019712331013579387, 0.02978815831738757, 0.04170984975644387, 0.07701394089963287, 0.05124055103806313, 0.03212404029909521, 0.05705781622964423, 0.11061841738410294, 0.042912956487271, 0.01934855434228666, 0.0709167004970368, 0.01866459846496582, 0.06168754494865425, 0.03317919617984444, 0.020181396175757982, 0.01687734358711168, 0.06813852261984721, 0.041145554059767164, 0.04824367708351929, 0.0526103033189429, 0.040619278588565066, 0.0501304428325966, 0.10348301628255285, 0.013319627705641324, 0.01590349926118506, 0.042850163372349925, 0.039870759574114345, 0.04348507442045957, 0.013554384786402807, 0.05020343676733319, 0.02793702864437364, 0.06347741218633018, 0.026163533184444532, 0.059516785258892924, 0.052825941747869365, 0.08216628630179912, 0.04740814125398174, 0.05104720301460475, 0.014971492582844803, 0.039942643998074345, 0.05433155529317446, 0.03885355712554883, 0.031125812711252365, 0.032504049595445395, 0.039726957329548895, 0.027936060141655616, 0.043051482061855495, 0.030394292589335237, 0.028690495928458404, 0.06981343860388733, 0.031246224316419102, 0.04896763843134977, 0.01125546825278434, 0.039811521346564405, 0.060995139720034786, 0.02383423034189036, 0.05753832716436591, 0.055271503879339434, 0.0048032957238319796, 0.04859068678342737, 0.06187396131281275, 0.018288416795257945, 0.0209688018730958, 0.018152937736886088, 0.03284905920736492, 0.0348558525001863, 0.0367431303311605, 0.018243923186673783, 0.030018253783055115, 0.03481372077658307, 0.03874842819641344, 0.028508283830888104, 0.07043837147648446, 0.041164950089296326, 0.0703429758141283, 0.055395501913153566, 0.014223847447283333, 0.0341003350331448, 0.09265093307476491, 0.03237308650568593, 0.019560725086193997, 0.04818695844733156, 0.0944634283951018, 0.041876157629303634, 0.032864859531400725, 0.02944798194221221, 0.04276067891623825, 0.03630565282946918, 0.07514873082982376, 0.053318033897085115, 0.06787974314647727, 0.06138955410278868, 0.0584517142851837, 0.0629549402219709, 0.027865658157679718, 0.1005184999667108, 0.06775636109523475, 0.03450826021435205, 0.04358406207757071, 0.0363085917342687, 0.028772609002771787, 0.02590717496786965, 0.033772925453376956, 0.06759835785487667, 0.01787853234418435, 0.03744155437743757, 0.03842342317511793, 0.05058004331658594, 0.02483203305018833, 0.09951375817763619, 0.03500582941342145, 0.09244768109056167, 0.07523962165578268, 0.01944666997587774, 0.049104401405202225, 0.035357496090000495, 0.033707731490721926, 0.0499153869895963, 0.048674668214516714, 0.02516232958441833, 0.03204627806553617, 0.04318779603636358, 0.013534225272451295, 0.0036095936275160057, 0.021140301068953704, 0.05550833804591093, 0.036613644115277566, 0.022714233018632513, 0.06290397694101557, 0.02065896820568014, 0.04979327030014247, 0.034981230928679, 0.008460212629870512, 0.017111949455284048, 0.039345226250588894, 0.013671203469129978, 0.007024858668955858, 0.02887898102926556, 0.024745671180426143, 0.06387858753441833, 0.01787645618605893, 0.08420628699241206, 0.07618390809511766, 0.04935753684549127, 0.015015527915238636, 0.026137485656363424, 0.014451399201789172, 0.050380424145259894, 0.04239950532792136, 0.04936280609399546, 0.03531350528646726, 0.06090503557061311, 0.022143718124425504, 0.019024458451895043, 0.06621876469580457, 0.019236373154853936, 0.08804410332231782, 0.022778831407777034, 0.09365413861814886, 0.0031926921701597166, 0.021248435696179513, 0.023108814384613652, 0.042768950152094476, 0.022060760857129935, 0.04961097285558935, 0.034459586458979174, 0.04770785759319551, 0.07544678475824185, 0.026741491819848306, 0.019445486250333488, 0.03610162530094385, 0.041050432992051356, 0.059973395327688195, 0.06409320922102779, 0.07070236082654446, 0.08581083995522931, 0.028839673177571967, 0.09074307919945568, 0.009687413185019977, 0.03602040836995002, 0.028119519047322683, 0.005623946390187484, 0.018715255610004533, 0.024694214371265844, 0.004917073920296389, 0.04108483153686393, 0.012601302041730378, 0.010029818786279066, 0.03622853255365044, 0.0238567081396468, 0.06362331099808216, 0.026263422550982796, 0.027590527315624058, 0.03500480896036606, 0.019636964061646722, 0.044794968780479394, 0.0706181419081986, 0.027522450109245256, 0.08001618058187887, 0.03524760628351942, 0.0798937855870463, 0.02385709034570027, 0.028124088821641635, 0.013535530524677597, 0.013398539340414573, 0.027468310436233878, 0.03511039059958421, 0.027061557848355733, 0.04833885752304923, 0.03686042306071613, 0.04859646440309007, 0.04810090271348599, 0.012352821722743101, 0.057234788764617406, 0.04590409364027437, 0.04714020367828198, 0.05656768335029483, 0.1305504111223854, 0.027820568975585047, 0.032144263823283836, 0.03222004452254623, 0.03442090572207235, 0.06778384282370098, 0.027417139353929088, 0.034965345257660374, 0.042175825728918426, 0.06122415165009443, 0.018480141370673664, 0.0547180583816953, 0.03769313872908242, 0.0628072083054576, 0.02443828845571261, 0.013653690639330307, 0.0012509477733146923, 0.03802881583396811, 0.026736563959275372, 0.06231232939171605, 0.01980858200113289, 0.024039487980189733, 0.052621249997173436, 0.03368158562807366, 0.03179526887834072, 0.07481052671209909, 0.028062191850040108, 0.0685142348811496, 0.039594413465238176, 0.04448249121196568, 0.04713390655524563, 0.03472549797152169, 0.01926297914906172, 0.0315288044657791, 0.041695815743878484, 0.02668753768375609, 0.039451516640838236, 0.045314672534004785, 0.018153425698983483, 0.02435229209368117, 0.05018662712245714, 0.034950394692714326, 0.0360415707109496, 0.02213964002294233, 0.052587177997338586, 0.05298245327139739, 0.03989267148426734, 0.027869762234331574, 0.05466583344968967, 0.0526107003679499, 0.054505269799847156, 0.04068259491759818, 0.01537763382657431, 0.04735953429189976, 0.04260673151293304, 0.1291018130723387, 0.11104792793048546, 0.1286610367242247, 0.14896475739078596, 0.08354498146218248, 0.061906541595817544, 0.16703551897080615, 0.1575719189713709, 0.20802958955755457, 0.12902283371658996, 0.16272502136416733, 0.15629667177563533, 0.10854778825887479, 0.20298997638747096, 0.12405147586832754, 0.1722620939835906, 0.1684004918206483, 0.16585039818892255, 0.1277795433998108, 0.14167869288939983, 0.17656376003287733, 0.08118268830003217, 0.09061623131856322, 0.07149222117732279, 0.07254270894918591, 0.15079562086611986, 0.1666523184394464, 0.0792365989764221, 0.16584655386395752, 0.15066458727233112, 0.08948007744038478, 0.1796904281945899, 0.1932327976101078, 0.14459180063568056, 0.14771820162422955, 0.16488717956235632, 0.060773805307690054, 0.08198646391974762, 0.11631914312602021, 0.15286686597391963, 0.16354923573089764, 0.13119676237693056, 0.22431377903558314, 0.10979913087794557, 0.1937302146689035, 0.18310500512598082, 0.22572244954062626, 0.113505646440899, 0.14485740044619888, 0.14038956753211096, 0.12647492199903354, 0.2106787747470662, 0.10625980634358712, 0.2043199198669754, 0.11667955230223015, 0.09756968007422984, 0.1822696437011473, 0.0778398993134033, 0.24010384659050032, 0.1594644400756806, 0.14628624252509326, 0.09947701444616541, 0.193129223480355, 0.07828285015420988, 0.10945988033199683, 0.1326991809764877, 0.11009862457285635, 0.09868840832496062, 0.08908394869649783, 0.06661939085461199, 0.15385372942546383, 0.18038522684946656, 0.07564968793303706, 0.12134509335737675, 0.11382152675651014, 0.16340470989234746, 0.11642189347185194, 0.13692813139641657, 0.1507103184121661, 0.17108622036175802, 0.10767831772682257, 0.2460584684740752, 0.13023752166191116, 0.14681819913676009, 0.1125759060960263, 0.16509499575477093, 0.11882422550115734, 0.16312489053234458, 0.07034575886791572, 0.13084814592730254, 0.13642881443956867, 0.08189010346541181, 0.07327123079448938, 0.1371183290029876, 0.23889971198514104, 0.10417832701932639, 0.11589765519602224, 0.24557807628298178, 0.12151710092439316, 0.07497304221033119, 0.16636003099847585, 0.12614701146958396, 0.242387316247914, 0.10336281062336639, 0.13044089981121942, 0.2199518951238133, 0.12108966097002849, 0.10564870710368268, 0.0887576189415995, 0.18937927001388744, 0.13735583110246807, 0.13805428112391382, 0.1375544149777852, 0.11549737042514607, 0.11343660444254056, 0.15591486648190767, 0.09654078879975714, 0.11670496343867853, 0.13168206758564338, 0.1098912388260942, 0.1682824012823403, 0.23422174737788737, 0.1401317899581045, 0.16504642961081117, 0.26136318629141897, 0.07638677416252904, 0.09051826782524586, 0.1197949843481183, 0.13061536388704553, 0.20116993342526257, 0.19959733734140173, 0.15103048091987148, 0.09346342892968096, 0.1238944819488097, 0.12556445522932336, 0.06582754154806025, 0.1830483941012062, 0.1130607511731796, 0.10993271003826521, 0.1001962149166502, 0.1835237248451449, 0.1571391726611182, 0.10748855798738077, 0.1436559672583826, 0.17554155550897121, 0.2392033245996572, 0.14600807073293254, 0.26516016223467886, 0.18512373586418107, 0.12058799140504561, 0.1420627988409251, 0.1361421079491265, 0.0848183584457729, 0.10349644915550016, 0.1318341336445883, 0.17660499375779182, 0.12483507249271497, 0.14055867330171168, 0.15673370769945905, 0.14736050128703937, 0.05751561744546052, 0.18285255617229268, 0.1759143066010438, 0.13124669407261536, 0.15233424142934382, 0.11483642112580128, 0.1954349724110216, 0.14416696561966091, 0.14640788052929565, 0.2841855335282162, 0.11509384246892296, 0.246398193994537, 0.13619529025163502, 0.09339326628833078, 0.10320390196284279, 0.14809420332312584], [0.032599964761175215, 0.05698101507732645, 0.0463330475758994, 0.014148726331768557, 0.051486984884832054, 0.02546982363128336, 0.06665447959676385, 0.07615591428475454, 0.016268652616417967, 0.005951233979430981, 0.04148998108576052, 0.049742923001758754, 0.054253306952887215, 0.054207701978157274, 0.043679034715751186, 0.020886746315227356, 0.06909129180712625, 0.00607683505222667, 0.003967554875998758, 0.032782165726530366, 0.047187229865812697, 0.0327957025001524, 0.07017628944595344, 0.051740862472797744, 0.04806686411029659, 0.13608650624519214, 0.02130398544977652, 0.04849928758630995, 0.023894104961073026, 0.02738268143730238, 0.02152853336156113, 0.034168137644883245, 0.05442836474685464, 0.02812345057463972, 0.07593295827973634, 0.023190235406218562, 0.016747317458793987, 0.029280703711265232, 0.02435142007016111, 0.054580664582317695, 0.032078954827738926, 0.05407158096204512, 0.029889474462834187, 0.08339936466654763, 0.05205186316743493, 0.005280905788822565, 0.006895883143442916, 0.09519606916001067, 0.0845492779626511, 0.05491343246831093, 0.04342644475400448, 0.07272468355949968, 0.10288528312230483, 0.04542908944131341, 0.033614135536481626, 0.044895819228258915, 0.009808730210352223, 0.06843224982731044, 0.022757817496312782, 0.03440400330873672, 0.10087473085150123, 0.042729657143354416, 0.03115423140116036, 0.060208878785488196, 0.040132440844899975, 0.008978548976301681, 0.05553345974476542, 0.026965655670210253, 0.0446297741291346, 0.05411292971984949, 0.01865133071987657, 0.02775800778181292, 0.032204878734773956, 0.05256197837297805, 0.01581647873535985, 0.015525634771620389, 0.03884780548105482, 0.051542286018957384, 0.03335627632623073, 0.032451171573484316, 0.023781632480677217, 0.07110500562703237, 0.04477526104892604, 0.0253846955820336, 0.07560703670606017, 0.050616159933269955, 0.01396756251779152, 0.03753859389689751, 0.04253262435668148, 0.016383223519369494, 0.024305703773279674, 0.014062832015042659, 0.03907898819306865, 0.019542314257705584, 0.027060238680860493, 0.05514995122211985, 0.0058921270192513475, 0.05428457363450434, 0.024881280114641413, 0.08344039801158942, 0.09259451500838622, 0.06876082828966901, 0.04512612249527592, 0.01709213225694839, 0.042860434696194716, 0.02328837515960913, 0.06773663480998948, 0.023829389683669433, 0.03063163698243443, 0.011052327590732602, 0.05377006862545386, 0.029866597760701552, 0.05350300307327416, 0.023077017067407724, 0.05503120017237961, 0.027965688532276545, 0.017676310089882463, 0.04021189146442339, 0.06572200072696432, 0.03868263309414033, 0.05529791691515129, 0.09160446774330921, 0.01641353654122213, 0.057795147367869504, 0.054513002978637815, 0.05482802240294404, 0.08436131422058679, 0.03655923355836421, 0.04316542028391268, 0.019170500127074774, 0.04129552355152555, 0.061003700393484905, 0.027042720284953248, 0.02462563250446692, 0.015228325773932738, 0.053331964008975774, 0.024955487460829318, 0.030171331018209457, 0.031562739168293774, 0.05638356022245716, 0.036110145156271756, 0.021201671115704812, 0.004959622638125438, 0.024341393655049615, 0.049863429230754264, 0.053567929862765595, 0.010468056061654352, 0.04604632624250371, 0.011295462591078831, 0.03132283251034096, 0.04191958068986423, 0.02697224965231726, 0.03413123435166199, 0.04979609417205211, 0.012870373248006217, 0.0519296574202599, 0.021934757169219665, 0.020299011739552952, 0.05603535937552806, 0.04162398327025585, 0.040697805234231055, 0.029329807912290562, 0.01840517888922477, 0.010172312995564425, 0.009893796104734065, 0.020213770512782503, 0.03518395598803181, 0.0466212049650494, 0.06809722952311859, 0.061566849472001195, 0.03328346421767492, 0.043300828838255256, 0.048853013722691685, 0.045720901907770894, 0.04853015721892007, 0.03849555621854961, 0.06213572050910443, 0.06225501332664862, 0.01973418355191825, 0.0054738020298827905, 0.021993800583004486, 0.016935416642809287, 0.09672733503975905, 0.022524170854012482, 0.05286705672915559, 0.0855123036308214, 0.04876063860137947, 0.04626288122381084, 0.0032588323711024714, 0.00186124711717639, 0.03896741371136159, 0.044481763907242566, 0.08136014323099516, 0.036960371799068525, 0.048870339160203, 0.09322267622337677, 0.015686588048993144, 0.018460493010934442, 0.026626896797097288, 0.04031746939290315, 0.02192828935221769, 0.08872347272699699, 0.006467626362791634, 0.03899975650710985, 0.04933788106427528, 0.034315476223127916, 0.04424356418894604, 0.05480585816258099, 0.0415011392760789, 0.059298771957401186, 0.07611067296238616, 0.0191593623458175, 0.04358016209152993, 0.0014164657227411226, 0.022897985072631855, 0.014415828991332091, 0.03656696673715487, 0.019514763880579267, 0.016411749820690602, 0.04667854700528551, 0.031051371588546317, 0.015480736692552455, 0.04667621666158084, 0.02316714533662889, 0.08003667870070785, 0.08689805661560968, 0.0394373156450456, 0.06549176425323822, 0.05028031584515702, 0.04928147784085013, 0.024841530685080215, 0.017227308890142012, 0.049115682049887255, 0.06582196801900864, 0.03677254164358601, 0.024674009400769137, 0.01656319247558713, 0.021806044642289635, 0.06039006300852634, 0.05308183055603877, 0.02942458573670592, 0.018989295494975522, 0.003287282370365574, 0.06193799381435383, 0.0018636542267813638, 0.02880714113416616, 0.04940247017657384, 0.10784685204271227, 0.012547918431664584, 0.03542877566360403, 0.10049354896182194, 0.04574915175908245, 0.02362130817346042, 0.024032465407799464, 0.03227544955734629, 0.02877910650568083, 0.03859055483189877, 0.0889944753726013, 0.012507963983807713, 0.020181036234134808, 0.048005425414885394, 0.034774720916175283, 0.022194954144652, 0.05806322595162783, 0.06995927804382518, 0.011951783671975136, 0.008451715038972907, 0.014177141310938168, 0.04899546525848564, 0.06444642698625103, 0.05289417480526026, 0.017773008221411146, 0.03338501228427049, 0.032993662971421145, 0.06723099475493655, 0.084231045038905, 0.0683803811261896, 0.06835062842583284, 0.045033034912194125, 0.04202203417662531, 0.032926862259046175, 0.029046524578006938, 0.04499150061747059, 0.031147340559982695, 0.028599152392416727, 0.03880274227412883, 0.0040631991578266025, 0.07520685583585873, 0.03919784685422201, 0.04034122554003261, 0.055792124185245484, 0.01634350192034617, 0.03832820933894254, 0.015948720174492337, 0.010708088884712197, 0.016455336153740063, 0.026240655315632466, 0.07774115656502545, 0.054769912239862606, 0.07317098890780471, 0.04290703043807298, 0.033375394050381146, 0.0895301798300352, 0.038819329274701886, 0.06728738313540816, 0.014737786568730371, 0.04809430873137899, 0.027108723188575823, 0.046379357590922154, 0.08668062961078249, 0.024914613677538, 0.024372068473894615, 0.02292925175424898, 0.03896841932146344, 0.024658747133798897, 0.07381092800642364, 0.019944495215895586, 0.04406508138345089, 0.0406471128371777, 0.016827371073304676, 0.02157823499146616, 0.03738413070095703, 0.025739495977177285, 0.028296105665504, 0.04358258891443256, 0.040693972041481175, 0.0023599259429829544, 0.04558949724014383, 0.039603040931979194, 0.02162615732231643, 0.03307561833935324, 0.04383204330224544, 0.01798403049178887, 0.020369601115817204, 0.038467825870611705, 0.05631900450680405, 0.0479049237765139, 0.035939569934271276, 0.02440241674776189, 0.047515422411379404, 0.0032001284898797167, 0.02345264954783488, 0.05776757658168208, 0.03964077914133668, 0.08396894074394368, 0.04069400914886501, 0.012772267818945693, 0.035278334908070974, 0.053035947275930084, 0.0629576861683745, 0.04672825976740569, 0.04861550791247282, 0.11221635781112127, 0.11044419821701013, 0.058147730596829206, 0.0890958824311383, 0.13565074681537226, 0.08208208222640678, 0.23456004797481, 0.13259689818369225, 0.2318051364272833, 0.15153618034673855, 0.11611426583840512, 0.19592372118495405, 0.182129348104354, 0.16818157309899107, 0.15777388704009354, 0.18865462217945606, 0.16635084321023896, 0.06975371798034757, 0.1214387227082625, 0.20739149098517373, 0.1628766569774598, 0.1268208073452115, 0.056322154923691414, 0.14317032066173851, 0.09708036726806313, 0.18370835634414107, 0.10184406477492303, 0.1906713639618829, 0.1979599369224161, 0.10785228456370533, 0.18234314600704238, 0.11004434389178641, 0.16390687669627368, 0.2130249558831565, 0.1798128677182831, 0.10132073191925883, 0.15280747931683436, 0.100342596124392, 0.1689377028378658, 0.1194842322729528, 0.1275646174326539, 0.1756999149802141, 0.1200144893664401, 0.18683398549910635, 0.10896830397541635, 0.1247871297528036, 0.16952140198554844, 0.1880948498728685, 0.18516149633796886, 0.177398958185222, 0.20685761963250116, 0.15577921672957018, 0.2476201401441358, 0.1734440086875111, 0.10834159736987203, 0.10523340126383118, 0.10751545341918245, 0.15923646715236828, 0.10243787939543836, 0.09707018500193954, 0.13178299966966733, 0.15028337569674477, 0.14403334935195744, 0.2645399345783517, 0.1642957323929295, 0.10503104727831669, 0.18620541610289365, 0.2505589707288891, 0.18272431305376813, 0.15541740489425138, 0.0962486572097987, 0.25861818983685225, 0.1525817476795055, 0.14423623768379912, 0.15309884649468586, 0.1665589859476313, 0.16263810102827847, 0.13053461821982637, 0.06973959491006099, 0.16650754027068615, 0.10413581680040807, 0.20720559783512726, 0.17804042610805482, 0.13672319473698735, 0.14161716884700581, 0.09389167782501318, 0.2151061309268698, 0.10657084785634652, 0.16652357066050172, 0.13462840870488435, 0.16125355032272637, 0.09661687377956696, 0.09820463936193846, 0.15366921667009592, 0.09597367665264755, 0.1736296940362081, 0.15290023293346167, 0.13443246687529609, 0.1476572416140698, 0.13440324109978974, 0.26802114152815193, 0.11904836152098142, 0.1487046791589819, 0.12085629263310693, 0.18575960799353197, 0.08778285249718465, 0.08523958662408404, 0.13037872267886996, 0.1661894260905683, 0.07557122808066197, 0.17993935936829075, 0.10708520072512329, 0.12816250644391403, 0.059725035607698373, 0.16798500786535442, 0.10739019373431802, 0.1914801268139854, 0.14804033824475482, 0.1489600818604231, 0.10817949005286209, 0.14337732049170882, 0.21065814304165542, 0.13053515256615356, 0.16643320675939322, 0.18160562933189794, 0.1566998806083575, 0.2969261311227456, 0.09477000960032456, 0.11650102125713602, 0.12800108932424337, 0.12113579286960885, 0.1409668248379603, 0.1564936526119709, 0.2669299766421318, 0.07460407607140951, 0.12324252747930586, 0.06876125873532146, 0.17866650188807398, 0.1417554754880257, 0.18364833144005388, 0.10848247184185311, 0.1540420568198897, 0.12650488992221653, 0.12129477574490011, 0.07231604220578447, 0.11493706377223134, 0.18743276508757845, 0.10059624735731632, 0.15491425845539197, 0.12776403251336887, 0.0629031086282339, 0.10777465591672808, 0.07906096230726689, 0.19460559269646183, 0.13612465263577178, 0.1229683261772152, 0.11208683819859289, 0.0959457793214824, 0.12102278604288585, 0.13403538818238303, 0.14016647794051096, 0.07917183917015791, 0.0810576809453778, 0.09337740659248084, 0.1521304328343831, 0.0867014320101589, 0.14224186423234642, 0.14046355965547264, 0.22963968309340999, 0.12560315080918372, 0.1465925417141989, 0.10972473057336174, 0.09727445372845978, 0.1397202245425433, 0.12488681502873078, 0.13047447457211092], [0.014386726597876986, 0.04662491199269425, 0.062482362845912576, 0.06175295784487389, 0.043065081918030046, 0.03983800488640554, 0.0385380070656538, 0.043218936552875675, 0.012286729761399329, 0.07923216093331575, 0.03364821124705486, 0.0182522408067598, 0.024240684215328656, 0.10277896304614842, 0.032731948303990066, 0.04141897239605896, 0.05596782393695321, 0.06015218983520754, 0.011137090132251615, 0.020702907058876008, 0.034796777545125224, 0.010072176864923676, 0.05472785473102704, 0.03332149557536468, 0.04018576044472866, 0.01545961053125211, 0.009792389973881654, 0.03246589578338899, 0.05007262581784744, 0.07028354462818243, 0.023126868982217275, 0.05904596677282825, 0.037434767436934635, 0.017876012752822135, 0.06767672864953056, 0.03901841409970075, 0.05004610888136085, 0.03226087377697695, 0.010559247457422316, 0.0073390120996918995, 0.07041061515337788, 0.05307351108058356, 0.0758167750609573, 0.032793457503430545, 0.02391932128375629, 0.011933212354051648, 0.12041189460433088, 0.0375332838302711, 0.023242054012371227, 0.014783394326514099, 0.0223731827645679, 0.05490474934049416, 0.018329925114812795, 0.03221192542696372, 0.023794885382812936, 0.020465709239942953, 0.025770959327928722, 0.020569142361637205, 0.11337768533849157, 0.03319700772408396, 0.01394894296026905, 0.0422250301198801, 0.035494388939696364, 0.021860210290469695, 0.031423367545357905, 0.051348529814276844, 0.03433322468481492, 0.0242098887974862, 0.07649863808183, 0.02079623027384514, 0.006826397248005378, 0.021886018475925084, 0.020256896714272443, 0.04834332154132426, 0.10031837984570302, 0.006809840861023986, 0.034494048086344264, 0.08482634395477362, 0.045825618944945745, 0.07745027920464054, 0.024860108496795874, 0.029632303594553377, 0.01983981899684295, 0.0519570575124817, 0.05768725764937699, 0.03645905104349367, 0.03169038856867701, 0.05718776257708669, 0.012372374530968955, 0.05169441516045481, 0.07975823231390677, 0.03794057447521482, 0.07520022845710628, 0.08189017768017948, 0.05344736055121757, 0.05236008080828469, 0.04324391353293322, 0.02863574027287541, 0.031153915988397785, 0.04742637582239695, 0.01464179626054829, 0.030066868166613858, 0.04025654277938884, 0.03449549156357534, 0.031077120402187575, 0.03184213550412096, 0.021553371188929304, 0.04226459401252214, 0.05082184245111421, 0.06575058825546876, 0.05144731709151529, 0.03179938779794611, 0.03274393027822953, 0.00900649083632743, 0.054251080509857275, 0.026115041255252436, 0.007568324135718285, 0.03798339268541895, 0.028493984500528313, 0.023100865982996766, 0.027140182828588877, 0.04850674988119863, 0.04527623299509287, 0.037081820555613376, 0.032173675135709345, 0.0281163723411737, 0.07920536198071204, 0.051795120889437385, 0.03363447409356013, 0.10137227407540195, 0.046013616083655506, 0.027412859017204028, 0.026789560724864714, 0.04244116207701154, 0.03877139024552889, 0.05423964401416015, 0.022765200010326225, 0.06285121766268276, 0.021494422398973256, 0.09328984800959006, 0.009614657665224513, 0.07821598264854401, 0.04100761107110884, 0.021798597190354485, 0.025126177715719678, 0.060348721672198735, 0.014740624355908949, 0.06948423673748039, 0.043653200555127114, 0.030206466144591104, 0.08345176029251888, 0.017501675320090726, 0.05141332672792487, 0.041063813914661296, 0.028446177202567924, 0.08932902812375687, 0.0057005703547474695, 0.02904283053794643, 0.03267351530666929, 0.015447418900293997, 0.019154339861415792, 0.04697944335930515, 0.07010539207840338, 0.032390567794209346, 0.02576138747826917, 0.12234470690600574, 0.052236984483897686, 0.02123094142007176, 0.02353913016122533, 0.059017754028900526, 0.0909805070841685, 0.039128044154495, 0.0581987235636916, 0.014400851523532765, 0.03142251036479138, 0.016965308495855425, 0.01989651907933876, 0.016304028940794524, 0.058095628119190224, 0.009471515004406683, 0.028183280664961785, 0.04172572800598573, 0.015062584716361016, 0.04957773577189073, 0.021521273301914334, 0.04305439870222472, 0.020964547511539422, 0.029942662331450265, 0.04405588988447562, 0.10296142005245201, 0.03782876992772799, 0.020213187926856335, 0.012719432470476022, 0.06875394858070649, 0.028333428272162564, 0.04162230972724501, 0.08786900842096657, 0.03306866441562306, 0.06965166525333188, 0.011297353212285088, 0.042950138085871004, 0.04716263880254701, 0.013714376982534304, 0.013240669686638284, 0.018200813683506567, 0.04114750219741836, 0.014639774835814023, 0.10196578441536985, 0.06111988732300233, 0.014383610505319666, 0.06984536579693668, 0.048164508480113, 0.025538908303133212, 0.04390671449073125, 0.034122039141948335, 0.045280507765710354, 0.012224935762787936, 0.06037592138454784, 0.019007051378139295, 0.02606369020213606, 0.040184138852055185, 0.05530290043679997, 0.1093705851235427, 0.05329870466084685, 0.05676121319993399, 0.09156995787634514, 0.06027079245541245, 0.046760480108787306, 0.010886726613534847, 0.030751963240618352, 0.027139676312799565, 0.027750998197006993, 0.04424226543051191, 0.014196248830558034, 0.04186418678727932, 0.04193676883005537, 0.056010601329035126, 0.04337518090324011, 0.01922893126902636, 0.01197593965116539, 0.07693196326727048, 0.10346575392759405, 0.07243275234941393, 0.017322557978332043, 0.10587306576780975, 0.05882430952624418, 0.08404239852097817, 0.053132196408114396, 0.09722366114147007, 0.06737685645930469, 0.061477762064896524, 0.059931441719527356, 0.06743890742654912, 0.06093989053624682, 0.03509236383251846, 0.04150308370299172, 0.024784437264315784, 0.014162719526211731, 0.01851752334914636, 0.04094741918379441, 0.03793788418988697, 0.03178739840222988, 0.03363639254530426, 0.026884752296609804, 0.0674622850783635, 0.0589146029233234, 0.03137893516395707, 0.0397802064253483, 0.011633231624728069, 0.05445258844702039, 0.027819606038974598, 0.03753928038349841, 0.019067068860749714, 0.02064579322905047, 0.07604339727549814, 0.04119523713598028, 0.028731095117109362, 0.0315593030245509, 0.01935279942699708, 0.04046785819809884, 0.04121172765735537, 0.04438122516148724, 0.005329813784555881, 0.0512236708891578, 0.06715490977512673, 0.03424918759264983, 0.07115163476555608, 0.04705692357674707, 0.021487902631633915, 0.041033103843801655, 0.07377237343462184, 0.03145673079416156, 0.03951973114453722, 0.11002366023603827, 0.03223358500690665, 0.02799189562210813, 0.11501677785417996, 0.055099919336498715, 0.006050801903256797, 0.04963099599990528, 0.02796420238155406, 0.03686923977511469, 0.05294760572724044, 0.027016320236725733, 0.0800111933494918, 0.09709547739475965, 0.033698469487717375, 0.010454915409354726, 0.04768345577758737, 0.02964588304166682, 0.06069058828870766, 0.009913810899888631, 0.05013106623664498, 0.016316448782163206, 0.07024387683486566, 0.05631983571220189, 0.036263506262912415, 0.021070273869554512, 0.028398301255947445, 0.0113327174767619, 0.029823679360561073, 0.06188500075950287, 0.04394194053020328, 0.05474287208926398, 0.05600809658062644, 0.05852614798641298, 0.06728453328832984, 0.004377869308882509, 0.040977643147925846, 0.03255646377510857, 0.03238674202293623, 0.02288627398229437, 0.018996427534148097, 0.1166825728432741, 0.01303390548855532, 0.031074563703441527, 0.024143255068338476, 0.023987387357919943, 0.06022188863425981, 0.07904161451733671, 0.005685311334673315, 0.060950154438614845, 0.03501659055473283, 0.020796764620172326, 0.02628671300044516, 0.038505467600771226, 0.0795615631795954, 0.07583136568428017, 0.009192077850457281, 0.08544516895199195, 0.06962641738937236, 0.011962825901719043, 0.10262844065437093, 0.12321344271185808, 0.14729203074239194, 0.2026214258512482, 0.09038673699251376, 0.052608533296734095, 0.17716774949803948, 0.14313756226329133, 0.1747895817970857, 0.16801135410787538, 0.15512603771639988, 0.0890131329651922, 0.1774979309993796, 0.2917720639379695, 0.21490910556167364, 0.10407248191768304, 0.17921929800650105, 0.1664983673254028, 0.08952932636020705, 0.11347086940077133, 0.1604997063986957, 0.0789144697773736, 0.15981721255229786, 0.08355595040484332, 0.12502889177994803, 0.14586998673621565, 0.12875481450464576, 0.10614628001349047, 0.18907150137238204, 0.17177475529024377, 0.09425213153008372, 0.25808981037698686, 0.17988311941735446, 0.11757540618418716, 0.2473396380082704, 0.22327088343445212, 0.1601755659794435, 0.13464445393765345, 0.18922315182862803, 0.15958414849592373, 0.13240070402389392, 0.09585602398146875, 0.15091526991454884, 0.10120379170984961, 0.10519135859794915, 0.16632653045235202, 0.2229789225384593, 0.14240267279092222, 0.14644912909716368, 0.17650855908868834, 0.1361402971087955, 0.19832434627460316, 0.10760776174720377, 0.09210025207721628, 0.11721129369107075, 0.10748824628535658, 0.13096430688165128, 0.09324005732196383, 0.20456940022995695, 0.1320895808748901, 0.11461083791800775, 0.1675850644824095, 0.22301735094515607, 0.1083045790437609, 0.2693011978408322, 0.16381713619921356, 0.15200579655356705, 0.0676428792939987, 0.20138855528784916, 0.1483176788315177, 0.2632477961014956, 0.11156637745443732, 0.2605870185652748, 0.15328270616009831, 0.15533193916780874, 0.10801780576002784, 0.17726960184518248, 0.17806600051699206, 0.08323471920448355, 0.1820262786350213, 0.10982738443999551, 0.10430331953102723, 0.17427095415769145, 0.2417343747220002, 0.14933191268937662, 0.12189962610136718, 0.1509365695528686, 0.15138353541260585, 0.13728713791351765, 0.07649923922144808, 0.17911587230628356, 0.1492686668643728, 0.1342601253418252, 0.2348208980401978, 0.16578793904045597, 0.16837819770444185, 0.2208465096191503, 0.10424652296933345, 0.11211021585040726, 0.1802277727983892, 0.06686821070616134, 0.14679001236800104, 0.14293606916908175, 0.2314010518603027, 0.1412805009749718, 0.10740680299932137, 0.1747346925549209, 0.1325340976472944, 0.17051340109901503, 0.15924004430416971, 0.14591752871638164, 0.12161143531557173, 0.07868545042583719, 0.13288921531056985, 0.19133083638735116, 0.07351776483119465, 0.09511363881756552, 0.15392349130706862, 0.17913430725457147, 0.06643649598117918, 0.14092489349422976, 0.19334904762217775, 0.11470522425952367, 0.12011422659270465, 0.12359170053969137, 0.22353933309204876, 0.22538177407113835, 0.12841761228628457, 0.18270957400090992, 0.205460645374842, 0.07523197753471322, 0.10278635483700782, 0.06981402490055189, 0.13518837396986783, 0.1623609830858186, 0.16818847507238388, 0.1556412663194351, 0.13538124330807477, 0.11953496548812836, 0.14471067785052583, 0.0996463057526853, 0.1701948416302912, 0.09250090050045401, 0.14152897201711312, 0.09719533336465247, 0.11944653859245591, 0.1640255906386301, 0.3037730074720457, 0.11126707671792246, 0.1443246571579948, 0.11699446782586165, 0.11552615091204643, 0.14698199112899601, 0.13690052350284532, 0.1830598825472407, 0.1528123181196861, 0.05564306011365261, 0.17634720134083182, 0.04832337632251438, 0.10169533838052303, 0.09973085121600889, 0.06615623875404708, 0.16850492684170604, 0.19593479402828962, 0.12700154999038205, 0.1971908938139677, 0.1075458517880179, 0.1703814769280143, 0.11887869171914645, 0.10391618561698124, 0.1602360064862296, 0.16596621775534004, 0.17276452796068043, 0.20470420393394306, 0.10095439298311248, 0.11728802433935925], [0.04567748626868706, 0.034974343798239715, 0.03212915369658731, 0.039596283677383326, 0.03973653474531602, 0.026268088804499712, 0.03546053216268774, 0.014208085158315953, 0.01865817146608606, 0.0035245001345174387, 0.036792757746297866, 0.027191326080355793, 0.011196898885827977, 0.09519296698272228, 0.060168862182763405, 0.06094612086599227, 0.049283711705356836, 0.02682352325791726, 0.040639772996655665, 0.03387396143807564, 0.043844960382557474, 0.01649846792133758, 0.015983602970663924, 0.033218377866433, 0.027406196386436932, 0.010770632452477003, 0.054098580294521526, 0.07192278557340614, 0.020814331255678553, 0.06330897434963845, 0.04622672378900461, 0.056846745719667524, 0.020329766339273192, 0.022376644883479457, 0.026273942494299263, 0.03170777337800246, 0.026584052611724474, 0.045426057768054307, 0.04565801231365185, 0.028274134383536875, 0.019163143588230014, 0.031033695486257784, 0.03733713791007176, 0.0755255192052573, 0.06702639948343858, 0.03961804344726261, 0.06636529433308169, 0.01801385369617492, 0.018389634606137406, 0.04116329881071579, 0.048972774093272164, 0.026197352854069322, 0.07802790016285144, 0.02370056954532629, 0.11632410809397697, 0.030120735100354068, 0.016984339017653838, 0.03101931266428437, 0.024293322894664016, 0.06407985056284815, 0.029409789167402778, 0.06277053878875449, 0.015197300290310523, 0.03644582597189583, 0.05833048446220346, 0.06184085039421916, 0.03602774449973367, 0.0345707045198651, 0.03472657408565283, 0.05334298861271236, 0.042921175772789866, 0.059197220180067234, 0.06735039147315547, 0.05599394382443279, 0.12763412698404863, 0.05419662542408332, 0.039987295313039795, 0.020315826950536575, 0.08584360577515326, 0.04212898507830687, 0.07103180018020794, 0.026356614034739323, 0.03253323826356791, 0.06665826454991475, 0.02222683124273317, 0.016532226363779046, 0.019123024940199684, 0.04398021679662634, 0.0860321854997892, 0.042875789731624536, 0.04158388874202501, 0.029614707273140084, 0.020306759761297144, 0.04696393989434, 0.08406764638493769, 0.04511408114922233, 0.027701611979864538, 0.08502818585839123, 0.04177007875114214, 0.05414660838141572, 0.08311105513712391, 0.0011323209173497162, 0.025218242990376893, 0.010920592667389428, 0.04532693652436137, 0.05949785678240005, 0.02002493474719813, 0.020111699232074898, 0.04254296247381717, 0.004705636974904337, 0.07230184492073022, 0.0475212222954724, 0.05120274974615313, 0.03240955193177797, 0.00966440196862095, 0.0454919679032173, 0.04948238092765678, 0.012474695358832832, 0.027230103296460584, 0.06800792689318769, 0.033516658149892464, 0.02305529069417389, 0.062336011324077845, 0.02751758904196322, 0.011231712105654879, 0.047057357733137906, 0.03279075608588755, 0.07922752993181348, 0.09661475123721175, 0.05493898090207949, 0.049890009249793366, 0.051937305252067745, 0.06194733745360281, 0.04543270741123706, 0.07756716004223563, 0.029673782228201162, 0.019147768143739086, 0.03905752528226003, 0.011601725600485224, 0.05801072642498184, 0.04581754808896221, 0.03536223841365427, 0.010461219026183244, 0.008640014602860902, 0.03955476051487494, 0.05180168889637571, 0.017191320293932222, 0.11416036169975996, 0.03576654191419948, 0.04152368943323381, 0.0696276493545156, 0.026814773336809594, 0.02212534069258254, 0.03802360595727805, 0.03531297465087846, 0.02357594439672539, 0.036095020186621696, 0.05078536589280702, 0.010759377782960655, 0.022820913036412094, 0.04181628486549016, 0.030962119053583592, 0.056814740601112135, 0.08879167609848082, 0.020601266223820858, 0.024988923069031443, 0.04835016414290294, 0.026302149672119413, 0.03925597557099536, 0.059540404108702205, 0.02491567123797722, 0.045089163540978916, 0.010773343146865955, 0.016200567988562398, 0.0113393791798444, 0.024072331725619733, 0.019760743161896244, 0.046198581549106166, 0.03421720102778636, 0.021557248910539784, 0.03457834493019618, 0.04968951063347049, 0.04087669622094836, 0.06111608381615952, 0.01635975124372635, 0.03370454396645073, 0.022124678325781133, 0.010734027873695595, 0.03654108433693182, 0.09412834129761904, 0.0928926802589558, 0.025021792789630126, 0.022211229443200864, 0.0193728912199731, 0.007421473055728711, 0.07200600259238854, 0.03938744332117494, 0.022241134283831343, 0.02267587697133422, 0.02660346719494555, 0.018335057065996807, 0.08099085054709576, 0.03111110519967042, 0.02588943392765941, 0.008388140813622158, 0.09521504587610252, 0.026712941398727708, 0.013055126273684436, 0.004459559822862502, 0.032352410271414556, 0.031142969310167246, 0.029480992670869455, 0.06223073767614551, 0.06850024539744481, 0.010554174878052436, 0.03917612790246494, 0.032328561355825514, 0.035140258332830854, 0.020555232658807654, 0.07258176818140782, 0.05086214478069451, 0.007082911779434653, 0.033420620529796, 0.029190647801442537, 0.03859786127577536, 0.05440536930109374, 0.03048385311558377, 0.04430880268046167, 0.07302053330931813, 0.026900200100499205, 0.017644317958911415, 0.015542073342658114, 0.03858547854179051, 0.030198953754734248, 0.03125236929918174, 0.03041861462406814, 0.04572980025841389, 0.06803285563364625, 0.01591929958522087, 0.06285330309765413, 0.07211064541479573, 0.006865123441457399, 0.08480774573399685, 0.03382868671906181, 0.028052926136297174, 0.04568314514472149, 0.023162698016676586, 0.07454451872035861, 0.028345089267531876, 0.02899030689150095, 0.05208612070418894, 0.03178111612214707, 0.03444665082497522, 0.04194404558802489, 0.054010045787435956, 0.034317264799028635, 0.05078396694443654, 0.018722304157563485, 0.050932144149555825, 0.02795848969981307, 0.032884860411286354, 0.00927393302845303, 0.10455536772496998, 0.01763025426043896, 0.03867867373628542, 0.008320007018483011, 0.039775638506398536, 0.065156469354406, 0.04625329267582856, 0.011832511263492052, 0.051922629281762056, 0.015364643459179206, 0.022107412260083947, 0.041179685431416146, 0.051867372676497325, 0.01492968369348091, 0.03584557322028559, 0.046236360576585867, 0.025889276221278124, 0.04159418604103848, 0.05790309274743777, 0.03221674567612354, 0.0296874952618964, 0.0008273058176655468, 0.036695005765068345, 0.054327955876942724, 0.015446286197402515, 0.03703986694745254, 0.019079609301115852, 0.05745866132201627, 0.029114572098478675, 0.09496355429291725, 0.05805960427096579, 0.021863019319425803, 0.020631651605071966, 0.01839414871938061, 0.0399448667303659, 0.08096960285911337, 0.04607191549439449, 0.004267349140718579, 0.01932551065692678, 0.04709641325462144, 0.026107901794603094, 0.04069014255946968, 0.10809666637214832, 0.03639025395386852, 0.024728713106014766, 0.03902819189534057, 0.08036270417505875, 0.017653633767622523, 0.08768893370870501, 0.010610899080347735, 0.05754650563176256, 0.04378360703412909, 0.008688614143466111, 0.009005022311612265, 0.0483869338495424, 0.03428138938033953, 0.06557421686011367, 0.013638727086799918, 0.07846624968806282, 0.11282111168839037, 0.028579936333699152, 0.0602422086376464, 0.06744346421328373, 0.06344328823615797, 0.05404399162216578, 0.0030820857273283764, 0.028570268004841637, 0.03277049916505348, 0.0824494898552075, 0.048776988114695996, 0.07196025660960004, 0.027575446874834597, 0.06684003135887906, 0.006440018469220377, 0.04631468313164078, 0.03423112371820025, 0.0528296302218223, 0.015639331795682665, 0.0442555016343249, 0.010852435680135386, 0.05609693536825944, 0.022349808823491912, 0.029129018003004603, 0.043902706893277355, 0.02092851253109984, 0.012154500382166589, 0.02859150270523969, 0.04132345799007453, 0.016710709169274196, 0.032529939417145215, 0.12475115043343976, 0.18687685194890946, 0.09168985925498419, 0.12797247210983187, 0.15817763021914288, 0.21893766126595438, 0.09691924700746313, 0.22751017939299345, 0.08902542293071747, 0.1456861715996638, 0.12053256039507687, 0.10849974161828868, 0.16291688138153404, 0.27896523708477616, 0.17125385667895898, 0.1332601110334508, 0.21911056683165953, 0.16500396392075345, 0.07365068348008208, 0.17647155560553074, 0.1440226030535996, 0.1968522518291138, 0.1616368695977144, 0.12437415425665677, 0.14984858105890453, 0.21511597180506214, 0.12193968723295256, 0.1292571148951538, 0.09521702741039917, 0.19892284384695813, 0.13039168057730421, 0.1538149151019752, 0.11116872730781324, 0.15005679801106453, 0.08910812044632621, 0.20470355084398761, 0.19111794390482828, 0.16255121037829667, 0.1495108741801232, 0.11171236532391049, 0.07569721507024951, 0.12977410980965942, 0.07140662928577513, 0.15286837995518, 0.0785798131255433, 0.13991867483127862, 0.18290339328814298, 0.19778280111495405, 0.2246652453322895, 0.16997023805743083, 0.09896335177472793, 0.11892114256625064, 0.15591663279337808, 0.12870287901023403, 0.16326895623933524, 0.08389041409827769, 0.09545474473270588, 0.11678012073389255, 0.10357294231653214, 0.21921121689956635, 0.18400760513031855, 0.17059720441466197, 0.12441840852261521, 0.19946535379858688, 0.1355712182703428, 0.09999530069762841, 0.12963281973497942, 0.1441391944536008, 0.12858291825978085, 0.15960728866048157, 0.07038653246127069, 0.2215581847121939, 0.10725910819019191, 0.17234669881872833, 0.2992236422142014, 0.208834701043088, 0.1722214391338639, 0.11564946616999805, 0.1917875837534666, 0.1711972604971379, 0.13325809239177033, 0.08956458579632454, 0.19362879276741296, 0.11630582899670117, 0.07611322595039383, 0.10055202277726494, 0.17436488036764786, 0.11730137557606213, 0.2463520472520031, 0.17074541130568832, 0.09603387225070037, 0.2182164421537891, 0.1619004359235987, 0.13398631737800315, 0.21490803686901927, 0.2480828989064321, 0.10267631660099141, 0.15561744337901473, 0.15113320900127292, 0.14842062955722213, 0.11928062405786477, 0.12801450735423714, 0.11458921915618703, 0.1463783875806257, 0.22157921717735007, 0.1386232560616918, 0.11889055123901926, 0.16158471145899966, 0.09229428658727556, 0.09991960163461044, 0.13506269868230447, 0.12080009721103124, 0.16486703767441213, 0.16393322293879464, 0.09727530719828792, 0.18611027277074754, 0.1591139830998145, 0.1571077055996284, 0.1549209823133424, 0.14532658620737493, 0.10406253713881597, 0.19208606070606038, 0.15277210855856538, 0.05869969922059681, 0.10315562525647692, 0.10167029831791297, 0.13425893790554255, 0.21503368247067556, 0.2824103459715843, 0.13883987412555143, 0.13179718953324482, 0.09875618867226876, 0.19145337981171906, 0.1615527694229968, 0.19406058912863955, 0.07529183174483478, 0.12072200843249448, 0.15138246671995148, 0.0800917757442221, 0.17402561497874558, 0.15463017916772515, 0.09883420323603787, 0.12269373153685592, 0.08990354690467939, 0.15396784205222502, 0.18429402960464358, 0.1268115156562999, 0.20179713726975024, 0.13656536961207166, 0.1953188856714405, 0.15299402555683628, 0.21324007480870932, 0.08498036186210811, 0.17233786726137623, 0.12807279563276097, 0.24200929590733722, 0.1995657366933301, 0.12212673071189784, 0.15351335081504658, 0.1334275840781629, 0.14733782125404105, 0.06732164809363894, 0.09103786767809652, 0.14112101343926042, 0.09048242209246382, 0.11372660606866702, 0.15500701207201928, 0.09600253877579235, 0.12514626985648647, 0.21780796407256275, 0.14536560833221301, 0.1475671597290784, 0.13602673367131501, 0.10047659088741057, 0.09678613540017977, 0.12131278766901232], [0.06667307039606385, 0.057077238234342076, 0.091405505372677, 0.037586696198559366, 0.02976490868604742, 0.01734318968374282, 0.02748522769252304, 0.015456418368557934, 0.05209053648286499, 0.022887140439706855, 0.0467706401104806, 0.04251519130775705, 0.05097503286378924, 0.03764233872061595, 0.04949992158799432, 0.04970308451447636, 0.05515899429155979, 0.03750629934074823, 0.0061564944007841405, 0.02266203777253395, 0.005718207030440681, 0.05129534380102996, 0.009890686505968915, 0.009931782005878631, 0.016385062190238386, 0.03198065736796707, 0.04354016033175867, 0.0677706697024405, 0.03601981094107032, 0.030191235418897122, 0.022932344654691406, 0.03129940290818922, 0.029085984569974244, 0.02038850732787978, 0.05687363001925405, 0.027561193928704597, 0.007253834419316263, 0.050344930932624266, 0.049075724818976596, 0.04092099130502902, 0.0435905929771252, 0.003462897007011634, 0.04593870369717479, 0.047867018583929166, 0.01038262929796474, 0.0619564361841185, 0.05547471504542045, 0.03404423609026708, 0.0726424164895434, 0.02331419447727967, 0.05289988192089368, 0.03432533565501217, 0.07824911212082952, 0.03881249409459997, 0.038820108529762365, 0.0570278779923683, 0.035189581467420794, 0.026776975755637977, 0.03487862159090582, 0.057035741047002375, 0.022570620021724608, 0.01296793690926279, 0.04990851099137217, 0.00550604834643309, 0.04793076164787635, 0.046314508726936765, 0.1163069496396929, 0.05429439224826638, 0.03285040249465965, 0.03417256455577444, 0.04276061212294735, 0.03648619138402864, 0.06188091152580455, 0.07983570510987192, 0.013821448483213317, 0.02575645034085028, 0.014932617959857453, 0.029076922946842387, 0.031317904649768025, 0.038822873029857874, 0.03704502116306685, 0.017345269552606624, 0.027406272456573788, 0.03660769209091086, 0.016133383214764763, 0.02106316780555062, 0.01709521959128324, 0.022053803222661372, 0.020708400807052385, 0.04642806845367886, 0.07322541059693322, 0.07452563106198795, 0.0452850126021076, 0.06199597781233024, 0.038400817356887273, 0.02451750529871788, 0.014867047357256524, 0.044898067935719155, 0.0716106902109459, 0.0118653884055675, 0.0373896263045026, 0.04495275679801125, 0.06438589742174372, 0.03283085432485677, 0.037150135249248706, 0.035214313538745046, 0.04025640919280704, 0.0493457552511245, 0.040587214098195545, 0.06582358590094373, 0.061293553590076044, 0.018977159525093157, 0.01570270564116072, 0.06560624053236097, 0.021319117840903345, 0.042911453638225794, 0.033248976615141146, 0.02092089067446068, 0.03461125917965546, 0.03492751799058169, 0.015081733054103097, 0.04045010602567345, 0.022249101239140145, 0.02715623919357313, 0.025951210300263483, 0.07985120115336031, 0.014050233130546985, 0.035350174803170376, 0.07887146231951192, 0.016289145169139374, 0.104832545039244, 0.021138889132998884, 0.06534786924021319, 0.026479693660803605, 0.041500534425722435, 0.04249972495017573, 0.036579111983883195, 0.030293789095594548, 0.05455163918668404, 0.07693708408623934, 0.038502803290612064, 0.05801081548270304, 0.06969301772187464, 0.08872009595506825, 0.02535610805352917, 0.02448973598802695, 0.08874849794665352, 0.009121021848841337, 0.018192124989582226, 0.019505993550410494, 0.03819547622697428, 0.004586519953591051, 0.05433670579805039, 0.03470663257758133, 0.038293922116281465, 0.010556279794400325, 0.02549341650592396, 0.03408014490560163, 0.030414714638027363, 0.01951587895746343, 0.02560867946158396, 0.03974701015977189, 0.08084482557023875, 0.055254590333788656, 0.12048871431034058, 0.029103731176292058, 0.04136648400162812, 0.04423060629051179, 0.09295768497395329, 0.0303761971736094, 0.04256066640664358, 0.03854815222439356, 0.042987976485164836, 0.023265344461833593, 0.016934071500145365, 0.06663249718258157, 0.06128087770775892, 0.03550585141056217, 0.07241553452331573, 0.02651754504768178, 0.008561901704524644, 0.039184888955787756, 0.029679956896870863, 0.02660265083250124, 0.025874488928820938, 0.02769354668998858, 0.0731303117936477, 0.08513947832398117, 0.030129843107715715, 0.06116709904745221, 0.04594925332639832, 0.05068411468528211, 0.039294366870308295, 0.017108056890720036, 0.04479709874431137, 0.0811875271028839, 0.016419865205534734, 0.08154798822943121, 0.02408767006272683, 0.02243447488581296, 0.03543887629348319, 0.039900686679175124, 0.06013923564751167, 0.054445307978312485, 0.028112678301113192, 0.014901215836289339, 0.03333047185151372, 0.04104738647583872, 0.02224716794444248, 0.028485447946877684, 0.056906915342551656, 0.01830571625760058, 0.011966476340603549, 0.03073302548727952, 0.027860168120241724, 0.061601849156431854, 0.02078722060105065, 0.006848202938272152, 0.07804053151630796, 0.04936880635796115, 0.04150965542066842, 0.05397634857217781, 0.07116103035514243, 0.035609273400041275, 0.01398069574861438, 0.04931440322252456, 0.004931185394525528, 0.05052424494351726, 0.03335080298711546, 0.05549201821850147, 0.03624302669777535, 0.012901616737508448, 0.03373081228346564, 0.013950277898402419, 0.049185317766387016, 0.03426126604608726, 0.06702244383632205, 0.03083125986449886, 0.020976826344849542, 0.05161893132026307, 0.05545938227442093, 0.04192782595055178, 0.08407601781073026, 0.02609915187349543, 0.003576262847673206, 0.015894910757197067, 0.10700524915591814, 0.011682035255944356, 0.022450648139056284, 0.03848686195851769, 0.01536854437290458, 0.040777170506771654, 0.0761536878417246, 0.01324249444223824, 0.057419835866312496, 0.03808753826888278, 0.09587242544512264, 0.03855384078633506, 0.010102065007231431, 0.050335049236309715, 0.05208416514506098, 0.030301587212306913, 0.01574027872266015, 0.025980187456298154, 0.04671766560932156, 0.051390691223787144, 0.07955095046781935, 0.05947135839960538, 0.03592491993913427, 0.026231942501908634, 0.021593458295683376, 0.026512077274674084, 0.029424633976304904, 0.08323604022734798, 0.019120373617624864, 0.07458772655809298, 0.01481500517911627, 0.04027503338875249, 0.043142588110640645, 0.031313500003307126, 0.04079371668922249, 0.0709971493051853, 0.01987657571589807, 0.10835010980372317, 0.01040024417306995, 0.04511978455411736, 0.04304863221477717, 0.09423056471860036, 0.039057484464137815, 0.09099985487409867, 0.03425991162657738, 0.10413170530227944, 0.009796617432584753, 0.04307701936340891, 0.05318015770171769, 0.03682128219224978, 0.05659451198880561, 0.11122391340904869, 0.057033778066397645, 0.08490608772262931, 0.06707469103275798, 0.03444438727456145, 0.08404298481764272, 0.012530422300187638, 0.016846026810526382, 0.01821876623580465, 0.08696734352270141, 0.007479425512428861, 0.013952969111414859, 0.028683940909104422, 0.038085374908405356, 0.051348106790101156, 0.04065846027515363, 0.1100622296507936, 0.03362917144841049, 0.06739523945725523, 0.05692545048077591, 0.03956941051001195, 0.08526659337803721, 0.02464100980432704, 0.030325564148370177, 0.02311590560566401, 0.06566242111148313, 0.03312716791697312, 0.046869716825312935, 0.025248561578337103, 0.03625950608693529, 0.01646147371502593, 0.030057600597501732, 0.05377690009481739, 0.07156540435971692, 0.04759221243148204, 0.046202689336496405, 0.007628695530002005, 0.04317237049690448, 0.014813906800554832, 0.011141286977363052, 0.022979417226451915, 0.028512705175671726, 0.06849505036370829, 0.06670920556643978, 0.07544853622675873, 0.0576725371502107, 0.0387784258055035, 0.04507957128225826, 0.0246255044839927, 0.060663169642793946, 0.0325788988993736, 0.054387216368922964, 0.02648169560416136, 0.03169307885400485, 0.07495385769288987, 0.23673736082855612, 0.14761557744350284, 0.15866841247770935, 0.07745779716060497, 0.08910896649467759, 0.09468952368479222, 0.09511996191577055, 0.0942615196981933, 0.09390249091666192, 0.1937922730576247, 0.15108373743714765, 0.11265023218584247, 0.08449989545624703, 0.16711607167962939, 0.2342326717916876, 0.12842208001529798, 0.1170371710031759, 0.144049602386076, 0.14102683489909396, 0.18950041820062324, 0.1076001621549949, 0.1498667339910753, 0.1784802376641892, 0.1281366648618132, 0.12961116386577487, 0.1257974302279763, 0.11892652313690633, 0.2062278479570523, 0.11251128729782067, 0.12162855666247196, 0.16524241596926004, 0.11048164698877372, 0.1815038957283832, 0.09947164129698649, 0.18112381221726537, 0.10122366642463021, 0.10608345721266232, 0.16587776859523728, 0.10663028646376915, 0.13395272777415812, 0.11815316072897986, 0.0843857902509626, 0.18134152865968645, 0.09592750764568336, 0.1348712542676367, 0.17943014216143638, 0.11534963850863278, 0.10304330120561644, 0.1589852650067769, 0.16827463841764256, 0.10329425844247453, 0.22818960074800998, 0.2644392993533984, 0.15956875635311007, 0.12957537750480697, 0.1644115668023005, 0.07786873917211778, 0.1088239488308318, 0.1618099384359084, 0.266403675195761, 0.22874693881021813, 0.10202024321188219, 0.1120824521058239, 0.13798226311337203, 0.14637181215221062, 0.1957379764644429, 0.19600084517151117, 0.1270194654352963, 0.10954743149341084, 0.11135204520542175, 0.25450437620747834, 0.1073240461118985, 0.13827322953147814, 0.1906224712729454, 0.09464725095313042, 0.12256761096068658, 0.1006005889212247, 0.09035630151629448, 0.1675729823182337, 0.08472921908833086, 0.19589100731536746, 0.12749852176057175, 0.13151024555554613, 0.08776984264841303, 0.07593905873363838, 0.08800443552900106, 0.10269389065797441, 0.13160777860321105, 0.12161536869825795, 0.15372584253782406, 0.157523293455597, 0.21234195737633854, 0.13141692790668458, 0.2299440823844634, 0.1313489323365502, 0.13388927414780483, 0.08532718231435865, 0.15212980943033472, 0.2640892134513706, 0.14782306709093973, 0.09179272092296742, 0.1474249642342329, 0.21585071284789592, 0.1643949278513901, 0.11811522956122644, 0.1400274143088609, 0.08187374653061852, 0.15071327215991914, 0.07632786990143359, 0.15063899802044034, 0.20333685621153563, 0.12007084806100465, 0.08801488496828824, 0.1732726616319269, 0.1610240337322466, 0.23193765431642532, 0.10023654322139919, 0.16854017885634676, 0.207153647497762, 0.05623980250675231, 0.11620201737969182, 0.17739777074893937, 0.09768713236553594, 0.12840376381063834, 0.10150477712159045, 0.21277655905578285, 0.20037369802594185, 0.0994936385541223, 0.14835529087577015, 0.1156362633628305, 0.1661960015189834, 0.07521181338233873, 0.1543757412582636, 0.11077420160290785, 0.10986511522787623, 0.1113340852316469, 0.1733133610105142, 0.21920962870353833, 0.19697714044013992, 0.1566600866499357, 0.16803979320684448, 0.11427111239754595, 0.20066741039045155, 0.1594622730044648, 0.14388925395905972, 0.1297769002849236, 0.28206824557855725, 0.26088248239830136, 0.12868328631157055, 0.09433952684048563, 0.10528506216360256, 0.08532690029824153, 0.13871256611309946, 0.18287835322553292, 0.1273406224208884, 0.16082237736554816, 0.10134759766515344, 0.10314099752577022, 0.10183279155171476, 0.12363919799099676, 0.08965432629338466, 0.11892354712472297, 0.16286334284814075, 0.13722775125643238, 0.16007277852622792, 0.15369300992460921, 0.17189412232255563, 0.12433894677087665, 0.16300147137371823, 0.11341461460688151, 0.1620205896324478, 0.09078062445041724, 0.14945942850317806, 0.20246777159627527, 0.15387266903417185, 0.22728345327777788], [0.02741429692832753, 0.014506119605357526, 0.04059415317897219, 0.014968446066632168, 0.08890698358300142, 0.014527242983604083, 0.03214636781194713, 0.061466299594030716, 0.01460884861444356, 0.022101835020293947, 0.04725349623186048, 0.013717608107981505, 0.040900055319070816, 0.05305966260493733, 0.041821131089818664, 0.05940658003964927, 0.009329287968284916, 0.07317930838325992, 0.10386566020315513, 0.02872005195968086, 0.018765543536574114, 0.03201347513822839, 0.03298780371551402, 0.08889186603482813, 0.04786591278389096, 0.069492289039772, 0.046409091737587005, 0.03672446160635445, 0.024312692949024495, 0.06577409949386492, 0.008833560223138193, 0.022836082534922753, 0.047754635161254555, 0.04087444380274974, 0.0978352501988411, 0.05347775520931464, 0.03470874027698301, 0.016417777915194165, 0.01137763410952175, 0.058233567397110164, 0.09278526922571473, 0.04941787716234103, 0.04318193306971807, 0.035865206737071276, 0.05362612537282985, 0.05942108531598933, 0.03625272285717074, 0.049877671044669114, 0.09328925429144874, 0.0245204219390871, 0.019831907702609897, 0.018581047479528934, 0.05684939518687315, 0.09373527020215988, 0.0411602634267183, 0.0086242792167468, 0.06045948350219987, 0.04641770436137449, 0.027722631457436364, 0.02428699237498222, 0.025582451962691266, 0.029959763269289397, 0.03562680663890205, 0.03227726039767731, 0.031067696982063353, 0.03344515964272432, 0.04488036771363113, 0.03880392971041147, 0.020268951047910377, 0.05837057527969591, 0.07790836985805072, 0.0499679495987948, 0.039162865723483264, 0.04700436838902533, 0.02416801311483141, 0.043883392499992624, 0.06988012057263404, 0.07738719665212557, 0.022604977748414967, 0.012497534025897039, 0.03844820719677955, 0.05056650654296391, 0.06765758123947307, 0.050189491812488995, 0.029283130534167867, 0.08350408912519924, 0.03252400223573204, 0.02808942495903466, 0.05190073963603936, 0.04016413055069279, 0.04254660270817112, 0.06793584951083176, 0.05851464098668657, 0.055754185596015304, 0.018540323981142137, 0.019176099631295074, 0.055290977834374644, 0.06584874470718205, 0.0028512933386082295, 0.051131399668520316, 0.031037543521961197, 0.04268735472578555, 0.03833721530099865, 0.0439476031169761, 0.025797095913731027, 0.03486337045615073, 0.045526778339990415, 0.030855435325065628, 0.019131635708617978, 0.04516632834565826, 0.023468570470868144, 0.012261509727977682, 0.030935175382182933, 0.049841832733363844, 0.09366087731905282, 0.024930054059950635, 0.028419723348633852, 0.006544017478518072, 0.02127761508745607, 0.015512579466303578, 0.06032109151419718, 0.006817055464125588, 0.024111762031679973, 0.009426667947991518, 0.11202687266631983, 0.0190158810801222, 0.014225715804059291, 0.08327569317771122, 0.08988903049612418, 0.04452856373973191, 0.045022900885669515, 0.004504083581196028, 0.04475893380003981, 0.0351651239907369, 0.014351628578879172, 0.054454362179967575, 0.03783133033721242, 0.024343965196749195, 0.012278262784093386, 0.08389148279093206, 0.011590690792218084, 0.034984396188519895, 0.05181403081223834, 0.03926411322026979, 0.015027581321191974, 0.07921617507236078, 0.027398979000281543, 0.022525092972500715, 0.03920370611012913, 0.06450819593737833, 0.018990323369507678, 0.08245371267548762, 0.059213940767222084, 0.0655222219938878, 0.0911003045621328, 0.010677312020561658, 0.036027896640007384, 0.02406764506304171, 0.014919344648660626, 0.011269834376435028, 0.04408454420627095, 0.023640086365048774, 0.02963136663311161, 0.046479232114506885, 0.05134477454703301, 0.040485250428901054, 0.04135800125368405, 0.1794327248353511, 0.01833176564105088, 0.0323190470226109, 0.04714910945040174, 0.08317196319694631, 0.03525008505675942, 0.008425192536378745, 0.035353202765691094, 0.0273822565577575, 0.029068970834487118, 0.04603528308507521, 0.009448782093386399, 0.01979912518436322, 0.057559114720788784, 0.010239907805953408, 0.008472721528960392, 0.047888429544400424, 0.02647862125741085, 0.016589143524470273, 0.01178634875032003, 0.05349491737433709, 0.03541926133038942, 0.1102230159449391, 0.06007758172927424, 0.04580520617309958, 0.08109023154247552, 0.01783006824553013, 0.01605760437087156, 0.02222606311988784, 0.01526540068880422, 0.018245758146804292, 0.04229400903568603, 0.04001310720923357, 0.08640031301183626, 0.06244908494409174, 0.05210634793911595, 0.07207831004052423, 0.05651407802361064, 0.031843185643083416, 0.03402334092243109, 0.0405616619536886, 0.06518387686810456, 0.01077239041478606, 0.10128088601049967, 0.08005651630810462, 0.04244074647431262, 0.04664138024963904, 0.06097074903664179, 0.07646821002708748, 0.01985881055588834, 0.04637655227270443, 0.029525699646910653, 0.08200426804251038, 0.009550162249070127, 0.03119617758784443, 0.0345119227131363, 0.0667531110229902, 0.045285042288014665, 0.01859178450104082, 0.038410160996136256, 0.05190076932194643, 0.10092129319673404, 0.03341015995829366, 0.03924791955796536, 0.026103586205863394, 0.011878638524649432, 0.059751418957603164, 0.012779333992511965, 0.046898809014237486, 0.019667907909024507, 0.039830501773394644, 0.04267365096893627, 0.060946458543185145, 0.036025948502356187, 0.046723402410862036, 0.008804308472463163, 0.06415556446881965, 0.06671862342045642, 0.0694960962573532, 0.0535226031934144, 0.01712961256998824, 0.011301240210741526, 0.03186996604199521, 0.032770885081845336, 0.02868878342269454, 0.021781294017273467, 0.02567600709880935, 0.054078312241472304, 0.030834202480036765, 0.06671627081232145, 0.035404533409746364, 0.0635944191890303, 0.10713729207054712, 0.1188058647676371, 0.03630156359577086, 0.034608461282914504, 0.02701483779674163, 0.03144157242786605, 0.046322152848006226, 0.05265537394734565, 0.02010045755014289, 0.049717537840479054, 0.025608716568967793, 0.029017089145781938, 0.034215360501548275, 0.046736438234802336, 0.03328023958601989, 0.05376230947149452, 0.03786877168749925, 0.038237841727095656, 0.05872074281796813, 0.046692621835973114, 0.011489293010527035, 0.0712574427598156, 0.01727280625345884, 0.06771432585082948, 0.03530080342898145, 0.06210827959876042, 0.027410380243964028, 0.0636443508847151, 0.017527526179037523, 0.08335321792401373, 0.04129196495341603, 0.01592627577338135, 0.039779883591108955, 0.011911219735338818, 0.016373903999920003, 0.05924820572545286, 0.013812809884257149, 0.03799751204496715, 0.003048685834983189, 0.05324228659446817, 0.0356158414069796, 0.07932143387733959, 0.023774982837494463, 0.014141925475996686, 0.06774600071366876, 0.03340768860653043, 0.03963997391110752, 0.08257097942987457, 0.004440297379915137, 0.044354003184707835, 0.012599359470186755, 0.020238959004927892, 0.05707250333216507, 0.006252864131965907, 0.08500250754877925, 0.030013867690286133, 0.05578173782851081, 0.03082906681811437, 0.031049742574396078, 0.03502790459606331, 0.0665148816187866, 0.021418981232272927, 0.018435720121487975, 0.03194120850821491, 0.03829461973509751, 0.011518220999278128, 0.07141616588342004, 0.023338299433817156, 0.08186841048882343, 0.00911100007215282, 0.059076636025565676, 0.04868906216870528, 0.03061502029595431, 0.015953148940752726, 0.039978986969799735, 0.041843440048978664, 0.028500135049398523, 0.07253017407492734, 0.011638125160970958, 0.04566281029838137, 0.024522160420019645, 0.03341103198181372, 0.09623093472328037, 0.05245236687187571, 0.05968066259811167, 0.022238902274693828, 0.02368026067415485, 0.03757294049137272, 0.04848496784688905, 0.030831423136987723, 0.0063511931330140214, 0.06349982504616491, 0.07083683056407608, 0.12783072190359235, 0.0689831460476853, 0.09204792324453592, 0.10146234111743979, 0.1688549533719197, 0.1465403538895771, 0.06847359487437643, 0.22722084569977596, 0.16204515472054482, 0.09949980580131523, 0.1403971968102269, 0.10205480502918363, 0.131619697494898, 0.21368278074078262, 0.3056648309575394, 0.08832873922074214, 0.09829297719988972, 0.16966147493803874, 0.18514439725549892, 0.08153675953508355, 0.059673923897207715, 0.10577013730653562, 0.170021461090073, 0.10277534878696315, 0.15134115878026932, 0.15253696648869663, 0.15217706939438358, 0.17157581518404186, 0.11237662460189313, 0.14718220772920176, 0.07817562465788797, 0.1673611139995046, 0.12064358568750322, 0.0848791774478741, 0.20877442380879074, 0.20666305819759145, 0.05823701838380657, 0.12223375582834706, 0.26352722954470664, 0.22980985755566508, 0.1193202324793674, 0.14930477977031842, 0.16260044445516542, 0.10989700531354174, 0.1461597508750856, 0.15238941268762574, 0.22855482646264136, 0.1627253627520986, 0.1315293781226501, 0.14178802608512342, 0.12051364305079915, 0.08125519612804055, 0.19869749812642112, 0.1678179355803877, 0.12722711835522205, 0.10437046163133346, 0.11536201753187925, 0.16499026387464255, 0.09105248798732646, 0.08984036787296645, 0.14645303279394284, 0.1814192463643849, 0.13096455921186134, 0.16608880570856854, 0.11895349278347567, 0.10814880224643275, 0.14592858671676368, 0.11823052962427028, 0.07566058266093023, 0.15507793170399964, 0.19483007752569392, 0.13819809450069442, 0.1274256280157715, 0.183678804023657, 0.1935942383715883, 0.14985671499744058, 0.17447768681449816, 0.13741861679591238, 0.13170430233003572, 0.07458360763848759, 0.13169161160476506, 0.21993181260768324, 0.1642243526293896, 0.18638103792909533, 0.11137184570543468, 0.15499297063797712, 0.07184350935858674, 0.08515174602507614, 0.2647043648175895, 0.19243145623477176, 0.1566524276859127, 0.2207302744500339, 0.11705622935551219, 0.1149235269986093, 0.14752644550753757, 0.21115360083058476, 0.15140192583203316, 0.1542264805175364, 0.10240058647468686, 0.13591131486464292, 0.13305514468811452, 0.15097674942808226, 0.15545629343250766, 0.09743987102410756, 0.17194926389493048, 0.16572922031627968, 0.15069557935930789, 0.13062410638667643, 0.10003975534345955, 0.09974227286875248, 0.19072267605224624, 0.12417718826327473, 0.16103332542115822, 0.1495370126212947, 0.1215282257180661, 0.18725650501437485, 0.06794776098104194, 0.0662536604795605, 0.15661805140553042, 0.06350200696033426, 0.13998364243889228, 0.11877780416398309, 0.12325651696301065, 0.0867618502525147, 0.2929092716658488, 0.0847512757172808, 0.22522952989675105, 0.12848974904045463, 0.12940839427756146, 0.17668565036728978, 0.17309652030235156, 0.09620226555853151, 0.14531808119500056, 0.13969653518870473, 0.1243606916978024, 0.2007912748376839, 0.20764960994711146, 0.18764151638606563, 0.10085196918225847, 0.14571670355508104, 0.1625797979068011, 0.12478401273256168, 0.1457781533827074, 0.14347099437145516, 0.1490191716584377, 0.17363940132781863, 0.09162567090243101, 0.09817845639190637, 0.10318873246433213, 0.13015517295571044, 0.13858010759577155, 0.23366812005406246, 0.0844093608611729, 0.12348509102594107, 0.18258998432429507, 0.12836598849389702, 0.08645005174912512, 0.0948785783839412, 0.10095165445818566, 0.08054868638282642, 0.09645069207181223, 0.11938159324927256, 0.15071156522026286, 0.11598935496294871, 0.1396952586947009, 0.36950467096176, 0.08313548663863912, 0.23160974378697574, 0.10386101435869932, 0.18998370476765558, 0.11369867163011804, 0.1703088206704706, 0.11419127957196906, 0.058917616042890586, 0.16391843935707584, 0.08482124540023506], [0.039103171075112186, 0.07392609448288567, 0.07202795532066375, 0.12449614849174395, 0.022573505120817572, 0.05006250663427636, 0.016745326647651382, 0.005893507877772208, 0.049945332648348995, 0.019276881430414505, 0.019912003990611993, 0.019645393003884237, 0.01695801503956318, 0.03906264239049051, 0.02455678903061198, 0.016282859178318176, 0.038512169194291346, 0.026550294169283006, 0.06017943778715562, 0.041329476807732135, 0.06639728089794517, 0.016421859727415722, 0.07546646651462652, 0.029273855543578975, 0.06462652396294288, 0.06109034613473341, 0.038085946362116374, 0.024747884635871742, 0.10410693241283298, 0.019880093495885376, 0.02513990373699926, 0.0036654659834312042, 0.05093657106044702, 0.019178279690095223, 0.04600619831762742, 0.09730462945299223, 0.044927642520633526, 0.052319310925668105, 0.019210206883144565, 0.03560234545147978, 0.035459014470689, 0.0675621855771169, 0.002974214562527777, 0.015623874714947306, 0.03574154638045002, 0.022522911058331374, 0.0027261169134362717, 0.040750078405835666, 0.0307817419161438, 0.009614471200620756, 0.09150331301498227, 0.023830382306186948, 0.07037935589323752, 0.029549192331614904, 0.07133560575312003, 0.041131865145871416, 0.05582020334259141, 0.020362224167911336, 0.04926189998514019, 0.06443577716709115, 0.03551352892827708, 0.020187748959870078, 0.04083976324182004, 0.017471032042521983, 0.024547128123231232, 0.0284377946445602, 0.05256678006844595, 0.06427660875488073, 0.012232804383529583, 0.05258864373899996, 0.011089015661127632, 0.03620168907218613, 0.04559591681754682, 0.011915809918718878, 0.029280870694492478, 0.038252747763181105, 0.09717732886201702, 0.02590854051959468, 0.025521430725348182, 0.030883779800205957, 0.09364403056679294, 0.025011139259731863, 0.03832755253824871, 0.05534562216780614, 0.036526887051877566, 0.024744561669649556, 0.05988126140437089, 0.02312942382559413, 0.014931637397239683, 0.02544558694353327, 0.01660303838434629, 0.036843409325229004, 0.0105625045580382, 0.024280570942210034, 0.04061890380398836, 0.05555566109251231, 0.011715379023371497, 0.03822903243417386, 0.027323311478539836, 0.012592060447786935, 0.06950448994757608, 0.0639142032014206, 0.026680223818402737, 0.09430684265680611, 0.09087943399208598, 0.035089547382085584, 0.03772218638914637, 0.02355025124415988, 0.036325345718069, 0.06015656850649975, 0.048192123795161024, 0.01343109828667366, 0.02427265964797698, 0.03613031301938463, 0.022707273528794758, 0.054919944814173505, 0.04827465432754252, 0.09383215015986934, 0.020193723248667084, 0.003683691275000456, 0.01984438506042352, 0.031220727832987905, 0.04270710327546112, 0.0764673417143058, 0.04438430136360694, 0.07278026299900375, 0.051081824203720316, 0.03497624369629193, 0.052049814839847386, 0.04514830157859251, 0.005016143213651958, 0.044711310183629394, 0.05921038216911256, 0.027011190140910912, 0.07031717876088805, 0.014908697612554533, 0.021893182056373917, 0.019785588410741184, 0.039756346377544105, 0.01657369200984249, 0.08664473192766309, 0.005083783016743837, 0.028771133984264452, 0.03912571381079033, 0.02034508241194999, 0.06147959516965784, 0.03663851719466038, 0.04444610000064131, 0.041139620589092374, 0.08656596779474057, 0.02687857206183253, 0.02576929320639465, 0.02750848845607834, 0.0881552547798492, 0.012148165224061813, 0.055773154890630394, 0.0522289915534202, 0.05139872868312523, 0.02518497065466363, 0.018326221797906328, 0.03239371450035833, 0.06767650600522757, 0.006393026142177405, 0.05794922464701813, 0.02437422070215689, 0.016332798295479733, 0.07062310687615536, 0.03225097723770887, 0.04639303908334114, 0.031226490609697066, 0.06156784023914952, 0.037149986819713376, 0.026619122800184414, 0.03311390202725306, 0.013352893547562417, 0.050623080460354686, 0.04235136220813729, 0.048541181822656654, 0.07438297543558292, 0.02855262344382936, 0.024640002338855993, 0.026545807886577677, 0.052535030990839005, 0.05128522461745888, 0.019145263395330403, 0.05024118239816744, 0.023120868718251586, 0.02565671496995492, 0.018348695884924382, 0.020181776526442263, 0.06264127150643617, 0.003123089386463107, 0.004661783932533581, 0.02753396638581762, 0.060077043672208674, 0.04971758236933965, 0.037625517943524756, 0.04072698277013842, 0.0653188957949169, 0.01842123154347064, 0.044691298171528615, 0.02530352874600794, 0.02200611837906763, 0.015316070821427274, 0.058886215774691664, 0.04120393510675058, 0.025628685907577164, 0.06756208909791894, 0.03611365922552068, 0.07291442103451118, 0.04494728345889598, 0.0319752062932821, 0.048131141520570964, 0.053511148144025356, 0.028623871476156637, 0.010386878093413543, 0.011033114315068815, 0.055801972484914586, 0.026027868589153513, 0.037655663982150145, 0.027135282798553817, 0.03919270748156123, 0.08113559160847217, 0.02996496572450269, 0.04238958652422298, 0.0532046559965238, 0.08824657605146058, 0.021565245551755652, 0.01518128381576389, 0.012418825554050272, 0.055193459629663266, 0.03295470763987396, 0.056790194066707045, 0.09098487091250718, 0.010539484064793214, 0.04555488718324341, 0.0070242018682620255, 0.059860922847292386, 0.0642889877781272, 0.008392341369471978, 0.02303685945662437, 0.06809137397794984, 0.032003534070099704, 0.04616723323124461, 0.05859857046743855, 0.06109326277510263, 0.03703277572640218, 0.16246988583588973, 0.057599086794652976, 0.03251563452067785, 0.04391350143123418, 0.022567927881027572, 0.02302920605870895, 0.03854215938190464, 0.030785111266595777, 0.01460336414311314, 0.014778898766962811, 0.01167770111351274, 0.05744833062635735, 0.05036331021983642, 0.013547042162826983, 0.058760280735441484, 0.04353000033006538, 0.06980606165598147, 0.04894088029686827, 0.021000242959416937, 0.020614142486010678, 0.02525711854104884, 0.018926925404230133, 0.06594778431463055, 0.04416421375935897, 0.01660687157709617, 0.041352943517267704, 0.04316426995501388, 0.020709901800728403, 0.02452658547554165, 0.038304412373690866, 0.03782728192163631, 0.04263367889507208, 0.01965380710316822, 0.07329109808779322, 0.023598624429723714, 0.022018875897629187, 0.042835817657760344, 0.022380403861461673, 0.020188582020637114, 0.012654124402615707, 0.03617070811742451, 0.06028346833772957, 0.044302212409093045, 0.06082161817175802, 0.026533139425737318, 0.035811360212392174, 0.03502417901472654, 0.02234131494333269, 0.025289060577051714, 0.04617370846972335, 0.032685159603715874, 0.015662110163248144, 0.06854230290628038, 0.03585225626011379, 0.04055716453876812, 0.013645330345752882, 0.008768779080128297, 0.038642338186036795, 0.06035019854607526, 0.035809193141176365, 0.02029035458690487, 0.027103090287710074, 0.015777924163558055, 0.010396089073765324, 0.057462579861748964, 0.025182599492836744, 0.051754106098087505, 0.06445296530728228, 0.018418116378597915, 0.03825848827545997, 0.06470580017776228, 0.01948157874721801, 0.008986421307781711, 0.024066823134489823, 0.024558447730669286, 0.03179173625539988, 0.058363966454635374, 0.03241701422666665, 0.016165894849109463, 0.04123694212466944, 0.03245799562137108, 0.15544875321211293, 0.033799249431467615, 0.0671099207829684, 0.05231751121755224, 0.041745565613382496, 0.018153293967770878, 0.04136042065510992, 0.05465023721626494, 0.07086932921083644, 0.020796501157747116, 0.014987914455559803, 0.019910983537556604, 0.08231404790421948, 0.00826405093903304, 0.03469211616902612, 0.07737293999525718, 0.02159669962566113, 0.03876425820635632, 0.04288406838895753, 0.022345886573020834, 0.036223363495082594, 0.07901934266556054, 0.029071995086269453, 0.016040238115238026, 0.12636031955480576, 0.2629197668284178, 0.13196760148275644, 0.14699247025419027, 0.07927718703285791, 0.25735208590049297, 0.10779043397633359, 0.07855288800783455, 0.1000328385271132, 0.1457143880543299, 0.22235208976780996, 0.09648110528360121, 0.1420678454451263, 0.1106136008456815, 0.1828880308312364, 0.11761108122300357, 0.07053580804495141, 0.1014370635675732, 0.2795354143017903, 0.10683445871109143, 0.1395205719745718, 0.07819786682375707, 0.2794933196855709, 0.10821169926202856, 0.13628932036226615, 0.16860976262250915, 0.10607268864987418, 0.08394991949899122, 0.22145428403746337, 0.1205870637204498, 0.08940992222051136, 0.14301328221336007, 0.15105684200534597, 0.13980255840579048, 0.15911992028122768, 0.21259707806166261, 0.3016223228769377, 0.17192725179484114, 0.23731375724310055, 0.06713060443871655, 0.11147731973323971, 0.14423748449189588, 0.0867632677545771, 0.10854929481865838, 0.10514159759622999, 0.13353319169254974, 0.12456429249141365, 0.10921993656666018, 0.1427485581371002, 0.23966030945302919, 0.15628249675501138, 0.16468154528411105, 0.13881758000934497, 0.1059953568619676, 0.1331900671357289, 0.13811546377837658, 0.11176309111760929, 0.17169999133329839, 0.1575543449143879, 0.1660693169105798, 0.123644148116, 0.08626661510788836, 0.2034382038982585, 0.06909865391207859, 0.08941128035075963, 0.17377500655129552, 0.17358887591399252, 0.22896800976013765, 0.1058659931004513, 0.09886234547593631, 0.16972921817796305, 0.26908796397037804, 0.1358124756370671, 0.11452111968537793, 0.11047756517655216, 0.12072008627001196, 0.22143583424622193, 0.14885252981912345, 0.1257124840049073, 0.1495844210148789, 0.17288549803197384, 0.11266808083746582, 0.15699583425885066, 0.13217951433034614, 0.06893265774124302, 0.05968718236545101, 0.14023953495780006, 0.14254176610847935, 0.16987656417768449, 0.15315766911953688, 0.09220466483384371, 0.1549023692496121, 0.1319480681559071, 0.1297241632710211, 0.10765705519588664, 0.12270047765923664, 0.06813925734604709, 0.12140479913796298, 0.1491761062061414, 0.14615920168580487, 0.144630080612842, 0.11466046533314511, 0.13551957963500172, 0.16658316511893645, 0.18055329361231998, 0.1967527743545361, 0.13694520079297945, 0.11505734364618547, 0.09380132134538144, 0.13569089700467885, 0.13635051785968244, 0.12676709069637582, 0.16946609714068472, 0.1121905459149275, 0.2029143218533136, 0.19551806326489896, 0.14497222553472966, 0.20194626442389563, 0.1376101651112549, 0.10202024321188219, 0.11269505790551193, 0.11552718991879374, 0.07343282602960244, 0.15340958372689784, 0.1365579481353052, 0.24799084290862083, 0.12964982975972816, 0.09794976358534768, 0.1729415895533748, 0.34189149329904467, 0.07688825076911598, 0.09665696459705941, 0.18538031115895137, 0.16397901345044374, 0.1620300445938483, 0.09312040085205808, 0.08410861293668859, 0.08277027576696128, 0.12723681080387905, 0.059494465167517774, 0.22446755203418434, 0.146382795937825, 0.13708122161915526, 0.1185368065489456, 0.1166997461405117, 0.2371419797418639, 0.14087292831391096, 0.20204872533213347, 0.07884426260716282, 0.15535052254563197, 0.12343983486061916, 0.08415550924837589, 0.29341348679736257, 0.15861333027714863, 0.1920508680632338, 0.20404154027346522, 0.19819202134385705, 0.11029598390450701, 0.12025769116007723, 0.11044822807889432, 0.186660768231377, 0.2540099871112034, 0.0792218153947033, 0.21790131140733138, 0.17123981524491683, 0.10810238833073527, 0.14417158177820966, 0.1559791067847982, 0.09641824537538923, 0.13667507388163358, 0.19802238122792915, 0.11909920605830848, 0.08839544345391914, 0.22861489589558914, 0.10076895254314877, 0.13572488736826926], [0.05232553383393679, 0.022009222411725204, 0.01274181935514207, 0.039237458986463025, 0.03940766313462518, 0.029911210112913977, 0.003713325231728959, 0.02034454435488442, 0.040366477114730515, 0.003285569632680563, 0.043646213234751485, 0.05517611192772165, 0.028289890178712085, 0.03802317922236398, 0.047682279473519884, 0.05143782873346936, 0.053995058115106076, 0.042338493367424235, 0.036795099222217686, 0.03460867650574073, 0.036240622139303014, 0.0663610640913248, 0.03812911709246691, 0.043476383871166036, 0.03870952110446524, 0.036565879490808584, 0.01614446719031548, 0.055640748323639855, 0.06020173561410047, 0.01519628262030892, 0.052021386873093434, 0.0433140539098531, 0.05278006959997583, 0.011190035875188187, 0.03127464857243467, 0.019846949180646334, 0.03584278645575978, 0.05285962040943559, 0.010868683148146374, 0.04752770495542791, 0.055966269137570634, 0.03470006828138139, 0.02262835725559853, 0.04132440051762387, 0.04038956903968938, 0.03757726721232757, 0.048895668660406955, 0.03295098205853719, 0.06754807734978385, 0.033876952293212526, 0.004937417579640169, 0.06711395806632936, 0.03688204182253685, 0.04091647904715501, 0.015915750263957307, 0.0378135410574032, 0.03028581657417817, 0.035705359259736724, 0.023018700958346017, 0.006461034699896118, 0.016502000544278417, 0.02211728467955254, 0.16225257015321404, 0.011119425162178231, 0.040264491181005724, 0.01664478604652686, 0.05626771097013261, 0.03076725704886485, 0.05588727493886836, 0.012626839343283791, 0.041363225973327644, 0.07508501745178364, 0.03129640463157557, 0.006349602617774508, 0.03572104084014427, 0.102582835679641, 0.045692418279941194, 0.006992653634370072, 0.013258047074486967, 0.019848453885060735, 0.04587561001244467, 0.04514369284152053, 0.05827779939863831, 0.01695363265753258, 0.04858115760725923, 0.039961427755770274, 0.02409966316918144, 0.05134531260409858, 0.0433661526767537, 0.02566360024502501, 0.06650544150033966, 0.04413958558870945, 0.005669915481121279, 0.03620675423007924, 0.02228900651971344, 0.004927200061501935, 0.0394826868432574, 0.02517031509341905, 0.04816629705601372, 0.0686732548638247, 0.03348863836436067, 0.014242145098251058, 0.017330539776594378, 0.019079867197433487, 0.058944318516296335, 0.06617543811444193, 0.052901993331033736, 0.021883862536924426, 0.025382855055795517, 0.05222836072789505, 0.024647564823681023, 0.031149362912401557, 0.016886447883734945, 0.05423280883405823, 0.05306155508151278, 0.02582367778813932, 0.0782906575477682, 0.041629875922808424, 0.03453182340308558, 0.025271594131481834, 0.0003946123854348116, 0.05472015865962021, 0.02843179252522532, 0.06693741597700864, 0.032128931052284315, 0.006124130268290173, 0.03257550357375294, 0.0764227683248464, 0.03031330201338278, 0.05438108622911386, 0.026472582030692138, 0.01947881239175331, 0.14787620486458763, 0.007312039670068771, 0.010231127271254081, 0.018484032079868484, 0.055108754604589194, 0.03362180934345815, 0.07253481991938315, 0.06957947654882446, 0.007297577531062416, 0.05545449523197021, 0.0254277420026483, 0.08972683412139304, 0.019833946753351483, 0.08956264879088849, 0.04523183401033748, 0.007700078076595673, 0.04759823495987803, 0.0395878788549453, 0.05009070082451217, 0.04032212636957411, 0.01691592413408216, 0.015173897591012064, 0.04166800747043453, 0.019735352434508968, 0.047715572218294255, 0.031679631138104014, 0.02160284831916215, 0.04419759556185454, 0.03353693362441845, 0.09903592639602721, 0.014809502154093934, 0.033947218835237436, 0.05284278478939086, 0.03185252186085563, 0.062349978543352336, 0.02843199847120559, 0.048951808421406895, 0.04063650012540165, 0.04286614552256651, 0.02315311874554027, 0.06732385969371535, 0.1008038037980441, 0.03541336867783684, 0.06928340415470302, 0.08749013461056165, 0.06308435593382455, 0.07184693065937608, 0.013114795874571428, 0.03505341963318642, 0.006335229536489351, 0.05214931086811703, 0.053846802984480746, 0.033848928796942346, 0.05432509118691087, 0.01192706366055063, 0.013478930632118136, 0.004012516501461505, 0.024392045233980753, 0.06273992519709282, 0.004758675022458192, 0.01583783217938617, 0.03894983594364021, 0.08251321807620116, 0.05086071614641696, 0.04830379104532767, 0.07737406063824892, 0.06291251906077377, 0.028263401072763372, 0.03334697350510396, 0.21264494658680633, 0.056351948442170396, 0.030108489663689397, 0.016048616962507367, 0.042895779479295015, 0.03280616307165474, 0.03638073590991553, 0.06969212714466266, 0.07348516228375956, 0.041168712778016925, 0.018162277665396687, 0.04470013715035748, 0.059129985311301425, 0.013949368767498527, 0.023841154579713475, 0.09911831220961176, 0.013702312444365816, 0.08643481545732357, 0.022604530604439788, 0.026459551772859413, 0.00436392157098453, 0.08671194824273698, 0.08431064037722535, 0.020509330825007055, 0.024250664246210363, 0.06725276936776936, 0.05345177632989362, 0.015961492536007427, 0.03058073121792404, 0.051357517222641036, 0.054119868800626136, 0.05352429157937877, 0.03307955543277785, 0.0133826648016111, 0.01584428144269623, 0.02611972791783046, 0.047693229862488806, 0.13332316390005872, 0.017327400491922162, 0.036152421598671935, 0.01879127936263103, 0.036201663097017445, 0.0326482377568027, 0.055075532363844104, 0.050666043389355764, 0.021245739844744094, 0.07753021593089215, 0.09308451801189221, 0.01915176646434702, 0.028102696414862294, 0.07233564974740148, 0.05314217458362691, 0.08859504407155327, 0.015155335549934534, 0.01460433357351576, 0.04071557224960998, 0.07597503805300221, 0.016331228653143626, 0.037228513465379365, 0.04110114023205824, 0.08034400947508402, 0.04000786393589806, 0.022675622785754967, 0.028706403863907326, 0.014542456083290745, 0.034031563918688335, 0.07004848419455811, 0.03339343566040043, 0.08580888810683973, 0.02659621270140633, 0.13079071854008362, 0.006868275713713956, 0.023807596517144702, 0.05066916040959768, 0.02362214494496584, 0.018281312586623244, 0.054152319207787514, 0.027735722942452412, 0.06843705152277835, 0.026772326200443786, 0.007897564501035959, 0.033798113945522346, 0.045762766458210535, 0.037482966217794456, 0.04234215957694687, 0.042855521678575315, 0.052842844161204994, 0.02345190368941985, 0.028405218072293792, 0.0461917575012194, 0.01204246391353081, 0.04002833979029674, 0.0357905281271087, 0.022541744910995476, 0.029955276986584067, 0.04623837179678958, 0.04686074054916389, 0.08831919520162046, 0.056599799791001715, 0.025581852678442374, 0.01865640515461564, 0.04317335013183765, 0.06703626262606122, 0.08208223065594211, 0.007135228088372969, 0.030280970349849667, 0.02684911622054642, 0.06071645955671556, 0.034829094365704805, 0.07226125686429441, 0.027427371715020854, 0.05807044333778322, 0.04813798041141126, 0.03255047464335803, 0.0159203998191515, 0.028767742369382177, 0.03216076176613569, 0.0287711451164796, 0.03748694412934128, 0.026256143937644083, 0.022572109883185476, 0.0325669688754715, 0.04395522868435364, 0.05895815214898903, 0.02141340770322131, 0.048391642776550725, 0.020080228459846694, 0.023088275447662454, 0.04574570819386281, 0.027498875788296573, 0.03319187577289995, 0.07818332072929479, 0.05123684401041828, 0.034140559437219054, 0.03949418642150704, 0.030928833730285987, 0.08436374846496619, 0.007388073627225822, 0.03753196280740667, 0.03377923370862845, 0.015438148548128083, 0.03891344844305422, 0.006049787016308983, 0.08170482629793696, 0.033330085934721865, 0.03005563390615862, 0.04339708910265472, 0.14033809216925874, 0.079564086481696, 0.03677356580737978, 0.05658331298036501, 0.2535624720621854, 0.12856676912633702, 0.17575193953234702, 0.0896392903814558, 0.1427725443500094, 0.11917508323676884, 0.08376612662686966, 0.1973351970082149, 0.16047957935370505, 0.09807906055357307, 0.09495719408732839, 0.09720084752188995, 0.13262407563161105, 0.147848196211271, 0.2541463344823569, 0.1442839577794075, 0.08470503991702572, 0.22894907015142962, 0.15023549232864752, 0.1936641486827284, 0.1662726208451204, 0.15905734238913283, 0.14244924997910857, 0.26633789122570306, 0.142721202573739, 0.23688654735451564, 0.08562264614738524, 0.21046459092758596, 0.13120832503773272, 0.08298516462673433, 0.08818528207484633, 0.06323144218185917, 0.09370617801323533, 0.1297825257643126, 0.08809071019641124, 0.12409403803758323, 0.15706578909885138, 0.14042170252650976, 0.09232208743924275, 0.10969560127705336, 0.1687370557920076, 0.08279022469650954, 0.21566453768173233, 0.12107959744753316, 0.2033099756226875, 0.12125338616897352, 0.22285648301476613, 0.13880981714464724, 0.1356676677823998, 0.14743538398761302, 0.11663341298117302, 0.10059983935207129, 0.1440782641293481, 0.12446260341675952, 0.1525786900310777, 0.17130093852756545, 0.12940912158228457, 0.08727288572117686, 0.1658835425041616, 0.1268344183336012, 0.04598689505655784, 0.12738296936731786, 0.2822262339759618, 0.19495642074616626, 0.24369104707147926, 0.10513339686440304, 0.17428072082111612, 0.1055784108757507, 0.15202083246549591, 0.14553327433532104, 0.1238844555336982, 0.17821880872361362, 0.14913142891600728, 0.18257496325531974, 0.12362114153802395, 0.21432692039525136, 0.14896925480570644, 0.17338809528155252, 0.09456718806177378, 0.1141677460691426, 0.1417970802867785, 0.16156891855644062, 0.12223502490087412, 0.12247550301253796, 0.1281407318310812, 0.23274705541552976, 0.1171423407504335, 0.14982322929427028, 0.13974110857816413, 0.16994936886476353, 0.10189217820880003, 0.12548929051263258, 0.19957954064011574, 0.1582684987806715, 0.13646684208652005, 0.21160644449992105, 0.16496574331540614, 0.11619381664786488, 0.11574691758141853, 0.10091465839650482, 0.08910324453609064, 0.0952405460702721, 0.06387427565641701, 0.16816002113046125, 0.09408027239260264, 0.07382897703791969, 0.17751710809534416, 0.20203996798954904, 0.12318201275775209, 0.24586496088886634, 0.11167807810124941, 0.13152741885278374, 0.11217977735213935, 0.12238993338542059, 0.1656253493274562, 0.11335692746797577, 0.1706305268453434, 0.0767614548385609, 0.16347686148947105, 0.1186065461661201, 0.14107189810601994, 0.14961180626414716, 0.11785892143961973, 0.13411800406174734, 0.24319311050930992, 0.14279758441261947, 0.14619339985074475, 0.12439699014066719, 0.22837625088868663, 0.1344737154431641, 0.13274651515530422, 0.17416387709090486, 0.21929792943410575, 0.13997207977809012, 0.12338083412032574, 0.08576329055358656, 0.1617088876082562, 0.18447419337462634, 0.14115902624325827, 0.16434011282399297, 0.1057285325077828, 0.12891872524050996, 0.14400833897525445, 0.16126276779687032, 0.1149000231816899, 0.17369329609209672, 0.21337901969673112, 0.15848391456529498, 0.10579603083897382, 0.12052775869960897, 0.14702177024446428, 0.12502136640250683, 0.08192568944650702, 0.06394898024154827, 0.1425399404251948, 0.15678585099522024, 0.17431718995794654, 0.14204077189788222, 0.08491740547469817, 0.12076766535756178, 0.08302911461214535, 0.2058992101228796, 0.11598643832257949, 0.09924939775373787, 0.13858016696758568, 0.11826607107650489, 0.12580209091538563, 0.12769682361977175, 0.10908882875810377, 0.15202982729533687, 0.10645190384821035, 0.1278155524050817, 0.16880687704542652, 0.3128600714262575, 0.1348036594572477, 0.1205724805186037], [0.02355740925850114, 0.05833723800606094, 0.10599723449558951, 0.038296181955956854, 0.019899740000255406, 0.040550088160671294, 0.051969117412227206, 0.009221381551469676, 0.031148249690886587, 0.017536378145450726, 0.09409290374605916, 0.05305264930939302, 0.04845585710427258, 0.0020397910338942893, 0.01978599844733253, 0.10761311263195239, 0.07825343884178437, 0.04371570794319268, 0.0450903398450464, 0.029553806634794455, 0.03846414852887392, 0.03902531607309356, 0.03644095377239864, 0.02355729422561126, 0.06641040949034505, 0.021375899559643585, 0.05130225690663792, 0.023859645189077128, 0.06829726058640517, 0.05595323702436872, 0.017930464127857704, 0.04297806510294322, 0.041943566902773455, 0.00863947932884912, 0.03228103792935144, 0.052977788873249665, 0.013924400136602344, 0.020458228391362354, 0.05034677145886235, 0.04131478599447291, 0.07779170424328186, 0.03247221888159402, 0.01992462235648418, 0.05636081339616794, 0.05872478010132909, 0.03381726135557983, 0.06437979696784168, 0.023024048132356256, 0.003835004285974719, 0.03651273429568391, 0.028912552079418674, 0.05485953028255608, 0.013029597321292385, 0.02987200245115673, 0.037533491631620564, 0.04523611249169335, 0.015953564543451648, 0.014246653645386687, 0.05300262484524865, 0.04336690966738388, 0.004423307300385204, 0.042446973093319684, 0.028089423103665467, 0.05273662056424655, 0.029042355563433375, 0.04952733652316965, 0.06666832807241008, 0.032651514338795096, 0.022827980137662962, 0.05588331558101345, 0.0165528191064368, 0.008307176212838385, 0.03807345601671841, 0.043328770698281005, 0.0438199240306858, 0.03248858694860246, 0.02365523174375994, 0.015394367401313502, 0.04775011177116539, 0.05283510727167595, 0.029858949928893708, 0.05904644545807969, 0.031028956873342395, 0.04057579986692872, 0.08121678998577408, 0.06455050577642396, 0.018543795376899652, 0.0846064010693226, 0.008304568491439568, 0.0678512966260314, 0.06640626088483259, 0.010044383434433257, 0.03469599017989822, 0.019993538189737592, 0.06672490941127762, 0.04539331792329904, 0.040859085056581534, 0.044788556624553166, 0.02129582553607179, 0.08283110219053924, 0.004893969935437781, 0.048234021742246114, 0.08421489590546116, 0.014546196507581044, 0.018047588018816896, 0.08800862866337411, 0.029715442688029725, 0.03886983984557446, 0.03488550501060672, 0.003676312703646545, 0.01985978648008313, 0.027368454466341063, 0.03763837936276104, 0.07791524214553647, 0.022526148677570745, 0.06333750992780551, 0.03610302053857595, 0.04033959652588237, 0.042014991195173934, 0.018471582552592736, 0.07892150533734821, 0.03261031029978767, 0.04229014986776747, 0.02607994323625462, 0.09397124347742647, 0.022114596249593887, 0.1037267450010404, 0.04555420069664251, 0.12931285018566996, 0.06147189167677425, 0.07621664422913454, 0.021393058013927657, 0.05080989758425858, 0.031248176164808683, 0.03348520964209456, 0.04474233937798999, 0.07338984083617106, 0.017733036147546954, 0.015567966875096317, 0.024228073270933237, 0.04438678013684694, 0.013733183932345128, 0.010538038732192945, 0.059236951055936515, 0.037462802065419964, 0.01556250652356539, 0.009329237873316742, 0.046593990409746766, 0.019105708779534325, 0.035372335332795046, 0.035756678771576844, 0.009972383049898781, 0.04779853690706659, 0.021614793186017778, 0.10004604133428074, 0.06156738010759, 0.050801689430954866, 0.03367970057297498, 0.06056473488570191, 0.0239545751537662, 0.057625767003628425, 0.03092985974944895, 0.028811317570216488, 0.006124625188022037, 0.022201030478754546, 0.026110354592674412, 0.0326756155845942, 0.005364227636164287, 0.04849943230510689, 0.0447600655752467, 0.05653870990499854, 0.05415225983597338, 0.0632633693749085, 0.03269429915235378, 0.018329340673517436, 0.04340181658335496, 0.047585470019839704, 0.040528354365960695, 0.042279507470084354, 0.026755063845484983, 0.02392765189142665, 0.0246893328949227, 0.039732682998874225, 0.023062624968588352, 0.04290553129976615, 0.008139705951180076, 0.09229256480466574, 0.041482058659312315, 0.02970156267110724, 0.07136245665606111, 0.042496422393014655, 0.10897355095949024, 0.07613325651618652, 0.024828576497384347, 0.009239894425263628, 0.027838443602377083, 0.03622639887908008, 0.02310127230884973, 0.03635286455391906, 0.009995831205742434, 0.024536676828574855, 0.03156166676490102, 0.03581417666282505, 0.017466408462496474, 0.051795992912957445, 0.08054070829530247, 0.05751239281380549, 0.039284154918277636, 0.025896163351717405, 0.006875068684166763, 0.026913760993920732, 0.08470310291158967, 0.01481535491620889, 0.04838470740651246, 0.027984138323517982, 0.01955795130925253, 0.027178754098713398, 0.03432989244174678, 0.012564136213768506, 0.03798796060436871, 0.026223454187856987, 0.029374770929280203, 0.030613066592195537, 0.05167012095625978, 0.04389083253045101, 0.03173595272528473, 0.0534599696402438, 0.04576337873004377, 0.023526194527221378, 0.039726348768454045, 0.04676453965657856, 0.044906639741384424, 0.023093680138117634, 0.01359744604997104, 0.050933865932165645, 0.035116988292429596, 0.04806669712706935, 0.058513086187304, 0.015798084605194163, 0.007835727828933159, 0.024340931668120902, 0.06397424294846132, 0.04068224239745177, 0.04804519710887689, 0.03341831987199839, 0.024340777672477998, 0.06806360281188972, 0.02620985804242082, 0.055828526528785005, 0.03750239935470745, 0.0736041805066634, 0.03147608971630689, 0.007072575053825858, 0.027153248338436242, 0.023094862008292694, 0.01784074403985869, 0.07167897521867417, 0.04641218278266024, 0.03875671056448482, 0.011489703974802978, 0.04568160518829245, 0.04549361176032107, 0.021050070754426997, 0.04672597395256162, 0.07139869572711177, 0.019715589041879866, 0.01414653699612245, 0.041706476695253514, 0.020011744927614927, 0.018121281427738722, 0.0020435572014321224, 0.058728527947096154, 0.027675397468556184, 0.09411801802343689, 0.024301610828842968, 0.017794795821828302, 0.05208425049204379, 0.03247709850256797, 0.09010464666062035, 0.011269518035987858, 0.06107810440880712, 0.038870314820087515, 0.044924232352059335, 0.05864340731932316, 0.038022797016310506, 0.009317576877947431, 0.016547330924367998, 0.08546066499548033, 0.09169486133032478, 0.02665230793354567, 0.07406981138046831, 0.024422059541393537, 0.042071694988408126, 0.050266664038645104, 0.010733725448517362, 0.004764837167385849, 0.05304609985614661, 0.01513992392574437, 0.036466283272602595, 0.005119305451444234, 0.11925634840736166, 0.031408034774358384, 0.13185458723455667, 0.05959938258456532, 0.02678826011106139, 0.009902807632897748, 0.02673006645636633, 0.03727500901732128, 0.03495798686344642, 0.060968400139245205, 0.0552758046251256, 0.09880702578811906, 0.019196414068574086, 0.06438639466068707, 0.04878168962022755, 0.030575205928471405, 0.05196882426389493, 0.07119265326764435, 0.013319235295057297, 0.061434788003680296, 0.07474560363334604, 0.02950687507109251, 0.028528848743007984, 0.04704848164692521, 0.010674158820620505, 0.0664419136592187, 0.07178445666795596, 0.04654736498196144, 0.12544437573524192, 0.04089185087650549, 0.03576688701286912, 0.03915324006811716, 0.015807762210897636, 0.018064375399262644, 0.04651374569220934, 0.02422241810563719, 0.034027686197077855, 0.05273420116282068, 0.055442483571823686, 0.05746912931499537, 0.034860353625845164, 0.02056201032246463, 0.09584849118255079, 0.057337758044013754, 0.009003704071801621, 0.07300539349671453, 0.020953290986653883, 0.05680721893440932, 0.014018796682648826, 0.033671674245852046, 0.03204257103789132, 0.020458113358472474, 0.19685084174852818, 0.14734625205164775, 0.30455000640358776, 0.08738344346056692, 0.09276563941966742, 0.17438061389839277, 0.11036768279154785, 0.18956684041768312, 0.20670141238952056, 0.0961035821819678, 0.13541432825149968, 0.1835040282458067, 0.08986917804577388, 0.1711379480548203, 0.054317491594702005, 0.1382455919519998, 0.1767135105910711, 0.08300198169308715, 0.099893938167952, 0.14809813670581207, 0.12224535559653305, 0.09190127486363053, 0.18171396804973483, 0.10050030250567943, 0.11767085379688069, 0.1710405040648766, 0.10131236791494302, 0.11722031820681877, 0.1831812088494189, 0.20829651039093733, 0.07603531528729945, 0.1303876136080362, 0.10850596823729575, 0.09098979135160334, 0.17178492271341383, 0.4524075536755845, 0.12616425898158923, 0.10435578195028938, 0.12632702681003138, 0.13900351768825203, 0.1572928120731376, 0.15584786538966, 0.09005124171380885, 0.16161215608008206, 0.1729068421991542, 0.07487517519621179, 0.1117580890422687, 0.1310236638528295, 0.14638494816608727, 0.09066688289749436, 0.10784437326947227, 0.20376231463160366, 0.08313808415550739, 0.12447045533917844, 0.14080239459872246, 0.16344969888450578, 0.08232419306295924, 0.12301476235734299, 0.1964424378820695, 0.15215660096146166, 0.14123138564173132, 0.09925080041284673, 0.1478664530441165, 0.18400684813968837, 0.09557241224683821, 0.1691516491700895, 0.12770976667525247, 0.09059683899977244, 0.08327727395226248, 0.06747958454070613, 0.17373669688822702, 0.11728382378350943, 0.18221666919998825, 0.15662979218177497, 0.2010734542272985, 0.1415975613053888, 0.0978622717957478, 0.15410513937240466, 0.16518486983841285, 0.16780528938397765, 0.15044927538838238, 0.1668965443968773, 0.1375391415785998, 0.09949659230187535, 0.15959655720507726, 0.1486325275618583, 0.1036438174196519, 0.23166562750702724, 0.12259116672794335, 0.14162754407152534, 0.11093388209701516, 0.13145302596967667, 0.08192145178327337, 0.093619495164603, 0.17266160692088306, 0.1445380097720772, 0.15887121175182983, 0.12599061126820743, 0.24400084919761866, 0.16257887764368206, 0.11495341328554787, 0.1702494636992924, 0.2630643965676427, 0.13561390660470352, 0.15104584337677807, 0.08214540226617828, 0.08891553312423639, 0.15662869380321354, 0.15528245276072994, 0.10245580968330614, 0.06203113334777299, 0.18515824573114514, 0.14541592594468966, 0.1666571423993446, 0.17824738140916452, 0.11916205854504369, 0.1508349398500286, 0.1167410689231474, 0.07976850363775156, 0.062101678195176646, 0.17986149323405698, 0.08746522813453339, 0.1241425819171127, 0.09265330052585341, 0.28557429963257164, 0.08146099367877468, 0.2076096972450614, 0.1257080608047545, 0.13214472244726494, 0.1650033998885192, 0.16569233557675034, 0.10688519934774376, 0.18235537660075352, 0.10440977319376543, 0.11439606780186296, 0.31794847338460386, 0.19498644804116338, 0.15646916173864156, 0.1427461684215814, 0.08775952679570764, 0.20297618728363886, 0.14086512092035264, 0.11943755118409172, 0.145437938044779, 0.1307048520538956, 0.17437699221773073, 0.13622058264445513, 0.1713092505815439, 0.0890787759271916, 0.0899723959446419, 0.16448774083983153, 0.15682104363804683, 0.28926505940034986, 0.1105480469414033, 0.225950377935078, 0.1939730008598417, 0.14976553473388776, 0.12721548147965223, 0.21368203859310597, 0.10465514205861837, 0.18108731339452788, 0.16875267057912424, 0.12635467923246324, 0.112435833143536, 0.07704209056100808, 0.12905992625746876, 0.2111610519932583, 0.17608635127544403, 0.12919616972794756, 0.24507163470843807, 0.17877243604743853, 0.1636042882455513, 0.1349113747710362, 0.13147699733963236, 0.1360020795254968, 0.12332309503108263], [0.03418584157770965, 0.06554877603775822, 0.05472900505992584, 0.007742164343653712, 0.026627178813214414, 0.0807664696185384, 0.031230342356138863, 0.01777555935404962, 0.025717454191180877, 0.07536016870290041, 0.07569369729026221, 0.03371900842466857, 0.11805328249465674, 0.04292315359634813, 0.05030358588555828, 0.0066435093322070315, 0.05337444083124865, 0.022979578643571585, 0.03891766013111919, 0.06862466645543464, 0.09271532922866754, 0.03782089945161715, 0.04307791365135927, 0.03826473344815895, 0.02619338050863007, 0.030114348919596523, 0.03421158668061253, 0.05589664084254764, 0.014764272891625296, 0.11232252945774235, 0.03653047533589415, 0.018922058770840522, 0.03121929919871036, 0.004895248748653103, 0.02837091600667918, 0.05941611663729418, 0.08616525257821195, 0.04580848275509197, 0.022593376124859788, 0.03746067210158799, 0.030931731816963293, 0.07390901024336927, 0.029628190241055563, 0.04016049031633884, 0.039881145930849016, 0.014964943129598396, 0.05010123932152055, 0.04489806422498077, 0.030403767959796824, 0.06435023722588085, 0.05924104400037322, 0.026702825925895013, 0.023534705105703324, 0.05224691441981122, 0.02385089155723108, 0.01860184987890534, 0.03799620957579464, 0.017661751007835846, 0.02082709990645526, 0.02214330066635739, 0.02807971581205493, 0.02311522839590907, 0.03476031582977157, 0.008060540130827576, 0.013020545902691083, 0.06329928190098144, 0.06083726264478173, 0.03307838283944875, 0.019064005646214355, 0.013092634417262161, 0.09464676113566384, 0.016124562789627817, 0.050955737024196424, 0.01297621649428038, 0.023267700780706946, 0.02131536999513628, 0.10971178009640425, 0.024135143394232728, 0.027168545857421122, 0.015075876581249759, 0.04201972609735094, 0.054690684264642186, 0.04804349759069737, 0.04796152737981174, 0.06740033059031703, 0.052443513050093316, 0.024230424023699015, 0.07465902468538843, 0.029840195857104845, 0.047617501113563776, 0.026189816344412975, 0.04762239186675288, 0.0346428115881281, 0.025156266237900127, 0.018469929418643005, 0.03268490356276743, 0.003063381054744241, 0.09532561103696935, 0.037807707776664756, 0.08306001764140092, 0.037609383653034456, 0.029011062906647567, 0.06544903881149366, 0.05340768904716242, 0.02829285691404948, 0.03765769004530739, 0.05607896426226944, 0.005939304883213481, 0.04814881947822869, 0.015266265290847514, 0.0384940533695044, 0.06377836791216396, 0.03785199915000703, 0.02848758904292481, 0.03859998752886895, 0.04822653718292713, 0.033249240077566355, 0.031503879436058924, 0.06076381599996239, 0.04399990968522616, 0.053401714758365415, 0.018264033533341717, 0.04975110889063217, 0.020686770913016517, 0.047066389670362696, 0.03637356305262074, 0.03826105239568278, 0.05852365437021945, 0.01132811616116669, 0.06613202989683487, 0.05463357229018584, 0.02273693902679952, 0.06743933045072481, 0.027929692514589988, 0.026191361866949592, 0.0973625540791545, 0.026825595705304295, 0.03689096243761014, 0.005258134378891555, 0.030583673833461944, 0.036269632691983134, 0.03277690018876456, 0.033712113872752525, 0.010596942065603798, 0.04366301916888915, 0.009444615861866623, 0.047875864984234795, 0.010905435228778515, 0.007706377982685808, 0.023527266930614132, 0.04937610538036097, 0.08587545875343494, 0.05201374275202397, 0.04800322494702414, 0.036340441001811996, 0.025153707683784887, 0.019759754250117112, 0.037394164537545294, 0.08459296077489853, 0.029941951725049876, 0.054276773662422784, 0.03407250078453217, 0.022314488160191104, 0.029349305987125263, 0.03656974236946553, 0.027855913758685347, 0.0577889949636301, 0.019043615138798486, 0.0502693654561881, 0.046075778373051435, 0.03403113718377426, 0.009375720437674318, 0.1408961130073294, 0.021320359082892537, 0.04149117223278154, 0.02390890338574536, 0.06586493836948648, 0.07340279873460531, 0.039572252935613506, 0.04389516296214424, 0.0633925772854127, 0.034334445517743006, 0.02265839939354919, 0.04384742431284394, 0.0030058043103053933, 0.049239208819926716, 0.06637780694290996, 0.014554015961039113, 0.06903547488036565, 0.061948910806677304, 0.03533538751071319, 0.05281324731186032, 0.037990803029970266, 0.023864556351327337, 0.020402758418640587, 0.023509627935709432, 0.09189920427161269, 0.03697526299220044, 0.029821078132954426, 0.015487672062590718, 0.031023036390251946, 0.04024521760584321, 0.09885234132525511, 0.02544536615459947, 0.027869461664522532, 0.047208343967213295, 0.050322139577474445, 0.026606979408825282, 0.03905713565472979, 0.09386112360516563, 0.06967067165533081, 0.012460401594580617, 0.08121446706354618, 0.08151641726726666, 0.08299037450342439, 0.05112085746077355, 0.015890365102677606, 0.035385003793635406, 0.007274808904185193, 0.08460623779683374, 0.06524277370772325, 0.03205310582416132, 0.06246117452974431, 0.07037430928903632, 0.022073909858590923, 0.0529955967067508, 0.0365845779015217, 0.08624311871244572, 0.02805149935738882, 0.047452970684389584, 0.0649905251339078, 0.03026774342288263, 0.06767223865608685, 0.10168180160690099, 0.04761043957842048, 0.01522804190244642, 0.019166600141033996, 0.024573684022470843, 0.023856633924879134, 0.022455431280832272, 0.024119992449413985, 0.05649509017530363, 0.029870742655475624, 0.07649120918358676, 0.0542365121509647, 0.07261428167112172, 0.05995480823912658, 0.061717008211417124, 0.062093380984151736, 0.021593851633952, 0.02909529852331616, 0.022682699163851794, 0.0633342370565515, 0.04611834796378389, 0.016117970662890002, 0.04175638241576962, 0.043012671449105255, 0.034818986314348876, 0.09398210109793581, 0.06504523626063019, 0.01914523742016172, 0.015996297406672966, 0.04830342368222773, 0.059158788062632084, 0.024358195878448896, 0.08532836975064129, 0.0701729126740247, 0.007974091058713384, 0.11138324509374797, 0.06362094354699366, 0.05192541975702625, 0.0354309946851572, 0.06457300027250312, 0.05884412857994903, 0.03617575472162571, 0.04363075058790855, 0.08936667727539316, 0.031076279919943772, 0.03767878188227769, 0.022381509661499877, 0.04034697347378824, 0.06228476602700539, 0.029755129035038408, 0.032154672444448806, 0.02109903023665538, 0.0353567205456784, 0.0458050911402097, 0.013950955108157359, 0.05138628286658786, 0.033684261070447974, 0.043701158137992024, 0.027748851534852292, 0.05135355044330936, 0.043044309204560705, 0.1228035768144764, 0.048839540031622164, 0.01717428800475318, 0.025243158743251115, 0.03367126606462989, 0.04916155790851917, 0.024442587346129585, 0.02209301273978781, 0.04953060568368528, 0.0429014272231143, 0.02156827351427637, 0.04730307169666048, 0.04620373947545886, 0.02816917243762873, 0.035022345909965225, 0.04118556324101519, 0.03246956941438839, 0.035695399637916125, 0.03443641289777588, 0.07847027954994701, 0.005928589198447298, 0.02503194351447746, 0.006882761508677504, 0.024974395528261084, 0.023129321780288592, 0.03510271679260768, 0.012756242995237699, 0.05150086675712373, 0.03961312671890482, 0.0177015319786733, 0.022335145840770565, 0.002224454306087864, 0.022658655434497632, 0.05327195394784212, 0.06840749920229428, 0.027110610099043697, 0.08059606509050354, 0.05773540076916106, 0.015020276732684579, 0.01634616251976695, 0.12616581749171019, 0.0018533052093516744, 0.03066477016545832, 0.08887088552000932, 0.04055206598422956, 0.052537027368089184, 0.028846890563727356, 0.0418824733060319, 0.04185903999314178, 0.011146906890644459, 0.007887395222496707, 0.02695569048228208, 0.018696067381824832, 0.0754994252929464, 0.06792858388507739, 0.011776493029174162, 0.03339843402500264, 0.020822606202273164, 0.10934285106486641, 0.1306549648870714, 0.1526427225326188, 0.12315384083194658, 0.20871169748716056, 0.20564826030749828, 0.14557884220266715, 0.16755082178860903, 0.13929709646617994, 0.13045948318904266, 0.14156039454974234, 0.22667330398689955, 0.20459973922697827, 0.21048719674581662, 0.18228487257147208, 0.10255122018861584, 0.10471743051311933, 0.1415026406175457, 0.2020903301308863, 0.13255912286695093, 0.3112993645481765, 0.20490296592470258, 0.09177226733299904, 0.154945814574603, 0.10497532683075406, 0.1342611643485725, 0.15908808214589953, 0.16403795481892303, 0.10507901970413513, 0.16683040419593453, 0.13717320340219885, 0.12714269163552672, 0.1267896222998388, 0.0939911998284515, 0.1168324940954335, 0.22280907462118194, 0.16588208789471537, 0.17915628966875374, 0.19951154506998137, 0.2186444980907254, 0.06465114842285402, 0.10078616294777021, 0.1254179552779533, 0.14486387197393924, 0.1423122940468602, 0.19819193228613585, 0.19232964841648936, 0.13413689914159477, 0.1479280216153711, 0.16901878989301622, 0.13984842313220724, 0.06396731128916144, 0.1555897612706758, 0.16104356705909595, 0.21566241513937712, 0.14789422421017662, 0.1506010297453031, 0.15773477585753426, 0.11507241666549817, 0.07947017511469312, 0.10252488878904842, 0.10521966411033645, 0.07642518772627227, 0.1073932291183155, 0.1717355105211027, 0.07851289366954006, 0.1511293201474473, 0.13816296122968197, 0.2006223174976185, 0.1140929375833366, 0.23404719424434006, 0.15858012659009546, 0.12460698082577437, 0.09440843525226228, 0.11232469652895816, 0.12150391296017915, 0.15806975163286552, 0.1003032029257156, 0.17825374903623015, 0.10507979895919561, 0.1884498933213763, 0.22983507573371753, 0.14977184298913926, 0.136986464203801, 0.15948804037179798, 0.16968335345154628, 0.11114451845060103, 0.22869731881655753, 0.1426155207445845, 0.18198342702817172, 0.1005140099732671, 0.10801213575177826, 0.21793571737362072, 0.13450478174490854, 0.14977831451687962, 0.16809526132419705, 0.16779871395556256, 0.1648859921260737, 0.14165086235152557, 0.19901494437363, 0.18046629906166345, 0.10294330422766507, 0.1562903041485697, 0.15506929310504347, 0.1442101289285347, 0.1297765292110853, 0.1524664624594152, 0.10138058612938039, 0.1569919305620715, 0.08121963241137564, 0.16255463910056278, 0.13390583888394758, 0.12003503201412968, 0.11467734177131206, 0.0976464181439951, 0.1492452298407443, 0.09961555115296505, 0.10428895897348411, 0.18545418453868479, 0.11571792187169194, 0.1274149856180884, 0.15258100553182885, 0.16829558182507753, 0.10897202955675311, 0.17053945048246533, 0.09811119554797187, 0.1699500813265331, 0.21400389319751412, 0.1004331381409429, 0.18198793928604573, 0.13738870824454352, 0.09425616881344467, 0.18202022270997986, 0.09652208667830564, 0.09385706405737437, 0.11778033542213961, 0.10543007039814256, 0.266119729494676, 0.1093904598383233, 0.08364034001715481, 0.09534927812637761, 0.13032377406489104, 0.10369727431680076, 0.08631374148535542, 0.1977984159020707, 0.20782423729542643, 0.14445423614233732, 0.08566589109250344, 0.12171587033662945, 0.0894917588448152, 0.16836304304888472, 0.14477802033070475, 0.17621695442358032, 0.08489779793308116, 0.1650556767708622, 0.14255993388360366, 0.10145247055334039, 0.15924014820484444, 0.2708712557796389, 0.06640550389420241, 0.15222731279209256, 0.20709338510641828, 0.1270436742925085, 0.12845816323533654, 0.07772819124511443, 0.13447191944578663, 0.09505722075118683, 0.08921138287405483, 0.1035806309664622, 0.1659239301807247, 0.15251177799655125, 0.2140032549505122, 0.20583866571541876, 0.16340660979039967, 0.07689618432777934, 0.17307948059169576]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0588093441183446, 0.038142765188240446, 0.04444710190000478, 0.06224026685231365, 0.05775489698862657, 0.034771715218084864, 0.02704408769204747, 0.018382322596153244, 0.07186330985859968, 0.0313951510906918, 0.037410610530059785, 0.019214006679248996, 0.016423627894255333, 0.06576119354576804, 0.04841922840569168, 0.05621653988782782, 0.012929720014653867, 0.026112460436706897, 0.05291530003887601, 0.01801323585823411, 0.03052712960197823, 0.012755214193020947, 0.013867502457287628, 0.014448015008383663, 0.039403054397553205, 0.05887901694222819, 0.03714512575243134, 0.0266364333947422, 0.030365879465534817, 0.03462316693912726, 0.0838364525407087, 0.04244750372890849, 0.05197811595280655, 0.07794330274919048, 0.022728831063432153, 0.04620078943844419, 0.0643715591286309, 0.04407261418236885, 0.025787041668081656, 0.015956054448906798, 0.036013769858982414, 0.05091658131277654, 0.05507550267793704, 0.010471024652360938, 0.057879748492268845, 0.010000509519159095, 0.03931026738428045, 0.04771222884301096, 0.030993035070423502, 0.005452045043057296, 0.03589393898437265, 0.05717398089473136, 0.017547482530062553, 0.03560254583135247, 0.02952357524918625, 0.04813379098777659, 0.03977467742515728, 0.051518270120141096, 0.042401783721288666, 0.07013340073172003, 0.014984162899054354, 0.03589454383472912, 0.0419560832233401, 0.06593782469280995, 0.03780042359721847, 0.05072762680356391, 0.031291350605897605, 0.024612379602331202, 0.006488196377176791, 0.09262290957849473, 0.024353041662834585, 0.07213246455648914, 0.006553634320880519, 0.04249619603797328, 0.0500937918695854, 0.04191226682451088, 0.018841769524442498, 0.043692504696082324, 0.01089639308702317, 0.06113504940003622, 0.04521903938439209, 0.007540039960076683, 0.04798491616384126, 0.04064254120748956, 0.032140233961399645, 0.019046962224820163, 0.029066341776342597, 0.019431231448834296, 0.1046177303942386, 0.04333972479798831, 0.04535714193480089, 0.02356679742661072, 0.029722786239290144, 0.03848936299618799, 0.029177563737903256, 0.023074657037795987, 0.04399924546305556, 0.023464657497243024, 0.008470110096823191, 0.025954640877898782, 0.013576703022408765, 0.051902635823353194, 0.09366483296616934, 0.025529560953145847, 0.010617811258271104, 0.03459364059381187, 0.02139244017598685, 0.10888869379414245, 0.026969590908265673, 0.05492030475579668, 0.0191741459275363, 0.07897171162767336, 0.0473934318870306, 0.015339154397224775, 0.10825770499650389, 0.056125886549125426, 0.025512701213301625, 0.031560523857478984, 0.047400114926858805, 0.015931732414173894, 0.0031863802041698364, 0.02430645705317147, 0.02276801831612829, 0.015336181168095209, 0.029979244645801373, 0.03087975550442934, 0.02314360812306404, 0.06806034478358924, 0.03419088447117247, 0.04398197939735837, 0.024896028444345575, 0.05483207081852015, 0.0543289132474456, 0.04798997761099599, 0.11595238858717494, 0.029396280224318616, 0.028974224551348016, 0.04262107722752262, 0.019129726533719804, 0.038004113448550925, 0.011691407653415808, 0.01884056538983714, 0.04772851156303659, 0.041520008380757645, 0.06130245194071904, 0.03032190536032431, 0.043628917483147234, 0.05490720956004225, 0.0565785558137577, 0.013258259514259407, 0.0509193124162266, 0.034631642265594564, 0.09231767908204347, 0.011717773377313279, 0.04853504797210917, 0.020738064449687954, 0.02971012519992655, 0.03587256884202361, 0.02642091927555157, 0.0134817934667808, 0.013001192546653328, 0.04974476352799684, 0.08037273801164702, 0.030874319272697903, 0.03097994915151503, 0.07596775016281754, 0.13330987945664674, 0.024462244982714765, 0.06022984816809185, 0.030141218376229517, 0.030482777001452632, 0.017846143164206296, 0.02813570714351954, 0.048823242468643, 0.03594004861952271, 0.07606537968968041, 0.06199648618348874, 0.032795810111565515, 0.009903152731567388, 0.03958732966566458, 0.05371630373701919, 0.03190365954651497, 0.07787682858179323, 0.014438307716773124, 0.03182361149811186, 0.016609229751338717, 0.056744544563116506, 0.0479742403695127, 0.01723601613775827, 0.03993625410657842, 0.03193366828782018, 0.01269441931071924, 0.10999096120940521, 0.03883364159264602, 0.02167795923014637, 0.0720482382166665, 0.06515381988720037, 0.027618409803835675, 0.047176910302368924, 0.03216101409634575, 0.007936547663121019, 0.006422772812584299, 0.035875452085747384, 0.05431712794234045, 0.003008671551469888, 0.010724622079578694, 0.020739938372571487, 0.022923518663446885, 0.03848100270261057, 0.04050654635648243, 0.031128530827118084, 0.03996973980974872, 0.053293980890884995, 0.012787604300683597, 0.06818062465754338, 0.03363672651175875, 0.03342205658555031, 0.07095117325661704, 0.03357100191351492, 0.05387893797887955, 0.05400390080467332, 0.08196871174732223, 0.013065456969343359, 0.052703094042954035, 0.02013879504374927, 0.018017109869106207, 0.016328792553395033, 0.00934025134483818, 0.013229004052845994, 0.032415355526609346, 0.07903736943262629, 0.04342410698882304, 0.001330579407294863, 0.014826950973656494, 0.04817055698367767, 0.026206971087958664, 0.04367983252450358, 0.018217380275018513, 0.028120459719502833, 0.045877936645410955, 0.06058907361875754, 0.05606320846709423, 0.0308044275152497, 0.027792718028649688, 0.028765219067281578, 0.04906020651105791, 0.04162776080192998, 0.056582266552140936, 0.08199227493605576, 0.06956607336178422, 0.03051333493203856, 0.09414374828338623, 0.02094512921757996, 0.0035348804613022367, 0.03468690258159768, 0.04901315434835851, 0.023751493863528594, 0.02093755374517059, 0.041302154641016386, 0.021491323932423256, 0.018330394523218274, 0.03577988572942559, 0.03337311565701384, 0.024758493636909407, 0.041480073414277285, 0.049829806230263785, 0.017741737829055637, 0.042460387412575074, 0.04203714430332184, 0.053046196335344575, 0.011783142672356917, 0.03916181929525919, 0.014001760682731401, 0.042339435894973576, 0.043001884332625195, 0.004074535463587381, 0.016687685892975423, 0.031080794033186976, 0.03572540095774457, 0.029574484724435024, 0.027254421620455105, 0.03600334639486391, 0.07262756611453369, 0.07048412488074973, 0.025905607180902734, 0.03892125212587416, 0.10617785839713179, 0.11432819839683361, 0.03555474781023804, 0.040492356492904946, 0.028627381834667176, 0.01149670613813214, 0.03261827725509647, 0.032458559653605334, 0.05837735479872208, 0.07136286483728327, 0.07790359042701311, 0.04131451511057094, 0.04115931718843058, 0.02130679633410182, 0.01866409194917651, 0.026597789765219204, 0.12039003835525364, 0.005315393391356338, 0.03742786175280344, 0.06190306092321407, 0.029229779393062927, 0.021133324880793225, 0.07818081227014773, 0.011754604311136063, 0.06349932780722156, 0.04636679674149491, 0.03124724476947449, 0.04713356516731437, 0.054021782852942124, 0.02205878303357167, 0.026176422434218694, 0.026287944965588395, 0.020074194799235556, 0.03339901290019043, 0.05051795524195768, 0.04581627530569676, 0.03709438140504062, 0.04637686397472862, 0.002595421460682701, 0.021630641749652568, 0.012155311178503325, 0.02861323835531948, 0.023571908968733624, 0.06898621111758985, 0.006894101061334368, 0.014147050933388527, 0.04012585057353135, 0.04098509431059938, 0.025414780393475667, 0.03896898706443608, 0.016484565639984794, 0.08042615037993528, 0.026797483151312917, 0.08581217582104728, 0.02293162662681425, 0.04363902182376478, 0.12411285890266299, 0.025671684088592883, 0.03213451571355108, 0.05678077992342878, 0.03101087630057009, 0.03328756458358839, 0.022222085208341014, 0.039507392939412966, 0.02772298212221358, 0.014856534835416824, 0.16099345724796876, 0.15604315412929282, 0.16941174224484712, 0.12528778257546946, 0.17824954848038033, 0.17945096682524309, 0.14533182576997206, 0.2075639957911335, 0.19296237383969128, 0.045692384883295745, 0.11516104394104332, 0.1398005842929706, 0.0779488094849512, 0.22202273947186768, 0.1449170839623548, 0.09771041353815235, 0.24627300852444023, 0.16488777328049764, 0.1403496103012003, 0.12208136322442442, 0.17837114195572212, 0.15603576233843341, 0.13963174569653347, 0.14345103059895337, 0.12082317058229819, 0.13185804564272985, 0.12105774119845591, 0.1347668340895325, 0.15656439412850887, 0.1317642381764017, 0.14526627928717062, 0.11678509312332608, 0.19193059561075643, 0.1555576708051376, 0.10914169193711132, 0.14659390726592392, 0.13587054127128795, 0.08161415069480427, 0.1235041419568006, 0.09601723329978995, 0.10713531053625047, 0.1920269857509993, 0.13117746653733775, 0.15084014972671866, 0.13470262347254902, 0.1614652553689666, 0.11500980908749625, 0.11770600933232345, 0.2344164127134718, 0.07310519009479322, 0.11443321229307912, 0.08003165436093695, 0.07732646670774557, 0.10325493203708902, 0.15277722937753424, 0.11910878718481399, 0.09995125423301943, 0.10833753040060401, 0.12234628025908023, 0.12043816663208418, 0.18090486380970106, 0.10280519054504111, 0.09647054452216253, 0.13995738525409251, 0.10113624142832123, 0.1699046025169082, 0.08877247673808597, 0.10893213911913335, 0.09044587131938897, 0.18721221364103258, 0.1077713310951367, 0.16161882056621835, 0.12472720874939114, 0.14255812304327264, 0.14263015589676797, 0.10636602994054556, 0.10919431762886234, 0.1418609792017378, 0.09875340561848134, 0.13618078868603334, 0.14671735611045733, 0.09699355825432576, 0.14288631558883935, 0.138191593287047, 0.09999145637266338, 0.12968974246177822, 0.1241127253160812, 0.10281014809152111, 0.2588112372905016, 0.12696500663878396, 0.20856399525655434, 0.1375061011640355, 0.14945712784538046, 0.0943345099221915, 0.11186355564859696, 0.19451836065854877, 0.12879998161224648, 0.10100322630023584, 0.0870014303654898, 0.07469544187188148, 0.11088469997048378, 0.20728598727146164, 0.21626687957905233, 0.13374649977777153, 0.10824065786437131, 0.11179720022482798, 0.22159503976581618, 0.12720115802949294, 0.09687762736575678, 0.10784065510961227, 0.10923374051344581, 0.22703631810145453, 0.06375906465109438, 0.10092323020217009, 0.19242716662120074, 0.14506460807751864, 0.11024970357539132, 0.16539489763090387, 0.1633573608705774, 0.1144922649837099, 0.20223890809575096, 0.19132086192257702, 0.10225718870060518, 0.1722036424325779, 0.10156388918403536, 0.14238636038498953, 0.1967400242574513, 0.12000803268165328, 0.07915726338978857, 0.1305372454226017, 0.1548971890588291, 0.13068778265733272, 0.2792771765962243, 0.11476221377961338, 0.2060822831117548, 0.11239293700782582, 0.09670615414506756, 0.16961933579295874, 0.1458069190266542, 0.07140464033000171, 0.1735251402715221, 0.1008411635120865, 0.12233394576469436, 0.19974762224592268, 0.16694099904270843, 0.1275643947883509, 0.13728888938203454, 0.12485096929594874, 0.12016582069918513, 0.10753971422673203, 0.15220399451209232, 0.1262246401165612, 0.2621333277784288, 0.1508413816918619, 0.1886070950422436, 0.060802003208664246, 0.0913003133609891, 0.10680200459319167, 0.14040108566405252, 0.08750314445933327, 0.06653224045294337, 0.13091097614960745, 0.1614370389143005, 0.10864702824619599, 0.15058718126965687, 0.1477906946092844, 0.2825780416605994, 0.13144333352101967, 0.1233104859420564, 0.08502282013068907, 0.15449059603270143, 0.16191605071071535, 0.12741281854687259, 0.11751624959288165, 0.08490587249980308, 0.1248501826194115], [0.026831067189050373, 0.06463655779953115, 0.009639163381507387, 0.06300968845607713, 0.03286477418441791, 0.03971388810896315, 0.03333771150209941, 0.059824049239978194, 0.08842101786285639, 0.0282590131246252, 0.03155510617943946, 0.049308521702187136, 0.019170210689480882, 0.0545601256453665, 0.0774741466739215, 0.014956273917050567, 0.041428672266192734, 0.10672313655959442, 0.040366202520090155, 0.034200554655399173, 0.016806242128950544, 0.049811779463198036, 0.06752287401468493, 0.03306711332697887, 0.014616284006478963, 0.03845307568553835, 0.03579568976419978, 0.030466160314972512, 0.05961408081930131, 0.019865103968186304, 0.013464284347719513, 0.04064247812493704, 0.03318234288599342, 0.04681608181272168, 0.04241719070705585, 0.035329736056155525, 0.06412958930013701, 0.049284112465102226, 0.024098564790620003, 0.044125599815743044, 0.025665192151791416, 0.008103122709144372, 0.02982611917104805, 0.05252075206954032, 0.018037431727861986, 0.05931884705205448, 0.018635986816661898, 0.057055652869166806, 0.03687287629873026, 0.018115362800017465, 0.05813165567815304, 0.055324478380498476, 0.004394473935462884, 0.04520576236245688, 0.0515787996846484, 0.10082850989419967, 0.015750809798191767, 0.02186475965572754, 0.03921158400771674, 0.030236374695959967, 0.06015679857227951, 0.04208919854136184, 0.0558714189537568, 0.049393178487662226, 0.031227106592268683, 0.010437243945489172, 0.10468755164765753, 0.028108496298955288, 0.09330228640465066, 0.07321946599404328, 0.023003572277957574, 0.020979297696612775, 0.05356860892788973, 0.02217850629676832, 0.07180315878940746, 0.03904233351931907, 0.08647365946671925, 0.03138900239719078, 0.00654835347631888, 0.029947219118184876, 0.02561702120146947, 0.08662667547469027, 0.03215672077203635, 0.02397245534666581, 0.05736142513342202, 0.010391307787358528, 0.03084280211623991, 0.06061842184863053, 0.02604215122119058, 0.027217273418500554, 0.023421167643391527, 0.027743068349082023, 0.046516217043972574, 0.035895067048841156, 0.05904029305384029, 0.08481110766297206, 0.052480256781564094, 0.02540565939852968, 0.033826412036432885, 0.015303490490623517, 0.04456871763977688, 0.07994221814442426, 0.04587342438753694, 0.014866297788103111, 0.031442370236618444, 0.08628211115137674, 0.03583893470931798, 0.026045028898806777, 0.05495648074429482, 0.10693061136407778, 0.016407081711804494, 0.019447861122898757, 0.04702347127022222, 0.061210091662360355, 0.035022702140850015, 0.02481925141182728, 0.026796841193572618, 0.05959582769719418, 0.05527379340492189, 0.017835994294728152, 0.0013841963300365023, 0.023011836092337035, 0.11520781408762559, 0.0318233369034715, 0.04585287802910898, 0.06706918429699726, 0.053102874153410085, 0.00830652219519834, 0.033328145218547434, 0.01604109344043536, 0.020120449153182562, 0.013048312430328224, 0.06684758642222732, 0.030711254585185088, 0.022114638923085295, 0.034785797470249236, 0.07409201643895358, 0.030044828235986643, 0.03849887361866422, 0.03419165630475618, 0.020274730522942264, 0.015367195519502275, 0.027882371323357802, 0.034051716938847676, 0.04798378809937276, 0.029964785753691103, 0.04780687493621372, 0.037185123801464215, 0.05178582920052577, 0.028155930667708162, 0.023752863125992008, 0.010866495667869458, 0.05266436135570984, 0.03819188423221931, 0.04480420480831526, 0.021212278261373285, 0.11374967943993397, 0.041737613501027226, 0.00739603037800407, 0.027886000425496604, 0.017544949951115996, 0.051396717462921515, 0.011838682221423369, 0.0173437258854392, 0.04640596729586832, 0.03144423673802521, 0.014058317901799455, 0.055025040346663445, 0.02218472549429862, 0.024217134014179464, 0.03184253997460473, 0.0751768953341525, 0.035407910181675106, 0.024189537252823357, 0.03070009082875913, 0.05340542920748703, 0.02092663118673954, 0.04180953503237106, 0.04108734741748776, 0.013202753361838404, 0.052700477972393855, 0.07881842844653875, 0.03235458476410713, 0.007102247045622789, 0.09075425594346598, 0.041972944818553515, 0.050786011561285704, 0.12018062654533423, 0.03269279630330857, 0.03220076723664533, 0.0612153720430797, 0.027107587702630553, 0.017219453256984707, 0.09651372267398983, 0.027795478818006814, 0.05264457198791206, 0.018163986460422166, 0.05362334974051919, 0.031323114526458085, 0.012052289021085016, 0.0502278014755575, 0.08970278111519292, 0.007382758458334138, 0.029236443879199214, 0.03492556243145373, 0.0076507670019054785, 0.02657428223756142, 0.05571171248448081, 0.020095618747291155, 0.0417076084704604, 0.0641896587330848, 0.046982671701698564, 0.01931843984493753, 0.06605643473449163, 0.02780780032480834, 0.02267963038320886, 0.029317670087039005, 0.03616857444285415, 0.07393690757453442, 0.020890006198897026, 0.05522237370314542, 0.06226135868928395, 0.05165730035514571, 0.01607271820830647, 0.06725182684022002, 0.04615593403286766, 0.06951649047550745, 0.06531690683914348, 0.01879401974292705, 0.07481055639800616, 0.05249092515441589, 0.012170455629529897, 0.052656869374914095, 0.0212857750011608, 0.009986145250877598, 0.08065373738645576, 0.047653487854404375, 0.03683439594169613, 0.006660322223979165, 0.03282216748630162, 0.05179902458621655, 0.1655504369409755, 0.07024820355582051, 0.040913102275226265, 0.037559897245955653, 0.0202368327518343, 0.06037538332748227, 0.054295698428177275, 0.02215900080045685, 0.041038625422515906, 0.010117329129570862, 0.04981810627214145, 0.0654637036495842, 0.028712333623843733, 0.028295051815803163, 0.04603193228831515, 0.028504007204901427, 0.0521051196847111, 0.033434205543017015, 0.014324757266876986, 0.06560425899806432, 0.034081907506333664, 0.0347982432867866, 0.043050895765190944, 0.044694155440083705, 0.02224558531452203, 0.053459323971765116, 0.05115100349939894, 0.09446010357351042, 0.03928861522581428, 0.014565239089279203, 0.05834735718963202, 0.07250479262438603, 0.04866133182076737, 0.03742320477613248, 0.04534402447461616, 0.04938611695251893, 0.044779546951758675, 0.028988581398152746, 0.025077964091906324, 0.06262573835556395, 0.03244842933781911, 0.051594971082522534, 0.030216876621125266, 0.045988345955265686, 0.03491588853648864, 0.036252169957151636, 0.06229527483810671, 0.03689102923090104, 0.018493273673811927, 0.047161006077658385, 0.0389581591298338, 0.029696974343096372, 0.06840119836851954, 0.08305419920361601, 0.03033268134458922, 0.06415882249712013, 0.052798181714024395, 0.04034891418996267, 0.011168279816047288, 0.048695748919271864, 0.07818100522854365, 0.02352814823098015, 0.056725931499386206, 0.02623176438646624, 0.0691761786583811, 0.05182951943424996, 0.008983961088233627, 0.10336476989323273, 0.04314827296184376, 0.04337162972660735, 0.01562986013595946, 0.043654154214891605, 0.07100371731212363, 0.025259352405555546, 0.009011032780108508, 0.03989110184193123, 0.0055128723943198565, 0.028272369927435648, 0.012188282944407547, 0.04558659544272814, 0.06567658871063031, 0.08986804255982861, 0.08012908350792713, 0.008555195472581545, 0.027713670024240855, 0.028348655287118163, 0.026702692339313217, 0.03142714507703204, 0.0497937935142545, 0.05421426256361883, 0.01157973854787997, 0.06529366277391091, 0.021985616549500264, 0.025878722881316207, 0.015285254994523712, 0.04259253793861717, 0.04701391240814701, 0.007646486665180419, 0.02181831790949218, 0.005729227923438884, 0.023987251915968955, 0.05702257163648028, 0.048225724531221204, 0.0125755133376515, 0.05111309088533744, 0.03971846716012806, 0.0936043776164297, 0.07414427105686627, 0.0573706797149498, 0.03797758537984919, 0.024208894319599494, 0.09221342217642814, 0.22903887002030388, 0.1507420526468195, 0.13853356009349227, 0.06216055648110341, 0.11575829470530152, 0.1558788723195903, 0.1140472361294087, 0.14003676536958665, 0.1107164921995718, 0.18260317970998585, 0.18103114765835926, 0.12243454388226382, 0.17971496359677985, 0.11579327212530188, 0.10548670368734747, 0.12419052465702407, 0.1849248551297933, 0.14098846586421132, 0.10514967958442867, 0.0809870804368984, 0.15106083475984633, 0.1344311606953852, 0.1532594027230516, 0.09773340527317487, 0.18067177006741986, 0.057773090738919564, 0.138950543187093, 0.2722370746778324, 0.09177430081763305, 0.07743069392745383, 0.12718877900624648, 0.15145488549023867, 0.11566332948859781, 0.15085288498084992, 0.1218839742068667, 0.1314868382178247, 0.09877000004053116, 0.13171985774533823, 0.14586871024221182, 0.14308564161183313, 0.09133762112469412, 0.17627754335990176, 0.24448680749628693, 0.1071799655619543, 0.15334550669649616, 0.09874551658867858, 0.09195093196467496, 0.1674140291288495, 0.14129819377558306, 0.15375134273199365, 0.157563399116043, 0.12123923341277987, 0.2747131168143824, 0.20816605567233637, 0.14778210053918883, 0.11549058719538152, 0.08352797143743373, 0.1094123680377379, 0.11623438986134715, 0.1671412750147283, 0.17767773853847757, 0.1229311000497546, 0.13756378088146448, 0.1274445082526654, 0.17388937150826678, 0.2430834952974692, 0.1483929474488832, 0.27797164977528155, 0.14260336436564103, 0.17846566188381985, 0.13255435827886686, 0.13888333429349586, 0.12159828445874155, 0.08652514225104824, 0.15183746261755005, 0.22626862570177764, 0.08063742498052306, 0.0824274480692111, 0.14514925744151697, 0.08613439407781698, 0.13680273812497035, 0.15252958954079077, 0.08235347078880295, 0.14649162447312847, 0.18827618623618037, 0.10110054412507452, 0.11394599976483732, 0.09305485436925665, 0.07050817046547309, 0.10386862137238495, 0.15635690448107198, 0.1579821336781606, 0.1374667524942197, 0.1719696432701312, 0.18123701942386106, 0.13606887281639501, 0.135430239897687, 0.162744925764855, 0.15444887249032035, 0.11128697369713336, 0.24267838656669483, 0.15267626760760322, 0.08701061073224992, 0.15344545914558694, 0.14330916164908558, 0.1145592586544808, 0.11620413250057027, 0.15002381696831435, 0.257588712265715, 0.11122104871901684, 0.13721232942771167, 0.12070811542798765, 0.13234078302048147, 0.11817631573649123, 0.09646748687373474, 0.12515667476691306, 0.10165213796426542, 0.2000756812049076, 0.12017149812891148, 0.18176841200329363, 0.11366977239958942, 0.18841624434571713, 0.07801890533301048, 0.1087037283286918, 0.335910139256157, 0.13139392132870853, 0.1666236121673137, 0.2047570448485203, 0.1356827630661428, 0.11174117549671791, 0.13230035081505775, 0.18802182254148647, 0.11648365500150248, 0.09456936997594312, 0.10939467523712665, 0.13982382835820317, 0.08090436065685935, 0.10632157529471442, 0.1316740969195962, 0.0867743554408662, 0.09879241290036589, 0.12087976676411927, 0.14372834149980918, 0.1844583114143461, 0.13058526237728074, 0.11907965788850561, 0.11282924562692642, 0.11859444915899076, 0.13991733896546066, 0.12348480158834718, 0.12418342230375856, 0.10737041549873538, 0.08522671036189422, 0.13844012370100245, 0.0680543333874084, 0.16650920268148184, 0.163538133201655, 0.12405007320921868, 0.13477514614351094, 0.12634822254767641, 0.12857885129051283, 0.07105646916897967, 0.12762542901327834, 0.20489272428676486, 0.18577247683424503, 0.1327011699322611, 0.13431575673166662, 0.14049061835976318, 0.1327453722478822, 0.17011360614560544, 0.25287263095378876, 0.15034902608022094, 0.13812990597216412, 0.09026172963785939, 0.11805777990957722], [0.041634788940427825, 0.04217761059408076, 0.02260943434521323, 0.05648556842061225, 0.05712708087230567, 0.012662977296713507, 0.02171176405681763, 0.04753621367854066, 0.04121507845411543, 0.04569206947053317, 0.04044868481287267, 0.05269611043331679, 0.047444732845178805, 0.02502977087715408, 0.04270464676665142, 0.06696624841424637, 0.008837449076963821, 0.09049511281773448, 0.04718374548247084, 0.018436061509419233, 0.03997667517978698, 0.0046461575493594864, 0.012094310350221349, 0.01126905048295157, 0.02561928104114486, 0.04579038548399694, 0.0350097145565087, 0.05448599622468464, 0.034706498990999535, 0.0808284166851081, 0.03380200651008636, 0.0422425596480025, 0.041676226755953394, 0.05358263551897835, 0.034693956695264205, 0.006966966975596733, 0.05592839363089297, 0.07995493113412522, 0.04706863466708455, 0.016066560237959493, 0.016089893360913265, 0.06033120698702987, 0.039674706422374584, 0.061909502765047364, 0.057098007237073034, 0.03327324113342911, 0.02487547095370246, 0.032520792447030544, 0.03554350056219846, 0.014863296728435671, 0.02961975202197209, 0.034532984864199534, 0.0408833495748695, 0.0242966903897468, 0.009957862930605188, 0.03793917552684434, 0.06297892643488012, 0.030595804237236734, 0.03805946653301362, 0.0516315849381499, 0.06812164618168026, 0.004055316157973721, 0.010297218304913258, 0.059236045635771006, 0.024622214914415963, 0.08082581174676307, 0.0356078299228102, 0.022367624078469817, 0.06294913662713952, 0.04807079007150605, 0.03884962745360099, 0.05952675601292867, 0.007641763822903158, 0.0556471567688277, 0.011734606214304222, 0.022080372109485324, 0.034345574022154324, 0.07329582556849346, 0.01729146755678812, 0.05385079202824272, 0.02682108159206109, 0.05544142230064608, 0.01776970937498845, 0.012369795567792607, 0.05666096018103417, 0.08417464923695661, 0.06611585107748397, 0.022229491842153948, 0.026410621976538096, 0.06611792166950181, 0.02929675451014191, 0.0904532334243413, 0.015556938560621347, 0.03150363823806401, 0.022501019557239488, 0.042651816984289326, 0.05472224780532997, 0.08779428157140501, 0.04169219777395483, 0.038472334417747334, 0.06581491761608049, 0.017351125097775366, 0.03170408490404952, 0.008533991385775153, 0.0034811362138498225, 0.08178687072359025, 0.012012062761641573, 0.049981812917394564, 0.01769061498634983, 0.01547265284898458, 0.03409916615055408, 0.010945569647446973, 0.07755740080028772, 0.036261394852772355, 0.019416676077526063, 0.03683871153043583, 0.051104155427310616, 0.048266138182953, 0.03939596688724123, 0.02377278793574078, 0.0301058995682979, 0.05076563589682337, 0.07580554636660963, 0.06791831998270936, 0.0310581473968341, 0.053695505048381165, 0.07290443172678351, 0.016046782002376858, 0.042554239407763816, 0.042252986822859384, 0.05441777058877051, 0.0464093811751809, 0.03885893769620452, 0.05695545180060435, 0.0392761063267244, 0.03024330821062904, 0.02465170600771671, 0.030587011642637663, 0.0444470091315452, 0.039077704277588055, 0.01600290066562593, 0.043136791937286034, 0.006343284621834755, 0.04876679100561887, 0.01163139202617458, 0.014473473456746433, 0.030421681549341884, 0.07547708664787933, 0.06024059446644969, 0.006588230926354299, 0.06160485114378389, 0.024171011391445063, 0.017839614120020997, 0.05074490400147624, 0.07700332076638006, 0.0033244804353671498, 0.015504397288168548, 0.039129903234425, 0.09465638679102995, 0.020721078544738702, 0.09664340555900708, 0.07172702928073704, 0.03794408854446374, 0.05752409648266621, 0.018143328779842705, 0.010910652526945341, 0.015048336408653995, 0.015509022723563248, 0.04011712291685399, 0.04887806120677851, 0.05085333548777271, 0.04060170082084369, 0.06361904364894144, 0.06645602188655175, 0.011578575231396826, 0.06508402831968851, 0.05704517003323417, 0.03761181789741386, 0.015383914251287933, 0.03658732013718691, 0.03648702630016487, 0.08227466212701984, 0.01613460961380042, 0.06003939823131077, 0.025275740881625097, 0.04557088788715191, 0.019298995575809386, 0.02035456149314996, 0.03619119510403834, 0.03719883126905188, 0.04847613257879857, 0.06463620156864636, 0.03686675729113631, 0.03362600247783121, 0.044461024590418674, 0.043825534667121246, 0.030674586923851166, 0.013262637257867027, 0.03873485060466919, 0.019639491074485704, 0.0802344610565342, 0.09175302344374359, 0.06830268568592146, 0.0131096231052652, 0.01826725074351998, 0.03175756777636707, 0.01680613451753743, 0.02745801870332798, 0.0252192819971242, 0.044084106339141726, 0.0320730510429712, 0.019457876405795105, 0.05641788084176369, 0.08996415068395436, 0.006655122087977361, 0.022025186008249875, 0.11358900446793996, 0.05912964392337017, 0.0046049660340941045, 0.03861033677821979, 0.01728734863718273, 0.04751282118377276, 0.014353582282637944, 0.03228628862416372, 0.0768070894991979, 0.06541548631503247, 0.03675113810459152, 0.014878954189043725, 0.04369621543446556, 0.08669835209730081, 0.017077526790671982, 0.05043653422035277, 0.06772568071028218, 0.03405182455026079, 0.010375663314334815, 0.038242624868871644, 0.02786385844956385, 0.04033407494716812, 0.03423587346333079, 0.050957562707480974, 0.018355473548581358, 0.06472706270869821, 0.031159816062427126, 0.024411066478933208, 0.022744380912627093, 0.06431509653339162, 0.10593795173917897, 0.09565373678924516, 0.052369160985108465, 0.056534561299486086, 0.010708042500482406, 0.03985123737948015, 0.047233510194928385, 0.09965314093278721, 0.06409956200513989, 0.024819028767524287, 0.03532663016812876, 0.021590150172414724, 0.059668324392987415, 0.029788609172101133, 0.09772631034138612, 0.04186219041002914, 0.07891259214375168, 0.08009402445168234, 0.030394520799745806, 0.06462520294007845, 0.018639849695318844, 0.0544638728024438, 0.0546448677778244, 0.04137308169447351, 0.05635525842080824, 0.018043522904918063, 0.05718221131246537, 0.1211040215275716, 0.06695911637507379, 0.02620679297251627, 0.07999702575034462, 0.019103747654298786, 0.022419943634304218, 0.030744981486350298, 0.02066269935312448, 0.05277023243252188, 0.027833706844830886, 0.02232538659882266, 0.022217149926291313, 0.05291727415169589, 0.043373755979700945, 0.03646276920335367, 0.11700102098984644, 0.04705128325440455, 0.030224413130781613, 0.030757393906242214, 0.006618052275371156, 0.04674688767408952, 0.04227088371408172, 0.06288718213909306, 0.05569098429987207, 0.04807569937838707, 0.05430878620245494, 0.008044592304941034, 0.04861017187067773, 0.03820581805484835, 0.027118460166093428, 0.02718208263104316, 0.04445714315806981, 0.04293705402233172, 0.033774840194382705, 0.08124766332912259, 0.02453091034112731, 0.029686662201129366, 0.029143109532014932, 0.03471252151939552, 0.023185452264442574, 0.030108187238511164, 0.04067738504090812, 0.03409486169402953, 0.05092081155453343, 0.024768759394646622, 0.04722838566522114, 0.03301339667814318, 0.07839128535124473, 0.036667579697677866, 0.02854348575056065, 0.08319497719639912, 0.03353130443429109, 0.00906075389139005, 0.11370327294571325, 0.05211045943724457, 0.023266884418262634, 0.06154573165986221, 0.026654037137632258, 0.006312923824225436, 0.01321221574471565, 0.10855965520022437, 0.0416486485482892, 0.04546330244920682, 0.09902296107611619, 0.015951221212162636, 0.036547793351928703, 0.06770419553504325, 0.06624379733693786, 0.021893647754041012, 0.019137092349410523, 0.025558398956491146, 0.06361888779792935, 0.025906134105753154, 0.10418902136734687, 0.0431505884625949, 0.06442883066483773, 0.08998916106065735, 0.03817107812210452, 0.02165017507650191, 0.15406632504891604, 0.062383382610278204, 0.08949104638304561, 0.13327959983143955, 0.10195556504186243, 0.11065353581216186, 0.11354514354025014, 0.19086288259131834, 0.10141882157768123, 0.14156370452838019, 0.13975442270748317, 0.21991943358443677, 0.12014548585284501, 0.20381180103868246, 0.18365581228863448, 0.21943133790045977, 0.15530538512393832, 0.1983908427064307, 0.10420448772492819, 0.1427467176108621, 0.10423035899293609, 0.10454070288687944, 0.174758619396016, 0.14785273815505207, 0.1862085924949497, 0.14896398555720225, 0.17422258097212762, 0.11061571596655995, 0.13552521995734423, 0.19177521957317367, 0.14748650311958045, 0.15061179088661447, 0.17495662439614534, 0.1511885880609043, 0.11888055450981483, 0.1699400771758519, 0.1904306112555787, 0.17447501508286223, 0.15922221791697666, 0.1367812603712082, 0.11886125867022201, 0.1402655546553433, 0.09266661465517245, 0.14339450863189995, 0.11553687494597398, 0.14228853047825396, 0.11112370862974785, 0.13159866502974182, 0.09395939880050719, 0.13909785950090736, 0.12525732483481988, 0.08788023711531423, 0.102526840637438, 0.11718551148078404, 0.12595849111676216, 0.11673850851366296, 0.16471504583023489, 0.11625461338553578, 0.13820067717460915, 0.1264377700863406, 0.1339016976999119, 0.09562410283251666, 0.10491835215361789, 0.13875942531740293, 0.12704431253951043, 0.19648852525278926, 0.16244088270468637, 0.09948845094186254, 0.22603942081332207, 0.21043033339083195, 0.19779486843617633, 0.17745785502484068, 0.12237302726134658, 0.16021959017962217, 0.12276367895537987, 0.10580519636278041, 0.1373835577396676, 0.14519674004986882, 0.23430709436070174, 0.14863134012557566, 0.11590360722038895, 0.13409484905423597, 0.15263838839018717, 0.1001371696474962, 0.23104376712581143, 0.11283214742434211, 0.15725018311059102, 0.12621420552022755, 0.13433024345431477, 0.2414426364703104, 0.09288329209084623, 0.22202064661541954, 0.16468185698613524, 0.17808050208259374, 0.10277615030645393, 0.09282846964197233, 0.1740177333704196, 0.29950634110718966, 0.10381959509686567, 0.14199900382664055, 0.16497209609951824, 0.10054506143205799, 0.14541874610586092, 0.10773989371955395, 0.07947872465592809, 0.11989542661467567, 0.11897048054379411, 0.12447103421436623, 0.09413807827513665, 0.1367155951447785, 0.21630432835081592, 0.1222616754239425, 0.2079066156875342, 0.11430140686570667, 0.1850157236913219, 0.14744103915290907, 0.13470728415995836, 0.17470298800617456, 0.09942435906850733, 0.22535585827426985, 0.12788467603968456, 0.11075829737819731, 0.20144629437709227, 0.15115937712835148, 0.12334587896475568, 0.116217869654065, 0.11648227460682392, 0.10798564107972197, 0.1275174316833727, 0.1524350102408789, 0.21336172765586525, 0.15553795936284587, 0.22331559041049331, 0.12576942157465965, 0.08989550202386454, 0.0866762657824438, 0.10067255498142913, 0.16762088052928448, 0.2134036144707352, 0.1524240561411716, 0.14899049507221207, 0.11035432413336821, 0.10454594244947657, 0.06718406133586541, 0.10052181736682542, 0.11531460171681829, 0.1046575911459513, 0.1833759038709104, 0.08275734013295732, 0.1652943663066253, 0.2959651092533022, 0.15251349977916107, 0.08469021922792308, 0.1755956283886917, 0.26518097205553204, 0.12286377983400598, 0.09829918155446649, 0.17197497189044952, 0.25106321554630995, 0.09888918153592385, 0.19624749053036794, 0.15507100004469976, 0.09526176407234743, 0.14836927293799818, 0.12506693426985294, 0.12604876596014947, 0.1596904982579872, 0.129241440736223, 0.1288779071182944, 0.11171905949595384, 0.24021341727348045, 0.16206747852265835, 0.11401478943298571, 0.21505137527128682, 0.15996105561498553, 0.2424249134492129], [0.0732171356503386, 0.10462109232321382, 0.03376043510797899, 0.023177605908131227, 0.04963330407917965, 0.010339336113247555, 0.013956236416561296, 0.014167186327540549, 0.053491099024540745, 0.0226108351489529, 0.04247293712978717, 0.05936448542342987, 0.018799686040438246, 0.027957769816566724, 0.06771944666979834, 0.036558502542902716, 0.018204149637313094, 0.04733931818918791, 0.07560941900010221, 0.012445828597265063, 0.06379983082297258, 0.0117462746311503, 0.01924974665598711, 0.04375975069706328, 0.010549562430242077, 0.034026869834633544, 0.022418273802031763, 0.06153439164336305, 0.015208953864203067, 0.05457498715259135, 0.049849328424897976, 0.03986175361205824, 0.026139756628253963, 0.04690623049100395, 0.05061858675617259, 0.0489088046742836, 0.015171300074143801, 0.029787616549583618, 0.00875476454893942, 0.05488934606546536, 0.024940612966020126, 0.039699208427919075, 0.010905448216362856, 0.0406044430565089, 0.03468332542979624, 0.04223454445309471, 0.017121597375080455, 0.02228878758614883, 0.014358410880959127, 0.02175586618250236, 0.04355658034910448, 0.05574458962655626, 0.040855366896721534, 0.017818817286752164, 0.03516231867251918, 0.03344101845868863, 0.02505138221749803, 0.06574165279744193, 0.0699883553897962, 0.02356086581130512, 0.038111112589831464, 0.027666148453135975, 0.014033376173756551, 0.021514044783543795, 0.04624022345524281, 0.03621416457463056, 0.06100882121245377, 0.05096109161968343, 0.04478084571019281, 0.0649184180656448, 0.0507998006651178, 0.026538338170212228, 0.043958649985142983, 0.07783907552948222, 0.010777799743664218, 0.04433882626472041, 0.06137410629889928, 0.05725134236854501, 0.03192118907463737, 0.020434036232472863, 0.016154291370185092, 0.04217172536300495, 0.01580657291924581, 0.011393942804716062, 0.06127797219960485, 0.06096886769228149, 0.0718660261190962, 0.04862898160354234, 0.04583168600220233, 0.009446146541449707, 0.023673054420214612, 0.04834125837078318, 0.026237558704451658, 0.018106034003722016, 0.05293160502333194, 0.03637793801317457, 0.06505036450107582, 0.03720714332303032, 0.06160878452647012, 0.05957683613814879, 0.042441499754204415, 0.08910610180464573, 0.017432874519727193, 0.05542861654248554, 0.02736449325311696, 0.029802121825923678, 0.025354894642077852, 0.09227498332620598, 0.07270054891705513, 0.035955633720732294, 0.08164811137248762, 0.04821730857656803, 0.053779909503646195, 0.039365516568068415, 0.04342105676187202, 0.06254670704947785, 0.049826926697278395, 0.03514754251227714, 0.01129586335082422, 0.02913071381044574, 0.027997085089737084, 0.012269861672393745, 0.014053141421754844, 0.05627855374768842, 0.022001192373863887, 0.01689070966676809, 0.04751138141728006, 0.04038131264678668, 0.014778305048821494, 0.0684819440357387, 0.07956660236231983, 0.03599098221457098, 0.052099468230153434, 0.0376543244055938, 0.03326724829094019, 0.02079191468510544, 0.06369067574269138, 0.047846887828200124, 0.05948800106125418, 0.05902425153180957, 0.06530553713673726, 0.04584935282764491, 0.030651511697215028, 0.02978151609568158, 0.013533078654290875, 0.0371559796622023, 0.05446839990327135, 0.025396028177055996, 0.042141419762629084, 0.07755913000437431, 0.09129784200922586, 0.06863122704089619, 0.025237837544409558, 0.061756831855745986, 0.05582906087511219, 0.041448008923907764, 0.03359463931701612, 0.016721091815270483, 0.017281227774219587, 0.030247000395320356, 0.03268891116022132, 0.016716616664780304, 0.06826265424024314, 0.04249118654115591, 0.0748672045301646, 0.07451734127243981, 0.07355424138950184, 0.037450270901899785, 0.08253970532678068, 0.055313784032478, 0.08341797773027793, 0.023196616020868532, 0.03275555973232258, 0.07069551822496578, 0.02591755946923513, 0.039490831914008595, 0.05418592736532446, 0.022819157857156824, 0.03916950423445087, 0.013307719018484931, 0.06198612951266114, 0.021863902475161012, 0.05627093189104926, 0.0029647718929481925, 0.021702984449802898, 0.05001839337637648, 0.015069694491103292, 0.03969175726524554, 0.019673448041430674, 0.026034386501123663, 0.031116513600863982, 0.031112852957448922, 0.07271634181961417, 0.015745542405056767, 0.047858305770205334, 0.018916884146165103, 0.03745343616174068, 0.07261500155436806, 0.021351675859477837, 0.08287314485642128, 0.04890825548500288, 0.07829390073311515, 0.07398279456538148, 0.03187347640050575, 0.01602848991751671, 0.015155191758822184, 0.04640715844288934, 0.050823478886741214, 0.07248836147482507, 0.03822676888376009, 0.016657779196975753, 0.0036009466793984757, 0.03827137566986494, 0.03636620465840679, 0.06524357522721402, 0.045954203451401554, 0.0224122011786676, 0.026129867510462645, 0.009636254162614932, 0.050706542388070375, 0.06595723927603103, 0.02364674899581587, 0.03049805040063802, 0.053221510170260444, 0.0156368010721053, 0.05028309518820606, 0.009772656267159618, 0.07956334433401935, 0.060263341292738914, 0.04102423888980411, 0.03827071144769434, 0.03166265079926234, 0.027961122468695976, 0.04677971657656599, 0.02008361079788301, 0.07239447979372926, 0.04504504286160227, 0.034912604533019476, 0.01169509891042253, 0.011418597878218861, 0.0237215927336365, 0.055168623657664284, 0.0372507259453414, 0.05399736619438045, 0.031649358934373595, 0.06270989048061892, 0.01634928325074725, 0.07964889169670641, 0.06235521810594946, 0.01762157669872977, 0.04643105188733898, 0.023574905389978085, 0.0330125951586524, 0.029894409744883887, 0.03968462893681135, 0.01957353455509292, 0.04254861763911322, 0.011275958950136555, 0.03252993199566845, 0.06943345157196745, 0.05068180660600774, 0.04155898597673513, 0.06060485538910143, 0.01765423861797899, 0.0396722239383962, 0.0430778394365916, 0.03658336449007038, 0.04364896289189346, 0.04607847979059443, 0.06550569436512887, 0.03988563963503111, 0.06785803532693535, 0.03850283668725751, 0.10547128185862675, 0.05298190408211667, 0.008604337708675303, 0.05829162932059262, 0.01126110300901928, 0.045706982928095385, 0.05645222372550052, 0.016230380060733296, 0.028979306407563854, 0.051439624730846845, 0.11152448321809061, 0.038453758461400867, 0.028908811655128375, 0.02569918808148941, 0.07109112004400231, 0.0636046237195842, 0.013757890028500697, 0.004113849809073145, 0.033969193827942945, 0.030639206888736226, 0.024069880782917608, 0.03003686313604703, 0.04816745480638929, 0.03309094739961438, 0.07735201143077575, 0.0277619077678537, 0.018269772190251388, 0.03515784723276738, 0.07121999398805201, 0.03086600907408865, 0.035896773988497443, 0.01768017296853941, 0.060273141352809034, 0.0318951990630012, 0.01259344269783469, 0.03972876816987991, 0.049913602124433964, 0.031337527034338564, 0.0393989614531165, 0.03887887178279925, 0.031951594864949584, 0.024286302177642938, 0.054005719066481106, 0.031553213702864014, 0.07814575321390294, 0.02066780347377062, 0.026743909365904983, 0.029809086881869007, 0.0096448927615711, 0.047049127315403894, 0.03918348258594051, 0.07083006217726506, 0.04504437492869329, 0.05274143710266799, 0.03177897131536156, 0.06711134570650756, 0.04259601861122064, 0.03205103894288186, 0.13128635444445536, 0.02977468648168724, 0.015739581103844102, 0.008504513280058745, 0.033293902524746954, 0.011242582713748561, 0.02598587416287046, 0.01374580971969408, 0.05859836637682747, 0.01835447907069465, 0.05754378194978926, 0.05172000441234559, 0.08306698640808463, 0.04945997548929881, 0.050726120243780315, 0.018993685298482887, 0.03799551195697859, 0.03844176906568464, 0.04019189058453776, 0.023516617111454252, 0.004845463163292152, 0.16957041341811419, 0.1964353132643737, 0.18809335073456168, 0.14088539639487863, 0.254489800427109, 0.08658487771754153, 0.08446540785371326, 0.07883834769017994, 0.1524005745886825, 0.12344033209956251, 0.12903027003630996, 0.19103566941339523, 0.09951731306500733, 0.08686628527357243, 0.1668185298331082, 0.1258199173025787, 0.20187023881589994, 0.14129620481980965, 0.139616887900047, 0.11867563269333914, 0.17722704709740356, 0.18826352519681677, 0.0935970971477218, 0.1748253681580536, 0.1668340852484107, 0.09737168249557726, 0.10765582323074341, 0.17274858662858605, 0.07202201071777381, 0.11435968772275373, 0.15848326147533953, 0.11698788497596979, 0.1409592549316585, 0.12762191123329103, 0.15820992848603055, 0.12870431877672672, 0.12724475178401917, 0.12719588878098875, 0.13918667973484844, 0.101603274961235, 0.1332136377459392, 0.12658115301746875, 0.08439053999609314, 0.16554757225094363, 0.12915033468743786, 0.12173915893072262, 0.12831549276597798, 0.18438706523738801, 0.12991056108148769, 0.19212232204154134, 0.14798294054344296, 0.16793678310932592, 0.0797015248099342, 0.10390477880719118, 0.1409838200197555, 0.09865658503258601, 0.08953148600994609, 0.1508535974426195, 0.1828408896108158, 0.12623405054910108, 0.11724128387868404, 0.12918561638798565, 0.13624534069094807, 0.07708515739068389, 0.16818372532725334, 0.1534396703937091, 0.11179696273757145, 0.2597135107498616, 0.11892034104675986, 0.09670789077063091, 0.13349664834095165, 0.14170961076160893, 0.18295178131666034, 0.2745410572970286, 0.23548077122541144, 0.1323519300785847, 0.15092910354724154, 0.13413358916295692, 0.11106630350695923, 0.24289170949487016, 0.21840760455233976, 0.13670608081156388, 0.17407119768904522, 0.25563226256053895, 0.16870915103936568, 0.16250711196335033, 0.07654041357454844, 0.11420943250413984, 0.13167587807402015, 0.1602615215233527, 0.0804539438104257, 0.24660837021656334, 0.1317883431329392, 0.23836276814108714, 0.1569900306640193, 0.11650630534859374, 0.17865658679511398, 0.21125206898432225, 0.12307413417147473, 0.14551727363141254, 0.09662770171416923, 0.19711672357516363, 0.14701385895023122, 0.19647345965495333, 0.15061918267747387, 0.11689181395922787, 0.16709131363313645, 0.22307737584924325, 0.12421226958394982, 0.09781233267858624, 0.16727849812014028, 0.1399576524272561, 0.11144392308779061, 0.1395229616900906, 0.0971298165677581, 0.12914488732349128, 0.13412906206212938, 0.1760562349227257, 0.09846879198448732, 0.1666937896516174, 0.11992042214842513, 0.11077637609560043, 0.11649108389974572, 0.09607835658243857, 0.20901198528008536, 0.13326993706868961, 0.12852675252361223, 0.12729832000331953, 0.1039486842637416, 0.19965500221587718, 0.13485117175150663, 0.17890286108013242, 0.16515876108314842, 0.12298023022594862, 0.10411674360511824, 0.16437981772469357, 0.1235920048202388, 0.11070233202190138, 0.09473969286773354, 0.1510853404761292, 0.17637176642892882, 0.2631403924897313, 0.1524228390189819, 0.1012490107677877, 0.10741040241555311, 0.12243246586876921, 0.0778593732684385, 0.1148619138984941, 0.14395126781892031, 0.1628554315539077, 0.19273137295385823, 0.14263698365539312, 0.1803135799127631, 0.146377615747042, 0.13430371909635141, 0.2268764001200907, 0.1299930879031308, 0.09647689730627462, 0.08471119232126512, 0.09659949268097989, 0.15207787393592298, 0.1964893564581871, 0.14121189684374258, 0.12423598862369545, 0.09799383231438696, 0.17591398005606607, 0.1934292441001162, 0.16874082590220496, 0.13786108524072915, 0.10940746986307204, 0.16282684402540326, 0.12366187060251832, 0.14998423081124201, 0.18782099738018587, 0.09544140833895653, 0.1465126420953311], [0.03722631299751811, 0.06679324636934325, 0.051098555923090316, 0.04400997320772149, 0.034632410388439894, 0.07757003215374425, 0.07498260849388316, 0.019163180695613846, 0.016633486848149914, 0.004851882740695146, 0.02305257072293898, 0.03848932959954254, 0.008763834521232639, 0.06641498112003319, 0.024938008027675096, 0.023870187396823894, 0.03246645981562324, 0.05157451749255415, 0.04750950749439653, 0.04370240494608879, 0.02383550312515581, 0.096454417653149, 0.01813643793866504, 0.014024439788045129, 0.09855615018750541, 0.01805165684345411, 0.04615823840140365, 0.043396925830165856, 0.05974043146125041, 0.0403137178363977, 0.12672373442910612, 0.11605832274653949, 0.04463277611648664, 0.019797004497377202, 0.02460291907482315, 0.01950943154952256, 0.048357581908931024, 0.08276320309960283, 0.01551725777972024, 0.05876477443962358, 0.061116057840990834, 0.03630770486779511, 0.030440517257375177, 0.0828734936658293, 0.028449372148315888, 0.030749966863368172, 0.01798658719053492, 0.00790216767200036, 0.08910986449336633, 0.0018128586248167267, 0.027354340672900435, 0.029465624647855293, 0.03529783854901325, 0.03414967672142666, 0.037735867881565355, 0.04302317654946819, 0.012662114550039405, 0.054725472436985, 0.07945685356389731, 0.018335938366362825, 0.057837368149193935, 0.032300504462909885, 0.02491951556294225, 0.05902471166336909, 0.04907934649963863, 0.03417584484850522, 0.06117328484833706, 0.06373687443556264, 0.02930630224000197, 0.05176061102247331, 0.06552858219947666, 0.018441182328388095, 0.09801213367609307, 0.02566042199759977, 0.010553455922490684, 0.021674626987078227, 0.013121787833370036, 0.023375826131086797, 0.02888726710807532, 0.030692467116750777, 0.013475215255311923, 0.015477625238418113, 0.038381747872335836, 0.0645901141979266, 0.06780044466722757, 0.029857055596949067, 0.09639894211431965, 0.018331684004806448, 0.014590538903576089, 0.017873003343993332, 0.02663386370841181, 0.02140948359738104, 0.03462493325059768, 0.02758946047833888, 0.011884366049343953, 0.045981343791936524, 0.0492236311401939, 0.07440855726599693, 0.09605970641132444, 0.045831459647160955, 0.030038395670999307, 0.050659182234085165, 0.016025595541577786, 0.019962329024565406, 0.01975593033421319, 0.061389847251120955, 0.06127896667749155, 0.10592137216008268, 0.007789081064402126, 0.09730500052683055, 0.03445107773586642, 0.04252775957866106, 0.026448308235558216, 0.05249346329947002, 0.07842080056434497, 0.018286440827068873, 0.10302530412445776, 0.05303396574163344, 0.05093040752399247, 0.014376238195836777, 0.04014438200101722, 0.016200028076127637, 0.03155630845867563, 0.08989289708551951, 0.030535018631780986, 0.05151196557562798, 0.037287959494278766, 0.0713431830808986, 0.036179836533847265, 0.034109244516002946, 0.04432538968103472, 0.0925852678483352, 0.035822273493977264, 0.04772474887431599, 0.058493092728895135, 0.009160869612969691, 0.012121295767428819, 0.02657973331224639, 0.08667559042805806, 0.011107870850537438, 0.024567405453126412, 0.05734817037591711, 0.0485760516312439, 0.08948192538809963, 0.0111553302667744, 0.08451885732938536, 0.02967887521663215, 0.0155905893916497, 0.042235631699441, 0.05243150138994679, 0.04382087769045029, 0.04000715147412848, 0.06649161528912373, 0.03622586824349128, 0.07014402828644961, 0.09489901713095605, 0.041060622679651715, 0.0060462200690381, 0.07852948067011312, 0.08140445686876774, 0.01169955643490539, 0.011341079625708517, 0.023709367706032936, 0.047296269913204014, 0.057635040138848126, 0.05565309023950249, 0.04203743003017735, 0.1007503097935114, 0.018527226930018514, 0.011602177382883383, 0.03231249385862611, 0.09637580937123857, 0.022982530535955448, 0.03955737287469674, 0.009838919850153616, 0.040487454607500695, 0.022725404196535237, 0.07502957902033813, 0.013910749257775024, 0.01647968230827246, 0.0363178871339187, 0.04564370741718449, 0.05436622101115063, 0.07545853295596316, 0.0034156256788264727, 0.036000619002152234, 0.03591154272726271, 0.021105240157339722, 0.004672154054787825, 0.02103295126289595, 0.05464678251883015, 0.03858493306324817, 0.07254141761222854, 0.03533658978994936, 0.021909717106609605, 0.040907354341470636, 0.009535131903248839, 0.06557602770044468, 0.08287288510473445, 0.09295579249737784, 0.04458155308384448, 0.07565251551568508, 0.06654879034613259, 0.004653115183828049, 0.019608652983151842, 0.019096495016128756, 0.10617463747621514, 0.05250392387097236, 0.05456605169456452, 0.02029958319326397, 0.015476229073101422, 0.047296948978328146, 0.04679907549871132, 0.011876395383296767, 0.07455843398929574, 0.03325393787235953, 0.04272849197150208, 0.014964452384447213, 0.06652098207268864, 0.04321144457207993, 0.05180261658097152, 0.008555039621569449, 0.00925961143366294, 0.006818531410317519, 0.0717286323197186, 0.0308617046175641, 0.022757272017770447, 0.0113284018880222, 0.04601177184667904, 0.01412118708685739, 0.04628021408279892, 0.08971820294391364, 0.03661579263280146, 0.010819088201969862, 0.04433073314430658, 0.041422638605581596, 0.04100633828784339, 0.021449505766213406, 0.03145814458548557, 0.008975583168648882, 0.049670270454953425, 0.03735749873158056, 0.04109355548280291, 0.04524834679614287, 0.04609432093275245, 0.03440697561018169, 0.010144239404326072, 0.012507835963333491, 0.007535067106800852, 0.06389290356310084, 0.03254198076319881, 0.06300218534306623, 0.054644641422783025, 0.02369631332840072, 0.02467178852384677, 0.034789100027410313, 0.0636676320573315, 0.1033707738679368, 0.05546804684854578, 0.035158953032805584, 0.030581347200495657, 0.0199008699200931, 0.015223951741063502, 0.0243094163670321, 0.02342810301342979, 0.037126312308828346, 0.04781596624525264, 0.027335224804119207, 0.05441307650471572, 0.01938577861437807, 0.04495663823036011, 0.027802970798802562, 0.03443493231316097, 0.03950128135329578, 0.10879585111979395, 0.021284435424604453, 0.02457417383993743, 0.03326933001517318, 0.003878131415149255, 0.07297271673451178, 0.023301080727833323, 0.03968685166910291, 0.004693309901995235, 0.032458893620059825, 0.03362236595421564, 0.08780717267654836, 0.02517427445127396, 0.008806281657598447, 0.05312769899319392, 0.018861115459003486, 0.07772035416564904, 0.06580921792192385, 0.05109225880005397, 0.06308533556875773, 0.02401000245299656, 0.01693166694167303, 0.01318188602454029, 0.041760300955502316, 0.01133982632381958, 0.01748266335198423, 0.041554228810127825, 0.11418815513025038, 0.03362513045431115, 0.04313324447139166, 0.0384630019107135, 0.04182336495432537, 0.01787729295756435, 0.12739770842017606, 0.07916031361673959, 0.05542040467844345, 0.12242410928593017, 0.03974837571149692, 0.059710682471632026, 0.025121780490735546, 0.05072946732980199, 0.007695523145230254, 0.029577570203400683, 0.09428643359569833, 0.016320213326252997, 0.06389377929735929, 0.05197223072173074, 0.010413318032078678, 0.009951154843292898, 0.043166596587980166, 0.020558340402203612, 0.032937556607066654, 0.04902485430648085, 0.029645061113114934, 0.023944381755427457, 0.01767702997312881, 0.05222141793638002, 0.029664995199709665, 0.039966214608284645, 0.023926629583002068, 0.12640115251997486, 0.05294062582834158, 0.05063638716819696, 0.0660118910309393, 0.03258174874645192, 0.050829423489631154, 0.03801038830715697, 0.05837788543431088, 0.01758975526172435, 0.024568227381678298, 0.03452416814980097, 0.03667091565148439, 0.008423255530942697, 0.036904714434058405, 0.009191396002279362, 0.02072346083878074, 0.03714950071298517, 0.06396210141247138, 0.08114716911222786, 0.22225195920327678, 0.07702010072534904, 0.1761411811457947, 0.0832108294707723, 0.1664844891638495, 0.1607673248508945, 0.1453796646092087, 0.09697386907646433, 0.09108601821935736, 0.13039764744462445, 0.18627971992827952, 0.10305033676559106, 0.15857390739256516, 0.10871794045669958, 0.08661758416565135, 0.20215522352373227, 0.13738005480263382, 0.17029700567945838, 0.1468645833665505, 0.08535458240658045, 0.18456978199537843, 0.22242866456508636, 0.14068060816498473, 0.18527862208429724, 0.10757518888567574, 0.14908495562849566, 0.12163237130152993, 0.11515470599988475, 0.1671525853453204, 0.24544978863559663, 0.2604429825441912, 0.14394616184290498, 0.055537226144224405, 0.07576906238682568, 0.0806683131668251, 0.18214248411823064, 0.11236454985919409, 0.16605067416094244, 0.17957573669264093, 0.1888460517511703, 0.08590394238126464, 0.23197281727334484, 0.2030215028207749, 0.08631975288153626, 0.12378556435578503, 0.10233622000669129, 0.048103785957209766, 0.14038720750249922, 0.09651595653849654, 0.13475715648382902, 0.10629674303345382, 0.1514600805239752, 0.08988019893877208, 0.14964677626267076, 0.12277465531951748, 0.0860180846939329, 0.21856936305994168, 0.1220152601308655, 0.15388013503979892, 0.1001813200127799, 0.13706400379305705, 0.10895279308897443, 0.16405091271735728, 0.18102369649568573, 0.09736553009133786, 0.1363870908971876, 0.13517905259504914, 0.1115038811985869, 0.16171071329154074, 0.12557512731291354, 0.10235909299808554, 0.17915440461365506, 0.09914914102409966, 0.20524183055385947, 0.1260124155669473, 0.18292632565135136, 0.09287728069466539, 0.10082635024446063, 0.14523009216645733, 0.13024325104197487, 0.2178935188567266, 0.10012760336394422, 0.1746386883314699, 0.12912287522340193, 0.09166743155219592, 0.1848751015495509, 0.10002722789067775, 0.1276561093982309, 0.1373265459551476, 0.14009601844009012, 0.1380665265605785, 0.1939709673752077, 0.10089048664667644, 0.10690284761949442, 0.10971477837301791, 0.1618688352755271, 0.15249209624016657, 0.1949025408248417, 0.11446974822320044, 0.07702566683292389, 0.16051297599915415, 0.13259870902402326, 0.12999120284803212, 0.10506748672924004, 0.1157096766110044, 0.1608136051800102, 0.15953602764056996, 0.09794857614906505, 0.19003115769010037, 0.22386590775568038, 0.1515054702758789, 0.12075689679477364, 0.20592340413713828, 0.2115462117944844, 0.16119698382681236, 0.16819043434225023, 0.12531697866506875, 0.09559042417095043, 0.10729328409070149, 0.1324608625145629, 0.09820258361287415, 0.10657825449015945, 0.19728673476492986, 0.10875853593461215, 0.25777712871786207, 0.1374144756118767, 0.1481982078985311, 0.1617927206098102, 0.1277974885306321, 0.12364474183414131, 0.265180051792413, 0.1974997014622204, 0.08532384264981374, 0.1318392693065107, 0.15072398877236992, 0.08304242131998762, 0.13089263025904074, 0.15713951404904947, 0.0661220628535375, 0.06669269278063439, 0.18037657340755686, 0.11564487969735637, 0.1895828262786381, 0.11463157352409326, 0.15820494125364348, 0.09663881166488864, 0.06694946103380062, 0.1343972742324695, 0.15605547378072515, 0.14971625612815842, 0.17859239102108404, 0.1704936451278627, 0.0971311004832387, 0.23170055297669023, 0.1682722190162167, 0.13117136608343571, 0.11377861577784643, 0.18620014685438946, 0.23914172634249553, 0.1809474779292941, 0.13422689196886495, 0.11337009316775948, 0.12967046146513894, 0.1920620448072441, 0.16980546643026173, 0.09512975084362552, 0.19989266758784652, 0.12405098605086096, 0.06997000207775272, 0.10478034979314543, 0.25248517049476504, 0.07272596747498028, 0.11554411088582128, 0.09348380830488168, 0.12011692058877088], [0.03894878951541614, 0.03833308524917811, 0.04480493582377676, 0.05663394229486585, 0.01219251596921822, 0.1354790138429962, 0.027212957829760853, 0.04312269484216813, 0.06940466366359033, 0.02390580306382617, 0.01865735510364175, 0.024417627064394765, 0.03743444089195691, 0.033103923851740547, 0.05947667217697017, 0.10260637660394423, 0.0691244583867956, 0.025295658269897103, 0.02137977171514649, 0.019108404630969744, 0.07000691650318913, 0.04077626879734453, 0.07156077335821465, 0.052174818483763374, 0.07027783009107225, 0.028477699925133493, 0.03884786485286895, 0.04947891880874522, 0.05425913281214889, 0.05339468290912919, 0.04787048812431749, 0.020799211852136068, 0.12795816350262612, 0.04043912595079746, 0.010099848768732045, 0.05796254248707555, 0.03968252865888644, 0.05025515332818031, 0.040230018421425484, 0.06050266165402718, 0.03113489474344533, 0.07182004264905117, 0.005359659253372229, 0.006322945137071656, 0.05051195126725361, 0.011708115252986318, 0.034058852688758634, 0.02289926342200488, 0.05247663510090206, 0.05369489277654793, 0.0308015721020638, 0.0017258568846045819, 0.00845135788040352, 0.01729271622025408, 0.04615922174707521, 0.03702368070662487, 0.06969261696212925, 0.029410165807348676, 0.05788219757960178, 0.022608512226724997, 0.1266343501629308, 0.008627849874756066, 0.03470758623734582, 0.021146822691662237, 0.006796009083700483, 0.06314277037745342, 0.02507123281247914, 0.048334304447053, 0.03415887935261708, 0.0588984686328331, 0.02003351582970936, 0.030868849644321017, 0.02236842003185302, 0.022099120615166612, 0.06264765397645533, 0.04064380656927824, 0.051328128174645826, 0.0785969864227809, 0.04726281389594078, 0.026226931149722077, 0.016586312231083866, 0.028431729442672804, 0.019957343647547532, 0.08505761201377027, 0.025458431664446834, 0.030355276030604728, 0.09384388351463713, 0.02219828082161257, 0.026253141950292047, 0.07572214381070808, 0.05241209422820248, 0.03189361828844994, 0.07407511031487957, 0.02417315248749219, 0.011377443006495014, 0.06560549838468432, 0.04796192813955713, 0.11139947586343624, 0.019109515997115523, 0.013733142186538316, 0.010590975198283559, 0.027186023435206152, 0.01697008978226222, 0.03537018310453277, 0.021589265161310323, 0.019626225184765644, 0.04033909928693902, 0.03418632397369947, 0.01635233904380584, 0.0361271106521599, 0.024367730620724615, 0.08600137894973159, 0.04837356034840923, 0.0488060023781145, 0.06739517266396433, 0.011017149790859548, 0.05357590052881278, 0.030761151028855238, 0.026681943745643366, 0.033970340446103364, 0.04208356564049609, 0.0827696300984826, 0.006036545246388414, 0.016691533928678837, 0.04416040283103939, 0.07909840365755372, 0.04026622780656908, 0.0418630846979795, 0.02527612308767857, 0.027258930167590734, 0.04299364649341442, 0.07969661921379156, 0.023110563997761346, 0.06645291970926337, 0.029068625735817477, 0.04482687741983682, 0.036084426028537564, 0.007022199924904271, 0.03609281971876044, 0.06086723427870311, 0.026517081205383874, 0.023323872082983144, 0.024250462010968477, 0.06678904581349343, 0.015106274022400612, 0.07914599758805707, 0.016219874960370362, 0.06043403525836766, 0.011837691454275046, 0.051798185959341936, 0.018752919604594354, 0.06665453896857798, 0.0758143408165779, 0.041986474170698784, 0.02534206105337944, 0.02056390279904008, 0.05439017011667602, 0.07828843852621503, 0.04427116466104053, 0.036979708456783555, 0.05086276818474289, 0.036150744344922714, 0.03987301570305135, 0.02478227390383836, 0.004151397843088489, 0.02005621627176879, 0.043170403805561364, 0.047662048527854495, 0.020265665189072024, 0.0027363636536392733, 0.06059938204998616, 0.007094684560797759, 0.034411951710353605, 0.012375313435768476, 0.024262015394924674, 0.04900571431790013, 0.011533793112903368, 0.038759734816267155, 0.06804419565014541, 0.06373131574946456, 0.020830916400882415, 0.0409979705727892, 0.04559376830002293, 0.006033972313161939, 0.04923046632029582, 0.032672420638846233, 0.026131396334676538, 0.04127279527892824, 0.06416855205316097, 0.02178703638492152, 0.09512244068901055, 0.06264506388106383, 0.040223272299044766, 0.022849836386740208, 0.035724948247661814, 0.0166916304078768, 0.025032346129592042, 0.05907276943617035, 0.047288503337767906, 0.07138031272916123, 0.06523936724988744, 0.045200741733424366, 0.034176835615653545, 0.025281869166065007, 0.060071147308917716, 0.04737989140267018, 0.029310441568668466, 0.035988970994367264, 0.02372394534177147, 0.0027062684057455044, 0.059815625863848254, 0.02254336835903814, 0.01685108640231192, 0.030294716780190356, 0.010517728005652316, 0.08315546525409445, 0.06520505034131929, 0.01762039482855471, 0.02990639171912335, 0.03987060372310225, 0.05882558230950963, 0.013585835149569903, 0.05489511626365129, 0.0177812516267295, 0.011426146447774954, 0.030946376245992724, 0.012135118267906364, 0.051479492904036306, 0.03547183507180307, 0.002910163739215932, 0.036301526488387026, 0.03941329603549093, 0.009552501869620755, 0.048018450106610544, 0.04110247980861459, 0.045974219174240716, 0.056711081124376506, 0.03683497110614553, 0.06718651042319834, 0.047342735779238865, 0.024138685294019524, 0.04401958402013406, 0.0591831082419958, 0.02804991672746837, 0.03314761408546474, 0.06675722994259559, 0.012534663674159674, 0.013900327649025712, 0.07003017541137524, 0.04638915394025389, 0.037295210277079605, 0.037697380103054456, 0.01506100579717895, 0.016215928590099793, 0.019591199525166303, 0.08715409014257602, 0.051811496377922595, 0.03394242827198468, 0.03774084027099889, 0.024291528752655722, 0.010943307952402392, 0.02283819023432443, 0.08364180946955457, 0.022530406749865506, 0.023192383923742454, 0.04238475514284801, 0.013439672875392716, 0.03990637153037824, 0.07569852867163718, 0.041585810904507525, 0.050248637271579355, 0.06542444403748959, 0.03192119278537575, 0.0955667273956351, 0.015245536178554175, 0.0198767241454334, 0.023827810764487367, 0.041743784458958544, 0.05004392696719151, 0.05036316179030109, 0.06633728567976505, 0.04935521763400175, 0.021704014179704245, 0.04694966097304132, 0.05308027575665619, 0.07418435445288196, 0.017821637447923422, 0.11021640340914018, 0.03018190291186329, 0.06647778165643103, 0.02942102528322721, 0.0409953804773977, 0.014202715719875414, 0.05059801442257594, 0.006364904775182367, 0.03493811957014259, 0.017531416888232343, 0.04400911602715496, 0.0230404161993647, 0.03613286229665391, 0.03779972597840242, 0.09222080654581077, 0.020373755287437234, 0.020505792635958642, 0.04787218764249701, 0.017896466342790518, 0.013898437027819455, 0.027223802462685853, 0.024787327929516323, 0.05216878482315224, 0.0457579276553588, 0.07105129639967345, 0.04403395199915394, 0.10197423005593009, 0.013210660945333075, 0.03962157235946506, 0.0377353261137614, 0.013000182298128493, 0.01982070127269253, 0.03216663215425797, 0.028749910416081548, 0.014182462509779725, 0.03246647465857677, 0.09695350454421714, 0.026356608468631748, 0.024481390537403058, 0.032946106148301624, 0.14691975462483242, 0.004363294456197764, 0.05357408968848176, 0.029081249667797238, 0.046599623310612515, 0.0714149561827071, 0.10106080211699009, 0.10902699301368557, 0.03555737130227499, 0.01589509814948542, 0.04703338636318222, 0.010633644051267765, 0.04108416731469333, 0.010973735079460312, 0.02417364787106635, 0.035798866156255826, 0.05122748923895415, 0.04107435612240806, 0.04606423055520281, 0.06570733588887379, 0.01596493981196545, 0.020570749111357145, 0.04683098413806874, 0.023392910370603204, 0.03230670881748665, 0.17414980597095564, 0.14850003935862333, 0.17307428555795923, 0.1293638802599162, 0.08344929636223242, 0.259546497836709, 0.12629872129764408, 0.16001339186914265, 0.19029052346013486, 0.1199239473498892, 0.12995492666959763, 0.1633376642712392, 0.11533778641023673, 0.14596107794204727, 0.33563539618626237, 0.28708608413580805, 0.2185919540352188, 0.17655295436270535, 0.16686970833688974, 0.07919642652268521, 0.1866910033277236, 0.12322502763709053, 0.12685013702139258, 0.107731692987727, 0.27529733546543866, 0.17907685018144548, 0.09122252886299975, 0.14343741961056367, 0.14246024860767648, 0.20369859383208677, 0.07700215559452772, 0.16547500505112112, 0.16862580785527825, 0.15038162120617926, 0.1701842140755616, 0.15750000486150384, 0.0913646278786473, 0.11785079492256045, 0.05709247081540525, 0.2551114826928824, 0.27992204355541617, 0.1387852817424573, 0.09649417450418696, 0.07587155298097059, 0.14818593277595937, 0.12823660246795043, 0.2224158847820945, 0.14916921907570213, 0.10399023711215705, 0.17019190272549167, 0.08234915891080163, 0.22592772758798674, 0.11401180599932559, 0.08051709315623157, 0.13424396136542782, 0.13645829254528508, 0.14445402834098786, 0.0927690087701194, 0.18681029614526778, 0.12155432705185376, 0.1949472032720223, 0.15980915282852948, 0.16726037487387657, 0.09554718664730899, 0.07197620536317118, 0.12550272338557988, 0.10550334263825789, 0.09707718345453031, 0.10298188848537393, 0.21044161403551698, 0.0857308809645474, 0.08559673035051674, 0.10940893189399503, 0.3466681338613853, 0.1479900354752317, 0.15670305700041354, 0.10611838268232532, 0.13638634874951094, 0.08299813736812212, 0.23744933278067037, 0.0838242145255208, 0.09031286361278035, 0.12737030832795426, 0.17020468250848353, 0.1060693860927131, 0.16015591390896589, 0.20557046838803217, 0.09351619562949054, 0.07919935800600797, 0.16924266616115347, 0.10253449217998423, 0.1700500337756239, 0.17100118508096784, 0.12235443646204658, 0.19746691337786615, 0.16504776547662914, 0.12847757781855762, 0.1874944375595078, 0.057509780453983694, 0.11833898708573543, 0.11960470510530286, 0.08865264215273783, 0.10482296391273849, 0.22031823405995965, 0.1369708197307773, 0.1379736393573694, 0.20259702403564006, 0.21117179829161614, 0.14542535122018307, 0.10703440071665682, 0.05166207978618331, 0.32345322018954903, 0.11756224048440345, 0.1912882222677581, 0.138169284327887, 0.18192809249740094, 0.08786342004896142, 0.1748951300396584, 0.11163154544192366, 0.1628516911296174, 0.11424495911342092, 0.24389078869717196, 0.11755065555917099, 0.18333422485738993, 0.12288868631003425, 0.15098991512786597, 0.14123163797194138, 0.11403372904169373, 0.14114449499174953, 0.15038708341307938, 0.10075128942844458, 0.2060569016612135, 0.1287674013292417, 0.17141095449915156, 0.1205389725510031, 0.12140747829107568, 0.18342485593166202, 0.2185164627735503, 0.1334389834664762, 0.09766528353793547, 0.16285535733914003, 0.08405462169321254, 0.10364165776991285, 0.10422316758194938, 0.12045022653182968, 0.13248579867649823, 0.13878272875444964, 0.14333362283650786, 0.1703629974508658, 0.12225679951370694, 0.13061000558082014, 0.24282280850457028, 0.2027328370604664, 0.15035246964544058, 0.161861814558506, 0.12384668763843365, 0.18906299636000767, 0.19280465261545032, 0.20784466119948775, 0.13474477746058255, 0.1479219805332832, 0.07362634103628807, 0.11685887002386153, 0.0926488105324097, 0.06444756989367306, 0.11149479731102474, 0.10135441800230183, 0.17824981565354392, 0.09131066632107832, 0.0897706653631758, 0.14812961861025542, 0.07246292065246962, 0.33848782593850046, 0.16790525667602196, 0.07679711503442377, 0.18838565301848575], [0.02788463116303319, 0.08522117394022644, 0.04950427799485624, 0.0028001155305901193, 0.05149389056896325, 0.05277862983348314, 0.00967611213127384, 0.03731536700797733, 0.020421929948497564, 0.04429787826666143, 0.04508203150180634, 0.033246486709685996, 0.06645763234701008, 0.0503864652273478, 0.04568520460452419, 0.01008303170237923, 0.014290289145719726, 0.04104522682609968, 0.0546108514390653, 0.044898238629684784, 0.038863832160132006, 0.019619306513050105, 0.06863917544251308, 0.024204903420468327, 0.057374872849322855, 0.03796421930019278, 0.03900952317053452, 0.022548363012901973, 0.029079169798933435, 0.011384588960936526, 0.03438863714109175, 0.011945732385356678, 0.04177993818302639, 0.02073778614430921, 0.029202765217632987, 0.00878639117217972, 0.01585057114425581, 0.021834749059053138, 0.027539562179299537, 0.036954850220354274, 0.005520560116565321, 0.03707020965521224, 0.023870727309258655, 0.031156135009950958, 0.017519464599899948, 0.03552250891516451, 0.007003812752373051, 0.009249471841030754, 0.025967793590098154, 0.08171634442987852, 0.07788578630425036, 0.054520498670171946, 0.03748718161659781, 0.01960378449439304, 0.027421980012150016, 0.0564794716774486, 0.046374103185371496, 0.04410772518895101, 0.010716493707150221, 0.05283549318846781, 0.04586770985042676, 0.008816972294880543, 0.03767884125409182, 0.04116256408451591, 0.04792721418198198, 0.017614626485737972, 0.021752947686763946, 0.022176387465151493, 0.023282838737941347, 0.0933764863293618, 0.07941217627376318, 0.02920029201050056, 0.014051001253392315, 0.00585170037993521, 0.03990729179349728, 0.07529646274633706, 0.04021801789349411, 0.018235631541756447, 0.021683931663574185, 0.047020955389598384, 0.033876113666337915, 0.04195086963591166, 0.0678175882785581, 0.03330145016661845, 0.028415366941771936, 0.030859493017487694, 0.026803505679708906, 0.048228915766230784, 0.024271251422760542, 0.018621349809109233, 0.046313774000736885, 0.030416401168622542, 0.006239252679733909, 0.030498889027512632, 0.035316366265760735, 0.004243040093570016, 0.004027877566841198, 0.06312570098089054, 0.05253086383163463, 0.026108554884558544, 0.015183389659796376, 0.022218034937395714, 0.01207811854328611, 0.05757292608905118, 0.029175300187489484, 0.041573910566512495, 0.0503695776569657, 0.051370026121730916, 0.048265559307765216, 0.034991053253179416, 0.01933999181346735, 0.0608798285247758, 0.03953521234507207, 0.014560323288606014, 0.0929980503860861, 0.027453317197796423, 0.029242527634778526, 0.06149995228042826, 0.03357653462444432, 0.04597854218445718, 0.06836022439529188, 0.05673127125191968, 0.054723550274502486, 0.005032934768678388, 0.01360784353892086, 0.042426604850334115, 0.039999206783249974, 0.01571895681991009, 0.04568293734337203, 0.01378408227537875, 0.04414413866470568, 0.01974259765120223, 0.08583596907556057, 0.05324808647856116, 0.027474470261950046, 0.04088174653588794, 0.032959075178951025, 0.05345730904082302, 0.04355835779279005, 0.09536245124763809, 0.07747930460027419, 0.018123181325790938, 0.08520742936525494, 0.019437905211816542, 0.024227748581324704, 0.008418532688665437, 0.06214007691596635, 0.037229248191579245, 0.015428277984028682, 0.02770258048258256, 0.00565127133995702, 0.05625212586892303, 0.04962908125889953, 0.04887756767857354, 0.038875754762557335, 0.054719256950193085, 0.067315703490749, 0.04012436627817806, 0.08731777081266046, 0.05640645176754333, 0.023436095943907276, 0.0821123766945675, 0.028417730682122055, 0.03997650448582135, 0.09505425216048025, 0.02424688671453623, 0.054283501231111586, 0.025539910202496685, 0.02384482078923611, 0.013387637191044632, 0.049964246281888336, 0.05320608092006296, 0.03269152352004312, 0.07464489419362508, 0.01778569152520504, 0.05126467454829253, 0.058531799440970644, 0.044316454223007895, 0.0741631661367137, 0.029924865630164277, 0.01490933585955645, 0.04038550207042135, 0.03578794545319397, 0.017425922451366205, 0.020344559197837953, 0.046796411188552156, 0.03490080067422241, 0.02378317429247545, 0.12373008881695569, 0.02384193940088153, 0.031671964752604254, 0.022688940625812393, 0.06419155120966025, 0.10379508195910603, 0.027865019910677802, 0.008078783976088744, 0.030151289320201613, 0.025789201317820698, 0.009820456143643241, 0.014920892026566435, 0.012301884416956455, 0.013965402868052479, 0.02876682767237071, 0.01439324358216254, 0.05211013660300523, 0.02164124703995185, 0.023336829981417395, 0.06194049485202413, 0.036341724917292595, 0.0796343975525815, 0.02150358421204146, 0.05407418590039015, 0.03626144309237134, 0.07989534409716725, 0.0462487915501697, 0.026225539622828364, 0.03902675955032464, 0.033160349339595996, 0.01662152528297156, 0.030863318788760807, 0.045645599893759936, 0.05975526699330658, 0.014843242970528081, 0.010508934483368648, 0.044076896374463104, 0.02457771017361665, 0.15049419016577303, 0.05270168025163002, 0.03626469369919505, 0.013416738656815141, 0.024024285085033625, 0.05021421646233648, 0.037445383859449066, 0.006775824986107182, 0.025911345837812405, 0.05451395292766392, 0.06919423511135392, 0.030856017910991795, 0.0359634225605987, 0.04892174772976432, 0.07859348348574713, 0.06107921391958371, 0.021798882917209994, 0.061475765687646344, 0.022432678888435476, 0.05398004075686913, 0.11101044205133803, 0.018778215708152857, 0.027016657913918607, 0.021301814667822327, 0.03816808726696763, 0.02071443261229433, 0.03608606617490295, 0.04772400301590096, 0.02975110473926179, 0.022097079709055834, 0.03369157493580133, 0.06302309164311737, 0.04100024154467974, 0.07264270592713729, 0.015459625374205643, 0.0069619310397683876, 0.03000347947818227, 0.055524876806885004, 0.034645598352653906, 0.0696870731189847, 0.02108402957674116, 0.02141683828085661, 0.05403069233580027, 0.07281817932380363, 0.014102273453318048, 0.06679756566882133, 0.009878839973680442, 0.03563995749573223, 0.023470594678656198, 0.015170046772254864, 0.029877824599680025, 0.06087504167226143, 0.08599864784628153, 0.07283136728801765, 0.016322621595463715, 0.015518048166995868, 0.027477303410705645, 0.04786151555890683, 0.04457822455151472, 0.021957203425699845, 0.0028997040953981923, 0.053805020070285536, 0.02851835663022939, 0.01523498469396145, 0.0762306856631767, 0.043901400713366456, 0.011385566740500508, 0.03614017245126888, 0.01811591755540576, 0.04590609372826293, 0.061358380189631134, 0.05876704541151412, 0.020278103584132623, 0.01495586388045922, 0.0446541648125276, 0.03680672867631074, 0.07425181567668915, 0.03933695872547105, 0.012028431756334612, 0.020671931670221966, 0.034641984093468636, 0.0689878809498623, 0.0742174319748301, 0.06151506240712479, 0.024146581745299045, 0.06368335816659965, 0.055644444219069555, 0.01737633028824348, 0.015460166214325, 0.0430754274566425, 0.05875208000361454, 0.021076281554996967, 0.05116646985698026, 0.024175475409720093, 0.03958820539992303, 0.038357108569471166, 0.02243947881652275, 0.07510901108616963, 0.07032369481748901, 0.07791854470269755, 0.05023527119192295, 0.05843504193762783, 0.03309938561869785, 0.05898961178900208, 0.051912758717662655, 0.009818697253649589, 0.03235123396734707, 0.050261810392839834, 0.09618649492040277, 0.018714825164352078, 0.004160407979725278, 0.02276979390444467, 0.019134342692268547, 0.010778882351587527, 0.07514152457588352, 0.04366757224488538, 0.03368771947862115, 0.038233949162531644, 0.05372988132876344, 0.01916694895044202, 0.010978394839185057, 0.15057204145705327, 0.07801207757438533, 0.02470021277986234, 0.04678963538026437, 0.06449311549658887, 0.09742588896187954, 0.25414410803932697, 0.1117418434296269, 0.15572395641356707, 0.17849312134785578, 0.13713461172301322, 0.1700243999948725, 0.12293357140151784, 0.10277962355758063, 0.12261243668035604, 0.20078863279195502, 0.13704840384889394, 0.20558804244501516, 0.1996065251296386, 0.14789848413784057, 0.1032518372812774, 0.21554963837843388, 0.14673092256998643, 0.10387289614300244, 0.0785774456744548, 0.21401072095613927, 0.19603832362918183, 0.12872558872913942, 0.1448327166144736, 0.12360631342744455, 0.11169296558364294, 0.0798801968630869, 0.13934441580204293, 0.1427975101978518, 0.1322673846152611, 0.10709002468502149, 0.0859006991959177, 0.1550296921050176, 0.11527687092893757, 0.07284715276909992, 0.10677340964321047, 0.1319520312245004, 0.12109967254218645, 0.1069694034231361, 0.1282205423922278, 0.31545405567158014, 0.1168811864044983, 0.18670998746529222, 0.08656394173158333, 0.09187060932163149, 0.14787360734771937, 0.09008027453091927, 0.16114038764499128, 0.16535632079467177, 0.14671271026600152, 0.26172980724368244, 0.14306956669315696, 0.10770200708066113, 0.15412568202009425, 0.09914096997817978, 0.12137919504311867, 0.1381987624336034, 0.09639664887799881, 0.12769349879818037, 0.12575683475006372, 0.19734658155357465, 0.1055426467792131, 0.22007124731317163, 0.12294912681682035, 0.20235204108757898, 0.16370860452298075, 0.12491041532484815, 0.15861521533224732, 0.14558428956661373, 0.15101216471521184, 0.24326549959369004, 0.14504449587548152, 0.06187183134898078, 0.08905602910090238, 0.1032233091245871, 0.10909966411418281, 0.10708767207688652, 0.12312793245655484, 0.1309193772613071, 0.12965055706445128, 0.11110988984000869, 0.11006651184288785, 0.15490654011955485, 0.18536990624852479, 0.16339825320756063, 0.09703740433906205, 0.10303986506187357, 0.1558380838832818, 0.18128371535567567, 0.14681205415399745, 0.15962119650794193, 0.13690908788703382, 0.17713552544591948, 0.2229264675406739, 0.2838333696126938, 0.1047603043843992, 0.14021137787494808, 0.15088657848536968, 0.1223224498971831, 0.13060969387879595, 0.11675949644995853, 0.13337054260773584, 0.17722476128255948, 0.17179976566694677, 0.13750656129559502, 0.13092963374219835, 0.1018861668126192, 0.13339862547582015, 0.14231129956897348, 0.10383880930021405, 0.10086892725666985, 0.148370772076305, 0.15252503275405616, 0.10395610574050806, 0.19275043130619451, 0.13844525936292484, 0.10097526959725656, 0.12619839777471498, 0.24503808963345364, 0.120614641928114, 0.1715713326120749, 0.13626187574118376, 0.09516141086351126, 0.09484404625254683, 0.13952051260275766, 0.06905866699526086, 0.15846539055928588, 0.06617356048082002, 0.11890385052538477, 0.15717476606369019, 0.186053468787577, 0.15802491107024252, 0.17965811508474872, 0.19922078645322472, 0.09415298060048372, 0.19456382462522015, 0.17818140448071063, 0.0867074508278165, 0.16566060134209692, 0.2652210183441639, 0.11460566514870152, 0.11081738717621192, 0.15861925261560827, 0.13598236808320507, 0.10729137677117251, 0.08366448208107613, 0.13665438280440867, 0.1403558294987306, 0.1766499679069966, 0.25703177496325225, 0.10826417652424425, 0.13605031912447885, 0.16514598130015656, 0.1762323168804869, 0.14448389236349612, 0.112020638625836, 0.1937112008454278, 0.136476282204967, 0.1790388225344941, 0.09321437159087509, 0.14161194412736222, 0.12257294700248167, 0.12552308791782707, 0.20706268987851217, 0.2348655159585178, 0.1290724685532041, 0.18818111711880192, 0.1027252760832198, 0.10887847442063503, 0.1176382735138759, 0.07943637028802186, 0.20358060719445348, 0.17400153970811516, 0.11292226641671732, 0.1795668457634747, 0.14583552139811218], [0.07413016282953322, 0.06048688730516005, 0.01162756996563985, 0.05853533206391148, 0.07311658948310651, 0.01614818535017548, 0.06092791227274574, 0.015773538070789073, 0.09479331303737126, 0.05820939564728178, 0.0785561089287512, 0.042448809908819385, 0.035192635405110195, 0.007352581342274789, 0.024508501192030963, 0.006674206415482331, 0.02232244769402314, 0.08606409042840824, 0.08801086994935758, 0.045467929739970714, 0.05725016235373914, 0.03423926136747468, 0.038150015971041285, 0.02292020682943985, 0.049886829146998934, 0.04622388136340305, 0.02831902318575885, 0.07184912741649896, 0.02705550748942187, 0.011633053509285673, 0.00706061673554359, 0.047701675503049046, 0.01106197551052901, 0.00966831494224607, 0.035269121144665405, 0.06645268222200684, 0.07435032093781047, 0.029435664146149065, 0.07104855787474662, 0.06438490294385701, 0.01877034523204202, 0.026004015962826088, 0.038713910907972604, 0.04836196429096162, 0.0688567508768756, 0.06366832967614755, 0.0034775094309225096, 0.08728959888685495, 0.08191941829863936, 0.041146003059111536, 0.035077520878985524, 0.04484947210585233, 0.11969402999966405, 0.04563636757666245, 0.06921806547325104, 0.010314343362551881, 0.054001885873731226, 0.033628729870542884, 0.02469505856424803, 0.06286150382948108, 0.0404618913307786, 0.04269091703463346, 0.024849276851455215, 0.05756134858529549, 0.008365236280951649, 0.03265718063630629, 0.04587858602462802, 0.039508216723334044, 0.06915100500918925, 0.031298441826947965, 0.017481065879110247, 0.055688635402475484, 0.04066758127009962, 0.03359434616868384, 0.014456315002462361, 0.021334916309569962, 0.05173273224500008, 0.04035219448269345, 0.005350888459361158, 0.02799724094074918, 0.03732456963916775, 0.016652407903166022, 0.023482780743506737, 0.06284669798333198, 0.03538888893672265, 0.04284435977751855, 0.03431132761761546, 0.02001057604502421, 0.07662104049813934, 0.029717427933064755, 0.03699450317071751, 0.06476676760939881, 0.04871113364060875, 0.014709993138239952, 0.07959287439007312, 0.05365422308386769, 0.0703750662796665, 0.041137750376947224, 0.027648776631394867, 0.03544499530107714, 0.02592461729364004, 0.029859645692340564, 0.048506812963751145, 0.004266555042704567, 0.01942497143318178, 0.05381673858209979, 0.010500186417630175, 0.0423144886008231, 0.028143549789092503, 0.011427033314248547, 0.034684201164054684, 0.012069600543327397, 0.05333249093382619, 0.10410255374154076, 0.04016265367681626, 0.013309056739672087, 0.0764822366181761, 0.06156829294923227, 0.023989029359654523, 0.015862729378568474, 0.024212914904637728, 0.045589779256260954, 0.025709201509016566, 0.029972628399264067, 0.057934463329729624, 0.10374760677223094, 0.010887813859881135, 0.05048558647104073, 0.030643635654996615, 0.06370725532178767, 0.022898662282386795, 0.022452644516306464, 0.06861140427645296, 0.08017266241949983, 0.025793372187763453, 0.05834743882587645, 0.03840456520265434, 0.03796764060098212, 0.04071675597515423, 0.046855452746967785, 0.006056875454305555, 0.021426482489914633, 0.0982935560750775, 0.012305623913562158, 0.03232247574487701, 0.048717267491156235, 0.0387829640385462, 0.04302297245885711, 0.08351901371497661, 0.02936490964202676, 0.011641791370493593, 0.03818583943939302, 0.044499927971628495, 0.018770779388432857, 0.033737268968252465, 0.013808585208607838, 0.03707346768351272, 0.047786365685169585, 0.05274482871755026, 0.01298788862186484, 0.11635487011517398, 0.037280786636983976, 0.05059210321633145, 0.003848594169539865, 0.060054207788198255, 0.01744077839248348, 0.040005611517699435, 0.032087329964269884, 0.030524836365657393, 0.04827659504371695, 0.0464786532393191, 0.03370430276845582, 0.007343739116549841, 0.03378115958184935, 0.01888057271571597, 0.01702617017144803, 0.023652272429899313, 0.034458692171028815, 0.03444839116127696, 0.05069465689302888, 0.0482593438209733, 0.017584623310540337, 0.016850325700943358, 0.0765579950530082, 0.05043463432230055, 0.04482970500248484, 0.028228208429936785, 0.03136879371595569, 0.02753839515207801, 0.03528132205246948, 0.00494595135023701, 0.03354549058713019, 0.020687229189206846, 0.027723943203454837, 0.06351066040224396, 0.03128062286123168, 0.0019532260012056213, 0.017436310663470067, 0.04465879581402987, 0.02442860342853237, 0.0532276069134241, 0.024091006016533356, 0.01503301105913124, 0.0437484366557328, 0.01727329050481785, 0.014006182027515024, 0.00960984669291065, 0.09070023501408286, 0.030154766282066703, 0.051921263730037026, 0.06850778561783955, 0.02613018292322522, 0.04676374184782617, 0.05564056278672069, 0.032493344115209766, 0.07955357767059468, 0.046148375258781016, 0.052219184071873315, 0.03752791810256895, 0.06355791294481605, 0.022783638669352513, 0.032544444693485275, 0.036115607363171875, 0.04711436209618114, 0.029949924246466253, 0.05803774431115016, 0.01037189320413745, 0.04074486110766884, 0.04646280467568431, 0.07778331055305898, 0.081724560004659, 0.005559621204156429, 0.025777926239243243, 0.020641763367166277, 0.0624901257106103, 0.04796582812559791, 0.044494866524473764, 0.02856334005628014, 0.02815319770888891, 0.043376164248911664, 0.038079671503510326, 0.011777783438446932, 0.07298162250663154, 0.04443958023330197, 0.01313772638241062, 0.013109504361636937, 0.02207816236477811, 0.0043384737909946125, 0.046193750167731196, 0.007045719512461801, 0.014303483603725908, 0.04499765673244838, 0.023024003603495657, 0.008881028916221112, 0.024635601403133478, 0.03947418925235979, 0.04749156978505198, 0.034417183851473965, 0.03601778116717469, 0.03633211039414164, 0.07275633615790866, 0.02006192153203301, 0.041355503926752135, 0.06878867367049679, 0.019905727276636753, 0.020367764300317504, 0.010310367306374246, 0.018494739415473305, 0.07534311414929107, 0.045984765092725866, 0.08923092362238094, 0.09189701493596658, 0.036570068914443254, 0.01878798422694672, 0.03783867759921122, 0.025321470166090876, 0.04278435342712328, 0.052674680919153616, 0.0440242669719737, 0.06362220519804396, 0.03332934378704522, 0.02144254627637565, 0.03323659017041791, 0.03083577026700368, 0.0816870889684651, 0.01163727261882741, 0.0330567937635351, 0.025538741319905967, 0.00502237957334728, 0.05248309920716565, 0.009052404730027774, 0.051565099638537504, 0.04964333049429115, 0.02172595948650269, 0.061644151574000716, 0.038831964338896796, 0.027522151394805405, 0.013930736222391715, 0.05449358097393997, 0.03068417547183344, 0.041475587131571956, 0.02266439223603811, 0.01935203130415175, 0.030810745047347154, 0.09266107823350467, 0.0480126613547327, 0.025489189974905457, 0.05864067250513472, 0.09753145204740576, 0.034640225203474984, 0.0023457884935851325, 0.034414430483593605, 0.049453218234702945, 0.042026008377433755, 0.023838904016884044, 0.026426518779771868, 0.02102706603182014, 0.009330355733254692, 0.023080423525243532, 0.05454593207105063, 0.017665986815700307, 0.014818871768511599, 0.020263164151401725, 0.03331572537717875, 0.02050861465249909, 0.057908632879843935, 0.02979768378281733, 0.027240697454544716, 0.06209273160493467, 0.05929167331487406, 0.07141261841752566, 0.006462564915636904, 0.07171836841735058, 0.03133494064968545, 0.039291739667532966, 0.05080842071038205, 0.08512407133821398, 0.07284509702003561, 0.02713647951168241, 0.03236783952161204, 0.03792712675931398, 0.04890835196420085, 0.030636026785941795, 0.031108761868381407, 0.01854480469773989, 0.023792098618287127, 0.054890785831958055, 0.00935960562856053, 0.05981262387649622, 0.06654945827904157, 0.03188662354659755, 0.01976553743588738, 0.22205720480997115, 0.12750757596222684, 0.12620734807569534, 0.15896175376838073, 0.100498758838512, 0.09030208020703867, 0.147914900444448, 0.11797447383287363, 0.1966000848915428, 0.13414314802503213, 0.11220887696254067, 0.16817008465295658, 0.14876884524710476, 0.06654398122918792, 0.06718949385685846, 0.14714061777340248, 0.09819952596444637, 0.12264807461178862, 0.19063784857280552, 0.1758594618877396, 0.17617741279536858, 0.04637450765585527, 0.10496113696717657, 0.11650577842374332, 0.13523391215130687, 0.12527785263955593, 0.07720494744717143, 0.18048506055492908, 0.14203349885065109, 0.15248605515807867, 0.1741849392419681, 0.19049360475037247, 0.121378326730337, 0.13527878239983693, 0.15719909366453066, 0.13941978832008317, 0.19903429958503693, 0.1439521138672717, 0.1894759718561545, 0.1491402753163129, 0.16781222104327753, 0.1662083063274622, 0.17707173043163493, 0.1899407641030848, 0.23853620805311948, 0.18164232111303136, 0.1442495221272111, 0.1416429807431996, 0.18057508306810632, 0.11450062898802571, 0.06916333950357512, 0.13873892719857395, 0.25245646422263235, 0.1991070745862089, 0.18167126487242058, 0.07329745087190531, 0.1188396399084013, 0.1414631138322875, 0.12441273851436563, 0.11184107599547133, 0.1320495642721653, 0.15999837080016732, 0.11382579410565086, 0.12410689203534275, 0.16612974257441238, 0.09606873092707247, 0.14324297691928223, 0.19655947457067668, 0.1400092465337366, 0.13727946410654113, 0.07069298007991165, 0.09986318356823176, 0.22902278025867417, 0.16175457421923056, 0.0935597151692491, 0.1362454000627622, 0.15316770295612514, 0.15614695090334862, 0.1632770456490107, 0.15930821798974648, 0.11941197677515447, 0.1384844002313912, 0.16870008199475706, 0.1582654708181508, 0.17280708270845935, 0.1456976155168377, 0.12114679149817675, 0.1684132864465937, 0.23179939220426604, 0.10757100317277946, 0.09700954411528073, 0.12814301764592528, 0.13802357105305418, 0.0881862171809189, 0.22894267283845693, 0.1325400051428005, 0.12621316651348025, 0.09402641473570839, 0.11900448575033806, 0.15921892278129235, 0.10814972993102856, 0.09897991651087068, 0.15692890738137066, 0.15688694635173306, 0.09973099222406745, 0.17176139663206413, 0.1280831263284199, 0.07617758499691263, 0.13856622943421826, 0.1100286994187627, 0.13929259905125946, 0.09895150709780864, 0.16603007214143872, 0.16818372532725334, 0.09793049001018517, 0.0998168958176393, 0.1474495738511905, 0.17749714432284236, 0.13744837691774592, 0.12098366001737304, 0.15156773646594957, 0.0895996300096158, 0.15550202457234263, 0.1328350236872211, 0.19301269145216793, 0.15353781200246885, 0.07856264724978246, 0.12048737844452262, 0.20467629918130115, 0.1113549766887445, 0.0827447533083614, 0.17094136797823012, 0.14374064630828798, 0.19395814306335524, 0.097268694662489, 0.16425221285317093, 0.17015745223034173, 0.09581359539879486, 0.24047166982199997, 0.14396490849321708, 0.11834895412903279, 0.11681396266794764, 0.267124300589785, 0.09999978326959535, 0.11143052732222714, 0.13276400015456602, 0.12356211853330024, 0.13137279980583116, 0.16566333244554698, 0.12531401007436216, 0.12655321857891977, 0.12572107807500288, 0.1158543954079505, 0.1982493299874477, 0.1842765000765212, 0.04627215435903054, 0.12096367398044094, 0.1234272109286394, 0.15371334477094933, 0.11343091216986068, 0.25997691380325705, 0.17424536490580067, 0.1276920293457806, 0.09710436090244912, 0.15775509586092085, 0.08652348726172931, 0.22739416686818004, 0.18821852136170492, 0.07710537349339575, 0.14748749759746715, 0.11536972102476284, 0.13403106888290495, 0.14729645394254476, 0.1933077842113562, 0.15273134980816394, 0.1271173992427066], [0.031176547781797126, 0.028106154823035467, 0.07012920759734698, 0.02632586685649585, 0.030700899769726675, 0.012277268306206679, 0.0911477797490079, 0.0908562121912837, 0.06205661498825066, 0.043754370126407593, 0.09956021662219428, 0.013275778837851249, 0.10671111376723275, 0.014273208616941702, 0.018567085826362018, 0.06358019221806899, 0.032386526800110005, 0.03993915961473249, 0.022200086095836014, 0.03785566907026805, 0.04122640362766106, 0.03223103944037575, 0.023670913324167486, 0.012327761251071934, 0.01487360144892591, 0.018187794557888992, 0.03223939973395318, 0.013898133674956625, 0.020572333596646786, 0.07945777382701635, 0.018251969922857825, 0.013229723936092341, 0.011701435923896497, 0.011644603182503488, 0.08796421854640357, 0.017137898648798, 0.0926439420436509, 0.012486710729717743, 0.05815867356432136, 0.11941404736717232, 0.02230451184004778, 0.053951334484736435, 0.030923989361326676, 0.057985519379144534, 0.026554891774139833, 0.03137212595902383, 0.014462749422818888, 0.037303693025023676, 0.08282174370833673, 0.05707473348593339, 0.03927653677237686, 0.03336047688208055, 0.03494722943287343, 0.013797568954032613, 0.066772629506886, 0.06947198387933895, 0.027372473196010105, 0.07238878009957261, 0.058663207819336094, 0.039197683581733145, 0.03104248251474928, 0.03543815641023684, 0.023974388641363475, 0.07628809820744209, 0.029368716859607957, 0.030507019255310297, 0.031521152923232876, 0.011046780964534264, 0.0806111900601536, 0.04227469093166292, 0.01656196607655147, 0.0451146414707182, 0.054000498057575896, 0.013073376612737775, 0.030487465519399848, 0.030333915165101644, 0.03772380427108146, 0.0782807647192385, 0.06918986386153847, 0.015000434486864833, 0.07928594437544234, 0.016244289763562847, 0.03999184838903602, 0.06296175313764252, 0.0183027680759551, 0.04976335432729684, 0.03595184134610463, 0.027376395446481183, 0.06904074412886985, 0.017920703030540608, 0.019864235655404627, 0.043450998709886335, 0.02470651175826788, 0.02978709148010239, 0.02672557831829181, 0.04210217870422639, 0.02697124033147702, 0.07201827029348351, 0.08557226916309446, 0.02935577380412724, 0.07672396895941347, 0.0578659927850822, 0.004728875474029337, 0.03376614593435079, 0.040812723091221415, 0.028573212475748733, 0.044002548020216636, 0.011424680706113577, 0.03363717922184151, 0.020445307600311935, 0.019466761768853758, 0.017354793162667193, 0.04039752486278303, 0.019183684380550403, 0.025223089214705396, 0.08495678383042105, 0.05346302728867158, 0.10098260201630183, 0.04450888569408562, 0.05877026262169238, 0.034029326343443245, 0.016250360531557817, 0.041494166798656806, 0.02010678064834792, 0.05094479776744265, 0.014370785265782615, 0.04678811768826563, 0.014047649528947659, 0.044552728068083525, 0.0630245462525636, 0.016463614811073057, 0.022091552564234007, 0.09153124003205448, 0.05476598256791476, 0.051941401907242835, 0.03251003872719593, 0.02821819500240963, 0.020529025568976067, 0.03983889546361752, 0.02388489490840584, 0.07924607620225288, 0.0064248605667671654, 0.06510314604383893, 0.04584903741488233, 0.03781417559366673, 0.045299629200599156, 0.03648182755568996, 0.0361072359373793, 0.02406065588729689, 0.04323546789237298, 0.030460894777206704, 0.027649678340821993, 0.03269049935624935, 0.026952571606670972, 0.014619471530750161, 0.02846463812602451, 0.04852111786021851, 0.021129890592419542, 0.051416707210591994, 0.01624543081561569, 0.025223421325790696, 0.018130706703232136, 0.027490756692714058, 0.05736168488510884, 0.06647263857303187, 0.046762658312218264, 0.027247317411820404, 0.006547984257849748, 0.05330870881152805, 0.05075035507616121, 0.017220458867086563, 0.02000925687752897, 0.07051401858916506, 0.028907722553412896, 0.04729228086944204, 0.011248862210777588, 0.03366991535585839, 0.019234938954468817, 0.009372495806019288, 0.026596583775244653, 0.051247864903416485, 0.049936152281588875, 0.08932973316404969, 0.023063797561917454, 0.10580461006611586, 0.05259265875793062, 0.0300746495850035, 0.05511638017196674, 0.04099887970369309, 0.11258369122515433, 0.03732512253918685, 0.04992746173229534, 0.02460955201968318, 0.02461517749907216, 0.025660969331511296, 0.033300236755167134, 0.021595107718894724, 0.051277116654091515, 0.03697938191180583, 0.05902005097595975, 0.032758535744505934, 0.0600158869929146, 0.05854506904142909, 0.009905503484333167, 0.06736280760378577, 0.016973127021628898, 0.016722893378755543, 0.04006848255812656, 0.009224827899743104, 0.030416863155551255, 0.034050214089802466, 0.02422176501568174, 0.05572194670094177, 0.07074617722537369, 0.0014739015750819817, 0.06132696878921706, 0.06983435232541524, 0.023391650574922096, 0.039173723343992606, 0.028408780381141696, 0.03189670933352318, 0.0241603578615468, 0.0507216302503366, 0.02054344364296412, 0.0440975243691355, 0.010844420485227602, 0.07118752502719872, 0.03834427312540356, 0.03176225072820671, 0.033313918247586116, 0.06672614879789762, 0.05909208754019346, 0.026696667955548037, 0.0628024511388503, 0.03705986782733817, 0.018642719951458275, 0.05761095744674094, 0.08431726033450104, 0.05342773816664703, 0.023064693705237005, 0.04210579667415004, 0.03941128481528722, 0.05400763009674847, 0.023100348334992304, 0.05191093674511649, 0.023392242437694222, 0.022470871663244907, 0.03915819761459716, 0.04580098335281946, 0.06837465174612589, 0.015460311860806542, 0.024230527924373746, 0.02491489940439351, 0.02420702039671596, 0.06779933886718936, 0.017982683493755758, 0.020762271451530978, 0.03501185936329421, 0.010231766445940593, 0.04801902898179833, 0.011132473973702872, 0.041602301425882615, 0.03775429169763811, 0.01953679082362214, 0.027643768989946693, 0.03924148884834722, 0.039438480816897936, 0.053284603854990564, 0.0513124651479302, 0.11541665444383398, 0.03953950938011985, 0.02767882248008391, 0.03489099690341391, 0.05740131557104178, 0.03850152679660823, 0.020229344481776934, 0.03096172571531497, 0.06193247594637796, 0.07012644680798985, 0.03024222096428275, 0.05681701528374106, 0.05215646146098152, 0.03912378422683105, 0.03215141812688671, 0.06855107509181835, 0.079306294064736, 0.025249941973015666, 0.03472250340564642, 0.07445263341651298, 0.07237004087073728, 0.027162235746800434, 0.044864181472803466, 0.03455817706708331, 0.05584523969446309, 0.03142615059914533, 0.045969261627760716, 0.04767919584992342, 0.05651736573781818, 0.042229245518683456, 0.05829028974403627, 0.02784028598398436, 0.026033377180283424, 0.029206477811385412, 0.04555058272671886, 0.03699334542034194, 0.03269270353484899, 0.0491165132552851, 0.04079589118191507, 0.08343509907717817, 0.04008173360489309, 0.05988259355945047, 0.027450931193016004, 0.029800871307088528, 0.04642865103960503, 0.037188611895544454, 0.030547770584234968, 0.04576340470521245, 0.02154721507395152, 0.03843277423584368, 0.057167631821357645, 0.042868820964940824, 0.06537014109198935, 0.03075942182476865, 0.012369039504847024, 0.013657128638442373, 0.06877711100969464, 0.032951419925666414, 0.03878768409776967, 0.02269019856612431, 0.019286581300548278, 0.0459643077920191, 0.030257062062446494, 0.022801518862252124, 0.02545909403124824, 0.024924233766796533, 0.023328673778451048, 0.014636560408689547, 0.005943522601228324, 0.006855733881820925, 0.018014365778071806, 0.08337067323736846, 0.06269498815527186, 0.027382753796700854, 0.04077353769389447, 0.07245888336910866, 0.08100096601992846, 0.016826243008836173, 0.03022982709808275, 0.02960241174150724, 0.03321788062748965, 0.02539900418923935, 0.033550774678587914, 0.1153672274085693, 0.06943796382984146, 0.1477080787299201, 0.10485990802408196, 0.11761727815610357, 0.21976944553898647, 0.1419191635795869, 0.1417225835029967, 0.2056845068000257, 0.16148732684087008, 0.14919635199476033, 0.12034556886646897, 0.22691107325954363, 0.21191602398175746, 0.1578539054025896, 0.142009572009556, 0.09962467956938781, 0.09905892555252649, 0.10312236961908638, 0.11965134166530333, 0.1601384289097041, 0.13608481414848939, 0.17145367251941934, 0.09133538726018742, 0.1443620614008978, 0.1707905635703355, 0.11126838289783336, 0.12528068764368072, 0.1276998218963854, 0.12300784554099664, 0.10338051826693118, 0.15317019657231867, 0.14187500579282641, 0.09911906920024194, 0.18492656206944957, 0.12735217023873702, 0.19798804947640747, 0.1370943576330319, 0.10368052404373884, 0.14592600404284894, 0.16177197016077116, 0.1825589477084577, 0.09889771623420529, 0.1551959034986794, 0.2291939195129089, 0.18194612668594345, 0.19566097122151405, 0.1453797536669299, 0.26099600130692124, 0.10523060336709023, 0.1113572773465421, 0.12186129417386837, 0.11584055435378104, 0.08978078825748526, 0.18271870241733268, 0.1175860188959632, 0.16104794573038816, 0.1580057933460921, 0.1358104866812937, 0.13022803701460361, 0.13927218999015167, 0.14067308278754354, 0.19657253636978567, 0.14292404637672007, 0.14851853367872536, 0.12905643816338852, 0.16860232630278915, 0.13369201129535213, 0.15786258853040636, 0.1395496047916822, 0.07863875449402258, 0.16012655454687774, 0.15818255807971582, 0.17076693358831108, 0.07875821058405563, 0.09654513778514229, 0.12013554107397795, 0.11646081911749206, 0.18390376382740214, 0.1640740825678222, 0.24961430579423904, 0.12728375906590372, 0.13476208434440196, 0.12970949843293056, 0.07748932359390892, 0.12729981914162636, 0.1318015533615835, 0.1104946865234524, 0.061756486757076345, 0.13311104325111955, 0.09333409485407174, 0.14260464085964486, 0.15544054505880922, 0.14996068988693878, 0.21624755405355245, 0.15115937712835148, 0.0876818981487304, 0.13614892086479813, 0.2714813902275637, 0.12366209324682131, 0.20989371609175578, 0.10437975332024507, 0.16361635556677356, 0.22055530571378767, 0.18390639103017747, 0.08761093398788944, 0.08662274209200405, 0.1623337611090392, 0.171687196707353, 0.13346117368200794, 0.07435803185217083, 0.11648650484858081, 0.10343138506868854, 0.2889937598956749, 0.05749501913669519, 0.14851465966785327, 0.15316216653445736, 0.1543555993703194, 0.13663660094607621, 0.1838311817846261, 0.10027094176621176, 0.12770295375958085, 0.13394471257925034, 0.08869898927514441, 0.14798346004681662, 0.10046456809504889, 0.13734544103499502, 0.0974196994502563, 0.09077291353605688, 0.16533662419533357, 0.13341303798370063, 0.14834518282441422, 0.16563847049837932, 0.19215751468436792, 0.13936117349658161, 0.06674354473943822, 0.13202728499891236, 0.23984161613043398, 0.09631890890887007, 0.11951670123380609, 0.15152676991419867, 0.15232163976179436, 0.11581251601455733, 0.15170690399827436, 0.12656498904107139, 0.19408838998060673, 0.0763858984282706, 0.12987746129510924, 0.12022563038044609, 0.11789642958319746, 0.1427902074647136, 0.16826993320137262, 0.10132128853001632, 0.13208419288275763, 0.10624056245433167, 0.1671328887459822, 0.09005542000522837, 0.11591805683565326, 0.11756898660678416, 0.14228973275749013, 0.13061622477835044, 0.07059233001200482, 0.07452988356817514, 0.15782469447003677, 0.15475022897589952, 0.17492382146883756, 0.129288982716389, 0.06309850126854144, 0.14334960869746283, 0.18079900386510417, 0.09070102169062011, 0.10523077406105585, 0.06445811581215821, 0.0958639130112715, 0.07088250233209692, 0.04074681295605842], [0.030903151709935628, 0.031418580692843534, 0.05026014427130576, 0.01852787630923558, 0.028068342398910318, 0.011113179061794654, 0.01541404080853681, 0.06066060181183275, 0.02381661361141596, 0.07810901690390892, 0.012290833838051185, 0.05242150466074236, 0.04397756732942071, 0.05037823480961379, 0.04173093788267579, 0.03712716577865649, 0.040191597436205484, 0.023440502445737366, 0.09168453805614263, 0.01269484419026412, 0.03793063711782452, 0.04948484856868163, 0.03654432381154038, 0.044004588926327415, 0.022368434874806553, 0.034004861445282586, 0.04148799584072549, 0.0314458546199603, 0.013370730139286024, 0.047657599352533, 0.038862796864123084, 0.10559272690443322, 0.03141094770398922, 0.02758979444479337, 0.03488944210403133, 0.051347761691431515, 0.005894866008020472, 0.022394081643142272, 0.00325797171171871, 0.036103981619817205, 0.05523018851818051, 0.01663426053710282, 0.06777494447305799, 0.023101417027646676, 0.019845019596687052, 0.12056309235049412, 0.018177230085711926, 0.03731514807441272, 0.05333437969966326, 0.045101613068254665, 0.022035431356925983, 0.03587953018723056, 0.02505383872630773, 0.042781904339790344, 0.03970047378970776, 0.021804669813718647, 0.09525144079816528, 0.07803516578860581, 0.05629566767311189, 0.03796396325924434, 0.07729456177912652, 0.0314998792600818, 0.019898636055586394, 0.022421676549129188, 0.0666886629187502, 0.03500679049466271, 0.015024255571916001, 0.04736294074973557, 0.029660831751243677, 0.014909941637597512, 0.07492837976315059, 0.03830189278232865, 0.04717507348686922, 0.015196035856206436, 0.05262489394226577, 0.004848981407121755, 0.012760820191033417, 0.051531799472286366, 0.03152246652462054, 0.019167038008163217, 0.014265056124713738, 0.029104302630003076, 0.04013395111542195, 0.026475422600924503, 0.01209264793942566, 0.08343564084498212, 0.034664738341234624, 0.047387398226419464, 0.051845442212652415, 0.07356645714025944, 0.1300166139844805, 0.06553422252181917, 0.03318776056403294, 0.06269323668675497, 0.060868228756589815, 0.068162204552209, 0.04799407426617108, 0.04362298401247244, 0.009987294652091805, 0.028911049230373465, 0.03171985183143988, 0.044732821334037, 0.034440194140188396, 0.024197133134293836, 0.051502432688721456, 0.03637177076598164, 0.04376727978524286, 0.051162807358196005, 0.01590747902810108, 0.031146746841841377, 0.046327281088451855, 0.029674195975530893, 0.027625384136626963, 0.030305596665129997, 0.047460522036999464, 0.019797826425929088, 0.05244506784947589, 0.026814856828423217, 0.015967377767083235, 0.006847372196716606, 0.044344247653498314, 0.0380904326448217, 0.017080267170968, 0.022229812821024098, 0.04194385634036735, 0.029735514071944635, 0.027006444106518757, 0.04724159589386545, 0.017043451080098748, 0.011515454643813428, 0.02401236619334668, 0.020154387566435616, 0.022323464436340146, 0.021107264365127776, 0.043312510242685676, 0.032603463987470604, 0.023883902285888325, 0.015977817929524463, 0.04685271793277934, 0.07280810095835477, 0.02471329498803243, 0.008744484875933267, 0.02921199567936128, 0.016709480914869346, 0.03764290646358859, 0.024794367200229317, 0.006704901643388439, 0.04349067763541825, 0.04773289394506719, 0.12378818413708359, 0.04547887270746287, 0.026898856813204475, 0.01778853951691417, 0.04548858370981179, 0.01345533497442375, 0.055571687771589495, 0.036002559718326665, 0.01872105734946672, 0.018585181242087856, 0.11549575254321098, 0.06619396212045103, 0.025103304724325426, 0.043316399096511304, 0.02801661285047885, 0.029045385381323285, 0.0901721375703346, 0.03975044259277638, 0.024979113732115366, 0.0151449631084688, 0.0680783270217944, 0.049420385621488094, 0.008360452211491065, 0.04126403422560543, 0.056444831934641115, 0.013558785722125322, 0.040979914119816385, 0.059002042762585916, 0.05594812362687662, 0.03842222831735853, 0.01930245398398256, 0.023432342532032635, 0.03802877872658428, 0.04951961447659414, 0.07232147472677752, 0.044406009183148853, 0.0268282284741872, 0.0853180761623662, 0.035166159286745824, 0.04501908624661155, 0.07532342497142963, 0.07707177646807395, 0.01575416245032102, 0.061941003223182634, 0.036622753978008404, 0.050131585740018636, 0.03895857102179434, 0.03680179710499942, 0.032792021447676234, 0.01985295686608879, 0.03773021271626931, 0.03778332451474853, 0.0449130185006652, 0.02334131255338434, 0.02607404130685609, 0.046303387644002214, 0.04352482013928238, 0.022410922829294577, 0.05875243994523771, 0.03956598920922261, 0.07019843513262458, 0.006789424842281733, 0.05892506720556412, 0.058067341160494834, 0.07443606125889346, 0.028290695408941247, 0.02856004677596502, 0.03881037526298314, 0.027801436408481095, 0.041310496380901895, 0.04102737075299956, 0.019480957198538817, 0.03363098228874151, 0.06886933027999476, 0.016708651564840693, 0.025335450372949708, 0.03772461692278739, 0.017304173125012312, 0.07307573425350711, 0.03535385214490816, 0.04438475407368969, 0.030894334995537065, 0.03932058694772422, 0.08859243171173148, 0.013865082128177164, 0.05676874970959034, 0.04061588326294441, 0.019892244308721274, 0.07237183686811477, 0.026265569213137496, 0.03521041726344265, 0.04053351229231339, 0.0027557091243579634, 0.02383418395766057, 0.01595886718860129, 0.036094010865781456, 0.06748379251803271, 0.02559747859777417, 0.020435602164070588, 0.0755588490574155, 0.029679307517653797, 0.03547568681824487, 0.08083807944785804, 0.010456812524353154, 0.0250296335798339, 0.03653947016573511, 0.01908259087940678, 0.04687294516770635, 0.028339480486465618, 0.01617798443476204, 0.05951665167231113, 0.027481207107484806, 0.058777576487045735, 0.07099472248228267, 0.038604147266596556, 0.023243245159392245, 0.03774791293835733, 0.030485441311611794, 0.12335718929534778, 0.048007343866629526, 0.027592301048571244, 0.046191122964955866, 0.05640807707095519, 0.020206196895742323, 0.02843945891072508, 0.03691919373522978, 0.09978331363527104, 0.017449851147830486, 0.07886224484536797, 0.0927528522151988, 0.054687997690052725, 0.028577943667187355, 0.042137104173889384, 0.002120606277458137, 0.015441536452271976, 0.024858366305124946, 0.03601902055379469, 0.025977168770623393, 0.0347778824652778, 0.06042250228347257, 0.012810827956855064, 0.05368985730456188, 0.013414413879218046, 0.03668098659545649, 0.021198286922299303, 0.04437167001015041, 0.008433208658971125, 0.04475160138099454, 0.04683864310209174, 0.04704184684669599, 0.034722770578810014, 0.021605273286695592, 0.018384228060313035, 0.023254683510458563, 0.04729410655272659, 0.057957414246629924, 0.04263616137905046, 0.048163269093493, 0.018718725150392856, 0.0045202239016362, 0.036334930555312894, 0.023436257361026946, 0.023051897223922424, 0.015876557445153594, 0.016374000479117967, 0.05817463716084603, 0.09265691478503868, 0.020352396277303342, 0.016541601544304285, 0.034295126533834264, 0.007005172737990506, 0.017288248491240665, 0.07309517852263525, 0.02384440889727557, 0.04179949748504441, 0.01433360459486721, 0.025123971681750845, 0.03336750130984001, 0.021895774007134605, 0.037096392625244334, 0.05668128018442076, 0.024421113303105813, 0.046561339622712694, 0.023973874704097398, 0.026760067776194774, 0.028250138893781696, 0.05870103879715316, 0.016632594415568747, 0.006754023934263387, 0.01917100107675651, 0.02723451536439825, 0.027864758303621784, 0.0024906350790843135, 0.0570237850479316, 0.0457386503694579, 0.06587362149730325, 0.05109877485665493, 0.045689078615396284, 0.02083578674501041, 0.006032086330378661, 0.06817917746957392, 0.027788215047621634, 0.06835484382463619, 0.24864244856871665, 0.08934926649089903, 0.11169642399181612, 0.09915670350892469, 0.08293380800751038, 0.11292982148006558, 0.1082536083413288, 0.17429019062547013, 0.1065403530083131, 0.18129052827134728, 0.15382583951577544, 0.13004060019738972, 0.12702273088507354, 0.10502301724045537, 0.17029638227541, 0.14420474093640223, 0.19441649346845224, 0.07903873498435132, 0.15825291367946193, 0.10738202268839814, 0.08425129082752392, 0.11448444274719805, 0.22433366859331727, 0.11133789987070486, 0.15336281358031556, 0.09967172431061044, 0.12612424237886444, 0.13795038044918329, 0.1536178303649649, 0.135013360704761, 0.11040342462365516, 0.20894608256639913, 0.09249563125194982, 0.12907021242426708, 0.12126114161219448, 0.09543522624881007, 0.12704946304438636, 0.1935296566807665, 0.15071201050886884, 0.10020687215728685, 0.10538075468502939, 0.07320972901652567, 0.1472237383131869, 0.12351319615845568, 0.14439321676036343, 0.1775909072603099, 0.09844464992056601, 0.15271946060238406, 0.07357986774877645, 0.14570868836017326, 0.11082881625043228, 0.18530444882344455, 0.178911009861622, 0.1527683829772286, 0.20276479393942282, 0.16649838216835633, 0.17421305179595947, 0.23807284072972834, 0.10970895251375623, 0.12759663368342444, 0.18878000060794875, 0.135972868592944, 0.12095002588466741, 0.1353483958519064, 0.11458602049970068, 0.14429182454477996, 0.062172942925826646, 0.15980545693309978, 0.13491995399817824, 0.19928088557207957, 0.19993118505226448, 0.15528138406807557, 0.15438258385984227, 0.1308937434805557, 0.10842813178896904, 0.1469861768418923, 0.1604801879147999, 0.30633576214313507, 0.1503417085041292, 0.12368999799946323, 0.17286841379245743, 0.08654623408801854, 0.09169244935037568, 0.08221304160542786, 0.15431538980919868, 0.17928054003277794, 0.16273106244625524, 0.12919863365823403, 0.13386044913204387, 0.14574768079910427, 0.22306606551865116, 0.15670255233999342, 0.08418572950176895, 0.22341345000313595, 0.11246717403992079, 0.15127488499274477, 0.10865478368941694, 0.12578969704918563, 0.09319461561972275, 0.1970222927047871, 0.09463299429626204, 0.14014289248734713, 0.1684291090350598, 0.13263357512187213, 0.16524778911843896, 0.1098785555223003, 0.10625662995153107, 0.10605759336613119, 0.11342199897626415, 0.11235249738092534, 0.09179318105452694, 0.11815361343906261, 0.1726498661446385, 0.14120251609710976, 0.15169013146078214, 0.1158062597096432, 0.13505294686183333, 0.14957352628698573, 0.13353657588595524, 0.16181931918254122, 0.19596522208303213, 0.10063998954137787, 0.11381153002730571, 0.08082978965830989, 0.15193216066109017, 0.13500032859155908, 0.10429176429170184, 0.20017606409965083, 0.15972874854924157, 0.1559818527312018, 0.0908873527077958, 0.13660036929650232, 0.11553681557415985, 0.09396829715115018, 0.08682214232976548, 0.13966683443868533, 0.0596681722527137, 0.11776866886066273, 0.23284641414647922, 0.14278557646321133, 0.06258484601858072, 0.09282048413297161, 0.09585102190612815, 0.12326517040492035, 0.1052970478485804, 0.11272259158431552, 0.06697140634059906, 0.11843207466881722, 0.1360770661267452, 0.1757775287842378, 0.17311329283984378, 0.1147908013081178, 0.11187389376573265, 0.21168950566789135, 0.15124839032068849, 0.08338904139236547, 0.09975193563150242, 0.13879157515475526, 0.15902424260275438, 0.17767143028322607, 0.1262765162391588, 0.08177806885214522, 0.07645935620530508, 0.1217452296987176, 0.12904355447972193, 0.130540985846892, 0.1812889103894122, 0.1444759959122166, 0.13758169632637873, 0.09669092527474277, 0.1329987563076429, 0.09147432472673245, 0.10601690883049741, 0.12407902439008467, 0.10306581054464914, 0.11362744771759026], [0.000692995757844983, 0.03771839401451871, 0.03102826110989554, 0.016516936266270932, 0.025203949226124678, 0.014399718820641283, 0.06365623266901821, 0.012253448148840107, 0.038768833546782844, 0.08424784726230428, 0.07380772934993729, 0.008195897662517382, 0.032076680145110004, 0.05410928206401877, 0.030607695298385806, 0.05665507123921998, 0.022990907527855597, 0.02322644850210054, 0.019787402961810585, 0.06968786721699871, 0.032420977295259945, 0.062182190085877664, 0.031775442403159104, 0.05830832393257879, 0.10577672757790424, 0.014628682511101943, 0.023457345487258863, 0.020874202164122835, 0.027386106448830105, 0.06038456369424239, 0.01452376880479278, 0.04082962921529543, 0.04416924552060664, 0.018752207142824773, 0.0731083368009422, 0.015835438753128983, 0.011892128914041677, 0.011019789981219219, 0.03772360760194715, 0.026254713447997347, 0.042645308349165134, 0.066061221587006, 0.1536600140389055, 0.033807272047852166, 0.05276009840599727, 0.013597953493444948, 0.060508164679049514, 0.03507595865812618, 0.05237980338279158, 0.04000037566584069, 0.021617316488118377, 0.021768462283944245, 0.04229117032082286, 0.018344363597861957, 0.02594231380498968, 0.03038310656847898, 0.01624326188903069, 0.03793591749854386, 0.07973922591190785, 0.016579721959715243, 0.028742917529598344, 0.01968406817468349, 0.022589951113332063, 0.02820995716319885, 0.029444193278322928, 0.05454803605971392, 0.017829409589467105, 0.06168100662762299, 0.07961792929563671, 0.03181104322720785, 0.00982616882538423, 0.043308985041221604, 0.012444600342860213, 0.0649605572107248, 0.04328902126871981, 0.05686999349563848, 0.07092104206094518, 0.08793062152108178, 0.03843661856080871, 0.09698116438812576, 0.059427081869216636, 0.02392796359345084, 0.04021034779725596, 0.07404543925076723, 0.028104063821956515, 0.06306858529569581, 0.030673852197651286, 0.03606974634749349, 0.03418881387915462, 0.04402755468618125, 0.08234804568928666, 0.02626208297442645, 0.03255910211009905, 0.07432505080942065, 0.039436024308088236, 0.04123205508221872, 0.0439858905156143, 0.014235045528039336, 0.010292501028743573, 0.02784476298984373, 0.013807334689772688, 0.03999043459771201, 0.019133941932523157, 0.02083834529912565, 0.022513446820084937, 0.03925703313143458, 0.047931637382134795, 0.04810344456927851, 0.0265657215641113, 0.03706771232828032, 0.02177486145228613, 0.0478181667131139, 0.019548433265299536, 0.08537303961929865, 0.02318544855370419, 0.030854374053888023, 0.03211177259800024, 0.027828563761431724, 0.01114483722631121, 0.024479186358803418, 0.031908561431919225, 0.03404381677682977, 0.04131241854338441, 0.08060781328822486, 0.04801738141395617, 0.0706264613836538, 0.053455409142770804, 0.04760278061439749, 0.017546259841765277, 0.05910501575272065, 0.05100591733935289, 0.01907576126541244, 0.041752471297513694, 0.07895028582424857, 0.05207065063586924, 0.021788455742353108, 0.03083089064602973, 0.0545871917711338, 0.026899949625658337, 0.07535989410826005, 0.016560802760068327, 0.03142340465274174, 0.0795218360144645, 0.038067760033300146, 0.044571099933818914, 0.02382316677540075, 0.060304322687443346, 0.0544819107017247, 0.013376350980252028, 0.020597510956577025, 0.03784790991630871, 0.07913867259048857, 0.0449937790108379, 0.026348333522037137, 0.014730893872183515, 0.04745773898321204, 0.04413463546370622, 0.04584688147588167, 0.014620385300077032, 0.08109216854791157, 0.018864358644350432, 0.04911096941214055, 0.05662376745021902, 0.03351024970470462, 0.0495694645360345, 0.0285465953493258, 0.020480598577705678, 0.018847083301807288, 0.018856156057154294, 0.03680982714286074, 0.04883974041149486, 0.035735278943320736, 0.039393918559653684, 0.07972424937179312, 0.10585500189336017, 0.02338366692129057, 0.0112761704622244, 0.03321907548524905, 0.02188095146266278, 0.045966493416926824, 0.02200420363806188, 0.025631901262386236, 0.03358123612997588, 0.056892087231972255, 0.030698537884745747, 0.09571571354172193, 0.05648609534546267, 0.028705843542411458, 0.05815411306684837, 0.04757149166835006, 0.03550030756741762, 0.025369693066750187, 0.026269309637427796, 0.047418189933523536, 0.010753572332760086, 0.04797465226147324, 0.06272280385019258, 0.013308845227584243, 0.04095736025192309, 0.02203587664553197, 0.05936804773227777, 0.06618456653086469, 0.035594641958596185, 0.0202076626374037, 0.060681311442749575, 0.07647922349860892, 0.010820094739756314, 0.028250612012925558, 0.0320537960215006, 0.0399895959708374, 0.04624969697033521, 0.021946540618955623, 0.015720055198471528, 0.07619259864441119, 0.05504469241714105, 0.03751267067855224, 0.029563905409304425, 0.05774641795142088, 0.13515128142898902, 0.011160527155880118, 0.028922994097229093, 0.03255095703934785, 0.05226664070505649, 0.06091426046623383, 0.054011674801586196, 0.024931087500590365, 0.05672426166711375, 0.019224526622565463, 0.09771447308594361, 0.02225961747171823, 0.05854423783603124, 0.012683587665378582, 0.039544927058159374, 0.021534388906729873, 0.02249343480798416, 0.040125750383595005, 0.03722199740877841, 0.03784229185839649, 0.036719919662573375, 0.11320483914460056, 0.04735495152999647, 0.04208855658362154, 0.018630049635248724, 0.07155097700888291, 0.013779736073047388, 0.0626771395036485, 0.00446064706920879, 0.015576327168673743, 0.05763212720921729, 0.03747586015379056, 0.018361553593422286, 0.021212048195593525, 0.07736758911050856, 0.07457805637386627, 0.023155946328188293, 0.04440900374902412, 0.03536165211698972, 0.008487602517561754, 0.033306329787592404, 0.04530508769676089, 0.038526433272636496, 0.09665498306276277, 0.04215391010802705, 0.05652740328514483, 0.006889209844302968, 0.05912877561058849, 0.005630195737467147, 0.027912031255254988, 0.03187483082001563, 0.0764165045984555, 0.027831777260871604, 0.04526275188254658, 0.0750109956425149, 0.034219386652694084, 0.03802999584877398, 0.032602384162601084, 0.030684342455060687, 0.010996083929057932, 0.026814072007255163, 0.027095058394479565, 0.02558697720814962, 0.02116339670465095, 0.03103497754636919, 0.09590634901542217, 0.045134549582144246, 0.03532858201651834, 0.03863647893012967, 0.06223353928362485, 0.016402550900238566, 0.009083944150916068, 0.030406545447476674, 0.012718197722279001, 0.05973939987597987, 0.025593227946956176, 0.008863597722665872, 0.06880497123347595, 0.06735987612046301, 0.033536202608956955, 0.055965248684515245, 0.049891430462594144, 0.03649170554126613, 0.0523772541055223, 0.05908958279178478, 0.03605556390539277, 0.018243468621221837, 0.003333770732751873, 0.02008872790611349, 0.01910954939376097, 0.05104979682073463, 0.04170004969637375, 0.02191821284213802, 0.03891561922500841, 0.033667907846393064, 0.0574494920874713, 0.02662581882759696, 0.10358993007685058, 0.05370642575144302, 0.02883516834117472, 0.04116777396120597, 0.040558548644185066, 0.03944157186197117, 0.022177443170221522, 0.03840634264633991, 0.024060303367150482, 0.022434133497881703, 0.02429136362479767, 0.10185138235101476, 0.0655195205763448, 0.04016076862171758, 0.026587223437672947, 0.021428185718832538, 0.014364641210704576, 0.03691317862831056, 0.06914425888680853, 0.03150851414829958, 0.030938680174585897, 0.03489526796329301, 0.03308818661025725, 0.04914484474284109, 0.04037658516608644, 0.04289277007046621, 0.019459830109553877, 0.06302657231572084, 0.030889058325556107, 0.06025865091942251, 0.029234297217044514, 0.07914334069937468, 0.055178906113724224, 0.03510305075906217, 0.0530769323813729, 0.08235030181822367, 0.039015608781483024, 0.17369032750139013, 0.12220170989166945, 0.07317446215893142, 0.1663483792799525, 0.10149622015887871, 0.14803064579609782, 0.10653936595190316, 0.18249791348353028, 0.1953693517134525, 0.21486515557626262, 0.17268989759031683, 0.14074570935918018, 0.151204677822534, 0.1377314914134331, 0.12096984864911065, 0.11483573834993877, 0.15069562388816848, 0.20039306808030233, 0.06448843254474923, 0.18441281776176766, 0.18042739568045363, 0.2038439063471742, 0.12260440664249472, 0.13866082357708365, 0.20650729624321684, 0.1710111743886955, 0.2349350551958196, 0.0963254546513781, 0.1584866753546521, 0.19906070519937202, 0.10619649372529238, 0.0862105458509177, 0.24246599874459207, 0.10209649146418087, 0.11529882365721278, 0.1295287409448065, 0.08674893688294105, 0.24485348782036453, 0.11128102909424342, 0.08545863893232308, 0.12189199682325125, 0.16488340945215896, 0.3408031485741958, 0.1319736722507514, 0.12143439598730765, 0.10387375703430735, 0.21071984519949183, 0.10998184021445923, 0.17915560689289123, 0.0781247355917003, 0.12088136980310082, 0.13765267533017322, 0.08914577701943927, 0.06866928437375464, 0.19083511142525822, 0.2622244041413069, 0.1112593212747015, 0.12047848009387963, 0.22703388385707512, 0.10130315044079907, 0.11708428253768943, 0.07857313379645348, 0.08234486929723062, 0.17363422113703564, 0.09839230624493212, 0.2508350199786946, 0.07245014086947776, 0.11093666515080258, 0.12181315847556107, 0.14725590299349278, 0.08898403335479088, 0.10883756724069826, 0.15224513917928562, 0.1604507543379441, 0.20328043814515695, 0.09914367881719954, 0.09875163188553415, 0.23274334467714652, 0.148221600393299, 0.2641408075578511, 0.13103423203574494, 0.11620770223089494, 0.1353137820842676, 0.15466464450582862, 0.13326592947123572, 0.15484808856854215, 0.09546057801344432, 0.1391783231520094, 0.09767614857992157, 0.1780140947084874, 0.14530568732880056, 0.15764841955387965, 0.20652648818213493, 0.1368599577108398, 0.0827332871267572, 0.21477035363204777, 0.16805840627057478, 0.0830482694436796, 0.15445535886101425, 0.18209476402262226, 0.13135721470462158, 0.1140041915641632, 0.08059265863266774, 0.2129542440525256, 0.1068146359466482, 0.18325733835808933, 0.16011745581636205, 0.1386853589792736, 0.10615937891998328, 0.08649331895867363, 0.1244175476313103, 0.17504866555100307, 0.10281281982315704, 0.17790203040931374, 0.14865802775602788, 0.15481901122257113, 0.09768108386197127, 0.10465549828950316, 0.1311577996239066, 0.10494690257473849, 0.11592390495934524, 0.14874831744236872, 0.18149323848774657, 0.2155425731325522, 0.17329847352812067, 0.18540202639997005, 0.11933204747037962, 0.1083292109251488, 0.06406389438780025, 0.15347720822319388, 0.09771340439328924, 0.08516213609254919, 0.1609810336958617, 0.22313717810902745, 0.149922929413151, 0.08499633288010955, 0.1414304444915615, 0.1366979765589349, 0.09432797160116024, 0.16207644366659224, 0.14671149314381182, 0.14681151980767027, 0.18326225137570873, 0.1399960511480458, 0.09927122431690805, 0.09984005082515068, 0.10611833815346472, 0.14150247734505683, 0.08197412200388499, 0.07161535089835525, 0.16019235335988924, 0.20070157886948436, 0.10938049279502593, 0.11498451669467613, 0.046579770860262215, 0.07985591379110701, 0.09775182537850924, 0.15250159573042765, 0.07488247050787322, 0.13818840205203742, 0.08905251874239184, 0.22044788725906983, 0.12163899868028238, 0.10943961970042437, 0.1175662777677644, 0.1045262384286616, 0.11200851935427636, 0.09437971413717605, 0.14073089609155431, 0.10286626187735237, 0.22272656264249235, 0.11010203845216893, 0.1293170655844733, 0.18928621953818947, 0.1987623915192671, 0.11555582939763553], [0.025058477149286773, 0.018570483007351868, 0.01063037210769835, 0.02889245286496589, 0.06730143941240385, 0.04033706951304339, 0.08361406798940152, 0.015991820400813594, 0.122213450667914, 0.011838708196592052, 0.03445890368311666, 0.08282037073513493, 0.03723643960256595, 0.037738138853455894, 0.004408877630339703, 0.015632678441761527, 0.04283681955712382, 0.03541983649483882, 0.032705932317185216, 0.04758221941301599, 0.08678769183461554, 0.04475600602745544, 0.11384713827283122, 0.012533607041405048, 0.037753701690235175, 0.03624231794674415, 0.03848266882414464, 0.06054823694285005, 0.022765569228795357, 0.025643959306762554, 0.06627162787481211, 0.01962874477612786, 0.09985703116399236, 0.016373954094888177, 0.020689589218818583, 0.023234764266817365, 0.047226760361809283, 0.047300288642873056, 0.007808863010723144, 0.0469106240052497, 0.04777271758939605, 0.06617009465117007, 0.05031799468270037, 0.04280029475921765, 0.08223463810281828, 0.019574618090700824, 0.0687868776731193, 0.07161754765547812, 0.10722887309384532, 0.08792054315563291, 0.0006778491035674961, 0.05181022730539553, 0.0752515479689464, 0.018314894768991508, 0.0369582307030214, 0.053667655956815, 0.06204928256920539, 0.024475406971760094, 0.018696377228479832, 0.022294954833341762, 0.04124342478462495, 0.03443863934080582, 0.026502036016609054, 0.1095020046341233, 0.04844064678763971, 0.061858494955231436, 0.05483747365360614, 0.05499125778442249, 0.0718003608926665, 0.02855953098332975, 0.02505985012248857, 0.016527465486433357, 0.07189937081420794, 0.016694719597580843, 0.027216184316785075, 0.018913351523224264, 0.02893026714446023, 0.05580780947639141, 0.03967703305534087, 0.04947199828166049, 0.025736837233125698, 0.008127912296913564, 0.03356699802679941, 0.0388528557959944, 0.0701469300838653, 0.03656853637949098, 0.03472665943263564, 0.02829162865964463, 0.05260097452264745, 0.022639927337877452, 0.023941659928823356, 0.05974905150651466, 0.062421699694823474, 0.01954424940777244, 0.04668572357331868, 0.003839153123408323, 0.02904131841205526, 0.014189264293236192, 0.013325365434866399, 0.042236370136379264, 0.016072770158643834, 0.03538357515935786, 0.05464327958179638, 0.03019981650140835, 0.05045431236794684, 0.07069217856042087, 0.011962762819166528, 0.023739664029562846, 0.005001851768611232, 0.046761051562498324, 0.02308505823748419, 0.011776162773458054, 0.035283144025015645, 0.033748237910913303, 0.02233845581940841, 0.02660767517227214, 0.020295089489081874, 0.058047707643709145, 0.028062967394362204, 0.034589447459438816, 0.04457265844393987, 0.03200064711563755, 0.008946889884100528, 0.056861321500036865, 0.020796165335923433, 0.06259492438402958, 0.034762534851324745, 0.041688290366437286, 0.03967360804381315, 0.036262816065573134, 0.08498197232256643, 0.08861510432325304, 0.014555536436091643, 0.029658122912223917, 0.045097839247318916, 0.021078782592667267, 0.025431718058825936, 0.03775123775994871, 0.012482250422181096, 0.09574748488375917, 0.08387082882109098, 0.046313818529597484, 0.0644486237433739, 0.016068296863522846, 0.04413926275447011, 0.05675485670508351, 0.0683073241089005, 0.06055599238607101, 0.05781528554507531, 0.07167866351664998, 0.054874799971003085, 0.06692127426504157, 0.016776747324911412, 0.021963264916848857, 0.04071984330948908, 0.049000374565366656, 0.05658927984768525, 0.07086618992616422, 0.043958961687167175, 0.026744540191430133, 0.020694834347523283, 0.03466076414042618, 0.06511701678391546, 0.014447990888584172, 0.05157819854503032, 0.028622077334148344, 0.06864473412861116, 0.03779299098823685, 0.01836072053265525, 0.017002755412249826, 0.15477949928026646, 0.03683086331875529, 0.055365192602039315, 0.01591733845998533, 0.07956061323056929, 0.016617764449620154, 0.015383696245407918, 0.02929061509348685, 0.06547741111717187, 0.020120827648497652, 0.040693226183066145, 0.04273005419236142, 0.027611055120360106, 0.04282677087758202, 0.06603536516195163, 0.03810776921454817, 0.024869717453839257, 0.05418283260951284, 0.07583870552480221, 0.09295688345446251, 0.018286318372702226, 0.0170563644496724, 0.0372495978808729, 0.02489136404619785, 0.057595056932768784, 0.03974912528065033, 0.10109833252499811, 0.056550695589976385, 0.022987128140812274, 0.02686994273972232, 0.028228301198396366, 0.03575259695935529, 0.011059483749704668, 0.018424970112391748, 0.05680350819602609, 0.00976632853053161, 0.03912403655704111, 0.03213127623894252, 0.1201622435473837, 0.03980204040999524, 0.043568406472331844, 0.056001925622695126, 0.06492175030871294, 0.07426818003295921, 0.023835178435547277, 0.0252499568159692, 0.02645514341566013, 0.012538091468741186, 0.037434696932905354, 0.011437602424848592, 0.04686828819103539, 0.05112047525472008, 0.016715388410375454, 0.03325223093270324, 0.10433704272145405, 0.016761397855589166, 0.06359666047501378, 0.0711608151323162, 0.008867000469763298, 0.08725806503207423, 0.05653377091221046, 0.04946450259012636, 0.05996311658236664, 0.05826731285196729, 0.03143809546600096, 0.04015448263089638, 0.06917215621797368, 0.04816635642782785, 0.01563801633892581, 0.032400456912000664, 0.041785430075833574, 0.02499650596291758, 0.044430752386688255, 0.05137924359587487, 0.09963673946913332, 0.05043874210969079, 0.058665482501965016, 0.030465173258562572, 0.08666288485983387, 0.02091604816087056, 0.018929162979475223, 0.02810108595440397, 0.05631913067190908, 0.021655188284057658, 0.06194916684762575, 0.030194061146175954, 0.04157237803156022, 0.04288692194677424, 0.08198805953725241, 0.07437972482875921, 0.01884062476165127, 0.06036846280039754, 0.10018201021011919, 0.04178114788373932, 0.02599365372589091, 0.06717081399983726, 0.059966315238852985, 0.03469935210887343, 0.03262618112785276, 0.021150470347492956, 0.03701796245877631, 0.06513601576443762, 0.06797102731070481, 0.033185033171321265, 0.01174307875771774, 0.04130420296860393, 0.04559939006867353, 0.036115091570536606, 0.02931326915131649, 0.03957074266509153, 0.036252110585337505, 0.061799438553862274, 0.019524870076566003, 0.02796672568365466, 0.02550493649323471, 0.05741351647884585, 0.021013529258198105, 0.03766765337786637, 0.03337116380862426, 0.014513781352434307, 0.03018372673977865, 0.019343990134075284, 0.025223039119737223, 0.028186846684548073, 0.07616142102051526, 0.0225318910452188, 0.036193124687997624, 0.07643781165825203, 0.06395272066583857, 0.04434366135683376, 0.012489017881307518, 0.04617555270669982, 0.02361675138672581, 0.0300082533431123, 0.026811585812538397, 0.044983667248743586, 0.040119965342455544, 0.0271886246628128, 0.03701305315189529, 0.0322515672451118, 0.029088554256304633, 0.04513218213105574, 0.006718330805597361, 0.00870813262736192, 0.00696198809237103, 0.02521361384424381, 0.039448956231353804, 0.012823279339500004, 0.02317044974915916, 0.04422892532602418, 0.024793046177364886, 0.05135872321261559, 0.08530627601430751, 0.026136049600609113, 0.022879427669977304, 0.046750494511798024, 0.04694797258707695, 0.07678147798287682, 0.033002557611325756, 0.010499609397811582, 0.035816343734040856, 0.026407176555949263, 0.0550440838560462, 0.0402045627561165, 0.022343721357174218, 0.028401288400345948, 0.028184727852931246, 0.06699997160467319, 0.0338321636809269, 0.03645611213869415, 0.008739299119042698, 0.03198798236553557, 0.0856474635656923, 0.06822490118793212, 0.023757957969792187, 0.021346269313653465, 0.018373693274043035, 0.04613085315213539, 0.03742046625120565, 0.026695482374634594, 0.030796733299212065, 0.057789273269008845, 0.08641258071293123, 0.14563395408913493, 0.16094711754703894, 0.1482910951017402, 0.14617742883274332, 0.19883714063325897, 0.1810279267374426, 0.17962431767955422, 0.28280267491936684, 0.1587228267453611, 0.06600300010177307, 0.18678115942748263, 0.09496501632384025, 0.23096266522770748, 0.11058869436965324, 0.13680388103239238, 0.10033840299001895, 0.11307382781524211, 0.16018706926843151, 0.07432084283209406, 0.2389915008097887, 0.16100522771012038, 0.1677759745507501, 0.09213545214151964, 0.10636398161295801, 0.14085416682064533, 0.14449400041485205, 0.20813693379750475, 0.1330200707889162, 0.18820844299625605, 0.15410706895636395, 0.12596199405379593, 0.22975404805038124, 0.23131175665184855, 0.11505922870128416, 0.2286962204379961, 0.15555358899291605, 0.18627617246238515, 0.16033959545893595, 0.15154636261286214, 0.13211821293225512, 0.18449972325470299, 0.1396725044469349, 0.11612852991675027, 0.174391538312193, 0.19087460852460936, 0.1146944853826426, 0.12273900996660814, 0.22602621058467776, 0.2656640508212149, 0.19909122231183574, 0.13977527705719694, 0.159557000733912, 0.23706078878603876, 0.1523647882277146, 0.07170392622356303, 0.15200817142613232, 0.11146710035973229, 0.07369105631369166, 0.10253602842567489, 0.07794775563525036, 0.12616421445272863, 0.15023871324956417, 0.25650060502812266, 0.1814708553138189, 0.20920035720337182, 0.1540085711167194, 0.16307810554280877, 0.22239790996536613, 0.12786150618921965, 0.13280012790346518, 0.08835518936393782, 0.0792834952881094, 0.10550633349339478, 0.08731572248507291, 0.19020205945707858, 0.22939806949580088, 0.13352922862395644, 0.13041157013503835, 0.12032065496896394, 0.07601979697938077, 0.13590521441074088, 0.20273104106308892, 0.14283020922448486, 0.10783197940327227, 0.14712470612721518, 0.14302894152933732, 0.1437946895021014, 0.16492492519319057, 0.10835224718903191, 0.18694463971769437, 0.112079906539293, 0.07306377083295956, 0.056486922840122133, 0.11395891313441098, 0.15346836182288826, 0.27891759120393544, 0.14174597599776462, 0.08700811711605638, 0.1051808794727549, 0.1883148669730872, 0.11120144117739983, 0.16714310069801286, 0.172641969693359, 0.11192781079444103, 0.24624005716759712, 0.07743966649286449, 0.12460240919608623, 0.09594876275514252, 0.12874521111370996, 0.1733262001653202, 0.09137410510447808, 0.12240059062605724, 0.20543078135233372, 0.16484005318488926, 0.1137446476786863, 0.11675927380565554, 0.1575674067134969, 0.23457115050405264, 0.1128438585146796, 0.08704672363819554, 0.16549873893382028, 0.14999114762758836, 0.17762382893124595, 0.14424189284909517, 0.2130091332946904, 0.07076756592141464, 0.1478505413979292, 0.11079913776484318, 0.1597993416362442, 0.1789210140123032, 0.18198550504166633, 0.10529428705922328, 0.1468773334636353, 0.10184212776948698, 0.13318451587110758, 0.16848215775098652, 0.08921707514673471, 0.056337279893341474, 0.166186353599187, 0.17887832567794248, 0.14689088508021086, 0.11442715636803769, 0.08580317356972955, 0.14239919953979552, 0.08685329026775435, 0.13141406321665272, 0.15864506451180205, 0.15288910071831197, 0.2598126616794616, 0.11438377783633769, 0.26999893540050834, 0.10068941657664254, 0.13646768813487142, 0.09681794384960085, 0.17973369540413842, 0.1474386197514832, 0.1472636658581905, 0.10616474464768544, 0.0926105231337715, 0.20082910952623934, 0.14774879295146093, 0.10839522496098652, 0.16384665883379057, 0.12230737687787041, 0.0997786974767223, 0.18271797511260957, 0.1749592219130136, 0.10391717267339118, 0.15003705688286573, 0.20226166234351695, 0.1692701256251894, 0.09701585237053223, 0.11674166264128871, 0.1621858956059441, 0.13368024083320051], [0.026267105458828155, 0.01666903572186129, 0.04529980360530317, 0.02432227036479162, 0.0596421896625543, 0.027697405857907142, 0.017040775637724437, 0.030438287103606854, 0.058919026123476215, 0.05658811467583291, 0.013049063854850829, 0.046689330411027186, 0.050662944922805764, 0.040426884224871174, 0.028525030393211637, 0.06628883085795678, 0.01598607803316554, 0.04427458225109149, 0.04531969687377568, 0.08368185575818643, 0.045087256221449934, 0.04147994353843387, 0.010158445966226282, 0.03179988132615108, 0.02312197637365898, 0.011984530938207172, 0.03691284466185607, 0.019440825562924147, 0.02548471853515366, 0.04027553433843423, 0.07652429412701167, 0.047541230596834794, 0.0771976966643706, 0.030180633839336224, 0.053596825382555835, 0.04339246552262921, 0.012327348431426799, 0.020681933965533972, 0.03341860188811552, 0.037803585146320984, 0.03393446502741426, 0.05345575053070206, 0.026991532504325733, 0.03217538207536563, 0.023316194565268233, 0.04926258647174109, 0.011206199851585552, 0.07718438253505155, 0.023918983606563415, 0.041839068799163215, 0.02214407064457191, 0.02404643819318153, 0.06441731253289618, 0.00178955078126819, 0.09715663036331534, 0.03294687056040857, 0.030695426430611406, 0.050350738238194026, 0.018007998151006177, 0.07912233792012557, 0.01637412849959219, 0.02841342065948993, 0.0593497389490949, 0.03109532528469572, 0.03895827416272368, 0.016085058268799912, 0.059111197842867114, 0.01686907791736303, 0.07458518841303885, 0.02840570788976038, 0.06097048557421658, 0.06583253620192409, 0.07503796528908424, 0.15855199919315055, 0.045943223376525566, 0.04635796518414281, 0.021873110672459006, 0.02112096070050029, 0.005541895934584318, 0.03794179159740452, 0.03310530795715749, 0.034508553362684324, 0.03569158128811978, 0.01733619865262881, 0.0019017759177586413, 0.04828253593586851, 0.04324587651353795, 0.04575484032102395, 0.029322308510018047, 0.011397129401302664, 0.03786542460147757, 0.0204193546960596, 0.024567468535678927, 0.03189545139321126, 0.015723647193226498, 0.027395249708206393, 0.012715724515146576, 0.1174041630292777, 0.014445746819546912, 0.09662206139182672, 0.07014474074821919, 0.0451152834284585, 0.050649623372009955, 0.07256505501572974, 0.03232565213693306, 0.027300970978103578, 0.00803006569185527, 0.017861761662061326, 0.05672533035976812, 0.04811012760910671, 0.046107727830531076, 0.06391827017068863, 0.0152821370465972, 0.04778200927830767, 0.02560680924943881, 0.012628201184270438, 0.009528810660413, 0.012966845024493523, 0.03154159538098611, 0.04539290974207688, 0.04125841245695483, 0.022222840343602, 0.061142155464040115, 0.038931950184633024, 0.05009275657357648, 0.024406175725744106, 0.014682712717331015, 0.02132740948582068, 0.03268814674811438, 0.01646159988013096, 0.015555201935057994, 0.03549504945112858, 0.08108907379209995, 0.04646926507120952, 0.028546075845952146, 0.043618946729111485, 0.03418041276745498, 0.031488513268413953, 0.05630946790915914, 0.07986712022102438, 0.07453120459103957, 0.04025236448796932, 0.13441487797535956, 0.10592677499516867, 0.006164941432871274, 0.01564415761095006, 0.0296714722935576, 0.02795910753775388, 0.015940178054734133, 0.0698256617761217, 0.03461845059064217, 0.09653626169892959, 0.03866030558128841, 0.064862734725466, 0.03515853371936828, 0.04597955150529742, 0.004569867551253992, 0.05399222682171967, 0.02654531806911109, 0.014117031059868168, 0.015222248512145597, 0.024955901208159048, 0.052621391005232, 0.04254718900483567, 0.05803856438433286, 0.027884087539860047, 0.10158658405998722, 0.06904593174112961, 0.028338087104202714, 0.01946077449247241, 0.018794431634887587, 0.05073977205029223, 0.018622732059156988, 0.0778941206226591, 0.035850274725817144, 0.08096258956356905, 0.015643625119992066, 0.034227008509333245, 0.09801395935937762, 0.05336941649147775, 0.05674060004821513, 0.053015233934274875, 0.004322150716689066, 0.01635634107515216, 0.03982839778473135, 0.09591447553248145, 0.05445089263957925, 0.03630866594903637, 0.05774318960902747, 0.02620611947349971, 0.06598631662200205, 0.029288900732353795, 0.010177160147577524, 0.015513627749896841, 0.06048957016901113, 0.024399602152698208, 0.012238051367603475, 0.02156015812943224, 0.02066041353828041, 0.031237381626851857, 0.013615956140711205, 0.038696422197972424, 0.013266028872749303, 0.027428763241914567, 0.053660583289456554, 0.05124281087773852, 0.02895167996030068, 0.01644223910261644, 0.0446291544358246, 0.048100205094669946, 0.06034203492163215, 0.04056117213622201, 0.0037879379760852316, 0.045682573691010475, 0.02689750981517136, 0.051950504348496906, 0.0263996437570313, 0.023160376949817874, 0.029053623220534064, 0.030008535359229427, 0.010812328164320206, 0.007833372437744401, 0.070519963192055, 0.03809336783888284, 0.03342825351865031, 0.07557899094535969, 0.0532299743645126, 0.004217051009618444, 0.03431418117543217, 0.003647031498985598, 0.010873585961235221, 0.10149126261239871, 0.031981674110284075, 0.012649136242544046, 0.009882652757369215, 0.026692430292314384, 0.022482003878394607, 0.04711285924713593, 0.050044286908814684, 0.02439333842630731, 0.03196304249286186, 0.01686534862528788, 0.04787815450981725, 0.013198976757848868, 0.06974710544454865, 0.051824921829393134, 0.032541038235649467, 0.09303672370151617, 0.028215484308020677, 0.023812511390133295, 0.044883573791594245, 0.05669357757142279, 0.039812875766074285, 0.06363633568980731, 0.0408958102343604, 0.0061999800800549565, 0.060253392803133465, 0.03230443784559611, 0.04883803347183857, 0.0559482163953362, 0.014807692241447512, 0.0680544001806993, 0.020590096901287325, 0.02607460719445953, 0.05530833666853141, 0.052414008969208226, 0.04123812585021369, 0.06113209936302155, 0.0072880798961705295, 0.0192376644918113, 0.028883350423711818, 0.015949703520163894, 0.0353938798798481, 0.05282934078422841, 0.011355142396496376, 0.023670191585551947, 0.08253866632003337, 0.037419412401504815, 0.03761870502785314, 0.04739360258099623, 0.04913241005851887, 0.028292975657677744, 0.012333610302448506, 0.04960486869094893, 0.04205599856504705, 0.056759291037451476, 0.0220099534271867, 0.0343066929053748, 0.027690262686519418, 0.08827883721096441, 0.005852592812516377, 0.09562374660163186, 0.056583535624668, 0.0029047868792986264, 0.021506168741325382, 0.03246082320401911, 0.07100055576302111, 0.029731328359048348, 0.057703514394233935, 0.03248686145525426, 0.024352540713152848, 0.03897112073900644, 0.035904522010241635, 0.045091779611539096, 0.02652336534083588, 0.06320629079709761, 0.018690241522563156, 0.013394980742305052, 0.06568723852979019, 0.0741025252500549, 0.06133425667940173, 0.042822425602935255, 0.04080084872839507, 0.039670038313488476, 0.061040240034344606, 0.02545435356296366, 0.017888280453917105, 0.07567040127469227, 0.02046795423666481, 0.0428696670132922, 0.08363400949747302, 0.04625337060133461, 0.07822852494427934, 0.045632801557076164, 0.02360445028898539, 0.03317296956083737, 0.017308399656030815, 0.04816390362975653, 0.036374409100972116, 0.0211017706169514, 0.023141845522332005, 0.07264545187354088, 0.02394414241280174, 0.01827234558732016, 0.028045205945090856, 0.006455144366555032, 0.04727448045741767, 0.024894620219129138, 0.04066757384862285, 0.010429892972751986, 0.039256751115317456, 0.0547533141070744, 0.04877332932665013, 0.03408616001252085, 0.10859806134249084, 0.025758962510735728, 0.033780165103962645, 0.014074559803702869, 0.015347529533755733, 0.043983255891362205, 0.023632143529539462, 0.09141669695964083, 0.120427494548494, 0.12555934925330803, 0.23344777640886605, 0.17430467734811828, 0.13112820277456194, 0.16316616878611967, 0.09111645369557664, 0.17285431298660114, 0.09380597461131401, 0.17300980776781216, 0.13739639689447358, 0.10158908509765752, 0.16273336310405284, 0.07828771864296868, 0.18027427577180788, 0.11701626470312476, 0.10945347559754737, 0.18742329528322443, 0.195382205711212, 0.18150644871639088, 0.11928246458410285, 0.10565865930402651, 0.09964548939024098, 0.14763089537154883, 0.1636952013359405, 0.10374106102972291, 0.11163846225827001, 0.08601986584835686, 0.23091101174941286, 0.20697844127425924, 0.12936589890159667, 0.13115628564264625, 0.1544613257283345, 0.15131389227462932, 0.18414318066788837, 0.09747600619448349, 0.09345234866486862, 0.0840957069885917, 0.09427055163541809, 0.10535947731113993, 0.1232064665236976, 0.18568469560705125, 0.15580321778543293, 0.17883882857859135, 0.17868293303763494, 0.10812733933562413, 0.17241236404515803, 0.09206120026647113, 0.14249648025725037, 0.18768574838759378, 0.19223622686695307, 0.13044510036706924, 0.20431310695130378, 0.11933797723031603, 0.22476815152913332, 0.2636870287824422, 0.1566457186709158, 0.09999719317420386, 0.14287350611994043, 0.14126406982541084, 0.10095056350110099, 0.12779046781361103, 0.09840785423875786, 0.09844844229519367, 0.09019930017529987, 0.15264297486282885, 0.1514701737323776, 0.17182214884087443, 0.20844943734118715, 0.18981207569595426, 0.13031964772380888, 0.22854563867440447, 0.1637635679799132, 0.25595197977963835, 0.132536398305092, 0.16434624296380207, 0.1802681604749523, 0.12540679337689653, 0.1419105546665378, 0.10873753315536305, 0.16694199352059513, 0.09037188661750406, 0.17501575872302055, 0.14734087890246883, 0.10215153655735776, 0.18930622783955187, 0.15964616235578433, 0.2299953202600591, 0.19047853915253654, 0.10026424017269164, 0.20657229353673756, 0.1947085137362592, 0.11139009511680342, 0.07933527493150905, 0.1159288921917323, 0.11493286321638152, 0.10447486696648411, 0.19594608951592818, 0.08185752318240702, 0.28952875931281596, 0.12373728022794239, 0.09934202520526014, 0.16907649929635227, 0.1242069854924921, 0.17359462013700977, 0.11861353719723411, 0.12285679622436874, 0.24669570615515113, 0.11583471365156583, 0.15253396821208298, 0.07311547626159154, 0.09497887964244, 0.12706838781014085, 0.1864912171731703, 0.13030611095018685, 0.10324689457775094, 0.12052231133566238, 0.10116691439179704, 0.19956159550929442, 0.1549636261188425, 0.17582756438059732, 0.17405381659045815, 0.21889853524044156, 0.1591238091350533, 0.11720873328158632, 0.10074759353301488, 0.10628143994836137, 0.08530817591235973, 0.14861698698950931, 0.11037048810976557, 0.13034361909376457, 0.07199205021606758, 0.19959405704867095, 0.15660412871511653, 0.09961366609786637, 0.09958336420822889, 0.1469629179337062, 0.24963891541119665, 0.13129613595083356, 0.19985842489404604, 0.1882735441904515, 0.09840256272582337, 0.19814477622276172, 0.17565595015184954, 0.14414912438951433, 0.14046997181139886, 0.24386460572713986, 0.14189954119501635, 0.11507646137033589, 0.10800755670061335, 0.07008600718108937, 0.14134070399450138, 0.10106328831170686, 0.14683431858429685, 0.08626146460301243, 0.17091413115849718, 0.09774897553143091, 0.17435238260077313, 0.2098196349106729, 0.09219274594215676, 0.1575123393558897, 0.16346667922334746, 0.16612990584690124, 0.1483221910893917, 0.16429525741841644, 0.1313566358294338, 0.1865873549832031, 0.09256724850274622, 0.1489005913026631, 0.1505474912119098, 0.12433973344741389, 0.07761865766951814, 0.12435339638614096, 0.14837556635029614, 0.12532771012047306, 0.22738760628271848], [0.08736293049878441, 0.016571452579228207, 0.03719106469361577, 0.00687153049511835, 0.046724400599487126, 0.012146517656219658, 0.021048918570159003, 0.0393301977601368, 0.034631196976988576, 0.013624560415337328, 0.08703423329279758, 0.010344298298150534, 0.024832233430061024, 0.10136929064174183, 0.03757410937396344, 0.05453026533359662, 0.026124379328393843, 0.04082132829353213, 0.02993165257066721, 0.02190456845710287, 0.01459869881728082, 0.05889957072213292, 0.03517921366437804, 0.01576794598804554, 0.03143757225188892, 0.041422672002227046, 0.059651926640071906, 0.014518072821374517, 0.050763428007485345, 0.07466345530701801, 0.051164885371690616, 0.04620037754648365, 0.05523398089280818, 0.021414472685137298, 0.050792783658835106, 0.020969529177818913, 0.03824235769570805, 0.025849491539702285, 0.11622835620073602, 0.017180596260004677, 0.025237171466869768, 0.041111185200861655, 0.01958638855285244, 0.01915754037327133, 0.05555813244427554, 0.0809112552087754, 0.06567759060999379, 0.01673480113822734, 0.05492141055583488, 0.04861381952650845, 0.09789482239284553, 0.04349165355961304, 0.07693490217207, 0.02998446379933739, 0.025578557542758062, 0.08528364793164656, 0.060828727946500294, 0.06487357008154504, 0.03289651212980971, 0.02468047350703273, 0.01915620636282256, 0.04003536050731782, 0.013043802955508, 0.09150444107945077, 0.013139092861820245, 0.06842675051302649, 0.03649357575341128, 0.018421110944473185, 0.03812808179645799, 0.05946851226326544, 0.013773145801678766, 0.014722384221386164, 0.013994799337524455, 0.014155823118926492, 0.03961359427194111, 0.03652053426776547, 0.030386685575649608, 0.020751560405187774, 0.05006515610148199, 0.028355659305816516, 0.010712939747463679, 0.06858841996290721, 0.008643721630505752, 0.015201672467810567, 0.04180541240202729, 0.06157751784485299, 0.017095338334911503, 0.04619689687388018, 0.031560308634652756, 0.044494257963378914, 0.010865864842344308, 0.12544642406282946, 0.04561761721561197, 0.052883376556565054, 0.05462659610202536, 0.04968194814864546, 0.03373049315996468, 0.047365367572638206, 0.02648275130923139, 0.059802578907692805, 0.05388955811213236, 0.031162810628302395, 0.025858477092697285, 0.06492375410743989, 0.01237022879649885, 0.021634434124280233, 0.02312149397766916, 0.010284741874784231, 0.056769618022372015, 0.06367330206558108, 0.044763390396838076, 0.04362857980595436, 0.021422458194138017, 0.05666219585691579, 0.039224686624947935, 0.07894090507761575, 0.015571853873552755, 0.0026865537165576825, 0.07937762929941528, 0.0689607257663738, 0.04862897789280396, 0.022306951650534756, 0.04453733592526987, 0.044089360744692385, 0.06799934024456888, 0.15150653896853328, 0.01229976744070882, 0.08016072868485935, 0.02703159178054193, 0.025824037729762495, 0.017959806791623123, 0.03078540070418967, 0.06513945932965726, 0.06692239490803331, 0.01352934843453113, 0.025184978076140396, 0.00422391958636581, 0.005424156988738105, 0.014854027303954354, 0.014511502031382406, 0.05401569724199362, 0.04189896753814537, 0.017945329345820937, 0.018752580072032288, 0.05602760022156872, 0.07543131840066053, 0.045173909384175204, 0.03516243741614744, 0.08207979641156271, 0.049772427082643844, 0.11948836603551172, 0.09308517110184766, 0.07208826966234483, 0.028419051704986487, 0.037135147576918826, 0.02614356199046597, 0.041827020031632856, 0.036507286931737326, 0.02975187100673793, 0.02924666325270664, 0.04628250731911976, 0.02273992617119802, 0.046109701943350956, 0.10085174653795548, 0.01758724123646971, 0.07812281342921779, 0.03308627929072827, 0.05090002770884894, 0.059463918369146995, 0.06487184829893522, 0.01943317402037792, 0.025152900598186534, 0.05713673250284046, 0.09129981612204574, 0.04515148910286371, 0.034426249185344204, 0.03150387201458216, 0.03546451007423457, 0.09299421348259784, 0.06409687543055043, 0.05725209564843681, 0.05011528075556271, 0.02012453096540412, 0.04425643302965909, 0.008017629152163863, 0.043289511086186394, 0.08438847682555206, 0.08591882244218141, 0.03152975070406683, 0.08163057442288846, 0.05418924105470069, 0.03329914208734408, 0.024905759855755605, 0.010685091583582107, 0.08275091313407756, 0.04993830822058953, 0.009887393225653796, 0.04163571291428525, 0.01744767665513791, 0.021068863788968883, 0.05293996902764775, 0.05667988494678866, 0.025988291708927136, 0.04839002860535402, 0.04544459290627856, 0.03876284070429392, 0.012745173862640513, 0.006433078460759134, 0.025404529478691984, 0.024487884329573717, 0.030142329742375296, 0.022012712361174636, 0.018967669311678037, 0.020104845498281065, 0.06052101125533227, 0.04017127001134213, 0.06825532924267463, 0.022250533584156074, 0.02445056728902273, 0.018831769084499683, 0.03839028257061727, 0.0643695033795666, 0.007901181543275015, 0.06975653072004206, 0.09395831526489928, 0.04899777333776001, 0.032934183545876294, 0.024578942138759885, 0.05699710854969453, 0.03431181743508205, 0.04863356065470725, 0.031004905722511467, 0.05410568635852542, 0.06652674856013618, 0.04535493404546287, 0.016360688205168117, 0.02022081349423388, 0.04251184422173537, 0.061929277289891616, 0.035688067218870856, 0.01726263883028878, 0.04130408793571405, 0.040285571885760874, 0.03096995613304898, 0.02426735700282734, 0.09122667746851221, 0.042183191544609144, 0.02827465759764891, 0.018834620786947198, 0.1023744851408992, 0.019490273007249925, 0.06337977523799054, 0.030888459041307215, 0.030599785859521944, 0.018644347110239323, 0.05533798917895183, 0.035941176683991216, 0.07348583763814531, 0.025363679815200157, 0.012395428420859389, 0.015049551675474504, 0.08020745430258103, 0.012489968758018222, 0.046993655487312935, 0.02896863989008125, 0.006500195513581275, 0.06056330996216275, 0.12767941283527762, 0.07299743767362088, 0.021244665585982148, 0.08200887677958235, 0.03688026808958966, 0.008934306770242983, 0.041822704442893155, 0.029164652223698795, 0.07526383793447167, 0.047124718767008744, 0.05627312493743375, 0.02164863883081125, 0.0707371230237186, 0.02783032821753295, 0.012594002091645962, 0.05682878945663106, 0.035357666783966124, 0.029149367692298256, 0.051245419526821934, 0.05975840627797879, 0.016581206255068537, 0.018243899066874292, 0.03495937096886337, 0.06418949546059594, 0.05400613837991841, 0.09969325401470996, 0.026836371689569205, 0.06890703880344518, 0.05154918057087343, 0.038691754089086317, 0.03198885067831725, 0.06585811061086133, 0.12812910979846492, 0.034453827393008396, 0.030914053859305568, 0.05447824820294045, 0.015850380041229073, 0.011828674360003788, 0.019480233604554087, 0.012856711236963747, 0.019151608757965732, 0.06702412851154804, 0.02519980804208899, 0.06293009311775677, 0.01533722110252711, 0.04756397000164725, 0.016112272824102547, 0.0307945124222897, 0.06649577131611295, 0.07684027834329754, 0.017585252280696295, 0.07198362683993764, 0.00789468496805057, 0.08515366818755865, 0.08550645550712943, 0.08298388071125373, 0.028245982866792474, 0.02617311431095004, 0.019221465263399296, 0.07456613748217933, 0.07424190800520591, 0.04451944274478592, 0.030616096410085447, 0.047362565965158865, 0.00937649227125803, 0.025216469257429708, 0.02020207241002936, 0.08744708262383938, 0.05254102012258954, 0.07091952065820806, 0.039417867665179074, 0.04089276371814776, 0.07217809921712615, 0.013579397018474992, 0.08801988704362884, 0.00911553273908794, 0.031316457461798564, 0.04616372287273407, 0.03291049419203773, 0.058989533863496035, 0.008784820602159016, 0.025014805469254497, 0.08049722586292773, 0.04564756287436467, 0.057262789996457286, 0.28660155076067895, 0.1931401775800623, 0.16666793322656304, 0.18047324556391686, 0.09354578505735844, 0.1155991040286608, 0.12030347425024956, 0.1675608110963367, 0.12696873222012073, 0.10413364972919226, 0.24547984561650082, 0.23386792105156928, 0.122984571789857, 0.16049350204411894, 0.11019855475751683, 0.21320908272173256, 0.14840911142528057, 0.10072141056298278, 0.1931128665455617, 0.13581001170678064, 0.08138966586557217, 0.1703505590558052, 0.10933941492112353, 0.10619298336678185, 0.07994757645064965, 0.15630268317181617, 0.1539124481496401, 0.11673393688397482, 0.17221060377778485, 0.1668515702476725, 0.1806622408912517, 0.11996345187071711, 0.12350649456493556, 0.1330469810636714, 0.13911528512835503, 0.11549818678759038, 0.15734137821709737, 0.11296485085040331, 0.2120579226175323, 0.13557418686104938, 0.19901776453480124, 0.12320367604843341, 0.14342046895762905, 0.1163615939731244, 0.15403123630676419, 0.17285829089814797, 0.10393293589004315, 0.14110953983617947, 0.20503753214143217, 0.07528052141424268, 0.1987756314338185, 0.16305532160913572, 0.16541413409868255, 0.1077218669524882, 0.14756367163499817, 0.1925326109630987, 0.19070263806497678, 0.19133439869619906, 0.10552408566582017, 0.09403353193192743, 0.1280870448681526, 0.16569338942645118, 0.14655984268756583, 0.1498164312215522, 0.08294421291793697, 0.11956829534028657, 0.15363397949840873, 0.0972920648928266, 0.17098310636356473, 0.1693294825963676, 0.11282436229521409, 0.16251285618636757, 0.08588242009864189, 0.21001137618441135, 0.19556906365323812, 0.2366715917014517, 0.12486214603995904, 0.08951911440817639, 0.1510357204824686, 0.11752475460525602, 0.1448687701486051, 0.3007825679378584, 0.054903777127037756, 0.08956860823673196, 0.13058613811153919, 0.17499287088867277, 0.06457595402025618, 0.13550859584938735, 0.11358061077771708, 0.22668465884635225, 0.11957336420891806, 0.2498862287029624, 0.22436201863456517, 0.1687104720622301, 0.13774155493592843, 0.10472480003954843, 0.1307394658215344, 0.15851769712753594, 0.17345419095363468, 0.22802332998253405, 0.17035639233654365, 0.10881923619308509, 0.16511184250703081, 0.18075811152812093, 0.13773011101875454, 0.07580363162560388, 0.13406554906396195, 0.14166117820423096, 0.2566932368790731, 0.10583019931800663, 0.11937954492168501, 0.12162171406089328, 0.042424586208653636, 0.09842178435064852, 0.23767687525833026, 0.16442603868199512, 0.14798650285229087, 0.1350454956991598, 0.2293887481209822, 0.16497643024194986, 0.16459195321658626, 0.12304237767239101, 0.14466797467321157, 0.2321322899661027, 0.26158568216487765, 0.2569256181595847, 0.12309538185945712, 0.13477202912326902, 0.13146662211511284, 0.07497662678360939, 0.09816201039939187, 0.07188929244875908, 0.14227454841602594, 0.19342551851877943, 0.24499856284819543, 0.11517134495079517, 0.11958986957324669, 0.20931899693096057, 0.10707298497436568, 0.12334937448031269, 0.14321614085929468, 0.11367283746949397, 0.13740589638473466, 0.08556642103940248, 0.17599744198378175, 0.14383589354110882, 0.22666215692879632, 0.08747705054702237, 0.2264871881925501, 0.16072376078227535, 0.23049692303175107, 0.24064335826551542, 0.17556757520651445, 0.08272303064586595, 0.1756609819130972, 0.1337029950809665, 0.10350534750614315, 0.07922872478957288, 0.16298722213832662, 0.209937755134888, 0.11085190446465276, 0.1861217018449679, 0.11134058644529432, 0.20266506413463503, 0.11169414559844881, 0.19332817842951044, 0.1493251443025656, 0.12647024646867067, 0.19897829712135717, 0.1736792249721475, 0.1456029323162511, 0.13949288986623287, 0.21285656257532537, 0.1906619980582036, 0.15325815591495484, 0.09854751158854924], [0.027324170514475554, 0.012743849129037699, 0.04641444262233563, 0.02009945565077942, 0.04242939532559831, 0.030896012249286287, 0.027074944337073248, 0.06900422304170206, 0.02286638813529862, 0.023096708100638352, 0.0662834280228708, 0.03457477519987151, 0.011516124432091601, 0.01455327752410085, 0.03139667249342892, 0.04319558858696837, 0.04377512428618502, 0.04393231858557556, 0.014969333860790357, 0.029768804961349815, 0.030276274410425685, 0.08899761465727352, 0.013198749475122895, 0.04463774479518179, 0.059293951708241366, 0.05531901988433674, 0.02327568257896928, 0.027471230787341483, 0.02144018068065634, 0.006608582934859442, 0.06358277489198372, 0.029712696741626132, 0.013230486492830096, 0.016716644495318178, 0.013077898147457745, 0.05034845613408834, 0.06428350330679677, 0.049164912416017614, 0.04224511263601016, 0.04312473945901729, 0.07681622533709742, 0.009663312866905471, 0.061991554612177424, 0.04019968313514255, 0.04098732075362932, 0.022855834795336705, 0.036577115606633015, 0.014343801703944337, 0.06798232279834338, 0.07412366903736256, 0.05353051077690907, 0.008263469280791469, 0.014561962507286808, 0.05545608342799824, 0.03510570393700618, 0.07867575055570342, 0.0556254007096868, 0.13996228342875838, 0.04453224108146969, 0.00984572905508685, 0.03712394485773984, 0.03514131218253169, 0.013677880942850607, 0.0345919299434172, 0.00831512925287825, 0.02494864114851225, 0.060284893261268735, 0.11799359155702405, 0.05212797783315182, 0.04821988011826761, 0.04471383348572999, 0.05529013178602327, 0.0367115037079202, 0.08333723206305876, 0.019745169192901812, 0.01253147986062686, 0.036315868492238224, 0.13825411180732772, 0.02020613752392819, 0.019295613237773068, 0.04312264660256915, 0.03948355886677746, 0.0450247414119076, 0.033918642438948154, 0.10814670938998461, 0.07440733272233047, 0.021063859858259093, 0.04099338038940914, 0.08218316273996606, 0.04382259205158334, 0.07923839497379959, 0.06757693205145188, 0.012234598525537876, 0.0711618986679241, 0.01904755408759229, 0.05068948041298427, 0.028388365753926337, 0.06880409549921751, 0.02023827808443457, 0.026125783842871897, 0.021913975178904366, 0.024343801924260333, 0.0513428523845505, 0.0719667058729101, 0.02013637378695421, 0.060321340133668855, 0.05594489899522159, 0.02367561297432985, 0.006995815183472587, 0.08470495085930452, 0.02717747203860199, 0.052529305321513675, 0.011864031203003833, 0.027404376269259956, 0.10114672055351548, 0.02662903232703684, 0.02541954498155974, 0.013330065085028764, 0.0520648396195611, 0.014309488506114576, 0.03932347390218638, 0.07315097318496555, 0.06784504032111727, 0.03991979327111039, 0.09652176755480468, 0.0057714153081178665, 0.02673644521564711, 0.0354960847471375, 0.07782319356920198, 0.020286482431401964, 0.03875752321619075, 0.004373698438939755, 0.03209085887647234, 0.024226260575233027, 0.08619557673227973, 0.05188164046558086, 0.0585693224275019, 0.06080401442886796, 0.03743816647329368, 0.14977855200413615, 0.06153510410513263, 0.02993440593854757, 0.032740267779445276, 0.051539681080612354, 0.043100575130665675, 0.02475913930538809, 0.05365115801396314, 0.05458942563564051, 0.05113411963975523, 0.01715852107736282, 0.044402947823982686, 0.061475398324546404, 0.011032383299607318, 0.06457545678131282, 0.03953826628276147, 0.03413263330003247, 0.11475597231765278, 0.019256405576015823, 0.06074589313357137, 0.0254665173633839, 0.03164630870742258, 0.021214938860794064, 0.028055712900822982, 0.02753232438408304, 0.04808813406270929, 0.03990790406533051, 0.023280784844246227, 0.04757168462674599, 0.01511657039372949, 0.05817651850520633, 0.016715412530174945, 0.046128611866151914, 0.03838247146632057, 0.04172665569058154, 0.06013276783050969, 0.011583764699025778, 0.043834863463416696, 0.02156025275326101, 0.07132800616091117, 0.031082753303053323, 0.12753972579957917, 0.03129423756035976, 0.03678061992104631, 0.01802598409994971, 0.051230576573289, 0.031520774427917786, 0.007984962594491662, 0.014655850682174787, 0.07760998196317814, 0.027167380685568787, 0.027873318977071904, 0.042718075928860344, 0.053193980202195235, 0.024116216773109045, 0.06251855738810264, 0.0036895704761263914, 0.030810893476882484, 0.05263808932795655, 0.040473854751326144, 0.030733602507098112, 0.004516291446634568, 0.034245506540173665, 0.05380884955229703, 0.08292568891192786, 0.06648609371040948, 0.007283792137968703, 0.05193560944462661, 0.0367548822396202, 0.065019914181903, 0.018000331765506417, 0.008363564593310002, 0.051497415770427324, 0.05780306237284094, 0.05710486468160525, 0.12993609096156433, 0.005698684835806489, 0.06851931859273463, 0.03322489021229558, 0.050736495468299836, 0.05708167256671004, 0.02872079967346508, 0.026509366580285132, 0.016816442948766053, 0.06341765445540659, 0.06593650366994552, 0.04288205716875382, 0.10024662900832482, 0.03911115287337452, 0.03523747967847157, 0.008907750871003373, 0.03872610439429991, 0.04704239974671509, 0.05910723106353544, 0.0604361726436764, 0.04940906415868085, 0.039665136428084224, 0.037988494950695895, 0.034092464557033964, 0.02696194678719621, 0.060659210284939036, 0.011735640582628548, 0.04222650699375663, 0.08214865287300199, 0.09630753920646384, 0.017635115327720996, 0.03950150770833716, 0.005802359619337949, 0.02801685404847376, 0.0549741253053071, 0.08141955215251073, 0.03745767753571272, 0.029747186199529096, 0.024584959101048298, 0.09575958189088851, 0.016583111719228327, 0.0685826683184132, 0.02836760973877972, 0.008963311756815528, 0.018075151383527555, 0.04790741739270743, 0.009022654812724795, 0.02028841572609963, 0.017342551436740905, 0.012043068763887277, 0.048572763917036355, 0.02168639373849146, 0.042586782583384775, 0.04302782610466238, 0.029141261584300082, 0.052204586027073674, 0.022586349841731135, 0.012060770841344493, 0.00875051297043683, 0.13705459336051717, 0.008783574721746845, 0.04240280788508244, 0.03389565441466402, 0.04644791719329078, 0.07727352189249359, 0.11146595003083348, 0.037654847619705833, 0.07103416020981967, 0.029723289044341072, 0.044776229551644064, 0.03554592367436271, 0.0017085029207919433, 0.04002194618806243, 0.03163038221828174, 0.010262629584758542, 0.03172817130689509, 0.059880749322474, 0.02861548706277972, 0.016361686393793207, 0.035919246220146306, 0.024669174308655784, 0.10285901109455153, 0.04787888552527875, 0.02762762913334882, 0.023488777296734042, 0.055134507128968835, 0.027521574374986812, 0.061047665221849456, 0.03472439959296025, 0.040560177658335306, 0.08348907547770068, 0.012229103849676903, 0.029829605409759097, 0.041638577604317106, 0.048128184062079526, 0.04210947030514944, 0.07471536111552268, 0.028142312257841695, 0.10402954125311226, 0.04596932471031323, 0.04505846089159604, 0.05149313357833307, 0.037137418548809364, 0.0348987449251581, 0.027508722232596483, 0.05450389682664536, 0.05794515396701172, 0.025361188054375816, 0.07474462399841286, 0.03938384761568159, 0.014414258421311388, 0.026344461366534233, 0.09827818619669415, 0.03828270455414895, 0.016412016993854195, 0.047178094027913176, 0.04059957827848848, 0.05609866086160764, 0.06196657763211988, 0.04261138477886561, 0.02713171677896753, 0.034664831109694205, 0.03360105518368073, 0.03460392676061019, 0.061548407102236524, 0.055292425022344105, 0.06750226457370445, 0.06340601757983677, 0.07884381731855683, 0.03559333948942367, 0.01186034458442009, 0.033118024657596834, 0.027285380310786422, 0.03682154194393661, 0.03375457956281025, 0.01957102052983828, 0.028069002910342533, 0.007457741812686436, 0.11791487195296213, 0.11615931420237757, 0.19064906984567642, 0.10440111975185573, 0.17316527286311612, 0.1612624857807532, 0.09854852090938948, 0.1930340356193483, 0.12908496632007882, 0.12635332852369174, 0.10160959805944003, 0.08458038879325613, 0.1281617346103303, 0.09031183202750981, 0.08643685636343434, 0.11085872480180115, 0.17454483633628115, 0.20139044034294784, 0.17249873519176617, 0.05714342296414543, 0.1081444309966173, 0.17657702963333577, 0.09063712277566083, 0.15669201384298503, 0.06918242754181847, 0.12052983671310358, 0.16344622563337907, 0.2075562922982499, 0.0911317567806691, 0.1018970318546053, 0.11476914543891326, 0.15993692097254097, 0.12079785592504777, 0.19177219161065295, 0.05442768568173051, 0.1291602200944908, 0.1504802526324056, 0.14339369226945564, 0.15228729316731915, 0.14309993537608534, 0.2159009117167443, 0.0975699991977308, 0.18836159259080887, 0.10605109957396053, 0.12030602723825723, 0.11106582853244618, 0.17116671369876713, 0.12638256914215162, 0.16510266956174746, 0.20018676586914808, 0.14846345147816464, 0.10435573742142878, 0.10672542979591526, 0.1358811985119246, 0.09195539227221161, 0.1447777680004947, 0.17688257183181122, 0.2652273414423689, 0.13740472379140556, 0.11365639889845625, 0.1501102326437831, 0.16094848309876397, 0.11436114233219996, 0.3765145823126659, 0.1789747306611389, 0.1405432217870839, 0.10834601314854808, 0.24276640528114513, 0.13532984215999022, 0.12177073731436394, 0.07697022098000161, 0.24238305632025003, 0.1834450868773274, 0.230042832554318, 0.14345198054797947, 0.09138555644312873, 0.10670576288248412, 0.28427948942407966, 0.10666651069186628, 0.09885390725685284, 0.09176293111522682, 0.1964051226968877, 0.1408180984435603, 0.13286675792187452, 0.1472368001122959, 0.1294208475155756, 0.14313138759462163, 0.20708900643512607, 0.16214077302720398, 0.14590305683668703, 0.14487023960100487, 0.14770675770705566, 0.08625661095720716, 0.12114690282032825, 0.12129275710321963, 0.1635979799902998, 0.13193620863603428, 0.25097840290982276, 0.14230251254048198, 0.10609380275127478, 0.16168038913747296, 0.08872048929333687, 0.09648604798712768, 0.19046204863116145, 0.2476092751021497, 0.2264753435156308, 0.12304343152209185, 0.16276184673188254, 0.048279582188115455, 0.07902059689513408, 0.059975588374072686, 0.1489170966669917, 0.11369134663254954, 0.09190959433908574, 0.132638695940841, 0.0852224430127535, 0.05928205508098472, 0.14867536432575434, 0.1277125719934702, 0.21639739366946742, 0.16188577108550817, 0.12818990653613582, 0.18901181785622612, 0.2660185005515814, 0.14477531891316175, 0.057120397832477465, 0.09223513741744682, 0.12136902019847184, 0.16608993377303705, 0.14261148346122354, 0.13563482032623142, 0.0989727399428375, 0.1806006277911365, 0.07596083334647119, 0.21496049186680466, 0.15338133758632466, 0.2508991118520498, 0.1301364114624448, 0.1584512006957084, 0.16196616052184254, 0.17186329350806773, 0.10911855919403024, 0.11506282811751589, 0.09529104179819115, 0.1416489772964269, 0.16331091726897284, 0.29357577965129167, 0.09511640702839941, 0.09565198532072827, 0.12091947908629663, 0.19015052472241223, 0.17543398862471804, 0.10108704445883632, 0.17564630223205313, 0.15426180674694479, 0.13629856752231717, 0.1259600347839296, 0.12826931633753702, 0.07910860818810761, 0.13798894244246185, 0.09625849808799103, 0.13202875445131212, 0.10551687941187993, 0.09953322471119463, 0.17254231410333887, 0.20830878551350906, 0.17057629069313407, 0.19616451842011884, 0.11315071431454271, 0.15342030033934861, 0.1350103475851938, 0.23794756620191038, 0.12417275764164515, 0.13142788200639188, 0.10291735132341273, 0.08960132210631855], [0.024234483571490273, 0.04922423599055037, 0.04259529130649753, 0.0069079397962923395, 0.017925439788086805, 0.05823166749905795, 0.03148339244944509, 0.026491762837395072, 0.020890288215014152, 0.020532858761725947, 0.077729571639793, 0.04941113475069869, 0.024282465274154674, 0.05729752250772435, 0.029292869367054664, 0.011027888667740626, 0.018477644043741748, 0.048881026086746715, 0.08349030002136715, 0.02530060097342357, 0.0319491346454015, 0.04937526675348636, 0.027368435912649147, 0.01478731564930058, 0.043946809018962085, 0.031038794040796347, 0.032880993821891025, 0.028342291370790917, 0.03977400207077153, 0.04662915336666629, 0.07037895513349213, 0.03921778465155512, 0.04984440798580181, 0.03899049821484368, 0.043102274648845196, 0.05075395820313133, 0.09222320368280634, 0.03168079630995635, 0.009000313384603942, 0.010520961914153304, 0.037104864240973257, 0.02210215785453329, 0.0406291862600483, 0.01982572746783262, 0.010363529199821642, 0.096973720646929, 0.08189736166968942, 0.02691100391530199, 0.05565064486290794, 0.04301569199014921, 0.04879388310655486, 0.026527916561462916, 0.04989055101759732, 0.020723317975352984, 0.0869407226855401, 0.051555666941567324, 0.08832007835735567, 0.06722366233589128, 0.03286753868451342, 0.039741818836773746, 0.03685794799821451, 0.01364594818369369, 0.0259970638944651, 0.016016838198993355, 0.0523078484548023, 0.05193320488615427, 0.03361643619427923, 0.011895228308276273, 0.0149984056406538, 0.0329400687769521, 0.13171378697734326, 0.03297409253718797, 0.03220585836970713, 0.04162281067692675, 0.0442908241529949, 0.055982540725381114, 0.04307972820242867, 0.06386571869370528, 0.0637731802999042, 0.03534834169840906, 0.017297131998930126, 0.0279658313957043, 0.02840842971636448, 0.023930687275424134, 0.057429164662607946, 0.0354241557943169, 0.02529679004510399, 0.044381522020557895, 0.0013200525063439272, 0.043292197660775855, 0.06988691864535213, 0.049322177219437435, 0.021858056206838228, 0.040013585894485004, 0.04720895623904653, 0.054856313072377816, 0.0845346724963747, 0.1072743147960864, 0.08416954326094128, 0.015356443655036855, 0.006919806273799622, 0.050452642535674386, 0.054134281308506615, 0.043780616178992204, 0.05127022581291385, 0.0620661664288491, 0.07983122995938174, 0.02026840185862966, 0.04984372149920091, 0.03128374359221198, 0.03587123297620565, 0.010508837076486088, 0.07040337921353057, 0.058863598824245855, 0.03529879963025451, 0.055004954119795, 0.018896796063927468, 0.03981702808232512, 0.015269427767634625, 0.011559998347365763, 0.02190367416915251, 0.06736628085491247, 0.04672231516451575, 0.022346257646859158, 0.055002787048579194, 0.06556738168001175, 0.03804358457273338, 0.04684584564529359, 0.0039106646181608085, 0.08947838534368202, 0.031234227499226108, 0.07996290922164917, 0.019345830660313368, 0.05198654303967487, 0.040329629482585005, 0.04659463607822545, 0.05143233312992379, 0.06195713380293455, 0.016748753514548298, 0.0069009390244900715, 0.024627040729683358, 0.08768579442403279, 0.040210763399954885, 0.12639618013054132, 0.04517928995483089, 0.08064804511377588, 0.023359380138572305, 0.015567221016681287, 0.03267365631472785, 0.013279989598231623, 0.06343982240650803, 0.05814822041429579, 0.08404279185924679, 0.02622327236167621, 0.04061472922330722, 0.03645433840574697, 0.0425320232170634, 0.05142880050698295, 0.03242212762415875, 0.05340228250133805, 0.03551013731339481, 0.015295700723072514, 0.038621680505457334, 0.048317394612240605, 0.029192998554208316, 0.02540651101298863, 0.055905001136125065, 0.043737686646636575, 0.047690725114080124, 0.028063275385648012, 0.04201968156849034, 0.026415362444822676, 0.007464010641342611, 0.08453043483314104, 0.021052757329016458, 0.025836960376182105, 0.040729847460170276, 0.06505426077637821, 0.025565419673512224, 0.01346102260868065, 0.028597174568858463, 0.03062556806980865, 0.04911534437269438, 0.08148270891979337, 0.03752285294467583, 0.059591196695691906, 0.03777041485591326, 0.00796312768216012, 0.05565418861806393, 0.029581874659925234, 0.08368615279323421, 0.02173787281208206, 0.01804231505957432, 0.03380153895705007, 0.032741759496275336, 0.07516412297263741, 0.02400938461505575, 0.029751984184258617, 0.04673050105338916, 0.03454938261711504, 0.045537301994045265, 0.012462705963116605, 0.05412472986790817, 0.05535843905818183, 0.05447631861898117, 0.03393082479306031, 0.08632456199848093, 0.06292319114436395, 0.07364439006778412, 0.05279925782815553, 0.015431269766850164, 0.03406308293051552, 0.03408323223993648, 0.060200065781828016, 0.01715907212201273, 0.054291108244797215, 0.02437649167404743, 0.022815693882876076, 0.0647446812945418, 0.02304726807778934, 0.010133913347090129, 0.10068373172543943, 0.05423859016445931, 0.022350166909745894, 0.013538261628127657, 0.10135421762242913, 0.04950789225404151, 0.0465647683449788, 0.17618996993405744, 0.02055509165074909, 0.017678184012765996, 0.0551352010370465, 0.0554115397244459, 0.09750797791639343, 0.07176556158810854, 0.017086916814150754, 0.024129174671543296, 0.020713796220661607, 0.01816192514525028, 0.02419500317046186, 0.030923690646886826, 0.032263816392514855, 0.012145223536208505, 0.026898784453806, 0.03175165657012258, 0.06307481933617964, 0.06017206083924975, 0.023912224496598355, 0.05600752141617704, 0.025809432263486087, 0.12458404846256599, 0.021366400069382507, 0.020909018167003524, 0.05244369116553571, 0.08040734435780905, 0.021109557601448614, 0.048546024336246774, 0.038194233129615895, 0.03753076794964727, 0.024890712811611593, 0.08076648446149193, 0.040743892604950815, 0.03736696482519619, 0.04906517147901468, 0.0533582286152523, 0.04097613658814225, 0.06036671875335742, 0.058746168797370046, 0.02135320653906092, 0.019476572961139027, 0.06182241173519287, 0.01372926168187405, 0.040475209170836024, 0.06007567069900688, 0.033859025716083124, 0.021430833330668975, 0.04605347312462982, 0.01704890215478372, 0.056605573699926026, 0.058365380245959386, 0.05574652292125393, 0.04350592505943496, 0.08677261881530285, 0.05737317704188172, 0.027850928381667472, 0.0812284713902045, 0.055679800134385005, 0.06090589646191802, 0.07542540348367766, 0.027739654469769448, 0.028416665700206067, 0.02138265124813188, 0.029258845606818795, 0.04966847445757594, 0.09039473734446801, 0.09126147677307017, 0.018184093096351717, 0.033815235292422585, 0.02044538367044879, 0.09194288708386011, 0.049493509432068095, 0.06021428904205095, 0.011631422639766242, 0.05549079738557339, 0.03446782429818995, 0.07481750290025957, 0.0345211513194954, 0.06881503475597128, 0.01892698106530588, 0.01309997147473041, 0.03500188860925846, 0.07614662259584293, 0.010125862900167704, 0.07395705688395537, 0.047219876942108385, 0.028498448518803343, 0.016638969464111142, 0.030323692080855835, 0.06694394687656313, 0.0338891754654469, 0.038551729376195, 0.06743993901181966, 0.07736332176136784, 0.018254723290738184, 0.05123130387801211, 0.03672107370221056, 0.02269719887408428, 0.05919153532886412, 0.08657572703668848, 0.03524152809404768, 0.026948756967613008, 0.03728274590685032, 0.06701121514197439, 0.03261890808062162, 0.02290605778398458, 0.014896310240146704, 0.0506076957390178, 0.05601911747362465, 0.03600949879910331, 0.049475219202577136, 0.020300633332226425, 0.06978019780945033, 0.03231799688364845, 0.03497649231576361, 0.048822418684721924, 0.03835180963505991, 0.0497797632124275, 0.021654859883710742, 0.07976851105922833, 0.06273525708820671, 0.01580735217430629, 0.02391218182310695, 0.11152688035508618, 0.18661724869161844, 0.13739136513322592, 0.08423981722444296, 0.20969634933862835, 0.15628266002750024, 0.18587470025522634, 0.14159021404339, 0.2085775023442693, 0.1564246477209963, 0.11968051549047232, 0.16321274597430602, 0.10177845892030746, 0.1021449982363265, 0.1594313996611163, 0.17202203889610246, 0.1518374923034571, 0.147715930652339, 0.15012103831395507, 0.15739901340566576, 0.09221167812938802, 0.1217289172927849, 0.12252829197677784, 0.12430272996425629, 0.10286068092682399, 0.13035797222983092, 0.23734449699986726, 0.12937879742821679, 0.08840118767693639, 0.1407931325957179, 0.16424496949184686, 0.22252514376305044, 0.1502238109242171, 0.2045630177599378, 0.10477882096893154, 0.195701967459172, 0.15852753800572827, 0.14757952390937135, 0.10967315873131156, 0.10629172611515969, 0.10456353877088986, 0.1576777789159678, 0.10904243710683659, 0.09914206093526445, 0.19177817332092673, 0.21011910634115338, 0.2510705776512623, 0.10715465090470389, 0.17468931764597073, 0.17415860784240067, 0.10608592856442556, 0.1521354794385843, 0.2531732601346448, 0.09464837159612216, 0.1682025907211937, 0.13158327288692817, 0.10834530810825527, 0.2664873597677797, 0.16437661164673045, 0.09877280535874888, 0.2258509598323144, 0.1102057090611197, 0.16991184587823227, 0.11838269958388992, 0.17039109516190365, 0.10871036312892102, 0.1470928531489335, 0.1383251798688434, 0.0725603943283204, 0.09389639046275988, 0.22057944035623223, 0.15295372693799436, 0.1583580463193357, 0.15649485489120707, 0.3007603925652802, 0.15717773465439677, 0.22632240172242746, 0.0938993071031291, 0.1656503151752986, 0.10764052756712772, 0.12204972546896897, 0.16872941167093813, 0.11934259338886477, 0.13453224120894447, 0.15848624490899965, 0.18539337295806035, 0.11094882895122282, 0.12220034433994442, 0.15902272862149402, 0.1300958901992999, 0.17837742052506655, 0.12737556273350492, 0.07178744010161608, 0.08336809056345373, 0.1534675306174904, 0.09926341692334972, 0.1818775077117607, 0.1975294022122398, 0.17662664962699637, 0.07554808049462736, 0.11183730588527396, 0.10120737628312781, 0.17754053027601913, 0.12200472905533388, 0.10777835923363455, 0.16609276877716184, 0.18809231172781438, 0.09947437240043655, 0.13211521465564147, 0.1569213523180224, 0.0841776846209541, 0.27351558732334524, 0.2170375850982964, 0.09366760859848, 0.09775803715456277, 0.10672180069377646, 0.1601748535176739, 0.16287444537738338, 0.13777514453977346, 0.17094166483730078, 0.08854746498400345, 0.21001066372264177, 0.10195258902967907, 0.09687586847576313, 0.23311783239478245, 0.20907428115606308, 0.09501007953076623, 0.1101712734089233, 0.16295716515742242, 0.15738427435280755, 0.11210506534553133, 0.09344453384983353, 0.08766055398155004, 0.20275407732697204, 0.11267783265793696, 0.19593348784837872, 0.14091871882556006, 0.25184478610754013, 0.12712902127532288, 0.11193989295861684, 0.09988255362259224, 0.1641829704749398, 0.14800055912928656, 0.21444544137921184, 0.14474584080744535, 0.19423028861638159, 0.1728383419685997, 0.06426640422432683, 0.13225248228991404, 0.19815777865005657, 0.13135752640664577, 0.13829210976837203, 0.19366254564374685, 0.11673012224491686, 0.1322239392902702, 0.14472586219199002, 0.156744958658237, 0.11558040190720931, 0.1767834060592577, 0.12591635197168216, 0.15728470782050863, 0.11301573249511421, 0.14254436362534761, 0.17743042524671182, 0.09818877224461176, 0.22574768256163225, 0.10392948490334675, 0.14959470718167722, 0.16528537147678435, 0.1625514923944138, 0.1064228339237161, 0.07376011315500364, 0.17569835647009313, 0.1441697115660645, 0.08898058236809447, 0.16109354328364134], [0.037700972097809426, 0.010934867877949728, 0.01639538175368216, 0.02785701955872355, 0.013828960873070173, 0.10717970581026748, 0.0049439688882557675, 0.04203047981718555, 0.052032875319127925, 0.018021891155513003, 0.027977510944765527, 0.019541924630175345, 0.02933279134595068, 0.04349206545157358, 0.012854036722274031, 0.044267761913943104, 0.056591513712191954, 0.01398519316353486, 0.03975245381298009, 0.04704724226030521, 0.06901997883687727, 0.05398323941335548, 0.009372684125992237, 0.06095149030443281, 0.0343967710796278, 0.018218389595858753, 0.09380817878991365, 0.03828670101938769, 0.022265361694735475, 0.0799532093515154, 0.01765956352755893, 0.05591470471699722, 0.04860514382016845, 0.02913599233579589, 0.02066868848487502, 0.042255580628989264, 0.02932536430307664, 0.02472016727551818, 0.04508525613346137, 0.037200786828179844, 0.07392510000499897, 0.07043728051939979, 0.05886376209673472, 0.11161868402268738, 0.06203914854268078, 0.04195425754005555, 0.03867826184432488, 0.049128387618111446, 0.07248666195664555, 0.009757920925039798, 0.01572728928294964, 0.05987909433315508, 0.06071606250770856, 0.006357455931720324, 0.008723595274204854, 0.06019403212121688, 0.025287466814916115, 0.03384680996532552, 0.06571418591192923, 0.121825522655854, 0.0060506168301799335, 0.005004177937735221, 0.017232639365829527, 0.03194362790964078, 0.04049221919558477, 0.03904473807779141, 0.026866918487939984, 0.03151556826196611, 0.037521201666095294, 0.05717815176467411, 0.027430243826529477, 0.020482984582486097, 0.012838332877436187, 0.07516142155509442, 0.02427882132906234, 0.013218003568908898, 0.01228468236149638, 0.05617301292659249, 0.008515487788827159, 0.04068396789079998, 0.019718939838639926, 0.07312726898817345, 0.05400313268182799, 0.005766566764577874, 0.06889035532367416, 0.03314869762107264, 0.08603576265159063, 0.028188755859446246, 0.062472952413372695, 0.08900387838366441, 0.020782407773367595, 0.08579328074119985, 0.09304290579166263, 0.034694932619458996, 0.06988317822106183, 0.0699322490254417, 0.027658125836751424, 0.01773843712726375, 0.02902164593251655, 0.043873466274817474, 0.04239773901645094, 0.06747528750565834, 0.13292414078023285, 0.07396828557830304, 0.04962994957168121, 0.008598667700425722, 0.049452453822596, 0.056650406841072254, 0.017703094199532643, 0.02405474653642159, 0.09634094327338971, 0.06551786558702588, 0.07328876032261178, 0.03638400878116954, 0.06442621830501594, 0.005543841753024026, 0.03499412574456073, 0.0531177430821117, 0.07136702086427249, 0.05729031254304573, 0.028591255941137206, 0.06740128053934313, 0.04446786719199736, 0.0023603464160260046, 0.02058867012237897, 0.026798503604368307, 0.02789221405691933, 0.029682185195269994, 0.023904572954052128, 0.028928484134667087, 0.05043834877142217, 0.059843248600373045, 0.06299908316577785, 0.055299757441389374, 0.03914464970875997, 0.03049238039238844, 0.026711330938269384, 0.014580241604562616, 0.04035687743453309, 0.08473519337712787, 0.02514960175176384, 0.013816129139740951, 0.03666852964670397, 0.04068332964379806, 0.04326604808738921, 0.04063284504809417, 0.08113503499771468, 0.03424007401918061, 0.015748125078971498, 0.06624301066040061, 0.06839135006885044, 0.07959440321428701, 0.017402155172021594, 0.04802662857400719, 0.08652716831420548, 0.03146666815155186, 0.054559342679567635, 0.03821868318482302, 0.016298991613439284, 0.07643347751582041, 0.06265699019422755, 0.012652356235776097, 0.04364881075161975, 0.03760876767046284, 0.03806266890023835, 0.02924973945482634, 0.043535091463127173, 0.014951862776797498, 0.034348650224274024, 0.010442579059599666, 0.029555736218753736, 0.11579626298043877, 0.005828117709825165, 0.035705155169125646, 0.025249402060580906, 0.04180713789537549, 0.02153151493985206, 0.030720663162355777, 0.02215939970483305, 0.03327555663418025, 0.07048646264593117, 0.0467384605872212, 0.03884042853314895, 0.01756158519128803, 0.025452475929341745, 0.11693128137267195, 0.022794006472395267, 0.04609479961800389, 0.01185232846182771, 0.027753992762882262, 0.025207812104781624, 0.061727602369501255, 0.05491692056239117, 0.04567828778817784, 0.10047907708212733, 0.05667574005201459, 0.0356313337397296, 0.03932250911020674, 0.05197210455662571, 0.04438507690792903, 0.030043852311791852, 0.02893669043260161, 0.021604722242045682, 0.052130371259409, 0.02895894558605505, 0.04275392166164238, 0.07434068043949082, 0.03610024861700367, 0.1257888658437878, 0.06174008158268407, 0.02092156788421562, 0.039092484148568474, 0.028302879618422594, 0.023323539971897844, 0.12061234869179316, 0.033703356530168094, 0.1279449978028424, 0.04147992869548034, 0.030983639480837155, 0.052805881496169604, 0.0665436546842102, 0.0052771815990126925, 0.034981193821295165, 0.052968033342040144, 0.08040376720600761, 0.01610322047781665, 0.011833636544906767, 0.047137331566773355, 0.0266084804025013, 0.026954148670483846, 0.013559458293457283, 0.06398015044396743, 0.01166818214187515, 0.025057091188500635, 0.038375584335881285, 0.047337240175693296, 0.011606447515077889, 0.037181131046963856, 0.01893114636914106, 0.023562159003631677, 0.007893212732597021, 0.07023271493380889, 0.09856163465883583, 0.05512273666681722, 0.024731143639655784, 0.08291155099868774, 0.07322106161154807, 0.06435716888518073, 0.026074115521623753, 0.016893322026589885, 0.018015521673078183, 0.006553872271979344, 0.02375487434619572, 0.029292986255313735, 0.04227608616929501, 0.025522406649542972, 0.016095782302727457, 0.01695775157713797, 0.015690870241087396, 0.02272557860123925, 0.05332982662366703, 0.02531485206418438, 0.04050482457387261, 0.05456602943013422, 0.020090971047466155, 0.04170569001871627, 0.0031954371888787136, 0.038585452566621825, 0.06364553089952096, 0.08257413355750032, 0.017967990825127345, 0.06862714522867464, 0.060145243332954124, 0.06440410230425186, 0.026028699794551358, 0.027146585707669146, 0.03284366008301731, 0.02182609932788182, 0.06993184826569632, 0.04378444195026532, 0.022004780657880474, 0.021105095438542776, 0.05383523661294021, 0.043410614744061604, 0.05088559293653816, 0.08050299977185205, 0.030111859014141373, 0.07300454744836316, 0.011323200360493502, 0.04822310474992264, 0.09780959415365942, 0.08245841789175756, 0.03548519001924433, 0.0290929217953817, 0.036268486073822714, 0.013086038579785964, 0.046946477159508504, 0.03600828909839038, 0.03360681796038989, 0.016310951323248446, 0.012106813683203654, 0.02368758010561578, 0.0533582286152523, 0.007528738906330545, 0.030953719797253143, 0.010361941003793618, 0.06029835953086149, 0.030358265030372422, 0.04111432448553387, 0.0072803049715730594, 0.016569420949963387, 0.019057122226513457, 0.042455418733879924, 0.04064241875312291, 0.04004664115200285, 0.04001296991191339, 0.022831894966657273, 0.06568503435119055, 0.016180696984520182, 0.010830182382051134, 0.0718921422958374, 0.09098876718780957, 0.04096828466572333, 0.007451670580849168, 0.03741231375897769, 0.1090805241256021, 0.07255743315909058, 0.041706098199938424, 0.05932870648393873, 0.03510427901346702, 0.02111513113050023, 0.02468879298248794, 0.08096621866570786, 0.08873156213667244, 0.02148746105376631, 0.03352617619384546, 0.055716350907459855, 0.02647887358762091, 0.0629216548986733, 0.03695834944664966, 0.013833584453095682, 0.05500350693182554, 0.044320918241282925, 0.037309578256099485, 0.04419311670062598, 0.04899379542621318, 0.037827385822311044, 0.07327231433009729, 0.039861727636889555, 0.029880993570259307, 0.05421873400337063, 0.006382799347193213, 0.10195216600550339, 0.13056620402494445, 0.1397100868052803, 0.08954010976594873, 0.16515013732714579, 0.1726440922357142, 0.1541836585965939, 0.1811643037945032, 0.07919622614281252, 0.1769487268757075, 0.13255079597001895, 0.08613148485892452, 0.10798699920997024, 0.11282775391009636, 0.08805058227153495, 0.10319150067516603, 0.1370669575408101, 0.15051920054247603, 0.20292404398787767, 0.06541230250149965, 0.17753392516169697, 0.18100558809237555, 0.06789808903704397, 0.14724344975547865, 0.07384255091892555, 0.07713794635492377, 0.19860440312186256, 0.12026817770674825, 0.12234967929543927, 0.12527893617516384, 0.12700404360657558, 0.11372392691555433, 0.17051804694347084, 0.1116476277820766, 0.10513302579056472, 0.13935642375145108, 0.08142374528688379, 0.12604322953848168, 0.21928503090748563, 0.0871697197726462, 0.16006255173124373, 0.17598212405573577, 0.1263652919442393, 0.1915125735104084, 0.13107922102790326, 0.12961563159478828, 0.13309815956745297, 0.18812741531291977, 0.20007909508422017, 0.10361564549384639, 0.12000225877272896, 0.18895477638579905, 0.15651502646505833, 0.20323982782429084, 0.17612301337067038, 0.23265354480827227, 0.11466606112662703, 0.11039993652957492, 0.10380968000390567, 0.20009928150102496, 0.14387803268618882, 0.10287783938110806, 0.0896526787255425, 0.18656464526429772, 0.09955882880603895, 0.1795097449212335, 0.1448394256294705, 0.15447839512489736, 0.11021793223335408, 0.22921082563698292, 0.24300044897245243, 0.09538897560560144, 0.17561017448315397, 0.13898808101657778, 0.11263961205258965, 0.07268632194609381, 0.1134522414940875, 0.1222022071306128, 0.10218771625659429, 0.27134459756780416, 0.08453051646938547, 0.21728264226112515, 0.15131784050026909, 0.14165801665512845, 0.12619431596249342, 0.11168558863573708, 0.16258151968941092, 0.11378674229490571, 0.15859363367781043, 0.13920011260779575, 0.11378527284250595, 0.14699097111588344, 0.17341984435915947, 0.12395137498970143, 0.20498446858255193, 0.18390731129329652, 0.11816894621006213, 0.21722690697060898, 0.09317221018136479, 0.12888037104858086, 0.11782481975387782, 0.12060775479767472, 0.26406448509078473, 0.1372359148808755, 0.19683752761920914, 0.16123515990329906, 0.19641998049337417, 0.1352164865238592, 0.09593950075213797, 0.11848772090161219, 0.13428607082460076, 0.19090350775513798, 0.22701397945638746, 0.17694924637908116, 0.10928527524811216, 0.198625331686344, 0.1496279999264516, 0.1953752592089586, 0.10313718288671225, 0.22478906525066122, 0.1411964008002542, 0.18411784374620765, 0.09239835795597173, 0.0899254773685243, 0.16971921402728185, 0.09090271516470239, 0.1377011078875512, 0.07978296809596941, 0.06756899107131176, 0.0944124131638091, 0.1134747508331202, 0.11971905521932058, 0.1974068587878719, 0.13894346309825778, 0.11698213333147578, 0.0936624952009879, 0.12949685828061774, 0.07815373872290365, 0.16399333690060303, 0.17722596356179565, 0.15305139357224107, 0.13944867270765826, 0.18007079372182488, 0.18447702837875113, 0.14493057620711625, 0.14073840662604198, 0.10441991093102843, 0.0850748001539614, 0.17446570855099708, 0.1991147335502319, 0.08977174147730693, 0.18649056408321485, 0.13551530486438423, 0.14854925859253854, 0.16935339459450915, 0.1359140162821859, 0.21890168194659054, 0.21639430633513257, 0.14062310656299815, 0.1722744878497906, 0.17951706249732524, 0.15113625180674717, 0.12866422795923427, 0.1534050566260703, 0.12937884195707738, 0.18938188237370923, 0.13728354591876268, 0.12715812830720097, 0.11310200716252439, 0.10041135610663332, 0.14529614330967888, 0.16149654431501403, 0.19203909760108218, 0.21004043868742883, 0.24284879851620644, 0.11673224478727207], [0.03286819177446887, 0.010083153229061281, 0.04552052203507628, 0.04086920052941423, 0.03259178629377857, 0.03292854322353378, 0.0201082686544396, 0.04112902272026986, 0.030517674640577752, 0.007657966762053547, 0.005845806799698039, 0.09665996287367307, 0.04086711509444285, 0.009620961282053031, 0.02188010170357302, 0.025418372388230637, 0.03646747441962361, 0.0165190458210418, 0.06540568996570073, 0.08106742534437217, 0.024854635157680605, 0.010200505330431042, 0.05804532906040549, 0.03457317587162834, 0.016040662994782906, 0.07132438448024914, 0.040124659426510334, 0.027123402869619895, 0.048233932684524916, 0.055550525430589914, 0.09718025292386301, 0.048138039783225395, 0.10074619829538278, 0.043665342091117054, 0.027494072237459477, 0.07220302795758471, 0.12783326004864648, 0.03540575795341283, 0.03076486176723847, 0.06680702063022181, 0.01849373380537145, 0.07573437440441921, 0.015708325554442126, 0.07291642483323812, 0.023214902539621107, 0.015689857209508773, 0.009001369089673972, 0.04556706582661718, 0.03696421241329517, 0.03863574791466817, 0.014715468332724413, 0.0585849038179731, 0.03384210474905558, 0.042400117599754594, 0.07945609657326713, 0.03680525180243421, 0.04150217086134944, 0.04010739336081315, 0.04598654624714982, 0.03163533976476174, 0.021693332819268107, 0.051768770936178043, 0.020710831340693403, 0.03250459507398773, 0.011782197361753788, 0.014087869294598931, 0.040776803143671714, 0.06928154136403464, 0.03155186299409252, 0.07499548475607298, 0.012449782389012398, 0.012388506966090063, 0.04316871170885861, 0.020214828073221724, 0.028938289760844782, 0.007649789686183794, 0.04622158441634383, 0.0718565340503119, 0.012018887737212935, 0.01899835897347657, 0.0421302615723107, 0.011907103598787216, 0.02100413552398095, 0.014267364203988109, 0.04472992324735969, 0.018196245764556807, 0.09327423322247341, 0.03925635035557207, 0.08610312739619985, 0.011211573000764474, 0.044635032245423645, 0.011252551612415118, 0.06729858214384876, 0.021894157980568707, 0.017901917417475488, 0.017076968324545305, 0.05765030982729513, 0.04427090119861532, 0.04561376917990856, 0.10041649176855572, 0.03106543157628039, 0.009510154923191294, 0.05464840411150362, 0.047346190476673655, 0.0329276971751824, 0.062228941678768024, 0.041036005641217344, 0.02646681183250621, 0.04836222775338683, 0.03070610408030916, 0.0033427159314669552, 0.012449045807443326, 0.07943066317238845, 0.017068598754121922, 0.045912112545920536, 0.04885911046585534, 0.022712242207489908, 0.05968859615677502, 0.04462568860617466, 0.0534779184818035, 0.0603982822940452, 0.11690284969517961, 0.011468870034150314, 0.02196178804297233, 0.015523733018198982, 0.032950985769275576, 0.06335017838864587, 0.07192779507022351, 0.028337317125988193, 0.03878765812260099, 0.061317458166740835, 0.015353377657447709, 0.025691197006381117, 0.01779287551471498, 0.04556437925202772, 0.04084106571099255, 0.024229815462604165, 0.050903204100904986, 0.031133981901803054, 0.028004408231936395, 0.04694922681665048, 0.02305724068719428, 0.030104261277301703, 0.022456342267105356, 0.10463476268341765, 0.0840919888287317, 0.04994985974917654, 0.04287909971026238, 0.05365983000956476, 0.05816868142574094, 0.01939837100508157, 0.09130012040259317, 0.022155516417114995, 0.04889536809059791, 0.07806612818967551, 0.03733226942131296, 0.014790855693718186, 0.02339351336559048, 0.052789906767429784, 0.040772821521386504, 0.06922463348018937, 0.06956887868000194, 0.06181031101732515, 0.04715700590168126, 0.045192066027084365, 0.03182201959134545, 0.03181306557962671, 0.04595228499965742, 0.045231782060000114, 0.06252679522731341, 0.009881314108497463, 0.052205320753273554, 0.012295297856326215, 0.052313125124783255, 0.028976989051443525, 0.01810392815968953, 0.022804639593232423, 0.019936851094826125, 0.03558388081728481, 0.03778489786782302, 0.029250544685055502, 0.020024457917315885, 0.031036552754812874, 0.07804516251781024, 0.07638664057594724, 0.004075212209500023, 0.029684148175874725, 0.12727791094221175, 0.06460242642788216, 0.01576365451910533, 0.03536197495122906, 0.02243531165731838, 0.04054542376252357, 0.035220324934925884, 0.009315168608736712, 0.0880462110217195, 0.06305892995442264, 0.05006301129469648, 0.02880009629734559, 0.05123756389366463, 0.054015771456761286, 0.029577800269180443, 0.017683566438790876, 0.11990540850092657, 0.07626778562553227, 0.0389030064252438, 0.03376221997314133, 0.0830694280739408, 0.0066536911344883265, 0.017295154175371863, 0.02488475522113731, 0.03933974920073524, 0.03168298935634084, 0.023418594246322755, 0.016901138696994167, 0.05660736598656513, 0.053621256884071045, 0.08966292036348023, 0.030310227666632272, 0.07827854569768533, 0.053369858069345355, 0.027657129503495526, 0.010252415777358692, 0.04467598395422101, 0.05475958896568045, 0.032949735250440426, 0.0897865102160722, 0.07820359620382078, 0.013846623060089769, 0.06363864376908168, 0.025779996831261087, 0.001980935244318971, 0.04430140717886388, 0.054972997240838595, 0.027420052283559926, 0.062324203754542395, 0.018510784648242407, 0.01206203527544858, 0.00391818906791741, 0.050634772997000255, 0.024407333476119675, 0.025710257214086596, 0.0931993208359927, 0.0353647097654175, 0.020620736468117684, 0.09642484306823462, 0.03520902944728732, 0.029813135297445115, 0.024002139398362488, 0.012489924229157623, 0.04941735023749061, 0.038579415195272304, 0.05129584846145008, 0.09018936281790957, 0.014880666694807587, 0.062372332031372935, 0.023248980105563533, 0.056913731968961656, 0.06318676489172503, 0.06340206935419701, 0.07225867419037968, 0.07376460314844735, 0.10895466330111958, 0.023979711695574224, 0.08406308959820308, 0.05843763945449609, 0.05846072766871657, 0.037614029497490264, 0.028072795284970198, 0.016364656839868985, 0.05360230614314787, 0.023942253646964673, 0.02982115234772209, 0.012457636166800512, 0.03510215276037343, 0.052792444912483916, 0.028743266339006368, 0.027160283898410853, 0.06725027575157583, 0.044866051684948616, 0.0605260281736264, 0.030997938811196946, 0.017642961684032343, 0.008894136171875289, 0.029808060862706043, 0.06806363249779679, 0.04532353748800233, 0.05294227710692212, 0.042509562117629685, 0.018845806807803456, 0.023932193835207727, 0.01785403033863986, 0.03530078858602792, 0.03537553770001978, 0.06570867917616852, 0.03953676714445464, 0.038907852649572305, 0.054009756349842064, 0.02636451605212642, 0.057718617099453695, 0.04357304860604927, 0.040574267331976444, 0.03329433668113779, 0.027994094234600198, 0.04036304097098764, 0.07541891711298376, 0.03731044656888116, 0.017951394547708333, 0.017288604722125456, 0.021966855056234635, 0.03427294002904091, 0.03816517062659841, 0.023328749848587904, 0.05748814684920944, 0.018922314811788965, 0.028260579056222923, 0.026380706003692467, 0.0587987870676443, 0.028368131097522564, 0.07025615937891416, 0.049491869285702705, 0.09056201743078418, 0.034084067156072706, 0.07329202577238902, 0.031077684434421826, 0.024205053705372848, 0.06678694553556852, 0.05161790344573092, 0.03122113601421006, 0.06821201750426553, 0.08051085169427097, 0.006597916881219135, 0.036793136241612956, 0.06310150696663186, 0.09977457855711691, 0.029597491302411072, 0.06390100781572983, 0.03749099625565577, 0.09009634944959544, 0.03373828199983109, 0.06755324269761331, 0.04110329246032052, 0.036779618021682836, 0.03630924482422415, 0.03638269889052026, 0.024783620901871473, 0.03113799320999533, 0.012854105370934121, 0.044929924624739215, 0.04766216727148276, 0.0692182955390308, 0.038353149211616255, 0.09881242120172828, 0.08263221403467469, 0.09524881359538995, 0.13820260675856844, 0.12476213421905413, 0.11441739712608978, 0.11814305267762393, 0.15822543937247247, 0.13625228719320148, 0.09059643824002706, 0.11143635318148881, 0.19369466579519212, 0.07870004847063683, 0.09362908371258527, 0.06508008009404875, 0.12127412177505903, 0.16573759174207225, 0.15415483358083293, 0.1390496495878324, 0.17827715637395158, 0.16418855142546818, 0.126421042077709, 0.11741447146050632, 0.20202861313009635, 0.07824054773664102, 0.1796780343283899, 0.1727953864610754, 0.20709292497485876, 0.18996403785422444, 0.15884603810263798, 0.16303848969982937, 0.13605481653939933, 0.21573303791228682, 0.15562409302219748, 0.09660591225838289, 0.14298628288088366, 0.2587613055948168, 0.1749515629489906, 0.06784447628888302, 0.14760364370886236, 0.1666648013633676, 0.1831874280469492, 0.11881630678544752, 0.15629172907210886, 0.08171155015588738, 0.11699865353875794, 0.10569499485427514, 0.20529384026303887, 0.10241557043627836, 0.19909050985006616, 0.1835420707357116, 0.24090244201943278, 0.11184766626683995, 0.1738599527743645, 0.14114971971139312, 0.10709035865147598, 0.08256544300820678, 0.18151113908970729, 0.08006125121028163, 0.14774570561712608, 0.09701395247248001, 0.05621925614832435, 0.1440455502597615, 0.12859498558100313, 0.09288799730711617, 0.07945905774249695, 0.18465817178366706, 0.13779196160612628, 0.1277123493491672, 0.1944939439999871, 0.09954322886187583, 0.09783194022020325, 0.11801305809058249, 0.18696359416935593, 0.19108101463643834, 0.0918267855013255, 0.15897101577138528, 0.13300264516146854, 0.08178267016774043, 0.173580979462713, 0.14448255649767816, 0.10977249519783072, 0.14159128273604438, 0.11259981809416786, 0.14012649102369323, 0.16457924764836207, 0.1682445072219707, 0.1754439779324457, 0.17875692516099662, 0.13989264029078186, 0.14599076384911314, 0.13277804158860818, 0.1446061537717469, 0.11602877784753218, 0.11686412442941219, 0.06814201813540421, 0.12233902205480263, 0.08897009582142346, 0.13708468002732843, 0.19024828041438013, 0.10710451140766963, 0.06523783842567354, 0.10917105872067623, 0.17958574084332213, 0.2505235851276666, 0.13752140424912795, 0.12902160175144672, 0.10196819639531896, 0.11301447084406391, 0.12346345742116682, 0.07049573949188925, 0.12904199596960098, 0.13794027239782736, 0.09947944126906805, 0.12044519477058202, 0.11332279609632678, 0.09616578157874756, 0.15974387351889163, 0.14794290909776464, 0.09820375620620325, 0.15172198443906382, 0.13412692467682064, 0.09030202083522454, 0.11550266193808056, 0.1743507053470239, 0.2250956612988375, 0.24371564184548333, 0.08426646032603458, 0.13021285267313942, 0.134874772047624, 0.15835253958357498, 0.12150981303420849, 0.09989067271817476, 0.1120691528194584, 0.13811111479299143, 0.09731847050716169, 0.10968168600811623, 0.18822665530024096, 0.08992604882223532, 0.1428245985880494, 0.1521243472234346, 0.14861289033433422, 0.10574801388429478, 0.14301911549409851, 0.17892183037474751, 0.15210137033136562, 0.08250824568676762, 0.12345116003416479, 0.16145495435921475, 0.13167702098144218, 0.08988805828266777, 0.2935023664031178, 0.09059010772034526, 0.18195993063272908, 0.28342976002022624, 0.1424979348666966, 0.1867587020387873, 0.1419696444645524, 0.16597306035691872, 0.12718621117528528, 0.23295181395951658, 0.14346183626912534, 0.2819273265777156, 0.14313273830339313, 0.09640919117373414, 0.13831591786583886, 0.13672773668076843, 0.1431805474567227, 0.09898321164655499, 0.23962069361004978, 0.111384610645473, 0.1631927673588507, 0.1306223846040666, 0.2614965650718659, 0.17995950125623494, 0.09649621541029774], [0.022478361788671464, 0.031653032565372996, 0.09441190108191222, 0.0257628420877154, 0.03315256421046797, 0.06026565308275167, 0.027785999736806843, 0.04689598143158946, 0.07176623694249429, 0.04150502812990453, 0.03548331238562241, 0.025694994947116356, 0.05373208550736308, 0.04657435689296108, 0.07898151539848186, 0.06648840921116062, 0.05383568932302296, 0.022943196709093172, 0.02482892345142318, 0.02980091954668751, 0.07408613862935454, 0.03166080285154749, 0.02002947669097921, 0.03525830805301666, 0.02423538713628659, 0.10813813016284257, 0.035547545267036185, 0.09676411587861367, 0.022431888501159847, 0.05112104299769271, 0.033545086116646416, 0.009421681643289048, 0.02233858198451344, 0.0614339456660673, 0.039393758997903205, 0.05524602223886177, 0.04392340539197903, 0.045464983413694426, 0.056860356708057225, 0.03785220324061811, 0.02634781958477106, 0.02686719122721115, 0.09684408971224912, 0.04853369726333767, 0.017106542909459677, 0.07726785930572078, 0.012054768722009612, 0.07902407014626078, 0.03979892338975333, 0.06559924950124696, 0.01832978039601585, 0.03798668782110326, 0.10663509558071382, 0.09441970105399378, 0.044574955390999094, 0.05748051386035513, 0.06378601203323342, 0.03889339932356961, 0.05976839558570646, 0.03390733210835606, 0.024377523259317968, 0.04155537913902663, 0.0745286738674622, 0.016472084571432788, 0.02591102856968064, 0.06736900453688577, 0.03227768713259138, 0.014519917058350984, 0.08036383223952726, 0.005015366741645266, 0.0057199654565920355, 0.03170932446664665, 0.014801260604144773, 0.045788162751705386, 0.017888191396195907, 0.033458867110311985, 0.038946537097217515, 0.035906919147237204, 0.09311359535786323, 0.011378693525330164, 0.04105766893189866, 0.03132412013655994, 0.024129571720550302, 0.030827591799607035, 0.044500454896478914, 0.043561385755310766, 0.05380227041314356, 0.030449801524810027, 0.04516951958066784, 0.014548014769388828, 0.08659182421979494, 0.027325203955115285, 0.023305967770284042, 0.020473388613027055, 0.011868063847941812, 0.05604913363640662, 0.0718934930046089, 0.039834049239289016, 0.06156791445391718, 0.06229651422472671, 0.049479646113468334, 0.013648353669850621, 0.029366865201154724, 0.07689086312893778, 0.10412223549792543, 0.10209196436335333, 0.022754791389161255, 0.059368578367866576, 0.04100677615497261, 0.03987598429375794, 0.09287725843023509, 0.008787503466010094, 0.023595769016537815, 0.0268149050680222, 0.029450815090967808, 0.04103937499166932, 0.05737878767831717, 0.0254364399734186, 0.048017693115980364, 0.019737584443646483, 0.011081288048444549, 0.024341384378203657, 0.03775934201257769, 0.01817623746319441, 0.006784094830436516, 0.004738194065794232, 0.04384825922898017, 0.06200857205840293, 0.03385227588296402, 0.1064921727811452, 0.0271855261962628, 0.052849041094304994, 0.0933117042586673, 0.012852032923547085, 0.058248165441909805, 0.016733717602619436, 0.021143447775102686, 0.007309113289011293, 0.03602427495934535, 0.020475841411098372, 0.022876214170537423, 0.03771566291106865, 0.02899606966821011, 0.08660524967126548, 0.04230853286571801, 0.04492428059165832, 0.11266108238487504, 0.07574840099550784, 0.021449112427944783, 0.03434002646827139, 0.023436383526131976, 0.006254058062040713, 0.052735614954144694, 0.004521794471656904, 0.0008384753141399415, 0.03230159913073294, 0.033830820393632166, 0.012025403793813894, 0.03893864806741476, 0.059810415987158194, 0.029836542635166552, 0.010693701424315805, 0.052562182463589124, 0.043607666084426455, 0.030057374242460355, 0.09200082655297592, 0.005412175014498644, 0.048478054741281085, 0.017855332807812374, 0.02600658750452567, 0.09747187243192457, 0.025010706958710216, 0.017279194289585575, 0.013162631930754287, 0.0048660072025086265, 0.03417141422687564, 0.0033047615715986467, 0.05997488333377987, 0.0318915476964321, 0.07018590025836602, 0.028021407124469988, 0.03485133653157391, 0.0681995420018211, 0.0464620105776703, 0.06541317081428133, 0.05239289857854601, 0.04331619129516184, 0.04268280907126609, 0.026115846485481597, 0.051543744339141995, 0.055273604157264344, 0.0896301471220795, 0.008354779420187697, 0.007202830784081016, 0.0189117280751816, 0.04107214823307004, 0.07520933460909873, 0.02846321505785454, 0.005876079467270756, 0.04848828524700366, 0.013226012270024512, 0.02292623492394341, 0.020025493213324808, 0.07933786502690054, 0.01951161160832271, 0.018946219388453756, 0.03273983362305444, 0.08559002133551985, 0.03804950691119302, 0.02540616776968818, 0.014044498184375698, 0.09456876141484827, 0.05542811930354219, 0.03430638862482738, 0.08664472450618632, 0.026898673131654505, 0.07825665234122425, 0.027464787090138998, 0.06480790485511534, 0.02912205851316685, 0.015622622340742964, 0.008065634974627756, 0.028912516827404033, 0.029226977785583586, 0.03347215897520073, 0.06938835125765763, 0.07099517519236542, 0.026640259166015312, 0.06536367698572576, 0.06626495596719906, 0.045205272544990294, 0.035684909380506724, 0.06644949840847403, 0.039645213473704644, 0.04920760075037833, 0.014820515625615371, 0.02509509471565252, 0.01867702572781127, 0.037658176152035594, 0.06749280961230397, 0.022866540275572333, 0.04562125002848916, 0.04589621203194838, 0.029999505277373828, 0.11728654746548273, 0.05200512270675972, 0.016064298542914912, 0.06073195188946556, 0.07082860756781884, 0.043125867523485795, 0.02655313288414618, 0.03645960765425116, 0.10491849316167645, 0.0158967846800806, 0.07640886047738604, 0.02223183517344296, 0.005693079301636317, 0.036040854538441636, 0.04152675079239998, 0.017227874777745456, 0.004030487607451505, 0.009970202991098631, 0.059847586453543045, 0.03685696094180457, 0.07234740536659956, 0.017022618994815275, 0.07529061462264508, 0.04010701857623644, 0.014526026789098978, 0.03319385359645821, 0.07918795861769468, 0.02772652958810795, 0.03900307390722446, 0.004100304686289746, 0.061021304136374965, 0.04450157553947065, 0.03984214607044123, 0.003224330157536315, 0.02919788188592065, 0.015787047013873234, 0.1346870680572465, 0.03956757369451225, 0.021882758592255414, 0.048021882539615035, 0.03967731878219638, 0.04978633864084259, 0.0138194159262639, 0.029217925439297687, 0.05914926259720232, 0.018161262778448872, 0.0630642066244036, 0.04284279755665921, 0.10091835429193452, 0.03390657511772588, 0.06728998807375319, 0.042339124192949384, 0.0358159132883884, 0.03317649105156306, 0.03830358116829302, 0.03174688827130012, 0.037041354953544214, 0.07332437598961405, 0.041389345860807225, 0.07260933896759525, 0.03441654560447205, 0.07685904725803994, 0.05173096222279128, 0.01909815371618606, 0.05259390927676577, 0.03233554496546276, 0.04015803380752914, 0.011665453821478877, 0.04446081678906921, 0.01369294097457896, 0.04132692381972447, 0.08349936906597577, 0.032958511146716774, 0.05431673089333344, 0.01156025346062961, 0.032375142254750244, 0.01684159433352761, 0.034214718543807976, 0.035436356702120975, 0.06745622173184529, 0.026278718214598484, 0.055604954541195184, 0.04057000369357411, 0.04767471327795647, 0.10607796531985514, 0.009663193195592612, 0.05445861097541638, 0.04017288418253884, 0.06910062802489847, 0.03931451246899087, 0.02988450949487742, 0.04546499825664796, 0.02618197184347082, 0.054502731654793024, 0.07022812103969045, 0.03098221084655961, 0.046574297521146946, 0.06745127160684206, 0.0312042187579209, 0.04341597676102538, 0.026243289939884562, 0.021333465410862118, 0.02758105194516247, 0.012029484678350855, 0.03550922076101415, 0.03979834080382716, 0.0357594321394572, 0.018590127656352706, 0.16387521667638794, 0.14264137716963887, 0.14777824137127027, 0.13739060814259574, 0.10300096910214052, 0.12290082784602419, 0.1776259663165547, 0.1644047093577683, 0.16854892135597765, 0.11833539509098046, 0.14995813689893112, 0.11588347275392152, 0.08164075668901205, 0.10444524043123238, 0.14251230284571648, 0.19970533467130736, 0.1383548360900022, 0.1284108735853806, 0.2099338811240159, 0.1654547147336416, 0.15982138342224061, 0.13584985019406304, 0.08769346823100932, 0.08783282872173004, 0.15846795839024708, 0.45525983499828726, 0.10934455058304593, 0.2705615130253136, 0.09838225756539032, 0.13667085848283023, 0.09725174400955439, 0.18299184244824573, 0.13186297350330278, 0.21728237508796155, 0.14677310624392703, 0.30973554064985365, 0.13462903210893273, 0.12087770359357819, 0.15037121629575267, 0.16494460694957525, 0.1337838446488604, 0.08219345632824115, 0.26798148115631193, 0.15549400937743485, 0.10571545586572029, 0.15383643738459796, 0.13491940480889753, 0.29566459881607443, 0.11331317786243744, 0.14079445361858234, 0.14382577064679936, 0.14349947799928486, 0.28084711579140276, 0.12184372011688538, 0.1435004873201251, 0.12109055896871723, 0.1625742021133192, 0.15801186411408707, 0.1361722985166125, 0.10327881434932351, 0.1277208246756345, 0.1178192239603959, 0.16254047892289236, 0.17479321832070127, 0.2097531087929383, 0.1917953317752108, 0.1307127485051751, 0.08133357434417121, 0.22637985879555345, 0.07128965196898207, 0.0906641517940443, 0.10825506295077503, 0.14095180376898497, 0.15966133185429499, 0.21195276029175147, 0.14143581764074042, 0.1501173572614789, 0.12438756486517377, 0.17546216055052355, 0.19751346088014543, 0.19294383499072865, 0.1074242360482458, 0.12149506655987352, 0.15104149439139292, 0.13426009565591812, 0.15178067347733304, 0.1487538538640365, 0.13792263896903023, 0.21466507256263867, 0.09271881732274778, 0.18467945657903329, 0.12302538991207257, 0.16492134804138914, 0.08240738039603457, 0.11931066619581543, 0.17868501105112955, 0.13812350865919143, 0.10159540077438578, 0.15039229328976944, 0.09417551220394671, 0.0934879198030103, 0.09403875665157102, 0.11010013113263994, 0.12059810687787831, 0.33006738871335983, 0.17714015644742176, 0.08031727731577121, 0.2162972927908413, 0.13295554846990854, 0.1621481796610169, 0.12863811920396984, 0.15622465376509354, 0.11922330057132058, 0.12405841494910419, 0.12023648057947867, 0.1814329018816352, 0.19421774632064626, 0.07025508326478302, 0.15127089223824441, 0.09064122685231268, 0.18834161397535354, 0.11292884926660918, 0.13506835384760052, 0.08907408555387519, 0.11446690579759888, 0.10130461989319883, 0.1255669933743775, 0.19170789193594828, 0.1333710175822489, 0.17554013058543205, 0.14449272392084822, 0.11392409898689948, 0.1854966947576031, 0.09766207003849559, 0.10719153564423323, 0.0707850583421532, 0.17848865361884236, 0.11814457408036105, 0.14651783712906763, 0.1712820731336251, 0.10987716770614497, 0.06528745099785738, 0.16544837679248303, 0.3888545389054343, 0.13956046983366832, 0.08712856768397614, 0.138853871030733, 0.2381151876761578, 0.16388338030083105, 0.1771327794995159, 0.16345078242011368, 0.13453424500767142, 0.231848492694553, 0.07291311485460028, 0.1666950067738071, 0.18724771798588336, 0.11085298800026067, 0.13526414724765345, 0.10905251547228545, 0.1319353180588223, 0.10426733279018663, 0.20022624812554568, 0.16016315727028996, 0.14277828857302666, 0.11408334161387756, 0.2069256448885426, 0.07792916483595036, 0.14982781576691195, 0.08076574973529205, 0.07632759530679323, 0.2849341230466962, 0.14300528186140582, 0.16098035091999918, 0.155570688075386, 0.12570785300340503, 0.14288425241829827], [0.04027101836982183, 0.060008762375218794, 0.020828508131671697, 0.04389713336422574, 0.05664746793627273, 0.046797991963103414, 0.011496572551550344, 0.01093473892979091, 0.06861738598672673, 0.03344248791108839, 0.03342719966894947, 0.05702927694073878, 0.010256259174639126, 0.06285360737820156, 0.055569060568814166, 0.01821339308662573, 0.031013132429507095, 0.043513083073776215, 0.05679580841388088, 0.06770647392841056, 0.09637949042371474, 0.0344290173961781, 0.045479681648430414, 0.028683087439276278, 0.04045088528073393, 0.0030523453187925043, 0.05522430699784309, 0.05469322240969632, 0.04677214295952581, 0.03304558733361773, 0.05205048648349475, 0.048742077487986535, 0.01702714795101201, 0.052768529203603975, 0.01775931003066944, 0.022270469526119996, 0.045121190923964605, 0.0365038841846399, 0.01479973641835386, 0.06604974798392504, 0.04056752492033411, 0.05144987007952295, 0.01577200739120599, 0.03511500675813295, 0.046135372831486166, 0.01904422555526253, 0.05660808215907309, 0.01632945677556563, 0.03210724920791108, 0.008250917708210181, 0.011202003006474115, 0.018688358322833665, 0.053580828389385715, 0.00422561261075316, 0.023636796795472037, 0.09191497490974143, 0.02905440989707131, 0.03539015800924972, 0.05009350614272989, 0.05573156122409273, 0.022096474858699366, 0.06888197647640482, 0.07373158499831334, 0.06324185451376252, 0.02707927476876648, 0.05846867607033346, 0.016230593428190332, 0.03136563958832994, 0.029194731469033286, 0.02190914750826778, 0.06956151657504961, 0.005454545616885298, 0.09395181405125186, 0.04946155255311169, 0.034287623420823365, 0.013485673971445067, 0.06004077491525095, 0.112455885973759, 0.033143101827590726, 0.03225647655199282, 0.01691617646429222, 0.051684058489627205, 0.019532642218109686, 0.005224895903666038, 0.013770422119705472, 0.058973948762286454, 0.0002407691147254809, 0.03217025012418162, 0.056505194515921175, 0.008630370393802878, 0.01483956933952868, 0.07113665080396459, 0.09999843998230062, 0.059529572463361546, 0.010947835980914533, 0.03947970340959728, 0.04270181176252663, 0.012439684542187024, 0.019095671232207678, 0.0046127321456879145, 0.04770579071191605, 0.06868516633403488, 0.0283838813265902, 0.09038512653205544, 0.011125110013381345, 0.025033279380295426, 0.05029756706790067, 0.04198732764052693, 0.030117039204924367, 0.005896905058762059, 0.07050871223327704, 0.02935072534455685, 0.008281573973363265, 0.046673103352077305, 0.04504553638980724, 0.04012084107671399, 0.04640069433662575, 0.019961870748375077, 0.025181744167639408, 0.04467872618988622, 0.005878484489585389, 0.08165973340510391, 0.038865116075612605, 0.019223014496674296, 0.025891307850542944, 0.05248788234894164, 0.02851967394235544, 0.023891166056273505, 0.027788144543592352, 0.03645464268629439, 0.015415914731420344, 0.018386422962066717, 0.04409867098729592, 0.0302741463019629, 0.03458109829807654, 0.03480774648778606, 0.043988016768707894, 0.026598561598802917, 0.03645411205070559, 0.06356775382300839, 0.07627465791301802, 0.06677069250144996, 0.05800072227430064, 0.05363566568121314, 0.14335836604004726, 0.042214224449708126, 0.003342795016578748, 0.01223522192958626, 0.05411598365753889, 0.03894263711117674, 0.021399329161795322, 0.05867942745680921, 0.044591494151973166, 0.032969324238365516, 0.017478117697464768, 0.09305455751018599, 0.08872138729202561, 0.06172683053591754, 0.05380634480388835, 0.020281825454731006, 0.05993494836729951, 0.010911352928815177, 0.01882423628558172, 0.004952287436026381, 0.0273230981110828, 0.027030152014049236, 0.040591114084236324, 0.029766715815640055, 0.017406955012120306, 0.021308284340193495, 0.07132814716896974, 0.08609221040387638, 0.05240662088908721, 0.04358592857897747, 0.01429479212674778, 0.08649524854263291, 0.014566995196219068, 0.04324523084505927, 0.030534515826730058, 0.028885101892228704, 0.04569801407342311, 0.01104249506170163, 0.05746824244852178, 0.017039371123246383, 0.045121892253519036, 0.035395779777900316, 0.014176768381730653, 0.0424650963395834, 0.020583506629918702, 0.01864941412350163, 0.05342589764040895, 0.03514749798341654, 0.021403084429039154, 0.033881060080602765, 0.036793559265788645, 0.06596106133656576, 0.1098809452378191, 0.017618081183172762, 0.03044100336410338, 0.018906212062574923, 0.07689647376537323, 0.021558228545472957, 0.05493717748322524, 0.04280029846995603, 0.06125793792307377, 0.03515425523801241, 0.03141830980894156, 0.0602880659425864, 0.03792724550294224, 0.056188783564721234, 0.02678406141058076, 0.03432425583014265, 0.017898767000588123, 0.017938429227797315, 0.04262010130332783, 0.014133945533103542, 0.010936148082691943, 0.07128177036065608, 0.06278707383899018, 0.02714614227443235, 0.022245529653446283, 0.01857235507486621, 0.038670591748086736, 0.07113909989129752, 0.010972227591992123, 0.03946145028749015, 0.035603558862931095, 0.030918905649741646, 0.08111100425594486, 0.021808041019539814, 0.09560181613778695, 0.019254678227298427, 0.04563468290143646, 0.05770313218818046, 0.01889503160782624, 0.01618055783183081, 0.0150940155981516, 0.02773394364339765, 0.05357283174816985, 0.010963859876937931, 0.03324811943457462, 0.04041565924126189, 0.019409434571571182, 0.007328769997911877, 0.059138649885426275, 0.0039861280492914375, 0.018370661600783933, 0.0332995799544733, 0.02395884250290692, 0.09560865873936564, 0.022800496553827543, 0.044355220306897536, 0.0033453389596616034, 0.039210856702993624, 0.04225115371809807, 0.04964853294950444, 0.029042917740298435, 0.03743158362340182, 0.06065127672627568, 0.07471493066987023, 0.04533106657618191, 0.014989840328780701, 0.11004908621544018, 0.037567359540844336, 0.0562686646298971, 0.018244867569592316, 0.020589441955962684, 0.048776012190501206, 0.030871269045746885, 0.05724817339796573, 0.008714108771528117, 0.06556889566127211, 0.03999291337095201, 0.0319169773865724, 0.04666850574722048, 0.040912849945016205, 0.025725705017975997, 0.0702783718588762, 0.014193028837325983, 0.012608796805579914, 0.02413000402157195, 0.05514911259524524, 0.05058069640654139, 0.027486303806654178, 0.02994417074660305, 0.07787005277350545, 0.010892715745285386, 0.02507154636987252, 0.01719649491860764, 0.024940221483120695, 0.06086541230615694, 0.058895373877021484, 0.045582836464745924, 0.047872696013655514, 0.022795286677137483, 0.00619068839114334, 0.023140953089750838, 0.030182457667251583, 0.06928072500159033, 0.03963348382967524, 0.0059503893226064974, 0.03265345505496953, 0.016675893166393507, 0.0357830918073887, 0.006409435954992659, 0.01956718919245759, 0.03824113686277997, 0.007543238152720733, 0.011373770303180208, 0.022403686889447272, 0.03618620045017451, 0.006369184184222831, 0.06655043049249798, 0.06720982128172182, 0.02206601155194221, 0.03926042474631686, 0.036091231522732414, 0.04360996674222406, 0.08744906415813603, 0.058068443249794655, 0.09025461244164035, 0.08662168824230321, 0.04720425102277659, 0.008301072048197966, 0.01819838500523474, 0.03642948388005607, 0.013749827521678526, 0.04445135811693035, 0.057266886651632376, 0.06780173600418493, 0.03624819946708158, 0.011350606946507469, 0.08386730361962691, 0.07601806035381742, 0.05302133438817691, 0.04336962221714202, 0.10310001613106579, 0.03573295231035445, 0.022463741479441524, 0.0469088539830409, 0.047918048658175394, 0.02737176815571729, 0.033924093513633125, 0.06204167926625814, 0.04121441423194483, 0.030193925704224966, 0.06096185439673718, 0.05811377734062262, 0.021987291947880294, 0.04485844467126299, 0.041250215435866266, 0.04198000635369681, 0.12840322946431115, 0.12887581426184624, 0.100934006186435, 0.07804779714206234, 0.11575004944461398, 0.15056945878313854, 0.12813417124561965, 0.10908722571912222, 0.18480563652701676, 0.12084816611604765, 0.12384763016598299, 0.15784878458362073, 0.09868335429928266, 0.11851391129312105, 0.1230577623937279, 0.1301770069403574, 0.10247418525977992, 0.12598786532180384, 0.15369073895271868, 0.1815720842569135, 0.19879439292708412, 0.11877144395839423, 0.12448155044694431, 0.09498820101725869, 0.17433872708352283, 0.1030451936821919, 0.14487292617559433, 0.11285053042229265, 0.1319114357465878, 0.1424564339686185, 0.17896537960041314, 0.16231088811764494, 0.1628392082056962, 0.1435708429198712, 0.17474336083978415, 0.10348858981160447, 0.11111560437711887, 0.12447166503989138, 0.06307902731350623, 0.20223809173330665, 0.09828446476603858, 0.15439474023878574, 0.12996237783227116, 0.12117946083890274, 0.1471650938037783, 0.11196001258213073, 0.11402960270061158, 0.06899694257299416, 0.10274773347191513, 0.19597964943386614, 0.1008138970064465, 0.10145402164198458, 0.24542191356886178, 0.08769725318416022, 0.23830507358070463, 0.13627038075355813, 0.07052439381368458, 0.1747405406786129, 0.10338043663068675, 0.22189541661646217, 0.22181315696798265, 0.13062682264717296, 0.12742280785460025, 0.139968873700127, 0.23316421662457287, 0.17257149534998462, 0.09365880672703497, 0.08267779674497433, 0.16201912018004805, 0.08922175809857436, 0.1955651302705519, 0.13878531142836437, 0.23906044632894918, 0.22610015817917883, 0.10914773301919922, 0.13697736547328532, 0.16458387864986435, 0.2725989755708724, 0.17950643494259566, 0.15435427834745497, 0.12499929493060336, 0.16295324661768973, 0.15967979648848996, 0.18212499911896884, 0.07943349817651324, 0.18425567541271448, 0.28724297415465117, 0.13112527871271595, 0.1820016244892031, 0.0847864015668165, 0.09082678603590466, 0.1336582435760647, 0.14330332836834714, 0.1827853175927885, 0.1592641492607072, 0.16563253331696615, 0.19023971603019163, 0.14927577663911507, 0.08404524094657972, 0.09984004340367392, 0.1394374217488803, 0.15119654388399795, 0.08120554644847289, 0.1583147791097872, 0.17261252127354965, 0.17820908658904955, 0.10191569686867297, 0.1530996331712231, 0.05664746793627273, 0.13878868077881634, 0.19248023018008098, 0.14392400131328031, 0.08244041338912211, 0.11450467369286343, 0.14389039686648175, 0.12596387910889462, 0.2990567480446771, 0.20673534338129684, 0.074637873476604, 0.20610465144272894, 0.1913391484413296, 0.15897487493930385, 0.16005741606932133, 0.11216672297450714, 0.0970169878564775, 0.14559037517756224, 0.1257889103726484, 0.08882270529284142, 0.09678239497588947, 0.11206556082470343, 0.12164967818534933, 0.1218467258149758, 0.12688203452853486, 0.22137181658763438, 0.11724652344128117, 0.14650222234195098, 0.1315634130151011, 0.12965523259481415, 0.13909214496379718, 0.17465362034272403, 0.18420384381897748, 0.12991811614483595, 0.16020724084228277, 0.1752517616841942, 0.1974493541638367, 0.1849253597902134, 0.14683053363114595, 0.09154022001894191, 0.16368512297049165, 0.1312681718263775, 0.11415626504458487, 0.1166280620964244, 0.15229444747092202, 0.17570761847309768, 0.2541880134958774, 0.11689098275383003, 0.26538432051893324, 0.19938986253691837, 0.22907842649146914, 0.09945915837306529, 0.16015892702853307, 0.09993195097194985, 0.1045013393741101, 0.12412025811499916, 0.18539423384936526, 0.12984565284568816, 0.12277555331820622, 0.12207557447254658, 0.1495319660170935, 0.13597571844002232, 0.1521700932062231, 0.1699617033591494, 0.11741217822418548, 0.1939409549231641, 0.09246075773262419, 0.21314374404028058], [0.024502356209268328, 0.05441022294689901, 0.03463456632744055, 0.03971983271185309, 0.057642717656563036, 0.016862207485246472, 0.0642443475953769, 0.05905116551730316, 0.05748723400756717, 0.008162060366885271, 0.023568676915601827, 0.04493378750339616, 0.01687983349256683, 0.02051048300927505, 0.03462570508418139, 0.03476014513580594, 0.012858644531661412, 0.0644821094465442, 0.03882932600390632, 0.0117758427222725, 0.025287110584031325, 0.03399855319003109, 0.03221454520826228, 0.033651005433057435, 0.06360787432640791, 0.03467944770818576, 0.05056255831732415, 0.03450131000136025, 0.01927732115291292, 0.02614537468616618, 0.052323901109048165, 0.03710201068315655, 0.037819318677065894, 0.045458482200047, 0.038977911390247755, 0.043927427832386456, 0.04347044297901448, 0.02619997634610627, 0.007566684453195194, 0.035575787696870975, 0.04770189443661366, 0.021375237192842178, 0.01412608247846947, 0.08190207430743612, 0.01840289492974989, 0.03317191200039815, 0.049984855722868815, 0.0066283848263992695, 0.026120809598069172, 0.047725312906550243, 0.07766393609927036, 0.056772738753352314, 0.00741621911402035, 0.03567669751646463, 0.05324313635355793, 0.07638915645657107, 0.04999064818548504, 0.06251118044019677, 0.04472244610951748, 0.10727839660830796, 0.024210317387769464, 0.04525164935330395, 0.020618959024432115, 0.016902420757105574, 0.0589115712500643, 0.033884114018292166, 0.029721832579525653, 0.05929744351305999, 0.004792667241417803, 0.025702280981931835, 0.05442941859655548, 0.010022657061199425, 0.07439168082782999, 0.16826549515826628, 0.020411291261552833, 0.02529325556679396, 0.055059112346498296, 0.02850124456017511, 0.05198768594709691, 0.05334386063623242, 0.02402905152848689, 0.04795540095074102, 0.059935193276032805, 0.044549054437084123, 0.028811074516852386, 0.0018602321142680012, 0.04622894281055778, 0.006278496985032689, 0.009948138940671925, 0.04650889946788084, 0.02646869317686651, 0.06969232010305859, 0.08666738969623111, 0.005962161176285008, 0.04354874698037747, 0.00620039985733456, 0.015246565908455523, 0.022768495146010537, 0.03437797618971672, 0.017882454594655428, 0.00399615539208753, 0.05418170825578272, 0.05486715213919524, 0.07106592413038015, 0.062279986595967785, 0.009207745515595889, 0.040429262808174826, 0.08511663501849398, 0.01704204099951312, 0.04818997527763713, 0.03140065040497575, 0.017440117881051265, 0.04079891172295902, 0.016643611597828567, 0.043298669188516214, 0.00698267916959594, 0.0728588861238677, 0.025592689889890607, 0.02170238887629239, 0.01865118229034124, 0.035657286643981934, 0.01048946238370263, 0.017426267550035845, 0.06071653748222161, 0.01692264984740177, 0.03514750540489331, 0.03820586258370895, 0.016461972809338477, 0.041537074066582136, 0.04924157627101522, 0.026493814875721, 0.032013426898629405, 0.031933441932778805, 0.041212974465452135, 0.014869361930323066, 0.037235905256238766, 0.02018622570176376, 0.045514833473134786, 0.022881336844875477, 0.09518251012195833, 0.025123134910245426, 0.04231013219396118, 0.05486880341777578, 0.04525272917817347, 0.03841919664409943, 0.051756391912931576, 0.00848158369990415, 0.01503840461737127, 0.036182968397042714, 0.08556645072530955, 0.0386042919853935, 0.044846622258774005, 0.003556171982381784, 0.057256132931797765, 0.06946330817299895, 0.04550905214273371, 0.04515596796409227, 0.04144911472394597, 0.021218885231064633, 0.025829327387327794, 0.0716259636101313, 0.05718706495827064, 0.04063002488692291, 0.01556234046802274, 0.014464729101746343, 0.014563203749276, 0.014813897523708874, 0.06821972841862589, 0.05475863901665434, 0.03141693312500138, 0.027838595742650796, 0.060775987221859396, 0.03138388157822192, 0.02585163078038022, 0.06050680654880125, 0.042692991337389685, 0.04583991270919796, 0.023525775213784073, 0.017184895150421653, 0.017925013053172734, 0.03710333912749775, 0.020824940256716218, 0.031591760853189044, 0.06695931675494649, 0.035521677709766664, 0.031194804614642635, 0.06223754688107874, 0.02725287980865687, 0.04397879929456394, 0.04793875828909222, 0.03742293018149212, 0.0236856059927959, 0.04842113943595905, 0.015665885839553084, 0.04081645980477333, 0.03206387067621108, 0.04799385533260647, 0.028290968148212414, 0.04448098465218209, 0.01652543756790692, 0.07191815457190387, 0.04695604344306048, 0.048224050988210365, 0.015228043757815612, 0.02709835724090226, 0.040260498426505364, 0.05635740322759375, 0.03215248681954108, 0.012545571389637189, 0.06819766436819918, 0.006938341412023874, 0.06655560326180421, 0.07845373707823455, 0.05628362261631992, 0.01682470305240713, 0.04976867181540001, 0.10234899236820638, 0.07719083179836161, 0.058775580109795555, 0.04730873057269491, 0.014746844481123844, 0.06949146525585093, 0.06895916725625284, 0.04526540506049059, 0.058541851831250824, 0.043776727325166576, 0.03631289990153164, 0.037605528195854276, 0.024441552050120663, 0.056018267714534886, 0.045938815019326285, 0.01229899931786349, 0.03864579659420997, 0.026965648248733487, 0.008519149359926814, 0.02426689872663701, 0.02755327706836397, 0.02291377055371413, 0.008385476503462996, 0.04813361658307258, 0.07812278374331072, 0.02294330803124467, 0.016134065990627278, 0.03931146224203985, 0.021143996964383405, 0.027558529618545435, 0.0623364417697303, 0.05109267440275289, 0.014175586511555593, 0.012373495173960691, 0.004295667640690226, 0.07060859788907692, 0.03949581543565728, 0.09937701004673727, 0.011264403710811166, 0.01894043063657591, 0.04342224790889304, 0.05420350884378422, 0.059005438088206574, 0.015824364054424223, 0.08872238919138908, 0.04231342361890711, 0.035588148166425526, 0.008343925510416739, 0.05555374635150656, 0.02687425832846202, 0.03923014512110967, 0.010361839886172675, 0.07505486399168149, 0.045302141370484605, 0.04632893607777078, 0.027610192373686004, 0.00497552407978219, 0.020785610140592325, 0.025379340986546595, 0.007829046644474147, 0.024181926528399345, 0.05084751333924942, 0.02279503249155823, 0.02893990578741068, 0.12054342543706298, 0.06493978449725546, 0.03454630270425696, 0.047078230636543594, 0.06275611885939725, 0.07981699556694366, 0.10229134975816123, 0.04323647721321322, 0.01711034641630249, 0.055558444146299735, 0.015183442537818337, 0.04487214842811227, 0.03606924168707337, 0.05730047254473902, 0.026812676769623067, 0.0661913349176757, 0.0054384544637287036, 0.08056577804381959, 0.07059886091155931, 0.00955927303948556, 0.03463239183474798, 0.04181792872259393, 0.0208333543560002, 0.07109976606443524, 0.052850247084279545, 0.040968885805341415, 0.04209484257444274, 0.030544826113327872, 0.0688960772822611, 0.013879856433050008, 0.03671078011393547, 0.01965808929526247, 0.0187387445839704, 0.01763323769409908, 0.03279518299677875, 0.04416959433001466, 0.06553733954206109, 0.024310904373123776, 0.022395224550564308, 0.012031060814479133, 0.06801447263569571, 0.028963480108359363, 0.0458057108335197, 0.05859133081685286, 0.0016307217856592615, 0.08218533723265864, 0.08881758447387256, 0.0894839217653498, 0.020097858177905437, 0.08724095852812752, 0.010963210497720866, 0.04971488466253504, 0.03812314651440829, 0.028283841675147414, 0.040535571752116084, 0.01177335745524033, 0.05452877361676656, 0.04877179679169785, 0.04276710591511801, 0.026056424576381687, 0.061124206622480415, 0.06189828891365323, 0.07193229248514399, 0.05652280196954962, 0.01797538632672513, 0.04178689210675657, 0.03614275141444523, 0.10993217569193803, 0.05263148792437278, 0.037336915265768766, 0.03530939378833864, 0.02747846858255798, 0.1945136851281859, 0.142579912499059, 0.1169280159228947, 0.14953382138628513, 0.20076188578968868, 0.07452302612364292, 0.1612586117698811, 0.1069929962977767, 0.13561398081947118, 0.1312911487184465, 0.10514616922591813, 0.15944800892611966, 0.09018990458571352, 0.11710484744980931, 0.1128500554477796, 0.0811243406496942, 0.11818131781183183, 0.1486022924655117, 0.10785638864035718, 0.11076078357291408, 0.10150269168661907, 0.206370132509619, 0.11230953445192426, 0.11747653727070428, 0.16116011393023655, 0.17291920637944713, 0.17060425481759012, 0.2027224173070863, 0.08328589028678834, 0.10992535535478964, 0.12676894606556743, 0.08164089027559385, 0.13141332106897607, 0.1299236377235502, 0.21386263280874118, 0.10244414312182926, 0.18188424641266465, 0.08804035547655076, 0.09855194221017882, 0.14555626607034355, 0.21170201827771962, 0.17548770527355373, 0.11018437973689288, 0.14834555389825255, 0.07030150460195728, 0.1672456506639719, 0.1423393824370578, 0.13952671695733443, 0.13184210431063548, 0.18972439836943522, 0.22723689093254507, 0.16605598793830723, 0.23989337350940332, 0.15374346112366766, 0.19618883117800578, 0.19577892817324027, 0.1559874930535443, 0.1738975351327099, 0.08114069016301073, 0.1483586899121292, 0.1271210060804151, 0.21613240242004395, 0.14648268901510164, 0.1495394023368135, 0.23784446704667062, 0.09909084532409906, 0.10939578103716485, 0.11319723213091493, 0.14663263253169134, 0.09380553674418479, 0.16355033410945907, 0.09276713855797425, 0.1626918770489283, 0.3843079344369471, 0.08933133620303124, 0.23155007511377335, 0.16876038891496137, 0.24350555468117818, 0.10904223672696389, 0.12445680724340491, 0.12083690773579292, 0.2228713408112526, 0.09667879858170636, 0.14628809789428487, 0.1778884491068311, 0.11632887268206105, 0.1674169086618349, 0.10184798331465572, 0.0976377424376551, 0.09237000049324706, 0.16387192154070362, 0.19772736268350855, 0.27245675039011985, 0.12007962766801938, 0.12375585618428886, 0.053196870867395774, 0.1397282991092652, 0.0964701066550333, 0.09229579314705916, 0.07672563137020916, 0.12325567833613604, 0.15375152084743604, 0.14494761591777205, 0.1203800416260492, 0.26163222966715693, 0.28456729429308325, 0.14481975871603936, 0.25123613595496863, 0.16810143599286675, 0.1765806513139978, 0.129658319929149, 0.14402419124962762, 0.18279778567375615, 0.10776810275274329, 0.18006876023719087, 0.08034544182009995, 0.16168773639947176, 0.1251968546421267, 0.1190921408124268, 0.12142304112785496, 0.08660640742164105, 0.15672031935537234, 0.15794925653608516, 0.09791523145395331, 0.08182345118257217, 0.17306015506619588, 0.1760072383331135, 0.1601342431968078, 0.10819834802532569, 0.12431651164661162, 0.18347860226640478, 0.13958530209492892, 0.14386972063221037, 0.11839399507152848, 0.15212510421406478, 0.14950152311939746, 0.08648158560390584, 0.15973116795066744, 0.15320001606596634, 0.09671005042036995, 0.21832999074831605, 0.15642236190615222, 0.11841945815831423, 0.1782708481187001, 0.12126200992497616, 0.1403815671801567, 0.08708651759661734, 0.14647022093413398, 0.133674155222252, 0.20988662115996704, 0.17727113066939637, 0.17683572747046128, 0.1505074300803244, 0.2683671307750046, 0.1510001567658037, 0.1258456995128654, 0.10972360250889324, 0.14975747501011938, 0.12314097199123353, 0.08824659089441411, 0.20129522279603407, 0.15327921806601807, 0.19551669771317393, 0.14140228740870953, 0.19323120941407979, 0.1949115059687756, 0.11681760661303997, 0.20066556986421347, 0.15463127754628658, 0.20959791087079793, 0.12110712370485999, 0.18069186742650345, 0.10366264570620842, 0.05609336934867315, 0.13177686952985823, 0.13261470972793177], [0.03418835003685672, 0.06819229121902026, 0.06433271511923522, 0.020557744828693103, 0.008276632197521394, 0.024344102494069375, 0.04610792821040377, 0.0667381715902593, 0.04040071238705423, 0.030340754055941943, 0.05141331559570972, 0.017381063335051294, 0.06304864378762431, 0.03128005140752066, 0.023226361299748532, 0.035557723822421394, 0.015884646854829043, 0.06475330505054444, 0.044669861235888675, 0.02660631333128549, 0.027549911428650375, 0.040481569376424886, 0.06260591559112072, 0.07090666666044854, 0.06429552609915845, 0.026845388783840463, 0.028220243329997174, 0.01535661527668708, 0.01112386969907675, 0.11230435426114127, 0.04001118504675105, 0.04528715740889311, 0.01339124959486071, 0.028860026577604003, 0.022815753254690208, 0.030656140843348112, 0.05747711482399609, 0.041681989532662556, 0.01668344822974177, 0.02925149463408161, 0.03871281252941117, 0.07186915056081489, 0.08569204437662847, 0.02360512564337114, 0.019586908056226093, 0.025776942893571686, 0.06534826999995857, 0.06877358580823056, 0.016267205428448506, 0.0465740192157682, 0.03975314772105776, 0.09278298341087066, 0.046570152626372874, 0.012222350305819418, 0.006406694647012046, 0.026951573418045882, 0.008570676673116395, 0.05199416489631403, 0.07504143111873418, 0.07885476399678737, 0.031186885898932815, 0.008672901021782309, 0.048242549019050784, 0.036133326138951816, 0.05946343968389556, 0.041660678762127645, 0.021894124583923258, 0.034608520654728636, 0.06518331283587031, 0.0417435284180101, 0.04416008370753843, 0.06436014489736408, 0.04816037842829246, 0.0426163237716537, 0.014991572315921076, 0.03847446438157931, 0.02855204642401077, 0.03841390513116494, 0.06012786223436706, 0.0526673373678932, 0.057229163285228424, 0.017645555490162224, 0.03104441024333937, 0.03168341609125491, 0.03948400786612183, 0.016663530841469765, 0.045184021146269515, 0.032700169540476054, 0.1058139611268416, 0.020835643881582655, 0.018151089789171237, 0.055876139012980275, 0.00831924817248364, 0.007188117242549197, 0.018450399802532047, 0.03363391377206426, 0.015309109476220328, 0.05166008340893313, 0.047152170809567906, 0.07717494241660461, 0.05051061911217403, 0.042363110405858606, 0.047862242863629945, 0.089332805655431, 0.056284984457306564, 0.027217412571189925, 0.034253206322318874, 0.05728760370402597, 0.03540913472534157, 0.010620064604154322, 0.04036386475490872, 0.03600545780500397, 0.02065732805931475, 0.04312294346163981, 0.039109368008212186, 0.01623981832381105, 0.07782638480421156, 0.03561843892384786, 0.0526950009225402, 0.0374193938478129, 0.027831029547087383, 0.020331374944362324, 0.05405434829299338, 0.02296435533935437, 0.023130553745431826, 0.05297143979987595, 0.03170277501340024, 0.05736601531680208, 0.05903215911530424, 0.04645900859031826, 0.0641981785884127, 0.09813178272452205, 0.04160381911788136, 0.01778232031938387, 0.06931047770194709, 0.04355077304353472, 0.03951404258259572, 0.05656363493471872, 0.022624930388701614, 0.01639104575588135, 0.07141520851291716, 0.014832563465461135, 0.02841549867298454, 0.031799038988538086, 0.0108286628346832, 0.048576723274891265, 0.007894822265370749, 0.03029197825526353, 0.01524509460068657, 0.013689264560525771, 0.007700666228629416, 0.030660283882752992, 0.044161861151224, 0.024820976905175485, 0.029189517881604843, 0.04663397361582611, 0.06941848987480626, 0.042468124302104115, 0.046418249839916825, 0.04165507554716896, 0.01997655042941915, 0.053417036397149786, 0.03265380015363917, 0.028765352653863374, 0.009228156432072865, 0.06364645116264, 0.04183458622719627, 0.01765260960382875, 0.04357513033028226, 0.08430954199866392, 0.03926901510567404, 0.009937447375705233, 0.041255239775637165, 0.013697667527594604, 0.029947584625915624, 0.026363998404121958, 0.004452544208106701, 0.007808811988070374, 0.035076763888355345, 0.05288562526402529, 0.02900079714891035, 0.01762147650879342, 0.04783725475135725, 0.03277969066402875, 0.027127900284540374, 0.02101993955875514, 0.03978304142947309, 0.024375191060244106, 0.0642268625961151, 0.07054832065477967, 0.01611350478924578, 0.05873791982594412, 0.047507722629234195, 0.04201624913548585, 0.04656464217987377, 0.05845918771228753, 0.029686604684684426, 0.032224753449554555, 0.04263268812792376, 0.07691303850151598, 0.09552459567203186, 0.051374397371546365, 0.0494227530725766, 0.013764150971837807, 0.014949692922527902, 0.058353272106614895, 0.026797594473464414, 0.041255814940086566, 0.027408790192566812, 0.021149078820599243, 0.017855575861176476, 0.020224168001732323, 0.03638574169599451, 0.02923282405390637, 0.02085165942844469, 0.006782622594982968, 0.0075352790827309946, 0.05561821300943848, 0.013346269879548345, 0.03570457629393786, 0.04634993143554311, 0.007094875199982198, 0.06485864549176767, 0.03945387295971159, 0.09120669885305688, 0.07373888773145154, 0.028218326733622234, 0.10145181004190817, 0.034701600816333666, 0.04324509725847747, 0.029081255233904812, 0.08765249425778165, 0.031390386502607726, 0.009995320051530143, 0.02970941273815697, 0.009806180005398346, 0.06490927480626851, 0.01207357474413584, 0.03878484909364488, 0.05502384919964243, 0.07849503017496318, 0.08598557862569578, 0.032254932884825394, 0.048124384265975095, 0.1094780332641676, 0.02451295036735246, 0.06857701315311715, 0.010393565771664726, 0.016999953804770485, 0.06008322576235514, 0.09152403377811424, 0.023945148022903595, 0.05094347303383984, 0.03861546501866542, 0.015462491919606691, 0.09841410312219523, 0.023348583745246287, 0.023673277064517606, 0.04535215841315221, 0.0903730740537867, 0.03932254250685219, 0.04807905017514713, 0.05098352674394846, 0.022747709444956854, 0.07269736510352232, 0.02749055260210298, 0.0255876451410586, 0.041199708575732075, 0.018494971336622257, 0.04355040939117316, 0.09017051226692274, 0.050294323882553726, 0.02938441699370742, 0.04403042679768987, 0.051211889294791035, 0.06426255247788504, 0.018802964477799833, 0.048238830859190784, 0.04947422472469043, 0.0757135497406125, 0.040367119072470814, 0.048943730143946595, 0.023906877322588116, 0.032220092762145214, 0.0373853107157629, 0.03416584440856241, 0.031596076441928744, 0.04532820559688844, 0.019743183947866783, 0.04380446880531963, 0.039720842032693326, 0.023839408677304164, 0.09982963107177056, 0.03495627621305175, 0.027758675714721903, 0.05708343887818046, 0.022865495702717453, 0.030225348236854188, 0.03886455946485512, 0.010276228513248498, 0.0355278894858202, 0.04965177613485139, 0.030842032138025388, 0.030599984384025447, 0.06286576375714503, 0.03178255588863976, 0.02476945515809348, 0.1577034720685333, 0.06538006360642612, 0.013042785285506397, 0.031462029728572816, 0.03189379640389234, 0.02950820908154128, 0.06421990867238492, 0.010882549249799922, 0.06548003089847043, 0.05236556156887673, 0.007529446729677147, 0.040688131339265965, 0.05251295580819715, 0.025449286549701355, 0.041747792056412436, 0.059359694860177115, 0.041556284559192136, 0.03758772407309152, 0.0225715068881982, 0.04577932377287652, 0.05596341929049231, 0.060589997592614964, 0.025689740541565698, 0.07826508313883096, 0.011898182983713923, 0.022118034248705953, 0.02382628936175024, 0.051778801062027924, 0.011539491879375419, 0.04063645188580267, 0.0684576015919447, 0.027185498365724925, 0.10189188877120614, 0.027377245205570944, 0.03263225189584773, 0.025292609898315277, 0.03606306330766529, 0.05737457970099058, 0.10189922119025141, 0.044175958246341906, 0.027386470101191662, 0.08780112417298369, 0.01181261706733494, 0.06847772121545859, 0.018109191842086148, 0.11612369111389853, 0.18157435522880405, 0.23166763130575418, 0.11509099262184463, 0.11441018345067278, 0.07653248001588508, 0.11137900743051432, 0.13159177789930254, 0.10324460876290686, 0.11066481645684689, 0.13880499318474904, 0.09849611044046469, 0.2040148081141524, 0.1285878461203538, 0.07983027258887887, 0.1285289938095957, 0.09316020223195665, 0.1819688660907559, 0.15273942437488586, 0.22839355777250603, 0.1984852142049931, 0.14895996311679482, 0.16464198881294578, 0.1796222396660596, 0.24370265426114202, 0.1447485273820348, 0.12071572244167328, 0.16574704670347273, 0.13728537160204723, 0.3649436985142529, 0.0918419030494988, 0.09195385602652095, 0.16840956086525694, 0.0908563903067261, 0.09207177587086335, 0.11538661230588332, 0.06872389902127907, 0.21256369625916705, 0.08483518293360248, 0.07765527523588389, 0.1912299933610484, 0.17988162027904764, 0.12395465528243221, 0.1533427755930461, 0.13639518030686304, 0.06157111311040353, 0.1458792487392202, 0.19356191041879356, 0.14984832872869447, 0.19240522873587906, 0.09325637714937329, 0.15330520807765424, 0.07003476930549368, 0.10509525789530016, 0.1259027112973854, 0.16688038042047992, 0.2076154711539857, 0.12603414565091953, 0.13615901407320052, 0.2688931650482118, 0.06289228811510839, 0.07074493041727692, 0.16590484214248136, 0.10966594505589455, 0.21432984445709735, 0.12829538056394085, 0.11692114363540895, 0.12640722328796983, 0.2218786143930629, 0.07027074258076027, 0.1835748291341588, 0.16350245074136183, 0.1093855468207039, 0.1117428601719439, 0.10216174108791165, 0.09210799267748371, 0.1291056425543502, 0.13143557065632194, 0.19204350595828146, 0.15951763722114265, 0.1061810644750949, 0.09337069015600719, 0.12488654785556719, 0.17309332906734198, 0.10984869149979204, 0.16979047504719347, 0.12638148560654372, 0.09970647166483104, 0.1607722823973745, 0.09340891818283126, 0.08025930073927157, 0.15416010282933712, 0.15350469737313688, 0.12455189862521365, 0.18952493875985965, 0.11734928863006644, 0.13135831308318302, 0.21252967620966956, 0.12721822742605582, 0.18280017538927495, 0.06447537074564025, 0.1295776039478369, 0.1928545843111351, 0.16563495271839201, 0.1702700657187961, 0.127519138623029, 0.11600612007896416, 0.12756920390529558, 0.10988924244884402, 0.10943566405330785, 0.19052360235946253, 0.15563427528832108, 0.13583745632786304, 0.12014708889182657, 0.13900108344387263, 0.1421482051955536, 0.21997493138769642, 0.13513876881916076, 0.1503755949670449, 0.20682189264334738, 0.14902711263857782, 0.3639052261132747, 0.15438310336321592, 0.08500689364154823, 0.15376352879684418, 0.11723761024768464, 0.12321569884079508, 0.11965973535552621, 0.16335376887582242, 0.12293156760279089, 0.12778709846315905, 0.18005400634137914, 0.16837689152453095, 0.14128735841950402, 0.14616393658798188, 0.13806370639940724, 0.09468898933846503, 0.2619563404005021, 0.140537180704996, 0.1690173798124306, 0.17735687841195613, 0.11849034810438752, 0.13101253163767979, 0.14169651927659288, 0.07499438637751155, 0.1679077502922155, 0.1480928823002614, 0.16657402185956016, 0.12969336414244026, 0.09468978343647905, 0.10877265900489874, 0.14947541436413303, 0.18382917798589915, 0.11199369124369696, 0.1288163979188539, 0.10065643553389236, 0.13941100129159167, 0.11125752527732402, 0.15624731895513833, 0.08462412355584092, 0.10433855670271441, 0.16752089839428663, 0.09536634752294049, 0.19639030942926183, 0.12218800242408179, 0.0853329488018062, 0.13188373879529536, 0.14983290689997375, 0.17308464593952522, 0.22382611379725859, 0.11324649589369074, 0.12953387660672888, 0.19150212407112122, 0.1243728183908388, 0.18233231065096334, 0.0819214443617966], [0.04016840903204866, 0.044321641835267656, 0.011766886855184566, 0.07125254458514974, 0.028389844483172055, 0.01624987071409123, 0.050216242525493726, 0.04913838805805426, 0.08643080043839291, 0.07162041976698674, 0.047808559611439705, 0.02235290543467272, 0.09138956404058263, 0.03108070868620416, 0.0751363072777167, 0.03107726512098452, 0.002729528937379655, 0.04059057231643237, 0.110015088430373, 0.022694026192766614, 0.016163156324182637, 0.04541471033007838, 0.04513586689427029, 0.10521350428462029, 0.1037752591946628, 0.030650511653220747, 0.045771876320941374, 0.00811659732789849, 0.015614425319654401, 0.09044283593539149, 0.021543272414419334, 0.026019276374427136, 0.035044287506025285, 0.05170021875528619, 0.03770493516640272, 0.023106166772777215, 0.03201278865162749, 0.0665510242106393, 0.021379502686613705, 0.03636552930402104, 0.015257175837177783, 0.06736768351402134, 0.12958799401530996, 0.03681085872813128, 0.008532999690942233, 0.021944809559499845, 0.006772455635655206, 0.042545734395389445, 0.06161805024021305, 0.05883202415134292, 0.08442286794888787, 0.031152390874922276, 0.03724625821632799, 0.02501534909242764, 0.03722315886989236, 0.03761998894333374, 0.07227692360174842, 0.010301336296834052, 0.05677669068973046, 0.03542414466210175, 0.013174649157008389, 0.059771045052912086, 0.003337924672450754, 0.044896253384649754, 0.054740935083827935, 0.03222155479306821, 0.018178833124693483, 0.05813759285956621, 0.02463899858412333, 0.04815720945771318, 0.011443094317655778, 0.06042103283107281, 0.05980647147225682, 0.025572594386176206, 0.022747943221474998, 0.07214933357317932, 0.014276720830821432, 0.039392174512613565, 0.027395220022299327, 0.033526654879096895, 0.0739997452183161, 0.023969817011675332, 0.04026831695227884, 0.04370359609310981, 0.023173401641543023, 0.03968805023760069, 0.06329042807919905, 0.0335308368812548, 0.03233972696762066, 0.012486700525187189, 0.017472390172770247, 0.05060603332822211, 0.06672002607956529, 0.0644559042120818, 0.03412165322515648, 0.018676502513699234, 0.060086754674557596, 0.03639256945461966, 0.026315634495404083, 0.019808702600130346, 0.06957695324672386, 0.017029168448061682, 0.022625711499131285, 0.046014016843400896, 0.037836681221961044, 0.04581597102514934, 0.04585310067341197, 0.0068021396873518825, 0.0670568052737508, 0.0055774670727259945, 0.06847989570815116, 0.07999670662684366, 0.01770143735484453, 0.03830297260719817, 0.04637622201698832, 0.049228351199417375, 0.014264268520491896, 0.05147447227500379, 0.020310754371166695, 0.028650104541156907, 0.022830922753200866, 0.06166877232317347, 0.038175286099431105, 0.025253854946640786, 0.03475659395917319, 0.03651617415016517, 0.06274248560657725, 0.03955214444431476, 0.014793417958571808, 0.05179160682018846, 0.03831579320831224, 0.043767465322162025, 0.02794079133309424, 0.007603004696647986, 0.07847779008443467, 0.08703680112375878, 0.04654381380532868, 0.05364778495277278, 0.03131598619802389, 0.05827663051604759, 0.005884349775442388, 0.09037492200150155, 0.027804260280390736, 0.0193371475324966, 0.06676581659121439, 0.04834958155697677, 0.028473332386056427, 0.037161805521463975, 0.05226866305747535, 0.04308201401727274, 0.012460677116905572, 0.051464928255882114, 0.01918637837661663, 0.03167722657963168, 0.009914334114000667, 0.027605268223851454, 0.05378101901442278, 0.0622745392320212, 0.014174647694744635, 0.044759842930943705, 0.07816982848453335, 0.032973569323075935, 0.013148097896191757, 0.03230276801332366, 0.00464550167635025, 0.029508314837585203, 0.03359242771693971, 0.031867810102994554, 0.03964129864471033, 0.01295663400014746, 0.03259390141465701, 0.02901805579313077, 0.013136096440575784, 0.04858819316723384, 0.033958280546357855, 0.014887334891682258, 0.0333038732787827, 0.052326940203784034, 0.015389788350148592, 0.050925179093610495, 0.07561988328234293, 0.04620060761226341, 0.05385270305851009, 0.03949846861360129, 0.03579577511118259, 0.021068728347017895, 0.04477238151594065, 0.012461041696951725, 0.019696792296599597, 0.009425694806850515, 0.04401372105348855, 0.06436776675400324, 0.08595684266765602, 0.042786932390299626, 0.017649952715146355, 0.029794475849485025, 0.04560123801638838, 0.00812173391750548, 0.06364462547935545, 0.05444276612251997, 0.06834869142039679, 0.04545777715975419, 0.0573596810863819, 0.028184384609630797, 0.06808628284488805, 0.02326901252672542, 0.013128328009770485, 0.047197946478263475, 0.03475512450677343, 0.04167351791693363, 0.03314989990030881, 0.025275599873566534, 0.11748917604563758, 0.016995743972074706, 0.061025757022434846, 0.00658475164527772, 0.07401973125524819, 0.07677948160562664, 0.05576962597842794, 0.05024869664339349, 0.018773072624753695, 0.025654234341345727, 0.010909960474236868, 0.06218383394298144, 0.03677023356431164, 0.0178391706867842, 0.052879658396705054, 0.0808122156013269, 0.01458541066313046, 0.01483762398493127, 0.018651419777597766, 0.04982858168659732, 0.03422140529437456, 0.007471663575415732, 0.04537458240520209, 0.04099761805264279, 0.06829426230979152, 0.06677812139969319, 0.015632414979336318, 0.06264198396820575, 0.06628483810345642, 0.06221069226739928, 0.05272300215438008, 0.042229865211993456, 0.031506131854257546, 0.03577379269700032, 0.08485729893436655, 0.015012998119345866, 0.03694346196425613, 0.055251859230338596, 0.021678512130165473, 0.07463151327101514, 0.037579534473479725, 0.027145459498569835, 0.023749484498694073, 0.01327883926933282, 0.06151422749098856, 0.018242253354401328, 0.055891356751089916, 0.057419513032073155, 0.009206528393406188, 0.049874435280798934, 0.00810309209555271, 0.054921759365242906, 0.06996405005338602, 0.021411843626992777, 0.014874067146593006, 0.06451983281294815, 0.03304352787381504, 0.03542845282936469, 0.03866177503368817, 0.005822669418193982, 0.07255352946231142, 0.022408674121834338, 0.042850953759625554, 0.028758469234162476, 0.07634478344698437, 0.013384130543272477, 0.042525295648374595, 0.055011028598528355, 0.08592861879151314, 0.03787910609389655, 0.007349368770519504, 0.03432015917496756, 0.03375333275471348, 0.03709869328304194, 0.06200316551257856, 0.015662112018617336, 0.061245848337421194, 0.04029739058751147, 0.04804367199540138, 0.03475560690276325, 0.02026976741035469, 0.039033776556607336, 0.018367713419138454, 0.07894499431131408, 0.023303732050408144, 0.024121688256855123, 0.02018530543864472, 0.023977199525688775, 0.02482357813278213, 0.04863378329901025, 0.06084337423089892, 0.03809147165156901, 0.0030313910110635334, 0.023655890399822965, 0.06402242317562923, 0.014226164803403663, 0.03898984883562662, 0.03601662341679912, 0.05402096277975943, 0.0373301580111729, 0.04130648507270962, 0.05001771802199073, 0.018682697591430042, 0.01594201115949545, 0.0190573337386013, 0.023970772526809014, 0.033161507089971565, 0.046616184336016886, 0.056192386691691354, 0.04674563715525437, 0.016667935487930663, 0.036762014278792776, 0.051087457104586065, 0.017319739672529977, 0.052023854514118284, 0.03602236392907798, 0.05294463342579547, 0.018277275303262286, 0.038972300753812306, 0.041829658366623335, 0.017222685310116503, 0.08418021534453146, 0.024795652971079107, 0.09305631640017964, 0.0467111718171509, 0.004795345003003604, 0.02923931970144622, 0.01747604153933935, 0.0407630845438689, 0.01565998391015455, 0.05357319911126979, 0.027865606207342353, 0.07248360430821776, 0.06933296477654949, 0.047191337653202936, 0.016178865735128056, 0.04445720995136071, 0.0347356987913372, 0.06022277921147179, 0.013441320443234872, 0.16851962136570364, 0.30522408429533243, 0.07948032027343288, 0.13139460410457104, 0.15436959627550095, 0.16295890178298578, 0.17542263376526535, 0.12735439668176696, 0.16309630300384015, 0.11055234397645108, 0.08743494108784944, 0.0726198403572198, 0.12313530198298395, 0.06704085652017966, 0.2182610600721091, 0.1420181363937445, 0.2182459202595055, 0.14733295276528224, 0.24632614629808813, 0.06258739900658838, 0.09926642262144014, 0.1311042017186992, 0.23950413189595565, 0.24199685751227662, 0.12949194526299834, 0.10183276928728446, 0.11307880020467564, 0.12217170486110263, 0.13707391888601705, 0.14728775597177446, 0.08384389628190547, 0.1290667540160939, 0.09336996285128407, 0.11369837477104738, 0.12531035870779306, 0.09835619333898649, 0.1620583946350962, 0.15125811245525256, 0.1286362489918247, 0.14419544924749061, 0.21115962706971914, 0.20356330031063408, 0.12282179653993808, 0.13665668346220627, 0.10758921547676437, 0.09136125110671856, 0.11501749031594954, 0.10940000385744497, 0.12750046618748456, 0.174166415235959, 0.16822938225232065, 0.15557539329165593, 0.12211283028591424, 0.12605884432559833, 0.11739050009055063, 0.1689133158652112, 0.13178521126974374, 0.09216548685799353, 0.0896041645319201, 0.13171917496947572, 0.11754781313356943, 0.14946834911825135, 0.07940928189782426, 0.13210724398959428, 0.19568034127587453, 0.1820659835357219, 0.1440195454051718, 0.17093152710003778, 0.17548322270158678, 0.1550692188902758, 0.21462112257722765, 0.20265596540411934, 0.10169562039664015, 0.1656849289429374, 0.06234424916328862, 0.21183973120059818, 0.1451249298406765, 0.1427176847937517, 0.11079970179707743, 0.11628210995695554, 0.22357690060744062, 0.08219816896598786, 0.134061511780601, 0.140216751024127, 0.05360060291422997, 0.10797931798151694, 0.22254348965361714, 0.12340573317487724, 0.14865431701764464, 0.15556117374217138, 0.16740613267756999, 0.1132666229386814, 0.14925544179277495, 0.20307694125222042, 0.17169816565001383, 0.14245843776734546, 0.12935810635099187, 0.10138231533346698, 0.10671673182514496, 0.14852408494334668, 0.18803105485858396, 0.09123743118834682, 0.10136350188986398, 0.12237015514983796, 0.17176326684420928, 0.16256072471151128, 0.13628914224682376, 0.126021069008857, 0.15664834587369114, 0.0941657306975685, 0.12641399167478085, 0.13059620163403451, 0.11764667462557554, 0.09909869724651799, 0.17312129319179803, 0.11076177062932402, 0.11608219763729721, 0.20703104470157996, 0.05093421845231205, 0.11787458817707375, 0.13469888304825872, 0.1386158642708324, 0.15297481877496466, 0.13552271149819717, 0.10780628625070676, 0.08121641891193576, 0.15342586644692346, 0.2601886633783579, 0.10624465910950676, 0.07630413601873443, 0.1623062719590962, 0.17427275015506893, 0.19064858002820984, 0.127793837164063, 0.1686342089669779, 0.21539170935284346, 0.16223585698753595, 0.15249389223754406, 0.12443578219972551, 0.21862261957721785, 0.18778838741127402, 0.28027275286149234, 0.09144641997409053, 0.10896886058617383, 0.16886697616428137, 0.1777097993181087, 0.11105906756711192, 0.10740637255366892, 0.09959326445823535, 0.08700312988366932, 0.13003699335968122, 0.10425064188893884, 0.16549495398066938, 0.1405195175902918, 0.11359088210156187, 0.159995075664483, 0.16984561661956832, 0.24213071126723662, 0.09401540126418695, 0.26134041720069945, 0.14563583914423361, 0.12042401387589052, 0.10512819440918975, 0.1017097954172641, 0.09058378462214023, 0.0972725464089308, 0.09873180912109092, 0.0987176489434205, 0.1714912400348112, 0.16380808199755847, 0.07865081439376809, 0.09196788261760958, 0.1884504870395176, 0.15913219540379941, 0.21734554669819772, 0.09404226701008156], [0.026375618581369054, 0.05425600094895344, 0.010950813848467078, 0.061658701379201375, 0.0479990058374824, 0.03218513018509839, 0.02821338588546496, 0.06283447481109761, 0.0038237254966588807, 0.07740237357211299, 0.04208988873870112, 0.050869210026576184, 0.01361588192594354, 0.02201156017690664, 0.0624020179384388, 0.02035026074736379, 0.054395639745052904, 0.029389259507297538, 0.03535852025379427, 0.06356137135298923, 0.02317012877028901, 0.07134928353480063, 0.044285009425948374, 0.030600464924646076, 0.012857953406637534, 0.027228815670241602, 0.10780654600239359, 0.03340310213388875, 0.022287073225015774, 0.03844435545033775, 0.023655799486732576, 0.05348888000298757, 0.05722338566556573, 0.010242706630378962, 0.023319523097597994, 0.01860410786321154, 0.06872799567645416, 0.006996434412940289, 0.027286439726594836, 0.013134243854437955, 0.016958605046966113, 0.02323368073120946, 0.01646998800424626, 0.027981561215710826, 0.010388951468485175, 0.043233716423856094, 0.02230955102277221, 0.04346436478954274, 0.08389667040319182, 0.018223330444016028, 0.04569203607388772, 0.011558577134564985, 0.012841267143812729, 0.03596989408833906, 0.025009491691889707, 0.014857876267342363, 0.01872515400464181, 0.007960539442137815, 0.05379819973313715, 0.05178183644602541, 0.06507987229269929, 0.02297252824064344, 0.03487920417683199, 0.019909619841200765, 0.04122993996134028, 0.10241109528578818, 0.01917770267027663, 0.03577051611500792, 0.011275292872596765, 0.05309675514581613, 0.0828399189049378, 0.025124810308625456, 0.02640501690621022, 0.04071330127771944, 0.02625967656058492, 0.013675512564077508, 0.036671457419288345, 0.05471223994391039, 0.03619610070018098, 0.05396344633481931, 0.03833400180155877, 0.07824970583897084, 0.02121757534041535, 0.02352270643314114, 0.034134755842387676, 0.04416368683450855, 0.006528219473693753, 0.02449298473948147, 0.0047420226201211335, 0.06264712705160491, 0.023934898963489104, 0.06012779544107616, 0.04373444717202801, 0.059810085731442086, 0.026186992472503334, 0.07546324559370987, 0.08992183342343196, 0.06377521378453821, 0.024695811844139826, 0.047278424972319044, 0.034025493150693364, 0.04538526191026904, 0.023476745227526408, 0.028851464048784692, 0.1332962090964429, 0.0040778686343401205, 0.027883465991180856, 0.002749248264990456, 0.04418091208208352, 0.06920299245393835, 0.033228055472136475, 0.07933828805107623, 0.028660982570727356, 0.03195982157194521, 0.02387896329310024, 0.08624875903478824, 0.051022849438595586, 0.04430129956745077, 0.05355385132133961, 0.03011879809491802, 0.07982926326803863, 0.01272525369131472, 0.04736040631541982, 0.06484399549663067, 0.04223721618473064, 0.08972801413619891, 0.02722776738664834, 0.015019735892565222, 0.01415819613612257, 0.025977500881708693, 0.049381608405383304, 0.0472068374074297, 0.0440547432663152, 0.032287836002069525, 0.09159503504633904, 0.018751442730717827, 0.034240593522554263, 0.06863316404633224, 0.07542139588622376, 0.02400630841293605, 0.004524763526205788, 0.07871518828324042, 0.07260078942636028, 0.011663726472761482, 0.04035960111650638, 0.04726865459815599, 0.0164796730314265, 0.013346733721846249, 0.04441733435669448, 0.028472261838032864, 0.08559595851693302, 0.04929827635351103, 0.11815537975053303, 0.06906902737682685, 0.030413837048399728, 0.020170683274045587, 0.02348962520045461, 0.1216324232518673, 0.03269709333835635, 0.04260753303242382, 0.09130434322287329, 0.04122369107790291, 0.05262022212264128, 0.03431459677813109, 0.03025010442797793, 0.02397427731921198, 0.06017969011736568, 0.04744616147945635, 0.02622022213472519, 0.0386131012783153, 0.06568019554833882, 0.02561575769504998, 0.02804846953949891, 0.06682532199192792, 0.025984731255448423, 0.0016226909360739228, 0.019484337681205943, 0.032853166994755156, 0.09293193987105042, 0.017795434068830218, 0.0351491232868284, 0.03009414951520739, 0.0360868528514402, 0.03214363670849707, 0.03693119797389954, 0.013254736168164527, 0.029630902790813707, 0.04801409741048701, 0.025459748976572882, 0.021092554998176638, 0.014729725917277392, 0.05395477062847931, 0.02416632472886704, 0.03221204417059198, 0.05125989882799331, 0.018598790375108365, 0.029076498067297507, 0.0333591373055242, 0.006885670263727661, 0.013715698005398735, 0.03207628680684138, 0.058494365512160584, 0.04607692128047347, 0.00400046680624655, 0.06451929846662097, 0.029685571244044695, 0.02866639282729011, 0.042651356852729805, 0.03291763365268707, 0.020866823360847775, 0.032086354040075094, 0.028188826363475528, 0.06842520684585907, 0.044070747680962086, 0.050339387089479715, 0.08502275333739817, 0.03636985973571427, 0.0414503912179498, 0.04326548405515496, 0.032005875546019524, 0.04691994909080677, 0.11441386450314894, 0.058306498249294236, 0.026408312041894533, 0.039874054709798656, 0.01985096048883861, 0.03508261201204732, 0.011681922078423668, 0.030113489883660804, 0.06837606924818829, 0.04976263073331211, 0.0699040993640665, 0.034178464629803784, 0.03896950656780973, 0.05909746811084915, 0.04623414897650946, 0.024583465528849047, 0.015798075328348204, 0.027728924869734328, 0.017162408075819258, 0.06069458104320802, 0.08820078553981148, 0.044827652964158915, 0.018860458658309653, 0.07805873639881611, 0.01886522695713211, 0.036471756611717865, 0.05791885225335136, 0.04067061294335872, 0.010663440352800535, 0.035748084701481275, 0.03919098940968979, 0.02091919115628116, 0.033069413984776475, 0.028345478895062115, 0.02966225853015203, 0.04217033383611124, 0.08590950848883949, 0.04650074326491449, 0.006070362132959417, 0.04919561877613887, 0.016707989198039286, 0.0507390261918772, 0.07338989278650843, 0.07691546532441862, 0.016342310773325153, 0.017098943317250814, 0.047243354783859104, 0.038369316898752004, 0.027035708844778128, 0.02724259735259693, 0.05278580269077793, 0.12886656710179523, 0.033258969633607194, 0.03969729739765171, 0.0526243558852002, 0.011703566815413069, 0.016203710983972996, 0.05150687815330457, 0.06150724017061293, 0.04595219223119784, 0.05889233107154723, 0.03481518280750606, 0.03016938473592745, 0.01831953504733974, 0.10148606757866219, 0.08248609257861972, 0.07406970747979358, 0.04608429822837934, 0.028763539958163165, 0.04178986811893992, 0.05609817846561782, 0.021755253910669126, 0.03313555418571923, 0.052135640507913195, 0.029889470752095804, 0.04033270197396632, 0.022242143604671583, 0.03186172078130767, 0.013500187596946489, 0.01427858918759739, 0.04549726683762856, 0.01749939507135423, 0.027805518220702652, 0.038781709808972664, 0.05285415449179709, 0.04178537812549621, 0.032948358566500247, 0.03940585971577093, 0.029943820081825834, 0.04005375463748351, 0.011563945645320928, 0.017798653134377673, 0.02457160229823785, 0.035681168956216425, 0.04191551743133459, 0.039628771191928536, 0.022877583433000837, 0.04542312628473155, 0.0629276737163309, 0.005147609108462348, 0.04669399480917491, 0.020373950101202354, 0.025870191893773153, 0.06005843802995514, 0.02654765768966172, 0.04930596871417947, 0.0168881177160074, 0.07054024608805776, 0.06676128206891008, 0.024470597854815423, 0.043378427799325436, 0.025131283691735007, 0.10087491638842039, 0.050616460503079, 0.06715021940181032, 0.03561120669473894, 0.0032896136417548405, 0.020001943012175616, 0.0329024233360542, 0.021456296417454723, 0.05396836677391548, 0.014766311942366883, 0.029609703342430294, 0.009158901993941981, 0.01624805801839102, 0.06555202664458193, 0.039187872389447875, 0.02749603892880259, 0.022198173210199457, 0.032859293423825875, 0.028057230592821725, 0.08406962791923434, 0.20326181023847312, 0.16357357817469165, 0.19410522188991308, 0.13413161505013704, 0.09435664818738587, 0.11201899847947061, 0.13024780782870948, 0.11492298523080535, 0.14663852518424392, 0.0891556401620619, 0.11516992744873278, 0.08910309610655531, 0.1831929199397564, 0.12360122229438275, 0.1336085345246829, 0.1299647823907435, 0.1462996902409941, 0.15450242586666718, 0.21146274986676872, 0.12084665955626406, 0.1535190356662497, 0.1172253351251129, 0.0761773029807955, 0.17389314161846414, 0.2346279693301767, 0.16715409932658076, 0.09892029978800565, 0.1532610651338473, 0.1544699346413836, 0.14343078481033444, 0.11396886533475481, 0.15726843994343653, 0.12642375833820552, 0.100223837653175, 0.15016605699202046, 0.14724442939041182, 0.10271682302118279, 0.16952690872130916, 0.16826432256493717, 0.1273617587867193, 0.11575578624615446, 0.14093192905420437, 0.11325795465381816, 0.08524752760422416, 0.2435810014139861, 0.1624977312167175, 0.14176752796629444, 0.26902342680841684, 0.12652225617785007, 0.14544228703016415, 0.09891158697428182, 0.13210316217737272, 0.1560870002140291, 0.1509477462968789, 0.21941088431049138, 0.12504593149060383, 0.11720540103851818, 0.16040863003581762, 0.1652075647143647, 0.14973047567764297, 0.16424063534941524, 0.17495089501608163, 0.10039877670351416, 0.1179210763075389, 0.10387621354311705, 0.192798878706526, 0.12394488119753078, 0.10894474078668281, 0.1817584375385195, 0.2171005934360437, 0.15420641284435987, 0.11924421429284848, 0.07768659386783838, 0.10341118380893022, 0.14046568219782785, 0.20310656778747216, 0.12494275812059641, 0.18679021362913772, 0.13826079113641754, 0.1415189530234784, 0.31471927009988576, 0.15801204222952947, 0.11476792089524679, 0.12063813832355663, 0.16618476540315896, 0.13828252122038975, 0.08041828361456282, 0.1613305407227017, 0.15388101077405736, 0.07751353245112114, 0.13284004060551524, 0.13219944841694087, 0.10916771905613132, 0.05774974277301226, 0.2906538255047053, 0.249700365238823, 0.1871361435041763, 0.17751413950463757, 0.13403556629782543, 0.1525146872154437, 0.1227712191757746, 0.12484258302720264, 0.1678664275095798, 0.20470833027502522, 0.12124951957957819, 0.11731462291209027, 0.059893042998737656, 0.15181444119662046, 0.14397903898498043, 0.09032427784404717, 0.16535955655854195, 0.1660320462542586, 0.2039677114225924, 0.16913400089833885, 0.12715906341327354, 0.17967019724892452, 0.13110203464748338, 0.20070662547368556, 0.14876957255182788, 0.12085448179277591, 0.09889712251606397, 0.09267176516004838, 0.14346642274176702, 0.13081881625112146, 0.10183181191678159, 0.10590429534204304, 0.08447547879768535, 0.08926246489863843, 0.12597245833603665, 0.10456057018018328, 0.1244288134330418, 0.12148454290581867, 0.09166468560579233, 0.2146444408572279, 0.11617778625804931, 0.10714763760915957, 0.08952571952249855, 0.20843618258368224, 0.14778146229218692, 0.17408847488695756, 0.13296012009959668, 0.22419580724090338, 0.17246024741325527, 0.13388887338805944, 0.12194483031635173, 0.11227068302105181, 0.12561597512103617, 0.12432570685632527, 0.11264767177635804, 0.1627328436006792, 0.18147452152334154, 0.2798585157142952, 0.12473969167331234, 0.18933529034256935, 0.08391270079300739, 0.09201857872540131, 0.31987036869395524, 0.14377290004631504, 0.10346697104978375, 0.2070714917499572, 0.11615762952715158, 0.1273838451015763, 0.09835650504101068, 0.08734333780012093, 0.1204954826971516, 0.1622222163132392, 0.11954522196901962, 0.08419633479206823, 0.12653175566811115, 0.2240023887134157, 0.11776409723097458, 0.08776421716902405, 0.12310784994042479, 0.10640480715665035, 0.10899237182457], [0.018699893153097946, 0.018017987458733842, 0.025833288600551896, 0.031038641900522634, 0.07346874597715214, 0.021458981136674993, 0.014614118790632347, 0.03959376408602111, 0.025803086900850758, 0.05945012184383813, 0.005883231451662141, 0.024745992159296293, 0.030065398714214098, 0.06002275556966197, 0.03386771626537666, 0.07681275950744748, 0.009656014772190247, 0.06226416400750168, 0.016481253805977758, 0.021778010013804305, 0.01604983594006626, 0.06397868099156767, 0.01801237311156001, 0.030267068068496883, 0.036823753544013016, 0.03720360327861272, 0.06381358281942084, 0.07876254472648725, 0.006016901525072171, 0.05373534724640194, 0.009155146726698149, 0.06608694442547858, 0.047669440318713896, 0.019213147643313278, 0.07179021573392674, 0.027860032678290736, 0.002006004760914948, 0.03174337791278958, 0.0076397238444769755, 0.03668561388622038, 0.03941902170481626, 0.015907740635157097, 0.05069444167020265, 0.0365374366811011, 0.02539339169743471, 0.04424343060236424, 0.08527154350304045, 0.03189410439517815, 0.009485020236752462, 0.019801034359261394, 0.09262957406463102, 0.037681071407860145, 0.03671099904750008, 0.03007701332535362, 0.020348323741927743, 0.020918001864629332, 0.0612561827438185, 0.051087742831441574, 0.02062532294075936, 0.021315562953532208, 0.035828952823067084, 0.07298968965187669, 0.02810109523124993, 0.023469603911507875, 0.027794263551186305, 0.0327556005504448, 0.033631416445132345, 0.023445068509317935, 0.011895434254256543, 0.0465486340544885, 0.0547236356214853, 0.028362060329527594, 0.07080911134835333, 0.08103259635390714, 0.012033381881337846, 0.019120165816275403, 0.06968688016058877, 0.0020065087255716207, 0.011438338078733068, 0.0416271373978816, 0.007068611985232565, 0.04887872913968749, 0.019300236817798577, 0.014483635313808918, 0.05529505593585782, 0.03850532288197428, 0.04337799735367298, 0.039517686527688056, 0.037723358982475474, 0.03192371237673797, 0.029974561693961732, 0.03641593597421888, 0.055859110434539616, 0.02556618223024998, 0.024690164100320544, 0.06982594379223883, 0.04862751957261935, 0.05031423941545654, 0.062232077252701856, 0.04321347805671394, 0.018501474405638874, 0.05398817469540518, 0.06141233803646173, 0.038976030045887455, 0.10265491306199692, 0.035167732639820315, 0.022152495876071043, 0.04257858185155783, 0.044716705597238615, 0.006475633672380354, 0.0208894366005552, 0.0789315985457506, 0.04660045451601036, 0.03392579674255103, 0.026771624870889354, 0.0638748545316048, 0.03144972492009401, 0.007802939744578907, 0.047782888723304495, 0.04849984048632905, 0.02569978551036911, 0.03334219778480474, 0.04581761488225311, 0.08273900166386738, 0.024196114536607638, 0.05566164349147584, 0.09438620792934671, 0.004483183311094763, 0.025526815006742254, 0.006633629027419374, 0.0208265599940205, 0.013308633715496399, 0.0068683123572554905, 0.03215787481167354, 0.06605290953302756, 0.0515002544852905, 0.006331896365736611, 0.03223541811166797, 0.025665015891718213, 0.0418197952240007, 0.03239418947487138, 0.06597686908207834, 0.041000571800395846, 0.02236852393252775, 0.029979521095810924, 0.06948975089471787, 0.058937260691891424, 0.04970987887645606, 0.037758299295092, 0.06412608636310324, 0.007426187548844609, 0.01394528231685399, 0.03287755396740977, 0.02317281163414009, 0.02541361522162333, 0.07422267153742723, 0.034115359812858514, 0.032749893434811383, 0.04546380339888856, 0.053378270313260145, 0.007252331570271053, 0.07761493950965814, 0.06044308203854598, 0.07790606920025311, 0.060677511646645144, 0.07130881422199309, 0.017463896292611025, 0.017677872310741805, 0.019025965011678636, 0.03614623950852547, 0.07447645635693334, 0.0373635323921917, 0.0938844344636891, 0.07087283214787021, 0.03814839437836781, 0.061815023655071855, 0.02779524689685786, 0.02992166697367793, 0.025021243600349408, 0.020995752965973224, 0.055667339474894106, 0.01354013091258821, 0.0057922770793084055, 0.010690995368349832, 0.01861511391325621, 0.05554169387323782, 0.02838105931004975, 0.01621321789571084, 0.04583445792377461, 0.03966532567574177, 0.05902131633774843, 0.058098143999814056, 0.023019068321445957, 0.08810516723315232, 0.03981851237767842, 0.07562098908238113, 0.03918397611414548, 0.009190852379106218, 0.019961011712439358, 0.020785404194612056, 0.03240003017708659, 0.05197078353376128, 0.03952573882997967, 0.0148679601988988, 0.0446901070245076, 0.041434858067077585, 0.022332852604449727, 0.05630239895253908, 0.024208094655477908, 0.021993637310515624, 0.031043015005707275, 0.0407598524907371, 0.030801048887951765, 0.022825356645626016, 0.04116115400393028, 0.021568585216300562, 0.028334934831946157, 0.023155911076173652, 0.02814021754602436, 0.006342827737171319, 0.04317155042372178, 0.05680731912434567, 0.06807211524574086, 0.020447890274226665, 0.01794572268408956, 0.04719898548501078, 0.044582232148968615, 0.09417099252459593, 0.023167731633293442, 0.026160312263527885, 0.019052968054893427, 0.04929342641844414, 0.025789507453737315, 0.0839594189892523, 0.02118953885656083, 0.019354960932105314, 0.05742129418649711, 0.037265591163304634, 0.021141221332072746, 0.012870344489783747, 0.054248854066827334, 0.061002724469290115, 0.016593941509199794, 0.05056009438703768, 0.04088009154656902, 0.056714613747317344, 0.05133936800120864, 0.03458024111751001, 0.08508875995175913, 0.0593739069881849, 0.07675232642213814, 0.04317130922572687, 0.02520912756153848, 0.013278611058922252, 0.03825371997663751, 0.10347247778554447, 0.04249966186762322, 0.04909770723315887, 0.04295986393117346, 0.008916158476495184, 0.04100889498658944, 0.021096833479532506, 0.05151415120053571, 0.04943998945236672, 0.029528402919822838, 0.004684018213083618, 0.023671692579227965, 0.04605638234352227, 0.01851676635851618, 0.02691689100174699, 0.010195750946877524, 0.030031187561689876, 0.010327151903766207, 0.03379159046744462, 0.037178388811298646, 0.021978560580464546, 0.030531319025612902, 0.0953745779406745, 0.049795311206253245, 0.052640449357568286, 0.0748684439167846, 0.025365080618939828, 0.027422722159826662, 0.01264938764506951, 0.04991115303710103, 0.022018037270754576, 0.027734602299460676, 0.055473201064160094, 0.05577644260483794, 0.03216820921807084, 0.011374264759069774, 0.08011429992620833, 0.037663341499865055, 0.030478030967060477, 0.015866137691773474, 0.03332878717628773, 0.004169408375673811, 0.03501289837004151, 0.048821984528331086, 0.07354870496783406, 0.014564937591785565, 0.03141607223369647, 0.0881637746351771, 0.028975668028579094, 0.04241050766722765, 0.008852537866914645, 0.054995387836243026, 0.038139881944516674, 0.042918823164654896, 0.03300296208180953, 0.010631701479724143, 0.04220198643452022, 0.001164270142908208, 0.051619795922306366, 0.028023672530252952, 0.07401861061225645, 0.02530718567868462, 0.015503181093663443, 0.05597697090706788, 0.012406738751451485, 0.04353318043285981, 0.04787711179233156, 0.02465277284500189, 0.050767250068020076, 0.07267118213349022, 0.04896423197351396, 0.06374088203301653, 0.03169192852510605, 0.029389166738837957, 0.018055838845612016, 0.04101441656530369, 0.04464866178750526, 0.03997995918325614, 0.011757749161915854, 0.024926326623244677, 0.05033016961533576, 0.03870984764944296, 0.06030578842910472, 0.05373007799789775, 0.023672664792684373, 0.046722942279302515, 0.04192980006337166, 0.05338420749467332, 0.03999036409368273, 0.07138645771192387, 0.027649886142171454, 0.07618637202540413, 0.02289668260345934, 0.029724895794061013, 0.05479505249240901, 0.023922139589558356, 0.03424525792070199, 0.1708207986666821, 0.18324424687307328, 0.05912916523811873, 0.13776040548691526, 0.17030266084475443, 0.15428812330355868, 0.11546466397703625, 0.14299710339400917, 0.16640675661619753, 0.1621067084488459, 0.1028975285589695, 0.12598783563589677, 0.1696772381546907, 0.18738161626970395, 0.2739313681377098, 0.19385976396733895, 0.07859471545089036, 0.2735645690700039, 0.13431237253826112, 0.11010967515176162, 0.16986063768854365, 0.15002362400991842, 0.08207837890950032, 0.08076909682131372, 0.21200750110438094, 0.1195112983987201, 0.1470578831504099, 0.13747280841926113, 0.1161755746579729, 0.23395800293656066, 0.0986728974385187, 0.18265207239892334, 0.1392241581925191, 0.0802383573318366, 0.17728773993439972, 0.13497306208591908, 0.0670828101283405, 0.15495360712520778, 0.13213707832619548, 0.12358631254755892, 0.11470387355075218, 0.11784287620685063, 0.07121398259187117, 0.15402699122205377, 0.1468348826165311, 0.11458276989287697, 0.20905767189105973, 0.1084679999621585, 0.09724461939185858, 0.15332843729993328, 0.22460149484686553, 0.19346096349181607, 0.18058424117043614, 0.20236915501300246, 0.0766299462702591, 0.14714510034536943, 0.11328865730320103, 0.07368378326646052, 0.11261126943281852, 0.17763929528882727, 0.11510769836604595, 0.19591358344769105, 0.152515948866494, 0.09086125137400813, 0.10429878500872292, 0.0955070587224327, 0.14247515093302354, 0.08882283145794645, 0.1249766445835121, 0.1364881862537004, 0.1139938311825972, 0.1336779847042635, 0.21202540170634165, 0.15060493344208226, 0.15118928567972034, 0.17279145307838917, 0.1317153306445107, 0.1626812049653381, 0.09414693209691904, 0.2071669913129881, 0.14598994748666883, 0.1213928654033225, 0.10348404786782339, 0.11944264973863028, 0.1548181800171733, 0.0980901630828157, 0.13158641959307715, 0.08574094448704273, 0.1260598239605315, 0.13066038256511092, 0.1359887802391313, 0.21222685027169064, 0.08765822363784537, 0.06571633814019151, 0.12188190361484885, 0.2771222766023129, 0.1814671148895286, 0.12621947476873174, 0.12388211776851676, 0.1283122570021078, 0.15366903855465353, 0.20858161384239793, 0.16380641958676279, 0.09134568826993927, 0.19048282876610756, 0.23406623775372282, 0.07802230436936952, 0.15605755179421976, 0.15941268269671127, 0.13953493995359167, 0.05157466592208948, 0.21800203569000587, 0.12591914244694635, 0.17536652740091085, 0.14377957937540486, 0.14456860109930858, 0.09169048265903257, 0.08259999740403146, 0.16248363041086122, 0.11559721897356212, 0.05192199103476014, 0.11757963642594405, 0.11193217462277971, 0.22215064120246097, 0.14689204283058643, 0.11444556163041852, 0.1810728563577868, 0.053746561097796075, 0.11420676819398068, 0.11221681794268079, 0.1330965565284714, 0.12772851332556456, 0.09587242544512264, 0.1105767309491057, 0.1844276607153006, 0.14183472201693803, 0.1076662726700306, 0.2082395282923244, 0.13356712268432602, 0.23380583297694102, 0.0901174709724728, 0.09592531831003726, 0.1945102564059198, 0.0802604881755542, 0.16546722734346986, 0.2545972040388733, 0.1652478484902531, 0.19003632303792983, 0.17286847316427156, 0.11757218526327051, 0.14358623506268486, 0.12596379005117342, 0.16757354635046795, 0.08602566202171147, 0.08610797362052836, 0.3463116358034313, 0.11623819707892835, 0.05660179987899028, 0.13413767097517848, 0.21243674447759986, 0.1084333861945197, 0.13196809130022302, 0.11144223099108785, 0.18366688513197005, 0.13458497822284698, 0.18431975244311616, 0.10695766264689155, 0.13228543364675716, 0.10618864922435023, 0.1071912536281161, 0.18318163929507136, 0.10188485321123153, 0.17057124408893287, 0.2049012589850463, 0.09532161086099222, 0.12249619408976287], [0.026651161315385252, 0.03842635465844069, 0.039380975504172966, 0.03220163183868863, 0.04560249966743868, 0.06474177207564935, 0.03338408831041306, 0.06941266401554458, 0.018497939927328844, 0.021503391253645532, 0.00784965515777003, 0.08033749341848306, 0.012728704678011127, 0.03383795985428151, 0.09342560908407904, 0.006155809305710136, 0.034042295374092646, 0.033068690390791744, 0.020312305459810887, 0.031172506787697785, 0.023489716113545, 0.03019119831151329, 0.014923275248293066, 0.04989710789232049, 0.02887605511205038, 0.02079103338473942, 0.023509921084041707, 0.008471522960462607, 0.07206690323073417, 0.05185546862776391, 0.02433383859170135, 0.07122991650248878, 0.03535757030476816, 0.03675799183838535, 0.015346544332714984, 0.03376938169822097, 0.032974545247270726, 0.03509107991703786, 0.05583241909334902, 0.030414146895054728, 0.0705396820558235, 0.04798489018867258, 0.05905270176299382, 0.029260164774314035, 0.040911506657721475, 0.027934119425481185, 0.029789703839924186, 0.00689865970343817, 0.060647985301329754, 0.027087759372079745, 0.07828410438378341, 0.026497046928852797, 0.024951802697614767, 0.08399253361858428, 0.08662572552566417, 0.044710530928568915, 0.03872649773256853, 0.028870357273262925, 0.01977959185751388, 0.052866819241899066, 0.018303358083358034, 0.038168321043485776, 0.09432972306967713, 0.061163833597674966, 0.0762479257537052, 0.03770209274080116, 0.017124224577855784, 0.08534790307749063, 0.02177676506107673, 0.026786096750583965, 0.027685757850122172, 0.01718293031444773, 0.023887080533313565, 0.040511715415050276, 0.06431402041926049, 0.025932831013051327, 0.0590460446983343, 0.030569890295737423, 0.04886820548563264, 0.02335119053896051, 0.03396673360839486, 0.045138141576899216, 0.0652791018364951, 0.029185248677094933, 0.04578143518301658, 0.0329127800068818, 0.11524351881234907, 0.006049431713108788, 0.07687860284931958, 0.03180918785801623, 0.02880457330320496, 0.06480630923761055, 0.021294986909197178, 0.06410751782823354, 0.034533433863543905, 0.005701400632460718, 0.04074461248819716, 0.014338730052259052, 0.053420821350300685, 0.024172781413653865, 0.025868544325930998, 0.026100515569851268, 0.04524187526840251, 0.03496686294965912, 0.027435898991825525, 0.004844665354539757, 0.023442040546797216, 0.03978421773354057, 0.05720191904401872, 0.013588480906037148, 0.04918974096653983, 0.08447715605143458, 0.023306082803173922, 0.05847952626936603, 0.058203306325594895, 0.07323343321331777, 0.07097492198226973, 0.04713635935331695, 0.08143240615027025, 0.04115485688089393, 0.03195848941686563, 0.009765288596099708, 0.02417002247966593, 0.04128549342567567, 0.04526410259131808, 0.10353924139053561, 0.004191592561255675, 0.03046752401132835, 0.04600141888658982, 0.1252996124094352, 0.043721173860831186, 0.033694510129862465, 0.03520622783980798, 0.0756195122085046, 0.05477069891639985, 0.028950455416634213, 0.010351875625929097, 0.03750688934815116, 0.027876282001670916, 0.07358616116107441, 0.026451532867213245, 0.017308021160715725, 0.056785533379297704, 0.0506610338925384, 0.01020855948809185, 0.054549071355722845, 0.042065828311024234, 0.047104658515308984, 0.0675041570502799, 0.03536030140821822, 0.032353727583540604, 0.0564880583260674, 0.03204542459570803, 0.040982827049447224, 0.02762103144050343, 0.04375023636384867, 0.03604013836593367, 0.06711891561280936, 0.05320265961927362, 0.012431114591890946, 0.0998641706246417, 0.02346290788409533, 0.013474835832312237, 0.03240250895032659, 0.05198260594625026, 0.03485511406324804, 0.052129925970803015, 0.03198457219696138, 0.021157296250748914, 0.026383848999103066, 0.03969463308749255, 0.02608142382086953, 0.01118939762818627, 0.0737046598806046, 0.065859424212249, 0.03619123963289894, 0.03656652144854888, 0.03983433867688291, 0.016931546342675574, 0.017908121772052255, 0.04836476218770258, 0.026169218035647646, 0.006882970237711561, 0.08554773376090452, 0.056664270159672014, 0.038305158232105896, 0.008531801122444449, 0.08525425146217458, 0.02115874900482595, 0.05489227012731135, 0.08919242100091651, 0.02341462932236027, 0.018775215576170012, 0.025158468561130576, 0.04395745512738358, 0.03417979307414498, 0.014864016611682018, 0.009253586122213164, 0.01579234223754611, 0.012778092750522774, 0.023852503873058595, 0.03690185345476493, 0.04223074465699028, 0.009816365054575726, 0.022461771077360027, 0.04762592077895533, 0.06538381145219319, 0.008854194711602759, 0.04605426722264383, 0.04408087799674831, 0.04701507386926096, 0.02082826878904598, 0.01345356216916116, 0.004125245022805757, 0.04794439490069635, 0.009372012482344871, 0.042391924289404415, 0.023555956504424103, 0.034253091289428994, 0.01185426268420997, 0.0602781063207658, 0.03602828255679924, 0.023895654194348026, 0.055122146659414284, 0.027944390749325976, 0.058624489975045435, 0.08630315845948644, 0.06162721947475802, 0.04830131227208767, 0.06250269027077593, 0.0065554145476198755, 0.03606026170018595, 0.035363611386856064, 0.022247253291425295, 0.009700525079097133, 0.013618125994980801, 0.033204403225681745, 0.04159576681558974, 0.06909536619787104, 0.012176210984762292, 0.05669450154528022, 0.07503619155613706, 0.027065103458880913, 0.03242264341679402, 0.07236807417939417, 0.04032692806504201, 0.039724560192553326, 0.01646932007133728, 0.033353415346937254, 0.062406968063442037, 0.03267103653342929, 0.02457841892464785, 0.010622374538797885, 0.04563225978927221, 0.07624017031048425, 0.02178239981731167, 0.03228783971280791, 0.04666494714911096, 0.1239763259945903, 0.0481794924417045, 0.041853826405713335, 0.0387809713720344, 0.03287831095803995, 0.03301076947536785, 0.03883403493091464, 0.032209810306085274, 0.06282040369114839, 0.03555388691893313, 0.0071709411622578045, 0.03664392002974637, 0.038760903698857874, 0.0329259271529736, 0.05539222533116117, 0.03684977324155625, 0.1117529533803463, 0.013093505513097625, 0.05454218422528356, 0.07453438098309562, 0.013717892907152418, 0.03597635077312589, 0.016189033158298116, 0.030886405147612095, 0.02723917605180759, 0.050664310474530794, 0.03510909926262684, 0.06394485390046611, 0.011818009697890375, 0.05421684523753356, 0.021931627161393408, 0.03200176033715252, 0.030597366458096076, 0.0705773089430295, 0.033711932046571746, 0.010398348913440714, 0.017094150898628868, 0.032196922911680304, 0.05940742979873903, 0.03046950740099419, 0.05609368105069734, 0.04386655316920951, 0.029909633049101103, 0.04170092171989381, 0.07767561750370078, 0.051456367582431994, 0.053253021760610864, 0.03767068134038709, 0.015531028329860419, 0.041042859375011176, 0.022350857107085176, 0.043666043420671485, 0.0562959533999674, 0.032119223760673776, 0.047620588447898626, 0.054846628045197576, 0.029549539285653736, 0.02363137355132494, 0.004924866934743477, 0.02775225613731891, 0.028516445599962026, 0.011292719427729025, 0.023692637842032127, 0.04898323837551288, 0.019936326025344897, 0.03329068160383031, 0.0889054621802643, 0.04645652610633988, 0.025726628991833422, 0.05063463198894169, 0.03689822064188775, 0.09877484626485966, 0.05719341032090597, 0.03312327535240911, 0.052400342319742776, 0.0941659756063018, 0.00861260894453153, 0.06210992345586419, 0.04052887386933435, 0.04599387124471832, 0.018100950292136986, 0.029639496860909276, 0.06880270768306218, 0.057299292529933155, 0.05374208223656751, 0.02001424782065442, 0.05943858515820466, 0.043673824839061126, 0.05277038457279559, 0.06685263302642852, 0.03260202422097791, 0.03127493801002856, 0.011179716311744414, 0.011362305049260613, 0.191286827030126, 0.10736207375884987, 0.14347897988045588, 0.11576232456718571, 0.21220604045083746, 0.1992288016481325, 0.1305748277809471, 0.2171470964094624, 0.16423441615188494, 0.23175397276645526, 0.10619960332405753, 0.18227286462206393, 0.11915649243746884, 0.19974900264060125, 0.1834773109294474, 0.08282184018753469, 0.1303557606297545, 0.1352424468495883, 0.13227302493760362, 0.17910874768858775, 0.11812372715212405, 0.13079200987704098, 0.12400420848280191, 0.13991509767947719, 0.11569344584131613, 0.12102876775315963, 0.08635581383714452, 0.09952817810699344, 0.14921879454050213, 0.1392082910751924, 0.11806750946561806, 0.15792141115525737, 0.19212312356103212, 0.14365256822202355, 0.0873275226331316, 0.13215861545177177, 0.12220529446494766, 0.24059127434156835, 0.12459697667509317, 0.21124521153979003, 0.19866804970661178, 0.16326995071722195, 0.20845065446337685, 0.13167667959351093, 0.22155054059112445, 0.08710553142009303, 0.09314613111200742, 0.14960931264795363, 0.17236519313883036, 0.16397797444369644, 0.21230823418591172, 0.1992082441574894, 0.07339150324696675, 0.18742325075436383, 0.13587698311312124, 0.12696341844275594, 0.16983816545689479, 0.07939180432003923, 0.11460478941444308, 0.0975870389083866, 0.10096035985043272, 0.11949043662752956, 0.1694864171440713, 0.10983332162140869, 0.16672656289301813, 0.09227731366991065, 0.0841193443920929, 0.16130024625454098, 0.12327750489930622, 0.19662766309920698, 0.12453714472940192, 0.09231787946191616, 0.14821210090303794, 0.1361422860645689, 0.15639088000170887, 0.1338017452508211, 0.1590570158441551, 0.10316538449842483, 0.15566246205708012, 0.09886109866783954, 0.09252260831999592, 0.07545076266978867, 0.1914924761513248, 0.10590232865069993, 0.17436753725633025, 0.17597070982446894, 0.20237483986420557, 0.14818321651546285, 0.11255400531808846, 0.1532177979242988, 0.0964839848165866, 0.15203813934931532, 0.14432067924644798, 0.10815562258358113, 0.1415035905665718, 0.0917226992896758, 0.12966716632945463, 0.1631317034480162, 0.19460041250567883, 0.10514944209717214, 0.1353791356086731, 0.14720441278768703, 0.1058737188577652, 0.12266768957488239, 0.1510797892115079, 0.10797682436532341, 0.09535517820040695, 0.10526486090384424, 0.10862371738767251, 0.27435976546257734, 0.09421744354767725, 0.1328275873675011, 0.14815566799370572, 0.1690019728266634, 0.15179419540800154, 0.13770461082458496, 0.10311868114513345, 0.08489812447805889, 0.15054772869916633, 0.11907741660252213, 0.12852865242166445, 0.1427866896847263, 0.12253596578375436, 0.1425588651909493, 0.19506591721437871, 0.16863710334291682, 0.18452995835104957, 0.10858962312340736, 0.21238192945020273, 0.22340118972351775, 0.16439810424344614, 0.1457010887679644, 0.11530087198480032, 0.16563357232371345, 0.11424147101934068, 0.10428921130369417, 0.12605866621015593, 0.1892647863132879, 0.17683500016573817, 0.13679953204700723, 0.13267780712340027, 0.05739330779761076, 0.09445381758268923, 0.1560997057822533, 0.10225429432466626, 0.1791935009532608, 0.09958116745110601, 0.1680937473429367, 0.3354200843023136, 0.10763069411041215, 0.13271222793264315, 0.2197038396843709, 0.07929808591143228, 0.21188645681831986, 0.13557902566390112, 0.17732930020429194, 0.15381240664282814, 0.1660895033273846, 0.10668424802133814, 0.0955295235326048, 0.1434174706810154, 0.1277455233503133, 0.05687613105692435, 0.08363520435523242, 0.14365329552674666, 0.1261567632900551, 0.10475960676558316, 0.13962344848550856, 0.17490074067609385, 0.1982405429589562, 0.12345901195658371, 0.1234455568192061, 0.07492733333492652, 0.18078088061884046, 0.1587873639073223, 0.0945169001352042], [0.02750093710346846, 0.03273353650001809, 0.01479642736740061, 0.012116252873966005, 0.03262444450228941, 0.018286498343513813, 0.014288482016127091, 0.01792741761164507, 0.017215677580679767, 0.044544672055053525, 0.04094862888450734, 0.02172863678424619, 0.0571395563747501, 0.03417110623558983, 0.01653801511565689, 0.06611458942643367, 0.07762138135149144, 0.03594200417865068, 0.0299215185441426, 0.05033661887864582, 0.06367640424286947, 0.03337218426167965, 0.0636976667738054, 0.006046054477337748, 0.08037760650040582, 0.017536053455842193, 0.018116008468496148, 0.06047028917237185, 0.043396673499955796, 0.00893826241735951, 0.020569428088492714, 0.019163008146279026, 0.028158103305031545, 0.039889810504973866, 0.05140014247444924, 0.03653965199191589, 0.03563239130016882, 0.017094399518100545, 0.018237960030091926, 0.03134403938020114, 0.08077164980932139, 0.08251704755821265, 0.034360172066953965, 0.05126798823766876, 0.015321920800488442, 0.03592935798224062, 0.07518693659221753, 0.03674851090181619, 0.06568598430021666, 0.013768691060249694, 0.02037867387116421, 0.02364550960919587, 0.051754313899436966, 0.06408852626918815, 0.036970895453123376, 0.05014535257942043, 0.03814105824858416, 0.003443482655711705, 0.05152210702362936, 0.024180688997148536, 0.07512907133786939, 0.03421370551222935, 0.02173807875806233, 0.02766128924122313, 0.05203483087825589, 0.005367184630813426, 0.04295812359487172, 0.04839453715248965, 0.06649722592555918, 0.021139488417247776, 0.021525830088648945, 0.046669741423102096, 0.04423600170412101, 0.07115641419659369, 0.08596961502917111, 0.08755107235629112, 0.06690860580420122, 0.048664686328265816, 0.03638890695583541, 0.01748736856825417, 0.062415666034212336, 0.03833891110843979, 0.027727748565666843, 0.07732462618150748, 0.03013549456227338, 0.03118074091617018, 0.05642080861434806, 0.012778890559275169, 0.024608557541796472, 0.046292637634905986, 0.025277379172621295, 0.02388549048191635, 0.0259229660150595, 0.06498582733911462, 0.04599610881996341, 0.1112621117499657, 0.06339330459013581, 0.03507668225211091, 0.04780824790941551, 0.02950821835838724, 0.010289461006323108, 0.03609391438658349, 0.009350955897389213, 0.04593619523802772, 0.04208764003124088, 0.04893330667982809, 0.060602176235988736, 0.01829532062401995, 0.0065348092812200775, 0.07432260914356448, 0.06521259056171402, 0.009809490911720786, 0.0332556262583239, 0.015613030082022306, 0.02921394567238167, 0.018638027722772676, 0.027441697020549327, 0.03940593021980021, 0.03625776575063355, 0.028521171225293074, 0.07586897772853263, 0.0400892998004565, 0.05076291592558846, 0.04957148317771498, 0.025381591549376026, 0.04306714137783274, 0.1102173088293057, 0.041425770468777046, 0.07114439140423201, 0.03540673387760762, 0.02664373427251121, 0.037795736934640445, 0.09758349144249223, 0.023953792187967338, 0.0058119286859437125, 0.04045170164317824, 0.04099463461898267, 0.016183570951397996, 0.052909232981619425, 0.025665913890406955, 0.016996461999951862, 0.08652750228065997, 0.010646588962117676, 0.10968513699481264, 0.01920318802149268, 0.02242331855086377, 0.09149258155957796, 0.0576805486343801, 0.029257615497044753, 0.030446530508925207, 0.06274315353948623, 0.018667633848963305, 0.0831489491974935, 0.06320328509900719, 0.03267656924435869, 0.02674120794836199, 0.006818561096224585, 0.013231148859631503, 0.009278703182644676, 0.02719849337154301, 0.05123018694575876, 0.010928255342150806, 0.052363572613103315, 0.010793208584800595, 0.018185317640018184, 0.048390540687250905, 0.060130890196887776, 0.04199738003080711, 0.011682075146381976, 0.04337345912063029, 0.01340243283266318, 0.02079932688502595, 0.012519868960225722, 0.02332353440579027, 0.043717923254007474, 0.04842605616431683, 0.041920912844943814, 0.04397463955683634, 0.02915645334724104, 0.036327048946986906, 0.06558530454640277, 0.024718272943573538, 0.048865556018427014, 0.04532685117737856, 0.020534476643661037, 0.026819203958439175, 0.04287490657588933, 0.03004947408044245, 0.10000727896112949, 0.04482555639697239, 0.037034434426459484, 0.012565774504764704, 0.035315208515385166, 0.07168834112235345, 0.06051125572412275, 0.03959743400628213, 0.037747066890005954, 0.03837669384665787, 0.054514758157893084, 0.0402715118980268, 0.02608323651656974, 0.01701456669252366, 0.09944500561687164, 0.01665798143221764, 0.040209338476415724, 0.027351390635885764, 0.056861262128222734, 0.020124204420426395, 0.032162372226594016, 0.038499704824062064, 0.0689570743998047, 0.030213934005587362, 0.027753629110520706, 0.07735696897725575, 0.033030833437805995, 0.10088274604640901, 0.04278742962924298, 0.06545769967488013, 0.0516042293747887, 0.026838227058760822, 0.04272182006388903, 0.030238178114814218, 0.030748842509638052, 0.0566872025228804, 0.02788430832879385, 0.05279255252389703, 0.012356828392512398, 0.05228436319157481, 0.04359707192634232, 0.02554155591496965, 0.016979145839286502, 0.04773502019816078, 0.02786051878501894, 0.0368379434075905, 0.03876228409353644, 0.02732570490479702, 0.03270849272666965, 0.036166054851491936, 0.03386474396393169, 0.02102671907778131, 0.02916373938205652, 0.020785211236216128, 0.017306278969044797, 0.03999597844085656, 0.021045085377409123, 0.044292367820162326, 0.0020247245083737653, 0.056235535157611594, 0.01923535641253693, 0.0404333631740883, 0.04899428524367977, 0.03131296565697994, 0.043911404864047654, 0.03652823404991068, 0.0299357492258423, 0.06868649477837607, 0.023532602972409222, 0.033078067426686175, 0.041374577122041956, 0.031929538235999644, 0.037890227176831104, 0.01632383315154584, 0.04392775437736418, 0.012544855217129225, 0.02177076294174185, 0.03148988624161575, 0.07735083883744664, 0.023701102036284283, 0.15193524799542502, 0.0113733296529972, 0.02281870514707407, 0.028260636572667863, 0.07910678250482306, 0.031789673084858805, 0.02912931115133688, 0.023686542954237666, 0.05843949853442609, 0.0008973200874606846, 0.05243218787654769, 0.07620347110787407, 0.06744935686583631, 0.02424640246317722, 0.028765649512934033, 0.03415766965190414, 0.015148533766478067, 0.12592341721756384, 0.07009764405665919, 0.03938178444514051, 0.023211583284137305, 0.036162989781587385, 0.07901380624389276, 0.05033667082898319, 0.024520047154510394, 0.035715942285605706, 0.0525705316249514, 0.04576038787490688, 0.09844254222116433, 0.024455866223433986, 0.024531928938813508, 0.02667772463610163, 0.04043963803269435, 0.05004453923902474, 0.06818148554884829, 0.009425805201317417, 0.04345429013483226, 0.02750665349594783, 0.018213999792351387, 0.05380293834605254, 0.01633515646972228, 0.05526452398044057, 0.02737596871156711, 0.06105644482886419, 0.06839572131866589, 0.035550380271160975, 0.030045221574255265, 0.03259386430727318, 0.03128332056803629, 0.032232360463240184, 0.05154941063665319, 0.15905947977444157, 0.05841025420522783, 0.0224809871360776, 0.06905460002599284, 0.009292634222219931, 0.023520042122981977, 0.032673329769750126, 0.02350774288061075, 0.024791047944745515, 0.06821540911914781, 0.06118802761193365, 0.024894482921808958, 0.087384267244488, 0.10369034265750088, 0.006139546067061019, 0.01290637019337737, 0.024142371912603267, 0.010019781238952419, 0.023058919796312694, 0.043990406484226696, 0.0651664067117963, 0.07361109732300974, 0.0424061586818425, 0.004829137769775116, 0.05290218257869128, 0.006830865904703387, 0.0020828743299716734, 0.04935238634061534, 0.09100043374928646, 0.05320749471138697, 0.03210846633010078, 0.007356842661465635, 0.017099308824981563, 0.13845671812305227, 0.133047025592532, 0.08170261469786055, 0.13134235690813512, 0.16754380107158795, 0.18653415783774108, 0.11302180326310918, 0.15055434865644202, 0.14985678921220824, 0.13310449750861153, 0.11386992962798104, 0.10117101104697213, 0.2838135097408667, 0.11232575780013576, 0.12022560069453903, 0.16362929862225428, 0.17964448925340548, 0.32845128793269396, 0.09142404422163963, 0.1290697671356611, 0.13224409602116793, 0.19538446184014902, 0.1132305248756893, 0.20549171167658642, 0.12273259038920514, 0.12392499906127341, 0.16059492394560948, 0.15795100800460204, 0.24755796301178634, 0.14743728388566524, 0.14122037217020988, 0.0960674618545454, 0.09405339922523126, 0.15376102033769712, 0.18238883261801675, 0.1954590922105126, 0.15339732344727963, 0.13611454458441585, 0.0984611627063714, 0.1606814583647065, 0.2365065083722584, 0.1535879069706425, 0.1062368591374252, 0.10645369242411107, 0.1568060225690715, 0.11154086983879097, 0.21764724457170814, 0.1394207531120628, 0.16659649409120902, 0.14010548824444413, 0.10045978124253452, 0.16514543211087584, 0.1358644853462465, 0.2277805734775029, 0.12913391838083044, 0.16468065470689908, 0.14129004499409348, 0.09949006140232086, 0.11015671247150749, 0.14702221553307027, 0.158986882888712, 0.13125554047292098, 0.09929703621310182, 0.08801799456705339, 0.0852040525933262, 0.08244904456660151, 0.10058036539703608, 0.12794799607945606, 0.14244628138840199, 0.10667629219824448, 0.12797242758097127, 0.11963614248088561, 0.1223126906552352, 0.2327927271835506, 0.2327024523401633, 0.20893058652291074, 0.20501854800386354, 0.13330631714779884, 0.14416521415114403, 0.15210236480925232, 0.13259162893518806, 0.10472279624082148, 0.0619924229249591, 0.11782858244259842, 0.09168127260636538, 0.11928268722840585, 0.1245652127545327, 0.1131696390802972, 0.16955481347395107, 0.10224645724520087, 0.11923478901735507, 0.10384452383732423, 0.24279620993183926, 0.1581847993656993, 0.11844699183711782, 0.12057691856171004, 0.1598537410609424, 0.1611966424388811, 0.19154733570758253, 0.12269802115042694, 0.10201776443864219, 0.16136604506755248, 0.1341612564283423, 0.21437202813103795, 0.08881851215846837, 0.1278923943755217, 0.15262551954947412, 0.16299134847940877, 0.14649536489741877, 0.29303472430910915, 0.11949811043450609, 0.18348342622630298, 0.1711845994577743, 0.11126749974209815, 0.1438710416550748, 0.07640143900061958, 0.12205926206661388, 0.11154262130730785, 0.145775496494025, 0.12584455660544336, 0.18006096768658608, 0.1335109124192968, 0.13883717270800844, 0.11654323461698368, 0.13035135227255523, 0.13092111388687044, 0.18522477184887975, 0.19393044611206278, 0.1703040857682936, 0.11293564733932726, 0.0999200988735538, 0.19099922996247187, 0.20085322932573035, 0.1275473550776951, 0.08801887030131184, 0.20032044150866568, 0.13715175533434376, 0.13739673828240484, 0.10994842130457982, 0.2155869238777086, 0.17757501045707613, 0.20982429559808224, 0.09567884364514612, 0.26049457665067166, 0.19136383227305487, 0.1006663209409453, 0.16341548587661237, 0.10218657334917225, 0.08869502620655112, 0.1508131652371958, 0.14705734880408272, 0.12021736285532825, 0.1494376390473917, 0.15400773991132155, 0.12595491396496072, 0.22150546254124492, 0.1382760051637888, 0.1400579759501852, 0.04543587267107796, 0.13228285097284243, 0.1746060189907439, 0.08779232230153866, 0.15572692500427365, 0.1518640760332346, 0.0629845296498388, 0.17782086913939565, 0.19744243734749034, 0.14049852965399623, 0.07895568123785779, 0.09109095350140706, 0.12997377722058445, 0.11722033304977231, 0.13997886300785467, 0.13773986283922568, 0.13341248879441991, 0.13620683806948364], [0.06405132982763462, 0.10250770807033405, 0.01364735362585634, 0.04939204671245534, 0.014095146052568452, 0.013503494792530546, 0.03918132293620147, 0.04704110469901934, 0.08962311898358166, 0.031210597517201677, 0.042204101555398665, 0.03501722509099636, 0.042434007773408666, 0.1477662631077692, 0.008653900185890961, 0.013332993785297731, 0.02592378979898058, 0.061515600464190356, 0.007144660321500851, 0.025527193502057344, 0.022660572030872572, 0.03664083269541152, 0.03465978821623139, 0.08206255632103421, 0.03365252312505618, 0.013657936651725322, 0.046981732884887606, 0.0730472728901077, 0.07252694573253393, 0.016375900377170183, 0.03669962563435547, 0.039055131856002845, 0.0386942811019253, 0.027169028253410943, 0.058931167659466155, 0.01946194337506313, 0.07667271624086425, 0.022243479470489547, 0.030488986922136974, 0.024243899570137728, 0.05622721939289477, 0.02527397828089306, 0.0451628662267467, 0.031188674474833533, 0.01934412186528789, 0.031385577385663055, 0.025046498885785695, 0.044661070496658795, 0.05116564978379756, 0.04711123765446246, 0.04524133350059856, 0.009539296279399423, 0.023794148801243864, 0.030920749886718113, 0.03551667934516445, 0.03856679497403093, 0.03882229415467009, 0.04097369863302447, 0.03112148042418994, 0.0669538471265696, 0.020729494499391876, 0.0016019840882108838, 0.022452969205914997, 0.06026655850291718, 0.05261293423245661, 0.03609672712627798, 0.03284953418187797, 0.05299440927046817, 0.013274957836983958, 0.02227858676633332, 0.0339342572260648, 0.04346905887359753, 0.060106399323558435, 0.04942961051710881, 0.06371052819304168, 0.035750069946516305, 0.032852246731636114, 0.019628577792900614, 0.01582462380611105, 0.03652381827123463, 0.04853042439208366, 0.055992823181441054, 0.021499391077668406, 0.05230454589764122, 0.059711472858907655, 0.014771675814699847, 0.03909465864126105, 0.02253418799227802, 0.04288442461984232, 0.024079207723843865, 0.029363421635935083, 0.03172905075189192, 0.06672175528365187, 0.029195132228778675, 0.03058382968447404, 0.06276149943005294, 0.040726804654696025, 0.05921443800616544, 0.03089025689405389, 0.029523599368985742, 0.0338276922411751, 0.008635694375698222, 0.027677165635395795, 0.03795910961343907, 0.08473301146295853, 0.04751616084831767, 0.009881610967568122, 0.059520848517422564, 0.006481285126938019, 0.0581473780766828, 0.015297133995773038, 0.04563818954920862, 0.0273680036116275, 0.010573308372840984, 0.030665131962450687, 0.04042708460474387, 0.02182247208111221, 0.04020599510113243, 0.020434359066712204, 0.05186349124414846, 0.020066869801667053, 0.033463527797721326, 0.09065843725693412, 0.0661591108655557, 0.011437221146479715, 0.03685410367324948, 0.049143271389766596, 0.007234943977891817, 0.04846542709856294, 0.03301773453131318, 0.031391982120112516, 0.048026060831034556, 0.04711233974376228, 0.045408049554680474, 0.024743125613895245, 0.03361577197210863, 0.02573430279880995, 0.08721841950318776, 0.08233384098275565, 0.049234629768761806, 0.09329785578302108, 0.015768615776323713, 0.022967092008912005, 0.052871947482344694, 0.05263398896204308, 0.04580919892759994, 0.05797663958219346, 0.09536859623040073, 0.002610739620649838, 0.037435557824210264, 0.04301172150007915, 0.024678072659298778, 0.09040436299983412, 0.025213059088855516, 0.01867693295935169, 0.024852499627741054, 0.06277790089370683, 0.032067054489743896, 0.052110875039943494, 0.013195980336604407, 0.028792056982638314, 0.03189335853676312, 0.022943519543332513, 0.01970142144273268, 0.02412420970358653, 0.019830161800200585, 0.014721682891831733, 0.04503533185925335, 0.042673736315919086, 0.0515118728071684, 0.04647592955734581, 0.11557404912309721, 0.12166105530923232, 0.04346994945080951, 0.054641312890453264, 0.08098943304503337, 0.03864219346723985, 0.01930593280121684, 0.0044546537628775695, 0.024924213357735425, 0.03640069597167894, 0.046346261515282094, 0.058150654658675194, 0.03376201588253025, 0.04313721496146172, 0.046584268275182694, 0.02326224228454521, 0.15092619432834908, 0.02574980811914429, 0.0681660117697902, 0.020680043344327714, 0.005767620614278712, 0.03109121749730548, 0.05549202563997824, 0.029260752926347777, 0.003070720895266277, 0.03379626970854588, 0.020306615042500198, 0.037380327194114216, 0.062323951424332336, 0.035560744363465346, 0.030210071126930416, 0.015440498373209266, 0.03952685205149464, 0.03270802888437174, 0.05215504024818074, 0.04768868049723096, 0.025995269752456807, 0.03134647362458054, 0.012321438152866904, 0.03366066448506899, 0.038620982886641286, 0.06106611130235251, 0.024837756864144467, 0.022261897720454726, 0.034940683690365404, 0.03539704885042738, 0.004888034609393799, 0.007591836765641347, 0.049859918872243725, 0.008102108749881154, 0.10120229999301955, 0.04448182698979508, 0.05771408999862615, 0.06843899594969116, 0.05943219155597035, 0.02122986530594062, 0.08349942101631314, 0.04075410826771986, 0.04154098889557645, 0.020188582020637114, 0.04657834222598467, 0.0107852620385529, 0.008190941971406573, 0.06237396475626156, 0.09726761854835786, 0.026599923439789563, 0.040644648906891234, 0.044710464135278016, 0.0349921850283863, 0.008352313634532038, 0.030636579685960896, 0.028034830720571335, 0.02311766078491928, 0.02576898335973965, 0.030926831786928233, 0.00855310076076421, 0.049807118775788695, 0.07135352861951105, 0.026900636112259235, 0.039310308202402666, 0.010282683342666132, 0.03235448457417078, 0.06778744223993272, 0.020346603814687114, 0.022396324784494936, 0.037263112390064634, 0.02505240452592261, 0.0357701450411696, 0.03292989022156689, 0.07281709578819573, 0.09347771527245641, 0.04833724335185252, 0.05604152291198261, 0.018812053931469563, 0.026305557985324413, 0.024135655476129614, 0.06847146491054446, 0.023369143091258593, 0.05679829089785926, 0.01826967200031504, 0.04423664366186131, 0.03302282566437498, 0.023711694338999223, 0.039831674366723746, 0.027505811158334836, 0.02141603490599664, 0.05125261093780864, 0.04451110842637718, 0.03319008719699923, 0.05654773071000818, 0.022769901515857782, 0.019822597460006364, 0.06378909936756827, 0.05097447254229337, 0.021128834887349512, 0.020888204635411967, 0.00498238059662981, 0.036953406743123196, 0.04273175371054094, 0.02160924192139646, 0.039154364421847276, 0.025793537315621506, 0.008618085066700587, 0.02011741747992346, 0.036023640423081815, 0.03066591492824955, 0.055707077772240154, 0.08952035379479639, 0.04469839310331736, 0.039740453285048716, 0.016380791130359285, 0.007976188553584507, 0.04103075494640507, 0.045777880295645446, 0.05718025204259902, 0.044125395725131966, 0.05297148432873655, 0.05565369880059734, 0.04275367675290909, 0.06607384551898576, 0.0035113618014293024, 0.013421742587524932, 0.025223107768397313, 0.06099523619923275, 0.043410510843386874, 0.060183070600032806, 0.0688442679529544, 0.006651975845670677, 0.09591852023731917, 0.022789427421230357, 0.03366269054822624, 0.07145176670746878, 0.05079957431007642, 0.03012364246387733, 0.06527156161610037, 0.01782688072125893, 0.03316578186058905, 0.06967444918700494, 0.028717361674353015, 0.009057412371475948, 0.046317859523696825, 0.0805185032368172, 0.02284244830661919, 0.07822843588655815, 0.03845986633677967, 0.02879229261452565, 0.05302573903463781, 0.027999671474390198, 0.09006279695313424, 0.08423082981607877, 0.0502066651097266, 0.03184443987265695, 0.09388177757500671, 0.029955776080896612, 0.03492627860396169, 0.029759715507680085, 0.05951740866294131, 0.07724251496256329, 0.01647638902795734, 0.010415922042739112, 0.051972145374747925, 0.1400732938782312, 0.13068104395642877, 0.18828001571819186, 0.1426197509863414, 0.1534117359551601, 0.08691703333170153, 0.1595004490809515, 0.10938306062598713, 0.1774567863321863, 0.12116837315261364, 0.18721775006270036, 0.20828638749662787, 0.12121742911403999, 0.2555166062666103, 0.11540554449311458, 0.11632151057710871, 0.13454614905640483, 0.14944847440347075, 0.12103041532100178, 0.035370576442801394, 0.12058957960107364, 0.10963994020130485, 0.08853142717271112, 0.10715846554376185, 0.22051905922126025, 0.1854399946751073, 0.11460599169367924, 0.19596225349232554, 0.11901509846211411, 0.11997660272754729, 0.16946228250162676, 0.10077250743051991, 0.18041105358861387, 0.1638413598993793, 0.12861165421782061, 0.10521389020141214, 0.30782540095970035, 0.10774051712360233, 0.12611514364834875, 0.17198644549353048, 0.20353922504000366, 0.10801123033161275, 0.15586686437018216, 0.10441884965985082, 0.08004475326742977, 0.22534242540132254, 0.13987212732899934, 0.1304359719506465, 0.1490564423147589, 0.16457982652354985, 0.11675890273181722, 0.17751500039594248, 0.0568122692493489, 0.13516134495148435, 0.09337542505818419, 0.19376341835595667, 0.10179450415307656, 0.15535387705313042, 0.1191010168986395, 0.17596557416254655, 0.16410269978223369, 0.11660779404337518, 0.13915531657403335, 0.1799846749054268, 0.051821203669533134, 0.0891334647894837, 0.07135391453630291, 0.16169506881851703, 0.09840639220783487, 0.16539359145099297, 0.08935347446822561, 0.16500510682817549, 0.14211278990842402, 0.2053197709028609, 0.14166355307679623, 0.15904009487712756, 0.10820116076502018, 0.09348250212497078, 0.08922940221964382, 0.05722117035475094, 0.1139271492138505, 0.13685492594959214, 0.13980681833345443, 0.09016858268296346, 0.18043527728877962, 0.1759478368330747, 0.18259425909491256, 0.1787950418656692, 0.11942151337279938, 0.07095303604728542, 0.24939127557445318, 0.13607961911475286, 0.1380923532997258, 0.18647934281034395, 0.16719144419766963, 0.18753840238787234, 0.12946147267939523, 0.17417918017599732, 0.1981728442478925, 0.07827480527339503, 0.1349446823587641, 0.19916375982575119, 0.06185086938785389, 0.14459747064393014, 0.3400528966449201, 0.10680148508981802, 0.17273412959184498, 0.141335568332579, 0.2077194460434839, 0.11984240016317926, 0.09198976113111712, 0.11766572555643506, 0.11790339834988117, 0.12902338290587068, 0.11615158844506368, 0.17409194813808426, 0.1046958785445895, 0.18194774456787854, 0.1259531476534903, 0.08870145320543088, 0.1253536852891557, 0.13700497336685658, 0.3178344795014709, 0.1161659490026068, 0.1199748289946001, 0.08824889155221172, 0.10678672377252951, 0.17715158552164212, 0.16417492559412494, 0.11496547318529338, 0.13867853122064844, 0.1467145953211002, 0.1387494953814894, 0.1331779404426925, 0.13908176973927766, 0.11333861868479289, 0.1638541099964641, 0.15754070424009115, 0.27218102768529207, 0.17438511131331325, 0.2923960023326799, 0.19120988115901127, 0.10762970705400221, 0.17708777566440403, 0.11958592134760693, 0.1248946669511497, 0.26997325709089637, 0.13843518099747598, 0.12382947723381221, 0.15689542167820036, 0.12617116095498204, 0.19697967858519405, 0.19679187069414183, 0.17757358553353697, 0.17302242427831516, 0.1591139385709539, 0.1672533986857161, 0.0933997675019782, 0.1667409754008986, 0.13833037490257993, 0.18066938035190105, 0.16286461934214458, 0.11737993932911195, 0.11732602230040357, 0.16749030706705526, 0.140147790662013, 0.10041778310551308, 0.18421077547827736, 0.13183934352127835, 0.20026739279273897, 0.16591028950642794, 0.19624799519078806, 0.22228075453313068, 0.13573110656579956, 0.15644474508007988, 0.14399284293176606], [0.06870044715469703, 0.021474523564393166, 0.06298219930613413, 0.0589522928930819, 0.06808079095208086, 0.016360181689378805, 0.05646808342135046, 0.061106810680939816, 0.014412021773750894, 0.074929351976607, 0.03323997065308504, 0.058700563822640106, 0.019655972319014836, 0.006477197284766589, 0.026099971946678124, 0.016587264035479166, 0.038950232992647216, 0.032592402276350185, 0.0029935213024145924, 0.011769987177103758, 0.03208211266610306, 0.022149941032694187, 0.01526531905255979, 0.03315431938972324, 0.02686282925424166, 0.04832669743336737, 0.043497004444361664, 0.034934145369334146, 0.061464956306735985, 0.02552993202698417, 0.0632747687632218, 0.06713228169246577, 0.04962800143403001, 0.0160904611038859, 0.0022226615556064644, 0.023071729265211616, 0.05926719357375987, 0.07551107701146975, 0.04448004954610951, 0.045986449767951854, 0.08091695490293205, 0.0036724790470543667, 0.05260246995021589, 0.049612776274443604, 0.054325135715771466, 0.032019727732404135, 0.059542044255067594, 0.03179812614689581, 0.0312561171449488, 0.033882781863212585, 0.014463707721006358, 0.04379052756121382, 0.04086927103344351, 0.025267564269597642, 0.021173998284211848, 0.00848335650516674, 0.11770054712542333, 0.01003945835691411, 0.031955669255694374, 0.01810952766390983, 0.06216977024450898, 0.053956199262756854, 0.023700040765106678, 0.09308220993261784, 0.041023051453521475, 0.07393770167254843, 0.044301811649347655, 0.006615517377213109, 0.08351050870260224, 0.01956095886271214, 0.030269285234680865, 0.05494652854395099, 0.028934643960383255, 0.012176389100204688, 0.12480848876293749, 0.024607850646134466, 0.04665745887905359, 0.06151633519039024, 0.030304628162411973, 0.037540575431194156, 0.0214310708179255, 0.004684875393650145, 0.04527963945292868, 0.07557788514532149, 0.024955814005807042, 0.037737519160145894, 0.057493301064823754, 0.032058560609584674, 0.07917155715404078, 0.048380822263425216, 0.044216546302777715, 0.06261114031076431, 0.02401089859631611, 0.026928110419248696, 0.018422233442834113, 0.0500387727515772, 0.03583810721465852, 0.04573787111439742, 0.03428999458265025, 0.03769356546399649, 0.031209892476908863, 0.011430382255639415, 0.026679782240535133, 0.048467048691236414, 0.04273854065104388, 0.05649454840749968, 0.028526976675493643, 0.09068155515706167, 0.029251550295157358, 0.006762571156286867, 0.06325545808067545, 0.022022089397069067, 0.04561245928925928, 0.033327996789012104, 0.014669255724584218, 0.01710574324533809, 0.03525359170453157, 0.052016570334672, 0.056048320984700695, 0.024848395551089197, 0.06363769382005557, 0.02031616648309864, 0.05958049121545628, 0.010448791763337795, 0.015337068962253397, 0.023018982974463142, 0.06270992016652599, 0.018630832601047587, 0.06072106829378754, 0.03763804539630655, 0.014803526009927737, 0.049479416047688574, 0.05675422587955836, 0.014688453229609877, 0.0834608961304184, 0.05313950285199098, 0.07556780677987263, 0.05973748513497412, 0.024352950749744195, 0.015460472350241616, 0.014029149642738048, 0.008213750952563714, 0.05180901389394421, 0.03879895361023955, 0.00972814410488354, 0.029037479653197806, 0.002002948967856355, 0.051532129728002474, 0.05227227360592224, 0.016468546382384375, 0.026732009027909953, 0.021814282481500413, 0.0743030387093313, 0.12799299991456792, 0.050922540758620016, 0.02453576584230177, 0.017432948734494857, 0.04943533247569576, 0.048143605890800245, 0.044275231630308554, 0.05130348516104277, 0.04452372493688017, 0.05539576166484039, 0.02772190415271325, 0.04057119112985674, 0.02615015226183459, 0.051813047466566786, 0.06615995691390708, 0.04198169473966118, 0.05920388095546514, 0.06377400408382528, 0.06722202218952589, 0.016921746282605454, 0.054302411153912544, 0.09171470635919832, 0.018872776454372797, 0.01836985451518558, 0.07748049203655683, 0.01270105225557927, 0.03923085387214087, 0.07812985641066916, 0.012685361398325767, 0.028821629712183494, 0.037275714057614096, 0.03540334597346373, 0.04940395076118875, 0.05271279391308781, 0.0447284166875761, 0.016169189984793775, 0.05998362583341077, 0.03500959210214205, 0.01513851198978955, 0.07592326583107933, 0.03904715005774051, 0.03819548735918943, 0.01364598807413131, 0.033708807604853064, 0.05689878511475399, 0.041247332192142494, 0.014294315296865534, 0.013805074850097299, 0.028717944260279182, 0.03205271619663108, 0.019642843726614956, 0.03339657494507264, 0.06767226092051715, 0.04051186755532399, 0.03515981763484888, 0.03260333040088881, 0.029523224584409036, 0.03866568244120572, 0.006657229787379038, 0.06059543011360802, 0.0452608445630176, 0.029188972403062508, 0.07044505822705105, 0.07203046377981082, 0.007008525853962055, 0.060835429540020414, 0.01785415650374489, 0.036227426753612235, 0.026939203671645373, 0.039677415261394344, 0.01034408678606269, 0.01587966333318036, 0.026917781578958966, 0.044954059267183766, 0.047162898554233834, 0.09107631834922358, 0.0153828594739025, 0.04581351822707802, 0.02927155674115056, 0.08879011758835986, 0.04106758402485866, 0.007079736778905499, 0.0358575885911705, 0.025455750655964948, 0.08866551841492765, 0.0890306847577449, 0.020469993287406396, 0.08128810295602307, 0.06941243394976482, 0.062002790728001855, 0.011820854906545719, 0.0339523396542063, 0.04706893894763198, 0.06508698206744157, 0.03846997809887398, 0.009793685949261999, 0.023806854369468056, 0.10346826980821788, 0.07708648583502509, 0.049642417652648874, 0.009912667064782, 0.02340297018236015, 0.021757454378530383, 0.03545094732544385, 0.036537855994538404, 0.025186145103361923, 0.04936036442813929, 0.020947186822013464, 0.07099162772647105, 0.09630678221583366, 0.044046190014341846, 0.019203837400709745, 0.04520605922152754, 0.07456189239746891, 0.036553923491737805, 0.010367965387558797, 0.01628647714824183, 0.002759391104518727, 0.044586158110178076, 0.013796286893921206, 0.04271639496437274, 0.08289971374324523, 0.0199358603276778, 0.06038832638296299, 0.04896582388028037, 0.06003425885864999, 0.12207308827782981, 0.028781945220544003, 0.05957276916888077, 0.03919707130989991, 0.04507960096816532, 0.05000125718652271, 0.01768415459082462, 0.034749454498523846, 0.008572377118980512, 0.030105285441095475, 0.024385469805565663, 0.03186833331710659, 0.0694478492368944, 0.07168030366301537, 0.08056331411353312, 0.04368424830317963, 0.020940093745593913, 0.08301744805066846, 0.05289884291414637, 0.05428540855064057, 0.039727599287289195, 0.03918400208931416, 0.03941092858440243, 0.0405317830882268, 0.030456410349870566, 0.03404582057555672, 0.024524887812731322, 0.027551974599191453, 0.01998381791054271, 0.04391416936414316, 0.014879706541250926, 0.02894180939620128, 0.073726924310904, 0.07184074114775285, 0.040793649895931594, 0.023422952508553863, 0.010901183650275925, 0.030412731248361524, 0.050491991205490194, 0.0875505231670104, 0.04366228073195089, 0.055411625071428716, 0.02262607329612365, 0.021032658114563674, 0.013306445307534887, 0.05078849775600247, 0.028968921906198375, 0.049154010266647674, 0.0563351499295095, 0.06702952392515726, 0.02617666919832118, 0.08426263084402308, 0.0313652499607997, 0.06086248453357257, 0.03746644972125068, 0.036542724483297206, 0.05096458342450205, 0.01283791820242186, 0.06044286310498137, 0.14501673955237493, 0.015143512209760956, 0.024351804131583776, 0.035442282751319, 0.04026753769721836, 0.06294955222983845, 0.048928145042737015, 0.04723850484879222, 0.024765286143519916, 0.03872195949952584, 0.059717795957112685, 0.061346732181846164, 0.08946818081312813, 0.037375874308054335, 0.14551470580045134, 0.1961125829257071, 0.11053156384150498, 0.10205925049376674, 0.20856963557889685, 0.09327984385890886, 0.1542859265464358, 0.12735938391415402, 0.11005655222106725, 0.13002880004933104, 0.2640738064656034, 0.1548790658125654, 0.10728762892540544, 0.09569238784024492, 0.1435224845772609, 0.10067409122711979, 0.2734948368743062, 0.11896511481609195, 0.1512352394638583, 0.18685209390241653, 0.24538796773413196, 0.13885715132346377, 0.10203605095739476, 0.11826644215034321, 0.10338362786569633, 0.1666964465402998, 0.10511739616049454, 0.07132174243452027, 0.1489650839357637, 0.15913212118903175, 0.15107441606232896, 0.14968887087889016, 0.1687232221593149, 0.13220051710959524, 0.10698987185605802, 0.10433963281684555, 0.14195659750839695, 0.1806036854395643, 0.18331096594920382, 0.11783481648308225, 0.21947288332739845, 0.04879684798652306, 0.20901581476209685, 0.11694431348587386, 0.12551333609735593, 0.1442351541481912, 0.12478324089897797, 0.130556081130635, 0.12938753992784768, 0.08835473665385507, 0.13307335699209943, 0.06591540441149846, 0.22548101405845955, 0.12264632314327173, 0.07313795591471717, 0.05284036167722661, 0.2546109782997519, 0.12688298447756097, 0.07062154094455764, 0.06146001360320952, 0.08856738422764465, 0.22425537201343104, 0.11719908536178991, 0.21163007448194548, 0.1726825354853645, 0.2172326363506727, 0.20014384004753083, 0.06381690764101222, 0.2311264126910828, 0.16441244253655896, 0.1221989342593588, 0.25595756073016673, 0.24073146603768691, 0.08530393824912608, 0.15141175186727196, 0.17023307707859203, 0.07801860105246305, 0.15880766906775534, 0.09795812758966349, 0.09601917772670276, 0.14937817817553878, 0.15592608775477856, 0.15368109103292227, 0.204250336100813, 0.10865338103030808, 0.1523930492112413, 0.229473159997724, 0.163676721858792, 0.183759935607668, 0.10123208980076015, 0.17023435357259586, 0.1674903219100088, 0.08869168654200621, 0.11608327375142835, 0.06885232025524601, 0.1611701477668248, 0.16216392803471535, 0.1537564190221019, 0.20832990703638643, 0.1297132091713138, 0.11265907116467133, 0.076121419260744, 0.129231525643263, 0.28458756976760924, 0.1261861078091897, 0.10866668031667359, 0.13038653007242829, 0.11259916500421241, 0.20924458920489997, 0.06336492486298084, 0.10996919401804917, 0.14464925770880654, 0.1069498181459494, 0.1163601319422014, 0.1398666948080063, 0.20499065809417516, 0.2472814981592819, 0.11275321259745397, 0.10085133835673332, 0.12758168682921678, 0.24858895456418395, 0.15370225708466023, 0.25718355900608003, 0.12123793465434574, 0.14181386766722426, 0.137031527410727, 0.15982175449607894, 0.12871893908595666, 0.1658449211390689, 0.07385414326563478, 0.15056536212796345, 0.14837144000921398, 0.16796338168205693, 0.08459997407044284, 0.21047018672106788, 0.12227306739077903, 0.1589274813886732, 0.11298219484160654, 0.14446545741520822, 0.16679202031809837, 0.17356983240460977, 0.12386716349283233, 0.1709369893069379, 0.09733735816553235, 0.17064764077076688, 0.09206941584125161, 0.09066968079423532, 0.10157610493479297, 0.1453396925353445, 0.10466976978932507, 0.13088281906675547, 0.12861934286775067, 0.12585874646902084, 0.16700608539395034, 0.17929655557963997, 0.13701110350666568, 0.1500871666939929, 0.12917246553115547, 0.14352868893183768, 0.0976951772463508, 0.14513779868138954, 0.10824713681358844, 0.29769404616672546, 0.061094220145605505, 0.1796722604194656, 0.16254355141427368, 0.14849468105239794, 0.12645727372728288, 0.20383057737490162, 0.1602674141759053, 0.1021573698380962, 0.1478043055976741, 0.100267216184875, 0.12743457831675187, 0.1735514122992754, 0.09117742112721317], [0.08718282610061578, 0.035782787526841275, 0.03509466449031606, 0.019970897119492292, 0.07986781783984043, 0.021545730778598227, 0.026941181495203637, 0.0671646987029817, 0.014918443866918096, 0.03968670323956758, 0.037303897115634754, 0.05154115795448888, 0.06553922459715977, 0.01964193088497268, 0.04810767852177378, 0.04532192702754401, 0.019500796661304776, 0.030523244458890986, 0.03809739399002865, 0.006680431179120205, 0.03690941593958996, 0.03998623775260057, 0.04937062090903055, 0.02309790852450533, 0.01884288645669585, 0.033113723911810666, 0.019154226683895104, 0.03987717173004057, 0.10424946187413298, 0.0828574261686299, 0.010702598847274203, 0.06521847579278983, 0.026472405770618934, 0.006446193601732375, 0.05112178514536936, 0.045181219538790174, 0.026420559333928395, 0.03967652839492075, 0.06526245546410792, 0.05907334831135813, 0.06106371416535694, 0.05492527714523021, 0.0573516250733519, 0.0744160455360543, 0.029477552816388197, 0.028835173907282297, 0.059860210385522805, 0.03814049792708829, 0.005999192489980487, 0.03807825029070955, 0.0921551561623346, 0.06705914303893223, 0.020773103096871637, 0.039058300826582126, 0.02622019987029489, 0.019473860411380883, 0.016119239735417068, 0.012292192895984044, 0.021293068457453046, 0.05225733417319134, 0.024180403270293027, 0.03876083319482859, 0.10664293266017921, 0.05545446925680153, 0.030214865400921553, 0.023123239880078472, 0.059644957873388194, 0.07319559852476232, 0.018727172646322288, 0.05355052278900985, 0.02897575708630029, 0.040722329504205845, 0.03178812941769138, 0.03916109570127446, 0.03175283287419006, 0.016237744021054823, 0.037733871504315175, 0.04751653192215599, 0.03144169859297108, 0.028857872493972536, 0.07893389920354821, 0.03996475999883842, 0.03519865051202942, 0.044451777430367656, 0.03914654218533542, 0.0801786886586342, 0.051186470736865886, 0.03676119420561008, 0.04308506795496214, 0.043373503649490885, 0.026893672911683097, 0.049710287057678215, 0.02871034652343951, 0.03373880892468151, 0.08151453221216798, 0.07484167465008795, 0.01420480579326977, 0.02515753159968881, 0.07795956320478581, 0.01724468998872908, 0.022607083592447452, 0.020112450656597503, 0.05702015965653118, 0.02904431297793053, 0.03880696509440895, 0.07155462095397525, 0.0150294348350144, 0.061599474283866584, 0.026703137627919205, 0.05210052207985427, 0.008663582430017414, 0.03498156489513349, 0.06606678027310409, 0.03137067506031599, 0.01974477771000238, 0.04762924931128509, 0.01758167883963324, 0.04992299771402031, 0.02311012241989374, 0.0197183702402981, 0.01656636144616641, 0.06887680370709859, 0.05611413835140411, 0.03803709820203949, 0.014161687940941192, 0.02194565375248203, 0.024373144588025752, 0.01441487996999058, 0.018713674835453276, 0.07014987641014159, 0.04778622467711102, 0.06735376082360744, 0.03285186081484426, 0.05512485920917243, 0.011833503886009566, 0.06342664928524755, 0.0688280446047429, 0.08250483922893181, 0.05069431179435924, 0.028588710374606308, 0.009830009439610876, 0.028897453084937297, 0.0547371575521538, 0.053876960155321285, 0.047910167049849406, 0.012076244620402576, 0.05069661245215684, 0.027272166371403728, 0.09301339800003916, 0.021222848299657926, 0.052553770219674334, 0.019689387518155854, 0.05412775783042889, 0.013191763082431862, 0.022454802310676314, 0.0451927673566388, 0.04832983671803959, 0.06131588110292796, 0.043226658599451184, 0.047628080428694375, 0.014377975749084726, 0.037046060169814155, 0.0376132465316914, 0.0324734842433827, 0.03902647382346913, 0.034482422342989594, 0.08598819840699434, 0.012187263419036753, 0.032353293427149765, 0.03750781332200859, 0.059376140852691606, 0.01448677552616573, 0.04796130844624713, 0.029517155671783257, 0.00793284898463753, 0.08142899969243445, 0.058539625388220884, 0.055958650991669856, 0.06140167337434832, 0.044075831392547116, 0.08816965986625291, 0.03631814688560553, 0.023965516265889164, 0.07354616682277992, 0.0630626778001897, 0.04006168819614686, 0.04011292607174255, 0.03846847153909039, 0.025053775643755216, 0.008442310172540601, 0.03478674741927534, 0.03001420907821739, 0.08483271158183925, 0.024954006876214407, 0.060101901908637956, 0.010005187832575757, 0.02843498561560409, 0.04779364615387749, 0.014448860129050445, 0.03531351270794403, 0.0331806433678139, 0.039190455063362606, 0.03036646947293775, 0.0035004097890123376, 0.06224607044714503, 0.10105698005645536, 0.10842558622243814, 0.04340484083513729, 0.024930248873715755, 0.046754798968322575, 0.04076839832123369, 0.023208414313558023, 0.029974209173815325, 0.009943650802597404, 0.012818485993193462, 0.06012830010149628, 0.024545582600694615, 0.07909370586276054, 0.007891699679021258, 0.025788913735595997, 0.06306095601757988, 0.06685160886263475, 0.022612998509430327, 0.025302476751676295, 0.011386532460164744, 0.024114634143188596, 0.010239963467029156, 0.07769990799715742, 0.04073587369930465, 0.09070841348147951, 0.018462535772414412, 0.03975076542701572, 0.004275673718439066, 0.07006176121649332, 0.028633717920456547, 0.033412505144951865, 0.03548796565155499, 0.03449105723120738, 0.021678847951989155, 0.04609393130522221, 0.035030528088100255, 0.05513110809260979, 0.024715701401873957, 0.028637055729632266, 0.010701688788685715, 0.026115909568034112, 0.050445399174350314, 0.0724847917445004, 0.036267673422116786, 0.022481599407910835, 0.03281211138528306, 0.015909874309727456, 0.024310785629495513, 0.015196739968814654, 0.045529038179665804, 0.024856633390299976, 0.10120450417161919, 0.029021540176472627, 0.07466563722118735, 0.06565101430169307, 0.05572369074798189, 0.08804840777884237, 0.008733977920201141, 0.059057425532955676, 0.03783268104598392, 0.009246448516933015, 0.08626504175481386, 0.06276866857660934, 0.02418153133476153, 0.0707805460842792, 0.07470163138350472, 0.04517869252595119, 0.02507486191461794, 0.024072357700788416, 0.030695543318870477, 0.05637688089336734, 0.020309722785896156, 0.04833777769817971, 0.025264731120842043, 0.035431042924756184, 0.04367970264866017, 0.07248401991091669, 0.031153986492427066, 0.07080645445967093, 0.085527220799122, 0.011859040259878384, 0.03918840302503668, 0.036257205429137684, 0.053557636274490505, 0.04202976364467759, 0.023836848267819732, 0.019403031692490913, 0.018361358779657166, 0.06457009847508743, 0.03332423781102989, 0.030634651957370806, 0.023741040713503025, 0.06777450660592876, 0.036200045215082355, 0.05077269743196666, 0.018455184799677227, 0.02507811994291842, 0.01752263542584842, 0.03246486790885683, 0.009887750384223182, 0.07576475050882436, 0.020058594855072442, 0.018218831173726358, 0.031519683470833115, 0.08395032768021338, 0.014086372011661297, 0.017039903614204377, 0.021345271125028376, 0.013590609942184528, 0.015600621372868773, 0.07542465391452424, 0.0475205135444412, 0.0238054943838506, 0.07919445240986533, 0.014603285289922496, 0.00736829028937791, 0.029304287309059873, 0.030803893168922514, 0.017386655417794827, 0.036860200416413136, 0.047060845827218145, 0.01874080775451148, 0.07754106612992473, 0.023806718927517068, 0.07031751272734255, 0.03956233042117674, 0.017077231786970515, 0.01589052837516647, 0.09687137848231941, 0.023229988546518143, 0.05768603310571052, 0.04668586829211563, 0.017336369346594438, 0.040931232942966744, 0.02849516265996499, 0.030212505371309817, 0.011309671008348232, 0.02392426955339033, 0.04458493356651161, 0.04519259666267317, 0.024909400090109557, 0.03671548533020541, 0.030353587644640356, 0.02482177656929707, 0.02405156828899635, 0.09949651808710769, 0.039630619139643386, 0.15329744521295652, 0.169919163454324, 0.09078081740881316, 0.12244117868249305, 0.21439126459881663, 0.15549138217465952, 0.0974122853949666, 0.2214675091090612, 0.16205667285248637, 0.10950037933071144, 0.14975916710682213, 0.14116772421402857, 0.19478016067296267, 0.10987785048200749, 0.15949409629683942, 0.14803820085944608, 0.11344270489644259, 0.16202726896153763, 0.1648921222658828, 0.113276137271896, 0.0863580773875583, 0.07586806488689035, 0.20286493934690952, 0.10536365560255945, 0.08606557472376153, 0.0894346802670043, 0.13558058417402208, 0.16810004075523466, 0.15277564118150622, 0.1790739261195995, 0.18588137958431616, 0.12568901729537174, 0.1656355315935798, 0.09546647808747366, 0.16629423218546435, 0.09759769614902325, 0.11054250309825875, 0.14921061607310548, 0.20424675894901156, 0.22604396275710315, 0.13562680513132364, 0.12760500510921702, 0.0886027846718207, 0.2011944688274525, 0.2569046599091962, 0.1057854552345816, 0.1617243539658375, 0.2635527594247833, 0.12245582867763005, 0.180245480441954, 0.15844496665522456, 0.26288536086212844, 0.11261982639553025, 0.2799744688672945, 0.1667608055868186, 0.21367133682360873, 0.11783964044298045, 0.11880360121722333, 0.08918966021155939, 0.12962440378032625, 0.10261671472107992, 0.13979861018015072, 0.12226454011397436, 0.07529151262133382, 0.14506457839161158, 0.14703060180181637, 0.15475782856810838, 0.10579932597465813, 0.13249973620986566, 0.1842004299396649, 0.1203418210207019, 0.2174385971738957, 0.25897329265717417, 0.13885241642128676, 0.1045448960212525, 0.17467189201852307, 0.16238606767728925, 0.08508807717589661, 0.10208278399659321, 0.09366500366013497, 0.23323010449530557, 0.23196970025310293, 0.1488133889506571, 0.16189905552892014, 0.11607988213654608, 0.19652659742860124, 0.1571005958248861, 0.1046672835946083, 0.15625399828422815, 0.11583882514969446, 0.14542695425916463, 0.238834120973479, 0.12727810390060768, 0.16963628644589335, 0.20214582793414593, 0.23957822791999206, 0.18256675510201603, 0.10975170021993108, 0.21910590614425018, 0.1438484655227512, 0.07829179303371347, 0.15495332510909066, 0.11960422270931304, 0.14578968635760248, 0.08177000170690008, 0.19830965175060555, 0.09675336958025582, 0.14403422508621588, 0.1277459686389193, 0.14376789797097445, 0.12752897950122133, 0.221207816794049, 0.21101680817082524, 0.1460581211722456, 0.11123431089799851, 0.13074152899207547, 0.11247789807384834, 0.18357315188040957, 0.06839225548901595, 0.09520893800072372, 0.10783121499116533, 0.09976531655411236, 0.11946668790187687, 0.11049969602026977, 0.06834005282144062, 0.08881288667907938, 0.08085777604719624, 0.16085507639218122, 0.05564563536609057, 0.2626799640711397, 0.1609215876669623, 0.1514676949591376, 0.14805157436057925, 0.2103635252569802, 0.10628919539158233, 0.14102628570981324, 0.13662220328114927, 0.15858710277825594, 0.0818186198011972, 0.12321327943936922, 0.13525964983273298, 0.1561480641248636, 0.1541047089267522, 0.16060238995123655, 0.12237706454470754, 0.19510726968292147, 0.10719513506046496, 0.10447108943480998, 0.20891798485536128, 0.09682717616669834, 0.17073427909053862, 0.14465157320955768, 0.11942101613385603, 0.14659923588624224, 0.06344216759316623, 0.08724131475901231, 0.1077663067553658, 0.3373304021079093, 0.17452258674893528, 0.19967570813605562, 0.15490278485231102, 0.1670560022466816, 0.14729393064044416, 0.2204586038715206, 0.19328725640662014, 0.09793520264793187, 0.16166104876901954, 0.1027757792326156, 0.10893225786276162, 0.11828148548374884, 0.15713746572146192, 0.1580532017396763, 0.09543538209982216, 0.11098180257249624, 0.19783096649916843, 0.19448021426796913], [0.0213455754055758, 0.05429021024610847, 0.07327980260015465, 0.012343866783339763, 0.07246416003908962, 0.013064429094811203, 0.019828820368275046, 0.02571217937656911, 0.010737927859736374, 0.03647322977485601, 0.030743716124561615, 0.07233634736621752, 0.013309784972079797, 0.0202882005032734, 0.05382126197218895, 0.015596702833136078, 0.04206753525068052, 0.06346632450004108, 0.07423119139275514, 0.043500036117620766, 0.03244239567720797, 0.029015536201768555, 0.08924975933041424, 0.08748125852434896, 0.03454144905845169, 0.026570642003207467, 0.04437813040567562, 0.05690718251571525, 0.01639871028601192, 0.0767700860160403, 0.06630205592955463, 0.03192956792190671, 0.03993388294475153, 0.025127988556050695, 0.045892968846601434, 0.01884198845800711, 0.02205997603596188, 0.061880046923761256, 0.008293349073937861, 0.07081690389895812, 0.02491227405698737, 0.0229802168905735, 0.007646979729543091, 0.026077319744217675, 0.014592633615393424, 0.021710632281610742, 0.0159900485232356, 0.02439415478875162, 0.03490899398457259, 0.017762428906280547, 0.054392415113397874, 0.06503222641185857, 0.04112793176318519, 0.027096828416688368, 0.025359898572787642, 0.014801449851802317, 0.018121183093171567, 0.031133733282331377, 0.043028256550314836, 0.030170664940669667, 0.020676384556281846, 0.07421749134664424, 0.008474703990941634, 0.02656596276210621, 0.024277401971630752, 0.036476198365562595, 0.048157343044294976, 0.06547304728883319, 0.07305069419089705, 0.06961797917028889, 0.07156632462283596, 0.02429200929327635, 0.09775158046977594, 0.07144758841604926, 0.06396244280040264, 0.021961849270155653, 0.07385113014606759, 0.02108074928401038, 0.0241847912184312, 0.03632054773333948, 0.023075191384123173, 0.01868320225185016, 0.06749438296537846, 0.017505601281300187, 0.017482208786532283, 0.0919841208087746, 0.00900687582543469, 0.03115628715022467, 0.021398631542979274, 0.04986627907783259, 0.05426982344943099, 0.04943197425745893, 0.044707261768053286, 0.035261191296740435, 0.04067945934366435, 0.025050332078535575, 0.007053576537146, 0.07035991904558614, 0.1083427996491082, 0.025862002294161357, 0.05561737067182548, 0.02738225470238831, 0.020982440692023374, 0.002138762224603852, 0.083422742318362, 0.064228168776026, 0.04771172047185246, 0.0555232626356883, 0.03328027669340372, 0.015629064182576258, 0.05473070457810536, 0.06175066460855305, 0.015561502768832725, 0.05787253481685184, 0.07243128289701417, 0.020021613636345137, 0.01560025215439964, 0.03578735173505265, 0.015788045202498324, 0.02637874673382612, 0.013940870248916326, 0.02409153850749135, 0.006726281990268035, 0.02421438806777587, 0.04284748050849885, 0.05670188220392447, 0.05850641799042933, 0.028087035243515857, 0.0676145737816114, 0.011979987139056902, 0.07905518097686581, 0.0043591806388576515, 0.035038194473600015, 0.020056832254340407, 0.021489140162884723, 0.06451979570556432, 0.026907577048405074, 0.025034576283360366, 0.05773741941084154, 0.022680027432215866, 0.05643879085255321, 0.05366033838072326, 0.07292191672604531, 0.0025345226777062635, 0.02924775235442212, 0.08989651876618154, 0.09591494308551773, 0.04290378354198765, 0.04281493733287789, 0.02034056273259921, 0.011230029285798082, 0.02561413981311489, 0.026199443855148274, 0.03578963383915834, 0.03552565191057511, 0.036488466066657566, 0.026966206714860164, 0.06571993013494648, 0.023999738550628535, 0.04556819760182407, 0.019021246807824355, 0.03410251323657576, 0.04798113492142875, 0.04255049156199675, 0.03196056371962186, 0.026969251375703607, 0.03865279875753913, 0.036595821438822895, 0.04188317834632471, 0.04383951301861089, 0.0036721847391163465, 0.012010054324491648, 0.008892060941434465, 0.06382130115525797, 0.010887674707191763, 0.09141359478235245, 0.09764713802724145, 0.06473926361650229, 0.012128310918342322, 0.028564136009663343, 0.03345821030961815, 0.07135944353649393, 0.0027700448663381394, 0.004892863671557279, 0.010314834107703064, 0.021601972584903706, 0.04931031769956462, 0.06073405958886724, 0.021001745808462147, 0.0450314912450267, 0.014115618196228752, 0.03198336991772521, 0.02670820278581232, 0.014036960747034755, 0.08028728712815791, 0.025695167496451177, 0.006648429307460901, 0.02572982950368896, 0.0577489152783528, 0.03593915062083397, 0.00856208167533623, 0.04322649532696232, 0.050148053996963426, 0.026126859957003035, 0.01659251473029144, 0.024214573604695033, 0.002741680445979, 0.09251494935597293, 0.032100770258693956, 0.014930525103409309, 0.11903075035661459, 0.061950495291966945, 0.01715006430458743, 0.03822611579380464, 0.006429657623812091, 0.06827878853073344, 0.01945392446941696, 0.03769952862057835, 0.025185412232531235, 0.07603515201481059, 0.03927891164494213, 0.04720321201602928, 0.08605474678915925, 0.05278595112031326, 0.08336678438354284, 0.0898770299681928, 0.037774069933220744, 0.030693140615767334, 0.056668804681976326, 0.11229673982597888, 0.014470283149421448, 0.06259974092245102, 0.04577932377287652, 0.03436309612879995, 0.0064460999055881985, 0.05037500275648199, 0.08473984664306045, 0.028074693327653222, 0.06323469278868288, 0.03845771781925578, 0.020194240896671545, 0.025185723934555426, 0.03816093667410314, 0.014792786205362063, 0.07603901118272915, 0.032808938703965396, 0.06562547700013965, 0.04351306823082268, 0.040008765645325184, 0.018907714911620133, 0.03126551273453515, 0.030612445043516345, 0.07572528309538029, 0.018116683822881896, 0.03369347112311516, 0.06872337209642865, 0.030743523166165687, 0.06331070355372503, 0.03906696168996859, 0.07579861470730975, 0.00920949791179737, 0.03850550841889344, 0.026000385005318094, 0.044652246360783465, 0.011052907393604983, 0.04487977028475143, 0.07647411010111682, 0.02274028054671362, 0.061267964338185266, 0.02031905900366837, 0.03810463735135272, 0.03989611876022536, 0.060648478829534724, 0.04480726987821981, 0.04890882322797552, 0.035523410624591634, 0.018375595027464442, 0.04453469759027939, 0.07528197602368891, 0.02746578713413328, 0.06682918115984648, 0.10258564841933548, 0.043988740362692624, 0.03683297472889535, 0.06726741936290637, 0.043561819911701605, 0.019282286120869685, 0.06702826969558373, 0.0658630533143878, 0.08377011195989326, 0.015231417746690568, 0.013133635293343104, 0.016526625004189555, 0.07257450255565345, 0.014267652713897405, 0.017598187914700247, 0.026525100111030042, 0.041526802742737345, 0.10555207205470651, 0.03968431723478716, 0.0820156154804863, 0.07601779318065383, 0.033728730559232645, 0.045753378290100954, 0.0585706286074128, 0.025064343826670665, 0.011664749708870659, 0.0775779657124076, 0.03226678127248306, 0.041859310877043754, 0.006284987066464964, 0.01176221410787548, 0.039439786996808834, 0.0608650894719176, 0.035347362063475884, 0.061892633748357184, 0.02670182402653154, 0.026575863012112677, 0.029081806278554723, 0.03198480968421791, 0.03886142389092129, 0.043268627050565556, 0.055816110398154706, 0.02870880842237966, 0.04521509486949071, 0.019394446899241302, 0.015888272246229462, 0.0676395173650235, 0.05090938248031307, 0.05328762068529613, 0.010059272772195982, 0.055289211522904225, 0.02372928323893575, 0.08075127043412067, 0.03590258871554397, 0.02046010602498427, 0.01569146024849033, 0.01716011669486761, 0.039259708573808894, 0.07271716560353525, 0.01226377420607605, 0.02312780594365904, 0.049041422753361985, 0.03583356156013906, 0.03758208375074901, 0.04464997167815454, 0.0504334060678957, 0.07250146038131788, 0.022971444705035537, 0.08154783979989588, 0.021306267553882208, 0.06201831274665892, 0.16779893659986556, 0.08841269096592441, 0.12871153245214373, 0.07150940931751393, 0.15264275221852586, 0.14748699293704703, 0.14565780671546236, 0.105737074627541, 0.12949329597176984, 0.10009298217482865, 0.1623617103905417, 0.12255075678694993, 0.07157025800552219, 0.12646491784835234, 0.11070340071455576, 0.06991670103161596, 0.05487847731274087, 0.14937623374862596, 0.15864457469433546, 0.09225415124092251, 0.11376935377484187, 0.12501336605055258, 0.15141829760977998, 0.13560985447838902, 0.1912019104929641, 0.10435924035846256, 0.17618611076613888, 0.115332947607385, 0.10241752228466794, 0.22156768420245498, 0.1138241465378087, 0.22581195255042985, 0.10817125221365131, 0.09361713513499126, 0.21592002944089472, 0.21483259013621137, 0.13213313010055572, 0.23306502116611227, 0.08445089144515805, 0.15452221152372658, 0.10227119302726351, 0.050127670911024325, 0.17935946001671255, 0.19075430638622493, 0.10851700397324748, 0.12830388557631522, 0.16871988249477, 0.11407320387661457, 0.16019728122046217, 0.23629285889910534, 0.1459751045331359, 0.15738040034193546, 0.11967127575189807, 0.20371873572003096, 0.07275657364516519, 0.18191862269304693, 0.17623038729652762, 0.09584764513419941, 0.15322312654461712, 0.12785739469109103, 0.1160119310952723, 0.10862860071938485, 0.21028773713624105, 0.06098906524130143, 0.12274431632249616, 0.09605507540982217, 0.1424225771916099, 0.1738362485775724, 0.2712959423661232, 0.1173335625207983, 0.16464773303596303, 0.17690017557470128, 0.17965575505513698, 0.0941546207468491, 0.21544696966884658, 0.10164221544982865, 0.13615392294013873, 0.08966265319031663, 0.12176770935184322, 0.16577070637140423, 0.09807745751459152, 0.1670275186188519, 0.17795804771594703, 0.1519988352083601, 0.1424055523239076, 0.137390726886224, 0.12199865828733891, 0.20680237415945157, 0.14890746359014884, 0.14818465628195554, 0.15797445987118408, 0.1331705041229725, 0.1957160237361677, 0.1889178916462697, 0.07883794693043455, 0.08166724393959157, 0.06997266638791189, 0.17272979544941336, 0.14919835579348728, 0.0846103418734856, 0.10669576615327969, 0.10676962469005957, 0.19412644731346518, 0.1519556125276722, 0.162953142717015, 0.24347998027224094, 0.1756526401732117, 0.2144725594553165, 0.14156640594592318, 0.15118374925805256, 0.058441461515030824, 0.21687796397600323, 0.23889528878498822, 0.22571041190531105, 0.11213648045668378, 0.13104695244692266, 0.14710328774526715, 0.17869456991320476, 0.20409837394254282, 0.06120743477367796, 0.08647659095004201, 0.1588121961685829, 0.1781664724694565, 0.13930855522630736, 0.13137235451722518, 0.2103332307888195, 0.17508926102891564, 0.1347031132900156, 0.147078885929659, 0.12096841630409472, 0.1409368569147773, 0.15793064347235486, 0.2076816707267426, 0.09525884001050144, 0.10599470377201214, 0.09924435114953667, 0.17193091800436378, 0.1775163659476675, 0.11605601466726512, 0.16929313220316544, 0.07236175108118914, 0.07304297585505992, 0.13932604022556916, 0.14054780825972557, 0.11580989623325877, 0.20119488443015143, 0.14151185809168965, 0.09515611935057677, 0.19503899209666997, 0.20825551415327936, 0.14851687126792967, 0.1113796308345627, 0.15816502855159342, 0.21333189331926405, 0.07673612533835694, 0.10880947695113719, 0.11681101634167135, 0.17239560635061935, 0.10637863160809502, 0.15933906164718792, 0.17716448404826224, 0.11597388860536739, 0.18131795804947615, 0.19118601368973032, 0.22892906185006723, 0.11668440594803542, 0.16373094316804782, 0.13622603000840172, 0.14897235698299482, 0.13066489482298493, 0.088771363516571, 0.13900200370699167, 0.11278185949777253, 0.15460472350241616, 0.1601218938594684, 0.16370985133107752], [0.02234895535366377, 0.03857433519442566, 0.05296058960084338, 0.03450497992162127, 0.012773800353897968, 0.03202753883670084, 0.040606320690130815, 0.03443780813540798, 0.039981202280614525, 0.025391688468516804, 0.033132173703052104, 0.058961784961866215, 0.03905557343387045, 0.030085705730016343, 0.023452766436093953, 0.03271673427661881, 0.03950960082875099, 0.03711817094881553, 0.02796259563183412, 0.088820716337068, 0.039607000289834104, 0.028649226951529272, 0.034674505004659295, 0.02233517367130844, 0.029333876736927778, 0.06260832757106982, 0.04483574979531113, 0.006896439754200401, 0.017065355568774976, 0.016766477856435813, 0.028832533716922626, 0.020070270693395287, 0.03700276698509697, 0.032729514059610665, 0.05164434987818822, 0.04712418442068156, 0.05067098238214385, 0.05385114454838913, 0.04617658429197036, 0.051799124776152894, 0.0827506385394372, 0.04918300226563588, 0.04342241860285867, 0.023299809799937066, 0.03748829483811278, 0.02332200929231476, 0.011955255995417247, 0.011933398818655405, 0.01733678680466255, 0.03554335213266313, 0.029311575199244544, 0.0552821351448074, 0.04448604609933682, 0.0912444296409376, 0.00902860498172231, 0.022602289318456315, 0.06354901459417306, 0.021742288590758108, 0.049675124100758694, 0.017689696578599978, 0.021435712951642927, 0.017850373405963182, 0.03939446403819602, 0.021745810081483796, 0.015683018318668474, 0.062273745134007186, 0.05177543171157595, 0.06916975908097811, 0.022246049156819936, 0.05868496016773861, 0.02409246804745635, 0.010779583681141958, 0.06427516156691127, 0.017125478807429317, 0.025459088465140667, 0.04842401896894444, 0.040476908689015545, 0.059391941176727414, 0.015013528754934669, 0.09590765519533306, 0.083873656403739, 0.017511863152321894, 0.03441214837948792, 0.0463318972470006, 0.04956697091984097, 0.038831548736197874, 0.06664448286755942, 0.06547775992657989, 0.10556341207120568, 0.055703303951304406, 0.11485910858027637, 0.03312408058263827, 0.03493927732051816, 0.071430118259741, 0.020030710511491634, 0.008879118813638343, 0.045862822807976045, 0.017095857838285156, 0.02215914737462299, 0.04390076246636454, 0.02253322134492919, 0.020888796498184092, 0.009861726048256969, 0.05934432127105538, 0.011058117270295043, 0.045836691788281314, 0.041043111705221236, 0.09949231753125787, 0.10259397531626746, 0.06242353279958479, 0.0364430651825387, 0.0015460674353562354, 0.05394154926761985, 0.05755409780249465, 0.013704511056857882, 0.049551793999853544, 0.02556228038884001, 0.06905723465024494, 0.019213351733924355, 0.014545557332894532, 0.008698169294802938, 0.002019134049078275, 0.03705219773110002, 0.05461492211907171, 0.04452652283362113, 0.08902746383682825, 0.04491973864787724, 0.04649205642635934, 0.033382852634531446, 0.031824721008888446, 0.02694461578357732, 0.02668433346116217, 0.030588722293032333, 0.01306886713791755, 0.0177338228240842, 0.05700399568013381, 0.04320481719332747, 0.040197026246460155, 0.0028819340650443337, 0.05126707910676487, 0.05551123613258824, 0.02890898791520158, 0.05050925727118738, 0.03312777647806797, 0.04158845295023639, 0.02695004644920118, 0.01558612537337467, 0.07067225931677967, 0.015519706867053173, 0.08405599466641434, 0.06732637557433918, 0.0373376165953232, 0.029998598001839127, 0.06492119369795546, 0.027959124236076605, 0.03847547370241955, 0.03508915033307858, 0.03452091012150049, 0.010234424262307584, 0.02991278717672685, 0.048467163724126294, 0.03333717344503384, 0.04740563650557306, 0.0351112106727669, 0.035257484269095585, 0.039345686382148415, 0.03728827490704134, 0.02876362530514598, 0.06284534727456048, 0.023011698795016855, 0.03773431679292116, 0.02674656996532576, 0.03301626507891342, 0.026898773321590852, 0.0368262137635611, 0.014974573423387483, 0.031234420457622036, 0.06194382338435389, 0.0763645839469973, 0.011705589167831931, 0.018834511320164893, 0.031447030924027786, 0.022355998335115146, 0.014892969647917198, 0.01321743860899005, 0.014774675018998096, 0.01748898645018926, 0.017086788793676533, 0.04175231915723998, 0.06795346809667535, 0.015076773652253905, 0.043215941987000406, 0.035932144746766426, 0.05444289599836338, 0.10721697646658868, 0.05674464104231447, 0.04377794073661789, 0.024779494560789317, 0.012903560236736666, 0.019184352313459385, 0.04116702810279094, 0.06770553140086122, 0.016486608401464764, 0.0173848686972633, 0.01473930518841371, 0.033505047249491327, 0.09222947483067401, 0.04158331357757561, 0.019282573703094386, 0.005248535162536427, 0.034737724854494445, 0.03364177682669833, 0.020083258277736604, 0.025844003357633483, 0.037701866385759786, 0.08837379500619136, 0.05896023016248364, 0.013812385932396865, 0.04014294594526291, 0.04020123422378674, 0.013666724607901415, 0.09723594368551858, 0.030751482699997723, 0.012465769177651964, 0.010822081840160536, 0.005468148719955934, 0.04518989895586856, 0.048159547222894616, 0.0062407982022705255, 0.010928590236289892, 0.01640031703573186, 0.03741638072824571, 0.0897903842269443, 0.00880560815858189, 0.012620960606000153, 0.04085092143213842, 0.03226437300327234, 0.02136683793651173, 0.034336256358074024, 0.011193573136552004, 0.030485649112961255, 0.023217115995066706, 0.01665676802076632, 0.10972959164064378, 0.035155119840055704, 0.01841219960624585, 0.0023250229696714086, 0.026553899151622318, 0.04789963597431779, 0.04432257694134023, 0.021034279707237147, 0.028398247450240888, 0.027211271299165674, 0.012615827727131546, 0.07104366712155752, 0.13446853525238112, 0.12599291192600504, 0.06280904141021892, 0.011488280906633008, 0.14133608783595264, 0.024689260535524227, 0.050038275512633845, 0.0986158188607078, 0.04327194073994178, 0.05605200945865363, 0.06200234915013425, 0.01748148148180917, 0.06645527231739834, 0.037034631095593795, 0.006109232581366086, 0.038693141905241646, 0.04511358762101736, 0.015752449944557156, 0.05282240912492853, 0.05016469665861223, 0.03048752674658317, 0.051429846935207024, 0.037681806134060025, 0.041292454770882614, 0.02578002466179896, 0.04578145744744688, 0.08820056289550848, 0.020421091321622953, 0.03038309543626383, 0.05503013147972524, 0.07938329188618809, 0.01210097854709602, 0.022682066482957453, 0.03444914073043037, 0.04688251887273509, 0.0054870340591151034, 0.008390401580982143, 0.018618117755977437, 0.055262865280383267, 0.1301155422697775, 0.024026927130762488, 0.04434190246684011, 0.04430397500982508, 0.035283062388771214, 0.04926756628265139, 0.031168172645266168, 0.020966831471014302, 0.09204061308992095, 0.025728213477123063, 0.014836118352832273, 0.028662344411714002, 0.06065149565984029, 0.05264316190732643, 0.05116096683195792, 0.03446602830081247, 0.04601869237376377, 0.06116702854342293, 0.05831596805364825, 0.037265947394189425, 0.03840635748929344, 0.04702606878709048, 0.031115621168282814, 0.012167771837994223, 0.04751950051286258, 0.04073313517437782, 0.04143075399042573, 0.007911791471997276, 0.07380926559562795, 0.03704950002429541, 0.044664228335022926, 0.044360085084917955, 0.029168964101700112, 0.09925393969751894, 0.023393370502162725, 0.08897123872884549, 0.03524057814502157, 0.04861678069573827, 0.03498236270388588, 0.0374287337763235, 0.03998934364062734, 0.023960616235854104, 0.04163372766925022, 0.04852195648709312, 0.018270787077199202, 0.0286075906115002, 0.027069465431850404, 0.06017905558110215, 0.023958870333444793, 0.03560790413757786, 0.022857174371893052, 0.03985235431173351, 0.03430647397181019, 0.0349595193983987, 0.03111391793936491, 0.02660863068740582, 0.008624522270110901, 0.01918052654218627, 0.1049700278963428, 0.19781208626227453, 0.22891957720275968, 0.14758412522496656, 0.12544722558232024, 0.14470263296971098, 0.12146077933721244, 0.09177283136523329, 0.15326400403864682, 0.07310476707061753, 0.13826911803334951, 0.15831675322260708, 0.15452221152372658, 0.14458972262218595, 0.07777053819154389, 0.127213804225903, 0.1606677583185956, 0.09661196076194756, 0.12890131445601583, 0.17253860336495563, 0.13741753326030448, 0.1441943211830221, 0.10335318496800028, 0.07138246495742351, 0.16313306899974123, 0.1401497350889258, 0.14505071507301182, 0.12411850664648227, 0.10787372521008365, 0.14631665573688224, 0.15726420970167965, 0.13694704131921753, 0.0960168028541375, 0.16001763695385307, 0.11690995204844512, 0.15083928883541375, 0.09832071125856601, 0.1902740923105739, 0.1491099808481522, 0.20655702013755217, 0.14800573932006955, 0.14373068668646738, 0.17686391423922032, 0.14296924317022786, 0.15810040233191103, 0.19293271761853248, 0.08446899984846823, 0.056095050313160755, 0.09392056963406503, 0.16848405764903873, 0.18086066149407998, 0.10807308091898449, 0.0895832285459619, 0.2114015375263989, 0.15038067125715315, 0.11263529275311157, 0.19349118374520913, 0.10298881272319704, 0.17355960560962558, 0.1547563442727551, 0.08564410905819386, 0.08087523136055097, 0.16200077428948134, 0.08468614483717829, 0.09740634821355343, 0.13874992582714185, 0.19457244838122278, 0.24845392821589485, 0.09648043735069223, 0.13376840797718614, 0.13379757438087836, 0.192633468832355, 0.13893241994082928, 0.22555322502739727, 0.12427779380232096, 0.11223680397961289, 0.22120076639112085, 0.1944451848976314, 0.20757817081175745, 0.2044857305008918, 0.22190645977389067, 0.23883147892775014, 0.11548935523023829, 0.22473877732409164, 0.1454182859743014, 0.0704917244729586, 0.2299119473900646, 0.23995834111701697, 0.2547775162383914, 0.15535254118731245, 0.18117142841219902, 0.19077424047281966, 0.1961174514144659, 0.23318263672990724, 0.1224528971943073, 0.15484224044485018, 0.12682132684858516, 0.11815300487796776, 0.10548769074375741, 0.0707494278321974, 0.11323914121021517, 0.12774823961080983, 0.1015076418116223, 0.3126975707709789, 0.18977109430124983, 0.12839750008424744, 0.1298030832549557, 0.15771386213600636, 0.1400770343025215, 0.11850253416923806, 0.1413566156406887, 0.07844299820135348, 0.15067843574797735, 0.13640445715282112, 0.1147377080633305, 0.18093533639330417, 0.08954057731898502, 0.1552084754803218, 0.20738145714858547, 0.13420808594673872, 0.11222361601539887, 0.09129386409767903, 0.18549381522461772, 0.11402535019442439, 0.11470647106762044, 0.2843781653791666, 0.22239976533455774, 0.10431225498905405, 0.1227576527162455, 0.07555664487881586, 0.15974875685060397, 0.11673791479552165, 0.11147256998810917, 0.06753856301656924, 0.12784031045157462, 0.25852129503618926, 0.15118060255190358, 0.12032095924951136, 0.09853713636402972, 0.10563860647380352, 0.21119554701726884, 0.12318234672420658, 0.130266064661555, 0.06445141421863809, 0.13669526029843837, 0.08826460281852633, 0.163126434199512, 0.14098254352575168, 0.09816101592150517, 0.20362985611427575, 0.16635637963190675, 0.3316680825082585, 0.08963293017586693, 0.277405331726186, 0.10059546068077907, 0.13041685422649607, 0.1629644085187465, 0.13326106098247692, 0.1435872443835251, 0.14422519452637061, 0.36391003523021936, 0.1864053655299358, 0.14520229131449014, 0.0904867859208025, 0.1311302511021495, 0.17639173020143062, 0.11779773878515698, 0.24836874450556934, 0.14331766666145995, 0.12837731366744265, 0.1777972243144177, 0.1159525073308032, 0.14301954593975097, 0.08016959734959528, 0.22424648108426481, 0.13228706637164578], [0.02476804507750785, 0.024285495092044584, 0.030508620438922662, 0.017616537516005337, 0.028097891008656006, 0.02722747238294687, 0.0246571088428027, 0.035112004770780914, 0.07609513981151395, 0.034898822850664146, 0.019822371104964986, 0.06826544471550733, 0.0934667834371794, 0.032169107216759585, 0.010230271946056746, 0.01879446874227142, 0.05398747707658913, 0.00492970202685683, 0.022271612433542032, 0.06011727178702131, 0.051859420564142056, 0.06456197195802815, 0.015952609028317966, 0.039810545422369614, 0.03470901858236175, 0.02598286660941085, 0.02202134724939242, 0.030556268175132573, 0.05025952086725738, 0.03628439772001002, 0.008594245427957503, 0.10874080602661707, 0.04844936331210192, 0.016677267994964495, 0.034007971044047736, 0.05813845004013274, 0.05551711394218728, 0.047742790484335274, 0.007230260562209878, 0.08337842868058942, 0.0129182482669421, 0.02285622071212856, 0.02090322941512568, 0.02647346889716573, 0.03017736838955898, 0.06060055093257688, 0.03740608342923224, 0.030498809246637393, 0.05663876625476405, 0.10917194187641144, 0.023609680574736558, 0.021193000975472387, 0.0178382634112495, 0.007263748584591667, 0.02559743035817519, 0.007487976445190725, 0.005309724310791353, 0.044402524799807, 0.07517022342653945, 0.020967133896192536, 0.031362166337203234, 0.0730474287411198, 0.09207243638229556, 0.025243884192605037, 0.05644176315399818, 0.03952318584197201, 0.0494988640275551, 0.013006883891648613, 0.10471282177604735, 0.06294209364568815, 0.009533957454550546, 0.04706152489234228, 0.06764094228856266, 0.04774448258103803, 0.051286823945702054, 0.05075298970041331, 0.09574670562869869, 0.2771052368916571, 1.6640564636327326, 6.447226144373417, 10.449816416949034, 11.929214783012867, 18.143281638622284, 17.696307823061943, 15.486606694757938, 10.909234564751387, 4.863160969689488, 3.4278592374175787, 3.2757018646225333, 1.2391551886685193, 1.056565842591226, 0.5877867189701647, 0.6490520189981908, 1.3264407799579203, 1.9470087555237114, 0.34031116403639317, 0.07304609287530184, 0.35940006317105144, 0.15317960700485855, 0.2106651192298159, 0.03775049561227206, 0.12381067863316275, 0.051968931875308044, 0.03593157329305541, 0.03696425323141739, 0.025928064569598064, 0.05451632408949081, 0.047577462246408686, 0.023703020488028415, 0.026546468398009893, 0.016998989012790844, 0.0239300750035909, 0.022612284192291554, 0.06084499582357239, 0.035961830653832294, 0.027547523568500765, 0.032488902361365035, 0.005164420608707587, 0.020010499974887352, 0.08271157930721529, 0.03513708565151319, 0.06814759166445583, 0.036731118671013974, 0.05537315213587135, 0.003708334056682361, 0.04516161199717317, 0.039495021337643266, 0.07566653468529694, 0.04422831305419095, 0.05145152135810349, 0.07446737246937118, 0.02591228094388498, 0.022908556966285687, 0.021168970233702566, 0.10570742582785897, 0.015608300745952874, 0.026570899899525102, 0.04302991525037214, 0.024882933248591144, 0.027046653667639475, 0.02545355946494965, 0.04291682307666633, 0.06353935183142312, 0.04626704838301521, 0.07249294794746675, 0.03003821384481853, 0.031528841573162936, 0.035576659720391035, 0.06449237334891222, 0.05887438222998753, 0.02817203898302978, 0.010105347155331401, 0.0511296556214802, 0.05458953324705362, 0.028079469047952443, 0.0491976040211739, 0.04342100852227304, 0.04287213094357867, 0.019286178685433697, 0.03392314356460702, 0.014588097237719921, 0.005987163667668938, 0.056458992112311535, 0.014403308960027061, 0.027435796946519986, 0.08488855077303015, 0.01010178855722188, 0.04943495398038067, 0.013750084490311565, 0.037080202673678286, 0.04511963983532041, 0.010097885788127314, 0.020785894012078643, 0.016488912770000752, 0.05522218816622626, 0.03238509816583246, 0.02436189548461698, 0.06252813851460814, 0.03585298727557529, 0.03562180085282307, 0.022994690625637304, 0.028620138473343104, 0.03450728429015726, 0.01341742050499306, 0.0225662617594935, 0.0060072229916841025, 0.020293015186325647, 0.019309610142954625, 0.06874729151604697, 0.061512375832535326, 0.053224690273054875, 0.020540001933113672, 0.03708596916112583, 0.0268402902293019, 0.024674990891071502, 0.030054047565499786, 0.042024171561934054, 0.010369025731051806, 0.022457566810771823, 0.0453625855880091, 0.044377228696248494, 0.027284480456728488, 0.037700111206504516, 0.03679448323964607, 0.011682735657814192, 0.04053396129165776, 0.027294941028230824, 0.06711673369864002, 0.036641519182012416, 0.06237024659640156, 0.03023405919520883, 0.005785593575637904, 0.048646678114891984, 0.04100640879187267, 0.01603057906322647, 0.13154613581718877, 0.13445269782096148, 0.018189542315667495, 0.032019831633078866, 0.09755079983733594, 0.026530380491749384, 0.031131432624533772, 0.037441376261995174, 0.023926739049784373, 0.05172637203941122, 0.097208981460426, 0.026560394799162168, 0.025044257599802222, 0.06166261991893407, 0.07665532029932365, 0.0444514583068667, 0.02449449686537264, 0.02469613653374836, 0.0788563076639548, 0.05775901590823196, 0.05387912351579871, 0.038391982088796794, 0.027536187262739986, 0.04847951677220408, 0.014191243044479052, 0.020614452332665678, 0.12279481947189197, 0.0306832106798538, 0.018906549739767797, 0.02225016065494856, 0.0378445702517638, 0.0022205652203410864, 0.020278461670386605, 0.07984904150362127, 0.026399981434224173, 0.049099410462076776, 0.07458094332832843, 0.03936273351428099, 0.1890745441778563, 1.9739583344198763, 6.402038969099522, 11.496227066963911, 11.716122217476368, 17.3593932017684, 16.260790452361107, 16.504332683980465, 9.493600577116013, 4.149538837373257, 3.011212069541216, 1.8076983746141195, 0.8721620938740671, 0.7977831631433219, 0.49677646660711616, 0.5036094202660024, 0.9729597601108253, 1.4221314014866948, 0.24773732526227832, 0.03310154897917528, 0.22013078239979222, 0.17348027002299204, 0.15430164523422718, 0.09673841530457139, 0.020510085960268043, 0.02477479119988857, 0.01085139667338808, 0.05376310356950853, 0.02739560408372199, 0.06227681020391174, 0.04630300543794874, 0.017391933943144977, 0.03431593635468744, 0.08429958237684332, 0.041988266457337886, 0.010299184068571776, 0.05849177912750747, 0.037799833589815535, 0.05251012080407236, 0.05413765065895859, 0.031260054238373414, 0.041868895714287646, 0.023696929310972337, 0.014348989316204097, 0.028777538718713913, 0.06789941748138517, 0.032721732641221024, 0.01333906919171568, 0.020579768060997594, 0.03687918826472014, 0.064877607364906, 0.022198392143764067, 0.014713592554471688, 0.10331575103919022, 0.07942409516545013, 0.034346687243669294, 0.03311225074867252, 0.0834534820751287, 0.07491785610909574, 0.08323062254930846, 0.025739247357705608, 0.028535784113046248, 0.05401684386015404, 0.043133122017025016, 0.0426068057277007, 0.05040713775088079, 0.033974841571762227, 0.016818305739434436, 0.033787371357902884, 0.0394162460725056, 0.04639378865249455, 0.06533400592161343, 0.014691265041619772, 0.027089661125501152, 0.051583794338512234, 0.07404290852718987, 0.06710860718158074, 0.02190626983065158, 0.02529259134462336, 0.028894503047922626, 0.026842381230380852, 0.024284624923893716, 0.06615206788410433, 0.010761797184386523, 0.028715652879327536, 0.03242713712097611, 0.019541479341569357, 0.03656988337752409, 0.05776566555141471, 0.04575079932692461, 0.021344499291444663, 0.057950037298724055, 0.04308972122089472, 0.08606512943515554, 0.015717713722551707, 0.0646484098979272, 0.04237787172314711, 0.07085723962518387, 0.03723829497175757, 0.08819414331810549, 0.10983234198647551, 0.08693715295521542, 0.15502345806453377, 0.11351599940098822, 0.15526844101259485, 0.15203778311843053, 0.15397980547277257, 0.19476856832625344, 0.10009464458562434, 0.04959335426974576, 0.1230054409825243, 0.25304400769528, 0.13368372892728075, 0.116851418861188, 0.11735790496459231, 0.10645407834090292, 0.0946753412426915, 0.11920686200028285, 0.12894967279862612, 0.1328250640654005, 0.17390724242432043, 0.07053075401927345, 0.19891188974725083, 0.13364090700633824, 0.16254203743301332, 0.12290498387301341, 0.10812543201609515, 0.2381662474363111, 0.23937338031828403, 0.14065411349292845, 0.2299574707285501, 0.15542610286502168, 0.15095583570655435, 0.13615061296150088, 0.12716627708869055, 0.1619263962493278, 0.14726008870638907, 0.08368817885639146, 0.2567721123341471, 0.20895555237075314, 0.13400884898146614, 0.11044185303035192, 0.20781648927368224, 0.16851884953211993, 0.1131945826637093, 0.0873323243285995, 0.19147073122439906, 0.11040218523703516, 0.18872335989726707, 0.14381256041815504, 0.07859012897824869, 0.1203875224746298, 0.21235913067357615, 0.10297893473762088, 0.0738160488253925, 0.1490936684422195, 0.08780860502156429, 0.12537592003354803, 0.14561643940396607, 0.11800549560575746, 0.12720414146315306, 0.12915536644868553, 0.11199431464774534, 0.14016389526659623, 0.16836684284498915, 0.1724877068772912, 0.08567320124711841, 0.2339505369309336, 0.23732318251859397, 0.10192619083682075, 0.12000038856058381, 0.19834962382446975, 0.21676564734661952, 0.17591162002645433, 0.22746041096979752, 0.19842462526867166, 0.7645800104364753, 3.866870105266571, 10.81057095900178, 18.78566186875105, 19.571522399783134, 26.982483230531216, 28.349729664623737, 24.63857900351286, 16.643724404275417, 8.602367900311947, 6.003258442506194, 4.7407215647399426, 1.8164288811385632, 1.8323115538805723, 1.2534367223270237, 1.3019177271053195, 1.95634544827044, 3.2740304293110967, 0.9591821150388569, 0.14821928489254788, 0.43911479820962995, 0.33924158080480993, 0.3374730428913608, 0.20810984540730715, 0.1667370568611659, 0.0771292409626767, 0.10492181056179106, 0.18547368817962706, 0.13448217592667788, 0.2186130458721891, 0.11965108191361651, 0.14366853924002498, 0.12200190889416263, 0.18826264946255833, 0.1350190010271035, 0.10807843180373311, 0.13965153135359287, 0.1027350353251677, 0.17883629043353721, 0.18708944757236168, 0.12842972413636744, 0.12726532411761582, 0.15548442082945257, 0.1100373305962421, 0.12606867036083713, 0.11990843646344729, 0.13533977209590375, 0.12757969787344337, 0.16223576792981476, 0.17510079400381073, 0.22517726785736158, 0.10148937755730003, 0.0759891165944282, 0.22690408222842962, 0.15923142054816708, 0.1379158705822192, 0.15403171128127724, 0.16947069845627993, 0.2121822175104171, 0.10596912194159813, 0.09993730185669847, 0.12236727561685257, 0.15295371209504083, 0.1288113958435133, 0.09541378560243174, 0.1697209951817058, 0.14390103926416487, 0.12831567088142037, 0.18181734922109172, 0.1689834933495149, 0.10814612309332006, 0.20985202223528177, 0.12651194032514468, 0.052675630868179724, 0.15686071885284036, 0.18371568876318634, 0.13154151965864003, 0.11015961426892318, 0.13543883396778256, 0.1680771677638404, 0.10223272751318291, 0.2628858061507344, 0.17554296558955684, 0.09479169515543617, 0.1042807285557501, 0.11664854537229985, 0.1295149073121138, 0.12485937040764838, 0.11628827720414847, 0.11325709376251325, 0.09221460961271077, 0.1551024374202825, 0.1531667826930061, 0.10994476251653396, 0.13990193197969347, 0.17773559637134895, 0.07554919371614233, 0.11712714898749255, 0.15753114537801594], [0.014169848782330519, 0.017503404524177313, 0.08209354098653421, 0.040841677982825786, 0.02475692584994249, 0.07770128097035922, 0.028772740733984392, 0.0575702432252001, 0.06665220120339654, 0.0553249162476277, 0.05838915123604238, 0.04763934623042587, 0.012711915442196187, 0.03594487257942092, 0.02607052167149959, 0.06503782220534049, 0.07524451240897179, 0.04607740367646329, 0.039443905916414224, 0.04330814270360861, 0.052423508459469303, 0.034649557710508816, 0.026584592524159234, 0.05325879938027356, 0.011794767488026991, 0.009301615136791952, 0.018769116977637168, 0.05987387332424987, 0.07507876856834628, 0.05946783690887969, 0.02201680345024215, 0.07948736325488426, 0.06534919026307762, 0.031059846915013622, 0.0399820928578265, 0.008803701766737504, 0.02146285514754709, 0.015818835054233205, 0.06397613542503677, 0.0430220447742613, 0.084270482766442, 0.031810742657398805, 0.04972513001121115, 0.08212724191253074, 0.06951905830646865, 0.048903965871431865, 0.024755038939474616, 0.08118915982777253, 0.07118322057067417, 0.03819109755568206, 0.05512005009222776, 0.016357715903723147, 0.016701447166269645, 0.03917346730304416, 0.09138805748079903, 0.020772116040461697, 0.019599255538196303, 0.04233262297930196, 0.09551260256557725, 0.018866509017243516, 0.034895665012300014, 0.0245477107091574, 0.054837306670378894, 0.014299455597210908, 0.011199640193808591, 0.08846364682540298, 0.7081890769768506, 1.260660015977919, 0.7989839580841362, 1.5386546426452696, 1.3766258745454252, 2.5333019765093923, 2.902363110333681, 4.167571719735861, 10.006180722266436, 16.75536621361971, 36.3180597871542, 48.15056785941124, 67.19160452485085, 84.68528062105179, 83.72558131814003, 86.5904375910759, 84.64072421193123, 88.5405233502388, 85.58543711900711, 85.60407891869545, 65.65750524401665, 68.15564319491386, 46.55101329088211, 41.5784253180027, 46.44317887723446, 42.861251682043076, 52.56249591708183, 50.507531985640526, 42.414277866482735, 25.03432586789131, 24.85414143651724, 8.98138141259551, 6.58499582670629, 4.603532776236534, 3.6624327627941966, 1.6209798376075923, 0.7758626737631857, 0.5136079306248575, 0.08942525499151088, 0.11843923639389686, 0.08186920458683744, 0.046673069955431856, 0.02376845193793997, 0.13461953261867166, 0.11922511883312836, 0.06570631914655678, 0.03557608084520325, 0.046656646227347665, 0.04088097841304261, 0.0603387472074246, 0.0388707378442632, 0.04115089752303902, 0.09083368058782071, 0.03615842928411439, 0.040691767862881534, 0.08741763420403004, 0.04482420197746251, 0.06847173208370805, 0.044339338346617296, 0.05440264561912045, 0.028330409586487804, 0.0599565300217364, 0.06182525787153281, 0.06356202444294468, 0.022708533324475866, 0.057381923252251, 0.09165853320155293, 0.07685335498536006, 0.01366706414046348, 0.021006193128414452, 0.06346816502627917, 0.016555706060898956, 0.02478469701600261, 0.04600232430675533, 0.031569566926918924, 0.02963431667012628, 0.08550832571927458, 0.07071798303513788, 0.016718902479624376, 0.024072964406514075, 0.05894747264392208, 0.026442456401127856, 0.03378838810021989, 0.07217176869744435, 0.02777910889562918, 0.006293248097790638, 0.013132900567143224, 0.08940023719333112, 0.03447034760029055, 0.01623773103347048, 0.022049263134249486, 0.02242837072117254, 0.017745244476827793, 0.07191031749243848, 0.01781421226041857, 0.04253472092386801, 0.02520201036531944, 0.07813598655047826, 0.06930342729901895, 0.059377573197707534, 0.036070770511287265, 0.034587851841934025, 0.017987451792578213, 0.015261509051924804, 0.010682521897251718, 0.01887375423393678, 0.08917088387534022, 0.03802252984314691, 0.03651556187833194, 0.05711875026463531, 0.034255974533152767, 0.05196404112211894, 0.058512347750365734, 0.026877432865148876, 0.03511036091367714, 0.04115249314054381, 0.003944800164390472, 0.043009135115426034, 0.027472681686049327, 0.08239840040914714, 0.04059985287312884, 0.06902921115397476, 0.07457830128259957, 0.025186171078530606, 0.03656838052847888, 0.03510164809995331, 0.05921925083384849, 0.07620474018040113, 0.0464732318505412, 0.014551415661117062, 0.03561896584869828, 0.06638987426413223, 0.07200281877885573, 0.010788776107801823, 0.03344922290125396, 0.012068981777701993, 0.0406880793889286, 0.06372916352120228, 0.04024928086437285, 0.041059130962821655, 0.07272762988577597, 0.029168622713768855, 0.05026272694522049, 0.02016925092902966, 0.02523891736927908, 0.040895290730986744, 0.06797224443289451, 0.08929085946874693, 0.02180141364078736, 0.13402669021161273, 0.051556012040236965, 0.03939158079447225, 0.018813814676832408, 0.07026959967333823, 0.01883818124042591, 0.04866875329753384, 0.027915320824831724, 0.0817668104718905, 0.0180917625039001, 0.015218294720398262, 0.018785926622513216, 0.027198617681278847, 0.01124889931816142, 0.07988602272234857, 0.03364916490681935, 0.018558180054242257, 0.02010084532230394, 0.025284748699050397, 0.04261668000253849, 0.03936105997127015, 0.08243372663855553, 0.02777305111521855, 0.029363915164140053, 0.03616146837885026, 0.01698103646049276, 0.14777977019548416, 0.3242785477777943, 0.5225983669515699, 0.2819639886729419, 0.9698817471507937, 0.9031129174400121, 2.243423843756318, 2.7551062870770693, 4.479930158704519, 9.326486494392157, 17.472370639443398, 38.20637226104736, 54.30240735411644, 72.3345297574997, 94.4778111577034, 93.00342947244644, 98.30761045217514, 96.71652182936668, 101.84562340378761, 96.41158059239388, 95.13190805912018, 70.52404090762138, 70.64734429121017, 50.186209827661514, 45.803346410393715, 52.72451542317867, 46.6424173861742, 54.729945212602615, 56.680749133229256, 51.01569011807442, 29.285161569714546, 27.004852630198002, 10.638013668358326, 7.195687182247639, 4.5940005127340555, 3.319601621478796, 1.3442501868121326, 0.631762946723029, 0.4284333932446316, 0.10422443665447645, 0.12842803203966469, 0.12347668249276467, 0.07318566116737202, 0.08898132451577112, 0.07694628671742976, 0.0972572284808848, 0.06276693937252276, 0.04367291941889562, 0.027180884062545374, 0.0275145833438728, 0.01771979994373396, 0.03227541244996246, 0.020186830552120227, 0.06701456222799607, 0.011492384983284865, 0.028932953719049692, 0.019805292431556154, 0.016736697325541172, 0.05787810092442669, 0.04359250400739256, 0.052438555503613316, 0.015365213057521032, 0.047221220229403116, 0.07807795802364126, 0.0726906635100022, 0.026529760798439384, 0.06891850498504937, 0.055673350871074945, 0.07793566604959778, 0.037669286102754995, 0.04177002680080477, 0.03898284296155907, 0.012626279021787923, 0.0690326769836247, 0.03945869320887141, 0.04111194590223022, 0.03355645952979103, 0.08448761291219853, 0.0544943490967853, 0.030323402643261943, 0.06206192876561545, 0.09112698477110825, 0.08787703845882788, 0.12438412129995413, 0.02437366965750698, 0.009614800528652268, 0.05846884676429909, 0.04716801195172593, 0.03073309413593961, 0.04477452261198778, 0.04185716235951986, 0.062002423364901915, 0.00944349429119029, 0.012580594266182743, 0.04616481011908036, 0.027544157928787172, 0.031908720993669704, 0.03246349864639342, 0.07194296456873417, 0.05591961402387824, 0.07059008130454458, 0.02534963652578881, 0.04525141186604742, 0.029821148636983708, 0.01487062265368877, 0.04524637639406137, 0.02146447674022056, 0.03814260933722835, 0.0646670229616575, 0.027031057434214745, 0.03451519187365193, 0.1218008017167449, 0.22626633988693357, 0.21128648979356512, 0.09265684057027102, 0.09597573240171187, 0.301557102939114, 0.12931532895890996, 0.09906262886943296, 0.15004775865236297, 0.27128492889460176, 0.1320524883340113, 0.11934417416341603, 0.10876307787839323, 0.12063369285897352, 0.12080797881935723, 0.209713997610379, 0.21312547236448154, 0.13818715524394065, 0.09418847752385773, 0.11786669172579423, 0.2026396826840937, 0.18900068564107642, 0.11195857281563804, 0.07573553215479478, 0.10002120165154338, 0.07373127329628915, 0.15059304423630238, 0.16012069158023223, 0.12502760044299066, 0.17382618505507708, 0.10653044533682987, 0.17224205599632114, 0.2176637647789903, 0.09449476187000982, 0.1109222081140615, 0.12149229834903963, 0.12403586850268766, 0.14934886334231123, 0.16706915310351178, 0.17993434244999662, 0.12587537057697773, 0.12031275851768441, 0.11225822978303768, 0.15032221970614046, 0.1517136872280389, 0.19381452264497057, 0.08300981135107577, 0.12416158089763485, 0.10851940853171982, 0.20879935997072607, 0.19083736755419523, 0.08239701259299181, 0.08801156014669687, 0.2890600188402459, 0.27598174405284226, 0.06886262868647464, 0.06290451870881952, 0.15098520991159603, 0.19495683634886518, 0.157994705659803, 0.20163566077826545, 0.11688281170791015, 0.12201407269458286, 0.17022408224875107, 0.1450748200295493, 0.3146566922077909, 0.9299623954575509, 1.6962990397587419, 1.3971705408766866, 2.37934326287359, 3.194511621259153, 4.693299634382129, 5.091894445940852, 7.618041168898344, 15.225040130317211, 25.55510312318802, 50.511149391531944, 69.46753039956093, 92.28773787617683, 113.03579494357109, 114.32840958237648, 118.01200792193413, 114.45873498916626, 119.66495722532272, 117.45505660772324, 114.7773402929306, 90.40104031562805, 91.37632638216019, 69.8147177696228, 66.27305701375008, 69.3893913924694, 65.06411388516426, 73.92296612262726, 73.1221590936184, 69.29491326212883, 43.721609115600586, 37.06108711659908, 18.49394202232361, 13.005818612873554, 7.621602527797222, 5.745756709948182, 2.503653592430055, 0.9539648762438446, 0.5135156668256968, 0.21715699665946886, 0.3275304607814178, 0.2724828146165237, 0.3218741080490872, 0.1598630624357611, 0.2394902240484953, 0.23029139265418053, 0.3395429521333426, 0.09299461424234323, 0.23283259535674006, 0.27800783689599484, 0.13143502146704122, 0.15075640578288585, 0.12339895736658946, 0.18942605500342324, 0.11162544498802163, 0.17212400998687372, 0.1419762644218281, 0.17561764048878103, 0.19851310411468148, 0.1359241985483095, 0.15654644899768755, 0.09544156418996863, 0.2142743466538377, 0.16201204009121284, 0.1799775057588704, 0.1633497019065544, 0.16460612823721021, 0.36005122354254127, 0.11899858567630872, 0.13012047013035044, 0.13378270174143836, 0.19887133879819885, 0.07056658490910195, 0.13753108185483143, 0.12426856148522347, 0.158302073541563, 0.13268988928757608, 0.2672966866521165, 0.2373666426865384, 0.21111095702508464, 0.17919229867402464, 0.16511199093656614, 0.16177161392988637, 0.23908146395115182, 0.1395737542770803, 0.10874232742935419, 0.12495660659624264, 0.14212214096914977, 0.10929149444564246, 0.19352518895175308, 0.06577096020919271, 0.14553247281583026, 0.12890542595414445, 0.14420741266803816, 0.15252267272444442, 0.06666740038781427, 0.19791632832493633, 0.13805442955344915, 0.16722267377190292, 0.19769690494285896, 0.27104192005936056, 0.15573035372653976, 0.13789966207696125, 0.1377416736795567, 0.0897284594248049, 0.1346227090107277, 0.07144320974475704, 0.17972520523471758, 0.21556986932409927, 0.12953153142007068, 0.17830820783274248], [0.030598913836001884, 0.05795886885607615, 0.06786064026528038, 0.09129613506956957, 0.028377346716297325, 0.0346278498909669, 0.019304309353174176, 0.09203704335959628, 0.04000059831014369, 0.03307437895273324, 0.03866371203912422, 0.0666995279607363, 0.021442180768644903, 0.06256300461245701, 0.06210363004356623, 0.07000275305472314, 0.01830082921514986, 0.03741281099792104, 0.027981390521745197, 0.0738869165070355, 0.03765117027796805, 0.023371707211481407, 0.028413344589353073, 0.02999690219439799, 0.03732666249561589, 0.07237109472043812, 0.04792873187398072, 0.030494760831061285, 0.01829087887017522, 0.010947749706247123, 0.019743404736800585, 0.008604970389569644, 0.06565439849509858, 0.025815959452302195, 0.018719777144724503, 0.04978084303729702, 0.026647031263564713, 0.02724969970586244, 0.08372896729269996, 0.035640855494420975, 0.032073685579234734, 0.028681465846602805, 0.009526691828796174, 0.052353954379213974, 0.015812534220458474, 0.03142351968563162, 0.00506445006976719, 0.028372162814775947, 0.014839647265034728, 0.06942158463061787, 0.014182430040818872, 0.018743143664323725, 0.017352652066620067, 0.09812966018216684, 0.04033284669276327, 0.03474836725217756, 0.08070367650361732, 0.037440919841174036, 0.01758498139679432, 0.0302636560445535, 0.03344597600516863, 0.02675090596312657, 0.25226172467228025, 2.147030853666365, 8.89657186344266, 18.452286757528782, 16.016436964273453, 20.695405192673206, 30.004208385944366, 37.14469403028488, 49.8663429915905, 53.43171447515488, 60.57179734110832, 63.52918244898319, 77.45969474315643, 81.03840351104736, 92.7758900821209, 93.42330694198608, 84.57829356193542, 91.0946398973465, 77.64255613088608, 82.65649348497391, 77.23214775323868, 75.18189936876297, 87.33849585056305, 91.61990851163864, 96.76585078239441, 97.54998430609703, 107.09227547049522, 99.29304957389832, 105.24926796555519, 107.68592521548271, 95.71088299155235, 104.47502911090851, 93.91118556261063, 93.97905752062798, 94.43906083703041, 86.19608715176582, 87.53848671913147, 60.92295929789543, 59.711451306939125, 41.03238321840763, 27.226920314133167, 18.265460282564163, 6.133231893181801, 2.443938134238124, 0.6340479897335172, 0.11464656490716152, 0.12319714514887892, 0.02514590771170333, 0.03816032811300829, 0.011056062448915327, 0.053964188482495956, 0.05083987292891834, 0.008688353464094689, 0.011655437610897934, 0.055577699167770334, 0.0572777479828801, 0.04332421762228478, 0.034459152302588336, 0.04680336882302072, 0.05299100281263236, 0.04192751795926597, 0.05948814949078951, 0.05827981061884202, 0.042446089937584475, 0.036080618810956366, 0.0654429457790684, 0.061174357251729816, 0.02532822370994836, 0.05281177414872218, 0.04563028567645233, 0.032533817138755694, 0.009707207191240741, 0.04115880139579531, 0.06335292433504947, 0.022378463145287242, 0.05571220601268578, 0.04209658291074447, 0.0200865571241593, 0.06867678006528877, 0.04682905455410946, 0.046555305962101556, 0.05665952412527986, 0.03753364748263266, 0.0022785125747759594, 0.029719724880123977, 0.02650479680596618, 0.014552918510162272, 0.01959712742973352, 0.008940516690927325, 0.022983571398071945, 0.02313807541213464, 0.0414125008683186, 0.03741302993148565, 0.043748945026891306, 0.009522836371615995, 0.03788174071814865, 0.0411200501548592, 0.05788711059722118, 0.0642393455200363, 0.04979646153515205, 0.00802142338216072, 0.015374049253296107, 0.043300724937580526, 0.041963248659158126, 0.060490215837489814, 0.05470648087793961, 0.006896429549669847, 0.037428373834700324, 0.023152335779741406, 0.030721965631528292, 0.015174177751759999, 0.023171741086116526, 0.04691777459811419, 0.035745628192671575, 0.036903393411193974, 0.0009983302129512595, 0.03328254395455588, 0.02442182019876782, 0.1488328183768317, 0.055055598277249373, 0.030591687173000537, 0.09366933780256659, 0.023514752465416677, 0.029453746574290562, 0.022701230591337662, 0.08137580254697241, 0.04603342771588359, 0.05381579605455045, 0.01430409865861293, 0.02907358513766667, 0.0342000833916245, 0.01332459916739026, 0.045207235525595024, 0.051910910769947805, 0.06714060116792098, 0.026474734258954413, 0.01921204740938265, 0.03573985057300888, 0.02428142812277656, 0.03259395707573276, 0.04824189963983372, 0.09556819684803486, 0.02353923220653087, 0.06491844775155187, 0.012636638475669315, 0.023367415742541198, 0.034680965400184505, 0.027923159759666305, 0.02717426781600807, 0.02736946007644292, 0.02849099550076062, 0.036587672657333314, 0.05699781730072573, 0.04845988696615677, 0.04950395887135528, 0.08988398389192298, 0.014017141693329904, 0.10138760684640147, 0.0782662483106833, 0.03721144035807811, 0.06855037005152553, 0.01791996088286396, 0.02884447487303987, 0.037015201669419184, 0.013416769270406803, 0.06924765490111895, 0.030603906634496525, 0.10126955341547728, 0.016278716138913296, 0.08142778999172151, 0.008737327789276605, 0.04405750776641071, 0.042075309247593395, 0.0342714149155654, 0.021950457303319126, 0.048681588741601445, 0.13973566121421754, 1.6370833734981716, 7.646203832700849, 15.4840655811131, 15.791958309710026, 20.000597275793552, 31.953948363661766, 38.87088440358639, 53.53354141116142, 57.143397107720375, 67.2693407535553, 71.67471796274185, 90.47512114048004, 96.2767942249775, 111.07822358608246, 110.57028204202652, 101.80731385946274, 107.56471171975136, 91.74036204814911, 95.47662556171417, 91.39822080731392, 90.66511854529381, 103.14541965723038, 105.65243393182755, 112.59456261992455, 116.09393924474716, 118.98050755262375, 117.4769814312458, 120.4184339940548, 123.09248730540276, 110.92123121023178, 120.19841060042381, 109.78275910019875, 107.50239506363869, 109.01694819331169, 99.19801667332649, 98.7738986313343, 74.9213245511055, 71.20528355240822, 49.95129123330116, 31.498975977301598, 19.29590418934822, 7.331604463979602, 2.3357018921524286, 0.3537382185459137, 0.10218002018518746, 0.05037757058744319, 0.007929407274787081, 0.03486609042738564, 0.06483671502792276, 0.04023602610686794, 0.048200331948464736, 0.0139531370223267, 0.04651263247069437, 0.06418318720534444, 0.024110567173920572, 0.033216336960322224, 0.049150165941682644, 0.0698493214440532, 0.01740004005114315, 0.05130522920808289, 0.0764850493578706, 0.03665619144157972, 0.025602495516068302, 0.06095499324146658, 0.035986700022476725, 0.021878500519960653, 0.059621298205456696, 0.0049323450002702884, 0.007517633130191825, 0.0546735072566662, 0.02179612212785287, 0.030870202208461706, 0.04430110660905484, 0.025900454820657615, 0.021968242872389965, 0.037392680242192, 0.0395630465936847, 0.07820845727110282, 0.02595870228105923, 0.04851629761105869, 0.04143466881942004, 0.028832466923631728, 0.05842365739226807, 0.040280718239955604, 0.049506051727803424, 0.04800434559001587, 0.02107327956764493, 0.07695641703321598, 0.03259063967561815, 0.0511753348109778, 0.06193255387188401, 0.08043557565542869, 0.06251019338378683, 0.011833070657303324, 0.0748039735481143, 0.038273208774626255, 0.031539617557427846, 0.04107717628357932, 0.03823624982032925, 0.02729627874941798, 0.035101952380500734, 0.0455119094112888, 0.022884904719830956, 0.048642251204000786, 0.040093207207974046, 0.03374233783688396, 0.0334285429562442, 0.006224713542906102, 0.14480699377600104, 0.006973058152652811, 0.020401070032676216, 0.038671267102472484, 0.0344915841560578, 0.18159139493945986, 0.09342632896732539, 0.14465644169831648, 0.1734123783535324, 0.3094914631219581, 0.1764807730796747, 0.11354127695085481, 0.2504153799964115, 0.13682834221981466, 0.09395526503794827, 0.08446727806585841, 0.29641692875884473, 0.15220157511066645, 0.1632717318716459, 0.09012287380755879, 0.13708896964089945, 0.10414035132271238, 0.07316433184314519, 0.10158369710552506, 0.0862565144780092, 0.2218846109462902, 0.09799570994800888, 0.11703915995894931, 0.10495914058992639, 0.16466172994114459, 0.21084057778352872, 0.14117085607722402, 0.15133908076677471, 0.16401729342760518, 0.08546020486392081, 0.1737662492087111, 0.08575171304983087, 0.23979260469786823, 0.09114617671002634, 0.14538217306835577, 0.17787657474400476, 0.09047442174050957, 0.11941352786379866, 0.22246405016630888, 0.15619829267961904, 0.15415861853398383, 0.12425542547134683, 0.08899894310161471, 0.22963356779655442, 0.16480416292324662, 0.18569750507595018, 0.2455273875966668, 0.09102395983063616, 0.11407856218283996, 0.23084827058482915, 0.15679257485317066, 0.148254492378328, 0.14534660935169086, 0.22841159196104854, 0.10741202771896496, 0.30768094933591783, 0.18389372999081388, 0.18942862283438444, 0.15490811347262934, 0.1662687913631089, 0.20962568203685805, 0.1374048276920803, 0.535872895270586, 3.7020582240074873, 13.342496696859598, 23.61068096011877, 27.139743492007256, 30.26502639055252, 42.25159339606762, 53.31138253211975, 69.64538365602493, 74.90299433469772, 83.69224950671196, 89.8224301636219, 106.1271120607853, 111.3864554464817, 124.88758698105812, 122.82668396830559, 113.58301118016243, 114.8719248175621, 103.5485628247261, 111.55335009098053, 101.62284135818481, 102.11627528071404, 115.8142514526844, 118.46593916416168, 126.94512337446213, 125.16464531421661, 137.77039289474487, 132.84651070833206, 135.15640676021576, 140.55574983358383, 125.9904246032238, 138.6227783560753, 125.50617098808289, 129.63996917009354, 125.57216584682465, 122.10896328091621, 118.2566387951374, 92.74480774998665, 89.6649818122387, 66.45217940211296, 45.18419623374939, 30.455688759684563, 14.141361080110073, 5.389478802680969, 1.3824692484922707, 0.2797181310597807, 0.16534805326955393, 0.18191507522715256, 0.18350445869145915, 0.13170256570447236, 0.23226878576679155, 0.1566558564081788, 0.17577997787157074, 0.1803901547100395, 0.15067666943650693, 0.1492892688838765, 0.21088115841848776, 0.10004761468735524, 0.167130766203627, 0.1353546595782973, 0.2278016207856126, 0.1210717752110213, 0.17385662795277312, 0.11638667114311829, 0.13801793073071167, 0.21933033160166815, 0.21166390157304704, 0.1103248237632215, 0.11780754255596548, 0.11490183402202092, 0.15038122044643387, 0.08739479089854285, 0.07479569860151969, 0.14544053556164727, 0.15913952782284468, 0.16163489548489451, 0.1547212852165103, 0.10348870113375597, 0.12680758227361366, 0.09656710535637103, 0.13459401758154854, 0.1383318888838403, 0.08956385107012466, 0.1494811734301038, 0.09939635783666745, 0.16187008208362386, 0.15089949185494334, 0.09858699384494685, 0.185545097629074, 0.10768285224912688, 0.17305740911979228, 0.15924581821309403, 0.09341613185824826, 0.17578404484083876, 0.163012410630472, 0.13903912593377754, 0.089822586014634, 0.18048796977382153, 0.17729401850374416, 0.21779139933642, 0.14178020384861156, 0.10117811340023763, 0.08141753351083025, 0.14522739074891433, 0.16031222505262122, 0.15890208509517834, 0.11670820662402548, 0.11910516550415196, 0.1276833759038709, 0.21870044118259102, 0.15425299003254622, 0.12660117616178468, 0.20239177567418665, 0.0963412995042745], [0.00900132734386716, 0.06760445088730194, 0.037641296003130265, 0.01866164842795115, 0.009708171983220382, 0.07043362173135392, 0.0435067785292631, 0.03902901939000003, 0.015834371915843803, 0.005971377258902066, 0.09416314060217701, 0.04216364337480627, 0.01856948852946516, 0.015623060207872186, 0.02446654201776255, 0.02010309588513337, 0.017829491225711536, 0.058978390516131185, 0.014058576725801686, 0.02307862010638928, 0.06776225374778733, 0.07190644348156638, 0.030512785742757842, 0.03852855952573009, 0.061413313960656524, 0.060646838683169335, 0.020753571625391487, 0.03730761156475637, 0.03466827096417546, 0.014932366557331989, 0.06399301928468049, 0.012542537861008896, 0.02568291463830974, 0.05166940107301343, 0.02826628988259472, 0.02782596438919427, 0.058987685915781185, 0.05259170509816613, 0.04523173382040113, 0.09452015074202791, 0.03710071192472242, 0.11067388550145552, 0.05224318512773607, 0.053088402273715474, 0.012839934988733148, 0.016494191295350902, 0.0314986844023224, 0.027395129109208938, 0.08226582314819098, 0.04157720570219681, 0.017139353258244228, 0.08739985234569758, 0.07153480561100878, 0.05660181472194381, 0.05778341401310172, 0.027951426309300587, 0.037500169200939126, 0.07161364395869896, 0.13394025969319046, 0.15663197409594432, 2.2605188889428973, 7.44001074694097, 18.036965243518353, 26.47270828485489, 37.65555001795292, 55.5193642526865, 76.48981958627701, 67.15840190649033, 77.04163357615471, 72.61772096157074, 79.72941175103188, 77.0767892897129, 80.12872472405434, 81.28268480300903, 82.99596726894379, 72.99050375819206, 74.53056111931801, 71.25193744897842, 60.27192883193493, 57.750992104411125, 80.44985309243202, 66.60764425992966, 51.33031703531742, 41.80503375828266, 54.87482763826847, 64.40392211079597, 68.35491210222244, 67.96636775135994, 81.6630519926548, 58.84575515985489, 68.36071819067001, 71.3936622440815, 86.72169014811516, 86.88407823443413, 80.27098149061203, 84.41133052110672, 82.60635897517204, 94.73340064287186, 91.88090890645981, 101.94673597812653, 91.11078903079033, 92.04113110899925, 89.60111483931541, 76.62737980484962, 58.930338621139526, 42.96402096748352, 27.192336469888687, 11.846473272889853, 3.8841283041983843, 0.2716001635417342, 0.35716652520932257, 0.23764974233927205, 0.050646673334995285, 0.030760353220102843, 0.04865228504058905, 0.08188134612282738, 0.0512604109098902, 0.05983076567645185, 0.017023502150550485, 0.08942975240643136, 0.06297514890320599, 0.1083352074783761, 0.041229683920391835, 0.0458447292476194, 0.038256384286796674, 0.024567774671595544, 0.04885541828116402, 0.017888555048557464, 0.02729382224060828, 0.0710817392973695, 0.02442531014821725, 0.008997856875794241, 0.026554008618404623, 0.07747308540274389, 0.04910794144961983, 0.028032337104377802, 0.03374618216184899, 0.03194675977283623, 0.019421531578700524, 0.07164013863075525, 0.09560453981976025, 0.07860008117859252, 0.07998847620910965, 0.026017888558271807, 0.045936889146105386, 0.0128561462770449, 0.007490920452255523, 0.05420396897534374, 0.07511559393606149, 0.03761936925002374, 0.017909418675117195, 0.03314375120680779, 0.03692375423270278, 0.07371794432401657, 0.015141801559366286, 0.012527061298897024, 0.12242632830748335, 0.0930812228762079, 0.05817982106236741, 0.007206378249975387, 0.013995582303323317, 0.03891724452842027, 0.03177655191393569, 0.08630849450128153, 0.06181278236908838, 0.044174614959047176, 0.029955471800349187, 0.008449893066426739, 0.05199976068979595, 0.029273078143887687, 0.026147174394282047, 0.0525549502344802, 0.03682269227283541, 0.023459451331291348, 0.014531982524204068, 0.06242594477953389, 0.04851482815865893, 0.04747205130115617, 0.006593560938199516, 0.04123453014472034, 0.029217222254374065, 0.04272689635399729, 0.05985919735394418, 0.05809314563521184, 0.03660244510683697, 0.03863126163196284, 0.08200627926271409, 0.07424801588058472, 0.041613411376602016, 0.06743845471646637, 0.002703307004594535, 0.03153401063173078, 0.035749758244492114, 0.03113073129497934, 0.03984546347055584, 0.08076943820924498, 0.017898024852911476, 0.0408175952907186, 0.05849085886438843, 0.031048223027028143, 0.06889563199365512, 0.013942942696303362, 0.0581114358647028, 0.02372268554609036, 0.10717368699260987, 0.04212196436128579, 0.10394640587037429, 0.012572452906169929, 0.016753187846916262, 0.05427243951999117, 0.01439838944861549, 0.060238323494559154, 0.02675868738151621, 0.07091037739883177, 0.03534695759299211, 0.05369241029256955, 0.05152050027390942, 0.026075688874698244, 0.0476029772835318, 0.0624071758647915, 0.019309079507365823, 0.07660177434445359, 0.027834237480419688, 0.03756222387892194, 0.04329509203671478, 0.010276238717779052, 0.010605432235024637, 0.0383843453892041, 0.043626312544802204, 0.03779069033043925, 0.13059361896011978, 0.019594734003476333, 0.04813673731405288, 0.08320389038999565, 0.08359284998732619, 0.08566422868170775, 1.5785454958677292, 5.796140106394887, 16.784081272780895, 27.157021164894104, 41.19724877178669, 64.24319073557854, 81.96530297398567, 77.21545144915581, 87.55772888660431, 87.83617794513702, 93.1961627304554, 97.09981486201286, 96.69855639338493, 97.24308997392654, 101.1898697912693, 86.68049275875092, 86.88633531332016, 91.38400956988335, 73.39313015341759, 73.5819724202156, 94.8024733364582, 87.83866301178932, 72.67799332737923, 64.3740177154541, 76.27819374203682, 87.48176336288452, 84.15616661310196, 83.60034763813019, 99.19411048293114, 75.59762746095657, 90.60350865125656, 90.65023854374886, 103.36564064025879, 104.06149730086327, 97.9246897995472, 98.41045573353767, 96.16998195648193, 111.25046834349632, 105.61768099665642, 114.40701976418495, 101.48325204849243, 105.3851942718029, 99.66916859149933, 87.02495187520981, 64.87732350826263, 48.13899368047714, 30.307073034346104, 13.763356413692236, 4.283071272075176, 0.14265246485592797, 0.10159864395973273, 0.08286235402920283, 0.029994633077876642, 0.056292008885066025, 0.10572344879619777, 0.11584290696191601, 0.0710123336466495, 0.0651143747381866, 0.03397296022740193, 0.14639084081863984, 0.08949087568907999, 0.08390190996578895, 0.07107522324076854, 0.02195908105932176, 0.041202714273822494, 0.02872992066841107, 0.04779024711751845, 0.11495269340230152, 0.04283023670723196, 0.030726789591426495, 0.03643120566266589, 0.019706967141246423, 0.018589428182167467, 0.03972602964495309, 0.028720103910018224, 0.04525022814050317, 0.032102833429235034, 0.02345728611544473, 0.038111895555630326, 0.0617198469262803, 0.049584522712393664, 0.08472204994177446, 0.027506865008035675, 0.05819258600240573, 0.013716404901060741, 0.07359736016951501, 0.03343545235111378, 0.11086360813351348, 0.11755008410545997, 0.0806941621704027, 0.04286194125597831, 0.013044730640103808, 0.04440227618033532, 0.056319698414881714, 0.01859987391071627, 0.08135790194501169, 0.04224969168717507, 0.06629348412388936, 0.032949620217550546, 0.048905194125836715, 0.008785988557065139, 0.02267236846819287, 0.045292445211089216, 0.046440833393717185, 0.051806390401907265, 0.07039813222945668, 0.07410233229165897, 0.033172502007801086, 0.0687091748113744, 0.00972811534666107, 0.039834394337958656, 0.030231177806854248, 0.03878309020365123, 0.06951290590222925, 0.014814799233136, 0.07672315259696916, 0.1699360102065839, 0.10814713983563706, 0.12046673189615831, 0.1121286211127881, 0.0934842907008715, 0.13412670203251764, 0.09996747015975416, 0.16218588076299056, 0.10158371936995536, 0.14167143468512222, 0.2124291003565304, 0.15395439433632419, 0.15040303958812729, 0.18138700746931136, 0.15965532045811415, 0.0991737877484411, 0.08857259410433471, 0.09491727396380156, 0.15955167211359367, 0.1718603100744076, 0.14775048504816368, 0.1429901717347093, 0.14153529511531815, 0.07806082925526425, 0.17080297227948904, 0.22382486698916182, 0.13657810486620292, 0.1665760256582871, 0.2859884180361405, 0.08907709125196561, 0.15056399657623842, 0.08332311641424894, 0.0987312376673799, 0.11084361467510462, 0.20750134368427098, 0.16261392185697332, 0.2546960877953097, 0.2011568716261536, 0.1834217389114201, 0.20469577313633636, 0.18647293065441772, 0.19365047832252458, 0.16141688218340278, 0.13656213384820148, 0.15660478180507198, 0.08866649804986082, 0.1323074457468465, 0.12520939693786204, 0.1578976772725582, 0.07829336638678797, 0.11016668693628162, 0.17969841370359063, 0.10911979858065024, 0.22213579824892804, 0.23158617317676544, 0.09254012300516479, 0.22519285295857117, 0.2198617983958684, 0.2908967452822253, 0.29038730543106794, 4.489966845139861, 14.468062799423933, 30.23694209754467, 45.27672126889229, 57.37967222929001, 82.48007655143738, 98.26500713825226, 91.88667699694633, 106.24556690454483, 101.58815681934357, 106.88657730817795, 106.11019536852837, 108.87543618679047, 107.97891989350319, 109.0867580473423, 95.92972084879875, 92.9418271780014, 94.35506254434586, 81.54775097966194, 82.93146193027496, 106.31546795368195, 92.71839156746864, 72.99270763993263, 62.60983318090439, 79.69442322850227, 89.2932553589344, 96.73219218850136, 94.49819326400757, 113.15923511981964, 85.5735893547535, 93.71592164039612, 97.0746374130249, 114.39296051859856, 113.4970597922802, 104.58955496549606, 111.24338552355766, 107.7076904475689, 120.71288779377937, 118.84475603699684, 131.05095505714417, 115.71574553847313, 122.06860184669495, 119.720928221941, 108.9331702888012, 83.69346544146538, 65.6653556227684, 44.70577530562878, 23.71207471936941, 8.351743798702955, 1.2590220663696527, 0.6798138027079403, 0.4606800066540018, 0.1357516788993962, 0.27862536313477904, 0.20244739222107455, 0.22176361118908972, 0.17758219444658607, 0.14576912886695936, 0.14204096485627815, 0.200479676714167, 0.16367145261028782, 0.1658447875524871, 0.16484060237416998, 0.298996782512404, 0.15762373572215438, 0.1199226634344086, 0.11887516651768237, 0.27641367400065064, 0.12735309050185606, 0.13695988047402352, 0.08574308929382823, 0.13315968360984698, 0.16257954557659104, 0.08354744539246894, 0.15486725082155317, 0.1388178620254621, 0.11279474318143912, 0.10027694574091583, 0.06273435908951797, 0.1084703896776773, 0.20483030966715887, 0.2218307607108727, 0.18944493524031714, 0.16821477678604424, 0.10033346770796925, 0.1326840411638841, 0.11413097265176475, 0.15340999932959676, 0.18371907295659184, 0.12673669232754037, 0.12000640737824142, 0.17799040535464883, 0.10183691789279692, 0.0984203742700629, 0.10361501466832124, 0.20211168914102018, 0.31112181313801557, 0.16745827597333118, 0.10022639806265943, 0.1206886934232898, 0.08401948842220008, 0.15896945726126432, 0.15052245114929974, 0.1575023352052085, 0.26051773165818304, 0.11302509097731672, 0.13437300600344315, 0.10799642448546365, 0.1724951877258718, 0.10794705682201311, 0.12227769839228131, 0.14610696933232248, 0.14243590616388246, 0.21192484069615602, 0.09584230167092755, 0.18404717644443735], [0.058764470159076154, 0.013980728217575233, 0.019016658479813486, 0.06109167828981299, 0.03601719487051014, 0.012655614264076576, 0.014426706093217945, 0.006550130456162151, 0.043107759120175615, 0.048792409943416715, 0.03231500231777318, 0.042319101048633456, 0.08964948006905615, 0.07492953009204939, 0.07088508500601165, 0.019678930657391902, 0.06037076345819514, 0.06676009463262744, 0.005882436425963533, 0.03274017872172408, 0.041965152267948724, 0.05799774626211729, 0.09192183977575041, 0.07220969986519776, 0.13043781247688457, 0.06272856291616336, 0.03574362810468301, 0.029105918656568974, 0.07727876887656748, 0.04236292857967783, 0.06853761995444074, 0.01017325923385215, 0.016290019048028626, 0.03702135778439697, 0.04282941292331088, 0.08067286253208295, 0.04682355523982551, 0.07151691243052483, 0.0822995908674784, 0.028749428020091727, 0.024013484980969224, 0.013637725187436445, 0.06628486778936349, 0.04101940379769076, 0.06379250582540408, 0.02082884395349538, 0.06042191598680802, 0.04212563799228519, 0.0423807512561325, 0.03292072098702192, 0.027637228813546244, 0.057008211078937165, 0.024316203307535034, 0.02929069487436209, 0.03452755234320648, 0.027258347581664566, 0.05270281573757529, 1.1383438669145107, 5.402750540524721, 13.617020566016436, 32.5235415995121, 60.12333780527115, 65.39126873016357, 69.42426592111588, 68.67005959153175, 80.42504042387009, 75.59401765465736, 64.52846422791481, 72.5705198943615, 60.36712892353535, 48.37792105972767, 41.74192674458027, 38.89423035085201, 50.22342123091221, 43.38038742542267, 36.30790293216705, 57.83731207251549, 41.95088513195515, 31.903566867113113, 35.74068836867809, 22.878378555178642, 15.851465966552496, 17.734999246895313, 22.495302110910416, 22.265701331198215, 16.337637528777122, 32.840767577290535, 36.111909449100494, 35.93493774533272, 32.78743363916874, 29.18997287750244, 35.621040388941765, 40.14901801943779, 39.417481273412704, 39.80590023100376, 45.691894590854645, 61.3400287181139, 44.901366010308266, 76.03325888514519, 81.05718970298767, 81.2757919728756, 80.94036117196083, 77.9553173482418, 91.14810302853584, 87.35785961151123, 83.55359494686127, 79.66774106025696, 73.03224071860313, 41.47695176303387, 34.78160083293915, 18.371744379401207, 3.684418620541692, 0.464929158333689, 0.194644199218601, 0.10710182483308017, 0.06304120746790431, 0.029525176432798617, 0.07648949482245371, 0.05131607940711547, 0.03626292367698625, 0.047019074045238085, 0.05035246373154223, 0.012232183762534987, 0.06852533741039224, 0.04037065169541165, 0.08211645850678906, 0.06494743603980169, 0.053326639099395834, 0.04435857852513436, 0.0628060802409891, 0.043116457090945914, 0.004280445264157606, 0.025823245487117674, 0.03350039027282037, 0.0468772718886612, 0.04020739776024129, 0.039083478186512366, 0.030580541970266495, 0.018394282305962406, 0.048318804692826234, 0.02726119742874289, 0.04531620135821868, 0.009552616902510636, 0.06772802589694038, 0.02618002370581962, 0.013783567410428077, 0.0567712804331677, 0.01256421506695915, 0.057362386214663275, 0.014116393740550848, 0.0022267916074270033, 0.047260913997888565, 0.037034812921774574, 0.029053463658783585, 0.010059931428259006, 0.03078877376538003, 0.024823592975735664, 0.05265405292448122, 0.07505422574467957, 0.06114671596151311, 0.026282402977813035, 0.035326144061400555, 0.03101962065557018, 0.12210324173793197, 0.020427509043656755, 0.012987194713787176, 0.06913090765010566, 0.0410952624224592, 0.030015890042704996, 0.018127135117538273, 0.06227453181054443, 0.0637977676524315, 0.05626893922453746, 0.06587048221263103, 0.07148791672079824, 0.07172021636506543, 0.036053868097951636, 0.030144988486426882, 0.016657758787914645, 0.054522116552107036, 0.06621906155487522, 0.050775855270330794, 0.017632759008847643, 0.008852361606841441, 0.031527487153653055, 0.013922923262725817, 0.023804906231816858, 0.014100848529778887, 0.00860439151438186, 0.02428656935080653, 0.06178222443850245, 0.018200004742539022, 0.08787685292190872, 0.027545948360057082, 0.04272691119695082, 0.04098295692529064, 0.02493705065717222, 0.04012660756416153, 0.0746293090924155, 0.03711961442604661, 0.06627312701311894, 0.0600786096038064, 0.06380113700288348, 0.07524879460106604, 0.059280811983626336, 0.052064308983972296, 0.03453975325101055, 0.027775411144830287, 0.11955229463637806, 0.017863973262137733, 0.013961470413050847, 0.023975785734364763, 0.014168936868372839, 0.02359142374189105, 0.01688019714492839, 0.02007399070862448, 0.018506159212847706, 0.021247769618639722, 0.017522798698337283, 0.02518290562875336, 0.039318238050327636, 0.07038789801299572, 0.08757211966440082, 0.026064534395118244, 0.007516148834838532, 0.02446541766403243, 0.029067902141832747, 0.026118104469787795, 0.030305533582577482, 0.04147468542214483, 0.0649358362716157, 0.13976959220599383, 0.014281477997428738, 0.5954940116498619, 4.338240986689925, 12.625478021800518, 33.33703234791756, 62.80119851231575, 73.05826172232628, 79.57444846630096, 76.93767875432968, 91.86476737260818, 92.03401789069176, 75.2958020567894, 88.51830214262009, 76.83921083807945, 68.07647064328194, 62.16106206178665, 61.63701318204403, 69.12345886230469, 66.92039027810097, 61.52700148522854, 77.85727500915527, 57.521279230713844, 53.951891362667084, 51.300367042422295, 45.74805937707424, 38.98738235235214, 36.399128437042236, 37.87241958081722, 46.774084120988846, 38.00854727625847, 65.31623035669327, 63.15799556672573, 60.48673130571842, 58.59067864716053, 46.591165736317635, 60.30504025518894, 70.25246188044548, 62.18122377991676, 64.62985798716545, 71.71568736433983, 82.01270163059235, 66.09242990612984, 87.85102754831314, 97.57996469736099, 98.47644299268723, 94.75661739706993, 89.7757838666439, 101.91604122519493, 99.91080522537231, 94.48718905448914, 89.71914410591125, 82.57916763424873, 47.98475235700607, 37.93196998536587, 20.072422921657562, 3.6822840850800276, 0.3186664270469919, 0.18440515879774466, 0.10622868067002855, 0.05961462629784364, 0.04171871471044142, 0.024488659873895813, 0.03221835613658186, 0.05901237716898322, 0.020522917693597265, 0.045234331337269396, 0.02346558332646964, 0.015754125342937186, 0.04611137919710018, 0.043283291888656095, 0.05341653915820643, 0.03466249334451277, 0.02356817596592009, 0.021752049688075203, 0.056113021419150755, 0.05489929826580919, 0.030527285452990327, 0.008567547592974734, 0.04167028586380184, 0.04687163527705707, 0.10319912995328195, 0.03803292362135835, 0.005499434882949572, 0.02994305938045727, 0.030210165750759188, 0.10201996119576506, 0.002178088629989361, 0.038934313924983144, 0.05444310008897446, 0.11066664214013144, 0.04629358387319371, 0.03814417897956446, 0.04923611777485348, 0.09990075850510038, 0.037445806883624755, 0.044930017393198796, 0.09410451835719869, 0.04039614446810447, 0.0336751141003333, 0.015036154982226435, 0.04595272657752503, 0.045753975718980655, 0.051899745158152655, 0.04120335252082441, 0.045897711170255207, 0.009624432677810546, 0.04042708831548225, 0.03544272061844822, 0.02818837179802358, 0.021797359659103677, 0.030157374931150116, 0.05353705280867871, 0.08705858315806836, 0.02190175942814676, 0.032347051965189166, 0.026566838496364653, 0.05745317313994747, 0.057600990403443575, 0.15074482827913016, 0.031050345569383353, 0.11364873993443325, 0.12083772409823723, 0.1352786784991622, 0.20863614685367793, 0.1363648264668882, 0.12612816091859713, 0.2223565278109163, 0.1133083835884463, 0.13099246396450326, 0.11791319469921291, 0.09834278273046948, 0.14750801055924967, 0.15173620398854837, 0.13988158229039982, 0.11754874823964201, 0.0893640797585249, 0.211278326169122, 0.15420883224578574, 0.20524683262920007, 0.12346871182671748, 0.13887261768104509, 0.12350186356343329, 0.16315404209308326, 0.15859299543080851, 0.18879396782722324, 0.15080330951604992, 0.1388753339415416, 0.09669259510701522, 0.2277153090108186, 0.09804294022615068, 0.12203198813949712, 0.1677625862066634, 0.17319439473794773, 0.11353086461895145, 0.15646024112356827, 0.21190918138017878, 0.1681187577196397, 0.0919357624661643, 0.23772992397425696, 0.1467148624942638, 0.07274421688634902, 0.1271787451696582, 0.1282822445500642, 0.10698374171624891, 0.13392975088208914, 0.1744984817923978, 0.1822410264867358, 0.15343511360697448, 0.09729061770485714, 0.14056403160793707, 0.11484082948300056, 0.21784594719065353, 0.11815904596005566, 0.15116034192033112, 0.11348053216352127, 0.2503774710930884, 0.21770949591882527, 2.3478838009759784, 9.304327983409166, 23.162118829786777, 51.065364852547646, 83.03721025586128, 90.44205531477928, 93.83483245968819, 91.88718616962433, 106.8931357562542, 103.01665976643562, 89.70491006970406, 95.74004262685776, 86.22510239481926, 69.62073817849159, 61.41312159597874, 58.2079403847456, 72.86416053771973, 60.80277934670448, 52.924000918865204, 75.35465329885483, 58.458377346396446, 49.24854934215546, 51.30270391702652, 42.23193325102329, 30.141890197992325, 31.48529101163149, 36.09088517725468, 35.405443757772446, 28.5419537499547, 55.704695507884026, 58.47599320113659, 62.26793892681599, 54.18278977274895, 45.90059459209442, 56.79531678557396, 61.432542353868484, 56.036820486187935, 59.372380301356316, 68.19578424096107, 82.70260021090508, 68.69019851088524, 99.4738818705082, 105.21873280405998, 105.36157473921776, 105.4658031463623, 100.90946763753891, 116.70013591647148, 113.00280511379242, 108.13957527279854, 106.0547487437725, 101.07966810464859, 67.46969640254974, 56.579252779483795, 33.06862235069275, 9.235477577894926, 1.5676574176177382, 0.33067992771975696, 0.4155346588231623, 0.14611781953135505, 0.0713975379767362, 0.10906811541644856, 0.21649651491316035, 0.1470073132077232, 0.10830847531906329, 0.09979294671211392, 0.13287284353282303, 0.11477552048745565, 0.15167233475949615, 0.12062752561178058, 0.1307344637461938, 0.17078170232707635, 0.12205222650663927, 0.20711941964691505, 0.08907441209885292, 0.11475696679553948, 0.13197517138905823, 0.13411258638370782, 0.13337530719581991, 0.19506738666677848, 0.1101104989356827, 0.13936696224845946, 0.1268509979126975, 0.14144234854029492, 0.12569738872116432, 0.24309407832333818, 0.06605906935874373, 0.1050878141541034, 0.09283701176173054, 0.1992137508932501, 0.07176770639489405, 0.10429743429995142, 0.1789494976401329, 0.2576499246060848, 0.06770860389224254, 0.1336555421585217, 0.3335024637635797, 0.1517729551414959, 0.1439910617773421, 0.15457680390682071, 0.17032041301717982, 0.2313257090281695, 0.17947416636161506, 0.1816346769919619, 0.15871141251409426, 0.09168413729639724, 0.07156988693168387, 0.18921406794106588, 0.11834768505650572, 0.10381190644693561, 0.14155386365018785, 0.180748448765371, 0.1597906436654739, 0.17843193869339302, 0.12913469021441415, 0.15247495262883604, 0.14366232004249468, 0.1410392881371081, 0.2099933271529153, 0.1559641005587764], [0.025781184267543722, 0.10180331344599836, 0.07576774136396125, 0.10029857934569009, 0.0770201304112561, 0.009744563194544753, 0.030277523073891643, 0.027215102636546362, 0.027492448789416812, 0.09502213200903498, 0.007656139223399805, 0.05702283880964387, 0.03072308998525841, 0.047542941247229464, 0.053796344363945536, 0.03815656171354931, 0.03940538845199626, 0.010545168915996328, 0.03854488306387793, 0.01206248427479295, 0.008876507381501142, 0.0038151142643982894, 0.025938154067262076, 0.03823861356067937, 0.02320839947060449, 0.02281874039908871, 0.05390881313360296, 0.06397416131221689, 0.0067094305995851755, 0.0363358582399087, 0.034807509000529535, 0.02004737914830912, 0.02722876928601181, 0.026060194686579052, 0.05625811500067357, 0.13072582514723763, 0.04132331698201597, 0.04837319669604767, 0.043008678694604896, 0.024325790000148118, 0.033246393941226415, 0.022551001347892452, 0.07579317476483993, 0.014085901675571222, 0.07782266664435156, 0.020204237625875976, 0.03475703553704079, 0.02510420272301417, 0.0475515204743715, 0.019293095501780044, 0.0461278177681379, 0.044371031763148494, 0.016513201408088207, 0.05882768629817292, 0.27831719373352826, 1.933364518918097, 13.222765121608973, 25.339373499155045, 41.83742322027683, 63.06402660906315, 67.13754862546921, 65.79125806689262, 72.97006845474243, 59.94657129049301, 72.72634953260422, 61.15791209042072, 43.37809234857559, 55.52816078066826, 42.637481689453125, 31.216303445398808, 19.431309923529625, 24.133059829473495, 23.47360521554947, 27.772599533200264, 27.450259029865265, 29.981098026037216, 52.944660410284996, 61.07965148985386, 39.35356870293617, 43.937034755945206, 32.32934921979904, 33.9110903441906, 50.6781542301178, 55.40332987904549, 42.39234544336796, 49.65755179524422, 31.644314378499985, 41.364401802420616, 26.237768791615963, 28.467363752424717, 49.093259274959564, 34.598329067230225, 26.23659275472164, 28.232659846544266, 22.63455703854561, 18.60942542552948, 21.272624619305134, 26.774037815630436, 36.44940733909607, 32.545694410800934, 28.368171975016594, 47.838049829006195, 44.45501156151295, 53.932341411709785, 54.07257288694382, 66.66403323411942, 76.61185383796692, 76.8142993748188, 81.26077517867088, 80.45856222510338, 72.26864889264107, 56.28786161541939, 23.472197391092777, 2.844746564514935, 0.7103460549842566, 0.448622927069664, 0.05525746615603566, 0.06030944350641221, 0.09439969275263138, 0.08025666611501947, 0.05052306492871139, 0.073204919899581, 0.04846215793804731, 0.032472630773554556, 0.037834948307136074, 0.04068672496941872, 0.04293646401492879, 0.027300611036480404, 0.04713620350230485, 0.09597541327821091, 0.0231773238920141, 0.04936959674523678, 0.013517553852580022, 0.027052986042690463, 0.013450789319904288, 0.02274777252750937, 0.05891217981115915, 0.016310249993694015, 0.03940380396670662, 0.05197030113777146, 0.021560510649578646, 0.027584810923144687, 0.05758705287007615, 0.013232446690381039, 0.05345093770301901, 0.002109068664140068, 0.08907349925721064, 0.03066704113734886, 0.04741563694551587, 0.040323432549485005, 0.05360951239708811, 0.03461030180915259, 0.06655610050074756, 0.012679618102993118, 0.018502012462704442, 0.027851210397784598, 0.015423200766235823, 0.06765181475202553, 0.06740395969245583, 0.029460314581228886, 0.06789605555240996, 0.03628842758189421, 0.055637041295995004, 0.029585078882519156, 0.05507892397872638, 0.06791790438001044, 0.06256906795897521, 0.01223115403263364, 0.04878122948866803, 0.06163830345030874, 0.03805919935985003, 0.037348674595705234, 0.061723424078081734, 0.030078156232775655, 0.22512055293191224, 0.06670470073004253, 0.01515515928986133, 0.04838937922613695, 0.0151445206029166, 0.0855483794293832, 0.05572834030317608, 0.030177281187206972, 0.012106430549465586, 0.06361111009027809, 0.032056152340373956, 0.04259313165675849, 0.06196642920258455, 0.0837165882694535, 0.021327231370378286, 0.043539362523006275, 0.09293533890740946, 0.02496069919288857, 0.04251662365277298, 0.022315966889436822, 0.09621756864362396, 0.04056995916471351, 0.030580614329664968, 0.06046695321856532, 0.032785549919935875, 0.04345531800936442, 0.0175460112222936, 0.032472400707774796, 0.04215864872094244, 0.014828690382273635, 0.07804804205079563, 0.055979627795750275, 0.079520707949996, 0.04140179167734459, 0.04807342840649653, 0.04965228450600989, 0.08681237566634081, 0.07033234825939871, 0.09248311122064479, 0.034006293790298514, 0.10119261496583931, 0.04676299598941114, 0.007624620211572619, 0.025694236101116985, 0.027569800986384507, 0.07735279068583623, 0.04735845446703024, 0.018025336576101836, 0.05776147241704166, 0.04010406853922177, 0.050039192065014504, 0.02807010128890397, 0.025681087099655997, 0.04471836058655754, 0.03246232234232593, 0.13309526519151405, 0.09398588605108671, 1.4506383030675352, 11.653635520488024, 25.323657542467117, 44.89270247519016, 65.33266827464104, 76.25172436237335, 79.00230556726456, 83.10234636068344, 74.66907888650894, 84.61827501654625, 77.32837378978729, 55.45380637049675, 67.03270465135574, 53.81519749760628, 47.83605493605137, 34.91840869188309, 40.79532913863659, 39.583444967865944, 43.80541741847992, 33.04320551455021, 34.191933274269104, 54.09555785357952, 53.80207680165768, 35.53744487464428, 46.52756094932556, 28.473287634551525, 30.5154025554657, 37.80118100345135, 42.36306041479111, 34.05457824468613, 40.70292949676514, 41.03391453623772, 42.49086655676365, 36.9943019002676, 40.28978146612644, 50.888784527778625, 40.96280515193939, 31.2742655351758, 34.128837659955025, 33.961441442370415, 37.16859474778175, 37.28326879441738, 39.855236783623695, 57.93865263462067, 50.008181780576706, 47.93951578438282, 61.16152569651604, 61.22841350734234, 66.46767497062683, 66.08464032411575, 80.89313730597496, 87.82229349017143, 88.95511910319328, 92.56893798708916, 92.87302047014236, 83.07680413126945, 61.4822892844677, 26.698969043791294, 4.586415169760585, 1.28270702669397, 0.24230760958744213, 0.0803734282089863, 0.01308000399149023, 0.054705486400052905, 0.06668301517493092, 0.09214653982780874, 0.08405169020988978, 0.05494527431437746, 0.07966179022332653, 0.04625625384505838, 0.02826070151058957, 0.04601220971380826, 0.029624459093611222, 0.05418966036813799, 0.015218913486023666, 0.02719393844017759, 0.08185375307220966, 0.039550415240228176, 0.015723897668067366, 0.10770942113595083, 0.053339411460910924, 0.03467217837169301, 0.016477656245115213, 0.048070196353364736, 0.03647476602054667, 0.04852054269576911, 0.02881223783333553, 0.06366011410136707, 0.02004113583097933, 0.030854722863296047, 0.06110471411375329, 0.026531783150858246, 0.020138791333010886, 0.056270720378961414, 0.0477963661251124, 0.02702122768823756, 0.04414339280629065, 0.024035298556555063, 0.05062816046120133, 0.04914389850455336, 0.036893110955134034, 0.04208069723972585, 0.04835380066651851, 0.012013834639219567, 0.02036344685620861, 0.020816880532947835, 0.04689541368861683, 0.05027936589613091, 0.09397951100254431, 0.05809588044940028, 0.03782483283430338, 0.06632593082031235, 0.03343154865433462, 0.05545959007577039, 0.07770423471811228, 0.031517594325123355, 0.04190906445728615, 0.037039555245428346, 0.06144107028376311, 0.09006997352116741, 0.07209028830402531, 0.11940332333324477, 0.19769717211602256, 0.18695994280278683, 0.2047773648519069, 0.16766822955105454, 0.18816784751834348, 0.13757987064309418, 0.09751554782269523, 0.09232786134816706, 0.2477281671599485, 0.11212424986297265, 0.17304598004557192, 0.11924143123906106, 0.20247480715624988, 0.1735930616268888, 0.15503405593335629, 0.17838518338976428, 0.1119920436758548, 0.1739988976623863, 0.16787073196610436, 0.09258103760657832, 0.13591349677881226, 0.1479467682656832, 0.10568499070359394, 0.1613396394532174, 0.18072621402097866, 0.11912573041627184, 0.19380877842195332, 0.16795291739981622, 0.10456615113071166, 0.15271324140485376, 0.13478344335453585, 0.21800259972224012, 0.09696535664261319, 0.07829776732251048, 0.24774740362772718, 0.22230597271118313, 0.13698251597816125, 0.24707109929295257, 0.14270702755311504, 0.13346779363928363, 0.14381235261680558, 0.11638989206403494, 0.1719389480422251, 0.17687644169200212, 0.17055861273547634, 0.16761875798692927, 0.10129947680979967, 0.14727482775924727, 0.12506133847637102, 0.15353001945186406, 0.09155217601801269, 0.11420649359934032, 0.3710587875684723, 0.48248035716824234, 4.797936994582415, 21.81825254112482, 39.9633713811636, 61.62282474339008, 83.66607651114464, 92.00179561972618, 88.68869259953499, 96.43136233091354, 84.70316246151924, 98.6105377972126, 84.83280390501022, 63.822302520275116, 79.65691164135933, 63.44127036631107, 50.069141909480095, 30.608721747994423, 35.30089616775513, 36.25636249780655, 43.56938548386097, 40.47387018799782, 41.93019524216652, 72.09982395172119, 84.15738254785538, 53.369944989681244, 63.739474564790726, 49.87041637301445, 51.934408619999886, 74.18041750788689, 80.64010888338089, 59.965558871626854, 69.47501599788666, 45.877495631575584, 58.64404298365116, 46.6682294011116, 40.48726826906204, 67.3707041144371, 48.18690910935402, 39.72576633095741, 42.81801760196686, 35.84850378334522, 30.67492939531803, 34.87990915775299, 42.43293486535549, 54.02135543525219, 48.580480590462685, 43.45358669757843, 69.11769077181816, 64.67928573489189, 76.97389841079712, 75.45083373785019, 92.19163343310356, 100.12768238782883, 101.18980139493942, 107.7395935356617, 106.39523327350616, 99.99651342630386, 81.46284073591232, 42.47377887368202, 12.193455453962088, 3.8707822328433394, 0.8229314011987299, 0.24850642774254084, 0.14786968880798668, 0.20795069925952703, 0.12840702926041558, 0.15789904282428324, 0.13901108759455383, 0.23069822316756472, 0.17570279451319948, 0.1568282424705103, 0.1965399709297344, 0.10663344801287167, 0.21174182707909495, 0.13094943424221128, 0.206696885288693, 0.13700807554414496, 0.18619542679516599, 0.15047207416500896, 0.08512924410752021, 0.21375508076744154, 0.12953165016369894, 0.17343180777970701, 0.216918648511637, 0.13975612964713946, 0.11822900822153315, 0.18282954959431663, 0.11040783298085444, 0.1600380608579144, 0.16130290314322338, 0.20200968836434186, 0.17150848754681647, 0.1724170395755209, 0.08242978583439253, 0.20122716785408556, 0.127427424013149, 0.12616486754268408, 0.08405629894696176, 0.08954392440500669, 0.10278219138854183, 0.10840240895049646, 0.10281454160576686, 0.12031871796352789, 0.14130831666989252, 0.1513741843518801, 0.14418718172237277, 0.09342620280222036, 0.09356537775602192, 0.24750745244091377, 0.13946363440481946, 0.1412943346076645, 0.12988963251700625, 0.21545344119658694, 0.08652193617308512, 0.17432389897294343, 0.15235083585139364, 0.13512701319996268, 0.1441418068134226, 0.17484879033872858, 0.14863125106785446, 0.3722066822228953, 0.12371302684186958], [0.04929726703267079, 0.02156570382794598, 0.06491953870863654, 0.017851917073130608, 0.08405803557252511, 0.02371583366766572, 0.04541462869383395, 0.12107288843253627, 0.04317644859838765, 0.0406867732090177, 0.05743460089433938, 0.08003759154235013, 0.04348826565546915, 0.0926955955219455, 0.03757481070351787, 0.05637451715301722, 0.012673301498580258, 0.04461011092644185, 0.10938292703940533, 0.040759626135695726, 0.04618781298631802, 0.019101844045508187, 0.017261119282920845, 0.036680823322967626, 0.07605289676575921, 0.07903408171841875, 0.045553343516075984, 0.016105537833936978, 0.0008949943241987057, 0.08740956705878489, 0.016541119148314465, 0.02679519177036127, 0.05961348339042161, 0.04166829319729004, 0.06320942266029306, 0.07553290357463993, 0.06411386319086887, 0.028117593174101785, 0.08194374589947984, 0.0520313761808211, 0.05394114108639769, 0.06292509104241617, 0.0575294325244613, 0.08601167253800668, 0.020273609879950527, 0.08122997052851133, 0.029849917991668917, 0.018972534089698456, 0.05610033811535686, 0.0443596991681261, 0.04129650318645872, 0.02020868494582828, 0.16335256659658626, 1.7375776497647166, 19.033556766808033, 41.030825302004814, 57.574616968631744, 70.27329996228218, 68.5501304268837, 78.72240498661995, 64.68643695116043, 55.44351652264595, 53.08149106800556, 38.99662725627422, 43.67960996925831, 43.321737572550774, 45.9588872641325, 36.04584999382496, 44.238031804561615, 30.55065516382456, 53.873026594519615, 66.21895551681519, 70.40622442960739, 63.00396703183651, 77.93844625353813, 100.65274581313133, 76.22489780187607, 72.16106906533241, 98.15910682082176, 91.66243582963943, 96.15865856409073, 113.09457778930664, 106.77623882889748, 94.40370753407478, 121.10056579113007, 110.36265358328819, 124.19947430491447, 100.68636640906334, 88.13975125551224, 115.29852032661438, 86.62573009729385, 94.31758895516396, 94.10692825913429, 81.52886599302292, 84.53023374080658, 78.44020932912827, 75.3215342760086, 56.3153113424778, 27.000712752342224, 40.380870178341866, 39.4419177621603, 34.72184143960476, 28.973017819225788, 43.46572324633598, 53.08475889265537, 42.51676216721535, 60.315048918128014, 68.68311569094658, 75.79346895217896, 78.3495081961155, 83.45176041126251, 84.43055748939514, 80.23321151733398, 56.730211079120636, 43.90362314879894, 19.242142774164677, 2.76005148421973, 0.5687385192140937, 0.16769649053458124, 0.05782522290246561, 0.006565466937900055, 0.06803183889132924, 0.06394386684405617, 0.022710520424880087, 0.0743702995532658, 0.038871966098668054, 0.00016962104041340353, 0.04106823711481411, 0.027248421356489416, 0.02762066593277268, 0.07428514552884735, 0.0725766176765319, 0.026159796470892616, 0.09827538087847643, 0.005661682744175778, 0.05891423184948508, 0.03245274492655881, 0.051755998574662954, 0.0533606628596317, 0.1104078849311918, 0.08008776814676821, 0.040068141170195304, 0.03743616267456673, 0.05913184068049304, 0.06899845655425452, 0.0560214292636374, 0.04298521198506933, 0.03832497357507236, 0.020187225745758042, 0.07864314800826833, 0.01244283681444358, 0.07137448686989956, 0.036456676170928404, 0.06142800848465413, 0.04424397979164496, 0.022547105072590057, 0.06326371076283976, 0.005502021267602686, 0.07181666587712243, 0.07230876915855333, 0.027253861298959237, 0.019469388971629087, 0.028044771788700018, 0.05016476345190313, 0.039284084414248355, 0.018937309905595612, 0.07099472990375943, 0.05792051466414705, 0.040837488559191115, 0.00966104003964574, 0.031953030920703895, 0.03669968129543122, 0.03032334141607862, 0.04011005396023393, 0.026185172355326358, 0.04425090774020646, 0.04557202337309718, 0.05883952726435382, 0.06817588975536637, 0.07537527882959694, 0.035695514670806006, 0.06861879606731236, 0.012294155876588775, 0.07581234443932772, 0.059976148695568554, 0.01597441889316542, 0.05762036787928082, 0.011600013094721362, 0.020463738837861456, 0.08039577427553013, 0.07088732629199512, 0.097833854961209, 0.043960672337561846, 0.04809607133211102, 0.06522964511532336, 0.01738935497996863, 0.010482381367182825, 0.010024018902186072, 0.04401967307785526, 0.04005702750873752, 0.07102869058144279, 0.02740113308391301, 0.07300597237190232, 0.027917803308810107, 0.018578234739834443, 0.01888159131340217, 0.10234899236820638, 0.05209998031205032, 0.028582146078406367, 0.06595512415515259, 0.054610766092082486, 0.027793606750492472, 0.050725741748465225, 0.03432287914620247, 0.04408593202242628, 0.046544437209377065, 0.02541827219829429, 0.016013162712624762, 0.04043173787067644, 0.037575333917629905, 0.011339661195961526, 0.07967459227074869, 0.07306929983315058, 0.0882753639598377, 0.024817485100356862, 0.013232158180471743, 0.05135297527885996, 0.09404689801158383, 0.15221533452859148, 1.5844387421384454, 17.71866012364626, 42.795386016368866, 63.54755446314812, 76.26079827547073, 78.78124862909317, 92.75276452302933, 75.01939728856087, 66.3333597779274, 62.97104559838772, 54.141189604997635, 55.363420620560646, 49.10451427102089, 50.09963907301426, 44.41572546958923, 48.71063880622387, 26.190126948058605, 35.17023637890816, 46.53684005141258, 53.228368386626244, 51.615043357014656, 52.80441373586655, 71.06512427330017, 66.1519043147564, 64.17298570275307, 67.19098895788193, 67.82039478421211, 69.89664137363434, 69.44482281804085, 75.01816615462303, 63.22307847440243, 72.49809578061104, 79.02522593736649, 71.56611979007721, 71.63537487387657, 69.29674476385117, 70.05551844835281, 64.81065228581429, 62.97649830579758, 61.66728995740414, 62.28397026658058, 60.82884594798088, 55.58123633265495, 56.469868049025536, 53.27436491847038, 31.321263313293457, 44.22178767621517, 37.87031449377537, 53.558677062392235, 37.153486758470535, 50.31110152602196, 58.68641830980778, 53.351569175720215, 71.90945416688919, 75.79781591892242, 86.95612236857414, 86.93374916911125, 92.32043892145157, 97.33130604028702, 92.06333711743355, 67.59027913212776, 51.2408622354269, 23.103126995265484, 3.529626801609993, 0.22602011013077572, 0.07917819937574677, 0.10516385460505262, 0.02658478362718597, 0.1702177443075925, 0.030385258796741255, 0.06196756468852982, 0.026554873220447917, 0.14924180111847818, 0.014776753032492707, 0.05670580816513393, 0.03932566694857087, 0.032243125315289944, 0.07422244147164747, 0.03734282647201326, 0.024727165728108957, 0.030098424285824876, 0.024034385714912787, 0.015853502627578564, 0.024400745060120244, 0.02583124954981031, 0.03162673456245102, 0.05061178497271612, 0.04026858412544243, 0.04141163626627531, 0.012422425897966605, 0.037389611461549066, 0.028197695028211456, 0.03681209069327451, 0.044100470695411786, 0.022409419980249368, 0.04715452712844126, 0.01811361133150058, 0.012713533324131276, 0.0037226470703899395, 0.019056387500313576, 0.045100800416548736, 0.04287509582354687, 0.06883297246531583, 0.01866160389909055, 0.018680189132282976, 0.02281256387504982, 0.03643905758508481, 0.015755190324853174, 0.037093420323799364, 0.03484516928438097, 0.04684901090513449, 0.03311416177893989, 0.016308045815094374, 0.06154598399007227, 0.03746482812857721, 0.03507699024339672, 0.035979746098746546, 0.024385796350543387, 0.05302863341057673, 0.05774589102657046, 0.018684476890484802, 0.006405890808309778, 0.032555795842199586, 0.14675223705125973, 0.12423958061845042, 0.14998479484347627, 0.17172106832731515, 0.1870637692627497, 0.15598249097820371, 0.1138106914004311, 0.18589789979159832, 0.20665202988311648, 0.07110235615982674, 0.17746416328009218, 0.11922751597012393, 0.2018307417165488, 0.22931122337467968, 0.2363818572484888, 0.15642642887542024, 0.1382953010033816, 0.1500777414184995, 0.2760011883219704, 0.15081730642123148, 0.21935222495812923, 0.1681568447384052, 0.11291513437754475, 0.18607128033181652, 0.17518199980258942, 0.14021483628312126, 0.1942695927573368, 0.12917069921968505, 0.09168178468826227, 0.20070469588972628, 0.2455256212851964, 0.20089542784262449, 0.1364932328579016, 0.1332204951904714, 0.17968269501579925, 0.2068461905582808, 0.1479740793001838, 0.17718557588523254, 0.16984589863568544, 0.1539155057980679, 0.1890247015398927, 0.11379481686162762, 0.1314572265255265, 0.19521140784490854, 0.11919059412321076, 0.133255687833298, 0.15005575900431722, 0.21243809518637136, 0.24861629528459162, 0.13282061117934063, 0.1247177241020836, 0.20749490184243768, 0.2956455998355523, 4.7526363003998995, 29.69859078526497, 63.896527737379074, 78.5679280757904, 91.01365864276886, 90.24833410978317, 102.0355524122715, 82.4624302983284, 75.51856130361557, 73.67917120456696, 61.272365748882294, 66.38262793421745, 66.65859952569008, 69.20576244592667, 56.75070337951183, 68.22582542896271, 53.95609773695469, 78.28721433877945, 90.27383834123611, 93.99586021900177, 88.06273698806763, 105.51209226250648, 131.21624618768692, 104.52824905514717, 97.5311829149723, 129.47054386138916, 124.71378430724144, 128.66602063179016, 154.87459748983383, 143.47356766462326, 129.05539333820343, 161.3285207748413, 140.99441349506378, 159.3459239602089, 135.10904610157013, 117.33550742268562, 147.45380848646164, 112.78444603085518, 122.21781983971596, 125.49848780035973, 107.48468801379204, 109.30719181895256, 101.46737650036812, 102.45910048484802, 80.06582289934158, 46.74684338271618, 59.46898251771927, 58.01555670797825, 52.585952058434486, 43.07201497256756, 62.379740327596664, 70.75842753052711, 62.90532052516937, 83.09440478682518, 92.74591729044914, 100.25527194142342, 100.65725237131119, 107.42523640394211, 108.30570235848427, 106.94482818245888, 86.7602276802063, 71.82958245277405, 36.85862638056278, 9.186719544231892, 0.9827580687124282, 0.44695644930470735, 0.32230773009359837, 0.07214911092887633, 0.2949942910345271, 0.11554628537851386, 0.21104790415847674, 0.17226129246409982, 0.2021204464836046, 0.1273275160929188, 0.2003936469554901, 0.1579610418411903, 0.17251242039492354, 0.24999769928399473, 0.1602529571391642, 0.11921469907974824, 0.13732126186368987, 0.11452638893388212, 0.1708061486715451, 0.10148133267648518, 0.1781361037865281, 0.16565291269216686, 0.19812571787042543, 0.10660205516614951, 0.13498437241651118, 0.15698853152571246, 0.21884254761971533, 0.0916679881629534, 0.07858432538341731, 0.09145917007117532, 0.18823021760908887, 0.18907160527305678, 0.20319448260124773, 0.1640130631858483, 0.1138353010173887, 0.12570120336022228, 0.1534608958172612, 0.14217740128515288, 0.18886561476392671, 0.18230541521916166, 0.1274059314164333, 0.22839961369754747, 0.1898056932259351, 0.1650235417764634, 0.12175421710708179, 0.13899198471335694, 0.11882739447173662, 0.20228244247846305, 0.13629332795972005, 0.14136828220216557, 0.17343636456644163, 0.2551616815617308, 0.13130352774169296, 0.1278085762169212, 0.11058679447160102, 0.16135569952894002, 0.09079607596504502, 0.1392140204552561, 0.18555296439444646], [0.019940205602324568, 0.011882995859195944, 0.0518242204998387, 0.03157127015583683, 0.025184530932165217, 0.02153683057258604, 0.1119786330673378, 0.0643233343726024, 0.022475428449979518, 0.028404568693076726, 0.02329630315216491, 0.0410394677601289, 0.02110634039127035, 0.06110761591116898, 0.028817594284191728, 0.023585575618199073, 0.019868143062922172, 0.032316490323864855, 0.12087645678548142, 0.027827226040244568, 0.03285043218056671, 0.013716786179429619, 0.040786566096358, 0.031142943334998563, 0.014619499361288035, 0.022745668538846076, 0.037640457376255654, 0.03689020173624158, 0.02717698778724298, 0.024792176009214018, 0.06735435454174876, 0.03634210712334607, 0.053103883474250324, 0.05392014943936374, 0.0439523602835834, 0.05621133743261453, 0.01817313899664441, 0.03192455100361258, 0.017832775229180697, 0.08062700522714294, 0.1325430182623677, 0.017306998852291144, 0.010289839501638198, 0.0649979614536278, 0.05118667853821535, 0.022346163023030385, 0.054313636137521826, 0.027251595893176273, 0.09922736338921823, 0.09047784304129891, 0.13509248849004507, 4.361293874680996, 18.39941069483757, 39.59284566342831, 73.24468731880188, 73.94308984279633, 78.04633766412735, 64.00251924991608, 49.53339345753193, 45.95945343375206, 46.01885944604874, 39.838301092386246, 41.285388842225075, 33.96813668310642, 40.295777544379234, 46.86518043279648, 44.72049951553345, 39.27719660103321, 42.82884322106838, 65.6673239171505, 74.37702655792236, 83.706696331501, 82.85703152418137, 56.634896993637085, 32.71874472498894, 26.13234344869852, 22.48567722737789, 19.321172833442688, 26.007096469402313, 28.104990497231483, 20.82817006856203, 27.61452041566372, 29.80024293065071, 29.595283828675747, 21.843692176043987, 28.83973427116871, 29.888006821274757, 19.208818562328815, 25.29181905090809, 41.874942407011986, 36.640312895178795, 35.582658648490906, 28.309674113988876, 38.202462270855904, 61.69768452644348, 80.05990281701088, 69.11264464259148, 77.19787359237671, 101.84270516037941, 101.63996323943138, 89.15456280112267, 55.18099620938301, 42.76393510401249, 33.23821485042572, 28.33878055214882, 26.60792402923107, 31.089439652860165, 32.54156783223152, 48.0146149545908, 47.82760798931122, 65.35802811384201, 73.32011327147484, 73.51905539631844, 77.59002014994621, 79.06512379646301, 72.22146302461624, 56.66230492293835, 18.19022811949253, 2.0833997055888176, 0.043251412935205735, 0.043355992675060406, 0.044338466323097236, 0.04892022261628881, 0.05836540993186645, 0.12608033692231402, 0.0011101075097030844, 0.036373603870742954, 0.02488840102159884, 0.06377119134413078, 0.08640397179988213, 0.051649700762936845, 0.06271687409025617, 0.04251897997164633, 0.0952045148005709, 0.06065430097805802, 0.04681275328039192, 0.11358182789990678, 0.04221350456646178, 0.034117782925022766, 0.051913055576733314, 0.0325465635251021, 0.057812810482573695, 0.03086007374804467, 0.020453996294236276, 0.025445375431445427, 0.04104693005501758, 0.016089550117612816, 0.07692351762671024, 0.06928866598173045, 0.09355051995953545, 0.04222438074066304, 0.019130244181724265, 0.0754908831731882, 0.07326216917135753, 0.03553065769665409, 0.02334244618396042, 0.0047811996682867175, 0.04259585533873178, 0.018616520283103455, 0.06731295754434541, 0.037083460701978765, 0.03687010808789637, 0.020125148803344928, 0.04987109190551564, 0.05016227354644798, 0.021089892543386668, 0.03921940253349021, 0.05450394135550596, 0.02413265534414677, 0.06682338498649187, 0.03185556466632988, 0.005914365474382066, 0.09584592335158959, 0.014705845460412093, 0.056319253126275726, 0.05491125426487997, 0.01660884383454686, 0.021036903199274093, 0.054163072927622125, 0.008185861042875331, 0.005667608793373802, 0.020740886466228403, 0.034025125787593424, 0.049225538459722884, 0.02526435819163453, 0.05751256350777112, 0.04571838231640868, 0.01819729404815007, 0.016296974827127997, 0.14566361031029373, 0.04880250315181911, 0.043053686240455136, 0.03687900643853936, 0.03561629411706235, 0.03927311176084913, 0.054603775060968474, 0.027979132537439, 0.017443913966417313, 0.02969027089420706, 0.025339129570056684, 0.06514574532047845, 0.053410023101605475, 0.06293080557952635, 0.010819404542417033, 0.032980879477690905, 0.09547088644467294, 0.05381147304433398, 0.046033962062210776, 0.06957708683330566, 0.048991802759701386, 0.02075199085084023, 0.022100961141404696, 0.06948527574422769, 0.07082864467520267, 0.029280213893798646, 0.09670228013419546, 0.04506234974542167, 0.05850211724464316, 0.0609791575698182, 0.06354983837809414, 0.02664482522959588, 0.059181327087571844, 0.0384945840050932, 0.028142872579337563, 0.02887141854444053, 0.04394971823785454, 0.08108630558126606, 4.412444354966283, 18.038821443915367, 42.782592102885246, 82.39559948444366, 85.01337021589279, 85.80344662070274, 75.4783746600151, 61.665029078722, 60.65244421362877, 61.474997475743294, 49.61467109620571, 47.59100988507271, 37.16376140713692, 50.888507142663, 54.71504621207714, 56.8786995112896, 42.995848059654236, 45.74946150183678, 59.58856210112572, 64.42244991660118, 65.46197533607483, 62.826345562934875, 50.70149637758732, 33.286943435668945, 27.570678368210793, 24.56787619739771, 23.672526441514492, 30.36089714616537, 30.470595359802246, 28.037669509649277, 31.741915941238403, 34.52403545379639, 30.3692813962698, 24.797773361206055, 23.42404067516327, 26.878081932663918, 22.02511914074421, 26.880994476377964, 33.0522870272398, 31.537690199911594, 30.221828408539295, 28.47684044390917, 31.767232082784176, 43.72296944260597, 56.17811970412731, 60.86155839264393, 60.48886679112911, 73.45261216163635, 76.64516285061836, 80.4466612637043, 50.35387963056564, 37.98337742686272, 50.13548634946346, 43.70477981865406, 41.23393960297108, 44.8253358900547, 47.1400310844183, 62.58786275982857, 59.908371940255165, 79.24757480621338, 84.79876533150673, 82.18737825751305, 86.68774276971817, 88.79848390817642, 83.3849523961544, 63.83750170469284, 22.891400456428528, 3.155562048777938, 0.05473750636156183, 0.12649439595406875, 0.06249949161428958, 0.05000773613573983, 0.07161179601098411, 0.04350209186668508, 0.054445883142761886, 0.030366979699465446, 0.08224448640248738, 0.046650174699607305, 0.06108437926741317, 0.02706022383790696, 0.0547361630742671, 0.045127343328204006, 0.05957560417300556, 0.03032615415577311, 0.005177495395400911, 0.052930280289729126, 0.01023454486130504, 0.03912391039193608, 0.012071513428963954, 0.06690859838272445, 0.052215866671758704, 0.07578410572023131, 0.025363089807797223, 0.012099261402909178, 0.03431932425883133, 0.06651160874753259, 0.021147151092009153, 0.021908926719333977, 0.08624330424936488, 0.030362580619112123, 0.053300419021979906, 0.04624513276212383, 0.06379687707521953, 0.023445450715371408, 0.04922977983369492, 0.0750925725151319, 0.02406367457297165, 0.07173724865424447, 0.08647849826957099, 0.013094723562971922, 0.005960389762549312, 0.020877345159533434, 0.06008587522956077, 0.045891892732470296, 0.05030861764680594, 0.02713124737056205, 0.012083664241799852, 0.07553849194664508, 0.022894105495652184, 0.058485530244070105, 0.0038976686846581288, 0.07161348810768686, 0.029937003455415834, 0.018111286553903483, 0.015956542411004193, 0.1571058205445297, 0.1322009475552477, 0.132843766186852, 0.08733127047889866, 0.10511402681004256, 0.11262367072049528, 0.17414504138287157, 0.15984501340426505, 0.16546373924938962, 0.19777303445152938, 0.12220185089972802, 0.17175211978610605, 0.17176482535433024, 0.23515005537774414, 0.14649122371338308, 0.1474871116806753, 0.07920012983959168, 0.09773261859663762, 0.26152821024879813, 0.09824562817811966, 0.0743194624374155, 0.11836971942102537, 0.13050322537310421, 0.11171989812282845, 0.11386757701984607, 0.09916925322613679, 0.16147024260135368, 0.1470157440053299, 0.11513255289173685, 0.17481799121014774, 0.1640245516318828, 0.17303355649346486, 0.1343783049378544, 0.20674683182733133, 0.1743153197458014, 0.1528904217411764, 0.1563967578113079, 0.20887483638944104, 0.1266228171880357, 0.15838740568142384, 0.20483448053710163, 0.10740744124632329, 0.1419785650796257, 0.21396527183242142, 0.16157026926521212, 0.12471450318116695, 0.21953020681394264, 0.1281482126796618, 0.16991490352666005, 0.146206357749179, 0.20591681386576965, 7.740017948672175, 30.58909960091114, 61.53712794184685, 96.89294636249542, 93.66492837667465, 97.84978821873665, 83.76025065779686, 67.9963481426239, 64.38217207789421, 66.98107302188873, 58.315094634890556, 61.44286260008812, 54.396824687719345, 64.44173008203506, 70.32853379845619, 68.57402354478836, 61.41631342470646, 66.09381303191185, 89.52311262488365, 98.96155536174774, 109.75122839212418, 107.05730214715004, 75.08836358785629, 49.09974932670593, 40.03019839525223, 33.514699414372444, 33.13747085630894, 39.2196486890316, 41.9576221704483, 35.01386716961861, 43.25156673789024, 45.31231015920639, 41.71850860118866, 32.84462057054043, 41.32594786584377, 43.23370769619942, 29.18822307139635, 37.46528282761574, 58.491853550076485, 50.05925863981247, 47.86525256931782, 37.6246652752161, 51.99113577604294, 78.69202941656113, 104.40695956349373, 90.1460587978363, 107.12110832333565, 130.09516954421997, 134.59224343299866, 121.15484967827797, 74.75493907928467, 59.93725039064884, 48.8769368827343, 45.678473711013794, 43.47670465707779, 47.81341575086117, 49.661769568920135, 66.72213211655617, 68.26102674007416, 88.19959804415703, 95.73309659957886, 97.47928529977798, 98.4544649720192, 99.53483060002327, 99.23098370432854, 84.26539555191994, 39.27922569215298, 8.70018320158124, 0.23365327710052952, 0.19013139215530828, 0.19491122395265847, 0.12381120555801317, 0.2574230352183804, 0.23394614341668785, 0.12520598305854946, 0.14371977711562067, 0.15246809518430382, 0.12432987772626802, 0.22570514265680686, 0.19619683152996004, 0.18186774104833603, 0.09322080601123162, 0.14742417755769566, 0.08238516049459577, 0.20115474908379838, 0.3311646095244214, 0.1343379172612913, 0.1585398131283, 0.15800500666955486, 0.25286906864494085, 0.20176414138404652, 0.15496151841944084, 0.21861528715817258, 0.09234352808562107, 0.12231314336531796, 0.11702511110343039, 0.19085133477346972, 0.19542256370186806, 0.2694745338521898, 0.16726586676668376, 0.12077884952304885, 0.2581451152218506, 0.22403197071980685, 0.12195693474495783, 0.12391823067446239, 0.15482257353141904, 0.15853089251322672, 0.13879987236578017, 0.1605247167753987, 0.10129443020559847, 0.09823083717492409, 0.11159598914673552, 0.15225039358483627, 0.11264892600593157, 0.11428016659920104, 0.12523283396149054, 0.17653771064942703, 0.13190766563639045, 0.17008115944918245, 0.12330063022091053, 0.05075031796877738, 0.20094218314625323, 0.11081524979090318, 0.1642543205525726, 0.1315137930214405], [0.028539370541693643, 0.037642101233359426, 0.011575878452276811, 0.0596851043519564, 0.0500448360980954, 0.050518626885605045, 0.05713552651286591, 0.08670310926390812, 0.025477515991951805, 0.054277040835586376, 0.03330175073642749, 0.022054365399526432, 0.025555504580552224, 0.09923802062985487, 0.0507515759090893, 0.04037049955513794, 0.009729072717163945, 0.02376794542215066, 0.08076418380369432, 0.0409700398449786, 0.0570217033236986, 0.06470065709436312, 0.0066171287653560285, 0.04929415001242887, 0.03486203459033277, 0.11851857940200716, 0.08486616017762572, 0.05069257887953427, 0.0645662764145527, 0.03188651964592282, 0.004703362292275415, 0.0798339387984015, 0.03520221282087732, 0.018577384980744682, 0.007250555981954676, 0.06743356396327727, 0.08054602949414402, 0.10067828436149284, 0.033193994604516774, 0.08769321590079926, 0.048881393449846655, 0.04887528557446785, 0.08280258145532571, 0.054138838095241226, 0.09857929777354002, 0.03812211492913775, 0.055002846420393325, 0.013022379935136996, 0.3436089417664334, 3.7014101212844253, 22.316291816532612, 47.688797637820244, 68.3109712600708, 80.60839578509331, 63.815158903598785, 58.247040286660194, 49.21924911439419, 36.35986514389515, 26.431054919958115, 23.593631274998188, 26.518438830971718, 45.28488703072071, 27.18936312943697, 38.41540664434433, 22.166201770305634, 29.614755883812904, 29.249333292245865, 28.608858659863472, 34.72088009119034, 24.65409927070141, 20.635826289653778, 13.435048330575228, 10.856462996453047, 4.544962244108319, 2.2255783388391137, 1.2770427181385458, 1.66101852664724, 0.9584311803337187, 0.6686760659795254, 0.5510856758337468, 1.013733115978539, 0.44018179876729846, 0.23575532133691013, 0.25179152959026396, 0.2051961439428851, 0.46268879261333495, 0.11418272260925733, 0.361421198467724, 0.6657632254064083, 0.2976238983683288, 0.4297837457852438, 0.47730533173307776, 0.788375639822334, 2.0899044815450907, 3.026542109437287, 4.01513434946537, 5.91546225361526, 14.928880222141743, 26.397244334220886, 46.03033863008022, 57.71328292787075, 84.99409005045891, 73.64625737071037, 49.50508497655392, 57.89630390703678, 53.27715776860714, 40.05327455699444, 31.385620459914207, 20.96906840801239, 23.59399225562811, 28.34854032844305, 41.265322118997574, 54.45545934140682, 64.99788343906403, 69.98788967728615, 73.43441873788834, 79.57973778247833, 68.28880324959755, 53.93168784677982, 24.447829239070415, 4.230859698727727, 0.23771987529471517, 0.15604509855620563, 0.06104619948018808, 0.0901471271936316, 0.09909571381285787, 0.09786279129912145, 0.02485346998582827, 0.029083279441692866, 0.061243599629960954, 0.052780900805373676, 0.037018381772213615, 0.04007695788459387, 0.10141431674128398, 0.046433890602202155, 0.1109568664105609, 0.0832972303032875, 0.039993562750169076, 0.0429366606840631, 0.05573986956733279, 0.050052962615154684, 0.04875604099652264, 0.058313277768320404, 0.018933780993393157, 0.10140417158254422, 0.039305636382778175, 0.0649161842011381, 0.037993074001860805, 0.00919682295716484, 0.044417130266083404, 0.01550033124658512, 0.050222621284774505, 0.08237103742430918, 0.05053288725321181, 0.007359545006693224, 0.02293861394718988, 0.03821945872914512, 0.06541493712575175, 0.12860167975304648, 0.004801297955054906, 0.03015513178979745, 0.053584502020385116, 0.09190676675643772, 0.03539700432156678, 0.08744480423047207, 0.012268907084944658, 0.07671845480217598, 0.05103175149997696, 0.06885470254928805, 0.04839437759073917, 0.009397367957717506, 0.053855693913646974, 0.02430294483929174, 0.059220505063422024, 0.04087984292709734, 0.006781700940337032, 0.05404706782428548, 0.03515710137435235, 0.02394783830823144, 0.04965542379068211, 0.027195255752303638, 0.005382709896366578, 0.05294046255585272, 0.04826866519579198, 0.03674091130960733, 0.04329724055423867, 0.023070899915182963, 0.04832669743336737, 0.007083265227265656, 0.05391706952650566, 0.03986972427810542, 0.025285437041020487, 0.135791250213515, 0.07546138280304149, 0.05769939176389016, 0.05881560042325873, 0.028769323143933434, 0.06728912718244828, 0.05840794983669184, 0.04034991237858776, 0.03972136153606698, 0.015737291578261647, 0.03543572958733421, 0.034886002249550074, 0.049254114856012166, 0.0510123999993084, 0.040110911140800454, 0.06595458238734864, 0.02088034714688547, 0.03763811590033583, 0.0707705641980283, 0.07562646613223478, 0.10360009750002064, 0.08992846822366118, 0.08900252767489292, 0.08357192142284475, 0.03956280539568979, 0.05019592252210714, 0.04700275792856701, 0.13788231066428125, 0.034223301481688395, 0.03525107211316936, 0.07002557409578003, 0.006150970502858399, 0.2742504916386679, 3.995240516960621, 24.534010514616966, 54.50418412685394, 78.24948236346245, 88.38562846183777, 74.77582275867462, 68.11299428343773, 63.957301676273346, 45.85460565984249, 41.38338938355446, 37.411720901727676, 35.76694495975971, 45.34748487174511, 33.21314379572868, 44.16611686348915, 39.567710012197495, 41.69941462576389, 36.976416260004044, 38.87465760111809, 39.049786403775215, 30.560103356838226, 24.70411978662014, 17.452809289097786, 11.55472207814455, 5.94862449914217, 2.940855994820595, 1.8347414047457278, 2.3389732791110873, 1.3401104276999831, 0.9642213571351022, 1.150398482568562, 1.0592583543621004, 0.6173993612173945, 0.5676464340649545, 0.6445558508858085, 0.34951738722156733, 0.25412881979718804, 0.14200329344021156, 0.21845633396878839, 0.4657188628334552, 0.5405921232886612, 0.5275427328888327, 0.5410895403474569, 0.8086367463693023, 1.816035364754498, 3.0502751609310508, 5.029697008430958, 7.11608050391078, 14.968299306929111, 24.894447773694992, 42.39804893732071, 51.801750138401985, 65.49843057990074, 57.65101186931133, 42.03661233186722, 49.2653938382864, 51.02933518588543, 39.875421300530434, 38.298916295170784, 36.187730580568314, 39.021401926875114, 43.95989432930946, 54.34017352759838, 67.3230242729187, 75.1359598338604, 80.96077367663383, 81.69708296656609, 89.77969765663147, 77.88870692253113, 65.9722575545311, 31.05332639068365, 6.192936189472675, 0.32874030992388725, 0.0851977443380747, 0.06954737866180949, 0.064308506262023, 0.10187395848333836, 0.06719775396049954, 0.049845172397908755, 0.02250204372103326, 0.06899896121467464, 0.04195744506432675, 0.04078990205016453, 0.014684672914881958, 0.025972381918109022, 0.04419022603542544, 0.03656723019958008, 0.059504187302081846, 0.05452930425235536, 0.08515050663845614, 0.053870440387981944, 0.04870730415859725, 0.017706628677842673, 0.04005639668321237, 0.0400588902994059, 0.05986173178825993, 0.024393034145759884, 0.05666839650075417, 0.023321118715102784, 0.07690569123951718, 0.037490621471079066, 0.005231311770330649, 0.08931449687224813, 0.10072921053506434, 0.014531758024531882, 0.011956360867770854, 0.05096955952467397, 0.06636519785388373, 0.04917360296531115, 0.0648429490684066, 0.0562657665432198, 0.09845073553151451, 0.03286350882262923, 0.031013603693281766, 0.018912913656095043, 0.03784445521887392, 0.040831681253621355, 0.09485914895776659, 0.01962654245289741, 0.036434333815122955, 0.033602981056901626, 0.06339442523312755, 0.025772822118597105, 0.03533227791194804, 0.021123055412317626, 0.05971677179331891, 0.01578752384375548, 0.23067030357196927, 0.08846387689118274, 0.09411874532816, 0.16766315326094627, 0.14036765933269635, 0.15593925345456228, 0.1554352164384909, 0.1801021271967329, 0.16434462508186698, 0.22063646698370576, 0.15607236506184563, 0.26353272143751383, 0.12908091419376433, 0.24958542140666395, 0.1675056101521477, 0.1636844698805362, 0.1916133423219435, 0.18366281816270202, 0.2770690497709438, 0.13843010470736772, 0.15777825086843222, 0.18445480847731233, 0.09883873775834218, 0.22334349516313523, 0.1771815534448251, 0.22494705364806578, 0.1884578343015164, 0.11126269062515348, 0.16541281307581812, 0.18712513003265485, 0.24090193735901266, 0.14928843767847866, 0.2013750482001342, 0.15923348371870816, 0.18216940923593938, 0.1462110481224954, 0.19533859711373225, 0.2545837563229725, 0.25950315641239285, 0.24846725718816742, 0.17748014914104715, 0.18656267115147784, 0.1726677073747851, 0.30327348271384835, 0.20685698138549924, 0.13866987777873874, 0.19521799811627716, 0.14091149030718952, 0.961304004304111, 9.087315928190947, 38.31218518316746, 71.05928018689156, 91.67734622955322, 101.03733837604523, 82.37905517220497, 75.77247127890587, 68.80753621459007, 51.43488362431526, 41.03811331093311, 36.832225397229195, 38.76138187944889, 63.07378448545933, 49.004021063447, 63.14495086669922, 41.16625003516674, 49.86418470740318, 50.33509723842144, 50.39942778646946, 51.654857620596886, 38.544098138809204, 31.563734002411366, 20.977880135178566, 15.775125212967396, 7.895222520455718, 4.074667654931545, 2.612263639457524, 2.965707373805344, 1.8781214207410812, 1.6754030110314488, 1.6820081253536046, 2.1545214392244816, 1.0357276420108974, 1.0605095559731126, 0.8342465409077704, 0.9604818827938288, 0.9406118583865464, 0.40469443425536156, 0.8476850541774184, 1.222144451458007, 0.5906810949090868, 0.709911334561184, 0.896908266004175, 1.7087813699617982, 3.3974860422313213, 4.680009847506881, 5.862241834402084, 8.617952764034271, 20.888432934880257, 35.53147919476032, 60.37799634039402, 75.62422603368759, 114.36002388596535, 97.20842823386192, 74.17043924331665, 80.34359559416771, 73.31861615180969, 59.28930155932903, 51.311188861727715, 38.593518286943436, 41.41867808997631, 43.296605721116066, 61.31388612091541, 77.42345988750458, 86.17165446281433, 93.0685655772686, 94.96219396591187, 99.38752010464668, 92.70412713289261, 86.94156154990196, 48.11538554728031, 12.362703122198582, 0.827583895297721, 0.2874281845288351, 0.31630396319087595, 0.1530026047839783, 0.2818258007755503, 0.23353787313681096, 0.16488354303874075, 0.13930478511611, 0.1719803747255355, 0.1782944187289104, 0.08250034181401134, 0.12417155536240898, 0.12600114976521581, 0.143747192050796, 0.3094860602868721, 0.13625176768982783, 0.11849538728711195, 0.14006566460011527, 0.14950259181205183, 0.13602128630736843, 0.1347764820093289, 0.20742332912050188, 0.11927939209272154, 0.20198132348014042, 0.16738682199502364, 0.29338436492253095, 0.1876205432927236, 0.09351769476779737, 0.11377327231457457, 0.11851129893329926, 0.1142344280378893, 0.17550547228893265, 0.15966618550010026, 0.1367941143689677, 0.13978851697174832, 0.15710197621956468, 0.13369762193178758, 0.29925246722996235, 0.1404403304331936, 0.12237847462529317, 0.16775225551100448, 0.19855076068779454, 0.17091956367949024, 0.21104782994370908, 0.10372659657150507, 0.1877479997347109, 0.15488733333768323, 0.2060412275022827, 0.18576230941107497, 0.10444105471833609, 0.1991219917545095, 0.1637579721864313, 0.09644634308642708, 0.15767717035487294, 0.16133152035763487], [0.11297810560790822, 0.043381307332310826, 0.04567657713778317, 0.06190526510181371, 0.05959682217508089, 0.07505695684812963, 0.04686217289417982, 0.03561515863111708, 0.055135401416919194, 0.013494154864019947, 0.07104875083314255, 0.018661353424249683, 0.020815871212107595, 0.10217575283604674, 0.0518330520571908, 0.024047191473073326, 0.031050430916366167, 0.029088682276778854, 0.0342893192282645, 0.01913069689180702, 0.03370864062162582, 0.06792069485527463, 0.04791204468347132, 0.04916949888865929, 0.008500090079905931, 0.020249267436156515, 0.03673190534755122, 0.040799768903525546, 0.05603159668680746, 0.04196890753519256, 0.03318402013974264, 0.044199402691447176, 0.05383863564929925, 0.03867831750540063, 0.05589745720499195, 0.06699226069031283, 0.017902557519846596, 0.058789120594155975, 0.0898633076576516, 0.010812257660290925, 0.024714721766940784, 0.08758062467677519, 0.021520199043152388, 0.11738010260160081, 0.06339991712593473, 0.052971465775044635, 0.42764377780258656, 4.322530729696155, 22.683150731027126, 54.79154750704765, 77.80023247003555, 78.58492076396942, 74.8412324488163, 63.59203487634659, 49.9078481644392, 43.593871369957924, 24.56958420574665, 13.081453554332256, 17.846038788557053, 34.36585374176502, 50.60789220035076, 45.96519872546196, 53.28005701303482, 35.151624977588654, 45.14867193996906, 31.92078374326229, 22.521703094244003, 14.745536260306835, 6.0613050777465105, 5.590595360845327, 3.095843503251672, 1.280633881688118, 0.3890982602024451, 0.17793524893932045, 0.02790412552712951, 0.08014021572307684, 0.06185268022818491, 0.08237930494942702, 0.08603620051871985, 0.0784819015825633, 0.0785646287840791, 0.18756654462777078, 0.11359327923855744, 0.05808004301798064, 0.02951289945485769, 0.0316447984369006, 0.11622998892562464, 0.07151255602366291, 0.12851732724811882, 0.1206356892362237, 0.12175272539025173, 0.27152767055667937, 0.12080290995072573, 0.16337848239345476, 0.13265959481941536, 0.054484074062202126, 0.5069410696160048, 0.3938035655301064, 1.0211538802832365, 2.2766549605876207, 14.649199079722166, 22.346906773746014, 37.19600647687912, 69.55032035708427, 71.95498332381248, 99.49779018759727, 83.41408163309097, 64.98598247766495, 51.87248334288597, 24.859267361462116, 19.908501617610455, 16.777368932962418, 19.097119756042957, 35.860803723335266, 43.23487803339958, 74.23463299870491, 75.26760756969452, 83.67688313126564, 84.17349368333817, 80.43935045599937, 59.45101708173752, 37.78576523065567, 8.519752733409405, 0.4033128818264231, 0.21300585300195962, 0.007053353429000708, 0.0061073971573932795, 0.08507612117682584, 0.04303543682908639, 0.05503884800418746, 0.08671410047099926, 0.039777701676939614, 0.07256604949361645, 0.1194282594951801, 0.006250634442039882, 0.029639808562933467, 0.06401692386134528, 0.08401110215345398, 0.03342407893796917, 0.023117284144973382, 0.007619025809617597, 0.03547893742506858, 0.023261988098965958, 0.040011819583014585, 0.020771553863596637, 0.059011727789766155, 0.048604000912746415, 0.02604678778880043, 0.01327873536865809, 0.03557277457730379, 0.053904055966995656, 0.009766938019311056, 0.003901598820448271, 0.029578468202089425, 0.02956639160402119, 0.047587997032678686, 0.03468481343588792, 0.01901166939205723, 0.024380859213124495, 0.033766910346457735, 0.03490383234748151, 0.043500770843820646, 0.018531394089222886, 0.03534669041982852, 0.03612787135352846, 0.08262341216322966, 0.048855114000616595, 0.046155674281180836, 0.10534035216551274, 0.052321043840493076, 0.07623846337082796, 0.09572208116878755, 0.031615769330528565, 0.05351963460270781, 0.06727231753757223, 0.04351338364358526, 0.03607962804380804, 0.056349640362896025, 0.08481283686705865, 0.034873278127633967, 0.04100997852219734, 0.049557913007447496, 0.02689921861019684, 0.045322876976570114, 0.06618878192966804, 0.05306594117428176, 0.0705288838071283, 0.02414032358501572, 0.0691812475270126, 0.01781953531462932, 0.037225563428364694, 0.001383907820127206, 0.03433559955738019, 0.03044896846404299, 0.042633730845409445, 0.06949747665203176, 0.04426888997841161, 0.05689455858373549, 0.015494722465518862, 0.028297029639361426, 0.01604287088412093, 0.07418591296300292, 0.03957873188483063, 0.09668678409070708, 0.04141337289183866, 0.07167862640926614, 0.02160301159165101, 0.06893060199217871, 0.064298591169063, 0.019747339974856004, 0.025804333708947524, 0.014768086602998665, 0.023988212997210212, 0.04627716014510952, 0.06578814092790708, 0.044533127947943285, 0.08206076774513349, 0.09667459802585654, 0.04519578047620598, 0.05196903948672116, 0.029497644609364215, 0.05417552245489787, 0.33297295623924583, 4.712063502520323, 25.788363106548786, 60.30300736427307, 87.77250096201897, 84.99839901924133, 87.20121681690216, 75.87724685668945, 62.74436496198177, 56.3952324539423, 33.08806970715523, 26.184035874903202, 26.170936077833176, 31.153743602335453, 36.01978339254856, 45.06804786622524, 48.39309744536877, 34.92224268615246, 31.712488420307636, 31.81826714426279, 25.31805284321308, 17.396469712257385, 9.446504954248667, 7.683399561792612, 4.634744301438332, 1.8058171193115413, 0.6756282085552812, 0.24866336229024455, 0.056539700672146864, 0.06930898598511703, 0.11035877701942809, 0.0925175914017018, 0.1994257082697004, 0.165533990948461, 0.20469724258873612, 0.3091919026337564, 0.14538040675688535, 0.21579183085123077, 0.16989345545880497, 0.18630415142979473, 0.45537471945863217, 0.09784218927961774, 0.005413535000116099, 0.11867693145177327, 0.08508519764291123, 0.10134051015484147, 0.16404151712777093, 0.06287130017881282, 0.030471026948362123, 0.05375728142098524, 0.5055146617814898, 0.04435887538420502, 0.6037632585503161, 3.118362994864583, 12.227418031543493, 23.55229139328003, 36.001829355955124, 50.949566066265106, 60.2342576533556, 72.46711984276772, 72.64609783887863, 66.92224457859993, 48.955455869436264, 31.876991093158722, 29.122632890939713, 28.916613645851612, 34.09064210951328, 51.3276419788599, 53.21243964135647, 83.12148973345757, 83.55416491627693, 90.2336061000824, 93.26058447360992, 91.27825364470482, 69.64469209313393, 46.23699054121971, 10.64330868422985, 0.25636449514422566, 0.14260250347433612, 0.05431006269645877, 0.08010615856619552, 0.08378686965443194, 0.017962068486667704, 0.021237824839772657, 0.053380036624730565, 0.01724131878290791, 0.029765828949166462, 0.037470171591849066, 0.03291436820290983, 0.12450637528672814, 0.029864328644180205, 0.08446443564025685, 0.014319173533294816, 0.0523114998213714, 0.03393302897165995, 0.06775095826014876, 0.03168448849464767, 0.04944147003698163, 0.039305027821683325, 0.032170806734939106, 0.04109638677618932, 0.08687106470461003, 0.034185303520644084, 0.01300574933338794, 0.019172407446603756, 0.049052072572521865, 0.027876740277861245, 0.03229514986742288, 0.04050460192956962, 0.05629955652693752, 0.03894124929502141, 0.028836947640229482, 0.030906856882211287, 0.05095151791465469, 0.03397041837160941, 0.02547900214267429, 0.03151503762637731, 0.02175314806663664, 0.039834416602388956, 0.035639649504446425, 0.05112181854201481, 0.11654073357931338, 0.0747383528505452, 0.048976020989357494, 0.12399209663271904, 0.04813680781808216, 0.07509848743211478, 0.01849374864832498, 0.031098616709641647, 0.07507333604735322, 0.2937483735149726, 0.14152245596051216, 0.19544418988516554, 0.1629173563560471, 0.12344180897343904, 0.18403248192043975, 0.11607333639403805, 0.14951068122172728, 0.1658825034974143, 0.10090884738019668, 0.20204298110911623, 0.12700269289780408, 0.13629792927531525, 0.3041167702758685, 0.12029283185256645, 0.1316863571992144, 0.06389873684383929, 0.16767946566687897, 0.14770209701964632, 0.17323168023722246, 0.09263812360586599, 0.1306465786183253, 0.10483005142305046, 0.11430182988988236, 0.1709100790321827, 0.17320162325631827, 0.11910983361303806, 0.21923631633399054, 0.09311769943451509, 0.14471937582129613, 0.12729527719784528, 0.1357558200834319, 0.1542359503218904, 0.1989925908856094, 0.15484084520721808, 0.1654531413805671, 0.13797150197206065, 0.12556120462249964, 0.18724664929322898, 0.13523073575925082, 0.15692311862949282, 0.17145839257864282, 0.17457081150496379, 0.23483842756832018, 0.14835460809990764, 0.2017134675406851, 0.935760528082028, 9.766569379717112, 38.75796586275101, 77.49492645263672, 97.70354926586151, 96.86405271291733, 94.25673142075539, 83.12278926372528, 68.83492514491081, 60.275561437010765, 37.51625709235668, 26.671545915305614, 28.65756444633007, 45.280543863773346, 69.26798030734062, 67.99233555793762, 75.01161530613899, 52.3546888679266, 61.06330096721649, 49.339581057429314, 33.15475232899189, 22.644759491086006, 11.426191125065088, 9.915382694453001, 6.354671660810709, 2.795658898539841, 0.8413755521178246, 0.4554858634946868, 0.2661228465149179, 0.32775159110315144, 0.26564635802060366, 0.17064064973965287, 0.3160437959013507, 0.32325803535059094, 0.3612315945792943, 0.588211405556649, 0.4361789213726297, 0.36534199432935566, 0.3278289525769651, 0.2861150581156835, 0.61701878788881, 0.23238678724737838, 0.2713413321180269, 0.3690795984584838, 0.39331187785137445, 0.532475165091455, 0.3652982966741547, 0.3201243613148108, 0.24885358958272263, 0.3360383230028674, 1.0447786375880241, 0.8087585773319006, 2.081891424022615, 4.255614895373583, 20.70660889148712, 32.35419988632202, 49.72307167947292, 92.39320501685143, 93.40730980038643, 127.65355736017227, 107.34251484274864, 80.80238297581673, 73.8682946562767, 41.96654409170151, 35.51170885562897, 33.53895731270313, 34.34083588421345, 52.978136613965034, 62.310040667653084, 93.17425310611725, 96.22899278998375, 103.33243802189827, 103.27325239777565, 105.93934893608093, 92.14273005723953, 65.49147695302963, 18.980623707175255, 0.6482329254504293, 0.33490004658233374, 0.17242711794096977, 0.15405853249831125, 0.18549638305557892, 0.12457907607313246, 0.12906538846436888, 0.2500792464707047, 0.15030293870950118, 0.21376027580117807, 0.24474583187839016, 0.13086407241644338, 0.16280376323265955, 0.15389260312076658, 0.1716623199172318, 0.11424035779782571, 0.15195487037999555, 0.14354057813761756, 0.14185994019499049, 0.11984795884927735, 0.19270703051006421, 0.15399147203424945, 0.1586656368453987, 0.12434973017661832, 0.1694333684281446, 0.07504770226660185, 0.14182121492922306, 0.1891932581202127, 0.17602948792045936, 0.15264178742654622, 0.14775925723370165, 0.18405268318019807, 0.09403670832398348, 0.11943625242565759, 0.1760012417798862, 0.12704088381724432, 0.09672386921010911, 0.13674271322088316, 0.11970338848186657, 0.12184554580016993, 0.17875413468573242, 0.10002360621001571, 0.1626285570091568, 0.14055527426535264, 0.173058403597679, 0.14962356188334525, 0.13852260599378496, 0.2199097114498727, 0.1703450077911839, 0.15197474509477615, 0.1196748751681298, 0.17405680002411827, 0.1908533088862896], [0.016922347422223538, 0.03781377483392134, 0.0527854984102305, 0.01816181196772959, 0.016189643574762158, 0.0468493856897112, 0.04030176925880369, 0.07241085157147609, 0.09343213256215677, 0.022446165567089338, 0.05925360484980047, 0.04931234747346025, 0.0011529861353665183, 0.06435583301936276, 0.02757265083346283, 0.003953214727516752, 0.015517680803895928, 0.032750594764365815, 0.02929025886260206, 0.03668624471174553, 0.025290348203270696, 0.0425083858135622, 0.01128368841818883, 0.04194878420094028, 0.04455243863048963, 0.0596454662445467, 0.015248322015395388, 0.009585967163729947, 0.025626828683016356, 0.03733104487764649, 0.02874393427191535, 0.03142141198622994, 0.018408128926239442, 0.007809250782884192, 0.05471494507219177, 0.012566431305458536, 0.08143400918925181, 0.02592248361906968, 0.11181712688994594, 0.06933620796189643, 0.05900341202504933, 0.03292373410658911, 0.019709015468833968, 0.17327376001048833, 0.12812087195925415, 4.616989279165864, 28.03879614919424, 53.749210238456726, 73.74525725841522, 75.36506474018097, 67.04015225172043, 68.697539716959, 57.33634315431118, 47.02048569917679, 21.849351972341537, 18.262169659137726, 27.71707311272621, 24.92681633681059, 61.34161703288555, 83.5901489853859, 60.84852509200573, 49.31754224002361, 31.416170820593834, 26.5025594830513, 19.391415864229202, 4.654431045055389, 1.8718880927190185, 0.7599534618202597, 0.673031285405159, 0.08224453093134798, 0.0847822158539202, 0.05548003253352363, 0.036737215414177626, 0.02721936998568708, 0.02592569526314037, 0.031532719294773415, 0.06591972371097654, 0.08897197345504537, 0.013984617071400862, 0.06684265114017762, 0.11703941228915937, 0.016843091616465244, 0.05243044382950757, 0.10251665094983764, 0.18762711872113869, 0.07589074491988868, 0.2246824186295271, 0.15649627981474623, 0.1601482549449429, 0.038420361815951765, 0.014039861616765847, 0.08911786484532058, 0.05239818638074212, 0.024841116937750485, 0.11234399979002774, 0.03394299230421893, 0.07978730965987779, 0.09311084941145964, 0.05616433350951411, 0.1462577737402171, 0.1768710685428232, 0.9668831143062562, 2.4195104325190187, 5.733154211193323, 12.647042814642191, 25.270627588033676, 42.60008029639721, 61.5886227786541, 77.05019071698189, 75.42080774903297, 61.192505434155464, 37.17657811939716, 23.098111264407635, 11.946868635714054, 25.51943253725767, 37.69717678427696, 58.42439576983452, 66.81098654866219, 65.88695973157883, 79.13178741931915, 75.07922127842903, 86.46630585193634, 68.05566295981407, 35.152894109487534, 8.317884765565395, 0.5383643740788102, 0.14731957926414907, 0.07604191298014484, 0.07077905436744913, 0.02070562888548011, 0.07045217542327009, 0.029679222170670982, 0.1925465336535126, 0.07812823852873407, 0.00931508047870011, 0.02387207801803015, 0.016890540828171652, 0.07867980268201791, 0.035187688990845345, 0.039684369185124524, 0.03581268865673337, 0.04114444454899058, 0.07966351200593635, 0.013129383714840515, 0.04490720006288029, 0.028162604430690408, 0.030112719905446284, 0.016118579223984852, 0.008791314394329675, 0.09118265326833352, 0.04603348708769772, 0.02615392608277034, 0.03755455749342218, 0.06690931084449403, 0.01852257366408594, 0.0019540136054274626, 0.035550391403376125, 0.02411559336906066, 0.05439140208181925, 0.06091194867622107, 0.012872885417891666, 0.030922278710932005, 0.018276353184774052, 0.07381896546576172, 0.0665025100170169, 0.014465186450252077, 0.053430999905685894, 0.06298028456512839, 0.02842831741872942, 0.029747290100203827, 0.00959432560193818, 0.0296027086005779, 0.020587540202541277, 0.00958059494223562, 0.053109876316739246, 0.058049429426318966, 0.023491330284741707, 0.016782315287855454, 0.040124429360730574, 0.04505335120484233, 0.013067200088698883, 0.020685987947217654, 0.058279369040974416, 0.030316966367536224, 0.04706690917373635, 0.06048112452845089, 0.018411952842143364, 0.03985172348620836, 0.0593460207892349, 0.01457668857256067, 0.027746671476052143, 0.060523898209794424, 0.022112779843155295, 0.015036078912089579, 0.03190844268829096, 0.017680282435321715, 0.022818506622570567, 0.02431200089631602, 0.0359392545215087, 0.04637071899196599, 0.07532279414590448, 0.0073126987899740925, 0.05733747602789663, 0.04700418285210617, 0.01893082539027091, 0.10106443864060566, 0.05468063187436201, 0.08976910685305484, 0.030585831627831794, 0.049112950946437195, 0.04372233532194514, 0.025287249736720696, 0.0906132033560425, 0.03730149255716242, 0.03620573006628547, 0.01999476458877325, 0.036600125895347446, 0.01769310674717417, 0.02910466257162625, 0.19411432062042877, 0.21449498715810478, 4.931296538561583, 32.401332557201385, 60.38843438029289, 83.04575979709625, 87.10591033101082, 78.68727207183838, 78.01391780376434, 63.37811015546322, 59.208738282322884, 35.51289439201355, 32.99666941165924, 34.56207141280174, 22.450650706887245, 38.290864527225494, 58.371878787875175, 55.327565744519234, 50.49202501773834, 39.56767201423645, 27.091733068227768, 18.321398980915546, 6.733259595930576, 2.1437965147197247, 1.2549672089517117, 0.7608948613051325, 0.21205134718911722, 0.06322841421933845, 0.06617166800424457, 0.125642261991743, 0.10751016190624796, 0.13074445305392146, 0.10487003833986819, 0.2600821206578985, 0.17491525708464906, 0.131887182360515, 0.08378545957384631, 0.04225866425258573, 0.21736107242759317, 0.29378061241004616, 0.4069941124180332, 0.697335849981755, 0.8414222777355462, 1.3436622871086001, 0.8348274941090494, 0.40243682102300227, 0.05996970685373526, 0.10734763156506233, 0.04219273556373082, 0.020205490000080317, 0.08597788255428895, 0.02038997863564873, 0.08438000149908476, 0.05797606812848244, 0.1472635322716087, 0.07932519656606019, 0.005341913110896712, 0.30474189610686153, 0.7899938186164945, 2.6560353906825185, 6.05931113474071, 13.13527386635542, 25.236376225948334, 39.01185303926468, 41.416238620877266, 60.531135722994804, 46.9424606859684, 47.04410903155804, 35.41391350328922, 30.903331339359283, 26.387818939983845, 40.370314344763756, 54.44801554083824, 69.89449828863144, 81.44998982548714, 77.75156468153, 89.30708661675453, 85.29694139957428, 98.60128909349442, 80.22789940237999, 42.62462317943573, 9.360656160861254, 0.6318345491308719, 0.2933008287800476, 0.01922833384014666, 0.06492621803772636, 0.026452931815583725, 0.061729186854790896, 0.06656554804067127, 0.10799846539157443, 0.05155681355972774, 0.06921787251485512, 0.045855456992285326, 0.016440624931419734, 0.10987952031427994, 0.014110761767369695, 0.035575168003560975, 0.04720046606962569, 0.025196357055392582, 0.12771643116138875, 0.0629649666370824, 0.045876099829911254, 0.05246303524472751, 0.04655912060115952, 0.03979920169513207, 0.0643731547461357, 0.0685121123387944, 0.01761930758220842, 0.039126808478613384, 0.021385803520388436, 0.01970745510334382, 0.03496390920190606, 0.010141843195015099, 0.058391956554260105, 0.13424293720163405, 0.019196217399439774, 0.05997841966745909, 0.03146474227833096, 0.023409582718159072, 0.017659268523857463, 0.08726089261472225, 0.05419077358965296, 0.036862289562122896, 0.05118030348967295, 0.0710119551513344, 0.025083832624659408, 0.0462077582051279, 0.07778535888064653, 0.07136923988582566, 0.036814480408793315, 0.06253331870539114, 0.02482157990016276, 0.09867193264653906, 0.17793704493669793, 0.14958272891817614, 0.194299204449635, 0.12326842101174407, 0.10827194681041874, 0.20956582040525973, 0.2540062466869131, 0.17034162359777838, 0.22042090276954696, 0.1898470605374314, 0.15749296930152923, 0.10404361237306148, 0.17141316609922796, 0.08281329064629972, 0.0967775190656539, 0.09624435275327414, 0.20598446804797277, 0.13791471283184364, 0.12214843853143975, 0.16349087323760614, 0.0914043105149176, 0.2149238297715783, 0.13907626300351694, 0.2185645094141364, 0.11239297411520965, 0.16338691319106147, 0.13617312972201034, 0.1191628081141971, 0.1894286525202915, 0.220573250844609, 0.1634670206112787, 0.18781250721076503, 0.18052421626634896, 0.2075662073912099, 0.09527553091174923, 0.1083302499318961, 0.1881493383552879, 0.24031575943809003, 0.16094695427455008, 0.19916067249141634, 0.1224083905981388, 0.16513709037099034, 0.17150430183392018, 0.3151731676189229, 0.7734892854932696, 10.023513492196798, 45.6839644163847, 77.79790699481964, 95.18900379538536, 90.21526828408241, 84.0757705271244, 86.44874319434166, 75.06835386157036, 65.31244575977325, 35.18766984343529, 31.351920068264008, 43.38001124560833, 36.187251806259155, 82.11081996560097, 111.76642745733261, 86.06877878308296, 70.73353886604309, 44.98682342469692, 38.44868145883083, 27.786808870732784, 7.602162770926952, 2.8357619466260076, 1.6859688190743327, 1.4402829087339342, 0.4989526513963938, 0.3790469979867339, 0.21605038025882095, 0.3741105878725648, 0.21465766592882574, 0.37234276242088526, 0.20772887131897733, 0.2471578266704455, 0.501068722223863, 0.22248129767831415, 0.17049404588760808, 0.20958079694537446, 0.1907230174401775, 0.30175899679306895, 0.4997688950970769, 1.0634124814532697, 0.888660749187693, 1.3222069758921862, 0.5561875551939011, 0.3350708296056837, 0.10170962472329848, 0.18244781851535663, 0.2377125874045305, 0.15521757421083748, 0.29995703254826367, 0.1958172972081229, 0.1624164215172641, 0.1464244452654384, 0.25439017452299595, 0.3807218768633902, 0.4580304800765589, 0.8285377628635615, 1.8634855560958385, 4.072226760908961, 8.143686912953854, 18.401483483612537, 35.6997037678957, 55.70485129952431, 85.33275067806244, 104.84043270349503, 101.53492167592049, 82.0097453892231, 54.80614252388477, 36.69590771198273, 24.762933030724525, 43.93534004688263, 55.47876723110676, 76.70684114098549, 87.27295696735382, 88.18673953413963, 96.54834285378456, 92.16815069317818, 108.4141181409359, 98.72140824794769, 59.474689811468124, 16.19926605373621, 1.3278907584026456, 0.413084591855295, 0.12294894870137796, 0.17077659635106102, 0.20333010266767815, 0.17194663669215515, 0.21659069345332682, 0.277204328449443, 0.2245209866669029, 0.15373206173535436, 0.13015710253966972, 0.07049896783428267, 0.13559277023887262, 0.11341943856677972, 0.12025923482724465, 0.11651988665107638, 0.11896950090886094, 0.18463608546881005, 0.1660626969533041, 0.2173117344500497, 0.17902455845614895, 0.0940182214253582, 0.11165923497173935, 0.1242117426590994, 0.19629108428489417, 0.0914626507437788, 0.09012502603582107, 0.14460888487519696, 0.1364276121603325, 0.19442970369709656, 0.09428621095139533, 0.12086706119589508, 0.18734302459051833, 0.19460171868558973, 0.13246975344372913, 0.07923579003545456, 0.16306082834489644, 0.20393712009536102, 0.17538224608870223, 0.16794626775663346, 0.1818345076753758, 0.164081429829821, 0.20006113511044532, 0.08782499906374142, 0.14030520018422976, 0.25346780370455235, 0.08650687799672596, 0.11399769035051577, 0.23860971035901457, 0.09716412605484948, 0.206965483375825], [0.017861600244941656, 0.11132284911582246, 0.05912174005061388, 0.02493715270247776, 0.02869330310204532, 0.032752064216765575, 0.046361030254047364, 0.05178316117962822, 0.04120597972359974, 0.0037905278395555797, 0.01609014012501575, 0.05282977122988086, 0.06615974169108085, 0.01792886479961453, 0.0636912694608327, 0.04658699195715599, 0.1010231307009235, 0.039698703767498955, 0.05002414502087049, 0.04109198955120519, 0.05034145026002079, 0.031007362231321167, 0.04877949657384306, 0.038699910292052664, 0.07825001011951827, 0.03210195769497659, 0.03197601152351126, 0.055012728116707876, 0.06041143315087538, 0.01982173285796307, 0.11018099554348737, 0.03110598994680913, 0.07385769815300591, 0.0077415052237483906, 0.04185019730357453, 0.028662928853009362, 0.04756568065204192, 0.0931741546082776, 0.0848383667471353, 0.1466453677858226, 0.052957969819544815, 0.02125771439750679, 2.0063766511157155, 12.422098685055971, 27.73134134709835, 59.33520309627056, 70.07517859339714, 68.42566430568695, 68.05955395102501, 51.31097987294197, 48.71693506836891, 62.01237604022026, 71.42999589443207, 22.366851903498173, 26.922739036381245, 35.127933248877525, 45.55949069559574, 74.95842576026917, 83.93353655934334, 56.90658621490002, 35.607448518276215, 20.942198149859905, 6.08007132075727, 0.990037884330377, 0.11515647973283194, 0.04794236883753911, 0.00963606862569577, 0.14568461308954284, 0.052020251387148164, 0.24365202494664118, 0.1687690571998246, 0.23753304703859612, 0.09525361529085785, 0.11208296418772079, 0.05053570741438307, 0.24199474981287494, 0.1851223554695025, 0.08197470830054954, 0.031089529111341108, 0.07553254734375514, 0.0809250665770378, 0.09191039585857652, 0.13385047466726974, 0.33784666971769184, 0.5351381096988916, 0.5445923586376011, 0.8382049191277474, 0.6963121611624956, 0.5664341803640127, 0.2455683986772783, 0.30932068009860814, 0.0491381579922745, 0.045094889210304245, 0.0647237898374442, 0.014603665640606778, 0.11576412798603997, 0.08076076992438175, 0.1042139797937125, 0.03751290816580877, 0.1219990590470843, 0.1163999036361929, 0.15427166246809065, 0.051065240913885646, 0.2166989876423031, 0.570414288667962, 0.43624713958706707, 4.313090136274695, 19.333820454776287, 29.18471395969391, 58.383471965789795, 86.28947854042053, 67.38119915127754, 64.87462565302849, 43.554794266819954, 22.239976711571217, 15.42714273557067, 18.507562391459942, 30.34769095480442, 61.68781265616417, 63.83584499359131, 64.1616091132164, 67.92316406965256, 75.81730887293816, 78.61876174807549, 71.00004896521568, 41.16663761436939, 4.977727197110653, 0.06752600587788038, 0.08811244770186022, 0.021545283634623047, 0.13765818206593394, 0.011191089724889025, 0.023708714616077486, 0.09178813445032574, 0.0075679785732063465, 0.06091878756706137, 0.03209417998732533, 0.041734949190868065, 0.03530398724251427, 0.031736516757518984, 0.04880274063907564, 0.06754065587301739, 0.09338898409623653, 0.08119737540255301, 0.09035661321831867, 0.024173883502953686, 0.03825379419140518, 0.05999464301567059, 0.06356690777465701, 0.04633852091501467, 0.05492362586664967, 0.017357592914777342, 0.03845631144940853, 0.01944724328495795, 0.011677112961478997, 0.01653040624660207, 0.051071745838271454, 0.03615903413447086, 0.029514443122025114, 0.0425392591569107, 0.04276234503777232, 0.08818037647870369, 0.14986090071033686, 0.020934303138346877, 0.045035650982754305, 0.06762506032828242, 0.02360400128964102, 0.0652344393893145, 0.05989014862279873, 0.08519939932739362, 0.037078495734022, 0.06340034015011042, 0.021180820476729423, 0.06761469252523966, 0.03806091372098308, 0.026247078603773843, 0.07094052343745716, 0.08394029384362511, 0.048351900768466294, 0.017651513080636505, 0.0574414583388716, 0.022126884359749965, 0.05758960214734543, 0.0646580355532933, 0.03120795176073443, 0.01781777828000486, 0.0272080782087869, 0.04060791259689722, 0.061194565932964906, 0.03245321619033348, 0.01315759182034526, 0.05210044786508661, 0.06776358961360529, 0.09349237268907018, 0.10976881414535455, 0.07121978618670255, 0.012232297867740272, 0.033942832742468454, 0.053027561007183976, 0.03648331556178164, 0.0335530790471239, 0.009697246641735546, 0.04869905147643294, 0.06328695482807234, 0.012663524630625034, 0.026676104898797348, 0.04173444081970956, 0.03910978732164949, 0.06883335096063092, 0.019340780345373787, 0.06957498655538075, 0.03916078028851189, 0.0575003737321822, 0.0300374011931126, 0.06877757856273092, 0.13952854264061898, 0.029018005698162597, 0.14491913228994235, 1.9902580347843468, 12.924497276544571, 30.617940053343773, 67.07728385925293, 79.35361191630363, 79.92939502000809, 76.70060187578201, 66.65018677711487, 55.74849955737591, 72.15336307883263, 75.0421504676342, 35.582734644412994, 28.998799435794353, 32.69883379340172, 40.62950983643532, 48.334151208400726, 71.69128507375717, 57.39271692931652, 39.548365250229836, 25.152621120214462, 8.485119491815567, 1.805249999742955, 0.288930261740461, 0.08211645850678906, 0.025654004275565967, 0.07994427389348857, 0.04252192629792262, 0.5626315344125032, 0.6421828782185912, 0.45237481012009084, 0.5092891654931009, 0.6903965317178518, 0.7781930768396705, 0.8200104266870767, 0.5830274149775505, 0.34335658187046647, 0.3666578815318644, 0.5890831619035453, 0.3656709141796455, 0.8701983117498457, 0.6509750126861036, 1.4448313834145665, 1.5356055437587202, 1.772897110786289, 2.8145189490169287, 2.296454035677016, 1.4709824114106596, 1.9462349032983184, 1.2941307574510574, 0.20676332234870642, 0.0612939617712982, 0.06469267900683917, 0.04979530378477648, 0.16949613927863538, 0.09893140231724828, 0.15851959702558815, 0.03620777097239625, 0.20432661403901875, 0.14033999206731096, 0.15593693795381114, 0.12257917362148874, 0.2519184962147847, 0.9151830885093659, 0.5784929520450532, 4.370917333289981, 17.097129374742508, 27.251252308487892, 55.928841680288315, 66.90893769264221, 56.861600428819656, 48.982829600572586, 33.41634549200535, 32.79111944139004, 25.117792189121246, 34.06508468091488, 44.80697527527809, 76.05357259511948, 75.91576918959618, 72.5598956644535, 77.63723641633987, 85.92087551951408, 90.73471561074257, 82.23790794610977, 48.05583514273167, 7.409397689625621, 0.029973233249620534, 0.08745944680413231, 0.024755222621024586, 0.026947723526973277, 0.011747216231015045, 0.01314248447670252, 0.05903274912270717, 0.0403614342212677, 0.04138160897127818, 0.04379124744446017, 0.03891820932039991, 0.03521633960190229, 0.030985485573182814, 0.020564585574902594, 0.06400452257366851, 0.06741143311955966, 0.07339379648328759, 0.08275308762677014, 0.03160444786772132, 0.011595447958825389, 0.03844597333227284, 0.10263923148158938, 0.029268384059832897, 0.04702136357082054, 0.021623370557790622, 0.009198280349664856, 0.03369760488567408, 0.01717423234367743, 0.03013722933246754, 0.02668411823833594, 0.08977081379271112, 0.016234382092079613, 0.022066304700274486, 0.019561964472813997, 0.006290888995863497, 0.09814849589020014, 0.030593024894187693, 0.08583568705944344, 0.09676921443315223, 0.08314011021866463, 0.00575505466258619, 0.03838446413283236, 0.06379691418260336, 0.07683633011765778, 0.011106462625321, 0.05301840661559254, 0.11267812951700762, 0.03865869883156847, 0.05047715567343403, 0.2544977265642956, 0.32395992893725634, 0.19130582601064816, 0.13367164676310495, 0.13875241944333538, 0.13158077927073464, 0.3440945141483098, 0.2104121507727541, 0.10321317138732411, 0.08617890809546225, 0.15863722743233666, 0.2268521615769714, 0.1845575068728067, 0.09925842226948589, 0.12642432237043977, 0.13436733599519357, 0.23733064852422103, 0.17480399430496618, 0.3723039629403502, 0.11784818256273866, 0.07762823137454689, 0.13282996224006638, 0.10274184081936255, 0.11588707959163003, 0.11876116521307267, 0.1143562218931038, 0.17928851069882512, 0.14445903041632846, 0.19357086071977392, 0.15277233120286837, 0.2607753162737936, 0.20082416682271287, 0.15575674449792132, 0.14185419597197324, 0.21249939658446237, 0.17891035677166656, 0.18172857351601124, 0.16104272101074457, 0.3240612766239792, 0.24257323908386752, 0.08663368877023458, 0.2599699079291895, 3.0042893160134554, 20.95883935689926, 48.748750761151314, 86.47382944822311, 90.3547739982605, 85.99340602755547, 85.09110644459724, 69.93250384926796, 62.15323828160763, 78.89908790588379, 81.33260652422905, 33.51462721824646, 39.01863947510719, 50.48665590584278, 64.9414412677288, 98.85626301169395, 111.06285721063614, 76.4679479598999, 52.48721435666084, 31.632918789982796, 11.339838858693838, 1.9170504505746067, 0.4967224976280704, 0.37543300597462803, 0.196507568762172, 0.3748984221601859, 0.12813854991691187, 0.8498656621668488, 0.5828168231528252, 0.8440136793069541, 0.39600373653229326, 0.5029060423839837, 0.36695251415949315, 0.6430409196764231, 0.39832143404055387, 0.19609304959885776, 0.24504215660272166, 0.37928371340967715, 0.22064307209802791, 0.5793418502435088, 0.5374374613165855, 2.3532714368775487, 2.1613978827372193, 1.8063536030240357, 2.7834648778662086, 2.202449692413211, 1.8979749991558492, 1.3102616043761373, 0.6647482048720121, 0.19960961246397346, 0.22547056461917236, 0.09369440755108371, 0.21503822441445664, 0.33143846201710403, 0.23226615856401622, 0.17325744760455564, 0.29190283035859466, 0.36823286733124405, 0.3709267743397504, 0.5394417350180447, 0.40383182116784155, 0.549273588694632, 1.220307368785143, 1.1047005909495056, 7.058847025036812, 28.095061630010605, 43.51840361952782, 81.68433845043182, 109.11654084920883, 91.52317330241203, 86.38175278902054, 60.024976283311844, 36.7388454079628, 28.56910329312086, 34.875376001000404, 47.32049100100994, 79.85004007816315, 81.99108079075813, 83.15751180052757, 86.13053306937218, 94.74344730377197, 102.06982657313347, 97.47282564640045, 62.47313551604748, 11.48794636130333, 0.1222221709031146, 0.24166502844309434, 0.204061504045967, 0.26410316582769156, 0.21272788901114836, 0.1532592246076092, 0.20275278599001467, 0.10713057563407347, 0.10599706380162388, 0.23098666628357023, 0.1564749059616588, 0.14767520158784464, 0.12306516160606407, 0.08276902153738774, 0.16429675655672327, 0.25611287739593536, 0.2286934744915925, 0.2889233152382076, 0.10590755337034352, 0.19824271003017202, 0.1450722076697275, 0.18147429887903854, 0.15548260998912156, 0.21103947336087003, 0.12870488280896097, 0.1651593844871968, 0.081932776956819, 0.14295658213086426, 0.1089442138618324, 0.11883040759130381, 0.10095091973198578, 0.128480457351543, 0.16349614248611033, 0.15532171237282455, 0.1559508458012715, 0.2660520456265658, 0.17817948973970488, 0.1515811396529898, 0.16639112698612735, 0.1532225773553364, 0.13200696499552578, 0.19481999916024506, 0.1912907455698587, 0.10338727923226543, 0.12112944750697352, 0.1637549145380035, 0.23657729441765696, 0.24673609383171424, 0.09664686396718025], [0.01490383376221871, 0.08283931776531972, 0.05299817195918877, 0.047495547696598805, 0.010641731605574023, 0.08556256929296069, 0.050026775934384204, 0.017328320755041204, 0.044847598182968795, 0.034841888991650194, 0.034563234803499654, 0.04956800250511151, 0.05283282145683188, 0.06724718841724098, 0.03915190420229919, 0.06136187199444976, 0.038593634744756855, 0.034587276677484624, 0.025635261335992254, 0.023143728722061496, 0.03856746290693991, 0.03173506585881114, 0.037394327810034156, 0.05360301860491745, 0.045513649747590534, 0.02239123550680233, 0.006130194078650675, 0.033343637551297434, 0.056094671817845665, 0.03687044947582763, 0.032410305211669765, 0.0714944105129689, 0.011709763748513069, 0.05044240831921343, 0.07437844091327861, 0.037362641814979725, 0.12432912073563784, 0.04360025945061352, 0.02116789411957143, 0.06608549723750912, 0.05876893788808957, 1.2796813203021884, 11.883375942707062, 42.765124440193176, 78.75515922904015, 72.0588393509388, 73.20379391312599, 72.1311266720295, 52.604764848947525, 52.538040429353714, 97.5360618531704, 54.78503465652466, 27.23356045782566, 26.293817684054375, 49.175452664494514, 84.59951162338257, 65.80121353268623, 64.53868567943573, 34.59337793290615, 22.60283064097166, 6.459291921928525, 1.3810220011509955, 0.03395264764549211, 0.14824477024376392, 0.14087990450207144, 0.06539627211168408, 0.04613353230524808, 0.03864136597258039, 0.05297703930409625, 0.09237691730959341, 0.0778456509578973, 0.24940537638030946, 0.41042966244276613, 0.36487764737103134, 0.30274284712504596, 0.3986254474148154, 0.2988521527731791, 0.3821221017278731, 0.7384383631870151, 0.42014455364551395, 0.08502705037244596, 0.7240478228777647, 1.3844282808713615, 0.49352351459674537, 0.5997087573632598, 2.020228332839906, 2.381415101699531, 2.3129432508721948, 1.2257404834963381, 0.49026685184799135, 0.18047841091174632, 0.0657314779527951, 0.1337567117298022, 0.09465257957344875, 0.14341997914016247, 0.12259377166628838, 0.01908060748974094, 0.18282631383044645, 0.009199974301736802, 0.08525084500433877, 0.0682268975651823, 0.14513775415252894, 0.032232464363914914, 0.28967211255803704, 0.06694792478810996, 0.030666404745716136, 0.07806649926351383, 0.03894001361913979, 2.1740956138819456, 6.220970610156655, 24.447796940803528, 49.39249701797962, 66.38376027345657, 79.65948030352592, 63.389289155602455, 34.153927713632584, 26.121352538466454, 16.862244978547096, 16.234951838850975, 29.898904636502266, 55.39803296327591, 64.3260794878006, 67.59546965360641, 73.24171587824821, 70.17974138259888, 73.08099210262299, 67.82119274139404, 21.623581387102604, 1.0905816173180938, 0.16906431323150173, 0.029636051440320443, 0.062358468712773174, 0.202033867535647, 0.05969150908640586, 0.03088236044277437, 0.025891046243486926, 0.03694863844430074, 0.017087410342355724, 0.06076697012758814, 0.016130518524732906, 0.043789187984657474, 0.04339976454502903, 0.034767343968269415, 0.04441464407136664, 0.08027891570236534, 0.06628016999457031, 0.011214688165637199, 0.11233208089834079, 0.013431359893729677, 0.0515044587518787, 0.08876997570041567, 0.025718893957673572, 0.06556437598192133, 0.0074878962004731875, 0.05053463130025193, 0.012908771968795918, 0.02326994206669042, 0.045841051905881613, 0.030352366811712272, 0.04083396706846543, 0.05527557455934584, 0.02735876572842244, 0.05617988892481662, 0.019176914138370194, 0.014215784940461162, 0.040506527802790515, 0.06056045269360766, 0.041806455119512975, 0.04508389058173634, 0.0628185854293406, 0.04685734893428162, 0.051384494290687144, 0.036850296455668285, 0.06662305706413463, 0.03847241976473015, 0.01970744397112867, 0.04196289613901172, 0.05394245468778536, 0.020059403796039987, 0.022332954649755266, 0.013568467038567178, 0.10644482375937514, 0.03804504289291799, 0.020008733663416933, 0.03014699228515383, 0.04022944325697608, 0.05913670174777508, 0.04183677185210399, 0.07659870927454904, 0.05408902885392308, 0.030696400499437004, 0.05893974317586981, 0.025582576272427104, 0.014099097061262, 0.03694925813761074, 0.07881291428930126, 0.006218151102075353, 0.014292871819634456, 0.008284064806503011, 0.002775744792415935, 0.05596199436695315, 0.06202410892001353, 0.043901938770432025, 0.013216608331276802, 0.008847349326970289, 0.04064133521751501, 0.019865504727931693, 0.09482054243562743, 0.062149427976692095, 0.10379435465438291, 0.08516135683748871, 0.05891211301786825, 0.1487414599978365, 0.07224510030937381, 0.05960908245469909, 0.10221684555290267, 0.03655680673546158, 1.27834711689502, 15.511519107967615, 56.11871749162674, 86.67178362607956, 80.9007216989994, 81.30239814519882, 79.10520404577255, 66.8162302672863, 56.386815905570984, 86.25034064054489, 69.69682529568672, 42.7208112180233, 30.946052446961403, 41.77340045571327, 60.34404516220093, 51.37434147298336, 56.55089870095253, 40.051367059350014, 25.917339585721493, 9.083604477345943, 1.7359820916317403, 0.22464068024419248, 0.08789664600044489, 0.20780848892172799, 0.0431243609637022, 0.06705515770590864, 0.0787794211646542, 0.2848857350181788, 0.08818307047476992, 0.4508287680801004, 1.4554300834424794, 1.2415895517915487, 1.2899140524677932, 1.9509563874453306, 2.452447065152228, 2.0279663801193237, 1.5115369227714837, 2.6696168119087815, 1.841734335757792, 1.127120575401932, 2.16878492385149, 2.5514512276276946, 2.459598993882537, 3.558330461382866, 5.236910339444876, 5.302474871277809, 4.964686296880245, 3.6343783931806684, 2.3807271011173725, 2.0152807608246803, 0.8005656232126057, 0.483510012854822, 0.6242863729130477, 0.4166583891492337, 0.40525923832319677, 0.6053484266158193, 0.6120821402873844, 0.011323106664349325, 0.34672471520025283, 0.1753126029507257, 0.07228711328934878, 0.05186585498449858, 0.3593476378591731, 0.24842746322974563, 0.0864410717622377, 0.15949546184856445, 0.09766065253643319, 2.119046780280769, 7.174033094197512, 25.082452185451984, 46.34038299322128, 57.80813343822956, 61.971596628427505, 51.891524121165276, 27.733530029654503, 31.362926177680492, 31.207793802022934, 36.28553733229637, 45.13315737247467, 70.00332444906235, 73.07831704616547, 78.63504007458687, 83.7578035891056, 79.118282943964, 85.7440634071827, 81.59577280282974, 31.354154348373413, 0.5716084933374077, 0.09825824468862265, 0.05294745358696673, 0.05821525861392729, 0.11585307438508607, 0.06467163169872947, 0.053984441692591645, 0.019021588195755612, 0.05229748065175954, 0.05269442204735242, 0.06858948865556158, 0.03585949591069948, 0.01433952507795766, 0.03884237667080015, 0.030400830910366494, 0.010962611213471973, 0.07962059360579588, 0.037210520094959065, 0.04711541965662036, 0.0360986715531908, 0.012150000184192322, 0.07982020164490677, 0.06568070020875894, 0.039093575105653144, 0.05271014815662056, 0.03592635599488858, 0.05953093059360981, 0.0637757703952957, 0.06848708711913787, 0.10979549435433, 0.013822761156916386, 0.01145694835940958, 0.006768740722691291, 0.03693402555654757, 0.023136140262067784, 0.020068660232936963, 0.050839249524869956, 0.06567651449586265, 0.033656204177532345, 0.06069812850910239, 0.011710866765497485, 0.03864340687869117, 0.028984032032894902, 0.04079136037034914, 0.026554875075817108, 0.05357485410058871, 0.043179172280360945, 0.020711152319563553, 0.14877579174935818, 0.17142707394668832, 0.1722635337500833, 0.1362044780398719, 0.15294596407329664, 0.215470599650871, 0.07647527527296916, 0.09186961484374478, 0.14485751918982714, 0.14645264687715098, 0.19172965170582756, 0.14396513113752007, 0.21689596847863868, 0.1798711411538534, 0.15871352021349594, 0.1693235751008615, 0.13026319997152314, 0.18113156023900956, 0.14881423499900848, 0.10730650916229934, 0.15455183805897832, 0.15409537270898, 0.11761344867409207, 0.13629837456392124, 0.13478825247148052, 0.15484718314837664, 0.25600200053304434, 0.12629276927327737, 0.1610201597213745, 0.09753177117090672, 0.1247039795271121, 0.17310646508121863, 0.12278583948500454, 0.22053347172914073, 0.15515081060584635, 0.17615198681596667, 0.24112710496410728, 0.19396166084334254, 0.19120924291200936, 0.15138988819671795, 0.1737135270377621, 1.6328255832195282, 26.898388043045998, 71.52271091938019, 100.06027400493622, 89.8060454428196, 92.20490992069244, 91.60280182957649, 72.32297077775002, 68.76246303319931, 108.13376918435097, 68.65023985505104, 39.596565663814545, 40.567181780934334, 67.70884796977043, 105.04727080464363, 87.9743841290474, 87.14098244905472, 53.92255313694477, 34.502938985824585, 12.009559571743011, 2.6823045685887337, 0.34944483486469835, 0.276419700239785, 0.39820263104047626, 0.1387323220842518, 0.10790804954012856, 0.19241189322201535, 0.47868893248960376, 0.15440024697454646, 0.3369293751893565, 0.7293208711780608, 1.0448257788084447, 0.8783124200999737, 0.9530243079643697, 1.5736772445961833, 2.040887111797929, 1.5040414687246084, 1.7650479194708169, 0.9513098874595016, 1.0659904056228697, 1.127384186256677, 2.9815076384693384, 2.4600810930132866, 3.9521021442487836, 7.0100547932088375, 6.427283389493823, 5.421633152291179, 4.8810081370174885, 1.2179505452513695, 0.5202742572873831, 0.28464513074140996, 0.24807062378386036, 0.668756514787674, 0.44883491413202137, 0.45424145995639265, 0.49617200216744095, 0.44123211584519595, 0.13941793295089155, 0.3936289233388379, 0.47279274731408805, 0.4601074248785153, 0.4164504987420514, 0.5548832751810551, 0.4386465920833871, 0.3754458006005734, 0.3319476346950978, 0.1419942095526494, 2.974182819016278, 10.060817990452051, 37.060110569000244, 67.21402332186699, 89.25541698932648, 107.60691985487938, 82.6987624168396, 51.22296139597893, 39.52368937432766, 29.855807349085808, 28.622699417173862, 43.22936452925205, 73.63080739974976, 83.20259258151054, 89.7919026017189, 93.46990764141083, 89.94200214743614, 97.46321216225624, 98.29707741737366, 45.63617818057537, 2.362184808589518, 0.388946327730082, 0.1067474196315743, 0.12781286583049223, 0.28520108840893954, 0.18408199801342562, 0.15367396641522646, 0.13784459471935406, 0.15697667200583965, 0.13794512604363263, 0.21332404139684513, 0.15382340527139604, 0.1394642874947749, 0.22852260241052136, 0.2191786514595151, 0.1879526989068836, 0.13995655404869467, 0.13417857815511525, 0.1744546357076615, 0.26742326735984534, 0.10594117266009562, 0.1479590285453014, 0.16037953784689307, 0.13779542001429945, 0.17328033543890342, 0.11327662708936259, 0.11268823014688678, 0.1831602060701698, 0.1886485068826005, 0.12423952866811305, 0.08798859809758142, 0.16649326134938747, 0.08849316945997998, 0.17003051529172808, 0.20323506323620677, 0.1681754132732749, 0.10814335488248616, 0.14402653643628582, 0.11901869787834585, 0.28544599714223295, 0.1511333425878547, 0.18235147290397435, 0.10296762440702878, 0.16145658708410338, 0.1276513744960539, 0.1633208620478399, 0.1976902998285368, 0.07805930785252713], [0.04215992892568465, 0.05900624702917412, 0.08207170700188726, 0.034431344029144384, 0.004391124994072015, 0.0526975687535014, 0.041418449181946926, 0.08940351006458513, 0.02089454443193972, 0.026989604775735643, 0.04259265668224543, 0.008990692367660813, 0.035132881384924985, 0.03351471743371803, 0.017979996919166297, 0.01975294875592226, 0.0545861750288168, 0.0895463141205255, 0.02508601453882875, 0.044784571291529574, 0.0323208838381106, 0.04292998506571166, 0.017867346323328093, 0.023034822261251975, 0.08251735926023684, 0.07488264120183885, 0.02271771925734356, 0.01206364851896069, 0.05800647762953304, 0.028711567356367595, 0.009780333784874529, 0.06556822030688636, 0.04831950231164228, 0.07063752680551261, 0.019739419403776992, 0.06471170767326839, 0.07286178049980663, 0.06895158992847428, 0.035176386081730016, 0.23186047095805407, 0.11040607409086078, 31.590159684419632, 42.27544091641903, 34.4179717451334, 72.97854959964752, 80.63516154885292, 66.394072920084, 42.734946459531784, 18.477996177971363, 78.43062624335289, 126.85843482613564, 42.67112508416176, 33.497360944747925, 41.361441761255264, 71.01655527949333, 65.21868959069252, 44.66745436191559, 24.254079535603523, 8.383616488426924, 0.7242036145180464, 0.1251198790851049, 0.08565308904508129, 0.07629234329215251, 0.06529345497256145, 0.03883071753080003, 0.021957745193503797, 0.1538259137305431, 0.09075666050193831, 0.21602691354928538, 0.8545728970784694, 2.069528312422335, 0.9763868199661374, 1.9931562105193734, 2.9130108514800668, 5.880894083529711, 3.2879749685525894, 2.889323397539556, 1.268326104618609, 0.7749736995901912, 3.7584593100473285, 1.720516683999449, 3.6115287942811847, 1.4275053818710148, 1.8663319596089423, 1.6862178244628012, 2.9198768455535173, 5.127551732584834, 4.061403516680002, 1.234593652188778, 4.278021343052387, 5.374942682683468, 1.5899290912784636, 1.634099583607167, 0.18244407809106633, 0.3400268917903304, 0.4870312660932541, 0.3184492152649909, 0.4398018488427624, 0.20300039614085108, 0.30274085816927254, 0.07685659074923024, 0.030862066414556466, 0.031050057987158652, 0.43473134748637676, 0.39835109026171267, 0.1196413449360989, 0.08684311542310752, 0.11777024221373722, 0.13127774553140625, 0.4892573825782165, 2.279383451677859, 10.92796565964818, 31.715009585022926, 50.5665922164917, 64.68063086271286, 56.672431379556656, 38.44974920153618, 31.171545647084713, 27.051162645220757, 13.578399438410997, 19.764386750757694, 45.54936423897743, 62.75118939578533, 62.735028862953186, 72.68241629004478, 68.03563803434372, 63.326793909072876, 69.01504307985306, 29.690894298255444, 3.3632862148806453, 0.14496139017865062, 0.10568002573563717, 0.08261052847956307, 0.11235893922275864, 0.04653216208680533, 0.0419665512163192, 0.01694289006991312, 0.043815526805701666, 0.02124728536728071, 0.06894273610669188, 0.05095431952213403, 0.08927655086154118, 0.0165661870414624, 0.03921871604688931, 0.03978160908445716, 0.023471991771657486, 0.015304458993341541, 0.04966649292327929, 0.037779899503220804, 0.04870179371209815, 0.04545420000795275, 0.03351075436512474, 0.019723966033780016, 0.027917055595025886, 0.02801517679472454, 0.0067821248921973165, 0.07788638002239168, 0.03764196764677763, 0.07414398904074915, 0.030476184874714818, 0.04971219808794558, 0.03493723641440738, 0.02285695358295925, 0.03723356006958056, 0.02557904921559384, 0.02710751534323208, 0.0441744108684361, 0.06488007871666923, 0.11492806894239038, 0.034025311324512586, 0.04402788865263574, 0.009246723111573374, 0.012297534503886709, 0.09203474270179868, 0.018399206455796957, 0.021418163014459424, 0.07204886162071489, 0.04780360577569809, 0.07657439651666209, 0.03996688996267039, 0.026606235405779444, 0.051415972484392114, 0.028574950956681278, 0.02781259830953786, 0.029579740985354874, 0.06192043088958599, 0.018599413779156748, 0.038754606575821526, 0.05907609796850011, 0.02772621788608376, 0.010139522128156386, 0.020183947308396455, 0.016182188701350242, 0.03405483024835121, 0.046383502485696226, 0.03227826971851755, 0.00786362052167533, 0.02375847561779665, 0.052763675557798706, 0.01512721557446639, 0.02866449849534547, 0.07071682528476231, 0.041730140073923394, 0.02547217623941833, 0.044336629507597536, 0.07834228876163252, 0.026972121631843038, 0.021010235977882985, 0.09137535191257484, 0.018819655379047617, 0.04380993472295813, 0.017785196141630877, 0.05610346997855231, 0.03111352645646548, 0.053484189629671164, 0.19191371917258948, 0.5692586163058877, 34.59276236593723, 48.553357645869255, 40.59603363275528, 81.56086787581444, 88.16638022661209, 76.55384615063667, 57.212428003549576, 32.72032544016838, 73.85707005858421, 130.248863697052, 49.36060532927513, 24.81385599821806, 35.56645251810551, 52.77387857437134, 60.57341605424881, 45.24544894695282, 30.118738040328026, 10.860942956060171, 1.3997350470162928, 0.018864247322198935, 0.016600973358436022, 0.016284061457554344, 0.042173243055003695, 0.03380477843165863, 0.09286858272389509, 0.25074714969377965, 0.10375165889854543, 0.06695311240036972, 0.335482899681665, 0.4413099819794297, 2.3028875654563308, 2.31671882327646, 4.0817552246153355, 7.6683609187603, 8.33917312324047, 7.010538317263126, 6.826493293046951, 7.2920823097229, 8.11622578650713, 6.601981865242124, 6.585034299641848, 5.403412180021405, 4.862906858325005, 5.450468380004168, 7.168649258092046, 6.490748533979058, 8.55087211355567, 3.9894838258624077, 9.072689563035965, 6.218943893909454, 4.036422707140446, 5.596305029466748, 2.280394434928894, 1.7570586106739938, 2.1905171452090144, 1.9719464611262083, 2.488742242567241, 1.8888396956026554, 1.0893532144837081, 0.3240359842311591, 0.07183461100794375, 0.04159561467531603, 0.5010754312388599, 0.36346501379739493, 0.179562927223742, 0.11680383235216141, 0.04540749665466137, 0.06644385066465475, 0.3749344905372709, 2.6924079889431596, 11.46804017946124, 29.675415828824043, 47.726939991116524, 54.382735043764114, 43.096022084355354, 32.65804298222065, 22.787320241332054, 20.85684522986412, 22.749221585690975, 34.20954912900925, 63.37474353611469, 72.9984225332737, 71.06922045350075, 81.74672350287437, 80.64984396100044, 74.51650187373161, 85.47199800610542, 46.56185410916805, 6.930453339591622, 0.19436331116594374, 0.043866671912837774, 0.10921138702542521, 0.15222578396787867, 0.058747820075950585, 0.06114221483585425, 0.04521090173511766, 0.04747927981952671, 0.10195524591836147, 0.031137996920733713, 0.05692234459274914, 0.02802113252982963, 0.03255106836149935, 0.06874784070532769, 0.06343657179968432, 0.07751514291157946, 0.013853768086846685, 0.03129449731204659, 0.04276978877896909, 0.028022551887261216, 0.03439430714934133, 0.04322751578001771, 0.018305655030417256, 0.030399352181120776, 0.04439223492227029, 0.06100017890275922, 0.04988339300325606, 0.03217507037334144, 0.07056156799080782, 0.02163487755751703, 0.04323275534261484, 0.023969577669049613, 0.044705150357913226, 0.03784087806707248, 0.027133201074320823, 0.08871659301803447, 0.010227231923636282, 0.026587889515212737, 0.08165922874468379, 0.06544129078974947, 0.05170224110770505, 0.0567324623989407, 0.08615061742602848, 0.05022573830501642, 0.037522281490964815, 0.07096289918990806, 0.15736986184492707, 0.12916587525978684, 0.16519094060640782, 0.1646771517698653, 0.1103607214463409, 0.1513569219969213, 0.246767085918691, 0.08985811262391508, 0.12153110525105149, 0.13350019580684602, 0.12247626000316814, 0.11358797288266942, 0.13137328962329775, 0.07508282811613753, 0.08851957507431507, 0.12748143752105534, 0.20071792096132413, 0.2347424827166833, 0.12651768454816192, 0.15949041524436325, 0.10210200562141836, 0.0973231608804781, 0.10775188682600856, 0.11782501271227375, 0.13333353912457824, 0.16892124200239778, 0.20701084344182163, 0.07205964502645656, 0.16886409663129598, 0.15806417068233714, 0.0962469280057121, 0.0894826601142995, 0.1824254056555219, 0.19958506221883, 0.17315788107225671, 0.26612447923980653, 0.15755364729557186, 0.13452498300466686, 0.19001177279278636, 0.43928537343163043, 1.296717468649149, 49.587532952427864, 62.39114351570606, 51.40053726732731, 89.96259704232216, 100.29840722680092, 84.98140633106232, 59.59576651453972, 33.70043724775314, 91.1954864859581, 127.280812561512, 56.26038148999214, 53.1900854408741, 59.61869828402996, 90.69794118404388, 87.04548597335815, 62.13721074163914, 37.73234389722347, 13.541629761457443, 1.6265502199530602, 0.396538142231293, 0.22351870138663799, 0.30080999771598727, 0.29294504318386316, 0.2034844396985136, 0.22598052397370338, 0.7088947703596205, 1.3422440132126212, 1.0584649094380438, 3.5583154996857047, 6.260624807327986, 5.148820616304874, 9.352998621761799, 9.13051201030612, 14.388057142496109, 11.721747815608978, 7.097212616354227, 4.906481020152569, 6.1402700655162334, 11.025652717798948, 7.39726304076612, 8.405546061694622, 6.1473999079316854, 7.9438922088593245, 6.328652556985617, 10.409092102199793, 10.875761210918427, 13.213958144187927, 3.6823795549571514, 11.793871745467186, 17.826196253299713, 4.273844417184591, 4.653826877474785, 2.073983810842037, 2.5056304363533854, 2.7497063018381596, 1.9409791915677488, 2.269249870441854, 1.7526477598585188, 1.020349629689008, 0.2773998992051929, 0.3041547682369128, 0.3457897872431204, 1.5432147542014718, 0.9428979700896889, 0.31027347897179425, 0.30599476012866944, 0.6429080455563962, 0.2987689431756735, 0.9252952958922833, 3.723325920291245, 15.469638705253601, 44.20531556010246, 71.10007479786873, 88.7178598344326, 79.19047147035599, 61.241967380046844, 45.93949690461159, 39.29247938096523, 25.850761458277702, 34.940436109900475, 63.58375892043114, 81.36050462722778, 80.26877000927925, 94.5635649561882, 88.97510603070259, 85.30815839767456, 98.9520026743412, 70.29557436704636, 10.956400483846664, 0.25664410670287907, 0.19862987363012508, 0.28112307598348707, 0.42275370738934726, 0.1960019435500726, 0.16191496717510745, 0.19977128191385418, 0.1729628149769269, 0.24569717614213005, 0.11641246819635853, 0.1668468353454955, 0.20594777626683936, 0.09028368978761137, 0.20143771514995024, 0.17135317088104784, 0.18314678804017603, 0.07915862152003683, 0.13781283079879358, 0.1644245840725489, 0.16311984392814338, 0.10072798599139787, 0.17250534030608833, 0.15722932876087725, 0.10780480195535347, 0.13170312973670661, 0.1280485570896417, 0.19200645794626325, 0.11695462933857925, 0.15712358755990863, 0.09221325890393928, 0.10971095631248318, 0.14523595513310283, 0.10622868067002855, 0.1269863359630108, 0.16691399971023202, 0.25758414063602686, 0.06771399930585176, 0.168099521251861, 0.24788777343928814, 0.1936919940635562, 0.1711209974018857, 0.1345239143120125, 0.17902041727211326, 0.164794871234335, 0.11509769421536475, 0.13581833860371262], [0.026342923265474383, 0.09195208229357377, 0.05507125759322662, 0.08759251388255507, 0.047032603397383355, 0.017364535706292372, 0.021366717337514274, 0.039467491369578056, 0.02174015491618775, 0.04091630835318938, 0.021290866134222597, 0.012468470595194958, 0.018836019735317677, 0.08125161155476235, 0.03336297049827408, 0.021712790075980593, 0.06847645214293152, 0.013359684198803734, 0.048593603423796594, 0.028156784137536306, 0.01917700319609139, 0.07256768963998184, 0.01881149732071208, 0.00911149360035779, 0.08212834029109217, 0.01380231684379396, 0.05979140958515927, 0.036296316611696966, 0.04306789465772454, 0.05742486762756016, 0.057677761869854294, 0.048346371768275276, 0.02529392164433375, 0.07511146017350256, 0.026164820810663514, 0.05317732640833128, 0.1461710166768171, 0.0602366536622867, 0.05610103573417291, 5.880106575787067, 40.54387003183365, 77.66742959618568, 81.27950057387352, 64.8600572347641, 56.105156019330025, 49.86677996814251, 29.62543711066246, 22.436228580772877, 28.445528224110603, 25.601473934948444, 29.38907839357853, 47.027230337262154, 55.15776425600052, 64.34759393334389, 51.08740746974945, 35.24065800011158, 11.000434421002865, 2.1235151030123234, 0.10372260381700471, 0.033871901978272945, 0.27610057673882693, 0.5678108346182853, 0.13163189840270206, 0.10935937127214856, 0.5612725729588419, 0.30730188998859376, 1.0787590267136693, 0.30695685069076717, 0.6762918073218316, 0.7556006766390055, 1.2202823138795793, 3.8092592591419816, 1.573101575486362, 2.4271729588508606, 4.061727449297905, 4.952014926820993, 2.5078010698780417, 4.881389066576958, 8.635559119284153, 6.669759778305888, 4.064641417935491, 6.862838342785835, 5.028285384178162, 3.1107610277831554, 6.048837946727872, 6.032362030819058, 3.4500647708773613, 6.301869219169021, 3.4521311474964023, 4.451385140419006, 12.06069152802229, 5.5514907091856, 12.318035569041967, 1.463872636668384, 1.9813838484697044, 1.3234881008975208, 1.8201285763643682, 2.5089870812371373, 1.0704565909691155, 0.9604425192810595, 0.1968878897605464, 0.08046342103625648, 0.08747610059799626, 0.0695294038450811, 0.10191252789809369, 0.010905864746746374, 0.07323280238779262, 0.03489164628263097, 0.06565703311935067, 0.09823831060202792, 0.08416104567004368, 0.29654232203029096, 3.3137957705184817, 14.43577403202653, 43.459069803357124, 45.860833525657654, 57.761308550834656, 65.79898685216904, 55.452411845326424, 51.94171942770481, 28.952878899872303, 17.55328729748726, 24.015389643609524, 45.69267734885216, 63.566496446728706, 63.67229416966438, 76.50837019085884, 67.83291891217232, 73.04544121026993, 59.86069969832897, 19.949317127466202, 0.3385284956311807, 0.184330721385777, 0.06705420775688253, 0.0346526598877972, 0.05790284412796609, 0.09679391310783103, 0.05143189526279457, 0.04034311059513129, 0.07256700686411932, 0.01892319425678579, 0.022470367002824787, 0.07861789272283204, 0.0562824314692989, 0.07998578221304342, 0.005632844740830478, 0.017854637044365518, 0.05108390592795331, 0.08428975634160452, 0.0016534643214072275, 0.04623404878657311, 0.036566042763297446, 0.05270579917123541, 0.01474068372772308, 0.05349944447516464, 0.04030837808386423, 0.017520249421068, 0.04679365039919503, 0.07331555185373873, 0.031012034050945658, 0.05531545386475045, 0.056246277745231055, 0.09076172194909304, 0.05335176821972709, 0.026577809294394683, 0.06241935450816527, 0.08407582485233434, 0.042422953483765014, 0.020070990576641634, 0.018286646773049142, 0.07830060232663527, 0.11106875259429216, 0.031117342950892635, 0.04496079796808772, 0.11148547593620606, 0.031259723982657306, 0.030211585108190775, 0.08225187819334678, 0.02225814801931847, 0.04335463454481214, 0.07212268305011094, 0.06872841127915308, 0.028381962874846067, 0.027859524307132233, 0.007844200372346677, 0.04816635642782785, 0.05391774859162979, 0.009804783840081654, 0.031520280899712816, 0.08221969867008738, 0.02976547271828167, 0.017178169437102042, 0.09294299787143245, 0.02671497488336172, 0.04199674178380519, 0.04394811519887298, 0.02911853702244116, 0.036441896299947985, 0.04933244483254384, 0.04291788805858232, 0.0053852086148253875, 0.02607647555123549, 0.04366905282950029, 0.018447438633302227, 0.03389111989235971, 0.048534962625126354, 0.057479497118038125, 0.03420164932322223, 0.0032835268712005927, 0.0482284259487642, 0.040038822626229376, 0.04515742628427688, 0.1649488223483786, 0.060616978371399455, 0.12152626644819975, 9.08387141302228, 47.04756684601307, 91.14998012781143, 88.30123499035835, 75.81874519586563, 66.64957121014595, 62.3116821795702, 40.763186663389206, 33.78414675593376, 31.4609457179904, 38.0536774545908, 41.67404718697071, 43.199319541454315, 46.363956928253174, 44.61757443845272, 50.1103924959898, 36.79357387125492, 14.42354153841734, 3.0269413255155087, 0.07681024362682365, 0.0703157538373489, 0.3628507233224809, 0.8426199853420258, 0.15446895500645041, 0.2344545887899585, 0.4622183897299692, 0.47551871510222554, 0.1057051177485846, 0.30219101579859853, 0.4952385288197547, 0.7446652196813375, 0.5772783828433603, 0.9823518467601389, 1.0597303602844477, 5.610420322045684, 9.751111809164286, 14.591132495552301, 15.311821773648262, 9.621474165469408, 12.965723164379597, 12.296526823192835, 10.07960893213749, 10.69555588066578, 9.370499532669783, 10.835590716451406, 6.507630553096533, 7.810806725174189, 8.962556272745132, 7.728419546037912, 7.03911610879004, 14.790823180228472, 17.35807277262211, 11.790772061794996, 18.424618542194366, 3.905806140974164, 2.413935656659305, 1.334543013945222, 1.7530384263955057, 3.552744286134839, 4.990842193365097, 4.17710873298347, 1.0481808800250292, 0.206602914549876, 0.051245961294625886, 0.037700270768254995, 0.096468845003983, 0.22575195733224973, 0.1862905255984515, 0.09991230632294901, 0.2215027017518878, 0.1511906215455383, 0.06997913791565225, 0.18197168625192717, 3.3370730839669704, 14.912654142826796, 40.07894217967987, 47.441164925694466, 44.6769804507494, 44.03846651315689, 59.60637554526329, 38.594316244125366, 29.05281163752079, 32.35378950834274, 47.96122781932354, 62.69057884812355, 76.38509720563889, 72.03623816370964, 83.24787855148315, 77.3836076259613, 85.52179053425789, 76.5841381251812, 28.837292902171612, 0.50992242526263, 0.20037064037751406, 0.014750934642506763, 0.02189120237744646, 0.024693572413525544, 0.02349068090552464, 0.018246544823341537, 0.014329669356811792, 0.04517774628766347, 0.019723197910934687, 0.07304531362024136, 0.07584243852761574, 0.020296271359256934, 0.03621162642957643, 0.11222828412428498, 0.028220757267263252, 0.0630468552117236, 0.09526145237032324, 0.0482259471755242, 0.039221599290613085, 0.009919612639350817, 0.008794797849986935, 0.07254258278408088, 0.006372440357154119, 0.022220309620024636, 0.03573422880435828, 0.06676031727693044, 0.03467987815383822, 0.09165874842437916, 0.03004485792189371, 0.04209601887851022, 0.01868185896455543, 0.03222395935154054, 0.14761532511329278, 0.055326656583929434, 0.10568723198957741, 0.05252963557722978, 0.021601193329843227, 0.03447930532274768, 0.047704543903819285, 0.06240517948754132, 0.02940147154731676, 0.03311711552669294, 0.05621590535156429, 0.021830259065609425, 0.24853449576767161, 0.2012490463675931, 0.2108936561853625, 0.18422781518893316, 0.12373162506264634, 0.187877845892217, 0.18927192577393726, 0.1442691296688281, 0.09651712171034887, 0.15390706015750766, 0.1535877733840607, 0.10939089028397575, 0.18918412970378995, 0.2603318978799507, 0.16167857829714194, 0.10726624022936448, 0.15769435849506408, 0.10930633739917539, 0.1542801971663721, 0.22474805417004973, 0.13141971838194877, 0.21024144196417183, 0.1698400208260864, 0.12414406621246599, 0.12092019896954298, 0.1552143829758279, 0.21174826892092824, 0.07439499080646783, 0.15412541484693065, 0.17179065209347755, 0.23563026945339516, 0.15402013377752155, 0.09206351576722227, 0.14468566747382283, 0.16241195378825068, 0.146008278534282, 0.24889243359211832, 0.2060131001053378, 0.38075871707405895, 15.477912761271, 63.49616602063179, 101.73638686537743, 97.88359880447388, 88.65507960319519, 75.25877684354782, 69.02707323431969, 44.789553210139275, 37.98658065497875, 44.122962579131126, 36.57543137669563, 41.633001789450645, 67.4837252497673, 73.61365512013435, 87.21922025084496, 74.47085112333298, 50.35835199058056, 19.35651283711195, 3.875604886561632, 0.3908347670221701, 0.13714025204535574, 0.7002381223719567, 1.6594012384302914, 0.39353956875856966, 0.5428508052136749, 1.5748126711696386, 2.1335040545091033, 3.159588170237839, 1.8570782686583698, 2.3171512875705957, 2.677053725346923, 7.12318517267704, 15.221720058470964, 10.409162398427725, 14.748743288218975, 18.999060317873955, 19.801715947687626, 16.573038697242737, 17.528182044625282, 23.1172888353467, 18.907625824213028, 13.921000454574823, 18.074872009456158, 14.973658919334412, 15.789112262427807, 18.431845754384995, 19.33145698159933, 14.940153267234564, 16.28504265099764, 12.449294775724411, 21.672973036766052, 23.628103025257587, 27.67587762326002, 28.627755045890808, 4.966117395088077, 7.741712182760239, 6.26289471052587, 9.609055481851101, 7.83118455670774, 6.24254965223372, 4.404302816838026, 1.1452938127331436, 0.2112745857448317, 0.30113321787212044, 0.271136766532436, 0.41548342094756663, 0.31893538136500865, 0.19985170103609562, 0.14562521158950403, 0.49302612722385675, 0.2421125880209729, 0.2718185033882037, 0.666185833979398, 5.823912341147661, 21.092453487217426, 59.268087297677994, 66.08606144785881, 81.70374780893326, 89.3790927529335, 78.42070117592812, 71.96720346808434, 40.54629810154438, 29.1543497890234, 40.51935754716396, 62.214525192976, 82.69415706396103, 84.07858997583389, 97.55123063921928, 87.70696967840195, 94.3713104724884, 95.33274248242378, 41.63316898047924, 1.211655114311725, 0.4114127706270665, 0.1541152919526212, 0.15931636677123606, 0.11831204712507315, 0.17017263657180592, 0.21424379985546693, 0.10580598303931765, 0.17124060192145407, 0.14500808611046523, 0.2843974909046665, 0.21277422871207818, 0.20000314369099215, 0.1265534560661763, 0.2580680506071076, 0.1488447075826116, 0.14117741666268557, 0.227422323951032, 0.14799315249547362, 0.20531230489723384, 0.1326845309813507, 0.13302959996508434, 0.13346641324460506, 0.16213891765801236, 0.09318574695498683, 0.15595730248605832, 0.17762489762390032, 0.13928210508311167, 0.1988693795283325, 0.13318099809112027, 0.16255276888841763, 0.16263688390608877, 0.1320683109224774, 0.24510109797120094, 0.07829164460417815, 0.2789274766109884, 0.14735723583726212, 0.07118808905943297, 0.16059670510003343, 0.16335228458046913, 0.25196863571181893, 0.11108815233455971, 0.15419122850289568, 0.2886941994074732, 0.07527125198976137], [0.029886704396631103, 0.06604317255550995, 0.014145215045573423, 0.07010642366367392, 0.031092907738639042, 0.032395477101090364, 0.021866622446395922, 0.01881589269032702, 0.02258948727103416, 0.0784184702206403, 0.022175174053700175, 0.01918915400892729, 0.05716632935218513, 0.043999000554322265, 0.05930374434683472, 0.026107731100637466, 0.05649088961945381, 0.03688209006213583, 0.09342410994577222, 0.026173264595854562, 0.05580055498285219, 0.03882645760313608, 0.026390815910417587, 0.04511058192292694, 0.05643302807584405, 0.06385571454302408, 0.015939263357722666, 0.03966719588788692, 0.040784217198961414, 0.01690750075795222, 0.035635207750601694, 0.020446773341973312, 0.027237771537329536, 0.03468001916189678, 0.09860088684945367, 0.0773326339549385, 0.2879341214429587, 0.8286177960690111, 30.209872350096703, 72.33128473162651, 78.74434500932693, 75.54177805781364, 67.24474087357521, 73.06456938385963, 61.99816860258579, 33.490148931741714, 29.685280099511147, 19.441846758127213, 19.194546528160572, 29.273608289659023, 57.18055911362171, 58.313996493816376, 45.7722944766283, 41.27010986208916, 16.386852487921715, 3.0324427178129554, 0.1875834062229842, 0.06416357224225067, 0.05186450798646547, 0.03548104883520864, 0.06209040126123, 0.10966498026391491, 0.026782664317579474, 0.09030847752001137, 0.3427538985852152, 0.12762105034198612, 0.12629297707462683, 0.31574975699186325, 0.030874135591147933, 1.7998666386120021, 1.0873812390491366, 0.45450575358700007, 0.07974898515385576, 2.2921773651614785, 7.663747016340494, 11.335426345467567, 16.512426249682903, 13.550783470273018, 10.815682634711266, 9.706085175275803, 11.297345738857985, 6.637107180431485, 6.701372656971216, 4.673706935718656, 4.835495129227638, 5.115942880511284, 7.163268746808171, 5.256777098402381, 4.478950761258602, 14.70765894278884, 4.351282836869359, 3.8553837966173887, 7.228202037513256, 4.983595982193947, 2.664844268001616, 2.5252663576975465, 2.7628400595858693, 3.291513528674841, 3.3098430326208472, 2.126274942420423, 1.0704848519526422, 0.12666550552239642, 0.11258877493673936, 0.06046625188901089, 0.030082692610449158, 0.107606514939107, 0.28781442786566913, 0.21299518091836944, 0.03371329017682001, 0.11885477972100489, 0.0811852264450863, 0.029903113281761762, 0.007355450670729624, 0.0400157121475786, 3.9704895950853825, 22.10905283689499, 44.707728400826454, 47.233285680413246, 26.92525640130043, 76.37043759226799, 86.8878324329853, 33.50493773818016, 15.68524008616805, 22.095080986618996, 27.1881015971303, 55.922556817531586, 48.19083049893379, 57.21826449036598, 64.7289490699768, 74.55635413527489, 77.2408264875412, 30.939391404390335, 5.619490910321474, 0.36164541612379253, 0.08613860205514356, 0.03090925772994524, 0.049954490750678815, 0.08983268664451316, 0.06849418205092661, 0.04514380416367203, 0.027083638597105164, 0.027349628035153728, 0.017728733546391595, 0.052629042547778226, 0.04395155505335424, 0.04505961864197161, 0.0717189176066313, 0.07552576411399059, 0.09251969910110347, 0.00591436686590896, 0.027353320219845045, 0.03491399977065157, 0.035330789905856363, 0.034785315074259415, 0.022434374695876613, 0.0549530779971974, 0.059841975817107596, 0.06709432826028205, 0.028913644891872536, 0.0901263470586855, 0.027517846938280854, 0.026569103902147617, 0.06255651082028635, 0.035388031756156124, 0.035359069443074986, 0.08705269792699255, 0.03331553984025959, 0.08180907578207552, 0.08415660762693733, 0.04820344896870665, 0.04774501321662683, 0.039699037733953446, 0.02426098752039252, 0.025600109511287883, 0.022893621244293172, 0.03523485618643463, 0.05957764507911634, 0.016071623540483415, 0.06445407852879725, 0.06869813165394589, 0.029386595197138377, 0.08078776183538139, 0.06856460444396362, 0.07366442805505358, 0.01595981899299659, 0.1026977869332768, 0.04120143777981866, 0.008128983772621723, 0.05449851625598967, 0.03766985755646601, 0.06659075879724696, 0.0117798929932178, 0.03610063824453391, 0.06585976560018025, 0.05341161500837188, 0.04296001607144717, 0.031388171191792935, 0.01748783983202884, 0.010598802073218394, 0.0416419877728913, 0.04524006071733311, 0.034801805595634505, 0.03368804602359887, 0.05106953423819505, 0.07709623023401946, 0.05591048931819387, 0.055526988217025064, 0.030202252601156943, 0.017927376793522853, 0.09543061009026133, 0.07931485102744773, 0.005912612614338286, 0.25032278965227306, 2.0750187803059816, 38.451580703258514, 86.91367864608765, 89.98138323426247, 84.29930493235588, 77.79676705598831, 79.38611537218094, 67.9743093252182, 40.13774402439594, 36.04873783886433, 24.680789038538933, 21.379148103296757, 28.170358389616013, 56.89615577459335, 59.45722594857216, 54.0108148008585, 45.251369029283524, 20.36171469837427, 4.628166854381561, 0.19972877169493586, 0.16523307975148782, 0.07980400056112558, 0.04500583519984502, 0.051717900423682295, 0.1697333890479058, 0.04034594930999447, 0.11592473616474308, 0.15843283996218815, 0.46879453060682863, 0.13254595716716722, 0.43150119425263256, 0.06525928649352863, 3.552170041948557, 1.7855678871273994, 0.40955858887173235, 0.05611332569969818, 1.543378857895732, 5.435824915766716, 9.781044702976942, 4.732925333082676, 12.726223915815353, 12.913952842354774, 13.927723243832588, 12.726969625800848, 13.549104910343885, 11.1140644736588, 8.85086601600051, 7.859460264444351, 5.675517478957772, 7.136310143396258, 7.4105048552155495, 7.994768153876066, 5.383389154449105, 7.153270533308387, 4.532920690253377, 6.279085166752338, 2.744595338590443, 0.38162827666383237, 0.7111399155110121, 0.6143519247416407, 0.5410096258856356, 0.25528541242238134, 1.1658342042937875, 1.0418023285456002, 0.11807861941633746, 0.07868198459618725, 0.04333214004873298, 0.07303064136067405, 0.10920715678366832, 0.22041297663236037, 0.11629060012637638, 0.11011893715476617, 0.2157494393759407, 0.07977797344210558, 0.07684476833674125, 0.026349212967033964, 0.22307642590021715, 3.938805707730353, 21.80201981216669, 48.680441826581955, 46.323644891381264, 18.38697586208582, 62.69230395555496, 69.24454316496849, 24.399467334151268, 17.64380034059286, 30.862954705953598, 42.801712676882744, 66.45432248711586, 60.30390411615372, 63.545726761221886, 75.91153621673584, 81.8312917649746, 90.47401919960976, 43.1982745975256, 8.954770490527153, 0.32079927041195333, 0.06889516444061883, 0.031123680892051198, 0.12200123353977688, 0.08656682126456872, 0.05631563515635207, 0.03391662008652929, 0.062172148827812634, 0.04672007758927066, 0.019783421339525376, 0.06879775755805895, 0.04332418793637771, 0.1010059574036859, 0.03411294783290941, 0.045183182519394904, 0.04753517096105497, 0.046409447968471795, 0.011702487918228144, 0.01329420543697779, 0.00681492132571293, 0.0690535016474314, 0.03421853689360432, 0.08082608634140342, 0.05080639093648642, 0.050519751239335164, 0.07085885750711896, 0.028079433795937803, 0.014142022882879246, 0.05486938600370195, 0.0954635466041509, 0.09813802418648265, 0.011203986396139953, 0.07946719910250977, 0.057139411655953154, 0.05422507936600596, 0.0578175008558901, 0.11331613903166726, 0.04773232249135617, 0.009932361808751011, 0.029049094264337327, 0.032648241467541084, 0.035591049963841215, 0.012552271127788117, 0.15498163062147796, 0.19684051105286926, 0.2657298347912729, 0.18154984951252118, 0.19942796439863741, 0.15654434129828587, 0.14461010199738666, 0.1861663197632879, 0.13732068298850209, 0.13251009659143165, 0.19316340680234134, 0.11375920861610211, 0.19343152991496027, 0.15139763621846214, 0.2488446986535564, 0.10325434574042447, 0.10808594233822078, 0.1328866177937016, 0.14180129568558186, 0.11708842372172512, 0.1646687655011192, 0.18888779013650492, 0.10226459533441812, 0.18733817094471306, 0.14797960087889805, 0.18728279188508168, 0.19206707656849176, 0.20299622527090833, 0.19304727553389966, 0.1055043593805749, 0.143065752054099, 0.13818193052429706, 0.11330442794132978, 0.17359001882141456, 0.25823046220466495, 0.1683811514521949, 0.33404743764549494, 5.36256437189877, 52.21118576824665, 103.11704277992249, 101.07692465186119, 93.61649617552757, 87.0279461145401, 91.41979604959488, 84.00525391101837, 51.3785782456398, 45.2060716599226, 30.365863479673862, 33.41401241719723, 43.572881296277046, 79.00965437293053, 75.7744699716568, 64.96189177036285, 61.27730928361416, 27.760500982403755, 6.753224199637771, 0.5992119340226054, 0.4081915825372562, 0.2841984765836969, 0.18318064481718466, 0.3016382938949391, 0.4114785842830315, 0.1524736316059716, 0.49951888038776815, 1.064694793894887, 1.7470807023346424, 0.380615868489258, 0.6894927145913243, 0.1529939513420686, 5.428256196901202, 2.9362399550154805, 1.4403041638433933, 0.2850100595969707, 8.172586262226105, 22.163287326693535, 28.640786446630955, 36.49919606745243, 33.88032719492912, 26.83777939528227, 24.225132688879967, 27.659124322235584, 22.290348708629608, 19.820709228515625, 20.446773134171963, 18.379539661109447, 17.229825854301453, 18.033098950982094, 18.87002494186163, 15.584613885730505, 36.48530401289463, 16.405741274356842, 18.554014898836613, 21.977657787501812, 11.977418046444654, 7.3203646671026945, 8.266354780644178, 11.691811122000217, 7.9517359379678965, 8.82157813757658, 7.964041577652097, 5.428269021213055, 0.6626995804253966, 0.35030554805416614, 0.42681022721808404, 0.3772395121632144, 0.41912896907888353, 0.7378829398658127, 0.4718564834911376, 0.2106240636203438, 0.6734773458447307, 0.4257879633223638, 0.14673175377538428, 0.14939407497877255, 0.39109157980419695, 7.015645243227482, 30.836268737912178, 66.74772754311562, 65.48295021057129, 38.00397232174873, 96.49635404348373, 110.47442078590393, 46.55847989022732, 23.00771601498127, 35.27392901480198, 42.50443562865257, 70.83169519901276, 65.13361975550652, 77.28858232498169, 86.56432539224625, 93.0651305615902, 104.00378599762917, 56.93650580942631, 12.15438025072217, 0.4141851078020409, 0.24054462293861434, 0.09512738339253701, 0.30559569247998297, 0.3156367427436635, 0.16111496166558936, 0.23510178609285504, 0.12817726033972576, 0.0726928751100786, 0.10117110010469332, 0.23578459164127707, 0.12992506264708936, 0.18100220389897004, 0.1651159836910665, 0.14727901347214356, 0.15985112870112062, 0.07787115857354365, 0.10797008566441946, 0.16193291230592877, 0.07026346953352913, 0.09431005615624599, 0.09079903713427484, 0.1494079828262329, 0.16647785436362028, 0.16988622694043443, 0.2296121494146064, 0.176144921570085, 0.08778104165685363, 0.15179302281467244, 0.18096199433784932, 0.16943822207394987, 0.144820278219413, 0.20694140810519457, 0.13223710499005392, 0.2540891891112551, 0.18718942970735952, 0.19812542101135477, 0.2109811850823462, 0.11602539365412667, 0.1260587404249236, 0.08795583227765746, 0.08682950443471782, 0.08620645661721937], [0.02953137893200619, 0.025208389124600217, 0.023363558429991826, 0.037313170250854455, 0.014007268346176716, 0.017738878705131356, 0.046794930603937246, 0.06126325541117694, 0.08144493360305205, 0.05079127338831313, 0.041588701569708064, 0.061338850573520176, 0.029770710425509606, 0.01791051519830944, 0.055314010387519374, 0.09240356041118503, 0.02110445904691005, 0.023952081537572667, 0.0501043266558554, 0.010477345895196777, 0.03317240181786474, 0.08468041545711458, 0.0889860223105643, 0.03951407597924117, 0.04311704709834885, 0.030503427260555327, 0.02051743693300523, 0.02353516894800123, 0.03647177516540978, 0.13637180265504867, 0.02112211845087586, 0.045864566855016164, 0.07777401886414737, 0.10678412625566125, 0.10173371483688243, 1.545011701527983, 20.907348319888115, 55.564353838562965, 77.50378757715225, 72.53857120871544, 70.63950911164284, 61.288754269480705, 70.8001720905304, 68.80948171019554, 44.343635737895966, 39.426699578762054, 41.098511070013046, 47.8258752822876, 62.12749846279621, 62.925706431269646, 42.96150930225849, 42.694455832242966, 24.708113372325897, 6.657006237655878, 0.4833498573862016, 0.23581773595651612, 0.03624824028520379, 0.04473726308788173, 0.1809146601590328, 0.013699755745619768, 0.016609927370154765, 0.027369916497264057, 0.030503286252496764, 0.09826058987528086, 0.34640603698790073, 0.7874654699116945, 0.04243157723976765, 0.04643499640224036, 0.1113713113591075, 1.3633920159190893, 1.1604507244192064, 0.5285500350873917, 0.6162262335419655, 1.416120717767626, 4.2934641893953085, 8.528497014194727, 12.131343986839056, 7.628579428419471, 9.847788121551275, 10.958364978432655, 8.897299524396658, 10.278177727013826, 7.272736597806215, 9.213177524507046, 3.8489547790959477, 4.337041676044464, 7.3107578326016665, 5.46833929605782, 7.045390522107482, 7.291773101314902, 15.962571054697037, 5.7289107888937, 10.763036459684372, 3.354746885597706, 0.20999032887630165, 0.4134472052101046, 0.24372300395043567, 0.4727934597758576, 3.2765325950458646, 3.451649285852909, 0.5081368773244321, 0.23802972194971517, 0.3521479445043951, 0.3028135886415839, 0.2027293192804791, 0.44610861979890615, 0.3677833336405456, 0.5604056257288903, 0.024585884930274915, 0.16613594692898914, 0.09529835937428288, 0.032985562429530546, 0.08309380020364188, 0.0531356473948108, 0.11727982360753231, 0.09064041791134514, 6.724152434617281, 33.334011510014534, 86.7543075978756, 76.05399817228317, 60.81794053316116, 51.19770035147667, 61.61864496767521, 26.721712723374367, 29.232232309877872, 22.335305996239185, 24.50167614966631, 58.25877405703068, 61.49813063442707, 64.6621410548687, 69.33131530880928, 84.27446946501732, 75.52717924118042, 28.570769503712654, 1.2281652283854783, 0.1746446848846972, 0.1018362573813647, 0.058411638310644776, 0.01594225235749036, 0.06467563929618336, 0.07285155370482244, 0.05091888568131253, 0.055249309953069314, 0.06772435968741775, 0.08411446848185733, 0.062427681405097246, 0.04729895277705509, 0.013259941406431608, 0.07439484979840927, 0.03174443918396719, 0.09169074983219616, 0.056532334856456146, 0.08508413637173362, 0.02421341214358108, 0.03600460433517583, 0.04878020532487426, 0.011896383275598055, 0.018646217322384473, 0.0516010641149478, 0.09105964229092933, 0.019007869595952798, 0.09617362607968971, 0.013598036057373974, 0.09234165045199916, 0.018579353527456988, 0.07298815340618603, 0.023173475856310688, 0.07706102274823934, 0.02568787404015893, 0.054529448971152306, 0.06816887645982206, 0.0251491453309427, 0.022660583163087722, 0.04514164451393299, 0.020332682979642414, 0.0033547310704307165, 0.02534162504161941, 0.034882146792369895, 0.06085182729293592, 0.03101909187535057, 0.029206038088887, 0.04883348781731911, 0.06928375296411105, 0.03927063298760913, 0.1298304388183169, 0.020842217454628553, 0.05227260015089996, 0.1294826832599938, 0.016859298266354017, 0.028111227402405348, 0.015843806468183175, 0.05197233833314385, 0.016281263560813386, 0.023577066895086318, 0.05470592055644374, 0.018058911336993333, 0.07009621171164326, 0.028239433413546067, 0.05075402499642223, 0.024429377117485274, 0.016169420050573535, 0.023135874944273382, 0.12953936849953607, 0.04267404801794328, 0.047324924234999344, 0.023579922308272216, 0.04923377258819528, 0.07058464136207476, 0.03351004190335516, 0.07297398580703884, 0.13450708240270615, 1.8075896054506302, 23.025400266051292, 66.5075196325779, 91.04189872741699, 80.16505837440491, 78.61767500638962, 70.34072354435921, 78.08937415480614, 83.02498251199722, 61.0327810049057, 42.67692357301712, 35.046579614281654, 31.34318433701992, 43.36937941610813, 58.579492047429085, 51.68055944144726, 46.187798380851746, 30.84870357066393, 8.721288219094276, 0.8403975202236325, 0.15068824694026262, 0.0802071277576033, 0.04377185883640777, 0.12583481962792575, 0.11905670326086693, 0.04427846739417873, 0.1491927748429589, 0.16789198707556352, 0.3309403918683529, 0.8997350768186152, 0.6195139477495104, 1.0470431973226368, 0.745093171717599, 0.41323946323245764, 2.909694816917181, 2.3175702150911093, 0.6385575758758932, 1.1296449461951852, 0.45062773511745036, 3.3252331567928195, 5.809869719669223, 4.705360662192106, 8.317902814596891, 5.467299576848745, 5.148150902241468, 12.613334823399782, 12.264838423579931, 9.879505019634962, 5.692301653325558, 2.0008287113159895, 3.038060241378844, 2.4554876144975424, 2.924406439997256, 1.591386313084513, 2.120439405553043, 1.4655597461387515, 1.5658664074726403, 4.490134036168456, 1.8690473889000714, 0.17647986765950918, 0.40896246617194265, 0.18353586638113484, 0.9508697642013431, 0.7679469860158861, 1.0533971688710153, 0.962164361262694, 0.4135129298083484, 0.2468339237384498, 0.2988864993676543, 0.2218183668446727, 2.2624145122244954, 1.024945720564574, 1.2280779518187046, 0.5508182651828974, 0.6104881851933897, 0.23113092494895682, 0.2335030515678227, 0.08916737351682968, 0.0429495851858519, 0.08789683153736405, 0.30821357388049364, 6.625209543853998, 34.043593034148216, 64.17759865522385, 72.26228043437004, 69.53232452273369, 42.65651486814022, 43.0372354388237, 27.036943808197975, 36.229809522628784, 37.03317001461983, 39.43583428859711, 68.37110683321953, 70.80122083425522, 76.30499750375748, 78.02799224853516, 96.36798173189163, 92.46874496340752, 39.233620539307594, 1.7480295826680958, 0.07538978039519861, 0.037778110927320085, 0.06537774810567498, 0.027622241141216364, 0.005502131198227289, 0.01478398711697082, 0.02992459289089311, 0.04163909710769076, 0.06925449008122087, 0.08055466067162342, 0.10668360977433622, 0.046072576005826704, 0.011910126922884956, 0.05218305632297415, 0.04781891628226731, 0.04035397192637902, 0.07578997610835359, 0.09018242373713292, 0.03848164466035087, 0.02952870348963188, 0.015260236268659355, 0.03913129105058033, 0.015893391209829133, 0.02907868183683604, 0.03772768941416871, 0.04421270939928945, 0.07764740847051144, 0.08497646558680572, 0.08142490303725936, 0.030627187807112932, 0.05543744809983764, 0.03360412025358528, 0.10570006372290663, 0.04374891163024586, 0.0356020745675778, 0.032958399824565277, 0.029069826159684453, 0.02055216573353391, 0.09661599804530852, 0.020010201260447502, 0.010304350344085833, 0.15965220343787223, 0.10164006322156638, 0.15297780220862478, 0.1270409135031514, 0.15730084211099893, 0.09928850893629715, 0.1533790963003412, 0.16610777500318363, 0.2675887366058305, 0.12414185461238958, 0.1413824869086966, 0.3398378222482279, 0.15584931999910623, 0.0751164325629361, 0.15287652873666957, 0.20565563725540414, 0.10512361535802484, 0.0747491733636707, 0.21237756562186405, 0.10158553021028638, 0.13770204299362376, 0.13252213422674686, 0.20161750784609467, 0.2096707304008305, 0.12097301761968993, 0.1339765210286714, 0.22908094979356974, 0.12894714949652553, 0.1639523555058986, 0.2481261661159806, 0.12811089749448, 0.2401540009304881, 0.1319354071165435, 0.22573160764295608, 0.18225638894364238, 3.6819948256015778, 37.744282856583595, 86.18948310613632, 104.44103613495827, 88.55636090040207, 90.16854599118233, 82.04372316598892, 90.15609785914421, 88.79707798361778, 67.36222296953201, 59.38408747315407, 57.83528298139572, 68.22653219103813, 80.38573533296585, 78.09893444180489, 61.98016136884689, 61.856432408094406, 42.6190222799778, 12.66232654452324, 1.8540824856609106, 0.6564362696371973, 0.17883566702948883, 0.20604330551577732, 0.41477689635939896, 0.29040746216196567, 0.21803645649924874, 0.23485638754209504, 0.2020963266841136, 0.5432200978975743, 1.3266644929535687, 1.7653834889642894, 0.8100320433732122, 0.7393555389717221, 0.9214146353770047, 4.7851392813026905, 2.9462806787341833, 1.3400117517448962, 1.8372046225704253, 3.0678710667416453, 14.054859671741724, 23.642920330166817, 31.471841633319855, 22.647381350398064, 25.819796919822693, 25.258396044373512, 25.298751778900623, 23.087057657539845, 22.515549324452877, 21.548877395689487, 14.648003093898296, 15.91489216312766, 20.158710591495037, 20.6200248375535, 21.597507186233997, 24.491392001509666, 34.66218464076519, 18.511842861771584, 24.297782890498638, 10.221518017351627, 2.218679334037006, 1.3546618656255305, 2.0842244988307357, 5.29008231125772, 9.373859502375126, 10.532479081302881, 4.272948140278459, 2.1359333116561174, 0.8441451878752559, 0.5255354312248528, 0.45776351471431553, 1.512739914469421, 1.6279627941548824, 1.2728948844596744, 0.45126031211111695, 0.2987392572686076, 0.3146552079124376, 0.6204462633468211, 0.38668194611091167, 0.1938541978597641, 0.38639538805000484, 0.5864063242916018, 10.107372142374516, 48.57324577867985, 116.12008944153786, 84.21213760972023, 78.25292497873306, 74.48112577199936, 85.3078544139862, 42.46984228491783, 44.60755057632923, 37.08814166486263, 38.53205658495426, 75.48705339431763, 79.48481887578964, 88.2566785812378, 87.17545419931412, 105.61039298772812, 104.71175640821457, 50.42478762567043, 2.81903809402138, 0.4446635692147538, 0.19748298829654232, 0.24814853444695473, 0.11785708833485842, 0.08472950110444799, 0.12767648877343163, 0.13010200549615547, 0.12959762709215283, 0.17082951148040593, 0.2130418026354164, 0.22827359702205285, 0.14951644028769806, 0.1731437654234469, 0.22861822071718052, 0.14078590407734737, 0.1673521933844313, 0.21969474095385522, 0.1399851415771991, 0.17250700271688402, 0.08883529953891411, 0.12975086574442685, 0.12762486498104408, 0.11471836769487709, 0.09628681844333187, 0.13021605875110254, 0.1425360218854621, 0.2932888059876859, 0.25902565859723836, 0.15036395809147507, 0.10413785028504208, 0.1758454946684651, 0.16178553662030026, 0.18214376061223447, 0.11359172814991325, 0.1671383361099288, 0.12752866779919714, 0.13638050062581897, 0.1581089073442854, 0.1240693467843812, 0.15680605225497857, 0.10518418945139274], [0.015139749521040358, 0.05100497481180355, 0.02380746664130129, 0.024559204721299466, 0.03305522783193737, 0.060558901604963467, 0.022950096827116795, 0.028482065608841367, 0.03499609614664223, 0.02700812507100636, 0.0745362883026246, 0.08147542845108546, 0.02584994424978504, 0.0488091008446645, 0.0694975360238459, 0.04735617236292455, 0.03211662624380551, 0.023925880013848655, 0.026896218478213996, 0.05343082550098188, 0.0298676274906029, 0.04708602689788677, 0.08607368639786728, 0.03663763403892517, 0.024400507572863717, 0.031400609586853534, 0.0510934907651972, 0.011058982800022932, 0.048340345529140905, 0.051281925771036185, 0.03589675543480553, 0.012556859455798985, 0.1266677468083799, 0.13777738582575694, 2.4135537771508098, 47.001608312129974, 89.65987488627434, 79.56621050834656, 71.72485247254372, 66.97219669818878, 52.3291352391243, 49.222608134150505, 42.695569172501564, 24.189988374710083, 17.591218762099743, 33.35182495415211, 63.128638342022896, 75.910305082798, 57.484330013394356, 39.632804319262505, 38.50011549890041, 20.387342423200607, 3.6220820154994726, 0.2280894701834768, 0.1096604902704712, 0.03894386536558159, 0.030735142463527154, 0.04676601653045509, 0.07998498811502941, 0.012504696678661276, 0.14760634512640536, 0.1593094944837503, 0.07571711204946041, 0.09099845963646658, 0.07602067271363921, 0.3530060750199482, 0.23614615114638582, 0.23996396659640595, 0.5527395964600146, 0.11939170872210525, 1.0250451089814305, 0.22791223047534004, 0.1485009744646959, 0.37464567634742707, 2.025984786450863, 3.7825210439041257, 1.7973829968832433, 5.004186602309346, 7.719914652407169, 9.440728314220905, 7.998337112367153, 10.632100235670805, 8.825872857123613, 3.0373309180140495, 3.9223673148080707, 4.247222570702434, 7.266572853550315, 8.16435020416975, 19.37689684331417, 9.201401006430387, 3.111367807723582, 2.839228310622275, 2.8743301145732403, 1.5844779275357723, 0.11541979372850619, 0.07597698247991502, 0.05073350832390133, 0.22642429859843105, 0.873667822452262, 0.427508321008645, 0.518051910912618, 0.2498683874728158, 0.18949804332805797, 0.41553507442586124, 0.022221688159334008, 0.09311483474448323, 0.15849630843149498, 0.08920054009649903, 0.2254868028103374, 0.07017715033725835, 0.12021059446851723, 0.033124232722911984, 0.08894636936020106, 0.04733865396701731, 0.0664963130839169, 0.10296113061485812, 0.15485930984141305, 1.1886655166745186, 13.815874345600605, 28.03564991801977, 39.1949538141489, 40.256787836551666, 48.990091010928154, 71.22905507683754, 67.48839139938354, 46.237226128578186, 12.85623773932457, 19.48806557804346, 49.95025008916855, 62.98431448638439, 69.47794184088707, 58.38475629687309, 71.83984190225601, 79.3099294602871, 48.418563678860664, 5.0810308288782835, 0.32593433861620724, 0.020769464717886876, 0.09014458904857747, 0.05338382899935823, 0.055182063952088356, 0.06710427303914912, 0.07316062110476196, 0.07917800641735084, 0.07045791964628734, 0.03138748470519204, 0.00984657881417661, 0.0383671052986756, 0.044679924758384004, 0.03921123148757033, 0.015474354222533293, 0.01728286049910821, 0.06961436491110362, 0.07497451908420771, 0.043150321289431304, 0.05789691807876807, 0.03198263148078695, 0.03588746374589391, 0.041238693593186326, 0.018858052244468126, 0.040801223512971774, 0.018326917561353184, 0.024993492843350396, 0.03769965849642176, 0.08238879701821133, 0.02311595013452461, 0.0313170697336318, 0.07094014494214207, 0.033517326082801446, 0.031291417399188504, 0.026184224261669442, 0.03884111501974985, 0.023048780203680508, 0.014678022344014607, 0.024282120175485034, 0.04957220306096133, 0.014791701742069563, 0.057195035624317825, 0.031005636737972964, 0.023200670002552215, 0.012673574237851426, 0.03708118230861146, 0.0184963999708998, 0.02702001242141705, 0.020836527037317865, 0.013199052827985724, 0.01802086699171923, 0.009877447519102134, 0.02492011113645276, 0.10680751132895239, 0.04218488735205028, 0.05646512596285902, 0.01920616032293765, 0.002379899688094156, 0.046181241268641315, 0.022864360216772184, 0.06800171511713415, 0.04908566588710528, 0.015759517045808025, 0.06783287652069703, 0.05734141683205962, 0.021570561184489634, 0.11212798286578618, 0.018609497710713185, 0.013683255019714125, 0.03630335959314834, 0.03160140877298545, 0.03253032162319869, 0.09044296210049652, 0.028007354558212683, 3.26386003755033, 57.63047777116299, 103.87096032500267, 90.5544076859951, 78.73678341507912, 75.9735032916069, 65.52721783518791, 60.47978147864342, 58.64513352513313, 43.47003981471062, 31.496572606265545, 48.08614991605282, 57.260594218969345, 63.94485354423523, 55.425034314394, 39.23058830201626, 39.130752459168434, 23.012188374996185, 3.8400414073839784, 0.19760096009122208, 0.07303537626285106, 0.07462901223334484, 0.08168809086782858, 0.1618844352196902, 0.16880788636626676, 0.21909809875069186, 0.9588503453414887, 1.4298447500914335, 1.5533209056593478, 1.5021456079557538, 0.8145459042862058, 2.087012124247849, 2.5031976168975234, 4.478227850049734, 1.0400704527273774, 0.07543565996456891, 1.05581680778414, 0.23743391095194966, 0.2063109091250226, 0.11893980015884154, 0.5337182921357453, 1.0061189183034003, 0.847859785426408, 0.8582039584871382, 2.395701385103166, 4.166733389720321, 4.836203316226602, 9.120833929628134, 4.1403623297810555, 2.828937037847936, 1.2835991475731134, 3.684729253873229, 6.2471844535321, 9.547187201678753, 15.66063355654478, 9.640020970255136, 5.060620224103332, 1.5590483858250082, 0.6392138719093055, 0.5327384197153151, 0.24849409324815497, 0.13005191052798182, 0.01830400560720591, 0.45456794556230307, 0.6290851591620594, 0.039295446695177816, 0.98502132226713, 0.35987287061288953, 0.08747497253352776, 1.4112994889728725, 0.9304759022779763, 0.2503729291493073, 2.148437015712261, 3.0246521858498454, 2.1429897705093026, 1.349888846743852, 0.3517982445191592, 0.2173379174200818, 0.032583507636445574, 0.07230882853036746, 0.08628880532342009, 0.11339085845975205, 0.04730500870209653, 1.502807722426951, 17.642502710223198, 34.01199012994766, 42.520147785544395, 43.567949160933495, 52.087707594037056, 61.80928073823452, 67.30073466897011, 45.63542582094669, 21.034147515892982, 38.82494866847992, 59.674243703484535, 73.49843010306358, 75.59952735900879, 67.25060775876045, 77.83886879682541, 93.06164994835854, 64.42111998796463, 8.215913437306881, 0.3730700968299061, 0.025422192593396176, 0.09340468794107437, 0.06605604139622301, 0.029388226066657808, 0.10822867960087024, 0.04357037316367496, 0.011262518655712483, 0.02661666072526714, 0.012398914659570437, 0.06728617343469523, 0.07340337018831633, 0.046518146627931856, 0.05523702740902081, 0.01813909853808582, 0.01718299896310782, 0.04269157754606567, 0.04820001282496378, 0.07356411937507801, 0.00854401780088665, 0.026171869358222466, 0.020387965560075827, 0.05444462149171159, 0.0130139027533005, 0.06221493364137132, 0.0367021637794096, 0.05903765842958819, 0.02473388030921342, 0.08843976451316848, 0.03455207661318127, 0.06926400441443548, 0.014714439530507661, 0.07948374899569899, 0.017543102003401145, 0.01522084028692916, 0.031344243470812216, 0.027913014600926545, 0.045877201919211075, 0.043374650267651305, 0.0368868769146502, 0.115670060768025, 0.12079695792635903, 0.112721114710439, 0.10551877930993214, 0.0798677584680263, 0.1355025399243459, 0.21337489335564896, 0.26386493642348796, 0.08758167110499926, 0.1724864897551015, 0.1763848282280378, 0.18222694052383304, 0.1475872125593014, 0.18722879322012886, 0.12694728415226564, 0.20139171683695167, 0.1643810942186974, 0.0933327738312073, 0.14426672511035576, 0.1291931714513339, 0.14812709530815482, 0.0991067495488096, 0.15304086991818622, 0.12350544071523473, 0.12174167481134646, 0.21013316261814907, 0.16858307499205694, 0.10627864947309718, 0.16908893769141287, 0.16237909148912877, 0.10861743881832808, 0.14331238257000223, 0.2083993423730135, 0.1814160996582359, 8.22801673784852, 77.23418444395065, 115.57437032461166, 98.67663905024529, 90.59489071369171, 89.04862448573112, 72.60878384113312, 67.83652871847153, 61.46524719893932, 41.097557321190834, 34.66085471212864, 50.6162441521883, 81.64817199110985, 96.43335342407227, 80.20288914442062, 58.48318241536617, 57.901030853390694, 32.97862038016319, 6.949586737900972, 0.5495529330801219, 0.3183044074103236, 0.1709940010914579, 0.3407201764639467, 0.16997475031530485, 0.42029494245070964, 0.643436157843098, 0.5502360058017075, 0.9919108275789768, 1.1027726694010198, 0.453145545325242, 0.8709550055209547, 1.4515343424864113, 1.226480493787676, 4.291527243331075, 2.4589957762509584, 0.5877080513164401, 1.5950052626430988, 0.4682235518703237, 0.4545867961132899, 0.4449125152314082, 7.541649593040347, 8.65681802853942, 7.92045459151268, 17.384017780423164, 21.073804087936878, 30.48695158213377, 21.755145527422428, 24.30436223745346, 22.667330279946327, 12.17678764835, 11.598069202154875, 10.521838702261448, 11.801470387727022, 14.149070866405964, 26.84536948800087, 11.896732226014137, 7.203539460897446, 7.037123115733266, 7.1804219763726, 3.6007979325950146, 0.42455739341676235, 0.28504749352578074, 0.15109672502148896, 1.0760302981361747, 0.8929773769341409, 0.7038924575317651, 2.511737896129489, 0.8395733206998557, 0.5490169243421406, 2.0325669832527637, 1.4479159866459668, 2.080789958126843, 1.5098996856249869, 0.9707526722922921, 0.7072112231981009, 0.835147270699963, 0.2559735911199823, 0.21599684172542766, 0.1395847974345088, 0.211888104386162, 0.20274615118978545, 0.3175582818221301, 0.38203019415959716, 2.5211602030321956, 20.976234823465347, 45.29552645981312, 57.254009172320366, 57.8112530708313, 64.79056656360626, 85.60979381203651, 86.51224538683891, 59.269151240587234, 23.967935889959335, 33.6438050866127, 68.67765918374062, 80.04175499081612, 88.4076900780201, 76.54327511787415, 89.76860225200653, 100.51861301064491, 77.26614072918892, 10.298900865018368, 0.4533982020802796, 0.12471707101212814, 0.19917239842470735, 0.14167265180731192, 0.15515131526626647, 0.16815043258247897, 0.15192763356026262, 0.11046828833059408, 0.19963750237366185, 0.1377808887627907, 0.12690897448919713, 0.14517956675263122, 0.1303028455004096, 0.12625477131223306, 0.1646963437087834, 0.05766651091107633, 0.13736118940869346, 0.2740690513746813, 0.16093463462311774, 0.18465202680090442, 0.10169116751058027, 0.09360248513985425, 0.18374988692812622, 0.08242948897532187, 0.1480196916963905, 0.10723927800427191, 0.12706420209724456, 0.10233174485620111, 0.20546088286209852, 0.1009351787797641, 0.15321828774176538, 0.29470743611454964, 0.12289400008739904, 0.13737408793531358, 0.14520950498990715, 0.099171153124189, 0.13762248476268724, 0.11343678997945972, 0.24803773179883137, 0.16310888982843608], [0.018137742263206746, 0.045355434995144606, 0.03693601451232098, 0.08201160046155564, 0.02840724784618942, 0.08148268665536307, 0.028820336519856937, 0.06310609343927354, 0.1276688594953157, 0.10512750421185046, 0.10421740109450184, 0.069781066122232, 0.03282902493083384, 0.031838480426813476, 0.13718427624553442, 0.0658605300122872, 0.016538482668693177, 0.10478291020262986, 0.04098876794159878, 0.09484284397331066, 0.05624440382234752, 0.046424183310591616, 0.021410246154118795, 0.13537588500184938, 0.11600298079429194, 0.02087025022774469, 0.011289952144579729, 0.08043238442041911, 0.15805097529664636, 0.09872823196928948, 0.023705488129053265, 0.2360935922479257, 0.07930740728625096, 4.712264891713858, 65.71192592382431, 84.30298313498497, 74.95227009057999, 75.56324690580368, 74.28268522024155, 66.20665177702904, 40.373384580016136, 23.33732932806015, 12.564338352531195, 21.258246190845966, 35.37786863744259, 21.908267810940742, 41.03798791766167, 36.732932925224304, 37.11807645857334, 33.28769579529762, 8.589305151253939, 0.7730965409427881, 0.12159550882643089, 0.05168998453882523, 0.04872310077189468, 0.0846161157824099, 0.12265375204151496, 0.19384719198569655, 0.09048179868841544, 0.07529173526563682, 0.6280432431958616, 1.144779771566391, 1.30333315115422, 2.3014113446697593, 0.24665151868248358, 0.6084564223419875, 1.6643665032461286, 1.1040003597736359, 0.41161528788506985, 0.04823401803150773, 1.6899514803662896, 1.1470290133729577, 0.19114708062261343, 0.537198371021077, 0.9637353988364339, 0.30794577731285244, 0.6783981411717832, 3.742944267578423, 0.8992493560072035, 2.9502139426767826, 6.068247780203819, 11.169337257742882, 7.298460742458701, 9.181013200432062, 14.994037225842476, 38.77439238131046, 55.96766799688339, 66.43389478325844, 64.83437061309814, 67.192592471838, 53.05226303637028, 26.887733414769173, 4.138183621689677, 1.1867341515608132, 0.9698988462332636, 0.9366174414753914, 0.5739347403869033, 0.7583292271010578, 0.33566149009857327, 0.3238768083974719, 0.08271678918390535, 0.27932229917496443, 0.49568224407266825, 0.5766999232582748, 0.1735057553742081, 3.6948238871991634, 1.086947349831462, 3.6455089459195733, 3.7148027401417494, 2.80772942584008, 0.3066068241605535, 0.2889439766295254, 0.09615004062652588, 0.0894284833339043, 0.22968676494201645, 0.17073157767299563, 0.052759820100618526, 0.04743433906696737, 0.3892067918786779, 4.3871125392615795, 23.04028406739235, 38.298334926366806, 68.44163864850998, 124.6646149456501, 66.16217896342278, 37.23764084279537, 34.40589979290962, 23.455445989966393, 22.877396307885647, 43.66362802684307, 51.13508351147175, 58.60615521669388, 67.85601407289505, 70.11050909757614, 78.68745446205139, 59.72625911235809, 3.7656715605407953, 0.40253623912576586, 0.04263084389094729, 0.16386448522098362, 0.06132404843810946, 0.13026698492467403, 0.01773096370015992, 0.011707805406331317, 0.035310273233335465, 0.1335183042101562, 0.0888171985570807, 0.138382013537921, 0.2978347276803106, 0.38884607842192054, 0.34579605096951127, 0.11264757529716007, 0.06127872547949664, 0.038669100031256676, 0.022827453212812543, 0.012306982043810422, 0.027923482593905646, 0.015144518747547409, 0.011787710591306677, 0.03889120627718512, 0.10267978985211812, 0.008730969439056935, 0.04039139843371231, 0.04293302416044753, 0.0751894673157949, 0.04101223465113435, 0.048947021568892524, 0.045552920491900295, 0.010630989017954562, 0.0751807916094549, 0.05835202529851813, 0.02003254176088376, 0.08393486874410883, 0.07765324175124988, 0.06359027800499462, 0.05315986738423817, 0.04163592071563471, 0.08550981001462787, 0.058122197006014176, 0.028912852649227716, 0.009017548836709466, 0.07466220849892125, 0.007074996774463216, 0.02995956103404751, 0.06571480189450085, 0.06161398327094503, 0.06507156023872085, 0.06478194452938624, 0.019225804971938487, 0.05921978518017568, 0.12440477526979521, 0.09708012235932983, 0.014050901063455967, 0.11845227592857555, 0.0675708612834569, 0.11813436954980716, 0.032448818965349346, 0.09405239732586779, 0.038686288171447814, 0.06841020061983727, 0.09517674363451079, 0.05829690599057358, 0.06511112413136289, 0.004955542681273073, 0.16054281033575535, 0.08749374886974692, 0.0866308982949704, 0.1871927100000903, 0.02664993120561121, 6.342061087489128, 74.72506508231163, 97.45510339736938, 85.27173355221748, 84.98202189803123, 82.16372072696686, 75.82002192735672, 51.514481753110886, 36.21860392391682, 22.611720263957977, 24.415506273508072, 37.86903776228428, 27.20070742070675, 53.209813982248306, 43.75082574784756, 37.11986996233463, 35.594817996025085, 11.063763722777367, 0.979066863656044, 0.10828205486177467, 0.19002403307240456, 0.1035533199319616, 0.3100740193622187, 0.1679660682566464, 0.28818603605031967, 0.21739580493886024, 1.056465266738087, 2.03733264002949, 3.1294807232916355, 4.525593733415008, 6.577861709520221, 3.4270622301846743, 3.593278373591602, 5.460027242079377, 5.930951647460461, 1.193870168644935, 0.4719180817482993, 1.969295390881598, 1.7328308732248843, 0.4875071014976129, 0.919789153849706, 1.4875135431066155, 0.9773488214705139, 0.6889973161742091, 0.4290490789571777, 0.6884752004407346, 1.9139229808934033, 1.0694661503657699, 2.409656373783946, 3.9527687709778547, 7.571393921971321, 16.660008430480957, 41.21769927442074, 57.52787187695503, 70.12142971158028, 74.96819123625755, 76.88407123088837, 56.502075120806694, 26.43245704472065, 5.333502106368542, 2.1715794363990426, 1.6531034326180816, 1.7581749195232987, 1.3437448139302433, 1.0858552646823227, 0.4880721727386117, 0.7078983332030475, 0.13306436216225848, 0.271332812262699, 0.19213290506741032, 0.9804645355325192, 0.3368649270851165, 2.698664115741849, 4.020825969055295, 3.137010969221592, 7.702603731304407, 5.786774083971977, 1.40169158577919, 1.0225035203620791, 0.1634831994306296, 0.1738310238579288, 0.10413549025543034, 0.2667942823609337, 0.33531039487570524, 0.07126053751562722, 0.1601583036244847, 3.814679430797696, 24.446527808904648, 39.56177853047848, 60.99667154252529, 105.78596636652946, 57.34069772064686, 34.597926288843155, 23.43342427164316, 23.990050703287125, 38.99640306830406, 64.89291027188301, 60.565360486507416, 66.58666178584099, 76.53104737401009, 77.49339893460274, 85.92264622449875, 78.81165459752083, 9.235436730086803, 0.433071578736417, 0.08968541485955939, 0.19705935555975884, 0.09700323586002924, 0.035326006764080375, 0.04759200463013258, 0.028469098433561157, 0.0673441425897181, 0.0783703790511936, 0.07775617021252401, 0.09926255603204481, 0.16868227045051754, 0.1505398767767474, 0.11681891279295087, 0.013311798047652701, 0.0785958360938821, 0.0023001202043815283, 0.05946820056124125, 0.1175516500370577, 0.06123917271906976, 0.060248502049944364, 0.012884675361419795, 0.06636855978285894, 0.02418483760266099, 0.02809890404023463, 0.07485009802621789, 0.05708110111299902, 0.019796466440311633, 0.07253324656630866, 0.03717712716024835, 0.03141198671073653, 0.06923248540260829, 0.018833839676517528, 0.09263929619919509, 0.08081596344709396, 0.015276914182322798, 0.03860311568132602, 0.07124471492716111, 0.02445040958264144, 0.1349955194746144, 0.21702051570173353, 0.20471064577577636, 0.22316554299322888, 0.20284884958527982, 0.15669318643631414, 0.12977449572645128, 0.17368994158459827, 0.21414778078906238, 0.19016995414858684, 0.2665966929635033, 0.1624909183010459, 0.08105621149297804, 0.1835262036183849, 0.2837877720594406, 0.18248983891680837, 0.11746922711608931, 0.25877831561956555, 0.1825639052549377, 0.14585391181753948, 0.14657473016995937, 0.12908561941003427, 0.179880210198462, 0.1863011679961346, 0.2697556297061965, 0.1726080387015827, 0.2053347326000221, 0.23640324594452977, 0.2938791993074119, 0.16555692331166938, 0.19849744479870424, 0.27899412147235125, 0.19502744427882135, 9.566050339490175, 91.99693188071251, 104.84817668795586, 93.26494663953781, 98.0751921236515, 94.22753378748894, 83.66292268037796, 61.21503822505474, 39.86138105392456, 26.92272763699293, 36.209761798381805, 56.14585563540459, 35.704932287335396, 57.910507544875145, 55.94242215156555, 54.48885574936867, 50.685115456581116, 15.865453965961933, 1.5325511014088988, 0.19403124460950494, 0.20176175166852772, 0.20425026188604534, 0.46423554711509496, 0.2566659258445725, 0.3303646930726245, 0.2902757457923144, 0.8113152463920414, 2.5745641998946667, 3.0424782168120146, 3.1807050621137023, 5.226696962490678, 4.9332615081220865, 5.05270809866488, 8.296179380267859, 11.081475522369146, 2.288431953638792, 0.8655394054949284, 2.8085297578945756, 2.744976030662656, 0.6983265874441713, 3.3200583094730973, 4.410230973735452, 2.8357731085270643, 4.773376537486911, 9.983349647372961, 7.669264320284128, 11.181057728827, 19.498273730278015, 23.784419037401676, 17.038071043789387, 16.939147152006626, 17.273498810827732, 37.83837340772152, 52.164763659238815, 62.51759313046932, 61.58378563821316, 66.61974281072617, 49.81066457927227, 26.535824798047543, 5.9518372267484665, 2.3284281324595213, 1.8014760897494853, 2.740081180818379, 1.5706344391219318, 1.6606320161372423, 0.6800585333257914, 1.338626726064831, 0.1772290063672699, 0.25758241885341704, 0.7017294235993177, 1.078311363235116, 0.7143479527439922, 7.858340749517083, 8.397466745227575, 6.4711154624819756, 10.297359097748995, 8.463774137198925, 1.0216314671561122, 0.7117060851305723, 0.21903838554862887, 0.2720278187189251, 0.26682215742766857, 0.40872545388992876, 0.50777085009031, 0.10915330654825084, 0.8026423898991197, 7.5684799533337355, 36.30061112344265, 57.90508523583412, 83.91313165426254, 134.20933037996292, 72.97460541129112, 51.58941753208637, 50.700823813676834, 35.48420213162899, 39.4692724943161, 60.51177196204662, 63.28570291399956, 78.58823418617249, 89.16920721530914, 89.30541470646858, 97.92819321155548, 94.5951184630394, 13.458870202302933, 0.7085369364358485, 0.17384350678185, 0.31735312251839787, 0.2047883189516142, 0.23804628668585792, 0.13479273504344746, 0.13248155359178782, 0.16162827552761883, 0.25749333144631237, 0.2583703421987593, 0.2366950732539408, 0.33628118340857327, 0.36097709729801863, 0.3114594012731686, 0.2660461381310597, 0.22745775408111513, 0.13483954971889034, 0.1685022996389307, 0.12831627944251522, 0.10718701596488245, 0.1732330903178081, 0.11044715196476318, 0.16290623898385093, 0.22722749534295872, 0.15069519344251603, 0.12253252221853472, 0.14400327752809972, 0.16976010636426508, 0.18558395648142323, 0.19243384595029056, 0.17931178444996476, 0.19471272913506255, 0.18381006026174873, 0.23593596008140594, 0.24991546932142228, 0.20994611171772704, 0.08867182667017914, 0.1890141481999308, 0.1704501107451506], [0.11758409673348069, 0.1317025805474259, 0.028493147729022894, 0.04486811114475131, 0.018604714568937197, 0.051206712814746425, 0.07692825252888724, 0.016291301108140033, 0.16484450607094914, 0.11347576015396044, 0.19882344058714807, 0.04264242139470298, 0.039680847694398835, 0.0585732409672346, 0.03795104246819392, 0.027211855740461033, 0.06460484582930803, 0.09108096419367939, 0.03896649715898093, 0.29885577445384115, 0.1484286447521299, 0.03188935465004761, 0.1264346975949593, 0.03910567953425925, 0.1758814591448754, 0.1314728709985502, 0.01343801881375839, 0.28226856607943773, 0.0990905262005981, 0.28634034446440637, 0.127870679134503, 0.6235163798555732, 3.684879820793867, 62.17004097998142, 89.39613103866577, 75.63361912965775, 71.46435365080833, 63.52014273405075, 43.140734285116196, 33.1979788094759, 23.198931254446507, 26.28047849982977, 38.8740648329258, 53.150730952620506, 37.47808814048767, 47.32973970472813, 37.611024007201195, 39.25862319767475, 19.003726467490196, 2.6277430588379502, 0.054109334014356136, 0.02475334498740267, 0.07582992591778748, 0.09850043716141954, 0.11591312897508033, 0.18910354730905965, 0.2159788372227922, 0.11888256573001854, 0.6174470367841423, 0.6892481027171016, 4.110350590199232, 5.243872990831733, 5.355863906443119, 8.934784512966871, 2.961331671103835, 3.0517784552648664, 6.1760698445141315, 7.387839071452618, 3.556004036217928, 2.249659546650946, 5.052733272314072, 10.68063598126173, 12.102126404643059, 9.535284340381622, 7.763026664033532, 8.75681821256876, 8.251889906823635, 8.097996264696121, 8.020088095217943, 6.281019262969494, 8.975771013647318, 15.445768386125565, 16.961636245250702, 40.63596948981285, 81.26694604754448, 97.61398047208786, 88.29703241586685, 80.19239410758018, 77.54778921604156, 83.17844107747078, 88.27165737748146, 74.28672060370445, 49.19202737510204, 28.033449836075306, 25.531648881733418, 20.51256850361824, 22.07870576530695, 17.93225046247244, 20.046075135469437, 16.588515266776085, 9.638281613588333, 4.941721279174089, 2.8391212038695812, 1.9014658243395388, 0.4753623594297096, 0.7155022595543414, 4.004405625164509, 9.558488745242357, 8.423614092171192, 2.7380060171708465, 1.1506668431684375, 0.5280383094213903, 0.07753033467452042, 0.04727003128209617, 0.14272779284510761, 0.28980466013308614, 0.48932040575891733, 0.10666800240869634, 0.052120860636932775, 0.02221999049652368, 0.1271490889484994, 10.071279779076576, 35.20383417606354, 41.570616737008095, 54.09577824175358, 53.07053245604038, 51.003785356879234, 41.156408563256264, 20.105731934309006, 11.478739455342293, 20.62495317310095, 32.97229751944542, 49.467782378196716, 50.2509393543005, 62.06817224621773, 71.043541431427, 48.02376106381416, 10.943984650075436, 0.16417424281826243, 0.31944096204824746, 0.22383929433999583, 0.03467902097327169, 0.041076712441281416, 0.126432768011, 0.05869337612239178, 0.143957665131893, 0.16573352477280423, 0.09673607753938995, 0.28316228999756277, 0.6984494277276099, 0.5207016749773175, 0.1750020735198632, 0.19361438025953248, 0.10856908047571778, 0.041702428279677406, 0.007732208896413795, 0.04793966741999611, 0.022009428357705474, 0.08963577260146849, 0.031255913054337725, 0.2231719551491551, 0.28223166649695486, 0.11866645232657902, 0.23125250358134508, 0.06539250942296349, 0.06825958917033859, 0.11338156677084044, 0.15384789614472538, 0.0710755646286998, 0.04448898871487472, 0.04331439900852274, 0.07831293682102114, 0.12659602565690875, 0.0433370716200443, 0.07809078233549371, 0.0309456730610691, 0.05676270491676405, 0.15744956850539893, 0.02133401831088122, 0.038716975977877155, 0.034298904065508395, 0.05026315739087295, 0.028272828203625977, 0.03537418699124828, 0.15893093979684636, 0.17137056682258844, 0.12318610941292718, 0.012893883558717789, 0.027336746206856333, 0.05139694010722451, 0.035681432418641634, 0.03338817012263462, 0.02683960188733181, 0.042722495418274775, 0.055822077265474945, 0.13370367785682902, 0.030864407890476286, 0.04182185839454178, 0.06515703338664025, 0.040023627152550034, 0.2117038142750971, 0.051303351574460976, 0.10452342568896711, 0.18482334417058155, 0.02608386734209489, 0.26080054929479957, 0.10042922702268697, 0.28433740662876517, 6.484735356643796, 75.22701814770699, 103.25617611408234, 86.29753410816193, 80.62642201781273, 78.36918354034424, 61.851834654808044, 48.34257535636425, 33.946641236543655, 32.24505074322224, 37.33703970909119, 43.33499886095524, 42.84917213022709, 38.49477298557758, 41.656488329172134, 44.06761094927788, 24.13453985005617, 3.922492233105004, 0.026436960797582287, 0.1763333973940462, 0.030918005795683712, 0.11446969627286308, 0.31778748671058565, 0.3380912815919146, 0.9985455684363842, 0.7332274771761149, 1.4797319169156253, 1.7249379842542112, 4.63140475563705, 5.623750481754541, 5.529599133878946, 4.469527266919613, 5.9475543815642595, 4.347432218492031, 8.72557818889618, 5.569328377023339, 4.635971635580063, 3.4429800510406494, 6.37464813888073, 12.427586540579796, 13.428423386067152, 10.868250913918018, 10.214221458882093, 11.654052548110485, 10.759727787226439, 10.476726572960615, 11.35521948337555, 9.306425470858812, 11.88602440059185, 15.138635616749525, 19.930846318602562, 46.0097399353981, 87.88884311914444, 109.55082714557648, 102.02498897910118, 94.44303542375565, 91.98401257395744, 99.92700755596161, 100.95582515001297, 86.61332756280899, 51.46878160536289, 31.989210471510887, 27.226660028100014, 24.980648048222065, 23.986268006265163, 22.769744284451008, 22.24743001163006, 19.828614704310894, 11.38305963948369, 6.989974770694971, 3.274102625437081, 3.0724139604717493, 1.1219510715454817, 0.794370174407959, 2.187373526394367, 5.61796291731298, 6.266506891697645, 2.816288941539824, 2.642292003147304, 0.49888657056726515, 0.5146434344351292, 0.07489700918085873, 0.5935298139229417, 0.1480614152387716, 0.6397588457912207, 0.666789764072746, 0.11309661174891517, 0.08354758640052751, 0.2756870520533994, 9.889596328139305, 34.377082139253616, 55.721623599529266, 48.376974910497665, 39.554650112986565, 43.68319317698479, 32.90300063788891, 26.512176766991615, 21.239173114299774, 41.776979863643646, 53.367828503251076, 61.66000194847584, 61.28385253250599, 71.33023604750633, 81.16701900959015, 66.52091771364212, 17.906770929694176, 0.13899925776058808, 0.14906747062923387, 0.1359081533155404, 0.08932592594646849, 0.0444661750952946, 0.05631610270938836, 0.018922394592664205, 0.08171258174115792, 0.09833743926719762, 0.13471414160449058, 0.2594044210854918, 0.4414654173888266, 0.2382109544123523, 0.15368113556178287, 0.0298483947335626, 0.039884541256469674, 0.017712560293148272, 0.07388220386928879, 0.05302300793118775, 0.0748202636896167, 0.03914061984687578, 0.013371546501730336, 0.1669589738594368, 0.09781576140085235, 0.12252319342223927, 0.13631553301820531, 0.06805524622905068, 0.05509998612978961, 0.07186409653513692, 0.05593392263108399, 0.00824120670586126, 0.08035560924327001, 0.04902273176412564, 0.022451933909906074, 0.05510854680323973, 0.06112948329246137, 0.06190320193127263, 0.059857193555217236, 0.20445130969164893, 0.20734905498102307, 0.24530165595933795, 0.20090663427254185, 0.09890020985039882, 0.20524424995528534, 0.2729435102082789, 0.07183014327893034, 0.3696789569221437, 0.40278420550748706, 0.2999974350677803, 0.13712704181671143, 0.08443627113592811, 0.13501965411705896, 0.18718990468187258, 0.1465197221841663, 0.1298120929277502, 0.14053115446586162, 0.10010734273237176, 0.3818703652359545, 0.21969013963826, 0.10407789959572256, 0.23913320648716763, 0.2240793642704375, 0.31936339277308434, 0.3868996328674257, 0.29062933463137597, 0.5558876681607217, 0.23432058660546318, 0.47160925925709307, 0.26196940219961107, 0.508001153357327, 10.705316606909037, 95.00968381762505, 108.65850582718849, 95.65391644835472, 91.14270731806755, 81.98881611227989, 60.70591874420643, 49.290985465049744, 40.35242110490799, 42.02627308666706, 55.33126674592495, 74.84322354197502, 55.509154200553894, 66.40827655792236, 57.667168602347374, 57.342992797493935, 32.0621969550848, 5.867373459041119, 0.47798139858059585, 0.16673322737915441, 0.1659855284378864, 0.31571312458254397, 0.3081169759389013, 0.32064938626717776, 0.855556569295004, 0.479462873772718, 0.9702711668796837, 1.7016085423529148, 9.115250129252672, 10.80106196925044, 15.769183281809092, 18.569573163986206, 8.79032576456666, 11.099316515028477, 20.861727967858315, 20.622589699923992, 4.874208876863122, 5.006024278700352, 9.498736951500177, 17.676117606461048, 16.531911604106426, 13.154750671237707, 10.049423351883888, 11.63657633587718, 11.29205547273159, 9.306991640478373, 10.305972285568714, 8.207558635622263, 12.524965815246105, 23.668147176504135, 23.384083919227123, 48.04539330303669, 87.43419751524925, 105.44383272528648, 98.78124743700027, 92.67362236976624, 91.60657122731209, 98.38001176714897, 96.68923169374466, 84.70773741602898, 59.31214973330498, 36.51629514992237, 32.95113265514374, 26.202404089272022, 27.465745098888874, 25.927984714508057, 25.857811979949474, 22.931402809917927, 14.078121073544025, 7.505429461598396, 3.2524867728352547, 4.384934306144714, 1.803864142857492, 1.9591221492737532, 13.41994509100914, 22.747623771429062, 19.27625924348831, 8.430829904973507, 2.235397486947477, 0.5503466748632491, 0.30151782848406583, 0.10958428654703312, 0.44449159875512123, 0.6661752064246684, 0.6235881603788584, 0.40477856411598623, 0.32937217445578426, 0.14816049195360392, 0.6722647952847183, 17.140055671334267, 51.80543594062328, 62.3032808303833, 71.25696837902069, 74.00603726506233, 73.88416260480881, 60.98005883395672, 31.24540038406849, 20.06621215492487, 37.07854337990284, 50.180654525756836, 66.63304209709167, 74.37561303377151, 84.86332386732101, 92.33987107872963, 81.73561289906502, 24.498267732560635, 0.39696134452242404, 0.48294791020452976, 0.406482060207054, 0.2076619295985438, 0.16097656596684828, 0.1863510551629588, 0.1018473673320841, 0.23228999634739012, 0.25530384737066925, 0.3671364183537662, 0.5122893420048058, 0.8323331654537469, 0.730939406203106, 0.3166079765651375, 0.3521151118911803, 0.251487783389166, 0.1101709617068991, 0.23300566419493407, 0.12431067836587317, 0.2180491472245194, 0.16867397323949262, 0.1168574376788456, 0.2716052992036566, 0.4072458192240447, 0.2543939446331933, 0.22669994708849117, 0.16920962574658915, 0.14857109257718548, 0.24213710858020931, 0.24194849916966632, 0.17875315505079925, 0.15713359171058983, 0.20824363979045302, 0.1952837672433816, 0.3038819250650704, 0.25600303953979164, 0.2673538913950324, 0.18871267297072336], [0.03987434785813093, 0.04648261259717401, 0.007804851702530868, 0.02926873101387173, 0.06549786470714025, 0.01511805747213657, 0.07190374206402339, 0.06792282481910661, 0.02519051449780818, 0.05621760858048219, 0.12314566236454993, 0.09089916769880801, 0.048281107301590964, 0.04370340313471388, 0.08494593363138847, 0.09213738172547892, 0.0379009400785435, 0.060944669967284426, 0.14528967178193852, 0.05801479710498825, 0.11604755418375134, 0.07254394833580591, 0.047548611255479045, 0.0322560386848636, 0.15246279624989256, 0.1269496144959703, 0.2435762813547626, 0.06024321795848664, 0.07878679811256006, 0.12077030740329064, 0.24410572950728238, 2.047588052228093, 55.485428273677826, 77.52408608794212, 72.57100626826286, 82.93061077594757, 71.79270923137665, 32.49853894114494, 15.230194553732872, 25.293297171592712, 30.777687281370163, 26.3539931550622, 54.56207022070885, 39.22018826007843, 38.72719891369343, 52.47168079018593, 31.45948849618435, 10.081459432840347, 0.7261555816512555, 0.16214255418162793, 0.09722230301122181, 0.09587438471498899, 0.11109269427834079, 0.33031140686944127, 0.3056668199133128, 0.29776529234368354, 1.0135977482423186, 0.8545622695237398, 0.9549019415862858, 2.739990698173642, 2.270664107054472, 4.7068786807358265, 8.119871690869331, 7.293686298653483, 3.342984616756439, 5.467851972207427, 9.91695486009121, 8.395920228213072, 11.533775702118874, 14.26842151209712, 17.222203463315964, 25.204668827354908, 34.76356320083141, 41.68982774019241, 45.70936605334282, 46.527306362986565, 48.637789115309715, 50.74033409357071, 48.97376328706741, 56.414204835891724, 57.26327687501907, 51.75166882574558, 50.09463474154472, 66.79980754852295, 76.61576002836227, 63.88568311929703, 52.03883461654186, 54.37461107969284, 57.39011026918888, 61.5610096603632, 56.76495261490345, 48.720058500766754, 47.51260869204998, 56.0765815526247, 51.20490476489067, 56.94268427789211, 55.79200342297554, 60.95932334661484, 62.60022349655628, 59.834598898887634, 48.549542650580406, 40.58923579752445, 31.146826073527336, 20.85163000971079, 15.197081230580807, 7.078709984198213, 5.4212118498981, 0.6726510683074594, 5.071616834029555, 4.878409076482058, 3.8576541747897863, 2.039243462495506, 1.5253963228315115, 0.6171123578678817, 0.42135766823776066, 0.19674265146022663, 1.112057352438569, 0.6358512304723263, 0.3781178587814793, 0.03683644798002206, 0.16196439421037212, 0.07175995837314986, 1.588165748398751, 12.108605057001114, 39.139894768595695, 60.3362175822258, 44.5927769690752, 39.78525213897228, 40.957671627402306, 39.3912398815155, 14.659032002091408, 13.71948016807437, 17.52141460776329, 44.38402757048607, 67.92229771614075, 59.03300151228905, 70.35361245274544, 67.12574645876884, 17.733019553124905, 0.7560023863334209, 0.21143337566172704, 0.06644095628871582, 0.136942068929784, 0.39813628303818405, 0.1371148557518609, 0.048864190466701984, 0.059928283881163225, 0.12642355053685606, 0.08574482591939159, 0.1829918721341528, 0.19924833497498184, 0.01999035623157397, 0.22687844844767824, 0.04858699830947444, 0.0531759719888214, 0.058430273638805375, 0.03314277157187462, 0.14344444032758474, 0.031894067287794314, 0.04890789554337971, 0.07944022945594043, 0.16147720394656062, 0.13708261685678735, 0.10871089005377144, 0.09475639861193486, 0.10797975584864616, 0.18313344422494993, 0.014922642567398725, 0.05477214239363093, 0.07141797672375105, 0.0376053018408129, 0.022878112213220447, 0.03304926096461713, 0.01188291051221313, 0.01759431019308977, 0.02410225697531132, 0.008042714671319118, 0.07248617213917896, 0.053386897780001163, 0.024691082508070394, 0.05692510909284465, 0.04660108905227389, 0.045659518873435445, 0.002436480331198254, 0.048379122745245695, 0.05694632709491998, 0.054624581171083264, 0.03380778412974905, 0.10661010746844113, 0.08773308407398872, 0.04490951185289305, 0.050617124725249596, 0.008607758081780048, 0.044066235423088074, 0.12883095885626972, 0.014590399750886718, 0.19887944305082783, 0.04879218729911372, 0.04395887634018436, 0.04790468257851899, 0.22897323447978124, 0.11487103489344008, 0.08150240551913157, 0.0842083798488602, 0.015115487785806181, 0.11899306409759447, 0.18322336283745244, 3.9893123600631952, 69.99295100569725, 90.40025755763054, 83.70072305202484, 94.11682292819023, 83.06622549891472, 48.91858644783497, 30.581300519406796, 37.16555491089821, 35.20951107144356, 24.414866007864475, 47.2376174479723, 44.00793135166168, 39.9265019595623, 56.59193269908428, 33.7934410572052, 12.551482692360878, 0.894813509657979, 0.045244751090649515, 0.06522571173263714, 0.19261415814980865, 0.31399911968037486, 0.26293398637790233, 0.626648539910093, 1.2634495412930846, 1.958433911204338, 2.150826849974692, 1.3033793424256146, 3.9871749747544527, 3.5745712649077177, 2.547301137819886, 4.082356542348862, 1.6190794645808637, 3.107681768015027, 4.920531716197729, 4.154079593718052, 8.637196831405163, 10.875041149556637, 15.938850827515125, 18.95870268344879, 27.024018801748753, 37.76571750640869, 45.76188303530216, 48.60885366797447, 49.761328026652336, 50.46482227742672, 55.16268499195576, 54.69964183866978, 62.06095643341541, 60.949751660227776, 57.787154763937, 55.04057854413986, 75.27904495596886, 89.34285029768944, 74.83186215162277, 60.361870005726814, 60.51852039992809, 64.44575786590576, 68.4256263077259, 67.36372008919716, 55.0695937871933, 54.32103015482426, 61.62298433482647, 57.94868789613247, 60.54619051516056, 59.08907890319824, 63.722614869475365, 66.20205402374268, 62.96695701777935, 50.6160731613636, 41.41856789588928, 33.687343150377274, 23.804656751453876, 17.784426994621754, 7.673905771225691, 3.6795712681487203, 2.5499237095937133, 0.8436898654326797, 4.686796283349395, 5.469181900843978, 4.578635087236762, 2.7621969440951943, 1.515159197151661, 1.2636510492302477, 0.8091230608988553, 2.7329128654673696, 1.0173473157919943, 0.7727116334717721, 0.1649005085346289, 0.0301337857672479, 0.0819489780406002, 1.6410055942833424, 14.258390050381422, 38.6881598085165, 57.13379122316837, 42.048429697752, 39.481462240219116, 32.62321785092354, 30.959372632205486, 22.70811729133129, 27.51708224415779, 34.18229699134827, 50.96890702843666, 77.64202415943146, 64.00771737098694, 78.87373566627502, 83.0484576523304, 29.781285747885704, 0.5817378591746092, 0.2370116882957518, 0.05998475389787927, 0.05166278853721451, 0.2261766736046411, 0.03130272030830383, 0.058092151157325134, 0.103188895736821, 0.12767717154929414, 0.026203974666714203, 0.1268876451649703, 0.14906260214047506, 0.2688732754904777, 0.04136111827392597, 0.059492802756722085, 0.028211120479681995, 0.004796065813934547, 0.09084148055990227, 0.09810208939597942, 0.01864256595581537, 0.0483162665477721, 0.049722027833922766, 0.2126521454192698, 0.08907073846785352, 0.0677694971091114, 0.016776543234300334, 0.018278143616043963, 0.1153710123617202, 0.0279521090851631, 0.033819780946942046, 0.029782774035993498, 0.05166897433809936, 0.030145910604915116, 0.07728216049144976, 0.07421164322295226, 0.06793829117668793, 0.021200734154263046, 0.24534536845749244, 0.23653275071410462, 0.16129516996443272, 0.10967756708851084, 0.11398627611924894, 0.09956579015124589, 0.21933410171186551, 0.13979302922962233, 0.10164121355046518, 0.12716136407107115, 0.32289663911797106, 0.18075653817504644, 0.1395652344217524, 0.25721066223923117, 0.17310686584096402, 0.19835670391330495, 0.09239496634108946, 0.15686963946791366, 0.2046360302483663, 0.14360000932356343, 0.3990177169907838, 0.15476737258723006, 0.22522605664562434, 0.1563172144233249, 0.489726776140742, 0.48335531959310174, 0.42532625840976834, 0.377626467961818, 0.19208834652090445, 0.32959752017632127, 0.36718097690027207, 6.315415017306805, 89.83746975660324, 96.87618926167488, 94.62943822145462, 104.26354005932808, 92.37813502550125, 50.53042195737362, 28.06444477289915, 41.05762526392937, 48.097724094986916, 41.837571412324905, 70.73770344257355, 54.29907873272896, 56.903755366802216, 73.80687475204468, 46.01791329681873, 18.736864887177944, 2.291486277244985, 0.2543036994757131, 0.31273607339244336, 0.3541404032148421, 0.32872258743736893, 0.34716644149739295, 0.7766664493829012, 1.2860379042103887, 3.3158450480550528, 3.5554445162415504, 3.035769439302385, 8.791377358138561, 12.947239056229591, 15.037472695112228, 23.525696620345116, 20.07386114448309, 16.0578528419137, 19.542579352855682, 20.79932391643524, 20.683173649013042, 18.719955794513226, 20.14754869043827, 22.720022052526474, 30.09416475892067, 42.17832952737808, 47.736089900135994, 54.83708046376705, 53.61737251281738, 58.09225559234619, 65.59373706579208, 57.93921120464802, 66.14906206727028, 65.18348067998886, 61.71638332307339, 64.42078560590744, 86.03608533740044, 96.72418221831322, 83.50649267435074, 66.64659976959229, 69.32775110006332, 70.86720809340477, 76.01584061980247, 74.00920629501343, 58.94620656967163, 63.05460311472416, 72.92849108576775, 65.31686872243881, 60.92970013618469, 60.27222141623497, 66.8381018936634, 69.18621629476547, 66.57631114125252, 55.59792123734951, 46.982358545064926, 39.39917765557766, 28.678446225821972, 20.81647429615259, 11.61015160381794, 10.555596090853214, 7.486543525010347, 14.309969432651997, 14.370705373585224, 11.23951569199562, 4.675790648907423, 2.1728295693174005, 1.2567794742062688, 0.8573664003051817, 1.0002322029322386, 3.3015383407473564, 1.2338308431208134, 0.9608574095182121, 0.14526722923619673, 0.29239713039714843, 0.24194667348638177, 3.309760387055576, 22.926016598939896, 60.60203991830349, 84.95310544967651, 65.52322804927826, 59.027803391218185, 58.78379948437214, 56.09521955251694, 23.850567787885666, 24.112478233873844, 34.190827533602715, 62.41737350821495, 87.61608615517616, 76.66442781686783, 88.76055434346199, 94.93754848837852, 38.67258444428444, 1.0460123838856816, 0.5681975232437253, 0.1930024498142302, 0.2538747084327042, 0.5140551785007119, 0.24121825554175302, 0.1295033298083581, 0.17735269269905984, 0.3479064517887309, 0.3075969679048285, 0.48741756880190223, 0.32011144794523716, 0.49196432169992477, 0.36439563729800284, 0.2350174039020203, 0.15079300850629807, 0.12247726932400838, 0.19618893507868052, 0.3982961713336408, 0.18738097802270204, 0.16710888769011945, 0.3450307482853532, 0.40216356224846095, 0.27956311125308275, 0.18246607534820214, 0.2507573616458103, 0.2081213190103881, 0.35105021903291345, 0.17158577480586246, 0.13581415289081633, 0.11683452758006752, 0.11176721003721468, 0.08284197465400212, 0.20936567801982164, 0.2847682678839192, 0.19147113198414445, 0.11627135623712093], [0.04787464044056833, 0.10481419172720052, 0.06576684128958732, 0.04509959813731257, 0.02276827064633835, 0.058851665089605376, 0.04274480808817316, 0.058710397279355675, 0.04611090793332551, 0.08599674052675255, 0.052185126914992, 0.03884178295265883, 0.013944789716333617, 0.04925567707687151, 0.04071670031407848, 0.05387535711633973, 0.0458738103043288, 0.04408841450640466, 0.08826090692309663, 0.1305988139938563, 0.02749663635768229, 0.02827494332450442, 0.029017131819273345, 0.07194736550445668, 0.13808280928060412, 0.04589475371176377, 0.085657801682828, 0.14214201568393037, 0.16229528817348182, 0.13514538877643645, 0.6265303306281567, 53.72978188097477, 81.62199899554253, 79.7861123085022, 78.57754915952682, 67.52279475331306, 39.68127451837063, 26.425925195217133, 27.186467684805393, 23.70055563747883, 32.748782113194466, 48.16947944462299, 74.58007246255875, 47.23225213587284, 51.121404245495796, 18.30553863197565, 6.391300270333886, 0.9711452387273312, 0.25610314041841775, 0.10125202388735488, 0.18157569109462202, 0.2887717983685434, 0.1337745678029023, 0.10831044943188317, 0.7188907277304679, 0.9359507553745061, 1.8089147843420506, 3.089551040902734, 3.6704382207244635, 5.234024869278073, 2.9438533214852214, 4.101225854828954, 1.5543067152611911, 0.7490742893423885, 9.3268883228302, 9.940430000424385, 13.863246403634548, 23.68828609585762, 41.2257282435894, 44.29919712245464, 49.71655122935772, 53.90795812010765, 55.45583926141262, 59.32576820254326, 54.31572183966637, 53.73629093170166, 60.955230966210365, 71.10357820987701, 67.24769711494446, 69.15592432022095, 65.66382810473442, 65.99840015172958, 58.12988497316837, 32.97832779586315, 54.8123399913311, 47.53131128847599, 57.4915724247694, 52.02181912958622, 61.487715393304825, 65.50723850727081, 51.78048647940159, 28.216822296380997, 34.64556813240051, 56.113637164235115, 60.976703613996506, 72.59987711906433, 76.87203347682953, 77.3391880095005, 76.08916908502579, 74.03501451015472, 69.92581620812416, 67.59913265705109, 59.16975237429142, 53.538868725299835, 48.870587423443794, 29.795840866863728, 19.324822537600994, 8.192419297993183, 3.9823259599506855, 0.9895990672521293, 4.67425980605185, 2.902444093488157, 1.8971251510083675, 1.3567137555219233, 2.3055082373321056, 0.26540043996647, 1.5670131146907806, 1.590252430178225, 0.18282230623299256, 0.07521970241214149, 0.045674135471927, 0.047836341909714974, 0.06618824758334085, 0.16640936897601932, 7.374572083353996, 23.20852193981409, 46.234919652342796, 57.65559442341328, 53.98481659591198, 47.491276636719704, 50.250669568777084, 30.06227497011423, 18.39028548449278, 34.885050281882286, 45.91084264218807, 60.849482640624046, 58.618432357907295, 61.56677395105362, 69.96859431266785, 23.37211836129427, 0.3507634828565642, 0.07418810229864903, 0.11615524723310955, 0.1064785172638949, 0.10269706705003045, 0.04106699401745573, 0.12714356736978516, 0.10212530905846506, 0.1373473706189543, 0.12850810977397487, 0.1363049351493828, 0.1514562955708243, 0.014097889215918258, 0.07844046005629934, 0.04317139828344807, 0.11154689607792534, 0.13549848779803142, 0.03730622374860104, 0.08978296275017783, 0.04547702475974802, 0.0246945334947668, 0.14726544701261446, 0.05075422908703331, 0.046647981653222814, 0.03342167809023522, 0.007768636287437403, 0.04412999332998879, 0.04585073693306185, 0.031120536041271407, 0.03138303924060892, 0.011307739569019759, 0.07150111210648902, 0.005366222158045275, 0.032381854980485514, 0.10155879805097356, 0.04590799733705353, 0.04698877586633898, 0.03065581800910877, 0.08384673870750703, 0.045930369378766045, 0.0429541011544643, 0.013854402623110218, 0.06068815404432826, 0.037834410250070505, 0.0422536250698613, 0.06932690143003128, 0.03792158662690781, 0.016639130881230813, 0.05196821570280008, 0.05874648421013262, 0.05673566847690381, 0.05925731187744532, 0.02927259760326706, 0.044265776668908074, 0.11253537741140462, 0.20886100275674835, 0.01815015097236028, 0.03995729399321135, 0.017241751083929557, 0.08704756968654692, 0.06640235718805343, 0.047410293482244015, 0.06211358224391006, 0.13462686503771693, 0.10323509442969225, 0.13212808349635452, 1.6966089606285095, 66.767098903656, 92.32214882969856, 89.90507572889328, 88.85329976677895, 76.82897418737411, 58.182785734534264, 36.788466945290565, 19.958398640155792, 26.3676705211401, 47.08479344844818, 35.65025322139263, 64.96263653039932, 40.69096013903618, 44.34758372604847, 20.67446831613779, 6.887038294225931, 1.0130414343439043, 0.06365207664202899, 0.21156408271053806, 0.3709056379739195, 0.5627033743076026, 0.4990346438717097, 1.5773041499778628, 2.2107353853061795, 1.4450967754237354, 1.411729697138071, 1.613512288313359, 2.0594201423227787, 2.5884500797837973, 1.0060455347411335, 0.6495297839865088, 0.7917486713267863, 1.1654221639037132, 4.407846601679921, 6.788906659930944, 13.650550916790962, 24.269223622977734, 40.716107189655304, 45.90627148747444, 51.53481066226959, 56.7600204795599, 55.326813384890556, 61.73533670604229, 59.057867377996445, 59.63837742805481, 69.01672258973122, 74.84136164188385, 69.14891749620438, 68.79044473171234, 66.30483850836754, 67.4712923169136, 63.11408132314682, 42.13758051395416, 62.091639786958694, 54.200101643800735, 63.586251586675644, 59.92325194180012, 68.87714847922325, 74.6198183298111, 60.21402753889561, 35.216077119112015, 41.85386873781681, 60.03152713179588, 67.03999266028404, 72.00090005993843, 79.04883787035942, 79.32137444615364, 80.04896700382233, 78.0283722281456, 76.0131199657917, 71.49832382798195, 65.11084377765656, 59.28488239645958, 52.0818255096674, 34.18406009674072, 22.778875194489956, 11.708293687552214, 6.0909168887883425, 2.5855572475120425, 3.1843580910936, 5.727372821420431, 6.785564739257097, 4.7338206600397825, 1.687822169624269, 1.0472284373827279, 1.4126655156724155, 1.5893603092990816, 1.143753114156425, 0.540050296112895, 0.18116773251676932, 0.0673851759347599, 0.018811447225743905, 0.2865190536249429, 8.587912525981665, 25.710233598947525, 44.987864568829536, 50.54424561560154, 41.6990802437067, 39.80816870927811, 43.54708068072796, 31.161191202700138, 21.779452823102474, 48.87383624911308, 59.555811658501625, 72.65169113874435, 70.93261018395424, 69.0628369152546, 85.8889876306057, 38.53084444999695, 0.5147390230558813, 0.18998710380401462, 0.07362767690210603, 0.1386480437940918, 0.08456841052975506, 0.07950081839226186, 0.08500267082126811, 0.15808125492185354, 0.06658508878899738, 0.03651458224339876, 0.16021399438614026, 0.11314928196952678, 0.032079229422379285, 0.05319987656548619, 0.02275098788231844, 0.12001992930890992, 0.10038153661298566, 0.04085033513547387, 0.02125961986166658, 0.04850888355576899, 0.03839123251964338, 0.04371789356810041, 0.021718886819144245, 0.01643770458031213, 0.04441540106199682, 0.10451511363498867, 0.040609348652651533, 0.04536028493021149, 0.04367765432107262, 0.02966933861898724, 0.09604688209947199, 0.07898545620264485, 0.056108134376700036, 0.04349946837464813, 0.03342625714140013, 0.04779147908266168, 0.11613461552769877, 0.1712957286508754, 0.26133816107176244, 0.13263397588161752, 0.10035103434347548, 0.11601691832765937, 0.16697782441042364, 0.1964183774543926, 0.1020916155539453, 0.14261406613513827, 0.14924132614396513, 0.1021795452106744, 0.16694895486580208, 0.2214037289377302, 0.17087130923755467, 0.08824094315059483, 0.1861691547674127, 0.17638441262533888, 0.21108517481479794, 0.37355258187744766, 0.12742509366944432, 0.1818095418275334, 0.17988482635701075, 0.21806952659972012, 0.5380212049931288, 0.16316542663844302, 0.2740245818858966, 0.24388315941905603, 0.37367948913015425, 0.3034262463916093, 3.182679293677211, 85.15840843319893, 101.11073523759842, 100.91680124402046, 100.50336062908173, 85.98550245165825, 57.07154296338558, 39.10376250743866, 40.26553876698017, 37.80510999262333, 46.60295270383358, 63.15765358507633, 87.42699310183525, 65.30506655573845, 71.9675986468792, 31.572272144258022, 11.915534567087889, 2.262023608200252, 0.4669560823822394, 0.24820884136715904, 0.5411886912770569, 0.5102800810709596, 0.9178014448843896, 1.575866520870477, 2.762699229642749, 3.261366421356797, 4.7775073908269405, 7.185528902336955, 11.74538729712367, 13.794188909232616, 10.390193816274405, 12.937365286052227, 9.496630914509296, 7.120933793485165, 17.95819167047739, 14.969321452081203, 21.210946328938007, 31.923743784427643, 49.8879524320364, 51.47340215742588, 55.11405520141125, 60.11098466813564, 59.892378598451614, 65.35650819540024, 59.49229806661606, 57.653576731681824, 65.60283377766609, 75.87204873561859, 78.61143574118614, 72.79385671019554, 68.36294487118721, 73.68177026510239, 69.52676922082901, 49.5211087167263, 70.88208809494972, 62.506756111979485, 71.04734882712364, 64.20077741146088, 76.23866826295853, 83.03865417838097, 68.98486509919167, 40.217357352375984, 48.863797187805176, 69.64016273617744, 68.18012908101082, 73.4328456223011, 83.97542551159859, 83.22250351309776, 82.55443096160889, 80.07438763976097, 74.22283843159676, 72.95182183384895, 65.27245670557022, 60.99236637353897, 51.73382878303528, 33.351471573114395, 22.1704613417387, 14.919855706393719, 8.467546384781599, 6.31556510925293, 15.70846064016223, 7.374375443905592, 9.273977112025023, 5.090417750179768, 4.369606403633952, 1.2747058435343206, 2.2238841047510505, 3.171920645982027, 1.5799757628701627, 0.539464830653742, 0.20338997914223, 0.1475593523355201, 0.2394764794735238, 0.33353906648699194, 14.535625074058771, 38.64860773086548, 66.08489111065865, 79.40332844853401, 77.1755763888359, 68.24638232588768, 71.72307416796684, 45.27453638613224, 29.075576215982437, 52.67628461122513, 63.435156494379044, 80.26140600442886, 79.53689888119698, 79.30566608905792, 97.17381209135056, 50.76303027570248, 1.2930791638791561, 0.40385242318734527, 0.2507080533541739, 0.31629476055968553, 0.22122674155980349, 0.24952851352281868, 0.23558099084766582, 0.4128969769226387, 0.2446617910754867, 0.33288282982539386, 0.37313389184419066, 0.2883815474342555, 0.26533109368756413, 0.1940290626953356, 0.1407950621796772, 0.3196323470911011, 0.34239728178363293, 0.2069758586003445, 0.1353018483496271, 0.17260575288673863, 0.15627869695890695, 0.35895195440389216, 0.17084132647141814, 0.15548324823612347, 0.10697299541789107, 0.17452166648581624, 0.180071298382245, 0.1035893289372325, 0.1069173937139567, 0.12401991232763976, 0.13402367709204555, 0.15484002884477377, 0.20007007056847215, 0.110763900593156, 0.161596808466129, 0.23057067766785622], [0.03762794476642739, 0.10046021168818697, 0.0075047392419946846, 0.0459401397529291, 0.025604172769817524, 0.07467337039997801, 0.06908922121510841, 0.04539932189800311, 0.043716984437196516, 0.06645397355896421, 0.03075348649872467, 0.038190355408005416, 0.014665836279164068, 0.027566298049350735, 0.04523554474872071, 0.0445913754083449, 0.03413848884520121, 0.06381120794685557, 0.11829333758214489, 0.043959169488516636, 0.05511259521881584, 0.027012295940949116, 0.10476215233211406, 0.006233234325918602, 0.07929418221465312, 0.11700082060997374, 0.19971728324890137, 0.14266246900660917, 0.2074784113210626, 1.4987593959085643, 46.42475746572018, 81.71751827001572, 80.15582486987114, 76.85593754053116, 56.8680676817894, 47.74116262793541, 23.427629582583904, 24.796086251735687, 43.34951788187027, 48.36523354053497, 32.96450033783913, 52.56993971765041, 51.20575591921806, 48.4839391708374, 20.99967386573553, 2.7062064735218883, 0.3451884991955012, 0.05171421937120613, 0.0710482313297689, 0.021543252005358227, 0.34214824670925736, 0.24186895578168333, 0.3729147801641375, 0.8243753237184137, 0.7821859500836581, 1.036298917606473, 0.6703708344139159, 1.1107218428514898, 1.214594969060272, 6.618088725954294, 14.35198662802577, 19.264367781579494, 23.62779524177313, 30.30081856995821, 37.709681913256645, 40.403927341103554, 50.166025310754776, 57.327531427145004, 64.37970221042633, 65.77958509325981, 64.7074194252491, 62.36562788486481, 64.48871836066246, 63.882354497909546, 68.14154595136642, 66.57378047704697, 68.49244952201843, 72.84704625606537, 74.58085522055626, 72.6074843108654, 76.76733389496803, 80.4334607720375, 81.7599467933178, 58.169220462441444, 36.83484345674515, 50.713549330830574, 53.033944219350815, 57.4846225976944, 59.560363814234734, 59.248073771595955, 33.992295786738396, 27.804840803146362, 49.18723203241825, 65.07919907569885, 76.71102091670036, 77.50770896673203, 72.38481625914574, 73.20773050189018, 71.84739589691162, 69.0459506213665, 68.59238415956497, 70.89238554239273, 73.43210846185684, 77.89461180567741, 72.28260934352875, 61.41515828669071, 50.92913456261158, 36.85280129313469, 19.775786139070988, 12.096675597131252, 5.541746132075787, 8.469610624015331, 4.255327535793185, 2.6434711273759604, 2.648413237184286, 0.48390723997727036, 1.619930500164628, 1.2186039914377034, 0.7107600546441972, 0.35835782065987587, 0.4264294164022431, 0.04863382411713246, 0.06542857780004852, 0.05468190836836584, 0.08516818459611386, 5.082016875967383, 15.487598441541195, 41.36042341589928, 55.36160811781883, 54.85886849462986, 55.102108642458916, 51.57363697886467, 36.612255200743675, 14.633846003562212, 19.582739397883415, 37.67790801823139, 60.38447119295597, 63.74859407544136, 62.18777842819691, 73.35678890347481, 32.16536141932011, 0.5385028291493654, 0.22481941909063607, 0.0601145740802167, 0.055671321097179316, 0.1025303138885647, 0.13508892618119717, 0.04947733432345558, 0.07052651635603979, 0.08955457422416657, 0.1052748502115719, 0.09253248630557209, 0.06276094281929545, 0.05515011078387033, 0.0287144654430449, 0.10910260301898234, 0.12814962276024744, 0.06384298671036959, 0.03066755878535332, 0.13556557794800028, 0.05891493688977789, 0.11567782363272272, 0.029107124646543525, 0.039474363657063805, 0.026594440823828336, 0.05695829422620591, 0.04553787344775628, 0.017218937464349438, 0.05641516087052878, 0.07765911213937216, 0.02143422309018206, 0.007498589156966773, 0.0562718744185986, 0.03181710657372605, 0.02179883096687263, 0.05851567257195711, 0.018496279371902347, 0.07566208179923706, 0.05616165064566303, 0.0037143579766052426, 0.06603129819268361, 0.04602776141837239, 0.036211785991326906, 0.04194161134364549, 0.02781119750579819, 0.02195174492953811, 0.04002809488156345, 0.04729911233880557, 0.031469796304008923, 0.009290167508879676, 0.06739470511092804, 0.11407042082282715, 0.0789291197725106, 0.062445248040603474, 0.022493386568385176, 0.03697937077959068, 0.04861217566940468, 0.03051519401196856, 0.09960180657799356, 0.04468259649001993, 0.012213554928166559, 0.10266784869600087, 0.15886061388300732, 0.06006369614624418, 0.11622304242337123, 2.289015934802592, 58.900118842720985, 94.41113233566284, 91.304821819067, 85.32240763306618, 71.21472984552383, 67.9382948577404, 32.17706099152565, 26.878382116556168, 44.21550661325455, 43.64534340798855, 37.391593381762505, 60.833918675780296, 54.500600919127464, 43.09782698750496, 21.096591465175152, 3.596978662535548, 0.6808758457191288, 0.0784458925772924, 0.4616204561898485, 0.732025554170832, 1.0828581755049527, 1.2004062929190695, 1.4568032347597182, 1.899307540152222, 1.3798032165504992, 0.7313671801239252, 0.7120601192582399, 0.17902840278111398, 1.6742165246978402, 6.413197070360184, 15.680153109133244, 22.00536400079727, 25.291112288832664, 31.3350622728467, 41.16860210895538, 43.68089810013771, 52.30010859668255, 60.368911027908325, 64.98651444911957, 67.75850370526314, 65.99051177501678, 63.941616117954254, 65.29264122247696, 65.56461542844772, 68.96555453538895, 67.48836860060692, 69.6330039203167, 77.66305983066559, 79.30668443441391, 75.19366353750229, 75.93498095870018, 81.23397141695023, 82.34688609838486, 63.11831809580326, 46.006038933992386, 57.99686551094055, 57.17182718217373, 61.97873644530773, 67.30311334133148, 67.74411007761955, 40.30351012945175, 33.518035635352135, 51.99343845248222, 70.03515154123306, 78.7727902829647, 78.52850899100304, 74.2372852563858, 76.30388796329498, 74.34041932225227, 73.06314826011658, 73.10373768210411, 73.7059673666954, 77.97601103782654, 79.68503013253212, 73.70376348495483, 65.01730039715767, 54.06949505209923, 38.97095963358879, 22.203867249190807, 11.27162966877222, 3.301279954612255, 0.9995204536244273, 3.3996191527694464, 3.449250189587474, 2.160080303438008, 2.5319829722866416, 1.963443704880774, 2.9939313093200326, 1.938958887476474, 0.8622260426636785, 0.7791578688193113, 0.1203568272467237, 0.0855856723501347, 0.15444274235051125, 0.0736201366817113, 5.748943313956261, 18.062503673136234, 37.589277774095535, 51.07290364801884, 51.33746065199375, 47.08097845315933, 39.35550279915333, 36.931441873312, 21.559266038239002, 33.93246799707413, 59.52581226825714, 68.89370039105415, 74.33130741119385, 70.19433259963989, 89.11088034510612, 48.51994223892689, 1.4359678840264678, 0.25650582974776626, 0.079332321183756, 0.043908848165301606, 0.04965211381204426, 0.08873759579728357, 0.032801261186250485, 0.055652819355600514, 0.06265963966143318, 0.10498557589016855, 0.047749343648320064, 0.018360852263867855, 0.11394651184673421, 0.06787997321225703, 0.06782195210689679, 0.11254427576204762, 0.029569631078629754, 0.03335097739181947, 0.11831039213575423, 0.04482014242967125, 0.1285577891394496, 0.07274737101397477, 0.014881755796523066, 0.006164977148728212, 0.03404088529350702, 0.06998429584200494, 0.05023020974476822, 0.0699831751990132, 0.01744992350722896, 0.02474395867466228, 0.004246928483553347, 0.02631130591908004, 0.04451087836059742, 0.06419181838282384, 0.06834990854258649, 0.07662991658435203, 0.22777790174586698, 0.11034412702429108, 0.10813342494657263, 0.25974189047701657, 0.2544259757269174, 0.1358071024878882, 0.16009536950150505, 0.15053212875500321, 0.1065667363582179, 0.13346754130907357, 0.30408242368139327, 0.08992643473902717, 0.07471324599464424, 0.15913247741991654, 0.34254870959557593, 0.24496607162291184, 0.21876439946936443, 0.21187810023548082, 0.10036088264314458, 0.1669957843841985, 0.08185143014998175, 0.19697360781719908, 0.16916920838411897, 0.2408157888567075, 0.2675161248771474, 0.3360998025164008, 0.44504117395263165, 0.44840823858976364, 3.989449627697468, 74.49010089039803, 104.83693689107895, 100.14991879463196, 98.81929859519005, 77.24287077784538, 68.38752955198288, 35.72771966457367, 39.88260671496391, 64.22488331794739, 65.19867226481438, 48.194090723991394, 67.32652768492699, 67.87961080670357, 68.69386911392212, 30.796615965664387, 5.1706423703581095, 1.0275007272139192, 0.16553825087612495, 0.4532452009152621, 0.8331030991394073, 2.019203337840736, 2.292999546043575, 1.8526084022596478, 3.4244550950825214, 3.487800071015954, 4.0333714708685875, 4.018087740987539, 4.55297838896513, 3.605974679812789, 9.120244961231947, 18.70212335139513, 25.424200147390366, 27.17270102351904, 36.103386506438255, 45.58028697967529, 45.07044933736324, 55.1173610240221, 63.1696343421936, 67.45821341872215, 69.15941253304482, 67.34361156821251, 64.2591954767704, 66.30508169531822, 66.43629625439644, 69.93874311447144, 68.74163255095482, 70.5284258723259, 76.21897011995316, 78.57004076242447, 79.57820266485214, 78.5224749147892, 85.42625606060028, 87.46850967407227, 69.50425162911415, 52.97978952527046, 66.70757129788399, 65.0476835668087, 70.96603319048882, 74.09753635525703, 75.17320543527603, 46.094148606061935, 41.32704600691795, 57.15417332947254, 75.20627126097679, 81.21543601155281, 79.24352422356606, 78.29095333814621, 80.83036467432976, 77.8353425860405, 76.73545360565186, 75.29798313975334, 78.15863683819771, 80.05016013979912, 79.5157416164875, 76.09717905521393, 64.9416996538639, 54.07106436789036, 40.319549068808556, 22.74397786706686, 16.334533095359802, 11.867384500801563, 16.882410496473312, 12.866183705627918, 13.24372859671712, 8.517204020172358, 5.536024114117026, 5.5534404795616865, 3.715575048699975, 3.6275033745914698, 1.699667084030807, 1.0131271672435105, 0.228329777601175, 0.17341445636702701, 0.24072630068985745, 0.48547394340857863, 8.883545212447643, 28.176065683364868, 59.9766580760479, 76.05605766177177, 75.52128955721855, 76.11830592155457, 75.00426650047302, 54.80887457728386, 24.36570044606924, 34.49407786130905, 54.285270273685455, 76.73547640442848, 85.85776090621948, 80.42603597044945, 97.13703766465187, 58.72182860970497, 2.428233101963997, 0.44871899066492915, 0.2660957432817668, 0.20989227632526308, 0.1719375082757324, 0.24275139905512333, 0.18081788410199806, 0.25899523054249585, 0.36373043549247086, 0.2921263058669865, 0.1846441303496249, 0.17764717689715326, 0.23989497654838488, 0.19738456467166543, 0.23556166532216594, 0.28124232427217066, 0.1952723678550683, 0.13976594083942473, 0.3796587948454544, 0.09431104321265593, 0.27274865191429853, 0.12343530033831485, 0.09054352311068214, 0.23055930796545, 0.08988791727460921, 0.126126068062149, 0.15532523015281186, 0.2948388853110373, 0.15177798690274358, 0.17089240107452497, 0.12062569992849603, 0.1451568867196329, 0.09315009418060072, 0.17375649738823995, 0.21011980395996943], [0.07204351073596627, 0.06529081292683259, 0.08283404109533876, 0.07408980483887717, 0.04980175675882492, 0.018813148599292617, 0.03383297262189444, 0.030334826151374727, 0.012096231585019268, 0.007615174527018098, 0.017954591348825488, 0.02364523315918632, 0.0377806305186823, 0.03259698503825348, 0.012506359089456964, 0.04197737915092148, 0.08020017383387312, 0.06316416649497114, 0.015158128808252513, 0.10241099880659021, 0.05839216806634795, 0.058831089045270346, 0.0405090102867689, 0.10057850260636769, 0.03771233808947727, 0.04285631577658933, 0.08012226317077875, 0.07884750579250976, 0.8921050862409174, 49.38560038805008, 80.52682936191559, 76.95230796933174, 74.26479578018188, 67.30306774377823, 37.975614443421364, 17.978047505021095, 23.584880344569683, 35.85000470280647, 28.758135549724102, 34.195227697491646, 58.111638352274895, 43.49999740719795, 31.79050013422966, 7.936450783163309, 0.6397201947402209, 0.09304276478360407, 0.1400420197751373, 0.18257555697346106, 0.15692304441472515, 0.340664426330477, 0.11862600527820177, 0.72371581569314, 0.7719556521624327, 1.4995985571295023, 1.6830711183138192, 0.3767568786861375, 3.7204012647271156, 14.254842940717936, 38.822140619158745, 55.61414636671543, 62.495162934064865, 62.58672282099724, 66.5679743885994, 68.4041878581047, 69.02189031243324, 72.36213907599449, 70.45653373003006, 68.70325461030006, 66.77502527832985, 66.832265406847, 64.89560052752495, 67.29714766144753, 64.33780565857887, 68.74252930283546, 68.17824438214302, 70.89869320392609, 73.0003148317337, 73.45268815755844, 75.7507212460041, 77.54500016570091, 73.33110228180885, 74.85482811927795, 69.63257074356079, 78.46482440829277, 44.54421937465668, 40.57825818657875, 55.46821519732475, 54.488794952631, 68.1622776389122, 45.19265078008175, 33.37399296462536, 45.84323287010193, 63.48181799054146, 73.33168745040894, 77.10040122270584, 69.79409247636795, 71.0215862095356, 67.36578717827797, 65.93398600816727, 66.17071330547333, 67.12947025895119, 65.66276416182518, 73.93143206834793, 74.94438171386719, 78.35763216018677, 75.79649358987808, 75.50320252776146, 60.51203414797783, 42.87192150950432, 31.577996537089348, 14.935222081840038, 10.718488600105047, 6.359625644981861, 5.9390319138765335, 1.791890391614288, 1.210738888476044, 0.635757363634184, 2.2830811282619834, 2.315968838520348, 0.25138319993857294, 0.3921898396220058, 0.23025985137792304, 0.05411275531514548, 0.0467903144453885, 0.07955659079016186, 0.034907646986539476, 2.232900308445096, 13.607783261686563, 29.109633788466454, 46.89840964972973, 67.84076169133186, 52.56601072847843, 31.699926294386387, 28.87684118002653, 18.413737826049328, 18.03260687738657, 23.87592952698469, 39.012954980134964, 61.11581414937973, 63.766810297966, 75.35167425870895, 27.464759051799774, 0.6745684810448438, 0.07701823793468066, 0.10193367168540135, 0.07933140834211372, 0.04268273856723681, 0.11782227418734692, 0.023852305348555092, 0.018184549517172854, 0.022080520539020654, 0.06443502017646097, 0.05930903957050759, 0.03214410797227174, 0.058792471390916035, 0.013481576388585381, 0.04271311096090358, 0.05517250880075153, 0.05445705246529542, 0.065390936069889, 0.047040544377523474, 0.06329859170364216, 0.08372434371267445, 0.054450139359687455, 0.07837156648747623, 0.056188163871411234, 0.03054422682907898, 0.027588375087361783, 0.06273589533520862, 0.01385474957714905, 0.08604372589616105, 0.02628877617098624, 0.055176609166665, 0.04056425947055686, 0.0663549784803763, 0.07633621906279586, 0.06444347323849797, 0.08280701207695529, 0.02245405088615371, 0.10470108842127956, 0.04885506576101761, 0.03665112999442499, 0.03218927507987246, 0.0032088981242850423, 0.028404192053130828, 0.05413147599028889, 0.03870191409077961, 0.011414360214985209, 0.0379412201436935, 0.025251146107621025, 0.057293555728392676, 0.013266022378957132, 0.028481625886342954, 0.06936252451851033, 0.07195790400146507, 0.034419399162288755, 0.028166469164716545, 0.07176586586865596, 0.06472271372331306, 0.09663057382567786, 0.03300053154816851, 0.05519167105376255, 0.01416276405507233, 0.0700925751880277, 2.4467628076672554, 63.9388270676136, 95.0991690158844, 87.59600043296814, 82.64044314622879, 79.74665522575378, 49.809372648596764, 28.652107939124107, 24.674770161509514, 23.449351117014885, 31.843224205076694, 44.80970732867718, 50.318343937397, 40.06547950208187, 34.977780506014824, 8.995294366031885, 0.7478430960327387, 0.08508582104695961, 0.10609737248159945, 0.1894198209629394, 1.099479196127504, 1.334128836169839, 1.0104432050138712, 2.25137562956661, 1.3337669055908918, 0.8758245629724115, 0.5130509636364877, 0.6303798803128302, 4.440711988136172, 16.868339851498604, 43.86299192905426, 60.16134716570377, 69.1515089571476, 66.50865957140923, 70.7823434472084, 73.25746223330498, 72.11876973509789, 71.95100873708725, 73.36912304162979, 72.0447801053524, 70.33349633216858, 69.4126309454441, 67.33542680740356, 69.61861029267311, 65.70374876260757, 70.59719458222389, 71.9099785387516, 72.99324721097946, 74.77155178785324, 76.1451704800129, 78.39617729187012, 80.3676787018776, 75.75573697686195, 77.70084500312805, 75.1711155474186, 80.12370139360428, 51.45762540400028, 47.68439367413521, 62.30532892048359, 62.87583030760288, 73.17425429821014, 52.45344556868076, 42.19038628041744, 48.10349978506565, 64.89549413323402, 76.65700301527977, 79.69480320811272, 71.6310203075409, 75.51737576723099, 71.1753411591053, 69.35511723160744, 70.61914220452309, 70.43443411588669, 72.24306866526604, 78.79403874278069, 78.05756226181984, 78.69511485099792, 77.67106220126152, 76.84947028756142, 65.09356990456581, 47.32532814145088, 31.193312779068947, 16.38429332524538, 10.300878658890724, 2.834241078235209, 0.8170480106491596, 0.46792927547357976, 0.7261587283574045, 2.779251616448164, 3.3267402509227395, 3.6982904886826873, 2.533207219094038, 1.142780128866434, 0.5544794874731451, 0.23170433792984113, 0.08398615114856511, 0.12832174164941534, 0.041939184520742856, 2.2279059514403343, 15.481848400086164, 31.115420758724213, 43.95501159131527, 45.54101228713989, 42.956083193421364, 23.018328845500946, 19.736576043069363, 14.24721010029316, 19.9500884860754, 36.20824947953224, 51.163798570632935, 73.64964678883553, 71.29396319389343, 86.24607726931572, 42.81353384256363, 2.052992074750364, 0.04111058035050519, 0.006241058881641948, 0.04707015606982168, 0.09040921664563939, 0.07809073038515635, 0.00900447219464695, 0.028244134919077624, 0.06588216361706145, 0.0941959212650545, 0.07112069462891668, 0.05896291302633472, 0.023830000100133475, 0.026057086943183094, 0.0037102733813298983, 0.021761795942438766, 0.05810470458527561, 0.047224363224813715, 0.056684122610022314, 0.12321323491050862, 0.030050973218749277, 0.05418538930825889, 0.056715303944656625, 0.07577911106636748, 0.015263540681189625, 0.01691838991973782, 0.031574594977428205, 0.027871012753166724, 0.036138053619652055, 0.10576071945251897, 0.040867107672966085, 0.03756652462470811, 0.029196956056694034, 0.12802767305402085, 0.13168172619771212, 0.16387662675697356, 0.14648917538579553, 0.15400293079437688, 0.13925461593316868, 0.08960904044215567, 0.1688054224359803, 0.1364891362027265, 0.14182976447045803, 0.11445982570876367, 0.1178268383955583, 0.08292175552924164, 0.12361596134724095, 0.11677138565573841, 0.1666877485695295, 0.10383787419414148, 0.19497015047818422, 0.17888620728626847, 0.21405781764769927, 0.19472283718641847, 0.1333754407824017, 0.16066814423538744, 0.15942745143547654, 0.1936023574671708, 0.26062077144160867, 0.1403881871374324, 0.2895357948727906, 0.36416200920939445, 5.374528504908085, 80.75537949800491, 105.56289553642273, 98.99555593729019, 94.99551057815552, 89.3827785551548, 55.224921852350235, 30.176456943154335, 36.42960660159588, 54.160465970635414, 41.10075294971466, 48.147657215595245, 78.51800635457039, 60.90611860156059, 46.70554339885712, 12.696362268179655, 1.2396507058292627, 0.45795789803378284, 0.24239104182925075, 0.7306141674052924, 1.7180710402317345, 2.482072887942195, 2.389015881344676, 3.6377008398994803, 2.952436348423362, 5.887564150616527, 5.278033157810569, 2.497706199064851, 6.686427108943462, 19.007205180823803, 48.04816335439682, 64.9417832493782, 71.55881658196449, 72.33224228024483, 72.847760617733, 73.54714348912239, 72.45766595005989, 73.56108114123344, 74.8090709745884, 72.49451637268066, 71.12259238958359, 68.632882386446, 66.95293933153152, 69.19535860419273, 65.642199665308, 71.72068029642105, 72.14830935001373, 74.63702380657196, 79.46378320455551, 80.30587121844292, 78.27880159020424, 79.29879605770111, 78.5542032122612, 81.19607985019684, 76.78499534726143, 83.62853452563286, 57.86557875573635, 55.6374429166317, 71.84685632586479, 67.61879280209541, 84.30113643407822, 58.705504685640335, 48.87538656592369, 53.220711797475815, 67.09165468811989, 79.9745061993599, 82.8645171225071, 77.94495150446892, 80.18195226788521, 73.71392413973808, 71.69278979301453, 71.79604545235634, 73.0678828060627, 74.64312627911568, 81.45397961139679, 81.28104329109192, 81.15409970283508, 78.38302999734879, 78.320781737566, 65.1126828789711, 47.46047168970108, 36.66598051786423, 18.280038200318813, 20.87392721325159, 13.572141174227, 14.254963584244251, 6.583827389404178, 6.385578727349639, 6.797829531133175, 8.5597731359303, 6.7416338715702295, 2.401081183925271, 1.5015146043151617, 0.4345246445154771, 0.2547719649737701, 0.2147505382890813, 0.21476729598362, 0.27650525502394885, 4.256471749395132, 24.807706028223038, 45.83309881389141, 67.4818329513073, 90.66530853509903, 74.47493210434914, 46.427706107497215, 42.57446967065334, 30.920352526009083, 29.348918348550797, 39.34054680168629, 54.54666964709759, 82.4980191886425, 83.7276104092598, 96.5092733502388, 53.82285788655281, 2.2458082158118486, 0.36377490498125553, 0.14573963591828942, 0.12422579151461832, 0.21452053188113496, 0.2466545466450043, 0.1927259107469581, 0.17309781163930893, 0.18293500877916813, 0.21235904161585495, 0.1785689836833626, 0.1434915221761912, 0.16762962302891538, 0.09434023188077845, 0.14979360275901854, 0.10889733981457539, 0.16317977977450937, 0.13110917410813272, 0.1693096969393082, 0.2288679385674186, 0.13733387837419286, 0.07411690807202831, 0.17321231018286198, 0.14203045604517683, 0.07452550489688292, 0.2682061441009864, 0.14196177769917995, 0.15961889585014433, 0.18576596077764407, 0.21896805963478982, 0.20214113756082952, 0.11961251249886118, 0.11958969145780429, 0.1992304640589282], [0.047018684417707846, 0.0771665784122888, 0.10203074460150674, 0.03286717503215186, 0.024725484763621353, 0.014477326130872825, 0.028854208139819093, 0.014687546881759772, 0.014580894694518065, 0.0510110270261066, 0.009914002930599963, 0.02963182490930194, 0.021403787613962777, 0.04480123250687029, 0.03946756558434572, 0.09494733836618252, 0.047568430309183896, 0.013353789690881968, 0.13781624467810616, 0.015380862168967724, 0.03450735850492492, 0.04483363467443269, 0.03689087709062733, 0.03426063893130049, 0.03158920786518138, 0.056888346807681955, 0.03994154561951291, 1.9117718213237822, 54.60795655846596, 92.40937694907188, 73.25857937335968, 79.44088563323021, 55.746576860547066, 31.710881106555462, 19.70979318022728, 32.32969880104065, 43.277610540390015, 34.96698148548603, 48.24288010597229, 58.97377789020538, 52.304881140589714, 37.562154829502106, 5.745620392262936, 0.6172335951123387, 0.1345313951605931, 0.12245275618624873, 0.0741456811374519, 0.030284870335890446, 0.5780392920132726, 0.35555306647438556, 0.36415898124687374, 1.1076292837969959, 1.225885113235563, 0.6238917878363281, 0.47972663305699825, 7.957750065252185, 38.40993493795395, 71.01920753717422, 74.29818078875542, 77.61114701628685, 74.16511952877045, 74.905114620924, 69.52068954706192, 78.43154579401016, 76.28175035119057, 69.24813777208328, 74.64543655514717, 74.97995540499687, 73.75018939375877, 66.87335640192032, 70.16733884811401, 72.19573840498924, 69.26938623189926, 72.29280039668083, 71.84764668345451, 69.42383274435997, 67.13567912578583, 71.30587175488472, 67.1298198401928, 73.76884639263153, 72.55514591932297, 68.37742209434509, 66.80632799863815, 73.47742483019829, 73.38034763932228, 30.797807201743126, 35.961046144366264, 57.2355991601944, 53.224948570132256, 36.31356842815876, 42.56119318306446, 65.28768628835678, 73.61500784754753, 73.93133327364922, 69.20506328344345, 67.97544166445732, 60.18871709704399, 62.123197093605995, 64.15373593568802, 69.77140009403229, 69.50742825865746, 72.18848079442978, 73.44979271292686, 71.53621539473534, 73.25042501091957, 71.01909354329109, 68.07127252221107, 69.91197735071182, 61.09368033707142, 50.629539638757706, 33.4590096026659, 18.113132156431675, 10.520713962614536, 12.035435233265162, 6.061511216685176, 3.9380110753700137, 1.1760860541835427, 3.4205538919195533, 1.7785247275605798, 1.7140387441031635, 0.4744648060295731, 0.6690785475075245, 0.3668869973625988, 0.11045490740798414, 0.03335829125717282, 0.07237735844682902, 0.04380767488328274, 0.4471112909959629, 7.124566873535514, 25.611894875764847, 45.5762629956007, 51.441670060157776, 53.82701866328716, 43.622153252363205, 62.14512951672077, 96.44125699996948, 52.44647674262524, 27.299618013203144, 45.16532264649868, 70.73538556694984, 63.50482575595379, 80.29020845890045, 23.8403482362628, 0.15447195328306407, 0.08225504716392606, 0.11550027222256176, 0.07421829286613502, 0.11110454637673683, 0.02981575693411287, 0.0828078729682602, 0.022196842910489067, 0.02513327079213923, 0.027864231378771365, 0.039387309734593146, 0.06590632794541307, 0.0898288274765946, 0.04093258365173824, 0.06250304650166072, 0.031753100047353655, 0.03447988419793546, 0.08139891302562319, 0.06908663854119368, 0.051207239739596844, 0.09271745919249952, 0.03102306422078982, 0.028667934639088344, 0.047003017680253834, 0.03646878802101128, 0.031035944193718024, 0.0249127768620383, 0.087222924339585, 0.05666788812959567, 0.05215492521529086, 0.03879258227243554, 0.036318840793683194, 0.016685669106664136, 0.06490333020337857, 0.08853375751641579, 0.02965780564409215, 0.03040400544705335, 0.025496913876850158, 0.06893916637636721, 0.028600632977031637, 0.058575396906235255, 0.03839023062027991, 0.0614426436368376, 0.021678356279153377, 0.03884087011101656, 0.04665583728638012, 0.014429958555410849, 0.08185308513930067, 0.011453549323050538, 0.027843056050187442, 0.02368250938161509, 0.0356342986196978, 0.030447100107267033, 0.06470435298979282, 0.09868794077192433, 0.016536323018954135, 0.0580092309974134, 0.05756781640229747, 0.023856613515818026, 0.048260750190820545, 2.362951417453587, 66.435916274786, 107.00431779026985, 84.39645811915398, 93.2958921790123, 70.74224799871445, 54.27453204989433, 36.2014402449131, 38.662522584199905, 35.620945394039154, 49.1739821434021, 50.62320537865162, 42.796757742762566, 48.09976078569889, 40.13703726232052, 7.620171904563904, 0.27748135733418167, 0.14384959358721972, 0.1108045554428827, 0.15420351846842095, 0.30177743174135685, 0.968960237223655, 1.366765284910798, 2.160829813219607, 1.3258579862304032, 1.3689310499466956, 0.35809275519568473, 0.3052584605757147, 8.893497828394175, 42.35807128250599, 74.49478223919868, 77.65088528394699, 81.72146245837212, 75.39127573370934, 78.25737074017525, 71.42704725265503, 78.89310702681541, 77.7728359401226, 73.28279927372932, 78.63856628537178, 76.97618588805199, 74.68584358692169, 70.38240730762482, 72.22175180912018, 72.66334891319275, 71.35925129055977, 75.17486974596977, 74.2116442322731, 70.96870064735413, 70.58358371257782, 73.69123175740242, 70.82133695483208, 76.84052556753159, 76.93216904997826, 72.11851134896278, 68.95746096968651, 76.51357591152191, 77.05453008413315, 37.3402239382267, 45.44518142938614, 63.493091985583305, 60.08289657533169, 44.37430389225483, 46.683375388383865, 65.05497917532921, 74.03333500027657, 76.81449696421623, 71.37499004602432, 71.51866033673286, 62.9268653690815, 64.3210257589817, 67.19398319721222, 73.62932547926903, 72.20057934522629, 75.69644495844841, 75.06649196147919, 73.88613849878311, 75.38133546710014, 71.84052586555481, 68.74407202005386, 70.5527825653553, 63.00701446831226, 54.638928696513176, 36.23476825654507, 21.364927366375923, 14.27023971453309, 13.522568084299564, 7.661757348105311, 5.863337125629187, 3.5437171580269933, 2.9104505013674498, 3.0867610406130552, 2.0587029308080673, 1.7537760618142784, 1.954781475942582, 0.7333262718748301, 0.5015609145630151, 0.19181443465640768, 0.02758201302640373, 0.047028989138198085, 0.35024849174078554, 7.857396025210619, 26.029583662748337, 42.81377702951431, 42.17133790254593, 38.99722762405872, 34.193305000662804, 47.10751622915268, 75.40198355913162, 46.122616678476334, 34.522671326994896, 52.12867319583893, 80.98039582371712, 71.61898255348206, 94.29076999425888, 38.52501556277275, 0.5269073357339948, 0.04107327258680016, 0.16047877783421427, 0.14240231656003743, 0.05055327776062768, 0.07460744542186148, 0.056081691654981114, 0.023888744799478445, 0.013747070443059783, 0.0405957228213083, 0.005740389824495651, 0.06342719847452827, 0.0953410254442133, 0.07229584094602615, 0.08876153005985543, 0.08573133367463015, 0.0355254107125802, 0.08261605005827732, 0.03302672936115414, 0.02021259606408421, 0.06368161411955953, 0.017842621673480608, 0.041825023654382676, 0.048974818710121326, 0.03818569100985769, 0.03676785869174637, 0.03315066802315414, 0.08827713769278489, 0.028550803326652385, 0.05602906225249171, 0.053092361631570384, 0.02440943932015216, 0.05198103630391415, 0.18604549812152982, 0.13976188871311024, 0.14554882975062355, 0.12266475809155963, 0.169021847541444, 0.17160677758511156, 0.12574804772157222, 0.15079223667271435, 0.11733737715985626, 0.11600406432989985, 0.153931551030837, 0.15853975375648588, 0.07849335292121395, 0.12458051583962515, 0.16792459704447538, 0.17284687666688114, 0.1538140987395309, 0.09232694850652479, 0.24431108176941052, 0.0875678523152601, 0.24181802960811183, 0.21463603974552825, 0.11114302673377097, 0.2262691006762907, 0.1332861158880405, 0.08550223268684931, 0.07962770338053815, 4.507071152329445, 84.80969354510307, 116.67625799775124, 93.86565640568733, 101.82808354496956, 75.65576434135437, 49.95491623878479, 32.003847286105156, 49.0170581638813, 62.88311071693897, 53.58664356172085, 71.23679146170616, 78.2336676120758, 72.61773616075516, 53.26551899313927, 9.757997039705515, 1.1408136156387627, 0.3133538371184841, 0.3337744460441172, 0.34207996912300587, 0.39164979360066354, 1.919254451058805, 2.581435893662274, 3.943953006528318, 4.653556142002344, 5.213837502524257, 3.888404262252152, 3.2495134323835373, 10.689587350934744, 43.35439682006836, 77.59042292833328, 80.12802556157112, 82.99165830016136, 77.19947710633278, 77.38867655396461, 70.52413210272789, 77.52098545432091, 78.46418604254723, 75.5614686012268, 80.71852147579193, 80.68883746862411, 76.62982687354088, 70.71484386920929, 72.48655959963799, 73.86916860938072, 73.39876905083656, 76.393251568079, 79.38370630145073, 76.13448545336723, 74.60077375173569, 78.01749721169472, 74.9722570180893, 81.21599078178406, 80.57887136936188, 75.8948627114296, 71.7071758210659, 79.94974672794342, 78.84700790047646, 41.362144723534584, 49.830134734511375, 72.871775329113, 65.76772212982178, 50.892101749777794, 50.90185962617397, 65.8475786447525, 79.60378289222717, 78.7398612499237, 74.95173051953316, 74.70044240355492, 65.66515803337097, 68.71397763490677, 70.94027817249298, 79.50886398553848, 77.57260948419571, 79.81688305735588, 77.92969152331352, 76.04525104165077, 76.38642713427544, 73.38463380932808, 71.81275695562363, 73.01345452666283, 65.64864411950111, 54.37887825071812, 38.55530373752117, 22.718112654983997, 16.282692477107048, 18.50279364734888, 9.228514451533556, 8.27941657975316, 5.80933584831655, 8.534735329449177, 7.697396110743284, 5.701964059844613, 2.9026350332424045, 1.89471596153453, 1.0792191582731903, 0.6276682508178055, 0.26065802725497633, 0.16573852684814483, 0.1627761998679489, 1.37831725878641, 13.068797383457422, 39.984061270952225, 67.60795578360558, 70.6319247186184, 76.29042908549309, 59.941042587161064, 73.18077474832535, 107.30976060032845, 61.30207255482674, 41.093981713056564, 58.41238461434841, 91.5501518547535, 81.1608937382698, 105.34596517682076, 46.85253091156483, 0.7699186645913869, 0.3170641005272046, 0.1859824452549219, 0.17674806498689577, 0.17758168978616595, 0.18496034463169053, 0.16936198866460472, 0.14305582211818546, 0.18565058649983257, 0.13783696544123814, 0.1505984619143419, 0.105207856540801, 0.18398548912955448, 0.17023978609358892, 0.1452678081113845, 0.16553612833376974, 0.28572988347150385, 0.2207802061457187, 0.15941280144033954, 0.18804533377988264, 0.1439662295160815, 0.12839377450291067, 0.22244325518840924, 0.18063917494146153, 0.13452953979140148, 0.14622773160226643, 0.08590260651544668, 0.20560137141728774, 0.17062359518604353, 0.15528882038779557, 0.1410909416154027, 0.10627996307448484, 0.14520647702738643], [0.006593828111363109, 0.02253489859867841, 0.038070743466960266, 0.03414903476368636, 0.05161466768186074, 0.014677281124022556, 0.03675624408060685, 0.07189643190940842, 0.037355309395934455, 0.015496398791583488, 0.02377119417360518, 0.016608689838903956, 0.06787788035580888, 0.033057617547456175, 0.05277239208226092, 0.021584563655778766, 0.023369742375507485, 0.03398512773856055, 0.0512819443247281, 0.06375171738909557, 0.04208418162306771, 0.061404181833495386, 0.052637692278949544, 0.10611395206069574, 0.021806076183565892, 0.07396866407361813, 1.0104753845371306, 38.07252064347267, 82.47466564178467, 73.28244209289551, 68.72973158955574, 34.77700687944889, 35.16527384519577, 29.16459023952484, 26.039081253111362, 16.231305934488773, 32.145233899354935, 22.10469637066126, 33.75700481235981, 58.114769384264946, 33.10637332499027, 5.222188029438257, 0.6672401586547494, 0.10850119622773491, 0.07592790425405838, 0.06971778318984434, 0.30221509106922895, 0.3220524312928319, 0.5873201158829033, 0.7843842508736998, 0.9948224807158113, 1.4846475468948483, 0.3913502034265548, 0.6609375437255949, 15.210198126733303, 60.07063463330269, 82.73570403456688, 74.44448813796043, 74.2264786362648, 73.98505479097366, 76.91382363438606, 72.12394505739212, 69.45425391197205, 74.59266498684883, 69.88449722528458, 70.95655649900436, 71.6494569182396, 64.42575573921204, 69.08760398626328, 71.14993572235107, 72.70928844809532, 68.4052138030529, 70.7404924929142, 71.92599847912788, 65.6138151884079, 62.77325101196766, 60.7427691668272, 63.081524670124054, 65.36360621452332, 65.14027699828148, 65.8715857565403, 59.29872125387192, 62.254860028624535, 70.5930832028389, 72.13634759187698, 66.35036006569862, 22.817336730659008, 44.242732152342796, 34.40721832215786, 42.181289568543434, 63.7248757481575, 68.90662729740143, 70.3211697936058, 63.80793169140816, 64.94213283061981, 59.93072994053364, 55.546449199318886, 60.37057913839817, 67.0284640789032, 72.28087663650513, 74.47743996977806, 70.44201090931892, 74.72956404089928, 71.07482135295868, 67.6164673268795, 66.70665934681892, 63.05218264460564, 63.24152648448944, 64.21412989497185, 63.962454199790955, 63.80098566412926, 53.45973417162895, 39.99730356037617, 36.922892332077026, 36.75581529736519, 24.697306752204895, 13.41249369084835, 8.348134942352772, 3.6039593629539013, 1.969738898333162, 1.7143714637495577, 0.9470538783352822, 0.8247336326166987, 0.1433422465925105, 0.13620818877825513, 0.03550840439856984, 0.02289623360411497, 0.03467035268840846, 0.025202294236805756, 1.569629986770451, 8.05233221501112, 35.55442616343498, 50.00808298587799, 51.1032260209322, 64.0901729464531, 110.21378517150879, 132.09367990493774, 69.53446000814438, 38.693726509809494, 52.45217643678188, 71.84580758213997, 69.46097195148468, 73.71911466121674, 18.071731477975845, 0.2142186855780892, 0.08711955058970489, 0.06267233038670383, 0.015089307598827872, 0.02585268648545025, 0.07917266295407899, 0.048638347507221624, 0.08249514678027481, 0.0515888260997599, 0.04129596512939315, 0.041306767088826746, 0.08657822807435878, 0.08340407730429433, 0.021735156551585533, 0.07974761960213073, 0.026771912453114055, 0.024118112960422877, 0.02230525769846281, 0.03846693529339973, 0.03729723634023685, 0.05618744769890327, 0.018744600129139144, 0.06072215182939544, 0.060070089748478495, 0.005349416687749908, 0.00651934524285025, 0.03077359313465422, 0.02749790728557855, 0.046485050552291796, 0.009851196828094544, 0.02122901554685086, 0.004621562311513117, 0.13743610179517418, 0.021506077828234993, 0.011715377168002306, 0.02441096628899686, 0.08157480944646522, 0.045117060872144066, 0.021213393338257447, 0.012572617106343387, 0.007889790504123084, 0.051867406073142774, 0.03228784342354629, 0.012204377344460227, 0.04115786628972273, 0.06331776879960671, 0.07401298513286747, 0.04390709298604634, 0.07956595669384114, 0.0031493607184529537, 0.020353836043796036, 0.04429257933225017, 0.024688887606316712, 0.01648199224291602, 0.04897374630672857, 0.08605934810475446, 0.06187852181028575, 0.051385310653131455, 1.0387819656170905, 43.985672146081924, 96.3153013586998, 84.87976178526878, 77.1160639822483, 47.57375121116638, 50.81413373351097, 33.05464670062065, 22.365746162831783, 26.781633608043194, 46.16518199443817, 32.51895144581795, 42.37551994621754, 59.16151441633701, 35.460092425346375, 6.410901993513107, 0.429887498030439, 0.07506244874093682, 0.08620687964139506, 0.1925875892629847, 0.6247549946419895, 1.1854562326334417, 1.6832994623109698, 1.4217738644219935, 2.538585592992604, 1.5133863547816873, 0.21623866312438622, 1.3068344257771969, 16.814884319901466, 63.78314942121506, 83.44571113586426, 79.64924365282059, 77.12332159280777, 76.58580243587494, 79.66164618730545, 77.16820478439331, 73.13147619366646, 74.57552790641785, 75.16114488244057, 75.09544640779495, 74.04104858636856, 68.50323334336281, 74.7204065322876, 73.44989910721779, 73.94919231534004, 69.21142414212227, 71.71330109238625, 72.8932973742485, 70.30225440859795, 67.49704733490944, 64.92177352309227, 63.86669933795929, 67.93070286512375, 69.48263838887215, 68.89904290437698, 61.780197098851204, 64.65930640697479, 73.71067151427269, 77.37772554159164, 67.35859036445618, 29.39282689243555, 52.80461512506008, 42.75183655321598, 44.74513739347458, 64.16896551847458, 71.86648607254028, 74.53462690114975, 68.86359840631485, 68.26945468783379, 62.13346414268017, 57.98887833952904, 62.97044523060322, 70.12723580002785, 76.04215040802956, 78.32146570086479, 73.56304183602333, 76.31758242845535, 73.63356605172157, 69.05627846717834, 69.03848022222519, 65.01141831278801, 65.03475666046143, 64.95907992124557, 64.81794029474258, 63.95920157432556, 52.610012367367744, 43.57174135744572, 40.193563029170036, 40.97509369254112, 27.737441919744015, 17.479442059993744, 9.353579990565777, 4.0064470656216145, 1.9371324917301536, 2.4491410050541162, 2.946080002002418, 1.1955032497644424, 0.6104771420359612, 0.461454838514328, 0.2152252901578322, 0.04343906126450747, 0.05035101654357277, 0.08831158818793483, 1.5667670778930187, 9.50760092586279, 34.42756623029709, 48.191586658358574, 53.231336027383804, 69.85789105296135, 118.59789848327637, 128.91685277223587, 71.9281567633152, 50.34808874130249, 58.47028590738773, 80.75024217367172, 75.02128198742867, 87.62351095676422, 29.27473872900009, 0.297068296931684, 0.010317315663996851, 0.09522458247374743, 0.013225553066149587, 0.018284800680703484, 0.04287379335437436, 0.03979372464527842, 0.014687893835798604, 0.07370791790890507, 0.07158602122217417, 0.01815777097363025, 0.018319883856747765, 0.06262293303734623, 0.08247125704656355, 0.08809477716567926, 0.00690526620928722, 0.06019906017172616, 0.02409538097708719, 0.009361902575619752, 0.047441727147088386, 0.06958350641070865, 0.02914873130066553, 0.059976527190883644, 0.024688399644219317, 0.04235759253788274, 0.059272937796777114, 0.01770755450706929, 0.012111562500649597, 0.013211703662818763, 0.04684771214670036, 0.058415516032255255, 0.020066610049980227, 0.1833807278308086, 0.2142682165140286, 0.16955185972619802, 0.1008494607231114, 0.12345024719252251, 0.16983996145427227, 0.22282755409833044, 0.10322040732717142, 0.11105471116025001, 0.1255119705456309, 0.07924372359411791, 0.14896299107931554, 0.15566375339403749, 0.1364040415501222, 0.1528421969851479, 0.10644761423463933, 0.14000982540892437, 0.14115834346739575, 0.10988419584464282, 0.11490021614008583, 0.15159814967773855, 0.18086270982166752, 0.14440034137805924, 0.10613341859425418, 0.11402931326301768, 0.18807080428814515, 1.3712304015643895, 56.596059277653694, 104.78699997067451, 94.31619063019753, 89.1846951842308, 52.01438672840595, 50.56422494351864, 42.88770206272602, 41.00487269461155, 29.57688521593809, 46.445302963256836, 32.591280564665794, 51.10516391694546, 79.91918116807938, 50.531660690903664, 9.929486587643623, 1.3332470459863544, 0.22029222920536995, 0.19255353952758014, 0.3870227700099349, 0.8530065498780459, 1.0889395116828382, 2.1402030950412154, 4.444850916042924, 5.779841830953956, 6.7203939612954855, 4.641327448189259, 3.575010853819549, 17.67446279525757, 65.35055011510849, 87.92742624878883, 79.17854771018028, 80.61318352818489, 79.73674535751343, 82.9826831817627, 77.48842120170593, 72.98950061202049, 75.8195811510086, 75.35399973392487, 76.09993770718575, 78.63289698958397, 70.27217522263527, 77.95395702123642, 76.21561869978905, 78.58954131603241, 71.3038882613182, 74.25652742385864, 75.50634875893593, 73.68647441267967, 67.7224512398243, 68.3307757973671, 67.82525852322578, 71.20489597320557, 71.56642377376556, 72.53626093268394, 65.23741498589516, 67.86232933402061, 77.52065867185593, 80.8394081890583, 72.48981222510338, 38.8620612770319, 57.9968237131834, 49.59670566022396, 52.68193110823631, 68.60625341534615, 74.07398521900177, 78.44959482550621, 71.11104860901833, 72.84517675638199, 65.61981126666069, 61.29534691572189, 65.43898656964302, 73.5519540309906, 78.48641484975815, 80.88139593601227, 73.43916848301888, 78.65064963698387, 76.55329138040543, 72.73179844021797, 70.67033305764198, 66.08928367495537, 65.44824287295341, 65.91880962252617, 66.7033839225769, 67.18541845679283, 55.72116382420063, 45.1294981688261, 41.2999002635479, 42.811934128403664, 29.0700988098979, 18.695447109639645, 13.00620999187231, 8.668892830610275, 10.009007770568132, 7.586442064493895, 5.985127240419388, 1.6729331435635686, 0.8168757136445493, 0.4384327644947916, 0.2447561180451885, 0.20529467146843672, 0.21697721880627796, 0.21713179332436994, 3.263896373100579, 15.50315385684371, 53.357443660497665, 69.03415605425835, 65.91588377952576, 74.53214943408966, 113.61532464623451, 137.1377268433571, 76.51037648320198, 53.946472853422165, 67.08039209246635, 92.22343772649765, 84.31397214531898, 98.32954287528992, 32.98903942108154, 0.37621365627273917, 0.13756155443843454, 0.15519830805715173, 0.10707946392358281, 0.12800046592019498, 0.11585443251533434, 0.16903430077945814, 0.11736658809240907, 0.1506539003457874, 0.17733684042468667, 0.10306692376616411, 0.2178318315418437, 0.21193123800912872, 0.17908787849592045, 0.19903119740774855, 0.09902802252327092, 0.17706926650134847, 0.13915442599682137, 0.1166665053460747, 0.13162774237571284, 0.12834262568503618, 0.07434709259541705, 0.1732870889827609, 0.2270857006078586, 0.11990097045782022, 0.11855980570544489, 0.09280391939682886, 0.12110537965781987, 0.20231889677233994, 0.06660922343144193, 0.09462821486522444, 0.06525363874970935], [0.087311143433908, 0.05154501341166906, 0.0430246571340831, 0.018510081463318784, 0.02600502713903552, 0.040926516594481654, 0.023287482727027964, 0.03949964862840716, 0.05054688415839337, 0.042718239201349206, 0.017038727310136892, 0.04443827776412945, 0.07943136821268126, 0.05133905629918445, 0.042654592616599984, 0.07193118668510579, 0.025127938461082522, 0.0812733342172578, 0.07139540801290423, 0.05034383255406283, 0.059584216796793044, 0.08593063743319362, 0.061579265602631494, 0.12070932512870058, 0.12426840563421138, 0.11741934737074189, 18.482130356132984, 86.70567780733109, 80.96589580178261, 79.74068954586983, 72.41206839680672, 40.56703358888626, 73.01729992032051, 163.02274346351624, 98.07017639279366, 42.5130345672369, 21.48910090327263, 63.549097180366516, 55.121411606669426, 22.701731733977795, 6.2301551923155785, 0.44512640219181776, 0.0576800402632216, 0.10917380466707982, 0.17381714569637552, 0.3720926586538553, 0.2182508332771249, 0.21315900259651244, 0.7335867953952402, 0.9202729153912514, 1.1086395545862615, 0.4105613788124174, 1.6169943264685571, 25.021309666335583, 69.04870927333832, 77.06738099455833, 71.55713707208633, 70.64190298318863, 68.14814239740372, 71.28678157925606, 71.92023798823357, 71.48672685027122, 68.38829711079597, 67.56992742419243, 71.66158586740494, 68.02259713411331, 59.12199653685093, 65.65259590744972, 62.807547971606255, 69.11155790090561, 67.6819758117199, 69.97462838888168, 69.27995726466179, 71.68612495064735, 65.14026939868927, 60.79904414713383, 58.81997354328632, 59.13289055228233, 54.41894710063934, 58.36625508964062, 57.41055317223072, 57.778183445334435, 63.63754503428936, 64.06887128949165, 70.51914677023888, 61.79109871387482, 29.845574498176575, 29.251805059611797, 31.588730961084366, 48.24757665395737, 55.76877906918526, 70.27462989091873, 70.67079663276672, 65.29470831155777, 59.422723799943924, 51.57754696905613, 56.61126606166363, 59.20099809765816, 67.22413077950478, 66.21916070580482, 70.59635102748871, 70.0820030272007, 64.25726518034935, 63.23982797563076, 63.609791323542595, 68.00375014543533, 66.85633331537247, 66.8609082698822, 63.05177226662636, 63.64343471825123, 62.946894094347954, 61.39821119606495, 64.53616261482239, 65.28292134404182, 68.5912898182869, 64.9420340359211, 47.317956537008286, 29.433862790465355, 8.729000855237246, 1.0991787747479975, 1.6916474956087768, 3.5872317105531693, 1.0896284622140229, 0.4104529065079987, 0.4856305959401652, 0.19553857622668147, 0.02426748502330156, 0.02639184007421136, 0.0852844791370444, 0.043986480523017235, 0.32644781575072557, 2.935490207746625, 16.30883887410164, 33.19846138358116, 37.57109194993973, 51.431832388043404, 71.59108445048332, 56.46125391125679, 21.461561881005764, 40.3189866989851, 55.29300659894943, 60.02615422010422, 69.02968749403954, 62.06518940627575, 8.26882179826498, 0.14068751013837755, 0.11299323799903505, 0.026767357521748636, 0.035108230949845165, 0.03193365715560503, 0.012821689288102789, 0.08183410842320882, 0.03870763233862817, 0.035959351880592294, 0.08286061740363948, 0.06385273853084072, 0.0694639167340938, 0.07139923749491572, 0.043521402549231425, 0.03038066490262281, 0.009331548735644901, 0.043529952090466395, 0.03142456982459407, 0.04330062845838256, 0.02290548633027356, 0.08557721186662093, 0.03529809087922331, 0.04912438744213432, 0.04456898110220209, 0.02070169364742469, 0.054942012575338595, 0.022157509083626792, 0.05660502822138369, 0.040451312015648, 0.06278672502958216, 0.10036489024059847, 0.05829370362334885, 0.08610939112259075, 0.04136923736950848, 0.02556083505623974, 0.052014343891642056, 0.018107815158145968, 0.01853525325714145, 0.053114395996090025, 0.0491480953496648, 0.05623116761853453, 0.01183948095786036, 0.007475776465071249, 0.02856520099157933, 0.04963424289599061, 0.021443331097543705, 0.03292708490334917, 0.08697548488271423, 0.03878684918163344, 0.0202020853976137, 0.05006776103982702, 0.08103966159978881, 0.08143245067913085, 0.05871772598766256, 0.07570865156594664, 0.10246650403132662, 0.0315052783844294, 23.849710933864117, 104.4674751162529, 90.83529621362686, 90.42377069592476, 77.81607761979103, 43.255195543169975, 75.78532978892326, 128.58487218618393, 67.47751638293266, 20.571421645581722, 22.040561512112617, 46.11721336841583, 46.48368090391159, 26.06626309454441, 6.948625389486551, 0.2860336593585089, 0.06035823971615173, 0.1814401155570522, 0.5301165604032576, 1.0961331194266677, 1.393111408688128, 1.7760724341496825, 2.182558234781027, 2.5092233810573816, 0.5511577532161027, 0.2529359806794673, 2.2366165090352297, 26.340927556157112, 73.53080436587334, 80.97753837704659, 74.40478786826134, 74.491446018219, 69.04468148946762, 73.02508190274239, 74.84806448221207, 74.42026063799858, 68.57610583305359, 68.46006006002426, 75.99402979016304, 73.16805303096771, 63.54459062218666, 68.41071590781212, 67.361349016428, 71.78260937333107, 71.83738723397255, 72.19692394137383, 71.35223686695099, 73.70561018586159, 66.2302029132843, 60.59556886553764, 60.83068884909153, 63.453243523836136, 60.2400903403759, 61.99598751962185, 61.330498829483986, 60.726692229509354, 64.71157640218735, 68.09268057346344, 72.0148529112339, 65.83570808172226, 34.281536266207695, 34.19026896357536, 37.13845856487751, 51.54835693538189, 63.06979089975357, 74.21311095356941, 75.27983531355858, 69.79731470346451, 60.546836480498314, 55.052278116345406, 58.34489643573761, 62.671606466174126, 71.09290078282356, 70.32167136669159, 72.46119976043701, 71.97254598140717, 65.82633018493652, 64.79137971997261, 64.07175913453102, 67.30120584368706, 66.61095768213272, 67.65055909752846, 65.56301191449165, 66.37648746371269, 63.804078698158264, 63.120791763067245, 65.17203569412231, 67.10947573184967, 71.12760052084923, 67.14463144540787, 50.953654646873474, 32.3561567813158, 10.83188496530056, 1.9938214123249054, 0.8278755296487361, 1.9944768771529198, 2.618812588043511, 1.3931585499085486, 1.3361120922490954, 0.4458889737725258, 0.15176142216660082, 0.04499949725868646, 0.06530678394483402, 0.04144277307204902, 0.23170729167759418, 3.8073550863191485, 18.565003909170628, 37.032140269875526, 44.39695447683334, 60.21083950996399, 84.26222652196884, 62.829225808382034, 31.003568060696125, 54.55469861626625, 63.54656271636486, 68.08249711990356, 75.26445373892784, 77.93565720319748, 14.403599258512259, 0.17515123035991564, 0.0489918435778236, 0.053372852635220625, 0.04714097551186569, 0.015411527710966766, 0.046376396421692334, 0.08856227083015256, 0.06993683549808338, 0.03049446768272901, 0.06046211812645197, 0.11480621571536176, 0.04383266299555544, 0.07536394623457454, 0.08503596356604248, 0.01618849695660174, 0.055011692820698954, 0.06663312058662996, 0.014405083620658843, 0.029625620554725174, 0.0436003967479337, 0.08597113643190823, 0.021326667338144034, 0.06719428070937283, 0.05992000522383023, 0.042510066778049804, 0.028114594897488132, 0.020597817092493642, 0.0810575696232263, 0.00755370057959226, 0.03072352414164925, 0.018001326243393123, 0.26214404439087957, 0.17538242420414463, 0.15764700947329402, 0.10420383463497274, 0.180922185536474, 0.15498216496780515, 0.14061792637221515, 0.12296566186705604, 0.1610766668454744, 0.09954302848200314, 0.13370440516155213, 0.1436067628674209, 0.12275213855900802, 0.14206885476596653, 0.11870286951307207, 0.19324749213410541, 0.1684691256377846, 0.16421038541011512, 0.13174725783756003, 0.13104803598253056, 0.1066260488005355, 0.18511159432819113, 0.17489564954303205, 0.229472714709118, 0.22887727478519082, 0.13028742367168888, 33.67421865463257, 116.44746467471123, 100.92049464583397, 98.5640586912632, 91.68626055121422, 57.227972969412804, 81.42252489924431, 161.39535158872604, 107.90537863969803, 60.39157301187515, 33.82252089679241, 84.94123488664627, 73.17635178565979, 37.5855577737093, 10.60669669881463, 0.9283712308388203, 0.21098355995491147, 0.31668551615439355, 0.7717699371278286, 1.126158395782113, 2.130436194129288, 1.2730322708375752, 2.755046202801168, 5.036862473934889, 4.5417471416294575, 2.855943851172924, 3.6899812845513225, 29.71888169646263, 75.3650951385498, 82.65749663114548, 74.82346460223198, 76.95873722434044, 72.81787142157555, 76.05492532253265, 76.2765446305275, 77.57330104708672, 69.98215958476067, 71.25536486506462, 77.52541601657867, 75.70753276348114, 65.17787978053093, 70.9419196844101, 72.60510563850403, 75.01969367265701, 72.77725160121918, 76.26733392477036, 72.54945382475853, 74.49879482388496, 69.2972919344902, 65.64838573336601, 64.82104852795601, 64.95869994163513, 63.98945555090904, 66.4090745151043, 63.743126168847084, 64.22092393040657, 68.67381379008293, 71.3958129286766, 75.09289294481277, 72.19043388962746, 40.68445488810539, 41.93439781665802, 42.694858610630035, 53.84143128991127, 64.97465148568153, 76.98994874954224, 77.65377312898636, 74.22621265053749, 64.61228772997856, 58.199953213334084, 61.25604562461376, 64.87871423363686, 75.38319736719131, 71.63447052240372, 72.7337059378624, 74.66169208288193, 67.76368662714958, 64.70590710639954, 64.83462139964104, 68.46585854887962, 68.84535938501358, 70.39761409163475, 69.81235429644585, 67.23362267017365, 66.65994465351105, 62.48959243297577, 68.01116734743118, 69.64976862072945, 72.97867119312286, 70.11073708534241, 52.3842778801918, 35.59971213340759, 13.137175664305687, 5.69882970303297, 5.8297051303088665, 8.559765536338091, 4.8242396581918, 1.9969479320570827, 1.6198698221705854, 0.5918642564211041, 0.29398179380223155, 0.1880798436468467, 0.18719422398135066, 0.2667089947499335, 0.8984820346813649, 6.480499058961868, 28.218912184238434, 51.20735563337803, 55.49082778394222, 63.85856777429581, 79.02863815426826, 63.009073957800865, 31.388713493943214, 57.64800243079662, 70.37019476294518, 80.65483689308167, 84.58846181631088, 89.59969371557236, 15.331930294632912, 0.38417482282966375, 0.15136247326154262, 0.09298685879912227, 0.22755516838515177, 0.16615179920336232, 0.14110133168287575, 0.24800617567962036, 0.09276923141442239, 0.15130028128623962, 0.12868496356531978, 0.23651964438613504, 0.14311182458186522, 0.15659954224247485, 0.39501709572505206, 0.14398770726984367, 0.16837806411786005, 0.1537953520892188, 0.07555727570434101, 0.17450234096031636, 0.11741660884581506, 0.17258917330764234, 0.14710674615344033, 0.1966476862435229, 0.10446654006955214, 0.09279757403419353, 0.2080064345500432, 0.1323083956958726, 0.15058983815833926, 0.13326031883480027, 0.11280274353339337, 0.1543104916345328], [0.05864319209649693, 0.025425029452890158, 0.047311476519098505, 0.024217430873250123, 0.01733140437863767, 0.07030775348539464, 0.01578473707922967, 0.022295906637737062, 0.039423296475433744, 0.04190470433968585, 0.04443181736860424, 0.058725889612105675, 0.029847147925465833, 0.0350065715610981, 0.0372817328752717, 0.024824164429446682, 0.04959860867529642, 0.058696418927866034, 0.05923799006268382, 0.022161115921335295, 0.08811290041194297, 0.09881198333459906, 0.022035995389160234, 0.0446893982734764, 0.06950889088329859, 9.871652740985155, 75.9177602827549, 73.84271442890167, 74.39110860228539, 57.68029309809208, 58.69154803454876, 34.74763065576553, 47.249852791428566, 84.22381818294525, 64.73851695656776, 64.06165927648544, 61.024543046951294, 57.01583415269852, 28.024951592087746, 8.396129216998816, 0.2926180529175326, 0.00805661973572569, 0.15926034946460277, 0.11401387659134343, 0.7240984670352191, 0.3753001318546012, 0.1955215958878398, 4.051014399155974, 0.8799486479256302, 1.06969520682469, 0.5705836764536798, 3.1493992544710636, 38.072471246123314, 78.97436946630478, 74.54086616635323, 71.10974907875061, 71.0047759115696, 65.51493689417839, 67.3020114004612, 70.38974851369858, 66.83468967676163, 74.46322873234749, 68.9593456685543, 66.61764532327652, 72.62200713157654, 64.74229395389557, 61.35848052799702, 52.793667912483215, 56.83036230504513, 59.74181927740574, 66.69637709856033, 64.63249504566193, 68.68155017495155, 68.03975701332092, 68.95396515727043, 61.55012704432011, 58.37990015745163, 54.13340762257576, 54.11348149180412, 49.03601534664631, 53.00273269414902, 51.12690255045891, 58.695651814341545, 63.55786330997944, 72.21395462751389, 63.026078045368195, 57.526785135269165, 20.21759793162346, 32.16058507561684, 56.96294479072094, 60.69973647594452, 71.63589164614677, 63.80174562335014, 64.01679888367653, 55.1649534702301, 53.560820147395134, 51.92376919090748, 58.37622195482254, 66.8658784031868, 74.51810538768768, 59.611524268984795, 58.610543981194496, 62.003571912646294, 68.54302480816841, 71.10791757702827, 68.49741205573082, 69.91282850503922, 69.11401256918907, 68.97190019488335, 70.02397254109383, 69.2456679046154, 63.52665178477764, 62.948250621557236, 67.81242281198502, 73.74217942357063, 73.69354203343391, 76.10148042440414, 63.78106713294983, 39.0646056085825, 11.001201029866934, 1.9888246804475784, 1.1531605781055987, 1.3337008841335773, 2.7363281697034836, 0.7894617284182459, 0.17862084496300668, 0.06358434824505821, 0.006325341810224927, 0.050942782836500555, 0.03975741878093686, 0.001198288916839374, 0.07214862111140974, 0.37444983841851354, 7.211040258407593, 32.998877093195915, 39.310197830200195, 42.37504877150059, 46.27118870615959, 44.12261299788952, 22.449919246137142, 37.42462120950222, 47.776496931910515, 61.990409418940544, 75.9368808567524, 46.7916239798069, 1.4428759133443236, 0.2203191988519393, 0.022729100091964938, 0.03629016049671918, 0.011490804208733607, 0.020190201757941395, 0.09273463248973712, 0.02887138329242589, 0.05012183763028588, 0.04224030351906549, 0.012501808796514524, 0.02998365856910823, 0.04080261875060387, 0.0930366049578879, 0.060310920380288735, 0.08408239285927266, 0.11545089713763446, 0.06760607619071379, 0.07676708773942664, 0.023173193840193562, 0.06696445241686888, 0.03186851514328737, 0.04415048773807939, 0.04982440710591618, 0.08710448499186896, 0.03798548183112871, 0.03372699022293091, 0.07049330524750985, 0.04581350338412449, 0.05196409307245631, 0.057154495807481, 0.038517883731401525, 0.07352650733082555, 0.05581367244303692, 0.04723210382508114, 0.026690484010032378, 0.018426651076879352, 0.03404731600312516, 0.028140178583271336, 0.049288621012237854, 0.030056446557864547, 0.011135809927509399, 0.05987702003039885, 0.012294892458157847, 0.04748887578898575, 0.02519596371712396, 0.04135065399168525, 0.09037259165779687, 0.019744440032809507, 0.03795403703406919, 0.034228889853693545, 0.043333568683010526, 0.019089782290393487, 0.015267439739545807, 0.010610810950311134, 0.07274433562997729, 11.297028455883265, 90.48128440976143, 83.82360085844994, 84.72121149301529, 65.77095195651054, 74.46672454476357, 46.86524122953415, 60.75045235455036, 107.69616186618805, 70.72835594415665, 57.150369733572006, 52.82044507563114, 59.05895411968231, 31.991482749581337, 10.916267037391663, 0.03117706728517078, 0.07045460224617273, 0.2702354430221021, 0.28648865525610745, 1.8173613748513162, 2.31708740349859, 2.2099462151527405, 4.177968911826611, 5.018709897994995, 0.4876410443102941, 0.11917967713088728, 3.232357590459287, 41.95371977984905, 80.7620595395565, 77.35200852155685, 74.60270404815674, 71.7563071846962, 68.46705928444862, 70.38879856467247, 73.05874049663544, 69.43357542157173, 77.06129372119904, 72.02816739678383, 68.04550230503082, 75.1765188574791, 68.36159214377403, 63.84690999984741, 55.92163726687431, 61.79615244269371, 62.91667811572552, 69.46677044034004, 67.5531779229641, 69.75682407617569, 70.37131190299988, 71.74557656049728, 62.66443245112896, 61.266244277358055, 56.28819219768047, 57.268011420965195, 52.91745387017727, 53.5558158159256, 54.01255890727043, 60.84614261984825, 66.02292403578758, 73.57186496257782, 66.31489276885986, 63.565105721354485, 23.699968568980694, 34.56868685781956, 60.30059069395065, 62.72618293762207, 75.63456907868385, 68.35579365491867, 66.72230690717697, 57.95069798827171, 56.213864386081696, 56.01963020861149, 62.472850531339645, 69.87742200493813, 74.4109359383583, 64.17222574353218, 60.91417416930199, 63.50476495921612, 68.53601038455963, 73.60523477196693, 71.35127171874046, 73.9007905125618, 71.91285118460655, 71.04265227913857, 73.16163897514343, 73.54227975010872, 64.53690737485886, 64.21933561563492, 70.13023003935814, 75.83038777112961, 75.33615589141846, 77.94365957379341, 65.61588227748871, 41.636740788817406, 12.595785465091467, 1.4218718279153109, 0.2636358799645677, 0.9602976520545781, 2.7178616356104612, 2.604910796508193, 0.9343500318937004, 0.4238977131899446, 0.12140228325733915, 0.038754398774472065, 0.06607315532164648, 0.03752879383682739, 0.09801545849768445, 0.2957726555177942, 8.003906663507223, 35.119718089699745, 37.3611494153738, 44.761229529976845, 36.77199862897396, 41.926444843411446, 31.048787534236908, 43.030019626021385, 56.33146047592163, 67.376958578825, 83.73112142086029, 62.512037828564644, 2.5821067951619625, 0.18887607904616743, 0.04837720058276318, 0.09473216749029234, 0.045964062883285806, 0.031156598852248862, 0.00740709858291666, 0.030609895766247064, 0.019766697041632142, 0.07250495589687489, 0.027213772336835973, 0.030178420383890625, 0.008806238056422444, 0.04729984706500545, 0.03117838830803521, 0.08268180434242822, 0.03705069117131643, 0.01839455133449519, 0.03491872354061343, 0.016161351049959194, 0.04554612984065898, 0.05019934382289648, 0.022991779551375657, 0.0480937966494821, 0.10161846672417596, 0.027555533197300974, 0.02368507906794548, 0.023564185066788923, 0.16005570912966505, 0.0238511308998568, 0.11013449257006869, 0.138613430026453, 0.13754870044067502, 0.23270895355381072, 0.08167770080035552, 0.11298077733954415, 0.14338604814838618, 0.09035302864504047, 0.12201088145957328, 0.11039477860322222, 0.15117021248443052, 0.1716186074190773, 0.19375598203623667, 0.21060683095129207, 0.13387971528572962, 0.10130942158866674, 0.12792162015102804, 0.13954898138763383, 0.1376961948699318, 0.13508775358786806, 0.1285335951251909, 0.18819077988155186, 0.13740531750954688, 0.2547517785569653, 0.12265337354619987, 0.29301299422513694, 16.242486834526062, 108.4186626970768, 93.95118981599808, 95.18059864640236, 76.59692823886871, 79.04878467321396, 50.21077170968056, 58.67469593882561, 88.54889050126076, 74.07472237944603, 83.04385989904404, 83.38811382651329, 78.74309867620468, 43.17011810839176, 14.840111285448074, 0.7546100579202175, 0.1518715568818152, 0.7082847249694169, 0.6955694197677076, 2.7313471119850874, 3.288605734705925, 1.9869132642634213, 9.768902454525232, 5.214264979586005, 3.9667714945971966, 3.50928055588156, 4.304486447945237, 44.58154857158661, 87.26991713047028, 80.83924859762192, 76.98741808533669, 75.29598444700241, 71.72283098101616, 74.68485563993454, 76.26209780573845, 72.8267477452755, 81.55889198184013, 71.97245478630066, 68.26134592294693, 78.97489383816719, 71.39827519655228, 66.50233671069145, 59.78514455258846, 65.2712407708168, 64.26688626408577, 73.37657824158669, 70.19377782940865, 73.55877846479416, 74.33328330516815, 73.83693113923073, 66.5477366745472, 64.17581275105476, 59.73060227930546, 60.120814740657806, 55.64582906663418, 57.03596547245979, 57.284183353185654, 65.42692601680756, 68.75474944710732, 78.468798995018, 69.97451439499855, 64.42439541220665, 32.453640550374985, 37.921060770750046, 62.44111083447933, 65.23204207420349, 80.05876287817955, 71.93359807133675, 70.87734594941139, 63.54641452431679, 59.5846901088953, 59.26405191421509, 65.44828087091446, 74.66479271650314, 78.81939858198166, 64.91351276636124, 62.913015112280846, 65.73716416954994, 71.52686029672623, 76.87873631715775, 75.02831920981407, 78.00864368677139, 75.73604643344879, 75.82186102867126, 77.74575099349022, 75.85735872387886, 66.69526755809784, 67.85705521702766, 72.58701100945473, 79.81991529464722, 80.60480877757072, 83.2550297677517, 67.8196120262146, 44.179275557398796, 13.331400342285633, 5.251560928300023, 6.826696107164025, 5.310697155073285, 7.878802176564932, 3.089481694623828, 0.6962494645267725, 0.34518009808380157, 0.14222715486539528, 0.20209266047459096, 0.18292641470907256, 0.1679753154166974, 0.395145071670413, 1.0080555081367493, 14.071191195398569, 49.97125916182995, 57.48184114694595, 59.12187114357948, 61.701127141714096, 58.02528418600559, 33.12273524701595, 51.94725193083286, 66.73101603984833, 79.54845026135445, 94.08079326152802, 69.13199320435524, 3.565676179714501, 0.3189889941131696, 0.1385116222081706, 0.19756796420551836, 0.22061446972656995, 0.16157455887878314, 0.13607172266347334, 0.08934431636589579, 0.1688596437452361, 0.17068290762836114, 0.08268839461379685, 0.15100257616722956, 0.12899433524580672, 0.23309084790525958, 0.19613235373981297, 0.15874501696089283, 0.16718927712645382, 0.152136696560774, 0.1492643030360341, 0.07528847723733634, 0.10826740486663766, 0.15705835277913138, 0.14415690209716558, 0.11863856241689064, 0.20759393402840942, 0.12345328257652, 0.1526124874362722, 0.14571211708243936, 0.32025993685238063, 0.1550209496053867, 0.216739731549751], [0.013347358053579228, 0.019739517738344148, 0.07707855227636173, 0.04056807782035321, 0.028913494606968015, 0.023960354628798086, 0.05766872251115274, 0.05186554328247439, 0.042603492038324475, 0.1063348152092658, 0.02010955628065858, 0.03546107021975331, 0.04393796632939484, 0.018241266297991388, 0.016292195396090392, 0.0316509063122794, 0.0436301865556743, 0.0293036175207817, 0.07110321705113165, 0.03048082515306305, 0.05891874410735909, 0.04176806382020004, 0.0443503592396155, 0.029620585082739126, 1.4366704900749028, 54.05256316065788, 78.23616027832031, 82.91106462478638, 76.83934763073921, 65.72733029723167, 27.545394524931908, 22.852013669908047, 27.130686677992344, 12.033637929707766, 27.91678659617901, 35.06020188331604, 40.679036378860474, 19.153421334922314, 4.65722294524312, 0.15458177629625425, 0.11654126792564057, 0.18057607754599303, 0.0062181450721254805, 0.2901580708567053, 0.601624270202592, 0.7198535604402423, 0.9492683876305819, 2.2740069776773453, 1.1907538608647883, 1.1249707220122218, 7.032666904851794, 50.80333471298218, 81.55953034758568, 73.4321616590023, 72.37556755542755, 66.29901722073555, 63.28184612095356, 65.10748475790024, 63.08067351579666, 65.45135110616684, 68.7294428050518, 71.90341249108315, 69.07350674271584, 65.82394391298294, 71.356530636549, 63.07246595621109, 53.66590730845928, 50.373741164803505, 49.807795733213425, 52.183842435479164, 56.89415328204632, 57.93707571923733, 64.23554554581642, 65.38144245743752, 69.52918589115143, 63.763595670461655, 61.703646406531334, 53.9276372641325, 51.72288537025452, 48.52382183074951, 55.566755309700966, 48.902220726013184, 58.45022678375244, 63.72316963970661, 67.35865876078606, 64.59485426545143, 66.64184242486954, 20.64371846616268, 24.288708977401257, 64.50301319360733, 62.658820152282715, 68.29669162631035, 60.55458806455135, 61.09507866203785, 52.95249558985233, 52.13575601577759, 46.3531731069088, 55.830552354454994, 61.110673025250435, 73.76543417572975, 61.96279250085354, 55.9450364112854, 68.8937383890152, 66.78986728191376, 64.18909683823586, 62.94043444097042, 62.10808910429478, 62.58142590522766, 60.54381184279919, 63.60388644039631, 67.11718171834946, 63.20397689938545, 61.78041368722916, 73.9241136610508, 67.08349272608757, 68.25204402208328, 67.98361882567406, 73.1874167919159, 63.536003082990646, 53.185871466994286, 13.13734095543623, 0.7419079926330596, 1.452009198255837, 0.5335667752660811, 1.9144591083750129, 0.610724069410935, 0.22778296319302171, 0.20237783814081922, 0.06762569115380757, 0.08286502576083876, 0.1520947355311364, 0.07150615128921345, 0.03712323981744703, 0.09795624995604157, 5.53496397100389, 39.42112907767296, 49.188383370637894, 55.47850504517555, 58.21658872067928, 33.48663792014122, 22.84829556941986, 46.8539634346962, 55.77384039759636, 69.93216186761856, 74.4292813539505, 10.12734767049551, 0.5503695330116898, 0.1076301746070385, 0.12643125402973965, 0.06552153179654852, 0.07677143672481179, 0.02245567062345799, 0.0347110001166584, 0.0908549060113728, 0.0213254576374311, 0.01873098357464187, 0.10868702258449048, 0.02519114532333333, 0.03253610666433815, 0.05938139896898065, 0.10427583038108423, 0.06714328032103367, 0.031728405083413236, 0.02606876278150594, 0.055310945317614824, 0.05285786151944194, 0.04688094923039898, 0.023719618620816618, 0.07622878576512448, 0.019418503616179805, 0.04307791736209765, 0.040725735962041654, 0.10221421092865057, 0.07162226771470159, 0.017703443008940667, 0.015482421367778443, 0.04122166872548405, 0.07207286267657764, 0.015223552836687304, 0.021682775768567808, 0.022642285512119997, 0.05241197177383583, 0.04386749198602047, 0.04736245835374575, 0.08349280105903745, 0.08703939864062704, 0.010703126699809218, 0.0348758385371184, 0.011096338803326944, 0.018696724182518665, 0.09064163503353484, 0.03325596764625516, 0.026227847702102736, 0.05065773875685409, 0.11332147507346235, 0.024552720205974765, 0.029743963423243258, 0.031041846123116557, 0.06219111441168934, 0.13313851755810902, 2.2317864932119846, 64.95257467031479, 90.34175589680672, 93.31459477543831, 88.4530520439148, 78.00210043787956, 46.576563119888306, 36.62772797048092, 26.759632788598537, 25.368614830076694, 41.26118794083595, 39.22817163169384, 39.83724854886532, 22.308226749300957, 6.088561015203595, 0.061602802816196345, 0.04038576553284656, 0.07275756070157513, 0.581682346528396, 0.6603771925438195, 2.665512557141483, 3.0424751294776797, 2.9057416040450335, 0.9744907810818404, 2.0220220740884542, 0.6968892551958561, 8.473204281181097, 52.8592561930418, 83.67651835083961, 74.80577275156975, 75.7682079076767, 69.45777252316475, 66.95889741182327, 67.70271509885788, 65.94288513064384, 65.92212304472923, 72.94375866651535, 74.2715822160244, 69.57201719284058, 67.06406056880951, 73.97518292069435, 66.18262186646461, 57.0480602234602, 53.499449640512466, 53.81560407578945, 54.9850445240736, 60.75362518429756, 60.32970853149891, 68.11988711357117, 66.20385512709618, 72.81607031822205, 66.47741004824638, 63.54030825197697, 56.151787117123604, 53.97169589996338, 51.02854862809181, 57.58233055472374, 51.41494229435921, 62.82840505242348, 65.08235290646553, 70.91358840465546, 63.83102685213089, 72.86063432693481, 24.272808730602264, 27.175345681607723, 67.17337310314178, 64.25975784659386, 70.02771154046059, 65.30338704586029, 64.66521129012108, 55.58405578136444, 55.12956976890564, 51.02366589009762, 58.81414845585823, 64.02164742350578, 75.26317700743675, 63.70015047490597, 56.63258671760559, 69.98968318104744, 69.9933309853077, 66.20708495378494, 65.57089269161224, 65.77011600136757, 65.6987938284874, 63.20557281374931, 66.74984022974968, 70.36073327064514, 65.84554955363274, 63.691418543457985, 76.75047799944878, 70.21574065089226, 71.16493731737137, 72.06615775823593, 76.54189199209213, 70.20065546035767, 57.81610161066055, 16.322993114590645, 0.9618523623794317, 0.9098991751670837, 0.994633084628731, 1.2211664789356291, 3.201717222109437, 1.7652694950811565, 0.25196305476129055, 0.24770201387582347, 0.10461370053235441, 0.05155290986294858, 0.024902833938540425, 0.10899474669713527, 0.11418811060138978, 5.517187099903822, 38.35473909974098, 40.88759198784828, 44.35629665851593, 51.42213150858879, 39.10052888095379, 34.118015840649605, 56.89435847103596, 63.73523399233818, 75.22185042500496, 86.26221880316734, 18.86716179549694, 0.7041558902710676, 0.11744399409508333, 0.07277153534232639, 0.03376339627720881, 0.025551612015988212, 0.09363073870190419, 0.016698064828233328, 0.18026257952442393, 0.0302788162662182, 0.02622618900204543, 0.025942534593923483, 0.019402968609938398, 0.03673401675769128, 0.005495282566698734, 0.041598676034482196, 0.08975582240964286, 0.02638885849592043, 0.03354121952725109, 0.01981202556635253, 0.015519015742029296, 0.02793030478642322, 0.056188920862041414, 0.020624029748432804, 0.003551659492586623, 0.033664787115412764, 0.05051078609540127, 0.03551865716872271, 0.08628976269392297, 0.046806289174128324, 0.02801838101731846, 0.13949900516308844, 0.1303155510686338, 0.14265624980907887, 0.12431880488293245, 0.11391136373276822, 0.11417988760513254, 0.24850662070093676, 0.12434143296559341, 0.2572282066103071, 0.2595614001620561, 0.06354654324240983, 0.15247149422066286, 0.1242786918010097, 0.13611611793749034, 0.17102816957049072, 0.1333195570623502, 0.11705345372320153, 0.12332169979345053, 0.22931428102310747, 0.12808970175683498, 0.12950099946465343, 0.08967544781626202, 0.1906404906185344, 0.2728803682839498, 3.0782435601577163, 80.0458511710167, 99.70554783940315, 103.40614646673203, 100.822763890028, 88.34588259458542, 40.96651375293732, 35.15925116837025, 40.62382534146309, 20.287225395441055, 44.13517892360687, 49.89703394472599, 57.61309750378132, 31.528730280697346, 8.82527818903327, 0.26757704035844654, 0.1881847981712781, 0.37681310379412025, 0.8213877934031188, 1.2582675693556666, 3.891139402985573, 2.4308549612760544, 5.336365252733231, 8.477059174329042, 3.592093074694276, 5.145696233958006, 8.532934226095676, 56.938800886273384, 85.73353797197342, 78.42393100261688, 76.91284328699112, 73.10140460729599, 67.73952752351761, 72.23415434360504, 69.64284539222717, 69.71688821911812, 75.91927260160446, 78.06339114904404, 70.23796945810318, 68.88570562005043, 77.08231419324875, 70.3632715344429, 59.540650472044945, 55.83517290651798, 54.340340718626976, 57.1353567391634, 63.23481984436512, 62.95221760869026, 70.42251795530319, 70.31426936388016, 76.4974419772625, 69.88192096352577, 66.16249054670334, 58.91717612743378, 58.5457194596529, 54.78050149977207, 61.46266333758831, 54.112824127078056, 65.97186237573624, 69.72156956791878, 74.89298567175865, 69.37487617135048, 76.5428875386715, 27.538894973695278, 31.92283183336258, 69.7806715965271, 68.71393963694572, 73.92785266041756, 68.6738745868206, 67.7090759575367, 58.72469365596771, 58.57289560139179, 52.60879263281822, 62.02841877937317, 68.40481862425804, 78.88411670923233, 65.9885510802269, 58.540304750204086, 72.95984700322151, 73.46939966082573, 70.66479295492172, 69.53161016106606, 68.19393754005432, 68.56570959091187, 65.59771925210953, 70.03979489207268, 74.62087467312813, 67.58261874318123, 63.86308193206787, 81.29340022802353, 74.56115707755089, 73.66691306233406, 74.40959841012955, 81.57868131995201, 76.84238746762276, 60.53952947258949, 16.072767041623592, 3.4788612881675363, 5.357889672741294, 4.096229122951627, 6.2462093308568, 3.996687289327383, 1.0687154531478882, 0.28522299660835415, 0.24671558086993173, 0.29575772350654006, 0.35187812929507345, 0.17651457048486918, 0.2955508721061051, 0.21029511408414692, 9.391286317259073, 57.86185495555401, 66.43546789884567, 72.96420156955719, 74.66600105166435, 45.202971026301384, 36.92572697997093, 62.95960061252117, 75.93862116336823, 83.243288397789, 98.76498430967331, 22.60075595229864, 0.9903578390367329, 0.19623759028036147, 0.19639928941614926, 0.20454015961149707, 0.12014415740850382, 0.2125169854843989, 0.06702148646581918, 0.20328224898548797, 0.14327957964269444, 0.2038231707410887, 0.18448167422320694, 0.09477833649725653, 0.14226824016077444, 0.10806706952280365, 0.25660106213763356, 0.1453645693254657, 0.1512068894226104, 0.10123758169356734, 0.12072702535078861, 0.14275543042458594, 0.16518206452019513, 0.19771320250583813, 0.1774597103940323, 0.10947206639684737, 0.1736477727536112, 0.1106919493759051, 0.18030128994723782, 0.161016998172272, 0.1948317844653502, 0.08587722506490536], [0.03055115848837886, 0.09091566564165987, 0.017432509011996444, 0.0302236412971979, 0.011374189616617514, 0.07809000308043323, 0.025216754984285217, 0.06072091244277544, 0.07930549996672198, 0.04783279073308222, 0.09115011751418933, 0.0828387240471784, 0.11197667379747145, 0.04169486208411399, 0.03647652119980194, 0.10351262797485106, 0.031633306280127726, 0.03749420604435727, 0.15606175235006958, 0.04424407256010454, 0.013291729446791578, 0.05920870491536334, 0.16689915675669909, 0.017852443997981027, 21.450732462108135, 81.53069749474525, 83.43858271837234, 71.19302541017532, 57.080841064453125, 44.656355157494545, 19.579118192195892, 22.20558475703001, 41.418047323822975, 51.43127761781216, 39.29274916648865, 44.665341675281525, 20.5858950689435, 3.641248899511993, 0.03671698817925062, 0.18401511566480622, 0.03347150588524528, 0.07084540979121812, 0.633205563062802, 0.6955368246417493, 0.6825801730155945, 1.3425153424032032, 3.0771810421720147, 0.15351879817899317, 2.9473006865009665, 13.195650726556778, 66.88064441084862, 77.89217993617058, 71.7566567659378, 73.2367305457592, 64.27176520228386, 63.44885475933552, 69.46903511881828, 66.4643007516861, 59.33890789747238, 60.5819845944643, 67.82648965716362, 70.91275244951248, 67.2698575258255, 63.165553361177444, 67.87514984607697, 63.880553394556046, 56.160671040415764, 47.983829006552696, 50.41510954499245, 48.6878552287817, 50.77310353517532, 48.6425768584013, 52.19577379524708, 54.596625566482544, 59.53001104295254, 57.334272265434265, 54.64663848280907, 50.30806928873062, 50.63343442976475, 48.909330144524574, 50.61420366168022, 46.0065633058548, 58.93378883600235, 59.78274688124657, 70.20269215106964, 59.93430934846401, 73.77658277750015, 27.11160410195589, 24.576765820384026, 68.97617116570473, 58.66193242371082, 70.003020465374, 55.65094739198685, 55.006064996123314, 52.086746245622635, 53.25516454875469, 47.900940254330635, 52.15289689600468, 58.382810801267624, 68.42381000518799, 63.428073674440384, 62.53281511366367, 68.76195386052132, 63.421686217188835, 60.436535999178886, 56.706097573041916, 54.20704387128353, 55.12390047311783, 59.20370735228062, 63.1114936619997, 65.34888580441475, 65.98211422562599, 61.44511207938194, 71.33891478180885, 67.76073038578033, 64.91714537143707, 66.55292719602585, 71.81146502494812, 66.53930112719536, 62.87169612944126, 57.78300538659096, 22.376775071024895, 0.5785131978336722, 0.8172881696373224, 1.911640134640038, 2.133330451324582, 1.5043131541460752, 0.3069675376173109, 0.04261335518094711, 0.07776359168929048, 0.0491505073296139, 0.06258171415538527, 0.09848674453678541, 0.03430966520681977, 0.060812122392235324, 5.660072732716799, 45.92703357338905, 48.488536924123764, 53.57182435691357, 31.04680974036455, 16.979884766042233, 35.631467029452324, 54.872369170188904, 62.27051518857479, 67.43122726678848, 53.686069026589394, 3.374068373814225, 0.13567133399192244, 0.043084834178444, 0.02072123810648918, 0.025884250026138034, 0.0672226827009581, 0.043365666570025496, 0.03543689104844816, 0.04139492681133561, 0.10258266498567536, 0.07854895462514833, 0.07311655979719944, 0.049784316288423724, 0.004307632452764665, 0.04178347822744399, 0.029412288349703886, 0.043089387254440226, 0.06836330430814996, 0.05688855089829303, 0.029233334280434065, 0.06130152796686161, 0.045639480886165984, 0.03742051820154302, 0.014693729899590835, 0.06007157775457017, 0.027597980333666783, 0.05685044903657399, 0.05908012040890753, 0.04732628607598599, 0.035883671371266246, 0.0299141490177135, 0.1376089034602046, 0.03317554481327534, 0.0414502798957983, 0.0394496427179547, 0.07246165157994255, 0.03101482638157904, 0.052430039359023795, 0.04215853368805256, 0.01844791175244609, 0.07282222402864136, 0.02773470063402783, 0.09252807052689604, 0.03432682737184223, 0.06225044540769886, 0.00784177169407485, 0.052172788709867746, 0.05518655394553207, 0.06013647114741616, 0.07243410305818543, 0.05073014639492612, 0.05757136757893022, 0.1596623708610423, 0.062319268472492695, 25.288152247667313, 95.82564443349838, 92.66548320651054, 80.49676537513733, 66.65679842233658, 56.50554433465004, 28.862857930362225, 32.79865063726902, 39.945911318063736, 35.50974056124687, 46.08748376369476, 44.20992471277714, 23.09961598366499, 3.57015376444906, 0.06571141027961858, 0.13797565799904987, 0.08415527918259613, 0.34695751208346337, 1.9204247882589698, 2.1659403014928102, 1.7018197872675955, 2.2041833493858576, 1.8429087102413177, 0.6400906154885888, 0.9294088126625866, 14.591006152331829, 68.56487363576889, 80.30374333262444, 73.49845290184021, 74.95740741491318, 67.1828193962574, 66.23562902212143, 70.84674999117851, 69.00503441691399, 62.01799213886261, 63.02702039480209, 71.05800345540047, 73.53990107774734, 68.94023269414902, 65.37401005625725, 70.87998300790787, 66.30344018340111, 58.464969992637634, 50.61356909573078, 52.54321575164795, 51.077516600489616, 54.564160108566284, 51.19295060634613, 54.46244336664677, 58.58290046453476, 63.35761785507202, 60.84530666470528, 57.55978636443615, 52.474868819117546, 53.939963802695274, 51.88898205757141, 53.71663078665733, 47.851941883563995, 61.38435333967209, 62.76032790541649, 74.82110112905502, 61.839899495244026, 77.21779212355614, 29.526515118777752, 27.537623941898346, 71.31456568837166, 61.6083475202322, 73.71364295482635, 59.12918955087662, 59.65559810400009, 54.25747476518154, 55.20836994051933, 49.81267847120762, 55.776382461190224, 59.80312138795853, 71.08371287584305, 64.2999292910099, 64.44262683391571, 71.7854668200016, 66.15578770637512, 63.357655853033066, 59.23702396452427, 57.49627657234669, 57.48063661158085, 62.52328522503376, 66.76956117153168, 69.06467601656914, 67.1379666030407, 62.13857866823673, 74.92446318268776, 71.30069643259048, 66.89162582159042, 68.60200524330139, 74.82992425560951, 70.61158820986748, 70.59109970927238, 63.0764215439558, 26.394261494278908, 1.4892247575335205, 0.90264055528678, 0.9877889393828809, 1.9554889504797757, 2.710637035779655, 1.5813721879385412, 0.07655642912141047, 0.3381124773295596, 0.1923937996616587, 0.15610653354087844, 0.18746040266705677, 0.12009794387267902, 0.013059613484074362, 6.554747074842453, 45.81815041601658, 47.61967174708843, 46.16212695837021, 29.964061640203, 21.65116410702467, 44.080754444003105, 61.22183986008167, 70.20827785134315, 73.79523977637291, 69.5383358001709, 6.494348840788007, 0.17370503686834127, 0.05727815987484064, 0.019462119635136332, 0.0037895702371315565, 0.06883754409500398, 0.008879720880941022, 0.041715074476087466, 0.042268182296538725, 0.09302031481638551, 0.009252172330889152, 0.03138450127153192, 0.05260225101665128, 0.023402599108521827, 0.017951038316823542, 0.03196475685399491, 0.07417136686854064, 0.024698828674445394, 0.03279276359535288, 0.047012910508783534, 0.058873202215181664, 0.04510261496761814, 0.02299647734616883, 0.11626656196312979, 0.011538422259036452, 0.038090020752861165, 0.028951050990144722, 0.02493741430953378, 0.035663416783791035, 0.017065400097635575, 0.12837248970754445, 0.14992169744800776, 0.14414260833291337, 0.08713687973795459, 0.09413681662408635, 0.15751208702567965, 0.07336870447034016, 0.20143658708548173, 0.20865665981546044, 0.12945451133418828, 0.20927872799802572, 0.1604526987648569, 0.21107257314724848, 0.15397691109683365, 0.11622240417636931, 0.3046943689696491, 0.18712780176429078, 0.15577479352941737, 0.27391818759497255, 0.1814111421117559, 0.1134669805469457, 0.22336405265377834, 0.2654810668900609, 0.1509196634287946, 32.94837400317192, 109.50705349445343, 105.22866547107697, 93.22909936308861, 76.54721930623055, 64.37930703163147, 31.244205348193645, 32.080071195960045, 56.477045863866806, 70.61026588082314, 59.32728052139282, 64.09831210970879, 32.706193998456, 6.266847923398018, 0.3133574587991461, 0.36628639209084213, 0.15407355356728658, 0.5043601768556982, 2.379005318507552, 3.5530086094513535, 3.0932014575228095, 6.790463626384735, 8.142717014998198, 4.973319908604026, 9.920446872711182, 15.409324541687965, 75.18361687660217, 81.03899627923965, 77.46308416128159, 78.46148818731308, 70.84390014410019, 69.21612069010735, 75.29577165842056, 71.14621952176094, 66.019846200943, 66.99294358491898, 73.63121017813683, 76.95515021681786, 71.8442876636982, 66.58369794487953, 73.89608636498451, 70.22287666797638, 62.12062083184719, 54.11687470972538, 55.61400577425957, 54.444485530257225, 56.75692364573479, 55.1135840266943, 57.32463218271732, 60.18618643283844, 66.32674053311348, 62.89810091257095, 59.62591029703617, 56.789962872862816, 56.85671389102936, 55.062807351350784, 55.63071347773075, 51.56965099275112, 65.93360602855682, 66.59171551465988, 77.1354353427887, 66.06919035315514, 78.37742909789085, 34.68463383615017, 31.167360171675682, 73.60876098275185, 64.78229060769081, 76.11220344901085, 61.65532059967518, 63.209235817193985, 57.34306499361992, 58.0091692507267, 53.29157419502735, 59.23222482204437, 63.44021022319794, 73.58208641409874, 65.08070379495621, 63.970927745103836, 74.96684610843658, 67.760791182518, 65.99997326731682, 63.777624517679214, 60.55344432592392, 61.254282519221306, 66.52085691690445, 70.48468261957169, 72.72949576377869, 69.8028016090393, 64.35757979750633, 75.86404636502266, 73.35911437869072, 71.26398280262947, 71.8508081138134, 78.6873784661293, 72.26231843233109, 71.75452128052711, 65.8118225634098, 25.97615472972393, 2.42449386510998, 4.997210176661611, 7.610126668587327, 8.953957334160805, 4.682446466758847, 1.1588555225171149, 0.18026430130703375, 0.1899020091514103, 0.2220960339764133, 0.32002708059735596, 0.301086136023514, 0.2648272941587493, 0.11141668626805767, 10.270100310444832, 67.82734841108322, 63.86162281036377, 69.07551303505898, 43.60529735684395, 28.27642399817705, 49.38305452466011, 71.5879762172699, 80.58976918458939, 83.60612332820892, 77.78120309114456, 7.275084871798754, 0.3305176051799208, 0.13114978442899883, 0.10141293634660542, 0.08591172751039267, 0.13966083788545802, 0.14323441253509372, 0.1233487510762643, 0.10139430101844482, 0.2672076289309189, 0.16174425836652517, 0.12105051268008538, 0.15753849264001474, 0.10887420707149431, 0.0946417664818, 0.18102267233189195, 0.11937541115912609, 0.1334518226212822, 0.12599058158230036, 0.10898653112235479, 0.1541382836876437, 0.12163286111899652, 0.13894977135350928, 0.16249920066911727, 0.17715394555125386, 0.1742431681486778, 0.12319180910708383, 0.10525111632887274, 0.1670572193688713, 0.14433662057854235], [0.01610554154467536, 0.022429604541684967, 0.026276089156453963, 0.022978534070716705, 0.07755194601486437, 0.03712910649483092, 0.035323435222380795, 0.021197179266891908, 0.059886649396503344, 0.07113358573406003, 0.04450258114957251, 0.058252904054825194, 0.016301828472933266, 0.0032971181462926324, 0.03660869399027433, 0.032858295235200785, 0.033548377541592345, 0.06649478425970301, 0.008537131598131964, 0.06283459355472587, 0.023897416795080062, 0.01142614737545955, 0.026907259780273307, 0.2662106277421117, 47.88971945643425, 83.76924097537994, 70.90396732091904, 66.61331355571747, 66.15609169006348, 43.58513943850994, 41.190169751644135, 39.53368663787842, 40.459104180336, 50.14587499201298, 44.89039599895477, 16.450043097138405, 0.7417631847783923, 0.0575876391667407, 0.07542507693869993, 0.09282891493057832, 0.3036215796601027, 0.30921194062102586, 1.0314577398821712, 0.49613661656621844, 1.2858439958654344, 3.8232344342395663, 1.0639553773216903, 1.5625293552875519, 28.39181050658226, 77.22425937652588, 75.99643886089325, 71.85334637761116, 69.0334340929985, 61.92298203706741, 67.75202885270119, 72.76169523596764, 69.13565620779991, 68.99199351668358, 57.764720767736435, 58.338151797652245, 67.70700886845589, 69.1942946612835, 65.9629176557064, 62.85935819149017, 69.73037749528885, 62.48117208480835, 52.62252889573574, 48.613177835941315, 51.788424253463745, 53.56236286461353, 55.682820081710815, 52.0674242824316, 48.735048696398735, 47.05466106534004, 50.595007091760635, 46.68431393802166, 49.124542996287346, 49.21092376112938, 48.745406940579414, 48.38743194937706, 50.3294887393713, 47.58335329592228, 53.88715423643589, 54.08122882246971, 65.7241840660572, 59.97525215148926, 73.55190843343735, 34.20454099774361, 35.0664259493351, 69.85044345259666, 60.51331847906113, 65.0749509036541, 56.10760308802128, 55.977532267570496, 50.10772503912449, 50.69434516131878, 48.25851246714592, 53.646915927529335, 58.27167436480522, 67.38686084747314, 63.55141885578632, 69.09253612160683, 66.72571912407875, 59.968199729919434, 52.242822870612144, 50.22714123129845, 48.7497691065073, 46.260781064629555, 50.20935818552971, 59.81867395341396, 64.64055821299553, 63.598874509334564, 59.339561462402344, 67.561324685812, 67.25692301988602, 64.79791536927223, 60.23872621357441, 69.47712868452072, 73.17093327641487, 71.24700531363487, 63.232585564255714, 71.43987536430359, 38.99236388504505, 1.9202488102018833, 0.7563949527684599, 3.018940854817629, 3.891881788149476, 1.0735806170850992, 0.44109763868618757, 0.09934676010743715, 0.01611972213140689, 0.08716091790120117, 0.10657832870492712, 0.08651708252727985, 0.04749916566652246, 0.1946290594059974, 8.669035322964191, 44.98040556907654, 43.970495760440826, 60.1466229557991, 29.756205193698406, 25.87100487202406, 47.90288954973221, 51.05553857982159, 63.69571231305599, 70.18955245614052, 30.77618256211281, 0.7581359124742448, 0.057743323195609264, 0.06352725482429378, 0.06966991466470063, 0.09439146233489737, 0.09034996357513592, 0.03446469614573289, 0.02553434966102941, 0.029003747185925022, 0.0586165304412134, 0.04777944144734647, 0.03751333490072284, 0.04529718011326622, 0.035247728737886064, 0.006159581271276693, 0.05588214669842273, 0.09739169821841642, 0.016497762881044764, 0.046949920724728145, 0.10272454135701992, 0.05568645348830614, 0.05668773686920758, 0.024600380929769017, 0.05471008029417135, 0.04399570170789957, 0.029351571392908227, 0.05373574429540895, 0.05350283609004691, 0.05086187389679253, 0.0626299760187976, 0.02192830233980203, 0.02794492324028397, 0.02875187710742466, 0.11099984418251552, 0.0891953005339019, 0.06898667867062613, 0.013558997234213166, 0.04723263446066994, 0.02035042216448346, 0.02708788182644639, 0.02778459707769798, 0.057475916255498305, 0.01682407222688198, 0.0017773213471627969, 0.10745371415396221, 0.05353960950742476, 0.01284486563235987, 0.0351657659484772, 0.025140282232314348, 0.05213121730776038, 0.0552746097673662, 0.03811660448263865, 0.7284950092434883, 61.6891273856163, 96.21735021471977, 81.33705988526344, 75.74679985642433, 73.6698617041111, 52.71741360425949, 26.973977386951447, 24.363133683800697, 34.775372967123985, 42.0185898989439, 43.827083855867386, 21.033387556672096, 0.7532392221037298, 0.03763873188290745, 0.0663436904142145, 0.10715430951677263, 0.6502241967245936, 1.3055620878003538, 2.5748736457899213, 1.855567255988717, 2.4698040587827563, 0.8585506305098534, 0.5755406885873526, 2.1205997094511986, 29.996756985783577, 82.94416844844818, 79.06662851572037, 74.09049913287163, 71.0403648018837, 64.00612145662308, 71.1717389523983, 73.2675164937973, 72.69842103123665, 70.59765055775642, 61.03453271090984, 60.93323394656181, 71.2608289718628, 71.36352226138115, 65.68734124302864, 64.00282323360443, 73.32531899213791, 67.35642448067665, 56.11051373183727, 51.01312145590782, 53.11131186783314, 55.43126977980137, 57.20512479543686, 54.3202967941761, 50.736720487475395, 48.589151725173, 52.22470544278622, 49.66331608593464, 52.018308117985725, 50.76388143002987, 51.47049531340599, 52.03670673072338, 52.790134102106094, 49.36379715800285, 54.67973850667477, 57.34912186861038, 67.99850642681122, 62.64477610588074, 75.20500972867012, 38.07339459657669, 36.51506781578064, 70.64039826393127, 61.965687945485115, 65.89082032442093, 60.04287712275982, 58.04402858018875, 52.44270734488964, 52.66050785779953, 50.12366138398647, 56.29167281091213, 61.03580564260483, 69.62216690182686, 63.81005197763443, 73.10680791735649, 69.25394386053085, 62.71565370261669, 56.57485641539097, 52.99475312232971, 51.34135544300079, 49.15532134473324, 52.36612245440483, 62.330415174365044, 68.38013514876366, 67.40313917398453, 60.385348945856094, 70.61436206102371, 69.7022970020771, 69.33353438973427, 62.7456720918417, 72.69003868103027, 73.26980397105217, 73.98326888680458, 69.54006090760231, 76.14232063293457, 42.8861403465271, 3.3912360901013017, 0.8815184386912733, 0.46873973042238504, 1.1611947719939053, 2.533045490272343, 1.90462832339108, 0.721886451356113, 0.130724192422349, 0.19631158240372315, 0.03542415208357852, 0.24768271803623065, 0.0896760489558801, 0.06565666204551235, 9.746562503278255, 46.11664719879627, 43.086906373500824, 43.86417746543884, 28.202147483825684, 40.099388882517815, 55.382157415151596, 57.97384634613991, 71.2483124434948, 77.43787631392479, 42.68391899764538, 1.0954521247185767, 0.10073652068967931, 0.0328999000339536, 0.022277031966950744, 0.060734660728485323, 0.030287198824225925, 0.04376919081551023, 0.030262271939136554, 0.029910245320934337, 0.053980289376340806, 0.09259825543267652, 0.0997862896474544, 0.0833570325630717, 0.019117275151074864, 0.08624764581327327, 0.04634521137631964, 0.0066534875077195466, 0.010435778203827795, 0.025272614584537223, 0.03207322544767521, 0.06486606696853414, 0.021221454917395022, 0.0160641686670715, 0.023976329357537907, 0.039267720057978295, 0.025319004380435217, 0.011712905816239072, 0.026382123505754862, 0.03834458111668937, 0.12134943492128514, 0.12836658221203834, 0.11243881657719612, 0.09616762210498564, 0.22094807995017618, 0.3333333431510255, 0.1978443400003016, 0.12577397836139426, 0.1647897355724126, 0.16538119758479297, 0.14409663970582187, 0.12914230464957654, 0.18631704995641485, 0.12675808102358133, 0.2348117993096821, 0.16152867930941284, 0.0993546491372399, 0.16886273107957095, 0.17475147993536666, 0.13348302250960842, 0.17943976039532572, 0.17160239891381934, 0.10662063112249598, 1.3693466526456177, 72.17021137475967, 105.1923318207264, 89.53474000096321, 85.07887110114098, 84.6894983947277, 57.464856058359146, 54.46764148771763, 55.98595641553402, 58.80926571786404, 73.70858162641525, 68.8567815721035, 27.129265554249287, 1.4392338087782264, 0.12726587330689654, 0.2697946666739881, 0.1752426035818644, 0.7974343537352979, 2.3166433023288846, 3.924248213879764, 3.0356872687116265, 5.956486752256751, 12.17587759718299, 6.967562148347497, 3.862433605827391, 31.849049292504787, 85.81949695944786, 82.58397057652473, 77.56500229239464, 74.42624151706696, 67.13630989193916, 75.3289058804512, 74.61443781852722, 75.15833303332329, 74.00363579392433, 66.27891629934311, 62.192398980259895, 73.26438546180725, 72.97071442008018, 67.253138422966, 64.47610303759575, 76.19864121079445, 70.33807888627052, 59.3963798135519, 53.58290836215019, 56.39063850045204, 59.52555388212204, 60.44502094388008, 58.16499888896942, 53.98990832269192, 50.92954494059086, 55.23261643946171, 51.2965976446867, 53.9612540602684, 54.109563902020454, 53.86937879025936, 55.38392812013626, 56.05394996702671, 52.585986256599426, 58.59782226383686, 61.383536383509636, 70.79137176275253, 68.57460871338844, 77.64238134026527, 40.71913942694664, 39.288664385676384, 72.65033841133118, 66.70490384101868, 68.40664252638817, 63.289928287267685, 60.31063735485077, 55.99527731537819, 54.96914617717266, 54.33494880795479, 59.649427235126495, 66.72042980790138, 70.89979514479637, 63.84099751710892, 74.19991046190262, 71.6756223142147, 65.64084693789482, 59.8676685243845, 57.01917037367821, 53.13378006219864, 51.23064458370209, 56.54279753565788, 67.30022549629211, 72.25338891148567, 68.51971685886383, 63.07799465954304, 72.83545687794685, 71.55377045273781, 72.25860223174095, 66.42011672258377, 77.89767444133759, 79.56539735198021, 77.74240717291832, 71.39338105916977, 78.16489890217781, 43.64852003753185, 3.537698043510318, 4.083955306559801, 9.757558163255453, 10.051786825060844, 5.494161285459995, 2.7235197694972157, 0.812234915792942, 0.18446473841322586, 0.37118513078894466, 0.361245873500593, 0.29106987349223346, 0.3457832563435659, 0.3025101689854637, 14.934200886636972, 65.54493248462677, 62.211340963840485, 79.86787632107735, 44.15455408394337, 41.40336491167545, 63.17255258560181, 67.28058815002441, 81.0234323143959, 88.1366354227066, 49.50719766318798, 1.6287796315737069, 0.21652612660545856, 0.14139750797767192, 0.12371814766083844, 0.16354816703824326, 0.1982331066392362, 0.09893524664221331, 0.19358421937795356, 0.2695284434594214, 0.18525649124057963, 0.2173188145388849, 0.2021564554888755, 0.29839881928637624, 0.12571851024404168, 0.1291027630213648, 0.12480897858040407, 0.18692681333050132, 0.12211557623231784, 0.25175118644256145, 0.12609268625965342, 0.13020560931181535, 0.25906463619321585, 0.12655497004743665, 0.12303490424528718, 0.10351079487008974, 0.1342237601056695, 0.13690608961042017, 0.13507996103726327, 0.1615762955043465], [0.054898793605389073, 0.09330889894044958, 0.03378152323421091, 0.07721176778431982, 0.01893082353490172, 0.04460064483282622, 0.06980632140766829, 0.03778353602683637, 0.025864776071102824, 0.04059210856212303, 0.09428547622519545, 0.01866082093329169, 0.010768064621515805, 0.02644033942488022, 0.018340471033297945, 0.012894353894807864, 0.026183010850218125, 0.0611626090540085, 0.05587416118942201, 0.04579897584335413, 0.055752500920789316, 0.11030444438802078, 0.11399700015317649, 17.989880070090294, 82.2240462899208, 71.71093001961708, 77.12327599525452, 65.02626031637192, 43.7485458701849, 23.769580833613873, 54.040791392326355, 49.65661324560642, 54.899347722530365, 44.04695525765419, 23.99857174605131, 0.597234140150249, 0.1642294437624514, 0.05827055232657585, 0.3074014565208927, 0.30981892836280167, 0.23825938696973026, 1.044799298979342, 1.0590624273754656, 0.9366053889971226, 1.7274307692423463, 1.1513757426291704, 5.924452096223831, 42.99149729311466, 85.3865633904934, 68.97566959261894, 73.90076771378517, 66.25379964709282, 63.87760475277901, 68.76484170556068, 74.1830925643444, 73.52450430393219, 71.72096148133278, 65.91561019420624, 53.59447494149208, 58.14170613884926, 69.48370233178139, 67.7905435860157, 65.68386822938919, 62.13310316205025, 68.32578286528587, 61.46683931350708, 54.27405707538128, 45.92125028371811, 55.995934680104256, 60.91544710099697, 65.54119348526001, 59.607777670025826, 57.02854447066784, 48.40008907020092, 48.53875882923603, 49.48102466762066, 49.518228471279144, 44.20966252684593, 49.28945034742355, 46.98238514363766, 52.32558622956276, 46.600623428821564, 51.56513303518295, 47.826601043343544, 60.22348903119564, 52.706173807382584, 73.31711903214455, 43.03368262946606, 40.80945298075676, 70.5023592710495, 58.02382506430149, 62.70593002438545, 51.284768879413605, 52.103742733597755, 47.04445481300354, 49.55863170325756, 46.23413309454918, 48.97319711744785, 54.618261605501175, 67.07681268453598, 65.49929693341255, 66.06428101658821, 64.84696313738823, 59.04481887817383, 49.9970293790102, 48.642736449837685, 47.99533098936081, 48.51529508829117, 48.35723116993904, 58.968461975455284, 64.49301972985268, 64.56271559000015, 60.31602546572685, 65.0072081387043, 68.15579518675804, 65.78739747405052, 61.299386098980904, 55.905697122216225, 61.29042997956276, 66.07492804527283, 69.51284676790237, 67.06669002771378, 78.59285473823547, 58.89846973121166, 13.3606350235641, 0.13943616009783, 2.1071990160271525, 2.9968360159546137, 0.22920476971194148, 0.9943627647589892, 0.22753113764338195, 0.028390783299983013, 0.12507095671026036, 0.1015215422376059, 0.016945916177064646, 0.03683883398480248, 0.6487575941719115, 19.474794790148735, 45.20865552127361, 39.28984612226486, 30.781566873192787, 22.12560474872589, 32.88881599903107, 49.666306525468826, 60.64471922814846, 56.861908212304115, 62.93775178492069, 15.519615523517132, 0.34315525204874575, 0.05051344669482205, 0.10583030321868137, 0.06035335267370101, 0.0904536119196564, 0.00491608871925564, 0.012216127397550736, 0.0782175337371882, 0.059565893170656636, 0.026563137034827378, 0.007479107780454797, 0.010910426171903964, 0.017941147343663033, 0.030555297817045357, 0.023423794846166857, 0.10968290313030593, 0.03637404544861056, 0.016929288358369377, 0.06933744734851643, 0.07916762377135456, 0.04281215056835208, 0.02284781960042892, 0.03752801458176691, 0.023325081783696078, 0.04055009929288644, 0.07806603171047755, 0.07309901542612351, 0.01593768258317141, 0.0063586099713575095, 0.11900724653969519, 0.036790609228773974, 0.04005848582892213, 0.011551380157470703, 0.039175203928607516, 0.11840929815662093, 0.05400421250669751, 0.05469003488542512, 0.08736935749766417, 0.07094467946444638, 0.04876564438745845, 0.038699821234331466, 0.06622719549341127, 0.039966296244529076, 0.020902270189253613, 0.08732377478736453, 0.12543875025585294, 0.047144148193183355, 0.07516508776461706, 0.030158245099300984, 0.11402324991649948, 0.027860516929649748, 24.94052790105343, 97.59381875395775, 80.25401160120964, 87.34825372695923, 69.74706619977951, 60.95526896417141, 35.29869608581066, 56.91738523542881, 47.68733851611614, 47.008888721466064, 44.69263941049576, 27.530679814517498, 0.7678860111627728, 0.03126980234810617, 0.037679598244722, 0.3929947433061898, 0.8294845651835203, 1.8942099949344993, 2.1627292362973094, 2.2692978428676724, 1.956825410015881, 1.0681953560560942, 0.5490945826750249, 6.478639058768749, 46.63412243127823, 86.96289360523224, 70.13149917125702, 74.86219212412834, 67.07243531942368, 66.77066311240196, 72.23452672362328, 75.38302257657051, 76.64848387241364, 74.1389237344265, 68.11958312988281, 57.55004368722439, 60.45577056705952, 72.11266726255417, 69.67281818389893, 65.74945271015167, 63.778361678123474, 70.45908719301224, 64.13887113332748, 55.6276698410511, 48.89865651726723, 57.34891287982464, 63.84437933564186, 67.99246475100517, 64.63443294167519, 60.779095217585564, 51.24659612774849, 49.853389486670494, 51.9397359341383, 52.32641078531742, 46.47058680653572, 52.992518842220306, 49.94094058871269, 53.630219623446465, 49.10022810101509, 54.784517884254456, 50.39458304643631, 64.2460709810257, 57.39808604121208, 74.25620064139366, 45.82948140799999, 42.51760572195053, 73.4053198993206, 60.21365135908127, 65.38138926029205, 54.06515568494797, 54.62811827659607, 49.51473645865917, 51.88444510102272, 49.57561679184437, 51.147170662879944, 57.35670246183872, 69.5241017639637, 67.54167214035988, 68.68275091052055, 67.45545476675034, 62.69135020673275, 52.27660685777664, 50.91495752334595, 50.84903486073017, 50.86445443332195, 52.084166184067726, 62.40788161754608, 67.11557820439339, 68.09525683522224, 60.69443956017494, 69.25197556614876, 71.95565208792686, 68.54158848524094, 63.80047649145126, 58.6129492521286, 63.47381182014942, 69.25376906991005, 72.92852148413658, 70.86831763386726, 82.71787539124489, 63.64940419793129, 16.41934834420681, 0.9147366124670953, 0.44507267070002854, 1.0282045206986368, 1.8195602693594992, 2.4152586981654167, 0.9145490569062531, 0.3636438417015597, 0.55280965520069, 0.19734247005544603, 0.07308023166842759, 0.03314309069537558, 0.554131509270519, 21.466347724199295, 47.76701644062996, 41.44485868513584, 28.66168152540922, 27.956572361290455, 42.961862683296204, 56.535862907767296, 69.08644884824753, 63.978542536497116, 72.63137742877007, 23.20149801671505, 0.2622763841645792, 0.06705771811539307, 0.10934115896816365, 0.024137707514455542, 0.04018387167889159, 0.11261811945587397, 0.07100471179001033, 0.04799919137440156, 0.05117202854307834, 0.015850151830818504, 0.028521048770926427, 0.0186559932626551, 0.02129729498847155, 0.03665967582492158, 0.026674865512177348, 0.014290908839029726, 0.04702606878709048, 0.019130646796838846, 0.01652810187806608, 0.029221265103842597, 0.03844748360279482, 0.0086114205805643, 0.026202776098216418, 0.05536314427445177, 0.07411813261569478, 0.03748537077626679, 0.027046610994148068, 0.06486531739938073, 0.11774736922234297, 0.1683758822036907, 0.11130780578241684, 0.17854622943559662, 0.07704700357862748, 0.10653918783646077, 0.32109776220750064, 0.09186623065033928, 0.15889709786279127, 0.2463957597501576, 0.1674144744174555, 0.2055473133805208, 0.1598009149893187, 0.15160888113314286, 0.13409529434284195, 0.12319070330704562, 0.16303808894008398, 0.31035113730467856, 0.16167589172255248, 0.24497481412254274, 0.20051270228577778, 0.28332755144219846, 0.4197095660492778, 31.55568603426218, 113.46175208687782, 91.10943630337715, 98.74734565615654, 83.69987949728966, 61.20012402534485, 33.94243486225605, 65.62698528170586, 66.78496554493904, 77.41142973303795, 63.301323875784874, 36.95260293781757, 1.286818643566221, 0.33895368687808514, 0.2191882993793115, 1.0059038735926151, 1.5167171135544777, 3.0069866962730885, 2.427641046233475, 4.4897060841321945, 5.5734986532479525, 6.9180284813046455, 4.194965874776244, 9.406274612993002, 49.775360673666, 93.59926789999008, 71.94071128964424, 78.61435398459435, 69.65587109327316, 70.63394621014595, 74.80949655175209, 78.82018133997917, 78.0218517780304, 76.95736929774284, 70.02195864915848, 60.457244887948036, 63.11467029154301, 76.56693264842033, 73.0544239282608, 64.54961389303207, 66.66089460253716, 73.71580123901367, 67.09369137883186, 58.479318022727966, 50.917271599173546, 62.01313219964504, 65.68331345915794, 71.561309248209, 67.32734084129333, 63.36452588438988, 53.83546561002731, 52.99811214208603, 54.12510886788368, 53.955520167946815, 48.07298742234707, 55.67065693438053, 53.32810923457146, 56.22324228286743, 52.882043570280075, 57.52790987491608, 53.53258766233921, 66.23069688677788, 59.836365804076195, 78.27152118086815, 48.93845558166504, 46.77386753261089, 73.58829528093338, 63.94684463739395, 68.54441553354263, 56.38144299387932, 57.2260844707489, 51.832182705402374, 53.40150609612465, 51.994958370923996, 54.15628619492054, 61.48993447422981, 73.6270759999752, 71.40636876225471, 72.15160757303238, 71.57100632786751, 66.41115680336952, 54.838797971606255, 52.62093298137188, 54.58593674004078, 53.71525526046753, 54.87038567662239, 65.90722024440765, 70.03452837467194, 71.06151446700096, 63.298804610967636, 69.44309771060944, 74.95439037680626, 70.98089799284935, 67.74873062968254, 61.04055918753147, 67.1493735909462, 72.53813043236732, 76.87019437551498, 74.26796481013298, 85.87615951895714, 64.91608142852783, 16.299367882311344, 2.7573773777112365, 8.471779357641935, 11.614197436720133, 4.156203679740429, 4.2419432289898396, 1.0267233126796782, 0.32541456806939095, 0.8573943644296378, 0.5401676741894335, 0.30950600921642035, 0.17687437852146104, 1.2560620252043009, 31.407030411064625, 62.89340056478977, 55.52048519253731, 42.680734768509865, 33.714948669075966, 48.43233793973923, 67.83180177211761, 79.67949002981186, 73.17459627985954, 81.93339228630066, 27.343309968709946, 0.47672746586613357, 0.13159222318790853, 0.24258802266558632, 0.1288579433457926, 0.24425966577837244, 0.22563506907317787, 0.10287570199579932, 0.28126185759902, 0.257785203284584, 0.15654874965548515, 0.10813450106070377, 0.14998794154962525, 0.1563387515489012, 0.18251392903039232, 0.11247015005210415, 0.23806987213902175, 0.1204844618041534, 0.10386770853074268, 0.12282719937502407, 0.19509302044752985, 0.07686183773330413, 0.12059712724294513, 0.12697348196525127, 0.14733520889421925, 0.18182457773946226, 0.1963504560990259, 0.26303189049940556, 0.11839774291729555], [0.07174979837145656, 0.0700006156694144, 0.031341430731117725, 0.012742372255161172, 0.08096781428321265, 0.01662485195993213, 0.10447612861753441, 0.06669206195510924, 0.10283058683853596, 0.051274110956001095, 0.0524700299865799, 0.04309559903049376, 0.027741099802369718, 0.035416801110841334, 0.009205472688336158, 0.02448777115205303, 0.05011923269194085, 0.14904259383911267, 0.023385765343846288, 0.04507373429078143, 0.046240420124377124, 0.04730732791358605, 0.4271170904394239, 52.439614310860634, 77.92835399508476, 73.31160172820091, 51.231252551078796, 43.60503897070885, 18.6963514611125, 23.08658268302679, 16.52388833463192, 32.698153629899025, 44.06434312462807, 27.23218873143196, 1.6323476401157677, 0.08373464472242631, 0.07779373772791587, 0.5069606623146683, 0.13091945147607476, 0.3737093828385696, 1.1135643278248608, 0.7487287453841418, 1.371944050770253, 1.1689514620229602, 0.9812807198613882, 18.49711675196886, 54.04283568263054, 78.41095089912415, 69.37315106391907, 70.31854033470154, 65.05105778574944, 62.494630962610245, 69.68158051371574, 72.2991992533207, 74.67850998044014, 67.90918841958046, 72.11331322789192, 64.56322476267815, 52.16572120785713, 59.96887989342213, 66.9499222934246, 69.41008508205414, 65.64489752054214, 57.62953922152519, 67.42910698056221, 60.88177710771561, 49.38495062291622, 46.46716319024563, 56.60590074956417, 61.38148069381714, 66.30126670002937, 64.07544493675232, 63.381940349936485, 50.10620892047882, 49.46019798517227, 51.73925869166851, 53.11584122478962, 48.54485370218754, 49.28278170526028, 49.44361187517643, 54.44745697081089, 51.4251409471035, 55.32778613269329, 49.76325452327728, 61.011946722865105, 60.525424629449844, 70.01317352056503, 41.90319389104843, 39.94237370789051, 76.80303677916527, 56.69146455824375, 57.99591176211834, 45.9032316505909, 48.202564269304276, 45.33502534031868, 49.649712815880775, 46.12235829234123, 46.387169882655144, 47.19327762722969, 58.26928049325943, 62.66401447355747, 63.44449259340763, 55.83093233406544, 52.82181300222874, 46.237233728170395, 46.22782163321972, 43.49448390305042, 46.25933714210987, 46.63479879498482, 58.78984875977039, 61.790418550372124, 63.96761432290077, 60.61944678425789, 64.69170346856117, 67.79052078723907, 67.42488160729408, 63.40362958610058, 59.55050714313984, 56.580126732587814, 58.91212239861488, 62.61677160859108, 70.84226623177528, 63.42757970094681, 74.08632695674896, 75.72203278541565, 36.89819745719433, 2.3277824046090245, 1.6067935363389552, 2.8145372355356812, 0.7832807069644332, 1.1808398365974426, 0.14432168856728822, 0.027667556678352412, 0.32183842558879405, 0.16941620997386053, 0.10006164127844386, 0.0035757180648943176, 1.1481183674186468, 27.660247161984444, 33.843875750899315, 44.91577863693237, 34.76259425282478, 33.249667435884476, 44.039207473397255, 48.94739270210266, 58.07932488620281, 60.62890827655792, 47.04823940992355, 6.804780783131719, 0.10022256858064793, 0.04543140123132616, 0.05825438092870172, 0.01536630679765949, 0.1331878555356525, 0.05669053476594854, 0.05630429513985291, 0.0447234591410961, 0.047739959190948866, 0.0086406788250315, 0.017825452086981386, 0.060317139577819034, 0.02800721540552331, 0.08874343649949878, 0.0204614270478487, 0.015186810032901121, 0.08865322102792561, 0.023840579415264074, 0.05215764518652577, 0.031099742918740958, 0.035396410603425466, 0.019568836760299746, 0.06939770231838338, 0.06716846881317906, 0.01277194312933716, 0.03024387224286329, 0.03065212025830988, 0.031978471743059345, 0.036553578393068165, 0.02622620013426058, 0.03248011533287354, 0.07996568485395983, 0.02843229904101463, 0.07676733264815994, 0.03233941526559647, 0.07473775913240388, 0.035885667748516425, 0.05540595877391752, 0.025102833460550755, 0.07371720217633992, 0.037727904636994936, 0.07620318167028017, 0.05007182429835666, 0.05350124789401889, 0.1055243231530767, 0.07229355513118207, 0.07606876388308592, 0.023161248973337933, 0.04058194856042974, 0.6511633400805295, 65.09149521589279, 88.37413027882576, 83.01963999867439, 59.59196671843529, 55.17667584121227, 31.546712815761566, 31.469932235777378, 26.47665437310934, 25.66422376781702, 45.62523856759071, 33.31194989383221, 1.8680153880268335, 0.06889047406730242, 0.03671066508104559, 1.0291653941385448, 0.8659787569195032, 1.4872548007406294, 3.106945320032537, 2.7302114479243755, 1.3538512028753757, 0.5181554553564638, 2.0066635357216, 19.316069707274437, 57.418513745069504, 81.02689772844315, 72.55104213953018, 71.28283739089966, 68.83781298995018, 64.65338632464409, 73.28597590327263, 74.4439409673214, 75.60050770640373, 70.2945028245449, 73.70415106415749, 66.46115452051163, 54.14617493748665, 63.40566627681255, 68.91761630773544, 71.24778047204018, 64.26149055361748, 61.03293299674988, 69.40751641988754, 62.939503490924835, 53.34775798022747, 48.62272672355175, 59.165272414684296, 66.00152358412743, 70.02593323588371, 66.22324928641319, 66.36872828006744, 52.31832101941109, 51.52534916996956, 55.03543362021446, 54.84137803316116, 51.510982140898705, 52.014379128813744, 51.49857580661774, 56.9795460999012, 54.520375058054924, 56.842141672968864, 52.376913875341415, 62.7700287848711, 62.4988829344511, 72.77088314294815, 44.061759263277054, 42.95384131371975, 76.77050292491913, 59.499833062291145, 60.21835170686245, 51.32754698395729, 51.679073721170425, 48.04585687816143, 51.758694648742676, 48.13591584563255, 48.1346695125103, 49.65380899608135, 61.27753347158432, 64.01472419500351, 65.9157545864582, 58.61568510532379, 56.48635156452656, 48.270143643021584, 50.08068189024925, 46.14130027592182, 48.57983462512493, 49.90243725478649, 60.69573909044266, 66.13717630505562, 67.75077491998672, 62.52270385622978, 64.37974020838737, 70.05440130829811, 69.79330211877823, 66.07420608401299, 61.42191432416439, 59.69935655593872, 63.064889162778854, 65.72871342301369, 73.39984059333801, 66.80333375930786, 76.76522880792618, 80.26104122400284, 41.96737624704838, 3.3888315316289663, 0.34922720747999847, 1.4202664140611887, 1.1690228269435465, 2.2960519697517157, 0.7385033159516752, 0.5703464266844094, 0.6468739046249539, 0.430247588083148, 0.06605790418689139, 0.06700314799672924, 1.5275765745900571, 30.70678498595953, 36.509079337120056, 35.883560702204704, 34.232743084430695, 42.9429928958416, 52.624812573194504, 57.27734751999378, 64.28992822766304, 71.03154167532921, 56.64884224534035, 10.263960789889097, 0.19945913460105658, 0.06913682256708853, 0.035848831248586066, 0.04005073038570117, 0.09026882456964813, 0.02120329641911667, 0.05492350712302141, 0.02251715755846817, 0.01082953949662624, 0.03268960506829899, 0.04445014099474065, 0.0550787198881153, 0.01730531788780354, 0.05345240715541877, 0.10334778213291429, 0.05049928651715163, 0.059517946720006876, 0.03195575460267719, 0.06818141875555739, 0.02732331518927822, 0.014798035044805147, 0.04887770126515534, 0.11915753144421615, 0.06885580092784949, 0.015880624414421618, 0.007340268184634624, 0.02793986364849843, 0.1623999755247496, 0.19233868777519092, 0.083421502931742, 0.11519285981194116, 0.17559683066792786, 0.17048073175828904, 0.18597480113385245, 0.10077402883325703, 0.21975262847263366, 0.11899756151251495, 0.14921221911208704, 0.11369096071575768, 0.18282739736605436, 0.1269647543085739, 0.23922334774397314, 0.1477618102217093, 0.1285832151188515, 0.22238873702008277, 0.21560204884735867, 0.10414489326649345, 0.16687552677467465, 0.10022935923188925, 1.3322304817847908, 79.39113110303879, 97.48548656702042, 95.05132958292961, 71.3938370347023, 62.37135797739029, 29.269793294370174, 32.347367852926254, 24.9519082903862, 47.7214340865612, 63.629763051867485, 42.33605906367302, 3.5616780817508698, 0.1850491648656316, 0.2127315997495316, 1.5706708934158087, 1.799571798183024, 2.1304300194606185, 3.3160530868917704, 4.7599076852202415, 5.380940185859799, 5.621731365099549, 3.6537587782368064, 21.84201266616583, 62.794058695435524, 85.68933874368668, 72.37032383680344, 75.10113850235939, 70.90818509459496, 68.8031056523323, 75.77327683568001, 76.13551899790764, 78.2982337474823, 73.97601127624512, 76.36243522167206, 68.90676409006119, 57.325122356414795, 65.73912486433983, 71.55624032020569, 72.86634162068367, 65.59500619769096, 61.03659600019455, 70.80964118242264, 67.47046396136284, 55.23353599011898, 52.32085928320885, 63.674190267920494, 66.56687244772911, 73.26316192746162, 70.34094393253326, 68.78092244267464, 55.82196481525898, 54.17395144701004, 57.86800682544708, 58.31284515559673, 54.489307925105095, 55.04502810537815, 55.86851991713047, 60.599805638194084, 57.82709822058678, 60.289917066693306, 55.67576766014099, 65.901338160038, 66.50308907032013, 75.01535430550575, 48.25268737971783, 46.39072649180889, 80.64678892493248, 63.52923184633255, 63.50326403975487, 54.23026442527771, 52.2113985568285, 51.44599802792072, 54.22250144183636, 51.01895794272423, 50.10051682591438, 52.8460481017828, 64.27200838923454, 67.61933997273445, 68.13324719667435, 60.81243082880974, 58.831996098160744, 51.07666924595833, 50.950550213456154, 48.34785707294941, 50.59043973684311, 52.51884385943413, 63.901125490665436, 68.51403996348381, 69.99544367194176, 65.68315386772156, 66.86311975121498, 73.4343883395195, 74.25747737288475, 68.34026008844376, 66.32159560918808, 64.61298689246178, 66.2215393781662, 69.1733729839325, 79.18341144919395, 69.49317142367363, 79.93766337633133, 79.53934594988823, 42.982598170638084, 2.84891945309937, 4.892584690824151, 7.281413907185197, 4.251418495550752, 3.5696008941158652, 0.85911157540977, 0.36563312401995063, 0.9099241707008332, 0.6738457479514182, 0.27879887726157904, 0.14209729386493564, 3.2782631646841764, 44.03508849442005, 51.31754592061043, 60.74025370180607, 49.07571941614151, 46.89082905650139, 57.94418513774872, 67.9121370613575, 75.4684191942215, 79.65404659509659, 68.09892743825912, 11.578495502471924, 0.26619133190251887, 0.1996158019755967, 0.11421801915275864, 0.17663104314124212, 0.1893107104115188, 0.10012872400693595, 0.1358491971041076, 0.26582726393826306, 0.0788063314394094, 0.08640934494906105, 0.14834513829555362, 0.23070877650752664, 0.2113769279094413, 0.14078211912419647, 0.20114820334129035, 0.0945813259750139, 0.10920905668172054, 0.09422396702575497, 0.1979211819707416, 0.18703414272749797, 0.134669033868704, 0.07032112698652782, 0.2849775832146406, 0.1859301090007648, 0.14602687675505877, 0.07389064950984903, 0.13421801588265225], [0.05349274288164452, 0.04060671402839944, 0.0749822671059519, 0.036635092183132656, 0.0742488174000755, 0.025942191350623034, 0.046123917782097124, 0.03607888218539301, 0.09569908201228827, 0.0559521349350689, 0.07937443064292893, 0.016169698355952278, 0.049718387599568814, 0.02745519668678753, 0.23528479970991611, 0.07656131987459958, 0.11838197970064357, 0.016491818278154824, 0.11609445049543865, 0.14199107768945396, 0.19303630659123883, 0.29090199968777597, 13.57484757900238, 79.44604575634003, 79.76966679096222, 68.56892421841621, 54.86985370516777, 26.14234071224928, 27.634361051023006, 28.853932209312916, 38.787729665637016, 66.59772679209709, 33.94653484225273, 6.283013205975294, 0.07195961094112135, 0.040323191351490095, 0.0476791995606618, 0.21122043865034357, 0.29270535917021334, 0.1272915516165085, 0.455019497894682, 0.7652896223589778, 0.7588220725301653, 2.266162298619747, 28.783497288823128, 68.79892587661743, 71.92467615008354, 68.02815243601799, 69.84496414661407, 61.83094337582588, 64.09031733870506, 69.93090033531189, 69.90559369325638, 75.01983046531677, 68.53074386715889, 70.99611237645149, 67.97709837555885, 55.85473045706749, 51.01919732987881, 61.019029542803764, 64.18876245617867, 70.16667768359184, 59.56326685845852, 60.98998390138149, 65.63168942928314, 57.23195515573025, 50.0327018648386, 45.58206908404827, 57.15600483119488, 64.69649121165276, 61.76404416561127, 64.92469936609268, 63.858248591423035, 55.84499537944794, 48.192521408200264, 47.48747684061527, 50.838361233472824, 49.08403716981411, 54.211755618453026, 50.05927763879299, 54.422439113259315, 53.342043086886406, 60.6198837608099, 57.55922019481659, 65.1517827808857, 56.794446632266045, 73.2541336119175, 39.69303488731384, 42.94384405016899, 71.46059185266495, 55.935924500226974, 57.13881455361843, 45.070502534508705, 48.76204624772072, 45.44889383018017, 47.94938385486603, 45.41380651295185, 47.5197447091341, 44.701675325632095, 48.50244797766209, 45.27001842856407, 48.892067670822144, 46.349981278181076, 46.44459620118141, 46.487191915512085, 47.71223857998848, 44.18851286172867, 47.50600844621658, 46.2525849044323, 53.44947852194309, 62.5854878872633, 64.66198146343231, 61.94369092583656, 59.188622161746025, 63.02500270307064, 67.78876528143883, 67.19266086816788, 64.56041291356087, 53.64323392510414, 53.13982553780079, 55.66648095846176, 59.38980616629124, 68.28431949019432, 65.50219997763634, 64.61001545190811, 75.08463218808174, 57.84033291041851, 11.923473291099072, 0.13114795874571428, 2.238810178823769, 1.8289866135455668, 0.6539167079608887, 0.8715837530326098, 0.3859920456307009, 0.09883858932880685, 0.14044423412997276, 0.0859599225805141, 0.018229846500616986, 6.457747779786587, 33.86112302541733, 32.739377617836, 29.595008343458176, 18.7291095033288, 22.4275878444314, 32.62239709496498, 47.735379338264465, 57.86033123731613, 49.73735511302948, 27.62232519686222, 2.224401351995766, 0.24474929028656334, 0.09979628637665883, 0.06786190933780745, 0.046113349599181674, 0.04345200060924981, 0.07362724645645358, 0.10897411499172449, 0.04938901503919624, 0.034480474205338396, 0.06610363532672636, 0.037097023450769484, 0.04468117156648077, 0.06269101024372503, 0.02456735721352743, 0.039113475795602426, 0.04694424700574018, 0.020740290892717894, 0.022379427937266883, 0.16260229982435703, 0.044732012393069454, 0.057895033023669384, 0.052691078672069125, 0.011428266207076376, 0.04767303973494563, 0.04447927029104903, 0.017225900664925575, 0.031253582710633054, 0.03362466290127486, 0.0802258298790548, 0.02654023435752606, 0.03261910846049432, 0.0021718107564083766, 0.0343631072610151, 0.03556581323209684, 0.13324691564776003, 0.03768202135688625, 0.09449068005778827, 0.024612407432869077, 0.09409124133526348, 0.014998718270362588, 0.012391462569212308, 0.13169729645596817, 0.06031619705026969, 0.04021276348794345, 0.09475455066422, 0.027792532491730526, 0.09525967863737606, 0.23867257026722655, 17.053788900375366, 91.53307557106018, 85.7872822880745, 78.97812366485596, 62.95818328857422, 38.26928548514843, 32.076134607195854, 33.42757768929005, 29.882523715496063, 53.85402761399746, 42.7768050134182, 7.025215979665518, 0.06441799530875869, 0.10998987025232054, 0.21619769657263532, 0.9661903639789671, 0.9226977790240198, 2.0455164508894086, 3.6652683606371284, 2.1055814903229475, 0.20125545852351934, 2.7010860107839108, 32.079136446118355, 70.06315603852272, 75.55516853928566, 71.58156216144562, 71.1493581533432, 66.05833813548088, 66.45088747143745, 70.53582027554512, 72.50386387109756, 75.9759883582592, 70.17519682645798, 72.88898080587387, 70.9791348874569, 57.9464840143919, 53.63800920546055, 63.96515965461731, 67.19921931624413, 71.94786250591278, 62.81079679727554, 63.31562250852585, 69.22627374529839, 61.48174971342087, 52.546548172831535, 47.56228342652321, 61.092038825154305, 67.40951523184776, 65.55890053510666, 66.73211798071861, 65.70735856890678, 58.81147339940071, 51.64359122514725, 49.4699140638113, 54.0744461864233, 52.27213829755783, 56.853788048028946, 55.080875381827354, 58.70468012988567, 55.65649129450321, 62.60059967637062, 61.174095422029495, 67.69640743732452, 60.005323737859726, 73.98052543401718, 40.78358396887779, 46.67734511196613, 74.49529901146889, 58.49537596106529, 59.95403788983822, 49.00022126734257, 50.39341650903225, 48.25701914727688, 49.7500654309988, 48.507763892412186, 48.95570285618305, 47.741227224469185, 51.32065415382385, 48.12676593661308, 52.93739140033722, 50.87950922548771, 50.928591191768646, 49.16906140744686, 49.748883694410324, 48.32674540579319, 50.029757022857666, 49.38397027552128, 56.78976908326149, 65.73784813284874, 67.09288582205772, 63.93990620970726, 60.156468227505684, 65.9524454176426, 69.82119262218475, 71.5753684937954, 66.7749872803688, 56.55299238860607, 55.79248979687691, 60.88645085692406, 62.455280274152756, 72.50823363661766, 71.39784201979637, 68.98868769407272, 76.22271671891212, 63.599911853671074, 14.150022715330124, 1.024650048930198, 1.3677396951243281, 1.315676907543093, 2.4004725040867925, 2.166781243868172, 0.9312537324149162, 0.5871554184705019, 0.5417144286911935, 0.17041003477061167, 0.05106431694002822, 6.9893178809434175, 38.26336160302162, 39.52438473701477, 29.090262427926064, 22.768980525434017, 31.859749518334866, 41.49671450257301, 53.931604251265526, 68.59329611063004, 65.53227916359901, 40.13490177690983, 3.5232562059536576, 0.2764932025456801, 0.0982615324028302, 0.11342710495227948, 0.03596150410885457, 0.027231663661950734, 0.05748966825194657, 0.05614254034298938, 0.06084868800826371, 0.03754761099116877, 0.0527198999770917, 0.020653194296755828, 0.01285121285036439, 0.006245695449251798, 0.014830140353296883, 0.0247100703563774, 0.03607938684581313, 0.015932216665532906, 0.0937148611410521, 0.18657703913049772, 0.04449819134606514, 0.03944774281990249, 0.010324203722120728, 0.0205752298279549, 0.03258694378018845, 0.03312949826067779, 0.05397756198362913, 0.11117122092400678, 0.1265900587895885, 0.12239713963936083, 0.11056886418373324, 0.16482210805406794, 0.11650309184915386, 0.07967881509102881, 0.15500748704653233, 0.19017206184798852, 0.13127642450854182, 0.1532001348095946, 0.18255559320095927, 0.32698376511689276, 0.11633372632786632, 0.38523947820067406, 0.2819542813813314, 0.2164999139495194, 0.1719584219972603, 0.331992786959745, 0.23593308054842055, 0.3772597579518333, 0.6842137291096151, 22.103784419596195, 106.18957310914993, 101.35748639702797, 88.42972129583359, 76.11351817846298, 42.19349071383476, 38.426996022462845, 38.52056220173836, 57.34439492225647, 94.82249826192856, 51.936741694808006, 10.572580229490995, 0.2675598522182554, 0.4580917221028358, 0.6555855902843177, 2.111251736059785, 1.3015301479026675, 2.114398442208767, 3.753798147663474, 6.716526718810201, 4.870762936770916, 3.6323963245376945, 33.322950303554535, 74.29616689682007, 75.77909052371979, 73.76646772027016, 74.57790657877922, 68.66759732365608, 69.67953622341156, 75.11541813611984, 75.33455237746239, 76.59450396895409, 74.07116577029228, 76.18309244513512, 74.24477085471153, 59.25522118806839, 55.53269773721695, 67.10408762097359, 71.74572095274925, 76.27598986029625, 61.679688692092896, 63.92099842429161, 71.90462082624435, 64.34386253356934, 54.42625030875206, 49.36917766928673, 63.13889779150486, 71.64429679512978, 65.73553025722504, 68.90755444765091, 69.116520434618, 61.8824116140604, 54.5132352411747, 52.53063082695007, 55.78204035758972, 53.13106320798397, 59.16216418147087, 56.64617098867893, 60.387013256549835, 58.529053553938866, 65.44424548745155, 65.7778599858284, 70.87701916694641, 64.07691925764084, 76.51403948664665, 44.05255235731602, 50.34587725996971, 77.11887583136559, 62.52921290695667, 62.95152224600315, 51.59543640911579, 53.25219690799713, 50.63840076327324, 52.05239228904247, 52.32281997799873, 50.75918488204479, 50.08719854056835, 52.83306419849396, 49.65593308210373, 54.7755541652441, 51.28257259726524, 52.302430272102356, 52.31851100921631, 53.3851707726717, 51.770614609122276, 53.31283785402775, 51.32090874016285, 60.15658602118492, 69.6970684826374, 70.11813908815384, 66.28963932394981, 61.269090324640274, 67.05773770809174, 71.92159831523895, 74.63668942451477, 69.54000771045685, 58.57800252735615, 59.229568764567375, 64.70346763730049, 65.10678559541702, 76.27107292413712, 72.30969429016113, 70.85859015583992, 78.04549410939217, 67.67388224601746, 12.92405555024743, 2.0023830654099584, 10.82881947979331, 6.48012145422399, 3.379649086855352, 2.9417230607941747, 1.0914571140892804, 0.6259898096323013, 0.39000753953587264, 0.44453298090957105, 0.10645784845110029, 10.800454951822758, 52.84106656908989, 49.69632491469383, 42.3287558555603, 27.087144814431667, 36.1041084676981, 48.425536304712296, 65.13011634349823, 76.8980772793293, 74.2127613723278, 45.58608166873455, 3.8501512398943305, 0.5119125684723258, 0.35975240520201623, 0.15116239024791867, 0.1274882207508199, 0.16923248389502987, 0.32012685493100435, 0.22489399008918554, 0.1423119378159754, 0.130421782087069, 0.12053788159391843, 0.1254322935710661, 0.09265186818083748, 0.25220259034540504, 0.15021879400592297, 0.08287922304589301, 0.15249806310748681, 0.30282270221505314, 0.21033768367487937, 0.36393152782693505, 0.2041304495651275, 0.13666468381416053, 0.10018409564509057, 0.06861810586997308, 0.1695116946939379, 0.14025731681613252, 0.08901311812223867], [0.12866839882917702, 0.02045543420535978, 0.03285571998276282, 0.016138227583724074, 0.0665970151021611, 0.04938544901960995, 0.0023527544772150577, 0.027157408076163847, 0.02735964888415765, 0.024320426127815153, 0.039857493684394285, 0.04090547299711034, 0.050252481596544385, 0.03294681489933282, 0.012122332918806933, 0.06178442490636371, 0.03463302266027313, 0.06700054305838421, 0.05424738090368919, 0.04817292443476617, 0.03200172694050707, 0.2028766059083864, 46.594441160559654, 82.70952343940735, 73.1465993821621, 70.52932262420654, 46.03448420763016, 29.748881086707115, 31.40608426183462, 47.786289006471634, 50.121408104896545, 37.696732208132744, 17.259449064731598, 0.11964422446908429, 0.05575503164436668, 0.10470309222000651, 0.2814724494237453, 0.1756513785221614, 0.5261560447979718, 1.3799159042537212, 3.047900050878525, 0.8867702318821102, 2.0941925514489412, 33.41454818844795, 68.94701912999153, 73.05317759513855, 71.70861974358559, 69.14069473743439, 65.5812281370163, 66.6742242872715, 71.94351553916931, 69.96199026703835, 75.25819167494774, 64.2363891005516, 69.95688334107399, 69.01160046458244, 60.12454614043236, 49.22763526439667, 53.191951140761375, 61.49577856063843, 66.42438769340515, 65.96284165978432, 59.812613278627396, 60.84679238498211, 66.80660158395767, 55.24374604225159, 46.59162551164627, 43.4143728017807, 56.17595762014389, 64.71175879240036, 62.185889929533005, 62.84263528883457, 63.05697798728943, 57.97325357794762, 57.31358237564564, 51.81544080376625, 55.09838864207268, 54.564965665340424, 57.13049679994583, 56.529061272740364, 61.69457629323006, 58.105326890945435, 64.85466912388802, 60.238920003175735, 68.5695929825306, 61.00193805992603, 68.67543250322342, 35.130881890654564, 40.23511379957199, 73.41487258672714, 53.54579195380211, 54.780949875712395, 46.17672197520733, 49.75239470601082, 45.81905476748943, 51.0704679787159, 48.593833073973656, 50.00718243420124, 43.330955877900124, 45.95950663089752, 44.46938619017601, 47.682334184646606, 46.320935636758804, 47.21440829336643, 43.50321963429451, 46.87820613384247, 46.29285894334316, 46.75103075802326, 44.410914927721024, 50.42125761508942, 55.39703741669655, 58.72037708759308, 63.02030235528946, 63.613822907209396, 55.12891240417957, 64.03398916125298, 64.7134231030941, 67.47885391116142, 59.85117360949516, 53.3684478700161, 51.947297528386116, 56.41386665403843, 58.92989404499531, 67.19226568937302, 68.84003207087517, 71.10993906855583, 67.17572897672653, 60.56371137499809, 12.49598192051053, 0.42200562253128737, 2.4713634001091123, 1.2281702156178653, 1.7656589741818607, 0.6121694762259722, 0.38049142516683787, 0.3640328755136579, 0.19652012590086088, 0.06904435838805512, 0.04845532646868378, 16.018657945096493, 37.11113803088665, 43.25073838233948, 25.691308714449406, 16.13992653787136, 24.7292972356081, 44.888211116194725, 53.83497543632984, 60.39348430931568, 52.34190255403519, 21.91420119255781, 0.9695873223245144, 0.2872698992723599, 0.019901795749319717, 0.0461619899579091, 0.04187661405012477, 0.07252269322634675, 0.05396443710196763, 0.006027035087754484, 0.057301793567603454, 0.03515146476274822, 0.02633929230796639, 0.02737621918640798, 0.0099231573221914, 0.043741761037381366, 0.03551199639332481, 0.02634597163705621, 0.01979588756512385, 0.022026382721378468, 0.04088588771992363, 0.03455790247244295, 0.010548867594479816, 0.032209891942329705, 0.03430025106354151, 0.06442024401621893, 0.03094282692472916, 0.029519398813135922, 0.02690427820198238, 0.020240870035195258, 0.0260191075358307, 0.05430368393717799, 0.015608656976837665, 0.057594633908593096, 0.040316040758625604, 0.061436840042006224, 0.0421637027466204, 0.046206889892346226, 0.04240611786372028, 0.035440453357296064, 0.038125539940665476, 0.06061202824639622, 0.03371755010448396, 0.012361143981252098, 0.06945996108697727, 0.04016026396129746, 0.07966443969053216, 0.038735704074497335, 0.008182487981684972, 0.22182028158567846, 56.875576078891754, 94.69328239560127, 82.23796874284744, 78.56589138507843, 56.753990203142166, 39.02900151908398, 36.176361590623856, 32.79253676533699, 48.18350449204445, 48.232989236712456, 20.49986768513918, 0.29007391131017357, 0.08189925414626487, 0.3072138119023293, 0.7410352863371372, 0.8202104503288865, 1.4486384228803217, 3.34093795157969, 1.9012277433648705, 0.45712093356996775, 3.3892264729365706, 36.42074927687645, 70.46820670366287, 74.78022292256355, 72.87131935358047, 72.3508232831955, 69.06916737556458, 68.4097507596016, 72.90232568979263, 72.26075291633606, 77.27210640907288, 65.65733805298805, 72.19136103987694, 71.24784886837006, 63.51500540971756, 52.04042673110962, 55.489877834916115, 63.62825073301792, 67.85667523741722, 69.13677334785461, 60.25267146527767, 64.64093059301376, 69.94375124573708, 58.75048667192459, 48.78683231770992, 46.39038071036339, 58.659523352980614, 68.29423695802689, 63.85327085852623, 64.33503180742264, 65.06975278258324, 59.195970967411995, 59.03214655816555, 55.310861840844154, 57.15923085808754, 57.610411047935486, 61.3504059612751, 59.000061079859734, 63.58037330210209, 60.66100895404816, 66.5905299782753, 64.67495396733284, 70.50492033362389, 63.75447615981102, 70.60545533895493, 37.510086223483086, 43.32988813519478, 75.16020253300667, 55.641128718853, 57.62475907802582, 47.87835046648979, 51.189044415950775, 48.67974266409874, 55.216079726815224, 50.99264815449715, 51.071315333247185, 46.24316520988941, 49.3163301050663, 45.379973128437996, 49.500187039375305, 48.363759219646454, 47.85583667457104, 45.875645130872726, 48.22542004287243, 47.90851704776287, 49.87944848835468, 46.90660960972309, 52.61217825114727, 58.143837824463844, 62.73144945502281, 65.77625647187233, 65.58983087539673, 55.977479070425034, 66.79723128676414, 69.5613169670105, 68.75712811946869, 61.707043424248695, 55.78864060342312, 55.334397777915, 59.900988936424255, 62.42533028125763, 70.32014384865761, 73.33982661366463, 74.20549616217613, 69.83608022332191, 65.16322016716003, 15.85953863337636, 0.9252781374379992, 1.3347489153966308, 1.0287210554815829, 2.0534717990085483, 1.4339231187477708, 1.0449537844397128, 0.49507733434438705, 0.5493440630380064, 0.06344001536490396, 0.06490784246125259, 18.442813865840435, 38.62038664519787, 40.12778475880623, 27.91714947670698, 22.24138453602791, 32.8211834281683, 53.37332680821419, 60.55038928985596, 71.92050397396088, 69.0775953233242, 36.35314330458641, 1.8993116961792111, 0.2904680510982871, 0.014692714084958425, 0.05620466181426309, 0.04269788580131717, 0.09288824221584946, 0.011600316447584191, 0.016225470753852278, 0.03516673816193361, 0.05885854108782951, 0.09202936955261976, 0.058881855657091364, 0.01681585294136312, 0.05558659009693656, 0.07726089796051383, 0.04698671640653629, 0.02574595080659492, 0.05020713637350127, 0.020533626884571277, 0.014304361193353543, 0.05691978047252633, 0.07507578513468616, 0.024009366061363835, 0.040582520014140755, 0.01953705243067816, 0.020037104113725945, 0.16149946837686002, 0.09959835559129715, 0.09392921565449797, 0.15134676941670477, 0.18866700120270252, 0.1972392076277174, 0.10371340118581429, 0.13091308384900913, 0.17676488205324858, 0.09172133373795077, 0.12022125170915388, 0.08726485568331555, 0.21434250549646094, 0.12017564673442394, 0.11900786994374357, 0.12737863522488624, 0.36407025007065386, 0.1466342355706729, 0.16462152038002387, 0.16790623631095514, 0.11106185804237612, 0.43257065874058753, 67.20553457736969, 105.03057450056076, 91.66232943534851, 89.82035547494888, 63.05261582136154, 41.39156274497509, 42.46718242764473, 62.522757053375244, 71.73662424087524, 56.11068092286587, 28.657174967229366, 0.38659463985823095, 0.24452565150568262, 0.46469173044897616, 1.2739215418696404, 1.2042172509245574, 1.4696054602973163, 4.048701748251915, 9.493927359580994, 5.370323080569506, 3.798028724268079, 38.551302552223206, 76.35511681437492, 78.24774965643883, 76.12792700529099, 73.96161764860153, 71.818737834692, 70.44772580265999, 76.617241948843, 73.93871247768402, 75.71545913815498, 67.14581698179245, 75.65683588385582, 75.41326135396957, 65.72562038898468, 54.520933628082275, 58.16444791853428, 66.69041141867638, 71.39895156025887, 69.93401616811752, 60.5481094121933, 64.38645824790001, 74.33382287621498, 61.585130766034126, 51.67987547814846, 48.68222393095493, 60.79605370759964, 70.11300176382065, 64.49944898486137, 65.55808737874031, 68.08694288134575, 62.09788665175438, 63.27178046107292, 57.25794576108456, 59.82368968427181, 60.206051766872406, 65.94749048352242, 62.226338759064674, 68.03808510303497, 64.16401818394661, 69.03964295983315, 67.25026577711105, 73.81192848086357, 66.81426957249641, 70.8023227751255, 41.97529882192612, 48.61242167651653, 79.18069079518318, 59.657554998993874, 59.979169741272926, 51.467763260006905, 55.52354022860527, 52.13531903922558, 56.697316244244576, 52.91359327733517, 54.364530220627785, 49.62604768574238, 51.17746263742447, 48.26912149786949, 52.47693210840225, 52.21427500247955, 51.30303829908371, 48.15613076090813, 51.23576670885086, 52.095527574419975, 52.05292426049709, 50.07305949926376, 55.14066517353058, 60.92510998249054, 64.7358950972557, 69.87733840942383, 67.9912032186985, 56.30610443651676, 67.83332169055939, 70.96823707222939, 72.70938724279404, 66.29325672984123, 59.62598629295826, 57.614929005503654, 62.06639014184475, 65.73741495609283, 73.35697129368782, 75.71498036384583, 77.68721133470535, 71.32186129689217, 69.91441681981087, 16.277131475508213, 2.2089176578447223, 9.58121057599783, 6.18171539157629, 5.262372298166156, 1.4819356799125671, 0.799242997309193, 1.2184358504600823, 0.5871830857358873, 0.14841188705759123, 0.5655557743739337, 25.236889198422432, 53.67826424539089, 59.82400506734848, 37.07374043762684, 24.418774098157883, 38.31109844148159, 63.4744767844677, 70.89082762598991, 80.49048811197281, 82.10734695196152, 38.174396976828575, 1.5185888693667948, 0.47473340411670506, 0.1290698561933823, 0.25446602201554924, 0.19853232573950663, 0.22612950269831344, 0.11015496842446737, 0.09472054545767605, 0.09427661498193629, 0.21460574527736753, 0.13981260708533227, 0.18608594516990706, 0.1040281608584337, 0.1884547618101351, 0.1814370579086244, 0.12301998707698658, 0.09123104871832766, 0.17797300941310823, 0.10961498177493922, 0.20503109029959887, 0.17694718320854008, 0.22435925784520805, 0.08288589495350607, 0.16762714425567538, 0.15565216104732826, 0.13143788615707308], [0.020169397503195796, 0.13043824292253703, 0.0735704276303295, 0.0334793132788036, 0.024648256876389496, 0.04109116576728411, 0.03517098324664403, 0.10141514052520506, 0.03703587419295218, 0.03978192078648135, 0.021298050123732537, 0.02062777944956906, 0.021029869494668674, 0.030305238578876015, 0.020283061130612623, 0.042424619605299085, 0.06719398385030217, 0.09989084341214038, 0.013683182660315651, 0.030089004576439038, 0.11317821088596247, 3.29029165674001, 69.05880153179169, 71.58258810639381, 72.28097543120384, 56.53730683028698, 41.949228420853615, 22.016018629074097, 28.951811157166958, 55.04351198673248, 46.255028173327446, 37.570438385009766, 3.9035438373684883, 0.14539568015607074, 0.36265699309296906, 0.24305793573148549, 0.1743989301030524, 0.5007037636823952, 0.9107642224989831, 2.430511792190373, 3.9936864003539085, 2.004095111042261, 22.71843943744898, 56.685438081622124, 69.15021702647209, 70.33566981554031, 71.73172250390053, 68.21257174015045, 71.5976732969284, 68.3747698366642, 71.06784492731094, 71.71641692519188, 64.54887673258781, 65.15072643756866, 70.92817962169647, 61.78541801869869, 54.766244664788246, 47.11673453450203, 56.645426228642464, 62.000064700841904, 66.15201070904732, 63.8019660115242, 60.8358071744442, 62.2763516753912, 63.23896922171116, 53.53187330067158, 46.82777903974056, 43.913350626826286, 54.3751772493124, 63.57568435370922, 64.27201598882675, 60.70130579173565, 63.12151372432709, 60.98485417664051, 57.8045654296875, 55.30128635466099, 57.317078188061714, 55.28862163424492, 60.94761997461319, 56.67476445436478, 61.841936185956, 57.73814879357815, 66.16350129246712, 61.779596731066704, 69.97236371040344, 52.684754356741905, 64.45177674293518, 35.03609977662563, 40.06777457892895, 69.19133841991425, 53.240451738238335, 53.98032523691654, 43.644959628582, 49.30195927619934, 46.035434156656265, 55.91125622391701, 55.72843663394451, 57.95116916298866, 54.99420203268528, 48.98130588233471, 45.998268350958824, 43.93169604241848, 43.46742555499077, 46.139734759926796, 50.44857814908028, 49.34914894402027, 47.5739412009716, 47.161613926291466, 46.57474301755428, 45.90629428625107, 50.30589960515499, 58.29916588962078, 59.800890907645226, 62.02294707298279, 63.120723366737366, 58.95586185157299, 66.1466833949089, 64.0072537958622, 61.95257484912872, 53.430616334080696, 50.004089400172234, 53.473250046372414, 60.55075027048588, 62.09072783589363, 64.36559736728668, 70.34001678228378, 71.88621461391449, 65.24433061480522, 57.023258954286575, 12.270578015595675, 0.13869281014194712, 2.594973617233336, 1.2946210498921573, 1.3365489500574768, 0.7305937435012311, 0.7224357000086457, 0.16851966589456424, 0.040545509109506384, 0.1073957524204161, 1.7481536697596312, 34.965320974588394, 39.35357250273228, 40.789948627352715, 31.74410082399845, 21.681891158223152, 33.44930112361908, 41.845459789037704, 56.553904339671135, 65.70409834384918, 66.90209805965424, 14.470270480960608, 0.7277304783929139, 0.1573377862223424, 0.028666602484008763, 0.008972053328761831, 0.07232109623146243, 0.029729376510658767, 0.01797691329556983, 0.009732992184581235, 0.03571844703401439, 0.06999482691753656, 0.09899565004161559, 0.034388804124318995, 0.02950851892819628, 0.017608360903977882, 0.0339362721570069, 0.13239067018730566, 0.045257935344125144, 0.054277508388622664, 0.09216266669682227, 0.01821155998186441, 0.00756068975533708, 0.047902478399919346, 0.02507624787540408, 0.02273312067700317, 0.030940791584725957, 0.024661398456373718, 0.031700541148893535, 0.01769652804796351, 0.04811390143004246, 0.03729091324203182, 0.05523265244846698, 0.028119429989601485, 0.033660634799161926, 0.039096536274882965, 0.081030280853156, 0.013093768975522835, 0.007194977933977498, 0.015154217689996585, 0.044475748800323345, 0.07140316345612518, 0.040450755404890515, 0.007852148773963563, 0.09917357252561487, 0.03696823856444098, 0.026534870485193096, 0.11304535160888918, 5.873120175674558, 83.92899200320244, 80.44729202985764, 79.6748922765255, 66.45629838109016, 52.100630700588226, 30.25938179343939, 26.380435936152935, 40.74452966451645, 45.17905130982399, 40.24741753935814, 4.915683176368475, 0.26361637632362545, 0.32069495413452387, 0.9473215858452022, 0.7486388564575464, 1.9931414863094687, 3.108109482564032, 3.085736995562911, 3.3165506226941943, 2.35831709112972, 24.030165150761604, 57.883152812719345, 73.43573346734047, 74.106085896492, 73.459512591362, 70.23964136838913, 74.1390909254551, 70.60781881213188, 74.82761397957802, 72.13949382305145, 64.90161940455437, 68.021639585495, 74.51416119933128, 64.73026379942894, 56.47564373910427, 49.73100185394287, 58.286048993468285, 65.80899551510811, 69.34079959988594, 65.68697646260262, 60.89509539306164, 63.85545954108238, 65.11078298091888, 57.47549168765545, 49.35772888362408, 47.603887394070625, 58.12263876199722, 67.11462065577507, 65.36534652113914, 61.431402415037155, 65.85144683718681, 62.617007195949554, 60.52844166755676, 58.567435294389725, 59.55155588686466, 57.47799575328827, 64.48212191462517, 58.35216544568539, 64.27644655108452, 61.0070525854826, 69.40392941236496, 66.49132490158081, 69.81579691171646, 55.680950582027435, 62.98845626413822, 36.77332475781441, 44.17206734418869, 71.36297509074211, 56.193626672029495, 56.54056325554848, 46.66001044213772, 51.25375874340534, 49.51172322034836, 58.99224489927292, 58.330726996064186, 60.67746587097645, 57.74353310465813, 52.38438047468662, 46.55533365905285, 46.88850358128548, 44.59221459925175, 49.274049773812294, 53.02461192011833, 51.83333404362202, 50.05358174443245, 50.05648098886013, 48.26399177312851, 48.83135072886944, 51.575476080179214, 59.476927891373634, 61.26461796462536, 65.3876893222332, 63.57955254614353, 58.74165594577789, 69.4416081905365, 67.82322943210602, 64.28760275244713, 57.095075100660324, 52.01509349048138, 55.13801671564579, 63.103400096297264, 65.80163151025772, 67.58474662899971, 71.35685741901398, 72.92311817407608, 68.24611634016037, 63.434670120477676, 14.788439758121967, 0.24181428918382153, 1.0092601622454822, 1.2711617024615407, 1.8707860331051052, 2.260260027833283, 1.6687720105983317, 0.7660762395244092, 0.17426982609322295, 0.15939752804115415, 2.050862764008343, 35.78745625913143, 37.26208113133907, 35.915649980306625, 37.87769749760628, 31.14952202886343, 45.33858194947243, 51.5132088214159, 62.25878141820431, 74.23695087432861, 81.38071954250336, 22.384800240397453, 0.9606698539573699, 0.170638675626833, 0.0726990497787483, 0.02232837930932874, 0.06843187133199535, 0.018608065365697257, 0.019234454703109805, 0.0489658164588036, 0.04857399959291797, 0.016926868956943508, 0.046801977296127006, 0.014141202809696551, 0.043586069587036036, 0.01585754733241629, 0.05953957290330436, 0.05742135726904962, 0.06664284272119403, 0.022177582322910894, 0.06246306700631976, 0.0887143294676207, 0.073595326684881, 0.02363067222177051, 0.03906696911144536, 0.03188245638739318, 0.043354601148166694, 0.12548161670565605, 0.18161811225581914, 0.15484609961276874, 0.11048802945879288, 0.08212796921725385, 0.18377409578533843, 0.11546559166163206, 0.14237948809750378, 0.11000172977219336, 0.24322900077095255, 0.10180048586335033, 0.06701536374748684, 0.07950733444886282, 0.12268677019164898, 0.1105183239269536, 0.17990122782066464, 0.20428060088306665, 0.24510529852705076, 0.17830559547292069, 0.18709580035647377, 0.5397624615579844, 8.418337125331163, 97.06449195742607, 90.2602730691433, 93.62095713615417, 74.04289528727531, 59.28110919892788, 31.236016787588596, 39.32070806622505, 74.25978764891624, 64.06707018613815, 56.41931176185608, 6.809010906144977, 0.2669504896039143, 1.0538614564575255, 1.6447080206125975, 1.7780521279200912, 3.1178305484354496, 4.890692392364144, 9.582235570997, 12.422204129397869, 4.666429376229644, 26.1129454895854, 62.65081398189068, 76.24458074569702, 75.60224801301956, 74.85168188810349, 72.22248136997223, 76.90616324543953, 73.6099161207676, 77.67737746238708, 74.54940050840378, 65.75502321124077, 69.63991954922676, 75.13491109013557, 66.02965727448463, 59.026671051979065, 51.844471246004105, 61.66748374700546, 70.0664846599102, 71.86527013778687, 67.19830736517906, 61.18856884539127, 66.45835027098656, 67.4598017334938, 60.190890580415726, 50.83115302026272, 50.42693071067333, 60.075958147645, 71.38470992445946, 66.40134572982788, 62.857610285282135, 68.54716658592224, 66.36204063892365, 64.10678565502167, 63.32114741206169, 62.81794801354408, 60.73103919625282, 67.11628496646881, 62.43561252951622, 67.17034086585045, 64.01006564497948, 70.62159687280655, 68.7609127163887, 73.60519677400589, 57.84890905022621, 61.72764591872692, 39.27438475191593, 47.91773535311222, 73.19614872336388, 59.71709780395031, 59.50008384883404, 49.14497070014477, 54.83744524419308, 51.123315542936325, 61.556024327874184, 62.383745312690735, 62.564630806446075, 60.52817188203335, 55.50502002239227, 49.18364882469177, 48.66563022136688, 47.03553669154644, 50.92864438891411, 55.01038536429405, 54.805637151002884, 52.79873304069042, 53.48077744245529, 49.78562392294407, 51.32980786263943, 55.1651206612587, 62.3712819814682, 65.6779633462429, 69.6769143640995, 66.36782392859459, 59.807905331254005, 70.7477805018425, 73.15922230482101, 67.24312976002693, 60.18536567687988, 53.715878427028656, 61.019466519355774, 66.09964951872826, 69.15908575057983, 69.24594148993492, 75.68051621317863, 76.83579862117767, 69.74428474903107, 65.23302242159843, 15.520256739109755, 1.2414130987599492, 9.100145939737558, 5.711522921919823, 3.9682700391858816, 2.2991746896877885, 2.6178583642467856, 1.1461092252284288, 0.360670352820307, 0.280852637370117, 3.402329357340932, 53.39426748454571, 55.89395195245743, 53.15097413957119, 40.476286858320236, 32.95886904001236, 49.713872373104095, 59.354544058442116, 71.58395603299141, 81.06572404503822, 94.89333406090736, 24.549185000360012, 1.0472986148670316, 0.2646186912897974, 0.1671279757283628, 0.11750943667721003, 0.17875134421046823, 0.11975354282185435, 0.14413723518373445, 0.12512327812146395, 0.13416567962849513, 0.18593107379274443, 0.21079159603687003, 0.12400473540765233, 0.13869322574464604, 0.09871499947621487, 0.13828734518028796, 0.19579319225158542, 0.18686436902498826, 0.0868872509454377, 0.23387669323710725, 0.10471866989973933, 0.21457643044414, 0.19379914534511045, 0.09584746701875702, 0.10668745409930125, 0.1369640216580592], [0.03660458249214571, 0.03612090258684475, 0.049188679695362225, 0.0725229232921265, 0.033786855565267615, 0.04574238708300982, 0.02467656053340761, 0.04170460277236998, 0.04185119178146124, 0.028756496976711787, 0.02855312810424948, 0.041679039495647885, 0.008805830802884884, 0.020895557463518344, 0.03787577756156679, 0.060747904353775084, 0.14731043600477278, 0.06783339602407068, 0.054631661259918474, 0.047520528387394734, 0.13243562949355692, 21.53549451380968, 85.07551208138466, 71.48706883192062, 62.64865569770336, 34.678584560751915, 33.213873356580734, 29.709372706711292, 50.6007219851017, 44.1844242811203, 56.378729939460754, 18.928796388208866, 0.14214936294592917, 0.07496065576560795, 0.13302251987624913, 0.3808893944369629, 0.46264773700386286, 0.5204543319996446, 1.3979645795188844, 2.1493047941476107, 0.8827478508464992, 12.722913343459368, 49.280361235141754, 67.09808394312859, 74.96569857001305, 70.78228265047073, 70.8934722840786, 69.99323219060898, 69.63820204138756, 70.85056498646736, 70.39125323295593, 63.758519142866135, 63.8718518614769, 67.03171670436859, 65.15027806162834, 51.903109699487686, 49.00915078818798, 52.48069390654564, 60.26980474591255, 63.359491154551506, 68.18344250321388, 63.499908819794655, 64.21620458364487, 62.50793784856796, 60.65250501036644, 51.41607843339443, 45.256574749946594, 45.0025849789381, 54.31272380053997, 61.283514350652695, 65.23933008313179, 61.514135375618935, 62.48926565051079, 61.04416139423847, 61.818924620747566, 59.88737426698208, 60.421716794371605, 60.71321055293083, 62.01544247567654, 62.031777799129486, 64.30312111973763, 62.96858333051205, 62.569551542401314, 58.864575549960136, 57.897155061364174, 50.01688711345196, 63.72917331755161, 29.757660515606403, 39.002570137381554, 70.24569064378738, 54.38844993710518, 55.83625964820385, 46.09603330492973, 45.899792835116386, 49.036646112799644, 56.422328799963, 57.37387754023075, 61.43185459077358, 58.415371254086494, 61.052824929356575, 50.16297407448292, 44.786783158779144, 46.62562608718872, 54.5799520611763, 55.57868666946888, 58.141721338033676, 53.47616448998451, 44.917803928256035, 44.790753945708275, 46.821915954351425, 44.93375927209854, 49.95957858860493, 56.35597676038742, 59.78709764778614, 61.958810314536095, 55.9676717966795, 62.17629924416542, 66.00966274738312, 62.69626334309578, 59.141459092497826, 50.048003643751144, 51.883821934461594, 53.45953658223152, 62.140862345695496, 65.63314095139503, 65.79071089625359, 68.76276701688766, 71.70287445187569, 64.68532741069794, 54.80540916323662, 7.956428686156869, 0.7207100582309067, 1.2207961175590754, 1.485926890745759, 2.115998393855989, 0.5355557904113084, 0.3407344256993383, 0.23879137326730415, 0.10058086263597943, 0.1049390209664125, 10.929358284920454, 40.72661742568016, 42.69815683364868, 39.187282025814056, 20.30180711299181, 14.52317314222455, 36.02582886815071, 53.45973797142506, 57.341757863759995, 62.035129219293594, 49.63523179292679, 6.327145462855697, 0.4104235174600035, 0.09420339469215833, 0.04157186223892495, 0.023742621488054283, 0.01869962041382678, 0.05844408129632939, 0.008270682028523879, 0.037985719318385236, 0.014179365898598917, 0.031166484259301797, 0.04662549457862042, 0.010502024160814472, 0.017203129718836863, 0.020453294964681845, 0.028301872152951546, 0.06864606999442913, 0.009933269084285712, 0.01210876460390864, 0.024034543421294075, 0.08147734319209121, 0.058003791054943576, 0.04414925577293616, 0.10649889663909562, 0.030801854118180927, 0.02878756327845622, 0.06685222484520636, 0.0448723413865082, 0.06387775632902049, 0.05183401684917044, 0.04017839462903794, 0.034227947326144204, 0.010919575925072422, 0.012998260135645978, 0.010123106749233557, 0.044497794297058135, 0.02402091573458165, 0.003540102629813191, 0.02709638312808238, 0.04822323833650444, 0.08529918850399554, 0.05657582099956926, 0.05763314766227268, 0.023717466392554343, 0.03751299351279158, 0.1393666208605282, 28.953522965312004, 96.7124180495739, 79.67881366610527, 73.01938220858574, 44.92192670702934, 50.84495767951012, 34.92702282965183, 39.50641930103302, 44.56334374845028, 54.52924758195877, 21.190455928444862, 0.033903072180692106, 0.03579985692340415, 0.2913096168776974, 1.4495274564251304, 1.3460311037488282, 1.9389502191916108, 3.4192308504134417, 1.1812935560010374, 1.694021774455905, 15.414640456438065, 52.78759963810444, 72.25125342607498, 76.84098914265633, 71.60902708768845, 72.8433908522129, 72.5612635910511, 72.28602156043053, 72.41124004125595, 71.46412566304207, 65.41682615876198, 65.92825591564178, 70.03170132637024, 68.13496470451355, 54.694572910666466, 51.14015243947506, 53.97067375481129, 61.93815842270851, 66.05070814490318, 69.52695921063423, 63.956579715013504, 64.7331440448761, 63.983550667762756, 64.00476112961769, 55.05596771836281, 47.09615483880043, 49.21077936887741, 56.17867827415466, 62.4965650588274, 68.62863421440125, 61.63572505116463, 64.99992772936821, 64.79792296886444, 64.36530098319054, 61.59000210464001, 64.08561319112778, 63.73367227613926, 66.41376346349716, 63.80321994423866, 65.97420305013657, 64.75451409816742, 64.78359773755074, 59.65091675519943, 57.74131782352924, 51.0304219275713, 63.9666947722435, 33.17053288221359, 40.21764613687992, 70.28287544846535, 56.574252247810364, 56.56405359506607, 49.37268108129501, 48.18147920072079, 51.36882036924362, 58.45224067568779, 60.014412850141525, 64.36401665210724, 62.752777710556984, 63.97633105516434, 52.647356763482094, 47.517046853899956, 49.21121634542942, 57.56032593548298, 59.24318343400955, 60.69835714995861, 56.563962399959564, 47.79013440012932, 46.97858914732933, 49.28067661821842, 47.63356000185013, 54.00772176682949, 58.17059598863125, 62.67268940806389, 63.7883323431015, 54.99408423900604, 63.31136293709278, 68.09922382235527, 64.64145496487617, 61.05101242661476, 53.910173401236534, 54.03452552855015, 55.70152647793293, 64.04163435101509, 68.72046768665314, 68.67430776357651, 70.68687736988068, 73.07140901684761, 67.03968107700348, 59.544765651226044, 11.441692393273115, 0.33383746922481805, 0.3400336898630485, 1.7105035088025033, 3.169669029302895, 1.347519673872739, 0.7472939661238343, 0.7232097303494811, 0.10924490983597934, 0.039309881467488594, 10.679244305938482, 41.68279431760311, 32.65802398324013, 35.63087426126003, 26.381575874984264, 28.87067601084709, 44.75883945822716, 62.168893441557884, 62.87526033818722, 69.69725847244263, 67.53972664475441, 9.52569555491209, 0.38759695482440293, 0.03162626700941473, 0.06179475560202263, 0.04614220801158808, 0.05563952749071177, 0.09771333759999834, 0.047421414565178566, 0.0018406598246656358, 0.02193273296143161, 0.050341465102974325, 0.08048535892157815, 0.03771061630686745, 0.0401110558595974, 0.049306120854453184, 0.029308947996469215, 0.0889215296774637, 0.03718221087183338, 0.06263102244702168, 0.0640518864383921, 0.06150741086457856, 0.019311849573568907, 0.04614237870555371, 0.03775980214413721, 0.03714036487508565, 0.16173627285752445, 0.12288599231396802, 0.08705009298864752, 0.2114059607265517, 0.292425332008861, 0.10615339720970951, 0.09982257324736565, 0.13194726663641632, 0.13436315028229728, 0.2020771347451955, 0.11287122892099433, 0.13656156981596723, 0.0824882670713123, 0.11752241684007458, 0.11603369828662835, 0.11487581432447769, 0.2259305032202974, 0.205909080686979, 0.22632759675616398, 0.28927096689585596, 0.26247248926665634, 35.79832747578621, 110.74166044592857, 88.54091092944145, 83.6338846385479, 50.30816808342934, 49.67720814049244, 40.65666697919369, 72.04342737793922, 60.436577796936035, 75.84644570946693, 29.125499837100506, 0.2864277991466224, 0.23472180648241192, 0.5787165462970734, 2.6768547110259533, 1.3747839233838022, 2.9862692579627037, 6.992376716807485, 8.52675100788474, 4.624113421887159, 17.082540057599545, 57.57561631500721, 72.23236843943596, 78.92578527331352, 75.0305686891079, 75.80884292721748, 74.74950537085533, 76.25317588448524, 76.00749626755714, 75.10619983077049, 67.16345563530922, 67.26491779088974, 72.72142499685287, 71.35974526405334, 56.780383586883545, 52.50057063996792, 58.33851657807827, 65.45396536588669, 70.32984852790833, 72.37704187631607, 64.73762780427933, 65.98994180560112, 68.15262615680695, 66.81604787707329, 57.70404942333698, 50.53180128335953, 52.45339997112751, 57.01828122138977, 65.93964010477066, 71.25112429261208, 62.238900884985924, 65.47804847359657, 66.7093876004219, 66.53355583548546, 65.38423150777817, 66.20940282940865, 65.79182043671608, 68.67755278944969, 67.3823618888855, 69.09209534525871, 67.60246887803078, 67.35187232494354, 60.806366354227066, 58.26527550816536, 53.072291761636734, 64.31196704506874, 37.683801501989365, 43.95176276564598, 73.92523840069771, 60.812624618411064, 60.60606010258198, 51.75904802978039, 52.16885983943939, 56.11234523355961, 60.278931856155396, 62.53205135464668, 66.38828963041306, 63.48383568227291, 66.18716642260551, 54.79138791561127, 49.41470302641392, 52.36464813351631, 60.78960545361042, 63.1601956486702, 63.39925602078438, 59.516673758625984, 49.7486063092947, 48.970970436930656, 50.70279970765114, 48.824986070394516, 56.47690147161484, 62.36156590282917, 66.1382706463337, 66.2008760869503, 56.25036142766476, 64.6450799703598, 71.93124979734421, 68.07431995868683, 64.0574187040329, 56.38935796916485, 57.359347119927406, 58.723204135894775, 68.6686384677887, 70.85894733667374, 72.02194333076477, 72.62964472174644, 77.6190809905529, 69.03955176472664, 61.26631647348404, 10.402852836996317, 2.015472650527954, 6.267557060346007, 6.864958154037595, 6.9303925428539515, 2.19102346803993, 1.2253517168574035, 1.0624894872307777, 0.30369211337529123, 0.14385380898602307, 16.265711188316345, 63.605083376169205, 58.42613227665424, 51.03887267410755, 28.490436114370823, 26.29679672420025, 47.725663259625435, 74.46280315518379, 74.23656329512596, 81.03528007864952, 79.5057861506939, 9.23570366576314, 0.5570697016082704, 0.1564888286520727, 0.26083753793500364, 0.1824648879119195, 0.16246224171482027, 0.1722844029427506, 0.06920185696799308, 0.11068037187214941, 0.07515414850786328, 0.10660694591933861, 0.1499608383164741, 0.11661437689326704, 0.20308926090365276, 0.10357018152717501, 0.06231150560779497, 0.1425302925053984, 0.05990397483401466, 0.15715604909928516, 0.19141321477945894, 0.17633225448662415, 0.13414721499430016, 0.06514861743198708, 0.2443648874759674, 0.11237470243941061], [0.07606411061715335, 0.05789167480543256, 0.06409376583178528, 0.05999712178891059, 0.028924432008352596, 0.03132609053864144, 0.05140022039995529, 0.042227831727359444, 0.06861557514639571, 0.023683062281634193, 0.07619807569426484, 0.059376081480877474, 0.04317281207477208, 0.027319170294504147, 0.022044420620659366, 0.11346056096954271, 0.027388184462324716, 0.0388194146216847, 0.019392639769648667, 0.05448081603390165, 0.8473387977574021, 53.71777072548866, 76.0421884059906, 65.7558211684227, 51.855448856949806, 35.51625341176987, 21.34768009185791, 36.63533516228199, 41.8108968436718, 32.58831672370434, 42.938197553157806, 3.64827923476696, 0.07063982004183345, 0.06325839698547497, 0.23786858684616163, 0.7557641272433102, 1.1038385122083127, 1.0783669352531433, 2.394906277768314, 0.48569100676104426, 7.370373783633113, 50.34948326647282, 75.4784582555294, 70.14875024557114, 71.45458057522774, 69.84152913093567, 69.68288004398346, 66.69622510671616, 72.62684807181358, 64.45157155394554, 69.93327140808105, 60.93174062669277, 62.1069947630167, 69.85199376940727, 58.17315325140953, 49.28143657743931, 50.72062835097313, 56.53110556304455, 61.07900172472, 64.30407866835594, 61.37503623962402, 60.59501029551029, 65.43136417865753, 58.34735110402107, 56.08449652791023, 47.01074682176113, 47.0028280466795, 45.618550926446915, 50.03282345831394, 57.500057369470596, 61.800864189863205, 63.63922834396362, 60.74526563286781, 60.741914212703705, 62.654233798384666, 59.46025438606739, 62.377897426486015, 62.24032960832119, 62.623911425471306, 61.074441969394684, 61.29199929535389, 54.90460284054279, 60.23979015648365, 51.04086756706238, 55.457351580262184, 46.02707460522652, 57.33348950743675, 29.64262928813696, 36.811543107032776, 71.81201979517937, 53.848115131258965, 59.68168370425701, 50.38598410785198, 51.34141243994236, 44.10610668361187, 52.59800121188164, 54.75688196718693, 62.44447365403175, 61.63105510175228, 62.48065531253815, 58.437839448451996, 53.97682562470436, 53.276887983083725, 56.119553446769714, 65.286675542593, 59.28426682949066, 61.290726363658905, 50.25220088660717, 43.98516297340393, 45.12730948626995, 43.91238547861576, 48.90238031744957, 52.870526388287544, 57.469715997576714, 63.290889635682106, 58.03003393113613, 58.15571218729019, 66.81779578328133, 61.57448373734951, 60.11802949011326, 51.53045229613781, 49.28658530116081, 54.553904458880424, 58.95311459898949, 61.52879498898983, 66.43580228090286, 66.90201446413994, 70.932746976614, 67.58638054132462, 63.182378858327866, 55.0058788061142, 9.664743393659592, 0.2805757272290066, 0.5093890882562846, 3.1034490326419473, 1.0121824429370463, 0.32286671572364867, 0.43021303368732333, 0.13880331593099982, 0.03874576388625428, 0.2371993032284081, 18.34625344723463, 38.01259785890579, 39.242265075445175, 32.64200784265995, 19.820346347987652, 19.987026304006577, 42.97476299107075, 52.222379967570305, 60.31170129776001, 61.32724240422249, 40.0416623800993, 2.2903560753911734, 0.14268661849200726, 0.09230458759702742, 0.026962846641254146, 0.05533208910492249, 0.023488113074563444, 0.047720529764774255, 0.06058386374206748, 0.06394227122655138, 0.035738032311201096, 0.02844886934326496, 0.054922779818298295, 0.07750055970973335, 0.029289910053194035, 0.025787980484892614, 0.09808968068682589, 0.014393147102964576, 0.028126554607297294, 0.022037123453628737, 0.06834843909018673, 0.018498157005524263, 0.026508646697038785, 0.03873676905641332, 0.0316541828942718, 0.04771079278725665, 0.04376181015686598, 0.03282323246821761, 0.05348233426047955, 0.02785784705338301, 0.04997880350856576, 0.006017550904289237, 0.011642467652563937, 0.04068282127263956, 0.022751373799110297, 0.030893323819327634, 0.04216325374727603, 0.1068986915925052, 0.05384652838984039, 0.06115619689808227, 0.08820325689157471, 0.06473521891166456, 0.08651578376884572, 0.027206349004700314, 0.0015523467004641134, 1.2415637844242156, 64.68337431550026, 85.25164783000946, 72.00175121426582, 61.08579196035862, 40.70421762764454, 27.95269086956978, 33.15685361623764, 35.6663453578949, 34.25958104431629, 44.13414157927036, 4.880712227895856, 0.11611572044785134, 0.33543676778208464, 1.6459391545504332, 1.3071889942511916, 2.8597609838470817, 1.394080356694758, 1.2951203668490052, 0.08178675940143876, 7.9823884181678295, 54.06924046576023, 77.93407648801804, 73.7912879884243, 73.93931284546852, 72.08049058914185, 72.3315355181694, 70.981285572052, 74.28966164588928, 66.97731122374535, 69.83494028449059, 62.501535192131996, 64.59501385688782, 72.31957376003265, 59.97389942407608, 51.50601580739021, 52.961406111717224, 58.719430938363075, 64.72343936562538, 66.55611142516136, 63.77045810222626, 60.19856236875057, 66.45828947424889, 61.64977669715881, 59.22073043882847, 48.663335144519806, 49.60238255560398, 46.61670036613941, 53.11697356402874, 60.24173945188522, 64.7481532394886, 64.08951938152313, 60.340355560183525, 61.29810556769371, 63.59239585697651, 61.83484196662903, 64.06216844916344, 63.6723967641592, 65.39914190769196, 62.86877028644085, 62.69059404730797, 54.36215154826641, 60.48495300114155, 53.90924625098705, 58.715520948171616, 48.98958943784237, 58.850596100091934, 32.20356456935406, 39.966327622532845, 72.92351335287094, 57.914451733231544, 63.33769932389259, 52.12014265358448, 52.42836691439152, 45.920448526740074, 55.70102870464325, 59.309489876031876, 64.7649635374546, 62.68877774477005, 64.50539946556091, 60.441380739212036, 55.86970165371895, 57.40365274250507, 59.93588246405125, 66.0566358268261, 63.91356602311134, 65.00301316380501, 52.484524101018906, 46.55005194246769, 48.502094596624374, 45.35889945924282, 50.92762604355812, 55.39664603769779, 60.279634818434715, 67.17708170413971, 58.801221549510956, 59.41982835531235, 67.7568393945694, 64.57239747047424, 63.310595378279686, 53.75882372260094, 50.979930236935616, 56.29606157541275, 62.5949227809906, 63.357089683413506, 68.8949391245842, 70.18011376261711, 72.02684506773949, 69.587132781744, 65.52365362644196, 60.43619401752949, 12.94657789170742, 0.2971731178695336, 0.332070771837607, 0.8560979214962572, 1.9353981222957373, 2.307336889207363, 1.2366578914225101, 0.35908791585825384, 0.05019958131015301, 0.35840882104821503, 19.741690568625927, 38.884267285466194, 31.853762939572334, 31.403944976627827, 28.466854579746723, 27.751316875219345, 51.83927312493324, 62.929924204945564, 68.1832905113697, 69.48994159698486, 54.86589431762695, 3.2136587938293815, 0.1789720737724565, 0.10738257187767886, 0.06684285152005032, 0.024604911741334945, 0.06632400123635307, 0.022439803506131284, 0.028549101953103673, 0.07055255089653656, 0.04306932329200208, 0.05629148567095399, 0.027125710948894266, 0.03666400625661481, 0.10752807735116221, 0.1502026745583862, 0.08812694184598513, 0.03806838714808691, 0.04447832405276131, 0.011970088744419627, 0.04487636382691562, 0.04704719773144461, 0.05755440579378046, 0.026764223803183995, 0.019896903140761424, 0.150775627407711, 0.10050776108982973, 0.14218081516446546, 0.18418324179947376, 0.08288291894132271, 0.09323584934463724, 0.16165325621841475, 0.13882112747523934, 0.2195119796670042, 0.14800029195612296, 0.13758895453065634, 0.20263788668671623, 0.2368277098867111, 0.11491784214740619, 0.18817532836692408, 0.1238004221522715, 0.17369485460221767, 0.23090725648216903, 0.12902786547783762, 0.1785305849625729, 1.84368944959715, 78.93681988120079, 95.86977526545525, 85.4634028673172, 70.46104028820992, 51.87487721443176, 32.432794868946075, 51.899936869740486, 59.04611460864544, 44.815843999385834, 61.35022737085819, 6.073354231193662, 0.27803051692899317, 0.40462042728904635, 2.088103615678847, 2.779735140502453, 4.885766431689262, 4.8240054957568645, 9.120640140026808, 6.079657142981887, 9.960151892155409, 57.22506992518902, 81.32488533854485, 75.77358841896057, 76.42814889550209, 75.77664345502853, 73.8368171453476, 72.41412028670311, 78.25243100523949, 68.98665100336075, 73.01855385303497, 63.322598934173584, 67.69770696759224, 74.85651522874832, 62.03149661421776, 52.81154975295067, 58.103081211447716, 62.665792778134346, 68.55761602520943, 69.23486888408661, 65.76418831944466, 62.1279164403677, 71.70316323637962, 64.25175547599792, 61.136390045285225, 51.69519625604153, 52.03376188874245, 50.43059751391411, 54.83795441687107, 62.21788041293621, 67.30185180902481, 68.03214222192764, 59.763527512550354, 62.67310358583927, 67.25443795323372, 63.42041328549385, 66.17936924099922, 64.69518408179283, 67.523083537817, 65.39321422576904, 64.77623373270035, 55.382001623511314, 62.12501339614391, 57.0797923207283, 61.14118158817291, 51.41219884157181, 59.15102697908878, 36.93526826798916, 43.73040184378624, 73.93580943346024, 60.2157336473465, 65.32888367772102, 56.26816347241402, 54.894297793507576, 47.592507004737854, 57.8506987541914, 60.74106685817242, 67.54285767674446, 65.19573882222176, 67.17069044709206, 65.59128239750862, 60.49775071442127, 60.99043607711792, 62.951260060071945, 69.95119124650955, 65.50862163305283, 68.02873000502586, 55.75677551329136, 48.88115465641022, 49.778974279761314, 47.60460175573826, 54.2523792386055, 58.96428219974041, 63.9125020802021, 68.84708449244499, 59.78881515562534, 61.544586941599846, 70.75031116604805, 66.43373519182205, 66.86371251940727, 56.579355373978615, 54.45995070040226, 60.78998163342476, 66.64697214961052, 68.27216014266014, 71.9208611547947, 72.80238345265388, 76.78417459130287, 71.51949629187584, 67.41883993148804, 61.33072301745415, 10.623604841530323, 1.3122405856847763, 6.280614109709859, 11.590487658977509, 3.706533908843994, 3.620139369741082, 2.805051519535482, 1.1349076637998223, 0.15374335722299293, 0.9547324944287539, 29.491220712661743, 56.45606718957424, 52.13375352323055, 46.690063029527664, 31.451113745570183, 30.922096632421017, 57.10814639925957, 69.94528636336327, 77.24538624286652, 80.2616111934185, 60.67621573805809, 3.624304421246052, 0.3372366836993024, 0.21171687607420608, 0.10400513201602735, 0.22187031718203798, 0.13137703004758805, 0.1691406505415216, 0.15785262890858576, 0.1683912446605973, 0.11083329140092246, 0.16774422547314316, 0.10246785474009812, 0.22495303535833955, 0.2001552691217512, 0.16080245812190697, 0.20977583335479721, 0.10044404029031284, 0.10811602900503203, 0.24039193347562104, 0.16674496815539896, 0.18926195130916312, 0.11119134054752067, 0.08105437838821672, 0.08998895325930789], [0.012681684056587983, 0.030615691939601675, 0.026998432622349355, 0.05173845049284864, 0.06015226033923682, 0.05503687760210596, 0.02690202949452214, 0.024655316556163598, 0.02163895194826182, 0.033661517954897135, 0.03715263999765739, 0.001654389338909823, 0.021967098109598737, 0.046372195865842514, 0.05338534669135697, 0.04507590136199724, 0.05770598574599717, 0.08792916691163555, 0.08597327381721698, 0.13237496634246781, 9.139861408621073, 78.32892090082169, 68.57823371887207, 71.56186401844025, 47.39024765789509, 36.96670018136501, 28.695254623889923, 50.08755952119827, 41.63177065551281, 55.41324354708195, 25.81782102584839, 0.11556538083823398, 0.08625961665529758, 1.0585718974471092, 0.6014065537601709, 0.225345334620215, 1.7023286037147045, 0.612577716819942, 1.6089192847721279, 1.3629629951901734, 43.86695131659508, 78.92898470163345, 68.52280229330063, 69.7877088189125, 70.8884109556675, 71.22552886605263, 70.96895143389702, 64.23936814069748, 68.7247234582901, 66.90696179866791, 71.7678889632225, 59.09630611538887, 64.35785338282585, 65.8753627538681, 52.832840010523796, 47.56943464279175, 53.89191918075085, 61.93706788122654, 64.21834006905556, 63.325695767998695, 61.10787637531757, 61.46362088620663, 59.48001332581043, 57.239448353648186, 49.56043280661106, 45.249252542853355, 45.70121169090271, 45.68158194422722, 47.91987843811512, 56.68900229036808, 62.87055619060993, 62.490523383021355, 58.1534893065691, 54.49484042823315, 58.093965500593185, 56.882746294140816, 59.154063016176224, 56.153348833322525, 58.01932990550995, 59.18029300868511, 58.693105950951576, 55.304113402962685, 52.02712744474411, 50.50937868654728, 57.513527646660805, 52.87523053586483, 62.0206443965435, 30.43515656143427, 31.465368680655956, 65.04063114523888, 55.401372984051704, 64.47190046310425, 56.40014939010143, 57.58907899260521, 42.445861771702766, 47.92263709008694, 51.08975574374199, 59.93226505815983, 60.50261825323105, 62.28022746741772, 60.45713849365711, 62.64406554400921, 61.40970557928085, 62.33557529747486, 53.93899105489254, 54.29365262389183, 62.75550216436386, 51.558111011981964, 43.09393219649792, 44.692354425787926, 44.857588559389114, 47.5212874263525, 53.553034365177155, 56.93951144814491, 59.47782464325428, 62.345040589571, 54.52207736670971, 64.9396401643753, 63.47838677465916, 62.463092654943466, 54.351667910814285, 50.365191623568535, 47.97631300985813, 58.768087327480316, 60.32207854092121, 65.1332625746727, 63.81205826997757, 66.07637196779251, 66.07405409216881, 67.95988529920578, 62.2291050106287, 61.554850190877914, 15.18333736807108, 0.23189037950942293, 2.052005077712238, 1.3952313386835158, 1.372177975717932, 0.9038865321781486, 0.20891094929538667, 0.28548930888064206, 0.07473493154975586, 2.5908888364210725, 25.696917213499546, 42.347150668501854, 33.518096432089806, 23.093694001436234, 24.259868524968624, 28.688916563987732, 44.54031698405743, 49.525774866342545, 59.32745911180973, 64.41431075334549, 21.228983961045742, 0.8868727670051157, 0.26731236081104726, 0.06477886461652815, 0.035203559818910435, 0.048051063786260784, 0.13307561312103644, 0.048300707421731204, 0.009455428953515366, 0.024754999976721592, 0.059982323364238255, 0.027350613236194476, 0.023485048004658893, 0.026316417461202946, 0.042867607553489506, 0.019078048935625702, 0.04406823922181502, 0.014081535991863348, 0.07589899018057622, 0.05355563247576356, 0.04525040254520718, 0.02540940167818917, 0.04132272326387465, 0.09048642226844095, 0.041138358938042074, 0.049605076492298394, 0.05947655714408029, 0.05442647969175596, 0.06260467620450072, 0.04475577596167568, 0.029878809800720774, 0.022138344975246582, 0.06005958464811556, 0.07545097047113813, 0.08476551010971889, 0.019904005494026933, 0.10700102633563802, 0.0417504341021413, 0.026208334784314502, 0.03584968842915259, 0.08934479134040885, 0.11893815259099938, 0.1634456022293307, 0.16065681906184182, 12.048500832170248, 89.78948593139648, 77.07670569419861, 79.71580848097801, 53.76173436641693, 46.42098046839237, 33.663187846541405, 36.24283142387867, 35.13249680399895, 47.94058732688427, 27.796766236424446, 0.10823356293258257, 0.030662757089885417, 2.054487532004714, 1.60796660464257, 0.7507533836178482, 3.1087632849812508, 1.6835435992106795, 1.2298467569053173, 1.9173536030575633, 46.341078355908394, 80.828517973423, 69.89056929945946, 72.94484540820122, 73.57213854789734, 72.39071354269981, 72.99167409539223, 68.18094983696938, 69.7514359652996, 69.51821208000183, 72.81503677368164, 60.98247170448303, 66.33217424154282, 68.0494312942028, 53.95013585686684, 50.23671671748161, 56.8396870046854, 63.44100818037987, 65.43066501617432, 63.453285321593285, 60.06051957607269, 65.65492138266563, 63.839143216609955, 59.66466821730137, 52.08940610289574, 47.92414180934429, 48.57434391975403, 47.63342700898647, 49.24237847328186, 59.9120919406414, 65.1907230913639, 64.02051508426666, 60.42601056396961, 56.3907752931118, 58.06806989014149, 58.91655296087265, 59.04953442513943, 57.41798557341099, 59.51259657740593, 59.970635399222374, 60.1907841861248, 56.95160619914532, 55.872828885912895, 54.76574309170246, 59.73679594695568, 53.38395483791828, 61.97535462677479, 33.29072803258896, 34.35362599790096, 67.30296894907951, 58.72530162334442, 65.92357456684113, 57.16475576162338, 59.26302216947079, 46.10034987330437, 50.01557618379593, 53.26722890138626, 62.122760117053986, 62.47978515923023, 63.18891830742359, 62.62258529663086, 63.62974405288696, 62.81634069979191, 64.034353941679, 58.182401955127716, 59.75676387548447, 65.36713242530823, 53.991356045007706, 44.98458914458752, 48.12149181962013, 47.25088633596897, 50.960061103105545, 56.73276074230671, 61.43378868699074, 62.73684896528721, 62.61345438659191, 53.638468980789185, 67.28833213448524, 67.31094092130661, 65.63244938850403, 57.79138773679733, 52.40915894508362, 52.41380229592323, 60.174521058797836, 63.866334557533264, 68.09355452656746, 66.47213593125343, 68.71890217065811, 66.97485655546188, 68.58241349458694, 65.55388480424881, 66.71338498592377, 19.865358732640743, 0.16321325063472614, 0.5250897270161659, 0.4908306762808934, 2.6176384510472417, 1.4488130947574973, 0.6715998309664428, 0.5748555378522724, 0.169272871571593, 2.1458773780614138, 32.41567678749561, 33.6592398583889, 25.569969825446606, 25.10779682546854, 29.344996958971024, 42.97265790402889, 50.319065898656845, 56.768763810396194, 64.30962637066841, 74.37446549534798, 30.62001284211874, 1.0564854531548917, 0.2887205604929477, 0.04180719726718962, 0.024056601905613206, 0.09167623342364095, 0.029995224940648768, 0.16153279080754146, 0.011850346927531064, 0.07304555852897465, 0.05983190858387388, 0.09604239210602827, 0.01779971626092447, 0.015039686677482678, 0.09248576810932718, 0.04341039581049699, 0.014529440668411553, 0.009991215974878287, 0.033905376549228095, 0.08291870530229062, 0.024522227213310543, 0.05048708560934756, 0.025727953725436237, 0.037414970647660084, 0.08304802453494631, 0.13208573654992506, 0.09945851270458661, 0.12503962323535234, 0.26343867648392916, 0.12273054948309436, 0.15052913047838956, 0.09273593124817125, 0.1161099539604038, 0.21339439699659124, 0.1591074967291206, 0.12887149496236816, 0.18612520478200167, 0.16506263811606914, 0.10952549360808916, 0.1814459785236977, 0.2635336120147258, 0.19986167550086975, 0.30569799011573195, 0.40736396913416684, 16.191484071314335, 102.53665432333946, 85.74002802371979, 91.79490432143211, 63.35730627179146, 53.85541453957558, 38.970268070697784, 68.23325783014297, 53.979006707668304, 74.37938243150711, 38.27151216566563, 0.4364188725594431, 0.16918181005166844, 3.1735274847596884, 2.858049888163805, 1.7498398292809725, 6.319909226149321, 5.2170046325773, 8.506554141640663, 2.12004232686013, 50.173940286040306, 83.83714333176613, 72.82190680503845, 76.10640496015549, 76.43635645508766, 76.40662685036659, 75.9056769311428, 69.50098380446434, 74.4071513414383, 72.48462170362473, 75.33940851688385, 63.15330661833286, 68.83198410272598, 71.4096973836422, 56.4917928725481, 52.59202413260937, 59.35112424194813, 64.9952007830143, 67.76048719882965, 67.44901031255722, 63.10150019824505, 66.92154541611671, 65.6540322303772, 62.54652477800846, 54.65809866786003, 51.381127908825874, 50.95463499426842, 49.4898933917284, 52.133643329143524, 62.74848014116287, 67.6977601647377, 65.23111492395401, 59.67125706374645, 56.44062481820583, 59.0610022097826, 60.578720569610596, 63.93609121441841, 59.55985464155674, 60.59843011200428, 60.63753381371498, 59.96540307998657, 58.3072404563427, 56.651319712400436, 57.971520870923996, 61.05802685022354, 56.256859079003334, 62.741382122039795, 37.57270306348801, 39.29068587720394, 66.75820738077164, 61.2170635163784, 68.73103111982346, 60.30867666006088, 63.25753502547741, 48.46864499151707, 51.89227648079395, 56.054014563560486, 64.65696573257446, 65.61678662896156, 65.79885005950928, 63.640379682183266, 66.59663245081902, 67.99963116645813, 66.52331158518791, 60.173559710383415, 62.29970522224903, 67.84538984298706, 57.72760055959225, 47.27498084306717, 51.128133684396744, 50.56317999958992, 53.2528580725193, 59.38157580792904, 64.54116314649582, 67.12642282247543, 63.56706261634827, 53.96077908575535, 70.99694833159447, 70.08578762412071, 68.28912243247032, 60.629459246993065, 56.034487411379814, 54.44733917713165, 63.358100429177284, 65.90227290987968, 71.99002504348755, 69.02721002697945, 72.06855922937393, 70.82715064287186, 71.8630662560463, 68.57059612870216, 70.1870521903038, 18.72977066785097, 0.6219212373252958, 6.745324898511171, 6.720918333157897, 3.279802082106471, 3.305898606777191, 0.7466942514292896, 0.9163671999704093, 0.3299815667560324, 4.405447980388999, 42.86630921065807, 57.19080716371536, 46.27566106617451, 33.53074215352535, 33.45321871340275, 45.99651664495468, 58.76742996275425, 67.40685537457466, 72.7938263118267, 86.00159838795662, 34.45766821503639, 1.5646806336008012, 0.42727377265691757, 0.24134485109243542, 0.15620626334566623, 0.19458524300716817, 0.21144839673070237, 0.2225518017075956, 0.1437434961553663, 0.17722320277243853, 0.1485770891304128, 0.17751832521753386, 0.2111750192125328, 0.10482917568879202, 0.11119721093564294, 0.17804955452447757, 0.11560355691472068, 0.16210764355491847, 0.09811589334276505, 0.18566724029369652, 0.04838738284888677, 0.09673206994193606, 0.08042146000661887, 0.09780436201253906], [0.02256472551380284, 0.04900231899227947, 0.019606407986429986, 0.013128892042004736, 0.014430775845539756, 0.03605683297791984, 0.10483673817361705, 0.022642010917479638, 0.06300245993770659, 0.056877559691201895, 0.04772284155478701, 0.022217333607841283, 0.05851056659594178, 0.013084108068142086, 0.09666777026723139, 0.024786548674455844, 0.017487993827671744, 0.06577476000529714, 0.12689478462561965, 0.08184768230421469, 26.711105592548847, 80.72437316179276, 70.2365255355835, 70.42610496282578, 50.92145137488842, 32.20475010573864, 26.759055219590664, 62.300522178411484, 51.339539140462875, 44.582213535904884, 4.743815073743463, 0.039543401944683865, 0.04782721349329222, 0.30378969095181674, 0.270120469504036, 0.5610191146843135, 1.72051799017936, 0.45698247849941254, 0.21275941544445232, 27.111554704606533, 81.64051160216331, 67.1371078491211, 69.18035700917244, 64.10382941365242, 66.40439316630363, 65.17290204763412, 69.38720270991325, 64.70298886299133, 66.2117663025856, 65.26646062731743, 67.47725039720535, 64.85959365963936, 66.86185821890831, 60.316834822297096, 49.03157718479633, 50.50923049449921, 63.53814996778965, 62.72006906569004, 65.5476151406765, 58.321147710084915, 62.769576609134674, 60.259465500712395, 56.82672210037708, 50.2224712818861, 44.711794182658195, 44.43029768764973, 45.21509237587452, 44.54501733183861, 45.784902200102806, 54.23569813370705, 61.00460171699524, 61.810409277677536, 58.457476794719696, 52.78469659388065, 57.55476303398609, 58.06029550731182, 60.50773657858372, 57.93560899794102, 59.49955567717552, 53.30638200044632, 59.574924632906914, 49.65812176465988, 57.825107127428055, 61.89509533345699, 63.8732273876667, 55.917316898703575, 59.853860065340996, 35.70851929485798, 33.69574449956417, 61.321295723319054, 56.07904002070427, 63.24496150016785, 58.768121525645256, 60.23994214832783, 46.511715799570084, 44.44145768880844, 44.82565127313137, 55.04114471375942, 58.084010034799576, 59.639008194208145, 58.167069777846336, 54.137177020311356, 52.10800990462303, 55.86893789470196, 51.460653841495514, 58.27829360961914, 60.76484598219395, 50.96612557768822, 46.792760118842125, 44.3288317322731, 43.63536514341831, 50.519132763147354, 54.60058495402336, 54.9553719162941, 60.0235665589571, 59.8943392932415, 54.8287209123373, 59.73702013492584, 63.22068840265274, 61.89052037894726, 58.338649570941925, 48.89389917254448, 48.41480188071728, 52.546943351626396, 57.274083495140076, 61.36989511549473, 64.25451412796974, 62.71199069917202, 64.87279415130615, 65.01481533050537, 66.64979159832001, 59.21929411590099, 69.54255357384682, 21.05213575065136, 0.2790335443569347, 1.9523202767595649, 2.4396605137735605, 0.6412527593784034, 0.4175664216745645, 0.12240513999131508, 0.06178633964736946, 0.04951761809934396, 10.673205479979515, 35.22027209401131, 40.96630856394768, 50.38853757083416, 37.04340286552906, 16.98488339781761, 31.22941844165325, 47.43401750922203, 56.54737249016762, 61.79832212626934, 54.335708767175674, 11.107948701828718, 0.4968224500771612, 0.0792564291623421, 0.056517759076086804, 0.033324957694276236, 0.08797872011200525, 0.021613444332615472, 0.055132774214143865, 0.0417863763141213, 0.03230148409784306, 0.07626614547916688, 0.04758797847898677, 0.02851390374416951, 0.05423045251518488, 0.013761619320575846, 0.020734259087475948, 0.046676602578372695, 0.06768461767933331, 0.038125413775560446, 0.010053650075860787, 0.01084939380234573, 0.04564070542983245, 0.009694183427200187, 0.03353689280629624, 0.003342251857247902, 0.013188035645725904, 0.027767872779804748, 0.02565283539297525, 0.02087372533424059, 0.058961855465895496, 0.023853030797909014, 0.05409683253674302, 0.043003409446100704, 0.05099114860058762, 0.02849643544323044, 0.02293331501277862, 0.045739388806396164, 0.04693866976595018, 0.030845805958961137, 0.05566162493778393, 0.032994167631841265, 0.09052438312210143, 0.040361898063565604, 35.41093446314335, 92.91975036263466, 76.45548462867737, 80.58447986841202, 58.012372478842735, 39.01961222290993, 26.41795512288809, 50.7404138892889, 55.40201894938946, 50.19524194300175, 6.784552568569779, 0.14135655626887456, 0.06434933180571534, 0.7322998519521207, 0.9220894554164261, 2.1248920541256666, 4.802780784666538, 0.5629938805941492, 0.7647206622641534, 29.345048256218433, 85.0270114839077, 68.95518109202385, 73.15343141555786, 65.7395352423191, 70.05237221717834, 67.75379955768585, 71.88885167241096, 68.07907730340958, 69.66917037963867, 66.58884286880493, 69.51248198747635, 67.25409597158432, 69.3277283012867, 62.68381521105766, 51.1739706248045, 52.72388465702534, 65.23228526115417, 65.14815777540207, 68.33183974027634, 59.60997775197029, 64.37179863452911, 63.26559819281101, 58.560686856508255, 53.67659993469715, 47.82242886722088, 46.24663062393665, 48.5870960354805, 46.40878692269325, 47.12598703801632, 57.01468661427498, 62.683602422475815, 64.18778210878372, 59.98808026313782, 54.33870680630207, 59.858507215976715, 59.83691677451134, 61.2214370816946, 57.969332188367844, 60.00131495296955, 53.404504135251045, 58.73384736478329, 49.99143227934837, 59.61227662861347, 63.3916412293911, 65.88721811771393, 58.10468092560768, 62.43280827999115, 37.416512444615364, 37.13331364095211, 63.38727526366711, 57.95145034790039, 64.95553851127625, 61.99308827519417, 63.19769203662872, 49.46492113173008, 46.15407519042492, 49.98927779495716, 56.59096375107765, 60.159367471933365, 61.38388976454735, 59.523046016693115, 55.37608914077282, 53.22997570037842, 54.9538291990757, 53.24338138103485, 61.859886422753334, 62.00688533484936, 53.52188743650913, 49.3165048956871, 46.70920640230179, 46.067428439855576, 53.00492137670517, 57.33340211212635, 58.90832260251045, 63.875613659620285, 59.59444418549538, 54.90423426032066, 60.80665893852711, 64.58086341619492, 64.12612661719322, 60.018151849508286, 50.95731005072594, 51.44413612782955, 54.42256450653076, 59.4432009011507, 63.91396880149841, 65.99888652563095, 65.37546917796135, 67.09630563855171, 69.01433631777763, 68.53445246815681, 63.54468561708927, 73.03215712308884, 26.54281262308359, 0.4380972246872261, 1.3272327999584377, 1.1627453262917697, 1.0994770587421954, 1.4461835171096027, 0.8307360636536032, 0.10580650996416807, 0.03599380608648062, 12.282826658338308, 40.24041451513767, 34.12891745567322, 31.004168428480625, 31.819161996245384, 24.967825636267662, 41.745129972696304, 56.140193939208984, 64.22980785369873, 66.52326598763466, 66.11003816127777, 16.27474520355463, 0.6977323943283409, 0.07718738823314197, 0.07315656897844747, 0.04913299635518342, 0.09929018619004637, 0.034398433490423486, 0.007075759795043268, 0.07449079465004615, 0.03587304010579828, 0.04904866982542444, 0.03213861979020294, 0.008324899627041304, 0.04493394706514664, 0.03629784914664924, 0.11392522705136798, 0.03385781972610857, 0.046507689767167903, 0.020742918095493224, 0.03750631418370176, 0.019333054588059895, 0.031703695276519284, 0.03262457437813282, 0.14163867628667504, 0.10981408515363, 0.15660941280657426, 0.1087865223234985, 0.11914725269889459, 0.14797819079831243, 0.2595454588299617, 0.18627636542078108, 0.1366789182065986, 0.12894462619442493, 0.17454982356866822, 0.19197309098672122, 0.14797464333241805, 0.15251312870532274, 0.221564314852003, 0.16713995399186388, 0.13692167471162975, 0.11470854165963829, 0.24670910934219137, 0.1895713823614642, 42.8561257570982, 102.31912359595299, 88.26564610004425, 89.20502409338951, 67.73967951536179, 44.64918494224548, 38.25776070356369, 76.24943688511848, 65.3918918967247, 66.02563709020615, 8.788992036134005, 0.2888741553761065, 0.4866438946919516, 1.6497426317073405, 1.7977939685806632, 4.13502361625433, 7.344772182404995, 6.342387394979596, 2.7068690629675984, 31.18281964212656, 87.65272378921509, 70.86310431361198, 74.57163691520691, 69.25442263484001, 72.15984553098679, 70.86618214845657, 73.82246911525726, 69.19871762394905, 70.87514206767082, 70.0823450088501, 74.3008254468441, 70.6974484026432, 71.94809809327126, 65.91224357485771, 55.12025646865368, 55.72082184255123, 69.95265796780586, 67.232725918293, 73.74457329511642, 60.981255769729614, 64.87013429403305, 66.07982978224754, 59.962815418839455, 56.05056054890156, 49.62824396789074, 48.89715179800987, 50.04173777997494, 49.75113697350025, 49.97632808983326, 60.18299460411072, 66.69665068387985, 67.05751731991768, 60.287652388215065, 55.9620177000761, 61.081756576895714, 63.28314185142517, 64.30582657456398, 61.10473394393921, 59.92081627249718, 52.578721046447754, 58.93920734524727, 51.71686269342899, 60.622247233986855, 67.38462656736374, 68.90519857406616, 60.67199036478996, 64.94273319840431, 41.852071434259415, 39.94930073618889, 63.284749165177345, 62.36625485122204, 67.50038355588913, 62.92178504168987, 66.90606504678726, 52.519337832927704, 48.0173584073782, 51.11421123147011, 60.728922709822655, 61.669706627726555, 62.66305312514305, 60.02986662089825, 56.940962970256805, 56.427652314305305, 55.495512932538986, 55.37391185760498, 65.02803102135658, 65.72343170642853, 57.42247313261032, 52.52529591321945, 49.852557331323624, 47.90653735399246, 55.97738787531853, 61.40961818397045, 61.98704279959202, 66.2307196855545, 61.386614218354225, 55.13545945286751, 62.17839293181896, 68.65546837449074, 67.22066536545753, 62.378471195697784, 54.41834293305874, 54.7869573533535, 58.67081254720688, 62.14631885290146, 67.28017777204514, 70.24350956082344, 67.75616303086281, 71.04745522141457, 71.81523442268372, 70.62196165323257, 64.18048650026321, 76.6344702243805, 25.54070759564638, 0.6277168169617653, 8.303631730377674, 6.913439277559519, 3.039156482554972, 2.2474680142477155, 0.48934127495158464, 0.39455648919101804, 0.16178488353034481, 18.19781631231308, 55.22548422217369, 57.52919800579548, 64.04283508658409, 48.06158423423767, 26.85396272689104, 44.07785899937153, 63.477296233177185, 74.7316387295723, 75.81461861729622, 74.79520931839943, 17.415542788803577, 0.7357560633681715, 0.22237334487726912, 0.20806824060855433, 0.13388262450462207, 0.2075994704500772, 0.1224467225256376, 0.18649786681635305, 0.16342921560863033, 0.10752657821285538, 0.25882355694193393, 0.2165013982448727, 0.1813850927283056, 0.13263471802929416, 0.12963066750671715, 0.26542032952420413, 0.06264395808102563, 0.3248950053239241, 0.1028079810203053, 0.14554318942828104, 0.10859403148060665, 0.1346911647124216, 0.1762661142856814], [0.034996916219824925, 0.0421711613307707, 0.04049136201501824, 0.03449121679295786, 0.024249011112260632, 0.08881833404302597, 0.016436044024885632, 0.07461639572284184, 0.11059299882617779, 0.09550707356538624, 0.008126117227220675, 0.009107207697525155, 0.03359511058079079, 0.017929191344592255, 0.04023300927656237, 0.06986708103795536, 0.03179205537890084, 0.06977881741477177, 0.044572602782864124, 1.3560604280792177, 60.85308104753494, 71.23156294226646, 74.27036628127098, 53.454213067889214, 32.28732727468014, 26.224879883229733, 47.409280836582184, 52.309376299381256, 43.05612042546272, 25.62772672623396, 0.1364299573469907, 0.044592826307052746, 0.13170869584428146, 0.30853415199089795, 0.16755560121964663, 1.4771007956005633, 1.9421711401082575, 0.7175454217940569, 9.112959802150726, 77.50131770968437, 66.76635414361954, 72.2905433177948, 62.941809967160225, 63.26891541481018, 60.60830198228359, 64.72824990749359, 63.28295946121216, 66.75638347864151, 62.271214351058006, 64.65590178966522, 62.548876851797104, 63.885439932346344, 60.54025523364544, 52.67819970846176, 46.54449284076691, 55.46676367521286, 63.41178014874458, 64.23868417739868, 59.85793724656105, 61.152185797691345, 61.58681407570839, 57.46165283024311, 55.71283847093582, 48.37984375655651, 47.74737149477005, 44.74144399166107, 44.59835886955261, 45.538295432925224, 45.581977888941765, 51.62425026297569, 58.92406515777111, 59.61263380944729, 59.923240542411804, 56.19179517030716, 58.58019880950451, 59.91413623094559, 60.837072506546974, 60.86810164153576, 59.3438096344471, 56.693242862820625, 52.514588087797165, 52.68784739077091, 65.10631442070007, 56.30264662206173, 60.401615872979164, 54.26384322345257, 62.150544226169586, 36.201820224523544, 37.33159840106964, 63.665830716490746, 55.604631677269936, 59.285786747932434, 59.604236260056496, 57.26185195147991, 45.94994634389877, 44.53388772904873, 43.73572155833244, 47.62992739677429, 54.3986713886261, 60.11727333068848, 59.97166894376278, 56.944272592663765, 50.2268448472023, 52.4162607640028, 58.159435987472534, 59.10961300134659, 55.59787563979626, 47.58232735097408, 41.04739621281624, 44.51066717505455, 45.345113798975945, 52.675543650984764, 57.21065729856491, 59.70442168414593, 59.278969913721085, 56.80969901382923, 55.045039504766464, 59.20439891517162, 61.97902522981167, 63.16430702805519, 57.44173429906368, 51.60914607346058, 45.657464638352394, 48.47524143755436, 56.12805739045143, 58.20050798356533, 59.47083301842213, 61.33184015750885, 63.211998268961906, 65.2376201748848, 66.65606886148453, 69.54858765006065, 61.88044711947441, 70.42051926255226, 21.17202691733837, 0.30238563660532236, 3.549237549304962, 0.637057606363669, 0.9140115045011044, 0.4339875077130273, 0.033875779699883424, 0.03869324951665476, 1.855343186762184, 20.458410009741783, 28.79587322473526, 48.24470020830631, 56.785228326916695, 28.028542399406433, 25.73101468384266, 43.553775921463966, 51.3417886197567, 50.788420513272285, 62.591016590595245, 47.57551431655884, 2.6338170329108834, 0.11808412615209818, 0.03845223705866374, 0.0542233872693032, 0.08580341847846285, 0.07597216594149359, 0.0981972624140326, 0.030229695366870146, 0.013352864789339947, 0.142234917730093, 0.06586114599485882, 0.049725137432687916, 0.05155444239790086, 0.07320276024984196, 0.08580361885833554, 0.09119879498030059, 0.08063474582741037, 0.06526612167363055, 0.029625221650348976, 0.043981890339637175, 0.012128786820539972, 0.03511623872327618, 0.0028729830683005275, 0.053054230083944276, 0.03907135520421434, 0.06058018268959131, 0.0422646904917201, 0.09229842777131125, 0.021860162050870713, 0.035780490579782054, 0.045925801459816284, 0.06382164254318923, 0.05120637142681517, 0.019787599630944896, 0.07152834150474519, 0.03210776500054635, 0.06257104949327186, 0.07964035699842498, 0.09060689510079101, 0.015471914412046317, 0.015006773355707992, 2.5783017743378878, 71.85741975903511, 80.25402680039406, 83.36704015731812, 64.149259775877, 50.17611376941204, 38.111833333969116, 37.075708732008934, 53.083713948726654, 50.36468245089054, 27.784287706017494, 0.3409454628126696, 0.11885704327141866, 0.30718569934833795, 1.7722987616434693, 1.523739849217236, 3.9316981891170144, 1.9562622089870274, 0.62158691463992, 10.57606939226389, 80.02840250730515, 70.79269409179688, 74.6325932443142, 66.47548735141754, 65.66229298710823, 64.7355455160141, 67.52091005444527, 64.815554022789, 69.82488602399826, 64.37274858355522, 67.55133122205734, 64.90477323532104, 66.61680936813354, 65.33257707953453, 56.085742861032486, 48.64255025982857, 58.43194596469402, 65.54177105426788, 66.75933972001076, 61.965516954660416, 61.06921724975109, 62.06250675022602, 61.29502013325691, 57.48123697936535, 48.99093456566334, 49.03228774666786, 47.36261174082756, 47.678834572434425, 48.216403126716614, 46.867065131664276, 54.308490827679634, 59.78639468550682, 61.94760851562023, 60.66416658461094, 55.41613519191742, 62.60216139256954, 61.64859116077423, 63.15901771187782, 63.14489386975765, 62.480773106217384, 55.43353445827961, 53.65003935992718, 54.53886106610298, 65.94598576426506, 57.9120958596468, 61.98261983692646, 56.54972456395626, 64.79232206940651, 38.6044616997242, 39.387922659516335, 65.75517520308495, 58.75465504825115, 62.98551522195339, 61.92328602075577, 61.04227289557457, 47.829089909791946, 47.125056087970734, 46.64749391376972, 49.965878650546074, 57.492860555648804, 61.78949140012264, 62.94594794511795, 57.312860414385796, 50.51012724637985, 51.43043026328087, 59.93854612112045, 62.40863777697086, 59.491446912288666, 50.348461121320724, 44.6004943549633, 46.77922144532204, 46.604259833693504, 54.74283032119274, 60.017927661538124, 62.26390354335308, 61.27872280776501, 57.85650484263897, 55.3121043741703, 61.436220556497574, 63.25687766075134, 66.05892330408096, 60.17281495034695, 54.28531967103481, 47.790757566690445, 49.966498017311096, 58.27201634645462, 62.38760970532894, 60.79891875386238, 65.56376427412033, 66.67429268360138, 67.13142335414886, 69.06423524022102, 71.26644507050514, 64.15304437279701, 73.65352258086205, 26.047873981297016, 0.15640624245861545, 0.6954374955967069, 1.3139276951551437, 2.8559224773198366, 0.9299070609267801, 0.24926246842369437, 0.02810420668538427, 1.8606363027356565, 28.612951040267944, 34.54989306628704, 56.67760290205479, 49.92226459085941, 29.646199196577072, 37.52490542829037, 53.64274375140667, 60.194036811590195, 56.92229837179184, 67.66652584075928, 58.89297902584076, 3.1589253433048725, 0.18857426242902875, 0.018966474453918636, 0.036745189790963195, 0.035675602848641574, 0.04608791619830299, 0.04269885801477358, 0.05289889115374535, 0.00555722174794937, 0.13894597155740485, 0.059749010688392445, 0.0468016693048412, 0.056604942874400876, 0.05620365991489962, 0.023066599169396795, 0.030567895773856435, 0.03883194578520488, 0.03403043585421983, 0.05842764272529166, 0.07311788082006387, 0.04453170673514251, 0.10215483169304207, 0.11040874582249671, 0.163523483206518, 0.0984350465296302, 0.14078124338993803, 0.10323804817744531, 0.1748164920718409, 0.09647323851822875, 0.14987368049332872, 0.2775388292502612, 0.15589787130011246, 0.15326866472605616, 0.13765689072897658, 0.16042854927945882, 0.09742196300067008, 0.11684781202347949, 0.16474085772642866, 0.14340446825372055, 0.19679124729009345, 0.19293354882393032, 3.3220403781160712, 85.11248409748077, 90.9283684194088, 93.02921488881111, 71.37070387601852, 49.38785746693611, 37.529833763837814, 66.16464883089066, 65.25807067751884, 61.5548387914896, 39.561322554945946, 0.6018260749988258, 0.2604032034287229, 0.7120523415505886, 2.2615890065208077, 2.2364429058507085, 5.743521004915237, 5.4232879634946585, 5.382786886766553, 10.356183741241693, 83.9933605492115, 71.8483230471611, 78.16158547997475, 68.64886432886124, 69.02471736073494, 65.85596859455109, 70.94045296311378, 68.20261627435684, 73.94819676876068, 65.37176817655563, 70.74619978666306, 66.947171241045, 70.54576054215431, 67.08692774176598, 58.18031966686249, 51.974196285009384, 60.156665816903114, 68.04304763674736, 68.92390877008438, 64.16446655988693, 61.12162783741951, 63.931995034217834, 63.89014407992363, 60.46171724796295, 52.52018518745899, 52.19984717667103, 49.38027687370777, 49.730241894721985, 51.952681839466095, 49.103062748909, 56.844277158379555, 64.34782192111015, 64.45107758045197, 63.562936037778854, 58.78073304891586, 64.95331183075905, 65.50307393074036, 65.36729961633682, 66.28771662712097, 64.61889937520027, 57.3022285848856, 52.6241248100996, 55.578143298625946, 67.9956565797329, 61.904005855321884, 64.47407394647598, 60.42829044163227, 67.09434494376183, 43.25943611562252, 41.98224484920502, 66.61347314715385, 60.524250492453575, 64.3510289490223, 65.62441661953926, 63.71976122260094, 50.611547604203224, 49.41770866513252, 49.269600212574005, 51.27543278038502, 59.49133291840553, 65.65654769539833, 64.46215018630028, 58.385033681988716, 49.885889142751694, 52.43921533226967, 62.754715606570244, 65.23778736591339, 62.44654454290867, 52.57508844137192, 47.57672645151615, 48.45417156815529, 48.64203728735447, 57.61517599225044, 64.70053419470787, 66.70130163431168, 63.98291990160942, 57.17653512954712, 54.93497081100941, 63.99881064891815, 66.56976029276848, 66.11256122589111, 61.922366470098495, 58.12051087617874, 50.73807321488857, 53.598612919449806, 62.941133603453636, 63.91364201903343, 64.80470940470695, 67.30060547590256, 71.1773930490017, 68.75045567750931, 72.40231052041054, 74.33705270290375, 66.86489045619965, 74.89613950252533, 25.775747783482075, 0.5444118683226407, 9.967410452663898, 3.5439636697992682, 3.36072847712785, 1.2844869936816394, 0.5639377736952156, 0.17417460854630917, 2.8569545969367027, 37.695086896419525, 44.72538225352764, 64.2410096526146, 67.5572969019413, 40.90667076408863, 36.551234275102615, 57.35215790569782, 69.79099944233894, 65.71373462677002, 75.71595311164856, 67.01613754034042, 3.61474912147969, 0.2801954804453999, 0.11955552297877148, 0.12203218109789304, 0.24263566854642704, 0.11910076456842944, 0.14742063009180129, 0.12300082482397556, 0.09465509545407258, 0.2396564354421571, 0.2091244503390044, 0.10151857364689931, 0.17242236819583923, 0.1715033667278476, 0.2055683161597699, 0.145834987051785, 0.14966858056141064, 0.11762425434426405, 0.15694076690124348, 0.15346295898780227, 0.17993416433455423, 0.22158096864586696], [0.006255334092202247, 0.11281179773504846, 0.06918801591382362, 0.110903728636913, 0.03226690001611132, 0.04327851616835687, 0.007320251070268569, 0.03131792320345994, 0.10822172567714006, 0.014702310982102063, 0.047095340851228684, 0.03176472950144671, 0.0503851367830066, 0.0394572126242565, 0.02279863376315916, 0.0573359100962989, 0.04605398149578832, 0.1376500926562585, 0.0995604095805902, 16.603661254048347, 78.64172011613846, 62.95198582112789, 71.41300320625305, 43.75582627952099, 22.422615811228752, 17.86993570625782, 47.692570835351944, 22.684503458440304, 38.896255642175674, 10.81543754786253, 0.15760973881697282, 0.15404263569507748, 0.1975366158876568, 0.31660637352615595, 1.105199195444584, 1.36118124704808, 1.6355461184866726, 1.0382433445192873, 55.884688049554825, 78.3346737921238, 67.9335755109787, 63.72880853712559, 60.3605742752552, 61.388552114367485, 59.99701738357544, 62.92488947510719, 63.2288883626461, 62.08524852991104, 64.5310252904892, 59.74913388490677, 57.03988306224346, 58.67881491780281, 53.97944748401642, 47.615548968315125, 47.893686443567276, 57.59168945252895, 64.00275483727455, 58.90310928225517, 63.96758392453194, 61.55625231564045, 59.81937691569328, 58.28268617391586, 54.68943938612938, 53.27640540897846, 50.13845019042492, 48.33007402718067, 45.13294838368893, 43.55824448168278, 45.95453269779682, 49.22693990170956, 57.67138637602329, 62.10230581462383, 57.24622339010239, 59.046908766031265, 59.10194881260395, 54.669919833540916, 55.27768202126026, 56.354540437459946, 60.97739517688751, 56.2425072491169, 52.42735996842384, 57.11903661489487, 60.75280822813511, 54.871624410152435, 59.39967803657055, 52.94205754995346, 64.35261726379395, 36.45686633884907, 40.663594007492065, 63.04770268499851, 53.14902484416962, 55.298941880464554, 49.746508821845055, 50.88127613067627, 46.30477890372276, 46.05626083910465, 44.290966764092445, 47.85010278224945, 47.83331908285618, 55.519231259822845, 56.12581171095371, 60.282404869794846, 54.76907931268215, 54.619754925370216, 58.476821556687355, 56.63741245865822, 50.62278740108013, 45.688729360699654, 42.119824066758156, 43.15748758614063, 45.13162225484848, 53.37292023003101, 57.72577665746212, 59.881078004837036, 58.33956532180309, 56.15109175443649, 54.007752165198326, 56.35846182703972, 58.944717049598694, 62.962921634316444, 59.73668575286865, 49.14570026099682, 44.696359410881996, 47.46259577572346, 45.71201831102371, 54.143195897340775, 57.41144232451916, 60.23779906332493, 61.68877400457859, 63.21321800351143, 64.17930856347084, 64.79069575667381, 68.31127524375916, 62.496029287576675, 70.1480282843113, 13.381220418959856, 0.25678674748633057, 0.6597236869856715, 0.9119767136871815, 1.6031958418898284, 0.1587789924815297, 0.05882233912416268, 0.046476408242597245, 6.9032306503504515, 27.556237243115902, 15.863513220101595, 37.16456696391106, 55.908474773168564, 14.729317780584097, 27.168401554226875, 39.61648419499397, 51.78305134177208, 57.01188616454601, 58.664162904024124, 12.957027330994606, 0.26439254404976964, 0.054325903838616796, 0.0610862086614361, 0.06632222008192912, 0.058019409552798606, 0.03988667864177842, 0.04622870903403964, 0.02118444401276065, 0.046711019676877186, 0.007900365180830704, 0.008058260809775675, 0.03556705632945523, 0.01582595781655982, 0.04666563734645024, 0.028750088531523943, 0.06473800196545199, 0.04214104497805238, 0.03053458633075934, 0.029032214115431998, 0.02697178024391178, 0.00925610571357538, 0.04602317123499233, 0.06643164975685067, 0.014998384303908097, 0.05478778315591626, 0.023044624176691286, 0.033041872884496115, 0.011623814698396018, 0.06474326379247941, 0.07390851300442591, 0.02479296083038207, 0.026074968991451897, 0.03630633931607008, 0.06005896495480556, 0.03339227791002486, 0.003657029155874625, 0.06780553580028936, 0.03570609769667499, 0.05803697247756645, 0.09040088232723065, 22.04438030719757, 91.08499601483345, 69.89204362034798, 80.09871393442154, 48.94504442811012, 29.20298147946596, 20.763913616538048, 39.59968529641628, 32.423618361353874, 44.87419366836548, 13.613065928220749, 0.16545664431760088, 0.20472016010899097, 0.49520667584147304, 1.014363644644618, 3.8973390078172088, 2.936338512226939, 1.0386914829723537, 1.5479546436108649, 59.07692335546017, 82.44000390172005, 70.153439193964, 67.54798740148544, 63.706648126244545, 61.723910719156265, 62.81790241599083, 65.13675078749657, 65.40633112192154, 65.11298686265945, 65.68706765770912, 62.56327047944069, 60.80545820295811, 61.800347417593, 56.1631029099226, 50.23558057844639, 50.429392978549004, 60.64926378428936, 65.78444883227348, 61.394905373454094, 65.07817313075066, 62.19442047178745, 62.077242359519005, 61.70738160610199, 58.303250670433044, 54.8551294952631, 52.09377206861973, 50.59931606054306, 48.052540719509125, 47.443866580724716, 48.228117898106575, 51.09062969684601, 59.84886333346367, 65.70080772042274, 57.42223374545574, 60.69424957036972, 61.53421349823475, 58.04883912205696, 57.689481005072594, 59.08277124166489, 63.6439248919487, 57.027966901659966, 53.75669963657856, 59.109309017658234, 63.13930056989193, 57.64763385057449, 60.209866762161255, 56.01572021842003, 66.02737739682198, 40.76934613287449, 42.25044205784798, 65.08071899414062, 54.57368619740009, 59.04224641621113, 53.256521075963974, 53.55340674519539, 48.56684312224388, 48.70199427008629, 45.660759061574936, 49.853245094418526, 50.262125954031944, 57.3884991556406, 57.09001377224922, 63.25903594493866, 54.99288730323315, 55.13088829815388, 59.70866225659847, 60.17084285616875, 52.97230012714863, 48.45565728843212, 45.87667487561703, 45.85674114525318, 46.809061244130135, 56.00042603909969, 60.66019579768181, 61.55154436826706, 60.08597441017628, 57.874645069241524, 54.74453642964363, 59.146011248230934, 61.56177721917629, 65.39886072278023, 62.200709134340286, 52.029867097735405, 47.48748444020748, 50.44221729040146, 48.29666242003441, 56.80733934044838, 60.56584686040878, 62.79486425220966, 64.48749482631683, 67.0761439204216, 66.57088503241539, 67.73249790072441, 70.83005368709564, 65.14416038990021, 74.43995878100395, 17.183990813791752, 0.4044272314058617, 0.7746344490442425, 2.387873805128038, 3.1133980862796307, 0.24907158804126084, 0.31688441173173487, 0.01666034517256776, 9.617396034300327, 34.40988577902317, 15.115416012704372, 39.15446698665619, 48.7634863704443, 16.548056937754154, 38.822767585515976, 47.541965916752815, 60.5217844247818, 62.70089149475098, 69.02664005756378, 20.88681612163782, 0.28244703775271773, 0.036743160017067567, 0.03596059497795068, 0.036420678297872655, 0.05603315519692842, 0.009809967741603032, 0.07424526993418112, 0.07303584381588735, 0.04850523589993827, 0.025984425119531807, 0.021097059834573884, 0.016619831330899615, 0.028103032236685976, 0.09133259678492323, 0.04369312067865394, 0.018971892131958157, 0.050893942097900435, 0.08905142778530717, 0.020783025611308403, 0.04431933746673167, 0.015231164488795912, 0.14250825071940199, 0.21234448067843914, 0.09446410374948755, 0.1028516489895992, 0.09988729594624601, 0.17756889516022056, 0.06698957411572337, 0.07590929119032808, 0.3008194378344342, 0.08313988015288487, 0.14859113056445494, 0.1259209681302309, 0.18642853538040072, 0.10379278130130842, 0.16688168660039082, 0.2012863615527749, 0.2567640377674252, 0.2944704535184428, 0.20092357008252293, 29.318083003163338, 103.35117101669312, 79.73940521478653, 93.00687208771706, 57.721330896019936, 35.359128043055534, 27.753786742687225, 61.82078652083874, 36.46402135491371, 56.60538397729397, 17.93876711279154, 0.2957992540905252, 0.3487435943679884, 0.6261217931751162, 1.9357821391895413, 5.237826565280557, 4.695928618311882, 7.494206763803959, 2.2929223626852036, 62.920439913868904, 83.66799160838127, 71.13301903009415, 70.93086987733841, 67.6111552119255, 66.42908424139023, 66.23628258705139, 70.05585283041, 68.74743103981018, 66.82830601930618, 69.52382817864418, 65.64265564084053, 62.29237921535969, 63.775945007801056, 59.44255493581295, 52.73751452565193, 52.6890405267477, 63.2936292886734, 69.98092845082283, 62.17956326901913, 67.70837679505348, 62.59822100400925, 63.24832431972027, 63.63208472728729, 62.062913328409195, 56.847655177116394, 53.53565409779549, 52.25489482283592, 50.032363682985306, 49.717174395918846, 50.295545160770416, 53.43424133956432, 61.97893023490906, 69.16067406535149, 57.86824621260166, 62.80482351779938, 65.87916254997253, 59.75865997374058, 60.70127159357071, 62.40263409912586, 64.84766989946365, 57.764447182416916, 53.82445000112057, 60.57232931256294, 65.05346685647964, 61.16546608507633, 62.87249408662319, 60.77574759721756, 68.80073457956314, 44.76191349327564, 45.85792288184166, 66.65815114974976, 59.607785269618034, 61.24499961733818, 54.112634137272835, 56.77373394370079, 52.440902441740036, 50.79632788896561, 48.255902007222176, 51.65486142039299, 53.24363596737385, 60.62786713242531, 60.83532840013504, 64.86067280173302, 57.223755195736885, 57.58214436471462, 64.4632825255394, 63.68683598935604, 55.94773426651955, 49.57934059202671, 46.55248761177063, 47.74848483502865, 47.940222546458244, 58.12239557504654, 62.14134871959686, 64.32724982500076, 61.427424028515816, 59.27610106766224, 55.63227519392967, 59.865582436323166, 64.54424098134041, 67.85407617688179, 66.27081513404846, 54.655161425471306, 49.6610514074564, 54.08317431807518, 48.917537704110146, 60.29028184711933, 64.03438434004784, 66.97343543171883, 68.08114439249039, 69.46620807051659, 69.59915533661842, 71.26196131110191, 74.98309403657913, 68.92159849405289, 76.42159804701805, 16.932026334106922, 0.8720402035396546, 8.695766888558865, 5.08002863265574, 6.049697650596499, 0.26630954118445516, 0.40379667305387557, 0.3450482035987079, 12.693402227014303, 41.54830813407898, 24.086728915572166, 48.64945448935032, 68.72783929109573, 24.53878875821829, 38.08507137000561, 53.91396179795265, 72.28662952780724, 72.2755417227745, 78.58504235744476, 25.593277774751186, 0.4735443351091817, 0.2104840351967141, 0.1261728975805454, 0.16724571003578603, 0.20651517785154283, 0.08021417816053145, 0.13456280285026878, 0.11006887187249959, 0.14279035589424893, 0.09630083019146696, 0.11490458738990128, 0.08893028702004813, 0.09835973338340409, 0.14437577628996223, 0.22463971545221284, 0.16654383129207417, 0.2813596132909879, 0.15974121663020924, 0.10849726284504868, 0.12916879932163283, 0.1048720272956416], [0.07389427119051106, 0.03293104426120408, 0.07231653944472782, 0.029041286870779004, 0.011973185355600435, 0.08662133201141842, 0.0966142317338381, 0.08710216949111782, 0.01697379680990707, 0.05456343562400434, 0.03447064074862283, 0.05616445225314237, 0.049280130842817016, 0.0527993543073535, 0.08725569015950896, 0.07909189502242953, 0.027448623113741633, 0.04790343205968384, 0.39827690517995507, 45.89304439723492, 73.97930949926376, 75.83875492215157, 55.45915648341179, 38.19351375102997, 31.036138013005257, 45.26287481188774, 60.424091666936874, 44.298117980360985, 37.14246354997158, 0.5709168710745871, 0.0708074340946041, 0.04212571220705286, 0.2333875437034294, 0.6830853677820414, 2.1183093823492527, 1.601562404539436, 1.901145454030484, 20.948739498853683, 86.49583786725998, 64.7887958586216, 68.97465884685516, 61.51818975806236, 61.53892904520035, 53.5150858014822, 58.047436997294426, 56.70469544827938, 60.26532098650932, 60.49590781331062, 61.8132059276104, 59.297911897301674, 56.198102831840515, 51.65166579186916, 48.73300060629845, 44.90768127143383, 47.250289767980576, 54.14133779704571, 61.704771146178246, 59.92791049182415, 61.496872901916504, 57.62626759707928, 58.957324773073196, 58.8029770553112, 59.90242525935173, 57.053151950240135, 56.49862490594387, 56.75896033644676, 50.601850524544716, 43.76366525888443, 43.49224202334881, 43.696690052747726, 58.23828175663948, 58.23879472911358, 61.651672795414925, 57.721004113554955, 59.28519777953625, 48.05067881941795, 51.84664472937584, 54.847237318754196, 61.806316897273064, 56.382373943924904, 56.23345233500004, 58.99579390883446, 59.57708291709423, 53.2361351698637, 54.99251112341881, 52.469157725572586, 67.16322004795074, 37.38806717097759, 37.53345116972923, 63.6579043418169, 53.83143022656441, 57.11687073111534, 51.563024148344994, 52.89466269314289, 53.07850822806358, 53.40966425836086, 51.118949577212334, 49.327319115400314, 50.16631029546261, 55.372741520404816, 55.18294170498848, 58.05665150284767, 52.77731738984585, 56.30765475332737, 59.62817117571831, 57.006726041436195, 50.68243280053139, 43.492135629057884, 43.01677353680134, 42.19295114278793, 45.08483536541462, 53.90793912112713, 57.52426967024803, 60.18333658576012, 56.64573021233082, 54.53348435461521, 53.39590519666672, 58.067321330308914, 61.08677990734577, 61.78057707846165, 57.78776653110981, 47.39911638200283, 44.648732766509056, 46.1989089846611, 47.88767136633396, 48.03041070699692, 52.7516383677721, 54.04519535601139, 58.74531514942646, 61.75362132489681, 61.35145090520382, 64.45792481303215, 63.54275532066822, 67.1033276617527, 66.29903241991997, 58.61530892550945, 2.9353429656475782, 0.8701021294109523, 3.6964302510023117, 0.9176026680506766, 0.36531061632558703, 0.19516003638273105, 0.0631956706638448, 1.8981122667901218, 19.797496274113655, 51.98463812470436, 60.94963386654854, 103.91028061509132, 76.82725667953491, 24.934087246656418, 29.151731729507446, 39.88574534654617, 51.26397639513016, 61.33976653218269, 45.99242806434631, 2.4026654614135623, 0.1748643902828917, 0.003912181846317253, 0.04485517922148574, 0.07201039610663429, 0.03093916442594491, 0.07473807083442807, 0.03771971503738314, 0.048454524949193, 0.04204042459605262, 0.04791537321580108, 0.07195153637439944, 0.11677400543703698, 0.02918422265793197, 0.023894886071502697, 0.04052168245834764, 0.07418626919388771, 0.052626333708758466, 0.027293625571473967, 0.07139016102883033, 0.03802390652708709, 0.021856265775568318, 0.020587529070326127, 0.0766470527742058, 0.03407584044907708, 0.052666175906779245, 0.054348921548807994, 0.08970706330728717, 0.06374105272698216, 0.04434470407431945, 0.05487446971528698, 0.04536595122772269, 0.04821945709409192, 0.04792456100403797, 0.06343479064526036, 0.01935500175022753, 0.013128193495504092, 0.07359370880294591, 0.04819524452614132, 0.5791979329660535, 56.40885852277279, 84.09322679042816, 81.44921466708183, 68.53827506303787, 48.832247480750084, 38.31468164920807, 39.46954607963562, 54.92337383329868, 46.9740179926157, 37.84473806619644, 1.1021473654545844, 0.15594360243994743, 0.21111606300109997, 1.1872801347635686, 2.173869526013732, 5.692451745271683, 1.433328806888312, 0.6191707192920148, 23.941514007747173, 87.60233089327812, 67.54354923963547, 70.92161357402802, 64.12118688225746, 63.8213449716568, 56.16177678108215, 61.49802424013615, 59.62812937796116, 62.157273665070534, 63.52624900639057, 65.48307940363884, 61.56634457409382, 59.181033968925476, 53.312731459736824, 51.4448656886816, 47.798467352986336, 49.54860024154186, 57.07314267754555, 62.43435859680176, 62.72559776902199, 62.585047110915184, 58.29185128211975, 61.55974432826042, 60.99627636373043, 61.2126861512661, 61.7581582814455, 61.17208153009415, 59.351937398314476, 53.1611043959856, 46.711740866303444, 45.925061479210854, 46.517624482512474, 60.42567618191242, 60.991074442863464, 63.17362792789936, 59.950629472732544, 60.075160190463066, 51.84752628207207, 54.50885787606239, 56.96125388145447, 64.69017595052719, 56.616300791502, 59.67444509267807, 61.04141414165497, 61.76805295050144, 54.69303399324417, 56.42740152776241, 56.15109175443649, 69.12634670734406, 40.30937701463699, 39.58578944206238, 65.02076581120491, 57.26139597594738, 60.52246458828449, 53.26468303799629, 55.60212381184101, 53.79727765917778, 56.34528033435345, 52.39733397960663, 52.929780408740044, 52.68239848315716, 58.40840622782707, 57.109601721167564, 59.99458931386471, 56.23886324465275, 57.78313837945461, 62.427606359124184, 59.13668654859066, 51.95047415792942, 46.0654753446579, 43.84700618684292, 45.54931104183197, 47.37638600170612, 55.803702995181084, 59.30058695375919, 62.608020678162575, 56.1868554353714, 55.417107939720154, 53.081073090434074, 59.36178646981716, 63.67601037025452, 65.01290023326874, 60.15584506094456, 49.17473070323467, 47.55163639783859, 49.57760788500309, 51.40984296798706, 52.16096766293049, 54.99517858028412, 57.19274125993252, 60.24662598967552, 64.70622628927231, 63.44964511692524, 67.60099455714226, 67.17670172452927, 69.88499879837036, 68.48278284072876, 63.90716716647148, 3.9956950675696135, 0.5107788043096662, 1.4614050253294408, 1.8559288303367794, 1.5230698976665735, 0.33625746436882764, 0.06567357559106313, 1.0529489116743207, 25.101432166993618, 40.82709923386574, 58.72078746557236, 100.28890773653984, 63.23961138725281, 29.404938742518425, 42.210950776934624, 46.759052127599716, 58.363226652145386, 66.6423211991787, 59.32936280965805, 3.6546448431909084, 0.24279313744045794, 0.07981123650097288, 0.017552336175867822, 0.03207566711353138, 0.046227811035350896, 0.0510352841229178, 0.018410657794447616, 0.05922591903072316, 0.04648965928936377, 0.025412921313545667, 0.03405709379876498, 0.015643539773009252, 0.03962049253459554, 0.012663839115703013, 0.032259823638014495, 0.015958932126522996, 0.07439543609507382, 0.02841878082108451, 0.07137887296266854, 0.04601559761795215, 0.17725741578033194, 0.11039818506105803, 0.24213292286731303, 0.15774347382830456, 0.13153188658179715, 0.16888818674487993, 0.23121766716940328, 0.1318358999560587, 0.16026932891691104, 0.1708500986569561, 0.0918031926266849, 0.14245109050534666, 0.1705487273284234, 0.1139135827543214, 0.10840448696399108, 0.24681979324668646, 0.1527752701076679, 0.10108914473676123, 1.0047422046773136, 67.95181453227997, 93.78735020756721, 94.01561915874481, 73.56246426701546, 55.02874977886677, 42.51637078821659, 62.872000113129616, 77.02433690428734, 59.89312715828419, 54.00154709815979, 1.8367254920303822, 0.4070823092479259, 0.2672048384556547, 1.022644112817943, 4.167379355058074, 8.943247608840466, 6.974597470834851, 4.295124700292945, 24.47120178490877, 92.96794697642326, 69.05519172549248, 75.14193311333656, 67.10540235042572, 67.59250581264496, 58.34732450544834, 63.286763057112694, 62.82448746263981, 64.55617234110832, 65.17300844192505, 67.91139230132103, 63.81775036454201, 61.733136624097824, 56.26610778272152, 53.33201542496681, 48.86000119149685, 51.211793795228004, 59.07430909574032, 65.01499772071838, 66.77604362368584, 64.48066279292107, 58.78645174205303, 61.989611461758614, 63.540752828121185, 64.44581866264343, 61.38248763978481, 62.875473126769066, 61.91622219979763, 56.43843233585358, 48.6454951018095, 48.59152279794216, 48.48564147949219, 62.85575598478317, 64.67366963624954, 66.376061886549, 62.02890135347843, 64.54228788614273, 53.43429073691368, 57.43092767894268, 58.42189930379391, 67.22899451851845, 58.84578175842762, 60.961911007761955, 65.2953314781189, 65.24823680520058, 58.21978434920311, 59.173194989562035, 57.80603215098381, 69.8992708325386, 44.68405567109585, 43.00281308591366, 66.66199654340744, 60.52894324064255, 62.255631387233734, 56.88901215791702, 58.0112287402153, 58.10333959758282, 59.21488255262375, 55.642568841576576, 54.875971376895905, 54.71619375050068, 60.81490829586983, 60.3187271207571, 63.023402988910675, 56.29500523209572, 58.57486769556999, 64.7565507888794, 62.69976295530796, 56.080373749136925, 48.62294711172581, 46.62067115306854, 48.43247473239899, 50.23817963898182, 58.696920946240425, 63.117729127407074, 66.2909996509552, 58.5556673258543, 58.13648521900177, 54.75801810622215, 62.27984368801117, 66.29326432943344, 67.0469006896019, 63.792724907398224, 52.30660244822502, 51.78620137274265, 50.930168107151985, 52.924996465444565, 54.027404710650444, 57.75318078696728, 61.88762113451958, 64.38141971826553, 67.94821992516518, 65.49048140645027, 69.99266982078552, 69.95592579245567, 73.58955681324005, 71.7329004406929, 64.29374322295189, 4.062386238947511, 3.331357715651393, 10.838523209095001, 3.749846597202122, 2.2956539411097765, 0.4753808834357187, 0.2223824881366454, 2.7472148230299354, 33.06176371872425, 74.07522395253181, 67.5308047235012, 109.68920812010765, 83.3218377828598, 37.21448488533497, 42.50029765069485, 56.2993597984314, 66.80038511753082, 75.79995900392532, 68.11557814478874, 4.329948406666517, 0.4546852642670274, 0.11631132088950835, 0.12955467158462852, 0.23663659201702103, 0.12271859348402359, 0.2541916648624465, 0.1186992997827474, 0.1467577289440669, 0.10682039501261897, 0.23955829383339733, 0.10799765645060688, 0.18070954538416117, 0.10111175055499189, 0.08169395383447409, 0.09665979217970744, 0.1678243328933604, 0.15892314724624157, 0.18360055197263137, 0.3005071124061942, 0.134817314974498], [0.03152658544422593, 0.037749857365270145, 0.048785674953251146, 0.0708685202698689, 0.030491100187646225, 0.044299332876107655, 0.05083529758849181, 0.03382299444638193, 0.04729149048216641, 0.04802855815796647, 0.14521576871629804, 0.03573937930923421, 0.03108838620391907, 0.027123790641780943, 0.04221983137540519, 0.10567295306827873, 0.17279856285313144, 0.05541188482311554, 3.666676660068333, 69.09400284290314, 72.12129279971123, 69.38811466097832, 53.948384150862694, 22.464301474392414, 17.50570435076952, 43.19783382117748, 44.58893537521362, 44.85292240977287, 10.328703615814447, 0.056447299575665966, 0.04668548979680054, 0.21169085637666285, 0.652811739128083, 0.8700915612280369, 4.080005418509245, 2.4561307299882174, 3.309046975336969, 68.31222519278526, 73.98835301399231, 69.18009862303734, 65.9175556898117, 62.671929448843, 60.394962430000305, 53.36514584720135, 52.93789677321911, 51.52889057993889, 54.34092968702316, 55.66106244921684, 58.51880170404911, 54.23169694840908, 53.35945375263691, 49.43047598004341, 47.51632869243622, 48.39034639298916, 45.20963966846466, 49.349623918533325, 61.563160344958305, 61.005395874381065, 61.85503788292408, 57.637773379683495, 58.49579393863678, 58.901524767279625, 60.81333518028259, 59.34665948152542, 60.51877498626709, 57.340378537774086, 55.18090881407261, 41.427436619997025, 44.71896439790726, 40.943958163261414, 51.669331043958664, 58.97440865635872, 60.874633491039276, 58.43953795731068, 53.82745943963528, 41.907518059015274, 50.5163399130106, 55.28351850807667, 61.627430096268654, 55.52192911505699, 58.65935616195202, 58.369880095124245, 56.44928075373173, 49.59835857152939, 52.658547163009644, 53.2733503729105, 65.29835611581802, 40.916519835591316, 37.42746725678444, 60.770743265748024, 53.50904792547226, 61.21772088110447, 54.363964051008224, 59.02289405465126, 56.35063424706459, 59.55952785909176, 53.95992413163185, 54.416899010539055, 52.4707156419754, 56.32823444902897, 57.46775530278683, 57.90859244763851, 52.47700810432434, 57.031550109386444, 59.026275873184204, 55.601937621831894, 49.26027551293373, 44.34098348021507, 43.44759821891785, 42.22146101295948, 44.42706786096096, 50.72936788201332, 57.41167411208153, 59.365947246551514, 55.87674267590046, 53.322010561823845, 57.26499818265438, 59.91013504564762, 57.288625314831734, 59.17430453002453, 51.33568994700909, 45.18003925681114, 45.931194350123405, 46.52269721031189, 48.40064384043217, 52.64851190149784, 51.883514150977135, 49.1084660589695, 50.23127540946007, 54.77131739258766, 55.031945407390594, 56.34017340838909, 57.512866482138634, 64.58143338561058, 63.969871401786804, 67.71998137235641, 28.742070011794567, 0.024598740783403628, 1.7018774966709316, 2.2132672369480133, 0.2770185243571177, 0.4474681749707088, 0.0635709599009715, 0.2816896018339321, 10.274661965668201, 19.055717177689075, 58.03542584180832, 77.23888099193573, 76.06532156467438, 33.48262533545494, 16.75400208681822, 35.877849608659744, 46.28033101558685, 52.23966903984547, 57.48141176998615, 11.017220970243216, 0.4922982881544158, 0.06644296008744277, 0.13793481019092724, 0.029031776248302776, 0.08020537628908642, 0.06756545844837092, 0.010596184147289023, 0.025999720783147495, 0.06857883141492493, 0.03191360432538204, 0.03471693358733319, 0.04651943796488922, 0.061332687037065625, 0.017002211789076682, 0.01615980738279177, 0.0950956936867442, 0.07772854747599922, 0.015429272461915389, 0.027518019487615675, 0.07611827997607179, 0.02501434904843336, 0.03781775645620655, 0.09268089357647114, 0.05146235671418253, 0.034921625338029116, 0.00699014424753841, 0.029733061273873318, 0.06455166352679953, 0.02918256024713628, 0.09132115286774933, 0.018099812950822525, 0.1470375483040698, 0.025237566660507582, 0.055837706895545125, 0.08614001955720596, 0.1086772781854961, 0.06509239232400432, 0.04018751562398393, 5.4662342090159655, 84.38813656568527, 80.45016467571259, 77.59490668773651, 59.60923679172993, 33.710016533732414, 22.23615601658821, 37.30286814272404, 51.7186675965786, 45.72013087570667, 13.405495416373014, 0.03527547021803912, 0.05708173936000094, 0.3695173765299842, 2.3177780164405704, 4.0097172651439905, 5.66662548109889, 1.6079606674611568, 3.683746294118464, 70.91684862971306, 76.32227897644043, 72.34187096357346, 67.83952295780182, 65.08843258023262, 62.5378992408514, 56.19386225938797, 55.55361941456795, 55.98746873438358, 57.13456258177757, 57.77209997177124, 60.97315080463886, 57.24241599440575, 54.735690504312515, 50.87327755987644, 49.87013518810272, 48.836681842803955, 47.33034387230873, 52.36133091151714, 63.500440791249275, 63.046840131282806, 64.99330848455429, 57.119823172688484, 61.0414407402277, 60.505943074822426, 62.178738713264465, 60.75277402997017, 62.118523344397545, 59.73620317876339, 57.530497536063194, 43.44434939324856, 47.305162623524666, 42.46225789189339, 54.05358910560608, 61.62864223122597, 63.18491332232952, 61.16720639169216, 57.23122179508209, 45.0254787504673, 53.558574467897415, 58.647227212786674, 63.174866661429405, 56.99088469147682, 58.83013039827347, 60.42868562042713, 59.33653682470322, 51.76453113555908, 55.235375091433525, 56.29414267838001, 67.03681603074074, 43.42909701168537, 39.7003722935915, 62.87320464849472, 55.79888105392456, 62.93768338859081, 56.84125632047653, 60.23990415036678, 59.98784087598324, 61.02356269955635, 57.294233813881874, 57.103677839040756, 55.01731239259243, 57.8021639585495, 59.78254549205303, 60.223356038331985, 52.587468177080154, 58.799230456352234, 61.05989255011082, 58.17452497780323, 51.28421410918236, 47.211588844656944, 45.12078143656254, 45.408733785152435, 46.55904605984688, 52.29317016899586, 59.407528415322304, 60.82721583545208, 57.15854309499264, 55.159056186676025, 59.64817710220814, 62.06722989678383, 61.62693992257118, 60.467766523361206, 54.016446098685265, 47.439774200320244, 49.49656583368778, 48.67491692304611, 49.87511672079563, 53.838794231414795, 56.14437371492386, 52.06626154482365, 53.43378536403179, 56.31606750190258, 58.01982007920742, 58.47177542746067, 61.99589632451534, 67.19337522983551, 66.65170669555664, 69.98710691928864, 35.46863056719303, 0.023831874023017008, 0.7189907098654658, 1.0829464020207524, 2.159244823269546, 1.0132302367128432, 0.3599010722246021, 0.34076737705618143, 8.364111185073853, 29.355167113244534, 62.52070516347885, 79.85080763697624, 74.33151260018349, 37.21214801073074, 23.627593852579594, 42.7474819868803, 54.72575403749943, 57.33363389968872, 67.56208464503288, 16.641005650162697, 0.6056240305770189, 0.14578581234673038, 0.19108598702587187, 0.0533658207859844, 0.03427955256483983, 0.07124720854335465, 0.014240234067983693, 0.031784418679308146, 0.035638732952065766, 0.06462752586230636, 0.05188355891732499, 0.04576505598379299, 0.04778279224410653, 0.00812869433502783, 0.024599872558610514, 0.028021117686876096, 0.07129264282411896, 0.03848211963486392, 0.03560065335477702, 0.039840691460995004, 0.08559470428735949, 0.20107910939259455, 0.16349857673048973, 0.1814996506436728, 0.1157642318867147, 0.0998556285048835, 0.13238277373602614, 0.13834863173542544, 0.18355678010266274, 0.1263004430802539, 0.17948155815247446, 0.22067266894737259, 0.09277228906285018, 0.09433843588340096, 0.13848350965417922, 0.2399854888790287, 0.2961266302736476, 0.16395291953813285, 7.229294953867793, 95.76919466257095, 89.44245055317879, 88.87762606143951, 70.3066773712635, 35.61413995921612, 26.1764020845294, 57.16782979667187, 57.16207690536976, 61.97181701660156, 17.274562753736973, 0.12774911534506828, 0.189092890068423, 0.8223087689839303, 4.057974200695753, 4.498526835814118, 14.21586748212576, 8.913600649684668, 3.8516664085909724, 74.58725407719612, 76.82182297110558, 78.68738606572151, 70.82179293036461, 70.08169904351234, 64.64262530207634, 57.958210185170174, 58.864009380340576, 58.032522797584534, 57.045229375362396, 62.655039355158806, 64.40897583961487, 60.66079996526241, 58.740747794508934, 53.70337709784508, 51.63620822131634, 52.74538390338421, 48.58276426792145, 54.715460389852524, 66.26943960785866, 66.84831574559212, 67.42544397711754, 59.412870928645134, 62.35746592283249, 61.90272532403469, 63.275899440050125, 62.99190267920494, 63.77038210630417, 62.31629513204098, 60.39283834397793, 46.046882942318916, 48.32269102334976, 44.90188278257847, 56.906757205724716, 65.66462606191635, 65.88268116116524, 64.73513513803482, 58.728949427604675, 47.174483835697174, 57.0521792024374, 61.09201982617378, 66.56533733010292, 59.17107090353966, 61.55491478741169, 63.57219994068146, 62.6066717505455, 54.82311621308327, 58.40315490961075, 60.53585886955261, 69.97229531407356, 47.63676702976227, 42.28863760828972, 63.25994789600372, 58.46890278160572, 65.58873653411865, 59.55445893108845, 62.95111946761608, 62.7751699090004, 63.684145733714104, 60.07882319390774, 60.47998666763306, 57.42354467511177, 61.095014065504074, 62.609726786613464, 62.367083206772804, 53.77700574696064, 60.04478842020035, 65.13243421912193, 60.58744490146637, 53.76131258904934, 50.29001645743847, 47.748534232378006, 47.77831323444843, 49.954441264271736, 55.375313982367516, 62.82168321311474, 63.80549222230911, 60.38951352238655, 55.96002660691738, 62.03979916870594, 65.20339921116829, 62.90906332433224, 63.38012784719467, 56.02385178208351, 50.05322076380253, 51.95074774324894, 51.61649487912655, 52.41885982453823, 57.36161559820175, 59.434704557061195, 55.87594851851463, 56.465502083301544, 61.65080264210701, 61.9982597976923, 61.6473638266325, 65.11855736374855, 71.59990757703781, 69.52926188707352, 73.61253798007965, 35.03791227936745, 0.1253224557149224, 5.300022577866912, 7.578995889052749, 2.8891835175454617, 1.2750547123141587, 0.36606057139579207, 0.5636972584761679, 14.18958144262433, 33.908206298947334, 66.70990437269211, 80.20497143268585, 81.02527901530266, 45.32054051756859, 28.350052647292614, 49.159022346138954, 62.62016862630844, 64.91089090704918, 78.1780917942524, 19.958265647292137, 0.8373596426099539, 0.4876926087308675, 0.27665867179166526, 0.2710744854994118, 0.12601851602084935, 0.26247082685586065, 0.07090521947247908, 0.1473817860824056, 0.20157643739366904, 0.1698079748894088, 0.2150400055688806, 0.16954197431914508, 0.12761652324115857, 0.04397892174893059, 0.16039944224758074, 0.3371901955688372, 0.27179522963706404, 0.12338025524513796, 0.13801034598145634, 0.18928044562926516], [0.0349842180730775, 0.027038551270379685, 0.047422011994058266, 0.024962654752016533, 0.06606588227441534, 0.0470022940862691, 0.08015351500944234, 0.05842670019774232, 0.001726959901588998, 0.029446074622683227, 0.07234062955831178, 0.05914114721235819, 0.09218238556059077, 0.019855290920531843, 0.14166897075483575, 0.006916427646501688, 0.18496239295927808, 0.2104544680332765, 21.176713965833187, 72.93774738907814, 62.29051351547241, 63.058775290846825, 55.55421218276024, 34.07534413039684, 42.08180710673332, 40.49835227429867, 31.517384089529514, 34.40925121307373, 0.9179546241648495, 0.010162011058127973, 0.07449031225405633, 0.2702174533624202, 0.7742515008430928, 2.842310182750225, 3.015413931570947, 0.954291361849755, 22.47654441744089, 83.86844605207443, 64.84269216656685, 71.82740896940231, 61.29049837589264, 64.66007396578789, 55.26435233652592, 53.2333917170763, 50.831578597426414, 50.639605298638344, 51.2494345754385, 52.763911709189415, 50.87915204465389, 52.9634428024292, 48.46285030245781, 46.94714963436127, 44.200258031487465, 46.972076296806335, 44.99461680650711, 50.53078293800354, 56.04903683066368, 60.66701643168926, 61.841218024492264, 57.36255034804344, 60.635196939110756, 60.88075876235962, 60.63971869647503, 55.95436491072178, 59.68989126384258, 60.36401689052582, 53.37215647101402, 45.980424508452415, 42.652350291609764, 44.21570040285587, 43.58444407582283, 54.720460921525955, 57.0439488440752, 54.453430250287056, 45.411446839571, 44.141767770051956, 53.02208885550499, 58.35246562957764, 60.473158434033394, 58.504005298018456, 59.59068238735199, 55.54712176322937, 55.44632077217102, 46.53697304427624, 51.12596780061722, 52.89084009826183, 61.76831893622875, 41.87532998621464, 36.23344972729683, 59.066580310463905, 54.47749435901642, 59.74636763334274, 55.54203383624554, 58.75929839909077, 51.44971422851086, 55.49126856029034, 56.40506252646446, 58.51296901702881, 54.57374319434166, 58.00174064934254, 55.373976454138756, 55.187372267246246, 49.28026244044304, 55.07076792418957, 56.71189986169338, 58.143024668097496, 50.226358473300934, 42.49197229743004, 43.274969682097435, 43.663776218891144, 42.64958783984184, 45.574328899383545, 56.186741441488266, 57.935692593455315, 56.577744260430336, 52.8835216909647, 57.42496199905872, 59.76072706282139, 58.66396151483059, 54.22621004283428, 46.662761494517326, 43.94994646310806, 43.64451505243778, 46.99817329645157, 53.126830235123634, 50.93194641172886, 53.085754439234734, 52.18967132270336, 50.96003070473671, 49.161750599741936, 52.49213509261608, 54.07488316297531, 58.11449959874153, 63.029646053910255, 63.11292998492718, 66.73003569245338, 59.78470757603645, 5.666677728295326, 0.123709612962557, 1.858367349486798, 1.0537087521515787, 0.3776010568253696, 0.08401085724472068, 0.05781924490293022, 1.3763041980564594, 21.849973239004612, 30.453984551131725, 50.16802780330181, 62.01824672520161, 61.79712139070034, 31.895602494478226, 26.10074244439602, 46.589022651314735, 48.37744228541851, 56.92985616624355, 29.823066405951977, 0.5435218254569918, 0.03682949405629188, 0.0511790974996984, 0.04496589652262628, 0.049472016835352406, 0.02054887245321879, 0.10987439949531108, 0.10034917897428386, 0.03146514303807635, 0.09919738804455847, 0.050942244779434986, 0.019961182406404987, 0.06383563202689402, 0.04566132600302808, 0.05762375578342471, 0.017943167840712704, 0.06923186199855991, 0.027909494965570047, 0.030175106694514398, 0.057816254047793336, 0.04561476736853365, 0.05759933541412465, 0.04895049482001923, 0.030957039052736945, 0.05224303298746236, 0.042269351179129444, 0.020001319608127233, 0.06468367675552145, 0.07082664087647572, 0.04552665588562377, 0.021787210789625533, 0.051618797733681276, 0.10474803668330424, 0.010970996554533485, 0.10290065300068818, 0.052607364414143376, 0.09461415858822875, 0.10331098645110615, 28.374092057347298, 87.30713233351707, 69.06748786568642, 74.02408629655838, 59.460299983620644, 39.763053730130196, 26.615191139280796, 34.968322813510895, 33.49574223160744, 36.84673301875591, 1.1007466656155884, 0.08931768810725771, 0.17353737086523324, 1.137344401795417, 3.2351551903411746, 4.887660155072808, 3.1237520556896925, 0.36794271727558225, 25.25606296956539, 85.13813272118568, 67.84882485866547, 74.39979493618011, 64.40714433789253, 67.28415995836258, 58.126233369112015, 56.380455046892166, 54.5567163079977, 53.38414862751961, 53.15803036093712, 54.07976970076561, 53.062397092580795, 55.36894552409649, 50.66794417798519, 49.43110674619675, 49.604126662015915, 48.353461772203445, 48.434420228004456, 51.60292960703373, 58.71615171432495, 64.27070885896683, 63.99723753333092, 58.356649205088615, 61.45728662610054, 62.45135508477688, 62.089291512966156, 57.955690920352936, 61.43496282398701, 62.13938422501087, 55.51520347595215, 47.991759181022644, 45.7411627471447, 45.56361347436905, 45.63196040689945, 57.01027885079384, 59.77726377546787, 54.75063510239124, 47.57978908717632, 46.4843724668026, 55.212564915418625, 60.71509525179863, 62.01038494706154, 59.59075838327408, 61.712119951844215, 57.29852378368378, 57.62271098792553, 49.34935413300991, 53.85564252734184, 56.445849537849426, 62.222462967038155, 45.09704411029816, 38.64250525832176, 59.51057888567448, 56.831825226545334, 61.56925901770592, 58.646087273955345, 59.79144461452961, 53.04768048226833, 57.56487809121609, 59.974735379219055, 59.50097680091858, 56.88868537545204, 60.02940684556961, 56.110437735915184, 57.37175725400448, 49.994589909911156, 56.52574025094509, 59.73225899040699, 61.212005987763405, 52.11215168237686, 44.17646370828152, 44.30457763373852, 44.97730873525143, 45.405131578445435, 48.45449075102806, 58.54102671146393, 60.50225347280502, 57.70838879048824, 55.02984791994095, 61.26930691301823, 61.850120946764946, 59.91618052124977, 55.40920816361904, 49.60604555904865, 46.4451889693737, 46.7389740049839, 48.45561169087887, 56.15373261272907, 53.884182795882225, 55.367775186896324, 55.03497004508972, 53.826729878783226, 50.963302329182625, 56.14918425679207, 57.501326501369476, 61.63343757390976, 64.24880683422089, 67.72414594888687, 65.08812099695206, 60.837194100022316, 7.482290603220463, 0.1519628262030892, 0.3610598616069183, 1.6522673587314785, 1.512658812571317, 0.3645663312636316, 0.01598019094672054, 0.4291662492323667, 24.110994413495064, 39.45179343223572, 53.7087158113718, 67.98174172639847, 60.29202215373516, 38.88540342450142, 37.45360605418682, 52.21661947667599, 55.94181798398495, 62.91127860546112, 42.39653281867504, 0.8566379081457853, 0.01941615471878322, 0.05257646509562619, 0.034485925280023366, 0.011502395627758233, 0.05825982829264831, 0.04233988860505633, 0.04547427139186766, 0.03477689540886786, 0.04978626071533654, 0.03589268104406074, 0.0915419714874588, 0.0207081095140893, 0.0227345307575888, 0.03765136694710236, 0.02619573311676504, 0.10167313332203776, 0.011132427589473082, 0.06060753825295251, 0.04858590735238977, 0.14047587930690497, 0.08680459795868956, 0.16167897905688733, 0.13125393743393943, 0.20408779091667384, 0.18127448303857818, 0.2011330783716403, 0.19788220437476411, 0.14064442104427144, 0.16801358055090532, 0.1627698470838368, 0.20873746485449374, 0.19185452547390014, 0.1587953939451836, 0.1556323011755012, 0.23157229501521215, 0.3364785946905613, 0.4509566252818331, 35.19438028335571, 96.73773989081383, 79.00631055235863, 81.60794734954834, 71.61375403404236, 46.228623390197754, 55.72925738990307, 55.78381486237049, 43.94105114042759, 51.75304435193539, 1.8173897545784712, 0.22938903013709933, 0.32211925426963717, 1.8932480528019369, 4.148260205984116, 10.468822997063398, 10.703240018337965, 4.39208029769361, 24.806539490818977, 88.20126995444298, 69.00756508111954, 78.77223551273346, 66.23761251568794, 71.17572113871574, 60.88809236884117, 58.850261718034744, 56.49025395512581, 56.15541972219944, 54.558236226439476, 57.547862604260445, 56.01664736866951, 60.19812539219856, 52.637659683823586, 51.804315000772476, 50.908634662628174, 51.2692429125309, 50.57723544538021, 54.61654409766197, 61.06770873069763, 65.52897334098816, 66.45280256867409, 60.85759520530701, 63.93331736326218, 64.91452351212502, 62.8183925896883, 57.98899233341217, 61.678590551018715, 64.7132559120655, 57.326133102178574, 50.22763140499592, 46.97937950491905, 47.65611179172993, 47.8066711127758, 60.854266583919525, 61.08417324721813, 57.88172788918018, 50.27713894844055, 49.222262352705, 57.875880002975464, 63.79968613386154, 64.11319971084595, 60.88013559579849, 64.78103667497635, 61.69543504714966, 61.41231223940849, 51.299998462200165, 56.363234370946884, 58.906593695282936, 64.94643419981003, 49.265466034412384, 42.37939953804016, 61.17685407400131, 59.65787798166275, 63.760928213596344, 60.424581840634346, 61.6413601487875, 54.6173420548439, 57.899959310889244, 61.66314817965031, 63.13683070242405, 59.663695469498634, 62.70718015730381, 58.50302495062351, 60.5916702747345, 51.22337557375431, 58.540243953466415, 61.6078345477581, 64.32098776102066, 55.57744413614273, 46.91712744534016, 47.103028669953346, 47.93999455869198, 48.07153970003128, 49.77200925350189, 60.936630964279175, 62.49814957380295, 59.43125054240227, 55.21824561059475, 62.76489146053791, 64.9535246193409, 63.996257185935974, 57.68032729625702, 51.82242102921009, 49.6220389008522, 48.06116625666618, 51.0368587821722, 58.62721748650074, 57.34718017280102, 58.259621411561966, 58.94128583371639, 55.37664391100407, 54.46766048669815, 59.122182726860046, 60.298705995082855, 64.5914800465107, 67.66332641243935, 70.69270625710487, 68.53575959801674, 63.231814205646515, 8.161239121109247, 0.6859831872861832, 9.417606554925442, 5.531303817406297, 2.0340028312057257, 0.2946404943941161, 0.151011110865511, 1.8011480011045933, 32.4816070497036, 47.55999214947224, 56.57272092998028, 69.8835700750351, 70.79856097698212, 45.02575233578682, 37.68598258495331, 60.66391199827194, 64.7807402908802, 72.52815216779709, 50.20839683711529, 1.3559574773535132, 0.13352771464269608, 0.17366798885632306, 0.12621417583432049, 0.10281673094141297, 0.19381514604901895, 0.1871558401035145, 0.17179172078613192, 0.16119337698910385, 0.2610082022147253, 0.16224698920268565, 0.3194971277844161, 0.1318164705298841, 0.14410428382689133, 0.12616660416824743, 0.1510226438404061, 0.1796229521278292, 0.17809360841056332, 0.1096557776327245, 0.1584097888553515], [0.012089397332601948, 0.053284236491890624, 0.08479279887978919, 0.004572707193801762, 0.05016895658627618, 0.029230697800812777, 0.027696387260220945, 0.073710812284844, 0.10554024222074077, 0.0523883640562417, 0.05227948728133924, 0.08732359667192213, 0.04850294266361743, 0.041412296777707525, 0.03718875290360302, 0.0365033758134814, 0.11600886602536775, 0.8936042245477438, 48.44672776758671, 70.12104973196983, 65.64204007387161, 66.15419939160347, 39.540389478206635, 25.878184586763382, 47.29262709617615, 37.987500205636024, 40.16720004379749, 16.142022125422955, 0.10214883513981476, 0.05329878629709128, 0.38542587601114064, 0.2833675977308303, 1.5584489679895341, 4.169377097859979, 3.5162740806117654, 2.0354268047958612, 69.78369623422623, 72.44816645979881, 69.57494303584099, 66.59629806876183, 62.78920255601406, 57.38288305699825, 53.47010761499405, 50.81382215023041, 48.533325120806694, 50.672063156962395, 50.364051684737206, 48.16624201834202, 45.86030915379524, 47.08390809595585, 45.88407687842846, 45.00234939157963, 46.528807282447815, 43.92252333462238, 45.50782486796379, 47.02755331993103, 58.64995166659355, 61.013139858841896, 59.6212175488472, 59.162680953741074, 60.57430900633335, 58.878904581069946, 60.97109131515026, 57.417107820510864, 57.304679453372955, 60.450633242726326, 55.4155196249485, 43.71906705200672, 45.214514806866646, 43.03346984088421, 42.965191304683685, 43.78472752869129, 46.53632327914238, 44.12210762500763, 44.38552089035511, 46.01034790277481, 53.82183574140072, 57.878779247403145, 59.794552847743034, 57.22220867872238, 57.91606664657593, 54.701328948140144, 48.28274756669998, 44.718345031142235, 50.76696686446667, 51.1663444340229, 61.2952671200037, 42.99354538321495, 40.00845596194267, 62.308353558182716, 54.882453829050064, 57.66821354627609, 56.4608321338892, 58.38275380432606, 55.16513966023922, 50.88300883769989, 48.90268810093403, 57.6243980973959, 55.927865132689476, 56.96970082819462, 52.36212506890297, 56.023487001657486, 54.668734297156334, 51.511506512761116, 56.033176481723785, 56.12356223165989, 51.8378634005785, 45.859625190496445, 41.13678641617298, 43.48845362663269, 42.9064654558897, 46.31285347044468, 52.03709810972214, 57.15494468808174, 55.791767835617065, 55.36293424665928, 59.239497631788254, 57.719803377985954, 52.44657553732395, 48.49701426923275, 44.99108299612999, 45.50687111914158, 44.60513770580292, 47.518726363778114, 51.95617005228996, 56.12378641963005, 55.53632654249668, 55.360016003251076, 52.08218649029732, 54.197468385100365, 57.04392984509468, 60.484014451503754, 63.59717220067978, 62.43713244795799, 64.96229454874992, 57.420246452093124, 65.37866860628128, 36.60719387233257, 0.15553365490632132, 0.47845194989349693, 1.896244310773909, 0.7709375442937016, 0.5635448510292917, 0.2024892790359445, 0.12811821507057175, 9.646730460226536, 32.85725489258766, 33.957470655441284, 77.19523653388023, 77.55101904273033, 30.156886093318462, 16.11744124442339, 36.708656027913094, 43.36745671927929, 53.93275558948517, 53.63806240260601, 4.11638324148953, 0.18622769537614658, 0.03162841923767701, 0.057544943410903215, 0.029305586067494005, 0.04787630285136402, 0.010203551846643677, 0.044944786131964065, 0.05402726732427254, 0.010539782779233065, 0.05449300952022895, 0.034133583249058574, 0.006081985557102598, 0.06526104538352229, 0.04472750013519544, 0.04937635028909426, 0.05766486705397256, 0.01730203759507276, 0.02049860679107951, 0.011520159860083368, 0.04572332873067353, 0.04768390477693174, 0.06642568288953044, 0.020501059589150827, 0.015605929584125988, 0.05302557947288733, 0.02480352901329752, 0.027994344709441066, 0.08163257080013864, 0.06363350810715929, 0.005923400658502942, 0.07339566669543274, 0.022441065157181583, 0.0453797143563861, 0.08575430314522237, 0.020322812415543012, 0.024655769266246352, 1.329416970256716, 61.07091195881367, 79.96298521757126, 73.22411522269249, 72.81736984848976, 50.261954963207245, 30.869917832314968, 42.873753011226654, 40.040879622101784, 46.6932662576437, 22.417138405144215, 0.031257738737622276, 0.04652585383155383, 0.33093982783611864, 1.6164951282553375, 3.3637830382212996, 5.170979127287865, 1.6608005133457482, 2.696231296285987, 70.30623659491539, 75.64988985657692, 72.56570175290108, 68.4443973004818, 64.95163232088089, 59.85344968736172, 55.58541230857372, 53.69977109134197, 52.636158764362335, 51.953848376870155, 50.82151673734188, 50.08738473057747, 48.37698630988598, 48.917203322052956, 48.72337572276592, 48.63390572369099, 47.56705217063427, 46.81853033602238, 47.30651155114174, 50.10339707136154, 61.66604362428188, 62.097377479076385, 63.303922936320305, 62.0791270583868, 62.00016349554062, 61.62037007510662, 61.791311502456665, 58.450230583548546, 59.46495093405247, 63.60707446932793, 56.86302535235882, 45.53840562701225, 46.66075520217419, 44.25652541220188, 46.39989919960499, 46.75376661121845, 48.58803078532219, 45.91417506337166, 45.242580100893974, 48.1348443031311, 56.6757296025753, 61.347400322556496, 60.115548223257065, 59.0987341850996, 59.907273799180984, 56.0873843729496, 50.63812717795372, 47.24262937903404, 53.00155095756054, 54.28330957889557, 64.56699416041374, 45.35484127700329, 42.18056760728359, 63.95266592502594, 56.12519234418869, 59.82541859149933, 58.20506773889065, 59.862914979457855, 56.877411380410194, 51.8635880202055, 50.68130426108837, 58.390957564115524, 58.22610341012478, 59.50763024389744, 55.50979636609554, 59.88434202969074, 54.333007112145424, 51.37468725442886, 57.15940944850445, 57.940434738993645, 53.43085952103138, 47.20905438065529, 43.899500370025635, 44.3635580688715, 44.68589477241039, 48.27851839363575, 54.26257789134979, 61.959410682320595, 58.201009556651115, 56.152208894491196, 60.5574569106102, 62.28390946984291, 54.758337289094925, 50.95113918185234, 45.57205282151699, 48.038888052105904, 46.76238834857941, 50.225142538547516, 53.80341812968254, 58.334112614393234, 57.0700990408659, 58.97649474442005, 57.64221914112568, 56.99721895158291, 59.56654988229275, 64.5199678838253, 64.11914259195328, 65.60544803738594, 68.59897300601006, 61.546806022524834, 66.59204229712486, 42.07799971103668, 0.19120072305668145, 0.3572167834499851, 0.9980439953505993, 2.8981187380850315, 1.0056669800542295, 0.46589023957494646, 0.2648026845417917, 9.257376752793789, 37.81684376299381, 34.49494421482086, 81.45790100097656, 82.71958529949188, 35.37828281521797, 21.725396923720837, 43.12481313943863, 49.157882407307625, 59.168787226080894, 64.19752478599548, 7.4472560081630945, 0.2765522775007412, 0.06870641402201727, 0.037042594340164214, 0.046921151370042935, 0.05451175617054105, 0.029844442797184456, 0.01740741699904902, 0.03818547207629308, 0.03562429075827822, 0.030619723656855058, 0.024901846882130485, 0.04555009290925227, 0.06281848895014264, 0.07595158618642017, 0.016326840705005452, 0.01834636368585052, 0.03982322501542512, 0.050974453988601454, 0.050857242895290256, 0.14972271281294525, 0.13014939904678613, 0.1703795325011015, 0.09957826565369032, 0.12393380835419521, 0.19904440763639286, 0.129938421305269, 0.13391667424002662, 0.20538407057756558, 0.12765468447469175, 0.18107129784766585, 0.22384848212823272, 0.13427421130472794, 0.11612235524808057, 0.16302443342283368, 0.13317825214471668, 0.30414114240556955, 1.9079892430454493, 71.14990532398224, 89.04276520013809, 83.46459612250328, 84.0540736913681, 55.916553139686584, 36.394067108631134, 61.37469045817852, 51.17338165640831, 57.261004596948624, 28.018108159303665, 0.2688733348622918, 0.17427945917006582, 0.9278202010318637, 1.9465158507227898, 7.5136094726622105, 13.60390841960907, 11.35363306850195, 2.651717159897089, 75.00248059630394, 79.23582583665848, 75.65087780356407, 72.44664654135704, 68.97140622138977, 61.71050883829594, 59.2732360213995, 57.734630182385445, 54.762213081121445, 55.16222141683102, 53.686190620064735, 53.27045492827892, 51.78790748119354, 50.313430801033974, 50.975564271211624, 49.17731836438179, 51.275953352451324, 47.90907181799412, 50.58035887777805, 51.487708389759064, 64.3981084227562, 66.98220536112785, 65.06492704153061, 64.47197645902634, 66.01269498467445, 63.83310154080391, 66.41874119639397, 59.72413882613182, 60.642887726426125, 67.50311180949211, 59.431265741586685, 48.49219612777233, 50.58501362800598, 46.495802253484726, 48.6364059895277, 49.100539684295654, 50.651612654328346, 49.6219477057457, 48.860939741134644, 52.14378498494625, 58.84048104286194, 65.24629130959511, 61.48694023489952, 60.45182257890701, 61.90918117761612, 58.82308177649975, 51.76098212599754, 50.139913111925125, 54.75552164018154, 56.89475364983082, 66.86650156974792, 48.163726553320885, 45.29377855360508, 67.59787872433662, 60.23058325052261, 61.4343548566103, 60.11757351458073, 62.613499984145164, 58.69930721819401, 51.9214741140604, 51.88550904393196, 60.18828012049198, 60.2327149361372, 61.10381819307804, 58.30256290733814, 61.29037298262119, 57.52148821949959, 52.431159764528275, 60.199953094124794, 60.83175279200077, 56.66360825300217, 51.53701834380627, 46.15513913333416, 47.92403161525726, 47.66573667526245, 51.28808990120888, 56.58032052218914, 65.86527809500694, 59.219107925891876, 56.58872567117214, 64.32237088680267, 63.31235088407993, 56.463222205638885, 53.03165294229984, 47.923123463988304, 50.70454381406307, 50.52183821797371, 53.15051816403866, 57.14986436069012, 61.71216554939747, 59.892207607626915, 61.974074095487595, 57.947012186050415, 60.80328091979027, 62.4494893848896, 68.70426535606384, 66.47041082382202, 67.5584064424038, 70.91866493225098, 64.67433840036392, 70.23812144994736, 45.105411261320114, 0.405478379689157, 2.996477885171771, 7.90107230655849, 4.1341230645775795, 0.9843870531767607, 0.7041057804599404, 0.25686565262731165, 14.412201046943665, 46.96285039186478, 47.57166512310505, 80.48530519008636, 81.85218304395676, 37.16821476817131, 24.96809732168913, 50.994000881910324, 59.34245690703392, 65.5486410856247, 72.164146900177, 10.720217507332563, 0.4566159762907773, 0.2334876891109161, 0.2062972536077723, 0.19347362453117967, 0.12428824324160814, 0.08304158269311301, 0.08665928544360213, 0.1350714560248889, 0.07381785966572352, 0.11010867325239815, 0.1275375290424563, 0.1411975733935833, 0.250110030756332, 0.14751609996892512, 0.1984558251569979, 0.17034120799507946, 0.10124260603333823, 0.09015563220600598, 0.1513399268151261], [0.048933562720776536, 0.05625074547424447, 0.04633332217053976, 0.14256918104365468, 0.027334451115166303, 0.09508267641649581, 0.05036994502006564, 0.07852263064705767, 0.01605035358807072, 0.031911429832689464, 0.035356542430236004, 0.03891273598128464, 0.04095198710274417, 0.09995566259021871, 0.07062071716063656, 0.07936703143059276, 0.12016394306556322, 10.488675031810999, 73.60861659049988, 62.867824137210846, 71.30318149924278, 51.06471888720989, 38.25197361409664, 32.92095087468624, 35.117043033242226, 31.688931584358215, 27.479270473122597, 4.6823338977992535, 0.07073679647874087, 0.26956293848343194, 0.08252336323494092, 0.6351617455948144, 3.5668374923989177, 1.6634007613174617, 2.0963736344128847, 22.095662355422974, 81.90301671624184, 64.41030576825142, 72.79311954975128, 63.01864564418793, 60.804462656378746, 50.360688865184784, 51.35608345270157, 49.66873839497566, 51.183922290802, 46.877757757902145, 48.92074093222618, 46.403490006923676, 45.62641650438309, 43.73487040400505, 45.36957308650017, 44.611772149801254, 45.627795830368996, 41.80524654686451, 44.41601425409317, 46.68013036251068, 60.27061030268669, 58.698627054691315, 60.34618444740772, 56.49981804192066, 56.890007704496384, 53.88005621731281, 59.59573231637478, 58.33635449409485, 58.27801242470741, 58.59380587935448, 52.511791437864304, 42.91053123772144, 45.53991414606571, 41.77115477621555, 42.65163592994213, 44.68910180032253, 43.6878327280283, 41.882188618183136, 44.87480163574219, 48.969005942344666, 58.104152753949165, 55.91184139251709, 57.36614115536213, 54.77682709693909, 58.27919416129589, 51.532652378082275, 47.98290565609932, 43.104537427425385, 49.873463809490204, 50.046563521027565, 63.33826929330826, 42.574291080236435, 47.34618902206421, 61.905293986201286, 52.34160616993904, 57.27326653897762, 54.614959582686424, 57.483471259474754, 55.71471557021141, 58.31129103899002, 54.90380108356476, 50.3761350363493, 52.917613461613655, 56.63914896547794, 56.53515234589577, 55.255757197737694, 58.75104904174805, 50.25440476834774, 52.61319279670715, 57.58496381342411, 53.797220662236214, 44.00362238287926, 40.93513883650303, 40.7744150608778, 42.09356747567654, 41.89657464623451, 49.17284220457077, 55.910044088959694, 54.83316667377949, 55.43401323258877, 57.890562415122986, 58.51375177502632, 52.148272544145584, 45.24701066315174, 44.539929404854774, 44.43039648234844, 43.58735851943493, 49.19894680380821, 55.74305444955826, 58.02164398133755, 56.903686970472336, 53.976924419403076, 56.0385911911726, 58.499726727604866, 59.40987668931484, 65.37248253822327, 61.13582767546177, 63.44658628106117, 62.30140373110771, 62.718735337257385, 46.93991482257843, 62.30189770460129, 20.697871260344982, 0.4384806181769818, 1.7382591194473207, 1.7570675164461136, 1.2687591626308858, 0.050769098015734926, 0.018399592372588813, 0.4870057658990845, 30.755733959376812, 30.928748175501823, 19.199404567480087, 23.27603291720152, 25.124367736279964, 21.099475510418415, 33.15908409655094, 55.110836774110794, 48.144081607460976, 63.20216819643974, 18.065353520214558, 0.0374812741210917, 0.049508990632602945, 0.08536733250366524, 0.06779318646294996, 0.09344662670628168, 0.04259763278241735, 0.024269752284453716, 0.019632540861493908, 0.01850749322329648, 0.12519810145022348, 0.06670275630312972, 0.02717398208915256, 0.05867333813512232, 0.024794330092845485, 0.03634976608736906, 0.006917202263139188, 0.05923882497882005, 0.023181943761301227, 0.04067275775014423, 0.034605203254614025, 0.08305897863465361, 0.058465803958824836, 0.023855177460063715, 0.018977608524437528, 0.031483533457503654, 0.012769635050062789, 0.07074434412061237, 0.013356354738789378, 0.09367208374897018, 0.007887681877036812, 0.045087749749654904, 0.159997999726329, 0.027085558904218487, 0.047923087840899825, 0.18821771984221414, 0.11575134820304811, 14.686453230679035, 83.68347197771072, 72.10663318634033, 79.21255588531494, 63.532169088721275, 44.92901712656021, 38.32557946443558, 43.3224481344223, 32.95875884592533, 35.59471920132637, 7.707060417160392, 0.25024765462148935, 0.16804838727694005, 1.067196128424257, 2.084043533541262, 5.2766291331499815, 2.981596696190536, 1.152661854866892, 23.970591947436333, 85.35207644104958, 67.98815578222275, 75.86394757032394, 64.29171413183212, 64.18600380420685, 53.71093489229679, 53.87471750378609, 52.963043823838234, 53.07722009718418, 49.89367112517357, 52.25490242242813, 48.17586310207844, 48.63951042294502, 46.614808067679405, 48.48490811884403, 48.21975454688072, 47.04766944050789, 44.21353831887245, 47.95303925871849, 47.68189340829849, 62.62598991394043, 60.601127967238426, 62.5779414921999, 59.3269195407629, 59.37543913722038, 55.95353275537491, 61.613557040691376, 59.20637480914593, 60.066112875938416, 62.0527146756649, 55.51277920603752, 44.99998591840267, 47.25956507027149, 44.077342227101326, 44.967892840504646, 44.56899404525757, 46.819719672203064, 44.110913425683975, 47.18686357140541, 51.00082531571388, 58.17887954413891, 57.54531294107437, 58.728375658392906, 57.92288728058338, 60.10593853890896, 53.98744985461235, 49.07222740352154, 45.2023858577013, 52.808202132582664, 53.523373156785965, 64.83921155333519, 45.28382308781147, 48.26871871948242, 64.465342015028, 55.25959499180317, 59.62803058326244, 55.67759536206722, 59.86817769706249, 58.329704850912094, 60.575350150465965, 55.679620653390884, 50.51033243536949, 54.17313069105148, 58.596283346414566, 58.823438957333565, 55.92013634741306, 60.47961428761482, 50.15878289937973, 52.96622045338154, 60.533537194132805, 56.3472144305706, 47.20107480883598, 43.42805586755276, 42.68694743514061, 44.30694490671158, 43.19058761000633, 52.0076534897089, 58.2070854306221, 58.5425466299057, 56.76917038857937, 59.0775541216135, 59.7639986872673, 55.25811307132244, 48.26876811683178, 46.70214258134365, 46.80835448205471, 45.72237275540829, 51.927006617188454, 57.63933889567852, 60.35068720579147, 59.680159986019135, 58.03263299167156, 58.5728994011879, 59.73822087049484, 63.66812199354172, 65.82743972539902, 63.58392991125584, 66.26152843236923, 64.5598429441452, 63.77810329198837, 51.76303781569004, 68.36188092827797, 23.67501150816679, 0.34406467981170863, 1.3086832640692592, 1.7371664405800402, 3.828034526668489, 0.3855593141634017, 0.10547009442234412, 0.37200425402261317, 34.30570676922798, 36.595893278717995, 21.939321644604206, 22.920176312327385, 22.473622374236584, 25.991714894771576, 39.58832770586014, 60.48752546310425, 53.95313009619713, 70.53814575076103, 27.068896293640137, 0.11219980049645528, 0.06698139564832672, 0.05757315986556932, 0.03764582681469619, 0.04395778538309969, 0.06989348665229045, 0.015381389093818143, 0.019188115002179984, 0.042657345984480344, 0.07433141843648627, 0.0703206000616774, 0.028731156344292685, 0.06872703830595128, 0.0726829600171186, 0.027378957711334806, 0.05193741657421924, 0.020793445364688523, 0.005589106731349602, 0.03637148874986451, 0.11227052717003971, 0.10719097161199898, 0.20439066138351336, 0.29566406446974725, 0.09090127539820969, 0.17557990970090032, 0.09304535487899557, 0.16410520824138075, 0.11955876616411842, 0.13706241559702903, 0.1714821413042955, 0.19906092784367502, 0.34340259502641857, 0.12490165798226371, 0.168615106085781, 0.2775289141573012, 0.36420698335859925, 16.50819707661867, 93.11587303876877, 80.17740771174431, 88.03348615765572, 67.49485865235329, 52.257839664816856, 43.89910139143467, 50.60585170984268, 44.42002683877945, 43.15807655453682, 9.627112112939358, 0.4824206291232258, 0.6299986538942903, 0.9172799822408706, 5.032569654285908, 11.603813543915749, 11.361463498324156, 6.660205665975809, 25.47817625105381, 87.61674731969833, 69.60386708378792, 80.95382764935493, 68.06782990694046, 66.5419989824295, 56.72780580818653, 56.00758105516434, 56.5288370847702, 56.138514429330826, 52.58379377424717, 55.1602341234684, 51.89953789114952, 50.84805071353912, 49.014565497636795, 49.51504424214363, 50.642778128385544, 48.674438148736954, 45.04467532038689, 49.59368862211704, 51.15206480026245, 65.12583777308464, 62.72640332579613, 66.90601944923401, 61.37393809854984, 62.653143256902695, 58.246261328458786, 64.73543152213097, 61.41906447708607, 61.61608010530472, 64.05058667063713, 56.34493835270405, 47.86307528614998, 50.001345947384834, 45.11030539870262, 45.609188228845596, 47.6572023332119, 50.34829393029213, 46.16287171840668, 51.03295259177685, 54.97274458408356, 61.76894970238209, 59.0117796510458, 61.282408609986305, 62.15130038559437, 63.444135412573814, 57.0468594878912, 53.61336372792721, 48.61601248383522, 54.198874309659004, 55.72823524475098, 67.13941812515259, 49.20667938888073, 52.826741337776184, 65.47076806426048, 58.891132324934006, 62.43249669671059, 59.09975253045559, 62.73303396999836, 60.715752616524696, 61.232201904058456, 57.51092478632927, 51.19887448847294, 55.753161907196045, 60.383034870028496, 62.0684914290905, 58.44617620110512, 63.0912521481514, 50.86552977561951, 55.205174311995506, 62.52507112920284, 59.427655935287476, 47.9475561529398, 44.98480573296547, 44.48110856115818, 45.359401032328606, 46.22038923203945, 55.843509659171104, 60.990534871816635, 59.544955641031265, 59.2232459038496, 63.10324050486088, 63.201491832733154, 56.785064935684204, 49.963032603263855, 50.14592818915844, 48.460950404405594, 48.800435587763786, 53.74548263847828, 60.9416276961565, 63.72425638139248, 62.02828198671341, 60.132955089211464, 60.77976778149605, 62.93994426727295, 65.4808983206749, 69.76722791790962, 66.11123129725456, 70.02132028341293, 66.86850026249886, 66.95081144571304, 54.089994952082634, 69.17493090033531, 22.89958331733942, 0.447873892262578, 7.4617356061935425, 6.9987124018371105, 3.9815322775393724, 0.3993869503028691, 0.14065105584450066, 0.8422365027945489, 41.477730721235275, 47.13084697723389, 27.580033466219902, 29.655662588775158, 34.89425718784332, 29.23071999102831, 47.68739931285381, 69.6108815073967, 60.80387368798256, 80.81226244568825, 32.98633776605129, 0.3370083693880588, 0.12921751389512792, 0.18621212511789054, 0.10512875101994723, 0.2959745196858421, 0.11166846728883684, 0.14661338122095913, 0.12224658014019951, 0.1549494659411721, 0.1945530783268623, 0.29017246852163225, 0.12234235429787077, 0.23551755206426606, 0.20240569836460054, 0.07927326849312522, 0.14199287368683144, 0.16928186640143394, 0.08926388240070082, 0.18964859540574253], [0.08474593967548572, 0.06396465440047905, 0.06526646306156181, 0.05507357680471614, 0.020214666656102054, 0.027619328211585525, 0.03536632393661421, 0.07683889794861898, 0.0888248352566734, 0.04527882680122275, 0.03813616007391829, 0.019794497893599328, 0.02169276136555709, 0.004990689403712167, 0.02429156029393198, 0.021797584158775862, 0.058885722246486694, 32.32776090502739, 73.88290867209435, 64.92440298199654, 56.389844343066216, 31.256159506738186, 30.608689449727535, 31.444257013499737, 49.59098316729069, 41.79114930331707, 32.6635716855526, 2.611055066809058, 0.06316301616607234, 0.26462988287676126, 0.3075860138051212, 1.2044427450746298, 1.6232973570004106, 2.5582231767475605, 1.2867083307355642, 59.142401441931725, 78.87942776083946, 67.43394032120705, 66.22669190168381, 59.086054265499115, 54.557677656412125, 54.43962939083576, 53.27493488788605, 51.072652861475945, 49.98807705938816, 50.13664908707142, 49.318427592515945, 46.068173199892044, 44.20691527426243, 44.919114857912064, 45.15782564878464, 44.935522377491, 43.19983631372452, 42.96381577849388, 43.14358413219452, 44.327034428715706, 53.72265726327896, 58.26079174876213, 58.215038403868675, 53.2989078015089, 51.92758038640022, 53.127730786800385, 57.91513569653034, 58.448608070611954, 60.10000705718994, 55.78728787600994, 54.30798925459385, 44.486884251236916, 42.006981521844864, 41.23814217746258, 44.01072420179844, 43.27722676098347, 42.67482228577137, 43.14465947449207, 44.69600982964039, 53.45322132110596, 59.092863500118256, 55.564490631222725, 56.55145727097988, 55.58538191020489, 54.64230291545391, 46.61969840526581, 44.28618282079697, 40.87746553122997, 50.76632849872112, 52.15749844908714, 60.92505298554897, 47.375648841261864, 45.109572038054466, 57.963252514600754, 51.92407317459583, 51.194162741303444, 49.3369098007679, 55.48836551606655, 54.514048397541046, 54.63401556015015, 57.65772990882397, 55.57536564767361, 53.74564602971077, 55.592806711792946, 50.78638382256031, 54.31793712079525, 55.373170897364616, 55.916792526841164, 48.10582146048546, 52.47715249657631, 55.32766453921795, 45.98756432533264, 42.69784905016422, 40.98791040480137, 41.58429220318794, 40.47106593847275, 44.25814792513847, 53.30498367547989, 59.18087437748909, 56.803098767995834, 59.20604042708874, 56.67750410735607, 52.938158959150314, 44.44921687245369, 44.05972257256508, 43.03621329367161, 47.715400010347366, 50.10679788887501, 54.629622995853424, 55.655868127942085, 59.720840603113174, 57.48129777610302, 57.526321560144424, 58.3282495290041, 64.94435951113701, 59.058528542518616, 63.688690289855, 60.86056284606457, 61.37738451361656, 60.500205382704735, 66.93732976913452, 54.19426515698433, 63.38491939008236, 11.321378499269485, 0.41524533997289836, 2.6147088082507253, 0.9952282870654017, 0.3386956569738686, 0.11897278120159172, 0.10861709743039683, 9.788037277758121, 42.311744168400764, 33.045344799757004, 45.05218751728535, 35.07504768669605, 23.48746497184038, 29.90598365664482, 42.91881859302521, 45.97276411950588, 56.274927109479904, 45.621115788817406, 1.9453496695496142, 0.2084941740031354, 0.0527253658947302, 0.01444471801733016, 0.01680289689829806, 0.03477190817648079, 0.043645675177685916, 0.038129439926706254, 0.022269526998570655, 0.05164552618225571, 0.022003895646776073, 0.05631599880871363, 0.02858669173292583, 0.014848816499579698, 0.04126789339352399, 0.038089297158876434, 0.066888115106849, 0.0353512100991793, 0.04503981443122029, 0.014929390545148635, 0.017438156755815726, 0.026608810658217408, 0.015769352357892785, 0.08038215586566366, 0.012662379867833806, 0.13215652259532362, 0.05308073217747733, 0.03154074933263473, 0.050268879349459894, 0.05593129913904704, 0.003386784892427386, 0.036085895480937324, 0.05990958175971173, 0.061372874333756045, 0.023849164208513685, 0.07354102373938076, 39.674841463565826, 85.13295739889145, 69.64956343173981, 67.41776078939438, 36.47872656583786, 42.18163534998894, 35.89442431926727, 46.14585243165493, 42.23731756210327, 34.02093484997749, 1.8236350757069886, 0.13718400907237083, 0.1886645966442302, 1.1430262844078243, 2.9203817434608936, 4.884578520432115, 2.3953373171389103, 1.739961071871221, 63.19796182215214, 78.87352287769318, 68.86871293187141, 69.92485865950584, 62.874743565917015, 55.75264893472195, 56.832794174551964, 57.1585088968277, 53.43705698847771, 53.94655264914036, 53.369166031479836, 50.343050211668015, 50.146258771419525, 46.06438860297203, 46.957576274871826, 48.04220147430897, 47.17060424387455, 47.452184334397316, 45.95572203397751, 45.80574028193951, 46.62470653653145, 55.58381259441376, 60.06654605269432, 61.73527970910072, 55.06222978234291, 53.48119542002678, 55.179867669939995, 59.0547439455986, 58.86451855301857, 59.2228127270937, 60.25652065873146, 56.88424341380596, 47.0003467798233, 43.78478452563286, 44.81940060853958, 45.99296763539314, 44.64762322604656, 43.64478103816509, 44.247079119086266, 48.242120146751404, 54.654739648103714, 61.26936390995979, 57.07623191177845, 59.02221009135246, 57.23718747496605, 57.51007743179798, 49.67251539230347, 46.76055684685707, 43.46403993666172, 55.52389360964298, 55.122996121644974, 63.24023075401783, 49.36413154006004, 48.75177159905434, 60.264412835240364, 56.288423985242844, 54.82133790850639, 52.60932460427284, 56.80077709257603, 56.3109377771616, 58.12813326716423, 59.381040036678314, 59.2946782708168, 54.992397129535675, 57.660420164465904, 53.90856608748436, 58.75353030860424, 58.526454493403435, 57.15622141957283, 48.99470396339893, 55.298729091882706, 58.65075342357159, 45.94642013311386, 44.342864379286766, 43.21809433400631, 44.10149373114109, 42.95664556324482, 44.36376325786114, 56.77841529250145, 62.47231476008892, 58.87305669486523, 60.70269271731377, 60.193299651145935, 53.847138583660126, 46.41199015080929, 44.75088268518448, 45.51558405160904, 48.9950155466795, 52.37893156707287, 56.52765154838562, 57.710919454693794, 63.04139502346516, 60.45623034238815, 60.61127342283726, 61.25787332653999, 65.93777820467949, 62.66605116426945, 67.87525624036789, 61.097012758255005, 62.860087752342224, 62.51478508114815, 67.36362889409065, 57.92655028402805, 68.56487363576889, 13.83165679872036, 0.2936541207600385, 1.1749280663207173, 3.697309666313231, 2.2442821227014065, 0.2497419255087152, 0.16157218400621787, 10.344114638864994, 51.6298321634531, 29.170132242143154, 32.93085314333439, 35.760815888643265, 28.685418851673603, 37.20500059425831, 49.341716542840004, 52.60110184550285, 62.10198663175106, 56.97970189154148, 3.8184158178046346, 0.1426156988600269, 0.0655022136925254, 0.02384435138083063, 0.03522482234984636, 0.022801700688432902, 0.027416940829425585, 0.06080725019273814, 0.03730546675797086, 0.08527526908437721, 0.045058831965434365, 0.07763567511574365, 0.033929845158127137, 0.03296532406238839, 0.09891808076645248, 0.025722177961142734, 0.026666104458854534, 0.04487137288379017, 0.048088865078170784, 0.14563306351192296, 0.2955695445416495, 0.0949813361512497, 0.14928837830666453, 0.1553381435223855, 0.07858767246943898, 0.20230209454894066, 0.16709451971109957, 0.20640747738070786, 0.13267650094348937, 0.16845610836753622, 0.1778281421866268, 0.06972967981710099, 0.15981253702193499, 0.10910095545114018, 0.10243006458040327, 0.16555750218685716, 45.49748942255974, 93.88308987021446, 81.51113614439964, 74.57295164465904, 45.49772880971432, 42.06085503101349, 42.29973681271076, 64.24696773290634, 58.110034838318825, 49.36163507401943, 4.194807233288884, 0.294910398661159, 0.3438902157358825, 1.1070536146871746, 8.243369814008474, 11.325564924627542, 9.97640646994114, 2.2180041577667, 66.47728085517883, 83.36700975894928, 72.46886774897575, 72.44513422250748, 64.60916429758072, 58.526427894830704, 60.54655149579048, 60.815884843468666, 57.59117268025875, 56.19564816355705, 56.71823412179947, 54.57448035478592, 52.525014728307724, 47.537934333086014, 50.27971141040325, 50.37710018455982, 50.70129878818989, 48.91271196305752, 47.39082142710686, 48.79605442285538, 49.08855892717838, 58.260597959160805, 62.340655624866486, 65.17166331410408, 60.211360082030296, 56.920998841524124, 57.124599516391754, 61.02625675499439, 60.349847450852394, 62.77046196162701, 63.25618989765644, 58.83260026574135, 49.84540991485119, 44.61342506110668, 46.77015893161297, 49.2006529122591, 47.38575629889965, 46.754009798169136, 48.1374167650938, 49.47466000914574, 57.60422497987747, 64.63318660855293, 60.060196593403816, 61.15958400070667, 60.73030203580856, 61.95764757692814, 53.57185855507851, 49.21528212726116, 45.000890269875526, 57.39087022840977, 57.868455201387405, 66.43304362893105, 52.94288590550423, 53.35960574448109, 62.34868459403515, 58.18508841097355, 56.0697191208601, 54.172283336520195, 59.76120583713055, 60.49083508551121, 58.97432506084442, 63.275496661663055, 59.85230214893818, 57.8310652077198, 59.55785594880581, 55.29140308499336, 60.36214359104633, 61.397075057029724, 58.77915993332863, 49.59732122719288, 58.43905158340931, 60.46077109873295, 49.09450180828571, 46.79323509335518, 45.541760846972466, 46.6035682708025, 45.94409465789795, 48.57761554419994, 58.9197713881731, 65.51562085747719, 60.70441782474518, 61.32618606090546, 62.94528678059578, 56.76594816148281, 49.60808604955673, 47.912560030817986, 48.19322817027569, 51.79546907544136, 54.920022413134575, 58.444698080420494, 62.42426633834839, 65.27369543910027, 62.04947344958782, 63.56569468975067, 62.978949174284935, 68.59783306717873, 64.47445392608643, 68.6989152431488, 63.24425473809242, 64.72351536154747, 65.46158015727997, 70.2270944416523, 61.321622505784035, 71.42600610852242, 13.090402074158192, 0.6327092740684748, 10.743947234004736, 6.677223527804017, 2.0865585235878825, 0.4159519833046943, 0.19659762096125633, 14.053687434643507, 60.03674045205116, 46.486146971583366, 63.20034809410572, 48.43868739902973, 31.97839245200157, 42.586587220430374, 55.72071924805641, 61.11421823501587, 71.3039642572403, 66.91269189119339, 5.728509435430169, 0.3863208764232695, 0.3210207272786647, 0.14908093318808824, 0.11845200133393519, 0.2246739433030598, 0.13715300214244053, 0.1371375803137198, 0.15944615355692804, 0.1264333468861878, 0.19370683701708913, 0.12089754120097496, 0.09812666190555319, 0.06637373255216517, 0.12792841822374612, 0.13283131294883788, 0.13412293192232028, 0.08510567349730991, 0.14597126020817086], [0.032466192642459646, 0.022890079344506375, 0.05473242636071518, 0.09645179045037366, 0.03714536323968787, 0.05369250677176751, 0.03920781018678099, 0.07104189338861033, 0.038929742295295, 0.03662234950752463, 0.038554364000447094, 0.011359321615600493, 0.04500705974351149, 0.07996142492629588, 0.06127318163635209, 0.11420799273764715, 1.244357821997255, 57.82425217330456, 66.96170926094055, 65.46480238437653, 52.22106143832207, 73.31641986966133, 19.90656942129135, 40.980994775891304, 46.128217577934265, 40.64550317823887, 29.867233335971832, 0.1283858483657241, 0.05781835803645663, 0.28549025882966816, 1.5018353308551013, 2.2785854944959283, 1.739237210713327, 3.1501302402466536, 10.487575940787792, 81.84073805809021, 64.22997504472733, 67.29884997010231, 58.85477967560291, 52.18857318162918, 50.45718088746071, 52.720856219530106, 47.3430959880352, 51.88710875809193, 50.17663054168224, 49.80165146291256, 48.06616298854351, 46.18423417210579, 46.30859009921551, 43.96752052009106, 45.53507700562477, 45.928055718541145, 44.732837453484535, 43.957751244306564, 43.9515233784914, 44.12498787045479, 48.58712263405323, 51.36566273868084, 51.094201505184174, 49.05539810657501, 48.45184609293938, 52.96723499894142, 58.236716240644455, 59.38636735081673, 57.70722605288029, 56.96395933628082, 56.2106953561306, 47.53694258630276, 44.12393532693386, 42.93957307934761, 44.078523963689804, 42.22642734646797, 43.24662320315838, 42.42938965559006, 47.78397113084793, 53.0844397097826, 59.46826435625553, 53.34654204547405, 54.329184517264366, 55.408216416835785, 53.288405165076256, 44.132583662867546, 41.92708320915699, 41.37817986309528, 49.54561360180378, 52.31810823082924, 62.21068359911442, 43.01800087094307, 43.25023680925369, 60.84382474422455, 51.618060395121574, 49.24059636890888, 46.11437492072582, 49.14891108870506, 46.98051944375038, 55.325346663594246, 52.17780835926533, 56.372574269771576, 57.20794424414635, 57.39811643958092, 52.90014199912548, 52.3239067196846, 55.26968725025654, 56.654294952750206, 51.18155121803284, 54.36962194740772, 54.960866421461105, 47.510982379317284, 41.004002541303635, 42.39524848759174, 41.16629183292389, 41.3221100717783, 41.482548862695694, 48.54289300739765, 56.465992256999016, 55.360848158597946, 59.24106314778328, 57.400001138448715, 55.23905709385872, 45.92874348163605, 42.87717282772064, 45.173978582024574, 43.510074466466904, 51.558369398117065, 55.59966914355755, 54.82798375189304, 56.49687319993973, 60.40727376937866, 62.807418778538704, 59.7605636715889, 59.93846632540226, 63.86742129921913, 60.493988916277885, 55.779281705617905, 61.574445739388466, 61.87442064285278, 63.09861235320568, 63.466747999191284, 57.872691974043846, 55.86117871105671, 8.514194581657648, 1.445626609493047, 6.207935409620404, 0.8397922245785594, 0.1403967069927603, 0.04533744904620107, 0.7977930188644677, 36.69600270688534, 44.02970038354397, 31.622843630611897, 30.68344283849001, 19.498112238943577, 22.581525184214115, 38.587248623371124, 48.290005177259445, 46.918882951140404, 56.37690603733063, 15.72578676044941, 0.16769040492363274, 0.029120548242644873, 0.04067366317030974, 0.06917767779668793, 0.0573650356818689, 0.026949812672683038, 0.05189379313378595, 0.04285303919459693, 0.07156653984566219, 0.02528476354200393, 0.021173872119106818, 0.03303409517684486, 0.03426418639719486, 0.04942116858728696, 0.017663333637756296, 0.07627592698554508, 0.05188981151150074, 0.09163680311758071, 0.08131997077725828, 0.018823084101313725, 0.01743656670441851, 0.0818098773015663, 0.050447636749595404, 0.07320700533455238, 0.04632306197891012, 0.07783408087561838, 0.06675814278423786, 0.06669279668130912, 0.02681585872778669, 0.03416155850572977, 0.00906425497305463, 0.0229734225285938, 0.02559481428761501, 0.056287199768121354, 2.5665815407410264, 72.95292377471924, 74.5621146261692, 74.12836790084839, 57.21817709505558, 75.10545507073402, 24.041328951716423, 36.05127230286598, 45.95565743744373, 47.07708366215229, 32.6840677857399, 0.07870392990298569, 0.03146424132864922, 0.8338296320289373, 1.4923958061262965, 2.198255192488432, 2.8934825118631124, 2.26118266582489, 12.681689355522394, 82.62991011142731, 67.17183038592339, 71.72127306461334, 62.0700341463089, 55.36214388906956, 53.584223091602325, 56.32874742150307, 51.27184957265854, 54.38875392079353, 52.00567379593849, 53.164630606770515, 50.21127708256245, 49.51256677508354, 47.99430504441261, 46.01855926215649, 47.11414687335491, 47.342214435338974, 47.845828011631966, 45.6306266784668, 45.47167740762234, 46.85834459960461, 51.56896322965622, 54.4323755800724, 54.561219066381454, 50.59342257678509, 52.52752639353275, 55.07093891501427, 60.15801854431629, 60.47994866967201, 61.32644824683666, 59.789381325244904, 58.51728938519955, 51.313487738370895, 44.714264050126076, 45.00582240521908, 46.28685526549816, 44.09675158560276, 44.38395917415619, 44.673214852809906, 50.289978459477425, 56.05056434869766, 61.175235360860825, 55.4577961564064, 58.56658793985844, 59.0319299697876, 54.66236583888531, 46.89510762691498, 44.805709943175316, 43.27594242990017, 53.77274617552757, 54.95540611445904, 63.20377551019192, 45.66523902118206, 45.69216437637806, 64.21884924173355, 53.67303192615509, 52.984919250011444, 48.7237861007452, 51.832672879099846, 50.555390417575836, 57.6425801217556, 55.68362183868885, 58.771396949887276, 59.72221992909908, 60.66446676850319, 53.36829587817192, 53.969985991716385, 56.8763018399477, 59.07121226191521, 51.8645341694355, 55.09885221719742, 57.15373635292053, 49.223269298672676, 42.917367070913315, 45.46947732567787, 42.565688341856, 43.4778293967247, 43.480603247880936, 50.33691354095936, 59.503313675522804, 57.592248022556305, 60.51903337240219, 59.60905820131302, 57.1325258910656, 48.093453124165535, 45.27769401669502, 47.42456741631031, 47.054474875330925, 53.366122394800186, 57.533567771315575, 57.81936563551426, 59.5402666926384, 63.463464975357056, 63.077485486865044, 61.31728693842888, 62.422016859054565, 64.26567792892456, 59.6365687251091, 57.86036163568497, 62.6937060803175, 65.05492597818375, 64.2822602391243, 67.81902685761452, 60.06159111857414, 63.48940998315811, 9.186467807739973, 1.391625094693154, 3.055397286079824, 1.6321974294260144, 1.087398931849748, 0.10246827776427381, 0.5649176461156458, 38.85342814028263, 50.75315460562706, 32.72925116121769, 25.360411070287228, 19.857662245631218, 31.280643492937088, 44.35736820101738, 55.347488075494766, 52.759427949786186, 65.24297788739204, 24.35437325388193, 0.08103759100777097, 0.0063001788294059224, 0.041257533011958, 0.05524641186639201, 0.03696024934470188, 0.015431507254106691, 0.018305799749214202, 0.008529239785275422, 0.05922700998780783, 0.023753879868309014, 0.026019905344583094, 0.09984610675019212, 0.026345945661887527, 0.046218203933676705, 0.00691805387759814, 0.053292615339159966, 0.021460443167597987, 0.019806728487310465, 0.19054407079238445, 0.13590278016636148, 0.1292520682909526, 0.20093905128305778, 0.12083089633961208, 0.2102935704169795, 0.09499742591287941, 0.12674295605393127, 0.17437322210753337, 0.13827685121214017, 0.19960833596996963, 0.10167579021072015, 0.15691998676629737, 0.1895724213682115, 0.14105848007602617, 0.16456915443995968, 3.704298441298306, 87.00498774647713, 82.71763980388641, 84.99358087778091, 62.84088358283043, 86.48614078760147, 28.09804257005453, 54.659371599555016, 60.1174671202898, 57.73791320621967, 38.570407927036285, 0.4237517178989947, 0.2968033205252141, 0.9605980734340847, 5.636167740449309, 6.163575639948249, 9.49748681858182, 6.778764054179192, 14.667914975434542, 86.5780882537365, 68.58364462852478, 72.68033400177956, 63.78006398677826, 56.35670632123947, 56.26777209341526, 57.84507505595684, 52.41056486964226, 58.40263053774834, 54.103681817650795, 55.81845000386238, 53.99505324661732, 51.455493718385696, 49.4308065623045, 49.15928453207016, 49.860301315784454, 50.18544226884842, 50.06739780306816, 48.36778700351715, 48.0548319965601, 49.616457000374794, 52.978634387254715, 56.483106538653374, 57.744122073054314, 54.352507665753365, 56.30549266934395, 57.88196347653866, 63.7159538269043, 64.97048690915108, 64.56904605031013, 62.904902547597885, 61.38732858002186, 52.63573698699474, 47.080784663558006, 48.15958857536316, 48.21488320827484, 45.63674435019493, 47.771215215325356, 47.23768204450607, 53.071915581822395, 58.249365761876106, 63.30782152712345, 57.19969108700752, 58.66306856274605, 59.8981086909771, 58.26154790818691, 48.97347450256348, 46.32832244038582, 45.53875520825386, 55.73892027139664, 58.207526206970215, 65.15574216842651, 50.218196511268616, 49.24615167081356, 66.11330598592758, 56.156384870409966, 55.66569820046425, 51.289503425359726, 53.02240043878555, 53.43494430184364, 62.064817026257515, 57.18709856271744, 61.142443120479584, 62.37109199166298, 63.52097108960152, 57.45532236993313, 58.167138174176216, 60.627528950572014, 60.754134356975555, 54.08142641186714, 56.52791753411293, 60.03493554890156, 53.212162256240845, 45.422508046031, 47.1699582785368, 45.50144121050835, 45.53440824151039, 45.99315382540226, 52.900548577308655, 63.10471102595329, 59.5729411393404, 64.89258348941803, 62.14605666697025, 60.485576167702675, 50.115336030721664, 46.8022596091032, 51.27622313797474, 49.9147941917181, 56.7571934312582, 60.703144893050194, 60.022635608911514, 63.3052034676075, 64.92926672101021, 65.5464980006218, 66.0137665271759, 64.13127914071083, 66.9002665579319, 59.69127058982849, 59.85468082129955, 66.24501451849937, 68.37210237979889, 68.79578724503517, 67.97592803835869, 63.02990823984146, 66.46461993455887, 8.72764527797699, 2.729219226166606, 22.440410256385803, 2.74206823669374, 0.9352014237083495, 0.21376152260927483, 1.1736823269166052, 47.85674102604389, 61.378767639398575, 47.62344494462013, 42.723577469587326, 26.519827656447887, 34.342249408364296, 50.77675133943558, 63.51028986275196, 60.06447896361351, 73.93773972988129, 29.91446290165186, 0.3633265587268397, 0.10401774110505357, 0.1075766806025058, 0.18803034239681438, 0.19459416362224147, 0.10810308594955131, 0.11725134740117937, 0.17398720141500235, 0.0836271520529408, 0.10708263289416209, 0.1602347448351793, 0.12106243157177232, 0.17135731206508353, 0.19516877888236195, 0.16025828575948253, 0.19696106552146375, 0.13214160542702302, 0.12657552753807977], [0.05415733983682003, 0.06257432236452587, 0.055472618478233926, 0.057488759121042676, 0.043456186322146095, 0.04336097619670909, 0.05786833426100202, 0.08644507935969159, 0.04022114233521279, 0.02039293609414017, 0.05143310125276912, 0.1378900438430719, 0.04554038561764173, 0.005479939591168659, 0.1981230461387895, 0.14308972342405468, 20.87621469050646, 66.93032294511795, 61.991697549819946, 66.5275065600872, 56.484299674630165, 33.14985439181328, 36.1124300211668, 60.38890175521374, 33.99852365255356, 51.17339305579662, 10.742034986615181, 0.3071954956976697, 0.09125873824814335, 0.7508001092355698, 0.8155460224952549, 0.5974776239600033, 1.8058288749307394, 0.8118772006127983, 30.90880874544382, 83.12706023454666, 63.68612542748451, 66.58324956893921, 55.225788205862045, 55.903253853321075, 47.90668174624443, 48.586628660559654, 47.17448763549328, 48.320969715714455, 48.63873906433582, 48.73620003461838, 46.448414996266365, 46.02776616811752, 44.445432275533676, 45.25462545454502, 44.84965838491917, 45.45064553618431, 45.0957939773798, 47.36433304846287, 45.62004044651985, 43.59689600765705, 44.633639976382256, 45.932436883449554, 45.411340445280075, 45.422667637467384, 49.42867107689381, 54.543375223875046, 55.99362440407276, 59.5051945745945, 60.779422000050545, 57.40309797227383, 54.47917766869068, 52.47720569372177, 45.58579668402672, 42.4528343975544, 42.64877088367939, 42.00120963156223, 42.92750872671604, 43.265253603458405, 47.00466714799404, 51.96361765265465, 57.92465798556805, 53.54294590651989, 56.040901467204094, 54.318035915493965, 50.692969635128975, 39.52354118227959, 42.90884792804718, 42.67156206071377, 55.13951763510704, 50.17416447401047, 61.115954741835594, 37.94811151921749, 43.79524536430836, 60.84634020924568, 48.93835298717022, 49.860593900084496, 42.34472259879112, 45.7445065677166, 41.80845357477665, 48.721852004528046, 55.06028428673744, 54.81536462903023, 55.26058293879032, 55.200971737504005, 46.32405906915665, 48.89240205287933, 51.52775064110756, 56.031512171030045, 54.52864721417427, 55.5186764895916, 55.47422267496586, 45.202936828136444, 42.479569762945175, 42.53814361989498, 41.221065893769264, 41.68479301035404, 42.378441989421844, 46.93939425051212, 54.69770394265652, 57.99828663468361, 57.6514108479023, 56.782116293907166, 54.93550658226013, 46.143781542778015, 40.41906952857971, 43.89519140124321, 43.13156917691231, 52.093965858221054, 53.99180442094803, 58.22872146964073, 56.976430267095566, 58.633962124586105, 59.91066321730614, 62.72499740123749, 60.068392753601074, 59.06249172985554, 55.511779859662056, 65.72847783565521, 61.12198881804943, 58.742704689502716, 58.904560804367065, 64.33338269591331, 63.62929567694664, 59.36720497906208, 52.1663823723793, 3.7972849141806364, 4.476109463721514, 4.877940276637673, 0.16523885366041213, 0.08455794624751434, 0.27413109492044896, 11.657197829335928, 49.86882045865059, 21.10791865736246, 45.055975914001465, 45.18602013587952, 16.428851634263992, 21.344364769756794, 39.75280188024044, 48.95105950534344, 57.69136570394039, 35.304281786084175, 1.0118437861092389, 0.09008721361169592, 0.039181489919428714, 0.03342353717016522, 0.02467651414917782, 0.07352377622737549, 0.0912566676561255, 0.06454309914261103, 0.018574549976619892, 0.07141850364860147, 0.01694212194706779, 0.042569086072035134, 0.017534665639686864, 0.08620503169368021, 0.07608414860442281, 0.028522306711238343, 0.019625607346824836, 0.048889724057517014, 0.0365212133328896, 0.009907049006869784, 0.06795484106987715, 0.013793033504043706, 0.027704719723260496, 0.049817549661383964, 0.032310041060554795, 0.012425702479959, 0.037868734580115415, 0.06170266249682754, 0.06817681743996218, 0.027794489906227682, 0.08217233480536379, 0.04542708193184808, 0.21351211646106094, 0.1659812091384083, 27.579395100474358, 80.64807325601578, 67.9909448325634, 74.06314060091972, 60.823207050561905, 50.08713014423847, 33.73687729239464, 48.21951895952225, 34.13183189928532, 59.04827669262886, 12.41645123809576, 0.499925339827314, 0.07354824483627453, 1.590744978748262, 2.056303359568119, 4.184156404808164, 3.8084575021639466, 1.1488880636170506, 34.60632763803005, 84.4402925670147, 66.98171138763428, 68.39248448610306, 58.021434992551804, 57.76935271918774, 52.76327334344387, 52.14034616947174, 49.59454357624054, 51.42766021192074, 51.3064581155777, 51.67495854198933, 49.635984152555466, 47.64705307781696, 46.9077305495739, 48.21610674262047, 47.36335650086403, 45.55321343243122, 46.748948469758034, 49.94543194770813, 49.620427787303925, 45.56753106415272, 46.15513913333416, 48.07452633976936, 47.56485588848591, 48.731043711304665, 50.733205676078796, 55.496352687478065, 59.5192614197731, 61.57741338014603, 60.22961050271988, 61.19241043925285, 57.631290927529335, 55.31743548810482, 48.84533017873764, 44.69855569303036, 42.874372377991676, 44.44903828203678, 44.0226099640131, 44.675084352493286, 47.63872392475605, 54.09237362444401, 61.025941371917725, 57.111676409840584, 58.76092471182346, 56.72002762556076, 52.501159608364105, 43.85377362370491, 45.29391534626484, 45.28473883867264, 57.68338233232498, 54.34525765478611, 64.9711100757122, 40.960810258984566, 45.23545928299427, 62.718161568045616, 50.970958918333054, 50.13135977089405, 43.0883426964283, 47.64876298606396, 44.989080503582954, 50.8643214404583, 58.31850305199623, 56.994608491659164, 57.44918569922447, 56.125788912177086, 52.177283987402916, 50.324047431349754, 55.2752273529768, 58.45800116658211, 53.94081495702267, 57.55635894834995, 57.77945637702942, 48.53276275098324, 44.608667716383934, 45.68049140274525, 42.27748900651932, 44.885064885020256, 43.76853659749031, 47.997196689248085, 56.824544817209244, 60.16202352941036, 59.62280586361885, 58.96569952368736, 56.9890645891428, 48.53430546820164, 42.57389210164547, 45.47030948102474, 47.07814760506153, 54.744882211089134, 57.71951839327812, 59.05373699963093, 59.39598463475704, 60.82339324057102, 61.79550267755985, 64.156464189291, 61.78034529089928, 59.511897414922714, 58.13360117375851, 68.68274331092834, 62.99239285290241, 62.33022898435593, 61.69344015419483, 66.57670632004738, 65.09576618671417, 62.60065287351608, 60.043834671378136, 4.016830483451486, 2.6607559248805046, 5.390938874334097, 1.8476355378516018, 0.5022812727838755, 0.2720006264280528, 11.563765592873096, 57.10822619497776, 27.86909345537424, 35.30197910964489, 34.640579000115395, 22.7299053221941, 26.524187922477722, 45.32567024230957, 53.44753682613373, 64.97345075011253, 44.68061305582523, 1.8217115476727486, 0.11913335969438776, 0.06214718297997024, 0.034608335117809474, 0.05302710458636284, 0.02366854030697141, 0.026865026011364534, 0.056397423541056924, 0.008129632224154193, 0.03492062343866564, 0.013677750139322598, 0.03370982805790845, 0.042149750370299444, 0.034931366026285104, 0.054015793721191585, 0.07822804996976629, 0.02313008804776473, 0.07333811314310879, 0.20396551466546953, 0.17264812951907516, 0.2163470908999443, 0.08307749521918595, 0.11311912850942463, 0.09123484109295532, 0.18962725123856217, 0.09990945647587068, 0.22381916729500517, 0.1451941128470935, 0.17751991341356188, 0.20693009777460247, 0.1922996062785387, 0.07590521679958329, 0.421473651076667, 0.2765419764909893, 33.77726532518864, 90.43991222977638, 77.37544566392899, 83.3703687787056, 70.60898914933205, 47.46829926967621, 47.65143424272537, 75.86305841803551, 47.94222503900528, 68.4635178744793, 14.162899274379015, 0.534989977022633, 0.17704424128169194, 2.333992696367204, 6.113837258890271, 5.57396175339818, 12.719114497303963, 3.4153175354003906, 37.981378734111786, 88.36997330188751, 68.71058061718941, 71.57311141490936, 59.72451500594616, 61.89436577260494, 54.72490668296814, 55.66494584083557, 54.11107622087002, 55.45143149793148, 52.85355269908905, 55.307457223534584, 51.89453735947609, 50.7276351749897, 47.0667178183794, 50.476704239845276, 48.98736275732517, 50.244057923555374, 48.70847672224045, 52.60708652436733, 52.25023627281189, 48.79817470908165, 47.7805133163929, 50.64704529941082, 48.54570485651493, 50.41259787976742, 54.37310256063938, 59.82122361660004, 61.80858537554741, 64.05586838722229, 62.412403374910355, 61.83728523552418, 59.9211772531271, 57.57716663181782, 50.417499616742134, 46.98261693120003, 46.30259782075882, 46.01223260164261, 47.255263701081276, 49.6274384111166, 49.49175149202347, 56.36301778256893, 63.47731523215771, 58.55603590607643, 60.41524574160576, 59.19310972094536, 55.162966176867485, 45.36275625228882, 47.71009549498558, 45.8528995513916, 59.57772508263588, 56.16313710808754, 66.33932545781136, 45.3870065510273, 49.15916293859482, 66.39126107096672, 53.7539029866457, 53.4198135137558, 47.02314555644989, 52.4398422986269, 47.52229817211628, 53.76758985221386, 59.67435769736767, 58.71875077486038, 59.930178970098495, 60.00570371747017, 53.84191006422043, 53.932812586426735, 56.73184119164944, 61.22412733733654, 55.291577875614166, 60.42737849056721, 60.050583109259605, 49.15619149804115, 47.4866446852684, 47.1777630597353, 44.24756549298763, 46.693631038069725, 45.290362536907196, 52.384657859802246, 59.29063908755779, 64.76662024855614, 62.03416407108307, 61.60312660038471, 60.076649710536, 50.58853603899479, 45.02867437899113, 48.829393833875656, 50.31417176127434, 58.16184885799885, 61.18367850780487, 63.50986808538437, 62.71448716521263, 66.02641224861145, 63.926318138837814, 65.78355208039284, 63.548675402998924, 60.24433471262455, 59.8071263730526, 70.97079813480377, 65.49056500196457, 65.94863802194595, 64.95431497693062, 72.4406124651432, 67.0302651822567, 64.82552468776703, 60.533161014318466, 3.7292581144720316, 10.276682507246733, 15.969612076878548, 1.1825121031142771, 0.33455978671554476, 0.39324639074038714, 14.82665240764618, 64.66284021735191, 37.02565401792526, 62.33415797352791, 57.29310527443886, 26.269894167780876, 31.49434022605419, 55.84449000656605, 61.073294430971146, 71.27766966819763, 51.705793887376785, 2.253265790641308, 0.2087249225587584, 0.12894139043055475, 0.1797713222913444, 0.1486567364190705, 0.19023023138288409, 0.18723709043115377, 0.16919132438488305, 0.13567148242145777, 0.12204404061776586, 0.14618943678215146, 0.19864283152855933, 0.14953901642002165, 0.1710437546717003, 0.212312865187414, 0.12781034252839163, 0.12452344468329102, 0.1857742283027619], [0.051021791878156364, 0.030801954308117274, 0.011946943013754208, 0.03738640167284757, 0.02730255546339322, 0.06878726358991116, 0.08585749877966009, 0.021399356992333196, 0.04365444736322388, 0.01761970834195381, 0.034747343088383786, 0.04515647262451239, 0.005643696795232245, 0.05838929966557771, 0.031786518957233056, 0.3148026281269267, 38.06506544351578, 68.52596372365952, 63.88808459043503, 62.48436011373997, 38.348815217614174, 15.804281998425722, 27.23445151001215, 57.16736242175102, 45.88875062763691, 54.4067345559597, 2.4087097495794296, 0.06325683105387725, 0.010803124605445191, 0.46922916197218, 0.5288277764339, 1.2081653578206897, 4.166992725804448, 0.7251378893852234, 57.654845863580704, 74.33047145605087, 63.69866095483303, 66.79843202233315, 60.77408328652382, 55.69405607879162, 52.39450693130493, 51.86610348522663, 49.14468191564083, 47.251558899879456, 47.5237762928009, 47.162658870220184, 49.225207194685936, 44.51149173080921, 45.5625419318676, 45.56362107396126, 46.95702150464058, 45.80978326499462, 46.78596988320351, 46.80941842496395, 49.101276844739914, 43.4892325848341, 43.3748435229063, 43.617171719670296, 45.18031284213066, 44.05017368495464, 50.061485320329666, 52.927568927407265, 56.70861303806305, 57.079366743564606, 59.99276541173458, 57.140885442495346, 59.13642056286335, 53.65845590829849, 50.195823311805725, 43.55941861867905, 41.6820153594017, 39.9558287858963, 43.73852960765362, 42.432243302464485, 47.252030074596405, 53.83215218782425, 58.38382914662361, 53.81267063319683, 58.59404906630516, 51.56572200357914, 43.99930201470852, 38.53239856660366, 43.56199108064175, 47.817040756344795, 58.097404316067696, 49.94702406227589, 62.845321744680405, 35.320609509944916, 39.35637295246124, 59.871498718857765, 50.11049509048462, 49.40151393413544, 40.637371614575386, 43.77937361598015, 39.94824439287186, 43.381481766700745, 51.389411464333534, 55.54158166050911, 54.21569600701332, 51.41960084438324, 46.459597796201706, 46.20260238647461, 50.9489618986845, 54.04754363000393, 53.59058775007725, 52.154481410980225, 55.49889475107193, 45.22265776991844, 41.695223450660706, 41.694486290216446, 40.70004165172577, 40.955243557691574, 44.37691055238247, 44.51178051531315, 53.73929277062416, 55.41386291384697, 58.957237377762794, 55.93118615448475, 57.61186636984348, 47.03097693622112, 43.03959511220455, 42.27117754518986, 44.51901912689209, 50.26173457503319, 57.74431586265564, 55.919118002057076, 59.186083897948265, 58.260400369763374, 61.06577843427658, 58.223983123898506, 56.306545212864876, 55.25497063994408, 64.69948545098305, 59.4799829274416, 61.17835879325867, 53.70051585137844, 52.98243798315525, 58.775204345583916, 64.25197586417198, 62.61683240532875, 65.81111580133438, 34.75169263780117, 0.46142010600306094, 2.330240635201335, 2.9330374393612146, 0.08068500406807289, 0.09612868161639199, 0.5353620601817966, 43.309502229094505, 32.391548082232475, 32.94176235795021, 33.036282286047935, 12.203245628625154, 31.820189841091633, 32.066737711429596, 47.06707499921322, 53.9039721339941, 50.64622834324837, 8.32850519567728, 0.1127321801322978, 0.011293708339508157, 0.11967492711846717, 0.04974473384208977, 0.01224874014951638, 0.06422140781069174, 0.043826473483932205, 0.044544512493303046, 0.005222980234975694, 0.01960268426046241, 0.04616041660483461, 0.05549374000111129, 0.027144567065988667, 0.006026820328770555, 0.036077713302802294, 0.08387512585613877, 0.033193467679666355, 0.0397843884275062, 0.01862125518528046, 0.019209084384783637, 0.11132365063531324, 0.10544466102146544, 0.11128744125016965, 0.07130789395887405, 0.07097633948433213, 0.07720978625002317, 0.04477255220990628, 0.04825742907996755, 0.06786737896618433, 0.018488746572984383, 0.014279081788117765, 0.06471445361967199, 0.5297867499757558, 51.32760018110275, 78.80153194069862, 71.91029772162437, 69.66302990913391, 48.71348485350609, 28.8176042586565, 33.159395679831505, 47.58959636092186, 47.65744172036648, 59.495486095547676, 2.444926556199789, 0.07902726880274713, 0.0698369053134229, 1.203682548366487, 2.08813211414963, 3.2346270186826587, 2.7777316980063915, 1.3998849014751613, 60.7517708837986, 76.2616266310215, 66.4593306183815, 68.47604960203171, 63.361839428544044, 58.4696551412344, 54.39948834478855, 54.11563977599144, 51.27461202442646, 49.51586499810219, 49.16533760726452, 48.26830454170704, 51.70061856508255, 47.70567633211613, 48.72845605015755, 48.59057664871216, 47.60273985564709, 47.32389181852341, 49.62738901376724, 50.45178137719631, 51.25470869243145, 46.23536802828312, 46.24314621090889, 46.006551906466484, 47.31138288974762, 47.327019050717354, 53.14519464969635, 55.306883454322815, 58.76510448753834, 59.17915686964989, 61.24308452010155, 59.532306119799614, 61.59280255436897, 55.25731511414051, 51.50792710483074, 44.381211921572685, 43.252854868769646, 43.25236089527607, 46.230321899056435, 45.5868948251009, 50.24441510438919, 56.623235419392586, 57.88164049386978, 56.76837623119354, 59.889471754431725, 53.56862112879753, 45.981359258294106, 41.70180469751358, 46.236428171396255, 50.13027682900429, 60.25237128138542, 52.755156978964806, 65.96234008669853, 36.83392770588398, 41.71517997980118, 62.05483116209507, 50.90255118906498, 51.57368257641792, 43.88601869344711, 46.44673548638821, 42.274023592472076, 45.71906313300133, 53.17858345806599, 57.98349782824516, 56.70947179198265, 55.12530259788036, 47.42088921368122, 49.17289540171623, 53.6437962949276, 56.02648504078388, 54.9227050691843, 55.54531306028366, 58.38153026998043, 48.408669009804726, 43.34658823907375, 44.45494316518307, 43.16222593188286, 44.06456731259823, 47.32234910130501, 47.52305433154106, 55.10946124792099, 57.44369879364967, 58.37270714342594, 57.47506991028786, 59.32397089898586, 48.505457416176796, 43.86252835392952, 44.129118248820305, 44.86214071512222, 53.47261168062687, 59.967584162950516, 58.98510128259659, 61.39625810086727, 61.32398597896099, 61.992666497826576, 60.6316327303648, 56.53498895466328, 58.44442829489708, 66.96538746356964, 61.74797862768173, 63.924243450164795, 53.88972669839859, 54.33689430356026, 60.555473417043686, 67.94753596186638, 63.7626913189888, 66.43930569291115, 42.83879488706589, 0.2955104992724955, 0.4208829905837774, 2.519402322359383, 0.9821935615036637, 0.0798998266691342, 0.5494901770725846, 45.84830179810524, 41.19555786252022, 32.14261204004288, 31.223648451268673, 13.23119591921568, 36.62296302616596, 39.82640393078327, 53.91218729317188, 60.58657094836235, 59.33209866285324, 12.571206483989954, 0.09261243045330048, 0.040263448463520035, 0.1367496745660901, 0.08705928819836117, 0.03548031781974714, 0.08704470499651507, 0.01790567082935013, 0.014596606888517272, 0.09298177508753724, 0.036485538294073194, 0.033270803178311326, 0.03791435810853727, 0.04209961087326519, 0.029180985038692597, 0.028076105263608042, 0.019801691159955226, 0.03259727447584737, 0.36052812763955444, 0.14882481802487746, 0.16305091325193644, 0.2080561881302856, 0.16525803075637668, 0.23814364161808044, 0.20603429584298283, 0.14069084980292246, 0.2068484466872178, 0.1389416225720197, 0.15514116268604994, 0.14251887827413157, 0.1617370595340617, 0.14124652545433491, 0.16678741900250316, 0.7940394734032452, 61.612724885344505, 88.06227341294289, 80.59901028871536, 78.86150792241096, 53.48911799490452, 26.194502413272858, 34.88163806498051, 75.37554457783699, 63.43257263302803, 67.8665243089199, 3.457189151085913, 0.31375605147331953, 0.1018799921439495, 3.8188786804676056, 5.081430757418275, 6.554793622344732, 12.237971015274525, 1.9586819666437805, 65.01143351197243, 76.66190475225449, 69.15558233857155, 70.2339568734169, 65.23584946990013, 60.767133459448814, 55.58352380990982, 57.54895694553852, 55.13422451913357, 52.53751985728741, 52.31786124408245, 51.229896023869514, 54.582349732518196, 49.55939546227455, 52.53580994904041, 51.766773015260696, 50.036068484187126, 51.318442672491074, 53.28850395977497, 50.608735755085945, 54.43611837923527, 47.227642983198166, 48.90045002102852, 48.05468760430813, 49.85336288809776, 49.558061733841896, 54.88602563738823, 57.59820230305195, 60.69029778242111, 62.71367780864239, 63.69918152689934, 59.12174955010414, 61.906646713614464, 59.54380810260773, 55.2326924353838, 47.056918144226074, 45.54481588304043, 45.66328592598438, 48.992861062288284, 47.358378767967224, 50.900617092847824, 59.34170454740524, 61.70218728482723, 59.37112636864185, 62.763059958815575, 54.9149838835001, 48.597511276602745, 41.88393272459507, 47.43581101298332, 52.953928112983704, 64.89130675792694, 55.77109694480896, 67.89129137992859, 41.41443371772766, 45.70201724767685, 64.94369834661484, 53.134403228759766, 53.476681262254715, 45.475849583745, 48.512513637542725, 45.20960547029972, 48.645540699362755, 57.31489710509777, 60.390820652246475, 59.905301705002785, 57.84591481089592, 50.93373231589794, 53.222957476973534, 55.55124834179878, 59.22590956091881, 57.35241249203682, 56.85251511633396, 62.2383689135313, 49.6438193321228, 45.71164593100548, 45.62842659652233, 44.77327108383179, 47.01203495264053, 48.872346729040146, 48.58538992702961, 59.04940143227577, 61.15359552204609, 62.29080229997635, 59.54388789832592, 62.065178006887436, 51.94374091923237, 48.2219622284174, 46.12903453409672, 48.05306129157543, 53.984349220991135, 61.86363682150841, 60.35350285470486, 62.917867451906204, 63.03368143737316, 65.68660408258438, 60.25546811521053, 58.39817337691784, 59.743172004818916, 70.22432819008827, 64.37601640820503, 66.83677196502686, 57.885295897722244, 57.404279708862305, 63.18777076900005, 71.21374949812889, 65.2342763543129, 70.81331938505173, 41.97278715670109, 0.3944710531504825, 8.749115075916052, 10.01915892586112, 0.6626422866247594, 0.24909750383812934, 0.757969671394676, 53.267259299755096, 48.26497212052345, 49.77926306426525, 48.12469884753227, 20.348348915576935, 43.70613254606724, 45.3332432359457, 62.503720074892044, 67.77537479996681, 67.66994565725327, 15.64792038872838, 0.2508985478198156, 0.16356461303075776, 0.23623206216143444, 0.11602068101637997, 0.13060599798336625, 0.13374501548241824, 0.14423196291318163, 0.21460354852024466, 0.12471816939068958, 0.12790253211278468, 0.12776520510669798, 0.15618187637301162, 0.15233867947245017, 0.13045750907622278, 0.08522141884895973, 0.15846635535126552, 0.12732846604194492], [0.0806979248591233, 0.03185216562997084, 0.0674634799361229, 0.0626687087060418, 0.025370874936925247, 0.03959057285101153, 0.016334432875737548, 0.022867341795063112, 0.03601701304432936, 0.018701084300118964, 0.04066031935508363, 0.03358325477165636, 0.05539505662454758, 0.007401337197734392, 0.07326035090954974, 2.918475433252752, 59.012307822704315, 65.63453927636147, 63.82728785276413, 46.85474619269371, 33.526953756809235, 21.818704716861248, 33.7748334556818, 35.75130879878998, 47.42127299308777, 37.93848283588886, 0.1373638166114688, 0.05311518267262727, 0.36031005496624857, 1.1261257412843406, 1.138458929490298, 2.868987126275897, 1.8854876817204058, 13.780709132552147, 78.15149322152138, 66.96230202913284, 71.6590704023838, 60.20346410572529, 64.65847045183182, 61.586502492427826, 60.221596732735634, 50.27104027569294, 50.27656517922878, 47.163354232907295, 48.12959298491478, 43.97623345255852, 47.19693683087826, 47.78596222400665, 44.66291360557079, 43.245076686143875, 45.61071194708347, 45.34699849784374, 46.50020241737366, 50.06013639271259, 48.8094487041235, 45.23292101919651, 44.729527831077576, 44.30724509060383, 44.19141210615635, 45.03476545214653, 53.39070327579975, 54.19320121407509, 57.83571995794773, 56.11215904355049, 57.86513417959213, 57.394058257341385, 59.466828033328056, 56.20233580470085, 50.493552535772324, 41.515949070453644, 42.53369405865669, 40.62691457569599, 41.44031412899494, 42.34640970826149, 47.13701784610748, 52.42683179676533, 54.388970509171486, 53.44126716256142, 58.583060055971146, 47.88716599345207, 41.77085839211941, 38.50054107606411, 47.13811218738556, 52.22877882421017, 57.49557361006737, 52.817215248942375, 58.970734253525734, 31.02812424302101, 37.01208494603634, 61.92696422338486, 49.39795732498169, 49.97525654733181, 38.86748358607292, 43.083562552928925, 39.377176836133, 41.711790561676025, 41.9129441678524, 51.53899043798447, 49.496182054281235, 48.40405225753784, 43.499013260006905, 44.30501081049442, 49.48789469897747, 52.90610767900944, 55.22119425237179, 54.66306500136852, 55.532986521720886, 47.56366275250912, 41.40205018222332, 41.677729189395905, 41.759914979338646, 42.08241507411003, 45.13007573783398, 47.58279092609882, 51.55798181891441, 56.868827641010284, 55.13698697090149, 53.76613073050976, 54.94521886110306, 47.261643558740616, 41.06482967734337, 42.29368753731251, 43.57340566813946, 51.203973814845085, 55.05539394915104, 59.605615586042404, 58.6208376288414, 59.51567441225052, 56.992909982800484, 56.708936020731926, 57.346534207463264, 62.65553332865238, 58.43318089842796, 58.3448888361454, 54.5247258245945, 49.57785487174988, 49.63811583817005, 56.110388338565826, 62.24464997649193, 66.07556641101837, 59.904298558831215, 65.67885249853134, 11.234684251248837, 1.1804822995327413, 5.401855688542128, 0.7044975156895816, 0.5500498751644045, 0.45568244357127696, 15.000906307250261, 48.020189255476, 27.477642260491848, 38.859845995903015, 25.770448967814445, 12.21747301518917, 20.65267078578472, 40.83412125706673, 47.62704715132713, 57.01035864651203, 23.92646111547947, 1.2543777655810118, 0.10207573359366506, 0.01784445106750354, 0.041486671107122675, 0.05943362390098628, 0.008573055256420048, 0.03510416398057714, 0.0346735736093251, 0.1277704001404345, 0.03432032244745642, 0.03563857339031529, 0.015952390094753355, 0.015096763399924384, 0.046895354316802695, 0.08814753644401208, 0.06517480782349594, 0.017359648663841654, 0.04520303125900682, 0.048562206866336055, 0.041928902064682916, 0.044261865550652146, 0.03888132458087057, 0.0336033187340945, 0.021456205504364334, 0.06182463446748443, 0.005898118006371078, 0.017890705421450548, 0.052855401299893856, 0.00584187156164262, 0.027475620590848848, 0.08740844641579315, 0.06347449554596096, 4.590868055820465, 74.10915613174438, 71.93749666213989, 71.57481372356415, 55.97589075565338, 46.84026136994362, 24.12249069660902, 28.485291190445423, 38.74663107097149, 54.89085137844086, 41.28612980246544, 0.1181515131611377, 0.06379866565112025, 0.4622665996430442, 1.9586471747606993, 3.657874194905162, 3.3295399881899357, 0.9428710152860731, 16.093614622950554, 80.08005693554878, 66.61117807030678, 74.05320793390274, 63.626461029052734, 68.67502212524414, 62.770176976919174, 63.27964223921299, 52.75871738791466, 53.935442045331, 50.23005187511444, 49.30039756000042, 46.50931052863598, 50.06895951926708, 48.26600946485996, 47.937315702438354, 45.262510031461716, 47.05551601946354, 47.709137946367264, 49.505666345357895, 53.154477551579475, 52.04749435186386, 48.30695606768131, 45.859245210886, 45.76180703938007, 46.05622664093971, 49.35696892440319, 55.80249845981598, 55.21258391439915, 60.209000408649445, 58.817693665623665, 58.869804069399834, 59.06341888010502, 60.66535212099552, 59.20099429786205, 51.96663849055767, 43.92790764570236, 43.60884636640549, 43.507570400834084, 43.425274416804314, 44.046529680490494, 51.29934869706631, 54.92086976766586, 56.08423814177513, 55.819361954927444, 61.644848361611366, 49.220043271780014, 43.84871989488602, 42.03145980834961, 51.004214733839035, 54.259226471185684, 59.712059274315834, 57.58611895143986, 61.23159773647785, 32.77020916342735, 40.08450128138065, 64.4664591550827, 52.86438591778278, 52.30601727962494, 41.12569101154804, 44.423659443855286, 41.379844173789024, 43.30644719302654, 43.564012572169304, 52.756289318203926, 51.26876413822174, 49.87426556646824, 46.04006230831146, 46.909615248441696, 51.81944198906422, 54.751965031027794, 56.1265716701746, 56.32402427494526, 57.41838835179806, 48.82611081004143, 43.113018572330475, 44.29456137120724, 43.44578191637993, 42.9980443418026, 47.16448277235031, 50.35635709762573, 53.32679070532322, 59.6194202452898, 57.2185342758894, 57.03952968120575, 57.96872802078724, 50.18684819340706, 43.98303508758545, 44.434876441955566, 44.14674550294876, 53.200329691171646, 57.68549881875515, 61.200788989663124, 61.154397279024124, 60.86163818836212, 59.53484818339348, 56.290662065148354, 58.56779247522354, 64.50051292777061, 60.884167179465294, 60.738931372761726, 56.64963640272617, 51.49766765534878, 51.526451110839844, 57.96710170805454, 63.724476769566536, 69.48643818497658, 62.04467810690403, 71.554796397686, 15.07869478315115, 1.275090929120779, 2.477943222038448, 2.800098485313356, 1.1574655096046627, 0.6039253436028957, 14.258990418165922, 53.134840205311775, 35.481435880064964, 30.526193976402283, 21.451049745082855, 17.178264521062374, 27.869310043752193, 49.05664823949337, 52.631671205163, 67.74387449026108, 30.910718142986298, 1.93698572460562, 0.12950662494404241, 0.01057600700733019, 0.04885897687927354, 0.05186949892959092, 0.02008170347835403, 0.05582703852269333, 0.05961649650998879, 0.09829381582676433, 0.006592153640667675, 0.04660636201151647, 0.007557943345091189, 0.022874748428876046, 0.059918001425103284, 0.028414951339073014, 0.07432288373820484, 0.012884951811429346, 0.17349241155898198, 0.084431825671345, 0.11643291436485015, 0.1354290673043579, 0.0951588578755036, 0.13704800308914855, 0.09075474576093256, 0.22851909947348759, 0.1348402028088458, 0.04905290748865809, 0.09878573357127607, 0.19557675230316818, 0.13223404734162614, 0.24669039237778634, 0.23015606944682077, 6.691942038014531, 85.50991237163544, 80.8375994861126, 82.3177720606327, 63.619951978325844, 47.0914126932621, 29.852735213935375, 45.45845411717892, 49.98336911201477, 62.681269347667694, 45.94969555735588, 0.4358857433544472, 0.20492788724368438, 1.0035949037410319, 4.636366339400411, 5.3667165990918875, 13.393669500946999, 4.541224194690585, 16.97436936199665, 80.9243868291378, 69.03110861778259, 77.45728567242622, 65.17809256911278, 69.60626855492592, 65.41090607643127, 66.21117353439331, 56.293321922421455, 56.34671665728092, 50.26269592344761, 52.025801315903664, 47.39649072289467, 51.36749044060707, 51.25533565878868, 50.1380930095911, 47.274832651019096, 50.04043065011501, 50.67680150270462, 53.27442191541195, 55.63077427446842, 54.96565796434879, 51.02487422525883, 48.73770475387573, 49.7315414249897, 49.182125106453896, 50.316322445869446, 58.2633376121521, 58.78396287560463, 63.39732572436333, 60.69955788552761, 61.91212601959705, 62.25418746471405, 62.89571464061737, 61.613633036613464, 55.72946637868881, 45.73650419712067, 46.93207964301109, 45.12488141655922, 44.874824434518814, 47.044382616877556, 53.26319731771946, 56.424943059682846, 57.97228842973709, 56.89406968653202, 64.49903100728989, 52.4365858733654, 46.76207676529884, 43.50450396537781, 53.63509476184845, 56.839459016919136, 63.56258265674114, 60.13657629489899, 62.12976314127445, 35.27387961745262, 43.90663258731365, 67.68596559762955, 55.2238617092371, 55.307544618844986, 43.86077664792538, 47.05596059560776, 42.703940123319626, 47.87351332604885, 46.74556665122509, 55.81119619309902, 53.57843220233917, 53.5011101514101, 48.07940527796745, 49.15779501199722, 54.23404902219772, 56.930353939533234, 58.96501176059246, 59.10267077386379, 61.392693892121315, 51.074195578694344, 46.0399255156517, 48.06695714592934, 46.80275358259678, 45.42756177484989, 49.210258796811104, 53.21888029575348, 56.504647582769394, 61.51294983923435, 59.83458749949932, 58.69405969977379, 60.133684650063515, 53.134342432022095, 46.42652057111263, 45.84922134876251, 48.48030276596546, 57.14615575969219, 61.370123103260994, 64.8710386455059, 63.59220966696739, 65.0067825615406, 61.550647616386414, 60.306696966290474, 61.25460930168629, 67.27979019284248, 63.74621920287609, 63.920306861400604, 60.06977967917919, 54.49093043804169, 55.42512930929661, 61.69741094112396, 66.61472707986832, 73.53499174118042, 64.39829081296921, 73.15600767731667, 14.784363526850939, 2.9749881383031607, 17.901379019021988, 2.835989696905017, 1.031719094607979, 0.663947279099375, 18.46000414341688, 62.017893344163895, 44.12609741091728, 54.277484491467476, 37.1905879676342, 20.941478088498116, 31.99048340320587, 56.225191578269005, 62.30694003403187, 75.59814423322678, 38.515398278832436, 2.4675569543614984, 0.17035340890288353, 0.10109954964718781, 0.10647627597791143, 0.1545306868501939, 0.10608670781948604, 0.10152552014915273, 0.10236268499284051, 0.20393691229401156, 0.0866974021482747, 0.1405372252338566, 0.0858262024121359, 0.08207310966099612, 0.197494343155995, 0.17359353660140187, 0.13996875495649874, 0.12191071378765628], [0.034284684516023844, 0.05137093896337319, 0.05141922680195421, 0.06761231023119763, 0.017544682777952403, 0.017460901726735756, 0.11435522741521709, 0.05019728807383217, 0.06522797528305091, 0.017228973156306893, 0.03621165611548349, 0.0590961285342928, 0.06246674805879593, 0.08405432483414188, 0.09850687900325283, 15.387339871376753, 74.75474908947945, 58.267114609479904, 60.496766567230225, 32.05976128578186, 16.33575662970543, 23.361465632915497, 51.74684688448906, 34.74351927638054, 62.957107946276665, 17.24439237266779, 0.19446896330919117, 0.13347367144888267, 0.6397902534808964, 0.24432208039797843, 2.8657311759889126, 2.8731175046414137, 0.4947258532047272, 64.89120036363602, 74.03071314096451, 71.09246760606766, 71.00672900676727, 66.58905565738678, 66.26867204904556, 62.90488734841347, 62.892237827181816, 59.97004263103008, 52.70150005817413, 47.2929272800684, 46.33182965219021, 47.28209026157856, 46.27557747066021, 46.0196004062891, 46.45249977707863, 44.82650242745876, 44.2111786454916, 45.34789904952049, 48.53437006473541, 48.65898057818413, 48.13246563076973, 46.24426335096359, 44.33566376566887, 42.64170706272125, 44.04100477695465, 47.96464383602142, 51.29985027015209, 54.23907235264778, 53.58765430748463, 52.47879400849342, 54.981677904725075, 56.73367649316788, 57.512729689478874, 56.989729553461075, 50.66252566874027, 41.53380811214447, 43.020630329847336, 41.66952162981033, 41.26298904418945, 44.438056871294975, 47.29373283684254, 52.446510940790176, 54.0645819157362, 55.216262117028236, 54.71096523106098, 42.95972719788551, 40.88069535791874, 43.65172706544399, 55.202351063489914, 54.933074712753296, 57.805040404200554, 51.404538452625275, 57.776245549321175, 32.09107920527458, 38.41153845191002, 62.40741424262524, 52.2842862457037, 50.32626651227474, 41.841842383146286, 43.61502103507519, 41.378928422927856, 41.617696210742, 39.038637802004814, 42.247611209750175, 41.92583307623863, 43.102926313877106, 42.61001296341419, 43.0601292103529, 49.77148488163948, 56.050849333405495, 53.4224733710289, 56.09850637614727, 53.106250539422035, 47.765941098332405, 40.73866277933121, 40.618600621819496, 42.64649100601673, 41.21279753744602, 46.202940568327904, 50.32924935221672, 53.27741235494614, 55.99859833717346, 54.835359156131744, 55.50998255610466, 55.42325221002102, 45.534051060676575, 41.40612356364727, 43.78534309566021, 42.433922812342644, 51.61720544099808, 58.133152797818184, 56.35088883340359, 56.23760551214218, 56.96215443313122, 54.653231129050255, 58.25923763215542, 60.31479053199291, 56.5826041996479, 58.60756114125252, 51.68196156620979, 47.563050985336304, 51.28294877707958, 49.39187005162239, 56.24088853597641, 59.16230857372284, 64.01647210121155, 57.48636670410633, 63.36060829460621, 41.949194222688675, 0.7439219439402223, 0.7007973454892635, 3.1795017141848803, 0.11299271849566139, 0.03221689781639725, 0.8548812149092555, 43.42881962656975, 38.345068618655205, 39.908813908696175, 36.925882771611214, 50.1861946284771, 22.888516411185265, 30.256822630763054, 48.38588543236256, 46.643568724393845, 44.47514288127422, 7.324257558211684, 0.10105232679052278, 0.05670719227055088, 0.03806200096732937, 0.07217149410280399, 0.08496265421854332, 0.01689505865215324, 0.10822261625435203, 0.049457912318757735, 0.07055560854496434, 0.04140717595873866, 0.030571088864235207, 0.05962041504972149, 0.04608360060956329, 0.03846303159662057, 0.10858667679713108, 0.01849804011726519, 0.05029318097513169, 0.03948673154809512, 0.025067292008316144, 0.018860000382119324, 0.008508876180712832, 0.0368198832438793, 0.06330774238449521, 0.052160992272547446, 0.054927863529883325, 0.021623693392029963, 0.018623073447088245, 0.05170010743313469, 0.051165824188501574, 0.16310807346599177, 0.15743172727525234, 22.619420550763607, 84.96255174279213, 67.48301848769188, 66.42741233110428, 43.43545027077198, 27.1635340154171, 20.92624470591545, 45.24425961077213, 35.854689851403236, 71.84921979904175, 18.81761245429516, 0.33779088989831507, 0.05740013926697429, 1.0753580904565752, 3.3223248878493905, 3.662623227573931, 1.4732215600088239, 0.9385198331438005, 67.75905847549438, 76.76058545708656, 71.37252017855644, 70.75415655970573, 70.03613948822021, 67.26586014032364, 65.16322776675224, 64.09890487790108, 61.99625350534916, 55.96365541219711, 50.47350861132145, 49.76889722049236, 50.9980096668005, 48.127358704805374, 49.78331744670868, 49.26820948719978, 46.5432845056057, 47.2439669072628, 48.9440792798996, 52.35702574253082, 52.41456225514412, 51.68500520288944, 49.64161165058613, 47.133503034710884, 45.27932032942772, 45.653710439801216, 49.27929729223251, 51.80815279483795, 55.64957566559315, 55.81942655146122, 53.645905181765556, 56.57122761011124, 59.4638641923666, 61.01149454712868, 59.09548535943031, 52.57235638797283, 43.048688024282455, 43.61587218940258, 42.94480159878731, 42.42435112595558, 45.478064864873886, 50.7491610199213, 54.9414798617363, 57.262292727828026, 55.42664162814617, 55.4385007917881, 47.19736620783806, 43.34349140524864, 45.91321751475334, 57.074993178248405, 56.36126607656479, 60.22539272904396, 52.770154774188995, 58.684237226843834, 32.19204358756542, 40.14993757009506, 63.9436300098896, 53.91885593533516, 52.85971216857433, 42.17202566564083, 47.740087285637856, 43.98832060396671, 44.085188806056976, 41.45072177052498, 43.25604669749737, 45.20596146583557, 45.40559895336628, 46.597408801317215, 46.35053604841232, 52.81650468707085, 58.6847198009491, 56.44103139638901, 58.31224858760834, 56.08441673219204, 48.83666664361954, 43.40081512928009, 43.07692430913448, 43.65402974188328, 44.32510033249855, 47.28554047644138, 52.6873230189085, 54.439469799399376, 58.369348123669624, 58.57586324214935, 58.60207423567772, 57.612493336200714, 47.3690789937973, 43.78615625202656, 45.89250482618809, 43.96387651562691, 53.326357528567314, 61.192429438233376, 59.681968688964844, 56.42626918852329, 58.66510905325413, 56.151110753417015, 59.87334921956062, 63.01340572535992, 60.856649056077, 62.32189983129501, 54.24555100500584, 50.832764133811, 53.244623914361, 50.52287936210632, 58.39010640978813, 61.62323512136936, 66.5460267663002, 60.17470344901085, 66.50074079632759, 48.22894245386124, 0.9507630730513483, 0.9084699174854904, 6.340972920879722, 0.7962586137000471, 0.04091985581908375, 0.7092656067106873, 47.53790773451328, 45.493868216872215, 38.8868473470211, 37.60205268859863, 48.19520026445389, 29.98717959970236, 36.555881425738335, 54.35066096484661, 52.2110565751791, 56.65578067302704, 9.227929282933474, 0.10041621717391536, 0.05336282622010913, 0.03269515262218192, 0.03924990109226201, 0.1082560425857082, 0.10545264653046615, 0.09529186558211222, 0.040176153343054466, 0.04475682238989975, 0.01618827987840632, 0.06105688269599341, 0.01021415899231215, 0.017493695377197582, 0.02542366761190351, 0.047751124802744016, 0.046107404996291734, 0.1081716975022573, 0.22694442537613213, 0.2395075309323147, 0.13947616185760126, 0.1293560431804508, 0.18904600117821246, 0.19645558873889968, 0.20467459224164486, 0.12682646251050755, 0.0604257046506973, 0.19400685763685033, 0.1745143489097245, 0.11803645800682716, 0.2999284747056663, 0.3446252387948334, 28.037369325757027, 98.37899342179298, 76.17160186171532, 77.82579749822617, 45.13125367462635, 25.153686963021755, 34.99054402112961, 69.52275663614273, 47.36510060727596, 79.76882323622704, 21.025567576289177, 0.3136283130152151, 0.16241165692918003, 2.137189144268632, 2.4580394150689244, 6.595545960590243, 8.980256672948599, 0.8704014227259904, 73.23160082101822, 76.2402717769146, 75.9822428226471, 71.93864420056343, 70.3528144955635, 71.46367728710175, 68.48124772310257, 67.68822267651558, 65.30027121305466, 58.48338380455971, 51.71710968017578, 51.743024289608, 51.849220991134644, 52.038656026124954, 52.15415082871914, 50.96736431121826, 49.45742413401604, 49.48137424886227, 49.92017090320587, 54.298356771469116, 54.20823700726032, 53.403037413954735, 52.223451510071754, 48.98829750716686, 46.914106607437134, 48.16190265119076, 53.633890226483345, 55.37816382944584, 60.491750836372375, 57.39143639802933, 55.50334431231022, 59.24529232084751, 61.80461458861828, 62.020534202456474, 62.17329740524292, 55.55275306105614, 45.92383034527302, 47.74150460958481, 45.64085192978382, 44.70156133174896, 48.562534153461456, 53.36829587817192, 59.505080580711365, 59.96582865715027, 59.58081811666489, 58.90992611646652, 49.84548591077328, 46.11671179533005, 49.34086538851261, 59.93044875562191, 60.171519219875336, 62.12906397879124, 54.22818973660469, 60.822143107652664, 36.68907567858696, 43.21086332201958, 68.26326102018356, 56.206979155540466, 55.38235880434513, 45.56695729494095, 50.12376397848129, 47.48307667672634, 47.124577313661575, 43.33455428481102, 45.78606873750687, 46.99364773929119, 47.35685504972935, 48.25782470405102, 47.40844868123531, 56.413904651999474, 60.649362578988075, 58.004997074604034, 61.916362792253494, 58.306313306093216, 50.80323971807957, 44.97063249349594, 45.345748364925385, 48.32694299519062, 46.96611441671848, 51.329051703214645, 55.37883639335632, 58.35175886750221, 59.57957178354263, 59.09229353070259, 59.386279955506325, 59.94272209703922, 48.59797105193138, 46.72296546399593, 47.395407781004906, 46.228308007121086, 56.743612959980965, 64.82109412550926, 62.194234281778336, 58.54281261563301, 61.02637454867363, 59.534741789102554, 62.17687301337719, 66.59222468733788, 62.88432665169239, 65.43304368853569, 56.31425119936466, 54.16624926030636, 56.49781174957752, 54.18981559574604, 60.356022119522095, 66.55465230345726, 69.47596594691277, 62.04701118171215, 65.90209051966667, 49.6057453751564, 1.3007332594133914, 5.950160091742873, 10.926817171275616, 0.4889680934138596, 0.18502413964597508, 1.3704922911711037, 54.4320297986269, 51.93893797695637, 58.69273357093334, 49.37664806842804, 58.03914584219456, 31.519929952919483, 43.49041432142258, 62.89981462061405, 61.544119566679, 64.61241692304611, 11.583467535674572, 0.34476360480766743, 0.185036949114874, 0.11946515907766297, 0.20008335501188412, 0.26591338275466114, 0.16771128895925358, 0.18416565289953724, 0.09098930895561352, 0.15360893943579867, 0.17636507225688547, 0.2827313990565017, 0.18327369529288262, 0.16026138793677092, 0.16959857050096616, 0.14747874025488272, 0.2254869809257798], [0.04010663637018297, 0.02125815226463601, 0.0526244672073517, 0.0546989146823762, 0.0913843690068461, 0.018394657090539113, 0.023157143041316886, 0.018121739703929052, 0.018163344502681866, 0.04294206351914909, 0.042369055008748546, 0.03482598105620127, 0.04272272919479292, 0.01822539732529549, 0.159311379538849, 36.80576741695404, 70.6554226577282, 59.49862092733383, 56.99102908372879, 29.603624381124973, 24.66645810753107, 32.21241809427738, 43.73444862663746, 38.72960418462753, 62.728956788778305, 2.4165767524391413, 0.12035010338877328, 0.03698760119732469, 0.35974875383544713, 1.6730889352038503, 5.440830197185278, 1.8110304395668209, 26.380848214030266, 85.8146408200264, 61.50035351514816, 73.85212272405624, 66.53392821550369, 71.0398480296135, 65.69833785295486, 67.43136405944824, 62.462936863303185, 59.26511965692043, 57.22828075289726, 52.51282878220081, 47.36745648086071, 45.24436600506306, 47.13495075702667, 45.79316295683384, 43.95819202065468, 46.379376500844955, 42.001426219940186, 45.879938900470734, 49.03953395783901, 49.79060545563698, 47.40394972264767, 47.678139209747314, 44.94184523820877, 44.399751126766205, 45.7776939868927, 47.627898305654526, 48.019167110323906, 51.91542863845825, 48.64232987165451, 51.47902965545654, 51.10063076019287, 57.75566965341568, 58.163399174809456, 56.70300453901291, 48.92126530408859, 40.15801593661308, 40.79400300979614, 38.83270405232906, 42.11278684437275, 42.05493874847889, 47.649849727749825, 49.850748628377914, 52.87603609263897, 54.00813214480877, 47.189705818891525, 39.69011664390564, 42.347887828946114, 43.60970512032509, 58.14472697675228, 53.88657666742802, 59.279843866825104, 49.583075791597366, 61.650620251894, 35.09643293917179, 39.09715086221695, 62.28279992938042, 50.142656564712524, 49.18885834515095, 42.1980694681406, 44.02621977031231, 39.46985766291618, 43.44671666622162, 41.34889103472233, 42.32508145272732, 40.785438269376755, 41.99513755738735, 42.87771239876747, 41.83523453772068, 46.0278345644474, 54.64269429445267, 51.61882035434246, 55.4553946852684, 51.24440364539623, 48.40822443366051, 40.19671306014061, 40.2217461168766, 39.250658825039864, 41.28052890300751, 45.15481621026993, 49.94759023189545, 50.8927059173584, 53.6968794465065, 54.115480184555054, 57.26942874491215, 51.61810599267483, 42.02310785651207, 42.114755138754845, 42.713173627853394, 43.68744134902954, 51.03503108024597, 57.50418394804001, 55.198433473706245, 54.58686389029026, 54.47771094739437, 58.92117731273174, 57.482494711875916, 58.39686244726181, 56.527921333909035, 48.37806925177574, 46.67690433561802, 49.66468021273613, 49.25338268280029, 55.052141323685646, 57.97951944172382, 62.13137425482273, 61.10670983791351, 65.71754202246666, 57.702491506934166, 63.035991713404655, 11.871113050729036, 0.6318590696901083, 5.450504003092647, 0.15107354032807052, 0.254782740958035, 0.18412057484965771, 14.354565739631653, 59.308220744132996, 28.642674945294857, 26.599839963018894, 31.840117871761322, 16.073730289936066, 37.25211426615715, 45.25037728250027, 50.630405992269516, 50.7331220805645, 13.9504574239254, 0.21693738031899557, 0.06503078664536588, 0.05131034260557499, 0.0663647599867545, 0.028170450787001755, 0.05851423280546442, 0.02791553419228876, 0.03998015214165207, 0.03849446897220332, 0.08521177835064009, 0.0458167539909482, 0.008562570565118222, 0.029203765261627268, 0.020090134275960736, 0.052501968311844394, 0.0564013680559583, 0.014564112880179891, 0.030833263663225807, 0.012503314428613521, 0.07543594198068604, 0.08553056788514368, 0.0451331209478667, 0.013643751426570816, 0.02657781857124064, 0.03714419435709715, 0.0721141483518295, 0.025864523740892764, 0.04781804796948563, 0.08964220702182502, 0.05082521551230457, 0.3558470756979659, 46.614473685622215, 77.98492535948753, 67.19991847872734, 64.1871665418148, 34.06145967543125, 22.518478967249393, 24.720194824039936, 42.2132458537817, 46.53612568974495, 70.94494432210922, 2.7013987815007567, 0.16185350250452757, 0.17888061149278656, 1.084872423671186, 6.190284406766295, 7.777816895395517, 1.2662233924493194, 30.049760341644287, 86.39997661113739, 64.51594769954681, 75.2417841553688, 67.97500848770142, 72.1411581337452, 67.82018199563026, 70.02474769949913, 64.39096480607986, 60.96694193780422, 58.82877767086029, 53.650860115885735, 50.135231763124466, 47.7544467151165, 48.50922681391239, 47.94897347688675, 44.209476336836815, 49.73687633872032, 44.63587425649166, 47.709772512316704, 51.534419283270836, 50.3278586268425, 49.421098083257675, 50.34206226468086, 47.47185967862606, 46.371203139424324, 47.771747186779976, 48.258919045329094, 51.58565193414688, 53.32823842763901, 52.37435281276703, 52.91866980493069, 54.744916409254074, 59.851834774017334, 60.02801991999149, 59.578766226768494, 50.8433123677969, 42.463774010539055, 41.586317494511604, 42.438820749521255, 42.314772605895996, 43.2424396276474, 49.372498691082, 50.68723574280739, 54.936813712120056, 55.540711507201195, 50.27741253376007, 41.790442541241646, 44.80048142373562, 45.9116367995739, 59.413000121712685, 55.608385875821114, 62.47545339167118, 53.31765599548817, 61.40067346394062, 37.18977101147175, 40.163240656256676, 63.56285244226456, 52.593950629234314, 51.45328603684902, 44.02182720601559, 45.98167084157467, 44.9726539850235, 47.87216819822788, 42.15241111814976, 44.32484574615955, 42.19479784369469, 43.871279284358025, 44.523430690169334, 43.23423966765404, 47.79701203107834, 57.97123968601227, 55.93163073062897, 57.424980998039246, 54.21982258558273, 49.91962753236294, 43.60540375113487, 43.33067089319229, 42.918370217084885, 43.76571334898472, 47.14673012495041, 51.6510084271431, 55.14644466340542, 57.975309267640114, 58.018178567290306, 59.01576183736324, 53.58700834214687, 44.35774818062782, 44.228942692279816, 45.39722040295601, 44.91724535822868, 52.04525627195835, 59.06395845115185, 57.32860676944256, 56.06391303241253, 56.06208153069019, 62.47348129749298, 60.49838908016682, 60.269052386283875, 59.65207189321518, 50.64641073346138, 47.45905056595802, 50.73216453194618, 52.30717621743679, 57.23967254161835, 59.4100970774889, 65.00824928283691, 64.22638043761253, 67.84330755472183, 59.921329244971275, 67.66966447234154, 14.214860536158085, 0.4402432782808319, 4.029919356107712, 3.3350026700645685, 0.7608389330562204, 0.13511858240235597, 15.363430604338646, 65.50490543246269, 32.22456984221935, 25.5728804692626, 37.28775255382061, 20.67944034934044, 43.251156359910965, 52.000384479761124, 56.703806295990944, 58.48853252828121, 21.12772509455681, 0.29627695970702916, 0.034879037193604745, 0.01893376243970124, 0.05481001047883183, 0.02898784110584529, 0.05814634649141226, 0.025987072731368244, 0.06747243023710325, 0.0830843007133808, 0.06101281767769251, 0.009304083705501398, 0.05451193428598344, 0.015344493222073652, 0.08983120234915987, 0.044740220546373166, 0.05854443079442717, 0.12845644145272672, 0.09694663225673139, 0.1261003452236764, 0.11123195828986354, 0.14552534819813445, 0.15267960727214813, 0.1255127869080752, 0.0845409584871959, 0.09143711344222538, 0.1606472601997666, 0.14111972210230306, 0.1355340366717428, 0.3027894243132323, 0.24378117348533124, 0.6325103191193193, 57.52803146839142, 87.82018840312958, 75.12342810630798, 73.55624780058861, 40.94980604946613, 34.9248493462801, 46.16602174937725, 62.597293853759766, 56.32734529674053, 76.86865165829659, 3.5802412731572986, 0.2859054459258914, 0.31254038389306515, 2.8182294499129057, 4.177621705457568, 12.801571972668171, 5.578166702762246, 29.702971950173378, 91.48130714893341, 64.82016697525978, 80.27757033705711, 69.57659214735031, 73.23514223098755, 67.92245730757713, 73.40633824467659, 67.03354820609093, 65.05624070763588, 62.20117650926113, 56.506570279598236, 52.944360226392746, 49.396342411637306, 50.69441355764866, 49.070544093847275, 46.98813423514366, 52.93550670146942, 45.932763665914536, 51.29821255803108, 54.079465717077255, 54.94488447904587, 51.24384507536888, 54.165466502308846, 50.386295691132545, 48.54753255844116, 52.51294657588005, 52.14012198150158, 53.50763060152531, 56.14721976220608, 53.421439826488495, 57.07458660006523, 55.67335858941078, 63.99720713496208, 61.92517451941967, 64.93220776319504, 52.96525910496712, 44.48457017540932, 44.71204876899719, 44.50844049453735, 46.03421442210674, 47.0097740739584, 52.429111674427986, 54.99427802860737, 56.69065900146961, 58.90787422657013, 52.42433913052082, 42.298916056752205, 48.12186419963837, 48.60781252384186, 61.91734693944454, 58.70740458369255, 63.5269595682621, 52.72209495306015, 64.20152977108955, 39.38519440591335, 43.062922060489655, 66.7244727909565, 57.11763069033623, 53.93597021698952, 45.86187466979027, 49.04233440756798, 47.10018642246723, 50.03562770783901, 46.2888615578413, 46.90727077424526, 45.6254817545414, 46.39917343854904, 48.11679147183895, 45.922181233763695, 49.837852120399475, 61.473754942417145, 57.213396951556206, 59.7880931943655, 56.50903254747391, 52.91974514722824, 45.75940936803818, 47.561998441815376, 45.09995475411415, 45.27729503810406, 49.632108360528946, 54.20216113328934, 57.91515849530697, 60.82304745912552, 58.92408795654774, 62.41492263972759, 55.63780389726162, 46.34496934711933, 47.04977832734585, 47.02382571995258, 48.1827749311924, 55.591947957873344, 61.511931493878365, 59.40911293029785, 58.72223898768425, 58.15796546638012, 64.19847473502159, 62.7289529889822, 62.290703505277634, 64.0747381746769, 53.50297965109348, 48.93742963671684, 54.328059777617455, 56.22212894260883, 60.277028158307076, 63.93815070390701, 66.80845588445663, 67.53180786967278, 69.96436133980751, 60.75312741100788, 67.97193825244904, 14.76615870371461, 1.0972012183628976, 15.29770078137517, 1.9833842036314309, 0.5598576238844544, 0.19025298563065007, 18.767335452139378, 73.67206558585167, 40.79740382730961, 36.918457970023155, 38.22317875921726, 23.642242066562176, 50.67452162504196, 60.768034011125565, 63.893457502126694, 67.99811124801636, 27.0548028498888, 0.7609487709123641, 0.1475092425243929, 0.18450181611115113, 0.109010739979567, 0.13607203436549753, 0.2100948677980341, 0.11687192440149374, 0.102871612762101, 0.31134273565839976, 0.08520651652361266, 0.13327522116014734, 0.15564763394650072, 0.09864010193268768, 0.1649935293244198, 0.16099952801596373, 0.1544314913917333], [0.04903709232166875, 0.04740038581076078, 0.03434051999647636, 0.010925038131972542, 0.04002410583780147, 0.10123269094037823, 0.06551252954523079, 0.034301097111892886, 0.03243524508434348, 0.09400887036463246, 0.01621794537641108, 0.0463063339702785, 0.038690592627972364, 0.03202868545486126, 1.4530402491800487, 59.586897790431976, 59.56062600016594, 61.45937651395798, 47.81922943890095, 27.117307595908642, 19.96336117386818, 50.64935177564621, 43.36388111114502, 55.46258769929409, 47.31696479022503, 0.2949632692616433, 0.0316957691393327, 0.35731839830987155, 0.8882365969475359, 9.732548855245113, 3.86941050644964, 0.6352734833490103, 71.83515295386314, 66.66613832116127, 67.18766793608665, 62.456993982195854, 66.81718781590462, 63.92929717898369, 67.33412727713585, 63.260609060525894, 65.86380377411842, 59.58419233560562, 60.666727647185326, 54.98404137790203, 51.37860104441643, 45.96263386309147, 47.69626043736935, 45.01791335642338, 44.93876360356808, 44.63623523712158, 43.87341096997261, 42.62935392558575, 47.7120865881443, 45.60296416282654, 48.21892999112606, 45.84688067436218, 45.1670553535223, 45.5264400690794, 44.04629409313202, 44.932562336325645, 49.24125373363495, 46.97529852390289, 48.17709423601627, 48.101675882935524, 55.90940572321415, 57.651965618133545, 58.11080239713192, 53.638742566108704, 47.25087113678455, 39.10350412130356, 42.91851460933685, 39.24980767071247, 43.18992644548416, 41.974542662501335, 45.548475086688995, 48.425931483507156, 51.0733026266098, 47.47432954609394, 41.501270458102226, 39.06857639551163, 42.387565299868584, 44.90025646984577, 58.07839013636112, 54.185841009020805, 58.26223187148571, 52.47903719544411, 62.62891195714474, 36.93634741008282, 41.29343681037426, 61.346834152936935, 51.22556425631046, 47.24914602935314, 41.86490334570408, 45.96391819417477, 44.74194936454296, 45.10064631700516, 41.03022873401642, 41.296605840325356, 40.90137764811516, 41.92286543548107, 42.87407599389553, 41.810490265488625, 42.71707221865654, 53.89438904821873, 52.25283533334732, 54.603092819452286, 51.246584728360176, 45.0057578086853, 41.09992079436779, 40.19450917840004, 38.54390434920788, 41.02998934686184, 45.1113161444664, 47.94367656111717, 51.14487558603287, 53.528483882546425, 53.19381304085255, 51.04058638215065, 45.90767741203308, 44.19021897017956, 42.03392207622528, 42.247181832790375, 42.47029446065426, 46.85901336371899, 57.47265323996544, 54.28375795483589, 58.336343094706535, 58.2531351596117, 59.04491767287254, 57.99280732870102, 54.692798405885696, 47.56376154720783, 47.260340228676796, 44.251889660954475, 49.98813785612583, 54.85270902514458, 56.857629641890526, 57.98526093363762, 60.352370515465736, 59.51086767017841, 64.59420070052147, 52.98103965818882, 67.86081701517105, 42.79170021414757, 0.3488850180292502, 4.074004590511322, 3.4950581565499306, 0.0609035549859982, 0.045943590739625506, 1.6921680676750839, 44.35091234743595, 53.78025837242603, 35.12600675225258, 19.43286594003439, 21.983868554234505, 17.68583368510008, 36.79353587329388, 44.61719445884228, 45.75274832546711, 38.4675208479166, 1.3269194355234504, 0.05883757912670262, 0.05972000384645071, 0.053296793630579486, 0.045721280403085984, 0.02539508008339908, 0.11880280711920932, 0.03314751389552839, 0.06732375579304062, 0.02316303569386946, 0.10162296413909644, 0.014436318760999711, 0.051112935034325346, 0.10366187387262471, 0.012288307752896799, 0.029138048084860202, 0.037259015734889545, 0.10542405158048496, 0.02423584541247692, 0.020381859540066216, 0.036739152419613674, 0.06904025431140326, 0.01307506407101755, 0.006089514181439881, 0.035244081082055345, 0.08386313274968415, 0.0542432397196535, 0.061793082059011795, 0.036163186450721696, 0.03396999905817211, 2.6448616152629256, 74.05408188700676, 67.96845003962517, 68.44363734126091, 54.34170484542847, 36.38150118291378, 19.230931475758553, 40.43426871299744, 46.77360534667969, 61.48893132805824, 50.45013606548309, 0.15722590003861114, 0.07188084680819884, 0.31945678463671356, 2.5765106454491615, 5.436025829985738, 2.0380472391843796, 1.195477363653481, 75.03026470541954, 70.02493008971214, 69.12306368350983, 64.37837228178978, 68.44731554389, 67.19625547528267, 67.31501430273056, 65.10644361376762, 66.72517195343971, 62.84837678074837, 61.4664289355278, 57.64831021428108, 55.50244376063347, 48.323754966259, 48.513680174946785, 47.538952678442, 46.20846927165985, 46.79785944521427, 46.29733130335808, 45.92972382903099, 49.26154084503651, 48.24608713388443, 49.87978287041187, 47.935377806425095, 49.27111253142357, 48.34627255797386, 47.107839211821556, 47.1890864521265, 50.32396383583546, 48.01060996949673, 48.97222816944122, 49.629516899585724, 58.60254921019077, 59.22688610851765, 59.386086165905, 54.973557740449905, 48.529741913080215, 41.57273322343826, 44.04159374535084, 41.621518805623055, 45.699380189180374, 44.410599544644356, 47.58878320455551, 50.37643902003765, 52.828398048877716, 48.65855120122433, 43.79192054271698, 42.682870253920555, 43.5800439119339, 46.070061698555946, 59.57147441804409, 56.301871463656425, 60.26773765683174, 55.13119988143444, 65.1883216202259, 39.38465103507042, 42.784830182790756, 64.23168495297432, 54.57684002816677, 49.91114638745785, 43.856855258345604, 47.73166313767433, 46.26987397670746, 46.34792558848858, 44.20933574438095, 43.43750216066837, 43.229322731494904, 43.4562161564827, 44.74305510520935, 44.14919637143612, 45.262510031461716, 56.4756665378809, 54.79462154209614, 56.72105737030506, 54.179058372974396, 48.053543865680695, 43.601573556661606, 42.625759318470955, 39.7063759714365, 44.03020575642586, 47.78032712638378, 49.95556220412254, 54.187007546424866, 55.2013935148716, 55.12378267943859, 53.11790071427822, 47.243119552731514, 45.67587465047836, 45.15968754887581, 44.17228773236275, 45.531144216656685, 48.31237077713013, 59.159732311964035, 56.26635476946831, 59.88086901605129, 58.35514448583126, 62.31827102601528, 59.11165349185467, 58.21147419512272, 49.47808362543583, 48.66104766726494, 47.27843105792999, 53.35899777710438, 57.45218373835087, 59.657186418771744, 59.62041579186916, 63.402683436870575, 60.381465554237366, 66.3845582306385, 57.5175554305315, 68.24728667736053, 45.72243735194206, 0.5654420179780573, 0.331705694552511, 2.562730684876442, 0.2348711117519997, 0.03278747579315677, 1.4403219753876328, 50.12684941291809, 56.73889361321926, 31.331543661653996, 22.87177260965109, 23.821434751152992, 23.661605827510357, 40.37606343626976, 51.04344382882118, 54.18690875172615, 50.29569335281849, 2.845050785690546, 0.13102125929435715, 0.056440137850586325, 0.03482355794403702, 0.02376818662014557, 0.008142059486999642, 0.062287319015013054, 0.024050124811765272, 0.050875006199930795, 0.017896440367621835, 0.029474196453520562, 0.0369706913625123, 0.04009090655017644, 0.08900394517695531, 0.0027391506500862306, 0.06330510033876635, 0.14669326599687338, 0.2129518098081462, 0.17706595652271062, 0.08661569911055267, 0.10439870035042986, 0.18355985259404406, 0.16311717219650745, 0.10950234602205455, 0.1092574001813773, 0.10184333747019991, 0.1266785227926448, 0.14368253614520654, 0.13126642035786062, 0.1359223877079785, 4.158440809696913, 85.78293532133102, 73.85151475667953, 80.20207598805428, 62.78423622250557, 40.869801342487335, 28.403285890817642, 70.01626655459404, 59.926584362983704, 72.09002047777176, 56.07881583273411, 0.6248794379644096, 0.19260100729297847, 0.5826637032441795, 3.0632566893473268, 22.559811249375343, 15.402385164052248, 0.9569072839803994, 80.09673044085503, 71.8812520802021, 73.1034716963768, 68.17432299256325, 73.20967599749565, 70.07273152470589, 69.22375828027725, 65.28938099741936, 69.34118717908859, 64.8477990925312, 65.43835580348969, 60.45183777809143, 58.17167893052101, 49.691001400351524, 52.07518346607685, 49.533792436122894, 49.192490950226784, 49.40111115574837, 48.76426912844181, 49.32375110685825, 51.96436621248722, 51.03044092655182, 52.61156268417835, 50.24495467543602, 51.66884087026119, 51.50307476520538, 49.84407998621464, 49.34414081275463, 55.25518722832203, 50.754891112446785, 53.642910942435265, 53.059266060590744, 62.30334162712097, 61.540745347738266, 62.97320768237114, 58.788640424609184, 52.41958558559418, 44.099198654294014, 46.728197783231735, 43.1709198653698, 47.64678709208965, 47.332756742835045, 49.613379165530205, 53.43959145247936, 55.05780301988125, 53.26204217970371, 45.345850959420204, 44.33262012898922, 46.32639594376087, 48.07844392955303, 62.29002334177494, 58.791832253336906, 62.782636508345604, 57.57936671376228, 65.42361259460449, 41.819442585110664, 44.655181020498276, 64.66996863484383, 58.69254358112812, 51.59000650048256, 46.85950353741646, 50.892762914299965, 49.366191029548645, 48.87398824095726, 46.04435607790947, 46.219405084848404, 45.793083161115646, 46.69267728924751, 46.748948469758034, 46.613607332110405, 48.330951780080795, 57.6094800978899, 55.84467239677906, 59.262995570898056, 57.05207280814648, 50.307917296886444, 46.3905631005764, 44.70743581652641, 42.107569724321365, 46.92254215478897, 50.0531105697155, 51.35128811001778, 56.35577917098999, 58.50856505334377, 57.829085513949394, 57.44898810982704, 50.654663890600204, 48.688527792692184, 46.48356691002846, 46.63799062371254, 48.42835955321789, 52.19868063926697, 61.4449068903923, 60.6035902351141, 62.07421772181988, 62.31352128088474, 64.8565462231636, 63.211534693837166, 59.75848138332367, 53.699953481554985, 51.78998216986656, 50.440807566046715, 56.115540862083435, 60.566964000463486, 60.390984043478966, 62.78124198317528, 66.43239766359329, 64.30839523673058, 66.74396574497223, 59.34240370988846, 70.8527384698391, 50.19985489547253, 0.6198676850181073, 11.700416710227728, 9.887712579220533, 0.195196743006818, 0.12101477826945484, 2.31287794187665, 55.921519473195076, 70.19370183348656, 48.50605398416519, 29.635421074926853, 32.99108751118183, 27.730507291853428, 50.86915098130703, 58.21113221347332, 62.49361261725426, 57.700131833553314, 4.266839018091559, 0.19206900615245104, 0.24260372651042417, 0.1722445199266076, 0.1158495937124826, 0.19925265427445993, 0.1779356793849729, 0.08112373208859935, 0.14979323168518022, 0.1645876487600617, 0.1348832028452307, 0.1585261130821891, 0.15856578829698265, 0.22349857434164733, 0.09719221634441055, 0.12032409853418358], [0.008060009495238774, 0.0952952126681339, 0.05881205295736436, 0.04343028907896951, 0.01844489306677133, 0.039952458901098, 0.052751430121134035, 0.09027790845721029, 0.06658960846834816, 0.05751466749643441, 0.03586772261769511, 0.027334089318173937, 0.058891369990305975, 0.02785565400699852, 7.196041513234377, 64.72274020314217, 56.187949776649475, 53.46053592860699, 34.04344104230404, 25.98719123750925, 29.073980301618576, 45.634441673755646, 30.194678865373135, 71.91326916217804, 20.812946185469627, 0.04170044674538076, 0.10554303269600496, 0.7040216505993158, 1.4897682471200824, 13.439488392323256, 1.4749344368465245, 16.19293749332428, 86.51968538761139, 60.78446812927723, 66.23364552855492, 55.61003118753433, 66.29600018262863, 65.19096627831459, 68.63858968019485, 61.9487826526165, 65.80776438117027, 60.34361958503723, 62.435350343585014, 56.91594511270523, 55.834849923849106, 48.25916223227978, 47.67078660428524, 44.6345367282629, 43.52905064821243, 43.52568402886391, 43.575966730713844, 43.13298650085926, 43.618604242801666, 43.54856260120869, 42.22180299460888, 44.13456715643406, 46.15767739713192, 42.90469095110893, 44.80893597006798, 43.20079766213894, 45.74617087841034, 43.33132825791836, 44.271390214562416, 49.241774305701256, 55.9328618645668, 54.98974867165089, 57.17470742762089, 51.867349818348885, 45.3791181743145, 41.58930793404579, 42.16027669608593, 41.337894424796104, 42.40216791629791, 39.65368799865246, 44.2706910520792, 44.4553991407156, 47.31163747608662, 41.46981954574585, 41.086469516158104, 42.523894384503365, 43.74252699315548, 45.4674406349659, 54.01658669114113, 51.41215704381466, 56.62847153842449, 50.68293437361717, 59.13979098200798, 41.64020620286465, 41.70745499432087, 57.95001782476902, 48.700979724526405, 48.48691061139107, 44.731705114245415, 47.63561949133873, 45.97518838942051, 47.78647519648075, 45.21930634975433, 44.96937856078148, 40.087563917040825, 43.48909579217434, 39.704776257276535, 42.54229299724102, 40.60970529913902, 44.176212921738625, 52.11471654474735, 51.226544603705406, 48.19219462573528, 44.32812497019768, 40.97865790128708, 40.40734335780144, 39.43763919174671, 40.71184381842613, 42.04710356891155, 45.56147038936615, 46.70958258211613, 44.48553912341595, 42.79931500554085, 43.104598224163055, 42.84273907542229, 43.901867642998695, 42.361643090844154, 42.856878116726875, 42.53727346658707, 44.69723716378212, 50.02186484634876, 54.24581699073315, 54.77785304188728, 54.6169962733984, 51.92366659641266, 48.779228925704956, 44.37279537320137, 43.89130420982838, 44.46118623018265, 51.712884306907654, 55.48101671040058, 57.57684364914894, 56.67981058359146, 59.301077127456665, 60.5899603664875, 66.26408949494362, 55.72008468210697, 62.23194345831871, 62.66828164458275, 59.49861332774162, 12.33595160767436, 2.820952241308987, 7.538800220936537, 0.8381858607754111, 0.08224316537962295, 0.15621024125721306, 23.120011389255524, 60.025276467204094, 37.01208874583244, 38.24358746409416, 13.169066403061152, 19.542039781808853, 39.691089391708374, 51.03726916015148, 50.86747147142887, 50.48308789730072, 11.881607137620449, 0.5954623071011156, 0.11113593922345899, 0.05157859188329894, 0.03960464397096075, 0.07678926311200485, 0.045206615832285024, 0.047097682327148505, 0.08391997384023853, 0.0269701605066075, 0.02436953960568644, 0.058413864753674716, 0.04015583705040626, 0.04475907109735999, 0.0116812068336003, 0.06844687755801715, 0.009170639059448149, 0.0661916020908393, 0.03507211433316115, 0.03553680639015511, 0.044645945527008735, 0.04685764208261389, 0.047424316362594254, 0.11035544477635995, 0.056675862506381236, 0.030247527320170775, 0.011483146172395209, 0.05898523311770987, 0.12155900258221664, 0.056548469146946445, 13.31332091242075, 77.1286641061306, 60.438857674598694, 60.93349613249302, 39.43164311349392, 28.351118490099907, 26.688644997775555, 48.45989026129246, 36.54743067920208, 80.36895543336868, 22.631218917667866, 0.12787370709702373, 0.14012303261552006, 2.0150465983897448, 3.88666276820004, 14.135340303182602, 0.5921165272593498, 19.5345351845026, 88.35430294275284, 64.10116195678711, 68.65612953901291, 58.35987903177738, 69.4425505399704, 66.78893253207207, 68.01282405853271, 64.38582748174667, 68.06081548333168, 61.77589192986488, 64.30855482816696, 59.9589092284441, 57.96597696840763, 51.55338406562805, 49.3553464114666, 46.18353880941868, 47.22010798752308, 45.52348002791405, 45.06545640528202, 46.61906763911247, 47.235067784786224, 45.4903420060873, 45.62759444117546, 46.6556216776371, 48.55681546032429, 45.706128627061844, 47.333615496754646, 45.68132735788822, 48.16096790134907, 45.101725459098816, 45.68022921681404, 51.760210767388344, 57.703331261873245, 56.71303980052471, 57.50241704285145, 54.94745694100857, 46.45037569105625, 43.9015256613493, 44.260473400354385, 42.8977145254612, 43.88665705919266, 42.7210658043623, 46.29312112927437, 46.8522497266531, 49.13735970854759, 42.990307956933975, 43.17198760807514, 44.26951311528683, 45.339505299925804, 46.09609790146351, 54.92433898150921, 53.61633896827698, 59.37626749277115, 53.37232746183872, 61.91498726606369, 43.576996475458145, 42.09966994822025, 59.97377023100853, 51.51191309094429, 52.134099304676056, 46.19373366236687, 50.218565091490746, 48.67263704538345, 48.959282264113426, 47.37098269164562, 44.41965065896511, 41.39417700469494, 45.32458730041981, 41.70314222574234, 43.71581822633743, 42.826494947075844, 46.53147853910923, 54.94341015815735, 54.97695855796337, 51.14821180701256, 46.70317232608795, 44.56094227731228, 41.208864748477936, 42.14530549943447, 42.57973238825798, 45.26149928569794, 45.29559105634689, 49.30211506783962, 46.78285025060177, 45.4749870300293, 46.136527732014656, 45.46342425048351, 45.09039826691151, 43.89957256615162, 44.520660638809204, 45.120834633708, 45.78993692994118, 52.15639650821686, 56.17972321808338, 57.982943058013916, 58.08800742030144, 53.23657214641571, 52.060428857803345, 46.23703993856907, 45.07498249411583, 46.49244323372841, 56.115008890628815, 58.18844363093376, 59.22297991812229, 58.9292898774147, 62.396265640854836, 60.85815377533436, 66.58993721008301, 59.507577046751976, 64.23494517803192, 65.45353978872299, 62.95460768043995, 14.57780946046114, 2.0115339243784547, 6.737441746518016, 3.442628807388246, 0.0988194790261332, 0.018249533823109232, 23.829212933778763, 66.26327633857727, 35.80699481070042, 41.88179723918438, 19.798412024974823, 24.06503777951002, 44.91724915802479, 57.26602792739868, 57.180965691804886, 60.739634335041046, 17.96082492917776, 0.4493468179134652, 0.06904046211275272, 0.03271662295446731, 0.043840106736752205, 0.14017628913279623, 0.06109484354965389, 0.039090361606213264, 0.0490893358073663, 0.06785263991332613, 0.05812618604977615, 0.01189718108435045, 0.01851410390372621, 0.06686611042823642, 0.040440714146825485, 0.03449325398833025, 0.0862936960766092, 0.1813551693339832, 0.23018162901280448, 0.10502427147002891, 0.09601387137081474, 0.1158694238984026, 0.17110609507653862, 0.17952659167349339, 0.17508700489997864, 0.17134150431957096, 0.11065502010751516, 0.1670521727646701, 0.26979914924595505, 0.1771918692975305, 17.564969770610332, 89.37916874885559, 68.58125075697899, 71.89088836312294, 47.01867699623108, 37.01089181005955, 40.27395151555538, 61.45613148808479, 42.98799008131027, 86.80992141366005, 24.54927049577236, 0.19155181827954948, 0.30736719898413867, 2.8169448813423514, 3.384078936651349, 39.33102451264858, 5.443131923675537, 19.821898564696312, 92.55728021264076, 64.89395901560783, 71.72839388251305, 61.71249993145466, 72.02084138989449, 70.0382673740387, 71.34224340319633, 64.9138243496418, 69.95479345321655, 64.1172730922699, 67.07677468657494, 61.1226461827755, 61.002359837293625, 53.42447966337204, 51.94107346236706, 49.7962861508131, 48.40089462697506, 48.81645932793617, 48.71840938925743, 49.07204881310463, 49.059072509408, 47.60519452393055, 45.75105741620064, 48.9559156447649, 51.128699854016304, 47.23595693707466, 50.7289233058691, 48.743374049663544, 51.77306167781353, 48.62280271947384, 50.456671714782715, 52.24778540432453, 60.96800588071346, 58.73565226793289, 60.907980501651764, 58.05990032851696, 50.74415288865566, 48.01978647708893, 48.24686609208584, 46.24302461743355, 47.91687659919262, 44.01581212878227, 50.085032656788826, 50.00433258712292, 52.71680183708668, 46.60051703453064, 46.06935493648052, 48.475264236330986, 49.32977378368378, 49.49029617011547, 57.43367113173008, 55.92965103685856, 61.38582766056061, 56.030467227101326, 64.71472263336182, 46.683048605918884, 43.771713227033615, 62.50930957496166, 53.68543826043606, 54.405313432216644, 48.267255797982216, 51.935856342315674, 51.2202787399292, 52.74962067604065, 52.170277163386345, 47.874520272016525, 43.94613526761532, 49.753728434443474, 44.040734991431236, 48.91582399606705, 46.02135211229324, 49.53384943306446, 56.98186777532101, 57.458818182349205, 53.55129785835743, 49.31933954358101, 47.27951020002365, 44.57938268780708, 44.45094957947731, 45.081358551979065, 48.418966457247734, 49.16792146861553, 53.39938960969448, 49.202568009495735, 47.31790713965893, 48.56272794306278, 48.55154514312744, 48.07715579867363, 46.492895409464836, 48.014972135424614, 47.948464304208755, 50.564281940460205, 54.57728460431099, 59.36565086245537, 59.72709886729717, 61.23934932053089, 57.35551692545414, 55.04444673657417, 48.68522197008133, 48.062857165932655, 48.64779017865658, 57.84239239990711, 60.271951630711555, 61.66542425751686, 61.529535949230194, 65.40308609604836, 63.30712616443634, 69.46037918329239, 61.8441666662693, 67.63748779892921, 65.96337363123894, 64.04058560729027, 15.73324291035533, 4.037180291488767, 19.139588177204132, 3.0749265756458044, 0.2824519359273836, 0.24142748181475326, 30.432555601000786, 75.15850782394409, 50.61199977993965, 53.04397948086262, 20.46724833548069, 28.58387880027294, 53.31830956041813, 66.89826786518097, 64.37862306833267, 67.85603687167168, 21.073306314647198, 0.8157730603124946, 0.32455299398861825, 0.14492581161903217, 0.19731668784515932, 0.25848492980003357, 0.09464236019994132, 0.20090569916646928, 0.1457078571547754, 0.1272882564808242, 0.1375737998750992, 0.2133454746217467, 0.11879757497808896, 0.1406924973707646, 0.10682119653210975, 0.1466450560837984], [0.03405887124245055, 0.05766424736066256, 0.03856993425870314, 0.050840533440350555, 0.0543574414041359, 0.0689656165195629, 0.018246314757561777, 0.029543975033448078, 0.038460137220681645, 0.046304753195727244, 0.029097267070028465, 0.10123649815795943, 0.024197224047384225, 0.6020597030874342, 41.105198711156845, 68.78596097230911, 63.11059311032295, 53.51083382964134, 32.473338693380356, 22.88233794271946, 32.660045474767685, 32.309020310640335, 45.564012452960014, 68.53869304060936, 6.9040946289896965, 0.36308301554527134, 0.5340150324627757, 8.26217595487833, 9.394417349249125, 5.8393285889178514, 0.03638758964370936, 51.35047495365143, 73.58296036720276, 62.13985159993172, 63.016130179166794, 51.71471580862999, 57.96395167708397, 61.19797334074974, 67.17539459466934, 60.233053117990494, 59.769223406910896, 62.052726075053215, 59.12481598556042, 58.390220403671265, 58.04096594452858, 54.188523665070534, 48.9054049551487, 46.532280296087265, 44.46394108235836, 42.58462272584438, 42.53302909433842, 42.05064117908478, 44.922511875629425, 43.55518564581871, 44.577497988939285, 43.175164237618446, 44.01440620422363, 42.36878290772438, 43.60005363821983, 42.733206152915955, 42.55774676799774, 41.34085066616535, 42.696135342121124, 44.32622507214546, 53.8225083053112, 54.26341004669666, 53.5538437217474, 47.832775712013245, 41.75805687904358, 41.39290027320385, 40.6479312479496, 39.660922810435295, 41.55948333442211, 39.66184616088867, 40.27982600033283, 41.37866623699665, 40.33499903976917, 39.10739131271839, 43.30700196325779, 40.72043135762215, 44.531680047512054, 41.331685557961464, 49.91210773587227, 49.15920473635197, 51.832714676856995, 51.883145570755005, 61.10879972577095, 41.65296971797943, 41.616305485367775, 58.864393159747124, 49.94273789227009, 50.2897010743618, 48.09641316533089, 52.47232675552368, 48.31750050187111, 50.074210837483406, 47.08853244781494, 43.83224777877331, 40.99606476724148, 40.19510194659233, 39.669008776545525, 39.51273076236248, 39.93175707757473, 39.45787310600281, 42.8051932901144, 45.8124241232872, 43.01972217857838, 42.507327273488045, 41.007243767380714, 40.90228199958801, 41.25910185277462, 39.93600904941559, 41.259808614850044, 43.095053136348724, 43.648546636104584, 42.743264213204384, 42.054627165198326, 43.32985393702984, 42.970438823103905, 41.95344619452953, 43.53762298822403, 41.53020590543747, 43.213025406003, 43.61606977880001, 44.986363649368286, 47.213579937815666, 48.517392575740814, 46.282698288559914, 43.986109122633934, 42.54334934055805, 43.06202530860901, 45.88392488658428, 50.89818902313709, 55.75452223420143, 60.38885995745659, 59.070258513092995, 60.89205555617809, 61.569916382431984, 60.3460818529129, 55.68645268678665, 56.500798389315605, 64.05912861227989, 64.17393565177917, 62.44984656572342, 35.58507151901722, 1.696854759939015, 0.6142432149499655, 2.684318460524082, 0.040399320860160515, 0.027109424518130254, 4.897444155067205, 54.39410403370857, 49.59121495485306, 38.22429969906807, 26.684013046324253, 18.142363987863064, 17.865474745631218, 41.180890649557114, 45.07523328065872, 52.5309994071722, 33.13350006937981, 0.7515580498147756, 0.11019771613064222, 0.024433512735413387, 0.06453660535044037, 0.008932352138799615, 0.03145500901155174, 0.021280789624142926, 0.06835284744738601, 0.025103805674007162, 0.03248996363254264, 0.06744136393535882, 0.020413523270690348, 0.02863602785510011, 0.024917910668591503, 0.05401911483204458, 0.09460696717724204, 0.007924789260869147, 0.039645848009968176, 0.07206548572867177, 0.03646628698334098, 0.0393240453558974, 0.030022623177501373, 0.10940217835013755, 0.08915861617424525, 0.04111494417884387, 0.0635472334397491, 0.031187884087557904, 0.026399376583867706, 1.0569575778208673, 51.506437584757805, 78.07335421442986, 68.92925888299942, 59.90061655640602, 41.63624681532383, 33.586963936686516, 36.74551784992218, 35.340349450707436, 48.526105508208275, 74.45236131548882, 7.3493243381381035, 0.3460643521975726, 0.4016889736521989, 12.657493203878403, 12.386025320738554, 3.7131961388513446, 0.3819363273214549, 53.50106455385685, 76.36643260717392, 64.40289616584778, 64.60270464420319, 53.67285333573818, 60.34562207758427, 63.96279618144035, 70.95051482319832, 60.6626732647419, 61.7261715978384, 64.47076052427292, 63.10501500964165, 60.61120122671127, 60.390212684869766, 56.40289664268494, 51.42797939479351, 48.383784145116806, 46.23531483113766, 43.20955999195576, 43.92392545938492, 44.51134353876114, 47.0720337331295, 45.22830046713352, 46.95590056478977, 45.12183777987957, 46.333284974098206, 45.32094329595566, 45.49938552081585, 44.811455234885216, 45.00666216015816, 44.82817813754082, 45.753318294882774, 46.781345531344414, 56.19728207588196, 56.08346678316593, 56.605167388916016, 49.98375289142132, 44.633244797587395, 41.76582746207714, 43.16215753555298, 41.692897975444794, 43.91384080052376, 41.147224456071854, 43.57174135744572, 42.46516093611717, 43.817565366625786, 42.17775575816631, 45.64020216464996, 43.88615548610687, 47.5751381367445, 43.20810467004776, 52.47889660298824, 51.770219430327415, 55.13820290565491, 53.08939844369888, 61.879694759845734, 42.41829805076122, 43.26376788318157, 60.90975500643253, 52.589440271258354, 52.83306039869785, 49.724367409944534, 54.196928814053535, 52.25409306585789, 53.26105423271656, 48.646175265312195, 47.55320191383362, 44.68999855220318, 42.17828392982483, 43.024711310863495, 41.98961265385151, 42.06805184483528, 40.9734445810318, 44.22880969941616, 48.04739959537983, 45.17112873494625, 43.1173275411129, 42.70488627254963, 42.722239941358566, 43.91057297587395, 43.41252610087395, 42.800109162926674, 44.65202338993549, 45.35886526107788, 45.86372137069702, 44.43169601261616, 45.637492910027504, 44.43703092634678, 44.896958246827126, 45.483783558011055, 43.8465616106987, 45.11890433728695, 46.12062178552151, 47.04895757138729, 49.306009858846664, 52.53180876374245, 48.475161641836166, 47.12814912199974, 45.37459261715412, 45.824879854917526, 48.06348413228989, 55.03257617354393, 58.17694924771786, 60.97828812897205, 61.088892593979836, 63.42660695314407, 63.302285224199295, 62.63965018093586, 60.10389804840088, 59.08031277358532, 65.64272403717041, 65.01327261328697, 63.28793719410896, 41.439117193222046, 2.8203345369547606, 1.0216383542865515, 4.826021287590265, 0.4778459121007472, 0.026515845529502258, 4.295021630823612, 59.97595891356468, 52.4618811160326, 33.5824079811573, 21.444464698433876, 25.99900860339403, 27.916296422481537, 45.78304409980774, 52.46892973780632, 58.64147052168846, 44.289336651563644, 1.6405027150176466, 0.086283691925928, 0.039700021079625, 0.01457499554817332, 0.05573871181695722, 0.0271127344967681, 0.06236017565242946, 0.048436431388836354, 0.02720832868362777, 0.029041244197287597, 0.025422491307836026, 0.06514831315143965, 0.005483211070895777, 0.041596252922317944, 0.05441915840492584, 0.2747851051390171, 0.09552895950037055, 0.10276859524310566, 0.12171152877272107, 0.23210889747133479, 0.18000622687395662, 0.07959754249895923, 0.20409337186720222, 0.15728301572380587, 0.0921837511123158, 0.1067919039633125, 0.17619808902963996, 0.17453830543672666, 1.2943006795831025, 61.492731124162674, 87.52569660544395, 79.34992611408234, 68.87089401483536, 45.73069050908089, 35.16273558139801, 48.85851167142391, 45.36553010344505, 59.579693377017975, 79.74368378520012, 8.89719408005476, 0.49424464465118945, 0.4118135600583628, 12.829053048044443, 20.82048688083887, 15.495819300413132, 0.6474148412235081, 58.424821346998215, 77.33262196183205, 67.44819715619087, 68.5902638733387, 55.87702386081219, 61.989603862166405, 65.9070910513401, 73.0439592897892, 62.333287820219994, 61.11472740769386, 65.81743106245995, 64.66081872582436, 62.302281484007835, 63.54863740503788, 59.20575924217701, 54.06452111899853, 51.41835071146488, 48.12392368912697, 47.03630805015564, 46.2903206795454, 46.50757022202015, 49.83399532735348, 48.242617920041084, 49.75016802549362, 47.47348219156265, 47.30343371629715, 48.69882144033909, 46.686058044433594, 46.4215162396431, 47.169544100761414, 46.25487618148327, 48.12673173844814, 48.75029727816582, 59.827645272016525, 58.7696148455143, 57.88120351731777, 52.23916746675968, 46.45624257624149, 44.59086187183857, 46.069476529955864, 44.3169079720974, 45.65444380044937, 44.399982914328575, 44.793653190135956, 44.54168111085892, 44.85267922282219, 43.599377274513245, 48.319939970970154, 44.87200118601322, 50.569221675395966, 45.74273206293583, 56.156316474080086, 54.49884541332722, 56.48087225854397, 55.93432478606701, 66.23593300580978, 47.278252467513084, 46.34516693651676, 62.660150080919266, 55.43134577572346, 53.921063616871834, 54.35148932039738, 56.759716495871544, 55.77778458595276, 55.50174839794636, 52.98085726797581, 49.8623988032341, 45.98719194531441, 44.916166216135025, 45.57131186127663, 44.14932556450367, 45.74511453509331, 43.075947761535645, 47.76778019964695, 49.49549809098244, 45.430582612752914, 47.65801168978214, 45.827535912394524, 44.56428989768028, 47.13242009282112, 45.31530819833279, 46.7449776828289, 47.56251521408558, 48.600915893912315, 48.2512054592371, 47.35161133110523, 49.884654209017754, 47.11587198078632, 46.39821968972683, 48.31032268702984, 46.0805681347847, 47.95014761388302, 48.20394739508629, 50.482962504029274, 51.585689932107925, 54.88708958029747, 50.754932910203934, 48.47014591097832, 46.841055527329445, 47.71487183868885, 49.58285540342331, 56.794051453471184, 60.56755676865578, 66.28973811864853, 65.59365347027779, 65.76424911618233, 65.31585037708282, 64.6758659183979, 60.80559499561787, 62.216725274920464, 66.98943257331848, 70.2794936299324, 63.33519145846367, 46.42706774175167, 2.62342079076916, 6.012535644695163, 7.693161237984896, 0.5670315201859921, 0.12062400041031651, 6.134749911725521, 65.9595662355423, 61.890345588326454, 50.47899931669235, 37.23144717514515, 28.707697056233883, 28.53050496429205, 53.75043757259846, 60.77119164168835, 69.01094689965248, 48.558741956949234, 2.7498373948037624, 0.22673361090710387, 0.1046169362962246, 0.10602905036648735, 0.112373863812536, 0.21780569310067222, 0.12978273356566206, 0.16811820853035897, 0.13814609963446856, 0.16595594643149525, 0.15640321449609473, 0.42639272462110966, 0.09667148842709139, 0.16866808058694005, 0.1022122145514004], [0.006418798147933558, 0.03765076580748428, 0.03586028629797511, 0.05365734010410961, 0.009891692116070772, 0.06707500273478217, 0.05384744865295943, 0.0256168152554892, 0.0716788342106156, 0.01470027749746805, 0.016343060342478566, 0.029387808608589694, 0.015554655528831063, 3.2231722958385944, 58.81404586136341, 57.034722939133644, 59.02110055088997, 51.08615353703499, 21.46283481270075, 14.700115397572517, 42.363641783595085, 35.54681897163391, 58.78001868724823, 48.061314448714256, 1.162446686066687, 0.2854087116429582, 1.171562159433961, 6.471833623945713, 3.5386650916188955, 0.9824017190840095, 5.277690226212144, 80.71475967764854, 66.48705393075943, 69.17167827486992, 55.19812949001789, 52.89284259080887, 50.427154898643494, 63.374857529997826, 61.40616416931152, 66.2271098792553, 62.197741493582726, 58.41095209121704, 60.65376654267311, 58.97408187389374, 55.82242079079151, 58.23059856891632, 54.46556679904461, 47.73424319922924, 43.02853010594845, 43.81093472242355, 41.97966858744621, 43.908977061510086, 43.25311705470085, 43.224899768829346, 43.05313378572464, 43.986709490418434, 44.22186367213726, 43.486477732658386, 42.12892457842827, 42.35852725803852, 43.163312673568726, 43.22874516248703, 43.52355994284153, 41.3697899132967, 43.14766511321068, 46.45305074751377, 44.79913629591465, 41.805816516280174, 42.06477262079716, 41.38506509363651, 41.85850828886032, 40.424621030688286, 41.536889746785164, 41.01654186844826, 40.54939493536949, 40.992470160126686, 41.9713394343853, 41.04793578386307, 41.690678894519806, 41.655074805021286, 44.41696800291538, 43.17796848714352, 45.407525449991226, 46.54031686484814, 53.06449458003044, 49.26116846501827, 60.98208412528038, 34.553540870547295, 37.4327527731657, 61.94237619638443, 47.20645911991596, 51.81823365390301, 48.939747512340546, 52.142861634492874, 51.24404266476631, 51.76651082932949, 49.52986344695091, 50.82978129386902, 44.76561449468136, 42.06045605242252, 39.21442776918411, 39.42540384829044, 40.11912502348423, 40.6163739413023, 38.59641753137112, 41.93084880709648, 40.041430592536926, 40.44893592596054, 40.63125014305115, 39.5831485837698, 38.3687337487936, 42.029312923550606, 39.46276344358921, 41.18594437837601, 41.86974808573723, 42.594904974102974, 42.19675473868847, 42.89534345269203, 42.308658733963966, 41.342575773596764, 42.26696737110615, 43.67999754846096, 41.934572607278824, 44.763163626194, 40.91412216424942, 41.73442214727402, 43.62700559198856, 42.95883044600487, 42.70172864198685, 43.19646969437599, 45.12885980308056, 49.260723888874054, 54.46641035377979, 58.92269343137741, 57.1495945751667, 59.85868200659752, 59.67094928026199, 59.33339439332485, 56.406377255916595, 59.081019535660744, 60.49004092812538, 63.90237182378769, 60.54180175065994, 61.45764760673046, 54.86675687134266, 18.64671852439642, 1.170709461439401, 6.111631952226162, 0.2972170530119911, 0.1551700322306715, 0.20068830926902592, 33.53267624974251, 57.4356622248888, 53.978227749466896, 57.022829577326775, 21.50481306016445, 16.27556785941124, 31.80221300572157, 45.30574791133404, 45.735953226685524, 50.521021261811256, 5.61633612960577, 0.1355313352541998, 0.05353852597181685, 0.04386593718663789, 0.03340643808769528, 0.05978868590318598, 0.042683926003519446, 0.03176269972755108, 0.038994231217657216, 0.044721948870574124, 0.031136059915297665, 0.05794491647975519, 0.10557319357758388, 0.06458472620579414, 0.07918351315311156, 0.049059575685532764, 0.004774024955622735, 0.0495070090983063, 0.025107642577495426, 0.11942232973524369, 0.011629959681158653, 0.011743663199013099, 0.013217177929618629, 0.1315100525971502, 0.039397581058437936, 0.03486580841126852, 0.03020936423126841, 0.030473403676296584, 4.859110387042165, 72.75473400950432, 64.40637677907944, 65.99934250116348, 57.88161389529705, 32.58653461933136, 15.393539238721132, 29.453087858855724, 38.41619700193405, 64.35004860162735, 53.882647678256035, 1.2632922059856355, 0.42553091305308044, 2.013497231528163, 10.811443962156773, 3.965083435177803, 0.7195637666154653, 7.076886557042599, 83.95360708236694, 67.36568078398705, 70.61859503388405, 57.043006494641304, 53.975089117884636, 52.01235003769398, 64.46139022707939, 63.47798019647598, 68.31601738929749, 61.90072663128376, 59.681394919753075, 63.583903312683105, 62.88692571222782, 59.07203681766987, 61.34819447994232, 55.424456745386124, 49.67922583222389, 46.02556988596916, 46.11746035516262, 44.7570763528347, 46.194185838103294, 45.79662077128887, 45.614648535847664, 44.64435540139675, 45.76374873518944, 44.58195894956589, 45.59717707335949, 43.09362821280956, 45.18804922699928, 43.794755190610886, 44.28979642689228, 43.592834025621414, 42.11070455610752, 45.27837797999382, 48.65832321345806, 46.464389339089394, 44.20164495706558, 44.655325412750244, 43.73055383563042, 43.19541335105896, 42.5888404995203, 42.560269832611084, 42.22797006368637, 42.62881055474281, 43.95325228571892, 44.08012367784977, 42.2879346460104, 43.804110288619995, 44.11100462079048, 45.638883635401726, 44.680761247873306, 48.53523641824722, 48.35236743092537, 56.661856546998024, 51.855027079582214, 61.733360812067986, 36.84824913740158, 39.66784603893757, 61.89830616116524, 49.68362219631672, 54.64756183326244, 51.20403081178665, 53.50383460521698, 53.81900489330292, 55.34075103700161, 50.60157313942909, 51.658604219555855, 46.8198336660862, 45.17866753041744, 41.23931631445885, 41.66254140436649, 42.91138619184494, 43.79732385277748, 41.08786404132843, 43.67828384041786, 43.39295715093613, 42.810364812612534, 43.67026627063751, 42.04909846186638, 40.59432752430439, 43.25139954686165, 43.390726670622826, 43.49771372973919, 43.59914928674698, 44.14931036531925, 43.84822592139244, 43.47358502447605, 45.63815787434578, 42.375630140304565, 45.388720259070396, 44.83367644250393, 43.85037660598755, 46.94525733590126, 44.39947374165058, 43.47211830317974, 47.05741211771965, 45.92290319502354, 44.191434904932976, 45.363345220685005, 47.70584352314472, 51.17284968495369, 57.32700705528259, 62.37550735473633, 59.447559267282486, 61.67568750679493, 59.95459645986557, 59.96635302901268, 58.70124131441116, 61.02087624371052, 63.284844160079956, 64.66363817453384, 63.44959571957588, 60.392629355192184, 57.70154915750027, 23.2352402061224, 0.8223567414097488, 3.0699915904551744, 0.34441037219949067, 0.37398163229227066, 0.11882415870786645, 35.76386712491512, 65.52933052182198, 47.16691464185715, 44.823587983846664, 24.68459453433752, 23.82466647773981, 39.07448887825012, 51.75624378025532, 51.9568882137537, 61.26681424677372, 10.23104790598154, 0.2394752178224735, 0.11088461833423935, 0.07901304925326258, 0.029223133460618556, 0.06620879023103043, 0.020345856100902893, 0.06093915581004694, 0.05082634357677307, 0.03457688661001157, 0.022715659797540866, 0.03552229369233828, 0.030363447076524608, 0.06480686584836803, 0.08908298390451819, 0.10373720928328112, 0.1296554849250242, 0.08046434129937552, 0.19450420048087835, 0.1371121543343179, 0.1406667596893385, 0.07576568561489694, 0.1187079532246571, 0.35999330633785576, 0.12192137102829292, 0.06782630109228194, 0.1625952939502895, 0.1533549022860825, 7.193979173898697, 84.04320627450943, 71.92869633436203, 73.66016462445259, 64.51438218355179, 34.06582184135914, 22.10059069097042, 54.27009388804436, 51.25393733382225, 70.8999091386795, 58.38865868747234, 2.2096379566937685, 0.5346636101603508, 2.1549788396805525, 11.572222039103508, 12.675573583692312, 7.396085578948259, 7.677399208769202, 87.40477949380875, 71.73759698867798, 73.07487443089485, 60.46225681900978, 57.38374561071396, 54.54464055597782, 66.8336333334446, 65.8341121673584, 70.72789996862411, 63.34435656666756, 58.64677503705025, 65.83601966500282, 65.18455982208252, 60.492753982543945, 64.1878505051136, 58.056389316916466, 53.041551411151886, 48.23186829686165, 47.86728926002979, 46.404158771038055, 49.36592124402523, 47.33241856098175, 48.2955376803875, 46.38162977993488, 49.150772988796234, 48.22260059416294, 49.4920364767313, 44.47792053222656, 46.5062402933836, 46.51456944644451, 47.42116279900074, 46.7026973515749, 45.327801927924156, 46.838980838656425, 51.10965147614479, 48.8326920568943, 45.33922031521797, 48.04985046386719, 45.2418315410614, 45.35688556730747, 45.19948661327362, 45.77156111598015, 44.950835555791855, 45.611631497740746, 46.98717288672924, 47.357307225465775, 45.38320675492287, 46.48356311023235, 48.589698895812035, 49.46835994720459, 45.83546608686447, 50.72468653321266, 50.89830681681633, 59.54814746975899, 54.83458399772644, 64.84588399529457, 41.11363425850868, 45.762924179434776, 65.46918734908104, 51.568796038627625, 56.57304011285305, 52.47996814548969, 57.57719323039055, 55.8146084100008, 57.1551688760519, 53.398922234773636, 54.87411327660084, 48.03848907351494, 47.511164769530296, 44.64958772063255, 43.96262638270855, 45.94528019428253, 46.905617862939835, 43.75876732170582, 46.82233013212681, 45.34513279795647, 44.39223513007164, 45.799797400832176, 44.43137302994728, 43.48068684339523, 45.607094541192055, 44.19888250529766, 45.8583028614521, 47.72709958255291, 47.31643661856651, 47.21866026520729, 47.508679702878, 47.03562408685684, 44.02135223150253, 46.46573446691036, 47.44747258722782, 46.350828632712364, 48.242317736148834, 45.78505039215088, 45.064867436885834, 49.48888644576073, 47.34898567199707, 47.35568091273308, 46.618976444005966, 49.8644544929266, 53.70624214410782, 59.12357725203037, 64.24202799797058, 61.50097668170929, 63.93375813961029, 62.370453625917435, 63.71794871985912, 62.04997502267361, 64.16155591607094, 63.93550604581833, 66.41844481229782, 66.65478453040123, 63.549397364258766, 61.642522886395454, 24.870258271694183, 5.619925512000918, 12.783703431487083, 0.4318537737708539, 0.4114564089104533, 0.20526612846879289, 42.88098782300949, 69.93492051959038, 70.31726360321045, 71.58350765705109, 29.275787472724915, 26.752187088131905, 43.88655066490173, 62.27852135896683, 58.30942153930664, 71.05505481362343, 12.506199572235346, 0.32518224616069347, 0.2823418308980763, 0.25390727387275547, 0.1430899609113112, 0.1407710462808609, 0.10730049034464173, 0.11686082187225111, 0.12031400532578118, 0.16900749440537766, 0.17601834086235613, 0.1175815511669498, 0.27013157203327864, 0.24845204316079617, 0.1564166325260885], [0.0044429426725400845, 0.0804441623040475, 0.0625547964591533, 0.06866726573207416, 0.008751892437430797, 0.020395769242895767, 0.02885601712478092, 0.03046262398129329, 0.06688546563964337, 0.0818581020575948, 0.04240559836034663, 0.12209562730276957, 0.0710084596357774, 13.222714774310589, 77.19578370451927, 58.01221288740635, 64.72562044858932, 42.46566250920296, 19.849418587982655, 37.25004717707634, 54.98396158218384, 35.3107338398695, 73.62586006522179, 28.47418438643217, 0.15876128483796492, 0.1804135472048074, 0.5547736748121679, 8.207467440515757, 3.42591920401901, 1.3817133265547454, 33.087921515107155, 84.29004102945328, 60.8684778213501, 65.86538448929787, 55.52475996315479, 54.82231445610523, 46.53984569013119, 52.31638312339783, 60.41137374937534, 60.65803371369839, 63.68690438568592, 61.39674827456474, 55.13635240495205, 61.439290791749954, 60.79660847783089, 58.29608805477619, 58.49395863711834, 53.7185724824667, 45.08271127939224, 45.14599688351154, 43.82065840065479, 42.912754118442535, 42.95755371451378, 42.950425297021866, 43.82044181227684, 44.20451000332832, 40.67977733910084, 42.611738070845604, 42.314814403653145, 41.79986983537674, 41.069370433688164, 42.35580660402775, 41.28884665668011, 41.24276652932167, 42.51302316784859, 40.08904963731766, 41.67293764650822, 42.9221548140049, 42.274202182888985, 40.10799542069435, 41.43893860280514, 40.02804771065712, 40.46171844005585, 39.9417619407177, 41.39559052884579, 40.6910665333271, 40.900758281350136, 39.38115142285824, 40.93562141060829, 40.68485386669636, 46.46443493664265, 43.817109391093254, 48.537166714668274, 46.130995228886604, 52.72272951900959, 48.641132935881615, 61.14761084318161, 34.77001905441284, 41.33896976709366, 61.90905198454857, 48.07276703417301, 52.210547402501106, 50.537253990769386, 53.643572106957436, 50.83562918007374, 51.40783287584782, 52.0573890209198, 50.914543345570564, 45.735105872154236, 46.34858675301075, 41.10298343002796, 40.318021550774574, 40.6124297529459, 39.110936522483826, 39.84230987727642, 40.19432298839092, 41.397938802838326, 40.847891718149185, 40.341029316186905, 41.23713903129101, 40.71008451282978, 41.02806285023689, 39.75644588470459, 40.725789070129395, 39.82435204088688, 42.277477607131004, 40.19859775900841, 43.3660051971674, 40.65370313823223, 42.09449842572212, 44.83436420559883, 43.16237412393093, 40.714271888136864, 43.677189499139786, 42.068519219756126, 43.02052013576031, 41.69197082519531, 42.17399016022682, 41.3092515617609, 43.63471157848835, 47.508805096149445, 57.850713953375816, 61.53752312064171, 60.10520897805691, 58.47696214914322, 53.321341797709465, 55.47790087759495, 57.05494925379753, 60.27861647307873, 59.44771885871887, 60.97482271492481, 62.78758384287357, 62.33873672783375, 62.22471624612808, 68.02491500973701, 34.10428337752819, 0.16085356241092086, 4.355056984350085, 0.7800932123791426, 0.22487537702545524, 0.12275401619262993, 10.061686243861914, 60.96954099833965, 41.59390568733215, 34.53333355486393, 54.9686674028635, 28.535845577716827, 14.504821076989174, 33.64608496427536, 42.13971219956875, 51.268425956368446, 18.980099335312843, 0.11890346460859291, 0.06402430823072791, 0.12118398793973029, 0.024814193675410934, 0.06000082510581706, 0.025850914607872255, 0.04228023477480747, 0.010953293549391674, 0.024801846193440724, 0.02900973446230637, 0.0317278596048709, 0.03402527050639037, 0.012434779873728985, 0.06359228180372156, 0.018895469474955462, 0.0788424962956924, 0.03877345341606997, 0.008720591431483626, 0.012631516729015857, 0.03489576149149798, 0.04841349902562797, 0.04043814631586429, 0.02130770546500571, 0.056286502149305306, 0.07925072204670869, 0.06256741296965629, 0.07702444971073419, 18.4480157867074, 85.0195486843586, 63.604821190238, 67.4301253259182, 48.334063813090324, 26.506516970694065, 33.55976119637489, 51.17696866393089, 38.9324676990509, 79.39582005143166, 27.359293811023235, 0.181722606648691, 0.2842324966331944, 3.211632315069437, 12.81321169808507, 2.683936581015587, 0.38958362478297204, 34.21092085540295, 85.98346576094627, 62.52170071005821, 69.33799535036087, 57.764086201786995, 56.77542105317116, 48.01231227815151, 55.568271428346634, 62.39913448691368, 63.09257447719574, 65.42048156261444, 62.49662205576897, 56.20225980877876, 63.92178118228912, 61.965988129377365, 60.37036255002022, 61.26168832182884, 57.01478160917759, 46.424293890595436, 48.25809448957443, 45.78182056546211, 45.23955166339874, 45.38370072841644, 45.380341708660126, 45.82954220473766, 44.978053495287895, 43.554444685578346, 45.29682219028473, 44.681300818920135, 43.69904212653637, 42.27368541061878, 44.36888538300991, 43.64082545042038, 43.458769619464874, 42.89724715054035, 42.29525685310364, 43.69870014488697, 44.204126223921776, 44.812389984726906, 42.900492176413536, 43.24940085411072, 43.30016992986202, 42.630733251571655, 42.708157896995544, 42.493503615260124, 43.031820729374886, 42.07392632961273, 42.53148637712002, 42.68542751669884, 43.47366102039814, 48.49295608699322, 47.688155472278595, 50.31596526503563, 49.57726590335369, 56.84752598404884, 50.424103662371635, 63.44534374773502, 36.72151833772659, 45.02618171274662, 61.8400514870882, 49.3289378285408, 54.884425923228264, 52.74101413786411, 54.76159751415253, 51.862273290753365, 54.134399369359016, 53.04545380175114, 53.21074493229389, 49.547840282320976, 48.302498906850815, 43.217756152153015, 41.99076399207115, 41.478030905127525, 41.19284100830555, 41.5380372852087, 43.12079295516014, 41.96306727826595, 43.220465406775475, 42.536559104919434, 44.24857623875141, 41.93171516060829, 42.25539319217205, 41.958385929465294, 43.321729972958565, 43.09003360569477, 44.592564180493355, 42.68451176583767, 45.54502107203007, 43.59328240156174, 43.19018483161926, 46.98253333568573, 45.00405929982662, 42.47865401208401, 45.814202427864075, 43.30150365829468, 44.228213131427765, 44.53366734087467, 43.250111415982246, 44.14374366402626, 44.88178566098213, 50.25929130613804, 60.4136498272419, 63.57818461954594, 62.83638082444668, 58.34490403532982, 57.44511991739273, 56.62288583815098, 59.76273335516453, 61.16596005856991, 61.30891978740692, 62.70315997302532, 62.623611241579056, 64.72087070345879, 64.38374519348145, 68.13977524638176, 36.753873601555824, 0.7354434113949537, 2.933143121190369, 2.532162037678063, 0.6343694881070405, 0.1588592038024217, 10.312960110604763, 69.81061398983002, 46.099498718976974, 32.48732574284077, 46.09534174203873, 33.63140255212784, 21.827508844435215, 38.094339072704315, 45.7961305975914, 59.99001435935497, 30.49681395292282, 0.024409838224528357, 0.042006649455288425, 0.041650945495348424, 0.020551069210341666, 0.00468711621579132, 0.0766373825899791, 0.02562357251008507, 0.024406624725088477, 0.00733764422875538, 0.06448948639445007, 0.05273542570648715, 0.03883616118400823, 0.04676874392316677, 0.012762477963406127, 0.09692016727058217, 0.17833675083238631, 0.09493381643551402, 0.19468513608444482, 0.08346063637873158, 0.1335262303473428, 0.12099788698833436, 0.09998240959248506, 0.15074516966706142, 0.18281350436154753, 0.17684552381979302, 0.2749347814824432, 0.21480636263731867, 25.059170834720135, 94.60118293762207, 72.92369574308395, 78.45922350883484, 55.411218255758286, 29.27011627703905, 49.642637595534325, 74.11951437592506, 49.728467389941216, 86.02908611297607, 34.54478234052658, 0.5396566609852016, 0.2506804157746956, 3.2692075381055474, 16.97980687022209, 13.304201401770115, 2.5530692283064127, 38.98104049265385, 87.47988626360893, 66.01879745721817, 70.42808085680008, 60.68975441157818, 60.021153688430786, 51.94371432065964, 57.454934790730476, 66.20381712913513, 65.64873531460762, 68.94252017140388, 65.213613063097, 57.89612911641598, 65.7338659465313, 66.08166128396988, 63.28572951257229, 65.0228177011013, 59.20673578977585, 49.86192762851715, 51.20093397796154, 48.301556557416916, 47.432246804237366, 46.948228776454926, 47.84083127975464, 49.885984137654305, 48.38458210229874, 44.85691599547863, 47.46123164892197, 46.93970963358879, 46.2412691116333, 43.333847522735596, 46.50584891438484, 45.24172894656658, 45.8309481292963, 45.873011872172356, 43.195185363292694, 45.998002365231514, 48.243305683135986, 46.48433066904545, 45.54096668958664, 46.14441990852356, 43.88962469995022, 44.98683102428913, 44.79067035019398, 44.506460800766945, 47.101637944579124, 45.09424366056919, 44.658935219049454, 44.37795929610729, 45.84952153265476, 52.16394670307636, 49.861099272966385, 52.52188369631767, 52.482430413365364, 60.561450496315956, 54.1254660487175, 65.46601071953773, 39.10316973924637, 47.794865146279335, 65.91921240091324, 51.14614471793175, 54.66762475669384, 54.427147060632706, 57.476517632603645, 54.19100873172283, 54.14583295583725, 56.27298541367054, 56.505472138524055, 50.257976576685905, 51.492271944880486, 45.69667473435402, 46.15885153412819, 45.10007634758949, 43.72760899364948, 43.83469484746456, 44.518422558903694, 45.275113955140114, 44.73469935357571, 45.73765553534031, 46.62954367697239, 44.7487585991621, 43.80383290350437, 43.578307405114174, 45.05312606692314, 46.08977884054184, 47.535415068268776, 44.66644361615181, 49.16808485984802, 45.57947762310505, 44.77557756006718, 49.42820370197296, 48.423374220728874, 44.00311321020126, 47.76709623634815, 44.58664409816265, 46.82882398366928, 47.63536110520363, 45.55352121591568, 45.59837020933628, 47.138967141509056, 52.2180861979723, 65.02490758895874, 66.20546624064445, 65.65210953354836, 60.151589289307594, 56.54774866998196, 58.8270715624094, 61.95623405277729, 63.41267690062523, 64.01208713650703, 64.83223512768745, 65.93318045139313, 66.11713618040085, 67.3763658106327, 68.82990941405296, 40.69223307073116, 1.297735101543367, 10.28404651209712, 3.4839513525366783, 0.8153863716870546, 0.27145001222379506, 13.212586417794228, 74.95893493294716, 54.37906064093113, 47.646532505750656, 64.62704613804817, 39.001920372247696, 23.48443653434515, 49.35060426592827, 55.182698518037796, 68.73352378606796, 38.401108011603355, 0.2919489028863609, 0.2048094553174451, 0.17538465064717457, 0.10131365183042362, 0.11070184962591156, 0.1726202544523403, 0.13162415038095787, 0.12371765042189509, 0.14845298719592392, 0.15070772089529783, 0.1973496688879095, 0.10550036662607454, 0.13279650622280315, 0.1733612740645185], [0.07134411818697117, 0.056550087028881535, 0.04795559019839857, 0.04551410616841167, 0.04629469709470868, 0.08378752274438739, 0.03314137262350414, 0.07907504827016965, 0.02565372040407965, 0.0528854248841526, 0.02703364381886786, 0.10527433812967502, 0.02711258606723277, 30.292322225868702, 77.0611797273159, 52.32359893620014, 57.429962530732155, 24.132235273718834, 26.799296960234642, 41.837434619665146, 31.96768842637539, 43.76073941588402, 71.89339622855186, 11.81782091036439, 0.18413483892800286, 0.12727305729640648, 1.3723031315021217, 5.199687061831355, 2.7095479192212224, 7.9887777753174305, 66.31075859069824, 72.17676982283592, 64.0380397439003, 62.39715099334717, 52.67169065773487, 52.67134487628937, 50.23360088467598, 45.53335949778557, 49.67504225671291, 61.48652605712414, 60.85382200777531, 62.82803647220135, 59.38145041465759, 59.71768297255039, 59.446331933140755, 62.54177123308182, 57.11566619575024, 55.82612179219723, 49.02605228126049, 41.762058064341545, 43.69629867374897, 44.44971464574337, 41.804942563176155, 43.46407413482666, 43.6632214486599, 43.22505936026573, 42.68155552446842, 42.45599962770939, 43.83470244705677, 43.72947849333286, 41.89682923257351, 43.33638958632946, 42.222794741392136, 42.29489587247372, 40.85679084062576, 42.357254326343536, 42.69730567932129, 39.75022181868553, 40.09001098573208, 42.083885595202446, 41.44140087068081, 42.4320001155138, 39.66670610010624, 40.52510283887386, 39.578026458621025, 40.89853160083294, 40.31809374690056, 39.55803953111172, 41.88251540064812, 43.58974099159241, 44.404922649264336, 44.08661372959614, 47.864477410912514, 47.94928506016731, 51.96395583450794, 48.659132570028305, 58.79479989409447, 36.423283740878105, 44.50663939118385, 56.54500141739845, 48.47981259226799, 53.96623559296131, 51.037314757704735, 53.19594852626324, 50.707135275006294, 52.680373191833496, 52.28786565363407, 50.77912621200085, 46.868805438280106, 46.96557104587555, 42.100091725587845, 40.334486067295074, 39.458967447280884, 41.534644067287445, 38.861688897013664, 40.000654980540276, 38.60829949378967, 40.04161678254604, 39.85856540501118, 41.355020105838776, 40.53656302392483, 41.048114374279976, 41.73100993037224, 41.718668192625046, 40.57072699069977, 43.38109038770199, 41.76029875874519, 41.996254697442055, 44.203472658991814, 42.51285597681999, 42.34404243528843, 43.05773913860321, 43.46095450222492, 41.343803107738495, 41.32829234004021, 42.68625967204571, 42.44431525468826, 42.299440428614616, 42.64861509203911, 46.07154741883278, 54.521431401371956, 57.66703560948372, 55.72065085172653, 51.819783970713615, 44.80555035173893, 51.949945986270905, 56.78400859236717, 59.6835608035326, 56.9746595621109, 60.093346014618874, 58.513660579919815, 61.3269080221653, 60.473690405488014, 64.10162553191185, 59.02432277798653, 61.14573374390602, 5.049520544707775, 1.6692130244337022, 0.4203121305909008, 0.140056076052133, 0.11405671335523948, 0.688300053589046, 38.23029197752476, 58.07474233210087, 37.15876467525959, 71.60261303186417, 43.22986990213394, 16.033724136650562, 33.29010106623173, 37.33683452010155, 53.43120150268078, 31.193308979272842, 0.04425944614922628, 0.03950335565605201, 0.03496101482596714, 0.02647910365340067, 0.014337324610096402, 0.048947515097097494, 0.08130103116855025, 0.06254011677810922, 0.04275817787856795, 0.007605514547321945, 0.0718439843330998, 0.050874787266366184, 0.10061725755804218, 0.04050538489536848, 0.13014648982789367, 0.04254275467246771, 0.07744195230770856, 0.0029527593051170697, 0.056308109778910875, 0.12325651696301065, 0.07971987812197767, 0.0963699389831163, 0.04011992823507171, 0.08261020193458535, 0.02707224848563783, 0.03483203698124271, 0.11099884970462881, 40.57798460125923, 85.66393330693245, 58.35360936820507, 65.22388771176338, 32.657465413212776, 34.3036662787199, 34.22195926308632, 32.90091834962368, 50.57999789714813, 77.15679779648781, 12.75793606415391, 0.2956561680184677, 0.6802731030620635, 3.502228846773505, 8.0912459269166, 0.3739499277435243, 9.228559099137783, 67.24303096532822, 74.67969551682472, 66.23768091201782, 65.98937943577766, 54.31131027638912, 54.60626184940338, 52.11119793355465, 48.23864333331585, 53.163232281804085, 63.475126549601555, 63.59768137335777, 65.0871254503727, 59.80340637266636, 61.79432854056358, 58.95181506872177, 65.39618566632271, 59.37733143568039, 58.53666074573994, 51.4744509011507, 44.6674657613039, 45.04070073366165, 46.84821434319019, 44.23418641090393, 45.706162825226784, 44.80905756354332, 44.45387922227383, 45.018194541335106, 43.229915499687195, 46.7391411960125, 45.62331207096577, 44.389632269740105, 44.400659278035164, 43.315391913056374, 43.849799036979675, 42.64110669493675, 44.10156212747097, 45.23187227547169, 42.58835792541504, 43.352257534861565, 43.57276730239391, 43.48181538283825, 44.597469717264175, 42.13389851152897, 42.9067238420248, 41.03195384144783, 41.425798907876015, 44.11129340529442, 43.925517573952675, 45.09971536695957, 44.55801263451576, 45.95232501626015, 45.598184019327164, 51.657737866044044, 50.903223752975464, 54.26094777882099, 51.77374944090843, 59.93297941982746, 37.94661819934845, 47.532774209976196, 59.725685343146324, 50.805063620209694, 55.1640909165144, 54.37382832169533, 53.85372743010521, 52.90738061070442, 54.02414828538895, 52.4928342550993, 53.29538159072399, 50.221848115324974, 48.66942621767521, 44.24303613603115, 42.52294063568115, 41.541916877031326, 44.22986224293709, 41.75192020833492, 41.92492492496967, 40.96176780760288, 42.55811154842377, 41.310376301407814, 44.1021890938282, 41.20603770017624, 45.290696918964386, 43.54241833090782, 44.27304692566395, 42.709031850099564, 45.630307495594025, 42.35676035284996, 44.39239852130413, 43.505187928676605, 44.18870285153389, 42.94475220143795, 44.276003167033195, 43.658152520656586, 43.08609701693058, 44.08146880567074, 44.6695214509964, 44.27174359560013, 43.43171887099743, 43.554425686597824, 47.705623134970665, 56.64390631020069, 61.593292728066444, 58.62500220537186, 55.40195435285568, 45.86443953216076, 54.60925228893757, 57.91686840355396, 61.46858721971512, 59.5188282430172, 62.55033977329731, 60.29054403305054, 63.570436835289, 61.18234097957611, 64.34388533234596, 61.45604029297829, 64.85931247472763, 7.163673425093293, 0.9435539692640305, 4.371656393632293, 1.2199406884610653, 0.09007997025037184, 0.6788612413220108, 41.361947134137154, 63.942216485738754, 37.37928584218025, 67.03099474310875, 39.24025498330593, 20.614933110773563, 41.50646097958088, 43.521926030516624, 58.84914077818394, 40.912461653351784, 0.8049531409051269, 0.09882832542643882, 0.06819745656684972, 0.06214502704096958, 0.07690035519772209, 0.0792898035433609, 0.1424424073775299, 0.03167202041368, 0.03656010558188427, 0.01774728352756938, 0.03505175351165235, 0.05456974387925584, 0.031959721382008865, 0.030923262056603562, 0.20020341966301203, 0.08128137167659588, 0.18292803259100765, 0.12343991649686359, 0.1782750486745499, 0.23171469831140712, 0.23160236683906987, 0.24209278752095997, 0.13437612302368507, 0.14707239955896512, 0.07888484324212186, 0.21027430426329374, 0.1792495627887547, 49.235326051712036, 95.48506870865822, 68.0595463514328, 73.11083570122719, 36.989966332912445, 35.724843218922615, 53.78129571676254, 45.21119378507137, 56.71203285455704, 83.20133864879608, 14.591930452734232, 0.29610380181111395, 0.5885649647098035, 8.221953213214874, 10.584772825241089, 5.268723182380199, 11.319213565438986, 68.14125716686249, 76.31413221359253, 67.0438988506794, 68.1077353656292, 56.28481037914753, 58.46959054470062, 55.16328535974026, 50.52891343832016, 55.41608199477196, 67.12566286325455, 65.49017742276192, 68.36356043815613, 61.56416729092598, 63.04265655577183, 62.13548183441162, 67.86116659641266, 61.03164106607437, 61.728728860616684, 53.27493868768215, 44.588414803147316, 47.43593640625477, 49.531710147857666, 46.78535811603069, 48.666781559586525, 47.54113756120205, 46.39811709523201, 47.293284460902214, 46.547536477446556, 49.7137887775898, 47.57466696202755, 46.702146381139755, 47.58271872997284, 45.72125941514969, 46.72498315572739, 44.940906688570976, 46.22083380818367, 45.89150547981262, 42.46140293776989, 46.03638030588627, 46.25282049179077, 45.37442162632942, 47.9065715521574, 44.432577565312386, 45.555196925997734, 43.57564754784107, 43.49390633404255, 45.763874128460884, 44.02208559215069, 48.95246163010597, 47.914874106645584, 50.0064604729414, 48.92390616238117, 54.71272073686123, 53.90771113336086, 55.77105134725571, 55.121043026447296, 61.423179656267166, 41.597492694854736, 50.99387548863888, 61.70766659080982, 53.93236041069031, 58.33469018340111, 55.84503337740898, 56.16621874272823, 55.78440003097057, 55.71169473230839, 57.1251504868269, 55.55507853627205, 52.52997726202011, 51.92397817969322, 45.556568652391434, 45.66933900117874, 44.299257919192314, 46.23020030558109, 42.60841704905033, 43.73832821846008, 43.274171724915504, 46.07235677540302, 44.40580800175667, 45.93807578086853, 44.02145102620125, 45.29015734791756, 45.58744199573994, 46.745965629816055, 45.14703042805195, 47.125519663095474, 44.84940379858017, 47.10784301161766, 46.61810249090195, 47.7640525996685, 46.29961118102074, 45.732609406113625, 46.90998002886772, 45.52428558468819, 45.2120753377676, 47.05888643860817, 47.328185588121414, 46.41016624867916, 46.959616765379906, 50.21204464137554, 58.434203043580055, 64.72483769059181, 60.550062507390976, 56.77358195185661, 48.39256927371025, 54.12682257592678, 59.14616324007511, 63.55447769165039, 62.08019860088825, 64.92757201194763, 62.577930092811584, 67.71754190325737, 64.60958987474442, 68.93059641122818, 64.30279433727264, 65.4826158285141, 7.839884664863348, 5.884599359706044, 6.6420008428394794, 1.6478512831963599, 0.3509803977794945, 0.9973106347024441, 47.17098422348499, 70.81729397177696, 52.39813573658466, 77.49586120247841, 50.29528297483921, 26.05281751602888, 47.43538163602352, 51.886645182967186, 66.11971244215965, 53.66736263036728, 2.314325664192438, 0.3145521384431049, 0.12988878646865487, 0.2291801749379374, 0.22455389349488541, 0.08985385269625112, 0.2124798484146595, 0.23832851060433313, 0.10988226626068354, 0.08287029500934295, 0.21970455214614049, 0.17159263225039467, 0.12952678167494014, 0.1454050312167965], [0.029137560122762807, 0.060531015406013466, 0.06022781097271945, 0.06474128967965953, 0.03700789893628098, 0.03747091373952571, 0.07217947219032794, 0.028938857503817417, 0.07399863941827789, 0.05652135478158016, 0.07383630203548819, 0.08082511412794702, 2.5744019960984588, 51.3822640478611, 65.23331880569458, 54.60982985794544, 38.740205615758896, 13.978677559643984, 25.171779692173004, 91.66623562574387, 47.3460940271616, 52.60074846446514, 60.350801199674606, 2.006362876854837, 0.06190415930177551, 1.0332778422161937, 6.220043459907174, 5.125474669039249, 1.4728052448481321, 46.37201249599457, 65.16789391636848, 67.43352234363556, 64.61415722966194, 60.81971123814583, 54.16009359061718, 50.81618182361126, 46.29582658410072, 46.344672963023186, 44.63405415415764, 52.42730297148228, 57.04869098961353, 61.06798231601715, 59.72513057291508, 60.115780010819435, 56.306852996349335, 57.92025402188301, 58.29685561358929, 55.976973697543144, 49.58276800811291, 42.65959270298481, 42.406552881002426, 43.93091328442097, 43.605088368058205, 42.103925719857216, 44.41989004611969, 43.85688565671444, 43.169931918382645, 43.00579212605953, 42.207093983888626, 42.810759991407394, 42.84481756389141, 42.627936601638794, 43.044219464063644, 41.02632634341717, 42.09325589239597, 40.97615763545036, 41.44965022802353, 42.36780256032944, 42.22734309732914, 44.07053679227829, 42.890054136514664, 42.29906804859638, 40.553840696811676, 41.70186549425125, 40.76582372188568, 40.59928245842457, 42.70449869334698, 41.00044593214989, 43.22499096393585, 43.939717411994934, 45.247075259685516, 44.460061490535736, 50.398823618888855, 46.94824017584324, 52.6627991348505, 51.33754804730415, 62.14777037501335, 30.944912508130074, 45.106946378946304, 55.451074317097664, 49.27083894610405, 51.39338605105877, 51.128262877464294, 53.10526639223099, 50.78489810228348, 51.970415487885475, 50.888697132468224, 51.09624579548836, 49.79955017566681, 47.86649890244007, 46.39311656355858, 44.92593549191952, 38.73014755547047, 40.6378997862339, 41.893489211797714, 40.06581008434296, 39.578892812132835, 40.468250289559364, 40.42828403413296, 41.941913813352585, 42.630672454833984, 41.772735491395, 41.817075312137604, 43.27345736324787, 40.60839056968689, 42.8567299246788, 40.92454880475998, 43.242169842123985, 41.94644697010517, 43.104564025998116, 40.54106578230858, 42.0982526242733, 40.72055675089359, 42.26955123245716, 42.782341316342354, 43.58603619039059, 40.129772052168846, 42.2073295712471, 44.28554065525532, 50.46171024441719, 57.32750102877617, 60.9583505988121, 57.34104350209236, 57.165314331650734, 54.36841741204262, 56.98850601911545, 57.174927815794945, 59.58345517516136, 57.51315526664257, 59.98440586030483, 56.47752843797207, 57.98153713345528, 58.56176979839802, 61.821109503507614, 58.70992384850979, 67.36759588122368, 29.09395392984152, 0.6504102679900825, 3.792222160845995, 0.5766614503227174, 0.02148491177649703, 0.012949287665833253, 14.462145566940308, 60.01154400408268, 37.3021499812603, 65.9162637591362, 61.47178664803505, 17.01302468776703, 18.166942968964577, 36.344494968652725, 45.71241728961468, 38.30070219933987, 0.5425261007621884, 0.1600758807035163, 0.09341498895082623, 0.0821990001713857, 0.10813421162310988, 0.028442724360502325, 0.05496105608472135, 0.06857296102680266, 0.03362730494700372, 0.029373856232268736, 0.022715153281751554, 0.02432710174616659, 0.011047003608837258, 0.03766757916309871, 0.06231655221199617, 0.05242936029389966, 0.0825399650784675, 0.025692449380585458, 0.04213942709611729, 0.005530344405997312, 0.05622116346785333, 0.024538101752114017, 0.09636333386879414, 0.06300076041952707, 0.04607085793395527, 0.07700730609940365, 4.061527010053396, 65.23689821362495, 72.8594183921814, 61.74870818853378, 46.77542544901371, 21.989459954202175, 29.728763066232204, 76.17180705070496, 46.48491583764553, 60.115719214081764, 65.3340058028698, 2.227620966732502, 0.13499915599822998, 0.8229623932857066, 7.3773411847651005, 4.947560615837574, 2.894209697842598, 48.11583772301674, 67.53323659300804, 71.38887450098991, 65.67197486758232, 62.255984768271446, 53.31510253250599, 52.846070900559425, 49.83115307986736, 49.012259021401405, 46.16049684584141, 54.0816468000412, 61.10156871378422, 63.37687522172928, 62.00149342417717, 60.63922852277756, 58.30516956746578, 59.638415426015854, 60.7883021235466, 59.33087132871151, 52.0780561119318, 45.3588804602623, 44.99128058552742, 45.87520435452461, 44.600315764546394, 44.111984968185425, 44.97480846941471, 45.511480271816254, 45.7291553914547, 44.50723595917225, 44.25849750638008, 45.89831091463566, 43.04891601204872, 43.88421379029751, 45.0909074395895, 43.20384129881859, 43.44746522605419, 43.12379479408264, 42.568519189953804, 42.9304763674736, 44.93114501237869, 45.54714135825634, 43.85099217295647, 43.666702061891556, 41.97659835219383, 43.40583845973015, 42.01153747737408, 43.75744879245758, 44.862657487392426, 42.86491468548775, 44.828820303082466, 46.6109474748373, 46.92279674112797, 47.576266676187515, 51.9020077586174, 51.080294251441956, 54.633893966674805, 53.385459557175636, 61.56916782259941, 32.902662456035614, 46.33687578141689, 58.82516786456108, 52.03265994787216, 54.802183136343956, 51.427272632718086, 55.760518312454224, 54.21236738562584, 53.73705469071865, 52.803991958498955, 54.202381521463394, 51.4105649292469, 51.93888857960701, 48.53313133120537, 46.44919775426388, 39.96074192225933, 43.59429694712162, 42.56562374532223, 41.4187540858984, 41.55850298702717, 41.421691328287125, 42.291267067193985, 43.835504204034805, 44.15559142827988, 44.0633437782526, 44.410280361771584, 44.44151848554611, 43.337559923529625, 43.30530345439911, 44.14834141731262, 46.72355443239212, 42.76604779064655, 45.083323046565056, 42.456090822815895, 43.41200552880764, 42.42983043193817, 43.5281652957201, 44.109017327427864, 45.42866751551628, 41.52070261538029, 44.398789778351784, 45.24907775223255, 52.956861555576324, 59.72572714090347, 62.36384578049183, 57.50558227300644, 56.74650460481644, 55.94455383718014, 59.905035719275475, 60.13467259705067, 61.294206976890564, 59.6180485188961, 62.9544822871685, 57.092571035027504, 60.05123667418957, 61.75188101828098, 64.44593265652657, 60.702107548713684, 69.35562640428543, 32.499937266111374, 0.6155810400377959, 2.3959015868604183, 2.0346499839797616, 0.19044419255806133, 0.03187742091540713, 12.928463313728571, 68.76604244112968, 41.028355434536934, 60.064421966671944, 51.95601426064968, 22.853522188961506, 26.001609563827515, 42.39082172513008, 51.987590566277504, 51.363762840628624, 5.380166927352548, 0.19653810071758926, 0.04118488046515267, 0.0660218506527599, 0.06491450694738887, 0.09205829846905544, 0.04533127437753137, 0.018929543330159504, 0.06769413943402469, 0.03677152119053062, 0.05002347337722313, 0.08653965123812668, 0.051180800728616305, 0.06501440002466552, 0.17267269460717216, 0.09026088358950801, 0.21184603945584968, 0.1541409405763261, 0.16513210313860327, 0.11456783046014607, 0.16546373924938962, 0.12977929000044242, 0.17584613291546702, 0.16774489340605214, 0.14608513534767553, 0.15677565388614312, 5.047644395381212, 76.40422537922859, 80.19990250468254, 70.87660118937492, 56.92181959748268, 23.568290434777737, 34.04054559767246, 100.56552529335022, 62.4879015237093, 65.99136292934418, 72.12865680456161, 2.983804615214467, 0.19509940291754901, 3.2521901512518525, 17.015011981129646, 13.39026678353548, 3.590072770603001, 52.957917898893356, 68.48295003175735, 73.30214023590088, 67.03845754265785, 65.2110444009304, 58.278700187802315, 56.363089978694916, 51.31988279521465, 51.98762856423855, 47.779901549220085, 58.815018609166145, 62.41736590862274, 65.83940148353577, 64.33269113302231, 64.42377224564552, 61.121126264333725, 62.659420520067215, 62.904678359627724, 60.796521082520485, 54.18690115213394, 47.45952174067497, 45.665979981422424, 47.87213779985905, 47.86989971995354, 46.02964706718922, 48.812173157930374, 48.60734134912491, 48.80472935736179, 46.18217088282108, 46.09108217060566, 47.33590677380562, 45.58798536658287, 46.88101798295975, 47.32625909149647, 45.8756223320961, 45.86969085037708, 45.36413557827473, 44.753238558769226, 44.787341728806496, 46.24036855995655, 48.72864603996277, 45.92195704579353, 46.62822514772415, 44.8086965829134, 46.141687855124474, 44.00117911398411, 46.20916463434696, 47.44529150426388, 45.78074902296066, 46.777906715869904, 49.80587303638458, 49.08912889659405, 49.31584373116493, 55.19477427005768, 52.10260659456253, 56.41235053539276, 57.63276144862175, 64.76379320025444, 36.995643228292465, 51.555762737989426, 61.925600096583366, 54.667457565665245, 56.906757205724716, 55.169148445129395, 58.179734498262405, 56.550868302583694, 56.9989250600338, 56.21837854385376, 56.94562152028084, 55.0804004073143, 55.63859425485134, 50.65016113221645, 48.54868769645691, 42.47274912893772, 45.011411905288696, 44.408676847815514, 44.127241149544716, 44.15539003908634, 43.65206524729729, 44.96215134859085, 45.49161873757839, 47.35389120876789, 46.94681905210018, 46.5310263633728, 46.37516252696514, 45.46612210571766, 46.1576621979475, 45.472585558891296, 48.3144910633564, 46.331784054636955, 47.163954600691795, 45.732806995511055, 46.41253352165222, 44.580104649066925, 47.88900129497051, 47.93144881725311, 49.3666660040617, 43.653212785720825, 46.12629488110542, 48.2279697060585, 55.01121371984482, 61.336251720786095, 64.4859217107296, 59.798052459955215, 58.577554151415825, 57.72777535021305, 62.0989315956831, 62.60957859456539, 65.08306726813316, 62.84478597342968, 65.62454581260681, 60.3422212600708, 64.0499559044838, 65.52001342177391, 69.17831271886826, 63.85194852948189, 71.86596170067787, 33.60432140529156, 1.894391078967601, 10.128074381500483, 2.2883588075637817, 0.1717208159971051, 0.15712513122707605, 18.691778406500816, 73.69070738554001, 50.84208883345127, 74.12557125091553, 69.59511235356331, 28.117976300418377, 30.268085226416588, 54.1420141607523, 59.96172487735748, 64.2159765958786, 9.618535973131657, 0.5291278415825218, 0.17010725336149335, 0.15799912885995582, 0.13943556637968868, 0.14175218035234138, 0.17776292224880308, 0.1099433598574251, 0.14058669679798186, 0.11465875097201206, 0.1728327016462572, 0.27094392688013613, 0.189479578693863, 0.19822696165647358], [0.0799342623213306, 0.07297953707166016, 0.08502627111738548, 0.004174601090198848, 0.049284431588603184, 0.03293796478828881, 0.10449566936586052, 0.02980128505441826, 0.023458631258108653, 0.09190244745695964, 0.24859315512003377, 0.19365812244359404, 8.105104733258486, 66.09787881374359, 58.70370738208294, 50.36779448390007, 35.78291170299053, 25.48786763101816, 28.527128845453262, 45.126576125621796, 37.19962768256664, 63.61446887254715, 38.13627742230892, 0.11966092279180884, 0.017543254143674858, 0.8840917912311852, 2.074360940605402, 0.8791701053269207, 6.0596132185310125, 49.050845950841904, 63.709596768021584, 71.22159987688065, 64.41601306200027, 58.76201905310154, 49.37904953956604, 52.64248542487621, 51.14247791469097, 49.747014194726944, 45.801735296845436, 47.09019675850868, 45.636626556515694, 53.68254281580448, 56.04326494038105, 61.12663596868515, 57.05513924360275, 55.99166750907898, 58.61612968146801, 56.56424358487129, 51.32700361311436, 41.717201471328735, 44.643036872148514, 44.63005676865578, 43.48135940730572, 42.853180915117264, 42.41961658000946, 43.88105235993862, 43.63402001559734, 42.49397858977318, 41.715871542692184, 42.35428288578987, 41.43886640667915, 42.50309810042381, 43.637622222304344, 42.65302665531635, 41.67082116007805, 41.38339318335056, 41.457090228796005, 41.82743355631828, 43.438634499907494, 40.97194746136665, 40.43374054133892, 41.55616231262684, 39.93583805859089, 40.34260243177414, 42.0244225859642, 40.99798746407032, 41.248755007982254, 41.488921120762825, 42.023111656308174, 45.32431371510029, 47.17329069972038, 45.45351058244705, 50.818321108818054, 51.31217680871487, 55.44953539967537, 52.431554943323135, 56.83093227446079, 28.81843451410532, 43.987575843930244, 56.06928214430809, 50.25619447231293, 53.87862369418144, 51.32058575749397, 54.63009797036648, 53.5204017162323, 53.13315689563751, 48.488597720861435, 49.83349375426769, 50.564357936382294, 48.81433144211769, 45.771420523524284, 47.93413147330284, 39.65881772339344, 41.176311895251274, 43.023442178964615, 41.26201629638672, 39.85666550695896, 42.13517524302006, 40.18576204776764, 39.99805212020874, 41.472061425447464, 41.408221051096916, 40.95468878746033, 42.58547008037567, 41.310744881629944, 42.90335342288017, 42.47186757624149, 40.51625691354275, 41.68382786214352, 41.32906749844551, 41.8336234241724, 42.75321967899799, 42.682912051677704, 40.966563150286674, 42.29678437113762, 40.776193365454674, 39.4796497374773, 41.92670702934265, 43.13383385539055, 51.39277048408985, 58.912114799022675, 50.945663675665855, 42.05919831991196, 60.517604649066925, 59.45509046316147, 57.79250107705593, 57.712591364979744, 56.951355412602425, 56.05219826102257, 57.259925454854965, 54.75566603243351, 52.968010157346725, 52.26417772471905, 56.34814538061619, 59.012968987226486, 61.51055596768856, 53.14804829657078, 5.06737626157701, 2.786721778102219, 2.2153556998819113, 0.11585985761485063, 0.021120984820299782, 1.5181547426618636, 50.467554330825806, 50.0312427431345, 56.56771659851074, 48.3475036919117, 14.633905850350857, 29.088328331708908, 44.625690802931786, 47.92951852083206, 49.822759330272675, 9.293367471545935, 0.2230618501198478, 0.050359009474050254, 0.05794303884613328, 0.041413881262997165, 0.0531635781226214, 0.03917712238035165, 0.041403862269362435, 0.06173019246489275, 0.035147705784766003, 0.027580955465964507, 0.031189023284241557, 0.06465955695603043, 0.039344480392173864, 0.040736523078521714, 0.0549536531616468, 0.013176951670175185, 0.028556389843288343, 0.017107745188695844, 0.0359931678394787, 0.037013205292169005, 0.021901280742895324, 0.06089522808906622, 0.0731181183073204, 0.22780276369303465, 0.26274272007867694, 11.73198351636529, 80.46396553516388, 64.69307139515877, 55.96172131597996, 45.703179985284805, 28.746080696582794, 21.051066108047962, 47.04401783645153, 45.49341604113579, 71.54892951250076, 41.23599909245968, 0.14585774129955098, 0.026237005804432556, 2.3722081957384944, 3.4784008003771305, 1.6161318914964795, 7.485506655648351, 52.02602930366993, 66.08837932348251, 70.44188171625137, 65.88986277580261, 60.90318515896797, 53.423738703131676, 54.40246358513832, 53.615917190909386, 51.031064093112946, 48.117559030652046, 48.148333579301834, 48.50204139947891, 57.02028751373291, 59.25011806190014, 62.79262237250805, 60.32731845974922, 60.53500011563301, 60.35906195640564, 58.31802427768707, 53.94154071807861, 42.97336086630821, 45.964792147278786, 46.565285325050354, 45.011890679597855, 44.197978153824806, 45.9735506772995, 45.25418467819691, 43.080028742551804, 44.116160944104195, 43.87865848839283, 43.1721244007349, 43.26571337878704, 43.66917572915554, 45.12149579823017, 44.55267012119293, 44.12170484662056, 41.22003994882107, 42.62487396597862, 43.572125136852264, 45.168723464012146, 43.30543264746666, 43.81006836891174, 43.85743282735348, 42.253208309412, 42.10435129702091, 43.31986807286739, 41.97559520602226, 43.3128422498703, 43.094274178147316, 44.43446606397629, 48.03810529410839, 50.3375519067049, 49.58140768110752, 52.707674726843834, 52.335743084549904, 56.818362548947334, 53.51955056190491, 59.54724311828613, 30.59315588325262, 45.25952719151974, 56.49784214794636, 53.06465037167072, 55.533533692359924, 52.84098297357559, 57.146277353167534, 55.3360278904438, 54.02396969497204, 51.41852930188179, 52.49258726835251, 51.60910427570343, 51.21432065963745, 47.912472635507584, 48.009014055132866, 41.25923104584217, 43.817443773150444, 42.6898542791605, 43.92025865614414, 41.907252073287964, 43.16210053861141, 42.71445795893669, 44.039473459124565, 44.43116784095764, 43.8177477568388, 43.7800195813179, 44.38236705958843, 44.60000418126583, 45.30559591948986, 44.23550494015217, 42.991911470890045, 43.11016492545605, 44.095015078783035, 43.63620109856129, 44.45602610707283, 44.291635528206825, 45.65428800880909, 43.68734635412693, 42.473592683672905, 41.4882143586874, 42.96621724963188, 45.00114105641842, 53.53598088026047, 59.842643067240715, 49.63999293744564, 44.999757930636406, 62.54941262304783, 62.70706236362457, 58.48288603127003, 60.06393939256668, 58.4134903550148, 58.48982825875282, 59.778312519192696, 57.43349254131317, 54.737130627036095, 54.96191516518593, 59.451716244220734, 62.13148444890976, 64.12745654582977, 57.5468784570694, 6.314321625977755, 0.766478186706081, 3.6143890907987952, 0.7190411759074777, 0.05443124799057841, 1.5275515196844935, 56.1221145093441, 55.499232932925224, 55.1414555311203, 47.25658982992172, 13.73468030244112, 31.357258781790733, 51.5951856225729, 52.35806688666344, 60.93378111720085, 21.02948136627674, 0.2882681175833568, 0.05454852587718051, 0.09003777915495448, 0.10290949197951704, 0.03317053160571959, 0.09085589306778274, 0.024769531228230335, 0.0019787491555689485, 0.07476982733351178, 0.03613204964494798, 0.005789083061245037, 0.046666769121657126, 0.02044249114987906, 0.15832389268325642, 0.19948070141253993, 0.12939490203280002, 0.08471175635349937, 0.10755095776403323, 0.1284223175025545, 0.20971459132852033, 0.09722582821268588, 0.15700773830758408, 0.2416024950798601, 0.350134675973095, 0.4430873959790915, 15.810933541506529, 90.41875496506691, 72.58524030447006, 65.27206152677536, 51.25292278826237, 36.49147108197212, 37.49012589454651, 55.621130391955376, 49.95546720921993, 76.8691836297512, 45.88949538767338, 0.3879734018119052, 0.10574440704658628, 2.1599674969911575, 6.255056206136942, 4.3866983614861965, 9.017460476607084, 57.9219601303339, 69.90962147712708, 75.57858288288116, 69.70939502120018, 64.18820768594742, 55.707704946398735, 58.91271896660328, 56.61316595971584, 53.1368312984705, 51.87292791903019, 51.907027289271355, 50.810903906822205, 59.81998108327389, 59.881461784243584, 66.61221161484718, 62.954664677381516, 62.54447288811207, 62.66060225665569, 59.19421166181564, 55.663824900984764, 46.29943639039993, 48.05719926953316, 48.03358733654022, 47.5524115562439, 47.071368768811226, 47.512734085321426, 48.38476449251175, 46.17294117808342, 46.793121099472046, 45.9435398876667, 46.94488875567913, 44.37000252306461, 46.19211494922638, 48.26699361205101, 48.59979495406151, 46.742097437381744, 43.87553505599499, 45.16504526138306, 46.54221676290035, 47.21294917166233, 44.46527861058712, 46.16082362830639, 47.30455465614796, 44.17101100087166, 45.36723621189594, 46.39058589935303, 44.695861637592316, 45.01209206879139, 46.435260102152824, 47.13509514927864, 51.154519468545914, 50.960053503513336, 52.6009688526392, 56.399370431900024, 57.933017536997795, 61.893305629491806, 57.93832205235958, 62.41591438651085, 33.908267095685005, 47.08922781050205, 59.32199500501156, 56.269284412264824, 59.09490779042244, 55.64816974103451, 59.04686316847801, 57.585131004452705, 57.004085183143616, 52.27697163820267, 53.00106838345528, 55.00273257493973, 53.30411732196808, 49.45011332631111, 52.23148047924042, 43.88213150203228, 46.081328094005585, 45.81403523683548, 45.98836228251457, 44.0066584199667, 47.73430019617081, 45.39448454976082, 44.453088864684105, 47.34746195375919, 45.20398937165737, 45.30621528625488, 46.988575011491776, 45.433953031897545, 48.53784687817097, 46.097484827041626, 44.12269279360771, 46.0042492300272, 45.50741069018841, 45.78215874731541, 47.54044219851494, 46.61332994699478, 46.370397582650185, 47.0609687268734, 44.58267331123352, 43.77326354384422, 45.28915800154209, 48.31281915307045, 56.43251225352287, 64.27991956472397, 55.640296563506126, 49.35742110013962, 66.85624212026596, 67.5327730178833, 61.65049105882645, 63.9923357963562, 60.065546706318855, 61.45780339837074, 62.59184494614601, 60.13146176934242, 58.187828063964844, 57.75514908134937, 62.40467458963394, 64.86175194382668, 65.88994637131691, 58.6056574434042, 6.402977993711829, 8.464192114770412, 7.774705812335014, 0.5595816043205559, 0.28338671545498073, 2.153811827301979, 61.86663866043091, 63.02675060927868, 67.12130069732666, 54.00366738438606, 25.641578882932663, 42.08322823047638, 60.746758952736855, 62.92876906692982, 70.29495120048523, 29.150990769267082, 0.6291871599387378, 0.3093414899194613, 0.16449050162918866, 0.1858101482503116, 0.11436248561949469, 0.204423850227613, 0.13883095351047814, 0.1970866517513059, 0.14249846921302378, 0.10078198465635069, 0.05349304345145356, 0.20029608422191814, 0.1667942467611283], [0.07123868126654997, 0.04913285534712486, 0.028712906932923943, 0.04005902759672608, 0.07604324142448604, 0.029230866639409214, 0.09039191718329675, 0.058318005249020644, 0.0609325247205561, 0.051995534158777446, 0.020177832011540886, 0.03999215638032183, 18.148734346032143, 75.34741848707199, 54.13830555975437, 46.414912194013596, 21.732403747737408, 26.419511139392853, 43.737739250063896, 34.798395931720734, 46.02957487106323, 69.85160619020462, 17.699980325996876, 0.2599610318429768, 0.19377607939532027, 0.0758846741518937, 3.1370147690176964, 0.16319699760060757, 18.350779004395008, 64.23971772193909, 67.52341791987419, 64.85138610005379, 60.13627231121063, 51.375648602843285, 50.08318975567818, 53.290343061089516, 54.53900545835495, 54.961364194750786, 46.70513682067394, 45.77835515141487, 45.493929013609886, 46.34311884641647, 50.042060762643814, 55.360262989997864, 58.472979962825775, 60.81337697803974, 57.24788390100002, 58.38452450931072, 46.36456109583378, 41.614907160401344, 43.564536944031715, 42.87312604486942, 42.70517125725746, 43.244244530797005, 43.69979448616505, 42.06395946443081, 43.13891418278217, 40.554612055420876, 42.587487772107124, 41.07881672680378, 40.848818868398666, 41.18930719792843, 41.91221080720425, 41.58381722867489, 43.77469226717949, 41.336659491062164, 40.79561032354832, 42.45422512292862, 42.74575687944889, 41.85046412050724, 41.492264941334724, 41.856118217110634, 41.72483906149864, 41.02965496480465, 42.08277605473995, 40.01256354153156, 40.637816190719604, 39.832829385995865, 44.08577397465706, 45.74380740523338, 47.55943737924099, 48.162218034267426, 51.757433116436005, 52.704699486494064, 52.677413150668144, 54.6655348688364, 52.472467347979546, 26.725176237523556, 43.126952424645424, 57.4057350307703, 52.28523999452591, 52.682653069496155, 53.25824998319149, 55.85291415452957, 52.14630804955959, 53.26939098536968, 52.07400552928448, 51.6020480543375, 49.03765305876732, 48.58576990664005, 47.99898639321327, 47.16320984065533, 42.30503372848034, 39.41847302019596, 39.177197366952896, 43.52503426373005, 41.169118881225586, 40.07421523332596, 39.6822776645422, 42.234422117471695, 42.48999260365963, 42.28817403316498, 42.80303120613098, 42.038143649697304, 41.40807285904884, 42.61860050261021, 42.5481940805912, 40.469641014933586, 41.63592763245106, 41.64567410945892, 42.342074140906334, 41.622282564640045, 41.03645280003548, 41.04493774473667, 43.144370689988136, 39.786403477191925, 43.23450185358524, 43.356357514858246, 43.85044880211353, 52.0367257297039, 58.807635605335236, 41.27591595053673, 45.34254513680935, 60.04381947219372, 54.08393807709217, 56.27177707850933, 53.01947079598904, 53.43287341296673, 51.5106325596571, 52.54903703927994, 50.8835294097662, 50.0264398008585, 50.15801914036274, 56.3840002566576, 62.05508574843407, 60.437007173895836, 64.76831495761871, 22.42516927421093, 0.4904229997191578, 3.301283516921103, 0.9356227261014283, 0.09667877631727606, 0.0906520251010079, 18.517400063574314, 56.12530633807182, 37.976036220788956, 29.83591351658106, 21.342086791992188, 22.015226371586323, 36.896719336509705, 42.980420887470245, 51.010499596595764, 25.638149566948414, 0.24619879375677556, 0.06812029547290877, 0.08771499051363207, 0.05665143842634279, 0.062708458135603, 0.030809449999651406, 0.06256067426875234, 0.03800433609285392, 0.05228711655945517, 0.022768352282582782, 0.00937883838560083, 0.06106682376412209, 0.032303328334819525, 0.009232696520484751, 0.02277732299262425, 0.048384080291725695, 0.0716295481834095, 0.07381778545095585, 0.010049815027741715, 0.09108466751058586, 0.01564941201650072, 0.09543890730128624, 0.046099727478576824, 0.0664792733732611, 0.031689661263953894, 24.755350537598133, 86.52603104710579, 59.830217733979225, 50.02452850341797, 27.654469572007656, 33.5990434885025, 37.86572054028511, 35.24850457906723, 52.573895305395126, 76.68854892253876, 19.201008081436157, 0.4331242118496448, 0.26725218747742474, 2.0829434925690293, 6.3532486371695995, 0.8774903579615057, 19.650535359978676, 68.86864453554153, 68.6925695836544, 69.84308704733849, 61.8365328758955, 54.36562076210976, 51.04015700519085, 56.28084719181061, 56.276865005493164, 56.8218469619751, 48.0886235833168, 47.48517796397209, 46.1192424595356, 47.977756932377815, 53.90089809894562, 58.85273918509483, 58.46328668296337, 62.91304171085358, 59.56300087273121, 59.95141223073006, 48.61072696745396, 44.2796965688467, 43.97686801850796, 44.09122668206692, 45.73852948844433, 44.63854931294918, 45.77547490596771, 43.70393626391888, 45.647706761956215, 43.43871429562569, 43.33780691027641, 43.649241998791695, 43.03007662296295, 43.800268694758415, 44.2935012280941, 42.73080848157406, 45.27966231107712, 42.65867315232754, 42.99623943865299, 42.88349948823452, 43.36560241878033, 44.30552378296852, 43.22159394621849, 44.835412949323654, 43.56224566698074, 42.66993194818497, 43.90342935919762, 43.99008750915527, 43.18016476929188, 42.71819695830345, 44.707181230187416, 48.95264022052288, 50.56975744664669, 49.11718279123306, 53.88402320444584, 53.229356333613396, 55.12528359889984, 56.38722628355026, 54.9605168402195, 29.587214961647987, 44.45191852748394, 57.68983818590641, 53.51883240044117, 55.1405967772007, 55.202670246362686, 58.11302907764912, 56.37429937720299, 56.476745679974556, 55.70739336311817, 53.213431388139725, 51.08818642795086, 51.16173908114433, 51.84847243130207, 50.92596173286438, 44.14402864873409, 41.1044729501009, 42.15156376361847, 45.73246881365776, 44.44996923208237, 42.38431267440319, 42.17277802526951, 43.58745351433754, 43.646825328469276, 44.38891790807247, 43.864470049738884, 43.46089370548725, 43.767776638269424, 44.18187081813812, 42.586245238780975, 43.267286494374275, 44.18301075696945, 43.32271791994572, 43.76642011106014, 43.82284328341484, 42.79731631278992, 42.986131981015205, 44.26917113363743, 41.998021602630615, 43.552616983652115, 44.34663377702236, 43.258539363741875, 56.25647909939289, 60.12598246335983, 45.67069172859192, 49.949809312820435, 62.61107571423054, 57.77376428246498, 58.947779685258865, 55.43957233428955, 54.87089864909649, 54.389320090413094, 54.10530053079128, 53.3658792078495, 50.98055340349674, 52.97893077135086, 58.72397169470787, 65.3784330189228, 63.30664739012718, 67.34382435679436, 27.133319936692715, 1.166602356825024, 4.334558984264731, 1.3203499442897737, 0.13617799821076915, 0.10101612482685596, 22.17444732785225, 63.87513488531113, 42.35797628760338, 32.571130245923996, 27.27979637682438, 32.48478747904301, 42.541122660040855, 51.59206598997116, 56.563464626669884, 38.911006450653076, 0.8458599052391946, 0.10721983373514377, 0.0656397856073454, 0.014038228891877225, 0.00395358904825116, 0.025881097753881477, 0.038269293945631944, 0.005174136713321786, 0.033495395618956536, 0.039854499118519016, 0.02323818927834509, 0.02798793626425322, 0.07738612053799443, 0.11526959788170643, 0.10936164966551587, 0.14340852038003504, 0.21942299616057426, 0.1940662442939356, 0.15851738542551175, 0.3386178205255419, 0.174892918439582, 0.15451254876097664, 0.15406233229441568, 0.17320131155429408, 0.13199523906223476, 31.837657503783703, 95.29079273343086, 67.03846514225006, 59.79777507483959, 33.26201677322388, 37.06312760710716, 58.91784109175205, 48.99279646575451, 60.089823603630066, 82.89571344852448, 21.68284110724926, 0.41294391034170985, 0.5340082640759647, 1.4877957967109978, 9.074646458029747, 2.6034215139225125, 22.065503373742104, 72.26334437727928, 69.82504561543465, 71.73887372016907, 66.19698509573936, 56.47346645593643, 55.86060494184494, 59.66364227235317, 59.25178237259388, 60.472455471754074, 52.739669010043144, 49.013535752892494, 50.08347474038601, 51.91776931285858, 56.37211449444294, 58.75329092144966, 61.363598853349686, 67.15671479701996, 61.594330072402954, 64.25272822380066, 50.884315967559814, 46.75052158534527, 44.913266971707344, 45.32793492078781, 47.79196970164776, 46.74510307610035, 47.9024525731802, 45.37849880754948, 47.474230751395226, 44.56875465810299, 46.60694628953934, 46.4601943641901, 44.378871247172356, 46.41795963048935, 46.45414508879185, 45.07308639585972, 48.31006050109863, 45.515082478523254, 44.5095120370388, 44.816197380423546, 46.20164103806019, 44.95807036757469, 45.41341133415699, 47.13653527200222, 46.05876870453358, 44.8084381967783, 45.585219115018845, 46.306564807891846, 45.64708739519119, 45.13797931373119, 47.19907991588116, 50.965848192572594, 52.30562210083008, 52.81242370605469, 57.90894962847233, 55.87011583149433, 56.65817454457283, 59.649271443486214, 54.79552589356899, 31.283660531044006, 47.03424856066704, 60.3598865121603, 56.88683107495308, 57.12661720812321, 58.911240845918655, 61.860323399305344, 58.76777194440365, 58.25577221810818, 57.4478405714035, 56.195830553770065, 54.01895396411419, 53.77194061875343, 53.666279688477516, 53.913182839751244, 46.82134598493576, 42.50707648694515, 43.974405750632286, 49.2625667899847, 46.39655917882919, 43.69922831654549, 44.37029890716076, 46.50548413395882, 46.983703672885895, 47.025216445326805, 46.20028831064701, 45.98714254796505, 45.94984374940395, 46.806522980332375, 44.78711374104023, 44.82039235532284, 45.35025492310524, 46.96821190416813, 45.95967382192612, 44.68329191207886, 46.080883517861366, 46.313674226403236, 49.629235714673996, 43.8244391977787, 46.43838733434677, 47.62585021555424, 47.48719185590744, 58.701389506459236, 63.772000819444656, 48.31329792737961, 50.522495582699776, 65.57865187525749, 59.88606333732605, 62.78462380170822, 58.32669161260128, 58.34050007164478, 57.19284765422344, 56.259089559316635, 55.46862557530403, 55.115100145339966, 55.6090622395277, 61.54741778969765, 68.29282343387604, 64.66999143362045, 69.89861726760864, 27.619997821748257, 1.8270057323388755, 9.363981932401657, 2.5422075111418962, 0.29330575664062053, 0.10595487270620652, 24.204133115708828, 70.53165569901466, 48.250988870859146, 40.96466705203056, 34.70363661646843, 32.41741709411144, 52.519904002547264, 59.449797347187996, 64.27596777677536, 48.30233171582222, 1.8336667749099433, 0.1893455468234606, 0.37321416253689677, 0.13969749998068437, 0.15777776105096564, 0.1569981497596018, 0.1782476040534675, 0.13203636888647452, 0.1480948118842207, 0.14720374485477805, 0.10587713273707777, 0.16165589826414362, 0.1589426805730909], [0.028870689384348225, 0.06931648909812793, 0.053799821325810626, 0.013125615460012341, 0.020758642349392176, 0.031075537772267126, 0.07348560015088879, 0.0650559009227436, 0.014575002969650086, 0.07046509621432051, 0.20898222515825182, 0.13561006227973849, 35.46866096556187, 75.08246630430222, 56.414866000413895, 48.04236866533756, 27.8422611951828, 17.562220618128777, 31.156401559710503, 38.204023987054825, 48.74332085251808, 62.659754902124405, 3.9972287602722645, 0.16301738301990554, 0.1883208635263145, 4.521956378594041, 0.5985161557327956, 3.3040388440713286, 49.078227281570435, 75.2779658138752, 64.09287840127945, 65.30222430825233, 55.94248294830322, 50.75657442212105, 52.94250212609768, 53.90323877334595, 55.892105251550674, 56.27014696598053, 53.66696745157242, 47.27325953543186, 44.857212379574776, 43.98126818239689, 44.18431408703327, 47.45608672499657, 50.62898486852646, 51.48269645869732, 52.313328087329865, 45.2726174890995, 42.809559255838394, 41.27390965819359, 43.2338672876358, 42.572189792990685, 44.2228402197361, 43.467550948262215, 43.286342471838, 41.830754578113556, 43.2914911955595, 41.520588621497154, 41.055694967508316, 41.29866532981396, 41.28171443939209, 40.96039988100529, 41.28477327525616, 42.780832797288895, 41.29092134535313, 41.972114592790604, 42.87184551358223, 41.061850637197495, 43.39510403573513, 43.935739025473595, 41.229778826236725, 42.34883017838001, 40.847530737519264, 40.08063308894634, 39.82347048819065, 40.015481784939766, 41.451139748096466, 41.1537829041481, 47.38984487950802, 49.3365678191185, 51.42592370510101, 50.786277428269386, 52.52853713929653, 51.82584464550018, 55.67828692495823, 50.31204767525196, 58.275861740112305, 26.471237763762474, 35.56621313095093, 53.07813964784145, 48.66494245827198, 54.366126134991646, 48.912100195884705, 49.842826053500175, 48.7417097389698, 53.20585459470749, 53.8925651460886, 52.19674654304981, 47.82166510820389, 49.786581471562386, 49.500624015927315, 50.91199368238449, 43.34674023091793, 39.68392677605152, 41.80780000984669, 42.14328020811081, 40.9829630702734, 41.066190004348755, 40.60756601393223, 41.54341399669647, 43.55653457343578, 42.26445950567722, 41.52305468916893, 40.75920447707176, 41.84170939028263, 41.77877716720104, 41.6072391718626, 39.77933585643768, 41.58152215182781, 40.295982733368874, 42.50175677239895, 42.29549244046211, 40.65501406788826, 41.0681127011776, 41.610791981220245, 41.55558094382286, 42.410307079553604, 41.18557199835777, 43.09146232903004, 48.624626621603966, 53.314456567168236, 59.133072942495346, 61.33431002497673, 54.96825322508812, 53.56404237449169, 49.545112028717995, 49.36592124402523, 47.678131610155106, 48.8871431350708, 46.52632601559162, 49.1887329518795, 47.10451819002628, 50.62914066016674, 55.29427573084831, 59.3141408264637, 59.196662530303, 63.00436981022358, 47.07545354962349, 6.271044798195362, 1.435967527795583, 1.5427111624740064, 0.040312344863195904, 0.10290615231497213, 4.9659312050789595, 52.18065060675144, 44.78154703974724, 33.11827428638935, 15.372324027121067, 9.0903852134943, 29.81280505657196, 44.04597871005535, 51.82128109037876, 45.31045205891132, 2.9397692531347275, 0.10923995971097611, 0.06408701228792779, 0.028631934910663404, 0.09535022065392695, 0.10995724544045515, 0.008304466446134029, 0.019968344131484628, 0.009895957609842299, 0.025504097866360098, 0.04060486979142297, 0.042916904712910764, 0.03387287419172935, 0.04435669347003568, 0.06496195986983366, 0.02532870610593818, 0.009591408961568959, 0.011567912424652604, 0.022002259211149067, 0.005441245402835193, 0.03109474269876955, 0.04448633924766909, 0.09157587279332802, 0.11463449016446248, 0.051386572304181755, 47.01250232756138, 83.3855527639389, 61.64097256958485, 54.30558778345585, 31.893721595406532, 21.948883831501007, 30.26108030229807, 43.01586538553238, 55.407213270664215, 67.32766762375832, 3.856480037793517, 0.12019720612443052, 0.16129781201016158, 5.463545378297567, 5.101267118006945, 3.0725203547626734, 53.108891397714615, 75.15929818153381, 67.81145766377449, 66.17221802473068, 58.326661214232445, 51.02204717695713, 55.503503903746605, 57.61580675840378, 59.296327382326126, 59.044697284698486, 56.19120240211487, 48.51977124810219, 48.44128645956516, 46.5110432356596, 45.90990409255028, 48.306914269924164, 53.263904079794884, 52.912544533610344, 54.63555067777634, 47.54498675465584, 45.674787908792496, 43.051473274827, 43.95694948732853, 44.4257303327322, 45.212250128388405, 44.73408758640289, 44.85116310417652, 43.50218988955021, 44.62825946509838, 44.78062368929386, 43.650032356381416, 43.434648513793945, 43.07909019291401, 42.685640305280685, 43.68583783507347, 44.6534027159214, 43.22821319103241, 43.71014893054962, 44.282880797982216, 42.512559592723846, 45.30568331480026, 46.38071022927761, 43.94721820950508, 44.0936965495348, 41.227909326553345, 41.94240398705006, 41.205228343605995, 41.84593476355076, 42.383947893977165, 43.87541726231575, 49.275440499186516, 51.5607974678278, 53.63046281039715, 51.98388956487179, 55.427021607756615, 52.693311497569084, 58.9660757035017, 52.57769510149956, 58.596515133976936, 27.301164530217648, 37.5834146887064, 54.61760804057121, 50.91070555150509, 55.804124772548676, 50.877559930086136, 51.68096981942654, 50.6651247292757, 53.027659356594086, 54.55611974000931, 53.483061119914055, 49.87829715013504, 51.39288067817688, 51.16781495511532, 53.972087278962135, 45.563214495778084, 42.745958268642426, 42.08851754665375, 43.92510339617729, 46.06307007372379, 43.524498492479324, 42.801910266280174, 44.26822878420353, 44.17111739516258, 43.64590957760811, 42.85200297832489, 42.67768733203411, 42.3232651501894, 43.296305537223816, 43.32438223063946, 41.76550827920437, 43.30629140138626, 42.868034318089485, 46.21934048831463, 44.06767554581165, 43.757718577980995, 43.93718294799328, 43.77263657748699, 44.66387115418911, 45.38073688745499, 43.53215128183365, 43.92446883022785, 50.8349984139204, 54.705941900610924, 60.57166814804077, 62.12401024997234, 56.34469136595726, 55.83907909691334, 53.10457102954388, 51.39691986143589, 49.736826941370964, 49.677462726831436, 50.036273673176765, 49.09373424947262, 47.33679212629795, 52.567625641822815, 57.50931367278099, 60.171682611107826, 62.492598071694374, 64.23134297132492, 51.46565057337284, 7.051954669877887, 1.0309793218038976, 2.7313430747017264, 0.27087241353001446, 0.11868493922520429, 3.9029382448643446, 58.213085308671, 48.323766365647316, 35.725314393639565, 23.363969698548317, 18.729732669889927, 38.496737480163574, 51.723827719688416, 57.78755374252796, 58.72317373752594, 6.317691570147872, 0.15370043140137568, 0.10539077367866412, 0.06102391278545838, 0.04607957445841748, 0.034972462453879416, 0.015976268696249463, 0.006522757266793633, 0.0519698484276887, 0.02461058546032291, 0.04421298399392981, 0.03781102888751775, 0.0691442217794247, 0.06891048979014158, 0.2227344294078648, 0.1003738924919162, 0.12050058125169016, 0.12584486830746755, 0.10298632652848028, 0.14264345518313348, 0.12091217635315843, 0.07035920658381656, 0.1873314322438091, 0.18435300065902993, 0.23352084826910868, 55.69365710020065, 90.63753202557564, 70.3498886525631, 62.90256567299366, 38.46300669014454, 25.209950543940067, 42.72926576435566, 51.93222753703594, 59.85381066799164, 73.07027667760849, 5.506994621828198, 0.4058537579840049, 0.47264687076676637, 8.941541500389576, 8.269779346883297, 5.254430249333382, 54.21071447432041, 78.74530255794525, 69.74597185850143, 70.82889094948769, 59.73197400569916, 55.12724049389362, 58.97348910570145, 60.015415996313095, 61.24972656369209, 60.43322257697582, 59.27164010703564, 52.041391879320145, 51.27382546663284, 49.25646051764488, 48.56901280581951, 52.377521842718124, 54.927363619208336, 54.40271057188511, 57.57410779595375, 48.5436187684536, 47.52009429037571, 43.96093927323818, 46.86814807355404, 47.71210938692093, 48.11076499521732, 47.47819773852825, 49.11312460899353, 45.180958807468414, 47.88634903728962, 47.04961113631725, 45.96050977706909, 46.36539325118065, 44.02922160923481, 45.72327330708504, 45.91877281665802, 47.69659481942654, 45.856444761157036, 44.239171743392944, 47.354863956570625, 45.34219175577164, 47.67227232456207, 49.800830706954, 45.13330556452274, 46.22849799692631, 45.035130232572556, 43.92837502062321, 43.69882933795452, 44.3879983574152, 45.21246671676636, 44.899101331830025, 52.257041707634926, 54.415132105350494, 55.53174398839474, 55.52031800150871, 57.96726509928703, 56.98198936879635, 60.57595431804657, 54.597484320402145, 60.20714990794659, 30.864573419094086, 37.899998500943184, 53.049800768494606, 54.649518728256226, 58.060443699359894, 51.85016334056854, 53.71528185904026, 51.174054220318794, 55.835328698158264, 57.18848928809166, 56.692581698298454, 53.087718933820724, 53.3117663115263, 54.60599586367607, 56.70455105602741, 47.807488068938255, 45.293637961149216, 47.21390292048454, 45.045059099793434, 46.65505550801754, 45.56086242198944, 43.69335763156414, 46.31946511566639, 47.05789089202881, 45.303703621029854, 45.80687262117863, 44.26155634224415, 45.74181251227856, 45.13949543237686, 47.20212735235691, 43.09027299284935, 45.74278146028519, 45.48860549926758, 48.531379625201225, 47.337962463498116, 46.65024496614933, 47.224348559975624, 45.84779642522335, 47.175684571266174, 46.95653893053532, 44.95631106197834, 47.6755553483963, 54.2468923330307, 57.16544732451439, 63.14960561692715, 65.4568912088871, 60.255631506443024, 58.11827279627323, 55.510852709412575, 55.42533449828625, 53.512053564190865, 54.225621074438095, 55.008527263998985, 53.96268658339977, 51.403542906045914, 56.90706878900528, 60.60784600675106, 64.9958011507988, 65.3306695818901, 67.17192158102989, 52.6928973197937, 9.227597750723362, 6.719003710895777, 3.694511828944087, 0.33977052429690957, 0.192848899459932, 6.005877451971173, 65.27479737997055, 55.876978263258934, 47.7023097127676, 19.662060141563416, 16.798822581768036, 42.19458885490894, 61.17611691355705, 63.978892117738724, 67.65128865838051, 8.708096276968718, 0.23117122356779873, 0.210844540852122, 0.16800035547930747, 0.19147099839756265, 0.13700114388484508, 0.1599562168121338, 0.11274631804553792, 0.09754697777680121, 0.07534338132245466, 0.15121165401069447, 0.23414671624777839, 0.1580382845713757], [0.047096695270738564, 0.029555606342910323, 0.026757039813674055, 0.023276305983017664, 0.0513352824782487, 0.01386563873893465, 0.11805870017269626, 0.07284513412741944, 0.05650745064485818, 0.09451491860090755, 0.06766628663172014, 1.9416059204377234, 51.02426625788212, 65.83924949169159, 52.384289279580116, 40.93915142118931, 17.694107741117477, 27.138660550117493, 40.39608836174011, 36.092967465519905, 64.86835598945618, 46.418495401740074, 0.7872371259145439, 0.024749342956056353, 0.0714557446190156, 2.968041398562491, 3.7114802934229374, 15.037360601127148, 71.19712918996811, 62.33400598168373, 64.66335698962212, 55.906897857785225, 54.10142093896866, 52.90527932345867, 57.09026835858822, 56.73898100852966, 58.44544284045696, 57.62393072247505, 57.14154660701752, 52.129854932427406, 45.28790786862373, 43.780270367860794, 44.897102639079094, 43.361631631851196, 44.404869452118874, 45.177675783634186, 46.05819493532181, 44.574940726161, 45.57785511016846, 43.27849209308624, 43.872385025024414, 41.48773178458214, 44.71909739077091, 42.21700385212898, 41.694398894906044, 40.78399054706097, 43.09718482196331, 40.50797335803509, 41.07108414173126, 41.16963945329189, 40.43757073581219, 41.94775030016899, 41.18578478693962, 41.21283173561096, 42.82872162759304, 41.83051519095898, 40.95710165798664, 41.18831545114517, 43.02345737814903, 42.55610525608063, 43.87493848800659, 41.15762449800968, 41.39597050845623, 38.10823492705822, 40.92622831463814, 39.941640347242355, 41.02399326860905, 43.84078972041607, 46.462880820035934, 49.481811225414276, 53.9482207596302, 49.55387815833092, 54.50462490320206, 50.85784278810024, 55.15023685991764, 48.7391372770071, 58.28558161854744, 24.895300827920437, 28.50214708596468, 50.018376633524895, 44.45662647485733, 49.81691524386406, 47.08803467452526, 53.551723435521126, 52.863572761416435, 53.7237174063921, 53.33467908203602, 50.90143404901028, 47.47227385640144, 50.1958879083395, 51.351371705532074, 50.10358706116676, 45.54521106183529, 41.24515280127525, 39.0438587218523, 41.25885866582394, 43.060915768146515, 41.499150171875954, 40.71861885488033, 43.264147862792015, 43.31677503883839, 40.81187725067139, 40.67885018885136, 40.589486584067345, 40.503417402505875, 42.53592073917389, 40.68633958697319, 42.22119502723217, 41.537292525172234, 40.976203233003616, 41.72153703868389, 42.701504454016685, 40.35669207572937, 41.840083077549934, 42.80676640570164, 41.08721047639847, 42.05783799290657, 41.613003462553024, 41.633343771100044, 43.238370046019554, 50.57372063398361, 51.6578708589077, 52.099095582962036, 52.398865297436714, 49.11413535475731, 46.0345184057951, 47.23294369876385, 44.02313433587551, 47.62320555746555, 45.537497475743294, 43.469644635915756, 44.99737545847893, 50.99302053451538, 55.80928489565849, 59.99660320580006, 59.392462223768234, 63.772145211696625, 59.976536482572556, 24.919334538280964, 1.168659827671945, 1.3061391818337142, 0.24400427791988477, 0.20620625145966187, 0.6579512008465827, 31.463746167719364, 51.90253973007202, 40.69120332598686, 35.987089946866035, 17.85287842154503, 28.575743436813354, 45.2755319327116, 51.39366343617439, 57.1934100240469, 8.396041821688414, 0.33215119095984846, 0.05099759786389768, 0.04840234454604797, 0.03241129968955647, 0.023004893300822005, 0.005458906662170193, 0.04511819264735095, 0.0709215689857956, 0.009913713493006071, 0.06313472549663857, 0.0335859895858448, 0.04460028860194143, 0.03410437602724414, 0.0260531684034504, 0.08350191463250667, 0.009459207412874093, 0.03230288675695192, 0.06375766199198551, 0.09085022305953316, 0.005661362692990224, 0.04421766323503107, 0.043572376962401904, 0.023184663732536137, 2.942811227403581, 61.66586123406887, 71.92557290196419, 60.30376352369785, 49.276778027415276, 26.981016509234905, 28.766994774341583, 35.83728678524494, 43.20412628352642, 68.41210663318634, 52.231556475162506, 0.5000594013836235, 0.07346062688156962, 0.8156222559046, 3.6543942941352725, 2.542132940143347, 15.5696882866323, 75.22348433732986, 64.5011056959629, 68.04896011948586, 58.64183150231838, 56.38319090008736, 54.77455861866474, 59.834488704800606, 60.34270383417606, 62.27443277835846, 60.09686082601547, 61.36916935443878, 54.13122273981571, 47.65371032059193, 45.35557843744755, 47.36854702234268, 45.85981138050556, 46.580704897642136, 47.59731374680996, 47.994863614439964, 46.0857168585062, 47.06917628645897, 44.78593960404396, 44.45150814950466, 44.28848169744015, 45.0829316675663, 42.026440277695656, 43.56234446167946, 42.008843421936035, 45.05958192050457, 42.57058247923851, 42.753911241889, 42.26749934256077, 43.497709929943085, 44.82116371393204, 43.60430181026459, 42.442662343382835, 44.668180122971535, 43.48012447357178, 42.639609575271606, 42.2847656160593, 44.51227068901062, 43.36139604449272, 45.036631152033806, 41.33122958242893, 43.68559844791889, 41.48294784128666, 42.649264857172966, 43.43679919838905, 43.22430320084095, 45.837312787771225, 48.96394461393356, 50.15705019235611, 54.46880042552948, 51.723329946398735, 55.41202761232853, 54.039317071437836, 56.60776264965534, 51.009428054094315, 61.473686546087265, 26.223337166011333, 29.691982939839363, 51.369903311133385, 46.16274252533913, 51.45161032676697, 48.75239096581936, 53.299139589071274, 53.21758076548576, 55.37844501435757, 54.95020419359207, 54.386337250471115, 51.20649307966232, 52.33148351311684, 53.46113249659538, 52.181767746806145, 46.53818137943745, 41.716274321079254, 41.263642609119415, 43.13226833939552, 44.66931626200676, 44.727829322218895, 42.6161078363657, 46.269296407699585, 44.630577340722084, 41.11557595431805, 42.685811296105385, 41.682976707816124, 41.678295359015465, 42.18995690345764, 42.066315338015556, 43.13163757324219, 44.14453022181988, 43.67354929447174, 44.192103669047356, 43.822607696056366, 43.175198435783386, 43.491622656583786, 45.70991702377796, 43.45697991549969, 43.52545604109764, 44.56479147076607, 44.14833001792431, 44.75909784436226, 51.75736092031002, 54.060523733496666, 54.980306178331375, 55.226415172219276, 50.8059261739254, 49.05688002705574, 48.911792412400246, 45.79010412096977, 50.29926896095276, 46.141182482242584, 46.228057220578194, 46.68742597103119, 53.13682369887829, 57.29217812418938, 62.06462703645229, 64.33339789509773, 65.5918675661087, 62.24143534898758, 28.481924571096897, 1.486777332611382, 2.523180269636214, 0.3892866469686851, 0.15984974830644205, 0.3308487217873335, 33.945242911577225, 58.55619169771671, 43.934196308255196, 29.83328215777874, 20.05797989666462, 34.522952511906624, 52.539241164922714, 55.79082548618317, 66.3817235827446, 13.890407346189022, 0.5142374499700963, 0.053062594088260084, 0.0700241417507641, 0.0642527561285533, 0.04955595373758115, 0.06521030474686995, 0.08010264078620821, 0.014957249841245357, 0.06336830905638635, 0.07248079156852327, 0.05043844896135852, 0.022685042495140806, 0.1678606981295161, 0.20617937087081373, 0.13581912528024986, 0.11543265514774248, 0.09787532617338002, 0.12114164841477759, 0.18008381099207327, 0.10459283876116388, 0.22375633707270026, 0.21611515490803868, 0.17017697071423754, 4.1009437199682, 72.78355166316032, 78.75578239560127, 67.33155861496925, 56.940788179636, 27.580037266016006, 38.368786945939064, 55.58163911104202, 50.83773046731949, 76.66381984949112, 57.678051218390465, 1.0555471410043538, 0.2844233176438138, 1.3238210580311716, 10.715799294412136, 12.674059364944696, 19.353721886873245, 75.63408270478249, 67.31775775551796, 69.91931095719337, 59.85298231244087, 57.132807075977325, 58.00905145704746, 62.584568336606026, 63.479773700237274, 64.73967209458351, 61.42939232289791, 62.933929190039635, 55.75848162174225, 50.923864245414734, 49.224777817726135, 50.44492654502392, 49.039955735206604, 47.771181017160416, 49.12585772573948, 51.044131591916084, 48.86495232582092, 50.65990760922432, 46.64980798959732, 48.87740045785904, 46.05665981769562, 49.11941707134247, 44.393903240561485, 46.135239601135254, 45.151168406009674, 48.14001962542534, 45.12211516499519, 44.8898184299469, 45.08375622332096, 45.62044322490692, 46.94656066596508, 45.10077551007271, 45.454490929841995, 47.77417525649071, 45.226115584373474, 45.58905690908432, 43.640016093850136, 47.10125796496868, 46.02563448250294, 46.93633921444416, 44.934165850281715, 46.90937586128712, 43.123711198568344, 44.187908694148064, 45.7863537222147, 44.990015253424644, 48.66146184504032, 50.878004506230354, 54.031934067606926, 57.9025811702013, 55.468097403645515, 59.25141379237175, 57.94782914221287, 58.96791860461235, 53.25407400727272, 61.341199055314064, 30.395750775933266, 32.98486344516277, 51.31919123232365, 47.73462317883968, 52.291916236281395, 50.86494840681553, 57.673867642879486, 55.82107566297054, 57.63138212263584, 57.50746697187424, 56.617368534207344, 53.27020414173603, 54.7644055634737, 56.55912525951862, 54.590469896793365, 49.645305052399635, 45.1216059923172, 43.99816207587719, 44.6983353048563, 47.070665806531906, 46.22727446258068, 44.237104654312134, 47.731978520751, 48.51662501692772, 43.54290470480919, 43.82617570459843, 44.094809889793396, 42.72231213748455, 45.56529298424721, 44.657365903258324, 44.42664608359337, 45.84150396287441, 45.96207909286022, 46.821847558021545, 47.80612014234066, 45.191472843289375, 46.58804230391979, 49.24416437745094, 46.83928482234478, 46.53984189033508, 46.61261938512325, 46.7048404365778, 47.099563255906105, 54.12173084914684, 58.098209872841835, 57.28411875665188, 57.370776906609535, 56.279205679893494, 50.931551232934, 53.58347833156586, 47.87893943488598, 52.77338460087776, 50.21664999425411, 48.27095679938793, 49.60176698863506, 56.933990344405174, 59.75787341594696, 66.14411473274231, 66.91249430179596, 67.96937718987465, 62.57462427020073, 29.794613532721996, 4.478342793881893, 8.649012297391891, 0.42032216442748904, 0.39132972015067935, 0.6824453989975154, 40.81699177622795, 64.5710751414299, 57.49831326305866, 44.32497873902321, 27.23563514649868, 40.17445765435696, 62.030257880687714, 62.082577273249626, 77.20001667737961, 18.986851572990417, 0.845146196661517, 0.15819293330423534, 0.2473384208860807, 0.1581092635751702, 0.09436215492314659, 0.11077035727794282, 0.24126431322656572, 0.184218953945674, 0.06781643052818254, 0.17983801168156788, 0.15150566323427483, 0.1547449894133024], [0.018430604868626688, 0.023135251540225, 0.04059370417962782, 0.026547735615167767, 0.05748503353970591, 0.014924258593964623, 0.04854084785620216, 0.06980023579671979, 0.01804711118893465, 0.030355160997714847, 0.09648879393353127, 5.549488216638565, 63.55078049004078, 60.83270274102688, 55.04983104765415, 39.24896791577339, 15.922600999474525, 24.07409079372883, 38.518510311841965, 44.513707011938095, 66.64612099528313, 28.410389609634876, 0.11748113116482273, 0.09795767487958074, 0.691989358747378, 3.3247417956590652, 2.9877587780356407, 35.210202634334564, 76.01120486855507, 62.468279376626015, 65.35384073853493, 58.08935634791851, 61.929586082696915, 57.13657647371292, 60.270861089229584, 58.93410801887512, 61.26417338848114, 59.22120161354542, 60.84956243634224, 58.3682955801487, 54.38437655568123, 44.29829277098179, 43.65220583975315, 44.02462385594845, 44.24579478800297, 43.546829894185066, 45.45070253312588, 44.73867014050484, 44.925357922911644, 40.13400882482529, 42.92315796017647, 41.26669384539127, 44.1249118745327, 43.283184841275215, 41.621355414390564, 40.413806810975075, 41.30583554506302, 41.98809653520584, 42.104507088661194, 40.06652444601059, 41.088339015841484, 40.58140441775322, 43.17479565739632, 40.49351513385773, 42.44885981082916, 41.07105374336243, 43.03117096424103, 42.05585449934006, 42.91579395532608, 40.88585168123245, 42.941609770059586, 42.09763705730438, 42.201614677906036, 37.13203690946102, 40.95926754176617, 39.00298051536083, 41.01284086704254, 42.49795697629452, 51.119173765182495, 48.47638137638569, 56.19922757148743, 52.41924360394478, 56.16647332906723, 51.00052893161774, 58.817693665623665, 46.673598513007164, 60.45346409082413, 24.543380811810493, 25.63422817736864, 53.99911142885685, 47.66931228339672, 56.4122973382473, 51.56722292304039, 54.88995082676411, 50.38563832640648, 52.33010418713093, 50.117634907364845, 49.56609070301056, 46.88073679804802, 52.11890771985054, 50.49046330153942, 50.5893187969923, 45.88535360991955, 40.34419074654579, 39.8935729265213, 40.10639950633049, 44.00628983974457, 42.73333914577961, 42.38771349191666, 41.963078677654266, 40.925540551543236, 39.68094773590565, 41.608227118849754, 40.58225937187672, 39.04058709740639, 40.84543325006962, 39.98418286442757, 41.63155026733875, 41.381880864501, 40.27438849210739, 40.67910857498646, 43.63807059824467, 41.96975491940975, 41.53484545648098, 41.55773162841797, 39.90614265203476, 41.32775656878948, 40.56231044232845, 41.09765611588955, 42.09189936518669, 43.380907997488976, 44.78251598775387, 45.551150143146515, 44.2222398519516, 43.47906053066254, 42.266253009438515, 45.11376701295376, 43.89696590602398, 43.867977261543274, 42.898090705275536, 45.5378432571888, 46.07995256781578, 49.783777222037315, 53.842894211411476, 58.64233307540417, 58.74576352536678, 61.95281803607941, 66.12272948026657, 46.708184257149696, 5.920747295022011, 2.1092216949909925, 0.7971415913198143, 0.03220744285499677, 0.08556014247005805, 15.750114005059004, 57.29799181222916, 38.29003617167473, 56.42386011779308, 31.088639795780182, 28.847286365926266, 42.77993604540825, 49.30444434285164, 56.881074383854866, 18.727853670716286, 0.28443934803362936, 0.026532812880759593, 0.017110463304561563, 0.03327393133076839, 0.07066027363180183, 0.047041991565492935, 0.024869552325981203, 0.02931721737695625, 0.006705288951707189, 0.040144363447325304, 0.022457661434600595, 0.03589238789572846, 0.02592837998236064, 0.026960273244185373, 0.02535964438720839, 0.07146987511077896, 0.07744717702735215, 0.03461874002823606, 0.033297668924205936, 0.04087897832505405, 0.04649528847949114, 0.10836314933840185, 0.048626090938341804, 8.511682916432619, 75.60415551066399, 67.0600175857544, 62.1496968716383, 45.68981610238552, 21.40221856534481, 24.89819247275591, 40.74413448572159, 49.96652841567993, 73.40423315763474, 31.891624107956886, 0.016637167900626082, 0.07314576330827549, 1.074314215220511, 4.4726264756172895, 1.0282871662639081, 37.448601722717285, 76.17084950208664, 64.9874871969223, 66.70359671115875, 58.98130148649216, 62.34117239713669, 59.192627146840096, 62.33258865773678, 61.90184757113457, 63.6172541230917, 61.46354489028454, 63.82413402199745, 60.236286744475365, 57.073218673467636, 47.87653796374798, 45.278355181217194, 45.67700698971748, 45.405731946229935, 44.319925010204315, 46.66393183171749, 45.63583619892597, 47.508197128772736, 42.45003394782543, 45.260750725865364, 43.052932396531105, 46.41185335814953, 45.733817741274834, 44.009143486618996, 42.507285475730896, 43.642527759075165, 44.369094371795654, 43.31017479300499, 42.84409560263157, 42.99086272716522, 43.07851642370224, 44.28059332072735, 42.81188853085041, 44.07977409660816, 42.92486026883125, 43.97509351372719, 44.547699987888336, 45.57021751999855, 42.03435905277729, 44.82811354100704, 44.80950593948364, 44.76380959153175, 38.53973217308521, 42.86748714745045, 42.13781610131264, 45.07215924561024, 45.327235758304596, 53.06970790028572, 49.58770394325256, 57.949216067790985, 54.68513421714306, 58.20633687078953, 53.746937960386276, 61.12828887999058, 49.458339884877205, 62.911650985479355, 26.191397979855537, 25.9568764641881, 56.47770702838898, 48.88334333896637, 58.06370012462139, 52.489444836974144, 56.4623748511076, 52.83673860132694, 54.795347303152084, 52.03851543366909, 52.19489984214306, 50.868451818823814, 55.75788505375385, 53.3003631234169, 51.98674701154232, 48.9944189786911, 43.36332634091377, 43.563978374004364, 42.894127517938614, 45.1936387270689, 45.511970445513725, 44.098317101597786, 44.511864110827446, 42.42709457874298, 42.2977951169014, 44.35111753642559, 41.65502920746803, 40.678333416581154, 43.655108883976936, 42.58079253137112, 42.19564899802208, 43.386721685528755, 42.167861089110374, 43.29236514866352, 44.09076690673828, 45.62672808766365, 43.307693526148796, 44.185887202620506, 41.18294633924961, 43.086632788181305, 42.13991738855839, 43.412472903728485, 43.592157661914825, 45.32013773918152, 46.07790067791939, 47.594969272613525, 44.35568869113922, 45.62200874090195, 44.01384003460407, 47.037033811211586, 45.3608525544405, 47.464290484786034, 45.593426674604416, 48.660067319869995, 48.94736610352993, 53.191726952791214, 55.72813645005226, 59.28490899503231, 61.902333945035934, 63.028042539954185, 65.62283590435982, 49.5470879226923, 7.297995742410421, 1.7526629590429366, 1.0071356012485921, 0.2432696259347722, 0.04793274689291138, 16.81606985628605, 63.7205895781517, 44.33805763721466, 42.58040115237236, 25.384344086050987, 33.19500356912613, 48.87043543159962, 55.64145170152187, 65.46913415193558, 31.655352786183357, 0.6268713029567152, 0.05512745672604069, 0.01946129028510768, 0.039319477436947636, 0.0551500736764865, 0.050088069910998456, 0.02215526779764332, 0.017760219161573332, 0.07790989868226461, 0.009540481860312866, 0.027545345365069807, 0.0369955013593426, 0.14083494519582018, 0.10802259261254221, 0.14384586800588295, 0.11974378357990645, 0.15211354155326262, 0.1020481702289544, 0.1266007308731787, 0.2610824763542041, 0.1667769398773089, 0.1978527262690477, 0.3104330110363662, 11.583442836999893, 85.70358797907829, 75.54735615849495, 71.11718907952309, 53.12433756887913, 24.048599861562252, 34.98589687049389, 52.37525716423988, 60.15316240489483, 78.34019869565964, 36.84930548071861, 0.35660290857777, 0.19179709808668122, 1.496484149247408, 13.32310063764453, 6.175722163170576, 39.87440675497055, 80.08201763033867, 65.35346075892448, 69.30227726697922, 61.497868448495865, 66.89455166459084, 60.03272786736488, 65.77779158949852, 63.528395891189575, 65.26516869664192, 61.543222814798355, 65.78117340803146, 61.24126821756363, 58.63213822245598, 48.76499868929386, 48.643861189484596, 49.065076187253, 47.66670562326908, 46.65203087031841, 49.13922160863876, 48.19144606590271, 50.863633677363396, 43.88479135930538, 47.26475939154625, 44.56064969301224, 48.78803685307503, 48.15163180232048, 45.91291733086109, 44.23721484839916, 45.443479120731354, 47.26078860461712, 45.849293544888496, 45.089581310749054, 45.7290717959404, 46.183090433478355, 47.31967784464359, 44.58005525171757, 45.088844150304794, 45.54034732282162, 46.83802708983421, 46.92680552601814, 46.60282351076603, 43.48231315612793, 45.387451127171516, 45.846067517995834, 48.71467798948288, 39.37222570180893, 45.07105730473995, 43.91951769590378, 45.243636444211006, 48.22096288204193, 55.52549712359905, 51.281508654356, 60.91727860271931, 56.98279492557049, 61.168247535824776, 55.68373203277588, 62.50189237296581, 51.5826690942049, 64.21627297997475, 28.50123703479767, 29.16927918791771, 55.22756651043892, 50.720932334661484, 59.85129900276661, 53.95969994366169, 58.94342511892319, 55.767464339733124, 57.797794193029404, 55.859400406479836, 53.825057968497276, 52.83106930553913, 58.497332856059074, 55.98974481225014, 54.630086570978165, 50.63777759671211, 45.73406092822552, 43.255298137664795, 44.018395990133286, 48.27881097793579, 47.728174924850464, 46.687524765729904, 46.82673029601574, 43.36891584098339, 44.38745118677616, 46.71652480959892, 43.87642040848732, 43.19640509784222, 45.244305208325386, 44.251794666051865, 44.60460193455219, 45.68950831890106, 45.106467604637146, 46.42022430896759, 47.333398908376694, 48.965874910354614, 45.974876806139946, 46.15833856165409, 44.134753346443176, 45.37979073822498, 43.749674409627914, 44.82166528701782, 44.85992543399334, 48.1278982758522, 48.863572999835014, 49.978235587477684, 47.62672416865826, 48.96459057927132, 47.552050575613976, 50.56252263486385, 47.20392845571041, 50.53145930171013, 49.4606539607048, 51.129429414868355, 54.399001970887184, 56.46124251186848, 58.497538045048714, 64.50495108962059, 63.83751690387726, 66.88390463590622, 66.92808106541634, 51.8863146007061, 8.816045634448528, 9.204252753406763, 2.7787823416292667, 0.40550949051976204, 0.17886058834847063, 20.284852422773838, 67.7413210272789, 56.809075847268105, 72.27610409259796, 40.79472117125988, 42.14530549943447, 58.23699362576008, 64.83835279941559, 73.5590672492981, 40.173359513282776, 1.077364501543343, 0.21972188871586695, 0.1716985960956663, 0.18850261549232528, 0.19677138741826639, 0.09864971274510026, 0.09694434644188732, 0.09124457064899616, 0.21957328106509522, 0.08325449001858942, 0.09414026018930599, 0.14571584266377613], [0.0402647398004774, 0.07731612116913311, 0.04397641328978352, 0.01621294330107048, 0.07921113588963635, 0.03870239277603105, 0.025743592632352374, 0.027942722772422712, 0.02929983071226161, 0.06531709237606265, 0.06116883938375395, 14.058790560811758, 68.21760267019272, 54.092818200588226, 49.065296575427055, 25.439705215394497, 24.68292072415352, 42.947883233428, 40.27097247540951, 49.75543834269047, 68.25616300106049, 11.213981062173843, 0.14538776886183769, 0.03455766498518642, 0.511774291517213, 0.7874960463959724, 3.051793179474771, 51.047794595360756, 71.08468562364578, 63.62350098788738, 63.38591493666172, 62.46521294116974, 62.58178688585758, 61.51591747999191, 60.558954030275345, 60.75338579714298, 59.825912564992905, 60.9334809333086, 59.95785288512707, 60.13071320950985, 56.39570742845535, 52.66669772565365, 46.832445189356804, 42.925240248441696, 45.19178442656994, 43.045291006565094, 43.24218884110451, 42.38187700510025, 42.09900118410587, 43.03795360028744, 42.95906223356724, 40.73829799890518, 43.83856303989887, 40.70131458342075, 41.56481824815273, 40.10968632996082, 41.1894515901804, 39.64603900909424, 40.038626343011856, 39.16843503713608, 41.15430727601051, 39.952222779393196, 41.26582369208336, 41.688911989331245, 42.298805862665176, 41.37266255915165, 42.29201182723045, 43.61028648912907, 42.20382995903492, 41.270056664943695, 42.774221152067184, 40.53262263536453, 40.97011595964432, 37.74800285696983, 40.081552639603615, 41.135323494672775, 43.846952989697456, 44.48666386306286, 48.37330050766468, 50.13555854558945, 56.95863202214241, 52.382332384586334, 57.09117271006107, 52.24247328937054, 55.910929441452026, 50.557978078722954, 61.59532941877842, 29.718300327658653, 27.434909753501415, 61.180912256240845, 48.920547142624855, 54.04418081045151, 48.33891615271568, 51.95346459746361, 47.38016299903393, 51.48895852267742, 47.18404032289982, 49.02740500867367, 49.70145083963871, 53.09706263244152, 51.71242833137512, 51.25441990792751, 47.18068890273571, 39.93803434073925, 38.8222736120224, 41.48694522678852, 42.4197381734848, 41.488955318927765, 41.131858080625534, 42.083429619669914, 41.10765337944031, 39.43686403334141, 42.237002179026604, 40.824617967009544, 39.48467306792736, 42.361943274736404, 40.85171051323414, 41.66639059782028, 39.88949574530125, 40.02392113208771, 40.00849775969982, 41.52951434254646, 41.3704776763916, 40.934356078505516, 42.30157971382141, 40.52237458527088, 41.35714799165726, 42.1406127512455, 43.23447145521641, 42.717873975634575, 43.91209289431572, 40.43516166508198, 41.580367013812065, 42.85585217177868, 39.889940321445465, 41.12409509718418, 41.94147303700447, 40.25449275970459, 41.06182403862476, 41.80645868182182, 43.77560801804066, 45.24376563727856, 51.12325854599476, 52.46975429356098, 58.156092166900635, 59.46819216012955, 61.382582634687424, 62.225996777415276, 60.7824732363224, 17.761041149497032, 0.16892464103875682, 0.8015030447859317, 0.043960349503322504, 0.1740807862370275, 4.317728262394667, 57.483095079660416, 45.21922655403614, 44.82630863785744, 35.351479053497314, 19.735736288130283, 37.887941747903824, 44.35296803712845, 59.22825023531914, 39.20016333460808, 1.0564709664322436, 0.045080844065523706, 0.056163572808145545, 0.058322298573330045, 0.06605063113966025, 0.054575295143877156, 0.11615985597018152, 0.05805267261166591, 0.05247138440608978, 0.07200051812105812, 0.022195776073203888, 0.02869765394279966, 0.01391045332638896, 0.07772266224492341, 0.03412928621401079, 0.016827413746796083, 0.04162225406616926, 0.044349379604682326, 0.01702968052995857, 0.058384601870784536, 0.014666510705865221, 0.09383916345541365, 0.026779452673508786, 18.98558434098959, 79.81693625450134, 60.1057181507349, 55.05771562457085, 35.03423027694225, 31.17160454392433, 34.90474462509155, 39.018719270825386, 55.20670562982559, 75.0752466917038, 12.945495899766684, 0.18412446370348334, 0.1370187327847816, 2.5140845077112317, 2.6044989936053753, 3.7183491373434663, 54.0998288244009, 72.39347219467163, 66.86891824007034, 65.19636198878288, 64.28036794066429, 64.2418760061264, 63.589082434773445, 62.81889796257019, 62.972877100110054, 61.623178124427795, 62.146375849843025, 59.99960124492645, 63.54129999876022, 58.47785510122776, 55.137420147657394, 48.83339121937752, 44.46792706847191, 48.09757590293884, 44.838053807616234, 44.21994097530842, 42.96399436891079, 44.827653765678406, 45.04590265452862, 45.076844394207, 42.6247675716877, 44.34319116175175, 43.0805379152298, 45.05599491298199, 41.480705961585045, 42.676000222563744, 42.99163028597832, 44.1133338958025, 40.70272050797939, 43.01829345524311, 41.6977883130312, 43.21199186146259, 42.97225512564182, 43.97651083767414, 43.98018904030323, 44.68833044171333, 44.87246856093407, 44.35070715844631, 43.47759760916233, 44.43607337772846, 43.08814510703087, 44.02147002518177, 39.39874827861786, 41.401617005467415, 42.847169637680054, 45.54656378924847, 47.32324965298176, 51.98335759341717, 51.09882205724716, 58.94715651869774, 54.238654375076294, 58.66009332239628, 54.012973085045815, 57.83066622912884, 51.307183876633644, 63.15771818161011, 31.31983458995819, 29.531810134649277, 63.06519314646721, 50.90986579656601, 55.52144654095173, 50.623296573758125, 54.446096643805504, 50.7348395884037, 53.37963826954365, 48.980925902724266, 51.63542926311493, 52.14230686426163, 54.823663383722305, 53.01057547330856, 52.88987874984741, 48.86254325509071, 42.09115080535412, 40.76865456998348, 43.744195103645325, 44.12976421415806, 44.70978029072285, 42.939945459365845, 44.81611758470535, 42.97436021268368, 40.772986337542534, 42.73489706218243, 44.30230915546417, 41.325537487864494, 42.27780818939209, 43.70028845965862, 42.13827207684517, 41.888078302145004, 40.80236256122589, 42.273491621017456, 43.964594677090645, 43.936536982655525, 44.236789271235466, 44.72883626818657, 42.6289701461792, 42.42403194308281, 44.348309487104416, 46.03855758905411, 44.47595223784447, 45.926315411925316, 43.468846678733826, 43.512297347187996, 43.21964085102081, 45.35517945885658, 43.65839570760727, 44.11167338490486, 43.96256558597088, 43.73375326395035, 45.097933262586594, 45.821513235569, 48.0013270676136, 54.280965104699135, 54.13539491593838, 60.56270822882652, 62.829415798187256, 63.0313141644001, 61.88898526132107, 64.82394397258759, 21.82069581001997, 0.26045536156743765, 1.4740841137245297, 0.35400058259256184, 0.11031786983949132, 5.130201615393162, 61.18736431002617, 53.92884559929371, 41.83224409818649, 35.962117686867714, 29.386331140995026, 44.40228559076786, 52.567583844065666, 62.18628130853176, 51.6224567592144, 2.188525339588523, 0.08742973863263614, 0.0407457553956192, 0.03644655327661894, 0.03521415768773295, 0.07283327460754663, 0.05410607969679404, 0.03644477212219499, 0.02796130986098433, 0.04044143031933345, 0.010382137625128962, 0.10994163807481527, 0.13034197152592242, 0.18922735238447785, 0.13323657010914758, 0.10216738883173093, 0.14619421621318907, 0.15005485358415172, 0.08612138422904536, 0.1308269056607969, 0.11257772435783409, 0.19659471174236387, 0.21922255691606551, 24.793749377131462, 89.58604484796524, 68.48528310656548, 64.00057375431061, 37.26092219352722, 34.96616452932358, 55.65899156033993, 54.34371493756771, 61.58761963248253, 81.29564970731735, 15.688008237630129, 0.4387720744125545, 0.24353077285923064, 2.575627430342138, 10.037229806184769, 4.853188879787922, 57.052551582455635, 74.23302948474884, 68.12767669558525, 66.50184273719788, 66.97927191853523, 65.63725993037224, 67.62361854314804, 65.27205392718315, 64.2975278198719, 63.40824633836746, 65.26603505015373, 63.09031739830971, 67.24600240588188, 60.48344828188419, 58.273958042263985, 52.14982286095619, 45.73853708803654, 50.0117801874876, 48.7357934564352, 47.134962156414986, 46.13152340054512, 47.43318535387516, 47.63736739754677, 46.893998086452484, 45.63658855855465, 46.865237429738045, 44.40895043313503, 47.50264182686806, 43.92750486731529, 45.525794103741646, 45.649481266736984, 45.62760204076767, 43.493773341178894, 46.271105110645294, 45.06968937814236, 44.94416691362858, 45.41560761630535, 45.74623167514801, 45.91719590127468, 46.59661844372749, 47.95012481510639, 43.986211717128754, 44.88876208662987, 46.07502043247223, 45.1257211714983, 46.47191673517227, 42.45479889214039, 44.33437563478947, 46.92004568874836, 46.991884633898735, 50.13859078288078, 52.888013049960136, 53.24609063565731, 61.396064311265945, 55.43671868741512, 62.10112027823925, 57.42963954806328, 61.46930918097496, 53.64067666232586, 65.76844409108162, 35.31525559723377, 31.759909875690937, 64.13301944732666, 53.31032998859882, 58.30778382718563, 53.86602357029915, 56.97425298392773, 52.61387296020985, 55.9263414144516, 51.498746797442436, 54.33374047279358, 54.728505089879036, 56.96031153202057, 56.35451763868332, 56.127639412879944, 51.5289855748415, 42.55823694169521, 42.19566039741039, 44.150822684168816, 45.75450003147125, 47.15621441602707, 45.09142801165581, 46.275512874126434, 44.344414696097374, 42.57764250040054, 45.25876343250275, 45.218234807252884, 43.00595171749592, 45.56110180914402, 44.66555066406727, 45.66208899021149, 44.26596790552139, 42.36304521560669, 44.05188359320164, 47.223406210541725, 45.94981715083122, 45.841044187545776, 45.94441004097462, 44.69298519194126, 44.41174328327179, 46.97845235466957, 47.26710006594658, 45.8500687032938, 48.520086631178856, 45.667404904961586, 45.806553438305855, 46.99003413319588, 46.18051417171955, 46.95818804204464, 46.25622510910034, 45.984334498643875, 46.08192466199398, 47.41281844675541, 48.84876139461994, 51.03542625904083, 56.50407001376152, 56.58238761126995, 63.894643038511276, 65.32232522964478, 68.1587590277195, 63.54743666946888, 69.0420064330101, 22.067724354565144, 2.8134882543236017, 4.44941352121532, 0.8744618017226458, 0.24234390060883015, 6.18620865046978, 67.85248026251793, 59.9090863019228, 59.67476047575474, 46.48349091410637, 31.402444057166576, 51.30254052579403, 61.70287884771824, 71.31181463599205, 62.73794710636139, 3.614453924819827, 0.2897585876053199, 0.19229093799367547, 0.15398204675875604, 0.1495516626164317, 0.1911280074273236, 0.16866491903783754, 0.14243924582842737, 0.07743213369394653, 0.10712960342061706, 0.08614308462711051, 0.20176558115053922], [0.04597401508362964, 0.0387662323191762, 0.059031769487774, 0.04468611427000724, 0.05128913944645319, 0.024780053026915994, 0.05903897945245262, 0.024689789315743838, 0.049656165938358754, 0.17991368105867878, 0.16975045844446868, 20.91764386743307, 71.24056085944176, 50.82951910793781, 40.50959587097168, 14.602868165820837, 25.130671598017216, 38.12891721725464, 48.71322266757488, 55.16803130507469, 57.38706283271313, 3.802119204774499, 0.117493198486045, 0.03457582162809558, 1.5094333793967962, 2.4404456466436386, 7.492871610447764, 63.02933447062969, 63.63247610628605, 67.05310955643654, 62.38056868314743, 65.434510409832, 64.24441426992416, 62.602317184209824, 61.68011426925659, 60.44211409986019, 59.755764529109, 62.764712870121, 60.376765206456184, 58.625944554805756, 55.870959386229515, 52.215392142534256, 46.92592777311802, 44.57738779485226, 43.26071284711361, 42.6093365997076, 43.724550157785416, 43.49862188100815, 42.06846222281456, 41.26984387636185, 42.01118789613247, 40.917591378092766, 41.97002850472927, 42.17747837305069, 43.54040443897247, 41.20172493159771, 38.78692790865898, 40.615059211850166, 41.40699751675129, 40.137367844581604, 40.155454874038696, 39.53314706683159, 41.04478195309639, 39.45482946932316, 40.27488626539707, 41.47512786090374, 42.75238372385502, 39.95290294289589, 42.58048474788666, 42.131314650177956, 41.7493287473917, 40.50419256091118, 40.43276019394398, 39.118756502866745, 41.991968527436256, 44.303658083081245, 43.97757478058338, 45.60717053711414, 48.387701734900475, 50.98593391478062, 56.26373291015625, 53.74940782785416, 53.65171507000923, 49.125348553061485, 58.00292618572712, 50.55687993764877, 57.240219712257385, 40.76648108661175, 34.460825845599174, 58.25934022665024, 48.84131759405136, 53.756103068590164, 46.70871622860432, 52.05476716160774, 46.7656409740448, 48.8402346521616, 47.692133858799934, 49.95947599411011, 46.61505505442619, 54.80840340256691, 49.84315283596516, 51.96801021695137, 46.28343164920807, 39.20345015823841, 40.39265334606171, 41.39793120324612, 40.56591644883156, 43.5929100215435, 42.07192003726959, 42.43188992142677, 38.72822105884552, 40.58300033211708, 39.932961612939835, 41.3746802508831, 38.86486932635307, 41.0007993131876, 38.15539799630642, 39.58184905350208, 39.83942963182926, 40.21628201007843, 39.822813123464584, 43.01225557923317, 42.71579168736935, 43.7427131831646, 41.92261464893818, 40.62349855899811, 41.20749682188034, 42.17865251004696, 41.73626884818077, 42.29801170527935, 43.47785219550133, 42.3387835174799, 41.66728354990482, 41.303019896149635, 42.37765163183212, 41.36492617428303, 39.898189678788185, 43.311569318175316, 42.07917004823685, 44.012263119220734, 43.78398656845093, 44.69908006489277, 47.08168521523476, 53.12419317662716, 56.76280193030834, 59.116608425974846, 59.218784943223, 64.51128914952278, 63.03962051868439, 36.12156093120575, 1.943526598624885, 0.8315127657260746, 0.045815588819095865, 0.046663863613503054, 2.038978901691735, 47.3176259547472, 51.04976288974285, 50.38303546607494, 28.06302934885025, 13.042612988501787, 33.598386123776436, 45.064894035458565, 52.01396495103836, 47.93157421052456, 4.122996786609292, 0.22046719794161618, 0.03597426904889289, 0.03649167585535906, 0.09588698638253845, 0.054655209605698474, 0.029233985515020322, 0.01195036616991274, 0.09042221165145747, 0.06910278025316074, 0.09734711740748025, 0.06800501767429523, 0.0916051802050788, 0.06462265737354755, 0.05216499244852457, 0.022355998335115146, 0.030369246960617602, 0.025841570968623273, 0.06394526208168827, 0.03872578156006057, 0.09763756432221271, 0.16438685328466818, 0.1564510681782849, 26.188430339097977, 82.28609696030617, 56.1342890560627, 48.18754367530346, 19.73615426570177, 28.225780315697193, 34.007935747504234, 52.26638920605183, 61.92829415202141, 64.06983643770218, 3.74996367841959, 0.09988716235966422, 0.17668468557531014, 4.012717679142952, 1.7631797259673476, 9.418471958488226, 65.94142600893974, 63.3407049626112, 70.5786819756031, 64.55757826566696, 66.85400784015656, 66.26232638955116, 64.61131498217583, 63.03955212235451, 62.71733321249485, 61.442000046372414, 65.34239575266838, 61.207735016942024, 61.74738205969334, 59.19113762676716, 54.19980525970459, 49.37111176550388, 46.551514863967896, 44.80640530586243, 45.9209007024765, 45.869641453027725, 44.99296769499779, 44.552415534853935, 43.27746234834194, 43.24663460254669, 41.77486337721348, 44.26539033651352, 45.03895282745361, 45.79969480633736, 44.09403473138809, 40.76104357838631, 43.56507271528244, 41.889374032616615, 43.365686014294624, 41.312333196401596, 42.89777912199497, 43.674795627593994, 41.231921911239624, 41.726795956492424, 42.800770327448845, 44.466372951865196, 42.51391611993313, 43.26266974210739, 43.86383928358555, 43.58455426990986, 42.15714566409588, 41.78355731070042, 42.910257652401924, 43.34077075123787, 45.75611114501953, 46.65066674351692, 48.699307814240456, 52.785521149635315, 52.04810231924057, 59.282108545303345, 55.53769066929817, 56.361418068408966, 52.49471515417099, 59.413600489497185, 53.52579742670059, 58.39495114982128, 41.42732262611389, 36.05798654258251, 59.21551711857319, 50.837916657328606, 54.38191048800945, 49.892269000411034, 52.85300552845001, 50.27542524039745, 51.663912534713745, 51.46324910223484, 52.9351457208395, 49.15567472577095, 55.47296494245529, 52.530915811657906, 53.30989681184292, 48.99110555648804, 41.29023738205433, 41.79396875202656, 42.225340604782104, 42.210350409150124, 44.71448823809624, 43.309775814414024, 44.87662933766842, 41.483502611517906, 42.94917516410351, 42.64601223170757, 42.23137088119984, 40.5151891708374, 43.77182722091675, 40.66653124988079, 41.92609906196594, 41.96291908621788, 41.77065700292587, 40.93050688505173, 45.50413906574249, 44.65961918234825, 44.9349258095026, 44.97392691671848, 43.62663321197033, 44.38857592642307, 44.92169111967087, 44.39869858324528, 43.580195903778076, 44.36603933572769, 44.287022575736046, 43.223569840192795, 42.502809315919876, 43.43771494925022, 43.23105923831463, 43.33086088299751, 45.45170187950134, 44.456364288926125, 46.22196614742279, 45.15903018414974, 48.68970952928066, 48.10732997953892, 56.658546924591064, 59.15826939046383, 63.13898138701916, 62.19138443470001, 64.32810097932816, 64.61233332753181, 40.02579063177109, 2.7779404493048787, 1.2965132296085358, 0.36165524215903133, 0.09233094126102515, 1.5584920719265938, 51.25865288078785, 55.94322390854359, 51.52839660644531, 31.029767654836178, 23.300357311964035, 40.08594900369644, 51.38618163764477, 58.855699226260185, 62.29160785675049, 8.323037289083004, 0.08503277975250967, 0.07399607900879346, 0.09399008660693653, 0.11361083103111014, 0.099674789380515, 0.04532983461103868, 0.04032419696159195, 0.04456819442566484, 0.022561508303624578, 0.06311618664767593, 0.06582390502444468, 0.12457463803002611, 0.10601997390040196, 0.16994485660688952, 0.18528381711803377, 0.13188146782340482, 0.2533267956459895, 0.16390279488405213, 0.20901436015265062, 0.22283586615230888, 0.3660633915569633, 0.21992765658069402, 32.79847204685211, 89.21675026416779, 63.96809309720993, 56.68948486447334, 22.07755632698536, 34.40108925104141, 48.30853298306465, 64.77861240506172, 66.27284422516823, 70.67948296666145, 5.107375765219331, 0.4014482506318018, 0.21377969038439915, 6.964733675122261, 8.50435595959425, 10.612221602350473, 66.49764016270638, 66.28425121307373, 71.00520148873329, 67.43138685822487, 70.00583231449127, 68.09398770332336, 67.17809244990349, 65.76605781912804, 64.6312715113163, 65.58593988418579, 68.43392506241798, 63.179684802889824, 63.77706974744797, 62.59249471127987, 57.745573595166206, 51.95303522050381, 49.32275556027889, 47.98913732171059, 46.96237161755562, 47.25375898182392, 47.0147480070591, 48.03823068737984, 44.81007590889931, 45.33988527953625, 43.752246871590614, 45.6414370983839, 46.967402547597885, 48.07153210043907, 46.681103110313416, 43.316319063305855, 46.54372148215771, 46.39829948544502, 45.41339993476868, 44.83830839395523, 44.90823984146118, 46.16293251514435, 43.20413388311863, 42.74487152695656, 44.94559943675995, 45.86688280105591, 43.616578951478004, 45.77577129006386, 44.70938891172409, 45.11906012892723, 44.03514549136162, 45.66566839814186, 44.85846251249313, 45.2252796292305, 47.41977207362652, 46.768285632133484, 50.94712659716606, 55.50904780626297, 54.6760793030262, 61.760012581944466, 56.878175139427185, 58.69788609445095, 54.744335040450096, 62.483809143304825, 54.825274497270584, 60.58883562684059, 44.351824298501015, 39.20828349888325, 61.75579480826855, 52.5919633358717, 57.331544011831284, 51.69329635798931, 57.36509621143341, 52.624504789710045, 53.53732220828533, 54.570539966225624, 54.73228968679905, 49.289647936820984, 59.34461519122124, 53.52338455617428, 55.70585444569588, 51.57629683613777, 43.17218899726868, 43.319621086120605, 45.06701432168484, 43.412575498223305, 48.03128086030483, 44.98075895011425, 46.87139689922333, 43.39956879615784, 44.90116462111473, 44.15121026337147, 44.431221038103104, 41.001772060990334, 44.737279415130615, 41.664429903030396, 43.6037128418684, 43.59468452632427, 44.5116513222456, 42.962155267596245, 47.76253268122673, 46.48093365132809, 47.497512102127075, 47.6263327896595, 45.52732162177563, 45.47407127916813, 46.64355732500553, 47.40059830248356, 44.982932433485985, 47.84514784812927, 45.16700595617294, 45.802719444036484, 46.576175540685654, 46.130497455596924, 46.129083931446075, 45.74326403439045, 48.5764642059803, 46.575491577386856, 49.485660418868065, 47.37621121108532, 51.00885048508644, 51.757330521941185, 59.14677880704403, 61.94516524672508, 67.74124503135681, 64.95630607008934, 68.28368112444878, 67.22284644842148, 41.61464497447014, 3.74483585357666, 2.826714632101357, 1.2315208045765758, 0.2769391145557165, 2.358904634602368, 59.648028910160065, 59.4421673566103, 67.28200167417526, 35.60461387038231, 21.73854421824217, 47.86068521440029, 62.452681213617325, 65.25770589709282, 72.81991571187973, 11.165766399353743, 0.5672235286328942, 0.13967842678539455, 0.14370714576216415, 0.29696216981392354, 0.2203660728991963, 0.14338784414576367, 0.13294569274876267, 0.18291324900928885, 0.106603851163527, 0.1393034344073385, 0.22137825842946768], [0.10936575374216773, 0.06420486533897929, 0.019433181441854686, 0.00530829521267151, 0.0355278894858202, 0.10727809232776053, 0.05986480427964125, 0.04052655836858321, 0.0679320571362041, 0.05132704463903792, 0.08533897504094057, 25.69180268794298, 64.09620702266693, 50.36589078605175, 44.386117458343506, 22.880035266280174, 35.20247384905815, 40.57942472398281, 40.78023634850979, 62.089204117655754, 43.674848824739456, 0.9116102114785463, 0.09051237517269328, 0.21643565880367532, 3.917584321461618, 0.6229066906962544, 23.43573074787855, 72.19440087676048, 67.49044328927994, 66.72291487455368, 63.4183993935585, 63.831802010536194, 60.340363159775734, 63.230818659067154, 57.95998848974705, 58.911753818392754, 58.155355006456375, 58.05210694670677, 56.61003112792969, 54.6571259200573, 49.402524679899216, 49.36953864991665, 46.58850587904453, 43.070297464728355, 42.77232125401497, 42.69324749708176, 40.81082470715046, 41.378138065338135, 43.469747230410576, 43.37790995836258, 41.54600165784359, 41.42523653805256, 40.527728497982025, 40.562971606850624, 41.60424493253231, 40.48563815653324, 40.409022867679596, 40.78054413199425, 40.449103116989136, 39.277166202664375, 38.672873228788376, 40.51293969154358, 40.765295550227165, 40.0756249576807, 39.675791412591934, 39.79618415236473, 41.10364459455013, 42.395214289426804, 43.45314972102642, 42.26483188569546, 42.65360802412033, 39.65326242148876, 40.54732404649258, 41.386448219418526, 45.29846750199795, 48.03308576345444, 48.68913196027279, 49.230899289250374, 52.41851024329662, 53.17383371293545, 54.284438118338585, 53.566231057047844, 51.08025625348091, 53.13354827463627, 56.44686408340931, 49.47332248091698, 56.17837429046631, 45.5344994366169, 38.52050140500069, 57.65555262565613, 50.28345800936222, 50.51365725696087, 47.87720672786236, 49.631344601511955, 50.88792957365513, 53.35022024810314, 52.68186271190643, 52.89618261158466, 52.16638997197151, 52.17976525425911, 49.58132788538933, 52.1287339925766, 46.207245737314224, 37.73822218179703, 40.664407163858414, 40.0100214779377, 41.514569744467735, 42.79889702796936, 42.03390687704086, 41.20870515704155, 41.48335441946983, 40.33460386097431, 41.146308705210686, 40.526288375258446, 41.55188374221325, 40.38091957569122, 39.492994621396065, 40.655215457081795, 41.57600484788418, 41.19405314326286, 41.804410591721535, 42.80305400490761, 44.45079758763313, 44.047559425234795, 41.547103598713875, 41.56892582774162, 41.28488726913929, 41.52619332075119, 40.00883214175701, 41.69828608632088, 41.87793284654617, 41.03877067565918, 40.52276596426964, 43.29673871397972, 41.04027159512043, 41.17377743124962, 41.744529604911804, 42.59421721100807, 39.82932597398758, 42.810178622603416, 43.44928912818432, 44.508022516965866, 45.41579380631447, 47.62757912278175, 52.58697800338268, 58.020029067993164, 58.931725546717644, 60.9874152392149, 67.01753586530685, 51.5128668397665, 5.932644456624985, 0.6605821440462023, 0.7484942267183214, 0.04749295760120731, 0.4714083153521642, 28.7200178951025, 60.11486046016216, 45.90910613536835, 46.9633823633194, 18.75222936272621, 18.136438205838203, 40.21741434931755, 50.27926303446293, 59.73057568073273, 12.74961356073618, 0.10428811292513274, 0.020400962421263102, 0.11419774367823265, 0.04791487968759611, 0.028839587830589153, 0.0383569898258429, 0.015228107768052723, 0.05004649479815271, 0.06921353095094673, 0.00526745297065645, 0.019096882788289804, 0.02131250344973523, 0.06555211570230313, 0.051179676374886185, 0.022184649424161762, 0.02348809823160991, 0.06482839555246755, 0.0513668200437678, 0.0369470539590111, 0.02246637610369362, 0.024515399454685394, 0.036296142206992954, 36.14365294575691, 71.57285302877426, 57.20583915710449, 50.98378323018551, 22.539849020540714, 27.167550399899483, 36.36506326496601, 47.455528154969215, 68.02995353937149, 47.8873597830534, 0.798183447914198, 0.021570781973423436, 0.27623633039183915, 4.047700027003884, 0.573059362359345, 25.507936254143715, 75.0092214345932, 67.07085460424423, 68.43797564506531, 65.23790135979652, 67.91921228170395, 62.8374257683754, 66.38228595256805, 62.39979185163975, 61.48397259414196, 59.45636719465256, 59.51729692518711, 56.785262525081635, 56.47469758987427, 52.00598157942295, 52.269679829478264, 48.26114572584629, 44.55932356417179, 44.44032534956932, 44.26995389163494, 41.358439922332764, 43.71938243508339, 44.985026121139526, 45.55407978594303, 43.4149731695652, 43.77093426883221, 41.754785254597664, 43.60266789793968, 43.357942029833794, 43.024300932884216, 43.13247732818127, 41.96442000567913, 42.51748412847519, 41.27404645085335, 42.05191411077976, 42.278165370225906, 42.51940302550793, 42.339623272418976, 42.630235478281975, 42.33762837946415, 42.17365577816963, 43.41329365968704, 45.11213310062885, 45.28734929859638, 43.46411593258381, 40.99322251975536, 42.85238675773144, 44.289834424853325, 49.70591560006142, 49.33299221098423, 49.94681127369404, 51.268904730677605, 53.926930502057076, 54.87076185643673, 55.696514546871185, 55.55635146796703, 53.259644508361816, 55.25585979223251, 57.14040666818619, 52.44098223745823, 57.62597121298313, 46.617612317204475, 41.07941709458828, 58.858701065182686, 51.32775217294693, 53.3642452955246, 50.37040114402771, 53.01759749650955, 50.677002891898155, 55.144787952303886, 52.339269295334816, 55.547083765268326, 53.93162325024605, 55.35996660590172, 51.019170731306076, 54.27877262234688, 47.964233458042145, 41.19747295975685, 42.296772971749306, 43.865404799580574, 43.32262672483921, 45.1402173936367, 42.86552645266056, 42.90186010301113, 42.12028384208679, 43.21433253586292, 43.3245038241148, 43.03375482559204, 43.03731143474579, 41.666299402713776, 40.99071465432644, 43.6315805464983, 42.23453611135483, 43.87562245130539, 45.746159479022026, 46.19764365255833, 46.286961659789085, 46.09472997486591, 43.61328832805157, 43.504826948046684, 42.99590885639191, 43.80970738828182, 40.972943007946014, 43.20523202419281, 43.616168573498726, 44.79191668331623, 42.123475670814514, 43.9465494453907, 42.61479690670967, 43.97260084748268, 44.05722230672836, 44.852580428123474, 41.6030365973711, 45.44676214456558, 46.23958200216293, 47.53284640610218, 47.3640176653862, 49.12145376205444, 55.18582955002785, 60.87467148900032, 63.82322207093239, 64.35432717204094, 67.22963288426399, 57.679525539278984, 7.540019955486059, 0.6326802412513644, 0.973448627628386, 0.1040378310426604, 0.13882813334930688, 30.631860606372356, 64.70349043607712, 52.729379162192345, 36.883632838726044, 19.96734905987978, 23.865489587187767, 44.58109259605408, 56.09137035906315, 69.30828094482422, 22.138495557010174, 0.05168739444343373, 0.07457706931745633, 0.19814735889667645, 0.03401388596103061, 0.10202773890341632, 0.03417106170672923, 0.05386904886108823, 0.034025070126517676, 0.011713921630871482, 0.04196095542283729, 0.025163953032460995, 0.1944611856015399, 0.18317706766538322, 0.09293677867390215, 0.12597737135365605, 0.1377739867893979, 0.14829351450316608, 0.12783691141521558, 0.10153825540328398, 0.17365739098750055, 0.1483006836497225, 0.19539492612238973, 46.56471535563469, 80.98388403654099, 66.25536516308784, 60.80208398401737, 33.9712031185627, 47.25968286395073, 54.194166362285614, 54.04849737882614, 74.55136880278587, 55.22734232246876, 1.2517763301730156, 0.1377519450034015, 0.572583437897265, 14.655357599258423, 4.478244949132204, 28.56975495815277, 75.57319477200508, 72.59565934538841, 70.35273090004921, 68.04682463407516, 67.86871299147606, 63.678917214274406, 69.02436777949333, 62.88477502763271, 64.4316454231739, 61.1981937289238, 61.57599225640297, 61.02074325084686, 59.79231856763363, 54.07975450158119, 52.78982251882553, 50.5800586938858, 46.40701241791248, 47.397421672940254, 46.604123041033745, 43.8313814252615, 45.341230407357216, 47.4124650657177, 46.96123547852039, 45.77027678489685, 46.13153859972954, 43.67122381925583, 45.80852933228016, 47.19811476767063, 46.24740958213806, 46.88198693096638, 46.017100140452385, 45.53980395197868, 44.285890236496925, 43.37178088724613, 44.23487797379494, 45.86184047162533, 44.94308777153492, 43.613071739673615, 44.60880450904369, 45.02489738166332, 45.36535531282425, 48.06740552186966, 47.39519119262695, 46.627370193600655, 43.4317796677351, 46.881496757268906, 46.150495782494545, 52.620765790343285, 52.63213858008385, 51.11992992460728, 52.73890145123005, 56.67834386229515, 57.320604398846626, 58.656437918543816, 56.95996195077896, 56.25570394098759, 57.539183869957924, 61.01911313831806, 55.20547829568386, 58.651258796453476, 48.41617360711098, 43.45698371529579, 61.92042097449303, 53.57327587902546, 56.048672050237656, 52.712169885635376, 53.30265060067177, 53.25783580541611, 57.149537578225136, 55.40689408779144, 58.987852334976196, 56.61933682858944, 55.998548939824104, 53.942391872406006, 55.95038652420044, 50.84524646401405, 41.43048405647278, 44.75564382970333, 45.1572784781456, 45.891695469617844, 46.64298735558987, 46.482825949788094, 45.15451982617378, 44.8577481508255, 44.43369470536709, 44.82433274388313, 44.60407376289368, 46.622886434197426, 44.48828637599945, 42.95580580830574, 45.585116520524025, 46.10755808651447, 46.55464969575405, 47.66710080206394, 47.94063672423363, 49.387903064489365, 48.84937696158886, 46.022511050105095, 45.98313756287098, 46.02790296077728, 45.843487456440926, 43.299675956368446, 45.16381412744522, 47.16424338519573, 46.43997944891453, 45.298353508114815, 47.18623660504818, 45.13497747480869, 46.48971498012543, 47.64308609068394, 46.88156895339489, 43.253652825951576, 49.63527739048004, 49.800986498594284, 49.304372146725655, 50.817405357956886, 53.23591858148575, 59.18095797300339, 63.85576352477074, 66.79356828331947, 68.32797154784203, 70.08842468261719, 58.976095765829086, 7.826800066977739, 1.818736307322979, 2.4907397478818893, 0.18814368318999186, 0.624087299220264, 37.806683108210564, 71.39317587018013, 61.883099377155304, 57.1248959004879, 27.893233560025692, 28.881305940449238, 54.216273576021194, 64.66508209705353, 78.91443908214569, 30.282258465886116, 0.2751693001482636, 0.16534625727217644, 0.2125431239255704, 0.1421021920396015, 0.25341971253510565, 0.12198132171761245, 0.10680329593014903, 0.10166578606003895, 0.18018637580098584, 0.0853562522388529, 0.1561647476046346], [0.05553902956307866, 0.032698677823645994, 0.09965131524950266, 0.019687773346959148, 0.05131807207362726, 0.06588831602130085, 0.08256899789557792, 0.021923582280578557, 0.059683542131097056, 0.05548275621549692, 0.16879881732165813, 39.13913480937481, 69.06287491321564, 48.33440579473972, 38.94680052995682, 28.51570475846529, 45.71068078279495, 44.76946748793125, 50.733977034687996, 65.19348174333572, 27.56874807178974, 0.10763696525827982, 0.09103000833420083, 0.6248157913796604, 1.4711371343582869, 1.6056476603262126, 48.24978433549404, 71.77314788103104, 61.69462189078331, 66.60006746649742, 61.06914505362511, 62.466204687952995, 62.167711704969406, 61.02494962513447, 60.52451267838478, 59.66934196650982, 55.37786364555359, 49.69246432185173, 44.97441329061985, 46.084930300712585, 44.12703596055508, 44.80784922838211, 43.56764517724514, 43.19361984729767, 42.3090311139822, 42.571745216846466, 40.70661149919033, 41.52477599680424, 42.864663898944855, 41.42268307507038, 42.74692341685295, 43.740026727318764, 42.108702063560486, 38.79764333367348, 38.921877667307854, 38.61163571476936, 40.170049890875816, 40.006312876939774, 40.64154379069805, 40.12455113232136, 38.8314501196146, 40.12686140835285, 41.033219173550606, 40.619250386953354, 39.918237403035164, 41.049527898430824, 42.41789147257805, 42.35168382525444, 43.60120877623558, 42.755039781332016, 41.38558566570282, 40.940648540854454, 41.42717823386192, 44.33798164129257, 46.787649393081665, 47.53454111516476, 49.80550825595856, 50.347013399004936, 53.35418343544006, 53.03382642567158, 54.85884569585323, 49.33298461139202, 50.26950515806675, 52.423278987407684, 51.762578040361404, 52.136705964803696, 52.82422587275505, 48.71506176888943, 41.239255517721176, 54.87458825111389, 52.18624770641327, 51.53681695461273, 49.45779271423817, 53.173480331897736, 52.60990597307682, 52.66114242374897, 52.05972209572792, 55.40386185050011, 51.48468375205994, 49.93775635957718, 49.59249168634415, 53.303102776408195, 42.872947454452515, 40.22911012172699, 39.17448051273823, 40.702678710222244, 41.63780093193054, 42.93443575501442, 40.855042934417725, 41.40084184706211, 40.70619732141495, 40.85869833827019, 39.989669770002365, 38.8766410946846, 38.54991562664509, 40.94891309738159, 40.37663720548153, 41.3389203697443, 41.69865466654301, 43.23346450924873, 41.808483973145485, 43.58268857002258, 42.419551983475685, 41.449646428227425, 40.406526401638985, 42.05984428524971, 40.77350690960884, 41.311064064502716, 41.65713809430599, 41.52143597602844, 40.38091957569122, 42.06870540976524, 42.16447927057743, 43.27581703662872, 43.72475914657116, 43.32240633666515, 45.36937929689884, 46.805417239665985, 45.60624718666077, 48.22286657989025, 49.45287577807903, 48.88840466737747, 47.67497017979622, 44.66852590441704, 45.54805710911751, 54.290191009640694, 56.70708931982517, 61.17822200059891, 61.174437403678894, 64.31092590093613, 16.315007843077183, 0.3951428452273831, 0.19994409842183813, 0.23675879405345768, 0.027867444878211245, 14.821618627756834, 66.88918635249138, 44.10391420125961, 49.96277801692486, 28.91212798655033, 17.93648913502693, 42.26657599210739, 47.07543455064297, 58.91483545303345, 24.887009672820568, 0.36302186257671565, 0.023474886147596408, 0.06762463730410673, 0.08027092277188785, 0.020556965573632624, 0.03335246910864953, 0.038280600565485656, 0.08377524020033889, 0.0038132742020025034, 0.066696232825052, 0.03998299456725363, 0.051283966677146964, 0.09123400988755748, 0.0991702699684538, 0.08032420155359432, 0.01823288188461447, 0.027038612497563008, 0.04646945802960545, 0.1365140129928477, 0.04221081057039555, 0.11475707811769098, 0.6258726690430194, 50.98346024751663, 75.06909102201462, 55.41160583496094, 44.243837893009186, 26.16866759955883, 36.68742656707764, 44.941172674298286, 55.52772380411625, 72.77141511440277, 31.1400643363595, 0.13805241091176867, 0.042362661406514235, 1.325938613153994, 3.402141029946506, 1.9723252533003688, 51.10624685883522, 74.00330141186714, 64.996827095747, 68.33937853574753, 64.28734436631203, 65.44955760240555, 63.794191628694534, 63.640892654657364, 62.82884202897549, 61.14027343690395, 58.31605218350887, 51.96891836822033, 47.97323137521744, 48.246828094124794, 47.09994703531265, 45.83950147032738, 44.98876892030239, 45.37301570177078, 44.767130613327026, 44.72012333571911, 42.80696399509907, 44.31058891117573, 45.19611619412899, 43.58274556696415, 45.8894269913435, 44.525292590260506, 43.9961101859808, 42.02362082898617, 40.27005672454834, 41.71608053147793, 42.89436690509319, 42.09116220474243, 41.63232542574406, 43.03257308900356, 41.70309662818909, 43.01883302628994, 42.857144102454185, 41.318952441215515, 42.12366186082363, 43.7175053358078, 45.53079463541508, 45.496216490864754, 43.41839298605919, 45.48368476331234, 41.92910090088844, 41.92752778530121, 42.799808979034424, 45.53677551448345, 48.32923427224159, 49.12023022770882, 52.8329274058342, 53.378391936421394, 55.41648477315903, 55.58454215526581, 56.3077687472105, 52.73605540394783, 53.27907666563988, 56.83827728033066, 55.34667111933231, 53.43218944966793, 55.092692747712135, 50.680973678827286, 42.89387293159962, 57.03670643270016, 53.0183232575655, 53.127335608005524, 51.67203649878502, 55.58319702744484, 52.58489191532135, 53.95737826824188, 53.91197070479393, 56.46310821175575, 52.062298357486725, 52.20748856663704, 52.36333720386028, 55.14988347887993, 45.98417870700359, 40.67850060760975, 41.253694742918015, 42.475891560316086, 42.57548801600933, 44.82530549168587, 43.67561638355255, 43.420019298791885, 42.118323147296906, 43.171706423163414, 41.82189725339413, 42.38641016185284, 42.20851890742779, 41.63459770381451, 41.716061532497406, 43.74474607408047, 44.44165147840977, 45.412370190024376, 44.03394855558872, 47.34252601861954, 44.96812842786312, 43.429264202713966, 42.87446737289429, 44.41873490810394, 42.14118272066116, 43.007433637976646, 43.19239631295204, 45.553061440587044, 43.6482198536396, 43.25310945510864, 45.61271443963051, 44.98075895011425, 46.07414647936821, 47.700554206967354, 47.7969816327095, 48.98902326822281, 48.2370588183403, 51.72026731073856, 51.71108320355415, 51.92288003861904, 49.5797585695982, 48.364754766225815, 46.48406468331814, 57.3811199516058, 59.081448912620544, 64.5478355884552, 62.00208239257336, 68.29095393419266, 17.93525230139494, 0.43079933035187423, 0.7969338493421674, 0.2447057855897583, 0.04007615636510309, 15.335563849657774, 72.55703061819077, 50.24786151945591, 46.96978881955147, 30.970903113484383, 23.720344975590706, 47.835237979888916, 55.068510845303535, 65.80586448311806, 36.8990334123373, 0.10026280782767572, 0.07032174296909943, 0.038036508194636554, 0.1024240606056992, 0.0601368607749464, 0.034707163213170134, 0.08215992609621026, 0.07793727651005611, 0.015854602861509193, 0.025844220435828902, 0.11941060380195267, 0.16335188382072374, 0.311300937901251, 0.24155576946213841, 0.1751951506594196, 0.09177183688734658, 0.11556149198440835, 0.1952135600731708, 0.23987484950339422, 0.1264590400387533, 0.1785608200589195, 1.4652380696497858, 63.323602080345154, 81.09210222959518, 64.8648601770401, 50.152646228671074, 37.61403724551201, 56.831646636128426, 57.367372289299965, 64.83791962265968, 77.0869043469429, 35.733468756079674, 0.15794109291164204, 0.23322554770857096, 1.7419092985801399, 10.527944024652243, 5.080024357885122, 53.22897255420685, 75.67318260669708, 66.61024332046509, 72.26389154791832, 67.28719979524612, 67.38440617918968, 66.90757736563683, 65.65090879797935, 65.85382550954819, 63.61122764647007, 60.695290714502335, 53.69646526873112, 48.986617997288704, 51.04231908917427, 49.06759925186634, 49.972509294748306, 47.48341865837574, 48.57307478785515, 46.91498056054115, 46.95456683635712, 44.13618966937065, 45.95525845885277, 48.76535587012768, 45.216099321842194, 47.02856406569481, 46.93657100200653, 47.52675913274288, 43.81468892097473, 41.95766396820545, 44.0004875510931, 43.78792315721512, 44.10748980939388, 43.74574542045593, 45.91370388865471, 44.161439314484596, 44.8881009221077, 46.215951070189476, 43.53298723697662, 44.33083802461624, 44.98110473155975, 46.52944564819336, 46.63338907063007, 46.12922452390194, 47.71182060241699, 46.53657026588917, 44.59611319005489, 45.68356163799763, 48.42077136039734, 50.192221105098724, 51.74669109284878, 54.206542298197746, 55.65869517624378, 56.720924377441406, 57.90511563420296, 58.5621003806591, 54.54212509095669, 54.48277607560158, 59.78404641151428, 55.81710107624531, 56.6149290651083, 56.27318300306797, 51.2795327603817, 44.62153762578964, 58.917518109083176, 55.05006663501263, 56.05315200984478, 54.581825360655785, 57.41510912775993, 56.51062846183777, 56.06847658753395, 54.96877379715443, 59.22651752829552, 57.06037916243076, 55.42837433516979, 53.928344026207924, 58.39815437793732, 47.489562928676605, 43.59224125742912, 42.09881879389286, 43.97884011268616, 45.680138021707535, 47.46810548007488, 45.03374330699444, 45.464651584625244, 46.08198545873165, 43.61462965607643, 45.28294153511524, 44.38096113502979, 43.06403160095215, 44.553753063082695, 45.345611572265625, 45.38111686706543, 47.00576908886433, 49.335199892520905, 46.19697868824005, 48.388834074139595, 47.577296420931816, 46.00665830075741, 44.39168035984039, 46.80540584027767, 43.67363668978214, 44.438862428069115, 43.97008918225765, 47.93629355728626, 46.294610649347305, 45.44865824282169, 49.204008132219315, 47.53962144255638, 48.598883002996445, 49.517415314912796, 51.28078289330006, 52.05750681459904, 49.63768646121025, 54.07303266227245, 55.675915852189064, 54.60827574133873, 53.01295794546604, 51.28590501844883, 49.44055303931236, 60.21702937781811, 61.79866410791874, 66.08935207128525, 65.84296569228172, 70.45307591557503, 19.72352374345064, 1.6270462120883167, 2.052201717160642, 0.5816290900111198, 0.14795218594372272, 19.169302582740784, 79.44843202829361, 58.07845093309879, 64.03224885463715, 38.11961531639099, 28.00636488944292, 56.41074322164059, 62.75537297129631, 73.80552962422371, 50.11788949370384, 0.5385261622723192, 0.1294999456149526, 0.19136313465423882, 0.2385080064414069, 0.1083628970081918, 0.09929982668836601, 0.23287676798645407, 0.26498302642721683, 0.18101122841471806, 0.1765420299489051, 0.1519077440025285], [0.03002746198035311, 0.04928131456836127, 0.02238147812022362, 0.0396059167542262, 0.060033802437828854, 0.054625019038212486, 0.01296649807045469, 0.022372507410182152, 0.09807083013583906, 0.12480681150918826, 3.3461909322068095, 55.18616773188114, 59.99639041721821, 40.90555362403393, 46.9727336615324, 40.68622939288616, 37.50153288245201, 40.92938594520092, 47.588521018624306, 70.83409667015076, 22.370079830288887, 0.03739724816114176, 0.05225297776632942, 0.49042445432860404, 1.106638724450022, 7.019133931025863, 71.6711613535881, 64.25664961338043, 63.768261820077896, 59.14541848003864, 61.11546456813812, 57.9581493884325, 60.15608064830303, 57.97645300626755, 55.08546553552151, 50.598924681544304, 45.9241609275341, 40.84134466946125, 43.45130681991577, 41.81044086813927, 42.333482801914215, 42.51445569097996, 42.51688756048679, 40.62708556652069, 43.45671392977238, 40.388861149549484, 43.416553884744644, 40.94624564051628, 43.612729758024216, 40.069803670048714, 40.02569183707237, 40.07366806268692, 41.16051994264126, 40.16389802098274, 41.424400582909584, 39.890438094735146, 40.95815800130367, 40.15213005244732, 40.77944599092007, 38.952834606170654, 40.91284543275833, 40.02342715859413, 41.26520052552223, 39.54078085720539, 40.14538161456585, 40.699266493320465, 42.9422253370285, 41.75825446844101, 42.72950515151024, 42.217923402786255, 42.34011344611645, 40.154501125216484, 42.44716130197048, 44.01801981031895, 46.04777969419956, 47.05086126923561, 52.57467046380043, 53.70799385011196, 53.786649629473686, 53.8055270165205, 52.35793009400368, 50.15855111181736, 56.301981657743454, 52.63299733400345, 48.27708587050438, 48.91978718340397, 55.765526443719864, 48.844254836440086, 39.574682638049126, 54.80372205376625, 51.24838583171368, 51.367091462016106, 50.57136096060276, 51.01928852498531, 51.82579904794693, 51.805618330836296, 49.297513514757156, 50.11131964623928, 48.768973276019096, 49.04620260000229, 50.951572358608246, 51.10052816569805, 42.90910631418228, 38.9650509506464, 40.75920447707176, 40.95666088163853, 41.92687042057514, 43.30024592578411, 40.47780677676201, 41.81197978556156, 39.791377410292625, 39.38110962510109, 40.09281523525715, 41.081685572862625, 39.46176029741764, 39.88176316022873, 41.990080028772354, 43.783701583743095, 43.85032340884209, 44.54424977302551, 43.18114131689072, 42.73794449865818, 41.93778723478317, 41.15243397653103, 41.72439448535442, 41.331069990992546, 41.510823145508766, 41.43421545624733, 42.1566516906023, 41.62126041948795, 42.16825246810913, 44.04950872063637, 45.284263864159584, 48.587753400206566, 49.563145861029625, 50.050541907548904, 49.21424098312855, 53.83831925690174, 51.32289223372936, 53.88850316405296, 52.30122193694115, 54.605828672647476, 52.87893533706665, 51.76515430212021, 48.58831577003002, 50.04884719848633, 55.104954689741135, 61.36932134628296, 61.8869523704052, 66.8036225438118, 29.884594604372978, 0.13999422546476126, 0.6819370575249195, 0.028915157017763704, 0.1655161051894538, 5.3362142108380795, 59.93777856230736, 51.98847971856594, 43.780133575201035, 24.457469321787357, 16.645565405488014, 30.174408853054047, 46.998701468110085, 50.285304710268974, 35.09387947618961, 0.4330942884553224, 0.09270762573578395, 0.049299857128062285, 0.04669825473683886, 0.021042563930677716, 0.04846210598770995, 0.09499948166194372, 0.08582397596910596, 0.08145778760081157, 0.010087833397847135, 0.09038719712407328, 0.06620676416787319, 0.07228322443552315, 0.022737818471796345, 0.011543013370101107, 0.11308322340482846, 0.009384939767187461, 0.08600825123721734, 0.1331123197451234, 0.09683018186478876, 0.15410978521686047, 5.630004946142435, 64.34427291154861, 65.04410415887833, 49.39764194190502, 52.701363265514374, 52.14334420859814, 38.20981487631798, 41.801640540361404, 52.327725514769554, 76.73830345273018, 23.44258937984705, 0.07034668655251153, 0.07907618375611492, 1.2791018513962626, 3.430555430240929, 9.061872493475676, 75.73649480938911, 66.12771481275558, 66.41220554709435, 60.154796317219734, 63.77432629466057, 61.04639947414398, 61.471121683716774, 60.41385121643543, 56.92484803497791, 52.864036336541176, 47.66058035194874, 42.99574166536331, 44.86341364681721, 44.1137632727623, 44.05694492161274, 44.14722427725792, 46.3163036853075, 45.58723300695419, 45.178412944078445, 42.266313806176186, 44.12706255912781, 42.73249939084053, 45.16176223754883, 42.94774264097214, 41.3594164699316, 43.074112460017204, 45.0339674949646, 42.451375275850296, 42.61989243328571, 43.31420257687569, 42.85753168165684, 41.847192496061325, 42.81324125826359, 42.19777688384056, 41.93627491593361, 41.16843871772289, 43.22169654071331, 41.27063803374767, 42.26048491895199, 42.82212898135185, 44.0503066778183, 44.85369756817818, 45.83259344100952, 45.367562994360924, 42.4030988663435, 40.70534996688366, 43.38860258460045, 47.086579352617264, 46.85220792889595, 50.28734140098095, 54.35676723718643, 55.44072367250919, 56.66219852864742, 55.32288819551468, 52.44087964296341, 51.75474666059017, 57.65944741666317, 55.326262414455414, 52.74925209581852, 50.12593746185303, 56.3837456703186, 52.11390718817711, 41.95838212966919, 55.76601281762123, 52.94081501662731, 53.14458288252354, 52.50030465424061, 53.39317314326763, 54.00828413665295, 51.563848704099655, 52.00245916843414, 52.82961778342724, 52.2522159665823, 50.87474048137665, 52.31457822024822, 51.95376858115196, 44.22430694103241, 40.71257717907429, 43.227506428956985, 43.32953095436096, 44.35942769050598, 44.07228849828243, 44.41727198660374, 42.83681519329548, 41.27571076154709, 42.457565143704414, 41.73383317887783, 42.45895966887474, 40.40054552257061, 42.07390733063221, 44.5931189507246, 47.30704352259636, 46.06166794896126, 45.581875294446945, 45.86309440433979, 44.069503247737885, 44.15988899767399, 43.67381528019905, 44.30880680680275, 42.17661201953888, 44.71987634897232, 43.79400283098221, 45.337491407990456, 44.47758994996548, 44.764934331178665, 47.33346350491047, 47.846257388591766, 49.920824468135834, 51.96493998169899, 52.00861103832722, 52.481624856591225, 54.81777749955654, 53.65778334438801, 55.8050899207592, 54.174152836203575, 56.68726958334446, 55.36291144788265, 54.12871867418289, 50.638936534523964, 52.727236077189445, 57.68882744014263, 62.534935399889946, 64.25465852022171, 67.50414535403252, 33.17460626363754, 0.4888715548440814, 1.5806260029785335, 0.17109993525082245, 0.17729470127960667, 5.978912198916078, 65.24049282073975, 59.063639268279076, 47.28036895394325, 22.405516728758812, 20.206969901919365, 33.84087771177292, 54.55769285559654, 56.77885226905346, 46.51502162218094, 2.0926947193220258, 0.12132062474847771, 0.03761700550967362, 0.031237344519468024, 0.06907083821715787, 0.03699956832861062, 0.06443162856157869, 0.08445184881566092, 0.032594283620710485, 0.030895713534846436, 0.07861651974963024, 0.16702164080925286, 0.11555624500033446, 0.15519404812948778, 0.08455263247014955, 0.19229596975492314, 0.22324909397866577, 0.14620763424318284, 0.19145980681059882, 0.1924855588003993, 0.382341094664298, 7.724212696775794, 73.8286779820919, 73.12917351722717, 59.39211264252663, 54.9595782905817, 51.305872946977615, 45.89370936155319, 52.33653724193573, 61.18832565844059, 82.5062495470047, 27.829763665795326, 0.19339687161846086, 0.27923641784582287, 1.6424581850878894, 9.682781975716352, 9.591013099998236, 79.18693006038666, 69.6861706674099, 69.41096663475037, 62.92756453156471, 67.58658573031425, 63.2758804410696, 64.24262076616287, 63.73694010078907, 59.80075031518936, 56.057331785559654, 50.38924053311348, 44.701736122369766, 46.053878366947174, 44.74642172455788, 46.79242193698883, 45.89339017868042, 47.875626012682915, 47.36879400908947, 47.94687978923321, 45.125485584139824, 46.838209480047226, 44.76210728287697, 48.30327786505222, 44.402631372213364, 43.68613801896572, 45.06282314658165, 47.5998368114233, 43.62584285438061, 46.174103915691376, 45.31316511332989, 45.84665648639202, 43.96282397210598, 43.35221953690052, 43.987936824560165, 45.141041949391365, 44.150967076420784, 45.81563875079155, 44.04335305094719, 44.36910197138786, 44.16330121457577, 45.67428633570671, 46.25731945037842, 48.89557108283043, 46.93281680345535, 45.57981580495834, 44.218687042593956, 46.98538698256016, 50.10034583508968, 49.88359026610851, 53.86008068919182, 57.082281187176704, 57.46768310666084, 59.2314762622118, 58.60501527786255, 55.09524241089821, 54.19497191905975, 60.39781607687473, 59.20497268438339, 54.069552049040794, 51.789290606975555, 58.661453649401665, 53.85400861501694, 45.59585094451904, 58.78609076142311, 56.297608092427254, 57.030102387070656, 56.07925280928612, 55.596450716257095, 54.46211278438568, 56.15450017154217, 53.14682096242905, 54.023528918623924, 53.633916825056076, 56.460854932665825, 53.82256530225277, 56.166374534368515, 47.38388679921627, 41.85419552028179, 45.41403830051422, 45.136675983667374, 46.099130138754845, 46.64484545588493, 45.925715044140816, 45.980956479907036, 43.33142705261707, 43.86535920202732, 43.685978427529335, 44.40964199602604, 44.74992893636227, 44.070498794317245, 47.58366107940674, 47.739289328455925, 48.17279286682606, 49.04814049601555, 48.70266303420067, 47.090481743216515, 46.658961698412895, 46.715943440794945, 46.547167897224426, 45.12404166162014, 46.59819155931473, 44.85769875347614, 48.24775904417038, 44.43564400076866, 47.582080364227295, 51.60888768732548, 49.154075011610985, 52.713249027729034, 53.73596794903278, 54.46891821920872, 54.0157051384449, 57.206853702664375, 56.511654406785965, 59.67230200767517, 56.64774410426617, 59.47240233421326, 58.452366068959236, 58.308517187833786, 54.03159588575363, 56.61340534687042, 60.42647033929825, 64.80644971132278, 67.9167728126049, 71.03148847818375, 34.36615392565727, 1.1508791567757726, 3.963126065209508, 0.5886265332810581, 0.2620781713631004, 7.790953265503049, 70.8684392273426, 64.39430862665176, 60.10061502456665, 32.99060493707657, 26.093123853206635, 42.34563834965229, 64.90107223391533, 63.606455102562904, 58.58749061822891, 3.638023822568357, 0.23783815879141912, 0.16674140584655106, 0.21217886300291866, 0.14789043925702572, 0.12404870765749365, 0.24029822990996763, 0.18448024929966778, 0.11142220042529516, 0.09769165204488672, 0.1925918343476951], [0.010870531095861224, 0.07328077481361106, 0.0652863377763424, 0.052196266551618464, 0.04010571981780231, 0.012673594646912534, 0.008525910325261066, 0.11028207605704665, 0.10428852110635489, 0.07882979814894497, 7.824032390490174, 63.03943432867527, 50.007228031754494, 43.64230737090111, 21.123157739639282, 13.786518070846796, 47.8216765075922, 51.00920006632805, 55.13077810406685, 66.31401121616364, 18.3761103451252, 0.060762940265703946, 0.06389053611201234, 0.8624713669996709, 1.7989840172231197, 19.759866893291473, 78.07938069105148, 60.83809085190296, 63.059900030493736, 55.21398603916168, 53.48441004753113, 50.54079920053482, 52.01149508357048, 47.16096416115761, 46.97502113878727, 41.152183189988136, 42.22378268837929, 42.23433092236519, 44.54347461462021, 41.95887990295887, 41.946184784173965, 39.89440128207207, 41.267184019088745, 39.48991298675537, 41.85700736939907, 40.37758715450764, 42.52390198409557, 40.81337817013264, 42.89013013243675, 41.310129314661026, 44.040149822831154, 42.974880784749985, 41.210836842656136, 38.468413800001144, 40.76421640813351, 41.189322397112846, 41.56346932053566, 41.73430435359478, 41.55085399746895, 39.3574520945549, 41.01937271654606, 39.58062931895256, 40.06859913468361, 40.14987677335739, 40.23259073495865, 39.69228632748127, 43.57796162366867, 42.898732870817184, 42.078721672296524, 42.33231246471405, 41.54749117791653, 39.28532436490059, 42.73836247622967, 43.822752088308334, 42.20929026603699, 46.68945126235485, 53.18911649286747, 54.126423597335815, 54.08887401223183, 51.49412624537945, 51.3384447991848, 54.64465878903866, 54.129167050123215, 48.738145530223846, 45.26883289217949, 48.18055585026741, 54.664379730820656, 51.54229246079922, 39.50066640973091, 51.29947789013386, 50.53021676838398, 48.610039204359055, 52.67851509153843, 52.04014174640179, 52.23732836544514, 49.81080137193203, 50.20055405795574, 49.79623295366764, 48.67094613611698, 49.358568638563156, 50.77311873435974, 49.08311001956463, 41.20481036603451, 38.58038239181042, 41.18366830050945, 41.367411240935326, 41.5841706097126, 43.20036828517914, 42.38870903849602, 40.27517504990101, 40.43092109262943, 40.09840093553066, 40.614166259765625, 39.260040521621704, 38.68671588599682, 38.668001890182495, 43.79992291331291, 44.44995403289795, 44.71563197672367, 45.23134030401707, 42.44757167994976, 40.45122720301151, 41.02346129715443, 40.90677335858345, 41.95183888077736, 41.58412501215935, 41.690994277596474, 42.08855174481869, 40.615230202674866, 42.14304082095623, 47.897862419486046, 51.77941493690014, 52.61424534022808, 53.596751019358635, 54.338376224040985, 55.296061635017395, 54.67609830200672, 55.08127436041832, 55.06404988467693, 53.33231940865517, 56.90312460064888, 56.2560611218214, 54.34290938079357, 53.77106286585331, 52.178587317466736, 51.58513896167278, 55.60874305665493, 58.33328805863857, 62.10434250533581, 66.34001702070236, 43.59873130917549, 1.3310116971842945, 0.875051838811487, 0.06833446444943547, 0.05376967899792362, 1.5671066846698523, 48.354943692684174, 58.17139774560928, 50.41227109730244, 55.720449462533, 22.52024207264185, 29.37587220221758, 46.33027173578739, 52.09320589900017, 49.62994247674942, 5.857601333409548, 0.18553812144091353, 0.03514882271701936, 0.10602401118376292, 0.05350611267203931, 0.05838765580847394, 0.08336956743733026, 0.08765313992626034, 0.028469115131883882, 0.028246968067833222, 0.04845364921493456, 0.04107560664124321, 0.0637767203443218, 0.049703481563483365, 0.03150713375362102, 0.02973534894408658, 0.052703001274494454, 0.030962555065343622, 0.03194262972101569, 0.11116126872366294, 0.06101439845224377, 12.730807419866323, 73.11756893992424, 56.403417214751244, 48.944892436265945, 27.089983262121677, 20.794319584965706, 43.18255864083767, 51.21908940374851, 61.38449773192406, 72.66035467386246, 20.29971342533827, 0.10883646886213683, 0.09299664030550048, 3.20980295073241, 0.5911418201867491, 22.859968543052673, 79.8424480855465, 62.94442802667618, 65.18481820821762, 56.07595458626747, 55.722239166498184, 52.2126866877079, 53.162153139710426, 49.12907995283604, 48.86079154908657, 42.70201362669468, 46.07844024896622, 42.79427647590637, 45.99564269185066, 43.13627332448959, 44.70886833965778, 42.80267022550106, 42.788447588682175, 42.81859517097473, 44.70482915639877, 42.12089940905571, 44.37802769243717, 43.507718592882156, 44.685837775468826, 43.884141594171524, 45.05342245101929, 45.17876632511616, 44.55527678132057, 39.99334417283535, 43.13153877854347, 42.781406566500664, 42.346250116825104, 45.34322530031204, 44.50898386538029, 42.7797232568264, 44.20390583574772, 41.549581065773964, 43.18977825343609, 42.411466017365456, 41.28988020122051, 41.76695220172405, 43.891087621450424, 45.230017974972725, 44.939740151166916, 43.3004929125309, 43.43475490808487, 41.925886273384094, 44.84829045832157, 45.887177512049675, 44.534552693367004, 48.39923791587353, 54.20345686376095, 54.40929941833019, 54.878714829683304, 52.95232079923153, 54.14795324206352, 57.59619601070881, 55.45218005776405, 50.473770797252655, 47.65812188386917, 50.70901617407799, 56.74754194915295, 52.360483556985855, 41.80241569876671, 53.55002112686634, 52.70593822002411, 52.002888545393944, 53.89726549386978, 54.24641355872154, 54.26603190600872, 52.08605848252773, 52.24511794745922, 51.600961312651634, 51.63836270570755, 52.222448363900185, 53.075430393218994, 51.51565968990326, 43.54756325483322, 40.76702065765858, 44.32945489883423, 42.484817281365395, 43.7084998190403, 43.34058076143265, 44.05667133629322, 42.475899159908295, 42.63104483485222, 42.331639900803566, 41.83787539601326, 40.616867914795876, 39.87111233174801, 42.30789117515087, 46.86600498855114, 46.62522330880165, 46.227107271552086, 48.0893911421299, 44.73194070160389, 44.17161516845226, 42.293410152196884, 42.898022308945656, 44.69270400702953, 42.72326208651066, 43.996357172727585, 43.09317983686924, 43.15808415412903, 43.51867340505123, 49.65360380709171, 54.67652007937431, 54.5647756755352, 55.832722038030624, 55.334006398916245, 56.57747067511082, 55.2802886813879, 57.06253744661808, 56.50690846145153, 56.534266993403435, 59.57411527633667, 58.534403666853905, 57.105915918946266, 54.18768770992756, 55.632518380880356, 54.56067569553852, 56.978314965963364, 60.987354442477226, 63.59911389648914, 67.7477502822876, 48.52039821445942, 2.0843019196763635, 1.2074842443689704, 0.4286575218429789, 0.04002818765002303, 1.5596992196515203, 50.859260112047195, 64.53338876366615, 49.59189131855965, 41.43059805035591, 28.686893172562122, 38.439721539616585, 53.444713577628136, 57.0430026948452, 63.40977005660534, 8.94125746563077, 0.21066378336399794, 0.022275911323959008, 0.03716549770615529, 0.023319098218053114, 0.03941400478652213, 0.06696728742099367, 0.03066757919441443, 0.016480042249895632, 0.04774481654749252, 0.020363621260912623, 0.1185569039080292, 0.227343893784564, 0.12532169872429222, 0.1414866844424978, 0.06707054242724553, 0.16212364425882697, 0.10071864977362566, 0.26601663033943623, 0.2481677263858728, 0.1811823231400922, 18.168457187712193, 84.77615654468536, 62.608750239014626, 60.09219467639923, 30.043336786329746, 21.923489794135094, 56.455349028110504, 64.10905793309212, 65.29445752501488, 79.92589920759201, 23.864980414509773, 0.28572641022037715, 0.1360726577695459, 6.4585120137780905, 8.173304423689842, 23.512558825314045, 84.65319514274597, 64.68552500009537, 69.26076829433441, 58.65487240254879, 59.307962357997894, 56.0527416318655, 56.23061768710613, 51.90940976142883, 51.2579271197319, 45.30202031135559, 48.51478211581707, 44.90663252770901, 49.05448995530605, 45.627161264419556, 47.4814959615469, 44.583653658628464, 45.47639675438404, 43.10245893895626, 47.48776562511921, 44.913954734802246, 45.09967356920242, 45.17141371965408, 47.42348067462444, 44.245988577604294, 48.21432463824749, 48.68917375802994, 46.398782059550285, 43.54895778000355, 46.297483295202255, 47.02754192054272, 45.90891234576702, 48.053038492798805, 45.61993025243282, 44.85970884561539, 46.06625810265541, 44.749104380607605, 43.94763618707657, 44.83974851667881, 44.124144315719604, 44.332582131028175, 47.31116630136967, 45.43023683130741, 45.769687816500664, 46.32293812930584, 44.55971114337444, 43.64681012928486, 49.341401159763336, 48.73877249658108, 46.40869192779064, 51.30241133272648, 56.28214672207832, 57.49269336462021, 55.941506400704384, 54.73140813410282, 56.08415074646473, 60.93197241425514, 58.10393236577511, 53.23482804000378, 49.358583837747574, 52.060026079416275, 59.17310759425163, 55.05464918911457, 44.25203785300255, 54.316132217645645, 55.67224524915218, 53.051419481635094, 57.00110614299774, 56.77164025604725, 55.77449396252632, 54.187976494431496, 55.852891355752945, 54.95573669672012, 53.38755324482918, 54.93563577532768, 54.9438813328743, 54.330734834074974, 46.757292822003365, 43.846592009067535, 46.683519780635834, 45.01275323331356, 45.34927077591419, 48.053604662418365, 46.768939197063446, 44.36663590371609, 45.044055953621864, 44.77947235107422, 44.0780907869339, 42.256795316934586, 42.557283192873, 43.48715789616108, 48.675992265343666, 49.83439810574055, 49.88956354558468, 50.72168469429016, 47.13207431137562, 45.38055829703808, 45.87520055472851, 45.37402644753456, 47.08610437810421, 45.60191921889782, 46.6521068662405, 45.16768991947174, 44.13113974034786, 46.56525492668152, 51.97188600897789, 56.08595184981823, 56.272981613874435, 59.023790806531906, 58.57994422316551, 58.8457627594471, 58.691502436995506, 60.07646732032299, 58.56884501874447, 58.43720108270645, 62.010810524225235, 60.73370665311813, 59.70087647438049, 56.372984647750854, 57.2378334403038, 58.49156476557255, 61.81765168905258, 64.76677983999252, 67.24641278386116, 72.70230442285538, 48.1259223818779, 2.458410607650876, 3.2461145147681236, 0.882100104354322, 0.28245822933968157, 2.197598540224135, 59.10684674978256, 67.44702681899071, 65.63935741782188, 68.65677550435066, 35.185610353946686, 45.02314567565918, 63.71874287724495, 65.8694426715374, 73.75536471605301, 13.142634071409702, 0.36793108040001243, 0.16230906243436038, 0.15607273613568395, 0.13830248499289155, 0.16820408985950053, 0.19567777344491333, 0.1983609193121083, 0.1024698511173483, 0.16804152983240783, 0.13533805031329393], [0.09708511701319367, 0.025981840590247884, 0.016853353663464077, 0.03525465297570918, 0.045311481298995204, 0.0347393056290457, 0.06356855534249917, 0.013066352184978314, 0.08415877469815314, 0.32814567151945084, 12.753963377326727, 61.40267975628376, 49.09039042890072, 49.73002530634403, 24.974275790154934, 31.717126071453094, 52.5323673337698, 50.371810868382454, 54.33994933962822, 62.015279084444046, 9.958232995122671, 0.2045926739810966, 0.11759495435399003, 0.9631201287265867, 1.0966648533940315, 30.47712340950966, 77.26297169923782, 59.65446576476097, 65.65174475312233, 53.024965301156044, 51.166226640343666, 46.180825755000114, 45.22967979311943, 44.01129797101021, 45.374227836728096, 41.75196200609207, 42.38410748541355, 39.244408160448074, 44.059521183371544, 41.47828549146652, 44.19746518135071, 46.086077839136124, 45.15845261514187, 44.50656719505787, 42.026037499308586, 39.206660985946655, 41.66577123105526, 41.78087465465069, 41.42848916351795, 40.42150899767876, 41.14144116640091, 41.70659624040127, 41.257707327604294, 39.10444267094135, 40.22884413599968, 38.55323664844036, 40.05727954208851, 38.35073031485081, 43.09002220630646, 41.383385583758354, 39.333916157484055, 38.02196815609932, 40.144914239645004, 42.83593364059925, 42.04763174057007, 41.10191188752651, 43.40217165648937, 43.151119127869606, 42.97383204102516, 41.89088635146618, 41.34186141192913, 40.6804309040308, 42.5248709321022, 43.948293551802635, 42.10739113390446, 40.36957338452339, 47.839816734194756, 50.825559720396996, 54.72291938960552, 55.18603093922138, 56.52676999568939, 52.863511964678764, 49.42976921796799, 43.4461884945631, 44.12053070962429, 49.01001714169979, 54.84965018928051, 51.80691786110401, 39.40296605229378, 53.37303042411804, 50.55585019290447, 50.319236889481544, 51.14907816052437, 50.651517659425735, 54.211189448833466, 52.992218658328056, 51.95410676300526, 51.344159692525864, 52.54170723259449, 51.400062292814255, 51.21462844312191, 47.509173676371574, 39.58740055561066, 39.45257619023323, 42.558624520897865, 42.331210523843765, 42.36670821905136, 40.54925434291363, 42.92063869535923, 40.36151401698589, 40.68494126200676, 40.247911512851715, 39.185154139995575, 40.36719471216202, 38.51970724761486, 41.2054069340229, 44.5332645624876, 42.713139429688454, 43.666109293699265, 42.57402889430523, 42.07949683070183, 40.52508004009724, 41.283184960484505, 40.916854217648506, 42.17905908823013, 42.41946078836918, 42.84996248781681, 39.543193727731705, 42.3308951407671, 48.252007216215134, 53.080875501036644, 52.12595634162426, 54.51368361711502, 54.8533283919096, 55.827945694327354, 58.788059055805206, 58.9379496127367, 56.720836982131004, 56.48391969501972, 56.478630378842354, 58.36290746927261, 56.76257014274597, 57.67452120780945, 56.231126859784126, 56.54299512505531, 54.84042428433895, 57.38347962498665, 56.83947801589966, 63.969400227069855, 62.68832556903362, 52.82779388129711, 4.861955009400845, 0.6072828196920455, 0.09900760604068637, 0.024771577700448688, 0.40294338134117424, 35.59794522821903, 62.9504507035017, 49.339410066604614, 35.93049198389053, 16.150501370429993, 25.705806836485863, 41.57460652291775, 51.39707565307617, 58.01086015999317, 13.303723577409983, 0.5381524167023599, 0.05644806027703453, 0.08611852696049027, 0.024077059206319973, 0.06206149089848623, 0.009349074553028913, 0.04613775141478982, 0.05338186972949188, 0.04631231939129066, 0.06449029533541761, 0.0984150604926981, 0.01448855482522049, 0.04849636723520234, 0.04955026146490127, 0.05538815836189315, 0.0463380273868097, 0.06907500908710063, 0.03309139639895875, 0.051782797527266666, 0.23407705826684833, 19.012315906584263, 71.87293812632561, 54.05817925930023, 57.25264124572277, 28.9286931976676, 33.92014905810356, 55.84613151848316, 51.12759791314602, 60.7215891033411, 66.90649822354317, 12.625386826694012, 0.26148540317080915, 0.22710087010636926, 2.7794294944033027, 0.595663518179208, 33.21922346949577, 78.54210466146469, 61.91012732684612, 67.53920987248421, 54.6049053221941, 51.854324117302895, 47.80069403350353, 48.502653166651726, 47.288595512509346, 45.4673608392477, 44.293383434414864, 43.697742596268654, 40.8136897534132, 46.15021459758282, 43.54326568543911, 47.48219132423401, 47.49799087643623, 47.02891744673252, 45.700007155537605, 44.75597441196442, 41.87621533870697, 44.16430056095123, 42.815965712070465, 43.15284803509712, 41.76951326429844, 42.88412645459175, 43.36006611585617, 42.17960245907307, 40.8349534124136, 43.21977764368057, 40.9276532381773, 42.34776243567467, 42.02612489461899, 44.00871030986309, 43.8938120752573, 42.95162983238697, 40.12641683220863, 40.586587339639664, 43.75572748482227, 42.50848241150379, 42.34557755291462, 43.98939214646816, 44.379281625151634, 45.05784161388874, 43.27105209231377, 43.20781208574772, 43.027207776904106, 43.720081597566605, 44.98770497739315, 43.954365625977516, 42.81884215772152, 47.71953798830509, 51.86301425099373, 58.49308468401432, 55.8584276586771, 57.7640026062727, 52.53952234983444, 52.20673240721226, 44.116556122899055, 44.22187887132168, 51.92794896662235, 56.4701796323061, 54.59729813039303, 41.575229689478874, 54.040517807006836, 51.43305592238903, 52.680285796523094, 53.31017419695854, 52.78540335595608, 55.45411415398121, 54.50317718088627, 55.37946715950966, 53.76842960715294, 52.29154385626316, 54.59844946861267, 53.544389829039574, 50.910230576992035, 42.315844148397446, 41.54640443623066, 44.259865432977676, 43.7744452804327, 44.29616488516331, 42.99688920378685, 44.13593888282776, 41.73009417951107, 42.69688010215759, 42.044215723872185, 42.127343863248825, 42.427527755498886, 41.3450076431036, 43.59975345432758, 47.43628218770027, 46.708636432886124, 45.71253888309002, 44.23266649246216, 43.376868814229965, 42.3057708889246, 42.457101568579674, 43.23021188378334, 44.76465694606304, 44.890525192022324, 44.45590451359749, 43.187038600444794, 44.077976793050766, 51.17417961359024, 55.66019609570503, 55.07614083588123, 57.15738795697689, 57.998678013682365, 58.79806771874428, 59.14098411798477, 60.338649451732635, 59.26153264939785, 58.04946608841419, 58.7263997644186, 59.37627129256725, 57.40751713514328, 59.2770130187273, 57.7180440723896, 59.34444040060043, 58.68217773735523, 59.36391815543175, 60.40581464767456, 65.65495938062668, 64.41519230604172, 57.12060213088989, 5.275992667302489, 0.7134786306414753, 0.4570725158555433, 0.1825295141316019, 0.4165657394332811, 38.3698470890522, 68.31123724579811, 54.94127847254276, 39.505875930190086, 22.66822513192892, 33.456619530916214, 49.90116812288761, 56.23374491930008, 66.28419801592827, 20.632459670305252, 0.36009046831168234, 0.030947934756113682, 0.03082180304772919, 0.049489653974887915, 0.056319546274608, 0.059421526893856935, 0.09050102031324059, 0.04345003762864508, 0.07269214038387872, 0.0452352812862955, 0.20345178520074114, 0.05503284774022177, 0.10381607731687836, 0.18000000767642632, 0.1801518362481147, 0.1749711556476541, 0.12115587538573891, 0.1176879825652577, 0.2196026997989975, 0.6756441795732826, 25.42386956512928, 82.88907140493393, 62.72440083324909, 69.3531185388565, 33.859207928180695, 45.02015143632889, 64.63837713003159, 63.568115159869194, 66.29445746541023, 71.82283401489258, 14.837213940918446, 0.2552864811150357, 0.2719258179422468, 5.741446791216731, 5.122629571706057, 36.11989662051201, 81.28724455833435, 65.55535912513733, 69.36257243156433, 57.73723304271698, 54.224728122353554, 50.43409712612629, 50.1506133377552, 49.517491310834885, 48.40043865144253, 46.833714321255684, 46.08730897307396, 42.584520131349564, 49.73029889166355, 45.694398656487465, 50.207743272185326, 50.768509581685066, 49.805120676755905, 48.121313229203224, 47.823306620121, 43.584550470113754, 46.67586699128151, 45.44010870158672, 45.37718407809734, 44.74004186689854, 44.93622533977032, 46.17307797074318, 45.9158393740654, 43.795868530869484, 45.860020369291306, 44.066554605960846, 45.3934396058321, 42.54275657236576, 47.3586181551218, 46.45919881761074, 44.830104634165764, 41.81984916329384, 42.10106447339058, 47.01751045882702, 45.95256820321083, 43.92386846244335, 46.72114156186581, 46.637447252869606, 48.114986568689346, 44.811402037739754, 45.14472395181656, 45.132697597146034, 46.80673576891422, 49.34680826961994, 46.17276258766651, 46.38504199683666, 50.69148391485214, 53.355539962649345, 59.70511704683304, 60.93478426337242, 61.05426885187626, 55.21857999265194, 55.03415308892727, 48.14706064760685, 47.53915786743164, 54.114040061831474, 60.365730598568916, 56.78361341357231, 45.275672525167465, 58.066781759262085, 53.34703981876373, 56.95563018321991, 55.787721052765846, 54.29454557597637, 57.89241671562195, 58.03229860961437, 57.73625649511814, 56.543287709355354, 56.45369611680508, 57.3664603382349, 56.701302230358124, 53.1574147939682, 44.926516860723495, 43.068256974220276, 47.050025314092636, 45.98188742995262, 46.727958396077156, 44.906286746263504, 46.379684284329414, 44.79638524353504, 44.236720874905586, 46.649948582053185, 43.53405497968197, 47.159622833132744, 42.42889568209648, 45.44348672032356, 51.564490869641304, 48.09851445257664, 48.11829999089241, 46.43226206302643, 47.2776634991169, 44.995692148804665, 44.381512105464935, 44.750107526779175, 46.47557593882084, 47.59199783205986, 47.815000265836716, 46.36440150439739, 45.838084146380424, 51.39883875846863, 56.64490945637226, 56.705941781401634, 60.096701234579086, 58.96506875753403, 59.269075244665146, 60.95814161002636, 62.12433323264122, 61.50176323950291, 59.18316565454006, 62.588246539235115, 61.273232102394104, 61.138498932123184, 62.115445509552956, 61.35734058916569, 62.05596350133419, 61.800829991698265, 63.64069886505604, 64.34010073542595, 68.7817431986332, 67.8197792172432, 59.49864752590656, 5.953351445496082, 2.2350481431931257, 0.6873748626094311, 0.22179782419698313, 0.7794883323367685, 42.93082594871521, 73.18815395236015, 66.23922362923622, 50.225811302661896, 24.292601868510246, 38.37175078690052, 58.268151953816414, 65.53776606917381, 75.89135929942131, 28.057458847761154, 0.9542990801855922, 0.15978534473106265, 0.13416659989161417, 0.09691178842331283, 0.09797550868825056, 0.1839027099777013, 0.22168210853124037, 0.15015790821053088, 0.2502541261492297, 0.12303732364671305], [0.06772316482965834, 0.06370286180754192, 0.02459895044012228, 0.07629313739016652, 0.033715464669512585, 0.053784510819241405, 0.04018537081719842, 0.004791600404132623, 0.01641604128963081, 0.26070027030073106, 23.643769584596157, 58.90782102942467, 45.112193897366524, 32.10684455931187, 21.063417345285416, 26.142914481461048, 30.578201785683632, 52.38435387611389, 56.462397649884224, 62.90736481547356, 8.944998364895582, 0.23868815536843613, 0.3868252399843186, 2.1562016615644097, 0.6629034038633108, 50.576802268624306, 73.1478913128376, 61.28907345235348, 62.53720387816429, 52.225081622600555, 49.851846769452095, 46.88142456114292, 46.93912826478481, 42.459966614842415, 42.880596444010735, 43.34251865744591, 46.84983305633068, 50.509443283081055, 51.43521800637245, 51.57638803124428, 55.2139176428318, 55.176360458135605, 58.668323680758476, 56.09568692743778, 53.57755824923515, 46.09571032226086, 42.14130811393261, 39.22438703477383, 42.01015815138817, 39.61406372487545, 40.45497000217438, 40.60012221336365, 41.435290798544884, 39.57557938992977, 38.929408863186836, 39.38106022775173, 40.850061401724815, 39.36804972589016, 40.94475232064724, 39.292205795645714, 40.487123876810074, 39.65709261596203, 39.54120643436909, 39.71471652388573, 39.7958991676569, 42.2319370508194, 43.14226560294628, 41.956904008984566, 42.22062885761261, 40.69367319345474, 42.52647064626217, 38.931320160627365, 42.158977165818214, 43.071710988879204, 42.348351404070854, 41.60633482038975, 40.84777012467384, 43.027842342853546, 49.722953885793686, 46.89923420548439, 47.131633535027504, 45.451891869306564, 43.01649235188961, 41.72869585454464, 47.716737538576126, 49.841059148311615, 52.379683926701546, 53.4822441637516, 40.252319276332855, 48.962086513638496, 52.18538895249367, 49.21641066670418, 51.98995403945446, 49.533157870173454, 49.172743409872055, 49.9259427934885, 52.13314935564995, 50.180293545126915, 54.70749981701374, 52.328713461756706, 51.61363743245602, 46.37770839035511, 41.091523244977, 40.83331570029259, 41.60489469766617, 42.630262076854706, 42.40451619029045, 42.26884447038174, 41.40338011085987, 41.11092120409012, 41.36229671537876, 40.31251184642315, 41.79052233695984, 40.13600371778011, 39.69088040292263, 43.135904744267464, 43.676725924015045, 44.690519124269485, 42.028659358620644, 39.77332457900047, 40.61386987566948, 40.60866415500641, 41.39444679021835, 41.5072513371706, 40.92673368752003, 41.24717429280281, 42.72141918540001, 41.859978809952736, 46.89045287668705, 54.607850164175034, 55.553592815995216, 56.17588922381401, 55.10714337229729, 53.34990106523037, 54.33383546769619, 54.77985553443432, 59.67160664498806, 57.717291712760925, 58.32614064216614, 58.62671211361885, 58.75206358730793, 56.082646027207375, 59.39360596239567, 58.61308604478836, 62.513523548841476, 59.61802192032337, 60.792079120874405, 58.963575437664986, 61.8036874383688, 63.755570501089096, 56.376560255885124, 7.395918862894177, 0.8231764286756516, 0.9982531028799713, 0.7745512691326439, 0.021237314613244962, 22.256806008517742, 65.31268134713173, 49.79977436363697, 38.468345403671265, 20.879811197519302, 21.887828707695007, 33.42470124363899, 45.14496713876724, 59.84179191291332, 26.763628274202347, 0.5391323484946042, 0.020188017988402862, 0.08858123270329088, 0.007161733892644406, 0.010282959792675683, 0.05008475993236061, 0.028474501268647145, 0.11352665664162487, 0.01997411989577813, 0.04347297741333023, 0.09909860818879679, 0.047928550047799945, 0.03300085438240785, 0.05456600716570392, 0.02251649148092838, 0.00672364272759296, 0.02920147388067562, 0.0301078254415188, 0.017016045421769377, 0.19830036006169394, 30.861280895769596, 69.48256999254227, 54.442984610795975, 41.29277564585209, 27.19678983092308, 31.400323770940304, 34.28257741034031, 56.38032205402851, 61.96750804781914, 68.80097776651382, 10.33468259498477, 0.2775732649024576, 0.3577146161114797, 2.5825195480138063, 1.5230976836755872, 53.21481071412563, 74.01820421218872, 63.70128661394119, 65.27172714471817, 54.50058571994305, 50.39372809231281, 49.52512510120869, 47.87774629890919, 46.491873264312744, 44.845953583717346, 46.3213612139225, 49.518692046403885, 51.98702819645405, 54.66773875057697, 53.980036452412605, 58.08554895222187, 57.67155356705189, 59.50143277645111, 57.423084899783134, 57.485914528369904, 48.44873785972595, 43.51001366972923, 42.66550898551941, 44.77625772356987, 41.978015676140785, 42.85102643072605, 42.81090058386326, 44.2031192779541, 42.067523673176765, 40.837145894765854, 42.0382272452116, 43.22570912539959, 41.04751020669937, 43.26122581958771, 41.806907057762146, 42.50315509736538, 41.63539566099644, 42.21165373921394, 41.686149537563324, 42.09028445184231, 42.47271113097668, 44.55995433032513, 42.977616637945175, 43.574534207582474, 43.35193835198879, 44.68742989003658, 40.99880062043667, 42.797023728489876, 44.50610741972923, 44.56174783408642, 43.621853068470955, 43.858382776379585, 45.58265045285225, 50.968542248010635, 50.17549440264702, 50.424935817718506, 47.29797340929508, 44.67709444463253, 44.31626580655575, 49.6487894654274, 53.092734664678574, 55.50580658018589, 54.68890741467476, 42.76083067059517, 53.16765144467354, 52.63600677251816, 52.499229311943054, 53.56457054615021, 51.30241893231869, 51.03736415505409, 52.12557256221771, 53.80127504467964, 53.671527206897736, 55.49393601715565, 54.45677027106285, 53.318598344922066, 47.531786262989044, 43.144104704260826, 43.230242282152176, 42.71545730531216, 44.49632294476032, 44.196819216012955, 44.12455089390278, 44.46546860039234, 42.672021836042404, 44.58537116646767, 42.51085728406906, 43.205194026231766, 40.91600686311722, 43.08485068380833, 44.66216504573822, 47.79350861907005, 47.001634910702705, 43.90234261751175, 42.852135971188545, 42.842959463596344, 43.05067531764507, 42.672553807497025, 44.301332607865334, 45.359469428658485, 43.587476313114166, 44.08221356570721, 42.67233721911907, 49.987890869379044, 54.21220399439335, 56.88496917486191, 57.55103163421154, 56.138392835855484, 52.47181758284569, 54.82234105467796, 56.43048316240311, 62.28909619152546, 58.84157158434391, 59.423780143260956, 58.648496344685555, 59.82623554766178, 57.626248598098755, 61.73219807446003, 61.275838762521744, 63.62541228532791, 62.57701054215431, 63.16870719194412, 61.82233303785324, 63.77693295478821, 64.61925655603409, 60.001113563776016, 9.270804282277822, 1.3095960463397205, 2.905466118827462, 0.9619871363975108, 0.02973509475850733, 23.468319699168205, 71.187082529068, 56.11174486577511, 39.85742546617985, 24.23368413001299, 30.007998682558537, 41.064088717103004, 52.91248753666878, 65.80291584134102, 38.41178923845291, 1.1976612964645028, 0.01553376592710265, 0.023000989604042843, 0.012703373322437983, 0.038086083659436554, 0.04250627811416052, 0.08272181352367625, 0.060832275412394665, 0.03809863708738703, 0.06763297162251547, 0.20955842861440033, 0.12628896947717294, 0.20370055310195312, 0.18226729851448908, 0.11290167924016714, 0.150114017596934, 0.07649804436368868, 0.29757583688478917, 0.14678659848868847, 0.6439295969903469, 39.942848682403564, 79.78926613926888, 61.13126792013645, 48.00597421824932, 31.744942478835583, 35.92176005244255, 41.43094763159752, 65.42681962251663, 66.56487375497818, 74.87569659948349, 12.667770702391863, 0.33612105762586, 1.1892270552925766, 11.854336000978947, 2.7201427007094026, 56.12392321228981, 75.25886803865433, 66.63382485508919, 66.70616537332535, 56.689374670386314, 52.575943395495415, 53.61695073544979, 50.86806043982506, 48.34583938121796, 45.35781651735306, 48.9092655479908, 53.70621934533119, 55.974591225385666, 56.98029465973377, 53.73845301568508, 59.99125309288502, 61.93644471466541, 61.02912940084934, 60.42558878660202, 58.83903332054615, 51.10632665455341, 46.08581565320492, 44.5897713303566, 46.25144116580486, 43.99135284125805, 43.85476537048817, 45.0790748745203, 46.41115039587021, 45.561671778559685, 41.238765344023705, 44.642162919044495, 45.444972440600395, 44.08480502665043, 44.82187807559967, 43.43977063894272, 46.12588830292225, 44.40718732774258, 44.19543229043484, 42.786817476153374, 43.60597752034664, 45.64488731324673, 47.12382115423679, 47.031801491975784, 45.77568009495735, 44.64247070252895, 47.561344876885414, 42.17455632984638, 46.19704708456993, 49.18277487158775, 47.071976736187935, 45.114614367485046, 46.60169117152691, 47.50788174569607, 54.27063345909119, 50.82541152834892, 51.4495812356472, 50.07182456552982, 46.593643203377724, 46.91094137728214, 52.460950165987015, 54.4323717802763, 57.781211882829666, 57.55258955061436, 45.13949543237686, 53.88650827109814, 56.43198408186436, 55.235880464315414, 57.11896441876888, 55.2660546451807, 52.7739317715168, 54.18494425714016, 56.2311914563179, 56.14361375570297, 58.47894564270973, 56.1306906491518, 57.261570766568184, 50.672321543097496, 45.80574408173561, 43.97469453513622, 46.34289085865021, 47.93556019663811, 46.47754803299904, 45.585219115018845, 46.87818333506584, 44.44067493081093, 47.23782263696194, 44.242542162537575, 45.029229149222374, 44.885072484612465, 44.302689135074615, 47.99396686255932, 50.21352656185627, 49.33960385620594, 47.95597270131111, 44.87886741757393, 46.31519794464111, 44.87864702939987, 44.97160144150257, 45.768274292349815, 47.322330102324486, 46.71888828277588, 47.43012271821499, 47.65888184309006, 50.63878454267979, 58.110730201005936, 58.516575023531914, 60.98740004003048, 57.74709731340408, 53.64886522293091, 56.635238975286484, 58.20422798395157, 63.38850639760494, 61.077675595879555, 62.489075660705566, 62.21669867634773, 62.93872073292732, 59.2512845993042, 65.07476851344109, 63.49466510117054, 66.86239019036293, 64.00477632880211, 67.08964839577675, 63.10911498963833, 67.77725949883461, 68.5891543328762, 62.10417911410332, 9.169176835566759, 3.3405335107818246, 2.5264350324869156, 1.6371098533272743, 0.11767605625209399, 26.92244455218315, 75.10369956493378, 63.81552368402481, 53.71580623090267, 30.941743478178978, 32.54922442138195, 49.07068468630314, 63.37470553815365, 77.49068588018417, 48.155416399240494, 1.644591533113271, 0.07791487107169814, 0.149612414825242, 0.1215753001451958, 0.15630250505637378, 0.1451557141263038, 0.2613479277351871, 0.14988631184678525, 0.22535386931849644, 0.24489991657901555], [0.04575224651489407, 0.0478043108159909, 0.01966434374480741, 0.036961036021239124, 0.050628861790755764, 0.037610485742334276, 0.05097389737784397, 0.026970026920025703, 0.05034017747675534, 0.6353325583040714, 33.09123493731022, 55.98653398454189, 51.85397073626518, 45.24082839488983, 17.371867932379246, 35.48846170306206, 46.94899633526802, 48.24753865599632, 60.54281249642372, 56.59404918551445, 7.131849182769656, 0.3531458362704143, 0.6549658672884107, 1.746415263041854, 4.2325567826628685, 68.43189597129822, 66.65217027068138, 61.594398468732834, 57.956306487321854, 50.749514400959015, 47.3328897356987, 45.67502349615097, 44.13483314216137, 46.255970522761345, 51.54046095907688, 54.9732081592083, 57.936353757977486, 55.63825227320194, 59.51930321753025, 58.146376088261604, 53.81946846842766, 57.18579903244972, 54.01891216635704, 54.230294823646545, 56.42238959670067, 53.42752330005169, 45.14800697565079, 38.55958230793476, 39.25320088863373, 37.752342224121094, 39.84938509762287, 38.930043429136276, 39.534609988331795, 40.97857050597668, 38.599939942359924, 39.7076603025198, 41.13881550729275, 39.27534610033035, 42.016868591308594, 39.89163503050804, 39.47705827653408, 38.90825539827347, 40.3777239471674, 41.446268409490585, 41.34205900132656, 40.61962656676769, 42.223642095923424, 42.074503898620605, 42.46752820909023, 41.615207344293594, 42.071228474378586, 41.33286729454994, 42.84316085278988, 44.322060495615005, 45.279521718621254, 42.490015402436256, 42.44190998375416, 38.9021073281765, 41.75380490720272, 40.43417751789093, 42.143147215247154, 42.703955322504044, 41.44883707165718, 45.31368188560009, 52.495824694633484, 54.5888701826334, 55.81617392599583, 50.58702751994133, 35.45972004532814, 52.4524462223053, 51.98588825762272, 50.02287179231644, 50.88257946074009, 50.97986564040184, 51.3981281965971, 50.19717983901501, 50.48208475112915, 49.755187556147575, 52.02287547290325, 50.76147995889187, 51.75372451543808, 43.54448541998863, 39.07509684562683, 38.390081003308296, 40.734194219112396, 42.86879047751427, 43.8387568295002, 42.33371078968048, 41.80528834462166, 41.44675858318806, 42.51121066510677, 40.944045558571815, 40.741242840886116, 40.53755857050419, 39.524354338645935, 40.818804278969765, 42.71780177950859, 42.19248376786709, 41.51384398341179, 40.40279120206833, 39.63441543281078, 40.47918230295181, 41.122924759984016, 40.31482592225075, 40.68516165018082, 41.2168101221323, 40.570039227604866, 42.83715337514877, 51.80310286581516, 56.55725575983524, 52.82954178750515, 52.42694579064846, 51.25114068388939, 54.43603478372097, 56.50642968714237, 54.31696057319641, 56.72413520514965, 57.311469689011574, 60.38485877215862, 57.031747698783875, 57.141056433320045, 57.516502887010574, 59.049276039004326, 64.93546798825264, 65.86427494883537, 58.63034471869469, 62.05223590135574, 59.91102419793606, 65.45961946249008, 64.93561998009682, 59.00168739259243, 8.189404159784317, 0.3614326869137585, 0.502287388080731, 0.6702736427541822, 0.15555520687485114, 13.35937824100256, 62.40950033068657, 57.41051897406578, 45.46453379094601, 28.058469593524933, 9.542234167456627, 26.40227146446705, 47.02133305370808, 50.21543025970459, 37.821494713425636, 1.9237540033645928, 0.15552776225376874, 0.060327136307023466, 0.06545926560647786, 0.03958719978982117, 0.07310549437534064, 0.007394246904368629, 0.027938477687712293, 0.03320288182294462, 0.07962768111610785, 0.0892907110392116, 0.011565547756617889, 0.0502495130058378, 0.01392453372318414, 0.024646440469950903, 0.0422233714198228, 0.046439653378911316, 0.027407552661316004, 0.07079766000970267, 0.6913134700153023, 42.18226991593838, 66.50991350412369, 57.61027045547962, 52.29694716632366, 24.304271042346954, 34.46424566209316, 52.021876126527786, 55.78207455575466, 65.20481273531914, 60.95955513417721, 7.026126030832529, 0.39646950841415673, 0.3145002177916467, 3.1198769761249423, 7.128155305981636, 71.23511955142021, 69.48016852140427, 64.86388742923737, 61.1482872068882, 52.79679894447327, 48.58026780188084, 48.072254061698914, 45.984266102313995, 49.13782708346844, 51.876834109425545, 55.72279013693333, 58.10390576720238, 58.17735582590103, 61.27852141857147, 59.61878567934036, 56.913916021585464, 58.451207131147385, 56.68184347450733, 55.52763260900974, 56.65765397250652, 55.85275836288929, 46.188406348228455, 40.36490723490715, 41.55414842069149, 39.757376834750175, 41.818260848522186, 40.75304500758648, 40.701477974653244, 41.733741983771324, 41.52716226875782, 41.15044288337231, 43.31194929778576, 42.24759601056576, 42.72838041186333, 41.820574924349785, 42.14666582643986, 40.66830575466156, 42.04863868653774, 42.8329735994339, 44.314514100551605, 41.73858292400837, 44.210540279746056, 42.9366510361433, 45.47428406774998, 43.388667181134224, 45.053677037358284, 42.44935378432274, 44.032603427767754, 45.82698114216328, 47.33665153384209, 45.56632652878761, 45.88983356952667, 41.13815054297447, 42.51095227897167, 42.76738151907921, 43.04934538900852, 43.55304256081581, 43.64188939332962, 47.16817997395992, 55.15087142586708, 55.23868851363659, 57.89734125137329, 51.54880911111832, 37.97458469867706, 56.335294470191, 55.470042899250984, 52.35393650829792, 53.32932896912098, 54.25098471343517, 53.805994391441345, 53.19671988487244, 52.895061671733856, 52.12193235754967, 52.2562475502491, 52.76326194405556, 53.28494355082512, 44.70706723630428, 39.746057242155075, 41.19086891412735, 42.983327731490135, 44.80728305876255, 44.60981145501137, 43.31325642764568, 44.640517607331276, 44.04718704521656, 43.850099220871925, 42.05474115908146, 42.74581387639046, 42.30104774236679, 41.73333540558815, 43.33091028034687, 44.4149237126112, 46.056040450930595, 43.63268628716469, 41.38594664633274, 41.0354458540678, 41.685165390372276, 43.051192089915276, 43.009850308299065, 42.95359432697296, 43.14450368285179, 43.31427477300167, 44.86689805984497, 53.509576097130775, 58.91207680106163, 55.56463122367859, 52.481890842318535, 54.43929500877857, 57.52665214240551, 57.81472988426685, 54.387803971767426, 57.80931517481804, 58.75511862337589, 63.135584369301796, 58.70043955743313, 59.35483664274216, 59.21088896691799, 62.53846921026707, 63.04802566766739, 66.98228135704994, 61.34376011788845, 65.97278952598572, 63.13439503312111, 66.92269295454025, 69.14178907871246, 62.13469907641411, 10.019168425351381, 1.299742462579161, 4.487552074715495, 2.534656128846109, 0.23444459948223084, 13.882581666111946, 67.13279888033867, 65.36131113767624, 49.83526825904846, 33.763209879398346, 16.777904704213142, 32.65239268541336, 53.41397702693939, 57.539879232645035, 47.513410449028015, 3.5200558276847005, 0.12699515267740935, 0.13685655867448077, 0.045296608659555204, 0.037727077142335474, 0.08948101996793412, 0.02987491352541838, 0.04977123222488444, 0.04370061265944969, 0.024884781196305994, 0.24840286845574155, 0.13656765542691574, 0.12277478148462251, 0.18575790105387568, 0.1313813345041126, 0.09797493723453954, 0.1827662147115916, 0.1039748227049131, 0.12262338335858658, 1.123947270680219, 53.47677245736122, 79.16543081402779, 65.82011371850967, 60.30737712979317, 27.324827760457993, 44.812199994921684, 63.51568557322025, 61.185962185263634, 69.8167696595192, 66.97545692324638, 9.191180504858494, 0.5301714199595153, 1.7301118816249073, 8.846950326114893, 8.024559505283833, 75.59579595923424, 73.78707021474838, 68.78890201449394, 63.51111821830273, 56.01011171936989, 50.6428275257349, 50.15041574835777, 48.028556406497955, 51.01217910647392, 56.01220540702343, 59.7956395894289, 61.60828672349453, 59.78447958827019, 63.572378531098366, 63.22663128376007, 59.07234460115433, 62.18153536319733, 58.828618079423904, 58.70398476719856, 59.20032553374767, 58.225731030106544, 50.43517246842384, 42.6533230394125, 44.59587000310421, 42.45590083301067, 44.63774375617504, 42.472418546676636, 42.872202694416046, 45.209882855415344, 44.152836576104164, 45.46114057302475, 45.04629023373127, 43.88459376990795, 47.348510697484016, 43.86291213333607, 44.22453872859478, 42.12248772382736, 45.075852647423744, 44.81061927974224, 46.19586154818535, 43.85767601430416, 47.810258120298386, 46.09073258936405, 46.24989464879036, 45.45753076672554, 46.62327021360397, 45.34278452396393, 46.54488801956177, 49.123855233192444, 49.444276839494705, 48.31841625273228, 48.68413522839546, 42.68707662820816, 44.80823300778866, 44.46141041815281, 46.05489671230316, 48.34906540811062, 46.276747807860374, 48.733718767762184, 57.53017455339432, 58.408383429050446, 60.236252546310425, 54.60819214582443, 40.61597876250744, 57.950295209884644, 58.46572235226631, 54.70842316746712, 54.737320616841316, 55.57987220585346, 57.0845914632082, 54.86409321427345, 55.38513645529747, 56.48538641631603, 54.895532727241516, 54.7612289339304, 56.67758770287037, 47.90429547429085, 41.856403201818466, 42.713637202978134, 45.136060416698456, 47.63779677450657, 47.987549006938934, 44.89133834838867, 47.30622656643391, 45.705589056015015, 45.74758440256119, 44.447719752788544, 44.99882698059082, 45.01188687980175, 44.100220799446106, 45.71405120193958, 47.62755252420902, 47.617384269833565, 46.169190779328346, 44.918457493186, 42.856870517134666, 44.21125464141369, 45.54743394255638, 44.051537811756134, 46.290829852223396, 45.73900066316128, 44.83151435852051, 45.447605699300766, 55.39748199284077, 61.4994415640831, 57.809398770332336, 55.68085938692093, 54.10053938627243, 59.080008789896965, 60.096477046608925, 57.671200186014175, 60.50433196127415, 61.294309571385384, 68.1173412501812, 60.185916647315025, 61.20877616107464, 60.87899565696716, 64.38167050480843, 66.21913030743599, 68.69769170880318, 63.00216592848301, 65.79718574881554, 65.18696889281273, 70.3941410779953, 70.45009687542915, 66.1616849899292, 10.973436869680882, 2.0958551997318864, 3.9737799810245633, 2.053266610018909, 0.38144226477015764, 16.499014869332314, 74.96528059244156, 71.10369220376015, 64.50675219297409, 37.86570154130459, 18.90915524214506, 41.91715054214001, 61.69373653829098, 66.15794599056244, 59.43224988877773, 5.261301230639219, 0.2655824739485979, 0.2911656996002421, 0.18624457181431353, 0.12777163210557774, 0.2197733343928121, 0.15860863990383223, 0.13907992921303958, 0.10926304050371982, 0.14149443246424198], [0.06368492409819737, 0.03789891772612464, 0.10149491397896782, 0.02951466947706649, 0.03297656017821282, 0.054299542753142305, 0.04504853466642089, 0.015637693504686467, 0.04935281307552941, 2.711140033788979, 44.75340574979782, 51.21106043457985, 49.6848039329052, 35.205445289611816, 22.045157365500927, 37.5782735645771, 36.89598597586155, 50.53694620728493, 62.98515044152737, 51.8671902269125, 4.3728528544306755, 0.31469875713810325, 0.3257031744578853, 2.8735271701589227, 14.842155575752258, 75.5328181385994, 62.43357963860035, 62.278631553053856, 52.81470738351345, 49.04994159936905, 49.56854157149792, 48.488631919026375, 51.72490306198597, 54.62730132043362, 57.78851509094238, 54.54109534621239, 56.68708339333534, 56.09032541513443, 55.2346683293581, 53.62808033823967, 53.881636932492256, 53.70834343135357, 49.6049740165472, 52.79637336730957, 50.804429054260254, 51.29297263920307, 48.30324366688728, 39.62707042694092, 39.748698100447655, 40.504591539502144, 40.46215921640396, 40.24949222803116, 40.58118022978306, 39.83229361474514, 40.43189004063606, 39.58705477416515, 40.212573409080505, 40.35106837749481, 41.079018115997314, 39.19639393687248, 38.26269283890724, 39.45142105221748, 39.12975311279297, 40.18346317112446, 40.03607288002968, 39.892254397273064, 42.02484056353569, 43.10574196279049, 41.553038880228996, 43.72747220098972, 41.88958302140236, 40.334007292985916, 38.89680661261082, 39.91035282611847, 43.30558083951473, 44.11139219999313, 43.81956785917282, 41.60999782383442, 41.01768180727959, 41.677987575531006, 41.389484256505966, 41.791787669062614, 42.372567504644394, 49.30822513997555, 54.014808386564255, 54.58426482975483, 51.95296682417393, 45.35774812102318, 34.01071339845657, 47.49284975230694, 52.0073077082634, 53.33644598722458, 52.511723041534424, 51.111661568284035, 51.083679869771004, 49.40699703991413, 48.11678387224674, 51.31207801401615, 52.93690122663975, 49.727927818894386, 48.13393235206604, 42.190644666552544, 39.488723650574684, 41.13162249326706, 39.821714982390404, 43.657662346959114, 42.21174493432045, 41.26798577606678, 42.70843528211117, 41.827794536948204, 40.8954955637455, 40.42594715952873, 39.56726163625717, 40.4192291200161, 39.67500865459442, 39.98324431478977, 39.99846249818802, 40.88509552180767, 38.87091860175133, 42.12208494544029, 40.239738151431084, 39.70927521586418, 40.421345606446266, 39.797928258776665, 40.93163542449474, 41.40483543276787, 43.07361848652363, 43.94077755510807, 52.53395564854145, 56.18923790752888, 54.09360095858574, 53.82326826453209, 56.13646253943443, 53.975123316049576, 54.83056761324406, 53.86408947408199, 57.30844505131245, 55.8282420784235, 57.850447967648506, 58.5548959672451, 57.61783204972744, 59.00846242904663, 59.02411758899689, 54.321501329541206, 43.44617709517479, 54.745680168271065, 56.781660318374634, 63.50115895271301, 59.86178644001484, 64.11891460418701, 56.30499869585037, 9.178562331944704, 0.7559871871490031, 6.662933919578791, 0.9359465399757028, 0.26185852533672005, 6.461539501324296, 58.49059201776981, 57.439412623643875, 46.617688313126564, 30.025823526084423, 24.51454795897007, 34.28585283458233, 46.481420025229454, 51.75036549568176, 42.774582132697105, 8.010049033910036, 0.2545708726393059, 0.049076389041147195, 0.04454691705177538, 0.025138870296359528, 0.02236453117802739, 0.01566758906847099, 0.10354850339354016, 0.03241515514673665, 0.10136042939848267, 0.051928700049757026, 0.043682396644726396, 0.017293131822953, 0.04510927574301604, 0.022596862363570835, 0.08520324365235865, 0.015683227975387126, 0.10213563233264722, 0.012500593529694015, 3.363627721555531, 57.71667614579201, 61.088292226195335, 57.304755449295044, 42.5416774302721, 22.869582027196884, 34.920654371380806, 44.910884499549866, 55.55843375623226, 70.62506228685379, 56.43454894423485, 4.323329636827111, 0.4870126530295238, 0.8091880136635154, 1.373635078780353, 18.72365679591894, 80.5652529001236, 63.252146914601326, 64.66698199510574, 54.62429188191891, 50.12664042413235, 51.1040011793375, 51.66751854121685, 53.57867158949375, 56.83173023164272, 58.80046918988228, 58.437330275774, 58.78008708357811, 58.642238080501556, 59.345698133111, 54.97047230601311, 54.87445525825024, 54.3976454436779, 51.35648623108864, 52.952917367219925, 53.04646834731102, 54.530493915081024, 49.07036930322647, 41.64104215800762, 42.72461861371994, 42.284929007291794, 41.43622174859047, 41.94702833890915, 42.07588702440262, 41.45476475358009, 42.50836841762066, 41.613839417696, 42.78482638299465, 41.95154249668121, 43.61289694905281, 40.723421797156334, 40.97347877919674, 41.61122515797615, 41.30083121359348, 41.81373529136181, 42.35346592962742, 42.091534584760666, 44.46920000016689, 44.27661873400211, 42.63391748070717, 45.39165370166302, 43.90824370086193, 41.720218509435654, 41.28554083406925, 43.00008483231068, 45.70893667638302, 45.14443896710873, 46.54243715107441, 43.9468914270401, 42.72370286285877, 43.00820879638195, 42.79269576072693, 44.21698473393917, 44.78464387357235, 52.932706251740456, 57.69598625600338, 54.81793329119682, 52.522776648402214, 46.22139997780323, 36.58001393079758, 48.09096045792103, 52.82202199101448, 55.70865109562874, 54.04298387467861, 51.57826513051987, 54.290954768657684, 51.92973107099533, 50.55817946791649, 52.8791519254446, 53.55955861508846, 50.01571677625179, 50.2429635822773, 44.97802309691906, 42.187164053320885, 43.273829743266106, 42.75397963821888, 43.91389399766922, 43.93790490925312, 43.74504625797272, 44.10094656050205, 42.07719415426254, 42.89730414748192, 42.803806364536285, 41.90174996852875, 41.657483875751495, 43.26871141791344, 42.523525804281235, 43.51148039102554, 43.70959796011448, 41.96494817733765, 43.48080463707447, 42.66352169215679, 41.518506333231926, 42.94592633843422, 42.63402007520199, 43.444809168577194, 43.61288174986839, 43.908376693725586, 46.57423384487629, 52.590033039450645, 58.46618972718716, 56.34414799511433, 56.416127532720566, 58.027799651026726, 58.11178654432297, 58.37594456970692, 55.74998527765274, 57.75343917310238, 57.32424080371857, 58.54899488389492, 59.61227662861347, 60.84392353892326, 59.766966328024864, 62.38746151328087, 54.18345853686333, 44.25483450293541, 56.986598521471024, 57.42330528795719, 64.65086326003075, 61.47449590265751, 64.2076626420021, 56.54605396091938, 10.648781340569258, 1.7929960135370493, 6.229241816326976, 1.8086852529086173, 0.26209084724541754, 6.314661232754588, 64.15321916341782, 64.17274251580238, 53.50777879357338, 27.93154690414667, 24.45724133402109, 43.944459557533264, 54.325316324830055, 59.7359523922205, 53.75884272158146, 11.539452597498894, 0.2880112751154229, 0.02383374609053135, 0.07628244304214604, 0.07186172166257165, 0.08739257929846644, 0.05011015251511708, 0.084627648757305, 0.015191939201031346, 0.03793633310124278, 0.1576948186266236, 0.19138158444548026, 0.16229159227805212, 0.2661473077023402, 0.0857689679833129, 0.16004341916413978, 0.15288918977603316, 0.1411543507128954, 0.21214018226601183, 4.378059050068259, 68.35716158151627, 69.2540730535984, 69.54069927334785, 49.05145391821861, 29.6920570358634, 48.21959115564823, 49.858724400401115, 63.54098081588745, 73.06333065032959, 62.987137734889984, 5.625695502385497, 0.5423912673722953, 1.7264814139343798, 6.2329670414328575, 24.267219230532646, 83.33067610859871, 65.9269867837429, 65.88871523737907, 57.880245968699455, 53.60698767006397, 55.20726419985294, 53.66587691009045, 56.634365022182465, 57.82867133617401, 62.64484070241451, 59.61156226694584, 61.0930609703064, 59.26263839006424, 59.65495593845844, 56.7661115527153, 55.835226103663445, 54.522742331027985, 50.77187240123749, 54.5366495847702, 54.90073464810848, 55.50379268825054, 51.099099442362785, 43.73856760561466, 44.36109200119972, 45.28529740869999, 44.44949045777321, 44.58106219768524, 44.28858429193497, 44.246151968836784, 45.89430592954159, 43.809859380126, 44.60737198591232, 44.21179421246052, 45.97499839961529, 42.98238918185234, 41.008075922727585, 43.12355920672417, 42.926646173000336, 44.299945682287216, 43.7380850315094, 44.705646112561226, 46.149766221642494, 46.297414898872375, 44.142907708883286, 47.727635353803635, 46.840447559952736, 43.08046571910381, 42.76616558432579, 44.66765195131302, 49.01606261730194, 47.20963194966316, 49.174141734838486, 46.30124889314175, 46.716680601239204, 45.65368764102459, 46.07193499803543, 46.9390294700861, 47.071349769830704, 54.17270511388779, 58.267012014985085, 58.203145042061806, 54.672473296523094, 45.93686364591122, 38.70406195521355, 51.38447932898998, 55.36337122321129, 56.41699768602848, 56.58325396478176, 55.16535624861717, 60.00076398253441, 53.78777056932449, 54.03772495687008, 55.945230200886726, 55.837927758693695, 53.430460542440414, 54.15150225162506, 46.790651232004166, 44.39419582486153, 45.72196617722511, 43.27172465622425, 46.37567549943924, 46.68308660387993, 45.21083280444145, 46.9458045065403, 45.6278870254755, 45.56075602769852, 44.428606778383255, 43.46307098865509, 42.96544589102268, 44.56880405545235, 44.42802540957928, 45.101869851350784, 45.87954752147198, 43.3635201305151, 47.4864736944437, 45.88367410004139, 43.10079462826252, 45.8748509734869, 42.976347506046295, 45.85743270814419, 45.85175201296806, 46.96592442691326, 48.61379720270634, 57.610445246100426, 60.8105993270874, 58.900426626205444, 56.015116050839424, 61.32806695997715, 61.53196021914482, 60.69804936647415, 56.138693019747734, 61.28530405461788, 59.3817164003849, 60.78653521835804, 63.36075268685818, 62.99383297562599, 62.997119799256325, 63.7227288633585, 56.74778513610363, 48.79635840654373, 57.76471696794033, 58.219978138804436, 67.35677406191826, 62.4577197432518, 67.72594705224037, 58.19487288594246, 12.616211269050837, 2.9283741395920515, 13.824768718332052, 2.2033122461289167, 0.47450850368477404, 8.249139804393053, 70.33971279859543, 68.99517014622688, 64.16648045182228, 40.75149469077587, 35.641072914004326, 50.01818664371967, 63.35086181759834, 68.41122508049011, 67.52344071865082, 15.82380535081029, 0.5494221369735897, 0.2087734144879505, 0.19800008711172268, 0.18010659492574632, 0.15947943145874888, 0.09662125245085917, 0.21794820029754192, 0.1062047464074567, 0.32448943646159023], [0.0700355634035077, 0.028308766704867594, 0.09092727283132263, 0.012214438083901769, 0.016722405416658148, 0.05419707071268931, 0.06930156450835057, 0.09051518791238777, 0.03664398682303727, 2.3389597423374653, 51.87879100441933, 49.32946979999542, 47.990927025675774, 25.903449431061745, 24.277995452284813, 49.79933358728886, 42.95957140624523, 55.09914480149746, 60.92433102428913, 48.8667344301939, 2.6703356858342886, 0.28788591152988374, 0.4556657304055989, 1.348843784071505, 22.097461558878422, 69.96188387274742, 64.33771446347237, 58.88075888156891, 49.757520630955696, 49.918905571103096, 48.71767982840538, 53.16001005470753, 53.912506476044655, 57.20024585723877, 56.858340203762054, 57.689705193042755, 54.09557305276394, 54.39520977437496, 50.80384388566017, 55.28845824301243, 56.25813581049442, 55.132241025567055, 54.851728677749634, 55.81374205648899, 54.71969336271286, 51.37967258691788, 46.32865682244301, 39.02020499110222, 39.08813014626503, 40.77152721583843, 39.39310938119888, 39.45661157369614, 38.48111651837826, 39.49378117918968, 41.02644793689251, 41.667363345623016, 40.17047166824341, 39.82646472752094, 37.88387976586819, 39.70168702304363, 38.05568754673004, 38.89163129031658, 38.003432750701904, 41.5187419205904, 41.81501962244511, 41.07565529644489, 41.474128514528275, 39.6427483856678, 42.98393949866295, 42.57665075361729, 41.907654851675034, 42.555124908685684, 40.44965408742428, 40.98494276404381, 41.44018113613129, 44.141167402267456, 42.70123466849327, 41.527800634503365, 40.69403797388077, 39.20016333460808, 38.46933335065842, 42.153798043727875, 41.17861457169056, 49.095216169953346, 52.452959194779396, 54.213632717728615, 52.22412407398224, 52.04299159348011, 33.38775962591171, 47.31096111238003, 50.18380455672741, 50.04835702478886, 51.573443189263344, 50.1157958060503, 49.102865159511566, 49.83299218118191, 49.643161967396736, 47.684177085757256, 47.916675209999084, 50.74959419667721, 46.90733157098293, 40.347108989953995, 41.03875167667866, 41.548277735710144, 41.872917115688324, 43.406024649739265, 42.77914948761463, 40.926885679364204, 42.2273924946785, 41.478741466999054, 42.427174374461174, 40.537376180291176, 39.13847744464874, 40.76437219977379, 39.739411398768425, 40.58305352926254, 40.50491452217102, 40.6800889223814, 39.09849978983402, 38.22117246687412, 38.72285954654217, 40.593088790774345, 42.093309089541435, 40.71754351258278, 39.92915041744709, 40.3119570761919, 41.80321745574474, 41.661591455340385, 51.13232485949993, 53.68674539029598, 56.345261335372925, 56.66077360510826, 54.26495276391506, 53.177416920661926, 52.6150318980217, 53.66113096475601, 56.83652937412262, 55.17423257231712, 55.74856035411358, 54.2683269828558, 58.38968463242054, 54.34916764497757, 61.47177144885063, 43.003770634531975, 36.35593995451927, 55.87702766060829, 55.102116242051125, 59.626309275627136, 60.14749690890312, 59.71093833446503, 56.58306397497654, 6.883458411321044, 0.9567823063116521, 7.216939916834235, 3.072856399230659, 0.07177561026765034, 2.522032493725419, 52.712641060352325, 60.91551549732685, 52.22526781260967, 48.259177431464195, 25.91092173010111, 17.984814941883087, 39.75052960216999, 47.98999987542629, 54.22299921512604, 14.194559175521135, 0.27694282529409975, 0.04900478292256594, 0.036196568253217265, 0.04223972464387771, 0.06624922243645415, 0.06251148472074419, 0.02289405540068401, 0.03392015270947013, 0.023285542010853533, 0.12205159568111412, 0.03771177405724302, 0.06473645829828456, 0.04533913001068868, 0.06406626183888875, 0.03395341205759905, 0.05738804968132172, 0.1498381167766638, 0.07239149636006914, 4.0054695680737495, 63.09287466108799, 58.059698939323425, 55.937999188899994, 30.745573304593563, 24.947196543216705, 44.82209846377373, 43.254671171307564, 60.43198764324188, 66.3614858686924, 52.22847864031792, 2.479609907604754, 0.24947887868620455, 0.8605478389654309, 1.3905331282876432, 28.422108180820942, 73.8279940187931, 65.84709227085114, 60.99780388176441, 51.72913983464241, 51.507467329502106, 52.6114334911108, 54.37473647296429, 56.27154529094696, 58.96477997303009, 56.759074330329895, 59.45813030004501, 56.22713327407837, 55.32572664320469, 52.305413112044334, 55.87869197130203, 56.630215644836426, 55.2015683054924, 54.42315727472305, 56.38789884746075, 56.85639850795269, 53.34389738738537, 47.71175600588322, 40.67350007593632, 40.52514083683491, 41.39034681022167, 41.311235055327415, 40.54689086973667, 42.28710629045963, 43.0282337218523, 42.232123240828514, 42.97150656580925, 41.580040231347084, 41.47311016917229, 40.97613483667374, 41.0785773396492, 40.5121873319149, 40.75757056474686, 39.94186453521252, 42.27569930255413, 42.01891288161278, 43.27628821134567, 41.592191979289055, 42.53027804195881, 44.65496063232422, 44.31200623512268, 44.23651568591595, 43.2334341108799, 42.479474768042564, 43.60860697925091, 42.440021485090256, 45.91580517590046, 45.05588851869106, 42.59487837553024, 44.00171868503094, 41.61751762032509, 42.965799272060394, 45.7452817261219, 42.518373280763626, 51.23932331800461, 54.06716197729111, 53.62535588443279, 54.916317611932755, 54.78740952908993, 35.613699182868004, 47.59184584021568, 53.48020367324352, 53.691137954592705, 54.33638133108616, 52.44586117565632, 52.692179158329964, 53.196461498737335, 52.23467990756035, 50.18695078790188, 49.535532742738724, 52.984679862856865, 50.01241475343704, 41.768111139535904, 42.69667491316795, 43.76553475856781, 43.8015416264534, 45.13248860836029, 44.547544196248055, 43.63935872912407, 42.900636568665504, 43.319184109568596, 43.644192069768906, 43.8071159273386, 40.91876931488514, 43.13866339623928, 42.38893702626228, 41.640779972076416, 41.93007744848728, 43.08224022388458, 40.8896628767252, 40.66624626517296, 41.029214188456535, 42.74622045457363, 42.55044735968113, 43.71714435517788, 41.82063952088356, 42.76434168219566, 43.24031554162502, 44.31961342692375, 54.069080874323845, 56.04246698319912, 57.57515273988247, 56.83244839310646, 55.550032407045364, 56.45341873168945, 54.63944546878338, 56.74133688211441, 58.31317573785782, 56.532990261912346, 57.457541450858116, 57.15524107217789, 58.97506982088089, 56.46634563803673, 62.47730389237404, 46.55266620218754, 38.303092271089554, 58.51757436990738, 56.323625296354294, 62.035558596253395, 61.80238410830498, 58.35002616047859, 55.392952635884285, 9.055273197591305, 2.498702220618725, 6.1733202170580626, 2.2219457337632775, 0.05623781726171728, 2.592263650149107, 57.352777272462845, 67.94831112027168, 59.07174043357372, 40.77444925904274, 28.098570741713047, 26.270433738827705, 46.8367313593626, 55.656270906329155, 66.4561615884304, 21.191352680325508, 0.5376337445341051, 0.04773385502630845, 0.10785153499455191, 0.03484028595266864, 0.041152611884172074, 0.03678182962175924, 0.0238020860706456, 0.016679609470884316, 0.01834530798078049, 0.20430037169717252, 0.17652819631621242, 0.21132809459231794, 0.15106111677596346, 0.22739844163879752, 0.10423165032989345, 0.1350378812639974, 0.2777538145892322, 0.257447644835338, 6.272787479683757, 76.80479988455772, 64.88044694066048, 64.40759271383286, 36.864014491438866, 35.95311596989632, 58.29538509249687, 57.39536538720131, 67.19285845756531, 71.34035870432854, 59.079742804169655, 3.2256302889436483, 0.46949891780968755, 1.4714592858217657, 2.6166509790346026, 35.44555440545082, 75.74921652674675, 70.51811322569847, 62.768573462963104, 53.75669203698635, 55.253735706210136, 54.017114862799644, 55.700827315449715, 59.02615427970886, 60.473177433013916, 61.04956090450287, 60.963909700512886, 56.91379822790623, 54.732114896178246, 53.358386009931564, 56.78939290344715, 59.52118791639805, 56.87825493514538, 55.94823203980923, 59.14312340319157, 58.52584272623062, 56.353810876607895, 52.296084612607956, 42.88430504500866, 44.006244242191315, 45.07895328104496, 43.58368031680584, 43.52981060743332, 45.734471306204796, 44.48393560945988, 46.115191876888275, 46.26968018710613, 44.73814196884632, 44.69874568283558, 42.0053818076849, 43.34869712591171, 41.40279494225979, 42.76140443980694, 42.02509894967079, 44.55117680132389, 45.24789981544018, 45.12622654438019, 43.81755396723747, 41.762350648641586, 48.515086099505424, 45.529411509633064, 46.10772147774696, 45.27241609990597, 44.8983109742403, 46.2584213912487, 45.47671973705292, 49.81459356844425, 47.526633739471436, 45.57293817400932, 46.245817467570305, 42.48198263347149, 43.85331004858017, 49.81367401778698, 45.336058884859085, 53.39125044643879, 55.63000291585922, 57.81849168241024, 58.188481628894806, 58.678784519433975, 40.327635034918785, 51.02972276508808, 56.115016490221024, 56.933450773358345, 58.02792124450207, 54.826631024479866, 54.5625413954258, 55.66630236804485, 53.144985660910606, 52.0804575830698, 52.20749616622925, 55.18268331885338, 54.26954671740532, 43.75526770949364, 47.15222083032131, 46.08431853353977, 45.43965272605419, 47.820179387927055, 46.57488361001015, 45.01328520476818, 45.6601282954216, 46.90772294998169, 45.97401425242424, 46.27841591835022, 42.03838303685188, 43.84881488978863, 43.636706471443176, 43.19960832595825, 43.980793207883835, 45.38274697959423, 43.381147384643555, 43.49187724292278, 42.475025206804276, 43.598332330584526, 45.226674154400826, 47.50495970249176, 43.846645206213, 44.98139351606369, 46.637162268161774, 46.10060065984726, 55.289020612835884, 58.550260215997696, 58.701663091778755, 59.93921868503094, 58.627958446741104, 58.681733161211014, 56.49750776588917, 56.953080520033836, 62.762493789196014, 59.748522117733955, 59.44895379245281, 58.435183390975, 60.64531199634075, 59.678051099181175, 65.71026921272278, 50.17935499548912, 41.26445196568966, 59.28214654326439, 58.38014334440231, 64.2161513864994, 64.52103182673454, 61.5445451438427, 58.79573084414005, 9.477568287402391, 3.3138587046414614, 19.535059556365013, 7.451106626540422, 0.1231258841289673, 3.093860484659672, 62.94816702604294, 72.33981147408485, 70.3105379641056, 62.47365988790989, 37.637717574834824, 31.49564355611801, 56.491880267858505, 65.00903964042664, 76.20241820812225, 27.727098874747753, 0.9358234622050077, 0.20375147927552462, 0.23279946588445455, 0.1359836891060695, 0.14160848571918905, 0.18668505130335689, 0.16348070581443608, 0.3277838003123179, 0.24126594595145434], [0.06591407596715726, 0.014555695070157526, 0.05025855978601612, 0.02048427220870508, 0.017277997576456983, 0.01735845009534387, 0.08226772304624319, 0.057105822052108124, 0.008039275744522456, 2.1497593447566032, 44.31566163897514, 53.93761932849884, 49.49552468955517, 33.77609498798847, 23.902583196759224, 35.34703329205513, 44.8274789750576, 54.402509182691574, 61.57451033592224, 44.005609676241875, 1.0545411449857056, 0.06165913182485383, 0.5187516077421606, 0.5048182897735387, 35.36679983139038, 73.37696582078934, 59.641022086143494, 59.86360274255276, 51.42614409327507, 56.87565967440605, 55.37967994809151, 56.472508907318115, 56.08546927571297, 56.91262789070606, 55.27373023331165, 53.96873585879803, 48.314855843782425, 53.922154158353806, 58.18327970802784, 60.20290933549404, 55.21315008401871, 58.55058699846268, 55.20210787653923, 54.492222368717194, 52.65961870551109, 48.831434324383736, 41.45542971789837, 38.513126000761986, 39.52408455312252, 37.96597056090832, 38.555847108364105, 38.69426608085632, 39.582571014761925, 40.43970242142677, 39.1127148270607, 39.68366838991642, 38.631755635142326, 38.12858663499355, 38.785191401839256, 38.18941377103329, 40.336982533335686, 40.62696777284145, 39.75008882582188, 41.925741881132126, 40.089262425899506, 40.98036400973797, 41.98544807732105, 42.31209374964237, 41.433653086423874, 42.27017059922218, 43.35984192788601, 41.65242254734039, 41.873680874705315, 40.75816713273525, 38.758874014019966, 40.36927320063114, 42.587977945804596, 38.747296035289764, 39.770109951496124, 39.262932166457176, 39.339087679982185, 41.221434473991394, 40.117988884449005, 43.015827387571335, 50.995433405041695, 54.021967202425, 51.964575201272964, 56.07245497405529, 36.47219471633434, 49.110160768032074, 50.882799848914146, 50.74272036552429, 53.730807825922966, 52.2558181732893, 50.900875478982925, 51.248161643743515, 49.60557818412781, 48.187042102217674, 47.904310673475266, 45.306910648941994, 43.121875897049904, 39.86380532383919, 41.61241069436073, 42.0426882058382, 42.40477457642555, 40.1693507283926, 41.67680203914642, 42.13412269949913, 42.24642187356949, 41.99769102036953, 41.61399520933628, 41.655545979738235, 39.79083023965359, 39.21909011900425, 41.903703063726425, 39.97723303735256, 39.90277983248234, 40.14047987759113, 40.69146171212196, 38.539785370230675, 37.820035591721535, 38.40930797159672, 39.648204892873764, 39.91772063076496, 41.37310713529587, 42.01488509774208, 45.570650696754456, 40.51632910966873, 47.470130771398544, 51.44767753779888, 53.05553466081619, 52.089945673942566, 51.63681618869305, 50.05916744470596, 51.318408474326134, 50.4160138964653, 55.71840517222881, 57.38263987004757, 55.68604230880737, 54.53668378293514, 60.45741967856884, 57.047604247927666, 57.458715587854385, 59.45523865520954, 61.775112971663475, 60.29013745486736, 60.70542477071285, 63.2850531488657, 64.86461699008942, 62.68194951117039, 63.13129059970379, 11.302033737301826, 1.1175309587270021, 2.786543662659824, 1.1198819638229907, 0.12175112977274694, 0.37407564755994827, 43.08040492236614, 65.0499102473259, 57.1015727519989, 38.13722737133503, 19.66449201107025, 20.367285199463367, 32.011161893606186, 51.70912250876427, 61.47189684212208, 31.45218338817358, 0.8156539604533464, 0.04979827979695983, 0.05190210147702601, 0.021013508849136997, 0.059737670671893284, 0.08804968427284621, 0.0639366012183018, 0.07495571306208149, 0.0690835363639053, 0.02885502079152502, 0.027927417831961066, 0.11662479664664716, 0.034418642171658576, 0.06033096207829658, 0.03254117182223126, 0.10948240451398306, 0.07745101393084042, 0.1469366459059529, 4.009516825899482, 58.326250836253166, 61.32169470191002, 58.49603712558746, 36.98781184852123, 27.91745726019144, 36.75374060869217, 48.03285397589207, 61.45917132496834, 67.68151223659515, 48.70531149208546, 1.1319441790692508, 0.13317326491232961, 2.4937534611672163, 0.5425450403708965, 41.252022832632065, 74.8180840909481, 62.201290503144264, 60.105284973978996, 54.335374385118484, 59.54470105469227, 58.34206938743591, 57.8830274194479, 59.32810887694359, 57.86248952150345, 59.35329392552376, 55.814619809389114, 49.66259032487869, 53.079169392585754, 58.87556076049805, 59.87223967909813, 59.75553274154663, 58.65972474217415, 56.89478784799576, 56.33337177336216, 54.50514927506447, 49.48324374854565, 40.709719732403755, 40.38702964782715, 41.45049378275871, 39.279978051781654, 40.63796438276768, 40.36806486546993, 41.09028451144695, 41.74728065729141, 41.300413236021996, 43.76358546316624, 40.82610368728638, 40.19262067973614, 40.748033076524734, 40.24866387248039, 41.01403020322323, 41.51414796710014, 42.18211032450199, 42.48346075415611, 41.01172752678394, 42.45780073106289, 44.29922752082348, 43.87987062335014, 42.7723478525877, 44.48957070708275, 45.091811791062355, 44.487750604748726, 43.19131717085838, 43.051587268710136, 42.524734139442444, 43.130813017487526, 43.00074219703674, 41.608827486634254, 42.25855462253094, 42.20281541347504, 41.137390583753586, 42.41024628281593, 44.136125072836876, 45.11059798300266, 53.614895045757294, 57.200318053364754, 56.56500354409218, 57.719769179821014, 39.11309100687504, 52.11976647377014, 55.30705824494362, 53.26559878885746, 53.47784020006657, 53.72793138027191, 52.938880920410156, 53.448999747633934, 49.84915271401405, 49.40946690738201, 49.331590086221695, 47.02916823327541, 45.89527867734432, 41.346295773983, 44.60607245564461, 43.622358441352844, 43.6368128657341, 41.77173234522343, 43.91686923801899, 44.26061399281025, 43.74792270362377, 43.24615202844143, 44.06106010079384, 43.86141121387482, 43.026322424411774, 41.14456459879875, 43.852132111787796, 41.98605604469776, 42.84713923931122, 43.31793397665024, 42.5742606818676, 42.09478721022606, 41.278366819024086, 40.977487564086914, 41.781839802861214, 43.02313819527626, 43.797035068273544, 44.71851222217083, 46.14893786609173, 43.30433450639248, 48.598548620939255, 54.699322655797005, 55.16842268407345, 53.72261926531792, 54.180559292435646, 50.888123363256454, 53.325510174036026, 52.0989777892828, 57.49203599989414, 58.09198960661888, 57.1718879789114, 54.710383862257004, 61.99873477220535, 58.347001522779465, 61.38295501470566, 60.79844757914543, 63.56139712035656, 61.67367361485958, 62.1672747284174, 64.74387466907501, 65.97231835126877, 65.10623082518578, 65.35946443676949, 12.62547042220831, 2.2227123426273465, 3.619762477464974, 1.873492794111371, 0.036304658351582475, 0.6136666552629322, 47.039503678679466, 70.03154173493385, 63.92535299062729, 43.4928347915411, 24.172024838626385, 26.380059756338596, 39.991231486201286, 58.49814221262932, 68.98479670286179, 40.715062245726585, 1.1699867877177894, 0.04329997165768873, 0.05549875320866704, 0.02359986010560533, 0.04301473461964633, 0.13334951014257967, 0.051072666101390496, 0.04288519274268765, 0.08193376401322894, 0.16363657166948542, 0.14704798290040344, 0.11711567538441159, 0.08857686145347543, 0.20563412981573492, 0.1399964073789306, 0.28429931960999966, 0.2630723227048293, 0.26740106230136007, 7.700647786259651, 71.28944903612137, 67.90041089057922, 67.42260932922363, 45.68109177052975, 33.95149737596512, 46.2784843146801, 59.753393456339836, 68.47421050071716, 72.26430952548981, 55.337110832333565, 1.2491923500783741, 0.3000620019156486, 2.664673989638686, 0.7471988524775952, 46.34850315749645, 79.94956433773041, 64.68839004635811, 62.81517036259174, 57.53677099943161, 60.52132084965706, 61.61972410976887, 60.46311177313328, 61.679164320230484, 60.97726218402386, 61.663224175572395, 56.59656085073948, 50.19400700926781, 55.07207125425339, 60.86451083421707, 62.60640196502209, 62.89373494684696, 61.40573859214783, 59.87328082323074, 57.850147783756256, 56.42156504094601, 51.804527789354324, 44.71924178302288, 42.268346697092056, 44.429199546575546, 42.368368729949, 44.38384138047695, 42.19753749668598, 45.63216179609299, 44.10985708236694, 44.402718767523766, 44.80262450873852, 42.90298484265804, 40.988772958517075, 43.75469774007797, 41.711919754743576, 43.582870960235596, 44.858310520648956, 44.58936095237732, 44.46914300322533, 43.75882051885128, 44.54152151942253, 47.16555431485176, 47.324704974889755, 44.82486471533775, 45.690386071801186, 46.974424570798874, 46.34840056300163, 45.233764573931694, 45.67391775548458, 44.08048465847969, 45.525501519441605, 47.51141555607319, 42.560870200395584, 44.79441314935684, 43.84173966944218, 43.97652983665466, 45.91727949678898, 45.837054401636124, 46.944626569747925, 55.647953152656555, 58.45561109483242, 56.92650854587555, 59.45980221033096, 40.59920646250248, 54.09936524927616, 56.28659628331661, 56.98581576347351, 56.92104823887348, 55.61098873615265, 54.49943818151951, 56.848890110850334, 52.68100015819073, 52.864009737968445, 50.89474260807037, 49.6571110188961, 48.18473942577839, 43.58281396329403, 48.30552734434605, 46.43663942813873, 48.19223262369633, 43.998021483421326, 47.22533270716667, 46.61336034536362, 46.17784671485424, 45.88137522339821, 46.460376754403114, 45.67734897136688, 45.31093843281269, 41.55710466206074, 45.525357127189636, 43.489084392786026, 45.21948114037514, 45.75173377990723, 46.80370733141899, 45.69197818636894, 44.04493376612663, 41.999127343297005, 44.01051141321659, 45.8144836127758, 46.52301639318466, 46.21227286756039, 49.847963377833366, 46.70082405209541, 51.502588391304016, 57.63343781232834, 56.62576608359814, 55.592977702617645, 57.26187475025654, 53.47439758479595, 56.76899179816246, 54.0586694329977, 60.28629206120968, 60.76723225414753, 58.33950452506542, 57.14227996766567, 64.32868614792824, 59.62952770292759, 61.300947815179825, 62.8876818716526, 66.44584134221077, 64.09313678741455, 65.94225436449051, 69.09060582518578, 69.79620516300201, 67.41176471114159, 66.66315168142319, 14.96591018512845, 7.174465321004391, 10.031645055860281, 3.2172120781615376, 0.18177207821281627, 0.7276430237106979, 53.597993552684784, 75.67438334226608, 72.5363065302372, 51.694432497024536, 30.55792987346649, 36.82231932878494, 49.082293063402176, 71.6145595908165, 78.12520623207092, 51.89419537782669, 2.0108466362580657, 0.1734157625469379, 0.20763631066074595, 0.11789218449848704, 0.06847138327430002, 0.25562582071870565, 0.2269831209559925, 0.09935349138686433, 0.18262624565977603], [0.04622253807610832, 0.009014717543323059, 0.046414784010266885, 0.05054709195974283, 0.06649771574302576, 0.03125596500467509, 0.02388234563113656, 0.1310203835600987, 0.10735822201240808, 6.58439070917666, 58.16621482372284, 48.79019893705845, 49.939827248454094, 30.595215372741222, 19.886789582669735, 37.28006176650524, 43.728004172444344, 54.633217602968216, 60.95092199742794, 40.99712871015072, 0.5852560547646135, 0.12341153676970862, 0.28053870890289545, 0.4788884811569005, 30.769850201904774, 73.58372032642365, 59.15873296558857, 61.82927906513214, 58.877985030412674, 61.10493153333664, 58.51511970162392, 55.56653872132301, 55.47822766005993, 58.80922392010689, 55.34114621579647, 52.62051120400429, 55.849315747618675, 59.22017186880112, 56.36965222656727, 57.10617430508137, 52.888955399394035, 55.34096002578735, 52.191894203424454, 50.41656866669655, 48.11884716153145, 44.33201216161251, 41.289789006114006, 39.390263333916664, 38.332677483558655, 38.33581991493702, 38.794124722480774, 38.779145926237106, 37.286950796842575, 39.279780462384224, 39.9027456343174, 39.90481272339821, 40.707842633128166, 40.625330060720444, 38.91662634909153, 38.99947330355644, 39.60423365235329, 39.71210606396198, 39.109880179166794, 42.13087387382984, 42.37183794379234, 40.85610307753086, 41.85152806341648, 41.53047189116478, 42.385817393660545, 42.56962113082409, 42.70758792757988, 42.91590414941311, 42.674157321453094, 42.95372731983662, 40.1010075956583, 40.514429211616516, 40.631409734487534, 40.173598900437355, 40.07921576499939, 40.4027646034956, 40.7257054746151, 42.17203326523304, 43.19632910192013, 44.495202004909515, 44.73651185631752, 49.89807888865471, 49.49876591563225, 55.20449034869671, 42.68810257315636, 49.04870666563511, 53.20094905793667, 48.40923137962818, 49.57514561712742, 48.689428344368935, 48.146095499396324, 46.83573581278324, 45.66619277000427, 42.65738122165203, 43.206307366490364, 40.36797747015953, 41.01103216409683, 40.78546106815338, 42.66574837267399, 40.34593105316162, 41.381071507930756, 41.17376983165741, 41.508585065603256, 40.61005488038063, 42.19083845615387, 41.60520628094673, 39.55902747809887, 40.89540436863899, 40.21813251078129, 42.10366353392601, 40.60332544147968, 40.66105954349041, 40.113307535648346, 41.049083322286606, 39.53503176569939, 39.21620227396488, 38.4275583922863, 38.42650584876537, 40.87700575590134, 40.0288874655962, 42.257471680641174, 39.25967954099178, 42.8720773011446, 40.256202667951584, 44.38934728503227, 47.90470965206623, 48.68988811969757, 46.89951539039612, 43.77096846699715, 42.23198264837265, 45.73425471782684, 50.856756046414375, 52.3650699108839, 54.63741637766361, 56.99677437543869, 56.31040580570698, 56.02952867746353, 56.37908712029457, 58.86440835893154, 60.540190637111664, 60.07023565471172, 58.15898381173611, 58.69593299925327, 57.47129671275616, 62.890778705477715, 61.534312292933464, 67.16900333762169, 20.655058957636356, 2.050783443264663, 3.235308132134378, 0.574743147008121, 0.1071318521280773, 0.0743454450275749, 28.326530009508133, 68.08711767196655, 58.38710077106953, 46.9594419747591, 31.149157248437405, 28.971957676112652, 34.88690458238125, 49.76713791489601, 49.502793699502945, 44.162423461675644, 2.2859065141528845, 0.11607136228121817, 0.039429482276318595, 0.0959433228126727, 0.0236781696730759, 0.058083753756363876, 0.043631077132886276, 0.08671093892189674, 0.05403622504672967, 0.007908753304946003, 0.044355702702887356, 0.05242821738647763, 0.05913338805839885, 0.04989563472918235, 0.037651864186045714, 0.018575323665572796, 0.10420569742564112, 0.07882144156610593, 10.212241765111685, 70.1496621966362, 56.864746659994125, 57.05531783401966, 35.08208490908146, 19.8725251480937, 29.3329706043005, 46.913354247808456, 60.34917488694191, 66.93234443664551, 44.25277881324291, 0.6512962142005563, 0.25508868391625583, 4.39863589592278, 0.8107079321052879, 33.150101378560066, 75.46675488352776, 62.16094806790352, 63.71915325522423, 61.06867387890816, 61.78749270737171, 61.16465672850609, 59.18753921985626, 57.676242515444756, 59.64777812361717, 57.020857483148575, 53.57299089431763, 55.49014002084732, 61.544662937521935, 58.696286380290985, 58.68638031184673, 56.51997596025467, 57.16824397444725, 55.29307499527931, 53.07557098567486, 49.64850828051567, 46.15413598716259, 42.74063855409622, 41.374501660466194, 39.74514529109001, 40.84413751959801, 40.43141886591911, 40.44885993003845, 39.38593536615372, 42.142368257045746, 41.52291029691696, 42.59178154170513, 40.85031978785992, 42.30282984673977, 40.43386593461037, 41.41606763005257, 40.81530086696148, 41.225344464182854, 41.157943680882454, 44.16788376867771, 41.2460495531559, 40.83147659897804, 44.036464020609856, 42.670444920659065, 43.989608734846115, 43.28367121517658, 43.94948668777943, 44.759515821933746, 42.90503293275833, 44.75509285926819, 42.34058082103729, 41.489760875701904, 42.6078774780035, 43.60251970589161, 40.99833324551582, 42.905568704009056, 42.5892698764801, 44.248656034469604, 44.77006785571575, 45.0801046192646, 45.953848734498024, 53.66520434617996, 51.659512370824814, 57.64246232807636, 44.96492139995098, 50.316501036286354, 56.203350350260735, 51.00492909550667, 51.91312976181507, 50.15988864004612, 50.833603888750076, 48.69649216532707, 47.97179505228996, 46.44966892898083, 44.760328978300095, 43.30779232084751, 41.31331354379654, 42.48055011034012, 42.15717986226082, 42.898132503032684, 43.33380192518234, 42.9057776927948, 41.73666402697563, 42.56412282586098, 44.31145526468754, 42.89242900907993, 42.297312542796135, 43.03950771689415, 42.910747826099396, 43.25094357132912, 42.661287412047386, 41.43884740769863, 42.49326042830944, 42.59186513721943, 41.58983610570431, 40.627560541033745, 39.56695005297661, 42.419183403253555, 42.6750198751688, 43.32114100456238, 43.3657506108284, 42.90068976581097, 45.59308089315891, 43.10978874564171, 46.61283977329731, 50.048509016633034, 50.99170960485935, 46.27142809331417, 45.406803488731384, 42.888545617461205, 47.948525100946426, 53.818153738975525, 54.06444512307644, 56.03777803480625, 59.74661082029343, 59.252242147922516, 60.098080560564995, 59.42727215588093, 61.39213912189007, 60.98970651626587, 61.76370218396187, 59.65248607099056, 62.11141772568226, 58.54293800890446, 64.591563642025, 64.26060900092125, 71.41243323683739, 21.720595881342888, 0.6122395349666476, 4.015931356698275, 2.9036374669522047, 0.2261393584194593, 0.002874980837077601, 30.514636896550655, 74.0483745932579, 64.20218333601952, 46.746265813708305, 27.050602175295353, 35.055668726563454, 43.02469611167908, 58.29631984233856, 57.60265186429024, 52.997507974505424, 3.97195584140718, 0.22328203049255535, 0.03616513087763451, 0.027824218486784957, 0.012765191440848866, 0.019398458207433578, 0.07862221944378689, 0.004938548891004757, 0.07878662741859443, 0.18873572407756, 0.0983347230067011, 0.0950979498156812, 0.16208883753279224, 0.09971107298042625, 0.1787365903146565, 0.10118566104210913, 0.2552952681435272, 0.18465627188561484, 12.987160664051771, 80.3930689394474, 65.41799649596214, 66.41710728406906, 41.40819065272808, 27.65280906111002, 49.570718854665756, 58.5427176207304, 65.5264350771904, 72.33578369021416, 48.8437494635582, 0.7824845903087407, 0.34033954376354814, 2.8075881209224463, 0.5904147529508919, 35.82604318857193, 78.15797567367554, 64.3983744084835, 66.86967819929123, 65.32076731324196, 65.32196804881096, 63.5696654766798, 60.36975838243961, 60.01803405582905, 61.85360535979271, 58.33178713917732, 55.485865250229836, 57.411886900663376, 63.25497016310692, 62.01909027993679, 61.12288556993008, 58.6369563639164, 60.56199386715889, 57.964103668928146, 54.75888065993786, 52.64685899019241, 48.7486519664526, 45.67438893020153, 43.0618467181921, 44.510465785861015, 43.86166200041771, 43.4354654699564, 43.73810023069382, 41.17472358047962, 44.84888322651386, 43.567314594984055, 45.97016505897045, 44.6427670866251, 43.95141698420048, 42.871651723980904, 43.97182188928127, 43.460673317313194, 43.38454060256481, 42.68877133727074, 46.001775562763214, 44.21239838004112, 44.88592743873596, 47.01968774199486, 44.40083786845207, 46.334527507424355, 45.75491040945053, 46.6035682708025, 45.76846428215504, 44.628058075904846, 46.95743948221207, 44.32935610413551, 43.81651282310486, 45.99899411201477, 47.17720448970795, 42.94696748256683, 46.92827604711056, 46.285236552357674, 47.92350724339485, 48.56865182518959, 49.542702957987785, 50.351033583283424, 55.606748163700104, 54.38797876238823, 59.172963201999664, 47.6938209682703, 54.92040619254112, 59.45999599993229, 53.64120103418827, 54.015545547008514, 51.82187765836716, 51.691301465034485, 52.119648680090904, 49.96655501425266, 47.00874052941799, 48.183690682053566, 45.0115031003952, 43.83439086377621, 44.64947372674942, 44.27044786512852, 44.289465844631195, 46.11055612564087, 45.56439243257046, 45.99170610308647, 43.98455120623112, 46.734585240483284, 46.434678733348846, 44.123296961188316, 46.47013463079929, 43.82116757333279, 46.60204075276852, 45.3211484849453, 43.8532492518425, 44.27323691546917, 46.2659677863121, 44.67764921486378, 43.29378627240658, 41.20695725083351, 44.01154115796089, 44.481952115893364, 45.173002034425735, 47.435119450092316, 43.948601335287094, 47.11168460547924, 45.57985380291939, 48.65853600203991, 52.1883337944746, 54.056997522711754, 50.609210729599, 48.128764629364014, 45.05730964243412, 50.08485406637192, 55.316538736224174, 57.281827479600906, 58.13550867140293, 63.13268892467022, 61.716330125927925, 63.00547555088997, 61.056795716285706, 64.69688639044762, 65.52938371896744, 66.12208351492882, 64.08706471323967, 65.29715538024902, 62.10100628435612, 67.67452821135521, 67.02609300613403, 74.1151674091816, 25.806873813271523, 5.533200390636921, 9.973172843456268, 4.390377514064312, 0.7931437902152538, 0.12743110506562516, 34.044064208865166, 81.1290742456913, 70.23894980549812, 60.95075860619545, 42.39925727248192, 42.301712706685066, 49.568514972925186, 67.68006071448326, 66.63328528404236, 64.06679660081863, 5.619506584480405, 0.32119673502165824, 0.12317326283664443, 0.1980951859150082, 0.10601340589346364, 0.18423505855025724, 0.15603705367539078, 0.16327970253769308, 0.20734941121190786], [0.028937228489667177, 0.01493952828241163, 0.044304876719252206, 0.022743417976016644, 0.06352075361064635, 0.08022581503610127, 0.05988279022858478, 0.1253448982606642, 0.044447461841627955, 7.544365497305989, 59.33555267751217, 47.749613374471664, 49.67094987630844, 25.95866996794939, 25.05088347941637, 38.0097746104002, 41.76411375403404, 54.45559613406658, 61.76669642329216, 35.86881749331951, 0.5404077738057822, 0.1342555388691835, 5.69511872716248, 0.8008310152217746, 14.55488434061408, 75.31160920858383, 58.33774521946907, 66.5425081551075, 54.93041105568409, 64.930969029665, 57.894404008984566, 61.26146413385868, 55.79064689576626, 58.56347590684891, 54.268266186118126, 56.463959366083145, 58.34715351462364, 57.35104836523533, 54.7252144664526, 55.18198795616627, 50.41152633726597, 49.878593534231186, 49.02375340461731, 45.63509523868561, 44.90254394710064, 44.058974012732506, 40.44689543545246, 38.8770704716444, 37.68639296293259, 38.848458006978035, 38.18163178861141, 38.309840708971024, 36.441256776452065, 38.910345286130905, 38.471373841166496, 38.43137338757515, 39.34121176600456, 40.70366285741329, 39.8311422765255, 41.28470487892628, 40.58505602180958, 40.20384527742863, 40.247903913259506, 40.76877996325493, 39.928477853536606, 42.3571403324604, 40.91080114245415, 42.32312835752964, 42.104765474796295, 42.24385321140289, 42.69347928464413, 43.16827140748501, 42.46385760605335, 41.74554795026779, 40.68108066916466, 38.828091099858284, 38.6277886480093, 39.19127561151981, 39.4892518222332, 39.48669075965881, 38.28437827527523, 42.96621344983578, 40.53375877439976, 43.16859818994999, 40.627492144703865, 46.744669899344444, 50.53359858691692, 54.65813286602497, 44.029996767640114, 49.20739375054836, 52.28055864572525, 47.477403581142426, 44.210152700543404, 42.47599795460701, 41.10281623899937, 42.16312654316425, 40.82279786467552, 42.474888414144516, 40.187962129712105, 39.85520638525486, 41.531976610422134, 40.39866082370281, 40.545788928866386, 40.582840740680695, 39.57630135118961, 40.057138949632645, 39.707006737589836, 41.51675842702389, 40.53239084780216, 40.72357378900051, 41.8204191327095, 40.62369614839554, 40.411397740244865, 41.29899591207504, 41.001034900546074, 40.59521287679672, 40.279107838869095, 39.89919662475586, 39.61939483880997, 39.63028125464916, 38.711847737431526, 39.907647371292114, 39.3870335072279, 40.760526806116104, 38.68208773434162, 41.52802862226963, 41.159531995654106, 40.76450899243355, 39.965453669428825, 42.74937428534031, 45.037375912070274, 42.78090499341488, 41.03868328034878, 41.669248044490814, 41.412834003567696, 44.55241933465004, 48.63042131066322, 51.41019634902477, 53.14068429172039, 53.256540074944496, 54.950147196650505, 56.54320791363716, 55.37072002887726, 54.42617051303387, 56.77118808031082, 52.174012362957, 54.84578959643841, 55.1014968752861, 59.538575783371925, 61.122798174619675, 68.46872359514236, 29.73559509962797, 0.45200706110335886, 1.7919184151105583, 1.449467847123742, 0.23267776850843802, 0.11543937158421613, 18.028761483728886, 67.37125888466835, 59.06135939061642, 56.29574999213219, 45.48429273068905, 36.21936768293381, 46.333060786128044, 56.533666625618935, 51.361209377646446, 47.194645553827286, 4.327687053009868, 0.3510778269264847, 0.034626547421794385, 0.10590638819849119, 0.024212226562667638, 0.07874595030443743, 0.059209191022091545, 0.06400087862857617, 0.03453301826084498, 0.04477097885683179, 0.029831052597728558, 0.03545983825461008, 0.027755799892474897, 0.03982616020948626, 0.05749623254814651, 0.04397339274873957, 0.06641169340582564, 0.019164626028214116, 10.659477766603231, 69.33813974261284, 53.928268030285835, 58.15685972571373, 33.25865015387535, 28.054088428616524, 36.392687782645226, 46.08929246664047, 60.34852512180805, 67.7466331422329, 40.77891781926155, 0.3059790562838316, 0.16947556694503874, 8.55210229754448, 4.4522681180387735, 17.123762145638466, 76.43332421779633, 59.91506718099117, 67.87215560674667, 57.537040784955025, 65.4766197502613, 60.312769040465355, 62.85302393138409, 57.421747371554375, 59.19491082429886, 54.21407729387283, 56.30387395620346, 60.51290810108185, 60.19646108150482, 56.18628926575184, 56.03844679892063, 52.07814730703831, 52.09811143577099, 51.291973292827606, 47.90461465716362, 46.61897264420986, 45.65338745713234, 41.52393624186516, 40.34696079790592, 40.682228207588196, 40.52834786474705, 40.25369480252266, 42.02142454683781, 39.129312336444855, 40.808487832546234, 40.576023906469345, 40.352485701441765, 41.522929295897484, 42.88642533123493, 42.20361337065697, 41.50409750640392, 41.91805489361286, 41.23626887798309, 40.80442205071449, 41.8736656755209, 41.99690066277981, 43.47712643444538, 44.675699919462204, 44.03820812702179, 43.665379732847214, 44.18746031820774, 45.53519859910011, 44.74093481898308, 43.92586335539818, 44.19305741786957, 42.297510132193565, 41.79329998791218, 41.050257459282875, 41.224907487630844, 40.663164630532265, 40.406765788793564, 39.75472837686539, 45.158338621258736, 45.33519633114338, 46.77307717502117, 43.77519764006138, 48.37367668747902, 52.91667491197586, 57.22280144691467, 45.113155245780945, 51.212933734059334, 53.31678964197636, 50.72488032281399, 46.65835753083229, 44.974819868803024, 45.251722410321236, 44.37505625188351, 44.562766179442406, 44.09765213727951, 41.63363255560398, 40.946591421961784, 42.743530198931694, 42.253151312470436, 41.40821345150471, 41.826312616467476, 42.03874781727791, 41.23823717236519, 42.38332472741604, 44.009512066841125, 43.374467343091965, 42.07437850534916, 41.79346717894077, 42.58459612727165, 41.81574538350105, 42.43055999279022, 42.27231748402119, 42.29465648531914, 41.21436305344105, 41.34128384292126, 40.96664674580097, 41.64502814412117, 40.76123356819153, 41.29809536039829, 42.379369139671326, 43.404196947813034, 41.017852798104286, 42.72236913442612, 44.36266511678696, 42.41949878633022, 42.57041148841381, 45.26675820350647, 46.66933514177799, 44.9991537630558, 44.94676597416401, 43.33928123116493, 44.34296317398548, 45.59474520385265, 49.665386974811554, 52.09641672670841, 55.2654542773962, 55.941122621297836, 57.777009308338165, 58.549580052495, 56.55006654560566, 57.08192020654678, 58.57212044298649, 54.199261888861656, 55.562347546219826, 58.740474209189415, 62.34762065112591, 63.072709143161774, 70.90583682060242, 31.538871936500072, 0.4397213406627998, 1.8432705220766366, 2.349752113223076, 0.5304984992835671, 0.1772057919879444, 19.56330344080925, 72.33354181051254, 65.3319539129734, 58.37771147489548, 41.44948683679104, 40.05908444523811, 52.402741089463234, 65.03512144088745, 58.72986897826195, 57.80391566455364, 6.723889298737049, 0.2673588489415124, 0.019576085687731393, 0.05991097328660544, 0.04046555382956285, 0.04580521730531473, 0.05894008085306268, 0.06097914643760305, 0.036533495876938105, 0.18807049258612096, 0.08976092838565819, 0.09265789441997185, 0.08241063100285828, 0.24654928041854873, 0.1634875187301077, 0.11900000317837112, 0.22977266111411154, 0.13199371023802087, 14.76728344336152, 81.37239038944244, 63.411069586873055, 68.79771754145622, 38.45691941678524, 36.41164496541023, 51.48062936961651, 57.00061596930027, 64.2842285335064, 73.27925026416779, 43.12068276107311, 0.6459327426273376, 0.31795334187336266, 12.462837249040604, 3.458579401485622, 17.52450194209814, 80.33024311065674, 62.725491374731064, 71.97193801403046, 59.39675599336624, 68.93578693270683, 62.41568639874458, 66.26991838216782, 60.07327549159527, 61.888126507401466, 56.139361783862114, 57.36322671175003, 62.32596181333065, 61.78403489291668, 59.1705085337162, 60.27691416442394, 56.5991485118866, 54.23081539571285, 54.02452066540718, 51.50904804468155, 49.41732108592987, 49.4459031522274, 44.82428714632988, 42.0414874702692, 43.303585946559906, 43.806150779128075, 42.69009746611118, 45.04105031490326, 40.788637697696686, 42.37419381737709, 44.30668272078037, 41.39520674943924, 44.15364973247051, 46.19961574673653, 44.06029634177685, 44.793189615011215, 45.05768962204456, 42.28763826191425, 44.660797119140625, 44.347203746438026, 44.21570420265198, 46.42090067267418, 44.280657917261124, 46.670813262462616, 45.69134742021561, 46.19475960731506, 46.78569629788399, 46.03182815015316, 46.26624137163162, 46.35110981762409, 44.770645424723625, 42.45983362197876, 44.84347991645336, 43.753884583711624, 43.10992173850536, 42.830670922994614, 41.63233682513237, 47.530870512127876, 47.17198356986046, 47.52970777451992, 44.609765857458115, 50.84667518734932, 55.90834558010101, 59.29603099822998, 48.8666470348835, 54.078572764992714, 57.29934833943844, 53.13053883612156, 49.64900225400925, 46.757885590195656, 46.240714341402054, 47.71788127720356, 45.42356438934803, 47.730405405163765, 43.654592111706734, 43.23887541890144, 46.95132561028004, 44.030756726861, 43.85087437927723, 44.85901728272438, 44.607554376125336, 42.813735231757164, 45.24746283888817, 46.60102240741253, 45.618045553565025, 44.859750643372536, 45.015295296907425, 44.080112278461456, 43.86583797633648, 45.19107386469841, 45.427299588918686, 43.70389446616173, 43.798931166529655, 44.54885892570019, 43.77433508634567, 44.713663682341576, 43.48972275853157, 43.27789552509785, 43.4340937435627, 45.48046633601189, 43.22058320045471, 46.048870235681534, 47.45004124939442, 43.83012369275093, 44.64478857815266, 46.74161106348038, 48.989422246813774, 47.550994232296944, 45.68486116826534, 46.51470243930817, 46.44875317811966, 47.5272037088871, 53.76525677740574, 55.6126606464386, 58.694641068577766, 59.03215795755386, 59.719392880797386, 61.78409568965435, 60.35423621535301, 59.38572898507118, 61.73300363123417, 56.0478512942791, 60.46890266239643, 61.40320412814617, 64.95493814349174, 66.23356953263283, 72.91924238204956, 33.51525038480759, 1.8839494767598808, 7.754337005317211, 4.635769296437502, 1.5398456412367523, 0.1867711849627085, 21.506737656891346, 78.63016113638878, 70.40515288710594, 70.99477484822273, 55.231199115514755, 52.36928008496761, 63.7729811668396, 74.55881640315056, 68.52932274341583, 69.2960076034069, 11.430650185793638, 0.5231300415471196, 0.18343628500588238, 0.21045506175141782, 0.1540520609705709, 0.12090010161045939, 0.1289105467731133, 0.2346076790126972, 0.1380928431171924], [0.052960289031034335, 0.0426670495653525, 0.08631010496173985, 0.030161892755131703, 0.03065903150854865, 0.04810886595805641, 0.024207508358813357, 0.09026417130371556, 0.1460194998071529, 13.417851403355598, 62.8672731667757, 50.03773659467697, 48.781972378492355, 26.735137403011322, 23.93775410950184, 31.323636285960674, 44.11150619387627, 58.15090164542198, 61.55631311237812, 31.609757132828236, 0.023387687506328803, 0.046013983446755446, 7.110827760770917, 3.9687725622206926, 3.33421824965626, 59.30711880326271, 64.00870531797409, 62.9780600219965, 63.75487133860588, 55.94404086470604, 55.24548254907131, 61.097518131136894, 56.710284948349, 54.82859551906586, 51.16946406662464, 55.145464316010475, 55.70361636579037, 55.49641728401184, 49.575742185115814, 51.0482581704855, 46.09920233488083, 46.57581076025963, 44.693460166454315, 45.05548574030399, 43.114793077111244, 45.00363752245903, 39.43172290921211, 38.918860629200935, 37.36023746430874, 39.49511110782623, 36.52924865484238, 37.5224469602108, 36.38656251132488, 38.065000846982, 39.238792061805725, 38.55933532118797, 39.039333164691925, 39.791309013962746, 39.679469615221024, 38.96784380078316, 38.961349949240685, 40.674381628632545, 38.42741400003433, 40.056272596120834, 40.26242673397064, 38.75806845724583, 40.60915432870388, 42.02305845916271, 42.3585956543684, 42.184515595436096, 41.48996986448765, 41.83003641664982, 42.04561024904251, 42.27117754518986, 40.17459064722061, 40.60263387858868, 38.82882446050644, 40.35602331161499, 36.78342841565609, 40.40049612522125, 39.605457186698914, 39.42307457327843, 41.516465842723846, 42.54043489694595, 41.40334591269493, 46.79320089519024, 50.903311148285866, 55.803395211696625, 43.99369731545448, 47.259036898612976, 53.88626128435135, 46.25362604856491, 42.501745373010635, 40.124573931097984, 40.76919034123421, 40.9841638058424, 40.330705270171165, 41.741117388010025, 41.336249113082886, 40.488693192601204, 38.708021342754364, 38.13232563436031, 38.807545602321625, 40.10450340807438, 38.757304698228836, 40.523723512887955, 40.200687646865845, 41.445204466581345, 39.29456166923046, 41.50049909949303, 38.67483012378216, 41.624254658818245, 41.037258356809616, 41.719241961836815, 40.69270424544811, 41.53615638613701, 40.5764152854681, 39.83067870140076, 38.31663854420185, 38.44826728105545, 38.41238580644131, 39.92236778140068, 39.048585668206215, 40.49270957708359, 38.9762869477272, 40.785936042666435, 41.311379447579384, 41.87516279518604, 40.770174488425255, 41.43901839852333, 41.261567920446396, 39.80982542037964, 39.85569275915623, 39.61748354136944, 40.543737038969994, 43.32464061677456, 42.467778995633125, 44.91688057780266, 45.01548908650875, 48.17865215241909, 47.634551748633385, 48.40683750808239, 47.51272268593311, 49.16056506335735, 45.139746218919754, 49.45314556360245, 47.81699895858765, 55.186513513326645, 60.877350345253944, 63.388817980885506, 64.76046457886696, 40.57288147509098, 0.352386737940833, 1.72744145616889, 2.5101412693038583, 0.2792661334387958, 0.24183585599530488, 10.5028036236763, 62.78570294380188, 66.90780535340309, 51.04212909936905, 50.64859181642532, 38.95216204226017, 38.129935562610626, 54.161332324147224, 48.87847200036049, 52.941521778702736, 5.919917514547706, 0.5101270799059421, 0.07652115484233946, 0.018129489581042435, 0.03245070402044803, 0.01892284915811615, 0.04285373681341298, 0.11856954268296249, 0.11245493602473289, 0.03251134490710683, 0.005096354070701636, 0.012608777324203402, 0.03920067443687003, 0.018305504745512735, 0.05472851153172087, 0.03264393701101653, 0.07243175787152722, 0.07592752575874329, 18.097030520439148, 75.82813829183578, 55.68364843726158, 56.16144619882107, 31.594305261969566, 29.913003779947758, 35.32065510749817, 50.44365741312504, 61.45670905709267, 68.64101395010948, 34.301834776997566, 0.13855555735062808, 0.03540876365150325, 9.077624548226595, 7.695111008360982, 2.4665668699890375, 64.17891338467598, 63.5968492180109, 65.21742805838585, 64.70909133553505, 56.83859646320343, 55.826847553253174, 64.00420635938644, 57.64052823185921, 55.64579486846924, 50.236101150512695, 56.76056385040283, 57.240158915519714, 59.084047973155975, 51.32481873035431, 54.15850907564163, 49.40390020608902, 49.55202765762806, 47.646505907177925, 48.21730747818947, 46.312849670648575, 47.18581862747669, 40.11814847588539, 41.834698766469955, 39.74987603724003, 41.482617259025574, 39.283356070518494, 39.76184539496899, 37.52052426338196, 39.445101991295815, 42.141011729836464, 41.39597810804844, 39.50845219194889, 42.8013326972723, 42.126975283026695, 41.58002123236656, 42.00962997972965, 41.52245432138443, 41.66108228266239, 43.11811789870262, 43.13723847270012, 41.55777342617512, 41.24174438416958, 43.771884217858315, 43.63473817706108, 43.70760686695576, 42.95941561460495, 43.68056371808052, 43.27835530042648, 45.570050328969955, 42.302731052041054, 44.02662634849548, 40.924639999866486, 42.64701917767525, 39.376971647143364, 40.98937712609768, 40.52240498363972, 41.924970522522926, 43.945728689432144, 44.72983941435814, 42.33520410954952, 46.81605666875839, 52.72247113287449, 57.693144008517265, 45.81919156014919, 50.16007483005524, 55.00246278941631, 49.51522283256054, 45.098415836691856, 43.5181300342083, 43.040438666939735, 42.789750918745995, 42.63693451881409, 44.42356064915657, 43.86091724038124, 41.36608511209488, 42.13056229054928, 40.69442555308342, 42.74678282439709, 43.10359887778759, 40.9743869304657, 41.860989555716515, 41.50773771107197, 42.76884824037552, 41.36428780853748, 42.18946672976017, 41.400142684578896, 41.71225033700466, 42.29485787451267, 43.274627700448036, 42.05625727772713, 43.10681350529194, 41.593590304255486, 42.84148894250393, 41.48522771894932, 40.26403404772282, 40.77726110816002, 42.70096108317375, 41.6685526818037, 42.7227833122015, 40.369387194514275, 42.838502302765846, 41.512039080262184, 43.71622480452061, 42.48286798596382, 44.20968532562256, 41.28063529729843, 42.680092602968216, 41.84424005448818, 41.71745605766773, 42.69721448421478, 43.67438904941082, 44.15518864989281, 47.56123848259449, 47.44258984923363, 50.069571286439896, 51.282530799508095, 50.47180250287056, 50.009663701057434, 51.04627847671509, 47.369622364640236, 51.84882961213589, 51.62075065076351, 56.864891052246094, 64.37823548913002, 63.76861900091171, 69.05276745557785, 43.906807377934456, 0.47883463092148304, 0.8946746389847249, 3.691507615149021, 0.7015197223518044, 0.297588839312084, 10.760004222393036, 70.16785562038422, 71.03572905063629, 56.98529899120331, 51.986424028873444, 48.980135545134544, 44.531140476465225, 59.09431502223015, 59.10450227558613, 62.412574365735054, 9.08316845074296, 0.6931815447751433, 0.059242457791697234, 0.05280914694594685, 0.06744626953150146, 0.03214469426893629, 0.013413015858532162, 0.07750096789095551, 0.08091928524663672, 0.0956859088910278, 0.2008651482174173, 0.17638844990869984, 0.13383192097535357, 0.1220537033805158, 0.15852833952521905, 0.10168254375457764, 0.20352160645416006, 0.19004129542736337, 25.083033554255962, 85.42972147464752, 65.26449233293533, 63.960318714380264, 35.955506041646004, 32.0159762352705, 42.55543269217014, 60.467276349663734, 69.27158251404762, 72.33537331223488, 39.316885471343994, 0.1633296490763314, 0.08018990251002833, 15.296166613698006, 7.636558525264263, 4.029145622625947, 65.53783446550369, 66.0024431347847, 66.85651570558548, 65.93294486403465, 58.42162571847439, 56.845436096191406, 65.19005432724953, 58.01734261214733, 55.61790056526661, 52.15212553739548, 58.74866656959057, 60.93477666378021, 60.90997539460659, 54.02281075716019, 56.69429540634155, 52.501030415296555, 51.964309215545654, 49.64228801429272, 51.17626190185547, 49.28440801799297, 50.23946776986122, 43.99403169751167, 44.12175804376602, 42.54929602146149, 44.578208550810814, 41.30176596343517, 44.22990404069424, 38.12792927026749, 41.21550299227238, 44.96020205318928, 44.4394475966692, 42.36176088452339, 45.59655390679836, 45.73386333882809, 43.46476189792156, 44.17398624122143, 43.72930370271206, 43.7219662964344, 44.163992777466774, 44.51129414141178, 43.717414140701294, 43.44364643096924, 45.870507806539536, 45.884863436222076, 45.37441402673721, 43.94816815853119, 45.559657886624336, 45.28281234204769, 46.89525581896305, 44.464218467473984, 46.51295833289623, 42.726887091994286, 45.2050457149744, 42.14152470231056, 43.909782618284225, 44.81746271252632, 44.31614801287651, 44.80099819600582, 47.231647968292236, 46.51072025299072, 50.35458259284496, 58.564570248126984, 59.58701178431511, 50.61991475522518, 53.58057148754597, 57.64553256332874, 51.29512332379818, 47.51423500478268, 45.58387778699398, 45.86448892951012, 46.18166171014309, 45.61394937336445, 47.47693620622158, 46.960456520318985, 44.63216185569763, 43.28147113323212, 42.96504691243172, 43.956774696707726, 45.40483899414539, 43.6277199536562, 44.7701932489872, 43.2049660384655, 46.28018282353878, 44.277538284659386, 45.43173775076866, 43.77022750675678, 46.08715698122978, 45.79416610300541, 45.05442939698696, 45.36931090056896, 46.52975723147392, 44.02927100658417, 44.43591758608818, 43.79448160529137, 41.33982852101326, 42.68690563738346, 44.85579505562782, 43.78069594502449, 44.93635073304176, 42.64938645064831, 45.49556292593479, 45.137261152267456, 46.05589605867863, 45.07686339318752, 45.26149928569794, 45.11027120053768, 44.70657326281071, 44.23121117055416, 43.62442173063755, 45.69886341691017, 47.42675609886646, 47.241937816143036, 49.87041637301445, 50.77055387198925, 52.91406825184822, 52.57540002465248, 52.46190771460533, 52.46631547808647, 54.35367800295353, 49.22887779772282, 55.76006233692169, 52.85869002342224, 61.735743284225464, 66.09847918152809, 67.9125702381134, 70.27861207723618, 46.38313449919224, 0.6265489140059799, 5.4488905146718025, 10.700966790318489, 1.2233176385052502, 0.44417716562747955, 12.524234354496002, 75.73054432868958, 75.71798980236053, 67.22305163741112, 61.08734987676144, 55.42482532560825, 52.490379586815834, 71.96079701185226, 66.39417931437492, 76.29589319229126, 14.081917069852352, 0.8991868968587369, 0.20455191523069516, 0.15857957740081474, 0.15592685958836228, 0.1161853561643511, 0.16822276229504496, 0.24202054686611518, 0.22915175068192184], [0.020964239520253614, 0.05322381453879643, 0.10832859494257718, 0.05906899932597298, 0.005246277642072528, 0.022892198176123202, 0.008837058521748986, 0.19501041941111907, 0.1614006291492842, 10.873292293399572, 63.30964922904968, 45.479599982500076, 47.70052380859852, 30.402377620339394, 29.118320122361183, 33.30370053648949, 46.89359910786152, 60.934263691306114, 59.17974203824997, 28.919264003634453, 0.15943086531478912, 0.1820997364120558, 5.695701045915484, 16.275744549930096, 0.2393031879910268, 25.026876367628574, 63.205967992544174, 62.64242023229599, 42.84268207848072, 40.254127979278564, 63.997792303562164, 59.10007931292057, 56.47782102227211, 53.05341437458992, 54.96853820979595, 55.734083130955696, 57.03113213181496, 53.35005305707455, 50.001904517412186, 47.085663601756096, 41.55199773609638, 46.232955157756805, 43.85362923145294, 43.183060213923454, 40.979410260915756, 41.33793622255325, 38.09117004275322, 37.315529063344, 37.08241157233715, 37.38614447414875, 37.488320991396904, 38.0866102874279, 38.30009803175926, 37.22693681716919, 38.13197985291481, 38.632466197013855, 38.958313912153244, 38.97529900074005, 39.34088498353958, 38.822209015488625, 39.25147198140621, 38.73646281659603, 38.91794107854366, 38.30165594816208, 39.986770525574684, 38.75274494290352, 42.24666886031628, 40.01771606504917, 40.35752423107624, 42.79210679233074, 41.128943637013435, 41.905340775847435, 39.97091397643089, 41.42300985753536, 40.67860700190067, 40.40451630949974, 38.729083612561226, 39.9881536513567, 36.94038659334183, 39.854267835617065, 37.896989062428474, 40.47837674617767, 39.5643699914217, 40.933257937431335, 41.72089107334614, 47.00544610619545, 51.754096895456314, 53.73353607952595, 44.38980706036091, 50.01130901277065, 51.488369554281235, 48.55915613472462, 46.12917512655258, 43.35455261170864, 42.976545095443726, 40.35692386329174, 39.29147243499756, 39.11546967923641, 41.06293357908726, 40.14833025634289, 40.08002512156963, 38.5970064997673, 40.40757894515991, 39.83331955969334, 39.87877272069454, 39.917036667466164, 39.72753323614597, 40.44261686503887, 39.2665571719408, 41.53041869401932, 40.32187834382057, 38.995247930288315, 41.48372299969196, 41.68086402118206, 40.280616357922554, 41.52772843837738, 39.699072763323784, 40.308522060513496, 40.139271542429924, 38.30353304743767, 39.91437301039696, 38.50406728684902, 40.54582692682743, 38.4798663854599, 39.857372269034386, 38.15244175493717, 40.167382434010506, 38.95405054092407, 40.146570950746536, 42.82289654016495, 40.203396901488304, 40.732400715351105, 39.956706538796425, 40.749894976615906, 40.92763803899288, 41.29658304154873, 40.68041950464249, 41.78119383752346, 41.88240900635719, 45.09037546813488, 44.65561039745808, 45.53023986518383, 42.63433925807476, 44.718713611364365, 48.05496118962765, 56.770599111914635, 58.12288574874401, 63.81915628910065, 59.9358406662941, 72.28122621774673, 69.73847106099129, 44.56998199224472, 1.0584725090302527, 0.38970391207840294, 2.141235927119851, 0.3314848314039409, 0.18924085947219282, 5.702359713613987, 58.42756859958172, 65.68839758634567, 56.00073762238026, 60.16896955668926, 24.27092593163252, 17.439544200897217, 42.31830641627312, 45.75667351484299, 55.458681508898735, 12.965101897716522, 0.6720015406608582, 0.0475347442261409, 0.055725186175550334, 0.021780106580990832, 0.1025728983222507, 0.04596302016580012, 0.022609820262005087, 0.037669252706109546, 0.02202287236286793, 0.040144411686924286, 0.12281775183510035, 0.07625095371622592, 0.035280116062494926, 0.04172357948846184, 0.09866206950391643, 0.2018974459497258, 0.3059097990626469, 16.94909881800413, 71.7583666741848, 53.71833689510822, 53.531056344509125, 33.74275177717209, 28.557151034474373, 38.228027299046516, 53.15272964537144, 63.91607388854027, 66.13761708140373, 31.227142363786697, 0.42627784016076475, 0.28817214304581285, 9.446593299508095, 17.69276451319456, 0.11729734571417794, 26.52942594140768, 65.82129165530205, 60.59564106166363, 43.513935059309006, 40.63000001013279, 64.60286423563957, 58.50522503256798, 57.6289426535368, 53.13145838677883, 55.64606085419655, 57.06659942865372, 57.25558988749981, 54.70199391245842, 51.650879234075546, 49.71111752092838, 45.302350893616676, 48.047954365611076, 44.76898491382599, 45.51125608384609, 42.827095314860344, 43.447735011577606, 39.8404061794281, 39.25374045968056, 40.99841684103012, 39.89927262067795, 39.36040833592415, 39.12415221333504, 39.58119548857212, 39.31372784078121, 39.966464415192604, 40.9159080684185, 41.503291949629784, 39.73970778286457, 40.18687538802624, 41.18839144706726, 41.13579086959362, 40.772275775671005, 40.860590636730194, 39.591994509100914, 43.74288037419319, 41.54595226049423, 42.952697575092316, 41.231450736522675, 42.94203154742718, 42.289534360170364, 42.96086713671684, 43.58703553676605, 43.518958389759064, 42.56706386804581, 43.420292884111404, 40.87681196630001, 41.56919561326504, 42.432809472084045, 40.326039120554924, 40.61883240938187, 39.72178414463997, 40.816600397229195, 41.114519611001015, 44.460635259747505, 44.362570121884346, 48.0946234613657, 52.9952546954155, 55.689104944467545, 47.27779649198055, 52.01229304075241, 55.30857816338539, 50.746641755104065, 47.32229970395565, 44.83546234667301, 43.52132946252823, 41.65283292531967, 43.135589361190796, 42.93280944228172, 42.544869258999825, 41.57658241689205, 41.64904832839966, 40.81881947815418, 42.50309810042381, 42.168153673410416, 42.49405078589916, 43.27770933508873, 41.971643418073654, 42.31873579323292, 40.58895841240883, 42.84020461142063, 41.90895818173885, 42.39260382950306, 42.07353115081787, 43.171527832746506, 43.85651707649231, 42.68827736377716, 42.60152421891689, 42.231351882219315, 41.312314197421074, 42.185157760977745, 40.30320234596729, 40.961642414331436, 42.46908612549305, 41.02247714996338, 42.51719914376736, 41.43670812249184, 40.93289315700531, 40.68742632865906, 41.586104705929756, 44.253192991018295, 42.4712748080492, 42.57109925150871, 41.43717549741268, 42.86711096763611, 42.120929807424545, 45.1652542501688, 43.7740159034729, 45.63595399260521, 45.2658424526453, 46.63903556764126, 47.29816719889641, 47.323812022805214, 43.759553879499435, 47.21625879406929, 49.98283714056015, 58.047676384449005, 59.7271216660738, 65.79399392008781, 62.943303287029266, 70.51426023244858, 70.41029781103134, 46.395738422870636, 1.4651384437456727, 0.9918512776494026, 3.3942467160522938, 0.6807352532632649, 0.2404201202443801, 6.453577978536487, 63.15020218491554, 71.02061346173286, 61.133441403508186, 62.8388012945652, 38.903931230306625, 30.19566871225834, 51.41336917877197, 56.36768773198128, 65.95288619399071, 18.203153125941753, 0.9343667747452855, 0.06550201331265271, 0.11743536291760392, 0.08233753687818535, 0.03887321290676482, 0.08037815568968654, 0.06853007973404601, 0.09097199465031736, 0.14402996515855193, 0.14769939560210332, 0.3956831287359819, 0.1616433114395477, 0.1232111791614443, 0.08089156603091396, 0.16129503637785092, 0.27774202928412706, 0.33517081174068153, 23.9704779535532, 82.7053664624691, 61.09151065349579, 63.98314028978348, 40.485942140221596, 38.96968670189381, 47.72010415792465, 60.44917792081833, 69.91472840309143, 72.02559113502502, 35.21271049976349, 0.3116361511638388, 0.38817829394247383, 12.845099586993456, 27.859003096818924, 0.21326000889530405, 29.692499712109566, 66.28360524773598, 61.757774502038956, 43.8060861825943, 40.469150841236115, 65.60461208224297, 60.88812656700611, 57.61046424508095, 53.37906830012798, 56.233870312571526, 59.35963958501816, 60.4319154471159, 56.991333067417145, 54.84211139380932, 52.10022412240505, 46.49419493973255, 51.23214170336723, 47.13096097111702, 47.94114589691162, 45.413004755973816, 46.4346407353878, 42.64177925884724, 42.88427084684372, 42.85777106881142, 43.64476203918457, 42.211079970002174, 41.92487932741642, 42.20705218613148, 42.690682634711266, 42.86247901618481, 43.24157327413559, 44.2543975263834, 43.08390453457832, 43.27349156141281, 44.09402333199978, 43.418913558125496, 43.710753098130226, 43.61687533557415, 42.0229634642601, 47.248686254024506, 42.674449905753136, 45.95942683517933, 43.8946708291769, 44.999792128801346, 45.244081020355225, 44.74085882306099, 45.80272704362869, 44.74962495267391, 44.5527309179306, 45.09311132133007, 41.89997926354408, 44.881994649767876, 44.83220212161541, 41.888671070337296, 44.02108244597912, 41.83115355670452, 42.882921919226646, 42.16620057821274, 45.37274591624737, 47.10986830294132, 51.58035881817341, 55.320935100317, 56.80830828845501, 50.310843139886856, 55.847609639167786, 56.69322766363621, 52.16247618198395, 49.08424615859985, 48.50278615951538, 48.73007856309414, 45.38446828722954, 45.03961019217968, 44.894815161824226, 46.45011730492115, 44.64961811900139, 42.69699789583683, 42.46489875018597, 45.660569071769714, 43.55607479810715, 44.00435574352741, 44.655188620090485, 44.353462010622025, 44.8304808139801, 42.38454446196556, 44.84884902834892, 44.178253412246704, 44.69781093299389, 45.89446932077408, 46.166420727968216, 44.47905667126179, 45.72027526795864, 43.54185216128826, 43.54135438799858, 43.007980808615685, 43.0032766610384, 42.955870404839516, 42.362570241093636, 46.11722096800804, 42.73371532559395, 43.66872355341911, 42.54752151668072, 45.127716064453125, 43.024540320038795, 43.20615157485008, 46.35121241211891, 43.21152828633785, 45.277507826685905, 44.08059865236282, 45.20270884037018, 45.11360742151737, 48.60033072531223, 45.813526064157486, 47.043626457452774, 46.82077221572399, 49.26849067211151, 49.882476925849915, 50.66056877374649, 47.79925391077995, 49.29543882608414, 52.006380558013916, 61.32921449840069, 61.66938744485378, 69.4627046585083, 67.17781886458397, 72.75947615504265, 70.67740067839622, 49.27704781293869, 1.9894738518632948, 2.46471565682441, 6.320977443829179, 1.2549603218212724, 0.3518119000364095, 7.922278493642807, 69.57223758101463, 74.65980738401413, 68.19270640611649, 69.46271225810051, 35.24705685675144, 31.19697578251362, 61.53647817671299, 64.48263868689537, 76.1329959332943, 25.054498985409737, 1.1152794607914984, 0.21763376716990024, 0.22306517494143918, 0.15045436652144417, 0.207416620105505, 0.1930734733468853, 0.1550183372455649, 0.13545830792281777], [0.03619795235863421, 0.07095447581377812, 0.056291986620635726, 0.07548994806711562, 0.016347561468137428, 0.04247789467626717, 0.04699546632764395, 0.20394065271830186, 0.022454627905972302, 16.33202712982893, 65.10275781154633, 43.138503804802895, 55.1178739964962, 26.199953220784664, 29.105037935078144, 33.62563066184521, 50.222467482089996, 59.20176185667515, 60.06219148635864, 24.971173256635666, 0.34774472296703607, 1.0139468545094132, 5.797062031924725, 14.706078227609396, 0.4096885537728667, 5.451621618121862, 59.00908939540386, 59.3693670630455, 46.03315807878971, 59.60342690348625, 62.974302023649216, 60.22764980792999, 59.52557288110256, 54.690963104367256, 54.400666281580925, 58.10439974069595, 55.42325600981712, 54.438200667500496, 48.28228019177914, 45.61035856604576, 43.943122029304504, 42.77292922139168, 41.84250734746456, 40.81050552427769, 40.12806594371796, 38.11251349747181, 35.72748027741909, 37.15808071196079, 34.941146671772, 37.80608654022217, 36.59432776272297, 36.909950226545334, 37.83214934170246, 36.59333221614361, 36.697055250406265, 38.10259222984314, 37.07340605556965, 40.121427699923515, 39.2141617834568, 40.10868318378925, 37.98677824437618, 39.04661737382412, 38.094776049256325, 39.671486243605614, 39.52077493071556, 39.26147684454918, 39.847751185297966, 41.51521570980549, 40.26515118777752, 41.547266989946365, 40.013749077916145, 41.26952089369297, 39.18305665254593, 39.289523139595985, 38.761917650699615, 43.24061952531338, 40.238856598734856, 40.836108550429344, 38.22111926972866, 39.35377009212971, 38.0325847864151, 40.276440382003784, 39.19536419212818, 41.45852655172348, 42.036156356334686, 50.06836675107479, 47.91577085852623, 53.405446484684944, 42.990205362439156, 47.66916789114475, 52.46708303689957, 47.12916746735573, 50.80684192478657, 46.90453112125397, 41.03360675275326, 39.42752033472061, 40.077882036566734, 40.12791395187378, 38.98731015622616, 39.21617567539215, 38.55041719973087, 41.0438472032547, 39.20851528644562, 39.47374865412712, 39.86214481294155, 38.53495962917805, 41.110172644257545, 41.485045328736305, 41.89226947724819, 41.41242362558842, 40.58096744120121, 40.703803449869156, 39.45312336087227, 41.620876640081406, 38.82029011845589, 40.34495450556278, 39.33649241924286, 38.37904639542103, 39.31421801447868, 40.52053928375244, 40.40622241795063, 40.85859194397926, 39.24338981509209, 39.88796062767506, 40.30832067131996, 40.02814270555973, 39.20565403997898, 41.744617000222206, 39.853610470891, 41.09699875116348, 40.32268010079861, 40.25456115603447, 39.24973927438259, 41.87906138598919, 40.00627487897873, 40.73832839727402, 40.48301249742508, 44.83418181538582, 43.571387976408005, 44.76107753813267, 44.905940964818, 48.08994211256504, 50.22376701235771, 53.90556424856186, 56.08099691569805, 59.5849484950304, 56.75057798624039, 61.24237775802612, 65.55732741951942, 62.95692175626755, 72.13755592703819, 51.3270416110754, 2.6054280437529087, 0.35212392860557884, 1.2119577918201685, 0.3234388225246221, 0.1699744089273736, 3.776482455432415, 56.20391272008419, 62.49315284192562, 58.9813356846571, 67.13767021894455, 22.346331104636192, 14.484397172927856, 34.30427424609661, 44.79550749063492, 60.291797965765, 19.817331209778786, 0.5675032886210829, 0.03753343225980643, 0.08332250043167733, 0.027100257138954476, 0.030619148492405657, 0.023558040084026288, 0.0649852336209733, 0.04937271376547869, 0.05006652165320702, 0.05835147610923741, 0.05265080231765751, 0.06354458397254348, 0.023391810136672575, 0.07023294499958865, 0.06146815496322233, 0.20122850371990353, 0.05975208317977376, 22.859256081283092, 74.2694391310215, 50.01579277217388, 64.21096846461296, 30.943113304674625, 32.75908716022968, 39.4679007679224, 56.26014210283756, 65.99006339907646, 66.31079658865929, 26.915846206247807, 0.18478392128599808, 0.7213834533467889, 6.263756789267063, 12.883051950484514, 0.8090170822106302, 5.8398486860096455, 60.33963739871979, 57.51117557287216, 47.06899009644985, 59.90247085690498, 62.07899786531925, 62.63893201947212, 60.46979181468487, 57.157957926392555, 54.85336259007454, 59.06715787947178, 56.40735000371933, 54.75821949541569, 49.7883103787899, 47.28300601243973, 45.58811075985432, 45.46432100236416, 44.719006195664406, 43.467072173953056, 42.33129031956196, 40.22928111255169, 38.37643973529339, 38.98928225040436, 37.97111928462982, 41.425259336829185, 38.79128247499466, 39.901860281825066, 38.4975316375494, 39.15254428982735, 39.86369512975216, 39.07681815326214, 39.4015297293663, 41.77322946488857, 40.471928492188454, 41.425988897681236, 41.021667793393135, 39.4595830142498, 39.375170543789864, 42.201622277498245, 41.61022961139679, 40.520448088645935, 41.84119641780853, 41.38562746345997, 42.5337890535593, 43.668434768915176, 41.44562624394894, 42.35609918832779, 42.11082614958286, 42.20746636390686, 41.53198041021824, 44.40016150474548, 41.78958758711815, 42.34226033091545, 40.15609323978424, 41.475887820124626, 39.377024844288826, 41.20076358318329, 41.89446955919266, 43.021306693553925, 44.28037293255329, 53.35341967642307, 51.338775381445885, 57.46459387242794, 47.42286130785942, 50.561614483594894, 53.82932133972645, 49.86378572881222, 52.14283883571625, 50.104274824261665, 44.03039954602718, 41.503687128424644, 42.10721634328365, 43.49658519029617, 40.71048729121685, 42.600574269890785, 41.304528415203094, 43.79388123750687, 41.02370448410511, 42.2840778529644, 41.07886612415314, 40.617605075240135, 43.131318390369415, 42.666413336992264, 43.84685419499874, 42.77563467621803, 42.28447683155537, 42.25367188453674, 42.239456847310066, 41.99760742485523, 43.19905735552311, 40.7149862498045, 41.03066951036453, 41.85155466198921, 41.03967122733593, 43.195622339844704, 41.99247010052204, 42.36107312142849, 41.13458253443241, 40.71918502449989, 41.7192267626524, 41.538075283169746, 42.47442863881588, 43.42582158744335, 42.245346531271935, 42.77967765927315, 41.61708444356918, 44.10566210746765, 40.62199763953686, 42.77172468602657, 42.655325531959534, 43.241911455988884, 42.93972127139568, 47.13397040963173, 47.010355442762375, 46.73259034752846, 48.23290564119816, 51.14570394158363, 53.062826469540596, 56.85899376869202, 57.73669347167015, 62.225704193115234, 59.12371404469013, 62.34748765826225, 68.73140349984169, 66.9968269765377, 68.56521561741829, 55.90007722377777, 3.18585354834795, 1.1538041685707867, 5.38094493560493, 2.5373865198343992, 0.0592368657089537, 4.000624353066087, 62.63649635016918, 69.7913946211338, 63.49275000393391, 69.0343764424324, 29.936397224664688, 20.760085321962833, 40.593886747956276, 50.010788440704346, 70.4613670706749, 27.723316177725792, 0.6130658718757331, 0.05922994147113059, 0.07215857331175357, 0.03469715535175055, 0.024253360097645782, 0.03285218735982198, 0.06303251691861078, 0.012317166165303206, 0.10759431403130293, 0.09014137554913759, 0.12346142393653281, 0.16957219457253814, 0.08189794796635397, 0.11849598100525327, 0.16189098096219823, 0.4298558528535068, 0.1473076455295086, 33.97211126983166, 83.34551811218262, 57.079203352332115, 72.08090096712112, 38.03487986326218, 37.33469903469086, 46.91611669957638, 64.3385124206543, 69.02777999639511, 72.72510319948196, 29.646430984139442, 0.34178836445789784, 1.985676905605942, 12.055083028972149, 26.508061587810516, 1.2271243217401206, 7.58981010876596, 63.315413519740105, 60.1383052021265, 47.22489573061466, 59.446426928043365, 66.39421731233597, 63.02834652364254, 64.17788743972778, 57.5695176422596, 56.637906432151794, 60.390186086297035, 58.6398746073246, 57.51204952597618, 52.72708788514137, 51.307715848088264, 48.87298509478569, 46.97953909635544, 48.42457875609398, 46.22314028441906, 45.101391077041626, 43.05384814739227, 41.88761852681637, 41.67049057781696, 39.89188961684704, 44.522564336657524, 40.25948949158192, 42.047396153211594, 40.65038971602917, 42.4499237537384, 41.372898146510124, 41.99437379837036, 40.974633917212486, 45.343236699700356, 43.50726641714573, 44.18925382196903, 41.53539642691612, 41.612764075398445, 42.468120977282524, 44.41390536725521, 44.19858992099762, 42.2150469571352, 44.01578553020954, 44.23976831138134, 44.00846712291241, 45.87474837899208, 44.27545979619026, 44.73542511463165, 44.34121146798134, 41.92099213600159, 44.448578506708145, 47.99020126461983, 43.81591245532036, 47.04470939934254, 42.51084968447685, 43.81507270038128, 44.0958434343338, 44.47398394346237, 43.89156639575958, 43.604753986001015, 48.486701622605324, 56.27614684402943, 53.360008522868156, 58.18122401833534, 52.41821005940437, 52.78386443853378, 56.24806635081768, 53.466201424598694, 55.483524575829506, 51.049268916249275, 45.60726173222065, 44.4218735396862, 44.92496654391289, 45.59578254818916, 43.11576582491398, 44.337685257196426, 43.64994876086712, 46.065669134259224, 43.72547350823879, 43.837844878435135, 42.945956736803055, 42.763517126441, 44.50755514204502, 45.209985449910164, 45.614078566432, 44.455250948667526, 43.161674961447716, 43.80060687661171, 44.17977333068848, 44.934036657214165, 44.20331306755543, 43.1807841360569, 43.444930762052536, 42.11747959256172, 42.84215770661831, 45.54265379905701, 44.60877411067486, 45.17812795937061, 42.82185919582844, 44.47122909128666, 44.607132598757744, 43.63663047552109, 45.11333763599396, 46.21369779109955, 42.764600068330765, 46.04674614965916, 44.51172351837158, 45.56615173816681, 43.04105423390865, 44.79216367006302, 43.732343539595604, 45.30739322304726, 44.503930136561394, 49.98413287103176, 49.701918214559555, 49.33250203728676, 51.232126504182816, 53.1551007181406, 55.134737491607666, 59.467511996626854, 61.60497710108757, 64.03869330883026, 61.06414832174778, 65.00808209180832, 68.32341179251671, 68.09648796916008, 68.86973887681961, 56.72733083367348, 3.607592205516994, 1.8941762717440724, 7.51333873718977, 2.9125916864722967, 0.3826189547544345, 4.58172669634223, 67.87531703710556, 75.08121237158775, 72.00585499405861, 78.05511519312859, 29.100922755897045, 23.36277086287737, 49.60037626326084, 62.34774224460125, 79.57947179675102, 36.29459224641323, 0.8915275172330439, 0.10292396385921165, 0.12367042756523006, 0.11733689476386644, 0.11811286211013794, 0.14115325233433396, 0.2101343055255711, 0.13056773284915835], [0.06668058835202828, 0.031577029221807607, 0.07629851053934544, 0.011055168160964968, 0.10050635843072087, 0.03813868708675727, 0.08147065644152462, 0.007428174649248831, 0.14028919948032126, 28.391139842569828, 64.97241720557213, 45.49576811492443, 55.87999530136585, 23.050516918301582, 22.24426858127117, 36.27207085490227, 56.92091524600983, 58.908812776207924, 62.07388713955879, 22.292001619935036, 0.3958074830006808, 0.41402664443012327, 12.184145003557205, 20.276620164513588, 0.2782301843399182, 4.235601369291544, 58.150947242975235, 57.3211819678545, 65.03330513834953, 60.50911970436573, 56.22754745185375, 57.792539075016975, 56.043268740177155, 58.37283253669739, 57.54761181771755, 55.864210948348045, 55.50779767334461, 52.4792043864727, 45.949528366327286, 43.60846258699894, 43.850631192326546, 39.90844912827015, 39.904037564992905, 40.596261620521545, 37.8403265029192, 38.16757254302502, 36.81333661079407, 36.54695190489292, 38.327095583081245, 35.82379750907421, 36.14851288497448, 37.12338097393513, 36.49451471865177, 37.63903610408306, 38.99322263896465, 39.987800270318985, 36.935420259833336, 38.654812797904015, 40.513733848929405, 38.84567275643349, 40.45554377138615, 38.46830740571022, 40.42641453444958, 38.99860695004463, 38.40516619384289, 37.91508749127388, 40.276630371809006, 38.652711510658264, 40.537942349910736, 38.792274221777916, 41.04846775531769, 40.295332968235016, 41.03114068508148, 39.28114838898182, 41.4460252225399, 39.97157894074917, 39.60660472512245, 38.536604940891266, 38.36072377860546, 39.19651173055172, 38.286844342947006, 38.53332571685314, 39.6029569208622, 42.684097588062286, 49.56168293952942, 50.41927792131901, 58.40768426656723, 47.648800984025, 37.49685913324356, 49.906864017248154, 49.96338598430157, 54.08217877149582, 49.06557396054268, 50.40938325226307, 41.88393272459507, 39.55392435193062, 37.77191877365112, 38.52458618581295, 39.89098906517029, 40.6270931661129, 37.53578424453735, 40.53946986794472, 37.786240205168724, 38.738849088549614, 39.268453270196915, 38.847462460398674, 39.81079436838627, 41.604111939668655, 39.03524458408356, 41.59237056970596, 40.74013330042362, 42.31990993022919, 39.851634576916695, 40.822801664471626, 39.861042872071266, 39.87406097352505, 38.58703963458538, 40.34901648759842, 39.14646841585636, 39.53232631087303, 38.64182509481907, 40.36090224981308, 38.24838660657406, 39.37167473137379, 38.25369492173195, 37.886562421917915, 37.28395655751228, 40.82272186875343, 39.567409828305244, 40.688376277685165, 40.35841338336468, 41.64855435490608, 41.50156304240227, 43.64408567547798, 43.3210764080286, 41.2648319453001, 45.286262556910515, 48.33888575434685, 46.18832655251026, 47.01019965112209, 50.20656153559685, 57.617759853601456, 58.44023711979389, 55.51259681582451, 55.59632532298565, 61.43579117953777, 63.93114387989044, 83.25705125927925, 64.44438233971596, 51.208191588521004, 52.47980855405331, 52.585720270872116, 6.148478100076318, 0.4907438746886328, 2.5837445072829723, 0.16313064959831536, 0.013181180984247476, 1.9810250052250922, 51.08314789831638, 66.82196035981178, 60.97974345088005, 55.7403451949358, 41.016332879662514, 21.06755342334509, 30.682128109037876, 46.63429342210293, 59.22149419784546, 28.54762304574251, 1.5523489890620112, 0.08971421018941328, 0.09972582687623799, 0.01620596340217162, 0.013399963336269138, 0.02826820647896966, 0.06015818267769646, 0.021194743167143315, 0.04732674620754551, 0.03160649248457048, 0.041826225933618844, 0.016882939380593598, 0.07022814330412075, 0.03072211220569443, 0.03774160097236745, 0.0478206454863539, 0.1404535406618379, 34.70245108008385, 73.0889792740345, 53.6369376629591, 63.13949055969715, 27.021550834178925, 25.818333998322487, 46.7474627494812, 60.57904735207558, 63.245611265301704, 67.96637535095215, 23.746111392974854, 0.4060939169721678, 0.9475885215215385, 12.709665354341269, 21.34383089840412, 1.345965676009655, 4.9813018552958965, 58.198566287755966, 57.84345634281635, 67.62494087219238, 63.4485849738121, 57.64142878353596, 59.938093945384026, 57.89472699165344, 59.39030773937702, 59.57767188549042, 58.03402751684189, 57.79743701219559, 54.040620401501656, 47.20439963042736, 44.69621881842613, 45.02500757575035, 42.55439534783363, 41.891672909259796, 42.60274775326252, 39.45593520998955, 40.7135309278965, 40.00327304005623, 38.78605775535107, 40.942647233605385, 37.761492133140564, 38.72701272368431, 39.454605281353, 39.056869223713875, 39.20979581773281, 40.13240151107311, 41.592089384794235, 40.41025400161743, 40.61715669929981, 40.95428600907326, 41.786247566342354, 41.5522713214159, 40.83545118570328, 39.72572833299637, 41.41135588288307, 42.6750198751688, 38.46402883529663, 40.99857643246651, 40.602968260645866, 40.73767863214016, 40.85468955338001, 42.28297971189022, 42.090668231248856, 41.47864647209644, 41.40690632164478, 41.58857077360153, 43.33303816616535, 42.063191905617714, 42.128612995147705, 39.760583862662315, 40.76664827764034, 40.082358196377754, 42.45787292718887, 42.74671822786331, 45.362581461668015, 51.13287203013897, 52.16898523271084, 60.49770511686802, 48.68986152112484, 41.230884566903114, 51.93778283894062, 54.174760803580284, 55.430958196520805, 52.6007142663002, 52.10363633930683, 45.531649589538574, 41.47614620625973, 39.22354727983475, 42.12240792810917, 41.90378665924072, 43.151734694838524, 39.114219546318054, 43.56373518705368, 40.071699768304825, 41.844414845108986, 40.6782004237175, 42.43339844048023, 42.88044065237045, 43.18951986730099, 43.67999754846096, 43.35420683026314, 40.853439420461655, 43.8617379963398, 42.051769718527794, 42.218155190348625, 43.49034212529659, 42.09992453455925, 41.60133048892021, 42.361935675144196, 40.653079971671104, 41.66073650121689, 41.02365888655186, 41.40615776181221, 40.42167618870735, 42.1073417365551, 40.73032982647419, 40.67721247673035, 40.15694819390774, 42.479638159275055, 41.707253605127335, 42.926045805215836, 43.88075217604637, 43.60169515013695, 45.13020113110542, 44.515318125486374, 45.51736615598202, 45.07344737648964, 46.2490738928318, 48.90834979712963, 48.749104142189026, 50.69971427321434, 51.83064378798008, 61.034498512744904, 60.45700170099735, 57.54604630172253, 58.85107487440109, 63.98404464125633, 64.26363363862038, 75.76832190155983, 66.33563965559006, 58.699793592095375, 49.0533272176981, 55.982821583747864, 6.213501635938883, 0.4565552092390135, 8.450732287019491, 4.129061261191964, 0.04137329320656136, 2.2660065069794655, 54.46841284632683, 74.76622447371483, 65.44768050312996, 60.035315528512, 37.57693983614445, 22.31750015169382, 39.388720616698265, 52.70150005817413, 67.86287650465965, 37.00183689594269, 1.651240938808769, 0.07345950623857789, 0.04183069737337064, 0.03372664512426127, 0.022085845448600594, 0.021017050748923793, 0.10834461048943922, 0.04989281085727271, 0.1526530977571383, 0.18916786182671785, 0.15678482683142647, 0.08740603443584405, 0.29053748643491417, 0.18799256708007306, 0.2686305932002142, 0.12344985385425389, 0.47275602584704757, 44.915968626737595, 81.17634370923042, 62.965064719319344, 70.10974913835526, 33.132246136665344, 28.734820000827312, 52.39767216145992, 69.33820813894272, 67.6613961160183, 74.94423732161522, 26.672566160559654, 0.5632620630785823, 1.279151604976505, 24.69398383051157, 38.22193622589111, 2.675914973951876, 6.167910732328892, 66.52128249406815, 59.30005118250847, 69.51117485761642, 65.65433621406555, 61.522916704416275, 61.89532332122326, 63.065440133214, 63.24589625000954, 61.41809552907944, 57.67522417008877, 59.92890603840351, 56.796753108501434, 50.06775118410587, 47.56598822772503, 48.45140151679516, 44.129821211099625, 45.20588926970959, 46.46833352744579, 43.56869392096996, 43.57511177659035, 42.67374314367771, 41.44115388393402, 44.190773740410805, 40.18830791115761, 40.58775767683983, 41.6585174202919, 41.8177592754364, 40.928755179047585, 44.330119863152504, 43.70623514056206, 42.925240248441696, 42.7393314242363, 44.43364530801773, 43.69470655918121, 45.176972821354866, 43.65429572761059, 44.73668284714222, 43.275870233774185, 43.663400039076805, 42.62741602957249, 45.44980198144913, 42.41568759083748, 43.179553002119064, 41.67302884161472, 46.00730046629906, 43.91209289431572, 44.27089624106884, 43.12027998268604, 45.09105183184147, 45.00013031065464, 42.12289050221443, 41.31582900881767, 43.78844752907753, 44.593137949705124, 42.63951078057289, 43.86307552456856, 44.62113104760647, 47.20834381878376, 53.73670130968094, 54.966018944978714, 63.88193652033806, 49.9726764857769, 42.16251477599144, 56.8733000010252, 56.88818000257015, 57.64494739472866, 53.22620250284672, 56.372445076704025, 47.091948464512825, 44.27955597639084, 40.964325070381165, 43.21350038051605, 43.765994533896446, 46.24539189040661, 43.2113952934742, 45.6889383494854, 41.32298782467842, 44.42184694111347, 44.09995101392269, 43.2617311924696, 45.11463716626167, 47.783511355519295, 43.94935369491577, 45.35890705883503, 44.979117438197136, 45.69004788994789, 44.96368266642094, 43.91251467168331, 46.65580406785011, 45.17201408743858, 42.39419214427471, 44.18076887726784, 42.3115161806345, 43.103123903274536, 43.74778211116791, 43.51439483463764, 41.806948855519295, 43.578326404094696, 43.18535529077053, 42.28405125439167, 41.8603739887476, 45.52328243851662, 43.999229818582535, 44.878384843468666, 45.31576797366142, 46.25334866344929, 46.15061357617378, 46.833699122071266, 48.4052149951458, 46.96318857371807, 49.66444082558155, 52.41344131529331, 50.63860975205898, 53.63199032843113, 55.653295665979385, 63.288822546601295, 63.09063658118248, 60.69750599563122, 61.486678048968315, 65.36913871765137, 64.84743431210518, 77.76687785983086, 67.40341275930405, 60.484402030706406, 50.88342301547527, 58.499502539634705, 8.000395651906729, 1.817311740014702, 7.807185044512153, 3.203519037924707, 0.3758578113047406, 2.8073777072131634, 62.46232129633427, 81.33262172341347, 73.21313381195068, 68.0141007900238, 51.285703629255295, 31.635823734104633, 48.37353989481926, 62.63775788247585, 77.37402454018593, 49.322071596980095, 2.5981837324798107, 0.3298189473571256, 0.10230103478534147, 0.14954738784581423, 0.12313499770243652, 0.14973912911955267, 0.32413335400633514, 0.22336332534905523], [0.07465861650416628, 0.026580013472994324, 0.023407074259012006, 0.058008859923575073, 0.07454814040102065, 0.03387234355614055, 0.03431134988204576, 0.07860226309276186, 0.5312497902195901, 35.302944257855415, 62.14151971042156, 51.054474636912346, 44.71045285463333, 29.557800740003586, 38.39682184159756, 31.68234083801508, 57.91983604431152, 61.67134054005146, 61.78921781480312, 20.36404587328434, 0.6202452897559851, 0.48921184439677745, 4.803326530382037, 5.7027786411345005, 0.9435849613510072, 17.973594143986702, 75.807224214077, 61.47779792547226, 58.6800916492939, 55.211098194122314, 56.837802305817604, 53.891068026423454, 55.62418542802334, 55.369336903095245, 57.60968528687954, 56.571296006441116, 53.030976578593254, 50.795906111598015, 41.388051733374596, 40.93467906117439, 39.78628948330879, 38.82082588970661, 39.95346911251545, 38.540412336587906, 37.83002145588398, 36.1917507648468, 36.74306318163872, 37.15110428631306, 37.29842998087406, 37.6443026214838, 36.31033480167389, 37.216608971357346, 37.68141523003578, 37.655082643032074, 37.240061312913895, 39.089498072862625, 38.02913457155228, 38.170331194996834, 38.77188451588154, 38.22361573576927, 38.32200385630131, 37.6314403116703, 38.29888589680195, 39.68667022883892, 40.507122203707695, 39.07409369945526, 37.99891859292984, 39.64680656790733, 41.82501308619976, 40.5110701918602, 41.32113352417946, 40.80772787332535, 41.66812710464001, 37.22040496766567, 37.924879565835, 40.688661262393, 40.8265520632267, 40.4433274269104, 37.45374284684658, 38.14764641225338, 38.60099248588085, 38.28852765262127, 38.94656494259834, 45.98773151636124, 49.13717731833458, 52.39560127258301, 50.395677387714386, 58.47586400806904, 42.61124409735203, 45.79548843204975, 51.19647681713104, 50.95506817102432, 50.11293835937977, 46.76187537610531, 40.94041295349598, 39.6702741086483, 40.232339948415756, 38.07527169585228, 37.847956493496895, 38.99830296635628, 37.703431248664856, 40.57548053562641, 40.30639797449112, 39.244442358613014, 38.50086025893688, 39.5634276419878, 39.11529488861561, 41.013547629117966, 39.69580873847008, 40.926980674266815, 40.91838553547859, 42.53393344581127, 38.64011138677597, 40.36559499800205, 38.72599057853222, 39.37110096216202, 39.3737456202507, 40.743351727724075, 39.48632597923279, 40.27394771575928, 38.31511862576008, 38.729391396045685, 39.11250203847885, 40.26851400732994, 39.64260019361973, 39.27090033888817, 38.945622593164444, 40.54343685507774, 37.95063078403473, 39.72164735198021, 41.190074756741524, 43.42324152588844, 45.88688112795353, 47.409075647592545, 49.29791249334812, 49.17245462536812, 52.036778926849365, 51.79949685931206, 52.07574583590031, 53.4999930113554, 54.17041763663292, 55.67666061222553, 61.34249098598957, 60.47017939388752, 58.061393648386, 60.74912242591381, 57.851253524422646, 44.25744876265526, 48.21892999112606, 54.555534571409225, 35.50937958061695, 47.75314338505268, 7.561807511374354, 0.6957833957858384, 9.236940499395132, 2.009917823597789, 0.056507591652916744, 0.7855059031862766, 48.18828843533993, 65.0150129199028, 63.67870442569256, 52.92143225669861, 49.9003891646862, 15.710156299173832, 19.484750255942345, 38.40941436588764, 59.80167746543884, 27.812227606773376, 0.9614528494421393, 0.04615657599060796, 0.14251786895329133, 0.12036659391014837, 0.15693079243646935, 0.05680692207533866, 0.05095641237858217, 0.10805190002429299, 0.04675246491387952, 0.009206276063196128, 0.03786425571888685, 0.039763689928804524, 0.0459631129342597, 0.1063881310983561, 0.04300309774407651, 0.041708829303388484, 0.7265463669318706, 44.241975992918015, 71.68167918920517, 56.566724851727486, 52.78694227337837, 35.132238417863846, 31.975341215729713, 35.361890494823456, 62.83790074288845, 64.34352815151215, 69.3260107934475, 22.05634966492653, 0.49397833237890154, 0.3040877968305722, 9.848703872412443, 8.751753084361553, 1.2751909112557769, 20.43485127389431, 73.41325387358665, 61.44779093563557, 61.83539293706417, 56.96137547492981, 59.493924379348755, 56.46891809999943, 58.2591350376606, 57.69910968840122, 58.65816682577133, 56.53194911777973, 55.562328547239304, 51.93489879369736, 45.925620049238205, 43.015424609184265, 42.25673831999302, 40.50817854702473, 40.992150977253914, 40.12657642364502, 39.51448246836662, 39.242238476872444, 38.515911251306534, 39.034891203045845, 40.492690578103065, 39.26589220762253, 38.044774532318115, 39.00361888110638, 40.24731494486332, 40.9609280526638, 39.94474098086357, 40.343601778149605, 40.136288702487946, 41.1216214299202, 40.54388143122196, 39.386474937200546, 40.34178927540779, 40.85028178989887, 40.47227807343006, 41.73078194260597, 42.16767109930515, 40.10698467493057, 40.670471638441086, 40.69120332598686, 41.85432851314545, 42.03324571251869, 42.746798023581505, 40.87593041360378, 42.05815717577934, 39.897665306925774, 39.13099944591522, 43.36624078452587, 42.67085149884224, 43.27229082584381, 40.11012710630894, 40.3587781637907, 41.04790918529034, 39.374030604958534, 41.908847987651825, 47.87567920982838, 51.16486631333828, 54.72252041101456, 53.71855728328228, 59.87637385725975, 42.823838889598846, 48.09413708746433, 54.90122102200985, 52.0426420122385, 51.89485654234886, 47.98288285732269, 43.606152310967445, 41.84303551912308, 42.57495604455471, 42.47961916029453, 39.687206000089645, 42.538987174630165, 41.59851863980293, 39.79952037334442, 42.63970836997032, 40.83191737532616, 39.84882652759552, 42.037843465805054, 41.278974786400795, 42.08109274506569, 41.960677206516266, 42.61049173772335, 43.64234536886215, 44.194505140185356, 40.737709030508995, 41.974972039461136, 40.96594758331776, 41.18423826992512, 42.06960216164589, 41.66022352874279, 41.83047339320183, 41.17579132318497, 40.9869946539402, 42.38827586174011, 40.498983040452, 42.27795258164406, 41.32304482161999, 42.85513021051884, 41.643591821193695, 43.0261742323637, 39.03858840465546, 43.034290596842766, 43.75978946685791, 45.326240211725235, 48.271234184503555, 51.69858567416668, 50.229960680007935, 51.079572290182114, 54.22696240246296, 54.04616430401802, 54.46971237659454, 56.49104431271553, 56.11539267003536, 58.30010063946247, 61.83797299861908, 63.01687493920326, 60.21148167550564, 61.2533363699913, 56.8244194239378, 44.6585476398468, 48.024148643016815, 60.369142815470695, 35.9861171990633, 49.80497628450394, 8.880569972097874, 0.5547287897206843, 12.927141934633255, 7.114115059375763, 0.1916944293770939, 1.1259444197639823, 54.347355142235756, 71.58764943480492, 67.99726769328117, 58.73017676174641, 45.613140016794205, 17.304125167429447, 27.19046887010336, 48.220966681838036, 70.54202914237976, 35.09020887315273, 1.5268701687455177, 0.04564896924421191, 0.07440405242959969, 0.10289670477504842, 0.01607589645573171, 0.07756237318972126, 0.05693061953934375, 0.020528494933387265, 0.17949776665773243, 0.21104318409925327, 0.168545700435061, 0.1464037541882135, 0.2476243703858927, 0.14194245217368007, 0.23425705876434222, 0.18878911418141797, 1.1978428554721177, 53.95840421319008, 78.53940680623055, 64.93549078702927, 59.371582344174385, 41.736299246549606, 48.32487590610981, 43.087806925177574, 70.2746906876564, 68.68807822465897, 75.61947628855705, 23.504438661038876, 0.6265341304242611, 1.4809074788354337, 13.541533816605806, 14.917198698967695, 2.1956744184717536, 23.4605111181736, 72.39134430885315, 64.43497404456139, 63.92542138695717, 59.765191823244095, 62.6157570630312, 57.98974849283695, 60.1690873503685, 59.68765698373318, 62.59384743869305, 59.009169191122055, 57.81026132404804, 55.88096044957638, 46.617638915777206, 44.04375582933426, 45.115583315491676, 43.220860585570335, 44.508296102285385, 44.077110439538956, 42.700672298669815, 41.9372932612896, 40.46829208731651, 41.828995272517204, 41.271728575229645, 41.8871283531189, 41.13729178905487, 41.1675039678812, 41.55259810388088, 44.95950669050217, 41.43619894981384, 42.88488261401653, 42.98859424889088, 42.43089817464352, 42.93328821659088, 43.08306857943535, 43.248207718133926, 42.25258894264698, 39.74700719118118, 43.532113283872604, 46.30922846496105, 43.07904079556465, 42.749226093292236, 43.31663064658642, 44.83696326613426, 45.50286613404751, 46.650172770023346, 42.31539957225323, 46.654177755117416, 41.07261925935745, 41.49958334863186, 45.487195774912834, 44.99488279223442, 44.12130206823349, 41.656359136104584, 40.953168869018555, 43.978049755096436, 41.434606835246086, 42.85396747291088, 51.01394601166248, 52.84018501639366, 56.17268979549408, 57.20974534749985, 60.10590434074402, 44.76330041885376, 52.24130295217037, 54.58846740424633, 55.88642455637455, 53.58114905655384, 50.39495922625065, 46.424559876322746, 44.80817221105099, 44.80923995375633, 42.96541169285774, 41.91851086914539, 43.42795707285404, 43.18230025470257, 43.287258222699165, 43.54904517531395, 42.569507136940956, 42.44113102555275, 43.74465487897396, 43.49812030792236, 45.04236504435539, 43.544025644659996, 44.74104881286621, 45.12350969016552, 47.58492261171341, 44.03528608381748, 43.62303480505943, 43.46579544246197, 42.826494947075844, 43.1505985558033, 44.95312683284283, 44.1864799708128, 44.76742699742317, 42.307438999414444, 44.140779823064804, 43.08179944753647, 45.008847042918205, 42.937209606170654, 44.82736498117447, 44.167594984173775, 45.356440991163254, 42.685469314455986, 45.772784650325775, 46.327034309506416, 47.502117455005646, 49.820323660969734, 53.18257324397564, 54.651756808161736, 53.43017555773258, 57.75677539408207, 55.735428258776665, 57.816386595368385, 58.31273876130581, 58.512391448020935, 61.314402893185616, 65.18703728914261, 67.21804350614548, 62.2000365704298, 63.74073229730129, 57.38468796014786, 53.59084613621235, 52.08219788968563, 59.63040545582771, 40.08304215967655, 53.49878467619419, 12.231820095330477, 2.1077867969870567, 21.363555639982224, 9.46798425167799, 0.5495500238612294, 1.4718341594561934, 59.56511355936527, 78.79565745592117, 75.22517144680023, 67.1644739806652, 64.1512280702591, 25.22752460092306, 35.83961986005306, 55.99074795842171, 80.73438942432404, 46.94372981786728, 2.272943747229874, 0.13566539681050926, 0.2095325425034389, 0.24875669478205964, 0.1952652877662331, 0.1320988280349411, 0.12618748820386827, 0.1327855818090029], [0.026895207302004565, 0.04262430556991603, 0.06176891773066018, 0.010719029069150565, 0.13993783708428964, 0.01702040925010806, 0.03814060924923979, 0.047361638280563056, 0.8268225111532956, 35.69775067269802, 63.617064133286476, 50.45149639248848, 47.14358389377594, 20.203738175332546, 33.65048132836819, 34.90542858839035, 61.818537041544914, 59.340496212244034, 63.007265254855156, 17.904306761920452, 0.39687359298113734, 0.3657672449480742, 9.507086053490639, 9.719487056136131, 0.16958757187239826, 32.62458957731724, 29.877234399318695, 43.42713251709938, 62.40747503936291, 60.80207258462906, 55.549834817647934, 48.102207854390144, 49.86108027398586, 51.865077540278435, 52.68275186419487, 51.908330619335175, 47.054680064320564, 43.764493614435196, 40.039773881435394, 40.21991081535816, 38.537212908267975, 38.702963814139366, 38.29007416963577, 38.14544253051281, 35.716198682785034, 38.29057574272156, 37.00544290244579, 37.06482991576195, 36.63876637816429, 37.57950469851494, 38.042346462607384, 37.05998137593269, 35.079979822039604, 37.4469868093729, 37.2247139364481, 39.007768258452415, 35.66669873893261, 37.33379848301411, 39.13413047790527, 39.23249199986458, 37.04583093523979, 39.75483477115631, 38.02644431591034, 40.805068016052246, 39.02851514518261, 39.06108699738979, 39.547791481018066, 39.6702741086483, 39.71912428736687, 40.0287164747715, 38.18152539432049, 39.418640211224556, 39.496904611587524, 39.30795215070248, 37.791301533579826, 39.3133744597435, 37.591276466846466, 40.655188858509064, 37.75597482919693, 38.50766949355602, 36.07394948601723, 39.96187046170235, 39.67023231089115, 45.32813251018524, 48.56563098728657, 53.12248706817627, 49.769858568906784, 53.38738225400448, 45.62567174434662, 49.102735966444016, 51.99535354971886, 46.78599268198013, 49.30052675306797, 42.46393360197544, 38.97749148309231, 40.424233451485634, 39.82843682169914, 37.730896174907684, 38.62313389778137, 40.29339127242565, 37.7375990152359, 39.0382844209671, 37.26340726017952, 37.460487484931946, 37.75244861841202, 39.35035027563572, 40.01363508403301, 41.33661389350891, 42.311067804694176, 41.30572535097599, 42.21272528171539, 40.05755692720413, 41.35027416050434, 40.18807992339134, 39.859876334667206, 39.828592613339424, 39.987123906612396, 38.25814828276634, 41.07722081243992, 40.46347014605999, 39.618201702833176, 39.71033915877342, 37.262426912784576, 39.54311393201351, 38.790317326784134, 41.57064713537693, 38.137318566441536, 40.923541858792305, 38.2479952275753, 40.80071344971657, 41.904664412140846, 45.413441732525826, 47.73803919553757, 52.01608903706074, 52.393583580851555, 54.114127457141876, 54.55607794225216, 54.4926593452692, 57.30252876877785, 59.733832105994225, 53.78250405192375, 59.60622355341911, 60.03582090139389, 60.63128314912319, 52.12362326681614, 59.60031107068062, 49.48407210409641, 47.17152759432793, 64.5019568502903, 61.64677105844021, 39.152833074331284, 49.22341749072075, 8.619253244251013, 0.017916912511282135, 14.463750030845404, 7.575712390244007, 0.09934909787261859, 0.5845451366622001, 43.40841472148895, 67.24212661385536, 61.689720153808594, 51.78823046386242, 33.95387224853039, 20.20941697061062, 31.33808311074972, 37.345999628305435, 56.88286028802395, 36.34560450911522, 1.71601653797552, 0.16515200753929093, 0.04582014189509209, 0.013935140868852613, 0.014847867478238186, 0.062037333991611376, 0.04856631094298791, 0.015006740886747139, 0.016532590016140603, 0.022909516192157753, 0.01916731445817277, 0.035555786816985346, 0.09643128491006792, 0.021248623088467866, 0.11992909785476513, 0.07082161653670482, 0.8977323467843235, 46.86455346643925, 73.63801941275597, 57.450945004820824, 55.12125201523304, 28.955736346542835, 40.97245663404465, 36.45824946463108, 67.38119155168533, 62.65578031539917, 70.29258012771606, 18.22577141225338, 0.6713844300247729, 0.31140172155573964, 11.364346593618393, 3.168973666615784, 0.20321034971857443, 38.81500460207462, 29.045649021863937, 49.59066018462181, 65.02012744545937, 61.275454983115196, 56.05790555477142, 50.11755891144276, 50.251030549407005, 55.45810393989086, 54.448395520448685, 54.23581212759018, 49.1245011985302, 46.66787602007389, 43.11170384287834, 42.012643218040466, 40.80469183623791, 39.51020009815693, 39.33960825204849, 40.84133327007294, 38.56205217540264, 40.398379638791084, 39.57090184092522, 38.68402183055878, 38.900150433182716, 41.106338649988174, 40.529966577887535, 38.61508592963219, 37.951424941420555, 39.79200817644596, 39.373928010463715, 41.99182793498039, 38.45545269548893, 39.767427295446396, 41.885369047522545, 41.08572095632553, 39.724747985601425, 40.58806166052818, 40.502209067344666, 42.395841255784035, 40.366807132959366, 40.881215929985046, 40.752836018800735, 40.51668629050255, 42.097348272800446, 42.385756596922874, 41.14489518105984, 41.714036241173744, 41.66355215013027, 40.59925585985184, 39.16161060333252, 40.73063760995865, 39.52124610543251, 41.498515605926514, 41.179648116230965, 41.43022947013378, 40.64735367894173, 42.22941778600216, 39.921505227684975, 46.431049928069115, 51.71915777027607, 55.656578689813614, 52.37906835973263, 56.16355888545513, 49.768684431910515, 50.68551443517208, 54.063540771603584, 50.4598293453455, 51.86233028769493, 43.48263993859291, 40.878882855176926, 43.370557352900505, 41.548809707164764, 39.816364869475365, 41.42599269747734, 42.29850187897682, 41.04126714169979, 41.79581545293331, 40.289800465106964, 39.7909252345562, 38.953864350914955, 40.33991597592831, 41.48687683045864, 43.350414633750916, 43.732731118798256, 43.53690102696419, 43.35209034383297, 42.30775438249111, 43.627906143665314, 43.00807200372219, 41.3882265239954, 40.624577701091766, 41.78140662610531, 40.537581369280815, 42.24620148539543, 41.6466848552227, 40.04479341208935, 42.56065361201763, 39.68307562172413, 41.464602425694466, 41.93075381219387, 43.058480098843575, 40.206725522875786, 42.92628899216652, 41.285594031214714, 42.5245251506567, 43.090835362672806, 49.255597963929176, 49.97787080705166, 53.767251670360565, 54.99154217541218, 54.89334784448147, 56.8229641020298, 57.07964412868023, 59.54794608056545, 60.56029535830021, 56.444758996367455, 62.08651766180992, 62.12377846240997, 62.19913601875305, 52.399226278066635, 62.29749754071236, 52.31351047754288, 49.70571041107178, 63.15040357410908, 64.8880997300148, 43.34567628800869, 50.64084403216839, 9.92538945749402, 0.2665121771860868, 8.779596090316772, 11.077385041862726, 0.09838930796831846, 0.41401135618798435, 47.00198449194431, 71.97460547089577, 67.86106020212173, 56.79352708160877, 36.95196837186813, 23.209625780582428, 38.15050005912781, 45.78609153628349, 64.15399432182312, 44.32084456086159, 2.578715239651501, 0.11564120606635697, 0.04117153293918818, 0.06765158468624577, 0.046860376896802336, 0.015772669758007396, 0.020410376564541366, 0.004897245125903282, 0.1400115026626736, 0.1351359486579895, 0.11100011135567911, 0.10151652531931177, 0.20963518152711913, 0.06929194627446122, 0.301117246854119, 0.2378100759233348, 1.2997259572148323, 56.773608550429344, 83.8874526321888, 63.19695487618446, 61.459083929657936, 28.553166948258877, 43.219652250409126, 47.15181045234203, 75.3418555855751, 66.61927923560143, 76.2871004641056, 20.53029455244541, 0.5259914067573845, 1.9060203549452126, 14.560122359544039, 18.595852553844452, 0.2039041687385179, 43.19917134940624, 29.142032749950886, 53.031979724764824, 66.96982562541962, 66.09639689326286, 59.52212266623974, 52.263193577528, 52.25799925625324, 57.355684116482735, 58.82858768105507, 56.97289265692234, 50.63698723912239, 48.695466220378876, 44.385011717677116, 44.78756591677666, 41.95648603141308, 41.86838015913963, 42.45629221200943, 43.92266392707825, 41.13197207450867, 43.64190459251404, 41.28448449075222, 41.6976173222065, 41.23653866350651, 44.23637129366398, 42.59708605706692, 42.01744236052036, 38.71286228299141, 41.69871166348457, 40.54504416882992, 43.259664103388786, 39.76575918495655, 42.54144944250584, 43.18333379924297, 42.98884503543377, 41.14854298532009, 43.31527791917324, 42.3716289550066, 45.84821820259094, 42.472547739744186, 42.89489887654781, 43.61248657107353, 43.07625934481621, 43.990680277347565, 43.66575971245766, 42.973862439394, 44.27730269730091, 43.91113914549351, 41.74614831805229, 39.855913147330284, 42.81819999217987, 39.882618114352226, 43.98143917322159, 42.311504781246185, 44.485417529940605, 42.37336166203022, 45.426577627658844, 42.708758264780045, 50.210745111107826, 53.298695012927055, 56.99324816465378, 55.162126421928406, 58.54466311633587, 53.24428953230381, 53.089854419231415, 55.29133468866348, 52.15303748846054, 53.91419738531113, 45.744229182600975, 43.20427447557449, 46.53106056153774, 44.435286819934845, 41.924841329455376, 43.35187375545502, 45.522302091121674, 42.3307241499424, 44.35478433966637, 41.93033963441849, 42.28505440056324, 41.79173827171326, 42.480580508708954, 45.391060933470726, 46.493127197027206, 46.42222300171852, 45.76966501772404, 46.917100846767426, 42.515044659376144, 45.767434537410736, 46.229174360632896, 46.19480140507221, 42.75705747306347, 45.23335039615631, 42.46610328555107, 45.16374193131924, 44.60573047399521, 43.111285865306854, 44.376477375626564, 41.991485953330994, 43.32353487610817, 43.93422670662403, 45.55240027606487, 42.55336940288544, 47.34181545674801, 43.2142299413681, 45.62827080488205, 46.446435302495956, 52.26581163704395, 53.07797245681286, 56.41825921833515, 56.62102773785591, 57.554132267832756, 60.979952439665794, 58.67181949317455, 62.633764296770096, 64.01173755526543, 57.829556688666344, 64.4642248749733, 65.73711097240448, 62.57590480148792, 53.96087408065796, 62.52754099667072, 56.74254521727562, 52.59467639029026, 65.2017804980278, 69.89108607172966, 45.7159548997879, 54.03108291327953, 12.780906781554222, 0.3635521122487262, 27.073104567825794, 16.80174272507429, 0.20687856303993613, 0.6433718581683934, 53.23153741657734, 77.7253232896328, 73.69049459695816, 64.84235018491745, 46.10012948513031, 31.37964718043804, 48.85427109897137, 57.330799251794815, 73.64489704370499, 56.288955956697464, 4.223527992144227, 0.2739757188828662, 0.1812949514715001, 0.16308003512676805, 0.20293251931434497, 0.1875373040093109, 0.1262446929467842, 0.18453586584655568], [0.09644931167713366, 0.023642362903046887, 0.11388566315872595, 0.047402077907463536, 0.11186392672243528, 0.09092918757232837, 0.026234963042952586, 0.009905151891871355, 1.0501738730818033, 43.27181205153465, 63.07984136044979, 46.460008174180984, 36.03595532476902, 16.093660220503807, 34.63837131857872, 34.749553352594376, 59.63234715163708, 56.018676459789276, 64.38512831926346, 15.083194691687822, 0.19613829092122614, 0.37910245126113296, 12.429084610193968, 1.106882505118847, 0.8374114742036909, 47.448984906077385, 29.176069423556328, 44.97065529227257, 59.69193555414677, 58.48923549056053, 53.72435577213764, 48.1191511452198, 42.57103845477104, 43.21933686733246, 41.524832993745804, 43.60937833786011, 39.43474754691124, 40.70721946656704, 38.78684051334858, 39.925920590758324, 37.21653677523136, 40.19129455089569, 36.5758341550827, 38.34030747413635, 36.35611854493618, 37.45428241789341, 37.22316361963749, 38.91907721757889, 37.562823593616486, 38.692879155278206, 38.44014331698418, 36.90547026693821, 38.52609470486641, 36.93991541862488, 37.92232230305672, 39.106030985713005, 38.30343425273895, 37.9255635291338, 38.22309136390686, 38.77058498561382, 37.26556174457073, 38.648759722709656, 39.52227585017681, 37.75735415518284, 39.41108621656895, 39.193627685308456, 39.457151144742966, 41.18317432701588, 40.04291631281376, 41.58595651388168, 37.507255375385284, 42.09479101002216, 40.61307571828365, 38.28723952174187, 37.516542077064514, 40.35375103354454, 37.05474905669689, 40.355685129761696, 39.168792217969894, 36.894454658031464, 38.992914855480194, 38.83678503334522, 39.787706807255745, 40.85125833749771, 44.82400596141815, 48.40825103223324, 50.00319644808769, 51.877966448664665, 49.555873051285744, 51.17151215672493, 51.09450548887253, 47.87488505244255, 43.90047311782837, 40.02350315451622, 41.02649353444576, 40.17967477440834, 39.349814504384995, 38.531509414315224, 40.407993122935295, 38.32829251885414, 38.69645856320858, 39.18425738811493, 36.9210684299469, 37.438885644078255, 37.236614897847176, 40.032417476177216, 38.362209498882294, 42.0758718252182, 38.81303250789642, 40.748223066329956, 42.01634801924229, 38.85622479021549, 40.607493817806244, 38.999560698866844, 40.413145646452904, 39.66580554842949, 39.0631502866745, 38.853766322135925, 38.32356557250023, 40.39890021085739, 38.7226277589798, 38.98966982960701, 39.68209907412529, 39.496372640132904, 37.93227396905422, 38.13352257013321, 38.849734738469124, 39.734600856900215, 39.23848807811737, 39.976670667529106, 44.215350821614265, 47.81007193028927, 51.962534710764885, 53.45648534595966, 51.92009478807449, 59.25475761294365, 51.941293850541115, 56.53395161032677, 55.688667967915535, 57.25554049015045, 55.9702442586422, 57.93884642422199, 52.03335151076317, 58.22850488126278, 57.896539494395256, 62.785794138908386, 61.65495961904526, 69.37040761113167, 60.1081196218729, 68.30774903297424, 50.32294549047947, 67.7539211511612, 12.917826734483242, 0.3068351681577042, 9.19179892167449, 9.652421604841948, 0.6541897589340806, 0.09109119098866358, 36.98376886546612, 63.806753754615784, 62.73832328617573, 57.14261814951897, 39.71804894506931, 19.386529326438904, 18.98370534181595, 39.158707559108734, 58.95925126969814, 39.44303870201111, 1.9831230863928795, 0.20043047232320532, 0.026494740704947617, 0.05666085999109782, 0.039193356860778295, 0.10666900430805981, 0.04984562510799151, 0.10110773553606123, 0.039775764671503566, 0.09922831333824433, 0.03654178937722463, 0.01741111474984791, 0.05734142796427477, 0.01403893578753923, 0.041610587504692376, 0.034386830011499114, 1.5108091430738568, 55.82747831940651, 69.93403896689415, 53.99579420685768, 40.75464092195034, 20.711550526320934, 33.20658154785633, 36.08574405312538, 68.73090952634811, 58.2241503149271, 71.20460718870163, 16.293932273983955, 0.1970446461928077, 0.10013995270128362, 12.575314063578844, 1.2772076530382037, 1.618383745662868, 52.39373557269573, 29.36505228281021, 48.986336812376976, 60.44682964682579, 61.471224278211594, 56.933519169688225, 49.135467410087585, 45.92382274568081, 46.06523595750332, 43.21354977786541, 44.653877690434456, 42.47219815850258, 41.99172914028168, 39.61655259132385, 41.26513972878456, 40.091344714164734, 42.02775500714779, 39.48359772562981, 39.09538395702839, 38.774350583553314, 39.66348007321358, 38.52107897400856, 39.527192786335945, 38.51497270166874, 41.75523743033409, 40.37366196513176, 40.746722146868706, 39.78111036121845, 39.08909149467945, 40.25173790752888, 40.41169412434101, 41.42735682427883, 41.03634260594845, 40.74701853096485, 41.02649733424187, 38.46388444304466, 39.233407750725746, 39.9990476667881, 39.79439824819565, 40.9439467638731, 40.70038363337517, 40.48226773738861, 42.491926699876785, 41.524149030447006, 42.84641347825527, 39.652905240654945, 43.569047302007675, 41.61758601665497, 41.504511684179306, 38.19355174899101, 41.22608922421932, 41.62879541516304, 42.42986083030701, 39.93330359458923, 40.43909065425396, 42.513672932982445, 41.96092039346695, 41.52458980679512, 43.464849293231964, 47.51775361597538, 51.181566417217255, 51.49620473384857, 54.02434207499027, 52.52005599439144, 54.35222268104553, 53.48502941429615, 50.65304137766361, 45.85866004228592, 41.473965123295784, 44.28301379084587, 43.16470339894295, 41.40785627067089, 40.171163231134415, 41.260640770196915, 40.60129255056381, 40.57244069874287, 40.03073036670685, 39.01377193629742, 40.36480464041233, 39.51980218291283, 42.646399810910225, 42.4165615439415, 43.27987141907215, 41.00187085568905, 43.3086396753788, 43.13894458115101, 40.9024453908205, 42.32719033956528, 40.735505148768425, 40.88882312178612, 40.82633167505264, 40.22143453359604, 39.799326583743095, 40.59661120176315, 42.4788174033165, 40.54361164569855, 42.24098056554794, 41.61759361624718, 40.56544907391071, 40.12974165380001, 40.69726400077343, 40.705775544047356, 41.66158385574818, 41.0062026232481, 43.645924776792526, 45.66229037940502, 49.09774303436279, 54.04410861432552, 54.71778206527233, 53.315569907426834, 60.39533481001854, 55.088379979133606, 59.321725219488144, 58.34494583308697, 60.79657807946205, 57.43989519774914, 59.94243711233139, 53.89707550406456, 58.769227266311646, 59.61079090833664, 64.73185211420059, 62.107074558734894, 70.31271144747734, 62.481776252388954, 69.42357435822487, 52.68453776836395, 69.03113901615143, 15.819218996912241, 0.4095046198926866, 3.6877626786008477, 9.147414453327656, 0.24952791980467737, 0.04915010656986851, 40.848362892866135, 70.05639240145683, 68.81772726774216, 62.84359663724899, 42.45747774839401, 25.36779597401619, 28.70049264281988, 48.28783169388771, 67.59372174739838, 50.93783989548683, 3.7095694709569216, 0.27852977451402694, 0.04494804787100293, 0.04624427187081892, 0.06514661363326013, 0.014518528314511059, 0.028713597130263224, 0.1387977201375179, 0.20326667872723192, 0.20011127460747957, 0.2392918776604347, 0.11583856539800763, 0.1731042386381887, 0.15438604226801544, 0.2291478618280962, 0.1144454577297438, 2.5331245735287666, 65.8457699418068, 77.62994840741158, 61.76394537091255, 50.14583319425583, 22.342609204351902, 42.75105379521847, 47.23112739622593, 73.71700957417488, 63.55005472898483, 76.11506089568138, 18.16348135471344, 0.29757438227534294, 0.6695016904268414, 30.74556190520525, 3.6168454214930534, 1.3467324036173522, 57.144597843289375, 30.923863537609577, 53.95663730800152, 62.12734267115593, 63.359969928860664, 58.07672582566738, 51.58621430397034, 47.619124576449394, 49.13534961640835, 45.87087258696556, 48.94812986254692, 43.48490461707115, 44.68790106475353, 42.141270115971565, 44.60971266031265, 41.759390607476234, 46.21230706572533, 40.40653020143509, 43.23473744094372, 40.48575975000858, 41.427736803889275, 41.375162824988365, 44.59360532462597, 42.50693969428539, 44.191605895757675, 42.5351569801569, 43.010218888521194, 42.45965123176575, 40.916432440280914, 41.21677212417126, 43.769980520009995, 43.44545893371105, 43.13132219016552, 42.180776596069336, 43.31175930798054, 40.270987674593925, 42.081457525491714, 43.37163269519806, 41.91333934664726, 43.743492141366005, 42.99721218645573, 41.857877522706985, 45.39358779788017, 42.31603793799877, 44.95600327849388, 42.21798039972782, 46.286627277731895, 43.020774722099304, 43.72759759426117, 40.761453956365585, 45.6157960742712, 41.470484510064125, 42.77316100895405, 43.43022175133228, 42.75788962841034, 43.94290164113045, 43.61967958509922, 43.76983232796192, 45.3490199893713, 49.774927496910095, 52.92507626116276, 55.17806276679039, 57.94124409556389, 55.77559970319271, 58.448402881622314, 56.4365666359663, 54.68213997781277, 48.280091509222984, 42.512840777635574, 44.94596801698208, 45.67106410861015, 45.44833146035671, 42.42781654000282, 44.503690749406815, 41.75091706216335, 43.9135368168354, 43.02426293492317, 42.142983824014664, 42.88157299160957, 43.5552616417408, 44.24089305102825, 44.37163643538952, 46.68331079185009, 42.5841249525547, 44.47244882583618, 46.98270432651043, 40.765261352062225, 45.167366936802864, 44.088730216026306, 43.63643668591976, 43.98047402501106, 42.4150226265192, 40.88866353034973, 41.648660749197006, 44.97619919478893, 41.238088980317116, 44.43176060914993, 46.19403764605522, 44.237389639019966, 42.12922856211662, 42.660557851195335, 43.25022540986538, 44.90038186311722, 43.32802623510361, 45.230386555194855, 48.25075328350067, 51.073374822735786, 55.10186925530434, 57.548060193657875, 57.07383044064045, 61.79724678397179, 58.59050005674362, 61.87390387058258, 60.899457558989525, 61.90114840865135, 60.81404574215412, 61.49945296347141, 54.62598659098148, 60.13894736766815, 61.56488925218582, 68.14932033419609, 65.48222064971924, 74.96749207377434, 66.95886701345444, 72.8998102247715, 57.75095410645008, 71.33993312716484, 18.373097106814384, 0.3828552248887718, 16.378897614777088, 18.587411306798458, 0.8691153698600829, 0.15121192118385807, 45.08362703025341, 75.33126935362816, 76.1009332537651, 73.30451890826225, 50.85819996893406, 27.155415751039982, 33.77161882817745, 59.4870163500309, 77.17475563287735, 63.85688066482544, 5.800687987357378, 0.4145085357595235, 0.24303907033754513, 0.19252167170634493, 0.16807443666039035, 0.2022482146276161, 0.15135842113522813, 0.25348650582600385], [0.07488252245821059, 0.10669673094525933, 0.06183354023960419, 0.041030027641681954, 0.014997735852375627, 0.05604789053904824, 0.05059575829363894, 0.029214389105618466, 1.222478833515197, 43.110514506697655, 60.40633521974087, 41.60096950829029, 36.02672182023525, 18.367910385131836, 64.77982074022293, 42.14822754263878, 59.82126921415329, 54.59617339074612, 65.58950409293175, 13.474579509347677, 0.2657516242470592, 0.20885885052848607, 12.053350321948528, 0.8965444355271757, 3.9173420844599605, 63.160081654787064, 46.855642944574356, 64.62992638349533, 57.75862209498882, 60.67608654499054, 50.37930406630039, 49.06932815909386, 42.50706508755684, 44.701116755604744, 40.37625342607498, 39.862961769104004, 40.55717311799526, 41.33572094142437, 38.47426548600197, 40.807279497385025, 37.737146839499474, 39.70871664583683, 38.29424634575844, 38.35983842611313, 38.21003906428814, 37.62075148522854, 36.98467701673508, 38.02836701273918, 36.01999618113041, 37.40886725485325, 36.46116390824318, 38.27812761068344, 35.87449438869953, 39.24937829375267, 35.71107655763626, 37.59053170681, 38.36303025484085, 36.882682889699936, 37.9815611243248, 37.61862739920616, 35.197974890470505, 38.35169546306133, 38.36449697613716, 39.039101377129555, 38.55316065251827, 37.64193154871464, 40.182490423321724, 39.403083845973015, 40.16587391495705, 40.486816093325615, 38.748804554343224, 40.29853239655495, 38.03033530712128, 39.04585361480713, 37.199304699897766, 37.544162794947624, 38.944041877985, 39.973779022693634, 36.787695586681366, 38.39483454823494, 39.1552459448576, 39.68672722578049, 40.07955014705658, 41.40296213328838, 41.13767936825752, 40.546267703175545, 46.79654471576214, 52.03246995806694, 50.38923293352127, 52.086385264992714, 51.09420530498028, 49.00113321840763, 43.53114053606987, 42.306831032037735, 40.645552575588226, 40.556154772639275, 38.33567172288895, 37.07184053957462, 38.7089104950428, 41.136018857359886, 38.82881686091423, 37.868957966566086, 35.342697724699974, 35.32657139003277, 37.706440687179565, 38.5636480897665, 39.16399307549, 41.40315592288971, 40.94836972653866, 41.25722475349903, 39.97468717396259, 40.2607586234808, 38.792110830545425, 38.230573162436485, 39.126637279987335, 40.44251047074795, 38.898862302303314, 38.74968610703945, 38.88896003365517, 37.984920144081116, 40.12997344136238, 38.04543949663639, 38.98604102432728, 38.38629640638828, 38.020790219306946, 39.377872198820114, 37.58201256394386, 36.923903077840805, 38.08458499610424, 39.7880943864584, 43.6247219145298, 50.761647149920464, 50.6696654856205, 55.000338703393936, 53.90473589301109, 51.020474061369896, 54.75726954638958, 58.06339234113693, 53.20941120386124, 54.287911131978035, 54.6970883756876, 54.69290480017662, 54.794138967990875, 61.023893281817436, 57.06349119544029, 61.36778622865677, 56.069920510053635, 58.78144361078739, 56.20904624462128, 65.80176070332527, 57.06982925534248, 75.50266295671463, 25.55924490094185, 0.40326980757527053, 1.7889425810426474, 12.353631108999252, 0.6645515060517937, 0.17091168207116425, 34.2374624311924, 64.43582519888878, 63.8200606405735, 53.078466430306435, 34.28033173084259, 24.340323507785797, 26.960896588861942, 42.53660090267658, 55.129026398062706, 41.60494789481163, 2.557259928435087, 0.18694824655540287, 0.04702945669123437, 0.01590050098457141, 0.005634397221001564, 0.07212056050775573, 0.1335383570403792, 0.08151960108079948, 0.02165559089917224, 0.08514822824508883, 0.04736181268526707, 0.02196944144088775, 0.05258265089651104, 0.03786822249821853, 0.12504805403295904, 0.07089822844136506, 1.6155825834721327, 51.63778133690357, 68.01707223057747, 48.6772195994854, 47.60125793516636, 23.96121595054865, 50.77825985848904, 38.49773682653904, 65.45236185193062, 59.89709034562111, 70.71358993649483, 14.7744470089674, 0.13644650724017993, 0.22445959621109068, 5.406870944425464, 0.8030568051617593, 4.7876946441829205, 63.383175283670425, 47.12453931570053, 65.85636377334595, 59.45257879793644, 63.52919764816761, 51.94375231862068, 50.75986884534359, 44.949764013290405, 45.336051285266876, 42.61126309633255, 42.44406446814537, 41.80211551487446, 41.368858963251114, 40.41360542178154, 43.36825467646122, 38.72066326439381, 42.9598031938076, 39.637702256441116, 39.73067946732044, 39.673956111073494, 40.09117752313614, 38.98740895092487, 40.90318635106087, 37.78220482170582, 39.819693490862846, 38.76982122659683, 40.30831307172775, 38.13490189611912, 41.15381710231304, 37.63626225292683, 39.874505549669266, 39.843822196125984, 38.021029606461525, 40.59537246823311, 40.35527855157852, 37.986770644783974, 40.99966697394848, 40.23994334042072, 40.75789734721184, 39.95161101222038, 41.438798010349274, 40.11856645345688, 40.59550926089287, 41.66139766573906, 43.20515602827072, 41.205125749111176, 40.989646911621094, 40.90234659612179, 40.8545945584774, 39.22411344945431, 38.06549862027168, 39.20920304954052, 40.48856019973755, 39.99936304986477, 40.818933472037315, 40.64300671219826, 41.165721863508224, 41.0896385461092, 43.85181672871113, 42.716270461678505, 44.09631460905075, 50.274175107479095, 55.68749763071537, 54.22097772359848, 54.5180419832468, 53.90025973320007, 50.30985899269581, 45.19616559147835, 44.377807304263115, 42.95006811618805, 41.808913350105286, 41.68642692267895, 39.40237708389759, 41.19337297976017, 43.368980437517166, 40.090060383081436, 39.50033962726593, 39.055292308330536, 39.78901393711567, 38.80702123045921, 40.74643336236477, 41.10681362450123, 41.87548577785492, 42.081715911626816, 43.41375723481178, 43.10256153345108, 42.75107279419899, 39.87739719450474, 40.94828613102436, 41.867525205016136, 41.72530643641949, 40.45193016529083, 39.91178534924984, 41.31059668958187, 41.20237469673157, 42.38674834370613, 40.54480478167534, 41.681775972247124, 40.0106218457222, 40.999921560287476, 40.89667730033398, 39.80235502123833, 40.9115307033062, 40.3237896412611, 41.2634564191103, 45.14453776180744, 52.9047017544508, 53.57097700238228, 56.96529686450958, 54.455280750989914, 53.15289683640003, 56.35145880281925, 59.12776842713356, 55.761669650673866, 55.767764523625374, 53.810402154922485, 55.88908441364765, 55.80325461924076, 64.23022583127022, 59.16360430419445, 61.644684970378876, 59.79346610605717, 60.630686581134796, 59.477425664663315, 66.50454059243202, 59.62215229868889, 76.75906553864479, 29.278160445392132, 0.5022344877943397, 1.9597929320298135, 5.743974130600691, 0.08412216455326416, 0.09006375432363711, 37.189683616161346, 71.5231516957283, 67.78381794691086, 63.62464852631092, 37.35610708594322, 17.45644759386778, 29.190335758030415, 51.674331575632095, 62.5426109880209, 52.984011098742485, 4.113152464851737, 0.09766675299033523, 0.08541427334421314, 0.04732649016659707, 0.009518848255538614, 0.06734565657097846, 0.10108445436344482, 0.0770982117683161, 0.1724547555204481, 0.2764250140171498, 0.1741130548180081, 0.08593020698754117, 0.1778975923662074, 0.18743021209957078, 0.24066801241133362, 0.16047294455347583, 3.2323096180334687, 63.21693040430546, 73.59759718179703, 56.28438480198383, 51.52943395078182, 28.382468707859516, 74.16989967226982, 54.57445755600929, 70.9621573984623, 63.28699864447117, 75.24071261286736, 17.678481079638004, 0.6653121777344495, 0.33908380020875484, 27.037627771496773, 2.2655536187812686, 5.1765562780201435, 67.536800801754, 49.16977196931839, 67.86610633134842, 61.32900170981884, 66.83513805270195, 53.68073791265488, 51.72815188765526, 47.471228912472725, 48.533078134059906, 44.548676535487175, 43.37470293045044, 44.304224252700806, 43.601847141981125, 42.96845152974129, 45.775923281908035, 40.82909792661667, 46.12827077507973, 42.596793472766876, 42.74606466293335, 43.33420850336552, 42.10902124643326, 42.36076533794403, 42.13962100446224, 40.32534375786781, 41.95679381489754, 40.88562369346619, 44.1887104511261, 41.370884254574776, 44.560493901371956, 39.72675807774067, 42.947526052594185, 42.2898193448782, 40.46388432383537, 42.78802961111069, 43.07073064148426, 39.73130263388157, 43.56114372611046, 42.70766392350197, 43.299812749028206, 42.0630969107151, 42.581107914447784, 44.12376433610916, 42.78922654688358, 44.22615364193916, 44.53426770865917, 43.51304970681667, 44.98656123876572, 43.736888095736504, 42.354465276002884, 42.75087520480156, 41.15445926785469, 42.03663893043995, 43.31734120845795, 41.70221507549286, 42.43956930935383, 41.68308310210705, 43.876887783408165, 44.87898141145706, 46.178758665919304, 45.216350108385086, 45.58950148522854, 52.90698163211346, 56.579769551754, 55.146433264017105, 56.914953365921974, 56.35378047823906, 53.47394160926342, 48.5146377235651, 45.77944569289684, 45.51158666610718, 44.31550584733486, 45.428036749362946, 42.06243194639683, 43.97504411637783, 45.16389012336731, 43.92747446894646, 43.267655074596405, 40.646897703409195, 40.72936847805977, 41.612558886408806, 44.25361096858978, 43.935397043824196, 45.69507122039795, 45.21492898464203, 46.177044957876205, 43.694835752248764, 45.23474872112274, 42.97272250056267, 42.12575934827328, 43.72749499976635, 44.11246754229069, 42.05288305878639, 40.81878907978535, 43.847834542393684, 42.44234696030617, 44.50168825685978, 42.354784458875656, 44.00117911398411, 44.034396931529045, 41.74074500799179, 43.31302843987942, 42.07436330616474, 42.20745496451855, 42.39448472857475, 43.04070845246315, 47.66660302877426, 54.94227781891823, 56.39236740767956, 59.69045743346214, 57.51399502158165, 57.07444600760937, 57.95293226838112, 62.00753889977932, 55.394685342907906, 56.96757294237614, 57.51410901546478, 59.19290453195572, 57.35780440270901, 66.25905096530914, 60.989239141345024, 65.69701552391052, 63.14460128545761, 64.25587445497513, 60.14038369059563, 71.80385023355484, 63.78348380327225, 79.51261058449745, 31.247138790786266, 0.4353629151592031, 7.099588438868523, 22.465521208941936, 1.4059730060398579, 0.19179831520887092, 40.23267053067684, 77.22835555672646, 75.14397740364075, 69.47137579321861, 41.6880988329649, 34.99931775033474, 41.674780547618866, 61.51883952319622, 72.21124917268753, 66.11750096082687, 7.797164982184768, 0.30648911953903735, 0.1743293908657506, 0.17476963286753744, 0.14041138667380437, 0.1657463045557961, 0.3054798283847049, 0.1696032311883755], [0.05682375769538339, 0.0772745386348106, 0.040509281170670874, 0.03284535960119683, 0.08074698082054965, 0.025690081929496955, 0.14449732523644343, 0.04173205110419076, 1.5214817016385496, 48.37773106992245, 62.665997967123985, 48.34480583667755, 29.44367576390505, 25.092058070003986, 49.91385564208031, 41.48018538951874, 61.523646265268326, 52.898242101073265, 66.67987078428268, 15.075667295604944, 0.2485308444011025, 0.18703706678934395, 4.953026622533798, 0.5971057782880962, 7.50608017668128, 74.20679569244385, 52.60477624833584, 58.551441952586174, 53.67918759584427, 58.965657725930214, 50.02628020942211, 48.98739315569401, 42.23844230175018, 42.11870312690735, 40.03967508673668, 43.07670772075653, 40.233780071139336, 42.16289475560188, 37.73671746253967, 39.400135204195976, 38.84038344025612, 40.20796425640583, 37.24132664501667, 37.80665650963783, 38.20378080010414, 39.98384848237038, 36.3686578720808, 38.37240055203438, 37.37616240978241, 39.84853394329548, 38.24707567691803, 39.01548184454441, 36.3019410520792, 38.038497269153595, 36.36087968945503, 38.94244596362114, 37.4015374481678, 38.61761659383774, 37.144534438848495, 36.35145619511604, 36.00119858980179, 39.0254183113575, 37.268324196338654, 39.03547257184982, 38.821540251374245, 38.39441277086735, 39.08292442560196, 40.20113982260227, 40.2847695350647, 40.7267390191555, 40.12196347117424, 39.66230973601341, 39.773104190826416, 38.51764775812626, 37.6053661108017, 38.187259286642075, 38.67639183998108, 38.95437352359295, 39.2564383149147, 37.77407705783844, 38.90743464231491, 38.97280253469944, 37.78389573097229, 40.93361131846905, 40.40113069117069, 41.73244625329971, 48.18334870040417, 51.49350307881832, 54.406403973698616, 53.90008494257927, 52.48930424451828, 51.32165729999542, 44.398713782429695, 40.51013924181461, 41.27553217113018, 42.59737864136696, 39.5445616543293, 37.30794087052345, 38.57698917388916, 39.80590783059597, 36.71176806092262, 38.06498184800148, 37.09859870374203, 36.65375657379627, 38.165771439671516, 38.1096750497818, 39.2301931232214, 40.414243787527084, 39.45343874394894, 40.480478033423424, 40.82667365670204, 39.49921868741512, 37.31285020709038, 39.279807060956955, 39.149508252739906, 38.0069437623024, 38.085857927799225, 39.10779029130936, 40.313967168331146, 38.38115528225899, 39.18602429330349, 40.22290125489235, 37.960719242691994, 38.022230342030525, 37.457314655184746, 38.96257348358631, 37.33078524470329, 37.603280022740364, 38.73455531895161, 39.765060022473335, 40.51662169396877, 47.627392932772636, 53.094528168439865, 52.15150237083435, 49.721091985702515, 49.79374408721924, 49.818522557616234, 49.42883066833019, 50.96373550593853, 54.82641823589802, 55.5928523093462, 57.93920740485191, 59.042793586850166, 61.4202082157135, 55.68277448415756, 57.21139445900917, 54.7462273389101, 56.867756098508835, 53.357743844389915, 64.63356658816338, 57.80779905617237, 75.28670534491539, 36.123255640268326, 0.3910821693716571, 0.7810855528805405, 3.8767106272280216, 0.2811098954407498, 0.19464890443487093, 39.059905260801315, 62.694485038518906, 64.69111070036888, 56.36280119419098, 57.30104684829712, 70.01772567629814, 33.37956726551056, 30.822270289063454, 56.2351356446743, 48.25087867677212, 4.21585762873292, 0.16847580496687442, 0.010875280840991763, 0.0806336103414651, 0.07549142494099215, 0.0984757904370781, 0.06239181340788491, 0.04912484386295546, 0.15004982182290405, 0.028394239852786995, 0.02009398416703334, 0.04237331864715088, 0.04904988694761414, 0.052502498947433196, 0.1397979274042882, 0.055803341747378, 2.0074398815631866, 57.76054859161377, 67.7228844165802, 54.105216935276985, 34.78237219154835, 29.141295589506626, 49.157677218317986, 42.149861454963684, 64.8053477704525, 56.82856120169163, 71.37005031108856, 16.384124234318733, 0.244380472577177, 0.358749971492216, 3.6541568068787456, 0.9887889388483018, 7.114761024713516, 74.15288418531418, 52.79177561402321, 59.891668036580086, 54.31139387190342, 61.70532591640949, 50.410116612911224, 50.68466708064079, 42.883503288030624, 43.85892614722252, 42.04589143395424, 45.15264272689819, 43.266412541270256, 44.7578477114439, 38.92613343894482, 41.40017308294773, 40.53148649632931, 42.24890694022179, 38.816034346818924, 40.26311069726944, 39.243097230792046, 41.15072026848793, 37.36096702516079, 40.89463301002979, 39.23337735235691, 41.855115070939064, 40.707386657595634, 40.861525386571884, 39.095638543367386, 39.8321758210659, 38.57663579285145, 40.89524857699871, 40.02000734210014, 39.3566807359457, 38.02170217037201, 37.571019753813744, 38.54586884379387, 40.0931192189455, 39.03136499226093, 40.03985367715359, 40.61246395111084, 39.46255445480347, 39.990767911076546, 40.854761749506, 40.505381897091866, 42.584204748272896, 40.12091852724552, 41.91768251359463, 40.65169684588909, 40.11553801596165, 38.65217573940754, 40.79828158020973, 38.48366618156433, 42.01479770243168, 40.665368512272835, 38.14481936395168, 43.186970204114914, 42.63992875814438, 41.540518552064896, 44.320825561881065, 44.22400675714016, 43.64592097699642, 49.851846769452095, 53.76503258943558, 57.416895031929016, 54.829879850149155, 52.722030356526375, 52.366821616888046, 47.024323493242264, 42.730401903390884, 42.62250669300556, 44.37259778380394, 41.747900024056435, 39.35149021446705, 40.3378526866436, 42.06824943423271, 38.35028573870659, 38.92224624752998, 39.9385055154562, 38.51748436689377, 40.20041786134243, 41.63109049201012, 40.84975741803646, 43.13001126050949, 40.10461360216141, 41.801142767071724, 42.02242389321327, 40.67093141376972, 40.193578228354454, 41.70620486140251, 39.83531825244427, 39.346444085240364, 39.691913947463036, 41.533169746398926, 41.38078272342682, 40.98311886191368, 40.62800131738186, 41.21815524995327, 40.6019689142704, 39.60603475570679, 40.170794650912285, 39.95024688541889, 39.805733039975166, 40.62757954001427, 40.56781254708767, 42.49241307377815, 42.638013660907745, 49.95624616742134, 54.90185558795929, 55.80164350569248, 52.184211015701294, 53.03068779408932, 50.06539151072502, 51.822664216160774, 50.97607724368572, 55.24677447974682, 55.712352097034454, 61.49027265608311, 60.61149001121521, 61.82012915611267, 58.396524265408516, 60.67322909832001, 56.0594292730093, 58.24827902019024, 56.01432949304581, 66.29209399223328, 60.6844536960125, 76.38344809412956, 39.99713256955147, 0.2745222067460418, 2.0316569320857525, 5.08268041536212, 0.5034457321744412, 0.07968838137458079, 39.26015831530094, 67.58308991789818, 70.12536630034447, 61.715463772416115, 40.133210867643356, 59.56648528575897, 41.541297510266304, 39.49541129171848, 63.732904717326164, 60.56583546102047, 7.278284300118685, 0.17002195090753958, 0.06078369442548137, 0.032622492653899826, 0.09270640119211748, 0.06201173360750545, 0.047106209603953175, 0.08197458955692127, 0.312072059023194, 0.12718034820863977, 0.10778331678011455, 0.12209868495119736, 0.2130015633883886, 0.1332832660409622, 0.3211675537750125, 0.16297785623464733, 3.2315696077421308, 69.33275923132896, 74.68716591596603, 63.46013255417347, 41.906636506319046, 36.52025453746319, 60.468313694000244, 51.985352486371994, 72.81295448541641, 61.39576032757759, 79.25563797354698, 18.928450606763363, 0.3223058005096391, 0.2984210540307686, 14.476788081228733, 2.4012246262282133, 8.584331218153238, 76.57057285308838, 56.12564072012901, 63.34008939564228, 55.9567853808403, 65.5221489071846, 54.39587473869324, 53.10489781200886, 45.31830243766308, 47.54682965576649, 45.157267078757286, 49.390038549900055, 44.86894994974136, 47.20331288874149, 41.41135588288307, 43.959654942154884, 42.7677197009325, 45.6380020827055, 42.535187378525734, 43.062743470072746, 41.98719218373299, 45.528263971209526, 40.28046056628227, 42.176669016480446, 42.4233403801918, 44.45006422698498, 44.289663434028625, 43.37516650557518, 40.72735458612442, 42.67143286764622, 40.08086487650871, 43.39351952075958, 43.22021462023258, 42.84316465258598, 41.45633786916733, 39.375660717487335, 41.321388110518456, 44.21919621527195, 41.27192236483097, 43.16178895533085, 44.09713536500931, 41.61895774304867, 43.04150640964508, 43.13381865620613, 42.68897272646427, 43.683276772499084, 43.60121637582779, 42.389393001794815, 43.874991685152054, 41.3290560990572, 41.280217319726944, 43.48217636346817, 41.929959654808044, 44.96709868311882, 43.4844296425581, 40.206071957945824, 45.43662428855896, 45.419760793447495, 44.119592159986496, 46.872415244579315, 45.69092944264412, 45.67397855222225, 52.80684560537338, 55.44500604271889, 60.68721994757652, 57.584203854203224, 56.02878391742706, 55.905370339751244, 50.33478565514088, 44.80731725692749, 45.04878669977188, 47.94595643877983, 43.3197046816349, 41.588016003370285, 42.4332844465971, 44.617551639676094, 40.04112280905247, 42.257429882884026, 42.62995809316635, 40.321958139538765, 42.37678147852421, 43.88799078762531, 42.640996500849724, 45.793854519724846, 42.52183109521866, 43.277439549565315, 44.06739056110382, 42.58502930402756, 41.23066417872906, 45.587191209197044, 44.00994524359703, 40.65465688705444, 41.32375918328762, 45.1587375998497, 44.625630006194115, 42.91761785745621, 44.07719023525715, 43.837468698620796, 42.14994125068188, 41.89882792532444, 41.563644111156464, 43.021496683359146, 41.87472581863403, 42.79866524040699, 42.39312820136547, 44.12943363189697, 45.15548877418041, 51.57000057399273, 56.73885561525822, 58.8899239897728, 51.84012807905674, 53.949318900704384, 51.74415282905102, 51.63824111223221, 51.99646309018135, 56.62029817700386, 58.715057373046875, 64.1869005560875, 63.34057576954365, 67.24168583750725, 61.30447022616863, 63.37448514997959, 59.767163917422295, 60.08426830172539, 59.60128761827946, 68.25014412403107, 64.39636051654816, 79.24748361110687, 42.46996007859707, 0.35348369157873094, 5.620135925710201, 12.240081802010536, 0.8679453888908029, 0.19601723179221153, 45.28316952288151, 74.35684204101562, 75.04674062132835, 72.89719596505165, 69.00763347744942, 89.94079381227493, 47.60431297123432, 51.52876518666744, 71.05358049273491, 73.1035552918911, 12.104396782815456, 0.2664019534131512, 0.17873724340461195, 0.1222557901928667, 0.1302335289074108, 0.16769871697761118, 0.22258551005506888, 0.19927978719351813], [0.06019665932399221, 0.08635671183583327, 0.034733216307358816, 0.030931857982068323, 0.04168313244008459, 0.09171441692160442, 0.07894008871517144, 0.014015771503181895, 3.1916743610054255, 54.58147577941418, 59.675683826208115, 49.44468341767788, 38.29220585525036, 24.80444010347128, 35.67898727953434, 45.07128149271011, 58.49056541919708, 54.479196667671204, 65.57396292686462, 19.03513178229332, 0.21943715633824468, 0.19392863527173176, 1.2524199206382036, 0.3335681586759165, 15.511517208069563, 79.41758528351784, 58.09909522533417, 63.864905834198, 54.02351751923561, 54.66908007860184, 45.01251004636288, 47.25190468132496, 41.14990331232548, 42.391699478030205, 41.59510262310505, 42.37566813826561, 40.315741673111916, 43.1307902187109, 38.65575514733791, 40.71929521858692, 40.408053919672966, 39.793220311403275, 38.97548519074917, 40.71478106081486, 37.03540049493313, 38.881565630435944, 37.450155839324, 38.91765609383583, 36.61391571164131, 39.61087189614773, 36.558146104216576, 37.87746950984001, 36.038428992033005, 38.11211831867695, 36.973733603954315, 37.53303699195385, 37.178474217653275, 38.09916101396084, 37.950190007686615, 38.684861585497856, 37.07984670996666, 39.305558279156685, 36.71756274998188, 37.85196527838707, 37.63956047594547, 40.74224978685379, 38.345832377672195, 38.370109274983406, 39.25358846783638, 41.36268429458141, 40.65580062568188, 42.22307592630386, 38.01048517227173, 39.49004977941513, 36.556447595357895, 36.47159814834595, 37.599791809916496, 40.09015917778015, 36.73380687832832, 37.73215390741825, 38.97224776446819, 41.6890449821949, 40.39772987365723, 40.983799025416374, 40.44475995004177, 43.58022630214691, 47.290001437067986, 51.84041306376457, 50.09244225919247, 51.76378637552261, 52.669817358255386, 49.76983956992626, 44.27133321762085, 39.71338279545307, 40.712489783763885, 40.78481890261173, 39.9753787368536, 39.77344997227192, 39.714670926332474, 40.12841932475567, 37.24371671676636, 36.47985890507698, 36.483609303832054, 37.19453975558281, 38.345866575837135, 38.845216780900955, 37.45720826089382, 40.720609948039055, 40.96181720495224, 43.268187046051025, 41.81685112416744, 40.99842444062233, 39.057203605771065, 38.776881247758865, 39.11874130368233, 39.39521066844463, 38.52941192686558, 39.644792675971985, 36.18013858795166, 38.86350519955158, 39.60395246744156, 38.03400591015816, 37.05139763653278, 37.68505543470383, 37.27319173514843, 38.19433830678463, 39.06736806035042, 39.64045710861683, 40.722521245479584, 41.89220108091831, 38.126872926950455, 41.760127767920494, 49.603431299328804, 55.633365735411644, 56.086016446352005, 55.51796592772007, 54.90240655839443, 54.058832824230194, 56.02420516312122, 54.32290345430374, 56.601523384451866, 54.4931723177433, 54.31984841823578, 54.183637127280235, 49.431026950478554, 46.41917556524277, 46.098932549357414, 46.57280132174492, 51.463860869407654, 61.46171718835831, 61.84990055859089, 66.95556879043579, 48.39899852871895, 0.5209120293147862, 0.8423494279850274, 1.4057067828252912, 0.14372914301929995, 0.22163861867738888, 36.854374408721924, 66.75622388720512, 61.74303129315376, 66.34015381336212, 82.60752171278, 55.31096823513508, 20.056716464459896, 38.52137915790081, 51.01227790117264, 58.421238139271736, 6.132487133145332, 0.2349087831680663, 0.10844552030903287, 0.05142521593370475, 0.04900406675005797, 0.021285422481014393, 0.11733351057046093, 0.059605664864648134, 0.13081751007121056, 0.024881858989829198, 0.031896501532173716, 0.06296913008554839, 0.05390643455029931, 0.025458171912760008, 0.14842423639493063, 0.07925856654765084, 4.867653753608465, 63.65343578159809, 64.79269444942474, 54.885824248194695, 50.39613716304302, 27.528333440423012, 35.68190932273865, 49.261480048298836, 63.25727663934231, 59.70271177589893, 69.86335515975952, 20.67403133958578, 0.2233220322523266, 0.13840686064213514, 3.009846042841673, 0.5352718150243163, 15.093917716294527, 81.86700984835625, 58.56871582567692, 66.08483791351318, 56.646053194999695, 57.33499802649021, 47.053144946694374, 48.68009224534035, 43.04863482713699, 45.821885615587234, 44.44942586123943, 46.201424449682236, 43.05628381669521, 44.8826140165329, 41.19779594242573, 43.90566363930702, 41.106338649988174, 41.77521675825119, 41.320297569036484, 42.932064682245255, 40.10637670755386, 41.86973288655281, 37.75438271462917, 40.54323926568031, 38.49271349608898, 42.60031208395958, 38.3746462315321, 40.42335569858551, 37.8604806214571, 39.48332414031029, 40.448810532689095, 38.742151111364365, 38.56284253299236, 40.34401215612888, 39.26297776401043, 39.11941006779671, 38.538421243429184, 40.18187865614891, 39.4892518222332, 40.541020184755325, 39.11695919930935, 41.67236387729645, 40.978783294558525, 40.939269214868546, 40.00124394893646, 43.25130075216293, 39.84313443303108, 43.760085850954056, 39.598598554730415, 40.48005245625973, 38.312276378273964, 38.93605090677738, 37.91058473289013, 41.432874128222466, 39.41644012928009, 39.124741181731224, 42.28217035531998, 42.67815850675106, 42.310706824064255, 43.71411211788654, 42.97225512564182, 46.30267761647701, 50.99952578544617, 54.30790565907955, 52.50113680958748, 54.171812161803246, 54.007322788238525, 52.0858608931303, 46.66324406862259, 41.778351590037346, 42.41767108440399, 43.80784168839455, 40.95797561109066, 40.999089404940605, 41.4535716176033, 40.86689069867134, 39.97933052480221, 39.036118537187576, 39.26062189042568, 40.01555398106575, 39.648273289203644, 40.17308972775936, 38.771272748708725, 42.14965246617794, 41.97499483823776, 46.28748223185539, 42.331354916095734, 42.99642562866211, 42.52448335289955, 41.22613862156868, 40.66986367106438, 41.14148296415806, 39.94495376944542, 40.58221377432346, 39.01051551103592, 40.392771139740944, 40.193962007761, 40.33485844731331, 38.11597891151905, 39.3110603839159, 39.47246812283993, 39.75057899951935, 40.17324931919575, 42.18737304210663, 42.38110564649105, 44.03915047645569, 39.9292454123497, 43.002999275922775, 51.71212054789066, 57.17572197318077, 56.04517623782158, 58.22470888495445, 56.95144280791283, 57.413019239902496, 58.518763706088066, 58.129303604364395, 58.14917653799057, 57.7037188410759, 56.939830631017685, 55.721999779343605, 52.55658343434334, 49.445184990763664, 47.64360286295414, 50.003618225455284, 52.88967356085777, 65.27162075042725, 64.24672454595566, 70.77388510107994, 49.309346079826355, 0.30259195365943015, 1.9866069057025015, 4.13272331468761, 0.3048339521046728, 0.23619583051186055, 39.27841633558273, 71.6689270734787, 65.48942506313324, 71.76116332411766, 86.52879729866982, 70.1789890229702, 21.69739432632923, 45.58916710317135, 57.065835669636726, 67.43282318115234, 9.680719636380672, 0.4185067524667829, 0.09785805639694445, 0.09747901931405067, 0.03472269636404235, 0.09577694814652205, 0.11651825392618775, 0.004046921540066251, 0.27059496904257685, 0.17144570185337216, 0.1300080941291526, 0.09703925970825367, 0.20656988897826523, 0.25462994759436697, 0.4239800915820524, 0.14340749621624127, 5.703649269416928, 74.10143494606018, 72.9193639755249, 65.08411601185799, 52.786592692136765, 32.90108934044838, 47.775098606944084, 58.626913502812386, 67.61117041110992, 65.16924664378166, 78.02204176783562, 24.823412485420704, 0.3437769936863333, 0.6757961120456457, 8.602427747100592, 1.0961787169799209, 17.788889855146408, 83.04060727357864, 59.78435039520264, 69.22522500157356, 59.889376759529114, 59.55151788890362, 49.74135249853134, 51.233464032411575, 45.31622774899006, 48.05726006627083, 46.74541085958481, 49.193349704146385, 44.38979186117649, 48.12747269868851, 43.306895568966866, 46.0419812053442, 44.7979811578989, 44.96685929596424, 43.46637301146984, 45.80186828970909, 43.300986886024475, 44.54741880297661, 40.32752104103565, 43.55743132531643, 40.69332741200924, 44.93328809738159, 41.073067635297775, 43.04338350892067, 40.56391015648842, 43.0912571400404, 42.58213385939598, 41.49786964058876, 42.009838968515396, 42.39944726228714, 41.077938973903656, 42.800135761499405, 40.76537914574146, 44.288557693362236, 41.39143355190754, 42.039446979761124, 40.60596249997616, 45.00295735895634, 42.4386877566576, 42.20407694578171, 42.74674482643604, 44.01951313018799, 41.901335790753365, 46.040484085679054, 41.577365174889565, 43.83874922990799, 41.01327784359455, 40.43120987713337, 40.49712873995304, 45.207876563072205, 41.60340517759323, 43.205057233572006, 45.92705637216568, 45.377415865659714, 45.55366940796375, 46.03440061211586, 47.39631973206997, 47.86702327430248, 51.933876648545265, 57.13107816874981, 56.170782297849655, 55.90494476258755, 56.50011822581291, 53.870514929294586, 49.38966616988182, 43.60076040029526, 45.684914365410805, 46.10962517559528, 45.07419213652611, 44.79945167899132, 44.61299188435078, 43.5250798612833, 42.34004504978657, 40.87116166949272, 42.05239288508892, 41.62942238152027, 41.78152821958065, 41.920931339263916, 40.744886845350266, 44.19342219829559, 44.25725497305393, 47.47436374425888, 45.046818405389786, 45.76486587524414, 44.37475986778736, 41.97103925049305, 43.55279177427292, 42.161344438791275, 42.22331151366234, 43.89512300491333, 40.977248176932335, 41.95795275270939, 43.56850013136864, 42.48400792479515, 40.90277977287769, 43.22401061654091, 41.74595832824707, 42.11218647658825, 43.43055233359337, 45.026888474822044, 45.75592115521431, 46.16230174899101, 42.119770869612694, 44.80642430484295, 53.75683642923832, 58.522818088531494, 58.87598633766174, 60.99189139902592, 59.66073922812939, 58.78158040344715, 61.05243735015392, 59.71601486206055, 61.442634612321854, 59.53899756073952, 58.91993097960949, 57.70811900496483, 55.37278711795807, 52.03877381980419, 51.162563636898994, 50.93597039580345, 56.30045793950558, 68.16821292042732, 69.18936252593994, 69.47288811206818, 54.01876397430897, 0.417717641685158, 3.1121576903387904, 7.32858837582171, 0.5512916960287839, 0.45753430982585996, 41.48377999663353, 80.06846755743027, 70.02056792378426, 82.2524231672287, 93.51881861686707, 62.275139540433884, 31.55559863895178, 59.25234094262123, 65.89886829257011, 82.08687365055084, 13.61671183258295, 0.4623112175613642, 0.2616726025007665, 0.1581601006910205, 0.1839441218180582, 0.15483898983802646, 0.46537144866306335, 0.18894183333031833], [0.06095204320445191, 0.05570079549215734, 0.09233782096998766, 0.04122118261875585, 0.045240813997224905, 0.03368796067661606, 0.10987767978804186, 0.06055157289665658, 3.942081844434142, 60.09263925254345, 52.76567481458187, 42.41569899022579, 19.111969359219074, 37.36118741333485, 66.18620127439499, 43.667241632938385, 58.621768578886986, 52.0654483884573, 65.9113772213459, 20.377155169844627, 0.5011286283843219, 0.38786715595051646, 1.0635574674233794, 0.5963521124795079, 27.405598126351833, 76.32301613688469, 52.87622228264809, 61.76040396094322, 49.70474526286125, 51.78422927856445, 46.654519736766815, 47.75965243577957, 43.29244874417782, 45.28703771531582, 41.73773176968098, 44.043915420770645, 40.62634080648422, 41.12732492387295, 39.109709188342094, 40.21498627960682, 37.56272479891777, 39.3053112924099, 36.622552648186684, 39.78575371205807, 36.2070107460022, 38.25770750641823, 35.76758712530136, 38.410763293504715, 35.64472071826458, 36.83010131120682, 36.83750331401825, 38.52820739150047, 36.72997668385506, 37.65076607465744, 35.87062619626522, 38.236215859651566, 36.425685212016106, 38.643246218562126, 37.936734929680824, 38.39464835822582, 37.28743337094784, 36.39844447374344, 37.97303818166256, 38.46131578087807, 37.66320280730724, 37.11256295442581, 38.5554975271225, 39.27194528281689, 39.00168478488922, 40.21129667758942, 38.258091285824776, 38.88131104409695, 40.52563861012459, 38.17801058292389, 37.32802279293537, 37.73652747273445, 39.196618124842644, 39.34852637350559, 38.283515721559525, 38.349734768271446, 38.80861334502697, 40.46249359846115, 40.801336616277695, 41.84069484472275, 40.98167113959789, 42.78301768004894, 49.042178615927696, 51.54318921267986, 51.82711377739906, 50.90578481554985, 51.58209152519703, 48.296084851026535, 43.66164453327656, 39.918469190597534, 42.25819744169712, 41.5144557505846, 39.8207688331604, 37.82814435660839, 39.372761473059654, 40.897619649767876, 37.93917819857597, 38.45249265432358, 36.29588797688484, 36.46754376590252, 36.060680598020554, 37.89570853114128, 39.58335377275944, 39.53559793531895, 40.7687571644783, 39.87793676555157, 39.14574645459652, 38.90725985169411, 39.437479600310326, 38.4996747225523, 39.30015116930008, 39.004302844405174, 38.56694631278515, 38.3792819827795, 37.81049430370331, 38.68108078837395, 38.71635429561138, 37.577194422483444, 38.25411669909954, 38.542186841368675, 37.30895921587944, 37.64801882207394, 36.92779026925564, 38.7039365619421, 37.78487987816334, 38.310425877571106, 39.889632537961006, 40.066820830106735, 39.954441860318184, 47.0948401093483, 52.42829851806164, 53.348362147808075, 53.76003585755825, 55.269881039857864, 56.49494290351868, 55.98545104265213, 53.67291793227196, 51.38615883886814, 44.66421693563461, 43.01377169787884, 41.35445013642311, 46.61212161183357, 44.54371780157089, 47.20468081533909, 48.76542806625366, 61.54177509248257, 59.05217908322811, 68.6962553858757, 50.998366847634315, 0.591644758824259, 1.6580527857877314, 2.764627863653004, 0.513088486623019, 0.1183387050696183, 37.045568749308586, 65.81012785434723, 63.562225475907326, 60.426082760095596, 37.49584078788757, 22.66736827790737, 31.177952103316784, 45.129285380244255, 49.369166269898415, 60.038989931344986, 9.43427911028266, 0.33774627197999507, 0.046211617373046465, 0.011834785946120974, 0.012468252589314943, 0.09637429538997822, 0.10219615447567776, 0.0973306194646284, 0.07026856066659093, 0.0635638352832757, 0.013484545906976564, 0.044436307362047955, 0.03916241301340051, 0.01904191933135735, 0.17957122443476692, 0.07596403200295754, 5.468805246055126, 68.03770512342453, 59.037964046001434, 48.5798916220665, 25.283128917217255, 26.000614017248154, 64.8906759917736, 48.889916986227036, 62.68259547650814, 57.384744957089424, 71.1546702682972, 22.616492807865143, 0.2773879951564595, 0.7428505795542151, 4.334614556282759, 0.33448465168476105, 27.39503089338541, 79.48526725172997, 54.76539731025696, 64.2034600675106, 51.42936632037163, 53.644909635186195, 48.92527408897877, 50.67474581301212, 45.58819815516472, 48.2523187994957, 42.40113817155361, 47.088612243533134, 42.69662171602249, 43.05261701345444, 41.279506757855415, 42.14950047433376, 40.6433030962944, 41.005332469940186, 39.39451150596142, 41.93812161684036, 37.81576082110405, 39.143546372652054, 38.756670132279396, 40.84209322929382, 37.6960102468729, 40.52659995853901, 38.526315093040466, 40.09710140526295, 39.59501534700394, 39.99470829963684, 37.26851798593998, 39.890145510435104, 37.84283436834812, 40.94183027744293, 39.731359630823135, 39.91410322487354, 39.96312819421291, 37.83220633864403, 39.5920667052269, 40.621917843818665, 38.47418189048767, 39.93980884552002, 39.81429398059845, 39.608253836631775, 39.7995013743639, 41.792961806058884, 40.985755920410156, 41.620481461286545, 41.601041704416275, 40.48488199710846, 39.64765392243862, 39.43515032529831, 38.83414797484875, 40.68071968853474, 40.27103707194328, 40.662803649902344, 40.767472833395004, 42.53508098423481, 42.70783871412277, 44.551351591944695, 42.0245061814785, 44.94292438030243, 51.34210020303726, 53.62324699759483, 54.81547102332115, 52.28717789053917, 54.62856285274029, 51.022924929857254, 44.42414201796055, 42.44505241513252, 43.895316794514656, 44.25536647439003, 41.31934382021427, 40.672907307744026, 41.24944657087326, 40.68095147609711, 41.88969321548939, 39.91075940430164, 39.40314844250679, 38.27118158340454, 37.75317057967186, 40.00257007777691, 41.14968292415142, 42.00470544397831, 42.63183519244194, 43.07453043758869, 40.06664223968983, 40.670437440276146, 40.59847690165043, 40.322592705488205, 39.71087493002415, 40.873110964894295, 41.67342022061348, 39.65881012380123, 39.00498680770397, 40.53706839680672, 42.57708013057709, 39.72579672932625, 40.84355615079403, 40.45155018568039, 38.85765351355076, 40.27631878852844, 39.40490774810314, 40.30724912881851, 40.541080981492996, 40.17469324171543, 40.83311051130295, 41.05949856340885, 42.582042664289474, 50.13933174312115, 56.83375172317028, 54.626510962843895, 56.93390674889088, 57.44771137833595, 57.5096670538187, 59.93574947118759, 56.07948079705238, 53.46581384539604, 48.181802183389664, 44.892679676413536, 43.4764538705349, 49.501729756593704, 46.565475314855576, 49.16639395058155, 51.378479450941086, 62.77276463806629, 61.72229580581188, 72.57449448108673, 56.447426453232765, 0.4751189943635836, 2.1778291510418057, 2.8124516224488616, 0.4668069997569546, 0.1418183947680518, 40.1797241717577, 71.95837274193764, 70.13782203197479, 68.78447905182838, 52.60608717799187, 32.92953081429005, 42.375440150499344, 56.15183651447296, 55.56980274617672, 71.06107369065285, 12.504564709961414, 0.3626097331289202, 0.06869159333291464, 0.011896313699253369, 0.07290175257367082, 0.06796652989578433, 0.030480795467155986, 0.11874220333993435, 0.12432771065505221, 0.12081427965313196, 0.23428741260431707, 0.1161246484844014, 0.1480260890093632, 0.1623267849208787, 0.37375596002675593, 0.19080569269135594, 6.436566291376948, 79.15913835167885, 64.36670690774918, 58.4066317230463, 30.039886571466923, 45.66697172820568, 77.49831587076187, 53.102614134550095, 69.10279557108879, 61.052232161164284, 77.64327809214592, 25.361165329813957, 0.6461552088148892, 1.2273278483189642, 7.828715164214373, 0.9213823964819312, 31.126096285879612, 80.70396825671196, 57.59975261986256, 66.48212939500809, 55.03519423305988, 54.307514280080795, 51.19821332395077, 53.84702458977699, 47.963101118803024, 49.8617110401392, 46.64592459797859, 48.99188831448555, 45.41339993476868, 44.97046150267124, 43.12336541712284, 45.40765084326267, 42.32773371040821, 43.49924124777317, 41.48653864860535, 44.77341927587986, 40.2913735806942, 41.22945584356785, 40.223968997597694, 43.50426837801933, 39.76046606898308, 41.64656326174736, 40.74592798948288, 43.175042644143105, 41.986702010035515, 42.13663436472416, 39.96298000216484, 43.13718907535076, 40.7961954921484, 43.576901480555534, 41.61542013287544, 42.46335603296757, 40.42095422744751, 39.79951657354832, 42.083566412329674, 44.29635487496853, 42.404246404767036, 43.0538709461689, 42.24629648029804, 42.32274077832699, 42.264581099152565, 42.11253985762596, 42.78679467737675, 42.89527125656605, 43.82179073989391, 42.312378734350204, 41.325966864824295, 41.17034241557121, 41.96856178343296, 42.82988056540489, 43.587347120046616, 43.92243213951588, 43.461273685097694, 43.807077929377556, 44.94534485042095, 45.32986521720886, 45.33257447183132, 48.25673796236515, 52.70426630973816, 56.884984374046326, 54.30558018386364, 53.145061656832695, 56.72358423471451, 53.49079370498657, 48.96127335727215, 45.15465281903744, 47.76744581758976, 47.49689273536205, 45.509492978453636, 42.477107495069504, 44.90667052567005, 45.06704851984978, 44.61622551083565, 43.40811833739281, 40.51579333841801, 41.03944703936577, 39.75897654891014, 42.139461413025856, 43.85430559515953, 45.8197957277298, 45.42044475674629, 44.72547724843025, 42.79772289097309, 42.16542162001133, 43.19669388234615, 42.80603304505348, 41.90732806921005, 44.44986663758755, 43.03726963698864, 41.89910911023617, 42.4227362126112, 42.98855245113373, 45.23955926299095, 41.59624636173248, 42.352990955114365, 42.59151175618172, 41.484950333833694, 43.04807245731354, 41.63580223917961, 43.54663610458374, 43.23301613330841, 41.87296651303768, 43.708530217409134, 44.6734694391489, 45.05133256316185, 52.01428413391113, 58.45030277967453, 57.916218638420105, 58.22911284863949, 60.553071945905685, 60.30678056180477, 62.165044248104095, 58.866247460246086, 57.186916172504425, 49.25655171275139, 48.091925606131554, 46.19292430579662, 54.3569952249527, 47.940093353390694, 50.98211511969566, 53.836780339479446, 65.21446421742439, 64.20213773846626, 74.00042876601219, 58.84394645690918, 0.6016646430362016, 5.839636847376823, 7.888551978394389, 1.1693536466918886, 0.13864296750398353, 43.34762558341026, 79.90628466010094, 74.18825268745422, 73.62941667437553, 51.13897830247879, 37.38503873348236, 46.16727188229561, 62.28414125740528, 65.84608912467957, 81.54321402311325, 17.625304833054543, 0.7431149028707296, 0.23099989135516807, 0.15509989927522838, 0.10227791688521393, 0.12700024381047115, 0.36058248253539205, 0.22520719125168398], [0.06791841646190733, 0.008053223482420435, 0.060517849706229754, 0.06782503201975487, 0.05162010020285379, 0.20288355241063982, 0.2587024384411052, 0.092207388515817, 5.2880242466926575, 57.633460611104965, 58.699835389852524, 38.10819312930107, 36.51578217744827, 76.92950159311295, 88.20519134402275, 51.166165843605995, 52.987244725227356, 54.895848110318184, 61.6137470304966, 21.902758106589317, 0.4682068683905527, 0.04951659022481181, 1.7348414403386414, 0.020423631322046276, 32.7223165333271, 73.95888939499855, 56.21136412024498, 58.855843618512154, 45.70189565420151, 50.4232183098793, 42.97050341963768, 44.98771257698536, 41.895446106791496, 45.44532582163811, 38.26753377914429, 41.56009130179882, 39.97991569340229, 40.750776529312134, 37.678512185812, 41.985064297914505, 38.593259900808334, 38.78138780593872, 36.65344879031181, 37.614994794130325, 37.54751421511173, 36.63794182240963, 37.29505196213722, 37.04071640968323, 36.28336004912853, 37.604651749134064, 36.029716059565544, 38.49302127957344, 38.207857981324196, 38.090900257229805, 36.021664291620255, 37.04165115952492, 38.26626844704151, 38.21570836007595, 37.46943600475788, 37.25641943514347, 35.53650252521038, 37.61507458984852, 38.21228474378586, 36.162933111190796, 36.50766961276531, 38.085496947169304, 36.22565254569054, 37.76341862976551, 38.886307775974274, 39.758911952376366, 38.06813567876816, 41.309338957071304, 39.972878471016884, 38.40885579586029, 37.64821261167526, 38.225264847278595, 35.7355510443449, 37.60112173855305, 38.473961502313614, 36.639514937996864, 39.780221208930016, 42.58951686322689, 43.68659779429436, 42.84941531717777, 42.09850341081619, 41.53440847992897, 49.377552419900894, 52.25372828543186, 48.67835953831673, 52.24296346306801, 51.23072437942028, 49.10734511911869, 43.14509645104408, 41.29982806742191, 40.865393579006195, 42.14071914553642, 39.165509194135666, 38.9794559776783, 39.330667331814766, 40.34268222749233, 39.646859765052795, 37.02832527458668, 36.34177431464195, 37.700368613004684, 36.26811146736145, 37.250609546899796, 39.14248242974281, 40.291540771722794, 41.082483530044556, 40.18747575581074, 38.36291626095772, 38.465575352311134, 39.229049384593964, 38.735334277153015, 37.77041405439377, 38.9466143399477, 37.330865040421486, 39.82009246945381, 38.55926312506199, 37.93844483792782, 37.189364433288574, 38.374961614608765, 37.874049693346024, 38.24416123330593, 38.46241392195225, 37.99789644777775, 36.664133816957474, 38.358025923371315, 37.72090271115303, 38.84738266468048, 38.024331629276276, 40.89293450117111, 40.28523690998554, 41.49949975311756, 41.409463584423065, 45.454525128006935, 48.55887874960899, 49.164357259869576, 48.61877113580704, 48.03718954324722, 45.43626330792904, 41.24017506837845, 41.366947665810585, 47.05608978867531, 49.372536689043045, 52.67561584711075, 50.82346983253956, 52.75886557996273, 52.59898915886879, 56.99302017688751, 61.105657294392586, 69.51324954628944, 57.522172182798386, 0.8348751103039831, 1.7005825974047184, 2.286291243508458, 0.45405244978610426, 0.07976871886057779, 32.298156693577766, 68.27510878443718, 63.66960771381855, 67.0043657720089, 46.54625214636326, 26.992659084498882, 16.186958514153957, 37.247102335095406, 50.510507225990295, 50.94258204102516, 7.069279840216041, 0.4910885280696675, 0.04920227584079839, 0.029272951978782658, 0.024015206763579044, 0.1258058164967224, 0.013834396177117014, 0.05055651723523624, 0.045142397793824784, 0.020546508712868672, 0.031998142367228866, 0.02624597280373564, 0.11327750282362103, 0.047934323956724256, 0.2508322591893375, 0.07630956853972748, 6.8916768953204155, 67.65534684062004, 63.67162920534611, 45.297091975808144, 37.43382051587105, 75.55233389139175, 87.22827136516571, 51.062587201595306, 59.36418794095516, 58.854935467243195, 68.04104894399643, 23.86290192604065, 0.466625559492968, 0.28435343701858073, 2.312275436706841, 0.05251510061498266, 34.522268548607826, 77.4924185872078, 57.23567135632038, 60.3238682448864, 48.73670920729637, 54.19882111251354, 45.14179810881615, 47.650484293699265, 44.59221459925175, 47.40428030490875, 40.63425958156586, 43.7849061191082, 42.11442455649376, 44.91524286568165, 41.73462733626366, 42.65820577740669, 40.845224261283875, 40.578972548246384, 38.08673948049545, 38.84533457458019, 39.74498189985752, 38.69480185210705, 38.93219791352749, 40.739285945892334, 39.06166456639767, 39.95087765157223, 40.08476346731186, 40.68494126200676, 39.977252036333084, 39.93050694465637, 38.36659826338291, 39.926581755280495, 40.24953782558441, 40.663457214832306, 38.83594907820225, 39.193403497338295, 37.44539089500904, 39.577999860048294, 38.896084651350975, 37.56063871085644, 38.446941152215004, 39.80667918920517, 37.39348568022251, 40.3037229180336, 39.28088240325451, 41.38200245797634, 40.27946501970291, 41.52273930609226, 40.584710240364075, 40.27452148497105, 38.81116680800915, 40.55644355714321, 37.830986604094505, 38.549003675580025, 38.73845390975475, 39.860108122229576, 42.1082004904747, 43.49016733467579, 45.64363718032837, 43.86925399303436, 44.78419169783592, 44.50340196490288, 51.855217069387436, 53.43960665166378, 51.35025076568127, 54.54456076025963, 53.082866594195366, 51.783108338713646, 45.23525029420853, 45.1570200920105, 42.79928080737591, 45.32204903662205, 43.31123113632202, 41.49553656578064, 41.77934713661671, 42.15304188430309, 40.54672367870808, 38.86342540383339, 39.11584585905075, 40.106540098786354, 39.78083297610283, 38.799159452319145, 40.63897892832756, 42.304634749889374, 41.7074815928936, 42.60285794734955, 41.43315151333809, 40.16646668314934, 41.40812985599041, 40.43515406548977, 40.55001050233841, 42.37173534929752, 39.53846678137779, 41.282550394535065, 40.39288133382797, 39.49368238449097, 39.859009981155396, 39.00558717548847, 39.76737029850483, 40.617570877075195, 41.236253678798676, 40.72087213397026, 39.49402816593647, 40.7788760215044, 41.14267610013485, 39.94233191013336, 40.825374126434326, 42.13748551905155, 43.60627390444279, 42.52983346581459, 44.001528695225716, 48.026713505387306, 51.36985011398792, 52.578781843185425, 50.288367345929146, 49.509834721684456, 48.144013211131096, 43.61473225057125, 43.972775638103485, 48.565490394830704, 53.880614787340164, 51.95968486368656, 52.148025557398796, 53.77250678837299, 56.0125245898962, 59.42754574120045, 63.69142234325409, 69.47085902094841, 60.36566220223904, 1.3135556713677943, 3.0552533688023686, 4.43151505663991, 0.33745134249329567, 0.05676318360201549, 34.07180652022362, 74.87594738602638, 69.11787316203117, 72.52191290259361, 49.42295618355274, 27.485426142811775, 19.059205390512943, 45.15914037823677, 59.20174665749073, 62.33376659452915, 9.879890698939562, 0.4331461794208735, 0.042846742071560584, 0.08122200728394091, 0.07702862800215371, 0.04660255479393527, 0.09587720487616025, 0.04692240931035485, 0.14108365372521803, 0.1311178572359495, 0.10137959165149368, 0.1455719253863208, 0.1911020916304551, 0.18997879175003618, 0.3996931901201606, 0.2337694974266924, 8.436661642044783, 77.59100049734116, 71.77867278456688, 51.532352194190025, 45.38944222033024, 87.67174556851387, 89.8779147863388, 61.07746280729771, 65.10151147842407, 64.50492069125175, 74.52226236462593, 28.628421910107136, 0.6751006306149065, 0.7662200380582362, 8.047415278851986, 0.112263335759053, 38.087290450930595, 79.08146291971207, 60.63124895095825, 63.20703573524952, 51.78104504942894, 54.48323965072632, 47.600121796131134, 49.6940678358078, 48.28828006982803, 50.032834857702255, 42.13918022811413, 45.718675553798676, 44.05360110104084, 46.74980342388153, 42.96635024249554, 45.404618605971336, 45.408141016960144, 43.835648596286774, 41.48585468530655, 40.79513154923916, 42.2665835916996, 41.37157961726189, 41.90632112324238, 42.012590020895004, 41.81548319756985, 41.84748128056526, 41.99796840548515, 43.13354127109051, 43.343271017074585, 41.862224489450455, 40.032056495547295, 40.51253691315651, 42.41783827543259, 42.051632925868034, 41.62397347390652, 40.975979045033455, 40.09255304932594, 42.29151405394077, 40.54096698760986, 39.16619315743446, 40.54607391357422, 41.49107180535793, 39.45298656821251, 41.57106131315231, 42.55132131278515, 44.002661034464836, 43.29559117555618, 45.97276411950588, 43.744890466332436, 42.40861237049103, 40.54396502673626, 41.88326396048069, 39.847063422203064, 42.94983632862568, 42.90472134947777, 41.623661890625954, 44.51684184372425, 47.27102145552635, 50.10539576411247, 45.87038241326809, 47.60015219449997, 45.47741889953613, 54.52539078891277, 55.863242000341415, 53.302168026566505, 57.163334637880325, 54.560447707772255, 52.393849566578865, 48.90860438346863, 46.61884345114231, 45.28442345559597, 48.26680742204189, 46.847074404358864, 44.74462442100048, 43.64278234541416, 46.57749406993389, 42.666071355342865, 41.451086550951004, 41.59379169344902, 42.803832963109016, 40.88799096643925, 39.98126082122326, 42.95751191675663, 43.80370371043682, 44.979467019438744, 43.966129794716835, 41.55516676604748, 41.81787706911564, 42.72676929831505, 42.145917266607285, 42.578938230872154, 45.308601558208466, 41.681699976325035, 43.4640209376812, 43.358029425144196, 41.069799810647964, 42.03335590660572, 41.39303706586361, 42.430632188916206, 42.510329112410545, 44.51483175158501, 43.19890916347504, 41.61130115389824, 42.73982919752598, 43.00860397517681, 42.657316625118256, 43.23096044361591, 45.99131852388382, 45.13741314411163, 46.19874559342861, 46.75846315920353, 52.40087538957596, 53.3270338922739, 54.98166270554066, 53.84390875697136, 52.92581342160702, 51.6149065643549, 46.035228967666626, 47.11158961057663, 51.871320605278015, 55.97834922373295, 55.57366333901882, 54.82679061591625, 56.90120950341225, 59.72282409667969, 62.079609632492065, 67.1500651538372, 73.5381455719471, 64.75250780582428, 1.8422672571614385, 6.309943785890937, 7.073055887594819, 0.7553655048832297, 0.2129682112718001, 37.45965912938118, 82.02151715755463, 74.00784596800804, 79.77301821112633, 60.24230942130089, 40.09392857551575, 27.306244857609272, 58.1046999245882, 68.1140886247158, 74.742361754179, 14.337920732796192, 0.4548933921614662, 0.14552180073224008, 0.16882758296560496, 0.19312618067488074, 0.1500120316632092, 0.3143964061746374, 0.09304749968578108], [0.13811963464831933, 0.05420340494310949, 0.07159805885748938, 0.11160326961544342, 0.09257279976736754, 0.013781927264062688, 0.24318193376529962, 0.06231795487110503, 5.382582172751427, 62.32608340680599, 60.72066195309162, 39.037995636463165, 28.96212950348854, 56.36134207248688, 80.38841038942337, 49.79038126766682, 56.10182359814644, 55.244027227163315, 63.82034182548523, 22.952615171670914, 0.20751991221914068, 0.4695279209408909, 4.335650000721216, 0.04025735172035638, 34.441222697496414, 71.3399863243103, 52.56732925772667, 56.241416707634926, 43.11620660126209, 47.04918935894966, 41.518152952194214, 47.06857971847057, 43.30070570111275, 45.750943422317505, 40.28763458132744, 41.6006351262331, 37.11661733686924, 39.4804172962904, 38.47567521035671, 39.41559657454491, 37.5550302118063, 42.23230943083763, 37.27474585175514, 38.283808305859566, 37.598803862929344, 37.20487520098686, 35.17803356051445, 38.57720196247101, 37.49318853020668, 39.13381889462471, 37.195143923163414, 38.57836849987507, 37.19518572092056, 38.77984508872032, 36.59629225730896, 38.38078290224075, 37.25904889404774, 39.4749341905117, 37.78438210487366, 37.84964360296726, 37.161565124988556, 39.10912781953812, 36.280608996748924, 36.77152745425701, 37.45882697403431, 37.395092993974686, 37.118585631251335, 38.60825389623642, 36.752194091677666, 38.82138065993786, 40.12919068336487, 41.75290435552597, 40.721305310726166, 38.76031793653965, 36.37872353196144, 36.28636188805103, 35.76699435710907, 38.10074932873249, 37.69328959286213, 36.40615426003933, 39.31265629827976, 42.25541979074478, 42.87079676985741, 43.71522165834904, 41.72889344394207, 43.361168056726456, 48.27185355126858, 51.24834403395653, 49.55481670796871, 53.07831443846226, 50.678564608097076, 49.21865254640579, 42.838585898280144, 40.79471357166767, 43.25797699391842, 42.141441106796265, 36.536878645420074, 37.70472317934036, 40.11031709611416, 41.01001761853695, 40.055193454027176, 36.191530376672745, 35.855305418372154, 36.39888145029545, 38.05365465581417, 37.256628423929214, 39.20271299779415, 39.52550567686558, 39.4852202385664, 38.16458970308304, 39.318044409155846, 38.121667206287384, 38.450174778699875, 38.164141327142715, 37.80305430293083, 38.40916357934475, 39.947446435689926, 37.769509702920914, 37.203986048698425, 38.124600648880005, 38.224930465221405, 38.928789496421814, 36.14792391657829, 37.90013909339905, 37.87289075553417, 38.487579971551895, 37.66652762889862, 37.97277219593525, 38.91221858561039, 38.24854999780655, 39.49201047420502, 39.048654064536095, 39.36729356646538, 40.025376453995705, 40.68321615457535, 39.23455148935318, 41.135315895080566, 40.953864231705666, 41.424864158034325, 41.97788268327713, 41.03129267692566, 42.474303245544434, 51.01277947425842, 56.890927255153656, 58.33148695528507, 61.33766904473305, 62.49978728592396, 58.64041417837143, 60.85922911763191, 60.23626774549484, 60.53133711218834, 65.28343051671982, 62.406323701143265, 1.6187495947815478, 1.8392677931115031, 1.8894354323856533, 0.5388574569951743, 0.14032014703843743, 27.159713320434093, 68.9158684015274, 63.834727853536606, 65.86027756333351, 51.75628937780857, 29.295554012060165, 34.68350529670715, 42.699144780635834, 46.72224350273609, 55.010791942477226, 6.85164556838572, 0.3701278078369796, 0.048415821947855875, 0.033198941018781625, 0.08126255081151612, 0.058945936398231424, 0.03291441644250881, 0.005864398990524933, 0.08836963155772537, 0.040415251060039736, 0.02959382694825763, 0.11666787089779973, 0.06211652857018635, 0.06163082260172814, 0.18043453514110297, 0.12489328655647114, 7.3341835755854845, 69.67602521181107, 67.02811449766159, 47.10576072335243, 37.419016510248184, 64.45255190134048, 82.36569508910179, 55.54576523602009, 59.64367054402828, 59.10874284803867, 68.20143073797226, 25.490766875445843, 0.31440373859368265, 0.29528901271987706, 4.17610083706677, 0.054338594563887455, 37.81720854341984, 74.99295070767403, 55.55378660559654, 59.51366811990738, 45.2982547134161, 48.89879710972309, 43.966935351490974, 47.81769432127476, 43.61825846135616, 46.48801267147064, 43.0507855117321, 43.678143247962, 39.66507978737354, 42.491094544529915, 40.299071967601776, 41.47131286561489, 39.500104039907455, 43.35272490978241, 38.6814721673727, 40.0031628459692, 38.61554570496082, 38.955973237752914, 37.16745100915432, 41.47010073065758, 39.00425344705582, 41.255153864622116, 37.829193100333214, 40.35991810262203, 39.16921019554138, 40.29135838150978, 38.76403033733368, 40.924313217401505, 38.969557508826256, 41.47159785032272, 39.18081857264042, 40.60383081436157, 39.003326296806335, 38.6883307993412, 39.03217434883118, 39.00971755385399, 38.15514720976353, 39.92739491164684, 37.10227310657501, 38.08322086930275, 38.15991975367069, 42.27377660572529, 41.43379747867584, 44.06758055090904, 44.580849409103394, 40.62001034617424, 38.208165764808655, 38.818428218364716, 38.29761676490307, 39.755868315696716, 39.82845202088356, 38.33681546151638, 41.61235369741917, 44.736774042248726, 45.08209191262722, 46.616343185305595, 42.88921058177948, 44.99343886971474, 49.69988152384758, 53.18299502134323, 51.280429512262344, 51.9667524844408, 54.26015742123127, 50.34197486937046, 45.6844811886549, 44.38805915415287, 45.553715005517006, 44.16687682271004, 39.5647119730711, 40.54445140063763, 42.90181830525398, 42.06522859632969, 41.809057742357254, 39.227662459015846, 37.41898991167545, 37.73811198771, 38.70390236377716, 39.053627997636795, 40.5834449082613, 41.159197613596916, 40.89642271399498, 39.982491955161095, 41.225998029112816, 40.471757501363754, 39.53783981502056, 39.890970066189766, 39.626219272613525, 39.36790533363819, 41.060007736086845, 39.24557849764824, 39.094137623906136, 40.51354005932808, 38.99222329258919, 41.947959288954735, 39.27611365914345, 39.70151983201504, 40.26994653046131, 39.74346578121185, 39.92307074368, 41.35725058615208, 40.976013243198395, 41.506662368774414, 41.97575859725475, 40.479243099689484, 41.071703508496284, 41.43920838832855, 43.94571729004383, 41.94946400821209, 44.503854140639305, 44.318990260362625, 42.450543120503426, 43.432520627975464, 43.55876125395298, 44.1404340416193, 51.69552303850651, 58.45599867403507, 62.15265691280365, 64.02918621897697, 63.3093224465847, 61.14409603178501, 63.11238281428814, 62.94001646339893, 63.15764218568802, 66.89265176653862, 64.8329646885395, 1.3836036063730717, 1.2901575956493616, 3.9922078046947718, 0.590291793923825, 0.09932032480719499, 30.275107249617577, 74.96359348297119, 67.46360152959824, 73.57058823108673, 51.77451319992542, 30.637457706034184, 38.188821002840996, 52.72467881441116, 53.55490766465664, 65.17549350857735, 10.328974351286888, 0.48999706632457674, 0.01123220748922904, 0.0757904139754828, 0.07590350243845023, 0.020540341465675738, 0.049849005590658635, 0.0990808560163714, 0.21864538866793737, 0.19343273219419643, 0.15810685901669785, 0.2266938763204962, 0.17453128471970558, 0.1390085049206391, 0.35445629095193, 0.13862039137165993, 8.441728670150042, 80.77246338129044, 74.22017857432365, 55.23448593914509, 38.429097309708595, 62.466683462262154, 78.89218747615814, 59.18342024087906, 69.2887955904007, 65.44208720326424, 75.03149583935738, 28.1245993450284, 0.2776654693298042, 1.41341122565791, 9.871370606124401, 0.1987735682632774, 39.557993933558464, 77.03984007239342, 57.36672252416611, 61.18329472839832, 48.404029458761215, 52.792869955301285, 46.878092139959335, 51.82627782225609, 46.00394144654274, 50.72841793298721, 45.95689617097378, 45.53041085600853, 40.935093238949776, 43.41818779706955, 44.81959819793701, 44.738822132349014, 41.89764238893986, 46.353135108947754, 40.070259645581245, 41.354693323373795, 41.38645961880684, 41.92805975675583, 39.22080382704735, 43.251627534627914, 42.37672068178654, 43.993074148893356, 39.52568806707859, 42.56325267255306, 41.866734847426414, 43.73643971979618, 40.60229949653149, 44.19448234140873, 42.52931289374828, 45.0139007717371, 40.254564955830574, 43.79380144178867, 39.736667945981026, 43.86391147971153, 41.27241633832455, 41.58604770898819, 41.71124719083309, 40.695519894361496, 40.39797306060791, 40.35744063556194, 38.742683082818985, 43.85245509445667, 41.9559882581234, 44.59083527326584, 46.78967468440533, 42.042638808488846, 40.76403021812439, 39.11582686007023, 40.205900967121124, 41.059183180332184, 42.51047730445862, 41.462501138448715, 45.655184760689735, 46.37202389538288, 48.0776459723711, 48.96622449159622, 44.91354435682297, 46.41681209206581, 53.38097579777241, 55.93446537852287, 52.90044218301773, 54.428416192531586, 56.610810086131096, 54.70537953078747, 48.372076973319054, 46.04684494435787, 48.35888788104057, 46.94822117686272, 43.16411443054676, 43.74961741268635, 45.077311769127846, 44.62290175259113, 46.32459484040737, 39.19922858476639, 39.73042868077755, 39.04676176607609, 42.35384210944176, 40.591280087828636, 42.6286281645298, 42.40113817155361, 43.51979434490204, 41.00049912929535, 43.368456065654755, 41.208632960915565, 42.75860399007797, 42.216209694743156, 40.64752086997032, 41.23400419950485, 43.865670785307884, 41.80736303329468, 41.127366721630096, 43.280183002352715, 40.39657473564148, 45.30244588851929, 40.42913518846035, 42.02164113521576, 43.32434423267841, 41.784533858299255, 42.98292875289917, 43.82903315126896, 43.19709286093712, 43.71983841061592, 44.85049054026604, 43.748910650610924, 43.46517987549305, 45.762323811650276, 46.232217997312546, 44.89410080015659, 46.08274921774864, 47.17818483710289, 44.34384472668171, 46.633020490407944, 46.08080372214317, 47.49117024242878, 54.94001694023609, 62.88883700966835, 63.61201040446758, 66.40105694532394, 67.37929925322533, 64.19655963778496, 67.32047840952873, 65.8532327413559, 66.45033270120621, 68.30039262771606, 70.09686782956123, 2.887199311517179, 4.074919391423464, 6.365444082766771, 1.5837433794513345, 0.17220971320057288, 31.86390459537506, 79.65704083442688, 73.16176816821098, 81.72429710626602, 61.68979994952679, 41.97979398071766, 48.591841980814934, 63.913414031267166, 63.31345282495022, 77.83248513936996, 14.883724395185709, 0.6210180139169097, 0.08883036425686441, 0.19378667726414278, 0.19975057599367574, 0.09997344444855116, 0.29001198650803417, 0.10528893617447466], [0.10573051404207945, 0.03546610569173936, 0.08945140827563591, 0.02482603093085345, 0.07486512651666999, 0.038145013895700686, 0.15963980957167223, 0.03828672328381799, 3.6011323146522045, 54.755464643239975, 59.01261180639267, 42.23370015621185, 28.761276081204414, 40.0764799118042, 50.144887045025826, 31.56989347189665, 60.060530975461006, 55.88116563856602, 61.970088109374046, 24.338170923292637, 0.26748352975118905, 0.07899477757746354, 1.1330450512468815, 0.18555323156761006, 34.587739035487175, 71.24836564064026, 57.48044282197952, 53.97760458290577, 46.08189046382904, 49.341971129179, 44.63289521634579, 49.687691777944565, 47.433325946331024, 49.46240946650505, 45.409778729081154, 46.46733798086643, 40.96674554049969, 40.53426414728165, 40.090675950050354, 40.078672394156456, 38.83580468595028, 39.379810094833374, 37.898163199424744, 38.55151914060116, 39.744085147976875, 40.07845960557461, 38.55389021337032, 40.417143031954765, 38.20029258728027, 38.66793729364872, 37.731188759207726, 36.181438118219376, 36.8472345918417, 37.48729504644871, 36.37042097747326, 36.56620167195797, 36.62699081003666, 37.66468472778797, 36.9574286788702, 36.49180166423321, 36.818325743079185, 37.93488822877407, 36.36122167110443, 36.932479217648506, 35.061269626021385, 36.86501383781433, 36.6118486225605, 38.02491679787636, 37.67970532178879, 39.94666367769241, 39.15002882480621, 39.04714934527874, 39.761663004755974, 39.511036053299904, 39.76200118660927, 38.06444987654686, 38.028636798262596, 37.627230137586594, 37.543581426143646, 35.76423570513725, 40.75947426259518, 40.49270577728748, 45.109355449676514, 43.74016731977463, 44.91694897413254, 44.18243318796158, 47.37949423491955, 51.24810844659805, 48.906252309679985, 49.074712470173836, 47.86041162908077, 48.50528262555599, 42.72683769464493, 44.19756777584553, 43.65230083465576, 41.19616582989693, 38.18030945956707, 38.60840208828449, 39.83364634215832, 38.40062543749809, 39.4215964525938, 37.682000398635864, 37.570050805807114, 36.51051186025143, 38.28134983778, 40.18380895256996, 41.131960675120354, 39.98307332396507, 39.37487795948982, 41.07748679816723, 39.59248088300228, 39.58862029016018, 38.089779317379, 38.318785429000854, 38.5213677585125, 38.01056116819382, 38.8835035264492, 38.29506330192089, 38.33363503217697, 37.46064707636833, 37.94393554329872, 38.55137474834919, 37.85272903740406, 37.162678465247154, 37.99945816397667, 37.928451374173164, 38.16200204193592, 38.83749559521675, 38.06925281882286, 38.693323731422424, 38.4921283274889, 39.08701680600643, 40.294911190867424, 38.46267610788345, 38.890080973505974, 40.61110362410545, 41.89113333821297, 43.00676487386227, 43.18617604672909, 42.470085471868515, 42.755374163389206, 49.16306912899017, 56.65047995746136, 60.33708393573761, 61.46547518670559, 49.982069581747055, 58.81735548377037, 59.52776916325092, 64.46670234203339, 58.835993483662605, 66.01583361625671, 62.91431084275246, 61.99609771370888, 1.5723220235668123, 0.9531120001338422, 4.596722116693854, 0.1727924623992294, 0.22630945866694674, 23.03855326026678, 72.42914468050003, 63.53219948709011, 66.41365706920624, 55.69396108388901, 33.347132205963135, 14.1556616127491, 31.358144134283066, 49.67655457556248, 55.7517521828413, 8.632073756307364, 0.275576472049579, 0.07320696822716855, 0.019399558441364206, 0.0502303247776581, 0.024441177265543956, 0.08996616932563484, 0.041413113140151836, 0.1550414031953551, 0.011899525343324058, 0.049378636103938334, 0.02018597151618451, 0.06026619485055562, 0.06397358985850587, 0.1860177714843303, 0.06538899164297618, 4.262720989063382, 64.64238971471786, 66.18256106972694, 48.75589817762375, 25.310989022254944, 47.118292450904846, 72.11570709943771, 40.38797579705715, 66.1621181666851, 59.02011640369892, 68.33101898431778, 25.44855684041977, 0.3592117951484397, 0.3559001540997997, 2.021419331431389, 0.21183642122196034, 38.79744954407215, 74.21406850218773, 59.98062886297703, 54.908866211771965, 47.37354755401611, 50.865666568279266, 46.85262210667133, 50.642968118190765, 47.04960733652115, 51.60159967839718, 46.90146088600159, 47.951112762093544, 43.29451963305473, 42.36924648284912, 41.806150898337364, 42.634472250938416, 40.33938780426979, 40.49925282597542, 39.2691296339035, 41.69561102986336, 42.43778720498085, 40.89443162083626, 39.79954697191715, 40.84961302578449, 42.122575119137764, 39.23905424773693, 38.64076115190983, 38.603876531124115, 39.575017020106316, 40.94732478260994, 38.78047205507755, 39.658494740724564, 38.58600988984108, 40.35727344453335, 38.879384547472, 39.667671248316765, 38.61966088414192, 38.30785721540451, 38.64950828254223, 39.35369409620762, 38.76635201275349, 37.97059491276741, 40.30010171234608, 40.75409755110741, 39.315411150455475, 42.97024503350258, 42.74881191551685, 41.058411821722984, 41.813868284225464, 40.636676251888275, 38.93163554370403, 39.69835840165615, 40.29044643044472, 39.68679562211037, 41.073443815112114, 38.89783635735512, 43.06898653507233, 43.67853842675686, 46.493244990706444, 47.67370484769344, 46.359568163752556, 44.48366202414036, 49.156339690089226, 52.46759220957756, 49.94041621685028, 51.467919051647186, 51.35967046022415, 51.32914289832115, 46.4148323982954, 45.5459938198328, 47.48577833175659, 44.2313289642334, 40.826358273625374, 41.21872141957283, 41.676950231194496, 40.490547493100166, 41.77178934216499, 39.131740406155586, 39.16301652789116, 39.66668710112572, 40.00540852546692, 42.89982721209526, 42.82239876687527, 42.74461694061756, 42.13302455842495, 42.148824110627174, 41.82285860180855, 39.99894507229328, 40.732666701078415, 39.304118156433105, 40.10059341788292, 40.63493974506855, 39.603150710463524, 39.24896031618118, 40.862330943346024, 39.58281800150871, 39.36544306576252, 41.574116349220276, 40.12421295046806, 40.246600583195686, 41.7671649903059, 40.74147082865238, 40.27411110699177, 40.17682492733002, 39.917268455028534, 40.05036771297455, 40.38880415260792, 41.346770748496056, 42.065380588173866, 41.31903983652592, 40.728790909051895, 40.14916621148586, 43.60655128955841, 44.51142333447933, 43.21565106511116, 43.78652483224869, 45.81455960869789, 49.870659559965134, 60.9932479262352, 62.827546298503876, 62.84882515668869, 52.97444701194763, 62.37571634352207, 62.50024326145649, 66.80450409650803, 60.812453627586365, 67.81134366989136, 66.99016213417053, 66.0809925198555, 2.3561939550563693, 0.5977722269017249, 2.854124936275184, 0.3970123449107632, 0.2700322726741433, 24.40467495471239, 78.96382883191109, 67.86316528916359, 75.66229239106178, 56.558654084801674, 33.692214488983154, 20.232654623687267, 41.687205880880356, 58.393488228321075, 65.56855961680412, 11.91595634445548, 0.2772552100941539, 0.05009687920392025, 0.05686487267666962, 0.004820931007998297, 0.040904827328631654, 0.07638559414772317, 0.057655386117403395, 0.21194468572502956, 0.09676317335106432, 0.19944222847698256, 0.21824733034009114, 0.1416822848841548, 0.18407368595944718, 0.3893743985099718, 0.15550021373201162, 5.404212512075901, 72.91332229971886, 75.66386550664902, 56.91346004605293, 39.7748026996851, 50.67428223788738, 62.60630317032337, 44.52507600188255, 72.27561011910439, 65.818160623312, 74.18018952012062, 29.013191163539886, 0.5044894886668772, 0.9991815593093634, 6.027276003733277, 0.3009826212655753, 41.29773437976837, 76.60621494054794, 62.79934041202068, 58.5439183562994, 50.28423696756363, 55.889069214463234, 48.85701835155487, 54.36261132359505, 51.118402406573296, 53.907790929079056, 48.08465279638767, 51.35364778339863, 46.10776707530022, 43.361905217170715, 44.15508225560188, 44.18440908193588, 43.42201039195061, 42.815289348363876, 42.861354276537895, 42.63132981956005, 45.49889154732227, 43.52388672530651, 42.46272146701813, 44.03013356029987, 43.52414511144161, 44.250483736395836, 41.751236245036125, 40.15150308609009, 42.504215240478516, 42.80851051211357, 40.53408555686474, 41.22349016368389, 41.698096096515656, 41.12667515873909, 41.88786931335926, 39.938794299960136, 41.51929289102554, 40.520223900675774, 40.04143439233303, 41.52031123638153, 40.07535897195339, 40.54776482284069, 41.82043433189392, 43.04832324385643, 41.12148463726044, 43.55648897588253, 43.14876325428486, 42.65837676823139, 43.84838551282883, 42.16319873929024, 41.793683767318726, 43.109340369701385, 42.607185915112495, 41.722612380981445, 42.797426506876945, 41.07004299759865, 45.496801659464836, 48.47755931317806, 49.817906990647316, 49.7387458384037, 49.56300526857376, 47.474743723869324, 51.21000409126282, 54.967409670352936, 54.07991789281368, 54.01228152215481, 53.31705942749977, 53.437965139746666, 48.18988434970379, 47.390563040971756, 49.574070274829865, 46.990041732788086, 43.643067330121994, 44.937099292874336, 42.84501515328884, 42.65949010848999, 44.60125811398029, 42.2906818985939, 42.602272778749466, 41.37269675731659, 41.8726397305727, 44.23267789185047, 46.32576137781143, 43.173275738954544, 44.16132152080536, 44.24025468528271, 43.52286458015442, 43.8195488601923, 43.01147282123566, 41.877256482839584, 44.04777601361275, 43.60092379152775, 42.04539366066456, 42.226009368896484, 42.68064737319946, 42.703981921076775, 41.973170936107635, 43.55446748435497, 42.056834846735, 42.78628550469875, 44.234353601932526, 43.568078354001045, 42.08223648369312, 43.4539020806551, 43.328417614102364, 42.196838334202766, 43.55170123279095, 43.294272646307945, 45.57031251490116, 44.39449980854988, 43.33467207849026, 43.651909455657005, 46.913046464324, 48.72715651988983, 47.913065403699875, 46.447951421141624, 47.95644007623196, 53.785680681467056, 62.97070361673832, 65.4873275756836, 66.89511403441429, 53.61059747636318, 64.83016803860664, 62.829347401857376, 69.3702632188797, 63.28403860330582, 71.64487436413765, 67.07292169332504, 70.24506747722626, 4.107846524566412, 2.9633982852101326, 13.56623724102974, 1.6503897844813764, 0.3471964836353436, 27.250030674040318, 84.53236922621727, 72.64279201626778, 81.39853298664093, 70.72238266468048, 45.133719742298126, 23.596182838082314, 50.336997136473656, 65.27650728821754, 79.07125666737556, 17.566626481711864, 0.5625363613944501, 0.18352112732827663, 0.12777612952049822, 0.09180246532196179, 0.17454299581004307, 0.25039664818905294, 0.10978043617797084], [0.11384413999621756, 0.04238960878865328, 0.015308211477531586, 0.045375265181064606, 0.09367750884848647, 0.05801556893857196, 0.06376533579896204, 0.04938104066241067, 1.3776503945700824, 48.752318769693375, 64.09344837069511, 48.99738281965256, 36.17163464426994, 16.146086007356644, 26.352349743247032, 34.879320189356804, 60.39680153131485, 54.31678958237171, 61.0478737950325, 22.405096851289272, 0.1273495875648223, 0.23460500728106126, 2.8666307777166367, 0.1869880998856388, 31.458335258066654, 69.84660565853119, 52.831939458847046, 55.789590552449226, 46.250688806176186, 51.729383021593094, 49.57703411579132, 53.92020486295223, 49.11005437374115, 52.19528742134571, 49.4642523676157, 51.02580137550831, 45.01945987343788, 42.26328916847706, 39.54540900886059, 41.14663548767567, 41.01898893713951, 41.89633905887604, 37.88145549595356, 39.06715527176857, 38.27295608818531, 39.39591363072395, 38.417819514870644, 37.52694971859455, 35.61290882527828, 37.00371399521828, 36.97945609688759, 35.8119535446167, 36.70802906155586, 38.134214133024216, 35.20811274647713, 38.03336754441261, 36.14385053515434, 38.283017948269844, 38.63942742347717, 37.98352561891079, 38.75125162303448, 38.084083423018456, 37.02314235270023, 37.34568044543266, 35.20307421684265, 37.03602746129036, 35.65253309905529, 37.753903940320015, 37.96974755823612, 38.87713886797428, 39.350285679101944, 39.445641562342644, 39.83099788427353, 38.98408032953739, 39.18358862400055, 38.09744730591774, 37.592914178967476, 38.25272977352142, 37.350217401981354, 36.55742034316063, 40.43471708893776, 42.75487259030342, 43.85765701532364, 46.584690883755684, 47.34990522265434, 45.50139561295509, 49.531957134604454, 51.69686816632748, 47.65109986066818, 42.97879457473755, 47.27290615439415, 48.3520482480526, 44.820080772042274, 43.39685194194317, 44.72273379564285, 41.5344312787056, 38.56575697660446, 34.479125663638115, 39.37009781599045, 38.11170794069767, 38.693110942840576, 38.38620141148567, 36.17591701447964, 37.689451798796654, 37.98101395368576, 39.93825852870941, 40.46681396663189, 39.09413002431393, 38.29632483422756, 37.592724189162254, 37.13149733841419, 37.72208824753761, 38.02796043455601, 37.54310265183449, 36.77721194922924, 37.45656609535217, 36.78404778242111, 37.52760328352451, 36.65308780968189, 35.44171281158924, 38.32818992435932, 35.939873680472374, 36.788767129182816, 38.16473409533501, 38.17012220621109, 38.144948557019234, 37.41284944117069, 38.559415116906166, 38.93196612596512, 39.5906987786293, 39.18122135102749, 39.72195513546467, 38.949456587433815, 39.15895074605942, 43.03137995302677, 40.885399505496025, 38.4210417419672, 41.869212314486504, 43.34460474550724, 45.60376971960068, 43.86203058063984, 48.30409102141857, 60.652106031775475, 56.4791015535593, 61.99434220790863, 52.43197292089462, 56.713393181562424, 56.853195279836655, 63.754916936159134, 65.44939801096916, 58.28313834965229, 65.87907135486603, 52.89812050759792, 3.0156868044286966, 0.21306693175574765, 3.019310859963298, 0.5508582224138081, 0.06751684035407379, 25.35572972148657, 67.44681403040886, 61.61638408899307, 64.70754861831665, 55.707309767603874, 35.42858071625233, 23.33150614053011, 35.354712679982185, 49.157814010977745, 55.444850251078606, 6.037133624777198, 0.3219832928152755, 0.13950734690297395, 0.0668756767117884, 0.03886130143655464, 0.07878305768826976, 0.04567903364659287, 0.03318249131552875, 0.09013488175696693, 0.04308779534767382, 0.028880682402814273, 0.009288044966524467, 0.03620672825491056, 0.03850104440061841, 0.032735929926275276, 0.10327444309950806, 1.8001119629479945, 56.402938440442085, 68.67749959230423, 55.95989741384983, 41.319047436118126, 23.310468569397926, 39.877875968813896, 38.9639338105917, 63.91246408224106, 59.05822455883026, 65.71897834539413, 25.60032829642296, 0.21308699942892417, 0.14371372119057924, 3.1843246053904295, 0.2298233943292871, 34.93489220738411, 73.00679728388786, 54.03072193264961, 56.47544614970684, 45.594695806503296, 52.643199786543846, 51.830932572484016, 54.20857138931751, 51.592780351638794, 53.91353242099285, 50.88683523237705, 53.0636016279459, 48.55626069009304, 44.36358466744423, 42.276979833841324, 43.55316415429115, 42.20783494412899, 43.259569108486176, 39.76429246366024, 42.063108310103416, 40.363163128495216, 41.80385962128639, 40.47539010643959, 39.04040850698948, 39.05662223696709, 39.49137210845947, 39.004371240735054, 38.23700621724129, 39.43853214383125, 40.073364078998566, 36.98234014213085, 39.30284522473812, 38.43632832169533, 39.20356035232544, 39.70436587929726, 39.419008791446686, 40.5155273526907, 38.36565971374512, 38.70184667408466, 38.63808609545231, 37.6120575517416, 39.86762411892414, 37.231048196554184, 40.03006920218468, 40.92373564839363, 40.87276138365269, 41.6435120254755, 43.066395074129105, 41.97086066007614, 41.45537652075291, 40.176676735281944, 39.70642536878586, 39.06699188053608, 39.907381385564804, 39.84338141977787, 39.16293293237686, 42.04212963581085, 45.56594654917717, 45.88628076016903, 47.724701911211014, 48.51951666176319, 48.96532014012337, 53.40135410428047, 55.1670091599226, 50.267673656344414, 46.56932070851326, 49.90795075893402, 50.24173624813557, 46.00276730954647, 46.35410785675049, 46.12854816019535, 43.90305697917938, 39.46208328008652, 38.10460992157459, 40.08914843201637, 40.06813935935497, 39.736067578196526, 39.44925136864185, 38.22732053697109, 39.49131891131401, 40.821323543787, 42.438759952783585, 43.11566703021526, 40.74034608900547, 40.396734327077866, 39.243044033646584, 39.70469646155834, 39.366769194602966, 41.40716850757599, 39.5133463293314, 39.380779042840004, 39.5516786724329, 41.037163361907005, 39.35497082769871, 38.52745123207569, 37.52517521381378, 39.058567732572556, 38.5904024541378, 40.51581233739853, 40.40737375617027, 40.14279395341873, 39.66302789747715, 40.196450874209404, 39.842340275645256, 41.52519777417183, 42.08618067204952, 41.86101995408535, 41.77078619599342, 41.64266847074032, 41.23657286167145, 43.96401710808277, 42.216490879654884, 40.65593361854553, 43.39301414787769, 45.51696337759495, 47.202465534210205, 45.24387203156948, 49.21817757189274, 61.72395631670952, 59.15140315890312, 63.055807650089264, 53.77091087400913, 57.80554577708244, 59.11721259355545, 67.37228482961655, 68.59735429286957, 60.986856669187546, 69.47135299444199, 59.498408138751984, 4.978652447462082, 0.08305065173772164, 2.8176345443353057, 0.5358509276993573, 0.09276023658458143, 26.315788105130196, 73.35850641131401, 67.04620912671089, 71.34626358747482, 62.440890446305275, 33.06635767221451, 23.8296727091074, 45.16968481242657, 56.12113036215305, 65.51603883504868, 8.555544912815094, 0.3288108139531687, 0.04531773389317095, 0.0174915227398742, 0.001603370628799894, 0.025222491785825696, 0.08887169446097687, 0.01509578190962202, 0.18455577024724334, 0.11981571995420381, 0.09447102798731066, 0.09209286770783365, 0.14697241742396727, 0.19796004082309082, 0.12042215108522214, 0.25344268942717463, 2.415755046531558, 61.61437399685383, 77.33435466885567, 61.42767861485481, 50.32063141465187, 25.26913806796074, 37.570233196020126, 46.64120905101299, 71.80649489164352, 64.71094563603401, 71.86774760484695, 26.96448739618063, 0.2990443987073377, 1.154078347608447, 7.989642228931189, 0.3095944138476625, 36.92145600914955, 73.81097853183746, 56.23508624732494, 60.23429945111275, 50.05964241921902, 56.371039152145386, 54.10775899887085, 57.698950096964836, 53.44952791929245, 56.1661883443594, 52.814205810427666, 57.104722782969475, 50.23396946489811, 46.79399125277996, 43.0085963755846, 44.53413471579552, 45.268392115831375, 45.42682841420174, 40.696720629930496, 43.37120331823826, 41.00207984447479, 45.38266718387604, 43.05821791291237, 41.88629999756813, 40.9166794270277, 41.93237632513046, 40.64443163573742, 40.011286810040474, 42.99888789653778, 42.89350815117359, 38.452276065945625, 42.22510501742363, 40.68816728889942, 41.893018037080765, 41.50035470724106, 41.88921444118023, 42.47180297970772, 43.04719850420952, 42.24275887012482, 41.40045806765556, 38.675358295440674, 42.32269898056984, 37.98194870352745, 41.59504942595959, 42.06235595047474, 43.39071907103062, 43.51214915513992, 44.71305191516876, 44.29498694837093, 42.69485101103783, 42.414407059550285, 41.5053666383028, 40.660147592425346, 40.93499444425106, 41.06473468244076, 42.7154953032732, 44.44088771939278, 48.00589442253113, 47.491037249565125, 51.303866654634476, 50.45268572866917, 50.390179082751274, 55.59274971485138, 56.434427350759506, 51.542581245303154, 47.61902958154678, 51.666048020124435, 54.11070004105568, 50.171709805727005, 49.54873703420162, 48.887173533439636, 46.57288871705532, 42.54404470324516, 38.81261833012104, 42.506650909781456, 43.038705959916115, 41.44284099340439, 43.37442934513092, 39.76010508835316, 41.884031519293785, 43.05756434798241, 43.101786375045776, 43.44350203871727, 41.61830797791481, 41.938467398285866, 41.08196295797825, 41.95915728807449, 41.634099930524826, 42.52173610031605, 40.987066850066185, 41.598005667328835, 41.01343363523483, 41.66560783982277, 40.627792328596115, 40.867692455649376, 39.647038355469704, 42.178983092308044, 38.848921582102776, 42.582247853279114, 43.80725271999836, 43.90111528337002, 42.98462726175785, 41.25902205705643, 42.58709259331226, 44.7635094076395, 44.107740595936775, 43.63452158868313, 44.43920060992241, 44.00106132030487, 44.118254631757736, 47.25437834858894, 45.52021220326424, 42.77924068272114, 45.77645145356655, 49.264618679881096, 49.406940042972565, 48.75209838151932, 53.15236486494541, 65.72789266705513, 62.03671373426914, 67.30504363775253, 54.45417881011963, 59.668232426047325, 60.23294672369957, 68.19814011454582, 71.66736915707588, 62.55361519753933, 70.6523372232914, 65.48525288701057, 7.7616986352950335, 0.690264607546851, 9.409880619496107, 1.53026849264279, 0.12982289859792218, 29.97449968010187, 80.62643721699715, 71.0259559750557, 78.47684696316719, 71.12616419792175, 47.42184676229954, 36.80888704955578, 54.04416561126709, 64.7277483344078, 77.16567412018776, 13.767717629671097, 0.5267219175584614, 0.23943536449223757, 0.14337585103930905, 0.12749662186251953, 0.117860056925565, 0.2810640900861472, 0.17399762116838247], [0.06807843834394589, 0.06362789004924707, 0.03475731013168115, 0.020441632113943342, 0.050204141807626, 0.044904435562784784, 0.11499345957417972, 0.034407268758513965, 0.25454584741964936, 30.319473668932915, 66.88242271542549, 45.1484477519989, 33.153221011161804, 22.890839986503124, 38.36996108293533, 38.383066579699516, 59.5461867749691, 55.78492060303688, 61.29076436161995, 23.432259634137154, 0.23900076281279325, 0.0942430624854751, 1.139058347325772, 0.05455857084598392, 22.274205274879932, 72.15878158807755, 56.50942772626877, 60.112736374139786, 50.521097257733345, 55.308426171541214, 51.468937397003174, 54.434606060385704, 50.874797478318214, 52.02408380806446, 52.132666781544685, 51.84557318687439, 49.2181433737278, 44.95012119412422, 40.29670089483261, 41.7456429451704, 39.43100854754448, 41.386592611670494, 38.37621554732323, 38.27016703784466, 37.707546427845955, 38.714317604899406, 37.03243665397167, 38.10162328183651, 37.91410714387894, 36.76409885287285, 36.40068255364895, 38.21494460105896, 35.18426902592182, 36.63304768502712, 36.20233699679375, 36.27091571688652, 36.689877435564995, 38.065715208649635, 35.62775082886219, 37.447032406926155, 38.07792775332928, 37.40475207567215, 37.24073767662048, 37.15740814805031, 35.66246956586838, 38.63231800496578, 36.833521127700806, 37.429059371352196, 38.44221420586109, 38.447963297367096, 38.710612803697586, 40.42572297155857, 39.96263802051544, 39.84602987766266, 39.49441574513912, 37.16815397143364, 38.92615623772144, 38.16197544336319, 37.765402123332024, 37.65703573822975, 39.65501792728901, 44.74508799612522, 47.26575493812561, 50.34000277519226, 47.30760969221592, 46.03213973343372, 47.819484025239944, 50.57795740664005, 50.32081760466099, 49.16622295975685, 49.12118397653103, 47.76138514280319, 45.19717253744602, 44.68863822519779, 42.75773003697395, 42.85682111978531, 37.36822843551636, 36.12439177930355, 38.54221723973751, 37.70826458930969, 38.56731489300728, 37.13721223175526, 36.31835237145424, 37.99886919558048, 39.53554853796959, 39.01956282556057, 39.72024142742157, 40.33583499491215, 40.733593851327896, 37.49179020524025, 39.42149005830288, 37.07408621907234, 38.053768649697304, 36.66637569665909, 37.59370073676109, 37.68628276884556, 38.48559267818928, 39.80776973068714, 36.8755354732275, 36.52399733662605, 36.24655142426491, 35.9195713698864, 36.30051612854004, 36.647019535303116, 37.939375787973404, 37.0101622492075, 37.883731573820114, 37.36605115234852, 38.20146292448044, 40.85708722472191, 40.41037939488888, 39.16224516928196, 39.54770028591156, 38.103694170713425, 42.593267261981964, 41.017697006464005, 42.93872572481632, 42.28388786315918, 44.24598477780819, 43.71568903326988, 44.3306328356266, 45.08508615195751, 52.83822052180767, 54.65005449950695, 56.492077857255936, 59.95566800236702, 60.37127070128918, 59.322686567902565, 59.01798091828823, 58.33823539316654, 61.358719915151596, 56.663194075226784, 53.06240849196911, 7.349706217646599, 0.1261388775310479, 1.0231314366683364, 0.4485342849511653, 0.0965643223025836, 25.02395622432232, 71.96799382567406, 62.41505183279514, 70.26852741837502, 57.353601828217506, 38.972608745098114, 16.842573434114456, 33.948381543159485, 52.45509088039398, 49.620256796479225, 3.7349616084247828, 0.35547733772546053, 0.04878799416474067, 0.028169955403427593, 0.055245717958314344, 0.08519980750861578, 0.056437866878695786, 0.09898972770315595, 0.03323748074762989, 0.03465745787252672, 0.09190596523694694, 0.051091486966470256, 0.024595590366516262, 0.04244246083544567, 0.020334979926701635, 0.03400230845727492, 0.38871480734087527, 36.48292914032936, 74.14138600230217, 50.9138023853302, 38.24505798518658, 21.266356855630875, 39.73477564752102, 45.72362668812275, 62.248206585645676, 60.21824151277542, 67.29036882519722, 25.10294448584318, 0.2488870159140788, 0.0901757889369037, 2.9139805119484663, 0.04047004011226818, 24.88016054034233, 75.58580249547958, 59.12199653685093, 61.845910772681236, 51.94451987743378, 56.965513452887535, 53.28328303992748, 56.69160135090351, 53.26347090303898, 54.925596714019775, 54.702563881874084, 53.75187009572983, 50.87371453642845, 46.418890580534935, 42.226130962371826, 42.73472607135773, 41.12649276852608, 44.46667693555355, 42.06829883158207, 40.37407234311104, 40.00485375523567, 40.575165152549744, 39.028682336211205, 41.32862292230129, 37.90679253637791, 40.389298126101494, 37.96086363494396, 39.92233358323574, 38.035761415958405, 40.08628338575363, 39.259466752409935, 39.16443385183811, 39.839235842227936, 39.9908135086298, 37.584904208779335, 38.408430218696594, 39.805672243237495, 38.85131165385246, 38.94217237830162, 39.30303521454334, 37.67134577035904, 40.20170979201794, 37.659809589385986, 39.66336987912655, 41.14925354719162, 40.37247262895107, 39.72767002880573, 42.45453670620918, 41.735801473259926, 40.554285272955894, 38.9071686565876, 40.14435566961765, 40.56443452835083, 39.85636532306671, 40.143371522426605, 39.70052048563957, 42.725481167435646, 48.74759182333946, 48.4186776727438, 52.930870950222015, 51.192920207977295, 47.63815015554428, 48.837248012423515, 51.26326583325863, 53.50699983537197, 50.22887773811817, 53.262182772159576, 49.59784559905529, 46.55190624296665, 46.4055684953928, 43.82865697145462, 44.36590254306793, 38.87248411774635, 39.565240144729614, 40.69191388785839, 39.169555976986885, 39.41292531788349, 39.445823952555656, 37.203161492943764, 41.055341586470604, 40.990608260035515, 41.55222572386265, 42.177919149398804, 41.815437600016594, 43.42120863497257, 38.858569264411926, 40.77452525496483, 38.81740227341652, 39.480801075696945, 39.561269357800484, 39.70205560326576, 40.30783049762249, 39.60683271288872, 40.510002449154854, 38.5217971354723, 38.0621661990881, 38.67592066526413, 38.512662425637245, 39.302290454506874, 39.94775801897049, 40.815331265330315, 39.12949092686176, 40.346877202391624, 39.39765013754368, 40.67122019827366, 41.430936232209206, 43.77650856971741, 41.418586894869804, 43.10531258583069, 40.47243386507034, 45.86957685649395, 42.86831550300121, 45.78750506043434, 45.664437264204025, 46.43173009157181, 46.333592757582664, 45.84489718079567, 47.19893552362919, 56.46724618971348, 56.903360188007355, 59.925041645765305, 62.831817269325256, 64.49731349945068, 59.63224075734615, 60.50691582262516, 59.2929607629776, 65.25825306773186, 58.861737102270126, 61.43190398812294, 10.161713026463985, 0.20320365554653108, 2.3394019436091185, 0.3492944163735956, 0.16614914231467992, 27.598489075899124, 78.8882964849472, 67.22700342535973, 73.98553356528282, 62.66521140933037, 41.85408532619476, 25.199805088341236, 43.15693661570549, 58.71209733188152, 60.44399119913578, 6.012373678386211, 0.2899896923918277, 0.06779118266422302, 0.028831387098762207, 0.03842746045847889, 0.07097214634995908, 0.01814353101508459, 0.01798801211407408, 0.09220280204317532, 0.15539671381702647, 0.25320054148323834, 0.16452551615657285, 0.06061281492293347, 0.19301203836221248, 0.146605885529425, 0.14037784159881994, 0.444977794541046, 43.05205084383488, 83.32511320710182, 58.355543464422226, 45.71749001741409, 33.76869298517704, 49.70105566084385, 52.704460099339485, 69.0379710495472, 64.32344242930412, 73.71878027915955, 28.906052112579346, 0.5434153124224395, 0.31881067086942494, 5.947581455111504, 0.11426386161474511, 28.045120909810066, 77.77399107813835, 61.09656438231468, 65.03165602684021, 54.226787611842155, 60.27465708553791, 55.95385193824768, 57.345865443348885, 55.32210923731327, 56.72891154885292, 57.18462869524956, 54.67491276562214, 53.1569018214941, 48.89791175723076, 44.79142650961876, 43.32528278231621, 42.78052881360054, 45.71104936301708, 43.44928152859211, 43.36033210158348, 41.65496841073036, 44.11577716469765, 41.11305668950081, 43.79649929702282, 40.2801413834095, 43.149830996990204, 41.15714952349663, 43.11685636639595, 39.787133038043976, 42.66467683017254, 41.120154708623886, 41.49802923202515, 43.52371193468571, 42.956075593829155, 39.29884783923626, 40.01620754599571, 42.92158104479313, 41.27811223268509, 41.26181870698929, 42.67760753631592, 40.170794650912285, 43.171501234173775, 39.60981175303459, 41.13020516932011, 43.031015172600746, 43.239631578326225, 41.926650032401085, 44.12480168044567, 43.465141877532005, 42.29121387004852, 41.91514424979687, 42.58475571870804, 42.88160338997841, 41.45897872745991, 42.527523189783096, 42.63936638832092, 45.75963735580444, 50.20916819572449, 48.66369232535362, 53.236180767416954, 51.8794521689415, 51.03803291916847, 50.76598271727562, 53.74299377202988, 56.3292033970356, 53.01865004003048, 54.970358312129974, 48.80887493491173, 48.25897604227066, 48.777564615011215, 45.689356327056885, 48.30431520938873, 42.067599669098854, 41.98939986526966, 43.64043407142162, 42.246437072753906, 41.94253697991371, 42.60611057281494, 39.957846477627754, 44.30123381316662, 44.56855706870556, 43.10577616095543, 44.91361655294895, 43.76524977385998, 46.29608117043972, 39.969534650444984, 43.245471864938736, 41.60531647503376, 40.91838173568249, 41.17936313152313, 42.033367305994034, 41.65866941213608, 40.92750124633312, 43.806758746504784, 41.81513361632824, 39.70259137451649, 40.558856427669525, 40.43737694621086, 40.17829544842243, 42.274038791656494, 43.05213823914528, 40.96999816596508, 43.43541607260704, 41.88966281712055, 43.23413707315922, 46.034670397639275, 45.84191434085369, 43.5932520031929, 44.61204573512077, 42.532941699028015, 48.219534158706665, 43.61498683691025, 47.34594203531742, 47.409197241067886, 50.05513586103916, 49.18872155249119, 50.66925510764122, 50.05116127431393, 60.5349925160408, 58.48111912608147, 61.90829582512379, 64.82454434037209, 64.99235093593597, 60.65745234489441, 63.45337271690369, 62.73981660604477, 67.71229818463326, 59.611961245536804, 64.2787492275238, 13.677001297473907, 1.0676348861306906, 6.288531934842467, 0.9917031449731439, 0.18172980548115447, 30.13135716319084, 85.53065165877342, 71.29220008850098, 82.06208378076553, 71.14846900105476, 53.95098701119423, 28.50183930248022, 52.67406553030014, 68.49991232156754, 72.80536249279976, 9.487499054521322, 0.41128877259325236, 0.12124923756346107, 0.26401185197755694, 0.16335094871465117, 0.19339096412295476, 0.16302961361361668, 0.22583458805456758], [0.03698537104355637, 0.03251402777095791, 0.059915099627687596, 0.07226576912216842, 0.04650009759643581, 0.011238313509238651, 0.04768507737026084, 0.12375506208627485, 0.011277229878032813, 18.611952289938927, 62.95381732285023, 48.65374065935612, 40.82047238945961, 18.444373682141304, 23.014331459999084, 39.210209995508194, 52.71306663751602, 53.67575258016586, 62.213183864951134, 27.116982713341713, 0.12029484307277016, 0.13664537313161418, 2.2172985831275582, 0.3868329880060628, 15.370706263929605, 69.6525576710701, 60.017182901501656, 60.224085599184036, 53.094125390052795, 61.35301262140274, 56.84546649456024, 57.969693168997765, 48.543367981910706, 52.663745284080505, 55.12314811348915, 55.21819241344929, 52.836457416415215, 49.76593717932701, 42.25323110818863, 40.63945010304451, 41.20680905878544, 40.148816630244255, 40.424225851893425, 38.9948071539402, 39.342070519924164, 38.23594227433205, 38.305486142635345, 37.53935605287552, 35.948381423950195, 36.50288946926594, 36.5357881039381, 35.62349125742912, 35.422987416386604, 36.82418882846832, 35.06666153669357, 36.34237088263035, 36.61350533366203, 38.35915066301823, 38.71857337653637, 36.38261452317238, 38.21719028055668, 36.20158463716507, 37.32335664331913, 36.1988677829504, 36.07585698366165, 36.016580164432526, 36.17898724973202, 36.78544230759144, 37.57399879395962, 37.12664119899273, 42.0762138068676, 40.81518307328224, 41.68059803545475, 37.860906198620796, 38.074777722358704, 37.976036220788956, 37.446192651987076, 38.762328028678894, 39.484916254878044, 36.33386693894863, 40.60991808772087, 42.232792004942894, 51.38085812330246, 48.614120185375214, 45.96822336316109, 48.94140042364597, 48.58491875231266, 53.45211558043957, 50.912495255470276, 48.65410923957825, 48.1188889592886, 48.875416964292526, 45.67465491592884, 44.24217738211155, 44.89085577428341, 42.30672463774681, 36.23488985002041, 39.25864979624748, 39.487617909908295, 39.614325910806656, 37.56074130535126, 36.66033022105694, 35.48393614590168, 37.001122534275055, 39.70763370394707, 40.71494825184345, 41.37053467333317, 41.783735901117325, 39.49679061770439, 38.44281077384949, 38.226868361234665, 38.376325741410255, 37.139260321855545, 38.28568920493126, 37.42901377379894, 35.92061251401901, 37.66264423727989, 37.69833952188492, 39.33780714869499, 37.98286445438862, 36.319043934345245, 37.51262828707695, 37.246509566903114, 37.807739451527596, 38.157461285591125, 38.05471479892731, 37.00662463903427, 38.66170562803745, 37.437909096479416, 38.07482711970806, 37.305558398365974, 38.51766295731068, 40.03500133752823, 38.65026444196701, 39.06887657940388, 39.36876408755779, 40.85391819477081, 39.51574020087719, 41.351353302598, 40.96784748136997, 43.28045278787613, 46.3087572902441, 45.665637999773026, 48.263285011053085, 51.602925807237625, 52.677644938230515, 63.357792645692825, 59.59086857736111, 59.65047597885132, 58.73721398413181, 61.063585951924324, 56.80665537714958, 60.30998758971691, 8.941491153091192, 0.24266654188977554, 1.0302413301542401, 0.580248279729858, 0.2727543516084552, 25.61542108654976, 69.52402576804161, 64.30851683020592, 69.82658073306084, 54.418160542845726, 27.682200483977795, 17.147128991782665, 32.50357747077942, 49.58453871309757, 49.568530172109604, 4.980345256626606, 0.22205629938980564, 0.05513173520739656, 0.09294069721363485, 0.014200236946635414, 0.08984721047454514, 0.057106879612547345, 0.031829025465413, 0.006919274710526224, 0.062483268266078085, 0.03146037844999228, 0.06097776975366287, 0.009145783606072655, 0.02391556787188165, 0.006748881314706523, 0.11414192675147206, 0.027090349467471242, 23.564901016652584, 72.99266964197159, 54.276986718177795, 46.309806033968925, 21.504856757819653, 31.35406505316496, 46.94507874548435, 60.09221747517586, 58.507573306560516, 68.48506271839142, 29.284451007843018, 0.08006118441699073, 0.10505501122679561, 2.8676218120381236, 0.19495984946843237, 16.380945704877377, 72.9611237347126, 62.711428329348564, 62.70842269062996, 54.01799261569977, 62.41948239505291, 57.95177333056927, 57.78645180165768, 50.05193643271923, 54.89716283977032, 56.29829965531826, 57.14112102985382, 53.43134209513664, 51.88266679644585, 42.80121490359306, 41.2634602189064, 42.23290219902992, 42.39836432039738, 42.42231823503971, 41.1525821685791, 41.689854338765144, 39.78208310902119, 40.701109394431114, 38.615633100271225, 38.03236439824104, 39.73590038716793, 39.498363733291626, 37.47179567813873, 38.79528746008873, 38.98124948143959, 37.142201364040375, 39.04489606618881, 38.51548947393894, 41.383017003536224, 39.39311318099499, 38.59877720475197, 39.108105674386024, 37.82541610300541, 38.920224756002426, 37.55484402179718, 37.644424214959145, 37.907263711094856, 37.93674632906914, 38.60992580652237, 39.80399653315544, 37.66431614756584, 41.66393592953682, 42.01379835605621, 42.15127877891064, 40.88702201843262, 40.317877158522606, 39.705950394272804, 39.746049642562866, 39.68082994222641, 41.62120722234249, 37.0943733304739, 42.105707824230194, 45.255108028650284, 53.789966851472855, 51.505708023905754, 49.14810173213482, 50.867946445941925, 48.7671759724617, 54.39281590282917, 52.190959453582764, 50.386200696229935, 50.29229633510113, 52.20500349998474, 48.466148525476456, 46.59462355077267, 47.69684560596943, 44.951511919498444, 38.041833490133286, 40.56332118809223, 40.952990278601646, 41.729668602347374, 39.267442524433136, 37.712349370121956, 37.983050644397736, 38.83141592144966, 41.396369487047195, 42.77977265417576, 42.00991876423359, 42.88779325783253, 40.65151445567608, 39.356494545936584, 40.35154715180397, 39.69840779900551, 39.78085957467556, 40.33233918249607, 39.72225531935692, 37.54648447036743, 40.39437845349312, 38.830997943878174, 40.59468470513821, 38.28405149281025, 39.00969095528126, 38.445003256201744, 39.35866042971611, 40.18511988222599, 41.328573524951935, 39.50336806476116, 37.696253433823586, 42.20988683402538, 41.03180564939976, 39.95653934776783, 40.6525593996048, 40.34224525094032, 41.80028021335602, 41.71530917286873, 41.358322128653526, 40.4742843657732, 42.78693147003651, 42.616214230656624, 43.43301460146904, 42.739981189370155, 46.41274631023407, 45.695701986551285, 49.88647051155567, 51.618094593286514, 55.90287007391453, 54.93509240448475, 64.75925624370575, 60.82306265830994, 63.08253541588783, 59.10785369575024, 65.81711187958717, 57.416439056396484, 65.31293973326683, 11.419974658638239, 0.17943627230124548, 1.5474217222072184, 0.40144219470676035, 0.2121774380793795, 26.92462183535099, 76.01564303040504, 68.29441174864769, 75.04984885454178, 61.40220858156681, 34.01643209159374, 19.566594064235687, 37.719363793730736, 54.994677007198334, 59.02495354413986, 6.715968623757362, 0.1983737584669143, 0.12342549656750634, 0.05118275999848265, 0.08051613578572869, 0.06505362995085306, 0.04053153817949351, 0.060390229991753586, 0.1820658499491401, 0.2034979171003215, 0.12572824722155929, 0.1970174687448889, 0.11369875326636247, 0.10042494483059272, 0.18917155772214755, 0.3059104521526024, 0.12289696867810562, 28.41940462589264, 83.1852351129055, 61.238889545202255, 56.52086891233921, 27.317351661622524, 30.875950008630753, 50.693079829216, 68.37158560752869, 62.72673770785332, 73.23036208748817, 32.561550959944725, 0.14051144302356988, 0.3589259792352095, 6.781434835866094, 0.34675045288167894, 19.02758728712797, 74.77336049079895, 65.83282023668289, 65.14821857213974, 55.69445885717869, 65.73334157466888, 59.63394306600094, 59.63844582438469, 50.975659266114235, 57.48776122927666, 60.55624097585678, 58.687736839056015, 57.547459825873375, 53.379942253232, 46.17270939052105, 43.976609632372856, 45.23065634071827, 44.0524535626173, 46.25159315764904, 42.96005018055439, 43.80362771451473, 43.400252759456635, 43.3774995803833, 41.9600198417902, 40.51550455391407, 42.467041835188866, 41.177573427557945, 39.2729826271534, 41.35874390602112, 42.408806160092354, 38.28548401594162, 41.65893539786339, 41.881295666098595, 42.93044596910477, 42.13709034025669, 39.643078967928886, 40.883556604385376, 40.304148495197296, 40.4993212223053, 40.35190433263779, 39.03563976287842, 40.05772791802883, 39.424864277243614, 40.95244310796261, 41.79466791450977, 40.27197942137718, 45.94420105218887, 45.2269933372736, 44.500286132097244, 43.725887686014175, 42.32920043170452, 41.799866035580635, 42.92639538645744, 43.164555206894875, 43.545860946178436, 39.92780148983002, 44.339638352394104, 48.81900519132614, 53.278753682971, 52.25538119673729, 50.91518171131611, 53.04030507802963, 51.828770488500595, 57.29161575436592, 53.28789599239826, 53.23775388300419, 53.95724147558212, 54.825335294008255, 51.173678040504456, 52.91685730218887, 50.98946772515774, 47.54451557993889, 40.85194990038872, 45.14851614832878, 43.09429697692394, 46.13495461642742, 42.056846246123314, 41.43329210579395, 38.158498629927635, 40.56989103555679, 44.76989686489105, 44.789123833179474, 46.02198667824268, 44.443543776869774, 44.559266567230225, 42.71093934774399, 41.73126071691513, 42.14806795120239, 42.8306595236063, 41.09352953732014, 42.64324218034744, 37.37939603626728, 42.42283880710602, 41.1638979613781, 43.877883329987526, 40.56319199502468, 41.2019719183445, 40.83603635430336, 42.50141479074955, 44.61518816649914, 44.537022560834885, 43.06720443069935, 41.03683277964592, 44.33447062969208, 42.260131537914276, 43.626819401979446, 42.48296298086643, 42.38163761794567, 44.40417408943176, 43.67501601576805, 44.05806966125965, 43.13484460115433, 45.16111247241497, 43.848290517926216, 44.74284611642361, 45.14433637261391, 47.904276475310326, 49.43537771701813, 51.1426755040884, 53.464358523488045, 58.1284486502409, 56.90697379410267, 69.60322871804237, 64.46708232164383, 65.14860615134239, 62.24846877157688, 67.93052047491074, 59.10110145807266, 67.54541873931885, 15.425201989710331, 1.2902426160871983, 4.103766493499279, 1.0364408162422478, 0.3581127634970471, 28.617885075509548, 82.97411844134331, 75.20700082182884, 82.49382421374321, 66.57447203993797, 39.04141925275326, 28.068141974508762, 49.00804124772549, 63.717865124344826, 72.21304267644882, 10.529597885906696, 0.44192044297233224, 0.24491268151905388, 0.21429649234050885, 0.18789908615872264, 0.157038344477769, 0.13684232428204268, 0.135649960138835], [0.11244099849136546, 0.005696544667443959, 0.06193594919750467, 0.07485605747206137, 0.023945966240717098, 0.03964448987971991, 0.04653012860217132, 0.134745430550538, 0.018918205169029534, 8.930991366505623, 63.72119374573231, 44.3097909539938, 35.079371854662895, 15.253379959613085, 31.768474616110325, 37.51823678612709, 48.24388325214386, 49.86174903810024, 61.28044791519642, 32.21258908510208, 0.10299830479198135, 0.12511584180174395, 1.054781125858426, 0.10950519586913288, 10.05820183083415, 65.24721086025238, 56.297729685902596, 63.820311427116394, 55.41249118745327, 59.974906370043755, 49.700075313448906, 51.84209257364273, 47.939675375819206, 57.57239788770676, 53.778312876820564, 55.67582845687866, 51.6243414580822, 51.03800252079964, 44.65649954974651, 41.04493774473667, 40.87780371308327, 41.160877123475075, 36.988191828131676, 37.69608624279499, 37.137398421764374, 35.52495114505291, 36.14165045320988, 35.38517564535141, 36.60696968436241, 35.54824009537697, 36.097641214728355, 36.498873084783554, 34.472172036767006, 36.81475393474102, 34.831393361091614, 36.924940422177315, 35.74804097414017, 36.05877310037613, 37.16035678982735, 36.5212082862854, 38.59300911426544, 38.020121455192566, 35.50280213356018, 35.4559126496315, 35.63344292342663, 36.854959577322006, 36.17377012968063, 36.180750355124474, 36.99562422931194, 36.863645911216736, 38.90817180275917, 41.83067098259926, 41.463762670755386, 40.59659980237484, 35.93885913491249, 38.708355724811554, 36.803909316658974, 37.56161525845528, 38.20844314992428, 38.58891673386097, 39.77877728641033, 42.41675913333893, 50.00676445662975, 48.202659264206886, 48.732502833008766, 47.96277813613415, 46.76196277141571, 51.98244944214821, 48.518490716814995, 44.95272405445576, 49.612300023436546, 48.925125896930695, 45.68214051425457, 44.07396800816059, 43.96753191947937, 40.861578583717346, 35.83717659115791, 36.97270765900612, 37.92903274297714, 37.71791987121105, 37.02364772558212, 37.0641003549099, 35.68113036453724, 38.981382474303246, 40.54450459778309, 42.93277144432068, 43.23487803339958, 42.93191649019718, 38.84438082575798, 37.191439121961594, 38.4611751884222, 37.477628365159035, 38.17839816212654, 37.615868747234344, 37.47448593378067, 37.43876785039902, 36.79417043924332, 37.070385217666626, 35.378362610936165, 36.83106645941734, 35.91238975524902, 37.02323354780674, 38.310365080833435, 36.2329937517643, 36.02582506835461, 37.22841873764992, 37.59183883666992, 38.21973994374275, 37.008068561553955, 37.2096211463213, 40.4346638917923, 39.05033357441425, 40.257137417793274, 39.60555598139763, 41.16353698074818, 40.7237333804369, 39.99585583806038, 41.6700080037117, 44.39953833818436, 41.63629241287708, 44.686506539583206, 48.30566793680191, 49.77528087794781, 50.90394951403141, 54.70576710999012, 54.05893921852112, 54.80286329984665, 53.129737079143524, 66.30327299237251, 63.71480628848076, 66.18006840348244, 56.54449224472046, 64.0040011703968, 9.601904265582561, 0.7646057778038085, 1.2835933291353285, 0.27632764424197376, 0.23139747470850125, 23.767076767981052, 73.80027830600739, 62.27650746703148, 70.5637639760971, 53.093627616763115, 40.99267154932022, 24.518155865371227, 31.521945744752884, 52.015640661120415, 41.55469559133053, 3.407059391029179, 0.2958909538574517, 0.07109473430318758, 0.05265647232590709, 0.030854019678372424, 0.0830580509500578, 0.03406904608709738, 0.03988297903561033, 0.11974729393841699, 0.08133441297104582, 0.02352373987378087, 0.03136201419692952, 0.03196676436346024, 0.03217390149075072, 0.036011027623317204, 0.1538417808478698, 0.02871250246244017, 11.134006753563881, 73.93109008669853, 51.82674519717693, 42.31943495571613, 16.480439566075802, 29.137144312262535, 46.69805780053139, 55.2624486386776, 55.32302498817444, 67.48643070459366, 34.388553723692894, 0.02163484416087158, 0.23806788318324834, 1.467600236646831, 0.27494760579429567, 11.690880171954632, 68.89311522245407, 59.99522387981415, 64.281667470932, 58.17276567220688, 62.266950979828835, 52.13178522884846, 53.473926410079, 49.86700415611267, 59.237050563097, 56.66587293148041, 58.38191784918308, 53.13234753906727, 52.77982145547867, 47.599145248532295, 42.98695653676987, 42.14204527437687, 42.439455315470695, 40.509086698293686, 40.70625811815262, 39.511997401714325, 39.9149239808321, 37.83127158880234, 38.86697441339493, 37.99342788755894, 38.883229941129684, 37.62322515249252, 37.61477440595627, 37.33915239572525, 39.557461962103844, 38.402282148599625, 37.756647393107414, 38.25941741466522, 37.58891299366951, 38.87428522109985, 39.36324678361416, 38.27307008206844, 39.087886959314346, 37.90137782692909, 36.16650111973286, 36.792677119374275, 39.7082606703043, 38.122525960206985, 40.0881414860487, 37.36750267446041, 39.32998336851597, 39.94732104241848, 43.0645065754652, 42.51624919474125, 41.274764612317085, 39.15538653731346, 39.21524852514267, 37.797164618968964, 39.04021471738815, 40.119334012269974, 39.219850078225136, 42.24976949393749, 43.57261151075363, 52.61049874126911, 49.140441343188286, 50.2945040166378, 50.86105741560459, 49.50323827564716, 54.60345380008221, 50.646140947937965, 47.8542635589838, 52.32395991683006, 49.762399569153786, 50.41794799268246, 46.26710772514343, 46.62524990737438, 44.120234325528145, 39.42432850599289, 38.39441277086735, 40.006176084280014, 40.73191814124584, 40.38161873817444, 39.668989777565, 37.643945440649986, 40.935769602656364, 41.79352417588234, 44.87183019518852, 45.392140075564384, 43.41080479323864, 40.30524663627148, 40.90525344014168, 40.389214530587196, 38.858576864004135, 41.001335084438324, 40.54666668176651, 40.13030022382736, 39.241630509495735, 38.702800422906876, 39.59256827831268, 37.368783205747604, 38.28125864267349, 37.280441746115685, 38.822980374097824, 40.450851023197174, 38.494636192917824, 38.19273479282856, 39.76835444569588, 41.40253275632858, 38.91817286610603, 39.944938570261, 39.396042823791504, 41.27034544944763, 40.14968678355217, 43.17818507552147, 40.2811711281538, 43.35541136562824, 43.654550313949585, 43.19893196225166, 43.666101694107056, 46.012992560863495, 43.209464997053146, 47.27335453033447, 50.542296320199966, 52.63949118554592, 53.21928687393665, 56.2726966291666, 55.19665136933327, 57.868231013417244, 56.43364079296589, 68.21041345596313, 65.42048156261444, 69.93799075484276, 60.05538985133171, 66.0754220187664, 12.358412202447653, 1.1774444812908769, 2.7057455107569695, 0.724529743893072, 0.4083102667937055, 25.881173126399517, 79.54371571540833, 66.84336081147194, 76.07026889920235, 59.41230855882168, 40.692415460944176, 26.03599961847067, 39.575317203998566, 59.35944199562073, 53.58106166124344, 4.6195579413324594, 0.22434527578298002, 0.07010865752818063, 0.04836346342926845, 0.019408436382946093, 0.08380022831261158, 0.03873877285514027, 0.06640957086347044, 0.26625569094903767, 0.16181819111807272, 0.17407229606760666, 0.1947479959926568, 0.19916571909561753, 0.09327812207629904, 0.12329470046097413, 0.3337280172854662, 0.2104268007678911, 13.119439166039228, 83.58281537890434, 58.26092854142189, 50.45609034597874, 24.439577981829643, 40.69618105888367, 52.90507793426514, 64.32319164276123, 57.807168290019035, 73.0783474445343, 39.530965983867645, 0.18141323496820405, 0.5800018273293972, 5.207474268972874, 0.32111453474499285, 14.68244919553399, 73.92199337482452, 61.02304972708225, 67.69771456718445, 61.219552382826805, 64.08895701169968, 52.05723702907562, 54.589371755719185, 50.61404027044773, 60.84209583699703, 58.019094318151474, 61.22299499809742, 57.117414101958275, 55.904598981142044, 48.12613517045975, 45.46072639524937, 45.25518022477627, 45.91072864830494, 42.34707087278366, 42.23875008523464, 41.775684133172035, 39.952161982655525, 40.08103586733341, 40.715199038386345, 40.36676153540611, 41.2339624017477, 42.12122619152069, 40.576384887099266, 39.41927097737789, 41.854165121912956, 40.39601616561413, 41.240258663892746, 40.575165152549744, 40.11079587042332, 40.13700686395168, 40.47473654150963, 41.20218850672245, 41.64234548807144, 39.50642690062523, 38.36448557674885, 37.01770104467869, 41.27038724720478, 41.72611579298973, 41.26487374305725, 39.370618388056755, 41.26693703234196, 41.851436868309975, 45.23013196885586, 45.75775645673275, 43.926357328891754, 40.33835805952549, 42.461638525128365, 40.03791958093643, 41.133814975619316, 42.211874127388, 42.84196771681309, 44.2781500518322, 46.86261937022209, 52.584888115525246, 52.176254242658615, 52.386842742562294, 53.19762043654919, 51.834549978375435, 55.765579640865326, 51.35839372873306, 47.61091321706772, 53.803763911128044, 52.23398454487324, 51.04023300111294, 48.93470138311386, 50.150529742240906, 47.533192187547684, 40.688539668917656, 41.677284613251686, 42.16870464384556, 42.6644716411829, 42.90658324956894, 42.741721495985985, 39.08207707107067, 43.667610213160515, 44.81906242668629, 47.198829129338264, 47.99012906849384, 45.68749442696571, 42.95155383646488, 42.26183004677296, 42.5578797608614, 40.751779675483704, 43.18681061267853, 43.53403598070145, 42.7026291936636, 41.234410777688026, 40.587822273373604, 40.26516638696194, 38.15736249089241, 40.33190220594406, 39.906260445714, 41.86765059828758, 45.056842267513275, 41.23784959316254, 40.12511730194092, 41.96329526603222, 44.073816016316414, 43.62502969801426, 41.04209549725056, 40.695417299866676, 45.16732133924961, 42.93832294642925, 47.21862606704235, 43.4584504365921, 46.021534502506256, 45.035510212183, 45.551568120718, 45.868140533566475, 49.54972878098488, 44.006647020578384, 50.099893659353256, 52.645582258701324, 54.33337189257145, 56.63955934345722, 60.064440965652466, 57.613891661167145, 61.077333614230156, 58.95184546709061, 71.16114512085915, 68.201202750206, 70.52689835429192, 60.67492000758648, 71.44052892923355, 15.198213569819927, 2.0627069659531116, 5.735468287020922, 1.4951191912405193, 0.3652521944604814, 27.72560555487871, 85.56306391954422, 70.02491489052773, 83.97356361150742, 64.91036653518677, 53.76995712518692, 34.23864796757698, 48.570620119571686, 68.49146917462349, 64.88984003663063, 6.529483180493116, 0.44192964560352266, 0.17294964927714318, 0.24213531258283183, 0.17440060735680163, 0.23313518380746245, 0.18042531766695902, 0.1819786475971341], [0.08583654052927159, 0.023905773377919104, 0.04926299836370163, 0.03020183514308883, 0.045371947780949995, 0.024378335911023896, 0.019693807007570285, 0.05017167284677271, 0.07525607506977394, 2.340174727141857, 50.83008527755737, 51.144666597247124, 43.84469211101532, 31.336737982928753, 34.73777778446674, 31.334013529121876, 48.971639201045036, 55.63862845301628, 60.73561795055866, 38.68762403726578, 0.2325796862714924, 0.20916270063025877, 0.872030466562137, 0.15870562376221642, 9.308935236185789, 59.96563866734505, 53.27356316149235, 61.38852931559086, 55.81417143344879, 60.52159443497658, 46.87560327351093, 46.73353649675846, 51.13490492105484, 53.86543080210686, 50.72760857641697, 54.50746715068817, 52.718447148799896, 50.70563055574894, 46.023875176906586, 43.17902483046055, 38.730386942625046, 40.86230054497719, 38.14870275557041, 38.547168374061584, 38.030384704470634, 37.204886600375175, 35.18469840288162, 36.291852593421936, 35.14456495642662, 36.60429082810879, 35.32701596617699, 35.5880581587553, 35.06626635789871, 37.51296266913414, 35.17183609306812, 35.131645649671555, 36.350643038749695, 37.17117860913277, 36.05848051607609, 37.02916502952576, 36.18587248027325, 37.38891452550888, 35.53979314863682, 36.9390756636858, 36.25466398894787, 36.883427649736404, 36.46290421485901, 36.222247928380966, 36.844943314790726, 37.07868777215481, 38.47300015389919, 42.25107282400131, 40.30400410294533, 40.88111713528633, 38.864930123090744, 39.45947661995888, 39.03734967112541, 37.374425902962685, 39.008163437247276, 38.3544959127903, 39.01379093527794, 41.51962727308273, 44.039781242609024, 48.892717435956, 46.75357662141323, 50.52368491888046, 48.72169241309166, 52.808270528912544, 48.06357152760029, 46.63997791707516, 48.419498428702354, 49.04160864651203, 45.441260039806366, 43.34229826927185, 43.99974659085274, 41.499818935990334, 37.04787142574787, 35.526748448610306, 37.851858884096146, 35.72129040956497, 37.33737029135227, 37.17731527984142, 38.481678888201714, 39.535939916968346, 40.16664147377014, 41.56074866652489, 42.40735463798046, 43.24463590979576, 38.948316648602486, 36.954388841986656, 38.84309269487858, 38.10545727610588, 39.101254642009735, 36.871165707707405, 37.32616849243641, 36.999424025416374, 37.559563368558884, 36.929048001766205, 37.53697358071804, 37.107334434986115, 37.18185983598232, 37.08872303366661, 36.76765166223049, 35.733966529369354, 36.26572139561176, 37.35160432755947, 37.455384358763695, 35.370782017707825, 38.254960253834724, 36.681818068027496, 38.45954887568951, 38.54819431900978, 38.92848551273346, 38.603602945804596, 40.928610786795616, 39.9801816791296, 39.087301790714264, 39.7001139074564, 41.95760317146778, 42.40748383104801, 47.60655865073204, 53.07018667459488, 56.989319175481796, 56.5748830139637, 57.09164768457413, 50.9893499314785, 57.180863097310066, 58.80267687141895, 62.115289717912674, 59.359533190727234, 68.12166541814804, 58.716197311878204, 64.06742736697197, 9.106697738170624, 0.8228298753965646, 1.9147545425221324, 0.2701113262446597, 0.11280097722192295, 25.794817060232162, 70.96700593829155, 61.78738251328468, 68.04878532886505, 54.336799308657646, 40.26052683591843, 25.51724385470152, 37.04684928059578, 55.39299063384533, 35.57140365242958, 1.0059617017395794, 0.06829363148426637, 0.0866926672460977, 0.04282909751054831, 0.055380926132784225, 0.034338416007813066, 0.05268645138130523, 0.16039645881392062, 0.07407239405438304, 0.05584889848250896, 0.027970764822384808, 0.04202886935672723, 0.0628917982976418, 0.009031447407323867, 0.025976276338042226, 0.06589901036932133, 0.035479505168041214, 3.603377756662667, 61.09996519982815, 54.557772651314735, 49.56587791442871, 28.203526809811592, 32.585527673363686, 41.45029239356518, 54.671770334243774, 58.09762470424175, 64.43331733345985, 41.29998005926609, 0.3336939378641546, 0.2594248449895531, 0.6190095841884613, 0.23460571974283084, 10.786940976977348, 64.97634619474411, 54.02905382215977, 63.49309578537941, 57.151304483413696, 62.53432363271713, 49.19654533267021, 48.63332435488701, 51.7296452075243, 56.63546696305275, 53.02480950951576, 57.90531322360039, 54.93743687868118, 54.146068543195724, 48.60718555748463, 44.321999698877335, 39.863930717110634, 42.27795258164406, 38.882021605968475, 40.62064491212368, 39.49973925948143, 38.587936386466026, 38.14204931259155, 38.58741581439972, 39.070392698049545, 38.61802697181702, 37.09278121590614, 37.934667840600014, 37.472080662846565, 39.12870056927204, 37.231804355978966, 37.83082701265812, 38.930746391415596, 40.328330397605896, 39.73220318555832, 39.65198189020157, 37.53655560314655, 38.18193957209587, 36.33453570306301, 36.73620454967022, 37.91663400828838, 38.17676804959774, 37.24614858627319, 36.99900604784489, 39.58372615277767, 40.7126721739769, 39.41322170197964, 43.77399690449238, 44.155177250504494, 43.068332970142365, 41.44051931798458, 39.61919344961643, 39.72376763820648, 38.58570210635662, 40.600532591342926, 40.036403462290764, 41.0372469574213, 43.74922603368759, 49.69215273857117, 51.824233531951904, 48.70335079729557, 51.04069657623768, 50.3355798125267, 53.72161231935024, 50.15797734260559, 47.278640046715736, 51.13831713795662, 51.798018738627434, 46.94564871490002, 47.55057245492935, 46.330822706222534, 44.46692772209644, 38.30243870615959, 39.17902506887913, 40.171197429299355, 38.293634578585625, 39.85211715102196, 38.72045047581196, 38.469443544745445, 42.09561936557293, 42.26226322352886, 42.53087840974331, 43.549341559410095, 44.45193752646446, 40.552503168582916, 38.96978169679642, 41.39047980308533, 39.18662466108799, 40.2091383934021, 37.975948825478554, 39.58725616335869, 39.08652663230896, 39.91455540060997, 39.35679852962494, 39.54555720090866, 37.791369929909706, 39.93328459560871, 39.686176255345345, 39.59324464201927, 38.469717130064964, 39.531402960419655, 39.4275963306427, 40.69360099732876, 38.33866596221924, 39.289994314312935, 38.69966559112072, 40.2085380256176, 41.95686221122742, 40.664426162838936, 40.991979986429214, 42.30499193072319, 42.13094986975193, 40.78541547060013, 42.00714871287346, 44.01437200605869, 43.98208133876324, 49.08930368721485, 56.02578967809677, 58.789069801568985, 59.06140498816967, 58.423088639974594, 54.5794352889061, 60.165017768740654, 59.252044558525085, 64.50129568576813, 60.88020399212837, 68.57423633337021, 61.90111421048641, 67.24086508154869, 10.428334269672632, 0.8617637737188488, 2.945107016712427, 0.6192819820716977, 0.17223763279616833, 27.45241541415453, 77.2981122136116, 66.07916861772537, 74.5617650449276, 58.78638334572315, 43.84805113077164, 27.30080544948578, 42.71954208612442, 64.29128855466843, 45.659155547618866, 1.8847492150962353, 0.12061149522196501, 0.07969306432642043, 0.06431831745430827, 0.0475372897926718, 0.02829026496328879, 0.08043894500588067, 0.1200094650266692, 0.13765589625108987, 0.15764702431624755, 0.11670154955936596, 0.12790818727808073, 0.1351072869147174, 0.20168455346720293, 0.13139732036506757, 0.24027575767831877, 0.14504075545119122, 4.456272628158331, 70.12091293931007, 64.49291333556175, 57.62291617691517, 40.968071669340134, 46.206345185637474, 44.09178905189037, 61.85088850557804, 63.3350470662117, 69.91158217191696, 46.80536404252052, 0.47235811594873667, 0.39263676095288247, 5.9696045983582735, 0.3614686068613082, 13.269658405333757, 66.36531606316566, 55.08812919259071, 65.13066351413727, 59.41592216491699, 64.38398078083992, 50.50986886024475, 49.42015953361988, 52.773471996188164, 57.34718017280102, 54.445625469088554, 59.37577731907368, 57.07689307630062, 55.97481921315193, 50.60861796140671, 46.81622005999088, 42.23273120820522, 45.17582908272743, 41.82232283055782, 42.537984028458595, 41.87323249876499, 40.717402920126915, 40.637740194797516, 41.46035045385361, 40.465883016586304, 40.64340569078922, 40.44373020529747, 39.59426298737526, 40.62079310417175, 42.88910038769245, 39.46385018527508, 39.18336063623428, 41.82389974594116, 41.465483978390694, 42.01179586350918, 42.1258619427681, 38.931757137179375, 39.86643098294735, 38.348507434129715, 39.33536008000374, 40.4870592802763, 41.88765272498131, 39.958610236644745, 40.02669118344784, 40.743051543831825, 42.9286752641201, 41.57974384725094, 45.42501971125603, 44.65807646512985, 44.08101662993431, 42.910455241799355, 42.39031635224819, 42.78379663825035, 40.90383231639862, 42.96450354158878, 42.98817627131939, 43.83526861667633, 44.27620455622673, 53.30608941614628, 49.060991406440735, 53.20370391011238, 55.05398042500019, 53.897235095500946, 57.19180271029472, 51.36531315743923, 49.46209028363228, 52.770230770111084, 54.93632733821869, 49.62148793041706, 49.42452169954777, 49.715320095419884, 47.3107673227787, 42.03997515141964, 40.62860928475857, 42.00819745659828, 38.72659094631672, 42.20623143017292, 42.366590425372124, 40.75321599841118, 44.76643905043602, 44.34447929263115, 44.2618565261364, 45.77244646847248, 47.56642900407314, 45.14921151101589, 41.001525074243546, 43.246604204177856, 40.497371926903725, 42.52433896064758, 40.15595264732838, 41.531969010829926, 41.15681514143944, 41.63232162594795, 41.47829309105873, 41.250917091965675, 40.23129880428314, 42.27899372577667, 40.82268767058849, 41.93100459873676, 41.013418436050415, 41.366176307201385, 42.27030359208584, 43.72637405991554, 40.092040076851845, 42.37581253051758, 40.43679937720299, 42.79417008161545, 43.34756478667259, 42.28584475815296, 43.73409524559975, 44.91684637963772, 44.895601719617844, 42.56816580891609, 43.46460610628128, 47.193615809082985, 45.769611820578575, 52.126286923885345, 59.07055489718914, 63.21188807487488, 62.31960855424404, 61.769375279545784, 58.93992930650711, 64.0118819475174, 63.00201013684273, 68.8647535443306, 64.44403275847435, 72.19140663743019, 62.273391634225845, 70.92403024435043, 13.898364119231701, 1.0615604370832443, 5.394477434456348, 2.393089975230396, 0.2356089698150754, 29.996242113411427, 83.38407084345818, 71.5399543941021, 81.3180685043335, 64.83779042959213, 54.95951749384403, 36.80180422961712, 54.25552926957607, 71.90366327762604, 59.17967364192009, 4.605746157467365, 0.2734249265631661, 0.2224262006347999, 0.21116730087669566, 0.18246600113343447, 0.14051632635528222, 0.21647018351359293, 0.3905697906157002], [0.08989196197944693, 0.05151975812623277, 0.045648824525414966, 0.032960073367576115, 0.046352606877917424, 0.019506761673255824, 0.03764582310395781, 0.003761463945011201, 0.12040767920552753, 0.9261479345150292, 41.18687152862549, 57.93871723115444, 45.774429962038994, 33.4505170583725, 22.666315734386444, 32.04071290791035, 50.00689744949341, 57.53215804696083, 57.42758385837078, 46.4357540756464, 1.577597209252417, 0.6576234684325755, 0.21333021606551483, 0.10467651591170579, 11.15959933027625, 60.353244468569756, 54.12972182035446, 59.53033022582531, 53.094604164361954, 60.04793465137482, 53.740292116999626, 42.4907373636961, 52.212131917476654, 54.453506246209145, 54.64851178228855, 56.482403576374054, 52.41518162190914, 51.44735835492611, 47.90463365614414, 42.477004900574684, 36.65717639029026, 39.83617700636387, 36.8978288769722, 37.25416235625744, 37.71418087184429, 38.16207803785801, 35.2923808246851, 37.540723979473114, 37.11439825594425, 36.075765788555145, 35.52964009344578, 35.05093418061733, 34.940462708473206, 35.912955924868584, 34.68201197683811, 36.755982488393784, 35.863417983055115, 35.65738543868065, 36.36151805520058, 37.423143088817596, 37.190530970692635, 38.04898090660572, 36.43316701054573, 35.826476365327835, 35.834493935108185, 38.55120375752449, 36.32006607949734, 37.738906145095825, 37.42019824683666, 37.395427376031876, 38.384069725871086, 41.343894302845, 40.944816917181015, 41.653144508600235, 38.05240072309971, 39.42267179489136, 36.84821113944054, 38.98667559027672, 37.61761665344238, 39.23914924263954, 37.17217035591602, 43.09140533208847, 39.06318448483944, 45.45914947986603, 50.55563360452652, 48.52447919547558, 49.59367722272873, 50.927303060889244, 48.494969978928566, 47.07351565361023, 49.197730869054794, 47.57627807557583, 46.04502484202385, 43.2801716029644, 44.8892180621624, 40.08171983063221, 37.82204568386078, 38.15233536064625, 39.47071261703968, 38.849734738469124, 36.067045256495476, 38.17741401493549, 38.5222265124321, 39.79969136416912, 41.14008463919163, 40.00287026166916, 42.42190785706043, 41.16194486618042, 37.6523581892252, 37.37290598452091, 39.15493816137314, 38.29831212759018, 36.93076930940151, 37.58982874453068, 37.86757864058018, 37.433911710977554, 36.12258307635784, 36.441591158509254, 37.47280642390251, 37.537809535861015, 35.76936163008213, 35.15227474272251, 37.66314581036568, 36.82886637747288, 37.34457090497017, 36.322585344314575, 38.3776518702507, 37.48687706887722, 38.420076593756676, 36.76504120230675, 37.65436828136444, 38.85889984667301, 40.27886465191841, 39.4356556981802, 41.78915821015835, 41.14380083978176, 42.00956918299198, 40.922211930155754, 41.32674962282181, 41.61537453532219, 48.75497102737427, 54.848719239234924, 59.767327308654785, 54.79782857000828, 54.37377892434597, 58.6136370152235, 59.42994721233845, 57.492826357483864, 62.027548626065254, 58.94997976720333, 64.78900864720345, 60.72884291410446, 66.00368946790695, 11.887523420155048, 0.8962830808013678, 2.1105319121852517, 0.14217147894669324, 0.25441671372391284, 30.130851790308952, 72.47071444988251, 61.59776508808136, 71.05992615222931, 50.542577505111694, 52.12156377732754, 37.88962125778198, 33.57081860303879, 55.10968543589115, 43.792539909482, 1.3779831142164767, 0.06776492547942325, 0.08565100361010991, 0.0531929040880641, 0.030652331770397723, 0.04057813392137177, 0.06751177890691906, 0.012345906761765946, 0.12444769366993569, 0.015243083380482858, 0.03869385807774961, 0.049802907087723725, 0.07032497131149285, 0.05974064668407664, 0.06995057265157811, 0.040148322805180214, 0.0768469279864803, 1.6713638277724385, 49.41660292446613, 64.74870041012764, 52.879607900977135, 37.065924257040024, 25.417512506246567, 36.49944305419922, 55.37296190857887, 61.683374494314194, 61.28246560692787, 52.73920923471451, 1.29860537359491, 0.4999413702171296, 0.9962536976672709, 0.16402352746808901, 14.574245251715183, 62.61761136353016, 55.6334987282753, 60.3734327852726, 55.9926288574934, 60.28659224510193, 54.94649559259415, 44.71546858549118, 53.09828236699104, 54.4326301664114, 57.48361185193062, 58.02545517683029, 52.66387067735195, 54.30276833474636, 49.47314389050007, 43.777355924248695, 39.01768572628498, 41.242006570100784, 39.06464360654354, 39.50869917869568, 39.24816615879536, 39.430867955088615, 38.48925568163395, 39.819606095552444, 39.843556210398674, 37.79735080897808, 38.43827001750469, 37.232617512345314, 36.94154933094978, 37.66414895653725, 36.62338860332966, 36.90962344408035, 38.19099448621273, 36.983115300536156, 38.715628534555435, 38.88665355741978, 38.40961575508118, 38.6909868568182, 37.77539938688278, 37.5293055921793, 38.257456719875336, 38.78230355679989, 37.921300157904625, 40.99142901599407, 38.531441017985344, 40.1101841032505, 39.69533756375313, 42.73708574473858, 43.12885232269764, 42.632405161857605, 40.205961763858795, 40.76546274125576, 38.3719027787447, 40.90488865971565, 40.02165645360947, 40.68923123180866, 39.14801113307476, 43.97717200219631, 42.74020537734032, 51.73065595328808, 50.97187466919422, 49.47369106113911, 50.68800710141659, 51.97439007461071, 51.91280297935009, 47.06231005489826, 50.924498811364174, 51.16111971437931, 48.6628183722496, 45.32695457339287, 45.1360110193491, 41.870405450463295, 39.187099635601044, 39.57780607044697, 41.058335825800896, 41.040936559438705, 38.45421776175499, 39.128977954387665, 40.649264976382256, 40.45565016567707, 41.85893386602402, 43.26594516634941, 42.57163502275944, 41.87575176358223, 40.533766373991966, 38.42813216149807, 40.41401959955692, 40.516564697027206, 38.077213391661644, 38.26094873249531, 38.061014860868454, 39.20449510216713, 38.26401136815548, 38.4092927724123, 39.250617027282715, 38.82073849439621, 36.560023203492165, 38.77354122698307, 38.67244005203247, 39.36578884720802, 40.310125574469566, 40.265774354338646, 40.07054463028908, 40.221559926867485, 40.970138758420944, 38.867377191782, 40.71788929402828, 41.82572364807129, 41.72667816281319, 42.20889508724213, 43.090269193053246, 42.705251052975655, 42.39138029515743, 42.44559198617935, 44.79124031960964, 43.248910680413246, 50.81922546029091, 57.54728503525257, 61.710121259093285, 57.06042096018791, 57.762414291501045, 59.6369107067585, 61.88348315656185, 59.229097589850426, 64.10308465361595, 62.71427437663078, 67.49176561832428, 62.63889022171497, 68.9462211728096, 12.872712705284357, 0.6611488480120897, 2.382909134030342, 0.5942177551332861, 0.14508267195196822, 32.48136766254902, 80.73282390832901, 65.66480845212936, 79.67275679111481, 49.78270947933197, 53.541467785835266, 42.57120564579964, 40.32226972281933, 61.62062466144562, 53.178222477436066, 2.7544059371575713, 0.30160130525473505, 0.05430752455140464, 0.08845114163705148, 0.04438638308783993, 0.05031974615121726, 0.048942145658656955, 0.03511892158712726, 0.18199089303379878, 0.1738645986188203, 0.16161720268428326, 0.20044500357471406, 0.13320844271220267, 0.16429788462119177, 0.2124599291710183, 0.11173592851264402, 0.1211425093060825, 2.116062040440738, 57.384041994810104, 74.55742567777634, 60.18256902694702, 46.29089064896107, 31.793807856738567, 45.11443957686424, 62.728683203458786, 66.93592384457588, 67.0359268784523, 59.07722733914852, 1.9136840687133372, 0.840824581682682, 2.9963216185569763, 0.2672980522038415, 17.771686278283596, 63.94511952996254, 57.46541082859039, 61.722083017230034, 56.38987474143505, 61.4022845774889, 54.70807358622551, 45.56813143193722, 52.626047506928444, 54.727133363485336, 59.371308758854866, 60.88372640311718, 56.19137339293957, 56.500437408685684, 52.19249077141285, 45.97453862428665, 40.78518368303776, 44.08930018544197, 41.5794512629509, 40.98569132387638, 41.934230625629425, 41.942050606012344, 39.22654531896114, 41.20556652545929, 42.362140864133835, 39.631132408976555, 41.6524301469326, 39.687540382146835, 39.14211004972458, 40.34876190125942, 39.794250056147575, 41.88116267323494, 39.65118393301964, 38.220317512750626, 41.26589588820934, 41.442597806453705, 40.47930009663105, 40.88351480662823, 40.07226973772049, 40.70543356239796, 40.311041325330734, 42.346284314990044, 39.01191383600235, 42.621978521347046, 40.301652029156685, 40.276508778333664, 43.2013638317585, 44.02071386575699, 46.15385100245476, 45.711455941200256, 41.52690768241882, 43.18430654704571, 41.311679631471634, 43.120241984725, 41.45865574479103, 43.07023286819458, 39.38418745994568, 46.25100038945675, 46.240972727537155, 52.75940515100956, 49.21841315925121, 52.0426420122385, 53.798379600048065, 55.18389545381069, 51.85953363776207, 49.8497910797596, 52.91091062128544, 53.85235570371151, 50.34224845468998, 48.48784536123276, 48.71497057378292, 44.8833891749382, 41.24576456844807, 41.484281569719315, 43.93215201795101, 42.52551689743996, 39.0777301043272, 42.11165450513363, 42.15693287551403, 42.777393981814384, 45.15157498419285, 45.73840789496899, 46.07946619391441, 45.446241572499275, 44.01449739933014, 39.937661960721016, 43.85927572846413, 43.99906262755394, 40.90975619852543, 40.961281433701515, 40.99372789263725, 39.6383748203516, 39.94374543428421, 40.236660316586494, 41.654113456606865, 41.53251238167286, 39.27837833762169, 39.96030494570732, 41.115309968590736, 41.184150874614716, 44.43824306130409, 41.2084923684597, 43.267681673169136, 42.5082316249609, 43.88495475053787, 41.50794669985771, 42.577566504478455, 45.0850785523653, 44.42310847342014, 44.274639040231705, 45.38986399769783, 44.17364425957203, 45.628859773278236, 44.900226071476936, 46.82806022465229, 47.954688370227814, 51.57024756073952, 62.27324724197388, 64.6887244284153, 60.995140224695206, 59.95014309883118, 62.08673804998398, 62.97696188092232, 62.18323387205601, 67.36178979277611, 64.26231890916824, 71.27585336565971, 64.13624167442322, 71.0996264219284, 15.25990230962634, 1.073932098224759, 7.612701505422592, 1.9453445635735989, 0.2414068055804819, 35.895043686032295, 85.88763490319252, 69.59797739982605, 84.63045716285706, 62.041243091225624, 67.38746121525764, 50.4961021989584, 50.40272980928421, 71.48703843355179, 65.507572889328, 6.022255998104811, 0.5942729709204286, 0.12932064273627475, 0.18801379250362515, 0.16447978501673788, 0.17118335264967754, 0.162759798404295, 0.20247339707566425], [0.1375883904984221, 0.02637770401634043, 0.05369059574150015, 0.012919089676870499, 0.10397404344985262, 0.041140125249512494, 0.09849244423094206, 0.09659518080297858, 0.13112081098370254, 0.5685436015482992, 33.370542749762535, 58.68330627679825, 43.01368050277233, 29.922461472451687, 22.272174283862114, 32.00227037072182, 48.69004771113396, 59.48798529803753, 52.21357204020023, 51.47718295454979, 3.4405652806162834, 0.33862901211250573, 0.5069851828739047, 0.07935017725685611, 17.66374547034502, 64.42821800708771, 57.32262969017029, 58.98239202797413, 55.76558344066143, 58.04482273757458, 58.85575622320175, 53.88849176466465, 49.2701131850481, 53.59065234661102, 52.62138515710831, 53.75460594892502, 52.43382342159748, 48.814548030495644, 45.72868041694164, 41.09496206045151, 38.41136746108532, 37.70159974694252, 37.90471404790878, 37.4634513258934, 37.2808863222599, 36.62438414990902, 35.48990182578564, 37.170661836862564, 34.77442301809788, 35.19020810723305, 35.152244344353676, 33.90846848487854, 36.03864178061485, 35.66063426434994, 35.76160244643688, 35.52128054201603, 34.68896180391312, 36.91906973719597, 36.57499060034752, 37.83213414251804, 37.35684424638748, 38.057070672512054, 36.42429068684578, 35.29211483895779, 35.11371061205864, 37.577160224318504, 36.3046845048666, 37.861324176192284, 39.09691147506237, 36.46605044603348, 40.09630344808102, 41.91887564957142, 42.11702361702919, 41.0971013456583, 39.197210893034935, 38.594719022512436, 37.065950855612755, 39.33836571872234, 37.84057728946209, 37.30296313762665, 34.779788330197334, 40.095573887228966, 42.238795682787895, 38.415771424770355, 45.01602865755558, 53.94645385444164, 48.495851531624794, 50.38478337228298, 46.22217893600464, 44.26253288984299, 47.509432062506676, 46.79566316306591, 47.52666413784027, 43.139328360557556, 43.56199108064175, 38.85081768035889, 36.65563367307186, 36.0006096214056, 37.10642248392105, 36.80398531258106, 39.30021196603775, 37.03496731817722, 38.85206401348114, 39.15459617972374, 41.49711348116398, 41.27084702253342, 42.47633993625641, 40.451177805662155, 39.151985719799995, 36.75451196730137, 39.67555582523346, 36.12864375114441, 39.84273545444012, 35.8966775983572, 37.814256101846695, 35.67600063979626, 37.17097721993923, 36.52407333254814, 36.982427537441254, 34.972928166389465, 36.642019003629684, 35.78400984406471, 35.142057090997696, 36.02135270833969, 37.044907584786415, 35.88383808732033, 35.80936588346958, 36.96644939482212, 37.24986098706722, 38.226260393857956, 38.88748951256275, 37.39384666085243, 38.7631031870842, 38.23482133448124, 40.63272446393967, 39.29480105638504, 40.76457738876343, 40.44034458696842, 40.69611646234989, 40.36715671420097, 48.93568553030491, 56.98824003338814, 58.539077416062355, 55.88189899921417, 59.623847007751465, 57.32364043593407, 60.69072715938091, 59.67386372387409, 60.593425780534744, 57.603472620248795, 65.01581087708473, 58.422351479530334, 66.56457737088203, 9.268381912261248, 0.5486239423044026, 0.5777479545213282, 0.45544068154413253, 0.1704416354186833, 32.318949177861214, 70.24701297283173, 61.05718709528446, 68.38895827531815, 49.2940367013216, 41.86167731881142, 30.33740870654583, 32.274453565478325, 58.90981212258339, 39.40982088446617, 1.6533473320305347, 0.25842754694167525, 0.09009251254610717, 0.025692295384942554, 0.0938685450819321, 0.1288866496179253, 0.05381687587941997, 0.020313932618591934, 0.10857532193767838, 0.051328057670616545, 0.016192259645322338, 0.026683468859118875, 0.03594880225136876, 0.034062823178828694, 0.05295118287904188, 0.07708296805503778, 0.07205031623016112, 0.6734676088672131, 40.104362815618515, 67.0554806292057, 48.814301043748856, 35.06650194525719, 23.86001408100128, 39.91582453250885, 54.49181579053402, 63.30834209918976, 58.925946056842804, 56.22828461229801, 3.943141750060022, 0.3694567282218486, 0.6222789525054395, 0.21230813028523698, 20.538940988481045, 66.41429543495178, 57.62494906783104, 60.53306981921196, 59.010267332196236, 60.4792533069849, 58.76229643821716, 55.27793660759926, 49.926356971263885, 54.575411304831505, 53.74391712248325, 54.4472935795784, 54.62274916470051, 52.46998228132725, 48.41108188033104, 43.545104786753654, 41.0311558842659, 39.371211156249046, 39.6681310236454, 39.58099789917469, 39.09192234277725, 39.31625850498676, 38.718698769807816, 37.99952656030655, 37.09450252354145, 37.60312803089619, 37.3173263669014, 37.59981460869312, 38.249370753765106, 38.390381187200546, 37.08696372807026, 36.63212053477764, 37.31956444680691, 38.37218776345253, 38.44263978302479, 39.46621745824814, 39.26651157438755, 38.1259685754776, 38.03186662495136, 35.975667759776115, 37.42209814488888, 40.48778124153614, 37.864257618784904, 39.19586956501007, 40.65216422080994, 38.72495323419571, 41.24818503856659, 44.393739849328995, 42.82356910407543, 42.83886708319187, 39.85665410757065, 40.9372553229332, 38.795659840106964, 39.93663601577282, 38.39303344488144, 39.021059945225716, 37.487637028098106, 42.727631852030754, 44.30107802152634, 40.47795496881008, 49.46707561612129, 53.558882251381874, 49.629003927111626, 51.95402316749096, 48.96264508366585, 46.49110950529575, 49.20686557888985, 48.06146644055843, 47.950204610824585, 45.50578437745571, 44.77140158414841, 41.11623711884022, 40.10328367352486, 39.17221203446388, 39.34402361512184, 39.17097710072994, 40.56864470243454, 38.43024484813213, 40.65685696899891, 41.74311228096485, 44.60654743015766, 41.96340166032314, 44.20884557068348, 43.14554862678051, 40.38447618484497, 38.53259235620499, 41.41803212463856, 37.515299543738365, 40.82215189933777, 38.319359198212624, 38.775490522384644, 38.45743618905544, 38.91587398946285, 38.24204854667187, 38.74958351254463, 38.606790974736214, 37.17477321624756, 39.02723841369152, 38.79288598895073, 37.73264408111572, 39.524764716625214, 38.004660084843636, 40.04211075603962, 38.72452385723591, 39.65081915259361, 38.70009496808052, 41.09868586063385, 39.7124632447958, 41.856384202837944, 40.78949265182018, 42.30318322777748, 40.846751779317856, 42.785840928554535, 42.298452481627464, 41.71638071537018, 42.78766103088856, 51.96775563061237, 57.46682055294514, 61.169045493006706, 57.611946165561676, 61.74914516508579, 59.150472208857536, 62.24088437855244, 61.45092956721783, 63.54566976428032, 58.66548143327236, 68.16293120384216, 60.57811640202999, 70.88359281420708, 10.884031467139721, 0.24764256784692407, 1.654136145953089, 0.2286250633187592, 0.20701640954939649, 34.83365423977375, 77.16926872730255, 65.25598078966141, 74.98815536499023, 56.15573510527611, 52.37640090286732, 38.717361241579056, 36.67969398200512, 66.45874544978142, 48.36935251951218, 2.6924497867003083, 0.17251264303922653, 0.07607101259054616, 0.045116808541934006, 0.08046520219068043, 0.035136473379679956, 0.09616305789677426, 0.04875722101132851, 0.24071531690424308, 0.13035770505666733, 0.16374876955524087, 0.17400738783180714, 0.31461997074075043, 0.1460273368866183, 0.2452056368929334, 0.17623914463911206, 0.1503768120892346, 1.0611868696287274, 47.19519652426243, 75.41393771767616, 56.5022537112236, 41.88634179532528, 29.63630072772503, 44.22680340707302, 60.485541969537735, 66.545000821352, 62.031956389546394, 61.72327995300293, 4.921226603910327, 0.537079805508256, 2.673739353194833, 0.4918004258070141, 23.94542019814253, 67.89658069610596, 60.588417649269104, 60.46558924019337, 61.79318480193615, 61.400282084941864, 60.773178935050964, 53.56680862605572, 51.44996501505375, 56.82216614484787, 54.63881850242615, 60.88551610708237, 56.41714587807655, 54.82727698981762, 51.798611506819725, 45.54208762943745, 40.91731779277325, 41.19826331734657, 43.04785206913948, 42.5061721354723, 41.019361317157745, 41.17928333580494, 39.998948872089386, 40.95458619296551, 39.624657556414604, 39.19523499906063, 40.43129727244377, 38.5400665551424, 41.12070947885513, 41.51334621012211, 41.07374779880047, 38.99020940065384, 39.46999825537205, 40.165281146764755, 39.85555216670036, 41.85001194477081, 42.01523467898369, 40.76762482523918, 40.32117158174515, 38.07655982673168, 39.41906578838825, 41.19405694305897, 39.493955969810486, 41.18749849498272, 44.69367675483227, 40.10586753487587, 43.65766994655132, 46.79963394999504, 45.970742627978325, 45.4069858789444, 41.533211544156075, 41.968865767121315, 40.26380605995655, 43.48306931555271, 41.58261649310589, 40.63354901969433, 40.37022314965725, 44.29362662136555, 46.27108611166477, 44.510028809309006, 53.65101970732212, 53.02574425935745, 51.772430911660194, 56.58419631421566, 50.22533632814884, 48.84822182357311, 50.025520250201225, 49.28826101124287, 52.483821138739586, 46.83787129819393, 48.30446720123291, 43.46752054989338, 42.26857848465443, 39.4028976559639, 40.948597714304924, 42.330617755651474, 42.87555031478405, 40.269220769405365, 42.826092168688774, 42.50092841684818, 45.42758457362652, 45.645966455340385, 46.172602996230125, 45.42346179485321, 42.57474705576897, 40.74289195239544, 43.22792820632458, 39.47317488491535, 42.84908853471279, 40.87145425379276, 41.67843975126743, 39.27635684609413, 41.52210853993893, 40.95194913446903, 41.3078760355711, 39.56397861242294, 41.65836922824383, 41.75649896264076, 39.343066066503525, 40.3547427803278, 41.79928086698055, 41.97312913835049, 41.33825160562992, 42.345607951283455, 43.17712873220444, 43.20830225944519, 44.89188551902771, 41.39796920120716, 43.323128297924995, 41.99753522872925, 44.93264213204384, 42.74950347840786, 45.466908663511276, 43.761886954307556, 44.026557952165604, 44.019809514284134, 54.66645821928978, 60.90808689594269, 66.68481811881065, 63.12382400035858, 64.77434143424034, 61.34107746183872, 65.22858425974846, 64.58062022924423, 67.14549779891968, 61.614636182785034, 70.36691173911095, 63.43828372657299, 72.15828761458397, 12.978683318942785, 0.5924624868202955, 3.843797743320465, 2.038891981355846, 0.28216166712809354, 37.44803175330162, 83.01308915019035, 69.75085839629173, 78.97346511483192, 64.53908085823059, 55.49105577170849, 43.07044565677643, 47.20524698495865, 75.62239453196526, 60.75990244746208, 4.929131604731083, 0.5876965331844985, 0.15099138458026573, 0.1430106846964918, 0.18559266929514706, 0.15198506094748154, 0.2609227958600968, 0.07143884591641836], [0.027322205678501632, 0.06747624487616122, 0.019505681848386303, 0.03699292239616625, 0.020062019866600167, 0.055259455111809075, 0.06709455090458505, 0.019215604152122978, 0.11835108409286477, 0.21667014778358862, 25.313422791659832, 60.742590576410294, 44.74612534046173, 40.19129455089569, 25.458618700504303, 26.78667973726988, 46.72968730330467, 63.88278007507324, 52.40493357181549, 59.175091087818146, 6.779676480218768, 0.2623965824022889, 0.28472584672272205, 0.12567876081448048, 35.14698922634125, 61.96489758789539, 58.69532123208046, 56.28612890839577, 55.42843133211136, 55.28902441263199, 54.02263976633549, 59.352587163448334, 55.842301324009895, 52.939420491456985, 53.64402808248997, 52.26939104497433, 51.5474221855402, 46.404595747590065, 41.18083745241165, 39.22561436891556, 39.70241278409958, 37.84845806658268, 38.23200948536396, 36.486132368445396, 36.274563521146774, 37.40029491484165, 35.907066240906715, 35.35834148526192, 36.374961733818054, 35.05487456917763, 36.562629863619804, 36.33009374141693, 33.198696970939636, 34.51531112194061, 34.820392951369286, 36.12859435379505, 36.37620806694031, 36.42918482422829, 37.63761878013611, 36.97965368628502, 34.68415506184101, 37.13941991329193, 36.82757064700127, 36.32196597754955, 36.56831055879593, 36.43265783786774, 37.84379571676254, 37.85534709692001, 37.515299543738365, 35.130410715937614, 37.802294343709946, 40.1241597533226, 41.23309604823589, 41.9768301397562, 40.48852600157261, 38.41545224189758, 37.28157788515091, 37.342955991625786, 38.36090236902237, 37.07432180643082, 36.12321384251118, 36.84707500040531, 41.78241737186909, 44.90426145493984, 38.97950157523155, 42.49635726213455, 55.523912608623505, 51.9828712195158, 44.35434356331825, 44.67716284096241, 45.98318696022034, 44.926148280501366, 44.89315465092659, 43.63111697137356, 42.297517731785774, 39.683603793382645, 37.205760553479195, 36.79932676255703, 38.37009787559509, 37.95505754649639, 38.35567764937878, 38.15490782260895, 39.51153002679348, 41.46910898387432, 39.80030693113804, 39.94770482182503, 43.66167493164539, 42.868668884038925, 37.28425294160843, 37.629992589354515, 39.088399931788445, 37.05932781100273, 37.92132295668125, 35.29782973229885, 35.89714877307415, 37.860271632671356, 37.662013471126556, 35.615287497639656, 36.68841451406479, 38.19534905254841, 38.26607845723629, 37.95004941523075, 37.38163411617279, 35.7657328248024, 36.210996732115746, 37.02989459037781, 36.23602978885174, 34.74787384271622, 37.41192989051342, 38.08601371943951, 39.39472809433937, 36.694619581103325, 40.317155197262764, 39.20612521469593, 39.45928283035755, 40.56825712323189, 41.404284462332726, 40.32184034585953, 44.316649585962296, 43.8820631057024, 50.905686020851135, 55.665352419018745, 55.846211314201355, 54.10294845700264, 56.553672552108765, 57.21151605248451, 60.294701009988785, 55.6566508859396, 61.30926936864853, 59.69409003853798, 63.10936577618122, 61.2723695486784, 69.88538637757301, 8.815025389194489, 0.26469694334082305, 0.4248450498562306, 0.3809404541971162, 0.37509206333197653, 35.90251788496971, 70.85280686616898, 60.280713960528374, 70.29580995440483, 42.66833983361721, 29.075207635760307, 34.94887165725231, 35.069218799471855, 57.52997696399689, 45.25888882577419, 2.264381619170308, 0.2084510849090293, 0.11078610565164126, 0.1116227064630948, 0.097463055717526, 0.08626056660432369, 0.016306815705320332, 0.03436258033616468, 0.12752614449709654, 0.018929140715044923, 0.029085507740091998, 0.048392503667855635, 0.06198364331794437, 0.04857986255956348, 0.14027607830939814, 0.05189646115468349, 0.16688814328517765, 0.2524963620817289, 30.095646679401398, 67.65532404184341, 50.04420004785061, 45.71160413324833, 22.263292260468006, 31.205907203257084, 54.520960226655006, 67.87090927362442, 57.39042565226555, 63.35471101105213, 7.239930583164096, 0.3558249893831089, 0.42080242303200066, 0.14027521741809323, 38.39713342487812, 64.33068484067917, 60.72413116693497, 58.42988267540932, 56.441278383135796, 57.33326531946659, 55.42656183242798, 60.128102749586105, 56.509192138910294, 53.99544082581997, 55.152839720249176, 54.46443445980549, 53.8755002617836, 47.2720929980278, 44.88800972700119, 40.41377641260624, 41.10891491174698, 40.194068402051926, 40.18735036253929, 38.926141038537025, 39.089532271027565, 39.31703746318817, 37.92549133300781, 37.558518424630165, 38.83966147899628, 38.51386696100235, 39.14731577038765, 37.99025505781174, 36.434234753251076, 36.2150739133358, 38.68626371026039, 37.69526928663254, 38.652677312493324, 37.870439887046814, 39.43601667881012, 38.45473073422909, 36.19763284921646, 38.057796433568, 39.279514476656914, 37.66208566725254, 39.10185880959034, 36.29548519849777, 38.316383957862854, 39.60524819791317, 39.66086961328983, 38.375364392995834, 39.84416417777538, 43.17686654627323, 42.964788526296616, 43.64953078329563, 42.95654296875, 40.81316538155079, 39.75414700806141, 39.22398425638676, 39.4861625880003, 38.97308371961117, 37.7929924428463, 39.00023326277733, 44.07402880489826, 47.22185969352722, 42.22236916422844, 46.668050810694695, 56.19110740721226, 51.26955069601536, 43.99264857172966, 45.65233111381531, 48.86001259088516, 44.56118166446686, 46.09895534813404, 45.37142738699913, 44.84267815947533, 41.902175545692444, 40.26069402694702, 38.15139681100845, 39.23016272485256, 39.662936702370644, 39.229968935251236, 39.451139867305756, 40.24220421910286, 42.22801186144352, 42.215548530220985, 40.807021111249924, 45.69832384586334, 43.63258749246597, 39.556512013077736, 39.565498530864716, 40.505492091178894, 39.30773936212063, 39.69395063817501, 37.740448862314224, 37.57139593362808, 39.93454232811928, 38.34401987493038, 38.516633212566376, 38.77539932727814, 38.6601173132658, 40.568648502230644, 39.53662768006325, 38.7993798404932, 38.179439306259155, 39.65841494500637, 38.21701169013977, 40.10577253997326, 37.694178745150566, 39.587354958057404, 40.30661456286907, 40.72996124625206, 39.438919723033905, 42.85327970981598, 40.49187362194061, 42.82496742904186, 42.60867923498154, 42.88906238973141, 41.798657700419426, 46.39597401022911, 46.11706517636776, 53.51099342107773, 58.87495659291744, 59.24491614103317, 56.96776293218136, 59.58076111972332, 59.42458190023899, 61.86736062169075, 58.4285793453455, 62.745413705706596, 61.11878179013729, 67.623580545187, 62.32864826917648, 70.05698516964912, 9.846318550407887, 0.36339706275612116, 1.08581168577075, 0.37218753481283784, 0.273406402557157, 38.983662351965904, 77.19422578811646, 66.63625672459602, 74.30389568209648, 49.93193507194519, 31.90630652010441, 37.86184474825859, 42.14998684823513, 64.97633099555969, 53.53634566068649, 3.23979165405035, 0.22421807167120278, 0.05969471145363059, 0.03793688600126188, 0.057919145401683636, 0.03752798860659823, 0.02772597668808885, 0.03771399307879619, 0.2585170202655718, 0.11941406221012585, 0.14025304204551503, 0.17852641409263015, 0.16410367941716686, 0.15368138789199293, 0.2005549898603931, 0.17887737572891638, 0.20806582120712847, 0.4826700798003003, 34.15605179965496, 77.7717188000679, 56.98748767375946, 54.893043860793114, 33.94423596560955, 38.31101484596729, 59.25286151468754, 75.17132833600044, 63.093076050281525, 71.63525328040123, 9.167899154126644, 0.3719513240503147, 1.063360827974975, 0.20547959982650355, 43.67370128631592, 63.80461826920509, 62.42453992366791, 60.490694493055344, 57.76296906173229, 58.8967864215374, 58.04665043950081, 60.87747573852539, 58.37420046329498, 55.65317027270794, 56.65140710771084, 55.9402334690094, 57.948881685733795, 49.53260689973831, 46.354259848594666, 44.36019144952297, 43.319491893053055, 42.96714819967747, 42.368820905685425, 41.41288340091705, 40.50750978291035, 42.81703345477581, 41.099673807621, 40.22820197045803, 42.46896453201771, 40.760921984910965, 42.12588474154472, 41.200383603572845, 38.50496783852577, 38.10556747019291, 39.81324523687363, 40.16834378242493, 41.46374747157097, 40.766557082533836, 41.40993855893612, 40.55183820426464, 37.11104303598404, 40.7240791618824, 42.17064633965492, 40.42020566761494, 40.12692600488663, 38.67635004222393, 40.82279786467552, 40.99103383719921, 40.615196004509926, 39.999264255166054, 41.503584533929825, 45.99377699196339, 43.70122700929642, 44.78541523218155, 45.21977372467518, 42.9060322791338, 41.11197754740715, 40.37321738898754, 41.796750202775, 41.58055700361729, 40.20197577774525, 40.82242548465729, 46.338034719228745, 48.394518569111824, 43.53390298783779, 51.73543609678745, 57.319247871637344, 51.54901050031185, 48.09266276657581, 47.32166513800621, 51.496292129158974, 47.18221642076969, 48.81154239177704, 48.879292756319046, 47.83656410872936, 44.58155997097492, 43.13671790063381, 40.534150153398514, 40.992082580924034, 42.51175783574581, 41.733912974596024, 40.303855910897255, 43.3094148337841, 44.70128774642944, 44.689945355057716, 43.131686970591545, 47.89021722972393, 45.9988497197628, 40.57116016745567, 41.37882962822914, 43.42602677643299, 40.42092762887478, 41.37568719685078, 38.991296142339706, 38.7769990414381, 41.644431576132774, 42.45492048561573, 39.8287446051836, 42.461262345314026, 42.33568288385868, 42.44217596948147, 42.202530428767204, 42.21877075731754, 41.28083288669586, 42.33050376176834, 41.44495747983456, 42.99126170575619, 39.83141586184502, 42.00470544397831, 43.855688720941544, 42.542023211717606, 41.67786978185177, 46.43064334988594, 42.05608248710632, 43.98516297340393, 44.5804238319397, 45.72037786245346, 45.095387399196625, 48.6166812479496, 48.59014727175236, 57.11551420390606, 63.12813296914101, 62.09188297390938, 59.50576074421406, 61.171332970261574, 62.31967695057392, 63.951222002506256, 62.123463079333305, 64.35967728495598, 64.5444917678833, 70.6248115003109, 63.66654507815838, 74.61576014757156, 11.563600301742554, 0.44571825012099, 3.165584485977888, 1.8255292740650475, 0.3822254383703694, 43.03695045411587, 84.12128448486328, 70.32540276646614, 82.51343876123428, 56.274687722325325, 42.755947932600975, 46.09817638993263, 51.680745631456375, 76.16641134023666, 64.86948072910309, 5.904825199395418, 0.48823277349583805, 0.2547554299235344, 0.1883442560210824, 0.2588784758700058, 0.11250908311922103, 0.08861788737704046, 0.09344753954792395], [0.026425182913953904, 0.02777378398604924, 0.05393243198341224, 0.059166684513911605, 0.04586611052218359, 0.04714563619927503, 0.06709343768307008, 0.06420996389351785, 0.12457272328902036, 0.03208935602742713, 18.01980346441269, 63.03837798535824, 50.01983195543289, 37.62160263955593, 19.890762269496918, 38.19784551858902, 44.794192761182785, 64.14854541420937, 50.573766231536865, 59.60339270532131, 15.016532968729734, 0.23996255651582032, 0.05898985669773538, 0.3126775921555236, 37.107266038656235, 62.01260782778263, 61.083489283919334, 56.4178716391325, 53.06390181183815, 54.60318021476269, 56.69087938964367, 54.66389335691929, 56.83369852602482, 55.717394426465034, 52.17528149485588, 53.98312948644161, 50.51097460091114, 43.313944190740585, 37.210270911455154, 38.92511889338493, 39.70698393881321, 37.49881982803345, 36.744792088866234, 37.052822560071945, 38.04811455309391, 37.8507911413908, 37.65632517635822, 37.166383266448975, 35.5830804258585, 36.445561945438385, 35.73550924658775, 34.95819255709648, 35.22975258529186, 35.141791105270386, 34.73056197166443, 35.56019425392151, 35.21749824285507, 35.11298485100269, 36.76975674927235, 36.1802563816309, 36.79607033729553, 36.57056763768196, 35.435712933540344, 34.865010157227516, 38.005936816334724, 36.753960996866226, 35.43388523161411, 35.644021555781364, 37.32158213853836, 37.814392894506454, 39.42034251987934, 42.52664543688297, 41.52310408651829, 41.338494792580605, 41.72834247350693, 39.82871800661087, 37.603306621313095, 39.2400573939085, 38.511666879057884, 37.15985521674156, 34.662085846066475, 38.022306337952614, 39.66167896986008, 45.18090561032295, 45.19412510097027, 40.59327498078346, 41.12866245210171, 51.13412596285343, 42.40026041865349, 43.23529601097107, 48.571991845965385, 43.471118956804276, 45.83308361470699, 41.5953154116869, 43.37716519832611, 40.65499126911163, 36.79917477071285, 37.41422116756439, 37.714956030249596, 38.3764511346817, 36.85864917933941, 36.29452005028725, 41.57000117003918, 41.734308153390884, 41.006043031811714, 40.30493125319481, 41.886045411229134, 40.47743059694767, 39.292695969343185, 37.84440368413925, 37.31406234204769, 35.143504813313484, 36.019992381334305, 36.621971279382706, 36.89586438238621, 35.96851274371147, 37.92832978069782, 37.44781136512756, 38.88431288301945, 37.16566130518913, 38.35788533091545, 36.460327953100204, 37.4652486294508, 36.56447656452656, 34.61420841515064, 37.96467863023281, 38.089596927165985, 36.31409280002117, 36.69944152235985, 35.62769003212452, 38.930579200387, 37.960343062877655, 38.49362924695015, 36.58451668918133, 39.62813436985016, 39.404352977871895, 40.4723958671093, 41.61497175693512, 46.095478534698486, 50.39299473166466, 55.25606878101826, 55.0387242436409, 54.281573072075844, 54.44168508052826, 58.571140095591545, 58.28081287443638, 58.40601995587349, 57.25797235965729, 58.97465944290161, 58.005118668079376, 63.73061344027519, 58.83608087897301, 64.42273870110512, 6.019503520801663, 0.13854436576366425, 0.7012241100892425, 0.3236361447488889, 0.6648903409950435, 39.71466712653637, 70.35846099257469, 59.478318616747856, 63.89335870742798, 46.93250522017479, 36.0248789191246, 38.69937680661678, 42.99373537302017, 61.03667959570885, 39.08343359827995, 1.7232483811676502, 0.20661290385760367, 0.05183384244446643, 0.012740173642669106, 0.01802230119210435, 0.011397177640901646, 0.0871586098219268, 0.05189402691030409, 0.05358513655664865, 0.027994632291665766, 0.053209290708764456, 0.032638500779285096, 0.026112950254173484, 0.025558974120940547, 0.01875264129921561, 0.08156536932801828, 0.22323203942505643, 0.006011257491991273, 22.737016640603542, 71.85394674539566, 54.17449861764908, 41.76910288631916, 22.3764805868268, 37.71639995276928, 53.681611865758896, 69.53612431883812, 57.32891455292702, 65.95021113753319, 16.545881554484367, 0.3771407174644992, 0.10518736584344879, 0.3387302707415074, 43.24862949550152, 63.908953070640564, 62.45657980442047, 57.44007758796215, 56.45015090703964, 56.1006760597229, 58.11302527785301, 56.507546827197075, 58.372213169932365, 56.211120933294296, 53.56476813554764, 55.04476971924305, 52.29837588965893, 45.95549784600735, 39.57107663154602, 40.38452938199043, 42.01995022594929, 39.585846439003944, 38.957363963127136, 39.39418092370033, 41.22342176735401, 40.60280106961727, 38.76396954059601, 38.56430545449257, 38.199840411543846, 38.24928715825081, 36.158301159739494, 37.450915798544884, 38.79656799137592, 37.71380849182606, 36.52015954256058, 37.83822141587734, 37.39315889775753, 37.787604331970215, 38.444505482912064, 36.96098908782005, 38.258501663804054, 38.886205181479454, 38.83915230631828, 36.471537351608276, 39.60834503173828, 37.87915661931038, 38.517602160573006, 39.011807441711426, 39.785461127758026, 38.09542581439018, 42.212520092725754, 42.77366258203983, 43.91415998339653, 42.61717177927494, 42.105175852775574, 40.892052948474884, 40.01543238759041, 40.96451885998249, 39.49157729744911, 38.34303952753544, 36.622982025146484, 39.676862955093384, 42.86568604409695, 46.31419859826565, 44.51075457036495, 42.11930349469185, 46.07299514114857, 53.22936773300171, 44.52210836112499, 45.98706275224686, 49.805481657385826, 46.65582686662674, 48.05491179227829, 45.319731160998344, 46.07163481414318, 42.71946229040623, 38.411234468221664, 39.711790680885315, 40.971476286649704, 39.19559597969055, 38.20855714380741, 39.14702698588371, 42.927390933036804, 42.13428609073162, 43.47111135721207, 42.02096477150917, 43.28203730285168, 42.5286441296339, 40.23202836513519, 38.6733216047287, 40.31584806740284, 37.57616087794304, 39.478889778256416, 38.420950546860695, 38.92482250928879, 36.94339603185654, 39.54063646495342, 39.01091828942299, 38.97198937833309, 39.5534797757864, 39.89286236464977, 38.32591004669666, 40.33709652721882, 39.01636339724064, 36.590721756219864, 39.34605650603771, 41.26317523419857, 38.57287019491196, 38.6539426445961, 38.182114362716675, 40.50583027303219, 38.86635884642601, 40.04050724208355, 40.717703104019165, 40.77449105679989, 40.04116080701351, 43.23911860585213, 44.19244945049286, 48.48187208175659, 53.45581658184528, 56.83576941490173, 57.0015013217926, 55.79809449613094, 55.44101245701313, 60.384516790509224, 61.00743256509304, 61.048785746097565, 58.432626128196716, 61.03530026972294, 59.59757521748543, 66.01928383111954, 60.37671200931072, 68.20829316973686, 6.3781187776476145, 0.15686796221416444, 2.7197969192638993, 0.31595536158420146, 0.6615293025970459, 42.84080117940903, 75.62333688139915, 63.743760734796524, 71.9930648803711, 51.97078786790371, 40.806910917162895, 43.17154303193092, 47.86235712468624, 68.50207060575485, 47.92581371963024, 2.6136588770896196, 0.29042562993709, 0.0510478115756996, 0.1117554766824469, 0.009346939950773958, 0.04004830356279854, 0.12841168994782493, 0.038746216596337035, 0.15666183811845258, 0.11767977441195399, 0.20230448426445946, 0.11544211753061973, 0.2496310486458242, 0.15410899854032323, 0.1027981104562059, 0.14853365864837542, 0.2309473472996615, 0.12671662465436384, 25.59837520122528, 83.2257941365242, 60.93290716409683, 50.94019576907158, 30.292215831577778, 49.141976460814476, 58.83644945919514, 75.88249817490578, 61.20233550667763, 71.19301781058311, 19.205767326056957, 0.3571242227917537, 0.2377690203138627, 0.6692656280938536, 45.696439146995544, 65.16463369131088, 64.47142168879509, 60.623782351613045, 57.38820277154446, 59.024474769830704, 61.85909986495972, 58.30102019011974, 61.79152049124241, 59.210702776908875, 55.23625284433365, 59.15948152542114, 55.03789208829403, 47.370066940784454, 40.364671647548676, 41.369691118597984, 44.87156420946121, 41.840083077549934, 42.008953616023064, 41.926992014050484, 43.66840057075024, 43.25437478721142, 40.87935023009777, 41.392664685845375, 40.122404247522354, 42.07131966948509, 40.46966001391411, 39.37169753015041, 40.63872434198856, 40.96288874745369, 39.3541044741869, 38.379198387265205, 39.88061562180519, 39.75452698767185, 40.93471705913544, 39.91744704544544, 39.820301458239555, 39.86534044146538, 39.57840643823147, 39.691777154803276, 41.95354498922825, 40.04341408610344, 39.576894119381905, 39.33646962046623, 40.580139085650444, 41.40999175608158, 45.8468084782362, 45.05556173622608, 45.81023924052715, 44.70560051500797, 44.988943710923195, 43.665337935090065, 41.78883142769337, 43.703985661268234, 41.16511009633541, 40.18934145569801, 37.41782337427139, 41.454122588038445, 44.985702484846115, 51.02892480790615, 47.11420387029648, 43.54422703385353, 51.31073668599129, 52.54603520035744, 43.687574341893196, 47.64986492693424, 53.25153574347496, 48.4638724476099, 49.86982360482216, 46.3494873046875, 50.65804570913315, 44.29652966558933, 40.79219810664654, 41.87857501208782, 41.63289539515972, 41.892090886831284, 39.6014180034399, 41.367890015244484, 46.239540204405785, 44.309274181723595, 44.67016361653805, 45.58168150484562, 47.062123864889145, 43.65871109068394, 42.7978178858757, 41.589311733841896, 43.011643812060356, 39.61637020111084, 40.79127475619316, 40.41898213326931, 40.699129700660706, 39.935131296515465, 42.6254553347826, 40.56053213775158, 41.650435253977776, 40.854776948690414, 43.2461254298687, 40.48324428498745, 43.979721665382385, 43.04205358028412, 38.92705678939819, 42.61898048222065, 43.70775505900383, 41.96536235511303, 42.01369196176529, 41.40144981443882, 44.28994081914425, 40.62882587313652, 42.71741800010204, 43.28762300312519, 42.63185799121857, 42.50912457704544, 44.58563335239887, 46.9672429561615, 50.57966351509094, 55.68194232881069, 61.1365382373333, 58.76885108649731, 58.86928349733353, 56.87306061387062, 62.541896626353264, 65.09246036410332, 64.0369302034378, 60.529361218214035, 64.12136927247047, 61.559763327240944, 69.261953830719, 61.54486432671547, 69.59794700145721, 8.448069579899311, 0.40586782910395414, 4.3461141642183065, 1.499017900787294, 0.6189638678915799, 46.936669796705246, 82.48221963644028, 68.86280804872513, 77.86271631717682, 61.63030654191971, 50.657399743795395, 52.19159781932831, 58.21909658610821, 76.33937805891037, 57.50910848379135, 3.209719592705369, 0.4229344055056572, 0.1932283298810944, 0.15788336866535246, 0.1123006286798045, 0.11077296221628785, 0.3221736091654748, 0.10529772320296615], [0.046044496848480776, 0.06135173425718676, 0.03006459905009251, 0.10920564280240797, 0.08036886400077492, 0.06360168481478468, 0.036958275231882, 0.0893971647019498, 0.1573726671631448, 0.042886391311185434, 9.201994724571705, 55.423643589019775, 46.92032687366009, 48.38689237833023, 33.78168448805809, 31.458175666630268, 42.3805470764637, 63.429593592882156, 53.91969569027424, 59.556746408343315, 25.0789487734437, 0.3486005082959309, 0.07582360281958245, 0.5102713534142822, 34.423139467835426, 64.94928404688835, 58.93588252365589, 55.99455915391445, 52.58420795202255, 52.450170144438744, 53.4454545378685, 56.57853461802006, 54.732483476400375, 52.2109729796648, 51.8465231359005, 47.9833198338747, 41.04923911392689, 37.6628228276968, 37.49053247272968, 38.4502849727869, 39.34661887586117, 37.94639781117439, 40.200360864400864, 38.44948701560497, 40.9553537517786, 41.51115372776985, 40.57008482515812, 39.42212462425232, 39.31252330541611, 36.567174419760704, 37.143109515309334, 36.014205291867256, 35.0949814170599, 35.47538660466671, 33.720598965883255, 34.580793008208275, 36.17706075310707, 36.095676720142365, 37.27223798632622, 35.75445882976055, 36.191366985440254, 36.82008884847164, 36.38945035636425, 35.218805372714996, 35.43569393455982, 37.25604705512524, 37.39671170711517, 37.42806002497673, 38.8834161311388, 36.844772323966026, 36.75715662539005, 40.51797442138195, 41.38783894479275, 42.247352823615074, 40.92837139964104, 39.267947897315025, 37.336522936820984, 38.48452113568783, 38.90155255794525, 39.40311424434185, 36.344213783741, 39.43091355264187, 40.54489217698574, 43.406100645661354, 42.94750705361366, 49.78145934641361, 40.35927593708038, 42.0690131932497, 45.86153268814087, 43.36327314376831, 46.54416225850582, 44.54024098813534, 45.64996004104614, 41.16955205798149, 42.897585332393646, 37.705308347940445, 38.4957305341959, 36.229828521609306, 37.67790041863918, 36.84566907584667, 38.042699843645096, 37.74233736097813, 40.676619708538055, 38.96032400429249, 43.42999756336212, 41.53619818389416, 41.734213158488274, 39.03465561568737, 38.51890929043293, 38.12336951494217, 38.57627861201763, 36.55933544039726, 37.56949983537197, 36.32367208600044, 35.67323438823223, 37.06912748515606, 38.96174132823944, 33.59738677740097, 37.675852328538895, 36.4513186365366, 36.12856775522232, 36.10429085791111, 37.324165999889374, 35.82652196288109, 37.21709914505482, 36.17066189646721, 38.0855805426836, 35.894150733947754, 37.36632473766804, 36.812082678079605, 37.90827065706253, 37.75999881327152, 38.689250349998474, 38.411036878824234, 38.25959600508213, 40.60002721846104, 40.675426572561264, 41.76572106778622, 50.68522945046425, 50.79783260822296, 58.27895477414131, 55.18676809966564, 54.88740116357803, 56.75654746592045, 57.848491072654724, 54.49992075562477, 57.727889344096184, 53.13141278922558, 61.884490102529526, 58.23618046939373, 63.248096331954, 57.314368933439255, 71.08790025115013, 10.779215041548014, 0.38681330624967813, 0.5457777169067413, 0.32716182118747383, 0.46580518945120275, 42.34922535717487, 67.34243363142014, 63.27320538461208, 63.152090683579445, 45.97256653010845, 27.47353658080101, 52.293227165937424, 44.92584049701691, 58.984892293810844, 29.952491261065006, 1.225624589715153, 0.037550995184574276, 0.13342195859877393, 0.021506478587980382, 0.10437749719130807, 0.07587901898659766, 0.12762277212459594, 0.04798263777047396, 0.06616982747800648, 0.004764722598338267, 0.0033236353147003683, 0.024793367156235036, 0.04045536043122411, 0.016910968442971352, 0.09770875112735666, 0.013601603004644858, 0.23361967265373096, 0.059432670241221786, 11.706479284912348, 64.97885406017303, 53.561481311917305, 52.5851047039032, 30.763052366673946, 33.36187161505222, 48.61180990934372, 67.30253577232361, 58.20583909749985, 65.03886803984642, 26.934469006955624, 0.4315412702271715, 0.05341824238712434, 1.0124404728412628, 38.54631341993809, 66.73288553953171, 60.84370315074921, 58.16251382231712, 54.33494880795479, 55.35586662590504, 55.86766496300697, 56.903215795755386, 57.47738018631935, 55.103172585368156, 53.35029624402523, 51.42966270446777, 43.94781477749348, 39.708078280091286, 41.43061324954033, 40.6476728618145, 41.3816224783659, 40.095007717609406, 41.090071722865105, 41.455596908926964, 41.45443797111511, 43.43864969909191, 41.98097191751003, 40.72567127645016, 41.78591698408127, 39.56305906176567, 39.127613827586174, 39.2629511654377, 36.6780486702919, 37.81487926840782, 37.036255449056625, 36.362224817276, 37.99326449632645, 38.24221193790436, 39.17720876634121, 37.640487626194954, 38.5915157943964, 38.62284891307354, 37.79926210641861, 38.42550650238991, 38.08553494513035, 38.13438892364502, 38.75958077609539, 41.43222436308861, 40.95699146389961, 38.476457968354225, 38.83944869041443, 40.96977777779102, 44.181658029556274, 44.874816834926605, 40.54998770356178, 40.740821063518524, 40.4190619289875, 39.92228038609028, 41.01208470761776, 39.769475385546684, 38.203028440475464, 40.552313178777695, 41.90997272729874, 43.76669369637966, 44.346686974167824, 50.070452839136124, 42.78617151081562, 47.7850578725338, 49.69104699790478, 44.89535093307495, 48.031858429312706, 47.290001437067986, 47.055436223745346, 43.31165671348572, 44.93712209165096, 40.11239178478718, 39.39254321157932, 39.190238267183304, 38.85904423892498, 38.0758910626173, 39.66048963367939, 38.785928562283516, 42.402050122618675, 40.99392168223858, 45.99478393793106, 44.029654785990715, 45.0730711966753, 40.8755998313427, 39.66738246381283, 39.03757385909557, 40.34673660993576, 38.9669394493103, 38.95505748689175, 37.485011368989944, 37.90779188275337, 37.44705520570278, 40.20350329577923, 37.23844259977341, 40.06410397589207, 38.9166871458292, 38.64307522773743, 38.11446279287338, 37.771705985069275, 39.16944198310375, 39.40509393811226, 39.10153582692146, 40.86695149540901, 39.33871150016785, 39.91550534963608, 39.81509953737259, 41.42828777432442, 40.8439589291811, 41.043987795710564, 41.43345549702644, 41.359796449542046, 42.7587103843689, 43.22755202651024, 43.49915765225887, 51.941662430763245, 53.20167101919651, 62.35823728144169, 57.214031517505646, 58.69899183511734, 57.80545078217983, 61.41776494681835, 55.170444175601006, 60.78036054968834, 55.37860840559006, 64.95745360851288, 59.10213500261307, 66.28960132598877, 56.76597096025944, 70.9005855023861, 11.024683769792318, 0.23117619595723227, 1.9263642258010805, 0.3410072688711807, 0.4059328412404284, 47.58532539010048, 72.87162333726883, 70.26986494660378, 70.02641960978508, 49.948813766241074, 31.158917024731636, 56.146102622151375, 53.40553008019924, 65.56933477520943, 38.11738483607769, 1.2931289174593985, 0.08870134188327938, 0.07952902000397444, 0.07690780636039563, 0.03976107014750596, 0.09270285372622311, 0.0883898328174837, 0.03520797559758648, 0.23826011427445337, 0.12484711012803018, 0.17311851755948737, 0.2397331883548759, 0.17105294245993719, 0.1970273393089883, 0.20286007085815072, 0.08657440601382405, 0.2531207160791382, 0.1596580070327036, 12.617290411144495, 76.38045385479927, 61.72141805291176, 62.24677786231041, 44.48645867407322, 44.110047072172165, 55.11705704033375, 71.27057164907455, 61.59686453640461, 71.83101117610931, 30.56121289730072, 0.36440840223804116, 0.18500914826290682, 1.740590175613761, 41.82655580341816, 67.9479843378067, 64.91937965154648, 60.63843436539173, 56.93853110074997, 58.607849925756454, 58.157068714499474, 59.3626794219017, 60.704201236367226, 56.52399994432926, 57.155488058924675, 53.35367426276207, 47.03780896961689, 41.836131289601326, 43.72530251741409, 43.15765857696533, 46.71543046832085, 43.19732464849949, 44.075487926602364, 42.49535791575909, 45.87841138243675, 44.9832858145237, 45.39737619459629, 43.287900388240814, 43.93000893294811, 40.81145167350769, 42.532109543681145, 41.51054196059704, 39.29839186370373, 41.76947146654129, 38.11339125037193, 39.644431695342064, 40.72464533150196, 39.950497671961784, 41.52552455663681, 39.103922098875046, 38.69164802134037, 40.76284468173981, 39.76566419005394, 40.440055802464485, 40.08234679698944, 40.69597966969013, 40.85123933851719, 43.07905599474907, 42.60851204395294, 41.158107072114944, 40.2106849104166, 43.901540860533714, 46.06506496667862, 47.34469950199127, 42.86086790263653, 43.859815299510956, 41.6574002802372, 42.252619341015816, 44.39081020653248, 43.08288238942623, 39.94306147098541, 42.67348475754261, 43.697837591171265, 45.78606873750687, 47.209316566586494, 54.57570768892765, 43.46374735236168, 50.48776924610138, 47.43202641606331, 44.99273970723152, 50.73637090623379, 49.94447059929371, 49.73567560315132, 44.902566745877266, 46.161044016480446, 41.707082614302635, 42.838468104600906, 40.65937623381615, 41.29171170294285, 41.38120450079441, 42.83568665385246, 40.999450385570526, 45.75850121676922, 41.512092277407646, 48.789689764380455, 45.32976262271404, 46.27094551920891, 43.48927438259125, 41.34849965572357, 41.42627768218517, 42.745452895760536, 41.110807210206985, 41.05936177074909, 39.59820717573166, 40.46616420149803, 40.179002210497856, 43.07861141860485, 36.564670354127884, 41.34767509996891, 41.47737354040146, 40.3768689930439, 40.049079582095146, 41.63281939923763, 40.63205190002918, 42.76213780045509, 41.29519611597061, 44.138971120119095, 41.40061005949974, 42.79209539294243, 42.42466650903225, 43.45188818871975, 43.12485113739967, 43.483183309435844, 45.2420899271965, 42.75345906615257, 43.62859010696411, 46.493503376841545, 45.50403267145157, 56.02327041327953, 56.652459651231766, 63.929380774497986, 60.6472384929657, 59.833185374736786, 60.84299258887768, 63.75961348414421, 56.55480869114399, 62.70795911550522, 58.186159953475, 66.7505469918251, 63.0771891027689, 68.23682203888893, 57.098582312464714, 70.47108694911003, 14.39563488587737, 0.5025580048095435, 5.222414592280984, 0.8220218843780458, 0.48376836930401623, 50.37311039865017, 79.20899167656898, 73.28143894672394, 77.47845813632011, 57.82401658594608, 39.807249158620834, 64.4243574142456, 63.09806518256664, 73.35810363292694, 48.37081544101238, 1.8538039131090045, 0.20816826727241278, 0.31020469672512263, 0.22235198586713523, 0.19357191456947476, 0.14323365554446355, 0.2757526282221079, 0.13109792314935476], [0.03469991985184606, 0.052810898414463736, 0.06619569874601439, 0.05006886683986522, 0.057139003474731, 0.024889362102840096, 0.035743609550991096, 0.022867863153805956, 0.0800696894293651, 0.03390893143659923, 4.17203220538795, 45.85752010345459, 52.28576436638832, 43.458898812532425, 37.596368193626404, 33.19651208817959, 41.170429810881615, 60.70047363638878, 53.93794611096382, 55.70866249501705, 35.88109843432903, 0.1471425176714547, 0.076813219639007, 0.2586701401742175, 24.78855885565281, 61.69236481189728, 58.578830882906914, 56.0111490637064, 52.29437470436096, 52.877575010061264, 54.3618855625391, 52.72980093955994, 49.501361176371574, 48.82069610059261, 44.14544977247715, 38.47610078752041, 37.748417034745216, 37.440728545188904, 37.32457257807255, 37.71356150507927, 40.52514083683491, 41.61239929497242, 43.59688840806484, 44.18328434228897, 47.156279012560844, 44.86621029675007, 47.25497491657734, 45.512946993112564, 38.90675067901611, 38.9282651245594, 36.71985402703285, 36.42709493637085, 35.30628427863121, 36.663852632045746, 35.708420500159264, 36.51942998170853, 35.86225904524326, 35.43115317821503, 37.27192260324955, 36.45481064915657, 36.64350092411041, 36.17193102836609, 35.89623682200909, 36.777610927820206, 36.90924346446991, 38.810486644506454, 38.80678944289684, 36.903794556856155, 37.711011841893196, 38.7589880079031, 37.049923315644264, 40.81193044781685, 41.00735776126385, 42.210867181420326, 41.09813489019871, 39.83930043876171, 38.4539669752121, 37.92031221091747, 37.50122129917145, 38.06410789489746, 38.89112211763859, 37.431004866957664, 39.490361362695694, 41.22097849845886, 42.64944724738598, 42.11336061358452, 47.892922684550285, 39.595699310302734, 44.397855028510094, 42.23491229116917, 43.63349564373493, 46.58112287521362, 43.681338876485825, 42.33173109591007, 42.933736592531204, 37.80592694878578, 38.62458921968937, 36.87469191849232, 37.349848821759224, 37.51177713274956, 39.28609572350979, 37.626819759607315, 40.96372850239277, 42.036137357354164, 41.67483374476433, 41.98229804635048, 44.49458263814449, 41.07721321284771, 37.95156553387642, 37.28049114346504, 39.36194725334644, 36.86831586062908, 38.0873816460371, 35.74081376194954, 37.38872833549976, 35.56665010750294, 38.59291411936283, 36.839969381690025, 36.5234387665987, 36.3049390912056, 37.5927621871233, 35.85815906524658, 38.02030764520168, 35.89388094842434, 39.43254366517067, 34.64622549712658, 37.57771119475365, 35.31882740557194, 36.88921093940735, 36.18757098913193, 38.04582327604294, 38.32700438797474, 39.51248377561569, 39.32139962911606, 39.51118804514408, 39.25723247230053, 40.93286655843258, 38.80879953503609, 47.33818665146828, 50.956580489873886, 53.80587659776211, 56.36737994849682, 58.97732689976692, 55.78591614961624, 57.617030292749405, 53.994091898202896, 53.06578651070595, 52.85420626401901, 63.22181694209576, 55.37789024412632, 65.60065269470215, 59.96864050626755, 52.00093165040016, 10.0860714353621, 0.14490583300357684, 2.415304770693183, 0.4078442574245855, 0.630542915314436, 42.4986257404089, 66.40492513775826, 65.33368661999702, 57.81783051788807, 55.28326012194157, 46.952336356043816, 56.5197479724884, 47.15116448700428, 57.412289679050446, 21.17850746959448, 0.8233490225393325, 0.09451982419705018, 0.0948466437694151, 0.05570061366597656, 0.04468591017939616, 0.0540753918903647, 0.08084853630862199, 0.18785583379212767, 0.01699314274446806, 0.03963533177739009, 0.12610016710823402, 0.03686893549456727, 0.06856965104816481, 0.010572783303359756, 0.04317308666941244, 0.04302836787246633, 0.04903545217530336, 0.07892082998296246, 5.29167490079999, 55.50265654921532, 57.45421662926674, 52.327657118439674, 44.908654019236565, 35.02960592508316, 47.67116278409958, 66.41821682453156, 58.98535206913948, 60.889543890953064, 38.006339594721794, 0.06692036884487607, 0.013290036422404228, 0.3531706240028143, 26.676115170121193, 62.605638206005096, 60.275029465556145, 57.662426456809044, 56.0156936198473, 54.61496718227863, 55.096370950341225, 53.38179275393486, 51.68120540678501, 50.91352120041847, 47.20734067261219, 41.230937764048576, 40.8376132696867, 40.760663598775864, 40.30982919037342, 39.809411242604256, 41.86348982155323, 43.95488999783993, 46.066459491848946, 46.643105149269104, 48.13937745988369, 46.63769043982029, 48.306690081954, 47.38660745322704, 43.05949464440346, 40.57683706283569, 40.56979984045029, 39.069894924759865, 38.24361026287079, 38.786768317222595, 38.92712518572807, 37.56957583129406, 38.544090539216995, 38.73967744410038, 38.74995969235897, 38.1038461625576, 40.22123694419861, 37.568200305104256, 37.086488753557205, 37.2344034165144, 39.1584187746048, 41.21711030602455, 39.28400583565235, 40.21429471671581, 39.43115673959255, 39.6249121427536, 39.16241616010666, 42.84580931067467, 42.52280384302139, 41.971111446619034, 42.76819087564945, 41.1710187792778, 41.99650928378105, 40.43192803859711, 41.056929901242256, 39.38058145344257, 40.344810113310814, 38.3784194290638, 41.988529711961746, 43.45826044678688, 42.69359327852726, 45.115777105093, 48.03249679505825, 41.8587476760149, 47.06504210829735, 43.73871959745884, 46.957086101174355, 48.509906977415085, 45.378419011831284, 45.13634920120239, 43.468854278326035, 39.05233986675739, 39.81581009924412, 38.852531388401985, 40.36472484469414, 39.8844838142395, 40.52108645439148, 39.6011596173048, 43.8637138903141, 44.77593094110489, 44.32709522545338, 43.48459303379059, 45.23791395127773, 42.51726374030113, 39.95628476142883, 39.19173538684845, 39.739042818546295, 37.79180310666561, 40.82814037799835, 37.20731467008591, 39.80880707502365, 37.54597909748554, 40.232020765542984, 38.28585259616375, 39.41253013908863, 38.23527351021767, 39.72771942615509, 38.061280846595764, 40.258657336235046, 39.023134633898735, 41.28696195781231, 37.89738044142723, 41.22668579220772, 37.74950757622719, 39.26816448569298, 37.99419544637203, 40.61978615820408, 39.858436211943626, 42.37133637070656, 40.649109184741974, 41.052168756723404, 40.90806148946285, 44.118623211979866, 41.08119919896126, 49.7754480689764, 52.71378479897976, 57.9524002969265, 57.18355715274811, 59.70119945704937, 57.152254432439804, 59.235245659947395, 54.83306027948856, 56.67739771306515, 56.52102090418339, 65.13786792755127, 58.46892178058624, 67.998316437006, 60.48468701541424, 52.867216765880585, 10.585943162441254, 0.05210280418395996, 1.5561275300569832, 0.13772317935945466, 0.4347654862795025, 47.14760407805443, 72.70857408642769, 68.69448468089104, 65.00590860843658, 58.876168727874756, 43.352515920996666, 62.071858048439026, 54.077288433909416, 63.58378931879997, 28.538988009095192, 0.8835867152083665, 0.048174705589190125, 0.10832397136255167, 0.032981680997181684, 0.03796172939473763, 0.046260814342531376, 0.05275436160445679, 0.08217607522965409, 0.12551848660223186, 0.20139176136581227, 0.10623330425005406, 0.11508136696647853, 0.10959783074213192, 0.09494306359556504, 0.1481158591923304, 0.1641170826042071, 0.21342783817090094, 0.151273415540345, 5.946586858481169, 62.21134856343269, 64.85169008374214, 59.35036048293114, 49.44288991391659, 46.454236283898354, 54.9222756922245, 69.9376031756401, 64.64398562908173, 67.39391326904297, 43.24329078197479, 0.25224685203284025, 0.21805361495353281, 0.5436301196459681, 30.012687630951405, 63.86400908231735, 62.43086278438568, 60.10601453483105, 56.34788319468498, 56.1986918002367, 58.85381832718849, 56.92285314202309, 52.342122942209244, 52.00265675783157, 49.906746223568916, 43.35924915969372, 41.14098519086838, 42.689523696899414, 41.560627073049545, 42.932896837592125, 44.17977333068848, 46.886383295059204, 47.4712061136961, 48.489403277635574, 50.888757929205894, 48.32362957298756, 51.89144812524319, 49.50021743774414, 43.834174275398254, 43.67450304329395, 42.183493450284004, 40.867339074611664, 39.172626212239265, 41.325571686029434, 42.01896607875824, 41.714465618133545, 40.99686272442341, 38.96761581301689, 39.94458518922329, 39.75986950099468, 41.70042537152767, 39.15129795670509, 39.81991767883301, 40.61344429850578, 40.58268114924431, 44.56397831439972, 41.69752612709999, 40.46342834830284, 41.42837516963482, 42.60766088962555, 41.02512940764427, 44.7032256424427, 44.36428762972355, 44.83546234667301, 46.18366040289402, 43.025338277220726, 43.645597994327545, 44.037672355771065, 42.31320708990097, 42.27205149829388, 42.92519085109234, 41.20237089693546, 43.32909017801285, 46.41663730144501, 45.706463009119034, 48.16604442894459, 51.09864726662636, 44.54933010041714, 48.11395302414894, 43.98121498525143, 48.491933941841125, 50.12960806488991, 48.140745386481285, 46.62932328879833, 45.98880685865879, 40.30374191701412, 42.61537067592144, 38.76064471900463, 42.876944839954376, 42.18062840402126, 42.862425819039345, 41.40990436077118, 46.03729225695133, 47.989205718040466, 45.185925140976906, 45.54251700639725, 48.404276445508, 43.85447658598423, 43.19405682384968, 42.08397679030895, 41.8586640805006, 38.73810812830925, 43.08006294071674, 40.422280356287956, 43.30235481262207, 38.974075466394424, 42.269828617572784, 40.52289895713329, 41.121458038687706, 40.76340705156326, 41.643728613853455, 39.37869295477867, 42.64297239482403, 41.69602520763874, 44.846493154764175, 40.2530412375927, 44.65947479009628, 38.59786905348301, 42.41426266729832, 40.01735508441925, 43.30791391432285, 42.21073418855667, 44.322592467069626, 42.90436416864395, 43.13727647066116, 43.305265456438065, 46.33725956082344, 42.841021567583084, 51.68280512094498, 55.78072562813759, 59.264401495456696, 60.50955668091774, 62.3769436776638, 59.38199758529663, 62.25205957889557, 58.054158836603165, 58.24146218597889, 57.66061395406723, 70.06148412823677, 60.593991950154305, 69.72495898604393, 63.02134349942207, 56.21444955468178, 13.0203708820045, 0.12840805342420936, 6.700479229912162, 1.4695653249509633, 0.7153155351988971, 50.51551915705204, 77.94157728552818, 73.63550394773483, 70.89133679866791, 68.20264667272568, 59.76950839161873, 70.14452487230301, 62.503351494669914, 74.64830920100212, 36.814894527196884, 1.2884025648236275, 0.24053602886851877, 0.286170719191432, 0.19228802877478302, 0.2090956104802899, 0.1491442829137668, 0.13440528942737728, 0.21803939540404826], [0.036950571738998406, 0.03361260300152935, 0.05557267853873782, 0.06523866963107139, 0.035754775162786245, 0.054619003931293264, 0.058967685035895556, 0.05914197470701765, 0.0822090265864972, 0.04777013120474294, 1.743893267121166, 45.530699640512466, 57.79961049556732, 39.498086348176, 25.00138733536005, 20.068480633199215, 39.723820835351944, 56.26821666955948, 56.84713840484619, 53.21004576981068, 45.31202897429466, 0.7327748264651746, 0.26690759346820414, 0.1243768259882927, 11.712580807507038, 58.57528567314148, 59.54476945102215, 57.13286407291889, 53.900544717907906, 55.118341371417046, 53.82471598684788, 55.72853162884712, 49.060717821121216, 43.31674084067345, 36.961718648672104, 41.098689660429955, 39.77800212800503, 38.00989620387554, 38.4617755562067, 43.31225328147411, 45.98324775695801, 47.86534756422043, 49.881971552968025, 49.29263077676296, 46.75402879714966, 49.10210520029068, 50.157354176044464, 45.736390203237534, 42.8552670031786, 37.259706258773804, 36.77811250090599, 37.52219997346401, 36.26088045537472, 36.16529278457165, 36.52887627482414, 35.19742771983147, 37.369014993309975, 36.20685875415802, 37.401685640215874, 36.51152640581131, 36.319910287857056, 35.94593055546284, 37.28589065372944, 36.949012130498886, 36.95968195796013, 37.23626911640167, 36.568401753902435, 37.40807309746742, 37.367745861411095, 36.62640564143658, 37.15397693216801, 39.37555432319641, 41.310695484280586, 41.82794272899628, 42.112156078219414, 40.03708742558956, 37.901267632842064, 39.14305999875069, 38.372157365083694, 37.85472393035889, 37.235756143927574, 36.52293339371681, 37.1980469673872, 41.48124173283577, 42.46430978178978, 43.01601357758045, 44.17199894785881, 43.464636504650116, 38.495871126651764, 43.53092774748802, 44.87603656947613, 44.94843028485775, 42.257600873708725, 41.17630049586296, 39.67348873615265, 37.77040645480156, 35.690952837467194, 37.28161208331585, 36.755176931619644, 37.77606055140495, 35.8330500125885, 38.100677132606506, 39.34605650603771, 39.97642368078232, 41.30222573876381, 42.236052230000496, 43.19275729358196, 40.55193319916725, 38.24732646346092, 38.7962906062603, 38.53592857718468, 38.10325339436531, 37.94197864830494, 37.59300917387009, 35.898558497428894, 35.426931604743004, 38.87018524110317, 36.958545818924904, 36.42922282218933, 37.203279286623, 36.469348669052124, 34.644659981131554, 36.64500564336777, 34.895013347268105, 38.57293099164963, 35.2006271481514, 35.56509979069233, 35.60793109238148, 35.82827366888523, 37.718892619013786, 37.26372644305229, 37.583642676472664, 38.57307158410549, 38.86021837592125, 41.13207466900349, 41.03206403553486, 40.33653035759926, 37.271162644028664, 41.66224502027035, 46.10393688082695, 51.77548214793205, 51.84956297278404, 57.959874495863914, 52.96581767499447, 51.65885120630264, 53.10672551393509, 52.37479358911514, 52.234204933047295, 59.91708867251873, 59.52339179813862, 63.39685454964638, 53.72499033808708, 60.0041002035141, 12.215631064027548, 0.13316863391082734, 1.2438200321048498, 0.20811260619666427, 0.5170289345551282, 43.07868741452694, 63.29264134168625, 70.78761756420135, 54.580719619989395, 53.69833096861839, 32.9583028703928, 42.83792853355408, 57.5615456700325, 51.57505050301552, 19.008527509868145, 0.8957330603152514, 0.05624807745334692, 0.10809206505655311, 0.11909766981261782, 0.1285196575918235, 0.019332505398779176, 0.03195680845237803, 0.07137470951420255, 0.04911220879876055, 0.04341596933954861, 0.017327187124465127, 0.11582982289837673, 0.06352896176395006, 0.07240048376843333, 0.041839859186438844, 0.051545948517741635, 0.16069452016381547, 0.05522988794837147, 2.2025719983503222, 53.33986960351467, 61.9557248800993, 45.6594443321228, 31.22235842049122, 31.524957083165646, 47.96744428575039, 61.99737064540386, 61.70485474169254, 58.492944091558456, 49.79432925581932, 0.8021984074730426, 0.08899178137653507, 0.11222541201277636, 13.10418488457799, 59.197642877697945, 61.02227456867695, 58.804135993123055, 55.36219708621502, 54.75725054740906, 55.481799468398094, 57.90599338710308, 51.41898147761822, 46.13557018339634, 39.511868208646774, 41.856084018945694, 40.83276852965355, 40.51108159124851, 41.67060077190399, 46.24542608857155, 48.20736721158028, 50.16769342124462, 50.99759928882122, 51.33611552417278, 49.12675827741623, 49.60337050259113, 50.68638078868389, 47.41553150117397, 42.65110395848751, 38.962584882974625, 37.63558588922024, 39.671075865626335, 37.616237327456474, 38.10020215809345, 39.42003093659878, 37.700125426054, 38.050759211182594, 37.96450763940811, 38.70837852358818, 37.53171846270561, 39.178603291511536, 37.5269079208374, 38.46718646585941, 39.5046029984951, 37.51527674496174, 39.13965158164501, 37.29685686528683, 40.861749574542046, 39.24354940652847, 38.58666345477104, 39.53171834349632, 41.5947188436985, 42.98979878425598, 44.39067721366882, 42.13893324136734, 40.90517744421959, 40.55121883749962, 40.21329537034035, 39.65776897966862, 40.8142027258873, 39.4339419901371, 39.345775321125984, 41.00060932338238, 43.59921008348465, 43.36514264345169, 43.58783349394798, 45.67935526371002, 45.49801379442215, 41.44472189247608, 45.727764666080475, 47.41276524960995, 45.3543359041214, 43.64536240696907, 42.055645510554314, 42.44395427405834, 39.5530541986227, 39.08840373158455, 38.8729552924633, 38.45400117337704, 38.87234352529049, 37.56251960992813, 39.98615875840187, 40.49976959824562, 43.70649732649326, 43.425369411706924, 43.858348578214645, 44.82864931225777, 41.86755560338497, 39.98117722570896, 40.71865685284138, 40.40991581976414, 39.6194252371788, 38.668077886104584, 38.063545525074005, 38.291689082980156, 38.59636813402176, 41.24581776559353, 37.487336844205856, 37.8983835875988, 39.189022332429886, 38.488206937909126, 37.192092686891556, 39.25945155322552, 38.026345521211624, 39.82169218361378, 36.0732389241457, 37.75465250015259, 39.01380613446236, 38.97004388272762, 39.3460489064455, 40.97508989274502, 39.4534083455801, 39.91682007908821, 41.37741610407829, 43.2593335211277, 42.84511014819145, 42.1794618666172, 40.53149029612541, 44.48576711118221, 49.38213497400284, 53.406065851449966, 55.77631026506424, 59.07949201762676, 55.863720774650574, 54.805834740400314, 55.269273072481155, 54.679814502596855, 52.811469957232475, 62.821713611483574, 61.76762357354164, 66.20074689388275, 55.89033454656601, 64.57886472344398, 13.890839572995901, 0.1610714866546914, 1.250287878792733, 0.5228050996083766, 0.6091146182734519, 45.38009092211723, 70.12229606509209, 74.39122259616852, 62.66476683318615, 63.468507304787636, 40.68589501082897, 51.58624470233917, 63.57813902199268, 59.683393612504005, 26.65912438184023, 0.9548648342024535, 0.016311099752783775, 0.051123250887030736, 0.025470536093052942, 0.15797048195963725, 0.037442571119754575, 0.08179284501238726, 0.07393513384158723, 0.23442766367224976, 0.12182677688542753, 0.0852151402796153, 0.31903948984108865, 0.09840201353654265, 0.20855133421719074, 0.10828396960278042, 0.19114847586024553, 0.25498466449789703, 0.17955982504645362, 2.943581873551011, 64.17281851172447, 71.07500374317169, 53.46163026988506, 35.43725945055485, 32.28074982762337, 51.620032489299774, 66.74216464161873, 65.44533982872963, 62.57917262613773, 57.28436194360256, 0.831779760774225, 0.2924322785111144, 0.2683402947150171, 15.314689669758081, 62.55155190825462, 62.98601299524307, 62.031724601984024, 57.98470996320248, 58.69679555296898, 58.6934669315815, 60.621080696582794, 55.266161039471626, 47.79571250081062, 41.84464283287525, 44.4325015693903, 44.463268518447876, 41.680472642183304, 42.919468358159065, 48.44485826790333, 50.79103857278824, 53.014812245965004, 55.152718126773834, 52.22926139831543, 50.36512702703476, 51.79526008665562, 52.878870740532875, 51.54616445302963, 46.588532477617264, 42.5658593326807, 40.35388022661209, 42.50380486249924, 41.10563188791275, 41.32549189031124, 41.171957328915596, 39.127769619226456, 39.95268255472183, 40.50920829176903, 40.5445121973753, 39.146172031760216, 40.71635037660599, 39.78605769574642, 40.223573818802834, 39.72108118236065, 40.1605162024498, 39.25778344273567, 39.41588915884495, 43.589429408311844, 41.458135172724724, 39.98735189437866, 43.014866039156914, 42.665470987558365, 44.60180148482323, 47.17353768646717, 44.780293107032776, 41.93891577422619, 41.33782982826233, 43.81694220006466, 42.35579900443554, 42.00095124542713, 39.575051218271255, 41.39746002852917, 41.96577653288841, 45.89565485715866, 46.28074899315834, 45.0777867436409, 48.600710704922676, 49.555789455771446, 41.85940504074097, 46.61664716899395, 48.95426653325558, 48.46079841256142, 45.99466994404793, 43.877248764038086, 43.217087388038635, 40.61730869114399, 40.742356181144714, 40.978920087218285, 40.649709552526474, 41.28796510398388, 38.47756750881672, 44.150898680090904, 43.4622236341238, 46.90506689250469, 44.50280159711838, 46.613865718245506, 46.38403885066509, 45.26236943900585, 41.66514426469803, 46.20180442929268, 42.97397643327713, 41.27535358071327, 40.605289936065674, 40.37282221019268, 39.91740524768829, 40.40891267359257, 45.096219554543495, 40.38986809551716, 38.95001895725727, 41.425122544169426, 38.98460850119591, 39.2290835827589, 41.3864254206419, 39.670304507017136, 43.20766769349575, 39.816870242357254, 41.158304661512375, 41.51923209428787, 40.796115696430206, 41.096991151571274, 41.797285974025726, 40.50617605447769, 43.00685986876488, 43.414118215441704, 45.628574788570404, 44.949805811047554, 43.869512379169464, 42.93078415095806, 45.38978800177574, 52.22148701548576, 56.24446414411068, 57.58831903338432, 63.6447798460722, 57.27550461888313, 56.59627206623554, 59.66647312045097, 57.70617350935936, 55.204820930957794, 63.95301550626755, 64.11986455321312, 67.81993880867958, 58.27108159661293, 68.07382598519325, 15.959791503846645, 0.38917615602258593, 5.590536464005709, 1.839944631792605, 0.6429968064185232, 49.68533970415592, 77.04490140080452, 80.28452396392822, 67.56384775042534, 68.37511941790581, 44.90622214972973, 56.11306719481945, 72.98498645424843, 71.42639368772507, 35.488484501838684, 1.0712241497822106, 0.16121006046887487, 0.2022282508551143, 0.2827177435392514, 0.23529266647528857, 0.09182179826893844, 0.1409594775759615, 0.1358591567259282], [0.06328066883725114, 0.01571073938976042, 0.03018946725205751, 0.028167465497972444, 0.05269621433399152, 0.04796827721293084, 0.021097959688631818, 0.03298741779872216, 0.014119964398560114, 0.15517626627115533, 0.6269133975729346, 38.500176295638084, 62.92281098663807, 46.313826218247414, 36.27383776009083, 21.242262348532677, 37.809042781591415, 53.810143768787384, 61.12160123884678, 50.03883093595505, 51.63097970187664, 3.0092100519686937, 0.21176084090257064, 0.07182881483458914, 2.2019457444548607, 40.24532005190849, 60.24598382413387, 59.56514395773411, 55.844983980059624, 57.41071276366711, 54.64556314051151, 54.720263332128525, 49.497321993112564, 40.09332060813904, 40.745650604367256, 39.47399944067001, 40.969101414084435, 42.35690474510193, 46.26095965504646, 49.803026989102364, 52.8923524171114, 52.72766165435314, 49.057750180363655, 49.49813514947891, 49.01721015572548, 48.71646769344807, 43.6355285346508, 45.76602481305599, 41.904664412140846, 36.902867406606674, 36.22333087027073, 37.47377537190914, 36.093294247984886, 34.91068370640278, 37.28673800826073, 36.27790354192257, 36.10821604728699, 36.18868812918663, 36.66341185569763, 37.9879067838192, 36.11024133861065, 35.890438333153725, 35.16783110797405, 35.8066376298666, 36.38672590255737, 38.469245955348015, 36.678250059485435, 38.43702368438244, 36.01306535303593, 37.6543302834034, 37.74022087454796, 40.15330798923969, 39.32946279644966, 39.22862000763416, 41.180677860975266, 39.27520550787449, 37.26087659597397, 38.23509871959686, 37.572178691625595, 37.755112275481224, 38.25786329805851, 35.40409103035927, 37.26679287850857, 39.779183864593506, 40.058229491114616, 40.77136002480984, 44.737211018800735, 46.81859493255615, 39.75322365760803, 43.442761078476906, 43.62586945295334, 42.577068731188774, 43.32118660211563, 41.14144876599312, 39.40227448940277, 36.56807877123356, 36.835261434316635, 36.97890132665634, 37.936221957206726, 36.88437379896641, 36.69069059193134, 37.13695004582405, 38.53652514517307, 41.343544721603394, 40.327293053269386, 39.515778198838234, 42.20651261508465, 38.31335552036762, 37.11740389466286, 36.49312399327755, 39.26369212567806, 38.79246801137924, 37.16583989560604, 35.416075587272644, 37.95053578913212, 36.88474997878075, 36.6613257676363, 35.59555135667324, 36.61950521171093, 35.320351123809814, 37.36185237765312, 35.097481682896614, 37.691340297460556, 36.152358278632164, 35.20262584090233, 35.929215252399445, 36.05944566428661, 35.21639250218868, 36.9641999155283, 37.496904730796814, 37.44347579777241, 36.8604426831007, 38.60482268035412, 36.736459136009216, 39.25958834588528, 38.659649938344955, 38.05606372654438, 38.82361873984337, 40.73592692613602, 42.000970244407654, 46.82817801833153, 46.70798286795616, 53.2074961066246, 49.35234077274799, 52.553938776254654, 46.81438855826855, 53.53760339319706, 50.969408601522446, 61.60836271941662, 56.230397298932076, 66.9678345322609, 53.35765644907951, 76.57383307814598, 21.592746041715145, 0.10835753128048964, 1.3001510594040155, 0.20415157108800486, 0.4291268560336903, 42.215480133891106, 64.94111448526382, 67.1161937713623, 55.90006582438946, 44.10258427262306, 26.515511088073254, 36.40149191021919, 57.457473054528236, 57.77033306658268, 19.553868547081947, 0.8826976222917438, 0.043049381783930585, 0.060198240098543465, 0.05589109699940309, 0.07879434575443156, 0.04561019944958389, 0.09171635392704047, 0.04732247514766641, 0.1231430796906352, 0.07281654659891501, 0.030228389186959248, 0.0034801245737980935, 0.04699110992078204, 0.05784359105746262, 0.039514955424237996, 0.06708813874865882, 0.05619392293738201, 0.1748206332558766, 0.8593520906288177, 45.673963353037834, 68.66857007145882, 50.71647897362709, 37.87413328886032, 23.16103968769312, 47.49275475740433, 59.00675252079964, 64.96006786823273, 54.61833380162716, 56.450040712952614, 3.4084669779986143, 0.20335659733973444, 0.09690356542705558, 2.607682985253632, 43.56901690363884, 62.138787657022476, 60.1852934807539, 56.622247472405434, 58.4117728471756, 56.97548411786556, 56.28322206437588, 50.51837280392647, 41.65402226150036, 43.26787546277046, 41.81150861084461, 42.94316008687019, 44.19626444578171, 47.51513935625553, 51.07434757053852, 53.50055158138275, 53.5199723392725, 51.77168995141983, 51.023293510079384, 49.06830981373787, 49.61373254656792, 47.015355974435806, 47.79772259294987, 44.71772186458111, 39.312565103173256, 37.250780537724495, 39.79356229305267, 37.14217856526375, 39.454525485634804, 37.998227030038834, 38.274529203772545, 37.4330947548151, 37.88332499563694, 38.607512935996056, 39.21038098633289, 37.89706125855446, 37.702333107590675, 36.19083881378174, 38.033489137887955, 37.82646484673023, 39.76916000247002, 38.70422534644604, 40.66901631653309, 38.84389825165272, 40.24848908185959, 38.485110104084015, 42.68683724105358, 42.14559808373451, 41.39218971133232, 41.27438463270664, 40.46324975788593, 39.40714582800865, 40.477039217948914, 39.545287415385246, 38.98202084004879, 41.52264431118965, 38.72225537896156, 40.5115831643343, 42.38516382873058, 41.60829171538353, 45.46117477118969, 44.630535542964935, 46.66331626474857, 44.08517740666866, 46.267495304346085, 45.41620418429375, 45.528579354286194, 45.59448301792145, 43.55026111006737, 43.07596296072006, 39.189698696136475, 38.97646173834801, 38.84169436991215, 39.858253821730614, 38.13958704471588, 39.88049402832985, 37.688277661800385, 39.33957405388355, 43.82073439657688, 40.573124662041664, 42.32456088066101, 43.246809393167496, 39.40379060804844, 38.33371102809906, 40.22166632115841, 42.96701520681381, 39.171562269330025, 40.422029569745064, 37.83827841281891, 39.617403745651245, 38.82079929113388, 38.122328370809555, 38.977343291044235, 39.81428638100624, 37.70460158586502, 39.63284231722355, 37.172333747148514, 39.74403195083141, 37.89329946041107, 37.70932473242283, 37.245806604623795, 38.41248460114002, 37.98460096120834, 39.24198389053345, 39.45408470928669, 38.75458784401417, 39.300474151968956, 41.44704356789589, 39.23848047852516, 41.295576095581055, 40.23390546441078, 40.95465838909149, 39.18304145336151, 43.97671602666378, 45.05516275763512, 48.724432066082954, 49.9100748449564, 55.279270336031914, 51.786246970295906, 55.74134834110737, 48.93940553069115, 55.26472471654415, 53.35962474346161, 63.51426064968109, 59.94519956409931, 67.02521905303001, 55.75901359319687, 77.93178141117096, 23.463338166475296, 0.10931388504104689, 0.6876432825811207, 0.12725543871056288, 0.37311468506231904, 44.898261576890945, 70.07268592715263, 72.48916625976562, 62.70552344620228, 50.82570791244507, 34.5368255674839, 42.051727920770645, 63.893708288669586, 64.69431772828102, 26.710887104272842, 0.7152356801088899, 0.02899761519074673, 0.08611345809185877, 0.0074493096235528355, 0.0517742257216014, 0.00873232293088222, 0.03150761243887246, 0.03551034882548265, 0.3144350869115442, 0.14159717538859695, 0.11209279764443636, 0.14295765082351863, 0.1277298788772896, 0.15719904913567007, 0.14566040423233062, 0.20995777827920392, 0.16835044138133526, 0.22418658976675943, 1.1698218528181314, 49.644944071769714, 79.82425466179848, 59.206382408738136, 47.05971099436283, 30.917457081377506, 51.84311091899872, 63.3462792634964, 71.41230404376984, 59.94722105562687, 62.431896328926086, 3.924843594431877, 0.29779405798763037, 0.13155884138541296, 2.9240271728485823, 44.96634632349014, 63.66374082863331, 64.0189191699028, 58.46816562116146, 63.19966033101082, 58.82993280887604, 60.11763051152229, 52.75015264749527, 43.881990909576416, 46.10330991446972, 44.75942462682724, 45.3781758248806, 48.153866082429886, 50.10270930826664, 53.2904988527298, 57.9211051762104, 57.00425997376442, 53.55706974864006, 52.965901270508766, 49.81653906404972, 49.2837468534708, 48.53562779724598, 49.77476790547371, 46.20464287698269, 41.65814884006977, 39.81892593204975, 42.48420551419258, 39.819195717573166, 42.41054646670818, 40.53005777299404, 42.66848802566528, 39.18557971715927, 39.249442890286446, 41.24460183084011, 41.757684499025345, 38.95783133804798, 39.55784574151039, 38.65920156240463, 39.8608984798193, 40.59540666639805, 41.30985572934151, 41.05147339403629, 44.2541391402483, 41.01311445236206, 42.64006935060024, 41.999666914343834, 44.531740844249725, 43.95031124353409, 42.38927520811558, 44.22682620584965, 42.84666806459427, 41.077775582671165, 42.36114151775837, 42.64273300766945, 42.84597270190716, 43.21000076830387, 40.25286644697189, 41.188087463378906, 44.57711420953274, 44.38159950077534, 45.26991583406925, 47.06738658249378, 48.54058653116226, 45.40932275354862, 49.17827591300011, 49.06354486942291, 46.965559646487236, 48.99717003107071, 45.704851895570755, 45.76312556862831, 41.096375584602356, 41.56318433582783, 40.96302554011345, 43.5774752497673, 40.105035379529, 42.56751984357834, 40.72727479040623, 41.21494822204113, 44.74925637245178, 43.065296933054924, 44.09299358725548, 46.47403322160244, 41.76634043455124, 39.94660288095474, 43.01900401711464, 44.26989309489727, 41.44558064639568, 41.973231732845306, 39.245867282152176, 42.22398787736893, 39.72167395055294, 39.55567225813866, 40.4041401296854, 41.651670187711716, 38.584470972418785, 42.18313626945019, 38.77446077764034, 43.24729196727276, 40.343943759799004, 39.76284474134445, 39.37514014542103, 40.4214596003294, 40.875881016254425, 42.26088009774685, 43.31868253648281, 40.71798428893089, 40.74639156460762, 43.162206932902336, 41.07451535761356, 44.28846649825573, 42.313039898872375, 41.97352431714535, 42.36551508307457, 46.15829676389694, 47.658699452877045, 51.05151079595089, 51.184807643294334, 57.954531982541084, 53.84939566254616, 56.96801371872425, 51.507718116045, 57.96541839838028, 54.280767515301704, 66.4996312558651, 60.895984545350075, 69.58489090204239, 58.781550005078316, 80.13078421354294, 26.930053643882275, 0.1303746408666484, 3.2681713812053204, 1.48508369224146, 0.39980923233088106, 47.6192993670702, 77.11824506521225, 76.59581869840622, 68.18037986755371, 59.338843300938606, 40.27667596936226, 50.129691660404205, 73.00508737564087, 74.81553822755814, 32.8432260453701, 0.7879103429149836, 0.22045501187676564, 0.1977907124091871, 0.20617987553123385, 0.19004399684490636, 0.11145141135784797, 0.17411587497917935, 0.16264476551441476], [0.013642887752212118, 0.03371958729985636, 0.04626156391168479, 0.055631067007198, 0.026493581099202856, 0.02036543210124364, 0.11873532363097183, 0.07297093558008783, 0.0580065295798704, 0.15412670618388802, 0.1515351710258983, 21.23284835368395, 64.45226311683655, 48.138465508818626, 31.663873828947544, 28.475086838006973, 38.6978492885828, 48.731910064816475, 61.14438861608505, 49.14681740105152, 58.30422721803188, 7.734088366851211, 0.43284409563057125, 0.32823725254274905, 0.09025812280015089, 17.551919370889664, 54.47011135518551, 59.63289812207222, 54.52502220869064, 53.170402497053146, 52.81381443142891, 52.857527285814285, 46.383723467588425, 40.054969266057014, 41.79472491145134, 41.150948256254196, 44.29464116692543, 47.0611435174942, 51.14945434033871, 53.76936435699463, 51.68530538678169, 49.191787987947464, 50.40020674467087, 48.01948629319668, 45.14820836484432, 45.51583103835583, 47.26524956524372, 46.32946997880936, 38.32975164055824, 35.19979499280453, 38.314472660422325, 35.874505788087845, 36.448871567845345, 35.03930680453777, 35.613296404480934, 35.3845676779747, 35.193027555942535, 36.52242422103882, 35.91253414750099, 38.06120865046978, 36.436336040496826, 35.640343353152275, 36.046507358551025, 36.86363831162453, 35.0163484364748, 37.34081290662289, 37.77394026517868, 37.26931594312191, 38.29705059528351, 37.95210890471935, 38.485007509589195, 39.94163654744625, 39.71224665641785, 40.429777354002, 41.01145774126053, 39.12522375583649, 35.712110102176666, 38.585671707987785, 39.207200556993484, 39.123491048812866, 37.83013924956322, 36.903133392333984, 37.946751192212105, 40.22582329809666, 40.492458790540695, 42.58271522819996, 43.69107395410538, 45.588589534163475, 40.55123023688793, 41.53911642730236, 41.1976857483387, 41.655040606856346, 40.22173851728439, 39.44161757826805, 38.21528658270836, 37.99355328083038, 35.37205494940281, 38.8905293494463, 36.96613781154156, 36.26015469431877, 35.85569679737091, 37.31649801135063, 39.90890130400658, 39.6554397046566, 40.17232596874237, 39.435678496956825, 42.03984975814819, 39.87639404833317, 36.95658132433891, 35.35559423267841, 39.27145890891552, 37.011336386203766, 37.693156599998474, 37.17048704624176, 36.41554355621338, 35.69930098950863, 36.650329157710075, 37.490289285779, 37.74917319417, 36.05971544981003, 36.840569749474525, 37.35459856688976, 35.93643106520176, 35.10726995766163, 36.47657208144665, 35.48752695322037, 38.970997631549835, 36.889362931251526, 37.427634447813034, 36.62750378251076, 39.001130014657974, 39.330101162195206, 39.46134991943836, 40.04755586385727, 41.14543095231056, 39.83312577009201, 40.445774495601654, 37.688448652625084, 38.65933075547218, 37.797312811017036, 42.001065239310265, 43.18573907017708, 47.259078696370125, 46.13671392202377, 50.22526033222675, 45.905503928661346, 48.665273040533066, 47.27126844227314, 56.85742825269699, 54.35506492853165, 61.44007354974747, 53.211554288864136, 70.53144291043282, 23.354284018278122, 0.058771758049260825, 0.3554836905095726, 0.26744526461698115, 0.5523755878675729, 43.94288644194603, 66.08209446072578, 65.22588640451431, 57.15389974415302, 46.10197238624096, 29.404296576976776, 35.80719619989395, 56.09009362757206, 53.646779134869576, 10.621608048677444, 0.754868978401646, 0.04207585472613573, 0.1745978553663008, 0.03416106126678642, 0.05439431872218847, 0.07979404836078174, 0.0165075592303765, 0.038209988924791105, 0.04333706048782915, 0.05919983625062741, 0.030767255193495657, 0.058370404585730284, 0.06680497230263427, 0.030839477294648532, 0.02987264440889703, 0.06649764894973487, 0.0565626664320007, 0.21164582285564393, 0.21989056403981522, 26.64409428834915, 71.80470138788223, 53.33962261676788, 38.240521028637886, 29.631315395236015, 46.95906959474087, 54.76349741220474, 65.87185934185982, 53.5107996314764, 63.81726399064064, 8.740805871784687, 0.4278978594811633, 0.4084908461663872, 0.11352593675837852, 18.773379027843475, 54.52109321951866, 59.594664573669434, 57.54052899777889, 55.0473003834486, 55.675307884812355, 55.84038242697716, 47.576198279857635, 41.39389581978321, 43.897862657904625, 41.84858322143555, 45.93788579106331, 49.05443675816059, 53.25081378221512, 56.40655964612961, 53.041422218084335, 51.536801755428314, 49.58652600646019, 49.20889087021351, 48.00196163356304, 46.691366359591484, 49.946533888578415, 50.750844329595566, 41.56106784939766, 36.46596685051918, 39.48295176029205, 38.307199850678444, 39.12634089589119, 36.300785914063454, 37.930784448981285, 38.42479594051838, 39.09773603081703, 37.82852053642273, 37.55499221384525, 38.649272695183754, 37.088932022452354, 36.806363984942436, 37.673143073916435, 37.179135382175446, 37.14864581823349, 39.67433229088783, 38.29486571252346, 38.646897822618484, 39.90219086408615, 40.73609411716461, 39.05854873359203, 42.317060083150864, 42.02663406729698, 41.899295300245285, 43.26015047729015, 39.158399775624275, 38.04276444017887, 39.435070529580116, 39.967091381549835, 41.04008160531521, 40.02999700605869, 39.44462701678276, 40.19041299819946, 42.58959285914898, 42.42121249437332, 44.222433641552925, 47.45076701045036, 46.97763539850712, 42.87536032497883, 43.73055763542652, 44.31497387588024, 42.76331573724747, 43.03142935037613, 42.310414239764214, 40.2702809125185, 39.88845460116863, 38.36191311478615, 39.419050589203835, 39.11216385662556, 38.21516878902912, 38.9238041639328, 37.38690443336964, 42.20975384116173, 40.88107153773308, 41.802301704883575, 41.03603482246399, 44.13313843309879, 42.426490411162376, 38.663962706923485, 38.00855487585068, 40.86792804300785, 38.589855283498764, 39.36346337199211, 39.63883079588413, 37.44915269315243, 37.82947048544884, 39.83681537210941, 37.84406550228596, 41.21827304363251, 38.3766183257103, 39.100122302770615, 38.429226502776146, 38.26936528086662, 38.141828924417496, 38.74082498252392, 37.15160585939884, 39.97519634664059, 38.63203302025795, 39.69613552093506, 37.98928990960121, 42.746000066399574, 40.68208761513233, 42.694455832242966, 41.7445258051157, 43.16721886396408, 40.598944276571274, 41.94225959479809, 39.51800487935543, 38.99169132113457, 41.383472979068756, 43.9779319614172, 46.55500687658787, 49.77123409509659, 49.29328054189682, 52.16991238296032, 47.77026146650314, 50.67085862159729, 49.42082069814205, 59.19187858700752, 58.27308788895607, 63.15431736409664, 56.5642511844635, 72.30339422821999, 26.527818627655506, 0.05030254687881097, 0.9146631101612002, 0.12282817158848047, 0.4922132974024862, 47.116662338376045, 72.31653392314911, 68.45470234751701, 64.51891914010048, 52.53916136920452, 33.334277495741844, 40.32622531056404, 62.679624035954475, 61.19034335017204, 15.383275039494038, 0.7368626946117729, 0.027438002980488818, 0.10109574242960662, 0.04843293587327935, 0.11038738681236282, 0.03271167282946408, 0.059596484497888014, 0.024671666069480125, 0.11517191640450619, 0.13486303127137944, 0.20086148200789467, 0.13948837760835886, 0.1898966360022314, 0.1296108224778436, 0.19445604993961751, 0.18204392690677196, 0.18229397130198777, 0.3437581134494394, 0.4163566912757233, 30.626466795802116, 79.15184274315834, 60.73945574462414, 46.255962923169136, 39.83645439147949, 50.454502031207085, 61.402504965662956, 71.82572945952415, 58.69845986366272, 68.67429256439209, 10.249934792518616, 0.7277699012774974, 0.511891907081008, 0.3524306137114763, 21.572244241833687, 57.42650471627712, 62.372760102152824, 58.17701004445553, 57.12202325463295, 57.914846912026405, 57.7937588095665, 50.22810637950897, 44.98401157557964, 45.89563585817814, 45.020748004317284, 46.844536140561104, 51.03895626962185, 55.45379877090454, 58.83202649652958, 53.855798318982124, 53.07617135345936, 51.58537074923515, 51.02601796388626, 48.92851151525974, 50.485930144786835, 53.342875242233276, 51.58016882836819, 43.729231506586075, 39.87553529441357, 41.63054332137108, 39.990878105163574, 42.53779783844948, 40.02792991697788, 39.99565824866295, 40.599039271473885, 41.48252986371517, 40.81846609711647, 39.279438480734825, 42.65771180391312, 39.79828163981438, 40.14014169573784, 39.18717943131924, 40.46955741941929, 39.037687852978706, 41.825412064790726, 41.15939140319824, 40.698407739400864, 43.266283348202705, 43.023981750011444, 41.21197298169136, 42.93994165956974, 43.776626363396645, 43.57972472906113, 43.54161657392979, 41.384441927075386, 39.7913584113121, 42.15077720582485, 43.18008117377758, 42.644754499197006, 42.117095813155174, 41.130015179514885, 42.63305492699146, 44.89087477326393, 43.308841064572334, 46.26713812351227, 49.57254275679588, 50.002341493964195, 42.844186797738075, 46.09756462275982, 45.98471447825432, 43.83790947496891, 45.2384839206934, 43.26484702527523, 41.58346764743328, 42.660994827747345, 38.225333243608475, 41.80640168488026, 40.7196182012558, 39.84593108296394, 41.05335429310799, 40.187756940722466, 43.25601249933243, 43.546031937003136, 42.1326369792223, 42.28744827210903, 48.099498599767685, 45.32013013958931, 41.38529308140278, 39.43497933447361, 44.162879437208176, 39.67592440545559, 42.49189630150795, 42.17752017080784, 39.65651884675026, 39.44717288017273, 41.39987289905548, 42.06448383629322, 44.159877598285675, 40.122404247522354, 40.052301809191704, 40.39742209017277, 39.43596348166466, 41.36142276227474, 41.80975690484047, 40.04423104226589, 44.27428565919399, 41.39044940471649, 42.45511807501316, 40.98393201828003, 44.217588901519775, 44.52840082347393, 44.65873762965202, 43.74818108975887, 45.33906452357769, 43.43209125101566, 46.47695146501064, 42.32906363904476, 42.039515376091, 43.368285074830055, 47.24260278046131, 48.20823356509209, 51.86346262693405, 51.42696104943752, 55.08170373737812, 50.07457561790943, 53.954045847058296, 52.15132378041744, 61.3394283503294, 61.137898564338684, 67.3794436454773, 58.66544343531132, 75.34775286912918, 28.27474068850279, 0.15616823569871485, 3.3851742278784513, 1.9708873867057264, 0.573018811410293, 50.69803476333618, 75.95116049051285, 73.94033879041672, 69.11347299814224, 59.03675191104412, 41.54471732676029, 49.73019629716873, 70.0920344889164, 73.0116306245327, 20.157990530133247, 0.6801413570065051, 0.1861606349120848, 0.294981169863604, 0.1483469788217917, 0.22721119777997956, 0.17177058442030102, 0.3182399593060836, 0.10830510596861131], [0.1287302197306417, 0.02408856806141557, 0.07613350884639658, 0.07242980602313764, 0.0848458921245765, 0.11192161386134103, 0.03113513594144024, 0.020913621337967925, 0.014704277673445176, 0.14800324570387602, 0.07070443884003907, 12.83600002527237, 60.292025953531265, 49.22153279185295, 38.764687702059746, 22.786453887820244, 33.993564918637276, 49.71840552985668, 60.55734671652317, 48.730374947190285, 57.042098343372345, 14.772973638027906, 0.5726072459947318, 0.29788177984301, 0.13270967494463548, 2.9406959284096956, 37.17466302216053, 55.92883788049221, 50.5737092345953, 54.52380247414112, 51.69960401952267, 54.307487681508064, 44.58250232040882, 40.962060391902924, 43.6639130115509, 46.59977987408638, 47.85457894206047, 52.802525237202644, 50.9578800201416, 48.540761321783066, 48.12373749911785, 47.993750274181366, 49.46469694375992, 47.8417432308197, 48.5313606262207, 50.62162086367607, 48.95311899483204, 38.89109931886196, 34.633066803216934, 34.760109186172485, 36.120063811540604, 38.143713623285294, 36.123837009072304, 36.46163508296013, 36.06120117008686, 38.20516012609005, 36.45998977124691, 36.8274300545454, 36.30789913237095, 36.147281751036644, 36.50896534323692, 35.148334354162216, 34.37098726630211, 37.05937720835209, 36.59516751766205, 37.26116918027401, 36.88701085746288, 37.17701889574528, 38.77411499619484, 40.11808007955551, 36.99984960258007, 41.57762736082077, 41.820327937603, 38.629414960742, 39.520512744784355, 38.78700390458107, 36.91623508930206, 37.76946410536766, 38.378073647618294, 38.08596812188625, 36.19047403335571, 36.965647637844086, 37.64166936278343, 39.017191752791405, 39.96810592710972, 42.60740250349045, 42.11086794734001, 43.12417097389698, 39.47586514055729, 41.883301958441734, 42.531946152448654, 40.38236349821091, 40.76170854270458, 38.85335594415665, 37.25428394973278, 36.80661477148533, 36.50799639523029, 36.917994394898415, 38.0078899115324, 36.76349088549614, 37.28924207389355, 38.02274711430073, 38.53331811726093, 39.42261479794979, 39.711026921868324, 38.147103041410446, 42.298874258995056, 39.989669770002365, 37.05247677862644, 35.92016413807869, 38.69955159723759, 38.362726271152496, 38.96977409720421, 35.63869424164295, 36.250134631991386, 35.1679565012455, 35.63538081943989, 36.74984961748123, 37.51393921673298, 35.17343960702419, 37.342389822006226, 37.20098800957203, 37.981154546141624, 36.494689509272575, 38.11457298696041, 35.5965431034565, 37.077167853713036, 35.51190264523029, 38.17568890750408, 37.396293729543686, 43.19704346358776, 42.96167649328709, 44.027751088142395, 44.25298020243645, 47.39587515592575, 44.95736740529537, 47.98809997737408, 43.53592447936535, 42.948263213038445, 37.317117378115654, 38.24012205004692, 38.336416482925415, 41.874847412109375, 42.926927357912064, 46.35427124798298, 44.20385263860226, 46.62023797631264, 42.32111446559429, 48.99221509695053, 45.617855563759804, 58.85697215795517, 51.68382726609707, 73.36723074316978, 26.99907124042511, 0.02954109735583188, 0.22975336527451873, 0.13032698014285415, 0.4397641774266958, 43.40634383261204, 64.40215900540352, 61.29519872367382, 54.4474683701992, 40.76563373208046, 38.83237726986408, 32.24846675992012, 50.996675938367844, 52.23509408533573, 6.849108729511499, 0.5670335981994867, 0.036292550212237984, 0.045847215442336164, 0.09147333024884574, 0.1215577260882128, 0.018313939253857825, 0.0504378552432172, 0.09735560015542433, 0.0877125265833456, 0.06849984463769943, 0.020568726758938283, 0.030738105488126166, 0.02910824528953526, 0.038902961896383204, 0.015422642300109146, 0.06368479051161557, 0.006154584298201371, 0.14207455446012318, 0.04117747383133974, 16.210376657545567, 68.42122614383698, 55.47576539218426, 44.22856651246548, 27.440482154488564, 39.39583383500576, 54.25419934093952, 66.75197571516037, 51.987693160772324, 62.7407019585371, 16.134620122611523, 0.6360951298847795, 0.8461684011854231, 0.07905248698079959, 3.6848012125119567, 40.99570378661156, 55.776279866695404, 52.82764948904514, 55.54117128252983, 55.11569291353226, 55.36834515631199, 46.92220777273178, 42.78658948838711, 45.66255256533623, 48.314194679260254, 49.07480366528034, 53.75709481537342, 52.527826577425, 50.69271884858608, 50.940465554594994, 50.517084673047066, 51.48540951311588, 49.44917857646942, 50.43064311146736, 51.06064550578594, 50.72483852505684, 41.14585652947426, 36.58289797604084, 37.4950048327446, 39.09739784896374, 38.96284706890583, 37.79939129948616, 39.25138458609581, 38.53295713663101, 38.57062451541424, 38.66468466818333, 38.11974070966244, 38.53619076311588, 38.01580488681793, 38.58409859240055, 37.78479628264904, 37.86856658756733, 38.246129527688026, 36.78025558590889, 38.94096404314041, 39.08749558031559, 39.11809913814068, 39.851607978343964, 40.207128301262856, 38.278663381934166, 43.15144971013069, 43.68392273783684, 40.85576489567757, 41.080545634031296, 41.62609376013279, 38.28868344426155, 39.02823396027088, 40.58198198676109, 39.46842513978481, 39.17926445603371, 38.39443936944008, 39.47751045227051, 42.77830973267555, 42.78465159237385, 43.60834859311581, 45.15017285943031, 44.314187318086624, 44.22370657324791, 43.24123129248619, 44.94314096868038, 44.20825660228729, 41.461532190442085, 42.01460771262646, 38.703940361738205, 39.269654005765915, 38.11832718551159, 39.041742235422134, 39.344593584537506, 38.82967181503773, 38.97464543581009, 39.77289140224457, 41.5021026134491, 42.85303272306919, 42.07215182483196, 39.68234986066818, 45.25907501578331, 41.15214519202709, 38.181248009204865, 38.880855068564415, 40.41332423686981, 39.39997561275959, 40.333311930298805, 39.19297032058239, 38.39391499757767, 37.39449642598629, 39.801230281591415, 38.67897570133209, 39.97507095336914, 36.96950823068619, 38.7700492143631, 38.36927331984043, 40.56044474244118, 40.12499950826168, 39.232119619846344, 38.23354460299015, 38.81177857518196, 37.383712604641914, 40.25018759071827, 40.0214284658432, 44.41582426428795, 43.96370932459831, 48.04225467145443, 45.163027569651604, 49.20437291264534, 47.2127515822649, 50.81093430519104, 45.01080013811588, 43.28099235892296, 40.149682983756065, 41.10836014151573, 39.193361699581146, 45.16443729400635, 44.10427138209343, 47.56303198635578, 45.28183579444885, 48.99216569960117, 45.40352426469326, 50.66322863101959, 48.75837564468384, 59.51534762978554, 55.22152103483677, 77.07254111766815, 29.08181358128786, 0.007453117304976331, 0.7295338378753513, 0.15895688527962193, 0.46508147672284395, 46.65194347500801, 70.50967007875443, 65.06124123930931, 59.85322929918766, 45.28284654021263, 35.154892802238464, 38.29125590622425, 56.25775583088398, 62.733596339821815, 9.493025857955217, 0.4534193978179246, 0.08350497970241122, 0.08424325336818583, 0.014171114144119201, 0.08518314629327506, 0.03979037384851836, 0.025292925311077852, 0.016416126636613626, 0.26479775668121874, 0.18426643655402586, 0.19118620664812624, 0.15089872002135962, 0.16967238450888544, 0.21580735658062622, 0.15040893224067986, 0.13781897578155622, 0.11498804931761697, 0.20298803196055815, 0.16203632316319272, 18.32569845020771, 76.72663807868958, 63.67317572236061, 51.53286516666412, 33.28388839960098, 46.01664036512375, 61.34795129299164, 70.57508736848831, 58.98842990398407, 68.7771226465702, 19.266085289418697, 0.7658662414178252, 0.6363359419628978, 0.39327290025539696, 4.262987449765205, 41.50566682219505, 57.69359618425369, 53.99370811879635, 57.88585066795349, 56.040225103497505, 59.09379445016384, 49.0244297683239, 46.1201848089695, 48.672116473317146, 51.429715901613235, 51.583622843027115, 56.96235202252865, 54.520504251122475, 52.57020190358162, 51.58505916595459, 52.759142965078354, 54.57089714705944, 53.57007645070553, 54.19548489153385, 53.33933383226395, 53.92065703868866, 41.868931129574776, 38.286209776997566, 36.59998945891857, 39.98425506055355, 41.1719611287117, 39.755875915288925, 43.03959131240845, 39.6338302642107, 42.90936090052128, 40.424723625183105, 41.2096057087183, 40.25230407714844, 39.952169582247734, 41.83938771486282, 38.31936299800873, 39.298980832099915, 42.19208098948002, 40.0537533313036, 41.776292100548744, 41.38964384794235, 40.114686861634254, 43.10781665146351, 43.95027704536915, 42.109834402799606, 46.15475155413151, 45.48838511109352, 43.51114220917225, 42.6128476113081, 44.14119780063629, 40.136056914925575, 38.91229838132858, 41.59738630056381, 41.41745075583458, 41.46101541817188, 41.148349195718765, 42.50546537339687, 43.331275060772896, 44.991679564118385, 46.099635511636734, 48.26939508318901, 47.64611452817917, 43.71361814439297, 45.942555740475655, 46.7719866335392, 46.20034530758858, 44.94894705712795, 43.171562030911446, 41.02487102150917, 40.97598284482956, 41.02542199194431, 41.63001894950867, 39.913746044039726, 41.051792576909065, 41.11941374838352, 41.56004950404167, 43.151666298508644, 44.29386980831623, 43.169563338160515, 42.28113681077957, 48.33149895071983, 45.03487944602966, 40.63282325863838, 40.862479135394096, 42.23737835884094, 42.203252390027046, 43.09536851942539, 40.13763763010502, 40.63747800886631, 39.94967691600323, 40.45889899134636, 41.435290798544884, 41.677565798163414, 38.82139965891838, 41.164186745882034, 42.42303639650345, 41.968333795666695, 42.4694737046957, 42.96929508447647, 40.844677090644836, 41.924085170030594, 39.59570311009884, 41.53497464954853, 42.24082097411156, 47.079230546951294, 46.64216659963131, 49.9002979695797, 48.381553664803505, 52.033074125647545, 50.24243921041489, 53.152410462498665, 47.40501366555691, 46.38313449919224, 41.99261449277401, 42.56362125277519, 41.752976551651955, 46.185157522559166, 48.303338661789894, 50.13788402080536, 48.613333627581596, 52.08011940121651, 46.875280290842056, 53.60528156161308, 48.90203833580017, 62.93082855641842, 58.04779037833214, 78.80834877490997, 30.69498471915722, 0.11201179222553037, 1.8483379064127803, 0.9272480348590761, 0.44810461113229394, 51.35184668004513, 75.11623129248619, 70.7366319000721, 65.35216122865677, 55.77495753765106, 50.750791132450104, 45.94715729355812, 64.90487962961197, 73.37584108114243, 12.830582465976477, 0.7393065572250634, 0.16304128017509356, 0.24322794692125171, 0.1928459308692254, 0.24317727307789028, 0.13332340138731524, 0.18705211754422635, 0.2361787314293906], [0.12293342297198251, 0.06641671032411978, 0.06264266674406826, 0.039597385766683146, 0.036776449051103555, 0.03727811490534805, 0.035401768909650855, 0.02070543592708418, 0.14380972541403025, 0.1322884764522314, 0.05576199670031201, 6.570581775158644, 55.40800362825394, 49.79967936873436, 29.968142621219158, 18.81387535482645, 37.67750144004822, 46.951367408037186, 61.26607708632946, 49.65040057897568, 57.356945648789406, 22.866093814373016, 0.2681963477516547, 0.7028833741787821, 0.3675735730212182, 0.14050509023945779, 15.791223999112844, 55.952491611242294, 50.658798068761826, 55.290821716189384, 51.32667303085327, 51.80692546069622, 45.00559821724892, 42.35118605196476, 45.10739095509052, 48.83916310966015, 52.899005860090256, 53.18469353020191, 51.48631386458874, 48.87802742421627, 47.306902930140495, 49.49382998049259, 47.20141299068928, 48.85063089430332, 47.70078979432583, 45.14478474855423, 38.076666221022606, 37.13583670556545, 36.92585237324238, 36.23446047306061, 36.23990938067436, 36.391760632395744, 36.610959470272064, 34.23503056168556, 36.41017064452171, 36.483172327280045, 36.41310028731823, 35.04268862307072, 36.17172583937645, 37.65359312295914, 36.076210364699364, 35.21822780370712, 35.65729804337025, 37.4003367125988, 36.22701287269592, 38.33375662565231, 36.308822482824326, 38.892106264829636, 38.60275559127331, 38.292768225073814, 36.824439615011215, 39.14352357387543, 43.36299955844879, 39.34974990785122, 41.75836466252804, 39.87195208668709, 38.62376466393471, 36.567801386117935, 37.73945331573486, 38.2804910838604, 37.369178384542465, 36.449471935629845, 37.88434334099293, 40.976245030760765, 40.59617802500725, 44.251099303364754, 42.049995213747025, 43.25755141675472, 42.67065770924091, 42.44428485631943, 40.912815034389496, 41.428971737623215, 40.796491876244545, 39.06312748789787, 38.05409163236618, 37.12842330336571, 37.68993057310581, 36.21689781546593, 36.71875588595867, 37.02156163752079, 38.06657016277313, 37.25287802517414, 41.208564564585686, 39.661686569452286, 40.74686273932457, 39.941469356417656, 42.680005207657814, 38.81446123123169, 36.0959655046463, 37.11596377193928, 37.36350528895855, 37.84557782113552, 39.52493190765381, 38.86976346373558, 36.46970584988594, 37.512571290135384, 36.85931034386158, 36.88760742545128, 37.41667963564396, 35.87923653423786, 37.46020630002022, 35.710255801677704, 36.41832500696182, 35.3825917840004, 37.47532568871975, 36.20807848870754, 36.214416548609734, 37.00626365840435, 40.041369795799255, 39.810893163084984, 43.57261911034584, 43.84963944554329, 46.64739891886711, 46.06645189225674, 50.32741405069828, 49.276975616812706, 51.953145414590836, 50.96030808985233, 49.878635331988335, 46.77109748125076, 44.871146231889725, 41.066832169890404, 40.00768460333347, 38.88986058533192, 39.42509986460209, 40.29491499066353, 43.67736428976059, 43.41743163764477, 48.38010214269161, 47.15693637728691, 57.08089806139469, 55.28219237923622, 68.1932307779789, 22.103431038558483, 0.23858909349655733, 0.12472281523514539, 0.2609198272693902, 0.8475171506870538, 47.91628383100033, 64.62078407406807, 62.211580350995064, 58.5152792930603, 50.76366864144802, 30.761471651494503, 25.897318460047245, 53.077524080872536, 40.952397510409355, 2.2340967692434788, 0.26253465155605227, 0.028330376189842355, 0.07039277392323129, 0.03011986678757239, 0.07413034094497561, 0.06335063109872863, 0.07586507403175347, 0.05850871493748855, 0.0017661864649198833, 0.07000804456765763, 0.03750949428649619, 0.06132792244898155, 0.03351175626448821, 0.08208339582779445, 0.04457308146811556, 0.022574187896680087, 0.04602240682288539, 0.07534981574281119, 0.0843375209660735, 9.317636769264936, 64.78213101625443, 56.368037313222885, 38.53103443980217, 20.71012370288372, 42.361000925302505, 53.548550605773926, 66.74654960632324, 54.28091950714588, 63.02405275404453, 24.293707609176636, 0.28103576973080635, 0.8976074878592044, 1.278137534391135, 0.055771388579159975, 17.621360644698143, 58.29942427575588, 51.57188147306442, 58.41359294950962, 53.1838271766901, 54.030630737543106, 45.387321934103966, 43.17275516688824, 44.9567936360836, 50.80173879861832, 53.82638409733772, 54.73403759300709, 53.693334236741066, 50.235610976815224, 49.339546859264374, 52.91691429913044, 49.14410434663296, 50.54479658603668, 50.14232598245144, 48.68825800716877, 41.302256137132645, 37.90526121854782, 37.73411840200424, 37.952154502272606, 37.919423058629036, 38.651142194867134, 39.12305407226086, 37.52328671514988, 37.69853711128235, 37.797989174723625, 38.56037266552448, 37.05574080348015, 36.870386749506, 38.93130496144295, 38.78410466015339, 38.649899661540985, 38.14899154007435, 38.006100207567215, 38.15184138715267, 39.629065319895744, 38.70665341615677, 40.30159503221512, 39.79997254908085, 40.99824205040932, 39.57396447658539, 41.491022408008575, 45.512646809220314, 42.404527589678764, 42.363744378089905, 42.458287104964256, 39.82146039605141, 39.34927873313427, 38.52275848388672, 41.02441884577274, 40.736413300037384, 37.87252217531204, 39.40183751285076, 41.9583897292614, 42.70171344280243, 44.13286104798317, 43.919198513031006, 44.964849203825, 44.46796126663685, 43.429332599043846, 43.58002111315727, 43.63207072019577, 43.32134999334812, 40.79402580857277, 40.26132479310036, 39.41300891339779, 38.96147534251213, 38.52938152849674, 39.5681431889534, 38.275266364216805, 39.301614090800285, 40.3116150945425, 42.549801394343376, 41.645856499671936, 41.67838655412197, 41.51853293180466, 45.08040860295296, 41.41481749713421, 37.97653019428253, 40.19425079226494, 40.56853070855141, 39.110780730843544, 40.69194048643112, 39.5129169523716, 39.38665732741356, 38.27451400458813, 38.75499442219734, 39.873775988817215, 39.080606549978256, 37.97531045973301, 38.39374780654907, 36.94393940269947, 38.104997500777245, 38.44147324562073, 38.93828518688679, 38.17426398396492, 39.020562171936035, 40.28761938214302, 41.0884378105402, 42.385027036070824, 44.841716811060905, 47.279555797576904, 50.04678010940552, 50.30281037092209, 51.49591974914074, 51.42956770956516, 53.39142143726349, 53.629824444651604, 52.487525939941406, 48.65694388747215, 46.89511142671108, 43.7635550647974, 41.345809400081635, 40.64421124756336, 43.16404603421688, 42.42811292409897, 45.94734348356724, 46.82168036699295, 50.89696168899536, 48.908285200595856, 59.673719331622124, 58.73384736478329, 71.0534816980362, 24.043069258332253, 0.17114572576247156, 0.475119172479026, 0.1392121205572039, 0.9155690646730363, 51.366791278123856, 69.67001393437386, 65.91277554631233, 62.850124686956406, 55.018475130200386, 39.00485381484032, 34.25653360784054, 57.44589887559414, 51.525501161813736, 4.1829385701566935, 0.3494659415446222, 0.01239088462170912, 0.06253072118852288, 0.030212167694116943, 0.09174439226626419, 0.06680311693344265, 0.007420182646455942, 0.015201646492641885, 0.1902899594279006, 0.1784324730397202, 0.08700671445694752, 0.10438094075652771, 0.11289514091913588, 0.1496663986472413, 0.15362623147666454, 0.08538527763448656, 0.11844083201140165, 0.17741037241648883, 0.21217454370344058, 10.529583636671305, 73.04821506142616, 62.73865386843681, 45.8142214268446, 27.720264941453934, 52.495353519916534, 58.897314593195915, 72.64099851250648, 58.46123859286308, 68.66429910063744, 29.442868307232857, 0.6347431743051857, 1.7260271008126438, 1.3442159886471927, 0.18862855795305222, 19.238443672657013, 59.555435478687286, 52.89258800446987, 59.85096462070942, 56.69663608074188, 56.54108002781868, 49.754697382450104, 45.82767650485039, 50.06960928440094, 52.849509716033936, 56.755498722195625, 58.25626239180565, 55.96526272594929, 53.037941604852676, 50.999404191970825, 55.270283818244934, 52.628046199679375, 54.980382174253464, 52.35908903181553, 50.602295100688934, 42.400541603565216, 40.29064022004604, 41.26505233347416, 40.66051237285137, 40.590455532073975, 40.815460458397865, 41.17423340678215, 39.65062916278839, 39.92286175489426, 40.22936090826988, 41.468615010380745, 38.58017720282078, 39.782254099845886, 41.1885092407465, 41.36222071945667, 39.1077446937561, 39.80469949543476, 41.03346236050129, 39.8041333258152, 42.1342708915472, 40.07799983024597, 43.30927424132824, 42.37689167261124, 42.51349054276943, 42.081620916724205, 42.144435346126556, 47.293181866407394, 45.518308505415916, 44.08648833632469, 43.98249551653862, 42.74927169084549, 42.068921998143196, 40.74743650853634, 42.82346270978451, 43.13530057668686, 39.88057002425194, 41.1121029406786, 45.75916238129139, 45.29107689857483, 47.09200546145439, 46.130489856004715, 47.95730642974377, 46.99524745345116, 45.89262641966343, 46.155975088477135, 47.590922489762306, 44.98596467077732, 43.018289655447006, 42.98917941749096, 41.617274433374405, 43.11143785715103, 40.75507789850235, 41.92746698856354, 41.79747596383095, 41.963686645030975, 41.93288929760456, 44.901373609900475, 44.37434948980808, 44.558829590678215, 44.26482416689396, 46.14730015397072, 44.013783037662506, 40.528792440891266, 41.73138611018658, 42.55262464284897, 41.862532272934914, 44.53507326543331, 42.05825597047806, 41.55997730791569, 40.75638882815838, 42.28687070310116, 40.89930675923824, 41.066782772541046, 38.17739121615887, 40.88152751326561, 39.461156129837036, 40.604982152581215, 40.08386671543121, 42.28079102933407, 39.27139811217785, 40.87444469332695, 44.07347783446312, 43.562036678195, 44.85145568847656, 48.3845479041338, 48.80943350493908, 53.86777527630329, 52.4528793990612, 53.968382477760315, 54.29092437028885, 58.18305931985378, 56.05812594294548, 54.88209664821625, 51.10937029123306, 50.000403597950935, 46.39798030257225, 42.76781089603901, 43.36529843509197, 44.24788847565651, 44.099825620651245, 46.751171350479126, 48.38848449289799, 54.30826283991337, 52.678613886237144, 61.06255620718002, 61.55454620718956, 73.82101759314537, 26.32176138460636, 0.3218520217342302, 1.519831521436572, 0.7501967728603631, 1.055787953082472, 56.07247777283192, 73.93739774823189, 71.24802365899086, 69.53958973288536, 66.39178544282913, 42.60456025600433, 39.49112132191658, 68.34146842360497, 63.01156282424927, 6.61069099791348, 0.42729597771540284, 0.08788844526861794, 0.23137513606343418, 0.11130436963867396, 0.22539151104865596, 0.2540418697753921, 0.14898899593390524, 0.15900934027740732], [0.026539987593423575, 0.027715276773960795, 0.04344706532720011, 0.04657633471651934, 0.017184390490001533, 0.024081654955807608, 0.03892681823344901, 0.03693645980092697, 0.04323224326071795, 0.06451542445574887, 0.017979486692638602, 4.540484184399247, 48.05122219026089, 55.68404361605644, 39.36994582414627, 24.293494820594788, 35.28678372502327, 44.28388014435768, 59.29162323474884, 49.19205017387867, 54.67979550361633, 32.08566829562187, 0.38063807354774326, 0.9356620302423835, 1.6579595720395446, 0.07588245513034053, 3.421072089113295, 46.71685539186001, 53.291809782385826, 54.696039631962776, 52.86700777709484, 47.830400839447975, 43.41466158628464, 43.26018467545509, 47.65967980027199, 52.46904753148556, 52.85421006381512, 50.034635961055756, 49.96264882385731, 48.02180416882038, 47.08137363195419, 47.570016011595726, 45.54903365671635, 44.68355029821396, 42.71722421050072, 39.171835854649544, 37.56747454404831, 34.40483205020428, 34.40443307161331, 35.408358201384544, 36.28666587173939, 35.67970544099808, 36.9827239215374, 35.70174805819988, 37.63391397893429, 37.507460564374924, 36.479532122612, 34.95480693876743, 35.72281412780285, 36.7866962403059, 35.59351846575737, 35.15528418123722, 34.967756643891335, 34.68686431646347, 37.01492339372635, 37.314400523900986, 37.818861454725266, 37.10821218788624, 38.13264101743698, 37.14373268187046, 36.96416191756725, 41.476556584239006, 41.4212391525507, 41.940815672278404, 42.077547535300255, 40.32041162252426, 37.79431477189064, 38.17130774259567, 38.8107830286026, 38.928823694586754, 36.24391056597233, 36.83761730790138, 38.20141352713108, 40.77619716525078, 41.75771489739418, 41.53241738677025, 42.92768731713295, 42.84018561244011, 43.301663249731064, 40.37247642874718, 42.196921929717064, 41.57556027173996, 41.213717088103294, 39.66961294412613, 37.37653858959675, 36.32344029843807, 36.4733612537384, 37.75578863918781, 37.990277856588364, 36.38756185770035, 38.39647985994816, 37.90822505950928, 39.79576237499714, 40.438049510121346, 39.27050895988941, 39.51209619641304, 40.29345586895943, 39.54591438174248, 37.72159427404404, 38.46391104161739, 38.12692232429981, 37.7792751789093, 38.40448223054409, 36.88704885542393, 36.80145464837551, 36.335037276148796, 36.204958856105804, 37.24468946456909, 36.44633710384369, 37.5443109869957, 37.78024412691593, 37.06057034432888, 37.07028642296791, 35.4830127954483, 36.048547849059105, 36.66875436902046, 36.754834949970245, 37.13099576532841, 38.69602158665657, 41.584972366690636, 43.63606050610542, 44.85299840569496, 47.21323035657406, 46.976681649684906, 48.62033285200596, 49.29270297288895, 53.289237320423126, 51.711550578475, 52.841807529330254, 52.086031883955, 52.96126551926136, 49.33675020933151, 48.117000460624695, 45.04328079521656, 46.565148532390594, 41.66765592992306, 42.83635921776295, 40.546594485640526, 47.22233086824417, 48.362843468785286, 62.46675565838814, 53.87936845421791, 69.26872506737709, 13.260303307324648, 0.22400841495255008, 0.6414711882825941, 0.2027712357812561, 1.929430898744613, 56.60932816565037, 61.33912816643715, 61.325403302907944, 55.53853042423725, 40.68385072052479, 18.44487715512514, 27.824290059506893, 49.77040573954582, 43.03280487656593, 1.1908798478543758, 0.3139061731053516, 0.011196008308616001, 0.07229756272863597, 0.034046622095047496, 0.05107151206175331, 0.0353956276376266, 0.04342027008533478, 0.04000802720838692, 0.01658585766563192, 0.047485231843893416, 0.07754690683213994, 0.03358603782544378, 0.16985707537969574, 0.027122473329654895, 0.059334873731131665, 0.06424000603146851, 0.04802351526450366, 0.2259725087787956, 0.07448487231158651, 5.6897092424333096, 54.9963603168726, 60.45563757419586, 43.503652811050415, 27.32265617698431, 43.47358122467995, 51.49934336543083, 66.13922819495201, 54.261464551091194, 61.60627283155918, 33.6405448615551, 0.2315674562123604, 0.38657332537695765, 2.5148853147402406, 0.09146509240963496, 4.7460085060447454, 50.633749812841415, 54.158049300312996, 55.85709013044834, 55.4401309043169, 50.668248161673546, 44.93962235748768, 46.60721607506275, 48.67530830204487, 53.9009702950716, 52.942490726709366, 51.18533581495285, 51.80455818772316, 50.70446401834488, 48.65704268217087, 49.98255975544453, 47.799812480807304, 47.90469825267792, 45.98088428378105, 40.985539332032204, 37.747182101011276, 36.551131680607796, 35.419316813349724, 36.11528366804123, 37.83221773803234, 37.3062689602375, 37.84570321440697, 36.93562164902687, 40.14364890754223, 39.54468324780464, 38.80731761455536, 37.48047821223736, 38.38952623307705, 37.19520851969719, 37.69721858203411, 37.01960474252701, 38.518536910414696, 37.68398769199848, 37.61144578456879, 39.33623403310776, 39.122263714671135, 38.166611194610596, 40.52602618932724, 40.57150214910507, 39.74881589412689, 42.51314856112003, 43.721016347408295, 44.055964574217796, 44.01284448802471, 42.12556175887585, 38.681190982460976, 39.8170830309391, 40.14195039868355, 39.9680033326149, 39.042342603206635, 39.82538938522339, 40.39996795356274, 42.55532629787922, 43.7674992531538, 43.224401995539665, 44.49427865445614, 44.36266891658306, 43.913931995630264, 42.270121201872826, 45.400750413537025, 44.94585022330284, 42.680168598890305, 41.838308572769165, 39.627351611852646, 38.65893177688122, 39.09335486590862, 39.71194267272949, 40.11388510465622, 39.83715735375881, 37.728760689496994, 39.767624884843826, 42.23944164812565, 42.198156863451004, 41.65475182235241, 41.98457792401314, 43.02255682647228, 41.870473846793175, 38.53677213191986, 40.5835323035717, 39.2678415030241, 39.492694437503815, 40.09905830025673, 38.1853061914444, 37.740768045187, 37.338848412036896, 37.149310782551765, 38.30444119870663, 39.54309493303299, 38.49857658147812, 40.0179972499609, 37.10836037993431, 39.45747792720795, 36.853637248277664, 38.59924457967281, 37.68347851932049, 39.969466254115105, 38.53733070194721, 41.1549836397171, 45.24717405438423, 46.71462871134281, 46.92293733358383, 49.25848960876465, 50.15152908861637, 50.32846659421921, 51.65266893804073, 53.5558196157217, 52.51390032470226, 56.52135528624058, 53.94562549889088, 55.54624781012535, 50.38058079779148, 50.87200082838535, 47.14947357773781, 48.33924673497677, 43.35650570690632, 44.204004630446434, 42.71514572203159, 48.50421488285065, 50.773019939661026, 64.1306483745575, 57.243221551179886, 70.00363603234291, 14.92887832224369, 0.2813810168299824, 1.3647859473712742, 0.1253780722618103, 1.8331637769006193, 59.26952362060547, 66.21692642569542, 67.65525564551353, 61.42900474369526, 51.46178238093853, 24.89013310521841, 32.70451448857784, 55.56415244936943, 51.19078852236271, 2.616499224677682, 0.3402046806877479, 0.030209091491997242, 0.11124148004455492, 0.025603784997656476, 0.03566010309441481, 0.024741472479945514, 0.0244779284184915, 0.10229929815977812, 0.11030557245248929, 0.12078892788849771, 0.18067962198983878, 0.2032644671271555, 0.20709696225821972, 0.08286691823741421, 0.2075875218724832, 0.13534541241824627, 0.11362289093085565, 0.22520619677379727, 0.2172092438559048, 6.027866397053003, 61.649563908576965, 69.31956633925438, 52.21810519695282, 34.06579524278641, 48.447050750255585, 55.14461316168308, 71.06235042214394, 59.456724375486374, 68.12219738960266, 37.69919067621231, 0.7775301905348897, 2.9944388195872307, 5.7675817888230085, 0.1813105068868026, 5.62159932218492, 51.27131760120392, 54.85029235482216, 58.28372351825237, 56.695822924375534, 52.642880603671074, 47.47976325452328, 49.27263244986534, 51.55515097081661, 56.85855679214001, 55.78721188008785, 54.30570177733898, 55.47791227698326, 54.22590605914593, 51.11608073115349, 51.95658802986145, 48.80423538386822, 50.83234615623951, 48.30544754862785, 43.616012781858444, 40.66561929881573, 38.166789785027504, 37.80202075839043, 39.07033950090408, 39.29066687822342, 40.00294625759125, 41.17054380476475, 39.59495835006237, 42.83154107630253, 43.504348173737526, 41.50353513658047, 38.964427784085274, 40.26359707117081, 39.6627277135849, 39.37999628484249, 38.79099749028683, 38.648425340652466, 39.13499303162098, 40.73518216609955, 39.70024310052395, 42.31663830578327, 40.12479431927204, 42.66183078289032, 43.78780536353588, 40.75804553925991, 45.02970412373543, 45.16333915293217, 45.108302906155586, 46.9321708381176, 45.376500114798546, 41.63470409810543, 42.883537486195564, 43.804110288619995, 42.433710023760796, 39.78358782827854, 41.04696303606033, 42.56091579794884, 45.2353984862566, 46.35044865310192, 44.347921907901764, 46.07690513134003, 45.89098110795021, 47.44249105453491, 42.624414190649986, 47.393040508031845, 45.95407672226429, 44.350289180874825, 43.689390644431114, 42.499480694532394, 39.31237131357193, 42.12218374013901, 42.20725357532501, 41.095277443528175, 40.74819266796112, 40.3818429261446, 41.94894343614578, 44.139297902584076, 44.214020892977715, 42.25407466292381, 44.57986906170845, 44.71681751310825, 43.26333850622177, 40.840637907385826, 42.30830155313015, 40.792650282382965, 40.98614349961281, 41.73872351646423, 40.43773412704468, 40.18208384513855, 39.79982815682888, 37.09234803915024, 39.36524547636509, 41.865834295749664, 42.46126614511013, 42.69017346203327, 39.71133470535278, 40.74109464883804, 40.76957032084465, 41.46366387605667, 41.04685664176941, 40.852402076125145, 41.869109719991684, 43.47241848707199, 47.999271377921104, 48.19335736334324, 48.399697691202164, 50.479679480195045, 52.26189024746418, 54.210760071873665, 54.526884108781815, 57.808068841695786, 56.750148609280586, 57.632894441485405, 57.31341518461704, 59.32891823351383, 53.32749746739864, 54.06144708395004, 49.450956881046295, 50.96338972449303, 45.41252978146076, 46.19431123137474, 44.5584762096405, 50.8379128575325, 52.67057351768017, 68.33066940307617, 57.729587852954865, 73.01078706979752, 16.33132416754961, 0.2928590727970004, 2.255332642234862, 0.7555550197139382, 2.2478636680170894, 64.93173658847809, 73.04522082209587, 69.76726591587067, 69.84718322753906, 53.84856350719929, 27.755817733705044, 42.503922656178474, 63.258997946977615, 63.872801810503006, 5.13019971549511, 0.5283551767934114, 0.12931050499901175, 0.21876241051359102, 0.15603754349285737, 0.16332598286680877, 0.07347157355980016, 0.107176225137664, 0.15166909899562597], [0.0340663186943857, 0.048863455740502104, 0.0997318456938956, 0.056623381533427164, 0.04882838184130378, 0.07649594408576377, 0.11182693808223121, 0.05220344311965164, 0.037678696535294876, 0.1416060366318561, 0.12541240401333198, 2.356007765047252, 42.82046087086201, 56.87027156352997, 39.404558166861534, 22.809649743139744, 36.87455132603645, 42.8737074136734, 58.54340918362141, 55.691430419683456, 50.93934841454029, 43.54363426566124, 1.6187025723047554, 0.4671116068493575, 2.004699516110122, 0.28074398695025593, 1.2419824744574726, 40.087632313370705, 54.84645076096058, 55.12383967638016, 51.84190258383751, 47.76603989303112, 42.38029628992081, 43.24510708451271, 50.799671709537506, 52.081567123532295, 52.922116219997406, 50.59325158596039, 48.265754878520966, 46.02881111204624, 45.94004787504673, 43.934359699487686, 41.121260449290276, 40.76020382344723, 37.14228875935078, 35.21119438111782, 34.65432666242123, 34.85861510038376, 35.64312860369682, 36.138758808374405, 34.59675595164299, 36.33830890059471, 34.44745436310768, 36.34527772665024, 36.37394338846207, 36.33817970752716, 35.46389602124691, 35.592750906944275, 38.58087256550789, 36.198768988251686, 36.05927847325802, 38.09134863317013, 35.812379121780396, 35.02587832510471, 36.51538699865341, 36.67809046804905, 37.00586088001728, 38.65666329860687, 38.75354290008545, 37.59009853005409, 35.75008526444435, 42.03948877751827, 42.930316776037216, 41.83054178953171, 40.76064459979534, 40.573793426156044, 39.94136296212673, 39.03230354189873, 38.34929779171944, 39.454920664429665, 38.8995386660099, 37.08841145038605, 37.683166936039925, 39.97569032013416, 41.52986392378807, 42.97652989625931, 42.87380240857601, 42.52156510949135, 42.43306785821915, 41.19968444108963, 41.691587045788765, 41.762031465768814, 40.36142282187939, 40.00846356153488, 39.644253104925156, 38.4283297508955, 37.263772040605545, 38.115921914577484, 38.49891096353531, 37.703978419303894, 37.21472807228565, 38.378681614995, 40.197385624051094, 40.75524128973484, 39.682532250881195, 39.22735467553139, 41.5731929987669, 38.61671224236488, 36.574542224407196, 36.789306700229645, 37.64105759561062, 37.274362072348595, 38.712721690535545, 37.39951595664024, 38.23123052716255, 36.928352639079094, 37.505180686712265, 36.77592761814594, 37.146814316511154, 36.85822360217571, 37.19362020492554, 35.875045359134674, 36.31963290274143, 35.78479640185833, 37.51195952296257, 36.81080974638462, 34.61180314421654, 36.8613014370203, 37.698833495378494, 40.01403786242008, 39.18979749083519, 42.0645522326231, 45.75396426022053, 47.52679333090782, 48.59219156205654, 47.02703274786472, 51.58690966665745, 50.84906525909901, 53.46788853406906, 53.16365785896778, 51.68123200535774, 53.99948760867119, 54.72544625401497, 52.38722272217274, 52.30308383703232, 51.63339637219906, 48.5618843883276, 41.53451107442379, 43.43756675720215, 51.09295517206192, 61.948125287890434, 60.31458914279938, 62.237665951251984, 6.378053706139326, 0.3606098232557997, 0.3873383312020451, 0.21086570690385997, 3.235573642887175, 60.10804362595081, 62.44084484875202, 64.15159285068512, 51.13765977323055, 41.538014486432076, 47.443839982151985, 46.3472606241703, 48.444478288292885, 38.246969282627106, 0.2891527576139197, 0.15623583050910383, 0.08137647047988139, 0.03855552917229943, 0.07292072186828591, 0.07120022317394614, 0.060405306721804664, 0.0279499401585781, 0.017045189561031293, 0.03882048331433907, 0.028712745515804272, 0.09534177501336671, 0.03145920956740156, 0.03443800851528067, 0.12114163357182406, 0.012865674525528448, 0.05466180358780548, 0.04246411299391184, 0.07285896776011214, 0.061788870370946825, 2.692852090112865, 49.992515221238136, 63.97785857319832, 46.48549720644951, 28.58531892299652, 41.651275008916855, 51.02467283606529, 62.48534046113491, 59.323621317744255, 54.6677615493536, 48.30170854926109, 1.278342604637146, 0.37881788215599954, 2.973533528856933, 0.515079164179042, 1.437616995535791, 43.15588407218456, 57.8119408339262, 57.31887549161911, 53.165040984749794, 48.45816135406494, 44.67905513942242, 46.24192267656326, 51.25515326857567, 53.70909959077835, 54.65778708457947, 53.5454423725605, 50.7757443934679, 48.93495976924896, 48.809334710240364, 46.596200466156006, 43.645890578627586, 42.52055436372757, 38.23450595140457, 37.68950119614601, 35.84081679582596, 37.25974425673485, 37.293965220451355, 37.140331864356995, 36.105863973498344, 37.536745592951775, 36.73288352787495, 39.32465225458145, 38.5699063539505, 39.247915372252464, 38.64293843507767, 38.50548841059208, 39.33586165308952, 38.34778547286987, 37.54027180373669, 40.50985425710678, 37.489042952656746, 36.878221929073334, 37.821312323212624, 37.375299856066704, 38.93818639218807, 39.229273572564125, 39.66490879654884, 38.63778971135616, 38.26974146068096, 42.61776454746723, 44.58319768309593, 43.59661482274532, 41.06096148490906, 42.586811408400536, 40.67642591893673, 40.69319821894169, 40.68962641060352, 40.13953372836113, 38.60538125038147, 37.6984117180109, 40.42230315506458, 43.00351984798908, 42.680993154644966, 43.81395936012268, 46.00979693233967, 45.204034969210625, 44.18744891881943, 43.7276241928339, 42.942878901958466, 44.594091698527336, 42.89937503635883, 41.76535628736019, 40.27442269027233, 39.00695130228996, 38.86970266699791, 39.37689945101738, 41.67809396982193, 40.58517001569271, 38.70857231318951, 39.63180497288704, 40.40069751441479, 41.53840586543083, 40.47389678657055, 41.67810536921024, 43.12696762382984, 40.03967888653278, 38.93991529941559, 39.02784638106823, 39.532664492726326, 38.89657482504845, 40.16440339386463, 38.08295488357544, 38.967395424842834, 36.750092804431915, 39.378438368439674, 40.16879975795746, 40.102964490652084, 38.520140424370766, 38.01297403872013, 37.4939788877964, 39.45518285036087, 38.19399632513523, 39.50843699276447, 38.303814232349396, 38.81077542901039, 39.17792692780495, 40.453742668032646, 42.87424698472023, 41.95822633802891, 44.94748793542385, 48.95316459238529, 48.8290898501873, 51.81267835199833, 49.75684426724911, 53.61222378909588, 52.59995050728321, 54.76969487965107, 53.53213548660278, 56.02927029132843, 55.498598366975784, 55.8937581628561, 54.20398123562336, 54.419764056801796, 54.92506854236126, 50.19650347530842, 42.205273881554604, 46.47525295615196, 52.758132219314575, 64.47378516197205, 61.776587292551994, 65.4703576862812, 7.821292737498879, 0.13876546639949083, 0.9990796772763133, 0.18468805064912885, 3.4960432536900043, 64.43086266517639, 66.70511662960052, 67.92955532670021, 57.264306619763374, 45.910063683986664, 38.59114721417427, 48.21938596665859, 55.60283437371254, 47.56986401975155, 0.9523566719144583, 0.12212520930916071, 0.03635683504398912, 0.07658157308469526, 0.018637500797922257, 0.027707957342499867, 0.05117981738294475, 0.0891990409581922, 0.05595607573923189, 0.08340463391505182, 0.08554367421311326, 0.30518311774358153, 0.15385567385237664, 0.10958832383039407, 0.15496932581299916, 0.19973421905888245, 0.1400805966113694, 0.20658829424064606, 0.23069556627888232, 0.2024942365824245, 2.9726125532761216, 56.578378826379776, 71.36418342590332, 52.825533002614975, 33.13690848648548, 49.76174600422382, 54.21534262597561, 69.55968305468559, 65.98676517605782, 60.13610512018204, 53.06903153657913, 2.506231516599655, 1.6184991644695401, 7.363712266087532, 1.1404762649908662, 2.0441359374672174, 44.78731133043766, 58.638240694999695, 59.36071492731571, 55.88840804994106, 52.247823402285576, 47.728543505072594, 47.59882226586342, 53.68319258093834, 56.19711108505726, 56.69474758207798, 55.13479068875313, 52.83044993877411, 51.948737651109695, 50.502934232354164, 49.582448825240135, 45.41377231478691, 44.65002849698067, 39.618783071637154, 39.61717575788498, 38.909007757902145, 40.15629082918167, 41.177744418382645, 39.233320355415344, 37.33857482671738, 39.573120921850204, 38.58686864376068, 41.40818305313587, 40.877826511859894, 41.471780240535736, 41.524901390075684, 40.649641156196594, 43.16884137690067, 40.169791504740715, 39.04356233775616, 44.72521126270294, 39.338966086506844, 38.86612705886364, 40.150822922587395, 40.24808630347252, 40.700835809111595, 41.70733720064163, 42.37513616681099, 41.1522401869297, 40.17722770571709, 45.09891360998154, 46.201595440506935, 45.34951016306877, 44.97486166656017, 44.605255499482155, 43.52113947272301, 43.90757113695145, 43.958412408828735, 43.25036980211735, 42.48801290988922, 40.149511992931366, 42.83672399818897, 46.898364052176476, 45.0982828438282, 48.36419239640236, 47.66687661409378, 45.87132856249809, 45.52741281688213, 45.6816503405571, 45.05243070423603, 45.5600530654192, 45.163928121328354, 43.96677955985069, 43.767176270484924, 43.413134068250656, 41.64776399731636, 41.95082053542137, 42.08394259214401, 43.43593284487724, 41.97445526719093, 41.14532835781574, 43.78388777375221, 44.418043345212936, 43.10095801949501, 42.78532415628433, 46.53053238987923, 42.40728244185448, 40.84045171737671, 40.225933492183685, 41.378198862075806, 41.444828286767006, 41.93824701011181, 39.784233793616295, 40.29227793216705, 40.35330265760422, 42.0727863907814, 42.423720359802246, 41.261206939816475, 41.01336523890495, 41.1546378582716, 39.22528378665447, 40.51053822040558, 40.39396807551384, 42.07992620766163, 41.10522150993347, 38.820844888687134, 40.498796850442886, 41.97996497154236, 45.7321572303772, 43.676836118102074, 46.16909958422184, 52.00719751417637, 51.47623300552368, 53.169938921928406, 50.51524177193642, 55.09007848799229, 55.067952275276184, 57.065843269228935, 55.29847450554371, 56.53137154877186, 58.640839755535126, 58.7497229129076, 59.25888039171696, 57.92447179555893, 56.9469628483057, 52.79855065047741, 46.736576333642006, 48.79930704832077, 55.672264248132706, 66.9913324713707, 63.37924249470234, 67.35393181443214, 9.26091531291604, 0.3998390369815752, 2.5574114453047514, 0.42052331613376737, 3.985096486285329, 68.28771650791168, 70.86545258760452, 72.87859216332436, 61.77125237882137, 57.19389259815216, 57.91459232568741, 59.91306468844414, 64.47124689817429, 60.284479558467865, 1.6112523595802486, 0.18469281523721293, 0.1343026800896041, 0.17361957114189863, 0.17032209027092904, 0.12812569591915235, 0.19441631535300985, 0.17183767457026988, 0.2822881587781012], [0.039887847524369135, 0.060255630378378555, 0.006085432369218324, 0.013034524254180724, 0.0021402008314908016, 0.06096651508414652, 0.019345433611306362, 0.02305051497387467, 0.03075088341574883, 0.06562178110470995, 0.07225632900372148, 0.6787909450940788, 29.433864690363407, 58.35530407726765, 44.845300018787384, 32.91075602173805, 30.600432492792606, 43.78616765141487, 52.52650044858456, 57.7091221511364, 47.820984944701195, 55.490839183330536, 4.759749993681908, 0.35975273174699396, 1.8479987746104598, 0.7404289219994098, 0.8824218402151018, 33.19894775748253, 62.091966569423676, 53.88055019080639, 55.08001282811165, 42.58894309401512, 43.9178229868412, 45.963222831487656, 54.83510456979275, 50.92991732060909, 51.48455075919628, 49.60434325039387, 46.27632983028889, 42.37604811787605, 41.588281989097595, 38.790480718016624, 36.484665647149086, 34.28218603134155, 35.609112828969955, 34.79147270321846, 36.22521176934242, 35.43941393494606, 35.98327495157719, 35.724208652973175, 37.10865676403046, 37.08061806857586, 38.230983540415764, 36.15097135305405, 37.91357897222042, 35.98462387919426, 36.14549204707146, 36.11541286110878, 37.13978849351406, 36.057990342378616, 36.10923819243908, 35.667964071035385, 36.94407619535923, 37.33225576579571, 38.04359279572964, 35.15450522303581, 36.546131148934364, 37.09952965378761, 39.20273959636688, 35.92279739677906, 36.52893327176571, 42.030753046274185, 42.51100927591324, 40.97467951476574, 41.119322553277016, 39.422516003251076, 39.41843502223492, 37.11694411933422, 39.487154334783554, 37.58191376924515, 37.64123618602753, 37.7991709113121, 38.474615067243576, 40.955631136894226, 40.74640676379204, 41.466471925377846, 43.918700739741325, 44.79895390570164, 40.98985590040684, 41.10472373664379, 42.8761088848114, 44.659820571541786, 42.37195573747158, 41.060007736086845, 38.762928396463394, 36.79483540356159, 37.47229725122452, 38.058092817664146, 39.76962357759476, 37.635540291666985, 38.872647508978844, 37.31204845011234, 39.61500607430935, 41.62336550652981, 41.298114359378815, 39.067280665040016, 39.98270854353905, 38.33324745297432, 35.75614973902702, 39.31205973029137, 39.12903115153313, 35.814153626561165, 37.58337289094925, 37.062538638710976, 37.44539089500904, 37.14947037398815, 37.525992169976234, 37.533907145261765, 36.84246584773064, 37.12458550930023, 36.927847266197205, 37.28258863091469, 36.510766446590424, 35.7056238502264, 36.599290296435356, 36.295238211750984, 38.19212302565575, 37.829478085041046, 36.63459800183773, 35.98116986453533, 40.85131913423538, 40.509755462408066, 42.542999759316444, 43.52149285376072, 48.14280867576599, 49.4295222312212, 48.6190827190876, 51.80979810655117, 52.89387233555317, 53.6941359937191, 54.45761002600193, 51.06902785599232, 48.951872661709785, 42.22558379173279, 46.49147808551788, 55.08626729249954, 53.79820480942726, 46.8204340338707, 40.52275836467743, 51.00353077054024, 57.784133926033974, 59.78574112057686, 52.01140768826008, 2.095475932583213, 0.18178438302129507, 0.7649250794202089, 0.17604945169296116, 5.7842557691037655, 63.373185619711876, 59.47153598070145, 64.55354288220406, 49.10647116601467, 30.74229598045349, 26.446672081947327, 30.081674829125404, 50.7013063877821, 29.58106119185686, 0.2849225455429405, 0.09339014926808886, 0.012380968601064524, 0.05367481026041787, 0.030854687611281406, 0.09207130831782706, 0.025185684971802402, 0.04557606065645814, 0.12788280582753941, 0.07016926872893237, 0.02425247323117219, 0.04923481530568097, 0.023215034270833712, 0.04329991599661298, 0.04202220115985256, 0.03084434021729976, 0.053403700003400445, 0.012637869513127953, 0.12064032765920274, 0.08624059541034512, 1.197508592158556, 36.880820989608765, 65.31322091817856, 49.09761004149914, 32.8569471091032, 34.34845447540283, 49.5089265704155, 59.36017535626888, 64.27112683653831, 51.72312095761299, 58.70885610580444, 4.874232625588775, 0.45729973178822547, 1.8523692525923252, 0.8541573537513614, 1.1432964261621237, 34.70727302134037, 63.210607543587685, 54.95317183434963, 56.84956267476082, 45.38417190313339, 44.99622032046318, 47.58168898522854, 56.673734709620476, 52.27298945188522, 52.550081983208656, 51.38962045311928, 49.95760269463062, 44.021910801529884, 45.392440259456635, 40.69263204932213, 38.23786497116089, 36.09115116298199, 37.927216440439224, 36.40843793749809, 37.828379943966866, 36.694619581103325, 36.423181146383286, 37.024574875831604, 39.49256904423237, 39.18921612203121, 40.26579335331917, 38.718398585915565, 38.594350442290306, 38.83730560541153, 38.85753192007542, 38.87991651892662, 39.70280036330223, 38.07510830461979, 38.50042708218098, 37.79264286160469, 38.088601380586624, 38.677881360054016, 39.966190829873085, 37.806401923298836, 38.045682683587074, 38.47290895879269, 41.34318754076958, 36.96250140666962, 38.195740431547165, 44.27099883556366, 44.051161631941795, 43.558833450078964, 42.582206055521965, 41.88277758657932, 41.19294360280037, 39.57057125866413, 41.03348895907402, 39.90509390830994, 39.47752185165882, 38.84646691381931, 40.024897679686546, 42.26108528673649, 42.13973119854927, 43.79026383161545, 45.599152967333794, 44.136596247553825, 41.90355107188225, 42.884438037872314, 43.519988134503365, 44.71014127135277, 44.088943004608154, 42.2662416100502, 40.46135365962982, 38.77495475113392, 39.46761958301067, 38.33327405154705, 42.90120653808117, 38.731903061270714, 40.578220188617706, 38.7922628223896, 42.19864323735237, 41.57012656331062, 42.36279062926769, 41.1313983052969, 41.56519442796707, 40.06706401705742, 39.79225896298885, 41.309057772159576, 38.35036553442478, 37.07078419625759, 39.0407694876194, 40.03847815096378, 37.84887984395027, 39.016181007027626, 38.99923011660576, 38.75779487192631, 39.00652572512627, 37.358725145459175, 39.62394319474697, 38.77626188099384, 37.56561644375324, 38.40820223093033, 38.501042649149895, 37.73501515388489, 39.54948619008064, 38.7470718473196, 39.47770804166794, 38.87477159500122, 41.696097403764725, 43.481906577944756, 45.695409402251244, 47.423241287469864, 49.97286647558212, 51.43180198967457, 49.12721045315266, 53.04398328065872, 53.96849267184734, 55.41812248528004, 56.55090630054474, 52.70519345998764, 51.83282107114792, 44.15863886475563, 48.412784188985825, 56.89046747982502, 53.81566487252712, 49.017498940229416, 43.4509002417326, 52.76920102536678, 61.43758088350296, 61.4635106921196, 53.95640932023525, 2.3662489280104637, 0.8559961582068354, 2.407687366940081, 0.352767133153975, 5.294999247416854, 68.99773120880127, 63.74555043876171, 69.34173434972763, 54.399670735001564, 40.24889945983887, 29.427137151360512, 36.22625291347504, 57.6105060428381, 38.693711310625076, 0.3854433016385883, 0.05715055129257962, 0.0076673540024785325, 0.0905190322373528, 0.016205382671614643, 0.045948856277391315, 0.04141768476983998, 0.06550835867528804, 0.011672651726257754, 0.1493194149225019, 0.1709409969043918, 0.07250927519635297, 0.14278041111538187, 0.20589603373082355, 0.16882492607692257, 0.12001920200418681, 0.10654623081791215, 0.10607153832097538, 0.2806340006645769, 0.23012104007648304, 1.4180665696039796, 42.00534760951996, 75.82670956850052, 57.43576481938362, 43.223425447940826, 41.77166014909744, 55.46407341957092, 63.35930496454239, 69.28215354681015, 54.465733990073204, 66.03197515010834, 6.51631023734808, 0.8184700843412429, 6.21554022654891, 2.820204868912697, 1.434098978061229, 37.144363448023796, 64.50576424598694, 57.74158760905266, 59.252644926309586, 46.827729642391205, 48.07749018073082, 48.67315001785755, 59.122919887304306, 53.23706991970539, 54.89164933562279, 53.31543691456318, 51.421268954873085, 46.09439559280872, 48.29078033566475, 42.79690593481064, 39.95125763118267, 38.414612486958504, 40.994039475917816, 38.74289967119694, 39.507821425795555, 40.88178589940071, 39.07992258667946, 39.31895636022091, 41.7592766135931, 40.98585471510887, 41.98890969157219, 40.97719497978687, 41.81811645627022, 40.117422714829445, 40.7574375718832, 41.13983005285263, 41.4969576895237, 40.19165173172951, 40.96209459006786, 39.97106596827507, 40.297134071588516, 40.33272676169872, 42.459871619939804, 39.52226065099239, 38.380228132009506, 40.301325246691704, 43.066729456186295, 39.69276510179043, 39.28391844034195, 48.17758820950985, 48.19239981472492, 46.15773059427738, 44.37800869345665, 43.18517290055752, 43.39372470974922, 42.441932782530785, 42.687988579273224, 41.51354379951954, 42.349757328629494, 40.5192169547081, 42.678135707974434, 43.491596058011055, 44.826187044382095, 45.13441510498524, 48.904622197151184, 49.229322373867035, 45.35672977566719, 45.00506244599819, 44.89774480462074, 49.51589159667492, 48.359917625784874, 45.71572311222553, 41.2976735830307, 40.54344825446606, 41.59851863980293, 42.21018701791763, 45.677607357501984, 40.509436279535294, 43.50388839840889, 40.558385252952576, 42.55001038312912, 43.97583827376366, 45.2773330360651, 44.2210391163826, 43.87106269598007, 42.235159277915955, 41.31108686327934, 44.386752024292946, 41.04450836777687, 38.0334435403347, 41.48606367409229, 41.81407727301121, 39.46197308599949, 40.52936241030693, 41.6495992988348, 42.060174867510796, 39.70420628786087, 39.83334615826607, 42.1402707695961, 41.165026500821114, 40.28847813606262, 40.72115331888199, 41.79560646414757, 40.71359932422638, 41.55936174094677, 41.771774142980576, 41.27721928060055, 40.12642063200474, 44.62563760578632, 45.47699332237244, 48.5236432403326, 48.94955858588219, 53.342050686478615, 54.252968207001686, 51.51070475578308, 55.934415981173515, 56.096872463822365, 56.61511145532131, 57.634634748101234, 54.22076493501663, 52.77511350810528, 44.82690140604973, 47.58156359195709, 59.252188950777054, 56.452708169817924, 50.71364812552929, 46.633339673280716, 55.86049094796181, 65.53095683455467, 62.96610966324806, 58.53234797716141, 3.692621667869389, 0.8420618902891874, 5.75532934628427, 0.5239947326481342, 6.762261539697647, 73.08624342083931, 69.72566574811935, 74.85251784324646, 62.067381888628006, 46.515754982829094, 34.577844366431236, 45.466958060860634, 66.76459863781929, 48.37146520614624, 0.9107953333295882, 0.14222056459402665, 0.1043107855366543, 0.1657714633620344, 0.11336932875565253, 0.20303935889387503, 0.16367948264814913, 0.1509136223467067, 0.20539472781820223], [0.0015272590940185182, 0.010815344994625775, 0.032693582979845814, 0.05088291749416385, 0.04691983776865527, 0.03089146102865925, 0.06356833269819617, 0.022454863537859637, 0.10494475776795298, 0.021245203643047716, 0.19519245339324698, 0.1522719900822267, 18.95848609507084, 58.91010470688343, 42.374566197395325, 31.154775246977806, 25.382873564958572, 37.601361125707626, 47.83683389425278, 59.979880303144455, 47.38786518573761, 55.805101320147514, 14.121346604079008, 0.5258449364919215, 1.344162079039961, 0.5079048522748053, 0.5678872461430728, 26.4252982288599, 59.9118335545063, 52.52681963145733, 52.955850809812546, 41.43472082912922, 46.229987516999245, 48.28381530940533, 51.17501936852932, 51.997040659189224, 51.947913095355034, 48.38557384908199, 46.28327585756779, 43.14646057784557, 39.024696350097656, 37.73184232413769, 36.66204392910004, 35.72333849966526, 35.353477746248245, 34.64388482272625, 35.99343180656433, 34.11239214241505, 35.662887543439865, 36.26895122230053, 36.63896396756172, 37.07277908921242, 35.10674558579922, 37.381664514541626, 37.860055044293404, 36.416132524609566, 37.718007266521454, 36.80175103247166, 36.72407940030098, 38.41888725757599, 37.44641304016113, 36.267644092440605, 38.06780509650707, 36.63125418126583, 38.60016793012619, 35.684170201420784, 36.99443869292736, 37.183052971959114, 38.29388156533241, 36.83346413075924, 38.42517592012882, 40.6761409342289, 42.99873970448971, 39.993135184049606, 39.90909889340401, 40.29244512319565, 39.61471728980541, 37.42072641849518, 39.85622473061085, 37.87379510700703, 37.82976686954498, 35.70950724184513, 39.376739859580994, 41.14946633577347, 42.915626764297485, 43.08387033641338, 43.800010308623314, 43.35831820964813, 42.06606075167656, 41.082517728209496, 44.16575588285923, 42.610453739762306, 41.80287927389145, 39.04751032590866, 39.98639814555645, 36.715784445405006, 37.09381476044655, 37.16949909925461, 37.580203860998154, 39.352018386125565, 38.12167100608349, 37.54473276436329, 39.411633387207985, 43.308293893933296, 38.986998572945595, 39.236519783735275, 40.77023148536682, 37.53718636929989, 37.14662812650204, 38.76284100115299, 36.89412407577038, 37.48436540365219, 38.47389690577984, 36.01313374936581, 37.59664937853813, 36.794520020484924, 39.31091979146004, 38.39080296456814, 36.25614210963249, 35.91970056295395, 36.18828535079956, 36.55909605324268, 36.4043303579092, 35.0467050075531, 36.58158324658871, 35.539086386561394, 38.1335985660553, 37.36915558576584, 35.47761328518391, 35.91669872403145, 37.12719216942787, 36.92134961485863, 38.34328271448612, 41.86022199690342, 43.35677169263363, 45.02308487892151, 46.1607476323843, 48.279019966721535, 51.15976698696613, 51.78673334419727, 54.56379912793636, 53.05928125977516, 55.56091882288456, 55.274554789066315, 51.58630169928074, 56.049770191311836, 54.78329814970493, 50.6275599449873, 40.64451903104782, 50.97740337252617, 55.65401382744312, 64.87375929951668, 38.88544142246246, 0.47889421053696424, 0.8514528488740325, 0.5191787879448384, 0.2733405592152849, 8.038421161472797, 59.84051138162613, 62.030387073755264, 61.37263856828213, 49.433455020189285, 30.090724043548107, 23.444447480142117, 42.14321181178093, 51.98556147515774, 24.576043859124184, 0.29344777402002364, 0.11163953837240115, 0.06707068343530409, 0.04228849116771016, 0.04581170367600862, 0.019130568871332798, 0.00980902985247667, 0.025805092554946896, 0.0704690147540532, 0.03541051883075852, 0.010578618439467391, 0.032123973505804315, 0.08923902045353316, 0.026527419322519563, 0.09483367102802731, 0.021721115117543377, 0.043899964657612145, 0.08987461056676693, 0.04651935632864479, 0.19348261936102062, 0.2516029350226745, 25.56127019226551, 65.75553998351097, 50.24747774004936, 37.437574714422226, 32.25011587142944, 45.77205888926983, 51.60473071038723, 67.39268973469734, 51.48672804236412, 63.75509172677994, 14.397189002484083, 0.5664525856263936, 1.4259796449914575, 1.3888891227543354, 0.5147387261968106, 29.31984230875969, 61.42278827726841, 54.082604348659515, 54.27747309207916, 43.996520563960075, 48.8961448520422, 50.95517456531525, 53.30690257251263, 52.755061984062195, 54.002846628427505, 50.72314381599426, 49.32394489645958, 44.05493102967739, 42.99164928495884, 38.87851819396019, 38.56057785451412, 37.78261139988899, 37.59608320891857, 35.66321052610874, 37.0220822095871, 36.32461063563824, 38.43455761671066, 37.78580702841282, 37.856129854917526, 37.524156868457794, 38.16394753754139, 38.34840103983879, 40.34249983727932, 39.262536987662315, 39.06804822385311, 37.906629145145416, 38.353481367230415, 40.310304164886475, 38.25585700571537, 36.55956722795963, 39.38911959528923, 38.6580616235733, 39.01099808514118, 37.77542978525162, 38.64890791475773, 39.073265343904495, 40.63747800886631, 38.35319258272648, 40.02501167356968, 43.372993022203445, 42.62864336371422, 40.89609593153, 42.99862191081047, 42.13815428316593, 41.239392310380936, 40.07345147430897, 40.53721658885479, 39.48732532560825, 39.92253877222538, 38.01771238446236, 41.146779879927635, 42.37885616719723, 43.861152827739716, 43.933405950665474, 45.954639092087746, 46.35934017598629, 42.62445218861103, 43.953446075320244, 45.870241820812225, 44.48634847998619, 43.829534724354744, 42.44295872747898, 40.90884044766426, 38.706205040216446, 39.0304796397686, 38.32412414252758, 38.412940576672554, 40.946352034807205, 40.01865081489086, 40.125261694192886, 41.227901726961136, 45.06567679345608, 41.21600456535816, 41.1706729978323, 42.02565751969814, 38.8835833221674, 39.58699397742748, 40.68485006690025, 39.272028878331184, 39.44027625024319, 41.32479652762413, 37.73685805499554, 38.46845559775829, 37.38792657852173, 39.987070709466934, 40.08409470319748, 37.23199054598808, 37.74994075298309, 38.427022621035576, 38.27913835644722, 37.78732314705849, 39.01958182454109, 38.07050675153732, 37.39988453686237, 39.562154710292816, 39.53722804784775, 38.48857171833515, 37.40210361778736, 39.194262251257896, 38.55321764945984, 41.177881211042404, 43.21687459945679, 45.41042469441891, 47.48301587998867, 49.84243847429752, 50.506373047828674, 53.11128906905651, 55.20265504717827, 56.421675235033035, 54.82881970703602, 55.75931377708912, 55.904617980122566, 53.259420320391655, 56.7499016225338, 55.80591067671776, 51.19711138308048, 42.77687340974808, 54.06534947454929, 58.4954709559679, 66.74752235412598, 41.49145558476448, 0.5929878680035472, 2.347130491398275, 4.116985509172082, 0.3767789650009945, 8.208141904324293, 65.14736741781235, 65.61832934617996, 69.27272245287895, 56.958198845386505, 39.5178946852684, 25.251674205064774, 45.55096015334129, 58.81244234740734, 31.140970587730408, 0.4178006434813142, 0.080330027412856, 0.07916324510006234, 0.06720242206938565, 0.06871612873510458, 0.05861204044776969, 0.06671644892776385, 0.04002839545137249, 0.01935134110681247, 0.12021471338812262, 0.18730271112872288, 0.12492858309997246, 0.14304517972050235, 0.10914645652519539, 0.21011057164287195, 0.11904232043889351, 0.08564834672142752, 0.18869567778892815, 0.11797838495112956, 0.29710751201491803, 0.4501132189761847, 31.34727291762829, 75.20887032151222, 57.08149462938309, 43.5923932492733, 38.17985348403454, 49.5819890499115, 57.180802300572395, 72.09274873137474, 56.826243326067924, 67.46275037527084, 18.227031044662, 0.8294300618581474, 6.3597263395786285, 2.3873919434845448, 0.8541150216478854, 32.6823540776968, 61.1226461827755, 56.99139766395092, 58.991093561053276, 46.210274174809456, 51.66391633450985, 53.1047648191452, 55.56789144873619, 54.31215763092041, 55.2827737480402, 54.28045213222504, 52.4839161336422, 47.42840141057968, 45.146760642528534, 42.34503798186779, 41.33694067597389, 39.455118253827095, 39.97239209711552, 37.48882256448269, 41.356760412454605, 38.43499079346657, 40.671250596642494, 42.12191395461559, 39.13631536066532, 39.813150241971016, 38.783226907253265, 41.30421683192253, 42.661800384521484, 41.23894013464451, 41.30620412528515, 40.32112218439579, 41.050257459282875, 42.77295961976051, 40.80770127475262, 38.60921524465084, 42.70822249352932, 41.14572733640671, 42.24636867642403, 39.79310631752014, 41.272062957286835, 40.73409542441368, 43.14866445958614, 39.15619969367981, 42.20949925482273, 46.65290102362633, 48.40942896902561, 42.89477728307247, 44.473634362220764, 44.195044711232185, 43.6355285346508, 39.87211927771568, 42.345376163721085, 41.754238083958626, 42.7898421138525, 39.15175013244152, 45.558825731277466, 45.848871767520905, 46.50023281574249, 47.752212435007095, 48.900902196764946, 50.110989063978195, 45.41821047663689, 45.10658539831638, 47.77122661471367, 46.205076053738594, 46.78789637982845, 44.61133897304535, 43.477867394685745, 40.32033562660217, 41.55597612261772, 40.451212003827095, 41.60208284854889, 44.146388322114944, 42.73085407912731, 42.73115426301956, 44.09000314772129, 46.88725724816322, 44.18189361691475, 42.97899216413498, 42.97764703631401, 40.878548473119736, 40.937631502747536, 44.32746760547161, 41.815893575549126, 41.48001819849014, 42.737914100289345, 39.4913113117218, 40.24459809064865, 39.14994142949581, 44.7728531062603, 42.981553226709366, 38.89403276145458, 39.79637414216995, 39.53819319605827, 40.78730396926403, 39.93544667959213, 41.35078713297844, 40.180510729551315, 39.93477411568165, 42.70626559853554, 41.67717441916466, 39.37744662165642, 40.28696581721306, 41.377761885523796, 39.87028017640114, 43.055341467261314, 47.219796404242516, 47.51887835562229, 50.610647052526474, 52.376940473914146, 54.56559643149376, 57.06427775323391, 59.64427471160889, 57.83149838447571, 56.15126274526119, 57.20760226249695, 56.3205436617136, 53.674209862947464, 58.57800632715225, 59.330935925245285, 53.818146139383316, 45.675266683101654, 56.44820921123028, 60.65331056714058, 69.08739119768143, 44.41365458071232, 1.0184994852170348, 1.377172451466322, 3.135577733628452, 0.5641128018032759, 9.183999840170145, 71.07334703207016, 69.1064889729023, 72.6821731030941, 60.668407157063484, 42.879783287644386, 32.28139579296112, 57.16977149248123, 66.99301198124886, 40.28522551059723, 0.6794145272579044, 0.24130039644660428, 0.14358820917550474, 0.17830716882599518, 0.13082399644190446, 0.15114931360585615, 0.17521103261969984, 0.18107589916326106, 0.09885936946375296], [0.016889026846911293, 0.15513296937569976, 0.024616316695755813, 0.06973241834202781, 0.04765777375723701, 0.07023413985734805, 0.023552297716378234, 0.07590114983031526, 0.0936467171413824, 0.059193720953771845, 0.1303889197879471, 0.07677242378122173, 11.83487344533205, 55.66409468650818, 47.37515486776829, 36.46050654351711, 20.03238257020712, 38.069788590073586, 48.24079401791096, 60.317305997014046, 47.78627760708332, 55.78745126724243, 24.475928731262684, 0.10639332613209262, 0.5855549918487668, 0.7605354837141931, 0.26529986411333084, 19.175923727452755, 56.41978673636913, 51.7281860858202, 50.61637334525585, 45.25025188922882, 48.91069047152996, 51.10583268105984, 52.33217507600784, 51.065125465393066, 49.25994873046875, 47.77673251926899, 47.417317405343056, 40.56478410959244, 35.844054222106934, 37.88528949022293, 36.294862031936646, 35.689546912908554, 36.46544247865677, 35.7377815246582, 35.85101164877415, 36.0242785513401, 37.60491393506527, 36.05998523533344, 39.21669244766235, 39.74902108311653, 42.57070027291775, 40.86327709257603, 39.75000523030758, 37.143272906541824, 38.552115708589554, 37.44402676820755, 35.12086182832718, 36.52640640735626, 37.69361637532711, 36.75000920891762, 38.28465186059475, 34.767226204276085, 36.51156060397625, 37.10517235100269, 36.80691495537758, 39.24775958061218, 38.34818445146084, 37.33333110809326, 37.87365451455116, 39.110336154699326, 39.336625412106514, 39.04341034591198, 40.87819889187813, 40.4719702899456, 41.506757363677025, 39.94300067424774, 38.392729461193085, 36.804433688521385, 38.163077384233475, 37.02966660261154, 36.53677225112915, 41.8470861017704, 41.68562896549702, 42.48415991663933, 42.57859244942665, 43.69468756020069, 45.07007695734501, 40.43849028646946, 41.20611369609833, 40.089638605713844, 40.27651257812977, 40.253098234534264, 39.69664469361305, 37.70358324050903, 37.24993318319321, 36.862410977482796, 36.75054498016834, 37.64556795358658, 38.60265299677849, 38.37643973529339, 38.29873390495777, 39.46638464927673, 40.26617333292961, 40.12156829237938, 39.44962374866009, 41.31290316581726, 36.4315140992403, 37.000085189938545, 37.07548454403877, 37.92297586798668, 38.02097260951996, 36.51294372975826, 35.08539833128452, 36.78434796631336, 35.96780598163605, 37.90510542690754, 37.839938923716545, 36.6125325858593, 36.78902551531792, 36.15781478583813, 34.34453308582306, 36.688566505908966, 37.16825656592846, 36.98331668972969, 36.57665491104126, 36.70563519001007, 35.41384510695934, 36.530061811208725, 36.644678860902786, 38.075963258743286, 36.54434144496918, 38.0899503082037, 36.55581682920456, 40.58766268193722, 40.94007097184658, 45.60399390757084, 46.452651768922806, 49.091116189956665, 50.431615859270096, 52.34433062374592, 52.199493795633316, 55.4121758043766, 54.1143212467432, 53.383202478289604, 53.43258082866669, 56.45956680178642, 43.18470932543278, 51.483900994062424, 51.054755821824074, 65.52920132875443, 28.58189530670643, 0.37119489745236933, 2.70858870819211, 4.08460839651525, 0.3282426850637421, 8.569692503660917, 62.86687798798084, 50.50130791962147, 52.144389152526855, 40.476868227124214, 31.473899222910404, 30.426266938447952, 38.43536697328091, 50.398223251104355, 16.14757552742958, 0.2539819339290261, 0.06822105686296709, 0.1004578813444823, 0.04701800164184533, 0.04117430486076046, 0.014555388006556313, 0.0357123577123275, 0.036140061129117385, 0.05722620582673699, 0.07431497244397178, 0.09592830174369738, 0.029813686342095025, 0.03770792973227799, 0.033733676973497495, 0.020449762341741007, 0.0360602283035405, 0.05811343224195298, 0.09795622769161128, 0.04845902607485186, 0.19886394700733945, 0.037985960516380146, 15.366592034697533, 62.5204049795866, 52.877977788448334, 38.185518980026245, 22.952058501541615, 48.04613806307316, 52.5993425399065, 66.19055584073067, 51.91477507352829, 62.93823055922985, 25.83550527691841, 0.11116474939626642, 0.519473806489259, 1.042175896000117, 0.4750992829212919, 22.277425602078438, 59.074700474739075, 54.09197464585304, 54.339079186320305, 48.226085007190704, 52.99294821918011, 52.342920899391174, 53.89919579029083, 53.44149135053158, 52.910298854112625, 51.270132064819336, 49.92858745157719, 42.091215401887894, 39.76875342428684, 39.501414969563484, 38.8844458758831, 38.319841772317886, 37.4709939211607, 37.48469598591328, 37.573071643710136, 38.32601264119148, 38.11425380408764, 38.57973262667656, 41.400872245430946, 40.20362488925457, 44.304026663303375, 43.702587336301804, 40.9342572838068, 40.516614094376564, 40.677862241864204, 39.747668355703354, 38.547263368964195, 37.60836035013199, 39.275562688708305, 38.29075813293457, 40.19643947482109, 37.9909960180521, 39.71497491002083, 39.450642094016075, 38.78057084977627, 40.765740126371384, 40.80595336854458, 37.4918358027935, 40.26193656027317, 42.12639391422272, 41.83163993060589, 39.94445599615574, 41.18257775902748, 41.906951889395714, 41.96025162935257, 41.534849256277084, 40.293360874056816, 38.12512882053852, 39.65118393301964, 38.99638406932354, 40.38396701216698, 44.172998294234276, 43.1845573335886, 45.6076493114233, 44.99334007501602, 45.7111519575119, 44.81260657310486, 42.659486308693886, 44.040142223238945, 44.596576765179634, 42.27712042629719, 41.890916749835014, 40.87170884013176, 39.76227097213268, 39.67957220971584, 40.200619250535965, 39.27888371050358, 39.05420936644077, 40.88173650205135, 39.71787415444851, 39.79704290628433, 43.37671682238579, 41.521276384592056, 42.107413932681084, 40.7416570186615, 42.05913372337818, 38.303092271089554, 39.928683042526245, 38.893846571445465, 40.14855444431305, 39.060102850198746, 38.376093953847885, 38.15223276615143, 38.26787196099758, 38.99867154657841, 39.12024602293968, 39.08426195383072, 39.772142842411995, 38.80810797214508, 38.759045004844666, 37.32421159744263, 39.74655881524086, 38.607322946190834, 38.098009675741196, 38.731758669018745, 37.50099331140518, 38.42271365225315, 39.08919408917427, 38.7977497279644, 39.48435388505459, 38.303992822766304, 39.53077219426632, 41.21007688343525, 43.715898022055626, 43.081924840807915, 48.594235852360725, 48.49749684333801, 52.39623583853245, 52.34941095113754, 54.803091287612915, 55.18366366624832, 56.957959458231926, 54.418992698192596, 55.648348331451416, 55.401441380381584, 59.03756506741047, 45.50009608268738, 52.55288243293762, 55.21459400653839, 67.35178112983704, 31.246964000165462, 0.2033193563693203, 2.3973186733201146, 3.737611728720367, 0.6545730633661151, 10.1360435038805, 67.88168549537659, 57.94443592429161, 57.05828547477722, 50.143728107213974, 34.35446955263615, 29.908651113510132, 49.595371931791306, 58.53251896798611, 22.391368187963963, 0.40222590265329927, 0.01563411635288503, 0.07289154062164016, 0.006697757080473821, 0.024688887606316712, 0.03499462669424247, 0.03366492812347133, 0.017112396599259228, 0.035286402053316124, 0.2025087084621191, 0.2921890321886167, 0.26151600934099406, 0.262657105922699, 0.15605897671775892, 0.2800624578958377, 0.15525750175584108, 0.18985921691637486, 0.2217989374184981, 0.15994336281437427, 0.3076113952556625, 0.12100171647034585, 16.76580235362053, 71.49912938475609, 61.132711842656136, 48.11589851975441, 28.866762220859528, 50.846610590815544, 58.388472497463226, 71.16135030984879, 56.79268732666969, 67.74922460317612, 29.99402303248644, 0.2101100521394983, 2.7478261152282357, 2.5243482319638133, 0.779250607592985, 23.623607866466045, 60.10132558643818, 55.69293133914471, 56.73340290784836, 50.55601738393307, 55.745178535580635, 55.379592552781105, 54.607439786195755, 56.39272078871727, 54.15099307894707, 52.87312164902687, 54.49468843638897, 43.964758068323135, 41.39091677963734, 40.827277824282646, 39.87095274031162, 40.78074172139168, 40.284442752599716, 39.19566437602043, 38.87634851038456, 39.52794894576073, 40.98045900464058, 40.37654221057892, 43.127355203032494, 43.399686589837074, 46.833471134305, 46.19073182344437, 43.9935415238142, 42.39757016301155, 44.640080630779266, 41.404189467430115, 41.25352755188942, 39.66460861265659, 41.57942086458206, 39.88508798182011, 42.68269166350365, 39.994704499840736, 41.75753250718117, 42.28489100933075, 39.54409807920456, 42.56281949579716, 42.82914340496063, 40.10207533836365, 42.47543178498745, 44.584451615810394, 43.35262231528759, 42.11140751838684, 44.33181457221508, 43.64151321351528, 47.11084485054016, 44.52216535806656, 42.34158016741276, 38.69411028921604, 41.454962342977524, 41.29228547215462, 42.7804946154356, 45.62026083469391, 43.962991163134575, 46.88522055745125, 47.24826827645302, 48.590162470936775, 46.87981724739075, 42.86581143736839, 46.059684455394745, 45.3298956155777, 44.03742156922817, 44.42044101655483, 43.29196237027645, 42.483411356806755, 41.24728448688984, 42.36284002661705, 41.469720751047134, 41.17554433643818, 43.447537422180176, 40.46549543738365, 40.87996579706669, 44.39243271946907, 44.75742593407631, 43.86155180633068, 43.58787149190903, 45.33078856766224, 40.849787816405296, 41.29049576818943, 40.19792519509792, 43.10483381152153, 41.48415997624397, 40.51708146929741, 40.059882402420044, 41.823755353689194, 40.6733138859272, 39.99471589922905, 43.44778060913086, 41.13265983760357, 40.59341937303543, 41.91469967365265, 39.12237770855427, 40.56926026940346, 42.52687342464924, 40.74629656970501, 41.987610161304474, 40.20927518606186, 40.35853497684002, 40.76976031064987, 41.07452295720577, 42.85233736038208, 40.32983511686325, 42.50263072550297, 41.401016637682915, 46.759926080703735, 44.77994352579117, 50.68890765309334, 51.595953181385994, 53.54022905230522, 55.41223660111427, 55.877175852656364, 57.12314039468765, 58.73701639473438, 58.055933341383934, 55.54104968905449, 57.87929601967335, 63.84165868163109, 48.542699217796326, 54.867516830563545, 56.869333013892174, 69.15786221623421, 33.617894276976585, 0.40157005190849304, 5.9144168347120285, 10.654583629220724, 0.8833406784106046, 9.90882994607091, 75.55297985672951, 60.92418283224106, 66.42458528280258, 60.920527428388596, 45.78568875789642, 39.38601516187191, 55.9693019092083, 68.8986325263977, 30.137900412082672, 0.5251171567942947, 0.20916264125844464, 0.19903082633391023, 0.12445246567949653, 0.2441234965226613, 0.08974110562121496, 0.11696994726662524, 0.14218819211237133, 0.10057623905595392], [0.023999508484848775, 0.05172008604859002, 0.05603922967566177, 0.028902607300551608, 0.019833842852676753, 0.042171198438154534, 0.020581328426487744, 0.055999803080339916, 0.07952226646011695, 0.0588831321510952, 0.10035564308054745, 0.024652876745676622, 5.955810388550162, 53.5740814357996, 48.28380011022091, 36.254781782627106, 25.174840427935123, 33.0384823679924, 49.82533559203148, 58.6622554063797, 48.942361772060394, 52.85494342446327, 36.12491995096207, 0.38579187355935574, 0.5755185429006815, 0.7207898539490998, 0.06455287322751246, 9.914151560515165, 53.54393385350704, 56.48753710091114, 51.37235417962074, 48.953080996870995, 51.96882717311382, 54.8331742733717, 51.54443174600601, 47.68871024250984, 50.17330192029476, 48.98294739425182, 47.442567050457, 38.6777787655592, 36.91503055393696, 36.4537239074707, 38.015481904149055, 35.261834263801575, 36.210293769836426, 36.73905819654465, 37.67282009124756, 37.13920332491398, 40.616472736001015, 43.40864270925522, 47.619561553001404, 47.823188826441765, 46.54393807053566, 46.59321762621403, 47.31489010155201, 44.91105929017067, 43.68033193051815, 38.68979372084141, 38.01744259893894, 38.131915256381035, 37.193225026130676, 36.83714993298054, 36.722540482878685, 35.93424618244171, 35.95012553036213, 36.890913248062134, 36.54999554157257, 38.057671040296555, 37.31213204562664, 37.667036801576614, 37.85652883350849, 41.034617498517036, 40.28683662414551, 38.75917039811611, 38.97145360708237, 40.11861205101013, 38.31816226243973, 38.491782546043396, 39.794120863080025, 37.110936641693115, 37.83967673778534, 35.167249739170074, 37.769840285182, 40.74078306555748, 41.8774388730526, 42.76129424571991, 43.071076422929764, 44.210042506456375, 44.32890012860298, 42.81007222831249, 42.04880587756634, 41.07113353908062, 39.23703275620937, 39.643257558345795, 38.31657774746418, 38.20520952343941, 36.80030331015587, 37.368080243468285, 38.13837110996246, 39.58705857396126, 38.794056326150894, 41.165326684713364, 38.85361813008785, 41.34933181107044, 38.027082681655884, 38.60991820693016, 40.94107411801815, 37.29385882616043, 35.687833204865456, 36.66281908750534, 38.69510963559151, 37.132211700081825, 36.52740575373173, 37.76480175554752, 36.26098304986954, 35.96089795231819, 38.43178756535053, 37.30800546705723, 36.732651740312576, 37.391422390937805, 35.92999801039696, 35.88668033480644, 36.481834799051285, 35.932954251766205, 36.361259669065475, 35.470777451992035, 34.97718773782253, 36.026045456528664, 35.16865186393261, 35.67713297903538, 36.90585784614086, 35.86647681891918, 38.58247607946396, 39.318017810583115, 36.63175195455551, 37.203788459300995, 37.592587396502495, 38.116450086236, 41.78352691233158, 45.44311434030533, 47.08139643073082, 48.529510125517845, 49.54334132373333, 53.37035536766052, 52.815972715616226, 56.06303907930851, 51.129402816295624, 55.041266307234764, 49.855224788188934, 53.64047147333622, 51.80380582809448, 64.8601484298706, 15.732533298432827, 0.23489431128837168, 6.038290187716484, 4.461007174104452, 0.4757663846248761, 13.19987989962101, 63.93063470721245, 52.42344617843628, 52.86816291511059, 45.8101100474596, 36.458561047911644, 33.29049624502659, 37.9143351316452, 50.10740205645561, 6.310719894245267, 0.1314852203358896, 0.014140206476440653, 0.13330173067515716, 0.07036512150079943, 0.1040081525570713, 0.04646232227969449, 0.05304440033796709, 0.06625511508900672, 0.0450520524464082, 0.06537590015796013, 0.023360433988273144, 0.06999666744377464, 0.019746902107726783, 0.022946046556171495, 0.03979232940764632, 0.051597806086647324, 0.035162671192665584, 0.019958108059654478, 0.0561837889108574, 0.11538150632986799, 0.05257910343061667, 7.710725795477629, 62.31466881930828, 55.340910628437996, 42.71130792796612, 26.04974538087845, 44.11400645971298, 54.06949885189533, 63.251075372099876, 52.39453732967377, 58.86597767472267, 38.1817913800478, 0.24538836849387735, 0.9542672568932176, 1.1557438457384706, 0.24812962452415377, 11.398559957742691, 55.453578382730484, 57.439678609371185, 53.87825891375542, 50.8800145983696, 52.36023657023907, 56.85356765985489, 52.249373719096184, 51.13699480891228, 53.255320340394974, 50.60265228152275, 49.97758202254772, 41.523624658584595, 38.22615399956703, 39.734163880348206, 40.24108327925205, 37.03136511147022, 38.93595591187477, 37.70220771431923, 39.21840235590935, 40.17127342522144, 41.831199154257774, 44.33788664638996, 49.528674110770226, 48.77528473734856, 49.704361483454704, 48.255636021494865, 48.33057560026646, 46.98879919946194, 43.915296122431755, 42.405849918723106, 40.53833372890949, 38.636034205555916, 38.331647738814354, 38.45489412546158, 38.701573088765144, 38.99286545813084, 38.40138539671898, 39.128977954387665, 38.92883509397507, 38.97727869451046, 38.233172222971916, 38.03825408220291, 41.276409924030304, 42.00562499463558, 40.7009270042181, 41.247580870985985, 41.621252819895744, 42.14444674551487, 42.02143594622612, 40.783070996403694, 41.008984073996544, 39.85015645623207, 40.1611165702343, 37.31225363910198, 39.40405659377575, 42.5579709559679, 44.19209986925125, 43.900134935975075, 44.12952482700348, 46.86596319079399, 46.1655467748642, 44.43940959870815, 43.04749108850956, 43.845554664731026, 42.95914202928543, 43.090466782450676, 41.409026607871056, 40.38864456117153, 38.20414938032627, 40.02686597406864, 39.66295190155506, 39.964382126927376, 39.8193135112524, 41.86411298811436, 41.037490144371986, 42.50937536358833, 39.82361488044262, 40.95634549856186, 42.99183547496796, 39.87108573317528, 37.77239754796028, 38.69610518217087, 38.497166857123375, 38.039424419403076, 38.248109221458435, 38.42380419373512, 38.891901075839996, 38.64060916006565, 39.08423915505409, 40.0456977635622, 37.661994472146034, 38.91844645142555, 39.05951768159866, 39.2708433419466, 38.75271834433079, 38.373890072107315, 37.309768572449684, 38.763882145285606, 38.87745425105095, 36.98677450418472, 37.362103164196014, 38.23284924030304, 38.469606935977936, 40.8974676579237, 39.80408392846584, 40.98247669637203, 38.17262627184391, 40.79520374536514, 38.65242652595043, 41.24252714216709, 43.04669693112373, 48.84356327354908, 48.78200277686119, 52.20853731036186, 51.080138459801674, 56.356056556105614, 55.05847178399563, 58.30691747367382, 52.3806718736887, 59.31802041828632, 49.95524302124977, 57.850231379270554, 53.190758004784584, 68.31005930900574, 15.739574320614338, 0.07122253213310614, 9.888200853019953, 2.3103373032063246, 0.45143729948904365, 13.481218703091145, 70.03517434000969, 54.95438016951084, 59.424490705132484, 54.53007973730564, 37.08192519843578, 33.78480412065983, 43.150199577212334, 59.94919694960117, 10.898955166339874, 0.2606473403284326, 0.016488389555888716, 0.1368449960136786, 0.07874625458498485, 0.064789610914886, 0.024670918355695903, 0.06328717747237533, 0.01706060767901363, 0.022233276795304846, 0.17190418584505096, 0.10006982716731727, 0.18431478005368263, 0.07595672926981933, 0.1570753924897872, 0.11182687871041708, 0.17171478975797072, 0.11778824671637267, 0.1895476336358115, 0.2448490943061188, 0.2630454272730276, 0.27070593496318907, 8.354275412857533, 72.04642161726952, 62.56691448390484, 52.4853790551424, 35.06022468209267, 46.07407808303833, 59.663129299879074, 68.48740339279175, 57.992434948682785, 64.71675932407379, 44.50300298631191, 0.48241676995530725, 2.35401120968163, 2.6484170369803905, 0.2168129666824825, 12.587771695107222, 58.080537021160126, 60.95802761614323, 56.82809762656689, 54.671523347496986, 55.42823374271393, 57.435897812247276, 55.95905385911465, 53.4994762390852, 54.1084049642086, 52.777564376592636, 50.851105749607086, 43.822539299726486, 40.55527701973915, 42.47156359255314, 44.871180430054665, 38.78187417984009, 40.57957671582699, 40.121933072805405, 41.89188189804554, 41.173807829618454, 45.772552862763405, 47.82301023602486, 53.663578033447266, 53.07506561279297, 50.49465447664261, 52.051974311470985, 52.45111249387264, 49.89108346402645, 48.8508702814579, 43.96680235862732, 42.37587712705135, 41.5779085457325, 41.96123577654362, 40.15695579349995, 40.77504202723503, 39.46298003196716, 41.38663440942764, 41.296484246850014, 41.28930643200874, 40.818701684474945, 41.66061490774155, 42.2619554400444, 44.469321593642235, 45.13883426785469, 44.722179025411606, 43.71426410973072, 44.153463542461395, 43.681844249367714, 43.0564434081316, 41.545963659882545, 43.471829518675804, 40.743925496935844, 41.729026436805725, 38.63218501210213, 42.84898214042187, 46.10007628798485, 47.04164296388626, 45.98660297691822, 47.68600858747959, 48.11804920434952, 46.91717304289341, 45.27783460915089, 46.10288433730602, 45.53363688290119, 44.01627950370312, 44.42154295742512, 44.32336002588272, 42.91785344481468, 40.05338475108147, 41.65114961564541, 42.88190737366676, 44.62749570608139, 42.8170258551836, 44.89663526415825, 43.291939571499825, 45.42041435837746, 41.358774304389954, 42.561470568180084, 46.10853463411331, 40.94339579343796, 39.10470485687256, 41.604754105210304, 41.922337263822556, 39.40734721720219, 41.215020418167114, 40.87024211883545, 40.999062806367874, 39.95793767273426, 43.40789794921875, 40.91437675058842, 38.964986354112625, 40.726450234651566, 40.95786161720753, 40.514205023646355, 41.13255724310875, 41.0271281003952, 40.80447144806385, 40.57386562228203, 39.85410824418068, 39.67553682625294, 41.47180303931236, 39.48042489588261, 40.661724507808685, 42.23481349647045, 42.858189046382904, 44.06253822147846, 41.430145874619484, 41.92058935761452, 41.216418743133545, 41.81671053171158, 45.82150183618069, 50.136413499712944, 52.09641672670841, 52.74302423000336, 53.96511845290661, 59.32564280927181, 57.4343740940094, 60.383935421705246, 53.647155314683914, 60.43300598859787, 53.29797685146332, 59.91641990840435, 56.27808094024658, 69.81482416391373, 18.791644647717476, 0.19284449110273272, 18.46201043576002, 11.05557231232524, 0.8034168358426541, 14.680101871490479, 75.25169402360916, 61.69656738638878, 65.9326484799385, 61.15579940378666, 51.98752976953983, 42.59822219610214, 53.35117019712925, 67.57723823189735, 15.03946853801608, 0.33541658136527985, 0.08354969409992918, 0.21569955220911652, 0.17452790052630007, 0.1720453571761027, 0.14006278506712988, 0.2198177741956897, 0.14790663291933015, 0.16633154737064615], [0.014743432457180461, 0.13809400086756796, 0.0032723842195991892, 0.04687007676693611, 0.07919686438981444, 0.03340385541378055, 0.026072601540363394, 0.0720362451102119, 0.03895183232089039, 0.03238056364352815, 0.10017406922997907, 0.09597134630894288, 2.2733030654489994, 40.40092550218105, 51.85317277908325, 34.44660320878029, 24.230573996901512, 33.31328362226486, 52.0882585644722, 55.96414938569069, 52.7707589417696, 50.01271113753319, 44.90546599030495, 1.117238849401474, 0.23136759584303945, 0.5441948643419892, 0.17956574738491327, 1.6357312398031354, 33.45147080719471, 58.518642112612724, 52.41183020174503, 52.12932676076889, 54.6964918076992, 49.43771839141846, 47.909660786390305, 52.11773358285427, 51.84819124639034, 49.63883779942989, 43.68395693600178, 36.76197476685047, 35.73881506919861, 37.89232671260834, 35.00258557498455, 36.67300634086132, 36.522515416145325, 38.23649324476719, 42.01828971505165, 47.74257615208626, 48.625534772872925, 49.067971631884575, 50.03817357122898, 50.41233949363232, 50.89736066758633, 50.13395123183727, 50.18566645681858, 47.866802886128426, 45.186172127723694, 44.94904205203056, 41.79560266435146, 37.56414212286472, 38.12799386680126, 37.408350482583046, 36.006503105163574, 38.15900780260563, 37.057925686240196, 36.429568603634834, 36.03798061609268, 38.2880412787199, 38.13050173223019, 36.50797359645367, 37.73304305970669, 39.53713305294514, 40.65937623381615, 37.877575904130936, 40.396802723407745, 38.83795537054539, 39.192229360342026, 39.27932448685169, 38.051146790385246, 36.77911564707756, 36.67986877262592, 35.84563873708248, 35.725314393639565, 41.381835266947746, 44.9054279923439, 44.847830682992935, 44.516621455550194, 43.65352816879749, 46.469329074025154, 42.527941167354584, 43.42393308877945, 43.7963131070137, 42.08197809755802, 41.33509777486324, 39.16504941880703, 36.71175666153431, 34.5705259591341, 36.89279034733772, 37.238123416900635, 38.89950066804886, 39.33597184717655, 39.1574764251709, 37.94916406273842, 40.65322436392307, 40.26208095252514, 38.277101665735245, 40.665300115942955, 39.83050771057606, 35.545416846871376, 36.53390720486641, 37.20572255551815, 37.90268875658512, 36.44697166979313, 37.30152681469917, 36.70816585421562, 35.770832151174545, 35.91329410672188, 37.29124456644058, 36.42747491598129, 35.4079782217741, 35.301435738801956, 37.31938585639, 35.94559237360954, 37.98282265663147, 35.07141888141632, 36.968657076358795, 36.93767733871937, 35.36659464240074, 35.62997750937939, 36.53797298669815, 37.611213997006416, 36.03312827646732, 35.813477262854576, 38.132850006222725, 36.7524828761816, 37.90254056453705, 37.07978591322899, 38.36707703769207, 37.335607185959816, 40.32695487141609, 42.84373842179775, 45.33513933420181, 47.02978000044823, 49.884646609425545, 50.5920584499836, 54.910264536738396, 52.71576069295406, 58.68668429553509, 52.65932612121105, 57.27785289287567, 51.823864951729774, 56.712409034371376, 3.152745687402785, 0.21062826417619362, 3.129260572604835, 1.4029956283047795, 0.5510486871935427, 15.834326036274433, 63.58325734734535, 58.177891597151756, 54.060360342264175, 35.21559074521065, 27.74898760020733, 38.65511678159237, 51.10029637813568, 38.79624500870705, 3.1835786579176784, 0.30989949591457844, 0.027986693166894838, 0.1485084107844159, 0.015079144814080792, 0.10965094625134952, 0.006697746875943267, 0.06411028603906743, 0.04852127000049222, 0.054360306094167754, 0.06757302093319595, 0.10491824825294316, 0.09920928467181511, 0.035146948794135824, 0.01784573312761495, 0.07147250973503105, 0.030070261636865325, 0.05124618393892888, 0.03370053265825845, 0.026557646997389384, 0.12293203515582718, 0.04437597075593658, 2.640304947271943, 48.92465852200985, 58.262209072709084, 43.96073028445244, 28.26562687754631, 37.10896834731102, 59.27250266075134, 60.530554354190826, 58.79188925027847, 55.00786229968071, 49.70188021659851, 1.222585584037006, 0.5771360092330724, 1.7749058967456222, 1.367692316416651, 2.764294669032097, 36.49923026561737, 61.2655109167099, 53.8312516361475, 53.84255602955818, 55.57582162320614, 51.67051658034325, 48.51899228990078, 53.26054126024246, 52.4361526966095, 51.491979360580444, 48.06702934205532, 38.525353744626045, 38.784667029976845, 38.70977684855461, 38.554270192980766, 39.79091003537178, 38.197910115122795, 40.39320431649685, 42.57594399154186, 47.73110456764698, 50.58962658047676, 51.32280483841896, 52.11468614637852, 52.9609577357769, 53.83070066571236, 52.183166071772575, 51.34139344096184, 49.686012268066406, 46.79557956755161, 45.889491587877274, 42.1623931825161, 39.075203239917755, 38.71144875884056, 38.90732064843178, 38.22451628744602, 39.471487775444984, 38.980318531394005, 37.85760797560215, 37.68542781472206, 40.36587618291378, 39.754382595419884, 38.03838707506657, 40.24908944964409, 42.5631120800972, 42.35487945377827, 40.522781163454056, 41.90332308411598, 39.963344782590866, 41.344574466347694, 41.287896707654, 40.73455899953842, 38.88706773519516, 39.41140539944172, 38.540180549025536, 38.382876589894295, 43.71627040207386, 47.062253057956696, 46.82527117431164, 44.86518055200577, 45.926820784807205, 47.39400565624237, 42.784313410520554, 45.718306973576546, 44.79339100420475, 44.67585951089859, 41.79337978363037, 41.32304482161999, 38.19215342402458, 38.575929030776024, 37.71615296602249, 40.53095452487469, 40.85275545716286, 40.944345742464066, 41.505822613835335, 41.04398399591446, 42.192103788256645, 42.08681523799896, 39.88912336528301, 42.468257769942284, 42.08854794502258, 37.89155535399914, 38.962945863604546, 38.57344776391983, 39.393189176917076, 37.58656091988087, 40.226077884435654, 38.05285669863224, 36.66250370442867, 37.113911882042885, 39.225766360759735, 38.36481995880604, 38.163780346512794, 37.6702818274498, 38.464906588196754, 37.96177938580513, 39.80957843363285, 37.2432379424572, 39.33629482984543, 38.2988440990448, 37.10347384214401, 37.42303669452667, 39.51470285654068, 38.962406292557716, 39.198890402913094, 37.301485016942024, 38.753299713134766, 38.969401717185974, 39.627556800842285, 38.57125148177147, 41.47321656346321, 39.594585970044136, 43.53097714483738, 43.60996350646019, 48.016267865896225, 48.31146262586117, 53.578511998057365, 52.66192898154259, 57.006923630833626, 53.33309456706047, 61.14945374429226, 53.887013643980026, 59.905240908265114, 54.27326671779156, 61.05527959764004, 3.9867679215967655, 0.17361268401145935, 4.964799340814352, 0.10871135760680772, 0.438464023754932, 16.317916586995125, 68.33185493946075, 61.9656727463007, 58.01583789288998, 42.725959941744804, 36.94281846284866, 43.997926488518715, 57.480625212192535, 48.244274631142616, 5.405608462169766, 0.23843442992074415, 0.059783401811728254, 0.11764918308472261, 0.035140132167725824, 0.06313502977718599, 0.0592809975205455, 0.11730268175597303, 0.08139940284308977, 0.06147339823655784, 0.17024863249389455, 0.2287710882956162, 0.18279606389114633, 0.08964167267549783, 0.10950147028779611, 0.12851940526161343, 0.23622382432222366, 0.12378188330330886, 0.2199334156466648, 0.08705777421710081, 0.2843694674083963, 0.1260157849173993, 2.945833965204656, 54.91388954222202, 66.53607130050659, 48.06545242667198, 34.649702310562134, 44.163977578282356, 65.9100928902626, 66.16024866700172, 63.555382043123245, 59.24157232046127, 53.422211185097694, 1.6979466076008976, 1.3899366790428758, 3.3273130701854825, 1.5062997350469232, 2.495858548209071, 38.45759578049183, 62.34602853655815, 56.7046270519495, 54.4547525793314, 56.4092119038105, 53.98447461426258, 51.31524324417114, 53.94095174968243, 56.48050747811794, 54.19464893639088, 49.115925058722496, 41.466000750660896, 40.18320098519325, 41.56391389667988, 40.381641536951065, 40.98797120153904, 41.00863069295883, 44.36307169497013, 45.416356176137924, 51.85817711055279, 53.16491939127445, 54.43020589649677, 55.17548270523548, 55.24761043488979, 55.58166950941086, 54.82870951294899, 55.151202008128166, 52.21047140657902, 49.07344713807106, 48.561135828495026, 45.30515894293785, 40.919168293476105, 42.17034235596657, 40.85977368056774, 39.844509959220886, 41.78612217307091, 40.66237807273865, 39.89947400987148, 38.5408379137516, 42.891710847616196, 41.64316624403, 40.28499372303486, 43.579010367393494, 43.872780203819275, 44.11262333393097, 40.682706981897354, 45.10706417262554, 41.78861103951931, 42.64236442744732, 42.91670970618725, 43.2898610830307, 40.30319094657898, 40.752133056521416, 40.177740678191185, 39.98525820672512, 46.66378363966942, 50.52759110927582, 49.669650346040726, 46.63113959133625, 49.15172293782234, 49.149693846702576, 43.81992883980274, 48.41037131845951, 47.40498326718807, 45.975081995129585, 45.153338089585304, 44.56720054149628, 41.26855194568634, 41.05432704091072, 39.08856712281704, 42.84651607275009, 41.798836290836334, 44.819077625870705, 44.72659818828106, 42.29391932487488, 43.75649504363537, 45.10449171066284, 42.2690686583519, 44.51229348778725, 45.43166175484657, 39.260606691241264, 39.889279156923294, 42.089912071824074, 42.77718499302864, 40.19240029156208, 42.852675542235374, 41.589114144444466, 38.074367344379425, 40.066794231534004, 40.04581555724144, 40.258569940924644, 40.16046680510044, 38.814696818590164, 42.37090319395065, 40.99340870976448, 42.669502571225166, 39.24154691398144, 41.54891610145569, 41.88242420554161, 39.33323599398136, 40.11005491018295, 40.8340984582901, 41.341101452708244, 41.110051050782204, 39.37544792890549, 41.947419717907906, 41.00314758718014, 41.716395914554596, 40.22176131606102, 41.752410382032394, 41.31952241063118, 45.08156754076481, 47.942453026771545, 49.96380776166916, 51.421474143862724, 56.207416132092476, 53.6865022033453, 58.684032037854195, 55.013258010149, 63.7047216296196, 57.57682844996452, 64.40190821886063, 54.76126693189144, 63.45023788511753, 5.025956584140658, 0.5287194228731096, 10.850950442254543, 4.0586562640964985, 0.9548517724033445, 17.291329354047775, 76.40985667705536, 66.12646847963333, 61.89643286168575, 47.81200982630253, 41.51846833527088, 50.71527823805809, 64.81018111109734, 57.43594340980053, 8.982497602701187, 0.4807576542953029, 0.19166066165780649, 0.2675541822100058, 0.14588094083592296, 0.3204220219049603, 0.1563610159792006, 0.23153061600169167, 0.21886233327677473, 0.19080000784015283], [0.037451087264344096, 0.02481259249179857, 0.07037047980702482, 0.08686776214744896, 0.07652658736333251, 0.07360197632806376, 0.02089689704007469, 0.022973611776251346, 0.013042795490036951, 0.03155388905724976, 0.0865626207087189, 0.1145392726175487, 0.43631541717331856, 29.07598089426756, 54.96872819960117, 34.90621514618397, 25.79546682536602, 24.605689868330956, 51.80361583828926, 56.607413068413734, 54.02078166604042, 47.00313962996006, 47.64720506966114, 2.5667748553678393, 0.31177457654848695, 0.1131622027605772, 0.7962516078259796, 0.19534644903615117, 7.308619022369385, 45.29093250632286, 55.75159639120102, 53.41314107179642, 48.16266641020775, 52.87748001515865, 54.50562044978142, 52.8756333142519, 49.7353146225214, 48.9187840372324, 39.096717685461044, 35.509185791015625, 36.18938349187374, 35.76775051653385, 35.95375433564186, 38.6824107170105, 39.33122970163822, 43.89807164669037, 46.517134308815, 48.98314878344536, 49.0340356528759, 49.65094015002251, 50.62065191566944, 48.1778883934021, 48.41211922466755, 50.054786279797554, 50.928940773010254, 48.93571972846985, 49.92481805384159, 47.751688063144684, 45.363318622112274, 39.06848520040512, 36.95644073188305, 37.95659266412258, 35.87943032383919, 36.862752959132195, 35.850726664066315, 36.30286820232868, 37.763430029153824, 39.59687724709511, 37.78942063450813, 36.980706229805946, 38.840584829449654, 39.66229073703289, 39.20746274292469, 40.89698128402233, 41.25487647950649, 40.293136686086655, 40.918636322021484, 38.63706395030022, 39.732860550284386, 38.04841473698616, 38.499268144369125, 35.0725132226944, 37.29162834584713, 40.820673778653145, 44.05612796545029, 46.09730623662472, 47.01521538197994, 45.20742438733578, 46.05417475104332, 46.11249402165413, 44.98651564121246, 43.0888556689024, 41.821433678269386, 41.0550832003355, 40.995092019438744, 37.73520514369011, 36.510314270853996, 37.29692906141281, 37.74916559457779, 38.42041477560997, 39.44103240966797, 38.55334684252739, 39.05676282942295, 40.70460520684719, 39.25727427005768, 39.756305292248726, 41.11012324690819, 40.910345166921616, 36.74968242645264, 37.55422845482826, 37.78938643634319, 38.090429082512856, 36.21433675289154, 36.07265755534172, 35.37042863667011, 36.05142429471016, 38.18513140082359, 36.42373591661453, 37.35295705497265, 37.4042809009552, 36.773503348231316, 36.39176443219185, 36.5008831769228, 37.06145569682121, 37.33744628727436, 37.661530897021294, 37.2546449303627, 38.08511696755886, 36.95281572639942, 37.67283909022808, 36.46382376551628, 37.204784005880356, 37.10489496588707, 37.176304534077644, 34.482864663004875, 36.513536497950554, 37.96356149017811, 38.324659913778305, 38.09682793915272, 38.32900308072567, 39.19290952384472, 39.44461561739445, 41.97037048637867, 47.79518432915211, 51.24424785375595, 55.489801838994026, 56.8424266576767, 57.252952829003334, 57.73667447268963, 56.11488349735737, 59.80253241956234, 33.76393564045429, 0.019843539012072142, 0.3207638848107308, 3.9301896700635552, 2.507000737823546, 0.5293533951044083, 17.363137900829315, 64.24490064382553, 55.659512132406235, 53.99839326739311, 30.86238093674183, 18.746964745223522, 32.781958132982254, 50.776071175932884, 35.82124024629593, 0.6322963431011885, 0.1980393467238173, 0.040096305674524046, 0.06444928425480612, 0.024028196203289554, 0.04138868534937501, 0.10226786820567213, 0.033569380320841447, 0.034334616211708635, 0.11145371943712234, 0.006338495913951192, 0.051780960711766966, 0.04820892972929869, 0.07679130401811562, 0.01843089245085139, 0.022414236518670805, 0.040126819076249376, 0.04003876696515363, 0.06410406684153713, 0.047441816204809584, 0.058352696942165494, 0.04974425144609995, 0.8172224450390786, 36.260869055986404, 62.31479801237583, 40.28527110815048, 26.804092302918434, 34.82887789607048, 58.12237657606602, 61.36917695403099, 58.749316334724426, 51.48435316979885, 52.93067716062069, 2.743799756281078, 0.7145306398160756, 1.2537015206180513, 2.3346543358638883, 0.15765293181175366, 9.46613660082221, 50.30965380370617, 57.4155081063509, 55.75404345989227, 49.08243365585804, 52.63039447367191, 55.01969486474991, 54.20351006090641, 51.08926936984062, 51.54977805912495, 42.30592668056488, 37.587913647294044, 38.32185946404934, 37.85451114177704, 38.009067848324776, 40.22241868078709, 39.877875968813896, 45.073967948555946, 48.61823916435242, 50.60778200626373, 51.76602825522423, 51.53390631079674, 51.14080220460892, 51.552924290299416, 51.494422629475594, 50.74899762868881, 51.730173379182816, 50.43732315301895, 52.50898338854313, 48.33012342453003, 46.96517966687679, 41.39856576919556, 39.089627265930176, 39.62138593196869, 39.02849614620209, 37.59609840810299, 37.650332897901535, 37.97068230807781, 38.37857522070408, 41.80527314543724, 39.495893865823746, 40.89690528810024, 40.43316677212715, 42.95823387801647, 42.68191650509834, 43.012817949056625, 41.9649063795805, 42.41728350520134, 42.1534788608551, 40.496171191334724, 41.61022961139679, 39.72501017153263, 39.36211444437504, 38.79338376224041, 39.50418122112751, 42.76113845407963, 46.55645079910755, 47.356775254011154, 46.81105613708496, 47.12996542453766, 45.16625739634037, 47.63647444546223, 47.558894008398056, 44.095759838819504, 44.51955109834671, 42.37724505364895, 43.91674764454365, 38.824105113744736, 37.913814559578896, 37.16480255126953, 39.53004263341427, 40.4366397857666, 41.62166699767113, 40.0140530616045, 40.54361544549465, 42.30814956128597, 41.72722913324833, 41.20624288916588, 42.910250052809715, 41.60384215414524, 40.12762516736984, 38.62267032265663, 39.2482003569603, 39.358056262135506, 39.10600818693638, 37.37254120409489, 38.455878272652626, 38.86972166597843, 39.13598857820034, 38.287418112158775, 38.6708365380764, 39.792612344026566, 37.64070421457291, 38.47217179834843, 38.27206693589687, 40.55733270943165, 38.15585017204285, 39.890137910842896, 38.777550011873245, 39.40230868756771, 38.72266195714474, 39.587537348270416, 37.64270670711994, 38.902825489640236, 38.66043269634247, 38.56334790587425, 37.685541808605194, 38.578322902321815, 39.09139037132263, 39.94546294212341, 38.5190536826849, 41.190770119428635, 40.36213718354702, 41.29889711737633, 44.04136195778847, 51.87475182116032, 54.14790764451027, 56.778787672519684, 56.77992381155491, 60.52917502820492, 59.04989540576935, 57.510913386940956, 59.38585437834263, 37.316311821341515, 0.09986254532122985, 1.4980458654463291, 8.141548577696085, 1.7224351060576737, 0.5055951105896384, 18.824556581676006, 68.69380071759224, 61.686342135071754, 58.959080278873444, 39.910356625914574, 24.980262368917465, 36.11345216631889, 55.319916754961014, 45.41667155921459, 1.9715500948950648, 0.3422698104986921, 0.02766542114841286, 0.05365703582356218, 0.1040053843462374, 0.09014007679070346, 0.05727329509682022, 0.0408393958787201, 0.042742934165289626, 0.08275400788988918, 0.1786396509851329, 0.14391595643246546, 0.18456716963555664, 0.14358614600496367, 0.16521005833055824, 0.19328787981066853, 0.14116880774963647, 0.1347098668338731, 0.11210752185434103, 0.1337738850270398, 0.13540052430471405, 0.1586835374473594, 0.8204440784174949, 40.95698766410351, 70.86285352706909, 47.09566846489906, 36.87636382877827, 36.303008794784546, 63.19952353835106, 64.96709749102592, 63.58675695955753, 57.10609830915928, 58.77488516271114, 3.8721933821216226, 1.1231269896961749, 4.467447828501463, 3.8341388991102576, 0.45239360129926354, 9.248110000044107, 51.62543959915638, 57.22794637084007, 56.132408156991005, 50.427945256233215, 55.92815011739731, 57.638544738292694, 56.637230068445206, 53.86703811585903, 53.54670390486717, 45.18168456852436, 39.43492613732815, 40.02419471740723, 39.53061640262604, 41.280346512794495, 44.0858119726181, 42.3909243196249, 47.657000944018364, 48.75500522553921, 52.14143291115761, 55.24488218128681, 54.68228057026863, 53.18225026130676, 52.32980780303478, 52.16437987983227, 52.1126988530159, 53.63672487437725, 52.28599615395069, 55.27627609670162, 53.21285001933575, 48.20372320711613, 43.279582634568214, 41.463675275444984, 42.388192266225815, 40.884799137711525, 39.98670592904091, 40.383716225624084, 39.678854048252106, 40.66552050411701, 44.27123062312603, 41.67423717677593, 42.72957354784012, 42.77420975267887, 42.4605555832386, 42.84508354961872, 46.232225596904755, 44.321794509887695, 43.80450166761875, 43.26896220445633, 42.26309157907963, 43.740395307540894, 42.66811564564705, 43.93822409212589, 40.852660462260246, 41.523795649409294, 46.271241903305054, 49.91580493748188, 49.56356383860111, 50.22731602191925, 49.22660551965237, 48.852329403162, 48.213462084531784, 50.21986462175846, 47.20958635210991, 46.04190140962601, 45.00495985150337, 46.76123321056366, 41.50966040790081, 40.67968234419823, 40.847633332014084, 40.625451654195786, 42.27637566626072, 43.53966347873211, 42.43155173957348, 42.93565548956394, 44.95343081653118, 42.78732664883137, 43.63777041435242, 44.74284991621971, 44.00227725505829, 41.580325216054916, 40.63496634364128, 42.896965965628624, 42.67031952738762, 40.50247885286808, 38.198183700442314, 39.82251673936844, 40.05165584385395, 42.35864885151386, 41.40638954937458, 40.53586386144161, 41.07586808502674, 40.150678530335426, 41.64180211722851, 40.836340337991714, 42.68329583108425, 40.71187421679497, 41.41449831426144, 40.51238872110844, 41.00397974252701, 41.048764139413834, 41.36733144521713, 40.27375392615795, 40.223402827978134, 40.30236639082432, 41.16851471364498, 39.77153107523918, 40.90888224542141, 42.42579884827137, 43.31323362886906, 41.71138398349285, 44.362011551856995, 42.679990008473396, 43.5190761834383, 47.297179251909256, 54.03516009449959, 55.15018746256828, 60.71994759142399, 59.01035472750664, 61.5957397967577, 61.773878037929535, 60.60552433133125, 61.391151174902916, 40.39390727877617, 0.33495440147817135, 1.696495560463518, 18.284217976033688, 6.352416481822729, 0.6176299613434821, 19.55312378704548, 74.69748616218567, 66.57296732068062, 65.92945665121078, 41.40527240931988, 28.672246858477592, 45.680069625377655, 62.036732733249664, 55.80988526344299, 3.848438006825745, 0.512736946111545, 0.12348270131042227, 0.22498426493257284, 0.1311851551872678, 0.1378876095986925, 0.1909311453346163, 0.11937380812014453, 0.15899516525678337, 0.11197282205102965], [0.019428116283961572, 0.07568362634629011, 0.06747634877683595, 0.05198446131544188, 0.03744333182112314, 0.02039496772340499, 0.015981111209839582, 0.06822775845648721, 0.03863941412419081, 0.06525904900627211, 0.032499299850314856, 0.08484863064950332, 0.2958268322981894, 20.648950785398483, 51.097366735339165, 41.56448386609554, 24.455041252076626, 23.250446990132332, 42.771014124155045, 50.75407415628433, 58.34775008261204, 45.271762534976006, 55.38189522922039, 9.851937498897314, 0.5640981963369995, 0.6399345269892365, 2.6534037943929434, 0.6788056693039834, 0.3087206091731787, 24.342721179127693, 54.768627136945724, 50.36119423806667, 56.698482781648636, 55.32880447804928, 53.15988086163998, 49.003150910139084, 46.7853619158268, 41.33217193186283, 36.02802895009518, 38.339855298399925, 35.290252938866615, 36.45837485790253, 38.39347422122955, 41.36186733841896, 44.37524624168873, 46.691453754901886, 48.11377823352814, 51.88663378357887, 51.49336628615856, 49.81990568339825, 46.87401495873928, 49.07601960003376, 50.11927641928196, 48.17303225398064, 49.520937725901604, 48.97429145872593, 51.50858826935291, 49.67100687325001, 47.271960005164146, 41.23090736567974, 38.418112099170685, 36.91573731601238, 37.605749890208244, 38.203792199492455, 36.748021915555, 36.84828333556652, 35.558887124061584, 37.67647549510002, 37.143307104706764, 37.22948268055916, 38.09940420091152, 39.72217172384262, 38.03328014910221, 39.118547514081, 37.93758228421211, 39.80077810585499, 40.62480188906193, 37.91859470307827, 37.38412298262119, 38.143664225935936, 37.910854518413544, 34.80658069252968, 37.80023105442524, 41.84812344610691, 45.30791759490967, 47.38282285630703, 47.275850996375084, 47.04173795878887, 43.51539418101311, 46.2615068256855, 44.11277912557125, 45.070107355713844, 43.95173616707325, 41.543178409338, 40.28552949428558, 37.989536896348, 35.81446520984173, 38.24318088591099, 36.9876978546381, 38.09894062578678, 39.13961738348007, 36.06017142534256, 41.12915642559528, 38.89983505010605, 39.55174706876278, 38.90187554061413, 39.739153012633324, 40.63341222703457, 35.663351118564606, 37.57473215460777, 37.86145716905594, 38.94292093813419, 36.71755515038967, 35.53598575294018, 37.511868327856064, 37.232267931103706, 37.50158607959747, 38.23077455163002, 36.44532635807991, 36.806147396564484, 35.0527086853981, 36.005724146962166, 36.88027381896973, 36.637869626283646, 39.61208023130894, 40.547905415296555, 38.40589955449104, 37.055558413267136, 37.6538173109293, 36.284674778580666, 35.93058317899704, 34.84946899116039, 34.77815821766853, 36.81018278002739, 36.97434917092323, 35.189322754740715, 35.66716991364956, 35.30540272593498, 36.992504596710205, 36.3140320032835, 37.42235653102398, 37.18808390200138, 39.35571178793907, 43.18470172584057, 48.75256575644016, 50.143488720059395, 52.516199201345444, 55.775071531534195, 57.42686189711094, 53.69322404265404, 57.04785503447056, 14.000108409672976, 0.14802665304159746, 0.9942775662057102, 2.0585471391677856, 0.49057368538342416, 0.6156472989823669, 18.0238426476717, 64.76833015680313, 57.618162631988525, 56.735526993870735, 31.6328788921237, 21.47690735757351, 29.899339713156223, 51.89579889178276, 32.07836888730526, 0.6081958394497633, 0.06472907392890193, 0.024255647767859045, 0.0037693135482186335, 0.07743747715721838, 0.06632357079070061, 0.050101358065148816, 0.03960514863138087, 0.021613136341329664, 0.07331160362809896, 0.05297162162605673, 0.04416221738210879, 0.05633584012684878, 0.06781356583815068, 0.07320813339902088, 0.03184678505931515, 0.01774069696693914, 0.051529272459447384, 0.02802944087306969, 0.04255841027770657, 0.02722744640777819, 0.05429959470347967, 0.2626450831303373, 26.40211947262287, 59.288978576660156, 45.18284730613232, 26.94193370640278, 27.343718446791172, 53.46492849290371, 56.80724814534187, 62.36498951911926, 51.23526133596897, 60.70052683353424, 10.020970478653908, 0.8521801535971463, 1.8167955614626408, 4.24932005815208, 1.3724723411723971, 0.3291319857817143, 27.607889771461487, 57.00777858495712, 52.41293974220753, 56.496124640107155, 55.89397855103016, 55.478790029883385, 53.38857538998127, 49.398390501737595, 43.920938819646835, 38.970355466008186, 39.88860659301281, 37.289447262883186, 36.5807168930769, 40.22777259349823, 43.440454602241516, 45.282728746533394, 48.838893324136734, 49.78886514902115, 51.58306427299976, 53.84873829782009, 51.9062103331089, 50.20098723471165, 48.59354808926582, 49.25971694290638, 48.54440152645111, 51.30035564303398, 50.76518855988979, 53.48398447036743, 52.37726345658302, 49.442483335733414, 43.486519530415535, 39.97298866510391, 38.4685467928648, 39.30743917822838, 39.756886661052704, 38.693255335092545, 37.772374749183655, 37.566543594002724, 39.26688775420189, 37.62395851314068, 38.462600111961365, 39.975348338484764, 41.63969323039055, 41.242306753993034, 39.55916807055473, 40.140343084931374, 40.283242017030716, 42.305820286273956, 39.942651093006134, 38.723646104335785, 40.2335786819458, 38.429226502776146, 37.872328385710716, 40.92626251280308, 44.09765973687172, 46.683234795928, 49.46476154029369, 47.45835520327091, 49.588691890239716, 45.74093475937843, 48.70205506682396, 46.2525849044323, 45.66931240260601, 47.0288110524416, 44.23341505229473, 41.50636598467827, 39.427824318408966, 37.14612655341625, 39.130315482616425, 39.3053112924099, 39.56644468009472, 40.11626377701759, 39.899929985404015, 42.87837736308575, 41.48052357137203, 42.63464704155922, 43.06276626884937, 40.927022472023964, 41.36532135307789, 38.14090937376022, 39.00641173124313, 40.39982736110687, 39.908950701355934, 38.360488191246986, 37.03362599015236, 38.037159740924835, 38.41793730854988, 39.00187857449055, 38.24805982410908, 39.082852229475975, 37.72383235394955, 38.16629581153393, 37.92045280337334, 36.98431223630905, 37.12745435535908, 40.22762060165405, 42.016819193959236, 39.47845660150051, 38.738241121172905, 39.40602868795395, 38.94763268530369, 37.843157351017, 37.00495272874832, 37.63336680829525, 39.244039580225945, 39.187099635601044, 37.86220572888851, 37.16071397066116, 37.66417935490608, 39.598324969410896, 38.15285213291645, 39.66928996145725, 40.0011071562767, 42.34208554029465, 45.06310053169727, 51.80204652249813, 52.01831191778183, 55.95057271420956, 57.98588789999485, 59.007273092865944, 54.92365121841431, 55.8305561542511, 15.685183089226484, 0.11951176595175639, 3.8556816056370735, 3.5878275660797954, 1.433579830918461, 0.766105450456962, 19.605110697448254, 69.58879709243774, 61.86149373650551, 63.36579881608486, 40.5038695782423, 25.746367760002613, 34.697382152080536, 59.87754799425602, 39.1104843467474, 0.9144776326138526, 0.12249631283339113, 0.02083770334138535, 0.06336376711260527, 0.06831202932517044, 0.07816773562808521, 0.023091201364877634, 0.009774522768566385, 0.02892579013860086, 0.025151316112896893, 0.12204963641124777, 0.13189267425332218, 0.16563268174650148, 0.23993995069758967, 0.17018396174535155, 0.15488798642763868, 0.11373027969966643, 0.17089200031477958, 0.12341068329988047, 0.3040080307982862, 0.10996883778716438, 0.24639479495817795, 0.3466179349925369, 29.8009192943573, 68.0131508409977, 54.68433625996113, 35.87253749370575, 34.14548456668854, 56.33820131421089, 60.84030233323574, 68.9222064614296, 54.4525258988142, 65.75465083122253, 13.555888496339321, 1.0939097637310624, 4.642600854858756, 7.900334196165204, 1.2569707701914012, 0.7543050649110228, 29.142844006419182, 56.713446378707886, 52.2733960300684, 58.974275663495064, 59.090237841010094, 58.728444054722786, 53.86347010731697, 50.47868773341179, 46.72786720097065, 41.269095316529274, 42.079116851091385, 39.4510942697525, 39.47350546717644, 42.423290982842445, 45.49077518284321, 48.29271823167801, 50.71894124150276, 52.30502933263779, 55.68360283970833, 58.35588164627552, 53.917978182435036, 51.00174866616726, 51.36684067547321, 51.889422833919525, 50.14181300997734, 54.03341218829155, 52.22784407436848, 55.944542437791824, 55.592103749513626, 52.72285111248493, 45.405131578445435, 41.402927935123444, 40.435974821448326, 40.822474882006645, 41.397038251161575, 39.26890544593334, 40.54824739694595, 39.6648745983839, 40.880015194416046, 40.23577496409416, 42.3856958001852, 41.72018811106682, 43.4821155667305, 42.93054476380348, 42.995494678616524, 42.31330208480358, 41.9892630726099, 45.8528957515955, 42.412039786577225, 40.83986274898052, 41.69042430818081, 40.3650364279747, 38.778511360287666, 44.03081372380257, 46.236257180571556, 48.84391665458679, 52.11406297981739, 51.14777863025665, 50.30615419149399, 49.22538958489895, 48.30571733415127, 45.805139914155006, 49.76314052939415, 49.89817388355732, 46.95894420146942, 44.59662236273289, 42.41666033864021, 41.622753739356995, 42.249378114938736, 41.6256719827652, 40.23039065301418, 43.96537743508816, 39.57014948129654, 45.59968873858452, 43.82664307951927, 43.77224899828434, 45.950770899653435, 42.39947006106377, 43.92278552055359, 39.54295054078102, 42.16991677880287, 41.90640091896057, 42.32050649821758, 40.59208944439888, 39.1590229421854, 42.31092721223831, 40.53888089954853, 40.17767608165741, 41.87610134482384, 40.54181054234505, 40.580731853842735, 39.34650108218193, 41.54381297528744, 39.65463414788246, 38.746216893196106, 44.397505447268486, 45.33613108098507, 42.75321967899799, 42.259265184402466, 42.25748687982559, 39.78378541767597, 40.015618577599525, 38.11511255800724, 38.47786769270897, 40.45641392469406, 40.9981394559145, 39.81434337794781, 40.2453238517046, 41.97689853608608, 41.63964003324509, 39.22493040561676, 41.65561817586422, 41.61408260464668, 45.02893656492233, 47.95693404972553, 54.52178858220577, 54.86383102834225, 59.111847281455994, 60.74725292623043, 60.57637609541416, 55.96684344112873, 56.64736032485962, 19.80322066694498, 0.20929631689796224, 4.742375900968909, 6.890523657202721, 1.8131152214482427, 0.7563325529918075, 21.442397609353065, 74.28037494421005, 66.41481220722198, 67.02697455883026, 42.58207306265831, 32.05423638224602, 43.21150928735733, 65.2114699780941, 50.2318149805069, 2.2008183924481273, 0.2438410499598831, 0.13915650401031598, 0.200575903581921, 0.21214374457485974, 0.18905977543909103, 0.11576101838727482, 0.20467615075176582, 0.07635332556674257, 0.12346793999313377], [0.08549330465029925, 0.1355009517283179, 0.019456867084954865, 0.02292028846568428, 0.0997725450724829, 0.021644887274305802, 0.021364468630054034, 0.012365945676720003, 0.03672666578495409, 0.029311712496564724, 0.02149758394807577, 0.02633332729601534, 0.17069733497919515, 11.740248072892427, 50.82982309162617, 40.08921302855015, 30.016358233988285, 20.388077683746815, 34.959704875946045, 55.95912605524063, 55.63750371336937, 46.9577244669199, 54.953354224562645, 16.478091292083263, 1.1853081593289971, 0.38740209653042257, 1.1749855382367969, 0.7450734009034932, 0.13721544644795358, 11.036248449236155, 52.4310115724802, 59.46879252791405, 54.39430922269821, 52.07963302731514, 49.176326617598534, 45.38390211760998, 42.53589414060116, 36.79843381047249, 35.59981472790241, 36.08219884335995, 36.1229744553566, 36.58121466636658, 39.8440957814455, 43.96604619920254, 45.7410791516304, 47.1901997923851, 49.121685549616814, 47.4046640843153, 49.36256602406502, 49.068606197834015, 47.225173115730286, 49.034598022699356, 48.772917464375496, 50.51847159862518, 49.97898794710636, 48.985968232154846, 50.13514816761017, 48.68587173521519, 49.30548548698425, 44.78790409862995, 36.50356583297253, 35.38750872015953, 36.42487585544586, 37.20721587538719, 37.63413056731224, 36.08616583049297, 37.21031650900841, 37.70718924701214, 36.935720443725586, 36.764798015356064, 37.70790360867977, 40.47231987118721, 38.91038328409195, 37.062485441565514, 39.11733537912369, 39.170654118061066, 40.82635447382927, 37.8848335146904, 36.806371584534645, 38.59581716358662, 37.888063341379166, 38.54301519691944, 36.694080010056496, 43.75150591135025, 44.33834262192249, 47.6962186396122, 48.30010123550892, 52.35296756029129, 45.19095607101917, 46.65960766375065, 48.14490236341953, 45.83432614803314, 44.634069353342056, 42.44782246649265, 41.68366067111492, 38.36833097040653, 36.134016662836075, 37.404448091983795, 37.73037180304527, 37.807807847857475, 38.270550817251205, 38.28028969466686, 39.39651779830456, 39.357626885175705, 37.61725567281246, 38.43632072210312, 38.997075632214546, 39.06866759061813, 39.08157929778099, 36.007943227887154, 38.52052420377731, 37.352713868021965, 35.62834359705448, 36.305083483457565, 36.59454055130482, 36.28092058002949, 35.64801514148712, 37.743287310004234, 35.945550575852394, 37.11736969649792, 37.1688075363636, 36.654007360339165, 39.48252618312836, 43.48536819219589, 46.91157594323158, 45.44654555618763, 45.21191194653511, 43.30717295408249, 39.21229608356953, 35.39122112095356, 37.61667050421238, 37.93454624712467, 35.69921359419823, 37.211300656199455, 37.829956859350204, 38.11479337513447, 37.604112178087234, 37.91735216975212, 38.48867051303387, 36.92585617303848, 36.54486961662769, 37.01763644814491, 38.31265635788441, 39.818758741021156, 42.057602405548096, 47.74772107601166, 50.103476867079735, 54.92747001349926, 56.90217465162277, 56.342498883605, 49.04778711497784, 4.313758425414562, 0.34092399990186095, 1.5316049521788955, 2.1438266756013036, 1.3641827297396958, 0.305150433559902, 23.30776311457157, 64.04140636324883, 53.70208516716957, 51.83739982545376, 34.26005981862545, 25.22763479501009, 33.337313532829285, 48.900009244680405, 25.892466120421886, 0.5045477917883545, 0.047618350872653536, 0.0819237672840245, 0.026698716283135582, 0.025917615130310878, 0.05502440209966153, 0.045175942868809216, 0.017298389939242043, 0.04749714702484198, 0.09798448867513798, 0.03652388506452553, 0.014972761655371869, 0.04827590113563929, 0.053166721118032, 0.07263093546498567, 0.008580858939239988, 0.027202933270018548, 0.029490967135643587, 0.02198843671067152, 0.0440118731057737, 0.03085517371800961, 0.059320093860151246, 0.15345847641583532, 16.281208656728268, 58.65846320986748, 46.60550996661186, 31.563732102513313, 27.843416333198547, 48.48558448255062, 58.28315354883671, 63.17725673317909, 49.56592731177807, 60.72219707071781, 18.098024167120457, 0.9000066434964538, 0.7561193488072604, 2.6033873157575727, 2.73650414776057, 0.27419661171734333, 13.500816151499748, 53.449402526021004, 58.30838039517403, 55.20282983779907, 52.81065680086613, 51.59040927886963, 49.57802586257458, 44.267582818865776, 38.14600870013237, 38.110598400235176, 37.23055802285671, 38.53326492011547, 38.22382092475891, 42.115758284926414, 45.97052983939648, 48.711159378290176, 49.42354895174503, 51.75498224794865, 49.44987773895264, 52.29169584810734, 49.64927203953266, 48.269322887063026, 49.47225093841553, 50.648610815405846, 52.6693119853735, 50.359849110245705, 50.931935012340546, 50.240372121334076, 51.012266501784325, 51.66613921523094, 46.12592250108719, 39.00859661400318, 38.15240755677223, 38.85024391114712, 39.19521979987621, 38.81940856575966, 37.3150122910738, 37.888876497745514, 39.653007835149765, 38.618376553058624, 37.61569395661354, 38.089501932263374, 42.83424653112888, 40.521116852760315, 39.61491487920284, 40.68417750298977, 40.43165065348148, 42.11717560887337, 39.913795441389084, 38.885992392897606, 40.6567619740963, 39.75985050201416, 39.824409037828445, 38.91647435724735, 44.77356746792793, 45.52805878221989, 50.05692936480045, 49.86538544297218, 53.78386817872524, 46.08749516308308, 46.962094232439995, 49.090413227677345, 46.337761133909225, 46.3939943164587, 44.4704083353281, 43.45882661640644, 41.13269783556461, 38.625558167696, 38.16224902868271, 39.278598725795746, 38.70661161839962, 39.68420796096325, 40.43511226773262, 40.51736265420914, 40.73210813105106, 40.10119378566742, 40.83840362727642, 41.01368062198162, 40.59184245765209, 41.529643535614014, 36.82625971734524, 39.29251357913017, 39.00679171085358, 38.299474865198135, 38.8509126752615, 37.01870039105415, 37.989343106746674, 37.64629751443863, 39.26033690571785, 37.44987465441227, 38.60906705260277, 38.229714408516884, 38.66511404514313, 41.68822042644024, 43.47331523895264, 47.52434626221657, 47.61701188981533, 46.95226036012173, 43.55954401195049, 40.11687554419041, 38.3043310046196, 39.81679804623127, 37.58995793759823, 38.315551802515984, 39.12552013993263, 40.65665178000927, 39.83467988669872, 39.28255811333656, 38.709119483828545, 41.17140635848045, 39.069328755140305, 39.44086901843548, 40.0988645106554, 41.3312865793705, 42.975918129086494, 46.80237740278244, 49.51643116772175, 54.11407046020031, 55.268364921212196, 60.66587269306183, 57.132267504930496, 53.10814283788204, 6.291411705315113, 0.5384606751613319, 6.293236082419753, 5.271789617836475, 1.491584312170744, 0.5996087158564478, 25.03102194517851, 71.15760371088982, 58.39227609336376, 60.01513861119747, 38.61187890172005, 25.385440327227116, 36.528861075639725, 55.21476499736309, 31.45491164177656, 0.6296727620065212, 0.0866271578706801, 0.018184334294346627, 0.015091839250089834, 0.022543926825164817, 0.005813428288092837, 0.02142285153240664, 0.04346424604591448, 0.040753221401246265, 0.05610434200207237, 0.1711652590893209, 0.2468503697309643, 0.0749738363083452, 0.14533075707731768, 0.1979113114066422, 0.060384559983504005, 0.1969322850345634, 0.09158509026747197, 0.08191798595362343, 0.14155260199913755, 0.08791439817287028, 0.21550717268837616, 0.23090226924978197, 20.590789206326008, 68.74810740351677, 52.184195816516876, 41.6107539832592, 28.324943594634533, 46.351455599069595, 64.40327614545822, 67.09036275744438, 56.14000014960766, 64.26080659031868, 22.143874168395996, 1.5000755502842367, 3.7986811017617583, 5.942293563857675, 2.845851117745042, 0.4538082832004875, 14.794000759720802, 57.12881349027157, 60.58121703565121, 58.495987728238106, 55.42098753154278, 54.73771199584007, 49.28060822188854, 47.77429684996605, 39.954460859298706, 40.75681820511818, 39.74982663989067, 40.779856368899345, 40.36937579512596, 44.71528999507427, 47.456136122345924, 50.424343049526215, 52.78475359082222, 53.66786040365696, 50.95009423792362, 53.804501071572304, 51.75654016435146, 49.76165860891342, 51.25702276825905, 52.882883325219154, 54.855201691389084, 53.921827375888824, 54.320650175213814, 54.76840674877167, 53.096963837742805, 53.484964817762375, 47.62421250343323, 40.31029276549816, 39.161675199866295, 41.364709585905075, 39.93082232773304, 41.14035062491894, 39.25567075610161, 40.33327013254166, 41.021660193800926, 41.206026300787926, 40.53240604698658, 40.788535103201866, 44.95416417717934, 42.78415381908417, 39.77860629558563, 43.740399107337, 42.178941294550896, 44.40779909491539, 40.69745399057865, 41.178679168224335, 40.92786602675915, 41.1652696877718, 42.92237900197506, 41.38628862798214, 48.4431217610836, 47.73238889873028, 52.39223465323448, 52.41311453282833, 55.33067397773266, 50.922579914331436, 50.64860701560974, 50.76175734400749, 49.7932843118906, 50.23783765733242, 48.32775995135307, 46.37293964624405, 43.831123039126396, 39.40475955605507, 40.11353172361851, 41.92440055310726, 42.01667480170727, 42.97841839492321, 42.32437089085579, 42.670555114746094, 44.182129204273224, 42.142900228500366, 41.879049986600876, 42.47614234685898, 43.924050852656364, 42.2799626737833, 38.9188302308321, 42.77305081486702, 39.43310983479023, 39.359838366508484, 40.478866919875145, 39.66141298413277, 39.67606499791145, 39.23642858862877, 41.6828703135252, 38.63204441964626, 41.04541651904583, 40.55580139160156, 41.54977485537529, 44.252026453614235, 47.025087252259254, 50.78102231025696, 50.533864572644234, 49.57248575985432, 48.20245407521725, 43.30761753022671, 38.80465015769005, 41.31485626101494, 40.571555346250534, 39.61510106921196, 40.911956280469894, 43.06889533996582, 41.42424859106541, 41.46452642977238, 41.425969898700714, 45.5701719224453, 40.38446858525276, 42.16670215129852, 41.24470442533493, 43.65526847541332, 44.445132091641426, 48.62787924706936, 51.31256438791752, 55.546080619096756, 59.0158112347126, 64.0020252764225, 56.60291790962219, 54.0887638181448, 7.936204746365547, 0.8152203087229282, 7.25661501288414, 12.307236548513174, 7.162039987742901, 0.6528298475313932, 27.751512564718723, 75.81654131412506, 61.76299162209034, 65.64097613096237, 45.863200798630714, 35.49421079456806, 46.442943289875984, 62.44034707546234, 39.020296186208725, 1.1455425806343555, 0.22551800269866362, 0.2558946266071871, 0.20337084657512605, 0.24617025075713173, 0.11931649947655387, 0.09328711690614, 0.11377537259249948, 0.12559053429868072, 0.2721296710660681], [0.03854261951346416, 0.049052543836296536, 0.07227088251966052, 0.02766444336884888, 0.03538724879035726, 0.007500191732106032, 0.0448523553495761, 0.04135620154556818, 0.0506622955435887, 0.10382741733337753, 0.034313168143853545, 0.0538280452019535, 0.06137889315141365, 11.055874396115541, 48.18926878273487, 42.857451885938644, 25.618428625166416, 21.564920134842396, 29.341172464191914, 44.54973667860031, 54.39460180699825, 50.49244299530983, 52.84491956233978, 26.968575976788998, 0.7507998717483133, 1.1661519622430205, 2.9052495304495096, 3.6566157499328256, 0.07441280235070735, 11.99167488142848, 58.48546229302883, 58.188360035419464, 51.1837475001812, 50.16769342124462, 45.64569666981697, 42.51581981778145, 38.45847733318806, 36.19933895766735, 34.16599586606026, 37.11532160639763, 35.65662547945976, 36.179241836071014, 40.547073259949684, 45.49722343683243, 44.74050544202328, 47.68988437950611, 46.9030150026083, 47.95986749231815, 50.0161499530077, 48.60139086842537, 49.19269233942032, 48.78131881356239, 48.345786184072495, 49.91305388510227, 49.13699492812157, 49.72617231309414, 50.194622576236725, 48.82775232195854, 47.81599961221218, 44.52616274356842, 36.45776309072971, 37.37313777208328, 37.76019260287285, 38.22445549070835, 36.732195764780045, 36.158901527523994, 35.81335946917534, 39.18549232184887, 38.238051161170006, 37.62864366173744, 39.24665004014969, 39.30470332503319, 38.48700240254402, 37.51635208725929, 39.42151665687561, 40.05745433270931, 40.46440489590168, 39.20209363102913, 39.350920245051384, 36.80805869400501, 37.45095759630203, 37.00123652815819, 35.89963763952255, 44.8429099470377, 46.483342722058296, 49.13715831935406, 47.11854323744774, 51.346758753061295, 46.17300197482109, 46.03705286979675, 50.81529267132282, 48.425114527344704, 46.93573884665966, 43.91896292567253, 42.34837420284748, 36.60608813166618, 35.50426505506039, 34.80628810822964, 36.97131313383579, 36.73546738922596, 37.31473870575428, 38.30353304743767, 39.74150888621807, 39.887485653162, 38.538523837924004, 37.99262993037701, 38.88556681573391, 38.62460821866989, 38.23524311184883, 36.28876335918903, 37.17938616871834, 37.08924740552902, 36.378332152962685, 35.76428510248661, 36.281038373708725, 38.098017275333405, 37.362163960933685, 36.42957620322704, 35.595433562994, 36.31241708993912, 36.83802388608456, 39.81233708560467, 42.580765932798386, 46.33717976510525, 48.288101479411125, 50.148755237460136, 48.18255454301834, 46.90075032413006, 44.88389074802399, 39.41337749361992, 37.31573425233364, 36.57597474753857, 37.77225695550442, 40.17333671450615, 38.68994951248169, 38.70949946343899, 37.93160900473595, 39.51993137598038, 38.33261288702488, 38.1082159280777, 35.600707679986954, 37.000951543450356, 38.17582570016384, 39.50534775853157, 36.91761061549187, 41.683774664998055, 47.74298273026943, 52.77046635746956, 52.495953887701035, 57.43218161165714, 44.64752063155174, 3.1371959717944264, 0.26720032619778067, 4.754374232143164, 2.9355291556566954, 0.628002870362252, 0.47458574641495943, 31.963630244135857, 62.79125824570656, 53.938428685069084, 48.05253691971302, 30.32735824584961, 30.161861926317215, 39.50384683907032, 49.29085627198219, 12.570085544139147, 0.16508576343767345, 0.0500082296639448, 0.1160800528305117, 0.0520529986533802, 0.03897356611560099, 0.034549627525848337, 0.0942909310106188, 0.0396171602915274, 0.024942908057710156, 0.04872319354035426, 0.08350627103936858, 0.014029364865564276, 0.051724041695706546, 0.023477040231227875, 0.0061990264202904655, 0.008032242967601633, 0.029186810897954274, 0.12255264926352538, 0.031022322073113173, 0.04074710981512908, 0.06550266640260816, 0.1039644845877774, 0.03466909103735816, 13.603161759674549, 56.95106282830238, 47.62948282063007, 31.92857712507248, 18.662854358553886, 34.226063042879105, 55.802350267767906, 60.14986418187618, 55.65144516527653, 57.2824202477932, 29.458808451890945, 0.49221475201193243, 0.5434264743234962, 5.05207353271544, 5.405883472412825, 0.07445026596542448, 13.101084250956774, 61.25614821910858, 59.09325107932091, 54.29545372724533, 53.109233379364014, 47.213123962283134, 44.33632493019104, 41.403657495975494, 38.47580820322037, 37.0150525867939, 38.99016760289669, 37.891999930143356, 39.399945214390755, 43.06262947618961, 46.87931187450886, 47.0113205909729, 50.820996165275574, 49.34946432709694, 50.041684582829475, 50.14082886278629, 50.54178334772587, 51.75170682370663, 50.4780987650156, 49.34685006737709, 51.8762831389904, 51.06368154287338, 51.57602705061436, 51.65343649685383, 51.62742309272289, 49.84025739133358, 46.08447052538395, 38.758649826049805, 39.96526747941971, 39.49372798204422, 38.35198424756527, 38.65001365542412, 37.075530141592026, 37.722673416137695, 38.72427687048912, 39.35206018388271, 38.686814680695534, 39.665303975343704, 40.6517880409956, 39.263726323843, 37.809240370988846, 40.156260430812836, 41.59711271524429, 41.66515186429024, 42.04280599951744, 41.365036368370056, 38.78056325018406, 39.820426851511, 38.03217440843582, 39.01731714606285, 46.77804730832577, 49.4877503067255, 50.78139089047909, 49.509739726781845, 52.591343969106674, 48.95106330513954, 45.72179518640041, 50.4675505310297, 49.27161030471325, 46.90656781196594, 43.8516229391098, 42.87994287908077, 38.95349957048893, 36.46314740180969, 36.982427537441254, 38.82514625787735, 39.92137983441353, 40.84762953221798, 38.662727773189545, 40.94743497669697, 40.628898069262505, 40.31308561563492, 38.87883357703686, 41.311010867357254, 40.208036452531815, 39.55583184957504, 38.43575835227966, 38.74777860939503, 38.480831533670425, 38.48316080868244, 36.98876179754734, 38.095950186252594, 38.93107317388058, 38.44139724969864, 37.791746109724045, 38.32749456167221, 37.827376797795296, 39.29661735892296, 39.99166086316109, 46.12034060060978, 48.819746151566505, 50.9605360776186, 51.37844905257225, 51.25754714012146, 48.79942864179611, 45.80472193658352, 41.526626497507095, 39.65023398399353, 37.70839378237724, 39.29645776748657, 40.6480148434639, 41.75485745072365, 40.44810377061367, 40.45499660074711, 41.315642818808556, 42.65594109892845, 38.681559562683105, 37.80255652964115, 38.61347481608391, 41.56844325363636, 40.56473471224308, 41.79309479892254, 43.957751244306564, 51.31770171225071, 55.01491092145443, 56.69048421084881, 59.02165152132511, 47.92435459792614, 3.530213632620871, 0.6403126660734415, 7.239486007019877, 6.152246072888374, 2.0504478737711906, 0.6142349622678012, 35.739601626992226, 68.20519253611565, 56.44884757697582, 55.01203067600727, 30.86283691227436, 26.572202146053314, 45.66809266805649, 54.943725541234016, 18.263478688895702, 0.23280448280274868, 0.015670900902478024, 0.02088338809699053, 0.07800168750691228, 0.009801730830076849, 0.06894502192153595, 0.04139898264838848, 0.040366970642935485, 0.01602142467163503, 0.027147867767780554, 0.17450262297643349, 0.18182557221734896, 0.19796379609033465, 0.09976202883990481, 0.09316369032603689, 0.08605464288848452, 0.16025726159568876, 0.13451705686748028, 0.16094594495370984, 0.20314023160608485, 0.1220238022506237, 0.193429155042395, 0.15696702408604324, 17.034003362059593, 65.6647476553917, 55.74309624731541, 37.54922032356262, 28.893472887575626, 40.47972947359085, 57.91687600314617, 62.891002893447876, 61.31445989012718, 60.108541399240494, 35.8468546718359, 0.7621271826792508, 2.750361291691661, 12.43658160790801, 11.825268510729074, 0.2956572960829362, 16.55982680618763, 61.766897812485695, 61.305853351950645, 57.05788269639015, 54.38856393098831, 50.05186043679714, 45.66151142120361, 45.782002955675125, 39.439022317528725, 38.75144921243191, 41.96578413248062, 40.48623472452164, 41.93798862397671, 45.23704759776592, 48.36126655340195, 49.33230824768543, 52.5722423940897, 52.09763266146183, 53.79178315401077, 52.86014914512634, 51.55698247253895, 53.8898216933012, 52.80363857746124, 52.14616745710373, 54.72254320979118, 53.27316038310528, 55.29791593551636, 53.21556307375431, 54.363568872213364, 52.27306164801121, 48.3601114153862, 39.96394895017147, 40.602804869413376, 41.602318435907364, 40.654751881957054, 41.596865728497505, 38.02214294672012, 40.39243295788765, 41.22088350355625, 42.03875161707401, 40.9813329577446, 43.4521047770977, 44.25271041691303, 42.01272301375866, 38.91694933176041, 42.98244997859001, 43.129388093948364, 43.62426593899727, 43.83461885154247, 43.18441294133663, 40.02979941666126, 40.64610354602337, 40.15958905220032, 40.07568575441837, 50.425748974084854, 51.727471724152565, 52.67135247588158, 51.52229033410549, 53.367862701416016, 52.10119307041168, 50.007813200354576, 51.95192568004131, 53.571505174040794, 48.62797424197197, 46.829701736569405, 48.00600841641426, 41.458659544587135, 38.912822753190994, 37.888663709163666, 40.98394721746445, 41.120120510458946, 42.50256232917309, 41.297248005867004, 44.6148955821991, 44.69058372080326, 42.83781073987484, 42.98799008131027, 43.48629534244537, 41.322664842009544, 42.38576039671898, 40.1016079634428, 40.432741194963455, 40.83517760038376, 40.51940694451332, 38.578535690903664, 41.369425132870674, 41.33338026702404, 40.44002540409565, 39.8268599063158, 40.13253830373287, 40.91715060174465, 42.761385440826416, 44.14783984422684, 46.741128489375114, 49.59218010306358, 53.683386370539665, 53.761532977223396, 52.23324738442898, 49.557126984000206, 48.45836654305458, 44.033158197999, 41.701998487114906, 39.118448719382286, 42.284628823399544, 43.96000072360039, 44.96046423912048, 42.12693348526955, 41.83996148407459, 43.6399856954813, 45.34585855901241, 41.81678652763367, 38.986022025346756, 40.80433085560799, 42.737047746777534, 42.29458048939705, 42.94464960694313, 45.49763761460781, 53.09972628951073, 56.35575257241726, 58.507580906152725, 59.00232195854187, 52.056853249669075, 5.9658432751894, 2.9888448072597384, 15.850492268800735, 12.290342655032873, 3.4440703550353646, 0.6841952644754201, 39.218322560191154, 73.92439484596252, 61.468233838677406, 60.26549197733402, 43.36212940514088, 39.519585594534874, 50.924567207694054, 62.435950711369514, 22.117000110447407, 0.2990483766188845, 0.13291991053847596, 0.17806329909944907, 0.1048408867791295, 0.10737485354184173, 0.11073773246607743, 0.2526472258614376, 0.20629245933378115, 0.07434597937390208, 0.08923369183321483], [0.040993454604176804, 0.0622633847524412, 0.11594231022172607, 0.021504012802324723, 0.06180025862704497, 0.10222742115729488, 0.014950650293030776, 0.01953984105057316, 0.08965801476733759, 0.07626528458786197, 0.03280231132521294, 0.16129162249853835, 0.08500930562149733, 9.326014369726181, 50.46276658773422, 44.74450282752514, 41.190162152051926, 75.58182030916214, 60.99503383040428, 31.04354191571474, 50.508413538336754, 49.245418310165405, 51.16330459713936, 35.06418786942959, 0.19183758966391906, 0.4345550131984055, 0.29835800116416067, 2.644161502830684, 0.4901061620330438, 18.83035507053137, 59.91881377995014, 52.37267330288887, 52.027632817626, 44.75412391126156, 44.50390733778477, 37.004192769527435, 36.26464605331421, 36.12487435340881, 35.68218670785427, 35.07564425468445, 35.25545060634613, 39.04426150023937, 42.267985716462135, 44.44182246923447, 47.150792106986046, 46.85998611152172, 49.73357431590557, 50.65611161291599, 51.777370646595955, 49.08684901893139, 48.83202709257603, 48.64056296646595, 48.809771686792374, 48.86678382754326, 50.902547389268875, 48.53793807327747, 49.09701347351074, 50.33075787127018, 49.83764313161373, 41.0266949236393, 35.505146607756615, 38.464762195944786, 38.014923334121704, 36.38577215373516, 34.62243877351284, 36.49407394230366, 36.59312702715397, 36.93911366164684, 37.74522140622139, 37.82999485731125, 39.10770669579506, 39.2284794151783, 39.45329815149307, 37.6468750834465, 38.888101279735565, 38.07905249297619, 39.270391166210175, 38.20454455912113, 38.87939974665642, 37.728247717022896, 38.68291988968849, 36.771804839372635, 36.34583629667759, 43.41463878750801, 49.39630061388016, 51.17196433246136, 50.684522688388824, 53.031945526599884, 52.9604409635067, 44.94042791426182, 51.37773849070072, 50.36909021437168, 47.510195821523666, 45.66466525197029, 43.517012894153595, 38.861225321888924, 36.45628497004509, 38.55793699622154, 37.67681747674942, 38.315202221274376, 38.24313148856163, 36.98926717042923, 38.59216555953026, 38.22796270251274, 38.75989995896816, 40.33625677227974, 38.72453525662422, 39.613664746284485, 38.583528622984886, 35.73948763310909, 37.36056424677372, 38.187681064009666, 35.580298975110054, 36.25864997506142, 37.419985458254814, 37.29324325919151, 37.337252497673035, 36.18628665804863, 35.90828217566013, 36.053487583994865, 37.381603717803955, 41.11223593354225, 41.80783800780773, 46.637523248791695, 50.75090892612934, 49.79597456753254, 54.3013472110033, 49.527670964598656, 49.370291009545326, 45.679803639650345, 40.21461769938469, 38.61980527639389, 39.461224526166916, 38.844726607203484, 39.019859209656715, 41.03619061410427, 42.68644966185093, 41.7221450060606, 44.73163291811943, 42.15131677687168, 40.568811893463135, 37.85899870097637, 37.71388828754425, 38.25276777148247, 39.55241583287716, 38.2185810059309, 44.16328601539135, 51.40882842242718, 54.723607152700424, 55.17628066241741, 43.411142975091934, 4.1787355206906796, 0.6444387696683407, 4.899584390223026, 3.2969526993110776, 0.6362603616435081, 0.9104893309995532, 43.011917397379875, 58.850417509675026, 54.61787402629852, 43.41191813349724, 29.535241350531578, 29.41084362566471, 32.810015827417374, 43.80834326148033, 4.364547925069928, 0.13001325947698206, 0.06124111714598257, 0.05171267199330032, 0.021290760378178675, 0.0286775714266696, 0.03455749429122079, 0.08839039684971794, 0.030288406669569667, 0.04773357301019132, 0.04022278248157818, 0.05638168629957363, 0.037039555245428346, 0.07652318832697347, 0.019635507596831303, 0.02017020644416334, 0.04448082880116999, 0.09992132341722026, 0.032527230578125454, 0.048404611807200126, 0.05553154871449806, 0.037464512715814635, 0.17904452222865075, 0.044845108277513646, 12.099637538194656, 59.44625973701477, 47.969815358519554, 42.1361517906189, 53.66075858473778, 47.72963024675846, 38.08629110455513, 54.698251113295555, 54.867414236068726, 55.996698439121246, 39.0909343957901, 0.21089644666062668, 0.08790233827312477, 3.0787764815613627, 3.814445505850017, 0.5348802579101175, 20.29589083045721, 61.337923631072044, 55.098814219236374, 54.23558034002781, 47.50295341014862, 45.76418571174145, 37.97963462769985, 39.53882776200771, 37.759812623262405, 37.05126844346523, 38.40599834918976, 37.1429955214262, 40.35578012466431, 43.31180490553379, 46.994491294026375, 47.185332253575325, 48.42516012489796, 51.824799701571465, 52.19556100666523, 52.3179030418396, 50.25645665824413, 50.229782089591026, 50.276283994317055, 50.28974287211895, 51.54011517763138, 51.4830232411623, 50.41926272213459, 50.85989847779274, 52.46549092233181, 52.053004056215286, 42.67507307231426, 37.71103464066982, 40.300014317035675, 39.52205166220665, 37.93197378516197, 36.342857256531715, 37.56915405392647, 39.45450268685818, 38.588073179125786, 39.757015854120255, 39.39533606171608, 39.91498477756977, 39.319826513528824, 40.71603499352932, 40.77816545963287, 40.02918764948845, 39.71633143723011, 40.91475673019886, 41.05188377201557, 40.41676685214043, 39.904071763157845, 39.115173295140266, 37.531608268618584, 38.28558661043644, 46.98438763618469, 50.6906745582819, 52.91579335927963, 52.69489221274853, 53.74982200562954, 53.78968946635723, 46.388165429234505, 52.24103696644306, 51.664976477622986, 48.556154295802116, 47.687418311834335, 43.680464923381805, 39.56365562975407, 37.81246639788151, 40.45997813344002, 38.29762436449528, 39.27555128931999, 39.506191313266754, 38.10459092259407, 40.04350908100605, 39.133815094828606, 40.61743788421154, 41.15299254655838, 42.345949932932854, 41.062055826187134, 40.19022300839424, 38.0226369202137, 40.82618348300457, 39.48124185204506, 37.576293870806694, 37.7997674793005, 39.5096605271101, 37.96070024371147, 38.18340629339218, 39.39625561237335, 37.75188624858856, 37.50750616192818, 38.876413106918335, 41.809711307287216, 44.28634241223335, 48.74984510242939, 52.35559701919556, 50.73217213153839, 56.995072066783905, 52.2138000279665, 50.841621458530426, 47.83806122839451, 40.79947471618652, 41.43070824444294, 42.28575736284256, 41.36312887072563, 42.6641296595335, 42.91172817349434, 44.35968607664108, 43.77978399395943, 46.31537653505802, 42.308039367198944, 43.06325264275074, 39.868023097515106, 39.62274245917797, 39.48987498879433, 41.6655508428812, 39.30693760514259, 48.76096710562706, 52.920812889933586, 55.9759933501482, 56.00931376218796, 47.456470504403114, 4.783901497721672, 1.4765337947756052, 7.188824275508523, 7.868898008018732, 1.0941508132964373, 0.8302432182244956, 45.01934967935085, 64.66268822550774, 57.59300038218498, 50.20533800125122, 33.0636940151453, 28.499358035624027, 38.977643474936485, 51.94724813103676, 7.1359144896268845, 0.2935174765298143, 0.06083746673539281, 0.025034693171619438, 0.029006001459492836, 0.04515604588959832, 0.04676259522966575, 0.024370738174184225, 0.04575718550768215, 0.041448814154136926, 0.03198679863999132, 0.19930380309233442, 0.09240831757779233, 0.25094779673963785, 0.1625949377194047, 0.16620072157820687, 0.28953190601896495, 0.07746249495539814, 0.13815646001603454, 0.28333218244370073, 0.14385818765731528, 0.10623415029840544, 0.3631654236232862, 0.21481927600689232, 13.625685051083565, 67.94062793254852, 55.943778678774834, 54.256251230835915, 79.09277111291885, 71.94964841008186, 45.37395045161247, 59.42017413675785, 61.93027384579182, 61.68024726212025, 46.243955567479134, 0.318972934037447, 1.2284153024666011, 7.135988585650921, 9.210651610046625, 0.7136514026205987, 23.42856053262949, 63.581904619932175, 55.79675316810608, 59.16912920773029, 50.00503554940224, 48.252026215195656, 39.75214831531048, 41.26322843134403, 40.75322359800339, 39.60926838219166, 40.20835943520069, 40.46435549855232, 42.65822857618332, 46.183656603097916, 49.517061933875084, 51.84046246111393, 52.17903949320316, 54.84231658279896, 56.71481430530548, 53.4821567684412, 52.111235931515694, 52.79221259057522, 53.12456175684929, 52.235044687986374, 53.8394857943058, 54.97553363442421, 52.91867360472679, 53.44937592744827, 54.94933404028416, 55.234200954437256, 44.04793180525303, 40.28356499969959, 43.12900431454182, 42.47399166226387, 39.90602485835552, 37.19911091029644, 39.327030926942825, 40.70148937404156, 41.90846420824528, 41.412909999489784, 42.62149594724178, 42.46803738176823, 42.42389515042305, 43.82803000509739, 42.78329886496067, 41.40143841505051, 41.192202642560005, 43.01551200449467, 42.570320293307304, 41.403391510248184, 40.87567962706089, 41.27762585878372, 42.37200513482094, 40.70148937404156, 48.07347759604454, 52.83228524029255, 54.5275604724884, 54.21494744718075, 55.493145659565926, 55.94019927084446, 49.48273457586765, 54.65405188500881, 54.069012477993965, 50.14584839344025, 50.11074207723141, 46.323242112994194, 43.34342300891876, 40.83666332066059, 42.76278376579285, 40.02618961036205, 40.67044124007225, 42.01377555727959, 40.114523470401764, 42.50182896852493, 40.92523276805878, 42.6033291220665, 46.08635142445564, 43.49971242249012, 42.66737088561058, 43.70031125843525, 39.95840884745121, 42.42622062563896, 41.838050186634064, 38.424894735217094, 40.51216833293438, 42.13965140283108, 41.01751461625099, 41.08827441930771, 41.76344119012356, 39.557222574949265, 40.093943774700165, 41.649310514330864, 45.00703074038029, 46.73159100115299, 51.914847269654274, 54.64556314051151, 52.346823289990425, 57.29736104607582, 53.10821123421192, 53.87538246810436, 50.657126158475876, 44.0790331363678, 42.752148136496544, 45.1822355389595, 43.40577006340027, 43.611270636320114, 46.09682746231556, 46.05032555758953, 45.07481150329113, 49.76628676056862, 46.81012138724327, 45.95009073615074, 43.1710110604763, 43.2419266551733, 40.343928560614586, 45.033705309033394, 40.60214750468731, 50.03380760550499, 55.63594199717045, 59.735401421785355, 54.60498511791229, 52.056089490652084, 7.096024230122566, 2.0330269960686564, 13.854760508984327, 12.874994482845068, 2.6449112500995398, 1.076077320612967, 50.38458198308945, 69.73030909895897, 62.155320569872856, 55.35435810685158, 42.73290976881981, 39.78034280240536, 45.13111688196659, 63.130842223763466, 10.532065853476524, 0.33458406978752464, 0.15546990442089736, 0.135791250213515, 0.06132017442723736, 0.11346428655087948, 0.2072100804070942, 0.18751405994407833, 0.1673958168248646, 0.15477184031624347, 0.10923383699264377], [0.07162522888393141, 0.0074367172328493325, 0.03672621307487134, 0.024111980965244584, 0.0799022831779439, 0.03540417346812319, 0.040511507613700815, 0.013565382487286115, 0.0530632991285529, 0.05970178041025065, 0.05388858218793757, 0.15541519329417497, 0.05115443222166505, 3.6954178428277373, 42.69161358475685, 48.68704967200756, 47.51272268593311, 79.51305896043777, 75.41127786040306, 44.86416220664978, 52.673495560884476, 53.10205556452274, 47.99764886498451, 46.848233342170715, 2.732717413455248, 0.367408549063839, 3.8020812068134546, 5.07997116073966, 0.07198999446700327, 13.685920368880033, 59.60986375808716, 52.941837161779404, 51.067146956920624, 46.12384021282196, 39.99886907637119, 36.88503496348858, 38.520782589912415, 34.391221180558205, 35.46223171055317, 36.225101575255394, 38.34558919072151, 38.55174332857132, 43.23707811534405, 44.99421402812004, 46.29672333598137, 49.84221048653126, 50.65534025430679, 49.615746438503265, 50.1107382774353, 48.2657016813755, 47.63437695801258, 49.6146596968174, 50.59739336371422, 47.70937353372574, 47.31568045914173, 48.26515831053257, 50.60293346643448, 49.3041517585516, 48.69618058204651, 40.10290749371052, 35.6826388835907, 38.179842084646225, 36.33427731692791, 37.60041877627373, 37.806265130639076, 37.00581908226013, 36.92213997244835, 37.14051805436611, 37.295431941747665, 38.916759341955185, 38.3760179579258, 38.33480156958103, 38.038238883018494, 37.88952246308327, 39.68362279236317, 38.77629227936268, 39.74740996956825, 39.9477656185627, 39.08189468085766, 38.95958684384823, 37.44708560407162, 35.85107244551182, 36.302252635359764, 43.74403931200504, 48.268669322133064, 45.671683475375175, 50.12425035238266, 53.65043453872204, 53.70071344077587, 48.73563386499882, 49.535962119698524, 52.78380364179611, 48.76358896493912, 47.35843576490879, 44.26320545375347, 38.602539002895355, 35.438551381230354, 36.03066600859165, 38.21005046367645, 37.95702964067459, 38.20793017745018, 38.69661055505276, 37.382565066218376, 38.06135684251785, 38.12032587826252, 39.007597267627716, 39.10674914717674, 39.47876438498497, 38.736869394779205, 37.11045406758785, 35.948054641485214, 37.080177292227745, 38.23203608393669, 37.442651242017746, 36.584265902638435, 36.53599329292774, 37.016986683011055, 37.831928953528404, 36.9109495729208, 35.656317695975304, 39.81364421546459, 39.46361839771271, 43.61685633659363, 46.38270892202854, 48.85748192667961, 47.690066769719124, 46.88011363148689, 51.388203129172325, 50.82364082336426, 48.04885111749172, 46.22159756720066, 43.74841667711735, 41.73278823494911, 42.40458458662033, 42.90184110403061, 43.07313971221447, 43.47451597452164, 44.98389758169651, 46.835618019104004, 45.23270823061466, 44.14416164159775, 41.409668773412704, 39.82176437973976, 37.508893087506294, 38.2752625644207, 38.46288129687309, 46.86658635735512, 52.313654869794846, 54.343486949801445, 55.875838324427605, 33.060695976018906, 0.12032300015562214, 1.195605369284749, 3.2496157893911004, 5.680651003494859, 1.0900800442323089, 2.6620803913101554, 50.32689347863197, 55.13472609221935, 54.56621199846268, 39.03624773025513, 23.155085407197475, 22.315138578414917, 39.03270252048969, 38.0961287766695, 1.5297575388103724, 0.14701503154356033, 0.036823660775553435, 0.01771596489561489, 0.01905873268697178, 0.01831134173698956, 0.025764992460608482, 0.02053371223155409, 0.008579582445236156, 0.05983416842354927, 0.05026398859627079, 0.08380419880268164, 0.06746198079781607, 0.06267533608479425, 0.029083611552778166, 0.07229426759295166, 0.03463699686108157, 0.07254925469169393, 0.003947166687794379, 0.096284176397603, 0.0053222457336232765, 0.03540651123330463, 0.04046021778776776, 0.049562306521693245, 5.0764250010252, 51.36963352560997, 55.09922839701176, 55.987548530101776, 77.35826298594475, 70.63631728291512, 46.848696917295456, 56.072751358151436, 58.469541147351265, 53.589368015527725, 50.85493974387646, 1.8887172709219158, 0.36732248961925507, 1.6688205767422915, 7.405747510492802, 0.2968474931549281, 15.697659719735384, 62.502485141158104, 55.335404723882675, 55.389179438352585, 46.98767066001892, 42.34640970826149, 37.80504159629345, 40.09374998509884, 36.11017294228077, 39.89600859582424, 37.38359101116657, 40.29084920883179, 39.62068296968937, 45.09002588689327, 47.24455967545509, 47.88865551352501, 50.310987532138824, 52.68893413245678, 50.36290034651756, 51.538568660616875, 49.41401146352291, 50.628851875662804, 50.77224098145962, 52.5135887414217, 49.080096781253815, 51.03192284703255, 50.94522289931774, 51.84125281870365, 51.771359369158745, 50.69096714258194, 42.209339663386345, 38.34768667817116, 39.920543879270554, 38.275688141584396, 38.20338562130928, 39.30871970951557, 38.463876843452454, 38.858303278684616, 37.34145887196064, 40.32220892608166, 41.105369701981544, 40.76294347643852, 40.7466309517622, 40.29168136417866, 39.73187640309334, 42.000217884778976, 41.85042232275009, 40.00037379562855, 40.19062578678131, 40.27264818549156, 39.956904128193855, 38.76852169632912, 38.787231892347336, 38.77615928649902, 45.5870658159256, 50.86422264575958, 48.52182313799858, 51.73889771103859, 54.60680142045021, 55.214210227131844, 49.504663199186325, 50.75897969305515, 54.53812390565872, 51.34072847664356, 48.40868040919304, 47.44936488568783, 39.625987485051155, 37.178364023566246, 36.86899982392788, 39.41672131419182, 39.46145251393318, 39.808039516210556, 40.1991905272007, 39.83263939619064, 39.50242571532726, 39.173800349235535, 39.26227480173111, 40.9195938706398, 39.66331288218498, 40.93023329973221, 38.48273903131485, 38.739263266325, 38.05408403277397, 39.09588173031807, 38.336948454380035, 38.631858229637146, 37.81421050429344, 38.19715395569801, 38.25397990643978, 38.02511438727379, 37.912758216261864, 42.08815656602383, 41.81277774274349, 44.457462430000305, 48.36493715643883, 51.14287689328194, 49.4512190669775, 47.366981506347656, 53.07503521442413, 54.723838940262794, 50.112755969166756, 48.20903532207012, 46.272640228271484, 44.90576237440109, 44.104370176792145, 44.70405399799347, 45.43261930346489, 44.47911746799946, 46.500920578837395, 49.3626344203949, 47.13042140007019, 46.35262593626976, 42.05272726714611, 41.74317307770252, 39.247246608138084, 41.08497239649296, 41.42920732498169, 50.2590025216341, 53.611338436603546, 58.426269069314, 57.02895104885101, 36.10085964202881, 0.8471628790721297, 3.5058213165029883, 6.784079493954778, 4.659624891355634, 0.9812930098269135, 2.245190511457622, 54.1788037866354, 60.74737071990967, 59.029106721282005, 46.65777616202831, 30.140045396983624, 28.3751654997468, 44.90444004535675, 46.03319987654686, 2.563073616474867, 0.26298335404135287, 0.03153242985717952, 0.04041441985464189, 0.015850233467062935, 0.033354346742271446, 0.042215552894049324, 0.08471038338029757, 0.07540271602920257, 0.036811393074458465, 0.03901258824043907, 0.18499911442631856, 0.12039864726830274, 0.13343390717636794, 0.09451765712583438, 0.09867942091659643, 0.20807288645301014, 0.16949235432548448, 0.1371005323017016, 0.23967531567905098, 0.1467369933379814, 0.1013752500875853, 0.3923024976393208, 0.21144208847545087, 5.887086801230907, 60.11651337146759, 62.614263743162155, 57.71385669708252, 81.48264527320862, 76.0322405397892, 55.865084901452065, 62.25301332771778, 63.45817945897579, 56.27993144094944, 57.17199057340622, 3.330640741623938, 0.7824258715845644, 10.465019401162863, 13.82977969944477, 0.63519042218104, 16.91636737436056, 64.16398778557777, 57.7311647683382, 57.93837904930115, 49.97840657830238, 45.83179548382759, 40.141638815402985, 42.431042566895485, 36.885118559002876, 40.188262313604355, 40.79041600227356, 42.49517932534218, 41.67620927095413, 47.81943842768669, 49.911590963602066, 49.409151524305344, 52.112634256482124, 55.6271530687809, 52.91897378861904, 53.76928836107254, 51.68081782758236, 52.35590100288391, 54.39085900783539, 55.355821028351784, 50.63166752457619, 52.366160452365875, 52.97575794160366, 55.97992613911629, 54.94129367172718, 53.01273375749588, 43.76471020281315, 39.45046730339527, 42.71157391369343, 40.740152299404144, 40.04102781414986, 42.47859701514244, 40.59617042541504, 41.59478344023228, 39.567865803837776, 40.67039184272289, 43.23304273188114, 43.04351270198822, 43.39408949017525, 41.21722050011158, 42.21994489431381, 44.39028203487396, 43.87998081743717, 42.61708438396454, 42.507061287760735, 42.2110153734684, 42.36317440867424, 40.548144802451134, 39.625254124403, 40.511024594306946, 48.21233354508877, 52.18859978020191, 50.55539421737194, 54.179898127913475, 57.918422520160675, 56.83246359229088, 50.38107097148895, 52.34520457684994, 56.35925978422165, 53.431395292282104, 50.54443560540676, 49.49952967464924, 41.59863643348217, 38.076381236314774, 38.60136866569519, 42.091112807393074, 40.400378331542015, 42.343240678310394, 42.92594701051712, 40.67666910588741, 41.89310543239117, 40.397197902202606, 42.51589581370354, 43.19529935717583, 42.14449994266033, 42.53733426332474, 41.86764679849148, 39.85887698829174, 39.775144681334496, 40.410436391830444, 41.415680050849915, 39.056664034724236, 39.13736030459404, 41.753637716174126, 41.64829596877098, 40.51652289927006, 40.0155121833086, 44.82975885272026, 44.34776991605759, 47.25096233189106, 50.68139925599098, 54.00151289999485, 52.504435032606125, 49.934313744306564, 53.55606660246849, 56.76376707851887, 51.76322020590305, 51.11207194626331, 49.27719600498676, 46.97310224175453, 46.95329770445824, 48.38757634162903, 48.720126897096634, 46.28231830894947, 49.135699197649956, 52.65728943049908, 50.965532809495926, 50.431828647851944, 45.04266522824764, 43.454198464751244, 40.19375301897526, 43.07469002902508, 43.34587387740612, 51.96519076824188, 56.89986817538738, 62.30854354798794, 57.608214765787125, 39.37015861272812, 1.3449258380569518, 2.9995455080643296, 10.891715604811907, 16.07327811419964, 3.343018814921379, 3.0714279133826494, 58.12497563660145, 66.1832982301712, 63.781553506851196, 50.736515298485756, 34.5728400349617, 35.3652723133564, 52.835610061883926, 57.39948816597462, 4.608757495880127, 0.304370287922211, 0.1462472352432087, 0.16358196444343776, 0.08806423036730848, 0.15409526880830526, 0.12244456287589855, 0.159643535153009, 0.17926716653164476, 0.23492561507737264, 0.2547584578860551], [0.04566511095617898, 0.1576963474508375, 0.027553733489185106, 0.05873908870853484, 0.019659525351016782, 0.034769971171044745, 0.04216130189888645, 0.054572482404182665, 0.10029706536442973, 0.048580315269646235, 0.021886717950110324, 0.010932135846815072, 0.024898998890421353, 1.8740248843096197, 41.925107315182686, 51.51541270315647, 34.97976019978523, 54.070855379104614, 63.73545818030834, 46.526903584599495, 45.5684582144022, 52.70200163125992, 48.91467645764351, 55.625169575214386, 11.877704747021198, 0.3519488114397973, 0.6928465096279979, 12.2959616035223, 1.8420311948284507, 12.761676013469696, 63.615373224020004, 52.66830123960972, 54.153212159872055, 41.78350791335106, 39.85578015446663, 36.86406008899212, 37.18689076602459, 34.93835762143135, 37.710084691643715, 36.301971450448036, 40.46142965555191, 41.24976575374603, 44.208799973130226, 46.71527087688446, 49.00174878537655, 48.03364433348179, 52.13856406509876, 49.909067898988724, 49.30522710084915, 47.198863327503204, 49.44044664502144, 47.88823373615742, 48.710239827632904, 49.28816981613636, 51.643142849206924, 48.47835727035999, 50.36246336996555, 48.00736874341965, 48.67132231593132, 39.583376571536064, 37.123901546001434, 37.183972522616386, 38.8039243966341, 37.695850655436516, 38.2000569999218, 38.734372928738594, 38.15922439098358, 38.91242757439613, 37.13115155696869, 35.96386559307575, 38.15900780260563, 39.24774818122387, 38.050785809755325, 38.19703236222267, 38.3791071921587, 37.71265335381031, 39.91384103894234, 37.89361484348774, 38.04867312312126, 37.88090452551842, 38.80310744047165, 34.384541139006615, 36.605309173464775, 43.62256363034248, 45.620215237140656, 46.070696264505386, 48.526329696178436, 52.073747143149376, 51.89431697130203, 50.57237550616264, 51.97416588664055, 50.333163142204285, 47.6746091991663, 46.83168902993202, 44.41477932035923, 39.047248139977455, 35.08876875042915, 37.507213577628136, 37.82788597047329, 37.05802448093891, 38.33273068070412, 38.58078517019749, 37.19246506690979, 38.19786451756954, 37.3016370087862, 37.634107768535614, 38.7384083122015, 38.59104081988335, 38.194805681705475, 36.46442413330078, 37.23795622587204, 36.36813350021839, 37.38757699728012, 35.974269434809685, 34.238256588578224, 35.36491893231869, 35.7545006275177, 36.08143508434296, 36.41014404594898, 38.00539344549179, 38.450999334454536, 39.475500360131264, 40.97270742058754, 47.21403211355209, 48.14682886004448, 46.62314482033253, 47.02994339168072, 46.64462126791477, 52.7020738273859, 49.13701392710209, 48.0153027176857, 45.832878425717354, 47.41700582206249, 46.0370946675539, 47.1342021971941, 45.86050674319267, 46.468196734786034, 46.898276656866074, 48.79896506667137, 48.75504322350025, 47.49739810824394, 44.321270138025284, 43.842416033148766, 38.534176871180534, 37.9680110514164, 38.424928933382034, 48.9857592433691, 52.287972047924995, 57.46622018516064, 53.49744714796543, 26.881296560168266, 0.45349399850238115, 3.089912971481681, 4.511548262089491, 4.416172429919243, 0.3955976333236322, 4.788475977256894, 59.8705829679966, 52.0254897326231, 55.561120212078094, 32.80658841133118, 24.273323602974415, 20.007098726928234, 42.53783963620663, 24.749591946601868, 0.12418167083524168, 0.09115929788094945, 0.06484631841885857, 0.06084553388063796, 0.011625889001152245, 0.05843162063683849, 0.005343244338291697, 0.06116076110629365, 0.03241522194002755, 0.030754597864870448, 0.022846402098366525, 0.04283261157979723, 0.05518562997167464, 0.041841421407298185, 0.022398959408747032, 0.05332436070602853, 0.049202082882402465, 0.046303766139317304, 0.04478906499571167, 0.01298620209126966, 0.035320062161190435, 0.028377517410262953, 0.016350515215890482, 0.09954259061487392, 2.360688876360655, 48.83645385503769, 56.11432872712612, 39.736880734562874, 65.91898441314697, 68.80343243479729, 52.540707886219025, 50.396714732050896, 57.93736070394516, 52.41965018212795, 60.35627670586109, 11.237308010458946, 0.3181233530631289, 0.7060135749634355, 18.956595696508884, 2.690111487172544, 13.818680495023727, 66.25487118959427, 56.01145304739475, 55.59265851974487, 43.16473379731178, 41.55104398727417, 39.96941305696964, 39.47962313890457, 38.169647231698036, 39.55906167626381, 35.49397140741348, 41.703936383128166, 43.519893139600754, 46.70704431831837, 47.8470553457737, 51.14601172506809, 50.778446048498154, 53.04354630410671, 52.72749446332455, 51.86555631458759, 50.58805726468563, 51.92254565656185, 49.85030025243759, 50.48638232052326, 49.20168645679951, 53.024596720933914, 50.736059322953224, 51.21581397950649, 51.07633866369724, 50.30773490667343, 40.47574728727341, 39.211095348000526, 37.891236171126366, 41.23015120625496, 39.67222340404987, 40.02592742443085, 40.64394146203995, 38.12016248703003, 40.96653275191784, 38.84067602455616, 39.12307307124138, 39.89163503050804, 41.18333771824837, 39.8406607657671, 39.5550262928009, 39.77531187236309, 39.987602680921555, 41.34471885859966, 39.636911898851395, 39.40506733953953, 40.277641117572784, 39.94350224733353, 36.13620154559612, 38.082521706819534, 45.51403373479843, 48.622928112745285, 47.77134820818901, 50.311253517866135, 53.623034209012985, 54.57141391932964, 52.47254714369774, 53.94133172929287, 53.09983268380165, 48.99571470916271, 47.54888154566288, 44.80546675622463, 40.04531018435955, 37.86740764975548, 37.49602697789669, 38.32451172173023, 39.16660733520985, 39.764870032668114, 40.773218125104904, 39.63201776146889, 39.34858717024326, 38.78338269889355, 40.43216362595558, 38.1777635961771, 40.05787990987301, 40.3834730386734, 38.56778986752033, 38.44443328678608, 38.4593702852726, 38.77458617091179, 37.457424849271774, 37.81874746084213, 39.082286059856415, 38.72695192694664, 38.50751370191574, 38.623840659856796, 39.1028543561697, 38.26729439198971, 41.74215093255043, 44.59364332258701, 48.69158662855625, 49.79034326970577, 50.93690514564514, 49.740763530135155, 49.12208452820778, 53.86870622634888, 51.59820266067982, 49.8576794564724, 48.4315437823534, 48.28028529882431, 47.276983335614204, 49.44052264094353, 46.4390978962183, 47.96716310083866, 50.3800830245018, 50.78985683619976, 50.30463807284832, 51.39070339500904, 46.54908299446106, 45.121336206793785, 40.53821973502636, 38.65385144948959, 39.21168811619282, 51.0901965200901, 52.08741120994091, 59.91631731390953, 54.84976038336754, 30.78373085707426, 0.6407571234740317, 6.18913734331727, 9.215274062007666, 6.620677812024951, 0.4940667370101437, 4.787579225376248, 62.9038006067276, 57.66094073653221, 58.73102031648159, 41.08890138566494, 28.302015624940395, 23.9461250603199, 48.513003811240196, 31.783928386867046, 0.3654869506135583, 0.03699017644976266, 0.059973313691443764, 0.11464293580502272, 0.009912616969813826, 0.01142089760833187, 0.037796390024595894, 0.04228707737638615, 0.01856087961641606, 0.052725035639014095, 0.013206185794842895, 0.1444046903634444, 0.26468156604096293, 0.09038795411470346, 0.1347083825385198, 0.10970802482916042, 0.15299429272999987, 0.16003489930881187, 0.10741718564531766, 0.17027843714458868, 0.10182295067352243, 0.14023356809047982, 0.17157223803224042, 0.17726329358993098, 2.848523324355483, 57.08957299590111, 65.57647839188576, 44.49471563100815, 63.020857125520706, 67.08923801779747, 59.53639090061188, 54.62469846010208, 65.31597957015038, 56.48371450603008, 69.03559997677803, 13.94275713711977, 0.2991312596714124, 2.1241014590486884, 19.18927051126957, 3.349487967789173, 16.135494075715542, 68.99615809321404, 57.68945440649986, 58.64016719162464, 46.519535779953, 44.125903621315956, 41.735630482435226, 41.73504911363125, 39.15134355425835, 42.195421010255814, 39.918693378567696, 45.52528873085976, 45.758524015545845, 50.25825396180153, 51.45459696650505, 55.57386472821236, 52.34007105231285, 55.75751647353172, 54.907999858260155, 53.704156056046486, 52.268076315522194, 52.84316785633564, 51.98472172021866, 52.06049345433712, 54.151935428380966, 57.33757808804512, 52.75758504867554, 53.75531651079655, 53.198194205760956, 52.31143578886986, 42.34765224158764, 41.348845437169075, 41.55589632689953, 43.53953428566456, 41.34651616215706, 40.81479549407959, 42.67161525785923, 40.34752316772938, 43.48830163478851, 39.85314689576626, 39.021170139312744, 42.28766106069088, 43.28955329954624, 41.57229624688625, 42.977023869752884, 42.48548984527588, 41.260237991809845, 44.87623415887356, 41.34688474237919, 41.263486817479134, 40.803548097610474, 42.95794129371643, 36.761446595191956, 39.55713137984276, 48.36917392909527, 50.10658510029316, 49.760066494345665, 54.77616213262081, 55.73843389749527, 54.45428140461445, 54.80300769209862, 56.96580983698368, 53.75254645943642, 51.21938958764076, 49.391315281391144, 46.687961742281914, 41.557556837797165, 39.384286254644394, 40.776854529976845, 40.825510919094086, 40.30924782156944, 42.1001373231411, 41.919574812054634, 41.148444190621376, 41.8144990503788, 40.42100362479687, 42.85606876015663, 41.9923485070467, 42.28849321603775, 42.44991235435009, 40.36676913499832, 40.51722206175327, 39.67771790921688, 40.426437333226204, 39.20102968811989, 38.43622952699661, 39.362000450491905, 40.264341831207275, 40.69678522646427, 41.877978444099426, 41.73904649913311, 41.59732550382614, 43.47074277698994, 45.321859046816826, 50.54649889469147, 53.35905857384205, 52.478288635611534, 52.182257920503616, 51.14804461598396, 57.28873170912266, 54.926326274871826, 51.7729514837265, 50.921850353479385, 51.49987533688545, 49.9662434309721, 52.11593247950077, 49.575510397553444, 51.23343363404274, 51.32912389934063, 54.33090202510357, 53.14934782683849, 53.84638622403145, 48.60150866210461, 49.22817103564739, 43.14284697175026, 41.72292776405811, 41.15071266889572, 54.12269599735737, 54.940423518419266, 63.4502948820591, 54.75168764591217, 33.89512360095978, 0.8015462674666196, 7.9862005636096, 15.354199949651957, 15.284805223345757, 1.8230810179375112, 5.679064588621259, 69.9624690413475, 62.53552056849003, 63.843345791101456, 46.80296257138252, 35.20046375691891, 31.68935526162386, 56.95273093879223, 40.63629247248173, 0.9762031235732138, 0.2071810921188444, 0.16469665541080758, 0.2531123743392527, 0.12810783984605223, 0.14769466069992632, 0.27103942644316703, 0.28390862338710576, 0.08369255010620691, 0.22385201475117356, 0.15325028914958239], [0.07368682607193477, 0.05614946458081249, 0.05750970623921603, 0.049576882302062586, 0.030606376130890567, 0.025001098001666833, 0.07206245034467429, 0.09646333826822229, 0.0026260271670253132, 0.06839512760052457, 0.07637285889359191, 0.04785008648468647, 0.11981910414760932, 0.2345680186408572, 23.56776036322117, 58.67553949356079, 38.191857039928436, 26.346154175698757, 28.360684476792812, 36.77227981388569, 53.58708433806896, 56.16194397211075, 50.25005780160427, 53.13449442386627, 21.19146667420864, 0.12310794641962275, 0.45288620924111456, 18.289028517901897, 0.970024773851037, 13.952598609030247, 62.38964259624481, 52.46906653046608, 53.22698526084423, 42.00287014245987, 40.856312066316605, 38.35279740393162, 40.4121159017086, 37.36796624958515, 36.31114035844803, 37.08488903939724, 43.58523063361645, 44.36301089823246, 49.04577702283859, 48.81051264703274, 49.143348187208176, 50.0529395788908, 51.26263126730919, 47.850448563694954, 45.37558056414127, 48.52181553840637, 47.798311561346054, 48.486925810575485, 49.381078630685806, 49.22379367053509, 50.45389026403427, 49.26787130534649, 48.5835812240839, 47.61987693607807, 45.428112745285034, 39.85495939850807, 36.21820114552975, 37.91173227131367, 39.21972468495369, 37.6106022298336, 36.932388022542, 36.75832696259022, 37.40703575313091, 39.119630455970764, 37.04382464289665, 37.06501230597496, 39.059681072831154, 37.52308152616024, 38.55613209307194, 38.822965174913406, 38.56768347322941, 38.60065810382366, 38.72407928109169, 39.078771248459816, 38.161386474967, 38.80141273140907, 37.52908520400524, 35.57486906647682, 36.251384764909744, 41.997550427913666, 43.547901436686516, 43.99189241230488, 46.94440998136997, 50.99896341562271, 52.16319054365158, 52.777545377612114, 51.86760440468788, 52.7205066382885, 47.9298111051321, 44.7611079365015, 42.35309734940529, 39.32399868965149, 36.33585423231125, 35.649595856666565, 38.70270922780037, 38.464735597372055, 38.21547657251358, 39.04130905866623, 38.270018845796585, 38.10193866491318, 36.723870411515236, 37.63582527637482, 37.78964102268219, 37.47949406504631, 38.42748619616032, 37.31855370104313, 36.959077790379524, 38.62122640013695, 36.71273700892925, 35.926813781261444, 35.23809313774109, 35.331875905394554, 36.46386556327343, 36.69510595500469, 37.055436819791794, 36.82932235300541, 36.18872232735157, 38.06046009063721, 37.08860523998737, 41.719010174274445, 47.62202762067318, 51.08306810259819, 44.46127362549305, 47.07348145544529, 50.28494372963905, 48.8805390894413, 49.83152166008949, 48.462914898991585, 48.38337756693363, 47.96829164028168, 48.61897252500057, 48.15274514257908, 48.44404511153698, 49.726065918803215, 49.452165216207504, 49.88783083856106, 49.62853655219078, 48.43529798090458, 45.065821185708046, 42.3345847427845, 37.175403982400894, 38.590223863720894, 48.2697294652462, 53.48314471542835, 52.430730387568474, 54.43816266953945, 22.01274700462818, 0.46149099594913423, 6.001844918355346, 5.628387657925487, 2.08759943023324, 0.4607760702492669, 8.577238898724318, 59.23084929585457, 50.54366044700146, 52.212622091174126, 33.35573874413967, 23.63037910312414, 26.073600500822067, 52.09611274302006, 13.936088494956493, 0.034514201106503606, 0.0578738929471001, 0.006511597221106058, 0.012906833107990678, 0.0475298312085215, 0.04466299636987969, 0.022929587576072663, 0.02663956711330684, 0.07433558188495226, 0.022748616720491555, 0.03911416599294171, 0.07661805706447922, 0.09736245017847978, 0.01677939493674785, 0.034788424673024565, 0.044417623794288374, 0.02438849591271719, 0.0064359232055721804, 0.04770183135406114, 0.010895712166529847, 0.062142644746927544, 0.11798972496762872, 0.10340377717511728, 0.13444100157357752, 0.3796817717375234, 29.925180226564407, 65.96110135316849, 37.84671775996685, 36.22026823461056, 50.258550345897675, 45.83384357392788, 57.46120065450668, 61.27841502428055, 53.457116112113, 58.934187814593315, 22.194451354444027, 0.12735764728859067, 0.8254698431119323, 24.513463117182255, 2.7340238308534026, 14.85128553584218, 67.12077632546425, 54.033552780747414, 56.34319804608822, 44.870150685310364, 42.83532187342644, 39.99968983232975, 42.08022639155388, 38.41451749205589, 38.230504766106606, 39.087833762168884, 45.70974603295326, 45.24170994758606, 51.48002900183201, 50.029859617352486, 51.965167969465256, 51.2066450715065, 52.7595267444849, 49.96642202138901, 47.781033888459206, 49.451086074113846, 49.78989489376545, 48.90528716146946, 51.760305762290955, 50.43814770877361, 53.56931269168854, 50.35446099936962, 51.70707821846008, 49.89608019590378, 48.29480431973934, 41.14761583507061, 38.23740519583225, 40.41469216346741, 40.76684586703777, 39.475595355033875, 37.88075253367424, 38.24014864861965, 38.85968640446663, 40.579523518681526, 37.87673994898796, 41.38430133461952, 41.308267414569855, 39.69915635883808, 40.7306794077158, 41.31492465734482, 40.85566230118275, 39.57996815443039, 40.49998998641968, 39.31262210011482, 39.09827180206776, 40.96613757312298, 37.828980311751366, 37.876907140016556, 37.35275946557522, 43.01283314824104, 47.32004642486572, 47.64481499791145, 48.579804226756096, 51.78026229143143, 54.06174726784229, 54.572531059384346, 53.96923743188381, 53.24390955269337, 47.54307545721531, 46.9273678958416, 44.89084057509899, 40.418970733881, 38.094707652926445, 38.714632987976074, 40.980884581804276, 39.773069992661476, 41.09362073242664, 39.790450260043144, 41.05521619319916, 39.926479160785675, 38.594487234950066, 39.55796353518963, 40.68372152745724, 38.737469762563705, 39.78780560195446, 39.1891211271286, 37.47140809893608, 39.37859036028385, 38.794158920645714, 37.25578486919403, 38.3967724442482, 37.57431797683239, 37.922037318348885, 37.87620037794113, 37.918864488601685, 38.13470050692558, 39.07686375081539, 39.4662706553936, 39.649534821510315, 44.83525715768337, 50.3414086997509, 51.69432610273361, 49.24516372382641, 49.437604397535324, 51.76790535449982, 50.51283270120621, 52.49596908688545, 51.32302522659302, 49.8334975540638, 49.790784046053886, 50.24688497185707, 49.51067067682743, 49.57709111273289, 51.876457929611206, 51.43727749586105, 51.966668888926506, 50.57617910206318, 49.82734188437462, 48.294317945837975, 43.0128825455904, 38.415247052907944, 40.241995230317116, 51.49101801216602, 54.814483076334, 55.608112290501595, 54.91361975669861, 24.54045496881008, 0.25221805670298636, 9.382483139634132, 6.687152395024896, 5.1479841861873865, 0.2144359567319043, 8.992427419871092, 65.71753442287445, 55.36330282688141, 59.31708566844463, 42.75240272283554, 23.73501218855381, 27.647994719445705, 59.203422367572784, 19.539307728409767, 0.00562223202905443, 0.10600648165564053, 0.034600909930304624, 0.0404167205124395, 0.08294135564938188, 0.04107328371901531, 0.05074748296465259, 0.030342524078150745, 0.10657540464308113, 0.15797851199749857, 0.06993248651269823, 0.17979603580897674, 0.18944313924293965, 0.08916499864426441, 0.15794288890901953, 0.1662803688668646, 0.09299623954575509, 0.15156778099481016, 0.17240893532289192, 0.0856661656871438, 0.2613803744316101, 0.24704052280867472, 0.23781837313435972, 0.18890885228756815, 0.4111251438735053, 32.99121670424938, 75.476915538311, 47.487264052033424, 37.77980715036392, 39.33413654565811, 49.118307530879974, 63.673008531332016, 65.84914416074753, 56.7281249910593, 64.61870938539505, 25.231111608445644, 0.3067043126793578, 3.1698602065443993, 35.81713266670704, 3.6769415717571974, 16.295421794056892, 66.32403507828712, 55.65160475671291, 57.89549835026264, 46.326167955994606, 46.30734756588936, 42.65193611383438, 44.77099500596523, 41.64830356836319, 40.938839837908745, 40.62336936593056, 49.3550044298172, 48.34970757365227, 53.94194729626179, 52.20793314278126, 53.62993843853474, 54.085211008787155, 54.11882780492306, 51.74772083759308, 48.007220551371574, 52.49278485774994, 50.67934736609459, 50.3474085777998, 55.109001472592354, 53.308513686060905, 55.04999823868275, 51.97854705154896, 53.6608611792326, 52.941700369119644, 50.35008743405342, 43.347815573215485, 39.54971417784691, 42.707181349396706, 41.99101097881794, 42.06396326422691, 39.393694549798965, 39.44104760885239, 41.71147137880325, 42.83201985061169, 38.833152428269386, 42.37506777048111, 43.686578795313835, 39.799163192510605, 43.02788034081459, 42.727434262633324, 44.31243561208248, 42.06987574696541, 43.14155884087086, 41.67262226343155, 40.325932726264, 43.55587720870972, 40.564559921622276, 40.50868771970272, 39.51053828001022, 45.23613564670086, 48.42449516057968, 49.06932435929775, 50.68033531308174, 53.650552332401276, 55.0715696811676, 56.109563782811165, 55.17873153090477, 56.99750393629074, 50.596036836504936, 48.89426775276661, 44.77772444486618, 43.02463911473751, 40.87039791047573, 40.7251089066267, 42.59651988744736, 43.11890825629234, 41.67203709483147, 41.24771386384964, 42.703544944524765, 41.430180072784424, 41.56261816620827, 41.4837571978569, 42.906134873628616, 40.26167057454586, 42.56031163036823, 42.03801445662975, 41.048646345734596, 40.7693575322628, 40.97683019936085, 39.954270869493484, 39.297970086336136, 39.162172973155975, 40.5794171243906, 40.67060083150864, 41.9901180267334, 39.918605983257294, 41.18141122162342, 41.52438461780548, 41.743423864245415, 47.03266404569149, 52.54568561911583, 54.73186790943146, 51.1705432087183, 52.18471638858318, 53.060759380459785, 50.054676085710526, 54.800492227077484, 53.589565604925156, 53.446146100759506, 51.31549783051014, 53.4949354827404, 51.10466234385967, 51.72214061021805, 53.480652049183846, 54.171614572405815, 54.39020924270153, 52.827273309230804, 52.167963087558746, 50.482962504029274, 46.63428582251072, 40.63974268734455, 43.634973764419556, 54.31237801909447, 57.238445207476616, 56.273293197155, 55.68390302360058, 27.726116627454758, 0.6759579596109688, 14.794500432908535, 17.503082491457462, 11.653145346790552, 0.7379776379093528, 10.688633602112532, 69.50153857469559, 60.66413998603821, 64.00349199771881, 46.75652526319027, 33.38892616331577, 36.39422670006752, 66.60165578126907, 26.23649775981903, 0.27539250848349184, 0.17336945253191516, 0.09703817617264576, 0.12037978929583915, 0.19633870047982782, 0.1354860790888779, 0.14485501073068008, 0.16358376044081524, 0.26769643707666546, 0.2539115189574659, 0.1678682235069573], [0.023852414815337397, 0.05159684871614445, 0.08576179141527973, 0.06663869411568157, 0.049895033589564264, 0.05749108946474735, 0.05397584391175769, 0.04968450484739151, 0.07094436776242219, 0.03614016131905373, 0.046600391433457844, 0.025707824825076386, 0.106006244168384, 0.0792961785919033, 7.333344295620918, 44.547612592577934, 51.443752348423004, 28.191960230469704, 15.276861749589443, 35.30238188803196, 47.61914737522602, 56.8071835488081, 50.8454592525959, 50.248321294784546, 32.42386914789677, 0.6436452060006559, 0.24209819035604596, 15.80750897526741, 1.6405595932155848, 9.684965908527374, 56.87976345419884, 53.99257957935333, 51.9237045943737, 43.82742203772068, 41.189109608531, 40.5994838476181, 41.43556818366051, 37.50957705080509, 36.660721600055695, 42.32855446636677, 50.15186347067356, 48.165029883384705, 48.57177145779133, 47.825358510017395, 50.032561272382736, 50.3540126234293, 48.26186768710613, 48.92726518213749, 49.65824715793133, 49.566960856318474, 49.66746926307678, 49.96278561651707, 49.00090903043747, 49.55458492040634, 51.03284239768982, 48.77040579915047, 47.986572459340096, 44.96928736567497, 43.57899136841297, 40.53469352424145, 36.834087297320366, 37.37815350294113, 36.96132726967335, 36.53722442686558, 36.220344230532646, 36.41117379069328, 37.26537935435772, 38.19420151412487, 40.69560348987579, 40.27598060667515, 40.512506514787674, 39.65337261557579, 38.69466505944729, 37.53736115992069, 38.34071025252342, 38.46487618982792, 38.153456300497055, 39.44272331893444, 38.929887637495995, 38.567276895046234, 37.28412754833698, 34.4056262075901, 36.383081898093224, 38.89127030968666, 43.76057602465153, 41.33078880608082, 44.43348191678524, 50.589691177010536, 52.154291421175, 53.0986737459898, 51.7549442499876, 50.5968613922596, 44.53141786158085, 43.57059381902218, 41.20842017233372, 36.99690096080303, 36.26055367290974, 37.56345435976982, 38.19932743906975, 39.20586682856083, 37.84241259098053, 37.354993745684624, 37.762221693992615, 37.439581006765366, 38.47944840788841, 36.37737840414047, 37.82587207853794, 36.53748281300068, 38.958416506648064, 37.808818593621254, 35.765231251716614, 38.51461552083492, 36.73648953437805, 35.233373790979385, 35.68410560488701, 36.593279018998146, 36.72953970730305, 37.692275047302246, 34.853622168302536, 34.1999052464962, 33.80143202841282, 37.19278804957867, 36.04849465191364, 37.627454325556755, 42.12610512971878, 46.75374001264572, 49.3733536452055, 44.089106395840645, 47.547418624162674, 45.721118822693825, 48.36912453174591, 50.481678172945976, 48.229223638772964, 51.204247400164604, 49.53147456049919, 49.222015365958214, 50.930605083703995, 52.843642830848694, 53.22393402457237, 50.56319899857044, 51.82473510503769, 51.158722043037415, 49.69028703868389, 46.67504243552685, 40.07130838930607, 37.500404343008995, 47.66848772764206, 52.6459926366806, 55.93409299850464, 54.25055533647537, 16.08788453042507, 0.07584444974781945, 7.0919902715831995, 6.564091723412275, 3.5685044154524803, 0.14162059756927192, 15.04288075491786, 58.69491085410118, 49.96773675084114, 50.450265258550644, 27.84831427037716, 27.24158752709627, 35.10340176522732, 47.001076340675354, 6.771742505952716, 0.12188403357868083, 0.06848368808277883, 0.07971979648573324, 0.09180279186693951, 0.03019097937794868, 0.00893626418474014, 0.051181156959501095, 0.10180982208112255, 0.09143384057097137, 0.03650540187663864, 0.016073814731498715, 0.04896382008155342, 0.04959831552696414, 0.00871294174430659, 0.020910190760332625, 0.05565232953813393, 0.012635452894755872, 0.04022557295684237, 0.03874234258546494, 0.07462844077963382, 0.008767573090153746, 0.09284803265472874, 0.10866729629924521, 0.06566804659087211, 0.04091829730896279, 10.518874861299992, 55.90161234140396, 53.57260711491108, 27.034815922379494, 19.45229049772024, 46.723113656044006, 52.84970350563526, 61.07296384871006, 54.902794137597084, 55.6211493909359, 33.43282900750637, 0.6571597151923925, 0.5297447741031647, 20.62104318290949, 4.312990391626954, 10.129674095660448, 62.61418394744396, 54.67191472649574, 54.656008780002594, 45.20697221159935, 45.503128319978714, 42.927314937114716, 43.50695863366127, 39.61315557360649, 38.49510736763477, 44.302620738744736, 49.421261474490166, 51.37092165648937, 50.49128785729408, 49.8195219039917, 53.22403661906719, 52.19484284520149, 49.86324995756149, 49.747667759656906, 51.96752384305, 49.30883310735226, 51.207541823387146, 51.884441301226616, 51.1852940171957, 50.135444551706314, 52.553535997867584, 51.516822427511215, 50.0637461990118, 47.82717481255531, 45.54195463657379, 42.265508249402046, 39.9554830044508, 39.27048996090889, 38.849187567830086, 38.165805637836456, 38.90401102602482, 38.611928299069405, 38.915114030241966, 39.310874193906784, 41.035962626338005, 44.32880513370037, 41.95201747119427, 40.9701881557703, 40.61615735292435, 39.38884221017361, 40.52143603563309, 40.05036011338234, 41.02459363639355, 40.111745819449425, 39.90181848406792, 39.57630135118961, 39.61799271404743, 36.30695678293705, 38.177132830023766, 41.291297525167465, 44.46502402424812, 42.65991188585758, 46.55055731534958, 52.45051592588425, 52.76007391512394, 54.997747242450714, 53.96104887127876, 51.81316092610359, 47.31703698635101, 44.06770974397659, 43.956181928515434, 39.945086762309074, 37.34552465379238, 40.35410061478615, 39.545997977256775, 39.1961507499218, 38.72858203947544, 38.12337711453438, 38.61865773797035, 38.007008358836174, 38.93368363380432, 38.16639080643654, 40.14735750854015, 38.59950676560402, 40.081647634506226, 40.37230163812637, 38.192301616072655, 41.16346098482609, 38.741121366620064, 37.28689759969711, 38.337583020329475, 38.017822578549385, 37.903102934360504, 38.99023599922657, 36.580355912446976, 36.533561423420906, 36.60141438245773, 39.5227812230587, 37.78371334075928, 39.60419945418835, 45.238533318042755, 48.65156717598438, 50.1581597328186, 47.417427599430084, 50.057180151343346, 48.059247359633446, 48.757953867316246, 52.08248667418957, 50.37347137928009, 52.42485210299492, 51.10583268105984, 52.10487127304077, 54.423449859023094, 54.77336548268795, 55.1367399841547, 53.87859709560871, 52.94983573257923, 52.97923095524311, 50.57827278971672, 49.05438736081123, 42.45721936225891, 39.75703865289688, 48.97493362426758, 56.37823596596718, 57.31683500111103, 54.69766214489937, 18.27312257140875, 0.1336482839542441, 8.483591973781586, 8.984108716249466, 7.947545712813735, 0.21631627692840993, 15.940872319042683, 64.45555374026299, 54.17713947594166, 56.77062951028347, 35.66514082252979, 29.285440854728222, 36.923010125756264, 53.477452620863914, 9.741114545613527, 0.1956874510506168, 0.027038907501264475, 0.0853167031891644, 0.0493507127976045, 0.04686368687544018, 0.008648083603475243, 0.02705159451579675, 0.10779496107716113, 0.008336332412000047, 0.05648688202199992, 0.0381650184863247, 0.16926444077398628, 0.1279073560726829, 0.21442760014906526, 0.09641118012950756, 0.1309622882399708, 0.12792044755769894, 0.14245500904507935, 0.2825604676036164, 0.21480563533259556, 0.12452549301087856, 0.2405250005540438, 0.2495712018571794, 0.2627037721686065, 0.19237300468375906, 11.66260588914156, 63.645653799176216, 62.65136495232582, 39.71651002764702, 22.97590982168913, 49.047289341688156, 56.45092986524105, 69.30975526571274, 58.66339914500713, 60.46077869832516, 39.619315043091774, 1.4714367245323956, 0.9070717706345022, 30.082104206085205, 3.875481868162751, 13.457351233810186, 63.66444379091263, 58.27709287405014, 58.730853125452995, 46.77180424332619, 48.36898013949394, 45.57307876646519, 46.71203725039959, 41.5161694586277, 40.86877539753914, 46.63984872400761, 53.534468561410904, 53.784795328974724, 52.24306985735893, 51.85600362718105, 54.72046472132206, 54.067743346095085, 50.440739169716835, 51.691491454839706, 53.436874598264694, 52.63560779392719, 52.363192811608315, 52.93937109410763, 53.819130286574364, 51.82885028421879, 56.13289453089237, 52.84729443490505, 52.14077554643154, 49.4119443744421, 46.879456266760826, 44.77715067565441, 42.193646505475044, 39.98765587806702, 40.92111758887768, 40.34496210515499, 39.910778403282166, 39.33718778192997, 41.997850611805916, 40.6920962780714, 44.27298232913017, 44.60994824767113, 44.15949761867523, 43.10039944946766, 42.18602791428566, 41.49932876229286, 42.35687054693699, 41.9988689571619, 41.80262468755245, 42.19719551503658, 41.4762070029974, 41.49128079414368, 42.29100488126278, 38.5229978710413, 40.93105025589466, 42.90719501674175, 47.53807492554188, 44.79918569326401, 50.307617112994194, 54.90511581301689, 53.70192937552929, 55.81345707178116, 55.34347549080849, 55.03439627587795, 48.77341143786907, 46.04366451501846, 46.95273153483868, 42.06921078264713, 39.62915651500225, 42.48314917087555, 41.895864084362984, 42.15037822723389, 39.157465025782585, 40.90516224503517, 41.89618706703186, 40.95241270959377, 41.03864908218384, 39.93152529001236, 43.157704174518585, 39.21551451086998, 41.828516498208046, 44.356695637106895, 40.95692306756973, 42.51281417906284, 41.59601457417011, 39.63725008070469, 39.67837147414684, 40.28744459152222, 40.13773262500763, 42.40652248263359, 38.8542564958334, 38.007376939058304, 39.19942617416382, 42.34998531639576, 39.99893747270107, 42.045424059033394, 47.08865784108639, 50.251596719026566, 52.693235501646996, 50.20141661167145, 50.877457335591316, 47.33929619193077, 49.81166012585163, 52.63738229870796, 53.39247018098831, 54.89034220576286, 53.02133269608021, 53.627715557813644, 55.42031116783619, 57.86810182034969, 58.430103063583374, 55.22680275142193, 55.41829727590084, 55.63003711402416, 53.208259865641594, 51.841435208916664, 45.37288650870323, 42.39749796688557, 51.01265028119087, 57.5877870619297, 59.20896627008915, 55.74644386768341, 22.82674502581358, 0.2560224838089198, 14.449830427765846, 16.958524212241173, 14.287387244403362, 0.18884011456975713, 17.10026040673256, 70.56682661175728, 58.23903791606426, 60.64377687871456, 39.50213313102722, 37.18334935605526, 45.85790008306503, 63.44480037689209, 14.109015315771103, 0.30697285139467567, 0.15481861046282575, 0.2831230452284217, 0.1863730969489552, 0.16679261403623968, 0.10478625728865154, 0.09292152753914706, 0.2590127452276647, 0.1620057169930078, 0.12476002651965246, 0.10508215898880735], [0.05624685662041884, 0.047889327543089166, 0.011141113500343636, 0.02052810901659541, 0.07221059044240974, 0.07925608777441084, 0.04808834557479713, 0.04709121451014653, 0.10166468768147752, 0.04585045862768311, 0.05363306816434488, 0.02794832042127382, 0.04460894575458951, 0.09108841535635293, 0.5859866249375045, 32.0509647578001, 55.78517518937588, 35.663495510816574, 32.21617989242077, 31.447530537843704, 47.66860172152519, 58.424718752503395, 53.6244211345911, 48.153968676924706, 42.01948285102844, 2.8391105169430375, 0.4759969550650567, 9.699618872255087, 1.623777556233108, 2.2158565605059266, 51.6799970716238, 58.216812908649445, 51.76896929740906, 46.54704250395298, 45.71935571730137, 43.130881413817406, 41.104564145207405, 37.18027912080288, 40.24780511856079, 44.69203144311905, 48.95470730960369, 48.77200171351433, 51.37665554881096, 51.28808610141277, 50.777898877859116, 47.85010278224945, 50.54805301129818, 49.90564428269863, 49.72394563257694, 49.517749696969986, 46.792520731687546, 47.57784739136696, 47.345672249794006, 48.25692415237427, 45.61952367424965, 46.83558762073517, 45.59534937143326, 43.77056568861008, 42.39475071430206, 36.88077159225941, 37.4295761436224, 35.52395939826965, 38.5731665790081, 38.23193348944187, 37.046545296907425, 37.575815096497536, 37.77865581214428, 40.82995668053627, 40.586477145552635, 42.25945517420769, 40.64663551747799, 41.14128157496452, 39.18259307742119, 36.95398606359959, 38.82640779018402, 38.63337814807892, 39.56142134964466, 38.72122563421726, 39.29546222090721, 37.557325288653374, 37.51272328197956, 36.008091419935226, 35.83230525255203, 38.003835529088974, 39.74400915205479, 40.51691807806492, 45.37364646792412, 50.92845059931278, 52.87598669528961, 54.19019557535648, 52.61020615696907, 49.99688498675823, 43.1987039744854, 42.67048291862011, 41.54029816389084, 38.03665816783905, 37.64908656477928, 37.85381957888603, 38.150876238942146, 37.63058915734291, 38.9417240023613, 38.69333513081074, 38.16406913101673, 37.32283227145672, 37.94830530881882, 37.15847589075565, 37.024362087249756, 38.06360252201557, 37.24850445985794, 37.8552483022213, 37.171623185276985, 37.017279267311096, 38.485136702656746, 36.205886006355286, 38.1816203892231, 38.92815113067627, 36.77583262324333, 34.69385214149952, 35.40329687297344, 33.837100714445114, 36.098883748054504, 35.325032472610474, 36.20059669017792, 33.698560148477554, 37.954863756895065, 41.186149567365646, 48.06084327399731, 47.774901017546654, 47.84612059593201, 48.0201056599617, 44.89875175058842, 45.37393905222416, 48.21286931633949, 48.00014153122902, 48.882404789328575, 50.28715901076794, 50.09276524186134, 50.313730984926224, 53.45699451863766, 51.47224701941013, 51.138545125722885, 50.555303022265434, 50.40641941130161, 48.24238233268261, 43.835177421569824, 38.5125408321619, 46.29078805446625, 52.48548164963722, 52.770986929535866, 51.43443904817104, 10.760520044714212, 0.32047352695371956, 6.9180455803871155, 3.9709142223000526, 4.351791059598327, 0.06698283541481942, 16.24704848974943, 60.219275057315826, 45.42895630002022, 43.58603239059448, 28.656168021261692, 19.014686979353428, 35.18242992460728, 45.13577923178673, 2.94165157712996, 0.11686231358908117, 0.021692351328965742, 0.06168769337818958, 0.011452396211097948, 0.09001100988825783, 0.09418535308213905, 0.0594105356867658, 0.02357455658057006, 0.016570970183238387, 0.022676572734781075, 0.04352298332378268, 0.034616576667758636, 0.05855896946741268, 0.06777811344363727, 0.029418038138828706, 0.05121968555613421, 0.07272175949765369, 0.03001332592248218, 0.08737672702409327, 0.03536345924658235, 0.04027992043120321, 0.04138913434871938, 0.026820304192369804, 0.04735642469313461, 0.114124100364279, 0.8432605478446931, 37.181476056575775, 62.227041721343994, 37.31616362929344, 28.67980655282736, 38.28097365796566, 52.574735060334206, 65.77238067984581, 57.129505053162575, 53.26842203736305, 43.96264158189297, 3.027435061521828, 0.7395595405250788, 11.107176393270493, 4.863407956436276, 3.8938465202227235, 55.90092457830906, 58.66895064711571, 54.32677924633026, 49.36384655535221, 47.71335572004318, 44.83604371547699, 42.47117601335049, 39.69845339655876, 41.7410945892334, 47.551115825772285, 51.264899745583534, 49.993491768836975, 54.86303687095642, 54.62202340364456, 52.943938449025154, 48.80338042974472, 49.91620771586895, 52.256388142704964, 50.319495275616646, 51.557100266218185, 49.61719036102295, 49.34726804494858, 48.49869757890701, 51.354932114481926, 50.366460755467415, 49.16252575814724, 47.78277039527893, 45.97696669399738, 44.8647777736187, 38.29315200448036, 38.20484474301338, 38.05853359401226, 40.146183371543884, 39.29252877831459, 38.69078926742077, 39.36682619154453, 39.907141998410225, 42.53612972795963, 41.42383061349392, 46.430004984140396, 42.34051622450352, 42.366119250655174, 42.03476183116436, 39.45509545505047, 40.6908043473959, 39.37213830649853, 40.6727135181427, 40.08706994354725, 40.4597083479166, 39.21093575656414, 39.50244091451168, 37.403771728277206, 37.44390897452831, 40.88965527713299, 43.842313438653946, 42.32195042073727, 47.14499741792679, 52.67037212848663, 53.212454840540886, 54.32813197374344, 54.15185183286667, 51.61762721836567, 46.28437779843807, 44.95582468807697, 43.58097106218338, 39.652149081230164, 37.789610624313354, 39.99048672616482, 39.819195717573166, 39.44917917251587, 41.89006179571152, 40.03592848777771, 40.7895078510046, 40.22205010056496, 39.1667365282774, 39.040841683745384, 38.23345720767975, 39.22364227473736, 39.93453852832317, 39.98347230255604, 38.828915655612946, 38.93361523747444, 39.750594198703766, 39.200991690158844, 40.41248068213463, 39.63229514658451, 37.544618770480156, 36.74477308988571, 36.46761976182461, 35.201052725315094, 37.63448394834995, 37.89858877658844, 38.2305883616209, 36.33273459970951, 39.276797622442245, 43.03588651120663, 49.102169796824455, 48.77949871122837, 49.87531051039696, 49.53109458088875, 47.1546982973814, 46.291935592889786, 49.405678510665894, 49.972524493932724, 49.02519732713699, 52.07403972744942, 53.125124126672745, 51.90807983279228, 55.307852402329445, 54.0211084485054, 53.1905148178339, 53.3752229064703, 51.63558505475521, 51.27226375043392, 44.43293854594231, 40.662051290273666, 47.72536687552929, 55.394495353102684, 54.86478477716446, 53.50636526942253, 12.076296340674162, 0.27538752125110477, 8.290639277547598, 5.843565836548805, 4.207895630970597, 0.13850813411409035, 16.436132043600082, 65.81523478031158, 49.69632491469383, 53.498891070485115, 30.421148613095284, 17.34700206667185, 40.917591378092766, 52.512916177511215, 4.13777039386332, 0.03963333540013991, 0.030421163901337422, 0.029908692376920953, 0.019619890954345465, 0.03515018084726762, 0.08617252562544309, 0.06788623693864793, 0.04986918829672504, 0.005875505694348249, 0.09400353432283737, 0.07343093355302699, 0.15428595623234287, 0.09949068480636925, 0.18045271775918081, 0.10033541213488206, 0.11239830273552798, 0.24091539991786703, 0.17074830568162724, 0.28279032558202744, 0.12687393027590588, 0.15055399242555723, 0.1785628535435535, 0.13293775176862255, 0.13779641449218616, 0.3595058637438342, 0.9701142471749336, 45.48264741897583, 68.51007297635078, 47.81351074576378, 39.564537182450294, 45.09299732744694, 60.03048978745937, 65.60218021273613, 61.22590944170952, 56.58822409808636, 51.010499596595764, 4.243915798142552, 0.7448604935780168, 20.67984312772751, 6.455054674297571, 4.510017419233918, 57.4909720569849, 61.5966859459877, 57.59385533630848, 51.67294085025787, 50.76603211462498, 47.385433316230774, 44.441461488604546, 41.59742429852486, 44.839991703629494, 50.134167820215225, 53.356869891285896, 51.7938731610775, 57.996584326028824, 56.21775537729263, 53.966102600097656, 48.99886853992939, 53.85574892163277, 53.66651527583599, 53.324206843972206, 54.30907219648361, 51.573503986001015, 51.655670776963234, 50.09647384285927, 52.672397419810295, 50.46663857996464, 50.872981175780296, 51.227916330099106, 48.32702659070492, 47.25672282278538, 40.69801636040211, 40.492295399308205, 39.78065438568592, 42.29958102107048, 41.788880825042725, 41.07940189540386, 40.988411977887154, 40.46033911406994, 44.66988243162632, 44.14662390947342, 47.24899783730507, 44.184496477246284, 43.645537197589874, 43.81488271057606, 39.77675959467888, 42.307636588811874, 42.4780498445034, 43.1479386985302, 41.74685887992382, 42.46876314282417, 39.93462972342968, 42.926080003380775, 39.36289340257645, 39.49238285422325, 42.25986175239086, 45.43657869100571, 44.43133503198624, 48.90723265707493, 55.10880768299103, 56.61009572446346, 55.05147635936737, 56.09822899103165, 51.90208375453949, 47.63747379183769, 48.80723722279072, 46.88294067978859, 43.046210557222366, 41.65434144437313, 43.61431807279587, 42.931867092847824, 39.85639572143555, 44.56788070499897, 42.090033665299416, 42.98557721078396, 40.97662501037121, 40.35307466983795, 41.140844598412514, 41.11089840531349, 40.2554465085268, 40.52951820194721, 42.075780630111694, 39.955676794052124, 40.87963901460171, 40.79957351088524, 39.873065426945686, 43.363235145807266, 41.92098453640938, 40.14650255441666, 38.74230310320854, 37.4267490953207, 37.67319247126579, 39.848024770617485, 41.70761838555336, 42.199957966804504, 38.785901963710785, 41.55919834971428, 44.26778040826321, 52.65604689717293, 50.406833589076996, 52.96821914613247, 50.39967097342014, 48.46630431711674, 47.852002680301666, 50.085340440273285, 50.88326722383499, 49.75991070270538, 53.72096635401249, 54.53121967613697, 53.700185269117355, 58.22978541254997, 55.66010870039463, 53.984486013650894, 55.011665895581245, 54.186236187815666, 52.528274953365326, 47.12206184864044, 44.110073670744896, 50.95091499388218, 58.32163788378239, 57.02771611511707, 54.46943499147892, 15.896674040704966, 0.6126640434376895, 15.858455691486597, 12.879367098212242, 13.233436848968267, 0.20453615201404318, 18.611099235713482, 71.2499463558197, 53.487708270549774, 58.73621463775635, 37.50824712216854, 26.585911810398102, 48.122377172112465, 60.51868759095669, 5.982382362708449, 0.20749303163029253, 0.12405897898133844, 0.13887227629311383, 0.09163419817923568, 0.22039823757950217, 0.18846078804926947, 0.13472475431626663, 0.14482765516731888, 0.12502289522672072, 0.17716740811010823, 0.11596183612709865], [0.008780503158050124, 0.06386453867889941, 0.02730173167947214, 0.04274961720511783, 0.03922113544831518, 0.05895192924072035, 0.0639415365003515, 0.04491648061957676, 0.041657706460682675, 0.03032726552191889, 0.12167482214863412, 0.08280457041109912, 0.06168352992972359, 0.1512256360729225, 0.057840548251988366, 6.885069524869323, 46.93244442343712, 39.342990070581436, 24.65189538896084, 36.386478915810585, 38.053856045007706, 40.0500675290823, 53.85698385536671, 45.62587313354015, 51.93427562713623, 6.954864654690027, 0.31651167548261583, 5.550288548693061, 24.149446450173855, 2.815477210097015, 27.998772896826267, 61.574745923280716, 50.211660861968994, 50.55234678089619, 46.72553792595863, 47.41179630160332, 41.2872127443552, 42.79808767139912, 45.86231544613838, 50.31550168991089, 47.33977496623993, 51.72737292945385, 51.17890276014805, 46.47234231233597, 49.15539354085922, 47.48551994562149, 51.625496596097946, 49.533758237957954, 47.53553286194801, 48.21319229900837, 44.14512678980827, 44.002026468515396, 42.59002223610878, 42.54619158804417, 41.58559553325176, 41.22454270720482, 40.09442254900932, 39.57124762237072, 36.86239957809448, 36.26989737153053, 37.94696018099785, 37.63232186436653, 36.30576364696026, 38.13503488898277, 37.33789846301079, 37.004834935069084, 38.33386301994324, 37.5225305557251, 38.10664661228657, 38.84509138762951, 39.602671936154366, 38.76187585294247, 38.62572155892849, 37.91202485561371, 37.258463725447655, 41.071908697485924, 36.5882670879364, 39.12483237683773, 41.39669246971607, 41.132424250245094, 36.605643555521965, 34.8798293620348, 37.171596586704254, 37.64984272420406, 37.13470816612244, 40.329230949282646, 45.85947319865227, 51.39183193445206, 52.740930542349815, 49.62048098444939, 52.93735720217228, 51.04288525879383, 45.24475738406181, 44.293014854192734, 41.91197521984577, 40.20350329577923, 40.581271424889565, 40.12511350214481, 36.75791658461094, 36.391528844833374, 37.447993755340576, 38.5893689095974, 37.88761496543884, 38.91021229326725, 37.15186804533005, 37.63345420360565, 38.90611991286278, 36.50597110390663, 39.03729647397995, 36.09582491219044, 37.08244577050209, 37.024027705192566, 37.639587074518204, 37.115371003746986, 35.92762693762779, 36.43483892083168, 36.312166303396225, 38.814696818590164, 35.549832209944725, 35.29308758676052, 34.571969881653786, 34.2381501942873, 35.42704559862614, 35.61097852885723, 35.55772438645363, 35.75071223080158, 42.091800570487976, 45.60237139463425, 48.17819997668266, 47.01574735343456, 46.84172809123993, 49.55528408288956, 49.399515241384506, 47.670395225286484, 49.04993399977684, 48.4079584479332, 50.26681110262871, 49.0511005371809, 50.5526165664196, 49.78698804974556, 50.57871736586094, 50.17265975475311, 51.5500820428133, 47.89356864988804, 49.88344967365265, 41.65297731757164, 46.49339698255062, 49.08087193965912, 60.50118952989578, 43.226366490125656, 17.244893945753574, 5.917464746162295, 3.9603569637984037, 7.25543137639761, 5.585050983354449, 0.33825927414000034, 22.211772724986076, 55.99711261689663, 45.7190403342247, 34.405645206570625, 30.36860503256321, 35.08506014943123, 37.063807770609856, 27.102192007005215, 0.43730710458476096, 0.0628683612740133, 0.028387675556587055, 0.05605780934274662, 0.06087334215408191, 0.054075696170912124, 0.06989001340116374, 0.05308698848239146, 0.02955026473500766, 0.07468902971595526, 0.05069222635938786, 0.05920510920986999, 0.019175596826244146, 0.023915692181617487, 0.009629872620280366, 0.03542171041772235, 0.03920682313037105, 0.009121148013946367, 0.019162332791893277, 0.041618665782152675, 0.039476797901443206, 0.00664163726469269, 0.08016946376301348, 0.08611692392150871, 0.021661390783265233, 0.10005533302319236, 0.015012374715297483, 11.696424074470997, 55.60892164707184, 42.204897701740265, 25.774995423853397, 43.620283752679825, 49.753781631588936, 47.93510802090168, 62.88191758096218, 47.79935270547867, 55.57391792535782, 7.382286144420505, 0.2115662200958468, 8.846319559961557, 27.815041355788708, 4.199731294065714, 30.19799418747425, 64.65000450611115, 52.371271178126335, 53.37107352912426, 47.28291481733322, 48.99466976523399, 42.35371291637421, 41.91657677292824, 46.67636476457119, 52.822550162673, 50.76607011258602, 54.15109567344189, 52.60153882205486, 47.93757028877735, 47.713169530034065, 50.019516572356224, 53.4584878385067, 53.14725033938885, 50.07999412715435, 50.35856477916241, 46.73059545457363, 44.231693744659424, 44.078911542892456, 44.318861067295074, 43.962554186582565, 44.181821420788765, 42.399477660655975, 40.53940527141094, 38.96541953086853, 37.87461206316948, 38.65596033632755, 38.298076540231705, 38.89726638793945, 39.18142654001713, 40.1789528131485, 39.91513676941395, 39.832023829221725, 40.49153544008732, 39.93456892669201, 41.471419259905815, 40.741242840886116, 39.40417058765888, 39.596060290932655, 39.6492650359869, 38.70864450931549, 41.84188798069954, 40.39869122207165, 40.42023226618767, 43.037737011909485, 43.18823553621769, 38.65824021399021, 37.73886814713478, 39.097044467926025, 39.31532375514507, 41.05507180094719, 42.39716738462448, 46.16985574364662, 51.697605326771736, 54.969552755355835, 51.8005608022213, 55.340523049235344, 51.73757918179035, 47.167488411068916, 45.74300944805145, 43.08965742588043, 40.662598460912704, 41.25467129051685, 39.777082577347755, 37.52593517303467, 38.71761962771416, 38.80382940173149, 40.31254984438419, 40.2212293446064, 40.518441796302795, 38.59009847044945, 39.51062187552452, 39.810680374503136, 38.32275241613388, 40.17668433487415, 39.020220190286636, 40.020368322730064, 38.934097811579704, 40.40063291788101, 38.77777419984341, 37.370740100741386, 39.20031152665615, 37.442753836512566, 39.116142243146896, 38.06239798665047, 37.72409074008465, 37.894082218408585, 35.93035899102688, 37.048524990677834, 38.09323713183403, 37.90600597858429, 37.74339750409126, 45.490053221583366, 47.63530030846596, 50.56737497448921, 49.607865661382675, 50.146756544709206, 51.23936891555786, 51.28990240395069, 50.38238190114498, 49.99116249382496, 49.00834143161774, 51.538526862859726, 49.27793696522713, 52.669353783130646, 50.25832235813141, 52.794344276189804, 51.60776674747467, 53.61443147063255, 50.62469869852066, 52.0024211704731, 43.58736611902714, 48.021139204502106, 51.55820980668068, 60.558593049645424, 44.445747658610344, 20.614135153591633, 5.987694952636957, 7.41782421246171, 8.54326207190752, 4.281008457764983, 0.2704031683970243, 23.78024496138096, 63.786500841379166, 47.915010899305344, 43.00111837685108, 32.61922426521778, 31.178031899034977, 41.97344072163105, 33.16628850996494, 0.851461635902524, 0.06914189885719679, 0.05573545007791836, 0.012373626905173296, 0.06153146387077868, 0.03089227368036518, 0.046756992014707066, 0.0733090061112307, 0.007594768712806399, 0.005773324946858338, 0.03421800625801552, 0.09160116518614814, 0.13032662391196936, 0.1148804379045032, 0.10656610553269275, 0.11577278142794967, 0.25238465401344, 0.2378668650635518, 0.13311735150637105, 0.14082975016208366, 0.08645245630759746, 0.16599850117927417, 0.2200053000706248, 0.28855639742687345, 0.15745365031762049, 0.2985567186260596, 0.21470534149557352, 13.483304791152477, 65.96629187464714, 49.946104511618614, 35.452648624777794, 47.820076793432236, 52.50768005847931, 52.438474372029305, 65.03582820296288, 53.98582734167576, 64.086494743824, 9.890991803258657, 0.6495075789280236, 15.99609475582838, 44.73278805613518, 6.069819945842028, 34.2049665749073, 65.20456954836845, 55.662213787436485, 56.06588892638683, 50.9032541513443, 49.87928509712219, 46.45277716219425, 46.11247882246971, 51.148561388254166, 54.793546199798584, 52.5750732421875, 55.746455267071724, 55.34333489835262, 49.04755912721157, 48.74628089368343, 49.97734263539314, 55.00131145119667, 55.882947742938995, 52.17833653092384, 53.472737073898315, 47.31362856924534, 46.52385234832764, 47.23577454686165, 46.89774848520756, 45.92408873140812, 44.359165504574776, 44.77904297411442, 42.36085273325443, 41.03178285062313, 39.04003992676735, 42.20797933638096, 41.55499577522278, 40.10254271328449, 40.247010961174965, 40.356087908148766, 41.21499381959438, 42.35614858567715, 41.643865406513214, 41.72496825456619, 42.99022056162357, 43.084763288497925, 42.34422482550144, 42.20017835497856, 42.11623325943947, 39.82094742357731, 44.48605589568615, 41.28200322389603, 42.63604536652565, 44.38016697764397, 46.3515467941761, 40.18078811466694, 38.80925551056862, 42.15288609266281, 41.775957718491554, 41.59753069281578, 44.53361414372921, 49.46500092744827, 54.41765137016773, 57.99241594970226, 51.10857993364334, 56.99302397668362, 55.387214943766594, 50.333223938941956, 49.539796113967896, 45.31840123236179, 44.106102883815765, 44.46572698652744, 42.91110120713711, 40.262799113988876, 41.46060883998871, 40.58830864727497, 41.77813500165939, 42.6120762526989, 43.040567860007286, 40.1961924880743, 39.225568771362305, 42.26158685982227, 38.97194378077984, 41.975785195827484, 39.72968392074108, 42.00094364583492, 40.686540976166725, 41.39410100877285, 41.1519780009985, 38.861776292324066, 40.84420591592789, 38.364208191633224, 42.93706141412258, 39.867137745022774, 39.30198647081852, 39.8441793769598, 38.37768226861954, 39.35894161462784, 40.21756254136562, 40.17515301704407, 39.86773431301117, 47.326084300875664, 50.044857412576675, 52.61356137692928, 53.56677442789078, 52.11526371538639, 54.2071008682251, 52.19798527657986, 51.86468616127968, 50.777469500899315, 50.537766963243484, 53.931706845760345, 51.26441717147827, 53.295890763401985, 52.6425576210022, 52.79696233570576, 56.19038164615631, 56.27366557717323, 53.27253341674805, 53.612717762589455, 45.4725057631731, 49.07858066260815, 55.543618351221085, 63.42070206999779, 47.50554487109184, 22.898135595023632, 9.891026001423597, 9.841320868581533, 16.817644871771336, 15.208095889538527, 0.5348695709835738, 26.67078785598278, 68.41982021927834, 53.874690905213356, 47.020079120993614, 43.9859913289547, 44.41774696111679, 50.15320859849453, 39.452116414904594, 1.1508157476782799, 0.19144423655234277, 0.17323929467238486, 0.11257413236307912, 0.12885170930530876, 0.20229491055943072, 0.10469823857420124, 0.18807463377015665, 0.10435682095703669, 0.1707354368409142, 0.1648977180593647, 0.13095482223434374], [0.012330605532042682, 0.12434112126356922, 0.02254053335491335, 0.052385892704478465, 0.05394923049607314, 0.08357499391422607, 0.03634807399066631, 0.060288347958703525, 0.017851616503321566, 0.008825480090308702, 0.08063884990406223, 0.060302189012872986, 0.055330055620288476, 0.06469022249802947, 0.12633351318072528, 0.7471322966739535, 35.34564636647701, 47.42929436266422, 32.818728759884834, 25.365966372191906, 43.90986621379852, 44.955877885222435, 48.534620851278305, 46.878502517938614, 54.08464103937149, 14.839579313993454, 0.30573061492759734, 4.384091701358557, 15.400664806365967, 1.0747959581203759, 23.026215322315693, 62.478922605514526, 50.04312090575695, 54.780110120773315, 48.81923317909241, 49.08503271639347, 43.54815222322941, 48.17698024213314, 46.5889922529459, 50.45916438102722, 48.988977670669556, 48.97029027342796, 44.680700451135635, 44.89171452820301, 49.86525245010853, 47.973656952381134, 50.344646126031876, 48.49295228719711, 45.517388954758644, 42.341800555586815, 39.97940272092819, 39.3352384865284, 38.278473392128944, 37.67346225678921, 36.83570981025696, 38.54036293923855, 38.132352232933044, 36.95377707481384, 37.40705095231533, 36.670129895210266, 38.80071356892586, 37.29561433196068, 39.02271285653114, 38.42832215130329, 36.776273399591446, 36.000347435474396, 40.03925330936909, 38.21451522409916, 38.86552669107914, 37.93115682899952, 38.46466340124607, 37.60376639664173, 38.81871320307255, 37.87652716040611, 40.077008083462715, 39.83936883509159, 37.96373628079891, 40.63023939728737, 39.32475104928017, 38.71954992413521, 36.13418385386467, 34.3286157399416, 35.370550230145454, 35.82245618104935, 40.095942467451096, 42.322824373841286, 47.514911368489265, 52.81091898679733, 53.04560199379921, 52.423905953764915, 51.917944103479385, 50.4334207624197, 43.3866760879755, 43.11188243329525, 41.796795800328255, 43.99112105369568, 42.7718348801136, 43.83576638996601, 42.417443096637726, 37.66868211328983, 38.358694687485695, 39.21222768723965, 38.2702012360096, 39.44381386041641, 37.16786898672581, 35.71768060326576, 37.16810457408428, 37.078436985611916, 37.44722239673138, 37.503250390291214, 37.09312319755554, 38.06256517767906, 37.882831022143364, 38.38712856173515, 36.96803390979767, 38.08647729456425, 36.76155298948288, 36.28600470721722, 34.72365014255047, 35.18806502223015, 35.69770127534866, 35.56542657315731, 36.7863542586565, 35.998724922537804, 36.318572759628296, 35.14217108488083, 37.041468769311905, 39.42595861852169, 45.07325738668442, 47.05979838967323, 48.56693051755428, 46.26249857246876, 47.14643754065037, 46.21029317378998, 47.11116403341293, 45.60406990349293, 50.388233587145805, 49.78088177740574, 50.385300144553185, 50.324469208717346, 49.74237844347954, 48.720377683639526, 52.976464703679085, 49.3285046517849, 51.81169420480728, 45.76238840818405, 50.65463729202747, 46.74573764204979, 57.36532039940357, 38.14957670867443, 21.2943347543478, 0.9114178468007594, 7.430340265855193, 2.825470198877156, 1.4870055578649044, 0.05037885821366217, 21.176831759512424, 58.89296002686024, 48.40267293155193, 38.841743767261505, 25.876980051398277, 27.090712822973728, 46.93519547581673, 12.517156284302473, 0.28400186682119966, 0.05203416665608529, 0.06609746065805666, 0.04845018338528462, 0.051835916747222655, 0.024140060122590512, 0.02138656607712619, 0.02697364860068774, 0.04341346459113993, 0.017253738624276593, 0.01843867386924103, 0.03068131634790916, 0.059725599639932625, 0.06086616929678712, 0.05335256602847949, 0.06159406773804221, 0.04023665693239309, 0.07988892451976426, 0.03364104210049845, 0.009574652194714872, 0.025527462530590128, 0.017711345026327763, 0.028439169473131187, 0.06072748416045215, 0.025178389660140965, 0.07909071500762366, 0.01940813395776786, 1.5941500710323453, 45.21069221198559, 51.347093135118484, 31.307471953332424, 34.590079709887505, 52.25519880652428, 48.28368991613388, 56.020595356822014, 49.57514561712742, 61.21272794902325, 14.788800738751888, 0.359217346413061, 3.9244232419878244, 21.288353875279427, 1.4265347714535892, 24.596549458801746, 64.90725830197334, 52.520625963807106, 57.49844245612621, 50.390840247273445, 52.21771001815796, 46.78215868771076, 50.38546733558178, 49.07059349119663, 52.94311389327049, 52.20996603369713, 51.64352282881737, 47.93209098279476, 45.33882513642311, 50.95836639404297, 51.59830905497074, 51.657874658703804, 50.004879757761955, 47.39931017160416, 44.85627003014088, 41.967938616871834, 41.48928590118885, 40.74212059378624, 39.73892502486706, 38.656587302684784, 39.84857574105263, 39.52707499265671, 38.79116848111153, 38.61104674637318, 39.10296455025673, 39.33139689266682, 38.29556107521057, 39.70692314207554, 38.63094247877598, 38.78742568194866, 38.87670949101448, 40.67299470305443, 40.26581235229969, 40.284758135676384, 39.661815762519836, 41.09798289835453, 40.943676978349686, 39.80482488870621, 39.652175679802895, 41.99396342039108, 39.65826295316219, 38.89572747051716, 41.26793637871742, 40.56736797094345, 41.321353912353516, 37.91769415140152, 37.50562526285648, 37.77982234954834, 37.56869047880173, 41.78043007850647, 43.58620338141918, 49.66276131570339, 54.109666496515274, 55.93301385641098, 52.6381878554821, 52.456979379057884, 53.76554176211357, 45.780931413173676, 44.7627342492342, 44.73190650343895, 44.846029579639435, 44.371788427233696, 44.99207854270935, 43.28555591404438, 39.16509501636028, 39.31862197816372, 41.19696378707886, 38.96438218653202, 41.48028038442135, 37.47810333967209, 38.578151911497116, 38.04281763732433, 38.66718113422394, 38.4343296289444, 39.65619586408138, 38.38856488466263, 39.94873836636543, 40.06392538547516, 39.91670988500118, 38.672744035720825, 39.49937827885151, 37.61369526386261, 38.24451461434364, 37.30781927704811, 37.11175739765167, 37.647452652454376, 36.68633982539177, 39.25891198217869, 36.758315563201904, 38.29090632498264, 37.20830641686916, 38.14662046730518, 41.37861683964729, 48.21272112429142, 49.02389019727707, 50.72417736053467, 49.41823683679104, 49.54055607318878, 48.612167090177536, 49.53480698168278, 49.64815489947796, 50.87808430194855, 52.32419550418854, 53.468158319592476, 51.11303709447384, 50.33056028187275, 48.62949036061764, 55.003484934568405, 50.93620218336582, 55.099783167243004, 48.07088993489742, 53.86257715523243, 48.392565473914146, 58.18242855370045, 39.62924391031265, 24.782122001051903, 2.2573348972946405, 10.96675967797637, 6.0727001912891865, 1.624623010866344, 0.05371104933146853, 23.156354539096355, 63.99213820695877, 53.644848838448524, 46.03166475892067, 31.201003566384315, 32.477385476231575, 53.80952060222626, 16.30082320421934, 0.25527208345010877, 0.09727057229611091, 0.06604901325772516, 0.06717280295561068, 0.0154440319238347, 0.026656848021957558, 0.03250174151617102, 0.03665230258775409, 0.05565618870605249, 0.05478598344780039, 0.034521808120189235, 0.03804591120569967, 0.11831768744741566, 0.15528084972174838, 0.07527551933890209, 0.20716954430099577, 0.1798992240219377, 0.13903353014029562, 0.11319552519125864, 0.09124488977249712, 0.15046036307467148, 0.16525679879123345, 0.16250736429356039, 0.21373706142185256, 0.17854713485576212, 0.17834590893471614, 0.2281011367449537, 2.0813518529757857, 51.725875809788704, 61.72993719577789, 41.33152216672897, 35.8880140632391, 56.566922441124916, 55.2678519487381, 61.30136579275131, 53.2722332328558, 64.81946021318436, 19.212738052010536, 0.3866648767143488, 11.46350322291255, 24.502806589007378, 1.4429386099800467, 28.091535419225693, 66.89800187945366, 54.930346459150314, 60.307384729385376, 52.616050243377686, 54.552164152264595, 47.79499053955078, 53.534992933273315, 50.870142728090286, 55.134718492627144, 54.273977279663086, 53.98268111050129, 50.397261902689934, 49.19727489352226, 54.49628435075283, 53.425273820757866, 56.17971941828728, 52.85252295434475, 49.2254351824522, 46.28317326307297, 43.186533227562904, 43.15054155886173, 42.57630117237568, 41.91572181880474, 40.41542552411556, 43.42188119888306, 42.857588678598404, 41.21673412621021, 41.57995663583279, 42.3795211315155, 41.68917417526245, 39.904972314834595, 41.956011056900024, 40.92695787549019, 40.43791651725769, 39.7910962253809, 43.05452451109886, 42.514212504029274, 43.04809905588627, 40.254952535033226, 42.13575281202793, 41.62625715136528, 42.518373280763626, 42.46993348002434, 44.78097707033157, 42.62297786772251, 41.72254018485546, 44.58503678441048, 43.0367186665535, 42.2484927624464, 40.62450930476189, 39.94722604751587, 39.90390457212925, 40.487519055604935, 43.274745494127274, 45.38018211722374, 52.41132862865925, 55.98179183900356, 58.44431810081005, 53.74308496713638, 55.34647732973099, 57.90701173245907, 46.92838244140148, 46.25849738717079, 46.219036504626274, 46.11570104956627, 45.6217123568058, 49.1208153963089, 45.510511323809624, 41.06576822698116, 41.360636204481125, 44.08591456711292, 40.985223948955536, 44.13902431726456, 39.47795882821083, 39.30323280394077, 42.04763934016228, 40.84620840847492, 40.05374193191528, 40.83829343318939, 39.75553013384342, 41.40625275671482, 41.94486245512962, 42.38760709762573, 40.32549574971199, 42.74394817650318, 38.587214425206184, 39.9881536513567, 37.63956047594547, 39.89402510225773, 40.99680572748184, 39.09581333398819, 42.820776253938675, 40.18282860517502, 39.0640926361084, 39.25735026597977, 40.98831318318844, 43.021743670105934, 49.50124338269234, 51.76685281097889, 53.46186965703964, 51.86212129890919, 51.114355623722076, 50.84210783243179, 51.583915427327156, 51.816352754831314, 53.61323073506355, 53.20592299103737, 54.524338245391846, 52.78232932090759, 51.33157856762409, 50.56527368724346, 56.785391718149185, 54.03223045170307, 55.485660061240196, 51.01642347872257, 56.15540452301502, 51.30380965769291, 58.40231895446777, 41.86387360095978, 26.594324558973312, 2.9536774568259716, 19.066734686493874, 12.257905695587397, 7.487158617004752, 0.2673767792293802, 25.884568244218826, 71.11207455396652, 57.324092611670494, 51.02778486907482, 36.35111041367054, 36.508744955062866, 61.38672821223736, 22.580512538552284, 0.3869031654903665, 0.17085124156437814, 0.19888860115315765, 0.15568894188618287, 0.1114354922901839, 0.12129536946304142, 0.14338722074171528, 0.1398914380115457, 0.14213294663932174, 0.12536535185063258, 0.18776971497572958, 0.08131832320941612], [0.0768602050084155, 0.062052206631051376, 0.07852049326174892, 0.05229369198787026, 0.04099973688425962, 0.09767911717062816, 0.009828090987866744, 0.00706953595908999, 0.14091907505644485, 0.0716233067214489, 0.016043217838159762, 0.004585156257235212, 0.0351490787579678, 0.026422832161188126, 0.19665510772028938, 0.14578178990632296, 17.40942321717739, 54.983308017253876, 35.566691905260086, 32.843647822737694, 39.00862701237202, 38.79476688802242, 64.42776203155518, 47.05290175974369, 55.34726768732071, 19.955829977989197, 0.058648761914810166, 2.074747569859028, 6.623340994119644, 4.714825004339218, 12.122087683528662, 54.18872505426407, 53.555743619799614, 57.741439417004585, 48.42207469046116, 51.08491860330105, 50.36420747637749, 53.80454286932945, 49.66759845614433, 52.64512628316879, 51.633890345692635, 49.11975145339966, 45.41584700345993, 46.83310255408287, 46.88594251871109, 51.02282613515854, 47.34696418046951, 49.281314983963966, 42.96901769936085, 43.1158684194088, 39.45498526096344, 39.20225702226162, 35.79593740403652, 36.320518255233765, 36.11000955104828, 37.19751879572868, 34.87599916756153, 36.357281282544136, 35.137459337711334, 38.233738392591476, 36.00363425910473, 38.121135234832764, 38.55329744517803, 38.42135712504387, 37.96546898782253, 38.86428415775299, 36.61581180989742, 37.85671882331371, 37.68831565976143, 39.45816949009895, 39.662765711545944, 38.663062155246735, 37.11082264780998, 40.68056009709835, 36.81304782629013, 39.999735429883, 36.33885607123375, 40.941378101706505, 38.588776141405106, 39.06027764081955, 36.90828211605549, 37.76681184768677, 37.200186252593994, 38.45848113298416, 40.634840950369835, 46.98649652302265, 49.66354787349701, 58.557145446538925, 57.50442333519459, 46.997827515006065, 49.77011315524578, 52.29385793209076, 46.55639000236988, 44.69518907368183, 45.496775060892105, 44.13754239678383, 46.00102700293064, 45.61199627816677, 45.119888484478, 39.472893700003624, 35.52736021578312, 37.902597561478615, 38.54093290865421, 40.7462015748024, 38.3739622682333, 36.446462497115135, 35.59331327676773, 38.867194801568985, 36.941773518919945, 36.718440502882004, 37.42834120988846, 38.321718871593475, 37.06707939505577, 37.409634813666344, 37.211437448859215, 37.47105851769447, 37.423450872302055, 38.12865503132343, 35.84424801170826, 35.5016165971756, 36.09395921230316, 35.11949010193348, 34.81927961111069, 35.875398740172386, 35.781019404530525, 36.02935127913952, 35.83657242357731, 35.45723497867584, 34.71741087734699, 38.51217985153198, 41.182391569018364, 42.19572879374027, 41.94267377257347, 42.843062058091164, 43.973812982439995, 46.36610761284828, 47.07840979099274, 48.50484564900398, 48.291984871029854, 50.87420850992203, 49.61279019713402, 49.207883924245834, 48.49867857992649, 51.38270482420921, 51.23653806746006, 52.15563654899597, 48.93649108707905, 53.96643318235874, 53.79781723022461, 36.12398900091648, 8.111121710389853, 2.811107444576919, 18.93098507076502, 4.755655713379383, 1.3126688939519227, 0.4301720968214795, 33.0704652518034, 55.005415230989456, 47.47646123170853, 29.792954921722412, 19.950042888522148, 38.37488941848278, 39.9678323417902, 3.062762478366494, 0.03954592153604608, 0.057056305959122255, 0.05715441788197495, 0.020894229019177146, 0.04325481197156478, 0.036714424059027806, 0.035873125452781096, 0.01055137419825769, 0.02524117906432366, 0.04276723579096142, 0.04271471028914675, 0.06941840823856182, 0.08775194204645231, 0.08669000293593854, 0.032046682536019944, 0.012846772951888852, 0.016884958022274077, 0.009278615052608075, 0.02410916451481171, 0.0411715292284498, 0.11786409420892596, 0.006194348570716102, 0.013734309213759843, 0.029254103283165023, 0.06073293523513712, 0.08339393956703134, 0.016196052019950002, 0.1690917430096306, 24.7828496620059, 60.411126762628555, 38.6879014223814, 30.52151832729578, 50.509811863303185, 44.66522388160229, 63.16683009266853, 51.409804970026016, 59.065474569797516, 21.669560819864273, 0.041210436320398, 3.099965094588697, 12.20117473974824, 3.8583329133689404, 14.694287460297346, 58.11456419527531, 55.54373614490032, 60.03793738782406, 50.81993222236633, 54.96559716761112, 50.42716629803181, 54.00598146021366, 51.8016741424799, 55.48161327838898, 52.34925515949726, 47.11082965135574, 44.604750126600266, 48.608401492238045, 50.15338718891144, 53.175391629338264, 50.20793326199055, 50.70283770561218, 44.60345819592476, 47.201462388038635, 41.29065155982971, 41.557325050234795, 38.339957892894745, 38.91071766614914, 38.38511846959591, 38.695356622338295, 36.95963256061077, 37.81674116849899, 37.031615898013115, 40.33216059207916, 38.003922924399376, 38.38700696825981, 38.98267440497875, 40.179686173796654, 40.351250767707825, 39.269722402095795, 38.50640036165714, 39.67726953327656, 39.38750468194485, 39.716635420918465, 40.26011645793915, 40.10843239724636, 40.12776955962181, 42.28202596306801, 39.19860161840916, 41.44791752099991, 38.1147363781929, 42.583345994353294, 40.98031461238861, 40.562200248241425, 39.288064017891884, 38.68240311741829, 38.99169512093067, 40.744028091430664, 42.87249147891998, 46.935415863990784, 52.73597180843353, 55.66372990608215, 51.34902723133564, 47.16369241476059, 52.15251311659813, 54.34923604130745, 48.650453835725784, 46.36496387422085, 46.49128429591656, 48.005582839250565, 48.50796528160572, 46.495570465922356, 46.014964655041695, 40.638785138726234, 37.85811334848404, 40.80518960952759, 40.512962490320206, 41.27665311098099, 41.112520918250084, 39.98587757349014, 37.023271545767784, 40.14927260577679, 39.261267855763435, 39.75923493504524, 39.58217963576317, 40.30635617673397, 38.655181378126144, 39.248679131269455, 39.58504468202591, 39.11819413304329, 38.88734892010689, 39.315000772476196, 36.56672604382038, 37.47068993747234, 37.14068524539471, 36.20557062327862, 36.24580666422844, 38.177999183535576, 37.60591708123684, 37.41805896162987, 36.61554582417011, 37.50405974686146, 37.78594762086868, 40.817698538303375, 43.976351246237755, 43.80931980907917, 44.936875104904175, 45.243070274591446, 46.102998331189156, 48.334151208400726, 48.41858267784119, 50.2778647094965, 50.503724589943886, 52.81239710748196, 52.54937902092934, 50.298220217227936, 49.29182142019272, 54.438972026109695, 53.29756647348404, 54.079800099134445, 51.7925850301981, 55.59009745717049, 55.83950087428093, 39.60097722709179, 10.060638450086117, 6.9113565143197775, 15.375536754727364, 9.20324295759201, 1.10803586198017, 0.4040090460330248, 35.758619606494904, 59.67489346861839, 53.02515909075737, 40.05074009299278, 21.802357994019985, 37.423260882496834, 48.57926085591316, 4.986381232738495, 0.08266528413514607, 0.019117341944365762, 0.07086233075824566, 0.05844563609571196, 0.11689355058479123, 0.03000382086611353, 0.04321509964938741, 0.025253322455682792, 0.030657001734653022, 0.02893238968681544, 0.05598253701464273, 0.039726771792629734, 0.1323151937685907, 0.20337187073891982, 0.11491932644275948, 0.10174627197557129, 0.2707064396236092, 0.20803439867449924, 0.15558830666122958, 0.13461568829370663, 0.20844755228608847, 0.23445279279258102, 0.11256158264586702, 0.19327349698869511, 0.11293832649243996, 0.18548271269537508, 0.21071047929581255, 0.25521600677166134, 27.69120790064335, 69.27026778459549, 47.50695459544659, 41.42696164548397, 51.323674991726875, 48.043257817626, 72.15953394770622, 56.37281745672226, 65.69008469581604, 25.804749727249146, 0.22784478409448639, 5.323880072683096, 15.868409257382154, 8.63785894587636, 20.51109418272972, 57.9741845279932, 56.79923437535763, 62.674049735069275, 52.45898947119713, 56.917510628700256, 53.95684249699116, 57.137420028448105, 53.52525785565376, 56.59951709210873, 53.09232048690319, 47.66267403960228, 46.60482980310917, 51.11199215054512, 51.62403367459774, 56.65169969201088, 51.31120406091213, 53.92389066517353, 46.3987972587347, 49.52501870691776, 43.538356348872185, 44.57396037876606, 41.318694055080414, 42.62424699962139, 41.93187475204468, 41.90404124557972, 39.49059695005417, 41.21145620942116, 38.977453485131264, 42.57554121315479, 41.77799440920353, 41.05252593755722, 41.84172458946705, 42.71139532327652, 43.06110955774784, 41.784438863396645, 39.28777523338795, 42.38230638206005, 40.15682280063629, 42.799508795142174, 43.187255188822746, 41.76661781966686, 40.608481764793396, 45.31816564500332, 40.29362305998802, 43.12999226152897, 37.749857157468796, 45.6659571826458, 41.783606708049774, 43.004610389471054, 41.81374669075012, 41.2128621339798, 42.04488828778267, 42.09411084651947, 44.43195439875126, 50.26083022356033, 54.630610942840576, 58.94469805061817, 52.60488264262676, 47.44370698928833, 53.42288374900818, 56.87735058367252, 51.80603630840778, 48.04775297641754, 46.97803437709808, 49.03038024902344, 50.57678706943989, 48.17717403173447, 47.69315220415592, 42.81884215772152, 39.367874935269356, 41.481975093483925, 43.81474211812019, 44.642618894577026, 41.85272879898548, 42.153995633125305, 39.087328389286995, 42.12379105389118, 40.598001927137375, 41.70093074440956, 42.110408172011375, 40.3197580575943, 40.315175503492355, 41.536676958203316, 40.84049731492996, 40.49645237624645, 41.2717741727829, 42.08775758743286, 39.49333280324936, 40.5794171243906, 41.37726791203022, 37.6355554908514, 38.58853295445442, 39.98142421245575, 39.200322926044464, 38.65691028535366, 39.57945518195629, 39.13634955883026, 39.02107134461403, 42.81761862337589, 46.02716580033302, 46.920110285282135, 46.85330227017403, 46.46773315966129, 47.992659732699394, 51.950854137539864, 50.55691033601761, 54.13567990064621, 53.02243083715439, 56.36972442269325, 52.2503312677145, 51.36295348405838, 48.89311641454697, 55.422503650188446, 55.740478187799454, 57.73489996790886, 53.70575197041035, 58.36534693837166, 56.76142260432243, 43.14726613461971, 11.004444155842066, 7.5515775103122, 29.049241729080677, 18.140625581145287, 4.948113486170769, 0.5595495435409248, 41.46436303853989, 64.05239537358284, 58.84505979716778, 42.913825660943985, 30.289905555546284, 49.35478784143925, 57.61815883219242, 6.390362670645118, 0.3234218421857804, 0.10344419453758746, 0.13132217049133033, 0.13241983659099787, 0.20022326469188556, 0.13755488995229825, 0.1143870507075917, 0.14365740702487528, 0.12214567032060586, 0.17745825578458607, 0.17010162788210437, 0.10338884516386315], [0.07007911262917332, 0.018463893902662676, 0.03278288189903833, 0.028509569601737894, 0.06100207880081143, 0.031000591989140958, 0.05016426992369816, 0.034264178975718096, 0.020443376160983462, 0.03168341238051653, 0.06874387021525763, 0.014543154629791388, 0.060291375921224244, 0.14149906346574426, 0.04476402493310161, 0.20699902845080942, 5.623948546126485, 40.92692747712135, 45.54091349244118, 31.634858585894108, 29.274315051734447, 39.27211247384548, 54.61547635495663, 51.718226820230484, 50.80174259841442, 34.63528208434582, 0.7562547165434808, 1.6646891296841204, 4.124061679467559, 10.79654211178422, 35.13364814221859, 26.3261254504323, 58.129808977246284, 51.399188339710236, 56.16142340004444, 48.328481912612915, 53.65598604083061, 51.74815021455288, 51.91264718770981, 45.46266809105873, 43.02655041217804, 48.96687425673008, 48.618459552526474, 46.147493943572044, 49.659565687179565, 50.07690869271755, 50.82874774932861, 46.346413269639015, 45.94687610864639, 42.046917378902435, 41.54753677546978, 41.72316335141659, 40.12822933495045, 36.92368268966675, 36.98267072439194, 35.54181843996048, 37.075142562389374, 36.71748675405979, 36.14682197570801, 37.83941835165024, 39.49788875877857, 39.007399678230286, 37.458754777908325, 37.431905418634415, 38.565441593527794, 38.02936255931854, 38.42004619538784, 38.710149228572845, 38.865994065999985, 39.05548229813576, 39.56387601792812, 37.821475714445114, 39.14687119424343, 38.32918547093868, 40.09676702320576, 38.73273141682148, 39.08315621316433, 40.211182683706284, 40.822277292609215, 38.265234902501106, 37.01321728527546, 35.243887826800346, 38.62322509288788, 40.186863988637924, 45.4355413466692, 49.74867470562458, 51.290069594979286, 54.27008628845215, 77.77923479676247, 58.24246533215046, 47.82183989882469, 51.21817745268345, 50.23143120110035, 48.55256728827953, 47.94793613255024, 47.23537176847458, 48.71209032833576, 50.398265048861504, 49.43991467356682, 45.06941579282284, 37.53209464251995, 39.92657795548439, 38.808617144823074, 39.18796978890896, 37.98983708024025, 37.03587926924229, 36.48618556559086, 38.09875823557377, 38.61453875899315, 37.094901502132416, 34.764646142721176, 38.428094163537025, 35.083221048116684, 36.85681767761707, 39.36245642602444, 36.55625760555267, 35.340151861310005, 39.31769862771034, 37.55544438958168, 36.70764908194542, 35.61483532190323, 35.40247231721878, 36.26684993505478, 35.99908970296383, 36.42021730542183, 35.315498784184456, 35.69170139729977, 35.40200874209404, 34.2798263579607, 32.513760924339294, 34.05056186020374, 34.22464191913605, 34.41079393029213, 34.2594138532877, 36.55017413198948, 38.07334139943123, 40.00878654420376, 42.57928021252155, 46.64763070642948, 47.75460250675678, 50.16594931483269, 52.35187701880932, 49.66529957950115, 47.58581556379795, 52.477414682507515, 50.306298583745956, 52.33329601585865, 54.1806048899889, 53.950185254216194, 20.003977194428444, 3.519808603450656, 13.442182447761297, 6.621255856007338, 3.3985948702320457, 0.2181754756020382, 0.6598529394250363, 37.372624799609184, 53.80564481019974, 41.87115781009197, 28.76634880900383, 31.453450620174408, 49.47388865053654, 26.88777521252632, 1.1804856243543327, 0.08935307370848022, 0.04287477670004591, 0.015535322581854416, 0.028032901136612054, 0.07625994112459011, 0.02810182068060385, 0.04335106481448747, 0.1298755020252429, 0.04822630711714737, 0.03845431136141997, 0.06821863746154122, 0.0459785607381491, 0.05276542702631559, 0.06022491288604215, 0.019852170189551543, 0.021248129560262896, 0.009667338090366684, 0.056841146215447225, 0.046219235518947244, 0.023353641481662635, 0.06414359362679534, 0.03202380583388731, 0.1157615304691717, 0.01977186053409241, 0.029586077071144246, 0.07070268737152219, 0.04526126758719329, 0.05396925735112745, 8.852648120373487, 52.55701661109924, 47.58161298930645, 33.54646570980549, 38.801500126719475, 48.01688723266125, 60.257193222641945, 56.719928830862045, 56.58922724425793, 36.423352137207985, 0.5964956735260785, 1.163443538825959, 5.075897304341197, 15.534116495400667, 38.114352598786354, 31.704271361231804, 58.98277960717678, 54.10011760890484, 57.98149913549423, 50.20215757191181, 56.1001592874527, 56.336601600050926, 55.55561810731888, 48.79523366689682, 44.94061030447483, 48.246683701872826, 50.92677488923073, 47.9364113509655, 50.65660938620567, 51.969541534781456, 52.507881447672844, 50.32660089433193, 46.886341497302055, 46.140540316700935, 44.433041140437126, 42.49564670026302, 41.963789239525795, 38.46945494413376, 39.63737927377224, 37.8117710351944, 39.05066795647144, 38.46525996923447, 39.01279918849468, 40.58141201734543, 41.6377629339695, 40.46950802206993, 38.874912187457085, 37.771295607089996, 39.88117799162865, 39.17608022689819, 39.23142045736313, 40.69418616592884, 40.0375472009182, 40.80395847558975, 39.88732606172562, 40.47885172069073, 39.86076548695564, 40.722745433449745, 40.83509400486946, 40.31188108026981, 40.05077429115772, 40.30821807682514, 42.555622681975365, 40.47100894153118, 39.67359893023968, 38.23028817772865, 38.90817180275917, 40.75360357761383, 46.49661161005497, 50.39419166743755, 53.728843331336975, 58.33863817155361, 68.10678541660309, 56.77662178874016, 49.845330119132996, 54.407277926802635, 48.48878011107445, 50.89592434465885, 50.00092037022114, 50.568587109446526, 49.48656477034092, 50.488407611846924, 49.37353603541851, 47.097256779670715, 37.68341392278671, 40.5938221514225, 39.99759994447231, 41.47568263113499, 39.49384197592735, 39.119486063718796, 37.346694990992546, 39.9361914396286, 38.82258519530296, 38.7950898706913, 38.645586892962456, 40.42745187878609, 38.75900700688362, 38.47771190106869, 39.39745254814625, 38.895108103752136, 37.340280935168266, 39.786969646811485, 38.63006092607975, 37.468983829021454, 37.90879122912884, 36.521907448768616, 36.2829876691103, 37.71040387451649, 37.380300387740135, 37.75793932378292, 37.775737568736076, 36.86573579907417, 36.01050429046154, 34.97591480612755, 36.14717535674572, 38.066486567258835, 36.90811112523079, 35.96839115023613, 38.38452950119972, 40.734973177313805, 42.36003577709198, 43.61818626523018, 49.37897354364395, 49.93913188576698, 52.11962208151817, 53.345865681767464, 49.86592121422291, 49.67421390116215, 52.99577906727791, 51.894609555602074, 55.78713968396187, 55.766145810484886, 55.73583863675594, 21.620874032378197, 6.449574418365955, 17.261240668594837, 6.462065298110247, 7.564866347238421, 0.3362598689273, 0.6317957793362439, 42.81787320971489, 58.670869544148445, 47.45567634701729, 30.316551625728607, 31.53525833040476, 54.8417542129755, 35.131448060274124, 1.430697210598737, 0.09271501010516658, 0.023639676328457426, 0.028153364692116156, 0.03297535418823827, 0.01879246123280609, 0.020191289004287682, 0.028546341163746547, 0.04439474709215574, 0.05740596883697435, 0.07866524916607887, 0.04063414009578992, 0.01249192338946159, 0.13656198541866615, 0.14003483578562737, 0.08501270465785637, 0.09931917447829619, 0.1241584267700091, 0.13200203713495284, 0.14473660849034786, 0.15932657872326672, 0.19463229516986758, 0.1262388745089993, 0.16971511737210676, 0.12710880517261103, 0.09354196299682371, 0.16949468466918916, 0.11450455494923517, 0.29385482717771083, 9.158858489245176, 60.36278195679188, 57.3070315271616, 42.145172506570816, 38.670540153980255, 51.04649506509304, 63.04145202040672, 60.366106778383255, 59.32326793670654, 42.96844772994518, 0.7584895903710276, 4.834654899314046, 11.436071544885635, 19.65425346046686, 43.73001426458359, 32.099769338965416, 59.898287281394005, 55.6421584635973, 60.03564991056919, 54.02604818344116, 58.4823464602232, 57.11147502064705, 54.96024705469608, 47.59518966078758, 43.77059608697891, 50.54813280701637, 50.196989849209785, 49.14665400981903, 52.673168778419495, 55.524547174572945, 54.46814306080341, 52.56705567240715, 50.25030478835106, 47.95529253780842, 45.83602845668793, 45.95355994999409, 44.71072643995285, 41.9836013764143, 42.258801609277725, 40.49310855567455, 40.85209809243679, 42.51178443431854, 41.69215701520443, 42.67156586050987, 43.151958882808685, 43.50742220878601, 41.43285512924194, 40.135627537965775, 41.226947978138924, 41.8863607943058, 41.948833242058754, 43.0019923299551, 41.96715585887432, 41.229942217469215, 41.51936128735542, 41.808525770902634, 43.011446222662926, 42.36952006816864, 42.28825382888317, 42.983335331082344, 40.98051220178604, 43.150150179862976, 44.660367742180824, 43.28156232833862, 39.681304916739464, 39.62346062064171, 41.802043318748474, 44.90658313035965, 48.86095494031906, 52.98772729933262, 53.01231577992439, 60.83807945251465, 66.7656397819519, 54.06750775873661, 52.0792530477047, 54.02772769331932, 51.351998671889305, 52.31640972197056, 52.23021134734154, 51.16439513862133, 53.53954128921032, 53.86393368244171, 52.63876162469387, 49.610438123345375, 40.2640226483345, 43.605293557047844, 41.41569145023823, 43.573584258556366, 42.00998716056347, 40.699198096990585, 40.2804833650589, 43.64154741168022, 42.42734156548977, 39.643618538975716, 40.1270741969347, 42.8815957903862, 39.74752776324749, 41.10608026385307, 43.24222303926945, 41.083965450525284, 38.374133259058, 41.7610739171505, 40.96137262880802, 39.69701707363129, 40.39378568530083, 38.2450769841671, 37.998588010668755, 39.41804364323616, 39.486253783106804, 40.24104908108711, 39.46951948106289, 39.49409656226635, 37.67415001988411, 35.449544191360474, 38.03305596113205, 39.65350940823555, 39.066851288080215, 37.68204599618912, 41.69894725084305, 42.95279636979103, 44.25761975347996, 46.377480402588844, 50.98375663161278, 51.96133017539978, 55.06499983370304, 55.406441912055016, 50.99328272044659, 48.02734047174454, 53.90507407486439, 54.44500610232353, 59.970593601465225, 56.4748951792717, 57.16936871409416, 24.975119344890118, 8.427675124257803, 25.657412633299828, 14.198752250522375, 16.09595339745283, 2.2860323823988438, 1.1274528200738132, 46.22325047850609, 64.57406178116798, 51.445492655038834, 40.02155765891075, 42.44903840124607, 60.27236960828304, 42.24542632699013, 2.043065819889307, 0.42913018085528165, 0.08872017016983591, 0.11176352898473851, 0.11135464272229001, 0.10835972061613575, 0.1723338002921082, 0.15214748738799244, 0.21323529537767172, 0.1647326347301714, 0.24670093087479472, 0.2689712983556092, 0.1629913187935017], [0.022772337615606375, 0.03857717390928883, 0.006976926133575034, 0.05724771326640621, 0.07883199490606785, 0.0835058480151929, 0.03815454307186883, 0.051746899844147265, 0.03357763671374414, 0.06189543164509814, 0.015489434663322754, 0.10583897892502137, 0.044897759944433346, 0.03515303440508433, 0.012811303859052714, 0.0645146006718278, 0.337420855066739, 25.57096727192402, 46.600110456347466, 32.037498280406, 23.213663063943386, 31.335854530334473, 52.44796626269817, 51.73253685235977, 49.329317808151245, 41.81490942835808, 1.2213631183840334, 1.7105893604457378, 2.366843121126294, 1.078760214149952, 12.122316621243954, 18.785865157842636, 49.2829716950655, 51.79180987179279, 53.71524766087532, 51.60632282495499, 52.74283044040203, 51.22586444020271, 50.75123570859432, 46.3597771525383, 50.844269916415215, 47.48583912849426, 50.51733925938606, 47.86488018929958, 48.13449092209339, 47.71788887679577, 51.23334243893623, 47.73081198334694, 46.822318732738495, 45.49776300787926, 42.502353340387344, 38.454145565629005, 39.54103544354439, 36.39572761952877, 36.39176443219185, 34.74087081849575, 36.66674427688122, 38.5247989743948, 37.841618433594704, 36.574344635009766, 38.87787222862244, 36.55558884143829, 39.799292385578156, 37.76534892618656, 38.339881896972656, 37.24723532795906, 38.23502652347088, 37.30582058429718, 39.482609778642654, 37.09405414760113, 38.469014167785645, 38.31951878964901, 39.03660111129284, 39.55616243183613, 39.45837467908859, 36.577783450484276, 38.466536700725555, 38.67853492498398, 38.964412584900856, 40.360127091407776, 38.57295759022236, 36.045272424817085, 37.92286567389965, 37.304521054029465, 44.6075239777565, 47.48314507305622, 57.43354573845863, 43.90450470149517, 46.464381739497185, 65.244140625, 51.8069938570261, 50.64097322523594, 55.39094254374504, 52.9262275993824, 47.691054716706276, 51.102048084139824, 50.212656408548355, 51.63135968148708, 48.28840546309948, 49.831601455807686, 40.591758862137794, 36.75571270287037, 38.347975462675095, 37.41615526378155, 39.25935655832291, 37.30362810194492, 38.592325150966644, 37.080819457769394, 38.778252974152565, 38.20075996220112, 37.82548449933529, 37.05418288707733, 37.05021969974041, 35.82094766199589, 35.78687869012356, 35.64545027911663, 36.22260890901089, 36.15094095468521, 36.68055273592472, 36.07844464480877, 36.25808000564575, 36.39042690396309, 36.59492813050747, 36.300983503460884, 34.41735237836838, 34.56976220011711, 34.4983222335577, 33.65331217646599, 34.323486015200615, 34.76874612271786, 35.359264835715294, 36.83759830892086, 34.88590523600578, 35.647391974925995, 34.89877514541149, 36.334752291440964, 33.67624394595623, 33.744043707847595, 38.13751995563507, 42.75900676846504, 48.889958783984184, 50.75199946761131, 49.03011806309223, 47.844482883811, 50.701982751488686, 56.02724879980087, 53.75298723578453, 53.739399164915085, 35.1744769513607, 6.010537426918745, 26.14409051835537, 17.726400308310986, 3.2392853312194347, 7.928140629082918, 0.5174377094954252, 2.8755268128588796, 50.358674973249435, 49.23050791025162, 37.06366717815399, 26.718108616769314, 31.095941103994846, 44.94288258254528, 13.089700061827898, 0.14580631046555936, 0.1407971401931718, 0.06209180392033886, 0.034962005593115464, 0.01334193759248592, 0.042544632306089625, 0.04401062258693855, 0.040881234453991055, 0.033166360735776834, 0.013423875334410695, 0.033197746161022224, 0.02255529281683266, 0.026839047131943516, 0.04415031333337538, 0.06918941857293248, 0.07287722459295765, 0.04091526192496531, 0.017598609083506744, 0.08740089877392165, 0.03701743182318751, 0.023091205075616017, 0.02941946491773706, 0.016458059835713357, 0.0833137653535232, 0.0838885513076093, 0.005342863523765118, 0.046666401758557186, 0.04195304412860423, 0.04154115216806531, 0.947155641624704, 34.87004488706589, 53.256855458021164, 34.4641924649477, 27.05375600606203, 40.419422909617424, 56.11269861459732, 56.490972116589546, 53.47008481621742, 46.37528412044048, 1.2948023714125156, 1.4770725346170366, 6.486506061628461, 3.993665026500821, 18.392048589885235, 21.59593027085066, 52.72275231778622, 52.263695150613785, 53.99701774120331, 53.41215692460537, 54.09224443137646, 50.65769612789154, 49.96184706687927, 45.93768820166588, 50.15473611652851, 48.467949628829956, 50.88592328131199, 48.52715045213699, 49.611699655652046, 49.08870331943035, 53.117965310812, 50.47179490327835, 49.59144674241543, 45.368448346853256, 44.822748228907585, 42.10492506623268, 40.865317583084106, 40.040305852890015, 38.94176200032234, 37.12265141308308, 36.83881424367428, 40.59916466474533, 38.63197982311249, 39.76504482328892, 42.50751346349716, 39.26644317805767, 41.5458382666111, 41.08493059873581, 40.614439845085144, 38.70979584753513, 39.21480394899845, 39.36773054301739, 40.37673220038414, 39.12399262189865, 40.43451189994812, 41.908084228634834, 42.15406022965908, 40.97889728844166, 40.9190808981657, 39.11325819790363, 39.58128668367863, 40.699129700660706, 40.502687841653824, 40.923902839422226, 38.33659887313843, 38.98900106549263, 38.61630566418171, 39.715795665979385, 45.2025530487299, 50.062993839383125, 55.39237126708031, 49.4772856682539, 56.342749670147896, 63.015180230140686, 52.120439037680626, 54.33726668357849, 54.29398700594902, 51.83547332882881, 51.03383034467697, 52.20034874975681, 52.34560735523701, 52.46647886931896, 52.02119216322899, 47.89946973323822, 43.384620398283005, 37.783025577664375, 40.34391336143017, 39.415072202682495, 40.06956048309803, 38.62106680870056, 38.45631144940853, 38.55924032628536, 40.12611284852028, 39.470974802970886, 38.372750133275986, 38.59004147350788, 38.920790925621986, 37.91014015674591, 38.697397112846375, 36.85003504157066, 38.9786846190691, 36.747330352663994, 38.6149263381958, 36.89599357545376, 36.996988356113434, 38.44287917017937, 38.5184571146965, 37.00588367879391, 37.05305054783821, 36.93910986185074, 35.79806908965111, 37.120196744799614, 35.404972583055496, 36.944706961512566, 36.25673867762089, 37.20587834715843, 36.326400339603424, 36.613961309194565, 35.723650082945824, 35.473684296011925, 36.04997277259827, 36.060912385582924, 39.89432908594608, 44.94160205125809, 52.735751420259476, 51.94952420890331, 52.014500722289085, 47.78927944600582, 51.91991239786148, 53.94110754132271, 56.45224839448929, 56.439139097929, 39.88822661340237, 7.197224199771881, 31.995757520198822, 19.485229030251503, 4.234511777758598, 2.5330447778105736, 0.8352071768604219, 2.414848320186138, 53.65156687796116, 56.62305302917957, 45.46310506761074, 33.66698384284973, 33.27319957315922, 53.20298574864864, 17.54116404801607, 0.23374180047539994, 0.15616839897120371, 0.09336545801488683, 0.09573987787007354, 0.08079792925855145, 0.008951699928729795, 0.07463696063496172, 0.02470927996910177, 0.04861052439082414, 0.007104505957613583, 0.04820235801162198, 0.06940837440197356, 0.06079316794057377, 0.14604660304030403, 0.1906392289674841, 0.12670246447669342, 0.14040712674614042, 0.20007989660371095, 0.22035284782759845, 0.09533155563985929, 0.1989216118818149, 0.14236743561923504, 0.10745323917944916, 0.11770346376579255, 0.14119168074103072, 0.11765828923671506, 0.24594459333457053, 0.20078757894225419, 0.19888288661604747, 1.0637012659572065, 39.70823407173157, 63.08783993124962, 43.26265074312687, 33.621865063905716, 43.380471020936966, 63.7586635351181, 60.12697421014309, 60.19488416612148, 52.01800033450127, 1.9010037928819656, 4.998736744746566, 7.9373176116496325, 3.277526954188943, 15.553792789578438, 26.449645422399044, 52.126587107777596, 54.772632122039795, 53.49984861910343, 54.90605056285858, 54.193482398986816, 53.2096391916275, 49.507665038108826, 45.162016823887825, 50.00870235264301, 50.531045123934746, 52.59455859661102, 50.058456882834435, 50.3088254481554, 51.032701805233955, 54.54207569360733, 52.50862240791321, 51.16003297269344, 49.07049089670181, 47.626063004136086, 45.63610978424549, 42.790678068995476, 42.33485072851181, 40.8516801148653, 39.31900575757027, 40.369413793087006, 43.97062875330448, 40.807040110230446, 41.98091112077236, 44.18100066483021, 42.03411586582661, 43.80526162683964, 41.33940674364567, 40.294345021247864, 40.99430926144123, 41.81292213499546, 41.42008401453495, 43.52561943233013, 40.10802201926708, 41.3738176971674, 42.789880111813545, 42.428093925118446, 43.45134101808071, 42.59778901934624, 40.38937412202358, 41.6972791403532, 42.078318893909454, 42.67254240810871, 42.810759991407394, 42.50978194177151, 40.41237808763981, 40.98188012838364, 40.87665617465973, 47.70431600511074, 51.88242360949516, 58.82488287985325, 50.15222825109959, 61.05935677886009, 58.5392864048481, 50.416257083415985, 54.97014932334423, 57.04826921224594, 53.002139925956726, 50.95325566828251, 54.46533881127834, 54.037420973181725, 57.10445299744606, 52.10555903613567, 52.217535227537155, 45.69741189479828, 40.937399715185165, 40.85291504859924, 40.76120316982269, 41.62895880639553, 40.66143572330475, 41.18523761630058, 39.954141676425934, 42.013482972979546, 41.44829750061035, 39.14884328842163, 40.65859727561474, 41.599669978022575, 39.52370837330818, 41.19304999709129, 39.52179707586765, 39.22203116118908, 38.757202103734016, 41.049227714538574, 38.78978155553341, 38.82148705422878, 41.22388154268265, 40.973167195916176, 40.57818979024887, 37.4361801892519, 38.27175535261631, 37.75819770991802, 38.39402139186859, 38.34033787250519, 40.05558863282204, 38.614964336156845, 39.239597618579865, 39.50080320239067, 39.92343932390213, 38.19404952228069, 39.49220806360245, 38.29648822546005, 38.05571414530277, 44.368957579135895, 46.3180173933506, 54.464989230036736, 55.124687030911446, 53.75594347715378, 48.96284647285938, 50.935879200696945, 53.13997372984886, 58.41039352118969, 57.5020332634449, 45.92011034488678, 10.039663575589657, 38.358269110322, 25.922366715967655, 8.249686025083065, 21.42791658639908, 2.0807880582287908, 4.128312701359391, 58.57840150594711, 60.301305055618286, 49.00643393397331, 40.275729820132256, 37.9669015109539, 63.24328579008579, 22.670603804290295, 0.5455616628751159, 0.25899528991431, 0.15159938164288178, 0.15754729451145977, 0.1448497414821759, 0.10240401519695297, 0.19219894136767834, 0.12451266869902611, 0.1445592351956293, 0.05175058089662343, 0.14125013229204342, 0.25804991251789033, 0.12804800790036097], [0.039704614973743446, 0.06003159083775245, 0.019488840662233997, 0.06569522403879091, 0.05710299075872172, 0.03031868258403847, 0.04416964999109041, 0.01577081624418497, 0.04737201721582096, 0.033872992935357615, 0.04751578606374096, 0.022033483219274785, 0.10775686663691886, 0.01342718531304854, 0.07234668548335321, 0.06913136036018841, 0.16876591049367562, 12.56888385862112, 53.83094385266304, 35.358957052230835, 24.871400110423565, 35.81584073603153, 46.54796965420246, 51.091192066669464, 48.63830208778381, 48.849783539772034, 5.541041269898415, 1.18792075663805, 5.830875467509031, 1.8973920866847038, 0.44985984975937754, 15.625065565109253, 44.72731254994869, 49.79123242199421, 49.79061305522919, 50.20887181162834, 45.19556142389774, 45.58988146483898, 48.83638545870781, 51.6811978071928, 48.27902376651764, 49.89759251475334, 51.4341426640749, 48.257881700992584, 51.081787571311, 49.50485318899155, 48.8850836455822, 47.62036710977554, 47.90899582207203, 44.24001909792423, 41.96555234491825, 40.00641547143459, 37.90410988032818, 35.88601157069206, 35.03066226840019, 36.09522074460983, 36.96921944618225, 35.23866310715675, 35.73925204575062, 36.85682527720928, 37.324587777256966, 37.27123104035854, 39.76470664143562, 37.97055311501026, 40.20525500178337, 38.73045913875103, 38.67810934782028, 40.66186510026455, 40.94982124865055, 39.845820888876915, 39.93189387023449, 39.92500863969326, 37.52448745071888, 38.38482588529587, 36.76387846469879, 37.140195071697235, 39.308362528681755, 39.12571392953396, 37.315513864159584, 39.56865236163139, 39.50543515384197, 38.10603864490986, 37.235721945762634, 37.23986752331257, 44.36578094959259, 48.67779716849327, 55.941430404782295, 53.52318696677685, 34.038189724087715, 51.77117317914963, 57.803421691060066, 56.98748007416725, 51.462686732411385, 60.40230743587017, 54.40169982612133, 52.26562924683094, 49.5024137198925, 53.88442598283291, 50.74329033493996, 51.274650022387505, 41.860313192009926, 37.12014354765415, 37.77466222643852, 37.08937659859657, 39.7523383051157, 40.15253663063049, 37.86651469767094, 38.302826285362244, 37.9546357691288, 38.459932655096054, 38.75493362545967, 37.80695669353008, 37.307283505797386, 36.194893196225166, 36.78530931472778, 36.98902018368244, 35.4339574277401, 37.654413878917694, 35.441587418317795, 37.57997207343578, 35.880456268787384, 36.73580937087536, 34.316008016467094, 34.8890096694231, 34.325347915291786, 34.975192844867706, 36.012206599116325, 37.535871639847755, 35.93993827700615, 35.442548766732216, 36.13324150443077, 41.21686331927776, 45.29881328344345, 45.533956065773964, 42.4807932972908, 45.56793764233589, 41.627651676535606, 41.00686378777027, 37.289154678583145, 39.453488141298294, 42.33346000313759, 49.19037826359272, 50.343889966607094, 50.68025551736355, 45.1837744563818, 50.281060338020325, 47.27772429585457, 51.21131882071495, 14.345630519092083, 1.8489226000383496, 23.047535978257656, 7.7953648287802935, 1.602324501145631, 2.9835056187584996, 0.3855411463882774, 5.9470342844724655, 53.061496540904045, 43.4051126986742, 27.04033512622118, 17.682586759328842, 35.27340464293957, 41.4024605602026, 4.080819049850106, 0.15604079409968108, 0.07618326242663898, 0.048019759997259825, 0.0437639289884828, 0.04942679777741432, 0.023957241319294553, 0.07407602315652184, 0.03411019446502905, 0.01411045284839929, 0.06793213135097176, 0.018022661133727524, 0.03697988657222595, 0.026513732263993006, 0.07920109463157132, 0.07324034260818735, 0.014824897079961374, 0.012207383970235242, 0.09951785483281128, 0.012567804278660333, 0.05116773521876894, 0.04972322640242055, 0.052923140829079784, 0.017425545811420307, 0.027711731163435616, 0.02814821789797861, 0.05043336896051187, 0.0792453192116227, 0.06922445536474697, 0.09091006242670119, 0.08330897850100882, 17.41008248180151, 59.509761929512024, 37.743484899401665, 25.75778614729643, 45.66249556839466, 55.28965137898922, 56.583402156829834, 53.99552442133427, 50.967504903674126, 4.934938168153167, 0.7177741220220923, 4.884634567424655, 3.3764439588412642, 1.1702045635320246, 19.844171069562435, 48.99891033768654, 50.2363633364439, 50.50932928919792, 49.77497309446335, 46.82123199105263, 46.45156882703304, 49.94869977235794, 51.8040756136179, 52.13084667921066, 51.001144498586655, 51.64288066327572, 50.24233281612396, 50.63720762729645, 51.13974966108799, 51.70307323336601, 49.339934438467026, 48.4383150190115, 46.86287395656109, 43.91909211874008, 41.39451138675213, 40.60854256153107, 38.39979328215122, 36.66605271399021, 37.71433286368847, 39.31278549134731, 37.59860247373581, 37.887858152389526, 39.13474224507809, 40.216084420681, 39.46345120668411, 41.64530552923679, 39.728023409843445, 42.0637808740139, 40.17679072916508, 38.96082177758217, 41.09316475689411, 41.41534186899662, 39.77028474211693, 41.64287365972996, 41.95759557187557, 40.687810108065605, 41.12041309475899, 39.71756637096405, 38.88060428202152, 40.34442253410816, 40.283918380737305, 40.299972519278526, 41.81689292192459, 40.12761376798153, 39.30791795253754, 40.28772197663784, 38.39744880795479, 46.60772144794464, 49.96696539223194, 56.97391480207443, 52.561306580901146, 39.58053432404995, 55.57272098958492, 59.464905336499214, 53.653766959905624, 55.9794207662344, 56.472045332193375, 52.57708713412285, 53.35857219994068, 51.191240698099136, 53.765484765172005, 51.78263336420059, 51.6258005797863, 44.62818346917629, 39.595186337828636, 39.75595951080322, 40.91948747634888, 41.299212500452995, 40.0330064445734, 39.64414291083813, 37.53055952489376, 39.6156520396471, 39.543357118964195, 39.267757907509804, 39.49278563261032, 39.051792696118355, 37.68113784492016, 38.13052833080292, 37.48783841729164, 37.25497551262379, 38.53175640106201, 37.433767318725586, 38.13430912792683, 36.40620745718479, 38.49335566163063, 36.70667253434658, 35.483058393001556, 35.24912774562836, 36.26144662499428, 36.92221596837044, 37.55862481892109, 37.38953769207001, 36.46587185561657, 38.89239884912968, 42.642816603183746, 48.23414817452431, 46.60266011953354, 45.30724123120308, 47.4941910803318, 43.134533017873764, 42.531345784664154, 38.1185931712389, 40.977609157562256, 45.048824697732925, 50.90481586754322, 51.82829171419144, 49.53468158841133, 46.549542769789696, 49.272814840078354, 47.802821919322014, 54.19590286910534, 18.08244690299034, 2.6155837113037705, 30.844396501779556, 9.836226291954517, 1.001277503091842, 1.285113247577101, 0.5507566966116428, 6.844836808741093, 58.42945709824562, 47.77771666646004, 38.275695741176605, 23.513810858130455, 36.71300299465656, 48.74121956527233, 5.981145529076457, 0.19241590081946924, 0.0983210674894508, 0.03780962622840889, 0.04355917415523436, 0.02895305664424086, 0.07048342726193368, 0.041006401370395906, 0.0077043816054356284, 0.011043590657209279, 0.013831158557877643, 0.046691924217157066, 0.021320578016457148, 0.08178390955436043, 0.1243912978679873, 0.15866029338212684, 0.11709568192600273, 0.14062090980587527, 0.18181804683990777, 0.13417912734439597, 0.11158292734762654, 0.1284748615580611, 0.10952204262139276, 0.17497163062216714, 0.09474721824517474, 0.15105513506568968, 0.17761581373633817, 0.16171285067684948, 0.21303822548361495, 0.1773218045127578, 0.2561165584484115, 20.4637848213315, 69.8637655377388, 47.76988908648491, 33.71295377612114, 50.07887698709965, 58.39824177324772, 60.08140705525875, 60.32976932823658, 56.86196520924568, 6.565601192414761, 2.2507090028375387, 14.186083730310202, 4.829814434051514, 2.2573515214025974, 22.798115462064743, 48.32098111510277, 48.62691409885883, 51.304071843624115, 50.35017102956772, 46.154200583696365, 46.91183052957058, 50.10008364915848, 51.561671420931816, 53.196932673454285, 51.643709018826485, 55.8025174587965, 50.83958476781845, 52.1849861741066, 53.05346377193928, 52.82848544418812, 51.28043331205845, 51.37011229991913, 48.675038516521454, 47.360214069485664, 43.29701229929924, 43.59621204435825, 39.38074864447117, 39.3294969946146, 40.04236914217472, 43.53946968913078, 38.06982658803463, 41.2537707388401, 41.3831651955843, 41.290301978588104, 40.93970999121666, 44.84031468629837, 40.61057165265083, 43.052563816308975, 40.79290106892586, 40.47206148505211, 42.200885117053986, 45.51787152886391, 42.122096344828606, 43.634570986032486, 44.85506549477577, 43.36287796497345, 41.34778529405594, 40.93506284058094, 39.92276296019554, 43.6983847618103, 42.20196805894375, 42.642995193600655, 43.98859038949013, 44.02510643005371, 41.83371841907501, 43.84741276502609, 41.50532864034176, 49.90053355693817, 51.006916388869286, 59.91523057222366, 52.36194647848606, 44.02822986245155, 57.0978831499815, 52.68787018954754, 56.10079765319824, 56.843615993857384, 58.8291272521019, 52.78978452086449, 57.128843888640404, 50.8674980700016, 58.17780040204525, 53.16827841103077, 55.144871547818184, 46.81672543287277, 42.396544218063354, 41.776189506053925, 42.260344326496124, 43.729634284973145, 43.43076512217522, 42.44865082204342, 40.19544392824173, 41.20474196970463, 41.40527620911598, 42.26377934217453, 39.66999292373657, 40.6632824242115, 39.130737259984016, 40.30571021139622, 40.04608154296875, 38.533344715833664, 41.17735683917999, 39.70947280526161, 41.822642013430595, 39.158262982964516, 41.373867094516754, 38.54561805725098, 37.65957400202751, 38.9124009758234, 39.669464752078056, 38.420711159706116, 39.98094543814659, 38.67312781512737, 38.40733587741852, 40.265686959028244, 44.66749615967274, 50.85363261401653, 49.76486183702946, 48.36935251951218, 49.65989626944065, 45.45630723237991, 46.31547912955284, 42.7853811532259, 45.52336983382702, 47.319225668907166, 52.66656093299389, 55.17525091767311, 51.667305752635, 48.40165838599205, 50.55338032543659, 46.54975935816765, 55.388871654868126, 24.777148067951202, 4.772940510883927, 32.02082857489586, 13.064758200198412, 7.21484100446105, 10.051850471645594, 1.3347584148868918, 9.925114922225475, 62.2555135935545, 52.897512540221214, 38.39380860328674, 28.440060317516327, 44.76675823330879, 56.7776021361351, 8.226556666195393, 0.34746632853057235, 0.2087726426543668, 0.12135482291341759, 0.12889695062767714, 0.14550915453583002, 0.15956072631524876, 0.10583434050204232, 0.1227180814021267, 0.19822333997581154, 0.11199024025700055, 0.09843063075095415, 0.15011364652309567, 0.31830604013521224], [0.09243176944437437, 0.016401103712269105, 0.014173244107951177, 0.033034124862751924, 0.01267354919036734, 0.07352219545282423, 0.08606603485532105, 0.04105618463654537, 0.03291516230092384, 0.04402171769470442, 0.03615167945099529, 0.08065991205512546, 0.039792069655959494, 0.03547124135366175, 0.0465555842674803, 0.044350834214128554, 0.05796889527118765, 2.750936010852456, 40.11614218354225, 37.2394647449255, 25.294585302472115, 18.91040537506342, 33.91944229602814, 50.32058201730251, 50.45473761856556, 52.38699093461037, 12.414434496313334, 0.35778048913925886, 3.90016985591501, 3.0750640807673335, 0.881322689820081, 5.991893727332354, 47.15916305780411, 49.69143457710743, 48.25349673628807, 50.31070254743099, 54.14437383413315, 47.96707570552826, 49.78080578148365, 42.885973155498505, 46.62688381969929, 48.49694587290287, 50.905651822686195, 48.68527136743069, 48.51433753967285, 48.70822213590145, 47.71816626191139, 50.34874610602856, 48.08635510504246, 43.754150569438934, 43.52216921746731, 39.31444600224495, 39.12067539989948, 36.73973076045513, 35.41579820215702, 35.270452201366425, 36.019118428230286, 35.71802258491516, 37.10030481219292, 36.38883478939533, 38.2889798283577, 37.46108025312424, 39.96785134077072, 40.620150938630104, 42.14906729757786, 39.03846301138401, 40.47907590866089, 42.094319835305214, 38.4850113093853, 40.09891390800476, 37.94968083500862, 40.1588024944067, 37.32336804270744, 40.049121379852295, 37.40586541593075, 38.52954491972923, 37.73797519505024, 38.881824016571045, 41.249545365571976, 41.17365583777428, 40.74676774442196, 39.04813349246979, 38.53572338819504, 37.32559472322464, 40.16316086053848, 51.74253411591053, 50.62831990420818, 58.067484721541405, 42.006080970168114, 38.761856853961945, 57.069092094898224, 62.75610253214836, 43.38669128715992, 52.5210477411747, 61.032226234674454, 50.27993939816952, 51.08094781637192, 51.352975219488144, 49.45655018091202, 50.5433564633131, 42.85611055791378, 36.17921903729439, 37.572281286120415, 37.81195342540741, 36.68228544294834, 39.57890421152115, 39.8612442612648, 38.246505707502365, 36.11793972551823, 39.81349602341652, 39.9129518866539, 38.764851093292236, 37.061603888869286, 36.72144614160061, 37.79229708015919, 36.593579202890396, 36.954320445656776, 36.641840413212776, 35.78833021223545, 36.8525543063879, 34.95988346636295, 36.01200520992279, 34.79432255029678, 34.77373905479908, 35.012708231806755, 36.030985191464424, 33.52676376700401, 35.93898832798004, 34.452302902936935, 38.082350715994835, 41.98712758719921, 47.09476791322231, 47.16712363064289, 50.13272009789944, 47.16673985123634, 48.22880186140537, 49.46643725037575, 47.14497081935406, 44.28530506789684, 43.38094599545002, 40.66357120871544, 43.77076707780361, 48.762696012854576, 51.58475138247013, 51.858731880784035, 45.919300988316536, 44.24683213233948, 29.12208192050457, 0.7827030192129314, 1.418211436830461, 2.036491222679615, 2.5111190043389797, 0.7512112590484321, 0.4229210171615705, 0.4279168287757784, 8.726370446383953, 57.25971646606922, 36.64879024028778, 26.321755684912205, 21.61693174391985, 36.68369896709919, 32.54216820001602, 1.0813673492521048, 0.055034495308063924, 0.06924833767698146, 0.030782799476583023, 0.06001529698551167, 0.021576839753834065, 0.015857144717301708, 0.008665364512125961, 0.0823989867058117, 0.06673481708276086, 0.004447520332178101, 0.025836385211732704, 0.019424038182478398, 0.06443238555220887, 0.03898220100381877, 0.060807268746430054, 0.03846060477371793, 0.06893845391459763, 0.020644240285037085, 0.07404220348689705, 0.047933600362739526, 0.07170722878072411, 0.034164764583692886, 0.028592365451913793, 0.04977203374437522, 0.08051709315623157, 0.01769616068486357, 0.10542137984884903, 0.04591830205754377, 0.21731100714532658, 0.18838425778085366, 5.868591293692589, 49.14410434663296, 42.182482704520226, 27.521885186433792, 32.11444795131683, 43.0273711681366, 54.667731150984764, 52.766020596027374, 57.77113102376461, 12.754236962646246, 0.24669211416039616, 4.4936540722846985, 3.407565951347351, 1.2009300710633397, 9.204439893364906, 49.0975758433342, 49.389704167842865, 50.05511686205864, 50.05104348063469, 53.52686896920204, 47.72404454648495, 49.25426423549652, 44.7515894472599, 48.74843917787075, 50.79249769449234, 50.084200501441956, 49.65701602399349, 49.58244502544403, 50.514109432697296, 51.60107150673866, 52.79434807598591, 51.36333726346493, 46.35161519050598, 43.64013768732548, 43.004112616181374, 41.353648379445076, 37.74054005742073, 38.001855835318565, 35.798179283738136, 38.81308950483799, 39.37047779560089, 37.898987755179405, 39.561622738838196, 40.03858454525471, 39.70933981239796, 41.99414201080799, 43.379133492708206, 44.68930318951607, 42.28620573878288, 42.39249363541603, 42.0511731505394, 40.75615704059601, 41.61191292107105, 42.46402859687805, 40.801629200577736, 40.664707347750664, 42.66719229519367, 40.30974939465523, 39.760625660419464, 40.45530058443546, 41.59441106021404, 43.141007870435715, 40.38840137422085, 41.68649151921272, 40.26996552944183, 38.20554010570049, 40.05379132926464, 42.45444171130657, 52.763387337327, 52.27229788899422, 56.1601884663105, 42.747869566082954, 41.60957984626293, 59.872631058096886, 62.11695782840252, 49.619998410344124, 55.58003559708595, 57.19327323138714, 52.039256393909454, 52.47331090271473, 54.14787344634533, 51.377654895186424, 51.83690965175629, 45.41463866829872, 38.62610153853893, 37.82019518315792, 38.83524611592293, 39.54337991774082, 40.99799886345863, 41.61892354488373, 38.951728865504265, 38.27026583254337, 41.778024807572365, 40.23195996880531, 40.15528008341789, 39.10741411149502, 37.823079228401184, 37.94855609536171, 38.63359093666077, 37.99392186105251, 38.92665781080723, 37.922405898571014, 37.90571719408035, 36.92825764417648, 39.11755956709385, 36.564001590013504, 37.085493206977844, 35.844810381531715, 37.302214577794075, 35.79957380890846, 37.50556446611881, 36.38061203062534, 39.99979242682457, 42.54057168960571, 48.34643974900246, 48.87303069233894, 50.643705278635025, 50.193756222724915, 51.33396103978157, 50.24758033454418, 49.94701266288757, 47.220259979367256, 44.33425784111023, 41.285662427544594, 46.837145537137985, 52.45686158537865, 52.84515514969826, 49.49859492480755, 49.46840934455395, 41.99337065219879, 33.3892073482275, 2.2297065798193216, 2.6931059639900923, 2.998760612681508, 2.587507492862642, 0.7966438180301338, 0.23311904951697215, 0.5865656782407314, 9.727411530911922, 61.12919703125954, 42.78137616813183, 32.16301694512367, 22.838737182319164, 39.73585858941078, 38.885323628783226, 1.7970336531288922, 0.01316880845479318, 0.029006485710851848, 0.007079124970914563, 0.003051572789445345, 0.03334643544803839, 0.026078447808686178, 0.05798632832011208, 0.03816890362941194, 0.07682805517106317, 0.01248717178896186, 0.023072133735695388, 0.022856051873532124, 0.025002706606755964, 0.14870962186250836, 0.16608960722805932, 0.16322888026479632, 0.17744801414664835, 0.0980706000700593, 0.14509220112813637, 0.3194995323428884, 0.20303131401306018, 0.11331297006108798, 0.1489607646362856, 0.13205020251916721, 0.23591826728079468, 0.1100236750789918, 0.13209811557317153, 0.1678432576591149, 0.26535840472206473, 0.2830584190087393, 6.13845138810575, 54.902322962880135, 52.1083252876997, 32.89568603038788, 27.55439054220915, 45.299896225333214, 59.35765989124775, 59.90350440144539, 62.053353041410446, 15.358204934746027, 0.761458418564871, 9.848473984748125, 8.470060899853706, 1.6165797924622893, 11.585907004773617, 51.75176382064819, 49.301894679665565, 51.1735450476408, 51.20530754327774, 54.9107851088047, 47.62130945920944, 50.82661606371403, 46.16047404706478, 49.47329208254814, 48.834546357393265, 52.48187944293022, 50.665443912148476, 50.28983786702156, 49.94839958846569, 54.15272198617458, 54.93721269071102, 54.00497451424599, 48.4779316931963, 47.55286753177643, 44.732202887535095, 43.604180216789246, 40.646236538887024, 40.02349175512791, 37.27744750678539, 41.21469363570213, 41.46287351846695, 41.07336401939392, 42.45727255940437, 43.19583512842655, 41.87937676906586, 44.12695616483688, 43.72947849333286, 45.799941793084145, 43.69433417916298, 43.433884754776955, 43.530836552381516, 42.486622184515, 43.03945451974869, 43.471248149871826, 42.82855063676834, 41.48536831140518, 43.85155074298382, 42.62441039085388, 42.36025236546993, 42.373555451631546, 43.99536542594433, 45.3894080221653, 42.340497225522995, 44.08078484237194, 44.219424203038216, 42.2635817527771, 44.33850981295109, 44.01901915669441, 54.60416816174984, 56.71315759420395, 60.08024051785469, 44.760868549346924, 49.36626322567463, 53.31928230822086, 61.47630840539932, 50.93397170305252, 60.735937133431435, 58.006019219756126, 53.22749063372612, 55.45939967036247, 55.52520073950291, 53.460019156336784, 54.344482496380806, 47.25597806274891, 40.38804039359093, 41.60685159265995, 41.61056399345398, 40.452405139803886, 42.83098630607128, 44.240338280797005, 41.721806824207306, 39.41018186509609, 44.00364138185978, 44.00074973702431, 41.783572509884834, 41.18217118084431, 39.93060953915119, 40.92616371810436, 41.62964276969433, 40.902969762682915, 40.67513018846512, 39.79436784982681, 41.060041934251785, 39.220826625823975, 41.76782615482807, 38.7266631424427, 40.0228001922369, 38.613531813025475, 40.42033486068249, 37.266910672187805, 39.62562270462513, 37.88647502660751, 41.777948811650276, 47.29913614690304, 51.7020358890295, 50.417970791459084, 53.67769047617912, 51.49086222052574, 54.008018150925636, 52.50119760632515, 52.5932514667511, 49.14980784058571, 48.732012659311295, 44.10765700042248, 49.46575328707695, 55.57483747601509, 55.45707419514656, 50.46355314552784, 49.82080243527889, 43.760488629341125, 37.56821170449257, 5.9015673492103815, 4.53658084385097, 8.20639019832015, 7.614737721160054, 4.343561176210642, 1.2254208256490529, 0.7799403893295676, 11.103416495025158, 67.69353479146957, 45.98472587764263, 36.36725194752216, 30.3642238676548, 47.0807770639658, 48.01662504673004, 2.7787498058751225, 0.2036784667870961, 0.20076930726645514, 0.16933084814809263, 0.1251177120138891, 0.12262974356417544, 0.09981020164559595, 0.10622439105645753, 0.2115480523207225, 0.35430106334388256, 0.07980954440427013, 0.16297974128974602, 0.12925796094350517, 0.1693215119303204], [0.03150333395751659, 0.07859619974624366, 0.021371964321588166, 0.021860896777070593, 0.042085328241228126, 0.051482509734341875, 0.09534458033158444, 0.03755581914447248, 0.03661388160253409, 0.03808472181844991, 0.004895958891211194, 0.0638771106605418, 0.07082880794769153, 0.04294670565286651, 0.11570163915166631, 0.05563323407841381, 0.02997561368829338, 0.11512049299199134, 14.120237063616514, 47.866571098566055, 25.51781002432108, 31.962589100003242, 30.921425968408585, 44.994628205895424, 50.38620449602604, 51.57505430281162, 18.646089658141136, 0.323553261696361, 3.847206635400653, 1.3837635540403426, 0.2374181625782512, 3.0038300156593323, 36.682787016034126, 51.948847845196724, 48.90918955206871, 51.2429179251194, 49.57241736352444, 50.87534464895725, 50.49392491579056, 54.69849810004234, 51.69940643012524, 48.93503576517105, 52.58584186434746, 49.792429357767105, 50.523669719696045, 49.743943959474564, 46.129357516765594, 48.913190737366676, 50.46426750719547, 43.522921577095985, 44.007547572255135, 40.59507608413696, 39.12529215216637, 34.92207929491997, 37.25794315338135, 37.130471393465996, 38.07519190013409, 35.76794810593128, 38.165486454963684, 37.24053628742695, 36.69260948896408, 37.707949206233025, 38.10858830809593, 39.24775578081608, 38.03938262164593, 38.46730425953865, 39.7536264359951, 39.27163369953632, 40.04268452525139, 38.02552476525307, 38.545203879475594, 39.005393385887146, 42.118501737713814, 37.5815299898386, 36.63559354841709, 36.710920706391335, 38.86784836649895, 40.745263025164604, 44.58669729530811, 43.78158889710903, 45.67898668348789, 40.04876419901848, 40.70395164191723, 40.18529087305069, 38.51795554161072, 47.89364844560623, 52.170543149113655, 54.73934970796108, 52.25020207464695, 33.6861652135849, 46.41823701560497, 53.78919169306755, 49.2645388841629, 42.41020828485489, 54.42402742803097, 59.699865728616714, 48.35568465292454, 49.81084316968918, 49.84221808612347, 50.018034651875496, 47.598320692777634, 38.05200174450874, 37.571536526083946, 39.398265704512596, 36.34466975927353, 37.016454711556435, 37.741847187280655, 40.68704254925251, 39.17985342442989, 39.511362835764885, 38.784625232219696, 39.29926201701164, 37.33123742043972, 35.54626040160656, 37.14278653264046, 35.420646741986275, 38.52216571569443, 36.06664627790451, 37.87057667970657, 36.637698635458946, 35.5278579890728, 36.22991971671581, 37.10738763213158, 35.47157160937786, 37.56847009062767, 37.068884298205376, 34.64842937886715, 36.12047418951988, 32.415061220526695, 36.46576166152954, 38.696222975850105, 42.8396650403738, 46.1862176656723, 49.23868887126446, 45.53191177546978, 51.145620346069336, 47.06173628568649, 46.98469541966915, 44.951074942946434, 49.112414047122, 49.01648059487343, 49.74270902574062, 49.94179554283619, 51.305314376950264, 49.67385672032833, 50.590325742959976, 44.82818193733692, 8.29955929890275, 1.0080841253511608, 6.526255728676915, 1.2360040890052915, 1.2973778019659221, 0.5351156671531498, 0.42415443691425025, 0.332536306232214, 12.981274779886007, 55.825536623597145, 30.379474349319935, 25.286128856241703, 19.526943191885948, 45.6961465626955, 16.335291154682636, 0.18605615536216646, 0.035108976808260195, 0.07378758004051633, 0.09496149112237617, 0.05466419330332428, 0.05348815640900284, 0.07637416507350281, 0.05716860032407567, 0.041925009500118904, 0.023299152999243233, 0.11112249150755815, 0.008764705617068103, 0.05608123894489836, 0.01904568573081633, 0.00871836869919207, 0.07093321328284219, 0.08972278941655532, 0.06960060549317859, 0.03436120736296289, 0.047018925615702756, 0.03666357581096236, 0.024196706399379764, 0.07061250158585608, 0.021047061345598195, 0.029910636803833768, 0.019257260901213158, 0.05171182594494894, 0.016665438160998747, 0.014539346484525595, 0.03689177880005445, 0.015132926400838187, 0.06819476999226026, 22.554143853485584, 54.36387285590172, 23.49469978362322, 25.30312154442072, 40.12558847665787, 52.61092431843281, 55.72361849248409, 56.97321563959122, 20.884084068238735, 0.4098406940465793, 1.867973709013313, 2.4299266235902905, 0.423791971988976, 4.678318938240409, 42.25494481623173, 53.07101123034954, 50.76745703816414, 54.03476871550083, 50.31702160835266, 51.07597008347511, 52.88750387728214, 53.59443314373493, 52.63731770217419, 50.349988639354706, 53.77545163035393, 49.160283878445625, 49.91282969713211, 50.209156796336174, 49.138218462467194, 50.05697876214981, 54.03311960399151, 48.134965896606445, 46.15428797900677, 42.10585221648216, 41.62260174751282, 38.254952654242516, 38.30487437546253, 39.71506990492344, 39.091975539922714, 39.616032019257545, 40.17949998378754, 39.152449294924736, 39.26056869328022, 39.39825810492039, 40.683995112776756, 40.48455521464348, 41.16387516260147, 40.82928791642189, 41.936510503292084, 40.86775325238705, 42.29572042822838, 39.788675755262375, 41.3997171074152, 39.05241206288338, 42.460506185889244, 41.33821360766888, 39.295363426208496, 38.242895901203156, 40.328379794955254, 42.639761567115784, 47.2269856184721, 46.775763630867004, 44.78092387318611, 44.07058618962765, 41.908487007021904, 42.4092735350132, 39.27440755069256, 49.14250083267689, 52.49500013887882, 55.19707694649696, 51.52205474674702, 35.51195204257965, 53.688455298542976, 57.0421477407217, 49.43878993391991, 44.59956340491772, 54.98503312468529, 57.67553195357323, 51.14188514649868, 53.38847279548645, 52.27609768509865, 51.626541540026665, 47.94874168932438, 38.65774244070053, 39.86212581396103, 40.747569501399994, 39.77556645870209, 39.012088626623154, 39.10786248743534, 40.99940858781338, 41.01346403360367, 41.14419601857662, 41.50049149990082, 40.57891935110092, 38.10746356844902, 37.50502869486809, 38.7428692728281, 37.894097417593, 38.62123779952526, 37.85008057951927, 38.205969482660294, 37.71750569343567, 36.655679270625114, 38.27334746718407, 37.368817403912544, 39.10785868763924, 39.05298203229904, 38.00441309809685, 36.855841130018234, 37.38784298300743, 35.0912082195282, 37.574792951345444, 40.46641878783703, 45.04280962049961, 47.54608869552612, 50.38045920431614, 48.17194551229477, 52.22569338977337, 49.62844155728817, 49.449163377285004, 46.66550114750862, 50.95378004014492, 48.90540115535259, 51.33180275559425, 51.57441593706608, 53.508512154221535, 47.798699140548706, 51.83746822178364, 46.11404813826084, 10.335382707417011, 2.200185488909483, 12.345399800688028, 0.46272827486973256, 0.832160571590066, 0.6935672834515572, 0.278214777354151, 0.4177101014647633, 14.73788347095251, 60.98399922251701, 39.73982937633991, 34.58438761532307, 20.192050002515316, 51.62738889455795, 23.489989936351776, 0.20611244399333373, 0.04762442164064851, 0.08011863406863995, 0.14723187225172296, 0.1045408884237986, 0.042627660077414475, 0.05907347447646316, 0.07915929687442258, 0.017527010386402253, 0.034596961704664864, 0.035605039447546005, 0.03658530520624481, 0.06322888177237473, 0.082391350006219, 0.1517064735526219, 0.1257931554573588, 0.12241063188412227, 0.12070839002262801, 0.1391599327325821, 0.20119519613217562, 0.10758016869658604, 0.15990417741704732, 0.14449156617047265, 0.1647912643966265, 0.13395968911936507, 0.2086087319185026, 0.11333740156260319, 0.21922224521404132, 0.24997721600811929, 0.14870246755890548, 0.11670168314594775, 0.2457642217632383, 23.270842395722866, 63.19872558116913, 34.13817755877972, 41.033519357442856, 42.997554168105125, 55.2334675937891, 59.00190398097038, 62.24924772977829, 26.87044434249401, 0.4218047083122656, 11.243537776172161, 6.260043438524008, 0.6928327947389334, 5.874658143147826, 43.87658379971981, 53.894765228033066, 51.56012870371342, 54.58894997835159, 49.7421732544899, 50.87610840797424, 53.51222075521946, 55.14264486730099, 52.90624067187309, 50.284267365932465, 53.890828639268875, 50.34841172397137, 52.15115278959274, 51.39911234378815, 49.50746364891529, 55.22591359913349, 56.59174270927906, 49.31372344493866, 48.42409998178482, 47.20756486058235, 43.706284537911415, 40.618349835276604, 40.184378921985626, 42.195242419838905, 41.99958711862564, 41.89093194901943, 42.86211423575878, 42.16554321348667, 40.906632766127586, 41.454681158065796, 42.924708276987076, 43.324895203113556, 43.051363080739975, 42.732529789209366, 43.17726172506809, 43.302822187542915, 43.97254005074501, 40.80149620771408, 41.883628740906715, 42.47011587023735, 45.43583393096924, 41.31706774234772, 39.96237203478813, 39.72499117255211, 42.49340482056141, 45.196788758039474, 48.89788515865803, 50.97247123718262, 47.86174535751343, 45.90927712619305, 45.90135835111141, 45.30267767608166, 41.39788180589676, 51.812735348939896, 52.939652279019356, 59.17305439710617, 53.711451664566994, 42.7193520963192, 51.65750227868557, 51.62445545196533, 52.70958602428436, 48.474071100354195, 60.19872575998306, 55.105254873633385, 52.602302581071854, 52.44852863252163, 53.65291200578213, 52.395924255251884, 53.46846230328083, 40.714135095477104, 41.348640248179436, 42.6763916015625, 41.16511769592762, 39.860674291849136, 42.12812282145023, 44.10120114684105, 43.45610596239567, 43.57167296111584, 43.18098932504654, 41.90706588327885, 40.55089585483074, 38.5927165299654, 41.052856519818306, 38.980877101421356, 41.96210213005543, 40.38269028067589, 42.622715681791306, 40.83655312657356, 39.01995800435543, 40.63689284026623, 41.75811007618904, 40.6978377699852, 42.5185252726078, 40.424963012337685, 37.94345676898956, 39.121792539954185, 35.99317342042923, 39.28452640771866, 42.28304050862789, 48.03254619240761, 49.558464512228966, 52.43252769112587, 49.02781918644905, 53.55669356882572, 50.25190070271492, 50.226658657193184, 48.02909977734089, 52.39257663488388, 53.881268352270126, 54.16338421404362, 53.16409483551979, 55.15204556286335, 49.83936443924904, 50.91078154742718, 47.66032576560974, 14.934625513851643, 2.3842920223250985, 17.700305208563805, 5.863487692549825, 6.187663022428751, 2.1071562683209777, 0.6391984946094453, 0.5010112503077835, 17.126910276710987, 66.81366920471191, 42.97630190849304, 35.22765129804611, 26.46788064390421, 59.602134972810745, 30.708694383502007, 0.38359532423783094, 0.12415411489200778, 0.1838883716845885, 0.3090103139402345, 0.22024373727617785, 0.1606452267151326, 0.2541856386233121, 0.19122815283481032, 0.15893070230958983, 0.14617572189308703, 0.17758792382664979, 0.1224171108333394, 0.173467401182279, 0.13623181876027957], [0.03698749358591158, 0.06110740068834275, 0.088642244663788, 0.08269316662335768, 0.017174313979921862, 0.09928303930792026, 0.056769788716337644, 0.05928549864620436, 0.04041178151965141, 0.10196519069722854, 0.00989583793852944, 0.03549703469616361, 0.015017260830063606, 0.0438719114754349, 0.042888447060249746, 0.008170570945367217, 0.02132081179297529, 0.09589051158400252, 2.973007494583726, 41.68536297976971, 41.84592716395855, 28.04087843745947, 28.63055359572172, 44.25839111208916, 44.951074942946434, 48.34723770618439, 26.31923831999302, 0.23070864292094484, 1.248080434743315, 1.7226411262527108, 1.2097695842385292, 0.7198596163652837, 22.05791138112545, 52.1984488517046, 52.788899168372154, 50.662236884236336, 50.778145864605904, 48.006475791335106, 51.72457627952099, 47.95181192457676, 52.949402555823326, 48.42592008411884, 46.21781297028065, 49.99327518045902, 49.46011818945408, 49.30645063519478, 49.65353161096573, 50.56104451417923, 48.29162769019604, 45.510169342160225, 42.52618186175823, 39.21520672738552, 37.50852070748806, 36.09538413584232, 35.967752784490585, 37.77345769107342, 38.03256198763847, 35.35891905426979, 38.15923199057579, 38.00687536597252, 36.58292457461357, 36.61634378135204, 38.208663538098335, 39.06972013413906, 39.35462884604931, 36.5069704502821, 38.57649900019169, 39.27747018635273, 40.73998510837555, 38.647900968790054, 38.150256872177124, 38.981887847185135, 39.057366997003555, 37.24568121135235, 37.360697239637375, 35.86455412209034, 41.19773894548416, 48.03591661155224, 46.78900212049484, 45.46097718179226, 46.60321868956089, 48.64128492772579, 49.26110006868839, 40.08581221103668, 40.300990864634514, 42.8148789703846, 51.0213366150856, 52.02016621828079, 56.17751933634281, 40.57652547955513, 39.88144017755985, 45.66925160586834, 50.57248190045357, 47.4346786737442, 40.59799052774906, 55.05727104842663, 49.96660441160202, 48.629684150218964, 48.04727040231228, 49.59409520030022, 46.6202037781477, 37.18245640397072, 35.96924230456352, 37.119391188025475, 35.96643805503845, 36.26910321414471, 38.30445259809494, 38.94288294017315, 37.85437434911728, 38.735934644937515, 38.019992262125015, 38.09762589633465, 37.18646138906479, 36.34890653192997, 36.05847291648388, 35.678014531731606, 37.473820969462395, 36.17354974150658, 34.83190253376961, 37.380110397934914, 36.01203180849552, 37.466430366039276, 37.95441918075085, 37.85174109041691, 37.88250423967838, 37.637804970145226, 34.49329890310764, 35.16105607151985, 34.193153008818626, 34.73584748804569, 36.6245361417532, 38.85111026465893, 42.238161116838455, 45.17362140119076, 47.65221320092678, 47.74364769458771, 46.471525356173515, 48.9818150550127, 47.602762654423714, 51.26879073679447, 49.876887425780296, 50.843361765146255, 46.4119977504015, 50.69437175989151, 48.54817472398281, 50.70913776755333, 29.987039007246494, 1.1353806196711957, 0.917047600960359, 4.605931397527456, 0.8673700760118663, 0.7187006191816181, 0.19564902264392003, 0.34568075090646744, 0.23460576427169144, 20.258704125881195, 52.83260442316532, 24.044359289109707, 19.978347569704056, 23.34932718425989, 45.96070736646652, 5.227632662281394, 0.043381752620916814, 0.037487407971639186, 0.07154419377911836, 0.041217071120627224, 0.026743105991045013, 0.03124692193523515, 0.047460351343033835, 0.005647451598633779, 0.027123033651150763, 0.030172449805832002, 0.047552889736834913, 0.07685633841902018, 0.06129081506514922, 0.05170231161173433, 0.03236389129597228, 0.03702705376781523, 0.0978153309551999, 0.048765603569336236, 0.018692065350478515, 0.07938837559777312, 0.02495845234079752, 0.009181427103612805, 0.03251413167163264, 0.030677731774630956, 0.04364875137980562, 0.02290051765157841, 0.03155266080284491, 0.03627978156146128, 0.10941668733721599, 0.02695728424441768, 0.019703972575371154, 0.052438407074077986, 5.749658150598407, 49.7087312489748, 42.351824417710304, 28.409696146845818, 33.582050800323486, 49.117631167173386, 51.14613711833954, 54.945902824401855, 28.37003007531166, 0.5480121751315892, 0.7082594325765967, 1.6885070828720927, 0.305773718864657, 1.2375052459537983, 27.52635184675455, 52.1655236184597, 52.24246948957443, 50.4016088694334, 51.73453934490681, 49.414288848638535, 52.34727166593075, 51.13300122320652, 52.07629680633545, 49.773650765419006, 49.487298130989075, 50.7037952542305, 50.74575260281563, 49.793364107608795, 51.65717549622059, 51.58344425261021, 50.1827672123909, 47.20753826200962, 44.58901137113571, 42.16516703367233, 39.51768949627876, 37.9915963858366, 37.412028685212135, 39.30594205856323, 40.65947502851486, 36.97642385959625, 41.77143216133118, 40.21714076399803, 37.53017954528332, 37.98448696732521, 40.145753994584084, 41.38874709606171, 40.83277612924576, 37.464610263705254, 39.78463277220726, 39.497041404247284, 42.21643008291721, 39.26536403596401, 39.06342387199402, 40.61940997838974, 41.19424693286419, 40.06279304623604, 39.200915694236755, 38.06751251220703, 42.1132618188858, 47.994092255830765, 50.461155474185944, 48.340477868914604, 48.0669229477644, 49.48501065373421, 47.18503586947918, 44.061854258179665, 40.346166640520096, 43.994282484054565, 52.49425157904625, 53.888104185462, 57.80436784029007, 41.313267946243286, 46.257805824279785, 51.54633544385433, 51.35394796729088, 47.15288199484348, 42.66311891376972, 54.92405019700527, 51.15882083773613, 51.06417551636696, 51.03446491062641, 50.562454238533974, 48.18222776055336, 39.626424461603165, 37.794421166181564, 38.02031144499779, 38.93299587070942, 40.0584726780653, 40.93286655843258, 40.931620225310326, 40.083893314003944, 39.35847423970699, 40.69838494062424, 38.879627734422684, 38.6101233959198, 37.269456535577774, 37.838411405682564, 37.20080941915512, 38.108101934194565, 37.57349342107773, 36.4451439678669, 38.242740109562874, 38.085721135139465, 39.886091127991676, 40.371917858719826, 40.52655056118965, 40.97047694027424, 39.87482853233814, 37.91797913610935, 38.705167695879936, 36.38124659657478, 35.99056676030159, 37.39020265638828, 40.63092716038227, 46.30795173346996, 47.18775652348995, 50.15057533979416, 48.271500170230865, 49.76439826190472, 48.81992094218731, 47.863132283091545, 51.99958652257919, 50.57913154363632, 52.07315817475319, 49.49242785573006, 50.711432844400406, 48.31859104335308, 49.02787238359451, 32.599830105900764, 2.2846625559031963, 1.4669815823435783, 9.850887805223465, 1.1699034296907485, 0.2381265870644711, 0.4742066573817283, 0.27498729585204273, 0.2711363509297371, 21.5915510058403, 55.29690898954868, 30.646719709038734, 26.817258596420288, 21.849832646548748, 55.535539984703064, 8.063762951642275, 0.030664933437947184, 0.025438772172492463, 0.033422212436562404, 0.015466488384845434, 0.040188866332755424, 0.015527149680565344, 0.04259510948031675, 0.017496461732662283, 0.07303119797143154, 0.030595687348977663, 0.04295646489481442, 0.05260209887637757, 0.028510810843727086, 0.02860122298443457, 0.10662444576155394, 0.1436886069132015, 0.23919948027469218, 0.19450167717877775, 0.1342741519329138, 0.23058302700519562, 0.15821858192794025, 0.23536579770734534, 0.24407484132098034, 0.1835942140314728, 0.15003751701442525, 0.08375906880246475, 0.07662080301088281, 0.09553903786581941, 0.1720464852405712, 0.14089449512539431, 0.10356357641285285, 0.1817763678263873, 6.341240806505084, 55.43624751269817, 55.24326726794243, 36.10358789563179, 40.10277450084686, 55.325483456254005, 55.76954662799835, 62.16401070356369, 34.69834350049496, 0.5485809571109712, 3.8550273282453418, 6.077739195898175, 2.9014934320002794, 1.807497579138726, 29.458209984004498, 53.841761872172356, 53.31572189927101, 51.131781488657, 53.00372824072838, 50.17613656818867, 53.63729864358902, 51.937349662184715, 54.25993323326111, 51.959962248802185, 49.845938086509705, 52.75248572230339, 51.777070462703705, 50.98056860268116, 51.26343682408333, 55.18744446337223, 53.78385677933693, 51.07393339276314, 47.76019960641861, 43.594156354665756, 42.70175144076347, 39.57155540585518, 39.34074819087982, 42.43621028959751, 43.43489930033684, 39.862456396222115, 44.37176562845707, 44.17911596596241, 39.47127878665924, 40.46070769429207, 42.5840375572443, 42.440800443291664, 41.82743355631828, 41.19699038565159, 41.28940522670746, 42.65914812684059, 44.56586301326752, 39.911979138851166, 40.58129422366619, 41.549410074949265, 43.3254461735487, 40.78264541924, 42.40262009203434, 39.97634008526802, 44.98847633600235, 52.199930772185326, 53.25077958405018, 49.84070956707001, 50.79559452831745, 51.691335663199425, 50.84732875227928, 46.24272063374519, 44.38949167728424, 46.143857538700104, 54.10855695605278, 54.693406373262405, 58.750498071312904, 44.78902503848076, 47.74420626461506, 46.337536945939064, 52.672165632247925, 50.485690757632256, 49.17699158191681, 57.11088605225086, 50.09665243327618, 50.367954075336456, 52.584724724292755, 53.58709953725338, 48.84989753365517, 42.44082324206829, 39.25593674182892, 40.2974608540535, 40.590250343084335, 41.259896010160446, 44.1644449532032, 42.67707176506519, 43.041149228811264, 41.97149142622948, 41.58243790268898, 41.473391354084015, 39.733897894620895, 37.85749778151512, 38.97565998136997, 37.85354219377041, 39.891046062111855, 40.677493661642075, 38.366951644420624, 41.1696470528841, 40.47800436615944, 43.02593484520912, 43.54177236557007, 41.085192784667015, 43.415508940815926, 42.260044142603874, 39.538922756910324, 39.79387007653713, 39.24556329846382, 39.293972700834274, 39.706182181835175, 42.87224069237709, 48.686316311359406, 49.23271179199219, 51.27729468047619, 50.884703546762466, 51.24470762908459, 49.55177687108517, 49.749073684215546, 54.48799319565296, 53.522833585739136, 54.200641214847565, 50.735751539468765, 51.15979738533497, 51.59954398870468, 49.93916228413582, 38.223034366965294, 3.5961094591766596, 0.9695577551610768, 11.607406251132488, 3.279289109632373, 1.456768442876637, 0.979903353145346, 0.6473490572534502, 0.295252024079673, 25.712598972022533, 62.71808177232742, 33.39650295674801, 31.407072208821774, 29.950492568314075, 62.64119669795036, 12.49678272753954, 0.28340348799247295, 0.19164789671776816, 0.08875722560333088, 0.12601391470525414, 0.10469548520632088, 0.13059528137091547, 0.1068614877294749, 0.16854139597853646, 0.19758905604248866, 0.08491042928653769, 0.14027999684913084, 0.19141299213515595, 0.2054122870322317, 0.14978388062445447], [0.0555627894209465, 0.006981103033467662, 0.04739917611004785, 0.0521212762396317, 0.13353728834772483, 0.1048808365885634, 0.028179436339996755, 0.07002220474532805, 0.011998081627098145, 0.02070000711682951, 0.056307720151380636, 0.060376997498678975, 0.030540273037331644, 0.033537030103616416, 0.06091446826758329, 0.0242044006154174, 0.03847532527288422, 0.034866814021370374, 0.1488587787025608, 22.425929233431816, 44.90369148552418, 27.42789912968874, 32.37765982747078, 33.81691999733448, 38.209571689367294, 48.27446401119232, 35.80588527023792, 0.6903878040611744, 0.3366567101329565, 1.1642494518309832, 0.5207418103236705, 0.28829670511186123, 11.032530348747969, 47.7652495354414, 51.02924019098282, 51.906658709049225, 48.57036553323269, 50.43524846434593, 51.83686025440693, 51.24458983540535, 43.9907106757164, 52.62877196073532, 46.74388334155083, 47.425779551267624, 48.66134785115719, 49.1246721893549, 51.49710148572922, 50.604320392012596, 44.27399307489395, 41.432110369205475, 39.2241058498621, 37.6607633382082, 34.742778316140175, 35.67633882164955, 37.12453231215477, 36.239981576800346, 37.36110381782055, 37.646894082427025, 35.591857954859734, 37.955676913261414, 36.08072072267532, 37.157104164361954, 37.79871493577957, 39.15546253323555, 39.13413807749748, 38.816634714603424, 37.737963795661926, 40.95084719359875, 38.47599819302559, 40.23257553577423, 36.85271389782429, 38.93105797469616, 39.570787847042084, 37.80130259692669, 37.62289077043533, 37.99143299460411, 40.13071060180664, 49.22008506953716, 46.800682693719864, 50.26401445269585, 46.484395265579224, 58.38232442736626, 54.73389320075512, 44.955079928040504, 42.62294366955757, 44.201827347278595, 50.26773825287819, 51.52489319443703, 55.270842388272285, 49.155902713537216, 37.47608184814453, 42.889248579740524, 47.90638916194439, 53.50424498319626, 42.484517097473145, 45.33193230628967, 53.082813397049904, 49.92103345692158, 49.99057352542877, 50.088847652077675, 44.78638418018818, 40.114808455109596, 35.7727662473917, 36.54045045375824, 36.002748906612396, 36.58310316503048, 36.41652010381222, 37.87544421851635, 38.338027596473694, 37.631725296378136, 37.36983574926853, 38.728449046611786, 36.00631311535835, 39.1968385130167, 37.56186984479427, 38.15133221447468, 37.1638298034668, 36.93154826760292, 36.32530599832535, 36.24622844159603, 35.835926458239555, 40.31133010983467, 39.263034760951996, 40.836279541254044, 41.778051406145096, 40.40949024260044, 37.02509544789791, 35.49586370587349, 33.8447193056345, 34.78491045534611, 34.27260294556618, 35.20699940621853, 35.15343368053436, 39.920038506388664, 42.66895920038223, 46.76702409982681, 46.559996008872986, 49.626241475343704, 48.746212497353554, 49.18125495314598, 48.02445262670517, 47.94367276132107, 46.99063830077648, 49.31968532502651, 48.552354499697685, 49.65552270412445, 10.485034827142954, 0.24868295498890802, 1.5686876373365521, 3.4978153835982084, 1.0275782668031752, 0.14519985707011074, 0.09932315981131978, 0.443443211261183, 0.4652063950197771, 30.662918239831924, 46.23029910027981, 28.57316717505455, 28.911713808774948, 37.38492853939533, 42.43149854242802, 1.7322708782739937, 0.011033618047804339, 0.09320262339315377, 0.09415144435479306, 0.018535527851781808, 0.027366745671315584, 0.06024449445249047, 0.03138860534818377, 0.04937797559250612, 0.007919499603303848, 0.03614543427829631, 0.032808790274430066, 0.028958157054148614, 0.010258298225380713, 0.05572591348027345, 0.05737727369705681, 0.07665681943763047, 0.04597648272465449, 0.02261109675600892, 0.028459535860747565, 0.04672598137403838, 0.04372473245894071, 0.010510128413443454, 0.003965036212321138, 0.009707856570457807, 0.09843102408922277, 0.05076083049061708, 0.02684080787730636, 0.0473823887296021, 0.03482677886495367, 0.013066541432635859, 0.07853174422052689, 0.07025649334536865, 0.6504313449840993, 31.449538730084896, 54.39315788447857, 26.889468021690845, 36.054190546274185, 44.46419186890125, 43.360362499952316, 53.455903977155685, 39.56212431192398, 0.8102290390525013, 0.8754299185238779, 0.4326470702653751, 0.11267006237176247, 0.26281610364094377, 14.506397042423487, 50.89389145374298, 52.32394091784954, 54.19663242995739, 51.63112789392471, 52.04888507723808, 52.29797691106796, 52.27067157626152, 47.01366886496544, 52.70719215273857, 49.697803035378456, 49.405929297208786, 49.80536386370659, 50.96660055220127, 53.38416002690792, 52.3303397744894, 48.21083642542362, 43.53018678724766, 41.35150149464607, 39.97336104512215, 36.21072694659233, 37.81464748084545, 39.602098166942596, 39.113284796476364, 40.02321437001228, 38.145807310938835, 38.478354066610336, 39.78143714368343, 38.617468401789665, 38.613163232803345, 40.03742940723896, 39.8716177046299, 41.80322885513306, 40.62390133738518, 39.78502035140991, 42.89729654788971, 41.19213044643402, 41.79975964128971, 39.72657948732376, 40.25821276009083, 41.41319878399372, 39.22778405249119, 39.80744294822216, 41.18474364280701, 42.34291389584541, 50.868615210056305, 47.97427251935005, 51.25977382063866, 49.20389033854008, 57.56609782576561, 54.7048095613718, 46.783241629600525, 44.05645854771137, 45.082019716501236, 51.85086250305176, 52.5044122338295, 56.91816419363022, 50.24400852620602, 42.3928128182888, 49.03992533683777, 50.49120806157589, 52.98907622694969, 44.32786278426647, 47.31707878410816, 55.05048841238022, 51.92307762801647, 51.91611260175705, 52.08715662360191, 46.13117381930351, 43.69513973593712, 37.827179208397865, 38.98267440497875, 37.663529589772224, 38.58457736670971, 37.44892090559006, 39.62824076414108, 39.73943419754505, 38.2422461360693, 38.77560831606388, 40.24675637483597, 37.357497811317444, 39.79546599090099, 39.38383787870407, 39.923899099230766, 38.22208061814308, 38.39909411966801, 36.70068025588989, 38.96243289113045, 39.22563336789608, 40.69968827068806, 40.023609548807144, 43.20264056324959, 43.623388186097145, 41.30139358341694, 38.320088759064674, 37.20530077815056, 36.249351873993874, 35.95803290605545, 36.09789960086346, 36.01269297301769, 36.68050333857536, 42.56923735141754, 45.472995936870575, 48.60273599624634, 47.73254469037056, 51.70710861682892, 49.38415266573429, 50.08303016424179, 48.819985538721085, 48.88033390045166, 46.714047342538834, 49.412958920001984, 47.816345393657684, 50.534799322485924, 13.430223539471626, 0.4902102705091238, 4.477941915392876, 6.902370946481824, 1.6312408307567239, 0.20542376063531265, 0.13196917483583093, 0.4501239355886355, 0.09572815193678252, 32.103542536497116, 54.21529322862625, 35.10659359395504, 24.480194002389908, 37.5788701325655, 48.665915206074715, 3.274411358870566, 0.05621363809041213, 0.03569989334209822, 0.07974977925186977, 0.04702408354205545, 0.05904588142584544, 0.07035123591776937, 0.02591058328107465, 0.01943139657669235, 0.008236542307713535, 0.06793109234422445, 0.006008607097101049, 0.04680238547734916, 0.03280218144936953, 0.006716639172736905, 0.14093943958869204, 0.1612089027184993, 0.10944230627501383, 0.08239917966420762, 0.1811955778975971, 0.2268564363475889, 0.12189339206088334, 0.12516330956714228, 0.09449120698263869, 0.15611572132911533, 0.18265355669427663, 0.20414925558725372, 0.11099212584667839, 0.13797818130115047, 0.0972535325854551, 0.10192348941927776, 0.18601036485051736, 0.24712048179935664, 0.9071944921743125, 35.46508155763149, 59.247575998306274, 35.96139572560787, 43.26015427708626, 44.630603939294815, 46.351550593972206, 57.98402599990368, 45.44588439166546, 1.2237647082656622, 2.1666313894093037, 4.996976014226675, 1.8737716041505337, 0.715822511119768, 16.158942617475986, 52.064965814352036, 51.88753813505173, 53.27307678759098, 49.83676537871361, 52.75484539568424, 52.12559536099434, 53.63310366868973, 46.342298090457916, 55.28445705771446, 53.02203565835953, 52.449562177062035, 53.31404238939285, 53.71204823255539, 54.81857165694237, 53.85642908513546, 50.026994571089745, 44.803882241249084, 42.61942885816097, 42.60299853980541, 37.71598197519779, 39.95683193206787, 41.076745837926865, 39.202348217368126, 41.843685284256935, 41.19772754609585, 41.808320581912994, 42.087829783558846, 39.55035254359245, 40.747022330760956, 43.547437861561775, 41.67756959795952, 44.38183128833771, 40.73173575103283, 42.61244483292103, 44.45100277662277, 42.25403666496277, 42.87964649498463, 40.51047742366791, 42.21774481236935, 45.64629703760147, 41.67495533823967, 41.561493426561356, 43.16847659647465, 45.2473184466362, 51.93928375840187, 51.47853188216686, 53.22192773222923, 53.20017769932747, 56.69603951275349, 56.80312156677246, 48.51353198289871, 46.841382309794426, 48.28251577913761, 54.52362388372421, 52.52154931426048, 59.87771138548851, 51.42178572714329, 44.327102825045586, 46.45363211631775, 48.997937589883804, 54.54224668443203, 45.83869211375713, 51.51983566582203, 53.950253650546074, 54.38053876161575, 54.059596583247185, 55.72025567293167, 48.28316934406757, 45.6318274140358, 38.87051202356815, 41.26948669552803, 40.487192273139954, 39.62689943611622, 38.21220874786377, 41.66070230305195, 42.25454583764076, 40.284184366464615, 40.42186997830868, 42.83497989177704, 37.974079325795174, 43.00931453704834, 40.57756282389164, 43.72155971825123, 40.84257200360298, 40.333319529891014, 39.156279489398, 42.83255562186241, 39.8553279787302, 43.44151854515076, 43.32708768546581, 45.567390471696854, 45.27121916413307, 44.407692700624466, 41.76885209977627, 40.14879383146763, 38.22085328400135, 38.53141441941261, 37.40982100367546, 38.37531499564648, 39.5366732776165, 43.42571139335632, 47.15124808251858, 50.35005323588848, 49.634483233094215, 54.08238396048546, 50.387625619769096, 51.70991286635399, 50.56370437145233, 50.406635999679565, 46.33917085826397, 49.96361777186394, 48.58266547322273, 54.081840589642525, 17.01556485146284, 1.0643731174059212, 3.211301970295608, 8.384402096271515, 3.2548716198652983, 0.5064969090744853, 0.43634649831801653, 1.004435489885509, 0.7509249681606889, 37.14451164007187, 58.79041872918606, 39.76748429238796, 37.984551563858986, 46.98223315179348, 57.76369862258434, 4.777122661471367, 0.22257845965214074, 0.2607951464597136, 0.264140777871944, 0.10996969867846929, 0.19035997363971546, 0.1523534778971225, 0.14624310890212655, 0.1750321898725815, 0.11195799394045025, 0.17941705067642033, 0.11154144871397875, 0.09715033695101738, 0.13919638702645898, 0.17413672932889313], [0.05694015242625028, 0.06305715622147545, 0.024344872472283896, 0.040949871981865726, 0.030167952390911523, 0.023263934381247964, 0.019459438626654446, 0.015901037186267786, 0.07454687874997035, 0.024068192396953236, 0.03274230497481767, 0.026125013864657376, 0.080615086335456, 0.02224178366304841, 0.035312566469656304, 0.05681683345756028, 0.049889330184669234, 0.049563200809643604, 0.02608875438454561, 6.925323139876127, 39.83443669974804, 34.98529650270939, 25.22483814507723, 32.83008635044098, 38.34464304149151, 46.77802070975304, 40.82773759961128, 1.6823543817736208, 0.7706680556293577, 0.5314541480038315, 0.020502662628132384, 0.164901458483655, 3.1313592474907637, 33.23846943676472, 52.271165549755096, 53.49436171352863, 50.03148213028908, 50.32542675733566, 49.821095019578934, 52.386542558670044, 49.39984582364559, 48.349479585886, 49.99369315803051, 52.800784930586815, 50.389707908034325, 49.32504303753376, 48.140171617269516, 46.258706375956535, 43.30935403704643, 38.98266300559044, 37.662218660116196, 38.13066512346268, 36.32070064544678, 37.5158429145813, 38.55428159236908, 37.32228510081768, 36.58454708755016, 36.65439873933792, 36.82532876729965, 36.66233651340008, 38.01310323178768, 37.33960457146168, 36.1456136405468, 39.200547114014626, 37.98586629331112, 40.10390684008598, 37.21567042171955, 39.95404668152332, 40.5487147718668, 39.99780133366585, 38.3330612629652, 38.591143414378166, 37.98351801931858, 37.13386081159115, 38.36299225687981, 37.03331060707569, 42.829762771725655, 51.038344502449036, 49.89966720342636, 49.87652264535427, 48.31940419971943, 54.755232855677605, 47.829241901636124, 46.23542882502079, 43.21361057460308, 43.398554250597954, 46.151259541511536, 51.909265369176865, 53.196488097310066, 51.7534015327692, 38.11149135231972, 36.81218907237053, 48.14571551978588, 51.10915370285511, 49.13216158747673, 42.421121299266815, 50.093794986605644, 48.667321130633354, 50.44689483940601, 47.65536703169346, 45.82383491098881, 40.76564513146877, 36.35276712477207, 36.82242572307587, 36.940094009041786, 36.42893023788929, 36.636539697647095, 36.89420387148857, 37.72373355925083, 36.73946477472782, 40.35964071750641, 37.27247357368469, 36.952629536390305, 37.91719637811184, 38.4508815407753, 37.60031998157501, 38.01306143403053, 38.03187042474747, 36.687221378088, 35.90003281831741, 35.908206179738045, 38.895047307014465, 42.432269901037216, 42.029776498675346, 43.131550177931786, 42.56169095635414, 39.467885568737984, 37.69846871495247, 34.2454420030117, 35.30751161277294, 35.32664738595486, 35.25758609175682, 34.24096204340458, 35.76154924929142, 37.320780381560326, 41.953472793102264, 43.051724061369896, 46.182482466101646, 48.24557416141033, 50.2376514673233, 50.38441479206085, 47.74566538631916, 49.07202981412411, 48.33977870643139, 51.01312145590782, 31.367997005581856, 1.7826415691524744, 0.07482050859834999, 5.1402810495346785, 8.571227621287107, 0.29454451985657215, 0.11761399786337279, 0.04546640833723359, 1.343874006997794, 0.5133600533008575, 38.87482479214668, 38.34509901702404, 22.895259149372578, 24.50929094105959, 46.54360368847847, 23.97245954722166, 0.0338505763647845, 0.04326037065766286, 0.0310250828624703, 0.03263910191890318, 0.0767300026200246, 0.03609402941947337, 0.05915672118135262, 0.03547611355315894, 0.018332526342419442, 0.006600455026273266, 0.10316195577615872, 0.036436077862163074, 0.037972520221956074, 0.06287241340032779, 0.06191772947204299, 0.04442795820068568, 0.04085668420884758, 0.049681447198963724, 0.02377344102569623, 0.037672959733754396, 0.11031559144612402, 0.017494923631602433, 0.09216533100698143, 0.030927303050702903, 0.038135625727591105, 0.06998537195613608, 0.054843644611537457, 0.038848065232741646, 0.051973603694932535, 0.014540279735228978, 0.04299585067201406, 0.07899630640167743, 0.04528816672973335, 0.1056952694489155, 11.298101898282766, 49.58357356488705, 36.23708613216877, 30.223019644618034, 39.62489314377308, 42.410778254270554, 53.57180915772915, 44.41937707364559, 1.3934586150571704, 0.7188374118413776, 0.5169673659838736, 0.04547079071926419, 0.16838539653690532, 4.152064276859164, 37.693810164928436, 53.93624760210514, 53.65739196538925, 49.27398517727852, 50.613075122237206, 50.383552238345146, 53.99674415588379, 49.78588230907917, 51.45271606743336, 51.12763211131096, 54.64061580598354, 52.12555356323719, 52.376948073506355, 51.71389885246754, 49.1292205452919, 44.792452454566956, 40.918567925691605, 40.23459702730179, 40.59045933187008, 37.96242155134678, 38.92451472580433, 40.17081744968891, 38.644686341285706, 37.703446447849274, 38.23872372508049, 39.65824015438557, 38.18524159491062, 40.049584954977036, 39.859215170145035, 37.90735490620136, 41.882823184132576, 39.124733582139015, 41.05021186172962, 39.8526681214571, 41.70062676072121, 41.385384276509285, 39.582476019859314, 38.65294709801674, 38.39166931807995, 39.900632947683334, 38.56796845793724, 39.50390383601189, 38.73297080397606, 45.60112126171589, 51.50705315172672, 51.36070020496845, 52.516860365867615, 50.79665467143059, 58.95015075802803, 52.436536476016045, 47.49345771968365, 45.08266568183899, 44.85152788460255, 47.938106060028076, 54.02188740670681, 54.106212481856346, 54.20692227780819, 42.59266309440136, 42.04868048429489, 51.318195685744286, 50.935947597026825, 49.30729418992996, 43.58703933656216, 51.0797318816185, 50.88137872517109, 50.202746540308, 49.89637278020382, 47.59157605469227, 40.85546091198921, 39.138025268912315, 40.86278311908245, 38.711091578006744, 38.4908439964056, 38.195877224206924, 39.53432500362396, 39.0797857940197, 39.526968598365784, 41.77376143634319, 38.4249859303236, 38.043110221624374, 38.58238488435745, 38.51344898343086, 37.90797047317028, 39.143246188759804, 39.79254014790058, 38.15644674003124, 38.75045746564865, 37.499769777059555, 41.26305364072323, 43.42203699052334, 45.24451419711113, 44.18467506766319, 42.43081837892532, 41.443068981170654, 39.099358543753624, 38.33333104848862, 36.46642282605171, 37.05167502164841, 37.07615330815315, 35.647315979003906, 37.312170043587685, 38.94887521862984, 44.07847836613655, 46.504967361688614, 47.13808938860893, 48.666222989559174, 52.303741201758385, 50.60283087193966, 49.439029321074486, 48.8251418620348, 48.1720557063818, 49.926888942718506, 34.274780228734016, 2.886887965723872, 0.44869316392578185, 6.792737329378724, 9.91842158138752, 0.3467031929176301, 0.04868873562372755, 0.06560340552823618, 1.956680305302143, 0.34473846084438264, 41.622719541192055, 46.74229882657528, 32.55083553493023, 23.640657551586628, 51.04432538151741, 32.56053261458874, 0.19100592413451523, 0.06653910531895235, 0.003871954195346916, 0.03368175261130091, 0.029461470476235263, 0.03945573203964159, 0.02037799851677846, 0.03759110455575865, 0.06941088286112063, 0.08080371801042929, 0.11958777671679854, 0.020254670271242503, 0.026577798162179533, 0.02365758249652572, 0.05777697588200681, 0.3330614202423021, 0.1293366137542762, 0.1406981673790142, 0.13650942652020603, 0.1603936534957029, 0.20161629072390497, 0.06413035371224396, 0.17111917171860114, 0.15519812994170934, 0.08142725564539433, 0.19822008936898783, 0.11743660230422392, 0.14063265058211982, 0.16162964107934386, 0.12822100252378732, 0.2427649506716989, 0.28273804869968444, 0.1785831290180795, 0.30877995130140334, 12.946382202208042, 59.93356838822365, 44.34311516582966, 35.3274567425251, 45.11258527636528, 48.858393877744675, 58.74848037958145, 50.931102856993675, 1.8718869052827358, 1.7164016235619783, 1.8401374714449048, 0.5444088403601199, 0.669018403859809, 5.196709921583533, 39.86547343432903, 53.683359771966934, 53.59781116247177, 50.7826866209507, 49.81870494782925, 51.15328833460808, 54.41982105374336, 51.810307279229164, 50.84059551358223, 54.32761140167713, 56.66294328868389, 54.23430360853672, 55.38428910076618, 53.96952621638775, 50.953080877661705, 46.404029577970505, 42.82547280192375, 42.020307406783104, 42.97493778169155, 39.85586754977703, 41.64568170905113, 43.06626968085766, 41.1434056609869, 40.51831640303135, 38.880486488342285, 40.977206379175186, 40.62511347234249, 42.81929433345795, 42.204821705818176, 40.3234438598156, 43.512871116399765, 40.60141034424305, 43.67599256336689, 39.61566723883152, 43.21539647877216, 45.13914205133915, 40.7453428208828, 40.750495344400406, 40.712694972753525, 41.48651584982872, 41.345904394984245, 42.234353721141815, 39.33120310306549, 47.40051470696926, 56.00449562072754, 53.09836596250534, 55.094725638628006, 52.90073096752167, 57.088851034641266, 54.91674318909645, 50.5120575428009, 48.56289133429527, 46.59793317317963, 49.2216619849205, 55.14691963791847, 59.04466308653355, 54.69353936612606, 40.9964295476675, 41.6557739675045, 48.29801134765148, 54.36043404042721, 48.778172582387924, 47.56889507174492, 53.81612464785576, 51.68092042207718, 54.33654472231865, 51.602051854133606, 49.082737639546394, 44.76787157356739, 41.70763358473778, 42.31273211538792, 40.03301404416561, 40.730755403637886, 40.33376030623913, 40.44111594557762, 40.639659091830254, 40.31141370534897, 44.79456514120102, 40.34709759056568, 39.56953391432762, 40.96853904426098, 40.47741159796715, 39.72997270524502, 41.78194239735603, 41.927979961037636, 40.10387644171715, 40.770406275987625, 39.11686420440674, 45.14861114323139, 46.42422929406166, 46.56205929815769, 47.14970536530018, 45.70270501077175, 42.31328688561916, 42.20598064363003, 38.4555970877409, 38.46661649644375, 39.54059846699238, 39.59925591945648, 36.904626712203026, 39.38888020813465, 40.336484760046005, 46.96528986096382, 47.59522765874863, 50.64414985477924, 51.67963229119778, 55.312465354800224, 53.003948628902435, 49.75437059998512, 48.542877808213234, 50.79849757254124, 49.136162772774696, 38.01208108663559, 3.6238764692097902, 0.3984036936890334, 9.930433686822653, 16.26816775649786, 0.6048279139213264, 0.3626778325997293, 0.23465017438866198, 3.975353571586311, 1.2470505712553859, 45.95829829573631, 48.859096840023994, 35.403540059924126, 33.464158326387405, 59.073062762618065, 37.52636834979057, 0.5845975026022643, 0.1159452713909559, 0.11423045754781924, 0.11440791247878224, 0.13813734229188412, 0.16074808838311583, 0.18428576207952574, 0.0838998616382014, 0.2120052301324904, 0.2136876789154485, 0.27848159428685904, 0.12266688805539161, 0.14267990947701037, 0.23005886294413358, 0.14217122661648318], [0.019354628821020015, 0.053842004999751225, 0.03929398466425482, 0.03766179412195925, 0.050044850941048935, 0.040820241047185846, 0.1023582172638271, 0.080635933263693, 0.0933690500096418, 0.05164407899428625, 0.022254517061810475, 0.06030037817254197, 0.006488459375759703, 0.03886170590703841, 0.004022728917334462, 0.035911316372221336, 0.05818052981339861, 0.056318770730285905, 0.039702844951534644, 0.9812879632227123, 30.385531224310398, 47.679476737976074, 26.40118472278118, 33.76436121761799, 32.60695092380047, 42.51654177904129, 41.130357161164284, 0.8928184385877103, 0.13418976974207908, 0.16213430149946362, 0.2667501394171268, 0.19693948386702687, 0.14741533115739003, 12.116030808538198, 39.66957874596119, 52.492807656526566, 51.47461049258709, 51.563350930809975, 53.19473259150982, 51.184568256139755, 51.917609721422195, 51.311557441949844, 49.334721118211746, 46.866669952869415, 47.59362794458866, 43.87225963175297, 41.430609449744225, 40.07027104496956, 38.64404037594795, 36.48215018212795, 36.922641545534134, 37.16283805668354, 35.69360129535198, 36.15331582725048, 36.77463188767433, 37.93668553233147, 37.79703922569752, 38.89319680631161, 36.923629492521286, 37.36882500350475, 38.38178984820843, 37.51542493700981, 37.3656065762043, 37.987336814403534, 38.558195382356644, 39.05262865126133, 38.29716078937054, 40.307370722293854, 39.94707025587559, 40.013593286275864, 38.63592781126499, 36.63892596960068, 38.09034928679466, 37.273092940449715, 38.332711681723595, 36.91834017634392, 46.274243742227554, 52.71987587213516, 51.59553900361061, 50.77227137982845, 52.976001128554344, 50.955850929021835, 43.69200870394707, 49.08108092844486, 45.92824190855026, 45.49447998404503, 47.07963712513447, 50.87728634476662, 51.44590683281422, 52.70607501268387, 39.290894865989685, 36.48055426776409, 46.166120544075966, 51.00410453975201, 51.408972814679146, 47.93498642742634, 46.95053905248642, 48.841955959796906, 47.34571784734726, 48.01090635359287, 42.79505543410778, 38.58883693814278, 36.001092195510864, 35.610226169228554, 36.749595031142235, 36.79171197116375, 36.296541541814804, 37.400545701384544, 38.71004283428192, 37.45917275547981, 35.978745594620705, 36.79932676255703, 38.00511226058006, 37.271094247698784, 34.95356820523739, 37.335314601659775, 36.78867593407631, 37.418708726763725, 36.50391161441803, 36.11048072576523, 33.717631325125694, 37.004834935069084, 41.002193838357925, 42.74423696100712, 44.15932282805443, 41.600441336631775, 41.15140423178673, 38.674716129899025, 36.85582213103771, 34.94470328092575, 34.99715566635132, 33.159334883093834, 35.48178166151047, 35.042232647538185, 37.12346836924553, 35.290089547634125, 41.238028183579445, 41.64212889969349, 44.6575178951025, 45.69277614355087, 49.86465968191624, 48.9620067179203, 50.9812867641449, 45.3473062813282, 49.74804773926735, 12.512259297072887, 0.4822788492310792, 0.6107986997812986, 9.514631498605013, 5.620675021782517, 0.37652381462976336, 0.12386314847390167, 0.1227774829021655, 1.5046888589859009, 1.8842536979354918, 44.183801114559174, 30.896746292710304, 25.446922928094864, 27.460611574351788, 39.90891270339489, 4.8566751927137375, 0.05847686195920687, 0.08893143734894693, 0.1432202523574233, 0.08181678669643588, 0.04238178655214142, 0.04694875555287581, 0.024356004687433597, 0.04831988822843414, 0.022853003501950298, 0.028617262651096098, 0.039907573809614405, 0.03173397861246485, 0.08669506438309327, 0.07350644707912579, 0.04379638681712095, 0.0493750366877066, 0.049482540489407256, 0.06603995905607007, 0.03514449970680289, 0.042633626944734715, 0.00826859473818331, 0.06119657715316862, 0.03420159737288486, 0.020309858227847144, 0.0913373836374376, 0.06896173508721404, 0.008302346686832607, 0.014742034436494578, 0.0338667106552748, 0.029838190203008708, 0.02908085076342104, 0.06469328756793402, 0.05198021623073146, 0.01095136025469401, 1.8886083830147982, 37.49257676303387, 49.23613540828228, 25.693883076310158, 43.23320992290974, 43.15886691212654, 45.82333333790302, 46.65724419057369, 1.0653143981471658, 0.24506329296855256, 0.2235071684117429, 0.12129166614613496, 0.14839107723673806, 0.13825616013491526, 15.388253722339869, 42.507498264312744, 55.47501303255558, 51.59420147538185, 52.85167559981346, 53.044758439064026, 53.69383201003075, 53.42425927519798, 52.32513405382633, 50.78864090144634, 49.64874766767025, 47.31219984591007, 46.71228043735027, 43.21163088083267, 42.72697448730469, 40.726989805698395, 38.75472463667393, 40.735144168138504, 38.443768322467804, 38.512635827064514, 38.40388186275959, 39.376466274261475, 39.63387966156006, 40.20015947520733, 39.42098468542099, 39.16891001164913, 39.59906592965126, 40.243032574653625, 40.41789539158344, 39.87186849117279, 40.056701973080635, 41.60365216434002, 40.98206251859665, 39.13213178515434, 42.43751361966133, 40.2542457729578, 40.170255079865456, 39.26838107407093, 38.56155440211296, 40.56326039135456, 39.449904933571815, 39.19744648039341, 39.15209211409092, 46.884848177433014, 53.91599088907242, 52.74403117597103, 50.44794358313084, 54.55338008701801, 52.82210558652878, 47.538785487413406, 50.34343019127846, 48.162681609392166, 46.16365447640419, 49.20058831572533, 52.489368841052055, 53.13920237123966, 54.15075369179249, 42.794683054089546, 40.7317965477705, 50.1317473500967, 50.05296237766743, 53.22631649672985, 48.5140335559845, 50.739524737000465, 50.705463364720345, 51.78670294582844, 50.03988727927208, 44.594570472836494, 40.189755633473396, 38.0893499404192, 38.10892269015312, 39.48723413050175, 37.986018285155296, 37.55259834229946, 39.16923679411411, 39.56718564033508, 38.36062118411064, 39.24984946846962, 39.02255706489086, 38.943076729774475, 40.09863652288914, 37.20410764217377, 39.523411989212036, 39.50139977037907, 38.72545100748539, 38.72225917875767, 37.90086105465889, 36.60479240119457, 39.37339223921299, 44.716714918613434, 45.53362928330898, 46.646312177181244, 44.24704872071743, 42.372955083847046, 40.371359288692474, 39.91353325545788, 37.11841844022274, 37.0858009904623, 35.40424682199955, 37.86625251173973, 37.466867342591286, 37.99585975706577, 38.92918847501278, 43.52424010634422, 43.9974819123745, 47.874657064676285, 45.866544619202614, 50.49205921590328, 48.90473619103432, 50.02814210951328, 44.7412084043026, 49.72249411046505, 13.168452735990286, 0.3507756837643683, 2.963840961456299, 10.402165073901415, 4.523217910900712, 0.3679565212223679, 0.13624860614072531, 0.6422754388768226, 2.4349530413746834, 2.2599543817341328, 48.63980680704117, 39.495171904563904, 29.666997380554676, 27.84767970442772, 47.039606273174286, 7.505040457472205, 0.05700546513253357, 0.053066393884364516, 0.013378095027292147, 0.012791453264071606, 0.01628177378734108, 0.02023022392677376, 0.08254841071902774, 0.03854442293231841, 0.01764907512551872, 0.09164167160633951, 0.030994137159723323, 0.06760048039723188, 0.02801413407723885, 0.05279692748445086, 0.020229669171385467, 0.27426070359069854, 0.13858758844435215, 0.2506321464898065, 0.11511426637298428, 0.17203220631927252, 0.1383323935442604, 0.2492899278877303, 0.18600530340336263, 0.125193158746697, 0.14458286517765373, 0.14155827200738713, 0.11458711145678535, 0.12478004966396838, 0.16742523555876687, 0.11674152163323015, 0.12081488821422681, 0.19729295396246016, 0.093246439791983, 0.11974466673564166, 1.9353018212132156, 44.553726464509964, 59.50804442167282, 36.31639167666435, 44.60527829825878, 43.79638530313969, 52.539404556155205, 52.26506307721138, 1.4442282845266163, 0.6302979472093284, 0.7004087569657713, 0.5513297533616424, 0.4374872683547437, 0.5002919607795775, 15.675795692950487, 46.11866109073162, 53.847548961639404, 50.23809224367142, 52.1314812451601, 54.594748467206955, 53.805899396538734, 57.151551470160484, 54.75340515375137, 52.548896446824074, 51.17316126823425, 50.82157753407955, 48.47122125327587, 44.65146481990814, 44.5104505866766, 41.81462824344635, 40.96219338476658, 41.621708795428276, 41.15149162709713, 40.62462329864502, 40.18929585814476, 41.928185150027275, 42.74283103644848, 41.87348708510399, 42.3369862139225, 41.251646652817726, 42.3302111774683, 42.653687819838524, 42.45414912700653, 42.26132467389107, 42.98648156225681, 43.193437457084656, 42.42861069738865, 39.35609556734562, 43.4227779507637, 42.950440496206284, 42.27140553295612, 42.207401767373085, 40.1461947709322, 43.472517281770706, 42.15469479560852, 40.55511362850666, 41.57774895429611, 49.29757811129093, 57.52583898603916, 53.85169453918934, 54.65084105730057, 54.32014860212803, 51.082471534609795, 49.29415449500084, 52.40763142704964, 50.942156463861465, 49.44093681871891, 51.72185182571411, 53.79986152052879, 54.637005999684334, 54.43390689790249, 40.768244192004204, 40.619216188788414, 47.26426921784878, 54.229702055454254, 54.95999626815319, 50.87641999125481, 52.13436149060726, 51.977156326174736, 51.06450989842415, 52.426881194114685, 45.732248425483704, 41.39393001794815, 38.86199288070202, 39.0603194385767, 40.85095815360546, 41.38379596173763, 39.53653648495674, 41.2069458514452, 42.60627016425133, 41.09225660562515, 40.195584520697594, 40.71935221552849, 41.10705681145191, 41.81813545525074, 37.797122821211815, 40.3934171050787, 40.71694314479828, 41.46674171090126, 39.647494331002235, 39.62970368564129, 37.21709914505482, 40.75673080980778, 47.49104484915733, 47.308111265301704, 48.94760549068451, 46.535950899124146, 45.54363414645195, 43.79546195268631, 42.848355174064636, 38.93534794449806, 38.659159764647484, 37.91832871735096, 39.93234224617481, 38.96750941872597, 40.86898818612099, 39.304289147257805, 45.3300666064024, 47.160173803567886, 48.72404828667641, 47.88948766887188, 54.34291698038578, 51.75590559840202, 53.15209127962589, 44.721449464559555, 51.47484228014946, 15.466112494468689, 1.058782311156392, 2.193240886554122, 18.534575141966343, 12.959408853203058, 1.8771250429563224, 0.4123041790444404, 0.9393439732957631, 5.436203945428133, 4.045484745875001, 55.28523601591587, 41.437855660915375, 36.617468520998955, 33.76028783619404, 56.36661998927593, 11.448786612600088, 0.14646740077296272, 0.13891619659261778, 0.15045724605442956, 0.12357917308690958, 0.1750590407755226, 0.16055664396844804, 0.10659350562491454, 0.10300456109689549, 0.13454616389935836, 0.13775561121292412, 0.27604010654613376, 0.12129983719205484, 0.15926201187539846, 0.24318462033988908, 0.10938824081677012], [0.019611333991633728, 0.034619615762494504, 0.06671074181213044, 0.02065790322376415, 0.04830187630432192, 0.017230707926501054, 0.015950024499034043, 0.06880484506837092, 0.10633676705765538, 0.031198789947666228, 0.03549645953171421, 0.010158121276617749, 0.04567977579426952, 0.048235984722850844, 0.022642947878921404, 0.03323689445096534, 0.05639128226903267, 0.05361800256650895, 0.05245693479082547, 0.05594299167569261, 13.203112576156855, 49.550317749381065, 31.70653223991394, 22.78012342751026, 32.93329641222954, 35.25584198534489, 44.37096767127514, 1.9253845908679068, 0.19642680825199932, 0.05746027178247459, 0.20138769439654425, 0.08755862741963938, 0.057248088050982915, 2.047033994458616, 21.228231601417065, 44.0752637386322, 54.59177702665329, 52.71981507539749, 50.7546441257, 51.19103170931339, 51.69764332473278, 51.421466544270515, 47.58469082415104, 46.20779290795326, 40.74411928653717, 40.936833545565605, 39.255024790763855, 37.058602049946785, 38.573975935578346, 40.34316100180149, 38.68657149374485, 42.0537494122982, 39.913787841796875, 41.395598128437996, 40.51301188766956, 37.98099495470524, 38.003200963139534, 39.04419310390949, 37.18319356441498, 38.36483895778656, 37.73461997509003, 38.003869727253914, 37.07972891628742, 38.14188592135906, 38.590843230485916, 40.849461033940315, 39.17371675372124, 38.42486813664436, 38.10343198478222, 39.58134368062019, 39.23893265426159, 37.65918642282486, 38.54841850697994, 38.87846879661083, 39.13862183690071, 38.36695544421673, 47.38332062959671, 51.515697687864304, 52.21708305180073, 48.77172812819481, 52.03982636332512, 48.53176340460777, 44.74827982485294, 51.662848591804504, 49.13009449839592, 47.19338022172451, 45.90305306017399, 50.55200479924679, 50.947643369436264, 54.396095126867294, 42.55857512354851, 40.06544150412083, 46.927820071578026, 51.81717351078987, 50.39897941052914, 48.93688626587391, 46.65732778608799, 47.3244009912014, 47.265485152602196, 46.151833310723305, 41.8456269800663, 36.379996463656425, 34.30950656533241, 35.420817732810974, 36.71445831656456, 37.081438824534416, 36.230075508356094, 36.75389640033245, 37.70532354712486, 37.52078264951706, 36.82618752121925, 38.07503990828991, 37.9740185290575, 35.480159148573875, 38.10483790934086, 36.09524354338646, 37.82659024000168, 36.776083409786224, 34.57962267100811, 36.854461804032326, 37.37494267523289, 34.87755708396435, 39.17134188115597, 43.321285396814346, 42.901776507496834, 42.615564465522766, 41.76931567490101, 38.95494729280472, 38.67850452661514, 35.93962289392948, 37.21179462969303, 35.76103627681732, 33.62043634057045, 34.20753903687, 36.00314028561115, 37.64573514461517, 40.66215008497238, 41.797369569540024, 41.88825309276581, 47.05852925777435, 48.1615986675024, 47.946697399020195, 48.263611793518066, 48.92261043190956, 35.21442800760269, 3.8287211023271084, 0.7089761097449809, 1.226064059883356, 4.890665793791413, 4.94469984434545, 0.24426781455986202, 0.11419573245802894, 0.5437526036985219, 0.8945913997013122, 8.441701121628284, 41.18472844362259, 29.62155371904373, 23.84385734796524, 30.161956921219826, 29.826341830193996, 0.6477664411067963, 0.0424148121237522, 0.015681986733397935, 0.011503657278808532, 0.04706544343207497, 0.022783126587455627, 0.009727969700179528, 0.07285013620276004, 0.028014338167849928, 0.01840814933530055, 0.05344789118680637, 0.06958085694350302, 0.0346569309476763, 0.04793674706888851, 0.014662374160252512, 0.009647318656789139, 0.039922056821524166, 0.05122737420606427, 0.027770609449362382, 0.029878848763473798, 0.05497332378581632, 0.009471422235947102, 0.026874100622080732, 0.03597613555029966, 0.06339878906146623, 0.03731314056494739, 0.07659038979909383, 0.05195439691306092, 0.07606689367094077, 0.013489271532307612, 0.051943661746918224, 0.08146009568008594, 0.059920261264778674, 0.026225068359053694, 0.0742178772634361, 0.12505856284406036, 19.46755427867174, 58.7269127368927, 33.85065458714962, 28.119748905301094, 40.81406973302364, 41.13374277949333, 47.38367021083832, 2.000195332802832, 0.21514498977921903, 0.10142268074559979, 0.07993535327841528, 0.08137272263411433, 0.05882983110495843, 2.1175147499889135, 23.70145618915558, 47.64017924666405, 53.32620933651924, 51.80084578692913, 52.995999455451965, 52.73854807019234, 54.749453365802765, 52.514158710837364, 51.602701619267464, 49.04321976006031, 43.38802121579647, 42.3140886425972, 41.699004247784615, 40.2105101197958, 41.322159469127655, 39.71261143684387, 39.888310208916664, 42.17194586992264, 41.645229533314705, 42.54700854420662, 41.083315685391426, 39.85285431146622, 40.02076730132103, 40.14000490307808, 39.69900816679001, 40.507293194532394, 39.12829399108887, 39.48858305811882, 39.85555216670036, 40.71088247001171, 41.99498176574707, 41.73358999192715, 41.61180652678013, 40.10177135467529, 39.665433168411255, 41.06875106692314, 39.25191655755043, 40.131846740841866, 40.20929038524628, 39.91786502301693, 40.846588388085365, 40.41381061077118, 49.53892596065998, 52.85826824605465, 54.1521330177784, 51.62141561508179, 55.20624205470085, 51.93603873252869, 47.4037179350853, 52.27035239338875, 50.482080951333046, 48.959966227412224, 48.51602844893932, 52.01011195778847, 53.64981137216091, 55.88430047035217, 44.58279490470886, 41.8665486574173, 51.811903193593025, 54.17156897485256, 51.285601034760475, 50.368254259228706, 47.53139108419418, 49.50933314859867, 49.94822479784489, 48.29172648489475, 43.07888500392437, 37.326328083872795, 37.426528707146645, 37.33923979103565, 38.32223184406757, 38.26474852859974, 37.50239163637161, 38.806173875927925, 39.613201171159744, 39.96590204536915, 37.121963649988174, 38.60325336456299, 39.535081163048744, 37.93831564486027, 39.352884739637375, 38.02111700177193, 38.970260471105576, 38.863421604037285, 36.453784704208374, 38.21268372237682, 38.71360704302788, 35.920270532369614, 42.076707780361176, 45.99041037261486, 45.53062364459038, 43.8195526599884, 42.721073403954506, 39.527637362480164, 40.35623610019684, 38.71106877923012, 38.40387046337128, 37.35142193734646, 35.58344140648842, 36.02694980800152, 38.367973789572716, 39.32537421584129, 41.77496217191219, 43.030114620923996, 46.153907999396324, 48.26640844345093, 50.693904384970665, 49.449592754244804, 50.256920233368874, 47.641858756542206, 39.031220600008965, 3.340907790698111, 1.4671321492642164, 4.508232939988375, 11.30613561719656, 5.262129111215472, 0.4187186504714191, 0.15712642256403342, 0.6450880004558712, 0.8648365025874227, 9.97783424332738, 47.954319790005684, 35.95836728811264, 24.917113557457924, 32.98330172896385, 37.244537472724915, 1.0271930624730885, 0.03280339115008246, 0.0475541328341933, 0.017213850042026024, 0.060330772830639035, 0.009853972460405203, 0.03460385625658091, 0.014722406485816464, 0.06820442533353344, 0.14226613246137276, 0.05069769227702636, 0.05398317633080296, 0.041989583769463934, 0.06837469627498649, 0.015990096762834582, 0.0049479922563477885, 0.08427561100688763, 0.10631589044351131, 0.13974404748296365, 0.12046549993101507, 0.15254305209964514, 0.1074777077883482, 0.11193325815838762, 0.20233887538779527, 0.23230010439874604, 0.3243247984210029, 0.16474145144456998, 0.11171295904205181, 0.1623988474602811, 0.1388774416409433, 0.16379260079702362, 0.17662849015323445, 0.23524024116341025, 0.08529379309038632, 0.11386987767764367, 0.3482186881592497, 22.522417455911636, 65.68856477737427, 41.200588792562485, 30.552847646176815, 43.74594680964947, 43.56926769018173, 54.45696786046028, 3.260387498885393, 0.5276710947509855, 0.4168810631381348, 0.4149940190836787, 0.2776173484744504, 0.18950651865452528, 2.9884681524708867, 27.06045314669609, 48.92526648938656, 54.51851695775986, 51.39680206775665, 53.0527950078249, 54.50298719108105, 56.08465991914272, 55.27815319597721, 51.46840162575245, 51.08868420124054, 45.797927901148796, 45.087901800870895, 43.26349809765816, 42.79013089835644, 43.51559557020664, 44.83996130526066, 41.44314497709274, 46.35766826570034, 43.6295248568058, 46.79478920996189, 44.66324798762798, 41.79033614695072, 41.345509216189384, 43.51335369050503, 41.638241708278656, 42.922914773225784, 41.16452872753143, 41.07992626726627, 41.92266404628754, 43.58825907111168, 43.514714017510414, 45.5162338167429, 42.36046515405178, 41.469842344522476, 41.855270862579346, 43.460468128323555, 41.198145523667336, 41.068591475486755, 42.59420581161976, 41.7033664137125, 44.39508497714996, 42.6838506013155, 50.052050426602364, 55.48876449465752, 53.74765992164612, 54.640600606799126, 53.628281727433205, 50.45555457472801, 50.982639491558075, 54.61289629340172, 54.90345910191536, 50.33895403146744, 50.192589685320854, 54.32834856212139, 55.89430533349514, 56.737157106399536, 41.650864630937576, 43.201831206679344, 48.024106845259666, 54.696313217282295, 55.029562935233116, 50.66217988729477, 48.863960579037666, 52.16453567147255, 51.99853777885437, 51.384722515940666, 43.78637284040451, 39.544531255960464, 37.858607321977615, 38.52907374501228, 40.40116488933563, 40.487819239497185, 39.12684626877308, 41.090508699417114, 43.074215054512024, 41.95272423326969, 39.809213653206825, 40.45283831655979, 40.23694150149822, 38.53426806628704, 40.64689390361309, 40.14597438275814, 41.110267639160156, 40.98935052752495, 38.136596605181694, 41.09655037522316, 40.88809356093407, 38.15338410437107, 44.69183765351772, 47.971187084913254, 47.36713349819183, 45.97776085138321, 45.33510513603687, 42.43071958422661, 43.152190670371056, 40.51688767969608, 40.6121713668108, 39.776884987950325, 36.98682390153408, 38.36805358529091, 40.71889244019985, 41.253155171871185, 45.11794678866863, 45.626526698470116, 47.127810940146446, 52.026325687766075, 53.09067517518997, 51.74697607755661, 51.377852484583855, 48.884369283914566, 39.61621820926666, 5.312159601598978, 1.847531518433243, 3.7077365443110466, 13.108257316052914, 14.02963662520051, 3.0281774466857314, 0.34622432955075055, 1.7790677421726286, 2.1173656079918146, 13.039581701159477, 53.121290132403374, 42.373787239193916, 33.775042444467545, 39.1290083527565, 44.69738535583019, 1.9777748733758926, 0.1631839803303592, 0.10929760974249803, 0.06304243943304755, 0.2030700392788276, 0.10912866724538617, 0.13297785742906854, 0.14893366140313447, 0.10502252000151202, 0.21817314525833353, 0.13217400759458542, 0.17797391483327374, 0.13508120784536004, 0.2275577065302059, 0.14806634309934452, 0.1906977844191715], [0.005379184231060208, 0.026197514271188993, 0.02909831720899092, 0.053225424999254756, 0.030317016462504398, 0.047792276891414076, 0.011084790985478321, 0.08355040656169876, 0.03311039166874252, 0.07892477078712545, 0.08207196675357409, 0.02733873887336813, 0.0151744208051241, 0.06997579825110734, 0.058574135255184956, 0.06892596356919967, 0.039296385511988774, 0.08827405035845004, 0.05579061762546189, 0.06753047360689379, 2.2644607024267316, 38.50445866584778, 42.92706035077572, 36.02073714137077, 38.67513030767441, 27.501710169017315, 50.61827324330807, 7.555762035772204, 0.5495320342015475, 0.22901154414284974, 0.10079872750793584, 0.039106050608097576, 0.027453972143121064, 0.09977394773159176, 2.957808547653258, 26.205288134515285, 47.42821142077446, 54.738802537322044, 51.92384518682957, 55.850379690527916, 51.09767831861973, 49.49444554746151, 44.398706182837486, 41.19651161134243, 38.77439618110657, 38.62430423498154, 39.60485301911831, 42.109268233180046, 40.64788185060024, 43.125246316194534, 44.30808864533901, 49.31466959416866, 51.53832547366619, 51.10748179256916, 48.9391927421093, 44.725583642721176, 38.481325507164, 38.49731504917145, 37.313465774059296, 39.17242482304573, 40.37164427340031, 37.70331725478172, 38.197077959775925, 37.67046421766281, 39.410406053066254, 38.33892434835434, 38.060148507356644, 40.05300857126713, 39.26531083881855, 39.24898311495781, 39.526455625891685, 38.85272517800331, 37.95525133609772, 37.24243998527527, 38.985034078359604, 37.12409533560276, 48.44787910580635, 51.10858753323555, 53.42269375920296, 49.69532936811447, 51.15998737514019, 48.62798564136028, 47.4539740383625, 53.30870747566223, 49.37105856835842, 46.96765333414078, 46.48833945393562, 51.28267139196396, 52.78429001569748, 53.80991578102112, 43.8087422400713, 41.14264950156212, 46.80374912917614, 52.55138911306858, 52.245885506272316, 49.087616577744484, 46.19015425443649, 46.12993888556957, 44.97305676341057, 43.99082846939564, 39.23012472689152, 37.07494117319584, 34.27801765501499, 37.43159383535385, 36.79686829447746, 36.79249472916126, 37.49933660030365, 36.456315368413925, 37.17500880360603, 36.759174317121506, 36.42710633575916, 39.441533982753754, 39.11021836102009, 38.228103294968605, 37.30723790824413, 37.70689286291599, 36.72434538602829, 35.88683232665062, 37.391627579927444, 36.146749779582024, 36.443289667367935, 36.09989829361439, 37.68625237047672, 40.77375769615173, 42.0120694488287, 41.48996986448765, 41.13933227956295, 38.190766498446465, 37.70630769431591, 33.78616064786911, 36.06215871870518, 36.53750941157341, 37.80968114733696, 34.374456480145454, 34.77315008640289, 34.153627529740334, 38.71687486767769, 40.78095830976963, 41.781661212444305, 46.00608833134174, 49.64147865772247, 48.843988850712776, 48.26159410178661, 47.9715670645237, 19.258852377533913, 0.048334412058466114, 0.8919091592542827, 5.480914721265435, 7.578887119889259, 4.8759672325104475, 0.27191899018362164, 0.08163108650478534, 0.28610805224161595, 0.2078546059783548, 21.533729508519173, 41.64660885930061, 21.922161765396595, 21.97482693940401, 37.63591267168522, 14.436002969741821, 0.018273510759172495, 0.13015769625781104, 0.051652535767061636, 0.07671275510801934, 0.017359539197059348, 0.050743516185320914, 0.005909911196795292, 0.016533588204765692, 0.008281909795186948, 0.10016581654781476, 0.013835763584211236, 0.007319984360947274, 0.0145836313640757, 0.07976069624419324, 0.011126457939099055, 0.02432532059174264, 0.06271818769164383, 0.04247679629770573, 0.01320452245636261, 0.04539675406704191, 0.03879333926306572, 0.007824611384421587, 0.02721003933402244, 0.005397651648308965, 0.03378728601092007, 0.08928535273298621, 0.0941397703718394, 0.004297865789339994, 0.03662041621282697, 0.03211250361346174, 0.04610323783708736, 0.10471618370502256, 0.06286194911808707, 0.09102500625886023, 0.012198353888379643, 0.08829157246509567, 4.96773230843246, 46.852416917681694, 46.174172312021255, 29.62660364806652, 43.93370993435383, 33.89349728822708, 54.767992570996284, 7.834042003378272, 0.677345241419971, 0.13814555044518784, 0.19466726516839117, 0.15610224392730743, 0.1456904612132348, 0.13192123209591955, 3.674397370778024, 29.521885067224503, 49.77811932563782, 53.07384967803955, 52.08677664399147, 55.4786342382431, 52.14899070560932, 51.612280905246735, 46.03236012160778, 43.42859163880348, 39.825275391340256, 40.98574072122574, 39.401035755872726, 42.94023424386978, 42.80855230987072, 43.62827092409134, 45.412480384111404, 50.22510454058647, 52.74693801999092, 51.768615916371346, 49.773863554000854, 44.715875163674355, 38.343396708369255, 40.615237802267075, 38.3707058429718, 40.836161747574806, 41.350422352552414, 39.959818571805954, 40.05125306546688, 40.47339141368866, 42.16254897415638, 40.79614229500294, 39.13233317434788, 41.44820250570774, 40.481412783265114, 42.50212915241718, 41.62889041006565, 39.94412541389465, 39.19050805270672, 39.13220778107643, 40.749697387218475, 38.47667835652828, 49.41321350634098, 53.7033125013113, 52.504693418741226, 50.44032499194145, 54.180806279182434, 51.93289250135422, 49.44098241627216, 52.208924889564514, 51.80611610412598, 48.573963940143585, 49.00001987814903, 54.17945735156536, 54.0259113907814, 54.99642871320248, 46.11638501286507, 43.50576549768448, 53.108317628502846, 53.35142478346825, 51.734512746334076, 50.91123752295971, 46.890175491571426, 48.7558563798666, 45.93562111258507, 45.32924585044384, 40.1557170599699, 38.19232061505318, 37.74899460375309, 39.73146602511406, 38.37781526148319, 38.633366748690605, 39.202963784337044, 37.88136430084705, 37.96562097966671, 39.52239364385605, 38.4583405405283, 39.75566312670708, 40.57861536741257, 39.91456679999828, 39.86415110528469, 39.3854071944952, 38.0284658074379, 37.93420426547527, 38.39358061552048, 37.64941714704037, 37.492618560791016, 36.78277485072613, 40.064677745103836, 42.77588926255703, 45.204859524965286, 42.566512897610664, 41.714834198355675, 40.53171828389168, 38.88222299516201, 36.51311852037907, 37.263935431838036, 38.16018953919411, 39.49281603097916, 36.21688261628151, 36.562819853425026, 37.44199387729168, 40.392531752586365, 42.67653979361057, 43.4004807472229, 46.94891273975372, 51.3256698846817, 50.11167302727699, 48.73079292476177, 47.90720611810684, 19.601219706237316, 0.7441058184485883, 3.4621509723365307, 6.785989366471767, 10.417911428958178, 5.52142814733088, 0.582038814900443, 0.014915432602720102, 0.3578723076498136, 0.6577180477324873, 23.88178501278162, 47.56760694086552, 30.996570736169815, 21.94078266620636, 40.13505756855011, 20.262150540947914, 0.03640762763097882, 0.07660811970708892, 0.03449731724685989, 0.07547564688138664, 0.03171323929564096, 0.031005774035293143, 0.03827740190899931, 0.013032063106948044, 0.02640236372826621, 0.01722966891975375, 0.0610274268547073, 0.05145831200934481, 0.012111676605854882, 0.04354292483185418, 0.00805592675533262, 0.05232364506809972, 0.09216767619363964, 0.1250544365029782, 0.11745730822440237, 0.10912021418334916, 0.1777014130493626, 0.14836784801445901, 0.11141611481434666, 0.15144712262554094, 0.12004031610558741, 0.1480146005633287, 0.18597371759824455, 0.10014378960477188, 0.24580095807323232, 0.2789176505757496, 0.31713499047327787, 0.2213113018660806, 0.15261086955433711, 0.22309358435450122, 0.2153060061391443, 0.23348973743850365, 5.554267410188913, 53.31797517836094, 55.72217456996441, 45.2717587351799, 49.70639817416668, 37.22983606159687, 61.10868193209171, 10.097303632646799, 0.984272703062743, 0.23515879787737504, 0.43612812878564, 0.5412587500177324, 0.30566788860596716, 0.24301224912051111, 4.4107757695019245, 32.71138831973076, 50.25830715894699, 53.922993913292885, 54.52605955302715, 59.81944911181927, 54.337217286229134, 55.91997295618057, 48.49375784397125, 45.11401779949665, 41.9020539522171, 42.885775566101074, 43.14818188548088, 46.57095842063427, 44.67563912272453, 47.87493824958801, 46.946169286966324, 54.07840557396412, 56.85647450387478, 55.08077658712864, 52.47745268046856, 48.862072080373764, 41.99300207197666, 43.342404663562775, 42.38333232700825, 43.03877055644989, 44.92553271353245, 42.41512522101402, 42.957603111863136, 42.051598727703094, 43.560558557510376, 42.45243541896343, 40.30951000750065, 43.40092912316322, 43.51585775613785, 44.990539625287056, 43.64214777946472, 42.05594949424267, 41.40449345111847, 40.12738198041916, 42.540317103266716, 39.39171485602856, 51.2714733928442, 55.73981322348118, 55.79536244273186, 52.078831270337105, 51.49541437625885, 51.40354670584202, 50.82915812730789, 56.31742402911186, 53.70743528008461, 50.80380588769913, 51.03905886411667, 54.31824490427971, 56.85061901807785, 56.65152110159397, 44.22502510249615, 41.919069439172745, 49.577003717422485, 54.73619967699051, 55.92661499977112, 53.71556684374809, 49.66061823070049, 49.48323994874954, 48.65707688033581, 48.13387915492058, 43.34476053714752, 40.31492091715336, 37.92318485677242, 41.475458443164825, 40.07201515138149, 40.800899639725685, 40.39108783006668, 41.06351114809513, 40.28923809528351, 40.32735764980316, 40.38473457098007, 43.4416401386261, 44.201766550540924, 41.692153215408325, 42.62417480349541, 42.02310785651207, 39.64485727250576, 39.29406389594078, 38.911382630467415, 39.479737132787704, 39.433208629488945, 40.299387350678444, 42.71683283150196, 43.892915323376656, 46.5101882815361, 45.987746715545654, 44.64724324643612, 43.26329670846462, 41.04810297489166, 37.08944499492645, 40.120321959257126, 41.40420846641064, 42.49052457511425, 38.41798670589924, 40.04857800900936, 39.791138023138046, 42.700843289494514, 44.4831832498312, 46.037132665514946, 50.934575870633125, 53.898443430662155, 52.02377602458, 49.94320146739483, 48.76285560429096, 23.076125644147396, 0.762169158551842, 2.7691451087594032, 11.213746424764395, 14.856097027659416, 12.100503891706467, 1.4764441433362663, 0.18176897603552788, 0.8130923041608185, 1.7828566138632596, 28.050847202539444, 52.87043519318104, 34.04526874423027, 29.063148982822895, 52.141824290156364, 26.101031228899956, 0.14826601051026955, 0.254482141463086, 0.1698182907421142, 0.2071165104280226, 0.07266159358550794, 0.12891066551674157, 0.1139467122266069, 0.14827975508524105, 0.11822256637969986, 0.16184557636734098, 0.1511834969278425, 0.15278769365977496, 0.10560755501501262, 0.18955986422952265, 0.05427359355962835, 0.13140448951162398], [0.046547695237677544, 0.018996525868715253, 0.02294787595019443, 0.08550971353542991, 0.07254771844600327, 0.07669898826861754, 0.07685585602303036, 0.05070697283372283, 0.0694140963605605, 0.031113602526602335, 0.07489483468816616, 0.06423466998967342, 0.02831524750945391, 0.018143868692277465, 0.09802572982152924, 0.03854624861560296, 0.011940108761336887, 0.05332639419066254, 0.03455272970313672, 0.016892739440663718, 0.1534385868581012, 13.607464078813791, 44.11503620445728, 28.177488707005978, 33.87506067752838, 28.374973610043526, 45.82570441067219, 15.786493252962828, 0.1552032952895388, 0.9443819092120975, 0.069007911515655, 0.12160770231275819, 0.03133262143819593, 0.2168021906982176, 0.12250901840161532, 4.591321656480432, 29.034775905311108, 52.210186421871185, 53.97708021104336, 52.49990187585354, 48.330925181508064, 48.9770083129406, 43.1295020878315, 41.44698277115822, 39.95437726378441, 41.36054880917072, 42.30675123631954, 44.75652918219566, 47.085895389318466, 48.71499337255955, 51.31734073162079, 51.52120739221573, 53.109902143478394, 52.81667947769165, 50.45496180653572, 49.76502902805805, 42.631177827715874, 39.38005328178406, 38.41274678707123, 38.50635476410389, 38.06573040783405, 37.63918809592724, 39.59316864609718, 38.62441062927246, 38.693281933665276, 37.28642262518406, 38.08285988867283, 39.21646825969219, 38.37433084845543, 39.46483813226223, 38.35820831358433, 39.014277309179306, 38.31115923821926, 36.59964747726917, 37.96934477984905, 38.321882262825966, 45.8794791251421, 51.304930597543716, 54.143891260027885, 50.27202062308788, 46.14044912159443, 48.74592371284962, 47.02328234910965, 51.71999752521515, 50.06450995802879, 52.86212123930454, 48.38625781238079, 51.10475353896618, 50.532245859503746, 51.97365291416645, 47.46920742094517, 46.05839632451534, 47.1357487142086, 52.92231760919094, 53.14423710107803, 48.22761632502079, 46.869405806064606, 43.50974768400192, 41.73801675438881, 39.916402101516724, 38.40087242424488, 36.7090056091547, 36.03692427277565, 36.960415318608284, 36.78299903869629, 37.85538129508495, 36.51418626308441, 38.181369602680206, 38.018662333488464, 36.27754256129265, 37.631003335118294, 36.83483965694904, 36.62459313869476, 37.25402556359768, 38.33282947540283, 36.25831939280033, 38.657514452934265, 40.05243860185146, 37.92809799313545, 36.38015225529671, 36.06075279414654, 35.547841116786, 36.543114110827446, 41.24443084001541, 41.54458813369274, 40.16380302608013, 39.64117906987667, 38.467676639556885, 36.50570511817932, 33.207083120942116, 34.927881583571434, 36.01940721273422, 34.474752098321915, 34.79331560432911, 36.66960932314396, 35.587879568338394, 38.042699843645096, 39.915991723537445, 40.42233355343342, 44.84687313437462, 48.64715941250324, 48.774752765893936, 53.52412931621075, 39.06533896923065, 4.77709511294961, 0.501167873153463, 3.0939127318561077, 5.504909008741379, 10.428443513810635, 4.584733285009861, 0.7366101269144565, 0.17384702456183732, 0.27691483148373663, 2.2164405416697264, 29.381210915744305, 35.02667248249054, 21.104717329144478, 26.859155148267746, 39.07758571207523, 5.000483701005578, 0.028228989540366456, 0.08720493467990309, 0.02681277324882103, 0.035604935546871275, 0.10066843606182374, 0.021650915368809365, 0.07383252450381406, 0.05567152889852878, 0.04814425155927893, 0.037419675863930024, 0.0613244380656397, 0.002740372642620059, 0.08686740591656417, 0.0036511865982902236, 0.0356144239049172, 0.0640333179035224, 0.018139803578378633, 0.09375550856930204, 0.054178702557692304, 0.053271349097485654, 0.08118423938867636, 0.04862724497797899, 0.05588760890532285, 0.046246973288361914, 0.08730450121220201, 0.05406692027463578, 0.04467231032322161, 0.08505348567268811, 0.04296248371247202, 0.049820937565527856, 0.0391040319664171, 0.01358758197966381, 0.10099763050675392, 0.06152902220492251, 0.05833918614371214, 0.055644236417720094, 0.41774821816943586, 21.853296160697937, 51.37230858206749, 30.957622826099396, 41.45172491669655, 35.29359295964241, 50.326585695147514, 15.352697130292654, 0.12438072968507186, 1.2916074553504586, 0.214959972363431, 0.13305943430168554, 0.020945878786733374, 0.5051787954289466, 0.30480572080705315, 6.552100516855717, 31.05868600308895, 53.80333453416824, 53.95059183239937, 54.670938178896904, 51.01486176252365, 52.02567972242832, 45.1092604547739, 44.51132833957672, 40.20506501197815, 43.82894575595856, 43.03147874772549, 46.82233013212681, 47.839052975177765, 52.217071652412415, 52.43273288011551, 53.4488819539547, 54.23911415040493, 55.32649040222168, 53.21511849761009, 51.63357116281986, 43.48517820239067, 41.665398851037025, 40.17101503908634, 41.531376242637634, 39.7280690073967, 41.322030276060104, 40.25511212646961, 40.23468442261219, 41.11786723136902, 40.902069211006165, 40.29046542942524, 40.97412094473839, 39.522177055478096, 40.19270047545433, 40.29524937272072, 40.66781938076019, 39.06112499535084, 38.4005456417799, 38.30221451818943, 42.45676338672638, 47.54553772509098, 54.6583266556263, 53.821968734264374, 51.492811515927315, 51.25144846737385, 49.86207202076912, 50.63788779079914, 52.65887014567852, 52.64104910194874, 52.73460768163204, 49.947092458605766, 51.391881331801414, 51.44904546439648, 55.36874793469906, 47.947434559464455, 47.16004841029644, 51.74477979540825, 53.80512423813343, 53.09083856642246, 49.82060864567757, 47.83900737762451, 45.364143177866936, 43.606726080179214, 41.50887385010719, 41.597336903214455, 37.56128087639809, 38.491155579686165, 38.640346974134445, 39.58088010549545, 39.678287878632545, 36.954662427306175, 39.08223286271095, 39.377537816762924, 37.41505332291126, 38.61335702240467, 38.10528248548508, 37.968231439590454, 38.35139147937298, 40.06142891943455, 37.65925481915474, 39.6028733253479, 41.44287899136543, 38.477692902088165, 38.334820568561554, 37.33850263059139, 36.86585359275341, 38.325096890330315, 42.564179822802544, 43.01358550786972, 41.32094733417034, 41.58163234591484, 40.31909689307213, 39.22895438969135, 36.5390445291996, 36.80979520082474, 36.73532299697399, 36.798585802316666, 36.694509387016296, 37.5371977686882, 36.89447745680809, 39.87574428319931, 42.501779571175575, 42.6777633279562, 46.444915384054184, 49.98650774359703, 49.7811895608902, 52.05674305558205, 41.17473118007183, 5.945138186216354, 1.8529168982058764, 7.253408934921026, 9.81765953823924, 12.36031400039792, 8.860763534903526, 1.2401718716137111, 0.20575655449647456, 0.27526934165507555, 3.240829473361373, 33.65381374955177, 43.68824690580368, 23.02105139940977, 27.083122730255127, 47.14160040020943, 8.046648669987917, 0.1690787257393822, 0.16509043896803632, 0.022517957222589757, 0.043869484652532265, 0.06389953836333007, 0.06486936952569522, 0.01185725075629307, 0.05326498518115841, 0.051918094759457745, 0.02450441381370183, 0.05363625197787769, 0.04984413710189983, 0.0989345861307811, 0.010025045849033631, 0.08252176019595936, 0.037785339445690624, 0.19007841765414923, 0.1405407875427045, 0.16829862463055179, 0.17144120443845168, 0.26354462548624724, 0.11565837936359458, 0.2576586522627622, 0.1402490641339682, 0.15263228793628514, 0.12512381246779114, 0.2049082945450209, 0.16965188639005646, 0.17901586048537865, 0.18040240014670417, 0.2184007767937146, 0.0979268534865696, 0.14688831724924967, 0.15997245500329882, 0.09342857767478563, 0.07593067988636903, 0.5327738053165376, 24.230311810970306, 59.28534597158432, 36.80852606892586, 44.40100885927677, 38.20365160703659, 56.22188575565815, 19.637686349451542, 0.22765222645830363, 2.3244806192815304, 0.5322589329443872, 0.32709544349927455, 0.2648922469234094, 0.3603975096484646, 0.33027646655682474, 6.164169833064079, 32.534367218613625, 53.63648168742657, 54.635790064930916, 58.05670469999313, 52.42804393172264, 55.56195616722107, 46.40447415411472, 47.265861332416534, 43.01836185157299, 45.72531759738922, 46.6503931581974, 48.79165805876255, 51.15473225712776, 54.05590318143368, 55.273319855332375, 55.65203793346882, 56.63615472614765, 59.059360697865486, 54.00658182799816, 53.9651944488287, 46.37964628636837, 44.69381734728813, 41.922713443636894, 42.90910251438618, 43.13368186354637, 43.71059350669384, 44.75125126540661, 42.1958351880312, 42.33588807284832, 41.22944064438343, 42.62414440512657, 43.43096651136875, 42.46221989393234, 42.134932056069374, 42.756453305482864, 44.08313311636448, 41.72562561929226, 39.23357114195824, 41.559658125042915, 43.14881645143032, 49.00800324976444, 57.15540826320648, 56.41678489744663, 52.13867045938969, 49.60259534418583, 49.596717059612274, 49.74050894379616, 56.77798971533775, 53.531614914536476, 57.10743963718414, 51.75514183938503, 54.52119201421738, 53.16266991198063, 55.30940651893616, 47.49308533966541, 46.554695293307304, 50.963241532444954, 54.71950717270374, 57.01147958636284, 52.295218259096146, 50.772632360458374, 46.95393227040768, 47.11202658712864, 45.35431310534477, 43.59178528189659, 39.518840834498405, 39.630805626511574, 40.25825835764408, 39.46031637489796, 42.14434415102005, 38.531399220228195, 42.55315661430359, 41.43665872514248, 39.114546328783035, 40.910918936133385, 40.17318852245808, 39.4239941239357, 40.25968708097935, 42.07391493022442, 39.82841022312641, 41.85217782855034, 44.43011909723282, 39.92342032492161, 40.13881556689739, 39.80065271258354, 38.37758727371693, 40.29922395944595, 45.02910755574703, 46.25263810157776, 43.89893800020218, 43.699536100029945, 43.612668961286545, 41.28794610500336, 37.200110256671906, 40.41589289903641, 40.212451815605164, 40.15446312725544, 39.51412908732891, 41.156100779771805, 39.89606939256191, 41.64150953292847, 44.77476820349693, 45.48959344625473, 49.65380519628525, 51.574567928910255, 52.91823662817478, 55.911142230033875, 41.17808260023594, 7.065488593652844, 1.933707925491035, 9.867526162415743, 13.044824469834566, 16.968867257237434, 10.813138671219349, 1.8322184588760138, 0.4510496015427634, 0.6399727624375373, 4.860850218683481, 38.22477087378502, 46.53653606772423, 31.24388236552477, 34.151640236377716, 55.143518820405006, 11.671285573393106, 0.3296343010151759, 0.2961738605517894, 0.1397002162411809, 0.17514032078906894, 0.2557723503559828, 0.13143421994755045, 0.09645890022511594, 0.11652704837615602, 0.20696122344816104, 0.3144310199422762, 0.15977767092408612, 0.1503360236529261, 0.21416152536403388, 0.11918266798602417, 0.10325559254852124, 0.13462741422699764], [0.03646239070803858, 0.0923824759956915, 0.0860605355410371, 0.03964952535170596, 0.012624420869542519, 0.058146639639744535, 0.04719837692391593, 0.01792450468201423, 0.023670464324823115, 0.0701826941804029, 0.03547082204022445, 0.059950329377898015, 0.016590961786278058, 0.023849694844102487, 0.04518170564551838, 0.003596500287130766, 0.04154172733251471, 0.047017949691507965, 0.04857617779634893, 0.05440677938167937, 0.13367443723836914, 4.580926839262247, 41.55989371240139, 39.06256891787052, 20.61571206897497, 26.773961819708347, 41.14332586526871, 29.132880941033363, 0.3198952751699835, 1.7069495120085776, 0.5424607917666435, 0.09314749666373245, 0.0277488496794831, 0.4196842439705506, 0.3057150001404807, 0.2857386408140883, 5.702698370441794, 38.46533976495266, 55.286182165145874, 56.13922119140625, 52.13769771158695, 49.74118910729885, 46.842290461063385, 41.15681894123554, 42.487819120287895, 46.85688927769661, 46.10412307083607, 49.86969441175461, 49.86656337976456, 50.38347624242306, 53.695887699723244, 54.756665378808975, 52.561648562550545, 51.30735486745834, 51.7377045750618, 48.791962042450905, 44.585181176662445, 39.344772174954414, 37.92008422315121, 38.90862017869949, 37.188790664076805, 36.969367638230324, 37.44080074131489, 38.713329657912254, 40.55516682565212, 40.24528205394745, 38.21496739983559, 38.22334975004196, 40.285753682255745, 39.23514045774937, 38.000123128294945, 38.48799794912338, 37.75859288871288, 36.9218435883522, 37.51913733780384, 36.79703548550606, 45.37840761244297, 49.45234760642052, 52.67562724649906, 51.65328070521355, 42.797304913401604, 50.53120471537113, 47.273373529314995, 50.357679426670074, 53.733585476875305, 51.31370052695274, 50.04638493061066, 50.91692581772804, 54.778282418847084, 50.73240391910076, 48.07793855667114, 50.87250240147114, 45.59033744037151, 52.41615056991577, 49.368018731474876, 46.188596338033676, 44.56626959145069, 42.25095883011818, 40.82516893744469, 40.462463200092316, 36.414810195565224, 35.647494569420815, 34.93209555745125, 36.22338026762009, 36.06017142534256, 37.618133425712585, 36.634833589196205, 38.20625826716423, 36.90327398478985, 36.6524912416935, 38.28328773379326, 37.74813584983349, 37.39388465881348, 36.08613163232803, 36.83392770588398, 37.10721284151077, 42.668111845850945, 44.23771262168884, 42.75149457156658, 37.15736635029316, 35.11790558695793, 37.14852422475815, 33.913712203502655, 38.50277155637741, 40.116985738277435, 39.79233875870705, 39.14621762931347, 37.02568061649799, 35.83454333245754, 34.092796593904495, 34.15166683495045, 33.73681269586086, 34.050178080797195, 34.14858520030975, 35.06613336503506, 36.4380307495594, 38.19142386317253, 40.44711582362652, 41.53106465935707, 42.993119806051254, 47.389894276857376, 49.89293776452541, 49.67932842671871, 24.680844135582447, 0.3547679039184004, 1.3694579154253006, 5.248604211956263, 7.664260463789105, 10.056076794862747, 3.733305372297764, 0.10666374248103239, 0.08010526798898354, 0.21625926514388993, 10.2018360234797, 33.37997764348984, 28.10972884297371, 26.851945035159588, 27.274689450860023, 30.283018425107002, 0.5112664250191301, 0.08831527666188776, 0.0296274740685476, 0.08443862374406308, 0.013229860305727925, 0.02339788461540593, 0.06596443068701774, 0.017914205527631566, 0.0799083019956015, 0.015085889081092319, 0.024290736510010902, 0.05182151908229571, 0.06246773511520587, 0.030191365294740535, 0.023191133404907305, 0.03988875665527303, 0.025215907080564648, 0.06649306247709319, 0.03258892160374671, 0.08489715226460248, 0.030000015503901523, 0.022910679508640897, 0.03247325417760294, 0.021464615892909933, 0.06339199098874815, 0.03762445667234715, 0.09374909641337581, 0.04040077175886836, 0.06510165432700887, 0.026004336941696238, 0.03385517768037971, 0.05968352357740514, 0.005267632941468037, 0.014879428235872183, 0.03578682109946385, 0.04775057932420168, 0.001338887054771476, 0.12139037178712897, 7.599989762529731, 48.93352344632149, 38.355856239795685, 25.58323871344328, 37.711353823542595, 47.119534984230995, 32.19289094209671, 0.26071386644616723, 2.3847218742594123, 1.6661475389264524, 0.013497648524207762, 0.13126621255651116, 0.6295332382433116, 0.798213193193078, 0.10489904889254831, 7.64004341326654, 40.80883741378784, 55.718199983239174, 57.05391190946102, 52.69389666616917, 52.882548943161964, 48.35185445845127, 44.072942063212395, 42.78995990753174, 47.56011374294758, 48.85714374482632, 52.39324539899826, 52.35112465918064, 53.74254159629345, 54.54423017799854, 55.029236152768135, 53.5129427164793, 53.79665069282055, 53.83454605937004, 51.35158069431782, 45.687125846743584, 41.454928144812584, 39.575264006853104, 39.95587818324566, 40.23506440222263, 39.80180025100708, 39.77957524359226, 41.47554963827133, 40.957432240247726, 42.52962447702885, 40.91594986617565, 40.57510435581207, 42.657985389232635, 41.10290743410587, 39.03662770986557, 40.12692220509052, 39.05401557683945, 39.40606668591499, 40.066752433776855, 39.9526559561491, 47.77901999652386, 53.08559864759445, 54.773601070046425, 53.18272523581982, 47.36927278339863, 51.61286987364292, 49.94510896503925, 52.4471341073513, 53.085636645555496, 53.450671657919884, 52.00573079288006, 53.23953598737717, 54.781911224126816, 54.04026702046394, 48.59394706785679, 50.34442573785782, 49.92501184344292, 51.73202767968178, 50.736378505825996, 46.37993507087231, 45.49855716526508, 44.00016836822033, 43.19667488336563, 41.75206080079079, 39.338548108935356, 37.89078779518604, 37.50366076827049, 37.586800307035446, 38.46081420779228, 39.599996879696846, 38.967600613832474, 38.591075018048286, 39.660314843058586, 38.676851615309715, 39.63873580098152, 38.15839983522892, 37.834433019161224, 39.00230035185814, 37.781053483486176, 38.476826548576355, 44.01089899241924, 45.806443244218826, 43.399310410022736, 39.01533365249634, 37.75059811770916, 39.39590983092785, 35.71714103221893, 40.44053457677364, 42.19042047858238, 42.41586998105049, 40.034252777695656, 38.06922622025013, 38.22045050561428, 35.87742783129215, 36.78361460566521, 37.3628631234169, 36.09415300190449, 35.85478864610195, 37.94920966029167, 38.768502697348595, 40.68895764648914, 42.18677647411823, 43.162187933921814, 46.119375452399254, 49.96196486055851, 50.7165701687336, 49.82853502035141, 27.611543275415897, 0.752199087291956, 4.889377187937498, 10.316072143614292, 9.777205009013414, 7.060609180480242, 10.014327485114336, 1.8349283072166145, 0.030419054346566554, 0.278688000398688, 10.461804773658514, 38.627895042300224, 34.38500851392746, 27.961835078895092, 29.86945241689682, 39.123532846570015, 1.3108962890692055, 0.11647373990854248, 0.012980803894606652, 0.04486757308768574, 0.034984923113370314, 0.03137266030535102, 0.024956331653811503, 0.031897191729513, 0.028996082655794453, 0.0016044022140704328, 0.024799196726235095, 0.07164816866861656, 0.03816020194790326, 0.060399970680009574, 0.021955260854156222, 0.017272101213166025, 0.013983998305775458, 0.2132666140096262, 0.12389168405206874, 0.2657779853325337, 0.13346947089303285, 0.14240093616535887, 0.16835578484460711, 0.12729006732115522, 0.1933930569794029, 0.22907679376658052, 0.22438558924477547, 0.12236415117513388, 0.17525156872579828, 0.094335860630963, 0.3091008559567854, 0.10132085808436386, 0.21026781789259985, 0.12825683341361582, 0.09053064684849232, 0.1521568384487182, 0.11285925065749325, 0.2705821447307244, 9.323793388903141, 55.809946060180664, 49.46731120347977, 30.170384868979454, 39.50501337647438, 50.03485634922981, 37.25740738213062, 0.446766993845813, 3.361347606405616, 2.924500722438097, 0.22776273224735633, 0.30066239938605577, 0.98904411890544, 0.42429508874192834, 0.6904360733460635, 8.968493454158306, 42.795059233903885, 57.56030693650246, 59.83822390437126, 56.99704796075821, 55.52319444715977, 51.981210708618164, 45.80270804464817, 45.50718650221825, 53.160686418414116, 50.5822017788887, 55.53673692047596, 55.92170566320419, 55.17538771033287, 55.88110864162445, 57.277290523052216, 54.62947100400925, 54.844630658626556, 55.281930193305016, 51.39039561152458, 47.51253269612789, 43.67885001003742, 41.573797166347504, 42.29551903903484, 41.39451138675213, 42.15668588876724, 43.034925162792206, 43.80395829677582, 43.60039561986923, 43.48129481077194, 41.84997394680977, 43.19462679326534, 44.82189707458019, 43.84335458278656, 41.615731716156006, 42.21878595650196, 40.488978177309036, 40.91905049979687, 40.65325856208801, 39.55212324857712, 49.38020467758179, 53.15530210733414, 57.96253815293312, 53.38080480694771, 48.968435972929, 53.69445517659187, 48.21112520992756, 53.69539752602577, 55.7835640758276, 56.48042768239975, 52.754993587732315, 54.15446609258652, 58.129698783159256, 54.91788312792778, 51.09187223017216, 49.43493694067001, 51.362683698534966, 53.99993598461151, 51.87186777591705, 49.71712499856949, 48.22542004287243, 46.75722822546959, 46.209457218647, 45.61071574687958, 40.58395028114319, 39.59294065833092, 37.76894733309746, 40.44981747865677, 40.855274721980095, 41.558955162763596, 40.39829604327679, 41.07488013803959, 42.14392617344856, 40.08513204753399, 43.28690484166145, 40.71638077497482, 39.687308594584465, 40.6406394392252, 40.436358600854874, 40.326742082834244, 46.39345094561577, 48.46803322434425, 47.07264170050621, 41.544770523905754, 40.05263239145279, 42.26901926100254, 38.068185076117516, 42.97848679125309, 43.524198308587074, 44.247645288705826, 43.441336154937744, 41.30197115242481, 38.673454597592354, 37.00359620153904, 38.73519368469715, 37.759976014494896, 38.699840381741524, 38.707755357027054, 40.58902680873871, 41.65072403848171, 43.624588921666145, 45.12202017009258, 44.877115711569786, 47.012217342853546, 50.813605561852455, 52.70463488996029, 50.12281782925129, 29.175201170146465, 1.1041301465593278, 4.541810313239694, 11.475617922842503, 16.508939936757088, 17.194799333810806, 12.384056076407433, 0.7792590383905917, 0.19320572406286374, 0.5485747824423015, 15.868140421807766, 42.86758214235306, 40.83450123667717, 36.33078910410404, 35.80014377832413, 46.49392895400524, 1.6882684081792831, 0.20252221554983407, 0.18173158663557842, 0.172301932470873, 0.17707400140352547, 0.14906364114722237, 0.13804564252495766, 0.08179795840987936, 0.16801846388261765, 0.19892094394890592, 0.11050310989958234, 0.13816318387398496, 0.18579960975330323, 0.21107205364387482, 0.13511352095520124, 0.09004603925859556, 0.06829446268966421], [0.005216755935180117, 0.029281627685122658, 0.07129844641895033, 0.016509813503944315, 0.055336582809104584, 0.09382732619997114, 0.030449144724116195, 0.05795495402708184, 0.055974889182834886, 0.03201195002475288, 0.08549023215891793, 0.05576158109761309, 0.09228872047970071, 0.031743114450364374, 0.041014720845851116, 0.027349500014679506, 0.011806988804892171, 0.14561299583874643, 0.11375792470062152, 0.0712712318636477, 0.09646446633269079, 0.8505852485541254, 20.227927677333355, 41.16909608244896, 26.269457191228867, 33.19916434586048, 30.152979902923107, 35.175506696105, 3.120992216281593, 0.6040623143780977, 1.2433904176577926, 0.17355101153953, 0.11775433056754991, 0.9467628970742226, 1.5338945668190718, 0.11409795450163074, 0.19803879753453657, 14.914970118552446, 53.32953415811062, 52.875697910785675, 53.69011580944061, 48.10376197099686, 47.82310523092747, 43.88406939804554, 46.09483256936073, 43.60384963452816, 48.76308359205723, 48.18688631057739, 51.58667027950287, 51.84854842722416, 54.01291988790035, 54.02821026742458, 51.219135001301765, 50.08409410715103, 51.45954430103302, 48.73659521341324, 43.24435852468014, 40.227407813072205, 38.48141670227051, 37.33472563326359, 38.337917402386665, 35.69493502378464, 39.05414097011089, 38.85478846728802, 39.02139812707901, 39.09134857356548, 39.11097452044487, 39.89202260971069, 39.49083253741264, 42.11097814142704, 39.81163032352924, 38.550812378525734, 37.51726783812046, 38.81590895354748, 38.47211480140686, 37.419335693120956, 42.20036454498768, 49.68997925519943, 51.91089928150177, 55.36567769944668, 41.653513088822365, 49.04840648174286, 52.02250689268112, 47.152258828282356, 53.08997601270676, 51.23707763850689, 51.05904959142208, 50.25381959974766, 54.00193087756634, 48.04180629551411, 47.163130044937134, 52.48170845210552, 45.933835208415985, 51.26832336187363, 49.447210282087326, 43.891585394740105, 44.05980236828327, 40.89382365345955, 39.536376893520355, 37.92669586837292, 37.925115153193474, 37.10000462830067, 37.772040367126465, 36.677752286195755, 37.701896131038666, 35.88984936475754, 35.93558371067047, 37.29744203388691, 37.82937169075012, 36.498436108231544, 38.51599104702473, 37.397030889987946, 36.71810232102871, 35.06429806351662, 36.18643864989281, 41.24809004366398, 48.42161491513252, 49.58847150206566, 46.701682806015015, 44.98643584549427, 38.52700285613537, 35.91876961290836, 35.39508171379566, 34.66786153614521, 37.27924861013889, 38.007171750068665, 38.14686745405197, 36.14054471254349, 34.211160242557526, 34.95044097304344, 33.36578920483589, 34.25749495625496, 32.197009921073914, 33.8147085160017, 33.76909576356411, 37.100954577326775, 38.54218304157257, 41.06460548937321, 41.869763284921646, 46.91910333931446, 46.89510762691498, 50.802209973335266, 47.56984502077103, 9.411614276468754, 0.8939094550441951, 3.4917352348566055, 8.734355717897415, 9.70730111002922, 8.656388651579618, 8.236218597739935, 2.7275019558146596, 0.03713262798555661, 0.10888407763559371, 23.099319599568844, 33.0666084587574, 29.91093099117279, 21.431011520326138, 34.13005739450455, 9.949308224022388, 0.11241997344768606, 0.23041016596835107, 0.03496789082419127, 0.10232086497126147, 0.07964083197293803, 0.00886559688296984, 0.1360678783385083, 0.023888943323981948, 0.059631499025272205, 0.055101240359363146, 0.017020212580973748, 0.06598250198294409, 0.019310330026200972, 0.030932353365642484, 0.05890755252039526, 0.04338567487138789, 0.06261675094719976, 0.009146434840658912, 0.053670283159590326, 0.03724915630300529, 0.026390435559733305, 0.048703278007451445, 0.04987610511307139, 0.009512959313724423, 0.040385780375800095, 0.053133962719584815, 0.13592921546660364, 0.11424594616983086, 0.015807879099156708, 0.017941160331247374, 0.031320761918323115, 0.045094970846548676, 0.06159289514471311, 0.012093175791960675, 0.031460846003028564, 0.05323790421243757, 0.0822984405385796, 0.1747911106212996, 1.9856075593270361, 30.157400965690613, 49.53251950442791, 23.78785975277424, 37.637033611536026, 42.08829715847969, 36.23017430305481, 2.311556087806821, 1.0965708084404469, 1.7939068959094584, 0.23122332233469933, 0.06325838956399821, 3.018215806223452, 3.216971978545189, 0.819744678447023, 0.14730298484209925, 17.697567455470562, 53.27068671584129, 54.43006530404091, 56.18990287184715, 50.916105061769485, 49.79157440364361, 45.98184183239937, 47.35087037086487, 46.423074156045914, 50.87076209485531, 50.08652977645397, 55.20569488406181, 52.65241429209709, 56.13380268216133, 54.619169756770134, 53.138791993260384, 53.34973767399788, 54.54426437616348, 49.78658527135849, 46.13691531121731, 40.813032388687134, 40.383940413594246, 39.76618476212025, 38.2064064592123, 38.63845847547054, 41.46563597023487, 40.35864897072315, 41.02372348308563, 42.00976297259331, 41.64878234267235, 40.99147841334343, 41.42908573150635, 42.720317244529724, 40.87840028107166, 39.47951294481754, 39.75226230919361, 39.878134354949, 40.89441642165184, 39.41572196781635, 44.84947979450226, 51.575400084257126, 54.10727262496948, 56.26738451421261, 47.67765283584595, 51.09384812414646, 50.94919368624687, 50.93312434852123, 55.126624926924706, 52.72829242050648, 52.35964000225067, 52.07335576415062, 53.25833737850189, 50.92736765742302, 50.67287251353264, 52.72296890616417, 48.15274514257908, 51.437965258955956, 51.807400435209274, 46.83776490390301, 45.14196150004864, 43.009284138679504, 41.36261969804764, 40.46489126980305, 39.14522208273411, 39.639054983854294, 38.05274270474911, 38.105065897107124, 38.6360228061676, 37.589843943715096, 38.689584732055664, 38.473114147782326, 39.91962052881718, 38.93544673919678, 38.537805676460266, 39.18290466070175, 37.445299699902534, 37.38110974431038, 38.34395907819271, 41.77520155906677, 49.5337088406086, 50.28030797839165, 48.27248431742191, 45.893754959106445, 40.55838145315647, 37.459389343857765, 37.07024842500687, 37.49545320868492, 38.65560695528984, 41.143607050180435, 39.744077548384666, 37.88854591548443, 35.57957701385021, 35.844966173172, 35.05947232246399, 36.342032700777054, 36.23644396662712, 35.32557964324951, 34.53044950962067, 39.5117162168026, 40.584299862384796, 42.46959529817104, 43.476298078894615, 48.38637940585613, 48.05434562265873, 50.74363611638546, 49.43773739039898, 11.194057781249285, 1.8151577305980027, 6.236460004001856, 10.565139278769493, 9.366405252367258, 9.899629689753056, 5.969689143821597, 3.4643510542809963, 0.06383208456099965, 0.0769432884408161, 24.654773734509945, 36.07124783098698, 34.42700766026974, 25.105467550456524, 38.20721961557865, 16.01407539099455, 0.06301316170720384, 0.0721340675954707, 0.0038114429526103777, 0.04461728378373664, 0.01499105559560121, 0.022488929971586913, 0.07865845851483755, 0.012530156982393237, 0.020226409287715796, 0.0243298662462621, 0.04353572971012909, 0.03946534656279255, 0.047384002900798805, 0.003258951346651884, 0.04010887765616644, 0.0633874416234903, 0.09543302207021043, 0.14814913709415123, 0.17915254924446344, 0.11387307633413002, 0.1514748195768334, 0.18256202019983903, 0.2618762478232384, 0.11109872051747516, 0.14996175857959315, 0.15174003347055987, 0.31912222446408123, 0.2814654732355848, 0.12277452173293568, 0.20864288555458188, 0.11955065449001268, 0.08303921524202451, 0.06438626107410528, 0.13941377692390233, 0.20054097811225802, 0.2826496143825352, 0.1731358838151209, 0.2664116013329476, 2.0185469230636954, 32.533801048994064, 55.65972112119198, 33.91656585037708, 44.33057203888893, 42.006840929389, 44.956170469522476, 3.904512310400605, 2.099490179680288, 3.2185405818745494, 0.5964163527823985, 0.17267688032006845, 3.9728932036086917, 3.460431802086532, 0.3699019574560225, 0.6239661807194352, 17.781043276190758, 55.82123905420303, 55.82673355937004, 58.85441109538078, 51.57161548733711, 52.432831674814224, 48.281831815838814, 50.00446178019047, 47.21546843647957, 54.07520994544029, 51.943429335951805, 57.15451531112194, 55.24145856499672, 58.256722167134285, 57.63770878314972, 53.901692256331444, 54.793941378593445, 56.36585623025894, 50.5376111716032, 47.77955196797848, 43.71779792010784, 42.757680639624596, 41.68421544134617, 40.929784923791885, 39.72893916070461, 43.6869777739048, 41.36341005563736, 44.17545296251774, 43.7931364774704, 43.93249399960041, 43.16833980381489, 43.58875684440136, 45.72839543223381, 43.71795751154423, 42.40983970463276, 41.4276722073555, 41.758611649274826, 42.8701888024807, 40.03769539296627, 47.308582440018654, 53.01572039723396, 56.436570435762405, 58.49771283566952, 48.526466488838196, 52.966079860925674, 49.32968258857727, 52.37358905375004, 55.90063199400902, 54.6172546595335, 53.247055783867836, 53.627578765153885, 56.096830666065216, 49.41658012568951, 54.011901542544365, 53.51998373866081, 48.83038938045502, 55.6359001994133, 51.86142973601818, 50.686589777469635, 48.46896417438984, 44.920976758003235, 43.87921705842018, 42.5186924636364, 40.86898058652878, 42.47157119214535, 40.56954525411129, 39.50436741113663, 40.74266776442528, 39.57742989063263, 40.49541123211384, 40.4212050139904, 42.152297124266624, 41.123840510845184, 40.1321317255497, 40.676399320364, 38.37458163499832, 38.37501861155033, 40.01777306199074, 43.612239584326744, 52.611513286828995, 53.712842389941216, 49.47897657752037, 48.06424789130688, 41.58040501177311, 40.97206525504589, 39.17343556880951, 40.545522943139076, 41.59821845591068, 42.87683464586735, 43.02561566233635, 39.65180329978466, 38.07481952011585, 38.28308254480362, 35.97588434815407, 38.4953011572361, 37.085793390870094, 38.418807461857796, 36.290359273552895, 41.72251358628273, 42.16192580759525, 45.18958054482937, 45.409839525818825, 50.4075213521719, 51.059026792645454, 51.9905012100935, 50.315687879920006, 12.831826899200678, 1.7431115778163075, 9.714722111821175, 15.532854963093996, 18.522607684135437, 20.301372036337852, 18.481459692120552, 7.005540635436773, 0.260825069854036, 0.2997343288734555, 29.405069835484028, 43.48890960216522, 42.239540442824364, 28.86723529547453, 48.789647966623306, 19.00059163570404, 0.25816764682531357, 0.35166887333616614, 0.13057594100246206, 0.2437543819542043, 0.10277385707013309, 0.1576462821685709, 0.23129274282837287, 0.10030974124674685, 0.14859763177810237, 0.17372071102727205, 0.09950952051440254, 0.14156273973640054, 0.11667487677186728, 0.0896315200952813, 0.23608720977790654, 0.201952068018727, 0.17511023412225768], [0.04658262441807892, 0.0529548305348726, 0.09755307080922648, 0.05746118462411687, 0.04853024998737965, 0.035555924114305526, 0.008613804729975527, 0.06822496055974625, 0.018739210281637497, 0.059070286952191964, 0.06177893672429491, 0.0698496108816471, 0.05733724596211687, 0.09067763661732897, 0.028540060739032924, 0.0531935015169438, 0.06217201524123084, 0.0579322331759613, 0.01719016996503342, 0.036074258605367504, 0.052611780192819424, 0.05359655449865386, 2.1218572044745088, 31.59641794860363, 36.619611606001854, 27.10205141454935, 32.80822232365608, 42.02773220837116, 12.957154624164104, 0.44607085932511836, 1.1511330306529999, 0.16567452403251082, 0.07359803552390076, 1.0757885361090302, 2.265213062055409, 0.762965512694791, 0.06595525032025762, 1.5980665921233594, 31.953245401382446, 55.92378035187721, 54.045902118086815, 50.72752118110657, 49.764542654156685, 44.3990633636713, 45.09534180164337, 45.34618154168129, 48.04022178053856, 49.21243607997894, 52.48755633831024, 52.261764854192734, 56.48103944957256, 52.11748659610748, 56.08672320842743, 51.60397455096245, 49.531417563557625, 46.92187339067459, 44.14764605462551, 40.73144316673279, 39.533204063773155, 39.80034492909908, 38.21013405919075, 38.35511527955532, 38.60166884958744, 40.85783578455448, 38.99510733783245, 39.662929102778435, 41.38981483876705, 41.06609120965004, 40.02303197979927, 39.311862140893936, 39.73594978451729, 38.4319319576025, 37.79567129909992, 39.896156787872314, 39.87802796065807, 37.582958713173866, 38.036832958459854, 45.93811757862568, 49.6354977786541, 53.588938638567924, 46.3460598886013, 45.86625963449478, 55.07918067276478, 44.59306575357914, 48.21804463863373, 49.404264986515045, 53.483703285455704, 51.45980268716812, 54.13568750023842, 50.61119802296162, 41.490395441651344, 45.17112113535404, 53.87776494026184, 52.27068677544594, 49.1744989156723, 46.19018845260143, 41.75206460058689, 41.49211674928665, 38.52879635989666, 40.73454760015011, 37.33849883079529, 38.96871775388718, 36.90464191138744, 36.91690765321255, 35.447898879647255, 37.3739243298769, 36.822767704725266, 37.5387366861105, 36.72877974808216, 35.62520116567612, 36.5404162555933, 38.12348730862141, 35.5796530097723, 36.25792421400547, 33.18171948194504, 42.53422603011131, 47.77561157941818, 49.66217614710331, 49.07169543206692, 47.48945273458958, 46.75576530396938, 40.48849560320377, 35.83355538547039, 35.54324336349964, 35.63623957335949, 37.385513707995415, 34.79036696255207, 35.05962431430817, 34.77356806397438, 34.50778752565384, 37.70656608045101, 37.53899127244949, 39.59996648132801, 36.14085249602795, 36.130106672644615, 37.773472890257835, 36.34137913584709, 41.18329972028732, 42.35048308968544, 46.17318816483021, 49.34812679886818, 53.24932426214218, 30.49502044916153, 1.9904925534501672, 0.736418830929324, 6.253120210021734, 9.879840351641178, 6.399481231346726, 5.72629320435226, 6.596378115937114, 4.533701548352838, 0.021934966825938318, 1.8488487415015697, 42.50904858112335, 31.788607835769653, 30.69801315665245, 34.90441024303436, 28.827934004366398, 2.2828595526516438, 0.014053248105483362, 0.02280900898767868, 0.04577469277137425, 0.06683047249680385, 0.09942202130332589, 0.06079755403334275, 0.05362888616218697, 0.027140952806803398, 0.005523299569176743, 0.05315172973496374, 0.011450808015069924, 0.036986959239584394, 0.04380561542348005, 0.024906988110160455, 0.048858372028917074, 0.042957815603585914, 0.0402599158405792, 0.039913919172249734, 0.024660027338541113, 0.021066911940579303, 0.036907653338857926, 0.029101538129907567, 0.020045592427777592, 0.06379302532877773, 0.016875085602805484, 0.0388157632551156, 0.06111857001087628, 0.035301630923640914, 0.037718401435995474, 0.03932672079827171, 0.0476848435937427, 0.08686089728143997, 0.03901236559613608, 0.07800527950166725, 0.10492679779417813, 0.019661861260829028, 0.12418476559105329, 0.03608000282838475, 0.0680275121703744, 4.884933801367879, 41.70960187911987, 40.08767411112785, 29.307318180799484, 37.815396040678024, 45.66970378160477, 12.617579195648432, 1.0561285098083317, 1.5296860551461577, 0.2313944764318876, 0.11775848659453914, 2.7837389381602407, 6.110392743721604, 2.681660740636289, 0.37619210430420935, 2.3006623098626733, 36.73107102513313, 55.6498796492815, 56.61996379494667, 52.471566796302795, 53.14889185130596, 46.62331201136112, 48.128046467900276, 47.42643691599369, 50.26420824229717, 50.80059885978699, 54.91768553853035, 53.99533063173294, 58.2780884206295, 54.635170698165894, 56.497298777103424, 52.75424882769585, 52.65130095183849, 48.99774760007858, 46.39447309076786, 42.808658704161644, 42.42152027785778, 40.71153983473778, 40.0409822165966, 39.924146085977554, 40.60228809714317, 41.88847728073597, 42.249385714530945, 42.098214626312256, 42.97243371605873, 43.29291611909866, 42.19749189913273, 41.5214853733778, 40.92198774218559, 38.662461787462234, 40.30699834227562, 42.015918642282486, 42.34183095395565, 40.35520255565643, 41.440386325120926, 47.4205282330513, 51.12323954701424, 52.57292255759239, 48.325103893876076, 49.587928131222725, 55.51821291446686, 46.568860933184624, 48.51111151278019, 49.77952145040035, 55.0069959461689, 52.53243952989578, 54.782192409038544, 52.060292065143585, 45.50206437706947, 48.953039199113846, 53.23870003223419, 52.90610007941723, 50.595436468720436, 46.885904520750046, 44.54505912959576, 43.52090768516064, 41.019539907574654, 40.98505675792694, 40.03578029572964, 41.065186858177185, 38.91978777945042, 39.71278242766857, 37.166444063186646, 38.47507864236832, 38.91740910708904, 39.44055363535881, 38.44904623925686, 37.03112952411175, 37.57508933544159, 39.83415171504021, 36.7450200766325, 39.752026721835136, 35.5407202988863, 43.8655111938715, 51.044234186410904, 51.125895604491234, 50.239171385765076, 48.96247789263725, 46.62421636283398, 40.30356712639332, 36.87490850687027, 36.70864462852478, 37.833464071154594, 38.37694890797138, 37.6163437217474, 37.13406220078468, 35.859583988785744, 36.46575026214123, 39.883704856038094, 39.17709477245808, 40.375337675213814, 38.63851547241211, 38.203321024775505, 39.16564218699932, 39.653042033314705, 42.30819135904312, 45.19062928855419, 47.89366364479065, 51.17269389331341, 53.42739410698414, 33.67468982934952, 2.7459758520126343, 4.744516611099243, 7.902750391513109, 11.690337751060724, 7.544789174571633, 8.388260789215565, 7.783836722373962, 0.9806099371053278, 0.04555067549517844, 1.9271944812498987, 44.433246329426765, 41.919677406549454, 34.853029400110245, 34.309320375323296, 37.254990711808205, 4.2355182487517595, 0.053689779379055835, 0.09906675521051511, 0.057145241225953214, 0.03217811317881569, 0.017692618785076775, 0.06616458049393259, 0.04849992212257348, 0.06550485573825426, 0.033228560132556595, 0.06800028277211823, 0.07284230654477142, 0.031629254153813235, 0.01244797154868138, 0.017786641474231146, 0.059644419816322625, 0.0450147372612264, 0.030935590984881856, 0.16549400403164327, 0.16193488641874865, 0.14785794803174213, 0.1444578281370923, 0.09242224768968299, 0.1649868203094229, 0.1267922791885212, 0.13593123410828412, 0.09276769516873173, 0.22748966643121094, 0.2623680542455986, 0.1774972482235171, 0.16552766785025597, 0.23261274152901024, 0.14323564450023696, 0.16923330025747418, 0.19191398634575307, 0.21478769020177424, 0.09486951676080935, 0.24911584972869605, 0.10303205024683848, 0.1549835008336231, 5.30987354926765, 50.84870047867298, 49.38048206269741, 37.288546711206436, 43.843084797263145, 56.307289972901344, 16.380884908139706, 2.155358106829226, 2.681138743646443, 0.36007559567224234, 0.3328509768471122, 4.262679191306233, 8.484563771635294, 2.6001810003072023, 0.2147913267253898, 3.108650716021657, 36.93887047469616, 58.525382950901985, 58.24217654764652, 55.25497063994408, 55.39520591497421, 49.317553639411926, 48.92837852239609, 49.29735392332077, 51.58775322139263, 53.960862681269646, 56.43992945551872, 56.004860401153564, 57.02691815793514, 54.275314807891846, 60.283476412296295, 54.324476569890976, 53.63759122788906, 50.196750462055206, 48.744567185640335, 44.372989162802696, 45.506035163998604, 44.3334636837244, 42.583004012703896, 43.12195189297199, 43.7418582290411, 44.96778264641762, 44.01200853288174, 43.5209608823061, 45.490136817097664, 45.9392499178648, 44.17441561818123, 43.18902209401131, 42.82730430364609, 42.27214649319649, 41.663658544421196, 42.740444764494896, 45.76121047139168, 43.24654720723629, 43.919977471232414, 49.85190376639366, 54.86866436898708, 56.04662016034126, 50.06117753684521, 54.9459408223629, 53.91101315617561, 46.01048469543457, 48.58493775129318, 51.593441516160965, 56.940799579024315, 54.68706451356411, 58.03704455494881, 49.80095610022545, 46.33150666952133, 56.75185091793537, 53.266339749097824, 53.641634210944176, 52.393351793289185, 49.786786660552025, 47.15492628514767, 45.965502709150314, 43.88434678316116, 43.6723143607378, 41.85302898287773, 44.00635063648224, 40.288557931780815, 41.66216142475605, 39.447932839393616, 40.37404574453831, 41.0443639755249, 41.014953553676605, 40.27997799217701, 38.724588453769684, 40.007566809654236, 40.76980210840702, 39.136497750878334, 40.78565865755081, 37.590649500489235, 47.25324600934982, 53.56497332453728, 53.1088799983263, 51.87935717403889, 52.22186699509621, 48.85246619582176, 44.053065329790115, 38.60370934009552, 38.52339304983616, 39.63437743484974, 41.434546038508415, 40.74656255543232, 39.050850346684456, 37.24674515426159, 37.84096106886864, 41.850296929478645, 40.9283372014761, 43.3036657422781, 40.341124311089516, 40.111377239227295, 40.880862548947334, 40.55821046233177, 45.714609771966934, 46.83212220668793, 48.75591337680817, 52.848248183727264, 52.119169905781746, 34.690177738666534, 2.8954092459753156, 4.428221108391881, 14.226124081760645, 20.77054426074028, 15.860128551721573, 12.719627469778061, 14.761698693037033, 10.458595845848322, 0.17173638625536114, 2.801262647844851, 51.96242831647396, 44.04418520629406, 41.185754388570786, 41.29279084503651, 46.26663655042648, 5.197966704145074, 0.10579998648609035, 0.15942593745421618, 0.16593662090599537, 0.09438105742447078, 0.1767055844538845, 0.20377853797981516, 0.1806812101858668, 0.1226513549045194, 0.09039684504386969, 0.19958706601755694, 0.19769080448895693, 0.1964490578393452, 0.1361916834139265, 0.09749585864483379, 0.1310810021823272, 0.2345890659489669, 0.15971179789630696], [0.07257466582814232, 0.03652890940429643, 0.026959378956235014, 0.02286399841977982, 0.07386503799352795, 0.01880697578599211, 0.01992299519770313, 0.012052811307512457, 0.018753299955278635, 0.08159239834640175, 0.025840342714218423, 0.06743274760083295, 0.01098337836083374, 0.054036440269555897, 0.07504075576434843, 0.0284297163670999, 0.021400156656454783, 0.010587819215288619, 0.05942201300058514, 0.04258190296241082, 0.04039758052385878, 0.07652037558727898, 0.3220955649157986, 14.029931109398603, 37.301921993494034, 33.96337553858757, 31.676130071282387, 39.38946157693863, 25.44523771852255, 2.1010977309197187, 0.6682399800047278, 0.07503423228627071, 0.25711884372867644, 2.472977126017213, 4.904773011803627, 2.295106532983482, 0.45171955309342593, 0.08129407724482007, 8.574013821780682, 43.56584407389164, 53.32897558808327, 52.67310418188572, 50.149329006671906, 48.905351758003235, 47.04970993101597, 46.19921296834946, 47.735326141119, 49.34424340724945, 51.48304224014282, 53.18264164030552, 52.4458421766758, 50.028658881783485, 52.90546551346779, 52.165808603167534, 53.68560925126076, 47.74582497775555, 45.53878180682659, 44.730162397027016, 41.787045523524284, 39.6763651818037, 38.3259404450655, 38.815734162926674, 38.439721539616585, 38.99675264954567, 38.79152186214924, 40.60243248939514, 42.14093953371048, 39.46324601769447, 40.13611391186714, 40.81533506512642, 40.15357777476311, 39.170661717653275, 38.37286792695522, 39.57510821521282, 38.19349855184555, 38.512035459280014, 38.58990468084812, 41.34661115705967, 45.603777319192886, 50.09053096175194, 53.980146646499634, 41.696021407842636, 51.71596214175224, 50.41073977947235, 44.46492522954941, 49.022849053144455, 48.660401701927185, 49.84941489994526, 45.935799703001976, 47.7908905595541, 44.54698942601681, 39.8407481610775, 47.75565505027771, 52.527974769473076, 48.551385551691055, 43.25824297964573, 41.4833278208971, 39.97158274054527, 38.38583283126354, 41.142938286066055, 43.77437688410282, 40.650575906038284, 38.11554193496704, 37.706140503287315, 36.537881791591644, 37.37995080649853, 37.355662509799004, 37.094943299889565, 36.016416773200035, 36.26559980213642, 34.93245653808117, 37.614755406975746, 35.70835970342159, 36.26415967941284, 34.52715888619423, 41.20554752647877, 48.94165500998497, 49.772450029850006, 48.35079051554203, 46.69819459319115, 50.29554136097431, 46.42736412584782, 41.14739164710045, 34.9799919873476, 35.462125316262245, 34.636934995651245, 35.76806589961052, 34.706444665789604, 35.1036411523819, 40.03654405474663, 41.447708532214165, 43.459293991327286, 42.386793941259384, 42.72871859371662, 40.451572984457016, 40.25731980800629, 38.501232638955116, 42.1000537276268, 43.89935217797756, 47.931809797883034, 47.531615272164345, 55.19952781498432, 14.223252385854721, 0.3320076299132779, 5.416483003646135, 5.651903171092272, 8.753351848572493, 6.341983191668987, 9.351883381605148, 4.3064371682703495, 1.0684232250787318, 0.42400416685268283, 14.257183615118265, 43.5116133838892, 16.538103371858597, 30.68985879421234, 39.12567973136902, 16.276248022913933, 0.14959430642193183, 0.10281336901243776, 0.02698123520531226, 0.05657459645590279, 0.04641401959815994, 0.04090272333996836, 0.05568708431383129, 0.044489370920928195, 0.02075047501421068, 0.014537387214659248, 0.02207403416832676, 0.03776505283894949, 0.04931385032250546, 0.036442334167077206, 0.05014459558879025, 0.051514492588466965, 0.016422759581473656, 0.029365555310505442, 0.08184158185031265, 0.048054496219265275, 0.038092785252956674, 0.07225452558486722, 0.08664335895446129, 0.009434913208679063, 0.004244170477250009, 0.006991830314291292, 0.02004327321628807, 0.04602008390065748, 0.050523814497864805, 0.10336441366234794, 0.03341699884913396, 0.024821116057864856, 0.07942442913190462, 0.03928645557607524, 0.04674928852182347, 0.05103356234030798, 0.06010188706568442, 0.029277989306137897, 0.014776769730815431, 0.08392658637603745, 0.5717728345189244, 21.715004481375217, 44.03014495968819, 31.460485942661762, 37.02765271067619, 46.40865013003349, 24.312480501830578, 2.309661414474249, 1.0407577408477664, 0.12395061057759449, 0.5722884787246585, 3.4715319564566016, 5.946599682793021, 5.904759177938104, 2.0155237102881074, 0.1849109324393794, 10.847836509346962, 47.64402084052563, 56.35891020298004, 54.456283897161484, 53.014770448207855, 50.52347593009472, 49.21793818473816, 46.50802239775658, 49.09211553633213, 50.88647045195103, 53.96085888147354, 54.346686378121376, 53.01287814974785, 54.10845436155796, 52.95129865407944, 53.79791982471943, 54.41051535308361, 49.735550209879875, 48.2689543068409, 46.92712090909481, 42.78187394142151, 40.457481667399406, 39.82585296034813, 39.63245093822479, 41.00144907832146, 39.5406174659729, 40.79409800469875, 41.92056655883789, 42.52878852188587, 41.433174312114716, 41.85680978000164, 41.84392847120762, 42.52265565097332, 41.032789796590805, 40.46918123960495, 41.66995480656624, 39.47722926735878, 40.26179596781731, 39.72420081496239, 45.08288986980915, 47.982635870575905, 52.32923783361912, 52.68605388700962, 47.91543647646904, 52.29994900524616, 49.61568184196949, 46.2278026342392, 49.763471111655235, 49.61035832762718, 53.45181539654732, 48.01611967384815, 48.08295048773289, 46.12642787396908, 42.90233127772808, 50.20640194416046, 55.658440589904785, 50.127358585596085, 45.967793986201286, 44.30354408919811, 41.388781294226646, 40.876017808914185, 43.40969905257225, 43.37765157222748, 43.50271426141262, 39.250411838293076, 39.803768545389175, 38.072368651628494, 38.59416425228119, 38.24492119252682, 39.058738723397255, 38.5533582419157, 38.72197039425373, 37.359230518341064, 40.04730887711048, 36.84905469417572, 36.60178296267986, 36.87658041715622, 42.994559928774834, 50.96612177789211, 49.60833303630352, 49.785107150673866, 50.0841549038887, 51.701959893107414, 49.08984325826168, 43.17907802760601, 36.08256742358208, 36.287520825862885, 35.79433009028435, 37.308499440550804, 37.114170268177986, 36.7058289796114, 41.617677211761475, 43.40534448623657, 45.05427360534668, 45.47991156578064, 43.76135878264904, 41.92282363772392, 41.16678960621357, 39.71188947558403, 43.67885380983353, 45.37616193294525, 49.09293629229069, 48.26444014906883, 55.01054875552654, 16.107464879751205, 0.6686757097486407, 8.061903901398182, 6.9556863605976105, 10.71735056117177, 8.57849283143878, 11.954435929656029, 5.832008281722665, 0.3121524484595284, 0.27852508414071053, 13.25351307168603, 50.39462864398956, 25.115939788520336, 33.80444906651974, 43.32120940089226, 24.133696295320988, 0.4640834662131965, 0.11344136160914786, 0.02801555529003963, 0.044588314049178734, 0.050166722721769474, 0.07872813876019791, 0.06849778146715835, 0.05111534701427445, 0.048398574435850605, 0.06064814115234185, 0.04119980876566842, 0.05109772100695409, 0.05760771797213238, 0.05508322472451255, 0.065864159114426, 0.055599481202079915, 0.036542034285957925, 0.06677619181573391, 0.16974851401755586, 0.12029575591441244, 0.1003776106517762, 0.1295781382941641, 0.2415228181052953, 0.0856822999776341, 0.10842319650691934, 0.14083357964409515, 0.1663765957346186, 0.15955775772454217, 0.14759328332729638, 0.20049505401402712, 0.10723455794504844, 0.14370255928952247, 0.22922330856090412, 0.1415272057056427, 0.1641218175063841, 0.14243130484828725, 0.12044468268868513, 0.15320429083658382, 0.16792599228210747, 0.1407288626069203, 0.562904526013881, 25.684767365455627, 52.60331332683563, 42.40823619067669, 42.2411135584116, 51.40904501080513, 32.97344125807285, 3.9840900152921677, 1.6491514071822166, 0.24880628508981317, 0.8999796293210238, 5.71194707415998, 13.318053558468819, 5.389314461499453, 4.446941753849387, 0.2997920976486057, 11.274723652750254, 46.46478831768036, 56.71267122030258, 57.2903960198164, 54.493149518966675, 52.74061515927315, 51.43606536090374, 50.484490022063255, 51.15529842674732, 53.47936771810055, 56.04438968002796, 56.609848737716675, 55.36103054881096, 55.72889640927315, 54.53434310853481, 55.13867408037186, 57.51049920916557, 52.81256429851055, 49.88172076642513, 50.58749869465828, 44.358169957995415, 44.16289463639259, 42.15137757360935, 41.991083174943924, 42.571118250489235, 42.91734427213669, 41.383241191506386, 46.068431586027145, 45.85114024579525, 42.23333917558193, 43.849198669195175, 45.64713679254055, 44.87008608877659, 44.21048328280449, 40.665368512272835, 43.73569875955582, 41.63479149341583, 42.70149685442448, 42.91777744889259, 48.11775282025337, 49.07260738313198, 54.76439796388149, 52.91308790445328, 52.24922172725201, 52.660272270441055, 47.69462272524834, 47.62025311589241, 51.10756918787956, 52.19095565378666, 54.231392964720726, 48.36563251912594, 47.49730311334133, 47.17802904546261, 46.94818317890167, 55.67655421793461, 55.45474871993065, 54.660845920443535, 45.978733599185944, 47.39175237715244, 43.041578605771065, 43.80094885826111, 46.90425753593445, 47.044758796691895, 43.877256363630295, 42.522085681557655, 42.48681217432022, 40.12649662792683, 39.92236778140068, 39.591679126024246, 41.83829717338085, 41.30862079560757, 41.84921398758888, 38.39587949216366, 41.718109622597694, 38.14218610525131, 38.65535996854305, 38.866149857640266, 45.15866540372372, 54.42109778523445, 53.27667519450188, 50.16186833381653, 50.99885322153568, 54.29519534111023, 52.06161439418793, 45.778153762221336, 38.2745748013258, 37.51094877719879, 37.424146234989166, 38.821711242198944, 38.30868937075138, 39.569948092103004, 44.67391021549702, 45.61087913811207, 48.109359070658684, 46.40936069190502, 47.02430069446564, 45.57863026857376, 43.89870621263981, 42.53302529454231, 45.181361585855484, 46.43817834556103, 51.621138229966164, 50.02217262983322, 57.52178080379963, 17.11745448410511, 1.3041909551247954, 13.626843988895416, 9.771702904254198, 21.383572965860367, 15.20666241645813, 20.255899876356125, 14.087305180728436, 5.021798657253385, 0.5943363800179213, 17.343198470771313, 55.232810229063034, 26.446197107434273, 39.34981070458889, 49.232092425227165, 32.440785840153694, 0.6615842808969319, 0.2955879201181233, 0.12358112493529916, 0.14752224495168775, 0.15959582990035415, 0.09722350529045798, 0.1516263364464976, 0.18282843637280166, 0.1284083948121406, 0.23943536449223757, 0.1606918781180866, 0.20571122411638498, 0.13055001036264002, 0.2030565173481591, 0.16325224307365716, 0.12373406672850251, 0.11432883664383553, 0.25616280909162015], [0.01953201510332292, 0.08111452203593217, 0.028526243804662954, 0.08757548159337603, 0.055935956115718, 0.022326369944494218, 0.08341031876625493, 0.06853307801065966, 0.06088285277655814, 0.050974639525520615, 0.06380629492923617, 0.03413834412640426, 0.06820654045441188, 0.011331167315802304, 0.03176987258484587, 0.017805159914132673, 0.055901501909829676, 0.008551667488063686, 0.0520294725720305, 0.016039247348089702, 0.03143332345644012, 0.029780072618450504, 0.19891941512469202, 1.430028802715242, 31.782606057822704, 34.38361018896103, 26.47412560880184, 35.6539998203516, 39.05570648610592, 7.085586665198207, 1.761145528871566, 0.09821677347645164, 0.17280810687225312, 2.253430369310081, 6.28576235845685, 5.051805647090077, 1.806126565206796, 0.12198058699141257, 0.8228365250397474, 21.65815383195877, 56.50222711265087, 53.62171947956085, 55.8407624065876, 51.14514537155628, 51.803817227482796, 44.11391906440258, 48.50705333054066, 50.83128601312637, 52.675330862402916, 52.72255852818489, 52.03071065247059, 53.58637757599354, 54.42092679440975, 51.56488984823227, 51.904918402433395, 49.16348710656166, 46.92921839654446, 44.08633254468441, 41.17174074053764, 39.37995448708534, 38.49758103489876, 38.21918897330761, 38.88344652950764, 37.75682598352432, 42.30024218559265, 39.62493874132633, 40.387523621320724, 40.78207165002823, 39.915193766355515, 39.14337918162346, 39.3783737719059, 38.60517606139183, 38.23506072163582, 37.28416554629803, 38.520406410098076, 36.32331110537052, 38.55906553566456, 40.56805193424225, 44.37151864171028, 46.603522673249245, 53.08974802494049, 44.60978485643864, 44.175475761294365, 55.64059674739838, 48.525634333491325, 43.85679446160793, 46.07570059597492, 45.883362516760826, 47.38617807626724, 46.01624518632889, 40.57176053524017, 50.8602062612772, 43.68705756962299, 46.51425026357174, 46.49396315217018, 44.824378341436386, 41.96410082280636, 40.69992385804653, 41.79881729185581, 43.65930385887623, 44.05270054936409, 40.7901956140995, 39.218915328383446, 36.86064787209034, 37.56204843521118, 35.072931200265884, 36.16693049669266, 36.13660052418709, 36.93330377340317, 36.2540902197361, 35.638508051633835, 37.09029234945774, 36.51094503700733, 35.903832614421844, 35.17363339662552, 37.409182637929916, 46.88409581780434, 48.9626906812191, 48.14285807311535, 47.77394346892834, 48.045328706502914, 48.9265014231205, 45.901567339897156, 40.260561034083366, 35.70828750729561, 34.53241400420666, 34.0869715064764, 33.9899855107069, 35.72988174855709, 40.40395013988018, 44.01140816509724, 46.93204924464226, 45.18647611141205, 48.91181141138077, 44.98642824590206, 44.64256949722767, 42.434412986040115, 42.522754445672035, 45.76835408806801, 44.58130918443203, 50.89482240378857, 42.70294077694416, 3.6074387887492776, 0.5742580792866647, 4.982845997437835, 8.494220953434706, 6.954588694497943, 5.00655910000205, 4.824082441627979, 4.530533943325281, 0.11297977544018067, 0.3150651999749243, 34.636661410331726, 43.20693053305149, 41.15870364010334, 39.65262785553932, 38.94973397254944, 7.552508935332298, 0.046885301926522516, 0.07436693762429059, 0.022376353590516374, 0.07400223883450963, 0.04019951244117692, 0.059393848496256396, 0.05903535035031382, 0.031038617780723143, 0.035120795510010794, 0.01578984119987581, 0.0755367404781282, 0.044887555413879454, 0.05428416916402057, 0.04510437385761179, 0.028524707558972295, 0.008033313515625196, 0.02704509701288771, 0.0533545549842529, 0.046607196927652694, 0.018919891699624714, 0.01920087252074154, 0.06316867875284515, 0.01553560274260235, 0.05226333814789541, 0.028035279719915707, 0.05324403064150829, 0.02947249322460266, 0.023921659048937727, 0.02434073499898659, 0.03776360194024164, 0.008787562837824225, 0.05608289393421728, 0.058633199078030884, 0.018073453720717225, 0.03687848693516571, 0.0862312591925729, 0.025755611713975668, 0.04466914506338071, 0.025856413922156207, 0.0323062115785433, 0.022088982877903618, 2.948662913404405, 43.698335364460945, 38.14361482858658, 30.127853751182556, 44.83143836259842, 42.540127113461494, 7.607114855200052, 2.1151446271687746, 0.033023501018760726, 0.5078290344681591, 3.414715505205095, 4.933600164949894, 7.7997364941984415, 5.9239177498966455, 0.9631049889139831, 0.8171673479955643, 26.18217207491398, 57.965406998991966, 55.1457455009222, 55.593707263469696, 53.64541120827198, 51.645012348890305, 48.06087367236614, 49.159075543284416, 51.23264327645302, 56.018991842865944, 53.39788869023323, 53.735523372888565, 54.25031594932079, 54.26014222204685, 53.73934216797352, 53.52946802973747, 50.664174780249596, 48.822926580905914, 46.241280511021614, 42.93861173093319, 40.980979576706886, 40.69914489984512, 39.50376704335213, 40.746026784181595, 39.805113673210144, 42.011415883898735, 40.67346587777138, 42.48654618859291, 41.49761505424976, 42.64060512185097, 41.18672713637352, 40.635612308979034, 40.92615231871605, 39.881166592240334, 39.280434027314186, 38.91164481639862, 37.47160568833351, 40.06394438445568, 42.44900040328503, 46.87326639890671, 50.039343908429146, 53.794606402516365, 47.83547356724739, 49.816071689128876, 56.21297523379326, 45.95018193125725, 46.605262979865074, 48.315695598721504, 47.94090270996094, 46.507300436496735, 45.76245300471783, 43.02482150495052, 50.92668369412422, 46.24693840742111, 49.23142746090889, 48.894495740532875, 46.132864728569984, 43.70543718338013, 42.76418589055538, 42.4978543817997, 45.29548466205597, 45.92416852712631, 41.80843077600002, 40.25273345410824, 39.00959596037865, 38.889302015304565, 38.520569801330566, 39.81664225459099, 38.158635422587395, 38.34415286779404, 37.82545410096645, 37.060000374913216, 38.40141959488392, 36.76436483860016, 38.55028420686722, 36.4820171892643, 40.50778716802597, 46.672416776418686, 49.99391354620457, 49.15499836206436, 48.97662453353405, 50.46520225703716, 50.09400397539139, 49.02606748044491, 42.07149066030979, 36.71507008373737, 35.612551644444466, 35.90922832489014, 35.94768226146698, 38.26439514756203, 42.29472108185291, 45.22366851568222, 48.69776509702206, 47.368197441101074, 50.68409711122513, 46.722631081938744, 46.888655573129654, 42.389453798532486, 46.17484487593174, 48.72231177985668, 47.037873566150665, 50.275907814502716, 43.99984158575535, 4.2862726002931595, 1.56615020474419, 6.383475065231323, 10.46646997332573, 9.587503038346767, 6.650842493399978, 9.538470469415188, 3.248401042073965, 0.19135296723106876, 0.2118474495364353, 37.43342153728008, 45.99900931119919, 32.81071878969669, 38.78382347524166, 45.67945405840874, 13.385743126273155, 0.11289592017419636, 0.017471779756306205, 0.03835094132227823, 0.09174878578050993, 0.06002336413075682, 0.05628527018416207, 0.0834797318384517, 0.0380161362409126, 0.014861572162772063, 0.009841072078415891, 0.026488369367143605, 0.047834263896220364, 0.03354911597853061, 0.05011592642404139, 0.008340727781614987, 0.00654426795335894, 0.029021542031841818, 0.022941742099646945, 0.11740261936211027, 0.13535805861465633, 0.05267062508210074, 0.29826817160937935, 0.12091403172235005, 0.23829818645026535, 0.15154826251091436, 0.13786110008368269, 0.17253179044928402, 0.15455384185770527, 0.20070683327503502, 0.1442733153817244, 0.18233311217045411, 0.10687129892176017, 0.11428087906097062, 0.19532752427039668, 0.2807875955477357, 0.12447104905731976, 0.14301780931418762, 0.15337691438617185, 0.1904514359193854, 0.11653440305963159, 0.19589280331274495, 3.4481358993798494, 51.106524243950844, 44.90632474422455, 35.0321251899004, 48.158007860183716, 49.26307216286659, 10.728229377418756, 4.047511937096715, 0.13044018734944984, 1.560473428107798, 10.228780377656221, 16.284884959459305, 12.320401892066002, 4.094124510884285, 1.418620627373457, 1.4304117509163916, 26.88411220908165, 60.24504907429218, 56.32080964744091, 59.63711969554424, 55.49827918410301, 54.811082258820534, 50.82260347902775, 53.1223426759243, 53.70994694530964, 57.74580158293247, 54.877274706959724, 54.875895380973816, 56.37984327971935, 56.72080658376217, 54.42867837846279, 56.06762543320656, 52.50071503221989, 49.794659838080406, 48.52637529373169, 44.880835711956024, 43.688053116202354, 42.95779690146446, 41.84453643858433, 43.139240965247154, 41.72369532287121, 46.38187296688557, 42.99517169594765, 43.007973209023476, 43.807017132639885, 46.106049567461014, 42.8609324991703, 42.82655954360962, 42.34692268073559, 41.54679201543331, 41.09835147857666, 42.266074419021606, 39.10371690988541, 41.56574919819832, 43.58576640486717, 49.38140161335468, 51.269204914569855, 58.163091391325, 48.64359900355339, 56.67789168655872, 53.576315715909004, 47.29834958910942, 49.74795274436474, 48.67176689207554, 48.81563097238541, 46.55355155467987, 45.529301315546036, 44.98477913439274, 54.49245795607567, 48.668092489242554, 51.36268749833107, 47.94401854276657, 49.03011046350002, 45.381721034646034, 46.72760881483555, 44.68017987906933, 47.02352933585644, 48.01619566977024, 45.03775209188461, 43.0072208493948, 40.332008600234985, 40.56948445737362, 39.41725708544254, 40.26551976799965, 41.21437445282936, 40.30218780040741, 40.5868761241436, 39.276961013674736, 39.344403594732285, 38.75010408461094, 40.30254878103733, 39.05219167470932, 41.857372149825096, 49.32332172989845, 53.94374839961529, 50.39790026843548, 51.20114676654339, 51.26415878534317, 53.50263386964798, 51.4484678953886, 44.04841057956219, 39.364531114697456, 37.2179388999939, 37.87650056183338, 36.38310469686985, 39.48690354824066, 44.11367207765579, 47.699980437755585, 50.420493856072426, 49.79174919426441, 53.452533558011055, 49.650715962052345, 48.392075300216675, 45.21259590983391, 47.669677063822746, 51.4960603415966, 48.41465748846531, 51.49145118892193, 43.549968525767326, 4.728156588971615, 2.2982646385207772, 13.33040764555335, 17.359740883111954, 13.979718703776598, 12.781604994088411, 14.524987544864416, 13.962791562080383, 1.0770026897080243, 0.288848239579238, 44.42635729908943, 51.82417653501034, 47.66050435602665, 47.57606528699398, 52.46911972761154, 16.53353411704302, 0.16815877432236448, 0.20138793188380077, 0.1601281575858593, 0.21459002658957615, 0.19299854611745104, 0.18642252398421988, 0.2184463743469678, 0.09826755864196457, 0.15154375025304034, 0.08938505285186693, 0.1481792237609625, 0.125225382798817, 0.12628937023691833, 0.27764540165662766, 0.09421314651262946, 0.13036387972533703, 0.1686454747687094, 0.17067512992070988], [0.02453537250403315, 0.04958414792781696, 0.03187035566952545, 0.023995352457859553, 0.020382291841087863, 0.04302119130443316, 0.038745311176171526, 0.03574391012080014, 0.04372120354673825, 0.02449337251164252, 0.03647855468443595, 0.04404951854667161, 0.022619650007982273, 0.028711788145301398, 0.057444152334937826, 0.049569857874303125, 0.019883386776200496, 0.06718414297210984, 0.0181757754762657, 0.03560373326763511, 0.03804552157816943, 0.045046334198559634, 0.05043887940701097, 0.1751863636309281, 8.790565151721239, 39.858743995428085, 26.57514128834009, 31.48404847830534, 42.456596195697784, 13.134156726300716, 0.4674636520212516, 0.17219614674104378, 0.903733471641317, 1.2885525380261242, 2.9878604225814342, 7.17240440659225, 2.7931384462863207, 0.7656364724971354, 0.35535963310394436, 4.62390823289752, 36.57750606536865, 53.91100935637951, 53.00084039568901, 52.13781550526619, 49.13283035159111, 47.27984458208084, 46.515318006277084, 49.341879934072495, 52.039351388812065, 54.503560960292816, 55.47377049922943, 51.32210947573185, 50.3476669639349, 52.93224647641182, 51.41040153801441, 50.48825182020664, 46.64959520101547, 46.665770933032036, 40.771451219916344, 38.79427671432495, 37.75060571730137, 38.594453036785126, 38.68338726460934, 39.11910608410835, 39.47216033935547, 38.71085599064827, 41.97157122194767, 40.395936369895935, 41.0067155957222, 40.305520221590996, 38.49652089178562, 38.724656850099564, 37.860047444701195, 38.36351662874222, 37.977312952280045, 37.43271477520466, 40.41333943605423, 42.99634203314781, 44.329204112291336, 49.067739844322205, 52.86777153611183, 53.11771832406521, 41.87746547162533, 47.30146162211895, 57.829051315784454, 51.057662665843964, 45.83425775170326, 45.20175129175186, 46.62328541278839, 37.9376582801342, 47.8748432546854, 56.542945727705956, 51.35306641459465, 48.74895215034485, 44.10403959453106, 46.292140781879425, 43.31245467066765, 42.14690521359444, 42.36320100724697, 42.11556449532509, 42.165588811039925, 41.40689492225647, 40.661587715148926, 38.321684673428535, 37.23167136311531, 37.505112290382385, 34.80876177549362, 37.90912561118603, 37.83102460205555, 35.97529157996178, 33.52258399128914, 35.89000515639782, 34.73772458732128, 35.203085616230965, 34.1232405602932, 36.42566241323948, 42.153771445155144, 48.78001928329468, 47.347876131534576, 49.844497963786125, 48.34333911538124, 48.60069550573826, 47.77735948562622, 47.44125612080097, 43.144104704260826, 37.31307439506054, 34.34840887784958, 33.98737125098705, 35.29127888381481, 42.658764347434044, 44.94194023311138, 46.01600959897041, 39.76846843957901, 43.78529749810696, 51.1607663333416, 47.0625114440918, 45.946971103549004, 46.35968215763569, 48.829530626535416, 45.331521928310394, 49.95521642267704, 24.168177545070648, 0.20358749432489276, 1.4333677547983825, 3.3618774404749274, 7.7459413558244705, 9.343652073293924, 7.222811551764607, 8.986449390649796, 2.533836322836578, 0.2462528963224031, 3.806538605131209, 29.41311400383711, 42.108314484357834, 37.8073974698782, 48.42775538563728, 30.261084102094173, 2.227543545886874, 0.13032074610237032, 0.014300680140877375, 0.10129645626875572, 0.07148045071517117, 0.03414916092879139, 0.039963609669939615, 0.09991543818614446, 0.026769075593620073, 0.02265431387058925, 0.053440799965756014, 0.056687473406782374, 0.032459513313369825, 0.03327309270389378, 0.008574848470743746, 0.012327519125392428, 0.07782024724292569, 0.05948420497588813, 0.017273030753131025, 0.03311360145744402, 0.04765909106936306, 0.027922428744204808, 0.03111689951765584, 0.012995690449315589, 0.017897611105581746, 0.0365101924398914, 0.05071596766356379, 0.02760175415460253, 0.025882517111313064, 0.02772334948531352, 0.056828154920367524, 0.03892035412718542, 0.022177380087669007, 0.07925589481601492, 0.04643945299903862, 0.03006166200066218, 0.07159762099036016, 0.059012462515966035, 0.04030052987218369, 0.038185672456165776, 0.04699845718278084, 0.013890524805901805, 0.2824891620548442, 15.05121560767293, 45.388625264167786, 26.277765445411205, 35.3360290825367, 49.815684109926224, 15.20493445917964, 1.4305530558340251, 0.1500135604874231, 0.11187112555489875, 2.700736429542303, 4.9896561820060015, 9.893444571644068, 7.282988922670484, 3.991608861833811, 0.8649386814795434, 5.3735120594501495, 41.36437140405178, 54.49976496398449, 54.67937372624874, 53.408037945628166, 52.53582514822483, 48.84210795164108, 50.19653007388115, 51.27418264746666, 53.38635630905628, 53.930601105093956, 55.56951016187668, 53.498495891690254, 52.96325281262398, 54.60060775279999, 51.820049956440926, 51.92096874117851, 48.95124949514866, 48.00238341093063, 43.954004645347595, 40.27872785925865, 39.377503618597984, 41.666128411889076, 40.677486062049866, 40.44813796877861, 40.347967743873596, 41.04267306625843, 43.46362195909023, 41.72658696770668, 42.080454379320145, 41.70370079576969, 40.8005690574646, 39.63240534067154, 39.290055111050606, 39.43606607615948, 38.76406453549862, 38.85215520858765, 42.12121859192848, 45.63115105032921, 46.42622418701649, 49.446256533265114, 53.34986686706543, 53.20175841450691, 45.53026646375656, 53.23996156454086, 56.668202206492424, 47.732069715857506, 46.31189592182636, 47.88608305156231, 47.891421765089035, 39.88136038184166, 50.231685787439346, 57.63806216418743, 52.29513466358185, 52.08776839077473, 46.04847505688667, 49.78910453617573, 44.02929000556469, 44.18807968497276, 44.75847467780113, 45.36415457725525, 44.46199558675289, 44.40424628555775, 42.71388038992882, 39.60418425500393, 38.631858229637146, 38.67877431213856, 36.301507875323296, 40.276569575071335, 39.601110219955444, 39.034283235669136, 36.20678275823593, 38.87932375073433, 37.26055361330509, 37.89796181023121, 34.72360834479332, 38.21809463202953, 44.382747039198875, 48.9054087549448, 50.82673765718937, 50.93764990568161, 50.3384942561388, 49.883780255913734, 49.590295404195786, 48.42303603887558, 42.58195906877518, 39.025433510541916, 35.48900507390499, 35.9171698987484, 36.82052202522755, 43.787079602479935, 46.42950341105461, 48.7273845076561, 41.373395919799805, 46.58613480627537, 51.70609027147293, 48.9308749884367, 46.87395416200161, 48.78348469734192, 50.680080726742744, 49.267130345106125, 49.61361475288868, 27.027510814368725, 0.27590016718022525, 2.781565929763019, 4.193398458883166, 14.401025846600533, 9.40204543992877, 9.240259621292353, 6.682685734704137, 1.3852753979153931, 0.1826867158524692, 4.384099300950766, 38.15767787396908, 48.72673474252224, 44.0718325227499, 52.045001685619354, 36.81828394532204, 4.349079905077815, 0.22180432541063055, 0.05209876318986062, 0.04207601799862459, 0.0723618252959568, 0.032053339600679465, 0.053713234956376255, 0.0952119511202909, 0.028157101405668072, 0.02229253172117751, 0.02426027876936132, 0.07154242004617117, 0.04990564259060193, 0.11580836740904488, 0.036326681583886966, 0.03461449494352564, 0.07253435236634687, 0.050881581628345884, 0.02047316411335487, 0.09119634589296766, 0.1518150942865759, 0.1797823654487729, 0.17167857295135036, 0.0953632676100824, 0.1280881284037605, 0.09385448880493641, 0.12063283196766861, 0.11546863446710631, 0.09865175365121104, 0.12549991806736216, 0.13632653164677322, 0.10032036137999967, 0.12283350763027556, 0.19022669875994325, 0.08325506147230044, 0.17511637910502031, 0.272046253667213, 0.08385496912524104, 0.11731893479009159, 0.19259676220826805, 0.1143594502354972, 0.1418936633854173, 0.39720174099784344, 17.883531376719475, 57.694618329405785, 34.530061930418015, 42.4725591391325, 55.48567906022072, 21.41427531838417, 2.3580085951834917, 0.31021965842228383, 2.02209759503603, 7.969811093062162, 8.475042432546616, 14.046935196965933, 8.973630778491497, 4.030968574807048, 0.6500114675145596, 5.597387971356511, 41.68191276490688, 55.17044797539711, 55.73243781924248, 55.55782578885555, 55.72766147553921, 50.5341761559248, 53.48041646182537, 53.66787940263748, 55.97437083721161, 58.071865886449814, 59.62770760059357, 56.103107929229736, 54.79660123586655, 56.61514185369015, 55.53277373313904, 53.34861293435097, 50.163323655724525, 52.25570797920227, 46.47913634777069, 41.98269322514534, 41.728118285536766, 43.19385543465614, 43.206995129585266, 43.79507057368755, 41.67602688074112, 43.07351969182491, 46.88488997519016, 45.32007694244385, 44.68802645802498, 43.1863584369421, 42.27835536003113, 42.12536796927452, 40.801329016685486, 41.88488647341728, 41.453377828001976, 40.56388735771179, 44.26025681197643, 47.56506107747555, 47.95520894229412, 51.885607838630676, 57.43552163243294, 54.993993043899536, 49.241645112633705, 57.41360440850258, 54.64021682739258, 49.571558609604836, 48.37141200900078, 48.12890142202377, 48.916371166706085, 41.91629558801651, 50.45577496290207, 59.67681236565113, 54.40720193088055, 54.668228924274445, 47.75823891162872, 52.1355964243412, 47.31458991765976, 47.32840217649937, 47.18071170151234, 46.831734627485275, 45.31335510313511, 46.134563237428665, 44.697096571326256, 41.52224153280258, 40.876215398311615, 41.508794054389, 38.8779254257679, 42.30780377984047, 42.450440526008606, 40.24623580276966, 37.01066382229328, 40.732366517186165, 39.14726257324219, 39.754811972379684, 37.06894129514694, 40.61265394091606, 47.04226613044739, 51.69724054634571, 52.28182017803192, 53.67069885134697, 50.79828858375549, 52.31585115194321, 52.9895132035017, 50.207511484622955, 46.721312552690506, 39.86591041088104, 37.22658723592758, 38.032615184783936, 38.01788717508316, 47.936715334653854, 49.24305483698845, 50.71084767580032, 42.93988846242428, 47.60287664830685, 54.91054192185402, 51.615275144577026, 48.50904822349548, 50.98542854189873, 52.65952751040459, 51.39530494809151, 51.10704101622105, 28.08294218033552, 1.408212510868907, 4.782402478158474, 10.63778093084693, 15.73992770165205, 19.680453054606915, 15.576184038072824, 18.321824558079243, 9.340427946299314, 0.7158518407959491, 4.3382699601352215, 39.85485680401325, 52.40747943520546, 47.87349812686443, 52.69278332591057, 44.57130812108517, 5.89311090297997, 0.27764730155467987, 0.12748969020321965, 0.2949199278373271, 0.18654334562597796, 0.07254961834405549, 0.1239488591090776, 0.16527517436770722, 0.14973809011280537, 0.10476140276296064, 0.11268449714407325, 0.13034369330853224, 0.15340876736445352, 0.16879923292435706, 0.13864139415090904, 0.1272226357832551, 0.1593394624069333, 0.14391505101229995, 0.1090830251632724], [0.03978859640483279, 0.03616930916905403, 0.02898218222981086, 0.007449283184541855, 0.04037620667077135, 0.027498358140292112, 0.022218669473659247, 0.040678687510080636, 0.019223355884605553, 0.014029807371116476, 0.04594467427523341, 0.0559942295512883, 0.02983467984449817, 0.03804037478403188, 0.051352800874155946, 0.013170539514248958, 0.06573873615707271, 0.02910614501161035, 0.03747032373212278, 0.006752584167770692, 0.025242283008992672, 0.04780406590725761, 0.048608891665935516, 0.01449773519198061, 0.7007260993123055, 24.482215493917465, 37.3313894122839, 27.609706073999405, 40.496763959527016, 30.635314621031284, 1.8880089651793242, 0.08639583786134608, 0.06611312739551067, 2.1937747579067945, 3.100172420963645, 10.67175205796957, 12.458172999322414, 1.6789571265690029, 3.5099013475701213, 0.7853327156044543, 16.865372210741043, 53.17849986255169, 56.021727696061134, 54.477285370230675, 49.34957832098007, 48.43208335340023, 47.44488872587681, 49.674172103405, 51.832311898469925, 53.926159143447876, 53.265268206596375, 52.58971765637398, 50.5836571007967, 52.252770736813545, 54.36558276414871, 53.08003954589367, 50.285536497831345, 45.998492538928986, 41.487891376018524, 38.439858332276344, 37.91077472269535, 40.26645451784134, 40.2474707365036, 39.68293122947216, 40.040039867162704, 40.545135363936424, 40.32342106103897, 41.48326322436333, 38.978088051080704, 38.81788484752178, 38.49454119801521, 40.17950378358364, 39.74025875329971, 40.73044382035732, 39.069123566150665, 38.4245565533638, 41.641456335783005, 48.325936049222946, 48.86667363345623, 50.58453865349293, 48.596249744296074, 53.07832583785057, 50.69112293422222, 42.61855870485306, 45.015998259186745, 52.649184465408325, 52.31444902718067, 48.65800403058529, 43.42518702149391, 51.79719038307667, 57.15781733393669, 48.86363759636879, 49.11307901144028, 47.27068327367306, 47.470396757125854, 43.66075158119202, 41.80906914174557, 43.01437206566334, 42.857581079006195, 42.57972478866577, 43.63907374441624, 44.02968518435955, 43.56828734278679, 39.58586543798447, 35.96916250884533, 37.406625375151634, 37.249769791960716, 36.697731614112854, 36.23773589730263, 35.77508792281151, 35.74473135173321, 35.728323832154274, 35.161033272743225, 35.44628016650677, 35.350700095295906, 35.72378307580948, 37.04582333564758, 45.17172530293465, 47.300496473908424, 49.05165150761604, 49.09236632287502, 48.54615703225136, 48.54938305914402, 48.958328515291214, 46.18426077067852, 42.92493246495724, 36.19070962071419, 35.58130592107773, 33.64759348332882, 39.38512600958347, 44.63383376598358, 48.90350505709648, 46.75885833799839, 43.68669278919697, 48.17048639059067, 49.54918161034584, 48.0430868268013, 46.50491036474705, 48.20316843688488, 46.61787070333958, 44.81574900448322, 11.868350598961115, 0.3923179936828092, 1.2098058010451496, 3.3419562969356775, 11.586685013025999, 8.549228701740503, 3.6778416484594345, 5.592584079131484, 0.4986559704411775, 0.07937343616504222, 13.318280596286058, 36.02063074707985, 25.39256874471903, 22.934315353631973, 44.08048465847969, 21.39202371239662, 0.5407413246575743, 0.09443893752177246, 0.03676874184748158, 0.0033177663181049866, 0.07424282826832496, 0.012716548299067654, 0.12789862841600552, 0.01298880053582252, 0.013655379952979274, 0.07492183402064256, 0.02992895300849341, 0.11422164083342068, 0.007441213256242918, 0.028643174737226218, 0.056255732706631534, 0.05770992655016016, 0.048169814836001024, 0.021217870344116818, 0.036953900271328166, 0.041489264913252555, 0.039256461677723564, 0.01034628447087016, 0.03126844792859629, 0.06378362973919138, 0.03967234639276285, 0.03747736300283577, 0.05254217787296511, 0.10622353016515262, 0.036217270462657325, 0.04743734476505779, 0.07882657722802833, 0.01698139083600836, 0.03451840537309181, 0.05090622835268732, 0.02122486137523083, 0.0423806176695507, 0.03352708161401097, 0.053355067066149786, 0.030593373703595717, 0.02844046823156532, 0.040346932655666023, 0.03332988926558755, 0.04056171761476435, 1.6615292429924011, 36.08590364456177, 37.89493337273598, 30.685291439294815, 49.897235333919525, 34.46325771510601, 2.3317149560898542, 0.04679846693761647, 0.1394793827785179, 0.6360916863195598, 4.299724828451872, 9.891592171043158, 10.146532841026783, 9.259899817407131, 2.0057268859818578, 0.16659741435432807, 19.999844916164875, 53.92034165561199, 56.98504060506821, 56.69895775616169, 51.58311367034912, 49.67216581106186, 48.34126442670822, 51.20480217039585, 53.3445243537426, 54.95900072157383, 53.307681530714035, 53.151099532842636, 52.77087293565273, 54.035483077168465, 55.451393499970436, 53.18538509309292, 50.34568727016449, 47.19727121293545, 43.89323450624943, 40.47627925872803, 40.06226487457752, 41.07013039290905, 42.17484511435032, 41.32943607866764, 43.001593351364136, 42.47457683086395, 40.84959402680397, 43.96756611764431, 41.66630320250988, 41.07813276350498, 40.94797074794769, 41.36828899383545, 40.82105755805969, 41.50941722095013, 40.25804936885834, 39.92978498339653, 44.71475802361965, 49.325552210211754, 50.55073946714401, 50.91924749314785, 52.087783589959145, 55.18834501504898, 51.33940614759922, 46.63389064371586, 51.16185687482357, 56.31815358996391, 52.33519971370697, 46.73216477036476, 43.6071440577507, 54.447665959596634, 59.869363233447075, 51.35819233953953, 53.85617829859257, 48.63510265946388, 50.2945002168417, 45.63252277672291, 45.287189707159996, 44.04063619673252, 43.625892251729965, 43.04048806428909, 45.352986976504326, 46.412210538983345, 45.57459108531475, 40.00613808631897, 37.781300470232964, 39.03166897594929, 38.306230902671814, 37.54323944449425, 38.92752416431904, 38.87246131896973, 38.08544375002384, 38.00123646855354, 38.04547369480133, 37.57057137787342, 36.46063953638077, 36.29419706761837, 39.379794895648956, 48.51466812193394, 48.88266697525978, 50.36274455487728, 50.77159121632576, 49.80202004313469, 49.42870907485485, 50.73733605444431, 47.84091107547283, 44.01299647986889, 37.684265077114105, 35.66697992384434, 35.356794968247414, 41.66134066879749, 46.46369397640228, 50.0808946788311, 47.77237795293331, 45.82192741334438, 48.74752722680569, 51.19911007583141, 49.8476517945528, 49.19067084789276, 49.73876103758812, 46.239000633358955, 46.73690311610699, 12.332292404025793, 0.6614012969657779, 3.4472472220659256, 5.768236303701997, 10.269077215343714, 11.112577803432941, 9.000122006982565, 6.0856736451387405, 0.478201400837861, 0.019420238386373967, 12.309101298451424, 36.43758997321129, 33.861404210329056, 28.1643034145236, 48.70194487273693, 27.58666791021824, 1.6390348062850535, 0.14401059510419145, 0.03726094902958721, 0.061941775056766346, 0.06128675180661958, 0.02354116179049015, 0.05741789886087645, 0.06991830407059751, 0.07704285497311503, 0.04130424749746453, 0.01024605557176983, 0.02166658396163257, 0.020507417939370498, 0.044743293037754484, 0.03058463305933401, 0.09446983312955126, 0.0320711919630412, 0.02366066983086057, 0.03221828934329096, 0.14228421117877588, 0.23474686138797551, 0.06885255032102577, 0.18543018348282203, 0.11668223145534284, 0.0969077214540448, 0.06875732535263523, 0.16552397195482627, 0.23975668475031853, 0.11886826454428956, 0.10024230228736997, 0.17258051986573264, 0.11748910183086991, 0.12474132439820096, 0.13288875517901033, 0.08996362375910394, 0.2645041036885232, 0.15037011791719124, 0.21977182041155174, 0.0895211033639498, 0.1450633315835148, 0.1659718283917755, 0.10250950406771153, 0.13298781705088913, 2.14629749301821, 40.969188809394836, 46.88230611383915, 37.92706824839115, 51.644567772746086, 43.621682077646255, 5.352436490356922, 0.1649910505511798, 0.3084686945658177, 7.777996910735965, 8.019242640584707, 21.153037436306477, 22.80935525894165, 9.407766032963991, 6.682484345510602, 1.0651060030795634, 20.347474962472916, 54.08185958862305, 59.49463114142418, 60.089660212397575, 54.72526766359806, 52.35412649810314, 50.67242033779621, 55.27203552424908, 55.96665345132351, 57.915644869208336, 54.24711652100086, 54.39767204225063, 54.215502217411995, 56.27836212515831, 57.90274076163769, 57.255593687295914, 53.32276672124863, 51.499996930360794, 45.37786804139614, 41.5457546710968, 40.89747525751591, 43.431673273444176, 45.26822492480278, 42.878650948405266, 45.03417648375034, 44.19469512999058, 43.550318107008934, 45.7975859194994, 41.73649303615093, 42.49916911125183, 41.68082222342491, 44.436187371611595, 42.99400895833969, 43.680062144994736, 42.23024234175682, 41.16704419255257, 46.95139780640602, 52.44489602744579, 51.87621474266052, 53.20592679083347, 55.26043854653835, 58.30410182476044, 53.91583509743214, 49.54192779958248, 57.356911450624466, 56.04246698319912, 51.71847760677338, 48.92998203635216, 46.58654898405075, 54.59843046963215, 57.75832951068878, 51.591587215662, 55.028662383556366, 50.19513174891472, 52.51660957932472, 47.54027880728245, 45.71411959826946, 47.092111855745316, 46.0089647769928, 47.28488311171532, 47.80217595398426, 49.508975967764854, 47.45260991156101, 42.22118742763996, 38.28165382146835, 41.877419874072075, 39.59593489766121, 39.921573624014854, 39.82118681073189, 40.22111535072327, 40.542555302381516, 39.0944530069828, 40.066623240709305, 39.310866594314575, 39.20430891215801, 39.04399931430817, 40.88331341743469, 51.20876535773277, 51.95513270795345, 52.0063653588295, 52.37325467169285, 50.851679518818855, 51.06321416795254, 52.082741260528564, 50.17842024564743, 46.57727748155594, 39.553620368242264, 38.532736748456955, 36.955365389585495, 44.168031960725784, 49.90494892001152, 52.35435448586941, 48.38028073310852, 46.89991436898708, 50.94336099922657, 52.60709412395954, 52.19871863722801, 50.43085590004921, 51.150062307715416, 48.4918237477541, 46.588156297802925, 15.0100077688694, 1.1759160133078694, 5.269470792263746, 9.747447855770588, 19.946187995374203, 16.705208905041218, 11.855754274874926, 16.528902165591717, 3.6417013127356768, 0.18507055356167257, 18.161959536373615, 47.45737485587597, 37.488142400979996, 35.6093218177557, 53.84836211800575, 33.383500054478645, 1.86418839963153, 0.2684691909234971, 0.11168524724780582, 0.1333300065016374, 0.19850025011692196, 0.08052765391767025, 0.24696399254025891, 0.07653480293811299, 0.20674800442066044, 0.09528454058454372, 0.1546432706527412, 0.15853632503421977, 0.087165912555065, 0.20747003989527002, 0.16120344051159918, 0.1349136308999732, 0.1809989384491928, 0.10986187204252928, 0.16697757208021358], [0.01721556625852827, 0.027402906816860195, 0.02727635950577678, 0.021294010985002387, 0.026897066381934565, 0.046777968818787485, 0.02663968400156591, 0.03265151062805671, 0.05629488470731303, 0.035070912053924985, 0.01858790677943034, 0.014770947582292138, 0.049807831237558275, 0.054019671442802064, 0.023401658436341677, 0.03182262444170192, 0.017837764316936955, 0.06493237044196576, 0.05421680070867296, 0.055847128460300155, 0.06839209221652709, 0.032071945242933, 0.08282477909233421, 0.01519943674793467, 0.0547862691746559, 5.162167875096202, 40.48629552125931, 25.51799811422825, 28.9848180860281, 43.988768979907036, 10.212779436260462, 0.1530237411498092, 0.1589780958602205, 0.4927871853578836, 4.070552950724959, 7.443187851458788, 4.788842657580972, 13.973822370171547, 15.937439203262329, 0.09274627678678371, 2.883879477158189, 34.28579583764076, 58.07566948235035, 55.119344517588615, 53.73336508870125, 49.38571058213711, 49.585424065589905, 50.49385651946068, 51.06110908091068, 53.39822307229042, 53.91377940773964, 50.3748545050621, 49.48357433080673, 52.05226689577103, 54.47351597249508, 54.09231282770634, 51.12139284610748, 45.89631222188473, 38.68645749986172, 39.77699138224125, 40.90297356247902, 40.856536254286766, 41.14831879734993, 40.10711386799812, 40.52978798747063, 38.98615501821041, 40.441469326615334, 41.188798025250435, 40.271090269088745, 39.681726694107056, 41.341196447610855, 39.306595623493195, 37.77924098074436, 38.12113903462887, 38.03475446999073, 38.605453446507454, 45.628669783473015, 50.27019292116165, 50.7356071472168, 51.141888946294785, 53.700082674622536, 51.19634382426739, 54.71270173788071, 53.28165292739868, 46.43367178738117, 43.66251468658447, 46.03583313524723, 51.50178663432598, 55.326315611600876, 57.20677010715008, 52.188303396105766, 49.75009202957153, 51.38471111655235, 48.65573935210705, 45.814726799726486, 43.54052223265171, 42.13584020733833, 40.90715333819389, 43.77142444252968, 43.49243961274624, 44.35857653617859, 46.52608662843704, 46.87202386558056, 43.117555528879166, 37.18730114400387, 35.983985513448715, 37.0544146746397, 36.50292746722698, 36.549767553806305, 36.25181794166565, 35.23903548717499, 36.68522268533707, 36.084015145897865, 34.58216853439808, 33.980402424931526, 35.84967792034149, 36.0596926510334, 39.10821966826916, 44.43120963871479, 47.10136815905571, 49.00706090033054, 48.34101364016533, 48.40544678270817, 47.75209084153175, 48.25002372264862, 46.98865860700607, 42.49593548476696, 37.98580549657345, 35.914407446980476, 35.25891602039337, 44.47885148227215, 45.81533096730709, 51.461144015192986, 45.46416521072388, 48.190480917692184, 47.8034982830286, 47.93534740805626, 48.623733669519424, 46.850471422076225, 48.64594727754593, 34.94889445602894, 4.03201874345541, 1.090503721497953, 2.9473773948848248, 2.5497921416535974, 12.018796876072884, 15.919760651886463, 8.026055674999952, 3.4394927881658077, 1.0373843531124294, 1.3910795864649117, 30.256813131272793, 40.97982443869114, 26.32698230445385, 33.288117572665215, 33.03669646382332, 11.254299748688936, 0.536812572972849, 0.12307124721701257, 0.04590308803017251, 0.027135210439155344, 0.07786890986608341, 0.033130418523796834, 0.06831329097622074, 0.019010769537999295, 0.09727209369884804, 0.010858697551157093, 0.007199760611911188, 0.01596195452293614, 0.07607789229950868, 0.025471385852142703, 0.04843050905037671, 0.09007903514429927, 0.07023045880487189, 0.043676978966686875, 0.027710682879842352, 0.040761485215625726, 0.026034948677988723, 0.03171033378748689, 0.040205163895734586, 0.05384823904023506, 0.07576395641081035, 0.004218667036184343, 0.07211820047814399, 0.011132323688798351, 0.047059398639248684, 0.008916071274143178, 0.06299297529039904, 0.07807956848409958, 0.07799690807587467, 0.06118525569036137, 0.030515958424075507, 0.06614713260205463, 0.027565355521801393, 0.013942697787570069, 0.06753076304448768, 0.04098248937225435, 0.024835736367094796, 0.08315660816151649, 0.10204756166785955, 0.12128361384384334, 9.054975863546133, 45.932566076517105, 28.630743585526943, 35.58044716715813, 52.220537066459656, 11.143334303051233, 0.009158245193248149, 0.380782168940641, 0.5156678357161582, 1.7513907398097217, 8.305694069713354, 6.990931844338775, 15.46904118731618, 20.647949539124966, 1.0870199021883309, 4.4574766885489225, 38.12852963805199, 61.6849210113287, 57.83585675060749, 54.567059352993965, 50.654895678162575, 51.52711607515812, 51.79110310971737, 52.46835596859455, 55.282838344573975, 54.873262122273445, 53.008451387286186, 50.558263063430786, 51.45024999976158, 55.955835431814194, 54.787534922361374, 51.72598980367184, 47.203829661011696, 41.853040382266045, 40.02315357327461, 43.16877298057079, 41.988913491368294, 42.365948259830475, 42.977308854460716, 42.53636911511421, 39.90760937333107, 43.54419283568859, 43.234862834215164, 42.48153805732727, 41.23096816241741, 42.35467046499252, 40.530935525894165, 41.638249307870865, 40.126614421606064, 40.86440563201904, 40.9036423265934, 47.50557906925678, 50.88142812252045, 52.096135541796684, 54.05550420284271, 56.38137459754944, 54.281272888183594, 55.59806562960148, 51.548558324575424, 45.54819390177727, 47.97238402068615, 51.67842395603657, 52.18377023935318, 55.37540137767792, 58.16248722374439, 54.41972225904465, 51.957982555031776, 53.10996674001217, 48.57396773993969, 50.108089819550514, 46.06913074851036, 44.85378876328468, 43.13835561275482, 45.762631595134735, 45.4957415163517, 45.70082031190395, 47.95291766524315, 48.36865335702896, 44.20842379331589, 39.52267102897167, 38.40291291475296, 39.68610405921936, 38.370021879673004, 39.77640621364117, 38.19215342402458, 38.74834097921848, 39.10696193575859, 37.70288407802582, 36.81615985929966, 37.370120733976364, 37.021968215703964, 36.708321645855904, 40.703305676579475, 48.32819692790508, 47.96824224293232, 50.07573455572128, 50.07519878447056, 49.44986253976822, 48.53759229183197, 50.00012241303921, 47.72367216646671, 44.01032902300358, 39.06153157353401, 37.12532266974449, 37.13670685887337, 47.07657068967819, 47.486253306269646, 53.058631494641304, 46.919836699962616, 48.98899666965008, 49.39495928585529, 50.480184853076935, 48.71302507817745, 49.8093194514513, 48.16441431641579, 38.838665932416916, 5.780609864741564, 2.5370103400200605, 4.302440257743001, 4.942038562148809, 9.07353026792407, 12.898579817265272, 6.615172382444143, 3.0285638384521008, 0.32299415732268244, 0.9980486263521016, 33.74198041856289, 43.938269689679146, 28.989332243800163, 32.52642564475536, 42.95854926109314, 17.11899910122156, 0.36347602726891637, 0.11514001147588715, 0.02663217903318582, 0.035912244056817144, 0.029470550653059036, 0.02944852371001616, 0.037871866443310864, 0.03117068852589, 0.011744012936105719, 0.021232579711067956, 0.06523960473714396, 0.04926442699797917, 0.07445988419931382, 0.05253778806945775, 0.023596652172273025, 0.06842417526058853, 0.02263253369164886, 0.04215521628793795, 0.03864060898195021, 0.08174878370482475, 0.07760840118862689, 0.07735970750218257, 0.17735603236360475, 0.21978945384034887, 0.18192396615631878, 0.24434133170871064, 0.07955866880365647, 0.1344825024716556, 0.09628504471038468, 0.1023569333483465, 0.15207944728899747, 0.2991102123633027, 0.12599901237990707, 0.1119142517563887, 0.07665401411941275, 0.15099065727554262, 0.12136118311900645, 0.17296928650466725, 0.25942766515072435, 0.1288837255560793, 0.11410155391786247, 0.23110965499654412, 0.20212190109305084, 0.18474969343515113, 9.521293491125107, 54.608667120337486, 36.049140617251396, 38.1399442255497, 55.48264682292938, 17.27829035371542, 0.2564808935858309, 1.5414601983502507, 1.340607963502407, 11.45037492737174, 16.79648380726576, 12.982439417392015, 21.35007206350565, 24.40242737531662, 0.6091269082389772, 3.6775464517995715, 37.01017364859581, 61.32007218897343, 60.967827290296555, 58.75231057405472, 53.24606403708458, 53.98042403161526, 54.467003121972084, 56.752968057990074, 58.475818410515785, 57.25418396294117, 53.38375724852085, 52.19177260994911, 54.72480408847332, 58.43521758913994, 57.899856716394424, 53.96543763577938, 50.36992236971855, 43.12254086136818, 42.43085637688637, 44.075970500707626, 43.6558498442173, 43.929754346609116, 44.403566122055054, 45.505058616399765, 42.26517766714096, 45.003177747130394, 43.27036052942276, 44.69454310834408, 44.40081886947155, 45.465054363012314, 43.21206785738468, 42.307499796152115, 42.061041221022606, 42.356190383434296, 42.29741133749485, 50.54866477847099, 52.57489465177059, 53.581958413124084, 54.807936027646065, 57.380139604210854, 54.77834701538086, 59.142462238669395, 53.77180002629757, 49.19771566987038, 51.43747888505459, 54.129303842782974, 53.1773941218853, 52.67581723630428, 55.67641742527485, 55.75608015060425, 54.69502508640289, 55.997579991817474, 51.71737186610699, 51.626036167144775, 48.517719358205795, 46.55131347477436, 45.88022008538246, 48.120344281196594, 48.011928498744965, 48.29964905977249, 48.32603104412556, 51.6113955527544, 46.00761964917183, 42.2333999723196, 39.69528816640377, 41.50695875287056, 39.89978179335594, 41.97728231549263, 40.79834617674351, 40.871515050530434, 40.980747789144516, 39.3612252920866, 39.01966542005539, 38.72070886194706, 38.53996016085148, 37.860518619418144, 42.66746588051319, 48.68831120431423, 51.8035664409399, 52.444717437028885, 51.92219987511635, 48.82165364921093, 50.13643629848957, 52.78256490826607, 50.388731360435486, 45.28228797018528, 40.73307327926159, 38.549262061715126, 39.87040176987648, 49.28683988749981, 49.30002138018608, 55.46872437000275, 48.636280596256256, 50.839725360274315, 52.56723426282406, 51.101405918598175, 52.136379182338715, 49.62933070957661, 52.0972640812397, 40.664426162838936, 5.937272608280182, 4.055636851117015, 7.268463252112269, 8.46128337085247, 23.309807404875755, 27.640372328460217, 19.631927758455276, 13.954275269061327, 1.4063776843249798, 1.8061643256805837, 40.12937307357788, 50.77178880572319, 37.38550990819931, 40.25325782597065, 49.404599368572235, 20.796523466706276, 0.7022394274827093, 0.2524786989670247, 0.1936207478865981, 0.08369742601644248, 0.11971359301242046, 0.19176439906004816, 0.21690450317692012, 0.10822708398336545, 0.17933394497958943, 0.06939774684724398, 0.15273510507540777, 0.08972860043286346, 0.12197232688777149, 0.1505459178588353, 0.16022021358367056, 0.24017730436753482, 0.14166616543661803, 0.08178776130080223, 0.10476184063008986], [0.07943989548948593, 0.12774292583344504, 0.033190769972861744, 0.026070790700032376, 0.015174678701441735, 0.02153047036699718, 0.11747977303457446, 0.025137274678854737, 0.018459617276676, 0.0309101297534653, 0.03358692098117899, 0.04895546349871438, 0.025719266886881087, 0.03273223774158396, 0.02317962826055009, 0.06638552527874708, 0.04303975983930286, 0.02627097761433106, 0.0396127779094968, 0.057939146281569265, 0.029488308391592, 0.036538293861667626, 0.040723064230405726, 0.03366367760463618, 0.021758291150035802, 0.46626380702946335, 21.131068915128708, 34.549364894628525, 22.256484925746918, 44.24766428768635, 23.730370737612247, 2.6701034232974052, 0.14991956006269902, 0.5383509560488164, 1.3547320431098342, 4.75695856846869, 6.00052828900516, 12.295308988541365, 2.130216993391514, 1.3862467207945883, 0.2119590833899565, 11.346107572317123, 56.4416241645813, 55.397960767149925, 55.40756285190582, 49.944630190730095, 51.219298392534256, 50.20168639719486, 54.65223178267479, 54.38140511512756, 53.20728711783886, 48.576897382736206, 53.0936124175787, 53.788929507136345, 50.38240849971771, 52.22122862935066, 46.47581912577152, 40.824085995554924, 40.174833834171295, 40.66198289394379, 43.09279225766659, 42.83639341592789, 41.69064849615097, 40.45373506844044, 40.89058242738247, 38.589239716529846, 39.777485355734825, 41.051184609532356, 38.47373351454735, 39.13870923221111, 39.249545484781265, 38.58232408761978, 38.3677040040493, 38.25629398226738, 39.97862756252289, 39.350946843624115, 45.937813594937325, 48.19917485117912, 50.68451888859272, 51.04107275605202, 52.489076256752014, 51.731613501906395, 50.775204822421074, 51.003143191337585, 51.59520082175732, 51.529684737324715, 50.164953768253326, 47.58477441966534, 45.95018953084946, 46.34586609899998, 53.95512878894806, 53.09461176395416, 48.621932566165924, 48.13628822565079, 46.83893524110317, 44.46879722177982, 43.72853994369507, 47.02962800860405, 46.61800369620323, 47.075476348400116, 49.12239611148834, 50.599859431385994, 50.230260863900185, 49.024513363838196, 41.41930505633354, 34.9149888753891, 36.79293930530548, 37.959347516298294, 37.54796639084816, 36.92505441606045, 36.99935182929039, 36.43432214856148, 36.76528058946133, 37.393592074513435, 36.527850329875946, 34.375512823462486, 35.13430930674076, 34.0493231266737, 41.37311093509197, 43.98104779422283, 47.60012559592724, 47.813628539443016, 48.1317512691021, 46.911591142416, 48.86521451175213, 48.53369750082493, 47.01130159199238, 42.22769647836685, 38.98306958377361, 34.033071398735046, 41.85743294656277, 42.87458896636963, 46.87760956585407, 47.57690504193306, 47.39452622830868, 50.770713463425636, 47.458769381046295, 49.363394379615784, 46.1406809091568, 45.36520712077618, 26.701440811157227, 0.8989284513518214, 1.7400510795414448, 3.1211620196700096, 5.354031454771757, 4.762796480208635, 7.579473238438368, 5.185254011303186, 1.8643000186420977, 0.04711735666205641, 4.101242478936911, 33.65852549672127, 33.50178770720959, 24.133728593587875, 30.68222690373659, 16.727477610111237, 2.7739751245826483, 0.06321756402030587, 0.052555458605638705, 0.027918148407479748, 0.041519102960592136, 0.0863321615906898, 0.049850404539029114, 0.034343336446909234, 0.07950732702738605, 0.06730782930389978, 0.01594508736161515, 0.07057543873088434, 0.09276823693653569, 0.047678171686129645, 0.026448616226844024, 0.0478621426736936, 0.043500299580045976, 0.06492673754110001, 0.019134214671794325, 0.013027315217186697, 0.018255667673656717, 0.01643309398787096, 0.07448343254509382, 0.0035617230150819523, 0.006214394443304627, 0.07922390825115144, 0.07119587418856099, 0.02201009072450688, 0.012610520443558926, 0.06109096953878179, 0.005063081271146075, 0.04232756153214723, 0.03563267702702433, 0.011648120034806198, 0.1635869368328713, 0.05256951117189601, 0.06466096703661606, 0.05555933101277333, 0.0070016410427342635, 0.0697033632604871, 0.015454369113285793, 0.05188567403820343, 0.04116747710213531, 0.04962121449352708, 0.056338485883316025, 1.4033290604129434, 29.214627854526043, 36.223988234996796, 23.996935933828354, 52.616513818502426, 29.4149512052536, 1.7431365139782429, 0.10669948431313969, 0.03339051530929282, 1.4369831420481205, 8.142837658524513, 7.919055791571736, 12.09602203220129, 9.341141358017921, 5.013595847412944, 0.2702576480805874, 14.42249184474349, 56.390957683324814, 56.43451854586601, 57.86617532372475, 52.67508767545223, 50.915831476449966, 52.61801853775978, 55.127730667591095, 55.24437300860882, 53.23494203388691, 51.48651145398617, 53.165101781487465, 55.611140727996826, 53.7335816770792, 54.37793590128422, 47.05324374139309, 43.22628289461136, 42.607949674129486, 43.95809322595596, 45.93712963163853, 44.49785426259041, 43.722844049334526, 43.50885473191738, 43.4721677005291, 41.247675865888596, 42.05690324306488, 42.72654891014099, 41.30059562623501, 41.71303689479828, 40.06506532430649, 40.740247294306755, 40.11175721883774, 41.03640720248222, 40.05415990948677, 40.3139291703701, 48.19329656660557, 51.43427185714245, 53.85284207761288, 52.39990644156933, 53.784316554665565, 54.79075334966183, 52.45675899088383, 51.01367622613907, 51.726761162281036, 51.61272928118706, 49.842404276132584, 49.340113028883934, 48.01441356539726, 47.09216885268688, 54.58451181650162, 53.499525636434555, 51.47308297455311, 49.26120266318321, 47.51119136810303, 46.64497084915638, 45.69868482649326, 46.6182354837656, 47.65744931995869, 49.292588979005814, 51.652190163731575, 49.938413724303246, 51.32597766816616, 50.49102947115898, 41.76642782986164, 36.64840266108513, 37.314647510647774, 38.98728355765343, 37.94088430702686, 37.708576172590256, 38.25626738369465, 38.810691833496094, 38.8818696141243, 39.276805222034454, 38.85231480002403, 35.67533187568188, 37.3132111877203, 36.0710084438324, 43.490129336714745, 46.661028787493706, 48.47701594233513, 50.45755706727505, 48.579941019415855, 47.32475437223911, 50.31072534620762, 51.87084183096886, 48.53465124964714, 43.68307538330555, 40.084417685866356, 35.5380642414093, 42.97788642346859, 45.30223689973354, 48.86916249990463, 48.80731321871281, 48.82166884839535, 49.83165085315704, 49.80051152408123, 48.720153495669365, 46.785874888300896, 46.55230142176151, 29.063027389347553, 0.6965831341221929, 3.7341470271348953, 5.753439422696829, 5.579329440370202, 6.0719772800803185, 11.36002242565155, 5.630117040127516, 1.0648873960599303, 0.13055775838438421, 4.9185429979115725, 38.779582902789116, 41.26374140381813, 28.555311933159828, 36.65827453136444, 25.464831367135048, 6.409528367221355, 0.12493034941144288, 0.08172977730282582, 0.06245242460863665, 0.025990944886871148, 0.055937774377525784, 0.037401270601549186, 0.007902095312601887, 0.0596212536765961, 0.07758195846690796, 0.010687926587706897, 0.02599958905193489, 0.057207169738831, 0.027531699124665465, 0.008700285343365977, 0.029695234006794635, 0.05165106260392349, 0.132033429981675, 0.017145145720860455, 0.049370858396287076, 0.11683609351166524, 0.15642114478396252, 0.17594970704521984, 0.11806044421973638, 0.0454547417757567, 0.13315094111021608, 0.195598081627395, 0.12123697728384286, 0.12748977926094085, 0.2036272140685469, 0.18348980869632214, 0.1577749557327479, 0.19442366261500865, 0.1627420907607302, 0.29273839958477765, 0.16375394974602386, 0.10192933012149297, 0.17297425889410079, 0.14113288780208677, 0.18694168596994132, 0.14381581102497876, 0.10942125896690413, 0.19856141792843118, 0.1716668767039664, 0.22979560832027346, 1.2639027857221663, 32.65417858958244, 49.50936734676361, 30.33867783844471, 54.03485991060734, 35.85378170013428, 4.456179533153772, 0.6054879503790289, 2.160746455192566, 6.33508893661201, 13.667178824543953, 15.571863669902086, 19.32203348726034, 7.514460626989603, 4.132683891803026, 0.5834190908353776, 13.577390592545271, 61.68768346309662, 57.59618081152439, 60.84425412118435, 53.443881422281265, 54.1814636439085, 54.48574371635914, 57.953829020261765, 56.55652239918709, 57.17804744839668, 50.56006416678429, 56.047676503658295, 57.34545886516571, 54.164565950632095, 57.67895556986332, 50.121305510401726, 44.915455654263496, 44.7261156141758, 45.91572158038616, 49.30817574262619, 45.68888895213604, 46.13555498421192, 44.544705748558044, 45.79431429505348, 42.81951852142811, 42.74429775774479, 44.7380393743515, 42.13352993130684, 44.092081636190414, 42.5332722812891, 43.35408143699169, 41.99863336980343, 41.09745092689991, 43.86865362524986, 41.445839032530785, 50.01217536628246, 52.77575567364693, 56.428682059049606, 56.035011783242226, 55.26941366493702, 55.09904980659485, 54.29943971335888, 53.241686671972275, 52.23029114305973, 53.82202573120594, 50.53432434797287, 48.50620977580547, 48.07830713689327, 48.402794525027275, 57.535137087106705, 54.30598296225071, 51.72143004834652, 52.76863485574722, 50.51113799214363, 49.206075221300125, 46.97412818670273, 49.81642127037048, 49.736614152789116, 51.60409614443779, 53.868128657341, 52.393454387784004, 53.929571360349655, 52.309049516916275, 45.3924972563982, 38.835500702261925, 40.05117326974869, 41.4696941524744, 40.04726707935333, 39.95391748845577, 40.22193990647793, 41.416717395186424, 41.86521492898464, 41.40330031514168, 42.11726300418377, 38.97367648780346, 39.41649712622166, 38.79904545843601, 45.02550534904003, 47.98292085528374, 52.12104320526123, 52.66212277114391, 52.131903022527695, 48.35699938237667, 52.1747001260519, 53.599665462970734, 50.535487085580826, 46.663035079836845, 42.77695320546627, 37.4030801653862, 45.692255571484566, 48.46063122153282, 51.188307255506516, 51.05871520936489, 51.13441474735737, 53.24523188173771, 52.06086963415146, 51.8278319388628, 48.42707522213459, 46.92871682345867, 28.787673264741898, 1.4427154907025397, 5.287128919735551, 9.736526291817427, 11.11933859065175, 10.962341465055943, 14.056084156036377, 15.56110929697752, 6.770361755043268, 0.23988590750377625, 6.384023185819387, 46.397246941924095, 46.51950158178806, 34.06541906297207, 46.05064854025841, 29.79245524853468, 5.945011368021369, 0.2647029695799574, 0.1450329480576329, 0.27538989612367004, 0.1877860422246158, 0.17831071629188955, 0.13807566981995478, 0.2281198388664052, 0.1177140096842777, 0.2767186373239383, 0.14971815602621064, 0.1410241037956439, 0.21502447983948514, 0.13227458344772458, 0.11836425721412525, 0.11548085763934068, 0.16705070331227034, 0.26591504516545683, 0.12960271822521463, 0.14942603185772896], [0.03553768583515193, 0.06326967020868324, 0.03589617284887936, 0.027303215974825434, 0.013526934599212836, 0.051466753939166665, 0.029472270580299664, 0.01358342131425161, 0.030502802001137752, 0.06764778489014134, 0.10464182792929932, 0.10278962770826183, 0.04980535617505666, 0.06820280745159835, 0.03919593582395464, 0.042621177417458966, 0.06647726215305738, 0.047717798661324196, 0.15112598048290238, 0.05216046534769703, 0.05304261176206637, 0.020355209016997833, 0.018510521185817197, 0.043596073737717234, 0.06761316370102577, 0.21394762356067076, 3.9927326515316963, 26.101650595664978, 26.393803618848324, 32.71391898393631, 39.809521436691284, 11.119524780660868, 0.07872909613070078, 0.19504777912516147, 0.49107128055766225, 5.930138016119599, 4.996842071413994, 12.349970005452633, 7.211621627211571, 7.543226508423686, 0.07280755919055082, 1.7444195388816297, 35.239685252308846, 57.33497142791748, 56.97297625243664, 55.186110734939575, 52.06920638680458, 52.927774116396904, 54.012904688715935, 50.17656974494457, 53.43741416931152, 53.43415014445782, 55.52829757332802, 53.999168425798416, 51.81759148836136, 46.18142232298851, 41.34452126920223, 40.37641681730747, 42.64055572450161, 44.980033189058304, 46.194246634840965, 43.91607128083706, 42.52072915434837, 39.466403648257256, 39.44292850792408, 38.09829846024513, 40.50771877169609, 41.2892684340477, 39.81326423585415, 38.28815907239914, 39.12685006856918, 39.68535929918289, 39.01493847370148, 38.8383087515831, 36.76170498132706, 38.02989833056927, 44.352029487490654, 48.960353806614876, 51.77497677505016, 50.12340299785137, 50.92406943440437, 50.544902980327606, 49.99768294394016, 48.852580189704895, 48.744574785232544, 48.63539144396782, 49.73597198724747, 49.93959926068783, 47.33459584414959, 48.673837780952454, 53.629079684615135, 51.87354728579521, 49.010716304183006, 48.06276597082615, 45.808783918619156, 46.71694278717041, 48.01217548549175, 49.647174552083015, 50.77936939895153, 49.98542480170727, 50.9392686188221, 51.0809326171875, 51.38901628553867, 51.164930909872055, 41.76235444843769, 34.07383181154728, 36.39158584177494, 36.3629087805748, 37.172489538788795, 37.85606525838375, 36.78187809884548, 37.95130334794521, 37.74159260094166, 38.38298678398132, 35.70471189916134, 36.72459617257118, 33.183775171637535, 36.33689917623997, 36.05364717543125, 41.17224231362343, 44.600137174129486, 47.36526019871235, 48.90534795820713, 49.13790687918663, 45.74998587369919, 47.27153442800045, 47.1285405009985, 46.00957274436951, 43.143375143408775, 37.0877692848444, 37.42668829858303, 41.7519012093544, 42.892216220498085, 46.75326123833656, 45.90385861694813, 46.8600545078516, 48.93212132155895, 49.327775090932846, 45.31145520508289, 47.02243119478226, 12.674989365041256, 0.3906626481330022, 2.545588379725814, 2.2597420681267977, 4.18127378448844, 6.705644577741623, 6.04306748136878, 3.7537190644070506, 0.5746884655673057, 0.05902518663788214, 6.86489213258028, 41.95647843182087, 22.04351395368576, 26.60538386553526, 23.165479749441147, 7.687213132157922, 0.18832549452781677, 0.07997938490007073, 0.030378178707906045, 0.012920263197884196, 0.0820172333624214, 0.012880958129244391, 0.03643111289420631, 0.03324273886391893, 0.045722337963525206, 0.06471473563578911, 0.015305064771382604, 0.04522880233707838, 0.050153100601164624, 0.09334956121165305, 0.03839224184048362, 0.05718725791666657, 0.00887676249476499, 0.04993091642973013, 0.036740002178703435, 0.03952665538236033, 0.07626371123478748, 0.07274577539646998, 0.028927738276252057, 0.07225362016470172, 0.007893851907283533, 0.0576999372424325, 0.04377365483378526, 0.007696038474023226, 0.06044823625416029, 0.05027514307585079, 0.05185566529689822, 0.06969148147618398, 0.03217166020476725, 0.025802751079027075, 0.06903523739310913, 0.03794320538872853, 0.029576824344985653, 0.029516658432839904, 0.03975181927671656, 0.017509260069346055, 0.036747668564203195, 0.04384177656902466, 0.07708480858127587, 0.062144767289282754, 0.08649687384604476, 0.13370266853598878, 6.247585332021117, 36.29117622971535, 26.401862986385822, 34.48908492922783, 43.6613405495882, 12.340276725590229, 0.030803421905147843, 0.35788067907560617, 0.8538482047151774, 6.985752722248435, 6.028484338894486, 10.467860698699951, 12.923993803560734, 7.440481446683407, 0.4859124933136627, 2.360215801745653, 40.266089737415314, 59.269288033246994, 57.81740494072437, 54.32388760149479, 55.16876466572285, 54.69990782439709, 56.22752845287323, 52.899047657847404, 54.847613498568535, 53.52670177817345, 55.84549315273762, 55.485470071434975, 53.573161885142326, 47.44586527347565, 44.89914692938328, 40.5084977298975, 43.54928456246853, 47.05653816461563, 47.09033355116844, 45.84748484194279, 43.68815951049328, 41.92002698779106, 41.503584533929825, 42.03581057488918, 42.743256613612175, 42.22812965512276, 40.60748241841793, 40.85548751056194, 41.020090878009796, 41.332654505968094, 40.874072313308716, 40.44642046093941, 39.03367526829243, 40.20195297896862, 47.17709809541702, 49.6764861792326, 53.88951390981674, 54.10938911139965, 51.15825466811657, 52.292448207736015, 50.21100349724293, 50.920235440135, 49.423233568668365, 51.485496908426285, 51.18946239352226, 50.45127600431442, 47.98729442059994, 49.563575237989426, 54.353347420692444, 52.89047531783581, 50.880713760852814, 48.71301367878914, 47.53821551799774, 47.91637122631073, 48.60821530222893, 50.75033135712147, 52.87612348794937, 52.88340389728546, 52.0805411785841, 51.26402199268341, 52.45464250445366, 52.11202248930931, 44.25725877285004, 36.53799958527088, 37.27463945746422, 38.406621515750885, 38.761590868234634, 40.171189829707146, 38.72205778956413, 39.01596441864967, 38.998291566967964, 40.167956203222275, 37.54814878106117, 38.31885002553463, 34.89208370447159, 39.38838243484497, 38.58959689736366, 43.525030463933945, 48.394476771354675, 48.40629033744335, 50.55507503449917, 49.157605022192, 46.760868430137634, 49.43419598042965, 49.149469658732414, 47.43177182972431, 43.09016279876232, 37.85287722945213, 39.873073026537895, 43.19418601691723, 44.85177107155323, 47.916899397969246, 46.551617458462715, 48.61723981797695, 50.09873852133751, 50.89402064681053, 44.921037554740906, 49.28675629198551, 14.207731168717146, 0.36721229553222656, 5.504995929077268, 4.2856290098279715, 9.128266330808401, 11.565499249845743, 5.619610128924251, 1.7531412583775818, 0.3425060212612152, 0.03436869192228187, 7.901191050186753, 46.427261531353, 31.5877753123641, 28.50110024213791, 31.029201485216618, 11.400367710739374, 0.33470990834757686, 0.04395314696012065, 0.07244133899803273, 0.017309188187937252, 0.05293486305163242, 0.051659051823662594, 0.021376888471422717, 0.013100634769216413, 0.05649108257784974, 0.03894879322615452, 0.06870481840451248, 0.04420581855811179, 0.02905834513512673, 0.07024680831818841, 0.030231608252506703, 0.05090424310765229, 0.054519485638593324, 0.03289756226877216, 0.032009341375669464, 0.10273294989019632, 0.22202457999810576, 0.2000919045531191, 0.11394139102776535, 0.1749791411566548, 0.06176162241899874, 0.1380330408574082, 0.21306152892066166, 0.10143787993001752, 0.192905465955846, 0.1668170900666155, 0.17249103169888258, 0.21591159864328802, 0.09701729955850169, 0.17879691207781434, 0.13397433911450207, 0.13575204997323453, 0.1503487440641038, 0.06725913699483499, 0.19903958367649466, 0.18649880192242563, 0.10405441062175669, 0.11545107525307685, 0.13866698340279981, 0.13936924806330353, 0.2249002835014835, 0.3257168596610427, 6.6426886059343815, 44.32780958712101, 39.63787704706192, 39.497995153069496, 51.930540427565575, 17.342068031430244, 0.22461368091171607, 0.6014519731979817, 2.7836446557193995, 15.553654097020626, 12.579275351017714, 19.173607751727104, 13.527175337076187, 13.429749514907598, 0.4766882210969925, 2.3987564211711287, 38.785328194499016, 60.652679800987244, 59.76247496902943, 58.72204139828682, 56.88563793897629, 57.731115370988846, 58.8447330147028, 55.605900809168816, 55.31337350606918, 55.926964581012726, 57.77722209692001, 58.38826730847359, 57.027134746313095, 49.41678151488304, 45.609796196222305, 44.590618684887886, 45.54588362574577, 50.27839668095112, 49.31383743882179, 47.36531339585781, 46.88697226345539, 43.09780798852444, 42.80485510826111, 43.05159866809845, 45.64290001988411, 45.424426943063736, 42.85411186516285, 41.61644987761974, 43.364907056093216, 44.00698900222778, 42.36011177301407, 42.9351881146431, 41.20129555463791, 41.152323782444, 49.501292780041695, 53.12729001045227, 54.95351381599903, 56.8061538040638, 53.16740445792675, 52.71908551454544, 52.099494561553, 50.49094207584858, 50.51684528589249, 53.67709010839462, 51.50015652179718, 52.61440113186836, 48.46114419400692, 48.634589686989784, 56.99577882885933, 54.73464176058769, 53.24374236166477, 52.03659273684025, 50.56632623076439, 51.23298525810242, 52.63071745634079, 53.63684266805649, 55.97549557685852, 54.758876860141754, 55.550100803375244, 53.21319580078125, 54.180293306708336, 56.524011343717575, 45.26373736560345, 37.0131678879261, 39.450600296258926, 40.61977095901966, 41.04871094226837, 43.06706003844738, 41.486185267567635, 42.101129069924355, 42.24827617406845, 43.768703788518906, 40.04716068506241, 40.96497103571892, 36.12388640642166, 41.66051611304283, 39.658582136034966, 44.32560570538044, 49.00973215699196, 50.29948554933071, 53.084633499383926, 50.67328289151192, 49.86318156123161, 48.75026308000088, 51.47582642734051, 49.954885840415955, 48.137899339199066, 40.580492466688156, 41.672721058130264, 44.36249792575836, 46.31079778075218, 49.29739952087402, 48.42389479279518, 50.68574242293835, 53.15618745982647, 52.90253207087517, 48.78108322620392, 47.635410502552986, 15.619212929159403, 1.0517209838144481, 8.372942861169577, 7.503822622820735, 14.114712160080671, 15.03621781244874, 16.036545485258102, 11.031147222965956, 1.4924593339674175, 0.1114464686543215, 11.696643512696028, 53.41282568871975, 32.11706981062889, 36.40208087861538, 40.478239953517914, 12.360829822719097, 0.3621177782770246, 0.22023293160600588, 0.1384467733441852, 0.09289850611821748, 0.24211355281295255, 0.1148926536552608, 0.14293839951278642, 0.08284639043267816, 0.17066395317669958, 0.1580906950403005, 0.19180226343451068, 0.16799912351416424, 0.10501158074475825, 0.16978091618511826, 0.11425016899011098, 0.0943805453425739, 0.25434223178308457, 0.08352844641194679, 0.12011936967610382, 0.2686966146575287], [0.03186143876519054, 0.013554741944972193, 0.07944086770294234, 0.04046208428917453, 0.11569297086680308, 0.04274702710972633, 0.04129333050514106, 0.05351194595277775, 0.026470902921573725, 0.10769188418635167, 0.03368805344507564, 0.030379349445865955, 0.008722351249161875, 0.05711566293030046, 0.02380288944550557, 0.04962765262462199, 0.047514231264358386, 0.03258215692767408, 0.034667688378249295, 0.024718130080145784, 0.03978079643275123, 0.04378164034278598, 0.02115147224685643, 0.059557996719377115, 0.06381487415637821, 0.04623959262971766, 0.3584685194073245, 12.135625407099724, 34.41971965134144, 29.149354957044125, 45.97546957433224, 23.065533712506294, 0.6130325642880052, 0.04797825538844336, 0.9695834631565958, 5.643691336736083, 11.339984200894833, 4.548952979966998, 17.959713488817215, 10.50665756687522, 0.6625668844208121, 0.09277948789531365, 9.51612101867795, 49.00429084897041, 57.54466697573662, 54.5145233720541, 53.54779064655304, 55.587635189294815, 53.074959218502045, 53.740223720669746, 53.067344427108765, 56.63366585969925, 52.160431891679764, 51.64543032646179, 47.842628583312035, 41.61720983684063, 37.66296721994877, 41.73415996134281, 45.529833287000656, 49.5636360347271, 50.397854670882225, 50.250722765922546, 46.79572395980358, 47.51166254281998, 43.742025420069695, 39.426596984267235, 41.37545920908451, 39.38337430357933, 39.721514359116554, 39.025577902793884, 40.514402613043785, 38.40319409966469, 39.17305938899517, 37.279252409935, 37.573071643710136, 38.0093452334404, 41.80499196052551, 47.26573973894119, 50.82168012857437, 51.491166204214096, 51.92891411483288, 51.59489683806896, 50.15396475791931, 48.82829949259758, 49.33357737958431, 49.73720692098141, 49.50432501733303, 48.32024395465851, 47.61770345270634, 47.20241613686085, 52.574244886636734, 54.092183634638786, 48.64538870751858, 49.06482920050621, 48.66105146706104, 49.48720693588257, 51.2337414175272, 59.90087114274502, 57.12821312248707, 53.574712201952934, 51.4335460960865, 52.21331365406513, 53.656195029616356, 51.46112121641636, 40.156097039580345, 33.493819534778595, 36.4998572319746, 36.82087920606136, 38.02481800317764, 36.41477979719639, 36.377036422491074, 37.26224832236767, 37.68613837659359, 38.338912948966026, 36.63021303713322, 34.84036087989807, 35.42491391301155, 36.24008037149906, 35.64790114760399, 35.14291204512119, 40.191161558032036, 45.42320340871811, 46.19155637919903, 48.985109478235245, 47.20917597413063, 46.180825755000114, 48.404835015535355, 47.516488283872604, 46.91772781312466, 42.85335950553417, 41.314373686909676, 43.2508409768343, 45.127408280968666, 45.754458233714104, 47.48688407242298, 47.19866193830967, 47.85406216979027, 44.591792821884155, 48.36410500109196, 36.48857943713665, 4.40019903704524, 0.4380885267164558, 4.035792890936136, 4.668499315157533, 3.348853876814246, 3.256470146588981, 3.271699254401028, 2.376932054758072, 0.25760972988791764, 0.15058347053127363, 16.52536455541849, 38.9295494556427, 17.277764081954956, 34.36181075870991, 17.466270066797733, 1.2212319066748023, 0.1313678125734441, 0.00394247677832027, 0.10062058237963356, 0.03202362400770653, 0.014025156888237689, 0.05182216104003601, 0.025603048416087404, 0.05294022506859619, 0.049157891698996536, 0.05525625645532273, 0.03682270340505056, 0.034124644080293365, 0.019725398378795944, 0.017110899316321593, 0.0028209578204041463, 0.013509096152120037, 0.03418945583689492, 0.01128510963098961, 0.05058270391600672, 0.004039267214466236, 0.06938077392987907, 0.043420288639026694, 0.0707977861748077, 0.07231754876556806, 0.018687911178858485, 0.05558967743127141, 0.060884433551109396, 0.06505258352262899, 0.014925867199053755, 0.018625205266289413, 0.016995525038510095, 0.06120240672316868, 0.013234698180895066, 0.07054874367895536, 0.02714853941142792, 0.0805032521020621, 0.05561576763284393, 0.016020830953493714, 0.04271297737432178, 0.053894311568001285, 0.07225119334179908, 0.04022363595140632, 0.019806529962806962, 0.0501571564382175, 0.06639104685746133, 0.03434390790062025, 0.51540274056606, 18.144104294478893, 40.45261412858963, 30.30674435198307, 52.277613803744316, 27.430158108472824, 0.7089948118664324, 0.079795629135333, 0.5621503258589655, 1.6907454002648592, 9.232777822762728, 6.798499245196581, 13.357077464461327, 5.860218442976475, 1.7847067583352327, 0.03962808470532764, 11.45040912553668, 52.60415308177471, 59.45660658180714, 58.17328244447708, 54.74746227264404, 59.19458024203777, 54.53061930835247, 54.40491825342178, 53.15798096358776, 57.88994684815407, 54.29155133664608, 51.820194348692894, 51.098643466830254, 44.87883321940899, 39.210700169205666, 42.84196011722088, 48.21321129798889, 50.15673100948334, 50.46389512717724, 51.94080747663975, 49.44108501076698, 46.14774852991104, 44.69778433442116, 40.369147807359695, 43.4784259647131, 41.20352603495121, 42.01654180884361, 40.68969860672951, 42.5860096514225, 40.80471083521843, 40.548874363303185, 40.07093220949173, 40.2563052624464, 40.81330597400665, 44.19665962457657, 48.3316433429718, 52.127400264143944, 53.17986398935318, 53.688858076930046, 52.633628100156784, 51.32019057869911, 51.15350492298603, 50.04137299954891, 50.035912692546844, 50.00352323055267, 50.17663814127445, 46.87607824802399, 47.27522403001785, 53.46855729818344, 54.20625351369381, 49.71633084118366, 49.54130843281746, 48.30999210476875, 50.44796638190746, 52.74812735617161, 57.09279142320156, 54.94781792163849, 54.943467155098915, 54.158649668097496, 54.60120432078838, 54.034316539764404, 52.67618581652641, 43.518943190574646, 35.396069660782814, 39.1136609762907, 39.2609828710556, 38.34318771958351, 38.569602370262146, 37.429401353001595, 39.051990285515785, 39.11925807595253, 39.61287818849087, 38.955338671803474, 36.19241952896118, 36.15011639893055, 38.032554388046265, 36.08476750552654, 37.94216103851795, 42.05776959657669, 49.082635045051575, 47.5550752133131, 50.09416736662388, 47.86942854523659, 48.53115923702717, 50.4271586984396, 48.677234798669815, 46.926858723163605, 44.52172078192234, 41.03400573134422, 45.05773141980171, 47.36679531633854, 48.70938867330551, 48.860324174165726, 47.52211958169937, 48.89712519943714, 47.424844801425934, 49.63114321231842, 39.42345455288887, 5.504206521436572, 0.9942095854785293, 4.723236802965403, 5.381272193044424, 8.834808077663183, 12.471062857657671, 3.276958172209561, 1.3703673728741705, 0.14987449685577303, 0.1712268721894361, 19.649737402796745, 48.57326477766037, 20.278592258691788, 35.521018356084824, 22.854551933705807, 2.4593783682212234, 0.3311574552208185, 0.0324448670289712, 0.025379923572472762, 0.040633208700455725, 0.03426151095482055, 0.03806034226727206, 0.090120038803434, 0.043650710649671964, 0.06103597639594227, 0.08423215826041996, 0.035711934688151814, 0.014862518401059788, 0.03829737310297787, 0.026726138639787678, 0.03630309984146152, 0.05742225155699998, 0.07597047384479083, 0.03184435081493575, 0.05191460295463912, 0.03520780861435924, 0.16163689928362146, 0.11123144620796666, 0.21455585811054334, 0.1190492075693328, 0.2098202137858607, 0.19514853309374303, 0.06898243358591571, 0.1757094293134287, 0.1653891385649331, 0.14822893281234428, 0.10345090355258435, 0.14102051180088893, 0.06753085952368565, 0.1684724207734689, 0.09619661039323546, 0.18170219758758321, 0.1347810387960635, 0.12518284289399162, 0.11857113087899052, 0.10840513263246976, 0.25240478105843067, 0.08239481583586894, 0.07531449693487957, 0.17111629218561575, 0.1442305973614566, 0.1430098683340475, 0.4986071668099612, 20.531003214418888, 53.1910315901041, 40.66241227090359, 55.96429377794266, 34.6777980029583, 1.1218159412965178, 0.21322178828995675, 2.1643320377916098, 9.800357166677713, 24.588125310838223, 10.99855637177825, 32.063196301460266, 21.466794200241566, 2.085950318723917, 0.20304329227656126, 11.991705279797316, 53.63219931721687, 60.354555398225784, 58.33418861031532, 56.116612404584885, 60.120829939842224, 57.100470811128616, 55.11572331190109, 53.00346605479717, 61.851690262556076, 56.45960479974747, 53.377293795347214, 52.57278576493263, 45.55668644607067, 41.314852461218834, 45.40591813623905, 51.27385586500168, 52.56192974746227, 53.66810739040375, 53.377027809619904, 50.814205929636955, 50.738384798169136, 48.01674284040928, 43.1255616992712, 44.58603233098984, 43.87156426906586, 43.07053305208683, 43.14427949488163, 45.26287481188774, 41.89279764890671, 42.55289062857628, 40.94596445560455, 42.752132937312126, 42.29730114340782, 46.52003735303879, 50.774023085832596, 54.20919455587864, 55.485496670007706, 56.48960039019585, 55.54376654326916, 52.59907655417919, 51.08030565083027, 52.26084150373936, 51.06261380016804, 52.28764906525612, 52.63378009200096, 48.49512577056885, 48.72979357838631, 56.11368656158447, 56.28444939851761, 52.17847712337971, 53.12019199132919, 53.25480356812477, 55.32561644911766, 54.869694113731384, 58.57709817588329, 55.33339463174343, 57.468731850385666, 55.17585888504982, 55.23740038275719, 58.128995820879936, 55.45249164104462, 45.22389270365238, 37.23849579691887, 40.04522658884525, 41.3386619836092, 40.26096761226654, 40.09271644055843, 39.37043599784374, 40.157993137836456, 41.496809497475624, 42.50759705901146, 41.67792297899723, 37.452751100063324, 40.01434564590454, 40.99554039537907, 38.80355961620808, 39.186989441514015, 44.24694612622261, 50.590101554989815, 49.776926189661026, 50.23088403046131, 49.615412056446075, 49.47597473859787, 50.49162603914738, 49.4378399848938, 49.61708016693592, 46.29318192601204, 44.18812908232212, 47.534385323524475, 49.83399912714958, 51.433033123612404, 50.78226864337921, 49.455794021487236, 50.836791917681694, 49.90911729633808, 49.30215686559677, 37.63004958629608, 5.742237148806453, 1.06629605172202, 11.686213072389364, 9.164453689008951, 9.942442942410707, 11.489565074443817, 8.229043632745743, 5.869907448068261, 0.7605491392314434, 0.4655694239772856, 26.23235408216715, 49.825354591012, 25.42119260877371, 44.27562698721886, 28.539768867194653, 1.5817614295519888, 0.43570495618041605, 0.09023508653626777, 0.19130824541207403, 0.07100138696841896, 0.1230639593268279, 0.15473603911232203, 0.19309561903355643, 0.120944318769034, 0.28138523222878575, 0.23766094876918942, 0.14690366486320272, 0.1493908540578559, 0.07083085627527907, 0.16324822063324973, 0.1323121361201629, 0.18041347299003974, 0.20796226192032918, 0.12288501267903484, 0.14323203766252846, 0.18542970850830898], [0.04092816416232381, 0.03694235616421793, 0.03667281926027499, 0.06434948023525067, 0.007406430650007678, 0.04262105496309232, 0.019357467535883188, 0.040091485425364226, 0.006730778941346216, 0.0658681667118799, 0.02783857718895888, 0.04201043811917771, 0.041725483097252436, 0.03696532192407176, 0.03700877838127781, 0.11685950084938668, 0.04741513228509575, 0.01698101419606246, 0.019061810744460672, 0.01993076177313924, 0.021054065364296548, 0.04202029755106196, 0.04744969781313557, 0.07417228713165969, 0.03520150035910774, 0.07184969144873321, 0.06744398371665739, 1.6297768405638635, 27.723342776298523, 26.064758375287056, 27.356060184538364, 41.440162137150764, 6.369099961593747, 0.012317306245677173, 0.4758779739495367, 2.880560355260968, 4.980836380273104, 3.776096301153302, 19.317918308079243, 12.348297145217657, 1.0559913609176874, 0.010768172232928919, 1.5666669770143926, 27.029519006609917, 55.271286964416504, 55.68984590470791, 55.50476923584938, 55.95089949667454, 55.45885629951954, 54.52316410839558, 53.68407793343067, 54.71302852034569, 53.311789110302925, 49.2514181882143, 41.34996257722378, 39.048217087984085, 41.85441970825195, 42.86977842450142, 48.08465279638767, 54.24709752202034, 55.709008276462555, 53.694208189845085, 51.86395660042763, 52.744430154562, 50.31855292618275, 41.156659349799156, 38.37009407579899, 41.004534512758255, 39.032421335577965, 40.853105038404465, 39.380832239985466, 39.41807024180889, 38.59083943068981, 39.11832332611084, 38.14907893538475, 39.4431146979332, 38.7090814858675, 44.57218587398529, 49.77037534117699, 50.32289609313011, 51.204669177532196, 53.04502822458744, 52.899640426039696, 53.948479145765305, 53.86488363146782, 52.97478899359703, 49.26235020160675, 52.31911897659302, 47.033807784318924, 48.176056891679764, 51.194481924176216, 50.737260058522224, 49.763615503907204, 51.25033512711525, 49.85080562531948, 53.34713101387024, 47.88353718817234, 60.91858573257923, 63.25919173657894, 45.018338933587074, 49.55396555364132, 49.683257415890694, 50.693243220448494, 45.529130324721336, 36.63867138326168, 35.67790813744068, 35.66365510225296, 37.64300309121609, 38.04120272397995, 36.837130934000015, 36.475147157907486, 37.51705504953861, 36.980147659778595, 35.94987094402313, 36.005097180604935, 35.51700197160244, 35.52316144108772, 36.43112652003765, 38.27692307531834, 39.71507750451565, 38.951257690787315, 43.435093089938164, 44.374607875943184, 46.19009345769882, 45.69558799266815, 47.744297459721565, 46.20395891368389, 50.411438941955566, 48.634950667619705, 46.68571226298809, 43.12831275165081, 45.43807961046696, 47.125717252492905, 47.191240936517715, 48.587160632014275, 49.92755390703678, 49.11272943019867, 47.10548713803291, 45.79888924956322, 19.607660360634327, 0.8704465453047305, 0.6565797713119537, 3.0169564113020897, 1.9401280372403562, 11.425921339541674, 15.353181604295969, 1.306381062604487, 0.7593292265664786, 0.27227394457440823, 1.006208925973624, 32.90852174162865, 33.240912705659866, 26.384630911052227, 36.31693124771118, 4.96484256349504, 0.08356406207894906, 0.04132876805670094, 0.04929807968437672, 0.06235406035557389, 0.01578294479259057, 0.0643335834320169, 0.07128692086553201, 0.020271203466109, 0.03109387995209545, 0.06943898799363524, 0.09441438727662899, 0.019450224863248877, 0.039404453345923685, 0.015509506047237664, 0.013242485165392281, 0.019319425045978278, 0.04171009095443878, 0.03632419909990858, 0.03665925651148427, 0.09330109154689126, 0.04617123711796012, 0.0039126591400417965, 0.01927586654346669, 0.07219058214104734, 0.06724862818373367, 0.03910594299668446, 0.08458492331556045, 0.02165303420042619, 0.021789027196064126, 0.07087033111019991, 0.044243285883567296, 0.007107907313184114, 0.010388371665612794, 0.03528314031427726, 0.034982674405910075, 0.026605637976899743, 0.05117226603033487, 0.04128115557250567, 0.018008525075856596, 0.021880732529098168, 0.03140095839626156, 0.018708190364122856, 0.02170672858483158, 0.09752934434800409, 0.07713617262197658, 0.06073670905607287, 0.029845105163985863, 0.1566085816011764, 2.9265478625893593, 37.44491592049599, 30.33465575426817, 36.8487773090601, 48.59702490270138, 5.815240731462836, 0.02366340278967982, 0.5458440945949405, 0.6997205782681704, 5.458101695403457, 4.862203421071172, 9.64343698695302, 8.73146217316389, 3.0937391286715865, 0.11472702113678679, 1.409310889430344, 31.11841879785061, 56.68791554868221, 59.91085320711136, 56.787037029862404, 55.9747052192688, 55.90580731630325, 54.84065607190132, 55.0742257386446, 57.975943833589554, 55.61996005475521, 51.67831376194954, 45.76067470014095, 41.38777434825897, 41.46052524447441, 45.30013181269169, 49.51958119869232, 55.27036741375923, 57.31082372367382, 55.62026023864746, 53.99179682135582, 53.40760096907616, 51.2121319770813, 43.10699209570885, 39.53937493264675, 42.589288875460625, 42.93788217008114, 41.50011532008648, 41.29412457346916, 42.156138718128204, 41.22031733393669, 40.47005519270897, 42.0735539495945, 39.72937993705273, 41.2630308419466, 46.33928865194321, 50.53400136530399, 53.68618302047253, 54.71622794866562, 53.71373154222965, 54.16888251900673, 55.61947748064995, 55.351010486483574, 55.622201934456825, 51.8369210511446, 51.80173873901367, 48.76677319407463, 49.70657676458359, 53.37135851383209, 53.45723770558834, 51.34924001991749, 53.46718177199364, 51.581323966383934, 52.68859215080738, 52.298999056220055, 58.472953364253044, 61.94315895438194, 50.17149321734905, 50.68187043070793, 50.89877799153328, 51.457431614398956, 47.15465649962425, 37.9757284373045, 37.87950620055199, 36.39524884521961, 37.8035406768322, 39.315874725580215, 38.03598180413246, 38.1925980001688, 39.56044480204582, 38.23829434812069, 38.739749640226364, 37.53000855445862, 36.848287135362625, 38.68117198348045, 38.45202527940273, 39.84888732433319, 40.81680178642273, 40.3071541339159, 44.46189299225807, 46.45595759153366, 47.78424471616745, 47.65598639845848, 47.72492989897728, 47.64883518218994, 51.77547834813595, 51.331133991479874, 48.3082327991724, 45.54390013217926, 48.66228640079498, 48.27840819954872, 47.79505133628845, 50.49937002360821, 50.27293257415295, 50.66779598593712, 47.21314676105976, 47.35703743994236, 22.251353301107883, 1.625626275781542, 1.8669350584968925, 4.064407255500555, 4.560806918889284, 9.67479670420289, 11.058008931577206, 1.9896124256774783, 0.31067572301253676, 0.13422509597148746, 0.9371715586166829, 39.060178846120834, 41.20378442108631, 24.99704036861658, 40.23570656776428, 7.605937393382192, 0.05903385492274538, 0.11090660074842162, 0.02634990873048082, 0.08143599814502522, 0.017907631954585668, 0.04474496658076532, 0.02819598808855517, 0.05268769076792523, 0.08300466084619984, 0.032899172729230486, 0.09446228548767976, 0.04336291691288352, 0.013924663599027554, 0.02489425656676758, 0.027541226445464417, 0.04840975489059929, 0.047836928206379525, 0.03935206885216758, 0.019489191327011213, 0.012573955755215138, 0.023508024896727875, 0.056380554524366744, 0.16095891769509763, 0.16665190283674747, 0.1430972636444494, 0.1326217601308599, 0.18955124047352, 0.10083282177220099, 0.27716051205061376, 0.09546614412101917, 0.14238309493521228, 0.08750537832383998, 0.11316283358610235, 0.08707160042831674, 0.12053982602083124, 0.2112190137268044, 0.24187423987314105, 0.1986987894633785, 0.19479972368571907, 0.13772233331110328, 0.16793659015093, 0.15562489454168826, 0.1199143216945231, 0.14312881976366043, 0.17272408091230318, 0.10821794814546593, 0.20207484893035144, 0.38043080654460937, 3.599678655155003, 43.23470324277878, 39.842982441186905, 36.2129308283329, 54.72983501851559, 10.360872689634562, 0.074810370861087, 1.3444685563445091, 6.557433055713773, 12.375588230788708, 12.08631545305252, 27.796046175062656, 21.23012199997902, 5.078920042142272, 0.2721943863434717, 2.078618137165904, 31.714743599295616, 57.00637266039848, 59.428932666778564, 57.42084302008152, 58.00541125237942, 56.918016001582146, 56.54560178518295, 57.69637003540993, 60.40642261505127, 58.27531836926937, 54.444485530257225, 47.113147526979446, 43.45026187598705, 46.50738023221493, 45.958712473511696, 52.615689262747765, 59.45562243461609, 60.323917642235756, 57.645714953541756, 55.592103749513626, 56.02130591869354, 53.397550508379936, 45.53682491183281, 42.42627002298832, 43.0093677341938, 45.51439091563225, 44.48933131992817, 44.486215487122536, 43.70949536561966, 42.99406215548515, 43.265527188777924, 42.60704152286053, 43.08236941695213, 41.20435059070587, 49.48290176689625, 52.94515818357468, 54.91817571222782, 55.63506044447422, 55.37674270570278, 57.25950747728348, 57.8091099858284, 58.503199741244316, 59.22817803919315, 52.229918763041496, 54.6280612796545, 50.503629595041275, 50.989422127604485, 54.632248654961586, 54.560481905937195, 53.07908199727535, 56.140786707401276, 54.18539643287659, 55.396262258291245, 52.09703229367733, 60.47407038509846, 63.353848457336426, 49.70181941986084, 50.64989134669304, 53.1856282800436, 54.47853550314903, 48.86298783123493, 39.70853425562382, 40.45334368944168, 38.371146619319916, 40.18850550055504, 40.080310106277466, 40.102793499827385, 40.687870904803276, 41.49565435945988, 40.8387304097414, 39.827418476343155, 39.82022546231747, 39.74227264523506, 38.766025230288506, 40.431848242878914, 41.503174155950546, 44.11056384444237, 41.75666235387325, 46.3489705324173, 48.02289091050625, 49.64418411254883, 48.26255924999714, 48.9937350153923, 48.35195705294609, 54.82028916478157, 54.03591625392437, 50.761194974184036, 46.0309161990881, 50.533530190587044, 51.3493388146162, 50.30668616294861, 52.00580298900604, 51.16207726299763, 52.459304854273796, 49.012559205293655, 47.74237856268883, 22.55236554890871, 1.4375491929240525, 3.334893425926566, 7.991271391510963, 8.491212464869022, 21.11449610441923, 36.333152577281, 9.557461850345135, 1.602008524350822, 0.7123068091459572, 1.8521511205472052, 47.29988090693951, 43.04845243692398, 33.95957574248314, 48.88661876320839, 8.170320633798838, 0.2991107170237228, 0.2321123261936009, 0.13167489843908697, 0.170308330853004, 0.14368019095854834, 0.17456393921747804, 0.23712226829957217, 0.15207552874926478, 0.11767495787353255, 0.1646214016363956, 0.21751288615632802, 0.08742155274376273, 0.10737872755271383, 0.13297947531100363, 0.10027203272329643, 0.0930826626427006, 0.0949927578039933, 0.12949803087394685, 0.09755403560120612, 0.1336300716502592, 0.11264594257227145], [0.031079643704288173, 0.07432097641867585, 0.0727994846238289, 0.0655508614727296, 0.008706546286703087, 0.027266095603408758, 0.012590427722898312, 0.03805541440669913, 0.029095198333379813, 0.014753292816749308, 0.035091313693556, 0.0791771529475227, 0.02636009841808118, 0.037104426373844035, 0.10159425786696374, 0.0994475586048793, 0.044800089599448256, 0.018574540699773934, 0.0340260831580963, 0.02100977213558508, 0.0454449380049482, 0.044291562589933164, 0.027901667162950616, 0.09563519051880576, 0.019293754157843068, 0.03557749463652726, 0.05527089902898297, 0.20000054617412388, 10.99179083481431, 35.17445795238018, 25.93847595155239, 40.16042120754719, 21.09280116856098, 0.1892330520786345, 0.23576872452395037, 0.1159155483765062, 5.932539962232113, 5.096502648666501, 3.5989730805158615, 18.138273507356644, 2.8491113428026438, 0.3191164357122034, 0.06162199846585281, 10.35997498780489, 39.93183687329292, 56.58553384244442, 55.07421053946018, 57.33823925256729, 53.670026287436485, 54.25652861595154, 52.49229468405247, 53.514052256941795, 51.00369036197662, 42.721981555223465, 40.308734849095345, 40.53555987775326, 42.56031163036823, 47.962021976709366, 54.09830890595913, 56.2575164437294, 55.0043398886919, 54.164626747369766, 54.71867121756077, 53.00594352185726, 52.03906640410423, 44.7844272851944, 39.15101297199726, 39.686837419867516, 38.63354533910751, 38.95177826285362, 40.10086700320244, 41.518076956272125, 39.90314841270447, 37.951717525720596, 40.49035370349884, 38.34898620843887, 35.943236500024796, 40.34057334065437, 45.597849637269974, 49.67003792524338, 49.82951536774635, 49.614218920469284, 52.578542456030846, 52.32061229646206, 51.99919134378433, 53.41386303305626, 54.580529630184174, 51.074127182364464, 52.464225590229034, 45.06556659936905, 49.43073056638241, 52.37566374242306, 52.287945449352264, 51.39807499945164, 53.1746506690979, 50.04130460321903, 52.87968389689922, 49.64232221245766, 42.51919783651829, 49.92485985159874, 52.44732789695263, 50.60454078018665, 49.60646353662014, 40.844916477799416, 35.87476797401905, 35.43766222894192, 36.32122881710529, 37.710419073700905, 38.54463391005993, 36.1733977496624, 37.03823894262314, 36.59157291054726, 36.81783176958561, 37.23409563302994, 34.74251613020897, 36.04840345680714, 33.613383919000626, 35.928478091955185, 38.314138278365135, 40.961555019021034, 43.60537715256214, 45.145852491259575, 45.96741400659084, 47.782466411590576, 47.52096064388752, 45.76683036983013, 49.337342977523804, 48.93245570361614, 49.8064012080431, 48.55781480669975, 47.400662899017334, 46.848978102207184, 47.78943143785, 47.238567396998405, 48.62583875656128, 49.1559749096632, 45.1420982927084, 46.83526083827019, 32.71290823817253, 6.402702983468771, 0.7808002119418234, 2.016050931997597, 2.769751651212573, 3.2088848249986768, 5.888718338683248, 5.460278978571296, 1.0072183655574918, 0.2124460955383256, 0.09259827769710682, 6.386130647733808, 41.270983815193176, 21.272164843976498, 32.2990420460701, 27.015974633395672, 0.7554064120631665, 0.11348330779583193, 0.04382141574751586, 0.0834376372222323, 0.007216240464913426, 0.07397925452096388, 0.05643263102683704, 0.03425385199079756, 0.041062585660256445, 0.03434745536651462, 0.013976358823128976, 0.05042861921538133, 0.12328744967817329, 0.0685543405415956, 0.044835994704044424, 0.08914407007978298, 0.009982431729440577, 0.025862043112283573, 0.04604628171364311, 0.030956979680922814, 0.0257305735067348, 0.02889257903007092, 0.03824616491328925, 0.006874315404274967, 0.055321402178378776, 0.015778111555846408, 0.03262375801568851, 0.016361422931367997, 0.04405139618029352, 0.019496007953421213, 0.016523721351404674, 0.04233100509736687, 0.08035806575207971, 0.05918103764997795, 0.07824023603461683, 0.06879242151626386, 0.030653387475467753, 0.04707969637820497, 0.0691404590907041, 0.019141997945553157, 0.02814448675053427, 0.04931265546474606, 0.12123167092795484, 0.06746291590388864, 0.037667772121494636, 0.024455944148940034, 0.03943141928175464, 0.08766259488766082, 0.09516889913356863, 0.3768842312274501, 16.941685415804386, 38.940743654966354, 25.205711871385574, 53.20908062160015, 24.20739334076643, 0.06700756377540529, 0.09582698374288157, 0.20745528599945828, 2.523632920347154, 5.773634389042854, 8.4759515337646, 16.18758548051119, 5.225456804037094, 2.082090200856328, 0.08716825774172321, 12.518518511205912, 42.323029562830925, 58.50338593125343, 56.24797135591507, 56.316466480493546, 54.44450832903385, 54.52651172876358, 54.25157368183136, 54.67415660619736, 54.882138445973396, 45.42751997709274, 42.182722091674805, 42.6658471673727, 45.60152783989906, 49.555531069636345, 55.51722876727581, 58.43103401362896, 55.95331236720085, 55.62603212893009, 57.52937279641628, 54.81301635503769, 54.448019340634346, 46.069332137703896, 41.157430708408356, 40.75065493583679, 40.769034549593925, 41.760857328772545, 43.55293236672878, 42.4517210572958, 42.050097808241844, 39.12027642130852, 40.972566828131676, 39.133959487080574, 39.29745331406593, 43.255271539092064, 48.11751343309879, 51.52452081441879, 52.44165100157261, 51.61260388791561, 54.90003548562527, 53.166139125823975, 54.14667651057243, 55.989691615104675, 56.35903179645538, 52.482867389917374, 52.09696389734745, 45.318667218089104, 51.725336238741875, 53.12360800802708, 53.000133633613586, 52.744247764348984, 54.461387023329735, 51.28605701029301, 53.897569477558136, 51.25813610851765, 46.608865186572075, 50.970958918333054, 53.2737797498703, 51.603833958506584, 51.17829479277134, 42.163643315434456, 37.55883760750294, 36.198879182338715, 38.87031823396683, 38.91678974032402, 40.64264953136444, 37.56630040705204, 38.62952895462513, 39.85443502664566, 37.634092569351196, 38.63012172281742, 37.307625487446785, 37.46608458459377, 37.638602927327156, 37.247280925512314, 40.18187865614891, 42.04580023884773, 44.53150525689125, 47.036733627319336, 47.193118035793304, 48.60728055238724, 49.328443855047226, 46.620621755719185, 49.62608568370342, 49.3473706394434, 50.940457955002785, 50.260951817035675, 48.86737659573555, 48.9251296967268, 48.61155532300472, 47.81418330967426, 49.40892733633518, 50.23793265223503, 46.33033253252506, 47.80792124569416, 36.29999175667763, 7.513181045651436, 1.9166660774499178, 2.4334409600123763, 3.4327374631538987, 4.791454067453742, 8.135566748678684, 5.519479801878333, 1.2363503454253078, 0.5474017735105008, 0.1690293729188852, 6.832151664420962, 51.35297901928425, 25.667776577174664, 33.23906980454922, 33.49926844239235, 1.2041898211464286, 0.052870949293719605, 0.0492180761648342, 0.0150913596371538, 0.06036326776666101, 0.08781618234934285, 0.03834104849374853, 0.04724016354884952, 0.02645484470122028, 0.02557196727138944, 0.05372510560846422, 0.048343351227231324, 0.0800049296231009, 0.050256270260433666, 0.015416722744703293, 0.04351831150415819, 0.031675731152063236, 0.03738682469702326, 0.07314390793908387, 0.01603512471774593, 0.0249808763328474, 0.0013402697686615284, 0.11500829510623589, 0.20027666963869706, 0.08578810055041686, 0.1489306185976602, 0.1596443069865927, 0.12180774079752155, 0.13814967678627, 0.08173976661055349, 0.12960218387888744, 0.136329366650898, 0.1487834210274741, 0.15893383417278528, 0.17180899798404425, 0.13877530727768317, 0.11925243728910573, 0.14073772385017946, 0.10943380126263946, 0.15248581767082214, 0.17043716768966988, 0.16996921389363706, 0.2565027424134314, 0.12118276339606382, 0.14880463160807267, 0.17627153196372092, 0.07169010743382387, 0.1405558828264475, 0.15479775611311197, 0.3169780410826206, 19.74941935390234, 52.24724963307381, 33.132470324635506, 49.7437197715044, 31.159570589661598, 0.34917843353468925, 0.7788294833153486, 0.32453230291139334, 13.893009256571531, 15.236639957875013, 6.8093975353986025, 24.590777568519115, 8.16648568958044, 1.4539639558643103, 0.22641261719400063, 13.536630179733038, 42.00806066393852, 58.3302216231823, 56.36511147022247, 58.931881338357925, 53.89323391020298, 57.56486289203167, 56.094360798597336, 58.6821511387825, 56.780945956707, 45.62236972153187, 44.30038645863533, 45.43370224535465, 46.63469620049, 53.315098732709885, 58.41100908815861, 62.0312762260437, 58.22482667863369, 58.78885701298714, 59.00532379746437, 56.98344849050045, 56.61046050488949, 47.78019793331623, 43.283150643110275, 42.64051392674446, 42.98232838511467, 44.435723796486855, 44.489764496684074, 44.8072412610054, 44.272925332188606, 41.170729994773865, 43.94010879099369, 42.80022315680981, 38.99763040244579, 45.14570809900761, 50.615408197045326, 53.955915346741676, 52.724868804216385, 55.039431005716324, 56.86602719128132, 56.38810023665428, 55.17759159207344, 58.407011702656746, 57.55679972469807, 54.49322171509266, 53.40749837458134, 48.319974169135094, 53.18730778992176, 54.66971084475517, 56.344565972685814, 54.259758442640305, 56.58346675336361, 53.83683733642101, 53.698178976774216, 54.15776811540127, 49.466923624277115, 51.723022162914276, 56.79416164755821, 54.62816007435322, 54.833884835243225, 44.32043798267841, 39.11336459219456, 37.415516898036, 40.96477724611759, 41.48892492055893, 42.436495274305344, 39.43637765944004, 41.264573559165, 40.372294038534164, 40.33619977533817, 42.07967162132263, 39.466567039489746, 39.68266524374485, 39.31878536939621, 40.02284198999405, 42.127146273851395, 43.51099781692028, 47.168791741132736, 49.04747933149338, 49.20713536441326, 50.95408022403717, 51.03687398135662, 48.12870383262634, 51.432314962148666, 51.33428782224655, 51.561637222766876, 51.51066295802593, 51.83757461607456, 50.312686040997505, 49.90260064601898, 48.08425761759281, 49.048129096627235, 51.13194867968559, 47.287565767765045, 47.74387948215008, 34.50652219355106, 7.528406353667378, 1.6531876218505204, 4.626697758212686, 6.130319824442267, 10.372686255723238, 15.274691116064787, 16.78960047662258, 5.40152320638299, 1.7295426246710122, 0.6542428373359144, 10.970081649720669, 53.664083406329155, 30.02360064536333, 42.651468738913536, 38.81706029176712, 1.4694278198294342, 0.33752181683667004, 0.15256648912327364, 0.1670387844205834, 0.108222490089247, 0.16810090164653957, 0.13625259889522567, 0.17538576386868954, 0.10178991025895812, 0.10960292187519372, 0.09543452120851725, 0.11336259005474858, 0.2499230985995382, 0.22631567786447704, 0.17912982468260452, 0.15854453318752348, 0.13081917248200625, 0.1686902708024718, 0.15790400037076324, 0.08878835869836621, 0.13259338040370494, 0.17587575945071876], [0.020715174759970978, 0.09283837731345557, 0.05033225876104552, 0.05535325144592207, 0.06327087990939617, 0.028276242082938552, 0.05397083812567871, 0.05160339074791409, 0.03542499071045313, 0.04608389004715718, 0.020611522704712115, 0.07455584389390424, 0.06150941837404389, 0.033296555702690966, 0.025890675169648603, 0.046096744044916704, 0.02799601268634433, 0.0520369979494717, 0.011143355714011705, 0.020696973588201217, 0.048113482116605155, 0.03935930479201488, 0.11629928325419314, 0.08522643576725386, 0.04335815603553783, 0.05635873538267333, 0.055764353019185364, 0.0793322098616045, 1.3557075220160186, 32.37797521054745, 28.782228156924248, 34.430925250053406, 49.300256967544556, 4.6639143861830235, 0.06169344131194521, 0.3827927360543981, 0.830712077440694, 4.692789511755109, 3.2519310526549816, 8.550002910196781, 15.011441241949797, 0.6272848276421428, 0.25485983525868505, 2.35629512462765, 23.565493784844875, 48.29059414565563, 55.15684090554714, 53.68809811770916, 55.93022480607033, 53.66098277270794, 51.62405647337437, 50.446381866931915, 45.51686458289623, 41.68965294957161, 43.10448043048382, 43.83380949497223, 46.156909838318825, 52.454304322600365, 55.04506230354309, 56.210930943489075, 54.77726027369499, 53.12556870281696, 55.509849563241005, 51.91054590046406, 49.520766735076904, 42.28827282786369, 39.35265675187111, 40.347751155495644, 40.20106762647629, 39.41397026181221, 39.95747409760952, 39.81794558465481, 41.723041757941246, 39.920897260308266, 40.48792563378811, 36.923576295375824, 40.73542155325413, 37.28046074509621, 41.912879571318626, 43.672694340348244, 44.5780261605978, 46.82864159345627, 49.31568793952465, 47.359750494360924, 52.37585373222828, 49.65454235672951, 52.54344753921032, 54.612755700945854, 54.62950520217419, 46.28547213971615, 44.61108058691025, 50.63277326524258, 51.54299922287464, 54.265796318650246, 52.61630482971668, 48.84361267089844, 53.08736175298691, 40.425589978694916, 44.021603018045425, 54.839405938982964, 49.79135401546955, 49.625409319996834, 41.552111729979515, 35.47669753432274, 34.88216243684292, 35.896818190813065, 37.44696781039238, 38.5937462747097, 36.317003443837166, 37.13265247642994, 36.18410937488079, 37.33028747141361, 37.156651988625526, 36.35667331516743, 35.97809582948685, 36.49604223668575, 36.48871622979641, 35.181073397397995, 38.01521211862564, 42.17675641179085, 46.94307245314121, 47.311671674251556, 50.06381839513779, 45.930320397019386, 48.37111942470074, 46.23539462685585, 46.819548681378365, 49.073709324002266, 49.59518574178219, 47.48427361249924, 47.71550640463829, 47.03391797840595, 48.56861762702465, 48.38682398200035, 46.41719587147236, 44.3669056892395, 50.132100731134415, 43.109382167458534, 15.931478273123503, 1.5603157365694642, 1.7457672790624201, 0.864166907267645, 2.1101334085687995, 3.3745295740664005, 7.151968153193593, 4.374374197795987, 0.502829096512869, 0.07144024115405045, 0.22646210360107943, 17.239057458937168, 38.47778029739857, 23.56818974018097, 40.01158319413662, 10.288042947649956, 0.08635212536319159, 0.09362995944684371, 0.06104306390625425, 0.04931152368953917, 0.04552069272904191, 0.02041316889517475, 0.13278339989483356, 0.05651942890835926, 0.03720039348991122, 0.024630803418403957, 0.041360795439686626, 0.045543246596935205, 0.019459653849480674, 0.038533364931936376, 0.011030113255401375, 0.057798294074018486, 0.03170668984239455, 0.045375862609944306, 0.019708544205059297, 0.03536929994879756, 0.024780080857453868, 0.016193024057429284, 0.05633631881210022, 0.03665910437121056, 0.035082055401289836, 0.01834807433624519, 0.08039915104745887, 0.07798792066751048, 0.07302082274691202, 0.018097124520863872, 0.062220002510002814, 0.03610654574004002, 0.03057541744055925, 0.05298361473251134, 0.0261361627781298, 0.047687812184449285, 0.033267463513766415, 0.0819401464832481, 0.05179638625122607, 0.06829626610851847, 0.01303354461924755, 0.02073270243272418, 0.016426856236648746, 0.03898844246577937, 0.06573504026164301, 0.07774768004310317, 0.009705354605102912, 0.0649706504191272, 0.061155361981946044, 0.08507226200890727, 2.4062633933499455, 40.21867208182812, 29.504472501575947, 34.57329221069813, 47.54604309797287, 4.065858777612448, 0.08272798077086918, 0.19589222443755716, 0.9558650117833167, 3.6425899900496006, 4.038395751267672, 14.197902996093035, 10.239208918064833, 6.0541315376758575, 0.9148753643967211, 2.5909577077254653, 27.061384096741676, 49.13601458072662, 57.02791750431061, 53.25769141316414, 57.87255518138409, 56.153725013136864, 54.69953164458275, 53.27938824892044, 49.2015078663826, 43.913289830088615, 45.84207773208618, 45.47218278050423, 49.01612341403961, 54.39476899802685, 56.4550906419754, 56.67679354548454, 55.88435746729374, 55.979504361748695, 58.10647822916508, 54.07197251915932, 51.95651963353157, 44.1491773724556, 40.48546716570854, 40.99164180457592, 42.40994229912758, 41.28017172217369, 43.84371176362038, 40.941841676831245, 44.63582865893841, 41.07339821755886, 41.02485962212086, 38.56182798743248, 41.43821284174919, 40.45891419053078, 43.351683765649796, 46.612133011221886, 47.19978287816048, 48.403394892811775, 50.881333127617836, 49.93300661444664, 52.761715427041054, 52.08279065787792, 55.91650754213333, 54.82469692826271, 55.15984274446964, 49.580237343907356, 47.42571495473385, 50.06793737411499, 52.93198049068451, 54.411111921072006, 53.89025866985321, 49.18637327849865, 54.50131148099899, 44.061314687132835, 45.243370458483696, 56.84666723012924, 50.35938173532486, 51.92449875175953, 43.8708271086216, 37.81714774668217, 36.2021242082119, 36.85501277446747, 39.255967140197754, 39.99148987233639, 38.91811586916447, 38.06629657745361, 37.22150310873985, 37.900059297680855, 38.98213483393192, 37.196439653635025, 37.8502743691206, 38.1502340734005, 38.41200202703476, 37.20364406704903, 41.06647878885269, 43.04756708443165, 48.3835219591856, 50.03937050700188, 50.10892577469349, 47.939424589276314, 48.38034152984619, 46.41480579972267, 48.82931403815746, 49.61318917572498, 50.02950243651867, 49.423104375600815, 49.9418069422245, 48.21113660931587, 50.40750615298748, 48.04226227104664, 47.2564834356308, 44.42471958696842, 50.255138128995895, 43.5290202498436, 17.88671750575304, 2.738247304223478, 3.074391041882336, 1.9491607462987304, 3.114676480181515, 5.234113214537501, 5.908968402072787, 3.002916402183473, 0.9918294881936163, 0.13715445675188676, 0.16312790365191177, 21.425839997828007, 47.08923541009426, 22.145021706819534, 43.94092194736004, 14.097316693514585, 0.10976528152241372, 0.18430594849633053, 0.019168570543115493, 0.06148854175989982, 0.04915254823572468, 0.11369648229447193, 0.11284143911325373, 0.05247956658422481, 0.01864127832959639, 0.0479984752018936, 0.02057758243608987, 0.03949321420805063, 0.06351313917548396, 0.010476025800016942, 0.02659062432940118, 0.07883564627263695, 0.041737520732567646, 0.04864630333031528, 0.0817230089160148, 0.057006478164112195, 0.01921432023664238, 0.03103027233009925, 0.13199087523389608, 0.2251254065777175, 0.10149023844860494, 0.11643198668025434, 0.12126975794672035, 0.17200387112097815, 0.33491569105535746, 0.13396068359725177, 0.14305252698250115, 0.1867567576118745, 0.3589395456947386, 0.2547995431814343, 0.2028556921868585, 0.11256267360295169, 0.11894168521394022, 0.18069676560116932, 0.17893676238600165, 0.12930853088619187, 0.08894110011169687, 0.10428106994368136, 0.15756268665427342, 0.15165701683145016, 0.20752430573338643, 0.11776443861890584, 0.10636521357810125, 0.14138548518531024, 0.19283120665932074, 0.46942734508775175, 3.0673022847622633, 47.15556085109711, 40.88300943374634, 40.26930056512356, 60.86133040487766, 7.22029228694737, 0.2482611924642697, 1.6521703451871872, 2.575051048770547, 16.00252591073513, 9.36894541606307, 14.664555005729198, 24.63277291506529, 4.8525334149599075, 0.6423451413866132, 3.136915974318981, 26.895099319517612, 48.98422412574291, 56.082182452082634, 55.07966324687004, 58.9976292103529, 58.732654228806496, 56.14962503314018, 55.09561479091644, 50.96144422888756, 47.03525170683861, 48.86208347976208, 48.73422794044018, 51.25145606696606, 55.723869279026985, 57.621840834617615, 60.218374505639076, 56.48447446525097, 56.63215734064579, 60.545654743909836, 55.43583333492279, 55.087342634797096, 46.2345776706934, 42.476457729935646, 43.966969549655914, 44.57631625235081, 43.7994859367609, 45.22250957787037, 44.608154743909836, 47.60511852800846, 44.68107283115387, 43.03949251770973, 39.09999690949917, 43.80242697894573, 41.998621970415115, 45.14791578054428, 46.13411866128445, 48.35014075040817, 51.7134390771389, 52.73303456604481, 50.856832042336464, 54.13237027823925, 54.462526962161064, 57.27387070655823, 60.695351511240005, 59.05412457883358, 50.77293634414673, 47.47020296752453, 53.579781129956245, 53.357956632971764, 55.603636130690575, 55.851219445466995, 50.696245059370995, 53.89391027390957, 48.10322619974613, 51.35483331978321, 56.219944059848785, 53.962732180953026, 54.88495409488678, 45.522150099277496, 38.992401883006096, 37.78452269732952, 38.61147232353687, 41.27367787063122, 41.23251087963581, 39.68061335384846, 40.05292497575283, 39.401753917336464, 41.60102650523186, 40.648432821035385, 37.6365814357996, 39.71354238688946, 40.357725620269775, 39.32519182562828, 39.516310170292854, 43.36805708706379, 45.29986962676048, 51.17686226963997, 51.23058758676052, 53.13628792762756, 49.48633298277855, 51.07958368957043, 49.05809976160526, 49.17607583105564, 51.35880030691624, 54.453327655792236, 51.35838992893696, 52.714381366968155, 49.613781943917274, 52.69439443945885, 49.574207067489624, 49.393142983317375, 46.59076675772667, 51.072223484516144, 44.702104702591896, 18.41283157467842, 2.7208421006798744, 3.296004175208509, 3.6904315603896976, 8.353242818266153, 8.164932522922754, 15.105699934065342, 10.93470174819231, 1.8535593012347817, 0.5423949484247714, 0.270282257697545, 26.255213655531406, 50.87494947016239, 30.735165663063526, 52.63954818248749, 14.987966101616621, 0.17732227948727086, 0.24014208203880116, 0.11776451283367351, 0.2557017275830731, 0.17280049243709072, 0.17584191751666367, 0.3263297548983246, 0.14877015142701566, 0.10333125450415537, 0.18329692451516166, 0.10363317502196878, 0.10024891482316889, 0.10760218079667538, 0.08240772178396583, 0.1672825650894083, 0.1320969726657495, 0.10544745149672963, 0.12347634110483341, 0.15911891096038744, 0.22098670131526887, 0.12903981405543163, 0.19053957337746397], [0.021090660666231997, 0.05736252722272184, 0.017096904266509227, 0.07163121059420519, 0.047573558549629524, 0.08205227015423588, 0.03806751141382847, 0.019439539792074356, 0.04092312869033776, 0.021326517053239513, 0.05174197198357433, 0.023975004623935092, 0.03197918049409054, 0.04542024304100778, 0.013788038850179873, 0.020522427876130678, 0.027591267607931513, 0.017122931385529228, 0.007175694154284429, 0.026683159012463875, 0.024142898837453686, 0.06341769898426719, 0.02015611305978382, 0.025312584803032223, 0.04049041206599213, 0.05350824634660967, 0.13267814851133153, 0.09381373005453497, 0.44241426803637296, 17.27005809545517, 35.587237402796745, 44.67962130904198, 51.03658139705658, 17.565942518413067, 0.23837121378164738, 0.313543084776029, 0.3701316670048982, 1.7166476603597403, 9.303519576787949, 3.9987705275416374, 17.235305160284042, 7.725042002275586, 0.28529180854093283, 0.19556956831365824, 8.916564490646124, 34.40906882286072, 50.763474851846695, 57.15250141918659, 54.66787934303284, 54.444192945957184, 51.14992931485176, 49.43990707397461, 46.59561909735203, 43.44671666622162, 46.81313842535019, 50.595615059137344, 53.22199612855911, 54.43361431360245, 56.93678319454193, 56.18697702884674, 54.808863177895546, 53.0961848795414, 51.31593860685825, 49.94735084474087, 50.525144040584564, 47.55414426326752, 42.66909599304199, 41.94985918700695, 39.30510990321636, 39.304596930742264, 39.66568395495415, 40.71899123489857, 41.21554858982563, 41.02848842740059, 38.189660757780075, 39.196283742785454, 40.13385683298111, 37.584509029984474, 39.938133135437965, 39.71008837223053, 40.476302057504654, 45.33494934439659, 44.314506500959396, 47.22134292125702, 46.145214065909386, 47.37101688981056, 50.74712812900543, 50.92389464378357, 56.032602712512016, 48.2251350581646, 45.03823846578598, 49.88980673253536, 46.63887217640877, 50.94886690378189, 50.05082689225674, 49.963256791234016, 48.205239325761795, 43.61942499876022, 50.16600251197815, 51.41191765666008, 48.90587992966175, 43.33105467259884, 35.45756556093693, 35.37979133427143, 35.2968417853117, 38.01961608231068, 36.05304680764675, 37.4503306299448, 37.86233492195606, 37.23752684891224, 39.38466623425484, 37.64066241681576, 36.59713201224804, 36.21647983789444, 36.932023242115974, 35.71458376944065, 34.57888551056385, 35.24729244410992, 38.07532489299774, 42.93020278215408, 46.41246132552624, 48.45492012798786, 47.01419323682785, 46.986910700798035, 46.005670353770256, 48.09799388051033, 50.92625051736832, 46.74721576273441, 45.950463116168976, 47.089041620492935, 47.596151009202, 48.25394131243229, 47.560144141316414, 46.61843687295914, 47.726734802126884, 45.76776131987572, 41.226845383644104, 22.203504368662834, 2.485987152904272, 0.6577653076965362, 3.1619400065392256, 1.6778604104183614, 1.9988632667809725, 3.1199667463079095, 3.9206844801083207, 0.9401750599499792, 0.7199190475512296, 0.18251199944643304, 0.7672922336496413, 32.2330129891634, 33.64921599626541, 26.898281648755074, 28.92256412655115, 2.2431481210514903, 0.04211138504615519, 0.04165921673120465, 0.010939618550764862, 0.006831281043560011, 0.027418378740549088, 0.05312801440595649, 0.0924923583806958, 0.04182256343483459, 0.045236168152769096, 0.004759748353535542, 0.039827173241064884, 0.036966097468393855, 0.06585077819181606, 0.04447322920896113, 0.047670965432189405, 0.019514793566486333, 0.020924078198731877, 0.03934930806281045, 0.023832573497202247, 0.016767147644713987, 0.025037298109964468, 0.06815056767663918, 0.0860540269059129, 0.04140228149481118, 0.016088056545413565, 0.04509601727477275, 0.07187793016782962, 0.04325486021116376, 0.054162557134986855, 0.05038843934016768, 0.03133103695290629, 0.051118990959366783, 0.050723608073894866, 0.054312868014676496, 0.023286564319278114, 0.008224418397730915, 0.06841531401732937, 0.04815425942069851, 0.045614314658450894, 0.02828539832989918, 0.03287550192908384, 0.02159240815672092, 0.025484436519036535, 0.029393790318863466, 0.056026631718850695, 0.04306386108510196, 0.06333446712233126, 0.04919756691379007, 0.07326490769628435, 0.10194087051786482, 0.656527642859146, 23.408807292580605, 39.595262333750725, 38.287444710731506, 62.98297695815563, 18.874795585870743, 0.18167160626035184, 0.14311316044768319, 0.3850072156637907, 2.526773689314723, 2.8685586992651224, 5.829411596059799, 22.16693513095379, 8.137864675372839, 3.267524940893054, 0.7868748984765261, 11.099766790866852, 37.87473365664482, 51.93145997822285, 57.92842738330364, 55.54254300892353, 56.94649547338486, 53.70263233780861, 52.303072437644005, 46.074271872639656, 45.45445293188095, 47.83661350607872, 52.16281436383724, 56.33621782064438, 55.826334580779076, 58.243130296468735, 57.59103588759899, 56.13947577774525, 55.93970529735088, 55.117775201797485, 53.06759901344776, 52.716995626688, 48.78550238907337, 43.1888435035944, 43.49804811179638, 41.52676708996296, 42.440390065312386, 41.866256073117256, 42.3672553896904, 43.03684405982494, 42.43549972772598, 41.18496783077717, 41.34615518152714, 41.65885180234909, 39.44393165409565, 41.270888820290565, 42.33711540699005, 43.410242423415184, 46.06913834810257, 47.512775883078575, 49.48879525065422, 47.27621577680111, 49.41343769431114, 53.4429656714201, 53.016974329948425, 57.42867439985275, 50.03455236554146, 44.587187469005585, 51.00393354892731, 48.67110192775726, 51.33667789399624, 51.46432064473629, 50.77234737575054, 51.146726086735725, 42.45589703321457, 51.00921906530857, 53.60104098916054, 51.11358046531677, 46.39940522611141, 39.112950414419174, 37.558628618717194, 37.40208841860294, 38.75926919281483, 38.12282234430313, 38.945991173386574, 38.74476917088032, 39.11816753447056, 40.91023117303848, 39.88100700080395, 38.1805906444788, 37.800991013646126, 37.95203670859337, 37.59854547679424, 36.46719038486481, 37.79603987932205, 40.8159164339304, 44.439660385251045, 48.60001914203167, 49.94567133486271, 49.297513514757156, 48.466577902436256, 47.50579945743084, 49.78786200284958, 52.1114981174469, 49.92785409092903, 48.92054334282875, 48.654295429587364, 48.726704344153404, 49.013725742697716, 49.9912840873003, 47.348157316446304, 48.01323562860489, 47.12892808020115, 43.455467596650124, 26.010457389056683, 4.307233225554228, 1.8076496897265315, 4.734661839902401, 2.3945775954052806, 2.9595051566138864, 8.703440576791763, 5.27641111984849, 0.6948650325648487, 0.46224314777646214, 0.34383348596747965, 0.7316701544914395, 38.826479986310005, 37.55416765809059, 26.907319463789463, 36.74459829926491, 3.589907241985202, 0.05872914021892939, 0.030529795767506585, 0.02981766239827266, 0.017554126607137732, 0.039565503102494404, 0.05803599655337166, 0.08912631048588082, 0.019408338048378937, 0.03327126330987085, 0.015580414547002874, 0.01989678254176397, 0.048141219886019826, 0.02621851333969971, 0.03801023245614488, 0.03365648248291109, 0.04838906752411276, 0.015289171678887215, 0.02725208756601205, 0.00856581096741138, 0.08006898438907228, 0.01828523298172513, 0.11398859904147685, 0.16015494911698624, 0.2142572178854607, 0.11177173713804223, 0.17258724372368306, 0.1825270353583619, 0.1820387615589425, 0.1606458204332739, 0.148219789552968, 0.07911275679362006, 0.1158831907378044, 0.1614320368389599, 0.08674283642903902, 0.11680766925564967, 0.149568242195528, 0.07757523460895754, 0.0881465122802183, 0.13711749779758975, 0.20276540250051767, 0.1269401001627557, 0.20468116767005995, 0.07977593995747156, 0.2177489930181764, 0.1564339394099079, 0.12300158923608251, 0.17330408416455612, 0.13512178848031908, 0.19462855474557728, 0.1981534593505785, 0.7451889384537935, 26.48083794862032, 53.31512153148651, 49.749947637319565, 62.03035667538643, 25.074888691306114, 0.3452877391828224, 0.6937608355656266, 1.272101558279246, 7.191212447360158, 17.298963144421577, 8.896165285259485, 25.15502829104662, 15.60072312131524, 3.1054902356117964, 0.7894282427150756, 10.609921775758266, 37.30077065527439, 52.67908126115799, 59.07780110836029, 57.62451209127903, 59.69322368502617, 56.58801510930061, 53.8276532292366, 50.963929295539856, 47.1325720846653, 51.64968989789486, 54.59319055080414, 59.5042522251606, 59.45300817489624, 61.35881491005421, 57.47792735695839, 59.328200072050095, 56.97696603834629, 56.316002905368805, 54.86924193799496, 57.3601146787405, 52.41931959986687, 47.36377067863941, 45.118060782551765, 43.591557294130325, 43.592887222766876, 44.38677482306957, 44.64802600443363, 46.07332952320576, 44.79138471186161, 41.80740863084793, 43.40136229991913, 43.16435381770134, 41.193866953253746, 44.68605816364288, 44.49014827609062, 45.25877483189106, 49.78481076657772, 50.16377963125706, 51.56346492469311, 49.62415158748627, 51.14275150001049, 54.831414967775345, 54.27279554307461, 58.23192089796066, 53.882408291101456, 46.381553784012794, 50.0716307759285, 49.8638541251421, 53.15026357769966, 53.45727190375328, 52.74219207465649, 52.10091568529606, 46.72492615878582, 54.13889452815056, 56.11338257789612, 53.192285522818565, 48.00179444253445, 40.20769827067852, 39.62132893502712, 39.42139886319637, 40.05578242242336, 39.667800441384315, 40.31425975263119, 40.59488609433174, 41.45522452890873, 42.645928636193275, 42.16734051704407, 40.44479414820671, 37.84850746393204, 40.653338357806206, 39.1003692895174, 37.99310490489006, 38.92407774925232, 41.845896765589714, 47.25601986050606, 50.6269595772028, 50.06840854883194, 50.43097749352455, 50.0796065479517, 49.93916228413582, 51.76485411822796, 54.18593220412731, 50.59431552886963, 49.256916493177414, 50.84950603544712, 51.290650963783264, 51.535764411091805, 52.06833243370056, 47.847507521510124, 49.49943847954273, 46.91812299191952, 43.99144023656845, 24.164778627455235, 3.213984863832593, 1.4586872211657465, 8.425810374319553, 4.248510701581836, 6.086820233613253, 10.173111464828253, 12.418182995170355, 5.427357545122504, 2.3804254923015833, 0.47742336289957166, 1.262699319049716, 46.56999707221985, 44.02805507183075, 34.997554644942284, 43.31142872571945, 3.515326981432736, 0.12749896704917774, 0.15063784027006477, 0.12116325975512154, 0.13422034622635692, 0.10547360478085466, 0.11980610172031447, 0.16161522857146338, 0.19987813633633777, 0.1592819014331326, 0.06803018390201032, 0.16227945074206218, 0.12681905587669462, 0.15273400669684634, 0.17318985279416665, 0.11018774908734486, 0.12714834680082276, 0.12228218096424825, 0.1294806200894527, 0.08720782163436525, 0.12939784093759954, 0.08096923920675181, 0.21164533303817734], [0.03627522106398828, 0.09443899689358659, 0.05209439936152194, 0.021263458620524034, 0.06529630481963977, 0.02790847636788385, 0.0412203736777883, 0.07209339048131369, 0.020772433308593463, 0.08849246441968717, 0.03680781963339541, 0.06644446664722636, 0.0437639957817737, 0.029330613142519724, 0.03287021412688773, 0.012842462929256726, 0.04568992095300928, 0.03324691344460007, 0.01227137008754653, 0.05800829218060244, 0.041474310637568124, 0.07973128493176773, 0.02129027427145047, 0.029136201992514543, 0.028034359456796665, 0.07204236040706746, 0.029120474027877208, 0.1247734297066927, 0.039229506874107756, 2.0242660911753774, 36.18874132633209, 31.423202343285084, 32.48234421014786, 36.45391769707203, 2.1775923762470484, 0.08383490887354128, 0.4727529385127127, 0.4005381400929764, 1.5783648868091404, 1.6859075473621488, 7.472727941349149, 10.994348097592592, 4.471313646063209, 0.14660842367447913, 2.0348418736830354, 16.67868632823229, 40.82113355398178, 54.378114491701126, 57.036748230457306, 54.03496630489826, 51.785251423716545, 49.05114993453026, 46.284096613526344, 48.01330402493477, 53.55889365077019, 55.60147404670715, 56.0729755461216, 56.859677731990814, 55.441472232341766, 56.53571091592312, 54.534327909350395, 51.089307367801666, 50.482191145420074, 52.96606846153736, 52.777803763747215, 50.96020549535751, 51.131367310881615, 44.98428896069527, 41.75205320119858, 38.94640155136585, 40.894488617777824, 41.19612783193588, 42.44089163839817, 42.496000081300735, 38.87774683535099, 39.61842969059944, 39.0808991342783, 40.43298438191414, 40.8954955637455, 39.34097237884998, 40.768776163458824, 40.510587617754936, 43.58718752861023, 43.62236604094505, 43.275228068232536, 44.18455347418785, 48.06222639977932, 50.870982483029366, 55.51871068775654, 50.182489827275276, 46.3939905166626, 49.563514441251755, 51.61761201918125, 50.99322572350502, 50.34917168319225, 50.655427649617195, 50.32243251800537, 53.219115883111954, 51.83510094881058, 52.23594143986702, 48.076114654541016, 39.70653936266899, 36.14326536655426, 35.692548751831055, 36.606878489255905, 36.23323693871498, 37.02314235270023, 36.354792416095734, 36.15621507167816, 38.07428374886513, 38.48992444574833, 42.18779481947422, 41.09468087553978, 39.19138960540295, 36.92995235323906, 36.84591606259346, 36.32836863398552, 35.28652533888817, 37.725546061992645, 43.98934654891491, 47.03857272863388, 47.67861798405647, 47.064225152134895, 46.214928925037384, 47.40351274609566, 48.80710043013096, 49.78314645588398, 45.68993769586086, 45.02517856657505, 44.148197025060654, 44.42257270216942, 44.33814883232117, 48.04250925779343, 47.089334204792976, 46.54821664094925, 40.806139558553696, 28.649525977671146, 5.0416801404207945, 0.4350933968089521, 1.2845059926621616, 2.8846508357673883, 0.7750122912693769, 2.060514483600855, 7.659955769777298, 3.9066333090886474, 0.5585823173169047, 0.3296441864222288, 0.05399894325819332, 5.273314760997891, 40.78158147633076, 20.643332786858082, 34.42936733365059, 17.707167640328407, 0.18295515066711232, 0.10953984674415551, 0.07457395229721442, 0.01969879238458816, 0.039647098528803326, 0.04545204035821371, 0.03282912883150857, 0.07565027422970161, 0.09014357972773723, 0.034566173708299175, 0.049696356945787556, 0.02646672091941582, 0.02640027643792564, 0.06809181926655583, 0.012704483760899166, 0.061674067546846345, 0.03250096597184893, 0.04569098964566365, 0.046088183371466585, 0.043362349169910885, 0.014229032276489306, 0.0802914728410542, 0.03135563172691036, 0.05968267381831538, 0.03896340240316931, 0.01795563592168037, 0.04684583080234006, 0.07188660587416962, 0.049924882769118994, 0.059026808230555616, 0.012701267478405498, 0.04153702211624477, 0.05849437293363735, 0.06254620981053449, 0.06859811241156422, 0.07947925158077851, 0.03685625961225014, 0.0026078378232341493, 0.01682589605479734, 0.10329705633921549, 0.06479281699284911, 0.08348500850843266, 0.003187994607287692, 0.01435783478882513, 0.06072077885619365, 0.08296981701278128, 0.04832346909097396, 0.03402916307095438, 0.07468682553735562, 0.08044848902500235, 0.02715293663641205, 0.027202400779060554, 4.276886153966188, 45.37795923650265, 36.322653740644455, 43.0380067974329, 42.67872467637062, 1.5892602084204555, 0.08712573267985135, 0.47744058072566986, 0.9444049454759806, 2.162459925748408, 4.7060517501086, 13.13438756391406, 8.858358263969421, 4.866938441991806, 2.0224581006914377, 2.711581760086119, 18.652560710906982, 43.6192312091589, 57.86354586482048, 58.210938423871994, 56.06082759797573, 53.03078658878803, 50.69553829729557, 48.11661288142204, 48.73213805258274, 54.86791580915451, 56.90798074007034, 57.19372920691967, 57.746960520744324, 56.31612829864025, 58.07446874678135, 56.40411637723446, 52.02992409467697, 53.01360011100769, 56.64703354239464, 54.17892538011074, 52.333660796284676, 52.12025284767151, 46.604218035936356, 43.37914489209652, 41.03153966367245, 42.29104667901993, 43.155260905623436, 42.652513682842255, 43.836446553468704, 41.441020891070366, 41.33246831595898, 40.989639312028885, 41.98145069181919, 42.07153245806694, 40.20301692187786, 42.52321042120457, 43.27859088778496, 44.398652985692024, 45.19851006567478, 44.77022744715214, 46.35169118642807, 50.953913033008575, 52.31526978313923, 54.80182595551014, 52.3249364644289, 47.76486575603485, 49.344889372587204, 51.46717809140682, 51.84802785515785, 51.97803407907486, 55.04542328417301, 51.588991954922676, 54.082345962524414, 53.00932914018631, 53.63345704972744, 49.860096126794815, 41.345140635967255, 38.45591627061367, 37.09585525095463, 39.005837962031364, 38.749568313360214, 39.644800275564194, 37.78231881558895, 37.99701489508152, 40.897456258535385, 40.59034153819084, 42.888743206858635, 42.309076711535454, 40.64153239130974, 38.48946467041969, 38.18978615105152, 38.24258431792259, 37.579896077513695, 40.489354357123375, 46.441639959812164, 48.141037970781326, 48.220632299780846, 47.53300599753857, 48.23287904262543, 47.63240486383438, 48.980059549212456, 50.9439841657877, 46.16368107497692, 45.71075677871704, 47.07962952554226, 47.043447867035866, 45.63755750656128, 48.65803062915802, 47.85453714430332, 49.059190303087234, 44.04738463461399, 31.411318480968475, 6.219284450635314, 1.060662497766316, 4.2599571123719215, 4.014506433159113, 5.417929301038384, 5.779811907559633, 6.477055968716741, 3.2600977644324303, 0.2040668178233318, 0.36558856547344476, 0.04795028755324893, 5.074211619794369, 50.666154474020004, 23.51507429033518, 36.235881596803665, 22.037550173699856, 0.3188052086625248, 0.10920157583313994, 0.04244952608132735, 0.03502530336845666, 0.02027429080044385, 0.007093144604368717, 0.03998965163191315, 0.0921268506499473, 0.09250533854356036, 0.04172924949671142, 0.010765716651803814, 0.07838438337785192, 0.025689115282148123, 0.03351671381096821, 0.02602182750706561, 0.02697095274925232, 0.03841252844722476, 0.0319250556640327, 0.04493868567806203, 0.013169132216717117, 0.02309356139448937, 0.015138147409743397, 0.01737675516778836, 0.1605426025344059, 0.13342296791961417, 0.16830080654472113, 0.1405983039876446, 0.23775097128236666, 0.16234799550147727, 0.1480097320745699, 0.15950929548125714, 0.1774551981361583, 0.15061282989336178, 0.36307473317719996, 0.16444859997136518, 0.18969477183418348, 0.12397550221066922, 0.10831448671524413, 0.17407179140718654, 0.22520848258864135, 0.13089239277178422, 0.2334894851082936, 0.11510765383718535, 0.16005547164240852, 0.1500570948701352, 0.12272489431779832, 0.12134126387536526, 0.14892618055455387, 0.1381640596082434, 0.18277434865012765, 0.25789970182813704, 0.19043806241825223, 6.095241056755185, 55.91994255781174, 42.59821079671383, 43.565308302640915, 47.61785164475441, 3.4268563287332654, 0.2761387825012207, 1.7676603980362415, 2.30421488173306, 9.515941478312016, 6.5729685220867395, 13.465703185647726, 18.684520795941353, 11.11503817141056, 1.9889392680488527, 2.8106659557670355, 19.304123148322105, 44.65527981519699, 59.60977256298065, 61.55630171298981, 56.893043741583824, 55.58484233915806, 54.76650685071945, 50.66449016332626, 51.85740575194359, 57.35540673136711, 60.50100713968277, 60.10094940662384, 59.9397848546505, 57.47122831642628, 61.64071798324585, 58.63254100084305, 54.17361706495285, 54.99468840658665, 59.53913055360317, 56.0225560516119, 54.22377437353134, 54.83796961605549, 48.47818247973919, 45.86471691727638, 43.79374444484711, 45.114458575844765, 45.730185136199, 46.204939261078835, 47.57365621626377, 43.509166315197945, 43.67109842598438, 43.509656488895416, 44.1224230080843, 44.104670360684395, 42.670615911483765, 44.02911141514778, 44.446348026394844, 48.07478092610836, 47.69783355295658, 47.851770892739296, 49.86492566764355, 53.46668399870396, 55.8571433275938, 58.512733429670334, 54.3998721241951, 49.86856207251549, 49.45203982293606, 53.77768971025944, 54.6669065952301, 55.234132558107376, 54.91621881723404, 54.159858003258705, 56.2930179387331, 55.990804955363274, 55.84215693175793, 52.12493799626827, 42.69401125609875, 41.022636741399765, 39.527519568800926, 38.878746181726456, 40.25163151323795, 41.34394370019436, 40.27058109641075, 38.881523832678795, 42.11234986782074, 42.923283353447914, 46.722828671336174, 45.97213715314865, 42.67003074288368, 41.49293750524521, 40.24250440299511, 40.366670340299606, 38.48208926618099, 42.57543481886387, 47.354586571455, 51.22736535966396, 49.531273171305656, 49.08422715961933, 49.11541968584061, 49.893959909677505, 49.78552892804146, 52.575077041983604, 48.25706474483013, 48.77482496201992, 49.25609193742275, 49.021880105137825, 48.36710684001446, 50.238666012883186, 49.4901517778635, 48.67822654545307, 43.54325048625469, 30.755711160600185, 6.0846595745533705, 0.8512500941287726, 5.407869815826416, 8.707757145166397, 5.572422835975885, 8.513418473303318, 16.503048352897167, 11.772484593093395, 1.489510692190379, 1.391227066051215, 0.22774698387365788, 8.46984526142478, 54.67781201004982, 27.4044543877244, 45.144222378730774, 26.39130525290966, 0.42536772962193936, 0.26594357332214713, 0.26354661444202065, 0.1427000662079081, 0.1196117109793704, 0.12430537200998515, 0.091422856785357, 0.19649502646643668, 0.18955707375425845, 0.15423105214722455, 0.20110869139898568, 0.13029803638346493, 0.1328846436808817, 0.16186926572117954, 0.1731210557045415, 0.20502855215454474, 0.16847215360030532, 0.12656880368012935, 0.17530617595184594, 0.1324316961108707, 0.1387739268830046, 0.2968004113063216, 0.10862397713935934], [0.07937185539049096, 0.08395766752073541, 0.060897595540154725, 0.052662342714029364, 0.01850294014730025, 0.030169674173521344, 0.03347279351146426, 0.0360025968257105, 0.01785918455425417, 0.009809444527490996, 0.042043660359922796, 0.09043223806656897, 0.036952508744434454, 0.038318724691635, 0.05257355216599535, 0.007265612302944646, 0.11255889607127756, 0.0771826904383488, 0.06445159233408049, 0.03840637975372374, 0.041874966482282616, 0.021466513935592957, 0.042730172935989685, 0.030314005198306404, 0.057239801972173154, 0.0254085760388989, 0.017472915242251474, 0.0669499731156975, 0.08292558501125313, 0.39765730092767626, 19.584044627845287, 40.17996735870838, 31.695045456290245, 48.39276306331158, 14.753949958831072, 0.2987465600017458, 0.2908876317087561, 0.5634256917983294, 0.6753964209929109, 4.024816229939461, 10.659198481589556, 5.2412796299904585, 2.1409773034974933, 1.8937283707782626, 0.26087877165991813, 3.683318579569459, 23.702105954289436, 51.38378016650677, 60.11161923408508, 55.13949103653431, 53.186110854148865, 49.9778176099062, 50.66202789545059, 54.267209842801094, 55.89333638548851, 56.1510119587183, 59.2162998765707, 55.982574597001076, 57.054782062768936, 54.38461594283581, 49.914478808641434, 51.91931203007698, 54.41965006291866, 55.610540360212326, 53.62225525081158, 52.38871984183788, 53.8662401586771, 50.02507567405701, 43.69781859219074, 38.39409738779068, 41.22969903051853, 40.866921097040176, 43.00278648734093, 42.903311625123024, 42.855916768312454, 39.79610815644264, 38.96044559776783, 38.61127093434334, 41.253694742918015, 39.940432012081146, 39.01652678847313, 38.66305835545063, 40.749104619026184, 40.36024488508701, 44.3010476231575, 46.35601915419102, 50.505533292889595, 51.21197998523712, 56.89256116747856, 50.149834379553795, 45.09713530540466, 53.198631182312965, 48.16110469400883, 52.4383869767189, 51.62714570760727, 50.71932502090931, 48.244574815034866, 52.37387403845787, 48.98057632148266, 47.50850111246109, 43.602952882647514, 37.95842036604881, 36.37800917029381, 37.58979454636574, 37.29169674217701, 36.90543606877327, 36.18500612676144, 37.03523330390453, 37.13569991290569, 41.26210369169712, 50.0750657916069, 50.75057074427605, 50.459886342287064, 47.53750875592232, 42.19638615846634, 38.493598848581314, 36.75798498094082, 35.956596583127975, 36.47984750568867, 42.43121735751629, 46.270162761211395, 48.9289902895689, 48.70370417833328, 47.169692292809486, 48.87613132596016, 50.31881131231785, 46.93704217672348, 43.81964385509491, 45.28543420135975, 45.42846232652664, 44.884779900312424, 46.95272773504257, 47.45153456926346, 47.36630134284496, 44.76900011301041, 27.655877396464348, 7.71645113825798, 0.2178357055527158, 1.5323493559844792, 2.785504893399775, 3.1696115573868155, 4.749865299090743, 4.411904308944941, 7.676753718405962, 2.6914746640250087, 0.16095968952868134, 0.4210241767577827, 0.06798940288717858, 16.786205358803272, 33.389887511730194, 19.765030816197395, 32.578847631812096, 4.391810512170196, 0.0836273301683832, 0.015695148722443264, 0.024793298507574946, 0.07912331013358198, 0.0257351544132689, 0.006354679371725069, 0.03220127931854222, 0.011706955647241557, 0.03040083833184326, 0.11581693179323338, 0.07736410843790509, 0.013909505232732045, 0.0396126665873453, 0.03142175708489958, 0.026725010575319175, 0.057566024115658365, 0.018637267021404114, 0.08059370506089181, 0.02555374383518938, 0.034457360015949234, 0.045384122713585384, 0.03797635712544434, 0.027649199655570555, 0.024677417713974137, 0.018441495885781478, 0.06657203441136517, 0.05976327105599921, 0.0452875804330688, 0.0383985538064735, 0.03935666274628602, 0.034535704835434444, 0.06346006819512695, 0.03245695661462378, 0.05114712206705008, 0.06009406111843418, 0.06410851230612025, 0.014970615920901764, 0.054824730977998115, 0.028336300383671187, 0.08390252594836056, 0.044720505393343046, 0.04074991884408519, 0.11045050647226162, 0.02811229795042891, 0.006316190665529575, 0.0931951573875267, 0.015165009444899624, 0.02689950619242154, 0.015555424579360988, 0.019712292050826363, 0.024757057581155095, 0.031114511657506227, 0.7609935372602195, 27.852273657917976, 43.19632910192013, 31.406411044299603, 57.10025802254677, 13.681729193776846, 0.16378302709199488, 0.2021043121931143, 0.4882538801757619, 0.5239274050109088, 2.5723432190716267, 11.113295014947653, 5.471547748893499, 3.9184088772162795, 4.318296331912279, 0.7450197881553322, 4.470762675628066, 26.24735377728939, 51.26439817249775, 61.24429665505886, 56.85850739479065, 55.19752912223339, 51.65250934660435, 52.56981052458286, 55.57882346212864, 55.52515894174576, 58.920303359627724, 58.2623078674078, 58.15948538482189, 58.35019335150719, 56.26877523958683, 51.654865220189095, 54.52840782701969, 55.25590538978577, 55.835047513246536, 54.12945583462715, 55.60388691723347, 56.22958414256573, 51.34502984583378, 47.11469404399395, 39.49081353843212, 44.230409413576126, 43.07313971221447, 44.31282699108124, 44.8373394459486, 44.24233317375183, 41.57569706439972, 41.170068830251694, 41.021496802568436, 43.54561775922775, 40.660120993852615, 40.14032408595085, 42.189257740974426, 42.10232600569725, 42.26277619600296, 45.022670701146126, 46.49884968996048, 51.20859816670418, 51.57090872526169, 57.52284474670887, 51.682957112789154, 46.1808979511261, 51.220616921782494, 49.67524364590645, 53.88284146785736, 53.15317802131176, 51.74965113401413, 51.174046620726585, 53.675137013196945, 51.68323449790478, 48.66352133452892, 45.31724609434605, 37.806736305356026, 38.77118535339832, 39.50993791222572, 39.831784442067146, 37.28334479033947, 38.53422626852989, 38.47030229866505, 39.65873032808304, 42.35086686909199, 50.076654106378555, 51.654770225286484, 50.62120668590069, 48.83472494781017, 43.44473697245121, 39.29205000400543, 38.47370311617851, 37.489821910858154, 39.731298834085464, 44.54898811876774, 48.21279712021351, 51.86731182038784, 48.88947620987892, 46.666515693068504, 48.654185235500336, 49.46999005973339, 49.66335028409958, 46.04517303407192, 48.091051653027534, 46.82540036737919, 46.67361371219158, 48.02909217774868, 49.21984188258648, 47.608922123909, 46.19510538876057, 30.875898711383343, 11.227846518158913, 1.3614284712821245, 2.7975504845380783, 4.273681025952101, 4.482776205986738, 6.461513377726078, 5.897702006623149, 4.6584683284163475, 1.65856504580006, 0.15076906682224944, 0.4218077956466004, 0.04828407218155917, 19.48078326880932, 42.22682632505894, 20.19357182085514, 38.78046065568924, 7.457879763096571, 0.04335955127316993, 0.07650009269127622, 0.017558379113324918, 0.044868541590403765, 0.003133464379061479, 0.030463167604466435, 0.02831548499671044, 0.03501852013869211, 0.02568105555837974, 0.09345400365418755, 0.0291764913345105, 0.0557474134984659, 0.04207956917525735, 0.01949300967680756, 0.027741001467802562, 0.020866639679297805, 0.03682761271193158, 0.036875692749163136, 0.020240717894921545, 0.032785253060865216, 0.00599857882662036, 0.0237488369748462, 0.0213183088999358, 0.22264736064244062, 0.15688964776927605, 0.15718065871624276, 0.0988626126490999, 0.11827623107819818, 0.18596096750115976, 0.18373657279880717, 0.1940302798175253, 0.12714747106656432, 0.13511392171494663, 0.1707706888555549, 0.10522908938582987, 0.1467800824320875, 0.15016145567642525, 0.1548353087855503, 0.1386196046951227, 0.22932288993615657, 0.10985158587573096, 0.1742378098424524, 0.1982372923521325, 0.09310061519499868, 0.07477858467609622, 0.16306539997458458, 0.13172748702345416, 0.12272133943042718, 0.13740792986936867, 0.08673636490129866, 0.11752275080652907, 0.10358063838793896, 0.8241628913674504, 33.649554178118706, 55.88024988770485, 38.32402154803276, 63.02155628800392, 21.535885892808437, 0.37779045291244984, 1.4513531397096813, 1.9334571389481425, 4.390808790922165, 9.527988731861115, 19.793757274746895, 12.05630561336875, 8.104201331734657, 6.1956083960831165, 1.0304992413148284, 4.553782045841217, 26.2062019854784, 52.761381044983864, 62.9572219401598, 60.62984302639961, 58.542592227458954, 54.71193037927151, 56.10988676548004, 58.753602504730225, 59.69792403280735, 60.62418133020401, 62.078853473067284, 59.511794820427895, 60.548895969986916, 60.915914475917816, 53.8524316996336, 56.743210181593895, 60.55190160870552, 59.340462014079094, 56.803999319672585, 57.587213292717934, 58.73223625123501, 54.44501370191574, 48.71045641601086, 41.77740544080734, 45.98998099565506, 44.5476695895195, 47.23613552749157, 48.2615827023983, 46.53626628220081, 43.935636430978775, 41.8439968675375, 42.79320493340492, 45.408912375569344, 43.332346603274345, 43.290575444698334, 43.87649640440941, 44.29141514003277, 43.17214719951153, 46.80880665779114, 49.90200787782669, 53.927831053733826, 54.56944562494755, 60.79640708863735, 54.46258395910263, 46.579477563500404, 52.68066577613354, 50.1518140733242, 53.58043849468231, 56.66059121489525, 54.01910975575447, 52.93215528130531, 55.70291720330715, 52.379083558917046, 51.07181690633297, 48.5798954218626, 39.842955842614174, 40.1311019808054, 40.584436655044556, 40.80878421664238, 39.828448221087456, 39.90166649222374, 40.43614201247692, 42.08808816969395, 45.43542355298996, 53.2495978474617, 54.95409898459911, 52.93541170656681, 52.32648678123951, 46.59444876015186, 42.51315236091614, 40.41939631104469, 38.60308237373829, 39.841071143746376, 47.09522768855095, 49.04251679778099, 52.69437164068222, 51.01539373397827, 47.5476998090744, 49.379456117749214, 52.125154584646225, 52.46590130031109, 48.50233398377895, 49.94368024170399, 49.622570872306824, 49.21714402735233, 48.95595744252205, 49.77447532117367, 49.208776876330376, 47.743963077664375, 29.39922194927931, 8.702028952538967, 0.6790557433851063, 3.2643694477155805, 7.742543863132596, 8.84543040767312, 9.824268333613873, 8.479588888585567, 15.781086143106222, 7.801911402493715, 0.40259780769702047, 0.6238270725589246, 0.14426893671043217, 23.64330790936947, 45.879486724734306, 26.07987206429243, 45.96864894032478, 8.887261413037777, 0.2283764141611755, 0.13477290485752746, 0.25584273564163595, 0.19046345871174708, 0.12223151454236358, 0.18853550747735426, 0.1372887854813598, 0.15195359388599172, 0.15894242824288085, 0.22873497538967058, 0.16489235975313932, 0.10623322261380963, 0.14485705905826762, 0.14805783808697015, 0.105582373944344, 0.19894114520866424, 0.12822768185287714, 0.12445504093193449, 0.17998451163293794, 0.07798283695592545, 0.07870784102124162, 0.08803378746961243, 0.09538993297610432], [0.05581983597949147, 0.03343922988278791, 0.08122007027850486, 0.035753502379520796, 0.030679919254907873, 0.05958448025921825, 0.04998283337044995, 0.09104777534957975, 0.004489200273383176, 0.02532093581976369, 0.005037135324528208, 0.025736662828421686, 0.04925048575387336, 0.03053552700293949, 0.05502031657670159, 0.02395848998276051, 0.016931739301071502, 0.008508848350174958, 0.04642134459572844, 0.030782586109125987, 0.0382400459056953, 0.05156217186595313, 0.02324327298993012, 0.040140348428394645, 0.05040094081778079, 0.02596534635813441, 0.049191295765922405, 0.04518536072282586, 0.04788607322552707, 0.13352419686270878, 2.4877205723896623, 37.0716505497694, 30.719609297811985, 35.027303248643875, 38.234612345695496, 2.3751836735755205, 0.07613470370415598, 0.1043404862866737, 0.5613040993921459, 2.7492636255919933, 10.071040391921997, 8.219944071024656, 4.369498109444976, 3.8283831579610705, 0.2534084318904206, 0.03863924343022518, 6.928256582468748, 34.89615708589554, 60.39223797619343, 55.46702206134796, 56.64412669837475, 54.87491883337498, 53.83103504776955, 55.60191862285137, 59.708039090037346, 58.109236881136894, 56.52352876961231, 55.36647565662861, 56.53879635035992, 50.47924630343914, 49.31365504860878, 52.977228462696075, 55.83749458193779, 53.391873612999916, 57.12770774960518, 53.27165946364403, 54.153880923986435, 52.762034609913826, 46.408007964491844, 38.8058090955019, 42.156807482242584, 41.6573166847229, 44.080549255013466, 46.72340244054794, 43.80776949226856, 41.58553093671799, 40.33290155231953, 39.45497006177902, 40.805068016052246, 41.99902854859829, 42.576589956879616, 39.85796123743057, 41.11549235880375, 45.6627007573843, 46.50594010949135, 51.11845940351486, 53.06258328258991, 55.93678705394268, 51.969446539878845, 47.3745658993721, 43.767305463552475, 49.206117019057274, 54.265898913145065, 51.84714250266552, 49.91612412035465, 49.0045378357172, 48.17546032369137, 50.4870168864727, 49.769516587257385, 45.41784569621086, 40.01807704567909, 37.0397512614727, 38.14786680042744, 36.3005693256855, 36.327122300863266, 38.66487465798855, 37.762153297662735, 39.29285556077957, 38.96253928542137, 48.90242971479893, 51.89875893294811, 50.87652638554573, 51.4753932505846, 47.98346422612667, 43.77349533140659, 41.430275067687035, 37.54925072193146, 36.90022274851799, 37.69228644669056, 41.45842395722866, 45.67908547818661, 49.1536570340395, 48.731302097439766, 46.47152915596962, 45.60118965804577, 48.82452629506588, 46.885406747460365, 47.36537419259548, 46.313526034355164, 46.69072039425373, 48.45544449985027, 49.77797493338585, 47.263794243335724, 44.701485335826874, 28.342749439179897, 9.91835318505764, 1.5240312460809946, 1.5898007294163108, 1.7686646129004657, 4.177105408161879, 0.7939568278379738, 7.888576202094555, 14.227368514984846, 1.4987280475907028, 2.1241140458732843, 0.18567524064565077, 0.19857614213833585, 1.4281830517575145, 32.861742451786995, 29.930484741926193, 29.63693529367447, 28.853468634188175, 1.2689939187839627, 0.03881914002704434, 0.034376525291008875, 0.08299687571707182, 0.05693949562555645, 0.03436731894908007, 0.04717409385193605, 0.026745653412945103, 0.041103084658971056, 0.01785547567124013, 0.02960482372145634, 0.013732299848925322, 0.03353571650222875, 0.0482897310575936, 0.07313802270800807, 0.030160222922859248, 0.03893457738740835, 0.04395131014462095, 0.061163833597674966, 0.11146316697704606, 0.0378339909366332, 0.010174594171985518, 0.0172531170755974, 0.01137524624937214, 0.004307140316086588, 0.03016533260961296, 0.030270938368630596, 0.07379817790933885, 0.0735667985281907, 0.008832947023620363, 0.026311077708669472, 0.015938845899654552, 0.0319360542926006, 0.01898276459542103, 0.0468970798101509, 0.04234582949720789, 0.05385796488553751, 0.0742535523022525, 0.04348875918367412, 0.04593323035805952, 0.02208302899816772, 0.011473790473246481, 0.038126616054796614, 0.05368766425817739, 0.07269639289006591, 0.08445656145340763, 0.024415172410954256, 0.033288648119196296, 0.02072065180982463, 0.05231557421211619, 0.05734902384574525, 0.09511832176940516, 0.051093746806145646, 0.0992346067505423, 5.270625930279493, 47.75141827762127, 32.632219567894936, 43.41053120791912, 43.73030684888363, 1.8219587719067931, 0.05567470157984644, 0.059880749322474, 0.3754407539963722, 0.3507881221594289, 9.488961976021528, 5.124597391113639, 3.5708959121257067, 7.570181787014008, 1.3865643600001931, 0.11345027480274439, 8.158510867506266, 37.10692785680294, 61.83842897415161, 57.96846583485603, 57.147272899746895, 55.61162330210209, 56.140376329422, 57.02161744236946, 60.200648456811905, 60.33085606992245, 58.009192049503326, 55.17608307301998, 57.95825578272343, 54.272423163056374, 50.960661470890045, 54.50091250240803, 56.56734421849251, 56.54556378722191, 58.94785948097706, 56.07039548456669, 55.690108090639114, 53.538697734475136, 47.65885144472122, 41.52510277926922, 42.87958189845085, 44.25824671983719, 45.63840486109257, 48.34523141384125, 46.15950129926205, 42.9405914247036, 42.03864522278309, 41.94927401840687, 42.06504240632057, 43.1883305311203, 44.10091236233711, 41.619170531630516, 43.72005119919777, 46.79888159036636, 49.87475574016571, 51.63705177605152, 55.29935225844383, 57.59595662355423, 54.31040212512016, 50.55629476904869, 46.55535265803337, 50.46090088784695, 53.550127521157265, 54.32567350566387, 51.96022443473339, 52.73839607834816, 50.04785165190697, 52.29551464319229, 51.290145590901375, 48.81919898092747, 41.95658482611179, 38.37613195180893, 38.929082080721855, 37.88204446434975, 37.94227883219719, 39.83407571911812, 38.008167296648026, 40.66550150513649, 39.20402392745018, 50.52384831011295, 53.43283921480179, 53.732624128460884, 53.159527480602264, 48.93821619451046, 45.831806883215904, 42.79945559799671, 38.901358768343925, 39.196747317910194, 39.657913371920586, 43.06666485965252, 47.12410233914852, 50.38250349462032, 50.528788045048714, 47.67782002687454, 46.26192480325699, 49.76465664803982, 49.534917175769806, 49.31856818497181, 48.97551879286766, 48.254701271653175, 50.36335252225399, 51.26396119594574, 47.28023216128349, 46.193509474396706, 31.132417246699333, 12.419632617384195, 0.9502688026987016, 2.9772136313840747, 4.772037584334612, 4.713819958269596, 4.486281517893076, 7.739563873037696, 13.909477572888136, 0.8693286927882582, 1.1846936610527337, 0.1922306013875641, 0.2558698388747871, 1.0356753948144615, 37.124125733971596, 32.342488914728165, 29.751267358660698, 33.81403595209122, 2.241717497818172, 0.0669218234543223, 0.08112247785902582, 0.042663832355174236, 0.047208125033648685, 0.06061010979465209, 0.03962984730605967, 0.03673269944556523, 0.025785941434151027, 0.018596079680719413, 0.05614272587990854, 0.009334951482742326, 0.02533380094973836, 0.034946398227475584, 0.03415726147068199, 0.054441556421807036, 0.04546600015601143, 0.03930320584913716, 0.04069524853548501, 0.03693274535180535, 0.019311639916850254, 0.03412374237086624, 0.07131263628252782, 0.032693790781195275, 0.1596582742058672, 0.17513416096335277, 0.18187269859481603, 0.12749092216836289, 0.13726303295698017, 0.12495687376940623, 0.10957218953990377, 0.28573935327585787, 0.11290742346318439, 0.08505263962433673, 0.11733397812349722, 0.1127856964012608, 0.15115513204364106, 0.18184120184741914, 0.16751234885305166, 0.09618691794457845, 0.15311101771658286, 0.2025114989373833, 0.09350464781164192, 0.15250714699504897, 0.1358240531408228, 0.1402446409338154, 0.19913869007723406, 0.10715109601733275, 0.1190178221440874, 0.11383605058654211, 0.19267057621618733, 0.25154201954137534, 0.13579775142716244, 0.27432437986135483, 6.7214607540518045, 57.569943219423294, 41.22014254331589, 45.853838101029396, 50.884821340441704, 3.4758048271760345, 0.15815368853509426, 0.9114716376643628, 1.8530166428536177, 7.7575654070824385, 19.69729945063591, 17.209052368998528, 9.731752797961235, 8.024503458291292, 2.009336929768324, 0.2670141955604777, 8.871162626892328, 37.86874517798424, 65.30345544219017, 59.99706298112869, 61.16605505347252, 59.18022841215134, 57.07472339272499, 59.59511294960976, 63.15595507621765, 61.63963504135609, 59.72014904022217, 59.23483908176422, 60.854403376579285, 56.66985511779785, 53.45989756286144, 56.97476215660572, 58.556073904037476, 57.487305253744125, 60.75532369315624, 57.43736073374748, 58.39383400976658, 56.45681954920292, 51.9484830647707, 42.86568224430084, 45.15456162393093, 46.288264989852905, 49.84907291829586, 53.667024448513985, 49.05086874961853, 46.43282823264599, 43.85423339903355, 43.30968841910362, 44.18307915329933, 44.636273235082626, 45.48078931868076, 44.427501037716866, 45.50965256989002, 50.11174902319908, 51.20045520365238, 56.48058347404003, 57.19749480485916, 62.66560658812523, 58.033491745591164, 52.75163076817989, 46.59492373466492, 50.12520030140877, 56.74689218401909, 56.49731017649174, 54.183732122182846, 53.74440349638462, 51.50161564350128, 54.28008735179901, 53.38378004729748, 50.023384764790535, 43.355696350336075, 41.130744740366936, 41.270090863108635, 40.19536793231964, 38.98126468062401, 40.809620171785355, 39.31455619633198, 42.928652465343475, 41.93819001317024, 54.9035768955946, 56.26630537211895, 54.66637842357159, 55.52973009645939, 50.13346865773201, 47.214898467063904, 44.52882640063763, 40.96676453948021, 41.103268414735794, 42.21146374940872, 44.38950687646866, 49.28701467812061, 51.37489624321461, 52.432626485824585, 47.60896012187004, 47.45931655168533, 52.21518695354462, 51.011700332164764, 51.04203790426254, 52.578508257865906, 50.53695000708103, 52.4151436239481, 51.93484179675579, 48.34743529558182, 45.68616449832916, 30.8032314106822, 11.218740306794643, 2.502781064249575, 3.0054499162361026, 5.590320825576782, 10.585215501487255, 6.2427405919879675, 16.428116373717785, 29.50998790562153, 2.3358370224013925, 3.249754481948912, 0.7285289105493575, 0.4018041252857074, 2.12269339710474, 45.43990731239319, 39.236922562122345, 38.2636845856905, 41.18165820837021, 2.26664487272501, 0.14049539779080078, 0.31722015934064984, 0.12423457854310982, 0.1664196848287247, 0.1334796383162029, 0.191879699123092, 0.10759574637631886, 0.13269462418975309, 0.09547161374939606, 0.09045384198543616, 0.15490112244151533, 0.08128016939735971, 0.11523188193677925, 0.14781238016439602, 0.08609428841737099, 0.19966269086580724, 0.19244573515607044, 0.1532022573519498, 0.17656384909059852, 0.17796922445995733, 0.13159453868865967, 0.15342752885771915, 0.09220703970640898], [0.10087849354022183, 0.019607350513979327, 0.029335787767195143, 0.049504192647873424, 0.057677876902744174, 0.027887150754395407, 0.029030709411017597, 0.03115080267889425, 0.04360929138783831, 0.03244206542149186, 0.10665212786989287, 0.06273339429753833, 0.029105039211572148, 0.009568792938807746, 0.07611071749124676, 0.02538043565436965, 0.028729195219057146, 0.12340435278019868, 0.005038807012169855, 0.019351435730641242, 0.05292039117193781, 0.07664589502383024, 0.06534337924676947, 0.0937829383474309, 0.019372976566955913, 0.0306358486704994, 0.008794726418273058, 0.037197369238128886, 0.03302911907667294, 0.10228047729469836, 0.41205095825716853, 20.91368068009615, 46.33961543440819, 24.18289415538311, 45.26837691664696, 18.49044620990753, 0.06046123497071676, 0.06218281720066443, 0.1987582354922779, 0.23226133460411802, 6.209290036931634, 4.511395795270801, 1.6105344356037676, 4.977716272696853, 1.52996830875054, 0.12511159671703354, 0.5540106876287609, 14.690425917506218, 44.9753974378109, 57.15281680226326, 55.66258616745472, 54.17587414383888, 56.49072892963886, 55.85504963994026, 58.37777227163315, 58.24834741652012, 54.62302275002003, 56.45890563726425, 50.316485837101936, 48.70201326906681, 52.92053550481796, 55.37724427878857, 55.21690808236599, 55.94261974096298, 53.775493428111076, 56.18139132857323, 54.53865207731724, 52.71142512559891, 46.64678335189819, 40.61579257249832, 42.299113646149635, 44.09373074769974, 45.06427846848965, 47.229915261268616, 48.74465838074684, 44.310645908117294, 41.620052084326744, 40.735805332660675, 40.09339660406113, 40.49865625798702, 40.65880246460438, 43.44506375491619, 42.775577679276466, 46.66217252612114, 51.09204702079296, 53.420634269714355, 53.868877217173576, 53.45827504992485, 52.995691671967506, 52.82271735370159, 35.959005653858185, 53.1611043959856, 56.40443556010723, 51.915079057216644, 50.41023440659046, 46.03505797684193, 47.49666094779968, 47.85881571471691, 45.91746188700199, 42.52568028867245, 38.209127113223076, 38.064924851059914, 38.465936332941055, 37.54785619676113, 37.713162526488304, 36.45877003669739, 38.06292235851288, 38.386820778250694, 43.73426243662834, 50.32556354999542, 50.31078614294529, 51.74648970365524, 51.72731593251228, 48.65103900432587, 44.035263285040855, 40.30588120222092, 36.98548637330532, 36.45616337656975, 37.241923213005066, 42.21100017428398, 46.60830661654472, 49.29867245256901, 50.03043718636036, 49.15278308093548, 46.632317528128624, 49.6519622951746, 48.82617920637131, 47.133358642458916, 46.234619468450546, 50.67070282995701, 46.64153203368187, 51.8009065836668, 45.69260515272617, 35.974166840314865, 12.418168745934963, 1.5894591039977968, 0.5421819223556668, 3.1018243823200464, 5.862798979505897, 2.9440908087417483, 3.158474829979241, 9.593423120677471, 18.068079873919487, 1.3529440015554428, 0.5262005142867565, 0.0775022740708664, 0.09593705166480504, 8.138378597795963, 42.26791352033615, 19.199529960751534, 34.198905900120735, 13.78768365830183, 0.09356649839901365, 0.08437393815256655, 0.04479638999328017, 0.05101718685182277, 0.052256343406043015, 0.023378488585876767, 0.06790002604248002, 0.07237402620376088, 0.016917291541176382, 0.054681203328073025, 0.02324690023669973, 0.02139928277756553, 0.027415875847509596, 0.035228692649980076, 0.018283169811184052, 0.021393282513599843, 0.048495291121071205, 0.022601749406021554, 0.009642874119890621, 0.03519203426549211, 0.013785342071059858, 0.013922107827966101, 0.10397054051281884, 0.041627018654253334, 0.029096510079398286, 0.00771924496802967, 0.07825802531442605, 0.029650443539139815, 0.07539909434854053, 0.0337421077711042, 0.023605806563864462, 0.04486263409489766, 0.03184321532899048, 0.08486705817631446, 0.05478987230162602, 0.03314950656204019, 0.013743692743446445, 0.030221683882700745, 0.07784673449350521, 0.03952677041525021, 0.041778030863497406, 0.023905318812467158, 0.022664054558845237, 0.04504526550590526, 0.016525534047104884, 0.037423223329824395, 0.02671791193279205, 0.05477550432260614, 0.027460890814836603, 0.014154464060993632, 0.0349681283114478, 0.01759857939759968, 0.04554988139716443, 0.04117636432056315, 0.6054817757103592, 28.77392180263996, 46.784905940294266, 29.107851684093475, 58.6188655346632, 18.126767724752426, 0.11957983573665842, 0.17058381607057527, 0.1665122454869561, 0.3696617390960455, 1.0402972530573606, 4.034809693694115, 3.964787288568914, 5.216005761176348, 3.0248590372502804, 0.6775725167244673, 0.7925351103767753, 19.183990694582462, 48.15572038292885, 58.42683523893356, 57.24080108106136, 56.410560831427574, 58.01550351083279, 56.84415556490421, 60.990664064884186, 59.25417624413967, 55.2839744836092, 57.802023366093636, 53.872836604714394, 51.58577732741833, 54.65833805501461, 57.21260279417038, 56.146471202373505, 56.652440652251244, 56.07362151145935, 56.33933745324612, 56.97835676372051, 53.73270012438297, 48.448525071144104, 40.35986490547657, 44.365115985274315, 46.45135223865509, 47.57321543991566, 49.04841408133507, 49.149203673005104, 44.83887076377869, 42.61471711099148, 41.4560566842556, 41.9689379632473, 42.55851432681084, 42.688873931765556, 44.673249050974846, 44.42714385688305, 48.48133631050587, 52.54199221730232, 54.422207325696945, 54.15735773742199, 56.53185032308102, 54.121860042214394, 52.97217093408108, 38.37798245251179, 52.758208215236664, 55.19379772245884, 52.990432754158974, 52.508284226059914, 49.02581289410591, 49.319594129920006, 49.868945851922035, 49.29963760077953, 45.83029456436634, 39.043072164058685, 40.37201285362244, 41.12698674201965, 37.55928598344326, 39.7130636125803, 39.07692074775696, 39.690508022904396, 39.755051359534264, 43.993389531970024, 52.5000386685133, 52.05724082887173, 54.440009370446205, 54.801290184259415, 50.37035554647446, 46.80777311325073, 42.22890101373196, 38.24856899678707, 37.24908962845802, 39.11877550184727, 43.773909509181976, 47.92463578283787, 51.295985877513885, 51.17050901055336, 49.42948043346405, 47.81269758939743, 50.27694895863533, 50.39806745946407, 48.54187086224556, 50.1681911945343, 51.689321771264076, 48.123878091573715, 51.248522624373436, 46.87138929963112, 37.054828852415085, 14.63416613638401, 2.819820139557123, 0.6564941571559757, 5.25016070343554, 5.973302274942398, 4.8257063794881105, 7.89945786818862, 10.600911509245634, 25.038040168583393, 2.546868911013007, 0.7356558437459171, 0.18477175006410107, 0.11427635938161984, 8.00285317003727, 48.84120739996433, 23.398044370114803, 34.88690838217735, 19.722735285758972, 0.1599889009958133, 0.10227106686215848, 0.030251176831370685, 0.06517966889077798, 0.04660782033170108, 0.048606216223561205, 0.0318016699020518, 0.012987611244170694, 0.04222426941851154, 0.04505343284108676, 0.013529622101486893, 0.022489653565571643, 0.031223388432408683, 0.016212204864132218, 0.03934924126951955, 0.045269813417689875, 0.05611029402643908, 0.04352431176812388, 0.009238958391506458, 0.04775639405124821, 0.05554536008276045, 0.04894608646281995, 0.048941937857307494, 0.06117866170825437, 0.18821742298314348, 0.10120457096491009, 0.19895278208423406, 0.12801242934074253, 0.11111060230177827, 0.13339982775505632, 0.08362583845155314, 0.15947551291901618, 0.12344131173449568, 0.17832357028964907, 0.3038540796842426, 0.18475525954272598, 0.08706325126695447, 0.15669536835048348, 0.27005450741853565, 0.0769332842901349, 0.20176371093839407, 0.34770996076986194, 0.20391052152263, 0.11233522018301301, 0.2069847792154178, 0.17529811622807756, 0.16475702170282602, 0.210753048886545, 0.060982285722275265, 0.13634903356432915, 0.0748731565545313, 0.11997953421087004, 0.18227805965580046, 0.15308188099879771, 0.6957651092670858, 32.46490314602852, 58.33285868167877, 31.677072420716286, 58.238627538084984, 25.380673483014107, 0.36137690709438175, 0.3395033214474097, 0.3276241198182106, 1.2410791916772723, 10.250727999955416, 12.125990074127913, 5.5942189414054155, 12.177239824086428, 5.679975589737296, 1.504101671744138, 1.0563050815835595, 17.39657800644636, 47.08477444946766, 61.984690725803375, 60.47348141670227, 57.49805107712746, 61.38898529112339, 58.86161170899868, 61.10504932701588, 61.49149239063263, 57.536140233278275, 59.827808663249016, 55.074529722332954, 54.497618079185486, 58.24681989848614, 60.81867389380932, 59.11000818014145, 60.07101081311703, 57.11541160941124, 59.47351947426796, 58.88056129217148, 56.19093641638756, 51.44999921321869, 43.50480794906616, 47.703685238957405, 49.48325514793396, 50.420338064432144, 51.52922496199608, 52.55218327045441, 48.47388871014118, 45.227369517087936, 44.80561874806881, 44.96070362627506, 44.338095635175705, 44.2472805082798, 48.321509286761284, 45.790552496910095, 51.38043254613876, 55.18675670027733, 56.55014634132385, 58.06188762187958, 57.68809787929058, 56.46370477974415, 56.92173220217228, 37.531437277793884, 55.56700989603996, 57.69144929945469, 55.379885137081146, 53.111756443977356, 48.73739697039127, 52.19228558242321, 53.01067426800728, 49.69359666109085, 46.71141788363457, 41.364082619547844, 41.74163416028023, 43.83923940360546, 41.2628598511219, 41.73717699944973, 40.08712314069271, 41.84350289404392, 41.91279597580433, 46.89254276454449, 54.654739648103714, 53.7491000443697, 54.87516202032566, 56.29784747958183, 51.38141669332981, 49.16818745434284, 44.80185694992542, 40.180518329143524, 39.92889583110809, 41.00094370543957, 45.99683962762356, 50.4022054374218, 53.21960985660553, 52.98159442842007, 51.76385477185249, 48.497223258018494, 52.34590753912926, 52.281067818403244, 51.51416637003422, 51.86829596757889, 51.69553443789482, 48.109043687582016, 52.812165319919586, 47.249431014060974, 36.94230929017067, 13.802373670041561, 2.620154866017401, 1.1659467732533813, 8.086807765066624, 10.14208422973752, 10.676988177001476, 9.734785035252571, 15.304499566555023, 28.549604639410973, 3.711508554406464, 1.5627278946340084, 0.33180650789290667, 0.20504924323176965, 11.479408219456673, 54.46147821843624, 27.43628527969122, 44.4329309463501, 20.898937471210957, 0.29670081508811563, 0.2937340352218598, 0.15033272851724178, 0.1199623905995395, 0.1325907532009296, 0.1444458944024518, 0.13941995159257203, 0.13625433552078903, 0.0930196097760927, 0.11826196699985303, 0.10240402261842974, 0.09659919582190923, 0.18381675443379208, 0.10412384595838375, 0.133525651472155, 0.10768232532427646, 0.136907588748727, 0.0855670815508347, 0.07042179189738818, 0.24868102540494874, 0.14581030322005972, 0.08284701383672655, 0.13981611002236605, 0.14651345845777541], [0.1089688680076506, 0.04418297154188622, 0.06498733389889821, 0.010288310677424306, 0.0983967813954223, 0.019458024835330434, 0.03634886066720355, 0.05108282981382217, 0.04971621681761462, 0.05304742830048781, 0.016431294279755093, 0.0859787360241171, 0.05847488413564861, 0.09215921571012586, 0.02034180211921921, 0.04639649749151431, 0.07215826903120615, 0.04523430165136233, 0.05054668006778229, 0.05930601531872526, 0.03914566645107698, 0.01282819792322698, 0.0700453226454556, 0.06347968315822072, 0.05947820100118406, 0.00902442205187981, 0.01884995355794672, 0.04841064917854965, 0.07717138752923347, 0.04822258524654899, 0.1504096743883565, 3.843786818906665, 39.54060606658459, 33.150211572647095, 31.862304881215096, 45.00113345682621, 7.055526953190565, 0.2483189315535128, 0.07305638646357693, 0.17880921688629314, 0.6706062436569482, 0.10998788129654713, 5.7420846819877625, 6.72836403362453, 1.3461993634700775, 0.5602042959071696, 0.1539385865908116, 1.048815802205354, 19.001083709299564, 43.755780681967735, 57.279365211725235, 56.754066199064255, 55.75505420565605, 57.07912735641003, 59.13007490336895, 58.8638611882925, 56.67268976569176, 53.97199988365173, 49.8578542470932, 53.72490294277668, 57.06099092960358, 57.40431770682335, 57.367904260754585, 56.64556682109833, 54.43130023777485, 54.13702502846718, 55.423187613487244, 52.6299536973238, 42.18570493161678, 40.01109682023525, 42.35203720629215, 44.61181774735451, 48.47920082509518, 51.19898848235607, 51.0253643989563, 44.273404106497765, 41.99733763933182, 39.87147331237793, 41.31582520902157, 41.298441141843796, 40.15827052295208, 38.63204441964626, 43.206341564655304, 49.94607791304588, 52.65591010451317, 54.20816861093044, 54.26227770745754, 53.04163500666618, 54.98503312468529, 55.897842943668365, 47.124672308564186, 59.45072449743748, 54.69390794634819, 54.61567774415016, 48.89878571033478, 45.00819727778435, 43.010184690356255, 43.699665293097496, 42.034397050738335, 38.94776567816734, 37.379339039325714, 38.583570420742035, 38.748728558421135, 36.508288979530334, 36.552313417196274, 38.910216093063354, 38.004572689533234, 41.104092970490456, 45.768418684601784, 51.57332919538021, 50.03764919936657, 50.74458986520767, 52.72317789494991, 50.03356821835041, 47.531573474407196, 40.25521472096443, 37.71269895136356, 37.521705999970436, 38.63185063004494, 43.202765956521034, 47.606201469898224, 50.467390939593315, 50.48800103366375, 48.05452041327953, 44.86598990857601, 48.82172204554081, 48.4073580801487, 48.94302673637867, 48.99672545492649, 49.529384672641754, 48.81335869431496, 48.691537231206894, 35.591018199920654, 16.424109488725662, 2.9611903661862016, 1.0369616257958114, 0.5095375177916139, 3.399261496961117, 3.7451217882335186, 1.2638355768285692, 9.244091715663671, 2.95844501350075, 1.668001958169043, 0.97744619124569, 0.2020239969715476, 0.22677965374896303, 1.0178314335644245, 28.94604306668043, 30.986497476696968, 24.821989461779594, 29.3096474558115, 2.516465554945171, 0.04212204599753022, 0.019396294846956152, 0.004536180076684104, 0.0696336459077429, 0.046725202118977904, 0.04019645850348752, 0.07107220269972458, 0.06080319806642365, 0.07572011032607406, 0.026993120700353757, 0.029686882990063168, 0.042515977984294295, 0.04751161890453659, 0.022066681340220384, 0.0030918639868104947, 0.05893598419788759, 0.0194407476374181, 0.06922696382389404, 0.037930002581560984, 0.02836430532624945, 0.03141519278869964, 0.02081913480651565, 0.02954262432467658, 0.05978463748760987, 0.057545102972653694, 0.02525145038816845, 0.012292180836084299, 0.021031008691352326, 0.09764489674125798, 0.03331153595354408, 0.011193584268767154, 0.05386001692386344, 0.029016330299782567, 0.03098722405411536, 0.024848573666531593, 0.04480064249946736, 0.046731009424547665, 0.029317833359527867, 0.031153400195762515, 0.058369680991745554, 0.02814653136738343, 0.05728916963562369, 0.0416332675376907, 0.011684728324325988, 0.021185932018852327, 0.05994377250317484, 0.002513780113986286, 0.048279144320986234, 0.02609219794976525, 0.058866237159236334, 0.03155822319968138, 0.060909173043910414, 0.01638615500269225, 0.1722706138389185, 0.1337486520060338, 6.660762336105108, 51.30104720592499, 28.84626042097807, 38.587772995233536, 52.650392800569534, 5.656426353380084, 0.020898075199511368, 0.3435248712776229, 0.048688553797546774, 0.3049345873296261, 0.5666877573821694, 2.64463291503489, 5.050691356882453, 5.179935721680522, 1.7487594997510314, 0.5234047549311072, 2.2867992287501693, 22.716226056218147, 48.55823278427124, 58.74086178839207, 57.81634099781513, 56.892272382974625, 58.25610280036926, 59.13296274840832, 60.41250228881836, 58.89437735080719, 57.186520993709564, 50.86846701800823, 55.75953796505928, 58.443531543016434, 58.49728345870972, 57.95475997030735, 58.53582479059696, 54.9227050691843, 56.48293934762478, 56.92720390856266, 55.84846459329128, 45.95979541540146, 41.85756593942642, 43.90824370086193, 46.246683821082115, 49.87266965210438, 52.68631987273693, 52.93430596590042, 46.23187601566315, 43.9784487336874, 41.91974960267544, 43.41776601970196, 43.665166944265366, 40.72740778326988, 40.64282812178135, 44.2620275169611, 51.44002094864845, 54.66269642114639, 55.16258619725704, 54.77996572852135, 54.770435839891434, 55.060090497136116, 57.20022685825825, 48.99222269654274, 60.028217509388924, 55.81810422241688, 56.61273658275604, 50.794739574193954, 47.74228356778622, 46.31958290934563, 46.610126718878746, 44.87757168710232, 40.004625767469406, 38.55773560702801, 40.546062514185905, 39.74336698651314, 38.23544070124626, 37.753664553165436, 40.51138177514076, 40.936464965343475, 42.103591337800026, 47.874322682619095, 52.96939328312874, 53.11058230698109, 52.07393333315849, 53.82403962314129, 52.02946051955223, 47.90037788450718, 40.95979191362858, 39.74586725234985, 37.8010518103838, 39.24609147012234, 44.0772320330143, 48.2753037661314, 51.585450544953346, 51.345094442367554, 49.31230612099171, 45.66266655921936, 49.88655410706997, 51.34867385029793, 49.787584617733955, 50.43407432734966, 49.83800411224365, 49.39610302448273, 49.1600026935339, 38.1274238973856, 19.168360233306885, 4.4732961896806955, 2.293461221270263, 1.7270316719077528, 4.164996882900596, 8.254042491316795, 1.892088046297431, 8.760628458112478, 5.568260634317994, 1.609861277975142, 0.4683601367287338, 0.02472893575031776, 0.1477421136223711, 0.7229623279999942, 32.31479600071907, 38.69377590715885, 24.73668783903122, 36.0678356140852, 4.589122049510479, 0.05871034903975669, 0.027041649736929685, 0.047577517907484435, 0.028935779446328525, 0.1025530681363307, 0.040290633332915604, 0.033768138600862585, 0.05887139508558903, 0.043155969033250585, 0.035745583663810976, 0.022956481152505148, 0.053619431200786494, 0.04874188452959061, 0.06560788067872636, 0.017074888455681503, 0.0030813737294010934, 0.03912386957381386, 0.02052861738775391, 0.03768570983083919, 0.08155759162036702, 0.034827751078410074, 0.03426472074352205, 0.07787164839101024, 0.035896247063647024, 0.218380902078934, 0.2084621280664578, 0.1666059490526095, 0.2561984321800992, 0.22110737452749163, 0.10702180647058412, 0.10006665819673799, 0.17219991685124114, 0.1771931754774414, 0.16713115212041885, 0.14877322391839698, 0.1611360683455132, 0.15087701962329447, 0.17858706240076572, 0.18660810543224216, 0.1443338894750923, 0.18863320379750803, 0.19952168280724436, 0.19817734166281298, 0.2015302758081816, 0.11660934513201937, 0.11772616606322117, 0.19783630996244028, 0.09163776790956035, 0.1919032252044417, 0.16172715928405523, 0.15967987070325762, 0.34476036904379725, 0.2105701540131122, 0.32066888990812004, 0.24884607904823497, 7.61576509103179, 57.96559698879719, 40.70098400115967, 41.32454574108124, 57.76173412799835, 11.44678981974721, 0.39283568621613085, 0.5588347068987787, 0.21719212993048131, 1.643188577145338, 3.4914148645475507, 13.231399208307266, 17.686492949724197, 4.7120164800435305, 0.8966788533143699, 0.4237556958105415, 1.2715707742609084, 22.444624230265617, 47.38818436861038, 61.790806129574776, 60.103525668382645, 57.92183093726635, 59.18432459235191, 61.7855966091156, 62.55886271595955, 61.899951472878456, 60.16533315181732, 52.44743049144745, 58.95487390458584, 59.92879964411259, 60.12701600790024, 60.1118054240942, 57.5900137424469, 57.414440363645554, 58.3981391787529, 60.93118205666542, 55.52460037171841, 47.40782171487808, 44.13155011832714, 45.308840945363045, 49.35421407222748, 52.7643258869648, 55.509241595864296, 55.61128132045269, 47.71761529147625, 47.18975901603699, 44.65106964111328, 43.86561378836632, 46.88462778925896, 41.36405222117901, 43.22805739939213, 46.32910519838333, 54.988965913653374, 56.33362255990505, 58.4831178188324, 57.57418379187584, 56.843198016285896, 56.975700706243515, 58.67602966725826, 47.4944456666708, 61.077265217900276, 58.99104796350002, 58.287891894578934, 52.18660868704319, 49.38234396278858, 46.83900363743305, 47.232065945863724, 46.20143964886665, 42.43904873728752, 40.64796544611454, 43.614686653018, 42.97929994761944, 38.90647329390049, 39.608861804008484, 42.95672535896301, 42.17103771865368, 44.83756363391876, 48.96592050790787, 55.87888956069946, 53.037356436252594, 52.63427786529064, 55.91971457004547, 54.613758847117424, 51.83084897696972, 43.717045560479164, 42.45352976024151, 40.65458469092846, 41.27459742128849, 46.84112772345543, 50.63702143728733, 55.04778675734997, 53.505134135484695, 50.95650069415569, 47.346682995557785, 51.21394068002701, 53.10995154082775, 51.489543691277504, 51.252842992544174, 49.86615300178528, 50.10062702000141, 50.112695172429085, 36.34829856455326, 18.496634177863598, 3.635928947478533, 1.7179150111041963, 1.5930094197392464, 8.849891368299723, 9.340583737939596, 6.5192527044564486, 17.254087552428246, 7.499722167849541, 5.487878797575831, 2.267201542854309, 0.5528748454526067, 0.3151622135192156, 2.0011676056310534, 38.03954981267452, 40.367088317871094, 31.13115381449461, 43.694125190377235, 5.528777427971363, 0.19074722629738972, 0.1812305924249813, 0.09687715239124373, 0.241191879613325, 0.22773741016862914, 0.09743506932863966, 0.08524480392225087, 0.18402758374577388, 0.14857216126983985, 0.1230106657021679, 0.10324834918719716, 0.09573466057190672, 0.10616742380079813, 0.11958443705225363, 0.09338576317531988, 0.1726862313807942, 0.07974298117915168, 0.2688913542078808, 0.16280101728625596, 0.16602535208221525, 0.1551926528918557, 0.08873673490597866, 0.13846924557583407, 0.11482383430120535], [0.07622050339705311, 0.09339191557955928, 0.03741681488463655, 0.060891053508385085, 0.06131130205176305, 0.00902013522136258, 0.03587406055885367, 0.016389355514547788, 0.03956812659453135, 0.0943073102098424, 0.07105052456608973, 0.06785471050534397, 0.02666588366992073, 0.06847424054285511, 0.03591414395486936, 0.06893521072925068, 0.06522365598357283, 0.040785237652016804, 0.06251487633562647, 0.0030349493772519054, 0.04064575470692944, 0.039978975837584585, 0.012415290148055647, 0.024087332385533955, 0.035833383444696665, 0.03781993465963751, 0.028626264902413823, 0.029090257485222537, 0.01834028364100959, 0.020099006651435047, 0.08287615797598846, 0.1265530553064309, 16.23954389244318, 42.42237143218517, 25.406120717525482, 38.986595794558525, 39.7501952201128, 6.866465248167515, 0.4826531291473657, 0.18244125792989507, 0.14911587350070477, 0.7241381274070591, 0.6359754363074899, 1.1548443627543747, 6.583078354597092, 5.3493463061749935, 0.9872093517333269, 0.28100940864533186, 1.2738269031979144, 13.278770316392183, 33.75812575221062, 52.32023611664772, 56.57310090959072, 57.61537358164787, 57.154511511325836, 58.309364542365074, 55.01455374062061, 53.03439259529114, 50.60069918632507, 56.50181293487549, 57.424688413739204, 59.390980303287506, 53.71726915240288, 52.01975964009762, 51.39997109770775, 55.97254693508148, 55.62366105616093, 50.395274609327316, 43.462147638201714, 41.78015649318695, 42.885209396481514, 47.278415858745575, 49.720012843608856, 52.01805733144283, 52.323112562298775, 49.178788885474205, 44.08252514898777, 41.23227149248123, 40.806405544281006, 40.82602009177208, 39.16547119617462, 41.16228684782982, 41.05767846107483, 47.384867146611214, 51.02252975106239, 55.42594626545906, 52.89932504296303, 56.5205155313015, 51.45104795694351, 54.62903402745724, 54.15416970849037, 56.766312941908836, 54.876769334077835, 51.4715326577425, 49.24341581761837, 45.62305748462677, 41.133590787649155, 39.32714492082596, 37.50516168773174, 36.56765699386597, 38.19401912391186, 40.38903973996639, 38.80492754280567, 38.66935841739178, 40.15992343425751, 39.124072417616844, 41.68675750494003, 46.79032824933529, 51.496550515294075, 52.78403162956238, 51.9716390222311, 52.740269377827644, 53.45084644854069, 51.22203804552555, 49.55647721886635, 40.67733407020569, 36.54520019888878, 39.13760729134083, 40.669483691453934, 43.83913680911064, 48.858127892017365, 48.558605164289474, 49.71101492643356, 48.67362879216671, 50.303406938910484, 50.622635409235954, 49.34135556221008, 47.51589171588421, 49.346116706728935, 50.62638200819492, 49.9761912971735, 39.221426993608475, 21.734822317957878, 6.788124851882458, 0.9538849617820233, 2.93584406375885, 1.335552572272718, 3.429293422959745, 7.7612588088959455, 0.8605595945846289, 8.397490493953228, 8.008694406598806, 1.1442549247294664, 0.08445965620921925, 0.07338284980505705, 0.34512645564973354, 13.554360028356314, 40.677417665719986, 22.897643521428108, 29.84900001436472, 16.48048136383295, 0.32126032223459333, 0.0640098808798939, 0.04082628584001213, 0.06326458649709821, 0.0615052994544385, 0.03141253961075563, 0.009243320364475949, 0.002992612867274147, 0.03592287532228511, 0.06907524657435715, 0.08851928563672118, 0.02756059093371732, 0.05066463701950852, 0.05742145745898597, 0.028747036449203733, 0.0027790243893832667, 0.06230031402083114, 0.04630427822121419, 0.01684885995928198, 0.04433884110767394, 0.034735843510134146, 0.027383419874240644, 0.049475471532787196, 0.03445864393142983, 0.04649278002034407, 0.08766188242589124, 0.04969779300154187, 0.028466539879445918, 0.032149221369763836, 0.07747019102680497, 0.012340100383880781, 0.03865466896968428, 0.01367672040942125, 0.04100011537957471, 0.028440175083233044, 0.022254268442338798, 0.018419021798763424, 0.004711734181910288, 0.014741965787834488, 0.04087926405190956, 0.017430696316296235, 0.020995073900849093, 0.0433071482257219, 0.03671868398669176, 0.03303640325611923, 0.07827686844393611, 0.05783086693554651, 0.0288164940502611, 0.08443934362730943, 0.019100007230008487, 0.05509499147592578, 0.029526009493565653, 0.04314904108468909, 0.02641362210852094, 0.009701988965389319, 0.012363237765384838, 0.4331707890378311, 22.422233931720257, 48.15477803349495, 23.757208697497845, 47.70963191986084, 39.4406296312809, 5.740647884085774, 0.19232584862038493, 0.20489567803451791, 0.07142999209463596, 0.47006434528157115, 0.7200083427596837, 6.205973764881492, 14.949083738029003, 1.3456823537126184, 1.4309729333035648, 0.38877058716025203, 2.8971647517755628, 17.59594950824976, 40.689645409584045, 53.5651633143425, 57.542143911123276, 58.53422127664089, 59.929715394973755, 59.824445843696594, 57.585609778761864, 54.04892675578594, 52.74432756006718, 57.79980048537254, 60.986229702830315, 59.11189287900925, 56.1429487913847, 53.45636375248432, 53.496045023202896, 57.1007975935936, 57.238050028681755, 53.223956823349, 44.400856867432594, 43.07125501334667, 43.777082338929176, 50.0055181235075, 53.054121136665344, 54.63238924741745, 53.22286628186703, 50.945766270160675, 46.50250129401684, 43.02372716367245, 42.941678166389465, 43.576988875865936, 42.242637276649475, 41.85819290578365, 43.39181341230869, 49.390965700149536, 53.74560043215752, 56.95925138890743, 54.0236809104681, 58.05459961295128, 53.36247459053993, 54.62235018610954, 55.85864804685116, 58.697023540735245, 56.146110221743584, 53.47251668572426, 50.3727076202631, 48.000232726335526, 44.194717928767204, 41.72288216650486, 39.4601833820343, 38.477092534303665, 39.02717761695385, 41.05702489614487, 40.75795814394951, 39.36725936830044, 41.29762418568134, 40.08911423385143, 43.84711258113384, 49.00780566036701, 51.650062277913094, 54.9419966340065, 52.68399819731712, 53.9910064637661, 53.715388253331184, 53.29992614686489, 49.42830629646778, 41.99932113289833, 38.03691275417805, 41.036217212677, 41.16462752223015, 45.048068538308144, 51.138906106352806, 51.43638834357262, 50.574674382805824, 50.133472457528114, 49.23156425356865, 51.271545588970184, 50.59271581470966, 49.13738630712032, 51.69529125094414, 51.91954001784325, 51.13811954855919, 40.542665496468544, 25.21589532494545, 7.787969475612044, 1.5048425132408738, 2.905865334905684, 3.2290140073746443, 4.1244017612189054, 6.2777818366885185, 5.1898208912462, 5.62945825047791, 3.346821223385632, 0.07936645997688174, 0.046653009703732096, 0.10756212708656676, 0.35619033384136856, 12.848863285034895, 48.12497243285179, 26.072604954242706, 32.68428437411785, 22.551221810281277, 0.5603936326224357, 0.045294968513189815, 0.02490046463208273, 0.030773531907470897, 0.040851511439541355, 0.05508346963324584, 0.04318535065976903, 0.038232045553741045, 0.036867094968329184, 0.04045585395942908, 0.06302038280409761, 0.027016806343453936, 0.05488640716066584, 0.01406679786668974, 0.018618635403981898, 0.03804179599683266, 0.08002539805602282, 0.06076257661334239, 0.03917218709830195, 0.0024671203618709114, 0.04463810102606658, 0.018437692378938664, 0.049245576446992345, 0.05490564362844452, 0.040375427415710874, 0.13027390174102038, 0.11898726050276309, 0.12391228607157245, 0.16711587872123346, 0.19794406980508938, 0.14081609464483336, 0.09849231806583703, 0.07271134716575034, 0.14434677315875888, 0.2032335047260858, 0.14980369596742094, 0.15551563556073233, 0.26145150186493993, 0.140182493487373, 0.1656961502158083, 0.18003571982262656, 0.1413200722890906, 0.14533650130033493, 0.17551411088788882, 0.07882471443735994, 0.13208693882916123, 0.14795592636801302, 0.14838641654932871, 0.1261619434808381, 0.08878769076545723, 0.10764899547211826, 0.16740386170567945, 0.10010427024099045, 0.09400084032677114, 0.13872789888409898, 0.20269184082280844, 0.4314288793830201, 26.921249516308308, 59.03132200241089, 33.31414997577667, 50.092354863882065, 49.237032160162926, 10.229057762771845, 0.6649965571705252, 0.3098503063665703, 0.309020021231845, 1.342422366142273, 5.517419837415218, 6.127988649532199, 20.019402466714382, 14.078111574053764, 2.7087174262851477, 1.1694366484880447, 2.356432629749179, 16.724988743662834, 37.99362927675247, 55.6017704308033, 56.91178813576698, 60.72787396609783, 59.75502736866474, 61.840534061193466, 60.32822661101818, 58.860201984643936, 55.21384924650192, 60.305325239896774, 61.53993219137192, 60.77215299010277, 56.70615836977959, 54.30423505604267, 55.501189827919006, 59.89676356315613, 59.56126056611538, 54.02097925543785, 46.59448675811291, 45.68369463086128, 47.25307121872902, 53.61082166433334, 55.2474470436573, 57.363865077495575, 55.49152694642544, 52.447248101234436, 48.57087850570679, 45.10435491800308, 45.493541434407234, 45.72436764836311, 43.883997201919556, 45.69481283426285, 44.75195802748203, 50.00555232167244, 55.13570263981819, 59.31807741522789, 56.20231680572033, 60.433119982481, 53.77279557287693, 55.966288670897484, 54.758937656879425, 61.871661990880966, 59.54890362918377, 55.61452254652977, 53.197791427373886, 49.76916320621967, 44.91852588951588, 42.743761986494064, 40.92611812055111, 39.54814866185188, 41.97848305106163, 43.412233516573906, 42.63383008539677, 41.779217943549156, 43.96148644387722, 43.63511435687542, 47.63868972659111, 50.72723239660263, 54.43707212805748, 56.23851366341114, 54.39120478928089, 54.281189292669296, 56.488707438111305, 55.302749276161194, 52.61780954897404, 45.21235652267933, 40.27501545846462, 42.87320964038372, 43.327441066503525, 48.21465142071247, 53.39200660586357, 53.67779307067394, 51.4630401134491, 50.322014540433884, 50.280091390013695, 54.15025591850281, 51.73236966133118, 50.24025432765484, 50.637017637491226, 54.17310789227486, 52.4098315089941, 39.92421068251133, 23.7072641775012, 7.628953233361244, 1.6639925795607269, 5.040761064738035, 5.033715292811394, 7.649191897362471, 12.721671760082245, 5.345695652067661, 21.126231774687767, 21.538566648960114, 4.561291867867112, 0.2700855885632336, 0.19680751516716555, 0.536417334806174, 19.498649910092354, 52.53670670092106, 31.265275217592716, 42.34779663383961, 26.70778077095747, 0.8067841676529497, 0.23141717130783945, 0.16075485676992685, 0.1755006780149415, 0.20222872582962736, 0.1264191570226103, 0.12713409756543115, 0.08745669343625195, 0.12703364045592025, 0.17199015623191372, 0.18080039910273626, 0.10116546720382757, 0.19429547886829823, 0.0803335674572736, 0.12298837158596143, 0.10972327596391551, 0.17404436162905768, 0.20171913754893467, 0.1374952361220494, 0.13532855082303286, 0.09887965235975571, 0.10357637103879824, 0.18407655064947903, 0.18125226313713938, 0.09619604636100121], [0.03468854643870145, 0.011503682326292619, 0.04448626503290143, 0.04224051874189172, 0.01175077853986295, 0.07702155533479527, 0.008826514458633028, 0.03530624708218966, 0.05303597325109877, 0.019071970746153966, 0.05690688565664459, 0.02742084823694313, 0.021717601048294455, 0.051565147878136486, 0.02086600328766508, 0.04987215688743163, 0.028496466984506696, 0.03708268515765667, 0.039330962172243744, 0.014297571469796821, 0.027217583265155554, 0.05491170326422434, 0.025208272236341145, 0.0360794387961505, 0.019825673662126064, 0.018583823111839592, 0.05726189570850693, 0.04045510067953728, 0.05042290467827115, 0.07010924382484518, 0.039223332205438055, 0.15224073082208633, 2.3831328470259905, 28.622249141335487, 37.35970929265022, 25.906082689762115, 37.68827386200428, 35.89257001876831, 10.687292274087667, 0.6817931996192783, 0.21199313312536106, 0.25693915493320674, 0.27025393734220415, 5.4320393688976765, 13.009813148528337, 1.8113137618638575, 1.3147986796684563, 0.3087078739190474, 0.03744969944818877, 0.7133136363700032, 7.30943787842989, 24.79858461767435, 43.214153945446014, 57.27111965417862, 59.89136025309563, 55.78499659895897, 54.572436064481735, 50.715745612978935, 54.77320209145546, 57.805743366479874, 57.09920547902584, 57.04040363430977, 51.157251521945, 54.27469924092293, 55.15411265194416, 57.512722089886665, 54.659181609749794, 46.01174622774124, 39.74493250250816, 42.670220732688904, 44.78933662176132, 49.12613891065121, 52.20343418419361, 54.72441650927067, 56.22019484639168, 52.80263923108578, 46.2088530510664, 41.98708578944206, 42.47525319457054, 41.197442561388016, 41.86758980154991, 41.44624561071396, 41.56691953539848, 42.52421356737614, 45.83075813949108, 47.60675624012947, 53.022385239601135, 53.09939570724964, 57.03033797442913, 52.36273303627968, 52.97594033181667, 56.00834861397743, 53.31621587276459, 50.714647471904755, 46.502470895648, 44.62265856564045, 39.336823001503944, 40.89419983327389, 38.69670934975147, 38.282117396593094, 38.348412439227104, 40.71870245039463, 36.97804257273674, 39.103021547198296, 40.34084312617779, 43.02936226129532, 49.95275795459747, 50.617870464921, 53.465327471494675, 52.58246384561062, 52.554858326911926, 51.888111904263496, 53.18412736058235, 50.27221441268921, 49.98347170650959, 44.64179813861847, 36.97856314480305, 38.08006703853607, 42.948931977152824, 47.037778571248055, 49.9334017932415, 48.66262078285217, 49.381952583789825, 48.64275544881821, 49.373699426651, 49.92541842162609, 49.32305954396725, 51.38628423213959, 49.81929391622543, 49.98686492443085, 44.05036747455597, 26.24905038625002, 10.360333118587732, 0.9945453330874443, 0.8939818886574358, 2.5367835396900773, 2.828645878471434, 2.701580934226513, 5.4453918524086475, 3.8868230720981956, 2.9088009148836136, 1.6284564114175737, 0.12366647191811353, 0.10728229288361035, 0.4904262948548421, 9.274608828127384, 40.14879763126373, 29.737561494112015, 23.02828811109066, 30.390062481164932, 4.024781081825495, 0.018502728635212407, 0.09689392492873594, 0.11784008573158644, 0.04177225324383471, 0.06839722045697272, 0.11163242859765887, 0.02850055807357421, 0.03062550869799452, 0.10000068868976086, 0.0072710768290562555, 0.09360266325529665, 0.03421645888010971, 0.027377636688470375, 0.012962328128196532, 0.030457672000920866, 0.037182485466473736, 0.020251198875484988, 0.0203208457241999, 0.050891095961560495, 0.0928620740887709, 0.03518704332236666, 0.022399773915822152, 0.058523123734630644, 0.013244379497336922, 0.04391327878693119, 0.02455566467688186, 0.030411926018132363, 0.029304001582204364, 0.03995225481048692, 0.05799832513730507, 0.061823539799661376, 0.02897288868553005, 0.017788578479667194, 0.0751050554390531, 0.06463370053097606, 0.10666723799658939, 0.014764187544642482, 0.06885778246214613, 0.010628526943037286, 0.029139280050003435, 0.016008262682589702, 0.050980765954591334, 0.07793861237587407, 0.020563474208756816, 0.004614921481334022, 0.045685545992455445, 0.050949402793776244, 0.024357485272048507, 0.03258543350966647, 0.006554416358994786, 0.03614622837631032, 0.012082350640412187, 0.05341387484804727, 0.053264109446899965, 0.024769442170509137, 0.03642384726845194, 0.18975055165356025, 3.695004852488637, 40.521827414631844, 36.42818547785282, 29.42392062395811, 52.03356049954891, 38.31340491771698, 9.37197670340538, 0.5588149360846728, 0.042525559110799804, 0.11653735680738464, 0.05287917971145362, 1.2235426576808095, 7.149089332669973, 4.560311045497656, 3.9226409001275897, 1.8928617797791958, 0.30660881311632693, 1.8056563404388726, 9.851224087178707, 30.015176497399807, 48.716311901807785, 59.665857553482056, 61.35947227478027, 57.06031456589699, 56.64148963987827, 53.14214341342449, 57.46091566979885, 59.50739085674286, 58.29475812613964, 58.89065355062485, 53.2987330108881, 55.04415035247803, 56.158835738897324, 59.917495250701904, 57.14394427835941, 47.27807767689228, 43.235163018107414, 45.07816292345524, 45.53065404295921, 51.48908391594887, 54.244665652513504, 55.288823023438454, 57.325156554579735, 55.54142586886883, 46.131656393408775, 43.621982261538506, 43.61171901226044, 42.30955548584461, 43.40282902121544, 44.04590271413326, 43.09612847864628, 44.846090376377106, 47.71101124584675, 51.63697957992554, 56.422754377126694, 56.50488696992397, 57.299371138215065, 54.745919555425644, 56.096940860152245, 57.1477060765028, 54.51344422996044, 53.00500117242336, 48.956656605005264, 46.862699165940285, 42.75217853486538, 42.42184706032276, 40.479562282562256, 39.59332823753357, 41.165919452905655, 42.44502581655979, 38.85017171502113, 41.724584475159645, 43.094540163874626, 44.22123670578003, 51.06246180832386, 52.02096037566662, 54.947848320007324, 54.73494574427605, 54.57913890480995, 52.49830596148968, 54.07070338726044, 52.03070305287838, 51.01474776864052, 45.86925007402897, 38.963553830981255, 39.28483799099922, 44.44118410348892, 48.134057745337486, 50.347963348031044, 49.274315759539604, 50.89805603027344, 52.90617227554321, 51.193159595131874, 51.29980847239494, 50.02817630767822, 52.64639161527157, 50.29470540583134, 51.587354242801666, 46.12038619816303, 28.680315725505352, 12.65050632879138, 2.4176197964698076, 2.5907081086188555, 3.9745646389201283, 2.8157757315784693, 2.6645231852307916, 5.740800350904465, 5.26387226767838, 2.6723619271069765, 0.40474478155374527, 0.0740331641281955, 0.20087377197341993, 0.6576631288044155, 7.953509967774153, 45.89017555117607, 35.35613380372524, 23.96820567548275, 34.90828603506088, 5.9774217288941145, 0.05177227016247343, 0.15290090086637065, 0.11557252772036009, 0.0409726076759398, 0.059904290246777236, 0.09373740016599186, 0.03335642846650444, 0.038575652506551705, 0.030800930144323502, 0.04324979876400903, 0.05113790830364451, 0.039496386889368296, 0.04291714962164406, 0.008480761771352263, 0.06586824834812433, 0.014905114894645521, 0.012370987642498221, 0.018882196163758636, 0.043239512597210705, 0.06771163927624002, 0.030208097014110535, 0.039474834920838475, 0.03184230990882497, 0.022175457925186493, 0.05018403331632726, 0.1217984120012261, 0.1368040739907883, 0.07812813462805934, 0.2286685531726107, 0.1720463071251288, 0.13193608989240602, 0.11086507758591324, 0.11677566784783266, 0.1885329544893466, 0.15699892159318551, 0.16962763300398365, 0.12678331404458731, 0.1694586459780112, 0.15025927074020728, 0.11678674069116823, 0.12188595574116334, 0.16776585165644065, 0.16601928131422028, 0.19114736263873056, 0.10045806688140146, 0.14336954278405756, 0.22074734384659678, 0.13576390949310735, 0.050002229399979115, 0.1873921399237588, 0.06549557889229618, 0.19774827640503645, 0.17021919891703874, 0.12666755384998396, 0.21823894407134503, 0.14845202240394428, 0.3112290386343375, 4.125622445717454, 47.31131449341774, 47.235633954405785, 36.212566047906876, 49.137644693255424, 45.26321679353714, 15.430666096508503, 1.0450141062028706, 0.29972649179399014, 0.41597525705583394, 1.2646325840614736, 15.025122407823801, 30.32055851072073, 11.606702338904142, 8.867600318044424, 3.3819942735135555, 0.2911231300095096, 1.2653406523168087, 9.099000301212072, 28.207862377166748, 46.34496174752712, 60.59573605656624, 64.35656905174255, 60.78224524855614, 58.47978159785271, 53.99673655629158, 58.89527030289173, 62.402189522981644, 60.81406094133854, 59.74474512040615, 54.113739877939224, 56.33961483836174, 58.14459018409252, 62.147378996014595, 60.13656489551067, 49.40944790840149, 44.75835308432579, 46.197126880288124, 47.82241366803646, 53.02572526037693, 56.545825973153114, 58.17611329257488, 60.85211589932442, 58.283449932932854, 49.50374364852905, 45.543474555015564, 45.219488739967346, 44.76249486207962, 44.98926669359207, 44.974348694086075, 45.45041374862194, 46.979227513074875, 49.622228890657425, 53.17787289619446, 57.520181089639664, 59.30475912988186, 58.285311833024025, 55.04040755331516, 57.182098031044006, 60.85663005709648, 58.01968328654766, 53.15025597810745, 51.935590356588364, 49.05091054737568, 43.86243335902691, 44.02886442840099, 42.73944541811943, 41.8229003995657, 43.70854161679745, 44.43969078361988, 40.185784846544266, 43.92378106713295, 43.396745547652245, 45.95422491431236, 53.29961456358433, 53.08248661458492, 58.81765566766262, 56.74851469695568, 54.525083005428314, 53.05557645857334, 54.04095858335495, 54.31279979646206, 53.568263947963715, 47.82204508781433, 41.43146060407162, 40.637645199894905, 46.75808697938919, 51.4731627702713, 52.94934555888176, 51.47405572235584, 52.55765877664089, 52.94991172850132, 51.45770899951458, 51.88238561153412, 51.39044500887394, 55.301814526319504, 52.75167256593704, 52.047342360019684, 45.57764232158661, 28.53973276913166, 11.423441972583532, 1.64461005711928, 2.799095339141786, 6.813383996486664, 5.988197475671768, 7.183061884716153, 11.375197861343622, 9.509637616574764, 9.40562104806304, 3.185382136143744, 0.35067475168034434, 0.3075287793762982, 1.097122491337359, 13.228948339819908, 51.67031139135361, 38.35520647466183, 31.28248829394579, 42.68634706735611, 6.067757131531835, 0.13985804136609659, 0.5362699739634991, 0.414547958644107, 0.09692139181424864, 0.16528595035197213, 0.18740239640465006, 0.13998313777847216, 0.09612900816136971, 0.18709201540332288, 0.12206913263071328, 0.1933355999062769, 0.09944119097781368, 0.20356711494969204, 0.11320837918901816, 0.10732177514000796, 0.08264401418273337, 0.031091738856048323, 0.09613465590518899, 0.17116563016315922, 0.22162543813465163, 0.12271465267986059, 0.08216660542530008, 0.17347124550724402, 0.06429666158510372, 0.16063082905020565], [0.005450537555589108, 0.02080414713418577, 0.011603181137616048, 0.038332677067955956, 0.02420334676571656, 0.04454399298992939, 0.03504472166241612, 0.03674179075460415, 0.042839365123654716, 0.0696834440168459, 0.030318445096781943, 0.1022465834103059, 0.030421588780882303, 0.04858889449678827, 0.06005130970152095, 0.04995768940716516, 0.02961733076517703, 0.051957732866867445, 0.03937611814762931, 0.022751982360205147, 0.016561233205720782, 0.05040972042479552, 0.031087516035768203, 0.043614401074592024, 0.0327852567716036, 0.007508476419388899, 0.02513866806111764, 0.05726260074879974, 0.042107177068828605, 0.033946562034543604, 0.08045311260502785, 0.0511854280193802, 0.18447520269546658, 6.8637303449213505, 37.83772364258766, 36.00607372820377, 26.438567116856575, 39.849233105778694, 43.74145545065403, 15.075972229242325, 0.728716169251129, 0.1639679109212011, 0.04985916930309031, 0.2515077916905284, 4.470982113853097, 1.7538850684650242, 0.5404390627518296, 1.3566656643524766, 0.5355134583078325, 0.09376653688377701, 0.17919176432769746, 3.357175667770207, 21.459762677550316, 49.62931551039219, 57.27604039013386, 57.459711134433746, 55.174498558044434, 55.6390730291605, 59.10124585032463, 56.26434467732906, 57.372612208127975, 55.84036722779274, 55.50835244357586, 60.02303458750248, 57.6430094987154, 57.24963180720806, 49.95797507464886, 43.876219019293785, 41.69069029390812, 45.34480981528759, 46.94737762212753, 51.31678216159344, 54.77827861905098, 54.5832958817482, 55.626085326075554, 55.19933022558689, 47.97241821885109, 42.01217584311962, 41.89857333898544, 41.568971425294876, 41.62473723292351, 41.747394651174545, 42.43505895137787, 43.78041855990887, 46.2189757078886, 48.12698632478714, 49.799838960170746, 52.32358753681183, 56.13920599222183, 53.35511818528175, 52.42237463593483, 56.18521012365818, 54.58647631108761, 52.02805459499359, 46.350342258811, 43.85952651500702, 40.881052538752556, 39.7445335239172, 38.7637909501791, 39.761096835136414, 41.81011788547039, 39.12775821983814, 37.95809358358383, 41.46876700222492, 43.02890628576279, 50.30782990157604, 52.94044643640518, 51.92030757665634, 53.54892298579216, 53.7560498714447, 53.19793201982975, 53.55986259877682, 53.940700963139534, 52.372582107782364, 53.38199034333229, 46.26305714249611, 39.596770852804184, 40.837275087833405, 45.726495534181595, 48.73685359954834, 50.00441238284111, 49.64678697288036, 50.05191743373871, 50.548581182956696, 49.10834066569805, 48.83703522384167, 51.39005362987518, 48.28589379787445, 50.10729566216469, 48.89900989830494, 36.06524035334587, 15.50779340788722, 4.258965840563178, 2.0519927283748984, 0.8940318203531206, 1.7775739473290741, 2.4273099889978766, 2.0263937395066023, 4.0001375041902065, 7.201561192050576, 1.810746167320758, 0.27294686471577734, 0.1217139333311934, 0.4050393548095599, 7.621099529787898, 32.36933447420597, 30.901608131825924, 23.927726447582245, 32.40575931966305, 14.090564455837011, 0.14315167791210115, 0.08257093490101397, 0.06373886339133605, 0.01346834389551077, 0.027407747475081123, 0.016663566093484405, 0.007631803737240261, 0.07963181487866677, 0.04893511380942073, 0.023198710732685868, 0.13370701752137393, 0.07658977381652221, 0.0387096175836632, 0.00841476072309888, 0.07856260272092186, 0.031342209986178204, 0.07362960648606531, 0.07298024953342974, 0.03265323241066653, 0.035930159501731396, 0.03807852488534991, 0.03523963190673385, 0.014896310240146704, 0.03660184396721888, 0.01398813856212655, 0.007305911849471158, 0.06663487205514684, 0.03600221090891864, 0.021275115905154962, 0.03767277048609685, 0.05510681388841476, 0.02090887715894496, 0.06713496084557846, 0.013358242576941848, 0.03785614775551949, 0.02113373306201538, 0.03152180972392671, 0.059198864037171006, 0.020508800189418253, 0.05877824441995472, 0.06091312498028856, 0.043199933861615136, 0.056782056417432614, 0.03493644231639337, 0.04345754445239436, 0.059166639985051006, 0.01964296247024322, 0.007304697510335245, 0.0299026401626179, 0.09610237990273163, 0.048610357407596894, 0.03225300330086611, 0.06540176400449127, 0.031266240039258264, 0.061369282339001074, 0.0043114243635500316, 0.034081402845913544, 0.040537731401855126, 0.31207906489726156, 12.191235423088074, 45.84155336022377, 33.239358589053154, 27.27375090122223, 49.55361217260361, 47.41817235946655, 11.629551462829113, 0.5201720783952624, 0.11117908768937923, 0.0884552531351801, 0.5801065592095256, 2.195733552798629, 4.0988177340477705, 3.3614889113232493, 2.3952929070219398, 1.4618608821183443, 0.7367680559400469, 0.6176593503914773, 5.502925515174866, 24.875823073089123, 52.038975208997726, 60.21579824388027, 59.67557743191719, 57.65889264643192, 56.961535066366196, 60.61016008257866, 61.31525404751301, 57.93281614780426, 57.744988426566124, 56.048181876540184, 59.63745787739754, 59.8057546466589, 58.28288376331329, 52.420432940125465, 46.72435238957405, 43.882435485720634, 48.05428862571716, 49.14272502064705, 54.61551055312157, 56.54449984431267, 56.52868889272213, 57.77175799012184, 56.48654915392399, 50.139578729867935, 43.36885504424572, 44.29717943072319, 42.69556537270546, 44.12640139460564, 43.0761681497097, 45.472327172756195, 45.14804117381573, 46.551024690270424, 49.485386833548546, 50.98432660102844, 53.99661496281624, 57.127525359392166, 54.34555023908615, 53.06630328297615, 56.851325780153275, 55.57174064218998, 53.46902847290039, 48.032303005456924, 45.761123076081276, 40.911409109830856, 41.94854065775871, 40.15493430197239, 41.33486978709698, 43.0298638343811, 40.99459804594517, 39.88205574452877, 41.71171836555004, 44.67616729438305, 50.36943219602108, 55.41887864470482, 54.80322428047657, 53.99736352264881, 56.35576017200947, 53.11551444232464, 54.107189029455185, 54.7554000467062, 53.84565286338329, 54.62408669292927, 47.668354734778404, 40.96198059618473, 41.765728667378426, 47.42235593497753, 50.15127070248127, 51.07328362762928, 50.72781376540661, 51.288542076945305, 51.93244792521, 50.37629842758179, 51.209479719400406, 51.21157720685005, 49.85181637108326, 51.52035243809223, 49.825187399983406, 38.294896110892296, 16.357305273413658, 5.2695168647915125, 2.3280293913558125, 2.0899377297610044, 4.010470099747181, 2.699646600522101, 4.693036498501897, 5.120259448885918, 3.9261241257190704, 0.5961573135573417, 0.1757407924742438, 0.11779320426285267, 0.4599387792404741, 7.5138650089502335, 36.62216506898403, 41.77460119128227, 25.05041990429163, 35.02300567924976, 20.018969289958477, 0.21633597352774814, 0.07283717088284902, 0.06144659928395413, 0.05298903241055086, 0.038479473878396675, 0.0725701980991289, 0.0666079246730078, 0.03736145437869709, 0.03209957911167294, 0.06724159262375906, 0.059060624189442024, 0.04001547466032207, 0.04349661110609304, 0.029358755382418167, 0.02608918111945968, 0.05829214882396627, 0.04933971787977498, 0.02434059584629722, 0.047643654397688806, 0.041575380018912256, 0.026144972071051598, 0.06393251940608025, 0.03226604654628318, 0.03611797852499876, 0.05342074342479464, 0.035914173640776426, 0.11274825505097397, 0.16645855852402747, 0.1086862655938603, 0.1995880011236295, 0.12007467754301615, 0.17239385488210246, 0.12007914527202956, 0.1598710479447618, 0.11866838933201507, 0.1320870130439289, 0.2816790633369237, 0.17896800680318847, 0.1141490884765517, 0.17300266830716282, 0.17354719690047204, 0.17255452985409647, 0.11920965247554705, 0.11462640075478703, 0.17426706530386582, 0.13687071885215119, 0.09336984410765581, 0.1760718200239353, 0.12133898548199795, 0.20776753721293062, 0.1585992591571994, 0.07522405139752664, 0.13333705690456554, 0.10297460059518926, 0.19240631227148697, 0.10130166614544578, 0.1988468479248695, 0.16239847638644278, 0.33250293927267194, 12.415336947888136, 55.5349700152874, 44.31461289525032, 34.57947827875614, 51.00709117949009, 54.58450801670551, 19.534632079303265, 1.135052174795419, 0.3029503219295293, 0.1907151358318515, 2.322205016389489, 19.83606420457363, 7.862358083948493, 4.986894680187106, 4.278025142848492, 3.7259055068716407, 0.6186938448809087, 0.43324984260834754, 5.173476068302989, 24.93344508111477, 52.39663861691952, 62.14780457317829, 61.4587077498436, 59.27206568419933, 62.46145874261856, 63.53115074336529, 60.97661241889, 58.86246286332607, 59.48388151824474, 56.84875711798668, 62.5842909514904, 61.189685985445976, 61.250482723116875, 55.112235099077225, 48.95855650305748, 46.475271955132484, 51.7503958940506, 51.10645204782486, 56.949280723929405, 58.788161650300026, 57.834959998726845, 58.91216039657593, 58.812712132930756, 52.8222119808197, 45.45714698731899, 46.70393608510494, 46.11834950745106, 45.63605658710003, 46.67677894234657, 47.06918008625507, 48.681068792939186, 51.151209846138954, 52.71720841526985, 52.82344691455364, 55.84593012928963, 60.53667202591896, 56.7686802148819, 53.947012424468994, 60.07541097700596, 57.457541450858116, 55.42322181165218, 50.16771242022514, 47.15588763356209, 43.71044151484966, 44.035263285040855, 41.9714230298996, 43.44922073185444, 45.54998740553856, 42.280110865831375, 41.4257875084877, 45.39480373263359, 46.88605651259422, 53.5567619651556, 57.514504194259644, 55.82859545946121, 56.46568827331066, 57.03501172363758, 54.74780425429344, 54.17961314320564, 54.676212295889854, 54.38760258257389, 58.477798104286194, 49.722965285182, 43.2141387462616, 44.85460951924324, 49.80670139193535, 53.14862586557865, 53.62936466932297, 52.86201864480972, 51.771891340613365, 53.209152817726135, 50.220700576901436, 52.01017655432224, 53.27684238553047, 50.40345557034016, 51.157342717051506, 49.99480649828911, 38.37179638445377, 17.438333965837955, 5.006920080631971, 3.219313840381801, 4.6293058432638645, 5.444403430446982, 7.1497519221156836, 6.1567773297429085, 11.619781237095594, 15.904684010893106, 4.561462858691812, 0.9047331742476672, 0.4621947300620377, 0.6740675016772002, 11.361264009028673, 41.95014797151089, 40.907240733504295, 32.148475125432014, 44.689223393797874, 20.75950775295496, 0.3092014911817387, 0.18576282891444862, 0.13720514543820173, 0.09613597692805342, 0.11025375570170581, 0.20373766048578545, 0.09688599879154935, 0.20292664150474593, 0.11298969053314067, 0.2083277696510777, 0.17529544449644163, 0.25841929425951093, 0.12281932518817484, 0.16492050199303776, 0.11265401713899337, 0.15593629970680922, 0.16796508862171322, 0.2343254254083149, 0.12386478862026706, 0.13591794966487214, 0.13173627405194566, 0.11214802827453241, 0.09363039731397294, 0.10930147633189335, 0.17293908109422773, 0.15291161747882143], [0.04392442213429604, 0.03636681321950164, 0.045913960493635386, 0.03101942584180506, 0.03487597954517696, 0.061008954799035564, 0.08069767252891324, 0.03386381999007426, 0.0484315740322927, 0.06602950219530612, 0.019544885799405165, 0.12969569448614493, 0.06250282385735773, 0.029422767474898137, 0.019435302128840704, 0.03009458367159823, 0.018486716799088754, 0.06237287379917689, 0.01348583909930312, 0.029135940385458525, 0.09560307036736049, 0.04596153215970844, 0.03801477068918757, 0.040626803966006264, 0.046370555719477125, 0.034311264535062946, 0.010268366386299022, 0.09890443267067894, 0.033945645482162945, 0.07538323465269059, 0.09635045760660432, 0.08968784910393879, 0.07017998534138314, 0.2861455158563331, 11.190865952521563, 44.35223467648029, 32.76740871369839, 24.3395958468318, 37.76369221508503, 41.60690099000931, 16.456603445112705, 0.972741034347564, 0.04591804972733371, 0.05207613139646128, 1.0640497785061598, 3.700184687040746, 1.3183451956138015, 1.511191378813237, 1.8078940641134977, 1.3439082051627338, 0.3245391900418326, 0.3278078755829483, 8.45645572990179, 33.733366280794144, 57.732528895139694, 62.92406111955643, 59.20474849641323, 54.51106935739517, 56.81929349899292, 60.222884863615036, 56.36930264532566, 54.5008859038353, 55.404382422566414, 59.04960282146931, 59.14064213633537, 55.07289581000805, 47.567382752895355, 43.728254958987236, 46.05872690677643, 48.04928049445152, 49.4435852766037, 50.58568239212036, 55.25452606379986, 57.2491530328989, 56.44156336784363, 58.302266523242, 52.55719520151615, 47.68343612551689, 42.867604941129684, 42.31282711029053, 43.933056369423866, 42.3768612742424, 44.64558273553848, 47.50062793493271, 54.88713517785072, 51.78476884961128, 56.311629340052605, 53.45053866505623, 60.77987417578697, 50.79515375196934, 49.56249609589577, 58.87938715517521, 53.981149792671204, 54.358355551958084, 51.74735605716705, 48.748682364821434, 42.983669713139534, 44.28524807095528, 39.80771653354168, 42.37952873110771, 41.20658487081528, 38.31929460167885, 41.2778614461422, 43.291441798210144, 49.772560223937035, 52.16371491551399, 53.652558624744415, 55.683925822377205, 55.68270228803158, 50.32609172165394, 52.8577134758234, 50.99409967660904, 53.09401899576187, 53.196871876716614, 53.14486026763916, 49.25446182489395, 41.9547913223505, 40.24138726294041, 46.393146961927414, 50.82962930202484, 51.592472568154335, 50.147391110658646, 50.82161173224449, 50.054983869194984, 48.66608239710331, 49.48541723191738, 51.10075235366821, 53.125131726264954, 50.287877172231674, 39.77894827723503, 18.523204252123833, 3.9334477577358484, 1.1561684729531407, 1.7880666092969477, 1.8946899566799402, 3.9109059423208237, 1.265248863492161, 2.1307142917066813, 3.213623408228159, 1.8040312151424587, 0.09825208486290649, 0.031528173640253954, 0.1652399223530665, 7.153584491461515, 30.63314113765955, 40.16850337386131, 26.768932789564133, 30.198805443942547, 25.1031743735075, 2.1911932714283466, 0.06860419802251272, 0.04761066593346186, 0.06019298940373119, 0.019636383331089746, 0.022610907508351374, 0.021281785957398824, 0.029723053412453737, 0.06611948017962277, 0.0759011424088385, 0.12898709188448265, 0.06527372126583941, 0.033941010769922286, 0.1244782998401206, 0.04124222992686555, 0.05487143433128949, 0.018997388615389355, 0.04940170205372851, 0.014874200733174803, 0.051662621553987265, 0.03595488415157888, 0.09423352588783018, 0.023726902800262906, 0.018415440936223604, 0.04093550771358423, 0.037526285377680324, 0.011596130734687904, 0.03584996302379295, 0.05989218581817113, 0.12072603829437867, 0.05880781158339232, 0.03674423984193709, 0.06463170415372588, 0.03162247463478707, 0.03481148691207636, 0.041640815179562196, 0.04648963331419509, 0.05090521903184708, 0.026825712593563367, 0.02868992818548577, 0.002657893828654778, 0.040462459073751234, 0.013331207064766204, 0.04423173064424191, 0.03986644027463626, 0.04995068353309762, 0.030328772081702482, 0.027599908062256873, 0.049224588510696776, 0.09093538450542837, 0.02368271347222617, 0.01691384612058755, 0.041008134285220876, 0.036644294814323075, 0.044220001000212505, 0.04734342226583976, 0.09460549030336551, 0.028127955411036965, 0.057647753128549084, 0.13232737983344123, 0.5420380644500256, 18.967787995934486, 49.865241050720215, 30.787080377340317, 28.470399789512157, 51.63562685251236, 47.16183051466942, 14.31977765634656, 0.8055618801154196, 0.06705867548589595, 0.09313306931289844, 0.4431275313254446, 3.134736316278577, 5.034465752542019, 2.981811622157693, 1.798588482197374, 2.2166348062455654, 0.8034094143658876, 0.6999201863072813, 10.26555385440588, 38.04844133555889, 58.67511011660099, 62.85124942660332, 59.59673546254635, 57.41414777934551, 59.065679758787155, 61.687577068805695, 58.29224646091461, 55.76815590262413, 57.281010523438454, 61.41893528401852, 59.823176711797714, 58.19555304944515, 48.9875603467226, 44.08838823437691, 47.34150007367134, 48.969518914818764, 51.54423415660858, 53.96122746169567, 55.91206178069115, 56.821698769927025, 56.84656463563442, 58.49247291684151, 54.98084954917431, 49.12823639810085, 43.016659542918205, 43.35959494113922, 45.37297770380974, 44.744670018553734, 45.040104165673256, 50.524030700325966, 56.571440398693085, 54.538332894444466, 58.05331148207188, 55.490083023905754, 61.16603225469589, 54.50908966362476, 52.197658494114876, 60.126259848475456, 54.53197203576565, 57.103153467178345, 53.81901629269123, 49.12867717444897, 44.240877851843834, 43.45352590084076, 42.014820501208305, 43.42469684779644, 43.73657651245594, 39.972673282027245, 41.816296353936195, 45.13861387968063, 50.49463167786598, 54.96910437941551, 55.054611191153526, 57.14742109179497, 54.872996136546135, 52.320646494627, 54.28521707653999, 52.987142130732536, 52.754469215869904, 54.834150820970535, 54.21921081840992, 51.303866654634476, 42.07233041524887, 41.80162914097309, 48.8711915910244, 51.66591502726078, 51.043721213936806, 52.617414370179176, 53.045864179730415, 52.00358010828495, 48.418016508221626, 50.96040688455105, 51.79389975965023, 53.817177191376686, 49.885307773947716, 42.214142605662346, 20.32646968960762, 5.714673427864909, 1.8058230564929545, 2.832054770551622, 2.7867346024140716, 3.7418565759435296, 4.042246844619513, 5.101473731920123, 1.8270336370915174, 0.4599636560305953, 0.05424336217402015, 0.1486658796784468, 0.24322116369148716, 6.382651459425688, 32.77849271893501, 42.992321848869324, 24.92782898247242, 30.111201144754887, 31.945661008358, 3.3183061284944415, 0.0782683040597476, 0.0677236398041714, 0.03800893740844913, 0.019329455171828158, 0.038653103038086556, 0.08061392858508043, 0.030840065446682274, 0.040834401224856265, 0.029049068289168645, 0.05998020453262143, 0.04368254878500011, 0.04901100583083462, 0.04488922895689029, 0.03609920589951798, 0.007036762717689271, 0.027988344445475377, 0.034991246211575344, 0.012737341421598103, 0.01923733052535681, 0.03964542869653087, 0.056279570490005426, 0.037721889530075714, 0.027752321075240616, 0.03669963305583224, 0.01040400222336757, 0.023130073204811197, 0.15749924787087366, 0.10731537782703526, 0.2714652114082128, 0.1643956106272526, 0.1324721283162944, 0.2621818345505744, 0.12710107199382037, 0.0834612300968729, 0.08700174206751399, 0.22200955892913043, 0.12838158843806013, 0.13527251867344603, 0.1257299244753085, 0.1599957881262526, 0.11556844590813853, 0.17610426672035828, 0.1430310937575996, 0.2041981482761912, 0.12824043194996193, 0.10274782995111309, 0.155988932820037, 0.13758699526079, 0.12461588659789413, 0.14928555814549327, 0.09274664786062203, 0.12429077396518551, 0.1091881503816694, 0.21749078499851748, 0.08347435868927278, 0.3122562897624448, 0.1943644689163193, 0.14178812998579815, 0.2617754344828427, 0.4704868944827467, 20.574108101427555, 59.46835175156593, 42.83185265958309, 32.01315298676491, 48.589630499482155, 53.24286840856075, 23.053007684648037, 1.9681687513366342, 0.23479747585952282, 0.34950248489622027, 1.993676070123911, 11.543127950280905, 7.722941190004349, 5.649839406833053, 4.752929834648967, 3.670682357624173, 1.6385642252862453, 0.6769027432892472, 9.523837454617023, 37.74211697280407, 62.426063641905785, 68.74686107039452, 62.82811626791954, 59.150343015789986, 62.017866745591164, 64.83688607811928, 58.84176157414913, 55.840629413723946, 57.77920179069042, 64.76658225059509, 63.627517372369766, 60.08433669805527, 51.998343989253044, 48.685107976198196, 51.900039464235306, 53.73016186058521, 53.66718403995037, 56.36862248182297, 59.49568748474121, 58.9879435300827, 58.88599880039692, 63.367816507816315, 57.20912978053093, 52.7243672311306, 46.44821360707283, 45.41121505200863, 47.70210452377796, 46.2958911806345, 47.79630146920681, 53.69622968137264, 59.315569549798965, 55.530113875865936, 62.64685079455376, 58.26996065676212, 64.77771565318108, 54.56127606332302, 53.52818749845028, 63.87530207633972, 58.30317847430706, 58.2558786123991, 56.94980889558792, 52.475571781396866, 47.872589975595474, 48.33379402756691, 44.966931492090225, 45.36697022616863, 45.650784596800804, 41.94907262921333, 43.65237683057785, 47.362239360809326, 53.45585837960243, 56.58029392361641, 58.178841546177864, 58.64660404622555, 57.17887960374355, 52.44724430143833, 54.23235051333904, 53.42490904033184, 53.86782847344875, 54.94238801300526, 55.840241834521294, 53.18000838160515, 45.76571322977543, 43.33767011761665, 51.005578860640526, 54.6591854095459, 53.68687458336353, 54.75114427506924, 53.942099288105965, 53.02523888647556, 49.098499193787575, 50.8550613373518, 53.92142079770565, 54.77465361356735, 52.556298449635506, 41.57157048583031, 19.60628293454647, 4.581032283604145, 1.5739913214929402, 3.794935215264559, 4.9190018232911825, 8.253706209361553, 4.77817140519619, 9.44628931581974, 8.865437284111977, 5.004349043592811, 0.8772091730497777, 0.3050358756445348, 0.46749790955800563, 9.733366761356592, 41.486382856965065, 50.740672275424004, 34.57740359008312, 41.33913695812225, 36.29717990756035, 3.454943709075451, 0.14545243961038068, 0.17251277662580833, 0.09028572327224538, 0.14130601601209491, 0.11445603333413601, 0.19573692261474207, 0.09887824970064685, 0.13504978531273082, 0.13754956133197993, 0.20682431204477325, 0.189668188104406, 0.12555474793771282, 0.23880069464212283, 0.13924435945227742, 0.13250464922748506, 0.18519075179938227, 0.10153851515497081, 0.07454511243849993, 0.08575332351028919, 0.12113356642657891, 0.15057437180075794, 0.16058658220572397, 0.09194613769068383, 0.23368363094050437, 0.14442888437770307, 0.05442959300125949], [0.10413832525955513, 0.035662188529386185, 0.030131848761811852, 0.04545017014606856, 0.06435514282202348, 0.015081937144714175, 0.032011085422709584, 0.022323739030980505, 0.02798563746182481, 0.019113154376100283, 0.01152137883764226, 0.08877367159584537, 0.014308999616332585, 0.05447047049528919, 0.04367684909084346, 0.054120796485221945, 0.11423826494137757, 0.07090910090482794, 0.016067901669885032, 0.05743263791373465, 0.04552719765342772, 0.026516645193623845, 0.09024319821037352, 0.02521083821193315, 0.047939292635419406, 0.02177363319788128, 0.04281573885236867, 0.017468970727350097, 0.024470384487358388, 0.06502488657133654, 0.021986560932418797, 0.025804354118008632, 0.09146620563114993, 0.1735843191272579, 0.6833616248331964, 17.865130864083767, 40.93250937759876, 30.971725769340992, 27.621341049671173, 33.783063814044, 42.14817814528942, 21.208784244954586, 2.7305277809500694, 0.14725855988217518, 0.8273487235419452, 1.7557772481814027, 4.256088919937611, 2.4772426346316934, 0.8895846933592111, 1.2975586485117674, 0.3956919751362875, 0.016725750647310633, 3.685976774431765, 17.82373208552599, 40.65852127969265, 59.02372620999813, 57.94392675161362, 58.56988236308098, 60.39207838475704, 61.07508793473244, 55.166849568486214, 54.38431195914745, 56.68751657009125, 57.3589139431715, 59.2550577968359, 53.5187754034996, 47.81729154288769, 45.92229522764683, 47.64891117811203, 49.17622022330761, 49.81849975883961, 51.575065702199936, 54.868915155529976, 54.84435707330704, 58.434803411364555, 56.39022812247276, 52.9562383890152, 49.937744960188866, 49.164733439683914, 43.37200507521629, 43.13443802297115, 41.095988005399704, 44.05396208167076, 52.37584613263607, 56.486872136592865, 54.906191155314445, 54.287671744823456, 54.86215531826019, 56.5725689381361, 49.59498815238476, 47.13474176824093, 58.47022131085396, 56.39280818402767, 56.903496980667114, 53.28113995492458, 53.04532840847969, 48.42863693833351, 48.544876500964165, 43.99547941982746, 41.71592853963375, 39.19608235359192, 39.93329979479313, 41.301423981785774, 50.31780056655407, 55.743001252412796, 52.6327845454216, 54.137982577085495, 55.73205403983593, 53.38780403137207, 51.20889075100422, 52.442547753453255, 53.87999162077904, 54.39223073422909, 55.42732559144497, 51.50364853441715, 46.44780322909355, 41.47471748292446, 40.80330491065979, 48.766374215483665, 52.012357637286186, 51.94996498525143, 51.53499685227871, 50.69349780678749, 49.57141801714897, 50.66261686384678, 49.35357190668583, 52.19617657363415, 48.52449059486389, 38.826590180397034, 23.472744561731815, 5.298208650201559, 0.853384688962251, 1.6772937658242881, 1.944006560370326, 1.118196516763419, 2.5381799647584558, 2.60148243047297, 4.435081640258431, 2.1270137652754784, 0.4759365145582706, 0.08594510931288823, 0.24654108710819855, 10.384069494903088, 33.681126683950424, 34.99334067106247, 48.31375390291214, 26.460554637014866, 33.32516938447952, 7.5827401131391525, 0.042109069545404054, 0.11179060995345935, 0.043664885670295916, 0.05365394848922733, 0.053685474922531284, 0.04780142386152875, 0.06930094852577895, 0.03085941880272003, 0.043691417449736036, 0.020810006390092894, 0.04303057576180436, 0.0437218566366937, 0.03538308163115289, 0.05188731047383044, 0.030675687157781795, 0.004782770702149719, 0.021420497068902478, 0.06047944727470167, 0.06595860482775606, 0.014064621518627973, 0.0258334871250554, 0.07023906771792099, 0.022726743773091584, 0.03763903245271649, 0.022140181790746283, 0.03620196737756487, 0.06928477712790482, 0.1054930045211222, 0.03293383102572989, 0.03516909077006858, 0.05310198728693649, 0.042676682642195374, 0.06077128571632784, 0.08033424281165935, 0.04558015731163323, 0.045523371882154606, 0.050603777199285105, 0.017217221247847192, 0.03357879075338133, 0.028572859955602325, 0.04085265063622501, 0.02246817952254787, 0.011066999850299908, 0.07469836593372747, 0.013698901348107029, 0.07124102645320818, 0.03656564571429044, 0.024685700082045514, 0.05980948088108562, 0.028130833088653162, 0.04238505942339543, 0.03760139072255697, 0.008937803213484585, 0.06919681036379188, 0.12046344418195076, 0.054335770691977814, 0.037489070382434875, 0.03404598384804558, 0.06069445487810299, 0.016485877386003267, 0.16507764434209093, 1.6467416239902377, 26.009978614747524, 44.194486141204834, 26.868742033839226, 27.213655225932598, 47.583349496126175, 52.048440501093864, 20.80685131251812, 1.8514914996922016, 0.2355514682130888, 0.17406401369953528, 0.4938451020279899, 1.0386556223966181, 4.925477625802159, 4.281150950118899, 3.5079964622855186, 1.2796800141222775, 0.4635165544459596, 4.856871357187629, 20.967453494668007, 45.15737347304821, 61.29244767129421, 58.51945146918297, 60.273555144667625, 61.015575528144836, 62.03654654324055, 56.421975418925285, 55.51120989024639, 58.189895153045654, 58.42991687357426, 61.55784823000431, 55.530079677700996, 48.83738860487938, 48.258945643901825, 50.53895249962807, 52.15638890862465, 53.804064095020294, 54.396448507905006, 57.04753965139389, 56.669763922691345, 57.62823969125748, 56.94798119366169, 55.2935803681612, 51.43491022288799, 50.14490984380245, 43.913863599300385, 44.093677550554276, 44.13976147770882, 46.65900729596615, 55.4643128067255, 59.20522727072239, 56.62610046565533, 56.156958639621735, 55.45713499188423, 58.13732497394085, 49.88505698740482, 49.71107952296734, 60.4570434987545, 58.09390090405941, 57.62580782175064, 55.35041771829128, 54.69696678221226, 49.89257298409939, 50.53834833204746, 46.33217543363571, 41.75907522439957, 41.100019589066505, 41.0212954133749, 42.50929556787014, 50.556606352329254, 55.21870918571949, 55.401125997304916, 54.12078469991684, 56.890661269426346, 53.97532470524311, 52.25981555879116, 53.1183110922575, 55.11956870555878, 54.145323783159256, 56.400229185819626, 53.52390132844448, 47.527363300323486, 43.03558632731438, 41.770512610673904, 50.40679559111595, 54.52607475221157, 53.888187780976295, 52.983684316277504, 51.5228147059679, 50.07831081748009, 50.43339416384697, 49.797315895557404, 52.08653725683689, 50.421975776553154, 42.96195387840271, 25.380054116249084, 7.770830020308495, 1.6843909537419677, 2.022256711497903, 2.42196177598089, 2.975543146021664, 3.729434092529118, 4.0377697348594666, 4.2371222376823425, 0.15212577214697376, 0.1071728186798282, 0.021774944943899754, 0.6220779789146036, 8.511206991970539, 37.408692464232445, 42.90635906159878, 49.974481388926506, 28.543163985013962, 38.2318726927042, 11.49129968136549, 0.11804902998846956, 0.09100183640839532, 0.024892861329135485, 0.08160352314007469, 0.007035541884761187, 0.07263904713909142, 0.013468329052557237, 0.03882150005665608, 0.017942999002116267, 0.05237929872237146, 0.007087201393005671, 0.032516265346203, 0.031256499351002276, 0.009346148635813734, 0.07636711467057467, 0.13643068465171382, 0.012642760266317055, 0.05486781265062746, 0.008068970928434283, 0.00527268047335383, 0.014609368117817212, 0.03191401621734258, 0.02215125463408185, 0.014136015197436791, 0.025114789459621534, 0.058999322791351005, 0.029541162293753587, 0.4252586339134723, 0.1601267178193666, 0.14685156609630212, 0.20834460156038404, 0.174069520435296, 0.16452354204375297, 0.12312839258811437, 0.09867334272712469, 0.11335036688251421, 0.19359413447091356, 0.05572936075623147, 0.1354851885116659, 0.138276316865813, 0.1817756553646177, 0.2253654765081592, 0.17328391259070486, 0.1539669811609201, 0.18771147122606635, 0.1236651063663885, 0.18082683440297842, 0.1262826463789679, 0.16874695604201406, 0.28297330951318145, 0.12245003992575221, 0.0736696453532204, 0.14536706294165924, 0.14871204126393422, 0.15853320801397786, 0.18488503148546442, 0.17793839564546943, 0.11151555518154055, 0.10951114789349958, 0.12993696669582278, 0.2278579497942701, 1.4549198420718312, 25.789911523461342, 56.02249525487423, 38.05047042667866, 36.313135251402855, 45.36002419888973, 54.31846909224987, 26.66980180889368, 3.7564867408946157, 0.3773597104009241, 1.2353298626840115, 4.153698664158583, 12.59728068485856, 9.617703817784786, 2.963077202439308, 4.794819736853242, 1.1286834790371358, 0.26042615063488483, 4.843970099464059, 21.675627194344997, 44.45107877254486, 61.909074783325195, 61.34340673685074, 64.20771583914757, 64.7031332552433, 63.1930410861969, 56.55585363507271, 55.626016929745674, 59.24867033958435, 61.101386323571205, 64.6928434073925, 60.08540064096451, 52.845573127269745, 51.43199197947979, 52.84034080803394, 55.47173000872135, 54.563559740781784, 55.8832935243845, 59.25537697970867, 57.799021527171135, 60.446027889847755, 59.66965734958649, 57.14265234768391, 54.185069650411606, 54.19362299144268, 46.837343126535416, 46.77316837012768, 46.046366170048714, 48.72565560042858, 58.41713435947895, 60.00054359436035, 58.72342072427273, 57.48828560113907, 57.61198416352272, 57.92680487036705, 53.57737585902214, 52.24169813096523, 60.36984197795391, 59.295905604958534, 60.73161296546459, 56.53859496116638, 57.23819822072983, 52.78115138411522, 53.463663160800934, 49.44940656423569, 44.11104641854763, 41.63495108485222, 43.44823658466339, 45.414923653006554, 54.7194729745388, 59.43101115524769, 57.26395323872566, 55.72758547961712, 57.576623260974884, 55.483961552381516, 52.67611362040043, 53.57036903500557, 56.08873710036278, 55.308015793561935, 56.670159101486206, 55.9498355537653, 50.485432371497154, 45.40435642004013, 44.327213019132614, 52.723858058452606, 55.980009734630585, 56.76501341164112, 53.947905376553535, 53.92055444419384, 51.702047288417816, 50.58401808142662, 50.087715312838554, 53.67232896387577, 50.88916450738907, 41.294831335544586, 24.51552450656891, 7.15908327139914, 0.9993365197442472, 4.360158685594797, 3.9799328008666635, 4.5099228993058205, 7.021470330655575, 5.132641084492207, 14.20707855373621, 6.504632513970137, 1.7233136901631951, 0.33396235783584416, 0.7772433653008193, 13.888929225504398, 43.91918331384659, 44.012529104948044, 57.661115527153015, 33.744815066456795, 45.06704851984978, 11.973473858088255, 0.1971095395856537, 0.27736142626963556, 0.1885970018338412, 0.17797820444684476, 0.1506382558727637, 0.30716518638655543, 0.13901926606195047, 0.2030171241494827, 0.08720399215235375, 0.12843778386013582, 0.11331973102642223, 0.1076844849740155, 0.13715945882722735, 0.23091604351066053, 0.17952755646547303, 0.25404089014045894, 0.07947787860757671, 0.20565813087159768, 0.0769683433463797, 0.1328823430230841, 0.10271108621964231, 0.14234813977964222, 0.11443314549978822, 0.15373148286016658, 0.12387647744617425, 0.1027361411252059, 0.13580595958046615], [0.03393311060790438, 0.034347800465184264, 0.0326271681842627, 0.0268824293743819, 0.023982528146007098, 0.04995288029022049, 0.021599399187834933, 0.02848046256985981, 0.060860632875119336, 0.008804562658042414, 0.011808470317191677, 0.03684551702463068, 0.06301865360001102, 0.04137992058531381, 0.07216157158836722, 0.05633066364680417, 0.06619110485189594, 0.06563292816281319, 0.03168036215356551, 0.0497504372469848, 0.0013348279708225164, 0.04765398880408611, 0.0362170329754008, 0.08103630709229037, 0.038858826374053024, 0.03130499870167114, 0.04260837537003681, 0.03219571321096737, 0.03638714806584176, 0.09749628909048624, 0.06948470429051667, 0.03801263330387883, 0.06850131409009919, 0.08543162475689314, 0.12118114551412873, 1.2342896685004234, 20.185274966061115, 43.265219405293465, 33.58168222010136, 24.49222795665264, 31.838046982884407, 41.30560755729675, 22.658288665115833, 4.081085035577416, 0.25820487295277417, 0.205487689236179, 1.555172000080347, 2.1586123947054148, 4.011060018092394, 3.5717655904591084, 1.9279279606416821, 0.31936668790876865, 0.5646559351589531, 5.047986377030611, 23.05235031992197, 46.87329299747944, 57.22789317369461, 57.56583943963051, 59.10485565662384, 59.11719359457493, 54.89839017391205, 59.072591587901115, 57.918962091207504, 59.64859127998352, 58.98360796272755, 55.38779251277447, 52.098434418439865, 50.21280840039253, 50.98298907279968, 51.98410615324974, 49.44918617606163, 49.73709672689438, 53.73420484364033, 51.83173052966595, 53.38570274412632, 54.29346263408661, 56.09050780534744, 52.72498659789562, 50.29833801090717, 47.46088206768036, 43.516610115766525, 42.46027059853077, 42.22621835768223, 50.37372216582298, 57.377285957336426, 55.53167559206486, 59.0743812918663, 53.841093108057976, 58.7334293872118, 52.475313395261765, 46.6788574308157, 57.72417314350605, 57.81069070100784, 57.29264549911022, 55.677477568387985, 56.24557368457317, 52.26949363946915, 48.663376942276955, 46.669654324650764, 42.73318715393543, 40.73579393327236, 40.07640391588211, 44.46493282914162, 52.1524865180254, 55.922461822628975, 56.14846229553223, 52.92935863137245, 55.7388860732317, 52.76192061603069, 53.73281791806221, 55.057259649038315, 55.031234845519066, 55.070912316441536, 52.505609169602394, 49.99006815254688, 46.601516380906105, 42.51469127833843, 42.576734349131584, 48.843935653567314, 54.15276758372784, 53.775003254413605, 52.96124652028084, 51.62748008966446, 52.88098722696304, 52.04314738512039, 51.202130913734436, 50.98152615129948, 40.50049535930157, 22.905478700995445, 6.348206307739019, 0.46042441099416465, 0.45212883269414306, 1.3402169407345355, 2.2733215894550085, 2.582925888709724, 1.7918235389515758, 6.719330968335271, 2.6202329993247986, 0.2120286671561189, 0.053286281108739786, 0.5651281191967428, 9.091243967413902, 36.82494878768921, 33.26618134975433, 28.38978711515665, 48.96998628973961, 32.73731432855129, 15.166153740137815, 0.30817435879725963, 0.05716832944017369, 0.05324970436049625, 0.03965454969147686, 0.0511560575250769, 0.041866658139042556, 0.035128198433085345, 0.06316255603451282, 0.004949637041136157, 0.05998126580379903, 0.04132712791033555, 0.0513055149349384, 0.016338167733920272, 0.09359305244288407, 0.027246213467151392, 0.056973174287122674, 0.06973497875151224, 0.03632375752204098, 0.03206340683391318, 0.01308795146542252, 0.026168127078562975, 0.028104807825002354, 0.025949789087462705, 0.0509732479986269, 0.04234797059325501, 0.0546691694034962, 0.08363554574316368, 0.009176656021736562, 0.0716878661478404, 0.04491350089665502, 0.033997321224887855, 0.015866473513597157, 0.02041494819422951, 0.08157215255778283, 0.04152291388891172, 0.07564660802017897, 0.056347621721215546, 0.04256648855516687, 0.02170538715290604, 0.025832125284068752, 0.039680205736658536, 0.045756053732475266, 0.08610204386059195, 0.024023644982662518, 0.04291513097996358, 0.025024627793754917, 0.09286597036407329, 0.07214262455818243, 0.013568718441092642, 0.0979666697094217, 0.03375726242666133, 0.019203989540983457, 0.031177156342891976, 0.018693968959269114, 0.0302825121616479, 0.024836550874169916, 0.046043301990721375, 0.031964515656, 0.08605632014223374, 0.07802091655321419, 0.08586494252085686, 0.017225822739419527, 0.19957526586949825, 2.6970161916688085, 29.28368154913187, 46.490991711616516, 33.53063575923443, 25.548309087753296, 43.376739621162415, 55.890391543507576, 22.589413560926914, 2.4698914540931582, 0.3575271792942658, 0.07908583909738809, 0.4369871795643121, 2.704475191421807, 3.2744818925857544, 5.3222808334976435, 4.955839421600103, 0.4289697582134977, 0.7992679928429425, 7.0866843312978745, 26.089417152106762, 49.60093483328819, 61.822469830513, 60.12993045151234, 61.29277445375919, 59.69105400145054, 56.05755217373371, 59.0367329120636, 58.385683447122574, 61.591655015945435, 60.60577891767025, 56.33236102759838, 52.2857491672039, 51.278096437454224, 51.920018792152405, 53.00875537097454, 52.247960194945335, 51.43514961004257, 55.89659661054611, 53.76716427505016, 55.56206256151199, 55.61989165842533, 56.76244094967842, 54.36569295823574, 51.37857064604759, 49.222513139247894, 46.731207221746445, 43.718436285853386, 45.58060996234417, 52.88601815700531, 59.21257607638836, 57.91071653366089, 59.35846544802189, 52.91711188852787, 56.679077222943306, 52.91048124432564, 47.38093435764313, 59.288378208875656, 58.53048227727413, 58.24425883591175, 58.59561078250408, 57.42670230567455, 53.94660584628582, 51.95238545536995, 48.76413993537426, 44.595862403512, 42.77379937469959, 42.02525854110718, 45.07937125861645, 53.04956518113613, 57.00517192482948, 57.02789090573788, 53.83526422083378, 56.05757497251034, 55.21835200488567, 55.630956664681435, 55.95358595252037, 55.53465463221073, 56.825274378061295, 53.294116258621216, 52.035251408815384, 48.33457678556442, 44.84010569751263, 43.49862568080425, 50.16416721045971, 55.12185998260975, 54.62611958384514, 53.04692432284355, 53.004814982414246, 52.287132292985916, 52.963446602225304, 51.00981183350086, 52.61382736265659, 43.02576385438442, 25.7130416482687, 7.3484784085303545, 2.197710396721959, 1.482897384557873, 2.6663881726562977, 3.2479032687842846, 2.720544054172933, 4.897525375708938, 1.561446413397789, 0.9515560430008918, 0.11153073210152797, 0.10108925605891272, 0.6321286770980805, 7.4298529420048, 41.10396757721901, 42.1244066208601, 30.643881261348724, 52.59110078215599, 35.64138449728489, 22.396437115967274, 0.6169612566009164, 0.07881062847445719, 0.029560465554823168, 0.068397688010009, 0.02067598565190565, 0.023260535344888922, 0.03231387796404306, 0.04827555603696965, 0.026500820749788545, 0.018711348202486988, 0.02854879025107948, 0.04529092380835209, 0.020108071985305287, 0.027790411804744508, 0.05815666234411765, 0.06399822916137055, 0.07606798462802544, 0.043684689881047234, 0.042763877572724596, 0.023495104105677456, 0.023097639495972544, 0.02595739053504076, 0.019985432081739418, 0.08666954192449339, 0.034314841686864384, 0.05125041046994738, 0.05048162340244744, 0.032031271839514375, 0.1813502117875032, 0.13236505124950781, 0.11259500897722319, 0.1409683981910348, 0.11835910670924932, 0.12485175597248599, 0.1311734737828374, 0.14327156444778666, 0.12652690202230588, 0.17450597748393193, 0.12777516472851858, 0.15110528940567747, 0.240852732968051, 0.11624366670730524, 0.25622387300245464, 0.11645946840872057, 0.11634517766651697, 0.25841163529548794, 0.19386693311389536, 0.20869906613370404, 0.1286716791219078, 0.22192207456100732, 0.12913825252326205, 0.10619463835610077, 0.23176427377620712, 0.1443840586580336, 0.14883703377563506, 0.1713884377386421, 0.15949975146213546, 0.26926409045699984, 0.18685155955608934, 0.19322889391332865, 0.20559647324262187, 0.15673102112486959, 0.2537545101949945, 2.218900197185576, 29.79934047907591, 56.62809915840626, 44.08016927540302, 34.87598776817322, 43.290138468146324, 53.360042721033096, 29.698972664773464, 6.38871593400836, 0.6496047705877572, 0.33213379501830786, 3.815964236855507, 7.963122026994824, 11.103013716638088, 11.302814595401287, 6.265674261376262, 1.0874280240386724, 0.8743523200973868, 6.191729754209518, 26.148977056145668, 48.57948884367943, 62.256858721375465, 60.814030542969704, 61.542820036411285, 60.2322893589735, 56.03908136487007, 61.16116851568222, 62.15262271463871, 63.571675568819046, 64.12928804755211, 59.78675566613674, 54.94519606232643, 55.27159854769707, 55.02726025879383, 56.6166465729475, 54.48227070271969, 55.46663448214531, 59.54885423183441, 56.2888989597559, 56.77376054227352, 58.87372545897961, 59.66630972921848, 57.480925396084785, 53.76902997493744, 51.00475050508976, 48.897520378232, 46.27253383398056, 46.92984536290169, 56.7775147408247, 61.853103786706924, 60.760077238082886, 60.84671638906002, 55.61976246535778, 55.60797929763794, 52.62157514691353, 50.83189018070698, 59.11767236888409, 63.491959646344185, 61.701237335801125, 61.594124883413315, 61.3724447786808, 57.57607989013195, 54.54366400837898, 50.50570048391819, 47.731210961937904, 44.74347688257694, 44.850034564733505, 46.89774468541145, 55.18886938691139, 59.051951095461845, 58.47861126065254, 53.84207345545292, 58.93972411751747, 55.268201529979706, 56.98797024786472, 57.4555541574955, 58.80898453295231, 57.662342861294746, 54.77253332734108, 53.5041955858469, 49.96817372739315, 47.41767838597298, 46.299489587545395, 52.638560235500336, 58.167153373360634, 58.24387885630131, 54.84406068921089, 55.45811153948307, 53.51004347205162, 53.12710002064705, 51.36217452585697, 52.65357702970505, 41.7388679087162, 25.069890059530735, 6.872088946402073, 1.1283078929409385, 1.4225891581736505, 2.389162885956466, 6.0175570752471685, 7.17531600035727, 6.523088598623872, 15.46574106439948, 8.63144014030695, 0.5622265592683107, 0.14185912383254617, 0.913560634944588, 11.788011509925127, 47.008991315960884, 44.3857678771019, 36.27672180533409, 56.08997203409672, 44.3960577249527, 24.84276484698057, 0.47458476678002626, 0.23007661511655897, 0.11160966692841612, 0.16014448483474553, 0.124404114758363, 0.11909277905942872, 0.12956136575667188, 0.0980766188877169, 0.1110039408376906, 0.14978018472902477, 0.13663188088685274, 0.1361412915866822, 0.12712989700958133, 0.1371824654052034, 0.13605950691271573, 0.13481842819601297, 0.15391979541163892, 0.10288070407113992, 0.11747182463295758, 0.13252704724436626, 0.1680585992289707, 0.11357721916283481, 0.11179868452018127, 0.1702315779402852, 0.0926350436930079, 0.14803535101236776, 0.13338082877453417, 0.0952380672970321], [0.016576855414314196, 0.026036377312266268, 0.03722259483765811, 0.12258369330083951, 0.058953279949491844, 0.028408711732481606, 0.04835560037463438, 0.020664090880018193, 0.041700602596392855, 0.02080415826640092, 0.05487565715156961, 0.027991162751277443, 0.018957743086502887, 0.0710887971217744, 0.04890085256192833, 0.029285974815138616, 0.051742643627221696, 0.03816645454207901, 0.11467646603705361, 0.05068466758530121, 0.08910790522349998, 0.11298813202301972, 0.01605747820576653, 0.04011364966572728, 0.014565680667146808, 0.046434543692157604, 0.09290719666751102, 0.013712462241528556, 0.044802854099543765, 0.04436325776623562, 0.055749654784449376, 0.011799854910350405, 0.06117896598880179, 0.07934380220831372, 0.028817453276133165, 0.27817048598080873, 1.3812559260986745, 19.407599195837975, 41.60010315477848, 35.03294214606285, 23.876345604658127, 32.83899687230587, 47.91849531233311, 27.496833130717278, 7.93518022634089, 0.42944511864334345, 0.07019299519015476, 3.1920253671705723, 6.175717888399959, 2.70985784009099, 4.818806424736977, 2.1562147233635187, 0.4072431771783158, 0.8269657753407955, 6.065116273239255, 31.768826097249985, 43.819484263658524, 56.96395553648472, 63.447745218873024, 60.37043854594231, 55.58103494346142, 56.78447976708412, 58.63818369805813, 58.61073397099972, 62.33547270298004, 55.411792024970055, 53.42469625174999, 51.09128326177597, 50.177025720477104, 51.97953499853611, 50.029901415109634, 49.9568959325552, 50.031409934163094, 48.48654583096504, 50.80038607120514, 51.80928893387318, 50.009922087192535, 51.08439803123474, 51.04844816029072, 47.935351207852364, 43.644404858350754, 41.96329906582832, 41.91955581307411, 49.077816903591156, 53.131325393915176, 55.68600431084633, 54.36005786061287, 56.934119537472725, 56.4149533957243, 30.916909910738468, 46.18780978024006, 56.7678252607584, 60.01812145113945, 58.59944097697735, 57.93815106153488, 55.42839713394642, 52.10568442940712, 48.893124014139175, 47.783879935741425, 43.19529555737972, 42.30450935661793, 39.43375200033188, 47.49656595289707, 54.74009446799755, 57.441255524754524, 56.965376660227776, 56.721539944410324, 53.87530267238617, 53.865446001291275, 56.1101945489645, 56.571637988090515, 56.754898354411125, 54.04626689851284, 52.00889602303505, 52.00186260044575, 45.74671424925327, 42.44428865611553, 41.88728794455528, 50.20641714334488, 52.981814816594124, 54.71565417945385, 55.536030158400536, 54.11715589463711, 53.95897038280964, 52.009861171245575, 51.23952850699425, 39.04155984520912, 21.01316124200821, 5.953196128830314, 0.3666303330101073, 1.5607198211364448, 1.6561653558164835, 2.3538459185510874, 1.803321128245443, 1.4747263980098069, 4.1540050227195024, 1.368219656869769, 0.8185217971913517, 0.18608854268677533, 0.9829547675326467, 12.471849415451288, 36.294124871492386, 34.46095883846283, 27.097010985016823, 27.58452482521534, 37.84149304032326, 18.508772626519203, 1.7431030282750726, 0.015619086007063743, 0.009789652376639424, 0.07870578527217731, 0.10547577927354723, 0.08997995100799017, 0.0599026389681967, 0.047423514843103476, 0.0480962308938615, 0.03661172195279505, 0.014889234789734473, 0.021115652489243075, 0.014116340862528887, 0.02647141500347061, 0.017735103028826416, 0.041504493783577345, 0.0811875048384536, 0.026721108733909205, 0.021859605440113228, 0.05227466332144104, 0.0648949365131557, 0.006893654381201486, 0.072762236231938, 0.06744981699739583, 0.0358090521331178, 0.02118839038303122, 0.011309895508020418, 0.07069795246934518, 0.09518441744148731, 0.06361778199789114, 0.09554225878673606, 0.034074367285938933, 0.07220867570140399, 0.07957696274388582, 0.0022915558201930253, 0.022438690284616314, 0.048466213775100186, 0.057840362715069205, 0.023314610079978593, 0.03939294634619728, 0.031698095772298984, 0.003112327781309432, 0.03813277588051278, 0.04119835786696058, 0.032424728851765394, 0.04459419928025454, 0.0625656392367091, 0.018562996592663694, 0.03824964558589272, 0.0634892939706333, 0.037523943901760504, 0.04641656516469084, 0.013940414755779784, 0.035156336962245405, 0.031631629026378505, 0.0755837926408276, 0.026298620759916957, 0.04716686162282713, 0.05458458312205039, 0.0617078501090873, 0.042777269627549686, 0.05147354459040798, 0.09426133416127414, 0.015757212677272037, 0.2605136053171009, 3.460365068167448, 28.621947057545185, 45.59836260974407, 34.861134365200996, 22.412837035954, 39.107463508844376, 60.75240544974804, 29.975506626069546, 6.003483105450869, 0.307469645049423, 0.07347624909016304, 0.18276113842148334, 1.84977458557114, 3.7230827333405614, 7.766484003514051, 1.415650136768818, 1.124997439328581, 1.2994315917603672, 8.12552958726883, 35.58189868927002, 46.552423015236855, 59.92028050124645, 65.72401687502861, 61.21659994125366, 55.14093495905399, 57.45862819254398, 59.11143310368061, 61.16533689200878, 64.31556165218353, 55.87169274687767, 54.99654270708561, 54.96412664651871, 53.195636942982674, 53.74934323132038, 51.43160060048103, 51.09337314963341, 54.32096175849438, 52.268942669034004, 52.95279577374458, 52.65048399567604, 53.33347834646702, 54.419634863734245, 52.911602184176445, 50.267434269189835, 46.67334772646427, 45.33051498234272, 44.58162076771259, 51.73944108188152, 55.176892429590225, 57.453441470861435, 56.491640880703926, 59.05890092253685, 57.63491213321686, 33.30209702253342, 49.51907582581043, 56.00800663232803, 61.7647585272789, 59.777677953243256, 59.93594706058502, 56.38610914349556, 56.11749775707722, 51.235143542289734, 48.5813507437706, 43.77991318702698, 43.69385540485382, 42.346550300717354, 48.44155244529247, 56.5865483880043, 58.50973159074783, 56.13979496061802, 56.5716265887022, 55.13096809387207, 54.25158888101578, 56.70381389558315, 56.756167486310005, 56.009199768304825, 54.64031182229519, 52.52881832420826, 51.998568177223206, 47.46886543929577, 45.091674998402596, 43.00926133990288, 52.43064299225807, 54.267912805080414, 57.39391006529331, 56.288955956697464, 52.55278743803501, 54.19768497347832, 52.59734384715557, 52.24276967346668, 40.934629663825035, 23.799451030790806, 7.80798252671957, 1.0719320992939174, 3.022486539557576, 2.681359606795013, 3.4858875861391425, 3.1058635655790567, 4.9420390371233225, 3.7036501010879874, 0.5650986707769334, 0.09937625305610709, 0.10168592794798315, 0.4962115141097456, 10.336407702416182, 38.8137848675251, 43.53096954524517, 29.25499688833952, 28.835938274860382, 43.62406834959984, 27.215891405940056, 3.1805654196068645, 0.03227212102501653, 0.08329343792865984, 0.061551208709715866, 0.09277973280404694, 0.042860353059950285, 0.041766761351027526, 0.05085550255898852, 0.027284422940283548, 0.02823645369062433, 0.020473156691878103, 0.042738102783914655, 0.01592440741660539, 0.07308388303499669, 0.038820624322397634, 0.04994593749870546, 0.059565559204202145, 0.06560958761838265, 0.07123224684619345, 0.04615241625288036, 0.03320561663713306, 0.035783281055046245, 0.018905740798800252, 0.06342763634165749, 0.02921978637459688, 0.017799966735765338, 0.058305715283495374, 0.024965632619569078, 0.05208004622545559, 0.18296138470759615, 0.16529834421817213, 0.1160875559435226, 0.14893296378431842, 0.1690933757345192, 0.19403752317884937, 0.12310142294154502, 0.13021267455769703, 0.13882117200409994, 0.08703145766048692, 0.12085425914847292, 0.13046412903349847, 0.10021804147982039, 0.15216575906379148, 0.14850437350105494, 0.06842730712378398, 0.08773597844992764, 0.15856961777899414, 0.2874509239336476, 0.17037055251421407, 0.12833759392378852, 0.23491141037084162, 0.1502689631888643, 0.16908902674913406, 0.09587376873241737, 0.1784636135562323, 0.14415518031455576, 0.09944568097125739, 0.15585481189191341, 0.17178502661408857, 0.12061773668392561, 0.09849693422438577, 0.22021791053703055, 0.20045778335770592, 0.12932988989632577, 0.29948912328109145, 3.0768150743097067, 29.082064367830753, 54.91056092083454, 47.69198566675186, 33.35116758942604, 39.7372455149889, 60.58680273592472, 38.207462802529335, 11.89332190901041, 0.6221931602340192, 0.3225330461282283, 6.751535190269351, 12.983274422585964, 7.9963840171694756, 10.565215274691582, 6.1264160089194775, 2.1049564238637686, 1.578577437903732, 7.298382371664047, 33.700995817780495, 46.13856442272663, 61.83597810566425, 68.17709684371948, 63.06841917335987, 57.143970876932144, 57.450097650289536, 61.07124634087086, 63.51836822926998, 67.30473965406418, 59.626590460538864, 57.00739860534668, 57.858533933758736, 54.28284600377083, 58.144593983888626, 54.116502329707146, 54.337243884801865, 56.295123025774956, 53.348696529865265, 55.171052142977715, 55.84732845425606, 55.70035234093666, 56.81618146598339, 55.80288603901863, 52.250574454665184, 49.497587978839874, 47.06711299717426, 45.042239651083946, 52.316725105047226, 57.40282818675041, 60.04318870604038, 58.05276431143284, 60.116285383701324, 58.667472526431084, 34.75103907287121, 51.749046966433525, 55.30931152403355, 62.42844231426716, 61.44606202840805, 61.321896091103554, 60.92397004365921, 57.918688505887985, 54.20982912182808, 51.64853096008301, 46.591724306344986, 48.096523359417915, 44.006339237093925, 53.230899050831795, 60.27510926127434, 61.33104220032692, 58.54162707924843, 58.283107951283455, 54.59706634283066, 56.39865607023239, 58.3356287330389, 57.71633416414261, 59.694960191845894, 56.830309107899666, 55.149074122309685, 56.687634363770485, 49.956789538264275, 48.33467938005924, 45.92473089694977, 52.76230439543724, 57.20440663397312, 58.82453329861164, 58.96332465112209, 53.82033862173557, 55.478782430291176, 53.16103219985962, 52.612911611795425, 40.20375408232212, 21.323957964777946, 7.419938798993826, 0.7334180606994778, 4.15343077853322, 5.142355738207698, 5.938517991453409, 4.094357248395681, 7.052404945716262, 12.236809227615595, 5.034557897597551, 1.8525326438248158, 0.5842375312931836, 1.269419020973146, 16.296643428504467, 45.00341713428497, 43.843753561377525, 36.93809151649475, 36.648588851094246, 48.70908088982105, 30.45494969934225, 3.0215130792930722, 0.24016486597247422, 0.146120268618688, 0.09983202078728937, 0.22163213230669498, 0.11367121216608211, 0.21855578175745904, 0.18958671513246372, 0.12443037936463952, 0.17240233020856977, 0.12503439851570874, 0.1357015987741761, 0.08738307980820537, 0.12652126169996336, 0.0690485441009514, 0.12925276590976864, 0.14707217691466212, 0.17677501979051158, 0.1091495735454373, 0.2582125022308901, 0.1286951606743969, 0.1428463138290681, 0.21033993980381638, 0.22067519224947318, 0.23174704110715538, 0.1102804730180651, 0.10969428767566569, 0.12658992520300671, 0.1286022289423272], [0.06234226020751521, 0.018404518377792556, 0.02124436872691149, 0.09029938621097244, 0.06271245089010336, 0.1292828525765799, 0.07756113380310126, 0.048421295286971144, 0.034670133754843846, 0.018759413396765012, 0.015857443431741558, 0.020387939584907144, 0.05696886240912136, 0.027732223716157023, 0.06576531246537343, 0.05998931439535227, 0.02467364574840758, 0.09172537102131173, 0.00836119250379852, 0.035642517905216664, 0.024259926249214914, 0.019166796810168307, 0.08965998888015747, 0.021681015023204964, 0.03372536491951905, 0.030106411650194786, 0.026518507984292228, 0.021757844006060623, 0.014567909893230535, 0.029574683248938527, 0.03910558305506129, 0.061552859988296404, 0.006567142800122383, 0.05450098018627614, 0.04022453023935668, 0.01436612550605787, 0.0981955777388066, 0.9492529509589076, 22.035490684211254, 42.944911792874336, 39.32833805680275, 23.657640740275383, 26.76228504627943, 44.78812448680401, 30.210218131542206, 7.163489609956741, 0.38594831828959286, 0.0909866372239776, 0.4626014269888401, 3.772614737972617, 7.73609465919435, 0.30334342271089554, 1.7035722057335079, 0.11490566350403242, 0.42956956196576357, 9.991887789219618, 29.07913662493229, 43.27734835445881, 53.05756755173206, 60.85488975048065, 56.34096376597881, 55.73934584856033, 58.46170216798782, 56.92197538912296, 59.629292115569115, 56.843179017305374, 56.27456992864609, 54.298003390431404, 53.73243793845177, 49.71603825688362, 48.56859102845192, 47.898531183600426, 48.437087684869766, 45.34433104097843, 46.65731638669968, 47.83986233174801, 50.736883878707886, 48.35493229329586, 49.03235614299774, 47.47271083295345, 46.191947758197784, 41.75403289496899, 45.17600007355213, 41.22021093964577, 48.55567552149296, 52.804333940148354, 57.611258402466774, 55.651870742440224, 60.83177179098129, 47.121172696352005, 39.66239333152771, 61.165580078959465, 60.66219449043274, 61.63077771663666, 56.24105952680111, 55.904693976044655, 51.39002323150635, 48.951143100857735, 47.57053278386593, 43.453256115317345, 41.95409595966339, 41.62187598645687, 45.78350007534027, 55.75916178524494, 53.86496722698212, 57.07752004265785, 56.37632466852665, 54.41091813147068, 57.151217088103294, 59.2893585562706, 55.72315491735935, 55.298238918185234, 52.59864717721939, 50.34507930278778, 49.89002712070942, 48.911260440945625, 46.97682224214077, 45.98128326237202, 49.04572382569313, 53.58580760657787, 55.38300856947899, 56.406050473451614, 54.596359580755234, 52.916849702596664, 50.361057445406914, 32.47648872435093, 15.934748947620392, 4.39126999117434, 0.5143725802190602, 0.5184969026595354, 3.687588362954557, 0.8727868634741753, 2.438478064723313, 3.927697241306305, 3.99298676289618, 3.5656792670488358, 0.24551297508878633, 0.05167544586583972, 0.40454021596815437, 11.791384778916836, 38.59689250588417, 31.19376875460148, 21.203768514096737, 24.9281120672822, 29.86790779978037, 16.550490707159042, 1.862293726298958, 0.037844440375920385, 0.01962650534551358, 0.07176541315857321, 0.04349205431935843, 0.03069612033868907, 0.09529461894999258, 0.04283640766516328, 0.048446060754940845, 0.030786461975367274, 0.048532290893490426, 0.04277512111002579, 0.023386735701933503, 0.013583252475655172, 0.0058632672153180465, 0.042519451235421, 0.04657473538827617, 0.02531602465751348, 0.02101048274198547, 0.02972291797050275, 0.0608545546856476, 0.049939573582378216, 0.06872214013128541, 0.017956146148208063, 0.009410550355823943, 0.039510958958999254, 0.09141223665210418, 0.0206040678313002, 0.012213434329169104, 0.04000481741968542, 0.05959030982921831, 0.04238531175360549, 0.03423137604841031, 0.05808050686027855, 0.02204946351412218, 0.03534030794980936, 0.047153625419014134, 0.07713314465945587, 0.03821165875706356, 0.05693720238923561, 0.019644908752525225, 0.04687821812694892, 0.05917940492508933, 0.051430730090942234, 0.007159130809668568, 0.057204642725992016, 0.04884700974798761, 0.03581491138902493, 0.07323287660256028, 0.04066351801156998, 0.013532271568692522, 0.04864501199335791, 0.017012247481034137, 0.05284677383315284, 0.02052555231784936, 0.015007427373348037, 0.02075874996080529, 0.028397145360941067, 0.05529833993932698, 0.04673725830798503, 0.008225570581998909, 0.04728727137262467, 0.037187647103564814, 0.0900666115921922, 0.018233828122902196, 0.021586114744422957, 0.1564355127629824, 2.6723353285342455, 30.83770126104355, 47.86108039319515, 36.13192297518253, 21.597927063703537, 36.40445575118065, 60.2838221937418, 35.06791166961193, 5.118837850168347, 0.2582280873320997, 0.11002966421074234, 0.38089675654191524, 2.4584315065294504, 3.8997789518907666, 3.172493940219283, 2.415018598549068, 0.24788553215330467, 0.776033605216071, 11.938323844224215, 33.2492570579052, 45.72806105017662, 57.03279264271259, 61.17935813963413, 56.47656708955765, 55.93086317181587, 60.35691127181053, 59.276997819542885, 62.09205776453018, 57.459255158901215, 57.028027698397636, 54.89142894744873, 54.239342138171196, 51.333657056093216, 50.78024335205555, 51.00217044353485, 49.81978788971901, 48.167199566960335, 47.985637709498405, 51.13227926194668, 52.82614476978779, 51.21696911752224, 51.34145803749561, 49.86502066254616, 48.90329986810684, 43.65860089659691, 46.78455635905266, 44.150693491101265, 49.349699914455414, 55.634961649775505, 59.60095323622227, 56.87583826482296, 63.5513998568058, 46.80916003882885, 42.49010659754276, 59.59387421607971, 62.29973562061787, 62.813395857810974, 59.26074229180813, 57.159466445446014, 54.58143398165703, 50.9672237187624, 49.672899171710014, 44.186973944306374, 43.15906450152397, 43.58212999999523, 48.10325659811497, 56.11035034060478, 56.73439845442772, 55.90029001235962, 55.19595980644226, 55.75397506356239, 58.336772471666336, 59.17360536754131, 58.33534374833107, 55.8008873462677, 54.227190390229225, 51.38128750026226, 51.107793375849724, 50.65883606672287, 47.305804789066315, 47.02706314623356, 53.00116717815399, 55.592840909957886, 56.59483954310417, 56.60756126046181, 56.260324493050575, 52.97948554158211, 50.63158392906189, 36.913989409804344, 19.633485674858093, 7.717116577550769, 1.8294917489401996, 1.8366353656165302, 3.8006857316941023, 3.464688048698008, 2.6806789683178067, 5.279087126255035, 3.011124674230814, 0.1880760586936958, 0.18975325307110325, 0.024165267168427818, 0.3683747659670189, 10.772478953003883, 43.02365496754646, 41.1687882989645, 24.227165579795837, 25.712249390780926, 33.448035791516304, 25.21502137184143, 4.222926199436188, 0.0954514421755448, 0.026438957174832467, 0.019373817049199715, 0.0403676979476586, 0.01561439006763976, 0.04909102790406905, 0.04710461769718677, 0.07585843181004748, 0.030125219527690206, 0.02603551827633055, 0.01897715210361639, 0.004435413584360504, 0.020812761613342445, 0.019355973963683937, 0.016370900157198776, 0.030111061205388978, 0.05619774128717836, 0.06278011249378324, 0.030441545131907333, 0.06119750483776443, 0.04143061669310555, 0.05800872633699328, 0.0431994329119334, 0.02142444714991143, 0.0375904514658032, 0.08097755126073025, 0.07759113141219132, 0.02635248954902636, 0.043446523559396155, 0.08709005764103495, 0.09457181164179929, 0.14688325580209494, 0.1745790196582675, 0.09759620443219319, 0.2045729773817584, 0.188297203858383, 0.16003849130356684, 0.1405429100850597, 0.13144417956937104, 0.12102018110454082, 0.13823744317051023, 0.08751447705435567, 0.12549576204037294, 0.1579145685536787, 0.1743016642285511, 0.11164915660629049, 0.14566426340024918, 0.1455655726022087, 0.15435855311807245, 0.11607806387473829, 0.110976852447493, 0.3028324985643849, 0.0813564844429493, 0.09762759727891535, 0.07843243743991479, 0.10454540068167262, 0.08251618666690774, 0.13983081938931718, 0.1299820002168417, 0.16273066168650985, 0.10619137290632352, 0.1629064467852004, 0.19315782585181296, 0.22054484143154696, 0.08286540425615385, 0.2233344261185266, 1.8943147268146276, 31.60857729613781, 58.12444746494293, 51.56527742743492, 31.39140944927931, 35.39646103978157, 55.409990921616554, 41.3488682359457, 8.453161306679249, 0.5762824800331146, 0.21269983582897112, 1.859847845043987, 9.721735585480928, 18.116512075066566, 3.008560761809349, 3.099356652237475, 0.9918169013690203, 0.935546433320269, 12.159319035708904, 33.15185308456421, 47.804976403713226, 54.666830599308014, 61.45647346973419, 56.225415766239166, 56.38858661055565, 62.5687687844038, 62.478827610611916, 63.7063517421484, 59.942140728235245, 60.85271626710892, 59.01121728122234, 58.12019169330597, 54.737499207258224, 52.16899663209915, 53.57824221253395, 52.65741862356663, 50.56703299283981, 50.187281370162964, 53.338535875082016, 55.53906239569187, 51.91378332674503, 52.80450113117695, 52.76600919663906, 51.43871381878853, 45.73722995817661, 49.0087404102087, 45.23384436964989, 51.47728934884071, 58.96946892142296, 62.51163884997368, 60.1560540497303, 66.61013692617416, 53.76716427505016, 45.52720382809639, 60.62630161643028, 63.387085273861885, 65.65847799181938, 63.434575125575066, 59.84728641808033, 58.59818324446678, 53.39064247906208, 54.20224852859974, 47.09755316376686, 45.91401547193527, 45.290499329566956, 49.11989204585552, 59.42324057221413, 57.52676613628864, 57.61710628867149, 55.18726207315922, 56.53501935303211, 60.396258160471916, 63.24334278702736, 59.88817222416401, 58.14715124666691, 56.87815614044666, 53.771530240774155, 53.02880309522152, 52.28892579674721, 51.419494450092316, 49.268304482102394, 55.30283287167549, 57.43447668850422, 60.137758031487465, 57.48853638768196, 55.6725188344717, 52.61819712817669, 51.77741624414921, 34.85842891037464, 17.57694862782955, 5.561095643788576, 1.1171614285558462, 1.9125474547035992, 6.092490004375577, 2.676507979631424, 6.461386559531093, 9.731574207544327, 9.66884147375822, 8.759021144360304, 0.7658651727251709, 0.13495289051206782, 0.8976818807423115, 15.873805917799473, 46.93324998021126, 41.165611669421196, 30.111180245876312, 34.001118913292885, 41.73724539577961, 26.282412596046925, 4.011132689192891, 0.11198856300325133, 0.11116106834379025, 0.14956876169890165, 0.22243497282033786, 0.18308787635760382, 0.16082962072687224, 0.09797487044124864, 0.17463380499975756, 0.09522248219582252, 0.1564924354897812, 0.2021816885098815, 0.10591159807518125, 0.079051997163333, 0.0323198448313633, 0.11057606301619671, 0.1497278336319141, 0.10494218993699178, 0.14388667128514498, 0.11832819625851698, 0.14011887658853084, 0.20809190027648583, 0.13711083331145346, 0.20376899396069348, 0.118157955002971, 0.16468948626425117, 0.3153148584533483, 0.11195058730663732, 0.09966268495190889, 0.14287438185419887], [0.034660378223634325, 0.0022938117172088823, 0.052177813049638644, 0.059187932201894, 0.013210263896326069, 0.029691860945604276, 0.008891459801816382, 0.05646390141919255, 0.02424735426757252, 0.007963702846609522, 0.02144104157196125, 0.010682057127269218, 0.09134821899351664, 0.0736373545078095, 0.05302189842041116, 0.024272175396617968, 0.047601904880139045, 0.046300508111016825, 0.04310788899601903, 0.05553756382141728, 0.08031499150092714, 0.04080710874404758, 0.02907749811129179, 0.07740036235190928, 0.03314292371214833, 0.04570922421407886, 0.04152819798036944, 0.027263546326139476, 0.021531741294893436, 0.044266637560212985, 0.056064021118800156, 0.030525014481099788, 0.012838244747399585, 0.03073167106776964, 0.06638683145865798, 0.023774379842507187, 0.03658594716398511, 0.10448855959111825, 0.9480703237932175, 13.902853578329086, 38.93014222383499, 36.17617540061474, 20.990913435816765, 32.326529771089554, 49.24968548119068, 32.65160992741585, 7.590560568496585, 0.6215353799052536, 0.007605621694892761, 1.6997422487474978, 1.9030719506554306, 3.5912366956472397, 2.947266725823283, 0.44933155935723335, 0.09641693177400157, 0.388554681558162, 6.949067115783691, 24.03367806226015, 41.7788265645504, 52.48843029141426, 60.69019518792629, 53.01872603595257, 55.96762999892235, 53.09097155928612, 61.43644094467163, 64.26934853196144, 58.51341739296913, 55.7610996812582, 56.23927742242813, 54.301879182457924, 53.04665073752403, 51.83799259364605, 47.737480625510216, 44.47455391287804, 47.14660473167896, 46.63213513791561, 48.63428570330143, 49.24543350934982, 50.074742808938026, 47.50253923237324, 46.50130055844784, 44.39539276063442, 45.903710424900055, 45.805592089891434, 46.1509707570076, 50.04631653428078, 54.141428992152214, 53.73248353600502, 62.009472995996475, 51.07367880642414, 40.06733760237694, 61.71670250594616, 58.73197786509991, 58.34104724228382, 55.382670387625694, 56.150346994400024, 47.507269978523254, 46.90880969166756, 43.19448620080948, 43.37534509599209, 43.04621435701847, 43.47484275698662, 51.13113172352314, 55.15746407210827, 56.8118990957737, 56.93620182573795, 52.85547159612179, 56.62826634943485, 55.33434838056564, 56.91841498017311, 54.450808390975, 53.96611399948597, 49.592833667993546, 51.2364848703146, 50.81455931067467, 47.50954605638981, 50.52281856536865, 50.44141933321953, 51.16679660975933, 54.045069962739944, 55.7846774160862, 56.86251237988472, 55.48073552548885, 45.230044573545456, 29.43056456744671, 11.317157875746489, 2.77179095428437, 0.5525414133444428, 0.5849927407689393, 1.4525193208828568, 2.3869105568155646, 5.519561972469091, 1.5052639343775809, 2.4030941259115934, 3.2449980871751904, 0.7703584316186607, 0.1845363705069758, 1.2700634426437318, 15.952455997467041, 37.376527190208435, 29.62181780487299, 20.41416708379984, 29.386984705924988, 31.219164691865444, 12.799996007233858, 1.1132320831529796, 0.14586413861252367, 0.011969704682996962, 0.04265657415089663, 0.02589679046650417, 0.008542386003682623, 0.057918893071473576, 0.013328918466868345, 0.0433883725781925, 0.06283233742578886, 0.06673115087323822, 0.032328253364539705, 0.026028009597212076, 0.06517029556562193, 0.044672328876913525, 0.08458569514914416, 0.0232582829266903, 0.0877427394152619, 0.026323028141632676, 0.024862299687811173, 0.01664331473875791, 0.0486887244915124, 0.11431167818955146, 0.019231823789596092, 0.006104945287006558, 0.04975961761374492, 0.006419679448299576, 0.023605244386999402, 0.08489027255563997, 0.02423030342470156, 0.020910305793222506, 0.05553493661864195, 0.04821304122742731, 0.05640513445541728, 0.0311905409762403, 0.015095285598363262, 0.06225259021448437, 0.03669737321615685, 0.013076025152258808, 0.01083558800019091, 0.04866171031608246, 0.013356729523366084, 0.008526130186510272, 0.034643679900909774, 0.02732525590545265, 0.006872754111100221, 0.015012152998679085, 0.025391079907421954, 0.033165006316266954, 0.0710466579766944, 0.02100923036778113, 0.04783482050697785, 0.0492372866574442, 0.0573458474536892, 0.05306294289766811, 0.043262281687930226, 0.07080415380187333, 0.050604819916770793, 0.041014594680746086, 0.03347509788000025, 0.04529865698714275, 0.03880000003846362, 0.015359089411504101, 0.020382128568599, 0.033353945982526056, 0.016700838605174795, 0.012479877404985018, 0.04070342329214327, 0.009727469678182388, 2.8280402859672904, 23.86248964816332, 46.52512528002262, 34.00830812752247, 16.148584373295307, 39.990509524941444, 62.359958589076996, 35.50246015191078, 5.919868117198348, 0.23025566566502675, 0.09412349507329054, 1.0443167248740792, 0.7538892247248441, 3.4995036805048585, 4.536072621122003, 0.6431690440513194, 0.3982098150299862, 1.174446085933596, 8.149498701095581, 26.905757747590542, 44.49182778596878, 55.564361438155174, 59.39405053853989, 55.23211866617203, 56.314627379179, 56.24777376651764, 63.82199853658676, 63.68547946214676, 61.3581233471632, 57.91537508368492, 58.36596630513668, 56.18048317730427, 54.66155268251896, 53.459262996912, 49.10402029752731, 45.41772410273552, 49.19414006173611, 47.75960683822632, 50.60553252696991, 52.001953795552254, 51.673936396837234, 50.26622213423252, 48.29542748630047, 46.155101135373116, 47.69651882350445, 46.24704100191593, 48.43809463083744, 50.649021193385124, 57.58317410945892, 55.908508971333504, 63.09535212814808, 53.052175641059875, 42.185716331005096, 60.40305599570274, 60.757136195898056, 60.08650258183479, 58.882111608982086, 57.64663450419903, 50.17865963280201, 48.86228106915951, 44.81342352926731, 45.89660480618477, 44.671824127435684, 45.617650374770164, 52.89639160037041, 58.2996978610754, 59.33185547590256, 56.04942061007023, 55.43855778872967, 59.00501221418381, 57.538739293813705, 57.90428727865219, 55.11539652943611, 55.40564775466919, 51.36342465877533, 52.05815277993679, 52.013402581214905, 49.28598113358021, 51.936844289302826, 51.475868225097656, 53.03546033799648, 55.52232429385185, 56.27930827438831, 56.80366113781929, 55.50440065562725, 48.893785178661346, 32.52164930105209, 15.07709601894021, 4.2613668367266655, 1.3350979029200971, 2.43995048571378, 2.793622682802379, 4.624354233965278, 3.1627391511574388, 4.552626432850957, 3.9238929329439998, 0.7364105782471597, 0.16645508527290076, 0.15639791556168348, 1.2338817841373384, 13.410226162523031, 43.82473178207874, 39.36917066574097, 24.214757345616817, 29.18011050671339, 35.29695577919483, 20.221247635781765, 2.947577121667564, 0.10001639995607547, 0.032866625842871144, 0.116461806173902, 0.04535550920991227, 0.01543647407743265, 0.015566825823043473, 0.05543305458559189, 0.062339454889297485, 0.019399705015530344, 0.005826410306326579, 0.13527047034585848, 0.025695349322631955, 0.04227641271427274, 0.0712996041693259, 0.021437698196677957, 0.018808474924298935, 0.040224522817879915, 0.027851698359881993, 0.01497499459219398, 0.07031606553937308, 0.026014890281658154, 0.06587846772163175, 0.04773973654664587, 0.052499010853352956, 0.04250879770552274, 0.03097294884355506, 0.021735282716690563, 0.024237873331003357, 0.0777828430000227, 0.027595616593316663, 0.1405345683451742, 0.11325828862027265, 0.12673124496359378, 0.11616646108450368, 0.12138582984334789, 0.12067120842402801, 0.19393884722376242, 0.19617539830505848, 0.13047566200839356, 0.17118589079473168, 0.09885066407150589, 0.19937098230002448, 0.17996315262280405, 0.1799041815684177, 0.07056962029309943, 0.08691974217072129, 0.1605395448859781, 0.0910298376402352, 0.12821475364034995, 0.11008721034158953, 0.12848425714764744, 0.2153318774071522, 0.16880656534340233, 0.1629733736626804, 0.10717192068113945, 0.15305017645005137, 0.12765079562086612, 0.10374143210356124, 0.1446542894700542, 0.15489436889765784, 0.17964741331525147, 0.08353128141607158, 0.11284863052424043, 0.10457361713633873, 0.12024802839732729, 0.158495863142889, 0.13659434305736795, 0.25452290021348745, 2.1042536990717053, 24.3808426335454, 56.33536286652088, 47.60927550494671, 29.276047758758068, 39.545678794384, 61.49145059287548, 40.59218443930149, 11.080460976809263, 0.8955462765879929, 0.18526104802731425, 3.8708777027204633, 5.82493401132524, 16.48936338722706, 6.391341593116522, 0.7063661247957498, 0.7074215775355697, 0.892112567089498, 7.600058633834124, 26.997146643698215, 46.076749339699745, 56.32527440786362, 61.135257706046104, 57.33668893575668, 56.432257667183876, 59.48132045567036, 66.16327330470085, 68.43321070075035, 63.44018742442131, 61.19989223778248, 60.56369237601757, 58.958308920264244, 57.24822208285332, 57.27609358727932, 50.990725457668304, 47.78335936367512, 51.01050339639187, 51.12486205995083, 53.000836595892906, 54.98002499341965, 54.14531238377094, 51.94040469825268, 51.079131513834, 49.17567305266857, 49.689261093735695, 49.795868173241615, 50.916378647089005, 53.51912498474121, 59.08683702349663, 58.26197728514671, 63.28803978860378, 53.20018529891968, 44.5384930819273, 60.910499766469, 61.545487493276596, 61.03429712355137, 61.00895628333092, 60.573807433247566, 50.77755689620972, 50.007418021559715, 45.59173956513405, 47.90114164352417, 46.898527443408966, 47.4993360042572, 57.12033994495869, 60.040901228785515, 61.38249523937702, 59.30055655539036, 55.54244041442871, 60.425360798835754, 57.930547669529915, 59.810622185468674, 58.34224417805672, 56.707837879657745, 53.29250134527683, 54.748252630233765, 54.764846339821815, 50.99198319017887, 55.07641062140465, 55.882176384329796, 55.393613800406456, 58.5763344168663, 59.42293658852577, 59.03542958199978, 55.397797375917435, 47.06858731806278, 30.52862774580717, 13.148499056696892, 3.444872824475169, 1.0135248396545649, 2.359291026368737, 2.6961507881060243, 8.286835681647062, 11.740782894194126, 7.509492868557572, 8.393485508859158, 7.1024601347744465, 1.662026778794825, 0.39751492731738836, 1.6405378631316125, 19.411940462887287, 45.7800080627203, 38.53924959897995, 29.634085446596146, 39.781239554286, 43.35156597197056, 19.42769631743431, 2.569610453210771, 0.24449712334899232, 0.11359638141584583, 0.23255271662492305, 0.14496202842565253, 0.09531445655738935, 0.11729797653970309, 0.2423112015821971, 0.16174744960153475, 0.11754712293623015, 0.14254466048441827, 0.2803277608472854, 0.09646580219850875, 0.27586252545006573, 0.1907331551774405, 0.11792620454798453, 0.10256621899316087, 0.15443508338648826, 0.19129505002638325, 0.07398585963528603, 0.16064620635006577, 0.10780992277432233, 0.1976345051662065, 0.15924975159578025, 0.11892346548847854, 0.19172751432051882, 0.20011825079564005, 0.2154868675279431, 0.21786902798339725, 0.14980497246142477, 0.0831187363655772], [0.07099070004187524, 0.026207802293356508, 0.09594105926225893, 0.020782064530067146, 0.04458560149942059, 0.007391437875412521, 0.027372334043320734, 0.12351386409136467, 0.11849120899569243, 0.042867147421929985, 0.09602511490811594, 0.052240758304833435, 0.2183690870879218, 0.03660748800029978, 0.10870705315028317, 0.025039346437552013, 0.006199684148668894, 0.05058791379269678, 0.04178927069006022, 0.012933484558743658, 0.09515321013168432, 0.05602126599114854, 0.02476797457347857, 0.05618918432446662, 0.014365249771799427, 0.04273606558854226, 0.04536975844530389, 0.05634001470752992, 0.10024905583122745, 0.04316730162827298, 0.07183542737038806, 0.06203000899404287, 0.03288694584625773, 0.0480181718012318, 0.04048202208650764, 0.06848541728686541, 0.0628831003268715, 0.027355054990039207, 0.030697127804160118, 0.3692781674908474, 15.990995429456234, 34.74165357649326, 39.54520761966705, 27.54406839609146, 24.085374288260937, 46.83026410639286, 33.22716884315014, 11.03934433311224, 0.7961613032966852, 0.7409753801766783, 0.26330517895985395, 3.504018788225949, 7.327321143820882, 0.20518475939752534, 0.5095293244812638, 0.05129854616825469, 0.10944792433292605, 2.618268267251551, 13.927580751478672, 29.631115905940533, 45.92620901763439, 53.78644444048405, 54.93425264954567, 58.075126111507416, 53.164072036743164, 61.426025703549385, 62.32448369264603, 60.85701383650303, 61.94943621754646, 59.5660787075758, 57.679859921336174, 54.137340411543846, 51.51877172291279, 47.7794835716486, 49.35422167181969, 46.664045825600624, 51.60478010773659, 50.28117813169956, 53.08486148715019, 52.6919549703598, 50.48164017498493, 47.01305329799652, 48.095125034451485, 44.30466502904892, 49.06823381781578, 51.17412641644478, 60.16362704336643, 56.53620108962059, 62.108309492468834, 51.822595819830894, 37.29012742638588, 62.46232129633427, 60.29635772109032, 60.73855899274349, 55.169938802719116, 54.80868458747864, 46.899564787745476, 46.10896021127701, 48.5423344373703, 48.99333983659744, 48.55604790151119, 47.71287314593792, 50.051647648215294, 52.92636439204216, 56.22540816664696, 57.273612320423126, 57.002360075712204, 55.58881692588329, 58.65377426147461, 57.17945717275143, 55.51707677543163, 54.91596423089504, 52.12541677057743, 50.56492790579796, 50.37659101188183, 49.801510870456696, 52.20138229429722, 53.200964257121086, 53.558772057294846, 53.06588910520077, 56.795784160494804, 56.86432868242264, 44.03694659471512, 23.82665567100048, 8.311896286904812, 1.9533690204843879, 0.20801162958377972, 1.2497580447234213, 3.5229942575097084, 2.2150472039356828, 3.2792969467118382, 2.056391704827547, 3.2122243707999587, 3.9664371125400066, 0.6756847898941487, 0.11994171436526813, 1.8121037632226944, 16.084134131669998, 33.82429160177708, 25.648080334067345, 20.50139330327511, 27.989398799836636, 26.745140366256237, 8.916230108588934, 0.3011876321397722, 0.05634827852190938, 0.018846756756829564, 0.04163326011621393, 0.05418674372776877, 0.07933132670586929, 0.03718180269061122, 0.01626145007321611, 0.04655515011108946, 0.007308406393349287, 0.02739702529652277, 0.022322970908135176, 0.05448671981866937, 0.09327486404799856, 0.06275903549976647, 0.007330823427764699, 0.05025802172895055, 0.04705175080744084, 0.021312308635970112, 0.007527521784140845, 0.00978078927801107, 0.027980477680102922, 0.009301411046180874, 0.034576753023429774, 0.018918858258984983, 0.045688496029470116, 0.03962910515838303, 0.048771537040011026, 0.10470803492353298, 0.033001329356920905, 0.08709465153515339, 0.05232860261457972, 0.024183477617043536, 0.05969478937913664, 0.046568824182031676, 0.028789615316782147, 0.05658173962729052, 0.051554553720052354, 0.08956531310104765, 0.04652485193219036, 0.012429120997694554, 0.07032934998278506, 0.045003990962868556, 0.07510954543249682, 0.06777268092264421, 0.013640686356666265, 0.058414714512764476, 0.06145241030026227, 0.043539637117646635, 0.06744523052475415, 0.05907906284846831, 0.021030860261816997, 0.013037399148743134, 0.06802805393817835, 0.057262159170932136, 0.03880558469973039, 0.09801585925742984, 0.014157210935081821, 0.06783611228456721, 0.02413728263491066, 0.06864331662654877, 0.020591679531207774, 0.003258339538660948, 0.013709660634049214, 0.01645132855628617, 0.01312562009843532, 0.06659997627139091, 0.09445347619475797, 0.07495900077628903, 0.08519967392203398, 0.029361280539887957, 0.9010088397189975, 24.839858002960682, 42.11614586412907, 38.800797164440155, 22.665285989642143, 32.19488203525543, 58.41933064162731, 39.919198751449585, 9.68508655205369, 0.12890591577161103, 0.11722903844201937, 0.05978330162179191, 2.3638341575860977, 9.43740539252758, 0.7359858322888613, 1.0956513765268028, 0.4224341979715973, 0.5119611939880997, 4.999351361766458, 19.705867990851402, 35.23320659995079, 49.62549291551113, 53.26752908527851, 55.153523683547974, 57.95884095132351, 56.14994801580906, 64.12612661719322, 62.93620906770229, 61.956196054816246, 61.71991713345051, 62.43977710604668, 57.975267469882965, 56.14900566637516, 52.91909918189049, 49.919821321964264, 51.150465086102486, 49.124113619327545, 52.78178974986076, 52.929541021585464, 53.64669553935528, 53.58728192746639, 52.45741255581379, 48.038177490234375, 49.72539335489273, 46.55566044151783, 50.83689071238041, 53.763588666915894, 60.2031297236681, 57.8661373257637, 63.76362606883049, 52.89751634001732, 40.77105604112148, 61.10160291194916, 61.786945536732674, 62.005536407232285, 58.59806165099144, 57.47749038040638, 47.76518873870373, 47.87420488893986, 49.8811811953783, 50.186965987086296, 49.57679472863674, 49.86434809863567, 52.217527627944946, 56.060101836919785, 57.89226092398167, 57.58746787905693, 57.2082482278347, 57.27654956281185, 59.15116757154465, 58.879151567816734, 58.389422446489334, 56.302840411663055, 53.56060355901718, 54.99742045998573, 54.39199894666672, 51.49557776749134, 54.130272790789604, 54.4827114790678, 55.38639798760414, 54.796453043818474, 57.956872656941414, 56.42296716570854, 47.66395457088947, 26.46156158298254, 12.262458801269531, 3.700708821415901, 1.0585049260407686, 3.533319728448987, 3.657851633615792, 3.9632388716563582, 6.542068580165505, 5.616496196016669, 4.362491760402918, 1.7031677649356425, 0.27209039661101997, 0.2214904414722696, 1.2577863014303148, 13.959546536207199, 43.69056478142738, 36.07793927192688, 20.638679936528206, 27.77174837887287, 32.94067181646824, 14.473528806120157, 1.1232866998761892, 0.03670981161121745, 0.047009251720737666, 0.026145521260332316, 0.0528165276045911, 0.03514992480631918, 0.04839072251343168, 0.05625018886348698, 0.02556060684582917, 0.08398084479267709, 0.035608471880550496, 0.04101946688024327, 0.019809871482721064, 0.05700556161173154, 0.011240741259825882, 0.028380907169776037, 0.025383840256836265, 0.01604141441930551, 0.029928709955129307, 0.052563629651558585, 0.04570107543258928, 0.03799027981585823, 0.04172827357251663, 0.023882091445557307, 0.033873805587063543, 0.08181899087503552, 0.08004951043403707, 0.047773626720299944, 0.11999423615634441, 0.010591209902486298, 0.0493824730074266, 0.03999116561317351, 0.1954884218866937, 0.13957626273622736, 0.19271215132903308, 0.15529689495451748, 0.16735412296839058, 0.13568782451329753, 0.17973749520024285, 0.28109273698646575, 0.2467843928025104, 0.3133286931551993, 0.17913150193635374, 0.22573496215045452, 0.19446804304607213, 0.26722731068730354, 0.21690533438231796, 0.16184431471629068, 0.10923670168267563, 0.13486904266756028, 0.25253047118894756, 0.07633891305886209, 0.1600135551416315, 0.2027157973498106, 0.13235348858870566, 0.14887703553540632, 0.2627975499490276, 0.10693029966205359, 0.17752175393979996, 0.14839778625173494, 0.22392235550796613, 0.13180113775888458, 0.1639798891847022, 0.16556385497096926, 0.13195404986618087, 0.19600773230195045, 0.08862470029271208, 0.17766659148037434, 0.16570348263485357, 0.15355605399236083, 0.2522845531348139, 0.836136998841539, 25.737088657915592, 51.45167872309685, 53.15279804170132, 36.27039514482021, 31.95867531001568, 57.399442568421364, 42.28365607559681, 14.585182014852762, 1.546063176356256, 1.2973242485895753, 0.33026444376446307, 14.097413588315248, 14.34013506397605, 0.5936685658525676, 1.636410215869546, 0.4044660012004897, 0.5119516944978386, 3.8165619922801852, 16.121879406273365, 34.282676205039024, 48.0293657630682, 55.03341592848301, 58.19408632814884, 60.282165482640266, 59.278293550014496, 65.66636636853218, 66.53544813394547, 65.20099014043808, 66.11319199204445, 65.10284900665283, 60.620499327778816, 59.35830965638161, 56.33260041475296, 52.975419759750366, 53.78484092652798, 52.45840810239315, 56.762281358242035, 54.83880177140236, 58.58271047472954, 59.317583441734314, 56.30539007484913, 51.47648759186268, 53.377791568636894, 48.68229612708092, 53.84835831820965, 57.1620237082243, 64.97063130140305, 61.170314624905586, 65.44311314821243, 55.79618699848652, 42.42357976734638, 63.11117447912693, 62.94319309294224, 65.76459109783173, 59.89769831299782, 59.759514927864075, 50.26187136769295, 49.681988283991814, 53.31832475960255, 53.148492872714996, 52.397022396326065, 52.55939528346062, 55.32323777675629, 56.715589463710785, 58.76557946205139, 57.59762853384018, 59.17950265109539, 57.8679346293211, 60.950496420264244, 61.73245646059513, 61.20276488363743, 58.89563508331776, 55.57776711881161, 55.05637429654598, 55.85711292922497, 53.619371205568314, 56.306723803281784, 58.32128830254078, 57.46527403593063, 56.48070126771927, 61.03074811398983, 58.22082929313183, 45.87316006422043, 25.512209124863148, 10.368986204266548, 2.60993008967489, 0.6202189286705106, 4.190863994881511, 7.813628548756242, 7.063383981585503, 6.628625085577369, 6.295907814055681, 10.570967216044664, 8.414556328207254, 2.1063989214599133, 0.2842837345087901, 2.261262461543083, 20.19570540636778, 44.06217344105244, 35.78736126422882, 27.599674612283707, 37.83103600144386, 38.44715774059296, 13.39271480217576, 0.6542869505938143, 0.23844884242862463, 0.2426790990284644, 0.09195918464683928, 0.14822924451436847, 0.13687714585103095, 0.11115298635559157, 0.23086612665792927, 0.11247012036619708, 0.1360021240543574, 0.11005900872987695, 0.21159856289159507, 0.1272213296033442, 0.11363999743480235, 0.15267825656337664, 0.08242508061812259, 0.15468060068087652, 0.10359209714806639, 0.10256761423079297, 0.1035596059227828, 0.1652066592941992, 0.14138840924715623, 0.15185864351224154, 0.16613603598671034, 0.2507656143279746, 0.23568075033836067, 0.15392031491501257, 0.1474398368736729, 0.18730049952864647, 0.1345881397719495, 0.1957787203718908, 0.12569113983772695], [0.01028397653499269, 0.02362565715884557, 0.10246218473184854, 0.020465746347326785, 0.01857889896200504, 0.04188908584183082, 0.03413439219002612, 0.009822792981140083, 0.0436227947648149, 0.05333751527359709, 0.06163204714539461, 0.04760424264532048, 0.04543183167697862, 0.044746139174094424, 0.029066733259242028, 0.02338090056582587, 0.0213208322020364, 0.07501670275814831, 0.12261963551281951, 0.023531135375378653, 0.07093484600773081, 0.03605617617722601, 0.011066422830481315, 0.023722629885014612, 0.04692210874054581, 0.028518783365143463, 0.03605349331337493, 0.023139574550441466, 0.06943060172488913, 0.0557530352671165, 0.09080166433705017, 0.030403424716496374, 0.09048651874763891, 0.04209127655485645, 0.06331948316073976, 0.012259749910299433, 0.0772013925598003, 0.046898671716917306, 0.037707981682615355, 0.019446365695330314, 0.5168685712851584, 12.411701492965221, 34.35883171856403, 37.25179508328438, 27.948013320565224, 29.293162040412426, 37.847348526120186, 45.088844150304794, 18.952961191534996, 1.4766784245148301, 0.05626265694445465, 0.17557392799062654, 3.688351409509778, 1.4709102152846754, 0.5662410438526422, 1.100288077723235, 0.49389343068469316, 0.12883930059615523, 2.2187489178031683, 4.682847345247865, 14.662483166903257, 28.506634645164013, 43.338270485401154, 51.4736757427454, 60.67103661596775, 55.33359222114086, 61.015925109386444, 62.368378937244415, 64.72407013177872, 61.69076889753342, 58.3600690215826, 59.72269490361214, 55.96567690372467, 49.467489793896675, 53.6011777818203, 52.85984516143799, 52.50119000673294, 55.00215120613575, 56.93462111055851, 52.08525292575359, 55.092400163412094, 53.03108677268028, 55.03811627626419, 50.43147146701813, 47.880968526005745, 48.81222255527973, 58.59830863773823, 57.013508677482605, 66.3614858686924, 51.330130845308304, 40.59401594102383, 66.18674844503403, 59.73529502749443, 57.37801931798458, 56.21375039219856, 49.22352768480778, 46.691769137978554, 53.72591368854046, 53.7003068625927, 57.313924357295036, 53.85033421218395, 56.68084032833576, 53.89100342988968, 55.97992993891239, 60.61274394392967, 58.999323919415474, 56.90334498882294, 57.459213361144066, 57.63778477907181, 57.17321030795574, 58.87985073029995, 53.187148198485374, 53.712952584028244, 53.480815440416336, 56.147398352622986, 55.831787288188934, 55.44507443904877, 55.62956973910332, 57.40252420306206, 56.69966071844101, 53.89186978340149, 45.46719364821911, 19.160059578716755, 4.040636206045747, 1.3654342875815928, 1.3316201395355165, 1.5451127523556352, 2.817771336995065, 2.714908719062805, 4.197516487911344, 4.851381601765752, 3.5971130803227425, 3.916180534288287, 2.1753357723355293, 0.11570774702704512, 2.414320860989392, 19.149556942284107, 43.09575229883194, 45.693737491965294, 22.769915275275707, 28.409650549292564, 28.667696602642536, 6.421273062005639, 0.1223188875883352, 0.07614565038238652, 0.07300976474652998, 0.02573647358076414, 0.09206880728015676, 0.01961965532245813, 0.01075905587640591, 0.04096161275811028, 0.02388429747952614, 0.08486077218549326, 0.05066405443358235, 0.044945164627279155, 0.044299195578787476, 0.057484053904772736, 0.06334004807285964, 0.05841016514750663, 0.0355227983527584, 0.049368182953912765, 0.03566556530131493, 0.04445869795745239, 0.02998984436999308, 0.11831084484583698, 0.07932933775009587, 0.019675455550896004, 0.015076629861141555, 0.12267804995644838, 0.051052583585260436, 0.05285299303068314, 0.020114838516747113, 0.03199714788934216, 0.03301884775282815, 0.03817399847321212, 0.008179113992810016, 0.0637977453880012, 0.03896312780852895, 0.041601763368817046, 0.0404927646741271, 0.019687636049638968, 0.025245717297366355, 0.024896557224565186, 0.024399691210419405, 0.03652350285847206, 0.04178258765023202, 0.039662049093749374, 0.04290798409783747, 0.03614351953729056, 0.08541366478311829, 0.020254453193047084, 0.008202569570130436, 0.07503884844481945, 0.025038513376784977, 0.004425982278917218, 0.00819858702016063, 0.15341624821303412, 0.09664842989877798, 0.06179009491461329, 0.061068642025929876, 0.00954320554228616, 0.03630229832197074, 0.05580477780313231, 0.020902465003018733, 0.018247658044856507, 0.04990806570276618, 0.10641351254889742, 0.017315012191829737, 0.05012869878555648, 0.015595268632750958, 0.015803713795321528, 0.03858424286590889, 0.01960751564183738, 0.05462118213472422, 0.039133465543272905, 0.11031919828383252, 1.5570375812239945, 20.55620726197958, 41.10111013054848, 35.66486343741417, 21.04980267584324, 32.60015308856964, 48.68790842592716, 47.210844084620476, 16.07512291520834, 1.3857076247222722, 0.04046280788315926, 0.1619665464386344, 3.3816062193363905, 2.6590626407414675, 1.583392967004329, 0.8223591162823141, 0.33854280423838645, 0.5795196094550192, 3.7153995456174016, 8.328718934208155, 19.416971392929554, 34.66060772538185, 47.05707773566246, 56.22540056705475, 59.98397648334503, 56.08108431100845, 64.01160076260567, 63.771674036979675, 65.87097018957138, 63.98545056581497, 60.812256038188934, 59.204588904976845, 57.26639650762081, 51.749476343393326, 54.63257163763046, 53.86683292686939, 54.495558589696884, 56.35541059076786, 59.16756749153137, 55.80186769366264, 57.02614299952984, 55.1877598464489, 55.590447038412094, 49.44801963865757, 49.257319271564484, 48.81267853081226, 60.94941347837448, 58.69730852544308, 66.16138860583305, 53.68931405246258, 42.79596358537674, 63.29103022813797, 61.57697260379791, 59.779589250683784, 58.546031042933464, 51.73304222524166, 47.56248101592064, 53.167168870568275, 56.54843643307686, 56.395133659243584, 56.881013587117195, 56.970760971307755, 56.21054336428642, 58.62601675093174, 60.25900572538376, 59.45029892027378, 59.08345140516758, 58.579465448856354, 60.123121216893196, 59.81333523988724, 57.99420565366745, 55.00799149274826, 55.583425015211105, 53.926896303892136, 56.45741231739521, 57.70720325410366, 58.03436569869518, 55.79731933772564, 56.57624714076519, 58.12378250062466, 55.7941123098135, 48.77602569758892, 22.47017975896597, 6.3378162402659655, 2.0968322223052382, 2.4049033038318157, 1.4844371331855655, 5.961528131738305, 6.234109355136752, 4.5991117134690285, 6.740122977644205, 6.400707615539432, 1.140365714672953, 0.5567127582617104, 0.2634702029172331, 1.8888045474886894, 18.252478279173374, 48.67363639175892, 43.57484579086304, 16.68270081281662, 27.38893412053585, 33.79323206841946, 12.024620063602924, 0.43924455530941486, 0.06268901386647485, 0.011794411257142201, 0.06910188967594877, 0.019610037088568788, 0.035075205378234386, 0.08786572070675902, 0.041003150763572194, 0.042375352131784894, 0.025892675257637165, 0.04641472463845275, 0.024246176108135842, 0.0426687750587007, 0.0741496219416149, 0.04812931212654803, 0.036795533378608525, 0.058141452027484775, 0.03224427564418875, 0.030102057098702062, 0.054644674819428474, 0.02342519936064491, 0.013600691090687178, 0.04975910924258642, 0.033951382283703424, 0.019341192237334326, 0.08304361617774703, 0.01742535656376276, 0.02693903854378732, 0.05012225694372319, 0.012654285819735378, 0.03406605152122211, 0.035530182722141035, 0.02972470840177266, 0.15602776198647916, 0.1257590315071866, 0.15020913124317303, 0.16375077335396782, 0.18089619552483782, 0.13183005183236673, 0.1426047892891802, 0.14991875854320824, 0.16486966487718746, 0.22652692277915776, 0.16294058557832614, 0.11118555179564282, 0.14808744977926835, 0.1330860031885095, 0.09586273299646564, 0.1484122284455225, 0.1768526335945353, 0.17215377010870725, 0.2197472850093618, 0.2075834697461687, 0.2758927160175517, 0.20381278067361563, 0.08591779827838764, 0.15191930666333064, 0.08907136929337867, 0.08509392529958859, 0.1499019266339019, 0.12486698484281078, 0.25985941698309034, 0.1559994267881848, 0.16195057542063296, 0.16417038365034387, 0.29990339011419564, 0.14725792163517326, 0.10558262627455406, 0.15193652448942885, 0.18886778183514252, 0.13963556033559144, 0.1668749627424404, 0.1790821788017638, 0.9062221006024629, 20.837692357599735, 48.27377624809742, 47.37581983208656, 36.08724497258663, 37.07656368613243, 48.97044226527214, 53.524144515395164, 23.07421624660492, 2.4458506191149354, 0.28730875812470913, 0.4216496291337535, 11.129729133099318, 5.322929648682475, 1.1349057639017701, 4.312511617317796, 1.4809870370663702, 1.0112451994791627, 3.9450832083821297, 5.970224440097809, 17.496183961629868, 30.955453142523766, 47.75801472365856, 55.76603561639786, 62.56124138832092, 58.70858632028103, 64.17298570275307, 66.35028406977654, 69.22209396958351, 66.10679313540459, 61.87879800796509, 64.39487859606743, 60.79536214470863, 55.124147459864616, 58.23780298233032, 57.84167043864727, 55.53311951458454, 61.27442143857479, 62.34181836247444, 58.29565107822418, 59.77176547050476, 59.20463070273399, 61.63335017859936, 53.134179040789604, 51.40026368200779, 51.553832441568375, 62.531025409698486, 61.509248837828636, 67.74461165070534, 55.16628339886665, 47.52821825444698, 65.7276950776577, 63.413512855768204, 62.61374697089195, 59.877570793032646, 51.86565890908241, 49.95870843529701, 56.915253549814224, 59.13964278995991, 61.2047103792429, 58.3351993560791, 61.12542003393173, 59.95377570390701, 62.66945578157902, 64.55775305628777, 60.95990851521492, 59.987890273332596, 59.24700602889061, 60.69754779338837, 56.913916021585464, 61.73546589910984, 55.36180570721626, 56.68721258640289, 57.75934025645256, 61.104825139045715, 59.76557180285454, 60.57574152946472, 59.055123925209045, 59.84182991087437, 61.47876687347889, 55.38520485162735, 47.76642747223377, 20.783001892268658, 5.083988020196557, 1.6807129886001348, 2.7346795331686735, 3.3356692967936397, 5.128218121826649, 4.813398839905858, 8.316918667405844, 11.995275188237429, 12.986887078732252, 10.765192843973637, 4.235033774748445, 0.4260190384229645, 2.9054352454841137, 25.5439393222332, 52.18503177165985, 51.72755911946297, 30.04300430417061, 39.59257207810879, 40.020565912127495, 11.05069337412715, 0.2650310582248494, 0.19950329238781705, 0.19721902121091262, 0.266156688448973, 0.1586046619922854, 0.13846163114067167, 0.21414077491499484, 0.22191722091520205, 0.10106784509844147, 0.2058912394568324, 0.18400705594103783, 0.07296144351130351, 0.12015146756311879, 0.1592414840706624, 0.135883632756304, 0.1375518916756846, 0.08993642404675484, 0.13581741834059358, 0.11704640332027338, 0.1421949011273682, 0.09191910867230035, 0.28265071276109666, 0.15857911726925522, 0.07170046781538986, 0.10520013078348711, 0.22403569630114362, 0.17935264710104093, 0.12179076788015664, 0.12293495921767317, 0.14649183227447793, 0.11446261618402787, 0.2047720065456815, 0.0630851871392224], [0.05684545809344854, 0.02281600744026946, 0.04117600437893998, 0.020162489963695407, 0.04716365183412563, 0.02118930879078107, 0.010129249876627, 0.04106643740669824, 0.011265106895734789, 0.0252458842805936, 0.036247943426133133, 0.02759107836027397, 0.06109700319939293, 0.04173322369751986, 0.07436466665240005, 0.07944162469357252, 0.007993609542609192, 0.04801285431312863, 0.023331937372859102, 0.12564558681333438, 0.02783884065138409, 0.06676829536445439, 0.06894860649481416, 0.010020694080594694, 0.028957162576261908, 0.011200164335605223, 0.025110681672231294, 0.054902537740417756, 0.014330806698126253, 0.03591746135498397, 0.0224351966244285, 0.026414271487738006, 0.025481662742095068, 0.012265526602277532, 0.017613446470932104, 0.06293798214755952, 0.11986026365775615, 0.040624703688081354, 0.06564355571754277, 0.031138045160332695, 0.040938854799605906, 0.12100828447728418, 12.794661093503237, 39.41577136516571, 41.74463979899883, 28.346368744969368, 27.504206635057926, 36.10340930521488, 36.181438118219376, 23.323936946690083, 4.062081780284643, 0.26478582294657826, 1.4084971393458545, 2.265447936952114, 1.8895956175401807, 0.11560867031221278, 0.07108630350558087, 0.6371797935571522, 0.33054548024665564, 0.3392852487741038, 1.0156628186814487, 5.6270477548241615, 16.478127390146255, 30.46083938330412, 48.4281999617815, 57.47643783688545, 55.67373476922512, 64.42334666848183, 63.16633991897106, 62.52662904560566, 60.156494826078415, 58.8906155526638, 59.70897763967514, 60.41841857135296, 62.56612032651901, 59.58100810647011, 63.33348535001278, 59.48377512395382, 59.89833287894726, 57.13971130549908, 58.85925963521004, 56.47361844778061, 59.01335656642914, 56.84707760810852, 53.68253521621227, 51.68639972805977, 63.23504023253918, 60.29264532029629, 69.92922842502594, 49.623574018478394, 30.788055025041103, 66.29587098956108, 64.15008813142776, 61.79395616054535, 55.371916964650154, 49.37453918159008, 54.097773134708405, 60.28915710747242, 60.880044400691986, 61.07744000852108, 57.92148895561695, 58.25525164604187, 58.613526821136475, 58.31317573785782, 59.626016691327095, 58.005084469914436, 59.28996652364731, 59.5771399140358, 56.64703354239464, 60.379732847213745, 59.75633069872856, 59.76358450949192, 58.45888651907444, 55.64213566482067, 57.65293836593628, 56.042995154857635, 60.34770056605339, 60.46271659433842, 58.555807918310165, 53.84204685688019, 41.485372111201286, 18.10602653771639, 3.9750370010733604, 0.3461620782036334, 0.1324992612353526, 1.8182223848998547, 0.24204319721320644, 4.894059961661696, 5.833134446293116, 2.2201671916991472, 10.621648896485567, 7.6988789811730385, 1.5779152046889067, 0.06931039606570266, 1.587035427801311, 26.879805140197277, 36.214933320879936, 21.310785971581936, 49.021169543266296, 39.899853989481926, 30.184096433222294, 7.917563896626234, 0.23192977270809934, 0.09822708190768026, 0.07675947330426425, 0.029919093576609157, 0.051168603531550616, 0.040265719435410574, 0.06425814412068576, 0.03743218847375829, 0.03719123167684302, 0.08961957893916406, 0.05779314356914256, 0.07750930220936425, 0.02776882643956924, 0.050734543619910255, 0.03125223571259994, 0.0381414701405447, 0.0648391641152557, 0.016413534685852937, 0.010666485013643978, 0.03275324052083306, 0.021037916230852716, 0.03193741984432563, 0.08160977944498882, 0.04379187084850855, 0.03899911083863117, 0.05124378680193331, 0.025299448789155576, 0.03226515225833282, 0.013592031154985307, 0.014182253780745668, 0.052612136423704214, 0.017758729300112464, 0.006599697571800789, 0.05049707862781361, 0.04053328222653363, 0.032613609146210365, 0.012228068553667981, 0.028568015586643014, 0.044641080748988315, 0.02630129805766046, 0.05218705649895128, 0.018993844860233366, 0.029821328607795294, 0.057389597059227526, 0.05080029048258439, 0.01881107429653639, 0.03732165670953691, 0.06347377566271462, 0.08465148654067889, 0.04458158648048993, 0.02993689769937191, 0.028533661570691038, 0.004495098955885624, 0.0911985723359976, 0.06907899442012422, 0.043225430345046334, 0.03982568523497321, 0.021261608817439992, 0.05292959751386661, 0.018875010318879504, 0.01733957356918836, 0.037989574775565416, 0.044760095261153765, 0.015960984164848924, 0.04942344698065426, 0.02373881983658066, 0.021174810935917776, 0.017472904110036325, 0.025498433424218092, 0.008160297766153235, 0.08584664858062752, 0.08498031733324751, 0.10247742844512686, 0.09914623922668397, 0.004127186202822486, 0.9767460194416344, 20.84126226603985, 45.14103814959526, 41.20525114238262, 24.66615792363882, 25.482868999242783, 51.09342634677887, 53.03278528153896, 21.786041669547558, 2.8394954837858677, 0.17778940207790583, 0.07402887451462448, 1.0943371220491827, 2.065438781864941, 1.1706657637842, 1.5952217322774231, 0.7676419336348772, 0.30717744666617364, 0.2987770177423954, 2.0340299047529697, 7.780551323667169, 20.39738718420267, 36.01850666105747, 55.04528269171715, 58.86066935956478, 57.9151850938797, 64.11035746335983, 63.58856186270714, 65.03209680318832, 62.288594618439674, 62.733938321471214, 58.806811049580574, 59.94591772556305, 62.93011039495468, 61.09478607773781, 62.05954670906067, 61.05556458234787, 61.90135359764099, 59.396493807435036, 60.27074709534645, 60.54671868681908, 61.274227648973465, 59.388320446014404, 55.37162058055401, 53.79058621823788, 64.93563517928123, 62.06027626991272, 70.92754885554314, 52.15957313776016, 34.31339755654335, 66.08797654509544, 63.89428585767746, 63.28991688787937, 56.720897778868675, 52.87413239479065, 55.047570168972015, 61.9040210545063, 61.849999353289604, 62.828412652015686, 60.262877717614174, 61.18162661790848, 60.24592682719231, 60.7487728446722, 61.05765827000141, 59.35414507985115, 59.20407213270664, 59.4100096821785, 55.76390393078327, 60.616125762462616, 61.41349397599697, 59.59097117185593, 58.27703967690468, 56.26472845673561, 57.94475130736828, 58.34020748734474, 61.220357939600945, 60.43182425200939, 59.01988081634045, 55.65731585025787, 46.01210720837116, 22.27741800248623, 6.320026544854045, 0.8053397701587528, 1.8429803126491606, 4.717028411105275, 2.463381690904498, 9.11954389885068, 9.629786219447851, 3.3579249400645494, 2.3650225438177586, 0.6405918323434889, 0.5357277311850339, 0.19133629859425128, 0.9770776703953743, 25.012412443757057, 46.85032323002815, 32.29101687669754, 53.29095482826233, 38.96294206380844, 33.897118493914604, 14.770890399813652, 0.5476642563007772, 0.1152115099830553, 0.042028305324492976, 0.009238175425707595, 0.10617817009915598, 0.031448396475752816, 0.0569084552989807, 0.02313023833266925, 0.03179864193953108, 0.04373833231511526, 0.07185227412264794, 0.08231993313529529, 0.040201260198955424, 0.07070227919030003, 0.0826903093548026, 0.031835025729378685, 0.037226851054583676, 0.0296426565546426, 0.02740453212027205, 0.023880438311607577, 0.016787627209851053, 0.011306825799692888, 0.027072142729593907, 0.05306757760990877, 0.02287211194925476, 0.03315834554086905, 0.08104153923341073, 0.012545306999527384, 0.02965561445307685, 0.01842070461862022, 0.11625238694250584, 0.03971143902163021, 0.026640552314347588, 0.05129930686962325, 0.09896214207401499, 0.18473439035005867, 0.10687738453270867, 0.09811377080040984, 0.12508398882346228, 0.10866042401175946, 0.19201552699087188, 0.11542938227648847, 0.10277754554408602, 0.10870126439840533, 0.1886420205119066, 0.1689317062846385, 0.16336546512320638, 0.14704324799822643, 0.1941793179139495, 0.21147118066437542, 0.11949048115639016, 0.12876692635472864, 0.14868743164697662, 0.282458437141031, 0.14529440668411553, 0.11552175739780068, 0.14177437056787312, 0.14188336237566546, 0.18731194344582036, 0.08919086249079555, 0.10762304256786592, 0.15599653241224587, 0.07299247270566411, 0.10077508268295787, 0.09067538790986873, 0.08114631564239971, 0.07981157046742737, 0.07799426603014581, 0.0848220320767723, 0.2391987678129226, 0.23082401719875634, 0.15467623685253784, 0.19118283729767427, 0.2568750630598515, 0.1633269476587884, 0.5612700793426484, 19.951310120522976, 52.829272001981735, 56.464198753237724, 38.051427975296974, 33.694847747683525, 45.559570491313934, 45.87974891066551, 30.04530508071184, 5.536070661619306, 0.5607904738280922, 2.606775308959186, 7.9932729341089725, 8.449742440134287, 0.6219846464227885, 0.6894196872599423, 1.0182452551089227, 1.1226548650301993, 0.841423524543643, 1.615241076797247, 7.82681574113667, 18.55949230492115, 35.93027539551258, 54.31771673262119, 60.69660544395447, 59.135789796710014, 64.78516325354576, 68.33161935210228, 67.73122116923332, 65.71634128689766, 65.1922658085823, 63.92993554472923, 64.43941980600357, 66.88243791460991, 65.93406200408936, 67.60298565030098, 64.86783921718597, 63.86728450655937, 60.94010777771473, 62.70489647984505, 61.74156077206135, 65.51102310419083, 62.77839593589306, 57.83504359424114, 57.00254246592522, 67.8239057958126, 66.04125425219536, 73.08831050992012, 53.983775451779366, 37.08483204245567, 66.12225070595741, 67.34234243631363, 66.57859861850739, 59.50278550386429, 54.49327491223812, 60.19598230719566, 66.09046921133995, 65.64819574356079, 64.91994202136993, 63.3322162181139, 62.86059692502022, 63.135797157883644, 62.60659195482731, 62.26343236863613, 60.719962790608406, 60.01513101160526, 59.97422240674496, 56.693079471588135, 62.07931324839592, 63.55820149183273, 62.74952508509159, 62.1045096963644, 57.94810652732849, 60.39551340043545, 59.24053117632866, 63.73638153076172, 62.29812830686569, 62.89717376232147, 56.55527986586094, 45.773890390992165, 20.847758017480373, 5.532083725556731, 0.42215479421429336, 1.4776692213490605, 5.040343087166548, 4.537868499755859, 16.734267845749855, 19.36833780258894, 9.230352602899075, 20.382547080516815, 11.64404483512044, 3.2668383652344346, 0.24277232761960477, 2.8721271827816963, 33.643843084573746, 45.834937915205956, 32.26426251232624, 54.87676553428173, 45.39228826761246, 41.75365671515465, 15.167517866939306, 0.6975439481902868, 0.296194403199479, 0.16321169212460518, 0.14724877837579697, 0.1655168176512234, 0.11554987737326883, 0.16984891175525263, 0.07625162907061167, 0.09826918394537643, 0.10937225495581515, 0.2086147730005905, 0.14551466127159074, 0.11631938061327673, 0.1610208276542835, 0.13228893658379093, 0.15626358683221042, 0.1693813587189652, 0.16332047613104805, 0.10676773221348412, 0.10003010000218637, 0.14821189310168847, 0.11738524568499997, 0.1386162353446707, 0.17719942436087877, 0.1778533900505863, 0.11080039199441671, 0.1290401999722235, 0.18787226494168863, 0.11680931682349183, 0.08259549998911098, 0.24542869679862633, 0.13380790507653728, 0.09939421302988194, 0.2015473452047445], [0.09080138974240981, 0.036154648041701876, 0.06088860071031377, 0.04952497278281953, 0.00375546414488781, 0.014447591984207975, 0.03486877329123672, 0.06147152431367431, 0.08428257235209458, 0.04414235008880496, 0.03127780270006042, 0.04067833870067261, 0.03881162207107991, 0.04635472199879587, 0.07195423037046567, 0.08321249188156798, 0.06815893168095499, 0.003912907759513473, 0.0556806202075677, 0.013184348099457566, 0.030109300460026134, 0.045646000653505325, 0.04963588675309438, 0.04664691296056844, 0.0753172354598064, 0.03948645324271638, 0.043493828052305616, 0.04463930330530275, 0.05331328786269296, 0.053207498422125354, 0.02339679551369045, 0.04979772318620235, 0.048162029706873, 0.042578967768349685, 0.1030087839171756, 0.004686715456045931, 0.022056801499275025, 0.018614607397466898, 0.04399863690196071, 0.029900912813900504, 0.02759298567980295, 0.01497042203482124, 0.1986095536267385, 11.45640330389142, 34.22783374786377, 41.370223090052605, 34.465457797050476, 20.78626211732626, 28.728295750916004, 38.6415971070528, 25.80257434397936, 7.478719269856811, 0.4013324755942449, 0.04699953329691198, 2.618324076756835, 1.5153152262791991, 12.087351847440004, 9.961052443832159, 0.41414268664084375, 0.26998438930604607, 0.06443810751079582, 0.040312174169230275, 1.225219911430031, 5.351157383993268, 17.515692114830017, 32.0259241014719, 51.31257198750973, 57.48603232204914, 62.52094455063343, 65.40819302201271, 60.99004849791527, 60.13105519115925, 61.131989881396294, 62.3191449791193, 65.4555992782116, 63.13581995666027, 63.416412100195885, 62.83369816839695, 62.68971249461174, 60.68549104034901, 63.39297875761986, 62.677461951971054, 62.73150645196438, 59.38543640077114, 60.90010352432728, 55.48655301332474, 58.295491486787796, 61.42300106585026, 65.5513845384121, 40.852660462260246, 34.893683418631554, 57.70705506205559, 64.80932235717773, 58.85457068681717, 58.41053791344166, 52.81222231686115, 56.28643289208412, 58.95348317921162, 64.42634090781212, 59.31419022381306, 63.03984850645065, 63.26459884643555, 61.06320217251778, 61.76532469689846, 62.73134686052799, 61.88508287072182, 61.819996163249016, 60.333580523729324, 60.36320373415947, 58.97894561290741, 60.427188500761986, 61.374796852469444, 58.9280891418457, 61.67175851762295, 60.00769101083279, 60.58442406356335, 58.20632927119732, 55.132396817207336, 46.839512810111046, 32.58745416998863, 10.325960163027048, 1.8732504383660853, 0.5341887543909252, 0.5607920174952596, 2.909266627393663, 3.188049830496311, 2.4596027936786413, 3.6408845940604806, 28.20286564528942, 5.229330221191049, 1.034018921200186, 1.0272371163591743, 0.0498181619332172, 3.3208529418334365, 25.157950334250927, 35.73492027819157, 25.70419382303953, 21.67990006506443, 27.967825457453728, 31.695081554353237, 13.775445464998484, 0.23817543522454798, 0.0455150301422691, 0.07385636228718795, 0.05750782860559411, 0.04697053387644701, 0.04207709411275573, 0.13359569536987692, 0.030874172698531765, 0.008245892440754687, 0.04321309956139885, 0.01567186012835009, 0.06663430802291259, 0.022656397450191434, 0.12545320729259402, 0.11238764549489133, 0.06259893940296024, 0.051880720202461816, 0.08584569121012464, 0.07395054824883118, 0.06301584086031653, 0.05443727794045117, 0.039009686443023384, 0.02153474142687628, 0.046309046520036645, 0.046166231331881136, 0.03220524980861228, 0.030781977548031136, 0.054401699380832724, 0.04096103388292249, 0.037697517400374636, 0.015991234104149044, 0.0246145930577768, 0.055715167181915604, 0.07066712365485728, 0.03571501831174828, 0.05663028721755836, 0.03596066548197996, 0.06032849814801011, 0.039297339171753265, 0.008563711617171066, 0.0068763590934395324, 0.0621727314137388, 0.0441465024050558, 0.043778597537311725, 0.02956929154606769, 0.046409574133576825, 0.05190010881051421, 0.02994753267557826, 0.025125266729446594, 0.08010758348973468, 0.01908608082885621, 0.06147874541056808, 0.02574031605035998, 0.025542904768371955, 0.06287944153882563, 0.06755894239176996, 0.06519932096125558, 0.039705576054984704, 0.053906787070445716, 0.06565411647898145, 0.03912944681360386, 0.038760183815611526, 0.05365371471270919, 0.027428139837866183, 0.017943321836355608, 0.023888353316579014, 0.07696484040934592, 0.0507254819967784, 0.03956789652875159, 0.03130190023512114, 0.03646903292974457, 0.05776080448413268, 0.021538389082707, 0.04531891390797682, 0.06102817271312233, 0.04566728544887155, 0.029958249288029037, 0.4349558620015159, 19.4992046803236, 42.81151235103607, 40.1563174277544, 30.12384496629238, 19.6930018812418, 32.947545647621155, 57.11414247751236, 32.44724929332733, 5.540570095181465, 0.5618964519817382, 0.13699535513296723, 0.4407011537114158, 1.6205353802070022, 16.975579597055912, 11.503541674464941, 2.0376933831721544, 0.5827547796070576, 0.7592642738018185, 0.4467807977925986, 2.196247475221753, 9.103244673460722, 23.984888680279255, 40.596235021948814, 53.149708807468414, 60.89827582240105, 63.47093917429447, 66.07536122202873, 63.76655951142311, 61.73898071050644, 63.40359538793564, 63.921036422252655, 66.88091799616814, 64.84180301427841, 65.44029369950294, 65.52948251366615, 63.128516748547554, 62.72860340774059, 64.47712898254395, 62.21767142415047, 65.45614644885063, 62.43457518517971, 62.45534487068653, 57.467743903398514, 60.76834939420223, 61.23456537723541, 68.57663780450821, 44.84184980392456, 34.12687696516514, 59.32933621108532, 65.7556463778019, 62.65602730214596, 58.808680549263954, 54.89074878394604, 57.89540335536003, 61.01219370961189, 65.59329628944397, 61.759925186634064, 62.83063933253288, 64.51068118214607, 60.99178120493889, 62.918460220098495, 63.31058777868748, 61.23099736869335, 61.459118127822876, 60.66489614546299, 58.30294668674469, 61.141200587153435, 59.8831906914711, 60.422419756650925, 59.41020347177982, 61.42950251698494, 60.65215162932873, 60.98754063248634, 61.037363559007645, 57.41569809615612, 50.163289457559586, 36.6819054633379, 15.219942703843117, 4.2717754282057285, 1.0954099707305431, 2.3592713149264455, 2.763843680731952, 3.6691721761599183, 5.636296458542347, 8.632879313081503, 20.603638216853142, 4.585232958197594, 0.34485797630622983, 0.6884873122908175, 0.23907157854409888, 2.82437514513731, 26.571214199066162, 48.84206995368004, 30.385168343782425, 17.38166380673647, 32.355472818017006, 39.74657401442528, 19.21080395579338, 0.5270198453217745, 0.039488594338763505, 0.058887366103590466, 0.014830033669568365, 0.04125626765016932, 0.02925933356891619, 0.021378615820140112, 0.03261308593209833, 0.010588953773549292, 0.03184089240676258, 0.018257652918691747, 0.04527504184807185, 0.09440672089112923, 0.029376095662883017, 0.04685836567659862, 0.017437342248740606, 0.0798738663434051, 0.0747444829903543, 0.05959651789453346, 0.053159117815084755, 0.04375746117148083, 0.04865273403993342, 0.05487909329531249, 0.05154667582246475, 0.051757594192167744, 0.05052572181739379, 0.016224782411882188, 0.05861538753379136, 0.04166503145825118, 0.08244951954111457, 0.026804344306583516, 0.07059374751406722, 0.03838294644083362, 0.0323476865014527, 0.027910344724659808, 0.14795151801081374, 0.15457392437383533, 0.12162340615759604, 0.14534920686855912, 0.15283303888281807, 0.14315716980490834, 0.1637658686377108, 0.10101991720148362, 0.1228728488786146, 0.10800519667100161, 0.13678197283297777, 0.13104116369504482, 0.07286400694283657, 0.07433034232235514, 0.16401803557528183, 0.16207740845857188, 0.17948607041034847, 0.0866691634291783, 0.07820649800123647, 0.18291802844032645, 0.1362015539780259, 0.22997451043920591, 0.3299749764846638, 0.18398361891740933, 0.16562889679335058, 0.12356306106084958, 0.15043682215036824, 0.11807284550741315, 0.1406584624783136, 0.09270263850339688, 0.08354253979632631, 0.3126880415948108, 0.11159945497638546, 0.1297320003504865, 0.1919279684079811, 0.07394066284177825, 0.1996674554538913, 0.09145761898253113, 0.19292084325570613, 0.1520359722780995, 0.20122667803661898, 0.13000856910366565, 0.3380979609210044, 17.0801442861557, 49.515021443367004, 55.02732865512371, 45.229083225131035, 29.492862224578857, 35.965146124362946, 49.47998732328415, 33.57087180018425, 9.521081652492285, 0.77360037015751, 0.5737559124827385, 6.356587707996368, 6.887421598657966, 20.74026368558407, 14.043624624609947, 1.684198232833296, 1.1124190455302596, 0.40130608482286334, 0.16070268378825858, 2.0809835102409124, 7.2922419011592865, 23.458432629704475, 38.45022797584534, 55.53511820733547, 63.23228918015957, 63.148317486047745, 70.36920681595802, 66.8216335773468, 63.98386225104332, 65.48197746276855, 69.31651130318642, 68.47101867198944, 67.50548288226128, 66.80994540452957, 69.16611537337303, 67.58961036801338, 65.34222096204758, 68.26633885502815, 68.48352760076523, 69.27849814295769, 65.79857647418976, 63.86983796954155, 60.167540833353996, 61.97771430015564, 66.95966497063637, 67.61475741863251, 47.973425164818764, 42.7914684265852, 59.754601791501045, 67.14175119996071, 63.49072091281414, 62.1545834094286, 58.16683419048786, 59.71119672060013, 62.495694905519485, 67.27358132600784, 62.57895603775978, 64.94350075721741, 67.64256432652473, 63.81680801510811, 66.84353560209274, 64.9452106654644, 62.61636883020401, 61.613420248031616, 61.15961439907551, 59.46013659238815, 60.01162759959698, 61.124367490410805, 62.26721316576004, 60.72139911353588, 66.09382063150406, 62.50757686793804, 63.41259330511093, 58.97528260946274, 58.51571246981621, 47.816706374287605, 35.24221211671829, 12.575039528310299, 3.109166300855577, 0.8159373421221972, 1.6529145115055144, 4.968546889722347, 7.992085497826338, 4.766436209902167, 14.488244466483593, 38.54129008948803, 10.367557480931282, 3.0221174843609333, 1.6262970585376024, 0.2647107472876087, 4.981444822624326, 31.68143268674612, 46.046890541911125, 34.28680278360844, 28.07173278182745, 41.073675602674484, 44.577224403619766, 20.592915192246437, 0.4512083617737517, 0.1370721377315931, 0.14670549659058452, 0.2194000341114588, 0.13379653537413105, 0.14522577286697924, 0.21203312004217878, 0.13418827060377225, 0.1117196012637578, 0.14039299625437707, 0.12018229637760669, 0.1998214956256561, 0.23088877700502053, 0.22675532614812255, 0.1788830605801195, 0.15654370305128396, 0.18847874802304432, 0.1970866517513059, 0.19589784991694614, 0.15067622414790094, 0.1391574984882027, 0.2224690225557424, 0.13800372602418065, 0.28225357469636947, 0.14194923540344462, 0.14787572989007458, 0.0692283219541423, 0.16835715039633214, 0.18323989788768813, 0.1383493293542415, 0.11323570506647229, 0.09468996897339821, 0.1777816392132081, 0.1409299994702451, 0.12367920717224479], [0.04798872338142246, 0.054812544913147576, 0.03579453201382421, 0.053883123691775836, 0.025870195604511537, 0.03656107037386391, 0.0712747051147744, 0.05574847476964351, 0.006870700217405101, 0.05685646414349321, 0.08928828421630897, 0.22104257019236684, 0.02186169829656137, 0.023374102493107785, 0.04720885604911018, 0.023818539484636858, 0.05397122404247057, 0.08981078586657532, 0.08665745233884081, 0.03865371902065817, 0.052635042811743915, 0.007184824889918673, 0.047214448131853715, 0.0362709685578011, 0.018332953077333514, 0.026318840573367197, 0.008440056826657383, 0.022021286022209097, 0.03844146107439883, 0.057259598761447705, 0.023548870849481318, 0.045487336901715025, 0.033271686334046535, 0.05994434395688586, 0.014730097918800311, 0.07005161605775356, 0.04977860546205193, 0.022905195037310477, 0.04077735233295243, 0.04004622926004231, 0.04071467054018285, 0.08128223256790079, 0.058690429796115495, 0.17372626229189336, 7.291300976648927, 27.170088663697243, 39.878776520490646, 38.14128935337067, 20.42975004762411, 21.455284617841244, 46.86829626560211, 38.340995237231255, 13.599816989153624, 1.4025917812250555, 0.07263768158736639, 0.8074085810221732, 7.4587484914809465, 11.695957649499178, 5.110106868669391, 0.06273470047744922, 0.8038818358909339, 0.360376046737656, 0.03119153916486539, 0.3113989607663825, 1.5993284806609154, 5.611240128055215, 14.504276756197214, 39.05477173626423, 46.068826764822006, 59.28891398012638, 66.01962581276894, 63.96314576268196, 63.24108570814133, 67.5945197045803, 64.35020819306374, 67.88603246212006, 66.94012641906738, 69.05753999948502, 64.53483268618584, 65.90773701667786, 67.31056094169617, 65.88849484920502, 62.66444765031338, 61.05467543005943, 59.925634413957596, 65.28006389737129, 61.94112986326218, 70.1973344385624, 57.72290401160717, 41.15339532494545, 47.45044782757759, 48.17082077264786, 72.85982877016068, 64.28137868642807, 63.58696214854717, 58.00592802464962, 60.3260113298893, 59.76584538817406, 59.96476851403713, 60.449542701244354, 64.5231369137764, 62.78653509914875, 63.475221544504166, 61.9204817712307, 61.84378668665886, 60.08235700428486, 61.56187981367111, 61.54774457216263, 62.07348056137562, 60.63496135175228, 54.9643774330616, 51.63984462618828, 51.21473863720894, 48.964761570096016, 46.20889864861965, 39.55696418881416, 34.491577595472336, 23.522143810987473, 14.013027716428041, 4.411002332344651, 0.5267051747068763, 0.6969557516276836, 0.8566469920333475, 1.9472350808791816, 2.776291100308299, 2.9240281227976084, 5.59633020311594, 8.340353909879923, 3.6142684472724795, 1.184685230255127, 0.6033292505890131, 0.30003567051608115, 6.5195258148014545, 29.95510932058096, 30.305760204792023, 19.44747045636177, 22.18640148639679, 35.79271897673607, 32.45349235832691, 9.169344026595354, 0.7253126206342131, 0.02726732756855199, 0.05324349258444272, 0.028765265451511368, 0.08924072739318945, 0.05085972537926864, 0.0711633161699865, 0.0313226469734218, 0.05252295253740158, 0.02290574793732958, 0.04307893410441466, 0.062355544650927186, 0.04286873932869639, 0.01268870941203204, 0.00580434903895366, 0.009257340461772401, 0.03259215736761689, 0.025176734670822043, 0.028293187169765588, 0.05773979428340681, 0.03271861562097911, 0.04473078042792622, 0.0691079678654205, 0.024470944808854256, 0.07536730074207298, 0.012220086755405646, 0.037742870044894516, 0.08408277135458775, 0.04818465778953396, 0.03570504384697415, 0.020519874888123013, 0.04517715256952215, 0.020985578121326398, 0.021659236699633766, 0.029008246456214692, 0.025894111313391477, 0.01315276693276246, 0.051838774015777744, 0.027812748594442382, 0.105418774910504, 0.03078207217185991, 0.09120741873630323, 0.05769981478806585, 0.06654211843851954, 0.06681929575279355, 0.04548783785139676, 0.09825183253269643, 0.13699109520530328, 0.05590558372205123, 0.04843761882511899, 0.04334852295869496, 0.02927045279648155, 0.1024847460212186, 0.017823659800342284, 0.0557990929519292, 0.04707664986199234, 0.0639045107527636, 0.014355787388922181, 0.023441960765921976, 0.008787904225755483, 0.024111531965900213, 0.018179762664658483, 0.016694081350578927, 0.08437114767730236, 0.02408253996691201, 0.035651193611556664, 0.02222737301053712, 0.038682848316966556, 0.011912728150491603, 0.05009071195672732, 0.018658729932212736, 0.0496538318839157, 0.029958479353808798, 0.018914572356152348, 0.027668361908581574, 0.07460483306203969, 0.13394422276178375, 0.054871515967533924, 0.09594429502612911, 0.2344643702963367, 13.91545845195651, 35.56414224207401, 43.950831815600395, 30.283947475254536, 14.861640930175781, 23.79332385957241, 56.684822514653206, 43.68556424975395, 11.254443190991879, 0.7612205157056451, 0.22119048022432253, 0.6555366679094732, 4.493585675954819, 14.231735430657864, 9.934385474771261, 1.8528718943707645, 1.1691314773634076, 2.3751043528318405, 0.38081880134996027, 0.7157815445680171, 2.4976335279643536, 9.828712195158005, 23.113907016813755, 44.898261576890945, 51.24278113245964, 60.92035263776779, 65.41370272636414, 65.63641637563705, 64.86389502882957, 67.610372453928, 66.82135239243507, 68.85145425796509, 66.54595836997032, 69.36397835612297, 64.19415056705475, 65.29916167259216, 68.20173472166061, 66.33940145373344, 64.6003183722496, 62.76198461651802, 62.909017726778984, 65.78393965959549, 64.98690962791443, 69.1760328412056, 61.74604833126068, 43.350722417235374, 44.72445510327816, 52.586104050278664, 71.6649828851223, 66.95065945386887, 64.75265979766846, 59.33833792805672, 62.093114107847214, 62.9976973682642, 61.455413326621056, 61.25115908682346, 66.47415742278099, 64.30407106876373, 64.31403413414955, 63.41127097606659, 61.276560723781586, 60.74331633746624, 60.70278011262417, 62.68900953233242, 61.74144297838211, 60.82943111658096, 59.18190412223339, 55.53664952516556, 56.2944732606411, 54.55990053713322, 51.55577413737774, 46.57764606177807, 41.2473338842392, 30.051994621753693, 19.506230503320694, 7.767014550045133, 0.9790548705495894, 1.3731278060004115, 4.5758056640625, 4.288039980456233, 5.106467613950372, 5.983426356688142, 9.061252176761627, 3.8299002265557647, 6.233526086434722, 0.779975299956277, 0.31578505353536457, 0.18703679961618036, 5.471957651898265, 32.98090785741806, 42.081415727734566, 22.725529856979847, 19.916243702173233, 35.45783914625645, 38.32695119082928, 14.425282794982195, 1.4122832799330354, 0.05120484631333966, 0.06493691238574684, 0.08116157419863157, 0.01820442052121507, 0.030547926435247064, 0.014780364508624189, 0.03180764048011042, 0.025598795909900218, 0.11857945777592249, 0.061893921374576166, 0.07970088656293228, 0.04999955024686642, 0.040946910812635906, 0.012091480912204133, 0.07714646621025167, 0.0759170985838864, 0.05264601546514314, 0.0362430155655602, 0.038388345565181226, 0.018905425386037678, 0.06588979289517738, 0.051290519841131754, 0.02116840063536074, 0.06492373926448636, 0.059429983666632324, 0.02537159110943321, 0.07784555447869934, 0.018925444819615223, 0.04083017469383776, 0.012102593645977322, 0.025930639822036028, 0.010042571666417643, 0.02523904353438411, 0.06741388962836936, 0.034043980049318634, 0.14912212238414213, 0.08900203043594956, 0.15804627008037642, 0.16406249022111297, 0.10241645359201357, 0.11152136619784869, 0.1914787315763533, 0.19886508991476148, 0.12522293371148407, 0.14305868680821732, 0.1309843745548278, 0.35066370852291584, 0.09748549084179103, 0.2624870353611186, 0.24952322943136096, 0.07752059769700281, 0.19145743193803355, 0.1779426258872263, 0.1790114669711329, 0.16694050922524184, 0.21211874904111028, 0.10272529092617333, 0.12175703726825304, 0.14675971789984033, 0.14242639183066785, 0.1475379487965256, 0.07592824564198963, 0.18641792266862467, 0.11199746135389432, 0.18991674820426852, 0.13539411214878783, 0.12532324239145964, 0.1041804495616816, 0.16535667702555656, 0.08965209985035472, 0.19172662374330685, 0.11586506749154069, 0.09869942179648206, 0.16962056775810197, 0.11979097675066441, 0.2688014355953783, 0.2072166113066487, 0.2304127041134052, 0.27536258508916944, 12.438594549894333, 40.565297082066536, 54.75220441818237, 48.74411880970001, 28.102661222219467, 28.560549952089787, 57.4154207110405, 48.47692474722862, 18.94158460199833, 1.8681068206205964, 0.28388594335410744, 4.212932260707021, 13.750050477683544, 19.01274338364601, 8.23788670822978, 1.2239766656421125, 2.5940445670858026, 1.0142073780298233, 0.2257410329184495, 0.5396610544994473, 2.2520028334110975, 8.291716519743204, 17.886504717171192, 44.97991539537907, 53.65684859454632, 60.51446981728077, 67.00039878487587, 68.46432343125343, 70.01979276537895, 71.03557705879211, 69.98962998390198, 71.95334181189537, 69.62382361292839, 70.94302922487259, 66.37665465474129, 67.10293248295784, 71.0624948143959, 68.56184139847755, 66.29128083586693, 64.75050151348114, 66.87592506408691, 69.69392225146294, 68.20751041173935, 72.27113395929337, 62.92960502207279, 48.93468238413334, 47.90052227675915, 57.550237476825714, 74.3466129899025, 71.2398236989975, 67.02825888991356, 61.959049701690674, 63.96870106458664, 65.02308368682861, 62.963753789663315, 60.27497626841068, 66.16269573569298, 65.95636680722237, 65.79108327627182, 62.5517912954092, 60.428233444690704, 60.76569713652134, 61.12134285271168, 63.00193794071674, 62.188196405768394, 61.38930447399616, 56.53335124254227, 55.21430902183056, 56.782355681061745, 53.045024424791336, 50.56986764073372, 42.440724447369576, 38.39799217879772, 24.688183441758156, 15.801928974688053, 5.492845606058836, 1.2137384712696075, 1.1144484928809106, 3.4677209984511137, 5.848783431574702, 8.640356361865997, 9.414889700710773, 12.617704588919878, 14.57118546590209, 9.023795686662197, 2.175543811172247, 1.3422365323640406, 0.40154081129003316, 7.637943075969815, 38.495665937662125, 39.69500318169594, 26.37339111417532, 31.727991588413715, 47.55606696009636, 44.366043135523796, 16.140648499131203, 1.1641593254171312, 0.3005429729819298, 0.21799712267238647, 0.17514845472760499, 0.16200504906009883, 0.1442657454754226, 0.13428011880023405, 0.11774974409490824, 0.1575069216778502, 0.20838110038312152, 0.10898598935455084, 0.20248381682904437, 0.14000066730659455, 0.12343291062279604, 0.12744916894007474, 0.14088143332628533, 0.17809993150876835, 0.13443588075460866, 0.12631056597456336, 0.11763391710701399, 0.14874034677632153, 0.14078462758334354, 0.15517916064709425, 0.16653360449708998, 0.1661428192164749, 0.15273351687937975, 0.1607388412230648, 0.17972260771784931, 0.11265699315117672, 0.19179251161403954, 0.15596880577504635, 0.08743529731873423, 0.13019946432905272, 0.10164826395339333, 0.1505693994113244, 0.12515544280176982], [0.1154849914018996, 0.06966829678276554, 0.026281017017026898, 0.03315336572995875, 0.004243553103151498, 0.05120172929309774, 0.047233807053999044, 0.047635746814194135, 0.026057064678752795, 0.0969502613588702, 0.03224129221052863, 0.09067587772733532, 0.025729842491273303, 0.0019391551131775486, 0.06892197823617607, 0.07676906927372329, 0.05162301313248463, 0.11037693737307563, 0.0359609215229284, 0.01710946326056728, 0.06887485928018577, 0.14310719358036295, 0.05654404223605525, 0.0802521019068081, 0.11566565983230248, 0.02563678459409857, 0.04450817694305442, 0.030462720460491255, 0.039973810489755124, 0.07444480375852436, 0.05546228407183662, 0.04832428916415665, 0.02891761909268098, 0.02917002722824691, 0.06709174558636732, 0.03577739582397044, 0.02947988687083125, 0.048476036099600606, 0.039133498939918354, 0.09718708810396492, 0.034104149672202766, 0.11256150100962259, 0.04409543893416412, 0.050813463603844866, 0.1730319089256227, 3.4407379338517785, 22.66944296658039, 42.372259721159935, 39.80621561408043, 33.34297522902489, 24.884059131145477, 26.633770242333412, 42.517822310328484, 20.648221224546432, 4.094556737691164, 0.7525492028798908, 1.9130243291147053, 4.606240605935454, 11.43653891980648, 4.6060833893716335, 1.7187830270268023, 7.094835843890905, 0.8947132306639105, 0.956975620938465, 0.1190487177518662, 0.18336863082367927, 0.443667191429995, 5.198164293542504, 20.004056990146637, 36.017161533236504, 52.95267418026924, 66.18677124381065, 65.25830626487732, 68.06421250104904, 66.40427157282829, 68.0902411043644, 65.2137878537178, 66.11050933599472, 65.37775665521622, 63.98353546857834, 63.20585019886494, 66.25685468316078, 60.02558805048466, 61.377791091799736, 64.38814535737038, 65.4261888563633, 61.7743644118309, 63.37883211672306, 47.04574674367905, 37.05645516514778, 34.57407496869564, 40.20978435873985, 58.84776525199413, 65.86111351847649, 61.716105937957764, 60.80138862133026, 63.94940569996834, 62.22745589911938, 62.40468218922615, 63.98681849241257, 67.68236339092255, 68.33594352006912, 65.12933358550072, 65.40408924221992, 66.85552775859833, 61.73485033214092, 53.62151049077511, 47.95328624546528, 39.869695007801056, 36.951892375946045, 26.803537532687187, 21.587855704128742, 16.824678294360638, 15.783536061644554, 12.653346676379442, 8.204331658780575, 4.005097188055515, 2.15304521843791, 0.14452821342274547, 0.2990543138002977, 0.5467321781907231, 1.7336936644278467, 3.1005210522562265, 4.2092906311154366, 3.9535189932212234, 4.73548449575901, 8.088238388299942, 5.12531460262835, 3.0137308593839407, 0.13972210959764197, 0.4537937371060252, 12.174726258963346, 31.720743477344513, 32.41461664438248, 25.951410457491875, 25.034791342914104, 35.42563207447529, 26.65012076497078, 6.06106854043901, 0.05426176743640099, 0.05434247599623632, 0.025782288212212734, 0.04138579468417447, 0.06404429426766, 0.027610333381744567, 0.0075298716092220275, 0.022483892644231673, 0.016465731787320692, 0.05071341467555612, 0.024265926513180602, 0.03843726794002578, 0.02702756191865774, 0.01871805350674549, 0.0546597626816947, 0.012760642075591022, 0.050182445120299235, 0.013943575377197703, 0.09563965824781917, 0.05473601835547015, 0.028529032424557954, 0.06615949678234756, 0.044435765594244, 0.021777193651359994, 0.026669676044548396, 0.013426783625618555, 0.044439773191697896, 0.009404112224729033, 0.0556434831378283, 0.13058981916401535, 0.09614699039957486, 0.023407497283187695, 0.016349953039025422, 0.07186543982243165, 0.03324358862300869, 0.031197513453662395, 0.04376761004095897, 0.03334309578349348, 0.025832693027041387, 0.00755035859583586, 0.047840564729995094, 0.03516832264722325, 0.04090555834409315, 0.028744205155817326, 0.048458862802363, 0.02761213865596801, 0.08201538541470654, 0.033964971007662825, 0.07664902688702568, 0.06932976612006314, 0.01710398621071363, 0.033326553311781026, 0.04522837931290269, 0.00874823550475412, 0.033416293808841147, 0.03937901623430662, 0.04501156086917035, 0.05159842206921894, 0.03290006330644246, 0.09510108167887665, 0.06501376919914037, 0.03668677163659595, 0.04755003617901821, 0.046222174423746765, 0.03130246797809377, 0.015604812651872635, 0.0750555245031137, 0.02149439271306619, 0.08178368691005744, 0.01077677001376287, 0.01631496263144072, 0.06574111845111474, 0.020302861630625557, 0.023371753595711198, 0.05114421284815762, 0.02105453662807122, 0.060176309634698555, 0.04623597094905563, 0.025426517458981834, 0.03621119227318559, 0.07175823659054004, 0.1821315151755698, 8.33156118169427, 34.23825278878212, 49.188675954937935, 32.170415148139, 22.81059969216585, 27.185071259737015, 44.90663252770901, 53.34181509912014, 22.5946743786335, 2.671894314698875, 0.6426804733928293, 0.5690208915621042, 1.0167906456626952, 4.4264185801148415, 2.7112602023407817, 1.5996628627181053, 7.485351813957095, 3.3685057098045945, 1.534378209616989, 0.3495387907605618, 0.5509376025293022, 1.3551221159286797, 10.475535336881876, 27.60920450091362, 41.64798438549042, 58.0825737118721, 66.08769536018372, 67.7375516295433, 67.6647399365902, 66.86267897486687, 68.79410773515701, 67.70352825522423, 65.38176164031029, 65.50144001841545, 64.84545081853867, 66.27467572689056, 67.98184052109718, 63.116118013858795, 61.490785628557205, 62.00338572263718, 67.23574295639992, 63.12490314245224, 65.06993517279625, 50.932850763201714, 40.524958446621895, 38.14302586019039, 45.48538327217102, 62.01075352728367, 67.47023597359657, 64.2736878991127, 62.04672619700432, 65.05802661180496, 64.55648392438889, 63.692429289221764, 63.025633469223976, 67.67559215426445, 68.02210316061974, 63.871867060661316, 61.87081463634968, 65.20311802625656, 62.26208724081516, 56.938398107886314, 51.893891394138336, 45.63165262341499, 42.24532753229141, 32.369767650961876, 28.17761979997158, 22.979722917079926, 20.847782716155052, 17.33796615153551, 12.647472191601992, 8.36219608783722, 5.4230419266968966, 1.3563677365891635, 1.572167300619185, 1.7936599091626704, 3.4044788544997573, 6.258809929713607, 8.626919332891703, 4.848159374669194, 5.781877096742392, 3.2200063532218337, 0.7498093717731535, 1.2340243952348828, 0.11293941002804786, 0.5087618844117969, 12.186359334737062, 38.834524154663086, 41.1500933021307, 26.456842236220837, 21.494800597429276, 35.92053271830082, 34.258099123835564, 10.550624057650566, 0.14174475887557492, 0.05122472844959702, 0.008949545845098328, 0.08641295178676955, 0.07019236436462961, 0.04868556294240989, 0.04353708412963897, 0.02835167026205454, 0.05926059959165286, 0.12706961977528408, 0.02763423053693259, 0.03397296022740193, 0.02842245259671472, 0.05196711361350026, 0.03178919811034575, 0.06508477046736516, 0.07499460160033777, 0.011669935465761228, 0.055169039260363206, 0.1137460429163184, 0.0229539244537591, 0.025691517985251267, 0.06686265202006325, 0.055174731533043087, 0.05818554673169274, 0.04186455415037926, 0.030020752965356223, 0.09650139560108073, 0.019333939599164296, 0.10102501575602219, 0.12716578727122396, 0.06792197134927846, 0.05600289412541315, 0.011763956299546408, 0.05689560872269794, 0.026812504220288247, 0.0520530877111014, 0.2691441000206396, 0.15283392946003005, 0.0936923740664497, 0.1232474776043091, 0.16975976497633383, 0.10743597682449035, 0.15540271037025377, 0.15832892444450408, 0.1384584399056621, 0.2778148785000667, 0.18201308324933052, 0.21402440615929663, 0.1560030781547539, 0.18061244278214872, 0.15001753839896992, 0.17073727736715227, 0.19804690178716555, 0.13120920077199116, 0.09788494440726936, 0.13705515739275143, 0.1265490922378376, 0.26141528505831957, 0.22914432920515537, 0.1952820157748647, 0.21193914930336177, 0.13508183124940842, 0.14984472189098597, 0.27151036367285997, 0.09939747105818242, 0.13739678281126544, 0.16405765141826123, 0.09999412068282254, 0.14604626165237278, 0.05827468237839639, 0.18163826898671687, 0.20071183535037562, 0.11651968627120368, 0.13793363759759814, 0.1671344620990567, 0.2477837837068364, 0.0949318274797406, 0.20371327351313084, 0.26588093605823815, 0.09154341125395149, 0.21976854011882097, 7.189081236720085, 38.60987260937691, 59.14310820400715, 51.565854996442795, 44.47405233979225, 34.168610125780106, 35.99557489156723, 51.2447190284729, 26.380164250731468, 4.87209334038198, 1.1964074824936688, 3.307690448127687, 8.082200512290001, 20.962965935468674, 9.569422658532858, 5.508450418710709, 13.04539443925023, 2.633894453756511, 2.1143891802057624, 0.1350236765574664, 0.461444478132762, 1.4664177875965834, 7.969410214573145, 25.10229092091322, 40.94576686620712, 56.61276318132877, 69.28749606013298, 68.36923733353615, 70.61694592237473, 66.04362532496452, 69.80538547039032, 66.50570333003998, 64.17175456881523, 64.12663578987122, 62.941733971238136, 65.48025995492935, 69.21071738004684, 65.2389957010746, 62.391333505511284, 67.4746285378933, 67.92265489697456, 65.42294383049011, 64.00267124176025, 54.59603279829025, 43.52451749145985, 38.376386538147926, 48.6584410071373, 59.50351506471634, 69.4033594429493, 66.06663689017296, 63.81006717681885, 67.74244576692581, 66.17948323488235, 66.22277051210403, 65.44761970639229, 67.97497808933258, 67.85448655486107, 63.80918562412262, 65.20978286862373, 67.44552209973335, 63.03841598331928, 55.8926410228014, 51.162195056676865, 41.31869025528431, 39.16009068489075, 29.34618439525366, 24.543768391013145, 19.646093398332596, 17.98370160162449, 15.274390932172537, 10.794659312814474, 5.972003694623709, 3.4554870799183846, 0.6290828436613083, 1.0699719982221723, 1.5440243482589722, 4.535884531214833, 6.910340543836355, 10.978822130709887, 11.767676901072264, 13.00095772370696, 17.138423658907413, 12.954576462507248, 7.007293766364455, 0.5609028053004295, 0.7247538724914193, 15.417149271816015, 40.21372474730015, 39.55326318740845, 35.212140530347824, 33.50489214062691, 47.17759966850281, 37.917321771383286, 9.425357189029455, 0.1907624996965751, 0.15061379468534142, 0.0790381635306403, 0.12110251496778801, 0.11766482755774632, 0.13087443279800937, 0.14035354368388653, 0.10020290908869356, 0.23836164007661864, 0.1755124781630002, 0.12276000532438047, 0.1556785369757563, 0.09853744806605391, 0.10009511213866062, 0.16425338544650003, 0.17433040018659085, 0.15886445820797235, 0.15091535897227004, 0.19913652300601825, 0.17183405288960785, 0.09096990179386921, 0.1498494716361165, 0.09916203955071978, 0.17138873459771276, 0.14979860483435914, 0.11253442004090175, 0.11818976345239207, 0.15183489478658885, 0.15733158186776564, 0.2269428371801041, 0.22345181903801858, 0.11976533554843627, 0.12213209643959999, 0.10427798260934651, 0.22878968651639298, 0.11721948700142093, 0.1416069272090681], [0.015137457212404115, 0.08325155853526667, 0.02222422630438814, 0.06440003533498384, 0.02685904059035238, 0.06497276554000564, 0.07264498432050459, 0.03925124809029512, 0.07540955863078125, 0.010493688914721133, 0.04447627943591215, 0.08024309965549037, 0.0548395627993159, 0.060640894080279395, 0.05222538842645008, 0.03780046812607907, 0.15071385103510693, 0.04982701204426121, 0.11788321193307638, 0.034738734175334685, 0.046219109353842214, 0.023628796443517786, 0.062364747282117605, 0.05781874766398687, 0.12366714727249928, 0.07692312428844161, 0.020583219047694, 0.05463190987939015, 0.025841173919616267, 0.012252895248821005, 0.0438961240433855, 0.04440992030140478, 0.05281473902869038, 0.023726433391857427, 0.015463584732060554, 0.014359628930833424, 0.06957143166800961, 0.01240829355083406, 0.07747276627924293, 0.011363535159034654, 0.03673373474157415, 0.08364301174879074, 0.031413819815497845, 0.06432654045056552, 0.045941442222101614, 0.038654939853586257, 1.4750693296082318, 10.177604723721743, 40.326707884669304, 37.32177592813969, 18.34179248660803, 16.03308767080307, 24.895384423434734, 41.96003884077072, 30.06754908710718, 9.41460756585002, 0.5472168303094804, 0.5417602637317032, 2.4616128858178854, 2.4115242110565305, 0.7633264339528978, 6.75851684063673, 5.954607278108597, 1.6324495221488178, 1.0843120724894106, 0.6640760565642267, 0.012697416659648297, 0.2218980883480981, 1.340467727277428, 6.042804820463061, 17.535242065787315, 29.91236351430416, 42.196606546640396, 52.61029355227947, 52.830780521035194, 53.472197502851486, 53.50326843559742, 58.72633136808872, 60.4981154948473, 65.12175679206848, 68.54999363422394, 61.55506677925587, 63.637438639998436, 60.0280237197876, 68.0201044678688, 63.559394627809525, 65.18493980169296, 71.89726442098618, 37.897521033883095, 31.36283118277788, 28.521360754966736, 38.136452212929726, 57.98573590815067, 70.60396581888199, 65.2070926129818, 70.01485303044319, 68.27699348330498, 65.74093356728554, 63.29509221017361, 65.89762195944786, 67.48769223690033, 65.47593578696251, 64.98266145586967, 57.337711080908775, 45.989745408296585, 35.81239812076092, 21.040236689150333, 13.186611011624336, 8.733792398124933, 6.915443670004606, 4.5890821516513824, 2.18020164873451, 1.7955167032778263, 0.9687988646328449, 0.5422832106705755, 0.39241429476533085, 0.2790301007917151, 1.1394212278537452, 1.4320295141078532, 2.0243760477751493, 1.396556873805821, 1.8883919133804739, 8.203552700579166, 8.048106841742992, 4.498552959412336, 6.41848923638463, 4.510571714490652, 0.5769169866107404, 0.18467307410901412, 2.204526993446052, 21.68612603098154, 30.77074885368347, 26.72415029257536, 22.313911244273186, 29.56240799278021, 35.387539118528366, 18.85513924062252, 2.18705125618726, 0.15979481453541666, 0.08146016247337684, 0.06368462723912671, 0.06701412436086684, 0.04769693317939527, 0.06732781534083188, 0.04842700240260456, 0.06416876727598719, 0.01491254935899633, 0.05756384962296579, 0.027509037645359058, 0.03314301648060791, 0.038300935411825776, 0.06350437441142276, 0.02695446408324642, 0.030475203384412453, 0.03866007551550865, 0.014885295840940671, 0.02646753357112175, 0.07266783504746854, 0.048215994975180365, 0.06364372748066671, 0.03180369967594743, 0.02640405211423058, 0.021619986364385113, 0.026857098018808756, 0.039048638063832186, 0.012860492479376262, 0.027908897536690347, 0.05196116901061032, 0.08449286731774919, 0.030015995798748918, 0.050151553223258816, 0.03322143922559917, 0.023872434248914942, 0.025312343605037313, 0.06173976245918311, 0.04255645842931699, 0.04803411313332617, 0.05877637420780957, 0.03512013870931696, 0.08496930386172608, 0.03848860229481943, 0.10245624755043536, 0.04548994555079844, 0.04641368934244383, 0.05777432641480118, 0.018055519722111057, 0.0590415955230128, 0.04690845693403389, 0.018098100445058662, 0.054686183138983324, 0.09134440435445867, 0.061496089401771314, 0.05854288341652136, 0.03956768872740213, 0.07256456519826315, 0.09611686662537977, 0.03622207215812523, 0.027678521910274867, 0.0838079243840184, 0.045512191427405924, 0.052419998100958765, 0.010228324736090144, 0.04314934165449813, 0.05941466202784795, 0.051554164092522115, 0.07523445630795322, 0.02929596226749709, 0.08032102516153827, 0.05842624377692118, 0.021149078820599243, 0.030314691684907302, 0.03538090342772193, 0.036199826281517744, 0.01509573088696925, 0.04677314485888928, 0.02688905304239597, 0.05517670564586297, 0.0859539705561474, 0.07087618665536866, 0.05474867197335698, 0.049931380272028036, 0.06377768513630144, 4.2125931289047, 21.13805864006281, 48.01596388220787, 38.64879012107849, 15.82169646397233, 13.667661398649216, 41.43468663096428, 55.55598668754101, 33.943502604961395, 4.958856459707022, 0.5207568313926458, 0.45599824225064367, 1.528975849505514, 0.4684674512827769, 1.0699027706868947, 6.140908906236291, 4.919438324868679, 3.9618752198293805, 2.2586422646418214, 1.2121353135444224, 0.7229169679339975, 0.9329985512886196, 2.7684727823361754, 9.495246838778257, 24.738948717713356, 37.518669962882996, 46.52841970324516, 56.22096240520477, 57.121514081954956, 57.238376811146736, 54.63470332324505, 59.18884634971619, 61.81750349700451, 62.99216106534004, 65.93900933861732, 63.80829647183418, 63.56852553784847, 61.45137794315815, 69.3743745982647, 65.35291358828545, 66.18262946605682, 69.00271654129028, 44.25848990678787, 33.732955902814865, 29.7195827588439, 42.221259623765945, 58.89479152858257, 68.11840519309044, 66.81427717208862, 70.96348732709885, 70.9638749063015, 69.05052557587624, 66.13918259739876, 66.35177358984947, 67.28273883461952, 65.02868458628654, 64.79786217212677, 59.7765988111496, 51.90733887255192, 41.900306046009064, 25.14936849474907, 17.78256319463253, 12.451746594160795, 10.442252922803164, 8.211402129381895, 5.060218395665288, 4.194066748023033, 2.4926066352054477, 1.4103814819827676, 1.6571099613793194, 0.6393766100518405, 1.7544191773049533, 5.009405147284269, 4.478452512994409, 3.037902074865997, 5.711270710453391, 5.704183615744114, 7.553056105971336, 4.774433830752969, 1.3284913636744022, 1.5673629334196448, 0.15868724818574265, 0.1606078670010902, 1.4498293027281761, 21.01618967950344, 43.356338515877724, 34.18803848326206, 22.327434718608856, 27.192617654800415, 39.46165390312672, 28.66928681731224, 6.398374065756798, 0.07608320607687347, 0.13678896386409178, 0.020616650945157744, 0.0431187391950516, 0.050225823651999235, 0.05274853574519511, 0.05944800672295969, 0.04599955980665982, 0.09182325287838466, 0.06655043049249798, 0.07222191561595537, 0.11146977951284498, 0.009268383619200904, 0.14732024719705805, 0.054599782306468114, 0.05308204948960338, 0.04859232692979276, 0.02848235504643526, 0.09366253230837174, 0.07508204143960029, 0.06315894919680431, 0.118580363196088, 0.021324444605852477, 0.03042176875169389, 0.050251023276359774, 0.059889451003982686, 0.028027693115291186, 0.026480164924578276, 0.08181548793800175, 0.04033193756185938, 0.023863094320404343, 0.06496889895061031, 0.08414805808570236, 0.05149833232280798, 0.008293752616737038, 0.04137653268116992, 0.033592479667277075, 0.0155151862600178, 0.1305892996606417, 0.25154730363283306, 0.07082753887516446, 0.15682329976698384, 0.145343522017356, 0.15440845512785017, 0.1434271186008118, 0.1810780365485698, 0.2322848458425142, 0.14704632048960775, 0.13288740447023883, 0.1603087518014945, 0.12893819919554517, 0.21159342722967267, 0.1726006023818627, 0.20145389396930113, 0.2695151144871488, 0.15441654453752562, 0.2505681139882654, 0.15443322801729664, 0.056356764980591834, 0.174270523712039, 0.1557399719604291, 0.2182515012100339, 0.11482073212391697, 0.19937542034313083, 0.09613840375095606, 0.11514266836456954, 0.09481821951339953, 0.24581317382398993, 0.14865160075714812, 0.21270008815918118, 0.15742239105748013, 0.10296758729964495, 0.08829381375107914, 0.12775509705534205, 0.10886294126976281, 0.1842098997440189, 0.21300732245435938, 0.2162232412956655, 0.18487949506379664, 0.159020917781163, 0.15098270145244896, 0.15255590609740466, 0.1349905173992738, 0.2282178617315367, 3.0916110053658485, 23.332951962947845, 58.26006218791008, 49.74602244794369, 26.78067035973072, 22.692103050649166, 34.03695859014988, 50.58407887816429, 39.4378861784935, 10.928166098892689, 1.2176274438388646, 1.0647397977299988, 6.418662127107382, 10.092893969267607, 3.820818238891661, 12.341467961668968, 12.292049713432789, 4.186344612389803, 2.66218607313931, 1.4602203201502562, 0.6744109082501382, 0.7906577142421156, 2.4869549134746194, 7.616056250408292, 21.624098159372807, 33.728772327303886, 45.025277361273766, 56.00672610104084, 55.13122648000717, 55.32630041241646, 54.33190897107124, 58.45933109521866, 61.87362268567085, 62.317689657211304, 67.89562314748764, 61.59867703914642, 63.92422065138817, 62.76964120566845, 70.64473763108253, 67.06853672862053, 65.7687708735466, 69.23068910837173, 47.55484342575073, 36.93929985165596, 33.13159637153149, 46.764497235417366, 61.460387259721756, 69.17759075760841, 69.58803713321686, 74.23651769757271, 73.26244756579399, 69.40613329410553, 67.54611790180206, 68.19301798939705, 68.83140653371811, 64.75620880723, 63.9967967569828, 57.42390565574169, 47.27732911705971, 37.02832527458668, 21.46507479250431, 14.466754719614983, 10.231970306485891, 8.32818791270256, 6.339846756309271, 3.270714869722724, 2.540353685617447, 1.6707048006355762, 0.8575266448315233, 0.6286089378409088, 0.27367161645088345, 3.3105692686513066, 4.246285920962691, 6.74412083812058, 3.029994461685419, 7.073113359510899, 16.26424066722393, 19.754689671099186, 13.76997945830226, 13.6019192263484, 10.526001378893852, 1.1915596551261842, 0.40514010877814144, 3.052275753580034, 26.58086948096752, 38.90959292650223, 35.04553087055683, 33.17073807120323, 39.45050910115242, 48.75829204916954, 30.05103327333927, 5.143828159198165, 0.1911684247897938, 0.1926426714635454, 0.18647683435119689, 0.24832378519931808, 0.196540015458595, 0.14272141037508845, 0.11512438184581697, 0.1328104140702635, 0.1408341436763294, 0.20020040654344484, 0.19184009812306613, 0.18478485639207065, 0.11225447451579385, 0.2308075563632883, 0.11372411245247349, 0.09227247486705892, 0.12990373332286254, 0.1521491794846952, 0.180357025237754, 0.1257805389468558, 0.1513199185137637, 0.2178524187183939, 0.18992906785570085, 0.11346577826770954, 0.16693933663191274, 0.11979389339103363, 0.1181950698082801, 0.16850345738930628, 0.2236147501389496, 0.11627710788161494, 0.09785688380361535, 0.19031330739380792, 0.22125264251371846, 0.11930152293643914, 0.11437631183071062, 0.1880335039459169, 0.08222846343414858, 0.11713606218108907], [0.04467781705898233, 0.14453041017986834, 0.018823546088242438, 0.03263366568717174, 0.08030244178371504, 0.03677978500491008, 0.07252377676195465, 0.033896255554282106, 0.011514521393110044, 0.04905250301817432, 0.016751412258599885, 0.13542238797526807, 0.028834448457928374, 0.02642240171553567, 0.06197402879479341, 0.052235823022783734, 0.06021638931997586, 0.035613403451861814, 0.043864423205377534, 0.05987825199554209, 0.03388051460206043, 0.04642145962861832, 0.058590351181919686, 0.04710050248831976, 0.04308489355025813, 0.028457652661018074, 0.0534003009670414, 0.07648168000741862, 0.07438122396706603, 0.04690660898631904, 0.03049289432965452, 0.0033563494162081042, 0.012795397778972983, 0.12173454277217388, 0.07022193152806722, 0.013307603985595051, 0.010291151247656671, 0.03918897818948608, 0.06488448707386851, 0.04204935634334106, 0.022294774862530176, 0.09234073761035688, 0.028834372387791518, 0.0810029475542251, 0.1307743022334762, 0.008007380092749372, 0.013435954715532716, 0.7883925607893616, 12.691632471978664, 42.54443608224392, 41.920277774333954, 26.452217884361744, 23.53461094200611, 26.26516532152891, 34.11806523799896, 38.43890078365803, 18.01982246339321, 1.893068749923259, 0.06555914384080097, 0.47172827005852014, 0.3081149572972208, 2.911984194070101, 2.6285201171413064, 3.536698459647596, 4.260527556762099, 2.2957085631787777, 1.4588373131118715, 0.923611392499879, 0.024691414619155694, 0.10079120213049464, 1.1416395963169634, 3.9068479975685477, 10.162751320749521, 13.647772315889597, 16.749242842197418, 14.846711531281471, 16.305191069841385, 20.79568561166525, 28.368762843310833, 35.37657670676708, 54.00124691426754, 63.07737909257412, 63.58234539628029, 56.9800628721714, 53.63357104361057, 56.57596975564957, 51.94748751819134, 46.96761533617973, 30.433336459100246, 37.404413893818855, 39.75168474018574, 33.302651792764664, 46.492800414562225, 70.3494630753994, 64.38604027032852, 69.45828169584274, 66.0502901673317, 67.42387846112251, 63.74765172600746, 64.29185852408409, 68.26130032539368, 65.04095792770386, 56.56571410596371, 39.12430800497532, 21.644352972507477, 8.719421569257975, 3.0638340208679438, 0.8429202879779041, 0.3707649267744273, 0.1348798631806858, 0.21660779253579676, 0.17342918057693169, 0.18293800705578178, 0.2338737394893542, 0.71910529746674, 1.2581052468158305, 1.538501582108438, 1.5827388083562255, 5.286996401846409, 2.6397556392475963, 2.6377700082957745, 6.009041257202625, 3.8275673892349005, 5.595573568716645, 2.3469082033261657, 0.4094963672105223, 0.21417774871224537, 0.8986201928928494, 9.14435276761651, 28.248932473361492, 28.7760990858078, 28.874373212456703, 23.360487185418606, 31.7184180021286, 33.353812247514725, 16.490022651851177, 0.57068110560067, 0.053841236876905896, 0.030389208877750207, 0.0260574617277598, 0.021857987558178138, 0.03776306388317607, 0.03830407098575961, 0.04141136167163495, 0.031644160189898685, 0.02811617752740858, 0.12259088471182622, 0.06053737561160233, 0.05595781978627201, 0.08425876425462775, 0.03415595900150947, 0.02853770256479038, 0.13375435170019045, 0.04146944214880932, 0.06205307123309467, 0.05946261589997448, 0.032171103594009764, 0.0660487163986545, 0.10026015093899332, 0.03831628673651721, 0.03587689185224008, 0.04042748907522764, 0.015716082853032276, 0.08281550224637613, 0.05925476631091442, 0.057783065203693695, 0.018894890599767677, 0.05349186343664769, 0.059521264120121486, 0.08464947532047518, 0.09585762702045031, 0.07224964225315489, 0.016703809051250573, 0.05901702672417741, 0.04582295834552497, 0.03753702054382302, 0.029097667829773854, 0.0910172433941625, 0.056373359402641654, 0.014980292598920641, 0.0021278206486385898, 0.06823290896136314, 0.05586865445366129, 0.01910806880914606, 0.03772725525777787, 0.04748755105538294, 0.03689146338729188, 0.05770366653450765, 0.06404747808119282, 0.03682174974528607, 0.0974159812903963, 0.08641499269288033, 0.09643149271141738, 0.04738148702017497, 0.04131257068365812, 0.0509306227468187, 0.06410597416106611, 0.01459669594623847, 0.05384758966101799, 0.052971410113968886, 0.026001984333561268, 0.022038565075490624, 0.015777593907841947, 0.10048224605270661, 0.05298753698298242, 0.010144447205675533, 0.043020875891670585, 0.030516700571752153, 0.033994656914728694, 0.054445905407192186, 0.029035551924607717, 0.02814221577864373, 0.0731526875460986, 0.058172128701698966, 0.11402832620660774, 0.026407525365357287, 0.09606542836991139, 0.10959222752717324, 0.04664264932216611, 0.13393546541919932, 0.10032626145402901, 0.04356185701908544, 0.16865058074472472, 1.7954245582222939, 22.8758554905653, 50.703046694397926, 37.14581876993179, 20.712209790945053, 14.125500731170177, 27.599182538688183, 50.846071019768715, 52.291274070739746, 15.58928383514285, 1.2609992665238678, 0.10447609151015058, 0.36564066424034536, 0.28423225914593786, 1.834594993852079, 1.5704281814396381, 4.0376984886825085, 3.934854157269001, 4.180882880464196, 2.96794094145298, 1.9455142482183874, 0.5324920860584825, 0.5027117778081447, 2.242697370238602, 7.062355186790228, 14.441158343106508, 19.159345217049122, 21.72950830310583, 21.438005045056343, 22.1367172524333, 25.20355548709631, 34.41503830254078, 44.766435250639915, 61.346712559461594, 64.28099870681763, 65.69139182567596, 57.58988834917545, 55.43525576591492, 58.984079137444496, 55.162639394402504, 55.90986169874668, 36.94219529628754, 39.164342656731606, 40.09265184402466, 38.24869818985462, 48.87645810842514, 67.59607762098312, 67.42294371128082, 70.5258496105671, 68.80176052451134, 70.2944116294384, 64.35112774372101, 64.61079820990562, 67.12492570281029, 65.4454918205738, 55.972163155674934, 42.941951751708984, 24.47147347033024, 11.9218260794878, 5.306998053565621, 2.103820047341287, 1.4525582687929273, 1.352110777515918, 0.7530850928742439, 1.644010164309293, 1.1971086636185646, 2.0821854332461953, 1.3425146299414337, 2.6116397604346275, 3.809752995148301, 5.37915475666523, 6.2880137376487255, 6.044753165915608, 5.571640552952886, 4.5609275624156, 2.7585717011243105, 0.8665207028388977, 0.5834784032776952, 0.09356315131299198, 0.21292691817507148, 0.3678044106345624, 8.301881924271584, 36.153749004006386, 43.74623939394951, 26.702375560998917, 18.563331998884678, 28.082594498991966, 38.19555044174194, 23.98265440016985, 1.8422748567536473, 0.12846061232266948, 0.0426961974153528, 0.02723060239077313, 0.02799863988911966, 0.03953462604840752, 0.021548463737417478, 0.014318613211798947, 0.06950011869776063, 0.08544974058168009, 0.10525863428483717, 0.0817420004750602, 0.017670435991021805, 0.0804016669280827, 0.04306010952859651, 0.0519762012118008, 0.12580985378008336, 0.008957280879258178, 0.046051725366851315, 0.07962440824485384, 0.032329481618944556, 0.025665125358500518, 0.05082733434392139, 0.02957323977170745, 0.016712865108274855, 0.042226328878314234, 0.01474603090173332, 0.0705645143170841, 0.03785795488511212, 0.0949727495026309, 0.010336475133954082, 0.010367996001150459, 0.045166851559770294, 0.03159979089105036, 0.0986828125314787, 0.09244851971743628, 0.04162103694397956, 0.028250278046471067, 0.045074999652570114, 0.0214583373235655, 0.1398653886280954, 0.22174468642333522, 0.16398545529227704, 0.11173441453138366, 0.1776575669646263, 0.18646303040441126, 0.16193381772609428, 0.15044226951431483, 0.12752771785017103, 0.1716077869059518, 0.11973386848694645, 0.218747983162757, 0.24236674391431734, 0.1705916234641336, 0.18854989029932767, 0.18176946585299447, 0.17405120423063636, 0.13879688893212005, 0.080475035647396, 0.18051262391963974, 0.13273706019390374, 0.10023621667642146, 0.1669825889985077, 0.12309958241530694, 0.11129632475785911, 0.10216640919679776, 0.12689910392509773, 0.1500332125579007, 0.09713330466183834, 0.09746317446115427, 0.22615096560912207, 0.18518417637096718, 0.15011858922662213, 0.18414714373648167, 0.1429485372500494, 0.10918610947555862, 0.1534346237895079, 0.0884849316207692, 0.2408015841501765, 0.15591016126563773, 0.23695978248724714, 0.2052076323889196, 0.1177723721775692, 0.20899252616800368, 0.2005675173131749, 0.14908445096807554, 0.2723657333990559, 1.5520238690078259, 24.161125123500824, 60.015845373272896, 54.19322781264782, 36.63891837000847, 31.572435535490513, 33.90707015991211, 45.79293876886368, 49.176421612501144, 22.70382922142744, 3.282613456249237, 0.2487459039548412, 0.876887496560812, 3.1668042205274105, 10.852188225835562, 8.660807814449072, 7.58358889259398, 10.772253815084696, 5.809230403974652, 2.7243899228051305, 1.8847656017169356, 0.4280440625734627, 0.33750397560652345, 1.5652928757481277, 5.548422373831272, 12.105406578630209, 16.364308297634125, 18.93728893250227, 16.98266241699457, 17.39749565720558, 21.984972395002842, 30.166930854320526, 42.39488750696182, 59.323416128754616, 66.72270208597183, 67.03468814492226, 61.33669629693031, 58.39718922972679, 61.83685965836048, 62.49152272939682, 54.59282577037811, 42.944953590631485, 43.42039927840233, 45.381284058094025, 41.62225216627121, 50.04901818931103, 66.45698234438896, 68.00770953297615, 70.65204083919525, 67.17439904808998, 72.01125830411911, 66.30406334996223, 63.87021794915199, 66.15907073020935, 65.39753079414368, 54.06916826963425, 40.59271261096001, 22.683029137551785, 9.594375919550657, 4.608769845217466, 1.277708988636732, 0.8795719931367785, 0.5233332118950784, 0.46512303699273616, 0.8217028202489018, 0.6148100970312953, 1.2630186206661165, 1.8323712819255888, 2.5389553606510162, 4.1372165735810995, 5.1708979066461325, 9.453883208334446, 5.660892063751817, 11.554324049502611, 13.719260729849339, 12.885082941502333, 11.033148765563965, 7.432761210948229, 2.350323270075023, 0.45539238257333636, 1.3804450258612633, 11.83194000273943, 36.234072893857956, 37.79144212603569, 36.614269092679024, 31.17222961038351, 43.679005801677704, 46.34757600724697, 24.017430134117603, 1.599143953062594, 0.1950363945798017, 0.2066127851139754, 0.17518891661893576, 0.19112594425678253, 0.12776412157109007, 0.13143119198502973, 0.10071881304611452, 0.10635248574544676, 0.13467626238707453, 0.19584977359045297, 0.24135239131283015, 0.144740957475733, 0.1966031128540635, 0.07357687689363956, 0.17497180873760954, 0.24981530907098204, 0.16075837454991415, 0.07963039737660438, 0.18954355182358995, 0.14029443904291838, 0.17644642648519948, 0.16871554835233837, 0.12546238023787737, 0.28883357474114746, 0.14983489585574716, 0.08682833926286548, 0.10534403321798891, 0.18177289457526058, 0.21645023458404467, 0.15844109264435247, 0.0776002078782767, 0.1820980740012601, 0.1092946931021288, 0.2644331246847287, 0.20337994530564174, 0.08361074316781014, 0.2580193063477054, 0.10111622570548207, 0.1270244229817763], [0.08486136590363458, 0.038892015218152665, 0.02571740966232028, 0.021262794398353435, 0.08572832797653973, 0.036946048348909244, 0.06379874728736468, 0.04658683610614389, 0.04908483097096905, 0.05839817946252879, 0.020537354321277235, 0.07238014892209321, 0.02905815032136161, 0.044606218361877836, 0.05629227605822962, 0.030921269390091766, 0.07474895071936771, 0.08588147014961578, 0.06300768465735018, 0.014929096469131764, 0.03702985166455619, 0.05469196075864602, 0.105402662884444, 0.10038576685474254, 0.04517366076470353, 0.10295405794749968, 0.07870169603847899, 0.029685315203096252, 0.050790271488949656, 0.07285472267540172, 0.10441276404890232, 0.03975566360168159, 0.03737112827366218, 0.08356039586942643, 0.10165049781790003, 0.08412511830101721, 0.03951310005504638, 0.03929897189664189, 0.13143674324965104, 0.053516116822720505, 0.04989676279365085, 0.06550433623488061, 0.03950868056563195, 0.020026350393891335, 0.01462273419747362, 0.03638489935838152, 0.05051028885645792, 0.010656023514457047, 0.45535925310105085, 6.468245666474104, 34.431122839450836, 41.127074137330055, 37.35449977219105, 23.15274093300104, 19.2254426702857, 27.143518589437008, 41.62948697805405, 28.573957532644272, 8.364608008414507, 1.0298292897641659, 0.09403181014931761, 0.9266673191450536, 1.5390373533591628, 4.718611976131797, 1.5479333885014057, 4.142871620133519, 4.575728243216872, 3.5826569935306907, 0.7906878751236945, 0.18017174064880237, 0.05369624719605781, 0.03843365368084051, 0.232923834992107, 0.5012249294668436, 0.6007624289486557, 0.728795489994809, 0.3373443544842303, 0.5379997123964131, 0.7968104747124016, 3.094402668066323, 8.70722422376275, 20.436777770519257, 34.75128225982189, 44.94433790445328, 45.96834495663643, 53.72425317764282, 58.70309181511402, 38.344270661473274, 33.45509961247444, 42.12702088057995, 47.306937128305435, 37.6180612295866, 52.77405336499214, 60.3541412204504, 61.34598679840565, 69.59821298718452, 64.65147882699966, 63.97665023803711, 64.76739540696144, 56.91849857568741, 52.52578228712082, 44.6776682138443, 26.95145219564438, 13.726825173944235, 2.881497242487967, 0.8239624521229416, 0.49795526429079473, 0.5350831313990057, 0.37813130649738014, 1.188070848584175, 1.668168199248612, 2.812900235876441, 3.136633839458227, 2.5521798385307193, 0.7490775547921658, 5.411721859127283, 4.120213435962796, 6.681952374055982, 6.080659339204431, 7.055983878672123, 4.559297924861312, 4.028593227267265, 0.8817004133015871, 0.40927321824710816, 0.5405414791312069, 0.12713945587165654, 4.177199928089976, 22.64623001217842, 32.70951882004738, 23.735528960824013, 26.698695458471775, 28.462936989963055, 38.44227120280266, 32.92984239757061, 8.111758176237345, 0.02843752004991984, 0.02918287009379128, 0.04356353427283466, 0.035643070805235766, 0.04744948630104773, 0.1142270362470299, 0.039978883069125004, 0.02716795956075657, 0.02573223962826887, 0.00971515930359601, 0.036846945658908226, 0.03689735232910607, 0.02337710448045982, 0.025102560721279588, 0.0180530316720251, 0.0690447591478005, 0.10464288920047693, 0.07479602514649741, 0.061249637001310475, 0.020617602749553043, 0.029355486221902538, 0.013288327627378749, 0.004087750794496969, 0.06388687732396647, 0.02743952994933352, 0.020263062106096186, 0.05093673804367427, 0.02980487704917323, 0.023984830659173895, 0.0033281313380939537, 0.03939439353416674, 0.057209333099308424, 0.06761043259757571, 0.008714041050552623, 0.06364121160004288, 0.020243150283931755, 0.027560346024984028, 0.01804627256206004, 0.0319864053017227, 0.0601015159918461, 0.0807153430650942, 0.0681995420018211, 0.01861915305198636, 0.026622776022122707, 0.03187727619661018, 0.030290583017631434, 0.0360342234489508, 0.02348398858885048, 0.1329345308477059, 0.01620612667466048, 0.02707647316128714, 0.061400003542075865, 0.10681419807951897, 0.055668059358140454, 0.02144994734408101, 0.05183931207284331, 0.08453901406028308, 0.026466850795259234, 0.07298962285858579, 0.07501105501432903, 0.07021065830485895, 0.006769019491912331, 0.030791332319495268, 0.09160842339042574, 0.05362560215871781, 0.08686229251907207, 0.0721870049892459, 0.08019920162041672, 0.06821605478762649, 0.061425065869116224, 0.08365156871150248, 0.009231590720446547, 0.014155004901112989, 0.07107386511052027, 0.02488918213202851, 0.06072194402804598, 0.03069802394747967, 0.05873910355148837, 0.015222352412820328, 0.02265387971419841, 0.08403273575822823, 0.07612525616423227, 0.05059101968072355, 0.05541574028029572, 0.10872713566641323, 0.06089923197578173, 0.029905044721090235, 0.027298915229039267, 0.022490618357551284, 1.0534426476806402, 19.2908276617527, 48.68472799658775, 43.8236640393734, 31.32676351815462, 19.60635133087635, 20.521045848727226, 39.57651033997536, 54.76733520627022, 35.213865637779236, 9.394402150064707, 0.7160304312128574, 0.17569673858815804, 0.7694748602807522, 0.5567886948119849, 1.0800507199019194, 4.143557958304882, 3.9437026949599385, 5.489235799759626, 5.573098249733448, 2.184632448479533, 0.539073214167729, 0.2519158838549629, 0.13341395824681967, 0.8034391002729535, 1.4803386968560517, 1.8962741154246032, 2.0311477594077587, 1.525188283994794, 1.7415364435873926, 3.413155688904226, 6.152650276198983, 14.109753426164389, 31.078680530190468, 42.75379724800587, 54.084386453032494, 54.17612113058567, 58.72060127556324, 64.44191247224808, 44.06867869198322, 41.667678728699684, 53.101937770843506, 49.47774164378643, 44.108709543943405, 55.41741572320461, 66.2672509253025, 64.63503330945969, 71.26708343625069, 65.49567952752113, 66.84128612279892, 66.64974600076675, 59.24497313797474, 53.991587832570076, 49.70540642738342, 32.05989047884941, 17.38735780119896, 6.743124341592193, 2.2135693207383156, 1.318910177797079, 1.6577040357515216, 0.9116308728698641, 4.127823002636433, 3.815525360405445, 3.8730542734265327, 5.461207078769803, 4.522594744339585, 4.988744705915451, 4.909533681347966, 5.486935973167419, 7.605623435229063, 6.72248194925487, 6.532353451475501, 2.237257012166083, 1.468561941292137, 0.15504919574595988, 0.4008799436269328, 0.11315232477500103, 0.11392918269848451, 2.1005379734560847, 23.501488119363785, 46.3108965754509, 34.47843790054321, 21.055219285190105, 24.087249487638474, 33.12047436833382, 41.207158640027046, 15.996465235948563, 0.7286778150591999, 0.07704768635449, 0.057568217162042856, 0.04268903940101154, 0.01321734584053047, 0.018220144775114022, 0.12258979375474155, 0.020086542281205766, 0.0274681063456228, 0.09951728337910026, 0.09746595751494169, 0.0562843796069501, 0.036047956891707145, 0.055131371555035, 0.08577379936468787, 0.0388231105171144, 0.09788811337784864, 0.09280804573791102, 0.05416551088273991, 0.10157764118048362, 0.0272062191288569, 0.001533207987449714, 0.06401517239282839, 0.08772608562139794, 0.04133672387979459, 0.024953587562777102, 0.04100593381735962, 0.08484048186801374, 0.0450978429580573, 0.0257348445666139, 0.04186781960015651, 0.0950892963737715, 0.0046368468429136556, 0.0707480325945653, 0.034917918310384266, 0.017597612750250846, 0.054348153425962664, 0.04030900890938938, 0.09753327773069032, 0.08529141079634428, 0.04702197955339216, 0.1075889631465543, 0.1306386079522781, 0.26320098142605275, 0.11356437258655205, 0.24826053937431425, 0.23016038874629885, 0.14737089135451242, 0.26189444528426975, 0.16517945216037333, 0.23261235561221838, 0.07014634378720075, 0.20699154760222882, 0.19179504975909367, 0.11642267272691242, 0.16925296717090532, 0.19033243996091187, 0.1409095904091373, 0.1420493214391172, 0.2283585284021683, 0.1598111417843029, 0.13253860990516841, 0.1379173994064331, 0.26367767772171646, 0.31820801727008075, 0.17159355251351371, 0.22594121983274817, 0.2237052921555005, 0.15208962955512106, 0.09885286825010553, 0.18738568323897198, 0.17111724213464186, 0.07247219007695094, 0.20491041708737612, 0.36706540966406465, 0.1951050729257986, 0.15406785387312993, 0.15781569964019582, 0.12143462605308741, 0.17553423793287948, 0.14181282866047695, 0.2068678761133924, 0.21664951607817784, 0.20978255721274763, 0.17449558741645887, 0.21079220459796488, 0.14000630762893707, 0.1371516365907155, 0.12613807601155713, 0.8182326564565301, 16.920488253235817, 57.09590345621109, 57.524649649858475, 50.431152284145355, 34.90031786262989, 27.40082748234272, 35.87302006781101, 52.21274748444557, 35.162800177931786, 11.565560046583414, 1.6030854103155434, 0.27827946294564754, 2.411882341839373, 5.823928490281105, 12.286608405411243, 7.145975399762392, 12.879715729504824, 11.10734073445201, 8.117528166621923, 1.93282684776932, 0.8368460170459002, 0.15007069101557136, 0.17555816477397457, 0.7010802521836013, 0.6106454611290246, 0.8500478742644191, 1.0393507475964725, 0.9654738055542111, 0.849167627748102, 1.6582542937248945, 4.828709168359637, 12.09753055125475, 25.686319582164288, 41.58789440989494, 52.93785497546196, 54.79611486196518, 64.74819123744965, 69.70043510198593, 51.144043430686, 48.38277719914913, 59.538875967264175, 56.14787332713604, 52.116468250751495, 63.67730990052223, 65.81081181764603, 64.25700679421425, 70.2204903960228, 66.8456406891346, 65.9048567712307, 66.9873882830143, 57.97207184135914, 52.41715371608734, 44.09167505800724, 28.101726472377777, 13.556336872279644, 3.9167234301567078, 1.0597896133549511, 0.7919413328636438, 1.071318075992167, 0.7380929379723966, 3.3049968676641583, 3.906932780519128, 6.301239877939224, 6.913825906813145, 6.256262166425586, 2.230180366896093, 13.513617664575577, 10.198502652347088, 11.724962443113327, 10.830367896705866, 11.93638214841485, 8.675697315484285, 10.648893434554338, 5.931445145979524, 3.316515712067485, 1.4299927046522498, 0.4191949311643839, 5.1200514100492, 28.78203436732292, 42.72614233195782, 30.732044130563736, 34.374612271785736, 39.16329391300678, 48.287432715296745, 46.570749431848526, 15.844439193606377, 0.6128387153148651, 0.16151481599081308, 0.11268659742199816, 0.12342034606263041, 0.19607523805461824, 0.21070353279355913, 0.24074454267974943, 0.18147827679058537, 0.3435209527378902, 0.1344663681811653, 0.19502726616337895, 0.1167138246819377, 0.09639799216529354, 0.12750104506267235, 0.13703363511012867, 0.19876668113283813, 0.41139777924399823, 0.1656052519683726, 0.1887172891292721, 0.20653766492614523, 0.18071503727696836, 0.1226125776884146, 0.12422524974681437, 0.20742511027492583, 0.2521003520814702, 0.10772634952445515, 0.1428065643995069, 0.12894725339720026, 0.15640400117263198, 0.11071736051235348, 0.16012110718293115, 0.13014188851229846, 0.14038343739230186, 0.07971405968419276, 0.12804940313799307, 0.13911993097281083, 0.19240383349824697, 0.10185539736994542, 0.21508186269784346, 0.18462523526977748, 0.1800215893308632], [0.013909118388255592, 0.04289963864721358, 0.043376026951591484, 0.036075590760447085, 0.010614155253279023, 0.06663683874648996, 0.06449482243624516, 0.029502110483008437, 0.02583171153673902, 0.025758444862731267, 0.06972534567466937, 0.07910915737738833, 0.0162513383111218, 0.06433651491533965, 0.016693276120349765, 0.027152077600476332, 0.041416415697312914, 0.08646051603136584, 0.06051403506717179, 0.024760154192335904, 0.04108696892217267, 0.11372990120435134, 0.13870895927539095, 0.02822348465997493, 0.0439281922444934, 0.07250257360283285, 0.04245718133461196, 0.051779765854007564, 0.028766352697857656, 0.06175626411277335, 0.05186918351682834, 0.01825827446737094, 0.03759462233574595, 0.028579583813552745, 0.01819435699871974, 0.012188312630314613, 0.08700702615897171, 0.07939073562738486, 0.05437526779132895, 0.049361930359737016, 0.07060319505399093, 0.055189017875818536, 0.030873358191456646, 0.03416181083593983, 0.07198078441433609, 0.029731268987234216, 0.04801468370715156, 0.06972234739805572, 0.0473409138066927, 0.18037912639556453, 2.179412478581071, 22.5816410779953, 43.47948610782623, 39.230147525668144, 25.67622732371092, 29.888255707919598, 21.756036579608917, 25.41679624468088, 33.70482601225376, 17.887701652944088, 7.361180651932955, 1.0888107935898006, 0.31194627983495593, 0.7071321399416775, 3.01955072209239, 3.152036787942052, 5.675251493230462, 4.5762863382697105, 2.1927742240950465, 0.8490149828139693, 0.38264258473645896, 0.39418764179572463, 0.6057627825066447, 0.12432140982127748, 0.2818248508265242, 0.3443252627039328, 0.4552992875687778, 0.3462490875972435, 0.8403122622985393, 0.326838749460876, 0.16225601371843368, 0.37074156396556646, 1.8221093388274312, 4.058129042387009, 4.470298625528812, 16.781210526823997, 9.646556619554758, 3.8998076878488064, 5.672206431627274, 19.659176096320152, 24.222805313766003, 15.731647945940495, 9.50026161968708, 10.592088382691145, 22.77974534779787, 31.86660625040531, 36.9652296602726, 38.26232425868511, 38.76826710999012, 30.160530097782612, 24.56218220293522, 17.15142086148262, 7.316322633996606, 2.321757352910936, 1.8861968186683953, 0.8093742630444467, 0.5856811569537967, 2.5049908831715584, 1.8657732708379626, 6.74447706900537, 3.094341396354139, 4.343056278303266, 3.715138784609735, 5.762097733095288, 6.559783229604363, 0.8683759532868862, 5.383001575246453, 7.142237350344658, 5.889587067067623, 7.401375370100141, 1.9201059616170824, 0.787711328594014, 0.2993223478551954, 0.14851369487587363, 1.9853160437196493, 16.928435526788235, 32.921984419226646, 25.836099945008755, 16.49426132440567, 28.765357062220573, 35.91222636401653, 42.41680473089218, 30.55958468466997, 5.626961309462786, 0.09069486186490394, 0.03475650490145199, 0.029555238979810383, 0.033133528122561984, 0.03224614214559551, 0.04169460604316555, 0.12215866532642394, 0.053707071419921704, 0.136014562449418, 0.03514448857458774, 0.005902485545448144, 0.00547125692719419, 0.06176956339913886, 0.035353662897250615, 0.06902170804096386, 0.0852547561225947, 0.1757775733130984, 0.00412600340496283, 0.03132261728751473, 0.06633323355345055, 0.02774809083348373, 0.01862614222773118, 0.0229176278662635, 0.058208965201629326, 0.09407980483956635, 0.11397036447306164, 0.026424496427353006, 0.018174597316829022, 0.02057447469269391, 0.04090260830707848, 0.05816347154905088, 0.02569595231761923, 0.09835988181293942, 0.0497023015486775, 0.013506754676200217, 0.09220545151038095, 0.02479632275935728, 0.0229824526104494, 0.038550360113731585, 0.05707785050617531, 0.051158836868125945, 0.015530139608017635, 0.027074621502833907, 0.11001394552295096, 0.02381869162491057, 0.027146607972099446, 0.028842977590102237, 0.05823937099194154, 0.038253103994065896, 0.00855335309097427, 0.024715833133086562, 0.014781149329792242, 0.03469080256763846, 0.05676346190739423, 0.02396249386947602, 0.06755189941031858, 0.047293516545323655, 0.03981925081461668, 0.1115992249106057, 0.045753574959235266, 0.0719242995546665, 0.02039880091615487, 0.04743804609461222, 0.0935437812586315, 0.10902370529947802, 0.009051888009707909, 0.036273926016292535, 0.042833728512050584, 0.047571001850883476, 0.07015440351096913, 0.026983901370840613, 0.036966064071748406, 0.029346578594413586, 0.10420559352496639, 0.009504690860921983, 0.055005039466777816, 0.043947647645836696, 0.04101321428606752, 0.07558241224614903, 0.057691925758263096, 0.09042234523803927, 0.06834139610873535, 0.08019745015189983, 0.017164779237646144, 0.0744665709498804, 0.07482779648853466, 0.055840909262769856, 0.04103213534108363, 0.0010980181559716584, 0.08984691361547448, 0.05515320925042033, 0.09895380033412948, 8.629720732569695, 38.274255618453026, 48.366882652044296, 38.685427755117416, 21.873026601970196, 23.50210938602686, 31.71979732811451, 39.95010629296303, 40.68412810564041, 22.670881189405918, 4.761947225779295, 0.26456935331225395, 0.21621939697070047, 0.4464736970840022, 0.8951131592039019, 1.7589113675057888, 1.866697808727622, 2.336180191487074, 2.3154494538903236, 2.3976454557850957, 2.093241414986551, 0.8067280612885952, 1.3939383393153548, 1.2525717937387526, 2.1848034393042326, 1.1446466599591076, 2.49186591245234, 1.319958921521902, 1.8471032101660967, 1.170820842962712, 0.24701993563212454, 0.924571790965274, 4.260276770219207, 7.859318722039461, 8.942820131778717, 26.144191212952137, 17.985762991011143, 8.035090640187263, 10.785134173929691, 29.024845138192177, 36.123726814985275, 26.346159875392914, 17.146055549383163, 16.12451646476984, 28.906654380261898, 39.12355184555054, 42.43339084088802, 42.37122617661953, 42.67955303192139, 34.35725100338459, 28.204446360468864, 21.2303613871336, 9.28335690870881, 4.521682318300009, 2.054387074895203, 2.568527511321008, 2.9755968181416392, 3.500772099941969, 3.776948880404234, 7.41702483035624, 7.815834330394864, 8.230759240686893, 7.098019598051906, 8.909901548177004, 14.649199079722166, 4.506021458655596, 3.7506488291546702, 4.309006780385971, 3.130621137097478, 1.956333692651242, 0.7894725340884179, 0.5505963927134871, 0.25643155560828745, 0.055887430789880455, 1.0865167854353786, 12.905004322528839, 45.31581737101078, 44.13430117070675, 22.543702013790607, 17.352091893553734, 30.470789149403572, 40.776383355259895, 38.77069517970085, 10.792977903038263, 0.17022872809320688, 0.11997780500678346, 0.0786426433478482, 0.06331029537250288, 0.035604134027380496, 0.024026533792493865, 0.047956013222574256, 0.03498632206174079, 0.06734495153068565, 0.015003437401901465, 0.008848178676998941, 0.03579386408091523, 0.06829907884821296, 0.026628202977008186, 0.06072396266972646, 0.08162584694218822, 0.07848038017982617, 0.05778216349426657, 0.013699014525627717, 0.0730190786998719, 0.04802214971277863, 0.04131403271458112, 0.02958410666906275, 0.018209133158961777, 0.07572062240797095, 0.07660676899831742, 0.007618907993673929, 0.11571871596970595, 0.07037088056677021, 0.04077610181411728, 0.018130730823031627, 0.052981095141149126, 0.036281076609157026, 0.032548173985560425, 0.02560592423833441, 0.020348696671135258, 0.03818477074673865, 0.02109493358148029, 0.06706655709422193, 0.014546598195011029, 0.047418464528163895, 0.05149951233761385, 0.07879424185375683, 0.17385536630172282, 0.13798523170407861, 0.2679883979726583, 0.1000775232387241, 0.10147774810320698, 0.13410195882897824, 0.12016364620649256, 0.18509115558117628, 0.12325014933594503, 0.2015531191136688, 0.20005988830234855, 0.12105136614991352, 0.1610653119860217, 0.12186656342237256, 0.1779319389606826, 0.172022053739056, 0.22929057682631537, 0.3077461989596486, 0.0809746865706984, 0.1373460199101828, 0.20823838538490236, 0.2363360667368397, 0.156011687067803, 0.11346633487846702, 0.18102342932252213, 0.13052357506239787, 0.1375473794178106, 0.11539252722286619, 0.13385797035880387, 0.256207367638126, 0.21751870459411293, 0.1700570248067379, 0.08338148632901721, 0.08826994628179818, 0.1342778032994829, 0.24486030073603615, 0.14444675529375672, 0.21227339777396992, 0.13068463595118374, 0.23654768272535875, 0.19803544302703813, 0.12455776159185916, 0.20018532610265538, 0.20672447833931074, 0.22492884134408087, 0.12973293545655906, 0.2406299699214287, 0.12188305394374765, 0.16533467976842076, 7.728225756436586, 40.57465597987175, 61.231916919350624, 53.60402002930641, 38.32539327442646, 38.00127446651459, 31.723815612494946, 33.18159028887749, 43.7680122256279, 25.721209309995174, 8.860913626849651, 1.8281677574850619, 0.607714809011668, 1.9532830500975251, 8.935034349560738, 9.472141228616238, 11.980691570788622, 8.720724899321795, 7.297391574829817, 4.253045283257961, 2.3108623875305057, 1.4298726548440754, 1.262772346381098, 1.642352503258735, 1.3979660044424236, 0.8990518259815872, 1.4142838725820184, 0.8828720566816628, 1.0859326855279505, 0.2999995130812749, 0.17629885784117505, 0.9567613480612636, 2.6796117005869746, 5.182066457346082, 6.4858064241707325, 23.33517674356699, 13.708703946322203, 4.691959256306291, 9.119577147066593, 29.094860181212425, 34.600225165486336, 24.204182513058186, 12.666723858565092, 11.487234849482775, 25.419619493186474, 34.78017970919609, 39.90418195724487, 38.87872718274593, 39.902563244104385, 32.7280580252409, 26.315742507576942, 18.716972954571247, 9.082325845956802, 3.773218193091452, 3.7950316350907087, 2.1597791695967317, 1.7417873488739133, 5.091034742072225, 5.438157990574837, 10.860832761973143, 7.865538513287902, 13.410551995038986, 12.267468832433224, 12.840171251446009, 17.883411683142185, 8.26968815177679, 12.860342469066381, 15.175008215010166, 13.593994751572609, 17.838587388396263, 7.915177149698138, 4.395772749558091, 0.9980052849277854, 0.4402878961991519, 2.946864659897983, 21.32808454334736, 43.36305655539036, 36.45676754415035, 25.607998184859753, 39.1395527869463, 47.34673239290714, 54.43160802125931, 42.32847087085247, 10.598441641777754, 0.17107348510762677, 0.25883700465783477, 0.07901606979430653, 0.12713098054518923, 0.13744680356467143, 0.12004735166556202, 0.20640580012695864, 0.12372663040878251, 0.19588290306273848, 0.17194178304634988, 0.15707677288446575, 0.11516407190356404, 0.22704397706547752, 0.06715520663419738, 0.11876573684276082, 0.18257929739775136, 0.32053076138254255, 0.13428029691567644, 0.15687870851252228, 0.1055895653553307, 0.17967772262636572, 0.1379993770387955, 0.148881844652351, 0.1556431662174873, 0.16480693855555728, 0.1761515118414536, 0.11921279176021926, 0.1657779497327283, 0.10316817497368902, 0.17135719332145527, 0.11096414687926881, 0.10105462002684362, 0.1213086093775928, 0.13686280755791813, 0.11362783363438211, 0.15063840430229902, 0.3138832555850968, 0.13012474490096793, 0.1870164053980261, 0.06746489001670852, 0.11348111103870906, 0.1875804821611382], [0.013328697677934542, 0.07075822970364243, 0.021127012914803345, 0.0543226495210547, 0.020479895392782055, 0.0285837324190652, 0.00797995031462051, 0.04361041574156843, 0.038283320536720566, 0.0674569267721381, 0.03948638644942548, 0.030176294130797032, 0.06279560111579485, 0.03777646335947793, 0.05491127652931027, 0.0038064030741224997, 0.05706044343241956, 0.036644124120357446, 0.07711152589763515, 0.028901787227368914, 0.011415163589845179, 0.01112401998398127, 0.03686466814542655, 0.12434763732017018, 0.06767787897842936, 0.03860956865537446, 0.03942595336411614, 0.012012049774057232, 0.05900992066017352, 0.04278880631318316, 0.04140689394262154, 0.022402096838050056, 0.0577910766878631, 0.06222753901965916, 0.05825247360917274, 0.0353797605202999, 0.04915082645311486, 0.09259798825951293, 0.07742769565084018, 0.023980346231837757, 0.028581810256582685, 0.031294723667087965, 0.06460586257162504, 0.02743341650784714, 0.05337511989637278, 0.048262368072755635, 0.08758308118558489, 0.0417616108461516, 0.12231548113049939, 0.02130323959136149, 0.06784661367419176, 0.8141320233698934, 16.8135828897357, 42.838346511125565, 42.38864824175835, 34.5442845672369, 30.680266208946705, 25.556746535003185, 25.430469810962677, 32.51470327377319, 36.748933866620064, 19.85976543277502, 7.100994363427162, 2.067120191641152, 0.7311920926440507, 0.16514837101567537, 0.4872678924584761, 2.578696240670979, 2.982470649294555, 1.8284951336681843, 3.0510448571294546, 0.6878770294133574, 2.8025023313239217, 1.2060559960082173, 1.0954983159899712, 2.1892449259757996, 4.241109173744917, 2.0050623966380954, 3.3109577978029847, 2.0694850897416472, 0.7046875054948032, 0.05622543452773243, 0.08289668578072451, 0.16175829980056733, 0.056721627042861655, 1.9975036522373557, 1.5666758827865124, 0.10287054406944662, 0.1502757761045359, 1.7749114776961505, 1.5560754016041756, 0.5802843777928501, 0.09446950658457354, 0.25821959716267884, 0.6320570153184235, 2.4462106497958302, 4.995826100930572, 8.321104142814875, 6.569281769916415, 5.805199770256877, 1.887629460543394, 1.421695256140083, 0.05401588277891278, 0.6517379998695105, 1.2537006894126534, 3.3511142805218697, 5.976303638890386, 3.4308534767478704, 2.2411881387233734, 7.507541673257947, 8.321953397244215, 4.721426200121641, 6.427315212786198, 7.889449680224061, 26.503042057156563, 2.10827412083745, 1.5222734841518104, 2.8294965578243136, 2.6582558965310454, 0.947221425594762, 0.32976530492305756, 0.2679246029583737, 2.6019505178555846, 13.716115448623896, 40.73971152305603, 28.993061743676662, 22.99920067191124, 20.846428088843822, 24.21186190098524, 36.09490916132927, 38.41232880949974, 23.158541321754456, 2.3434463515877724, 0.03343753036460839, 0.09513584387605079, 0.015790379256941378, 0.024898221490730066, 0.0032021471315601957, 0.04406235028000083, 0.053418769311974756, 0.05023377205361612, 0.041434353406657465, 0.031559503404423594, 0.07675821165321395, 0.06555386717082001, 0.04473500695894472, 0.03342642041388899, 0.0412668729404686, 0.019070098678639624, 0.011469947075966047, 0.038165174337336794, 0.042751012442749925, 0.0233490012033144, 0.022563757011084817, 0.059549962970777415, 0.05813256480905693, 0.016373217513319105, 0.02304786550666904, 0.05887358442123514, 0.02671559457667172, 0.014806338749622228, 0.04997305186407175, 0.07431569232721813, 0.058938637375831604, 0.07493326309486292, 0.008104478984023444, 0.03463049935817253, 0.030974976762081496, 0.022161067681736313, 0.012265389304957353, 0.03985367533459794, 0.044841011622338556, 0.09544007989461534, 0.08581514441175386, 0.1108851601020433, 0.03446519338467624, 0.057634613403934054, 0.033458867110311985, 0.048282220523105934, 0.023699304183537606, 0.018774597738229204, 0.022714316510246135, 0.027247870311839506, 0.016686504022800364, 0.0323414005106315, 0.022433651101891883, 0.015614128460583743, 0.04120760873774998, 0.028872160692117177, 0.035543838239391334, 0.06082670188334305, 0.006698236229567556, 0.02263967129692901, 0.024724842805881053, 0.009207986713590799, 0.03142045461572707, 0.06028969866747502, 0.03385232041182462, 0.08792266569798812, 0.03333766326250043, 0.028131755207141396, 0.012601389244082384, 0.03376605687662959, 0.015168253557931166, 0.03189505063346587, 0.029446406733768526, 0.0177821589022642, 0.021461600917973556, 0.04823186951398384, 0.049171246646437794, 0.04431362664035987, 0.030229580333980266, 0.05009189939300995, 0.06449494117987342, 0.04664348052756395, 0.015802528214408085, 0.08328018317115493, 0.06804676348110661, 0.03264108716393821, 0.11062136371037923, 0.0747496186522767, 0.023510778264608234, 0.018673867889447138, 0.06072471594961826, 0.0613181966036791, 0.039016803639242426, 0.049918318472919054, 4.133042022585869, 30.281810089945793, 54.63694520294666, 41.73351779580116, 34.76513631641865, 25.936817340552807, 18.621664568781853, 32.4617987126112, 44.72972922027111, 45.485113486647606, 20.109657123684883, 4.7320490051060915, 0.47651072905864567, 0.3237461904063821, 0.2943066763691604, 0.1803440079675056, 1.140300405677408, 1.7693548696115613, 0.9163993201218545, 2.4208930833265185, 1.0232066013850272, 2.794514922425151, 2.0530383847653866, 5.887258742004633, 2.770481687039137, 5.307574672624469, 3.7929849699139595, 6.595659954473376, 5.118493968620896, 2.226216229610145, 0.8110119751654565, 0.22271235793596134, 0.5043170729186386, 0.36369243753142655, 4.1524281073361635, 2.0649801939725876, 0.20193073869450018, 0.13132430787663907, 3.7474757619202137, 4.81837609782815, 1.2093761865980923, 0.05390111335145775, 0.8314256672747433, 2.0513479504734278, 5.310757476836443, 8.815514612942934, 12.731543630361557, 10.997532326728106, 8.668486252427101, 4.673498896881938, 2.6152203558012843, 0.39198082115035504, 1.5967859420925379, 1.7875873600132763, 4.9657901376485825, 6.786421118304133, 7.252120804041624, 5.943954074755311, 10.007718689739704, 6.998948939144611, 8.508796021342278, 2.773571158759296, 5.609290357679129, 15.456971134990454, 2.8062631795182824, 2.019392615184188, 1.3593593635596335, 0.6647302745841444, 0.32473547325935215, 0.3984376246808097, 0.15649763052351773, 2.7662180783227086, 9.656025711447, 33.853599429130554, 48.62948656082153, 31.554584093391895, 16.09075717628002, 14.799694754183292, 33.99637296795845, 43.029780238866806, 34.65043567121029, 5.742662725970149, 0.036300480060162954, 0.0459449859772576, 0.027677816869982053, 0.025568677701812703, 0.014985774287197273, 0.040529122488806024, 0.06538162211654708, 0.0655719310452696, 0.053176502624410205, 0.03903507531504147, 0.07728873591986485, 0.058144550494034775, 0.059017516541644, 0.02158409981348086, 0.03907189326127991, 0.034840972439269535, 0.04633147422282491, 0.11751886195270345, 0.034563398075988516, 0.062098646521917544, 0.05421815883892123, 0.06470897656981833, 0.03660265290818643, 0.017223687209479976, 0.04738764684589114, 0.013828144510625862, 0.041126633004751056, 0.02783621344860876, 0.026061940588988364, 0.04072614414326381, 0.033654011131147854, 0.08822295349091291, 0.08047934010392055, 0.036620790997403674, 0.025648530936450697, 0.007928881277621258, 0.0026210492114842054, 0.0700687151402235, 0.03407112781133037, 0.03918256232282147, 0.05250482929113787, 0.09372024913318455, 0.05017908690206241, 0.12334829836618155, 0.20734434976475313, 0.20107158401515335, 0.18899528280599043, 0.15738550631795079, 0.07102097224560566, 0.1454732197453268, 0.10289946556440555, 0.13073458248982206, 0.1448991833603941, 0.11571886439924128, 0.15764047857373953, 0.14343903749249876, 0.19832255027722567, 0.19247766234911978, 0.1513207794050686, 0.12719477555947378, 0.16889802762307227, 0.1327540702186525, 0.08519056777004153, 0.2462752498104237, 0.12443984916899353, 0.150902044842951, 0.17197791079524904, 0.13164491567295045, 0.10277081426465884, 0.11566599379875697, 0.11498041261802427, 0.14547945378581062, 0.06007352960295975, 0.14075416984269395, 0.11403090888052247, 0.10518990398850292, 0.19048959715291858, 0.1584371889475733, 0.14300494047347456, 0.18495225522201508, 0.23283548973267898, 0.16109119809698313, 0.15883719170233235, 0.14254060835810378, 0.2058407140430063, 0.14410734147531912, 0.2131760719930753, 0.1461963090696372, 0.13977392634842545, 0.11542912252480164, 0.13978574133943766, 0.39454327896237373, 0.2086419059196487, 0.2006169591913931, 3.6585211101919413, 31.391686834394932, 66.08934447169304, 57.25629664957523, 48.0243956297636, 43.43714877963066, 35.520102605223656, 34.95892971754074, 43.66681605577469, 47.22576588392258, 25.702430717647076, 8.943311255425215, 2.947622244246304, 1.2269352818839252, 0.8114637352991849, 3.0883272690698504, 5.5924819596111774, 7.666660510003567, 5.441183103248477, 7.1315703727304935, 3.1985166063532233, 5.51744501106441, 6.079913154244423, 6.586026046425104, 6.560987289994955, 8.192714732140303, 7.472027353942394, 6.696269055828452, 5.61329391784966, 2.0447678910568357, 0.2702107740333304, 0.28978456277400255, 0.24892108049243689, 0.6850335351191461, 4.864191189408302, 2.6702715642750263, 0.38629380287602544, 0.1989963313098997, 2.942303717136383, 3.5107515519484878, 1.4309449098072946, 0.10304554249159992, 0.8032890083268285, 1.2003329093568027, 3.9362489199265838, 6.810562647879124, 10.380485337227583, 9.156187232583761, 7.047229623422027, 2.747677923180163, 2.266349201090634, 0.22553072310984135, 1.9018047186546028, 3.9749420061707497, 7.52646085806191, 13.3007806353271, 7.556142965331674, 10.266770739108324, 20.68244408816099, 19.085197895765305, 11.504448875784874, 15.147810224443674, 16.67768508195877, 35.948408022522926, 9.451449438929558, 11.122967395931482, 10.145848877727985, 6.490826904773712, 2.3183541605249047, 1.076051671989262, 0.4828102863393724, 3.595479167997837, 17.238257601857185, 48.57062391936779, 39.876941218972206, 30.035642199218273, 27.162449173629284, 33.69313783943653, 48.58757100999355, 53.11689376831055, 35.542544201016426, 4.40004182048142, 0.13067811989458278, 0.1950424356618896, 0.07105477707227692, 0.09131539380177855, 0.09562252947944216, 0.13270651339553297, 0.16633690567687154, 0.18875497538829222, 0.1436713000293821, 0.1779342396184802, 0.18013120454270393, 0.12050254794303328, 0.1048026884382125, 0.24506382731487975, 0.11290849215583876, 0.04964612839103211, 0.15852887387154624, 0.1901114877546206, 0.11607638662098907, 0.08356855207239278, 0.1091734113288112, 0.14164464315399528, 0.17120674514444545, 0.12111238553188741, 0.2592610678402707, 0.16959916421910748, 0.14297568501206115, 0.11146103701321408, 0.13603075611172244, 0.17046280147042125, 0.19647025357699022, 0.16924184979870915, 0.2014401345513761, 0.1341968053020537, 0.07838682504370809, 0.09741079367813654, 0.0954118485969957, 0.14767258922802284, 0.21700552431866527, 0.25767869025003165, 0.1933977918815799, 0.20127061317907646, 0.16831040993565693], [0.0485122232203139, 0.029372635399340652, 0.02920058701420203, 0.02182955402531661, 0.029058981526759453, 0.016889193830138538, 0.046511226100847125, 0.07921954442281276, 0.042923721339320764, 0.04003875954367686, 0.03890779698849656, 0.006064635072107194, 0.08166937390342355, 0.03019564006535802, 0.03973426377342548, 0.05671512953995261, 0.03293277717602905, 0.09943815559381619, 0.020470585150178522, 0.04565851697407197, 0.06740138444001786, 0.04516664004768245, 0.019060146478295792, 0.0055192344552779105, 0.022327549959300086, 0.032501466921530664, 0.014065103914617794, 0.03785946886637248, 0.03411223166040145, 0.04807182165677659, 0.06466786901000887, 0.06573588630999438, 0.028234461024112534, 0.09134102016105317, 0.012779185562976636, 0.04012703800981399, 0.028966843892703764, 0.05169342810404487, 0.07569399414933287, 0.029528581035265233, 0.007100888915374526, 0.06713844151818193, 0.023248801990121137, 0.07091759849572554, 0.01684427905274788, 0.034433136315783486, 0.04526231030467898, 0.03307575563667342, 0.06958665311685763, 0.13191875332267955, 0.06543460403918289, 0.049091584514826536, 0.23134417366236448, 6.8313052598387, 34.73779298365116, 51.498822793364525, 44.1893146187067, 30.481358282268047, 15.697308238595724, 17.42820180952549, 19.759226627647877, 34.36758644878864, 29.086671620607376, 22.07848347723484, 10.83079157397151, 4.041824117302895, 0.28210947930347174, 0.8230903395451605, 0.09900480814394541, 0.5853974784258753, 2.274228553287685, 0.47822865250054747, 2.88484628777951, 1.3159880158491433, 8.633269742131233, 2.603832366876304, 3.7921502022072673, 2.506771800108254, 6.279079467058182, 8.286432903259993, 2.076205504126847, 2.040741532109678, 0.39164133311714977, 1.0379372234456241, 0.3265030909096822, 0.3229687758721411, 0.5707067542243749, 0.03535686155373696, 0.09479663043748587, 0.06704412939143367, 0.05038062452513259, 0.05696306252502836, 0.09444208422792144, 0.018961353634949774, 0.08329534524818882, 0.08561353257391602, 0.131336449412629, 0.12043250404531136, 0.13094222056679428, 0.17063774052076042, 0.27151915070135146, 0.48783676349557936, 0.5943832837510854, 1.4583388273604214, 0.7408794946968555, 3.929047118872404, 6.052894229069352, 6.425954410806298, 5.094539104029536, 6.38427872210741, 6.727627823129296, 9.589493181556463, 2.6046058628708124, 4.2109026946127415, 9.802581947296858, 2.4285537097603083, 0.6842761882580817, 0.8888765063602477, 0.5997254408430308, 0.6775564269628376, 4.878292232751846, 18.610958643257618, 31.559385135769844, 59.085917472839355, 25.105501748621464, 18.375867158174515, 31.55714325606823, 32.83186845481396, 43.47282126545906, 36.34998567402363, 9.499796144664288, 0.8551574719604105, 0.20480777806369588, 0.05089612772280816, 0.03931128041585907, 0.05758437000622507, 0.0285558907489758, 0.07200650725280866, 0.07418196473736316, 0.008736211784707848, 0.015894652860879432, 0.05240466161922086, 0.021993468471919186, 0.04236005275743082, 0.11133033738587983, 0.023360940504062455, 0.019160354968335014, 0.0738753167388495, 0.06964298212551512, 0.05087366662337445, 0.040960013429867104, 0.022128340824565385, 0.027561039933061693, 0.09957243237295188, 0.06236383444047533, 0.0037800913878527354, 0.04103936014871579, 0.024299931719724555, 0.06303587884758599, 0.040334598161280155, 0.01299231738812523, 0.04013206977106165, 0.08965722066932358, 0.0161825078248512, 0.05393627630837727, 0.008803895652818028, 0.023601570756, 0.012678824004979106, 0.08866461299476214, 0.01621836840058677, 0.04596905753714964, 0.030646021659777034, 0.04736403912829701, 0.05590985107119195, 0.057065349028562196, 0.01829204775276594, 0.04437124327523634, 0.026813559925358277, 0.02086514054099098, 0.07281870624865405, 0.023423381098837126, 0.043793882068712264, 0.0282979870098643, 0.0456117022986291, 0.011174342234880896, 0.04138780590437818, 0.01533991880933172, 0.08317509506014176, 0.10489149382920004, 0.0053857267266721465, 0.024868810178304557, 0.03924442775314674, 0.06374988428433426, 0.07753691010293551, 0.05828349167131819, 0.02756402151135262, 0.01587315469805617, 0.08139336918247864, 0.052240643271943554, 0.020086905933567323, 0.04381393489893526, 0.03990352910477668, 0.04676341901358683, 0.022596459748456255, 0.031073277932591736, 0.07321239332668483, 0.043740555047406815, 0.06522531097289175, 0.06987634304095991, 0.03089254085352877, 0.01703462694422342, 0.10013416394940577, 0.04275863801012747, 0.029635338978550863, 0.10260290335281752, 0.010127351833943976, 0.047906504551065154, 0.01572121665958548, 0.01000278605715721, 0.05809254820633214, 0.0209505431848811, 0.059740197684732266, 0.03255379575421102, 0.01726452388538746, 0.03968558259657584, 0.04305996480979957, 0.07389936232357286, 0.024150116223609075, 0.9556043695192784, 17.504420019686222, 46.30276881158352, 52.16149963438511, 42.63811245560646, 26.731977872550488, 16.013986095786095, 21.771290861070156, 34.118608608841896, 48.953578770160675, 42.46934071183205, 27.544094994664192, 8.250059355050325, 2.6195115130394697, 0.23992846225155517, 0.42855952866375446, 0.2927216567331925, 0.0940222290228121, 0.41235081560444087, 1.0310409497469664, 1.209848786238581, 0.9439090127125382, 3.093438232317567, 3.1776360142976046, 7.0544202625751495, 3.113869735971093, 4.185100654140115, 4.020289722830057, 4.266128456220031, 5.181793347001076, 1.85881441924721, 2.100193379446864, 1.1125320894643664, 2.951498036272824, 1.8158080894500017, 0.5645744770299643, 0.3368323319591582, 0.13474044331815094, 0.11635769027634524, 0.1318413918488659, 0.5181973718572408, 0.19703136174939573, 0.9799217584077269, 0.6405536562670022, 0.8746734028682113, 0.9373252128716558, 0.5096047860570252, 0.18147759401472285, 0.6042102689389139, 0.9336218959651887, 1.911702356301248, 3.3289864053949714, 1.8167327460832894, 6.304625021293759, 8.028972018510103, 7.4388655833899975, 3.9903216809034348, 4.946563169360161, 4.129880117252469, 2.283678171224892, 2.300469232723117, 2.2306862147524953, 3.2110578333958983, 1.6939354478381574, 0.43371338804718107, 0.2871211728779599, 0.2529106882866472, 0.4938164254417643, 2.237459351308644, 15.807857606559992, 32.00961157679558, 62.47724309563637, 47.08835385739803, 18.85482955724001, 20.619846247136593, 24.755238443613052, 38.4886135160923, 45.60398630797863, 18.712202310562134, 2.432268960401416, 0.07505432222387753, 0.08526491612428799, 0.06852072867332026, 0.029119140017428435, 0.05548438894038554, 0.01696771490969695, 0.04263579030521214, 0.06897749088238925, 0.07171496938099153, 0.0655729255231563, 0.0649979837180581, 0.03624961696914397, 0.04524870673776604, 0.015702314158261288, 0.016266398342850152, 0.03195734279870521, 0.0507916333299363, 0.011674927336571272, 0.10352714438340627, 0.019394515547901392, 0.074382337188581, 0.03998598542239051, 0.004154846974415705, 0.006776674745196942, 0.0031115264937398024, 0.018747943504422437, 0.06096287856053095, 0.023655051772948354, 0.052135043079033494, 0.0028555010840136674, 0.05210081522818655, 0.014933518741599983, 0.0548508063366171, 0.024487626433256082, 0.026936752728943247, 0.019987107480119448, 0.04397105498355813, 0.018578329363663215, 0.02893748453061562, 0.0058024245572596556, 0.012095870715711499, 0.02553972095483914, 0.029734489908150863, 0.039493321819463745, 0.10120319057023153, 0.14739682199433446, 0.06459905707743019, 0.17392756242770702, 0.1079289113113191, 0.1229449336824473, 0.09641392607591115, 0.12121005216613412, 0.14450243121245876, 0.12047982338117436, 0.2218749184976332, 0.2223381819203496, 0.19394114788156003, 0.16672316385665908, 0.11065907965530641, 0.16998850973322988, 0.16603897791355848, 0.15495124709559605, 0.13985167373903096, 0.1869646628620103, 0.11419519811170176, 0.3164810099406168, 0.15810973854968324, 0.1134807028574869, 0.13368778105359524, 0.13433471118332818, 0.18383159738732502, 0.128743652603589, 0.1702755576116033, 0.1930449006613344, 0.17877291102195159, 0.1553202429204248, 0.23727216728730127, 0.21133872214704752, 0.08394004151341505, 0.22453780373325571, 0.17841950029833242, 0.1956468407297507, 0.15063369908602908, 0.1586978608975187, 0.11812147844466381, 0.21190539642702788, 0.11105668527306989, 0.13358282652916387, 0.11284980311756954, 0.2023584532435052, 0.12146426743129268, 0.11829764203866944, 0.2004114881856367, 0.2645716688130051, 0.11183605165570043, 0.23757678922265768, 0.5410808126907796, 16.83727651834488, 52.11106114089489, 67.85376459360123, 56.51184439659119, 43.98302748799324, 25.215992219746113, 26.43234685063362, 28.355746641755104, 46.312781274318695, 41.26078516244888, 28.81396785378456, 15.772720891982317, 5.182538107037544, 0.4895688174292445, 1.243457745295018, 1.154500599950552, 3.364323084242642, 6.588127333670855, 6.111044408753514, 9.852195885032415, 6.040985668078065, 18.64275723695755, 11.771110966801643, 17.41964276880026, 11.46510198712349, 15.16025835648179, 16.554127112030983, 6.321772551164031, 5.558114228770137, 2.2060469118878245, 3.7199220154434443, 0.8224672917276621, 3.023950648494065, 1.348467841744423, 0.23835619271267205, 0.21497756126336753, 0.1480534000438638, 0.2893869794206694, 0.20685913361376151, 0.4232178465463221, 0.2206805208697915, 0.4795714351348579, 0.43677857669536024, 0.4281892563449219, 0.5288074119016528, 0.43527694477234036, 0.38356670702341944, 0.6931805948261172, 1.2095820880495012, 2.348165698349476, 4.051069971174002, 3.0008429009467363, 15.43116481974721, 21.74411091953516, 12.231048736721277, 15.399667359888554, 17.950668074190617, 16.333216466009617, 18.75439714640379, 10.037681981921196, 13.61033957451582, 19.489545598626137, 7.64902233146131, 2.342742676846683, 1.3671259093098342, 1.1276743956841528, 0.9206446423195302, 6.189986597746611, 23.261633589863777, 39.84643265604973, 66.14687338471413, 34.73999686539173, 24.809737019240856, 43.15925069153309, 45.060478672385216, 54.5675191283226, 53.641812801361084, 18.99862714111805, 1.7574455961585045, 0.25664003973361105, 0.24418634158791974, 0.12348828968242742, 0.10841024602996185, 0.10606236537569202, 0.15705097583122551, 0.17147653066786006, 0.11932443303521723, 0.15815497987205163, 0.2147121840971522, 0.08320740816998295, 0.11329489876516163, 0.20584970887284726, 0.10944422101601958, 0.1336312442435883, 0.10102655942318961, 0.14183757186401635, 0.1182644531945698, 0.15386848332127556, 0.14380877546500415, 0.12443291750969365, 0.20242754719220102, 0.1316291227703914, 0.15686377650126815, 0.1461033328087069, 0.09092932858038694, 0.20225624466547742, 0.13924523518653587, 0.17868892959086224, 0.11805919741163962, 0.2216246069292538, 0.17621986364247277, 0.22318228584481403, 0.12536723690573126, 0.1844755292404443, 0.09594902250682935, 0.12614453269634396, 0.11692754836985841, 0.13995279878145084, 0.11911537745618261, 0.162809596513398, 0.1155213121091947, 0.1840366527903825, 0.12052108679199591], [0.06341581392916851, 0.035327453952049837, 0.003323805544823699, 0.003527668873175571, 0.029479901713784784, 0.006792609119656845, 0.05653372638334986, 0.0158242137695197, 0.025353133896715008, 0.03883790152030997, 0.049253172328462824, 0.05342691809346434, 0.08869495941326022, 0.027222138196520973, 0.050414666839060374, 0.0034597560988913756, 0.05327345308614895, 0.014327770386444172, 0.05469029834785033, 0.022854203925817274, 0.09031507521285675, 0.08120412152493373, 0.09951492334948853, 0.06755824477295391, 0.02201899649662664, 0.018942074493679684, 0.052258729410823435, 0.11134184067486785, 0.07109726502676494, 0.10654925878043287, 0.056801623140927404, 0.01170352228655247, 0.035610512786661275, 0.019049272159463726, 0.04040650856040884, 0.03825927124125883, 0.053202392446110025, 0.01478160575061338, 0.030290594149846584, 0.060791846917709336, 0.09923402045387775, 0.040589292111690156, 0.04031312411825638, 0.047646348393755034, 0.06968765941564925, 0.02282461635331856, 0.04019553824036848, 0.08504489160259254, 0.10996399898431264, 0.04871987614023965, 0.05184550529520493, 0.06134221621323377, 0.11344307597028092, 0.16456192592158914, 2.4585842108353972, 22.089907564222813, 51.22347816824913, 46.60826861858368, 37.551914379000664, 21.19891807436943, 28.81146378815174, 19.664511010050774, 13.24091199785471, 31.079622879624367, 38.87292489409447, 31.58978920429945, 21.262574158608913, 7.38419696688652, 3.080227291211486, 0.7218523125629872, 0.18510742345824838, 0.5829162115696818, 0.39278219221159816, 0.7850815134588629, 3.730442225933075, 2.008485537953675, 3.8774551497772336, 1.5200272109359503, 4.408337725326419, 3.495034882798791, 3.9218759536743164, 8.454988058656454, 0.867630896391347, 1.5811572619713843, 1.8814704660326242, 2.1440385142341256, 1.068686479702592, 1.2008128711022437, 0.6153889722190797, 0.7578889257274568, 0.08813852677121758, 0.06133652394055389, 0.6543334980960935, 0.20412173675140366, 1.706756316125393, 0.7403267431072891, 0.9706797637045383, 0.1037924547563307, 0.3548158466583118, 0.3017357230419293, 1.2127239257097244, 0.945720209274441, 1.1707961442880332, 2.6411898247897625, 1.3631064374931157, 4.181315582245588, 4.600687203928828, 7.726326333358884, 2.744580851867795, 2.712666126899421, 1.839606687426567, 1.7855003220029175, 0.4764478246215731, 0.817127509508282, 1.8750618724152446, 0.5448594130575657, 0.1894103511585854, 2.5597112718969584, 7.424666220322251, 19.997160360217094, 38.36996868252754, 27.1422266587615, 49.045351445674896, 32.01311118900776, 19.600060768425465, 36.76106281578541, 36.5248066931963, 43.88381861150265, 31.510799042880535, 6.128727709874511, 0.06968334011617117, 0.16918501612963155, 0.017354277370031923, 0.06539484718814492, 0.004547500147964456, 0.06960733677260578, 0.034905513311969116, 0.11638687152299099, 0.05269359455269296, 0.03894808818586171, 0.022039240429876372, 0.09213281009579077, 0.04438047559233382, 0.03214189266145695, 0.05509438291483093, 0.026560858641460072, 0.019303439185023308, 0.018771319300867617, 0.04257055181369651, 0.07777711361995898, 0.07117432222003117, 0.05487590577104129, 0.13797096762573346, 0.009679822869657073, 0.020910958883177955, 0.009533720894978615, 0.060506684094434604, 0.06852012753370218, 0.04785361539688893, 0.09588864137185737, 0.02768699352600379, 0.07712691061897203, 0.07118724301108159, 0.07438632994308136, 0.09012473659822717, 0.031377417471958324, 0.029940896019979846, 0.09077899172552861, 0.09768262010766193, 0.05931619387411047, 0.04317684935813304, 0.012891111637145514, 0.019998041170765646, 0.044235333771212026, 0.0396735746471677, 0.04322278458857909, 0.06693513016216457, 0.040065825669444166, 0.012706261204584735, 0.025570306715962943, 0.037790204223711044, 0.011914455499208998, 0.058286723724449985, 0.05521128230611794, 0.017496409782324918, 0.04211889186990447, 0.005220618349994766, 0.04483740478463005, 0.045598202632390894, 0.03938509813451674, 0.04269760749593843, 0.008441132013103925, 0.08411891394644044, 0.01944299634487834, 0.0669911177828908, 0.011856325854751049, 0.02704777059989283, 0.06859889908810146, 0.07236547666252591, 0.07853642717236653, 0.054843941470608115, 0.021233268053038046, 0.03372326093085576, 0.11604569139308296, 0.04200135052087717, 0.04222345305606723, 0.008440875972155482, 0.05138276879733894, 0.026646554433682468, 0.03645224554929882, 0.024025073616940062, 0.0326780498289736, 0.03899214949342422, 0.012282423449505586, 0.034398489151499234, 0.07552842100267299, 0.07122086230083369, 0.023756223199598026, 0.05259287769149523, 0.07605376507854089, 0.009094090237340424, 0.1572999218478799, 0.035883496966562234, 0.04242627459461801, 0.05717140193155501, 0.005889058702450711, 0.11109640501672402, 0.06050819807569496, 0.08966818219050765, 0.2854815311729908, 7.183325970545411, 36.09495095908642, 57.108701169490814, 46.987613663077354, 33.319579884409904, 17.00801845639944, 21.963891126215458, 23.7558426707983, 27.667848654091358, 44.35741759836674, 51.82434752583504, 37.76225969195366, 15.575481075793505, 6.172823868691921, 1.8263053824193776, 0.6814098358154297, 0.25686155597213656, 0.21994016919052228, 0.6232270610053092, 0.5691528751049191, 1.2602281454019248, 1.1746730050072074, 1.336447661742568, 1.5074838465079665, 1.5484803216531873, 1.9553014542907476, 2.8751648822799325, 2.234556069597602, 1.428161677904427, 2.0546549605205655, 2.0789667684584856, 2.0580146927386522, 1.840150177013129, 4.013455789536238, 3.31639364361763, 2.7584985550493, 0.8789794030599296, 0.9605569881387055, 2.438316335901618, 1.8353753769770265, 3.8320777472108603, 3.20176281966269, 2.4997376650571823, 1.9067860138602555, 1.0134281823411584, 1.5080567845143378, 2.286203848198056, 1.495956927537918, 2.551179542206228, 3.955155280418694, 3.167228135280311, 4.640510017052293, 2.8464697720482945, 3.962409091182053, 1.4365593460388482, 1.79641428636387, 0.8839639043435454, 0.7222620374523103, 0.5592759582214057, 0.8217538800090551, 0.5557353794574738, 0.043712038022931665, 0.28642854129429907, 1.278372765518725, 6.706923684105277, 21.32928527891636, 47.11247876286507, 47.21276298165321, 59.38583917915821, 45.89965604245663, 13.767537139356136, 24.85686969012022, 37.33194798231125, 45.25710292160511, 42.33739659190178, 14.011081270873547, 0.5641823261976242, 0.04383412131574005, 0.07376741588814184, 0.061751150715281256, 0.02930504058895167, 0.03012572789884871, 0.014534481706505176, 0.09244748071068898, 0.034891913455794565, 0.0711584922100883, 0.014086802457313752, 0.07740140135865659, 0.027580345049500465, 0.012739907397190109, 0.012606702093762578, 0.02059549602563493, 0.052545784710673615, 0.06417134252842516, 0.08441630736342631, 0.04326774760556873, 0.11043564867577516, 0.0494548880669754, 0.056858646057662554, 0.03718306434166152, 0.003608206275202974, 0.05411271078628488, 0.04692698465078138, 0.08087068199529313, 0.038632193027297035, 0.10074268051539548, 0.03179510931659024, 0.08369007875444368, 0.048127208137884736, 0.07096991248545237, 0.054646741700707935, 0.01932999508426292, 0.039972422673599795, 0.0231469366553938, 0.036111462468397804, 0.06764471982023679, 0.04433416557731107, 0.0028061457123840228, 0.08008605378563516, 0.029862076225981582, 0.020115506449656095, 0.03203771368134767, 0.14485358580714092, 0.09794618643354625, 0.08681650200742297, 0.09452284473809414, 0.08526251898729242, 0.09258878562832251, 0.1441291903029196, 0.15737242967588827, 0.11333408416248858, 0.13470210396917537, 0.12106161520932801, 0.11040381054044701, 0.28004791180137545, 0.2254139239084907, 0.12122485801228322, 0.09196114391670562, 0.2401882881531492, 0.09729079582029954, 0.13968077197205275, 0.11720851063728333, 0.20245779713150114, 0.1854697844828479, 0.2667469036532566, 0.14659545093309134, 0.15631895104888827, 0.11035358940716833, 0.1464681132347323, 0.27529778075404465, 0.08617530867923051, 0.21223032352281734, 0.19711406668648124, 0.10453038703417405, 0.10305480449460447, 0.19453164510196075, 0.1590970769757405, 0.17748334037605673, 0.1335589590598829, 0.09830877010244876, 0.1250386139145121, 0.26252075855154544, 0.26501007028855383, 0.1088806489133276, 0.17923105362569913, 0.1562596979783848, 0.16437089710962027, 0.16514788119820878, 0.23073962016496807, 0.18166549096349627, 0.2247525961138308, 0.14455169497523457, 0.26229235518258065, 0.19024856243049726, 0.23835165076889098, 0.38151532178744674, 5.030239429324865, 33.623544573783875, 70.09162411093712, 62.83820852637291, 50.21288059651852, 31.38708148151636, 41.425259336829185, 28.272092230618, 21.549690552055836, 39.47301909327507, 48.46988372504711, 43.147516921162605, 26.171329356729984, 10.831390991806984, 4.701756555587053, 1.4813879155553877, 0.7089197658933699, 1.1725286138243973, 1.2330696964636445, 3.737698649056256, 12.365472223609686, 6.925556352362037, 13.49854102358222, 7.239547278732061, 12.296421378850937, 8.48352262750268, 7.36215197481215, 18.784062154591084, 6.458183331415057, 3.5042880987748504, 5.607392359524965, 4.021390713751316, 3.7562554283067584, 4.945247964933515, 3.949815616942942, 2.702690474689007, 0.5970923008862883, 1.0313915996812284, 2.823368674144149, 3.3382693072780967, 6.902400394901633, 3.838132959790528, 3.973672636784613, 1.2868065317161381, 0.9301091625820845, 1.5771794691681862, 2.8308255365118384, 4.014227148145437, 5.3304066974669695, 7.360970238223672, 8.236391488462687, 14.797731209546328, 14.29493933916092, 21.781050637364388, 9.89727571606636, 9.387406725436449, 7.753949426114559, 6.261745747178793, 3.579221502877772, 2.7336417138576508, 2.7828234247863293, 1.3300353870727122, 0.8277807722333819, 4.04319204390049, 10.113114584237337, 27.339544370770454, 47.12291680276394, 37.159042060375214, 59.019253849983215, 40.44847995042801, 27.8802477568388, 49.405773505568504, 48.84848780930042, 57.22766138613224, 43.51765885949135, 13.564348742365837, 0.4491292202146724, 0.28191595687530935, 0.17336589022306725, 0.15211771242320538, 0.15521729219472036, 0.15956085990183055, 0.1972209062660113, 0.2972456405404955, 0.12371832577628084, 0.1502252952195704, 0.09618198266252875, 0.21032753109466285, 0.18610371218528599, 0.16680048080161214, 0.15592789859510958, 0.1283471824717708, 0.1552157336845994, 0.18085258692735806, 0.14317610941361636, 0.17691061017103493, 0.345539950649254, 0.2083914607646875, 0.2544455387396738, 0.11669126339256763, 0.06432069232687354, 0.11868372210301459, 0.1106049474037718, 0.18431506206979975, 0.16047760524088517, 0.3479282115586102, 0.1608505196054466, 0.15615204203641042, 0.12857447261922061, 0.15709023544332013, 0.15070585068315268, 0.12124879969633184, 0.11004073705407791, 0.23117704200558364, 0.12374493177048862, 0.2704994101077318, 0.20217184763168916, 0.1565375877544284, 0.18212692870292813, 0.1969825878040865, 0.19383105769520625, 0.17331649287370965], [0.039284648446482606, 0.006488562812592136, 0.012186202147859149, 0.033150582676171325, 0.026180934692092706, 0.031218341828207485, 0.02778283818770433, 0.07837952231056988, 0.025338398554595187, 0.06142182268376928, 0.07882064004661515, 0.03228221794415731, 0.07714277031482197, 0.05583591089816764, 0.0703540412359871, 0.026792063617904205, 0.07977503453730606, 0.06678432575426996, 0.04380752274300903, 0.03703309856064152, 0.06211658052052371, 0.031770199129823595, 0.05912475688091945, 0.08901030538254417, 0.033610862665227614, 0.04877783045230899, 0.030117920505290385, 0.019029174800380133, 0.05372683852328919, 0.03908934486389626, 0.007849640314816497, 0.05113788974995259, 0.03993702965090051, 0.0324672873102827, 0.07795421232003719, 0.03484447908704169, 0.041773529737838544, 0.003914441222150344, 0.09292563161579892, 0.049145197262987494, 0.07211291638668627, 0.1338257166207768, 0.019193786865798756, 0.01998345982428873, 0.02422841094812611, 0.03729251628101338, 0.050955336264451034, 0.017061307153198868, 0.028299677251197863, 0.10871548394788988, 0.01712534522084752, 0.00841732113258331, 0.030084132376941852, 0.04353443466243334, 0.0686075673729647, 0.27357080311048776, 13.641384858638048, 35.99219307303429, 49.72970612347126, 43.2276052236557, 43.35136458277702, 25.16041450202465, 23.405497670173645, 27.649197354912758, 14.195491075515747, 25.920884795486927, 35.652802884578705, 39.91530776023865, 30.69794286042452, 23.00919033586979, 15.155615955591202, 7.857661535963416, 3.485443009994924, 0.7206428493373096, 0.09770688091521151, 0.06818779380409978, 1.2566699925810099, 0.7701677293516695, 0.8583002595696598, 1.2776831025257707, 4.276977824047208, 1.1147977178916335, 2.499284539371729, 1.093322813976556, 2.0021185046061873, 3.1575191812589765, 0.973781228531152, 2.950180694460869, 2.3340874537825584, 2.6098027965053916, 0.8250184392090887, 0.5390020273625851, 2.7167202718555927, 1.7230553040280938, 2.934863716363907, 3.9571204874664545, 1.9570991140790284, 5.781661933287978, 1.822341363877058, 1.5556223946623504, 2.4884650949388742, 1.3538947817869484, 2.799856485798955, 2.704981751739979, 1.6952761821448803, 2.042955863289535, 1.6540340264327824, 1.3198679639026523, 1.003956359345466, 0.8228334970772266, 0.3082581324269995, 0.10890456091146916, 0.20973903767298907, 1.8312129378318787, 6.54292780905962, 12.55829382687807, 20.078246109187603, 38.06219659745693, 45.78953795135021, 31.835138238966465, 22.52756427973509, 25.481654964387417, 27.311328984797, 27.432208098471165, 37.29473277926445, 38.23610566556454, 41.999051347374916, 22.6651643961668, 3.0497937742620707, 0.010283597111993004, 0.030416102454182692, 0.11650658736471087, 0.04828248027479276, 0.05787883936136495, 0.0087666537547193, 0.03967941534938291, 0.06795245877583511, 0.024297625495819375, 0.06706684653181583, 0.05814422023831867, 0.004238756973791169, 0.05417866173957009, 0.013748970341111999, 0.06348084833007306, 0.06517344227177091, 0.037233756738714874, 0.021639209844579455, 0.022061942727304995, 0.05374862055759877, 0.05218622158281505, 0.0711560357012786, 0.04373443603981286, 0.028156212683825288, 0.05694667219358962, 0.05031192020396702, 0.05259641773591284, 0.024241643441200722, 0.05554656978347339, 0.04984959559806157, 0.11393963955924846, 0.11785285809310153, 0.07978236695635132, 0.05861426689079963, 0.05119229659612756, 0.04642858053557575, 0.023648053320357576, 0.021318071412679274, 0.043729641765821725, 0.03770850489672739, 0.08823832336929627, 0.030877922399668023, 0.07310754270292819, 0.06513686923426576, 0.056794888150761835, 0.05373294268792961, 0.06534951680805534, 0.035968810552731156, 0.01491143613748136, 0.011484072001621826, 0.026239929866278544, 0.013261113072076114, 0.09794032346690074, 0.05155601575097535, 0.03769858980376739, 0.033343674658681266, 0.02311357526195934, 0.04726861749077216, 0.03804676467552781, 0.02120046327036107, 0.02153415698558092, 0.018371251608186867, 0.05660450871801004, 0.08421448030276224, 0.0715301078162156, 0.08686712390044704, 0.057028260198421776, 0.09228302820702083, 0.03276810202805791, 0.034891019167844206, 0.08071580319665372, 0.045457799424184486, 0.02370661990426015, 0.016863233504409436, 0.01607124875590671, 0.02686513733351603, 0.033852899287012406, 0.025461012482992373, 0.0529001639370108, 0.05622304852295201, 0.027921588261961006, 0.020496797806117684, 0.027516802365425974, 0.024405877011304256, 0.03273775560955983, 0.03925208671716973, 0.006655340557699674, 0.03720818232977763, 0.050104055771953426, 0.031804968748474494, 0.016895544758881442, 0.012947151208209107, 0.053532930178334936, 0.0296017567961826, 0.021844612201675773, 0.06629847877775319, 0.08147279382683337, 0.009021386667882325, 0.05372173625801224, 0.0527451960806502, 0.03232405651942827, 0.25021731562446803, 2.04200092703104, 24.89206150174141, 46.883100271224976, 52.07473509013653, 42.253063917160034, 37.67034262418747, 19.511730708181858, 14.046707209199667, 25.781757161021233, 25.772343166172504, 39.71828453242779, 52.502960711717606, 47.3713094741106, 37.94920966029167, 21.8048582598567, 12.77699489146471, 4.741620691493154, 1.7421515355817974, 0.31468361732549965, 0.09967066303943284, 0.1482085682800971, 0.43632883520331234, 0.5059956922195852, 0.4021677776472643, 0.927581941941753, 0.9284119005315006, 0.891592885600403, 0.5766960047185421, 1.30199633538723, 1.5257193055003881, 1.230563255958259, 0.8450466301292181, 2.0049804635345936, 2.036236636340618, 1.6064194939099252, 2.2629994433373213, 2.1389035647735, 1.5842482773587108, 0.3108382236678153, 1.951811460312456, 2.496745325624943, 2.29357972741127, 3.171752505004406, 1.72161138150841, 0.8186695142649114, 3.0054463539272547, 1.0930440039373934, 1.4705503033474088, 1.191277876496315, 1.8647055281326175, 0.3073431830853224, 0.5022476089652628, 0.40017436898779124, 0.4974970029434189, 0.5101288016885519, 0.15645856386981905, 0.13552461139624938, 0.16101619665278122, 0.5874649237375706, 2.561133108101785, 11.153048481792212, 19.751908220350742, 31.275162287056446, 45.54456129670143, 44.45324085652828, 38.94890561699867, 22.902587056159973, 33.733985647559166, 24.590494483709335, 32.134043499827385, 43.60543414950371, 48.18461023271084, 34.32806856930256, 7.091913325712085, 0.12720472033834085, 0.06606908093090169, 0.01600053506990662, 0.0799530980293639, 0.06642220963840373, 0.007134855159165454, 0.024166859075194225, 0.0134399641683558, 0.08378246871870942, 0.02952054543129634, 0.07932148582767695, 0.019983008969575167, 0.042037530220113695, 0.04103721905266866, 0.04626389425538946, 0.054374065512092784, 0.05367462843423709, 0.04616419042577036, 0.055912827083375305, 0.03354718268383294, 0.023250677768373862, 0.03102089343883563, 0.08176557850674726, 0.0295134504995076, 0.03947121324017644, 0.011904437433258863, 0.030435227599809878, 0.07512937561841682, 0.1198421255685389, 0.038691212321282364, 0.1504420765559189, 0.10160002435441129, 0.0691356573952362, 0.07490498726838268, 0.05403986528108362, 0.04672231887525413, 0.016897799032449257, 0.031521794880973175, 0.03142756067973096, 0.09047855550306849, 0.09371665713842958, 0.07183685971540399, 0.033502716905786656, 0.023689389090577606, 0.0838034343905747, 0.07435688152327202, 0.016738625054131262, 0.1321341987932101, 0.20633591950172558, 0.06966932836803608, 0.09361375094158575, 0.09730488920467906, 0.15743291471153498, 0.13845944922650233, 0.1577317775809206, 0.12752656009979546, 0.10227699662209488, 0.07788115530274808, 0.07626442369655706, 0.12726974731776863, 0.11864385392982513, 0.20871929707936943, 0.11412234889576212, 0.2178901940351352, 0.1771732562338002, 0.19351889553945512, 0.20722660061437637, 0.1632455043727532, 0.11396368514397182, 0.1493107614805922, 0.21264289825921878, 0.11751236816053279, 0.10197929892456159, 0.16273941902909428, 0.15045328298583627, 0.1733962885919027, 0.14426396432099864, 0.08391926137846895, 0.11650318832835183, 0.14507201471133158, 0.30407984100747854, 0.18940303358249366, 0.1676804749877192, 0.09657763643190265, 0.1847733382601291, 0.1611720328219235, 0.1311962428735569, 0.22279218334006146, 0.340074478299357, 0.07822577899787575, 0.16966710041742772, 0.20164045505225658, 0.17898173653520644, 0.12550725048640743, 0.2172591013368219, 0.12466598156606779, 0.1552637357963249, 0.12590008409461007, 0.15029459696961567, 0.12088986739399843, 0.08646688365843147, 0.32550190400797874, 1.0217358428053558, 20.671949051320553, 48.86159710586071, 65.32558545470238, 56.68765716254711, 58.56835104525089, 35.930389389395714, 31.361031979322433, 39.9183551967144, 24.29140493273735, 35.80574847757816, 48.25736492872238, 51.988886296749115, 44.451226964592934, 29.363874346017838, 21.904464215040207, 9.741753861308098, 4.9434406869113445, 1.2589290901087224, 0.2753388957353309, 0.8550437155645341, 2.621848862618208, 3.229594901204109, 3.912482145242393, 5.218298463150859, 9.724058210849762, 8.451629038900137, 8.304505683481693, 6.99127952568233, 5.947262272238731, 6.013245256617665, 6.0990513022989035, 9.338131919503212, 6.086053149774671, 5.724426079541445, 3.774274536408484, 5.093725947663188, 9.862033557146788, 9.07039163634181, 10.679681282490492, 10.535506568849087, 9.120283909142017, 13.073840662837029, 7.731808014214039, 4.209691034629941, 9.321907740086317, 6.2739122193306684, 10.670322384685278, 9.884168319404125, 9.549641869962215, 6.887214034795761, 7.01056681573391, 5.040136948227882, 2.996967821381986, 1.988879065029323, 1.167160333134234, 0.299475408392027, 0.628453561803326, 2.721186219714582, 9.090374764055014, 18.486201837658882, 24.48961939662695, 47.199653685092926, 56.153725013136864, 38.64480413496494, 32.598731964826584, 31.91881164908409, 40.51018483936787, 38.15091423690319, 46.6929242759943, 56.07442706823349, 57.25994825363159, 31.984331533312798, 5.039285318925977, 0.16848701139679179, 0.14254893525503576, 0.21827329066582024, 0.08895733088138513, 0.2537783479783684, 0.12672725220909342, 0.27378617436625063, 0.17986318533075973, 0.17857134371297434, 0.18218520213849843, 0.19665611704112962, 0.10503329598577693, 0.14836358808679506, 0.16010043094865978, 0.11234618912567385, 0.1910857346956618, 0.0791027452214621, 0.09213738172547892, 0.12095338781364262, 0.12173999013612047, 0.13249994401121512, 0.1989291817881167, 0.22636330890236422, 0.09828898444538936, 0.21863572590518743, 0.1066026563057676, 0.12693082331679761, 0.1731103687779978, 0.1928968125139363, 0.15958818577928469, 0.35872969601769, 0.28248485759831965, 0.2206926920916885, 0.2508410165319219, 0.16610836872132495, 0.15895749384071678, 0.07315437964280136, 0.2575154771329835, 0.15045976935653016, 0.18137614242732525, 0.22696979198371992, 0.17543832276714966, 0.1345123368082568, 0.18716937687713653, 0.1146858096763026, 0.25946290232241154, 0.18753791257040575], [0.04642094012524467, 0.08131830094498582, 0.08658076621941291, 0.030783135298406705, 0.04221326336846687, 0.0211828613828402, 0.11290106325759552, 0.013493850583472522, 0.05593457943177782, 0.06775886955438182, 0.04575266953906976, 0.019473435531836003, 0.007522688547396683, 0.014621924328821478, 0.06180453710840084, 0.06394592259312049, 0.057069720278377645, 0.029989896320330445, 0.010512079334148439, 0.05380541340855416, 0.04323550499975681, 0.028251331896171905, 0.039762372616678476, 0.001790058688584395, 0.05296313887811266, 0.04984619656170253, 0.06352680953568779, 0.008994701820483897, 0.028322752477834, 0.05316532216966152, 0.03812031522102188, 0.05551152928092051, 0.0473351584514603, 0.1356266121729277, 0.0580097171041416, 0.0517809532902902, 0.05272654590953607, 0.022848580301797483, 0.02595326233858941, 0.04486661571718287, 0.05041464828536846, 0.03086183078266913, 0.056520928046666086, 0.021307501374394633, 0.02592622218799079, 0.03305637073935941, 0.030063090634939726, 0.03843936821795069, 0.015928277716739103, 0.06581416804692708, 0.08396855482715182, 0.053675329763791524, 0.07765233633108437, 0.060610907603404485, 0.05784986962680705, 0.08112869705655612, 0.07245306493132375, 4.31747367605567, 21.840137466788292, 46.30424693226814, 43.327999636530876, 43.57943594455719, 39.83202002942562, 30.037219114601612, 30.922136530280113, 23.770029209554195, 20.867522656917572, 23.32850620150566, 28.207224011421204, 32.158989161252975, 35.049383863806725, 37.89724364876747, 37.660888731479645, 32.496559247374535, 24.994154423475266, 14.345771111547947, 7.5615443754941225, 3.2791627664119005, 0.5916494491975754, 0.11507077651913278, 0.09517913335002959, 0.3104876331053674, 0.01229984722158406, 1.5328644658438861, 0.3473441710229963, 0.9798657114151865, 0.35725151596125215, 1.0438413941301405, 2.0133193535730243, 1.219229414127767, 2.417056239210069, 1.050567151978612, 1.308694900944829, 0.6109422608278692, 1.8686549412086606, 2.3378174286335707, 1.4765587309375405, 1.2474933662451804, 1.6293050721287727, 1.5167680545710027, 1.6876505850814283, 0.6640651915222406, 0.31286333687603474, 1.4306617062538862, 0.5478780542034656, 0.5213325598742813, 0.12376312923152, 0.47192045662086457, 1.9265822391025722, 3.8975593959912658, 9.690041486173868, 15.944759510457516, 26.44165825098753, 32.26424351334572, 35.3645883500576, 41.525752544403076, 37.53011114895344, 73.95620673894882, 45.90640068054199, 15.720044318586588, 22.258620411157608, 32.62372322380543, 35.76302357017994, 40.160633996129036, 35.528222769498825, 25.557029619812965, 8.641545698046684, 0.060317829775158316, 0.0017870470765046775, 0.05061431940703187, 0.05678362234903034, 0.021902816988585982, 0.021751485655840952, 0.04582990855851676, 0.08668316775583662, 0.056499628408346325, 0.051808858042932115, 0.09613003974664025, 0.059446221857797354, 0.07416728505631909, 0.033982448585447855, 0.0057057074081967585, 0.08484145408147015, 0.04967185122950468, 0.07683860108954832, 0.08127746055833995, 0.04363527026725933, 0.012640426211874, 0.024422460301138926, 0.020423512578418013, 0.031139562852331437, 0.019731137035705615, 0.1288067499990575, 0.041164983485941775, 0.0056402847712888615, 0.023125828120100778, 0.020668215365731157, 0.007318567786569474, 0.06252484337892383, 0.05737390063586645, 0.03396880791115109, 0.037989033007761464, 0.12411793519277126, 0.00849212497996632, 0.03190780073055066, 0.08749011976760812, 0.03923908428987488, 0.11248329348745756, 0.013084848360449541, 0.008400203496421454, 0.015916514676064253, 0.07968513818923384, 0.08964611071860418, 0.030488612137560267, 0.04859228240093216, 0.047431066195713356, 0.03740687381650787, 0.08819217662676238, 0.13760347093921155, 0.02985259343404323, 0.03451208598562516, 0.04254939318343531, 0.11473948921775445, 0.039815068812458776, 0.04459433286683634, 0.04648035275749862, 0.036592964170267805, 0.03524485291563906, 0.04786776073160581, 0.034910378089989536, 0.043780708947451785, 0.04942544335790444, 0.014965635182306869, 0.08149056084221229, 0.05825849984830711, 0.041972774124587886, 0.0414657722285483, 0.0716184382326901, 0.04809091340575833, 0.016426984257122967, 0.03199174505425617, 0.03965592637541704, 0.038470085710287094, 0.04337834245234262, 0.034199144574813545, 0.038990086322883144, 0.029800593001709785, 0.008880230179784121, 0.03974128820118494, 0.06281818466959521, 0.037529317050939426, 0.006450779610531754, 0.055703545149299316, 0.05934885950409807, 0.025574943283572793, 0.05207447269640397, 0.052259798103477806, 0.08838256719172932, 0.07367265105131082, 0.07990856174728833, 0.02090632973704487, 0.09107556878007017, 0.03832120717561338, 0.00683589581058186, 0.013298017292981967, 0.04172793960606214, 0.10016160857048817, 0.033707100665196776, 0.04119832818105351, 0.024712166923563927, 0.07754137041047215, 0.02040622610365972, 0.4409876524005085, 10.704023726284504, 33.7047728151083, 54.176888689398766, 52.47445464134216, 43.42935159802437, 35.263464376330376, 31.08593814074993, 22.843376733362675, 20.673307478427887, 25.58533050119877, 33.184804916381836, 41.37762509286404, 51.84942618012428, 50.43123587965965, 49.61399853229523, 41.17272108793259, 31.400213576853275, 22.570490576326847, 11.112801041454077, 3.8824252830818295, 0.9296282508876175, 0.18074455991154537, 0.039960878566489555, 0.0473178515676409, 0.07780653977533802, 0.13834192272042856, 0.9442055749241263, 0.33276750007644296, 0.386149826226756, 0.355342801194638, 0.6617138895671815, 0.37052812229376286, 0.6117525673471391, 0.5471743200905621, 0.26935774949379265, 0.5986126349307597, 0.8231107040774077, 0.7823399011977017, 1.1764551093801856, 1.1309683439321816, 1.4811346353963017, 1.6595148760825396, 0.6578989536501467, 0.7962611666880548, 0.428282143548131, 0.4546331655001268, 0.5882467911578715, 0.33191254595294595, 0.29566839861217886, 0.05513225100003183, 0.13989741972181946, 1.408869638107717, 2.280534552410245, 6.521611427888274, 12.705510277301073, 22.56523545831442, 40.3346798568964, 41.761989668011665, 49.283123686909676, 44.46305952966213, 79.53874558210373, 55.201480910182, 18.3968648314476, 15.768847949802876, 22.11721669882536, 30.24869866669178, 39.656317457556725, 43.46387654542923, 37.34791472554207, 17.505837343633175, 0.9512369788717479, 0.007449783670381294, 0.030834864846838173, 0.10553860949585214, 0.007819587972335285, 0.02418036245217081, 0.07065072219120339, 0.026337535273341928, 0.11173108228831552, 0.03131348887109198, 0.07230378192616627, 0.003404842968848243, 0.022704058173985686, 0.023259381305251736, 0.03657177585409954, 0.05002260877517983, 0.026829957678273786, 0.03108231358055491, 0.046492416367982514, 0.066435516346246, 0.04317359132983256, 0.005669025831593899, 0.04218243084324058, 0.016886492412595544, 0.02467537866323255, 0.11577048819162883, 0.04185860954748932, 0.02637717338075163, 0.04835914784052875, 0.025330752578156535, 0.06966300526983105, 0.03185077781381551, 0.1080591582285706, 0.09348069870611653, 0.048998033089446835, 0.04716915856988635, 0.04608232411555946, 0.06885338152642362, 0.0473198219697224, 0.057876490463968366, 0.06281122332438827, 0.017719326824590098, 0.012148309015174164, 0.03439491571043618, 0.0534691091888817, 0.05167953509953804, 0.06983865678193979, 0.019089806410192978, 0.07758333886158653, 0.13585664826678112, 0.24968988611362875, 0.26623120007570833, 0.16463355801533908, 0.15598229801980779, 0.09576058379025199, 0.1720553613267839, 0.12287347228266299, 0.1303716129041277, 0.17442888318328187, 0.1549848515423946, 0.17474183201557025, 0.22855136805446818, 0.10836961344466545, 0.13266750611364841, 0.0988017713825684, 0.20982230664230883, 0.23100406222511083, 0.16875451110536233, 0.13829941250151023, 0.09343631827505305, 0.15904799132840708, 0.1365887769497931, 0.0844030748703517, 0.2137575892265886, 0.19378143770154566, 0.17036243341863155, 0.11307904511340894, 0.09708637866424397, 0.1615883331396617, 0.0994738974259235, 0.09733706130646169, 0.09506381844403222, 0.25081587256863713, 0.13046565785771236, 0.2161240903660655, 0.19225774914957583, 0.08892806057701819, 0.16517575626494363, 0.1322532244375907, 0.14906611992046237, 0.1660617024754174, 0.10120944687514566, 0.15644349827198312, 0.15383283054688945, 0.14109693816863, 0.1837488479213789, 0.15688553627114743, 0.14169643021887168, 0.23814048006897792, 0.21711741050239652, 0.17313992109848186, 0.21105155552504584, 0.11091572174336761, 0.23095319542335346, 0.1430027882452123, 0.2100494780461304, 8.458329029381275, 32.25292012095451, 64.05692473053932, 62.00615957379341, 58.11546854674816, 53.90390373766422, 44.893758818507195, 41.6696660220623, 32.96793155372143, 31.88153564929962, 35.514269918203354, 38.11411701142788, 42.59598791599274, 48.7813226133585, 50.72554528713226, 48.07743318378925, 40.99128842353821, 31.87029205262661, 19.22843500971794, 10.63075890764594, 4.3201150093227625, 1.1010906659066677, 0.2962077915435657, 0.5033053772058338, 0.9678537840954959, 0.3387974202632904, 4.874357068911195, 3.5174560546875, 4.591778106987476, 4.63654350489378, 9.015368688851595, 6.322415191680193, 7.359055615961552, 9.47363929823041, 6.919472403824329, 5.077561140060425, 4.54557828605175, 8.588449247181416, 8.565766364336014, 7.658499022945762, 6.35614313185215, 7.156991483643651, 5.320836436003447, 5.9319500438869, 4.026218354701996, 2.8927536634728312, 2.6147748297080398, 1.8340829713270068, 1.7579139210283756, 0.31107398914173245, 0.8034291851799935, 2.3876194562762976, 5.852785566821694, 12.75920519605279, 22.476400025188923, 33.78447353839874, 41.62950597703457, 45.18788203597069, 53.30041632056236, 46.0268048197031, 82.65016302466393, 56.83322735130787, 19.614689983427525, 32.50906817615032, 44.99343127012253, 47.56781592965126, 54.313552156090736, 54.65451546013355, 42.32224680483341, 15.613128505647182, 0.6289527600165457, 0.19100806151982397, 0.1085711584892124, 0.19508412951836362, 0.11662798046017997, 0.08095439625321887, 0.3393237217096612, 0.16766567656304687, 0.1700466198963113, 0.11932939058169723, 0.13596216682344675, 0.27087799448054284, 0.13667168968822807, 0.11694246553815901, 0.1307321185595356, 0.19014626479474828, 0.1451391790760681, 0.15425583987962455, 0.20426366507308558, 0.16900026588700712, 0.18233680806588382, 0.07701353271841072, 0.09025812280015089, 0.14847611251752824, 0.08287885939353146, 0.24396902590524405, 0.187105136574246, 0.14246685372199863, 0.08820980263408273, 0.12187026673927903, 0.14740219514351338, 0.15847903123358265, 0.13721868221182376, 0.1684054493671283, 0.17457182082580402, 0.2492817642632872, 0.15163273375947028, 0.17165185563499108, 0.12942061002831906, 0.13417933514574543, 0.21814489911776036, 0.10587431999738328, 0.1058588016894646, 0.15249430784024298, 0.24159323307685554, 0.3993913735030219, 0.12308902165386826, 0.06459752083173953, 0.14104774862062186], [0.0733364952611737, 0.027891611061932053, 0.0552826212515356, 0.04913549368211534, 0.017988993604376446, 0.02620239760290133, 0.006569860452145804, 0.04920591236441396, 0.014804724578425521, 0.04930758659611456, 0.03424986294703558, 0.030313929128169548, 0.02366032473219093, 0.01986971084988909, 0.00453503902463126, 0.0739189401792828, 0.0240728920471156, 0.09837768593570217, 0.030764086222916376, 0.05275264353258535, 0.04701088444562629, 0.06564041643287055, 0.05874484035302885, 0.04833617094845977, 0.07496193968108855, 0.05421138303063344, 0.03514087431540247, 0.005637096783175366, 0.03615647372498643, 0.054518821416422725, 0.030395990252145566, 0.09392213556566276, 0.0038018632176317624, 0.06917568141943775, 0.0657070464512799, 0.04905027657514438, 0.021443264304252807, 0.012419953618518775, 0.023517377812822815, 0.02084614898194559, 0.042035188744193874, 0.022155106380523648, 0.06388420559233055, 0.06430921130231582, 0.06241104245418683, 0.05249772693787236, 0.07662892210646532, 0.11621938363532536, 0.00944274193898309, 0.043492254699231125, 0.022068850266805384, 0.04494939115829766, 0.10443156264955178, 0.1002520986367017, 0.04722647092421539, 0.08025396469747648, 0.04272196107194759, 0.10063629364594817, 1.101740193553269, 5.467599760740995, 18.490715995430946, 40.94526909291744, 47.59125307202339, 40.49652077257633, 31.493363678455353, 40.71317754685879, 32.3471512645483, 30.548954755067825, 24.46319941431284, 21.944242380559444, 27.24825046956539, 25.27392391115427, 34.81155842542648, 31.73408456146717, 31.58358223736286, 37.30975717306137, 40.02655819058418, 36.451710015535355, 33.56720119714737, 23.78371797502041, 16.360147520899773, 10.751638021320105, 4.152069976553321, 2.158430004492402, 0.45292943192180246, 0.12934553436934948, 0.03614338223997038, 0.25184119411278516, 0.2805269235977903, 0.42984222702216357, 0.7744614395778626, 0.5330755328759551, 0.58110186830163, 0.34901388455182314, 0.7406668248586357, 0.2539997157873586, 0.4433847893960774, 0.11862196057336405, 0.11111202722531743, 0.5005652492400259, 0.5728070915210992, 1.324363003950566, 2.9641247587278485, 6.757087642326951, 10.343534220010042, 15.270606335252523, 21.409056298434734, 27.60811395943165, 33.19313786923885, 36.750297993421555, 35.21015703678131, 37.185678631067276, 28.21045383810997, 29.81464795768261, 44.76871892809868, 41.054201647639275, 45.818883776664734, 61.165811866521835, 38.04723300039768, 31.161136105656624, 42.25023306906223, 38.943506106734276, 51.78087405860424, 35.44611297547817, 15.801757033914328, 2.1377436770126224, 0.06704366183839738, 0.013380083055380965, 0.022068516300350893, 0.04133679438382387, 0.029412945150397718, 0.027487370643939357, 0.06168883257487323, 0.04610619900631718, 0.0068743687461392255, 0.017865205227280967, 0.04359098631539382, 0.026019541692221537, 0.07001767022302374, 0.07765940899844281, 0.05791491144918837, 0.012478959924919764, 0.11000441634678282, 0.04283920927264262, 0.011738056273316033, 0.059619209059746936, 0.07541710627265275, 0.05720523273339495, 0.05240342223260086, 0.07658576621906832, 0.03224320324079599, 0.037320721603464335, 0.05688300705514848, 0.0038876861026437837, 0.07316237999475561, 0.03153335383103695, 0.054870818348717876, 0.0161379344353918, 0.04382448452815879, 0.03495235025184229, 0.03362729381478857, 0.03946154305594973, 0.06976718796067871, 0.024367697224079166, 0.046374641242437065, 0.047189237375278026, 0.032137398957274854, 0.048069758486235514, 0.014704543918924173, 0.07546363151050173, 0.023889627955213655, 0.07210192517959513, 0.031045256291690748, 0.031135781609918922, 0.08149253495503217, 0.014317365476017585, 0.02012536773690954, 0.027159669771208428, 0.012059150176355615, 0.0676664053753484, 0.11038308235583827, 0.09988234582124278, 0.03883262485032901, 0.0956883431354072, 0.0175081876659533, 0.03761008869332727, 0.01569226547871949, 0.10376166304922663, 0.04889529387583025, 0.09344142425106838, 0.022617349350184668, 0.08120562066324055, 0.0774812935560476, 0.04125097984797321, 0.0927096517989412, 0.01810206722439034, 0.02563293655839516, 0.018946130330732558, 0.012961242737219436, 0.05794866432552226, 0.033685385424178094, 0.038948982473812066, 0.06459692711359821, 0.0711970022530295, 0.026125553777092136, 0.013782019104837673, 0.015899072350293864, 0.013036692253081128, 0.02517680146411294, 0.011025516578229144, 0.02823048682330409, 0.03539048084348906, 0.05711640136723872, 0.06416370582883246, 0.08807146630715579, 0.06530011945869774, 0.036210442704032175, 0.02641543665959034, 0.04515703665674664, 0.05088135527330451, 0.017660237026575487, 0.03112094236712437, 0.08386987145058811, 0.08212834029109217, 0.05411450307292398, 0.03265361832745839, 0.06185039441334084, 0.04708001550170593, 0.08841980816214345, 0.030906036809028592, 0.09482483204919845, 0.13789158751023933, 0.057327546091983095, 0.251626149402, 2.9444261407479644, 15.910405553877354, 30.60176432132721, 48.331730738282204, 52.99512930214405, 45.518247708678246, 39.743845760822296, 37.767735198140144, 30.52234288305044, 27.365561574697495, 22.52815704792738, 20.987884998321533, 29.797679968178272, 34.867829605937004, 48.88745091855526, 54.16270785033703, 51.85240142047405, 58.09830866754055, 52.20746196806431, 42.968527525663376, 34.93661731481552, 20.13894785195589, 12.547947932034731, 6.330996081233025, 1.1165895592421293, 0.6495140504557639, 0.1975804174435325, 0.1687527447938919, 0.06983957704505883, 0.17481672955909744, 0.32447506848257035, 0.26574515271931887, 0.42950208589900285, 0.36267397343181074, 0.25370481598656625, 0.27862649119924754, 0.19209609454264864, 0.33747874258551747, 0.1358274818630889, 0.16767130204243585, 0.07019086522632279, 0.35037667548749596, 0.3314415196655318, 0.8336763933766633, 1.7778592882677913, 3.6456699622794986, 6.959454333409667, 13.542080037295818, 18.174248076975346, 27.044495902955532, 36.39833427965641, 47.061523497104645, 51.63096830248833, 57.713020741939545, 54.67378422617912, 40.983183458447456, 50.06625786423683, 45.39495192468166, 41.97335332632065, 72.36262544989586, 37.53609202802181, 20.095090605318546, 32.010705918073654, 40.918560326099396, 56.361152082681656, 45.44862024486065, 27.51556422561407, 5.50128067843616, 0.037401775261969306, 0.04530224156042095, 0.11843575572129339, 0.04330780873715412, 0.028699895228783134, 0.016919254521781113, 0.05003400816349313, 0.08564830219256692, 0.020592790897353552, 0.05718762899050489, 0.025738518197613303, 0.10384401175542735, 0.03841699246549979, 0.08376542158657685, 0.06697453078231774, 0.07377957968856208, 0.02062813382508466, 0.0266596273650066, 0.013825811383867403, 0.04608587158145383, 0.020737435479531996, 0.0244860734892427, 0.028366821206873283, 0.017526659721625037, 0.05337019574653823, 0.02468555907398695, 0.050676901009865105, 0.02549138673202833, 0.05493747063155752, 0.061236946276039816, 0.02868490384571487, 0.04630235234799329, 0.02113749575073598, 0.037001271557528526, 0.027146585707669146, 0.040161829892895184, 0.05588780186371878, 0.04714399605290964, 0.04463843128178269, 0.047415228764293715, 0.061193063083919697, 0.03838746983092278, 0.0019408633284001553, 0.037449135415954515, 0.030317899618239608, 0.060590654393308796, 0.03630680686910637, 0.01923602063470753, 0.014557987378793769, 0.1017211057478562, 0.20832640409935266, 0.14864159660646692, 0.12668616691371426, 0.20647367695346475, 0.2715233067283407, 0.13902052771300077, 0.14186857879394665, 0.20458520797546953, 0.12363839647150598, 0.2530505385948345, 0.11017646102118306, 0.25047300034202635, 0.21662803832441568, 0.11928362233447842, 0.14259659597883, 0.20037950162077323, 0.1451794183230959, 0.18322769697988406, 0.20270677283406258, 0.18230643938295543, 0.181596189213451, 0.1987926266156137, 0.24321489996509627, 0.12880355876404792, 0.1512004921096377, 0.1324198514339514, 0.14045545540284365, 0.11800860520452261, 0.09204845016938634, 0.14623795839725062, 0.16354111663531512, 0.20174211444100365, 0.22463259083451703, 0.21606376860290766, 0.17005289846565574, 0.1298990726354532, 0.18458475853549317, 0.11703555312124081, 0.09677695503341965, 0.1567914171027951, 0.1481251063523814, 0.10136057040654123, 0.22825165913673118, 0.1305710428277962, 0.12926493713166565, 0.1854453084524721, 0.22718514839652926, 0.3086855204310268, 0.14527430932503194, 0.1315627302392386, 0.20172534190351143, 0.15402359218569472, 0.2207836348679848, 0.2757641760399565, 0.179779025784228, 0.2526894985930994, 0.20196443219901994, 0.5044074961915612, 1.5499171195551753, 10.68282751366496, 31.21102172881365, 57.33847863972187, 68.97607237100601, 59.742252454161644, 51.16217985749245, 56.42478346824646, 46.51770427823067, 43.012422770261765, 35.73067210614681, 29.03650861233473, 39.49184328317642, 37.243139147758484, 46.31910793483257, 46.08788654208183, 40.79643487930298, 51.41314499080181, 50.895867347717285, 47.15673118829727, 42.903801798820496, 32.54270397126675, 23.434942290186882, 14.19906573370099, 6.124813919886947, 4.0288853365927935, 1.0768796713091433, 0.2882789232535288, 0.14826660422841087, 0.422848227317445, 1.4231159049086273, 1.8568175076507032, 1.9764759368263185, 1.5218323515728116, 1.4506869879551232, 1.3780997204594314, 1.1859436752274632, 0.7977797195781022, 0.7128626480698586, 0.2659657783806324, 0.1914315903559327, 0.9410268079955131, 0.9424430038779974, 2.002574480138719, 4.759515831246972, 10.241184812039137, 15.052152257412672, 22.54492174834013, 28.666761852800846, 35.8977909386158, 42.21892274916172, 47.41844214498997, 44.62257497012615, 48.94920140504837, 38.44354033470154, 36.99079088866711, 59.1793392598629, 54.32605728507042, 52.90931090712547, 74.55709129571915, 47.806982696056366, 37.561254277825356, 52.56451740860939, 53.216972798109055, 68.66607740521431, 51.314783468842506, 26.85301087796688, 3.830095916055143, 0.1867232273798436, 0.20334595494205132, 0.14352598751429468, 0.1480945892399177, 0.19362143066246063, 0.08976004522992298, 0.1233154212241061, 0.3194397152401507, 0.13410140963969752, 0.18414844991639256, 0.12175450654467568, 0.19184848439181224, 0.21429269254440442, 0.2344942491617985, 0.31532305176369846, 0.1838352339109406, 0.1609546726103872, 0.21040217630797997, 0.1136244271765463, 0.1386143354466185, 0.2047525325906463, 0.10640456224791706, 0.12545659148599952, 0.1719762186985463, 0.12357926214463077, 0.12577749614138156, 0.16866925318026915, 0.06498819479020312, 0.18147913768189028, 0.11182554284459911, 0.1351840843562968, 0.0875105510931462, 0.14663894078694284, 0.187196851184126, 0.15724506229162216, 0.19456806970993057, 0.2202155059785582, 0.11861335908179171, 0.1807548015494831, 0.17877918959129602, 0.08056815291638486, 0.14659399632364511, 0.11033094648155384, 0.1590407034382224, 0.1652839020243846, 0.23580776149174199, 0.11787363080657087, 0.21545327792409807, 0.14294874505139887, 0.13522381894290447], [0.1224827983241994, 0.03640604314568918, 0.03701177665789146, 0.027596252984949388, 0.08177757903467864, 0.069302662886912, 0.04393517956486903, 0.030731116312381346, 0.031753270741319284, 0.029465095867635682, 0.04764344288560096, 0.056717838378972374, 0.06535497901495546, 0.045976145047461614, 0.03174135184963234, 0.05381481641961727, 0.034071706686518155, 0.011271997736912454, 0.0330163133185124, 0.027837551169795915, 0.013608096796815516, 0.01436525348253781, 0.029540147406805772, 0.022720090419170447, 0.08086976173217408, 0.04434471149579622, 0.07178800413385034, 0.02613012540678028, 0.03653437532193493, 0.0655396847287193, 0.10044569527963176, 0.07125694552087225, 0.08824041622574441, 0.02583950037660543, 0.08210639498429373, 0.0374770030612126, 0.031458805096917786, 0.02684221795789199, 0.08871958387317136, 0.052532897316268645, 0.005153562988198246, 0.043073182459920645, 0.06951232702704147, 0.04068452079081908, 0.017928295201272704, 0.039272013382287696, 0.04030039257486351, 0.021206747405813076, 0.02930967901193071, 0.06828161611338146, 0.028396087800501846, 0.02779510774416849, 0.06245082156965509, 0.07136171450838447, 0.027327523166604806, 0.06266320939175785, 0.01608855563972611, 0.01562059813295491, 0.056454435325576924, 0.13028009125264362, 0.5272310902364552, 6.564570497721434, 12.579852920025587, 24.32242076843977, 37.48653128743172, 43.53892631828785, 41.990346014499664, 46.356463730335236, 40.41913792490959, 44.022298380732536, 34.63497430086136, 31.515453793108463, 26.120039708912373, 31.395598724484444, 32.880547642707825, 27.31292299926281, 30.086479671299458, 37.574219182133675, 24.087093695998192, 41.28826528787613, 45.595071986317635, 35.52467755973339, 37.8251501172781, 34.18746091425419, 28.20674903690815, 21.48055326193571, 18.29317219555378, 14.950957037508488, 9.24679147079587, 9.634975790977478, 10.074426960200071, 9.442012645304203, 8.233284205198288, 8.77525007352233, 10.6379908695817, 9.77885602042079, 13.76813655719161, 14.205450341105461, 16.2587708607316, 17.031888775527477, 28.462492413818836, 35.13360634446144, 37.93770007789135, 36.020797938108444, 36.86496444046497, 32.48849608004093, 33.30329775810242, 34.00820553302765, 36.36587642133236, 25.85245616734028, 26.155123226344585, 20.74635475873947, 24.898790940642357, 54.50955703854561, 35.85528261959553, 34.68507461249828, 37.030776143074036, 39.75980870425701, 45.27073659002781, 48.78402426838875, 37.183911725878716, 25.538807697594166, 13.24249841272831, 2.8316945023834705, 0.14261391770560294, 0.08358450082596391, 0.048905298026511446, 0.03048376034712419, 0.04118803088204004, 0.10872274957364425, 0.07930273175588809, 0.023880321423348505, 0.040499766837456264, 0.026871855625358876, 0.06856447085738182, 0.05452461016830057, 0.01993160225538304, 0.051376590417930856, 0.029667590861208737, 0.042145713086938486, 0.05028185580158606, 0.023592598190589342, 0.07627987521118484, 0.07371303130639717, 0.05770450887212064, 0.02909677725256188, 0.056003773570409976, 0.039420175744453445, 0.028596280280908104, 0.05686187440005597, 0.05443031288450584, 0.02521584214264294, 0.014515163602482062, 0.02059074628050439, 0.07809811475453898, 0.02542416114010848, 0.03493987474939786, 0.005360827672120649, 0.04528985511569772, 0.04121721583942417, 0.14708126080222428, 0.05467818278702907, 0.049848204071167856, 0.018120810163964052, 0.018583583769213874, 0.05177845596335828, 0.03179663443006575, 0.10226388287264854, 0.07371805564616807, 0.11467362361145206, 0.009477707299083704, 0.024000148587219883, 0.05992024271108676, 0.04835666906728875, 0.08111864095553756, 0.05689207238901872, 0.03708386517246254, 0.01656827618717216, 0.03819475634372793, 0.06315912731224671, 0.03801870778261218, 0.10747315842309035, 0.016317882982548326, 0.05387979887018446, 0.058253089591744356, 0.03604222751164343, 0.030126219571684487, 0.005898615709156729, 0.06652859650785103, 0.05182440232601948, 0.05775845187599771, 0.04707186672021635, 0.06053161283489317, 0.06495717301731929, 0.00996006896457402, 0.043402881565270945, 0.10545802710112184, 0.03935659595299512, 0.0072399706368742045, 0.03954000290832482, 0.05904083853238262, 0.039643009295105, 0.04848251133807935, 0.05668790385243483, 0.045390894811134785, 0.05095537708257325, 0.022866404833621345, 0.040125624218489975, 0.032354235954699107, 0.01741520027280785, 0.05531242961296812, 0.05246748813078739, 0.05441247165435925, 0.018698696439969353, 0.07722090362221934, 0.030193348684406374, 0.05850409506820142, 0.05222755920840427, 0.0803941415506415, 0.0430458380287746, 0.12582958006532863, 0.08914181395084597, 0.05103333227452822, 0.033002798809320666, 0.03068737412831979, 0.08143380138790235, 0.07725218514679, 0.04553837439743802, 0.04945959328324534, 0.11438128422014415, 0.0038401450501623913, 0.05278480821289122, 0.040388889974565245, 0.02812742292007897, 0.04522907693171874, 0.22923260024981573, 2.914621727541089, 17.749362476170063, 29.595969691872597, 39.62537571787834, 48.8747102022171, 50.05567543208599, 46.46598905324936, 46.8311570584774, 37.060232162475586, 32.34224572777748, 32.108668461441994, 26.958814300596714, 25.116967633366585, 21.962190717458725, 23.536704629659653, 27.73898083716631, 36.79580815136433, 48.99478755891323, 45.626104921102524, 55.068286657333374, 51.97176821529865, 50.07740646600723, 50.65231181681156, 39.44014325737953, 29.296678751707077, 21.31428938359022, 16.42140783369541, 9.416580609977245, 7.952074119821191, 6.767389364540577, 6.967191193252802, 7.19366854056716, 5.136066125705838, 4.9827030301094055, 4.884451702237129, 9.44585993885994, 10.728058386594057, 17.254095152020454, 18.68872907012701, 17.066273130476475, 30.30058678239584, 44.215058237314224, 50.754856914281845, 53.58098566532135, 55.78121580183506, 52.91699409484863, 52.51320496201515, 50.96659295260906, 48.81607934832573, 35.865990445017815, 29.36050772666931, 23.112844973802567, 18.241671659052372, 36.360153928399086, 40.07906377315521, 39.18085277080536, 44.07972849905491, 45.34595735371113, 44.73784938454628, 47.580613642930984, 49.78777840733528, 38.79432611167431, 27.280026264488697, 7.5256662257015705, 0.45800649386364967, 0.11642086930805817, 0.042264979929313995, 0.02895099161833059, 0.0056585949459986296, 0.07902596262283623, 0.02840864864992909, 0.12529747502412647, 0.07137372245779261, 0.006795484941903851, 0.04146575367485639, 0.011124286229460267, 0.034651175592443906, 0.05001716883271001, 0.018806181687978096, 0.06746569895767607, 0.01673465270869201, 0.0313434939016588, 0.043645055484375916, 0.059811944811372086, 0.0434113457595231, 0.06502333548269235, 0.003939392227039207, 0.04285972594516352, 0.03561410107067786, 0.054061053597251885, 0.0535596734698629, 0.04892036733508576, 0.059635825746227056, 0.0803458722657524, 0.13305049884365872, 0.033928112243302166, 0.06616665108595043, 0.02978191500005778, 0.05422495691163931, 0.014338944347400684, 0.024512408599548507, 0.04202018251817208, 0.03513644369377289, 0.05976209475193173, 0.04228687328577507, 0.007238371772473329, 0.01385240810122923, 0.05857308140548412, 0.039286058527068235, 0.073890523344744, 0.016892693056433927, 0.08594725411967374, 0.07151775105739944, 0.0486404106777627, 0.021220204398559872, 0.013215753006079467, 0.21459195617353544, 0.12673833989538252, 0.16851925029186532, 0.14251301530748606, 0.11556428245967254, 0.18921843176940456, 0.15708655439084396, 0.24481351574650034, 0.12143053681938909, 0.13809373369440436, 0.08498298164340667, 0.15317564393626526, 0.1474394361139275, 0.1506301961489953, 0.12353362748399377, 0.20651312952395529, 0.13006333960220218, 0.16072503727627918, 0.056332322346861474, 0.14344240684295073, 0.23569799785036594, 0.14004182681674138, 0.10145540945813991, 0.13340925303054973, 0.19078785146120936, 0.1648768043378368, 0.2894712280249223, 0.12211297871544957, 0.19047972658881918, 0.14230935514206067, 0.1658031827537343, 0.16146068373927847, 0.2547509176656604, 0.09910935448715463, 0.15856059326324612, 0.14254154346417636, 0.1972980154096149, 0.12866639503045008, 0.18252828216645867, 0.20690859033493325, 0.14004736323840916, 0.21557712752837688, 0.17752996209310368, 0.09774836697033606, 0.21241433161776513, 0.14575456792954355, 0.16762188985012472, 0.09567525165039115, 0.13774459774140269, 0.24716374900890514, 0.18352964718360454, 0.1348916336428374, 0.16129104362335056, 0.1963020977564156, 0.10370416144724004, 0.0977967178914696, 0.20366098178783432, 0.07122343013179488, 0.1754514587810263, 0.26225103239994496, 1.3817470497451723, 12.136354967951775, 24.01681076735258, 42.08465315401554, 62.48586103320122, 63.06677766144276, 60.763128474354744, 63.02198186516762, 54.574339762330055, 56.247496381402016, 48.157852068543434, 44.86487276852131, 36.90304979681969, 42.744886726140976, 43.18796195089817, 37.724086940288544, 40.190507993102074, 44.553726464509964, 33.71670037508011, 52.852287366986275, 61.08770325779915, 46.926729530096054, 54.62755590677261, 45.965331718325615, 42.335625886917114, 32.46872194111347, 25.990502759814262, 21.92760307341814, 15.552915036678314, 14.401809554547071, 14.398193098604679, 14.128184337168932, 12.595863360911608, 12.87037393078208, 14.240675400942564, 14.973827060312033, 20.181946344673634, 20.693885274231434, 24.999360144138336, 25.255705788731575, 38.106703609228134, 45.72083003818989, 51.26139633357525, 46.22974053025246, 48.627377673983574, 42.41855263710022, 41.67486034333706, 44.77278470993042, 42.88325250148773, 34.616260305047035, 35.3553282469511, 26.66114967316389, 33.429298996925354, 65.10391294956207, 46.770987287163734, 48.90739984810352, 49.17445331811905, 53.77867765724659, 58.49368505179882, 63.03784981369972, 61.071820110082626, 42.747793570160866, 22.8967372700572, 4.638144169002771, 0.27446040068753064, 0.18239064345834777, 0.16930209734709933, 0.16767949535278603, 0.12958839477505535, 0.17484631156548858, 0.1875716951326467, 0.1651472577941604, 0.17784963478334248, 0.1159822080808226, 0.10799427225720137, 0.18712063261773437, 0.15895774617092684, 0.1244532671989873, 0.12739292898913845, 0.1858799101319164, 0.10133431322174147, 0.11273656622506678, 0.13873356889234856, 0.14518661715555936, 0.10755172217614017, 0.16542780445888638, 0.12656010570935905, 0.18124978436389938, 0.1672238760511391, 0.1302073014085181, 0.2193968725623563, 0.08161297810147516, 0.27219462383072823, 0.2563772303983569, 0.39004684367682785, 0.13904739345889539, 0.15727088903076947, 0.13645660044858232, 0.27255269524175674, 0.16966218739980832, 0.25459848053287715, 0.14753753319382668, 0.16793418559245765, 0.21714055066695437, 0.08214903136831708, 0.16331062040990219, 0.07016456351266243, 0.17405432125087827, 0.17468247504439205, 0.315114181721583, 0.16705163841834292, 0.14389716525329277, 0.16294806642690673, 0.13960113952634856, 0.1921204518293962, 0.14516395196551457], [0.06279897046624683, 0.015706937738286797, 0.06429148139432073, 0.03615241788793355, 0.10795163587317802, 0.06884025293402374, 0.12590747588546947, 0.07200898602604866, 0.07807098183548078, 0.001988627604987414, 0.006836889360783971, 0.007726901612841175, 0.025820388218562584, 0.002542940023886331, 0.03294044727226719, 0.05444298505608458, 0.052635925967479125, 0.009118467005464481, 0.049998615140793845, 0.05624530924251303, 0.049505365241202526, 0.04527493794739712, 0.03939489819458686, 0.037551165878539905, 0.04550101839413401, 0.0390356875868747, 0.015232883488351945, 0.12452770461095497, 0.02745455472904723, 0.026373139808129054, 0.020059168164152652, 0.04122509002627339, 0.0602830193383852, 0.00784310199378524, 0.04230471451592166, 0.03811737260548398, 0.038754409906687215, 0.03372722399944905, 0.029661824373761192, 0.05873446512850933, 0.013946479029982584, 0.07185214053606614, 0.031244780839188024, 0.03471504482149612, 0.05670049067703076, 0.02765771951089846, 0.07071433166856878, 0.04100064601516351, 0.0734628904319834, 0.08464402053505182, 0.048679833562346175, 0.004915698164040805, 0.0624912537750788, 0.06957779929507524, 0.013958813524368452, 0.07764812093228102, 0.0471473691141, 0.06370652801706456, 0.014997831403888995, 0.05905000405618921, 0.038240754656726494, 0.060581403522519395, 0.24469468306051567, 1.5755246579647064, 7.1598774287849665, 17.50011295080185, 28.794275410473347, 37.58561857044697, 50.58910220861435, 56.813088431954384, 50.155074298381805, 47.0912417024374, 37.05623097717762, 35.68326584994793, 40.034887343645096, 39.60987254977226, 31.60097010433674, 58.31635996699333, 34.32331882417202, 32.8968221694231, 87.72843092679977, 33.74283157289028, 22.636253647506237, 19.42008912563324, 23.054525703191757, 21.59503161907196, 21.14485077559948, 21.571742668747902, 36.61061368882656, 35.83197847008705, 31.26086365431547, 27.56063550710678, 33.93162064254284, 43.92456382513046, 36.68878689408302, 32.59545274078846, 33.954898193478584, 25.080936066806316, 27.102929167449474, 66.84802696108818, 44.57517631351948, 25.981689132750034, 24.659466482698917, 25.717614702880383, 22.612696811556816, 27.33570657670498, 26.835376024246216, 30.800586752593517, 39.73511382937431, 38.468011021614075, 48.362680077552795, 52.50203736126423, 57.89650909602642, 50.672370940446854, 38.08855198323727, 42.11761258542538, 47.016701102256775, 42.027990594506264, 41.54885530471802, 25.840635001659393, 5.688362689688802, 0.6968336238060147, 0.10392323601990938, 0.0864472686953377, 0.03107414253463503, 0.009654839395807358, 0.025866054420475848, 0.03191951553162653, 0.12388711984385736, 0.0813155846844893, 0.00826702138510882, 0.039659536923863925, 0.04092568538908381, 0.012057763287884882, 0.08454353373963386, 0.05001957339118235, 0.06296245075645857, 0.03690301862661727, 0.06090489085181616, 0.09834234486334026, 0.08041135937673971, 0.05712858743208926, 0.08382346495636739, 0.042847547301789746, 0.02064455384243047, 0.011109250317531405, 0.06435536546632648, 0.0317402979999315, 0.036155750131001696, 0.017791734462662134, 0.022892292799951974, 0.028648334518948104, 0.036170979001326486, 0.011825244710053084, 0.03935887434636243, 0.0346642782096751, 0.05476509570144117, 0.06497448732261546, 0.04972108159563504, 0.042180772143183276, 0.019963956183346454, 0.12220178410643712, 0.0491542032250436, 0.030122473581286613, 0.015948488253343385, 0.054624800104647875, 0.08157000032952055, 0.015582229098072276, 0.014010100567247719, 0.017670402594376355, 0.04263321134203579, 0.043228473150520585, 0.07527950467192568, 0.036091610018047504, 0.05104388190375175, 0.033303910386166535, 0.029261851304909214, 0.01541823487059446, 0.018544650702096988, 0.05426390853244811, 0.026379292212368455, 0.030107055463304278, 0.08983748833998106, 0.03800742713792715, 0.0034578684926600545, 0.015972166474966798, 0.02719338925089687, 0.019024367538804654, 0.08141748156049289, 0.08052645905991085, 0.005997917851345846, 0.013598938694485696, 0.05590513101196848, 0.012038507338729687, 0.04269787466910202, 0.0331403855670942, 0.015438320169778308, 0.0492552132345736, 0.11297668068436906, 0.07253860487253405, 0.05130877667397726, 0.026371108178864233, 0.007394375388685148, 0.029558330024883617, 0.018603853677632287, 0.03952534549171105, 0.04021724234917201, 0.05544363761146087, 0.07247486923006363, 0.018160633808292914, 0.06795116001740098, 0.03659290108771529, 0.02758880924375262, 0.03232302493415773, 0.043016768104280345, 0.04939773527439684, 0.030402025768125895, 0.09899158307234757, 0.05224349682976026, 0.027400635844969656, 0.03390782934729941, 0.039527657281723805, 0.0423237172071822, 0.01525325915281428, 0.07233934564283118, 0.08042960878810845, 0.08782676537521183, 0.013536838559957687, 0.04651546376408078, 0.09003685889183544, 0.0024100241580526927, 0.045326984763960354, 0.02451996366289677, 0.05609590749372728, 0.055078794102882966, 0.05798023157694843, 0.022877652081660926, 0.19331615563714877, 0.8896151510998607, 5.155464084818959, 18.094560652971268, 31.224248819053173, 42.628658562898636, 49.56841237843037, 56.251242980360985, 59.27184149622917, 52.089455500245094, 49.788287580013275, 38.311204835772514, 37.76468776166439, 38.44103246927261, 30.63866414129734, 27.219554409384727, 42.73606359958649, 20.25063145905733, 33.04874561727047, 76.26430928707123, 31.59407537430525, 37.128438502550125, 45.076513811945915, 45.75931437313557, 42.34432362020016, 45.10782793164253, 44.4036041200161, 49.55667480826378, 47.24432788789272, 47.80732087790966, 49.590200409293175, 52.5428281724453, 58.5599534958601, 57.09478251636028, 48.6458370834589, 52.18240611255169, 43.64868722856045, 34.96780604124069, 62.826277166604996, 46.85994811356068, 36.6447738558054, 33.65498788654804, 32.449190989136696, 23.799278140068054, 25.18935564905405, 21.981714069843292, 25.32817929983139, 29.65896461158991, 23.870222233235836, 30.419869981706142, 32.55601465702057, 41.405253410339355, 57.87201561033726, 42.548137083649635, 44.96377386152744, 50.584983229637146, 49.853191897273064, 51.901616379618645, 39.52085092663765, 14.490530043840408, 3.6958298832178116, 0.41974456573370844, 0.12316947788349353, 0.07114894819096662, 0.028300632766331546, 0.04666875065595377, 0.03290766660938971, 0.020598099108610768, 0.08138858975144103, 0.011902337155333953, 0.03315351787023246, 0.06599952685064636, 0.0474077293620212, 0.049755947693483904, 0.04251200007274747, 0.029925045600975864, 0.11120231691165827, 0.029180983183323406, 0.029371201198955532, 0.07850696390960366, 0.011288908499409445, 0.027487459701660555, 0.015096744846232468, 0.004800046044692863, 0.03232557050068863, 0.09887256484944373, 0.050279577408218756, 0.08143158236634918, 0.02639671783981612, 0.015221486883092439, 0.11435596214141697, 0.05043003671744373, 0.010828740760189248, 0.029041862035228405, 0.08019609944312833, 0.03040586452698335, 0.04975395873771049, 0.07096996443578973, 0.04538708017207682, 0.017202259550685994, 0.05145528033608571, 0.07272816423210315, 0.00448451407464745, 0.13568246620707214, 0.060654527333099395, 0.034089688924723305, 0.0784819906402845, 0.037024738267064095, 0.03225902954000048, 0.04985073108400684, 0.03779525824938901, 0.08865319134201854, 0.026663959652069025, 0.015479782105103368, 0.06561609625350684, 0.1786761052790098, 0.07875225855968893, 0.18937778571853414, 0.13546393340220675, 0.19355175783857703, 0.09849124195170589, 0.20083515060832724, 0.16380794841097668, 0.1291139842942357, 0.10153697890928015, 0.0952305196551606, 0.13397355243796483, 0.19390969566302374, 0.16645607975078747, 0.14496248855721205, 0.09254652773961425, 0.23164526297478005, 0.10083002387546003, 0.2243891218677163, 0.17979973170440644, 0.11673393688397482, 0.11366478516720235, 0.22316610702546313, 0.2377480620634742, 0.12213398891617544, 0.15161691117100418, 0.07645319637958892, 0.20289348234655336, 0.08015220140805468, 0.06601696732104756, 0.15983834891812876, 0.18273207591846585, 0.1232397518469952, 0.06615342601435259, 0.22578158386750147, 0.13880496349884197, 0.1259805922745727, 0.21697410178603604, 0.18293845234438777, 0.18627194222062826, 0.19208171172067523, 0.34053912211675197, 0.13650691806105897, 0.17058485507732257, 0.1516879940754734, 0.08793785003945231, 0.23796865803888068, 0.14199984987499192, 0.17245911934878677, 0.2272472661570646, 0.1905654149595648, 0.19376877666218206, 0.16077387059340253, 0.17947036656551063, 0.0820032216142863, 0.2476609731093049, 0.11390574567485601, 0.14430168026592582, 0.1473556031123735, 0.2157897231518291, 0.10801641794387251, 0.17913818126544356, 0.45354375208262354, 3.597210687585175, 13.808232005685568, 28.481400199234486, 43.62707398831844, 54.063696563243866, 67.50574886798859, 76.63324669003487, 68.58987629413605, 64.83503177762032, 56.88283748924732, 51.79081812500954, 56.26167342066765, 52.91415944695473, 44.227578565478325, 70.15036895871162, 44.29211810231209, 39.65977527201176, 100.0254374742508, 37.28204146027565, 32.260424718260765, 31.96497917175293, 33.80315713584423, 33.16629230976105, 34.41305100917816, 33.36260877549648, 52.10096128284931, 52.77456633746624, 46.23066388070583, 41.64096236228943, 48.70617784559727, 59.08894591033459, 52.17835932970047, 46.763243302702904, 47.68861144781113, 37.99068823456764, 37.965427190065384, 86.28205373883247, 52.00853884220123, 33.80289874970913, 30.408200807869434, 36.102254167199135, 29.96585324406624, 38.24427142739296, 34.74558636546135, 41.462603732943535, 53.776800557971, 47.328839153051376, 62.94747546315193, 62.83586785197258, 68.91520723700523, 67.75722697377205, 54.217937886714935, 59.867691323161125, 66.12602010369301, 58.374056071043015, 57.457644045352936, 40.204187259078026, 12.297447323799133, 2.430893196724355, 0.26016268820967525, 0.18165006913477555, 0.19040193466935307, 0.14714536751853302, 0.10653601886588149, 0.13431920029688627, 0.19961970567237586, 0.14914849831257015, 0.15551839635008946, 0.23939962266013026, 0.17171429994050413, 0.1358278380939737, 0.14738975674845278, 0.13851963740307838, 0.1587301294784993, 0.1487663367879577, 0.08656328864162788, 0.22083574847783893, 0.16770199727034196, 0.1546699582831934, 0.13824366236804053, 0.14565326477168128, 0.09625769656850025, 0.09195278733386658, 0.1694852000218816, 0.15289536444470286, 0.14256956696044654, 0.0725503901776392, 0.12303726427489892, 0.28145995165687054, 0.1291486425907351, 0.07160301640396938, 0.15748180740047246, 0.11764232564019039, 0.16997335507767275, 0.20131328667048365, 0.1515251223463565, 0.1499634506762959, 0.06885286202304997, 0.2015546034090221, 0.17110538261476904, 0.11511590651934966, 0.26468655327335, 0.17636479024076834, 0.09406119177583605, 0.12885049218311906, 0.07905231628683396, 0.10005514006479643, 0.1431165446410887, 0.17920001700986177, 0.24894717440474778, 0.16549346968531609, 0.11096798378275707, 0.14848151535261422], [0.08521577110514045, 0.04415857714775484, 0.05793987358629238, 0.06908271257998422, 0.14656854065833613, 0.016626249052933417, 0.09379038951010443, 0.031129243288887665, 0.020214700052747503, 0.0362777629197808, 0.057317170867463574, 0.022107364020484965, 0.10110540519235656, 0.047125601922743954, 0.06161544530186802, 0.05698341963579878, 0.054411707242252305, 0.023416147014359012, 0.0476933634490706, 0.05775344237918034, 0.01765161141520366, 0.042548372730379924, 0.030933581620047335, 0.054257655938272364, 0.07754562291665934, 0.06591563447727822, 0.05165910748473834, 0.024890657150535844, 0.005873091859029955, 0.0517512080114102, 0.030324760773510206, 0.08209351872210391, 0.05910697873332538, 0.046162672733771615, 0.05979130568448454, 0.011062934736401075, 0.15841922897379845, 0.050476773467380553, 0.038175159934326075, 0.03883262113959063, 0.05620210511551704, 0.050177246375824325, 0.05620626856398303, 0.06297163854469545, 0.05201976528041996, 0.051575990655692294, 0.026450072691659443, 0.008733928752917564, 0.05475335492519662, 0.029187337822804693, 0.05376587920181919, 0.033918905901373364, 0.025963242369471118, 0.06585635914234444, 0.0933861119847279, 0.020274320486350916, 0.09922056531650014, 0.01839357726566959, 0.04070879644132219, 0.024848848261171952, 0.029930268465250265, 0.02094807925459463, 0.029046531999483705, 0.04098505720321555, 0.012222185177961364, 0.24223213316872716, 0.9138786303810775, 3.2641120115295053, 9.504781477153301, 18.174185380339622, 24.408089071512222, 28.475267328321934, 27.095724754035473, 28.691034950315952, 45.459977835416794, 51.601151302456856, 51.5305282920599, 55.64723879098892, 51.81904301047325, 42.68127053976059, 67.21635639667511, 57.42868959903717, 33.95634971559048, 30.150080658495426, 30.15257142484188, 42.560520619153976, 30.566473715007305, 21.83165442198515, 21.406147554516792, 21.892232671380043, 29.99572154134512, 31.2298896163702, 24.998550787568092, 26.37094784528017, 25.26769034564495, 33.56041096150875, 31.720314100384712, 40.68310596048832, 34.82775315642357, 89.59498956799507, 56.56298205256462, 45.20024657249451, 52.36121691763401, 52.07169525325298, 53.82875517010689, 54.065376073122025, 57.152246832847595, 51.70115053653717, 58.041057139635086, 52.666188552975655, 51.88939243555069, 53.6877865344286, 42.40694805979729, 40.44691443443298, 28.497642427682877, 20.962977334856987, 16.267316602170467, 9.32530665770173, 3.96402305457741, 0.443156118853949, 0.09213461351464503, 0.07828627887647599, 0.03302577570138965, 0.03798859514063224, 0.053278429186320864, 0.012086315564374672, 0.02105545689119026, 0.07011665045865811, 0.015210736873996211, 0.04664214837248437, 0.03318125935038552, 0.02410651319223689, 0.049187774275196716, 0.017504198622191325, 0.066760680929292, 0.020691118043032475, 0.021826149422849994, 0.06122051883721724, 0.029675526275241282, 0.04293912090361118, 0.04440887016244233, 0.05163875779544469, 0.04878419065789785, 0.04128829874389339, 0.04875532482401468, 0.04545653777313419, 0.027066194415965583, 0.0771057816746179, 0.014198632979969261, 0.03677037086163182, 0.0539948985533556, 0.053801713802386075, 0.03312875240226276, 0.037266956715029664, 0.04569046272081323, 0.008600849614595063, 0.035600219198386185, 0.034296276862733066, 0.040811517101246864, 0.03036359736142913, 0.10814002263941802, 0.03510042355628684, 0.03356707966304384, 0.014130748731986387, 0.050207622480229475, 0.021378491510404274, 0.04639245649741497, 0.09159064153209329, 0.006730715858793701, 0.004664813750423491, 0.01900444087368669, 0.0246205246730824, 0.017866750749817584, 0.029543006530730054, 0.058006303224829026, 0.03449975891271606, 0.01834244885685621, 0.031415196499438025, 0.0466325152956415, 0.07493618715670891, 0.058458516068640165, 0.048555861503700726, 0.09228608585544862, 0.024507024318154436, 0.0482172046758933, 0.041806740846368484, 0.09545340886688791, 0.0071261692482949, 0.03246986998419743, 0.03802084887865931, 0.03412415797356516, 0.0274461294975481, 0.06132863120001275, 0.06796307890908793, 0.027241569478064775, 0.013157320936443284, 0.020492875555646606, 0.039454796933569014, 0.026832334406208247, 0.055892458840389736, 0.04133305024879519, 0.0158589165948797, 0.009453879720240366, 0.07607027044286951, 0.02729723240918247, 0.0472769295447506, 0.02012815821217373, 0.014203190694388468, 0.05190274343476631, 0.03682761271193158, 0.0282797505860799, 0.09567881395923905, 0.16236663825111464, 0.021940583028481342, 0.06318795232800767, 0.07660879506147467, 0.017009284456435125, 0.01840028999140486, 0.017821444489527494, 0.013185349071136443, 0.04860964123508893, 0.021678816410712898, 0.06239452966838144, 0.09508410876151174, 0.06017176769091748, 0.019050225819228217, 0.021908132621319965, 0.04619728650141042, 0.019702451172634028, 0.03993871061538812, 0.0365162557864096, 0.029806836319039576, 0.009811608815653017, 0.015868471746216528, 0.06442878613597713, 0.03859467375150416, 0.08485358819598332, 0.0303932164752041, 0.03998389256594237, 0.09399627611855976, 0.029824304619978648, 0.9492365049663931, 4.128677481785417, 10.237907487899065, 20.50269093364477, 32.15311847627163, 38.4869834035635, 42.969238087534904, 38.763323575258255, 45.94634413719177, 53.56438435614109, 56.23863525688648, 50.02253741025925, 57.631393522024155, 44.68887761235237, 38.753675892949104, 83.51073324680328, 45.74191510677338, 20.817241854965687, 14.844483900815248, 19.605585671961308, 28.756172955036163, 19.217349104583263, 17.666817605495453, 27.461559623479843, 29.374574571847916, 29.372144602239132, 25.036204867064953, 26.618540659546852, 34.55044403672218, 28.10699298977852, 27.910256646573544, 28.87394953519106, 25.309282913804054, 27.112973928451538, 94.15026113390923, 50.28685122728348, 24.3081696331501, 26.467738151550293, 28.02210744470358, 34.08042445778847, 36.2271648645401, 42.11764298379421, 45.62555015087128, 55.63137084245682, 52.76697814464569, 62.74372659623623, 63.04197259247303, 56.15663565695286, 52.04982742667198, 43.10028165578842, 36.09039880335331, 29.36999201774597, 19.035369269549847, 9.441986996680498, 1.9335438217967749, 0.13402109441813082, 0.10376187827205285, 0.016413807425124105, 0.030007444402144756, 0.04991588051780127, 0.05238353267486673, 0.05497340171132237, 0.020196860677970108, 0.0801415961177554, 0.05175203921680804, 0.008102838837658055, 0.017100060249504168, 0.008745734467083821, 0.027421154372859746, 0.04953318464686163, 0.05387507138948422, 0.03089616438956, 0.03240606383769773, 0.043116100860061124, 0.040246004282380454, 0.0467551700421609, 0.08961346364230849, 0.0626761004969012, 0.05622408010822255, 0.002736529941103072, 0.032152089770534076, 0.03628968923294451, 0.033764223771868274, 0.017310555595031474, 0.0354991609492572, 0.05955703934887424, 0.05458120635012165, 0.014447352641582256, 0.07951763545861468, 0.0438624824892031, 0.030145897617330775, 0.04806529817869887, 0.02706169143493753, 0.03881885430018883, 0.05328035505954176, 0.045140356887714006, 0.030972935855970718, 0.07001432313700207, 0.058770425894181244, 0.0323359568574233, 0.013094730984448688, 0.034554295634734444, 0.0289809780952055, 0.0312741995730903, 0.013353861122595845, 0.03853725749650039, 0.06806542107369751, 0.03795517252001446, 0.021561840949289035, 0.023666336128371768, 0.01644588861381635, 0.23591323551954702, 0.16109657124616206, 0.1656810104032047, 0.2174780794302933, 0.2337064890889451, 0.11032791109755635, 0.19590276293456554, 0.12561912182718515, 0.11066920254961587, 0.14184138650307432, 0.20022700511617586, 0.1388009707443416, 0.17260553024243563, 0.1307234651176259, 0.1886452711187303, 0.18643148912815377, 0.11595083749853075, 0.11460514564532787, 0.13751600141404197, 0.11042331418138929, 0.04424289254529867, 0.13470228208461776, 0.09351980988867581, 0.15717512229457498, 0.15137786540435627, 0.14133798773400486, 0.24028187297517434, 0.18071782775223255, 0.15794606530107558, 0.1598757234751247, 0.11049272725358605, 0.13396909955190495, 0.1520226284628734, 0.17388827312970534, 0.1284556250902824, 0.2090058699832298, 0.20406980125699192, 0.2142696562805213, 0.1049078359210398, 0.11501610249979421, 0.16662163805449381, 0.13864685635780916, 0.19212503830203786, 0.15234713995596394, 0.20841555087827146, 0.1803922772523947, 0.11470371769974008, 0.16586590907536447, 0.1312215649522841, 0.13494885322870687, 0.07843412953661755, 0.13506234245141968, 0.12596723361639306, 0.14035099069587886, 0.1977869274560362, 0.12602667964529246, 0.16943605500273407, 0.07016891991952434, 0.15787524956976995, 0.20376647065859288, 0.25604364986065775, 0.09305512154242024, 0.09182908615912311, 0.17302644671872258, 0.17723976750858128, 0.3417802305193618, 2.0669686747714877, 6.438266700133681, 14.978360217064619, 26.95604044944048, 36.50640808045864, 43.86300712823868, 45.27161814272404, 56.37660205364227, 67.28834733366966, 70.91814056038857, 70.94075694680214, 75.48218965530396, 66.51676073670387, 51.26931130886078, 85.2896685898304, 63.929114788770676, 46.96849308907986, 41.002323031425476, 42.17695780098438, 54.94262360036373, 38.035085052251816, 32.77615204453468, 33.499291241168976, 35.47667093575001, 40.174275264143944, 40.04334568977356, 34.11828562617302, 37.03969806432724, 36.024134159088135, 42.896221205592155, 44.59958240389824, 53.10196816921234, 45.821707025170326, 106.46999046206474, 65.4021817445755, 58.54758135974407, 65.08925333619118, 64.6606895327568, 66.27499490976334, 66.59094035625458, 72.85691812634468, 65.80860793590546, 76.04576781392097, 68.9207473397255, 70.88878333568573, 76.06124058365822, 60.24623081088066, 58.2316929101944, 47.018638998270035, 35.7683926820755, 26.56985007226467, 15.72091257199645, 6.4607154205441475, 0.9908736019860953, 0.1640898606274277, 0.24355971661861986, 0.12601424125023186, 0.07652363361557946, 0.11568945308681577, 0.13293637137394398, 0.11275419223238714, 0.13401564705418423, 0.24190769589040428, 0.1121794582286384, 0.14446078188484535, 0.21655146352713928, 0.10214092384558171, 0.11124152457341552, 0.12273311731405556, 0.2493342786328867, 0.09452892292756587, 0.22568920132471249, 0.18205168977146968, 0.11824745059129782, 0.11944330282858573, 0.20315673697041348, 0.19897881662473083, 0.12637443520361558, 0.09586828426108696, 0.10658408034942113, 0.10160815087147057, 0.14916386076947674, 0.18380326218903065, 0.10476722862222232, 0.13211729266913608, 0.24936268804594874, 0.09186373703414574, 0.1850640820339322, 0.13324083003681153, 0.10295908228727058, 0.18454739882145077, 0.12606466276338324, 0.09443662202102132, 0.2205330115975812, 0.16786611580755562, 0.16998092498397455, 0.14275501482188702, 0.1505559665383771, 0.11984858225332573, 0.07184674512245692, 0.12869539816165343, 0.2351418769103475, 0.17017057340126485, 0.16103711037430912, 0.14475869480520487, 0.0880721045541577, 0.1730423583649099, 0.16884214390302077, 0.17323610343737528, 0.12925490329507738], [0.03837049691355787, 0.07246862034662627, 0.027976323508482892, 0.022350259678205475, 0.023764589059283026, 0.03295238842838444, 0.05933510750764981, 0.04208874954201747, 0.03791504830587655, 0.03188060472893994, 0.1091411204834003, 0.04556464271445293, 0.005629276865874999, 0.036248370161047205, 0.07070279869367369, 0.07551021612016484, 0.020351605890027713, 0.04021310116513632, 0.08103049607598223, 0.10469798624399118, 0.062495580496033654, 0.012107643033232307, 0.024638302820676472, 0.04209902086586226, 0.07109829661203548, 0.08004693518159911, 0.0728502104175277, 0.04026627975690644, 0.03488896712951828, 0.03472880423942115, 0.01464576675061835, 0.04012357960164081, 0.021663826883013826, 0.05964465359284077, 0.02284057809447404, 0.032388419276685454, 0.05319891177350655, 0.062113782623782754, 0.04686652187956497, 0.04064260057930369, 0.037318346730899066, 0.023938505801197607, 0.02053048574452987, 0.017254983577004168, 0.04328079456172418, 0.03369179758010432, 0.04071361669048201, 0.04374914169602562, 0.05673176478012465, 0.055470024672104046, 0.010917998861259548, 0.05914565204875544, 0.08143052109517157, 0.043513661948964, 0.04170423169853166, 0.09540654224110767, 0.024813230738800485, 0.10253856657072902, 0.016807965766929556, 0.018969665688928217, 0.020207354646117892, 0.010248039889120264, 0.053776098575326614, 0.004801153700100258, 0.04220421287755016, 0.06345983070787042, 0.09315309245721437, 0.02515121963369893, 0.0645628699567169, 0.1289556099800393, 0.33941343252081424, 1.123295605648309, 4.727753810584545, 5.088334986940026, 9.710750374943018, 22.789843305945396, 35.40178835391998, 51.46958716213703, 53.51848281919956, 62.02979810535908, 60.11242479085922, 49.92588199675083, 51.76320880651474, 48.467581048607826, 52.5647833943367, 62.51691676676273, 52.82617136836052, 55.11542312800884, 45.38811609148979, 46.496744602918625, 44.055132418870926, 49.05415937304497, 50.79419620335102, 53.430794924497604, 50.59389375150204, 52.94939115643501, 54.78430509567261, 55.14524392783642, 47.92934373021126, 50.41115015745163, 59.97834138572216, 64.78966221213341, 71.30266472697258, 62.42752656340599, 51.43027067184448, 47.19496473670006, 41.15582339465618, 36.417538449168205, 24.919011555612087, 19.538222886621952, 10.11706542223692, 8.716614469885826, 6.622918741777539, 2.932001044973731, 0.6178626394830644, 0.34113013884052634, 0.05724739414290525, 0.062137379209161736, 0.013177678047213703, 0.06994021227001213, 0.02603338645712938, 0.12205299834022298, 0.03346334968227893, 0.1520539470948279, 0.06549528203322552, 0.008057654104050016, 0.054976210740278475, 0.051784263268928044, 0.05260781712422613, 0.016927507203945424, 0.08061797328991815, 0.12444168227375485, 0.0713494245428592, 0.07021049503237009, 0.02524713665479794, 0.010217031103820773, 0.029088008777762298, 0.040120128614944406, 0.03120323170151096, 0.04935076845868025, 0.05656981702486519, 0.013930242694186745, 0.024181011831387877, 0.04468169849133119, 0.02341345858440036, 0.05062041243945714, 0.05889405285415705, 0.0380974051222438, 0.09617614196031354, 0.03861257435346488, 0.10406430345028639, 0.07751643424853683, 0.010938419054582482, 0.03567550636944361, 0.017735127148625907, 0.0830531156680081, 0.013790395169053227, 0.0203685621090699, 0.08595725827035494, 0.1240505110763479, 0.052603520089178346, 0.08212554981582798, 0.016546097103855573, 0.03046443482162431, 0.020025511767016724, 0.0024974505458885687, 0.015849211158638354, 0.03117439555353485, 0.059433301066746935, 0.03154798898322042, 0.03874435380566865, 0.026368983781139832, 0.042131630834774114, 0.029744995008513797, 0.026457611056684982, 0.03700373177707661, 0.02557617895945441, 0.055104060520534404, 0.025748427724465728, 0.05058924223703798, 0.09220485037076287, 0.04262892914994154, 0.02566792696597986, 0.02270208962727338, 0.04488782629778143, 0.10002563969464973, 0.010176045070693363, 0.03708659998665098, 0.02704097994865151, 0.036722869699588045, 0.05794464559585322, 0.024642297430546023, 0.08617802493972704, 0.04756925038236659, 0.08817651731078513, 0.08634716781671159, 0.008417645822191844, 0.07842650025850162, 0.03686069765535649, 0.06351356962113641, 0.039308252453338355, 0.02618403686938109, 0.04159935881034471, 0.0399678844405571, 0.06032696932379622, 0.05679191213857848, 0.0714049965608865, 0.07441043489961885, 0.03501749968563672, 0.035596616071416065, 0.01521448843050166, 0.04357092235295568, 0.05799184618808795, 0.04095234704436734, 0.013046652802586323, 0.03860582823108416, 0.025710160734888632, 0.0283494438190246, 0.09224006527801976, 0.05137422296684235, 0.07742677538772114, 0.04332312666520011, 0.04985988918633666, 0.09222815380780958, 0.025747585386852734, 0.06481418342445977, 0.027863693321705796, 0.036021002088091336, 0.03181874672009144, 0.05010732864320744, 0.08019407337997109, 0.17012723197694868, 0.03798626479692757, 0.08047221548622474, 0.07261051156092435, 0.08330509706865996, 0.008955180601333268, 0.07040700831566937, 0.04117978191061411, 0.047811246186029166, 0.031001137467683293, 0.020372714425320737, 0.04414443923451472, 0.05837872035044711, 0.10903543865424581, 0.7745257392525673, 1.9795180298388004, 4.209134364500642, 9.088762700557709, 11.161870658397675, 21.540173962712288, 37.01519317924976, 48.22208762168884, 59.74243484437466, 59.66260872781277, 64.6411281824112, 59.3545326590538, 55.85503824055195, 47.714446261525154, 37.697830349206924, 41.44212283194065, 52.48961582779884, 40.853842198848724, 39.388754814863205, 32.8698094189167, 36.61735452711582, 35.40004804730415, 36.39745272696018, 35.49052879214287, 34.619664922356606, 35.88831424713135, 40.334854647517204, 44.121864438056946, 45.112281292676926, 48.41844208538532, 63.75981107354164, 66.79913118481636, 63.89694571495056, 74.50848430395126, 70.19415780901909, 65.36943510174751, 60.71805529296398, 54.96209375560284, 50.98193272948265, 42.407297641038895, 34.45397101342678, 25.283932574093342, 20.798278972506523, 16.329036690294743, 11.093666218221188, 3.8139142468571663, 1.669520689174533, 0.3967340098461136, 0.10451440117321908, 0.07543607556726784, 0.1462277167593129, 0.03840443161607254, 0.11532689168234356, 0.024223308682849165, 0.009317405256297207, 0.02576102939201519, 0.08268990117358044, 0.05900539727008436, 0.026255861921526957, 0.051861910469597206, 0.04562332804198377, 0.09575685078743845, 0.09869019690086134, 0.061813980937586166, 0.04995635725208558, 0.033120826265076175, 0.07584272796520963, 0.05403793940786272, 0.03054040662391344, 0.02770665116258897, 0.04583987931255251, 0.01504306344941142, 0.07440091314492747, 0.03422770241741091, 0.014056844738661312, 0.004295682483643759, 0.026263262989232317, 0.06865785529953428, 0.04506505487370305, 0.0766298126836773, 0.027854362670041155, 0.12655718164751306, 0.06869001997984014, 0.04160424585279543, 0.03431502351304516, 0.03046287631150335, 0.019583844841690734, 0.02764049426332349, 0.03716778723173775, 0.012420477760315407, 0.14465871267020702, 0.03384939634997863, 0.04088559828232974, 0.02833808153809514, 0.06890798875247128, 0.042756726979860105, 0.04897664439340588, 0.022704117545799818, 0.01901146530144615, 0.05553643946768716, 0.06232196989003569, 0.03140473592793569, 0.04703549035184551, 0.06287470663664863, 0.04673616735090036, 0.054957482643658295, 0.025376105222676415, 0.08161273319274187, 0.1677539327647537, 0.1278160125366412, 0.06124502084276173, 0.11376754293451086, 0.13091213389998302, 0.20647783298045397, 0.1735059780185111, 0.14414796663913876, 0.18138399434974417, 0.2646687417291105, 0.09288868750445545, 0.1401559097575955, 0.13930148998042569, 0.13971259526442736, 0.15372254740213975, 0.14081450644880533, 0.18479057092918083, 0.26870204717852175, 0.21605057321721688, 0.10640136359143071, 0.12824004603317007, 0.08896680810721591, 0.07804537774063647, 0.20972339319996536, 0.2148898839368485, 0.14838025672361255, 0.2018676116131246, 0.15205492672976106, 0.12063390066032298, 0.163118997879792, 0.1336316895321943, 0.1507903664605692, 0.1372105928021483, 0.11161633883602917, 0.17467959551140666, 0.1802949668490328, 0.1895302376942709, 0.1949037579470314, 0.10498539777472615, 0.05607565428363159, 0.15041357808513567, 0.13738587324041873, 0.15742167859571055, 0.24202220927691087, 0.19245956878876314, 0.15214830375043675, 0.12756976793752983, 0.26270062546245754, 0.23503634351072833, 0.12833802436944097, 0.15243964124238119, 0.14525863516610116, 0.0900058593833819, 0.30597534554544836, 0.2696711733005941, 0.12879015557700768, 0.15918988996418193, 0.10513943794649094, 0.1403881426085718, 0.0685700740723405, 0.14347890566568822, 0.09752453523105942, 0.08006660951650701, 0.0845853760256432, 0.12477196025429294, 0.1618545563542284, 0.1416450142278336, 0.16329361038515344, 0.31085422437172383, 0.9240378602407873, 2.273119962774217, 7.375527732074261, 9.325804430991411, 17.867891415953636, 34.915114268660545, 50.71876645088196, 69.43288385868073, 73.97337421774864, 79.87436637282372, 80.08661538362503, 66.59141913056374, 70.34117192029953, 63.060610592365265, 67.48171895742416, 83.25680047273636, 68.29360619187355, 67.82752320170403, 58.52336525917053, 59.63937297463417, 58.94095905125141, 62.62755163013935, 64.84757870435715, 66.3927049934864, 64.69631642103195, 67.07430481910706, 70.32134458422661, 69.20038193464279, 63.7221322953701, 68.75437706708908, 81.27412006258965, 82.38305255770683, 94.58785325288773, 79.81984689831734, 74.87573459744453, 66.52005895972252, 55.13831689953804, 50.658771470189095, 39.22516979277134, 32.56995990872383, 21.13965455442667, 15.144175719469786, 11.951241251081228, 6.837151246145368, 2.0383429108187556, 0.9709104825742543, 0.30506820359732956, 0.10173753689741716, 0.21180651267059147, 0.2579002361744642, 0.15489129640627652, 0.25730286666657776, 0.14045447576791048, 0.18995088699739426, 0.08383768450585194, 0.10555898887105286, 0.13093334448058158, 0.10498207295313478, 0.14020486181834713, 0.11962336269789375, 0.20820371224544942, 0.2886840468272567, 0.23476841335650533, 0.14716665231389925, 0.2013203816022724, 0.1328537258086726, 0.2198689230135642, 0.10710979549912736, 0.12337283376837149, 0.12467372958781198, 0.1158816396491602, 0.19049765687668696, 0.14368042844580486, 0.10997041856171563, 0.13057209667749703, 0.22265018080361187, 0.21236107510048896, 0.12389427414746024, 0.15655961469747126, 0.12255330235348083, 0.20723225577967241, 0.18654509709449485, 0.11597743607126176, 0.11581899496377446, 0.11672059306874871, 0.1616292996914126, 0.10550367660471238, 0.13950546184787527, 0.14114214980509132, 0.3077920340001583, 0.07058763963868842, 0.16774294897913933, 0.07431512829498388, 0.14008878992171958, 0.12489388027461246, 0.13538275728933513, 0.12314376246649772, 0.09018035314511508, 0.17060400248738006, 0.1752351672621444, 0.11814101919298992, 0.15128772414755076, 0.1403693069005385, 0.24421296984655783, 0.11287817542324774, 0.1181872772576753], [0.017083007551264018, 0.00409176766879682, 0.014074894697841955, 0.05513476688065566, 0.015349152981798397, 0.05625342462735716, 0.01796014632418519, 0.02376326432568021, 0.03658973211713601, 0.012641827015613671, 0.05872574860404711, 0.039904957739054225, 0.04012297846202273, 0.04577087071083952, 0.023414221141138114, 0.0586166194989346, 0.033418323582736775, 0.050537262213765644, 0.03532989190716762, 0.04659710742998868, 0.061630655618500896, 0.029824530975020025, 0.05375696600822266, 0.043300357574480586, 0.06865408518933691, 0.007027916317383642, 0.03996677121904213, 0.017146095669886563, 0.025646451067586895, 0.032328390661859885, 0.02181845706218155, 0.020655780681408942, 0.025854773775790818, 0.06171813256514724, 0.042539170099189505, 0.05640898620185908, 0.03815200863755308, 0.005597488825515029, 0.044532667816383764, 0.03167174210830126, 0.01367453385682893, 0.06561033718753606, 0.07371576240984723, 0.025346254187752493, 0.09748595839482732, 0.047995269123930484, 0.01731152780848788, 0.009121414259425364, 0.03074266413022997, 0.04288446914870292, 0.045184481277829036, 0.02777640191197861, 0.028107505531806964, 0.0298905338786426, 0.06054886405763682, 0.050238744443049654, 0.05193150165723637, 0.07857072181650437, 0.014236821116355713, 0.025966873326979112, 0.057439009251538664, 0.05298240874253679, 0.03567193663911894, 0.08347864088136703, 0.013939667969680158, 0.029925481612735894, 0.09023853010148741, 0.04152706249442417, 0.05408855387941003, 0.08425591440754943, 0.043549047550186515, 0.03268823209509719, 0.2002755118883215, 0.18407850991934538, 0.12996540579479188, 0.16793854942079633, 0.6969187036156654, 4.517710106447339, 11.856735572218895, 20.66737599670887, 35.99081754684448, 44.2864678055048, 44.76154871284962, 51.18318893015385, 54.47462931275368, 50.46293377876282, 56.029300689697266, 54.761175736784935, 59.27253685891628, 59.42267060279846, 62.49357461929321, 59.807449355721474, 56.07277795672417, 60.26817463338375, 57.18113288283348, 53.626841604709625, 46.12458877265453, 51.8776548653841, 50.79180233180523, 49.49457474052906, 43.75359959900379, 36.6005290299654, 27.491053640842438, 12.968940641731024, 7.055617198348045, 5.5212989542633295, 3.3495881874114275, 0.7170022884383798, 0.1574205356882885, 0.19037069025216624, 0.16674112383043393, 0.05576129537075758, 0.16770737041952088, 0.01168898825198994, 0.07288527689524926, 0.03448532414040528, 0.020729030657093972, 0.05165573442354798, 0.0564242076507071, 0.06131391812232323, 0.010466939129400998, 0.0347933302691672, 0.029682793756364845, 0.011630256540229311, 0.1472404069500044, 0.03134969825623557, 0.06976111719268374, 0.06352577052894048, 0.056162274049711414, 0.07185352835222147, 0.06369549970258959, 0.04301441178540699, 0.03697224616189487, 0.058536378492135555, 0.030844290122331586, 0.013757769429503242, 0.06178550102049485, 0.04673687981266994, 0.007546459073637379, 0.03356512781465426, 0.040479205636074767, 0.05764720022852998, 0.04064575841766782, 0.06846399148344062, 0.026100905197381508, 0.05469651754538063, 0.03178716462571174, 0.034550302880234085, 0.07864742277888581, 0.09265670698368922, 0.10639708139933646, 0.10065876587759703, 0.015742846553621348, 0.07116990644135512, 0.04638373255147599, 0.01279238651477499, 0.022553574744961224, 0.03680481393530499, 0.055772995328879915, 0.03635451212176122, 0.020237791977706365, 0.08876478808815591, 0.035521967147360556, 0.0318357307696715, 0.04046437381475698, 0.074179077782901, 0.03847568150376901, 0.025200036252499558, 0.03257262404076755, 0.045480108383344486, 0.04318755854910705, 0.03274911789048929, 0.03135838509479072, 0.10624485206790268, 0.04805808450328186, 0.06020162800268736, 0.034474919229978696, 0.009766264520294499, 0.02842837493517436, 0.10318129614461213, 0.03158006089506671, 0.05374715110519901, 0.05358716633054428, 0.06402841230737977, 0.06742282508639619, 0.019358276476850733, 0.025858395456452854, 0.05245231863227673, 0.02202543277235236, 0.03354752036102582, 0.04424731945618987, 0.022994889150140807, 0.07983824325492606, 0.04646095672796946, 0.055704773403704166, 0.003287413405814732, 0.060001303791068494, 0.02924268348579062, 0.06327867988147773, 0.027283755007374566, 0.018656924657989293, 0.02194806202169275, 0.047416638844879344, 0.030413924250751734, 0.035384658694965765, 0.03789630536630284, 0.05826024018460885, 0.0359348721394781, 0.035019202914554626, 0.032237180712400004, 0.03374575171619654, 0.013265724592201877, 0.036799689405597746, 0.06292669408139773, 0.033672216013656, 0.05113944454933517, 0.04000650209491141, 0.09111286912229843, 0.0860951493086759, 0.04581537730700802, 0.04005527604022063, 0.04429151435033418, 0.03759880804864224, 0.09754624305060133, 0.05472063734487165, 0.024514416109013837, 0.050410559051670134, 0.07497964732465334, 0.021445514867082238, 0.01965681280125864, 0.04135789735300932, 0.04573270205582958, 0.031862648465903476, 0.08471262466628104, 0.054414289916167036, 0.029243778153613675, 0.03723112582520116, 0.04282280038751196, 0.01094294337235624, 0.05525080909137614, 0.03844427381409332, 0.023962556952028535, 0.022982651134952903, 0.0789071447798051, 0.043575683230301365, 0.19911841460270807, 0.00527095869074401, 0.1413730764761567, 0.20022252254420891, 0.250593614182435, 0.20870381587883458, 1.1157942144200206, 4.04922042042017, 11.73827787861228, 22.76308324187994, 34.73784998059273, 53.31332802772522, 56.457921490073204, 55.28829865157604, 61.242791935801506, 63.736240938305855, 61.79986484348774, 66.50201752781868, 66.0629814863205, 69.15634989738464, 69.76142182946205, 67.98859655857086, 65.83924189209938, 67.52356231212616, 71.55192375183105, 66.16116061806679, 66.2331135571003, 59.38464604318142, 62.58306361734867, 60.505050122737885, 61.13553129136562, 57.56998121738434, 49.27682362496853, 40.66251486539841, 27.610770016908646, 16.126245371997356, 12.45045941323042, 8.733506463468075, 4.094606610015035, 1.6546695423312485, 1.0635002329945564, 0.34000234154518694, 0.21312403259798884, 0.3195778437657282, 0.07481146181817167, 0.04733290603326168, 0.033740975995897315, 0.038352908013621345, 0.02230022964795353, 0.09974113738280721, 0.044316877247183584, 0.017222149108420126, 0.03215593780623749, 0.015638563672837336, 0.04878028325038031, 0.01995738632103894, 0.012363019759504823, 0.018018172995653003, 0.0392180110065965, 0.02391443238593638, 0.0240760127780959, 0.06994211216806434, 0.0021055126171631855, 0.0338866744277766, 0.015689113206462935, 0.010481232893653214, 0.03393478044017684, 0.015439600374520523, 0.06978844307013787, 0.0064044584632938495, 0.03690946788992733, 0.02161717176932143, 0.021116704483574722, 0.054052069899626076, 0.0753024518780876, 0.020586042919603642, 0.04838827713683713, 0.029325785471883137, 0.05810378061141819, 0.008448413409496425, 0.05623804732749704, 0.016293449625663925, 0.06154735696327407, 0.080320112319896, 0.07727439762675203, 0.007988048073457321, 0.034730002807918936, 0.022761346408515237, 0.05492556287208572, 0.013264606732263928, 0.03894788780598901, 0.021309623916749842, 0.03745911359146703, 0.01770796825439902, 0.05816305223561358, 0.0258197425500839, 0.04701688470959198, 0.05361275187169667, 0.048706606539781205, 0.030554032455256674, 0.020000006006739568, 0.023770657971908804, 0.049008133719326, 0.06329252835712396, 0.04065524677571375, 0.07112794541171752, 0.054616606794297695, 0.13027185341343284, 0.05709689030481968, 0.07903293138951994, 0.16372217098250985, 0.10684208798920736, 0.09846453205682337, 0.18255274335388094, 0.20550784596707672, 0.23444550490239635, 0.09972557454602793, 0.23920713923871517, 0.12467430846299976, 0.10681542262318544, 0.10662745145964436, 0.12497232528403401, 0.16682329442119226, 0.11882669685292058, 0.14741245162440464, 0.18955072097014636, 0.13294959644554183, 0.20386841206345707, 0.10431496382807381, 0.1586353126913309, 0.11827198599348776, 0.13649320317199454, 0.1325356710003689, 0.14196479081874713, 0.09694702559500001, 0.10842757517821155, 0.17986152291996405, 0.16204079089220613, 0.1267092625494115, 0.18613290827488527, 0.13545217778300866, 0.10536841276916675, 0.14823172328760847, 0.2407107304316014, 0.10856557753868401, 0.13843022345099598, 0.11877776705659926, 0.13906643696827814, 0.1797747064847499, 0.21986460371408612, 0.15237155661452562, 0.2568337105913088, 0.15977539995219558, 0.15475186170078814, 0.12870127597125247, 0.14402365690330043, 0.19632366456789896, 0.14447436318732798, 0.19596422760514542, 0.07964128468302079, 0.0894383093691431, 0.263611210975796, 0.20882598822936416, 0.2443477141787298, 0.15408382489113137, 0.13577728299424052, 0.12738782301312312, 0.13151178922271356, 0.15103327139513567, 0.08621270550065674, 0.17762246337952092, 0.1028489698364865, 0.09234432960511185, 0.16494876297656447, 0.15324954700190574, 0.13347488857107237, 0.3017220081528649, 0.1133915338141378, 0.19819642970105633, 0.31174768111668527, 0.3148953669006005, 0.28133889252785593, 0.46805965597741306, 2.0592966489493847, 6.518136989325285, 16.057902239263058, 29.452147409319878, 48.87275330722332, 59.593714624643326, 61.715627163648605, 73.11380714178085, 73.46621543169022, 70.58266416192055, 79.29091528058052, 77.46812269091606, 78.31775709986687, 81.16109892725945, 82.61544808745384, 80.52880525588989, 76.79352208971977, 80.82325905561447, 76.5692201256752, 74.4975408911705, 64.79985326528549, 69.27552670240402, 67.59146466851234, 71.20027542114258, 62.219848707318306, 49.55311059951782, 37.578121572732925, 24.286632388830185, 12.982944790273905, 8.26989809051156, 5.289818225428462, 2.166934898123145, 0.581451568286866, 0.47136016481090337, 0.19289601099444553, 0.1158532896079123, 0.3646841843146831, 0.22159511398058385, 0.11721633287379518, 0.1398058090126142, 0.2500112063717097, 0.08394155549467541, 0.25030750141013414, 0.18278746982105076, 0.11820543761132285, 0.32278027036227286, 0.10813483502715826, 0.11467181277112104, 0.24965874559711665, 0.15603070089127868, 0.1403739082161337, 0.1996681233868003, 0.1523820505826734, 0.18698637810302898, 0.12662108056247234, 0.12545932258944958, 0.11171091813594103, 0.15198804438114166, 0.1232324936427176, 0.14234031754313037, 0.1791856490308419, 0.10711162118241191, 0.11096165326307528, 0.15206748386844993, 0.1397182504297234, 0.15594361728290096, 0.100710693950532, 0.21275140024954453, 0.07552911862148903, 0.18209675297839567, 0.1455360944964923, 0.20437650120584294, 0.21462207252625376, 0.2323934665764682, 0.17659451463259757, 0.19424621510552242, 0.13869549671653658, 0.1646739902207628, 0.13723061594646424, 0.0897123473987449, 0.1349139426019974, 0.13773361395578831, 0.11263451349805109, 0.14116005040705204, 0.14961980661610141, 0.2422755042789504, 0.05807643618027214, 0.15602785104420036, 0.18205130385467783, 0.1537136861588806, 0.1817538362229243, 0.17500440386356786, 0.0842990554519929, 0.10534890170674771, 0.14588987629394978, 0.12698790931608528, 0.2125773814623244, 0.20343240030342713, 0.12354807709925808, 0.18243674567202106], [0.036108445638092235, 0.04896129677945282, 0.02911708055762574, 0.02101555532135535, 0.026752193589345552, 0.01189177639389527, 0.034173874446423724, 0.013900818394176895, 0.03235125994251575, 0.02521024078305345, 0.055768486781744286, 0.026018762437161058, 0.03991670593677554, 0.03785965440329164, 0.1019839670334477, 0.018452438853273634, 0.007564137495137402, 0.004538587882052525, 0.06950342867639847, 0.017941080550372135, 0.04458682604308706, 0.025029010175785515, 0.014042237417015713, 0.02513608353183372, 0.012451104339561425, 0.04719911165011581, 0.05724733477109112, 0.02123636095348047, 0.017806221185310278, 0.042699956393335015, 0.03347449302964378, 0.031441279279533774, 0.06939781364053488, 0.02365204978559632, 0.045052750065224245, 0.017341530983685516, 0.017855989608506206, 0.005756714290328091, 0.05462307461129967, 0.020931009858031757, 0.03376492139068432, 0.028464931274356786, 0.08387170455534942, 0.05416805644927081, 0.08190735097741708, 0.05071080973721109, 0.04177428301773034, 0.04755754671350587, 0.010297517019353108, 0.01644359352212632, 0.09072679647943005, 0.017415810689271893, 0.010270898965245578, 0.07664662975003012, 0.09542595682432875, 0.010127700643352, 0.025966351968236268, 0.0373691541608423, 0.0417595959152095, 0.02807419979944825, 0.06037533879862167, 0.03280515746155288, 0.04916433725156821, 0.03515172822517343, 0.08270436563179828, 0.055100939789554104, 0.10904974726145156, 0.06218051283212844, 0.0569648919190513, 0.11674414883600548, 0.082126121269539, 0.050774296760209836, 0.0093516006381833, 0.08775672889896668, 0.08810838815406896, 0.07610569315147586, 0.031179750149021856, 0.10910215773037635, 0.12336514511844143, 0.05449636773846578, 0.32812011195346713, 0.9280525229405612, 2.376382271759212, 3.895775629207492, 9.297787584364414, 9.193400535732508, 10.032883789390326, 11.363071762025356, 8.16794291138649, 9.486925285309553, 9.162781778723001, 10.31109631061554, 7.3696565721184015, 6.556638898327947, 6.248098304495215, 4.089027559384704, 4.581804592162371, 4.432798912748694, 3.47311575897038, 2.121580531820655, 1.4018301595933735, 0.42771066015120596, 0.12103783679776825, 0.18722252949373797, 0.18929503625258803, 0.06967900597373955, 0.12116532292566262, 0.19463891512714326, 0.0349723993713269, 0.08873479790054262, 0.035225260216975585, 0.01471774208766874, 0.007475359934687731, 0.04123487524338998, 0.024162465560948476, 0.06277479871641845, 0.0401260175567586, 0.012370809527055826, 0.04656604112824425, 0.008421569000347517, 0.07233790587633848, 0.05170500560780056, 0.04885964110144414, 0.06408721266780049, 0.05586938546912279, 0.07249530797707848, 0.04089219968591351, 0.03386490723642055, 0.056076047621900216, 0.0676613810355775, 0.02238507011497859, 0.014382869285327615, 0.07776937301969156, 0.029913924518041313, 0.029952074619359337, 0.03272908361395821, 0.07712410530075431, 0.06172664499899838, 0.003412447663322382, 0.0457002293842379, 0.07483384499209933, 0.04429184831678867, 0.019662087615870405, 0.07808550566551276, 0.014519416108669247, 0.07303757301997393, 0.044885789102409035, 0.0051292608986841515, 0.0339298748440342, 0.08359293904504739, 0.047483647358603776, 0.029528235936595593, 0.01985365634027403, 0.019742978001886513, 0.03029554613021901, 0.04206607321975753, 0.044218602051842026, 0.04978599725291133, 0.13620535377413034, 0.046428751229541376, 0.021060243743704632, 0.05475163685332518, 0.057580611028242856, 0.01205727439810289, 0.05922449039644562, 0.00305582761484402, 0.028932920322404243, 0.0030587486617150716, 0.02435387472360162, 0.007319439810089534, 0.05717599211493507, 0.025218172486347612, 0.013404725141299423, 0.053709023268311284, 0.04790024453541264, 0.04614913967088796, 0.045513972581829876, 0.03562556354154367, 0.05253920557152014, 0.022001203506079037, 0.03167485170706641, 0.08363070694031194, 0.04404628649353981, 0.007135856130844331, 0.014521235298161628, 0.0777901679975912, 0.07290869907592423, 0.03947630808397662, 0.09632165485527366, 0.01921551509440178, 0.08341173626831733, 0.07348419749177992, 0.006270754529396072, 0.037341342176659964, 0.05459136635181494, 0.04769974962982815, 0.042473048451938666, 0.02914358821726637, 0.037108868127688766, 0.01902191659610253, 0.023332712917181198, 0.045625517377629876, 0.04463885801669676, 0.05756714104791172, 0.06793524837121367, 0.03878929084748961, 0.07798152335453779, 0.08144562380039133, 0.02494514934369363, 0.021663875122612808, 0.03711233766807709, 0.03502054249111097, 0.026422795053804293, 0.014280175528256223, 0.006543953004438663, 0.01667973934672773, 0.049650451401248574, 0.021436191636894364, 0.09086957827094011, 0.05180219726753421, 0.08238592490670271, 0.052040575101273134, 0.037680715176975355, 0.01975851115275873, 0.0274736390565522, 0.014874233202135656, 0.04896056205325294, 0.009492335957475007, 0.012012486713501858, 0.01517958429758437, 0.14487132313661277, 0.024319327749253716, 0.0583152704348322, 0.0346117823937675, 0.03626560283009894, 0.05064508513896726, 0.06654439683188684, 0.08498128212522715, 0.049170823622262105, 0.0101547899612342, 0.019998614479845855, 0.01095631780117401, 0.0862449147098232, 0.07670079910894856, 0.052640608919318765, 0.023332740747719072, 0.05214502496528439, 0.02899429964600131, 0.08901618319214322, 0.00779155890995753, 0.03872195207804907, 0.04176645335974172, 0.035977497391286306, 0.05613374218228273, 0.21223572635790333, 0.19961550511652604, 1.1926175421103835, 4.137388039380312, 8.606459330767393, 11.637395191937685, 19.159662500023842, 18.79199042916298, 19.962485320866108, 22.145920358598232, 19.237413927912712, 20.997509881854057, 21.55227441340685, 22.102274000644684, 17.102745473384857, 15.258714873343706, 14.482365231961012, 11.262562405318022, 10.523049887269735, 10.71683568879962, 9.856139123439789, 7.7179772313684225, 4.745830865576863, 2.0720922248438, 0.6875120115000755, 0.21490947663551196, 0.08441848927759565, 0.0593409519206034, 0.0596993795625167, 0.19053037074627355, 0.16356847219867632, 0.07387320903944783, 0.05276622483506799, 0.022357864836521912, 0.13623750361148268, 0.07483466135454364, 0.03228025867429096, 0.012414949687808985, 0.07673144980799407, 0.04235600063111633, 0.10532410655287094, 0.029495922826754395, 0.042436412331881, 0.05716399900848046, 0.10258030495606363, 0.08092106640106067, 0.029684077671845444, 0.01797932527551893, 0.01024001356199733, 0.0578701970516704, 0.017522230955364648, 0.022976201871642843, 0.06627144233789295, 0.06174867936351802, 0.026358695758972317, 0.04974975447112229, 0.040233495383290574, 0.06267073476919904, 0.05508298352651764, 0.01615790377400117, 0.022474818033515476, 0.03203795487934258, 0.07255395990796387, 0.021333279873942956, 0.029220617579994723, 0.041313145848107524, 0.04793125146534294, 0.09368550920044072, 0.008127774071908789, 0.06405032792827114, 0.02476688547176309, 0.02583278950623935, 0.14713980141095817, 0.04123018115933519, 0.07992104467120953, 0.027437978860689327, 0.021625667504849844, 0.027972206444246694, 0.060141194917378016, 0.06770964289898984, 0.09371388150611892, 0.029790611115458887, 0.04951365503075067, 0.059500031275092624, 0.08207144725020044, 0.043222643580520526, 0.08721323931240477, 0.03325797515572049, 0.04697080476034898, 0.04045290392241441, 0.019403642108954955, 0.04863890782871749, 0.06511000348837115, 0.029565361874119844, 0.07494133766158484, 0.015375459333881736, 0.016001058284018654, 0.016841577635204885, 0.1565986219793558, 0.19080330297583714, 0.08690256887348369, 0.1149449528020341, 0.09814448087126948, 0.17127117840573192, 0.13527012895792723, 0.1222554562264122, 0.1762258750386536, 0.17530157463625073, 0.13319364428753033, 0.12385802765493281, 0.20713230333058164, 0.14839269511867315, 0.18403504975140095, 0.09284025494707748, 0.13290441449498758, 0.134797262144275, 0.2680807211436331, 0.10041573477792554, 0.17198182933498174, 0.10702061161282472, 0.12137762169004418, 0.09796937112696469, 0.08191868357243948, 0.082728685811162, 0.1030029432149604, 0.15944134443998337, 0.16258667019428685, 0.1998164935503155, 0.11036587195121683, 0.12347957686870359, 0.14636784908361733, 0.1497381494846195, 0.11206563503947109, 0.22010507440427318, 0.10758741947938688, 0.23733052978059277, 0.14202819991623983, 0.1126045901037287, 0.0909814570331946, 0.09289199006161653, 0.25856582389678806, 0.14327886718092486, 0.19325909932376817, 0.18929183017462492, 0.09926525744958781, 0.10590657373541035, 0.09186943672830239, 0.10453553011757322, 0.24750316282734275, 0.10213350979029201, 0.10228839601040818, 0.2085231474484317, 0.26027142768725753, 0.09814069591811858, 0.10779510950669646, 0.1018262532306835, 0.15528407064266503, 0.2216121685341932, 0.2776592056034133, 0.1633041785680689, 0.12210185392177664, 0.11864682994200848, 0.14573371357982978, 0.13234220794402063, 0.2068537604645826, 0.18083069357089698, 0.1672733624582179, 0.18016412621363997, 0.1818258097046055, 0.17182774463435635, 0.16079154855106026, 0.193428709753789, 0.1505883241770789, 0.09898981676087715, 0.1042412240349222, 0.2489709825022146, 0.29378827137406915, 0.20799699443159625, 0.5147097527515143, 1.5683720167726278, 4.993123495951295, 7.6688529923558235, 13.190653994679451, 14.208688717335463, 14.87737588584423, 17.272324673831463, 13.570517711341381, 15.282896775752306, 15.385036244988441, 15.558693576604128, 11.877016983926296, 9.848174750804901, 9.227565452456474, 7.2484231274574995, 7.351587591692805, 7.557022143155336, 6.4914818946272135, 4.780277917161584, 2.947031850926578, 0.9557328501250595, 0.3628850699169561, 0.18771498900605366, 0.20298867020756006, 0.38717063551303, 0.24572310678195208, 0.31757012649904937, 0.3254586219554767, 0.27111135539598763, 0.11464433846413158, 0.09562304156133905, 0.22483228793134913, 0.30962193268351257, 0.12045816009049304, 0.12857116264058277, 0.14474796334980056, 0.12897202628664672, 0.16597684531006962, 0.11816500540589914, 0.15382977289846167, 0.1332367185386829, 0.1782621056190692, 0.18854239460779354, 0.10170618115807883, 0.10205366954323836, 0.09129862126428634, 0.1680713938549161, 0.1318837536382489, 0.1461620960617438, 0.18460641440469772, 0.1447437034221366, 0.1268385595176369, 0.15167417528573424, 0.10429969042888843, 0.10175540781347081, 0.18859011470340192, 0.1366793634952046, 0.13024374085944146, 0.07997726235771552, 0.18015211826423183, 0.1264081138651818, 0.09603593542124145, 0.1495827140752226, 0.1637279597343877, 0.2080807532183826, 0.08329522650456056, 0.09409604303073138, 0.10651468954165466, 0.15422921162098646, 0.2162180165760219, 0.1201631489675492, 0.17120255943154916, 0.12354099701042287, 0.16318401001626626, 0.1294200905249454, 0.15407094120746478, 0.14784938364755362, 0.2801866043591872, 0.1037591694330331, 0.12336857384070754, 0.15461306524230167, 0.3211018885485828, 0.16210412577493116, 0.191723536408972, 0.16997629398247227, 0.11915341994608752, 0.14309362712083384, 0.10455364594236016, 0.10827675592736341, 0.18670180899789557, 0.10133319257874973, 0.19807345583103597, 0.19853072270052508, 0.08416767304879613, 0.1400405800086446], [0.044686444525723346, 0.023064702982082963, 0.024170948308892548, 0.025804929282458033, 0.02310966043296503, 0.04546556228888221, 0.011126393001177348, 0.01733650849928381, 0.03788116926443763, 0.02149883261154173, 0.05753106153861154, 0.04603216235409491, 0.04134200054977555, 0.002565238546594628, 0.04448538187716622, 0.054295089867082424, 0.003822306603069592, 0.03456097125308588, 0.05307809013174847, 0.031998943886719644, 0.027542955649551004, 0.06600938257179223, 0.021828746939718258, 0.022625112214882392, 0.04529887963144574, 0.024767859540588688, 0.01071105840310338, 0.024308607426064555, 0.017379408345732372, 0.022137404303066432, 0.06299055588897318, 0.027029114862671122, 0.029141870145394932, 0.03792593190155458, 0.01731170963466866, 0.02820357469317969, 0.07029418702586554, 0.006402699573300197, 0.04824589239433408, 0.010452063706907211, 0.06691362272249535, 0.03182225707860198, 0.03178695682436228, 0.051256184378871694, 0.04668387191486545, 0.05854011520568747, 0.036033852375112474, 0.02926855846453691, 0.03279078577179462, 0.06141936617495958, 0.030858596874168143, 0.01017025353576173, 0.04727258055936545, 0.040427518761134706, 0.04369296111690346, 0.022955423592065927, 0.09222687731380574, 0.04305897775338963, 0.09697006185888313, 0.06322275163256563, 0.017718519738991745, 0.02195918124925811, 0.07718867957009934, 0.07475370046449825, 0.024592805457359646, 0.03258948192524258, 0.03023080302227754, 0.04285797076590825, 0.04097278950212058, 0.052649822682724334, 0.036211314727552235, 0.02570539429143537, 0.09108080092119053, 0.04488917700655293, 0.01765590288414387, 0.02834277747751912, 0.03732800207217224, 0.03093052397161955, 0.025782635166251566, 0.040773418950266205, 0.08225408237194642, 0.022037795097276103, 0.047626139712519944, 0.05795098353701178, 0.23174147499958053, 0.279694827622734, 0.1535170615534298, 0.10900668043177575, 0.015577451522403862, 0.034248122610733844, 0.07762763765640557, 0.10333942555007525, 0.12446150503819808, 0.11699216716806404, 0.0726745069550816, 0.08288251076010056, 0.1488794549368322, 0.1573877624468878, 0.12136811477830634, 0.054166950649232604, 0.07265247259056196, 0.04530705067736562, 0.06442298254114576, 0.09822792795603164, 0.04980858451745007, 0.028597727468877565, 0.012495027422119165, 0.016578543800278567, 0.07478251805878244, 0.02223274059360847, 0.08959561499068514, 0.08835789078148082, 0.0687773633399047, 0.02991637546074344, 0.051696864247787744, 0.01693661335593788, 0.03918584261555225, 0.08958202626672573, 0.045486234812415205, 0.03398298293177504, 0.02866254850232508, 0.07137293578125536, 0.08838858600938693, 0.029100246792950202, 0.07524213011492975, 0.030471858153759968, 0.0876209455600474, 0.038265186158241704, 0.02255237803183263, 0.06587419295101427, 0.005632837319353712, 0.08040322543820366, 0.03935554210329428, 0.021525013726204634, 0.06537585562909953, 0.027506122860359028, 0.011196178074897034, 0.01169764633232262, 0.0859734222467523, 0.09165097813820466, 0.03333609362016432, 0.04235281310684513, 0.019225125906814355, 0.028508983305073343, 0.02282949411892332, 0.01723334255075315, 0.005173711833776906, 0.04743132594740018, 0.03939183312468231, 0.028425330274330918, 0.07326211722102016, 0.07892132722190581, 0.02358220997848548, 0.013385858819674468, 0.01948986482602777, 0.04585627335472964, 0.04238280700519681, 0.023785070479789283, 0.054615872068097815, 0.01912284868012648, 0.0347288821649272, 0.05954155814833939, 0.021048495545983315, 0.07834234071196988, 0.05473230019561015, 0.019998514289909508, 0.05197764839977026, 0.031343942901003174, 0.06914594356203452, 0.05309594620484859, 0.033386648719897494, 0.06252625345950946, 0.006756490183761343, 0.045967940604896285, 0.03928301943233237, 0.027176789262739476, 0.06222717907803599, 0.043749805918196216, 0.05791317111288663, 0.05781607222161256, 0.03678105407743715, 0.06715739596984349, 0.017048898444045335, 0.06102064362494275, 0.03924719967471901, 0.040915269346442074, 0.020994869810238015, 0.031354789389297366, 0.0030250045983848395, 0.08740122531889938, 0.024207584428950213, 0.02559712051152019, 0.03299729578429833, 0.0626882717187982, 0.018120915920007974, 0.0407847292808583, 0.023765496334817726, 0.04541355257970281, 0.002727489654716919, 0.05184269255551044, 0.011413779484428233, 0.0315102581953397, 0.025962561448977794, 0.04230010948958807, 0.022235503238334786, 0.03428469935897738, 0.026727578406280372, 0.04347366761066951, 0.04272950871381909, 0.07729905177257024, 0.025754641355888452, 0.016590169543633237, 0.031972642173059285, 0.06210101768374443, 0.015416662445204565, 0.018747687463473994, 0.05213314318098128, 0.02088119876134442, 0.03723547109984793, 0.013369229145610007, 0.02697408461244777, 0.050329531368333846, 0.024441887871944346, 0.04326130205299705, 0.017808926313591655, 0.1457378250779584, 0.034611055089044385, 0.01813505939935567, 0.014461606515396852, 0.06681683182250708, 0.018227364016638603, 0.045707350291195326, 0.049190494246431626, 0.036458639151533134, 0.039788741123629734, 0.010903918464464368, 0.010085592111863662, 0.019423424055275973, 0.039587192368344404, 0.03313307912321761, 0.02290553271450335, 0.028062472010788042, 0.07080727082211524, 0.059279836059431545, 0.0886387046193704, 0.01955484171048738, 0.060672223844449036, 0.01633095776924165, 0.011082164710387588, 0.04405835752550047, 0.024472494042129256, 0.0615412194019882, 0.06597525120014325, 0.05939645714533981, 0.021746312886534724, 0.03547259206243325, 0.06445755177992396, 0.03569679116480984, 0.06669851863989606, 0.0789996534876991, 0.08093377939076163, 0.22546257911017165, 0.10044150956673548, 0.14023104478837922, 0.13393240777077153, 0.11611566107603721, 0.10299148445483297, 0.07678534457227215, 0.2061149079236202, 0.12155580392573029, 0.04337588223279454, 0.06780429641366936, 0.09316816547652707, 0.10421699291327968, 0.20142307999776676, 0.2029003991628997, 0.05570762325078249, 0.03875537840940524, 0.11791685348725878, 0.01736452086333884, 0.030900967940397095, 0.040597069819341414, 0.021869125339435413, 0.033179674865095876, 0.05308047613652889, 0.07658955117221922, 0.09476904480834492, 0.02739975825534202, 0.04866109804424923, 0.019579531108320225, 0.09618562660762109, 0.022660748290945776, 0.022563046404684428, 0.07418975728796795, 0.048663376437616535, 0.004371852346594096, 0.026169707853114232, 0.03362859999469947, 0.04109855755814351, 0.041362617412232794, 0.0632066470279824, 0.04573021586111281, 0.019528521443135105, 0.046426213084487244, 0.020220429432811216, 0.0750470046477858, 0.009030139372043777, 0.035166010857210495, 0.06989266286836937, 0.03017419014213374, 0.020299221396271605, 0.006575689558303566, 0.0722257376764901, 0.06317049701465294, 0.05269906789180823, 0.050825237776734866, 0.04603541296091862, 0.020075194843229838, 0.028590599140443373, 0.03660079753899481, 0.05928886057517957, 0.022737271137884818, 0.020837120755459182, 0.015149311166169355, 0.03031762873433763, 0.08155287156114355, 0.046222623423091136, 0.10808416118379682, 0.030129097249300685, 0.021972350659780204, 0.012266377289051889, 0.011147995064675342, 0.09958691167412326, 0.03707065123307984, 0.003146973322145641, 0.02605982546810992, 0.020017641290905885, 0.021047267291578464, 0.07437602893332951, 0.0360916545469081, 0.04220542628900148, 0.05162905050383415, 0.04270639823516831, 0.0213137057289714, 0.009104563796427101, 0.0765454676002264, 0.020514887655735947, 0.098270119051449, 0.015247103037836496, 0.05880129181605298, 0.005668177464031032, 0.013237112943897955, 0.1953143734135665, 0.09183305664919317, 0.09054201655089855, 0.12633945036213845, 0.1564857710036449, 0.10346490787924267, 0.11148816993227229, 0.1410391100216657, 0.14402258821064606, 0.07969399201101623, 0.07808920156094246, 0.10959105493384413, 0.11490348158986308, 0.15727737540146336, 0.31541065487544984, 0.16280489129712805, 0.09071347492863424, 0.15645121660782024, 0.10672133314074017, 0.13205008377553895, 0.0708288153691683, 0.14208031352609396, 0.13154122279956937, 0.15332469687564299, 0.09812131844228134, 0.15393082372611389, 0.12025072239339352, 0.06769100014935248, 0.12095670521375723, 0.10300319554517046, 0.14428275550017133, 0.14144426328130066, 0.21663770108716562, 0.14853965520160273, 0.08777797658694908, 0.12692150194197893, 0.13766184827545658, 0.10744132028776221, 0.1399080769624561, 0.14823702222201973, 0.1297726106713526, 0.13201741443481296, 0.09117574387346394, 0.13093919260427356, 0.09676482091890648, 0.12330894227488898, 0.0953941854822915, 0.17357761011226103, 0.10092655502376147, 0.19112929876428097, 0.12336078871157952, 0.1856072450755164, 0.12114456505514681, 0.21171369968215004, 0.1328837382607162, 0.10079965519253165, 0.14863545162370428, 0.07480832995497622, 0.17261780536500737, 0.12895929103251547, 0.20186551875667647, 0.144525304203853, 0.09221089145285077, 0.19250023848144338, 0.10027366544818506, 0.12438360921805725, 0.14606773940613493, 0.14791108580539003, 0.17645922111114487, 0.1325885861297138, 0.11677839152980596, 0.193335184303578, 0.16666116483975202, 0.2967396145686507, 0.1793756239931099, 0.15344583021942526, 0.16016536887036636, 0.09428249279153533, 0.11842253807117231, 0.09604642196791247, 0.15294096199795604, 0.08530629085726105, 0.12013199360808358, 0.19882795284502208, 0.33628545817919075, 0.4943532060133293, 0.27523909171577543, 0.41971802653279155, 0.19926883309381083, 0.10015922627644613, 0.16253366600722075, 0.15944216080242768, 0.2097530642640777, 0.2053050763788633, 0.11830885589006357, 0.1634196419036016, 0.3142158268019557, 0.27919580752495676, 0.2983620681334287, 0.2021380650694482, 0.3698610799619928, 0.1330198481446132, 0.18096907442668453, 0.26168551587034017, 0.1764157015713863, 0.09905647646519355, 0.15392184373922646, 0.16696525242878124, 0.14912374026607722, 0.25077481695916504, 0.19724541198229417, 0.22521214879816398, 0.13490613520843908, 0.09781560554984026, 0.21956954064080492, 0.11998561240034178, 0.17670160654233769, 0.29994584096129984, 0.14589609549148008, 0.12834765744628385, 0.1235956116579473, 0.14931485813576728, 0.2192171837668866, 0.20519133482594043, 0.19581363099860027, 0.1534311060095206, 0.19233889557654038, 0.1412818962126039, 0.10205012949882075, 0.15384770318632945, 0.1445979456184432, 0.11162865106598474, 0.12257677648449317, 0.12342348534730263, 0.12835721630835906, 0.1685759355314076, 0.13352851616218686, 0.16231394576607272, 0.18898898939369246, 0.21909490751568228, 0.1544529988314025, 0.1345841767033562, 0.08146304200636223, 0.11283007683232427, 0.13831456715706736, 0.14361457026097924, 0.09719707741169259, 0.14566426340024918, 0.11274916047113948, 0.18356345943175256, 0.1122088472766336, 0.16336637054337189, 0.15160151902819052, 0.09513547280221246, 0.08158480617566966, 0.1593654227326624, 0.20558942283969373, 0.08860689616994932, 0.1076102998922579, 0.14615883061196655, 0.18291817686986178, 0.08684868895215914, 0.28264646767638624, 0.14540681237122044, 0.14251642918679863, 0.14622007263824344, 0.12128943970310502, 0.0943231773271691, 0.1446127737290226, 0.11928047562832944, 0.15125162608455867, 0.16170774470083416, 0.10464360908372328, 0.13339699275093153, 0.10084284076583572, 0.09366702230181545], [0.039971331716515124, 0.024866188541636802, 0.025847871802398004, 0.02739445561019238, 0.00437111901192111, 0.03824412400717847, 0.031767801992828026, 0.04924077104078606, 0.027577658474911004, 0.017588031623745337, 0.03757389044039883, 0.020333009524620138, 0.04559466258797329, 0.01994727826968301, 0.10973330237902701, 0.039086105389287695, 0.04328045317379292, 0.03536619777150918, 0.0074542337733873865, 0.048444546773680486, 0.04591612385411281, 0.026204688983852975, 0.04269272416422609, 0.040050585666904226, 0.004635023014998296, 0.022163834037201013, 0.09261039696866646, 0.021741034361184575, 0.02656246353581082, 0.057132320434902795, 0.07449348122463562, 0.052076183346798643, 0.04069251743203495, 0.027243523181823548, 0.02780954437184846, 0.013728144749620697, 0.04014886086224578, 0.08597921099863015, 0.07082119351252913, 0.018887598998844624, 0.09155466221272945, 0.08188911640900187, 0.06335880214464851, 0.1059627097856719, 0.0754723146383185, 0.05776188801974058, 0.0251628231126233, 0.028789949283236638, 0.06596298349904828, 0.05734992184443399, 0.054629000660497695, 0.05264539948257152, 0.009537886198813794, 0.05254772913758643, 0.08879535715095699, 0.051525624803616665, 0.10636060484102927, 0.017335731099592522, 0.04078708931047004, 0.013430752260319423, 0.03746819005755242, 0.03344074386404827, 0.09790920521481894, 0.06336115475278348, 0.0038307077147692326, 0.05849974608281627, 0.03447020659223199, 0.025555961001373362, 0.02709766704356298, 0.027744105500460137, 0.05542113940464333, 0.03266613093728665, 0.02122015801433008, 0.03745154739590362, 0.03374910622369498, 0.02584272500826046, 0.0279649241201696, 0.03536914038704708, 0.02437000715872273, 0.02935480159067083, 0.07346444152062759, 0.09199203952448443, 0.039369579826598056, 0.08343762237927876, 0.08207611535908654, 0.10053227422758937, 0.04789931685081683, 0.03574339432816487, 0.02596571186586516, 0.03047470800083829, 0.04667696623073425, 0.04788040321727749, 0.04396758173243143, 0.054056418885011226, 0.03500864215311594, 0.007751254725008039, 0.053196206645225175, 0.034766987737384625, 0.09423618277651258, 0.05106149677885696, 0.00862182920172927, 0.029256782436277717, 0.0158419863510062, 0.062384347402257845, 0.0728246063226834, 0.07078620124957524, 0.07103431606083177, 0.03296537972346414, 0.02517997971153818, 0.037453818367794156, 0.042600853703333996, 0.03468377442914061, 0.021746390812040772, 0.02131548502802616, 0.04167713959759567, 0.02466463607561309, 0.04478143200685736, 0.022213478150661103, 0.05874478098121472, 0.0677036092383787, 0.07797821337589994, 0.03871182918373961, 0.049672415261738934, 0.01671769277891144, 0.08006180039956234, 0.03702295340190176, 0.02042392261500936, 0.02813433045957936, 0.01289074056330719, 0.03948477969970554, 0.014518019943352556, 0.012240923479112098, 0.025157924937957432, 0.032308571608155034, 0.04019957923446782, 0.05170642682060134, 0.04812973515072372, 0.08517830749042332, 0.010536075751588214, 0.028160120091342833, 0.042882591515081, 0.05951006511168089, 0.0075463709436007775, 0.03142389075946994, 0.004910902498522773, 0.016191508220799733, 0.012656502058234764, 0.027870589728991035, 0.028014193449052982, 0.02746097801718861, 0.032980719915940426, 0.060840034566354007, 0.06469873493188061, 0.04723891303001437, 0.03587343715480529, 0.008295845473185182, 0.05971372527710628, 0.05890706270292867, 0.044783495177398436, 0.032116685615619645, 0.013619963738165097, 0.038452519074780867, 0.046151655551511794, 0.012227248480485287, 0.05113685074320529, 0.011975301404163474, 0.049561137639102526, 0.058545410429360345, 0.04397694763611071, 0.02021242351474939, 0.007451792107531219, 0.024924662357079796, 0.025619804255256895, 0.043608834967017174, 0.0250125920138089, 0.028360440592223313, 0.016217939810303506, 0.07301829944481142, 0.022998789136181585, 0.062124617979861796, 0.022213901174836792, 0.06652314914390445, 0.02094509211019613, 0.02100738242006628, 0.08307885334943421, 0.04004593982244842, 0.08490039544994943, 0.0203663486536243, 0.06904202062287368, 0.04834004124859348, 0.01484118258304079, 0.008287782966363011, 0.03097562243056018, 0.028403683681972325, 0.012089634819858475, 0.0372558170784032, 0.10276520362822339, 0.008856403528625378, 0.018240587232867256, 0.02981591835123254, 0.02007563271035906, 0.028686757359537296, 0.00942019827562035, 0.036276196988183074, 0.05588870728388429, 0.02729285002715187, 0.028348161758913193, 0.03912232590664644, 0.07445359078701586, 0.04343572902143933, 0.034241617686348036, 0.0660425639944151, 0.001571975578826823, 0.02908376554842107, 0.038373576826415956, 0.06665942230029032, 0.06482475902885199, 0.04562363974400796, 0.05661344046529848, 0.05193003962631337, 0.024906837825255934, 0.046627613410237245, 0.06508986160042696, 0.028202110806887504, 0.025243869349651504, 0.003960756803280674, 0.018799814060912468, 0.03294766465842258, 0.057342303698533215, 0.0569797645584913, 0.03948528064938728, 0.013992577532917494, 0.033761162412702106, 0.05514472279173788, 0.04578653744829353, 0.02069376194413053, 0.05122868038597517, 0.03526146960211918, 0.04940961705869995, 0.054317925751092844, 0.020807640794373583, 0.025614694568503182, 0.0016536162297597912, 0.0036818199032495613, 0.03990971119492315, 0.07016639661742374, 0.014452712803176837, 0.011270942031842424, 0.049093202396761626, 0.01949407651409274, 0.03414127560972702, 0.029835845016350504, 0.0701011618366465, 0.049833683951874264, 0.06321852139080875, 0.05361344577977434, 0.06323649620753713, 0.10395022793090902, 0.02703823400224792, 0.03995462968305219, 0.09050801876583137, 0.06021578075888101, 0.044062943998142146, 0.018089291152136866, 0.07611341890878975, 0.0434466014849022, 0.04685239138780162, 0.015798407439433504, 0.04014618170913309, 0.010307348620699486, 0.07560557467513718, 0.03347268590005115, 0.08842461727908812, 0.02924572443589568, 0.1319827264524065, 0.03133639525913168, 0.022098805202404037, 0.053127580249565654, 0.06190294589032419, 0.050022953873849474, 0.03953833678679075, 0.06115927310020197, 0.02085791202262044, 0.047640359262004495, 0.04025390444439836, 0.03392345526663121, 0.05609546962659806, 0.036014022189192474, 0.03007385734235868, 0.03150341559376102, 0.0223077605915023, 0.018606855664984323, 0.03575922062736936, 0.013082578316243598, 0.041800877879722975, 0.014599980877392227, 0.037192077725194395, 0.01904959684907226, 0.030547330861736555, 0.05634388129692525, 0.08045187321840785, 0.03276615389040671, 0.046811855281703174, 0.08405195738305338, 0.060173990423209034, 0.09133962492342107, 0.04884670917817857, 0.030509323623846285, 0.024865535451681353, 0.032791565026855096, 0.028583671191881876, 0.019141940429108217, 0.04477825190406293, 0.052291584288468584, 0.03389931320270989, 0.019645333632070106, 0.0571135069912998, 0.01676739069807809, 0.0781023598392494, 0.005543430324905785, 0.1177971153811086, 0.024704231509531382, 0.022512673131132033, 0.03549737608409487, 0.030910632558516227, 0.06018994659825694, 0.03903072632965632, 0.07088752667186782, 0.00778516716309241, 0.07379573624348268, 0.04943650506902486, 0.03145607770420611, 0.03621015326643828, 0.03013391193235293, 0.02250654113595374, 0.018409967597108334, 0.051047670567641035, 0.021997973308316432, 0.0565632193320198, 0.042839305751840584, 0.04096782453416381, 0.09300352743593976, 0.06157202224130742, 0.05985581687127706, 0.016307086589222308, 0.020116799641982652, 0.05470542702823877, 0.029243618591863196, 0.052951921315980144, 0.03018526669620769, 0.032664709724485874, 0.01532866042907699, 0.09011438363813795, 0.1538295205682516, 0.0845107456552796, 0.1486273473710753, 0.08694918316905387, 0.11173016202519648, 0.11482902933494188, 0.11989628750598058, 0.1318754712701775, 0.18002066906774417, 0.10772085021017119, 0.10329686338081956, 0.14274723711423576, 0.1065183557511773, 0.27595983585342765, 0.1352386618964374, 0.11186416420969181, 0.10132916271686554, 0.13194848375860602, 0.18492610193789005, 0.18410929420497268, 0.16269757674308494, 0.17888024041894823, 0.11119006405351683, 0.13940203614765778, 0.09387797035742551, 0.16531940636923537, 0.17708813189528883, 0.18488489789888263, 0.11976664914982393, 0.22060225397581235, 0.11243712448049337, 0.20079750887816772, 0.1850813889177516, 0.08709376095794141, 0.13699591916520149, 0.08146208463585936, 0.17245851078769192, 0.15869242837652564, 0.10553574480582029, 0.1903583706007339, 0.1427713717566803, 0.1955327281029895, 0.11288982714177109, 0.18434228404657915, 0.1422503247158602, 0.15991631895303726, 0.10092121156048961, 0.17536030820338055, 0.1729733237880282, 0.13748183293500915, 0.11199643719010055, 0.1544439743156545, 0.18888452468672767, 0.15837771323276684, 0.26471807970665395, 0.19921553204767406, 0.13582120329374447, 0.15241243410855532, 0.11394516855943948, 0.09490125841693953, 0.11594664436415769, 0.18000374810071662, 0.14151929441140965, 0.17178309703012928, 0.16803532547783107, 0.08355364232556894, 0.08711238886462525, 0.08450973633443937, 0.1384977440466173, 0.18631376966368407, 0.11519183564814739, 0.13624749291921034, 0.1648781550466083, 0.20045567565830424, 0.17347075568977743, 0.17233157384907827, 0.16497371398145333, 0.18511006550397724, 0.23576795269036666, 0.1717562461271882, 0.16329714300809428, 0.121820787753677, 0.14095631602685899, 0.19199108064640313, 0.18950908648548648, 0.10401883948361501, 0.16160736180609092, 0.14310426951851696, 0.12004511037957855, 0.12873412342742085, 0.1297698201960884, 0.10860209120437503, 0.14869572885800153, 0.38928148162085563, 0.13143977121217176, 0.19709027343196794, 0.11863321153214201, 0.23309587966650724, 0.12621626869076863, 0.10968861766741611, 0.16520826233318076, 0.2086195079027675, 0.20549554115859792, 0.20949145720805973, 0.16749047033954412, 0.21346083405660465, 0.16190508176805452, 0.08008062868611887, 0.15848787763388827, 0.21294201345881447, 0.16850028099725023, 0.19544381881132722, 0.096344112243969, 0.10507932398468256, 0.12076423663529567, 0.10753869006293826, 0.07110795195330866, 0.08396035409532487, 0.1756795059191063, 0.1298336300533265, 0.1583087825565599, 0.15924811887089163, 0.09652976790675893, 0.19517351378453895, 0.17653195158345625, 0.10398496786365286, 0.15880970255238935, 0.1294739852892235, 0.1941173485829495, 0.08388934540562332, 0.1403108553495258, 0.12310756050283089, 0.1009651244385168, 0.13211629819124937, 0.09331056877272204, 0.1529283751733601, 0.19130959612084553, 0.0994437959161587, 0.1351702952524647, 0.16544355283258483, 0.09890124143566936, 0.1680789192323573, 0.11657821203698404, 0.23065176472300664, 0.1569205359555781, 0.07117633344023488, 0.056875526206567883, 0.13744989089900628, 0.1275478448951617, 0.15475748718017712, 0.1813185220817104, 0.17105047852965072, 0.2302065206458792, 0.307161386590451, 0.139673677040264, 0.10488410945981741, 0.24613903602585196, 0.13542994303861633, 0.08590590165113099, 0.16281008633086458, 0.1074390196299646, 0.15723157004686072, 0.23953041876666248, 0.14469451387412846, 0.13228412746684626, 0.14815523754805326, 0.2317312333616428, 0.10240745134069584, 0.13434879714623094, 0.15563872817438096, 0.096962566167349, 0.20586921251378953, 0.1953342926572077, 0.05808510446513537, 0.1540186197962612], [0.021470345272973645, 0.0337161251809448, 0.053965472397976555, 0.057044784116442315, 0.03218526748241857, 0.033010888218996115, 0.04418137963511981, 0.013039398309047101, 0.0076105977950646775, 0.009616416555218166, 0.02503308827726869, 0.04895123696769588, 0.02706286402826663, 0.049322956474497914, 0.039876518640085123, 0.008139661422319477, 0.052795647279708646, 0.05358446862373967, 0.03197765538061503, 0.021161971781111788, 0.03395123014342971, 0.048664445130270906, 0.017536940322315786, 0.06516690395073965, 0.04364519649243448, 0.033617059598327614, 0.018421385539113544, 0.0653325735765975, 0.02429533597023692, 0.029138272584532388, 0.017128354629676323, 0.04527051103650592, 0.02923796528193634, 0.05816986144054681, 0.024654667176946532, 0.036616501383832656, 0.09905059865559451, 0.024382709016208537, 0.029630830431415234, 0.046430632573901676, 0.05951757564616855, 0.04382487415568903, 0.06892381876241416, 0.04377794815809466, 0.03134344195132144, 0.00929411295146565, 0.013490764176822267, 0.0383886387135135, 0.0417187184211798, 0.03454703000898007, 0.025563343515386805, 0.05841711907123681, 0.07197153725428507, 0.028738340333802626, 0.017413042478438, 0.011067181676480686, 0.02098222917993553, 0.04538233784842305, 0.03197530277248006, 0.015532828037976287, 0.05900296673644334, 0.11069739673985168, 0.06908797440701164, 0.05578939679253381, 0.03732325974851847, 0.01901267871289747, 0.038307050708681345, 0.013073466598143568, 0.0975984828255605, 0.034423703618813306, 0.024921760559664108, 0.07009320601355284, 0.04018068044388201, 0.039480571722378954, 0.05125374271301553, 0.04214256267005112, 0.013130608258506982, 0.08368815659196116, 0.09664891971624456, 0.029212863992142957, 0.10008161989389919, 0.03373828571056947, 0.024594850074208807, 0.09777290979400277, 0.028664379751717206, 0.04252948878274765, 0.03420747147174552, 0.06816095774411224, 0.048833331966307014, 0.05074091866845265, 0.011130297625641106, 0.04133908762014471, 0.0659696628281381, 0.057924136344809085, 0.0477801205124706, 0.014771623864362482, 0.03377263230504468, 0.03482458952930756, 0.006974378247832647, 0.06727496700477786, 0.05541745835216716, 0.04301188848330639, 0.08909200099878944, 0.041503310058033094, 0.05266007545287721, 0.005532302284336765, 0.024812060000840575, 0.022078654037613887, 0.049498938242322765, 0.02539205026550917, 0.03598952018364798, 0.03655448010249529, 0.026776044360303786, 0.026202692606602795, 0.010733806157077197, 0.032531475662835874, 0.023809351696399972, 0.049472499231342226, 0.019157050555804744, 0.014969278199714608, 0.028479230604716577, 0.06180334596137982, 0.0560667559329886, 0.03470763076620642, 0.03516940247209277, 0.008441703466814943, 0.03370357917447109, 0.04428336185810622, 0.040470355525030755, 0.09790842595975846, 0.004290730039429036, 0.07070444626151584, 0.06007817173667718, 0.08922802182496525, 0.026822443433047738, 0.05963108713331167, 0.040466088175890036, 0.07414753650664352, 0.032034633768489584, 0.06657769699813798, 0.045251003684825264, 0.02602888533147052, 0.044289692377788015, 0.0197617487719981, 0.04816104265046306, 0.03260581288486719, 0.018062876260955818, 0.03901839183527045, 0.030896116149961017, 0.03966001560911536, 0.045820579762221314, 0.06686811422696337, 0.08749712564167567, 0.030314571085909847, 0.02060253158560954, 0.03247170308895875, 0.03917301459296141, 0.06269072080613114, 0.025564838942955248, 0.0395532650873065, 0.060609601423493586, 0.07065511570544913, 0.040271092584589496, 0.04556347012112383, 0.05348646802303847, 0.061415451345965266, 0.05399832356488332, 0.008664672459417488, 0.07729381220997311, 0.01612348853086587, 0.035199923295294866, 0.0502675063762581, 0.03350680613948498, 0.024402273884334136, 0.038934417825657874, 0.045765864924760535, 0.019922698338632472, 0.021087055683892686, 0.05146194111148361, 0.055755851717549376, 0.02929270423919661, 0.05478756793309003, 0.05187484610360116, 0.033357664142386056, 0.02300618278241018, 0.025386074121342972, 0.051540634740376845, 0.11069845058955252, 0.024914042223826982, 0.05734116079111118, 0.029062785033602268, 0.0024100058362819254, 0.033436706580687314, 0.039255649026017636, 0.028298315410211217, 0.04173612920567393, 0.08191121014533564, 0.07694562620599754, 0.06448681466281414, 0.02920293034549104, 0.030449591868091375, 0.10652002558344975, 0.08799446848570369, 0.01208199812026578, 0.023864062823122367, 0.06552529448526911, 0.01062904830178013, 0.04414177492435556, 0.038030956930015236, 0.07710055695497431, 0.011215156646358082, 0.02245368537842296, 0.03977030988608021, 0.015246159582602559, 0.009186037696053972, 0.04740301301353611, 0.04016952225356363, 0.0860813824692741, 0.08441960992058739, 0.040518094174331054, 0.05631368330796249, 0.026685353914217558, 0.07316850271308795, 0.07976848879479803, 0.06339940504403785, 0.019035317927773576, 0.0473799544852227, 0.026814084994839504, 0.03908678445441183, 0.022197147191036493, 0.04220771952532232, 0.045073578439769335, 0.02932820858404739, 0.0532282266067341, 0.005301285164023284, 0.07008640794083476, 0.03283513280621264, 0.07294984374311753, 0.09726197822601534, 0.048403220280306414, 0.006190062667883467, 0.022899881259945687, 0.026679971488192677, 0.08407543893554248, 0.02006109403737355, 0.019847761832352262, 0.05419658831669949, 0.028253946111362893, 0.05275793875625823, 0.03368661738932133, 0.04203834287181962, 0.01032317863064236, 0.01655729611229617, 0.05604833953839261, 0.009008532670122804, 0.08344456888153218, 0.01943366940395208, 0.061112536350265145, 0.022451831864600535, 0.03623136755777523, 0.06386127322912216, 0.032684862744645216, 0.057804695097729564, 0.08908590796636418, 0.07639527917490341, 0.006432166546801454, 0.06885459122713655, 0.02078002547932556, 0.07013346010353416, 0.054129449927131645, 0.053288540948415175, 0.012544037927000318, 0.05825689309858717, 0.059661337072611786, 0.0308484034758294, 0.018278030438523274, 0.008503191329509718, 0.03194265940692276, 0.0979193949024193, 0.11247094415011816, 0.03847125459287781, 0.09228207825799473, 0.06506411649752408, 0.0626031770661939, 0.021373454183049034, 0.020538573298836127, 0.10362513014115393, 0.06886517425300553, 0.04236023829434998, 0.07370790306595154, 0.01368845469187363, 0.019668102722789627, 0.02303575922269374, 0.04450961670954712, 0.030698664049850777, 0.019330124960106332, 0.04465681056899484, 0.06622318789595738, 0.058194185330648907, 0.02969675355416257, 0.007691586979490239, 0.05025322374422103, 0.05605361991911195, 0.056934719905257225, 0.05497109734278638, 0.01774422958987998, 0.02097199310810538, 0.01749294766341336, 0.026962080373778008, 0.07013714115601033, 0.022252051276154816, 0.06784164128475823, 0.030824973873677664, 0.037971878264215775, 0.08673561533214524, 0.039957115877768956, 0.009980128288589185, 0.01508449013272184, 0.07046452476060949, 0.008232956806750735, 0.015196771510090912, 0.029950534662930295, 0.04591025717672892, 0.0348987003962975, 0.018250212888233364, 0.01660661739151692, 0.08099666898488067, 0.024655771121615544, 0.03442549961619079, 0.025408629844605457, 0.019454993162071332, 0.038792418999946676, 0.027289150420983788, 0.06888455172884278, 0.018849113075702917, 0.007874231378082186, 0.10168234337470494, 0.030612044283770956, 0.041335009518661536, 0.06395730713848025, 0.015787015472596977, 0.05482686836330686, 0.01243072403667611, 0.03232550741813611, 0.05812464238260873, 0.01446110463803052, 0.009364864672534168, 0.08632538578240201, 0.08435125811956823, 0.054620796217932366, 0.06663489431957714, 0.04804790223715827, 0.09215577956638299, 0.1641542196739465, 0.250117689720355, 0.17828233656473458, 0.1122027616656851, 0.20279621647205204, 0.11339988297550008, 0.11615069044637494, 0.15287878486560658, 0.11003315230482258, 0.17296726786298677, 0.14730964932823554, 0.116339329542825, 0.14638030232163146, 0.07644324417924508, 0.10002900162362494, 0.12430213624611497, 0.13934302056441084, 0.09340121468994766, 0.14924114802852273, 0.14680717082228512, 0.15433622931595892, 0.11283458166872151, 0.17300569626968354, 0.11994661996141076, 0.19781861716182902, 0.28263052634429187, 0.1330399900325574, 0.10779280142742209, 0.1404310090583749, 0.09151538775768131, 0.11653000954538584, 0.1251729129580781, 0.22042119962861761, 0.14206463936716318, 0.06493686043540947, 0.19791327067650855, 0.10307494638254866, 0.09227623755577952, 0.1430416470975615, 0.1547655469039455, 0.10780089825857431, 0.19480485934764147, 0.15403073164634407, 0.11591460584895685, 0.11912592337466776, 0.16426374582806602, 0.1516181431361474, 0.11763958711526357, 0.118635118851671, 0.162737044156529, 0.17676124552963302, 0.1812465931288898, 0.15220513741951436, 0.09394583234097809, 0.10203711965004914, 0.1456839154707268, 0.19960193865699694, 0.08077412116108462, 0.15334670897573233, 0.12643610767554492, 0.20558912598062307, 0.19941224571084604, 0.19523353868862614, 0.18070158956106752, 0.21695446455851197, 0.12353062920738012, 0.2684853400569409, 0.16976347571471706, 0.09560577178490348, 0.20300143514759839, 0.21691131609259173, 0.1306092189042829, 0.10497188326553442, 0.16114883328555152, 0.20101399335544556, 0.141007924976293, 0.19837764732073992, 0.17620917671592906, 0.16728128859540448, 0.23172007146058604, 0.13452970306389034, 0.10526105368626304, 0.26035342016257346, 0.16746744891861454, 0.2250314803677611, 0.1483204247779213, 0.17974696500459686, 0.1915821127477102, 0.1286267940304242, 0.1364687568275258, 0.1754293724661693, 0.18342620664043352, 0.1461932365782559, 0.16967961302725598, 0.12840021634474397, 0.19789253507042304, 0.10070313146570697, 0.09044011225341819, 0.1370884946663864, 0.11439488036558032, 0.12532359862234443, 0.20336813031462952, 0.23359844723017886, 0.1520230737514794, 0.2990678505739197, 0.18740883824648336, 0.15497462474741042, 0.10420554899610579, 0.13355786068132147, 0.18151756608858705, 0.2281022648094222, 0.13408439961494878, 0.12558183632791042, 0.10052431840449572, 0.0823183597822208, 0.16482719918712974, 0.13829072937369347, 0.14429645554628223, 0.17323540581855923, 0.135667534195818, 0.18594987981487066, 0.1039611894520931, 0.11295483185676858, 0.06832877217675559, 0.10294017978594638, 0.12587602366693318, 0.13732567022088915, 0.1249864260898903, 0.1973405701573938, 0.13255334895802662, 0.1408072779304348, 0.12459013407351449, 0.19363067782251164, 0.11302423750748858, 0.10855432657990605, 0.1134832261595875, 0.21523968782275915, 0.18009584862738848, 0.1902016141684726, 0.08810903382254764, 0.24310295440955088, 0.19603617140091956, 0.0647932400170248, 0.14856837631668895, 0.1702780809137039, 0.21186195110203698, 0.10752565794973634, 0.09133909799857065, 0.10621858004014939, 0.16019811242586002, 0.15193904779152945, 0.11272630232269876, 0.1344629839877598, 0.13177418295526877, 0.2002664576866664, 0.16850753920152783, 0.24288152722874656, 0.08539853981346823, 0.09515287616522983, 0.20003342331619933, 0.2716243575559929, 0.13849493872839957, 0.10735828138422221, 0.19362248451216146, 0.14890976424794644, 0.1120505397557281, 0.1370363958994858, 0.16692676465027034, 0.22816809330834076, 0.06253516665310599, 0.1331757882144302, 0.1782662616460584, 0.16559642041102052, 0.15906391781754792, 0.13210222707130015], [0.02218238772911718, 0.047400905314134434, 0.10035917570348829, 0.05744592235714663, 0.022206637404451612, 0.03134956095891539, 0.054674824568792246, 0.02825456209393451, 0.02376956144871656, 0.06634274788666517, 0.0773601231048815, 0.015743071053293534, 0.02623657350341091, 0.03929665639589075, 0.028701652263407595, 0.11226972565054893, 0.06352409327519126, 0.00974720431258902, 0.04174465277174022, 0.020921977920806967, 0.01990431348531274, 0.0422139646980213, 0.09186487994156778, 0.05565049643337261, 0.029288542646099813, 0.01766316479915986, 0.031435887576662935, 0.011033352730009938, 0.035303374970681034, 0.033966507253353484, 0.0513860528008081, 0.03264734346885234, 0.03740966800251044, 0.045623966288985685, 0.015562268108624266, 0.041124933486571535, 0.018795520736603066, 0.05810296795971226, 0.017664767838141415, 0.02503133309801342, 0.0392775683576474, 0.060748293981305324, 0.008718722147023072, 0.04786299614352174, 0.03570617933291942, 0.0322912053525215, 0.05360813200240955, 0.04722657111415174, 0.04185419005807489, 0.029022905728197657, 0.01750997809722321, 0.05046689919254277, 0.023162859433796257, 0.02196135017584311, 0.044670525458059274, 0.05813208612380549, 0.03583419238566421, 0.015945026134431828, 0.07309442895348184, 0.06555830521392636, 0.020274032904126216, 0.06793029082473367, 0.06431302594137378, 0.010950743344437797, 0.026372082247689832, 0.0604294450749876, 0.04477146496355999, 0.023380171405733563, 0.039634426357224584, 0.030907062828191556, 0.017272333134314977, 0.062117708584992215, 0.017895970959216356, 0.0424954613117734, 0.06342669381410815, 0.008275864074676065, 0.03393412735022139, 0.05307862447807565, 0.08217911803512834, 0.09373014938319102, 0.05641637799271848, 0.024874856826500036, 0.027817752525152173, 0.03313196590170264, 0.01624196313059656, 0.03661385562736541, 0.06762078555766493, 0.09158240369288251, 0.061059713989379816, 0.03135565399134066, 0.016318704911100212, 0.008620684438938042, 0.01543397953355452, 0.01227395276146126, 0.06020025131874718, 0.028367416780383792, 0.04098326120583806, 0.06901024185935967, 0.0447569225798361, 0.015764866075187456, 0.07533614538260736, 0.01968865835806355, 0.03736455655598547, 0.03634263775893487, 0.059788017970276996, 0.011764966548071243, 0.05992515572870616, 0.03876095564919524, 0.04747131657495629, 0.049021982194972225, 0.03134889673674479, 0.1268320286180824, 0.05306396706146188, 0.03301013493910432, 0.07666881996556185, 0.034607303532538936, 0.02506627526599914, 0.0381438153272029, 0.023521346447523683, 0.07392803890979849, 0.0344554860930657, 0.012260133044037502, 0.046378177576116286, 0.02846958268492017, 0.04950439302774612, 0.07447730982676148, 0.036496384782367386, 0.02248833996418398, 0.028263645981496666, 0.024313268113473896, 0.06289623634074815, 0.05356754765671212, 0.02129372525814688, 0.019349617468833458, 0.03225826512789354, 0.030423189964494668, 0.03718357642355841, 0.07518845799495466, 0.05533121708140243, 0.05952001731202472, 0.06355742312734947, 0.03866903323796578, 0.05646102930768393, 0.018886691723309923, 0.025124730527750216, 0.05900526368350256, 0.03358960755576845, 0.02156442733394215, 0.030598500088672154, 0.045365717451204546, 0.061182287099654786, 0.033973657846217975, 0.03733600242412649, 0.026421075126563665, 0.0946186188957654, 0.04741391145216767, 0.012161457088950556, 0.03658026602352038, 0.09760356653714553, 0.05220394035859499, 0.028489592841651756, 0.022900107614987064, 0.041979509114753455, 0.022734122576366644, 0.030596358992625028, 0.03364823722222354, 0.030308646892081015, 0.06253517407458276, 0.08679232283611782, 0.020652389066526666, 0.022055150220694486, 0.05312406618031673, 0.015552377135463757, 0.03010774566064356, 0.06875863153254613, 0.029683296561415773, 0.042952698495355435, 0.06253231680602767, 0.042883660207735375, 0.021920240760664456, 0.03348172896949109, 0.03129856057057623, 0.013324686369742267, 0.02882574306568131, 0.07276464079041034, 0.044260945287533104, 0.0046819401995890075, 0.03793232550378889, 0.10730883208452724, 0.08318073538248427, 0.004933634481858462, 0.07874311530031264, 0.03476701742329169, 0.03770426723349374, 0.1538758008973673, 0.018464797467458993, 0.025055749756575096, 0.06986670254264027, 0.01788275330909528, 0.08037312392843887, 0.0776088835846167, 0.03858926720567979, 0.04224704593070783, 0.054737677055527456, 0.05661024551955052, 0.0341370750538772, 0.0645228533539921, 0.08260741888079792, 0.04592757148202509, 0.017508992896182463, 0.005401167109084781, 0.012583227035065647, 0.02581199452833971, 0.034346442334936, 0.07703816459979862, 0.055441563308704644, 0.11513495002873242, 0.025637291109887883, 0.017904602136695758, 0.005606216482192394, 0.03827912740234751, 0.03380742418812588, 0.02965780749946134, 0.04483939745114185, 0.04696720905485563, 0.03135269282211084, 0.016590909835940693, 0.047191842313623056, 0.019007450282515492, 0.024047163642535452, 0.07973285828484222, 0.019366851993254386, 0.03437427287281025, 0.0168800394385471, 0.045095876266714185, 0.022399135668820236, 0.03254735020163935, 0.026398480440548155, 0.03143657777400222, 0.025673684176581446, 0.04145749728195369, 0.06250709120649844, 0.06947521222173236, 0.04942739520629402, 0.06065623427275568, 0.01080235926565365, 0.01609369872312527, 0.07498301667510532, 0.0704071122163441, 0.05526073160581291, 0.03830607849522494, 0.049144544173032045, 0.008347462771780556, 0.02902302447182592, 0.017037788493325934, 0.047563966290908866, 0.005673289933838532, 0.03026381746167317, 0.011697636127792066, 0.08015915533178486, 0.04376965094706975, 0.1309638170641847, 0.02352002171392087, 0.013051414607616607, 0.055334152275463566, 0.06314939775620587, 0.028481744629971217, 0.03002171219122829, 0.008721130416233791, 0.019901291088899598, 0.05105626092699822, 0.047735873667988926, 0.03582476339943241, 0.07012560818111524, 0.06558570530614816, 0.024311913693964016, 0.03160815860610455, 0.03940604154195171, 0.029054771694063675, 0.029893669452576432, 0.09177758853184059, 0.01967495831195265, 0.05128623393829912, 0.037628145146300085, 0.06905214351718314, 0.04586604001815431, 0.040463516634190455, 0.057024438137887046, 0.07643760385690257, 0.03205387023626827, 0.016276660389848985, 0.052177549587213434, 0.033504279126646, 0.13684366014786065, 0.04617147831595503, 0.07450022734701633, 0.04887792390945833, 0.010329138076485833, 0.0433085657277843, 0.017801304456952494, 0.012350414381216979, 0.06528575147967786, 0.002409679755146499, 0.03818318997218739, 0.050536816925159656, 0.02765967135928804, 0.03235838084947318, 0.05074514148873277, 0.018503361316106748, 0.023581482673762366, 0.05552797898417339, 0.060038533629267476, 0.05774385012045968, 0.02301264503330458, 0.015500706958846422, 0.05758267048804555, 0.10379533428931609, 0.037046267971163616, 0.02947612047137227, 0.009352222186862491, 0.034529797339928336, 0.03050280014576856, 0.006856727895865333, 0.014460295697062975, 0.022885030884935986, 0.01816204203350935, 0.018948213910334744, 0.06515357497846708, 0.05138548876857385, 0.03566497158317361, 0.10407406269223429, 0.050680537533480674, 0.0026951707468469976, 0.043376783942221664, 0.002321734327779268, 0.009699261572677642, 0.03166784212226048, 0.09420069327461533, 0.05656023960909806, 0.06053952041838784, 0.055455693800468, 0.032968622908811085, 0.050508541098679416, 0.10536223067902029, 0.08691476978128776, 0.02145827980712056, 0.03669257523142733, 0.03149305521219503, 0.015173597948887618, 0.03829830820905045, 0.03357731016876642, 0.06669721988146193, 0.10819604736752808, 0.22584094083867967, 0.26782551140058786, 0.14159637386910617, 0.17454568238463253, 0.10973650845699012, 0.1432998402742669, 0.07707563563599251, 0.2234340668655932, 0.14205142913851887, 0.13880643295124173, 0.1531123387394473, 0.1726901053916663, 0.29915661143604666, 0.16793657530797645, 0.12655042810365558, 0.2053498724126257, 0.10001887130783871, 0.2332846523495391, 0.10569706544629298, 0.11365534504875541, 0.14870019658701494, 0.12814089510357007, 0.19731075066374615, 0.14030790160177276, 0.12046791933244094, 0.06892148841870949, 0.12348975171335042, 0.20640297996578738, 0.07846931475796737, 0.18206898181233555, 0.09148533819825388, 0.10529356717597693, 0.11277149911620654, 0.06167902880406473, 0.17227478470886126, 0.08846585842547938, 0.1484461742802523, 0.12153414063504897, 0.15035442891530693, 0.21113167778821662, 0.1524451925070025, 0.15816896193427965, 0.11273675918346271, 0.10277442852384411, 0.12836089736083522, 0.06480432028183714, 0.09376872621942312, 0.12971074524102733, 0.10898226377321407, 0.17726442165439948, 0.15565219073323533, 0.08752343477681279, 0.05263753642793745, 0.21973400056594983, 0.13502337969839573, 0.1895519974641502, 0.16981498076347634, 0.07910440763225779, 0.18225254461867735, 0.23702310252701864, 0.10647307732142508, 0.1944681172608398, 0.12330739118624479, 0.09427953904378228, 0.13426168385194615, 0.1722274356870912, 0.15353858383605257, 0.057325757516082376, 0.13213296682806686, 0.09757406616699882, 0.13097578048473224, 0.1426798352622427, 0.15220981294987723, 0.12131975643569604, 0.12266039426322095, 0.11232422897592187, 0.1092908858845476, 0.2526782773202285, 0.18108333548298106, 0.09848233617958613, 0.162400153640192, 0.0968505983473733, 0.1496760020381771, 0.17639499565120786, 0.27271908475086093, 0.18921384529676288, 0.18546778068412095, 0.19225356343667954, 0.1079821158782579, 0.10695614866563119, 0.1908248697873205, 0.14911294943885878, 0.0854220510518644, 0.30331453832332045, 0.2152964027482085, 0.10303058821591549, 0.16968661890132353, 0.20735487341880798, 0.12718517216853797, 0.23908778704935685, 0.13251306518213823, 0.13141795207047835, 0.14684013702208176, 0.21381601109169424, 0.10963626657030545, 0.1638689381070435, 0.1312874528230168, 0.14516862749587744, 0.19098956719972193, 0.19006207556230947, 0.1468886437942274, 0.24920057330746204, 0.13885541469790041, 0.15436873538419604, 0.16746415378293023, 0.10952815791824833, 0.20661067741457373, 0.1676645188126713, 0.23077389254467562, 0.10780156619148329, 0.09257763114874251, 0.12685277906712145, 0.05241953054792248, 0.13849948067218065, 0.17559724627062678, 0.11344068625476211, 0.1852862216765061, 0.23340657236985862, 0.09620682976674289, 0.12712792289676145, 0.14663997979369015, 0.08681851322762668, 0.13202954112784937, 0.15438905538758263, 0.14381107612280175, 0.18474086187779903, 0.1946143203531392, 0.09237525489879772, 0.10286511154845357, 0.13426592893665656, 0.1279243512544781, 0.2375057656900026, 0.16540554002858698, 0.1454889978049323, 0.17152767948573455, 0.11216473401873372, 0.1137413970718626, 0.11177919572219253, 0.2240383977186866, 0.12122851680032909, 0.16178443824173883, 0.22114313120255247, 0.12099963845685124, 0.18811110290698707, 0.10268009413266554, 0.11678962764563039, 0.12233011628268287, 0.1360624161316082, 0.06525219898321666, 0.09698957292130217, 0.22943483549170196, 0.13972389075206593, 0.2130335647962056, 0.11971298445132561, 0.08991373659227975, 0.09274184616515413, 0.2741680241888389, 0.24164614820620045, 0.10136430340935476, 0.09396542503964156, 0.14376302948221564, 0.05530133450520225, 0.11667956714518368, 0.14498861215543002, 0.2182081449427642], [0.04925031134916935, 0.05026555452786852, 0.015639398588973563, 0.06506813151645474, 0.08790999723714776, 0.03513844007102307, 0.02803124243655475, 0.04001092158432584, 0.015607040950271767, 0.009699704078229843, 0.03261569087044336, 0.02723740974033717, 0.013378129351622192, 0.018312633073946927, 0.00867586219101213, 0.060154045204399154, 0.04265365008905064, 0.029473164868250024, 0.051963996593258344, 0.042652481206459925, 0.01773018444509944, 0.008066275076998863, 0.055622925647185184, 0.026538622041698545, 0.017414537906006444, 0.05782106316473801, 0.006818446063334704, 0.03120591827610042, 0.0273509397811722, 0.03024422847374808, 0.05802538384159561, 0.04792349602212198, 0.020461870481085498, 0.03094681782386033, 0.04299599168007262, 0.023664619911869522, 0.026468097603356, 0.03680860630993266, 0.021889712515985593, 0.03515146476274822, 0.051827415445586666, 0.03367973768035881, 0.025524759257677943, 0.1107362555922009, 0.014831082880846225, 0.08910160438972525, 0.023463026627723593, 0.030785961025685538, 0.09812204574700445, 0.027750988920161035, 0.017998448565776926, 0.04566435767628718, 0.017741780502547044, 0.03499173602904193, 0.042360538864159025, 0.0503156643389957, 0.07025429658824578, 0.03794663782173302, 0.021554322993324604, 0.018633713989402167, 0.10341805609641597, 0.01985589577088831, 0.00497912720675231, 0.009637184630264528, 0.054075696170912124, 0.047202777859638445, 0.05814355601614807, 0.035469200447550975, 0.028021325488225557, 0.042348452989244834, 0.02698678832530277, 0.006219915094334283, 0.027618424646789208, 0.05307413077389356, 0.011278950732958037, 0.032224846218014136, 0.061505603734985925, 0.019422268160269596, 0.01773836662323447, 0.08952206073445268, 0.04030972508189734, 0.04698319862654898, 0.02454959390888689, 0.06625836569583043, 0.055799308174755424, 0.0903777421626728, 0.04582251305691898, 0.1429721969179809, 0.011183116275788052, 0.021723558638768736, 0.025045958973350935, 0.03997162857558578, 0.010336200539313722, 0.020588063416653313, 0.054636975037283264, 0.05953550964477472, 0.052500235397019424, 0.04992493471945636, 0.14908958662999794, 0.014200050482031656, 0.0463957033935003, 0.06343027096590959, 0.0679749681148678, 0.07868190295994282, 0.0054222408562054625, 0.014640503995906329, 0.07218560233013704, 0.07294225157238543, 0.008608404677943327, 0.06502330579678528, 0.015503756258112844, 0.03896297937899362, 0.06947975416551344, 0.06286511808866635, 0.029705100860155653, 0.01605085639312165, 0.01557880223117536, 0.06144043945823796, 0.0642562739085406, 0.05074726403108798, 0.05723479618609417, 0.006041890565029462, 0.019061879393120762, 0.030915196766727604, 0.07802335821907036, 0.028861867103842087, 0.023502184194512665, 0.04816117252630647, 0.02953513048851164, 0.03605463251005858, 0.046430528673226945, 0.06716831296216697, 0.06249949903576635, 0.05190806092286948, 0.0350815767160384, 0.07668031583307311, 0.01766415371093899, 0.023102277918951586, 0.03646164113888517, 0.015218630542221945, 0.027952847522101365, 0.07560830577858724, 0.047013656367198564, 0.03358445334015414, 0.04472581174923107, 0.010622413501550909, 0.02187475452956278, 0.046721209364477545, 0.10509221508982591, 0.050048327902914025, 0.03223185209208168, 0.024291736554005183, 0.027057069710281212, 0.055316262805718, 0.016980349973891862, 0.016705278503650334, 0.03532595852448139, 0.038287324423436075, 0.030502529261866584, 0.042421246544108726, 0.0418581716803601, 0.035577565140556544, 0.061435073730535805, 0.0479717615962727, 0.051839289808413014, 0.01286142480239505, 0.053313696043915115, 0.08929599513066933, 0.008690383237990318, 0.050488250781199895, 0.02902762764279032, 0.01895740355394082, 0.015086993953445926, 0.048882610572036356, 0.02108119457261637, 0.02358752190048108, 0.03053251017263392, 0.06660601735347882, 0.017420376752852462, 0.03077119414228946, 0.09576628348440863, 0.02211571318184724, 0.015792466547281947, 0.01861091335740639, 0.020955678846803494, 0.07376924157142639, 0.042225894721923396, 0.008183368354366394, 0.056227226814371534, 0.03541031474014744, 0.02508420369849773, 0.08148322100169025, 0.022162667009979486, 0.013984667166369036, 0.04543695249594748, 0.0333132577361539, 0.011067332889069803, 0.010517711307329591, 0.053375780407804996, 0.04200785173452459, 0.02324477583897533, 0.028782427616533823, 0.01900732040667208, 0.02408573305729078, 0.022117943335615564, 0.01711512028123252, 0.07549518762971275, 0.029371514756348915, 0.08238188762334175, 0.03564261438441463, 0.053387001680675894, 0.052567370075848885, 0.038017323677195236, 0.04246649899869226, 0.03241872487706132, 0.09564707972458564, 0.05707867429009639, 0.06717844327795319, 0.036977422641939484, 0.11046939413063228, 0.01694826321909204, 0.0439492618170334, 0.04524522977590095, 0.012175190531706903, 0.04209579994494561, 0.029370685406320263, 0.051660372846527025, 0.033775745614548214, 0.04119598670513369, 0.02778935795504367, 0.0469436013372615, 0.07107585406629369, 0.03852746114716865, 0.018385918301646598, 0.05522745370399207, 0.032610417911200784, 0.07155862112995237, 0.02368576740991557, 0.09314777867984958, 0.048912136917351745, 0.03758598744752817, 0.02247049502329901, 0.031200059020193294, 0.04986927735444624, 0.06780867508496158, 0.04763671531691216, 0.03975670631916728, 0.060484159912448376, 0.0036986576105846325, 0.03640949784312397, 0.004272938440408325, 0.013610847381642088, 0.011723166935553309, 0.07047064747894183, 0.03176773891027551, 0.04401734644488897, 0.02804113712045364, 0.007420547226502094, 0.005441657294795732, 0.026713510997069534, 0.06266732831136324, 0.023486715981562156, 0.044997048171353526, 0.02890125473641092, 0.04463399323867634, 0.05430283046734985, 0.057760696872719564, 0.04378872414235957, 0.06170503365865443, 0.06436385563574731, 0.020282879304431845, 0.08179469296010211, 0.02124056150933029, 0.03591397326090373, 0.050954991165781394, 0.02146748243831098, 0.031216059724101797, 0.08224803386838175, 0.04736883711302653, 0.029771801382594276, 0.013258792005217401, 0.00974283306277357, 0.05962246337730903, 0.0548902885930147, 0.025144028222712222, 0.04268975186278112, 0.040767682148725726, 0.03456763573922217, 0.02022115859290352, 0.06848312405054457, 0.060033713380107656, 0.03622762342274655, 0.015714659784862306, 0.015423314871441107, 0.0379034856450744, 0.03494982323900331, 0.044407823734218255, 0.06337380094919354, 0.1066150947008282, 0.03772718846448697, 0.02857758187019499, 0.01579514198965626, 0.05898389354115352, 0.04160422358836513, 0.06769143059500493, 0.02366086464462569, 0.01782333511073375, 0.037244443665258586, 0.04380847269203514, 0.04468299724976532, 0.029926800780231133, 0.031192455717246048, 0.023626180372957606, 0.033557958668097854, 0.021546211319218855, 0.027410367256379686, 0.04480967814743053, 0.029745187966909725, 0.01638494159124093, 0.02922030587797053, 0.047805976937524974, 0.015089527460077079, 0.032035587428254075, 0.06114556563261431, 0.06070425864891149, 0.036459511175053194, 0.05587028346781153, 0.01900980103528127, 0.05351513347704895, 0.10083923392812721, 0.056235308802570216, 0.03345674085721839, 0.07294067821931094, 0.016091466713987757, 0.010617878979246598, 0.01015061816360685, 0.050379759923089296, 0.04470690182643011, 0.026930255226034205, 0.049944356724154204, 0.012221862343722023, 0.07037422765279189, 0.04825044918106869, 0.04376007353130262, 0.01908916630782187, 0.010061191223940114, 0.025721708552737255, 0.02295015990966931, 0.04365714507002849, 0.04804472584510222, 0.02591361309896456, 0.05884757585590705, 0.09422634189832024, 0.1296199212083593, 0.16122871806146577, 0.14137634192593396, 0.2141103765461594, 0.11752023492590524, 0.14141549763735384, 0.12409716247930191, 0.07725176212261431, 0.15440303744981065, 0.13808610441628844, 0.12539119343273342, 0.09640410746214911, 0.10240667950711213, 0.09954411201761104, 0.1567067825817503, 0.16070390091044828, 0.1463759533362463, 0.09453701233724132, 0.12296008833800443, 0.08392691292101517, 0.11345758495735936, 0.2102487298543565, 0.09447410047869198, 0.08953717828262597, 0.15185122203547508, 0.08119614343740977, 0.14389467163709924, 0.08595741412136704, 0.1182606237125583, 0.17807009717216715, 0.17915029311552644, 0.1293645185069181, 0.17762644129106775, 0.18976784369442612, 0.15939405479002744, 0.09511481141089462, 0.2725691709201783, 0.14277962443884462, 0.15948204381857067, 0.15371744142612442, 0.18982999114086851, 0.14544957492034882, 0.27448673208709806, 0.09258234378648922, 0.15051862166728824, 0.1359420397784561, 0.15194559353403747, 0.1545216326485388, 0.21566606650594622, 0.08561423761420883, 0.1512239736621268, 0.13406044308794662, 0.061366276640910655, 0.1631476150942035, 0.2862826350610703, 0.11462482740171254, 0.1299328255117871, 0.18472851254045963, 0.0770796654978767, 0.15306834422517568, 0.08224383331253193, 0.1450924831442535, 0.07877186610130593, 0.16694583784556016, 0.17388376087183133, 0.11931709319469519, 0.1625873232842423, 0.11693397536873817, 0.12556831439724192, 0.06475470028817654, 0.1292482388089411, 0.15217862790450454, 0.13374654430663213, 0.06840602974989451, 0.12643745838431641, 0.13483273680321872, 0.12278553520445712, 0.1103573149885051, 0.1461506076157093, 0.16089534532511607, 0.19678584445500746, 0.1849668606882915, 0.17947281565284356, 0.13176509906770661, 0.22620223317062482, 0.11727952674846165, 0.17960996454348788, 0.18084523966535926, 0.12806673970771953, 0.1675380568485707, 0.1506778717157431, 0.12030078025418334, 0.183105762116611, 0.12649972457438707, 0.17299750295933336, 0.20913822459988296, 0.2133838288136758, 0.17935073236003518, 0.13637198077049106, 0.1786894490942359, 0.1955709487083368, 0.07941399453557096, 0.19798243883997202, 0.11335978473653086, 0.0904859250294976, 0.2821456070523709, 0.17618370620766655, 0.06826729266322218, 0.14969446667237207, 0.1291836125892587, 0.09228748109308071, 0.2040759165538475, 0.15777877037180588, 0.19690334127517417, 0.11642057987046428, 0.135216842754744, 0.1396715544979088, 0.16342534159775823, 0.2392948610940948, 0.18087502947309986, 0.14749586902325973, 0.21312386932549998, 0.10867926714126952, 0.16510517802089453, 0.08804296041489579, 0.09142697570496239, 0.12825214304029942, 0.2364533705986105, 0.1012763440667186, 0.14959687425289303, 0.13727342302445322, 0.1176269409188535, 0.11561955019715242, 0.10471793517353944, 0.15614246833138168, 0.09739506014739163, 0.15794159757206216, 0.1194466053857468, 0.08529596758307889, 0.09048717183759436, 0.18568594241514802, 0.15571038995403796, 0.1649707305477932, 0.13205210241721943, 0.10481083721970208, 0.09684152930276468, 0.13161715934984386, 0.21294662961736321, 0.20583943754900247, 0.15551185060758144, 0.09292261849623173, 0.08038647516514175, 0.23393228009808809, 0.1401674872613512, 0.16939191205892712, 0.15026390174170956, 0.12984366388991475, 0.0951190416526515, 0.11107768805231899, 0.17893563432153314, 0.26299588149413466, 0.14198687713360414, 0.1849369818228297, 0.12775000592228025, 0.13521105400286615, 0.12143619198468514, 0.12531277810921893, 0.15467375807929784, 0.12383473163936287, 0.19837503496091813, 0.05695223459042609, 0.18276076734764501, 0.141062012698967, 0.09533800490316935, 0.1293971878476441], [0.018528766886447556, 0.02528192853787914, 0.029132339113857597, 0.039676866072113626, 0.044125473650638014, 0.02376228840148542, 0.030771337005717214, 0.029236124755698256, 0.028757446925737895, 0.045541996078100055, 0.09916749433614314, 0.034284098219359294, 0.055502846153103746, 0.04368144669570029, 0.03607015823945403, 0.06781528019928373, 0.005286540545057505, 0.07045595295494422, 0.04134748873184435, 0.03824931161943823, 0.024995194216899108, 0.030158898189256433, 0.05404168725362979, 0.06881369889015332, 0.037189884678809904, 0.013379934625845635, 0.07594665090437047, 0.0305229754303582, 0.012214095768285915, 0.048514535010326654, 0.03801182807364967, 0.0384102834505029, 0.051655678762472235, 0.04794595712155569, 0.04315500795200933, 0.036207388766342774, 0.01711130935291294, 0.0419561945454916, 0.008730898935027653, 0.042933454606099986, 0.057485233919578604, 0.025918613318935968, 0.01184471309898072, 0.06520309107145295, 0.029053840298729483, 0.051136012116330676, 0.044836751694674604, 0.03294317837571725, 0.030140294402372092, 0.03332773703732528, 0.051795647814287804, 0.053280484935385175, 0.025072431380976923, 0.06666082495939918, 0.006740618428011658, 0.08104704596917145, 0.020378106128191575, 0.05024962061725091, 0.017213658938999288, 0.03584787016734481, 0.026299442688468844, 0.029758518794551492, 0.04423754908202682, 0.03972931364842225, 0.051902761988458224, 0.051009342350880615, 0.0353518297924893, 0.02568172163591953, 0.03743756162293721, 0.03146100556477904, 0.031156558034126647, 0.08502145457896404, 0.026792432836373337, 0.03605369740398601, 0.03936425120627973, 0.04453809291590005, 0.02106319192535011, 0.038184844961506315, 0.06337604965665378, 0.027643542634905316, 0.024500448889739346, 0.04344503555330448, 0.023942279622133356, 0.018369054851063993, 0.11619855897151865, 0.015757338842377067, 0.041372131745447405, 0.017625452564971056, 0.026172236721322406, 0.0673296039167326, 0.006013184756739065, 0.03710445234901272, 0.04835073559661396, 0.021707821397285443, 0.04313400146202184, 0.07901280434452929, 0.05249652465863619, 0.025920884290826507, 0.07018253090791404, 0.04209273487504106, 0.04510338680120185, 0.016673399550199974, 0.02172812841308769, 0.050848233222495764, 0.08014184844796546, 0.02219944970420329, 0.015279930084943771, 0.055196762186824344, 0.029713745025219396, 0.038752573091187514, 0.043053133340436034, 0.05468332958116662, 0.046952009870437905, 0.06198817784024868, 0.06061046973627526, 0.0290720507473452, 0.05437986910692416, 0.045714063016930595, 0.044103097898187116, 0.06254292951780371, 0.015345591600635089, 0.0045683359439863125, 0.0034312124034840963, 0.010160215988435084, 0.024146160576492548, 0.024576611795055214, 0.05807996880321298, 0.03342092481034342, 0.01724115551041905, 0.0245163716681418, 0.047587125009158626, 0.07426449898048304, 0.045015612995484844, 0.029584288495243527, 0.048280372575391084, 0.06168559310026467, 0.03620296927692834, 0.03758826213015709, 0.024240248203568626, 0.013294418804434827, 0.030140466951706912, 0.018282182754774112, 0.05569636487052776, 0.07279537312570028, 0.034211252714158036, 0.0165391635891865, 0.049743709678296, 0.033195738651556894, 0.03135724960884545, 0.04883518733549863, 0.03225371576263569, 0.03631465137004852, 0.0837537030747626, 0.04721276345662773, 0.0536514994018944, 0.029244245706649963, 0.04347743029939011, 0.05979528359603137, 0.009404398879269138, 0.04382609127787873, 0.03481621068203822, 0.0214710855652811, 0.04893339944828767, 0.021089495494379662, 0.020891746535198763, 0.059185976642766036, 0.026321721961721778, 0.025615009981265757, 0.023083386549842544, 0.03554788665496744, 0.05451589735457674, 0.03909050261427183, 0.05708058532036375, 0.030510295837302692, 0.034518364554969594, 0.08648422022815794, 0.028606245468836278, 0.020724698370031547, 0.03559541750291828, 0.029531865038734395, 0.059152349931537174, 0.008796648580755573, 0.03538275137543678, 0.02396582054643659, 0.020956658481736667, 0.038726545972167514, 0.0292893645746517, 0.02851395940524526, 0.04176263500994537, 0.017820702341850847, 0.008640452469990123, 0.025968127556552645, 0.024228596485045273, 0.042542142400634475, 0.0184074739809148, 0.010943297747871839, 0.04202139221888501, 0.07597710864502005, 0.011305458392598666, 0.04308785100874957, 0.041702253874973394, 0.014408757251658244, 0.03705076167534571, 0.042984647952835076, 0.05912413718760945, 0.0358637632598402, 0.05168329778825864, 0.06683301064185798, 0.0026147217067773454, 0.0017831032573667471, 0.03736048216524068, 0.013141127274138853, 0.06390609894879162, 0.044060750951757655, 0.03502713647321798, 0.1004579704022035, 0.0026027197873190744, 0.07415894331643358, 0.02209464175393805, 0.027907910480280407, 0.033977709972532466, 0.028302228383836336, 0.036991768356529064, 0.05147688425495289, 0.04381490340165328, 0.03563139682228211, 0.00934309748117812, 0.038606878370046616, 0.029431144466798287, 0.03519058707752265, 0.013738237030338496, 0.07647843682207167, 0.054584186073043384, 0.09679451424744911, 0.06356995058013126, 0.02871646182029508, 0.08475701251882128, 0.04326109054090921, 0.05129231583850924, 0.01778467107214965, 0.07476348197087646, 0.037918562375125475, 0.01440715792341507, 0.04011073302535806, 0.044829797770944424, 0.00825853585411096, 0.04594687474309467, 0.07496721635106951, 0.02290433600137476, 0.027620532346190885, 0.05109517544042319, 0.0062742231420998, 0.049392970686312765, 0.05934811364568304, 0.06383863772498444, 0.03726076349266805, 0.04261398600647226, 0.028457827065722086, 0.08489375322824344, 0.02350988954276545, 0.03633817002992146, 0.04249696787155699, 0.07704194955294952, 0.06579518390935846, 0.023858687818574253, 0.05413403268903494, 0.09256285498850048, 0.030547970964107662, 0.03478447273664642, 0.025772295193746686, 0.06257682340219617, 0.0889002374606207, 0.04163162739132531, 0.04725808270450216, 0.13343671249458566, 0.03278384298027959, 0.06003451118886005, 0.032870770737645216, 0.018001485805143602, 0.02410391010926105, 0.04561264482617844, 0.021429905646073166, 0.06372868854668923, 0.08028189171454869, 0.03589056221244391, 0.019850207208946813, 0.028443128830986097, 0.06579810797120444, 0.03838256423478015, 0.015298167436412768, 0.06380017221090384, 0.07731827339739539, 0.02952362163341604, 0.0376437005616026, 0.0409049497829983, 0.06375030730850995, 0.010754922113846987, 0.02905783119786065, 0.029747839289484546, 0.019651198454084806, 0.01045038645315799, 0.06477615577750839, 0.09696156426798552, 0.028611661291506607, 0.04059984174091369, 0.056997446226887405, 0.011094476940343156, 0.11992634448688477, 0.023820508031349164, 0.07644438708666712, 0.011850619666802231, 0.033055966268875636, 0.028584619285538793, 0.027269257152511273, 0.026012101661763154, 0.049068333028117195, 0.04050161107443273, 0.04293375888664741, 0.04655293108953629, 0.026181543253187556, 0.039684599250904284, 0.004382191391414381, 0.10165077983401716, 0.03987584699643776, 0.08807637932477519, 0.06844772360636853, 0.023743905403534882, 0.019605281777330674, 0.009614302362024318, 0.0700006156694144, 0.0637110105890315, 0.01433980152796721, 0.15583422471536323, 0.03619859431637451, 0.07510347466450185, 0.03036497775610769, 0.031898520173854195, 0.05938616355706472, 0.04377525416202843, 0.04998083699319977, 0.05679099558619782, 0.025200297859555576, 0.02584753598057432, 0.01669267498073168, 0.05718033738958184, 0.05508740301593207, 0.01295820085942978, 0.01561721208418021, 0.02581598728284007, 0.05811902432469651, 0.035079828958259895, 0.05383579322369769, 0.22060351562686265, 0.1047652174020186, 0.09988115838496014, 0.12475380732212216, 0.1606435197754763, 0.1216620126797352, 0.23480792529881, 0.12741600978188217, 0.11457484375569038, 0.11241576547035947, 0.09852387418504804, 0.20060674723936245, 0.1687866312568076, 0.11775571838370524, 0.08754965485422872, 0.10588777513476089, 0.10282795221428387, 0.15966487932018936, 0.10988667461788282, 0.15979119285475463, 0.1529030382516794, 0.13937043549958616, 0.11074061199906282, 0.1610288131632842, 0.18128435360267758, 0.09324036160251126, 0.24914779176469892, 0.08895771679817699, 0.13603289349703118, 0.18743028631433845, 0.1738972234306857, 0.15490726742427796, 0.10283857234753668, 0.09752956699230708, 0.10548510806984268, 0.12306755132158287, 0.1407661332632415, 0.17468097590608522, 0.18139586871257052, 0.26805391476955265, 0.10784470723592676, 0.10744857849203981, 0.12932748533785343, 0.14258887764299288, 0.07995705367648043, 0.17177420610096306, 0.10083604269311763, 0.08683961248607375, 0.1801128438091837, 0.15722972952062264, 0.1377158469404094, 0.09597427037078887, 0.13958058203570545, 0.18124770635040477, 0.058045996993314475, 0.15796656341990456, 0.18517786811571568, 0.1809247088385746, 0.09752089870744385, 0.1163604213797953, 0.20513433788437396, 0.13107372913509607, 0.11111120344139636, 0.10712139526731335, 0.1565345746348612, 0.09387229292769916, 0.09995404470828362, 0.08665957488119602, 0.08423917897744104, 0.1619455436593853, 0.12170803325716406, 0.17588813847396523, 0.12628396740183234, 0.09879000834189355, 0.21794474188936874, 0.09359353483887389, 0.17180476774228737, 0.15358291973825544, 0.18519708974054083, 0.17965444887522608, 0.16792125737993047, 0.12490891618654132, 0.1920806578709744, 0.13345081330044195, 0.14452999457716942, 0.18330985272768885, 0.1514465585933067, 0.19981168443337083, 0.1946222613332793, 0.22324495279463008, 0.16673923877533525, 0.12219065189128742, 0.14857591653708369, 0.17064434563508257, 0.12952764256624505, 0.23066451482009143, 0.14858100767014548, 0.15310024173231795, 0.21887275303015485, 0.1717823845683597, 0.2599977236241102, 0.11045386840123683, 0.09427968747331761, 0.16030504106311128, 0.188599168905057, 0.07315990864299238, 0.12322696464252658, 0.13439172296784818, 0.14828486106125638, 0.15361885452875867, 0.18055734573863447, 0.15917345881462097, 0.1685157770407386, 0.15452359191840515, 0.18030320468824357, 0.1829659563372843, 0.15448569785803556, 0.09758079002494924, 0.1337627973407507, 0.16120136249810457, 0.09035374110681005, 0.1374312926782295, 0.10492291636182927, 0.10468217107700184, 0.08778446295764297, 0.09911114306305535, 0.15884991211351007, 0.10236290763714351, 0.09872931550489739, 0.09167995158350095, 0.1276436710031703, 0.18058811518130824, 0.1311344961868599, 0.17131797823822126, 0.1370054334984161, 0.14256406022468582, 0.07751794822979718, 0.09230127019691281, 0.08242414551205002, 0.12674846278969198, 0.07666806297493167, 0.07765744972857647, 0.13971569744171575, 0.15722995216492563, 0.09506657181191258, 0.09829072849242948, 0.18187234236393124, 0.15746323886560276, 0.1410960772773251, 0.12254019602551125, 0.11115741697722115, 0.1273770915577188, 0.1435752958059311, 0.1376478810561821, 0.15295228717150167, 0.16255103226285428, 0.24508343485649675, 0.1314676908077672, 0.1426230461220257, 0.08107210087473504, 0.2145726009621285, 0.12883741554105654, 0.12572147883474827, 0.1252557069528848, 0.09744652066729032, 0.1453584391856566, 0.1475811714772135, 0.1264556558453478, 0.12801603617845103, 0.18186604895163327, 0.13555805257055908, 0.15173893509199843, 0.15486273856367916, 0.15559951309114695, 0.18096203886670992, 0.2168876861105673], [0.07197979735792615, 0.020262694742996246, 0.01653928975429153, 0.02186053683544742, 0.03023737659532344, 0.030817196166026406, 0.020521264559647534, 0.054905725264688954, 0.011256108355155447, 0.03157129242026713, 0.07509045739425346, 0.05847782675118651, 0.02432348748698132, 0.0603258672344964, 0.07151686048018746, 0.03397980653971899, 0.028723341529257596, 0.07827568100765347, 0.018411520541121718, 0.03688203440106008, 0.07948696991661564, 0.03622100346547086, 0.022053174252505414, 0.039375661726808175, 0.07032173554762267, 0.021041710460849572, 0.03642915362433996, 0.038531676545972005, 0.04987193053239025, 0.025966071807488333, 0.04972889269993175, 0.049561757332412526, 0.08873663100530393, 0.027693010488292202, 0.01043401096467278, 0.06391711242031306, 0.06209013779880479, 0.01306260155615746, 0.03184849570970982, 0.12005181197309867, 0.05156157443707343, 0.059075496828882024, 0.05787936628621537, 0.03349659418745432, 0.012468619024730287, 0.026600003220664803, 0.05122219772601966, 0.07124133815523237, 0.015184320127445972, 0.06620561383897439, 0.04335830075433478, 0.04272338228474837, 0.0274138609165675, 0.042490603955229744, 0.03150876276777126, 0.06944974171346985, 0.053109920845599845, 0.019290490563435014, 0.03921022958820686, 0.03170387339196168, 0.06767146682250313, 0.044417074605007656, 0.054293208522722125, 0.0669264915632084, 0.061599221953656524, 0.03249937035434414, 0.0724747430649586, 0.022959256784815807, 0.025689323083497584, 0.08746981460717507, 0.024357392503588926, 0.02783088853902882, 0.02512335569917923, 0.0752578784886282, 0.015031561088107992, 0.03867200553941075, 0.019547184601833578, 0.0036829122518611257, 0.06152306646981742, 0.03037561273231404, 0.04143864302022848, 0.06728789521730505, 0.029479795957740862, 0.048620732632116415, 0.019959091405326035, 0.040851132944226265, 0.03532530914526433, 0.020338052418082952, 0.020161549291515257, 0.03173326615069527, 0.0392985043436056, 0.038923849642742425, 0.061331540418905206, 0.029293431543919723, 0.024091933701129165, 0.05019788921345025, 0.027827719568449538, 0.01754495366185438, 0.010476069401192944, 0.04547194475890137, 0.031650806122343056, 0.03485964858555235, 0.07198865117970854, 0.013835429617756745, 0.03198705097020138, 0.04490963801799808, 0.049240262669627555, 0.010064927009807434, 0.033789920635172166, 0.028291680609981995, 0.029288717050803825, 0.092306539445417, 0.026906491657427978, 0.042246159064234234, 0.02201782575866673, 0.061757440416840836, 0.025332270270155277, 0.044340462700347416, 0.029658740750164725, 0.05745164060499519, 0.02802022896503331, 0.025891792101901956, 0.022438137384597212, 0.049562503190827556, 0.027686472167260945, 0.012077094379492337, 0.033258212642977014, 0.03471497802820522, 0.02478220525517827, 0.05771460579126142, 0.10498484116396867, 0.04815111642528791, 0.026324690552428365, 0.0408713972865371, 0.04156019196670968, 0.04228496596624609, 0.10362797256675549, 0.046737529191887006, 0.009159833389276173, 0.035351217520656064, 0.013613284409075277, 0.039846328072599135, 0.03391099831787869, 0.031556519970763475, 0.025205416823155247, 0.007627372651768383, 0.019405419552640524, 0.008992344573925948, 0.05331242697138805, 0.03943423573218752, 0.07302954298211262, 0.06280598376179114, 0.04001270644948818, 0.01977713905944256, 0.03833959017356392, 0.0833024104940705, 0.047490074357483536, 0.036593457698472776, 0.04767834238009527, 0.035856256436090916, 0.008601873778388835, 0.053535063852905296, 0.043212476157350466, 0.013733042924286565, 0.018930625010398217, 0.02914933986176038, 0.0316405496414518, 0.047079354990273714, 0.03872627508826554, 0.061099956947145984, 0.039048396865837276, 0.024184414578485303, 0.019564910799090285, 0.02579244079242926, 0.05903649696847424, 0.054167997077456675, 0.008300097979372367, 0.02964421692013275, 0.03429340104048606, 0.051166388220735826, 0.0508430901390966, 0.05409078403317835, 0.02274840520840371, 0.05897011928027496, 0.018129250238416716, 0.024406908596574795, 0.03783546409977134, 0.04668176050472539, 0.07963119147461839, 0.0309981484679156, 0.03903716446075123, 0.014160540395096177, 0.0241730838388321, 0.017897379184432793, 0.037682321926695295, 0.007888632753747515, 0.07905283579020761, 0.03006012204423314, 0.028825772751588374, 0.04560149405733682, 0.020495868266152684, 0.03072451305342838, 0.03775226192374248, 0.07175371691118926, 0.03423971778829582, 0.02440882148221135, 0.006861723477413761, 0.05135747269378044, 0.03542011108947918, 0.029161885868234094, 0.050029692574753426, 0.044448159460444, 0.040092220151564106, 0.025168465290335007, 0.029953078374092, 0.015333174542320194, 0.0941485351359006, 0.02075020041957032, 0.031988052869564854, 0.02628412847116124, 0.026513298107602168, 0.029269727347127628, 0.030189495082595386, 0.09733570317621343, 0.06337890692520887, 0.04244715491950046, 0.04234332103806082, 0.057971392598119564, 0.03509719892463181, 0.03044731533009326, 0.0031712487407276058, 0.017336308119411115, 0.004103210194443818, 0.03150053606077563, 0.03339187343954109, 0.008629016901977593, 0.05544413856114261, 0.044973451585974544, 0.006455731127061881, 0.07021263241767883, 0.04237500703311525, 0.03664764190034475, 0.029256146044644993, 0.009808050217543496, 0.03068447418627329, 0.03385776035429444, 0.02372208811721066, 0.012931609708175529, 0.004808827043234487, 0.060833470270154066, 0.018209261179435998, 0.10251742278342135, 0.027875675295945257, 0.05224048742093146, 0.06958739526453428, 0.038109873203211464, 0.03388467805052642, 0.04565655399346724, 0.026471305536688305, 0.035997201412101276, 0.03742775043065194, 0.028837079371442087, 0.0517368214786984, 0.00965084385825321, 0.04457487004401628, 0.02204572308983188, 0.008139393321471289, 0.03412174599361606, 0.06763669720385224, 0.06248876758036204, 0.02904210879933089, 0.054758494297857396, 0.03005178030434763, 0.07134402912924998, 0.015586264526064042, 0.05778246035333723, 0.004573238293232862, 0.06312627985607833, 0.08756870578508824, 0.044425071246223524, 0.020915374661854003, 0.04386315784358885, 0.027828853199025616, 0.03991562611190602, 0.08544179960153997, 0.015385035821964266, 0.030324222716444638, 0.034631998496479355, 0.019907705100195017, 0.018912707710114773, 0.023870719887781888, 0.04666246095439419, 0.01690810931904707, 0.054991532379062846, 0.05736863880883902, 0.03524174331687391, 0.03612833890656475, 0.025733807415235788, 0.03746305810636841, 0.030672414286527783, 0.10306566953659058, 0.08080235988018103, 0.07936050795251504, 0.04202604919555597, 0.0027365893129172036, 0.011267740592302289, 0.0017839568431554653, 0.09938597519067116, 0.0065553227068448905, 0.06911024625878781, 0.018462329826434143, 0.10628122472553514, 0.07260413651238196, 0.05358380440156907, 0.03637650566815864, 0.015376298888440942, 0.009136904736806173, 0.12303015450015664, 0.040012669342104346, 0.05808756468468346, 0.05445643277198542, 0.010876767919398844, 0.03725602859049104, 0.03235156422306318, 0.04642587911803275, 0.031054616629262455, 0.020549126638798043, 0.06440516357542947, 0.031080899789230898, 0.0174428545506089, 0.060978337496635504, 0.020006570302939508, 0.03077389184909407, 0.057315014928462915, 0.07896955197793432, 0.04395326570374891, 0.05687807919457555, 0.007371548317678389, 0.06372188305249438, 0.023479682276956737, 0.020449105541047174, 0.07166591341956519, 0.0802270247368142, 0.022277625685092062, 0.03515819233143702, 0.08132384478813037, 0.009795221267268062, 0.06811516723246314, 0.025160912082355935, 0.03291501387138851, 0.027111307717859745, 0.03882953751599416, 0.126963670772966, 0.11000713260727935, 0.15200858702883124, 0.10876085143536329, 0.15392926521599293, 0.1779789465945214, 0.08567387660150416, 0.1371204070164822, 0.1343917823396623, 0.0874437355378177, 0.11736393120372668, 0.15107762214029208, 0.18835991533705965, 0.09664238881669007, 0.14210247405571863, 0.1477927280939184, 0.14198279532138258, 0.25183816615026444, 0.07345591424382292, 0.34380973724182695, 0.13472500664647669, 0.11435685271862894, 0.08666825058753602, 0.1297629182226956, 0.1504133702837862, 0.113803099229699, 0.1520717141102068, 0.21702438971260563, 0.09346803766675293, 0.11074757334426977, 0.10170556517550722, 0.10195229959208518, 0.12917760119307786, 0.12188266060547903, 0.167313750134781, 0.15248492709361017, 0.1567581095150672, 0.06365077046211809, 0.20618438778910786, 0.2442519474425353, 0.17983165889745578, 0.2263370220316574, 0.22639820468612015, 0.11599558900343254, 0.14574365835869685, 0.07389997088466771, 0.2033625790500082, 0.1211452997813467, 0.08319778993609361, 0.25277843757066876, 0.08361405314644799, 0.14453098905505612, 0.126958490582183, 0.06814362859586254, 0.1208127879363019, 0.21483680553501472, 0.19205729506211355, 0.1731860826839693, 0.12872655352111906, 0.1679570140549913, 0.1229622405662667, 0.12997508340049535, 0.13385436352109537, 0.2237310298369266, 0.14503413549391553, 0.11370817112037912, 0.17897483456181362, 0.08962098901974969, 0.13966508297016844, 0.38078193145338446, 0.20892086438834667, 0.11438077213824727, 0.2308992709731683, 0.16013805783586577, 0.09958600625395775, 0.152701411570888, 0.06309196294751018, 0.09798159429919906, 0.18322889925912023, 0.06654297932982445, 0.11604540937696584, 0.1551743218442425, 0.13972313376143575, 0.12789922213414684, 0.08342221539351158, 0.19214261235902086, 0.18917909794254228, 0.10275796026689932, 0.1983461802592501, 0.11075010406784713, 0.08154321621987037, 0.17618698650039732, 0.11886824227985926, 0.1796974043827504, 0.16053773404564708, 0.14176896773278713, 0.15811272198334336, 0.11943059726036154, 0.08033464357140474, 0.11902102822205052, 0.09681115319835953, 0.131859470566269, 0.1522766359266825, 0.1362727556261234, 0.12777939497027546, 0.06791954452637583, 0.11539733633981086, 0.15960702148731798, 0.1467491200310178, 0.11661444368655793, 0.1824497480993159, 0.17284840549109504, 0.13816259015584365, 0.1949681615224108, 0.16493050614371896, 0.1377764655626379, 0.11788668518420309, 0.17857509898021817, 0.1490909670246765, 0.13150150305591524, 0.17282223736401647, 0.08627108283690177, 0.13596531352959573, 0.12668024457525462, 0.139751186943613, 0.22374550171662122, 0.2419050390017219, 0.11997942288871855, 0.12086262315278873, 0.12629983451915905, 0.17893125565024093, 0.20203011226840317, 0.17874843499157578, 0.13599439087556675, 0.11815646328614093, 0.19337851088494062, 0.2230803741258569, 0.128634809225332, 0.08001438458450139, 0.14834179863100871, 0.08956232966738753, 0.22046893456717953, 0.07550232709036209, 0.10386591253336519, 0.10662417116691358, 0.09793867589905858, 0.1485076834796928, 0.15522649482591078, 0.26472407625988126, 0.10696909172111191, 0.16099218075396493, 0.21266455412842333, 0.1423315008287318, 0.2014711414813064, 0.11441222435678355, 0.10034269260358997, 0.15928990178508684, 0.11821698542917147, 0.15656244970159605, 0.16162484680535272, 0.13519324245862663, 0.09851079754298553, 0.11058721007429995, 0.07242048464831896, 0.18776223412714899, 0.17830638214945793, 0.14482113911071792, 0.09708010009489954, 0.2118354564299807, 0.1613900312804617, 0.15993231965694577, 0.17618394369492307, 0.1411637314595282, 0.09407423131051473, 0.20625094359274954, 0.08254355707322247], [0.056068299600156024, 0.025061827946046833, 0.04265067407686729, 0.07724532770225778, 0.0285976087252493, 0.04884996720647905, 0.016228689819399733, 0.017293597520620096, 0.09469911965425126, 0.055235506006283686, 0.018839049553207587, 0.03351739658683073, 0.031015648310130928, 0.03659932437585667, 0.010580749330983963, 0.02356492721446557, 0.008044267615332501, 0.047875200762064196, 0.05862035621248651, 0.0557697669864865, 0.019934383453801274, 0.05633607761410531, 0.02405021386948647, 0.058150161130470224, 0.049322889681207016, 0.01651326263527153, 0.025213010849256534, 0.029326483090699185, 0.03227920111385174, 0.05498259692103602, 0.060167967894813046, 0.047965468183974735, 0.013511101806216175, 0.02214214106061263, 0.03173574121319689, 0.02722643708693795, 0.036039681945112534, 0.005097698749523261, 0.04533389044809155, 0.01911857947561657, 0.04522958159213886, 0.04274850398360286, 0.025005506358866114, 0.036008285387651995, 0.03897235270414967, 0.04436069735675119, 0.03830856840068009, 0.0304663180213538, 0.0971086802019272, 0.017089594111894257, 0.021111450078024063, 0.010906946426985087, 0.04087378329131752, 0.029960946994833648, 0.05889556683541741, 0.07264837593538687, 0.04643105188733898, 0.023293442172871437, 0.021713365240429994, 0.015310564085666556, 0.023227359488373622, 0.06464294026955031, 0.010401772069599247, 0.06283707232796587, 0.1120071834884584, 0.01016250736938673, 0.03237162818550132, 0.029510715685319155, 0.04954792369971983, 0.025057102320715785, 0.016397365143347997, 0.08906045230105519, 0.046254721310106106, 0.015968492843967397, 0.027891714962606784, 0.015276081121555762, 0.031730813352623954, 0.011716829922079341, 0.03450243435509037, 0.13302459788974375, 0.024353594562853687, 0.017639210127526894, 0.0706551899202168, 0.006600051019631792, 0.06045124937372748, 0.053839652391616255, 0.08309509154059924, 0.04585886716085952, 0.035986239890917204, 0.03812905772065278, 0.005861947583980509, 0.016925442178035155, 0.041540480524417944, 0.045063117868267, 0.05226310808211565, 0.005879778145754244, 0.05119267509144265, 0.021552111393248197, 0.02887245198508026, 0.04043428343720734, 0.037894509368925355, 0.011046384843211854, 0.06776787180569954, 0.054917696106713265, 0.03773567121243104, 0.049725938952178694, 0.0805148073413875, 0.006988483692111913, 0.023721232792013325, 0.026904226251645014, 0.04015382954094093, 0.01778745969204465, 0.03641797688032966, 0.04715663853858132, 0.06519304981338792, 0.01275595262995921, 0.046197594492696226, 0.055548139425809495, 0.031449428061023355, 0.048885824071476236, 0.040914018827606924, 0.0320130075851921, 0.060716392763424665, 0.030354585833265446, 0.028533485310617834, 0.021011913231632207, 0.03414210310438648, 0.03770510586036835, 0.016149248476722278, 0.04129104840103537, 0.030276697434601374, 0.026068916777148843, 0.031229911910486408, 0.06277554086409509, 0.012559542319650063, 0.03941459108318668, 0.020462811153265648, 0.004792113413714105, 0.02571022752817953, 0.027453805159893818, 0.04884390757069923, 0.03212745417840779, 0.04238039873598609, 0.059683081999537535, 0.04552562430035323, 0.058922332391375676, 0.06178986113809515, 0.05452931538457051, 0.03313241119030863, 0.021594328463834245, 0.01484015563619323, 0.05435976061562542, 0.077802695450373, 0.035367845339351334, 0.045024956634733826, 0.030293956078821793, 0.1079521702195052, 0.0505784588312963, 0.01786447235645028, 0.024749986769165844, 0.027936082406085916, 0.020249300832801964, 0.0186272665814613, 0.11625029408605769, 0.05986544994811993, 0.04322547116316855, 0.038896939367987216, 0.0055922483352333074, 0.02118665746820625, 0.10981934698065743, 0.06665685446932912, 0.04243912859237753, 0.04821626585908234, 0.0126641740098421, 0.06800960414693691, 0.058763553606695496, 0.02554450780735351, 0.05676063061400782, 0.04511149105383083, 0.07515894278185442, 0.032284782064380124, 0.05250525602605194, 0.036569208023138344, 0.017392791123711504, 0.07330460517550819, 0.08231637824792415, 0.0488796790887136, 0.07432246813550591, 0.01771258255757857, 0.04412546993989963, 0.07269660069141537, 0.05234290751104709, 0.018368641103734262, 0.016551106600672938, 0.054742103966418654, 0.05068243001005612, 0.007228157037388883, 0.023732225854473654, 0.020799161757167894, 0.05192150863877032, 0.03153735400701407, 0.02989382901432691, 0.05711675017664675, 0.10139480567886494, 0.039831522226450033, 0.04116596312087495, 0.057648602887638845, 0.05419000917754602, 0.048501454657525755, 0.009322424957645126, 0.026594867558742408, 0.04383717154269107, 0.05958680689218454, 0.04386153625091538, 0.01083157112589106, 0.04611780619597994, 0.027206254380871542, 0.08480796837829985, 0.022706245654262602, 0.02855723403627053, 0.019454982029856183, 0.056141675740946084, 0.023109732792363502, 0.0314519847597694, 0.053828876407351345, 0.03540036253980361, 0.011088448845839594, 0.05716551298974082, 0.020781958774023224, 0.022744460693502333, 0.04421076868311502, 0.04534599487669766, 0.03184078108461108, 0.04653947595215868, 0.03666847027488984, 0.034767310571623966, 0.057894413330359384, 0.032171619386645034, 0.02367710283579072, 0.03276897034083959, 0.02927128029114101, 0.00047243474455171963, 0.03864987469569314, 0.029240431067592, 0.033207961823791265, 0.010766614650492556, 0.02664383631781675, 0.042645219291443937, 0.01209776040923316, 0.03229950998502318, 0.07846274675102904, 0.007197669146989938, 0.012909114284411771, 0.015231427951221121, 0.04470202591619454, 0.04524978656263556, 0.02398423879640177, 0.012393365250318311, 0.060084825090598315, 0.06028378746123053, 0.04273489299521316, 0.03549664506863337, 0.022237327066250145, 0.02741800210060319, 0.07411182436044328, 0.07272813454619609, 0.008435291310888715, 0.024050449501373805, 0.0410152774566086, 0.020831927577091847, 0.04870219447184354, 0.016768858295108657, 0.09055532325874083, 0.037755642406409606, 0.026385027158539742, 0.09104684766498394, 0.08019917935598642, 0.021153546549612656, 0.020998125983169302, 0.011063497840950731, 0.04699964832980186, 0.038322383479680866, 0.04327615984948352, 0.03177312319166958, 0.050016712411888875, 0.04580649751005694, 0.035939981826231815, 0.01790517730114516, 0.05203418149903882, 0.014527176190313185, 0.057194920591427945, 0.04684113300754689, 0.011292789004073711, 0.01682068617810728, 0.09710283949971199, 0.002695246585062705, 0.021964446787023917, 0.02303308563568862, 0.035561957774916664, 0.055772535197320394, 0.04501958719629329, 0.05158333049621433, 0.03874696987622883, 0.01972574904357316, 0.04055425903061405, 0.04121673715417273, 0.06289610275416635, 0.028859189806098584, 0.008695878841535887, 0.09273645817302167, 0.1252628315705806, 0.01776457742380444, 0.0046789001771685435, 0.016105912618513685, 0.05894121633900795, 0.03250679925258737, 0.061143636048655026, 0.03825964973657392, 0.04542729344393592, 0.05430044075183105, 0.048563034360995516, 0.021728013380197808, 0.0533229283610126, 0.03711741024744697, 0.0422213342244504, 0.05002384816179983, 0.037821522855665535, 0.03410505138162989, 0.047715664986753836, 0.02564647889812477, 0.020274053313187324, 0.06010381293890532, 0.023209215833048802, 0.06409719455405138, 0.036405553328222595, 0.016491437927470542, 0.010810383737407392, 0.014226233452063752, 0.06473695553722791, 0.04791200757608749, 0.011970257583016064, 0.04087351611815393, 0.015245968479575822, 0.013453073279379169, 0.04347250243881717, 0.03998762185801752, 0.0474382056563627, 0.09949046216206625, 0.02914951983257197, 0.03154276797431521, 0.01948710032593226, 0.03443958186835516, 0.1445761858485639, 0.12873335159383714, 0.116651877615368, 0.1547556318109855, 0.05256169264612254, 0.11978280570474453, 0.1168822476756759, 0.18608656857395545, 0.17342992272460833, 0.19059462589211762, 0.1782921774429269, 0.17905034066643566, 0.10455803203512914, 0.15253566030878574, 0.10312687445548363, 0.15343355509685352, 0.09279513236833736, 0.10566381723037921, 0.1374376454623416, 0.15798823413206264, 0.11346295810653828, 0.18835460155969486, 0.10758790929685347, 0.14821358519839123, 0.14961023291107267, 0.07520583167206496, 0.15061790618347004, 0.1293597390758805, 0.16650099452817813, 0.10667226233636029, 0.14199833589373156, 0.15422794996993616, 0.07551388232968748, 0.12640326021937653, 0.12349966680631042, 0.09777167782885954, 0.14516791503410786, 0.16486650332808495, 0.10400977043900639, 0.08736419214983471, 0.10000765745644458, 0.1478449604474008, 0.09013137881993316, 0.15277819416951388, 0.12220173957757652, 0.1499545300612226, 0.1348124910145998, 0.10003612624132074, 0.17928925284650177, 0.11913438385818154, 0.09194420068524778, 0.11595132731599733, 0.16030084050726146, 0.07350050989771262, 0.16008454898837954, 0.19675172050483525, 0.1469329500105232, 0.06689614514471032, 0.12487183848861605, 0.15116994531126693, 0.15618629957316443, 0.1824845845112577, 0.095365790912183, 0.10773789734230377, 0.1969718118198216, 0.06971238777623512, 0.17456404311815277, 0.15192607505014166, 0.06142387843283359, 0.15414609108120203, 0.09496465267147869, 0.15475858555873856, 0.11313828334095888, 0.07349093619268388, 0.1442012083134614, 0.09945144745870493, 0.16466554458020255, 0.13666508457390592, 0.18663590628420934, 0.21479531947989017, 0.10414613265311345, 0.1220575328625273, 0.1615849489462562, 0.17898195917950943, 0.1845552062150091, 0.12998951075132936, 0.1971425354713574, 0.14433954464038834, 0.12959416868397966, 0.10932384466286749, 0.13060979777947068, 0.09277976248995401, 0.13461735070450231, 0.18218895740574226, 0.1556263491511345, 0.15290162817109376, 0.17557425453560427, 0.18012215034104884, 0.13514452788513154, 0.1568701144424267, 0.31516972405370325, 0.1302956318249926, 0.13937094016000628, 0.10282770730555058, 0.1663564538466744, 0.12145058222813532, 0.18610776431160048, 0.11986056793830357, 0.11652626169961877, 0.09846426488365978, 0.09511435870081186, 0.1914890919579193, 0.18026658712187782, 0.12849262857344002, 0.1693345737294294, 0.14182486629579216, 0.12971954711247236, 0.10783574209199287, 0.20102043519727886, 0.088774064934114, 0.0839792714396026, 0.10948196664685383, 0.24527323170332238, 0.20990967226680368, 0.12520657677669078, 0.08744346094317734, 0.07909283754997887, 0.0977633657748811, 0.11676283611450344, 0.13268706912640482, 0.17123693571193144, 0.1103062106994912, 0.09224699693731964, 0.19586571492254734, 0.12118927203118801, 0.12984629109269008, 0.08901170062017627, 0.131433789501898, 0.17424993653548881, 0.10880120942601934, 0.16346605581929907, 0.1623440472758375, 0.11646050741546787, 0.13806881237542257, 0.171570026432164, 0.24435443803668022, 0.18021579453488812, 0.09947547077899799, 0.04102765647985507, 0.20631910243537277, 0.13231554999947548, 0.11191972138476558, 0.19086064130533487, 0.0876260812219698, 0.10111054085427895, 0.1969259322504513, 0.21162042656214908, 0.18049316480755806, 0.0977013741794508, 0.1477874885313213, 0.05847020118380897, 0.08848323952406645, 0.15562191110802814, 0.17749462102074176, 0.10925771930487826, 0.10648820229107514, 0.11240030653425492, 0.09386096775415353, 0.132461812463589, 0.1867276505799964, 0.12930260854773223, 0.21750044776126742, 0.14772819093195722, 0.2008350467076525, 0.12698459933744743, 0.1648159185424447], [0.13965047750389203, 0.017237275933439378, 0.08256731322035193, 0.05834047376993112, 0.04479444556636736, 0.028351790861051995, 0.028502303975983523, 0.02925753015006194, 0.029114583230693825, 0.035158793471055105, 0.0761585563304834, 0.055944924970390275, 0.01867497183411615, 0.027698971789504867, 0.03553066882886924, 0.04446450897376053, 0.12863849027780816, 0.04624796776624862, 0.04407492597238161, 0.023877360254118685, 0.03414620347029995, 0.02255312017950928, 0.05364799275412224, 0.06168489548144862, 0.08842521099722944, 0.020005128681077622, 0.007746087985651684, 0.05372553976485506, 0.03956761822337285, 0.04706024468760006, 0.0576559167529922, 0.0021705662675230997, 0.05875551243661903, 0.058287068823119625, 0.038960745514486916, 0.05656036577420309, 0.05241245045908727, 0.032638007251080126, 0.04338349666795693, 0.0575844961713301, 0.024645316116220783, 0.06328405303065665, 0.08681948544108309, 0.03432328732742462, 0.03031483640370425, 0.017130512424046174, 0.021191349696891848, 0.04687301567173563, 0.057662648032419384, 0.049224703543586656, 0.030094047469901852, 0.08809955659671687, 0.04955575706844684, 0.031497099917032756, 0.04549086581391748, 0.0483709999389248, 0.06133707312983461, 0.015186214459390612, 0.0735423002333846, 0.04751036467496306, 0.02502034003555309, 0.02567366747825872, 0.03786962144658901, 0.027760469856730197, 0.043052146284026094, 0.005428300955827581, 0.04689647495979443, 0.05793731688754633, 0.02975942235934781, 0.031451309405383654, 0.020467510803428013, 0.03252290756790899, 0.05050628868048079, 0.04095376825716812, 0.03310972002509516, 0.013307524204719812, 0.04373958283395041, 0.005539707062780508, 0.031834198234719224, 0.042708231339929625, 0.04531123267952353, 0.07403645184240304, 0.09354674984933808, 0.02978968343086308, 0.011263670839980477, 0.008317421561514493, 0.045324439197429456, 0.037077252636663616, 0.049053378752432764, 0.03159843647154048, 0.050403638524585404, 0.052950785830034874, 0.012793615696864435, 0.0605682786408579, 0.018212806789961178, 0.04438004514668137, 0.09323964914074168, 0.02023650249611819, 0.11132927611470222, 0.02665036721737124, 0.04758146984386258, 0.01862296212493675, 0.07152581078116782, 0.017350638991047163, 0.10694994431105442, 0.011419096972531406, 0.006790772304157144, 0.04365716733445879, 0.015491366102651227, 0.06453811191022396, 0.028709626640193164, 0.0677904776239302, 0.025643154076533392, 0.05422461181296967, 0.04863293725065887, 0.05795484270493034, 0.007294429897228838, 0.007733525280855247, 0.036331145602161996, 0.0497592465399066, 0.014863259621051839, 0.025504669320071116, 0.034997179682250135, 0.025289856530434918, 0.02411128891253611, 0.025261508344556205, 0.0184871491001104, 0.011500739710754715, 0.05822871004056651, 0.02816390504449373, 0.036004967987537384, 0.029926368479209486, 0.022768413509766106, 0.03326787169498857, 0.024337649520020932, 0.03331278647237923, 0.01369038242046372, 0.03580764576327056, 0.08276155553176068, 0.04789798840647563, 0.0695669416745659, 0.11537579179275781, 0.041171466145897284, 0.034678178635658696, 0.037782574945595115, 0.04409145731187891, 0.022773315395170357, 0.04265883027983364, 0.04088405461516231, 0.03115977524430491, 0.05527790119231213, 0.03795247852394823, 0.019893188691639807, 0.02331465275347, 0.05005281047488097, 0.05875817674677819, 0.021734904221375473, 0.04637355770682916, 0.03009703832503874, 0.026755097242130432, 0.022600476622756105, 0.018824193612090312, 0.0196975659855525, 0.05123665105202235, 0.010066543036373332, 0.021273844977258705, 0.09358056209748611, 0.04418956923473161, 0.033364811024512164, 0.016957918560365215, 0.07015974697424099, 0.024708190867386293, 0.01960377521754708, 0.030722140036232304, 0.026446078081789892, 0.041000753626576625, 0.11477005828055553, 0.055872123994049616, 0.05805135158880148, 0.05387370954849757, 0.09318570242612623, 0.023270728743227664, 0.04367218469269574, 0.039894905348774046, 0.013062160905974451, 0.039045754820108414, 0.01455250940125552, 0.11832165051600896, 0.05617311682726722, 0.03215870601707138, 0.04565157047181856, 0.045110162609489635, 0.0679851726454217, 0.014316967499325983, 0.03351230174303055, 0.07829858368495479, 0.05437524181616027, 0.053998145449440926, 0.055663068415015005, 0.07904388548922725, 0.02508980320271803, 0.0697987069725059, 0.06004559887514915, 0.029569571706815623, 0.1553945615887642, 0.032184829615289345, 0.03816815777099691, 0.03512338560540229, 0.11895460600499064, 0.03619618604716379, 0.01767324316460872, 0.04734563757665455, 0.09740413661347702, 0.044949008952244185, 0.06319765219814144, 0.013155391352484003, 0.02614028169773519, 0.03437180152104702, 0.04098428908037022, 0.034259288222528994, 0.0380050930834841, 0.023350062474492006, 0.015105795337149175, 0.014314637155621313, 0.05918707502132747, 0.07431496502249502, 0.02917353944212664, 0.06018038773618173, 0.010414874686830444, 0.05226098182902206, 0.11787398703745566, 0.06951395975193009, 0.0299035474381526, 0.0186548429337563, 0.10550045568379574, 0.053825800205231644, 0.0562558069213992, 0.03121694659057539, 0.060635866029770114, 0.025016935433086473, 0.025397677600267343, 0.03201659957994707, 0.09978350659366697, 0.028196615203341935, 0.055549965109094046, 0.037613524837070145, 0.05789906659629196, 0.06698546261759475, 0.08969427610281855, 0.03215964483388234, 0.023780650990374852, 0.05946422264969442, 0.06945580505998805, 0.050645582377910614, 0.03681731170217972, 0.02020548072323436, 0.11079369782237336, 0.021692720547434874, 0.06252567458432168, 0.01675006526056677, 0.023624308305443265, 0.023017014427750837, 0.029254246146592777, 0.10115849843714386, 0.057735430455068126, 0.07878423770307563, 0.05799779450171627, 0.03493163691018708, 0.020577550894813612, 0.04941341685480438, 0.019544601927918848, 0.041857488904497586, 0.03685032243083697, 0.042378142607049085, 0.10861507136723958, 0.030595377502322663, 0.06825356293120421, 0.031116995996853802, 0.08808305865386501, 0.0423591065191431, 0.05915362271480262, 0.03444408670475241, 0.03952945698983967, 0.08410562950302847, 0.03480254403257277, 0.06748821571818553, 0.022420262757805176, 0.07821602717740461, 0.01881492975371657, 0.01982478494028328, 0.07738158601569012, 0.011523117318574805, 0.004170707597950241, 0.03286292623670306, 0.0017593529082660098, 0.030804891357547604, 0.061091500174370594, 0.019483682735881303, 0.06068478469387628, 0.012250557483639568, 0.018801819715008605, 0.03784801381698344, 0.045258109748829156, 0.0639292762207333, 0.050535518166725524, 0.02282828627357958, 0.06598364489036612, 0.03825435080216266, 0.08680467959493399, 0.018440275052853394, 0.027772054781962652, 0.03125894843833521, 0.008876932261046022, 0.05500577790371608, 0.0789306263322942, 0.075465783738764, 0.03618965143687092, 0.0528476013278123, 0.021895477148063947, 0.04263056929630693, 0.04433905261976179, 0.03075122665904928, 0.023032356475596316, 0.08925746282329783, 0.02866456714400556, 0.005716587756978697, 0.049045712366933, 0.032670954897184856, 0.02690458990400657, 0.014451417755481089, 0.04323545676015783, 0.022181693821039516, 0.020224047402734868, 0.02177224352635676, 0.04109702873392962, 0.05062193013145588, 0.044127963556093164, 0.049061423633247614, 0.07134514235076495, 0.04455077993043233, 0.028592881244549062, 0.132414938416332, 0.04421729587193113, 0.049643556849332526, 0.035328678495716304, 0.020420751789060887, 0.09103142583626322, 0.02982233236252796, 0.04966346867149696, 0.0738459276908543, 0.02824641516781412, 0.03858106276311446, 0.1996475807391107, 0.08932868673582561, 0.18633291707374156, 0.2382912251050584, 0.2088257804280147, 0.06334056015475653, 0.11865415493957698, 0.12326766402111389, 0.12580039881868288, 0.1417907275026664, 0.15067827247548848, 0.2626369195058942, 0.14265020872699097, 0.08132337723509409, 0.14576093555660918, 0.17133378598373383, 0.19938287150580436, 0.13036937161814421, 0.11126811572466977, 0.11195345941814594, 0.13090021500829607, 0.06270293655688874, 0.12968560127774253, 0.16466066124849021, 0.17188230733154342, 0.14117947983322665, 0.11408386853872798, 0.10354569065384567, 0.3067475650459528, 0.150472994428128, 0.1890643173828721, 0.10099458770127967, 0.2272218995494768, 0.23128462373279035, 0.12574237771332264, 0.17069360939785838, 0.21403123391792178, 0.23719514720141888, 0.15404036472318694, 0.19443771889200434, 0.06330045449431054, 0.1364863754133694, 0.18916839617304504, 0.11226623013499193, 0.13055573974270374, 0.17387298488756642, 0.09323874372057617, 0.13865332788554952, 0.229101566656027, 0.15231852274155244, 0.09601108089555055, 0.14180778205627576, 0.1117158385750372, 0.15674433525418863, 0.2136582601815462, 0.2183860377408564, 0.15529272408457473, 0.2023871149867773, 0.26772713230457157, 0.15569820388918743, 0.08721837497432716, 0.14102021494181827, 0.2398191884276457, 0.08954168311902322, 0.17096278636017814, 0.11646954677416943, 0.21164646110264584, 0.1362181335571222, 0.11455190397100523, 0.20086263975827023, 0.11486948380479589, 0.10347673029173166, 0.16514268616447225, 0.15444336575455964, 0.11434172032750212, 0.14036449778359383, 0.13789556542178616, 0.08893177131540142, 0.16760913975303993, 0.13913667382439598, 0.22224562126211822, 0.13987150392495096, 0.11844848355394788, 0.06030763266608119, 0.13612215901957825, 0.1343984913546592, 0.16508653527125716, 0.26597720745485276, 0.2082727022934705, 0.17235607956536114, 0.14483768900390714, 0.3108701657038182, 0.0893019768409431, 0.12854119471739978, 0.09790858923224732, 0.1046280685113743, 0.2256576155195944, 0.16041847091400996, 0.24056486872723326, 0.21405519044492394, 0.1356479711830616, 0.0844959843379911, 0.20511648181127384, 0.13863196887541562, 0.36663442966528237, 0.1449764854623936, 0.1886317046592012, 0.11223923080251552, 0.16556701652007177, 0.16330110607668757, 0.06968650908675045, 0.15529916592640802, 0.11107112004538067, 0.17705259786453098, 0.18923020223155618, 0.15189214405836537, 0.06299245578702539, 0.08879168351995759, 0.22388348181266338, 0.2188499690964818, 0.12480498582590371, 0.07189813142758794, 0.1440687943249941, 0.1540241710608825, 0.12511150765931234, 0.10719730213168077, 0.20983885653549805, 0.13400605850620195, 0.1964820537250489, 0.13003353495150805, 0.15570443792967126, 0.14015393564477563, 0.2053359497222118, 0.15927586035104468, 0.14304135023849085, 0.16915996122406796, 0.07905541846412234, 0.17436108057154343, 0.22146834031445906, 0.1410664655850269, 0.2045210122014396, 0.18533550028223544, 0.14793096052017063, 0.11849181013531052, 0.08688627873198129, 0.1836076023755595, 0.190014993713703, 0.18551303684944287, 0.20140590670052916, 0.14755457290448248, 0.1281347352778539, 0.1414719453896396, 0.16336378786945716, 0.07871515117585659, 0.12588571611559018, 0.15569728362606838, 0.12856249435571954, 0.13541038002585992, 0.15164331678533927, 0.10953223973046988, 0.10802387652802281, 0.15101149678230286, 0.08956011064583436, 0.18648664554348215, 0.08207020044210367, 0.19743506039958447, 0.12801508622942492, 0.13238025043392554, 0.06492805856396444, 0.10156845339224674, 0.20910994877340272, 0.07939908478874713, 0.23224180127726868, 0.15047663095174357, 0.11407518541091122, 0.17006296198815107], [0.05054890280007385, 0.0595307339244755, 0.05997728047077544, 0.031172885283012874, 0.013100899159326218, 0.019049845468543936, 0.09141682312474586, 0.058947060751961544, 0.07358645802014507, 0.0460071111592697, 0.023819764028303325, 0.0630208726215642, 0.0021456906370076467, 0.05969875244772993, 0.01766396817401983, 0.07811640869476832, 0.08425789594184607, 0.041513559117447585, 0.05699477820598986, 0.009846961020230083, 0.04618931212462485, 0.03242707774916198, 0.04846733441809192, 0.009445232772122836, 0.02766382553090807, 0.05004941143852193, 0.04359028869657777, 0.04071925701282453, 0.04317889026424382, 0.0682700534525793, 0.04917534701235127, 0.028489822907431517, 0.036155772395431995, 0.031797729097888805, 0.07074414374073967, 0.028941119198861998, 0.028418810506991576, 0.038589000032516196, 0.03558705349860247, 0.02986652540130308, 0.042590111115714535, 0.03716270352015272, 0.0395961129834177, 0.0328262455877848, 0.02206726021540817, 0.0073958504071924835, 0.026874341820075642, 0.03647377896413673, 0.045720764610450715, 0.010906046572927153, 0.04944843880366534, 0.019940845704695676, 0.03158612424158491, 0.03255743227782659, 0.042700026897364296, 0.024142657639458776, 0.03346226985740941, 0.02071356058877427, 0.060255251883063465, 0.04773330954776611, 0.027283443305350374, 0.033402924018446356, 0.014046792348381132, 0.013683069482794963, 0.03313683067972306, 0.05546041014895309, 0.01790687681932468, 0.023350361188931856, 0.09870339228655212, 0.011419723159633577, 0.025390883238287643, 0.019105801547993906, 0.026946458165184595, 0.03374862011696678, 0.04529588135483209, 0.025187740720866714, 0.06818868438131176, 0.009650432893977268, 0.14391846489161253, 0.021327632130123675, 0.018630418853717856, 0.05769607436377555, 0.03154070480377413, 0.022849834531371016, 0.051812828533002175, 0.040638270147610456, 0.1038617713493295, 0.07563054052297957, 0.030576040844607633, 0.011818258317362051, 0.035232021182309836, 0.052026036428287625, 0.09257974626962095, 0.015419836054206826, 0.05960245878668502, 0.018058180321531836, 0.08486896549584344, 0.05330981461156625, 0.027032124271499924, 0.03872629735269584, 0.05569535554968752, 0.020879530784441158, 0.04125558858504519, 0.06655431934632361, 0.02935941403848119, 0.03301404976809863, 0.05737393774325028, 0.014629317975050071, 0.05885450380446855, 0.14809114567469805, 0.0235073996373103, 0.024867387110134587, 0.018231844733236358, 0.045728579425485805, 0.028467256051953882, 0.03999623819254339, 0.008034380352910375, 0.03704013412061613, 0.06274403669522144, 0.024416690102952998, 0.036862987180938944, 0.008197717779694358, 0.01074619260180043, 0.09996680964832194, 0.053861182095715776, 0.04689408524427563, 0.049739434907678515, 0.054157128324732184, 0.020748541719513014, 0.011093119737779489, 0.035188126857974567, 0.02901718376961071, 0.04629390299669467, 0.021792042171000503, 0.01715841717668809, 0.02725962778640678, 0.027005468182323966, 0.009943032036972, 0.03337340509460773, 0.07015458162641153, 0.06768487743102014, 0.011197526000614744, 0.010280521837557899, 0.14205864281393588, 0.011052481586375507, 0.02788616740872385, 0.046513831039192155, 0.018493744937586598, 0.06528610028908588, 0.03325525889522396, 0.0526664950302802, 0.004853332711718394, 0.09693642030470073, 0.007986095297383144, 0.05962498296867125, 0.042092029834748246, 0.021409704386314843, 0.02878202129068086, 0.10365559530328028, 0.03506415479932912, 0.0205997299781302, 0.05799066988402046, 0.024384874232055154, 0.042664704378694296, 0.027937368176935706, 0.04479884279135149, 0.029463333266903646, 0.03315718779049348, 0.01608849997865036, 0.03852409550745506, 0.02849741322279442, 0.008188076353690121, 0.009493920442764647, 0.053863119101151824, 0.039838947413954884, 0.0613782845903188, 0.02930550072051119, 0.05669227881298866, 0.05808205052744597, 0.07391106599243358, 0.059591033423203044, 0.09014299343107268, 0.02714710706641199, 0.08770430358708836, 0.062442977068712935, 0.06843727416708134, 0.008496506434312323, 0.054771403956692666, 0.05379516805987805, 0.05850945337442681, 0.012173242394055706, 0.03958016794058494, 0.0443924093269743, 0.05001512050512247, 0.007041636772555648, 0.08440545716439374, 0.027577832879615016, 0.02753382723312825, 0.0755243466119282, 0.03828969187452458, 0.021723579047829844, 0.07231000854517333, 0.06426362117053941, 0.028148440542281605, 0.03677279397379607, 0.027332100362400524, 0.01253867498235195, 0.06363678839989007, 0.07092835221556015, 0.020007785569760017, 0.061470155051210895, 0.006676120228803484, 0.06677576137008145, 0.04115166193514597, 0.035246318657300435, 0.024757770042924676, 0.03823851337074302, 0.04729422158561647, 0.06969788621063344, 0.025839619120233692, 0.04808813777344767, 0.04874409241892863, 0.05779331797384657, 0.013590791768365307, 0.15476565080462024, 0.015133120286918711, 0.07285030689672567, 0.02474627603078261, 0.04656852732296102, 0.03228736844903324, 0.048552143343840726, 0.04716773364634719, 0.013054151277174242, 0.05663965312123764, 0.037051845210953616, 0.011819493065559072, 0.03442390028794762, 0.027540135488379747, 0.03854868657072075, 0.01659744630160276, 0.021191193845879752, 0.03307549959572498, 0.02595508431113558, 0.04311542179493699, 0.021712322522944305, 0.005981924105071812, 0.03578671719878912, 0.031994112505344674, 0.04631046031136066, 0.060367542537278496, 0.06360021536238492, 0.0383017925923923, 0.05910583211516496, 0.023009194046608172, 0.03902627344359644, 0.012724948483082699, 0.017394017522747163, 0.06799836803111248, 0.06925511348526925, 0.02992884168634191, 0.013539732008212013, 0.044690151553368196, 0.05710329503926914, 0.019155883528583217, 0.07178484258474782, 0.061188884792500176, 0.021495611690625083, 0.06974993302719668, 0.018534600167186, 0.05502940417500213, 0.030743237439310178, 0.04268045275239274, 0.028078871619072743, 0.060995781677775085, 0.040161258439184166, 0.022261656522459816, 0.016814439150039107, 0.09244624874554574, 0.030601657927036285, 0.08776419490459375, 0.022779660757805686, 0.019204870841349475, 0.03921950643416494, 0.0036980662116548046, 0.036019439867231995, 0.0471951968211215, 0.031221833633026108, 0.06082993022573646, 0.019955681236751843, 0.027111730742035434, 0.06024443508067634, 0.034596215846249834, 0.057525068696122617, 0.037825493345735595, 0.060158086198498495, 0.12100149382604286, 0.07738675878499635, 0.04347348207375035, 0.0354861251253169, 0.033757384881027974, 0.05549020366743207, 0.03370245482074097, 0.04896989084954839, 0.059599675732897595, 0.037595909961964935, 0.029765155450149905, 0.052784915824304335, 0.02760093964752741, 0.02503078205336351, 0.08545518794562668, 0.009451755322515965, 0.0283705133915646, 0.013570324263127986, 0.023239124384417664, 0.05876050337974448, 0.10546242061536759, 0.045429924357449636, 0.010369509982410818, 0.02490365401172312, 0.08131688344292343, 0.025707915738166776, 0.025336411454190966, 0.01822233225539094, 0.03274801951192785, 0.10295627696905285, 0.05518927391676698, 0.033635078943916596, 0.015974930975062307, 0.08003929848200642, 0.038797755041741766, 0.026684949443733785, 0.008907701703719795, 0.03666907883598469, 0.05277326410578098, 0.06188381332322024, 0.0348131159262266, 0.02276407009048853, 0.036028609101776965, 0.029894472827436402, 0.048549100538366474, 0.054135524405865, 0.0395488604408456, 0.011356817794876406, 0.04458027287910227, 0.03435913306020666, 0.019619441955001093, 0.047638707983423956, 0.018764330125122797, 0.057488952079438604, 0.03598443647206295, 0.010963646509480895, 0.014267021888372255, 0.14301032846560702, 0.17833459860412404, 0.1307329794508405, 0.15448142308741808, 0.14773685921682045, 0.19459633069345728, 0.12880620080977678, 0.1472560514230281, 0.15293091331841424, 0.1685003997408785, 0.10460449047968723, 0.15799142536707222, 0.10254141641780734, 0.20547008549328893, 0.1732512135640718, 0.26338625117205083, 0.19911078532459214, 0.1488695843727328, 0.12096646445570514, 0.20525345258647576, 0.18606452678795904, 0.07877148760599084, 0.13731395913055167, 0.13263627653941512, 0.1774155822931789, 0.15743425057735294, 0.19562172645237297, 0.13557222759118304, 0.12867913028458133, 0.15238647378282622, 0.17489946418209001, 0.1097695340286009, 0.11200290871784091, 0.13658816838869825, 0.19794068561168388, 0.10978793929098174, 0.15535043348791078, 0.1289507414912805, 0.12957168160937726, 0.14192073693266138, 0.1563049986725673, 0.1211675419472158, 0.15071643370902166, 0.11746080373995937, 0.16930341836996377, 0.16417811682913452, 0.09048328298376873, 0.11023239669157192, 0.2855764963896945, 0.12511400127550587, 0.1357024151366204, 0.10291298007359728, 0.16838686598930508, 0.13388649851549417, 0.12860026967246085, 0.10197475698078051, 0.06998595825280063, 0.09817014433792792, 0.2240080141928047, 0.10943913730443455, 0.11878961173351854, 0.09629872249206528, 0.11683685050229542, 0.08639551873784512, 0.1209242882032413, 0.1454292400740087, 0.13616040931083262, 0.10249046055832878, 0.19982891710242257, 0.10514414316276088, 0.10665405745385215, 0.13493690465111285, 0.10564792042714544, 0.15866060508415103, 0.15894153766566887, 0.10098556318553165, 0.14231998269679025, 0.12943949026521295, 0.2561249298742041, 0.10025635856436566, 0.2195098125957884, 0.15994695480912924, 0.17871340562123805, 0.1506359552149661, 0.1618539626360871, 0.21787597448565066, 0.15727237332612276, 0.175209978769999, 0.170759690226987, 0.08628012219560333, 0.13943547732196748, 0.20649620855692774, 0.22949223319301382, 0.05856502539245412, 0.23728151834802702, 0.1046824902005028, 0.19399173266720027, 0.18179941893322393, 0.12611508427653462, 0.21198468748480082, 0.15458881185622886, 0.13709432794712484, 0.10801663316669874, 0.18762515945127234, 0.07931108833872713, 0.1030523628287483, 0.1419714849907905, 0.09017527685500681, 0.16163602354936302, 0.21084081527078524, 0.10908217169344425, 0.14853552886052057, 0.10785653706989251, 0.19398416276089847, 0.14586633536964655, 0.12458232667995617, 0.12771984504070133, 0.10715414624428377, 0.2056855903356336, 0.1924376012175344, 0.13853309996193275, 0.11659287687507458, 0.12867092213127762, 0.1570337134762667, 0.3211365616880357, 0.133409594418481, 0.11095262874732725, 0.10180269004194997, 0.17864658264443278, 0.06440612094593234, 0.15579637518385425, 0.07463582514901645, 0.09131723432801664, 0.1189535744197201, 0.11144371528644115, 0.07033769172267057, 0.10859845468075946, 0.09893293114146218, 0.13245403475593776, 0.23228275298606604, 0.10422041421406902, 0.05591106819338165, 0.10871011822018772, 0.253318928880617, 0.07726959593128413, 0.08517578418832272, 0.20064873795490712, 0.14887011871905997, 0.2138461868162267, 0.11177116568433121, 0.12421927545801736, 0.12603910319739953, 0.2915273333201185, 0.16540614858968183, 0.10576337634120136, 0.15473136358195916, 0.09606271953089163, 0.17299879429629073, 0.0979826258844696, 0.07279791127075441, 0.1433442800771445, 0.24195360514568165, 0.08903487047064118, 0.09356793074402958, 0.127548438613303, 0.15570605581160635, 0.15328626846894622, 0.11714047053828835, 0.11978490598266944, 0.1770961470901966, 0.18095448380336165, 0.05545257678022608, 0.11039001401513815, 0.16479436657391489, 0.10357565857702866, 0.1859811836038716], [0.011903293598152231, 0.00975297172772116, 0.10738182973000221, 0.04311050506657921, 0.006514872875413857, 0.053476890607271343, 0.03311983178718947, 0.009548038779030321, 0.03790280286921188, 0.0007158916514526936, 0.040064860877464525, 0.043106234006700106, 0.03140185268421192, 0.06017818726832047, 0.02111689744197065, 0.04416966112330556, 0.03436893312027678, 0.052500376405077986, 0.004779608689204906, 0.0633765765815042, 0.009135100390267326, 0.08551886421628296, 0.05919137205637526, 0.035068147553829476, 0.029029377255938016, 0.05361309325962793, 0.03351127015776001, 0.05874959380889777, 0.005169267296878388, 0.034035582648357376, 0.02732549710344756, 0.051949057160527445, 0.020560410994221456, 0.0026875936509895837, 0.02702095494896639, 0.033701946449582465, 0.028744012197421398, 0.006652549154750886, 0.029485469676728826, 0.024987676260934677, 0.026512650583754294, 0.020661797643697355, 0.018726226408034563, 0.04891428914561402, 0.03994073296780698, 0.03082906867348356, 0.011775181283155689, 0.07496682301280089, 0.02744453388004331, 0.09137230168562382, 0.0075733475478045875, 0.04312465411203448, 0.017610490867809858, 0.040057528458419256, 0.06411140668205917, 0.07698441826505587, 0.028070633779861964, 0.07800983628840186, 0.024509132017556112, 0.043216628473601304, 0.04271829115168657, 0.07946384459501132, 0.008929054220061516, 0.04995045717805624, 0.012116020025132457, 0.050091602533939295, 0.061256190165295266, 0.026071419670188334, 0.049804020309238695, 0.07715279672993347, 0.035942460599471815, 0.03270897512265947, 0.09205780865158886, 0.1473192378762178, 0.035957492800662294, 0.0373145543562714, 0.028351249093248043, 0.010168254375457764, 0.06919009392731823, 0.042005558498203754, 0.03642083043814637, 0.018627997596922796, 0.04969903609890025, 0.025663047345005907, 0.03358892477990594, 0.03948248275264632, 0.07514862692914903, 0.04803574956895318, 0.016419050698459614, 0.019472151616355404, 0.009854531854216475, 0.0983121246099472, 0.040416983974864706, 0.04874801838013809, 0.04201841991744004, 0.058089305020985194, 0.03498132740787696, 0.02313886765477946, 0.06404184518032707, 0.007959779668453848, 0.09372436063131317, 0.027074792196799535, 0.03866326675051823, 0.030068011074035894, 0.05486557878612075, 0.02315299258043524, 0.059128790453542024, 0.09744098424562253, 0.09713389095850289, 0.05824735650094226, 0.013399659055721713, 0.054499199031852186, 0.048235639624181204, 0.01616928831936093, 0.013961860968265682, 0.026908521431323607, 0.020670484482252505, 0.02294878137035994, 0.004897864819213282, 0.0504173830995569, 0.02468632534146309, 0.037935260697850026, 0.05761958491348196, 0.016029337821237277, 0.0437968395272037, 0.04004543887276668, 0.04852561527513899, 0.07289905857760459, 0.007334638530664961, 0.03768700858927332, 0.03280917619122192, 0.04871993551205378, 0.009121668445004616, 0.0270684041606728, 0.059583036781987175, 0.03545068757375702, 0.040190461950260215, 0.044628742543864064, 0.03724419504578691, 0.060367679834598675, 0.017094403228838928, 0.019743061493500136, 0.018315325214643963, 0.03523785446304828, 0.022341827025229577, 0.08995521522592753, 0.017698808296700008, 0.053293075470719486, 0.021416309500637, 0.03551133217115421, 0.025865811367111746, 0.02311008531250991, 0.017671723617240787, 0.07251979142893106, 0.00584163036364771, 0.05683507915819064, 0.0360063149855705, 0.016290314051730093, 0.07269553942023776, 0.08400667895330116, 0.07045812002616003, 0.007143045686461846, 0.04944528467603959, 0.06375844866852276, 0.08826907054753974, 0.031456463620997965, 0.05798660662549082, 0.045700889895670116, 0.031540786440018564, 0.05168130141100846, 0.033530016808072105, 0.05993137863697484, 0.08735703042475507, 0.01378716311592143, 0.0342862430261448, 0.012529071591416141, 0.027401506013120525, 0.03159927509841509, 0.07299802397028543, 0.02163786284654634, 0.04410084547998849, 0.018605812947498634, 0.022483495595224667, 0.052108088275417686, 0.027648349896480795, 0.008260843005700735, 0.04138359421631321, 0.00740210346521053, 0.02093179282383062, 0.08782900666119531, 0.017143644727184437, 0.02882440348912496, 0.045748595148324966, 0.041571097826818004, 0.01842042816861067, 0.014350290857692016, 0.04287010116968304, 0.018167739872296806, 0.05986815878713969, 0.043797396137961186, 0.0217248722401564, 0.021558868647844065, 0.05384061347285751, 0.0954452452424448, 0.019282642351754475, 0.016062938557297457, 0.03854795184452087, 0.03380266702151857, 0.03663020885142032, 0.10028991106082685, 0.023499866838392336, 0.06077843630919233, 0.07107481505954638, 0.04713761358289048, 0.021735924674430862, 0.03728884636075236, 0.02597863265691558, 0.035225571918999776, 0.011026629799744114, 0.021152466724743135, 0.03206214889360126, 0.040100929254549555, 0.05515282704436686, 0.037568298357655294, 0.048620721499901265, 0.06854444771306589, 0.03629475068009924, 0.010505652335268678, 0.021408502107078675, 0.027092156597063877, 0.061791775879100896, 0.04300804044760298, 0.03688597149448469, 0.03533263414283283, 0.03754075354663655, 0.10991143266437575, 0.11531945536262356, 0.012041418412991334, 0.03222771090804599, 0.0633220880990848, 0.05626377016596962, 0.051626256317831576, 0.04429182234161999, 0.0649024841550272, 0.049064132472267374, 0.03587337036151439, 0.036628999150707386, 0.007815966291673249, 0.0387630225304747, 0.030349572625709698, 0.035177143072360195, 0.04765756595588755, 0.06172193607199006, 0.05625335412332788, 0.06138287477369886, 0.011676189915306168, 0.039032262575346977, 0.0021323572582332417, 0.014279314636951312, 0.03542500555340666, 0.04014133919554297, 0.022212528201634996, 0.08507058475515805, 0.1171724422601983, 0.0031588901265422464, 0.037456582867889665, 0.034475895154173486, 0.027137989782204386, 0.027025665731343906, 0.10633784317178652, 0.12132760835811496, 0.04810040918528102, 0.03121489455224946, 0.04980292564141564, 0.0296466845611576, 0.04525470329099335, 0.027628736788756214, 0.02969582401419757, 0.03635560307884589, 0.03779134713113308, 0.019801186499535106, 0.10169745350140147, 0.03362165720318444, 0.023022059176582843, 0.13019622856518254, 0.03785805507504847, 0.013764209415967343, 0.024023351834330242, 0.026810366834979504, 0.0629126006970182, 0.023975292206159793, 0.039581422170158476, 0.03506812900013756, 0.0233211372687947, 0.03818543867964763, 0.053409128813655116, 0.03908389378921129, 0.08840667214826681, 0.05639333801809698, 0.036741022631758824, 0.05765053618233651, 0.043178162959520705, 0.05098036148410756, 0.05045504338340834, 0.06171180204546545, 0.038122486002976075, 0.034750003687804565, 0.06752089990186505, 0.034653012407943606, 0.042473883368074894, 0.023624091227247845, 0.07423442715662532, 0.054318029651767574, 0.07511901523685083, 0.055446498590754345, 0.034752378560369834, 0.03607326783821918, 0.013876383181923302, 0.04239963891450316, 0.05110349862661678, 0.0066340590092295315, 0.059361784005886875, 0.012665418962569674, 0.024268763372674584, 0.03430755008594133, 0.03746919937839266, 0.031407897477038205, 0.03455894890066702, 0.01979171112907352, 0.02193097592680715, 0.04825649026315659, 0.009433620944037102, 0.06432128604501486, 0.060294118156889454, 0.032593949654255994, 0.014570834882761119, 0.009860912468866445, 0.019335442448209506, 0.022532618349941913, 0.04386763299407903, 0.0625742926786188, 0.04071000985277351, 0.023499213748436887, 0.056005298683885485, 0.03261180201661773, 0.022338867711368948, 0.04065252680447884, 0.02932580217020586, 0.009184704613289796, 0.032098681112984195, 0.06378801583196037, 0.04646362103812862, 0.0983755337074399, 0.06350131676299497, 0.218850058154203, 0.09536311918054707, 0.22619837400270626, 0.1473273866577074, 0.14763499202672392, 0.1858589073526673, 0.08181452314602211, 0.050298613496124744, 0.18050428217975423, 0.07318985430174507, 0.11360777338268235, 0.24780800740700215, 0.11316382064251229, 0.19185560900950804, 0.13493619218934327, 0.261117565096356, 0.10705265012802556, 0.1055525618721731, 0.1642513371189125, 0.1700640158378519, 0.10198188159847632, 0.0945649690402206, 0.09727238313644193, 0.23439159529516473, 0.14225059188902378, 0.21185905672609806, 0.11103042066679336, 0.11387551057850942, 0.13580109109170735, 0.13044950872426853, 0.12289461606997065, 0.3032326645916328, 0.08857372216880322, 0.2542472071945667, 0.16169650858500972, 0.058766225338331424, 0.16487068904098123, 0.09384570919792168, 0.10672206044546328, 0.1010010889149271, 0.13322358252480626, 0.1594572264002636, 0.12988580303499475, 0.11269890223047696, 0.133442041114904, 0.12997355457628146, 0.16961970686679706, 0.1742372606531717, 0.11235536949243397, 0.16994743928080425, 0.16585927427513525, 0.1433719028136693, 0.1754202737356536, 0.14472090464551002, 0.19347849301993847, 0.15801587171154097, 0.15476069325814024, 0.179241131991148, 0.18815517163602635, 0.10375936239142902, 0.11430677259340882, 0.2288251166464761, 0.1644628492067568, 0.22455496218753979, 0.16817950992845, 0.21034372475696728, 0.09714199521113187, 0.1821787899825722, 0.13672458997461945, 0.12931130651850253, 0.15006702480604872, 0.1445084426086396, 0.0830075032718014, 0.16321895032888278, 0.1682716846698895, 0.115242472384125, 0.2654955832986161, 0.1302902735187672, 0.1207234185130801, 0.10715955650084652, 0.09410428829141892, 0.1114428395521827, 0.15604854212142527, 0.07395764318061993, 0.1944306239602156, 0.16018211172195151, 0.11873434399603866, 0.16256513306871057, 0.14175644028000534, 0.12306527292821556, 0.12649837386561558, 0.2857100829714909, 0.14691611810121685, 0.16022169787902385, 0.10170208450290374, 0.16539388831006363, 0.183981214358937, 0.10749329288955778, 0.2671845629811287, 0.1869657909264788, 0.15603948791977018, 0.12583379546413198, 0.1229338905250188, 0.14263849763665348, 0.06515650646178983, 0.20130927907302976, 0.2037978041335009, 0.13165555807063356, 0.10764100996311754, 0.10753125374321826, 0.1364709238987416, 0.121338221069891, 0.1311088030342944, 0.1595556500251405, 0.07292510796105489, 0.14394616184290498, 0.11000952974427491, 0.14074529375648126, 0.14614219166105613, 0.23105472122551873, 0.15809822041774169, 0.10909435033681802, 0.1990563710569404, 0.07946972240461037, 0.11467669610283338, 0.15890199603745714, 0.18017470923950896, 0.2059666861896403, 0.11402160977013409, 0.1659615125390701, 0.11105462210252881, 0.05736834566050675, 0.1090368116274476, 0.08732357440749183, 0.15913158684270456, 0.15664442733395845, 0.12109156828955747, 0.2746347460197285, 0.13138022128259763, 0.0786802034417633, 0.10715447278926149, 0.1875244648545049, 0.10197879426414147, 0.15874440839979798, 0.13642902224091813, 0.21157650626264513, 0.12275410525035113, 0.10535959605476819, 0.21875944192288443, 0.0933158231782727, 0.14692236698465422, 0.1703471303335391, 0.08476314265863039, 0.2002242294838652, 0.1363719956134446, 0.09203405992593616, 0.11230061383685097, 0.1166341031785123, 0.1215961025445722, 0.0846968540281523, 0.08511157357133925, 0.14083111571380869, 0.18784208921715617, 0.14715275930939242, 0.14801845973124728, 0.10455996904056519, 0.09630869695683941, 0.1771989939152263, 0.11000950005836785, 0.13835116988047957, 0.15820363507373258, 0.08662421896588057, 0.13412383734248579, 0.17135750502347946], [0.08921361673856154, 0.044866853204439394, 0.012856436642323388, 0.06557480315677822, 0.02023787918005837, 0.032382500648964196, 0.05994944993290119, 0.011836875091830734, 0.05891747503483202, 0.08852871091221459, 0.04243660529027693, 0.032724281918490306, 0.10180890923948027, 0.017241038622159977, 0.07157048807130195, 0.029172055146773346, 0.042026090013678186, 0.07545815446064807, 0.03636285757238511, 0.013190479166951263, 0.04654327203752473, 0.028687039375654422, 0.017036066710716113, 0.021387328633863945, 0.013507916137314169, 0.07728584154392593, 0.0451596787024755, 0.03938945825211704, 0.09134815220022574, 0.024259362216980662, 0.04190070045297034, 0.030509154785249848, 0.07272436443599872, 0.03625978439231403, 0.059011820558225736, 0.075637041736627, 0.03828832632279955, 0.0002284796275375811, 0.03289579224656336, 0.008929747200454585, 0.04786642486578785, 0.0031671068609284703, 0.027654064433590975, 0.024819667014526203, 0.02702873265661765, 0.0306879474374, 0.03672581231512595, 0.057891797259799205, 0.039449850519304164, 0.016307350051647518, 0.03308223087515216, 0.035726855567190796, 0.04793560045072809, 0.04013214027509093, 0.04022499779239297, 0.020323788339737803, 0.03623952376074158, 0.04818675806745887, 0.022474699289887212, 0.02917635032645194, 0.09067503910046071, 0.020744732646562625, 0.07651023042853922, 0.04512669765972532, 0.009595040846761549, 0.025368622518726625, 0.010732528735388769, 0.020173397679172922, 0.010582023969618604, 0.02595537374872947, 0.10905584029387683, 0.028699761642201338, 0.017600341998331714, 0.06356762023642659, 0.054541920762858354, 0.03646013457910158, 0.05591466760961339, 0.03444505149673205, 0.028509846051747445, 0.06677688943454996, 0.11367000988684595, 0.07042775134323165, 0.02676013085874729, 0.07401055830996484, 0.020440748958208133, 0.05871728812053334, 0.031870359380263835, 0.02038164431723999, 0.022757982624170836, 0.029857011068088468, 0.040348450347664766, 0.013443723146338016, 0.03765908899367787, 0.06990336463786662, 0.12182757098344155, 0.028352466215437744, 0.027570463353185914, 0.05084961361717433, 0.03802978062594775, 0.008797768296062713, 0.01857338851550594, 0.01663991941313725, 0.031739915793878026, 0.05426967501989566, 0.027122532701469027, 0.04674251642427407, 0.013325668787729228, 0.05842716775077861, 0.02275656326673925, 0.03778479767788667, 0.03435430538957007, 0.02705118076846702, 0.04349600996647496, 0.023294727943721227, 0.03308182640466839, 0.08525404366082512, 0.06466012840974145, 0.04058810096466914, 0.03941530725569464, 0.02194823457102757, 0.04445807084266562, 0.026770979202410672, 0.034166586556239054, 0.028987213991058525, 0.03806239059485961, 0.022789893118897453, 0.04744858088088222, 0.024716317384445574, 0.04226999684760813, 0.0467279035365209, 0.058907608181471005, 0.09889480701531284, 0.042466495287953876, 0.03224518477509264, 0.04678258868807461, 0.017390011780662462, 0.03505133790895343, 0.10186658895690925, 0.047215424056048505, 0.049572117713978514, 0.031058629792823922, 0.02475057863193797, 0.04206930156215094, 0.0366668412607396, 0.07166683368268423, 0.06115918775321916, 0.02892040956794517, 0.05871323970495723, 0.03536777112458367, 0.01822342321247561, 0.027223919350944925, 0.04664083848183509, 0.014916182171873515, 0.045263100691954605, 0.032592550705885515, 0.05232819443335757, 0.06428315449738875, 0.025255085056414828, 0.057875388374668546, 0.05041892305598594, 0.04111758622457273, 0.08424453728366643, 0.014274601999204606, 0.019519812340149656, 0.042587105417624116, 0.08708757886779495, 0.08904049595003016, 0.03323052682389971, 0.07314082060474902, 0.09231476986315101, 0.06396737808245234, 0.01887333120976109, 0.029724992273258977, 0.034763785370159894, 0.0445455626322655, 0.03721649438375607, 0.03759631814318709, 0.03210163486073725, 0.017707042425172403, 0.03588381237932481, 0.046887595162843354, 0.0805507495533675, 0.02692091900826199, 0.03023804081749404, 0.030024588013475295, 0.035801504491246305, 0.020848924614256248, 0.045181175009929575, 0.07222266518510878, 0.03925774559320416, 0.006250537035157322, 0.05551292822929099, 0.06455104754422791, 0.027681759529514238, 0.05350346691557206, 0.009109906332014361, 0.05501952990016434, 0.00996353943264694, 0.08653588112792931, 0.040920950486906804, 0.03854546193906572, 0.07245454922667705, 0.05810116825159639, 0.045366359408944845, 0.017555703670950606, 0.04098633740795776, 0.03521026512316894, 0.011596966578508727, 0.029587956560135353, 0.03480010978819337, 0.05269390996545553, 0.013742723313043825, 0.029378275721683167, 0.03824122963123955, 0.08587795236962847, 0.10055516206193715, 0.023615957288711797, 0.02562350571679417, 0.0381023626687238, 0.040059086968540214, 0.07976391716510989, 0.03637246096332092, 0.05352638443582691, 0.03492814510536846, 0.045116956971469335, 0.030483018199447542, 0.03388503428141121, 0.06418533943360671, 0.06836241373093799, 0.01597512764419662, 0.016894834152481053, 0.043884828555746935, 0.07138049084460363, 0.046982489875517786, 0.016205855790758505, 0.007739902184766834, 0.0617041987425182, 0.060401143273338675, 0.009740819987200666, 0.017107800849771593, 0.037755538505734876, 0.0360850160359405, 0.07285155370482244, 0.024821219958539587, 0.05028833475080319, 0.00953733608184848, 0.05511492185178213, 0.02195291752286721, 0.024401526170549914, 0.04333260760176927, 0.011225382513657678, 0.1116150920279324, 0.0937754574988503, 0.05602456854830962, 0.033290173232671805, 0.02743901415669825, 0.027241578754910734, 0.022640133283857722, 0.022488597860501613, 0.028631454370042775, 0.0764166827138979, 0.02672018476005178, 0.0356274819932878, 0.04665767410187982, 0.01830663652071962, 0.02654503234225558, 0.021423022226372268, 0.014372119276231388, 0.0418228491616901, 0.028131578947068192, 0.03188666807545815, 0.028729859441227745, 0.06105172105890233, 0.0072096288567991, 0.0807787076337263, 0.032938257936621085, 0.05699155357433483, 0.042605499547789805, 0.07129746678401716, 0.030914577073417604, 0.05379866728617344, 0.030477019790851045, 0.010664005312719382, 0.0221811223673285, 0.024677297114976682, 0.04193758519249968, 0.012735362670355244, 0.050900242931675166, 0.010688741094782017, 0.04913163080345839, 0.03180638996127527, 0.025791700500121806, 0.08477227849652991, 0.027043154441344086, 0.026856945878535043, 0.029651937111339066, 0.02029893938015448, 0.0875737820751965, 0.05282489160890691, 0.015591214651067276, 0.055093251139624044, 0.03781105115194805, 0.06574559360160492, 0.03837430042040069, 0.02207944999099709, 0.03438542364165187, 0.07171311401179992, 0.01664133134909207, 0.005172829605726292, 0.03135314924293198, 0.019931689457735047, 0.029722880863118917, 0.030878645993652754, 0.03022690118086757, 0.010294047478964785, 0.05101730188471265, 0.029695018783968408, 0.02465206038323231, 0.041021823199116625, 0.02522808386856923, 0.05146314710145816, 0.08772827495704405, 0.014022444338479545, 0.09123352749156766, 0.035413094083196484, 0.018343020310567226, 0.019896930971299298, 0.027539100192370825, 0.08640584943350405, 0.10339070053305477, 0.046602205984527245, 0.029168598593969364, 0.02573948113422375, 0.026212208795186598, 0.01893836561066564, 0.027404949578340165, 0.03696126979775727, 0.09315036877524108, 0.024120235502778087, 0.06552982158609666, 0.013588736019300995, 0.06530052021844313, 0.062133234314387664, 0.012719018723146291, 0.056655401494936086, 0.020722891240438912, 0.051162061499780975, 0.1492953099659644, 0.018998820960405283, 0.03181544045219198, 0.05138766697200481, 0.04063376160047483, 0.15609615831635892, 0.11872506715008058, 0.07561741935205646, 0.1635123064625077, 0.1741749350912869, 0.12034499741275795, 0.1324966043466702, 0.08821057446766645, 0.08124450920149684, 0.13792286161333323, 0.08141380792949349, 0.18285372876562178, 0.1928555194172077, 0.11096154194092378, 0.14441888022702187, 0.10108822447364219, 0.1420823173248209, 0.17374868999468163, 0.1275271241320297, 0.12016662221867591, 0.1476801442913711, 0.0871512848243583, 0.1938922848785296, 0.06952626456040889, 0.09424226838746108, 0.20536634809104726, 0.2075001859338954, 0.14518056123051792, 0.14697317441459745, 0.1788973988732323, 0.1134174718754366, 0.07105747106834315, 0.13948693784186617, 0.11003848834661767, 0.24801594234304503, 0.09707399221952073, 0.16300990217132494, 0.08027734234929085, 0.09695648797787726, 0.2559268061304465, 0.09427719385712408, 0.11088300045230426, 0.17050287744496018, 0.10061758410301991, 0.24342613003682345, 0.160681695851963, 0.12867987243225798, 0.09052119188709185, 0.10259419053909369, 0.0644448610546533, 0.24464130779961124, 0.15181168040726334, 0.1267246250063181, 0.12714675860479474, 0.13506827963283285, 0.11894308045157231, 0.18990868848050013, 0.1511607872089371, 0.2711291966261342, 0.14648599899373949, 0.16132743854541332, 0.13191608159104362, 0.16000978503143415, 0.10395890363724902, 0.10194231028435752, 0.1499410971882753, 0.25023417721968144, 0.12657091137953103, 0.14726715395227075, 0.07868404776672833, 0.2335015227436088, 0.11310525034787133, 0.13059553370112553, 0.14951581688364968, 0.09438689812668599, 0.17137262999312952, 0.17969413893297315, 0.18488420028006658, 0.08831176630337723, 0.22145193885080516, 0.19603847205871716, 0.15191322105238214, 0.0800807325867936, 0.0995417074591387, 0.22034226480172947, 0.13353564077988267, 0.15765824558911845, 0.14676044520456344, 0.07675352870137431, 0.15492868580622599, 0.11948164959903806, 0.08942614556872286, 0.24002115649636835, 0.14605466276407242, 0.19394644681597129, 0.09976346860639751, 0.2097797073656693, 0.09382386779179797, 0.14548862673109397, 0.06490900021162815, 0.18123688583727926, 0.13872834417270496, 0.1275912011624314, 0.15176781947957352, 0.18209022207884118, 0.15248414041707292, 0.11366227670805529, 0.15628622233634815, 0.29247146390844136, 0.11321137004415505, 0.18200055579654872, 0.139652036014013, 0.08408693480305374, 0.07851980306440964, 0.14016296016052365, 0.1786215277388692, 0.26365072291810066, 0.17444415658246726, 0.1207149209221825, 0.170734902494587, 0.14225513383280486, 0.1509033510228619, 0.161209897196386, 0.11680715717375278, 0.1801827541203238, 0.10591484126052819, 0.1044295885367319, 0.13066341052763164, 0.1399865813436918, 0.22071520885219797, 0.25664959859568626, 0.1297992983018048, 0.08320724489749409, 0.08345384572749026, 0.20918947731843218, 0.14209147542715073, 0.16008968465030193, 0.19717455172212794, 0.07769987831125036, 0.1605359825771302, 0.12085507551091723, 0.11375121568562463, 0.1356105669401586, 0.08826723744277842, 0.18447260517859831, 0.17466501973103732, 0.15749714017147198, 0.13249509036540985, 0.12213305381010287, 0.15445837198058143, 0.12359179701888934, 0.1272849168162793, 0.19557813269784674, 0.1997379446402192, 0.23248185636475682, 0.18793024151818827, 0.14385858841706067, 0.11010174159309827, 0.12551556254038587, 0.1455232553416863, 0.09972578976885416, 0.2849818579852581, 0.11864268133649603, 0.14209293003659695, 0.12301471782848239, 0.16574845678405836, 0.3071252291556448, 0.10541736482991837, 0.1832446179469116, 0.15808257594471797, 0.17844385758507997, 0.32588413974735886, 0.1412425920716487, 0.12474243761971593, 0.13821457017911598, 0.08883496557245962], [0.010884810944844503, 0.03866767139697913, 0.0077637520280404715, 0.016413120938523207, 0.029928847252449486, 0.02617175989144016, 0.013440013335639378, 0.0541082356357947, 0.015479902704100823, 0.057222257601097226, 0.06802046918892302, 0.044709269277518615, 0.015101661574590253, 0.03084381329244934, 0.03450097232416738, 0.0521385608590208, 0.02970511941384757, 0.10019224442658015, 0.025573433013050817, 0.045583734463434666, 0.05903771780140232, 0.0680704231490381, 0.06384706110111438, 0.028861815153504722, 0.008999368074000813, 0.019173635701008607, 0.015456245819223113, 0.05123468807141762, 0.004767103037011111, 0.04830829217098653, 0.07682688257773407, 0.03997725034423638, 0.03195405879523605, 0.0033760471751520527, 0.04356112229288556, 0.04568395779642742, 0.03339924296597019, 0.03694178842124529, 0.023903125766082667, 0.013627924199681729, 0.04335523197369184, 0.03591817010601517, 0.051787432239507325, 0.10793667417601682, 0.019813524704659358, 0.06587469761143439, 0.05876051822269801, 0.029038911998213734, 0.05685262724000495, 0.023266082898771856, 0.02392841073742602, 0.031067140371305868, 0.056401382898911834, 0.09341976096038707, 0.08166718456777744, 0.05709409982955549, 0.0472148711560294, 0.012468572640500497, 0.014094974430918228, 0.020384373565320857, 0.0640878286503721, 0.012210257937113056, 0.048014769054134376, 0.06384009233443066, 0.0506014988059178, 0.045799268991686404, 0.025431794128962792, 0.03020375173946377, 0.026229018440062646, 0.032727725483709946, 0.02811985857988475, 0.01460335301089799, 0.020126623821852263, 0.04816107604710851, 0.015308321871998487, 0.07405123542412184, 0.006221999601621064, 0.05528812427655794, 0.026920085947494954, 0.026373030341346748, 0.07278274919372052, 0.028183473623357713, 0.02510848677047761, 0.017226919262611773, 0.035179529077140614, 0.03699661458085757, 0.06189294916111976, 0.00397960086047533, 0.05949879559921101, 0.009742323763930472, 0.007928334871394327, 0.026239950275339652, 0.013483532875397941, 0.0338802548503736, 0.07644609402632341, 0.003274079795119178, 0.09322075406089425, 0.026682056923164055, 0.01623376982024638, 0.05667336146871094, 0.07799641825840808, 0.11655542068183422, 0.008159126100508729, 0.014527086204907391, 0.03295499336672947, 0.010113920816365862, 0.02937993256637128, 0.05537358629226219, 0.03951032071199734, 0.01117443222028669, 0.06072639691410586, 0.026328388303227257, 0.05845092760864645, 0.04423100333951879, 0.051308079055161215, 0.06733148155035451, 0.09883995488053188, 0.008575998799642548, 0.024695457468624227, 0.019269764234195463, 0.008889578457456082, 0.06717481417581439, 0.01868962739536073, 0.049867986017488874, 0.04397348551719915, 0.0033209083858309896, 0.06303756352281198, 0.01246343976163189, 0.0005552763991545362, 0.05080795686808415, 0.027453732800495345, 0.039048029502737336, 0.023591514654981438, 0.031444437117897905, 0.028411936364136636, 0.004588670326484134, 0.052264581245253794, 0.019880240070051514, 0.06498703703982756, 0.02145974740415113, 0.034540261622169055, 0.043572239665081725, 0.0644521192589309, 0.06316969549516216, 0.026175743369094562, 0.04239907859300729, 0.0326159469113918, 0.04205936420476064, 0.04221596478600986, 0.008508140526828356, 0.066143021103926, 0.05530039197765291, 0.03183885521139018, 0.06195012050739024, 0.03531044763803948, 0.03006855840794742, 0.040864569527911954, 0.03188587026670575, 0.09649366242229007, 0.029608157819893677, 0.02281565120938467, 0.029163674444134813, 0.06457749026594684, 0.03590653694118373, 0.05128444165166002, 0.024739878717809916, 0.030197569649317302, 0.04918006707157474, 0.06315193590126, 0.014497876200039173, 0.03113170350843575, 0.05251756825600751, 0.0513210295321187, 0.038939512669458054, 0.08790923282504082, 0.029602038812299725, 0.03341417497722432, 0.007771927248541033, 0.018914399806817528, 0.058064632321475074, 0.05297720999806188, 0.02310742471308913, 0.0161288598246756, 0.0604059189936379, 0.06603428162634373, 0.010588497352728155, 0.06198700895765796, 0.048084805530379526, 0.060520651313709095, 0.050945135444635525, 0.020603991761163343, 0.03437693347223103, 0.03344203520100564, 0.017329250295006204, 0.005069210483270581, 0.0443045241991058, 0.02457231476000743, 0.08189872722141445, 0.05500365536136087, 0.010993002160830656, 0.09962847936549224, 0.009862696406344185, 0.04506919976847712, 0.09806087793549523, 0.05153620782948565, 0.053229911281960085, 0.035772916962741874, 0.012112619133404223, 0.02205664750363212, 0.03457760649325792, 0.09093731408938766, 0.044247991099837236, 0.03641936098574661, 0.04848786964430474, 0.040933563286671415, 0.026380750532553066, 0.04104247345821932, 0.006455135553551372, 0.024028396583162248, 0.06310690980171785, 0.021821757763973437, 0.07005244726315141, 0.009392750871484168, 0.03949214922613464, 0.015195642517937813, 0.03667103810585104, 0.016135620790009852, 0.0056060606311802985, 0.040913491902756505, 0.060138656772323884, 0.018354610801907256, 0.04997236537747085, 0.06813963584136218, 0.005529783156816848, 0.04421197467308957, 0.008329117808898445, 0.03951323735236656, 0.10105080538778566, 0.09297070966567844, 0.0021418667211037246, 0.006876315956105827, 0.037863580364501104, 0.04287662835849915, 0.0066875279662781395, 0.02611683539726073, 0.03551651978341397, 0.04279825014236849, 0.016659458306094166, 0.029991204355610535, 0.05770130279415753, 0.07144556235289201, 0.02978805627208203, 0.0215727152681211, 0.022986406402196735, 0.01946960976056289, 0.026313788403058425, 0.09237682083039545, 0.049405041718273424, 0.04617272883479018, 0.04565468378132209, 0.03786146153288428, 0.01915793000080157, 0.08501117583364248, 0.03723154142790008, 0.009268308476748643, 0.04881145345279947, 0.0390587052970659, 0.028261215447855648, 0.021655551936419215, 0.022997603555268142, 0.011643598500086227, 0.0487936975696357, 0.015122876793611795, 0.026458592546987347, 0.08272202132502571, 0.08479768221150152, 0.2091263502370566, 0.0892301369458437, 0.028312095237197354, 0.04050378927786369, 0.06906539085321128, 0.023576168896397576, 0.03180312822223641, 0.053651321286452, 0.02917129259003559, 0.04414317387272604, 0.040828467754181474, 0.0313968543196097, 0.030604585699620657, 0.012342879726929823, 0.0664319763018284, 0.0455515475186985, 0.026057925570057705, 0.007130203748602071, 0.035745732093346305, 0.02761920575721888, 0.023309335265366826, 0.013731858271057718, 0.016761865408625454, 0.019577877974370494, 0.043111247214255854, 0.023537126362498384, 0.06526171331643127, 0.05023672209063079, 0.041982618713518605, 0.0331267300498439, 0.052626827236963436, 0.06483367222244851, 0.026385845376353245, 0.023783797696523834, 0.07011565598077141, 0.026893142276094295, 0.06082242340198718, 0.005668473395417095, 0.061573309867526405, 0.03739180450793356, 0.025220771858585067, 0.06305798000539653, 0.0939378394105006, 0.060702692717313766, 0.03502194143948145, 0.026957896516250912, 0.01903614913317142, 0.05851870424521621, 0.033469182963017374, 0.07506673835450783, 0.009499383577349363, 0.02903408803831553, 0.028101434763811994, 0.023129943328967784, 0.09986550649045967, 0.023615118661837187, 0.07388377722236328, 0.042564221294014715, 0.06104416599555407, 0.04674062394769862, 0.02597987389890477, 0.057116987663903274, 0.018960446359415073, 0.05749818439653609, 0.06651367191807367, 0.05452359342598356, 0.02425699476589216, 0.05603764519037213, 0.05951610619376879, 0.040056931029539555, 0.009949857012543362, 0.053560975939035416, 0.013906986569054425, 0.07395405118586496, 0.03400354413315654, 0.024570965906605124, 0.16023188014514744, 0.1367261484847404, 0.11373332992661744, 0.13513415266061202, 0.1763505261624232, 0.13384934660280123, 0.1264069858007133, 0.1679108227835968, 0.14346836716867983, 0.14221780380466953, 0.15868937072809786, 0.08796904992777854, 0.12379149411572143, 0.17833373771281913, 0.09754287370014936, 0.06877104766317643, 0.12891295133158565, 0.13657911418704316, 0.09962885043933056, 0.22127272502984852, 0.1488368259742856, 0.1400473780813627, 0.14010931772645563, 0.1278097933391109, 0.1264576893299818, 0.10838418922503479, 0.16148245835211128, 0.15286227950127795, 0.1397413609083742, 0.1703523995820433, 0.10764262784505263, 0.15069467393914238, 0.09689015481853858, 0.11367071492713876, 0.11116316120023839, 0.1117801753571257, 0.178657952346839, 0.14727126545039937, 0.07665322002139874, 0.09356050184578635, 0.11881174257723615, 0.085840785613982, 0.1709607825614512, 0.22954093292355537, 0.11628600623225793, 0.20817991899093613, 0.09437064509256743, 0.10517782924580388, 0.2074232994345948, 0.09917131639667787, 0.2026950172148645, 0.08490970198181458, 0.1590731056057848, 0.18297793460078537, 0.1371813818695955, 0.13643895217683166, 0.18181690393248573, 0.0974534300621599, 0.12244141616974957, 0.09518854378256947, 0.17632707429584116, 0.25586577190551907, 0.1504025942995213, 0.14526795654091984, 0.1473807025467977, 0.15201385627733544, 0.1067390556272585, 0.16638196888379753, 0.09751904333825223, 0.11708212288795039, 0.0744629641121719, 0.12409617542289197, 0.1007924712030217, 0.14012089523021132, 0.1466301834443584, 0.14881254290230572, 0.08289594363304786, 0.15213396545732394, 0.10424303487525322, 0.13054903072770685, 0.14358391956193373, 0.14608565485104918, 0.1423159454134293, 0.11407589045120403, 0.09173515252768993, 0.18212970433523878, 0.2555896039120853, 0.10205867904005572, 0.12955597776453942, 0.16052726976340637, 0.1594714162638411, 0.15211274003377184, 0.07530879724072292, 0.2045494513004087, 0.18240118195535615, 0.13862833235180005, 0.1672800863161683, 0.09104303302592598, 0.21096303215017542, 0.14590280450647697, 0.36637978395447135, 0.17227257310878485, 0.11826676127384417, 0.0903245598601643, 0.20316522713983431, 0.10032277335994877, 0.12433279436663724, 0.20504437474301085, 0.17030398186761886, 0.165451523498632, 0.18874289322411641, 0.10989149857778102, 0.09996155524277128, 0.10189099819399416, 0.3274341596988961, 0.12632462225155905, 0.24340904579730704, 0.14551544794812799, 0.12590137543156743, 0.14429142378503457, 0.10579464302281849, 0.164852105663158, 0.08456213196041062, 0.20227945904480293, 0.25700419675558805, 0.1661249334574677, 0.10125315195182338, 0.12410088063916191, 0.10179011806030758, 0.095830560894683, 0.09745118135469966, 0.24099068337818608, 0.12228981024236418, 0.07355339534115046, 0.1411964453291148, 0.1137794618261978, 0.174262864748016, 0.10852610270376317, 0.13464472111081704, 0.1031901128590107, 0.1906466207583435, 0.17720838950481266, 0.21643171057803556, 0.13613369199447334, 0.12442916224244982, 0.0766457020654343, 0.1423767866799608, 0.12963108310941607, 0.10494052010471933, 0.14729937800439075, 0.293268560199067, 0.16813202732009813, 0.09557929195580073, 0.14347301301313564, 0.2061018906533718, 0.07123337491066195, 0.1331748382654041, 0.11195509956451133, 0.22808862413512543, 0.09979398571886122, 0.19788701349170879, 0.227980270574335, 0.11891225163708441, 0.15494899096665904, 0.06947703790501691, 0.1972131137154065, 0.11010128888301551, 0.17659467790508643, 0.1400483280303888, 0.12461294769309461, 0.11969264960498549, 0.11214416910661384, 0.13814749487210065, 0.1295464189024642, 0.1765600938233547, 0.18820116994902492], [0.05415755877038464, 0.018804916326189414, 0.04156923132541124, 0.0261386638158001, 0.009234425724571338, 0.029658211969945114, 0.009517904800304677, 0.020707755138573702, 0.06831220744061284, 0.03346977297042031, 0.009005821975733852, 0.015558248451270629, 0.07426154523272999, 0.06206064485013485, 0.031803855526959524, 0.016647134943923447, 0.028277551973587833, 0.04424249920703005, 0.03916245012078434, 0.03310129664896522, 0.01977156181965256, 0.015178793910308741, 0.006158722235340974, 0.010802961332956329, 0.05733071135182399, 0.031421118837897666, 0.07828933652490377, 0.013034470448474167, 0.021669344750989694, 0.05583951402513776, 0.02948588713479694, 0.03724145652086008, 0.017758319263521116, 0.053913878291496076, 0.04367673405795358, 0.048274038344970904, 0.0351242910255678, 0.07483469104045071, 0.0238228680609609, 0.013808618605253287, 0.047616031661164016, 0.049439481081208214, 0.07693638646742329, 0.05372135405195877, 0.0646839290857315, 0.03990546611021273, 0.017012987773341592, 0.035342530682100914, 0.04618503364326898, 0.05001742116292007, 0.02271487312100362, 0.038771969120716676, 0.048253774002660066, 0.007188441004473134, 0.010812407945195446, 0.04124325409065932, 0.03545312923961319, 0.10731220885645598, 0.05403556453529745, 0.026142994247493334, 0.0410240199562395, 0.0272599339223234, 0.0466386676998809, 0.04064085653226357, 0.060070846739108674, 0.02404680741165066, 0.05025951344578061, 0.07825045540812425, 0.010018592874985188, 0.026230237417621538, 0.03159160500217695, 0.05712113998015411, 0.03860055898257997, 0.02300565585755976, 0.1154010248137638, 0.037958716275170445, 0.05207048736338038, 0.010348359701310983, 0.025435929746890906, 0.02118780779710505, 0.04433563874044921, 0.03821068654360715, 0.06932810370926745, 0.03892686276230961, 0.02316948495717952, 0.05642592572257854, 0.026468528049008455, 0.00614808215686935, 0.04016284292447381, 0.033350135054206476, 0.039171118405647576, 0.04505120268731844, 0.02047742218564963, 0.021790043938381132, 0.024061143849394284, 0.03127742791548371, 0.05234651434875559, 0.019565109323593788, 0.0329185576265445, 0.036744410535902716, 0.05901820673898328, 0.05235050339251757, 0.03655226108094212, 0.017129375082731713, 0.05818946898216382, 0.054554281232412905, 0.014385419490281492, 0.03192154901626054, 0.06901633489178494, 0.04166860118857585, 0.022743278823327273, 0.019408727675909176, 0.04245532225468196, 0.02847501335054403, 0.07051438966300339, 0.027150407768203877, 0.01749477149132872, 0.0573713439371204, 0.042995743060600944, 0.01911478153488133, 0.05051596257544588, 0.04828680699574761, 0.07587231739307754, 0.040723349957261235, 0.07823215404641815, 0.03334227942104917, 0.06685906744678505, 0.044151226175017655, 0.03669079036626499, 0.04692909606092144, 0.030957244998717215, 0.06492856322438456, 0.033702358341543004, 0.03420035427552648, 0.061376373560051434, 0.027198990610486362, 0.09805269946809858, 0.020272737856430467, 0.04483109281864017, 0.011961476120632142, 0.0706317751610186, 0.11437937690061517, 0.022035535257600714, 0.019069367663178127, 0.01963868398888735, 0.035634751329780556, 0.0090154828831146, 0.04030256706755608, 0.09827388916164637, 0.05041985816205852, 0.02396872605459066, 0.06016984181769658, 0.08774896603426896, 0.0835715800349135, 0.02054401509667514, 0.009279988025809871, 0.04010278091300279, 0.01825712970457971, 0.04060176019265782, 0.042338756829849444, 0.03331387371872552, 0.022541149337484967, 0.034559943378553726, 0.04419947319547646, 0.027849291946040466, 0.028047450941812713, 0.02639235772221582, 0.06749551102984697, 0.042100096979993396, 0.04703448103100527, 0.059710567438742146, 0.013793582693324424, 0.04321003820223268, 0.0345782298973063, 0.056800316961016506, 0.036829661039519124, 0.06226180397788994, 0.03254034061683342, 0.020923820302414242, 0.05725836679630447, 0.015762442963023204, 0.036860968539258465, 0.014564470966433873, 0.03505139357002918, 0.021595220896415412, 0.04534262552624568, 0.0821632138104178, 0.02211624196206685, 0.03354244036017917, 0.04125351428228896, 0.06285857234615833, 0.00794904542999575, 0.02119514949299628, 0.13169146317522973, 0.021208712241786998, 0.04847429947403725, 0.05105099167849403, 0.02026873768045334, 0.04861593093664851, 0.11784600807004608, 0.049629968125373125, 0.031027938275656197, 0.057327568356413394, 0.0029552190608228557, 0.02450442309054779, 0.011708774836733937, 0.05110267855343409, 0.013895754163968377, 0.03057479960261844, 0.04604643756465521, 0.030627651649410836, 0.06111248439992778, 0.06116074255260173, 0.02860591335775098, 0.07334000561968423, 0.08461187069769949, 0.022121487090771552, 0.03368355603015516, 0.06975258991587907, 0.05461918204673566, 0.014047769200260518, 0.033573417604202405, 0.04533480328973383, 0.07325189042603597, 0.028228759474586695, 0.021406559535535052, 0.03740806867426727, 0.03503707383060828, 0.05647590194712393, 0.0537046594399726, 0.01333972228167113, 0.02406660049018683, 0.016550390428164974, 0.036600756720872596, 0.04236085798765998, 0.021632786556438077, 0.0042361209580121795, 0.010212032739218557, 0.01222342549226596, 0.07046888116747141, 0.011889883917319821, 0.005720510935134371, 0.035434404853731394, 0.088142994500231, 0.013550415224017343, 0.015879895254329313, 0.016521828874829225, 0.0389234340400435, 0.04298354957427364, 0.0017981600421990152, 0.051369176362641156, 0.06252905135625042, 0.052975896396674216, 0.07747340452624485, 0.04891612596111372, 0.019459219693089835, 0.051306598470546305, 0.03345134173287079, 0.03972637474362273, 0.052414547026273794, 0.06630223404499702, 0.021005786802561488, 0.05048830273153726, 0.02407547286566114, 0.09558620877214707, 0.016085878341982607, 0.01290868291107472, 0.0533669488504529, 0.012062540863553295, 0.012989082551939646, 0.037892568652750924, 0.04975870848284103, 0.06400867117918096, 0.038188596518011764, 0.017622261329961475, 0.03920294169802219, 0.03279603646660689, 0.03572332294424996, 0.020107943964831065, 0.05183264016523026, 0.011425188149587484, 0.06810119259171188, 0.020997875508328434, 0.047179092216538265, 0.01559303291287506, 0.04962600505677983, 0.019313979537400883, 0.06339204293908551, 0.034072348644258454, 0.016852602238941472, 0.03493329932098277, 0.012449170117179165, 0.06254359002923593, 0.021158166418899782, 0.050352103789919056, 0.0617748883087188, 0.05719885026337579, 0.021750739797425922, 0.06774844237952493, 0.034028098089038394, 0.06922707514604554, 0.05322782584698871, 0.01098034854294383, 0.005869813885510666, 0.029045396513538435, 0.012148406422056723, 0.08320372711750679, 0.0629587474395521, 0.06939595827134326, 0.010125954740942689, 0.03902012475009542, 0.03420868488319684, 0.01854319794801995, 0.028241878790140618, 0.025710286899993662, 0.058783543354365975, 0.08491962449625134, 0.08647168535389937, 0.025615568447392434, 0.08622428300441243, 0.023633271594007965, 0.010690398867154727, 0.05386470729717985, 0.032119635652634315, 0.05120573317981325, 0.018404607435513753, 0.024432809550489765, 0.04868181138590444, 0.06849001118098386, 0.03941350012610201, 0.08496231283061206, 0.05925636563915759, 0.08219920797273517, 0.07941701507661492, 0.04291098979592789, 0.06807453464716673, 0.06021267858159263, 0.03686393712996505, 0.06869609816931188, 0.007351960721280193, 0.05550168840272818, 0.0313032361009391, 0.011398691622162005, 0.040930761679192074, 0.10037680913228542, 0.054383546448661946, 0.0682788404810708, 0.09666870537330396, 0.050530720181996, 0.03334795685077552, 0.08515054374583997, 0.02828818509442499, 0.17627798864850774, 0.08799502509646118, 0.08304969436721876, 0.1880767711554654, 0.10193525245995261, 0.0967725837836042, 0.1018550262961071, 0.13041243102634326, 0.11236359991016798, 0.19008407281944528, 0.13739365094807, 0.05238757366896607, 0.1469662575982511, 0.1792389649199322, 0.1844728723517619, 0.07825661523384042, 0.10561757400864735, 0.1664977439213544, 0.10988569498294964, 0.13063207705272362, 0.1579712686361745, 0.13980002026073635, 0.15901455015409738, 0.13335599651327357, 0.18541180790634826, 0.1920111186336726, 0.15351441950770095, 0.12029166668071412, 0.15654180315323174, 0.13650568609591573, 0.07543054656707682, 0.07402238072245382, 0.14093850448261946, 0.15172066341619939, 0.16564348741667345, 0.15808625699719414, 0.11345646431436762, 0.11984461176325567, 0.13269270944874734, 0.10634883437887765, 0.10491572495084256, 0.15696735063102096, 0.21600058214971796, 0.1864957739599049, 0.10707809837185778, 0.12861894210800529, 0.27195648348424584, 0.16816600284073502, 0.13966843747766688, 0.15956050367094576, 0.14291134080849588, 0.14752067159861326, 0.10658382801921107, 0.28681261755991727, 0.09376462214277126, 0.24089972575893626, 0.09780848093214445, 0.14207238738890737, 0.1405017208890058, 0.0581784072710434, 0.13906931650126353, 0.13405726669589058, 0.14179244928527623, 0.10384197827079333, 0.10607928634271957, 0.060062953998567536, 0.08722043814486824, 0.2979858289472759, 0.10997369143296964, 0.07158294873079285, 0.13826684706145898, 0.3124819620279595, 0.148217533424031, 0.08872279737261124, 0.1750941592035815, 0.14459516998613253, 0.18585650279419497, 0.2071659523062408, 0.12275101791601628, 0.1235893256671261, 0.14451020892011002, 0.10157611235626973, 0.13233906123787165, 0.09037132258526981, 0.13885875436244532, 0.16550883214222267, 0.1650191779481247, 0.0910845932958182, 0.19693826674483716, 0.08692309667821974, 0.15817527018953115, 0.18627229845151305, 0.1443347058375366, 0.07846607157262042, 0.12137257508584298, 0.11369657135219313, 0.185979105590377, 0.16955277998931706, 0.09911579632898793, 0.16484009771374986, 0.112749620602699, 0.14497890486381948, 0.15706495789345354, 0.11186109913978726, 0.08298285654745996, 0.18757073034066707, 0.11511498625623062, 0.07036327355308458, 0.19222444156184793, 0.12375761507428251, 0.09724665287649259, 0.12322247464908287, 0.1526098305475898, 0.14888703968608752, 0.12653166661038995, 0.05055873254605103, 0.1268292826716788, 0.1453650591429323, 0.16051183309173211, 0.09481466462602839, 0.13225410017184913, 0.07002026031841524, 0.1623486337484792, 0.08070838171988726, 0.17515280371299013, 0.09550135160679929, 0.11468739045085385, 0.0837327225599438, 0.09496831145952456, 0.09991785016609356, 0.18810362205840647, 0.1368640543660149, 0.18393699720036238, 0.14909593941411003, 0.12403612825437449, 0.0930466091085691, 0.2404838558868505, 0.07252818511915393, 0.12561983428895473, 0.10265041564707644, 0.15401205921079963, 0.2921180531848222, 0.06598869149456732, 0.20642030169256032, 0.10367966315243393, 0.0944040491594933, 0.14629082899773493, 0.10744171362603083, 0.17861006897874177, 0.10667966154869646, 0.15955541253788397, 0.10837262656423263, 0.14251026936108246, 0.2132307385909371, 0.16253955865977332, 0.10041028741397895, 0.13496317667886615, 0.10685218119760975, 0.0818670672015287, 0.0946073530940339, 0.08419076126301661, 0.10547475510975346, 0.12927652947837487, 0.15810153039637953, 0.16986259695841, 0.22591295884922147, 0.06687588451313786, 0.1845619300729595, 0.11962177450186573, 0.13029116409597918, 0.16597736481344327, 0.12278260372113436, 0.1366698046331294, 0.14660009677754715, 0.16167638154001907, 0.11997697380138561], [0.035306417776155286, 0.025610668417357374, 0.06148867905722, 0.025103070947807282, 0.027835046421387233, 0.006531868057209067, 0.022549661771336105, 0.025093489821301773, 0.01802504157240037, 0.03749537492694799, 0.029325217728910502, 0.04206252946460154, 0.03587858394894283, 0.011126064600830432, 0.029686556445085444, 0.025513148357276805, 0.01926843022374669, 0.04457930066564586, 0.02243130777060287, 0.02568307605542941, 0.12185097832116298, 0.056020631454885006, 0.04498952650465071, 0.02368308083532611, 0.037801807702635415, 0.053655158189940266, 0.018262575213157106, 0.0510897503409069, 0.045529887938755564, 0.06528470505145378, 0.032700306837796234, 0.08597509207902476, 0.09693526255432516, 0.03792952760704793, 0.0032545272188144736, 0.021656756071024574, 0.05446006929560099, 0.04825149560929276, 0.06104864114604425, 0.0928207958349958, 0.02046187233645469, 0.01015822517729248, 0.06265632226131856, 0.014091822158661671, 0.0368918567255605, 0.039048923790687695, 0.0624220707686618, 0.059458396790432744, 0.04135325150855351, 0.05459863197756931, 0.03579545969842002, 0.028409557780832984, 0.007066634625516599, 0.02633502495882567, 0.048196487623499706, 0.016560797193960752, 0.08348029587068595, 0.051699825417017564, 0.04853595710301306, 0.0362980346835684, 0.07496835925849155, 0.04198562070087064, 0.08905808484996669, 0.07536884440924041, 0.02651328883075621, 0.08479475814965554, 0.05730845805373974, 0.04061456595081836, 0.04407693719258532, 0.06638942897552624, 0.017371367175655905, 0.016415009704360273, 0.01811157970223576, 0.01745640616718447, 0.03473367643891834, 0.020280471035221126, 0.09045591999893077, 0.04670327536587138, 0.007330298358283471, 0.049012664530891925, 0.05529795402253512, 0.009779505362530472, 0.04841966256208252, 0.03873126603139099, 0.007946708592498908, 0.030014730436960235, 0.04439713309693616, 0.04612503471435048, 0.007096810813891352, 0.0718576621147804, 0.03147105795505922, 0.03549848930560984, 0.044688051275443286, 0.006581815987374284, 0.019281896493339445, 0.013748268083872972, 0.07630891544977203, 0.0390375911956653, 0.06289856668445282, 0.013962922239443287, 0.006424989978768281, 0.012322089387453161, 0.0686099348240532, 0.027245439778198488, 0.011790938006015494, 0.030246221140259877, 0.00507771595948725, 0.03619489842094481, 0.012420461989677278, 0.046145239684847184, 0.030097554117674008, 0.04537670123681892, 0.05367978636058979, 0.003138145707453077, 0.040576185783720575, 0.03381221475137863, 0.04742361503303982, 0.07558452736702748, 0.08661828920594417, 0.014893235893396195, 0.025256060980609618, 0.04609339695889503, 0.02447267215757165, 0.07329082349315286, 0.01749877537804423, 0.051048635359620675, 0.03385308482393157, 0.009625542188587133, 0.022783007843827363, 0.05809582107758615, 0.03579370451916475, 0.03783236563322134, 0.04966346867149696, 0.02760925726761343, 0.023617369224666618, 0.05863280573976226, 0.035913416650146246, 0.022475565747299697, 0.047861875500530005, 0.049357640746166, 0.06503705779323354, 0.09693217521999031, 0.04596645630954299, 0.12106853944715112, 0.017081341429729946, 0.04282899360987358, 0.03289961059635971, 0.06778999522794038, 0.06139846358564682, 0.028333214904705528, 0.030093754321569577, 0.04594585800077766, 0.03702729125507176, 0.050505854524089955, 0.09687143043265678, 0.034464406708138995, 0.03338267080835067, 0.07125606978661381, 0.0415620696003316, 0.05599962496489752, 0.06720162054989487, 0.02746940139331855, 0.04409897155710496, 0.03524941341311205, 0.013985920468257973, 0.05138886182976421, 0.02782736519293394, 0.1078013658116106, 0.051543080116971396, 0.03802204373641871, 0.04246771612088196, 0.07171040517278016, 0.009328961423307192, 0.031841682794038206, 0.03489372429612558, 0.12673005752731115, 0.02907388570747571, 0.042515655150054954, 0.07415014144498855, 0.05590074862993788, 0.043687754950951785, 0.022124522474769037, 0.07497610728023574, 0.07465672402759083, 0.012778001837432384, 0.013837094811606221, 0.02047642399702454, 0.03184277375112288, 0.04129197608563118, 0.044067626949981786, 0.05383441653975751, 0.00741633646612172, 0.03864210069878027, 0.020352724677650258, 0.05083558331534732, 0.037067897865199484, 0.0372023230738705, 0.018481404877093155, 0.039409893288393505, 0.007164985427152715, 0.08175479510100558, 0.013821330667269649, 0.05843163176905364, 0.0307446048464044, 0.04031391079479363, 0.02219105230324203, 0.030913385926396586, 0.043584199374890886, 0.10262549432809465, 0.022981395050010178, 0.021118519034644123, 0.06575328967301175, 0.07527634312282316, 0.010989298843924189, 0.06208244543813635, 0.031827199782128446, 0.03562558580597397, 0.0228507677820744, 0.055199174166773446, 0.06417396973120049, 0.04815459709789138, 0.039580939774168655, 0.028928662250109483, 0.027658290964609478, 0.03325295081594959, 0.07530097500421107, 0.014283860291470774, 0.06323789144516923, 0.04768885861267336, 0.011823695476778084, 0.03063323445530841, 0.04915649646136444, 0.023407736625813413, 0.007003116061241599, 0.036741816729772836, 0.03750453302927781, 0.0684560059744399, 0.02089998251904035, 0.02272374178573955, 0.04150711727561429, 0.03633132000686601, 0.019823078000626992, 0.04786224657436833, 0.04176967056991998, 0.06386400433257222, 0.06192323620780371, 0.02495124608685728, 0.02467535639880225, 0.03544975617842283, 0.015176002507359954, 0.05509193753823638, 0.08683542677317746, 0.09691115017631091, 0.03575627059035469, 0.05070517312560696, 0.014367363964993274, 0.029574460604635533, 0.02146725237253122, 0.07366258752881549, 0.07844370324164629, 0.059081511935801245, 0.06905908259795979, 0.007548093190052896, 0.024121701244439464, 0.07524711734731682, 0.04513024883635808, 0.025988809356931597, 0.056308076382265426, 0.1312086812686175, 0.04776735557243228, 0.03697965279570781, 0.021421454439405352, 0.07347899503656663, 0.015334477939177305, 0.078093951306073, 0.03887129445502069, 0.013132319836586248, 0.008625757018307922, 0.01919716549309669, 0.04549802382825874, 0.011388207858544774, 0.02150462692952715, 0.036057137258467264, 0.04480506198888179, 0.028570034228323493, 0.05270083049254026, 0.046189905842766166, 0.039488720503868535, 0.0305621274310397, 0.017329515612800606, 0.059634816425386816, 0.035989134266856126, 0.016660695837344974, 0.05438506785139907, 0.07415748870698735, 0.04436656403413508, 0.06459778058342636, 0.01995262544369325, 0.004401237683850923, 0.08060154956183396, 0.015207079013634939, 0.02351513281610096, 0.05040901538450271, 0.0361563252954511, 0.004185718926237314, 0.01588653562066611, 0.06196390590048395, 0.0665110744012054, 0.14585014170734212, 0.02293779944011476, 0.019883973072865047, 0.024471564502164256, 0.05385827287682332, 0.04708797874627635, 0.03742600267287344, 0.05492175194376614, 0.007651008663742687, 0.03294184250989929, 0.02153064477170119, 0.03380025133083109, 0.020432696655916516, 0.03661885770270601, 0.024816431250656024, 0.04545151714410167, 0.03436606471950654, 0.0506237187073566, 0.008443123751931125, 0.025349300703965127, 0.03032307795365341, 0.004702258347606403, 0.05003198952181265, 0.029471354027919006, 0.046043186957831495, 0.038829815821372904, 0.03345204306242522, 0.06988203531363979, 0.08395483251661062, 0.013680066567758331, 0.06642012420343235, 0.00901405981494463, 0.07654838424059562, 0.07396185857942328, 0.05981993403111119, 0.05726190312998369, 0.04048389972012956, 0.08347063310793601, 0.021357557379815262, 0.01591835705767153, 0.04066720277478453, 0.012979199927940499, 0.07121339629520662, 0.014863018423056928, 0.2100010306457989, 0.1133272638253402, 0.18527428794186562, 0.16364515089662746, 0.11729329358786345, 0.12906618998385966, 0.11917452662601136, 0.15810320765012875, 0.07484986053896137, 0.1072940559242852, 0.11155656626215205, 0.13611829985165969, 0.14965363370720297, 0.10425566622870974, 0.08946225847466849, 0.11031805537641048, 0.0755923124961555, 0.15378493233583868, 0.11273275158600882, 0.1265157846501097, 0.3022915025940165, 0.15300772560294718, 0.13616005307994783, 0.1183287454477977, 0.1961031131213531, 0.11150966252898797, 0.13964133424451575, 0.12880029331427068, 0.10450320216477849, 0.09214640624122694, 0.12388185801682994, 0.1220397806901019, 0.20982718997402117, 0.1048324782459531, 0.11372550026862882, 0.19002916873432696, 0.17620700964471325, 0.17358722834615037, 0.15387007151730359, 0.2345903721288778, 0.10564455107669346, 0.23104238673113286, 0.23486844002036378, 0.16186809312785044, 0.27619563101325184, 0.11758305030525662, 0.10059050313429907, 0.12222316538100131, 0.10963050750433467, 0.1515934889903292, 0.23910598451038823, 0.23265449475729838, 0.1864306430798024, 0.09063528224942274, 0.17366206651786342, 0.17991541768424213, 0.13630649365950376, 0.1861369752441533, 0.14082649955525994, 0.08685162785695866, 0.14187145832693204, 0.135744153521955, 0.17215840111020952, 0.16040048125432804, 0.13851098396116868, 0.22129251068690792, 0.1893048029160127, 0.1268460403662175, 0.15792987163877115, 0.16026207071263343, 0.12465511652408168, 0.10310477329767309, 0.1050887863675598, 0.11378202223568223, 0.1302717049838975, 0.14737239049281925, 0.2560253633419052, 0.1401340906159021, 0.16241469973465428, 0.09555158016155474, 0.11743706985726021, 0.0740689282247331, 0.21007579460274428, 0.18713644036324695, 0.09214826903189532, 0.16523020021850243, 0.1017236513143871, 0.0682826922275126, 0.1946596210473217, 0.15250054188072681, 0.10488587577128783, 0.09751257923198864, 0.19630787166533992, 0.2180513588245958, 0.11427680467022583, 0.17314857454039156, 0.1792767847655341, 0.14802882011281326, 0.1355540449731052, 0.10626768053043634, 0.0737938289239537, 0.06181774733704515, 0.1533600379480049, 0.14341037574922666, 0.10649557181750424, 0.09036644667503424, 0.15078241063747555, 0.12942579021910205, 0.14036054955795407, 0.17242067609913647, 0.16677867650287226, 0.10414186530397274, 0.09218353588948958, 0.06533127481816337, 0.1354004055610858, 0.17315838573267683, 0.12086158414604142, 0.14934400969650596, 0.1300344106857665, 0.15036130120279267, 0.1669928157934919, 0.115094985376345, 0.16254209680482745, 0.16909693804336712, 0.08141841666656546, 0.10318314409232698, 0.11122406183858402, 0.12761299061821774, 0.09440934809390455, 0.12994290387723595, 0.15788583259563893, 0.09256019809981808, 0.31380681437440217, 0.1456056337337941, 0.06448134503443725, 0.13454389292746782, 0.15694182075094432, 0.13186273601604626, 0.12133805779740214, 0.15135923749767244, 0.14306229364592582, 0.27893133577890694, 0.11801142536569387, 0.2002057054778561, 0.14725234068464488, 0.12712994153844193, 0.13461355090839788, 0.15556507743895054, 0.23065660352585837, 0.11937928516999818, 0.12334221275523305, 0.10353936755564064, 0.17234622384421527, 0.10570277998340316, 0.19895526085747406, 0.10557652582065202, 0.15857350663281977, 0.17047745146555826, 0.11044789411243983, 0.20653527521062642, 0.2443747580400668, 0.08581612404668704, 0.17273835983360186, 0.14153645286569372, 0.15555574122117832, 0.17133672488853335, 0.3074820834444836, 0.18567593826446682, 0.1303058140911162, 0.1421768224099651, 0.07029175278148614, 0.22024165926268324, 0.21724353107856587, 0.05918871145695448, 0.14262359531130642, 0.23334351950325072], [0.0770820552133955, 0.0795081582327839, 0.02182444619393209, 0.033799101001932286, 0.014330867925309576, 0.017856724334706087, 0.062288788467412814, 0.031020221795188263, 0.01991049557545921, 0.02217707395175239, 0.05403244751505554, 0.06504820485133678, 0.04721600293123629, 0.02863250450900523, 0.02277284784213407, 0.02663730912900064, 0.01456444499126519, 0.03281397788668983, 0.03175394609570503, 0.0468486324098194, 0.05497202873812057, 0.020993058969906997, 0.04658930374716874, 0.019231066798965912, 0.021481822586792987, 0.09981967144994996, 0.044247530968277715, 0.042079209233634174, 0.053732104061055, 0.116215390880825, 0.011381740041542798, 0.03284247635747306, 0.047867556640994735, 0.011817494832939701, 0.10940519146970473, 0.052346644224599004, 0.07903034871560521, 0.05292056186590344, 0.06726094041368924, 0.039340339208138175, 0.051139682036591694, 0.04366003202449065, 0.002074840349450824, 0.04979180826921947, 0.09669779014075175, 0.027606409275904298, 0.045399099253700115, 0.07695873995544389, 0.059216582812950946, 0.05858652541064657, 0.04418691976752598, 0.06972694129217416, 0.018396412269794382, 0.0543864334031241, 0.0459035333187785, 0.06293833095696755, 0.05435729297460057, 0.07379300514003262, 0.031409745424753055, 0.03916165231203195, 0.07040606578812003, 0.05630993917293381, 0.052964111091569066, 0.03630163781053852, 0.02677882555872202, 0.03485265013296157, 0.033958302810788155, 0.017570049385540187, 0.04689823756052647, 0.03587214581784792, 0.037892661421210505, 0.045145600161049515, 0.054397799394791946, 0.07196373728220351, 0.009083553595701233, 0.05783003201941028, 0.05639883362164255, 0.049114925059257075, 0.09909283427987248, 0.04603836299793329, 0.07736345534794964, 0.026615842507453635, 0.039222059422172606, 0.02982552174216835, 0.01256873660167912, 0.038445505779236555, 0.056212079580291174, 0.030686396348755807, 0.011093208795500686, 0.05025386570196133, 0.039478174585383385, 0.0026133167284569936, 0.004222910729367868, 0.07577267664601095, 0.11067184459534474, 0.06721902391291223, 0.049712914260453545, 0.04986529944289941, 0.030351934510690626, 0.02260445453430293, 0.06766972277546301, 0.040691311442060396, 0.034332219074713066, 0.021248038647172507, 0.09160837886156514, 0.03799126687226817, 0.07883017664426006, 0.02022263732214924, 0.06013223719492089, 0.04075030476087704, 0.0722641586617101, 0.04391224720166065, 0.042751483706524596, 0.06285170748014934, 0.054820645455038175, 0.030905476487532724, 0.026339782125432976, 0.10519891366129741, 0.027044200869568158, 0.02485060158505803, 0.012693634489551187, 0.05262821134238038, 0.02879471387132071, 0.01300557214563014, 0.06328436473268084, 0.045834431948605925, 0.023445823644578923, 0.03145785885863006, 0.05006855513784103, 0.05018589239625726, 0.023288089432753623, 0.06481728560174815, 0.04460393625777215, 0.04675494368711952, 0.05898521085327957, 0.023519422429671977, 0.029058018590149004, 0.03907579695805907, 0.05598460389592219, 0.013990093193569919, 0.02209208319982281, 0.05208297028730158, 0.017333901705569588, 0.06155640374345239, 0.042105351385544054, 0.033102098168455996, 0.06965798835153691, 0.0025879102304315893, 0.05520685910596512, 0.017459031514590606, 0.03574526454031002, 0.05368897043808829, 0.07359027265920304, 0.04224091208016034, 0.040093986463034526, 0.0503425115311984, 0.033236133749596775, 0.004515444470598595, 0.049552391428733245, 0.017330471127934288, 0.027051967445004266, 0.0252337779966183, 0.020564422302413732, 0.10765709972474724, 0.03676636697491631, 0.048480385084985755, 0.021064301436126698, 0.07688790938118473, 0.030146521021379158, 0.03874816473398823, 0.013594835545518436, 0.08079912411631085, 0.018524803817854263, 0.06002419162541628, 0.04788541642483324, 0.025008732845890336, 0.02125301103660604, 0.0959409776260145, 0.01598961065610638, 0.017968011234188452, 0.04686800988565665, 0.04743590128782671, 0.00667829657686525, 0.04846777970669791, 0.015161838618951151, 0.047402133568539284, 0.015778983579366468, 0.0462352028262103, 0.056536041884100996, 0.040000227236305363, 0.017027795474859886, 0.03885924939822871, 0.027363381886971183, 0.028560614518937655, 0.046976222438388504, 0.02678969245607732, 0.050354879422229715, 0.031186344131128863, 0.04114559487788938, 0.08238945010816678, 0.021762207834399305, 0.03581711556762457, 0.029575985718111042, 0.02477038469805848, 0.035445596440695226, 0.059821214235853404, 0.014638666252722032, 0.049252107346546836, 0.0382802369131241, 0.052116856750217266, 0.07914748930488713, 0.006446549368774868, 0.04643835833121557, 0.007893658948887605, 0.003668874528557353, 0.011778821517509641, 0.01627892579563195, 0.05574815935688093, 0.04829945319215767, 0.05076438537798822, 0.022104916788521223, 0.03456135716987774, 0.060109601690783165, 0.1282717802678235, 0.05414471961557865, 0.026317198571632616, 0.04485666722757742, 0.03339597380545456, 0.027172084046469536, 0.07426820229738951, 0.03755860961973667, 0.05822816085128579, 0.02031528332736343, 0.03955604071961716, 0.018948147117043845, 0.09923980920575559, 0.028057354902557563, 0.06823481628089212, 0.023631765034224372, 0.003034608221241797, 0.025877134685288183, 0.009783701279957313, 0.021098781617183704, 0.042885990551440045, 0.028989523925702088, 0.03570499560737517, 0.09777642015251331, 0.0347158908698475, 0.041356787842232734, 0.0303779449313879, 0.015237465322570642, 0.03985037648817524, 0.0984224968124181, 0.032902979946811683, 0.08591883728513494, 0.05587222789472435, 0.06311807912425138, 0.047517121929558925, 0.008562905459257308, 0.03770659757719841, 0.0283060875517549, 0.017246960960619617, 0.04005260801932309, 0.01882792104879627, 0.03738734048965853, 0.04215317538182717, 0.02432476027024677, 0.020043495860591065, 0.013709249669773271, 0.03150181255477946, 0.06417824450181797, 0.01580567677592626, 0.035017069239984266, 0.06976441974984482, 0.01552887702928274, 0.021484791177499574, 0.015580657600366976, 0.007561722268292215, 0.06668800240731798, 0.04433897469425574, 0.038138427335070446, 0.019263084905105643, 0.08357271552085876, 0.022446852053690236, 0.015886711880739313, 0.04139883421885315, 0.06803045849665068, 0.03886141275870614, 0.04491233943554107, 0.03415910941839684, 0.053503388990066014, 0.017879883052955847, 0.05846648302394897, 0.047147959121502936, 0.03723281050042715, 0.016052815662987996, 0.03319029128761031, 0.06112739414675161, 0.03393588624021504, 0.03937057059374638, 0.08889316479326226, 0.0353289234044496, 0.03162394408718683, 0.060366221514414065, 0.06695412914268672, 0.04953399358782917, 0.027584313684201334, 0.026582770551613066, 0.034844931797124445, 0.04838549408304971, 0.02444134053803282, 0.004613969676938723, 0.048057320091174915, 0.04264772403985262, 0.037681976828025654, 0.03337297464895528, 0.054374388346332125, 0.04701481411757413, 0.03541349113220349, 0.07373515472863801, 0.023556542801088654, 0.05332231979991775, 0.03209143404092174, 0.032399763003923, 0.01135065333073726, 0.044970134185859933, 0.032265779373119585, 0.09803974156966433, 0.03572694091417361, 0.030004496220499277, 0.032577069505350664, 0.028578483579622116, 0.054547108375118114, 0.04648126930987928, 0.04697058211604599, 0.023150855195126496, 0.03557401396392379, 0.018017326947301626, 0.055705574923194945, 0.05215261713601649, 0.06378062404110096, 0.06264877461944707, 0.05733148689614609, 0.007600582976010628, 0.038844117007101886, 0.07883198748459108, 0.023790458471921738, 0.07456402978277765, 0.06471541099017486, 0.015363275124400388, 0.05460332235088572, 0.01799334815586917, 0.18370975158177316, 0.15774693223647773, 0.1456484556547366, 0.1728930085664615, 0.12486610910855234, 0.11232799908611923, 0.11874988456838764, 0.1701534297899343, 0.08025642862776294, 0.12646712944842875, 0.16761329578002915, 0.10561905830400065, 0.20090664911549538, 0.14376531529705971, 0.13988481805427, 0.09379940660437569, 0.11380719588487409, 0.09123543481109664, 0.270586478873156, 0.15282760636182502, 0.09630842236219905, 0.13683969707926735, 0.13577354256995022, 0.12363600675598718, 0.0912626419449225, 0.24092590872896835, 0.140789792931173, 0.1244336819218006, 0.22516977216582745, 0.21202810312388465, 0.16499293560627848, 0.09305988613050431, 0.12774314847774804, 0.13546469039283693, 0.2591074729571119, 0.12883863266324624, 0.12361849207081832, 0.18094299535732716, 0.1332368966541253, 0.16449207498226315, 0.12322523543844, 0.13455132924718782, 0.09142194394371472, 0.09720826899865642, 0.09935067864716984, 0.14526378567097709, 0.1394704621634446, 0.1785750247654505, 0.1054236656636931, 0.14363287162268534, 0.13746255193836987, 0.08937534556025639, 0.10108809830853716, 0.16758595505962148, 0.11701031267875805, 0.12122427171561867, 0.18842004414182156, 0.160957062325906, 0.1389440122875385, 0.1941792288562283, 0.13391766871791333, 0.2923116646707058, 0.09805727109778672, 0.12748544511850923, 0.10974293545586988, 0.17167910729767755, 0.12616170599358156, 0.08856110565830022, 0.07543804225861095, 0.11380501397070475, 0.13110950065311044, 0.11880397229106165, 0.1157044741557911, 0.2765594911761582, 0.17980595090193674, 0.1772168796742335, 0.20823531289352104, 0.11903430524398573, 0.19119503820547834, 0.15512939222389832, 0.14921322843292728, 0.09327004008810036, 0.1080825729877688, 0.09648667139117606, 0.13050178560661152, 0.1258478665840812, 0.15149754413869232, 0.11080784315709025, 0.17259246844332665, 0.18335411441512406, 0.16182844759896398, 0.032003534070099704, 0.08066806825809181, 0.17934921837877482, 0.22325909812934697, 0.27612649253569543, 0.22330361214699224, 0.14217931602615863, 0.11804464389570057, 0.06429670611396432, 0.09392208361532539, 0.14956039027310908, 0.16603793890681118, 0.09673604785348289, 0.12789842061465606, 0.12606402451638132, 0.1579430076526478, 0.07478530111256987, 0.0985245050105732, 0.11486877134302631, 0.10419579717563465, 0.13616048352560028, 0.1318376514245756, 0.15044828091049567, 0.14916372718289495, 0.2196906739845872, 0.2479819965083152, 0.19856830505887046, 0.10899324755882844, 0.08744469290832058, 0.11388262777472846, 0.16649339493596926, 0.11666032325592823, 0.1067522435914725, 0.32956542971078306, 0.10377994214650244, 0.11408482590923086, 0.16058319801231846, 0.22556834999704733, 0.14520399825414643, 0.08886341951438226, 0.14632723876275122, 0.10968206450343132, 0.13842026382917538, 0.08380413200939074, 0.10481316014192998, 0.24213566881371662, 0.15841927350265905, 0.08125282125547528, 0.09977014793548733, 0.2002140917466022, 0.1735589376767166, 0.18066448217723519, 0.23913492826977745, 0.15073737711645663, 0.19944334169849753, 0.1200531107315328, 0.19323870510561392, 0.10075351587147452, 0.11982634008745663, 0.10510909152799286, 0.20158969215117395, 0.15814528742339462, 0.1493144573760219, 0.12271601823158562, 0.13763801049208269, 0.15151004190556705, 0.11859446400194429, 0.14202766556991264, 0.12724086293019354, 0.16850863758008927, 0.10447671491419896, 0.15739712835056707, 0.20404300972586498, 0.1676374304224737, 0.159646013926249, 0.10396931596915238, 0.16928155469940975, 0.11276515375357121, 0.15675853996071965, 0.08159664343111217, 0.17068733082851395, 0.14816687442362309, 0.13448848418192938, 0.1806219422724098, 0.15739744005259126], [0.06337893661111593, 0.026073926273966208, 0.0499637675966369, 0.022601784658036195, 0.09218772902386263, 0.05902892335143406, 0.07903452700702474, 0.013263622458907776, 0.038068665453465655, 0.05433280210127123, 0.021966714048176073, 0.0061624543104699114, 0.03178073762683198, 0.02248307442641817, 0.03367052020621486, 0.05051701642514672, 0.07823655498214066, 0.13343160651857033, 0.019469683975330554, 0.06083628300984856, 0.028497702660388313, 0.03849525935947895, 0.056754953184281476, 0.009887114920275053, 0.027957988750131335, 0.08156685362337157, 0.04500355680647772, 0.037496161603485234, 0.026273408147972077, 0.031877142610028386, 0.0591177955357125, 0.029531241634686012, 0.07611960842041299, 0.05131963058374822, 0.021477187874552328, 0.04003868903964758, 0.028895456707687117, 0.08606178977061063, 0.006062389147700742, 0.028232431250216905, 0.0127056934616121, 0.00896614212251734, 0.13715153269004077, 0.01060370303093805, 0.04426893821801059, 0.028273778152652085, 0.023652548879908863, 0.03580720418540295, 0.007682805053264019, 0.017488006815256085, 0.04090785529115237, 0.022581516604986973, 0.03284642458311282, 0.01530674109744723, 0.017361607933708, 0.02925723329099128, 0.07880724428105168, 0.021921758452663198, 0.03276708899647929, 0.059480086056282744, 0.017537079475005157, 0.047642288845963776, 0.01944343421200756, 0.02212010669609299, 0.08391616662265733, 0.05124146759044379, 0.047203649883158505, 0.029222298544482328, 0.01902651049022097, 0.0391790148569271, 0.058369072430650704, 0.030583081970689818, 0.01819564091420034, 0.023904441222839523, 0.0880548644636292, 0.02677233176655136, 0.027457350770418998, 0.022917457172297873, 0.003726189434019034, 0.03286785780801438, 0.03867290724883787, 0.012755393236147938, 0.018875938003475312, 0.013217599098425126, 0.035909765283577144, 0.0513656919792993, 0.04561272646242287, 0.027275572829239536, 0.029059027910989244, 0.0624666886869818, 0.03733378340257332, 0.037974427541485056, 0.010475005346961552, 0.042302528891013935, 0.0543691042548744, 0.028135978027421515, 0.05470146395964548, 0.08907738811103627, 0.04081336133822333, 0.0444860052812146, 0.020953083185304422, 0.016397042309108656, 0.013084741676721023, 0.10326227929908782, 0.021159474454179872, 0.018875572495744564, 0.06926217873115093, 0.03551061228790786, 0.05877052608411759, 0.012989446204301203, 0.04926023386360612, 0.02565036960731959, 0.0667467359744478, 0.0365230056195287, 0.08763197387452237, 0.03335448775033001, 0.023481456009903923, 0.03387321557966061, 0.0628940544265788, 0.007845075178920524, 0.07332113280426711, 0.03323831195302773, 0.08556406843126751, 0.01853919035056606, 0.03052131116419332, 0.053369260640465654, 0.022616071000811644, 0.04271863625035621, 0.08214538742322475, 0.045502795837819576, 0.026616117102093995, 0.04040524690935854, 0.02690665678528603, 0.03924055374227464, 0.037843739046365954, 0.023478248076571617, 0.04384370244224556, 0.07802590378560126, 0.012865433327533538, 0.031838101931498386, 0.024774145531409886, 0.04001645058451686, 0.03819979181571398, 0.04138874472118914, 0.03023305172973778, 0.05859135679202154, 0.032117145747179165, 0.02814960571413394, 0.024155198079824913, 0.02216361139289802, 0.025741596255102195, 0.030677386675961316, 0.031688273447798565, 0.07497225553379394, 0.029451531263475772, 0.03495450990158133, 0.04689061941462569, 0.01608356469660066, 0.01847979441663483, 0.04212490326608531, 0.10865469463169575, 0.006933983149792766, 0.03659810725366697, 0.015269603100023232, 0.01357270470180083, 0.018735629419097677, 0.04788751670275815, 0.03414792154217139, 0.08379144870559685, 0.05670243510394357, 0.06679229642031714, 0.03465152811259031, 0.03553257243765984, 0.050708022972685285, 0.009724796091177268, 0.047948265200830065, 0.0458192550286185, 0.030660766278742813, 0.06670006972854026, 0.02717193005082663, 0.043808031114167534, 0.07044557030894794, 0.021850560515304096, 0.026549670765234623, 0.03727474184415769, 0.007374661627181922, 0.05550974812649656, 0.010587526066956343, 0.07457793020876125, 0.03391542151803151, 0.026637201517587528, 0.041198239123332314, 0.03187858979799785, 0.0686658630729653, 0.024960704758996144, 0.09671797655755654, 0.050881307033705525, 0.06379318860126659, 0.027641770757327322, 0.050552435423014686, 0.06346835056319833, 0.017163335760415066, 0.0563840389077086, 0.06452225963585079, 0.0355644291266799, 0.06330510033876635, 0.0597333291079849, 0.053113408939680085, 0.040638900973135605, 0.07104936681571417, 0.06132611531938892, 0.032497496431460604, 0.012413218628353206, 0.05720497669244651, 0.06101258761191275, 0.017526758056192193, 0.04065045250172261, 0.055384748193318956, 0.05057220252638217, 0.03695300969411619, 0.09528395428787917, 0.02725902850215789, 0.0027573021907301154, 0.018508214961912017, 0.023177169896371197, 0.007415542368107708, 0.027544939039216843, 0.054007002981961705, 0.004782770238307421, 0.05292767164064571, 0.038561848559766077, 0.06439569377107546, 0.05831380469317082, 0.06539552996400744, 0.00978748437773902, 0.022980561989243142, 0.03273773705586791, 0.02809843648719834, 0.04199303475616034, 0.0642752877320163, 0.02946976397652179, 0.006839159404989914, 0.03023237451998284, 0.08153811024385504, 0.07165831382735632, 0.04736681847134605, 0.06634203542489558, 0.016026888733904343, 0.03244839965191204, 0.02559730790380854, 0.035958561493316665, 0.10675927915144712, 0.061313717742450535, 0.031009401282062754, 0.028090256164432503, 0.0393760550650768, 0.053550956945400685, 0.01871161537565058, 0.007821541676094057, 0.036630075264838524, 0.06738014417351224, 0.030213206700864248, 0.018049547288683243, 0.026838484955078457, 0.03736787766683847, 0.03360304413945414, 0.0709550324245356, 0.06516101871966384, 0.03688815711939242, 0.042600887099979445, 0.0440138657722855, 0.01748628132190788, 0.03340637129440438, 0.04806551711226348, 0.060092228013672866, 0.026637541050149594, 0.025073550168599468, 0.018957006504933815, 0.031106925052881707, 0.054235543648246676, 0.03723685891600326, 0.0251672277590842, 0.06220082541403826, 0.048207007566816173, 0.026103909040102735, 0.010787271403387422, 0.05520292943401728, 0.0489622541499557, 0.004446338462003041, 0.0563189933745889, 0.055054358890629373, 0.07635269474121742, 0.04665542539441958, 0.021498643363884185, 0.04631455696653575, 0.0038611888794548577, 0.06290281176916324, 0.04425844053912442, 0.02103617774992017, 0.07820652768714353, 0.0037406754609037307, 0.03180120977049228, 0.03217770499759354, 0.036157598078716546, 0.060352565997163765, 0.020833506496273912, 0.05761839376646094, 0.008517951719113626, 0.01753060980263399, 0.07486474059987813, 0.046087804876151495, 0.11000385231454857, 0.020309054852987174, 0.01987816947803367, 0.03913617809303105, 0.04863924921664875, 0.05784628876426723, 0.08313314145198092, 0.013745171472692164, 0.06182802237162832, 0.030481507928925566, 0.03909110004315153, 0.05016980263462756, 0.052836591567029245, 0.01738473139994312, 0.03663674717245158, 0.057497215893818066, 0.03611124353483319, 0.029423350060824305, 0.05311624765454326, 0.0008702501929747086, 0.04902683955151588, 0.06114184005127754, 0.07431848280248232, 0.028121448631281964, 0.03911047380825039, 0.02495776399882743, 0.033656664309091866, 0.022177483988343738, 0.059344914989196695, 0.01735309178911848, 0.035706888083950616, 0.06840928035671823, 0.0249763399551739, 0.05165796828805469, 0.033455735247116536, 0.008672868552821456, 0.05350935956812464, 0.07153427868615836, 0.016622907533019315, 0.07420033289236017, 0.07573933937237598, 0.1656046137213707, 0.12033342733047903, 0.1232338220870588, 0.09624828613596037, 0.1828004722483456, 0.1687811393640004, 0.16299980896292254, 0.11022458187653683, 0.1084298016212415, 0.13618540484458208, 0.17559723142767325, 0.07884380989708006, 0.14135158387944102, 0.11032771813916042, 0.09771883691428229, 0.13797668216284364, 0.16832673718454316, 0.23839503672206774, 0.21358397119911388, 0.14624828909290954, 0.1181649905629456, 0.1486554302391596, 0.09637335286242887, 0.2151908099767752, 0.13396767462836578, 0.15384268626803532, 0.2283026892109774, 0.11363335521309637, 0.15272337914211676, 0.15830383985303342, 0.14423358079511672, 0.08449869317701086, 0.16125168011058122, 0.11423045754781924, 0.17781779664801434, 0.11462708353064954, 0.1006153279740829, 0.1652742689475417, 0.16573309432715178, 0.09841318285907619, 0.10170658191782422, 0.1285965886199847, 0.2095701397047378, 0.06435849732952192, 0.1587313020718284, 0.12232025314006023, 0.11768509561079554, 0.13651582383317873, 0.1387669358518906, 0.0709129823371768, 0.15487243101233616, 0.1292221448966302, 0.09656297901528887, 0.16825526836328208, 0.08055449739913456, 0.1268630355480127, 0.16997586353681982, 0.12115818346501328, 0.13722412957577035, 0.12126993606216274, 0.10421655504615046, 0.16181681072339416, 0.10389024755568244, 0.13108947750879452, 0.19439032534137368, 0.15140165865886956, 0.09911187036777847, 0.19970257388195023, 0.10008354947785847, 0.12783879647031426, 0.14294818101916462, 0.1557945495005697, 0.16822875884827226, 0.12396279664244503, 0.15028923866339028, 0.20352341729449108, 0.14884708245517686, 0.11647337625618093, 0.05285497827571817, 0.1108146931801457, 0.13300910184625536, 0.1912745667505078, 0.0770424616348464, 0.11827721071313135, 0.17784534516977146, 0.09135028958553448, 0.12994927150430158, 0.06774521403713152, 0.07614792135427706, 0.15265547262970358, 0.10080604508402757, 0.16668820870108902, 0.2205495466478169, 0.15648514759959653, 0.16170841263374314, 0.13821649976307526, 0.11098952090833336, 0.20772627380210906, 0.15126844315091148, 0.12966727023012936, 0.19762797426665202, 0.19484352524159476, 0.1273132223286666, 0.37876141956076026, 0.15904965373920277, 0.0960649385524448, 0.1566775716491975, 0.09133032581303269, 0.13812064396915957, 0.1025898044463247, 0.19794786960119382, 0.1201647668494843, 0.2095655829180032, 0.11742239017621614, 0.16552530782064423, 0.21936169476248324, 0.11766176248784177, 0.1983261719578877, 0.1278041530167684, 0.07603647303767502, 0.21196646033786237, 0.12260860719834454, 0.10789000050863251, 0.2543676132336259, 0.16249658830929548, 0.1518749410752207, 0.14870604471070692, 0.11287531073321588, 0.15853113000048324, 0.14387181348865852, 0.08498431750922464, 0.10198361080256291, 0.0843426120991353, 0.14145533612463623, 0.1354164507938549, 0.18110062752384692, 0.07715326428296976, 0.14567361446097493, 0.1728663209360093, 0.14835294568911195, 0.13746871176408604, 0.17452571861213073, 0.13253032753709704, 0.12798439100151882, 0.12459709541872144, 0.0976145280583296, 0.11338609387166798, 0.130379865586292, 0.11439522917498834, 0.08367585920495912, 0.13640108780236915, 0.10426794135128148, 0.17726183898048475, 0.09804421672015451, 0.19833439495414495, 0.16172131116036326, 0.17041891085682437, 0.20990339369745925, 0.19952920818468556, 0.16654400940751657, 0.20046744612045586, 0.09990663631469943, 0.1277912248042412, 0.11557246092706919, 0.09813964948989451, 0.09937510272720829, 0.14801317563978955, 0.14060088666155934, 0.14836664573522285, 0.18050959595711902, 0.14049753517610952, 0.2085402762168087, 0.156055859697517, 0.11957451453781687, 0.10091112577356398, 0.1007640543684829], [0.00773599663261848, 0.026443705064593814, 0.0703028924181126, 0.03400067944312468, 0.023666965098527726, 0.03377963075763546, 0.02057744699413888, 0.021606043264910113, 0.05661683579091914, 0.0207930297619896, 0.01272463399800472, 0.021706357510993257, 0.07224918954307213, 0.030816381658951286, 0.04447369305125903, 0.04139486372878309, 0.027830530452774838, 0.02811419228237355, 0.03062904317630455, 0.052789851106354035, 0.04226057899359148, 0.019603283544711303, 0.05094710584671702, 0.029930747150501702, 0.013641926670970861, 0.0331552359421039, 0.06914184690685943, 0.12421749430359341, 0.011471603920654161, 0.0057963055496657034, 0.05817170567752328, 0.05377925270295236, 0.12655635044211522, 0.05790469207568094, 0.05458512488985434, 0.04821636604901869, 0.038744275880162604, 0.06715211929986253, 0.08846711265505292, 0.04290631055482663, 0.01940853657288244, 0.07423882067087106, 0.05346222947991919, 0.02963823892059736, 0.03994161983428057, 0.038573656129301526, 0.05430719429568853, 0.05752810036938172, 0.02009125120821409, 0.06369216745952144, 0.03058208563743392, 0.08230415507568978, 0.024824086503940634, 0.0158149628987303, 0.033713468292262405, 0.04759826093504671, 0.010786620168801164, 0.04323070701502729, 0.009106835696002236, 0.0839346757857129, 0.013088544255879242, 0.011800018182839267, 0.04353551077656448, 0.050220981138409115, 0.03892530054145027, 0.08421930426266044, 0.07379477145150304, 0.016766227381594945, 0.07234891934785992, 0.04413064270920586, 0.048586374905426055, 0.022652655170531943, 0.010543925818637945, 0.02474120159604354, 0.03542313163052313, 0.054174995530047454, 0.04707550324383192, 0.028414021799108014, 0.0592702846188331, 0.06346081776428036, 0.06696770302369259, 0.03563933409168385, 0.005209757018747041, 0.054897235095268115, 0.061850368438172154, 0.059389889138401486, 0.023454085603589192, 0.12055705126840621, 0.012906411939184181, 0.047181789923342876, 0.05801235543913208, 0.04696567280916497, 0.03182282482157461, 0.07108044053893536, 0.020361995957500767, 0.04575782746542245, 0.07346528756897897, 0.05461235428811051, 0.06355797231663018, 0.009677508296590531, 0.04010385702713393, 0.027371291325835045, 0.06862232126877643, 0.015483745173696661, 0.01731944466882851, 0.030917907461116556, 0.015731595594843384, 0.0578794701868901, 0.03626369179983158, 0.015819913023733534, 0.030919102318875957, 0.01925788244989235, 0.08098525475361384, 0.03432644145505037, 0.05681300397554878, 0.011140881579194684, 0.02150721145881107, 0.07782231783494353, 0.03421646630158648, 0.019135157199343666, 0.005071114555903478, 0.013837735841661924, 0.020529641551547684, 0.030750644073123112, 0.017496500695415307, 0.027581478680076543, 0.047581065373378806, 0.03594667599827517, 0.012515964335761964, 0.07144564398913644, 0.029942298679088708, 0.05682240327587351, 0.024891510620363988, 0.012414766006259015, 0.01630128299439093, 0.05717026644560974, 0.07690782120334916, 0.025959334961953573, 0.024634039182274137, 0.06912400567671284, 0.031560650022584014, 0.04175239708274603, 0.06382805469911546, 0.05213008924329188, 0.04992850444978103, 0.024339933479495812, 0.05055393085058313, 0.044098507714807056, 0.058795903823920526, 0.04505868724663742, 0.017380721947120037, 0.017336710734525695, 0.01335030345217092, 0.058982635600841604, 0.027830116705445107, 0.04877009727351833, 0.03254808492783923, 0.01743897497362923, 0.03250065055908635, 0.039808241053833626, 0.07915620954008773, 0.07337015907978639, 0.04512537663686089, 0.018999418389284983, 0.053438940885826014, 0.05472831857332494, 0.06499479990452528, 0.034167573612648994, 0.06166165512695443, 0.04915458914183546, 0.05426145944511518, 0.07236598132294603, 0.043991015045321546, 0.02069450965791475, 0.01941216381965205, 0.03760172468901146, 0.029800325828546192, 0.018244017810502555, 0.0515156800247496, 0.014933990933059249, 0.038429141422966495, 0.00580552858991723, 0.019227330085413996, 0.023969254834810272, 0.010780633820104413, 0.024193218305299524, 0.04459485979168676, 0.03612244996475056, 0.027593956037890166, 0.0014260558941714407, 0.03373985906364396, 0.043214505931246094, 0.03688733333547134, 0.12553447246318683, 0.0550236117123859, 0.03150172720779665, 0.04392418093630113, 0.004247509214110323, 0.046559365509892814, 0.029261613817652687, 0.02316824371519033, 0.041382380804861896, 0.08719985096831806, 0.046433731040451676, 0.037620434231939726, 0.010678643247956643, 0.008072682594502112, 0.02994309277710272, 0.016428943526989315, 0.018476254372217227, 0.02019915762502933, 0.04698430813732557, 0.01797538632672513, 0.09749884949997067, 0.09455457897274755, 0.0710503984009847, 0.0661966264306102, 0.04047283058753237, 0.0252015984733589, 0.03596980131987948, 0.0033289075781794963, 0.06890606658998877, 0.023190860665636137, 0.011455003932496766, 0.012760034442180768, 0.02466676232870668, 0.019730263156816363, 0.02259081014926778, 0.013390878521022387, 0.04627886708476581, 0.06404646133887582, 0.08290624464279972, 0.09226910551660694, 0.06491913052741438, 0.026331932058383245, 0.09447731397813186, 0.020121300767641515, 0.018583576347737107, 0.009045412771229167, 0.014454044030571822, 0.013720650913455756, 0.04289498167054262, 0.030027389620954636, 0.017121163218689617, 0.04214777625747956, 0.023899003135738894, 0.031068574571690988, 0.034075424846378155, 0.003728337255779479, 0.017505688483652193, 0.04169474705122411, 0.03188019654771779, 0.006832360868429532, 0.02281596291140886, 0.03682755334011745, 0.08607265481259674, 0.046253723121481016, 0.044371662588673644, 0.061063202083460055, 0.037122557041584514, 0.023108116765797604, 0.05866602798050735, 0.11540929233888164, 0.06288067350396886, 0.03811166920058895, 0.05608070088783279, 0.018482401210349053, 0.01740025898470776, 0.021817772430949844, 0.025980760765378363, 0.025827880199358333, 0.026364271143393125, 0.09234796612872742, 0.008697313041921007, 0.036790609228773974, 0.027280621288809925, 0.047422642819583416, 0.004922204016111209, 0.0399901266064262, 0.06586129442439415, 0.0208873122028308, 0.010100449908350129, 0.05355436711397488, 0.026870239598792978, 0.04767273545439821, 0.04017075050796848, 0.025404117586731445, 0.021648720467055682, 0.07442086207447574, 0.015095313428901136, 0.05199124454520643, 0.01254277163752704, 0.027721482983906753, 0.02440283049509162, 0.022825317682872992, 0.019961625839641783, 0.02284435191540979, 0.027755558694479987, 0.08340341679286212, 0.02990085158671718, 0.020759308426931966, 0.008983469415397849, 0.03174239827785641, 0.06709631721605547, 0.034654570918064564, 0.02973479604406748, 0.04223635158268735, 0.09042941790539771, 0.03904587727447506, 0.026449905708432198, 0.0359517374454299, 0.013963889814476715, 0.024657930771354586, 0.027385349458199926, 0.03410026081837714, 0.033589140002732165, 0.0220332809840329, 0.05160854125279002, 0.01113923586672172, 0.024137184300343506, 0.017318184873147402, 0.0469652238098206, 0.04876408587733749, 0.042302298825234175, 0.02468508781021228, 0.013796280400129035, 0.03502713647321798, 0.03087704852077877, 0.0328552821156336, 0.02625188215461094, 0.052956385334255174, 0.01554250564367976, 0.018289786057721358, 0.03894285604474135, 0.03920930561434943, 0.03865407525154296, 0.01322089145105565, 0.10163234488572925, 0.031439891463378444, 0.0473538383084815, 0.02537033687985968, 0.09557454963214695, 0.04254245039192028, 0.04575958264467772, 0.06310806755209342, 0.04304393813072238, 0.04596117592882365, 0.029672502023458946, 0.06126899221271742, 0.03567738771380391, 0.026863812599913217, 0.032772996491985396, 0.09295632684370503, 0.17835165315773338, 0.1925324328476563, 0.10101919731823727, 0.18246951891342178, 0.15564625355182216, 0.13472254271619022, 0.11792024510214105, 0.1168822922045365, 0.09041712793987244, 0.10720948819653131, 0.10555607223068364, 0.13294668722664937, 0.13936669507529587, 0.10323825597879477, 0.11411852683522739, 0.12357964806142263, 0.2087751214276068, 0.15169909660471603, 0.11615002993494272, 0.1429823791841045, 0.09931158972904086, 0.14685500966152176, 0.11421063478337601, 0.09786337017430924, 0.234577844676096, 0.2259592540212907, 0.19813429709756747, 0.11544835899258032, 0.11772557976655662, 0.16116042563226074, 0.1793169794837013, 0.1692338494467549, 0.13222558685811237, 0.14559868723154068, 0.1170336309587583, 0.17742563097272068, 0.17216142907273024, 0.17104756931075826, 0.1687272297567688, 0.1330617646453902, 0.08846664510201663, 0.1575855299597606, 0.09833311254624277, 0.10609116070554592, 0.10279552778229117, 0.09100453782593831, 0.08545218966901302, 0.09406366312759928, 0.17218839871929958, 0.08960258375736885, 0.08932540644309483, 0.1459582132520154, 0.13892483519157395, 0.11485342372907326, 0.1620164336054586, 0.12095535450498573, 0.1491168382926844, 0.12198345168144442, 0.2150930988136679, 0.1046181534184143, 0.17676166113233194, 0.14338809647597373, 0.1405475559295155, 0.08120568745653145, 0.25039228436071426, 0.13713360240217298, 0.11856344222906046, 0.17243896261788905, 0.15439190523466095, 0.13952162582427263, 0.08162720507243648, 0.08333047109772451, 0.1719743336434476, 0.13537002203520387, 0.16190319671295583, 0.22638536553131416, 0.11176338797667995, 0.1259467948693782, 0.19939088670071214, 0.17472344159614295, 0.14504292252240703, 0.1034252623503562, 0.10062394430860877, 0.14654458413133398, 0.15643845166778192, 0.20154013152932748, 0.20568357169395313, 0.08206795173464343, 0.17691482556983829, 0.14471777278231457, 0.1336035769782029, 0.12493728107074276, 0.1525001708068885, 0.1190117810619995, 0.14254118723329157, 0.23510258761234581, 0.15216336934827268, 0.12463378719985485, 0.1217064302181825, 0.1364107950939797, 0.10455937532242388, 0.17359416000545025, 0.10456141622853465, 0.19951353402575478, 0.16927491989918053, 0.1240852584305685, 0.10581379043287598, 0.0967044620483648, 0.10803389552165754, 0.16359566448954865, 0.27111482864711434, 0.14420331601286307, 0.16299921524478123, 0.1877393017639406, 0.09703288465971127, 0.06873109785374254, 0.19148802326526493, 0.11934331327211112, 0.11065521306591108, 0.17023957829223946, 0.14407958515221253, 0.19151810993207619, 0.18846745253540576, 0.07713059909292497, 0.06758169663953595, 0.1750942927901633, 0.1706695489701815, 0.1022158213891089, 0.19392686896026134, 0.1745459792437032, 0.31484216975513846, 0.19868166069500148, 0.13198711996665224, 0.10871474922169, 0.15993732173228636, 0.21820293506607413, 0.12464521627407521, 0.0753616529982537, 0.11698225949658081, 0.07541984479757957, 0.14794984075706452, 0.09670147861470468, 0.12796413036994636, 0.1409719159710221, 0.1667434541741386, 0.11704984688549303, 0.11002771978382953, 0.2308832257403992, 0.1436614739941433, 0.14211694593541324, 0.17612417112104595, 0.12007325261947699, 0.1907093173940666, 0.13097024406306446, 0.12090284755686298, 0.05806368608318735, 0.0916148503893055, 0.1450587747967802, 0.15997337526641786, 0.13186251337174326, 0.1348367889295332, 0.13953140733065084, 0.2167896187165752, 0.07758625550195575, 0.19049556402023882, 0.17361161531880498, 0.16666058596456423, 0.1884845070890151, 0.1296420520520769, 0.13769567536655813, 0.12124459914048202, 0.1870810316177085, 0.15797860105521977, 0.11576980541576631, 0.18679656641324982], [0.014604431908082915, 0.025323084337287582, 0.03303874844277743, 0.03576172537577804, 0.0319106468668906, 0.025493592765997164, 0.03417150699533522, 0.00960344845225336, 0.006342246542772045, 0.007878160122345435, 0.03794968062720727, 0.021220360249571968, 0.020225568805471994, 0.011605722065723967, 0.037615443288814276, 0.026105137294507585, 0.034391683657304384, 0.02000355347263394, 0.06354174154694192, 0.09205674738041125, 0.027498317322169896, 0.03056841898796847, 0.010847518951777602, 0.07661030904273503, 0.026066597565659322, 0.03552692098310217, 0.030711319523106795, 0.013624484345200472, 0.044984721098444425, 0.0390536141640041, 0.004921318077322212, 0.013040334342804272, 0.02010279531532433, 0.028205122071085498, 0.07081590199959464, 0.01121763820265187, 0.03655721491668373, 0.022808543290011585, 0.013313869567355141, 0.017092564557970036, 0.047844019427429885, 0.03242228347517084, 0.04071484123414848, 0.0633675669087097, 0.05955614506092388, 0.039515860844403505, 0.08697413417394273, 0.0009210256757796742, 0.02372481736529153, 0.03373890169314109, 0.02359963003982557, 0.08297071501147002, 0.04528969184320886, 0.029258136855787598, 0.010771354191092541, 0.02075323023746023, 0.056201325860456564, 0.021335116689442657, 0.029142437888367567, 0.07490986317861825, 0.00678703512676293, 0.04946672161167953, 0.03904859724570997, 0.04388455025036819, 0.015271050287992693, 0.061507336649810895, 0.04805510106962174, 0.07127834905986674, 0.07956757457577623, 0.03840736681013368, 0.02387150099821156, 0.05071980085631367, 0.024121428505168296, 0.06177168594149407, 0.017926462096511386, 0.2102946094237268, 0.045894668364780955, 0.05036856833612546, 0.02457191400026204, 0.06677967990981415, 0.0837176718050614, 0.0675783198676072, 0.028727991084451787, 0.039878986281109974, 0.1031811922439374, 0.02833501832355978, 0.03617202914028894, 0.01831283159845043, 0.019933810144721065, 0.033276629037573, 0.007138223581932834, 0.054718555620638654, 0.06315816994174384, 0.018874129018513486, 0.011916926850972231, 0.00970111230344628, 0.038244127717916854, 0.04490322586207185, 0.06451060791732743, 0.03763944434467703, 0.021228227014944423, 0.06758660965715535, 0.06483322693384252, 0.06253884770558216, 0.033451167328166775, 0.036007862363476306, 0.00689616330419085, 0.03109739216597518, 0.027768344043579418, 0.040289256648975424, 0.02022869881329825, 0.011551380157470703, 0.0694054429186508, 0.04840193265408743, 0.021397805903689004, 0.03187425194482785, 0.03647049867140595, 0.019751824402192142, 0.0926164751581382, 0.02356665085244458, 0.08014577440917492, 0.031874225969659165, 0.009824076896620682, 0.06245333745027892, 0.04708384869445581, 0.030381533215404488, 0.03205913206329569, 0.038451680447906256, 0.08288524186355062, 0.01983544589165831, 0.013610128426080337, 0.00770785810345842, 0.01638755580643192, 0.025064341971301474, 0.009219234889314976, 0.015859439808991738, 0.057627292117103934, 0.06844831732450984, 0.03499002537864726, 0.014732150884810835, 0.0512405139306793, 0.03848486558126751, 0.09570110807544552, 0.09517081387457438, 0.03027988495887257, 0.030262162472354248, 0.016280916606774554, 0.07718621563981287, 0.05125467410834972, 0.07668214151635766, 0.04480983770918101, 0.025797435446293093, 0.03597719311073888, 0.036852188932243735, 0.03697050211485475, 0.02435999002045719, 0.026478003419470042, 0.10132140727364458, 0.03400454603252001, 0.05751120166678447, 0.016810169945529196, 0.037903036645730026, 0.017917027544172015, 0.04111090318474453, 0.054012613618397154, 0.017987223582167644, 0.002501907838450279, 0.03475199635431636, 0.030688405713590328, 0.04397985685500316, 0.026295885945728514, 0.09951043335604481, 0.027814837740152143, 0.01565300401125569, 0.027934304962400347, 0.0634162814822048, 0.03244406922021881, 0.034653491093195044, 0.04473990513361059, 0.028325502134975977, 0.014602626633859472, 0.04373255469545256, 0.04304225345549639, 0.01439818350263522, 0.011574328291317215, 0.04770490755618084, 0.03623828808485996, 0.058868073974736035, 0.07496271151467226, 0.029414310702122748, 0.04113945360586513, 0.026068896368087735, 0.04016258317278698, 0.030699406197527424, 0.03907606784196105, 0.023049904557410628, 0.10363081499235705, 0.027694643213180825, 0.06576375395525247, 0.05090652521175798, 0.004857528629145236, 0.02848520303814439, 0.04948117864842061, 0.07359285533311777, 0.016653801285428926, 0.03588000516174361, 0.021435434646264184, 0.0207469071392552, 0.02793020088574849, 0.0226418420788832, 0.030781530404055957, 0.025147978303721175, 0.04286932562536094, 0.05049064420745708, 0.033351303936797194, 0.02154649333533598, 0.07752838282613084, 0.021102533173689153, 0.09295729905716144, 0.03471670723229181, 0.038819911860628054, 0.041902002922142856, 0.04084591935679782, 0.03913883127097506, 0.04048527640406974, 0.03617426671553403, 0.031783234953763895, 0.059190232859691605, 0.126192549651023, 0.04156779155891854, 0.014158715639496222, 0.008799833321972983, 0.026916848328255583, 0.008564500149077503, 0.015228171778289834, 0.013624840576085262, 0.02596587142761564, 0.04839878594793845, 0.045656524307560176, 0.02874706799047999, 0.041468918934697285, 0.03038884522538865, 0.03687763717607595, 0.02747800845099846, 0.006008923901390517, 0.07904358120867983, 0.015899421159701888, 0.004969552574038971, 0.05288385524181649, 0.021707671112380922, 0.030537630991602782, 0.026591390596877318, 0.004935383167321561, 0.015949211847328115, 0.09495680817053653, 0.021630187184200622, 0.048873419073061086, 0.004778014927069307, 0.026098075759364292, 0.0235662927661906, 0.047117523645283654, 0.0189461210538866, 0.05315103582688607, 0.01371551988995634, 0.016738383856136352, 0.08207094258978032, 0.05376508510380518, 0.008073432163655525, 0.03388288205314893, 0.07314179281820543, 0.012189936078357277, 0.019882201195287053, 0.055883901877678, 0.00751538349504699, 0.026645073849067558, 0.051194467378081754, 0.03755212324904278, 0.057787243495113216, 0.037861079326830804, 0.03530445108481217, 0.04039474923047237, 0.044117933430243284, 0.03235108182707336, 0.03690987607114948, 0.006848644979982055, 0.0022139712382340804, 0.009901687917590607, 0.035256693881819956, 0.08506171609042212, 0.03145822251099162, 0.033804607737693004, 0.03921391806215979, 0.02308531056769425, 0.025027483206940815, 0.027528175778570585, 0.026331345761718694, 0.09697828485514037, 0.08427656095591374, 0.07563049599411897, 0.055608502007089555, 0.015885741522652097, 0.05838682089233771, 0.04408474458614364, 0.019087442669842858, 0.08685678578331135, 0.06283198861638084, 0.05628863953461405, 0.05041274838731624, 0.010610878671286628, 0.02837938205630053, 0.10977694066241384, 0.020209573667671066, 0.03867609106237069, 0.07420596579322591, 0.019343082858540583, 0.04174550995230675, 0.06161523378978018, 0.02130391865648562, 0.12933348189108074, 0.07945798904984258, 0.013045303949184017, 0.0446479456149973, 0.025786856131162494, 0.053370373861980624, 0.033153532713185996, 0.06345387868350372, 0.041742329849512316, 0.002740596214607649, 0.023962581071828026, 0.025110772585321683, 0.00918445784918731, 0.031443724656128325, 0.04532517021289095, 0.021750424384663347, 0.052598250840674154, 0.029659375286428258, 0.08769603606197052, 0.040161314100259915, 0.0972166181600187, 0.020378642329887953, 0.01121398869145196, 0.039951928265509196, 0.030297318007797003, 0.021834198014403228, 0.06204576478921808, 0.03674311919894535, 0.013456939868774498, 0.042049463954754174, 0.02074001258733915, 0.042766608676174656, 0.04940229206113145, 0.056013952125795186, 0.1216617232421413, 0.10394243538030423, 0.13305587199283764, 0.10512165608815849, 0.10469791202922352, 0.14836931746685877, 0.11690532104694284, 0.14217986521543935, 0.0726336962543428, 0.1524809343391098, 0.10064391550258733, 0.12172620845376514, 0.13325766194611788, 0.11834309858386405, 0.13515283993910998, 0.18122385372407734, 0.10976989025948569, 0.09000635662232526, 0.1615308760665357, 0.2170341563760303, 0.14718351390911266, 0.17865893198177218, 0.14406018541194499, 0.21397667122073472, 0.09793254575924948, 0.111328838247573, 0.18436806625686586, 0.17415572830941528, 0.12209554566652514, 0.15995918540284038, 0.1432428730186075, 0.11650473941699602, 0.10883732975344174, 0.20022624812554568, 0.1350069633917883, 0.19227115233661607, 0.15075817209435627, 0.21221273462288082, 0.08230216611991636, 0.08397097422857769, 0.17696785944281146, 0.1945545626222156, 0.2021110212081112, 0.11720132664777339, 0.23774231784045696, 0.141471455572173, 0.21601180342258886, 0.17818420979892835, 0.10606155643472448, 0.1332531200023368, 0.09564953623339534, 0.12485519953770563, 0.2700383879709989, 0.0990148790879175, 0.15954588336171582, 0.14987992937676609, 0.1250188282574527, 0.11445853437180631, 0.19054447155212983, 0.19083897059317678, 0.088912876235554, 0.2103758745943196, 0.10851181636098772, 0.15514905913732946, 0.1272683817660436, 0.1450896481401287, 0.13739535788772628, 0.1314897177508101, 0.34053000854328275, 0.14861676434520632, 0.1455620548222214, 0.10307747710612603, 0.09122915624175221, 0.17311811679974198, 0.11869538866449147, 0.25952740979846567, 0.1336458497098647, 0.21250632824376225, 0.12078858650056645, 0.1438273736857809, 0.13696228503249586, 0.13506220886483788, 0.08129004738293588, 0.1140659827797208, 0.2204469224670902, 0.17864815599750727, 0.10941762986476533, 0.12508063431596383, 0.12905997078632936, 0.12943573499796912, 0.09480483859078959, 0.1575038640294224, 0.17406894156010821, 0.11745823590899818, 0.13191167323384434, 0.13628657441586256, 0.1116870432451833, 0.1720552722690627, 0.1706246638786979, 0.11284758409601636, 0.13490377517882735, 0.13873797724954784, 0.1727700198534876, 0.17450041137635708, 0.18262179277371615, 0.08663605622132309, 0.0942390994168818, 0.10101481122546829, 0.061652307776967064, 0.18352696060901508, 0.10403977546957321, 0.19182118820026517, 0.1508573378669098, 0.10934984209598042, 0.08355453290278092, 0.1124198324396275, 0.17904527921928093, 0.08378505139262415, 0.177589378436096, 0.16406599315814674, 0.420882337493822, 0.17101015022490174, 0.14677703962661326, 0.1485513662919402, 0.19875455443980172, 0.23785876081092283, 0.12545936711831018, 0.14738049474544823, 0.16969677148154005, 0.1334336251602508, 0.15221051056869328, 0.15328628331189975, 0.14436676661716774, 0.1230318020679988, 0.19971556146629155, 0.10509240804822184, 0.11261279083555564, 0.1295588127686642, 0.08977465069619939, 0.08666126697789878, 0.11807663046056405, 0.08498845869326033, 0.2322860629647039, 0.28518455335870385, 0.12215459093567915, 0.09157391352346167, 0.0893044333497528, 0.13925566978286952, 0.13016814569709823, 0.16972280602203682, 0.13580644939793274, 0.11250046678469516, 0.12466056388802826, 0.18771446950268, 0.0926772273669485, 0.12670798605540767, 0.1407475201995112, 0.15610028465744108, 0.15817954496014863, 0.1611189395771362, 0.17001500440528616, 0.07436857777065597, 0.2704719209577888, 0.12313124985666946, 0.16274685534881428, 0.0974435372336302, 0.13983874552650377, 0.11297364530037157, 0.18002044642344117, 0.1073513126175385, 0.0988638075068593, 0.13935191149357706, 0.11209049698663875, 0.08132463146466762, 0.11346375962602906, 0.11084166282671504], [0.018386970295978244, 0.022537672375619877, 0.013955348622403108, 0.035402859866735525, 0.05272078684356529, 0.01876609087048564, 0.017915687967615668, 0.028433898369257804, 0.04209872771752998, 0.04528067845967598, 0.06269266523304395, 0.015158405258262064, 0.037733344579464756, 0.02711445813474711, 0.03256160314776935, 0.06374243312166072, 0.01356701242912095, 0.02660933016159106, 0.07633350280229934, 0.03536626085406169, 0.028729195219057146, 0.08071366581134498, 0.03814050534856506, 0.049428567799623124, 0.042603239708114415, 0.05686444965249393, 0.026967139965563547, 0.03146041555737611, 0.02302842494827928, 0.05014350463170558, 0.031751916321809404, 0.01727594182739267, 0.02880709474993637, 0.03523426617903169, 0.048420412131235935, 0.018551246539573185, 0.021852592144568916, 0.04137535266636405, 0.06972251067054458, 0.03487567155389115, 0.020543297068797983, 0.008421871425525751, 0.053166220168350264, 0.03864965576212853, 0.03229292713513132, 0.009972665066015907, 0.03938845264201518, 0.015983853445504792, 0.02963397157145664, 0.029094361561874393, 0.041890251013683155, 0.0210765617157449, 0.09614021459128708, 0.038944678017287515, 0.09598932854714803, 0.058424970993655734, 0.01958727170858765, 0.01551344221297768, 0.019639782367448788, 0.03613865475927014, 0.030980320225353353, 0.03789363363466691, 0.04932739451760426, 0.07074738692608662, 0.0254436332397745, 0.04947396126226522, 0.03807984961895272, 0.04196111869532615, 0.03490360228170175, 0.08469871681882069, 0.0693685284932144, 0.05485863599460572, 0.02016138230828801, 0.055729501764290035, 0.010581510032352526, 0.04074332486197818, 0.004670329763030168, 0.06363800552207977, 0.023276202082342934, 0.03842053622065578, 0.034793107624864206, 0.05907898121222388, 0.07023077050689608, 0.0478062589536421, 0.005837867211084813, 0.054317042595357634, 0.13908626715419814, 0.050256017930223607, 0.025464880927756894, 0.09450933765037917, 0.07190128555521369, 0.0181838314892957, 0.021560106179094873, 0.025389361835550517, 0.02583039979072055, 0.053628392633982, 0.05304037418682128, 0.03201067724148743, 0.13516505568986759, 0.026260530030413065, 0.017549838848935906, 0.06930491159437224, 0.0675056636100635, 0.0236508809030056, 0.053883568980381824, 0.04073625219461974, 0.043744113645516336, 0.010653919525793754, 0.021497493034985382, 0.03609872350352816, 0.047532948228763416, 0.023662280291318893, 0.018136755206796806, 0.016680180924595334, 0.02176105565013131, 0.031190956578939222, 0.05017677140131127, 0.03521258804539684, 0.0722529819176998, 0.07303346152184531, 0.019720806340046693, 0.038172588392626494, 0.02592498651210917, 0.04406874388223514, 0.030027432294446044, 0.047245098830899224, 0.02862517208995996, 0.03519505109579768, 0.10017271852120757, 0.02433811892842641, 0.012798091775039211, 0.04655970689782407, 0.01167081583844265, 0.03573533831513487, 0.008854396946844645, 0.04164717909588944, 0.01563914254802512, 0.043359870396670885, 0.02196237248426769, 0.10256707246298902, 0.04045065892569255, 0.054093173748697154, 0.043466491042636335, 0.024189084542740602, 0.05305469763698056, 0.019804526164080016, 0.014998884325905237, 0.04032646793348249, 0.01610546918527689, 0.013599750418507028, 0.10243142271065153, 0.06334622274152935, 0.17482272611232474, 0.019668510904011782, 0.09433992017875426, 0.030738968234800268, 0.01837897922086995, 0.01206538143378566, 0.042216643851133995, 0.017822982590587344, 0.09968166908947751, 0.011961400978179881, 0.05364573291444685, 0.11047897525713779, 0.052957409498048946, 0.08403925923630595, 0.03793350551859476, 0.005548319686567993, 0.029541908152168617, 0.040118429096764885, 0.04385097177873831, 0.02062922478216933, 0.016777240853116382, 0.04139278571528848, 0.037093616992933676, 0.08407566900132224, 0.057434304035268724, 0.033778651122702286, 0.02802815695758909, 0.009405586315551773, 0.03180392974172719, 0.030388676386792213, 0.044850581616628915, 0.02366133590840036, 0.06045255184289999, 0.045356811679084785, 0.02165711972338613, 0.07337181406910531, 0.055954242634470575, 0.07159463755670004, 0.03240133264625911, 0.05223081352596637, 0.014122064676485024, 0.03482274158159271, 0.03913895372534171, 0.038599004183197394, 0.01949568511918187, 0.04498963782680221, 0.045513178483815864, 0.0805999687872827, 0.027172978334419895, 0.008176403298421064, 0.013405671379587147, 0.019269326367066242, 0.01083400537027046, 0.027090043331554625, 0.026608322696120013, 0.055904425971675664, 0.026237829588353634, 0.046509010790032335, 0.038058806021581404, 0.040894199773902074, 0.03271421097451821, 0.08744866339839064, 0.06912589815328829, 0.06144608720205724, 0.032931764144450426, 0.04706368454208132, 0.025452106710872613, 0.006315073269433924, 0.04933210715535097, 0.06826778990216553, 0.045585934931295924, 0.03598545692511834, 0.0702856077987235, 0.04306029135477729, 0.033551108645042405, 0.016302192125294823, 0.014570455459761433, 0.023055218334775418, 0.05414628183643799, 0.08249701699241996, 0.037551321729552, 0.01620967042981647, 0.011747770986403339, 0.03678437147755176, 0.008280409729195526, 0.02659411242348142, 0.05217178681050427, 0.041070329971262254, 0.045469157994375564, 0.060613249079324305, 0.004993103239030461, 0.0484830976347439, 0.023318328239838593, 0.09922934492351487, 0.06524301861645654, 0.04986047177226283, 0.009164591483568074, 0.04905586123641115, 0.007882741028879536, 0.002404909369033703, 0.018579273746581748, 0.06384597756550647, 0.013911466357967583, 0.029325967298063915, 0.026537775993347168, 0.0043569778517849045, 0.02623165306431474, 0.03308803446998354, 0.06834023093688302, 0.03138451240374707, 0.047186424635583535, 0.036597977377823554, 0.05868991029274184, 0.019485541815811303, 0.034895665012300014, 0.026567860804789234, 0.09154350031167269, 0.0500399898737669, 0.01550832974317018, 0.014685345486213919, 0.07816558339982294, 0.017550970624142792, 0.0987091290880926, 0.05155023813131265, 0.033712447839207016, 0.03823272461886518, 0.03690631747303996, 0.034044462445308454, 0.05870861241419334, 0.062471460696542636, 0.05776285281172022, 0.055010501673677936, 0.08132551462040283, 0.04365709683042951, 0.035624880765681155, 0.04447388229891658, 0.04351060058979783, 0.04891311655228492, 0.03634453023551032, 0.02543315782531863, 0.030093663408479188, 0.03553036454832181, 0.047756516505614854, 0.01885044708615169, 0.022743616500520147, 0.031219859520206228, 0.0258535603643395, 0.04334931705670897, 0.09325341598014347, 0.02362689840083476, 0.01313690074312035, 0.04019282940134872, 0.055742711992934346, 0.053682903380831704, 0.022026458791515324, 0.06129215093096718, 0.010847157154785236, 0.05415202605945524, 0.022844121849630028, 0.034373827584204264, 0.033892708088387735, 0.049002222513081506, 0.016688906725903507, 0.045056880117044784, 0.026915798189293128, 0.0416463478904916, 0.0457814092078479, 0.05012049063225277, 0.026764466856548097, 0.08126419837935828, 0.01192425277622533, 0.051802501548081636, 0.022865454884595238, 0.025130020185315516, 0.03917035770427901, 0.035620754424599, 0.15824639762286097, 0.03610195555665996, 0.051855553974746726, 0.006312955829343991, 0.04105435895326082, 0.007808570790075464, 0.04901257547317073, 0.04268783341103699, 0.08873591112205759, 0.03859589087369386, 0.052597608882933855, 0.09276166892959736, 0.04841087182285264, 0.0848729805147741, 0.0556396981846774, 0.01719037776638288, 0.01913037776830606, 0.03599276707973331, 0.02692498226679163, 0.014407033613679232, 0.0379429901659023, 0.0068842119435430504, 0.03555785369826481, 0.027563119801925495, 0.12300386762944981, 0.08769852225668728, 0.09621119359508157, 0.12026078591588885, 0.09195336620905437, 0.2261543201166205, 0.1353075183578767, 0.10046463488833979, 0.27939725609030575, 0.1757443102542311, 0.12038385626510717, 0.16729789786040783, 0.14190671034157276, 0.23245706863235682, 0.2565921563655138, 0.10503606419661082, 0.13110396423144266, 0.12123884749598801, 0.16050496080424637, 0.14283083262853324, 0.06374039221554995, 0.1354554877616465, 0.0934669170237612, 0.21344121167203411, 0.09883349077426828, 0.11231800977839157, 0.11973029133514501, 0.1439929913613014, 0.1493274004315026, 0.1438759101438336, 0.24083558935672045, 0.13244885456515476, 0.1770961916190572, 0.11697109017404728, 0.11896630225237459, 0.13941698300186545, 0.12537436152342707, 0.16589146864134818, 0.1558545298757963, 0.17673538910457864, 0.13817030849168077, 0.08215742505853996, 0.1512167154578492, 0.09382212374475785, 0.15300523198675364, 0.11412110208766535, 0.1369404065189883, 0.15101292170584202, 0.24942814547102898, 0.18594308174215257, 0.10451187787111849, 0.08582406502682716, 0.13995723682455719, 0.15342686092481017, 0.22105198062490672, 0.22653232561424375, 0.23043194058118388, 0.10577248249319382, 0.125091974332463, 0.09381033101817593, 0.125035185192246, 0.09538657846860588, 0.12212318324600346, 0.11186442396137863, 0.14263777033193037, 0.16678841348038986, 0.1374826196115464, 0.11816979967989028, 0.20551133406115696, 0.158518394746352, 0.2281220949953422, 0.16464279033243656, 0.08882419700967148, 0.19959598663263023, 0.09798067403608002, 0.2174075011862442, 0.13807293871650472, 0.12900499248644337, 0.11103516299044713, 0.16205468389671296, 0.22795108932768926, 0.16163063555723056, 0.19771191116888076, 0.1278437688597478, 0.1972174330148846, 0.07834737989469431, 0.271305323112756, 0.08437456155661494, 0.17752065556123853, 0.14015714172273874, 0.13185101008275524, 0.16137970058480278, 0.24601622542832047, 0.15239125321386382, 0.19664681050926447, 0.13121310446877033, 0.12332310987403616, 0.1169910687895026, 0.39190010516904294, 0.12492822686908767, 0.10618139102007262, 0.16595072171185166, 0.1419682046980597, 0.11091171414591372, 0.12077375096851029, 0.14530472253682092, 0.2157948142848909, 0.161286739166826, 0.182530909369234, 0.13030118308961391, 0.09047175743035041, 0.16222631296841428, 0.12278937952942215, 0.2041675866348669, 0.2735820540692657, 0.11107402184279636, 0.13684217585250735, 0.16087924072053283, 0.12417028628988191, 0.12455881544156, 0.10826802827068605, 0.1497451405157335, 0.08503695062245242, 0.17105022619944066, 0.21732442517532036, 0.09308900800533593, 0.08749645770876668, 0.13250233372673392, 0.1884549399255775, 0.2821414510253817, 0.08293282095110044, 0.11771406905609183, 0.09249711554730311, 0.07665038501727395, 0.08160362704074942, 0.08193966408725828, 0.1544636263861321, 0.157075080787763, 0.10117797981365584, 0.14053775958018377, 0.11387552542146295, 0.19566312344977632, 0.13600553793366998, 0.14150788018014282, 0.11793293582741171, 0.15028132736915722, 0.0925444571475964, 0.13290344970300794, 0.09393074447871186, 0.1211163931293413, 0.1897338978596963, 0.16289711056742817, 0.3142060007667169, 0.18063593917759135, 0.17573190154507756, 0.07980828275321983, 0.11661510419799015, 0.145167751761619, 0.175603658426553, 0.09847160472418182, 0.1812104950658977, 0.13006978144403547, 0.2013834789977409, 0.298327513737604, 0.14187942899297923, 0.20638423331547529, 0.10123390064109117, 0.08450560257188044, 0.10936989492620341, 0.1704896820592694, 0.11466675132396631, 0.0767329712107312, 0.19164378521963954, 0.07907478851848282, 0.16843808902194723, 0.22787718626204878], [0.015567311929771677, 0.01294098674406996, 0.031906334988889284, 0.10276296234223992, 0.00905927330677514, 0.06263451054110192, 0.013732814713875996, 0.03645874676294625, 0.025369544637214858, 0.020463827895582654, 0.04527119752310682, 0.01706521270534722, 0.06918695464264601, 0.09197632825816981, 0.05763549284893088, 0.05098425033793319, 0.01941703045304166, 0.06049014162272215, 0.013667029816133436, 0.03142246954666916, 0.029435823707899544, 0.04811337450519204, 0.05741989523812663, 0.022287978645181283, 0.08849033445585519, 0.0413375402422389, 0.06234485030290671, 0.024533942014386412, 0.030075486356508918, 0.046981113191577606, 0.010961727130052168, 0.03297267132438719, 0.057264830902568065, 0.03484565910184756, 0.0344895469606854, 0.016718466467864346, 0.1599723956314847, 0.029819115152349696, 0.08570242702262476, 0.01350703947537113, 0.016851010332175065, 0.07312479763641022, 0.040191482403315604, 0.029516430222429335, 0.01854904792708112, 0.060276217554928735, 0.053774354528286494, 0.04071852228662465, 0.011124092343379743, 0.0696235749637708, 0.01659961893892614, 0.020263349688320886, 0.05587111467320938, 0.04182546523225028, 0.030949062820582185, 0.01937794339028187, 0.0010991379872393736, 0.01485278420659597, 0.04197847381874453, 0.04024990055768285, 0.03330239269416779, 0.028544938504637685, 0.02704630300286226, 0.016504499726579525, 0.047179630273603834, 0.017043321204255335, 0.08292473154142499, 0.04148839660047088, 0.01877101130958181, 0.05007734216633253, 0.06134016417490784, 0.009203774097841233, 0.03520342994306702, 0.033305698962067254, 0.010228519549855264, 0.02058250473055523, 0.04647230416594539, 0.023074196906236466, 0.009061004366230918, 0.09245147346518934, 0.027515728106664028, 0.06169532636704389, 0.08839410758810118, 0.02778141511953436, 0.054683314738213085, 0.07442586414981633, 0.00614633810982923, 0.02780862596409861, 0.060919388706679456, 0.03829987414064817, 0.053445323355845176, 0.016843310550029855, 0.039773835087544285, 0.018481599690858275, 0.02636200388224097, 0.02497914341802243, 0.0463392445089994, 0.045541491417679936, 0.014418447844946058, 0.06076626137655694, 0.035981638575321995, 0.024017789437493775, 0.017076472940971144, 0.03958974906709045, 0.03045584075152874, 0.024133406768669374, 0.0237163253405015, 0.013959246753074694, 0.02084650706819957, 0.044753427064279094, 0.030107215025054757, 0.05030724096286576, 0.04927912523271516, 0.05374171487346757, 0.0293782237713458, 0.03597508912207559, 0.0419437116215704, 0.03371954277099576, 0.0414721918059513, 0.053969891887390986, 0.014931768200767692, 0.02484014843503246, 0.09543576801661402, 0.05843011036631651, 0.04333011027483735, 0.04837884072912857, 0.02275211038067937, 0.016403567642555572, 0.027201538032386452, 0.07458737032720819, 0.08176327042747289, 0.03467181471933145, 0.024067825033853296, 0.005961483966530068, 0.059052902142866515, 0.030748972385481466, 0.03455322323134169, 0.005672981942552724, 0.04627038804756012, 0.029747676016995683, 0.0475979529437609, 0.022170398333400954, 0.019588195682445075, 0.052404171801754273, 0.027806141624751035, 0.016530782886547968, 0.06892638659337536, 0.04983218852430582, 0.027729140092560556, 0.03759415849344805, 0.0710520608117804, 0.0634955354325939, 0.05270884568744805, 0.050655738668865524, 0.05935669658356346, 0.01638181714952225, 0.022096838511060923, 0.03698288855957799, 0.11549561895662919, 0.05378431415010709, 0.006215710827746079, 0.021772390100522898, 0.05762242362834513, 0.03288888656243216, 0.04643362342903856, 0.07260656333528459, 0.024897765069908928, 0.03515190262987744, 0.07307824271265417, 0.03076573379075853, 0.02354418047616491, 0.07504054796299897, 0.009196825740218628, 0.027516427580849268, 0.012261600641068071, 0.026097379995917436, 0.05370866332668811, 0.01176820509499521, 0.019555904837034177, 0.05011444583942648, 0.02776826611807337, 0.027411396986281034, 0.01545690169223235, 0.05007835519791115, 0.03509628979372792, 0.05610182983218692, 0.042862442205660045, 0.01737252121529309, 0.06331951284664683, 0.03613169341406319, 0.01166196294434485, 0.02425055849016644, 0.018977055624418426, 0.03632067389844451, 0.07909743886557408, 0.07853017828892916, 0.0170956927104271, 0.052597252652049065, 0.040700365643715486, 0.04455431626411155, 0.0032970251459119027, 0.03974641273089219, 0.06100928134401329, 0.026364640361862257, 0.018526002386352047, 0.027220924785069656, 0.032267041024169885, 0.10242333330097608, 0.07707642973400652, 0.025384194632351864, 0.04396990465465933, 0.02511868759029312, 0.02839787081029499, 0.05554764960834291, 0.07454664868419059, 0.027907654439331964, 0.023803683543519583, 0.10557896748650819, 0.0055624395099584945, 0.015936461750243325, 0.05949870654148981, 0.003853910961879592, 0.05023338242608588, 0.0298797115101479, 0.011872852555825375, 0.048305011878255755, 0.044855171800008975, 0.017900711427500937, 0.059142460813745856, 0.03932899177016225, 0.04710555280325934, 0.07455756567651406, 0.07006441810517572, 0.07118897963664494, 0.05707906391762663, 0.045546526889665984, 0.015195981122815283, 0.04389640977024101, 0.027098327554995194, 0.016400437634729315, 0.02508025547285797, 0.010025680385297164, 0.039250691479537636, 0.03971156147599686, 0.05900115218537394, 0.08652319040265866, 0.05506299377884716, 0.032294088596245274, 0.10795421112561598, 0.04090034475666471, 0.042176742281299084, 0.016450423136120662, 0.007617504870722769, 0.0401382333075162, 0.037652175888069905, 0.09489305768511258, 0.01747955375321908, 0.018564480888016988, 0.02345479620998958, 0.04151223438384477, 0.020923458505421877, 0.07170412660343572, 0.06967369961785153, 0.009485429345659213, 0.0441042074089637, 0.035406347960815765, 0.01117888510634657, 0.007510816967624123, 0.05512968316907063, 0.010057729105028557, 0.051343813465791754, 0.034675573697313666, 0.04492403197218664, 0.060038233059458435, 0.01995830472878879, 0.09664966186392121, 0.07049275605822913, 0.06379707745509222, 0.0938559731002897, 0.018743557411653455, 0.03068733145482838, 0.05825409149110783, 0.04747197337565012, 0.020498706981015857, 0.040552604041295126, 0.03634525754023343, 0.05894914247619454, 0.043447280550026335, 0.02363137169595575, 0.034260746542713605, 0.014883840303809848, 0.09893161754007451, 0.02424391441309126, 0.04733740715892054, 0.044616029554163106, 0.044988005101913586, 0.07925146419438533, 0.025728295113367494, 0.004673431940318551, 0.034652229442144744, 0.037210026566754095, 0.05061323587142397, 0.06669484500889666, 0.021222022660367656, 0.016698821818863507, 0.05993594284518622, 0.03527410466631409, 0.08159042423358187, 0.006283042175709852, 0.08060166088398546, 0.05827512766700238, 0.03964409654145129, 0.05260792844637763, 0.045548549242084846, 0.05081577168311924, 0.01988499723665882, 0.05780856910860166, 0.011646584716800135, 0.020878886971331667, 0.049009599460987374, 0.06924764747964218, 0.021921194420428947, 0.026916894712485373, 0.07473699472029693, 0.028604408653336577, 0.014166526743792929, 0.006641182699240744, 0.08100287333945744, 0.06858093169284984, 0.017143260665761773, 0.07196545164333656, 0.03300605312688276, 0.10083554545417428, 0.06975443044211715, 0.050503835882409476, 0.06271511520026252, 0.03181103580573108, 0.007855429066694342, 0.07223057647934183, 0.041568722954252735, 0.05460792366648093, 0.043513116470421664, 0.06919986801221967, 0.052828546686214395, 0.01769082464306848, 0.020223238461767323, 0.04877051658695564, 0.013315201722434722, 0.04017380444565788, 0.033768736029742286, 0.04420750694407616, 0.0756755517795682, 0.10297756176441908, 0.04463036413653754, 0.11116186986328103, 0.18798679317114875, 0.14354212180478498, 0.13519414787879214, 0.20031177322380245, 0.14342011272674426, 0.11499869171530008, 0.10138238954823464, 0.15366837062174454, 0.13255321537144482, 0.1348747275187634, 0.17919703357620165, 0.08301609734189697, 0.14370938704814762, 0.12472266680561006, 0.11204906288185157, 0.1018192176707089, 0.18994422251125798, 0.08860491463565268, 0.11770352313760668, 0.15491023601498455, 0.1511539742932655, 0.14338318345835432, 0.15696407033829018, 0.14220673096133396, 0.0673898885725066, 0.10276921864715405, 0.11430621598265134, 0.11795640995842405, 0.13748061581281945, 0.24606413848232478, 0.15246331575326622, 0.1208997676440049, 0.12998550315387547, 0.21905303554376587, 0.11562450032215565, 0.15277813479769975, 0.13599804224213585, 0.07008307569776662, 0.1902618765598163, 0.09186408584355377, 0.05665089294780046, 0.09221719970810227, 0.10553610103670508, 0.15705657162470743, 0.09812742631766014, 0.06174991503939964, 0.22102104790974408, 0.15534906793618575, 0.10919520820607431, 0.20063436997588724, 0.13102575670927763, 0.28787875722628087, 0.239486706268508, 0.1873758275178261, 0.19309872121084481, 0.13731078273849562, 0.12000640737824142, 0.11017547396477312, 0.13704680080991238, 0.09547361012664624, 0.12086014437954873, 0.17531720426632091, 0.12542775162728503, 0.19446390186203644, 0.1126054955238942, 0.11867267894558609, 0.2054132369812578, 0.13249737618025392, 0.09489699106779881, 0.13214274833444506, 0.11719158967025578, 0.17021127277985215, 0.1668599565164186, 0.13790442666504532, 0.2005879263742827, 0.11772317520808429, 0.1730840967502445, 0.13499851775122806, 0.23061054584104568, 0.16515197785338387, 0.10153239243663847, 0.12354554637568071, 0.17778301960788667, 0.11440573798608966, 0.17527968127978966, 0.15571312105748802, 0.21409197128377855, 0.09946986014256254, 0.11507077651913278, 0.15175097272731364, 0.10927418756182306, 0.18418301915517077, 0.18592350388644263, 0.1282661102595739, 0.2091678511351347, 0.10030583754996769, 0.1347384840482846, 0.1054409948119428, 0.1669452292844653, 0.19489777623675764, 0.09628483690903522, 0.06700357102090493, 0.08331406963407062, 0.1317992081749253, 0.15020579157862812, 0.12144415522925556, 0.11491453959024511, 0.2182525402167812, 0.18672239617444575, 0.19135452574118972, 0.11182799935340881, 0.13795415055938065, 0.14016760600497946, 0.15809977892786264, 0.15643626975361258, 0.16850319021614268, 0.14300884417025372, 0.1979803162976168, 0.07298666911083274, 0.11694467713823542, 0.1252983952872455, 0.12968335999175906, 0.20342275238363072, 0.10180844910792075, 0.0930639605212491, 0.10506396894925274, 0.20584351936122403, 0.24166922899894416, 0.2045290867681615, 0.1611659917398356, 0.13528178067645058, 0.24445081333396956, 0.08810983534203842, 0.14734499040059745, 0.15881381405051798, 0.1303863074281253, 0.09585157851688564, 0.10329595053917728, 0.06618340135901235, 0.15283522079698741, 0.13986666512209922, 0.19007887778570876, 0.0909230500110425, 0.14464024803601205, 0.172457649896387, 0.1370408636284992, 0.07787056485540234, 0.12433732888894156, 0.17239287524716929, 0.20563212601700798, 0.08194354551960714, 0.22174847137648612, 0.11100096482550725, 0.15268953720806167, 0.14313055638922378, 0.16591591498581693, 0.18467570131178945, 0.13642832462210208, 0.11456971551524475, 0.23016598453978077, 0.17637523968005553, 0.18590503925224766, 0.11558306621736847, 0.11703064010362141, 0.15831639699172229, 0.1665870688157156, 0.060671648679999635, 0.14454316027695313, 0.18188484013080597, 0.1525763893732801, 0.170613219961524, 0.13598584133433178, 0.1291116836364381], [0.044018634071107954, 0.044300549998297356, 0.03245862644689623, 0.019619662743934896, 0.025700227088236716, 0.038464727404061705, 0.01792706138076028, 0.02306458609382389, 0.04825326563150156, 0.08737470838241279, 0.05680572721757926, 0.0427357909939019, 0.03664538206066936, 0.06830533515312709, 0.05418108856247272, 0.01642004517634632, 0.02108803531882586, 0.023566524687339552, 0.10516273396206088, 0.028867650289612357, 0.014177640405250713, 0.10172786671319045, 0.05044177749368828, 0.03449173258559313, 0.01696685401839204, 0.028128634476161096, 0.027668927796185017, 0.04227402670949232, 0.05293016154610086, 0.05445873714052141, 0.055052948810043745, 0.0899863186350558, 0.017708018349367194, 0.039932821673573926, 0.013094510195514886, 0.009960766583390068, 0.07312162866583094, 0.03842179416096769, 0.06299936518189497, 0.02863243771571433, 0.02713335878070211, 0.041732481549843214, 0.05226887085882481, 0.013132073072483763, 0.07021895551588386, 0.057765275923884474, 0.01416077231624513, 0.007410967491523479, 0.04496777786698658, 0.009830516883084783, 0.02493705993401818, 0.017804714625526685, 0.022398892615456134, 0.07080112583935261, 0.03707189804117661, 0.013600441543530906, 0.0301957550982479, 0.04693360831879545, 0.08244974218541756, 0.029452175076585263, 0.06646549169090576, 0.05017655617848504, 0.05668395562679507, 0.02806649816193385, 0.028961305615666788, 0.019984804966952652, 0.05509831629751716, 0.026873573697230313, 0.036798472283408046, 0.01709155894786818, 0.03601817079470493, 0.04123314603930339, 0.007432764832628891, 0.03292728528322186, 0.044258318084757775, 0.06018140818923712, 0.0651044596452266, 0.06665030130534433, 0.049723014890332706, 0.04626188674592413, 0.028358768904581666, 0.03961157563026063, 0.08438504810328595, 0.042393772237119265, 0.03563324105925858, 0.024801540057524107, 0.012503674370236695, 0.03742772445548326, 0.0024405978592767497, 0.03926545650756452, 0.03329797320475336, 0.08067166767432354, 0.036233267455827445, 0.06313028003205545, 0.029714626325585414, 0.021375179676397238, 0.01141977325460175, 0.04456097332877107, 0.05039715215389151, 0.0045566967492050026, 0.05016619950765744, 0.019212470433558337, 0.04222396142722573, 0.024386621989833657, 0.031524284786428325, 0.05330896114173811, 0.01986863288038876, 0.025121420549112372, 0.02871075841540005, 0.009325711744168075, 0.06815231914515607, 0.017083397178794257, 0.06638197039137594, 0.011955545433011139, 0.03624138284067158, 0.048267704114550725, 0.034514557337388396, 0.011229025531065417, 0.035686263800016604, 0.004141221143072471, 0.1245216783718206, 0.03793106385273859, 0.06892252000398003, 0.009968205686163856, 0.03678342895000242, 0.07180361892096698, 0.11511967662954703, 0.02029923994996352, 0.05093946914712433, 0.07966187185957097, 0.03872049004712608, 0.044840321424999274, 0.052992134587839246, 0.03708229924086481, 0.040924212225945666, 0.06534658532473259, 0.022938745678402483, 0.0193725591088878, 0.018973968290083576, 0.015946753483149223, 0.033073247177526355, 0.04479945506318472, 0.061989732639631256, 0.049970109248533845, 0.019998362149635796, 0.09575054253218696, 0.03813717310549691, 0.03644557735242415, 0.036518934939522296, 0.0346879601420369, 0.008655393758090213, 0.007028027175692841, 0.025541260911268182, 0.010491576576896477, 0.025193915389536414, 0.040688279768801294, 0.01570805281517096, 0.058457966879359446, 0.04155672613705974, 0.018358944944338873, 0.05570795721723698, 0.07840741964173503, 0.07297146250493824, 0.04835055748117156, 0.036750651997863315, 0.026522029475017916, 0.037398238928290084, 0.01685508843365824, 0.041000145065481775, 0.08246764278737828, 0.0730923806258943, 0.0577395976142725, 0.05302742742060218, 0.07761360364384018, 0.028517868668131996, 0.013880614351364784, 0.01524889717984479, 0.06637817801674828, 0.04406109233968891, 0.023103995990823023, 0.019473474494589027, 0.07270889065694064, 0.02896235389926005, 0.05459026055177674, 0.0649780644744169, 0.04518512694630772, 0.03014793666807236, 0.027536337547644507, 0.04270926663593855, 0.06983730607316829, 0.03691805082780775, 0.020863912286586128, 0.017878712314995937, 0.05655599452438764, 0.04542336377198808, 0.030488046249956824, 0.040164390302379616, 0.022930114500923082, 0.036310936920926906, 0.01884684581455076, 0.04016921426227782, 0.04188360879197717, 0.04506482480792329, 0.05753907673351932, 0.057599279753048904, 0.01750938994518947, 0.036626153014367446, 0.022503583677462302, 0.04031842676340602, 0.058812290444620885, 0.034754204243654385, 0.02878496947232634, 0.03838752549199853, 0.014644304719695356, 0.009018480232043657, 0.06670858958386816, 0.057300123735331, 0.05397250424721278, 0.06634308185311966, 0.059268199183861725, 0.02677511853107717, 0.03274872826295905, 0.01802456103177974, 0.06255562766455114, 0.029768790118396282, 0.04316904938605148, 0.03176319325575605, 0.017481583527114708, 0.04299773572711274, 0.04106326843611896, 0.04803495918167755, 0.021553590122493915, 0.028264048596611246, 0.03412417652725708, 0.019770773287746124, 0.056712721270741895, 0.06280786139541306, 0.015013347856438486, 0.012688938550127205, 0.03877334209391847, 0.07870949601056054, 0.010106788777193287, 0.02613283239043085, 0.04177987138973549, 0.023582824105687905, 0.04085281761945225, 0.07345882346271537, 0.03813805626123212, 0.0375098468066426, 0.049895538249984384, 0.05920371026149951, 0.03921068229828961, 0.03213978125131689, 0.0787533717812039, 0.05075134955404792, 0.06233491294551641, 0.037983882502885535, 0.08046630799071863, 0.008968209003796801, 0.00959907070864574, 0.048005206481320783, 0.0030338220085468492, 0.04308599192881957, 0.036070210189791396, 0.05717114960134495, 0.031506450977758504, 0.0290763886005152, 0.014059148179512704, 0.009079457868210739, 0.047940747244865634, 0.027966534580627922, 0.021133955706318375, 0.009470452805544483, 0.020530320616671816, 0.0449261211178964, 0.032965776772471145, 0.02682553262275178, 0.0024627954962852527, 0.07644696976058185, 0.08844325260724872, 0.0705845003540162, 0.058754703495651484, 0.018161427906306926, 0.008830840251903282, 0.03885644779074937, 0.07775705336825922, 0.014600017057091463, 0.04156528309977148, 0.05369526013964787, 0.03572024674213026, 0.030016522723599337, 0.014151232935546432, 0.0290445411883411, 0.02756464120466262, 0.018449080635036808, 0.1625127374427393, 0.02260441928228829, 0.024336091009899974, 0.03448039999057073, 0.01845710325142136, 0.045241088591865264, 0.026566137166810222, 0.03258801247284282, 0.02254393981274916, 0.05230542905337643, 0.037957877648295835, 0.05006560510082636, 0.07837172975996509, 0.027629347205220256, 0.033735365359461866, 0.0530699599039508, 0.004525067342910916, 0.037843282625544816, 0.046036440835450776, 0.013892844945075922, 0.0456029820634285, 0.03409918841498438, 0.05481490123202093, 0.06373509328113869, 0.06776153386454098, 0.025608050491428003, 0.06835396809037775, 0.07116713823052123, 0.04269621225830633, 0.023962727645994164, 0.037276997973094694, 0.07437797336024232, 0.05343400189303793, 0.010096822661580518, 0.025489746585662942, 0.075192101940047, 0.03269756089139264, 0.06433293776353821, 0.03758571656362619, 0.007282045307874796, 0.06647134723607451, 0.04238369016093202, 0.03959563058742788, 0.028833177530032117, 0.03133637299470138, 0.04307144583435729, 0.021054696189821698, 0.05060538023826666, 0.053634259311365895, 0.03254599949286785, 0.01365712492770399, 0.05046413840318564, 0.029087326001899783, 0.02882295815652469, 0.07484168949304149, 0.020119773798796814, 0.011895732041011797, 0.1675255739246495, 0.22634609107626602, 0.11365020196535625, 0.08744535341975279, 0.10079658270115033, 0.16923049493925646, 0.18049122038064525, 0.1521849213168025, 0.16267075552605093, 0.2528989326674491, 0.07971087587065995, 0.24819776852382347, 0.10096438229084015, 0.11587285262066871, 0.18815999559592456, 0.08063913192017935, 0.2045858759083785, 0.24144855880877003, 0.27605331677477807, 0.18036582710919902, 0.1319015651824884, 0.18168662732932717, 0.1734171132557094, 0.23002034547971562, 0.13637085270602256, 0.1488801822415553, 0.1264067631564103, 0.17129369516624138, 0.17248568823561072, 0.16666986281052232, 0.13119039474986494, 0.15260824235156178, 0.12670500262174755, 0.10258679874823429, 0.20089165773242712, 0.08347315641003661, 0.13485356146702543, 0.1294211740605533, 0.12827575817937031, 0.11123198797577061, 0.20385560259455815, 0.1328465566621162, 0.1378332547028549, 0.18848677806090564, 0.16598254500422627, 0.15209233097266406, 0.10250970444758423, 0.15026854758616537, 0.10927264389465563, 0.09123778741923161, 0.15480266913073137, 0.130305279744789, 0.1444673424703069, 0.13107300183037296, 0.1888094490277581, 0.14842456293990836, 0.18639208108652383, 0.11266952802543528, 0.16802598926005885, 0.17338261823169887, 0.18566887301858515, 0.14862926211208105, 0.14869620383251458, 0.17846621107310057, 0.18084491312038153, 0.10903518632403575, 0.14273782668169588, 0.1082585436233785, 0.136026956315618, 0.14164146676193923, 0.16592746280366555, 0.11632657944574021, 0.17813957703765482, 0.14054675441002473, 0.10255962872179225, 0.1629166884231381, 0.15246255876263604, 0.2543502766638994, 0.18259794014738873, 0.20592793123796582, 0.06467083760071546, 0.19566984730772674, 0.2133226313162595, 0.1390707414248027, 0.11742495800717734, 0.09887981563224457, 0.07612719316966832, 0.12502204917836934, 0.1540067305904813, 0.1371122433920391, 0.14930762961739674, 0.1344906067242846, 0.11083473116741516, 0.13494460814399645, 0.12669663119595498, 0.10119756509084255, 0.12980639323359355, 0.14150252187391743, 0.1267080899560824, 0.08199789299396798, 0.10106247937073931, 0.0911102419195231, 0.2217832038877532, 0.142344206396956, 0.12553557084174827, 0.13687290076632053, 0.13788614014629275, 0.19428272877121344, 0.11274700082140043, 0.30040784273296595, 0.10406670800875872, 0.11911191904800944, 0.24296616174979135, 0.12669015966821462, 0.1050952504738234, 0.09031114183017053, 0.0767721417651046, 0.18232687812997028, 0.21703486883779988, 0.24885563791031018, 0.22474079596577212, 0.1095042607630603, 0.09238891041604802, 0.22687132382998243, 0.09106603218242526, 0.18175886798417196, 0.22091760736657307, 0.13256715290481225, 0.18038908601738513, 0.14507943618809804, 0.10447325650602579, 0.29892455670051277, 0.13956710463389754, 0.08215443420340307, 0.1509298011660576, 0.12659917236305773, 0.15393435634905472, 0.10229805135168135, 0.21620103623718023, 0.14123425033176318, 0.24973206978756934, 0.1492642585071735, 0.12809213600121439, 0.21123020531376824, 0.08728017361136153, 0.15155127563048154, 0.16331911057932302, 0.11232362041482702, 0.13212241348810494, 0.15275064564775676, 0.11853020143462345, 0.12050760196871124, 0.09347868748591281, 0.09568357112584636, 0.1248006516834721, 0.1512574148364365, 0.11510894517414272, 0.1342472416581586, 0.2003312620217912, 0.16569649160373956, 0.19024121516849846, 0.11850395909277722, 0.11292343901004642, 0.14815424307016656, 0.11240490784985013, 0.09363225268316455, 0.13055015879217535, 0.1673933380516246, 0.14662299945484847, 0.1618489160318859, 0.22459719039034098, 0.17617315286770463, 0.11705297132721171, 0.1806264100014232, 0.05847575986990705, 0.11419194750487804], [0.08356299338629469, 0.034471086037228815, 0.02254317168990383, 0.018911271654360462, 0.07193863784777932, 0.06052186101442203, 0.02690041346795624, 0.024903444355004467, 0.022724331793142483, 0.07207144517451525, 0.015436753310495988, 0.024859624245436862, 0.02935584430815652, 0.013636941293952987, 0.05294579859764781, 0.022929737860977184, 0.022226803412195295, 0.023923770459077787, 0.0040854552389646415, 0.028384092838678043, 0.017020797022269107, 0.017526761766930576, 0.046837437112117186, 0.04949302332533989, 0.009409456615685485, 0.040950502807390876, 0.054206588756642304, 0.02960946956591215, 0.05796591183752753, 0.06718718577758409, 0.014564119373972062, 0.060573507071239874, 0.020474305165407714, 0.08629941803519614, 0.03404188719287049, 0.020717098777822684, 0.05423716895165853, 0.03436698498262558, 0.0810486712725833, 0.06406949760275893, 0.034278276070836, 0.0447860704298364, 0.03726413655385841, 0.05145013354194816, 0.03719450454809703, 0.030386396138055716, 0.058797428937396035, 0.036970884320908226, 0.08633828430902213, 0.02528628865547944, 0.050211088309879415, 0.041047586855711415, 0.09247735215467401, 0.05814717398607172, 0.11563477164600044, 0.08095320881693624, 0.022511908719025087, 0.02539412827900378, 0.06144118160591461, 0.033160475504701026, 0.03263887185312342, 0.03207887690223288, 0.0430692082591122, 0.03289138760010246, 0.014596591117879143, 0.026798251274158247, 0.08092053205473348, 0.01913512565806741, 0.08925208225264214, 0.02295137703185901, 0.06055344310880173, 0.04822664850507863, 0.032303246698575094, 0.0043931436357524944, 0.023622206172149163, 0.030824738241790328, 0.07294957656995393, 0.025141404730675276, 0.04581458691973239, 0.05939394497545436, 0.04174055240582675, 0.09095876215724275, 0.061121854014345445, 0.11756961001083255, 0.047020176134537905, 0.019803754330496304, 0.01840079279645579, 0.041340516254422255, 0.036382773105287924, 0.06486579979537055, 0.03284466569311917, 0.026104853423021268, 0.002580577115622873, 0.07936816691653803, 0.011915270006284118, 0.04142002253502142, 0.017959613833227195, 0.004167761271673953, 0.05457017061416991, 0.06041499917046167, 0.019740911120607052, 0.015111178690858651, 0.07395772481686436, 0.028006313696096186, 0.019160742740496062, 0.04804764990694821, 0.030792705292697065, 0.022291424065770116, 0.03626476420322433, 0.038542923794011585, 0.05050322361057624, 0.01342937186564086, 0.033540139702381566, 0.0427847690298222, 0.1480717459344305, 0.03611753694713116, 0.03982662034104578, 0.06717833937727846, 0.02771659037534846, 0.012759977853420423, 0.04326971429691184, 0.041665532407932915, 0.011544654444151092, 0.0398786263394868, 0.031714129872852936, 0.05116681866638828, 0.018403451540507376, 0.046437367564067245, 0.007902766028564656, 0.051885711145587265, 0.044053878664271906, 0.030075402864895295, 0.0933765531226527, 0.020797042925551068, 0.016827402614580933, 0.05674992142303381, 0.00584332106882357, 0.016437370613857638, 0.08054735793848522, 0.031498936732532457, 0.0035047047367697814, 0.028609355067601427, 0.007286008376468089, 0.06449966866057366, 0.014525980404869188, 0.054137275874381885, 0.04846567571803462, 0.06945273256860673, 0.08151837653713301, 0.12215243128594011, 0.06875786712043919, 0.058019762072945014, 0.014616682910855161, 0.01526996211396181, 0.04482996846491005, 0.006578062575499644, 0.03325882491481025, 0.02838251577486517, 0.025605198788980488, 0.09437615924980491, 0.02065763790596975, 0.04349744973296765, 0.030089043539192062, 0.015628164328518324, 0.01679316548688803, 0.042445470244274475, 0.03637655761849601, 0.02251178626465844, 0.002270298391522374, 0.01687889282038668, 0.018118136576958932, 0.09580819256370887, 0.042047998213092797, 0.01440457061107736, 0.04003061447292566, 0.050370163953630254, 0.05745514725276735, 0.029069096999592148, 0.05914633482461795, 0.02342230684007518, 0.05600543969194405, 0.030510755968862213, 0.03594225650886074, 0.04241638176608831, 0.02380880992859602, 0.02169373728975188, 0.0019388432951927825, 0.010892609061556868, 0.007686591397941811, 0.02935279037046712, 0.02219543468527263, 0.03146962189930491, 0.025710401932883542, 0.024892840920074377, 0.01711149117909372, 0.0542692668386735, 0.04829239536775276, 0.03214272757759318, 0.04421314726641867, 0.021489488972292747, 0.03160682274028659, 0.0808259824407287, 0.033252772700507194, 0.04737206174468156, 0.05597362011030782, 0.06608306299312972, 0.01528251090348931, 0.014447919456870295, 0.07889035739935935, 0.0414428658405086, 0.060449111988418736, 0.003893911098202807, 0.05968442899757065, 0.03285102589870803, 0.06421945596230216, 0.06455835027736612, 0.06038429281034041, 0.08915995946153998, 0.03284865102614276, 0.02586654052720405, 0.014925187206245027, 0.05621021307888441, 0.04481409763684496, 0.05340810464986134, 0.038975135757937096, 0.0505209386756178, 0.03363630719832145, 0.04218947753543034, 0.014139163758954965, 0.07949324848596007, 0.03499127960822079, 0.04925273075059522, 0.03951017599320039, 0.03394612416741438, 0.05682508985046297, 0.019585805966926273, 0.029805036610923707, 0.023682858191023115, 0.0018839085964827973, 0.043144172595930286, 0.02955543193820631, 0.05938233407505322, 0.030400611976801883, 0.043756069644587114, 0.011588302932068473, 0.03741828062629793, 0.05470667383633554, 0.025664950953796506, 0.046738352975808084, 0.02515085227059899, 0.025011656907736324, 0.03854458991554566, 0.043666087949532084, 0.022660150862066075, 0.10214549547526985, 0.03957114342483692, 0.03250632056733593, 0.0541286855150247, 0.02844763181201415, 0.04599991974828299, 0.030231619384721853, 0.06368184418533929, 0.047752501486684196, 0.045045369406579994, 0.027354682060831692, 0.04240262605890166, 0.032304660489899106, 0.046025653718970716, 0.043412165832705796, 0.058537343284115195, 0.005359502010833239, 0.13899808516725898, 0.03850957167742308, 0.022274256334640086, 0.06954763099201955, 0.043383407610235736, 0.029941918328404427, 0.012250609433976933, 0.05962285300483927, 0.006673958259852952, 0.04183145436400082, 0.03603140699851792, 0.03933129984943662, 0.014309287198557286, 0.019981745463155676, 0.03760326093470212, 0.01860567193944007, 0.07481144697521813, 0.03900135954609141, 0.03857563766359817, 0.04634273631381802, 0.006618419638471096, 0.10084685578476638, 0.022816521377535537, 0.15761475573526695, 0.05027279788919259, 0.05763667286373675, 0.051112326473230496, 0.06442035533837043, 0.03834541232208721, 0.06513868749607354, 0.04130559820623603, 0.031711981355329044, 0.021105379310029093, 0.018214361589343753, 0.09470323115237989, 0.06927124777575955, 0.0160811434398056, 0.07214744109660387, 0.04341798798122909, 0.013086932867736323, 0.007894591271906393, 0.12900968285975978, 0.017026535679178778, 0.004317693656048505, 0.04772025145939551, 0.02118746269843541, 0.047435125743504614, 0.014064086244616192, 0.04590902892232407, 0.016397981125919614, 0.06305320057435893, 0.0261872874762048, 0.08211157517507672, 0.07693574822042137, 0.04270056124369148, 0.032313644187524915, 0.03483577740553301, 0.03633628126408439, 0.08351462020073086, 0.09731366139021702, 0.03501671671983786, 0.024598486597824376, 0.03056574354559416, 0.030832803531666286, 0.10843645126442425, 0.03434322512475774, 0.03624316770583391, 0.03666452204925008, 0.017593375087017193, 0.031102620596357156, 0.029998332684044726, 0.016229405991907697, 0.03983773771324195, 0.02995265349454712, 0.06589398602955043, 0.01794815692846896, 0.0288316988007864, 0.0865684836753644, 0.08199245305149816, 0.03381945069122594, 0.022911135929462034, 0.1612424329505302, 0.10519947769353166, 0.18452234391588718, 0.11929358937777579, 0.1628056334448047, 0.15880496765021235, 0.12780434597516432, 0.12624271883396432, 0.08595734732807614, 0.2123855214449577, 0.13575467717600986, 0.09431992672034539, 0.07919983298052102, 0.10081821630592458, 0.07830230926629156, 0.09496703496552072, 0.17439452174585313, 0.07967494850163348, 0.0934207925456576, 0.08515300025464967, 0.17088435619371012, 0.11704382064635865, 0.16688655508914962, 0.16747538989875466, 0.15715673187514767, 0.15232095698593184, 0.22238674806430936, 0.16697608778486028, 0.177195476135239, 0.11903809019713663, 0.15446298813913018, 0.07660390430828556, 0.11585628046304919, 0.17945346044143662, 0.1880948053440079, 0.09376756104757078, 0.16437111975392327, 0.09982888892409392, 0.16905727767152712, 0.15495092055061832, 0.11297135206405073, 0.18574715475551784, 0.10931494631222449, 0.15554512850940228, 0.11226476810406893, 0.13622646045405418, 0.10458328732056543, 0.1179952391248662, 0.16280181880574673, 0.14836640824796632, 0.12967987189767882, 0.10095215911860578, 0.11538998907781206, 0.15234111371682957, 0.2726466808235273, 0.18701493594562635, 0.13112193904817104, 0.2084921405185014, 0.3808160108746961, 0.10893855127505958, 0.0996473670238629, 0.0992729164136108, 0.2609400433721021, 0.14185211795847863, 0.1050727856636513, 0.18986147304531187, 0.08299241540953517, 0.14258521143347025, 0.20962513284757733, 0.10131270930287428, 0.16609729587798938, 0.15095203591044992, 0.17924508021678776, 0.11531634576385841, 0.08935547826695256, 0.21223833871772513, 0.13744690746534616, 0.10930650067166425, 0.1243245268415194, 0.3476242278702557, 0.0842768578149844, 0.288399358978495, 0.20462707994738594, 0.18969385157106444, 0.18135310616344213, 0.10403492182376795, 0.10134523763554171, 0.16265292913885787, 0.0774925816222094, 0.1399915834190324, 0.1552587782498449, 0.13853660289896652, 0.19496109627652913, 0.1866028064978309, 0.10424514257465489, 0.2856139896903187, 0.1083650863438379, 0.07454275240888819, 0.20799920603167266, 0.11695153458276764, 0.06937333761015907, 0.12947607814567164, 0.1921336175291799, 0.11633117333985865, 0.18837015697499737, 0.1495377250830643, 0.11254230164922774, 0.05850337889569346, 0.09952546926797368, 0.13844052446074784, 0.10716882592532784, 0.19318820937769488, 0.11030746492906474, 0.15280888939742, 0.3229854296660051, 0.1086674966791179, 0.14817604736890644, 0.12488176842452958, 0.18428280833177269, 0.12223027515574358, 0.15054799587232992, 0.08219268449465744, 0.21714343019993976, 0.14304041513241827, 0.19833541911793873, 0.12204961414681748, 0.13913937524193898, 0.08597498075687326, 0.09776283885003068, 0.16871532570803538, 0.13572442723670974, 0.04778725255164318, 0.11127397126983851, 0.11586629203520715, 0.14508237509289756, 0.25027273921296, 0.1677715958794579, 0.07242371299071237, 0.12627356249140576, 0.09716288666822948, 0.061374722281470895, 0.19593008881201968, 0.13168729230528697, 0.14516732131596655, 0.19482445204630494, 0.132315564842429, 0.11445020747487433, 0.15749892132589594, 0.16630235128104687, 0.2029987337300554, 0.1485857425723225, 0.20993034850107506, 0.14443928928812966, 0.12506617727922276, 0.17803944647312164, 0.08339665582752787, 0.24580165569204837, 0.15324490115744993, 0.12921102752443403, 0.27009876910597086, 0.13108312472468242, 0.15314031770685688, 0.15281206578947604, 0.09236836776835844, 0.09294824485550635, 0.15360343270003796, 0.18661960872123018, 0.11829587572719902, 0.12908508506370708, 0.18025042314548045, 0.1394050195813179, 0.16149762785062194, 0.236568522232119, 0.1072655277675949, 0.12592536164447665, 0.11776239771279506], [0.03014371199242305, 0.02424340975267114, 0.02513387935323408, 0.043447922507766634, 0.010580506277619861, 0.00514492624461127, 0.0461414287565276, 0.059990917434333824, 0.025996405238402076, 0.06733419781085104, 0.029852404186385684, 0.014596502987842541, 0.038926662382436916, 0.025268449280702043, 0.03433421174122486, 0.059224453289061785, 0.014016090626682853, 0.00360097891643818, 0.03490575822070241, 0.02622233168949606, 0.01289824553168728, 0.016965353024716023, 0.06777702990802936, 0.03132754885882605, 0.023885141672508325, 0.009016533022077056, 0.03500320221064612, 0.0135476804098289, 0.04724375183286611, 0.021674729032383766, 0.059972912931698374, 0.02383006503805518, 0.029417921250569634, 0.0678560537926387, 0.007877409625507426, 0.035675536055350676, 0.025746626160980668, 0.021586586008197628, 0.03907796402927488, 0.0243425476946868, 0.048253889035549946, 0.03126215822703671, 0.04677193886891473, 0.054807242267997935, 0.056491286668460816, 0.010782820372696733, 0.05965549637039658, 0.042085109307663515, 0.05281892103084829, 0.044184789803694, 0.01192845333207515, 0.06194102548761293, 0.06686162043479271, 0.01363074807159137, 0.042428656888660043, 0.030114412002149038, 0.0322063518979121, 0.0215392963582417, 0.044184596845298074, 0.05099032852740493, 0.027671825882862322, 0.05820079786644783, 0.03437095176195726, 0.0318127130594803, 0.04412661655806005, 0.04453966255823616, 0.016262246026599314, 0.05064157478045672, 0.019859547137457412, 0.03197605976311024, 0.010637026389304083, 0.03377972352609504, 0.020533651004370768, 0.08783745972323231, 0.02779728965833783, 0.027580588102864567, 0.038637506804661825, 0.021969669651298318, 0.06099389291193802, 0.04569027718389407, 0.028928122337674722, 0.04436164359503891, 0.031818108473089524, 0.07882098885602318, 0.023667549539823085, 0.02968422239064239, 0.0349024185561575, 0.05696825013728812, 0.013371049262786983, 0.03761575499083847, 0.040989747576531954, 0.01556209927002783, 0.027048466363339685, 0.022275388109846972, 0.006942097606952302, 0.019720938071259297, 0.034728485115920193, 0.06069267001294065, 0.021536745225603227, 0.055953496776055545, 0.02008721206948394, 0.01772487066773465, 0.036590288727893494, 0.02153473957150709, 0.0114945019595325, 0.04216143177472986, 0.03621285839471966, 0.042492670836509205, 0.05458569634356536, 0.025238832022296265, 0.06449121559853666, 0.023217446250782814, 0.052064984338358045, 0.025558983397786506, 0.0319980013591703, 0.09836008961428888, 0.00705394390024594, 0.036206093718647026, 0.056716932958806865, 0.05654475469782483, 0.016736411598685663, 0.015207719116006047, 0.016267355713353027, 0.050868074540630914, 0.031106646747502964, 0.05142738671565894, 0.0206105746110552, 0.05574366936343722, 0.026831451250473037, 0.0060179901629453525, 0.028020577774441335, 0.02396934389253147, 0.018632057144714054, 0.04917873862723354, 0.014991966581874294, 0.04868285781412851, 0.030147550751280505, 0.0300587806123076, 0.03461389380390756, 0.0865276061813347, 0.031504476864938624, 0.033568827420822345, 0.03210116359696258, 0.028150692960480228, 0.04691476147854701, 0.019412373476370703, 0.02255768809845904, 0.03310748244985007, 0.025186965176544618, 0.024696951040823478, 0.018360980284342077, 0.023376766803266946, 0.013766391330136685, 0.02553327169152908, 0.08173570706276223, 0.02054813772701891, 0.010739199715317227, 0.032694744440959767, 0.037087201126269065, 0.06469877946074121, 0.039745136236888357, 0.04446785977052059, 0.018072045495500788, 0.027168729538971093, 0.05864495840796735, 0.06675086231552996, 0.02084880030452041, 0.02940540678537218, 0.02584101621323498, 0.03240132522478234, 0.05913668319408316, 0.022856408104416914, 0.025545812131895218, 0.05910285981371999, 0.025286696836701594, 0.047395892106578685, 0.009779075844562612, 0.029868302844988648, 0.019190076127415523, 0.06640479143243283, 0.07332563021918759, 0.033297219924861565, 0.023952862648002338, 0.05592377747234423, 0.029274497501319274, 0.01774663971445989, 0.0425300750794122, 0.00790229383710539, 0.009407042780367192, 0.03074405565712368, 0.0921827121055685, 0.01705062393739354, 0.06221891897439491, 0.08458600685116835, 0.042948405171046034, 0.014646572908532107, 0.032170187041629106, 0.026174797130806837, 0.01924398387927795, 0.023578013133374043, 0.043467548603075556, 0.04253449085808825, 0.03155374062771443, 0.03397508648049552, 0.06201492855325341, 0.014429480797844008, 0.04738125324365683, 0.04422790116223041, 0.02031149280810496, 0.04922438813082408, 0.05309398693498224, 0.04292254503525328, 0.018244181082991417, 0.11002144863596186, 0.023786792262399103, 0.046537423913832754, 0.045480728076654486, 0.05225156397500541, 0.02344646374695003, 0.020110457990085706, 0.02385643354500644, 0.014707842765346868, 0.025515239358355757, 0.05743087160226423, 0.05078916568891145, 0.010673903707356658, 0.04273080005077645, 0.03609501276514493, 0.04084623105882201, 0.011342627931298921, 0.01273799265618436, 0.02672293812793214, 0.07940162293380126, 0.06502199219539762, 0.03443093955866061, 0.044560554015333764, 0.053789468365721405, 0.05780396408226807, 0.03764785658859182, 0.05611680637230165, 0.041427087780903094, 0.012100339372409508, 0.039590854867128655, 0.005034923724451801, 0.05022841374739073, 0.07043047502520494, 0.02006460625125328, 0.05436195737274829, 0.06404017534805462, 0.0018544293311606452, 0.00938138116907794, 0.05068777347332798, 0.027009371879103128, 0.029978096172271762, 0.031482835838687606, 0.011096883354184683, 0.005266407006274676, 0.023738103664072696, 0.03288207735749893, 0.09902516525471583, 0.030978060385677963, 0.012303545900067547, 0.019689409782586154, 0.014253183617256582, 0.0751384966133628, 0.018450843235768843, 0.013664064008480636, 0.023245770316862036, 0.05100900096294936, 0.01861209522758145, 0.051006885842070915, 0.043794342200271785, 0.021132658803253435, 0.007364517396126757, 0.06745885635609739, 0.009620781311241444, 0.006568606686414569, 0.04919568556942977, 0.040870514130801894, 0.024538513644074555, 0.09343107129097916, 0.057054124044952914, 0.04346366345998831, 0.0678960258665029, 0.04049620823934674, 0.02446490187139716, 0.02524185441870941, 0.02651434453582624, 0.11930495165870525, 0.0710073983645998, 0.017908635709318332, 0.03428502219321672, 0.03538234690495301, 0.07077825284795836, 0.03375020460225642, 0.07405417432892136, 0.06214082648511976, 0.05792796582682058, 0.005495792793226428, 0.038916001431061886, 0.06428956665331498, 0.029215648901299573, 0.0430104487168137, 0.010044824084616266, 0.040049298040685244, 0.009774961563380202, 0.05969310470391065, 0.031269293976947665, 0.018077873210131656, 0.03904892007994931, 0.047834586730459705, 0.033038373658200726, 0.04386786305985879, 0.08923303874325939, 0.054380217916332185, 0.03751399170141667, 0.045999281501281075, 0.009061761356861098, 0.029406080284388736, 0.04989777211449109, 0.06050065785530023, 0.04510453713010065, 0.04592606121150311, 0.06764068253687583, 0.06036506747477688, 0.07687256176723167, 0.05551324735279195, 0.027872138962266035, 0.06615704027353786, 0.02720136362768244, 0.004678578270613798, 0.017496886612207163, 0.06139893856015988, 0.026663417884265073, 0.04327764414483681, 0.02574425499915378, 0.019538644337444566, 0.03749832867470104, 0.009191246645059437, 0.049493668993818574, 0.04098656376299914, 0.025324880334665067, 0.03734941674338188, 0.01849707346991636, 0.02814462590322364, 0.072935973003041, 0.037364949894254096, 0.030298835699795745, 0.0225371584383538, 0.015724389340903144, 0.02435003967548255, 0.053071603761054575, 0.17211921571288258, 0.16444926790427417, 0.11416403533075936, 0.11800988169852644, 0.11607341803028248, 0.10029024502728134, 0.24433273763861507, 0.12036270505632274, 0.14168534253258258, 0.15994575252989307, 0.14443922991631553, 0.10244277757010423, 0.17830332450103015, 0.12394861420034431, 0.19067828077822924, 0.17604516207939014, 0.13073738780803978, 0.2117651008302346, 0.1054830448993016, 0.12374447906040587, 0.15070521243615076, 0.1276412812876515, 0.15778386150486767, 0.14038032037205994, 0.1818919350625947, 0.14641027024481446, 0.12124510380090214, 0.0576365281449398, 0.17799996421672404, 0.07339299496379681, 0.1312653665081598, 0.1292532854131423, 0.10966718444251455, 0.09743895076098852, 0.11074386260588653, 0.12218696341733448, 0.05360155657399446, 0.158359753258992, 0.13585286331363022, 0.11421711373259313, 0.11968896113103256, 0.08862038841471076, 0.2087834631674923, 0.1592232272378169, 0.08365028479602188, 0.06623328110435978, 0.23164404585259035, 0.15871380222961307, 0.12389535026159137, 0.07464823385816999, 0.1188219990581274, 0.14684812253108248, 0.21531575795961544, 0.14648349053459242, 0.1676926907384768, 0.10390736890258268, 0.15690333297243342, 0.12997549900319427, 0.09570328998961486, 0.12862391449743882, 0.11945343314437196, 0.18930938938865438, 0.14571440289728343, 0.10708254383644089, 0.15257849707268178, 0.25084030407015234, 0.11338106953189708, 0.2175147712114267, 0.1738438184838742, 0.17132631997810677, 0.10830232291482389, 0.11453612591139972, 0.19784284086199477, 0.19249431614298373, 0.10278369052684866, 0.12958704406628385, 0.1488414718187414, 0.1680180779658258, 0.13502118294127285, 0.21526073513086885, 0.09990978302084841, 0.10149699199246243, 0.15951218985719606, 0.30114705150481313, 0.107356158841867, 0.07493958619306795, 0.11185344759724103, 0.19527213036781177, 0.2833156770793721, 0.09930371554219164, 0.12417545905918814, 0.15172128682024777, 0.11854721145937219, 0.1276876061456278, 0.20224490464897826, 0.1386464704410173, 0.07995743217179552, 0.08799265022389591, 0.10234536326606758, 0.15132873522816226, 0.1724708452820778, 0.11776326602557674, 0.0937319231161382, 0.06699677294818684, 0.17382171732606366, 0.19289900927105919, 0.17033209442161024, 0.16143864195328206, 0.13658493262482807, 0.07396352099021897, 0.13072251516859978, 0.12467411550460383, 0.18393189122434705, 0.24194937490392476, 0.12944885616889223, 0.15778224362293258, 0.11090642263297923, 0.2656529186060652, 0.1679171755677089, 0.14146427158266306, 0.09646969847381115, 0.145234678639099, 0.15586808149237186, 0.19917489204090089, 0.1695906146778725, 0.31597234192304313, 0.06856344669358805, 0.09075407782802358, 0.1617949322098866, 0.09505157300736755, 0.15644728322513402, 0.10393103599199094, 0.06206780286447611, 0.23593582649482414, 0.11003412451827899, 0.1294815551955253, 0.19959519995609298, 0.16860621515661478, 0.1319821475772187, 0.13466722302837297, 0.08979048070614226, 0.08986465094494633, 0.13314012059709057, 0.20628270751331002, 0.15964089310728014, 0.1628820301266387, 0.13075683207716793, 0.1824698899872601, 0.20785203814739361, 0.19091061752988026, 0.13846649962943047, 0.07315037946682423, 0.12266488425666466, 0.13215563201811165, 0.17864187742816284, 0.0940144810010679, 0.11480027111247182, 0.0932300160638988, 0.21296341699780896, 0.11097195427282713, 0.13477725384291261, 0.12447574685211293, 0.09692369989352301, 0.16298544098390266, 0.09625984137528576, 0.14361715293489397, 0.12927722709719092, 0.07848661422031, 0.12081350781954825, 0.16810612636618316, 0.15874949953285977, 0.11415465458412655, 0.12442839783034287, 0.1893622154602781, 0.10931056021945551, 0.20264596125343814], [0.03909785358700901, 0.03893419518135488, 0.08473214315017685, 0.010704696342145326, 0.05908759754674975, 0.026692532337619923, 0.054423514811787754, 0.06290737597737461, 0.08780107222264633, 0.008589311073592398, 0.02120286226272583, 0.03741479253221769, 0.010927740477200132, 0.03532432208885439, 0.023674872682022396, 0.01252765965546132, 0.05268667402560823, 0.015158293936110567, 0.049415498579037376, 0.06112729024607688, 0.08356117512448691, 0.037644772964995354, 0.056230488553410396, 0.014938600597815821, 0.029206988037913106, 0.031347924523288384, 0.019982361445727292, 0.03862775498419069, 0.04789563208760228, 0.03581011711503379, 0.006286343805186334, 0.04049754781590309, 0.051664617931237444, 0.0276685771314078, 0.033123601897386834, 0.0495516938099172, 0.012806260037905304, 0.03196879042661749, 0.06296443971223198, 0.06445560735301115, 0.07842100094421767, 0.06106374385126401, 0.05891961613087915, 0.025671710063761566, 0.017583979497430846, 0.03248190761951264, 0.0483375142357545, 0.09452392827370204, 0.03505425083858427, 0.017112580280809198, 0.08447359374258667, 0.0281027168239234, 0.03564767954230774, 0.02064200827589957, 0.0013573823025581078, 0.02736448954237858, 0.04095875548955519, 0.06533209118060768, 0.03404969087569043, 0.01599171278940048, 0.013188093162170844, 0.05490459720022045, 0.07586638021166436, 0.07473669786122628, 0.054801642763777636, 0.005654769638567814, 0.07286534280865453, 0.006671960027233581, 0.006314304682746297, 0.07578228745842353, 0.0275198507370078, 0.035486277265590616, 0.05396539447247051, 0.08574247331125662, 0.0584695740690222, 0.029997054334671702, 0.03644801159680355, 0.018022974691120908, 0.009659448132879334, 0.09029317443491891, 0.06184917358041275, 0.05145276074472349, 0.006917306627656217, 0.021119016273587476, 0.07681408053031191, 0.012354361679172143, 0.08522101808921434, 0.026754420032375492, 0.01524202489235904, 0.052969424868933856, 0.03898809736710973, 0.02394274531980045, 0.014580450333596673, 0.06658222409896553, 0.02582942572189495, 0.04466723032237496, 0.06327559996861964, 0.04363032756373286, 0.015093439506017603, 0.1023149277898483, 0.04521605223999359, 0.003571601696421567, 0.06184317702718545, 0.017461103961977642, 0.01708674055407755, 0.069952101475792, 0.03704475027916487, 0.0668793058139272, 0.023498911323258653, 0.03803007377428003, 0.03983920716564171, 0.016685591181158088, 0.027429473848314956, 0.0232944459276041, 0.013269614373712102, 0.050226547245983966, 0.027699671263690107, 0.034116632596123964, 0.08395179713261314, 0.020453226316021755, 0.01719353374937782, 0.04569925346004311, 0.08820956514682621, 0.018661871072254144, 0.029084988236718345, 0.13340949051780626, 0.019837737272609957, 0.026401924005767796, 0.04679143137764186, 0.06742901459801942, 0.1346968495636247, 0.004936993627779884, 0.009739336619531969, 0.031104012123250868, 0.06492169835837558, 0.026232658674416598, 0.03811361733824015, 0.018975743878399953, 0.07209301940747537, 0.01649626559810713, 0.06954958284040913, 0.027753193098760676, 0.0127573051940999, 0.04391121932712849, 0.08517332025803626, 0.011380337382433936, 0.033138062644866295, 0.02502471314073773, 0.03581892640795559, 0.028850781272922177, 0.04196478861558717, 0.02337625286600087, 0.05377017623686697, 0.04964570536685642, 0.0302921396723832, 0.01014280798699474, 0.08117074714391492, 0.02643539115524618, 0.02884625046135625, 0.031232631881721318, 0.05262578823021613, 0.06137107833637856, 0.012785201597580453, 0.05967642122413963, 0.020361969982332084, 0.03298053066828288, 0.039285026941797696, 0.0137606777207111, 0.06763586599845439, 0.02727312188653741, 0.03380672656930983, 0.039528907800558954, 0.013074357175355544, 0.05884182421141304, 0.011887061900779372, 0.03433364770899061, 0.06996383483055979, 0.02764244425634388, 0.04790630788193084, 0.033209234607056715, 0.011064456139138201, 0.015208529912342783, 0.02109711178491125, 0.03926661425794009, 0.08972025127150118, 0.019839063861581963, 0.048518379335291684, 0.08187544604879804, 0.06991595888393931, 0.011052937079512049, 0.04045572779432405, 0.0068804385864496, 0.021284964204824064, 0.01700520264421357, 0.06307167263003066, 0.05578164134931285, 0.0601380111038452, 0.06772536158678122, 0.03193102253135294, 0.028437260298233014, 0.03005035538080847, 0.023728930718789343, 0.05431730976852123, 0.00564941226002702, 0.04762681506690569, 0.013389817249844782, 0.056652956118341535, 0.012700198785751127, 0.023067218862706795, 0.04199648945359513, 0.05831552276504226, 0.015790613033459522, 0.047361074248328805, 0.06774418245186098, 0.030025667838344816, 0.014426984398596687, 0.005425285053206608, 0.04413109541928861, 0.01565586127981078, 0.02320290201168973, 0.03268505199230276, 0.014459778049058514, 0.01690817611233797, 0.061040581422275864, 0.07166378345573321, 0.030494797938445117, 0.06993084636633284, 0.05980522095342167, 0.030724663338332903, 0.027967111600446515, 0.014662671947007766, 0.05429101918707602, 0.045734156665275805, 0.050113225006498396, 0.03281238597992342, 0.024708031305635814, 0.033567691934877075, 0.05186391055758577, 0.03849754146358464, 0.039365056436508894, 0.1290116718155332, 0.03529530040395912, 0.061260457514435984, 0.025475864713371266, 0.028677667905867565, 0.04648518413887359, 0.04176060523604974, 0.040440428419969976, 0.06204212084412575, 0.11375495610991493, 0.047051858418853953, 0.026542980303929653, 0.03379970214155037, 0.04253582301316783, 0.022176151833264157, 0.10708709320169874, 0.015490755686187185, 0.09469061464187689, 0.048713708893046714, 0.014815411504969234, 0.029718600526393857, 0.07127681281417608, 0.03015828777279239, 0.042353996832389385, 0.027748222564696334, 0.00935902582568815, 0.014226834591681836, 0.007240829208967625, 0.020097603992326185, 0.03135908271360677, 0.038148364692460746, 0.017623877356527373, 0.017451044150220696, 0.06620441898121499, 0.034879256127169356, 0.08386584158870392, 0.07475452424841933, 0.06390983937308192, 0.06227902922546491, 0.014261604210332735, 0.04405187857628334, 0.007922622189653339, 0.023781838426657487, 0.040623200839036144, 0.016576269117649645, 0.023388737645291258, 0.04074030432093423, 0.024134735213010572, 0.006624060888498207, 0.059954529933747835, 0.05075652603409253, 0.0597958958678646, 0.06277780441450886, 0.06381287777912803, 0.06326084607280791, 0.04174876055913046, 0.025183324942190666, 0.059773913453682326, 0.04985956635209732, 0.06020954671839718, 0.030292412411654368, 0.0891843909630552, 0.04340150117059238, 0.07208210983662866, 0.04425517137860879, 0.05878000330994837, 0.06742076191585511, 0.02457854694512207, 0.023949751193867996, 0.031089321309991647, 0.1267576654208824, 0.0397360968781868, 0.03537833188602235, 0.010934527417703066, 0.020036653259012382, 0.07053954846924171, 0.06742819081409834, 0.04816504653717857, 0.033200503239640966, 0.02904496792325517, 0.04990041416021995, 0.031179290017462336, 0.02997328705532709, 0.0162125852148165, 0.05810465634567663, 0.06599872533115558, 0.09800456376979128, 0.014497121064778185, 0.03354709733685013, 0.03403060283744708, 0.022402132090064697, 0.012913820428366307, 0.01687370520812692, 0.06614903992158361, 0.03248948123655282, 0.04199098271783441, 0.023138403812481556, 0.018921841692645103, 0.053906063476460986, 0.06962105166167021, 0.04596599617798347, 0.051124720339430496, 0.04984543957107235, 0.019087923210463487, 0.058357105299364775, 0.019952226539317053, 0.02522251961636357, 0.13804824004182592, 0.059467658793437295, 0.071448486414738, 0.021311876334948465, 0.02454802241118159, 0.1439314821618609, 0.16800526849692687, 0.20297946757636964, 0.11351245935657062, 0.11646299361018464, 0.0981251776101999, 0.08750994253205135, 0.10795988855534233, 0.3228645783383399, 0.18916186527349055, 0.15444039716385305, 0.18858980300137773, 0.10281148395733908, 0.08907453084248118, 0.08544713564333506, 0.15282437059795484, 0.1285774857387878, 0.10100457700900733, 0.11125037097372115, 0.15518239641096443, 0.12051152050844394, 0.2153380520758219, 0.12977927515748888, 0.0831970626313705, 0.12490343913668767, 0.10567349483608268, 0.14174232463119552, 0.1699226367054507, 0.1070832488767337, 0.13312921102624387, 0.11526629532454535, 0.07657936148461886, 0.09844410073128529, 0.11407453974243253, 0.1365072446060367, 0.15952989750076085, 0.13673184817889705, 0.1506871188757941, 0.1521092964685522, 0.1335246124654077, 0.15644720901036635, 0.11473719598143362, 0.1246429156162776, 0.08624099617009051, 0.1474809370120056, 0.13627683743834496, 0.12482514255680144, 0.15081208170158789, 0.15050627232994884, 0.09838593861786649, 0.26570575952064246, 0.12143441825173795, 0.16879715491086245, 0.10946391761535779, 0.1253406234900467, 0.11269096867181361, 0.20675368927186355, 0.2013066370273009, 0.10038924752734601, 0.09871057627606206, 0.1608753963955678, 0.11032774782506749, 0.16180239821551368, 0.239955194410868, 0.2831635664915666, 0.11957877446548082, 0.16078605665825307, 0.09983727519284002, 0.12110793264582753, 0.16031314531574026, 0.1118992010015063, 0.17472894833190367, 0.17455107037676498, 0.17019589547999203, 0.29431106988340616, 0.11953706576605327, 0.11673060464090668, 0.10505771264433861, 0.09975103021133691, 0.23616639693500474, 0.14830932224867865, 0.1528002359555103, 0.1497153952368535, 0.07409062120132148, 0.1413959643105045, 0.15272153861587867, 0.1590356568340212, 0.09346159582491964, 0.1408056600484997, 0.10963927968987264, 0.13252511766040698, 0.1387659413740039, 0.14010357350343838, 0.1598580158315599, 0.12182964899693616, 0.1577903181896545, 0.10392589290859178, 0.11796250299084932, 0.07264747793669812, 0.1756405134801753, 0.19402729638386518, 0.14400194166228175, 0.1322159537812695, 0.11744587915018201, 0.1404260069830343, 0.18520799931138754, 0.15330323396483436, 0.14523757301503792, 0.1331712759565562, 0.08998024786706083, 0.14788503642193973, 0.07265514432219788, 0.07415291707729921, 0.13938296295236796, 0.15410516905831173, 0.13992422609589994, 0.09265129672712646, 0.21238906891085207, 0.19763027492444962, 0.13873015501303598, 0.09984109725337476, 0.13105380989145488, 0.22604932106332853, 0.1479836826911196, 0.14086991519434378, 0.1782012643525377, 0.1654467440675944, 0.19158150418661535, 0.12756052077747881, 0.1112483671749942, 0.18591829400975257, 0.1208613243943546, 0.17895113036502153, 0.13928832428064197, 0.2211205699131824, 0.0876990937103983, 0.1406944269547239, 0.11435831474955194, 0.15010300412541255, 0.22427723568398505, 0.22144570481032133, 0.14018847519764677, 0.13329996436368674, 0.12251877022208646, 0.28704390046186745, 0.14588549762265757, 0.12845672346884385, 0.09868298322544433, 0.18786331464070827, 0.17028139089234173, 0.17462435003835708, 0.09363861288875341, 0.2587220608256757, 0.07664902688702568, 0.13318410026840866, 0.11616502873948775, 0.12936454819282517, 0.12844544282415882, 0.14570571976946667, 0.141617703193333, 0.1350611847010441, 0.1557227541343309, 0.13399771676631644, 0.15698275761678815, 0.1445221871836111, 0.11495594400912523, 0.15353573398897424, 0.08471818335237913, 0.17550131626194343, 0.20205032837111503, 0.1329832899500616, 0.18833667127182707, 0.12808363098884, 0.15945577179081738, 0.17860974243376404, 0.12298486122745089], [0.04422235731908586, 0.0573675367195392, 0.07137510285247117, 0.01132963663621922, 0.005058887209088425, 0.029195774186518975, 0.0514178352750605, 0.030300765283755027, 0.028544879132823553, 0.02464951296133222, 0.029713919429923408, 0.15093993890332058, 0.07467171541065909, 0.09231810952769592, 0.030320237383421045, 0.02055346263659885, 0.0450694261235185, 0.02202749779826263, 0.05433724756585434, 0.055704428305034526, 0.04400007295771502, 0.020271288813091815, 0.018632715800777078, 0.016530936882190872, 0.010898663131229114, 0.01636733784835087, 0.004704079856310273, 0.04697258962551132, 0.029438408237183467, 0.04920177118037827, 0.019198111731384415, 0.0142602618507226, 0.03784385778999422, 0.0823577307164669, 0.01732656186504755, 0.048376425038441084, 0.016789029868959915, 0.012086564183846349, 0.05454861864564009, 0.007560600697615882, 0.027334670048730914, 0.05313479392498266, 0.022545516876562033, 0.019646574874059297, 0.0467148677125806, 0.047045205064932816, 0.011971846706728684, 0.029943033405288588, 0.04448638377652969, 0.048226885992335156, 0.05603489182249177, 0.05871661276614759, 0.0469607746344991, 0.0199318768500234, 0.034034595591947436, 0.031551310094073415, 0.015044460542412708, 0.02517901491955854, 0.039661418268224224, 0.020099236717214808, 0.04548439057543874, 0.04188527862424962, 0.023030460288282484, 0.020338308459031396, 0.018381359659542795, 0.02931027458544122, 0.06003336085996125, 0.02935212614829652, 0.004627306070688064, 0.05274040922813583, 0.02197298890678212, 0.04123614802665543, 0.03532745024131145, 0.009582800976204453, 0.014148355257930234, 0.029514880989154335, 0.11025773361325264, 0.0161598222257453, 0.05530983580683824, 0.049374094160157256, 0.01156300682850997, 0.003610303306231799, 0.050078407148248516, 0.05377343055442907, 0.007164240032579983, 0.036581672393367626, 0.02111727779265493, 0.012846369409089675, 0.03975878433266189, 0.026515235113038216, 0.07306210842216387, 0.0772954523563385, 0.009173176276817685, 0.0474108723574318, 0.005325636420820956, 0.04057326172187459, 0.03243232473323587, 0.025490388543403242, 0.01609246861335123, 0.042424894199939445, 0.02878259459976107, 0.038871587603352964, 0.03231338814657647, 0.026615243223204743, 0.039363108298857696, 0.030524103494826704, 0.04580346583679784, 0.038349189853761345, 0.13238308543805033, 0.07662356380023994, 0.02578064249973977, 0.061587792879436165, 0.0489348540577339, 0.08850206038914621, 0.05240253536612727, 0.02218075500422856, 0.02904284167016158, 0.04520414076978341, 0.044055448306608014, 0.047359538002638146, 0.08306016607093625, 0.010071644373965682, 0.04770053259562701, 0.052937464279239066, 0.04382417653687298, 0.04172397653746884, 0.0976939155953005, 0.015652388028684072, 0.01991345674468903, 0.018183571737608872, 0.06427091648220085, 0.01789671125152381, 0.016534016795048956, 0.02317137928912416, 0.025155574185191654, 0.05493513286637608, 0.03082968465605518, 0.06444820814067498, 0.041826296437648125, 0.011154320018249564, 0.02729346786509268, 0.04652781681215856, 0.0803435270790942, 0.04938580525049474, 0.09347729224828072, 0.01871653767011594, 0.01608817899978021, 0.012479373672249494, 0.014376862527569756, 0.03200877734343521, 0.03002964203915326, 0.03121894296782557, 0.015174171257967828, 0.04276634150301106, 0.02356018860155018, 0.035116468789055943, 0.02330232753593009, 0.0323965532152215, 0.015802197958691977, 0.05921880183450412, 0.026145773590542376, 0.06844774587079883, 0.03270002853241749, 0.04607388960721437, 0.05701182162738405, 0.04834543295146432, 0.020448317009140737, 0.026280419588147197, 0.06134654293418862, 0.05017362840590067, 0.05784523120382801, 0.035412259167060256, 0.03911370957212057, 0.06593994723516516, 0.062367604550672695, 0.049977753369603306, 0.0539706191921141, 0.022215398457774427, 0.014385493705049157, 0.08858507702825591, 0.0439189859025646, 0.008050550823099911, 0.08414487427216955, 0.049471063175587915, 0.10416263059596531, 0.01956096999492729, 0.04698033393651713, 0.14070300618186593, 0.038651232825941406, 0.028579674726643134, 0.009080928248295095, 0.04192828979284968, 0.01937082619406283, 0.026895324190263636, 0.04135637223953381, 0.03540619210980367, 0.04557892163575161, 0.0024831356768117985, 0.028674237328232266, 0.06976312841288745, 0.03454599471297115, 0.01882336611743085, 0.01749403862049803, 0.017008134127536323, 0.055353073330479674, 0.012970511234016158, 0.019551366603991482, 0.014172584524203558, 0.029200700191722717, 0.020131373566982802, 0.0835343984363135, 0.03553681010089349, 0.034929046814795583, 0.03457101251115091, 0.03573815476556774, 0.04547299860860221, 0.017544307993375696, 0.04871643628575839, 0.03206715467968024, 0.04448225001397077, 0.02955251529783709, 0.026079006274812855, 0.023984288891369943, 0.039525293541373685, 0.008366256734007038, 0.05208388312894385, 0.0251819890763727, 0.06677977638901211, 0.09421600378118455, 0.02443696928821737, 0.011102136832050746, 0.01904125325381756, 0.003770057319343323, 0.005980092391837388, 0.024235288801719435, 0.024866413041308988, 0.08815452747512609, 0.047998679292504676, 0.04770149738760665, 0.05207706279179547, 0.04237302920955699, 0.05547507498704363, 0.02062913015834056, 0.018730404699454084, 0.03333843509608414, 0.042479839103179984, 0.04952685412717983, 0.05323589299223386, 0.02780755912681343, 0.011824680677818833, 0.030162505026964936, 0.0010345990858695586, 0.07502027248847298, 0.023972715098352637, 0.0345596836268669, 0.0384581111575244, 0.0257569327368401, 0.052166098248562776, 0.023691669339314103, 0.015559050898446003, 0.028808352690248284, 0.06278628716245294, 0.03787506509979721, 0.030126492310955655, 0.04169976768025663, 0.007188451209003688, 0.023834395469748415, 0.03627984464401379, 0.015563141059828922, 0.0077354247150651645, 0.06681585218757391, 0.08154070033924654, 0.04990215449652169, 0.004657896006392548, 0.053225655065034516, 0.009366073445562506, 0.04087943845661357, 0.007254473130160477, 0.030878684956405777, 0.03536047210218385, 0.013997012792970054, 0.0021804771859024186, 0.018173255884903483, 0.05183472931094002, 0.12264192962902598, 0.13065052684396505, 0.019346298213349655, 0.044756859497283585, 0.05545172331039794, 0.05877355033589993, 0.06897922008647583, 0.057096526652458124, 0.034967801766470075, 0.043008767752326094, 0.0608061072853161, 0.044351364849717356, 0.038292326498776674, 0.04482236516196281, 0.06934574455954134, 0.02217823355749715, 0.013015903768973658, 0.03833105547528248, 0.13227928866399452, 0.039160145752248354, 0.0252725310929236, 0.009688865939097013, 0.02400585013674572, 0.05228369154792745, 0.08359567014849745, 0.05283595703076571, 0.025227447476936504, 0.0610169143328676, 0.029340441033127718, 0.041375586442882195, 0.01616530484170653, 0.062498667830368504, 0.02584117577498546, 0.01862224038632121, 0.04310929907660466, 0.10411617215140723, 0.03274658716691192, 0.03147569266729988, 0.046396616235142574, 0.023106409826141316, 0.03343601638334803, 0.03362940522492863, 0.029276026325533167, 0.016869935097929556, 0.05228858230111655, 0.02162256532756146, 0.0145269294262107, 0.061869085402577184, 0.02493441974365851, 0.08899851265596226, 0.03587226827221457, 0.043460086308186874, 0.02975268736918224, 0.024582339319749735, 0.013313545805431204, 0.0817465127329342, 0.032591849376331083, 0.04392924238345586, 0.003646919712991803, 0.00793567100117798, 0.041448057163506746, 0.033581725947442465, 0.06128236200311221, 0.04543810282484628, 0.04920576393487863, 0.11210179989575408, 0.027793749613920227, 0.0051351623642403865, 0.11286992274108343, 0.1659156774985604, 0.16656079678796232, 0.12122144413297065, 0.13762681890511885, 0.1406781145487912, 0.18430722499033436, 0.12387385024339892, 0.1646971600712277, 0.13787085190415382, 0.10905718358117156, 0.4151288524735719, 0.15479026042157784, 0.19113452348392457, 0.13183175877202302, 0.1844902237644419, 0.15034616139018908, 0.10813569591846317, 0.13025974156334996, 0.18593888118630275, 0.09835767763433978, 0.07037842820864171, 0.0858124355727341, 0.11436931337811984, 0.12070833807229064, 0.12410541516146623, 0.10777588046039455, 0.16449600836494938, 0.18313846114324406, 0.15518165426328778, 0.13161620940081775, 0.10026715681306086, 0.1265987122314982, 0.13732126186368987, 0.06527311270474456, 0.0943135294073727, 0.16429991810582578, 0.0895273670903407, 0.15398810268379748, 0.14265510690165684, 0.0726607178512495, 0.13358255935600027, 0.17486315831774846, 0.1441781423636712, 0.0811889668693766, 0.15981951321009547, 0.15899552148766816, 0.12398443024721928, 0.10199076510616578, 0.08708432826097123, 0.12896071595605463, 0.21481175062945113, 0.1446982691413723, 0.08536877227015793, 0.1725234487093985, 0.13701822812436149, 0.1303411106346175, 0.11096075526438653, 0.134839623933658, 0.217334859771654, 0.12954437057487667, 0.15884447959251702, 0.07640618132427335, 0.21561239438597113, 0.15757156274048612, 0.13340601726667956, 0.18628305959282443, 0.07928483115392737, 0.10800321513670497, 0.16811843117466196, 0.08896511601051316, 0.15628846362233162, 0.11228881368879229, 0.10946067443001084, 0.0812322786077857, 0.06679318699752912, 0.26281874568667263, 0.07028615698800422, 0.11382201657397673, 0.12553208274766803, 0.15370037202956155, 0.12817855167668313, 0.16720523330150172, 0.17716935253702104, 0.11105675206636079, 0.09830773851717822, 0.15301459789043292, 0.13505731069017202, 0.08708636916708201, 0.10459107244969346, 0.17470266146119684, 0.2636868506669998, 0.07931193438707851, 0.12694761069724336, 0.1736527748289518, 0.1647108601173386, 0.06714547707815655, 0.11236846839892678, 0.11905000908882357, 0.09977557303500362, 0.16029025748139247, 0.11914058079128154, 0.13062654063105583, 0.18112511839717627, 0.14945914648706093, 0.13696547626750544, 0.11132040002848953, 0.19865826820023358, 0.2651884825900197, 0.24065999721642584, 0.1396856107749045, 0.2506871544755995, 0.16359133034711704, 0.15210067271254957, 0.18783595907734707, 0.12214762216899544, 0.18914010550361127, 0.15094229893293232, 0.1465421202010475, 0.09984252217691392, 0.125134336121846, 0.10950042385957204, 0.11183291237102821, 0.1826470109517686, 0.09140385038335808, 0.1722600604989566, 0.2529347041854635, 0.15370592329418287, 0.07845171843655407, 0.0672317146381829, 0.15990974352462217, 0.15429100283654407, 0.1580742045189254, 0.10475940638571046, 0.07707769138505682, 0.1202672797080595, 0.09007560642203316, 0.13002502993913367, 0.07187788563896902, 0.11247217611526139, 0.09293015871662647, 0.13909250119468197, 0.18700843473197892, 0.17277226113947108, 0.20237725926563144, 0.18550463573774323, 0.08145229570800439, 0.11583464685827494, 0.0728616320702713, 0.1394956061267294, 0.13753851817455143, 0.0690858147572726, 0.1180264241702389, 0.15607741166604683, 0.08062323511694558, 0.13692762673599645, 0.17973601090488955, 0.167053478944581, 0.1474255431094207, 0.13818083214573562, 0.09493544173892587, 0.1446807396132499, 0.15975785558111966, 0.23185824451502413, 0.1927002175943926, 0.0836856703972444, 0.06723362195771188, 0.13566124078352004, 0.09704091469757259, 0.18387143587460741, 0.17202680348418653, 0.17838470841525123, 0.1805143605452031, 0.22959084977628663, 0.16274025023449212, 0.15852093289140612], [0.049929187225643545, 0.06463335172156803, 0.023111343252821825, 0.1128769211936742, 0.0689345205319114, 0.02480618033587234, 0.0377483619377017, 0.08256304587121122, 0.029142385938030202, 0.05834209907334298, 0.06120570556959137, 0.04021563559945207, 0.08336843195138499, 0.050529781365185045, 0.030755464322282933, 0.011302399816486286, 0.015198497931123711, 0.029258136855787598, 0.023118748031265568, 0.01452018144846079, 0.043289581590215676, 0.021773957887489814, 0.07005471081356518, 0.014847108632238815, 0.041072244712268, 0.04213662548863795, 0.006886573364681681, 0.009148326389549766, 0.05571197594690602, 0.06729751345119439, 0.09631314242142253, 0.04545800722553395, 0.07133491555578075, 0.0642182759474963, 0.016126997034007218, 0.08079421109869145, 0.03446249567787163, 0.018395751758362167, 0.034203378527308814, 0.07849683359381743, 0.024445615308650304, 0.03448652641964145, 0.06064079760108143, 0.025322986002720427, 0.052158765829517506, 0.028034431816195138, 0.046567825993406586, 0.05185439993510954, 0.023193805136543233, 0.052221421647118405, 0.04403445294883568, 0.011636399667622754, 0.026230348739773035, 0.036767428246093914, 0.03621229807322379, 0.005290609369694721, 0.038803399074822664, 0.026467002935532946, 0.0075818636923941085, 0.026890409317275044, 0.036544743124977686, 0.023123263999877963, 0.04879953085037414, 0.027809880193672143, 0.03891660628141835, 0.007613686057084124, 0.017925231986737344, 0.06752207249519415, 0.02290148986503482, 0.020084668358322233, 0.03664334486529697, 0.0720111456757877, 0.10660593659849837, 0.009543758442305261, 0.04004124944913201, 0.002683637076188461, 0.049774460567277856, 0.0190641726294416, 0.032439979986520484, 0.02806729040457867, 0.07366949692368507, 0.036296509570092894, 0.019980968063464388, 0.021351453215174843, 0.013096745915390784, 0.029783460522594396, 0.10239738039672375, 0.0265712988039013, 0.010509397397981957, 0.02389755223703105, 0.05212465301156044, 0.054613831161987036, 0.03410161523788702, 0.011333630318404175, 0.043516960795386694, 0.04127431668166537, 0.054097812171676196, 0.06785095523810014, 0.0341278019186575, 0.041821316626737826, 0.004044289698867942, 0.020391834004840348, 0.020142093890171964, 0.04720843302493449, 0.01505084301243187, 0.02437940645904746, 0.023779665789334103, 0.023553782011731528, 0.09949817307642661, 0.012898929235234391, 0.03657750894490164, 0.05264214145427104, 0.071438348677475, 0.0171598754968727, 0.017721629337756895, 0.01901891089801211, 0.056751301817712374, 0.027139134544995613, 0.014027856450411491, 0.019585249356168788, 0.0188175569564919, 0.05637496986309998, 0.07421225920552388, 0.06419640485546552, 0.02117117812304059, 0.03895146866852883, 0.03783099266001955, 0.13441725284792483, 0.03734268175321631, 0.011139160724269459, 0.012291400653339224, 0.030201534573279787, 0.05896141388802789, 0.020419076390680857, 0.09428567660506815, 0.0410251257562777, 0.05301727112964727, 0.005095686601634952, 0.05559148085012566, 0.01948370128957322, 0.04230221347825136, 0.08434149145614356, 0.03771830124605913, 0.028683707132586278, 0.026319295138819143, 0.03592791821574792, 0.013179270881664706, 0.05862125792191364, 0.032903840838116594, 0.035106453506159596, 0.047311038651969284, 0.08488207924528979, 0.025490609332337044, 0.08521456140442751, 0.022066200799599756, 0.011402865275158547, 0.03687856486067176, 0.039092027727747336, 0.003851964215755288, 0.01332343306785333, 0.031233455665642396, 0.03788075366173871, 0.03396759449969977, 0.10600086359772831, 0.041074118635151535, 0.03363574687682558, 0.08724706640350632, 0.024652550200698897, 0.02616856865643058, 0.02746445868979208, 0.01965275325346738, 0.04146314131503459, 0.05097882152767852, 0.04479371455090586, 0.029472715868905652, 0.05607766921457369, 0.036066525426576845, 0.03336585003125947, 0.06381995044648647, 0.05889519947231747, 0.045213707053335384, 0.06482015771325678, 0.06003675618558191, 0.0292942553278408, 0.026520752981014084, 0.050923238377436064, 0.07102113551809452, 0.03804875734203961, 0.031512659043073654, 0.016095344435598236, 0.026943094380840193, 0.005117049786349526, 0.02865357222617604, 0.07846391192288138, 0.008947966925916262, 0.027702367115125526, 0.12291070583160035, 0.02458374383422779, 0.046253526452346705, 0.06678997349808924, 0.009240318377123913, 0.054883442280697636, 0.029952866862004157, 0.035040224247495644, 0.04395487987494562, 0.06207234851899557, 0.08316719118738547, 0.02445829119096743, 0.051979318232042715, 0.04705171370005701, 0.032455093823955394, 0.09416869928827509, 0.05405743562732823, 0.02888840259402059, 0.022470934745797422, 0.027569671110541094, 0.03226056207495276, 0.051018808444496244, 0.012791410590580199, 0.03228554647648707, 0.024273975104733836, 0.06350614072289318, 0.057625674235168844, 0.051825289192493074, 0.002106463957716187, 0.028414858570613433, 0.04060987557750195, 0.05779177059594076, 0.034812433150364086, 0.017216727719642222, 0.02779522277705837, 0.012809406744054286, 0.033948974014492705, 0.030308088425954338, 0.02761128889687825, 0.011935633610846708, 0.03424077163799666, 0.03599519390263595, 0.0418632182845613, 0.026630154825397767, 0.05347749545762781, 0.0409955140639795, 0.022424344570026733, 0.026149250552407466, 0.011561872270249296, 0.015767908880661707, 0.05130583776917774, 0.04195746732875705, 0.06814948414103128, 0.026323349120502826, 0.0356071657006396, 0.03171547687088605, 0.011934206831938354, 0.015053056467877468, 0.0460708282480482, 0.012767516218445962, 0.010913095120486105, 0.016569478466408327, 0.05461767177621368, 0.047178747117868625, 0.0629923667293042, 0.04114091192604974, 0.10783328558318317, 0.049487943324493244, 0.05673078885592986, 0.03460890286078211, 0.05307487663230859, 0.042654087956179865, 0.0640470847429242, 0.019641420658444986, 0.02573322482930962, 0.06281451846007258, 0.028730204539897386, 0.028329747219686396, 0.03690767931402661, 0.10083296278025955, 0.024842803468345664, 0.02885604124458041, 0.02420892215013737, 0.06902365988935344, 0.03331604821141809, 0.03422717549256049, 0.04782706135301851, 0.046944343484938145, 0.03654034961073194, 0.02658030847669579, 0.0404401130072074, 0.05480353895109147, 0.04664708365453407, 0.04906718269921839, 0.06878741201944649, 0.019104456405329984, 0.07090387618518434, 0.026558819590718485, 0.026868078093684744, 0.06230809914995916, 0.02538440985517809, 0.04728120802610647, 0.0254246880649589, 0.031990657807909884, 0.03698652879393194, 0.04216375840769615, 0.03196694618964102, 0.053103642276255414, 0.04476070011151023, 0.03077997374930419, 0.034980481359525584, 0.015391310680570314, 0.05476134414493572, 0.012746297288686037, 0.05672157509252429, 0.03170758413034491, 0.023274415361811407, 0.00808346136182081, 0.02959568788355682, 0.05332552216714248, 0.07326340855797753, 0.007469991423931788, 0.022866174767841585, 0.019061719831370283, 0.05851936846738681, 0.027239689989073668, 0.054867397047928534, 0.04974047391442582, 0.06020401029672939, 0.053016165329609066, 0.03149653959553689, 0.07175543869379908, 0.017307863454334438, 0.10366430069552734, 0.09069368185009807, 0.02428683095786255, 0.014274562108766986, 0.011754743463825434, 0.07505121262511238, 0.004338817961979657, 0.07601247940328903, 0.07657971029402688, 0.029486297171388287, 0.050632706115720794, 0.028879717610834632, 0.02617922960780561, 0.05313495719747152, 0.008448518237855751, 0.04132228539674543, 0.04658212717913557, 0.04976456402800977, 0.047413083957508206, 0.026621783399605192, 0.05219044069235679, 0.025577438755135518, 0.009571935934218345, 0.17464069213019684, 0.13354558555874974, 0.12755672098137438, 0.24413087347056717, 0.10271640741848387, 0.11065313505241647, 0.17315126111498103, 0.09567754488671198, 0.10352510347729549, 0.14625600742874667, 0.17369798646541312, 0.10732105525676161, 0.1455272184102796, 0.206432324484922, 0.2702043321914971, 0.0670542819716502, 0.12320428460952826, 0.2109742385800928, 0.1634834220749326, 0.15445420111063868, 0.13649446482304484, 0.14025731681613252, 0.1637264309101738, 0.1665424954262562, 0.09312451977166347, 0.24774278746917844, 0.17215491301612929, 0.1431159212370403, 0.14040473703062162, 0.1754325785441324, 0.28814970050007105, 0.09777906219824217, 0.13152587518561631, 0.11870891059515998, 0.2463245135731995, 0.1546853652689606, 0.1316456578206271, 0.19292146665975451, 0.15537997096544132, 0.24833913281327114, 0.11370495019946247, 0.20358326408313587, 0.16043810814153403, 0.10303593910066411, 0.2690819971030578, 0.2031431853538379, 0.15069685585331172, 0.29474908544216305, 0.08704984807991423, 0.09973686261218973, 0.19621427200036123, 0.13987662474391982, 0.124623486190103, 0.09869206711300649, 0.07913922177976929, 0.06897694169310853, 0.10463743441505358, 0.09638073723181151, 0.09842399595072493, 0.14990983792813495, 0.08928746043238789, 0.12944616959430277, 0.13573918113252148, 0.12049713026499376, 0.10899349246756174, 0.14323073148261756, 0.09766192903043702, 0.09981613140553236, 0.05044552905019373, 0.1569947655661963, 0.09448042357689701, 0.1565454842057079, 0.20977535838028416, 0.10932185570709407, 0.08993614203063771, 0.07075685673044063, 0.0950188739807345, 0.10950302879791707, 0.1221354138397146, 0.1089057706121821, 0.11346862811478786, 0.1780427564517595, 0.12091311888070777, 0.1458348089363426, 0.1990452388417907, 0.19969797256635502, 0.26219442137517035, 0.14836719492450356, 0.17267754825297743, 0.08984899905044585, 0.15872726478846744, 0.08160351571859792, 0.26016105548478663, 0.11888840643223375, 0.09362913566292264, 0.393345482298173, 0.14685060130432248, 0.09489328032941557, 0.10690646187867969, 0.19520324422046542, 0.18323820579098538, 0.0904140183411073, 0.08439285549684428, 0.26057496608700603, 0.13492468890035525, 0.1399954129010439, 0.15478833083761856, 0.09422657938557677, 0.16161752922926098, 0.26533970260061324, 0.21509348473045975, 0.1416463649366051, 0.16304767748806626, 0.0968769816972781, 0.1410643578856252, 0.13840743951732293, 0.21304138703271747, 0.13639130629599094, 0.14620791625929996, 0.13761332666035742, 0.11411083818529733, 0.18207778368378058, 0.1813036049134098, 0.23009963653748855, 0.10331552839488722, 0.10890115445363335, 0.11313010487356223, 0.216668292414397, 0.14918373548425734, 0.14142003958113492, 0.10206377017311752, 0.1337473458261229, 0.1412887981859967, 0.14710391114931554, 0.14088861731579527, 0.18262274272274226, 0.10430450696730986, 0.08772748085903004, 0.19565488561056554, 0.10700196144171059, 0.14168831112328917, 0.1755777871585451, 0.0797139409405645, 0.12028210039716214, 0.1629569721990265, 0.08561477196053602, 0.0993867618672084, 0.13988780148793012, 0.09037176045239903, 0.10680512161343358, 0.17561946617206559, 0.1776506649912335, 0.07500823485315777, 0.26571151858661324, 0.1601344213122502, 0.1252546679461375, 0.1160762901417911, 0.11935507631278597, 0.19080374826444313, 0.11187065800186247, 0.21787005214719102, 0.13872233277652413, 0.15068124106619507, 0.17312938260147348, 0.09360280426335521, 0.15132831962546334, 0.18100153596606106, 0.12838056427426636, 0.1431905070785433, 0.13292661955347285, 0.1864040593500249, 0.1854573906166479, 0.12334641331108287, 0.1730716583551839, 0.15977197122992948, 0.18125463800970465], [0.015367048945336137, 0.04610561270965263, 0.03146599279716611, 0.022444569949584547, 0.011741242869902635, 0.05110598482133355, 0.04618710052454844, 0.04652192787034437, 0.03310917083581444, 0.033863812568597496, 0.014409382511075819, 0.04914194665616378, 0.07398255707812496, 0.004264878252797644, 0.032715940178604797, 0.040839770663296804, 0.03331798892759252, 0.023137747011787724, 0.049888391367858276, 0.07262445651576854, 0.02877668710425496, 0.00943801909670583, 0.09813724493142217, 0.07196733669843525, 0.06847522017778829, 0.04890904587227851, 0.048457523225806653, 0.030028994515305385, 0.023719774471828714, 0.0763324044237379, 0.02802444992994424, 0.026127075179829262, 0.05095871303637978, 0.07203061963082291, 0.035323861957294866, 0.013834445344400592, 0.03413943879422732, 0.06294055739999749, 0.017309902505076025, 0.03326686237414833, 0.027283823656034656, 0.027126568129460793, 0.03154179947159719, 0.00044973557805860764, 0.06463794561568648, 0.034865667403209955, 0.012179410568933235, 0.027500347096065525, 0.017198804853251204, 0.10302535607479513, 0.10680085426429287, 0.017302353007835336, 0.03589644744351972, 0.06644785084063187, 0.04242558068654034, 0.05172620505618397, 0.07286820007720962, 0.022924160621187184, 0.05580379074672237, 0.05110777339723427, 0.015553055272903293, 0.03107719461695524, 0.029889392826589756, 0.025395028133061714, 0.05160676751984283, 0.04769088096509222, 0.048165502957999706, 0.03238928758946713, 0.034313639407628216, 0.041784250061027706, 0.03879586998664308, 0.02466525576892309, 0.02634932428918546, 0.018228200788144022, 0.014917041207809234, 0.04021516804641578, 0.02346943692828063, 0.03660844908154104, 0.018593374552438036, 0.05122193797433283, 0.037993118530721404, 0.07238117308588699, 0.026700920461735222, 0.019963969170930795, 0.045287773391464725, 0.08632796103483997, 0.04072389543580357, 0.024340215495612938, 0.05251041024166625, 0.02339656544791069, 0.030277235491666943, 0.013165736891096458, 0.02301287695445353, 0.061237599365995266, 0.07169168078689836, 0.03950281759898644, 0.00482385831674037, 0.042150106601184234, 0.06445044200518169, 0.0311763102945406, 0.01720634136290755, 0.08595805978984572, 0.008990003098006127, 0.02227721008239314, 0.03995511207904201, 0.028092768334317952, 0.019384435327083338, 0.029228020503069274, 0.030905925486877095, 0.020581200406013522, 0.013665542737726355, 0.06941173633094877, 0.09165833282168023, 0.05716005449357908, 0.0410569304949604, 0.015487465188925853, 0.03417935520701576, 0.02155326357751619, 0.04487754755245987, 0.015581869156449102, 0.021639541955664754, 0.04786902238265611, 0.04468274120881688, 0.022327711376419757, 0.07259267775225453, 0.050794204871635884, 0.016931544487306383, 0.04332648488343693, 0.029997685160196852, 0.04509484468144365, 0.0648480402014684, 0.008571903072152054, 0.03177531252731569, 0.041094327316386625, 0.04094760100997519, 0.012485717179515632, 0.023346025191131048, 0.07749015479930677, 0.021872917714063078, 0.06175621587317437, 0.09674707616795786, 0.061141086771385744, 0.0450681867368985, 0.0321883807919221, 0.09895212308038026, 0.02948145651316736, 0.03380671543709468, 0.027050418211729266, 0.06962249884963967, 0.06026808732713107, 0.0787794211646542, 0.04383538667752873, 0.06287374926614575, 0.0316224004200194, 0.02837567688402487, 0.007815734370524297, 0.024688305020390544, 0.028536069839901756, 0.01352952562228893, 0.05250662157777697, 0.03866776416543871, 0.07432436803355813, 0.022846389110782184, 0.03012710643815808, 0.03564424339856487, 0.02373609986534575, 0.028126244760642294, 0.05331780754204374, 0.03460430525592528, 0.014665795461041853, 0.025764200217963662, 0.01579028834385099, 0.08751269589993171, 0.044646131063927896, 0.037658049986930564, 0.039205142165883444, 0.032073629918158986, 0.024904713427531533, 0.021706609841203317, 0.05553661016165279, 0.03292745597718749, 0.023367677349597216, 0.035502329919836484, 0.023201028088806197, 0.037055184875498526, 0.03236149415897671, 0.020633002313843463, 0.013111038751958404, 0.08252811298007146, 0.03977378313720692, 0.02580595715699019, 0.0260760970559204, 0.07390293205389753, 0.03778420024900697, 0.029326394032977987, 0.03152429962938186, 0.04713624432042707, 0.028111681967857294, 0.034653973489184864, 0.06510500883450732, 0.023351298150373623, 0.01509083735072636, 0.07542376333731227, 0.04770132669364102, 0.019640350110421423, 0.017706793805700727, 0.04336281301220879, 0.016132218042912427, 0.015532034867646871, 0.08934629047871567, 0.07059034847770818, 0.0717818591510877, 0.07710241974564269, 0.053718263006885536, 0.0613119328772882, 0.0031263014943760936, 0.03482576212263666, 0.040320174521184526, 0.041385557196917944, 0.03134196136670653, 0.05483877983351704, 0.005752481729359715, 0.02881689666537568, 0.018620086302689742, 0.016996100202959497, 0.05984948264085688, 0.0735385152802337, 0.07712862498010509, 0.027697201767296065, 0.012710305909422459, 0.025802999698498752, 0.027955799414485227, 0.09077050897758454, 0.045998661807971075, 0.01802831258828519, 0.03882330347551033, 0.03092924005613895, 0.02063620097032981, 0.0186866903459304, 0.05959867012279574, 0.05258608332951553, 0.03486121822788846, 0.028912038142152596, 0.04095974625670351, 0.06155684903205838, 0.03254304203437641, 0.014563565546268364, 0.03915875422535464, 0.05168408817553427, 0.018390794211882167, 0.059595727507257834, 0.03624323078838643, 0.0487453392270254, 0.061803880307707004, 0.1188852745690383, 0.015814497201063205, 0.03376230160938576, 0.023680401682213414, 0.037233322582324035, 0.018298665854672436, 0.025324577909486834, 0.07704657313297503, 0.010061237608169904, 0.04608921124599874, 0.07320306453038938, 0.017688718799035996, 0.03593248613469768, 0.05219750222750008, 0.013247037313703913, 0.064233126322506, 0.01877558108390076, 0.06615868041990325, 0.05577708827331662, 0.03207273191947024, 0.04030554679047782, 0.1105119711428415, 0.05246505759714637, 0.04664710591896437, 0.046229517975007184, 0.037790066926390864, 0.014532228360621957, 0.027490085049066693, 0.04162976831139531, 0.04046774316520896, 0.024504473185515963, 0.042457819581613876, 0.04123059676203411, 0.015462660758203128, 0.06539473586599343, 0.014658208856417332, 0.02153237768652616, 0.03144117537885904, 0.011470483277662424, 0.06140984070952982, 0.10907312491326593, 0.05345402503735386, 0.042179347219644114, 0.048174304829444736, 0.04002542314992752, 0.008887774110917235, 0.043617959672701545, 0.06389600574038923, 0.04792465377249755, 0.008165417657437501, 0.02667549819307169, 0.0527198109193705, 0.050875533124781214, 0.025359158280480187, 0.04598324368998874, 0.05038868053816259, 0.04456877701159101, 0.06920674772118218, 0.040597782281110995, 0.05373407075239811, 0.03276918185292743, 0.05600534692348447, 0.08660680818138644, 0.05302472971379757, 0.020521772930806037, 0.029175361414672807, 0.03379308960575145, 0.004943580652252422, 0.029916414423496462, 0.02745925808994798, 0.03440017011598684, 0.03020462376298383, 0.046600747664342634, 0.04354058706667274, 0.021736282760684844, 0.05817826997372322, 0.05257158918539062, 0.026714787491073366, 0.05653955595334992, 0.017542380264785606, 0.010028316864918452, 0.055361062550218776, 0.01792184222722426, 0.06807120240409859, 0.008336470637004822, 0.017080298712244257, 0.009935239486367209, 0.02942061524663586, 0.04706799270934425, 0.05803928797831759, 0.06070662238926161, 0.022026813167030923, 0.027733784081647173, 0.020272149704396725, 0.07158558335504495, 0.022946759017941076, 0.027160482422914356, 0.012449518926587189, 0.1331812355783768, 0.12087925468222238, 0.08592084850533865, 0.11115711269667372, 0.07837328827008605, 0.15537792263785377, 0.13041504338616505, 0.12760176934534684, 0.11307822132948786, 0.15180578775471076, 0.13483778340741992, 0.18351199891185388, 0.2528993779560551, 0.08931216652854346, 0.12537005706690252, 0.14917543827323243, 0.15538233099505305, 0.10057490319013596, 0.15581270243274048, 0.15017574944067746, 0.10878898625378497, 0.10914774786215276, 0.25356036436278373, 0.13477173226419836, 0.10423410683870316, 0.1825217661098577, 0.17584326822543517, 0.12553047970868647, 0.04734787515189964, 0.17971819936065003, 0.14043161761946976, 0.15517243678914383, 0.09894519884255715, 0.1983190918690525, 0.12821237876778468, 0.1182608463568613, 0.09644513338571414, 0.24453828285913914, 0.1009874556621071, 0.16384199814638123, 0.12572147883474827, 0.15526496776146814, 0.19413944974076003, 0.09963457981939428, 0.14567506907042116, 0.1059790221916046, 0.1067485922249034, 0.15009837312391028, 0.15689429361373186, 0.22220042446861044, 0.302079456159845, 0.15293653879780322, 0.1236923060787376, 0.10703138759708963, 0.16891828825464472, 0.26763653091620654, 0.17090889159590006, 0.0854941358556971, 0.11612899004830979, 0.10258689522743225, 0.06954907817998901, 0.08995071038953029, 0.1145182030450087, 0.13536739483242854, 0.1888187407166697, 0.13800562592223287, 0.0982417022169102, 0.09093031563679688, 0.09951713494956493, 0.07976718261488713, 0.12042589150951244, 0.12558891641674563, 0.08448575012153015, 0.09263584521249868, 0.13574357464676723, 0.07988066441612318, 0.11998218367807567, 0.19158889597747475, 0.2200107029057108, 0.18122732697520405, 0.14835043722996488, 0.1677451457362622, 0.12046846852172166, 0.09887909574899822, 0.12428036163328215, 0.2701835223706439, 0.1121943308680784, 0.13368353596888483, 0.16546007303986698, 0.06788341677747667, 0.10922853063675575, 0.12474987393943593, 0.07585826853755862, 0.15177270281128585, 0.13682184100616723, 0.16657114232657477, 0.1762102305656299, 0.14256683585699648, 0.08220554591389373, 0.23539275251096115, 0.12419259524904191, 0.21931203023996204, 0.13183184782974422, 0.10933112513157539, 0.17768057354260236, 0.10018011773354374, 0.10986003893776797, 0.08210243191570044, 0.13573287287726998, 0.10566756507614627, 0.17181805218569934, 0.15372795023722574, 0.24580316967330873, 0.1177523861406371, 0.11819990861113183, 0.1427167051588185, 0.14678107690997422, 0.11511496399180032, 0.2627496962668374, 0.23353624041192234, 0.09978646034142002, 0.08843225397868082, 0.15647446067305282, 0.08794242166914046, 0.15811965364264324, 0.156992835982237, 0.1517841318855062, 0.1475241596926935, 0.07877472336986102, 0.14066665578866377, 0.17699227610137314, 0.134770663571544, 0.13915927964262664, 0.10183273217990063, 0.13098332070512697, 0.2719052752945572, 0.1299753357307054, 0.16141326050274074, 0.08289549834444188, 0.1813264036900364, 0.20786429842701182, 0.17844295216491446, 0.13548469869419932, 0.12306257893214934, 0.21346089342841879, 0.056003094505285844, 0.11688762824633159, 0.18290091451490298, 0.10434739568154328, 0.147766396694351, 0.1421733046299778, 0.14732032141182572, 0.20477025507716462, 0.07649685692740604, 0.11597684235312045, 0.11626760839135386, 0.16712300333892927, 0.1454593861126341, 0.07045843172818422, 0.20268994092475623, 0.16089317825390026, 0.12180486868601292, 0.06545646028826013, 0.1377551956102252, 0.15698646835517138, 0.08000199071830139, 0.18040799594018608, 0.17316119105089456, 0.11400970572140068, 0.09553670010063797, 0.11898297831066884, 0.07518901460571215, 0.1634167178417556, 0.07350911881076172, 0.13188899320084602, 0.1500874783960171], [0.03774287746637128, 0.004834817982555251, 0.038111869580461644, 0.03115230552793946, 0.06600708933547139, 0.041386822558706626, 0.043715800711652264, 0.017950077235582285, 0.03785186185268685, 0.06037413280864712, 0.0872478233941365, 0.018987967050634325, 0.01327143170783529, 0.057196356647182256, 0.033127127098850906, 0.029258192516863346, 0.042631471005734056, 0.06989199493546039, 0.04836518150113989, 0.023594357080582995, 0.05585522158071399, 0.09416479559149593, 0.060818285928689875, 0.03215633114450611, 0.055909108923515305, 0.035421357897575945, 0.014839995146758156, 0.03134554222924635, 0.045136282496969216, 0.04776386747835204, 0.05190405703615397, 0.05847043496032711, 0.07134723520721309, 0.053530907825916074, 0.033886763485497795, 0.05245457105047535, 0.03913651577022392, 0.045691331033594906, 0.031958044128259644, 0.038905574256205, 0.05189458723179996, 0.03659675654489547, 0.06915658595971763, 0.003372672026671353, 0.051207102442276664, 0.026600383571349084, 0.016457553319924045, 0.013034350777161308, 0.058362830968690105, 0.03330598468892276, 0.013158775545889512, 0.07434658051352017, 0.011588044108066242, 0.03351832798216492, 0.010641972803568933, 0.022665542564936914, 0.09606877545593306, 0.0974383125139866, 0.007595028928335523, 0.03878194358549081, 0.12789301777957007, 0.04955923403031193, 0.05326105179847218, 0.015486537504330045, 0.05772720745881088, 0.026234397155349143, 0.013975908896100009, 0.02292437584401341, 0.04499871800362598, 0.035131593758706, 0.034796859181369655, 0.022065473494876642, 0.058120245157624595, 0.010848196161532542, 0.033717635451466776, 0.016874914908839855, 0.04953883610141929, 0.031480078760068864, 0.012958441129740095, 0.03346369478094857, 0.02603108765470097, 0.054950918347458355, 0.08177930081728846, 0.02691456251341151, 0.05460714441142045, 0.023417917036567815, 0.028766499272023793, 0.03890785636031069, 0.055391301357303746, 0.0167269974554074, 0.053533408863586374, 0.06512009669677354, 0.012784320297214435, 0.010833073047251673, 0.049679428557283245, 0.03366068674949929, 0.057199443981517106, 0.03606503742048517, 0.09108371014008299, 0.06394541793270037, 0.05076429632026702, 0.022762687840440776, 0.022876408984302543, 0.019036509074794594, 0.02683357750356663, 0.014097789953666506, 0.08205152800655924, 0.09490692842518911, 0.09517031663563102, 0.023538311943411827, 0.013818908482789993, 0.017368760381941684, 0.022956659267947543, 0.027492098124639597, 0.0904632153105922, 0.02884997047658544, 0.011321169658913277, 0.07187287614215165, 0.021391072768892627, 0.08161821024259552, 0.005956194772807066, 0.04307802868424915, 0.08850677302689292, 0.024752630670263898, 0.05492340322234668, 0.009632871824578615, 0.057249683668487705, 0.025119802667177282, 0.06695942065562122, 0.03860222510411404, 0.03115095110842958, 0.034941303383675404, 0.05048049533797894, 0.0508216012531193, 0.007011093221080955, 0.015837234750506468, 0.0249923629235127, 0.03598498195060529, 0.016750486429373268, 0.015424361299665179, 0.05603013836662285, 0.0282053873888799, 0.0553589548508171, 0.06507504091132432, 0.005956916975264903, 0.02893207798479125, 0.0387145973945735, 0.060998019253020175, 0.04311235672503244, 0.028766272916982416, 0.024009089611354284, 0.02752778058493277, 0.05831760820001364, 0.027018305481760763, 0.017472419858677313, 0.046044656410231255, 0.01764445154549321, 0.006627916345678386, 0.025182794306601863, 0.017261106295336504, 0.05788302136352286, 0.032658490526955575, 0.0063958263581298525, 0.012475586863729404, 0.019649242894956842, 0.008198875530069927, 0.041597032177378424, 0.05488343856995925, 0.033115557016571984, 0.04080625527421944, 0.015918344070087187, 0.020230123736837413, 0.030080833530519158, 0.020838109667238314, 0.033604665732127614, 0.07691162842093036, 0.006830504107711022, 0.04351579562353436, 0.03556779847713187, 0.035457574704196304, 0.03464347952103708, 0.024505747824150603, 0.05759969906648621, 0.0025303297752543585, 0.09043587459018454, 0.035917134810006246, 0.03638912217866164, 0.05660369235556573, 0.032252650780719705, 0.038953309194766916, 0.015559750372631242, 0.057098111137747765, 0.04273779479262885, 0.04990389854356181, 0.03415141334699001, 0.02408517088042572, 0.0035684944168679067, 0.012706810393865453, 0.05404038849519566, 0.0269772424508119, 0.0260959272418404, 0.04875005928624887, 0.06806370671256445, 0.04768440943735186, 0.06241778115509078, 0.02714762285904726, 0.07274110728758387, 0.03224745574698318, 0.0303802251801244, 0.05560600839089602, 0.07315996801480651, 0.06280248824623413, 0.049267896538367495, 0.054306934544001706, 0.05550952919293195, 0.04513038984441664, 0.04272764221241232, 0.023288664597203024, 0.0327376294444548, 0.016078968947113026, 0.011574569489312125, 0.07292780195712112, 0.025636172322265338, 0.021801786569994874, 0.023058094157022424, 0.033234927759622224, 0.0023646177078262554, 0.026608866319293156, 0.07570263274828903, 0.03286360159108881, 0.02323638771486003, 0.07679382732021622, 0.0641845008067321, 0.04847760574193671, 0.027057520564994775, 0.04192425622022711, 0.1041541997983586, 0.010373479544796282, 0.027015873092750553, 0.10616875224513933, 0.048802395540405996, 0.022543143859365955, 0.05585991937550716, 0.03945947617467027, 0.03225754524464719, 0.07199550862424076, 0.041149249955196865, 0.03653158484667074, 0.020221733757352922, 0.07792491975123994, 0.04959637481078971, 0.04709859887952916, 0.0372818441974232, 0.12706285138847306, 0.046442878010566346, 0.04565203060337808, 0.01315029279794544, 0.04176544774963986, 0.05812151051941328, 0.02829209806805011, 0.05757727878517471, 0.0696190627058968, 0.02960262881970266, 0.021719758842664305, 0.0383565482479753, 0.019966128820669837, 0.060000502271577716, 0.024145398019754793, 0.0050544654004625045, 0.06290011777309701, 0.024322813987964764, 0.006692197930533439, 0.029773346905130893, 0.039574041511514224, 0.04503763993852772, 0.13069383858237416, 0.035996763544972055, 0.040958054160000756, 0.0457126677792985, 0.015058765438880073, 0.0655705580720678, 0.02462674572598189, 0.013606581887870561, 0.025170252010866534, 0.030187532101990655, 0.027516479531186633, 0.039455958394682966, 0.08936338213970885, 0.051905596992583014, 0.07114687017747201, 0.022101731119619217, 0.051280022162245587, 0.022883639358042274, 0.0339682735648239, 0.030989517290436197, 0.04875735830864869, 0.05360432107408997, 0.06928566028364003, 0.05392069862864446, 0.041609715481172316, 0.027498443487274926, 0.021065592773084063, 0.05259117817331571, 0.11336689451127313, 0.044368059461703524, 0.03206451263395138, 0.012509490024967818, 0.05654191969370004, 0.06673476513242349, 0.03349625279952306, 0.08736473391763866, 0.10561395232798532, 0.03849101427476853, 0.015233396497933427, 0.024290888650284614, 0.041156972001772374, 0.015339031015173532, 0.06685600979835726, 0.030490276403725147, 0.04649338487070054, 0.02452080043440219, 0.06296926367213018, 0.009715340202092193, 0.05575703915383201, 0.06375614801072516, 0.07184564674389549, 0.06256635169847868, 0.03125650306174066, 0.05840251731569879, 0.0759418863162864, 0.02315961439308012, 0.04570208475342952, 0.037745174413430505, 0.015776315558468923, 0.02362532504776027, 0.04550740086415317, 0.02584454141469905, 0.026285532985639293, 0.04592301098455209, 0.021743813704233617, 0.045546033361461014, 0.012584655669343192, 0.05733274854719639, 0.06581999390618876, 0.04495180684898514, 0.020704421040136367, 0.037266923318384215, 0.05099223955767229, 0.058346410951344296, 0.04058622333104722, 0.020967707205272745, 0.03927906378521584, 0.15492546488530934, 0.08456846990156919, 0.09936518763424829, 0.1651094973203726, 0.12437291487003677, 0.09958884125808254, 0.11135083550470881, 0.18172579788370058, 0.09879032746539451, 0.08083396794972941, 0.12948627525474876, 0.14568354439688846, 0.20763965032529086, 0.09270531023503281, 0.141488806984853, 0.12858089961810037, 0.1523148565320298, 0.23594461352331564, 0.24897834460716695, 0.11465514413430355, 0.1522531543741934, 0.25982661405578256, 0.10147529901587404, 0.1612413494149223, 0.1537646568613127, 0.1254913239972666, 0.20260958117432892, 0.15481820970308036, 0.11526673319167458, 0.08764515441725962, 0.11803863249951974, 0.12303686351515353, 0.10613373029627837, 0.1429552017361857, 0.1241361400752794, 0.15939757257001474, 0.11170745972776785, 0.19749567902181298, 0.12098548570065759, 0.13992009975481778, 0.1676784415030852, 0.10289212572388351, 0.14223335921997204, 0.14133583550574258, 0.12676710553932935, 0.19047524401685223, 0.09629974665585905, 0.11706857869285159, 0.1553430565400049, 0.06332811433821917, 0.1043065775593277, 0.18093014135956764, 0.16871755215106532, 0.20910996361635625, 0.11984821860096417, 0.1789338086382486, 0.22215792909264565, 0.21829879085998982, 0.10708625457482412, 0.12789610511390492, 0.4360283544519916, 0.17974873131606728, 0.08419171121204272, 0.14702551066875458, 0.24990677135065198, 0.12562640971736982, 0.09442318914807402, 0.10114017481100745, 0.18371539190411568, 0.2579184336354956, 0.1275425756466575, 0.09833864896791056, 0.16114038764499128, 0.19278381310869008, 0.15023610088974237, 0.09336870862171054, 0.10632495948811993, 0.20566912950016558, 0.18520948360674083, 0.16670210170559585, 0.18112259509507567, 0.17680559627478942, 0.17297488229814917, 0.10885726384003647, 0.13094468449708074, 0.20447341084945947, 0.09866987689747475, 0.10596532956697047, 0.09912102104863152, 0.08366946189198643, 0.16118053783429787, 0.13901178521336988, 0.16222680278588086, 0.19211815117159858, 0.22587217041291296, 0.0869354311726056, 0.12767037347657606, 0.13904800201999024, 0.11997532623354346, 0.218872589757666, 0.09108255238970742, 0.0789143584552221, 0.14120637526502833, 0.11391743450076319, 0.16748340509366244, 0.18395936553133652, 0.19944770552683622, 0.13929043198004365, 0.23083632200723514, 0.1216023662709631, 0.11285860498901457, 0.15572232368867844, 0.11814809928182513, 0.25768373685423285, 0.17292026022914797, 0.13676962349563837, 0.09735248313518241, 0.3065022703958675, 0.10451854235725477, 0.12634038546821102, 0.12708060356089845, 0.12685410008998588, 0.09701012299046852, 0.14139401988359168, 0.14322887611342594, 0.11725329924956895, 0.1462978051858954, 0.22421444999054074, 0.22645490476861596, 0.12289730264456011, 0.1098438526969403, 0.14707029185956344, 0.15529028984019533, 0.18570997315691784, 0.17467269353801385, 0.17113034846261144, 0.1342757698148489, 0.0776860817859415, 0.09867907952866517, 0.08707123677595519, 0.09905013110255823, 0.12964739551534876, 0.15055151365231723, 0.11207937961444259, 0.10035474508185871, 0.19406130159040913, 0.09362494252854958, 0.1784934924216941, 0.1322467825957574, 0.20296003815019503, 0.18094721075613052, 0.11753464001230896, 0.2198994401260279, 0.14660938846645877, 0.0742983706004452, 0.10606113341054879, 0.12357977422652766, 0.08782761884503998, 0.11856012482894585, 0.13456991262501106, 0.18523841252317652, 0.10518643073737621, 0.1704848135705106, 0.08673760428791866, 0.07727962234639563, 0.11425143064116128, 0.1602474949322641, 0.16625371092231944, 0.08816062050755136, 0.12513246590970084, 0.15410505031468347, 0.16702845372492447, 0.11815636680694297, 0.07918735747807659, 0.14237071591196582, 0.20135101745836437], [0.06039755870006047, 0.06054138320905622, 0.03366122851730324, 0.041637690737843513, 0.06557570857694373, 0.0034668306216190103, 0.008535612978448626, 0.04992509799194522, 0.0907350640045479, 0.058839430785155855, 0.011493731981317978, 0.009718549063109094, 0.03550867157173343, 0.02860649965441553, 0.057744436417124234, 0.07379037051578052, 0.04472528111364227, 0.0074599028539523715, 0.05839061697770376, 0.074202626128681, 0.04288161188014783, 0.04871174962318037, 0.030960285948822275, 0.017876459896797314, 0.031847397331148386, 0.02276704053656431, 0.02690960311156232, 0.040371182331000455, 0.05436776096757967, 0.0499313876935048, 0.010760859295260161, 0.014390440119314007, 0.04341326050052885, 0.04069564558449201, 0.03907305472239386, 0.03890379681251943, 0.015834063924557995, 0.022435846003645565, 0.04525587588432245, 0.02052692714642035, 0.00586137195568881, 0.07976462962687947, 0.048168037392315455, 0.01439331686924561, 0.020091546211915556, 0.021362952793424483, 0.04927622343529947, 0.026933734043268487, 0.07634129535290413, 0.020179999082756694, 0.041940657683881, 0.06632120333961211, 0.017855698315543123, 0.12644977803574875, 0.042100623904843815, 0.05887507242732681, 0.04009599026176147, 0.048672764605726115, 0.022988825803622603, 0.05082118193968199, 0.048207994623226114, 0.025012803525896743, 0.045975940956850536, 0.011823572094726842, 0.06686028456897475, 0.056318781862501055, 0.026587232714518905, 0.05777014070190489, 0.023434398281096946, 0.009632221517676953, 0.027898156804440077, 0.024160086977644823, 0.08850436846842058, 0.023169867163232993, 0.07667622659937479, 0.022582357087230776, 0.05914186709560454, 0.020859294272668194, 0.010747059059212916, 0.006990816355028073, 0.02083575149299577, 0.022171993950905744, 0.06599714455660433, 0.06718124117469415, 0.028883016457257327, 0.07208813607576303, 0.037315556255634874, 0.04043465822178405, 0.03535811207257211, 0.014562919877789682, 0.039844765851739794, 0.052594050284824334, 0.043619737116387114, 0.01634326072235126, 0.004415633493408677, 0.0717226357664913, 0.002768934195955808, 0.01995113372686319, 0.07708212942816317, 0.03637363355665002, 0.0780131017381791, 0.019291848693683278, 0.02733062719926238, 0.04865981412876863, 0.05104044576000888, 0.02538433749577962, 0.008218958046199987, 0.016166824389074463, 0.05000170618586708, 0.006488159269792959, 0.05087217490654439, 0.048197426440310664, 0.004711399751613499, 0.017396487019141205, 0.01183111509817536, 0.02166367288737092, 0.029267448953760322, 0.061091088282410055, 0.051042954219155945, 0.04748177343572024, 0.029568872232630383, 0.018339062808081508, 0.03904215540387668, 0.05451200107927434, 0.037349583726609126, 0.03929814069124404, 0.02725477228523232, 0.04709665816335473, 0.01719630010484252, 0.025082084866880905, 0.1032554441189859, 0.03235347154259216, 0.020141299792157952, 0.03439164283918217, 0.024659914161020424, 0.03458038954704534, 0.0477386901184218, 0.03656736749690026, 0.024373610285692848, 0.021895052268519066, 0.047362369296024553, 0.035993483252241276, 0.06883781868964434, 0.0049836881680676015, 0.037730646872660145, 0.06952037932933308, 0.039627888036193326, 0.012433616557245841, 0.04301899825804867, 0.04720960932900198, 0.008194544170692097, 0.039025204750942066, 0.04427054496773053, 0.09048435909789987, 0.01800783116777893, 0.025406034183106385, 0.06158747375593521, 0.04908967348455917, 0.047973023247323, 0.03834959432424512, 0.007643178078069468, 0.06699793812003918, 0.07297601929167286, 0.05427163800050039, 0.0878020073287189, 0.027718545934476424, 0.09363617122289725, 0.04214835884340573, 0.05644483935611788, 0.053992442044545896, 0.013803077545162523, 0.054589306892012246, 0.03218350117094815, 0.08613610843895003, 0.011562220151972724, 0.03339241520734504, 0.044662825675914064, 0.01684468166786246, 0.11728857352863997, 0.050270623396500014, 0.03530498543113936, 0.05520149337826297, 0.014127025933703408, 0.03898645351000596, 0.07509622388170101, 0.0173418445410789, 0.025046920054592192, 0.03330048537463881, 0.06944766369997524, 0.027037439904233906, 0.04685091451392509, 0.038344655331457034, 0.1118123548803851, 0.044773888075724244, 0.08125170803396031, 0.033536191476741806, 0.009505986836302327, 0.11454320600023493, 0.020992376194044482, 0.06290650024311617, 0.010735639261838514, 0.04531194514129311, 0.04508625061134808, 0.03447835908445995, 0.06276978179812431, 0.020400415087351575, 0.03295590249763336, 0.01719645781122381, 0.01557629006128991, 0.055020001163939014, 0.042711296409834176, 0.02390310535702156, 0.05875795781321358, 0.012795395923603792, 0.04831146856304258, 0.012422067811712623, 0.036095914474572055, 0.07421708316542208, 0.09859391808276996, 0.045171742312959395, 0.013480690449796384, 0.026831907671294175, 0.026297720905859023, 0.025960106795537286, 0.015890608156041708, 0.06450131622841582, 0.03316116570204031, 0.047433760191779584, 0.04361562190752011, 0.0239839883215609, 0.04678028431953862, 0.031070760196598712, 0.02679444591194624, 0.04094676980457734, 0.025041118315130007, 0.08053059282246977, 0.007694091264056624, 0.03965185198467225, 0.022927557802177034, 0.037897756265010685, 0.023961992919794284, 0.04931334566208534, 0.029942573273729067, 0.0036236287996871397, 0.04040613377583213, 0.022207147630979307, 0.0304778268764494, 0.0931321490497794, 0.04803288487892132, 0.052934454870410264, 0.061115311982575804, 0.007280939507836592, 0.0554400456167059, 0.02614509081467986, 0.011130541606689803, 0.03581374621717259, 0.004734733802251867, 0.012931225646752864, 0.06459521275246516, 0.0810625939629972, 0.03799010541115422, 0.04426238876476418, 0.020646752454922535, 0.04884371090156492, 0.067112666729372, 0.028609963628696278, 0.03357615612912923, 0.04216218505462166, 0.01937273351359181, 0.021490335020644125, 0.014150557581160683, 0.04837133761611767, 0.05349835722881835, 0.06676518576568924, 0.044424347652238794, 0.04416357180161867, 0.09138209803495556, 0.04087562752829399, 0.016769682079029735, 0.07202917244285345, 0.02720384425629163, 0.03893923436407931, 0.014082868146942928, 0.012913211867271457, 0.0623623798310291, 0.029657102459168527, 0.04377653436677065, 0.0552820015582256, 0.015602003622916527, 0.036702419820358045, 0.05402408722147811, 0.062091956060612574, 0.02072203962597996, 0.04330581235990394, 0.08914249672670849, 0.04622067899617832, 0.013536301430576714, 0.014230064789444441, 0.007185706190284691, 0.008193681424017996, 0.014429358343477361, 0.05643290191073902, 0.05709461562219076, 0.03296826296718791, 0.04112294082005974, 0.011224183017475298, 0.07839380865334533, 0.028779162166756578, 0.03521265112794936, 0.039527679546154104, 0.042906221497105435, 0.031111066236917395, 0.041834523144643754, 0.01254806778888451, 0.011063733472838067, 0.031185750412987545, 0.07439556226017885, 0.03051263545785332, 0.031170766451396048, 0.04462414493900724, 0.02309591400262434, 0.057615944679128006, 0.0019567535218811827, 0.038615795274381526, 0.045494762089219876, 0.07753616795525886, 0.02540381145081483, 0.06737249263096601, 0.05618241222691722, 0.06319987121969461, 0.02523895447666291, 0.06164884194731712, 0.037624690448865294, 0.010423844469187316, 0.04861416091443971, 0.02034053861279972, 0.016686324051988777, 0.07685728836804628, 0.04319126186601352, 0.039547799169667996, 0.00939255791308824, 0.008148432680172846, 0.01787318517017411, 0.03438130843278486, 0.020253677648724988, 0.021397137970780022, 0.048987453774316236, 0.021721170778619125, 0.038339011298376136, 0.05513859636266716, 0.021535088380915113, 0.024240671227744315, 0.13788507145363837, 0.0857602700125426, 0.1952333012013696, 0.22297133778920397, 0.17352895491058007, 0.1334952234174125, 0.12399949584505521, 0.10916885454207659, 0.23652194504393265, 0.15295402379706502, 0.05780853571195621, 0.13498558953870088, 0.1194805141130928, 0.0960305029002484, 0.20824865670874715, 0.2692645357456058, 0.1597946067340672, 0.12043499024002813, 0.21269066288368776, 0.26281749887857586, 0.15772543963976204, 0.2613709639990702, 0.1165897524333559, 0.1732471614377573, 0.11047585823689587, 0.13008262059884146, 0.13577787671238184, 0.10419072088552639, 0.19386469182791188, 0.10306693860911764, 0.09770924836630002, 0.09029931941768155, 0.17307568079559132, 0.15905415115412325, 0.16829580446938053, 0.2093552879523486, 0.15038913174066693, 0.13950878666946664, 0.18025671655777842, 0.07783119392115623, 0.13324810308404267, 0.19195327564375475, 0.2141703717643395, 0.08970366427092813, 0.08825482873362489, 0.11230586824240163, 0.16933694860199466, 0.1125349618087057, 0.2837391465436667, 0.21305728383595124, 0.10779438220197335, 0.17953576461877674, 0.1568217115709558, 0.21478160459082574, 0.15169014630373567, 0.09838967904215679, 0.13584616914158687, 0.09967553894966841, 0.0781084009213373, 0.187308395979926, 0.12344493341515772, 0.14457473123911768, 0.1282969390740618, 0.1268206737586297, 0.08431017282418907, 0.21035966608906165, 0.10016867381636985, 0.11709160753525794, 0.13838366110576317, 0.08450879380689003, 0.14609554025810212, 0.16200398036744446, 0.32250125252176076, 0.10047903255326673, 0.16490410052938387, 0.08594808532507159, 0.14385784626938403, 0.09805380526813678, 0.08567514567403123, 0.1230663045134861, 0.07371514642727561, 0.1116287030163221, 0.13464160409057513, 0.2327937216614373, 0.12236052949447185, 0.12401978616253473, 0.2392209877143614, 0.06970853602979332, 0.2800564910285175, 0.14126187306828797, 0.2151867133216001, 0.15165199991315603, 0.12300248723477125, 0.09699506481410936, 0.10832786763785407, 0.13321378617547452, 0.10412647316115908, 0.1267120530246757, 0.11893525821506046, 0.161494956118986, 0.19295573903946206, 0.1468946848763153, 0.16233950533205643, 0.135710341273807, 0.16341569367796183, 0.18507815315388143, 0.13448717800201848, 0.1287365725147538, 0.1330563469673507, 0.11639011470833793, 0.13787073316052556, 0.10481851844815537, 0.13810265430947766, 0.14441966690355912, 0.16003573051420972, 0.16871351486770436, 0.09902381454594433, 0.10224312500213273, 0.1304388217977248, 0.20070304832188413, 0.15207460848614573, 0.07203349174233153, 0.12834072578698397, 0.16690792894223705, 0.10738535493146628, 0.11704829579684883, 0.15323188388720155, 0.08999557321658358, 0.14553898887243122, 0.1182271825382486, 0.17535413353471085, 0.1524875097675249, 0.1225224586960394, 0.09513577708275989, 0.08031316581764258, 0.17182397452415898, 0.16158690821612254, 0.18107257434166968, 0.15827626164536923, 0.13341801037313417, 0.12740504083922133, 0.10204288613749668, 0.13133524713339284, 0.13493688980815932, 0.07410133781377226, 0.15806408162461594, 0.1919584409915842, 0.10773241287097335, 0.14446388406213373, 0.15109436499187723, 0.1305357611272484, 0.13905861473176628, 0.19548132695490494, 0.22532155620865524, 0.12257269467227161, 0.13789920194540173, 0.1111009914893657, 0.07261276768986136, 0.22105254465714097, 0.1298035285435617, 0.14866221346892416, 0.15156246721744537, 0.19347669702256098, 0.18868242303142324, 0.13400877476669848, 0.0968099657620769, 0.19843007263261825, 0.185396593878977, 0.19375663512619212, 0.12500202603405342, 0.2083345825667493, 0.18861234944779426, 0.10822047886904329, 0.13307959103258327, 0.1427170613897033, 0.15332239621784538], [0.0912330970459152, 0.09589238179614767, 0.02469550570822321, 0.051040887337876484, 0.07722903756075539, 0.01980567834834801, 0.06427944375900552, 0.046223573372117244, 0.05682880801032297, 0.09567171902745031, 0.06069442519219592, 0.038251749574556015, 0.021406433370430022, 0.01273382085855701, 0.049006753324647434, 0.0713840605749283, 0.014504010050586658, 0.017586489811947104, 0.06311150369583629, 0.034169710997957736, 0.023624330569873564, 0.021923782660451252, 0.05019139913201798, 0.021117556098033674, 0.07424094321322627, 0.06682933701085858, 0.05285903040203266, 0.02142331166396616, 0.03337958347401582, 0.11801251632277854, 0.017924966668942943, 0.04129798377107363, 0.0067572545958682895, 0.028909672546433285, 0.05264890241960529, 0.0356275265221484, 0.056991650053532794, 0.03134285565465689, 0.0672721245791763, 0.02593211298517417, 0.09055800241185352, 0.05433188925962895, 0.0433234828960849, 0.029348825446504634, 0.08241179617471062, 0.026245084081892855, 0.054465780121972784, 0.03591289714677259, 0.03626008125138469, 0.07982736336998641, 0.044234346714802086, 0.025046775335795246, 0.04849179931625258, 0.021635133598465472, 0.03492513198580127, 0.008475016620650422, 0.05034243731643073, 0.021588853269349784, 0.02029206709266873, 0.01666530271904776, 0.03675250736705493, 0.037057949375594035, 0.01937598040967714, 0.05676345819665585, 0.03487830617814325, 0.018108833755832165, 0.029437614139169455, 0.029760687721136492, 0.03131056851998437, 0.012430172064341605, 0.005138403230375843, 0.0797025192878209, 0.022892970009706914, 0.017347792854707222, 0.01806360171030974, 0.014195615221979097, 0.054177889905986376, 0.035740281018661335, 0.05595761940639932, 0.014196794309100369, 0.0028589128760359017, 0.021053278687759303, 0.02431641853036126, 0.03050056071515428, 0.019148526989738457, 0.019742968725040555, 0.017666571256995667, 0.05465547677886207, 0.07513900869525969, 0.05210090799664613, 0.020146492970525287, 0.03974557781475596, 0.07289594897883944, 0.034635371557669714, 0.053117334900889546, 0.05496346435393207, 0.03603119919716846, 0.03932752602850087, 0.027599681707215495, 0.028230651951162145, 0.04646368783141952, 0.029829946797690354, 0.06796140907681547, 0.04466550482902676, 0.043208494535065256, 0.037559221891569905, 0.02992910329339793, 0.0194177521916572, 0.05838829034473747, 0.032937178111751564, 0.0261009070527507, 0.03517537305015139, 0.029584312615043018, 0.06795752022298984, 0.05008388419810217, 0.057551255376893096, 0.08687274195835926, 0.011838983718917007, 0.04196702619083226, 0.051088926556985825, 0.014786642150284024, 0.03175927842676174, 0.0723806164751295, 0.024167597512132488, 0.07267773529747501, 0.05127234093379229, 0.03569725500710774, 0.02876957176340511, 0.04618968319846317, 0.029241405136417598, 0.07086390411132015, 0.017672927751846146, 0.04225038930599112, 0.05798234298708849, 0.05357692469260655, 0.07466537004802376, 0.05429045886558015, 0.018196941528003663, 0.028746476127707865, 0.0158459030353697, 0.01787493849406019, 0.05482066029799171, 0.02010902750043897, 0.01539639068141696, 0.026004852734331507, 0.0713207850640174, 0.012982966327399481, 0.028931029701197986, 0.047046663385117427, 0.10035578408860601, 0.024674497362866532, 0.13672689063241705, 0.038342670086422004, 0.04407979446114041, 0.031050427205627784, 0.00500844296766445, 0.04067750749527477, 0.06210263556567952, 0.024139766974258237, 0.07381182600511238, 0.023641520565433893, 0.053255307575454935, 0.056370583770330995, 0.0632808766386006, 0.03811745424172841, 0.0070665594830643386, 0.013664081634487957, 0.04303179659473244, 0.061309001393965445, 0.04439605698280502, 0.04288291063858196, 0.043921056494582444, 0.03643849726358894, 0.0209442794584902, 0.023577961183036678, 0.0106834774123854, 0.15016917401226237, 0.07688486657571048, 0.03821405960479751, 0.05929675702645909, 0.038653778392472304, 0.041986143914982677, 0.04905518959276378, 0.02115015307936119, 0.05742260407714639, 0.019179841910954565, 0.04889492651273031, 0.05576528812525794, 0.08545374817913398, 0.051854414778063074, 0.031752869981573895, 0.09975854816730134, 0.03646024219051469, 0.04977517302904744, 0.025724851548147853, 0.02549338125390932, 0.016360549052478746, 0.07493255805457011, 0.10553880245424807, 0.024458936859446112, 0.08875109546352178, 0.053072498049004935, 0.022660815084236674, 0.03588678468076978, 0.020646544653573073, 0.053241537025314756, 0.02072604536806466, 0.02665461230208166, 0.02818256449245382, 0.05535492869967129, 0.013346041669137776, 0.03515601783874445, 0.024337113318324555, 0.019709698244696483, 0.02860222117305966, 0.02602695945824962, 0.07436577245243825, 0.01736042420816375, 0.037609060818795115, 0.021558441912929993, 0.1070439002069179, 0.0175295893495786, 0.05902265591430478, 0.055128195162978955, 0.05631880783766974, 0.08081548847258091, 0.09060732554644346, 0.028484451613621786, 0.03248025263019372, 0.0627256091684103, 0.026356641865277197, 0.0400795405585086, 0.047666605314589106, 0.03969520825194195, 0.01738383711199276, 0.010063921399705578, 0.038137473675305955, 0.01585426518431632, 0.041675584798213094, 0.056860141485231, 0.030477398286166135, 0.03437717095948756, 0.05642326512315776, 0.07126184369553812, 0.0016210019703066791, 0.03510657224978786, 0.055660270518274046, 0.02621945401187986, 0.01805438794690417, 0.027101197811134625, 0.023739224307064433, 0.03888682389515452, 0.04385957698104903, 0.0043145571544300765, 0.04234451589582022, 0.05668779253028333, 0.020251907626516186, 0.10713640149333514, 0.04177311042440124, 0.05563374616031069, 0.05310258100507781, 0.04459134201169945, 0.024730215955059975, 0.04226227480103262, 0.057822046510409564, 0.005726717145080329, 0.049900154408533126, 0.03908133709046524, 0.07959593945997767, 0.03569808992324397, 0.02097565189615125, 0.06622957036597654, 0.08919544896343723, 0.029085329624649603, 0.03376477296114899, 0.09330086890258826, 0.05322293138306122, 0.03454864789091516, 0.09617806412279606, 0.06862612848635763, 0.014220108878362225, 0.0015159531699282525, 0.03042606207600329, 0.02398608859948581, 0.01832649824791588, 0.06003336457069963, 0.04601687782269437, 0.026894235088548157, 0.016607324287178926, 0.0591023699962534, 0.11133640073239803, 0.03062022089579841, 0.07580262230476364, 0.04451524589967448, 0.04179236544587184, 0.02748546889051795, 0.031526544626103714, 0.026948157683364116, 0.02098603825288592, 0.03903422555595171, 0.05322810415236745, 0.043565630840021186, 0.06379098442266695, 0.03415421495446935, 0.04432888890733011, 0.052161207495373674, 0.05198048340389505, 0.03771365540160332, 0.061549958190880716, 0.03115575651463587, 0.03421898960368708, 0.058413853621459566, 0.026917673967545852, 0.025767439692572225, 0.03217143013898749, 0.009678845090093091, 0.015346304990089266, 0.03368070247233845, 0.01689142398390686, 0.05513696734851692, 0.022904907455085777, 0.018920401926152408, 0.030112723616184667, 0.03538861434208229, 0.06359896855428815, 0.03835790266748518, 0.006511813371616881, 0.07990401238203049, 0.013903387152822688, 0.08040156302740797, 0.030090720792941283, 0.018726100242929533, 0.03303754987427965, 0.044947034839424305, 0.10839175170985982, 0.05937670488492586, 0.028851252536696848, 0.046067607327131554, 0.07939584902487695, 0.03976769381552003, 0.00506727858009981, 0.043434875551611185, 0.008703920011612354, 0.04386769236589316, 0.10984855791321024, 0.06400058919098228, 0.04939698199450504, 0.03722516637935769, 0.032499173685209826, 0.08458876764052548, 0.043903853511437774, 0.04062894506205339, 0.3562752058496699, 0.30485600873362273, 0.07601788223837502, 0.17032206058502197, 0.1450864865910262, 0.09671249950770289, 0.10709245892940089, 0.12354326056083664, 0.1727965145255439, 0.23197522183181718, 0.15792478050570935, 0.1346405057120137, 0.1778070948785171, 0.11612271147896536, 0.12591133505338803, 0.1681198412552476, 0.17204853356815875, 0.11793984522228129, 0.14739821723196656, 0.13167399301892146, 0.13754466315731406, 0.16678787913406268, 0.17065991589333862, 0.08209507723222487, 0.12825539364712313, 0.15426572528667748, 0.14118146878900006, 0.15710285195382312, 0.09384780947584659, 0.20196279947413132, 0.07647827354958281, 0.1358632682240568, 0.1053309343114961, 0.10136674507521093, 0.11610878878855146, 0.1135971829353366, 0.11660742296953686, 0.1990395985194482, 0.08226358928368427, 0.12453471048502252, 0.22715518047334626, 0.12193650341941975, 0.13124362158123404, 0.1427371142199263, 0.2619468705961481, 0.18379449000349268, 0.13487983349477872, 0.21461475495016202, 0.08565719312173314, 0.12934764206875116, 0.1720357092563063, 0.08231443382101133, 0.10169616958592087, 0.13504160684533417, 0.19759178714593872, 0.11189914905116893, 0.16417804261436686, 0.15557422069832683, 0.08290975500131026, 0.08565299998736009, 0.07598612573929131, 0.10197315394179896, 0.13138330861693248, 0.1692658063257113, 0.1502711302600801, 0.13695461122551933, 0.12919955392135307, 0.16131252137711272, 0.10405798777355812, 0.09785462767467834, 0.16562667035032064, 0.14484626823104918, 0.12602345872437581, 0.09211486496496946, 0.1060907673672773, 0.11735673979273997, 0.18674737686524168, 0.16140281106345356, 0.10549707891186699, 0.06448831380112097, 0.13340273697394878, 0.16356286156224087, 0.10045837858342566, 0.2299937914358452, 0.16090696735773236, 0.18885978148318827, 0.11497723622596823, 0.1501065367483534, 0.1761762995738536, 0.10515865214983933, 0.11150915786856785, 0.08740877296077088, 0.1869948979583569, 0.18149758747313172, 0.08904751666705124, 0.15073115791892633, 0.2585167530924082, 0.12627820833586156, 0.13181103800889105, 0.16674738755682483, 0.13926077575888485, 0.09388011516421102, 0.17368971894029528, 0.18185508000897244, 0.12187350250314921, 0.157603059487883, 0.12677826744038612, 0.08109780887025408, 0.0786847824929282, 0.16502064740052447, 0.13244250178104267, 0.0873223424423486, 0.16470523463794962, 0.10172587775741704, 0.19143283716402948, 0.21596408332698047, 0.21221629693172872, 0.13297931203851476, 0.10644941023201682, 0.07613756839418784, 0.134777431958355, 0.17455503344535828, 0.15719464077847078, 0.14655616163508967, 0.08893629841622896, 0.15974118694430217, 0.11178240180015564, 0.09845846871030517, 0.0890591683855746, 0.15717136702733114, 0.148400517355185, 0.15875231969403103, 0.12402662134263664, 0.15000998333562165, 0.13045330852037296, 0.1928884262451902, 0.19338964310009032, 0.09200807733577676, 0.11244290581089444, 0.10026607327745296, 0.09367471837322228, 0.1844773697666824, 0.07384386452031322, 0.12393150027492084, 0.06786368307075463, 0.19424060446908697, 0.1229401987802703, 0.11922567544388585, 0.2595209382707253, 0.17262360895983875, 0.06166764425870497, 0.22677079250570387, 0.14001947332872078, 0.13451301958411932, 0.18742344371275976, 0.08094049582723528, 0.15966775885317475, 0.12314313906244934, 0.18349065474467352, 0.11250116440351121, 0.1223686856974382, 0.13838456652592868, 0.24845425476087257, 0.1806340689654462, 0.10979734972352162, 0.15677985444199294, 0.1884413289371878, 0.12444432431948371, 0.1723804368521087, 0.14245978847611696, 0.07625363286933862, 0.10569302816293202, 0.13391731248702854, 0.18228793021989986, 0.14500995632261038, 0.08097166602965444]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.01737219838105375, 0.0324319425271824, 0.05443764530355111, 0.03239784826291725, 0.027608734053501394, 0.013256446818559198, 0.015453227133548353, 0.024738925058045425, 0.011238050974498037, 0.030089015708654188, 0.03482660074951127, 0.04585718248563353, 0.10224017125437967, 0.1158372443751432, 0.026601602548907977, 0.03986816947872285, 0.0902835042506922, 0.01896783443953609, 0.03596618334995583, 0.06261837625061162, 0.022026894803275354, 0.08187957981135696, 0.028035771392751485, 0.051301010098541155, 0.03002359353558859, 0.08846605138387531, 0.014586194556613918, 0.048882562332437374, 0.027306576048431452, 0.038762707117712125, 0.05633309418044519, 0.09533191187074408, 0.016004730059648864, 0.02664404411916621, 0.0622149373521097, 0.07260907179443166, 0.011829673476313474, 0.043674162516254, 0.041232771254726686, 0.013850711366103496, 0.05972872408165131, 0.038076101773185655, 0.10535807465203106, 0.07272934424690902, 0.07131274018320255, 0.04180708223429974, 0.10775383867439814, 0.06652723837760277, 0.13381407974520698, 0.013317166558408644, 0.03030786207091296, 0.03614592780650128, 0.012125918419769732, 0.04202285053906962, 0.03393706996575929, 0.02359861886361614, 0.018646618082129862, 0.027998715959256515, 0.11816229656687938, 0.06041796405042987, 0.062195400314521976, 0.06632246499066241, 0.03697692540299613, 0.0516698946012184, 0.03862842662783805, 0.10320128218154423, 0.07929249011795036, 0.08434584786300547, 0.06041766348062083, 0.04221042094286531, 0.019245956136728637, 0.008338133975485107, 0.021000909036956728, 0.06659257705905475, 0.05233546005911194, 0.040902556356741115, 0.011782471956394147, 0.048898158565862104, 0.05845677944307681, 0.045392846659524366, 0.027495205868035555, 0.010027624812209979, 0.02215521028119838, 0.024507423222530633, 0.02622216099553043, 0.09428816279978491, 0.06409217021428049, 0.07111824554158375, 0.07386209908872843, 0.08585746167227626, 0.03481746491161175, 0.0246465295276721, 0.012277899131731829, 0.048702680578571744, 0.023097479934222065, 0.05323635312379338, 0.03377199034730438, 0.00508825955876091, 0.06740026379702613, 0.07153066442697309, 0.12313711282331496, 0.01858898289356148, 0.0178559469350148, 0.05572006164584309, 0.03967990887758788, 0.08301335139549337, 0.026824974156625103, 0.05925084034970496, 0.010514953301026253, 0.032026785556809045, 0.029042748901701998, 0.04960460893926211, 0.03094635027082404, 0.05575834904448129, 0.04668298875913024, 0.03920547242159955, 0.03184053617587779, 0.04290068136469927, 0.04352407428086735, 0.045919411568320356, 0.030496849976771045, 0.048315030871890485, 0.06657917387201451, 0.031190526133286767, 0.04747444843815174, 0.017412081397196744, 0.05897696559259202, 0.03993137819634285, 0.12993600190384313, 0.03809769084909931, 0.030506664879794698, 0.0727266057219822, 0.02641798222612124, 0.021638890721078496, 0.012311046230024658, 0.04771816231368575, 0.010994321328325896, 0.023531330189143773, 0.009428718130948255, 0.025230267638107762, 0.07968774312757887, 0.016395105303672608, 0.027523413045855705, 0.03330609230033588, 0.033809773085522465, 0.0032180534435610753, 0.03354559448780492, 0.06866419324069284, 0.0725283706560731, 0.044405367225408554, 0.032307380461134017, 0.03427668416406959, 0.053385005303425714, 0.02973925078549655, 0.015185996453510597, 0.03715842503879685, 0.05537028373510111, 0.008624452693766216, 0.017958630487555638, 0.0368999572674511, 0.07326796534471214, 0.014622799135395326, 0.03521594997437205, 0.015196808617474744, 0.02294052126671886, 0.03789731839788146, 0.0561683633713983, 0.03836556905298494, 0.07142406975617632, 0.007949863647809252, 0.025763869962247554, 0.02097472606692463, 0.028867256951343734, 0.04715451970696449, 0.06920030587934889, 0.009926228885888122, 0.04760973453812767, 0.06151619789307006, 0.07340063908486627, 0.006294765325947083, 0.017723651690175757, 0.07174788363045081, 0.0014075456874707015, 0.04024886526167393, 0.06552147984621115, 0.05055591609561816, 0.06506746358354576, 0.01941593949595699, 0.07081726755131967, 0.018220465753984172, 0.03171001095324755, 0.017234819424629677, 0.021507857127289753, 0.06198299022798892, 0.03526956643327139, 0.015979988711478654, 0.019045108710997738, 0.04696435549703892, 0.001825754600304208, 0.010280757469445234, 0.019925824635720346, 0.03741654771147296, 0.07891275541624054, 0.0824233068851754, 0.04132850459427573, 0.03788676505791955, 0.011801992295659147, 0.0735608019749634, 0.012434662985469913, 0.033419277242501266, 0.04315674457757268, 0.1165884685178753, 0.03086971424636431, 0.06254577936488204, 0.042067965696332976, 0.004433372678249725, 0.030418276946875267, 0.05670912185451016, 0.021624856708513107, 0.04906476700853091, 0.01825774754252052, 0.027209161744394805, 0.03804916552326176, 0.04299977663322352, 0.02703115391341271, 0.035200461352360435, 0.1134026660292875, 0.028206292809045408, 0.02620301915158052, 0.03948609701183159, 0.031662899418734014, 0.0670592617825605, 0.01807361884857528, 0.014561173047695775, 0.03914004468242638, 0.025921177439158782, 0.04965277432347648, 0.026678257127059624, 0.11420609283959493, 0.035237023257650435, 0.013923656133556506, 0.023479084848077036, 0.14082019130000845, 0.020618693706637714, 0.0733563031826634, 0.08960958963143639, 0.0675874408625532, 0.020939316345902625, 0.07760185544611886, 0.03441493885475211, 0.05356525813112967, 0.029106035544828046, 0.030274313285190146, 0.032353074493585154, 0.04030137220979668, 0.05882616118469741, 0.043045251732110046, 0.06821082264650613, 0.03689153389132116, 0.05264214145427104, 0.03964956988056656, 0.09335730181192048, 0.01661485708609689, 0.12334895887761377, 0.042805842313100584, 0.055325049834209494, 0.017464560514781624, 0.023122095117287245, 0.03986953874118626, 0.06627018810831942, 0.009798031223908765, 0.011865240903716767, 0.04459209900232963, 0.06025801267242059, 0.048690334951970726, 0.055753384076524526, 0.04691223817644641, 0.03718347994436044, 0.028563091436808463, 0.007168017564254114, 0.05598451854893938, 0.024527242276235484, 0.051882727711927146, 0.05536934491829015, 0.038953123657847755, 0.052196058750269, 0.006708156888635131, 0.07716645224718377, 0.04247554577887058, 0.030693828957737423, 0.05402348979259841, 0.07846411230275407, 0.024671526916790754, 0.03650794744316954, 0.029637776933668647, 0.026110510443686508, 0.018374190512986388, 0.032584691361989826, 0.06263854782446288, 0.040510268227080815, 0.07285991028766148, 0.030320823680085596, 0.04766708028910216, 0.02440154472424183, 0.056366899007116444, 0.01992868561501382, 0.03282891360868234, 0.04786779412825126, 0.031609238430974074, 0.03728130614035763, 0.012477337404561695, 0.040144181621144526, 0.038763349075452425, 0.044535502820508555, 0.050737872152240016, 0.0265437224516063, 0.05515987373655662, 0.016141993983183056, 0.03145617047266569, 0.04919445360428654, 0.05837912482093088, 0.04564257193123922, 0.04557087675493676, 0.07902677898528054, 0.0500109088170575, 0.03186780639225617, 0.025998896999226417, 0.023404383973684162, 0.035427257971605286, 0.01981582350708777, 0.03324731420434546, 0.046019490182516165, 0.025356377082061954, 0.03824118510237895, 0.03155797086947132, 0.10162908685742877, 0.052160339182592, 0.03417109510337468, 0.030157094770402182, 0.049750693287933245, 0.005607702632914879, 0.039552801245008595, 0.09955082103260793, 0.05936980291153304, 0.09139506335486658, 0.07393913401756436, 0.057069627509918064, 0.047189786564558744, 0.03139500266115647, 0.03276328177889809, 0.005005001721656299, 0.028115272107243072, 0.10301751899532974, 0.11040887940907851, 0.1345464904443361, 0.10228752027614973, 0.13157922076061368, 0.1309310141368769, 0.07330583714065142, 0.10342265741201118, 0.28859249548986554, 0.14669231604784727, 0.14356077939737588, 0.15784136310685426, 0.2506330964388326, 0.41580171324312687, 0.08362534121260978, 0.10844362041098066, 0.24112823302857578, 0.14145358465611935, 0.16192106762900949, 0.13155560562154278, 0.08681178936967626, 0.12917488493258134, 0.12245327568962239, 0.14115369762293994, 0.11765912044211291, 0.1984744382207282, 0.15843622415559366, 0.16691296070348471, 0.14047975331777707, 0.15117301780264825, 0.1520268141757697, 0.18700307642575353, 0.097715890588006, 0.10637085390044376, 0.11313624985632487, 0.3066450002370402, 0.11017108045052737, 0.3786783287068829, 0.09097315240069292, 0.10809892250108533, 0.12196983327157795, 0.10537808295339346, 0.16194110561627895, 0.1840295281726867, 0.16456433048006147, 0.1051607153203804, 0.20556159230181947, 0.1105775695759803, 0.21296755818184465, 0.1314815689693205, 0.18435463338391855, 0.2065507267252542, 0.21679117722669616, 0.264844304183498, 0.14231916633434594, 0.10916702143731527, 0.08638201165013015, 0.12056798310368322, 0.16306183766573668, 0.10900901819695719, 0.12784887483576313, 0.12548945378512144, 0.14397197373909876, 0.16524015984032303, 0.15213077422231436, 0.19261718611232936, 0.19403908168897033, 0.19301355234347284, 0.26804061548318714, 0.13559793558670208, 0.15351446403656155, 0.0821845060272608, 0.08046707982430235, 0.14150666305795312, 0.20711202785605565, 0.16160136525286362, 0.08311357101774774, 0.1683921500807628, 0.09906069186399691, 0.18101964436937124, 0.13339769036974758, 0.1097385493631009, 0.1921091414988041, 0.08139437108184211, 0.14390911383088678, 0.24197110498789698, 0.11533080280059949, 0.1701785292243585, 0.1413347222842276, 0.12326770112849772, 0.07905624224804342, 0.06617439168621786, 0.181231364258565, 0.1948869408806786, 0.08538652444258332, 0.14174800948239863, 0.11270706585492007, 0.1591079420177266, 0.11617567113717087, 0.1313524055876769, 0.2518227888504043, 0.0685799446364399, 0.16112308076117188, 0.12082264365744777, 0.16648771008476615, 0.1567779842298478, 0.10094129407661967, 0.1466518541565165, 0.10379512648796663, 0.11541776766534895, 0.08566770193283446, 0.19632986892247573, 0.1196578131930437, 0.23254373663803563, 0.19757835427299142, 0.15230839984724298, 0.07607391438796185, 0.05903834491618909, 0.17304758308455348, 0.08650247706100345, 0.15460896858712658, 0.18116693099727854, 0.22929048776859418, 0.11427379897213541, 0.12211622932227328, 0.08090813076705672, 0.15779818495502695, 0.1195049678790383, 0.23435545270331204, 0.14510039443848655, 0.16889035381609574, 0.12252583546796814, 0.11942481592996046, 0.14459381927736104, 0.08277394939796068, 0.19069600326474756, 0.10974428616464138, 0.1212528592441231, 0.12116896687075496, 0.1816929949563928, 0.1555512734921649, 0.11936789320316166, 0.1040863229718525, 0.10397030302556232, 0.2335305407177657, 0.1096515919198282, 0.13412872067419812, 0.2124744455795735, 0.20882488985080272, 0.205871453799773, 0.08653322423924692, 0.12780673569068313, 0.15541580185526982, 0.1446136791491881, 0.09212723656673916, 0.10389604372903705, 0.12276769397431053, 0.18389117700280622, 0.12134654796682298, 0.09312925467384048, 0.1887957935105078, 0.10798037183121778, 0.1585044275270775, 0.11643020552583039, 0.1675137144047767, 0.12243944947840646, 0.18256371229654178, 0.1810886344173923, 0.2427850925596431, 0.17038947727996856, 0.12058145308401436, 0.14904813026078045, 0.06653924632701091, 0.10780666474602185, 0.1648703179671429, 0.11857967299874872], [0.05682688955857884, 0.01767082005244447, 0.01966645329957828, 0.013296577526489273, 0.034365979372523725, 0.03020645130163757, 0.02044201988610439, 0.021040921928943135, 0.014227877309167525, 0.048102706132340245, 0.020281454380892683, 0.029474001639755443, 0.01662409496930195, 0.05813840551127214, 0.018683295020309743, 0.03938094210752752, 0.03202721229172312, 0.017995680354943033, 0.012155056992924074, 0.0375675673421938, 0.03854217422485817, 0.07082828102284111, 0.051325786698726006, 0.02359297483053524, 0.044197736569913104, 0.05167515642824583, 0.03543185186572373, 0.022955848471610807, 0.03439917192736175, 0.015959965567162726, 0.014330968115245923, 0.015762717557663564, 0.014392204575415235, 0.03227250694180839, 0.02398202719632536, 0.007675394708712702, 0.08510573286912404, 0.013211672121542506, 0.02359370955673512, 0.015217739037325373, 0.05356793728424236, 0.04395447169372346, 0.04932563933834899, 0.02439540345221758, 0.03864272039209027, 0.06776355992769822, 0.061846030585002154, 0.032086413411889225, 0.0026937230950352387, 0.0348266601213254, 0.03952816936362069, 0.06562922484590672, 0.02654724394233199, 0.11515966354636475, 0.040165548052755184, 0.02143191872164607, 0.02275170034408802, 0.02544626229791902, 0.015566451038466766, 0.05158250300155487, 0.08679974431288429, 0.03936007291486021, 0.017782485447241925, 0.036481627175817266, 0.0942030458827503, 0.01961132471478777, 0.021593539931927808, 0.018013456647167914, 0.05094055268273223, 0.03516018499794882, 0.04048598886583932, 0.04550430610834155, 0.09632454180973582, 0.03113829377980437, 0.06830138692748733, 0.07065145691740327, 0.022590184889850207, 0.043082845222670585, 0.031882627081358805, 0.05141261797689367, 0.0836728535068687, 0.04431945621035993, 0.024284034916490782, 0.06361150342854671, 0.008337181243405212, 0.05586860250332393, 0.031247901570168324, 0.09598732474842109, 0.04202522170089651, 0.028937890856468584, 0.03651614817499649, 0.010072149962070398, 0.062388970982283354, 0.012016798591503175, 0.012496962572186021, 0.06476407361333258, 0.02494867268978851, 0.06026355280482676, 0.02078164336126065, 0.0018069224870487233, 0.018121513348887675, 0.05049955740105361, 0.08311358586070128, 0.0284699741678196, 0.023188765953818802, 0.03902410637238063, 0.041967252545873635, 0.0037527849917751155, 0.048283163050655276, 0.08623375280876644, 0.029826070931449067, 0.061507819045800716, 0.018228757398901507, 0.06325774389551952, 0.031152387164183892, 0.005344381679606158, 0.03298152885690797, 0.05212476433371194, 0.03936937944672536, 0.022692729289701674, 0.03454716730630025, 0.13831369142280892, 0.050989671726711094, 0.03138378509902395, 0.03748551920580212, 0.03220554666768294, 0.0833134759159293, 0.01981910565518774, 0.02566569124610396, 0.0244711563209421, 0.05346080826711841, 0.023765485202602576, 0.046312705308082514, 0.024665723321959376, 0.05879735843336675, 0.023816493012418505, 0.020649574471462984, 0.04732190369395539, 0.05445178692752961, 0.015480171732633607, 0.06372990566887893, 0.0109476439502032, 0.02304088560777018, 0.023304873102460988, 0.033172639305121265, 0.008466673025395721, 0.02947394041257212, 0.04353576310677454, 0.019235762738389894, 0.09287158842198551, 0.0836096893181093, 0.06505937417387031, 0.0945587943715509, 0.007646527483302634, 0.022009355998307, 0.018592675078252796, 0.06087702320655808, 0.03595555208448786, 0.00796019990957575, 0.05431481986306608, 0.027191650769964326, 0.02029496889008442, 0.04670057394832838, 0.025803073913266417, 0.005346344196368591, 0.011360781791154295, 0.03788672052905895, 0.026177916006417945, 0.06122444108768832, 0.020034753360960167, 0.03130313220026437, 0.05556352414714638, 0.0418756344151916, 0.04421800091222394, 0.014069634726183722, 0.007061001260808553, 0.03449129100772552, 0.03343501077324618, 0.021772319596493617, 0.01004286017632694, 0.01821505735279061, 0.03940479102311656, 0.06792388609028421, 0.04873957273957785, 0.01400369304974447, 0.037335523738875054, 0.0346656066540163, 0.07241003520903178, 0.029167615248297807, 0.05218256279476918, 0.014826074311713455, 0.051190923622925766, 0.028418428300938103, 0.06346279929857701, 0.04965098203683738, 0.0052615547519963, 0.033216247902601026, 0.054606357734883204, 0.08971516013843939, 0.09804127039387822, 0.058481663654674776, 0.04517788358498365, 0.015961364515533205, 0.04837147491343785, 0.03565110826457385, 0.02566219016443938, 0.05105764132167678, 0.0070164835324249, 0.01797273500415031, 0.02000012475036783, 0.043643125900416635, 0.02947036140540149, 0.03515382850309834, 0.059425003855722025, 0.06846042175311595, 0.004033814284412074, 0.0061926550824864535, 0.028095412235416006, 0.030403137134271674, 0.08337135601323098, 0.036134483889327385, 0.0361121489549987, 0.0628124775539618, 0.04144186394114513, 0.023818624831619672, 0.017605286557227373, 0.035766582732321694, 0.05913811182836071, 0.028539120066852774, 0.06994291368755512, 0.015293438100343337, 0.02514480376703432, 0.027488593332236633, 0.028246545043657534, 0.030483890222967602, 0.007423469896821189, 0.03319659212138504, 0.02619285358377965, 0.019213316481909715, 0.01474907185183838, 0.042190112071693875, 0.04921318912238348, 0.03183818356774282, 0.07707493801717646, 0.02096902080666041, 0.02803409970510984, 0.0008333938058058266, 0.013105513462505769, 0.024766304741206113, 0.027590582976699807, 0.055590371339349076, 0.0985513484920375, 0.012880476660939166, 0.04677976481616497, 0.026801461062859744, 0.01570421034557512, 0.053343842082540505, 0.04162880723015405, 0.029442419545375742, 0.03894088564265985, 0.07701383699895814, 0.0273528879188234, 0.04183428565738723, 0.020657469067373313, 0.03289664200565312, 0.027601492547546513, 0.06487265723990276, 0.06726019084453583, 0.05798350444820244, 0.05269602879707236, 0.0031534613162875758, 0.043663186152116396, 0.02530771445890423, 0.08616980936494656, 0.07469417279935442, 0.05680128917447291, 0.03323073833598755, 0.007050745707601891, 0.028055933689756785, 0.022598350369662512, 0.016625189637125004, 0.023103995990823023, 0.025041459703061264, 0.0580988861474907, 0.04622235253918916, 0.007062617287374451, 0.04863472582655959, 0.0027389006390876602, 0.012274929613340646, 0.01112298190491856, 0.036553392856149, 0.0387438120378647, 0.018823150894604623, 0.08725905950996093, 0.03720997832715511, 0.02161296008125646, 0.037449892406584695, 0.0631891397642903, 0.04599489540851209, 0.04675302523537539, 0.039292830624617636, 0.025341665859741624, 0.012327637869020691, 0.01342287621810101, 0.031776993491803296, 0.02626937086461112, 0.07129866906325333, 0.044869391349493526, 0.01708933250483824, 0.02340356575587066, 0.02980264132929733, 0.07543131097918376, 0.1257735033868812, 0.09396619687322527, 0.01560699827678036, 0.06012938363710418, 0.012467617125366814, 0.03757394981221296, 0.03763053486181889, 0.045387736972770654, 0.07753331810818054, 0.009027518663060619, 0.050592106927069835, 0.02983315473102266, 0.018404564762022346, 0.03367941484611947, 0.03856217139400542, 0.06798541013267823, 0.05344575380149763, 0.011563574571482604, 0.04057666446897201, 0.006214098048076266, 0.06116716584074311, 0.08326105802552775, 0.0719875305367168, 0.012228789364598924, 0.04433969828824047, 0.05935204331763089, 0.01583386168931611, 0.09185245638946071, 0.035810729386867024, 0.0131576716012205, 0.04478093105717562, 0.014350937453855295, 0.034522806308814324, 0.03745826383237727, 0.08844880387187004, 0.045331404253374785, 0.005995792989779147, 0.00959165015956387, 0.0254550085082883, 0.03584302765375469, 0.09394936496391892, 0.14671196811832488, 0.11094887348008342, 0.1550621388014406, 0.10737931384937838, 0.14445272216107696, 0.09586846979800612, 0.1453743953607045, 0.09292923103203066, 0.15952621644828469, 0.10221654869383201, 0.11862573068356141, 0.07529008769779466, 0.12746344786137342, 0.08843381991027854, 0.12669210409512743, 0.06453250869526528, 0.14084426657063887, 0.11275896424194798, 0.2510383981280029, 0.14026096818270162, 0.17372373898979276, 0.14607848570449278, 0.15072703157784417, 0.2189330302644521, 0.13263118540635332, 0.10239667535643093, 0.2314907032996416, 0.12027127988403663, 0.07257795354234986, 0.14289525104686618, 0.05910533858695999, 0.1281254881178029, 0.12122728483518586, 0.15152124833548442, 0.0980121930479072, 0.10422594321426004, 0.11210335840587504, 0.12636055704206228, 0.08369747796677984, 0.1624795189127326, 0.12236264461535029, 0.1587509986711666, 0.1369610827532597, 0.08542377283447422, 0.22188548668054864, 0.20478765101870522, 0.19987001724075526, 0.0745013850973919, 0.09027922205859795, 0.1299295452190563, 0.17584691959200427, 0.0908154682838358, 0.20186773035675287, 0.17874864279292524, 0.08266984834335744, 0.11249244416831061, 0.14632980659371242, 0.1766252692323178, 0.13513870944734663, 0.1535381533904001, 0.1672776075429283, 0.08958416365203448, 0.15993534761946648, 0.15023356274468824, 0.16177321696886793, 0.1016442637774162, 0.13931372057413682, 0.099845602089772, 0.13536467857193202, 0.15316013304982334, 0.20498587866313756, 0.3155191568657756, 0.15903243591310456, 0.19994028378278017, 0.1384680432965979, 0.11435494539909996, 0.1386661670403555, 0.0963277330447454, 0.09043611949891783, 0.1310855886549689, 0.10901263245614246, 0.13236555590992793, 0.12071051998645999, 0.17112392146373168, 0.09466100294957869, 0.11586348671698943, 0.19722014927538112, 0.1531880081165582, 0.07860832643928006, 0.17897538375109434, 0.11439795285696164, 0.17082973412470892, 0.12302383140195161, 0.1132864085957408, 0.18717608589213341, 0.10671486903447658, 0.23184062592918053, 0.1667623789398931, 0.17120486008934677, 0.12960268853930756, 0.11437156950705685, 0.08559019202948548, 0.22193093580426648, 0.09688314894447103, 0.07592317677335814, 0.11430182246840559, 0.13391480402788147, 0.1660101825837046, 0.2077454954269342, 0.10689789007301442, 0.07164032416767441, 0.1030559251375962, 0.16076904663350433, 0.10629226788296364, 0.1225718115165364, 0.08185390892322175, 0.18228218599688262, 0.12232132925419137, 0.12772750400472432, 0.0769882625900209, 0.22150268690893427, 0.10190496541326866, 0.1864196889800951, 0.15697503928095102, 0.11107176571385935, 0.1531208585947752, 0.09344146877992898, 0.13530327327316627, 0.09149586185230874, 0.18646887852810323, 0.10886811403906904, 0.14308209414593875, 0.11683350341627374, 0.12377617618767545, 0.1903231185860932, 0.20758271275553852, 0.12871797429397702, 0.11898418058990501, 0.20927249395754188, 0.18125350994523615, 0.07116422901162878, 0.11876865348313004, 0.1071877581125591, 0.16952916485024616, 0.13555515819462016, 0.09335365044535138, 0.1042375504039228, 0.08453857619315386, 0.1448694826103747, 0.4563905415125191, 0.14345860050525516, 0.15530198608757928, 0.04576656996505335, 0.12142893378040753, 0.2070014033233747, 0.12074304831912741, 0.20102709968341514, 0.10761382509372197, 0.11400336035876535, 0.18658129905816168, 0.1796750508947298, 0.24810798349790275, 0.1613491092575714, 0.08086806221399456, 0.11591513277380727, 0.15405394602566957, 0.1577416036161594, 0.17463196447351947, 0.1009378579328768, 0.08992686518467963, 0.15173425956163555, 0.09575733318342827, 0.14960061467718333, 0.0781967758666724, 0.128300174837932], [0.03829624874924775, 0.03177238104399294, 0.02536161664465908, 0.03412426187423989, 0.040900044186855666, 0.006071771749702748, 0.011068486001022393, 0.036486699755187146, 0.02120435397955589, 0.0675485523242969, 0.029030624064034782, 0.03524484549416229, 0.05254811876511667, 0.08743327867705375, 0.06758278759662062, 0.019004951100214384, 0.010082989028887823, 0.0034452948875696165, 0.014679273790534353, 0.03439457432250492, 0.02133518719347194, 0.04949524605763145, 0.005282998181428411, 0.012933325924677774, 0.008909827029128792, 0.015343035829573637, 0.0425456342054531, 0.08701582060893998, 0.040822786613716744, 0.03141222790873144, 0.07677023444557562, 0.017273066005145665, 0.04795653643668629, 0.09866598804364912, 0.044654817902483046, 0.007002514457781217, 0.045338643903960474, 0.049304057683912106, 0.03471931217063684, 0.006962029374335543, 0.011426866331021301, 0.027968664544459898, 0.028966433856112417, 0.04731519838969689, 0.009447926768189063, 0.013253886409074767, 0.0314174600498518, 0.007705750404056744, 0.02022975266299909, 0.027287677257845644, 0.017194986503454857, 0.06756491668056697, 0.02875248195778113, 0.02012281103816349, 0.07222975269542076, 0.06478769617388025, 0.05698438071704004, 0.05303811063640751, 0.03689659533847589, 0.0840662288828753, 0.0361569449887611, 0.047221954955602996, 0.03833655850030482, 0.020451070377021097, 0.038919912549317814, 0.05139290282386355, 0.037140001222724095, 0.02230114991107257, 0.04753285174956545, 0.04717299547337461, 0.09280026803025976, 0.021227199140412267, 0.0302955702500185, 0.026362248790974263, 0.055985271828831173, 0.05599676769634243, 0.03850081062410027, 0.05501074658241123, 0.040345429806620814, 0.05274823517538607, 0.012605024840013357, 0.017745381774147972, 0.02186852419981733, 0.01806550717446953, 0.04698209282651078, 0.05504623979504686, 0.02165841477108188, 0.02195230710640317, 0.023921312094898894, 0.025932378302968573, 0.03644515803898685, 0.06416370582883246, 0.022184217123140115, 0.028597649543371517, 0.03206736990250647, 0.022813033283455297, 0.1050220376055222, 0.05900875919905957, 0.039868050735094585, 0.02400644385488704, 0.04367069668660406, 0.02204246135079302, 0.023905971902422607, 0.016429596616944764, 0.04368927635368891, 0.020919256094202865, 0.02243365852336865, 0.013022536713833688, 0.039619152958039194, 0.06874946600873955, 0.10594245657557622, 0.04611752046912443, 0.05052170679846313, 0.03840945224510506, 0.04406362306326628, 0.06801583818742074, 0.03862693491100799, 0.04811406099179294, 0.010813468288688455, 0.020298161980463192, 0.01603002987394575, 0.04266897914931178, 0.03923470932932105, 0.03900055060512386, 0.07387194738839753, 0.04861016073846258, 0.03289841944933869, 0.05983286966511514, 0.039664104842813686, 0.012502679892349988, 0.020323385724623222, 0.027226268248341512, 0.07219309802167118, 0.07387070058030076, 0.030622413942182902, 0.023348618997260928, 0.0035222062024331535, 0.05079921436845325, 0.044015535604557954, 0.022248390632739756, 0.029635088503709994, 0.06514917404274456, 0.040940725011751056, 0.05559389654081315, 0.04190550956991501, 0.02737776841968298, 0.03469375260465313, 0.03557368370820768, 0.010878263346967287, 0.09276169861550443, 0.057695057621458545, 0.023412156115227845, 0.01729048050037818, 0.03450742529821582, 0.0727336858108174, 0.00826761417556554, 0.02613920187286567, 0.07521626626839861, 0.016920540292630903, 0.04511798484600149, 0.0184360911953263, 0.07853575923945755, 0.013064538561593508, 0.04879990934568923, 0.016796154486655723, 0.05572117486735806, 0.042149245709879324, 0.04269588942406699, 0.0555393969261786, 0.04079318976437207, 0.04793857646291144, 0.024655264605826233, 0.03715930819453206, 0.04989396489690989, 0.027481765573611483, 0.018175346885982435, 0.0703800683550071, 0.025045949696504977, 0.04651699258829467, 0.0328656833153218, 0.0934732920723036, 0.03395741594431456, 0.030267244328570087, 0.057115406889352016, 0.013731004801229574, 0.008877221698639914, 0.004557285365081043, 0.05419138215074781, 0.07778033454087563, 0.048387052593170665, 0.047880147176329046, 0.0627816042106133, 0.05456236322061159, 0.01973365662706783, 0.04076025325048249, 0.04079898964846507, 0.015864486413192935, 0.04716503593954258, 0.01870025309472112, 0.03303294113720767, 0.022734215344826225, 0.020125983719481155, 0.0555021262698574, 0.06315647784504108, 0.05426737065135967, 0.016016021836549044, 0.014275769026426133, 0.02687982629140606, 0.033887186509673484, 0.071995278558461, 0.062032947898842394, 0.01757534275384387, 0.007962814124766737, 0.04561469686450437, 0.009687296296760906, 0.027602065856626723, 0.009694062828202732, 0.04353670563432388, 0.035093128244625404, 0.0093557390391652, 0.015345892170444131, 0.019248614880780224, 0.02541494552133372, 0.020783530271728523, 0.06137167205451988, 0.07431969992467202, 0.029318178458197508, 0.04922827698464971, 0.043920058305957355, 0.036544364629662596, 0.04356882949650753, 0.029765417057205923, 0.014881474708090536, 0.007744244212517515, 0.018138922278012615, 0.15398192801512778, 0.01850251526775537, 0.06710705609293655, 0.027548221187316813, 0.0487465563492151, 0.06667218724032864, 0.015968144034559373, 0.019527152180671692, 0.06360149927786551, 0.04871011318755336, 0.024140932146110572, 0.03684120143589098, 0.04600136693625245, 0.04544942428765353, 0.03448758398008067, 0.059674565854948014, 0.0439492395526031, 0.026078958035213873, 0.06998429584200494, 0.04336059027991723, 0.01862972494564019, 0.028334624985291157, 0.03486137036816217, 0.02032239681284409, 0.03968341181462165, 0.030085284561209846, 0.0807822031492833, 0.04835965621168725, 0.04921933410514612, 0.012020118774671573, 0.05256318807369098, 0.029087326001899783, 0.09069928506505676, 0.04511465260293335, 0.003709770344357821, 0.060869523804285564, 0.05588065869233105, 0.02393449263763614, 0.05317788301908877, 0.031150234935921617, 0.03313659690320492, 0.0686360732652247, 0.014685826026834548, 0.041309119696961716, 0.04708738502813503, 0.019923850522900466, 0.025753001209523063, 0.04984025938028935, 0.04472906977753155, 0.07619375639478676, 0.04865103823249228, 0.06913018776685931, 0.023618144768988714, 0.013187786098569632, 0.04205708210065495, 0.05601628989097662, 0.03276026123785414, 0.03820399608230218, 0.010600027544569457, 0.030604092171415687, 0.07343203193158843, 0.031158380006672814, 0.04199040384264663, 0.027195929251320194, 0.03035920384718338, 0.062093047017697245, 0.03598233619413804, 0.06692171955364756, 0.008473021171084838, 0.01756639245286351, 0.027630460426735226, 0.027426199121691752, 0.004689697498179157, 0.020721059991046786, 0.0337142883654451, 0.02829526703862939, 0.020603279299393762, 0.04068046124302782, 0.026999443798558787, 0.0449479217058979, 0.028260538238100708, 0.017044276719389018, 0.025142312006209977, 0.06702891536406241, 0.06799933282309212, 0.03197324331267737, 0.048382451277575456, 0.027170382672920823, 0.02998937310621841, 0.0972636257938575, 0.07801506100804545, 0.02950783058622619, 0.058357149828225374, 0.015696666414442006, 0.0061158743392297765, 0.01745928941090824, 0.03734281905053649, 0.03612774147768505, 0.07215914476546459, 0.03812663460848853, 0.04494231478020083, 0.039076843386283144, 0.060464856651378796, 0.09825858607655391, 0.025439367746002972, 0.008616513568995288, 0.02588217943412019, 0.03315857560664881, 0.04035734498756938, 0.024134499581123237, 0.03790941169427242, 0.02389122728345683, 0.024301720295625273, 0.030293312265712302, 0.01565397065860452, 0.006179118772706715, 0.06790894665755332, 0.17905938002513722, 0.1586521594435908, 0.12591347243869677, 0.10404066604678519, 0.22934089443879202, 0.08752169072977267, 0.08938969869632274, 0.10187052233959548, 0.10296098218532279, 0.14413241122383624, 0.1201359047263395, 0.1856545198825188, 0.20025646837893873, 0.22207081579836085, 0.15940646349918097, 0.19922831183066592, 0.16463156905956566, 0.16754537442466244, 0.11878015677211806, 0.1146435369446408, 0.1224540475232061, 0.15733370441012084, 0.13624597893794999, 0.0809422621387057, 0.1907450592261739, 0.11242457476328127, 0.1750494967564009, 0.14779667631955817, 0.11601976817473769, 0.12581354967551306, 0.11040925048291683, 0.08296387240989134, 0.13392651511821896, 0.23264915129402652, 0.12491943984059617, 0.09160438610706478, 0.14272838656324893, 0.12289941776543856, 0.11806814771261998, 0.10298951034201309, 0.15789160650456324, 0.11738596556824632, 0.09658872411819175, 0.13614893570775166, 0.06732255351380445, 0.09120432398049161, 0.0783439066435676, 0.17540627683047205, 0.19385526655241847, 0.10564762356807478, 0.0942454522009939, 0.22604526893701404, 0.1519529111101292, 0.1281870566890575, 0.16086499148514122, 0.08723070946871303, 0.10305951713235117, 0.13664789643371478, 0.1493649382609874, 0.23364264954579994, 0.13530457945307717, 0.19279298605397344, 0.23017358413198963, 0.12668728013522923, 0.1382832188392058, 0.09217210681526922, 0.1023730676388368, 0.11941947988816537, 0.23576875420985743, 0.12999889149796218, 0.1078828313620761, 0.13082898367429152, 0.08904339032596909, 0.11067522136727348, 0.13342773250769824, 0.157905692467466, 0.13235617516329512, 0.1444005491794087, 0.08347844050149433, 0.11914731207070872, 0.05941729665210005, 0.09942180608049966, 0.12275180459255353, 0.18004559038672596, 0.11304486921289936, 0.1336570709827356, 0.15655130264349282, 0.12003727330011316, 0.1298953322111629, 0.13725228665862232, 0.12713673961116, 0.15147867874475196, 0.11497524727019481, 0.1375381025718525, 0.12280002192710526, 0.14375508850207552, 0.17072765913326293, 0.12996070057852194, 0.1724031614139676, 0.11970660940278322, 0.08070520532783121, 0.06114781434007455, 0.12064129245118238, 0.11203326255781576, 0.21857932268176228, 0.11944618978304788, 0.16747777961427346, 0.13100260170176625, 0.20655158761655912, 0.12220031465403736, 0.24414714134763926, 0.13271043193526566, 0.09747654054081067, 0.0816725725599099, 0.12329985838732682, 0.15931776200886816, 0.15147548750974238, 0.06639414161327295, 0.13775518076727167, 0.16082782472949475, 0.1335428692982532, 0.189368033898063, 0.12643598893191665, 0.16942523448960856, 0.27249798411503434, 0.11629491200437769, 0.18716600752668455, 0.14423855318455026, 0.15503531758440658, 0.10906926574534737, 0.2561438991688192, 0.08795057045063004, 0.1528143516043201, 0.10434718788019381, 0.08294308485346846, 0.1119860693870578, 0.13252850185381249, 0.29355396050959826, 0.1693054221686907, 0.11857945035444573, 0.07676645691390149, 0.15224390721414238, 0.2759033435722813, 0.16965473623713478, 0.13506436109310016, 0.10180376615608111, 0.08906356932129711, 0.13440981652820483, 0.18256375682540238, 0.1707515711314045, 0.11496746214106679, 0.13505186332622543, 0.06748938831151463, 0.11219535503187217, 0.18631332437507808, 0.08327578965690918, 0.0846932694548741, 0.1837373001035303, 0.09658695780672133, 0.15893367090029642, 0.12390140618663281, 0.11489742566482164, 0.16217773198150098, 0.13035010546445847, 0.10663565219147131, 0.18052524043014273, 0.19452316977549344, 0.19795285683358088, 0.16510158602613956, 0.12215959301101975, 0.09624401878681965, 0.16511053632711992, 0.12412171272444539, 0.1948660716880113, 0.07939046845422126, 0.13374581700190902], [0.008867357628332684, 0.006903647863509832, 0.05624504206934944, 0.016197820186789613, 0.031011353130452335, 0.021652913601428736, 0.012313959159655496, 0.07295877920114435, 0.08954028788139112, 0.04429578912095167, 0.042995869225705974, 0.037654595289495774, 0.08004669769434258, 0.006543540648635826, 0.02811719612509478, 0.06653561722487211, 0.055956135111046024, 0.0449862091045361, 0.03484599306830205, 0.06024231253832113, 0.049473497419967316, 0.006328521913019358, 0.013044725073996233, 0.08501058211550117, 0.023126572123146616, 0.06862425827421248, 0.008236822468461469, 0.07119752917787991, 0.0642207547207363, 0.041235101598431356, 0.0494220443215454, 0.05984667361190077, 0.02467675720254192, 0.06866037860163487, 0.030226789858716074, 0.06835819091065787, 0.05412473728938494, 0.03391099089640193, 0.012746447573590558, 0.044388854439603165, 0.010816844132932601, 0.06578304979484528, 0.05336390604497865, 0.05525690212380141, 0.021388673776527867, 0.08059537489316426, 0.00805685443992843, 0.04905212081212085, 0.03711764402396511, 0.010363416022300953, 0.015699330724601168, 0.0387190243054647, 0.015936591626086738, 0.015394539022963727, 0.03317869151942432, 0.03191844683897216, 0.016772101480455603, 0.01976050753000891, 0.046770291301072575, 0.03751225507585332, 0.024535962511436082, 0.053273657176760025, 0.060338071853038855, 0.04854312624956947, 0.06405196065315977, 0.008912382800190244, 0.014760192934772931, 0.07075384361087345, 0.013786220588372089, 0.04100256446690764, 0.015745043310744222, 0.026412674014864024, 0.015312657869799295, 0.013469074910972267, 0.06651059200521559, 0.027860858317581005, 0.0693460636830423, 0.058631959691410884, 0.04399065510369837, 0.037484754793695174, 0.1012833128334023, 0.02016830098000355, 0.0379195308778435, 0.01728085113427369, 0.010359369462094037, 0.15356543473899364, 0.06550936057465151, 0.052010132203577086, 0.03392200807866175, 0.020423197165655438, 0.01746815807564417, 0.04599530358973425, 0.02187068384955637, 0.03919034745194949, 0.023299696622416377, 0.024830203656165395, 0.022460670843429398, 0.050523710597190075, 0.061418100813170895, 0.06085637665819377, 0.03752253753191326, 0.02202095762186218, 0.07653127031517215, 0.04394424118800089, 0.045111665458534844, 0.03388388024177402, 0.06428230844903737, 0.020990500415791757, 0.05178955849260092, 0.03969795048760716, 0.019709675980266184, 0.0160021325427806, 0.04505086501012556, 0.006365439121509553, 0.022927225691091735, 0.06167077612190042, 0.014717751364514697, 0.06707179665681906, 0.022230875947570894, 0.027383497799746692, 0.08075397185166366, 0.030309060639410745, 0.0281997878846596, 0.025886053444992285, 0.03101103586232057, 0.06285823095822707, 0.02413413592876168, 0.05129267206939403, 0.037609417049679905, 0.016909103796933778, 0.01334483660684782, 0.01219485558976885, 0.050762774917529896, 0.028981846407987177, 0.010383435455878498, 0.04304262081859633, 0.024477715051034465, 0.07126063399482518, 0.0711473822593689, 0.02362293718761066, 0.03193952012225054, 0.02079382200463442, 0.025901226654241327, 0.010121667910425458, 0.035748040172620676, 0.029960609317640774, 0.011777859508583788, 0.04498355963733047, 0.021135174683877267, 0.028158964196336456, 0.08931459335144609, 0.08869276265613735, 0.050968086361535825, 0.03911537569365464, 0.04945473963744007, 0.03360649512615055, 0.04660027268982958, 0.029494006230379455, 0.012433307638275437, 0.023759412579238415, 0.047126922945608385, 0.04704776918515563, 0.027245894343650434, 0.041132106343866326, 0.06801612762501463, 0.05900285912503023, 0.027019203480449505, 0.033095040344051085, 0.028237058540980797, 0.04064511645992752, 0.03563747501175385, 0.03219553880626336, 0.020414565988176037, 0.05269756504276302, 0.04123940605495591, 0.06130970272351988, 0.03541890509950463, 0.04465528174478095, 0.04434169466549065, 0.00978536832917598, 0.009984955031541176, 0.058914101973641664, 0.02774381049675867, 0.0705214920162689, 0.07337219998589717, 0.049998707909253426, 0.05244174302788451, 0.03406340576475486, 0.05998652020934969, 0.010263729818689171, 0.016951092657109257, 0.005557236127060605, 0.09012950118631124, 0.0547037609067047, 0.061279196743271314, 0.03404649221920408, 0.0260193728536251, 0.014636898085882422, 0.01671326215728186, 0.0759913727233652, 0.027924339774472173, 0.06891326542245224, 0.05809644077089615, 0.033774725161492825, 0.09049172862432897, 0.014364172729983693, 0.0333912500354927, 0.04209061975416262, 0.012988668804609915, 0.05602199329587165, 0.04552888603939209, 0.03730565600562841, 0.01740902374876896, 0.06022872381436173, 0.05670036451192573, 0.004654654676414793, 0.08358236344065517, 0.024936076588346623, 0.07318353120354004, 0.044175958246341906, 0.012225098107592203, 0.023816971697669942, 0.007837240882508922, 0.042019915345008485, 0.014559521769115236, 0.018325498203921597, 0.021845816336281132, 0.016206844702537637, 0.02115146297001047, 0.013475815467245411, 0.024147281219484285, 0.02866329250537092, 0.02821130045049358, 0.05056180132669397, 0.055185700475703925, 0.04431734480021987, 0.034092282730853185, 0.0387829195096856, 0.013705767141800607, 0.014437853151321178, 0.03457998507656157, 0.014555426969309337, 0.05647297788527794, 0.041374402717337944, 0.016927247452258598, 0.06615347796468996, 0.044201603159308434, 0.02406944848189596, 0.026204505302303005, 0.047070141226868145, 0.034959526819875464, 0.03719194784935098, 0.03411818739550654, 0.020351312741695438, 0.04649887305276934, 0.0404475047980668, 0.0712464218668174, 0.02917986439570086, 0.028403422074916307, 0.06833920677308924, 0.02337608217203524, 0.04193860564555507, 0.02518073670216836, 0.06741766716004349, 0.029989313734404277, 0.05380546164815314, 0.029789577674819157, 0.05929366598138586, 0.015524797072430374, 0.056794197953422554, 0.011272533010924235, 0.03767416943446733, 0.036410510874702595, 0.03407691285246983, 0.026071859392686747, 0.1173695937904995, 0.03387125259905588, 0.05245149113761727, 0.04823768795176875, 0.05778085360361729, 0.043049519081250764, 0.0243159676756477, 0.04019143416371662, 0.007056957947497722, 0.03427897368965205, 0.08079195496975444, 0.024968144789454527, 0.026718127155618276, 0.05591823733993806, 0.041138600136036985, 0.07375904446234927, 0.02852424371667439, 0.0675364924245514, 0.015262882952811196, 0.01528232722193934, 0.019996781375084538, 0.03608717939641792, 0.06088885304052383, 0.042143464379478246, 0.02468738290190231, 0.04602393935783766, 0.07396024811896496, 0.03580583492293954, 0.07568960805656388, 0.02939248784969095, 0.054320760755217634, 0.03427195668336935, 0.05693707993486896, 0.009242953001376009, 0.004079421114511206, 0.05146831987076439, 0.05442127352580428, 0.029736577198491432, 0.02280423512274865, 0.034532331774244085, 0.03049900034966413, 0.033807787840487435, 0.040917440128396265, 0.0015834544001336326, 0.0557481222494971, 0.03733736797585152, 0.04654818505514413, 0.02151538250473095, 0.07516145124100149, 0.0557010700867977, 0.027852930325025227, 0.03304903832031414, 0.020157897924946155, 0.029163271829020232, 0.002656045649018779, 0.04807991106645204, 0.04167629354924429, 0.00843022429762641, 0.03241086182242725, 0.025168695356114767, 0.008212834400183056, 0.04460742806259077, 0.07176018843892962, 0.06142568927316461, 0.05418679938884452, 0.08844846990541555, 0.07716865642578341, 0.011373515189916361, 0.042659457394620404, 0.07284323422936723, 0.036526092953863554, 0.0162927909696009, 0.05209121554798912, 0.05800791368528735, 0.037802312363055535, 0.02121646211890038, 0.042753814050229266, 0.11263999054790474, 0.09744209004566073, 0.10079841580591165, 0.11993058215011843, 0.08954061442636885, 0.11768375232350081, 0.12847248668549582, 0.2110913346405141, 0.17750885541317984, 0.19026916445000097, 0.10008912300691009, 0.15920554928015918, 0.11534303339431062, 0.07887263491284102, 0.11504258232889697, 0.07149035096517764, 0.16779200494056568, 0.14259784278692678, 0.12353954240097664, 0.14343384245876223, 0.19370844005607069, 0.08468781466945074, 0.10683172760764137, 0.2133087976835668, 0.12312923121498898, 0.1485785882687196, 0.11986151788732968, 0.1477877705474384, 0.1669495040550828, 0.12865670258179307, 0.09578650700859725, 0.138843510649167, 0.22622814896749333, 0.2936992433387786, 0.09343924233689904, 0.09757053354405798, 0.16532412642845884, 0.1833032030845061, 0.14387395087396726, 0.14325075462693349, 0.18346034543355927, 0.11460207315394655, 0.16488749126438051, 0.11407903715735301, 0.0793124019401148, 0.1450505666434765, 0.1375181833282113, 0.16109787742607296, 0.12582114926772192, 0.0716293032746762, 0.13772758771665394, 0.08537715853890404, 0.14288777019828558, 0.09292054048273712, 0.16603120020590723, 0.13885157037293538, 0.10964943227008916, 0.15669094515033066, 0.18796314834617078, 0.1441943211830221, 0.15142787131480873, 0.09179070228128694, 0.1428214815678075, 0.11233338707825169, 0.15840100182686, 0.20946644683135673, 0.18431822361890227, 0.19887985865352675, 0.13763569499133155, 0.15846218448132277, 0.12500064563937485, 0.17373438138747588, 0.13735703338170424, 0.12350675431662239, 0.1423971215263009, 0.1660534497932531, 0.1994156595901586, 0.14322526927571744, 0.0942203305021394, 0.21377258060965687, 0.2552785846637562, 0.06504652017611079, 0.11883318322361447, 0.12180692443507724, 0.1045941820484586, 0.26961405761539936, 0.12386463276925497, 0.22434285638155416, 0.15817503270227462, 0.07422234499244951, 0.15380001277662814, 0.2131295541767031, 0.16809486056445166, 0.135325686133001, 0.17054048948921263, 0.20634988672100008, 0.10441384016303346, 0.11302196653559804, 0.12231261644046754, 0.17631871771300212, 0.12085754686268046, 0.2114755444927141, 0.119745831907494, 0.16150205105077475, 0.12924935203045607, 0.20307582803070545, 0.15238230291288346, 0.09160925459582359, 0.15156132431002334, 0.20119976776186377, 0.09623325022403151, 0.0897456104576122, 0.12527668004622683, 0.08689363341545686, 0.27701214188709855, 0.10905162489507347, 0.10698501821025275, 0.10671710289898328, 0.11585998377995566, 0.13137248810380697, 0.15464741183677688, 0.11968577731749974, 0.1379514194559306, 0.12686153640970588, 0.16179009340703487, 0.1619428867707029, 0.1635885250288993, 0.1603013600106351, 0.15726475889096037, 0.14660316926892847, 0.11271183786448091, 0.11074061199906282, 0.10818280003149994, 0.12191563422675245, 0.1474587171105668, 0.16572929453104734, 0.20028492232086137, 0.17451572930440307, 0.15810816519660875, 0.13294630130985752, 0.10927155293757096, 0.11062887424486689, 0.13145431730663404, 0.17812238889746368, 0.17858145176433027, 0.12627688731299713, 0.109653187537333, 0.16569622443057597, 0.20083354756934568, 0.07816392098902725, 0.16422764776507393, 0.19963650789577514, 0.167420337384101, 0.17111129011027515, 0.1777393219526857, 0.13033753348281607, 0.2406899948255159, 0.07552741910330951, 0.11243859393289313, 0.12719116872176528, 0.18456096528097987, 0.15827189781703055, 0.2253671092330478, 0.12792015069862828, 0.22692572325468063, 0.2131021095556207, 0.15077372750965878, 0.1263782795285806, 0.1054387386830058, 0.1817735773511231, 0.17000405030557886, 0.13918654614826664, 0.16980660933768377, 0.1608729176223278, 0.10887460040976293, 0.10856700246222317], [0.009040135173563613, 0.04553079335892107, 0.06926204514456913, 0.01717379447654821, 0.02529556179069914, 0.12035313877277076, 0.06133108399808407, 0.05838400815264322, 0.05889522915822454, 0.014399003575817915, 0.03822527716693003, 0.017838486055552494, 0.030336542367876973, 0.013968847360956715, 0.023357654645224102, 0.0028549530543386936, 0.040049676536000334, 0.027700842001650017, 0.049923494952963665, 0.01442822749595507, 0.03204429282050114, 0.019333021191414446, 0.02418031421257183, 0.011101092259195866, 0.07002161102718674, 0.06218699178134557, 0.03374256790266372, 0.015296140445570927, 0.030662604949611705, 0.04320774496591184, 0.015584871143801138, 0.06917686143424362, 0.05646463614539243, 0.06055492740415502, 0.045423129995469935, 0.06279533394263126, 0.02604374869406456, 0.03321175048768055, 0.03847456828225404, 0.044787153965444304, 0.044063378154532984, 0.050906989054055884, 0.04357046964287292, 0.015343026552727679, 0.10605278424918652, 0.06299278975347988, 0.04335316509241238, 0.044325831258902326, 0.05167603958398104, 0.011320484099996975, 0.029905078117735684, 0.03681108508317266, 0.020106943920836784, 0.028481303052103613, 0.04418518685270101, 0.05334649154974613, 0.06918481725733727, 0.07302239609998651, 0.039316824259003624, 0.029486892744898796, 0.018886971884057857, 0.0023491295496569364, 0.042295942330383696, 0.05748404648329597, 0.05519341881154105, 0.04980778299795929, 0.022244002684601583, 0.04585568705806509, 0.0184518488458707, 0.016362027781724464, 0.02712392422836274, 0.02527554977859836, 0.018618370086187497, 0.006843763039796613, 0.00615361301242956, 0.0732916546985507, 0.033057168548111804, 0.038963532279012725, 0.027234869739913847, 0.04188862942100968, 0.055246315387194045, 0.05826431457535364, 0.020381367867230438, 0.06056858292140532, 0.0329898223571945, 0.04331421347160358, 0.021722293276980054, 0.026702200666477438, 0.07461568326107226, 0.040640897350385785, 0.033122477543656714, 0.041931759333238006, 0.012670834785240004, 0.018410876728012227, 0.017854379148047883, 0.0218966163447476, 0.05685248994268477, 0.12194469672976993, 0.043255004929960705, 0.02139837364666164, 0.013851621424691984, 0.025399757469131146, 0.011330379711580463, 0.07620750096975826, 0.0632336240960285, 0.01830553257605061, 0.05487922688189428, 0.0014476462456514128, 0.08166837942553684, 0.03563944541383535, 0.027864107069035526, 0.024717887026781682, 0.10523493750952184, 0.05272819347737823, 0.04057694648508914, 0.052661530062323436, 0.03402482521778438, 0.06830549100413918, 0.029152475435694214, 0.03620233845140319, 0.0323866381222615, 0.018048127931251656, 0.04765300174767617, 0.0241345960603212, 0.04688113105657976, 0.033603348420001566, 0.1000390354602132, 0.04052552307257429, 0.03872023771691602, 0.0215891148764058, 0.02209068425145233, 0.0077917982525832485, 0.050499635326559655, 0.03364562857314013, 0.022562833037227392, 0.015205286726995837, 0.016970876458799466, 0.08643023640615866, 0.03762735104828607, 0.08724699961021543, 0.007006485875535873, 0.0557226257660659, 0.020390885911183432, 0.021901961663388647, 0.10018821456469595, 0.018361266011197586, 0.09216250342433341, 0.04153488844167441, 0.06824486496043392, 0.035878494891221635, 0.05528859925107099, 0.040856123887351714, 0.05488244038133416, 0.02683546998014208, 0.04688146502303425, 0.010092434713442344, 0.0963523203972727, 0.027702931147359777, 0.01694781236437848, 0.04258138345903717, 0.01549641827296, 0.02923772593931062, 0.0553973313071765, 0.038954548581386916, 0.010338107858842704, 0.05281878744426649, 0.05202146479859948, 0.009077963368326891, 0.07482149565475993, 0.016728487316868268, 0.07027593019302003, 0.0023903359078758513, 0.01745205903716851, 0.10030925142928027, 0.04318722458265256, 0.061782432239851914, 0.015085303712112363, 0.09299022072809748, 0.03728611896804068, 0.0257103666808689, 0.026572822062007617, 0.015450457067345269, 0.06932995907845907, 0.029467186868714634, 0.023256891399796586, 0.0414132541482104, 0.07041560238576494, 0.03874048350553494, 0.02086757478537038, 0.06551645550644025, 0.035143564600730315, 0.011172501708642812, 0.062182112160371616, 0.06667649169685319, 0.014607191769755445, 0.022433209524024278, 0.02400638819381129, 0.015920238402031828, 0.03595328853407409, 0.04901273132418282, 0.019044121654587798, 0.00946771335293306, 0.036200561007717624, 0.02647527046065079, 0.02447472419589758, 0.05620245392492507, 0.06069361996196676, 0.04159567404713016, 0.04312243137974292, 0.031832717650104314, 0.04004881193395704, 0.04195272871584166, 0.030673212095280178, 0.03487247660814319, 0.05562579033721704, 0.03958246859838255, 0.0722924419096671, 0.0368541890202323, 0.061800666808267124, 0.03969796533056069, 0.03108783144853078, 0.012429095022525871, 0.038583971982006915, 0.019758917478611693, 0.012481351495807758, 0.04213400941807777, 0.023120870573620778, 0.014832733231742168, 0.03273659785918426, 0.08513129243510775, 0.02724771260545822, 0.006508885135190212, 0.04295760780223645, 0.05398892426455859, 0.041016234827111475, 0.05331882057362236, 0.034564292363938875, 0.05235414362687152, 0.01560843433253467, 0.060953505235374905, 0.01608101541933138, 0.019339461177878547, 0.026913170986517798, 0.027762128556787502, 0.02552146412199363, 0.0492496805236442, 0.08774137386353686, 0.03700625507917721, 0.030496679282805417, 0.02860176289686933, 0.03795550648646895, 0.027417914898251183, 0.05718911699659657, 0.006906621092639398, 0.07151355050154962, 0.07138395667425357, 0.02458600738464156, 0.011399606319173472, 0.04281646615709178, 0.007844251394999446, 0.027440799021860585, 0.03139748143439647, 0.05023812103900127, 0.04084977110323962, 0.07515374032664113, 0.04989679990103468, 0.005494431879924377, 0.007799124177836347, 0.009208467254211428, 0.019786722041317262, 0.015508421583945164, 0.010487570834811777, 0.015298994003387634, 0.07563537932583131, 0.006056274314687471, 0.0286240124842152, 0.045819180813850835, 0.03121788911812473, 0.02753129094344331, 0.01620447354071075, 0.05198023107368499, 0.06901336630107835, 0.06931477473699488, 0.023909318988444284, 0.03255288291256875, 0.04442646648385562, 0.04207912759738974, 0.01804140592867043, 0.05576229727012105, 0.02199919970735209, 0.040804600284900516, 0.03648851801699493, 0.03365140248206444, 0.04104886706045363, 0.010146239492314635, 0.04094964562682435, 0.03601199983677361, 0.03606991333072074, 0.02653520816238597, 0.03984503673564177, 0.035305979909026064, 0.05072868807474151, 0.033251318091060966, 0.05770531039161142, 0.00918857027500053, 0.050523354366305284, 0.06760247677448206, 0.03305332793388516, 0.06329908152110875, 0.05402828777732793, 0.06390215814462863, 0.012969664257980185, 0.052783895371248946, 0.02497919722372899, 0.037952667771605775, 0.098059645970352, 0.013280586099426728, 0.016717705766495783, 0.011275522938376525, 0.02782582894724328, 0.08253179403254762, 0.029278885449457448, 0.03197942169208545, 0.019920419945265166, 0.052848914929199964, 0.014041553713468602, 0.025243052987207193, 0.02471780539053725, 0.05526161476154812, 0.0656371955119539, 0.05756320766522549, 0.003085142679992714, 0.05083844800537918, 0.005867612026122515, 0.015497191961912904, 0.02987059051520191, 0.024425465999229345, 0.06515105909784324, 0.06362651707604527, 0.0709527762955986, 0.021669587804353796, 0.026771960692713037, 0.05045312122092582, 0.04375818476546556, 0.0031461722664971603, 0.011239127088629175, 0.030364291269506793, 0.017973169160541147, 0.06271154546993785, 0.052173271105857566, 0.04007797462691087, 0.052357683671289124, 0.10250235718558542, 0.15850644616875798, 0.181221671809908, 0.08486610080581158, 0.12520660646259785, 0.18820943747414276, 0.13937056908616796, 0.14522734622005373, 0.10888169534155168, 0.18017227499512956, 0.14765342697501183, 0.0882334919879213, 0.14666450035292655, 0.14371409226441756, 0.21249570068903267, 0.12810466345399618, 0.19560505781555548, 0.18059534369967878, 0.12881714006653056, 0.15130733168916777, 0.11636521565378644, 0.12276708541321568, 0.165571172547061, 0.1378085560281761, 0.1419165957486257, 0.10102754647959955, 0.22232427407288924, 0.15089589986018836, 0.07113349667633884, 0.11917101626750082, 0.1400061888853088, 0.10041918576462194, 0.1885771716479212, 0.17675331939244643, 0.1236861982033588, 0.1167990306566935, 0.0969564360275399, 0.1125290765776299, 0.11829105176730081, 0.14750122732948512, 0.16267152735963464, 0.13193088001571596, 0.08935023870435543, 0.17892246862174943, 0.28481395449489355, 0.1272713948856108, 0.10479806485818699, 0.08954360528150573, 0.13329969719052315, 0.1108891676994972, 0.15817679901374504, 0.17255944287171587, 0.1150849366968032, 0.22209640505025163, 0.10193731563049369, 0.2830101200379431, 0.15179651090875268, 0.1584165869280696, 0.13080078206257895, 0.12787447893060744, 0.13396837224718183, 0.164896278292872, 0.0953598388878163, 0.12679158156970516, 0.12680623156484216, 0.09766584014869295, 0.11841992571135052, 0.1280871339258738, 0.0895721631241031, 0.1271887493203394, 0.11081402524723671, 0.17205263022333384, 0.08239066723035648, 0.07508926253649406, 0.07820829399861395, 0.20486136112594977, 0.12714252836303785, 0.16134750621858984, 0.09361733551486395, 0.1554904322256334, 0.2507807838264853, 0.23548727243905887, 0.12153647840023041, 0.1325408511911519, 0.13121383177349344, 0.10481831806828268, 0.13415865891147405, 0.13558493315940723, 0.14069248252781108, 0.2462166646728292, 0.1594356299028732, 0.10727869346737862, 0.0949592943652533, 0.20143385598203167, 0.1739742435165681, 0.17346716369502246, 0.21445026533911005, 0.16956178966211155, 0.12259164912393317, 0.15283302403986454, 0.11953762979828753, 0.10339464133721776, 0.15819403168279678, 0.3357634611893445, 0.11451685233623721, 0.17005420464556664, 0.13596900942502543, 0.09857208409812301, 0.14559579285560176, 0.12367646864731796, 0.1647301114280708, 0.10549742772127502, 0.19942892919061705, 0.16077505802968517, 0.1213434457895346, 0.1686740474542603, 0.17520435329061002, 0.13837905979016796, 0.0876097465516068, 0.0840956847241614, 0.15044736064737663, 0.2096210658783093, 0.13817364815622568, 0.19034213240956888, 0.17888767673866823, 0.12956329534063116, 0.25351755728479475, 0.12511876586358994, 0.09953782602678984, 0.1309484991361387, 0.162732531898655, 0.06235471344552934, 0.230576436733827, 0.1539859949843958, 0.13519325730158016, 0.10388349401182495, 0.31466093729250133, 0.2489876511390321, 0.12549999228212982, 0.15727290767244995, 0.0706068983708974, 0.09524856868665665, 0.07733578808256425, 0.1218146353494376, 0.1972081561689265, 0.06628903865930624, 0.09936387403286062, 0.14785768085857853, 0.1657895717653446, 0.09460577231948264, 0.16356793785234913, 0.13317807402927428, 0.1467991407844238, 0.14267652528360486, 0.21138455718755722, 0.1579144349670969, 0.21898974518990144, 0.12338895321590826, 0.08497599061229266, 0.17839909123722464, 0.15082716214237735, 0.14251372776925564, 0.1300399174215272, 0.1878784692962654, 0.1980410685064271, 0.1377692518872209, 0.09427945740753785, 0.15385887993033975, 0.15512986719841138, 0.12698486651061103, 0.1371838606428355, 0.10818930866662413, 0.12253429595148191, 0.20949634053977206, 0.0945405598031357, 0.2123481172020547], [0.08963131229393184, 0.016622399161860812, 0.06534815867780708, 0.02842450649040984, 0.04512736930337269, 0.026809520786628127, 0.010727740027505206, 0.008353507564606844, 0.023845787436584942, 0.0655619046301581, 0.032615939489915036, 0.06795481138397008, 0.011699536025844282, 0.05991073208861053, 0.018078160792356357, 0.03970150166423991, 0.0682997319381684, 0.02425203721941216, 0.041746148199308664, 0.04016256832983345, 0.0491333340323763, 0.04737843308248557, 0.06978656543651596, 0.02158747101930203, 0.018744301414699294, 0.034078671742463484, 0.033907684628502466, 0.06783573378925212, 0.018925491203845013, 0.012169730180175975, 0.009501936565357028, 0.026446703341207467, 0.033165054555865936, 0.0625634053722024, 0.04747319420857821, 0.03980564353696536, 0.0012453633439690748, 0.04144317012105603, 0.036107414052821696, 0.05194279714487493, 0.04389967522001825, 0.017853714925877284, 0.029562220734078437, 0.04544995121250395, 0.035272449676995166, 0.12656108534429222, 0.013678870782314334, 0.0350332629022887, 0.02741107044130331, 0.018448893242748454, 0.040615029793116264, 0.06284575545578264, 0.02946431290183682, 0.015813591780897696, 0.0433252306538634, 0.008287435084639583, 0.04323088513046969, 0.0476016488391906, 0.009046327468240634, 0.028291059061302803, 0.06693816554616205, 0.04890805881586857, 0.020229049478075467, 0.012668423732975498, 0.023839308487367816, 0.06440454017138109, 0.05794258613605052, 0.011829135419247905, 0.02023994420596864, 0.04186098070931621, 0.01005670586891938, 0.024144145645550452, 0.04296394203265663, 0.03251930444093887, 0.047925050821504556, 0.08234846871346235, 0.03900453222740907, 0.013986793419462629, 0.05765353074821178, 0.03779411534196697, 0.053294771278160624, 0.027102210842713248, 0.042846938740694895, 0.03793091542320326, 0.02692918282264145, 0.015190492013061885, 0.05930521750997286, 0.011798279701906722, 0.024842321072355844, 0.11436489017796703, 0.05957419038168155, 0.04583177877066191, 0.012298498368181754, 0.06473643603385426, 0.051502043061191216, 0.015670522407162935, 0.12160873389802873, 0.10336293678847142, 0.030989398546807934, 0.059688028413802385, 0.009933067776728421, 0.11298849567538127, 0.02425366808893159, 0.05168550196685828, 0.04961285419994965, 0.028244346431165468, 0.02008514889894286, 0.051798757413052954, 0.061873022496001795, 0.028292897732171696, 0.0349657163314987, 0.013261313451948809, 0.01857031416875543, 0.0354268349474296, 0.014416085032280535, 0.06832292405306362, 0.03781391213124152, 0.06573475824552588, 0.014316303277155384, 0.03903894561517518, 0.01692423062195303, 0.019294036173960194, 0.03981678317359183, 0.01484034395616618, 0.02715643586270744, 0.08994098083348945, 0.042732733345474117, 0.02667281161848223, 0.01926624830957735, 0.052820008277194574, 0.04503450807533227, 0.01180412504254491, 0.023919284176372457, 0.06661836669081822, 0.054476867808261886, 0.01972695317817852, 0.03592909823055379, 0.07374971566605382, 0.031706415247754194, 0.025084285334742162, 0.04794803884578869, 0.038002369401510805, 0.03090181027801009, 0.0588104721828131, 0.031918016393319704, 0.01380749146846938, 0.022616648020630237, 0.02025662768573966, 0.008805256566120079, 0.01500558313637157, 0.07074859662679955, 0.03895647074386943, 0.026145667834498454, 0.04653843323467299, 0.04911208263365552, 0.0607423234032467, 0.02843697086063912, 0.049843955275719054, 0.043857550917891786, 0.046027843054616824, 0.016810366614663508, 0.03771744777623098, 0.04677259195887018, 0.007089826276569511, 0.07314510279684328, 0.02502122504665749, 0.0204925007710699, 0.032419518975075334, 0.027763807665905915, 0.027751608613471035, 0.04240128648234531, 0.011985170112893684, 0.03977275155193638, 0.026710004349297378, 0.09859712416073307, 0.02567641899076989, 0.0757768029870931, 0.04866794064582791, 0.09934953573974781, 0.03751792879484128, 0.0773486569232773, 0.0077782039625162724, 0.018599226386868395, 0.04035000514704734, 0.03782714091357775, 0.030678770781378262, 0.03841197925794404, 0.08529247206752189, 0.027855407242896035, 0.06731378132826649, 0.04117811949981842, 0.04086837674549315, 0.08084231711109169, 0.05762483189755585, 0.03568378131603822, 0.027190652581339236, 0.03637384135799948, 0.027240031377004925, 0.01591303400346078, 0.025663652195362374, 0.04883954374236055, 0.05701548041542992, 0.027375471472623758, 0.040542377246310934, 0.025471421104157344, 0.0064797284721862525, 0.054189526781556197, 0.08496136288158596, 0.12444573440006934, 0.04351533920271322, 0.016409953823313117, 0.05102555085613858, 0.06534916799864732, 0.05483908040332608, 0.01079499808838591, 0.07925555342808366, 0.02674320618098136, 0.0774220924358815, 0.02926530043623643, 0.017026645145961083, 0.027993652656732593, 0.09169697645120323, 0.030831771946395747, 0.05830286543641705, 0.04749295760120731, 0.05544275074498728, 0.029447195265674964, 0.08321007248014212, 0.01772174993675435, 0.07264770058100112, 0.0534580437670229, 0.01463515682189609, 0.03141398308798671, 0.047937730414560065, 0.043496306825545616, 0.03169321615132503, 0.01809731562389061, 0.06681737359031104, 0.03599618095904589, 0.030857845449645538, 0.05874669201148208, 0.14988249720772728, 0.033257362883887254, 0.06818263587774709, 0.02143062181858113, 0.012034059091092786, 0.028841803141403943, 0.038172796193975955, 0.04243783354468178, 0.0379232713021338, 0.060765496964449994, 0.014742701441718964, 0.0038977099666226422, 0.007391523686237633, 0.026857372613449115, 0.08400801481911913, 0.03398753600777127, 0.027683921034622472, 0.0130054923647549, 0.02889077932195505, 0.02771160870906897, 0.02455954239849234, 0.021885322712478228, 0.060215624907868914, 0.03331512794829905, 0.08175449824193493, 0.008055836769926827, 0.01111534891606425, 0.03135901963105425, 0.02382823749940144, 0.07722816182649694, 0.027516967493284028, 0.018839392796508037, 0.06742240948369727, 0.012221102570038056, 0.04567152682284359, 0.041382610870641656, 0.06318243074929342, 0.019295629936095793, 0.06123152488726191, 0.014709150800626958, 0.013144468794052955, 0.03249222718295641, 0.05014392394514289, 0.10342576701077633, 0.06543798081111163, 0.03156313621730078, 0.032477966815349646, 0.03244296713091899, 0.05868771353561897, 0.031969335905159824, 0.06160971963254269, 0.01923735093441792, 0.031219180455082096, 0.02361840637604473, 0.039834015842643566, 0.02291719185450347, 0.02350724007555982, 0.08384217449929565, 0.03385227588296402, 0.04459486350242514, 0.04627412105037365, 0.00908919577341294, 0.038420154014602304, 0.009819673177844379, 0.022708141841576435, 0.019184537850378547, 0.06512923995614983, 0.05690291516657453, 0.05044759964221157, 0.02216534616309218, 0.06368195550749078, 0.0626750837545842, 0.014180313992255833, 0.046113442367641255, 0.01591348300280515, 0.03257713258790318, 0.024068774982879404, 0.06303892165306024, 0.08150321446009912, 0.05628071339742746, 0.07836262360797264, 0.02108678479999071, 0.017353418334096204, 0.09357279923278838, 0.045539149941760115, 0.08531722269253805, 0.043200093423365615, 0.08458521275315434, 0.0241550904684118, 0.0034678951396927005, 0.037240128076518886, 0.04670406946388539, 0.012944730879098643, 0.07711196376476437, 0.029393367294687778, 0.01748859867802821, 0.024735906372370664, 0.03127495656372048, 0.014003249616507674, 0.03802035535045434, 0.024866017847671174, 0.022514704760396853, 0.05479198371176608, 0.027467776089906693, 0.03636011162598152, 0.011868741057696752, 0.048652040131855756, 0.017703726880426984, 0.026319241333112586, 0.07184431087807752, 0.08435800424194895, 0.17535940278321505, 0.09713404680951498, 0.203791985695716, 0.10448490080307238, 0.15738963265903294, 0.08945738256443292, 0.08055956626776606, 0.12392473930958658, 0.12396696751238778, 0.07716956184594892, 0.22396774525986984, 0.18371902842773125, 0.11553421805729158, 0.12601211870787665, 0.11338492869981565, 0.15196812513750046, 0.10338846666854806, 0.15148556587519124, 0.14241053955629468, 0.10343906629714184, 0.08802772412309423, 0.12888957367977127, 0.10405505629023537, 0.08291906895465218, 0.13219754851888865, 0.2085134995286353, 0.10219451432931237, 0.2299799132742919, 0.1207496682764031, 0.10795348382089287, 0.1213794547948055, 0.14514907932607457, 0.15881538740359247, 0.09818976672249846, 0.09884762126603164, 0.0875936790544074, 0.10602032270980999, 0.1869746224838309, 0.16270676453132182, 0.1879292173543945, 0.13220317399827763, 0.13445839751511812, 0.20291694905608892, 0.12216121089295484, 0.08205370249925181, 0.16437192127341405, 0.10333696161978878, 0.1270665175979957, 0.06813856714870781, 0.13759034976828843, 0.14342132984893396, 0.11762084046495147, 0.1596257829805836, 0.08144229897879995, 0.1370801529265009, 0.11660645075608045, 0.1560110636637546, 0.2264543852652423, 0.2087489829864353, 0.1451645011547953, 0.18569372012279928, 0.12143694897531532, 0.1648814947111532, 0.0863317385665141, 0.14464006992056966, 0.2143031419836916, 0.11606758474954404, 0.1276027935091406, 0.10684735723771155, 0.27456919953692704, 0.10790814601932652, 0.11764255570597015, 0.1560303891892545, 0.08839123547659256, 0.1830835422151722, 0.16375886276364326, 0.07777390754199587, 0.12154988900874741, 0.128825006831903, 0.23479946481529623, 0.13065815612208098, 0.14934602833818644, 0.13399707851931453, 0.0884043046971783, 0.23924258421175182, 0.1591176789952442, 0.11277158075245097, 0.11806521622929722, 0.15961628349032253, 0.2522141975350678, 0.17020466766553, 0.187910960521549, 0.15605005610268563, 0.1250519577297382, 0.26776551618240774, 0.11998695568763651, 0.21273269812809303, 0.24026420986047015, 0.10736554700997658, 0.22744522662833333, 0.12684034067206085, 0.12159875201177783, 0.07324768987018615, 0.10325977826141752, 0.14967845112551004, 0.1484113378683105, 0.09025667561218143, 0.1554832185502164, 0.16725287918234244, 0.1473287818953395, 0.13363306992687285, 0.08538229420082644, 0.08081803403911181, 0.10047702133306302, 0.14621134498156607, 0.22210005641682073, 0.11867763649206609, 0.17501195892691612, 0.1042930778930895, 0.10394777142209932, 0.11895058356458321, 0.29128574940841645, 0.11190187273314223, 0.11343696067342535, 0.08464546772302128, 0.1289714325685054, 0.15306743880501017, 0.1462992004235275, 0.0808692941791378, 0.12051806625095196, 0.2678814990213141, 0.18300551280844957, 0.11250983268837444, 0.19744672696106136, 0.1762470559333451, 0.12113577802665532, 0.21322946209693328, 0.2016725900466554, 0.1326473939116113, 0.15153996529988945, 0.11221575667150319, 0.057870167365763336, 0.18441710737533867, 0.2240039175376296, 0.14501522557111457, 0.2696847991319373, 0.08046468268730678, 0.07163404559832998, 0.1945238228654489, 0.11201545101357624, 0.1908367738360539, 0.2044038864551112, 0.20806518296012655, 0.1102693630673457, 0.10189141379669309, 0.11277883895672858, 0.09694188993307762, 0.09870194509858266, 0.18657128006452695, 0.14334064355352893, 0.08317368497955613, 0.13080006960080937, 0.12974783778190613, 0.118736525910208, 0.13414253946393728, 0.0912502703431528, 0.10400805607787333, 0.1218082380364649, 0.1343833960709162, 0.1743660678039305, 0.1192945170623716, 0.1495437216362916, 0.14716841862536967, 0.18698269705055282, 0.15068980545038357, 0.10661249718395993], [0.024291753252327908, 0.05761539548984729, 0.019034585056942888, 0.03271740220952779, 0.007129809018806554, 0.026851177535718307, 0.02399184952082578, 0.04926609683025163, 0.048360016153310426, 0.05780863961263094, 0.05856748190126382, 0.0456054163078079, 0.036836514773312956, 0.02273442871228326, 0.057738677351153456, 0.029518337541958317, 0.010412716892460594, 0.03774909666390158, 0.03875364549458027, 0.05063150754722301, 0.039384085102938116, 0.044009650373482145, 0.02540696743380977, 0.007644285269634565, 0.04310195552534424, 0.06481367876403965, 0.017256991086469498, 0.027367684488126542, 0.011683565007842844, 0.010827404894371284, 0.04525810603809077, 0.008930647982197115, 0.030139850969135296, 0.08853321574861184, 0.01949571851582732, 0.0317519831151003, 0.034082334241247736, 0.09582825281540863, 0.04539031222520862, 0.015936281779431738, 0.04671931317716371, 0.038318698716466315, 0.06255077401874587, 0.03314148765639402, 0.03109910096100066, 0.015662388468626887, 0.03118643318885006, 0.02605001427582465, 0.05949652833805885, 0.08008096265257336, 0.026008702625404112, 0.04408715285535436, 0.04078090722032357, 0.045170217199483886, 0.04637002508388832, 0.13353783753700554, 0.05286677842377685, 0.09345947328256443, 0.02225254851509817, 0.03868152358336374, 0.06841926224296913, 0.03859839191136416, 0.025539336893416476, 0.05334573826985434, 0.02579778611107031, 0.02604902536404552, 0.056883366996771656, 0.06773746601538733, 0.03985557152191177, 0.06599185304366983, 0.027668543734762352, 0.023644654283998534, 0.06724869497702457, 0.03708386888320092, 0.027058689447585493, 0.014750057980563724, 0.019690270673891064, 0.03428788317251019, 0.0358104028418893, 0.014066582643863512, 0.11690071973134764, 0.06820007634814829, 0.032681018419680186, 0.03873392292007338, 0.04320660947996657, 0.0320291641401127, 0.036839876702288166, 0.03302243603684474, 0.031943034191499464, 0.02564735277701402, 0.07482940694899298, 0.08815820110612549, 0.022492338284791913, 0.006409731422536424, 0.036362015234772116, 0.04640522143745329, 0.03457339480519295, 0.04216435583657585, 0.030146233439154457, 0.008364016375708161, 0.03092699877015548, 0.1300678518600762, 0.07700099042267539, 0.04405701423820574, 0.07981346294400282, 0.09003742292406969, 0.05653261687257327, 0.03209803173376713, 0.052192284929333255, 0.011375351077731466, 0.0253621435695095, 0.007078826720317011, 0.010128496596735204, 0.040918909580796026, 0.02658188925124705, 0.027635902224574238, 0.02946373959275661, 0.04615276506228838, 0.06345853194943629, 0.05875939015822951, 0.02239202403870877, 0.03407685719139408, 0.019949519555666484, 0.07190541931777261, 0.09426744203665294, 0.06032160730683245, 0.016626429023745004, 0.04958113480824977, 0.028238515005796216, 0.02163454359106254, 0.055866004986455664, 0.05601143253443297, 0.019537735206540674, 0.038934466065256856, 0.11086308863013983, 0.015904744213912636, 0.01195042368635768, 0.02100107230944559, 0.045239025421324186, 0.02089105448249029, 0.0272732350640581, 0.01069739175363793, 0.038031472722650506, 0.01773899744875962, 0.01595411558810156, 0.02859014643036062, 0.01960884779691696, 0.027344700174580794, 0.023967180532054044, 0.03817881130089518, 0.013116701338731218, 0.02809642712236382, 0.033094891914515756, 0.03635728033259511, 0.018450871066306718, 0.025602992755011655, 0.026380277413409203, 0.01863975136075169, 0.009081418993446277, 0.0183848774395301, 0.04053363103594165, 0.06356750149279833, 0.02264879414724419, 0.03764768218388781, 0.025668791568023153, 0.018239520395582076, 0.02100103705743095, 0.08572062448365614, 0.021377916345954873, 0.07160483466577716, 0.06099534009990748, 0.019607944232120644, 0.018874950947065372, 0.05276994299492799, 0.04646314606361557, 0.03676761749375146, 0.02076378914352972, 0.04838668894080911, 0.07301434379769489, 0.07131402409868315, 0.026993565988959745, 0.05003359627153259, 0.043112716666655615, 0.05686293196049519, 0.027609079152171034, 0.05530883019673638, 0.06168489548144862, 0.040518635942135006, 0.019701239616551902, 0.07236558056320064, 0.04669073307013605, 0.018619047295942437, 0.04524855459749233, 0.022960032329137903, 0.029824918747181073, 0.025148128588625696, 0.047502204761258326, 0.04752829125209246, 0.03806356318818871, 0.036952738810214214, 0.040046451904345304, 0.020308782113716006, 0.02964491639431799, 0.027255132226855494, 0.050704178647720255, 0.013983386033942224, 0.05549491259444039, 0.04927994901663624, 0.02450108342600288, 0.0754523953946773, 0.03297961411590222, 0.10585200361674652, 0.06557563436217606, 0.027286692056804895, 0.05152370264113415, 0.049931721659959294, 0.030834775789116975, 0.02338703070563497, 0.030108933096926194, 0.022188482616911642, 0.01901079736853717, 0.09689036261988804, 0.028831717354478315, 0.049575034354347736, 0.027330617922416423, 0.011496103143144865, 0.031629643781343475, 0.061888388663646765, 0.015438466743944446, 0.024754064870649017, 0.047132303516264074, 0.01721626573271351, 0.03240428639401216, 0.039787446075933985, 0.04140304219617974, 0.05052790744230151, 0.05244239240710158, 0.0947559236374218, 0.09276318291085772, 0.052858121271128766, 0.009294191804656293, 0.022929361221031286, 0.06201193027663976, 0.05339587776688859, 0.06522550393128768, 0.05389978861785494, 0.011442293725849595, 0.04439070980879478, 0.048240908872685395, 0.015065563511598157, 0.03815336305706296, 0.03371886741661001, 0.06832440834841691, 0.04746253696794156, 0.015687152081227396, 0.034125297170248814, 0.10126926397788338, 0.009694833734101849, 0.08917249433579855, 0.0342540412384551, 0.034601414590724744, 0.039284359008888714, 0.034427718637743965, 0.019025976143893786, 0.010130587597814156, 0.04987914420780726, 0.05477924845763482, 0.04918549588182941, 0.010425861255498603, 0.01436474232832552, 0.036832748373853974, 0.020677507054642774, 0.056234607473015785, 0.0352706499688793, 0.017844527137640398, 0.033434951401432045, 0.031647455325582996, 0.03994004648120608, 0.07933383516501635, 0.01966528256161837, 0.034099719050573185, 0.0322645808046218, 0.031671864562667906, 0.015289552029571496, 0.019009390998689923, 0.03613539673096966, 0.09693647967651486, 0.01347310013443348, 0.015568341659673024, 0.023060044150042813, 0.019240113579144236, 0.02142357512639137, 0.05895671609323472, 0.030831263575237244, 0.09754515209351666, 0.058897648559650406, 0.013984563265694305, 0.04318525046983268, 0.006195579608174739, 0.01645136009756243, 0.04862793517531827, 0.05871400411706418, 0.06723938844515942, 0.08763126141275279, 0.050486736799939536, 0.011102842800028156, 0.03842843638267368, 0.04023131346912123, 0.012811927263101097, 0.03314957706606947, 0.0948104566487018, 0.024521974883100484, 0.04040962929138914, 0.03478949707641732, 0.01102236801671097, 0.054947738244663924, 0.035487319983076304, 0.060468400406534784, 0.039062234209268354, 0.0860987338819541, 0.04068094363901764, 0.01403051704983227, 0.016704451008990873, 0.017906012217281386, 0.05838501005200669, 0.07827567358617671, 0.03314339126518462, 0.01517520006018458, 0.050353283804724924, 0.004755304280479322, 0.01863511664851103, 0.01784375901479507, 0.02434958325466141, 0.03451082804531325, 0.018986300929100253, 0.033843889614217915, 0.010287284658261342, 0.020983405484003015, 0.022681405971525237, 0.005325976881067618, 0.082248820544919, 0.05340803414583206, 0.034392555680824444, 0.08701145678060129, 0.0398482613672968, 0.05478993167344015, 0.03304517544165719, 0.0629474593733903, 0.028680788636847865, 0.05145841591001954, 0.03956997083150782, 0.015420848158100853, 0.0896712249959819, 0.1541609043488279, 0.1753896230366081, 0.13575083285104483, 0.08895876322640106, 0.13720989518333226, 0.13284400367410854, 0.09381731462781318, 0.09216877457220107, 0.13455922569846734, 0.2079107568715699, 0.13698144728550687, 0.14163319923682138, 0.17463690717704594, 0.12581884860992432, 0.09551098468364216, 0.206399877788499, 0.11263092150329612, 0.11158294961205684, 0.1653997809626162, 0.12910439574625343, 0.16603878495516255, 0.18947233533253893, 0.09555252268910408, 0.12796237890142947, 0.1179743254033383, 0.10887484531849623, 0.15289834787836298, 0.1244098886672873, 0.12314023726503365, 0.09434412815608084, 0.11524620538693853, 0.16483956336742267, 0.19032938231248409, 0.10080020438181236, 0.14221642340999097, 0.18106444040313363, 0.1690562831936404, 0.11696959845721722, 0.11074559923144989, 0.14444393513258547, 0.12630467332201079, 0.1300738038844429, 0.10436585289426148, 0.10801498559885658, 0.15392965113278478, 0.15017528930911794, 0.09847885550698265, 0.10873578910832293, 0.25236016314011067, 0.06345528876408935, 0.2404694285360165, 0.17206241172971204, 0.08376874640816823, 0.15712038148194551, 0.1275259515387006, 0.16696353064617142, 0.2489208578481339, 0.17329173482721671, 0.12593861640198156, 0.1000437480979599, 0.23145390761783347, 0.18255698843859136, 0.09279757403419353, 0.13765651965513825, 0.08550172802642919, 0.09765632581547834, 0.16266855876892805, 0.1309263237635605, 0.2501549158478156, 0.12591075617820024, 0.15749307320220396, 0.15655002614948899, 0.12530238804174587, 0.10093184653669596, 0.13899904995923862, 0.13295406417455524, 0.14406653819605708, 0.0922841191641055, 0.0888384685094934, 0.19628489477327093, 0.12694332108367234, 0.2011653914814815, 0.16284716402878985, 0.16393700789194554, 0.16108447423903272, 0.11788881514803506, 0.10488790183444507, 0.11089852618169971, 0.11157894201460294, 0.1770650511025451, 0.15169621707173064, 0.10725497442763299, 0.10646264272509143, 0.23764432466123253, 0.11810288022388704, 0.14922237169230357, 0.14849288505502045, 0.15911517053609714, 0.07733501624898054, 0.14839058741927147, 0.21798354136990383, 0.13205389841459692, 0.11450456237071194, 0.21206651668762788, 0.17126310383901, 0.1978653873084113, 0.08387937836232595, 0.12447035143850371, 0.10444643528899178, 0.1502881699707359, 0.07537199111538939, 0.06578302753041498, 0.1469994761282578, 0.13939842930994928, 0.11710509978001937, 0.16183279658434913, 0.2321825036779046, 0.1844381249975413, 0.12593591498443857, 0.09302620746893808, 0.15592156065395102, 0.1038804957352113, 0.09667736623669043, 0.14329675293993205, 0.18142815213650465, 0.1383066113339737, 0.2013488207012415, 0.13366903440328315, 0.12918324151542038, 0.1351151239941828, 0.13593727519037202, 0.09702507726615295, 0.09504287503659725, 0.17972229601582512, 0.10416698700282723, 0.11893200760823674, 0.13352391484659165, 0.12702281994279474, 0.13830420677550137, 0.09957885195035487, 0.1163551521312911, 0.1639604300726205, 0.36611652933061123, 0.11204950074898079, 0.1464962851605378, 0.1333485305076465, 0.11493816957226954, 0.10886814372497611, 0.1730358274653554, 0.06503885379061103, 0.09620658485800959, 0.13166804099455476, 0.10699609105358832, 0.11546023335540667, 0.07401409835438244, 0.10146660846658051, 0.07935968416859396, 0.1232025925128255, 0.12725042179226875, 0.1206702139461413, 0.1936206588288769, 0.13417253707302734, 0.09709837177069858, 0.1748803464579396, 0.11350502303685062, 0.10607621385133825, 0.19217875495087355, 0.22056343965232372, 0.18931022059405223, 0.21159161638934165, 0.08797044516541064, 0.08078353901510127, 0.17700380907626823, 0.15123255288926885, 0.12314249339397065], [0.030115753434074577, 0.006798431268180138, 0.005148090112925274, 0.06298422536929138, 0.012721028087980812, 0.032950020977295935, 0.029269460173964035, 0.026978312998835463, 0.049740295798983425, 0.05987604410620406, 0.08615803890279494, 0.07483601206331514, 0.04084447959030513, 0.058844811355811544, 0.04022970300866291, 0.03266300649556797, 0.03169803268974647, 0.05494859171449207, 0.04440862525370903, 0.16110038588522002, 0.04272373109415639, 0.030300039834401105, 0.018656607389857527, 0.010596420706860954, 0.01663879320403794, 0.02764476532320259, 0.03694170307426248, 0.05934249929850921, 0.02768617901892867, 0.002815663756337017, 0.08993162235128693, 0.08772987799602561, 0.046300704780151136, 0.0028905675617352244, 0.020678117471106816, 0.03983191185398027, 0.06463452431489713, 0.024312409077538177, 0.018997846891579684, 0.06984768129768781, 0.01635400145460153, 0.07563005812698975, 0.015477168817596976, 0.014641230372944847, 0.004110912295800517, 0.052963547059334815, 0.06995320727583021, 0.054698658641427755, 0.05991155587253161, 0.0962010929652024, 0.05445797272841446, 0.04723873862531036, 0.058000610952149145, 0.016821469143906143, 0.047471320285694674, 0.027774860100180376, 0.07769206349621527, 0.025118312805716414, 0.0562179833650589, 0.01153268174675759, 0.03285559381765779, 0.014519033902615774, 0.0225814442455885, 0.053602139159920625, 0.03157420906063635, 0.0138910350324295, 0.014849843446427258, 0.020271218309062533, 0.03435159655055031, 0.025394428848812822, 0.017395568611391354, 0.03546403138898313, 0.02361136896070093, 0.05370884515286889, 0.08358689054148272, 0.021309811309038196, 0.022918930335436016, 0.06690606765914708, 0.053022440188215114, 0.05200449930271134, 0.045436121290549636, 0.03248396336857695, 0.03344291093526408, 0.030073495545366313, 0.01616971134353662, 0.023749417705403175, 0.057293737554573454, 0.04646763605705928, 0.06756047121598385, 0.08287926757475361, 0.035137664526700974, 0.05338245231541805, 0.019004322130058426, 0.06921679640072398, 0.02308340695890365, 0.06465649188612588, 0.04165073769399896, 0.057889938179869205, 0.030027430439076852, 0.05547026958083734, 0.10780797834740952, 0.020237875469319988, 0.03785883804084733, 0.02361331895372132, 0.061157094896771014, 0.02358174984692596, 0.0748548774572555, 0.006418306938940077, 0.03724077745573595, 0.02591651489638025, 0.044661426727543585, 0.037194627002463676, 0.05252855204162188, 0.033115156256826594, 0.0467531996400794, 0.031127881447901018, 0.1195660763187334, 0.006889328587931232, 0.091809545410797, 0.030839965256745927, 0.02497690398740815, 0.04759288036439102, 0.03216396413336042, 0.015747147299407516, 0.01604755198059138, 0.07883178710471839, 0.05688512588676531, 0.05199576793529559, 0.02634098254929995, 0.11375635876902379, 0.023396123870043084, 0.04277282045222819, 0.0716825746349059, 0.06610422904486768, 0.02929287864390062, 0.004948247833453934, 0.04136832452786621, 0.03417938118218444, 0.03181205996952485, 0.025040647051355336, 0.02041678315436002, 0.07264693616889417, 0.03961641443311237, 0.027347362629370764, 0.02223555518867215, 0.08239019225584343, 0.03541101235896349, 0.054662772090523504, 0.03391633435967378, 0.01776041397533845, 0.06730071210768074, 0.027665862726280466, 0.028133621708548162, 0.01497308912803419, 0.03455517507973127, 0.04870265089266468, 0.07867273743613623, 0.02582119715953013, 0.02800424124870915, 0.027821138573926874, 0.026695278284023516, 0.0737911942997016, 0.035363199494895525, 0.009946956142812269, 0.01901823368825717, 0.018017690599663183, 0.016690244447090663, 0.022662546143692452, 0.05638935268507339, 0.023286729447136167, 0.022178890358190984, 0.0335580811224645, 0.03259102188167162, 0.03426456118177157, 0.03890339605277404, 0.025703704050101805, 0.03874553010973614, 0.01071225326086278, 0.03092321196163539, 0.038620522755081765, 0.014449516929744277, 0.02080439018754987, 0.06727459593093954, 0.02212508650700329, 0.07324039455852471, 0.03349221922690049, 0.09862753737252206, 0.06647816757322289, 0.028353729721857235, 0.030830688410787843, 0.02490298793418333, 0.05319921976479236, 0.00680263599861064, 0.04558849905151874, 0.01866027174401097, 0.04053442142321728, 0.02307119491888443, 0.053296344631235115, 0.01259638809642638, 0.029037900822004303, 0.01799863781343447, 0.04626121881301515, 0.028548556474561337, 0.06254046558751725, 0.030408603051910177, 0.05846086125529837, 0.12897159584099427, 0.12044416318531148, 0.012371214925224194, 0.05120554764289409, 0.02177591530198697, 0.013650256350956624, 0.05247290580882691, 0.0801390950800851, 0.034156960900872946, 0.05062354801339097, 0.0737144859158434, 0.05643833814247046, 0.018954639053845312, 0.02807781220326433, 0.020724789283121936, 0.01183717937237816, 0.016066766183939762, 0.06544160249177366, 0.040501121256966144, 0.03741111890121829, 0.03680195295601152, 0.03104149360297015, 0.049663223762763664, 0.028626172133954242, 0.02381772683293093, 0.04610184631019365, 0.05787945534393657, 0.04626297399227042, 0.027003174946003128, 0.04295934813853819, 0.026801802450791, 0.02099100693158107, 0.02738071660132846, 0.01954972274688771, 0.05870638968190178, 0.002383830983490043, 0.037981518762535416, 0.009976749661291251, 0.05913173306907993, 0.05041895645263139, 0.021679985293303616, 0.056573212350485846, 0.054775593380327336, 0.003923360445696744, 0.026775986843858846, 0.005447525827548816, 0.041124002091237344, 0.006398436862582457, 0.04487908008741215, 0.02775895773083903, 0.03970432182541117, 0.028466283838497475, 0.03243767190724611, 0.03464875990175642, 0.03875781636452302, 0.010744965275080176, 0.026573152317723725, 0.03340364761243109, 0.09699913178337738, 0.024169673670257907, 0.056003554636845365, 0.06954481825232506, 0.022100293208495714, 0.048937763276626356, 0.06788563579902984, 0.058723811598611064, 0.01084103258108371, 0.03292880668595899, 0.08062996639637277, 0.04471970387385227, 0.03550814093614463, 0.01902307620184729, 0.024288296699523926, 0.040330386473215185, 0.07303585865884088, 0.01077700471796561, 0.01782688999810489, 0.04314811340009328, 0.08185656581190415, 0.0503536660107784, 0.05696349297068082, 0.05553835420869291, 0.02980812580062775, 0.03843717146082781, 0.017834792015491985, 0.02625569308293052, 0.0707471049099695, 0.03455424368439708, 0.0676357546763029, 0.1329060472198762, 0.06699704012135044, 0.04652926028938964, 0.08954693752457388, 0.014032971703272779, 0.02851880191883538, 0.027996389326290227, 0.12248288738192059, 0.05050826650403906, 0.026690790145948995, 0.028331172143225558, 0.03996487874246668, 0.008590320394432638, 0.033219001270481385, 0.07930387466331013, 0.007783682867739117, 0.01416487082678941, 0.02395259176410036, 0.0638488942058757, 0.06364511529682204, 0.026336935989093035, 0.017947470441868063, 0.054027040969231166, 0.02039604754827451, 0.011628169249888742, 0.026001466685556807, 0.025519022456137463, 0.0087426629033871, 0.019491291604936123, 0.028814620127377566, 0.04084193402377423, 0.03259022778365761, 0.016476094024255872, 0.02187422760471236, 0.026756141814985313, 0.0037419644786496065, 0.004360997045296244, 0.04089019959792495, 0.047568326408509165, 0.02979799177410314, 0.047361512115458027, 0.046420843646046706, 0.05009232983866241, 0.012261053307156544, 0.007588246626255568, 0.0347083877568366, 0.033327837227261625, 0.006891682587593095, 0.014002416555740638, 0.019760379509534687, 0.058305670754634775, 0.030566348395950627, 0.022495874618471134, 0.056335639746976085, 0.06617492603254505, 0.09583983774064109, 0.01183697342639789, 0.10744256709585898, 0.13967689796118066, 0.0800126331159845, 0.17896570614539087, 0.10471196088474244, 0.1787070231512189, 0.13879175327019766, 0.13547087990446016, 0.16180640581296757, 0.1287150353891775, 0.2611969452118501, 0.14412260003155097, 0.058534211420919746, 0.12260368675924838, 0.17112886416725814, 0.1281188681605272, 0.17847355833509937, 0.16211125039262697, 0.1114019843225833, 0.260085504851304, 0.12594127329066396, 0.1345909747760743, 0.19684952072566375, 0.23707143118372187, 0.15463117364561185, 0.1723007153486833, 0.10368643896072172, 0.12449243033188395, 0.09336384013295174, 0.13442844443488866, 0.14885082287946716, 0.1867693295935169, 0.11127498059067875, 0.12502822384703904, 0.06368174028466456, 0.12537945265648887, 0.09730088160722516, 0.23220766248414293, 0.09341884811874479, 0.13419588503893465, 0.1233206904726103, 0.11781350200180896, 0.09283160892664455, 0.11236623453442007, 0.12966329231858253, 0.13252646836917847, 0.08667528614751063, 0.13641401601489633, 0.09778730003745295, 0.264513484435156, 0.16952206991845742, 0.187530817638617, 0.21764069882920012, 0.06712264861562289, 0.13608894048957154, 0.10087062677484937, 0.16380923974793404, 0.16421918728156015, 0.21771475032437593, 0.21992738940753043, 0.10593835249892436, 0.1180983753874898, 0.15958020027028397, 0.14520937140332535, 0.12906565563753247, 0.10389339426183142, 0.12543907680083066, 0.2396036242134869, 0.13392160210059956, 0.07900818076450378, 0.1314246907713823, 0.11654779882519506, 0.11685542645864189, 0.14209135668352246, 0.13494195125531405, 0.2258815660024993, 0.09146478070761077, 0.08415168718784116, 0.15699844661867246, 0.13710771629121155, 0.10992137002176605, 0.16035320644732565, 0.21116920077474788, 0.21051001036539674, 0.11673307599266991, 0.0994018571509514, 0.13613778864964843, 0.10881668320507742, 0.2929955389117822, 0.2584619529079646, 0.15066371153807268, 0.15660743869375437, 0.09420781789231114, 0.25875049992464483, 0.16268418839899823, 0.1449257819331251, 0.14286422927398235, 0.17069246649043635, 0.15058243152452633, 0.16515128023456782, 0.1969523378647864, 0.10645090194884688, 0.12377913735690527, 0.1845782424788922, 0.18477511941455305, 0.07788980132318102, 0.18326134595554322, 0.06089800372137688, 0.11616632749792188, 0.18477048841305077, 0.18016601126873866, 0.18065648182528093, 0.09712294428027235, 0.13476119376718998, 0.15764457522891462, 0.19293246528832242, 0.31059658038429916, 0.12356618550256826, 0.20442583918338642, 0.1930200684000738, 0.14708516449900344, 0.08686108281835914, 0.17184365628054366, 0.16331379680195823, 0.08502071243128739, 0.12162398503278382, 0.20718318497529253, 0.09781603599549271, 0.16432706586783752, 0.15995157096767798, 0.13697353599127382, 0.10242466174531728, 0.13725742232054472, 0.24522297346265987, 0.08947693815571256, 0.07933533430332318, 0.08116668759612367, 0.1992032420821488, 0.11596741707762703, 0.12334857296082191, 0.06840900576207787, 0.13257274869829416, 0.17895015073008835, 0.12609780707862228, 0.10393432370619848, 0.2096564811654389, 0.053001418855274096, 0.08683685911819339, 0.15984578523784876, 0.13546114292694256, 0.1370627569849603, 0.12868377612903714, 0.08078915707301348, 0.13599762663943693, 0.11055629220209084, 0.12610194826265797, 0.1371837715851143, 0.11857400299049914, 0.12036831569275819, 0.20783195563126355, 0.22071356128435582, 0.23728212690912187, 0.1385105386725627, 0.18993659323314205, 0.16055276995757595, 0.15173154330113903, 0.08575537183787674, 0.08612951816758141, 0.12881120288511738, 0.14910221798345447, 0.09136283188126981, 0.1605360716348514, 0.0784369719622191, 0.1199663314037025, 0.182493950414937, 0.22734432423021644], [0.0061583098795381375, 0.04349954630015418, 0.045518366096075624, 0.038998268501018174, 0.02330905139388051, 0.016551436856389046, 0.06409144290955737, 0.153990818944294, 0.05719576292904094, 0.05218642938416451, 0.01588139439263614, 0.015369222510344116, 0.02235064559499733, 0.029483681100828107, 0.027878222717845347, 0.005838796751049813, 0.08655410827486776, 0.015390488752018427, 0.07561906691989861, 0.031057069427333772, 0.06449627704569139, 0.024364333439734764, 0.04341672633017879, 0.04173241104581393, 0.031912646954879165, 0.035229724235250615, 0.06327892479021102, 0.0327746106631821, 0.016816570969240274, 0.05680159716575872, 0.01589273255376611, 0.06569010321982205, 0.002361134252168995, 0.029362176683207508, 0.05051840424130205, 0.031376556580653414, 0.018493661445972975, 0.015149571845540777, 0.04816791864868719, 0.04646956193028018, 0.013709361919609364, 0.03713198602781631, 0.045511723874369636, 0.08105883869575337, 0.03230137277569156, 0.06155198054329958, 0.0147206281144463, 0.022887017985340208, 0.023292269579542335, 0.0566808497387683, 0.05981006717775017, 0.04888257717539091, 0.012753695573337609, 0.017422788732801564, 0.02786833360005403, 0.025418370532861445, 0.11766615600208752, 0.07072049149428494, 0.0489887896401342, 0.1519539946457371, 0.02194890064856736, 0.022866748076921795, 0.046804110970697366, 0.01971216217498295, 0.02057557492662454, 0.025667706177046057, 0.07514501266996376, 0.009925777103489963, 0.04428495005413424, 0.014311102677311283, 0.05285380939312745, 0.052096418003202416, 0.07333537461818196, 0.015389453456009505, 0.056618965754751116, 0.04751290282001719, 0.03438366104091983, 0.043997553366352804, 0.03459847197518684, 0.04304490292270202, 0.033009385369950905, 0.022422491056204308, 0.02998457697685808, 0.04066985966346692, 0.02690244324185187, 0.02220760961790802, 0.02558824071456911, 0.02287527906446485, 0.01707186791463755, 0.06143816848634742, 0.01867266561021097, 0.028555198696267325, 0.031544779194518924, 0.027790480453404598, 0.05925462530285586, 0.0403564766747877, 0.02136600116500631, 0.07952493077027611, 0.04792393017851282, 0.03308178929728456, 0.050154421624029055, 0.07600330645800568, 0.006637001160925138, 0.024033843947108835, 0.01317552767432062, 0.05890189735509921, 0.09552746036206372, 0.06848935809102841, 0.06470939217251725, 0.035564666613936424, 0.0942415781901218, 0.019539952372724656, 0.06014002974552568, 0.03622575692133978, 0.01431277436495293, 0.0869815111218486, 0.04384102328913286, 0.04041817141114734, 0.004021707072752179, 0.023052004835335538, 0.060890285385539755, 0.00566174860978208, 0.034115293019567616, 0.030366322898771614, 0.037093902719789185, 0.10990479044266976, 0.02722802157222759, 0.041802863124758005, 0.0419034092919901, 0.039311662621912546, 0.05887986299057957, 0.07786316564306617, 0.011725936074071797, 0.035055557018495165, 0.05355308319849428, 0.07285218453034759, 0.07500930354581214, 0.07103508789441548, 0.014942926391086075, 0.031165241161943413, 0.01518080141977407, 0.03599296003812924, 0.023530298603873234, 0.016334035826730542, 0.06030230775650125, 0.03521999838994816, 0.030148033147270326, 0.036224031427991576, 0.09687100740848109, 0.0032598050484011765, 0.027988125511910766, 0.022948625519347843, 0.01485493550717365, 0.02139779106073547, 0.03619159586378373, 0.10742848113295622, 0.011221011263842229, 0.08116130702546798, 0.026370321502326988, 0.04841071968257893, 0.050987115027965046, 0.015081218189152423, 0.03399435263418127, 0.044783231714973226, 0.017561644563102163, 0.07284148276085034, 0.014906645574228605, 0.03318089198728558, 0.02839022854459472, 0.02606195914268028, 0.040484986966475844, 0.05046709586167708, 0.04439236850885209, 0.029876594489905983, 0.03169366886140779, 0.016765826621849556, 0.019447675585979596, 0.03866268045385368, 0.009636326522013405, 0.053176183500909247, 0.024822279374348, 0.028389727594912983, 0.07268925342941657, 0.051288924223626964, 0.01695723392913351, 0.04172911219939124, 0.031895102583803236, 0.013193559079809347, 0.018953934013552498, 0.03739023857633583, 0.02200773811637191, 0.039195423742057756, 0.08171784356818534, 0.050396847873344086, 0.0823072498315014, 0.04227770034049172, 0.0596082623815164, 0.04329194904130418, 0.07643000426469371, 0.10306326497811824, 0.04937787540256977, 0.03870190295856446, 0.03330562845803797, 0.04185119549219962, 0.08630396740045398, 0.02955026659037685, 0.03747499555174727, 0.03785147964663338, 0.055132933775894344, 0.015027585031930357, 0.032351490008295514, 0.03094952666288009, 0.0344548441353254, 0.04820069560082629, 0.026132606035389472, 0.03405717172427103, 0.07057583206915297, 0.08069255913142115, 0.028212322758918162, 0.0007036044110009243, 0.03422028836212121, 0.010916060000454308, 0.00316840167670307, 0.02897407055570511, 0.04268936223525088, 0.04577292645990383, 0.009295004456362221, 0.035149394170730375, 0.041700569199747406, 0.036955228715669364, 0.020226123560860287, 0.008565449170419015, 0.05314293899573386, 0.07835736920242198, 0.028387671845848672, 0.10978232123306952, 0.0043039064075856, 0.012087165323464433, 0.04795749751792755, 0.024089640464808326, 0.055967463995330036, 0.07779661726090126, 0.07314203772693872, 0.037089898833073676, 0.0598368178907549, 0.016484625011798926, 0.04978122524335049, 0.032554979479755275, 0.1198767838650383, 0.028499060790636577, 0.04699538469139952, 0.03178296406986192, 0.010429570138512645, 0.043839969439432025, 0.040050114403129555, 0.06072534677514341, 0.017205413678311743, 0.013521208002202911, 0.06273895298363641, 0.06237677749595605, 0.04175932874204591, 0.01009014054943691, 0.03196699071850162, 0.026265357701049652, 0.0428926179301925, 0.021841424677404575, 0.04554096078209113, 0.053912616640445776, 0.043598058982752264, 0.03513031726470217, 0.034326615859754384, 0.05632917564071249, 0.042422207625349984, 0.04257920525560621, 0.03518316560075618, 0.009454167302465066, 0.03360192720720079, 0.029648218951479066, 0.06558147506439127, 0.024437316242256202, 0.05182753789995331, 0.02787839712254936, 0.06281926820520312, 0.036971823137719184, 0.02016677586652804, 0.01632019477256108, 0.024510065268259495, 0.021969413610349875, 0.03294859234301839, 0.0375053753668908, 0.13860600854968652, 0.05518374491657596, 0.02965014111396158, 0.02872821372875478, 0.017150238709291443, 0.06974980686209165, 0.02216263732407242, 0.011845092521980405, 0.015298994003387634, 0.0744703113741707, 0.03173195254930761, 0.03793255928030703, 0.0787707899871748, 0.04420354758622125, 0.02159427836886607, 0.06394019321305677, 0.027040653403673787, 0.030872395254846197, 0.011393451131880283, 0.014730615566804772, 0.034389780048513785, 0.0020722214958368568, 0.052421066793613136, 0.06999047793215141, 0.03375289488758426, 0.04416923809912987, 0.021654702177329455, 0.030689231352880597, 0.040205553523264825, 0.020644123396778014, 0.05210856324993074, 0.010444474319228902, 0.060117598331999034, 0.07145455718273297, 0.033898526526172645, 0.04256599131622352, 0.04994123228243552, 0.0160517080075806, 0.005481672042151331, 0.0311446391424397, 0.03788065347180236, 0.06354419063427486, 0.022383749092114158, 0.07093241918482818, 0.04551555335638113, 0.04859351807681378, 0.024320936354342848, 0.02893191842304077, 0.016869139144546352, 0.07650143597857095, 0.030525845686497632, 0.016177782199520152, 0.027390698487579357, 0.005991988555251737, 0.04701398662291467, 0.059087352638016455, 0.03692530532134697, 0.03415402941755019, 0.040660315644345246, 0.053792347898706794, 0.027166388063051272, 0.050364761118544266, 0.17445905890781432, 0.1399223113548942, 0.07381053466815501, 0.16275303001748398, 0.1489282288821414, 0.11416547509725206, 0.2618200227152556, 0.31843538163229823, 0.15099116193596274, 0.1764399401145056, 0.1092475518817082, 0.10874201572733, 0.13925262697739527, 0.08937205042457208, 0.11870825750520453, 0.10123548883711919, 0.16269586980342865, 0.15633177536074072, 0.16842809971421957, 0.11086372687714174, 0.12329591758316383, 0.1076860360626597, 0.17173770727822557, 0.29518092633225024, 0.11231035823584534, 0.12802378420019522, 0.14828364393906668, 0.06961539649637416, 0.1422350958455354, 0.10659532388672233, 0.1350993014057167, 0.16034562169807032, 0.11435317166615278, 0.05835027383000124, 0.12748807232128456, 0.15558964252704754, 0.0912245326617267, 0.15483419556403533, 0.12273266460397281, 0.10265478689689189, 0.15979292948031798, 0.1460365840466693, 0.09317403586464934, 0.12123337044613436, 0.12352020203252323, 0.18136456492356956, 0.15119252144359052, 0.10156856471439824, 0.13836892205290496, 0.10378811319242232, 0.08008011660422198, 0.15875890996539965, 0.082482841971796, 0.13915528688812628, 0.10522528958972543, 0.11412875363021158, 0.16730431001633406, 0.1277642254717648, 0.10402218656963669, 0.23206668411148712, 0.08021595189347863, 0.17026976885972545, 0.11144962278194726, 0.08506190162734129, 0.11918074582354166, 0.22304037236608565, 0.21205450873821974, 0.10729588902904652, 0.2345953742042184, 0.10459932513185777, 0.08450056338915601, 0.14457887242315337, 0.1272422433248721, 0.1212320568447467, 0.1817917451262474, 0.14105698093771935, 0.15296643250621855, 0.09187557428958826, 0.11351142034982331, 0.16948987555224448, 0.1026989372621756, 0.1257169814198278, 0.1717133796773851, 0.18495031079510227, 0.11254714787355624, 0.07340713287703693, 0.11106647420092486, 0.07384054712019861, 0.19716932700248435, 0.11084376310463995, 0.1273762751952745, 0.11137490335386246, 0.19796461245277897, 0.0663577466912102, 0.15612519113346934, 0.1575598813360557, 0.07145599694922566, 0.17591261450434104, 0.21339602972147986, 0.17081821599276736, 0.11699169961502776, 0.17503579671029001, 0.1441167073789984, 0.15593401389196515, 0.16532583336811513, 0.08849528458085842, 0.2319138462189585, 0.16664753900840878, 0.2183256417629309, 0.13822838896885514, 0.10745245992438868, 0.11081358738010749, 0.152684728091117, 0.1071590518404264, 0.23971690563485026, 0.19586207839893177, 0.11574364471016452, 0.12589450314408168, 0.07123417643015273, 0.18461606232449412, 0.10149886220460758, 0.1320317675708793, 0.13203157461248338, 0.16211096837650985, 0.11493153477204032, 0.1713928164099343, 0.14531042223097757, 0.12244542376720347, 0.09230984200257808, 0.12964834546437487, 0.06775734073016793, 0.2358892047777772, 0.08818027999950573, 0.13153703708667308, 0.09464558854233474, 0.1450252890936099, 0.0840524620434735, 0.24533629941288382, 0.11236129925237037, 0.13597049372037873, 0.11008583736838773, 0.2910865272860974, 0.09175820363452658, 0.13624433137010783, 0.25563146104104817, 0.14574708708096296, 0.0867966198711656, 0.11674993016640656, 0.26713320636190474, 0.1061624959402252, 0.13279061357025057, 0.0807925190019887, 0.0798291816317942, 0.14564875251380727, 0.1507153204875067, 0.17910221678903326, 0.1233304497145582, 0.21342855063267052, 0.12061056011589244, 0.1285425157402642, 0.15925573330605403, 0.1060173318546731, 0.19611664989497513, 0.17348626657621935, 0.06866030438686721, 0.10932544770184904, 0.19119206961477175, 0.08082692496827804, 0.11314966788631864, 0.2138274401659146, 0.1796441775513813, 0.14868180616758764, 0.14197472075466067, 0.1098836021265015, 0.06191981861775275, 0.06644909022725187], [0.054796752010588534, 0.04835885098145809, 0.01999887237616349, 0.061403525032801554, 0.046521909316652454, 0.00922860450373264, 0.0585426756151719, 0.04040397412609309, 0.027906166433240287, 0.09233859280357137, 0.0383948356466135, 0.03824696643278003, 0.020028806902701035, 0.02856590046576457, 0.005872634046681924, 0.023692953254794702, 0.03581605800718535, 0.041092271567322314, 0.037931208571535535, 0.05941679199167993, 0.04269352197297849, 0.03801753518928308, 0.030282860971055925, 0.033185619467985816, 0.05724602859118022, 0.060670030798064545, 0.029377576247497927, 0.052549239408108406, 0.046221614102250896, 0.01603949596756138, 0.02147114122635685, 0.031247756851371378, 0.03197758487658575, 0.020988203468732536, 0.02496002198313363, 0.021857069150428288, 0.02785156848403858, 0.024963942378235515, 0.022224794047360774, 0.015532259367319057, 0.048137924750335515, 0.02657648641616106, 0.035075754567515105, 0.04977580385457259, 0.02192530591855757, 0.07631261134520173, 0.04060789033246692, 0.02958743520139251, 0.014846451831544982, 0.060540273698279634, 0.020828621309192386, 0.039290155182243325, 0.010299327859684126, 0.0447557722509373, 0.04004639253253117, 0.03069730406423332, 0.03072758740017889, 0.07857818040065467, 0.022612345419474877, 0.020191600706311874, 0.03696539984957781, 0.010912237012234982, 0.045839537924621254, 0.022567770174646284, 0.04852178579312749, 0.05254743969999254, 0.06311603079666384, 0.0393195961805759, 0.03345970202644821, 0.024655390770931263, 0.017324877189821564, 0.03620821997174062, 0.03409530698263552, 0.041541352547938004, 0.030579942686017603, 0.04439383053977508, 0.03965007454098668, 0.048849629529286176, 0.07540569204138592, 0.054527359825442545, 0.04265409537765663, 0.04328642004111316, 0.0401475287071662, 0.02767504865914816, 0.01293133511353517, 0.019292143697384745, 0.04714106828032527, 0.055212840816238895, 0.06308468990027905, 0.02699751978070708, 0.049329175672028214, 0.0464656619442394, 0.024688121338840574, 0.010864440846489742, 0.033344661715091206, 0.04332556090957951, 0.03105833107838407, 0.028975842433283105, 0.06878989821416326, 0.060566486354218796, 0.02715866045036819, 0.01158374892838765, 0.08105499437078834, 0.062395019485848024, 0.05228633730439469, 0.012854850301664555, 0.06349311603116803, 0.10480646596988663, 0.03612502150645014, 0.06222720134246629, 0.035640339701785706, 0.012113851098547457, 0.02371583181229653, 0.040636329431436025, 0.01644918003876228, 0.026188337615167256, 0.031127786824072246, 0.057347892070538364, 0.04189932005829178, 0.07563528284663334, 0.023931880277814344, 0.05465668276883662, 0.002385176126153965, 0.02189121350966161, 0.07471029966836795, 0.01596669499122072, 0.02610870145872468, 0.04396349992020987, 0.060858989018015563, 0.041308462896267883, 0.015270630974555388, 0.0368626866111299, 0.04172718261543196, 0.04245427582645789, 0.011167899465363007, 0.06724720326019451, 0.029860840550099965, 0.04495718370890245, 0.019103250415355433, 0.022367666751961224, 0.030855856493872125, 0.026824629057955462, 0.031831856758799404, 0.007180305674410192, 0.04075239019584842, 0.035627611869131215, 0.05071259831311181, 0.014615976015193155, 0.04012224744656123, 0.020504237836576067, 0.03721936278452631, 0.062083796146907844, 0.08815393375698477, 0.0283364302595146, 0.03155618971504737, 0.01385279309033649, 0.11722607727278955, 0.07654426532099023, 0.06772303124307655, 0.0546206774743041, 0.08978199053672142, 0.01573791498231003, 0.032377049574279226, 0.03761621512239799, 0.0027381283416616498, 0.0159646188330953, 0.03167767928971443, 0.013797733154206071, 0.029164030675019603, 0.007638117094757035, 0.047386184814968146, 0.03085678232309874, 0.03270001368946396, 0.03450280171819031, 0.05540250407648273, 0.029670468538824935, 0.07490134332329035, 0.036376231073518284, 0.016401036918978207, 0.11237761907977983, 0.028190050907141995, 0.037622879608534276, 0.04915438505122438, 0.01357381142952363, 0.01812110516766552, 0.06628722781897523, 0.05540016631130129, 0.04100958147319034, 0.007480666290575755, 0.02366637138038641, 0.024430904086329974, 0.04545762130874209, 0.012107507591281319, 0.034805122995749116, 0.06196144939167425, 0.04371581926534418, 0.032140200564754196, 0.04405772669997532, 0.05923432756389957, 0.07617494295118377, 0.0666997951338999, 0.030461688875220716, 0.012758903594658477, 0.06431885922211222, 0.05279934317513835, 0.057658655277919024, 0.029727710389124695, 0.051723455399041995, 0.028680525174422655, 0.019983290985692292, 0.01054664022376528, 0.04152286936005112, 0.03319697061670013, 0.025632784418121446, 0.05017077855882235, 0.06362690299283713, 0.025979786696552765, 0.008749852459004615, 0.06178767922392581, 0.013838454797223676, 0.008834616855892818, 0.08548945290385745, 0.056987323332577944, 0.026133344472327735, 0.05212414835114032, 0.06151746696559712, 0.04128726715862285, 0.013547450344049139, 0.012878773432021262, 0.05050139792729169, 0.03672645798360463, 0.02111394740495598, 0.0617760831664782, 0.07011980458628386, 0.03464142748271115, 0.04177603077550884, 0.010621943165460834, 0.04799732116225641, 0.02098244811350014, 0.030946799270168412, 0.022762396547477692, 0.025714672992762644, 0.016666868650645483, 0.024074970060610212, 0.020308112325437833, 0.0455657114071073, 0.0490192659344757, 0.03689728553581517, 0.03261884499806911, 0.04311518059694208, 0.03132993486360647, 0.028872891707578674, 0.07242891544592567, 0.042614082485670224, 0.0925927932257764, 0.045506706956075504, 0.03252572401834186, 0.060138096450828016, 0.05558224853302818, 0.03544472070643678, 0.083416322740959, 0.03388252582226414, 0.029984983302711044, 0.04611926822690293, 0.01554450202092994, 0.05863612313987687, 0.0365021141624311, 0.05816016157041304, 0.040439177901134826, 0.03205297594831791, 0.03498675621813163, 0.048075910890474916, 0.014010214672453003, 0.00669089638904552, 0.036338385252747685, 0.007674313492316287, 0.03195902376319282, 0.028956732130609453, 0.09151714664767496, 0.038775216016802005, 0.016248030187853146, 0.022728716030542273, 0.043225189147051424, 0.0505897691618884, 0.04156769507972058, 0.030196000006981194, 0.053289561401470564, 0.020131247401877772, 0.03822960388788488, 0.01599182596692117, 0.03893042136041913, 0.033718837730702944, 0.04054176126373932, 0.026902287390839774, 0.019168917497154325, 0.039726935065118596, 0.017510031902929768, 0.03961623631766997, 0.0749822671059519, 0.04914924196782522, 0.11063959827879444, 0.03408914715691935, 0.04839428482227959, 0.048869114616536535, 0.010214625617663842, 0.059179516247240826, 0.039519070633105, 0.023996981472009793, 0.0162419983826112, 0.019068352776230313, 0.039562749734614044, 0.026284994928573724, 0.06454296555602923, 0.037979796979925595, 0.009804166929825442, 0.049782193746068515, 0.03256764051911887, 0.04881303793808911, 0.01784224503353471, 0.02982389272801811, 0.0635203009005636, 0.10954432189464569, 0.06270856203627773, 0.05552330345381051, 0.042903950525214896, 0.025284722723881714, 0.03703388152644038, 0.015527475297858473, 0.03535310257575475, 0.03449934331001714, 0.05636488407617435, 0.02443756857246626, 0.1449709341977723, 0.058807551831705496, 0.03718586223840248, 0.04949260772264097, 0.08028634460060857, 0.024753738325671293, 0.07333104789722711, 0.050536345661384985, 0.020831098227063194, 0.048487454041605815, 0.029485401028068736, 0.06012180259858724, 0.08208332161302678, 0.04339410937973298, 0.022872271511005238, 0.05695802334230393, 0.02492824878572719, 0.035143887434969656, 0.007155639468692243, 0.03381451911991462, 0.1990285108331591, 0.0804252598027233, 0.10612831261823885, 0.19611247902503237, 0.104501183523098, 0.16304191842209548, 0.2226218456053175, 0.0801363713981118, 0.11653842550003901, 0.20514227886451408, 0.07879916971432976, 0.071223934792215, 0.15095476701389998, 0.1289938751142472, 0.1661723863799125, 0.16541055694688112, 0.14606714568799362, 0.19491209968691692, 0.17046312801539898, 0.10455084062414244, 0.10862218114198186, 0.11025708052329719, 0.14042869355762377, 0.23904723610030487, 0.15959584474330768, 0.14010893180966377, 0.1118381593551021, 0.11513211502460763, 0.14247112849261612, 0.17580950050614774, 0.10024739342043176, 0.09895729584968649, 0.08732545204111375, 0.07364249759120867, 0.0810080609517172, 0.19042367959627882, 0.1100820598367136, 0.0974198107724078, 0.1236598816467449, 0.10784081096062437, 0.15392009227070957, 0.12465150968637317, 0.1467819674871862, 0.13864357606507838, 0.06520754395751283, 0.24830134265357628, 0.19519429391948506, 0.13547141425078735, 0.09538415164570324, 0.16767180670285597, 0.16576806432567537, 0.11023763625416905, 0.08759747885051183, 0.10355525693739764, 0.14920245244866237, 0.16862448683241382, 0.24309820466442034, 0.2517499099485576, 0.0884355788002722, 0.21251538244541734, 0.07362617034232244, 0.10460192264872603, 0.08608382413513027, 0.09187484698486514, 0.09453364298678935, 0.08179740179912187, 0.18084740673657507, 0.12094872712623328, 0.09971782652428374, 0.1087990720407106, 0.09776326929568313, 0.10981239305692725, 0.0961147811904084, 0.14266683283494785, 0.08323382120579481, 0.14496743126073852, 0.176355617295485, 0.15287629124941304, 0.18125782924471423, 0.22112368693342432, 0.1313359892810695, 0.11073434085119516, 0.13530358497519046, 0.16519997996510938, 0.18435035861330107, 0.10186399886151776, 0.1037537443335168, 0.07680021721171215, 0.12665245856624097, 0.10813326167408377, 0.10407999987364747, 0.25404715386684984, 0.14015574648510665, 0.09597292708349414, 0.1280593776027672, 0.20255703711882234, 0.12554269545944408, 0.17618002515519038, 0.1648182637291029, 0.1844680929207243, 0.11437555484008044, 0.08557158638723195, 0.22529518028022721, 0.1693119085393846, 0.10877963519305922, 0.09256337449187413, 0.15889821108430624, 0.15611632989021018, 0.14592150662792847, 0.1583039140678011, 0.13064824102912098, 0.09645812097005546, 0.09381530340760946, 0.10411027207737789, 0.12202723097288981, 0.1917286275420338, 0.2898373146308586, 0.10051481891423464, 0.1092426165996585, 0.12307992292335257, 0.13538848666939884, 0.09594605391612276, 0.1504194558947347, 0.17255291197216138, 0.14724647771799937, 0.1750596344936639, 0.08646950343973003, 0.10422431791084819, 0.12013824249152094, 0.1237739497446455, 0.1539404716459103, 0.12887689779745415, 0.1276721101021394, 0.15562208922347054, 0.10138579600607045, 0.10187336476519704, 0.11667963393847458, 0.1496979102375917, 0.0647806902998127, 0.14456725039053708, 0.1106718074879609, 0.1464397631934844, 0.12360725595499389, 0.060848595239804126, 0.14419574610656127, 0.17720463423756883, 0.15506760100834072, 0.11321646859869361, 0.13300328340847045, 0.10660044470569119, 0.1413052887073718, 0.09957449554349296, 0.11109101702459157, 0.11230275122215971, 0.2342046334524639, 0.19737041933694854, 0.26470130716916174, 0.13698707276489586, 0.18210129492217675, 0.14407293550902978, 0.28831033094320446, 0.12338091575657018, 0.1910378661705181, 0.18292531633051112, 0.14693075325340033, 0.0902303887414746, 0.18380038265604526, 0.12466834159567952, 0.21861050772713497, 0.12194002119940706, 0.11155951258842833, 0.16136644582729787, 0.07410239908494987, 0.12066918978234753, 0.09769045718712732, 0.1002024563786108], [0.022359466020134278, 0.02740907591942232, 0.02203216961788712, 0.06928326314664446, 0.05335762005415745, 0.012120211304136319, 0.11564375163288787, 0.021406249688880052, 0.029858794077881612, 0.024203934917750303, 0.040298867461388, 0.03753898723516613, 0.025952106443583034, 0.04432291832927149, 0.021363182859204244, 0.02404098897386575, 0.03783630643738434, 0.02774875876639271, 0.06162583908007946, 0.05334489593224134, 0.01746496869600378, 0.03638664340542164, 0.01807452797947917, 0.05681039903720375, 0.0637185137020424, 0.02649687809025636, 0.02329036968149012, 0.010582552749838214, 0.03229148736863863, 0.07452459205524065, 0.0721299932047259, 0.023616335784026887, 0.03671102131193038, 0.10416134668048471, 0.0262161254795501, 0.013722148196393391, 0.058959295056411065, 0.03402368602110073, 0.036541633526212536, 0.08310493241879158, 0.05678047193214297, 0.07382868017884903, 0.037485170396394096, 0.03397910149942618, 0.038484475953737274, 0.024287656597152818, 0.04200365860015154, 0.05642086798616219, 0.0869482035341207, 0.023019177788228262, 0.028419016452971846, 0.03011572374816751, 0.02372758372075623, 0.06334243036690168, 0.10359885811340064, 0.043816009201691486, 0.020784300249943044, 0.03239987803681288, 0.052686866984004155, 0.09976686022127979, 0.036796312633669004, 0.03950515907490626, 0.022185170782904606, 0.05389653430029284, 0.023330464209720958, 0.028483254900493193, 0.07293434027815238, 0.02533300685172435, 0.020856182818533853, 0.015992935477697756, 0.038785131109762006, 0.06263370902161114, 0.03756849131605122, 0.018412605932098813, 0.020159482410235796, 0.05719919536204543, 0.022263675164140295, 0.01363759995001601, 0.023405148385791108, 0.05465403330163099, 0.03801358325290494, 0.03368595316715073, 0.01691725257842336, 0.08192303255782463, 0.011419566380936885, 0.006744348183929105, 0.05463723107823171, 0.07899860705947503, 0.03002574019774329, 0.02760958937869873, 0.044817003144999035, 0.03298750685644336, 0.035969255841337144, 0.04821200964215677, 0.036386595165822655, 0.08189438565750606, 0.03323124299640767, 0.020338788999652024, 0.07395324966637418, 0.05152064128196798, 0.028763827540387865, 0.08219396098866127, 0.024992600410769228, 0.03612453911046032, 0.01825083814765094, 0.039897925889818, 0.13316581374965608, 0.08215542868128978, 0.0393548296415247, 0.04389224632177502, 0.01447613869459019, 0.03455779115029145, 0.023509895108873025, 0.05200377941946499, 0.07295492003322579, 0.023449794134648982, 0.021769759187009186, 0.03785337212320883, 0.023160504970292095, 0.03108596123638563, 0.024931050393206533, 0.021527978606172837, 0.025674821517895907, 0.04372895898995921, 0.01961126905371202, 0.07386248500552028, 0.06140103883808479, 0.03925375654944219, 0.04015804865048267, 0.053699924537795596, 0.029684161163459066, 0.06421595302526839, 0.016071619829745032, 0.02019820582063403, 0.060540596532518975, 0.07777848659316078, 0.025282692949986085, 0.027650116207951214, 0.053341571110649966, 0.03511973794957157, 0.03340785930049606, 0.006327828468783991, 0.03987973585026339, 0.01690393102762755, 0.031569752463838086, 0.07861975551350042, 0.03148427189444192, 0.037370055870269425, 0.05734054109780118, 0.02867434493964538, 0.014422782915062271, 0.07986936892848462, 0.038369190733646974, 0.01231158150403644, 0.018761652827379294, 0.009966829002223676, 0.06769409490516409, 0.04395894684421364, 0.03943959032767452, 0.06530957442009822, 0.008594309438194614, 0.07704640986048616, 0.0439202252891846, 0.016199822130147368, 0.0287789135472849, 0.07176529441494495, 0.016938683947955724, 0.03611828280554619, 0.047923421807354316, 0.02707011481106747, 0.016366764539270662, 0.012412021915224614, 0.034145576355513185, 0.02711138193262741, 0.07342554556089453, 0.04598617888404988, 0.01877609687653603, 0.06757072769687511, 0.011154805197293172, 0.04521952178038191, 0.04463457953534089, 0.040991584392031655, 0.036561946108122356, 0.0705549554550089, 0.04548489523585886, 0.034624929539859295, 0.06394569252734073, 0.049186534888576716, 0.032055751580628566, 0.022846641440992244, 0.07572431830340065, 0.028329927190497983, 0.042026650335174054, 0.032567454982199706, 0.10058833606308326, 0.04789126083778683, 0.1076994466711767, 0.026703857511165552, 0.04598946659825742, 0.03825373853032943, 0.05953900144959334, 0.03630885519669391, 0.01695677750831237, 0.013540003819798585, 0.03796760349359829, 0.07304311686311848, 0.03237810713471845, 0.029341123808990233, 0.05736075348977465, 0.05649584716593381, 0.05451366720080841, 0.012608243905560812, 0.024595768481958658, 0.02107269141561119, 0.034309620677959174, 0.044173190035508014, 0.038776752262492664, 0.028908453568874393, 0.0013499047008735943, 0.04109509172849357, 0.05195039673708379, 0.05670615326380357, 0.07409158599330112, 0.037247022628434934, 0.04629066723282449, 0.06757639028364792, 0.040225717675639316, 0.0214060400321614, 0.03927756464690901, 0.05299454656778835, 0.1572166825644672, 0.024152261030394584, 0.051792482554446906, 0.013555429359257687, 0.07857654767576605, 0.04037077786051668, 0.04139608827244956, 0.03537201620929409, 0.029614017075800803, 0.032815239537740126, 0.06273297127336264, 0.01706228678813204, 0.01465468365495326, 0.04342563952377532, 0.047959523581084795, 0.03607344224292319, 0.010501209653739352, 0.0736908930412028, 0.024214057812059764, 0.022748316150682513, 0.07551250935648568, 0.04446352562808897, 0.06596237493795343, 0.03853953217912931, 0.015492885650019161, 0.04561537964036688, 0.059601249085972086, 0.03529020556015894, 0.04396336262288969, 0.051046223379671574, 0.028080007105018012, 0.03105714735283982, 0.11868487243191339, 0.05848836895893328, 0.050552802786114626, 0.03620616793341469, 0.022345322540786583, 0.033532298912177794, 0.06080488645238802, 0.02432796078210231, 0.02723854337091325, 0.04995791576220654, 0.028096833448216785, 0.09379147304571234, 0.05804816406453028, 0.06522661715280265, 0.021356243778427597, 0.1125422868062742, 0.038756658614147455, 0.030956823829910718, 0.0459932997910073, 0.007915042078820989, 0.020770303344761487, 0.029312475053302478, 0.015858063125051558, 0.0031363668722406146, 0.01904019754874753, 0.04906924215902109, 0.03412821752135642, 0.04681134691054467, 0.027903481714020018, 0.012854446758865379, 0.09127798955887556, 0.05417188222054392, 0.019061586244788487, 0.011646140355878742, 0.0748363534512464, 0.027469709384604357, 0.06957504592719488, 0.02132626101229107, 0.038772035914007574, 0.035699830259545706, 0.06533073305035941, 0.010711521317716688, 0.04879179767158348, 0.044395084769348614, 0.02180555668019224, 0.015900324724498205, 0.05148829848621972, 0.032410075145890005, 0.03759725695999805, 0.05963009265542496, 0.05622109296382405, 0.04072222189279273, 0.09507846843916923, 0.045230097384774126, 0.055259707442019135, 0.00863796349221957, 0.04231150516716298, 0.05537257697142195, 0.068070489942329, 0.013899096611567074, 0.036961956284358166, 0.010347907918912824, 0.06347702626953833, 0.04936093588185031, 0.02168165327020688, 0.07830806833226234, 0.01608784317795653, 0.08560810005292296, 0.023822803123039193, 0.026731921825557947, 0.04667117747885641, 0.058184533700114116, 0.049434720203862526, 0.016725429668440484, 0.028240066094440408, 0.018106815114151686, 0.006096785373301827, 0.024839627076289617, 0.017776793174562044, 0.011474658786028158, 0.07991303689777851, 0.03498664118524175, 0.023276539759535808, 0.06222386167792138, 0.029464559665939305, 0.041578478485462256, 0.02659127741935663, 0.040553427825216204, 0.03813182964222506, 0.02858552285033511, 0.03930939536076039, 0.17435702844522893, 0.07771256161504425, 0.2757640869822353, 0.14911379548721015, 0.08189917251002043, 0.15167689154623076, 0.21011134347645566, 0.10098255006596446, 0.08652190648717806, 0.14181219041347504, 0.13564249413320795, 0.1470447619794868, 0.13676263246452436, 0.10944960900815204, 0.12368770476314239, 0.13396464666584507, 0.08725516323465854, 0.2062536746961996, 0.11725537726306356, 0.15310874674469233, 0.1346968050347641, 0.0908908927522134, 0.10762903912109323, 0.2166217300691642, 0.22479282051790506, 0.19899686565622687, 0.09762015353771858, 0.13300757302204147, 0.21053980017313734, 0.2021702445927076, 0.14681858505355194, 0.12898726999992505, 0.26005831256043166, 0.19963199563790113, 0.11581551429117098, 0.28856188931968063, 0.22036712674889714, 0.11154523366712965, 0.1687484106514603, 0.12523710873210803, 0.14564220677129924, 0.12229298663442023, 0.1326683966908604, 0.15696787013439462, 0.20828059874475002, 0.25467100320383906, 0.16186380351427943, 0.11676938185701147, 0.13048177730524912, 0.11481452034786344, 0.10055174818262458, 0.08421994993113913, 0.12115528166759759, 0.2068029678775929, 0.14463664119830355, 0.24645229656016454, 0.06550012825755402, 0.2282879946869798, 0.20756573241669685, 0.13173229614039883, 0.11439272813731804, 0.13939581695012748, 0.17734872963046655, 0.1345431210938841, 0.19894160534022376, 0.1716389274224639, 0.11946112921577878, 0.19316092802910134, 0.08623069516033866, 0.08229881161241792, 0.11778849162510596, 0.1112755668873433, 0.06928926712134853, 0.16936007392359897, 0.1357325611752458, 0.11213347475859337, 0.11210686876438558, 0.24039043433731422, 0.193252494209446, 0.13885792315704748, 0.1984797668410465, 0.11789218449848704, 0.13232711266027763, 0.13931760942796245, 0.07737505511613563, 0.2359807412722148, 0.20212911476846784, 0.12447930173948407, 0.09774510894203559, 0.11930866239708848, 0.17041386425262317, 0.12810654850909486, 0.10283058683853596, 0.1185083674499765, 0.11987114354269579, 0.1632408585282974, 0.13605098705738783, 0.24307724641403183, 0.26490124175325036, 0.2273958144360222, 0.17448124912334606, 0.07079009010340087, 0.16479411424370483, 0.13507639872841537, 0.14104099507676437, 0.20902371121337637, 0.15124831610592082, 0.11962627191678621, 0.17024232423864305, 0.09573814866598696, 0.19834993552649394, 0.1075595740985591, 0.12495966424467042, 0.1732646909658797, 0.06840962174464948, 0.16910419624764472, 0.09227950300555676, 0.09582123209838755, 0.18058403336908668, 0.12777357653249055, 0.05789235015981831, 0.08569310564780608, 0.11245346657233313, 0.08885518909664825, 0.12542815238703042, 0.1479168448713608, 0.14074809907469898, 0.12395806916174479, 0.14481882360996678, 0.1215529466571752, 0.16242526791756973, 0.19698257296113297, 0.10024769027950242, 0.19091894442681223, 0.2265573656768538, 0.18813161586876959, 0.1416807115310803, 0.15925129526294768, 0.1193143695127219, 0.17975147726247087, 0.1332780858501792, 0.06036566490365658, 0.16754654701799154, 0.12848069483879954, 0.16284992481814697, 0.06926243848283775, 0.16692189616151154, 0.14329688652651384, 0.18377563945250586, 0.10489278516615741, 0.2411488350480795, 0.17688908788841218, 0.16735865006921813, 0.08761775432503782, 0.06273980645346455, 0.16650758479954675, 0.14616369910072535, 0.1532088773092255, 0.16641710215480998, 0.11088006154750474, 0.12442632723832503, 0.11204602007637732, 0.08157097996445373, 0.09279046425945126, 0.1638022784027271, 0.16209484892897308, 0.12250433544977568, 0.07736111016129144, 0.12176293734228238, 0.13446218246826902, 0.08617896746727638, 0.14293247717432678, 0.13186788652092218, 0.2279975329292938, 0.12108863680623472], [0.029736742326349486, 0.06282973248744383, 0.024213208052970003, 0.07924215766252019, 0.02860789860278601, 0.0274604269725387, 0.05174289224669337, 0.00684033988363808, 0.06687713132123463, 0.02652140236023115, 0.012639138585655019, 0.024085057702905033, 0.03705167451698799, 0.031396765261888504, 0.043924603960476816, 0.029566681041615084, 0.06878288491861895, 0.04596684593707323, 0.040966703891172074, 0.029228193052404094, 0.08052998426137492, 0.05660528797307052, 0.023384615014947485, 0.019742313779715914, 0.023567884672957007, 0.03576469396648463, 0.06860807945486158, 0.036772523089894094, 0.009249962586181937, 0.07863721082685515, 0.021435111812024843, 0.07447943979059346, 0.05848619817697909, 0.0713491573696956, 0.040582898509455845, 0.03013323472259799, 0.06633414639509283, 0.02704621208977187, 0.0898684210551437, 0.02495396234735381, 0.017006150737870485, 0.036367785432958044, 0.023762603814247996, 0.02535874638851965, 0.006900597636558814, 0.05443478803499602, 0.03579153744794894, 0.05471289674460422, 0.01574233076098608, 0.03774238393816631, 0.053833329293411225, 0.037566005121334456, 0.05869765460374765, 0.01878051636595046, 0.0981707900064066, 0.025084238950512372, 0.05694097621017136, 0.05443873997137416, 0.0519607756723417, 0.03905815981852356, 0.021386252519732807, 0.03376322929398157, 0.03995285223936662, 0.01320719604336773, 0.016080597961263265, 0.03187384376360569, 0.043557378157856874, 0.040959623802336864, 0.04340248451626394, 0.038761708929087035, 0.085541299340548, 0.06083118074457161, 0.028329977285466157, 0.018311480889678933, 0.07044641635729931, 0.007460915421688696, 0.03763810847885907, 0.08598567510489374, 0.06749519190634601, 0.016753206400608178, 0.007624074269187986, 0.0530433130916208, 0.04033569653984159, 0.09040748002007604, 0.05256168522464577, 0.04432197580172215, 0.04875623395491857, 0.035559504976845346, 0.058602904609870166, 0.026023599384643603, 0.01725477948639309, 0.03727488285221625, 0.0296202585377614, 0.07629716725205071, 0.042177098512183875, 0.04933418887958396, 0.04988141146895941, 0.04090329479367938, 0.011191689009137917, 0.054045824726927094, 0.009673618515080307, 0.0811244074429851, 0.06896204678923823, 0.050939940410899, 0.05411517100583296, 0.07557242293842137, 0.06245963086257689, 0.03563299615052529, 0.07371582178166136, 0.02447300241328776, 0.02152368899260182, 0.05062393764092121, 0.006524224863824202, 0.049425458200857975, 0.011494916634546826, 0.07443938608048484, 0.008160794077411992, 0.0509490576951066, 0.041740411397768185, 0.022520205930049997, 0.043398450943641365, 0.03840431287244428, 0.04187601662124507, 0.039835585484979674, 0.0738397975510452, 0.02116117026162101, 0.07516640136600472, 0.04755730180477258, 0.04395760355691891, 0.01038297254126519, 0.02195766912336694, 0.029118562997609843, 0.06468290492193773, 0.060453242040239275, 0.008063109817157965, 0.03982094662205782, 0.03149449126794934, 0.048475921066710725, 0.013368553791224258, 0.02426865576126147, 0.07645788675290532, 0.06767254293663427, 0.022614761110162362, 0.05925576449953951, 0.014132893538771896, 0.02635827459016582, 0.04181441094260663, 0.028632955363718793, 0.053116232811589725, 0.01080723053746624, 0.030997009271231946, 0.12228477105963975, 0.031110700729186647, 0.028619669064937625, 0.017559559128130786, 0.04791207436937839, 0.028802558372262865, 0.10230801839497872, 0.024806911351333838, 0.08866038275300525, 0.04488178892643191, 0.026235458426526748, 0.013238141746114707, 0.07337495335377753, 0.043798680053441785, 0.05690735692041926, 0.01224602017828147, 0.0049844340264826315, 0.04473163018701598, 0.017620112812437583, 0.041969412195612676, 0.026899543299805373, 0.022408880067814607, 0.09020196448545903, 0.031122573236643802, 0.0498365523526445, 0.014899851212248905, 0.04686940512328874, 0.020780962440767325, 0.08058971972786821, 0.02504017949831905, 0.0337130044499645, 0.04555877603706904, 0.057138966367347166, 0.006288511804086738, 0.10301562651875429, 0.029468185057339724, 0.025621997301641386, 0.029618761254823767, 0.06127163796918467, 0.014867281133774668, 0.006332710872811731, 0.015288474060071167, 0.0497827280923957, 0.022056237467040773, 0.00442554580331489, 0.025672270385257434, 0.09780013177078217, 0.06261099930270575, 0.020801208229386248, 0.06698316938127391, 0.03626788122346625, 0.0108252545214782, 0.008884454855433432, 0.05623984332487453, 0.01680100442172261, 0.022718220207025297, 0.04500106690102257, 0.0740166290779598, 0.04028940878924914, 0.02127102852682583, 0.01317431240750011, 0.027303299466439057, 0.036222283670213073, 0.0593545629089931, 0.02582981720479438, 0.017127217288361862, 0.027614793689281214, 0.05581131983490195, 0.02901858457335038, 0.01464894499804359, 0.01781536815542495, 0.028940677620994393, 0.07808212147210725, 0.05757934195571579, 0.019128214407828636, 0.01150673626398202, 0.036409995082067326, 0.02823460388754029, 0.03864682817948051, 0.024708565651963, 0.020301095319155138, 0.07756664053886198, 0.027268390695098788, 0.08206064900150523, 0.03859079602989368, 0.022060371229599696, 0.05398779991082847, 0.022249448193178978, 0.02864803023840068, 0.017532845522509888, 0.044898939959239215, 0.026541538682067767, 0.02642722196469549, 0.02386751937592635, 0.024654995577293448, 0.030232359677029308, 0.02096854026603978, 0.03691937556141056, 0.02763826967566274, 0.022712522368237842, 0.05203725027968176, 0.07541617116658017, 0.12219736832776107, 0.025971292816393543, 0.019046470551984385, 0.042090972274309024, 0.006786913600080879, 0.03533004033670295, 0.07184561705798842, 0.027265874814474955, 0.04632374846551102, 0.04305721144191921, 0.024843230203259736, 0.06908379611559212, 0.04075570759596303, 0.01816447442251956, 0.011419127586123068, 0.036591702519217506, 0.09103858756134287, 0.03825791682174895, 0.007856632273615105, 0.0352588757959893, 0.02199271704739658, 0.06713827824569307, 0.01668234614044195, 0.02055313980235951, 0.01548114951219759, 0.015718687791377306, 0.02521276594052324, 0.019594015975599177, 0.05994219543936197, 0.02909580503910547, 0.05692732440365944, 0.04739472693472635, 0.042643438137019984, 0.03989903911133297, 0.0354874313052278, 0.07283401675522327, 0.020839811040787026, 0.05764147084846627, 0.1347890985198319, 0.003547283604348195, 0.001481956196585088, 0.014697640090162167, 0.016961371402430814, 0.05125123054313008, 0.001818128801005514, 0.0467941439274, 0.02559403503255453, 0.07088520374963991, 0.009866031432466116, 0.047066159604582936, 0.024598785312264226, 0.06035300757503137, 0.01969802240637364, 0.034253080157213844, 0.03908134080120362, 0.037913719861535355, 0.024825609762046952, 0.04666240158258006, 0.05194422948989086, 0.0058771912972588325, 0.03393033126485534, 0.026627099032339174, 0.03773005315451883, 0.016064706724137068, 0.03487458059680648, 0.03213961055735126, 0.07296647527255118, 0.010746056232164847, 0.0768690365657676, 0.06973167619435117, 0.0340203500672942, 0.06431108893593773, 0.044940815641894005, 0.03401632762688678, 0.05325714810169302, 0.08230553547036834, 0.06146870044176467, 0.048569825012236834, 0.05221131730650086, 0.017409389256499708, 0.12860780989285558, 0.007861220601625973, 0.04087937166332267, 0.012168050143372966, 0.04981531579687726, 0.0011914885249098006, 0.004476155172596918, 0.04378362558782101, 0.07434215731336735, 0.12162820785306394, 0.04161247255979106, 0.013000777871639002, 0.028952553839189932, 0.08891582998330705, 0.05946637858869508, 0.06077717465814203, 0.07579825847642496, 0.04401479716761969, 0.04423500351549592, 0.1347616984276101, 0.15612633404089138, 0.08554397849366069, 0.1774396575638093, 0.0979703656048514, 0.15326352906413376, 0.20620975439669564, 0.11656332455459051, 0.11369556203135289, 0.1311071406234987, 0.11123609947389923, 0.16401864413637668, 0.1402421621605754, 0.09163372320472263, 0.1306659635156393, 0.10156369622563943, 0.09970558108761907, 0.16785716550657526, 0.10218874784186482, 0.12655590515350923, 0.12761877937009558, 0.134626226790715, 0.21035723184468225, 0.10996996585163288, 0.17933292081579566, 0.16308263264363632, 0.15047332097310573, 0.14303498261142522, 0.16923873277846724, 0.12140632054070011, 0.14177650795318186, 0.4079434083541855, 0.18993812205735594, 0.14520433964207768, 0.10387339338194579, 0.0983532470127102, 0.14195227820891887, 0.12526767037343234, 0.1677121498505585, 0.12336522675468586, 0.08966341760242358, 0.08414078503847122, 0.0918915230431594, 0.09522254898911342, 0.08295926367281936, 0.1453727181069553, 0.15852572716539726, 0.12906996009405702, 0.14924696646630764, 0.23753620858769864, 0.17759377195034176, 0.14415412646485493, 0.13502786227036268, 0.11695414694258943, 0.14700468600494787, 0.18919164023827761, 0.1910367826349102, 0.12324377428740263, 0.11292407725704834, 0.18941049958812073, 0.16051779995905235, 0.14118678256636485, 0.07807545698597096, 0.17457434412790462, 0.10743616236140952, 0.0928481291339267, 0.15051025024149567, 0.14552085078321397, 0.13721289345994592, 0.11478004016680643, 0.18392343074083328, 0.18349430611124262, 0.09833798103500158, 0.2035938174230978, 0.17310573777649552, 0.2375664733699523, 0.15411275380756706, 0.282955527654849, 0.152339955966454, 0.06928904447704554, 0.07785008157952689, 0.13127958605764434, 0.15037670818855986, 0.22620719071710482, 0.11295552947558463, 0.14069861266762018, 0.1425771220237948, 0.07376517460215837, 0.10301251691998914, 0.14715002820594236, 0.12150822483818047, 0.10411181574454531, 0.06859208617242984, 0.16434766788734123, 0.1329664431978017, 0.1244880368176382, 0.2051024403772317, 0.15165226708631963, 0.1627332592033781, 0.16076552885351703, 0.10545335899223574, 0.11184160292032175, 0.14378548687091097, 0.13942703168140724, 0.1111689351091627, 0.2058931690407917, 0.10769024403998628, 0.13634548609843478, 0.18053260253509507, 0.15582096995785832, 0.1142294036981184, 0.10187657084316015, 0.08383576234336942, 0.1798226046958007, 0.17202284041559324, 0.20263920770958066, 0.12251341933733784, 0.11168535856995732, 0.22170477372128516, 0.14172543335007504, 0.10106258327141404, 0.09486049966653809, 0.15485760290175676, 0.10469235334312543, 0.16802217462100089, 0.14407194103114307, 0.20387005963129923, 0.16362870490411296, 0.08525989920599386, 0.1317772554466501, 0.09033290902152658, 0.120584896649234, 0.15367531712399796, 0.16597019566688687, 0.14474903204245493, 0.12064475085935555, 0.12569024926051497, 0.1598397144698538, 0.1363710901932791, 0.13269480230519548, 0.12430146089172922, 0.18659756693523377, 0.07025896469713189, 0.20782175852218643, 0.07613205423695035, 0.11648424129816703, 0.12614055478479713, 0.09764459246071056, 0.20423751178896055, 0.061498375216615386, 0.13640442746691406, 0.20499221660429612, 0.20973419887013733, 0.22076068766182289, 0.279973340802826, 0.15909474663203582, 0.07383882533758879, 0.2718211751198396, 0.18065809970721602, 0.14346038165967911, 0.10764736274722964, 0.16635853186016902, 0.11740106085198931, 0.1741066129761748, 0.07381642732070759, 0.12138177029555663, 0.1408688465016894, 0.1052451271971222, 0.21451452048495412, 0.06500530129414983, 0.12931871315231547, 0.14892125269398093, 0.13879978330805898, 0.10193926747888327, 0.15279778686817735, 0.14758884528419003], [0.055520045425510034, 0.010796570513775805, 0.024887491890694946, 0.030448740253632423, 0.03752820011868607, 0.02365056920098141, 0.04862991670961492, 0.008986889788502594, 0.03321375057566911, 0.0345466923317872, 0.016899678521440364, 0.11950893836910836, 0.028881239013571758, 0.10748349654022604, 0.0658729906717781, 0.04420946250320412, 0.03268460299295839, 0.04152438334131148, 0.03175208330503665, 0.018332988329348154, 0.11504056368721649, 0.034593243544804864, 0.005555570469368831, 0.010138237284991192, 0.060823473540949635, 0.009534143919154303, 0.046329266333486885, 0.04109410467208363, 0.02994562721141847, 0.04944246080412995, 0.042343669847468846, 0.026696623426687438, 0.03714890328410547, 0.030218077044992242, 0.031568579870508984, 0.016103597117762547, 0.018798138662532438, 0.08175108436262235, 0.0256930597970495, 0.04125329534872435, 0.031838606591918506, 0.10802970980876125, 0.027819442766485736, 0.030292996852949727, 0.071339197747875, 0.0029411224295472493, 0.030360966447915416, 0.0344623917771969, 0.029710850649280474, 0.029668175302504096, 0.08716548953088932, 0.027991821407340467, 0.05095771855849307, 0.02762644911854295, 0.03397379143279977, 0.03544084669556469, 0.01684496925008716, 0.0278377534050378, 0.06201790085469838, 0.08768734551267698, 0.01369817960949149, 0.023253828185261227, 0.10508142426260747, 0.04329859868448693, 0.05329181381966919, 0.0454046802042285, 0.11896634678123519, 0.020655795524362475, 0.022511366951221135, 0.030544573783117812, 0.013099287771183299, 0.01950430145370774, 0.05932956366450526, 0.009954104880307568, 0.010965196670440491, 0.05902356875594705, 0.05893214729439933, 0.025492984204902314, 0.035549070380511694, 0.005219203630986158, 0.007007617650742759, 0.055595269514014944, 0.009630525710235815, 0.027654123805405106, 0.05682136055838782, 0.06015958162606694, 0.01575763941218611, 0.034920029720524326, 0.03529924862959888, 0.09904529229970649, 0.03741945321962703, 0.03567444880900439, 0.020532864327833522, 0.024906702383304946, 0.015545871283393353, 0.04303852416342124, 0.020736652513733134, 0.07086786717991345, 0.03745333226106595, 0.022858751435705926, 0.022868983796797693, 0.036690679044113494, 0.027667109534377232, 0.01633259791560704, 0.026260457671014592, 0.020047761354362592, 0.02811729074892355, 0.050674711674219, 0.03375388936547097, 0.0729633063019719, 0.013646754341607448, 0.004081661936652381, 0.026496445789234713, 0.060222820029594004, 0.02876383496186463, 0.024525260741938837, 0.025224681121471804, 0.03378281828190666, 0.03922800031432416, 0.014854020810162183, 0.013211352070356952, 0.04142428246268537, 0.08394174103159457, 0.03789094706007745, 0.02855897808331065, 0.018551591638242826, 0.07006181316683069, 0.03930130224034656, 0.027224915684200823, 0.05170730255485978, 0.019045539156650193, 0.041684627867653035, 0.023358057260338683, 0.01619035789190093, 0.0071981598921411205, 0.014609845875384053, 0.019769261161854956, 0.034034810814773664, 0.1247623420204036, 0.017509033714304678, 0.038048582937335595, 0.025828720681602135, 0.026596849093039054, 0.03825163083092775, 0.04176206355623435, 0.017566865572007373, 0.017531439152662642, 0.01068433830369031, 0.03263704616983887, 0.027788218758360017, 0.09563581392285414, 0.11294383322820067, 0.031474423594772816, 0.05654416097968351, 0.03297677540103905, 0.026368818653281778, 0.025032051125890575, 0.07275799856870435, 0.06538155532325618, 0.04954231306328438, 0.030431537270487752, 0.024551454844186082, 0.047904255843604915, 0.036436745795072056, 0.035310032035340555, 0.04207860809401609, 0.029297873297764454, 0.04119619450648315, 0.010558490466792136, 0.031772240035934374, 0.01578254217747599, 0.0828349836228881, 0.07445980998454615, 0.03650511986052152, 0.03608934275689535, 0.06598204185138457, 0.04025603811896872, 0.03520184545777738, 0.016180550410354044, 0.05143107147887349, 0.023157117066148203, 0.013253151682874886, 0.036217155429767445, 0.08778335715760477, 0.07826377695892006, 0.06388301815604791, 0.019329924580233637, 0.04609112969774287, 0.0507360835763393, 0.0636492193734739, 0.009036634091899032, 0.004851315925407107, 0.03647235775133595, 0.015983606681402307, 0.035167688110959716, 0.011304677282168996, 0.03128182142972946, 0.04408310443977825, 0.012848106034653028, 0.004392442770040361, 0.056071513099595904, 0.004189172232145211, 0.03349611550220288, 0.027488287196320016, 0.04467094477149658, 0.01579476349434117, 0.02392590784438653, 0.023975936019269284, 0.046307888769661076, 0.006228272141015623, 0.08562387811252847, 0.022433588019339368, 0.033017934911185876, 0.023882213899923954, 0.025737521864357404, 0.08094272227026522, 0.04121169426070992, 0.012882577866548672, 0.021329225892259274, 0.04955601310939528, 0.03896693502611015, 0.03196222613041755, 0.03458905041043181, 0.033057524778996594, 0.06295302548096515, 0.04867802643275354, 0.05306539940647781, 0.06817580811912194, 0.07796656165737659, 0.059973833194817416, 0.030585970780521166, 0.043665479388437234, 0.05691667087376118, 0.004171240088908235, 0.12065635804901831, 0.036903122527292, 0.008160189227055525, 0.04382708946650382, 0.08891947392839938, 0.04707640124252066, 0.040555093946750276, 0.029565625336545054, 0.044907088740728796, 0.03157339269819204, 0.06282753573032096, 0.011481944820843637, 0.005406840828072745, 0.026729003329819534, 0.04510269660386257, 0.024291198496939614, 0.03483571061224211, 0.04404933672049083, 0.04179727104201447, 0.044458030024543405, 0.09072554967133328, 0.024159741878975183, 0.0402443789789686, 0.03516856384521816, 0.08795998830464669, 0.0738185943919234, 0.012129090173402801, 0.10758489617728628, 0.038688514614477754, 0.06028268166119233, 0.051689350002561696, 0.005327368871803628, 0.025289127370342612, 0.03446105220064055, 0.01831130462960573, 0.09343789904960431, 0.0543052313150838, 0.03655980501207523, 0.03883107376168482, 0.014361314533744007, 0.06824939206126146, 0.04070343071362004, 0.017587970396562014, 0.040139327975339256, 0.06494337649201043, 0.020050128805451095, 0.02722760782489786, 0.010319731354684336, 0.06315254446235485, 0.0333225976646645, 0.01939853984367801, 0.02030196919804439, 0.015212046764645493, 0.11209916527150199, 0.04682346247136593, 0.008317932715726783, 0.01601226471393602, 0.07412917577312328, 0.030717091576661915, 0.0401458477426786, 0.023723065896774642, 0.044799180468544364, 0.027522448253876064, 0.031106989990803413, 0.08605925904703327, 0.026569057517917827, 0.09691822284366935, 0.022280781668087002, 0.06602900495636277, 0.03737526945769787, 0.033282336153206415, 0.020221188278810587, 0.007483337094527087, 0.034186646807938814, 0.039979584398679435, 0.005739764565078076, 0.017876448764582165, 0.022069559017836582, 0.014827245049673365, 0.04117241238418501, 0.03709150187205523, 0.02080903788737487, 0.015196668537100777, 0.07483440160285681, 0.05418401262431871, 0.014951474076951854, 0.10367254595621489, 0.016078462431323715, 0.022945376767893322, 0.036944419334759004, 0.03745540656382218, 0.0037381389392976416, 0.06418743229005486, 0.08271938670077361, 0.0464848056435585, 0.09916268521919847, 0.022936903296795208, 0.022965086354815867, 0.01095093723051832, 0.05397595894464757, 0.05491601143148728, 0.06923368026036769, 0.03500146558508277, 0.038889284114702605, 0.07646958300028928, 0.03000339598656865, 0.016219978861045092, 0.029462583697750233, 0.07171021221438423, 0.09064209516509436, 0.0577185503061628, 0.01460736988519784, 0.04131015499297064, 0.16508053871802986, 0.04415728952153586, 0.06618624378461391, 0.025893743950291537, 0.04582005654810928, 0.18616765562910587, 0.20989062875742093, 0.10343139249016531, 0.20208748028380796, 0.07954564411193132, 0.16867011407157406, 0.09767141367774457, 0.1369077668641694, 0.12323449744144455, 0.2199257566826418, 0.07478592451661825, 0.18069890298647806, 0.12494382681325078, 0.2307843865128234, 0.12358615669654682, 0.1945543845067732, 0.12909093318739906, 0.083924471255159, 0.16712034645024687, 0.13467422890244052, 0.2384600933874026, 0.1317927218042314, 0.09905435392283835, 0.140956093382556, 0.1764833409106359, 0.12516163231339306, 0.1276205011527054, 0.16293487104121596, 0.10229885287117213, 0.13245786423794925, 0.15810610202606767, 0.20887498481897637, 0.1602003982407041, 0.13597715820651501, 0.08028582509723492, 0.11287750006886199, 0.09744594179210253, 0.18358989473199472, 0.0927081452391576, 0.1783723442349583, 0.10962870408548042, 0.20944109506672248, 0.14808961685048416, 0.23896135477116331, 0.12445252505131066, 0.10599681889289059, 0.16935410705627874, 0.10202762758126482, 0.09734859428135678, 0.10676611433154903, 0.2113286586245522, 0.13065511331660673, 0.2160385058959946, 0.16691791824996471, 0.12063167421729304, 0.09493372737779282, 0.14492508431430906, 0.07575645329779945, 0.2621537516824901, 0.2274566557025537, 0.09937990442267619, 0.099452493886929, 0.21676192176528275, 0.19684497878188267, 0.12038024942739867, 0.12274720327695832, 0.19218378671212122, 0.10362804678152315, 0.12964769237441942, 0.09146904805675149, 0.08290007739560679, 0.10486927392776124, 0.169029061216861, 0.14355617808178067, 0.09669365637819283, 0.17351791175315157, 0.14116195030510426, 0.17125351529102772, 0.2428528357995674, 0.09133649306022562, 0.12235346424859017, 0.14152739866403863, 0.14754176343558356, 0.16539813339477405, 0.14077554369578138, 0.22706940304487944, 0.10175295872613788, 0.1261936777154915, 0.15452100924449041, 0.17496406071586534, 0.11436782908276655, 0.1067064308153931, 0.060893992413184606, 0.19425731763476506, 0.15734358981717378, 0.13345453888177872, 0.09612816211301833, 0.20330294006271288, 0.1298042558482848, 0.16265623911749572, 0.13522206747438759, 0.19459101691609249, 0.12833358632633463, 0.10356696802773513, 0.13128338585374877, 0.08414251424255781, 0.15687924285884947, 0.11167904289322905, 0.1224130587070249, 0.14821892866166309, 0.11260292027145624, 0.2192914133775048, 0.16485311498399824, 0.14527319610351697, 0.1920064727892168, 0.16620697046164423, 0.1069064173498191, 0.15052215429022908, 0.15898525016382337, 0.1424247442628257, 0.08309607117553242, 0.0888779952947516, 0.17214370658621192, 0.09606443389202468, 0.18939343019155785, 0.10268769372487441, 0.13732777792029083, 0.11879775309353136, 0.06518968046293594, 0.1618620817316696, 0.1305369337205775, 0.142026700777933, 0.0909766998665873, 0.0932536312029697, 0.06937403522897512, 0.11898588010808453, 0.17624546773731709, 0.16267838480416685, 0.32113391964230686, 0.1331417978508398, 0.11970623832894489, 0.15425077843246982, 0.26537814585026354, 0.08006364092580043, 0.28640725649893284, 0.17996153474086896, 0.11428468627855182, 0.22227033477975056, 0.13234395941253752, 0.08990500151412562, 0.12866102188127115, 0.17590428760740906, 0.22341107513057068, 0.17634690448176116, 0.08495885442243889, 0.12740882579237223, 0.06335120255243964, 0.14614324551075697, 0.23232100327732041, 0.11309339082799852, 0.09602854363038205, 0.1636479710577987, 0.1260231321793981, 0.08317288346006535, 0.18477822159184143, 0.14305554010206833, 0.1318482047645375, 0.17280360945733264, 0.13913872215198353, 0.16497911681653932, 0.1525888277683407, 0.2224030753131956, 0.1577119473950006, 0.1370390527881682, 0.1659417714108713, 0.16637371620163321], [0.01283252928260481, 0.031852009778958745, 0.07678797177504748, 0.039265712548512965, 0.056515729302191176, 0.024352332911803387, 0.04449607993592508, 0.006828741970821284, 0.009698716094135307, 0.06515417611808516, 0.0386966262885835, 0.04973820294253528, 0.05155857616045978, 0.03781968232942745, 0.001698122478046571, 0.039732957593514584, 0.052067945507587865, 0.059733058224082924, 0.08179487849702127, 0.042838986628339626, 0.03162463799526449, 0.01349766893326887, 0.03303999896161258, 0.13734578242292628, 0.030518344428855926, 0.01429090327292215, 0.009705382435640786, 0.01543572821901762, 0.04728851818072144, 0.027766559178417083, 0.0266642082715407, 0.08359797822777182, 0.03589642517908942, 0.030345297855092213, 0.02078420191537589, 0.06936917416169308, 0.022698326938552782, 0.012576365879795048, 0.015519166026933817, 0.07015200637397356, 0.03890033840434626, 0.03907262427674141, 0.006326215225271881, 0.020686277384811547, 0.009972814423235832, 0.04575698512780946, 0.04823621107789222, 0.03368904421222396, 0.08318132910062559, 0.026053257461171597, 0.025193115725414827, 0.03380245922016911, 0.0331156200991245, 0.01668280441663228, 0.04286173716536723, 0.038490925217047334, 0.02939339326985646, 0.07722704118350521, 0.08514537839801051, 0.03383633455086965, 0.032860866776900366, 0.032025946929934435, 0.08533335698302835, 0.03181381143804174, 0.024149850905814674, 0.024113045947160572, 0.04775021196110174, 0.06147331288957503, 0.03366856093634851, 0.08058965293457732, 0.08231642277678475, 0.03227459979825653, 0.04598135121341329, 0.03266816813265905, 0.040052385375020094, 0.04459462230443023, 0.0032509551692783134, 0.04165556536463555, 0.04882517947407905, 0.015976175927789882, 0.05082076633698307, 0.038421189310611226, 0.01022876816932694, 0.07777494654874317, 0.029657835329999216, 0.04736710419820156, 0.05949447258899454, 0.016896327724680305, 0.02605921690701507, 0.01860990589193534, 0.015548299033980584, 0.08771639317274094, 0.0371677093062317, 0.008310404555231798, 0.024684312265890185, 0.08880467852577567, 0.028620403791137505, 0.026039230870082974, 0.02587792321719462, 0.024758135550655425, 0.04943532505421899, 0.03247310945880599, 0.04491320032684598, 0.04129960165300872, 0.03498825535643846, 0.05755262835009489, 0.05172898439923301, 0.04239120440615807, 0.029460585465130862, 0.08063490909989923, 0.009972652078431565, 0.05626169957395177, 0.06169278080051299, 0.024085167169687338, 0.007472445149687701, 0.06455663591623306, 0.04196932313789148, 0.03373796658706851, 0.047434910520678386, 0.03993784972408321, 0.045795495170750655, 0.09088318925932981, 0.02158291608793661, 0.006585559194718371, 0.039284830272663385, 0.07705185722443275, 0.07963881333125755, 0.014504829196084756, 0.0503045098594157, 0.06991675298195332, 0.09125556927756406, 0.04169161147729028, 0.019813751059700735, 0.030314984833239578, 0.042344816465629265, 0.013286896210047416, 0.051210041347076185, 0.06534346830449067, 0.022419516899390146, 0.05628748178423848, 0.037899077287875116, 0.0338513519091066, 0.0880661747942213, 0.05733569858421106, 0.037549581393250264, 0.0123112141409365, 0.06854025457869284, 0.010827712885657093, 0.049904996922123246, 0.05934249558777083, 0.031330584242823534, 0.035290558080305345, 0.03751347219804302, 0.030706662546435837, 0.01835840317653492, 0.033672624194878154, 0.04755513102281839, 0.04299952430301346, 0.0545903125021141, 0.013851793046342209, 0.056974276376422495, 0.02237022345070727, 0.025625550333643332, 0.04860786008066498, 0.042718328259070404, 0.04458414317923598, 0.03109323799435515, 0.04902502871118486, 0.06032459074049257, 0.06890222226502374, 0.07142116053728387, 0.027069261341239326, 0.07674132037209347, 0.024793387565296143, 0.05023844016250223, 0.0963824887003284, 0.04378557001473382, 0.038441743090515956, 0.04381029837531969, 0.07275494092027657, 0.04557816093438305, 0.032307606816175394, 0.040347359390580095, 0.01143725083238678, 0.06155887138447724, 0.030244798072089907, 0.010023355607700069, 0.05689912650268525, 0.06235589346033521, 0.046189779677661136, 0.026809780538314953, 0.01918673460750142, 0.024460821914544795, 0.04393389564938843, 0.04996605341148097, 0.03306376253021881, 0.036053315197932534, 0.056378008957835846, 0.015440067927556811, 0.015404054283862934, 0.050807700827135704, 0.025413398143427912, 0.018327138350286987, 0.046428120404016227, 0.023796464301995, 0.01972003636183217, 0.031073446771188173, 0.025111729955824558, 0.023967252891452517, 0.07449251643265598, 0.008356377820746275, 0.028791194235964213, 0.03482644860923756, 0.021343413900467567, 0.0292912236545817, 0.009519208197161788, 0.04008422351034824, 0.023958690362633206, 0.017397615083609708, 0.050370854150969535, 0.018349981655774172, 0.04670638496463653, 0.05126294905494433, 0.03194679316948168, 0.023402289261866827, 0.05034089364926331, 0.013408843133220216, 0.032245489055640064, 0.06670827788184397, 0.017866281341412105, 0.06990366891841404, 0.028947713180969004, 0.03792495968809817, 0.029874037791159935, 0.04465193094802089, 0.061997866578167304, 0.01610038732906105, 0.026096610017702915, 0.10418215650133789, 0.03347954334458336, 0.04664767737267539, 0.01309073359152535, 0.027770919296017382, 0.008503527151333401, 0.03429667391174007, 0.04721990291727707, 0.0568823168578092, 0.058024203826789744, 0.014721992738486733, 0.04487355108722113, 0.04790530598256737, 0.05172337005205918, 0.07524431202909909, 0.025662550106062554, 0.07237255675136112, 0.04089456342626363, 0.025133246672339737, 0.03793349809711799, 0.009423414558114018, 0.09109774415264837, 0.0040416397678200155, 0.008921153130359016, 0.07386264085653238, 0.02620893035782501, 0.06029252253938466, 0.0048803478148329305, 0.019455121182545554, 0.02537830197979929, 0.038639031918137334, 0.035878587659681216, 0.032553855126025155, 0.09551769369863905, 0.006639366292802151, 0.03761136147659272, 0.09398033478646539, 0.03437075138208456, 0.052997882521594875, 0.05543705105083063, 0.04402945458423346, 0.009238379516318673, 0.05711328434699681, 0.03885185389663093, 0.08639548163046129, 0.012288873640500242, 0.048756215401226655, 0.02521439495467348, 0.0024330221549462294, 0.01203095320306602, 0.03580314834835008, 0.040943534040707164, 0.0879361059924122, 0.05851397305377759, 0.04291836674383376, 0.04673174786148593, 0.07737491410807706, 0.04312207143811975, 0.05803166612167843, 0.04936042008921504, 0.012620724974112818, 0.053219354231259786, 0.07569392735604197, 0.017855655642051715, 0.04632309537555557, 0.02487566391209839, 0.09333830283139832, 0.07679711503442377, 0.06263569055590779, 0.01193854561279295, 0.006485829389930586, 0.038724686892237514, 0.0738877551339101, 0.049167346660397016, 0.03724603186128661, 0.053999763331376016, 0.03209276619600132, 0.024849262008501682, 0.06361828665831126, 0.017837376544775907, 0.00563666216294223, 0.0857593200635165, 0.025486911581538152, 0.07004114435403608, 0.025171318848151714, 0.04439678057678975, 0.01157670409156708, 0.037250696259434335, 0.045172165337135084, 0.03432423356571235, 0.009155104980891338, 0.04054689692566171, 0.023987426320672967, 0.09342976511106826, 0.05334773464710452, 0.0913655778276734, 0.04621915388270281, 0.015665991595597006, 0.0744306955311913, 0.04713712005468551, 0.031293198553612456, 0.03548511209373828, 0.056340860755881295, 0.033851567131932825, 0.08915258993511088, 0.043537239980651066, 0.03778335791139398, 0.045805799891240895, 0.0515504273789702, 0.0689034022798296, 0.06534280779305845, 0.018929765974462498, 0.044138913945062086, 0.022908620048838202, 0.32281722931656986, 0.06000697751005646, 0.2911242877598852, 0.26233637938275933, 0.09794684694497846, 0.14295359869720414, 0.1920203657937236, 0.06024955218890682, 0.14701621897984296, 0.09614301248802803, 0.2042216298286803, 0.15903642866760492, 0.21892171993386, 0.1749197841854766, 0.09169518045382574, 0.1063829286431428, 0.1236227891058661, 0.11513815610669553, 0.16620823211269453, 0.09425573094631545, 0.12957983039086685, 0.16161463485332206, 0.19311354932142422, 0.22346948215272278, 0.1487510633887723, 0.1968615286750719, 0.10192252462729812, 0.10770637833047658, 0.1438179929391481, 0.05381079768994823, 0.15544519090326503, 0.12925316666951403, 0.1546210507513024, 0.23379542806651443, 0.09123637733864598, 0.09883703081868589, 0.1228567591169849, 0.13953627581940964, 0.15490878140553832, 0.12325266521656886, 0.1710477177402936, 0.14314970379928127, 0.1045756580424495, 0.18987688003107905, 0.13918415643274784, 0.15487110998947173, 0.10445743391755968, 0.18858045194065198, 0.186658957391046, 0.1230575842782855, 0.07308216125238687, 0.11017241631634533, 0.12349971875664778, 0.16916545311687514, 0.17916697659529746, 0.10729516914580017, 0.1633471786044538, 0.19748616468859836, 0.14044095383724198, 0.15811487421160564, 0.08412104391027242, 0.08733512964681722, 0.20100824913242832, 0.13148103462299332, 0.1166319138428662, 0.13212702964665368, 0.17917108809342608, 0.09944777382770553, 0.1457965438021347, 0.172182506066747, 0.11492541205370799, 0.15613154391758144, 0.15301767038181424, 0.1715905690798536, 0.21375230513513088, 0.14951180928619578, 0.15111014305148274, 0.12967291055247188, 0.16961105342488736, 0.1083665706391912, 0.22208763286471367, 0.16618031251709908, 0.0645084037387278, 0.29328842007089406, 0.1332756070769392, 0.1437631482258439, 0.23326574242673814, 0.13008316978812218, 0.1289686866221018, 0.13536193262552842, 0.1960999664152041, 0.2534344367450103, 0.15215807041386142, 0.10385235349531285, 0.09197867344482802, 0.23223682888783514, 0.09291575363022275, 0.13364834332605824, 0.21612671756884083, 0.09136060543823987, 0.11472309517557733, 0.16092359146568924, 0.09967473743017763, 0.12915131432237104, 0.10343446498154663, 0.1061563435359858, 0.15412041277159005, 0.1300690244534053, 0.11628119711531326, 0.10937816245132126, 0.11972423541010357, 0.067408880131552, 0.16939574154093862, 0.09011656555230729, 0.16893789579626173, 0.1433551451191306, 0.2640887978486717, 0.101431000221055, 0.20735116268042475, 0.1528348051942885, 0.17709782434394583, 0.14131708885543048, 0.11268155823927373, 0.10106822359375656, 0.08884715163731016, 0.12442793027730659, 0.13801264663925394, 0.13165475655114278, 0.1603368643554859, 0.2705290069570765, 0.2557138988049701, 0.09256367877242155, 0.10254253706079908, 0.12985972396563739, 0.23785651952493936, 0.10111184703418985, 0.1093607368238736, 0.1530725447810255, 0.09423182636965066, 0.14531347987940535, 0.1845776487607509, 0.1570990076288581, 0.1420319254975766, 0.24860648409230635, 0.1530736283166334, 0.18267475243192166, 0.15629753266694024, 0.15009182738140225, 0.07718470908002928, 0.15627789543941617, 0.17604300985112786, 0.15175003762124106, 0.09059293530299328, 0.10630283606587909, 0.10522069569560699, 0.11319853088934906, 0.19944050669437274, 0.14185581385390833, 0.17827216914156452, 0.18666544376173988, 0.13793390477076173, 0.12673259567236528, 0.1639433013042435, 0.09607999672880396, 0.11780328262830153, 0.2159060028498061, 0.2126208713161759, 0.1659382981597446, 0.21735598129453138, 0.1405961814452894, 0.14689936040667817, 0.20441210945136845, 0.18921617564046755, 0.10400695027783513, 0.11645537917502224, 0.1514458016026765], [0.016030725637392607, 0.04607283575751353, 0.007994237585080555, 0.042836700813495554, 0.03622310745413415, 0.05024216945457738, 0.026309534041502047, 0.013897517692385009, 0.030716954279341735, 0.05673045488947537, 0.0390802609763341, 0.032536674407310784, 0.02084480755002005, 0.026987656638084445, 0.020491634313657414, 0.01667072039708728, 0.0647932622814551, 0.10470200126292184, 0.068919915065635, 0.016728418668208178, 0.05383305098803248, 0.008591352907387773, 0.10230484200292267, 0.018921106966445222, 0.02170889565604739, 0.031959342886693776, 0.03615202454966493, 0.02867297938792035, 0.04663887921196874, 0.024849870569596533, 0.03852297115372494, 0.06900437889271416, 0.05323857956682332, 0.026095622961292975, 0.06032378179952502, 0.04834121384192258, 0.019074805750278756, 0.10513551198528148, 0.028227061811776366, 0.130340205214452, 0.054010227613616735, 0.08335975624504499, 0.0071168334943649825, 0.03906318044755608, 0.050232514113304205, 0.032240761574939825, 0.030439665642916225, 0.0270289423133363, 0.05653863940096926, 0.050170945542049594, 0.05122401227708906, 0.06641304411459714, 0.030395977264561225, 0.019185732708137948, 0.051871020332328044, 0.06674707736237906, 0.024790164789010305, 0.04208628190099262, 0.020373174556880258, 0.05876200622878969, 0.06978233519475907, 0.09453922393731773, 0.053132207540329546, 0.053442098724190146, 0.019503438707033638, 0.01984874517802382, 0.05376259519835003, 0.027549484693736304, 0.018713671124714892, 0.08272747611044906, 0.09405479446286336, 0.037615669643855654, 0.039594765985384583, 0.04599750776833389, 0.05556143500143662, 0.03642255593149457, 0.06959684280445799, 0.04567733783915173, 0.0964691121771466, 0.051127841070410796, 0.0098994540530839, 0.01838846943428507, 0.03328018392494414, 0.05714419479772914, 0.028834242511948105, 0.06082358115236275, 0.03766146757698152, 0.020111270641791634, 0.04202811607683543, 0.06690574111416936, 0.08107589324936271, 0.036478996262303554, 0.05432673504401464, 0.03845986633677967, 0.03672937833471224, 0.025389426773472223, 0.0642117895768024, 0.02890964471589541, 0.046895996274542995, 0.04337386730185244, 0.06258794077439234, 0.011891629819729133, 0.17944219463970512, 0.05033274115703534, 0.024210768242483027, 0.014265634999901522, 0.012404067019815557, 0.038979792734608054, 0.025757383591553662, 0.04691705842560623, 0.06300423367065378, 0.07835126132704318, 0.021286006922309753, 0.07039844393148087, 0.07911544336820953, 0.009660948198870756, 0.04414111070218496, 0.039521026192232966, 0.03779532133194152, 0.018248875167046208, 0.03637520319898613, 0.01905713706946699, 0.02683877624804154, 0.038730768792447634, 0.058245159743819386, 0.06005507610097993, 0.044800408722949214, 0.02266339404741302, 0.0510229125211481, 0.03351908868353348, 0.04051420903124381, 0.02266563162265811, 0.04951402610458899, 0.020033454602526035, 0.09695449902210385, 0.031759950070409104, 0.04057896512676962, 0.016771197915659286, 0.037923942945781164, 0.05084133867057972, 0.009803526827454334, 0.05157527448318433, 0.02555366405431414, 0.035582066266215406, 0.01926676410221262, 0.015119532490643905, 0.04350813294877298, 0.016534345195395872, 0.038930425071157515, 0.07117987348465249, 0.04584690002957359, 0.0557276501058368, 0.013178385870560305, 0.059793947730213404, 0.012126386900490616, 0.04181635536951944, 0.02805146596074337, 0.01879673971416196, 0.022990972465777304, 0.029614000377478078, 0.021474072709679604, 0.014694150140712736, 0.02770175113255391, 0.007072448888720828, 0.02794170974084409, 0.009544253825879423, 0.024611175467725843, 0.020286951839807443, 0.025408615001651924, 0.04245866562996525, 0.04577316765789874, 0.05441275367047638, 0.0328541317867348, 0.020499219062912744, 0.046434131800197065, 0.011576224478631048, 0.038602414351771586, 0.012859356993430993, 0.00845248687255662, 0.01212102766658063, 0.07979663103469647, 0.027439941841294058, 0.05367584184568841, 0.03914331755368039, 0.03505741238768678, 0.024459845990350004, 0.01851737491961103, 0.023847787524573505, 0.060027100844308734, 0.021862609282834455, 0.01421347036739462, 0.029415720782708377, 0.0514208001550287, 0.06332957636914216, 0.026681658018787857, 0.01332065558017348, 0.010691615989344427, 0.053876065867370926, 0.07318719741306268, 0.022955280728638172, 0.031145180910243653, 0.05513149400940165, 0.06882260466227308, 0.06920461033587344, 0.0388957704853965, 0.03307110979221761, 0.010723225914262002, 0.06611290475120768, 0.11060408651246689, 0.03214921394828707, 0.05914849076361861, 0.04162288118095603, 0.02311404467036482, 0.05279964745568577, 0.02967732412798796, 0.027050672397308517, 0.023419905992341228, 0.06849009281722829, 0.033876584930112585, 0.018285156911588274, 0.0622409644711297, 0.04686382788349874, 0.03141205721476581, 0.041565795181668364, 0.03490209943265654, 0.026503139961278066, 0.03181341067829635, 0.027353561417839956, 0.029310486097529065, 0.023729745225864463, 0.052975621802033857, 0.06915173231391236, 0.039618214141228236, 0.00046813886910967994, 0.0727175292558968, 0.05238129881036002, 0.041218206606572494, 0.01969333017768804, 0.02070431157335406, 0.025003784576256294, 0.06826087308581918, 0.03628062018833589, 0.029285386663104873, 0.009922824283421505, 0.028145824471721426, 0.019479541551845614, 0.05846636056958232, 0.025183614379784558, 0.050098793944926, 0.02801670376356924, 0.04639505030354485, 0.09767188865225762, 0.013054635528533254, 0.023688472538196947, 0.01710785465547815, 0.016621258109807968, 0.02995638278662227, 0.058368270911159925, 0.00574007580325997, 0.040452351022395305, 0.0808366693672724, 0.01386703490425134, 0.06775673216907308, 0.04385715386888478, 0.03915886925824452, 0.004431121187735698, 0.03686469040985685, 0.07247056477353908, 0.1125053501164075, 0.1033027189259883, 0.016286486425087787, 0.04728622123366222, 0.04042865053634159, 0.018002385659201536, 0.01737358805257827, 0.031803432502783835, 0.041140655885101296, 0.0396034157165559, 0.13302928826306015, 0.026178068146691658, 0.026010775072791148, 0.13373559020692483, 0.004414008189996821, 0.04515762295341119, 0.011893781120306812, 0.0834881403716281, 0.06815437489422038, 0.030149298509059008, 0.019354352371010464, 0.04253763014276046, 0.026500371750444174, 0.0668223162938375, 0.058549610985210165, 0.016548329112993088, 0.06183243815030437, 0.07104157426510938, 0.02697406420338666, 0.0044671209161606384, 0.06702164973830804, 0.013872049039491685, 0.02495817589078797, 0.06620058207772672, 0.03013373938301811, 0.035179529077140614, 0.02171790532884188, 0.04672398128604982, 0.029618618391396012, 0.062475431186612695, 0.030291224975371733, 0.05123692193592433, 0.039741050713928416, 0.050084303511539474, 0.11118785245344043, 0.05089649137516972, 0.029537273439927958, 0.05385970522183925, 0.06915568796102889, 0.043553478171816096, 0.034008887596428394, 0.014226607308955863, 0.04062501167936716, 0.05110994417918846, 0.05138886554050259, 0.024985531454149168, 0.09648727995227091, 0.055290176314883865, 0.03304493424366228, 0.018515727351768874, 0.051992090593557805, 0.1402826388948597, 0.040331362397409976, 0.010022860224125907, 0.02608200826216489, 0.019515014355420135, 0.004500585282585234, 0.00918849698791746, 0.016014643297239672, 0.03509925467369612, 0.0016771108857938088, 0.022076238346926402, 0.03804604108154308, 0.1716018794104457, 0.06788785482058302, 0.028504897782113403, 0.010526618007133948, 0.05871878354810178, 0.0500436857691966, 0.09292061469750479, 0.015854192824917845, 0.052374289225554094, 0.04885022695816588, 0.029200501667219214, 0.14556843729224056, 0.08995842130389065, 0.09865927160717547, 0.11663154276902787, 0.20123810711083934, 0.10940940686850809, 0.12108851064112969, 0.1433271958376281, 0.16341664362698793, 0.1298246649093926, 0.16785976302344352, 0.056105366165866144, 0.11911311390576884, 0.12659845990128815, 0.07477025035768747, 0.10419812751933932, 0.1171374054683838, 0.3183134022401646, 0.08488923354889266, 0.11512613331433386, 0.1605632936116308, 0.1457984437001869, 0.19250288052717224, 0.12116702986531891, 0.1571678344043903, 0.10083297762321308, 0.14248674327973276, 0.22916929505299777, 0.10470949695445597, 0.158793093287386, 0.15924886101856828, 0.15959824930178002, 0.21113565569976345, 0.1473752551828511, 0.2738718775799498, 0.1462792811798863, 0.14303293428383768, 0.23593532183440402, 0.20034444256452844, 0.2169832302024588, 0.18270670931087807, 0.1690681278705597, 0.14774984680116177, 0.1435673251398839, 0.1957700669299811, 0.20766565517988056, 0.08090865769190714, 0.08453113245195709, 0.11455338826635852, 0.12154149531852454, 0.1700628877733834, 0.17180067108711228, 0.17200008616782725, 0.10365193651523441, 0.14942162350052968, 0.143982452864293, 0.07544134481577203, 0.24629887979244813, 0.13994531793287024, 0.17624672938836738, 0.10595963729429059, 0.20464270957745612, 0.1323391354526393, 0.13695133093278855, 0.10528780811000615, 0.15544159890851006, 0.1730446590227075, 0.0974844815209508, 0.16405474219936877, 0.1187925432168413, 0.21832488477230072, 0.11366759048542008, 0.15129288949538022, 0.15065382613101974, 0.12613632454304025, 0.19670594483613968, 0.20163015404250473, 0.17288563161855564, 0.20773644122527912, 0.16363418195396662, 0.19138216332066804, 0.1364615876809694, 0.08217149617848918, 0.1124049152713269, 0.23536759370472282, 0.09844208208960481, 0.12631337129278108, 0.1456950922147371, 0.11299426958430558, 0.17552276432979852, 0.20551914145471528, 0.19983197475085035, 0.19614565302617848, 0.1832052247482352, 0.13174108316889033, 0.09491984179476276, 0.1278122721123509, 0.09112720741541125, 0.18895915505709127, 0.1952421772875823, 0.10347226998419501, 0.15808725147508085, 0.2725513593759388, 0.14185760985128582, 0.11694019456626847, 0.17662847531028092, 0.1293182381778024, 0.17378863238263875, 0.1865270480629988, 0.29309317586012185, 0.1682926874491386, 0.13270384166389704, 0.11692391184624285, 0.12527200451586396, 0.1433621658361517, 0.15130632236832753, 0.1159314600226935, 0.15544433001196012, 0.11962610122282058, 0.12108863680623472, 0.10533134991419502, 0.1312095273169689, 0.07773519711918198, 0.17746158060617745, 0.08880047796992585, 0.11942479366553016, 0.20810709946090356, 0.16126698319567367, 0.19586996000725776, 0.12287236648262478, 0.1257230670307763, 0.19404473685426638, 0.11643076955806464, 0.18230360437883064, 0.21616637794068083, 0.09717599299619906, 0.158490905596409, 0.13164720148779452, 0.1496273319935426, 0.17330381699139252, 0.1530369365355, 0.19708982814336196, 0.1598755898885429, 0.12712783383904025, 0.13610412483103573, 0.14176464843330905, 0.13855928293196484, 0.10058129308163188, 0.13934511342085898, 0.17286733025684953, 0.11235813770326786, 0.07789812079863623, 0.089055183052551, 0.17676955758361146, 0.11141889044665731, 0.0944251632608939, 0.11894466864760034, 0.06947469271835871, 0.06522902171127498, 0.07127454926376231, 0.09016905765747651, 0.17174101725686342, 0.06656873185420409, 0.18363755545578897, 0.19265227485448122, 0.24229496339103207, 0.21218159410636872, 0.20283762831240892, 0.12837879796279594, 0.12826027697883546, 0.10506359045393765, 0.22259524703258649, 0.15991964377462864, 0.09783451547264121, 0.1584115403238684, 0.1443605771055445], [0.0921416119672358, 0.03179541359713767, 0.013854303360858466, 0.043304624923621304, 0.0657577499805484, 0.033079937638831325, 0.044148495071567595, 0.03153312747599557, 0.027376927937439177, 0.06434587339754216, 0.06525872988277115, 0.026165828276134562, 0.06832934363046661, 0.04442653327714652, 0.08678112382767722, 0.027918261585000437, 0.04945429434883408, 0.03707885567564517, 0.043578013574006036, 0.06358615166391246, 0.048694613433326595, 0.0651442536036484, 0.017698884366836865, 0.004794066189788282, 0.027925237773160916, 0.044156918447697535, 0.008925260917749256, 0.026137841887248214, 0.06243794530746527, 0.03429724536545109, 0.03830169611319434, 0.061635761594516225, 0.053087151754880324, 0.028029782261000946, 0.015367819851235254, 0.024790530296741053, 0.040079525715555064, 0.043180560096516274, 0.03437586849031504, 0.020426822557055857, 0.0645688887743745, 0.03905952165951021, 0.04858425607380923, 0.00927216022319044, 0.02185648656450212, 0.030779810476815328, 0.051043217681581154, 0.012988691069040215, 0.008657776979816845, 0.05318534160323907, 0.05388631492678542, 0.040745384321780875, 0.11401366878999397, 0.057501505507389084, 0.030231025666580535, 0.038777409063186496, 0.054132938021211885, 0.03621551899414044, 0.12243110773852095, 0.06858243083115667, 0.08003630762686953, 0.07323845755308867, 0.016068500954133924, 0.07461216548108496, 0.00258652241427626, 0.027715163596440107, 0.02894199493312044, 0.050285243705729954, 0.014520046934194397, 0.045445416690199636, 0.04138952026551124, 0.003087054637944675, 0.028303282233537175, 0.047080204749363475, 0.014387337014341028, 0.03176134901877958, 0.019741120777325705, 0.016088928568933625, 0.05937230023846496, 0.01745376783219399, 0.05494147080753464, 0.035823995276587084, 0.08191510642063804, 0.023901446656964254, 0.046695182245457545, 0.07163927773945034, 0.0426999601040734, 0.002840551910594513, 0.05572069247136824, 0.11052156711230054, 0.02645769083756022, 0.042592979516484775, 0.07109653030056506, 0.0381778761948226, 0.0360006041591987, 0.04273303391528316, 0.04874342448601965, 0.059384252526797354, 0.025626403803471476, 0.05909665545914322, 0.01209011164974072, 0.03883739685988985, 0.05297837145917583, 0.018833351714420132, 0.03433858299104031, 0.0357545413862681, 0.030729207137483172, 0.04681475707911886, 0.005651964784192387, 0.0494505724782357, 0.05379414760682266, 0.08336760074598715, 0.01713344761810731, 0.03062937899812823, 0.06290905323112383, 0.06807397061493248, 0.04554078266664874, 0.0050433684373274446, 0.03789653172134422, 0.08125052059767768, 0.018076572596328333, 0.04668841385864653, 0.03701901630847715, 0.038224323507165536, 0.035413120058365166, 0.057422117970418185, 0.01782507730240468, 0.014854002256470267, 0.03170578071149066, 0.006131886175353429, 0.03141442095511593, 0.07046084370813332, 0.021898610866628587, 0.027295299114484806, 0.028665804675256368, 0.010259554310323438, 0.07046661761705764, 0.0459717441117391, 0.05201491163461469, 0.007576135240014992, 0.07460072898538783, 0.010217201797786402, 0.03995426231995225, 0.016093379599624313, 0.0731255768914707, 0.04531848717306275, 0.007888337750046048, 0.08287979449960403, 0.06083608262997586, 0.013481115329341264, 0.012966306039743358, 0.013109681549394736, 0.047407276651938446, 0.025290357480116654, 0.03998223015514668, 0.06641582716838457, 0.13624545943457633, 0.08285473959404044, 0.015304729877243517, 0.03656904475064948, 0.05836934702529106, 0.04108056047698483, 0.03740477353858296, 0.009364412890136009, 0.05592475339653902, 0.054928186364122666, 0.014001491654198617, 0.014598075413232436, 0.034396526170894504, 0.1283324879477732, 0.035930319063481875, 0.07841436614398845, 0.03465013287495822, 0.0644994608592242, 0.02634450404002564, 0.05542140657780692, 0.03349588543642312, 0.03260638804931659, 0.02073213654512074, 0.02972850819787709, 0.05837873890413903, 0.04329834635427687, 0.03106305855908431, 0.019537445768946782, 0.07188682109699585, 0.030691055180795956, 0.041153543279506266, 0.02348109792364994, 0.0532293992000632, 0.06546749602421187, 0.02754227287368849, 0.007043644282020978, 0.025777365917747375, 0.006187061144373729, 0.06873158767120913, 0.07823045452823862, 0.0362008318916196, 0.06824525087722577, 0.06755455629900098, 0.057941543418564834, 0.04563664959277958, 0.06345731482724659, 0.042678107565734535, 0.00781281865783967, 0.041331543689011596, 0.014397837476280984, 0.049290825190837495, 0.02259889955894323, 0.0629511997976806, 0.004441242690518266, 0.020089709396415856, 0.019092491129413247, 0.051826176058966666, 0.08605904382420704, 0.06297655898379162, 0.04251843820384238, 0.05375942251703236, 0.05093663785373792, 0.02438954048557207, 0.027159276432939805, 0.027082421474915463, 0.02794194166199304, 0.06905031783389859, 0.051788682758342475, 0.030542250860889908, 0.02531036763684824, 0.043274549389025196, 0.0406899162044283, 0.05131637255544774, 0.051804141694447026, 0.012853294574597385, 0.03654004533018451, 0.052173556832713075, 0.052509107772493735, 0.07758319785352796, 0.03981457157351542, 0.01815857434849022, 0.07027382249361835, 0.019550268225430045, 0.03449617433943786, 0.03609414074162487, 0.0011215095651095908, 0.04190689738607034, 0.060443787078838795, 0.04983313105185516, 0.07907600564067252, 0.02169873008824652, 0.05628403079754207, 0.06566622090758756, 0.04201553667371627, 0.044921007720404305, 0.09520916064502671, 0.017617878947930876, 0.00912004963538493, 0.04898790648439899, 0.01884047633211594, 0.058785539731616154, 0.03273474991146941, 0.08236822468461469, 0.01613752254343126, 0.058724798655021004, 0.08039097258006223, 0.05393541541707236, 0.06446518105803989, 0.06298416599747725, 0.04151606386585627, 0.023256084314198233, 0.034506200754549354, 0.06296480336459354, 0.06773794841137715, 0.027126360328111332, 0.04909938077616971, 0.03277875926869456, 0.06517298956168815, 0.003362451493558183, 0.023346834132098593, 0.04167421553574968, 0.055334126300294884, 0.05094625608762726, 0.0279112538555637, 0.046678142534801736, 0.01160620167866, 0.03385687348782085, 0.018966212846862618, 0.05552878421440255, 0.05239023797912523, 0.01617753729078686, 0.06872352052596398, 0.054511522394022904, 0.058979284804081544, 0.05999486937071197, 0.016766804401413538, 0.02862897188606439, 0.020865309379587416, 0.04785494755196851, 0.019715503694897052, 0.031750506241223775, 0.04060846920765471, 0.11995347740594298, 0.024017752330109943, 0.04219438313157298, 0.071552594890818, 0.025826266028161626, 0.07307406442123465, 0.06007211581163574, 0.03579051699489355, 0.025504394725430757, 0.0469014621921815, 0.018919483518402558, 0.023475617163057905, 0.005104560832478455, 0.02189263657783158, 0.031445413042092696, 0.08198594441637397, 0.06859616056317464, 0.027762783502112143, 0.05719499480619561, 0.06723003738443367, 0.0790643019718118, 0.033619412206462584, 0.041627078026067466, 0.04156617738772184, 0.02520833531889366, 0.05201218053116463, 0.05199575680308044, 0.016120508807944134, 0.04638604434148874, 0.027604225506365765, 0.04015259015432093, 0.021036470898252446, 0.013299205656949198, 0.028092738648410887, 0.06966406654100865, 0.07204135850770399, 0.017409125794074498, 0.037606938276439905, 0.08498557173879817, 0.009960319439414889, 0.03164071291394066, 0.002217022624790843, 0.03275273214967456, 0.05908119281230029, 0.012323659029789269, 0.06488400467787869, 0.051396925264270976, 0.035832867652061395, 0.029593619146908168, 0.0732469477225095, 0.06933832308277488, 0.04291328674298711, 0.01631520382943563, 0.07988684650626965, 0.12383053108351305, 0.07190276985056698, 0.06765426383935846, 0.12023196090012789, 0.09710685451864265, 0.14724429580383003, 0.159817049279809, 0.17778386565623805, 0.1306150373420678, 0.17983070894842967, 0.12592038925504312, 0.11896309617441148, 0.20955773099558428, 0.14987473434302956, 0.18828105472493917, 0.11494417354697362, 0.07076113150105812, 0.09564794803736731, 0.1476399347302504, 0.1343926283880137, 0.11120862516690977, 0.19641998049337417, 0.20743728149682283, 0.15399096737382933, 0.17423392098862678, 0.1690933757345192, 0.15501667483476922, 0.08034797996515408, 0.11619922690442763, 0.08773042718530633, 0.0908103103574831, 0.10333251615520567, 0.11333158312481828, 0.1302881955052726, 0.05450102842587512, 0.15237220970448107, 0.12113693577703089, 0.1773814286570996, 0.1137078668398317, 0.10151855138246901, 0.16962174035143107, 0.12895740597741678, 0.11626932275248691, 0.1643015508307144, 0.11131521983770654, 0.2324352494906634, 0.1968960533849895, 0.10589271041681059, 0.1298512634821236, 0.102712748630438, 0.19321203231811523, 0.1308406502357684, 0.20963099581422284, 0.15338935278123245, 0.10727826302172616, 0.12837476067943498, 0.14367725205374882, 0.155840874358546, 0.2618380420608446, 0.18851811153581366, 0.19586608599638566, 0.156368185125757, 0.09506522110314108, 0.18850184365874156, 0.07500265390262939, 0.1419686499866657, 0.15645446721464396, 0.13885755208320916, 0.1017853312077932, 0.16252655623247847, 0.18673618527827784, 0.15967474988428876, 0.1506780943600461, 0.13847225869540125, 0.12962756532942876, 0.17492980317911133, 0.12797547038644552, 0.13139844842953607, 0.16828008578158915, 0.08756671682931483, 0.10534136890782975, 0.1323654965381138, 0.1780066138599068, 0.12868652207544073, 0.10736583644757047, 0.15600227663526312, 0.11099178445874713, 0.18035352230072021, 0.20691518060630187, 0.21608895709505305, 0.19246773241320625, 0.09439427507459186, 0.18194183707237244, 0.08510942134307697, 0.17974052316276357, 0.14128174778306857, 0.12712275754893199, 0.2176064858213067, 0.18923254741821438, 0.11010050962795503, 0.15099996380740777, 0.08921297107008286, 0.14242441771784797, 0.11516623155330308, 0.13664752535987645, 0.20411545818205923, 0.25908244773745537, 0.13190281199058518, 0.20053744548931718, 0.1814389874925837, 0.1331363504868932, 0.1627149133128114, 0.11076254246290773, 0.12964472378371283, 0.331713828491047, 0.10480086275492795, 0.1440791695495136, 0.2261215023463592, 0.24626704165712, 0.16602575284196064, 0.11936410825001076, 0.13332303031347692, 0.18433227989589795, 0.13844858418451622, 0.10722128834459, 0.17869131930638105, 0.11110029387054965, 0.1980744206230156, 0.1757122197886929, 0.0694825743266847, 0.12729115085676312, 0.17716227244818583, 0.2288974612019956, 0.14100007305387408, 0.13216167310019955, 0.05999890294333454, 0.16848640283569694, 0.24924881290644407, 0.12953634053701535, 0.11750989680876955, 0.13163221010472625, 0.11207681920495816, 0.24928390164859593, 0.053989673833712004, 0.18853109912015498, 0.12366118040517904, 0.10987826608470641, 0.11889652552781627, 0.1046851025603246, 0.09617987496312708, 0.17312059557298198, 0.08110025053611025, 0.1947810364072211, 0.10029923243564554, 0.12837676447816193, 0.11878113640705124, 0.17943193815881386, 0.16720710351364687, 0.06740373704815283, 0.09181223940686323, 0.16697110055247322, 0.12599585083080456, 0.10587290991679765, 0.09590300192940049, 0.09495326812611893, 0.16109422605950385, 0.1457665313500911, 0.13569658185588196, 0.13366248866077513, 0.20289189415052533, 0.12217723386129364, 0.1507029266213067, 0.20614644919987768, 0.19619062717538327, 0.10875715553993359, 0.25131518952548504], [0.03273867958341725, 0.012496990402723895, 0.05971752878394909, 0.013914149221818661, 0.035943321490776725, 0.1049338853044901, 0.034732296044239774, 0.03040146915736841, 0.06142982674646191, 0.0717408925993368, 0.045177456850069575, 0.009612864450900815, 0.04862513727857731, 0.039674776926403865, 0.033740482467692345, 0.10761128694866784, 0.06493312743259594, 0.036026211964781396, 0.08524793578544632, 0.02935668107966194, 0.0033800536130002, 0.030828397029836196, 0.05208723021496553, 0.012643083100556396, 0.014610562975576613, 0.02957358672574628, 0.09687769415904768, 0.05676404820405878, 0.01825633746193489, 0.02759408591373358, 0.0363259431469487, 0.01452513435651781, 0.04205940131214447, 0.05278621087200008, 0.12447432192857377, 0.013026896831433987, 0.021560833483817987, 0.08701190949068405, 0.02301845048350515, 0.012772893078363268, 0.06153388698294293, 0.046615998799097724, 0.031386230475618504, 0.02973354366986314, 0.08137005832395516, 0.01135115984652657, 0.022944623488001525, 0.033511990041006356, 0.03785924993280787, 0.08554502492188476, 0.033811116372817196, 0.05126543153892271, 0.03660103502625134, 0.025481670163571835, 0.018679474815144204, 0.05051410349551588, 0.06893622005009092, 0.030595518510381225, 0.014756973869225476, 0.05453564219351392, 0.05979062661936041, 0.019591581731219776, 0.03873371511872392, 0.043384038435760885, 0.06181394011946395, 0.030145413365971763, 0.02403534308541566, 0.03165768583130557, 0.02640356971824076, 0.03163146575388964, 0.008902060453692684, 0.020510696376732085, 0.06044279631169047, 0.04975269708666019, 0.07288134351256303, 0.03395974257728085, 0.0028035124796588207, 0.07117261528037488, 0.007645244495506631, 0.06267798555199988, 0.035422563887550496, 0.028115700697526336, 0.012359706070128595, 0.026284993073204532, 0.015005008899606764, 0.04630511313735042, 0.026847242297662888, 0.046302931223181076, 0.0147819777521363, 0.038119732635095716, 0.03317523682198953, 0.07165389804868028, 0.0686357170343399, 0.010297308290319052, 0.051901214610552415, 0.025344571367895696, 0.11783231544541195, 0.04003134548838716, 0.057509702528477646, 0.04851732919632923, 0.01575860420416575, 0.048857648434932344, 0.05547318622120656, 0.04455756687093526, 0.04248520483088214, 0.011153261530125747, 0.05199151171837002, 0.022131305704533588, 0.016780949736130424, 0.07528312635258771, 0.013140941737219691, 0.010085122703458183, 0.02930658982222667, 0.02843030266376445, 0.03401215304620564, 0.050884108641184866, 0.05873692534805741, 0.039057807298377156, 0.019051311210205313, 0.027858880494022742, 0.05144370283233002, 0.011945538499276154, 0.052412068253033794, 0.007922009917820105, 0.004841965792365954, 0.014259801719163079, 0.038682733284076676, 0.014884498959872872, 0.011883741717610974, 0.04364418717159424, 0.02428941363177728, 0.059754988687927835, 0.04497720685321838, 0.030615638133895118, 0.05054908091551624, 0.05418562679551542, 0.03743064109585248, 0.02953017108666245, 0.05948789716057945, 0.0514127886708593, 0.030623668171756435, 0.03237990313209593, 0.03679223824292421, 0.045768859490635805, 0.01913430001877714, 0.0053065353949932614, 0.022634984634350985, 0.029359363943513017, 0.060202418389962986, 0.04319038984249346, 0.014220758257579291, 0.022056424859329127, 0.020411593686731067, 0.08969441711087711, 0.0806697306688875, 0.02129651758878026, 0.027252193322055973, 0.0362764122110093, 0.010856448843696853, 0.03946261917008087, 0.02219408026576275, 0.024496053520124406, 0.044610771437874064, 0.020429459036677144, 0.043282271435600705, 0.03571238739823457, 0.08075990903307684, 0.041033300512935966, 0.040141713980119675, 0.04195726323814597, 0.04616317368345335, 0.028017169461236335, 0.03609994804719463, 0.04904840265226085, 0.057415587070863694, 0.01662473878241144, 0.013149875339877326, 0.024970996491902042, 0.10060763932415284, 0.004336272859291057, 0.008705391319381306, 0.025963548505387735, 0.027202886885788757, 0.02012172193644801, 0.06878699641674757, 0.037780908824061044, 0.07599710210342892, 0.05358294351026416, 0.04639879072783515, 0.051236491490271874, 0.07516428624512628, 0.049482332688057795, 0.009981867697206326, 0.019685335391841363, 0.07558355515357107, 0.020159988926025108, 0.031048647906573024, 0.02673763821803732, 0.0510793268767884, 0.11690413361066021, 0.026301151483494323, 0.05194083045353182, 0.04081719082023483, 0.0466893712291494, 0.026471927085367497, 0.011148586927447468, 0.02572877194324974, 0.030131240200717002, 0.04185108045930974, 0.01767293331795372, 0.04182663782557938, 0.0282779137705802, 0.019016864425793756, 0.015543512181466212, 0.02738402472459711, 0.020047534999321215, 0.0022820563299319474, 0.01755057728587417, 0.04971278067387175, 0.06213998785824515, 0.16442185296909884, 0.07937267917441204, 0.09989867307012901, 0.015800080982444342, 0.01764631062542321, 0.06722875346895307, 0.022068998696340714, 0.03397818494704552, 0.016410044736403506, 0.027748714237532113, 0.015021596827864414, 0.07819853475666605, 0.05243828833044972, 0.04487616344704293, 0.03265313964220695, 0.05096768931252882, 0.050868590333266184, 0.09998037610785104, 0.07226113812066615, 0.024281248151964974, 0.025260946167691145, 0.0035607213476396282, 0.014065000013943063, 0.03453397563134786, 0.046104569992166944, 0.030737346642126795, 0.022374889704224188, 0.01341826840871363, 0.028209556403453462, 0.01793282415746944, 0.06987286236835644, 0.023486706704716198, 0.03882304001308512, 0.05378914553148206, 0.02360271737416042, 0.021775165732833557, 0.012291541661397787, 0.03717093022714835, 0.046418995698331855, 0.02920420312875649, 0.06769842162611894, 0.03333754080813378, 0.012655767332034884, 0.06070765768527053, 0.010433330971864052, 0.05979110530461185, 0.04037613616674207, 0.02172131364204688, 0.07052097993437201, 0.08566606920794584, 0.018817508716892917, 0.06193453540618066, 0.01254808541489183, 0.035881363291991875, 0.07929938466986641, 0.041984455529018305, 0.030584892811020836, 0.036202639021212235, 0.035701229207916185, 0.05140067311003804, 0.020106853007746395, 0.023057741636876017, 0.05771568190539256, 0.013448021109070396, 0.009438109082111623, 0.02030588217166951, 0.05650935425364878, 0.011189033975824714, 0.08171720532118343, 0.025327737603220157, 0.02264735067001311, 0.010685140750865685, 0.05761567379522603, 0.03708930882567074, 0.06985165920923464, 0.03132171186734922, 0.00244781942001282, 0.030813880621280987, 0.04219388589262962, 0.02214357526099775, 0.023281766334548593, 0.026039870972454082, 0.07812357784132473, 0.05080605697003193, 0.04776609392138198, 0.03907666898157913, 0.04263992406777106, 0.014118014405539725, 0.03608951345086098, 0.0388769347773632, 0.0573396505205892, 0.08662625987199135, 0.05849841392773669, 0.018492114068067167, 0.05338197363016661, 0.028753695369232446, 0.02078425015497487, 0.018015148743870668, 0.018124255584552884, 0.02305935209733434, 0.05822841318149585, 0.036090760258957744, 0.044340047097648494, 0.02188675876823254, 0.02227334349299781, 0.010737125412561, 0.009620630098652327, 0.03652507992228493, 0.04156393239099998, 0.027860568879987113, 0.08114732496323995, 0.024442038156848866, 0.013768191965937149, 0.07867715321481228, 0.07499661282054149, 0.07075246321619488, 0.018935938787763007, 0.02969090171973221, 0.05322951423295308, 0.05699490066035651, 0.05133347163791768, 0.052873209133394994, 0.05901319353142753, 0.022997082196525298, 0.012879410751338582, 0.04933823358442169, 0.032820516207721084, 0.019627347683126573, 0.04980868470738642, 0.0038300699316096143, 0.008913005276554031, 0.05826492684718687, 0.13134859094861895, 0.10207887287833728, 0.1782893275958486, 0.12872723629698157, 0.09123322321102023, 0.22498223144793883, 0.16872050589881837, 0.09125096054049209, 0.17732466920278966, 0.16973488818621263, 0.12873127358034253, 0.098274853953626, 0.10006282871472649, 0.21153271954972297, 0.12584243406308815, 0.24665551143698394, 0.14754727017134428, 0.14061521011171862, 0.1642238479689695, 0.10597276588669047, 0.0963698944542557, 0.09336354327388108, 0.14520292956149206, 0.22857910953462124, 0.13201505440520123, 0.17299535073107108, 0.15543000656180084, 0.12591414037160575, 0.1251729129580781, 0.09329992637503892, 0.09317601739894599, 0.13959147676359862, 0.17566320835612714, 0.12003948490018956, 0.2376727489172481, 0.0754336042155046, 0.09648731705965474, 0.08651436626678333, 0.16848447325173765, 0.07478429179172963, 0.11959270457737148, 0.15395549271488562, 0.12321098620304838, 0.18276456714374945, 0.29741695791017264, 0.18645405041752383, 0.23548096418380737, 0.10279215101036243, 0.1374188542831689, 0.3432956070173532, 0.14881806448101997, 0.13453078659949824, 0.1295191523968242, 0.16549317282624543, 0.17498739383881912, 0.17540158645715564, 0.20243413746356964, 0.10675181314582005, 0.13957791030406952, 0.14815931936027482, 0.13118466536980122, 0.2343963153543882, 0.07751411874778569, 0.08583749789977446, 0.13042224221862853, 0.09589584762579761, 0.18551465473137796, 0.1525672757998109, 0.144788054167293, 0.1314304646803066, 0.06228505546459928, 0.16354589606635273, 0.22947166085941717, 0.13637606258271262, 0.20211038296110928, 0.10022047572419979, 0.07077069778461009, 0.16969307558611035, 0.12231854620040394, 0.15031810820801184, 0.09160590750980191, 0.09933205074048601, 0.10245242548990063, 0.17539238382596523, 0.11069579370087013, 0.13035510753979906, 0.08835429878672585, 0.14044442708836868, 0.07217383186798543, 0.12090622432879172, 0.09753814621944912, 0.12362995083094575, 0.15496986015932634, 0.18611573497764766, 0.09389666505740024, 0.12794784764992073, 0.29480510274879634, 0.11545038505573757, 0.1510976898134686, 0.086416306294268, 0.09490941461990587, 0.12285075514228083, 0.1758858675020747, 0.14269455947214738, 0.14740924554644153, 0.15286003821529448, 0.23441455734428018, 0.11521851585712284, 0.08944176777731627, 0.15942926227580756, 0.1242005213862285, 0.10754732866189443, 0.11950849308050238, 0.10864069030503742, 0.1518623245647177, 0.12070586672052741, 0.11602159385802224, 0.17923483857885003, 0.0846327176259365, 0.18000956653850153, 0.13661542005138472, 0.12240970419952646, 0.12421991370501928, 0.16569536353927106, 0.18422083900077268, 0.11066803737776354, 0.15357368742115796, 0.17443384072976187, 0.07340677664615214, 0.17328269546851516, 0.12277521193027496, 0.14282819058280438, 0.09724432995426469, 0.08300470537506044, 0.17050305556040257, 0.2952473930781707, 0.16775317577412352, 0.11162131864693947, 0.12910377234220505, 0.14331438636872917, 0.1251815218711272, 0.09804936722503044, 0.1279215607792139, 0.1043078837392386, 0.15961067285388708, 0.09641161057516001, 0.08302889196784236, 0.11121210583951324, 0.07398733650916256, 0.20214484829921275, 0.08308488701004535, 0.1691461869631894, 0.12788341438863426, 0.18638745008502156, 0.21135576185770333, 0.16677411971613765, 0.12721797509584576, 0.15614730713423342, 0.11707504279911518, 0.17304485198110342, 0.11006378073943779, 0.1532456581480801, 0.15591728588333353, 0.13629803317598999, 0.1324588290299289, 0.16485264000948519, 0.1407264728914015, 0.11801094296970405, 0.11058756630518474, 0.2808450080920011, 0.13689730258192867, 0.19648098503239453, 0.20740931737236679, 0.16302127187373117, 0.13745593198109418, 0.21086762164486572], [0.05760175110481214, 0.05260580590402242, 0.047166583317448385, 0.03518775578413624, 0.07791559095494449, 0.013682082426385023, 0.08450520181213506, 0.026258580037392676, 0.040610944270156324, 0.033904010997503065, 0.015944883271004073, 0.04603905319527257, 0.03401636473427061, 0.015656968935218174, 0.038531505852006376, 0.02274205799039919, 0.028505667760327924, 0.01686404059000779, 0.0531884994416032, 0.06402759594493546, 0.05658689384290483, 0.045539116545114666, 0.044208857652847655, 0.015752505605632905, 0.03409439785173163, 0.018660999048734084, 0.05995045925374143, 0.04213033949781675, 0.0320643308077706, 0.02315489989996422, 0.03418868771404959, 0.10695467921323143, 0.03252622867876198, 0.024588432352175005, 0.05946601493633352, 0.039585377817275, 0.04185528101515956, 0.013406117595877731, 0.017704953279462643, 0.029818538132531103, 0.07457287618308328, 0.045665726938750595, 0.06538606015965343, 0.08816380432108417, 0.010014680829044664, 0.02660369540535612, 0.016304067903547548, 0.05201541258429643, 0.01633118783502141, 0.07694685074966401, 0.011760261331801303, 0.026600496748869773, 0.019465837794996332, 0.06508400605525821, 0.04212368614389561, 0.032537787628825754, 0.06402636397979222, 0.06125718464318197, 0.03866674371238332, 0.04245971947966609, 0.09555716111208312, 0.025697234377730638, 0.041249799833167344, 0.023623619963473175, 0.016347270175174344, 0.027113177930004895, 0.038930436203372665, 0.04681150276155677, 0.018338509908062406, 0.0709192905924283, 0.033619115347391926, 0.026465552036825102, 0.017009447728923988, 0.07807974659954198, 0.03452478413237259, 0.03964666808315087, 0.013789017557428451, 0.015260463551385328, 0.05121982285345439, 0.061803846911061555, 0.03346408440847881, 0.08550892685889266, 0.027913051708310377, 0.018096590174536686, 0.05472089338582009, 0.013525798185582971, 0.008638695435365662, 0.06984315419686027, 0.011180966830579564, 0.05597913055680692, 0.06683712956146337, 0.044621617926168256, 0.05638561226078309, 0.04318985920690466, 0.019515463354764506, 0.0880598665389698, 0.028362867415125947, 0.09216566497343592, 0.002726342108871904, 0.04321337786677759, 0.009470031636737986, 0.08763143952819519, 0.04674552954384126, 0.08461113597149961, 0.07166741997934878, 0.04018839135824237, 0.035240155120845884, 0.029892877209931612, 0.01362920533210854, 0.032284930493915454, 0.07715521613135934, 0.059815028434968553, 0.030542417844117153, 0.02222083097876748, 0.04289031356165651, 0.0473272137605818, 0.028212682700541336, 0.07388631536741741, 0.024527704263164196, 0.0214419154508505, 0.04640480954549275, 0.05695151099644136, 0.025935892372217495, 0.02737253627856262, 0.040534621803089976, 0.025479740579612553, 0.027582584480114747, 0.027586172764131334, 0.06399169084033929, 0.06185623882629443, 0.04667381952458527, 0.027119398982904386, 0.05136717627465259, 0.04900240805000067, 0.028900239849463105, 0.008832800449454226, 0.046587114411522634, 0.12923038273584098, 0.02049317983619403, 0.04230013917549513, 0.021782416515634395, 0.013555739205912687, 0.04814325708139222, 0.04160300646617543, 0.03617629277869128, 0.048513251094846055, 0.06299253000179306, 0.006591635992663214, 0.08597354841185734, 0.033152070682263, 0.04087385750608519, 0.06554192601470277, 0.052509519664454274, 0.06319377818726934, 0.024241864230134524, 0.04875938808254432, 0.04785102530149743, 0.021283257265167776, 0.055875311518320814, 0.028949529587407596, 0.03578889911295846, 0.03615649970015511, 0.04189198021776974, 0.0483950566558633, 0.019449514256848488, 0.05699792491213884, 0.0913459257571958, 0.03170420364767779, 0.0324574612750439, 0.06761988755897619, 0.0609605890349485, 0.019963544291385915, 0.031549083651043475, 0.09398177455295809, 0.040057732549030334, 0.06184646474139299, 0.030615452596975956, 0.026903059224423487, 0.0425417156657204, 0.004756163316415041, 0.027369990712031722, 0.013919610501034185, 0.07944552839035168, 0.037173360760789365, 0.012856725152232684, 0.04889429939794354, 0.030805401584075298, 0.013570193459599977, 0.04695016563346144, 0.013988749906275189, 0.0375481787341414, 0.037998788538970985, 0.010999095193255926, 0.07257034652866423, 0.02826541971444385, 0.06852208680356853, 0.04617465099727269, 0.05272976683045272, 0.044687980771414004, 0.02008829003898427, 0.04671177295676898, 0.03841292178549338, 0.0714659046207089, 0.028271048904571217, 0.01044733437083778, 0.05887908744625747, 0.01076187325452338, 0.013467549797496758, 0.06925015593878925, 0.06827579025411978, 0.043377073379815556, 0.05155992315849289, 0.055501629030914046, 0.015984293168003205, 0.02812787006405415, 0.044158157834317535, 0.08307152093038894, 0.022081450078985654, 0.01622269512154162, 0.048144678294193, 0.07341532618738711, 0.01354958123556571, 0.03255309442465659, 0.042595836785039864, 0.04850191849982366, 0.0073516383508831495, 0.039719680571579374, 0.04433265530678909, 0.032488868964719586, 0.09525241301162168, 0.08376646059332415, 0.06394820098648779, 0.02700447555980645, 0.02744251523836283, 0.027283190975140315, 0.004655337452277308, 0.06416346834157594, 0.037211885646684095, 0.04611902702890802, 0.019842167894239537, 0.05445639566460159, 0.02240382233139826, 0.05856023482920136, 0.020805885615118314, 0.0023422166759701213, 0.06082542167860083, 0.03204444125003647, 0.020081926122657023, 0.040146612154785544, 0.044074499237467535, 0.042023956339107826, 0.0366042967652902, 0.07756648468784988, 0.0410519061551895, 0.005198600683797849, 0.01840704724600073, 0.07161296860431321, 0.03607257021940313, 0.03567915402527433, 0.05005560095014516, 0.015114276229724055, 0.011231318767386256, 0.04980993893695995, 0.05831355978443753, 0.04726616469270084, 0.02054970736935502, 0.11032334688934498, 0.02404423586995108, 0.058533027695375495, 0.014911837824911345, 0.025215625064447522, 0.05984890376566909, 0.032096410141093656, 0.01872126700618537, 0.022871123037475627, 0.06553465296747163, 0.017532671117805876, 0.02873827725125011, 0.04253886952938046, 0.03622350450314116, 0.08647116585052572, 0.023682169849053025, 0.0695691978035029, 0.04425643302965909, 0.05388032950577326, 0.04921005354844965, 0.04161073222348932, 0.04221183844492771, 0.10568100537057035, 0.031319544796133414, 0.021275232793414034, 0.045256365701789036, 0.07079017916112207, 0.020460595842450857, 0.029519118652387988, 0.05172067234525457, 0.039404557246598415, 0.0493185332743451, 0.03244219158659689, 0.02056942437775433, 0.0580934647587128, 0.0720151310088113, 0.019397241085243877, 0.027313546670484357, 0.010852978375623934, 0.025970031165343244, 0.035754374403040856, 0.019377294011064805, 0.021898312152188737, 0.04442223995283712, 0.06948530543013476, 0.013761033951595891, 0.018820638724719174, 0.056965567273437046, 0.003982993866884499, 0.06773033397621475, 0.06063140943297185, 0.01892773620056687, 0.014137544949335279, 0.030458968903985806, 0.031297488167183474, 0.10189631197135895, 0.036003925270051695, 0.049038988508982584, 0.06396854325430468, 0.0511685849778587, 0.01377239437715616, 0.03789391936152242, 0.012322715574555332, 0.05766313784988597, 0.04347254325693939, 0.045625907005160116, 0.01460380015487317, 0.03961432528740261, 0.021030192328908015, 0.022557589763891883, 0.018488312416593544, 0.023258908186107874, 0.03953204337449279, 0.023738849522487726, 0.03124245791696012, 0.031366652619908564, 0.16883258504094556, 0.025825965458352584, 0.04016236052848399, 0.04194212342554238, 0.014647745501861209, 0.011831757983600255, 0.029648126183019485, 0.04988577158655971, 0.06290160948992707, 0.022764567329431884, 0.13446157390717417, 0.13474937877617776, 0.17400297947460786, 0.13644594320794567, 0.1303312845993787, 0.0744296787888743, 0.2105247345753014, 0.10802206568769179, 0.11861588980536908, 0.06526578028569929, 0.18948806886328384, 0.11056919815018773, 0.21587777155218646, 0.06766809005057439, 0.1291258735000156, 0.13058043841738254, 0.1296723316772841, 0.11725240125088021, 0.10055144390207715, 0.15776076586917043, 0.16312388121150434, 0.05714330793125555, 0.16527996864169836, 0.1110401279584039, 0.12843104515923187, 0.0807886449911166, 0.16011007886845618, 0.15501897549256682, 0.08730340283364058, 0.17601207713596523, 0.097604568436509, 0.21828322060173377, 0.16461789869936183, 0.13060280674835667, 0.17891319177579135, 0.09343540543341078, 0.1731301544350572, 0.07774815501761623, 0.09777087630936876, 0.14187591121299192, 0.12335455467109568, 0.09057654868229292, 0.1030832584365271, 0.224536586611066, 0.2302590201725252, 0.10906606708886102, 0.10161480051465333, 0.10076503400341608, 0.12679870618740097, 0.10235730442218482, 0.17463126685470343, 0.11007841589162126, 0.17620191851165146, 0.23331567412242293, 0.15458501206012443, 0.14021768613019958, 0.16216352727496997, 0.1248367052176036, 0.11870010130223818, 0.1315534979221411, 0.20356656576041132, 0.176623102161102, 0.1157639424491208, 0.11599474295508116, 0.14447176567045972, 0.2074988352251239, 0.1963355389307253, 0.1373584583052434, 0.08675000557559542, 0.1585698701092042, 0.1569402770837769, 0.1444675205857493, 0.26119462971109897, 0.10153342402190901, 0.1165077525365632, 0.1520776067627594, 0.2171456121141091, 0.13847451482433826, 0.18469741655280814, 0.12338539832853712, 0.14903907605912536, 0.2329143206588924, 0.13788664480671287, 0.11059704353101552, 0.11272997595369816, 0.08881916524842381, 0.09830057679209858, 0.19783905590884387, 0.14259291492635384, 0.19249116943683475, 0.284190847305581, 0.18460283725289628, 0.1380635579698719, 0.18517786811571568, 0.12034523490001447, 0.1635063099092804, 0.2099271275801584, 0.1623581480816938, 0.08238684516982175, 0.2934200770687312, 0.1459239557152614, 0.1507428690092638, 0.08003275273949839, 0.1784760074224323, 0.18649718404049054, 0.23442922218237072, 0.12065232076565735, 0.09732690872624516, 0.17160903371404856, 0.10671471318346448, 0.20614658278645948, 0.14047570119146258, 0.20504582935245708, 0.2071215570322238, 0.20160646468866616, 0.17349011090118438, 0.15163212519837543, 0.15815306513104588, 0.11053836933569983, 0.13332029921002686, 0.082438446697779, 0.10698052079533227, 0.12660687585594133, 0.10647309958585538, 0.10514702269574627, 0.17161997297080234, 0.18690834869630635, 0.13824263820424676, 0.17434699460864067, 0.10655598263838328, 0.13798656756989658, 0.13143850956112146, 0.14687056507682428, 0.13009848771616817, 0.1976647847914137, 0.10243905941024423, 0.1338967846822925, 0.19888480135705322, 0.12054839782649651, 0.14430120529141277, 0.12161743186879903, 0.09608090214896947, 0.1649443100905046, 0.14692152093630284, 0.12650551332626492, 0.10882852046051994, 0.21512026141863316, 0.11448639459558763, 0.22646685334620997, 0.08243770455010235, 0.16229174070758745, 0.1604946152656339, 0.11571030001505278, 0.24808591202599928, 0.10134228388778865, 0.12723258056212217, 0.09956447654985823, 0.07263958890689537, 0.13151971535990015, 0.08898894637241028, 0.11074303140048869, 0.12176621763501316, 0.10441906488267705, 0.12697781610768288, 0.1704457914456725, 0.17224621202331036, 0.3724644152680412, 0.12425026754499413, 0.10994511874741875, 0.1104848604882136, 0.12919793603941798, 0.17813597019994631, 0.12131152601796202, 0.2292475025751628, 0.3573661035625264, 0.1004034819197841], [0.02112409441906493, 0.08389656650251709, 0.019433684246905614, 0.03170159870933276, 0.10627662340993993, 0.04880182779743336, 0.039611041283933446, 0.05908818755415268, 0.015586797017022036, 0.016630169448035304, 0.0417955381271895, 0.02756945959845325, 0.07456298335455358, 0.05189163719478529, 0.024804488239169586, 0.023256306958501227, 0.029705473789363168, 0.023056864047248382, 0.011526252892508637, 0.035496570853865705, 0.04200564384518657, 0.028375086876621936, 0.037943005008855835, 0.039114885876188055, 0.02322001408174401, 0.05418089189333841, 0.031998647027648985, 0.06865298681077547, 0.06780295312637463, 0.001668577231157542, 0.015108418829186121, 0.05092650382721331, 0.01988940373848891, 0.013275779765535844, 0.022063779542804696, 0.03756151512789074, 0.011864593379868893, 0.035734406919800676, 0.05679716654412914, 0.026135481857636478, 0.013479798944899812, 0.022760249885322992, 0.06267568489420228, 0.06527274163090624, 0.08253859952674247, 0.010877225267904578, 0.033872866770252585, 0.02984533151902724, 0.013188692446419736, 0.09390280261868611, 0.06408506786101498, 0.02264984985231422, 0.03218024685338605, 0.02437445076793665, 0.060932951455470175, 0.029511836328310892, 0.06441729768994264, 0.009615307044441579, 0.05064272882009391, 0.038712638124707155, 0.018355753709329292, 0.05440008520963602, 0.04574246871925425, 0.03595550384488888, 0.07475793070625514, 0.048299100672011264, 0.04757033762871288, 0.049386888786102645, 0.03248590408475138, 0.02481863171851728, 0.037384342213044874, 0.02394852850557072, 0.041590530963731, 0.09698748748633079, 0.01817330783524085, 0.01936227665282786, 0.048677080194465816, 0.03809132322203368, 0.021925584223936312, 0.018652379003469832, 0.048545052122790366, 0.02237803826574236, 0.05167721588804852, 0.06948399925022386, 0.040689474626560695, 0.04452539105841424, 0.01809810972190462, 0.01407467019816977, 0.056650317783351056, 0.07458883235813119, 0.013147326062608045, 0.06192426408233587, 0.0266003798606107, 0.018139898202207405, 0.027735335170291364, 0.034182056624558754, 0.048294636653736234, 0.05890540771360975, 0.01151843065599678, 0.04735472517495509, 0.04586097857099958, 0.040239796217065305, 0.02265828436065931, 0.005066624562459765, 0.016929540688579436, 0.04704992512415629, 0.06297409505350515, 0.03795828582951799, 0.04023093497380614, 0.03415112390939612, 0.050965525952051394, 0.040222686002380215, 0.04072292322234716, 0.05767704569734633, 0.08028437048778869, 0.05813475414470304, 0.019376928503334057, 0.041528843648848124, 0.031076662125997245, 0.03326883648696821, 0.052709840165334754, 0.07331355547648855, 0.036036435049027205, 0.05744037851400208, 0.0522407434618799, 0.03079490390518913, 0.029331063997233286, 0.03993497019109782, 0.03296571740065701, 0.07322595978621393, 0.02006686794629786, 0.06795989509555511, 0.03198820872057695, 0.04250067489920184, 0.01296937110964791, 0.04317918712331448, 0.03517968863889109, 0.02831048292136984, 0.005967075121589005, 0.026424795141792856, 0.025467810555710457, 0.03459155144810211, 0.04442759083758574, 0.018123292647942435, 0.025331548531539738, 0.06734653972671367, 0.02687064592464594, 0.00602062664256664, 0.015222499914671062, 0.028461725196393672, 0.05940709212154616, 0.016268487488559913, 0.066917860385729, 0.023628462477063295, 0.04005383627372794, 0.024735778351896442, 0.02255591065477347, 0.029134148098819423, 0.039546834377688356, 0.03223150699341204, 0.031425204360857606, 0.018185315784648992, 0.050040364658343606, 0.05634729146549944, 0.004326261287133093, 0.04887602030066773, 0.08154975454090163, 0.004093202796866535, 0.030940511423978023, 0.06380558988894336, 0.03698875894770026, 0.016381529567297548, 0.07570045083411969, 0.04517026543908287, 0.019895170225936454, 0.0704235804732889, 0.07183381690992974, 0.017665252089500427, 0.014847458369331434, 0.021744854566350114, 0.054103274378576316, 0.044818598762503825, 0.042782546297530644, 0.0625014583056327, 0.03520902573654894, 0.017384738821419887, 0.07100963965058327, 0.041968777659349144, 0.03609967345255427, 0.027218065661145374, 0.015282032218237873, 0.031742197897983715, 0.04080773585883435, 0.019166312558809295, 0.007256277476699324, 0.017938965429493692, 0.04348249174654484, 0.06361145147820935, 0.05178149134735577, 0.024122322793118656, 0.04677261422330048, 0.038397295866161585, 0.03707381278218236, 0.022895864385645837, 0.017016858073475305, 0.012315439744270407, 0.03932933686883189, 0.04892933247901965, 0.056636328299646266, 0.05068091231805738, 0.006111341208452359, 0.041105088457698, 0.05701683112420142, 0.05030759719375055, 0.02631163617479615, 0.09959629984223284, 0.10542857125983573, 0.02786607190500945, 0.05382503950386308, 0.028667765800491907, 0.046124574582790956, 0.013054533483227715, 0.02197726738813799, 0.006520659308080212, 0.0030335740848386195, 0.05022643963457085, 0.0354615155083593, 0.019066196837229654, 0.04402534679684322, 0.08418958124821074, 0.06559339395607822, 0.022350204017129727, 0.0745163245301228, 0.01884193094156217, 0.10421784638310783, 0.020703892259916756, 0.03469827970548067, 0.031876396751613356, 0.03400885048904456, 0.04402029277116526, 0.030873174509906676, 0.03183519271260593, 0.003987181435149978, 0.03946563600038644, 0.06484234050731175, 0.020649381513067055, 0.036302799271652475, 0.026441545414854772, 0.021918400234426372, 0.04962626480846666, 0.019662364065879956, 0.00983635387456161, 0.011629233304120135, 0.016132112286868505, 0.030738573041162454, 0.02877511189581128, 0.028803474924643524, 0.051318060941412114, 0.056486373650841415, 0.045218516170280054, 0.015693391687818803, 0.04326117588789202, 0.03509680558636319, 0.05464719441079069, 0.03870779932185542, 0.07998476547072642, 0.009354996891488554, 0.13125249766744673, 0.04105082633031998, 0.02453623525070725, 0.04161920012847986, 0.009443667768209707, 0.05759963227319531, 0.015740202652523294, 0.048923577123787254, 0.020811473987123463, 0.012802295113942819, 0.02883570639824029, 0.017815010069170967, 0.03711052682774607, 0.0135487648731214, 0.023477570866816677, 0.07776650090818293, 0.032257148195640184, 0.0360385613021208, 0.04494144275668077, 0.040724737773416564, 0.051292082061991096, 0.025688028035801835, 0.0393889127735747, 0.0405305882304674, 0.09042339166626334, 0.022610378728131764, 0.0687885846127756, 0.02506421024008887, 0.011250084899074864, 0.049358475662302226, 0.05152097153768409, 0.04698647891927976, 0.10183926307945512, 0.02537161337386351, 0.004816821829081164, 0.06299094180576503, 0.04189588762528729, 0.03302479235571809, 0.02419401611405192, 0.033403933339286596, 0.021242253606033046, 0.014777125034015626, 0.02249932189442916, 0.06492501575849019, 0.07230125862406567, 0.03504010550386738, 0.01546363204397494, 0.04181677468295675, 0.03422931658860762, 0.07015867086010985, 0.04388365225167945, 0.025383196443726774, 0.009265658081858419, 0.023665378757868893, 0.06514161155791953, 0.04791055296664126, 0.034664875638554804, 0.03203817381290719, 0.033884125150507316, 0.024111468883347698, 0.04646618886908982, 0.035017343834624626, 0.03852048124826979, 0.06592958685359918, 0.07066815524012782, 0.016728839837014675, 0.056010037296800874, 0.021788945559819695, 0.08143534505506977, 0.0404326544230571, 0.04774120599904563, 0.02645334927365184, 0.029417631812975742, 0.0045130366652301745, 0.05081705188786145, 0.040843169699655846, 0.02204058186180191, 0.038462879456346855, 0.03402375652513001, 0.03955199230404105, 0.02324011886230437, 0.02262627924210392, 0.02810908445098903, 0.05867355706868693, 0.020572251960402355, 0.12337323452811688, 0.16275659232633188, 0.12497284478740767, 0.1076761209696997, 0.1793314513633959, 0.17775266576791182, 0.1152053130499553, 0.19486227189190686, 0.1631349095259793, 0.09192995887133293, 0.12121028223191388, 0.151541568338871, 0.19826148636639118, 0.17515516374260187, 0.11763046612031758, 0.16055305197369307, 0.09563067083945498, 0.099106705019949, 0.1032433842192404, 0.08752607682254165, 0.08030331751797348, 0.1111716810555663, 0.11516672879224643, 0.11487914656754583, 0.11588568435399793, 0.1898558475659229, 0.11368006598786451, 0.14025268581463024, 0.13824339519487694, 0.14738194935489446, 0.1110065309330821, 0.15726998361060396, 0.2536250202683732, 0.14627606025896966, 0.07410611724480987, 0.10997638542903587, 0.12518803792772815, 0.10703930631279945, 0.13367479346925393, 0.1641607060446404, 0.20383428811328486, 0.10257122106850147, 0.1495158762554638, 0.1381830734317191, 0.15242359600961208, 0.13561450032284483, 0.16043019684730098, 0.10547338213655166, 0.07173159348894842, 0.13151674676919356, 0.12523657438578084, 0.1139208186941687, 0.10352153374697082, 0.156987878435757, 0.15132503933273256, 0.11800081265391782, 0.15861974243307486, 0.104050046793418, 0.2777892298763618, 0.1697940076701343, 0.08477233044686727, 0.13614298368338495, 0.12574317923281342, 0.12024074050714262, 0.18693476915359497, 0.09828039037529379, 0.08503743301844224, 0.1862516815890558, 0.11159112807945348, 0.09533745571388863, 0.13104928279062733, 0.0911092029127758, 0.12604498100699857, 0.2302442365908064, 0.13288016110891476, 0.07810682756826282, 0.09635943759349175, 0.1733148007770069, 0.10591139027383178, 0.12277395027922466, 0.10449944689753465, 0.13946535618742928, 0.18910598155343905, 0.2294583764160052, 0.10910147495451383, 0.13988171587698162, 0.0889161713712383, 0.12295645181438886, 0.15669716434786096, 0.24006439402000979, 0.10797827155329287, 0.37709039985202253, 0.10762324294773862, 0.11043216800317168, 0.119409735489171, 0.14291181578300893, 0.1357475674012676, 0.06144464001408778, 0.12288243000512011, 0.09454323895624839, 0.11253878386924043, 0.12980103492736816, 0.12217735260492191, 0.0996537420724053, 0.05922884680330753, 0.22532327799126506, 0.15375293092802167, 0.10568614103249274, 0.11339578632032499, 0.105728621565504, 0.11687525664456189, 0.14562090713297948, 0.10785257400129922, 0.2373420330695808, 0.19908397895051166, 0.14967846596846357, 0.09869729925412685, 0.15897101577138528, 0.10379172745160758, 0.08661687912535854, 0.18532291345763952, 0.14250409469241276, 0.0968372100032866, 0.15848606679355726, 0.19120437442325056, 0.12519447976956144, 0.14162773702992126, 0.11129992417409085, 0.12174641713500023, 0.15820869652088732, 0.11431071339757182, 0.22343598160659894, 0.10376617530710064, 0.13290045142639428, 0.14154461649013683, 0.11663729441352189, 0.1601269849925302, 0.13910606765421107, 0.1215342445357237, 0.09985571014112793, 0.1344472949858755, 0.14277949085226282, 0.11096538626588881, 0.09635482885641977, 0.14077828964218497, 0.18050217448035255, 0.24388816149439663, 0.1661744643934071, 0.11253073898842558, 0.10788288331241347, 0.20234791474649683, 0.10364991045207717, 0.20607973012374714, 0.09789168310817331, 0.15325446001952514, 0.1374466996639967, 0.16704835812561214, 0.16417943785199896, 0.10702271189074963, 0.12409633127390407, 0.14126686030067503, 0.15713256754679605, 0.23133198759751394, 0.09236657919245772, 0.16283530450891703, 0.07514552475186065, 0.1824497035704553, 0.12281178496778011, 0.1115719138761051, 0.1740386916208081, 0.24634777248138562, 0.0983951857779175, 0.2166370183113031, 0.16443015018012375, 0.19331009971210733, 0.13447784178424627], [0.027685770837706514, 0.01661389229411725, 0.08440144214546308, 0.1369498614803888, 0.012344149727141485, 0.014019566660863347, 0.04392014736367855, 0.07447924683219753, 0.03238067125494126, 0.06330013537080958, 0.017496393084002193, 0.0137334334795014, 0.06125591185991652, 0.022683018287352752, 0.047691645377199166, 0.004497783675105893, 0.04701632438809611, 0.016678550055075902, 0.06783237186027691, 0.025901794397213962, 0.029201637153164484, 0.0543617792573059, 0.0355388213210972, 0.03968967925175093, 0.08858090615831316, 0.06071543539292179, 0.045775479447911493, 0.03121645306237042, 0.05251095943094697, 0.06109904781624209, 0.031132916919887066, 0.06465643993578851, 0.010060662443720503, 0.04678105986386072, 0.023423700222338084, 0.030934544556657784, 0.060586717299884185, 0.0027956953454122413, 0.04869077281909995, 0.010111913306900533, 0.03800507452979218, 0.026977376037393697, 0.029421984509099275, 0.029031004414719064, 0.023351687777903862, 0.030181529982655775, 0.020252356625860557, 0.0040242637714982266, 0.0788178866787348, 0.012905839557788568, 0.042124331812374294, 0.03805135114816949, 0.040604220412205905, 0.009475009592279093, 0.038258176573435776, 0.10546322955633514, 0.02294136917043943, 0.028333157388260588, 0.09051508401171304, 0.07704517789534293, 0.10766360093839467, 0.048448873494635336, 0.033540276999701746, 0.022438450941990595, 0.0868019336485304, 0.0291201437721611, 0.04385851942060981, 0.03547239539329894, 0.01742323031066917, 0.06526474127895199, 0.057743942888919264, 0.024807709160086233, 0.07142848553485237, 0.04012865218101069, 0.03128113123239018, 0.012491312045312952, 0.0648267479846254, 0.019469121798465494, 0.03513324132654816, 0.07063621320412494, 0.04655340606404934, 0.03433208919886965, 0.03985846589785069, 0.07235867858980782, 0.020822930891881697, 0.056164812194765545, 0.04931517134536989, 0.08927229093387723, 0.01144212674262235, 0.02753077329543885, 0.028898015261802357, 0.007636908321728697, 0.029552897503890563, 0.06580188550287858, 0.010732981445471523, 0.0237233850202756, 0.018061839109577704, 0.05340551084373146, 0.03341146613820456, 0.01743762240948854, 0.08597457257565111, 0.06248188787139952, 0.04434022892382927, 0.018883298253058456, 0.013299463553266833, 0.02381832240644144, 0.04118883240153082, 0.020726394177472685, 0.035707760107470676, 0.05314299094607122, 0.05572241425397806, 0.05212868287344463, 0.027682420040946454, 0.03909757899236865, 0.010015855277742958, 0.04872032142884564, 0.047593893395969644, 0.03289165106252767, 0.027715104224625975, 0.014697805218020221, 0.02029545314144343, 0.061006019604974426, 0.031034122221171856, 0.06149647160782479, 0.07202396998764016, 0.025806717858358752, 0.020221299600962084, 0.035202320432290435, 0.05046711070463061, 0.00747129899536958, 0.029005457836319692, 0.03149773816403467, 0.04656385179259814, 0.012209328397148056, 0.03471889656793792, 0.027840558723255526, 0.020220221631461754, 0.03485702138277702, 0.03468846480245702, 0.03544904742739163, 0.04757729526318144, 0.016384717091568746, 0.05242576458840631, 0.061317836662055925, 0.04164664846030064, 0.030378926421690267, 0.11362497636582702, 0.11015662341378629, 0.02234465275250841, 0.023318662206293084, 0.017288578746956773, 0.013547818634833675, 0.023633755845366977, 0.02860224343748996, 0.02875662499718601, 0.11731579550541937, 0.06563815288245678, 0.038066669076215476, 0.021065036162326578, 0.044835308217443526, 0.030178962151694577, 0.025361779917147942, 0.054881672258488834, 0.06902379347593524, 0.06954733413294889, 0.05970286023512017, 0.01693350561254192, 0.033747733250493184, 0.07555602889624424, 0.05574233720835764, 0.045293658622540534, 0.05861566954990849, 0.03006687002198305, 0.043217122001806274, 0.08552070474252105, 0.04663764724682551, 0.0019690903354785405, 0.046330598488566466, 0.03263971047999803, 0.05027267543482594, 0.04628708637028467, 0.08135675161611289, 0.03204499415005557, 0.0553527801821474, 0.06457058829255402, 0.026960241702909116, 0.03923194853996392, 0.01554804299303214, 0.09199879306834191, 0.01942235350725241, 0.022105137577455025, 0.03424184404138941, 0.027040581044275314, 0.04282875241187867, 0.031031650869408622, 0.0431157743150834, 0.039090591671993025, 0.05020827185944654, 0.02755842015176313, 0.04459444789972622, 0.04575900376948994, 0.0920610295725055, 0.015794127102708444, 0.014136963291093707, 0.044200389747857116, 0.010509898347663693, 0.039951835497049615, 0.011048775486415252, 0.024742748973949347, 0.060641469244728796, 0.009724062292661984, 0.029640415268659126, 0.012878998859378044, 0.04206179844914004, 0.03209946407878306, 0.06000168970786035, 0.03764971566852182, 0.03266724044806324, 0.05507725785719231, 0.04289811353373807, 0.07196853155619465, 0.04137552707106806, 0.01850128701335052, 0.022226577057153918, 0.02776447930955328, 0.0801848410628736, 0.07112970430171117, 0.036864501162199304, 0.05036812675825786, 0.03366149197972845, 0.060843715618830174, 0.0171645899899886, 0.00557751670385187, 0.07997805645572953, 0.07678942638449371, 0.05835427771671675, 0.056590170424897224, 0.0061837803878006525, 0.04298428430047352, 0.014643229533248814, 0.07009754757746123, 0.027022578397009056, 0.031623183385818265, 0.036621410690713674, 0.04516240609518718, 0.04277780026313849, 0.04320759282563813, 0.0423416215198813, 0.0561751799978083, 0.05263392216875218, 0.025300111155956984, 0.03081351696891943, 0.02582861121481983, 0.02323052474821452, 0.009707070821605157, 0.08230543899117038, 0.042177488139714114, 0.06494746572570875, 0.03316091337183025, 0.0737764775112737, 0.027041007779189385, 0.03355455592100043, 0.0023294385164263076, 0.0857392004400026, 0.03239453457354102, 0.10692425115848891, 0.06838988061645068, 0.04350994749984238, 0.01616028050193563, 0.07575718802399933, 0.04276779240171891, 0.07140846981201321, 0.013494922986865276, 0.05905510261072777, 0.04531867270998191, 0.06451133522205055, 0.09523081651423126, 0.050468272165744565, 0.026540412472968455, 0.04339453611464705, 0.025615336526243482, 0.028333597110759, 0.040412093221675605, 0.007543256706412649, 0.051147956983186305, 0.06655043049249798, 0.03751568750885781, 0.09721690759761259, 0.04630346185876988, 0.033850854670163244, 0.1048473508853931, 0.09467145981034264, 0.04892492412182037, 0.039722712244838476, 0.026548115965852048, 0.02885192232497502, 0.03206067573046312, 0.07928526902105659, 0.026221910520689562, 0.015429871746164281, 0.05037075767177157, 0.01811938524042489, 0.033773912509786896, 0.04675226453400683, 0.010041128189186566, 0.006706661924908985, 0.025214192719431594, 0.01785538475814974, 0.01606116296898108, 0.032316720389644615, 0.0687422820192296, 0.05838718083396088, 0.029598730689031072, 0.08829204743960872, 0.004086503986400203, 0.0032759646182967117, 0.0630393075698521, 0.029442081868182868, 0.07351540480158292, 0.04492047337407712, 0.0311053554105456, 0.021356677934818435, 0.11775887251133099, 0.03642883079010062, 0.0482680417917436, 0.04405507352203131, 0.052011334482813254, 0.02201051560405176, 0.016452423224109225, 0.08704676816705614, 0.025054842481040396, 0.07618398973136209, 0.03750153104192577, 0.06271813574130647, 0.041852356953313574, 0.044040108114131726, 0.06958461221074685, 0.013668237661477178, 0.06448098880355246, 0.03404845148907043, 0.05888693194719963, 0.05777758815384004, 0.02097166099702008, 0.028870335008832626, 0.0608167756581679, 0.043694664345821366, 0.0020233376199030317, 0.016646515250613447, 0.041351830295752734, 0.051762243747361936, 0.06507515965495259, 0.02708350686589256, 0.11698651942424476, 0.07025175102171488, 0.14947467221645638, 0.18689896794967353, 0.13098088646074757, 0.12980320199858397, 0.16054147446993738, 0.19543550675734878, 0.26809645467437804, 0.10970170915243216, 0.12501554796472192, 0.09493947160081007, 0.17863441142253578, 0.13638180680572987, 0.09241802486940287, 0.1305646009859629, 0.12967556744115427, 0.13737105997279286, 0.13147622550604865, 0.08604173694038764, 0.17864601861219853, 0.1660503476159647, 0.1580286366515793, 0.10249496539472602, 0.17850425356300548, 0.16643190057948232, 0.1942285816767253, 0.09130564198130742, 0.08020759531063959, 0.12362773923086934, 0.1670030871173367, 0.2542128012282774, 0.11579275262192823, 0.11449107754742727, 0.0888791678880807, 0.13780086737824604, 0.10368189701694064, 0.119528716604691, 0.19123097299598157, 0.1305185878300108, 0.1906464871717617, 0.09770541888428852, 0.17442178825149313, 0.15759271394927055, 0.15253092540660873, 0.08690739283338189, 0.1149411455844529, 0.09567913308274001, 0.13907875661971048, 0.12074575715814717, 0.18652937840670347, 0.1452571657137014, 0.13970797910587862, 0.18432831682730466, 0.11881583181093447, 0.16536463284865022, 0.15775925188791007, 0.20754578348714858, 0.17693351284833625, 0.15325080865295604, 0.21948943322058767, 0.11545250759809278, 0.13895486248657107, 0.06554241583216935, 0.22344463504850864, 0.08982069353805855, 0.07303185848286375, 0.16071961959823966, 0.11380634241504595, 0.1292072722571902, 0.20411686826264486, 0.061298132641240954, 0.21402805752586573, 0.1976340005057864, 0.15465199830941856, 0.17680216755252331, 0.15643509716028348, 0.11605367690208368, 0.08204876721720211, 0.09428781399037689, 0.16075608873507008, 0.13276532117743045, 0.0996260302781593, 0.16418458835687488, 0.1557526329997927, 0.11792045290349051, 0.15422376425703987, 0.24281716818222776, 0.11544870038051158, 0.25563704199157655, 0.14367085474077612, 0.11370118751074187, 0.11643184567219578, 0.19910925650037825, 0.09395799614139833, 0.19358816760359332, 0.12787430081516504, 0.22174861980602145, 0.2273077511927113, 0.19083935650996864, 0.16672504891175777, 0.15053650742629543, 0.0967726728413254, 0.10896791063714772, 0.11395282010198571, 0.058079697919311, 0.12134161268477328, 0.21423835249152035, 0.20584565674653277, 0.19281057495390996, 0.22500847378978506, 0.22836664749775082, 0.10496446921024472, 0.13474228384438902, 0.13581667619291693, 0.21176207286771387, 0.16221521043917164, 0.1254714938113466, 0.11836420526378788, 0.15612906514434144, 0.08096933568594977, 0.16609444603091106, 0.09346728067612275, 0.14197758544469252, 0.20852353336522356, 0.09255978249711916, 0.0757904585043434, 0.15903476625680923, 0.12141527826315723, 0.09059800417162478, 0.18281068420037627, 0.1696992650977336, 0.11654951318632811, 0.1514288064208813, 0.18834685353795066, 0.14515091985231265, 0.14533014851622283, 0.16376867395592853, 0.11104972392786294, 0.151229688199237, 0.14031618396984413, 0.16360669280402362, 0.18452367978170514, 0.14021311450051144, 0.09451680365600623, 0.12098481034627184, 0.14456823002547026, 0.14366843533935025, 0.15959728450980037, 0.17146134632639587, 0.07924806515802629, 0.1526204135734588, 0.09063843637704849, 0.1450784268672578, 0.1063757372321561, 0.34091841895133257, 0.19878950959537178, 0.1277754467446357, 0.1028703065821901, 0.12676343932980672, 0.12205325067043304, 0.11542538210051134, 0.09444274473935366, 0.1851437144796364, 0.18737180507741868, 0.18792415590723976, 0.11131253326311707, 0.10654162950231694, 0.18110953329596668, 0.12955351383425295, 0.21331178111722693, 0.11600547441048548, 0.11196146719157696, 0.14517400064505637, 0.2689484995789826, 0.13611360947834328], [0.04183972559985705, 0.040694799536140636, 0.07973442421643995, 0.01267546578674228, 0.012174639487056993, 0.052736653960892, 0.033199456811416894, 0.018693774145503994, 0.05218048478127457, 0.07033035188214853, 0.02622742838866543, 0.022443853777076583, 0.023886011840659194, 0.02088485940475948, 0.020482570835156366, 0.03466763271717355, 0.016856290712894406, 0.020607548503903672, 0.05642535055812914, 0.06869309989269823, 0.017513907769171055, 0.039590910528204404, 0.05421290814410895, 0.026551073424343485, 0.07940948227769695, 0.04859028602368198, 0.08647049791761674, 0.07483541092369705, 0.009418049758096458, 0.046763463542447425, 0.11681509073241614, 0.09677387512056157, 0.05782911175629124, 0.013221403532952536, 0.03466461588686798, 0.051263231071061455, 0.06200147712661419, 0.04994813054508995, 0.04079185389855411, 0.05584264959907159, 0.03394326318812091, 0.03804657913860865, 0.02937596207630122, 0.021317177124728914, 0.018904438329627737, 0.07102287956513464, 0.09273026123992167, 0.03185663706972264, 0.03595349262468517, 0.010177638832828961, 0.04103524493984878, 0.022001637662469875, 0.033022376665030606, 0.018541528115747496, 0.02223269792011706, 0.028023585327900946, 0.018242503829242196, 0.026834497766685672, 0.03590723455999978, 0.017157955189759377, 0.02211684866779251, 0.014269254825194366, 0.033020447081071325, 0.015874974815233145, 0.08227207203162834, 0.046148304754751734, 0.024395780092163477, 0.04120350095035974, 0.01933716794155771, 0.08953019467298873, 0.01614172495465027, 0.0545488375792047, 0.07846262058592401, 0.02588437062513549, 0.035029622667934746, 0.07836045653675683, 0.004406764828672749, 0.03320621035527438, 0.07089548991643824, 0.013948934611107688, 0.03233307732443791, 0.04348389069491532, 0.03990633071225602, 0.03085761909460416, 0.03825329324172344, 0.020614888344425708, 0.011405720688344445, 0.07118402209016494, 0.06726794628775679, 0.029592058781418018, 0.05362558731576428, 0.055347451561829075, 0.02224720134108793, 0.05846296524396166, 0.0055121075183706125, 0.06695496034808457, 0.03342875075759366, 0.0759627109800931, 0.021565445931628346, 0.013720947772526415, 0.08225222700275481, 0.07798183505656198, 0.03336151588882785, 0.019251179001003038, 0.0026991066806658637, 0.046990430855657905, 0.023271496866072994, 0.03581583536288235, 0.0494252541102469, 0.046947063456173055, 0.04560870773275383, 0.1478302659234032, 0.013848124053765787, 0.012920227945869556, 0.03280257107689977, 0.04607722927175928, 0.07045011967420578, 0.026587844986352138, 0.0533055992127629, 0.023790341583662666, 0.024820275575621054, 0.03393580831470899, 0.031296456581912935, 0.04110349284019321, 0.031889673773548566, 0.07547367276856676, 0.01736990514473291, 0.027448385626485106, 0.0010478935018909397, 0.032885687905945815, 0.036016434169141576, 0.033295268076471984, 0.009398145357408794, 0.019304057022964116, 0.03833819122519344, 0.060326286547933705, 0.015197109187283786, 0.09931748238159344, 0.036757995549123734, 0.04370656839455478, 0.019261351990280673, 0.043265057320240885, 0.0362381470768014, 0.030383609373529907, 0.055204083473654464, 0.03776501944230404, 0.03610529893194325, 0.07399123278446496, 0.055298106162808836, 0.04732770728878677, 0.06133068694907706, 0.04551295583951287, 0.056154622507165186, 0.044346314534777775, 0.03437508923525456, 0.016700807063898537, 0.02286418210132979, 0.05875297058082651, 0.05266386782750487, 0.07494360121199861, 0.02830865909345448, 0.03643550269771367, 0.031169786816462874, 0.021429655171232298, 0.02375684660364641, 0.027228834223933518, 0.008274460487882607, 0.009041792945936322, 0.08932097582146525, 0.04211600491544232, 0.020862993878836278, 0.054817580385133624, 0.04854091093875468, 0.018685951908992138, 0.012733698404190363, 0.01460330013287603, 0.05091954619274475, 0.03338945403811522, 0.026114388165296987, 0.05291384914016817, 0.023605198002769612, 0.03468909933872055, 0.014717796821059892, 0.04542020964436233, 0.07036135139060207, 0.04661092993046623, 0.012568847923830617, 0.054044529679231346, 0.00469300562144781, 0.00977408768449095, 0.02826132305926876, 0.04103724873857573, 0.02206209857831709, 0.03977621367084794, 0.020908637816319242, 0.07218688624561764, 0.04937717407301534, 0.029734398995060474, 0.03866124068736099, 0.014382601184479427, 0.08068901166552678, 0.03289724685600959, 0.05608928011497483, 0.016554433277633507, 0.0719406564894598, 0.023872655037848745, 0.019968431333836634, 0.024045569880399853, 0.028707136734738015, 0.04866882380156312, 0.03165522932249587, 0.042853569830185734, 0.03250103647587821, 0.0019960043209721334, 0.05369181286368985, 0.03502167426631786, 0.025670249888207763, 0.08007049837033264, 0.08275456450064667, 0.06302934052655473, 0.024003699763852637, 0.060592019945033826, 0.06523757867398672, 0.0326693741226336, 0.03283471720351372, 0.060704102797899395, 0.012018082506983774, 0.03598670744395349, 0.04365151216916274, 0.039508847548859194, 0.06501920172013342, 0.018565039354143664, 0.030979073417256586, 0.03415028899325989, 0.022185686575539876, 0.01323295784459333, 0.02926061748439679, 0.02210985949204769, 0.05603065415925812, 0.03563721897080541, 0.07686641678446904, 0.04269962984835729, 0.05709925033443142, 0.024419426772510633, 0.08397376470384188, 0.07803679109201767, 0.06544136500451714, 0.016331607148458716, 0.07594151524244808, 0.03768205104279332, 0.04347433183284011, 0.017589510352991056, 0.03580278469598852, 0.049201682122657076, 0.05128065669850912, 0.0629585025308188, 0.02476041208865354, 0.05006515610148199, 0.03570287677575834, 0.02119043499988038, 0.031431468087248504, 0.03695054576382972, 0.022992005906417035, 0.0376338745263638, 0.12205567007185891, 0.04014978854684159, 0.021895840800425503, 0.02916074296081206, 0.025473094647168182, 0.00698170324540115, 0.03851716384815518, 0.10684644439606927, 0.07167250369093381, 0.015541697630396811, 0.032452626182930544, 0.021500135080714244, 0.06807732512243092, 0.04229835802107118, 0.027844920696225017, 0.02790303828078322, 0.044194775400683284, 0.031325489399023354, 0.05534300238650758, 0.02166726117138751, 0.058459525389480405, 0.025497542847006116, 0.052767174784094095, 0.049184994932147674, 0.060063595956307836, 0.014439804072026163, 0.05937360641837586, 0.07000561032327823, 0.019846316499751993, 0.026813511685759295, 0.041138232772937045, 0.047717294000904076, 0.009586522846802836, 0.04261212692654226, 0.055857581610325724, 0.022700371555401944, 0.008878640128386905, 0.04133975184231531, 0.02367621968005551, 0.018460450337443035, 0.04446512866707053, 0.0369457477791002, 0.022235111755435355, 0.021938794452580623, 0.054668108132318594, 0.029531968939409126, 0.07483167049940675, 0.016081013563962188, 0.035023678065044805, 0.04806215518328827, 0.014237696850614157, 0.02686080875719199, 0.02012702272622846, 0.004890073660135386, 0.026266311360814143, 0.02294647700182395, 0.0381104186817538, 0.1264705284847878, 0.03802437779086176, 0.03979602159233764, 0.04023543238872662, 0.025803704738791566, 0.05244185435003601, 0.09009122120914981, 0.09050561420735903, 0.029709108457609545, 0.02917945064837113, 0.017681670251477044, 0.06410302041331306, 0.03800899678026326, 0.028638857293117326, 0.02233539074950386, 0.03122301735857036, 0.07650632673176005, 0.015082290592545178, 0.03543284263287205, 0.011450616912043188, 0.035107325529679656, 0.09714499348774552, 0.024280209145217668, 0.024742858440731652, 0.03401935187866911, 0.017996862225118093, 0.010755969469755655, 0.03172889490087982, 0.030190137040335685, 0.026131999329663813, 0.05656832901877351, 0.08730243062018417, 0.10512938184547238, 0.18084117269609123, 0.15521211200393736, 0.0828919063496869, 0.22491824347525835, 0.10429010930238292, 0.09965546385501511, 0.16039543465012684, 0.1342285395367071, 0.10494724396266975, 0.12051820725901052, 0.13901378901209682, 0.06780361363780685, 0.16538732772460207, 0.14427367161260918, 0.12804134341422468, 0.21634869393892586, 0.09989724814658985, 0.2000496763503179, 0.16781778715085238, 0.1323985814815387, 0.23692561400821432, 0.07139093286241405, 0.14824051031609997, 0.12940434215124696, 0.21677427110262215, 0.12299229754717089, 0.16100453009130433, 0.17373338690958917, 0.2454063284676522, 0.10147790395421907, 0.1573654089588672, 0.16388387011829764, 0.109562712314073, 0.11002864746842533, 0.12235920105013065, 0.08914837453630753, 0.1711370871635154, 0.14666770643088967, 0.13989645492983982, 0.15590652474202216, 0.20167086826404557, 0.10763202997623011, 0.1294886798132211, 0.13350751338293776, 0.20896880712825805, 0.1164943864569068, 0.06984687977819704, 0.2135611724224873, 0.10745412975666113, 0.10691686678910628, 0.16430975898401812, 0.12782730802427977, 0.08957365484093316, 0.06636045553022996, 0.09267650748370215, 0.09973482170607895, 0.08993542214739136, 0.06755462309229188, 0.1406120485626161, 0.12398848237353377, 0.1531608751975, 0.16334824729710817, 0.23567617870867252, 0.1306094415485859, 0.17123954807175323, 0.2108200202928856, 0.1937148522119969, 0.16105465474538505, 0.14852960652206093, 0.13163753872504458, 0.1330626997514628, 0.12078523941454478, 0.12543992284918204, 0.31094806152395904, 0.11296043507172726, 0.09561416547512636, 0.2320759164285846, 0.12859750888310373, 0.11082919474574737, 0.08656492878799327, 0.15211210178676993, 0.12137345824157819, 0.07965499957208522, 0.11292259296169505, 0.07068627848639153, 0.17785569070838392, 0.19651966576930135, 0.11176908024935983, 0.18697992141824216, 0.1464602316264063, 0.11062046571169049, 0.16040233662351966, 0.15219059132505208, 0.25814924156293273, 0.11710374164977111, 0.08520964096533135, 0.06605438640690409, 0.1481106344726868, 0.1499682301073335, 0.17978404270252213, 0.20560165343340486, 0.10160182035178877, 0.08306185074616224, 0.12904186238301918, 0.14745442749699578, 0.14831589767709374, 0.11633592308498919, 0.15268575225491077, 0.1331772279809229, 0.2596163784619421, 0.1613069701124914, 0.1618957900791429, 0.1666171703254804, 0.15660951670724899, 0.1410069304984063, 0.12308947436395101, 0.14659751410363242, 0.08919103318476118, 0.14988424867624417, 0.15308988135075197, 0.18318971386179328, 0.14482801139820367, 0.0809969064721372, 0.11873467796249315, 0.13395554793532938, 0.072718857700238, 0.20352702413219959, 0.12671951903030276, 0.15130258194403723, 0.09524161476292647, 0.22387801960576326, 0.14619669498642907, 0.14618924382375553, 0.14725490851560608, 0.09843914318480529, 0.26296388008631766, 0.12261208044947125, 0.13759213092271239, 0.10551972925895825, 0.13334499788470566, 0.1305113741545938, 0.10691553834476508, 0.1980670288321562, 0.24661013652803376, 0.14526363724144176, 0.24297741270856932, 0.09706123470095918, 0.11935911359614693, 0.24268601584481075, 0.22151448705699295, 0.23896879109088331, 0.15634679642971605, 0.1205762654717546, 0.13049148459685966, 0.10970475937938318, 0.19790435006143525, 0.14488085231278092, 0.14101718697929755, 0.14584390766685829, 0.15822091227164492, 0.15855389909120277, 0.16181278828298673, 0.1603312388760969, 0.12393254670314491, 0.14953653764678165, 0.08919864019844681, 0.2366797553258948, 0.20570248161675408, 0.12555517838336527, 0.09151120946626179, 0.264084434020333, 0.1125497899192851, 0.06874039696413092, 0.1072361164551694], [0.02150309068383649, 0.02855728227586951, 0.02100571073242463, 0.01610949719179189, 0.011729021553037455, 0.07615903130499646, 0.09954288005246781, 0.023865103685238864, 0.0262410022696713, 0.038342213665600866, 0.05486881454999093, 0.06327301729470491, 0.013771167050435906, 0.08508513084962033, 0.06304082897258922, 0.04540943366009742, 0.03780269456910901, 0.036964030587114394, 0.08583671122323722, 0.02476886143995216, 0.009983468880818691, 0.03807614259130787, 0.025575358886271715, 0.05508173671842087, 0.062331113149411976, 0.027443750914244447, 0.044577115040738136, 0.04376585115096532, 0.011599157769524027, 0.016253397770924494, 0.06615062069613487, 0.0323444544483209, 0.040235666165244766, 0.05605497062788345, 0.06511837491416372, 0.049349844484822825, 0.05416988213255536, 0.059099045174662024, 0.050023191361106, 0.028337241055851337, 0.028146911718067713, 0.08923784786020406, 0.07970809281687252, 0.020245653176971246, 0.06231307896086946, 0.06835541527834721, 0.05610013773548417, 0.03669003337563481, 0.0457678872771794, 0.00864823017764138, 0.018661216126929503, 0.03183899993018713, 0.008244434120570077, 0.018073600294883363, 0.061875731335021555, 0.027872942337126005, 0.05100731257698499, 0.0446633488900261, 0.013420620089164004, 0.02982287413033191, 0.030638357129646465, 0.046140018675941974, 0.07273075432749465, 0.0734997157996986, 0.02584193276561564, 0.0698454919620417, 0.012609191071533132, 0.052384044756763615, 0.009636628947191639, 0.07750843389658257, 0.030170019272190984, 0.08444111736025661, 0.043199588762945496, 0.005131751731823897, 0.009326611598226009, 0.01856304854300106, 0.03789968213823158, 0.004556954181680339, 0.0410015774104977, 0.04980495541531127, 0.037317715905373916, 0.08241679825005122, 0.044382887572282925, 0.016480919839523267, 0.034088668471667916, 0.06343067914713174, 0.04883782567048911, 0.0195770133723272, 0.019262329769844655, 0.05321919466950931, 0.08353614990483038, 0.018982217261509504, 0.022170157135406043, 0.006719120729030692, 0.018760790080705192, 0.025059293511731084, 0.0037552048570432817, 0.043928103186772205, 0.03918680740753189, 0.08510519852279685, 0.01981585690373322, 0.02954944095108658, 0.03979827401053626, 0.0509875677380478, 0.06102745282987598, 0.008020196055440465, 0.026614914822857827, 0.07180524422437884, 0.020574294721882325, 0.01403359789037495, 0.03753648619749583, 0.03754171833861619, 0.019963701997767203, 0.03952889295760542, 0.03899376366462093, 0.13346866937354207, 0.013752550275967224, 0.022819159712526016, 0.04688848202931695, 0.009914619840856176, 0.08026558673009276, 0.005016249433538178, 0.04681872756918892, 0.04841748064791318, 0.007914522575447336, 0.027496098300616723, 0.06263193528866395, 0.023233812462422065, 0.019263524627604056, 0.026048424224427436, 0.029648777417605743, 0.02461302898154827, 0.043284360581310466, 0.08577598870033398, 0.04489505852689035, 0.04611435149854515, 0.01690744138613809, 0.09550314760417677, 0.020428390344022773, 0.08168340791598894, 0.006633883676840924, 0.040733565620030276, 0.028241084692126606, 0.009374366945849033, 0.04915632205666043, 0.05693556224287022, 0.06656495432252996, 0.022693105929647572, 0.0301366411804338, 0.018868574043153785, 0.020655563603213523, 0.06490678119007498, 0.04084493230038788, 0.019197525434719864, 0.10767013925942592, 0.05282043872284703, 0.06557452114066109, 0.047755425548530184, 0.026118551613762975, 0.0530100055038929, 0.027998816149192862, 0.09785818998352624, 0.04187805010587908, 0.03333608990942594, 0.0029011111610088847, 0.03226856242690701, 0.02403066941042198, 0.0381921514053829, 0.048204922131844796, 0.08489310755976476, 0.02400500037765596, 0.01655254265642725, 0.023290069111681078, 0.03254570263379719, 0.029460036275850143, 0.0397111978236353, 0.0425548405473819, 0.018420504238747526, 0.04905764610157348, 0.023633102755411528, 0.111440605687676, 0.057404491963097826, 0.03343270640471019, 0.0319926022348227, 0.06193698078277521, 0.027432056522229686, 0.05486309630214237, 0.08982090876088478, 0.04426203995535616, 0.07034656780888326, 0.019667356864374597, 0.02162375647458248, 0.025625598573242314, 0.06212028383743018, 0.01456389394661528, 0.03430000244406983, 0.043297786032781005, 0.037164788955124095, 0.006861700285298866, 0.07724061506451108, 0.023064224296831526, 0.058457540144445375, 0.02732547483901726, 0.02347558747715084, 0.011607150700001512, 0.024769889314484317, 0.02669040422915714, 0.05066380210337229, 0.08000959031051025, 0.009699324655230157, 0.03437606144871097, 0.008565163443563506, 0.03863645295496099, 0.016673505306243896, 0.013557214224420022, 0.0323632233630633, 0.03963424824178219, 0.033148033398902044, 0.023335418045462575, 0.06424197272281162, 0.05191787953663152, 0.06366695670294575, 0.06187790211697575, 0.04373321520688478, 0.07996930653462186, 0.008598492368037114, 0.011712700797943398, 0.030321246704261284, 0.022679110879835207, 0.06011566874803975, 0.03500864957459271, 0.038302367756841704, 0.04890052601695061, 0.02085761330818059, 0.007714976227362058, 0.03208899979654234, 0.011590531230467604, 0.04468614766665269, 0.0528096664493205, 0.04597155857481994, 0.03185536428645719, 0.052249022119212896, 0.029935444945294876, 0.055233016100828536, 0.041464499445282854, 0.04922610620269552, 0.024475317914038897, 0.11922010191483423, 0.03427987910981756, 0.03515804019116331, 0.021317947102943435, 0.021251459947961848, 0.035284383411635645, 0.03095485157246003, 0.030764947114221286, 0.038171798005350865, 0.044104211119702086, 0.05201783940719906, 0.045810746305505745, 0.017478997142461594, 0.0334855547407642, 0.01336023617113824, 0.04402737286000047, 0.08730500587262213, 0.01364015201033908, 0.07334688532864675, 0.05280657911498565, 0.027971059826086275, 0.03790574919548817, 0.01917265235533705, 0.03413914564589504, 0.029285826385603286, 0.06570354351424612, 0.01694127218797803, 0.07258816549438052, 0.03213054522348102, 0.00919543328564032, 0.03113571110588964, 0.028317152973613702, 0.06002822890877724, 0.02459634364640806, 0.03074733594985446, 0.012757589993270813, 0.025990391986852046, 0.04202529220492579, 0.0437616060662549, 0.03281703553511761, 0.056791926981532015, 0.052542203848133795, 0.12233528163051233, 0.04632439784472808, 0.1579956110799685, 0.02102823491441086, 0.04951201488438528, 0.01843267360527534, 0.02759949245955795, 0.03548144959495403, 0.05025865997595247, 0.020235289084666874, 0.011236518439545762, 0.014998435326560866, 0.027286504664516542, 0.051114230082021095, 0.03676143540360499, 0.05944816628471017, 0.02376772834395524, 0.010327134277758887, 0.07443775335559621, 0.027225468584219925, 0.06834742234786972, 0.034213557082694024, 0.00854292869917117, 0.06385830463841558, 0.07027906947769225, 0.04038027364003938, 0.05520008329767734, 0.039655555301578715, 0.057941613922594115, 0.038220364149310626, 0.06756445654900745, 0.015901643891993444, 0.08323076355736703, 0.05141201683727559, 0.03199847633368336, 0.07789702242007479, 0.0392043554893462, 0.02483172320353333, 0.09567502158461139, 0.04651917079172563, 0.02765901826933259, 0.03054930126381805, 0.05276213931210805, 0.10395105913630687, 0.04313492914661765, 0.012167586301075062, 0.03292739660537336, 0.037574806992779486, 0.03555136361683253, 0.05978870816761628, 0.04774297973199282, 0.024886491846700665, 0.04739445976156276, 0.039356139532173984, 0.008840097616484854, 0.027249284103163518, 0.03529386063746642, 0.08938806597143412, 0.0616360102139879, 0.006394726588041522, 0.007106565417416277, 0.05693043029168621, 0.04365970547951292, 0.09321687262854539, 0.12696747056907043, 0.1390248618554324, 0.06990458918153308, 0.14405214053113014, 0.1593471658998169, 0.18603564240038395, 0.06038825216819532, 0.12894413637695834, 0.08065241636359133, 0.1734238667995669, 0.1666232559364289, 0.08057014187215827, 0.23737856157822534, 0.14029360783752054, 0.14697215025080368, 0.10578135115792975, 0.16661528527038172, 0.2376601769356057, 0.14908413926605135, 0.14532845641952008, 0.08820871909847483, 0.14063299197005108, 0.21800000220537186, 0.20113273698370904, 0.1700855529634282, 0.14445471111685038, 0.20708216383354738, 0.104896993143484, 0.10637725121341646, 0.17369403823977336, 0.16464463085867465, 0.16925957228522748, 0.12974001554539427, 0.1410292839864269, 0.10560336188063957, 0.3053335956064984, 0.1454533895594068, 0.07038947878754698, 0.08980107115348801, 0.12306415228522383, 0.18610878847539425, 0.25628814299125224, 0.10699201666284353, 0.14173804986057803, 0.17708152678096667, 0.21116692980285734, 0.15324165055062622, 0.22055263398215175, 0.10013392646214925, 0.06881617766339332, 0.14337356522446498, 0.11341721954522654, 0.19113167363684624, 0.12959611311089247, 0.12084725327440538, 0.2095803219708614, 0.10146369182621129, 0.09131825107033364, 0.07300050274352543, 0.11526549380505458, 0.1132676619454287, 0.2216877488535829, 0.3084684570785612, 0.12355295300949365, 0.12796280934708193, 0.09555760640068911, 0.13542059197789058, 0.15626674838131294, 0.17502125061582774, 0.16341477341484278, 0.16616735461866483, 0.14881962299114093, 0.07072178283124231, 0.12099694446078502, 0.10087131697218865, 0.1680217738612555, 0.09008613007608801, 0.17214551742654294, 0.180213256389834, 0.10619838620186783, 0.14961244451114908, 0.10383699845988303, 0.09114838088862598, 0.11151688362588175, 0.15932154696201906, 0.22767220507375896, 0.16331746301148087, 0.1385397496051155, 0.2242522401502356, 0.13884343643439934, 0.11927735860808752, 0.11874886040459387, 0.1453703283914365, 0.14966372691560537, 0.14722069550771266, 0.25923580513335764, 0.09549241614877246, 0.11126407101983204, 0.1741694877273403, 0.08322673369548284, 0.09057926494278945, 0.1825089121120982, 0.24406903772614896, 0.11915920869796537, 0.096315161063103, 0.08871911632013507, 0.1325788936810568, 0.12033217310090549, 0.09424335934454575, 0.11755248124245554, 0.19921639293897897, 0.09364880999783054, 0.22155337559524924, 0.16972819401416928, 0.2751135203288868, 0.11596201424254104, 0.14111742144450545, 0.10296902706613764, 0.08641432475997135, 0.21379805111791939, 0.1301244183559902, 0.09720725225633942, 0.10193568290560506, 0.08804103825241327, 0.15298645565053448, 0.10363320470787585, 0.10611004836391658, 0.23441675410140306, 0.12870089005446061, 0.13959855685243383, 0.1758415761287324, 0.1083058852236718, 0.1787392917321995, 0.10055735139758326, 0.08137582481140271, 0.12440322418115102, 0.1864220786956139, 0.08052785429754294, 0.17943618324352428, 0.26549590984359384, 0.11127365956781432, 0.15804402879439294, 0.12116831378079951, 0.1731308372109197, 0.1929925347212702, 0.19225271738832816, 0.12338227388681844, 0.09242471904144622, 0.14770999347092584, 0.13499099237378687, 0.1858403833466582, 0.18389614939223975, 0.09329251231974922, 0.16626844997517765, 0.15659047319786623, 0.2196206004009582, 0.14938225998776034, 0.12852316052885726, 0.1686426397645846, 0.0769866669725161, 0.1494708427344449, 0.15727615827927366, 0.12875016866018996, 0.15347183507401496, 0.1473656072630547, 0.08309303579153493, 0.12115305522456765, 0.21929792943410575, 0.1893508160719648, 0.2117433410603553, 0.1429684564936906, 0.04926129142404534, 0.1533296098932624, 0.15325162501540035, 0.16348518838640302], [0.041545497442712076, 0.038188470352906734, 0.07525612702011131, 0.08697161087184213, 0.05633022577967495, 0.07223476961371489, 0.10204164675087668, 0.00971930698142387, 0.049185065436176956, 0.08811721971142106, 0.05419944558525458, 0.02243309634650359, 0.04124992228753399, 0.04352745847427286, 0.06150696557597257, 0.014790098703088006, 0.0560041891731089, 0.032559591927565634, 0.06210547056980431, 0.03039442432054784, 0.060997996988589875, 0.06625782392802648, 0.058884553363895975, 0.019365970692888368, 0.0207159002093249, 0.039329815554083325, 0.03284311831521336, 0.054662360198562965, 0.0897879945114255, 0.031146769106271677, 0.03875438022078015, 0.011680548177537275, 0.029418301601253916, 0.06461692057200707, 0.006895646120028687, 0.008433456350758206, 0.02860356446035439, 0.03163491302984767, 0.01755219516780926, 0.07769617499434389, 0.025377496749570128, 0.017264401431020815, 0.02707173454837175, 0.011033342525479384, 0.009313736263720784, 0.02322787157027051, 0.04506876561208628, 0.033158386358991265, 0.01858961742982501, 0.03293347850558348, 0.04364108870504424, 0.05376643210183829, 0.06392471943399869, 0.023169214073277544, 0.01572080291225575, 0.012198922559036873, 0.03396205807803199, 0.018079223918903153, 0.014577018828276778, 0.031016652064863592, 0.029592993887490593, 0.06278596061747521, 0.053447319733095355, 0.019458588867564686, 0.03295606205938384, 0.020996112907596398, 0.040945704822661355, 0.04891545802820474, 0.01801567937945947, 0.068621222890215, 0.05160618864465505, 0.033859920004033484, 0.007547794011770748, 0.03452078024565708, 0.017719590287015308, 0.03896104608429596, 0.03269245120463893, 0.03936604720365722, 0.05058537564764265, 0.0022263106029640767, 0.020687672622443642, 0.024540157501178328, 0.030254995181167033, 0.03185965018928982, 0.02847092411684571, 0.02907997688453179, 0.02058163270703517, 0.033888804391608573, 0.018421456043142825, 0.0625001298612915, 0.05193101926124655, 0.07242590974783525, 0.08005791154573672, 0.04687936474510934, 0.0284365552579402, 0.018923654388345312, 0.05509991562576033, 0.006737839548804914, 0.05004226455639582, 0.025779696261452045, 0.07480585860321298, 0.037194946125964634, 0.016536640287085902, 0.05717841151636094, 0.027599694694799837, 0.017610943577892613, 0.03322190677863546, 0.01448088843972073, 0.04006066774309147, 0.05706392781576142, 0.0298272583677317, 0.05039469564508181, 0.012708726990240393, 0.030423345815506764, 0.03350392289576121, 0.035004181845579296, 0.047645799204474315, 0.09588088592863642, 0.0674407256883569, 0.0557400217076065, 0.04927208225126378, 0.045818468352081254, 0.009795001406018855, 0.03161142776662018, 0.026230599214613903, 0.067910831712652, 0.02942118670034688, 0.039465298323193565, 0.04955161588441115, 0.01843492416810477, 0.054613437823718414, 0.018263376732647885, 0.03073749136092374, 0.025676391160232015, 0.07432567421346903, 0.01788601319276495, 0.0365232282638317, 0.007897194354882231, 0.0519475394685287, 0.08225181140005589, 0.025219920244126115, 0.08035108214244246, 0.010551032810326433, 0.03498353900795337, 0.04906868183752522, 0.05190954892896116, 0.03517386277962942, 0.03640612478193361, 0.10495660244487226, 0.04306257345888298, 0.09851873110164888, 0.025906258415488992, 0.013597270717582433, 0.032400286218035035, 0.032636860632919706, 0.02589258805528516, 0.05689875913958531, 0.015792509220773354, 0.027951318697887473, 0.06778966868296266, 0.029149965121177956, 0.01978042120754253, 0.025190956075675786, 0.03280148754129186, 0.017946236621355638, 0.057408577486057766, 0.03906451631337404, 0.0664171036623884, 0.06584507849765942, 0.05111615595524199, 0.05394529340264853, 0.07365146273514256, 0.011090265252278186, 0.11215162026928738, 0.02532242568122456, 0.02701840567169711, 0.06121535348938778, 0.010409816950414097, 0.04824475690838881, 0.016175763557839673, 0.05262337625026703, 0.021582795488939155, 0.048857466608751565, 0.014958642295823665, 0.038767456862842664, 0.017493764025857672, 0.027916237377212383, 0.036190349055686966, 0.037454196863109246, 0.031976853861124255, 0.04719179036328569, 0.040160623902920634, 0.03605845085985493, 0.03563775331713259, 0.012574391766975168, 0.06976715085329488, 0.020859604119323194, 0.03520054669934325, 0.0480734803568339, 0.012401341482473072, 0.01207946832437301, 0.06018382016918622, 0.02797909728542436, 0.04994893206458073, 0.045186555580585264, 0.06442433324991725, 0.06291017387411557, 0.024798762569844257, 0.03517474222462624, 0.08837490080622956, 0.022286524035735056, 0.020563704274536576, 0.019029564427910373, 0.045737841428490356, 0.09194402256980538, 0.015333546543843113, 0.01312489186602761, 0.025883838134177495, 0.021657088182109874, 0.07485048394300975, 0.03738446095667314, 0.034221650203107856, 0.015024896601971705, 0.018315308516321238, 0.03901887052052189, 0.03222924344299827, 0.006362224694385077, 0.030051832254684996, 0.006571651347258012, 0.03802139064646326, 0.030371187676792033, 0.007933882425277261, 0.054312407883116975, 0.08416076365392655, 0.07960229224408977, 0.04594068152073305, 0.01141734550401452, 0.06867586722364649, 0.06181476390338503, 0.05320592877978925, 0.05182846558454912, 0.009576811844453914, 0.1044347464630846, 0.050042591101373546, 0.04074182201293297, 0.006206455782375997, 0.06681082784780301, 0.10123634230694734, 0.03567371779354289, 0.020171102587482892, 0.06600849941605702, 0.040070631075650454, 0.026707763063313905, 0.023589948723383714, 0.04540744841506239, 0.028837814097641967, 0.05752446384576615, 0.02901738786022179, 0.08085732333711348, 0.0014733257148691337, 0.08478683943394572, 0.03493864649499301, 0.023970551737875212, 0.028634371010411996, 0.03189541799656581, 0.05975871055852622, 0.04139807351748459, 0.04866478280746378, 0.0383006199990632, 0.0362819894507993, 0.057245768839493394, 0.07160297929658554, 0.011528130526130553, 0.10545744822593406, 0.07170400785980746, 0.03280462682596408, 0.08983388892374933, 0.02843311169272056, 0.04583685877150856, 0.02207833491411293, 0.05155486913281493, 0.04133010021178052, 0.09594300368917175, 0.03272039677540306, 0.06331428070552647, 0.03233308103517629, 0.024954569053079467, 0.020047306788910646, 0.01568780146044446, 0.014178143210301641, 0.02026736841798993, 0.08434745090198703, 0.01879624989669537, 0.08974206299171783, 0.06469468280556612, 0.06195757167006377, 0.1131908199749887, 0.046601148424088024, 0.05512052135600243, 0.01680596196820261, 0.025406459062651265, 0.023637576050532516, 0.029494911650544964, 0.03158828760206234, 0.042931354328175075, 0.03947907629481051, 0.049983100543613546, 0.03213996307749767, 0.03481706044112798, 0.006723950718878768, 0.049782802307163365, 0.0941981773939915, 0.08176951188943349, 0.023944654494698625, 0.035073802719125524, 0.08563612354919314, 0.007030084780126344, 0.03289065287390258, 0.044449962879298255, 0.036495753956842236, 0.05351898151275236, 0.060534778094734065, 0.02118205800798023, 0.021885591741011012, 0.02777183399302885, 0.004893300147159607, 0.017036960998666473, 0.043677932626451366, 0.023559839792142157, 0.028300404555920977, 0.02870019950933056, 0.024060846990323626, 0.06964167594560422, 0.06876862826175056, 0.04751515523821581, 0.06301794113824144, 0.03773356351302937, 0.03793675612541847, 0.03609603321820032, 0.03308489147457294, 0.02016792248468846, 0.022365668519341853, 0.06088145753892604, 0.03123682501609437, 0.10255196975776926, 0.018373151506239083, 0.03384722185728606, 0.027412077906774357, 0.04046979891427327, 0.039502743384218775, 0.03856553703371901, 0.03176425823767204, 0.23753647576086223, 0.11524244269821793, 0.11897586853592657, 0.19007699273061007, 0.17541329754749313, 0.18437103484757245, 0.1971187867457047, 0.0811221290496178, 0.12701383995590732, 0.26953708205837756, 0.1227007745183073, 0.0894480240822304, 0.1463138949475251, 0.16819448646856472, 0.17475364700658247, 0.0958269985858351, 0.12062303561833687, 0.07185697191744111, 0.10306519456207752, 0.15379371936433017, 0.1422487068339251, 0.17455455847084522, 0.15439282549778, 0.1191777920757886, 0.14790382760111243, 0.22586026636417955, 0.16652791964588687, 0.13891330221667886, 0.15286903304513544, 0.22844206454465166, 0.14543403434799984, 0.11782939880504273, 0.07419029163429514, 0.1787468171096407, 0.18428332783514634, 0.11714487147401087, 0.10822434545843862, 0.16545505612157285, 0.14391729229828343, 0.23311398806981742, 0.14426973822992295, 0.13436199253192171, 0.1027303004229907, 0.1890376297524199, 0.14093844511080533, 0.1683838083408773, 0.0916556833544746, 0.10524488228838891, 0.0891556178976316, 0.06970532995183021, 0.09997397879487835, 0.10912426630966365, 0.08556319269700907, 0.11103082884801552, 0.11707449360983446, 0.0659113671281375, 0.32255528087262064, 0.14523130928864703, 0.18195072800153866, 0.09676435336587019, 0.10890283912885934, 0.13926062732934952, 0.14322788163553923, 0.18261984834680334, 0.09297912562033162, 0.08164227067027241, 0.2142476144945249, 0.23194517969386652, 0.1896753572509624, 0.19886023626895621, 0.1507962739560753, 0.14044800424017012, 0.12013683241093531, 0.2290470781736076, 0.12555777590023354, 0.13097739836666733, 0.18366329313721508, 0.09588530170731246, 0.1606813693069853, 0.14275120018282905, 0.12469669163692743, 0.08892877303878777, 0.1609519711928442, 0.12321348724071868, 0.17329241760307923, 0.09724937655846588, 0.07562956830952317, 0.13226811191998422, 0.16575427522184327, 0.1764901983551681, 0.19996389892185107, 0.2020016880123876, 0.1013279530161526, 0.16765219916123897, 0.14664606540463865, 0.14207290689228103, 0.131383546104189, 0.13888901914469898, 0.16209299355978146, 0.18577262526378036, 0.2377580662141554, 0.09673814070993103, 0.1272144276299514, 0.18523492442909628, 0.18138460291083902, 0.1018748119531665, 0.21006555296480656, 0.06948854119400494, 0.11462369191576727, 0.183467885653954, 0.13199927634559572, 0.18681813322473317, 0.11258006212301552, 0.09123919749981724, 0.17069639987312257, 0.13979007548186928, 0.1708862857776694, 0.1145975237886887, 0.13967793696792796, 0.1981380078359507, 0.1671845867531374, 0.18458713340805843, 0.07116264081560075, 0.12764383427565917, 0.1966250062105246, 0.17136918642790988, 0.07557808552519418, 0.18624388903845102, 0.12746901396894827, 0.0818833573430311, 0.11010346337570809, 0.12922775553306565, 0.10178423282923177, 0.08121773993480019, 0.13879513746360317, 0.1619758826564066, 0.22754978039301932, 0.14216373092494905, 0.13774986698990688, 0.178987629187759, 0.10369448384153657, 0.14291726314695552, 0.08006433112313971, 0.1366275319014676, 0.13490994984749705, 0.16236723196925595, 0.09305572268203832, 0.13672770699486136, 0.22286144056124613, 0.10900429071625695, 0.21499840077012777, 0.16230419394560158, 0.12836771027650684, 0.11184513554326259, 0.12190119945444167, 0.07817209203494713, 0.18150254501961172, 0.16369049611967057, 0.2433867219951935, 0.19541903107892722, 0.12278426613193005, 0.14028226782102138, 0.16043009294662625, 0.0883189651358407, 0.06974555435590446, 0.08279376474092714, 0.1270684620249085, 0.20814634423004463, 0.17813755839597434, 0.10616576881147921, 0.19525874202372506, 0.12671294360188767, 0.11632816764176823, 0.1898860529763624, 0.12024309311527759, 0.16774179122876376], [0.044688852794934064, 0.05403428433055524, 0.04056882367876824, 0.09902302044793032, 0.03828840795904398, 0.042073105068993755, 0.04292296805942897, 0.07224830638733692, 0.006107110502853175, 0.046770384069532156, 0.05377045083150733, 0.014811461423960282, 0.06324965448584408, 0.06272761296713725, 0.01220653884956846, 0.04825374802749138, 0.09197925974149257, 0.009589509063516743, 0.04394618190417532, 0.05365718425309751, 0.025638220649852883, 0.011798677678598324, 0.015311648548959056, 0.05199818733672146, 0.018058811147056986, 0.0391417664650362, 0.009681399005785352, 0.04598069812345784, 0.04502142772253137, 0.014897877099429024, 0.024149006712832488, 0.06016024955897592, 0.05464435198518913, 0.03839783021248877, 0.022053153843444306, 0.02539164765039459, 0.033223190694116056, 0.04593422112520784, 0.06391501956386492, 0.039837329532019794, 0.042645790745154954, 0.04914782075502444, 0.04525811345956754, 0.030814088422630448, 0.014419766084756702, 0.11312106551486067, 0.08911911165341735, 0.06223955439054407, 0.03123275062534958, 0.06435078641516156, 0.047307825152529404, 0.03271183610195294, 0.03598035094910301, 0.020797452962142415, 0.023817849287297577, 0.018434378689562436, 0.09414493571966887, 0.044450916539062746, 0.06807444558944553, 0.035376086889300495, 0.1114593078091275, 0.08642961300211027, 0.019098378215858247, 0.016968054442259017, 0.027175562863703817, 0.06856063395389356, 0.02426235307211755, 0.046819625567877665, 0.05398373294156045, 0.037604069875669666, 0.00261166869677254, 0.05711897661967669, 0.05285707113216631, 0.03401389709324576, 0.060149811251903884, 0.058364953511045314, 0.05217801342951134, 0.068938505864935, 0.010521258773223963, 0.043274122654111125, 0.04372881798190065, 0.04249202516803052, 0.07250919356010854, 0.02004237521759933, 0.03682621747429948, 0.039959798741620034, 0.0614204682642594, 0.015210674719128292, 0.017318288773822132, 0.07424941111821681, 0.044478836134658195, 0.06690203037578613, 0.042298844127799384, 0.044935628029634245, 0.054730734264012426, 0.0132550961097877, 0.04691478745371569, 0.02787589608487906, 0.03654481362900697, 0.0016092752252916398, 0.019198694317310583, 0.005220794146225671, 0.08296535670524463, 0.029596381791634485, 0.019933704388677143, 0.02357023913646117, 0.034780220230459236, 0.08141675425576977, 0.10035601415438578, 0.033667046955088153, 0.027544128242880106, 0.016957347106654197, 0.03062734736886341, 0.11275401411694475, 0.04916092708299402, 0.012891192345705349, 0.0662251545873005, 0.029491772365872748, 0.030908682565495837, 0.019972861955466215, 0.06419988552806899, 0.03511556707962882, 0.03512725219479762, 0.04886281749350019, 0.012694604847638402, 0.09061283970368095, 0.03204314620234072, 0.02857253155525541, 0.06276040847296827, 0.04038609578856267, 0.025542388975736685, 0.08933254590374418, 0.06663107225904241, 0.05245443375315517, 0.02685806466615759, 0.036480833077803254, 0.08876579740899615, 0.022240540565690026, 0.024334322843060363, 0.06561624468304217, 0.037962308269925416, 0.023901630338514224, 0.013806569349981146, 0.05810919086798094, 0.008652325905131875, 0.01164186280220747, 0.02709010641410714, 0.024135429121088237, 0.014395325306395534, 0.029659202737093437, 0.046124663640512154, 0.07172653946327046, 0.014187262349878438, 0.016345527983503416, 0.06348005423205905, 0.021914171848038677, 0.08324576236191206, 0.03298620067653246, 0.05537448429095093, 0.06170102606120054, 0.032806103699840605, 0.011479634886200074, 0.049015488402801566, 0.052741147665074095, 0.015352737555076601, 0.05939334012509789, 0.02835794697602978, 0.05983505900076125, 0.07512433643569238, 0.0448729165509576, 0.006241929513635114, 0.026392062718514353, 0.03839445344056003, 0.033217108793905936, 0.01406188670443953, 0.032797290696180426, 0.07246073131682351, 0.012501575947680976, 0.05683812567440327, 0.05787629750557244, 0.033418609309592284, 0.04925386994727887, 0.019720923228305764, 0.02532691381929908, 0.034367437692708336, 0.04988006818166468, 0.04142357371165417, 0.015710205043433234, 0.038411559944506735, 0.04851386336667929, 0.009855499429249903, 0.04947701148921624, 0.02985848237585742, 0.06367760652210563, 0.029952931799925864, 0.05197523641982116, 0.055103051199694164, 0.04389108486066107, 0.03080050526477862, 0.015598953395965509, 0.027860498375957832, 0.04152810150117148, 0.014954577181924833, 0.016603741569269914, 0.041214685115846805, 0.045639080126420595, 0.026491065218579024, 0.0353317992266966, 0.012842079795518657, 0.020233203649695497, 0.023781161216902547, 0.07616657152539119, 0.038628393231192604, 0.01723172466881806, 0.06564312527189031, 0.034665966595639475, 0.015559525872959057, 0.017263930167246144, 0.10391966628958471, 0.012414705706760287, 0.06086896719352808, 0.084232284425525, 0.03892330416420009, 0.02393826831394108, 0.0368851959501626, 0.10006380834965967, 0.03386953452718444, 0.013195308692957042, 0.036260775159462355, 0.01704572390735848, 0.023843590679462068, 0.014014949574630009, 0.07183631052612327, 0.015368488711828832, 0.03647281788289547, 0.010233337015961297, 0.08759223186643794, 0.03349235652422067, 0.028552502844831906, 0.019210045466024894, 0.018914809843408875, 0.04541990907455329, 0.02635350072523579, 0.0311867560230894, 0.047545434863423, 0.042075034652953036, 0.044108159345341846, 0.058151459888904355, 0.04098259698366746, 0.04200635630695615, 0.009845853364822688, 0.04426321997016203, 0.031695112338638864, 0.09397162939421833, 0.009859217589109903, 0.025962364779843483, 0.07608006679220125, 0.0425938589614816, 0.044844028452644125, 0.06719525292282924, 0.028987865225644782, 0.020347752288216725, 0.05834379117004573, 0.016588431062700693, 0.009190818982460769, 0.01793415631254902, 0.010770133358164458, 0.017626287481107283, 0.025406960012333002, 0.0523467555467505, 0.024222731663030572, 0.07635080968611874, 0.04737679293612018, 0.03110846500931075, 0.02493040286935866, 0.05921483505517244, 0.013848674170731101, 0.07267725290148519, 0.03189263865351677, 0.038443902740255, 0.034219709486933425, 0.039264977822313085, 0.015351322836067993, 0.029220170436019544, 0.017885243214550428, 0.01427955861800001, 0.0344208500609966, 0.03137605934171006, 0.019397927571844775, 0.044867439501103945, 0.003461152728050365, 0.046373724690056406, 0.06004595881677233, 0.02288159103045473, 0.01604189681529533, 0.03532759867084678, 0.02895562633057125, 0.04202452037134208, 0.04359888276667334, 0.05904144709347747, 0.032673455934855156, 0.02506758701201761, 0.05270597728667781, 0.03661098722659517, 0.020754501165356487, 0.030012886199983768, 0.004621414809662383, 0.01663491733779665, 0.051548367919167504, 0.00761447041440988, 0.01048310403348296, 0.036552569072227925, 0.07021833211183548, 0.019248269782110583, 0.010692428641050356, 0.03147610084852204, 0.029459841462085024, 0.03108443612291012, 0.024536151759093627, 0.042805107586900704, 0.021506031444005203, 0.046390226343646646, 0.06198272305482533, 0.06327453127596527, 0.06542563147377223, 0.043177209299756214, 0.014366299910761882, 0.022083288749854546, 0.12913388869492337, 0.03781039435125422, 0.027723518323909957, 0.07687187899136916, 0.04007860545243602, 0.0683745181595441, 0.00997418275801465, 0.008509079343639314, 0.03343997203046456, 0.06666000859695487, 0.06815510962042026, 0.06928202376002446, 0.057315096564707346, 0.05307669118337799, 0.021569423843175173, 0.0077695764957752544, 0.04032000753795728, 0.02983730890264269, 0.010824774908542167, 0.04431976791238412, 0.05439275279059075, 0.03843703045276925, 0.006105669808675884, 0.021881337379454635, 0.22139699023682624, 0.11186144052771851, 0.1268181949853897, 0.1562981857568957, 0.12461630220059305, 0.13370548869716004, 0.0967762796790339, 0.12323837145231664, 0.10715968266595155, 0.14971824508393183, 0.22663288662442937, 0.1368681064923294, 0.16133298981003463, 0.1225034226081334, 0.09925507518346421, 0.16463985142763704, 0.18796507793013006, 0.13148226658813655, 0.15192242368357256, 0.2455633075442165, 0.14124578330665827, 0.10616793588269502, 0.11039776203688234, 0.14860839291941375, 0.1197604373737704, 0.1673902804031968, 0.1140992458385881, 0.11359106021700427, 0.1430915787932463, 0.14757933095097542, 0.09262564810342155, 0.12349024895229377, 0.15548672148725018, 0.1958880535676144, 0.10480087017640471, 0.22246857726713642, 0.17470497696194798, 0.09623366582673043, 0.2043119046720676, 0.09537612160784192, 0.13474868115736172, 0.15231000288622454, 0.13861865474609658, 0.1093119777215179, 0.15777854772750288, 0.12237264134455472, 0.13383987679844722, 0.21097060205647722, 0.10146364729735069, 0.2282986816135235, 0.16866113408468664, 0.0922621441714, 0.10436844298965298, 0.1032805658178404, 0.1302325789583847, 0.08559103807783686, 0.1558508785092272, 0.13206725707277656, 0.1828497211681679, 0.1377902991953306, 0.21555133047513664, 0.15699595300247893, 0.0444600004266249, 0.16450432041892782, 0.13080934644676745, 0.24461128050461411, 0.13694218767341226, 0.12516378454165533, 0.1098168756288942, 0.1092477745260112, 0.09965550838387571, 0.11472293932456523, 0.1486728261807002, 0.19233536295359954, 0.18605836696224287, 0.23174203903181478, 0.10939631538349204, 0.21825031377375126, 0.08461341436486691, 0.14204492792487144, 0.13028213958023116, 0.08241207076935098, 0.15299870108719915, 0.1386964021367021, 0.1381404444691725, 0.09120119211729616, 0.14449453476117924, 0.08076586105744354, 0.17564049863722175, 0.18363764451351017, 0.14641481218859553, 0.12923094676807523, 0.10374692399636842, 0.15807945892447606, 0.12892402417492121, 0.08426599277299829, 0.19829467521049082, 0.14483896549791098, 0.09430162535863928, 0.1551589445443824, 0.06610273732803762, 0.1639605191303417, 0.2553487621480599, 0.21122898819157854, 0.16870149207534268, 0.10275228283717297, 0.18186968547524884, 0.14000774739542976, 0.1848065567901358, 0.09763184978510253, 0.10279236623318866, 0.19961995800258592, 0.0643295090412721, 0.1740150319528766, 0.08393293173867278, 0.15855651145102456, 0.1106433461245615, 0.11252765165409073, 0.11724198149750009, 0.13853079930413514, 0.1493557950016111, 0.14956343307858333, 0.13037101918598637, 0.14053127320948988, 0.0818857247941196, 0.15496622363571078, 0.09201355438563041, 0.24333701294381171, 0.15399475232698023, 0.10868220604606904, 0.17022924759658054, 0.17937464435817674, 0.137514442903921, 0.09783702393178828, 0.09642049408284947, 0.1766441939980723, 0.17046522087184712, 0.07159547618357465, 0.09554480435326695, 0.13850329531123862, 0.20909013343043625, 0.0853364888462238, 0.06987775312154554, 0.1633857554406859, 0.1866894745035097, 0.18035993445664644, 0.15471806429559365, 0.12923217873321846, 0.10640585358487442, 0.09301377649535425, 0.15000318526290357, 0.11208329815417528, 0.26276750781107694, 0.14223543723346666, 0.13869328511646017, 0.18090559111442417, 0.15564036089926958, 0.1425254685455002, 0.18338952970225364, 0.06704252635245211, 0.1429614654625766, 0.17579673556610942, 0.1497911982005462, 0.1684266747906804, 0.10166261708945967, 0.1572074947762303, 0.08109191621770151, 0.19419137039221823, 0.28691708226688206, 0.11188105549081229, 0.12836110516218469, 0.11305099935270846, 0.09288032350013964, 0.1881717363721691, 0.06742132594808936, 0.10876543790800497], [0.023460950469598174, 0.06266320197028108, 0.029324993229238316, 0.021492902851605322, 0.04027915601909626, 0.03368302539456636, 0.011977555677731289, 0.051388442516326904, 0.03888742874551099, 0.027379265702620614, 0.038910594885237515, 0.0823059881804511, 0.03467177761194762, 0.10542814081418328, 0.03347707570355851, 0.06705282736220397, 0.025879101376631297, 0.09210414835251868, 0.05754758916737046, 0.014892279450577917, 0.01847856616222998, 0.019244132308813278, 0.04071661125635728, 0.00986347195066628, 0.045051833512843587, 0.014563523800461553, 0.07838753750547767, 0.07368391685304232, 0.021935914919595234, 0.026408978119434323, 0.05580948301940225, 0.024442978829029016, 0.028210176096763462, 0.0637221873330418, 0.03182420892699156, 0.00686987504195713, 0.06365970592014492, 0.06038470099156257, 0.02639881997311022, 0.06215295317815617, 0.018621858180267736, 0.03647609075414948, 0.04441729724931065, 0.038667411645292304, 0.03771246054384392, 0.02249845172627829, 0.034077569653163664, 0.018112032412318513, 0.05369250306102913, 0.060654230474028736, 0.12136910183471628, 0.05866731931746472, 0.01434492512998986, 0.027193064561288338, 0.06989944609813392, 0.0201837599161081, 0.03119193992461078, 0.04857206258748192, 0.013910674115322763, 0.09619840639061294, 0.00926261249333038, 0.056064388481900096, 0.06521275383420289, 0.03290457927505486, 0.059596028077066876, 0.06328027549898252, 0.021592916527879424, 0.017510197030787822, 0.011526362359290943, 0.013659086052939529, 0.028336467366898432, 0.04298443644074723, 0.03666617332783062, 0.10854743944946676, 0.02199588230723748, 0.0295723213639576, 0.0647736324754078, 0.0851184681232553, 0.05265148509352002, 0.020818878765567206, 0.06411177775589749, 0.03779057529754937, 0.011725296899385285, 0.01998319450649433, 0.05189830910239834, 0.04018145598820411, 0.03214538446627557, 0.02049733400781406, 0.06633622440858744, 0.039382099857903086, 0.01949251614860259, 0.01900239996757591, 0.012369805772323161, 0.008322622161358595, 0.0920586398569867, 0.05723416164983064, 0.016692071985744406, 0.026796651945915073, 0.04854818027524743, 0.07355936962994747, 0.04602816217811778, 0.022719593180227093, 0.03990440112829674, 0.043981946000712924, 0.042105273460038006, 0.08735973184229806, 0.05716699728509411, 0.04926749948936049, 0.004865703385803499, 0.07530260772909969, 0.05250717447779607, 0.0688220703159459, 0.0634013643139042, 0.0257572648479254, 0.030223071698856074, 0.04750631625938695, 0.07448007803759538, 0.04282030677131843, 0.030800460735918023, 0.03610028201364912, 0.02871586253604619, 0.07709281635470688, 0.02327316855371464, 0.03302124117908534, 0.026169539014517795, 0.048772546360851265, 0.04358430327556562, 0.03314261572086252, 0.01962729944352759, 0.030407610429392662, 0.013533079581975471, 0.029610404671984725, 0.038364774954970926, 0.002820396803144831, 0.10529061342822388, 0.031427130234078504, 0.022531163740495685, 0.029894639810663648, 0.019257830499554984, 0.09913001587847248, 0.03828745429927949, 0.027436657837824896, 0.018642595641722437, 0.03626343946962152, 0.07185927257523872, 0.04154970170930028, 0.036676711824839, 0.06026884431776125, 0.051019175807596184, 0.015926223823043983, 0.06323491543298587, 0.027767154751927592, 0.006986431653785985, 0.014064534316275967, 0.06569640405359678, 0.05070148836239241, 0.021955400006845593, 0.017176815017592162, 0.08403955609537661, 0.03252136019000318, 0.006450936853070743, 0.028817280726798344, 0.031841096497373655, 0.016510351561009884, 0.023888112118584104, 0.03698880347656086, 0.006855442125015543, 0.03944201715057716, 0.030242282191466074, 0.06753273715730757, 0.06887619514600374, 0.017388661071890965, 0.055846152536105365, 0.03169854848238174, 0.05959484806226101, 0.08331676363013685, 0.01696986899332842, 0.0500016356818378, 0.01959604018338723, 0.040776031310088, 0.0527415669785114, 0.021521926391869783, 0.0250323331420077, 0.056639872054802254, 0.06838594723376445, 0.030073276611801703, 0.06383330910466611, 0.012648178872041171, 0.027428798493929207, 0.059823177216458134, 0.04188059567240998, 0.03203629246854689, 0.032652694353600964, 0.031827233178773895, 0.009868517627182882, 0.015059258039400447, 0.04287404197384603, 0.020337989335530438, 0.02637292829604121, 0.018742969259619713, 0.07526111425249837, 0.018649538433237467, 0.03808951238170266, 0.019849288801196963, 0.05852869355294388, 0.08006042000488378, 0.06673544048680924, 0.034267184673808515, 0.0015468920310013345, 0.05865342631295789, 0.014908422090229578, 0.021756135211035144, 0.010443670016684337, 0.06596411898499355, 0.04280140055925585, 0.027859548426931724, 0.03888380335411057, 0.03860781347611919, 0.03691323428938631, 0.026004348073911387, 0.027807060032500885, 0.01920647016959265, 0.04587967698171269, 0.021697459160350263, 0.01842992951424094, 0.05229590358794667, 0.02610832296340959, 0.05707577620341908, 0.022454169629781973, 0.02223694114945829, 0.03002649718837347, 0.06725826126057655, 0.020477058533288073, 0.032081685931188986, 0.04339300729043316, 0.021076511620776728, 0.06398835859727114, 0.06311689910944551, 0.073849400941981, 0.03694171791721601, 0.05875987255421933, 0.008461199686280452, 0.043765825175796635, 0.02392396898358129, 0.026612202273099683, 0.045912765635875985, 0.00878182974702213, 0.033580968956812285, 0.05704413844796363, 0.05260421028651763, 0.02236987649666844, 0.038516392014571466, 0.10925607915851288, 0.05659792586811818, 0.015752767212688923, 0.04541951202554628, 0.014208774427970638, 0.03799590158450883, 0.012197996729810257, 0.07009106120676734, 0.07581465251860209, 0.10138969970284961, 0.0915638796868734, 0.07221756663057022, 0.015685925682191737, 0.04338059858127963, 0.033745632972568274, 0.01734652749291854, 0.02008659237617394, 0.014442447973124217, 0.08332019235240296, 0.03206977817171719, 0.03909618375473656, 0.022234447533264756, 0.0746848588460125, 0.11620499339187518, 0.031226364444592036, 0.058642587246140465, 0.014121919957688078, 0.07784763991367072, 0.007455748218490044, 0.10209802028839476, 0.04767538121086545, 0.07020733348326758, 0.0740019345539622, 0.07517912919865921, 0.02999383897986263, 0.03391078680579085, 0.037025784695288166, 0.002363961370974721, 0.016348025310435332, 0.05401679933129344, 0.08321848843479529, 0.04754124172904994, 0.04103949373529758, 0.042314336460549384, 0.030034850060474128, 0.0409750864491798, 0.036280627609812655, 0.04068405323778279, 0.04172343476966489, 0.023846425683586858, 0.07744535876554437, 0.029881201371608768, 0.007941387393657351, 0.04863628062594216, 0.01178704822450527, 0.019090776768280193, 0.026773682475322857, 0.008414718977292068, 0.05907009770453442, 0.06820717127993703, 0.02597334485471947, 0.043513116470421664, 0.015937395000946708, 0.030572363502869848, 0.06316041864920408, 0.03430174278037157, 0.0175838125142036, 0.057040698593482375, 0.07191251424956135, 0.041100409216596745, 0.04081122395291459, 0.020718968989967834, 0.07420871916110627, 0.07399889916996472, 0.05332938875653781, 0.02394497176283039, 0.028749377925123554, 0.014513763726426987, 0.089086167718051, 0.03934906315407716, 0.017323314968962222, 0.042004779243143275, 0.02363887851970503, 0.018266785045852885, 0.05624738725600764, 0.0379293791775126, 0.03676140200695954, 0.07520367944380268, 0.02819895111315418, 0.028980595889152028, 0.04651679962989874, 0.02861499353457475, 0.035449771021376364, 0.015506883482885314, 0.05512569041457027, 0.035637790424516425, 0.009947980306606041, 0.015144408353080507, 0.01380848501867149, 0.0254284284892492, 0.11508171577588655, 0.32029000867623836, 0.10626623334246688, 0.186368940921966, 0.1420479707303457, 0.10267016419675201, 0.11404279808630235, 0.13485393254086375, 0.24412147788098082, 0.17075584590202197, 0.12468554457882419, 0.18410509364912286, 0.09024085302371532, 0.18281007563928142, 0.09816408841288649, 0.12007867029751651, 0.12117456266423687, 0.2165357448393479, 0.14039237285032868, 0.09971198582206853, 0.12375342193990946, 0.2200379248824902, 0.10639750442351215, 0.1397504744818434, 0.10761057448689826, 0.16703813133062795, 0.14010959974257275, 0.13277878373628482, 0.13115551380906254, 0.1954742765519768, 0.1758271487778984, 0.13079822907457128, 0.04411064182932023, 0.10028720964328386, 0.08676767611177638, 0.10256340625346638, 0.15071955072926357, 0.13981609517941251, 0.06123595550889149, 0.1302833715453744, 0.0848073820816353, 0.11581340659176931, 0.12470445450162515, 0.18299228773685172, 0.09715991807752289, 0.10391486459411681, 0.16485808737343177, 0.10879798108362593, 0.13022414816077799, 0.16724851535400376, 0.19236420281231403, 0.1425966405076906, 0.09402684518136084, 0.1259608066175133, 0.16603986849077046, 0.11279557438683696, 0.08719821824342944, 0.08077519727521576, 0.0975013876450248, 0.12690713396295905, 0.1162700574786868, 0.17911625822307542, 0.19938993675168604, 0.09248472168110311, 0.1801955932751298, 0.16865170880919322, 0.13470888719893992, 0.09316476644016802, 0.11630010703811422, 0.11891631860635243, 0.12638231681194156, 0.1504735733033158, 0.13889050344005227, 0.17090662062400952, 0.1503035324276425, 0.09748679702170193, 0.19374528026673943, 0.1951858334359713, 0.22555971139809117, 0.09662369411671534, 0.14328315679449588, 0.12786619656253606, 0.05790783136035316, 0.1571297919144854, 0.14785818551899865, 0.16303995915222913, 0.22078056237660348, 0.1753527086111717, 0.114514507149579, 0.18519682256737724, 0.18578726041596383, 0.10645443457178771, 0.13409965817118064, 0.1705542637500912, 0.20462051936192438, 0.16819960728753358, 0.10851462910068221, 0.12437431010766886, 0.1442105445312336, 0.24946112651377916, 0.18561244010925293, 0.13645355764310807, 0.13985744764795527, 0.1556779581005685, 0.17827767587732524, 0.2481226038071327, 0.15686566155636683, 0.1542442326899618, 0.11473481368739158, 0.18929681740701199, 0.12889809353509918, 0.22947102261241525, 0.12469820561818779, 0.08871290454408154, 0.08244050986832008, 0.1273579293047078, 0.22756607795599848, 0.21686459047487006, 0.16105493676150218, 0.2321219741133973, 0.1079426336218603, 0.25061362248379737, 0.10443387815030292, 0.1778107017162256, 0.09456297266297042, 0.18580611096695065, 0.1340127526782453, 0.15805952483788133, 0.15874222648562863, 0.16289610124658793, 0.12668808165472, 0.07090174622135237, 0.11641210454399697, 0.0813069535070099, 0.16302505682688206, 0.11609568246058188, 0.128391444159206, 0.16684903210261837, 0.09355837930343114, 0.1613927772268653, 0.14971883880207315, 0.10093350152601488, 0.08353994227945805, 0.12098481034627184, 0.22911832435056567, 0.16911952901864424, 0.1197739593044389, 0.1139863948628772, 0.16773341980297118, 0.1715889511979185, 0.11156103399116546, 0.11221428721910343, 0.09233592849341221, 0.16873779793968424, 0.12595831300131977, 0.1277008609031327, 0.20916826673783362, 0.11403590353438631, 0.21683791768737137, 0.13666420883964747, 0.07446427771355957, 0.0906777182535734, 0.1780864837928675, 0.17938539065653458, 0.1526539883343503, 0.14451136667048559, 0.08760045486269519, 0.08498908951878548, 0.13239737920230255, 0.14156941906549037, 0.11893562928889878, 0.07346170299570076, 0.1484153454657644, 0.11247009810176678, 0.13395072397543117, 0.15060091100167483], [0.03867934909067117, 0.048816911948961206, 0.026723678420239594, 0.1229585224064067, 0.026339210671721958, 0.06231028848560527, 0.06187189072079491, 0.023409148561768234, 0.011053165289922617, 0.024213707147282548, 0.03638485482952092, 0.06102783132519107, 0.04020727159513626, 0.04157807401497848, 0.07061305819661357, 0.06234448665054515, 0.017222913520527072, 0.017055843090929557, 0.032207609838224016, 0.022975504252826795, 0.09872132999589667, 0.03188022252288647, 0.06191139153088443, 0.05870749919267837, 0.06170698550704401, 0.06401024453225546, 0.009899154410959454, 0.008888378961273702, 0.010067059756693197, 0.023972677990968805, 0.025178437899739947, 0.013615034022222972, 0.07043622666969895, 0.012375028636597563, 0.03731827993760817, 0.046110136099741794, 0.027807516453322023, 0.045615142153110355, 0.03571998699044343, 0.02625212520797504, 0.05126193231262732, 0.05378711204684805, 0.053168632148299366, 0.0461669029755285, 0.10235714114969596, 0.02343786782148527, 0.04658095458580647, 0.029609794255520683, 0.07466378185199574, 0.03791642127907835, 0.04394806324853562, 0.05766293375927489, 0.013390559397521429, 0.053092914531589486, 0.11172728991368786, 0.019879234459949657, 0.020049631566507742, 0.03621520729211625, 0.04143597871006932, 0.035618349866126664, 0.0721858323959168, 0.03225544867746066, 0.005647554107781616, 0.04479526192881167, 0.024930606959969737, 0.01832247024140088, 0.06775645015295595, 0.009972710522561101, 0.04530516562226694, 0.06647314323345199, 0.02041426170762861, 0.03920229231880512, 0.010644517442415236, 0.023983648788998835, 0.07563635896076448, 0.0672882811340969, 0.10371717871748842, 0.06231267820112407, 0.05650601829984225, 0.010567244098638184, 0.08392916162847541, 0.07425815361784771, 0.03505600230710115, 0.0807190166960936, 0.03480852574284654, 0.06987416112679057, 0.042883604546659626, 0.06312476587481797, 0.039035093868733384, 0.05482448606926482, 0.01686936735495692, 0.012181525689811679, 0.026356020316598006, 0.0216960787656717, 0.03689217584906146, 0.021861761379113887, 0.041971475366153754, 0.02630865274113603, 0.07896810478996485, 0.029767545165668707, 0.060925147772650234, 0.045449743411154486, 0.07249830625369214, 0.0224553366570035, 0.051294111835886724, 0.041551349277142435, 0.1582660200074315, 0.0106030499409826, 0.044858214605483226, 0.01065921196641284, 0.04500574243138544, 0.026367597820353694, 0.042664392676670104, 0.04612390293914359, 0.03669295001600403, 0.026969396094500553, 0.08259973023086786, 0.009969727088900981, 0.0037961361567795393, 0.02270051812956808, 0.04146721570577938, 0.05020322154450696, 0.027197328199690674, 0.039709661577944644, 0.06260739988647401, 0.06693004645057954, 0.0453396569355391, 0.01379947070745402, 0.07080407958710566, 0.040177014234359376, 0.04133711721806321, 0.01989074702578364, 0.05976211330562364, 0.05632746499031782, 0.02619403174321633, 0.018178007485403214, 0.04084474305273034, 0.07817947640432976, 0.06852872902527452, 0.015053480419737753, 0.0659610316506587, 0.05066026576969307, 0.06100787126342766, 0.04362381521787029, 0.02139416195859667, 0.02987423817103263, 0.06581468012882397, 0.06781511692679487, 0.09958234746591188, 0.05473835983138997, 0.06570309080416337, 0.04732229332148563, 0.05581183191679884, 0.05931471328949556, 0.026018944263341837, 0.023110552865546197, 0.049227056151721627, 0.01973720038222382, 0.040615489924675785, 0.07917162394733168, 0.049551300471648574, 0.014089358228375204, 0.01764108776114881, 0.0636505255533848, 0.03061957708268892, 0.015238398573274026, 0.06504591161501594, 0.06093551928643137, 0.03023986650077859, 0.03455681522609666, 0.02614267883473076, 0.07418123001116328, 0.03021603242814308, 0.055710933229420334, 0.008210409432649612, 0.0712933849717956, 0.05759246683737729, 0.02358774268941488, 0.016172164141607936, 0.07460614666342735, 0.035858894771081395, 0.07671512255910784, 0.039604740450158715, 0.005294244037941098, 0.07011377092567272, 0.01792569582903525, 0.020163540102657862, 0.005614100409729872, 0.02857404553651577, 0.044259613132453524, 0.03053392210858874, 0.024354062115889974, 0.05555335672397632, 0.03583382873330265, 0.018534913724579383, 0.04319236024457496, 0.09335338327218778, 0.03699169785249978, 0.034585176399559714, 0.028402021271176636, 0.0523250662809005, 0.04142086487263441, 0.06710452536935918, 0.03362079631187953, 0.10392796350060962, 0.019217594963265583, 0.05402253242209554, 0.04177616807282902, 0.06235089138499461, 0.007851792543078773, 0.038029717543395236, 0.07150206947699189, 0.0233651354938047, 0.0226796878996538, 0.03680274334328715, 0.061677407211391255, 0.03425916576816235, 0.013942731184215518, 0.02615260505990591, 0.030636462797701824, 0.10121332088601775, 0.03128817421384156, 0.08119298930978402, 0.052678903739433736, 0.08871706057107076, 0.04839372450078372, 0.06053064062143676, 0.04107333195861429, 0.055204751406563446, 0.07023600264801644, 0.05860536482941825, 0.0555330664064968, 0.02361087543249596, 0.008684921031090198, 0.03840051307633985, 0.03996163184638135, 0.015615840966347605, 0.03395082567294594, 0.026570766312943306, 0.06029916476109065, 0.019000910106115043, 0.026799776387633756, 0.07326431397814304, 0.025198600196745247, 0.006339354949886911, 0.04024131761980243, 0.016518543015990872, 0.050354089034954086, 0.0393270992935868, 0.04461473821720574, 0.06263829549425282, 0.03739847270480823, 0.022143022360978648, 0.04340142695582472, 0.04963132625562139, 0.050391062832204625, 0.07143869748688303, 0.06149181834189221, 0.02056799945421517, 0.042035051446873695, 0.04208238562569022, 0.08736114934436046, 0.016729069902794436, 0.016067892393039074, 0.03979385452112183, 0.04156586197495926, 0.03409511402423959, 0.024195504120143596, 0.024112220307870302, 0.056809256129781716, 0.06031432312738616, 0.004350579147285316, 0.012497895822889404, 0.052044638359802775, 0.006588006890524412, 0.07551126996986568, 0.014595245047530625, 0.02317470782145392, 0.06627050723182037, 0.02398048723989632, 0.10224690995528363, 0.03708694508532062, 0.054132652294356376, 0.01891188763693208, 0.034381471705273725, 0.014380995362444082, 0.010296107866452076, 0.034281975677004084, 0.019036280864384025, 0.038459265197161585, 0.0524502888583811, 0.009375546960654901, 0.018469306014594622, 0.026946478574245702, 0.019633546471595764, 0.016619258021819405, 0.019514164596330374, 0.026061367279908154, 0.03049043967621401, 0.043530972543521784, 0.047343218175228685, 0.08555202337447554, 0.024164085298252758, 0.03001170804054709, 0.01034104119753465, 0.02906566642195685, 0.013028616758674616, 0.018426439564791508, 0.032528251031180844, 0.04818734436412342, 0.02251739875646308, 0.031097857863642275, 0.01826141004130477, 0.07426330412272364, 0.02756623682216741, 0.08116432014503516, 0.022816027849330567, 0.03516517594107427, 0.04729022512037773, 0.07546184293460101, 0.01858465802797582, 0.029500546406779904, 0.07016883086180314, 0.047581915132468566, 0.02698993317608256, 0.058974869025405496, 0.08275527696241625, 0.034060403777402826, 0.014784206978220027, 0.08034433602006175, 0.03865469494485296, 0.0223288969573332, 0.03908880680683069, 0.019202562762075104, 0.03628394129918888, 0.052429579227464274, 0.046652297241962515, 0.059980579317198135, 0.0051620081649161875, 0.04660836209950503, 0.01882475393358618, 0.04277992651623208, 0.05569618304434698, 0.032591749186394736, 0.09652180466218852, 0.05901254415221047, 0.07074996217852458, 0.11072583583882079, 0.06108727364335209, 0.04867411531449761, 0.040379639103775844, 0.03621199750341475, 0.16927000688156113, 0.082888344040839, 0.13045158673776314, 0.275184825877659, 0.12213056019390933, 0.1583302899962291, 0.24993016384541988, 0.0601189119333867, 0.17871543910587206, 0.09670409839600325, 0.16664161666994914, 0.14404305664356798, 0.18686056922888383, 0.10775626549730077, 0.18419842614093795, 0.2578658302081749, 0.16186800407012925, 0.12835003231884912, 0.0741172420384828, 0.3003164695110172, 0.20133813377469778, 0.17191990453284234, 0.1034352219721768, 0.14445154956774786, 0.1846902770921588, 0.15803568705450743, 0.19142957171425223, 0.09254559263354167, 0.21897736616665497, 0.07681885253987275, 0.15697247144998983, 0.11030454086721875, 0.28769654512871057, 0.07415350337396376, 0.09665822624810971, 0.15158630500081927, 0.09745720017235726, 0.2136815042467788, 0.0886426008946728, 0.21768331294879317, 0.11349323773174547, 0.10968783099087887, 0.09363119141198695, 0.12701195490080863, 0.239253701583948, 0.11405824217945337, 0.14555153116816655, 0.14566732104867697, 0.15769520454341546, 0.08287790944450535, 0.16055818763561547, 0.16711776377633214, 0.133124090207275, 0.27271777857095003, 0.19929927599150687, 0.104008130292641, 0.09528960203169845, 0.16726469417335466, 0.10093940902152099, 0.11823150925920345, 0.15508536802371964, 0.08664040520670824, 0.12530225445516407, 0.14452076226007193, 0.1443526361254044, 0.19334406038979068, 0.3112152050016448, 0.09587054781150073, 0.12200726720038801, 0.11888747132616118, 0.14244142774259672, 0.19020915438886732, 0.11239938627113588, 0.14314048632513732, 0.17744869692251086, 0.2002338774036616, 0.2354886825196445, 0.1282266280031763, 0.12498163181589916, 0.08617769839474931, 0.19911970593966544, 0.15594143536873162, 0.27286760334391147, 0.12808544182917103, 0.07062848744681105, 0.17000790947349742, 0.19970546825788915, 0.16209281544433907, 0.2568467130186036, 0.15196704160189256, 0.10529299572226591, 0.09878015262074769, 0.19655183044960722, 0.17305006185779348, 0.11763386515667662, 0.2157415429246612, 0.11782701651100069, 0.13432279229164124, 0.14989901741500944, 0.18161213054554537, 0.18153470969991758, 0.13048611144768074, 0.2238992153434083, 0.11173321967362426, 0.13557889207731932, 0.1297747332137078, 0.234453906014096, 0.09246806046576239, 0.17880740604596213, 0.10138779238332063, 0.1324642467079684, 0.16001576674170792, 0.10124602733412758, 0.1116080119390972, 0.11312600821838714, 0.10816132227773778, 0.15060209843795747, 0.07135856780223548, 0.0718068472633604, 0.0782339574652724, 0.2792933554155752, 0.1661234491621144, 0.15651642170269042, 0.08706415668711998, 0.19689151144120842, 0.09643126264563762, 0.1471695615327917, 0.10053095320472494, 0.07009187014773488, 0.06758217903552577, 0.09542591971694492, 0.14905494317645207, 0.23088726302376017, 0.1109236478805542, 0.11505106507684104, 0.10084172754432075, 0.14873788284603506, 0.1533601270057261, 0.18859189585782588, 0.15188298595603555, 0.08878045482560992, 0.2146192968939431, 0.1450222759740427, 0.24813872325466946, 0.18222524842713028, 0.14753514347830787, 0.20772673393366858, 0.14541807817295194, 0.19473245542030782, 0.20742542197695002, 0.15234979684464633, 0.11733224891941063, 0.14690526790218428, 0.14941688859835267, 0.23505299730459228, 0.14678411971544847, 0.18989243544638157, 0.1003575578215532, 0.15467831486603245, 0.16068982979049906, 0.14587941201170906, 0.12353580939816311, 0.07224702989333309, 0.24364055134356022, 0.163488112448249, 0.06881005494506098, 0.18348606827203184, 0.12792788387741894, 0.13270853203721344, 0.11170596058946103, 0.16571700456552207, 0.2351820419426076, 0.09915564223774709, 0.17705136589938775, 0.08604810456745327, 0.20348170859506354], [0.03175955673214048, 0.02386795538768638, 0.04868700270890258, 0.06628832619753666, 0.07742262678220868, 0.03391184065549169, 0.027507681370479986, 0.012077920946467202, 0.06991103844484314, 0.00841053790281876, 0.05478435443365015, 0.06565022020367905, 0.0872378860367462, 0.011177432352269534, 0.023556277483294252, 0.07877756579546258, 0.03400494308152702, 0.06007477641105652, 0.02170513296732679, 0.027694875134329777, 0.043560547128436156, 0.007949320024636108, 0.05568141430558171, 0.040449319349136204, 0.017818219857872464, 0.05549227054871153, 0.030478225780825596, 0.05626258272968698, 0.024776678110356443, 0.013912191807321506, 0.032132463675225154, 0.02252088685054332, 0.03225751184800174, 0.027241832940489985, 0.021422593636089005, 0.014904061972629279, 0.0714234983024653, 0.04775615656399168, 0.10024389048339799, 0.03276718176493887, 0.02572888697613962, 0.050080748624168336, 0.03274062029959168, 0.030669545885757543, 0.1344148928183131, 0.04420601893798448, 0.028698550086119212, 0.02841173598426394, 0.09713156061479822, 0.0691193672537338, 0.01603632885235129, 0.06537314679007977, 0.04671229617088102, 0.03610630454204511, 0.03219603604520671, 0.0057698322143551195, 0.035570429390645586, 0.03354234759171959, 0.05274392700812314, 0.03443538873398211, 0.04284849354007747, 0.04048806687933393, 0.05448437463201117, 0.030096689515630715, 0.05829222303873394, 0.10973493510391563, 0.022251789669098798, 0.02691395395231666, 0.018942527203762438, 0.05767788432422094, 0.05695866530004423, 0.040344064254895784, 0.034837391576729715, 0.0308186136680888, 0.04890342410362791, 0.054749414121033624, 0.04053133408888243, 0.03422225505346432, 0.017994786066992674, 0.026460505432623904, 0.019543011876521632, 0.012866534489148762, 0.029637316802109126, 0.017166595644084737, 0.032788499956950545, 0.04350258910562843, 0.021562102556345053, 0.016860686082509346, 0.013277408779686084, 0.06592454767087474, 0.03566525731002912, 0.05769699091615621, 0.028808363822463434, 0.016199759047594853, 0.049566117450012825, 0.05407567019574344, 0.022531327012984548, 0.0426875662378734, 0.08561134323826991, 0.06613401143113151, 0.06305491493549198, 0.02369819652813021, 0.035812417772831395, 0.04156624789175112, 0.020814685631194152, 0.02815833708154969, 0.06395983044058084, 0.022722556204826105, 0.12747336295433342, 0.026108614256372675, 0.020100665351492353, 0.016342852541129105, 0.008531591465725796, 0.04835936677409336, 0.12914730672491714, 0.01534220091343741, 0.02027977527177427, 0.05755478057835717, 0.06359168808558024, 0.030673334549646825, 0.028754782615578733, 0.04121308207686525, 0.01971826819499256, 0.01988733871257864, 0.04142343641433399, 0.01959253910172265, 0.02871035765565466, 0.09912735156831332, 0.04374553114757873, 0.09374946006573737, 0.01825087339966558, 0.03113744402071461, 0.05259898927761242, 0.024484988098265603, 0.03439762454945594, 0.013265390625747386, 0.04027870330901351, 0.015408657454827335, 0.019631720788311213, 0.050449829795979895, 0.04630623749108054, 0.0031488289232584066, 0.051170035876566544, 0.04523596406215802, 0.024884539998311084, 0.047982507894630544, 0.009858391022135038, 0.041464751775492914, 0.058752076292876154, 0.04306828799599316, 0.03167083297739737, 0.023250930098583922, 0.0868663149594795, 0.012979360417375574, 0.01260322698726668, 0.03018730760231847, 0.030550477567885537, 0.005219115964791854, 0.05252426984952763, 0.11260476079769433, 0.03968210192397237, 0.046729380410397425, 0.05042857097578235, 0.08311327415867709, 0.05489215880515985, 0.06815309097873978, 0.02095313884638017, 0.03820231511781458, 0.03830954803561326, 0.022727031355316285, 0.06030034477589652, 0.05919824063312262, 0.03180238236382138, 0.038465072502731346, 0.02283432550029829, 0.015662813348171767, 0.04357750149210915, 0.0509942953067366, 0.03202349413186312, 0.02515570962714264, 0.10533022927120328, 0.023677190038142726, 0.0319814922841033, 0.05400829431891907, 0.04373328200017568, 0.06410613743355498, 0.013527186929422896, 0.02356813885853626, 0.02748541137407301, 0.011712108007486677, 0.02238885877886787, 0.055313746925094165, 0.08349310533958487, 0.01866470051027136, 0.016542647972528357, 0.02761314797680825, 0.030676659371238202, 0.0373207290249411, 0.08788537277723663, 0.03436704064370133, 0.012414197335601784, 0.028666572798101697, 0.08275534375570714, 0.03874236856063362, 0.07795087265549228, 0.04407190172059927, 0.020128039468545467, 0.01244483319169376, 0.01757589379849378, 0.012692526834143791, 0.04729630330984946, 0.010582785598671762, 0.06575049919774756, 0.039871954431873746, 0.053285568646970205, 0.04016310638689902, 0.01835275728808483, 0.03659891619463451, 0.03621226096583996, 0.016237437885138206, 0.09029839173308574, 0.016801663077785634, 0.054244093189481646, 0.058587297244230285, 0.04355442441010382, 0.013059113462077221, 0.02321570962521946, 0.021928959140495863, 0.034892967305495404, 0.01541529596579494, 0.009957057700376026, 0.015155925557337468, 0.008369490642508026, 0.08903474430553615, 0.059328962524887174, 0.021505595432245173, 0.03898335504345596, 0.052995589285274036, 0.018281872908119112, 0.015560113097308204, 0.0875923506100662, 0.056161691463785246, 0.024128898221533746, 0.028846692039223853, 0.06097869743825868, 0.016119640495162457, 0.05660309863742441, 0.05378917521738913, 0.033772257520467974, 0.011918439904547995, 0.030637368217867333, 0.04263993519998621, 0.0025209715249729925, 0.07241282568429597, 0.016656482293910813, 0.042299705019104294, 0.028178716456750408, 0.09671799140051007, 0.04481849857256748, 0.014001790368638467, 0.04468967286811676, 0.03130354409222491, 0.030743371025891975, 0.022329271741909906, 0.06127127060608473, 0.08154530165484175, 0.024348566512344405, 0.042768582788994536, 0.05399107278208248, 0.01240852361661382, 0.06988586479565129, 0.04100218597159255, 0.01693178197456291, 0.025563783237885218, 0.02974741812067805, 0.037166154506849125, 0.06268052369705401, 0.038276604100246914, 0.023065025816322304, 0.033800811652326956, 0.0491808277729433, 0.04846705611271318, 0.022769215029256884, 0.067539015726652, 0.024447108880849555, 0.058864032980636694, 0.020862103301624302, 0.030925620230846107, 0.04534248451818712, 0.06613407822442241, 0.05146109877387062, 0.018343755036767107, 0.04210663530102465, 0.05556021787924692, 0.03600673058826942, 0.05040552729042247, 0.017154567285615485, 0.03902128250047099, 0.07002422338700853, 0.03822403035883326, 0.017176520013890695, 0.038149581814650446, 0.01030566116241971, 0.08613725134637207, 0.073049773927778, 0.0244395296977018, 0.014854361270408845, 0.04466561986191664, 0.019926344139094, 0.04230781669321004, 0.009375854024256114, 0.033546678023412824, 0.03535373711201828, 0.024124180017679464, 0.010167686632485129, 0.06238628440769389, 0.056973519385792315, 0.009491743167018285, 0.03400995999982115, 0.04950886075675953, 0.04410207002365496, 0.06209612693055533, 0.04287353731342591, 0.046956830119597726, 0.03214501339243725, 0.021890669886488467, 0.04622979999112431, 0.01115460203436669, 0.04664868669351563, 0.048292436185874976, 0.05182812048587948, 0.06970449874643236, 0.019147836792399175, 0.025480467884335667, 0.04968549561453983, 0.038598603423452005, 0.05775766519946046, 0.025604759066482075, 0.04405142957693897, 0.020091312435397413, 0.043225545377936214, 0.023843028502597008, 0.025883333473757375, 0.0761974448687397, 0.03780460188863799, 0.08049352254602127, 0.01789589674444869, 0.03392369646462612, 0.10056346669443883, 0.013688393464690307, 0.020966877855244093, 0.030962388082116377, 0.10823551478097215, 0.13185679883463308, 0.12617608881555498, 0.1978253261768259, 0.1617470191558823, 0.09100145049160346, 0.0765990951913409, 0.11675473928335123, 0.20196002384182066, 0.1368434078176506, 0.15325025946367532, 0.12878130917670205, 0.1013406363199465, 0.1265594526194036, 0.05372161751438398, 0.18456299876561388, 0.16909680445678532, 0.17241558496607468, 0.0908528502623085, 0.11861600112752058, 0.13768773438641801, 0.08275371845229529, 0.19223796349251643, 0.09448356286156923, 0.11381696254829876, 0.10156224903766997, 0.19235076993936673, 0.07683285686653107, 0.11683630873449147, 0.12489922373788431, 0.1694377322564833, 0.09334890070022084, 0.2559868310345337, 0.1530709268990904, 0.09344014033558778, 0.16491892863996327, 0.1479666875093244, 0.16692533972673118, 0.10955726495012641, 0.14548549486789852, 0.12445078100427054, 0.08229005426983349, 0.27814638102427125, 0.12267342637642287, 0.25056300801225007, 0.13229240983491763, 0.18454134289640933, 0.1864321273751557, 0.16720049839932472, 0.10521219810470939, 0.09184343187371269, 0.20777540397830307, 0.09174445163807832, 0.14078728447202593, 0.19088767032371834, 0.06964259620872326, 0.1192549234838225, 0.20906053658109158, 0.14238153642509133, 0.130570953770075, 0.21078160672914237, 0.14922266855137423, 0.14721285842824727, 0.06121353893831838, 0.15042788669234142, 0.1714899338549003, 0.13977054215501994, 0.207243105978705, 0.09500306623522192, 0.1267140865093097, 0.2597844006959349, 0.11766296476707794, 0.09452580590732396, 0.08420791229582392, 0.0993165621184744, 0.14322932140203193, 0.09694466556538828, 0.19664131861645728, 0.1487003598595038, 0.1061701326398179, 0.16319392510922626, 0.1657759607769549, 0.085344014223665, 0.07576227173558436, 0.16702802327927202, 0.15111930115381256, 0.10447891167132184, 0.13092969311401248, 0.12430067421519198, 0.1276170724304393, 0.11825664580101147, 0.12472689704736695, 0.15297747566364706, 0.18094908096827567, 0.18729751609498635, 0.11584407955524512, 0.1419544601230882, 0.12472547212382779, 0.10816531503223814, 0.10260987211950123, 0.14661191176855937, 0.08676543482579291, 0.1619914232287556, 0.15576965786749497, 0.12050387638737448, 0.12013321073027328, 0.11328791515552439, 0.22521863516885787, 0.2625274675665423, 0.32955403032246977, 0.1057868504722137, 0.10095946927322075, 0.15459629270480946, 0.1860597325139679, 0.16044254618464038, 0.14888589677866548, 0.09597168769687414, 0.09199206921039149, 0.18038838839856908, 0.14813978603342548, 0.1512951753102243, 0.13196518208133057, 0.14749613619642332, 0.09695759377791546, 0.09476149716647342, 0.13346483989153057, 0.08131516908179037, 0.205269111902453, 0.14917600230546668, 0.16021156014176086, 0.10983818268869072, 0.17548504838487133, 0.08330813245265745, 0.16019505477743223, 0.15421662479639053, 0.09637355324230157, 0.10122274616151117, 0.17229816236067563, 0.06915660822414793, 0.16773352370364591, 0.12508308340329677, 0.07054616100504063, 0.1519446584279649, 0.1702159779961221, 0.12235576490638778, 0.16669042030116543, 0.11991873747319914, 0.13685589074157178, 0.1829544233623892, 0.1524835466989316, 0.07808624039171264, 0.07316123708733357, 0.10244035074720159, 0.10901186804403551, 0.13655873481184244, 0.17868508526589721, 0.15509237389778718, 0.09948220205842517, 0.14244729070924222, 0.2043593130656518, 0.15274411474820226, 0.18488250818336383, 0.11455229730927385, 0.1416804443579167, 0.10144913831027225, 0.2617651631589979, 0.1021923843654804, 0.15398011717479676, 0.15791707701282576, 0.22325213678414002, 0.12008453326416202, 0.12029280216665938, 0.16447297210106626, 0.08638980420073494, 0.12760678626364097, 0.11827294336399063], [0.012656886119657429, 0.027518123388290405, 0.010199374482908752, 0.018971155550389085, 0.07217854450573213, 0.023511837680416647, 0.07785293884808198, 0.04550991303403862, 0.03949762998672668, 0.10129796282853931, 0.020344735457911156, 0.033965015536523424, 0.06233077176148072, 0.02161424585210625, 0.039889591571409255, 0.0342281254415866, 0.05158236941497307, 0.05837362550664693, 0.034484363059164025, 0.0520170564414002, 0.012736934168060543, 0.00981615632554167, 0.02657325992913684, 0.02207254059612751, 0.033588557416806, 0.05601836048299447, 0.03358302099513821, 0.02729121915763244, 0.013374991922319168, 0.04494396234804299, 0.14461216516792774, 0.0547361630742671, 0.027071189069829416, 0.10409502836409956, 0.03204733562597539, 0.049085970167652704, 0.03443798254011199, 0.051143563468940556, 0.028802270790038165, 0.05802959552966058, 0.08700650665559806, 0.04548761891783215, 0.042236785739078186, 0.04986050887964666, 0.03940573726140428, 0.06637944708927535, 0.008448065527772997, 0.046657518250867724, 0.013729233851336176, 0.06317014820524491, 0.024725800176383927, 0.06379881408065557, 0.028685137622233015, 0.05324934441887308, 0.01451297055609757, 0.03344397962791845, 0.024288649219670333, 0.06155330156616401, 0.12983567838091403, 0.06557803149917163, 0.019937596953241155, 0.03039366547454847, 0.022067716636229306, 0.06491951644420624, 0.00763797886975226, 0.035381033303565346, 0.027921189357584808, 0.09327691979706287, 0.04033319179143291, 0.04850222649110947, 0.024809575661493, 0.024672985236975364, 0.011187177678948501, 0.07090866303769872, 0.011931964618270285, 0.03769060429476667, 0.03976370848249644, 0.02688517161004711, 0.0690821856551338, 0.06279298133449629, 0.03005911457876209, 0.0650433957343921, 0.011254369874222903, 0.04967562133970205, 0.020562347999657504, 0.046487069193972275, 0.03761308325920254, 0.07282724836841226, 0.030019608202564996, 0.02489407288521761, 0.07852692026062869, 0.0409998964460101, 0.030621226505900268, 0.03545607927662786, 0.04589089825458359, 0.03212314972188324, 0.04697517229942605, 0.08441498634056188, 0.052958715677959844, 0.008877615036908537, 0.04286810850317124, 0.09738454391481355, 0.006537911922350759, 0.056673142535146326, 0.02346368713915581, 0.05250631358649116, 0.02799925958242966, 0.041012483270606026, 0.015013583488325821, 0.05855489878740627, 0.05972070888674352, 0.1168935802706983, 0.022192226751940325, 0.030260654057201464, 0.045693119609495625, 0.0246322988459724, 0.03313147237349767, 0.05157226878509391, 0.0210416158370208, 0.04099208163097501, 0.055524476047139615, 0.06660883009317331, 0.03750894880795386, 0.0338828894746257, 0.022093452462286223, 0.00726442301129282, 0.054301665295497514, 0.04754882276756689, 0.02298628765856847, 0.03357758105266839, 0.06974243733566254, 0.02420801672997186, 0.04521073104115203, 0.07293895643670112, 0.021914778553764336, 0.029843377815268468, 0.04110882517124992, 0.025556747677910607, 0.04272577200026717, 0.028458572924137115, 0.08910784585168585, 0.03083665342273889, 0.037865509948460385, 0.05672329687513411, 0.0582421911531128, 0.0038450522697530687, 0.06198241506353952, 0.10593262311886065, 0.067081459419569, 0.0328800921124639, 0.06493442619103007, 0.010453204758960055, 0.020623948112188373, 0.012821453656215454, 0.04219098038447555, 0.01085146996047115, 0.03451991935435217, 0.014699034400109667, 0.09452746831811965, 0.022609241386817303, 0.03870901644404512, 0.05411146026744973, 0.006104027806941303, 0.04395931420731358, 0.03123407906969078, 0.048891479236772284, 0.026205700160062406, 0.06656018973444588, 0.03988002899859566, 0.009272788265661802, 0.011055434406443965, 0.033062311631510966, 0.03777072284719907, 0.06504893215605989, 0.02717559997108765, 0.0367133627878502, 0.07115947184502147, 0.02191589734138688, 0.015517370957240928, 0.0370808409206802, 0.04351606279669795, 0.04004666341643315, 0.12124353786930442, 0.01011098005619715, 0.006006082867315854, 0.036778745998162776, 0.059412127593532205, 0.0344164899433963, 0.016147543392435182, 0.015429992345161736, 0.06850880978163332, 0.036595509736798704, 0.04322721892094705, 0.024494057142874226, 0.015499090004595928, 0.0366360124462517, 0.0382095028180629, 0.04299698986869771, 0.008009555513126543, 0.0621002050320385, 0.013279212198540336, 0.017170805476780515, 0.06903078450704925, 0.03377701839781366, 0.010438180906930938, 0.008590425222791964, 0.06778264054446481, 0.04912050972052384, 0.005306835964802303, 0.0570268612500513, 0.04199987364700064, 0.02435791386233177, 0.07536712262663059, 0.10086374706588686, 0.04360050064860843, 0.012535267596831545, 0.0260909919597907, 0.007369549157374422, 0.025075785888475366, 0.06642002772423439, 0.05095949600217864, 0.05351738218450919, 0.0316951494460227, 0.028584185129147954, 0.03219073340005707, 0.07831779046682641, 0.028814352954213973, 0.01851901692134561, 0.05873817586689256, 0.02310534669959452, 0.06497220150777139, 0.08113420379231684, 0.033892121791723184, 0.12243979828781448, 0.06917770006111823, 0.06051824304449838, 0.04700810881331563, 0.04843766706471797, 0.02504263786249794, 0.016201950238610152, 0.03866853970976081, 0.040409866778645664, 0.029180328237998765, 0.026906142848019954, 0.05452492187032476, 0.004724522314063506, 0.0483046927547548, 0.04783001510077156, 0.036414882124518044, 0.06786213198211044, 0.02316227684787009, 0.022977478365646675, 0.011576339511520928, 0.04560835521260742, 0.1169439498335123, 0.05999803091981448, 0.009092271047848044, 0.020532135167741217, 0.008913026613299735, 0.060000969824614, 0.06893266516271979, 0.05857296637259424, 0.003475600487945485, 0.04768891798448749, 0.05803883897897322, 0.035057853965554386, 0.022272189453360625, 0.07777644568705, 0.08559427384170704, 0.028823091743106488, 0.04422152240294963, 0.07472342826076783, 0.013058858348813374, 0.05320006581314374, 0.0867893839313183, 0.0632167179719545, 0.0734095745428931, 0.07385157543467358, 0.030650441149191465, 0.036863528948742896, 0.03215255361283198, 0.04628151284123305, 0.02485652206814848, 0.02254537586850347, 0.015856324644119013, 0.0064644731628504815, 0.05535082091228105, 0.11679016941343434, 0.08140759615343995, 0.040560556153650396, 0.05048078477557283, 0.04093213094165549, 0.04655700919101946, 0.04734093978186138, 0.01954617713636253, 0.028990299470024183, 0.05633360255160369, 0.01480465407439624, 0.02115020131896017, 0.028188286451040767, 0.044782129625673406, 0.10156952950637788, 0.04440477350726724, 0.03560424163879361, 0.05810383998323232, 0.0626499397912994, 0.05956412685918622, 0.036056057433597744, 0.018575566718936898, 0.01934878069732804, 0.027328426731401123, 0.02810059057082981, 0.0761387484089937, 0.01225065674589132, 0.06708220156724565, 0.046147844623192213, 0.06038680498022586, 0.04414566377818119, 0.02605779198347591, 0.06512736974400468, 0.06860323323053308, 0.006866201874800026, 0.09439497269340791, 0.014392987541214097, 0.05447950985399075, 0.03199630184099078, 0.04867737334279809, 0.042089113194379024, 0.05995284896926023, 0.032359007964259945, 0.05068350612418726, 0.05151110097358469, 0.016940543027885724, 0.020646032571676187, 0.028648625811911188, 0.025475278416706715, 0.07020221266429871, 0.03791328570514452, 0.05591110901150387, 0.04234038955473807, 0.030484686176350806, 0.06019389853463508, 0.0037113274629518855, 0.053263857116689906, 0.027460849996714387, 0.025310888995591085, 0.0961443038249854, 0.030731780534551945, 0.02869490985176526, 0.040175544781959616, 0.01227776368978084, 0.0190034872139222, 0.1730100897839293, 0.10541058160015382, 0.08147254149662331, 0.13923756137955934, 0.1565445787855424, 0.12055336279445328, 0.34875226265285164, 0.09935743219102733, 0.12378630650346167, 0.15124076104257256, 0.15150014165556058, 0.11918463467736728, 0.1303869902039878, 0.07202886816230603, 0.11999920112430118, 0.13030499772867188, 0.1992433180566877, 0.09863633924396709, 0.1379625961999409, 0.20240744983311743, 0.1284787355689332, 0.15192132530501112, 0.19377254677237943, 0.1823800159036182, 0.15709007217083126, 0.25627318129409105, 0.15293655364075676, 0.11755600644391961, 0.10180876080994494, 0.11592968628974631, 0.2934312983416021, 0.16323750402079895, 0.14994569850387052, 0.1762948650866747, 0.123651361791417, 0.1065553147054743, 0.13830848154611886, 0.18760838691378012, 0.13301722094183788, 0.20719004241982475, 0.20484872977249324, 0.18260677170474082, 0.1747479769983329, 0.18741695734206587, 0.10032071018940769, 0.13243700988823548, 0.1264811708824709, 0.15342410013545305, 0.1752658179611899, 0.15278646169463173, 0.14020538132172078, 0.139250029460527, 0.19205481628887355, 0.16571235872106627, 0.24180155392969027, 0.15852393116801977, 0.2155466252588667, 0.2894229884259403, 0.22593768720980734, 0.16453611402539536, 0.034079974211636, 0.23185628524515778, 0.07843036684789695, 0.18676918116398156, 0.08374945799005218, 0.10555198299698532, 0.1294785866048187, 0.1371054898481816, 0.12022195674944669, 0.11125782955787145, 0.07885390310548246, 0.13483721937518567, 0.15508542739553377, 0.15752399107441306, 0.13725503260502592, 0.12991952622542158, 0.09973753054509871, 0.13749986712355167, 0.21718742471421137, 0.12440231876098551, 0.0969686072494369, 0.15303116262657568, 0.07887872052378953, 0.2186223227181472, 0.20905160112306476, 0.1724703999934718, 0.15428516955580562, 0.20509899681201205, 0.1857661092071794, 0.13562523177824914, 0.16978654166450724, 0.12466126150684431, 0.19674973154906183, 0.13037692668149248, 0.24623009754577652, 0.15484357631066814, 0.09538707570754923, 0.19151132670231164, 0.15526275616139174, 0.06624743386055343, 0.11394761764677241, 0.21495608350960538, 0.18560055090347305, 0.18079619854688644, 0.0681783388426993, 0.1707823554170318, 0.1115121561451815, 0.08890892058843747, 0.18727345566730946, 0.09870971538475715, 0.14195578114595264, 0.18331011990085244, 0.10572681072517298, 0.12544070952571929, 0.15411797852721065, 0.14112629753071815, 0.09919528034515679, 0.15864669723669067, 0.11664481236948632, 0.09155083273071796, 0.07355346213444136, 0.14706907473737374, 0.11090683823567815, 0.13397582340985537, 0.08155128336511552, 0.11839996936032549, 0.20803435414563864, 0.1601577692781575, 0.09174812526907772, 0.15684314479585737, 0.2123632570146583, 0.09065618854947388, 0.19689418317284435, 0.16730785748222843, 0.12980820407392457, 0.09371556618134491, 0.19333061267388985, 0.13339435070520267, 0.14851902349619195, 0.0913571470300667, 0.12313162093050778, 0.1615274473442696, 0.1113787476788275, 0.12208330022986047, 0.1237656970624812, 0.11864032872836106, 0.19245326053351164, 0.11770444340072572, 0.21306595212081447, 0.16878295020433143, 0.15932874579448253, 0.19692590256454423, 0.08259518086561002, 0.08189989981474355, 0.19603634951636195, 0.11132005864055827, 0.19488400197587907, 0.1046355048310943, 0.2042389367124997, 0.18445224064635113, 0.1353369964635931, 0.21622520056553185, 0.1561479305382818, 0.12795556598575786, 0.11251015923335217, 0.1856642123311758, 0.07868663786211982, 0.1497021404793486, 0.11031128698959947, 0.18097625841619447, 0.11463699120213278, 0.12121048261178657, 0.15879509708611295, 0.11640410419204272, 0.13977259048260748, 0.11053629132220522], [0.0375755342975026, 0.0055864864862087416, 0.12324593393714167, 0.0709688215283677, 0.0874944390670862, 0.03983203430834692, 0.02676428503036732, 0.0017737794473760005, 0.05360409471904859, 0.0555225984135177, 0.015017030764283845, 0.0449799453781452, 0.010930315729638096, 0.03393299186427612, 0.020362684299470857, 0.014328533870866522, 0.03401603076781612, 0.10585878684651107, 0.10621996043482795, 0.04744338213640731, 0.027230747109570075, 0.036438523238757625, 0.0368529051047517, 0.033426665322622284, 0.023918974329717457, 0.04916391793813091, 0.053361456957645714, 0.009673251151980367, 0.015130046867852798, 0.11548234935617074, 0.006895092756167287, 0.011423351334087783, 0.058169750118395314, 0.0041086362216447014, 0.015823011490283534, 0.027649921394186094, 0.09645207246649079, 0.004270487961548497, 0.03746829766896553, 0.01908605670905672, 0.026420273607072886, 0.014698475006298395, 0.09878303215373307, 0.03400046793103684, 0.02922671803389676, 0.018140727552236058, 0.046223369281506166, 0.04503964002651628, 0.042860879984800704, 0.018847734536393546, 0.027754259936045855, 0.030169616657076403, 0.021561317735177, 0.04327859409386292, 0.015357077263615793, 0.02227096676506335, 0.011640150296443608, 0.04112376460398082, 0.03249644629249815, 0.030897453871148173, 0.00970878982116119, 0.018575117719592527, 0.026952781263389625, 0.042060896739712916, 0.01780667018465465, 0.02077777677186532, 0.0385468386230059, 0.06261000482481904, 0.003019990231223346, 0.019020521358470432, 0.057469259190838784, 0.041145865761791356, 0.08174148839316331, 0.008032954501686618, 0.027391457333578728, 0.06353372635203414, 0.05516574783541728, 0.07167803269112483, 0.006363473821693333, 0.012572653286042623, 0.06226365192560479, 0.016215826544794254, 0.00823871216198313, 0.04265560935891699, 0.05924740791670047, 0.08340360232978128, 0.021608570277749095, 0.050030597994918935, 0.038502001771121286, 0.020226661617925856, 0.047102283642743714, 0.032820208216435276, 0.08139148412737995, 0.06356793935992755, 0.07816490062396042, 0.07016278977971524, 0.037694348429795355, 0.03721583016158547, 0.03405946867133025, 0.005128003422214533, 0.030446370947174728, 0.0437070507905446, 0.026797952559718397, 0.05979229274089448, 0.042104100866708905, 0.06131008492957335, 0.027357209073670674, 0.06620396627113223, 0.015954696318658534, 0.02066700380964903, 0.024728102689550724, 0.027336115381331183, 0.07944713885081, 0.035238685668446124, 0.02487946370820282, 0.056573097317595966, 0.06385779997799546, 0.03163323948683683, 0.043664896802511066, 0.07518899976275861, 0.10903108224738389, 0.03236419186578132, 0.07964148506289348, 0.029648987074324396, 0.03231298738683108, 0.06665472450549714, 0.07480241503799334, 0.0755961642425973, 0.05814712574647274, 0.04368890899058897, 0.011814427907665959, 0.04950104594172444, 0.03104999675997533, 0.04693526330811437, 0.032954518392216414, 0.02152460740035167, 0.035445410903776065, 0.06544005140312947, 0.06831293474533595, 0.025351235854031984, 0.023463852267013863, 0.018340780879952945, 0.05125824754941277, 0.06286626841756515, 0.02873718814953463, 0.055087870568968356, 0.022325586978695355, 0.017807189688028302, 0.030341121419041883, 0.016818418916955125, 0.041473690944258124, 0.08041858789511025, 0.026662673881219234, 0.031239570962497965, 0.032683931349311024, 0.059062164145871066, 0.04070280359883327, 0.025357781596540008, 0.03158173443807755, 0.055067409557523206, 0.028576381446328014, 0.020547254571283702, 0.005607970733763068, 0.007741905519651482, 0.06738476775353774, 0.028673099986917805, 0.10555366025073454, 0.026740666180558037, 0.007111389377314481, 0.008062674733082531, 0.033338947177981026, 0.023692680515523534, 0.05245948406809475, 0.019058326361118816, 0.040759477706160396, 0.038463328455691226, 0.046356336169992574, 0.022261645390244666, 0.03847192623652518, 0.05794651209725998, 0.05446416966151446, 0.08538995316484943, 0.00540019350410148, 0.01157547583716223, 0.011796654398494866, 0.11591360394959338, 0.02694552305911202, 0.03324338453239761, 0.019561443114071153, 0.05655967186612543, 0.046490605527651496, 0.07273508846992627, 0.042495160741964355, 0.019285725975350942, 0.010005607146013062, 0.01887642967631109, 0.05210272254771553, 0.07340371157624759, 0.024852571987139527, 0.030766025083721615, 0.02316919923032401, 0.02602575346827507, 0.0388764709350653, 0.022364675896824338, 0.07121576374629512, 0.04141804471146315, 0.02206826025940245, 0.035206691682105884, 0.021772458749182988, 0.0301858177408576, 0.042256348751834594, 0.003030762736671022, 0.07382767827948555, 0.010813178851094563, 0.02053858999715885, 0.005627963728329632, 0.04667418688768521, 0.008454447997792158, 0.07939223476569168, 0.03577709896489978, 0.02985818366141757, 0.03807013119512703, 0.035044654869125225, 0.030449625264736824, 0.020228116227372084, 0.031483088168897666, 0.035926934870076366, 0.04762205047882162, 0.05127614815137349, 0.030290030117612332, 0.02485148659616243, 0.01676550007687183, 0.025728282125783153, 0.048107433613040484, 0.05902339064050466, 0.05815141907078214, 0.008055950875132112, 0.032287019639625214, 0.031161615770542994, 0.0120344320203003, 0.014966069338697707, 0.00319974929880118, 0.006776868631277466, 0.03267566382419318, 0.03237450771848671, 0.024777900798653718, 0.044976357094128616, 0.029001303664699662, 0.04840120534936432, 0.021928951719019096, 0.05573601411015261, 0.027017656102543697, 0.035500311278156005, 0.03176379810611252, 0.07055053967633285, 0.012472220296331216, 0.038314557532430626, 0.05165287715499289, 0.02140559103281703, 0.04070328599482309, 0.024171935365302488, 0.06036519363988191, 0.00784190249760286, 0.07915704074548557, 0.02925685479567619, 0.08548824320314452, 0.06541726004797965, 0.06191333224705886, 0.07966276985825971, 0.04486960657231975, 0.034408140782034025, 0.023700038909737486, 0.022994749997451436, 0.06314234735327773, 0.03184094435709994, 0.025591240846551955, 0.03359191934578121, 0.03795684977376368, 0.04766413025208749, 0.03382226714165881, 0.006087209812903893, 0.1133333939651493, 0.0691827763512265, 0.03711164747073781, 0.02769864153378876, 0.08794518987997435, 0.06604193316888995, 0.01788797617336968, 0.06739661985193379, 0.02308851107954979, 0.0794474505528342, 0.015313728417822858, 0.011539502083905973, 0.0557412833586568, 0.03973011516791303, 0.02692821617529262, 0.0016952431769823306, 0.027922412045882083, 0.024869815788406413, 0.05505065186298452, 0.018437855651427526, 0.05250611691735685, 0.010186595627601491, 0.0503230783942854, 0.03691931990033481, 0.07845818254281767, 0.05859519740624819, 0.028663748926192056, 0.03999164058768656, 0.014878623005643021, 0.034654351984499954, 0.039175270721898414, 0.0359802656021202, 0.06214719782292377, 0.058387915560160764, 0.014136994832369965, 0.03598200964916032, 0.07321102035348304, 0.07564077473944053, 0.04476315662031993, 0.029923787660663947, 0.08395787532208487, 0.11569026202778332, 0.022401983660529368, 0.034055572396027856, 0.03443442765274085, 0.048124922323040664, 0.05303180238115601, 0.022447894771175925, 0.01954139028384816, 0.04669260699301958, 0.04150265325733926, 0.026109638420166448, 0.03954996253014542, 0.01540314979138202, 0.04723274949355982, 0.03266598992922809, 0.010565651264187181, 0.022198998849489726, 0.019720591117220465, 0.04255747146089561, 0.01921619044878753, 0.05059570263256319, 0.050421461201040074, 0.013375200651353225, 0.059758706847787835, 0.05924705168581568, 0.07100258182617836, 0.04172441069385968, 0.01297628050451749, 0.02765360059129307, 0.025371320225531235, 0.11517958279000595, 0.15938464435748756, 0.2212277360376902, 0.19497953122481704, 0.20441752712940797, 0.17448764643631876, 0.10384781155153178, 0.07327414001338184, 0.16740310471504927, 0.18826972955139354, 0.0939339876640588, 0.11325680432491936, 0.12217587573104538, 0.10499969896045513, 0.1512917020590976, 0.18315694062039256, 0.18914006097475067, 0.18310531682800502, 0.2406968522700481, 0.16911963291931897, 0.22898855240782723, 0.15912049915641546, 0.15280676685506478, 0.13794856960885227, 0.1720758742885664, 0.1938592889928259, 0.16636513697449118, 0.13228236115537584, 0.1329911864013411, 0.18271240900503471, 0.09277965116780251, 0.12601373658981174, 0.15512930316617712, 0.10784692625747994, 0.10222608529147692, 0.10897200729232281, 0.17053625924745575, 0.1005941248149611, 0.15938945347443223, 0.06930721967364661, 0.07126192533178255, 0.06688962908810936, 0.13477740227244794, 0.12103902423405088, 0.15890307957306504, 0.11788912685005926, 0.147014660469722, 0.10811258543981239, 0.10220138661679812, 0.22552753187483177, 0.18596090812934563, 0.08967541813035496, 0.18835964816389605, 0.1329206526861526, 0.07067812228342518, 0.14094282378209755, 0.08099926650174893, 0.1483632021700032, 0.1332687644753605, 0.13251952186692506, 0.1021325153124053, 0.1224567712051794, 0.1394882588647306, 0.08601437395554967, 0.1618234158377163, 0.07413451181491837, 0.11869038658915088, 0.09130619117058814, 0.09987838275264949, 0.12042457048664801, 0.12609463068656623, 0.09809210750972852, 0.10017131586209871, 0.11748703123885207, 0.149845642154105, 0.17684513790300116, 0.1395867863902822, 0.14379602536791936, 0.18781552033033222, 0.13960808602860197, 0.13520928769139573, 0.1844097304274328, 0.09107937599765137, 0.1626888639293611, 0.16679445456247777, 0.1492720065289177, 0.07372647902229801, 0.2401472325436771, 0.1385113995638676, 0.24385008931858465, 0.22174915415234864, 0.2519632031908259, 0.12394539327942766, 0.16749557631555945, 0.2781342691741884, 0.1444288101629354, 0.19120783283142373, 0.15064450475620106, 0.13043551181908697, 0.09409602818777785, 0.12580661801621318, 0.16286754340399057, 0.14121786371106282, 0.1686492151929997, 0.14047662145458162, 0.1867431466234848, 0.13530348107451573, 0.13995740009704605, 0.14816605806117877, 0.16454236290883273, 0.12752862327033654, 0.12619784858543426, 0.11025607862393372, 0.15630241599865258, 0.15599372709402815, 0.10626745788613334, 0.11746280753868632, 0.2345811398117803, 0.10054005193524063, 0.1756709415349178, 0.1670993139850907, 0.15805057453690097, 0.2659002912696451, 0.17527487216284499, 0.2372634396306239, 0.16419307852629572, 0.13392016233410686, 0.19337281119078398, 0.14061699126614258, 0.17668766900897026, 0.11040995552320965, 0.0742992760206107, 0.20935738080879673, 0.08914496807847172, 0.2193905643071048, 0.1321830617962405, 0.15050529269501567, 0.19807496981229633, 0.11910693181562237, 0.13034149655140936, 0.10208580453763716, 0.13575488497735932, 0.1099518351838924, 0.12334607192315161, 0.09485781309194863, 0.12875030224677175, 0.22710416524205357, 0.12179096083855256, 0.09024410363053903, 0.09839898557402194, 0.13762705639237538, 0.32049101195298135, 0.12268488513655029, 0.1277530041988939, 0.1569867503712885, 0.17815961502492428, 0.13204092567320913, 0.12781921861460432, 0.09847733410424553, 0.14999036095105112, 0.11283032174105756, 0.0980506585619878, 0.0935786399350036, 0.08454596056253649, 0.15718398353783414, 0.14098243962507695, 0.15397061768453568, 0.11785154449171387, 0.07797807236784138, 0.14802084944676608, 0.21012945187976584, 0.12755793810356408, 0.14248773775761947, 0.06894403486512601, 0.10990372917149216, 0.1726930888253264], [0.06404577114153653, 0.012939212083438179, 0.03705011600686703, 0.03676850064948667, 0.041897182672983035, 0.017050137830665335, 0.034381954101263545, 0.05040372387156822, 0.023840492212912068, 0.02812302569509484, 0.04912240219709929, 0.0905355004942976, 0.05327320446667727, 0.03209264745237306, 0.08871720900060609, 0.00836517412608373, 0.06868514406960458, 0.11017952609108761, 0.04091057526238728, 0.017256217397516593, 0.026893613539868966, 0.04542788716207724, 0.035067423959844746, 0.05456336883071344, 0.037541080091614276, 0.043770931151811965, 0.03480257000774145, 0.0459028690966079, 0.010544087235757615, 0.056263480728375725, 0.013854086282663047, 0.021775291897938587, 0.07613087422214448, 0.018289826875843573, 0.05255481293716002, 0.05262706472421996, 0.08309265729621984, 0.0017137503687081335, 0.0385832892061444, 0.021100698213558644, 0.05472229233419057, 0.0026004251594713423, 0.04858666434301995, 0.013101874155836413, 0.04069328926561866, 0.016209753921430092, 0.059669574911822565, 0.03646710334578529, 0.03223082050681114, 0.022080219969211612, 0.05691808837582357, 0.05774242148618214, 0.024267147346108686, 0.025255073924199678, 0.024567728287365753, 0.01782084334990941, 0.03284052450908348, 0.04992637077521067, 0.0776971917366609, 0.011496663464640733, 0.0053230736921250354, 0.02944024690805236, 0.05030739681387786, 0.0028577184821187984, 0.01352329993096646, 0.02016832324443385, 0.030429028811340686, 0.04297380517527927, 0.022835049094283022, 0.036988740394008346, 0.03858826159557793, 0.03531845912220888, 0.04012312689155806, 0.10171801841352135, 0.027659138868330047, 0.05724946102418471, 0.01117719208195922, 0.035715734484256245, 0.02555050992668839, 0.043583980441326275, 0.04810885111510288, 0.06381088140187785, 0.037078788882354274, 0.09636149334255606, 0.07531794792157598, 0.0554847080638865, 0.06162844772916287, 0.029036995401838794, 0.02964187729958212, 0.10327591997338459, 0.006089480784794432, 0.015095262406248366, 0.028401614945323672, 0.07386601762846112, 0.03826374639174901, 0.03948177029087674, 0.020667836870416068, 0.03733779471076559, 0.032034897230914794, 0.0187413346793619, 0.035568269740906544, 0.02374793155468069, 0.025317588733742014, 0.014086350674915593, 0.03808636938629206, 0.08842673239996657, 0.048421306419186294, 0.06354778262902983, 0.04333729055360891, 0.050892416984424926, 0.03844052967906464, 0.061980158934602514, 0.03313565066491719, 0.009063440465979511, 0.02131345339876134, 0.06331641809083521, 0.0404202828212874, 0.03643914664280601, 0.04719638796814252, 0.07939933711895719, 0.027270301725366153, 0.04090732094482519, 0.03217633944586851, 0.03246560263505671, 0.010962602864310611, 0.04585370552376844, 0.020373321131046396, 0.02326119956705952, 0.030922024525352754, 0.09778473220649175, 0.08987038774648681, 0.053137576978770085, 0.06649476941674948, 0.030129017468425445, 0.021063865424366668, 0.03865404927637428, 0.026015370822278783, 0.00761413830332458, 0.04094101816008333, 0.09748572832904756, 0.05318911171343643, 0.11793162964750081, 0.04600542277330533, 0.041975126732722856, 0.029818358161719516, 0.07917920127511024, 0.04780401766765863, 0.05503630243765656, 0.033732689917087555, 0.0400923760025762, 0.05427387557574548, 0.06530793427373283, 0.04189340143057052, 0.08454435752355494, 0.014185116615408333, 0.025525724049657583, 0.021858559011889156, 0.029680834486498497, 0.025940502964658663, 0.1068629942892585, 0.019459254945104476, 0.06067067646654323, 0.02824026461894391, 0.02870376738428604, 0.022159776344778948, 0.03330359126266558, 0.037043076736154035, 0.027831276311189868, 0.004967811310052639, 0.0589455430599628, 0.028276028715481516, 0.058107944059884176, 0.02368661716900533, 0.034709827523329295, 0.04378813784569502, 0.025773163506528363, 0.06721103840391152, 0.03966320684412494, 0.07874770177295431, 0.041865808379952796, 0.01909098085889127, 0.04756939881190192, 0.019480762384773698, 0.0361555720155593, 0.05472337215906009, 0.039552868038299493, 0.05622337506792974, 0.03912882712029386, 0.028398416288837325, 0.041307501815026626, 0.017416396985936444, 0.031584691896568984, 0.02039709397649858, 0.04159820848144591, 0.0882407279277686, 0.011137649526062887, 0.04007647919934243, 0.05797832796815783, 0.021052720221632626, 0.038130059620016254, 0.02005698439461412, 0.059612195764202625, 0.03472900833003223, 0.03193590215232689, 0.057457395960227586, 0.07356460177106783, 0.04711310415586922, 0.06297475556493737, 0.07349231658736244, 0.05663575684593525, 0.03692870435770601, 0.044679523998638615, 0.07734219281701371, 0.0319145208777627, 0.019714175250555854, 0.03457408871327061, 0.03339642280479893, 0.00330107147419767, 0.04507346711761784, 0.003339273757774208, 0.05093774736451451, 0.014566967365681194, 0.0032256159283861052, 0.04683058708906174, 0.04813819192349911, 0.05456169157696422, 0.01612772062799195, 0.03877553885104135, 0.00841624130771379, 0.04038773964566644, 0.024491693402524106, 0.004823864346690243, 0.06135517411166802, 0.033587729922146536, 0.05461474029289093, 0.06789925420889631, 0.02227578886959236, 0.02952053429908119, 0.028937349088664632, 0.012392868939059554, 0.03204694599844515, 0.024646961828693748, 0.02787511682981858, 0.039968303753994405, 0.029246911872178316, 0.05220135397394188, 0.027667228278005496, 0.05619063522317447, 0.054450736788567156, 0.07200054780696519, 0.02184417433454655, 0.06981954647926614, 0.014178392757457914, 0.025320984059362672, 0.016191589857044164, 0.02953251441795146, 0.022312890687317122, 0.07460112232365645, 0.03054002627322916, 0.11295560369035229, 0.052227882042643614, 0.050235326852998696, 0.022243490602704696, 0.03233462470234372, 0.0793653615983203, 0.07031657762126997, 0.03757970887818374, 0.01974231006897753, 0.04333152777689975, 0.04786645084095653, 0.07621839569765143, 0.06529766294988804, 0.02008282968745334, 0.040168909981730394, 0.031941464549163356, 0.022497438694699667, 0.01835584276705049, 0.03507594010443427, 0.029598105429613497, 0.017524249597045127, 0.03604168574383948, 0.0030619825702160597, 0.12468572269426659, 0.034121809076168574, 0.030274393066065386, 0.04024881331133656, 0.044012978905811906, 0.027103708125650883, 0.03059898805076955, 0.019563944151741453, 0.02303966106410371, 0.041539515732438304, 0.017696913964755367, 0.011293358602415537, 0.05560712903388776, 0.04273490412742831, 0.018956260646518786, 0.024406481861660723, 0.023954087191668805, 0.04031670127005782, 0.024286619445774704, 0.0624231320398394, 0.053946250773151405, 0.01976202522200765, 0.09371381471282803, 0.035081261303275824, 0.03373195890162606, 0.05373657921154518, 0.045487874958780594, 0.00424718684371328, 0.036553589525283314, 0.02268473821459338, 0.049812558718258515, 0.03398716122319456, 0.05058131238911301, 0.05029486936109606, 0.058351138432044536, 0.020212178606016096, 0.03849731139780488, 0.024553744369768538, 0.0355712234886596, 0.08067750837653875, 0.027335419617884327, 0.024493977361998986, 0.028894801762362476, 0.05410485886386596, 0.022870683314977214, 0.05476860977069009, 0.06022151756042149, 0.020751920346810948, 0.01590152329299599, 0.03500414844893385, 0.047488545533269644, 0.041058533533941954, 0.056310529180336744, 0.02860707481886493, 0.04313531877414789, 0.01215365247844602, 0.03151972057821695, 0.1551504692179151, 0.03764774155570194, 0.060238635196583346, 0.03175606863806024, 0.004304193062125705, 0.019506214339344297, 0.04042999011289794, 0.021742516801168676, 0.029481775636668317, 0.03672544866276439, 0.025681313454697374, 0.06706423417199403, 0.05331965548975859, 0.13522543682483956, 0.1388090749969706, 0.11508318522828631, 0.11241512722335756, 0.11421113944379613, 0.09239605729817413, 0.11508804629556835, 0.1825218106387183, 0.1863654825137928, 0.15646942891180515, 0.1044196734437719, 0.15292565891286358, 0.14785368810407817, 0.13160218280972913, 0.2997419284656644, 0.11728158249752596, 0.18591642379760742, 0.11704744232702069, 0.17597878439119086, 0.14919657463906333, 0.0925383492722176, 0.1369270181749016, 0.19407667889026925, 0.1542600998072885, 0.08889584394637495, 0.12921292742248625, 0.1474584944662638, 0.14773979812161997, 0.1916873938171193, 0.19559171400032938, 0.11625052415183745, 0.1605570744141005, 0.18662049929844216, 0.10308466109563597, 0.14329785131849349, 0.12902854825370014, 0.16795446106698364, 0.09412470477400348, 0.10644830443197861, 0.10281200346071273, 0.1775308229844086, 0.08975076096248813, 0.12553086562547833, 0.07551863949629478, 0.13353518064832315, 0.11815238889539614, 0.0973677342699375, 0.1472413123701699, 0.12166126311058179, 0.19213395891711116, 0.1396793915773742, 0.11660651012789458, 0.07329497952014208, 0.1350247600930743, 0.17628018540563062, 0.1201557571766898, 0.09476229126448743, 0.12107611677492969, 0.1518096320796758, 0.11074248963268474, 0.15530698816291988, 0.11363152952981181, 0.1556726888520643, 0.09955833898857236, 0.06281155729084276, 0.13206752424594015, 0.07235231838421896, 0.07840775360818952, 0.20620984345441684, 0.15762087103212252, 0.12245194724528119, 0.16227967338636518, 0.21879626729059964, 0.26243621308822185, 0.08234102497226559, 0.1713608150021173, 0.13505673181498423, 0.1696426243870519, 0.11421751449233852, 0.1630992567515932, 0.07109938014764339, 0.1929241235484369, 0.20169112889561802, 0.1968663526349701, 0.1907441092771478, 0.13425513810943812, 0.12859903770731762, 0.16125181369716302, 0.14502595702651888, 0.20946335949702188, 0.11351266715792008, 0.1362567103933543, 0.14248313644202426, 0.16444696724647656, 0.13975369540276006, 0.26037927658762783, 0.18322471354622394, 0.13353644229937345, 0.08040977118071169, 0.09517937825876288, 0.15033029427286237, 0.15610378759447485, 0.12031796097289771, 0.16138045757543296, 0.17315816308837384, 0.23339598934398964, 0.306310499436222, 0.09699742484372109, 0.1035569490341004, 0.18604159442475066, 0.2331058244453743, 0.15099570387974381, 0.07786856105667539, 0.07432035301462747, 0.1624359845300205, 0.10065792725072242, 0.085673691064585, 0.08156735828379169, 0.2435331477317959, 0.11479261956992559, 0.07273692157468759, 0.15752200211863965, 0.10275545180775225, 0.1209479033423122, 0.13844151893863454, 0.20774366974364966, 0.16606523509835824, 0.1068318537727464, 0.1226808775390964, 0.1299746974837035, 0.13525757181923836, 0.1563842748873867, 0.1964959318866022, 0.093462093063863, 0.09646465186960995, 0.08099691389361396, 0.1042819902068004, 0.11943625242565759, 0.1334191532805562, 0.19616284116636962, 0.16532382956938818, 0.20905032462906092, 0.12558278627693653, 0.1700627987156622, 0.06806415200117044, 0.21421265933895484, 0.12144704218371771, 0.1520639957743697, 0.13240218831924722, 0.19551034492906183, 0.13269469840452075, 0.14643897651694715, 0.13976985937915742, 0.27150792942848057, 0.15327586355851963, 0.11082739132689312, 0.2249025396304205, 0.04635078119463287, 0.11217355073313229, 0.200157436192967, 0.06676166798570193, 0.10305724616046064, 0.11186764488229528, 0.2460468019125983, 0.0969192321645096, 0.11494937600218691, 0.15624488471075892, 0.08589482880779542, 0.11864962041727267, 0.14179264224367216, 0.12055137383867987, 0.13348097418202087, 0.11205214279470965, 0.07650968866073526, 0.15248767304001376, 0.13109170395182446], [0.01991824545257259, 0.07047529332339764, 0.03712024896231014, 0.029931311182735953, 0.03152579134621192, 0.03798113655648194, 0.05083415839180816, 0.026845876745937858, 0.10240750329103321, 0.05372879408241715, 0.014107597435213393, 0.04456226095499005, 0.05347192935005296, 0.04688031840487383, 0.03925201621314045, 0.012796326391253388, 0.012698467726295348, 0.020643553798436187, 0.06575818042620085, 0.026062261567858513, 0.03371018799953163, 0.052459372745943256, 0.07257421311805956, 0.012791304834536277, 0.022929728584131226, 0.04272361606126651, 0.05874167509318795, 0.05095316177175846, 0.05929496473981999, 0.06631544427364133, 0.01041790543240495, 0.04175302790827118, 0.008321924542542547, 0.01965546023711795, 0.028062694655091036, 0.018540951095928904, 0.04656466444430407, 0.03271501249400899, 0.04297433581086807, 0.055923076142789796, 0.009210129665007116, 0.024833977477101143, 0.09231930438545533, 0.038977313961368054, 0.025741184363141656, 0.015917368145892397, 0.04752085493237246, 0.02115615519869607, 0.02109296874550637, 0.01449471650630585, 0.0074831125948549015, 0.07625008540344425, 0.04027216498798225, 0.09463598515139893, 0.029782538404106162, 0.061305650597205386, 0.049475263731437735, 0.03685438940010499, 0.01768229736626381, 0.06383774714777246, 0.04417404721607454, 0.032927767679211684, 0.03616107132984325, 0.02494168536941288, 0.009050529879459646, 0.027480618955451064, 0.014939446646167198, 0.013696465248358436, 0.04388502151414286, 0.0563101840816671, 0.015012069507065462, 0.02795516116748331, 0.0573789138434222, 0.05538194287510123, 0.04445142862095963, 0.025083687905862462, 0.0727401944459416, 0.052543662168318406, 0.034693418638198636, 0.0061348816689132946, 0.020324625111243222, 0.014178787951095728, 0.04101561884453986, 0.011961964082729537, 0.05280454563035164, 0.057993634763988666, 0.04431317393027712, 0.042157932548434474, 0.04192376640276052, 0.03713322541443631, 0.007490520620194729, 0.01643833540583728, 0.04706215942860581, 0.017385746286890935, 0.05399444584327284, 0.09201414810377173, 0.024865344348654617, 0.0461674781399779, 0.049353907743352465, 0.034065717554767616, 0.052499778976198286, 0.011988833539362531, 0.048904355498962104, 0.05974527768557891, 0.04203344098641537, 0.05062958167400211, 0.0035442542503005825, 0.052145258741802536, 0.051882865009247325, 0.045044293292448856, 0.020265791354177054, 0.0224646543210838, 0.024282222220790572, 0.029283781768754125, 0.04208473452308681, 0.0489132315851748, 0.04375989912659861, 0.03484872788249049, 0.03587309947761241, 0.0412198875710601, 0.09780816923012026, 0.0531512510497123, 0.04577035491820425, 0.03563340433174744, 0.04650030910852365, 0.04065379216626752, 0.021508354366233107, 0.0629225380544085, 0.09088551960303448, 0.06039195548510179, 0.07091726452927105, 0.024883612313715275, 0.08947989932494238, 0.07685155898798257, 0.03772150361328386, 0.04046490816108417, 0.04020054402644746, 0.05110794780193828, 0.07695430933381431, 0.016271270542347338, 0.028076788039470557, 0.0463986905378988, 0.021204370677878615, 0.021909325623710174, 0.017507408410892822, 0.035247799241915345, 0.006384252565112547, 0.08856117245159112, 0.00642657260868873, 0.03351869534526486, 0.020869344807579182, 0.028547224319481757, 0.006930966783329495, 0.09749879012815654, 0.09780933440197259, 0.038217633045860566, 0.00613906784565188, 0.039487377216573805, 0.0641015954897739, 0.02681212758034235, 0.03276911505963653, 0.06910898460773751, 0.015578783677483443, 0.04142358113313094, 0.05895820781006478, 0.031031103535497095, 0.024554017109039705, 0.035668040363816544, 0.04077623911143746, 0.0856068087159656, 0.02019480863964418, 0.07110821912647225, 0.03744048939552158, 0.04179027630016208, 0.048638484804541804, 0.03281763296399731, 0.02184374759963248, 0.020217982200847473, 0.06902127017383464, 0.05241961589490529, 0.05258034652797505, 0.012387180377118057, 0.030220223707146943, 0.03528414592437912, 0.049258831204497255, 0.027901847133762203, 0.02760163912171265, 0.046391280193347484, 0.011696586916514207, 0.08585280098486692, 0.018766695720842108, 0.0631397869437933, 0.02838159736711532, 0.038568364616367035, 0.04032501332403626, 0.04321004933444783, 0.02018778606725391, 0.029649350726685952, 0.04908870498184115, 0.017678517979220487, 0.03416869054490235, 0.025078045728150755, 0.03905882032995578, 0.03674412851978559, 0.04508926373091526, 0.029675906625925563, 0.014547456303262152, 0.06243459079996683, 0.023023326393740717, 0.039561543744639494, 0.024197455968533177, 0.019061157654505223, 0.04463528086489532, 0.02893253811635077, 0.04824452684260905, 0.03131117708107922, 0.01598591661604587, 0.04121755722735543, 0.053432447093655355, 0.020012583554489538, 0.04136915202252567, 0.025734631199156865, 0.04130494882701896, 0.034873059194069356, 0.037870868254685774, 0.0272942823721678, 0.04267670119588729, 0.04728366824565455, 0.018705492657318246, 0.01579390445840545, 0.010793434012157377, 0.0126312857355515, 0.02493739204510348, 0.019481999916024506, 0.01643110688746674, 0.05592198147496674, 0.01711349126708228, 0.006814548860347713, 0.036059708800166845, 0.01539061213406967, 0.04214494125335477, 0.041301761302747764, 0.03251478847232647, 0.03212155410437845, 0.022587518724321853, 0.012081925760867307, 0.028649184278037865, 0.05237412595306523, 0.05446412513265386, 0.045381829477264546, 0.08212388740503229, 0.008552520030207234, 0.02618153768707998, 0.030350570814334787, 0.03493194861221127, 0.04914978373562917, 0.01912508625537157, 0.013817580038448796, 0.07379126851446927, 0.024897265975596383, 0.04205805802484974, 0.03278274089097977, 0.0208882417427958, 0.02924839616753161, 0.09777092083822936, 0.05897485047171358, 0.04313770477892831, 0.044562194161699153, 0.0726902850146871, 0.024721182162465993, 0.015210450219456106, 0.07478756466298364, 0.05627858714433387, 0.030771589335927274, 0.019611148454714566, 0.06824580006650649, 0.036471218554652296, 0.03050069801247446, 0.05188124341657385, 0.01484433856603573, 0.02108731358021032, 0.040072078263619915, 0.04188658109342214, 0.02634504209709121, 0.07446592528140172, 0.012158362333138939, 0.09248538219253533, 0.03702605186845176, 0.015191076454357244, 0.0296237781731179, 0.055011373697197996, 0.028223265726410318, 0.0157161663446459, 0.041497090860502794, 0.015161423016252229, 0.04746766520838719, 0.08410425652982667, 0.03669166238978505, 0.009459167522436474, 0.062284817977342755, 0.04331864038249478, 0.05102945084217936, 0.035790064284810796, 0.03730699187144637, 0.01848845713539049, 0.04225699813105166, 0.03459037885477301, 0.04057530633872375, 0.06013261940097436, 0.06902577501023188, 0.02590383530332474, 0.01789192254364025, 0.044182485435158014, 0.019720587406482082, 0.06870435085147619, 0.021188041573623195, 0.09069248699233867, 0.030038631302886643, 0.021473376946232747, 0.05689543431799393, 0.042341098305769265, 0.05978435176075436, 0.024385701726714615, 0.056120721201295964, 0.043873833637917414, 0.06468404782935977, 0.020420890941750258, 0.06949631148017943, 0.03375047548615839, 0.04706316132796928, 0.09174056278425269, 0.07775469333864748, 0.018740633349807467, 0.02434493555483641, 0.015715125482529402, 0.05282444260956254, 0.018896020519605372, 0.01872120763437124, 0.019989666034234688, 0.020147088544035796, 0.03258482123783324, 0.01313823753662291, 0.0374398659914732, 0.052998524479335174, 0.018651703649084084, 0.06181049655424431, 0.005747933755628765, 0.028064657635695767, 0.08713028946658596, 0.04663723164412659, 0.025408869187231176, 0.03500751037790906, 0.089748000173131, 0.1713539575575851, 0.20536906435154378, 0.11984429263975471, 0.09804633926250972, 0.0917390116956085, 0.153911720844917, 0.11166246331413276, 0.16928176250075921, 0.13007877627387643, 0.09114562009926885, 0.16103194502647966, 0.16871615691343322, 0.2172854178934358, 0.12698528211330995, 0.15052654780447483, 0.09725993731990457, 0.13106715370668098, 0.22713159502018243, 0.07545610613306053, 0.11357513372786343, 0.11110593419289216, 0.20886646496364847, 0.16434907796792686, 0.12905159936053678, 0.11571366936550476, 0.14292971638496965, 0.17590753821423277, 0.14568574115401134, 0.198590628860984, 0.11272579024080187, 0.10243298864224926, 0.1250146425445564, 0.10283085401169956, 0.07931896994705312, 0.14817839255556464, 0.1049117767252028, 0.1851173533941619, 0.18269634892931208, 0.14991786796599627, 0.12443987143342383, 0.10836698624189012, 0.1621283049462363, 0.10464092993061058, 0.10729790024925023, 0.06339975385344587, 0.13569120870670304, 0.14111256779870018, 0.13985413766931742, 0.1513434000662528, 0.18033487955108285, 0.18904171156464145, 0.14309727848740295, 0.13891497947042808, 0.09259878235752694, 0.16766331653343514, 0.19338388403411955, 0.1829728583106771, 0.12448273046175018, 0.18855710397474468, 0.21330104966182262, 0.10097148464410566, 0.10368770061177202, 0.12459831254091114, 0.12503163772635162, 0.11589726927923039, 0.15787205833476037, 0.1280411652987823, 0.1919839411857538, 0.22216156561626121, 0.12765805382514372, 0.17660257435636595, 0.17974659393075854, 0.13228408293798566, 0.23486805410357192, 0.09588239248842001, 0.2922353125177324, 0.1266911838320084, 0.10616466301144101, 0.12283542979275808, 0.1182593397970777, 0.07093851221725345, 0.14841650321613997, 0.07857824719394557, 0.20366414333693683, 0.13752903352724388, 0.09323924838099629, 0.08467294945148751, 0.18779174191877246, 0.2120718898368068, 0.10570119178737514, 0.08872140955645591, 0.14466466469457373, 0.04580503918987233, 0.12027531716739759, 0.16902880888665095, 0.08683612439199351, 0.1384381644311361, 0.24519192200386897, 0.19096618954790756, 0.10841454306500964, 0.05267980173812248, 0.1562234663288109, 0.1385669270530343, 0.09747136777150445, 0.16759327263571322, 0.16255377820925787, 0.11093260560301133, 0.14721518877195194, 0.10117993908352219, 0.15804385067895055, 0.08844302996294573, 0.09951798099791631, 0.16232161957304925, 0.12539570569060743, 0.26128006575163454, 0.08760184267885052, 0.24103746836772189, 0.10445342632010579, 0.14873394946334884, 0.1787077059270814, 0.1168351509841159, 0.27612907520961016, 0.18399020918877795, 0.16393780941143632, 0.14564798068022355, 0.1886522027780302, 0.10171402565902099, 0.1956640585558489, 0.1732683868613094, 0.17570061259903014, 0.13566763809649274, 0.24525086337234825, 0.1848373410757631, 0.10077701968839392, 0.08889111646567471, 0.1428711015614681, 0.12768027372658253, 0.14090898184804246, 0.06379882150213234, 0.1554439144092612, 0.11288127760053612, 0.12348071235464886, 0.19380751677090302, 0.17656785668805242, 0.21131657646037638, 0.12411343035637401, 0.22729416989022866, 0.07930306572234258, 0.17723158904118463, 0.13108187791658565, 0.20006204053061083, 0.09716918008052744, 0.09948137085302733, 0.22300498676486313, 0.17025099252350628, 0.0733311592193786, 0.09840743121458218, 0.13188301149057224, 0.13381074008066207, 0.05901363510929514, 0.13838668906828389, 0.11786880684667267, 0.09387366590090096, 0.10008601340814494, 0.08789612649707124, 0.15850142925046384, 0.12320553883910179, 0.10310656929505058, 0.17355521209537983, 0.09286225220421329, 0.10088681301567703, 0.12557946145534515, 0.2062419190770015, 0.09295991883846, 0.08138412202242762], [0.010316340667486656, 0.030219435175240505, 0.021655004602507688, 0.09062103301403113, 0.05584276092122309, 0.05742396220739465, 0.032563655186095275, 0.015496869127673563, 0.029431374532578047, 0.03842811725917272, 0.034558830157038756, 0.022463101377070416, 0.011525460649863817, 0.06241305367439054, 0.03005442977155326, 0.0995255731686484, 0.04594050711602904, 0.03005515336553799, 0.027859641195391305, 0.015874071250436828, 0.10765871760668233, 0.03767579844861757, 0.010831952404259937, 0.05176586171728559, 0.011598763503570808, 0.02089590812829556, 0.09425377909792587, 0.025005458119267132, 0.028446017640817445, 0.02353810970816994, 0.04816557346202899, 0.020582616052706726, 0.02821755304466933, 0.0622187668341212, 0.08171190638677217, 0.030633837450295687, 0.034809620410669595, 0.04411260480992496, 0.020378015215101186, 0.03544631261320319, 0.023009808173810598, 0.03085279884544434, 0.08083931883447804, 0.022930288905627094, 0.05329094550688751, 0.08635876016342081, 0.06397594988811761, 0.030478359367407393, 0.09445122006582096, 0.0033739230093488004, 0.07394146436126903, 0.007841896931495285, 0.01830174576753052, 0.014725185828865506, 0.053268881456460804, 0.039642289411858656, 0.030294815114757512, 0.06251632352359593, 0.03285841768956743, 0.06633364173467271, 0.003948092517020996, 0.023900366832094733, 0.07838076169718988, 0.04118459844903555, 0.07293253685929812, 0.04456624257727526, 0.03876039161696099, 0.056536223710281774, 0.09762378263985738, 0.03419049484364223, 0.03444468784437049, 0.019314730961923487, 0.02628899695992004, 0.04782874973898288, 0.011969103543378878, 0.08772838627919555, 0.15563164808554575, 0.04305037255107891, 0.0178203368341201, 0.031174380710581318, 0.04219695838401094, 0.04048508715641219, 0.084988310263725, 0.03442081666435115, 0.013649066131620202, 0.038115840070531704, 0.09338684671092778, 0.03631481835327577, 0.03337420290336013, 0.01887776183139067, 0.05778853483207058, 0.011964633031311678, 0.04013111611129716, 0.0045676777517655864, 0.06026917457347736, 0.044198322866577655, 0.03672684390039649, 0.07161946981796063, 0.0875539964181371, 0.02631161576573504, 0.020054238448210526, 0.032070405286503956, 0.008762799225223716, 0.057923598287743516, 0.05700783629436046, 0.07047673308989033, 0.037069148384034634, 0.09463562149903737, 0.06699567456962541, 0.041590115361032076, 0.0318853730277624, 0.029376503844105173, 0.10061968438094482, 0.05011731052945834, 0.02996149989485275, 0.0425343461392913, 0.04023558081826195, 0.07473398902220652, 0.02350420840230072, 0.08990683461888693, 0.05107681470690295, 0.030608485685661435, 0.012025503056065645, 0.008753908296057489, 0.014213312661013333, 0.011571105515031377, 0.04166306847764645, 0.018632159190019593, 0.01582350130775012, 0.005702550033674925, 0.04185034573310986, 0.020405452414706815, 0.026857116572500672, 0.04496892819588538, 0.04251120597473346, 0.03148877673083916, 0.05336023241397925, 0.044471915607573465, 0.08362516309716739, 0.016534690294065513, 0.1077045600686688, 0.029139565776858944, 0.01912870051455684, 0.0249629274912877, 0.006778121933166403, 0.027937974882661365, 0.017772642713680398, 0.032141495612449944, 0.037169252973399125, 0.03445055823249277, 0.06166985956951976, 0.00949591403696104, 0.05743988498579711, 0.014653770813310985, 0.030872968563926406, 0.017612205228942912, 0.07044481331831776, 0.06825126227340661, 0.04491204257647041, 0.05893474110052921, 0.053317633137339726, 0.02318932441994548, 0.016989246469165664, 0.021198003050812986, 0.03402702197490726, 0.01690887558652321, 0.015887359404587187, 0.054750412309658714, 0.03296134244010318, 0.008782047752902145, 0.03844760234642308, 0.06325355818262324, 0.05387152392358985, 0.048188075379584916, 0.060647020509350114, 0.034043764826492406, 0.03971435195126105, 0.01698539843346225, 0.014858328977425117, 0.03653848310932517, 0.08596930332714692, 0.04644423985155299, 0.04629870098142419, 0.029607653159473557, 0.023907688118924852, 0.0684389217349235, 0.04517510795267299, 0.03611275380535517, 0.03425843104196247, 0.05103283503558487, 0.027601598303590436, 0.07815795412170701, 0.05444327449367847, 0.01025424888212001, 0.04321838736359496, 0.05792897143692244, 0.05229364374827128, 0.06827759367297404, 0.022816326563770417, 0.027786675091192592, 0.028763000045728404, 0.06333762867143378, 0.12295171691221185, 0.04224635944410693, 0.042045849695568904, 0.01980471355636837, 0.030502199006150477, 0.014227070223569172, 0.011257578735239804, 0.0098890964545717, 0.04871205019298941, 0.011629196196736302, 0.08259551483206451, 0.05722806490666699, 0.04704284874605946, 0.050109562507714145, 0.007295484210771974, 0.05570143744989764, 0.044978839578107, 0.019109469612885732, 0.09689403625088744, 0.027506249025464058, 0.02150404248823179, 0.08572803853894584, 0.04741641248983797, 0.03337143098178785, 0.03856843140965793, 0.012167602999397786, 0.03882074677676428, 0.05183620618481655, 0.014461857917922316, 0.05220316852501128, 0.040246431017294526, 0.0418159434775589, 0.034587759073474444, 0.018242683800053783, 0.03891882530297153, 0.03225212756660767, 0.019763003001571633, 0.06572606027475558, 0.005115378562550177, 0.030591676040785387, 0.07287953267223202, 0.06283379203523509, 0.0468896212260006, 0.04075948512763716, 0.03088159046455985, 0.03988727607065812, 0.011528855975484475, 0.03713906240591314, 0.046700069287908264, 0.04775875779159833, 0.04753856628667563, 0.04288948235625867, 0.060564890736714005, 0.02394451163127087, 0.03243022445531096, 0.020686852549260948, 0.0544299455214059, 0.011463608207122888, 0.053923069790471345, 0.06311435354291461, 0.05793192518467549, 0.024975623782665934, 0.010243762335448992, 0.08189348765881732, 0.0648562483547721, 0.019335592733114026, 0.09081599520868622, 0.015200616762740538, 0.025691286064102314, 0.04659917431126814, 0.056804825508152135, 0.007803398020769237, 0.0690722482977435, 0.02933712734375149, 0.014782314501644578, 0.03536511052516289, 0.08431085560005158, 0.05145849754626397, 0.05666241850121878, 0.03670121754112188, 0.030898672848707065, 0.01233077437063912, 0.06432187976315618, 0.029992757299623918, 0.06375455981469713, 0.04949375434080139, 0.025057983621081803, 0.05074750151834451, 0.03930710212443955, 0.022388253928511404, 0.06744127487763762, 0.06802296280511655, 0.01709959269646788, 0.053133172332309186, 0.01566490620461991, 0.04374009862658568, 0.01768901009199908, 0.025663685592007823, 0.03978710839874111, 0.02422917907097144, 0.023656231787754223, 0.018288142200617585, 0.04111042078875471, 0.04486744321184233, 0.03165034970152192, 0.04184448276646435, 0.00095801402608231, 0.012088315652363235, 0.012966838530701352, 0.026597606083669234, 0.09643401601351798, 0.017484904637967702, 0.04193642373138573, 0.03824521496426314, 0.11544513807166368, 0.056362961913691834, 0.02314833560376428, 0.05568572618358303, 0.009457455944357207, 0.07270687943673693, 0.02535302071919432, 0.042755695394589566, 0.03175746387569234, 0.05773169374151621, 0.00854629712193855, 0.043194801910431124, 0.012177392854937352, 0.04431213121279143, 0.02484291479049716, 0.015106003138498636, 0.02400856825261144, 0.0321002507553203, 0.026439858884259593, 0.04384844105516095, 0.03582305274903774, 0.00936409840505803, 0.014989946084824624, 0.059946666879113764, 0.06722993348375894, 0.04695942763646599, 0.08945948284235783, 0.037181257212068886, 0.045323314843699336, 0.07282960097654723, 0.047848346148384735, 0.06491285937954672, 0.015590260991302785, 0.07087497695465572, 0.048301134156645276, 0.03820568817900494, 0.10499216616153717, 0.0857023082789965, 0.1021873154968489, 0.1672349637374282, 0.14541185897542164, 0.15682732220739126, 0.18306531506823376, 0.0833893234084826, 0.13681841228390113, 0.1558662112802267, 0.11819979728898033, 0.2028532134136185, 0.07952392887091264, 0.15214358369121328, 0.1445646380307153, 0.25175457063596696, 0.1848436938598752, 0.11204849884961732, 0.14809856715146452, 0.11611405803705566, 0.20760641695233062, 0.17735693778377026, 0.1325071428436786, 0.08220467017963529, 0.17274708749027923, 0.13667998689925298, 0.2339714951813221, 0.1117146882461384, 0.08440726800472476, 0.15275159559678286, 0.09802679109270684, 0.1480456520221196, 0.11882095262990333, 0.1011658605420962, 0.19853228121064603, 0.05660325077769812, 0.206087329715956, 0.13852466916432604, 0.11966069272602908, 0.10099394945427775, 0.09513712037005462, 0.1163543802977074, 0.15251790813636035, 0.16136730671860278, 0.1709258570917882, 0.13942495366791263, 0.11809939955128357, 0.2137886406853795, 0.18503788422094658, 0.10551441548159346, 0.1808385454933159, 0.12290240119909868, 0.07337152463151142, 0.19995914917672053, 0.10978609134326689, 0.08828635516692884, 0.08970448063337244, 0.15161956805968657, 0.16547985869692639, 0.24496540369000286, 0.07950688916025683, 0.12082059532986023, 0.18515370378736407, 0.23193312721559778, 0.15720703464467078, 0.1951319386716932, 0.2594561339356005, 0.1446091668913141, 0.15374390641227365, 0.09823626227444038, 0.1896387990564108, 0.1735797623405233, 0.08480537828290835, 0.11409467420889996, 0.19407623360166326, 0.27991085196845233, 0.2605981507804245, 0.15185714437393472, 0.20397973421495408, 0.1051941119658295, 0.14466398191871122, 0.1432332696276717, 0.20400835142936558, 0.09521938001853414, 0.14210379507858306, 0.12300299931666814, 0.25659132516011596, 0.09440476904273964, 0.10475847870111465, 0.13680575124453753, 0.12383410823531449, 0.1592443636036478, 0.19479889248032123, 0.12481212528655306, 0.13715953304199502, 0.2460934384725988, 0.20864074816927314, 0.2522407367359847, 0.235003971029073, 0.10167825414100662, 0.11482578614959493, 0.10591617712634616, 0.2159216918516904, 0.241335203172639, 0.1971106676501222, 0.14723498927196488, 0.1100398538983427, 0.14814271009527147, 0.18013562774285674, 0.12839628296205774, 0.1565951932570897, 0.09120526650804095, 0.2691311272792518, 0.27512993663549423, 0.16206022031838074, 0.15786668518558145, 0.1386977973743342, 0.2010123457876034, 0.11820686253486201, 0.147113811399322, 0.1522394097992219, 0.08180447446648031, 0.10035298619186506, 0.08774322181125171, 0.08299179200548679, 0.09782521636225283, 0.12910494493553415, 0.11430316575570032, 0.10995971679221839, 0.13667556369910017, 0.18505327636376023, 0.08122801125864498, 0.1721305854152888, 0.13455986394546926, 0.13502265239367262, 0.15806808922206983, 0.2952082670526579, 0.16183704166905954, 0.1624861833988689, 0.1362247089855373, 0.29508925625123084, 0.10942926674033515, 0.09106952769798227, 0.1361896054004319, 0.07283351951627992, 0.1560793857788667, 0.09418928646482527, 0.08119940146571025, 0.15901696955552325, 0.10129310918273404, 0.12334185652434826, 0.09978465692256577, 0.09606185121810995, 0.14712966367369518, 0.13595807016827166, 0.08993716619443148, 0.18871562671847641, 0.19126291503198445, 0.13192492799134925, 0.12149096990469843, 0.16531366214621812, 0.16671826568199322, 0.07377823640126735, 0.13220177876064554, 0.11486134244478308, 0.23722005367744714, 0.1640574584598653, 0.13268671289552003, 0.20329528109868988, 0.13617902237456292, 0.1218280904868152, 0.14379445201484486, 0.13625105522805825, 0.16064823983469978, 0.1478071851306595, 0.14047555276192725], [0.020923304509778973, 0.07691087885177694, 0.028569316200446337, 0.0344345723715378, 0.06956015102332458, 0.02736901478783693, 0.050788709268090315, 0.05530418064154219, 0.03237129050830845, 0.10555922635830939, 0.014684632096759742, 0.020749484247062355, 0.042208461672998965, 0.05129842371388804, 0.06713306836900301, 0.07306057217647322, 0.038694470349582843, 0.0283181715712999, 0.016979622669168748, 0.02280687531310832, 0.08832680221530609, 0.04331151947553735, 0.008552644339943072, 0.014568067599611823, 0.04214475200569723, 0.020123263748246245, 0.021927435882389545, 0.015489627621718682, 0.008006094321899582, 0.05944055927102454, 0.0690747938642744, 0.0711397900886368, 0.07702266855631024, 0.05145339157024864, 0.02995725295477314, 0.08507142338203266, 0.03516850818414241, 0.05161555083759595, 0.05787358866655268, 0.005771219566668151, 0.05320229596691206, 0.01996995273657376, 0.03001884379045805, 0.033051168284146115, 0.012517379982455168, 0.07834799587726593, 0.035050276637775823, 0.018757673060463276, 0.03212308663933072, 0.03306987040559761, 0.06905821428517811, 0.06772430773708038, 0.008998976591101382, 0.02803073777613463, 0.055866394613985904, 0.0047597135653631995, 0.09072401342564262, 0.0214875519668567, 0.026196755425189622, 0.006729186106895213, 0.0100493317040673, 0.11143142532091588, 0.05779231236374471, 0.06759790514479391, 0.04184457182418555, 0.03843510457954835, 0.03821268292085733, 0.005261976848487393, 0.061623675719602033, 0.025525074670440517, 0.05591775494394824, 0.050405694273649715, 0.07673055180930533, 0.012052567326463759, 0.005186144198887632, 0.027288347046123818, 0.04709501430625096, 0.022886622791702393, 0.07615970665938221, 0.09079272145754658, 0.04700325516751036, 0.10756104355095886, 0.06904140464030206, 0.027082759152108338, 0.026522719672357198, 0.02919774273323128, 0.07897586023318581, 0.04803533396625426, 0.04636816600395832, 0.009346973347419407, 0.059217677480774, 0.020696732390206307, 0.04782013340445701, 0.0073920937484217575, 0.08116407523630187, 0.026463149333721958, 0.016319686401402578, 0.03941103248507716, 0.07179688022006303, 0.06846706397482194, 0.03781143335800152, 0.038129462191136554, 0.04091331749805249, 0.06487495789770037, 0.03429346783377696, 0.014406990940187825, 0.0712912624294404, 0.0031267284612113144, 0.02709283937292639, 0.008394916621909942, 0.017984882106247824, 0.01675755724136252, 0.10710320522775874, 0.07151856741984375, 0.02492807438102318, 0.01257025058293948, 0.04730037398985587, 0.06801150404498912, 0.07550551832537167, 0.023746170809317846, 0.04265779127308633, 0.07551600487204269, 0.023669018992222846, 0.04090284579433501, 0.03599172807298601, 0.01630492137337569, 0.024725651746848598, 0.05705889605451375, 0.03586785991501529, 0.048041115296655335, 0.016376451421820093, 0.02961783542559715, 0.043045938218710944, 0.03813285751675721, 0.052717714352183975, 0.03174519988533575, 0.07984717871295288, 0.013670996595465112, 0.05326442114892416, 0.04480635703657754, 0.027826123950944748, 0.027381226827856153, 0.033928513003047556, 0.03599535717512481, 0.14574925415217876, 0.04331913391069975, 0.020457677346712444, 0.04128682558075525, 0.025183256293530576, 0.010854630581889069, 0.06836236178060062, 0.06532812069053762, 0.038123851554701105, 0.06099928461480886, 0.015164383257797454, 0.031987674374249764, 0.021964018196740653, 0.00948920780501794, 0.01705996572127333, 0.04183376986475196, 0.027630564327409957, 0.04095219119335525, 0.07582807054859586, 0.01363758881780086, 0.00797654200141551, 0.010260743601975264, 0.022881589175085537, 0.0285065138086793, 0.07650516155990772, 0.028595762632903643, 0.06073656062653754, 0.040296221704920754, 0.016021669580368325, 0.040966867163660936, 0.05478649924043566, 0.03105477062490536, 0.03589749387174379, 0.032409626146545634, 0.02464643675921252, 0.045332380177569576, 0.04703415819676593, 0.009172025020234287, 0.0894604402128607, 0.025579351640772074, 0.03161215136060491, 0.06631216398091055, 0.02464996938215336, 0.0754656724166125, 0.07108330522896722, 0.058120163521380164, 0.04737330113130156, 0.011227363120269729, 0.009733481074363226, 0.023136001109378412, 0.07229336217278615, 0.03141786452033557, 0.015900669823167846, 0.06201040516316425, 0.0353115497273393, 0.033919251000043005, 0.013363084162847372, 0.03325535908516031, 0.05377728601160925, 0.04160454271186609, 0.059201101612416096, 0.008285130716103595, 0.031452986659132876, 0.08871354279108346, 0.046310115212691016, 0.08362402018974535, 0.006931640282346052, 0.038760365641792305, 0.011492592784634326, 0.053245184681145474, 0.03338346861710306, 0.04446273153007496, 0.05912009619351011, 0.017751983177731745, 0.037377020926214755, 0.05212843054323457, 0.013262454504001653, 0.026935763817164116, 0.022536720571224578, 0.04707946260168683, 0.0073424250513198785, 0.08041005319682881, 0.03541948397469241, 0.03738999366760254, 0.04426502709975466, 0.02861223645595601, 0.009223587585438509, 0.026297691219951957, 0.08424140542047098, 0.015273112530849176, 0.04721236640762072, 0.007644817760592559, 0.044611944031203166, 0.02015424284763867, 0.03623787619289942, 0.054507370077772066, 0.07000394049100578, 0.032150646293303, 0.08141050537233241, 0.04039201812702231, 0.06466706006904133, 0.011176937896379968, 0.027107231471745763, 0.017873660144687165, 0.06360495026456192, 0.04159859068749938, 0.03031252090295311, 0.04372349307232071, 0.020715182181447744, 0.024105793308990542, 0.09374623172334395, 0.03174446515913587, 0.010461646688781912, 0.038081679012975655, 0.021866628012503497, 0.021666663742507808, 0.004541273065115092, 0.04894281730230432, 0.08200290249078535, 0.026246644447383005, 0.06308054129476659, 0.047618280368624255, 0.03397888256586157, 0.0568911484151613, 0.023269424418685958, 0.08042252127779648, 0.042409286834299564, 0.053344977568485774, 0.023741773584333714, 0.05108805082272738, 0.05372937295760494, 0.03819062629190739, 0.01581668282597093, 0.02248029693873832, 0.03564616556104738, 0.044736892014043406, 0.02632592622830998, 0.03227321940357797, 0.05152179903234355, 0.023289501368708443, 0.025511654785077553, 0.0866428468725644, 0.057478016533423215, 0.041852219655993395, 0.09980541479308158, 0.11603511578869075, 0.07800990308169276, 0.012917322437715484, 0.021656839562638197, 0.01989351152587915, 0.009738983171700966, 0.014646734325651778, 0.05144103481143247, 0.09352267457870767, 0.0061186049788375385, 0.07956257250043564, 0.035244619139120914, 0.024351045285584405, 0.04768363018229138, 0.053499693094636314, 0.02634858770761639, 0.04466179037990514, 0.01655915333685698, 0.03705328868818469, 0.035668708296725526, 0.030295664873847272, 0.06163280784676317, 0.030448085308307782, 0.03288421103206929, 0.02079252324620029, 0.013661492466781056, 0.007369938321062364, 0.04397243908897508, 0.04386490189062897, 0.07485682188416831, 0.04447169296327047, 0.05755380836490076, 0.014874872376822168, 0.03757698148547206, 0.05493881762959063, 0.024362546719203237, 0.007714245211900561, 0.029361475353653077, 0.0008177596532732423, 0.07505307541578077, 0.03519724043144379, 0.012329037745075766, 0.0504502936382778, 0.013639720637002029, 0.03456020313024055, 0.03870703490974847, 0.0760125981469173, 0.005349378188839182, 0.04862763831624761, 0.11800430816947483, 0.06015609724272508, 0.035340133545105346, 0.07948506259708665, 0.04394847514049616, 0.02864172940462595, 0.019404207996558398, 0.016398474654124584, 0.06364469227264635, 0.09872766793705523, 0.09630947621189989, 0.06301168483332731, 0.04800328431883827, 0.026871751724684145, 0.07687190125579946, 0.1664351808722131, 0.10834438042365946, 0.2627908409340307, 0.10057140767457895, 0.08579334753449075, 0.1624350345809944, 0.11967567668762058, 0.18599630857352167, 0.21908471040660515, 0.05314683527103625, 0.1554374280385673, 0.18663059250684455, 0.19170869345543906, 0.13418217014987022, 0.17763819691026583, 0.09679247334133834, 0.0974765776481945, 0.1327129700803198, 0.11310990361380391, 0.17317440127953887, 0.11036199051886797, 0.0855830822547432, 0.13450645899865776, 0.10826485930010676, 0.1210791670018807, 0.1255078293615952, 0.08275502463220619, 0.16132592456415296, 0.10680245730327442, 0.15705202968092635, 0.3222807456040755, 0.1643219598918222, 0.1835141659830697, 0.06408091183402576, 0.24627140548545867, 0.11911686917301267, 0.16517548909178004, 0.1969035787624307, 0.20691705081844702, 0.11012402828782797, 0.15066176711115986, 0.1217812164395582, 0.12217720417538658, 0.12799681455362588, 0.18829101434675977, 0.1317718526115641, 0.10686041903682053, 0.1401163384434767, 0.16340494737960398, 0.15982568787876517, 0.12842178315622732, 0.10544259042944759, 0.07092392159393057, 0.13939652941189706, 0.11213212404982187, 0.18445117195369676, 0.08961350074969232, 0.17981718701776117, 0.07903688703663647, 0.10972578442306258, 0.2375824295450002, 0.10539638431509957, 0.09537380610709079, 0.1599469844950363, 0.1284177607158199, 0.10194662216235884, 0.1118272275198251, 0.1743442635051906, 0.12589107442181557, 0.20399126718984917, 0.23625379224540666, 0.2642705349717289, 0.19057990168221295, 0.11861462073284201, 0.1039769007184077, 0.11314587551169097, 0.14952405472286046, 0.16528882988495752, 0.15034028358059004, 0.13774504303000867, 0.19985933031421155, 0.1691111724358052, 0.12130182614782825, 0.11354170739650726, 0.1401053398149088, 0.151680379640311, 0.18174619210185483, 0.15967659041052684, 0.12724340107524768, 0.20587160222930834, 0.15322317107347772, 0.12840033508837223, 0.21867716743145138, 0.16202839702600613, 0.1368854579050094, 0.12018598485155962, 0.2236647708923556, 0.2134964126162231, 0.1364411786198616, 0.15064484614413232, 0.12151791728683747, 0.15617656259564683, 0.14927901240298524, 0.1443922519683838, 0.11348016851115972, 0.2466832974459976, 0.1450845124782063, 0.0888681247306522, 0.16300674062222242, 0.14713462122017518, 0.10780854980112053, 0.20459599880268797, 0.23754005291266367, 0.15967222658218816, 0.08248022219049744, 0.08162005819031037, 0.13286289875395596, 0.18670305580599234, 0.1215915234934073, 0.0963252542715054, 0.21887425216846168, 0.16092939506052062, 0.24569416302256286, 0.11645507489447482, 0.16641140246065333, 0.21445373859023675, 0.16008184757083654, 0.14971756230806932, 0.08121915743686259, 0.11122900454211049, 0.17308377020526677, 0.1643521653022617, 0.1002023895853199, 0.13265953544760123, 0.17834561207564548, 0.11487901298096403, 0.17568958428455517, 0.11289526708424091, 0.09137660614214838, 0.22380398295354098, 0.10587514378130436, 0.09515924379229546, 0.1543744796072133, 0.15349859691923484, 0.13270820549223572, 0.11052613132051192, 0.15697257535066456, 0.11672149106743746, 0.07997375942068174, 0.2418771936208941, 0.15442386211361736, 0.18010758940363303, 0.1470174509449862, 0.07789790557581, 0.131907012546435, 0.06898707943037152, 0.10078940613311715, 0.1759774930542335, 0.15504331793636084, 0.0818026858905796, 0.1718878437532112, 0.1594165715505369, 0.06471762259025127, 0.09122402800130658, 0.1076511996507179, 0.13116026355419308, 0.16308119287714362, 0.17664480255916715, 0.10948041555820964, 0.15675304806791246, 0.16625149932224303, 0.18510864058043808, 0.12320938316406682, 0.13413351494818926, 0.12212847475893795], [0.008860901871230453, 0.05649334612826351, 0.024024247977649793, 0.04479263843677472, 0.09999391288147308, 0.0349037247360684, 0.030374115449376404, 0.004327482583903475, 0.06934158853255212, 0.04122717917198315, 0.022519985141116194, 0.026911547538475133, 0.025473235655226745, 0.034988437182619236, 0.019677392556332052, 0.04873311976552941, 0.04637694561097305, 0.031691383046563715, 0.025814992804953363, 0.022609970546909608, 0.03167432849295437, 0.03502291736367624, 0.008206433376471978, 0.046421036604442634, 0.02003865705773933, 0.05146820483787451, 0.04736289251013659, 0.02357819495955482, 0.03219664089556318, 0.020164497473160736, 0.04710255452664569, 0.03948559606214985, 0.09644620207836851, 0.03833774222584907, 0.05149079952389002, 0.005839644190928084, 0.020900596646242775, 0.045326457839109935, 0.02351284885662608, 0.032750446334830485, 0.049713660118868575, 0.028877967997686937, 0.021507675301108975, 0.030144912416290026, 0.06796080793719739, 0.02491088253009366, 0.01053693757057772, 0.02427783612802159, 0.0421295973501401, 0.06557957516633905, 0.024288617678394075, 0.06280137502471916, 0.050697729384410195, 0.03832911475910805, 0.021935718250460923, 0.023048075163387693, 0.012651085307879839, 0.049124428260256536, 0.03934948988899123, 0.058551009933580644, 0.04691492475103587, 0.05844310166139621, 0.013546632126235636, 0.015591596857120749, 0.07401861061225645, 0.06842939998023212, 0.05233787203906104, 0.042449934262549505, 0.09302018865128048, 0.030319678917294368, 0.05053299115388654, 0.007648722385056317, 0.07332517750910483, 0.045484294096240774, 0.07843502753530629, 0.06051239121006802, 0.028509005569503643, 0.6220699043478817, 0.8260697952937335, 3.0698961205780506, 5.2857771422713995, 2.4056544760242105, 3.714460521005094, 3.9727447740733624, 3.2250061724334955, 1.5532798203639686, 0.614823930663988, 0.1687765380484052, 0.14988107228418812, 0.05282721082039643, 0.07024656340945512, 0.1685671039740555, 0.2424834095290862, 0.0796541386807803, 0.15191344369668514, 0.07976264809258282, 0.18762391264317557, 0.24542779137846082, 0.097329201962566, 0.07824192813131958, 0.03341393377922941, 0.11720571274054237, 0.11783713940531015, 0.01872058979643043, 0.05447161711344961, 0.050433432043064386, 0.025839060654107016, 0.019877238082699478, 0.03669197038107086, 0.04915301578876097, 0.011173196544405073, 0.01155119276518235, 0.011248693372181151, 0.016356749256374314, 0.006828667292211321, 0.02096345469908556, 0.013310887989064213, 0.03176239173626527, 0.0656843367323745, 0.048088304756674916, 0.028463107446441427, 0.05500344756001141, 0.12029165183776058, 0.06425683051929809, 0.04602547560352832, 0.06602806242881343, 0.067055209656246, 0.044571548933163285, 0.027337881692801602, 0.05587013132753782, 0.014586451525246957, 0.0700290547683835, 0.05596913382760249, 0.06498817994724959, 0.07490396310458891, 0.07623226643772796, 0.028362360899336636, 0.05641948759148363, 0.03757774589757901, 0.02512098268198315, 0.01985424263693858, 0.06810749342548661, 0.06352874654112384, 0.00869938827236183, 0.045671315310755745, 0.0223043522782973, 0.05150958328158595, 0.07136011146940291, 0.018688258132897317, 0.05290193766995799, 0.05857056923559867, 0.028377645430737175, 0.010044640403066296, 0.03701676017954014, 0.04186448364634998, 0.013700304934900487, 0.056493513111490756, 0.02396770189079689, 0.03188405571563635, 0.08834404230583459, 0.04342829641245771, 0.018865041420212947, 0.04565871364320628, 0.01538679656732711, 0.01817053220293019, 0.012190387860755436, 0.08603356589446776, 0.018087719654431567, 0.03183828004694078, 0.008890856806829106, 0.0034663936821743846, 0.009918897394527448, 0.05961896415101364, 0.009884555438475218, 0.06200194839038886, 0.02601108677481534, 0.010330142758903094, 0.06507549362140708, 0.04577037718263455, 0.023298524029087275, 0.04678429933846928, 0.061077043137629516, 0.06120363497757353, 0.008002451304491842, 0.02198378901084652, 0.004368559993963572, 0.06759329640772194, 0.060239599988562986, 0.062476017483277246, 0.03531900089001283, 0.05535790842259303, 0.04141398145293351, 0.035503387480275705, 0.04523843170318287, 0.06782417112844996, 0.02012360328080831, 0.019504184565448668, 0.004726243168988731, 0.013160544640413718, 0.01397539959725691, 0.08452731039142236, 0.05773276985564735, 0.05775363904831465, 0.039483198925154284, 0.02012014672800433, 0.04683919600211084, 0.016560249860049225, 0.07319369120523334, 0.06561463422258385, 0.04793186373717617, 0.043589876804617234, 0.05828766254126094, 0.06155369490443263, 0.05726175098970998, 0.013012642029934796, 0.02357030778512126, 0.036064080049982294, 0.06147639280243311, 0.018384105605946388, 0.017915400385390967, 0.031189620713121258, 0.03596758600906469, 0.026213591045234352, 0.0315022689756006, 0.017844864814833272, 0.016028875834308565, 0.024899048985389527, 0.06061457381292712, 0.021806517761433497, 0.029450124893628526, 0.028925680671818554, 0.07337503499002196, 0.04558048014587257, 0.015138004546315642, 0.058066791971214116, 0.03154923579131719, 0.0727646482118871, 0.056722680892562494, 0.046790429478278384, 0.011957816404901678, 0.028152652230346575, 0.07335563524975441, 0.03738322157005314, 0.05469647301652003, 0.056877006791182794, 0.04217170309857465, 0.12067250718246214, 0.014910269110259833, 0.011438942929089535, 0.008788040595391067, 0.06212891501490958, 0.11064128295402043, 0.07296472380403429, 0.4036195669323206, 0.8930984360631555, 2.1824283292517066, 5.010184580460191, 2.478241268545389, 3.740194165147841, 3.461352065205574, 2.769542424939573, 1.0586341191083193, 0.33194620977155864, 0.15914907184196636, 0.030589803973271046, 0.0962904623884242, 0.10584394389297813, 0.1660156447906047, 0.21414687536889687, 0.06776166745112278, 0.08242487281677313, 0.04598954081302509, 0.10739858000306413, 0.24049158906564116, 0.016584134027652908, 0.024640143346914556, 0.029490147062460892, 0.05112005223054439, 0.08760575379710644, 0.011641302480711602, 0.013595391228591325, 0.03486731868179049, 0.028246693473192863, 0.01877740305644693, 0.08084218352450989, 0.056861250996007584, 0.029299064444785472, 0.05123276590893511, 0.03241997539589647, 0.02732666784140747, 0.0062009870816837065, 0.015251996574079385, 0.0414746260503307, 0.01611214851436671, 0.02173269633203745, 0.033772888345993124, 0.017185299620905425, 0.022300969940260984, 0.0916059965675231, 0.05689369027095381, 0.03234679592424072, 0.06384787746355869, 0.031709090690128505, 0.10660526124411263, 0.03866988670779392, 0.01915023949550232, 0.047292173258028924, 0.029311803409655113, 0.026690250233514234, 0.026832421608560253, 0.04484275195864029, 0.03828322034678422, 0.0165242686853162, 0.05264298008114565, 0.09805853274883702, 0.03415120183490217, 0.042847766235354356, 0.05217429898038972, 0.029352922101679724, 0.000417836708379582, 0.10327230571419932, 0.020303676137700677, 0.02873066838219529, 0.010934077490674099, 0.03239227844460402, 0.06642569773248397, 0.041539504600223154, 0.02471240997692803, 0.01287695238715969, 0.042037645253003575, 0.10672031639842317, 0.034155962712247856, 0.05126872296386864, 0.05180615662538912, 0.017235988307220396, 0.053738308415631764, 0.029962377484480385, 0.038695275579812005, 0.11402957301470451, 0.016033146894187666, 0.08341685708728619, 0.02855083115719026, 0.06310492084594443, 0.014275481444201432, 0.02730091531702783, 0.06850676887552254, 0.021582945773843676, 0.056567839201306924, 0.042616906357579865, 0.029259476432343945, 0.04690840498369653, 0.03528995322994888, 0.12262998105143197, 0.14572471874998882, 0.2220826901611872, 0.12932705489220098, 0.18394517566775903, 0.12795083108358085, 0.12040771631291136, 0.08271486702142283, 0.1802947442047298, 0.19436271744780242, 0.19302089960547164, 0.10370009447797202, 0.13948821433587, 0.129901239706669, 0.1667016267310828, 0.26413136743940413, 0.15436692454386503, 0.1880887197330594, 0.09588062617694959, 0.08908162577426992, 0.11844308071886189, 0.10165888408664614, 0.16202538390643895, 0.1286552776582539, 0.16444376116851345, 0.13988741557113826, 0.1762357901316136, 0.13287226465763524, 0.08047689101658762, 0.14466999331489205, 0.14169928006595, 0.14352926780702546, 0.17703618155792356, 0.1449880629661493, 0.1423812989378348, 0.16770502523286268, 0.12429988011717796, 0.08236854380811565, 0.07889989399700426, 0.08177164927474223, 0.08564947478589602, 0.17465177981648594, 0.12009530182695016, 0.12442994891898707, 0.11783072724938393, 0.10947827075142413, 0.11111570085631683, 0.14665246271761134, 0.12725701206363738, 0.13206523843109608, 0.16142629261594266, 0.1861766801448539, 0.09716978122014552, 0.10149953755899332, 0.09274132666178048, 0.12522924196673557, 0.0793876928219106, 0.11643937104963697, 0.10160133795579895, 0.15441660390933976, 0.152372402662877, 0.15749866899568588, 0.16091989557025954, 0.14997609687270597, 0.30796976352576166, 0.1786374393850565, 0.1548876301967539, 0.09691774044767953, 0.267513245344162, 0.15766483586048707, 0.2004301457782276, 0.1426378742326051, 0.17659113043919206, 0.1847531518433243, 0.14108769100857899, 0.22909641615115106, 0.1516542411991395, 1.131220911629498, 1.9461792125366628, 5.226082820445299, 8.512226287275553, 5.392083562910557, 6.4050427079200745, 6.457404373213649, 5.626581329852343, 2.5421552639454603, 1.0056299320422113, 0.47554273100104183, 0.2180270609096624, 0.376192846451886, 0.28725977637805045, 0.5172157776542008, 0.3764140064595267, 0.19586004491429776, 0.2619233593577519, 0.23136986681493, 0.19974395603640005, 0.44748925196472555, 0.1887024164898321, 0.23963158833794296, 0.23729312553768978, 0.2771785610821098, 0.22315059613902122, 0.1897763487068005, 0.19542008492862806, 0.0905413189320825, 0.10493609690456651, 0.08473896348732524, 0.21987477113725618, 0.12873673578724265, 0.12892363825812936, 0.1720725791528821, 0.2076433610636741, 0.14205629762727767, 0.12162749539129436, 0.10710260408814065, 0.11669887782773003, 0.12687207490671426, 0.12813093548174948, 0.1804234177689068, 0.17058555269613862, 0.18157855578465387, 0.25484000507276505, 0.16207967943046242, 0.15357998083345592, 0.19878475985024124, 0.16602134448476136, 0.27160648663993925, 0.14560754847479984, 0.11092989676399156, 0.16287432663375512, 0.23348323622485623, 0.12111496820580214, 0.15176989749306813, 0.10974611184792593, 0.2481830443139188, 0.0852111104177311, 0.12294156433199532, 0.17932751798070967, 0.1434052994591184, 0.10089726987644099, 0.1922339855809696, 0.17125081387348473, 0.07909108608146198, 0.16860250441823155, 0.08446986073977314, 0.10999568126862869, 0.20580964774126187, 0.15056856820592657, 0.1762096962193027, 0.1764212825219147, 0.12567363999551162, 0.10500655640498735, 0.16505456354934722, 0.1619960245443508, 0.09042770354426466, 0.15148601116379723, 0.1319055727799423, 0.08769713444053195, 0.15543727960903198, 0.14376347477082163, 0.13915098243160173, 0.22776936704758555, 0.15080752491485327, 0.15819294814718887, 0.09083658980671316, 0.22839704586658627, 0.096576894284226, 0.15062376915011555, 0.11828593836980872, 0.23614861507667229, 0.09251733165001497, 0.11309092689771205, 0.06758770061424002, 0.1809588773176074, 0.12756706651998684], [0.07421097529004328, 0.06630850519286469, 0.06439988690544851, 0.04880550884990953, 0.03571571593056433, 0.012525093679869315, 0.09467422059969977, 0.016758802194090094, 0.010899432181759039, 0.012245341113157338, 0.04068340014782734, 0.061859010747866705, 0.011881382615683833, 0.05133061065862421, 0.05389695732446853, 0.008800749874353642, 0.047148656740318984, 0.023786747733538505, 0.06666853587375954, 0.0976304397045169, 0.05313686080626212, 0.037319159382604994, 0.06050882519048173, 0.03793326060986146, 0.03677785913168918, 0.0349016652762657, 0.07499410436139442, 0.03771714720642194, 0.010332035235478543, 0.018589094215712976, 0.06569220349774696, 0.03777335747145116, 0.08340804037288763, 0.03172885779349599, 0.033669562835711986, 0.010213627429038752, 0.03956708016630728, 0.05687508833943866, 0.021783231022709515, 0.037933538915240206, 0.01598784620000515, 0.04140483448281884, 0.02879235198633978, 0.05816865916131064, 0.0536607948015444, 0.03406839299714193, 0.04934775904985145, 0.0638066214742139, 0.026675193912524264, 0.024848621906130575, 0.09408701109350659, 0.08092757503618486, 0.03467169597570319, 0.05505102293682285, 0.021369275891629513, 0.015118005521799205, 0.015089338212419534, 0.0306652618382941, 0.09400660681421869, 0.05730322591261938, 0.06816671681008302, 0.0581967976904707, 0.024986999051179737, 0.05098144873045385, 0.007239546221171622, 0.05279402568703517, 0.04580823042488191, 0.030806622417003382, 0.14518206036882475, 0.08979307080153376, 0.11592219801968895, 0.13408376136794686, 0.20227141416398808, 1.268824115395546, 5.750840362161398, 13.580148294568062, 22.761842608451843, 31.256740875542164, 40.63329063355923, 51.974298879504204, 57.02474847435951, 61.752629578113556, 56.76248274743557, 53.45064505934715, 51.74381084740162, 37.657723501324654, 27.77141399681568, 27.42075551301241, 23.356826081871986, 20.88192008435726, 26.729542203247547, 30.775794982910156, 21.28911193460226, 19.74850170314312, 14.280597008764744, 12.091437578201294, 8.4152602404356, 4.043888356536627, 3.549293358810246, 1.7690833029337227, 0.36467952362727374, 0.21495684050023556, 0.11233954690396786, 0.0824051836389117, 0.040052685944829136, 0.07940004215925, 0.028900276956846938, 0.02534997976908926, 0.06204475917911623, 0.07497532802517526, 0.044245293393032625, 0.0490222976077348, 0.023992356036615092, 0.04936220866511576, 0.032503648835700005, 0.009250195435015485, 0.020207395464240108, 0.12589990597916767, 0.06719737546518445, 0.03066400946408976, 0.04372673254692927, 0.019147821949445643, 0.025207229518855456, 0.031227232757373713, 0.061293253020267, 0.028290623049542774, 0.025943074506358244, 0.024569093839090783, 0.008966501136455918, 0.0420628708525328, 0.05384818337915931, 0.06368880553054623, 0.06253624276723713, 0.019182598989573307, 0.0172203623878886, 0.020828140768571757, 0.040384952881140634, 0.009277443386963569, 0.05046273574407678, 0.041068036734941415, 0.06399995094398037, 0.019792863313341513, 0.03258422380895354, 0.04442015822860412, 0.013372315552260261, 0.04919167797197588, 0.020534715986286756, 0.0636428888537921, 0.10539584254729562, 0.02469904018653324, 0.04981934936949983, 0.0034055025525958627, 0.01927522087498801, 0.024407801029155962, 0.006895630349390558, 0.043061341493739747, 0.046133146388456225, 0.03232755945646204, 0.023087750378181227, 0.015099653137440328, 0.01990214455872774, 0.03636922519945074, 0.003476908059383277, 0.08124234213028103, 0.018733909491857048, 0.06498187911347486, 0.06053712328139227, 0.013531848544516833, 0.04393185845401604, 0.052929063167539425, 0.07583211525343359, 0.12571475497679785, 0.0576682660903316, 0.03243848084821366, 0.03513407995342277, 0.039782718595233746, 0.08037609251914546, 0.058287343417759985, 0.03766108537092805, 0.04195945628453046, 0.02848459262168035, 0.014285917895904277, 0.03188803362718318, 0.024000770135899074, 0.059634575227391906, 0.08246292272815481, 0.012593726569321007, 0.09284098967327736, 0.04486549507419113, 0.033990712399827316, 0.0684771423402708, 0.03290754044428468, 0.01035760500599281, 0.07733961756457575, 0.026323037418478634, 0.0697851405129768, 0.0217295199399814, 0.02807707933243364, 0.014644030125054996, 0.06256625521928072, 0.02466477522830246, 0.10597606102237478, 0.030132370120554697, 0.06215766210516449, 0.040480051684426144, 0.07155696614063345, 0.0816550430317875, 0.05612097724224441, 0.05195544334128499, 0.06155565417429898, 0.0510075315105496, 0.06818211637437344, 0.0287779840073199, 0.01661616697674617, 0.03338722759508528, 0.06257383996853605, 0.06761072945664637, 0.04617127051460557, 0.03942954535887111, 0.024638540307933, 0.024279537501570303, 0.02968057287944248, 0.012807652492483612, 0.03782174549996853, 0.041629419501987286, 0.02643123698362615, 0.023278146509255748, 0.05404806972364895, 0.057160585129167885, 0.04316108985221945, 0.032912126916926354, 0.03847535866952967, 0.03720274609804619, 0.02849349839380011, 0.09802397835301235, 0.07749635915388353, 0.05392321079852991, 0.06261366361286491, 0.04677496683143545, 0.022376377710315865, 0.032066056301118806, 0.04483301869186107, 0.048118669728864916, 0.04708719949121587, 0.1041677662578877, 0.05214822733250912, 0.06230812141438946, 0.09531755873467773, 0.18953197431983426, 1.255107563920319, 6.103875143453479, 14.912389107048512, 25.24113357067108, 34.44193325936794, 43.719139248132706, 56.6914227604866, 63.66024121642113, 66.31642028689384, 62.30907551944256, 58.83317783474922, 55.36399058997631, 40.66441096365452, 31.118637286126614, 29.758956246078014, 25.149699077010155, 22.833808846771717, 29.816010184586048, 35.78942075371742, 25.96898451447487, 23.060386888682842, 17.169627584517002, 13.807357102632523, 8.749688845127821, 4.926402876153588, 4.292352749034762, 1.8561614491045475, 0.5247512483038008, 0.15782490227138624, 0.039018273091642186, 0.07729920762358233, 0.02836602710885927, 0.10382638574810699, 0.04485187295358628, 0.06127416498202365, 0.07324695514398627, 0.03987952433817554, 0.023364799671981018, 0.026837969162443187, 0.05035423004301265, 0.05124853283632547, 0.011910213197552366, 0.05422339840151835, 0.024519076796423178, 0.11478602929855697, 0.05683642615622375, 0.0440273654385237, 0.055071446840884164, 0.029242310556583107, 0.033186936780111864, 0.03325598248920869, 0.03400025270821061, 0.031857828216743656, 0.011836903850053204, 0.01580617401486961, 0.01161378178949235, 0.028070014086551964, 0.017631912960496265, 0.018312618230993394, 0.033033794607035816, 0.0055846714712970424, 0.0659668723528739, 0.014457986690104008, 0.02171847863792209, 0.05535228665394243, 0.037308042010408826, 0.011880250840476947, 0.023945216671563685, 0.06165872735437006, 0.020504536551015917, 0.03806130334851332, 0.05702074595319573, 0.02332238593226066, 0.030113400825939607, 0.05791516749013681, 0.036764077449333854, 0.04516670684097335, 0.041364283533766866, 0.014130002873571357, 0.04041685038828291, 0.060618618517764844, 0.026120802176592406, 0.06222891199286096, 0.03621083975303918, 0.05073760497907642, 0.01791113489161944, 0.06251791171962395, 0.024438212385575753, 0.06288784265052527, 0.040028733128565364, 0.06905160917085595, 0.09274214302422479, 0.02047976551693864, 0.041617530296207406, 0.008846798282320378, 0.037033258122392, 0.079297395714093, 0.022284214101091493, 0.07180517000961117, 0.013033505656494526, 0.05163440881005954, 0.07459353015292436, 0.0460176236811094, 0.3108992875786498, 0.2462869163719006, 0.16035866865422577, 0.1320824711001478, 0.07746101808152162, 0.13119607960106805, 0.21444651007186621, 0.10421340834000148, 0.12135422919527628, 0.1388339963159524, 0.11649352556560189, 0.1875916589051485, 0.1858660764992237, 0.12570583436172456, 0.16706011374481022, 0.194058540801052, 0.12176803589682095, 0.12145029279054143, 0.13495740276994184, 0.2532579837134108, 0.14721952291438356, 0.13546072732424363, 0.17781978560378775, 0.09775089027243666, 0.1561189570929855, 0.15215262304991484, 0.12470630987081677, 0.1492051687091589, 0.08213061126298271, 0.12507321283919737, 0.1782254732097499, 0.09529869334073737, 0.19945759093388915, 0.11484398361062631, 0.12933128513395786, 0.1122177678917069, 0.1292852422920987, 0.26909022009931505, 0.21693953254725784, 0.16391889948863536, 0.2148685249267146, 0.13867217843653634, 0.1900460451724939, 0.09018352211569436, 0.21602443477604538, 0.1069755780918058, 0.09722015078295954, 0.1403437918634154, 0.1566518933395855, 0.16779844678239897, 0.21260285197058693, 0.1787459710612893, 0.0959610972495284, 0.15722080890554935, 0.12431752096745186, 0.10906096111284569, 0.1903745494200848, 0.09731114550959319, 0.2893019886687398, 0.2640680770855397, 0.17030885035637766, 0.20047391764819622, 0.12740729696815833, 0.20883861958282068, 0.10555335597018711, 0.19267976400442421, 0.23103872052161023, 0.11494944279547781, 0.283128596493043, 0.1810666816891171, 0.20474335964536294, 0.30515690508764237, 0.45025591913145036, 2.268307521007955, 9.14707152172923, 21.538505852222443, 36.18409797549248, 48.78429025411606, 59.62307944893837, 73.61880764365196, 80.6427763402462, 88.72850686311722, 84.59234520792961, 80.38572773337364, 71.2881039083004, 56.78470395505428, 44.518422558903694, 41.78422227501869, 37.051363438367844, 34.19987104833126, 43.4628240019083, 49.21712122857571, 38.032793775200844, 33.76870818436146, 27.43049819022417, 21.267059817910194, 14.202972874045372, 8.068135567009449, 5.807563718408346, 3.5204203706234694, 1.365652538370341, 0.5072092521004379, 0.20060045382706448, 0.23850586905609816, 0.2151377612608485, 0.25450158573221415, 0.12835346104111522, 0.18445280467858538, 0.11761564543121494, 0.13711047708056867, 0.1457476511131972, 0.18535187205998227, 0.10367801558459178, 0.13468117540469393, 0.1130917358386796, 0.14732162759173661, 0.09854560426902026, 0.28477004903834313, 0.11566784174647182, 0.09447233416722156, 0.1615612002206035, 0.08950547373387963, 0.11068414198234677, 0.08762978453887627, 0.1478828545077704, 0.10120712395291775, 0.08730867208214477, 0.1078050617070403, 0.15210923709673807, 0.2056634149630554, 0.08767319275648333, 0.16075251158326864, 0.13609860325232148, 0.09753138525411487, 0.1346986900898628, 0.10547666242928244, 0.1233946306456346, 0.12153520932770334, 0.1811203092802316, 0.11470476412796415, 0.13036848104093224, 0.18903207848779857, 0.1363304947153665, 0.13293315045302734, 0.16739416925702244, 0.11268383663264103, 0.07822563798981719, 0.09391171581228264, 0.1137251069303602, 0.1741979268263094, 0.12921785528305918, 0.07312386253033765, 0.1037317248119507, 0.14207882923074067, 0.11192097561433911, 0.12692332762526348, 0.09725549185532145, 0.14521116740070283, 0.0996421423042193, 0.11812239870778285, 0.08848615616443567, 0.10791398672154173, 0.1353722930070944, 0.18851765140425414, 0.18775509466649964, 0.09178084656014107, 0.25264449475798756, 0.1321710241609253, 0.0849101175845135, 0.11465155213954858, 0.20167600392596796, 0.284546900074929, 0.16269475658191368, 0.18037161586107686, 0.121602655708557, 0.1530151767656207], [0.06358837068546563, 0.0399139488581568, 0.018036032779491507, 0.08050310367252678, 0.04907827409624588, 0.05782214298960753, 0.05037326984165702, 0.026368955950601958, 0.10792482207762077, 0.02665020765562076, 0.055839001943240874, 0.08169298904249445, 0.05012000823626295, 0.026651265216059983, 0.07993932376848534, 0.06720804012729786, 0.03389073026482947, 0.04551324156636838, 0.02507987697754288, 0.052080959067097865, 0.03649362770374864, 0.03184822482580785, 0.10745742489234544, 0.012055184324708534, 0.04872740893915761, 0.028223137705936097, 0.01953169412445277, 0.020811075082747266, 0.1163255627034232, 0.08043844034546055, 0.020144806439930107, 0.018853437941288576, 0.058405600939295255, 0.0011107230284324032, 0.0635079960920848, 0.01043064903569757, 0.030162378861859906, 0.046173081354936585, 0.02303964807651937, 0.008681334602442803, 0.06234490967472084, 0.061001485082670115, 0.012842583528254181, 0.12847539590438828, 0.02369577527133515, 0.051685895305126905, 0.03438585037656594, 0.02557499708927935, 0.019836325336655136, 0.059883999929297715, 0.021141790930414572, 0.029488440122804604, 0.021848699580004904, 0.017703947669360787, 0.07798317834385671, 0.09922026103595272, 0.0773775190464221, 0.01997511622903403, 0.017578329898242373, 0.043282902261125855, 0.02531804515456315, 0.052475815027719364, 0.08249709120718762, 0.04263936003553681, 0.1199450169224292, 0.6389241968281567, 2.119346014223993, 3.4283843217417598, 8.952335771173239, 8.609897196292877, 17.902165576815605, 25.66804826259613, 38.22723314166069, 53.24957124888897, 68.57751175761223, 82.3630428314209, 81.1815570294857, 87.84541144967079, 93.45509603619576, 85.8708930015564, 87.81688258051872, 91.2250716984272, 90.07451623678207, 89.29404571652412, 82.61256784200668, 89.12025824189186, 88.22687298059464, 83.66635009646416, 92.76762172579765, 84.04216513037682, 89.56429481506348, 89.36007097363472, 89.44307371973991, 86.43981367349625, 79.80340138077736, 73.7074264883995, 63.98852840065956, 57.1217230707407, 58.896672427654266, 48.4740749001503, 29.2577251419425, 24.291460029780865, 11.007309202104807, 2.4957082187756896, 0.7905792247038335, 0.3617957455571741, 0.02220189322542865, 0.12658686755457893, 0.0455284852796467, 0.05109018449729774, 0.023377032121061347, 0.05901229182200041, 0.02532130132749444, 0.059641436382662505, 0.0411298984545283, 0.042620683889253996, 0.03553663569618948, 0.015111794673430268, 0.06809587139287032, 0.02334429598704446, 0.045004343483014964, 0.02006640781473834, 0.037981025234330446, 0.03975430547143333, 0.024011720524867997, 0.04336692451033741, 0.022523439838550985, 0.01622045754629653, 0.0358041613799287, 0.06913818811881356, 0.09298642093199305, 0.04166228922258597, 0.013053676302661188, 0.04698238968558144, 0.04968497611116618, 0.021276297775330022, 0.04216825582261663, 0.02604925728519447, 0.01249773533345433, 0.027060965985583607, 0.09159798137261532, 0.018542914076533634, 0.02712312270887196, 0.05518529600522015, 0.032336858566850424, 0.06916095720953308, 0.03136333150905557, 0.028546869943966158, 0.024200584120990243, 0.041587187588447705, 0.13002974999835715, 0.045478535030269995, 0.012902641828986816, 0.030018806683074217, 0.024380720060435124, 0.016632618535368238, 0.02631831735925516, 0.02310520940227434, 0.020876092785329092, 0.03229834481317084, 0.038625766028417274, 0.020589490195561666, 0.04771123065438587, 0.08916887265513651, 0.06323100431472994, 0.031232138353516348, 0.022873338348290417, 0.039573262256453745, 0.06190481981320772, 0.051182099487050436, 0.07683734685997479, 0.033417841186746955, 0.06530862447107211, 0.01975597671844298, 0.022117321786936373, 0.03714258760737721, 0.05065820259915199, 0.021436215756693855, 0.04135274684813339, 0.06071210686059203, 0.09072705623111688, 0.041166660739691, 0.08976345910923555, 0.048217831790680066, 0.016401205757574644, 0.03696424209920224, 0.037239990779198706, 0.0314204694586806, 0.04195555629848968, 0.04811293663806282, 0.04920832805510145, 0.03912350221071392, 0.02401399706286611, 0.07917917158920318, 0.04199506453005597, 0.05615701222268399, 0.039651354745728895, 0.018080891895806417, 0.06426507577998564, 0.04491495550610125, 0.194514412432909, 0.07235383236547932, 0.0332468392298324, 0.09307730433647521, 0.08273235202068463, 0.015996408728824463, 0.015090515444171615, 0.04288251730031334, 0.052222649901523255, 0.04250060810591094, 0.09678194968728349, 0.0400539995462168, 0.01661961796344258, 0.04798022207978647, 0.04730248168925755, 0.03533700910338666, 0.021659190315403976, 0.03074645464948844, 0.03175936748448294, 0.010028168435383122, 0.033816036811913364, 0.05953287130978424, 0.03652667553978972, 0.00783026098361006, 0.014035743624845054, 0.0390988963044947, 0.05878152842342388, 0.07184011774370447, 0.029274406588228885, 0.06096376171626616, 0.047220266569638625, 0.04305073991417885, 0.04909181829134468, 0.07298312906641513, 0.008118610403471394, 0.013623550166812493, 0.028249795650481246, 0.12245815159985796, 0.05814104384626262, 0.027537701244000345, 0.09114721571677364, 0.6531851284671575, 1.3333251792937517, 2.58130076341331, 8.529878240078688, 10.28799070045352, 20.59587523341179, 28.79373013973236, 42.700706496834755, 61.27497240900993, 80.32079681754112, 93.90003696084023, 93.34335923194885, 100.73549017310143, 107.46740654110909, 96.89529463648796, 98.52852299809456, 105.065076649189, 102.43540495634079, 106.0950493812561, 95.7279060781002, 99.39581885933876, 99.53755125403404, 95.0905890762806, 106.95217698812485, 99.27945390343666, 103.21664303541183, 102.07757815718651, 103.00721347332001, 100.60350805521011, 91.76714301109314, 84.22287583351135, 77.03136652708054, 65.62326148152351, 70.4526275396347, 57.06990145146847, 37.74302892386913, 29.610933288931847, 13.241266328841448, 2.78946784324944, 0.7228831259999424, 0.2611964999232441, 0.02762108895694837, 0.053579440573230386, 0.14862472016829997, 0.04691683949204162, 0.07814895929186605, 0.07049388412269764, 0.0113017328112619, 0.046167723048711196, 0.021329057053662837, 0.018007961043622345, 0.03953688588808291, 0.07861466438043863, 0.07959720853250474, 0.07991586448042654, 0.044401649065548554, 0.055512367907795124, 0.027172288137080614, 0.07233540483866818, 0.0624430958123412, 0.05917091475566849, 0.04836206448089797, 0.017303789063589647, 0.05675892738508992, 0.07346094600507058, 0.07416155567625538, 0.0445077836047858, 0.022769767929275986, 0.02320342893654015, 0.024837810669851024, 0.04323269968153909, 0.02480910439771833, 0.018042780757241417, 0.02666131389560178, 0.04776684720127378, 0.0165875441962271, 0.05683050010702573, 0.02959480472782161, 0.08901135923224501, 0.02659683239471633, 0.04885520305833779, 0.05275437273667194, 0.027540365554159507, 0.03899596784322057, 0.009847088113019709, 0.0702260949765332, 0.03207012327038683, 0.053954273389535956, 0.06490676634712145, 0.06798717644414864, 0.0070566397516813595, 0.009956089197658002, 0.04044932677061297, 0.02154681431420613, 0.06944811641005799, 0.0677840580465272, 0.039405358766089194, 0.035052354651270434, 0.053676112729590386, 0.02469782677508192, 0.0927133031655103, 0.03374380357854534, 0.022382871502486523, 0.007742072502878727, 0.01931882019562181, 0.02869466679840116, 0.009667609901953256, 0.0057768863280216465, 0.06925584821146913, 0.03178789935191162, 0.07050097905448638, 0.17707276943838224, 0.14846734033199027, 0.11770112600061111, 0.2119743122602813, 0.2291493906523101, 0.11158599241753109, 0.13814739097142592, 0.1504151662811637, 0.13914247741922736, 0.12874764535808936, 0.15682042023399845, 0.1297964484547265, 0.12169082285254262, 0.14183573133777827, 0.12049710057908669, 0.13413302513072267, 0.10341718036215752, 0.1282720622839406, 0.07370969906332903, 0.18315884051844478, 0.1467750358278863, 0.09906832114211284, 0.19449884217465296, 0.09809896495426074, 0.19873941462719813, 0.15473727107746527, 0.16591818595770746, 0.28374276822432876, 0.2551982249133289, 0.18245179642690346, 0.06476767302956432, 0.15858873550314456, 0.21052736177807674, 0.1396677695447579, 0.23520819522673264, 0.083617326017702, 0.16935881227254868, 0.2400858569308184, 0.06628520917729475, 0.0841528078308329, 0.10227383507299237, 0.15117600123630837, 0.08542146475519985, 0.25454673799686134, 0.17603705782676116, 0.13816940307151526, 0.11065538375987671, 0.09292483751778491, 0.09950945372111164, 0.16331018996424973, 0.12821974087273702, 0.18058330606436357, 0.11208303840248846, 0.15741525159683079, 0.141211407026276, 0.14018051937455311, 0.3006893541896716, 0.11279466154519469, 0.14842907519778237, 0.15175414911936969, 0.10429240996018052, 0.21150324144400656, 0.1560519856866449, 0.16530300490558147, 0.35913443367462605, 1.0732368542812765, 2.4657867243513465, 4.579002242535353, 12.581998854875565, 16.027997843921185, 28.536751829087734, 39.7242122143507, 56.62238046526909, 74.96312990784645, 95.84241673350334, 111.18084847927094, 110.01088365912437, 115.70760637521744, 120.89889541268349, 114.73590731620789, 116.38824865221977, 116.87090635299683, 119.84144255518913, 119.06243115663528, 108.80088418722153, 118.91462668776512, 115.47778710722923, 112.19093307852745, 124.8173439502716, 114.56633001565933, 120.5173046886921, 119.30234268307686, 122.94453844428062, 117.42607176303864, 110.77721893787384, 103.16664531826973, 93.67841005325317, 83.94880414009094, 84.68432307243347, 72.20287442207336, 54.54374000430107, 41.44608981907368, 20.436897464096546, 5.163313038647175, 1.3932737312279642, 0.5448979453649372, 0.12007554585579783, 0.36717429757118225, 0.26343416422605515, 0.16611066937912256, 0.20921074727084488, 0.1368797878967598, 0.2538440132047981, 0.15723278716905043, 0.09748497875989415, 0.09934094166965224, 0.17507361655589193, 0.2162494242656976, 0.20194148499285802, 0.1113660421106033, 0.10918508531176485, 0.1010296170716174, 0.10261680377880111, 0.12060140201356262, 0.11417662957683206, 0.11441167516750284, 0.08160430981661193, 0.1279507568688132, 0.18059448280837387, 0.1850837786332704, 0.13425435143290088, 0.14884623640682548, 0.1696536675444804, 0.13895824667997658, 0.09733367711305618, 0.1586035784566775, 0.15606427565217018, 0.12477611628128216, 0.07273723327671178, 0.210140346607659, 0.15825319569557905, 0.2255552585120313, 0.12340645305812359, 0.15713264176156372, 0.11489574098959565, 0.13217283500125632, 0.08916797465644777, 0.19520610891049728, 0.08794262204901315, 0.15018751990282908, 0.19659261888591573, 0.10940243810182437, 0.14122454304015264, 0.16736282093916088, 0.18646568729309365, 0.11891683068824932, 0.12082717817975208, 0.1422788083436899, 0.06214219203684479, 0.13291793642565608, 0.14023120806086808, 0.22826917382190004, 0.14632262260420248, 0.17290647112531587, 0.10385829067672603, 0.14616901287809014, 0.12570503284223378, 0.10374357691034675, 0.22517103381687775, 0.1638352742884308, 0.1575948513345793, 0.11577188342926092, 0.10322900881874375, 0.11999144568108022, 0.09049011074239388, 0.13254601653898135], [0.06880537941469811, 0.04488723257964011, 0.07006423998973332, 0.04578966931148898, 0.08101602419628762, 0.061000327332294546, 0.06525963530293666, 0.008840958507789765, 0.033334241961711086, 0.02800515780108981, 0.05370256658352446, 0.02719578453252325, 0.026937921611533966, 0.015187331391643966, 0.011331904825055972, 0.030215616825444158, 0.030547937567462213, 0.04066862027684692, 0.024414153813268058, 0.021943418032606132, 0.04488267208216712, 0.06271552338148467, 0.03921197363524698, 0.046121349951135926, 0.03156760765705258, 0.045713821818935685, 0.03436086597503163, 0.08212269254727289, 0.02570571712567471, 0.019852266668749508, 0.02111698835506104, 0.020238356009940617, 0.01305631834839005, 0.04587101982906461, 0.06374400647473522, 0.07234188378788531, 0.03677527274703607, 0.02387153810559539, 0.0037094980689289514, 0.05212980351643637, 0.0791300339915324, 0.018259441494592465, 0.08077605816652067, 0.05107252138259355, 0.060732515921699814, 0.10749170469352975, 0.03658559835457709, 0.028006740431010257, 0.09946529593435116, 0.04110132205823902, 0.1059246227669064, 0.027426913438830525, 0.06496947040432133, 0.03675591382489074, 0.06459231095504947, 0.02666505617526127, 0.05647659214446321, 0.03182300293701701, 0.0318592123221606, 0.09496498663793318, 0.06924610381247476, 0.6639018002897501, 2.482127984985709, 5.200828900560737, 8.84047357365489, 14.281559307128191, 20.08193951100111, 44.052267372608185, 72.80347779393196, 77.88872212171555, 78.95265743136406, 81.40649735927582, 80.29796004295349, 84.11578238010406, 79.87757340073586, 77.58964017033577, 79.47167158126831, 58.544522523880005, 69.46504533290863, 72.51030832529068, 67.24731713533401, 54.0360264480114, 66.97460576891899, 56.17986001074314, 66.55488029122353, 66.80271059274673, 76.23507365584373, 87.35276028513908, 79.527148604393, 85.93324765563011, 77.267926633358, 88.2804349064827, 84.35641586780548, 84.4968943297863, 85.0836132466793, 89.1603384912014, 103.66314947605133, 94.73633408546448, 86.93305760622025, 95.4402083158493, 81.97128385305405, 92.1155995130539, 66.8668207526207, 47.981374338269234, 24.870309568941593, 11.656777001917362, 4.635785445570946, 1.5009348979219794, 0.2013514330610633, 0.17513577884528786, 0.008973529274953762, 0.11495821498101577, 0.03468906965281349, 0.06129678193246946, 0.03523418083204888, 0.08071048941928893, 0.018262115081597585, 0.018119611595466267, 0.009829954706219723, 0.027089731629530434, 0.01355574755507405, 0.05793069321953226, 0.0656734939548187, 0.04637051490135491, 0.047010732305352576, 0.045797068523825146, 0.06873010337585583, 0.046431319060502574, 0.027222268072364386, 0.038324687848216854, 0.023289837190532126, 0.06957486781175248, 0.028374224129947834, 0.06585276714758947, 0.040946428416646086, 0.029625153001688886, 0.05417781198048033, 0.07973814237629995, 0.0554134878620971, 0.010372133474447764, 0.026936253634630702, 0.010433143579575699, 0.03309310333861504, 0.03331185878778342, 0.04605780355632305, 0.022775031611672603, 0.0283039186251699, 0.026926195678242948, 0.05347155085473787, 0.057373622330487706, 0.024171347213268746, 0.10646737020579167, 0.0228066804993432, 0.03017484508745838, 0.02660017020389205, 0.007310351747946697, 0.04532155966444407, 0.0545793138735462, 0.07687416480621323, 0.008179723481589463, 0.030110530569800176, 0.06651004281593487, 0.022963882220210508, 0.06962287734495476, 0.05803953288705088, 0.11795798331149854, 0.09912559267831966, 0.04262543734512292, 0.0338079065841157, 0.04716501367511228, 0.07016280462266877, 0.0687923250370659, 0.02284750975377392, 0.05440811895823572, 0.08678329089889303, 0.03532429240294732, 0.07952343163196929, 0.036057367324247025, 0.04290476688765921, 0.09212528471834958, 0.06980566089623608, 0.030871074231981765, 0.026658553106244653, 0.07013225040282123, 0.06638268285314552, 0.03866794599161949, 0.09972189349355176, 0.03415416300413199, 0.015041192309581675, 0.031960582273313776, 0.029979491409903858, 0.013877847068215488, 0.07327668557991274, 0.10013107661507092, 0.042150303270318545, 0.034090067420038395, 0.007448083224517177, 0.015811708581168205, 0.059413159178802744, 0.01835028964705998, 0.02971182100736769, 0.01356906632281607, 0.0998517767584417, 0.05333874352800194, 0.030334601651702542, 0.03247953274694737, 0.0610496467561461, 0.06055151352484245, 0.06048637893400155, 0.01063473408066784, 0.062155532141332515, 0.06983225204749033, 0.019915048651455436, 0.017890618219098542, 0.015130092324397992, 0.03919587274140213, 0.01959295099368319, 0.041784788118093275, 0.022510682319989428, 0.04259179579094052, 0.062126005796017125, 0.05671211642038543, 0.036388168518897146, 0.03256752548622899, 0.0163697219977621, 0.03747918126464356, 0.008602298657933716, 0.02254022165288916, 0.04721678589703515, 0.03524691237544175, 0.039077934343367815, 0.04613051547494251, 0.031358266351162456, 0.06927462454768829, 0.05895192181924358, 0.03997210726083722, 0.04752353408548515, 0.44009683770127594, 2.111727185547352, 4.624003702774644, 8.49355598911643, 14.662008192390203, 23.85197751224041, 47.5825971364975, 79.78529155254364, 87.34452232718468, 91.30929797887802, 91.91595822572708, 95.70717439055443, 94.8594018816948, 94.3704441189766, 89.59631949663162, 92.13667318224907, 74.70966070890427, 89.20940905809402, 90.95964834094048, 86.12774401903152, 73.35211515426636, 86.01030752062798, 72.63219818472862, 83.60394984483719, 83.1926979124546, 93.50625649094582, 102.94857501983643, 92.28651434183121, 99.99759256839752, 90.03350123763084, 102.1473728120327, 100.22529155015945, 96.48872405290604, 95.90761363506317, 103.05465012788773, 116.06677070260048, 106.92007631063461, 100.64409747719765, 108.85354936122894, 93.13345849514008, 103.1145729124546, 76.65815055370331, 54.54108774662018, 29.21747960150242, 12.98615276813507, 5.566291864961386, 1.5279314992949367, 0.11753232451155782, 0.09289857291150838, 0.007349045472437865, 0.05703849070414435, 0.033030351041816175, 0.05561458761803806, 0.03403441376576666, 0.08387513327761553, 0.04321555978094693, 0.016951643701759167, 0.05663603515131399, 0.04329402705479879, 0.0271999999313266, 0.04369372923974879, 0.059964122192468494, 0.05057188340288121, 0.06499933442682959, 0.03482745050860103, 0.07530476737883873, 0.023360001687251497, 0.05648649239446968, 0.02484999302396318, 0.01850372125772992, 0.03279987708083354, 0.03731242810317781, 0.007489021945730201, 0.015161822848313022, 0.06059050967451185, 0.08809813909465447, 0.049624483654042706, 0.035670222277985886, 0.020956899679731578, 0.023205306570162065, 0.05542235652683303, 0.02293930599989835, 0.054338653935701586, 0.02865180591470562, 0.044950534065719694, 0.014135074525256641, 0.07438894230290316, 0.02727368406340247, 0.023821278009563684, 0.05514462631253991, 0.028675903449766338, 0.03975800136686303, 0.04214500433590729, 0.016425067660748027, 0.04412447917275131, 0.04519170608546119, 0.010711766226449981, 0.02878607341699535, 0.049189173223567195, 0.015944187507557217, 0.06132093141786754, 0.01635043172427686, 0.038355030555976555, 0.011018316818081075, 0.10309341101674363, 0.037984776790835895, 0.03811581409536302, 0.03284717786300462, 0.033978615392697975, 0.0467824588122312, 0.049261469539487734, 0.034710666150203906, 0.02227727873105323, 0.05414801475126296, 0.034773206934914924, 0.11337050134898163, 0.09924205791321583, 0.14490561035927385, 0.15912866278085858, 0.2428438261267729, 0.11628050691797398, 0.12717754289042205, 0.1955675199860707, 0.17521882517030463, 0.10888988123042509, 0.21227305638603866, 0.1244123229116667, 0.08560477523133159, 0.13827245769789442, 0.10768743872176856, 0.12028293160255998, 0.1923513488145545, 0.15419787814607844, 0.07625873884535395, 0.146392711030785, 0.10208749663433991, 0.1474072565906681, 0.2430304911104031, 0.14798754185903817, 0.10293481405824423, 0.16002658725483343, 0.16752297640778124, 0.15015968936495483, 0.1733596858684905, 0.19966108782682568, 0.16220070887356997, 0.10312398007954471, 0.17277723352890462, 0.0797721253184136, 0.14204347331542522, 0.16201591410208493, 0.0847664823231753, 0.20320349227404222, 0.13305171596584842, 0.12274405657080933, 0.14736489480128512, 0.11811449483502656, 0.2186108788009733, 0.19911793962819502, 0.15617847733665258, 0.0914485944667831, 0.15856375481234863, 0.0812386091274675, 0.24114810774335638, 0.12698955688392743, 0.2079239671002142, 0.14631892670877278, 0.17047041590558365, 0.16408993484219536, 0.17411369306501, 0.09713354957057163, 0.18200382124632597, 0.2503464790061116, 0.22559025819646195, 0.13146604323992506, 0.09704669602797367, 1.435760201420635, 3.1683915853500366, 7.404519226402044, 13.214088287204504, 21.525259763002396, 32.55040995776653, 58.51283222436905, 95.52161514759064, 104.13571491837502, 106.3415801525116, 107.49547183513641, 107.94323220849037, 109.94227454066277, 105.19709676504135, 101.86590671539307, 103.83015051484108, 82.25973397493362, 97.55159541964531, 100.34560829401016, 93.51595357060432, 78.77534374594688, 92.06437066197395, 79.72753465175629, 93.43959286808968, 91.41706019639969, 103.28980430960655, 112.45050475001335, 104.42483380436897, 110.83531022071838, 101.7782986164093, 114.58632454276085, 110.81283062696457, 109.32230740785599, 108.93999472260475, 118.18184360861778, 131.0149785876274, 120.61779409646988, 113.70892882347107, 124.53897848725319, 110.62457352876663, 121.21265977621078, 92.37979933619499, 69.8678769171238, 40.36266155540943, 21.298936307430267, 10.987416319549084, 4.357194844633341, 0.6442684319335967, 0.24643770593684167, 0.06501362819108181, 0.26636502414476126, 0.20492291485425085, 0.18358373490627855, 0.2503739681560546, 0.18267258536070585, 0.13670468557393178, 0.13736613211221993, 0.16315747081534937, 0.12893197999801487, 0.08691302573424764, 0.1795895554823801, 0.11589581466978416, 0.15564524423098192, 0.12241429067216814, 0.15487464261241257, 0.22664557734970003, 0.2473900149925612, 0.15948725369526073, 0.16697832907084376, 0.09639907570090145, 0.09996211185352877, 0.09202191096846946, 0.10163359911530279, 0.12785044818883762, 0.10889101671637036, 0.2102377757546492, 0.19138437492074445, 0.09107754289289005, 0.06909400064614601, 0.10930490505415946, 0.1478611837956123, 0.1201384057640098, 0.11929464322747663, 0.14630138233769685, 0.14639340864960104, 0.12675367266638204, 0.1334531733300537, 0.14313359919469804, 0.16222232021391392, 0.12008390986011364, 0.17595920653548092, 0.1178490137681365, 0.16615052270935848, 0.1159002527128905, 0.13975252280943096, 0.2018429574673064, 0.11139065172756091, 0.20597237104084343, 0.14792073372518644, 0.14308691810583696, 0.1477237677318044, 0.1902889649500139, 0.14411054755328223, 0.10006342243286781, 0.20750187803059816, 0.0952677680470515, 0.16634391155093908, 0.104977330629481, 0.15296644734917209, 0.09862638704362325, 0.08668445909279399, 0.1381917714024894, 0.10688194874092005, 0.20637908281059936, 0.11971074316534214], [0.05671987928508315, 0.06550592443090864, 0.06362849118886515, 0.05745472422859166, 0.09152274986263365, 0.018088751239702106, 0.013068051703157835, 0.032789038014016114, 0.04454730296856724, 0.038197524554561824, 0.0037494165690077352, 0.03262014375650324, 0.020944667230651248, 0.03576385533961002, 0.0520883211720502, 0.009986422628571745, 0.023998842407308985, 0.010396423967904411, 0.017735459259711206, 0.051158677306375466, 0.019881228981830645, 0.04598909923515748, 0.045287565590115264, 0.041328467486891896, 0.054070601327111945, 0.03545507737726439, 0.07095586362993345, 0.0661640238831751, 0.12139927013777196, 0.04224005118885543, 0.03785830740525853, 0.05545586820517201, 0.09349403509986587, 0.012572715440910542, 0.03578263167582918, 0.06604826368857175, 0.05089664722618181, 0.0446409731375752, 0.010960623185383156, 0.026294486997358035, 0.021184004290262237, 0.024025374186749104, 0.02946315515146125, 0.02760788058367325, 0.03344361968629528, 0.0256273723061895, 0.04156501963734627, 0.04061814681335818, 0.07290944122360088, 0.030108966493571643, 0.01755416928062914, 0.012581850351125468, 0.02150569747755071, 0.027345416347088758, 0.02530127818317851, 0.13942683872301131, 0.0648193339293357, 0.07416191932861693, 0.3601753996917978, 1.4566405559889972, 8.129738811403513, 12.764488812536001, 23.51284570991993, 40.47597527503967, 58.28369311988354, 64.90018308162689, 60.180076360702515, 75.04715099930763, 87.37174406647682, 78.10404136776924, 70.05988821387291, 62.36863732337952, 58.5927951335907, 67.82965868711472, 53.74492026865482, 55.58114133775234, 40.28731919825077, 41.861787512898445, 33.59873570501804, 33.34167569875717, 26.250686198472977, 20.35500045865774, 17.211330346763134, 22.246966436505318, 26.935379058122635, 28.47136303782463, 31.049606390297413, 37.41764858365059, 47.8956813365221, 49.24433536827564, 42.61796593666077, 38.35827670991421, 48.862657248973846, 55.04964865744114, 58.399902284145355, 51.90132759511471, 63.33757013082504, 67.66609266400337, 72.4314321577549, 66.72261089086533, 79.55640703439713, 92.85120204091072, 74.45759743452072, 84.42070081830025, 71.40915021300316, 69.68056976795197, 40.24539224803448, 35.817026272416115, 22.889268770813942, 10.561392679810524, 3.5236067371442914, 0.550743694184348, 0.07013983515207656, 0.10313315302482806, 0.02716646598855732, 0.04436039678694215, 0.039961947259143926, 0.02165810677979607, 0.019309853196318727, 0.03973920647695195, 0.026625230675563216, 0.02502621598978294, 0.03927835132344626, 0.05813843148644082, 0.026405501157569233, 0.020732294251502026, 0.02437609276967123, 0.012827769332943717, 0.04308820723963436, 0.010746455136541044, 0.031405971603817306, 0.026785475201904774, 0.022316417744150385, 0.04721981014881749, 0.013025457992625888, 0.009820977502386086, 0.044724416511598974, 0.03313393630378414, 0.015124798028409714, 0.005868651960554416, 0.06094731572375167, 0.030236686397984158, 0.028094768422306515, 0.1014719445083756, 0.03504727465042379, 0.06444155849749222, 0.0299273833661573, 0.12994158285437152, 0.01743626984534785, 0.010498993415239966, 0.06347834729240276, 0.06807930665672757, 0.06021806657372508, 0.010850532999029383, 0.012082814482710091, 0.029845047647540923, 0.05977977270958945, 0.06843214592663571, 0.03169998453813605, 0.014736491521034623, 0.017772687242540997, 0.06718855132930912, 0.019691554589371663, 0.03956813030526973, 0.0013451666677610774, 0.06291244484600611, 0.016156449164554942, 0.0631607451941818, 0.004717073934443761, 0.025618023100832943, 0.014929216140444623, 0.04447416060429532, 0.03756343729037326, 0.013924543000030098, 0.01604480046808021, 0.03634336877439637, 0.022554033021151554, 0.07343897843384184, 0.0759208835370373, 0.06655468299868517, 0.06655510602286085, 0.051434667184366845, 0.05310644017299637, 0.03736401107744314, 0.04565065020869952, 0.0597196513263043, 0.06881228138809092, 0.0069891743532934925, 0.022701234302076045, 0.057280115433968604, 0.03209422080544755, 0.038430540371336974, 0.04745018020912539, 0.015040185771795223, 0.03964219293266069, 0.042861833644565195, 0.011766701318265405, 0.031443001062143594, 0.03561931094736792, 0.020914033229928464, 0.007773192146487418, 0.03867702245770488, 0.10061765831778757, 0.019523255905369297, 0.06660523809841834, 0.07990792350028642, 0.07644929268280976, 0.006037780922270031, 0.013458269240800291, 0.06096228855312802, 0.024286676962219644, 0.07318546820897609, 0.074756854592124, 0.043859580691787414, 0.04104624727915507, 0.04118691766052507, 0.025356024561915547, 0.023295440405490808, 0.06874368467833847, 0.045097379115759395, 0.05803223015391268, 0.022135773433547, 0.0164171285359771, 0.0502388668974163, 0.014887105753587093, 0.0419579423032701, 0.06231520892470144, 0.04739165073260665, 0.03942950825148728, 0.10569558115093969, 0.027762661047745496, 0.044008088152622804, 0.0898993166629225, 0.013229607975517865, 0.08945724897785112, 0.7933884020894766, 6.458512963727117, 13.083206210285425, 28.048105649650097, 47.25184768438339, 65.49595311284065, 71.96561515331268, 73.71714636683464, 87.22224488854408, 101.46832644939423, 90.43082311749458, 87.5115841627121, 79.55628544092178, 76.87463253736496, 84.91839051246643, 76.67170822620392, 77.30181321501732, 65.81287890672684, 54.960076063871384, 53.572303131222725, 56.0304444283247, 49.97754022479057, 42.79021069407463, 42.26460009813309, 42.20164507627487, 46.031421571969986, 49.99250002205372, 48.69461506605148, 62.68900193274021, 78.10002118349075, 82.65100657939911, 65.40587514638901, 56.375093534588814, 62.548998445272446, 78.87365967035294, 79.39261302351952, 75.03937661647797, 81.90420985221863, 82.8013189136982, 82.80006498098373, 84.25411775708199, 90.53952768445015, 107.90504425764084, 88.61029520630836, 96.21710702776909, 83.24052214622498, 79.94627371430397, 46.821049600839615, 38.720404878258705, 26.404256857931614, 12.71830989047885, 3.543266882188618, 0.7115087925922126, 0.09585923748090863, 0.20448197523364797, 0.017630408256081864, 0.06776054680813104, 0.03739622399734799, 0.09468262913287617, 0.04691115835157689, 0.09120444272411987, 0.010735356318036793, 0.03849463595543057, 0.04157360628596507, 0.055142103010439314, 0.006528269104819628, 0.04419795179273933, 0.03636855726654176, 0.011081568209192483, 0.04156346483796369, 0.02887522947276011, 0.034598523925524205, 0.03640226190327667, 0.0692741792590823, 0.06595554717932828, 0.05123831346281804, 0.0481861309526721, 0.05156201972567942, 0.03771178890019655, 0.054141569198691286, 0.017620817852730397, 0.05165315917111002, 0.024058115886873566, 0.029708882102568168, 0.052949743112549186, 0.046476809002342634, 0.04354527743998915, 0.025995633404818363, 0.01922564912092639, 0.038502332026837394, 0.04541438749583904, 0.02447221017064294, 0.07841717888368294, 0.023878703541413415, 0.04159418975177687, 0.04820586837013252, 0.06791735519072972, 0.03494316617434379, 0.037439157240442, 0.014577888996427646, 0.06324051122646779, 0.05568570391915273, 0.048046440206235275, 0.001847705241289077, 0.016764698557381053, 0.04974422547093127, 0.01859188654634636, 0.04295540362363681, 0.056016787129919976, 0.03287130137323402, 0.06312665835139342, 0.02641896000568522, 0.02613161897897953, 0.008964211610873463, 0.01088329789126874, 0.035288791768834926, 0.0233847226263606, 0.11868387795402668, 0.14979666040744632, 0.1296452432870865, 0.18732346157776192, 0.1778238228871487, 0.10601183996186592, 0.12677914317464456, 0.128559778095223, 0.07498439706978388, 0.1972366843256168, 0.09831320814555511, 0.13176404521800578, 0.12272199252038263, 0.13225132453953847, 0.14125025103567168, 0.06398869256372564, 0.12343299225904047, 0.14626510615926236, 0.13671322027221322, 0.129239407251589, 0.0892584869870916, 0.12611063139047474, 0.10965341018163599, 0.21466672013048083, 0.12376517013763078, 0.10503162615350448, 0.15194764186162502, 0.1430683198850602, 0.22764165827538818, 0.19566466711694375, 0.1677077860222198, 0.12886157986940816, 0.17737023707013577, 0.15775726293213665, 0.06224615950486623, 0.18621785449795425, 0.13171720085665584, 0.07711917744018137, 0.16453688585897908, 0.08186395018128678, 0.1472489268053323, 0.0648219240247272, 0.20948636607499793, 0.0829653641267214, 0.1549484269344248, 0.19532500096829608, 0.154498744814191, 0.15397196839330718, 0.13424041389953345, 0.1641987485345453, 0.2414809016045183, 0.15443926909938455, 0.11705418844940141, 0.1095442105724942, 0.08124044965370558, 0.19745558820432052, 0.21501929964870214, 0.1584662959794514, 0.5602521495893598, 2.7512148208916187, 11.49520967155695, 20.21552514284849, 40.13143636286259, 59.17490489780903, 82.32698276638985, 91.88375115394592, 90.22570252418518, 105.0572718679905, 113.67075607180595, 101.7634566128254, 93.62489372491837, 83.29035267233849, 80.41488736867905, 90.73863700032234, 73.63955453038216, 78.7030716240406, 60.1909551769495, 65.3190878033638, 51.29182130098343, 52.40135796368122, 44.112714529037476, 34.36356246471405, 32.1033601462841, 37.93515421450138, 45.1058292388916, 49.55751836299896, 47.862402722239494, 52.87485055625439, 69.5930452644825, 68.91471326351166, 64.99047383666039, 59.79715570807457, 70.25606408715248, 82.72023126482964, 81.99944794178009, 74.4734425842762, 86.98324531316757, 94.62983340024948, 96.28754004836082, 95.51608264446259, 105.77917993068695, 118.85539546608925, 99.40291687846184, 110.11492967605591, 99.89196583628654, 98.29356640577316, 63.55790130794048, 55.86740277707577, 40.6152568012476, 21.562001891434193, 8.119461312890053, 1.97345616761595, 0.2760223246878013, 0.3772486554225907, 0.12814280984457582, 0.24363551958231255, 0.20447813090868294, 0.21153211098862812, 0.1390801667002961, 0.15278678823960945, 0.14291465078713372, 0.14237168070394546, 0.24197952094255015, 0.16713603545213118, 0.08171283407136798, 0.14290129212895408, 0.17753095657099038, 0.10809838073328137, 0.17039186699548736, 0.11359258904121816, 0.09704979820526205, 0.12215701033710502, 0.20715001097414643, 0.19388278538826853, 0.13596915785456076, 0.09763426176505163, 0.26555207557976246, 0.14099434367381036, 0.15557692211586982, 0.07644415702088736, 0.10385089146438986, 0.18393530510365963, 0.11613178052357398, 0.17089314322220162, 0.20394569932250306, 0.17119634023401886, 0.10269331920426339, 0.20158792583970353, 0.15016869903774932, 0.10528940372751094, 0.12754346622386947, 0.21066035464173183, 0.2344750869087875, 0.09030237706610933, 0.1842510889400728, 0.12973217846592888, 0.14755734853679314, 0.15504854265600443, 0.15116531430976465, 0.15405862155603245, 0.16415748512372375, 0.09838734127697535, 0.191500001528766, 0.21264715818688273, 0.16270176245598122, 0.15169071033596992, 0.08663981891004369, 0.11542607229785062, 0.09339815704151988, 0.1649126352276653, 0.23079206031979993, 0.10529427963774651, 0.2152845580712892, 0.1055438416369725, 0.09322957819676958, 0.1397419991553761], [0.013193021022743778, 0.02479076778399758, 0.014906750402587932, 0.04327743634348735, 0.00786474023698247, 0.05392921848397236, 0.04676761956943665, 0.028413474465196487, 0.023585119197377935, 0.011450078854977619, 0.05636884343402926, 0.02625875629746588, 0.0443868766160449, 0.03951094411604572, 0.025592454258003272, 0.044176540832268074, 0.05393475490564015, 0.048830853193067014, 0.04677712277043611, 0.020521106853266247, 0.03051443702133838, 0.04575336344714742, 0.08955367622547783, 0.0389936152350856, 0.05223842425039038, 0.053987002102076076, 0.01433278359399992, 0.07266574961249717, 0.05602962257398758, 0.047645958766224794, 0.021926550871285144, 0.055637846526224166, 0.052591987114283256, 0.06087515299441293, 0.009270905065932311, 0.07772960874717683, 0.030756514461245388, 0.05881736673472915, 0.036145167105132714, 0.08911403536330909, 0.04223480791551992, 0.050444849985069595, 0.006401192085832008, 0.047730411461088806, 0.024860175290086772, 0.025752980800461955, 0.03476758887700271, 0.056612330954521894, 0.03766457346500829, 0.0677767330489587, 0.044621569686569273, 0.03112145630439045, 0.019259641339886002, 0.013774262733932119, 0.027706280088750646, 0.33907536941114813, 1.2253968394361436, 3.5480334889143705, 11.987676545977592, 30.854986533522606, 39.9198143184185, 47.84672476351261, 70.4186649620533, 79.1225615143776, 69.69840601086617, 67.39652752876282, 59.54120524227619, 40.12370377779007, 48.48588466644287, 56.09102837741375, 34.93015006184578, 21.654338836669922, 17.082505859434605, 21.574389226734638, 20.690068379044533, 21.370596662163734, 25.24605430662632, 41.882367208600044, 49.58885908126831, 27.930076383054256, 37.61721007525921, 32.08816096186638, 30.519010461866856, 26.92728739231825, 31.122729666531086, 17.105411030352116, 17.730112709105015, 30.167875103652477, 20.82070156931877, 13.240990843623877, 16.24684140086174, 23.53720050305128, 26.465577967464924, 14.625823684036732, 16.569041311740875, 16.290888637304306, 30.4405427724123, 32.49206028878689, 34.79300782084465, 34.81310114264488, 61.38382516801357, 85.22326335310936, 80.93074768781662, 83.0381678044796, 82.160924077034, 78.04321423172951, 86.38135001063347, 84.83730286359787, 76.89170122146606, 66.22959494590759, 42.22258575260639, 22.535868734121323, 9.563492126762867, 1.5134622319601476, 0.25656603276729584, 0.1760738980374299, 0.019155052323185373, 0.017907511355588213, 0.023244358380907215, 0.07740999542875215, 0.09412785890162922, 0.05128846038132906, 0.07303714999579825, 0.08062382141361013, 0.06001022811688017, 0.0577872694702819, 0.019094517192570493, 0.019428730411163997, 0.030106237245490775, 0.05283513695758302, 0.0503418918378884, 0.03079158650507452, 0.07372301319264807, 0.08579034183640033, 0.006107694016463938, 0.019501553651934955, 0.03374964428076055, 0.052310382889118046, 0.05734068952733651, 0.01647519602556713, 0.03455582445894834, 0.036203807903802954, 0.010289958245266462, 0.009660979740147013, 0.030033449256734457, 0.006636125890508993, 0.014148890531942016, 0.04034039062389638, 0.04585031019814778, 0.018524024562793784, 0.026878063690674026, 0.016540191463718656, 0.03347417019540444, 0.05410355639469344, 0.07128700250177644, 0.031499025790253654, 0.06157558455015533, 0.02592859891592525, 0.07579183889902197, 0.07750602933811024, 0.0486262690537842, 0.026676639245124534, 0.04417278556502424, 0.08009199096704833, 0.044681427607429214, 0.042445459112059325, 0.10612160360324197, 0.03875045797030907, 0.05888859064725693, 0.11333084097714163, 0.03821593723841943, 0.046755006769672036, 0.055763963391655125, 0.025407525899936445, 0.04221233197313268, 0.024216688725573476, 0.029535178728110623, 0.015520796896453248, 0.03555249539203942, 0.04086931556230411, 0.08866706208209507, 0.024477110200678, 0.022089682352088857, 0.02345026168768527, 0.022162410969031043, 0.040750928164925426, 0.05505906039616093, 0.01926387529238127, 0.04200329494778998, 0.022135292892926373, 0.06868796423077583, 0.03919091519492213, 0.028902054400532506, 0.03629363374784589, 0.03747404189198278, 0.04683755585574545, 0.028861395840067416, 0.018162114392907824, 0.03653417865280062, 0.04330125557316933, 0.026593960283207707, 0.07216274418169633, 0.02440310323436279, 0.020988383439544123, 0.11839516024338081, 0.01655293228395749, 0.0024804715985737857, 0.0795900468074251, 0.03024055669811787, 0.0247738765028771, 0.005043207020207774, 0.042473516004974954, 0.04147562794969417, 0.022999163920758292, 0.03244914551032707, 0.06284615621552803, 0.06320796062937006, 0.03293897781986743, 0.041028617561096326, 0.061914300749776885, 0.05901867429201957, 0.050626728116185404, 0.062482028879458085, 0.025891317127388902, 0.05889492116693873, 0.043536252924241126, 0.0587664294289425, 0.008400845454161754, 0.014656735693279188, 0.09309072236646898, 0.009707823173812358, 0.19688300642883405, 0.7277514366433024, 2.524267961271107, 11.099729742854834, 31.961057782173157, 49.06509518623352, 60.230541452765465, 84.3111602962017, 92.46998369693756, 84.79988247156143, 81.89785659313202, 74.05656695365906, 53.632328510284424, 64.32440757751465, 73.54018986225128, 49.73486624658108, 37.47740417718887, 39.60922658443451, 40.612957924604416, 36.94016620516777, 37.02650137245655, 37.8110034763813, 49.985876977443695, 41.01393520832062, 32.13678315281868, 44.75032791495323, 30.96980307251215, 33.703389689326286, 31.08855240046978, 33.18403735756874, 29.204227812588215, 26.451526321470737, 31.845673173666, 35.6671205163002, 22.23909515887499, 29.54611636698246, 34.25139628350735, 40.820871368050575, 26.08431212604046, 32.148775309324265, 34.984821528196335, 53.25321525335312, 56.00390285253525, 58.06520864367485, 53.74496966600418, 78.10562208294868, 96.33388996124268, 82.80836373567581, 92.5095471739769, 91.13684043288231, 90.72911471128464, 94.54534873366356, 94.15411412715912, 85.85716813802719, 75.96934631466866, 46.731902584433556, 26.915656216442585, 10.778950955718756, 1.4118213672190905, 0.502472153166309, 0.12828208127757534, 0.050254385205334984, 0.01644063049752731, 0.005228109403105918, 0.04179850671789609, 0.03580621712899301, 0.07968985082698055, 0.0343445609905757, 0.046695972632733174, 0.03144452246488072, 0.031863026961218566, 0.04053913406096399, 0.026870326801144984, 0.08120661514112726, 0.03170982170559, 0.040455323323840275, 0.05247972614597529, 0.035365886069484986, 0.04850165874813683, 0.07114874781109393, 0.03645945922471583, 0.022261313279159367, 0.06469588508480228, 0.04806346507393755, 0.04928743357595522, 0.029063529036648106, 0.041423280563321896, 0.04930683702696115, 0.06130877874966245, 0.008599420980317518, 0.005438868674900732, 0.05866169012733735, 0.009271963554056128, 0.04777218695380725, 0.03475631936453283, 0.06161776451335754, 0.05506812573003117, 0.031729288239148445, 0.01827219715778483, 0.07126015159883536, 0.029141749546397477, 0.03992057994764764, 0.07004810569924302, 0.09338715841295198, 0.021189084291108884, 0.007772722274239641, 0.05658177673467435, 0.01267387202460668, 0.06749951862730086, 0.08573889615945518, 0.052660932633443736, 0.049914155024453066, 0.10182427911786363, 0.05784917942946777, 0.049555916630197316, 0.04538186658464838, 0.040209190046880394, 0.03056700705201365, 0.05919267081480939, 0.07043546225759201, 0.07805988672771491, 0.15261422406183556, 0.12280060822376981, 0.10732305905548856, 0.1099294149025809, 0.21314274956239387, 0.08644125729915686, 0.1961509816464968, 0.17884154483908787, 0.09534509983495809, 0.14889333309838548, 0.17336900724330917, 0.16498984827194363, 0.17656479903962463, 0.09454465645831078, 0.19399202952627093, 0.21762628632131964, 0.1963009696919471, 0.14306441618828103, 0.10476937342900783, 0.0773660083359573, 0.14153427095152438, 0.11309384353808127, 0.18018429778749123, 0.10919387234025635, 0.1331071395543404, 0.120635488856351, 0.14531802182318643, 0.25555501983035356, 0.2533693058649078, 0.071351591614075, 0.07524785949499346, 0.1913343244814314, 0.15906857850495726, 0.10529788647545502, 0.12489885266404599, 0.1717717421706766, 0.10831093182787299, 0.15736696746898815, 0.16286099766148254, 0.30778894666582346, 0.15617746801581234, 0.13622697995742783, 0.15866531030042097, 0.18605142045998946, 0.16640297166304663, 0.1780188296106644, 0.10873766674194485, 0.11233807003009133, 0.12326295138336718, 0.16951276338659227, 0.11792931414674968, 0.10898621199885383, 0.11432922998210415, 0.18039217335171998, 0.13390744192292914, 0.8307662839069963, 2.3206335632130504, 6.482591321691871, 18.813242688775063, 45.38574121892452, 62.096442729234695, 78.35862010717392, 100.2532884478569, 109.08518493175507, 92.53662452101707, 95.5566568672657, 84.7597186267376, 63.1205789744854, 70.48118680715561, 77.2805267572403, 53.1681302189827, 32.496449053287506, 26.22882977128029, 33.605400547385216, 31.9268786162138, 35.51882207393646, 39.15270768105984, 58.52415181696415, 66.08258843421936, 43.035669922828674, 52.74942308664322, 47.58553817868233, 47.34227143228054, 41.88030771911144, 47.90276795625687, 28.320900611579418, 31.891168132424355, 45.585382506251335, 33.15379858016968, 22.595569230616093, 30.77581588178873, 39.29327353835106, 45.56664191186428, 27.95294925570488, 28.370736837387085, 26.344666555523872, 48.758124858140945, 52.215297147631645, 54.571201130747795, 56.70671693980694, 82.31796965003014, 106.38895601034164, 102.3949447274208, 104.92992550134659, 105.01722201704979, 101.19777336716652, 108.66591542959213, 110.18137291073799, 101.27259895205498, 94.50296580791473, 65.48704639077187, 38.570639714598656, 18.74780260026455, 5.0995291862636805, 1.4918406796641648, 0.252087646513246, 0.13190018478780985, 0.08824729593470693, 0.09992385414079763, 0.139175443619024, 0.18685941147850826, 0.19841643195832148, 0.2534318243851885, 0.25285802548751235, 0.18062082905089483, 0.19380941666895524, 0.16878801165148616, 0.10336620223824866, 0.13343282364076003, 0.14882829127600417, 0.11209961798158474, 0.10190898785367608, 0.12650428136112168, 0.22023900237400085, 0.1760675452533178, 0.10996350916684605, 0.15803092246642336, 0.12004769305349328, 0.13241005508461967, 0.22775508812628686, 0.12120630432036705, 0.13425356475636363, 0.08363723783986643, 0.11437312059570104, 0.08207564780605026, 0.1435007099644281, 0.09192635945510119, 0.1290954602882266, 0.18502032500691712, 0.07198946012067609, 0.19966899912105873, 0.19653452356578782, 0.08890351033187471, 0.18978589272592217, 0.11509259566082619, 0.08851342267007567, 0.21162029297556728, 0.1405690485262312, 0.26607846608385444, 0.19203191361157224, 0.09977514258935116, 0.113948330108542, 0.11500127438921481, 0.1877686462830752, 0.12222074597957544, 0.20499655074672773, 0.2836377691710368, 0.15269722585799173, 0.15371194953331724, 0.15128874831134453, 0.10205136146396399, 0.10032760474132374, 0.16404629655880854, 0.13342143909540027, 0.1409211233840324, 0.16176456352695823], [0.01958455359272193, 0.022774584467697423, 0.07296072362805717, 0.0010582034406070306, 0.01607281097676605, 0.02194004126067739, 0.03424591472139582, 0.04822471149964258, 0.03085719421505928, 0.03958339257223997, 0.02424076770694228, 0.016299876624543685, 0.06810934879467823, 0.05767890477727633, 0.03634410721133463, 0.016246189661615063, 0.011274149037490133, 0.1104252808727324, 0.06184609737829305, 0.01967057221918367, 0.03883763434714638, 0.03863408921461087, 0.04369809677882586, 0.05993557548208628, 0.07914190093288198, 0.07669274680665694, 0.005999143322696909, 0.033714915480231866, 0.014930604884284548, 0.04101124017324764, 0.03255772913689725, 0.08166662053554319, 0.08983656807686202, 0.05846225278219208, 0.0633294130966533, 0.05411384998296853, 0.011455080930318218, 0.011517589246068383, 0.023215045403048862, 0.11284073407296091, 0.0685267400695011, 0.018463001470081508, 0.031090050470083952, 0.03414382859773468, 0.0401365746074589, 0.04099027079064399, 0.046964448265498504, 0.05709385121008381, 0.04128147840674501, 0.06448792046285234, 0.03402812777494546, 0.028950950800208375, 0.04167581857473124, 0.4201992944581434, 6.165827494114637, 10.972391925752163, 22.42885697633028, 43.059920221567154, 57.24246919155121, 67.37720176577568, 74.47308540344238, 65.8704686164856, 78.70514631271362, 49.37599070370197, 55.9952013194561, 60.622471421957016, 50.20370028913021, 35.67479610443115, 38.57678398489952, 30.16753312200308, 31.220279932022095, 40.969272404909134, 37.70224191248417, 48.79739575088024, 52.229523584246635, 62.5329253077507, 80.43623462319374, 53.03489036858082, 74.13802698254585, 77.00083896517754, 83.93665999174118, 110.07422626018524, 100.68739995360374, 97.15358197689056, 83.0780428647995, 83.89113083481789, 84.06646102666855, 82.26813912391663, 84.64660629630089, 103.11197385191917, 70.9614810347557, 52.072569206357, 40.09207047522068, 56.147166565060616, 48.723387122154236, 42.2015006840229, 27.05920111387968, 20.11552970856428, 26.169123575091362, 19.662138037383556, 29.76809475570917, 39.76183019578457, 65.73437511920929, 62.199010625481606, 59.93002697825432, 64.08624395728111, 73.65068793296814, 71.9239541888237, 75.88834226131439, 85.6896199285984, 69.70124065876007, 74.52305272221565, 55.98959282040596, 37.3182725161314, 18.472072295844555, 4.888255773112178, 0.5218542006332427, 0.10961668129311875, 0.16478578734677285, 0.04868438292760402, 0.048387980277766474, 0.17869997274829075, 0.15628159133484587, 0.04579589964123443, 0.04416769072122406, 0.041695507752592675, 0.10886671137996018, 0.032806805029395036, 0.03543881692166906, 0.0974557529843878, 0.019618321312009357, 0.03312968750833534, 0.03424223366891965, 0.047465390525758266, 0.05948879515926819, 0.06661710503976792, 0.0019392325748412986, 0.02434667960187653, 0.08221480791689828, 0.050212787828058936, 0.06623408262385055, 0.034113270667148754, 0.043911037500947714, 0.04625107736501377, 0.037829397042514756, 0.07030636566923931, 0.02525256360968342, 0.034741799245239235, 0.034394841495668516, 0.06088433707191143, 0.005273062215565005, 0.0719490872870665, 0.059931783107458614, 0.09394935754244216, 0.0776734207465779, 0.04092005990969483, 0.006487424543593079, 0.04316799924708903, 0.04252887280017603, 0.02982577778311679, 0.06413856928702444, 0.02227637331088772, 0.038030530195101164, 0.03667935758130625, 0.07427162359817885, 0.006422709730031784, 0.06201473930559587, 0.04303469839214813, 0.008953835458669346, 0.06739168456988409, 0.003734118122338259, 0.03107431322860066, 0.018982504843734205, 0.01553394960865262, 0.038386679443647154, 0.05575172537646722, 0.0422405001881998, 0.09234752084012143, 0.0132899983873358, 0.06516991707030684, 0.021639202423102688, 0.03263374732341617, 0.0015727001004961494, 0.01287092800339451, 0.018266692277393304, 0.00509057459566975, 0.01507725512055913, 0.01929328474943759, 0.025310718301625457, 0.043610029824776575, 0.01857793231465621, 0.01560479595354991, 0.07453692654962651, 0.07024822582025081, 0.04041572974529117, 0.034511054400354624, 0.08134053568937816, 0.053013834985904396, 0.03936403969419189, 0.118413046002388, 0.09889194974675775, 0.011755344603443518, 0.07015640730969608, 0.03360448761668522, 0.020503215528151486, 0.008255768570961663, 0.0407964366604574, 0.13693475135369226, 0.02811664693581406, 0.028346588405838702, 0.027471063804114237, 0.007293385324373958, 0.03451195982052013, 0.01679353284998797, 0.0463887754449388, 0.012623993206943851, 0.10055418984848075, 0.10346881157602184, 0.04943090185406618, 0.03686225987621583, 0.0551860604173271, 0.07720531852100976, 0.05055186768004205, 0.022345923680404667, 0.10284720352501608, 0.04846797266509384, 0.013214976534072775, 0.04622319116606377, 0.12914272025227547, 0.32090302265714854, 5.189080405980349, 10.701771397143602, 22.396970987319946, 44.54314023256302, 64.37009632587433, 80.85127875208855, 86.91610291600227, 80.98711386322975, 91.71361148357391, 63.32246594130993, 70.44563591480255, 74.33751627802849, 63.74985180795193, 48.94252136349678, 44.3219693005085, 39.32499423623085, 39.38322991132736, 38.41161824762821, 26.72765750437975, 39.0898172557354, 43.21782074868679, 54.182360395789146, 54.61572714149952, 53.27577844262123, 68.37233036756516, 54.12586882710457, 58.368500769138336, 69.13173481822014, 62.06798605620861, 61.83051019906998, 63.76959174871445, 54.214662462472916, 64.38805416226387, 64.84305694699287, 53.2082636654377, 53.233935087919235, 54.07167613506317, 55.26478931307793, 41.76208086311817, 46.704718843102455, 37.91696839034557, 35.780521631240845, 37.634331956505775, 27.1843283995986, 32.21965670585632, 30.755359679460526, 46.48099824786186, 53.58768470585346, 82.39528030157089, 82.21368804574013, 75.95312878489494, 78.24410185217857, 83.81229266524315, 83.00027623772621, 86.64564102888107, 94.66785416007042, 80.31126692891121, 85.31031668186188, 62.799830585718155, 41.51873432099819, 20.129938535392284, 5.432263081893325, 0.5615739442873746, 0.11284659703960642, 0.17148917686427012, 0.022169398289406672, 0.024250942551589105, 0.11541230545844883, 0.06599099957384169, 0.06761830678442493, 0.05479247723997105, 0.030005147455085535, 0.0530997274472611, 0.010133794603461865, 0.022223200285225175, 0.08783658398897387, 0.02614668457681546, 0.12848645390477031, 0.038204400552785955, 0.032184417723328806, 0.019597528189478908, 0.023795581146259792, 0.02518040459108306, 0.03225200140150264, 0.1090405297873076, 0.0164818196935812, 0.06172730922116898, 0.012958241677551996, 0.011913964754057815, 0.02077559856843436, 0.010851503357116599, 0.0759255516459234, 0.0478881697927136, 0.029479295008059125, 0.05141762005223427, 0.061991450711502694, 0.04602959823387209, 0.04500805793213658, 0.030498777705361135, 0.009457289888814557, 0.07556413314887322, 0.03222962564905174, 0.04622907639713958, 0.04404131781484466, 0.009789075356820831, 0.07496398058719933, 0.10835348657565191, 0.05221347324550152, 0.06366242960211821, 0.035327439109096304, 0.06878728585434146, 0.041139038003166206, 0.02570506403571926, 0.05010912092984654, 0.005138245523994556, 0.013022025559621397, 0.018477660742064472, 0.054901539551792666, 0.012639120031963103, 0.03271671572292689, 0.013728766298299888, 0.036720572752528824, 0.11311060123261996, 0.1390753427403979, 0.13755999592831358, 0.12176934949820861, 0.09613399539375678, 0.11090582149336115, 0.1090171818214003, 0.08960357081377879, 0.13081972167128697, 0.17032406438374892, 0.14328931662021205, 0.0864221692609135, 0.13555327313952148, 0.19936744967708364, 0.1650131813948974, 0.07694529223954305, 0.0872442388208583, 0.2158516479539685, 0.16266953840386122, 0.14106946386164054, 0.13849749171640724, 0.15663469035644084, 0.09383508906466886, 0.23569908138597384, 0.23397243028739467, 0.14297308749519289, 0.14193666342180222, 0.2245108489296399, 0.29967872716952115, 0.08306078205350786, 0.18951174337416887, 0.21274504746543244, 0.16379378823330626, 0.08715680640307255, 0.14280828618211672, 0.09301941681769677, 0.09288899178500287, 0.10684896769816987, 0.14611390099162236, 0.20466251007746905, 0.2217466160072945, 0.17172877182019874, 0.135072628618218, 0.10213139466941357, 0.13832096447004005, 0.15335384843638167, 0.1455764821730554, 0.11902398939128034, 0.18170901050325483, 0.16619705536868423, 0.15900871687335894, 0.20859396317973733, 0.20852457237197086, 1.1190939811058342, 11.303316168487072, 20.146549344062805, 35.34547537565231, 56.986522525548935, 78.0899441242218, 94.06232625246048, 102.05267429351807, 92.82615378499031, 102.48658061027527, 68.9246991276741, 81.53153344988823, 83.34218949079514, 74.2060661315918, 56.66885957121849, 56.77058011293411, 44.60562787950039, 45.712671875953674, 56.05988524854183, 50.943262204527855, 65.00203281641006, 72.23775655031204, 83.8699659705162, 103.74409273266792, 75.03217980265617, 102.47892782092094, 101.69745415449142, 110.36627098917961, 142.3046287894249, 130.6807029247284, 126.85124561190605, 109.17123511433601, 113.12445178627968, 112.48445212841034, 113.49934726953506, 114.03574928641319, 137.0579919219017, 96.36614263057709, 76.07942640781403, 59.50064241886139, 81.55202195048332, 65.11451438069344, 61.23239949345589, 41.84062644839287, 34.00440573692322, 38.048992305994034, 34.833631440997124, 44.661302492022514, 57.8975198417902, 85.5315712094307, 85.22616639733315, 82.00221419334412, 87.28326201438904, 97.51452460885048, 93.56027439236641, 97.02243581414223, 105.86808755993843, 93.83019670844078, 102.26985543966293, 79.02675345540047, 60.88186450302601, 34.55242373049259, 13.982289265841246, 2.7314710803329945, 0.22663248586468399, 0.4209203354548663, 0.14111219672486186, 0.20396597479702905, 0.2638543088687584, 0.31962195702362806, 0.13027033943217248, 0.14737716992385685, 0.13267437840113416, 0.4269802087219432, 0.04812373488675803, 0.12699243641691282, 0.22291147615760565, 0.12469637993490323, 0.25213075045030564, 0.10966456466121599, 0.1416744032758288, 0.09203767418512143, 0.13170057674869895, 0.08069235133007169, 0.1339745766017586, 0.15260258718626574, 0.1463219992001541, 0.129078064346686, 0.05980931760859676, 0.1623035260126926, 0.1147898513590917, 0.1401665373123251, 0.1346944598481059, 0.1650130923371762, 0.21877801045775414, 0.18654398387297988, 0.39394071442075074, 0.16164758621016517, 0.1618669056915678, 0.1254404423525557, 0.31763944309204817, 0.17141398246167228, 0.1976482942700386, 0.10368303992436267, 0.12684436311246827, 0.08464292957796715, 0.06390299677150324, 0.25419231795240194, 0.141305823053699, 0.13412302098004147, 0.25204115838278085, 0.20392211386933923, 0.1424279948696494, 0.13526346447179094, 0.21697255811886862, 0.19998507981654257, 0.1397733177873306, 0.1503774058073759, 0.08238562062615529, 0.09230710347765125, 0.1153971285384614, 0.09300040299422108, 0.1194664578360971], [0.026322640369471628, 0.05991894024191424, 0.0410234447917901, 0.004713644748335355, 0.13805952068651095, 0.039931292849360034, 0.045820995364920236, 0.023968464447534643, 0.10587023818516172, 0.05547954271605704, 0.05741406566812657, 0.01617308626009617, 0.08430900765233673, 0.03560770375770517, 0.009791778629733017, 0.05324069097696338, 0.05118080443935469, 0.002974848866870161, 0.03171479780576192, 0.017950251640286297, 0.005947500048932852, 0.0697761531046126, 0.11574282092624344, 0.03674078885524068, 0.06713565846439451, 0.01526357500551967, 0.022950868660700507, 0.031165842301561497, 0.04460245567315724, 0.03595566340663936, 0.05093017374747433, 0.018723018474702258, 0.06339389830827713, 0.07295200339285657, 0.0498552322096657, 0.020639136164390948, 0.051082280624541454, 0.02505355114408303, 0.01307556873143767, 0.03200620580173563, 0.036901823768857867, 0.016372529171349015, 0.0687387197103817, 0.036521551010082476, 0.06640925916144624, 0.06367596637574024, 0.031985978566808626, 0.022943382246012334, 0.016509034248883836, 0.009271852231904631, 0.10325715848011896, 0.6777644657995552, 6.647470174357295, 29.58421502262354, 48.60590882599354, 57.940837517380714, 66.8043065071106, 71.17870777845383, 74.38097074627876, 65.51654800772667, 58.258899450302124, 38.664931654930115, 38.88240158557892, 35.419985577464104, 28.29546667635441, 29.00725968182087, 29.387499578297138, 24.033225886523724, 35.60735732316971, 62.01340198516846, 69.54419508576393, 76.7195476591587, 104.29705426096916, 78.99054899811745, 77.25887551903725, 75.86260244250298, 76.13061726093292, 64.89403501152992, 46.21598146855831, 58.004567697644234, 65.29369756579399, 48.15342530608177, 53.54096241295338, 46.64166882634163, 42.88765266537666, 67.33848944306374, 52.767711505293846, 43.59010197222233, 61.539723202586174, 56.28889515995979, 63.94076496362686, 72.56371825933456, 68.17768201231956, 65.06742730736732, 89.26476448774338, 116.80330038070679, 95.5597423017025, 92.3814332485199, 80.81663221120834, 74.57940369844437, 32.09756925702095, 25.370142348110676, 22.78278898447752, 16.556967459619045, 23.95434971898794, 24.66653600335121, 40.64914718270302, 48.65225113928318, 51.59238897264004, 57.499593794345856, 61.56839266419411, 64.17934656143188, 68.86429756879807, 69.83536586165428, 65.0078997015953, 47.32953071594238, 25.177808068692684, 8.291704170405865, 0.9501708392053843, 0.18127906951121986, 0.08812784726615064, 0.03752877899387386, 0.028243218366696965, 0.1282847233233042, 0.04840245957893785, 0.09404639335116372, 0.037403151945909485, 0.016657634478178807, 0.019720053060154896, 0.043941988769802265, 0.054065714284661226, 0.008373721811949508, 0.025939690312952735, 0.04579425207339227, 0.0801516225328669, 0.03795186254137661, 0.03542764017765876, 0.055520928581245244, 0.021018408879172057, 0.05643314681947231, 0.01728701467072824, 0.10424348758533597, 0.042210907049593516, 0.039190098832477815, 0.045954871384310536, 0.029945040914753918, 0.054545297534787096, 0.0586697795370128, 0.03518770754453726, 0.058084384581889026, 0.05357780413760338, 0.03938015172025189, 0.023954612261150032, 0.05801535000500735, 0.029814319022989366, 0.008782713830441935, 0.031040847934491467, 0.019036119447264355, 0.03942468058085069, 0.043291336769470945, 0.0744815549114719, 0.046590925339842215, 0.029336292427615263, 0.024200424559239764, 0.0026116965273104142, 0.01604649813089054, 0.05997959597152658, 0.06367071197018959, 0.040842008238541894, 0.04523904026427772, 0.02060366707155481, 0.021137766634637956, 0.04051285832247231, 0.0656855761189945, 0.046524607023457065, 0.04641398620151449, 0.08052879682509229, 0.057561652865842916, 0.027931147124036215, 0.037180062354309484, 0.030131722596706823, 0.023742771772958804, 0.14398013736354187, 0.041833365394268185, 0.08146545398631133, 0.009175886971206637, 0.02311316151462961, 0.04858242296904791, 0.0707072218938265, 0.010247804257232929, 0.05845586289069615, 0.030299017525976524, 0.04756857131724246, 0.0358350569877075, 0.029548001184593886, 0.005481391417561099, 0.07423986709909514, 0.09525134431896731, 0.027068214913015254, 0.0233902776017203, 0.059329526557121426, 0.02635086053487612, 0.019334830176376272, 0.025510489613225218, 0.022942612267797813, 0.026197217412118334, 0.021826082629559096, 0.02484297045157291, 0.07119199275621213, 0.021924426473560743, 0.104120691830758, 0.020680093439295888, 0.0223128071957035, 0.024198042265197728, 0.019560480177460704, 0.030273383745225146, 0.055673959432169795, 0.04595723883539904, 0.0570050161331892, 0.0747507912456058, 0.02821805956045864, 0.04698435266618617, 0.03394528182980139, 0.02890772626415128, 0.024734633589105215, 0.04345238281530328, 0.03240668724174611, 0.482780808233656, 6.8824229668825865, 30.77602107077837, 52.093084305524826, 63.62472452223301, 76.5693037211895, 81.52685970067978, 86.80671438574791, 78.61799418926239, 74.35367301106453, 49.00456443428993, 57.986226081848145, 43.82336385548115, 44.63650122284889, 45.92927545309067, 46.822026148438454, 43.864967823028564, 41.39480397105217, 44.36954274773598, 53.18638823926449, 62.65763081610203, 68.11541855335236, 66.64886444807053, 58.16333457827568, 62.99186088144779, 59.1227412968874, 57.66070134937763, 49.901909083127975, 54.92874674499035, 54.947548136115074, 49.42351475358009, 48.6622180044651, 49.89420309662819, 41.821578070521355, 56.31744682788849, 47.09179267287254, 41.776052713394165, 51.92745499312878, 52.74690382182598, 51.606896594166756, 51.69168144464493, 48.59732888638973, 60.08742593228817, 71.86085477471352, 73.93881887197495, 58.08758944272995, 64.10256028175354, 65.44717133045197, 61.34210340678692, 32.189448326826096, 33.60734224319458, 36.24758496880531, 24.534403793513775, 37.93123662471771, 42.18534015119076, 57.66227446496487, 61.72727353870869, 66.83400571346283, 70.46786472201347, 74.86711665987968, 74.30089384317398, 78.83797958493233, 78.54196786880493, 73.39358612895012, 55.174555554986, 27.03901469707489, 9.475471749901772, 1.4533912553451955, 0.1794654832337983, 0.16767148015787825, 0.042755350295919925, 0.03821206322754733, 0.004792678373632953, 0.03618327267759014, 0.04667471752327401, 0.027571212922339328, 0.03202245512511581, 0.032212830847129226, 0.10372271513915621, 0.007410807002088404, 0.04276718755136244, 0.0037913847882009577, 0.06126611267973203, 0.019086913889623247, 0.040235907363239676, 0.013437118959700456, 0.040122228892869316, 0.14063937444007024, 0.038968445296632126, 0.009421005361218704, 0.08251242397818714, 0.034138633563998155, 0.0025696703278299537, 0.05497993261087686, 0.008697049579495797, 0.04131512367166579, 0.05709396253223531, 0.03669706522487104, 0.04600247644702904, 0.01635270640690578, 0.027669005721691065, 0.04789835948031396, 0.015477538963750703, 0.015699959694757126, 0.028780826432921458, 0.0493644351081457, 0.0746888441790361, 0.007161053435993381, 0.04330356736318208, 0.03601580705435481, 0.009054340807779226, 0.03194719763996545, 0.00657559122373641, 0.054862246543052606, 0.017599872589926235, 0.05693243037967477, 0.05922975222347304, 0.05132550839334726, 0.05149521901330445, 0.016957272891886532, 0.04225833028613124, 0.031658988300478086, 0.06984118008404039, 0.03102203078015009, 0.07445844443282112, 0.16422464948846027, 0.1799528961419128, 0.13947979838121682, 0.07901278950157575, 0.18857914576074108, 0.14447642635786906, 0.14628284348873422, 0.1829461261513643, 0.13532782351830974, 0.14227126812329516, 0.18204158172011375, 0.12780268356436864, 0.18925003241747618, 0.10080535488668829, 0.149451294564642, 0.0877733010565862, 0.1309342499007471, 0.1422038662713021, 0.11355893264408223, 0.09056801398401149, 0.16765067033702508, 0.20973802835214883, 0.18157417711336166, 0.11971613857895136, 0.18265986494952813, 0.15495155879762024, 0.10076579099404626, 0.15836367179872468, 0.13486634125001729, 0.13038728706305847, 0.11391488151275553, 0.15058321820106357, 0.19231458281865343, 0.2943558065453544, 0.2000494537060149, 0.12543971504783258, 0.13409910898189992, 0.12857876223279163, 0.09862939274171367, 0.11890433292137459, 0.09874598414171487, 0.059807777652167715, 0.16489887580974028, 0.17303870699834079, 0.14449250127654523, 0.17978187563130632, 0.09166332747554407, 0.09625515100196935, 0.1555218399153091, 0.18171699601225555, 0.23537568311439827, 2.0158393308520317, 13.507263455539942, 44.63758036494255, 67.21944943070412, 78.7311065196991, 87.34901368618011, 91.1280021071434, 98.55717346072197, 90.12450635433197, 81.18093386292458, 56.54436305165291, 59.13332372903824, 56.00689709186554, 44.98402297496796, 45.24995930492878, 48.89381177723408, 44.39020983874798, 57.51016862690449, 86.48622438311577, 93.55672538280487, 102.14804157614708, 136.84948951005936, 105.47687575221062, 104.31472331285477, 97.63741761445999, 98.93918216228485, 85.22500365972519, 68.69259998202324, 76.79210096597672, 86.21488854289055, 65.36863714456558, 74.5836290717125, 65.48756316304207, 60.60394361615181, 93.37788417935371, 71.90681710839272, 60.634562373161316, 84.64751824736595, 79.2480231821537, 82.85827025771141, 94.95980009436607, 86.82638213038445, 86.83078229427338, 113.43177929520607, 142.26199507713318, 116.52803555130959, 115.87664410471916, 101.46166920661926, 95.7701826095581, 45.10352276265621, 42.07923084497452, 40.964659452438354, 29.194984808564186, 41.3174819201231, 39.04235020279884, 60.426048561930656, 71.0467180609703, 73.67588818073273, 79.22459363937378, 83.29189538955688, 86.31369844079018, 91.4768385887146, 90.15138611197472, 88.33958253264427, 71.21852964162827, 42.51391611993313, 17.312524616718292, 3.7345334189012647, 0.6354647199623287, 0.34156316716689616, 0.22306965751340613, 0.16361476737074554, 0.16311650426359847, 0.1786273907055147, 0.18643021263414994, 0.04762202450365294, 0.12231969652930275, 0.09896765623125248, 0.2152144696447067, 0.12572900421218947, 0.07346209633396938, 0.21208535239566118, 0.1025890103483107, 0.2180678938748315, 0.12071559627656825, 0.22834233473986387, 0.1467667386168614, 0.21562057285336778, 0.16940950095886365, 0.14626905438490212, 0.14380709821125492, 0.15123589255381376, 0.153770876058843, 0.21754093933850527, 0.12728546600556, 0.18706792528973892, 0.17328610934782773, 0.11932092267670669, 0.11619113749475218, 0.08787957660388201, 0.07529185400926508, 0.09795286576263607, 0.10331136494642124, 0.1184724697668571, 0.10418358884635381, 0.19732467335416004, 0.1282968945452012, 0.1659853948513046, 0.06425403262255713, 0.15239877859130502, 0.08911543802241795, 0.10998675323207863, 0.06811228027800098, 0.16555622569285333, 0.12109889328712597, 0.23329035204369575, 0.17316591111011803, 0.17917117715114728, 0.13258674560347572, 0.08157564065186307, 0.11733487612218596, 0.1568069725180976, 0.2098108033533208, 0.11578069272218272, 0.15829435520572588], [0.04947069210174959, 0.05202730550081469, 0.024964712356450036, 0.02220048500021221, 0.09839546037255786, 0.00868276045366656, 0.03369901125552133, 0.015245790364133427, 0.02911542742367601, 0.02469279686920345, 0.037506340158870444, 0.020853396054008044, 0.021980326891934965, 0.02098865617881529, 0.02570365209976444, 0.06032513250829652, 0.04532641702098772, 0.05155251652467996, 0.060607430641539395, 0.0540213672502432, 0.01704629907180788, 0.020304995305195916, 0.030500074608426075, 0.07035215618088841, 0.07211708725662902, 0.08416578799369745, 0.03254500501498114, 0.04917686841508839, 0.03587508472264744, 0.02137186413165182, 0.026715626117947977, 0.05502231295395177, 0.007665513476240449, 0.005599002806775388, 0.05107210577989463, 0.045725711024715565, 0.03373386993189342, 0.08844325260724872, 0.04990190216631163, 0.02588047991594067, 0.027858906469191425, 0.0804525708372239, 0.04752394226670731, 0.017440741285099648, 0.06656366298557259, 0.04519051122770179, 0.009652018306951504, 0.0589035597658949, 0.08425260442891158, 1.2844328465871513, 9.682628083974123, 33.6135359108448, 54.472775012254715, 61.96667209267616, 71.66648000478745, 76.89312234520912, 62.11017519235611, 52.80938766896725, 44.99416083097458, 37.99446143209934, 30.80539159476757, 28.306767269968987, 24.851188994944096, 30.445317216217518, 31.060232520103455, 34.29315984249115, 18.485468477010727, 34.90396186709404, 39.55309599637985, 39.522758424282074, 60.11011451482773, 56.964202523231506, 46.485219821333885, 40.09224146604538, 38.68306428194046, 24.18281625956297, 17.81639087945223, 15.328842960298061, 11.883329395204782, 6.109116962179542, 2.836858187802136, 3.534582923166454, 3.4357592510059476, 2.8616556571796536, 2.819189135916531, 1.7996582435443997, 2.1740960888564587, 3.4549071360379457, 3.0240337690338492, 3.280956270173192, 6.984853595495224, 9.86957710236311, 15.160606987774372, 19.992669001221657, 30.713238939642906, 47.14504301548004, 66.49450153112411, 66.15365222096443, 73.4030856192112, 74.96062204241753, 79.82252955436707, 58.20122994482517, 41.79977864027023, 55.67533068358898, 47.49073326587677, 29.12987530231476, 23.527564220130444, 19.357221499085426, 15.037138313055038, 26.305395662784576, 35.24654768407345, 61.82972364127636, 76.01020932197571, 71.94978520274162, 68.30826580524445, 78.51226106286049, 75.05273669958115, 60.59126749634743, 32.907697185873985, 17.74275653064251, 3.390514603815973, 0.3780911711510271, 0.3188733971910551, 0.03203530912287533, 0.08821360985166393, 0.04065968852955848, 0.019792759412666783, 0.030150530474202242, 0.03826757216302212, 0.01489944952481892, 0.009441481215617387, 0.044568472731043585, 0.08511290201568045, 0.043697473374777474, 0.0796086821355857, 0.03848075408313889, 0.0658036295499187, 0.02272121848363895, 0.017178379093820695, 0.027371807118470315, 0.04842906928388402, 0.018708357347350102, 0.04516026128840167, 0.020503614432527684, 0.05626484256936237, 0.07909923486295156, 0.048923131835181266, 0.02093010814860463, 0.030113089123915415, 0.034802480950020254, 0.04125160696275998, 0.02553514190367423, 0.0322417634743033, 0.08395141121582128, 0.054614105756627396, 0.009548528596496908, 0.008363587785424897, 0.06889280441100709, 0.04929560833261348, 0.05252844814094715, 0.03950504775275476, 0.028972204054298345, 0.06894534846651368, 0.020178648373985197, 0.022999418106337544, 0.04230667378578801, 0.049128031387226656, 0.011088244755228516, 0.013972862379887374, 0.039659904286963865, 0.05646755649650004, 0.03956819338782225, 0.046676535785081796, 0.04001691071607638, 0.042863889393629506, 0.05508597438165452, 0.01876697402622085, 0.0686543078336399, 0.04178001239779405, 0.07099687471054494, 0.08236521898652427, 0.07920467178337276, 0.007983330797287636, 0.08051170516409911, 0.03439509753661696, 0.028858850273536518, 0.030196198531484697, 0.03750813986698631, 0.00374362804905104, 0.03810154630627949, 0.022061115232645534, 0.04026621667435393, 0.02392744780081557, 0.06005597781040706, 0.05084637785330415, 0.04476685251574963, 0.05783231412351597, 0.0277268283025478, 0.030022198297956493, 0.0311341711494606, 0.01622853767912602, 0.06575306702870876, 0.03553949667548295, 0.03870090476993937, 0.046284626150736585, 0.07199481100542471, 0.05071446852525696, 0.04710854736913461, 0.014182311297190608, 0.031704500506748445, 0.07724921655608341, 0.013720380957238376, 0.06413321840227582, 0.11286533626844175, 0.012241879921930376, 0.05813269097416196, 0.0424166489392519, 0.07286495689186268, 0.038095586860436015, 0.04545517593214754, 0.06777502610930242, 0.04960593367286492, 0.02717789691814687, 0.05325502927007619, 0.10889190729358234, 1.1995811434462667, 9.258662033826113, 36.18464134633541, 61.28119647502899, 71.00116610527039, 80.23291513323784, 86.73598498106003, 71.92475214600563, 62.85518981516361, 59.28476460278034, 53.03620509803295, 46.127583011984825, 42.176916003227234, 38.70892949402332, 42.121298387646675, 32.85378947854042, 30.76362993568182, 26.031268872320652, 35.71404419839382, 42.865024879574776, 45.15217915177345, 57.19706542789936, 54.42650869488716, 46.16665631532669, 40.41452877223492, 32.26818390190601, 24.079507403075695, 20.30603628605604, 17.524291053414345, 13.602103516459465, 9.69180554151535, 5.203486382961273, 4.460943527519703, 4.447139343246818, 3.7846762407571077, 4.070150647312403, 3.0174489598721266, 3.13528586179018, 4.226610101759434, 3.8588242745026946, 4.429006241261959, 7.184784142300487, 9.7545325756073, 13.319723568856716, 17.30798576027155, 25.605811402201653, 42.00147941708565, 56.8369397521019, 58.5390318185091, 60.53000718355179, 66.9173276424408, 57.49193340539932, 54.98938009142876, 40.400488525629044, 46.77080109715462, 44.8193322122097, 31.146626584231853, 35.458420515060425, 36.05302020907402, 24.173620752990246, 38.99551771581173, 48.26130911707878, 71.16260424256325, 88.90588894486427, 80.64770087599754, 80.04055425524712, 90.65482869744301, 86.9788907468319, 68.8456329703331, 40.727890357375145, 20.033380016684532, 4.734690813347697, 0.320442623924464, 0.2860444353427738, 0.038395733645302244, 0.035245424369350076, 0.08399482685490511, 0.03882089520629961, 0.026702859322540462, 0.016411324941145722, 0.022655271241092123, 0.048988863854901865, 0.04001508132205345, 0.039257623138837516, 0.03411643221625127, 0.018458043923601508, 0.014594978802051628, 0.020804041378141847, 0.03268706321250647, 0.0356962234218372, 0.061455326940631494, 0.07221752952318639, 0.015359677563537844, 0.009047675393958343, 0.010159426528844051, 0.05248948909866158, 0.030889436820871197, 0.024004462320590392, 0.04575930433929898, 0.043677702560671605, 0.03693263031891547, 0.036547073468682356, 0.03754518045752775, 0.011933934092667187, 0.017797517648432404, 0.014595922257285565, 0.03180326923029497, 0.011698338385031093, 0.04159659059951082, 0.01908682483190205, 0.02205865501309745, 0.043797485195682384, 0.07334315974730998, 0.040820114882080816, 0.07671569401281886, 0.025581644877092913, 0.0825126540439669, 0.009545216762489872, 0.040537924360251054, 0.07710737729212269, 0.023338494247582275, 0.05942619500274304, 0.021375266878749244, 0.021619446451950353, 0.041562937913113274, 0.013913947914261371, 0.06730573644745164, 0.10188345797359943, 0.23911328724352643, 0.08283083501737565, 0.1551012202980928, 0.23603864363394678, 0.10786142040160485, 0.06333245590212755, 0.16496497148182243, 0.10026098956586793, 0.14556294539943337, 0.12117576494347304, 0.15093321504537016, 0.05488200251420494, 0.1647689109086059, 0.13196587970014662, 0.12357707280898467, 0.16579347546212375, 0.1750545433606021, 0.18587584316264838, 0.16953167330939323, 0.10372847420512699, 0.1579965016571805, 0.13362653902731836, 0.14444788335822523, 0.0947227051074151, 0.16309370548697188, 0.11600906640524045, 0.14765853295102715, 0.07879936267272569, 0.1283181644976139, 0.1843049837043509, 0.16092183999717236, 0.13213716738391668, 0.10115618293639272, 0.1379100966732949, 0.2079653344117105, 0.19251006451668218, 0.16881125571671873, 0.09959557995898649, 0.07911058972240426, 0.13102174911182374, 0.1668084366247058, 0.10007007949752733, 0.1610022145905532, 0.3089922945946455, 0.10669221126590855, 0.20131825905991718, 0.20579781790729612, 0.3468384419102222, 2.711387020535767, 15.932251531630754, 49.415481984615326, 77.87614479660988, 84.30124282836914, 93.45759630203247, 96.73398569226265, 83.42871084809303, 73.08995202183723, 65.23568987846375, 55.71956790983677, 49.5480340719223, 45.503960475325584, 40.048684403300285, 49.59607109427452, 45.204498544335365, 51.91402271389961, 32.04762473702431, 54.0307941287756, 61.877373084425926, 61.87590256333351, 83.89946758747101, 78.42999547719955, 63.15867193043232, 54.27249535918236, 50.34273862838745, 34.495848566293716, 25.70961993187666, 22.334458641707897, 17.354922741651535, 10.83175577223301, 5.428790543228388, 5.316981542855501, 4.780781390145421, 4.825091287493706, 4.64894556440413, 3.177189538255334, 3.406134615652263, 5.18887996673584, 4.627676205709577, 4.757740376517177, 9.88078935071826, 13.747073337435722, 20.260761715471745, 28.041140623390675, 38.92559006810188, 63.00351485610008, 89.74368318915367, 83.96807670593262, 96.89902603626251, 100.27046352624893, 104.08858224749565, 81.31124407052994, 67.21560403704643, 82.48082131147385, 64.29125055670738, 43.24712477624416, 37.38405458629131, 33.796317502856255, 27.844932451844215, 43.877393156290054, 54.38733659684658, 85.31670793890953, 98.07017639279366, 94.27726551890373, 89.04879927635193, 102.14032799005508, 98.78914341330528, 86.76463544368744, 57.91897349059582, 31.00596383213997, 8.957005720585585, 0.8063538407441229, 0.4657821828732267, 0.19339375459821895, 0.1593774455250241, 0.3323263971833512, 0.08687478286447003, 0.14087414543610066, 0.08838995898258872, 0.10181981138885021, 0.17532619909616187, 0.23940122569911182, 0.26397026202175766, 0.15288270340533927, 0.14116101519903168, 0.11125942517537624, 0.19529734854586422, 0.10149109191843309, 0.1584290253231302, 0.2851784380618483, 0.2651955478359014, 0.11634042049990967, 0.12204972546896897, 0.07449484677636065, 0.14781433943426237, 0.13936534436652437, 0.18353407038375735, 0.12299827925744466, 0.1725878077559173, 0.10670872405171394, 0.1056011428590864, 0.11328599299304187, 0.15279318555258214, 0.22020768374204636, 0.15568175789667293, 0.0545636656897841, 0.14416554069612175, 0.15340896032284945, 0.1591840566834435, 0.13904182735132053, 0.08383516120375134, 0.12914429360534996, 0.12677777762291953, 0.1599293213803321, 0.12464724975870922, 0.15848591836402193, 0.1384325241087936, 0.07819456426659599, 0.10750292596640065, 0.09919679432641715, 0.11524469140567817, 0.14015294116688892, 0.16365030140150338, 0.13815988873830065, 0.10475441173184663, 0.14539768395479769], [0.029223283745523077, 0.048683013665140606, 0.06760732299881056, 0.05496695244801231, 0.03276502953667659, 0.06877040199469775, 0.018995980390172917, 0.05456083810713608, 0.047266995898098685, 0.018774519812723156, 0.05449099830002524, 0.07398182977340184, 0.04861736699240282, 0.0642302467895206, 0.051072929563815705, 0.023858559798100032, 0.014046585474716267, 0.02037563106568996, 0.026327527411922347, 0.04476826259633526, 0.03118995467957575, 0.07606916464283131, 0.003129291885670682, 0.02669452685950091, 0.02181846633902751, 0.026405913049529772, 0.04885592294158414, 0.05125472605868708, 0.043182363515370525, 0.02983150345244212, 0.04213429885567166, 0.03496896322758403, 0.038327879083226435, 0.03516002914693672, 0.027573170336836483, 0.0740663158649113, 0.01634604934224626, 0.06021089000569191, 0.01815000068745576, 0.06529272024636157, 0.058544686835375614, 0.050181688129669055, 0.05475741076224949, 0.00919300089663011, 0.05907206439587753, 0.013922231210017344, 0.2822661615209654, 1.1515236971899867, 8.792243711650372, 30.439944304525852, 55.19064009189606, 68.76167267560959, 73.44889596104622, 80.30471608042717, 65.82813888788223, 45.36750599741936, 37.511286959052086, 31.52844339609146, 23.71317096054554, 29.368037022650242, 25.477444790303707, 22.530433125793934, 50.178184658288956, 43.257897198200226, 67.37073451280594, 62.81723365187645, 66.01355373859406, 70.01456424593925, 42.00573518872261, 29.873109720647335, 21.49259101599455, 17.88139209151268, 13.35882917046547, 9.110276196151972, 3.4108579996973276, 2.2142129112035036, 1.182393478229642, 0.5980319785885513, 0.13369005202548578, 0.09269609276088886, 0.034305364461033605, 0.06442595855332911, 0.0420942748314701, 0.027887455034942832, 0.04878843203186989, 0.05587632083916105, 0.12924020877107978, 0.06184316960570868, 0.019031150768569205, 0.04597555875079706, 0.045036845840513706, 0.09014021037728526, 0.14403658511582762, 0.8720397879369557, 2.6443959027528763, 3.7070965161547065, 4.580702176317573, 10.61823382973671, 21.608139015734196, 27.469096519052982, 46.04829266667366, 57.49326333403587, 50.71669936180115, 50.62020353972912, 63.60757224261761, 76.60082682967186, 50.279757007956505, 24.794148355722427, 27.392657920718193, 20.158102624118328, 22.455883026123047, 26.841043420135975, 36.51148080825806, 46.53018280863762, 55.06673254072666, 63.32967035472393, 71.54531970620155, 76.46809995174408, 72.41343632340431, 74.86017063260078, 51.32235646247864, 31.091267354786396, 7.43933723308146, 0.43856486678123474, 0.07497670841985382, 0.1394976396113634, 0.043229426810285076, 0.02807714612572454, 0.06862855530926026, 0.0566877999517601, 0.011356814084138023, 0.03793317897361703, 0.049397160109947436, 0.03569251268345397, 0.07652391563169658, 0.030145769596856553, 0.017997864124481566, 0.014782898015255341, 0.008995418920676457, 0.023956196746439673, 0.029229074352770112, 0.09330541084636934, 0.03323991499200929, 0.012791763110726606, 0.04669497815484647, 0.027644253241305705, 0.026321055884181987, 0.030215431288524996, 0.04763570599607192, 0.02842731737473514, 0.08253825071733445, 0.024659570917719975, 0.026657107773644384, 0.05586505874816794, 0.029254094006319065, 0.030323013015731703, 0.013279921877256129, 0.0181912232801551, 0.08266735472716391, 0.05109755773446523, 0.03951857339416165, 0.024297959462273866, 0.056590252061141655, 0.057962431164924055, 0.012769941185979405, 0.03318397932162043, 0.048737843535491265, 0.026126666998607107, 0.07768751413095742, 0.015620262311131228, 0.02244443636300275, 0.025966897446778603, 0.035100186069030315, 0.018555834867584053, 0.04925747307424899, 0.04013408470200375, 0.07427268486935645, 0.028566696419147775, 0.05960765753115993, 0.06392725757905282, 0.04952671682985965, 0.03951856597268488, 0.06586229632375762, 0.02061089558992535, 0.04028499301057309, 0.05241207567451056, 0.06072846008464694, 0.0520628469530493, 0.03722259483765811, 0.04765270488860551, 0.06389383124769665, 0.04010564931377303, 0.01831652563851094, 0.018288351857336238, 0.0802967198251281, 0.07310906410566531, 0.04730473410745617, 0.035142521883244626, 0.05944371339865029, 0.03646481010946445, 0.03544616047292948, 0.14100480795605108, 0.05613100736809429, 0.08974773299996741, 0.04642920022888575, 0.025195395974151324, 0.007596734012622619, 0.12949509196914732, 0.0175640045927139, 0.027687665169651154, 0.0691478731459938, 0.03748628732864745, 0.10123076877789572, 0.14186550630256534, 0.05133717866556253, 0.02493758871423779, 0.05278729440760799, 0.03610548075812403, 0.11319621538859792, 0.009230061896232655, 0.046609620039816946, 0.031563852389808744, 0.05787904345197603, 1.0482619819231331, 9.361002892255783, 35.67718617618084, 62.16493025422096, 76.43260985612869, 82.21926614642143, 86.81774139404297, 73.56634765863419, 61.35188788175583, 51.199634447693825, 47.25662022829056, 39.29413229227066, 38.79747234284878, 30.083477832376957, 28.561330810189247, 45.71522913873196, 39.06410023570061, 52.806762009859085, 58.11537355184555, 44.68192778527737, 57.61177137494087, 45.80551229417324, 36.491277292370796, 28.194236308336258, 22.315995432436466, 16.869532987475395, 11.081761457026005, 4.970158478245139, 2.9377140384167433, 1.8539807223714888, 0.8783247694373131, 0.34468410594854504, 0.07180080618127249, 0.0964404949627351, 0.07405297947116196, 0.14808988402364776, 0.051700675176107325, 0.16755119286244735, 0.09295302428654395, 0.025097853649640456, 0.03658277819340583, 0.04682660546677653, 0.06826242417446338, 0.07924341189209372, 0.08650989853776991, 0.10279023626935668, 0.8604665589518845, 2.138232900761068, 4.13112455047667, 4.824677109718323, 9.936003237962723, 20.5395470559597, 28.617554493248463, 46.045226231217384, 52.93572708964348, 51.12165503203869, 59.39294099807739, 61.3884799182415, 61.605813056230545, 48.321896865963936, 25.619935244321823, 36.35747887194157, 31.4845709502697, 31.83416549116373, 40.691051334142685, 48.77696044743061, 61.28084309399128, 64.64764103293419, 71.36031523346901, 79.03380587697029, 85.96698984503746, 81.66257321834564, 85.51577165722847, 62.74820275604725, 36.83545522391796, 10.277067236602306, 0.4277360119158402, 0.12308882869547233, 0.08507729377015494, 0.04704168728494551, 0.041389861653442495, 0.06217960370122455, 0.043209503855905496, 0.046157577889971435, 0.044526092387968674, 0.016296963694912847, 0.034899268139270134, 0.09374273620778695, 0.024538571160519496, 0.06166787803522311, 0.07522617393988185, 0.0900306025869213, 0.014676348801003769, 0.006238223877517157, 0.07162487265304662, 0.015816057566553354, 0.021197290589043405, 0.025746666979102883, 0.06022297959134448, 0.026938676746794954, 0.07740098575595766, 0.08590392011683434, 0.03545632789609954, 0.0659718744282145, 0.019385567102290224, 0.02288065035827458, 0.01027792339300504, 0.020907266698486637, 0.044762184406863526, 0.02978897282446269, 0.10033545666374266, 0.0295151982572861, 0.09728403485496528, 0.0900035141967237, 0.052062197573832236, 0.04753345659992192, 0.042836162756429985, 0.0608310286042979, 0.018679168679227587, 0.059258577239234, 0.05989359589875676, 0.020768364483956248, 0.04738514580822084, 0.004864032625846448, 0.0764205789892003, 0.03387229531654157, 0.012976903908565873, 0.01700263295788318, 0.04052415752084926, 0.12673537130467594, 0.1223029314132873, 0.17377809388563037, 0.16809621127322316, 0.1258259583846666, 0.16969564341707155, 0.1301012039766647, 0.17908385605551302, 0.12762339552864432, 0.15538526989985257, 0.1813258248148486, 0.13048801134573296, 0.14547528291586787, 0.16780123725766316, 0.16214469156693667, 0.14123677363386378, 0.1436532658408396, 0.1506933380733244, 0.1203019380045589, 0.14793732814723626, 0.08103258893243037, 0.15519248961936682, 0.1346530776936561, 0.1064312647213228, 0.08917024562833831, 0.2451956772711128, 0.10544880962697789, 0.21818350563989952, 0.15395955968415365, 0.12935890787048265, 0.15770313068060204, 0.1625920581864193, 0.11008765563019551, 0.11276303863269277, 0.10735646312241443, 0.14458368154009804, 0.21617653052089736, 0.26446420582942665, 0.1412185761728324, 0.13845590176060796, 0.12841577176004648, 0.15307318302802742, 0.21973328810418025, 0.09652765278588049, 0.15665759303374216, 0.13741541071794927, 0.4969207401154563, 2.6692247204482555, 18.38246550410986, 48.93918514251709, 77.54578292369843, 88.33576753735542, 93.32423105835915, 95.75480103492737, 84.50811132788658, 62.42366977035999, 56.07294134795666, 49.36182126402855, 40.05560003221035, 43.82384642958641, 39.21934470534325, 35.22570960223675, 64.81376811861992, 63.113108575344086, 92.1313002705574, 85.15552818775177, 88.92389997839928, 96.6613107919693, 58.199516236782074, 46.89259976148605, 34.45978470146656, 27.823520600795746, 21.062381900846958, 14.663601256906986, 5.971669312566519, 4.045927422121167, 2.4925123527646065, 1.2701393198221922, 0.49263875582255423, 0.37275536684319377, 0.3811404184671119, 0.24775058001978323, 0.34412607026752084, 0.1814088859828189, 0.20235131378285587, 0.274836432072334, 0.26973009982611984, 0.2475743941613473, 0.24822555453283712, 0.31715458317194134, 0.27197969786357135, 0.20868682069703937, 0.41756348276976496, 1.5382775128819048, 4.224920142441988, 5.800945423543453, 7.627026736736298, 16.080535724759102, 29.461937583982944, 40.39194658398628, 59.95675474405289, 76.67497605085373, 76.73609957098961, 76.40776678919792, 87.80612155795097, 99.8292464017868, 69.83820050954819, 40.928025618195534, 47.05031789839268, 33.97337280213833, 37.767693400382996, 42.627404630184174, 53.63637909293175, 69.03566837310791, 75.42142331600189, 82.83898249268532, 89.27679464221, 95.82983940839767, 94.87204000353813, 99.91818442940712, 80.11151924729347, 50.89463621377945, 16.582351997494698, 1.0608795611187816, 0.20984048926038668, 0.3395834140246734, 0.1349339509033598, 0.17083141137845814, 0.17164090153528377, 0.18044111056951806, 0.13834699901053682, 0.06878509651869535, 0.1374204276362434, 0.10729555506259203, 0.1711581344716251, 0.0676145292527508, 0.1314394743531011, 0.10723360057454556, 0.1427929534111172, 0.130104276468046, 0.10682938984245993, 0.20182658568955958, 0.16298889939207584, 0.1087803699192591, 0.129298897809349, 0.1594042222131975, 0.183202879561577, 0.1487448887201026, 0.19401827186811715, 0.21242028364213184, 0.23503005009843037, 0.11267685302300379, 0.10505844737053849, 0.20360538008389995, 0.1170681779331062, 0.1414303554338403, 0.09997253902838565, 0.2437562818522565, 0.14749309339094907, 0.19361334125278518, 0.14492511400021613, 0.11357102965121157, 0.1710624567931518, 0.17491119011538103, 0.12857678811997175, 0.08816431640298106, 0.13513165904441848, 0.14946094248443842, 0.1556445614551194, 0.11348715954227373, 0.1115336710063275, 0.1687347106053494, 0.0963029675767757, 0.15493627055548131, 0.15330038411775604, 0.08995601674541831], [0.012074901333107846, 0.03767153852095362, 0.07686761164222844, 0.03636306537373457, 0.05301210578181781, 0.10585094234556891, 0.014399970223166747, 0.022149959586386103, 0.011874542797158938, 0.02279008607729338, 0.007113741985449451, 0.043607001862255856, 0.052128467650618404, 0.0901297535165213, 0.05213785952946637, 0.03726745395397302, 0.06396262091584504, 0.04063373191456776, 0.05036882808781229, 0.06048890594684053, 0.08877067331923172, 0.0530520333268214, 0.03838667202217039, 0.0182203488657251, 0.07479714578948915, 0.03127815522020683, 0.03442669447395019, 0.030977438836998772, 0.06467781378887594, 0.035758916346821934, 0.051552661243476905, 0.023613719713466708, 0.044260911890887655, 0.056353358522756025, 0.04765592580952216, 0.021265469840727746, 0.031278830574592575, 0.07935848931083456, 0.07422800015774556, 0.03875001268170308, 0.04975896452378947, 0.08081312844296917, 0.036316076293587685, 0.03170327967382036, 0.36685624276287854, 1.9229946378618479, 9.13518100976944, 27.01499618589878, 58.08826580643654, 72.5580945611, 75.31153321266174, 73.14469188451767, 67.67178475856781, 62.75556296110153, 42.01076611876488, 25.672526322305202, 19.43960677832365, 19.999818317592144, 25.22886022925377, 47.04871818423271, 58.38098309934139, 66.04559361934662, 69.36479911208153, 47.161013558506966, 32.149607464671135, 28.183889463543892, 28.201170936226845, 13.126898165792227, 11.584564726799726, 7.838352872058749, 4.235924826934934, 1.535808239132166, 0.600221729837358, 0.1160094745864626, 0.08400738399359398, 0.036311671647126786, 0.09469849625020288, 0.06298712716670707, 0.05287487154419068, 0.10860183887416497, 0.08231038911617361, 0.09115042179473676, 0.023470544583688024, 0.03221665661840234, 0.040813194354996085, 0.02547110569139477, 0.1304849685402587, 0.11773998485296033, 0.23552007536636665, 0.02247958633233793, 0.1908349184668623, 0.09274822121369652, 0.07441160007147118, 0.10536580040934496, 0.05273232723993715, 0.09658796712756157, 0.45400305243674666, 0.4549509531352669, 0.8418977272231132, 2.812022245489061, 6.5472695510834455, 16.44315216690302, 29.882293827831745, 40.38665346801281, 57.23792463541031, 75.00001072883606, 81.80663108825684, 74.32968109846115, 46.03382304310799, 37.73170933127403, 32.8955302387476, 25.249001048505306, 29.105406515300274, 23.70055563747883, 37.22379058599472, 54.26038160920143, 62.84130536019802, 60.345937460660934, 70.15932127833366, 75.57412192225456, 78.74797761440277, 68.51791575551033, 71.4553253352642, 27.48829308897257, 4.739194996654987, 0.4338659142376855, 0.24784812791040167, 0.014065528794162674, 0.029817977811035234, 0.012784198770532385, 0.07169411503127776, 0.009334628648502985, 0.04555223771603778, 0.05691754289728124, 0.020419165448402055, 0.06818224996095523, 0.02710717209993163, 0.041797319281613454, 0.022812161259935237, 0.06169967535242904, 0.058991244513890706, 0.04525835836830083, 0.03620047937147319, 0.03744040775927715, 0.016450024231744464, 0.015454680815309985, 0.018246474319312256, 0.05293143432936631, 0.025326346076326445, 0.012984712229808792, 0.07815661825588904, 0.06886733390274458, 0.03133226891804952, 0.09319174350821413, 0.044245924218557775, 0.0463372741069179, 0.013059401044301922, 0.03903063727193512, 0.05438907915959135, 0.04612836324668024, 0.030781738205405418, 0.0733179044618737, 0.04934665696055163, 0.027099863800685853, 0.060997388427495025, 0.03349984479427803, 0.02459939758409746, 0.042182330653304234, 0.026975778564519715, 0.07574342118459754, 0.0463435155688785, 0.038722723911632784, 0.006418668735932442, 0.08249985941802152, 0.02042136406089412, 0.025950731615012046, 0.025557938824931625, 0.00447629432528629, 0.055368817993439734, 0.046563291471102275, 0.0738234851451125, 0.08488599778502248, 0.0063531825526297325, 0.013888475550629664, 0.022721005116181914, 0.04102983839402441, 0.013848259495716775, 0.003655284876913356, 0.03745714690012392, 0.03755219375307206, 0.07384598706266843, 0.04039270461362321, 0.06407893772120588, 0.04197873728116974, 0.03829706882243045, 0.09074635207070969, 0.07853277580579743, 0.020685802410298493, 0.02718428866501199, 0.06210994572029449, 0.09862144434009679, 0.03159142688673455, 0.016731984687794466, 0.008391960091103101, 0.05904935467697214, 0.01007961225695908, 0.02915434193710098, 0.0358630322443787, 0.026974721004080493, 0.03731614626303781, 0.05186688656976912, 0.02032711316132918, 0.015846626629354432, 0.07143161739804782, 0.0206852699193405, 0.02436427221255144, 0.044404472937458195, 0.025063004250114318, 0.010421195929666283, 0.040993766306200996, 0.22196170524694026, 1.5965346805751324, 9.644181746989489, 30.252912640571594, 65.44383510947227, 82.82184541225433, 81.90000727772713, 80.6340292096138, 77.15905487537384, 77.46494606137276, 54.627187326550484, 33.67579936981201, 27.543371133506298, 27.41797026246786, 36.449677124619484, 46.62364259362221, 48.73222164809704, 47.6484552025795, 49.64111767709255, 51.77722625434399, 38.84763345122337, 32.17809073626995, 30.359514020383358, 18.376604318618774, 15.277312025427818, 11.350238900631666, 5.232883030548692, 2.8121495386585593, 1.0193571704439819, 0.1713700918480754, 0.15716498455731198, 0.11533293276443146, 0.04028802468383219, 0.04520026304817293, 0.054875660862307996, 0.05867298190423753, 0.08559353911550716, 0.1739066932350397, 0.07234108226839453, 0.16371123172575608, 0.08263353505753912, 0.12979141669347882, 0.39625381061341614, 0.3019655216485262, 0.19924956694012508, 0.0528840964398114, 0.1423437165794894, 0.08742212419747375, 0.11647625578916632, 0.0984896240697708, 0.11404068296542391, 0.16201347985770553, 0.23252947255969048, 0.46403611719142646, 0.918032816844061, 3.469779775477946, 6.430230131372809, 16.764626316726208, 28.24621941894293, 35.418933033943176, 50.06802476942539, 60.53514450788498, 62.03563079237938, 55.929442048072815, 46.4985229074955, 37.41530030965805, 33.09836335480213, 29.39623910933733, 36.411321982741356, 34.55873519182205, 51.90610773861408, 64.31870028376579, 74.5019942522049, 68.27162817120552, 80.65330177545547, 84.44932088255882, 89.32874545454979, 79.91497859358788, 83.22960153222084, 34.39374804496765, 5.931526366621256, 0.37319931958336383, 0.2213827261584811, 0.03817323406110518, 0.054121601715451106, 0.03392288381292019, 0.04948450347001199, 0.0525848958932329, 0.023650194416404702, 0.034943429636769, 0.009302084545197431, 0.010751963727670955, 0.057609161449363455, 0.11066736202337779, 0.05293613583489787, 0.04192487591353711, 0.0687955979083199, 0.03558462667569984, 0.011375112662790343, 0.03729684671270661, 0.0631817257090006, 0.01703924310277216, 0.014423146567423828, 0.026083474003826268, 0.045566323678940535, 0.04619495986844413, 0.10845962853636593, 0.03390369929547887, 0.026755054568639025, 0.03054748485737946, 0.10761015888419934, 0.05633336506434716, 0.07254482407006435, 0.10074748221086338, 0.041300833618151955, 0.07898081035818905, 0.04705634470155928, 0.0782930917921476, 0.03907928134140093, 0.03357006309670396, 0.08171554291038774, 0.014441355160670355, 0.06351825999445282, 0.0027315561601426452, 0.033851637635962106, 0.007505768508053734, 0.03994009101006668, 0.030698205773660447, 0.01871071923233103, 0.02860316184523981, 0.047201115448842756, 0.08005282041267492, 0.09540880579152144, 0.11927302446565591, 0.17893699987325817, 0.09240364946890622, 0.10694365832023323, 0.1387521522701718, 0.10491145018022507, 0.1346054911846295, 0.09335824433946982, 0.06798744361731224, 0.11463817121693864, 0.13487416348652914, 0.10376489139162004, 0.15291840070858598, 0.1448198626167141, 0.16077395965112373, 0.12618397042388096, 0.10394509226898663, 0.1934095920296386, 0.22764588851714507, 0.20650738530093804, 0.14020821632584557, 0.21754043467808515, 0.17003127228235826, 0.2071448604692705, 0.24569150613388047, 0.1420147076714784, 0.12882377486675978, 0.2624631382059306, 0.11194572623935528, 0.19867410563165322, 0.10437158227432519, 0.174644595826976, 0.11320123972836882, 0.1914694844163023, 0.11149456724524498, 0.13258977356599644, 0.24336834641871974, 0.18815229210304096, 0.11580806312849745, 0.14577439811546355, 0.18856658862205222, 0.07400047994451597, 0.2017935601179488, 0.6628182646818459, 3.8764275424182415, 17.249850779771805, 42.84082777798176, 82.18633711338043, 93.71413573622704, 93.44404622912407, 90.76610952615738, 87.96601697802544, 82.83120810985565, 60.392123982310295, 39.52963225543499, 32.0915237814188, 31.48440755903721, 36.60958394408226, 64.34207662940025, 77.59814411401749, 88.10920849442482, 90.28782919049263, 68.9913247525692, 48.04837614297867, 40.76791740953922, 40.93216359615326, 21.989632844924927, 19.036321118474007, 12.874602153897285, 6.927097644656897, 3.6245525954291224, 1.3895768858492374, 0.33228097774554044, 0.40044388733804226, 0.3036714519839734, 0.23095101350918412, 0.1725942941266112, 0.22680102760205045, 0.4172072221990675, 0.2384578817873262, 0.20520553953247145, 0.1928027972462587, 0.313915346050635, 0.4085821006447077, 0.2779827226186171, 0.8826484030578285, 1.0137202916666865, 0.37792115996126086, 0.20983210299164057, 0.3556333074811846, 0.2864839055109769, 0.2682412031572312, 0.19004196336027235, 0.22697017790051177, 0.560297331539914, 0.7550518435891718, 0.8314149803481996, 1.4900797116570175, 4.515923727303743, 9.379616193473339, 23.256625458598137, 39.297077134251595, 54.32906672358513, 76.26880824565887, 96.71812534332275, 110.24539947509766, 101.11412465572357, 65.2177320420742, 55.382902175188065, 47.19298504292965, 40.069651678204536, 45.15191316604614, 39.25640031695366, 52.89551384747028, 76.14694118499756, 83.80156964063644, 80.59093952178955, 91.25373736023903, 94.23527017235756, 99.8461326956749, 94.31998282670975, 100.67625135183334, 49.48887884616852, 10.255626887083054, 0.7758572115562856, 0.48403842200059444, 0.11338877302478068, 0.11096263289800845, 0.10714084695791826, 0.188002675131429, 0.19277587212854996, 0.143221914768219, 0.12256341782631353, 0.0814254893339239, 0.18048650032142177, 0.18223299644887447, 0.197594162018504, 0.10801110416650772, 0.13025482854573056, 0.20267402927856892, 0.09728054676088504, 0.14388250041520223, 0.16225438099354506, 0.1291314692934975, 0.2605757676064968, 0.0657305502681993, 0.11740372516214848, 0.08757075411267579, 0.1252879755338654, 0.21294753503752872, 0.1680566102731973, 0.07214047232992016, 0.17901253566378728, 0.12960976862814277, 0.12335491832345724, 0.14344957598950714, 0.17847625975264236, 0.2836973191006109, 0.08780672738794237, 0.05092222534585744, 0.18091693113092333, 0.12455580232199281, 0.16410813230322674, 0.3308661771006882, 0.09495134596363641, 0.26663448312319815, 0.20098825567401946, 0.12209647335112095, 0.11951480875723064, 0.14737909950781614, 0.1369440578855574, 0.11239321902394295, 0.16161882056621835, 0.13479516928782687, 0.23105719999875873], [0.06944940032553859, 0.04961788225045893, 0.019051576527999714, 0.02546625390095869, 0.022483024331449997, 0.030962731325416826, 0.04585131580824964, 0.054959560657152906, 0.025768332125153393, 0.027088887436548248, 0.02632866846397519, 0.0089817095977196, 0.0609473973599961, 0.041259473728132434, 0.04373546391434502, 0.01744143333780812, 0.004203031840006588, 0.03159282212436665, 0.031056915431690868, 0.017650479639996774, 0.010335742263123393, 0.00834281878269394, 0.07132392434868962, 0.041937770729418844, 0.036292483418947086, 0.04964118197676726, 0.03154232268570922, 0.05671668433933519, 0.044261631774134, 0.02367286888329545, 0.04884497255261522, 0.02544209513871465, 0.03037010414118413, 0.08706360749783926, 0.05512136369361542, 0.028631237291847356, 0.03322147262224462, 0.04910079456749372, 0.019103875674773008, 0.046674008772242814, 0.03049959592317464, 0.050072989470208995, 0.18932628066977486, 1.9821503385901451, 20.57387251406908, 33.471841514110565, 60.839705765247345, 69.09648790955544, 71.61055460572243, 63.1737495213747, 65.84735065698624, 54.31033752858639, 29.597316719591618, 23.280163295567036, 16.170260310173035, 19.42578312009573, 28.605560436844826, 49.52343799173832, 63.95548537373543, 64.59224760532379, 51.59616217017174, 53.86720530688763, 27.38492153584957, 10.847732964903116, 7.776810424402356, 5.832430059090257, 1.2210245802998543, 1.335044230800122, 0.8255185279995203, 0.12655875500058755, 0.024996843640110455, 0.059353531323722564, 0.07958410220453516, 0.04312401586503256, 0.04361823797808029, 0.10925810522167012, 0.039486056193709373, 0.11332630645483732, 0.061854168234276585, 0.06935470228199847, 0.10955284917145036, 0.044677401456283405, 0.05327707847754937, 0.04536913133051712, 0.12779236771166325, 0.02434677051496692, 0.285726350848563, 0.3488854336319491, 0.017969990913115907, 0.12574099731864408, 0.047389613537234254, 0.01377635187964188, 0.02928762052761158, 0.13045268511632457, 0.09434932318981737, 0.0793681966024451, 0.008927929866331397, 0.03848077634756919, 0.1113513030577451, 0.04852529615163803, 0.1114902034169063, 0.1151876499352511, 1.6740166791714728, 6.948754107579589, 13.566723614931107, 22.459017857909203, 34.60349678993225, 52.980975061655045, 83.60716447234154, 81.90106362104416, 57.827535197138786, 32.90042817592621, 20.522126890718937, 22.9860457777977, 23.026939183473587, 27.188844457268715, 33.389271944761276, 42.41877682507038, 50.98511315882206, 63.18204067647457, 69.85944896936417, 73.93982201814651, 71.83633849024773, 76.13966837525368, 64.14235934615135, 25.106618888676167, 4.278092114254832, 0.3530365921324119, 0.013457947334245546, 0.03103533377725398, 0.1067524217069149, 0.035761038889177144, 0.032014105963753536, 0.05410596095316578, 0.06010802091623191, 0.03309774547233246, 0.03207508452760521, 0.0182631522329757, 0.06906442606123164, 0.07328389183385298, 0.020855568691331428, 0.023951207658683416, 0.02540098015742842, 0.03415853425394744, 0.013900489066145383, 0.015947252577461768, 0.01068424553523073, 0.05084496035124175, 0.018830266235454474, 0.01721106884360779, 0.0438513057451928, 0.052371654601302, 0.0686260468501132, 0.024002558711799793, 0.019622165636974387, 0.04549659148324281, 0.04723729885881767, 0.026817020188900642, 0.031364095921162516, 0.029202271689428017, 0.007891540117270779, 0.04950442642439157, 0.03830315443337895, 0.00596004048929899, 0.03251605012337677, 0.0035717394575840444, 0.038827934477012604, 0.041986474170698784, 0.015013376614660956, 0.02013430876104394, 0.03208580114005599, 0.03150934906443581, 0.03148336647427641, 0.0631647082627751, 0.03640040653408505, 0.0331335912051145, 0.05525725464394782, 0.011154510193591705, 0.02903094133216655, 0.030511390505125746, 0.021794148015032988, 0.027152470938744955, 0.05038242794398684, 0.008118773675960256, 0.06243767071282491, 0.03593168832594529, 0.06242221177672036, 0.06287347467150539, 0.05725020317186136, 0.05956166663963813, 0.03797673933149781, 0.015004512588348007, 0.007756289269309491, 0.02099566761899041, 0.08012065271032043, 0.03127344258246012, 0.034995940295630135, 0.05191368640225846, 0.03345522316521965, 0.03288666011940222, 0.02285686266986886, 0.03868764630169608, 0.05225640277785715, 0.06462400808231905, 0.023249314072018024, 0.06439090691856109, 0.06564414201420732, 0.01747918824548833, 0.02136039980541682, 0.07811318777385168, 0.08152495938702486, 0.04979105870006606, 0.04263029099092819, 0.08991979251732118, 0.08586754745920189, 0.014412864111363888, 0.05334863635653164, 0.10518866460188292, 0.01874138106359169, 2.060190076008439, 21.304835490882397, 37.10482656955719, 70.129424482584, 77.53186047077179, 81.39474079012871, 71.10072076320648, 76.12551793456078, 63.677116110920906, 45.51118768751621, 40.749826580286026, 27.02427338808775, 29.828224629163742, 32.18997649848461, 38.67811694741249, 41.23965449631214, 51.38808913528919, 52.61573486030102, 52.52711221575737, 33.866017162799835, 15.292147379368544, 9.745690450072289, 7.453740360215306, 2.000809949822724, 1.5907538845203817, 1.08454528497532, 0.17692849593004212, 0.0831746200856287, 0.044519298025988974, 0.07437343141646124, 0.160282613360323, 0.16143507964443415, 0.2432478661648929, 0.20117281295824796, 0.25590676814317703, 0.210011673043482, 0.10085850008181296, 0.16700844542356208, 0.20424897054908797, 0.2707596367690712, 0.24771166179561988, 0.49916995223611593, 1.4416789775714278, 0.7349116180557758, 0.614929375005886, 0.32872217183467, 0.08132283546729013, 0.2290418979828246, 0.4705761600052938, 0.28579442063346505, 0.40142904384993017, 0.018164958673878573, 0.16307513695210218, 0.06838739442173392, 0.08817999056191184, 0.02893365319323493, 0.05551373717025854, 0.28652101289480925, 0.32858113409020007, 2.085949368774891, 5.979217132553458, 13.227274529635906, 21.82507887482643, 33.482560738921165, 43.49937044084072, 56.480765864253044, 55.330088809132576, 52.46978469192982, 40.63584789633751, 32.02534273266792, 29.587537944316864, 28.984137922525406, 39.71537008881569, 46.76395006477833, 56.484770849347115, 62.58500911295414, 71.6139668226242, 78.92222106456757, 82.59084060788155, 82.25540220737457, 88.17168474197388, 74.5111745595932, 29.82235014438629, 4.869519453495741, 0.27713809919077903, 0.0280551117612049, 0.057168503844877705, 0.08661681233206764, 0.016166124914889224, 0.05559466466365848, 0.06497648369986564, 0.034491376354708336, 0.07800127932569012, 0.04093494368134998, 0.03387082957488019, 0.018252246372867376, 0.06276819360209629, 0.08941772219259292, 0.01841457633418031, 0.03381011076271534, 0.030253265977080446, 0.02360939484788105, 0.032244791436824016, 0.029947243237984367, 0.03264642691647168, 0.011771315621444955, 0.03909600563929416, 0.011491116838442395, 0.02009293773880927, 0.05073960877780337, 0.10020158806582913, 0.02290521915710997, 0.028441343965823762, 0.031324743540608324, 0.03236772077798378, 0.06127134482085239, 0.04383068146125879, 0.04925207766063977, 0.03314556575787719, 0.021439748379634693, 0.05347448604879901, 0.0505178402090678, 0.015920852529234253, 0.06527112374897115, 0.04413925162225496, 0.030506223301927093, 0.03052059870242374, 0.03786769557336811, 0.02769948016066337, 0.05090629514597822, 0.036848251838819124, 0.01663112867390737, 0.06523299962282181, 0.19346839981153607, 0.13732617488130927, 0.05222748870437499, 0.17862890468677506, 0.1788401644444093, 0.13435086031677201, 0.1589416860952042, 0.16122943052323535, 0.17806650517741218, 0.18818383337929845, 0.1642223191447556, 0.11439715875894763, 0.14205568906618282, 0.14246186648961157, 0.11644878148217686, 0.07794576667947695, 0.16029493301175535, 0.16505039267940447, 0.19518414133926854, 0.14642576628830284, 0.139064121467527, 0.12571367144118994, 0.11029565735952929, 0.1613911148160696, 0.12061385525157675, 0.15136775735300034, 0.09242220316082239, 0.12394313715049066, 0.18981311470270157, 0.2280433679698035, 0.14975637663155794, 0.11167028555064462, 0.11217467879760079, 0.16905606054933742, 0.13197451829910278, 0.1748849923023954, 0.10004429728724062, 0.25172803143505007, 0.20282885612687096, 0.20261266850866377, 0.18529422202846035, 0.19569877622416243, 0.5545622517820448, 4.971306016668677, 30.17100803554058, 52.0882623642683, 85.61009779572487, 91.16690441966057, 89.647745937109, 80.51470041275024, 85.15394747257233, 73.67802366614342, 48.231651708483696, 39.386790320277214, 32.842979058623314, 32.97114618122578, 44.344038516283035, 68.55736523866653, 83.04130643606186, 85.54208904504776, 71.45601689815521, 72.27967590093613, 40.59398554265499, 17.73468766361475, 12.968303225934505, 10.28945742174983, 2.1441294718533754, 2.6976056350395083, 1.6165515314787626, 0.5311514704953879, 0.2100649444037117, 0.20940682268701494, 0.22266775486059487, 0.25181581266224384, 0.26778291212394834, 0.28778477164451033, 0.28761793684680015, 0.4870808415580541, 0.22323478537146002, 0.18343855597777292, 0.406427527195774, 0.2197020288440399, 0.2796171692898497, 0.3271476610098034, 0.3789696958847344, 1.544086926151067, 1.360420100390911, 0.6317327858414501, 0.35939457127824426, 0.33298346505034715, 0.13010101101826876, 0.4204631131142378, 0.2044342996669002, 0.48185923893470317, 0.37397539825178683, 0.37943419127259403, 0.12886490469099954, 0.18726178910583258, 0.26094553526490927, 0.3812686912715435, 0.4393048770725727, 0.7013860170263797, 3.367483327165246, 10.065616182982922, 19.48876094073057, 32.54627197980881, 49.43624407052994, 68.42249527573586, 106.89315855503082, 101.8146550655365, 80.49103528261185, 53.04018348455429, 35.82947060465813, 36.38296790421009, 34.45268288254738, 44.88211244344711, 49.29071947932243, 61.95752218365669, 68.58068838715553, 83.89205038547516, 91.31764993071556, 93.34395959973335, 89.95451107621193, 99.04036313295364, 90.14616519212723, 42.975051775574684, 9.456980042159557, 0.7081824273336679, 0.14443698863033205, 0.31587247853167355, 0.23369975038804114, 0.18219364777905867, 0.17226700700121, 0.15795467421412468, 0.14935738319763914, 0.1675782515667379, 0.0986308696155902, 0.10191613473580219, 0.13773673097603023, 0.12189619737910107, 0.1606564925168641, 0.18817037082044408, 0.1669271060382016, 0.10092122640344314, 0.10963403270579875, 0.06786012076190673, 0.10010579906520434, 0.21204864577157423, 0.14879483525874093, 0.15342785540269688, 0.1389807485975325, 0.09984415490180254, 0.1896677428158, 0.1334126223810017, 0.12414765820722096, 0.31390397634822875, 0.14337279339088127, 0.11637078918283805, 0.1742595250834711, 0.1694958721054718, 0.11107579557574354, 0.1162932941224426, 0.163693850627169, 0.15322429913794622, 0.1564554765354842, 0.06107734370743856, 0.15528643067227677, 0.1392846877570264, 0.05814828349684831, 0.12374779646052048, 0.08489520783768967, 0.08954206903581508, 0.07910197338787839, 0.15960719960276037, 0.20467949041631073, 0.37792709714267403], [0.07333222049055621, 0.05833867035107687, 0.050416388621670194, 0.027241532370680943, 0.039739362327964045, 0.05704386014258489, 0.0836134297423996, 0.05360311137337703, 0.05872019362868741, 0.044057838022126816, 0.04757099442940671, 0.0401061873708386, 0.10660298285074532, 0.04050925519550219, 0.0493178467877442, 0.05045518068072852, 0.030841818770568352, 0.10037703919806518, 0.02038107100815978, 0.08551832244847901, 0.045140494185034186, 0.037421798406285234, 0.007228883414427401, 0.09387295343913138, 0.01972527963516768, 0.03977862936153542, 0.020899507544527296, 0.007716847367191804, 0.06625281443120912, 0.028085905323678162, 0.0294690533701214, 0.07145809722715057, 0.041566348081687465, 0.0205888408163446, 0.051101194258080795, 0.12832972715841606, 0.040962584971566685, 0.0068146740977681475, 0.02335844503249973, 0.02024246936343843, 0.1025057488004677, 0.23099862970411777, 2.2313564037904143, 24.859033674001694, 41.30970373749733, 71.3738577067852, 72.57857546210289, 68.55489537119865, 53.34667883813381, 89.83810052275658, 64.09299999475479, 24.883833043277264, 18.74032460153103, 17.898065596818924, 20.638771131634712, 30.35647228360176, 40.849426835775375, 53.62876810133457, 74.5891235768795, 51.28288798034191, 25.479918457567692, 7.3434546031057835, 1.3070181221701205, 0.6909986212849617, 0.2604196494212374, 0.022467951312137302, 0.08584555762354285, 0.02045513549091993, 0.07244622975122184, 0.12881087634013966, 0.13775458704913035, 0.23593082441948354, 0.1471127723925747, 0.21401601989055052, 0.10074958248878829, 0.070996110298438, 0.010758256212284323, 0.13893210823880509, 0.1731285810819827, 0.009818863309192238, 0.04288858064683154, 0.10296820328221656, 0.08837893066811375, 0.33655951847322285, 0.027656064521579538, 0.8100580482278019, 0.3441517485771328, 0.1619225667673163, 0.068899862235412, 0.12544289143988863, 0.13510844466509297, 0.06405645806808025, 0.15140277188038453, 0.07186083850683644, 0.04068198264576495, 0.09736375635839067, 0.09658695038524456, 0.05062958167400211, 0.069468963338295, 0.09869742541923188, 0.020528791792457923, 0.17245693743461743, 0.0837436098663602, 0.048291322964360006, 0.0582843302981928, 0.5627722456119955, 1.315100525971502, 5.580594772472978, 19.091585353016853, 43.239038810133934, 57.941171899437904, 64.69125509262085, 47.65320494771004, 48.845539167523384, 36.40640504658222, 23.48131500184536, 18.1793550029397, 20.137182846665382, 26.977798081934452, 38.23741279542446, 51.60898648202419, 52.420828118920326, 71.04366302490234, 64.02477845549583, 72.2844560444355, 75.09369850158691, 59.25290331244469, 20.18446560949087, 2.144369096495211, 0.24420608271611854, 0.08070815907558426, 0.0699485836958047, 0.03188271242834162, 0.04001318142400123, 0.016367757161788177, 0.060832000817754306, 0.07315596041735262, 0.02996373747009784, 0.005411110960267251, 0.059202237098361365, 0.050959366126335226, 0.0370548805949511, 0.023872228302934673, 0.06841876500402577, 0.09859211466391571, 0.009681781211838825, 0.047379264287883416, 0.025903061614371836, 0.08289809586131014, 0.10294158244505525, 0.07308812069823034, 0.041580129764042795, 0.022487120986625087, 0.02766865505691385, 0.005119518355058972, 0.03774930446525104, 0.03036522823094856, 0.0642996524402406, 0.04133941045438405, 0.03667783246783074, 0.03398570290300995, 0.030057478143135086, 0.053998935836716555, 0.03106331088929437, 0.00878512952112942, 0.05807773493870627, 0.04879428386630025, 0.039175834754132666, 0.022074219705245923, 0.05336986549082212, 0.012497060906753177, 0.013308519610291114, 0.012315632702666335, 0.07593790840473957, 0.028768901975126937, 0.04821578346309252, 0.09396455672685988, 0.06266954733291641, 0.024822242266964167, 0.022994772261881735, 0.04769056184159126, 0.02703509100683732, 0.048276357556460425, 0.0873359979595989, 0.02846223727829056, 0.01645046580961207, 0.034887334404629655, 0.02068414742097957, 0.052374337465153076, 0.12087522482033819, 0.04499684779148083, 0.06080671584641095, 0.02811184895108454, 0.049928452499443665, 0.03533827075443696, 0.08671450865222141, 0.008225149413192412, 0.02341840499866521, 0.039603627228643745, 0.03467590024229139, 0.02423420526611153, 0.017574383527971804, 0.010933108987956075, 0.04594709738739766, 0.0072520115190854995, 0.03000895096192835, 0.0387791122921044, 0.05372883861127775, 0.07883275189669803, 0.04027861054055393, 0.032106210201163776, 0.09518836566712707, 0.024546107670175843, 0.049766645752242766, 0.07171706223743968, 0.0556571386550786, 0.019865680988004897, 0.10964151355437934, 2.9132314771413803, 28.199804909527302, 49.86892305314541, 81.19207486510277, 81.72690376639366, 77.51760363578796, 67.61472702026367, 90.55143624544144, 75.2940921485424, 40.557252913713455, 26.136420629918575, 21.78113043308258, 23.134357519447803, 24.037513956427574, 38.8645501434803, 51.73562228679657, 60.41608929634094, 50.64299091696739, 30.60611128807068, 9.963949788361788, 2.3440265329554677, 0.9792520443443209, 0.5799771880265325, 0.15591479226714, 0.0954165167058818, 0.08428140718024224, 0.08425356922089122, 0.08371209085453302, 0.19396262563532218, 0.03942345232644584, 0.11760204186430201, 0.18209522415418178, 0.4482985788490623, 0.8128134347498417, 0.1875526219373569, 0.20115614432143047, 0.4683391487924382, 0.5267153866589069, 0.37615425477270037, 0.3789770579896867, 0.5077516136225313, 1.0218010330572724, 1.1528214463032782, 1.2917799898423254, 1.4921082090586424, 1.3028316968120635, 0.8100983023177832, 0.5147629498969764, 0.41654359374661, 1.812469493597746, 2.211745656095445, 0.601506654638797, 0.152593013481237, 0.4934229387436062, 0.23857713007600978, 0.13236606057034805, 0.17223105736775324, 0.0789998761320021, 0.06629274939768948, 0.04469530947972089, 0.06419710247428156, 0.04821396149054635, 0.06775700676371343, 0.49821121618151665, 1.9459651177749038, 6.762033551931381, 20.485348664224148, 38.19418631494045, 55.86493670940399, 49.2605073004961, 35.04384756088257, 48.70446793735027, 41.9928652793169, 36.213629990816116, 30.601171553134918, 34.92148272693157, 41.33748784661293, 50.24760313332081, 63.08794252574444, 61.139821261167526, 79.48982700705528, 73.84657502174377, 81.7925414443016, 86.26838967204094, 68.67462694644928, 22.783605940639973, 2.068324964493513, 0.1239773650013376, 0.11973565706284717, 0.07878725082264282, 0.05065114477474708, 0.004957271421517362, 0.04547072392597329, 0.021259417626424693, 0.07368287784629501, 0.03430978766118642, 0.01910125032736687, 0.021460166717588436, 0.01802816415874986, 0.058540842510410585, 0.03060371924220817, 0.03571155248209834, 0.0810288633510936, 0.015017106834420701, 0.023956454642757308, 0.042009577227872796, 0.0900083604210522, 0.09410336802829988, 0.023864534086897038, 0.0502228439290775, 0.08157923264661804, 0.05065006866061594, 0.03613624649005942, 0.023659909129492007, 0.07538789534009993, 0.014986290079832543, 0.10349509844672866, 0.028445333009585738, 0.0144007773087651, 0.031482754202443175, 0.00777168002059625, 0.05997106127324514, 0.06442464495194145, 0.08686086759553291, 0.0720422193990089, 0.026195278551313095, 0.05590904955170117, 0.045934536537970416, 0.051966946630273014, 0.03578336640202906, 0.01581014450493967, 0.025208604347426444, 0.00841202498122584, 0.014339284807647346, 0.2031782889389433, 0.13112269603880122, 0.2075577765936032, 0.07549695394118316, 0.27888870681636035, 0.12229203668539412, 0.14318359026219696, 0.16557936585741118, 0.12968962371814996, 0.11841508690849878, 0.24445940740406513, 0.12897998210974038, 0.11925421102205291, 0.22126157797174528, 0.09861685044597834, 0.19486452802084386, 0.24369162594666705, 0.168414548097644, 0.061550199388875626, 0.14078376669203863, 0.09878927361569367, 0.10296699358150363, 0.12329769873758778, 0.09841002873145044, 0.13258800725452602, 0.0829467733274214, 0.07155163752031513, 0.15223911294015124, 0.21896730264415964, 0.1219744494301267, 0.07923224999103695, 0.1092822992359288, 0.15926777094136924, 0.11625269122305326, 0.1344370236620307, 0.19132286572130397, 0.06112860013672616, 0.17389563523465768, 0.17184902942972258, 0.30386307451408356, 0.1761706147226505, 0.2847214532084763, 6.2336187064647675, 42.39004656672478, 64.27052646875381, 93.35328429937363, 89.59611430764198, 86.49696260690689, 71.76176369190216, 104.1208653151989, 80.30899465084076, 41.45927891135216, 32.17758156359196, 31.85804720968008, 35.57834967970848, 44.77202095091343, 58.88027250766754, 75.04645183682442, 97.81665399670601, 68.73816713690758, 38.16539905965328, 12.402482237666845, 2.980398810468614, 1.5148068848066032, 0.8094927691854537, 0.3075803437968716, 0.4450993880163878, 0.21988431515637785, 0.18037741945590824, 0.468067730544135, 0.26236757927108556, 1.2233664421364665, 0.5222141125705093, 0.3575379849644378, 0.3090856270864606, 0.3613117168424651, 0.28411048755515367, 0.24151417950633913, 0.5186337546911091, 0.34465738863218576, 0.1802219098317437, 0.4348648153245449, 0.46036352519877255, 1.3775102770887315, 1.3873303751461208, 2.4322611233219504, 1.8196802004240453, 1.1799357226118445, 0.6464109825901687, 0.33893854706548154, 0.6892829539719969, 0.6105305766686797, 0.5797613714821637, 0.28731264697853476, 0.31223859696183354, 0.4995790240354836, 0.4647221288178116, 0.3035372419981286, 0.2540803427109495, 0.2707489498425275, 0.23339275358011946, 0.4551063588587567, 0.2603260794421658, 0.20260931400116533, 0.5303859303239733, 1.2109943060204387, 2.4345362512394786, 9.589282292872667, 27.91421413421631, 57.635527700185776, 78.47376152873039, 85.36400780081749, 65.89708998799324, 66.51450365781784, 57.05782189965248, 39.59113575518131, 32.56923034787178, 35.49194611608982, 42.235049083828926, 56.98393486440182, 72.80318140983582, 71.62932559847832, 93.14817130565643, 85.58857575058937, 90.27924165129662, 98.26365441083908, 83.95208716392517, 33.220887780189514, 3.8551370473578572, 0.33160535618662834, 0.17509461933514103, 0.18961389258038253, 0.15822687913896516, 0.09962539945263416, 0.13985468685859814, 0.11495762868435122, 0.1299455013941042, 0.10335464699892327, 0.110755002242513, 0.16113240213599056, 0.15337884397013113, 0.16147383459610865, 0.1345555149600841, 0.1708667672937736, 0.1481481723021716, 0.1640551578020677, 0.19129819673253223, 0.11107664904557168, 0.23542663897387683, 0.1919698849087581, 0.19102332007605582, 0.2212796121602878, 0.3332574956584722, 0.17101924895541742, 0.0467036464397097, 0.16171026800293475, 0.17323436681181192, 0.14169938396662474, 0.23243005445692688, 0.13820959778968245, 0.15239143132930622, 0.16072748636361212, 0.09679209484602325, 0.162166926311329, 0.11200420005479828, 0.16937997832428664, 0.1784933143062517, 0.1171997755591292, 0.12252351254574023, 0.1702679877053015, 0.295920402277261, 0.11160955560626462, 0.08901468405383639, 0.19755255721975118, 0.10456383562996052, 0.12565297860419378], [0.027316921587043907, 0.04128983127884567, 0.0352550017851172, 0.10511094689718448, 0.05693783692549914, 0.033450421469751745, 0.06096275981690269, 0.0220759507647017, 0.07421803311444819, 0.03309681407699827, 0.0415569784672698, 0.01637254772504093, 0.027379197053960524, 0.059709784472943284, 0.0443527489551343, 0.03143788024317473, 0.030841755688015837, 0.03983021975727752, 0.022405033887480386, 0.03107206637650961, 0.05947344012383837, 0.027047631447203457, 0.026021133598987944, 0.13136824301909655, 0.04884262365521863, 0.0633890372409951, 0.008180119602911873, 0.018951690872199833, 0.08027286719880067, 0.04970800495357253, 0.08813127598841675, 0.020705990682472475, 0.025541192262608092, 0.02634292141010519, 0.0852360094722826, 0.019819756889774, 0.01921547056554118, 0.06465479978942312, 0.04560333829431329, 0.14220668643247336, 1.489825719036162, 11.084332019090652, 44.08988535404205, 70.08581802248955, 64.26791980862617, 70.9047120809555, 63.91886293888092, 54.829442873597145, 37.91787274181843, 83.36114287376404, 41.38534627854824, 23.72335061430931, 46.27750016748905, 52.714217975735664, 54.13501113653183, 75.41257739067078, 69.4180266559124, 45.32399833202362, 23.45174878835678, 10.17790300771594, 2.3484696820378304, 0.22187638795003295, 0.17138701281510293, 0.04028110415674746, 0.02687914722628193, 0.05845959960424807, 0.0904645214905031, 0.0916756248625461, 0.1464397631934844, 0.061519982846220955, 0.3494575998047367, 0.7481525419279933, 0.5794273456558585, 0.6497065932489932, 0.18209191417554393, 0.427031505969353, 0.22731115022907034, 0.6406574381981045, 0.798163617728278, 0.5614747339859605, 0.6439810723531991, 0.6170719850342721, 0.4060261440463364, 0.05788864684291184, 0.763509952230379, 1.4695929922163486, 1.603977531194687, 2.3720305552706122, 0.905864741653204, 0.25323159294202924, 1.2038025981746614, 5.711187114939094, 7.841520952060819, 0.48889628320466727, 0.3332546161254868, 0.16408671392127872, 0.8561160892713815, 0.38106617401354015, 0.29310766258277, 0.13572096882853657, 0.10079035608214326, 0.18851698347134516, 0.07001018195296638, 0.06259999325266108, 0.1422942747012712, 0.03977290369221009, 0.21074219868751243, 0.10985774570144713, 0.296991232316941, 1.6664942703209817, 16.802937760949135, 55.2585044503212, 91.94818809628487, 87.50042036175728, 42.470754235982895, 31.901742964982986, 28.33125125616789, 32.128305807709694, 23.59208095818758, 25.605401024222374, 26.984326131641865, 50.90366072952747, 61.555724143981934, 66.73147961497307, 71.90713629126549, 72.57808908820152, 81.23783200979233, 69.83292639255524, 38.682699501514435, 9.497827850282192, 0.5088545638136566, 0.11133093852549791, 0.05292059897328727, 0.04990928282495588, 0.04112615431949962, 0.048098219849634916, 0.04199042981781531, 0.028462259542720858, 0.017976024573727045, 0.11845877714222297, 0.0558379332505865, 0.05290577086270787, 0.031705888322903775, 0.07729557109996676, 0.04000624605396297, 0.02609609979117522, 0.018342792100156657, 0.027877211541635916, 0.0722655093704816, 0.006899171321492759, 0.02771932147879852, 0.023132535279728472, 0.07151253375923261, 0.039707056639599614, 0.06794736022129655, 0.03744403315067757, 0.026801362728292588, 0.027439281329861842, 0.06802605756092817, 0.04135918126848992, 0.062221301268436946, 0.03817357915977482, 0.009437409607926384, 0.04085697735717986, 0.07617266455781646, 0.08140987454680726, 0.07541372207924724, 0.03249995665100869, 0.016549885767744854, 0.03577429735742044, 0.02946680280729197, 0.04684144842030946, 0.04995475050236564, 0.0074035724537679926, 0.006700807307424839, 0.05469823932799045, 0.065817285067169, 0.06307233314146288, 0.033415317884646356, 0.02759212293312885, 0.0591903441818431, 0.031213120819302276, 0.034402990277158096, 0.021433978181448765, 0.028820388470194302, 0.03844883060082793, 0.04775003013492096, 0.016471579911012668, 0.047342390680569224, 0.0525544418633217, 0.02225118481874233, 0.050904821982840076, 0.0066675474954536185, 0.02933496954938164, 0.04455927752132993, 0.05057097056123894, 0.07431704303598963, 0.03302362347312737, 0.0663871357392054, 0.08853249586536549, 0.045246001609484665, 0.01871277498139534, 0.0325163544039242, 0.015387934836326167, 0.048620539673720486, 0.05197673926886637, 0.041227802576031536, 0.03970905672758818, 0.03358958529133815, 0.05656120069033932, 0.05252308241324499, 0.03705321447341703, 0.01740428328048438, 0.037448033326654695, 0.05304170263116248, 0.12174744872027077, 1.0450765653513372, 13.442079853266478, 51.49136759340763, 81.438377648592, 73.22147816419601, 81.22796013951302, 77.3681728541851, 67.45438322424889, 42.80085392296314, 89.94916096329689, 52.97053322196007, 31.54612574726343, 51.4036151021719, 44.509702026844025, 41.5448085218668, 57.55329631268978, 51.809991896152496, 47.71661214530468, 27.092208042740822, 13.51055882871151, 3.3394014090299606, 0.43075940280687064, 0.2478858586982824, 0.059446002924232744, 0.09186758135911077, 0.17820309003582224, 0.05184442918107379, 0.1531671834527515, 0.08467198465950787, 0.03380127178388648, 0.3895806265063584, 0.659988900879398, 0.7679612946230918, 2.0180163765326142, 3.4726621583104134, 3.7104275124147534, 2.7235641796141863, 2.0140873873606324, 1.919087735004723, 2.0176185853779316, 1.9193929061293602, 2.271251888014376, 2.0801798533648252, 2.4892457155510783, 2.7668628562241793, 4.331523422151804, 3.461481020785868, 4.332908922806382, 1.5018587233498693, 2.7647010097280145, 2.6100379088893533, 4.402088485658169, 13.551818914711475, 3.131349985487759, 0.7719551178161055, 0.05634679793729447, 0.6778025825042278, 0.568669707281515, 0.4259326821193099, 0.1562378936796449, 0.16392559366067871, 0.10011656762799248, 0.04502418109041173, 0.04627340487786569, 0.06560199544765055, 0.03389295299712103, 0.09076886140974239, 0.021482130578078795, 0.1472760151955299, 1.9618747453205287, 14.708745684474707, 47.953540831804276, 76.2349520623684, 73.8634917140007, 43.84811952710152, 33.91251526772976, 28.699766881763935, 30.255561098456383, 27.422313429415226, 37.18259699642658, 44.02336612343788, 59.22123201191425, 74.30428326129913, 74.64376464486122, 84.7630624473095, 80.95625951886177, 90.34351900219917, 79.69155058264732, 45.51911026239395, 10.896596442908049, 0.3740823862608522, 0.03830245310382452, 0.08796833746600896, 0.10425636384752579, 0.008821148730930872, 0.038495114640682004, 0.03676471569633577, 0.024377977824769914, 0.026479270636627916, 0.10116259509231895, 0.09742303169332445, 0.009013872422656277, 0.019298823026474565, 0.04031889060570393, 0.006311646402537008, 0.026742319314507768, 0.032138938913703896, 0.05465382550028153, 0.020807301261811517, 0.010893691669480177, 0.015512229729210958, 0.05000429999199696, 0.008564033523725811, 0.0316119324270403, 0.014894719261064893, 0.029655551370524336, 0.06606951879803091, 0.012505103932198836, 0.03650157981610391, 0.030310633992485236, 0.033680453852866776, 0.03329444800328929, 0.04292752484616358, 0.03741229520528577, 0.047625327060814016, 0.02859356587578077, 0.014569300492439652, 0.060835143813164905, 0.02206481669418281, 0.05142404705111403, 0.07213017874164507, 0.022681216723867692, 0.05782362357422244, 0.0170641106160474, 0.06320956366835162, 0.026695632659539115, 0.119789210439194, 0.1322279023588635, 0.07567660562926903, 0.18057420733384788, 0.111416834697593, 0.12370400232612155, 0.16875100816832855, 0.06546497272211127, 0.12318224282353185, 0.116386203590082, 0.14718468650244176, 0.09489109099376947, 0.09564677544403821, 0.1431804583990015, 0.0704718274937477, 0.10668217742932029, 0.11992054831353016, 0.11487329102237709, 0.09335577298770659, 0.159673280431889, 0.20003912301035598, 0.16171544819371775, 0.2372836705762893, 0.2237028579111211, 0.1136603693885263, 0.24611041881144047, 0.1626235104049556, 0.1331770943943411, 0.09546377666993067, 0.1129104068968445, 0.2651883341604844, 0.10044488633866422, 0.1840153828379698, 0.12957306200405583, 0.2030989236664027, 0.11436949149356224, 0.1643017289461568, 0.12573972082464024, 0.16693236044375226, 0.2537394594401121, 2.7773486310616136, 22.644774690270424, 67.76925712823868, 90.39109244942665, 83.81709560751915, 90.76079741120338, 85.39534851908684, 71.11459001898766, 49.57278594374657, 96.40916392207146, 53.8663237541914, 36.07690192759037, 62.73903764784336, 72.07888707518578, 72.24306106567383, 102.93938711285591, 89.75654929876328, 63.32424804568291, 34.893273040652275, 15.986011996865273, 4.21402707695961, 0.5280767823569477, 0.5047757201828063, 0.2660516003379598, 0.24216718040406704, 0.28563960862811655, 0.2326008226373233, 0.3795112855732441, 0.5033199826721102, 0.43109693157020956, 0.6047528085764498, 2.1707712672650814, 1.2615602114237845, 1.5589146804995835, 2.5661039538681507, 3.248620005324483, 1.2298201583325863, 2.5568490754812956, 2.0241188490763307, 2.563631236553192, 1.9813459692522883, 1.632744837552309, 1.489661259111017, 1.5555003262124956, 3.5844020498916507, 5.076178964227438, 3.678868068382144, 4.739498980343342, 1.1238470510579646, 1.9978275848552585, 1.3911573635414243, 12.898196037858725, 15.51897905766964, 1.3365805358625948, 1.4687983598560095, 0.6417397269979119, 1.9508730294182897, 1.629655840806663, 0.987213448388502, 0.7408815727103502, 0.4093965928768739, 0.34271619748324156, 0.28584093844983727, 0.14567745878593996, 0.26494603778701276, 0.21492521016625687, 0.38362783030606806, 0.24501827429048717, 0.5733827606309205, 3.1631644908338785, 22.582273744046688, 70.1891116797924, 114.76673886179924, 107.8906962275505, 58.38201284408569, 46.70807786285877, 43.9030721783638, 44.32456076145172, 38.7286314368248, 42.1335793286562, 47.04511217772961, 68.3280399441719, 81.21463045477867, 85.06022170186043, 94.72176566720009, 92.91526660323143, 99.99966725707054, 93.45772549510002, 59.520712941884995, 17.804493717849255, 0.9011552506126463, 0.317903914838098, 0.23323825327679515, 0.16361113084712997, 0.20865266706096008, 0.24126461008563638, 0.1537786834524013, 0.1367722952272743, 0.12753147311741486, 0.25740133482031524, 0.26109167898539454, 0.11342804005835205, 0.09348862484330311, 0.16157795791514218, 0.08862429953296669, 0.15862775762798265, 0.1052304104086943, 0.13490273617208004, 0.15077763120643795, 0.11112488864455372, 0.08954983932198957, 0.22122184338513762, 0.14229676831746474, 0.11618730801274069, 0.1643325577606447, 0.14289069426013157, 0.15824252361198887, 0.10844316027942114, 0.16857762762811035, 0.16323808289598674, 0.10761544297565706, 0.0932091914000921, 0.14850186504190788, 0.11651723718387075, 0.2342153649078682, 0.29360686079598963, 0.11133836742374115, 0.19860609521856532, 0.1148689939873293, 0.10102040701895021, 0.17296438833000138, 0.1902332593454048, 0.2110023659770377, 0.09886853498755954, 0.15106378850759938, 0.10017823267844506], [0.015825573755137157, 0.10406417728518136, 0.05551788206503261, 0.08510533953085542, 0.01506299568063696, 0.022687476739520207, 0.027698968078766484, 0.054911822007852606, 0.09986438584746793, 0.1351793939829804, 0.032952455221675336, 0.04148526473727543, 0.05231510294834152, 0.0294550880062161, 0.020548256470647175, 0.010971613464789698, 0.07285211773705669, 0.026668134232750162, 0.04205753481073771, 0.0552480297483271, 0.029814200279361103, 0.06726249150233343, 0.044249631246202625, 0.044949847579118796, 0.056097321285051294, 0.0262204855971504, 0.0514734072930878, 0.0692158167657908, 0.03589141939301044, 0.025589107171981595, 0.012668369927268941, 0.03542447120707948, 0.03759577637538314, 0.061537389919976704, 0.027144967825734057, 0.030450614176515955, 0.033491068898001686, 0.09275642936700024, 0.822561455424875, 11.292803082615137, 45.86889669299126, 75.05455300211906, 73.04443806409836, 73.69950771331787, 79.63678792119026, 67.94818952679634, 31.68533507734537, 30.54235450923443, 65.80492213368416, 75.10427713394165, 45.24089299142361, 36.334300115704536, 43.48353289067745, 72.27523773908615, 71.28654599189758, 46.983095705509186, 27.358961328864098, 11.302602756768465, 2.7371239895001054, 0.1952432162943296, 0.08920730106183328, 0.03869940934237093, 0.024970666236185934, 0.07183465553680435, 0.08384401502553374, 0.06257287517655641, 0.07542746665421873, 0.04368769557913765, 0.11515725898789242, 0.1595344246015884, 0.7400140317622572, 0.19826766103506088, 0.4301182762719691, 1.0541426413692534, 2.8235907247290015, 5.178711712360382, 2.67306393943727, 0.7182457717135549, 1.0905689117498696, 2.2999835712835193, 3.0830861628055573, 1.1691416893154383, 1.157477383967489, 2.269299030303955, 1.7837823391892016, 1.836083207745105, 2.7353371353819966, 3.197348644025624, 2.612466453574598, 3.54368319734931, 0.8984566235449165, 8.49849572405219, 13.958439845591784, 5.424289684742689, 0.1857448837836273, 1.0721697052940726, 0.5520497553516179, 1.2244484340772033, 0.3382125188363716, 0.17284567438764498, 0.07422797047183849, 0.05937625959631987, 0.06848589968285523, 0.08014379287487827, 0.008864093106240034, 0.017073235321731772, 0.02344378830457572, 0.052701212698593736, 0.11290651804301888, 0.07881325567723252, 0.2034098983858712, 1.4231071178801358, 12.628085631877184, 42.99140989780426, 76.1199702322483, 76.57784566283226, 62.76163883507252, 63.3545134216547, 40.835895761847496, 27.745098508894444, 26.839734390378, 29.490732438862324, 30.05158804357052, 40.45616693794727, 56.84844173491001, 61.54938228428364, 72.12902158498764, 74.2146460711956, 70.47177851200104, 57.730051428079605, 16.667370535433292, 0.22807394445408136, 0.1319747557863593, 0.05122686212416738, 0.032648508640704677, 0.0786973990034312, 0.035163487555109896, 0.029628156844410114, 0.05734544298320543, 0.004541135303952615, 0.024577756557846442, 0.030163249030010775, 0.08514120010659099, 0.02559874210419366, 0.004659177602661657, 0.06451032590121031, 0.05692427417670842, 0.020801317696168553, 0.01649345471378183, 0.021306273119989783, 0.0751958423643373, 0.03214151045540348, 0.03734894547960721, 0.01452077887734049, 0.02174801797082182, 0.045198229563538916, 0.07319568758248352, 0.030103209282970056, 0.060187178387423046, 0.05569468761677854, 0.06437724397983402, 0.04428328393260017, 0.074564749666024, 0.027817854570457712, 0.05130819779878948, 0.015600983169861138, 0.0621999979193788, 0.06911493663210422, 0.04636589503206778, 0.03199820544978138, 0.018140417705581058, 0.02798011959384894, 0.035959340748377144, 0.05820503552968148, 0.07890349341323599, 0.06795611756388098, 0.010385013447375968, 0.08705017462489195, 0.03167805407429114, 0.10758549731690437, 0.015619188052369282, 0.04623853135854006, 0.04309250427468214, 0.04535817352007143, 0.033099630527431145, 0.0611526939610485, 0.06417256707209162, 0.016070452802523505, 0.047834620127105154, 0.05018023723096121, 0.08379107021028176, 0.023018491301627364, 0.06164803300634958, 0.06149075707071461, 0.02189853479649173, 0.04534546795184724, 0.09404020383954048, 0.03780506944167428, 0.02233815896033775, 0.11394588102120906, 0.0659483706112951, 0.04610507836332545, 0.051503475406207144, 0.07237693542265333, 0.04182182499789633, 0.061875638566561975, 0.028304887127887923, 0.038573771162191406, 0.028025583560520317, 0.05737648702051956, 0.037336959794629365, 0.019864337700710166, 0.0533322237606626, 0.07956420522532426, 0.6875043525360525, 12.684392910450697, 51.51934929192066, 83.3054606616497, 82.82954379916191, 83.77544984221458, 89.42929565906525, 78.21713849902153, 43.8652528077364, 49.168977811932564, 62.03908480703831, 80.35339146852493, 38.56740988790989, 32.71360740065575, 47.178181037306786, 67.56986662745476, 70.02667799592018, 48.97085264325142, 32.421106696128845, 13.523767869919538, 3.4393588453531265, 0.19318553764605895, 0.054568155683227815, 0.1505982392700389, 0.031089124640857335, 0.11132836327305995, 0.09071351203601807, 0.038804638461442664, 0.18058648245641962, 0.019248028584115673, 0.2568025403888896, 0.30907793843653053, 1.063706015702337, 1.0085304826498032, 0.5062133492901921, 1.6582753113470972, 2.4671954987570643, 7.057024072855711, 5.323962718248367, 3.1112982239574194, 4.4860022328794, 3.743437766097486, 5.341358184814453, 5.372200179845095, 4.7763171046972275, 3.851536028087139, 5.578039884567261, 6.190895698964596, 6.025445451959968, 11.313978396356106, 6.479061786085367, 4.0308507811278105, 5.697242338210344, 4.58876296877861, 7.664873655885458, 3.303631078451872, 0.9375130652915686, 0.23846853902796283, 2.196836918592453, 2.042153156362474, 0.22778879647376016, 0.1178366644307971, 0.1243752748996485, 0.07945157689391635, 0.10860893380595371, 0.07609085019794293, 0.017793730839912314, 0.023491350693802815, 0.06358232218190096, 0.05268883738608565, 0.13560756866354495, 0.035363106726435944, 0.18336077890126035, 1.9770618178881705, 13.547580242156982, 36.07394188642502, 54.00535449385643, 52.93668083846569, 47.64693148434162, 47.898443788290024, 36.194961592555046, 31.58752452582121, 30.82448747009039, 43.71549144387245, 42.860221937298775, 53.56074035167694, 65.2142134308815, 72.3931074142456, 80.71985140442848, 82.68150374293327, 81.31963402032852, 67.97668799757957, 22.954184487462044, 0.37968215765431523, 0.16444361273897812, 0.050911809303215705, 0.029195061724749394, 0.11142813760670833, 0.04060468425450381, 0.03777971025556326, 0.03900823554431554, 0.03317115500976797, 0.004649983784474898, 0.03858139301883057, 0.03890034953656141, 0.025561977963661775, 0.02973814869619673, 0.020634035754483193, 0.009890449018712388, 0.005817251740154461, 0.04493399530474562, 0.049610768764978275, 0.04428150277817622, 0.04841264926653821, 0.06042544489901047, 0.02684542218048591, 0.04656826386053581, 0.06930208401172422, 0.07724423674517311, 0.07766962095047347, 0.028714960826619063, 0.04103067702089902, 0.07944814817165025, 0.021765833225799724, 0.09297409385908395, 0.023165866987255868, 0.04845731542445719, 0.04214985056023579, 0.015781827860337216, 0.02148869858501712, 0.054026662473916076, 0.05679132213117555, 0.031152324081631377, 0.05076550973171834, 0.024129003977577668, 0.08076209094724618, 0.06525162752950564, 0.07489256371627562, 0.24747936957282946, 0.20113892649533227, 0.18716054531978443, 0.23561694048112258, 0.08867006778018549, 0.12723813182674348, 0.10110213974257931, 0.12426099900039844, 0.17929970228578895, 0.2522111695725471, 0.13296721503138542, 0.12978264450794086, 0.1195286720758304, 0.15679643402108923, 0.16837629780638963, 0.08198290903237648, 0.23536397202406079, 0.2169099060120061, 0.06303062444203533, 0.2281092113116756, 0.18425132642732933, 0.22969675424974412, 0.1478443667292595, 0.2500228432472795, 0.2636698406422511, 0.14179532881826162, 0.16042215196648613, 0.24324293830431998, 0.1355353873805143, 0.17707196791889146, 0.09962764073861763, 0.11348990548867732, 0.07818172511179, 0.12244879311765544, 0.14894749503582716, 0.20312247943365946, 0.1699495321372524, 0.17231754725798965, 1.8756171176210046, 19.57400556653738, 63.06545913219452, 97.9124316573143, 91.32667064666748, 91.40468046069145, 97.26427003741264, 88.42917412519455, 48.59422445297241, 48.92764136195183, 79.51808989048004, 85.10978624224663, 60.008975341916084, 51.19487710297108, 56.09765142202377, 86.30254223942757, 88.83716583251953, 64.53769773244858, 41.283424347639084, 18.396215066313744, 4.9327414110302925, 0.8005051233340055, 0.2652608568314463, 0.29546228935942054, 0.1546641843742691, 0.2196877499227412, 0.27488630439620465, 0.2076626123744063, 0.38577569474000484, 0.25441487319767475, 0.1593532069819048, 0.813106968998909, 1.5477927960455418, 1.671526744030416, 0.6420015566982329, 2.7854348346590996, 14.829057678580284, 28.324248231947422, 11.467821691185236, 2.7414023224264383, 4.346705982461572, 7.585978489369154, 7.602711841464043, 4.370881235226989, 4.839179031550884, 5.78738110139966, 6.183249559253454, 6.714880932122469, 10.841851830482483, 12.003309857100248, 7.8872856963425875, 11.486708577722311, 5.864013964310288, 16.881736032664776, 31.638253703713417, 7.6888232957571745, 2.19553311355412, 2.9723159316927195, 3.972815782763064, 4.264066116884351, 0.6912900181487203, 0.6948711478617042, 0.5320263735484332, 0.21053650503745303, 0.3809598390944302, 0.2588776149787009, 0.21765282552223653, 0.13838722341461107, 0.20434012112673372, 0.2562442672206089, 0.4213548480765894, 0.3026540268911049, 0.3460388816893101, 2.3256416944786906, 19.283934831619263, 59.435202330350876, 99.37743544578552, 100.28335243463516, 81.58039882779121, 84.27327632904053, 59.71006438136101, 44.9272046238184, 38.38326036930084, 43.23460824787617, 45.54190903902054, 59.787625819444656, 75.34731209278107, 81.1542820930481, 92.60338693857193, 92.41875484585762, 93.83651956915855, 80.49438670277596, 31.949479803442955, 1.7869932856410742, 0.1926267598173581, 0.18848471489036456, 0.2432446155580692, 0.1808387681376189, 0.080580160865793, 0.1819602571777068, 0.11381658405298367, 0.09696422857814468, 0.10954151657642797, 0.13636705290991813, 0.11746073694666848, 0.1309112730086781, 0.1350256209843792, 0.15910259855445474, 0.15630128793418407, 0.26167438365519047, 0.10607110045384616, 0.20633274310966954, 0.21895904996199533, 0.14271149528212845, 0.16044285788666457, 0.10338963926187716, 0.08970321898232214, 0.21847712894668803, 0.14851140906102955, 0.24980049580335617, 0.19323395536048338, 0.15002979867858812, 0.1961376823601313, 0.12196188486996107, 0.23875005048466846, 0.15111155313206837, 0.10033665152150206, 0.0938520990894176, 0.13562793319579214, 0.14609340287279338, 0.18468450318323448, 0.2412242817808874, 0.09170781180728227, 0.15717981266789138, 0.0606728286948055, 0.1667571987491101, 0.19986143801361322, 0.20219871337758377], [0.03526273125316948, 0.007938595990708563, 0.05672509658324998, 0.06066262416425161, 0.0358966515341308, 0.05291826120810583, 0.020829816166951787, 0.014883066614856943, 0.04485753925109748, 0.02487202738848282, 0.013319811387191294, 0.01614312390302075, 0.001495398926181224, 0.03081853203184437, 0.08350502423127182, 0.054902214906178415, 0.02423120884486707, 0.024707914417376742, 0.05369806174712721, 0.03372430735907983, 0.01637361456232611, 0.04928674337861594, 0.050037381224683486, 0.024162059235095512, 0.01969212604308268, 0.07514340220950544, 0.12900349334813654, 0.04034582314488944, 0.03774638411414344, 0.03677714295918122, 0.02469564300554339, 0.04305081041820813, 0.06461812285124324, 0.03501541053992696, 0.1225170113320928, 0.04175524321908597, 0.17681601602816954, 7.428999412804842, 36.431894078850746, 65.69424167275429, 83.10578137636185, 69.78053480386734, 71.32087334990501, 53.89583297073841, 59.99645121395588, 50.384099408984184, 35.781224593520164, 22.301269322633743, 39.68548849225044, 51.476046815514565, 38.11008162796497, 43.46632361412048, 58.06630298495293, 60.45359708368778, 26.744101122021675, 16.121742613613605, 2.008288661018014, 0.35440597333945334, 0.09766948409378529, 0.0740440069057513, 0.066518777894089, 0.0468574639671715, 0.057072061754297465, 0.01278541496503749, 0.19458447117358446, 0.020578699368343223, 0.23154772992711514, 0.2847201470285654, 0.09854296964476816, 0.3341433231253177, 0.8527738717384636, 0.2771170815685764, 1.5256713330745697, 4.369762670248747, 5.257948860526085, 5.742600979283452, 10.54429929703474, 4.448364302515984, 4.761205790564418, 1.3345039472915232, 4.240885935723782, 6.404325496405363, 4.372961148619652, 5.002280529588461, 4.004718633368611, 6.799224531278014, 4.612891199067235, 7.3965980764478445, 4.299693005159497, 4.809457026422024, 11.567668933421373, 1.7866137810051441, 12.972813583910465, 10.211118925362825, 0.9278450778219849, 0.16691419266862795, 0.9566868958063424, 0.3058928484097123, 1.4221397135406733, 1.5389232407324016, 0.3905401937663555, 0.062011236368562095, 0.017914322415890638, 0.11385264500859194, 0.03377420565811917, 0.08017833242774941, 0.07157051033573225, 0.09889287743135355, 0.07416978609398939, 0.07133395818527788, 0.05943085940089077, 0.09832534226006828, 0.5684464098885655, 3.0404761992394924, 16.219619661569595, 39.45262558758259, 60.6051329523325, 74.21922862529755, 85.77552571892738, 75.58843955397606, 55.0810007750988, 35.38874365389347, 23.07702999562025, 31.49175826460123, 26.623793877661228, 37.232720106840134, 55.954627096652985, 64.0275751054287, 63.32071803510189, 77.17423126101494, 81.57468393445015, 48.29795815050602, 14.161624442785978, 0.6107696669641882, 0.22761430271202698, 0.03704193753947038, 0.03988424068666063, 0.026454596081748605, 0.021476378933584783, 0.03528608664055355, 0.03900709634763189, 0.09062200522748753, 0.03548458516888786, 0.07503574626753107, 0.0260584135321551, 0.0257301968667889, 0.027580858986766543, 0.06710129702696577, 0.01966561467270367, 0.038179174953256734, 0.05992020931444131, 0.06059965664462652, 0.022898356146470178, 0.03091663838858949, 0.04466977217816748, 0.026613441659719683, 0.0467761505569797, 0.00993762270809384, 0.05053554785263259, 0.0036657637701864587, 0.007456624416590785, 0.05777877930086106, 0.005394002137109055, 0.03959104040404782, 0.020752682903548703, 0.03274542570579797, 0.0407817421364598, 0.029259177717904095, 0.021074698925076518, 0.07786869464325719, 0.04733597481390461, 0.08577501648687758, 0.06079210666939616, 0.06275527281104587, 0.0232597653666744, 0.03975831306888722, 0.021805497308378108, 0.0627480962430127, 0.02590769076050492, 0.060039862073608674, 0.06303209389443509, 0.009321269990323344, 0.0045299868543224875, 0.07368640304775909, 0.024991839709400665, 0.018193054529547226, 0.05003473175747786, 0.034348101034993306, 0.017347408793284558, 0.039914724402478896, 0.11137891837279312, 0.024825188593240455, 0.040804540913086385, 0.0385447346343426, 0.04639075697923545, 0.04179336734523531, 0.04721661520306952, 0.03335502580739558, 0.04504872762481682, 0.029372498102020472, 0.06014419319399167, 0.03291113614977803, 0.06394287236616947, 0.011450215224613203, 0.029897630665800534, 0.007146241096052108, 0.014860732608212857, 0.07668122867471538, 0.0582737509830622, 0.026459574037289713, 0.1070908633118961, 0.08226539270253852, 0.07169473843532614, 7.209100462496281, 41.0561091452837, 73.91504734754562, 91.28522247076035, 77.46692195534706, 80.26884600520134, 65.0773523747921, 71.54254585504532, 63.38198974728584, 37.1586012840271, 23.160840198397636, 56.09916374087334, 66.04661956429482, 40.54895795881748, 40.83664432168007, 42.058673948049545, 55.2557647973299, 33.26318331062794, 17.17656221240759, 2.6010599406436086, 0.5205164942890406, 0.0031384356088892673, 0.07627597151440568, 0.014149287580949022, 0.1734619092894718, 0.11550701834494248, 0.07362198462942615, 0.2819405071204528, 0.1278613429167308, 0.46586426440626383, 1.02470597717911, 1.328887373674661, 0.453812557971105, 2.0860524382442236, 0.6900618528015912, 2.421579658985138, 1.3005309202708304, 0.6059001688845456, 0.040723683923715726, 2.345512490719557, 1.2913785176351666, 1.6430084430612624, 1.7076080641709268, 6.216282611712813, 10.51898505538702, 11.194040682166815, 7.0162147376686335, 8.319793213158846, 5.939312623813748, 6.002117078751326, 10.684434827417135, 6.737248431891203, 2.1354424254968762, 1.4064356312155724, 0.26347667444497347, 2.597298617474735, 0.9383522265125066, 0.4812963050790131, 0.34320500562898815, 1.3059591664932668, 0.5634772265329957, 1.982941289898008, 2.90186058729887, 0.8523258520290256, 0.09839105943683535, 0.1115421240683645, 0.050621369809960015, 0.2518231450812891, 0.160409698728472, 0.15316892007831484, 0.2612267201766372, 0.06658347090706229, 0.08184538906789385, 0.07356026020715944, 0.18133698671590537, 0.27654049219563603, 3.153299270197749, 17.337806560099125, 38.229877799749374, 51.51744179427624, 73.5768274962902, 88.2601971924305, 67.08309754729271, 42.012023851275444, 36.722574681043625, 35.59022404253483, 51.85769073665142, 43.77055808901787, 49.4133996963501, 65.42494252324104, 71.09412431716919, 72.31103181838989, 88.00932705402374, 93.90983283519745, 59.117406383156776, 19.787711799144745, 0.4961302044102922, 0.32307614979799837, 0.024576337200414855, 0.09746278854436241, 0.05426486590295099, 0.09459084030822851, 0.010177059957641177, 0.01849753545684507, 0.048775266332086176, 0.045773197343805805, 0.06689080910291523, 0.014475510652118828, 0.005991632324366947, 0.053270054049789906, 0.028262161686143372, 0.03527652777847834, 0.005260332527541323, 0.02698156917176675, 0.010734216193668544, 0.038618066246272065, 0.020333016946096905, 0.02626905174111016, 0.05683999217581004, 0.018779074744088575, 0.04207933910947759, 0.0658939711865969, 0.022173511642904487, 0.03817940872977488, 0.01067477294782293, 0.02011153967032442, 0.01815101186366519, 0.015066431824379833, 0.06410410394892097, 0.08141350364894606, 0.026802516767929774, 0.03300973417935893, 0.014553606852132361, 0.08247721649240702, 0.0916062414762564, 0.01832917369029019, 0.013978034221509006, 0.01024242368657724, 0.05356313558877446, 0.13001501094549894, 0.198627810459584, 0.18894523236667737, 0.19292139244498685, 0.11800844193203375, 0.12965685047674924, 0.19323876447742805, 0.14970289746997878, 0.19907265377696604, 0.16239155957009643, 0.20497853140113875, 0.12255016306880862, 0.1277795879286714, 0.18689628137508407, 0.20260526187485084, 0.08845118616591208, 0.14546973165124655, 0.10679729195544496, 0.31647652736864984, 0.08175066133844666, 0.08834412394207902, 0.10820199197041802, 0.13348213193239644, 0.14940963039407507, 0.15555017511360347, 0.29059828317258507, 0.2059914739220403, 0.15313093696022406, 0.13777901855064556, 0.1605722142267041, 0.14912130602169782, 0.17675076640443876, 0.17862051841802895, 0.0969266462197993, 0.22262181591941044, 0.2441109690698795, 0.3933145198971033, 11.992955412715673, 55.271913930773735, 89.19251516461372, 100.85651367902756, 89.207843542099, 90.81473931670189, 75.37080243229866, 79.8781281709671, 71.9507123529911, 54.25891488790512, 34.55168277025223, 51.797315776348114, 62.80336059629917, 53.05709257721901, 61.35981045663357, 78.36715444922447, 81.140998005867, 41.23108595609665, 24.53308906406164, 4.308050656691194, 1.1827100487425923, 0.14522667828714475, 0.38192572945263237, 0.16526873252587393, 0.37326756748370826, 0.1973585895029828, 0.28557706042192876, 0.43622914992738515, 0.2255626948317513, 0.302295777364634, 0.7245263003278524, 0.8069347345735878, 1.3401721743866801, 1.6381939826533198, 1.9997284328565001, 3.5424390016123652, 9.926442950963974, 18.02440881729126, 17.898812256753445, 23.293986953794956, 9.496875051409006, 13.10655215755105, 8.925397116690874, 14.635496065020561, 19.062395319342613, 15.803126860409975, 18.060250394046307, 17.538905069231987, 19.354519844055176, 19.5737224817276, 20.42204026132822, 14.487541504204273, 13.960008211433887, 20.69762997329235, 8.420787993818521, 26.973599307239056, 20.02531874924898, 3.879525801166892, 0.46421156090218574, 1.90878102555871, 1.4883844088762999, 3.024237295612693, 3.101220214739442, 1.5496237040497363, 0.248916627606377, 0.2839828678406775, 0.23615893092937768, 0.25316574960015714, 0.22183500579558313, 0.303461721050553, 0.3238530893577263, 0.21904598514083773, 0.21779724746011198, 0.2728932222817093, 0.44764721067622304, 0.8843647234607488, 5.1259515434503555, 25.28873171657324, 56.32429786026478, 81.13690182566643, 91.39885157346725, 96.81868314743042, 92.99766138195992, 76.53390482068062, 49.668328016996384, 37.22261644899845, 45.654945373535156, 41.10483393073082, 56.345895901322365, 73.67856323719025, 81.6530129313469, 83.1896124780178, 95.92885449528694, 105.22999539971352, 73.98928016424179, 25.432156920433044, 0.9494233480654657, 0.48764048027805984, 0.20649724756367505, 0.22662349103484303, 0.11683176679071039, 0.14952899742638692, 0.1683844911167398, 0.13652916764840484, 0.164849404245615, 0.17097230069339275, 0.18478941317880526, 0.09601616460713558, 0.13810480653773993, 0.14438383601373062, 0.11036755662644282, 0.18275434034876525, 0.08769723834120668, 0.11734732936020009, 0.11489830139908008, 0.14901117130648345, 0.07842100836569443, 0.11476363870315254, 0.0997849834675435, 0.09644479199778289, 0.11590740701649338, 0.25716022588312626, 0.1046514832705725, 0.1082586994743906, 0.13806605158606544, 0.13969591178465635, 0.16666229290422052, 0.06675469179754145, 0.07448566640960053, 0.15565150795737281, 0.12680307001573965, 0.11436889035394415, 0.14960805099690333, 0.14642404450569302, 0.17554661695612594, 0.18065202893922105, 0.14123824308626354, 0.20037319336552173, 0.12245949488715269], [0.0709999620448798, 0.07065302284900099, 0.050118754006689414, 0.041685785618028603, 0.01568650270201033, 0.03977754582592752, 0.05338278257113416, 0.049570214105187915, 0.04705818522779737, 0.070133051922312, 0.025058382525458, 0.021945750231679995, 0.043762359346146695, 0.04729287087684497, 0.011170214038429549, 0.02273361234983895, 0.07220382205559872, 0.007792904980306048, 0.04048884613439441, 0.012952644956385484, 0.037159178318688646, 0.05319163130479865, 0.005111215577926487, 0.005759014948125696, 0.05476889178680722, 0.04233945073792711, 0.02999848482431844, 0.11352999630616978, 0.08611863828264177, 0.14561443560523912, 0.03142041008686647, 0.10451362933963537, 0.05339644922059961, 0.05356984089303296, 0.0787928985664621, 0.5182291357778013, 23.663277737796307, 63.478496968746185, 72.61136770248413, 71.18427827954292, 67.95737743377686, 65.72875142097473, 56.18907451629639, 41.64844796061516, 23.863046318292618, 23.038804046809673, 38.44888664782047, 46.79802663624287, 15.562974996864796, 25.918988697230816, 34.123350754380226, 55.11270247399807, 58.09418968856335, 19.809098951518536, 4.304808005690575, 0.022890812215337064, 0.04827428696444258, 0.09785531045054086, 0.16725555091397837, 0.08978455094620585, 0.10556983164860867, 0.022358441856340505, 0.12757772376062348, 0.14661704743048176, 0.07713826547842473, 0.11222546396311373, 0.4072505986550823, 0.35660555062349886, 2.8343246737495065, 0.4689670947846025, 0.320903675747104, 0.2104543344466947, 0.7291187695227563, 0.4570107097970322, 0.28711775899864733, 1.213480916339904, 2.080419003032148, 2.589090345427394, 4.391168346628547, 2.702472461387515, 4.936431962996721, 6.304199444130063, 6.225636759772897, 2.6674858387559652, 6.4475662261247635, 6.362616084516048, 2.218814939260483, 11.830744966864586, 9.14138512685895, 0.2495476312469691, 4.131442783400416, 1.1920573096722364, 0.6248851970303804, 0.7441792020108551, 0.3585731325438246, 0.9475055197253823, 0.5728695506695658, 0.4396750603336841, 0.5700276594143361, 0.27810532541479915, 0.06438695127144456, 0.049256511993007734, 0.048762171136331744, 0.1071798987686634, 0.026579555196803994, 0.14379240368725732, 0.009025027829920873, 0.04278637206880376, 0.04023710222099908, 0.10859824687941, 0.07664564269362018, 0.06003484144457616, 0.03878804032865446, 0.08748374471906573, 0.3254454117268324, 3.6009845975786448, 19.51872233301401, 38.6997339874506, 53.220214024186134, 37.988127171993256, 35.409061163663864, 34.77513737976551, 24.94379572570324, 21.23097125440836, 11.378708872944117, 21.37143451720476, 24.857038781046867, 41.40891641378403, 53.12931530177593, 66.92006349563599, 69.40220430493355, 83.23234498500824, 72.69085943698883, 28.223827220499516, 4.202754506841302, 0.19325985631439835, 0.08256589571828954, 0.023884384681878146, 0.010808309434651164, 0.08110179420327768, 0.06254329317016527, 0.03685234478325583, 0.028346579128992744, 0.003263103662902722, 0.06196941634698305, 0.03885136407916434, 0.04640367777028587, 0.022542900806001853, 0.03664661031507421, 0.07667308731470257, 0.08417515389737673, 0.010531648840697017, 0.057368527486687526, 0.047375234425999224, 0.03544697683537379, 0.030563938271370716, 0.018812916678143665, 0.012713305113720708, 0.037198860954958946, 0.04318218539992813, 0.008243058364314493, 0.06382763167493977, 0.032082903053378686, 0.03187100504874252, 0.016670844706823118, 0.025334164602099918, 0.00805801404567319, 0.04127154104935471, 0.029272374958964065, 0.036585861817002296, 0.0415223201707704, 0.028941388227394782, 0.03207481364370324, 0.07251878210809082, 0.020877643873973284, 0.04869211610639468, 0.03125072915281635, 0.06114888303272892, 0.020701396788354032, 0.029269977821968496, 0.027872298524016514, 0.024732715137361083, 0.04319093161029741, 0.06312102545052767, 0.03732275879883673, 0.02499959144188324, 0.04744531172036659, 0.011459717497928068, 0.03164680223562755, 0.013375902908592252, 0.074631899187807, 0.027078473249275703, 0.055005670292302966, 0.032938833101070486, 0.037874037225265056, 0.08171295281499624, 0.04124345075979363, 0.02069338344881544, 0.044331282333587296, 0.05888904335733969, 0.06858729931991547, 0.0035828846603180864, 0.04514021587965544, 0.07578404634841718, 0.06901894725160673, 0.060773783043259755, 0.03728943265741691, 0.18546994775533676, 0.01456690613849787, 0.05524650463485159, 0.0499828222382348, 0.4986527643632144, 27.77211505919695, 70.97412675619125, 85.05452960729599, 82.95363754034042, 78.79317998886108, 72.67238482832909, 67.52510502934456, 52.30146512389183, 38.465035781264305, 41.610218212008476, 47.01327368617058, 36.576426923274994, 22.862970381975174, 38.6726338416338, 36.519300788640976, 51.83272987604141, 49.18228469789028, 24.26088687032461, 4.440942350775003, 0.039460006810259074, 0.03109607299847994, 0.024327153696503956, 0.11795463622547686, 0.0693983405653853, 0.106064495339524, 0.10730577443609945, 0.22672120219795033, 0.3518654534127563, 0.40400753205176443, 0.6159023602958769, 0.9708784811664373, 1.3162702694535255, 6.178961964324117, 2.546184710226953, 1.306456821039319, 0.2397417082102038, 1.499607937876135, 1.1424356536008418, 0.12666370952501893, 0.7549469929654151, 1.1831913166679442, 0.7522462285123765, 0.6116014067083597, 0.8824568102136254, 2.0301187271252275, 8.891168553382158, 7.148503214120865, 6.7807328235358, 6.0046995151788, 5.891129309311509, 4.823558544740081, 5.5983873177319765, 5.755266174674034, 0.9802656399551779, 1.1628703633323312, 0.37792567221913487, 0.631083317566663, 0.12945373950060457, 0.7487257767934352, 0.808717313921079, 0.7650829490739852, 1.2408548849634826, 0.5782230477780104, 1.0235123662278056, 0.5983580485917628, 0.8023835881613195, 0.19028430426260456, 0.7548719469923526, 0.31297875568270683, 0.7630931027233601, 0.23256196378497407, 0.4205511318286881, 0.2580365241738036, 0.08723309176275507, 0.15611103095579892, 0.041843877916107886, 0.04896412807283923, 0.10242397896945477, 0.24818616133416072, 4.031197987496853, 22.95381970703602, 45.87730944156647, 59.14501190185547, 44.875390604138374, 38.27546775341034, 39.301511496305466, 24.50411181896925, 19.444715604186058, 17.311838753521442, 33.63674886524677, 41.26528412103653, 49.32937480509281, 59.278764724731445, 77.20348209142685, 76.61753833293915, 92.20027416944504, 85.61191409826279, 38.572406619787216, 6.1457783449441195, 0.1533119913074188, 0.04547398566501215, 0.05991099926177412, 0.06738890151609667, 0.08841212693369016, 0.02998549538460793, 0.013167395591153763, 0.0533849199564429, 0.016702803441148717, 0.011183186779817333, 0.029193954069342, 0.047237480684998445, 0.02502078717952827, 0.037433127290569246, 0.07961907962453552, 0.034246630893903784, 0.0904634156904649, 0.06678633697447367, 0.06990910886088386, 0.03693191785714589, 0.02499946527677821, 0.07050593660096638, 0.06628310889936984, 0.056613729902892374, 0.045491652490454726, 0.04773289394506719, 0.09888651722576469, 0.05513344585779123, 0.04563497976050712, 0.04280915229173843, 0.014820193719060626, 0.03396678184799384, 0.03529408328176942, 0.021646507011610083, 0.049606419779593125, 0.024182193701562937, 0.02136932784196688, 0.014162217648845399, 0.02770200531813316, 0.057891830656444654, 0.06238664806005545, 0.20864328631432727, 0.19802974333288148, 0.15013965137768537, 0.16313094645738602, 0.12192488138680346, 0.15381610253825784, 0.10519042349187657, 0.17951057612663135, 0.1439130026847124, 0.260729985893704, 0.16727564827306196, 0.1534919918049127, 0.14874843618599698, 0.13491423946106806, 0.10165180399781093, 0.13488958531524986, 0.12547928636195138, 0.11523514738655649, 0.11582152568735182, 0.17195917898789048, 0.151413117418997, 0.15369673550594598, 0.16517991229193285, 0.1304731090203859, 0.24732152960496023, 0.11339598670019768, 0.09180170090985484, 0.22303960053250194, 0.16303391807014123, 0.26600537938065827, 0.11839864091598429, 0.24061471136519685, 0.13829982810420915, 0.20607594517059624, 0.18133363220840693, 1.7284396151080728, 37.32811398804188, 83.47316086292267, 95.02986833453178, 89.17027115821838, 88.16436633467674, 86.88878998160362, 75.75047045946121, 60.07137939333916, 38.489985242486, 37.666128650307655, 56.67755350470543, 67.19528272747993, 28.51828671991825, 42.896623983979225, 50.02690717577934, 74.21424329280853, 77.32550874352455, 30.722584538161755, 7.110957903787494, 0.26036968803964555, 0.2978659572545439, 0.18759231199510396, 0.4751080699497834, 0.2400676000979729, 0.5917851731646806, 0.29730055946856737, 0.2799244481138885, 0.3010002546943724, 0.5210416379850358, 0.5180998239666224, 0.799499424174428, 1.2363336025737226, 7.893660804256797, 4.269373007118702, 2.2976982314139605, 0.5181688733864576, 1.7612138064578176, 3.6700632283464074, 1.7507072514854372, 2.6498930202797055, 8.372788969427347, 9.458836242556572, 13.306526876986027, 10.032493360340595, 17.498230151832104, 18.72421346604824, 19.67139434069395, 13.592587877064943, 22.590152621269226, 18.91219697892666, 14.406240116804838, 24.402279183268547, 28.9003961160779, 11.362478043884039, 13.57897985726595, 5.760739780962467, 4.0939881931990385, 4.937225170433521, 1.4188272412866354, 1.590335788205266, 1.9010370410978794, 2.9904461838304996, 2.5617861980572343, 0.9913595602847636, 0.31615446496289223, 0.5027247802354395, 0.35754611890297383, 0.4818305326625705, 0.13676312228199095, 0.32624699058942497, 0.15377666481072083, 0.24760980944847688, 0.37272746209055185, 0.3940694621996954, 0.25196237198542804, 0.16227441898081452, 0.15033955627586693, 0.307818484143354, 0.7476923509966582, 5.902084596455097, 29.63654961436987, 56.180661767721176, 68.34953159093857, 51.30799703299999, 51.91035971045494, 51.32019817829132, 40.43005853891373, 31.896860226988792, 20.74638895690441, 35.82750231027603, 42.11285904049873, 58.76076512038708, 72.73043811321259, 86.7568002641201, 85.96346363425255, 100.76053082942963, 98.58547434210777, 48.63610960543156, 8.925738148391247, 0.21818255569087341, 0.09439978923182935, 0.12391843847581185, 0.10313477090676315, 0.21990156266838312, 0.20677158987382427, 0.1431774749653414, 0.11474032784462906, 0.10321068519260734, 0.15083833888638765, 0.20854461035924032, 0.13987420534249395, 0.13013414049055427, 0.11029727524146438, 0.15681279095588252, 0.21721909957705066, 0.1795310594025068, 0.3003041201736778, 0.27802555938251317, 0.2459260990144685, 0.07880264296545647, 0.17826678114943206, 0.18817964766640216, 0.1810619467869401, 0.08374514611205086, 0.07974117776029743, 0.17061678227037191, 0.1923180412268266, 0.11913646929315291, 0.1416231505572796, 0.1077207166235894, 0.12818898627301678, 0.16014488559449092, 0.09499733685515821, 0.20112862548558041, 0.12877856323029846, 0.12106711452361196, 0.10079173647682182, 0.19454409833997488, 0.3969942661933601, 0.12386126341880299], [0.005457746128740837, 0.015256201768352184, 0.02347004548937548, 0.059363205218687654, 0.0491710240021348, 0.05477494029037189, 0.038264499671640806, 0.02542013313359348, 0.0787853731890209, 0.005567003718169872, 0.07234764285385609, 0.03580074378987774, 0.06513626067317091, 0.017963949831028003, 0.027477449984871782, 0.03778467893425841, 0.04956372402375564, 0.012589930483954959, 0.03979106404585764, 0.047143495103227906, 0.07124638475943357, 0.05907009028305765, 0.06976676493650302, 0.03192424672306515, 0.02115932231390616, 0.015531961580563802, 0.08370578259928152, 0.03047772668651305, 0.031261282492778264, 0.021043458218628075, 0.04651375311368611, 0.08932505021221004, 0.07431642705341801, 0.08131772206979804, 1.6316697327420115, 36.24384216964245, 83.40539529919624, 73.22255730628967, 71.22032314538956, 70.21544426679611, 70.44479995965958, 58.452510461211205, 31.897452995181084, 22.326532267034054, 20.845554135739803, 21.37744579464197, 37.96562857925892, 41.3018761575222, 54.052350372076035, 52.91613154113293, 51.132541447877884, 35.16966260969639, 8.168505281209946, 0.16825909784529358, 0.02000506930926349, 0.021840309600520413, 0.039554222457809374, 0.1291553070768714, 0.009118747166212415, 0.05884102269192226, 0.05722567890188657, 0.1063010623329319, 0.08909659489290789, 0.2351424706284888, 0.07091633684467524, 0.32847566006239504, 1.1278436053544283, 3.0122460890561342, 3.9191579120233655, 1.1177455284632742, 0.7351339654996991, 0.05974115505523514, 0.22937145608011633, 0.23191095184301957, 0.12411799456458539, 0.1732032559812069, 0.22546468680957332, 0.28521376429125667, 0.10061016262625344, 0.34327607369050384, 1.3831846788525581, 7.415977511554956, 10.314763113856316, 5.624618735164404, 5.7367179449647665, 2.103894855827093, 3.7415884528309107, 5.753925321623683, 4.5744971092790365, 1.4857814298011363, 0.9182254783809185, 0.15004045591922477, 0.04705461178673431, 0.08386760047869757, 0.6989635282661766, 1.5709010185673833, 0.3531694068806246, 0.3433761448832229, 0.7379541860427707, 0.15665695478674024, 0.805070340866223, 0.09564802225213498, 0.10080712119815871, 0.3311446902807802, 0.3179401613306254, 0.4333988658618182, 0.613958170870319, 0.9543110732920468, 0.27308766497299075, 0.02873211557016475, 0.020827461703447625, 0.08437251322902739, 0.0967678711458575, 0.09029327833559364, 0.03923976335499901, 0.061180598713690415, 0.4406351619400084, 4.551920145750046, 31.01729292422533, 48.486120253801346, 42.50537037849426, 39.89483445882797, 70.57563453912735, 168.49666893482208, 76.79126501083374, 18.695994280278683, 14.772682003676891, 24.355279505252838, 42.78900995850563, 63.27222503721714, 66.15266427397728, 67.21313416957855, 71.81515082716942, 79.19995576143265, 60.9469398111105, 13.1885090097785, 0.5557757522910833, 0.08232437117840163, 0.11497496525407769, 0.006307940302576753, 0.08672241994645447, 0.03845957689918578, 0.03606731952459086, 0.013478242290148046, 0.03661895047116559, 0.039088710327632725, 0.11144524411065504, 0.027931299264309928, 0.011314905004837783, 0.041483227541903034, 0.05857768643181771, 0.054046054792706855, 0.00999276891889167, 0.015478737532248488, 0.09107509380555712, 0.01942455583048286, 0.05619690637104213, 0.020221028717060108, 0.05849516332091298, 0.04320708816521801, 0.07898294774349779, 0.007040536074782722, 0.0489354960154742, 0.05414999628555961, 0.08555272841476835, 0.04407542321132496, 0.05545443586015608, 0.06650178271229379, 0.032233095189440064, 0.10233587861876003, 0.035788249733741395, 0.04784674682014156, 0.05075183566077612, 0.04488510632654652, 0.023391221984638833, 0.03906561469193548, 0.06809471364249475, 0.02201783689088188, 0.03574883798137307, 0.03580545642762445, 0.018929489524452947, 0.03932294697733596, 0.031753007278894074, 0.07978227047715336, 0.07467657647794113, 0.1031997830432374, 0.006633713446717593, 0.012215691385790706, 0.09906933046295308, 0.06276943298871629, 0.06371602008584887, 0.039925292585394345, 0.035349978134036064, 0.05086771459900774, 0.0695022263971623, 0.03815878815657925, 0.038496261258842424, 0.033218414973816834, 0.03534754388965666, 0.052235949187888764, 0.039101093061617576, 0.027635965307126753, 0.08617007653811015, 0.04636507866962347, 0.013650244291056879, 0.06297913423622958, 0.0785424756759312, 0.03577915842470247, 0.022652621773886494, 0.03926700017473195, 1.6227460303343832, 42.36325800418854, 94.9412950873375, 82.49974429607391, 80.71220621466637, 80.220368206501, 77.88632825016975, 70.73606193065643, 42.15386264026165, 37.360260263085365, 35.3909969329834, 26.987916938960552, 45.14883913099766, 44.49821524322033, 40.32086379826069, 49.437638595700264, 51.3689723610878, 35.07746435701847, 10.382345337420702, 0.309976827702485, 0.0863445554568898, 0.10014330720878206, 0.039604384219273925, 0.1417439870419912, 0.03310548607259989, 0.09092238207813352, 0.13391582819167525, 0.4723931156331673, 1.1973601626232266, 1.0594539251178503, 1.7049092589877546, 1.9395142514258623, 4.757024114951491, 6.58600989729166, 4.487922079861164, 2.1046291664242744, 2.3214343702420592, 0.1584247505525127, 0.5034570721909404, 0.19767337886150926, 0.17340014775982127, 0.6678935454692692, 0.4712236096384004, 0.2838285901816562, 0.2511647710343823, 0.49544618173968047, 1.564019825309515, 6.352880531921983, 6.05270566418767, 6.341222282499075, 2.5557989068329334, 0.7102567004039884, 1.2655902514234185, 3.0543091194704175, 3.8301123026758432, 1.0650663427077234, 0.42676733108237386, 0.14683599583804607, 0.14742064493475482, 0.17841540364315733, 0.8638533053454012, 2.181932693347335, 0.7011179532855749, 0.7591584732290357, 2.5248887529596686, 2.4951178254559636, 2.2174776485189795, 1.2582760001532733, 1.1383685655891895, 2.6054194942116737, 2.2982620261609554, 2.171912156045437, 1.9813257828354836, 0.8409713488072157, 0.7308860309422016, 0.08106410052278079, 0.13318816723767668, 0.09427720870007761, 0.061652641743421555, 0.0540417726006126, 0.11283493047812954, 0.07733765087323263, 0.6093643954955041, 5.916874352842569, 28.153023719787598, 40.58457724750042, 38.91090385615826, 26.328939199447632, 44.19930048286915, 114.84137445688248, 60.05706176161766, 26.232599169015884, 23.414571583271027, 38.059840723872185, 57.12094031274319, 73.27482730150223, 74.3446446955204, 77.01714769005775, 82.76762992143631, 91.64925053715706, 75.69258436560631, 16.09923642128706, 0.5184967839159071, 0.09216093749273568, 0.09890179804642685, 0.03091897986450931, 0.021125335661054123, 0.020516409058473073, 0.020636529370676726, 0.06654107943177223, 0.07281896600034088, 0.044740654702764004, 0.06449248467106372, 0.028604484723473433, 0.06205199140822515, 0.03168813986121677, 0.06088611080485862, 0.036466639503487386, 0.0523435680224793, 0.030655317059427034, 0.018022546100837644, 0.055579903346369974, 0.03182885477144737, 0.011885628628078848, 0.03877901210216805, 0.02013826811889885, 0.009451511341467267, 0.009897826894302852, 0.07077561822370626, 0.06617570528760552, 0.06405397187336348, 0.040863203976186924, 0.09632435627281666, 0.07337254879530519, 0.05863313970621675, 0.05769364383013453, 0.0072284432280866895, 0.12698890379397199, 0.07697909706621431, 0.019153321263729595, 0.01338156456768047, 0.03637532936409116, 0.11361881654011086, 0.08748009335249662, 0.17990487918723375, 0.21291103621479124, 0.23982953396625817, 0.1434659626102075, 0.1592034861096181, 0.1919269739300944, 0.1623988029314205, 0.13918754062615335, 0.11165202129632235, 0.1051111621200107, 0.20430437929462641, 0.07808667083736509, 0.09954561857739463, 0.06936400139238685, 0.1912846599589102, 0.13476199528668076, 0.12001926137600094, 0.15113976958673447, 0.17041836166754365, 0.15617124881828204, 0.17173481290228665, 0.14044341776752844, 0.11991574661806226, 0.11719518908648752, 0.1639424849417992, 0.22785508510423824, 0.10495830938452855, 0.13046778040006757, 0.22935509914532304, 0.13777585700154305, 0.1502441754564643, 0.13640668359585106, 2.668447899632156, 55.95873087644577, 106.82692050933838, 92.38679096102715, 89.301318526268, 93.35441663861275, 89.77275162935257, 75.85005551576614, 46.91993549466133, 39.66814622282982, 34.57603946328163, 34.897688403725624, 55.97658231854439, 60.152113661170006, 78.89416337013245, 73.81740018725395, 71.2111048400402, 50.92259131371975, 13.75520870089531, 0.9915445628575981, 0.2489680881262757, 0.22596924332901835, 0.486971745849587, 0.3003469272516668, 0.25512570224236697, 0.17939514247700572, 0.20679536828538403, 0.6881444400642067, 1.148190088570118, 0.700519010424614, 1.524317655712366, 1.5988669241778553, 3.0049590300768614, 7.5454574637115, 9.66357970610261, 3.4544274117797613, 8.019255939871073, 0.3366480121621862, 1.0740152187645435, 0.8173822739627212, 0.35466593282762915, 1.0470751393586397, 1.8191561847925186, 0.9211954940110445, 1.363519427832216, 0.9947551530785859, 9.04958300292492, 17.69419703632593, 23.54013204574585, 23.316519744694233, 16.604937985539436, 10.700328424572945, 10.858018063008785, 17.760368585586548, 15.388183426111937, 3.737041996791959, 1.6760595445521176, 0.3848346514860168, 0.3405808605020866, 0.7275915483478457, 1.4271086594089866, 4.1154480166733265, 0.6154695991426706, 1.110783708281815, 2.7848142804577947, 3.9275592612102628, 2.446947335265577, 0.41652040905319154, 0.45359252602793276, 1.2703814380802214, 1.7263542395085096, 2.6317326072603464, 2.5060776248574257, 3.026799070648849, 0.9452780080027878, 0.19566760602174327, 0.3140841698041186, 0.25318234402220696, 0.28807159687858075, 0.32666856015566736, 0.3595797816524282, 0.3455486486200243, 1.0328988125547767, 8.979340922087431, 43.93645338714123, 71.80923834443092, 59.453243762254715, 57.92227931320667, 83.90761435031891, 172.87932336330414, 90.87726876139641, 31.615217439830303, 27.600288279354572, 40.06373539566994, 63.915427923202515, 82.35121786594391, 86.76124602556229, 86.3652540743351, 91.90532639622688, 100.91128394007683, 90.56142970919609, 21.516081355512142, 0.748723876895383, 0.3120216226670891, 0.19997439288999885, 0.1581457772408612, 0.12189896558993496, 0.18254175956826657, 0.10246064106468111, 0.13795760896755382, 0.15954696689732373, 0.17372057744069025, 0.2575761254411191, 0.09707647099276073, 0.14424232329474762, 0.12071462406311184, 0.12177788419649005, 0.14806545252213255, 0.12084283749572933, 0.05557605159992818, 0.24190408905269578, 0.17305841844063252, 0.11943922101636417, 0.1284766723983921, 0.11888789435033686, 0.13830370211508125, 0.2755126770352945, 0.15157454938162118, 0.1242416437889915, 0.21014393860241398, 0.12182751903310418, 0.1571840577526018, 0.27181295212358236, 0.11020579069736414, 0.09351320477435365, 0.1817630833829753, 0.09942816628608853, 0.25568697368726134, 0.21141011675354093, 0.15333076764363796, 0.06737418472766876, 0.09355024536489509], [0.10876577187445946, 0.0471456881496124, 0.03610651234339457, 0.09963797885575332, 0.07708540972089395, 0.08819461087114178, 0.030617456395702902, 0.05643127660732716, 0.05867677056812681, 0.027336323182680644, 0.03332273867272306, 0.07460460299625993, 0.06985286148847081, 0.04077918914845213, 0.03550502020516433, 0.025536412831570487, 0.06321783119346946, 0.05355923560273368, 0.014228863437892869, 0.11240787644055672, 0.0682378739293199, 0.021773789048893377, 0.007784591070958413, 0.04049193717946764, 0.08316919498611242, 0.004505973738559987, 0.04073890908330213, 0.03976681808126159, 0.08262578703579493, 0.04671894210332539, 0.1657978244475089, 0.08449019558611326, 0.07301691905013286, 2.562197525985539, 47.294245809316635, 78.51264104247093, 67.9929131269455, 65.42062595486641, 61.246496737003326, 58.745140358805656, 53.057027980685234, 22.88489520549774, 25.241530649363995, 21.702337861061096, 31.385208182036877, 40.92189274728298, 34.084041863679886, 37.55032606422901, 53.3692230284214, 46.31401240825653, 18.179444298148155, 4.334357595071197, 0.09497842693235725, 0.04760951560456306, 0.03667047407361679, 0.06620461936108768, 0.11439812355092727, 0.09301590645918623, 0.0731444348639343, 0.1741874625440687, 0.10179440025240183, 0.3117695002583787, 0.7881114352494478, 1.5507833543233573, 1.5888493554666638, 1.4342835056595504, 2.9084822069853544, 2.2515309462323785, 4.064763011410832, 3.239493607543409, 1.6480644280090928, 1.0954879852943122, 0.2787792548770085, 0.2892130200052634, 0.13348741602385417, 0.4759841604391113, 0.18569076637504622, 0.20234392199199647, 0.10060769127449021, 0.13757709501078352, 0.5092637543566525, 4.92457564920187, 1.6148311737924814, 3.9787881122902036, 3.5581000987440348, 7.2697775065898895, 13.877760674804449, 23.030735179781914, 27.0688221976161, 28.98379784077406, 17.56891965866089, 3.362253620289266, 0.9583557781297714, 0.47390967956744134, 0.18637640692759305, 1.7022163909859955, 0.8206958742812276, 0.17808822041843086, 0.4060882469639182, 0.39395410276483744, 2.899804897606373, 0.9371941792778671, 0.3114557795925066, 2.1917178807780147, 3.46089418977499, 3.63643788266927, 0.5758031120058149, 1.1730601103045046, 0.3694264485966414, 0.020070112987014, 0.21395284828031436, 0.01977569372684229, 0.13009779009735212, 0.0743615347892046, 0.07344972473219968, 0.23366865440038964, 0.19116686627967283, 0.15134166344068944, 1.0499607282690704, 13.600047826766968, 35.61046175658703, 70.16429901123047, 59.327599704265594, 73.83884623646736, 52.65405960381031, 27.979794815182686, 27.044824585318565, 18.13723236322403, 16.1854100972414, 33.056451603770256, 38.66381451487541, 67.8895890712738, 64.47000816464424, 67.42912977933884, 75.87821200489998, 61.91588781774044, 9.818641785532236, 0.35820737248286605, 0.027510859617905226, 0.112608330528019, 0.03661777045635972, 0.08167331470758654, 0.04821346796234138, 0.009904791022563586, 0.06430349676520564, 0.06851174126495607, 0.1174783703754656, 0.19303682609461248, 0.14424601919017732, 0.025804452452575788, 0.0313523699878715, 0.03273412279668264, 0.026085763529408723, 0.042111871152883396, 0.06058188220777083, 0.05827284556289669, 0.05416728090494871, 0.07606026629218832, 0.09895000053802505, 0.10695394448703155, 0.09434610226890072, 0.03713676174811553, 0.06971235809032805, 0.05864096194272861, 0.07453433645423502, 0.04961112128512468, 0.09514775534626096, 0.016137448328663595, 0.0011804997529907268, 0.028646050559473224, 0.03492404845019337, 0.060532013594638556, 0.03281648634583689, 0.039897532551549375, 0.04017513660073746, 0.08605171882663853, 0.045920005286461674, 0.005913221639275434, 0.031076773448148742, 0.06657036457909271, 0.0389606824319344, 0.10355133839766495, 0.023971703922143206, 0.03320104500744492, 0.13290693779708818, 0.02143513222108595, 0.06511436731670983, 0.036714939851663075, 0.06751906679710373, 0.03915745175618213, 0.02223816940386314, 0.07073283341014758, 0.02927800229372224, 0.09631176944822073, 0.047734471008880064, 0.03580118907848373, 0.09048807725775987, 0.07644049081136473, 0.041920834919437766, 0.09056620314368047, 0.05670165213814471, 0.01228350698511349, 0.07000026686000638, 0.017057529621524736, 0.08940074185375124, 0.03297904637292959, 0.0224227804937982, 0.050037173423334025, 0.1150932784366887, 3.0553514510393143, 54.24953319132328, 91.05912700295448, 77.66286984086037, 77.31204986572266, 71.60625323653221, 71.36097639799118, 68.35371896624565, 38.12103644013405, 34.563788920640945, 25.392591543495655, 34.53338675200939, 48.05594153702259, 44.25040014088154, 44.02359791100025, 54.36844401061535, 43.732430934906006, 23.097778782248497, 4.6855684742331505, 0.11762005378841422, 0.09807068170630373, 0.017398039963154588, 0.10298455279553309, 0.17059990583220497, 0.20719967549666762, 0.15670293825678527, 0.41405894269701093, 0.4635082423919812, 0.8381359884515405, 2.2219963185489178, 2.878647157922387, 3.8526056706905365, 3.782251258380711, 6.681590443477035, 8.234151508659124, 5.5574943870306015, 3.440764294937253, 0.6230461550876498, 1.021216339431703, 1.143792774528265, 0.9161836223211139, 0.42494479450397193, 0.9261446096934378, 0.3900309023447335, 0.47375540190842, 0.1150264183524996, 0.10947395145194605, 0.19130636035697535, 0.6484628131147474, 1.4260662090964615, 1.5965634165331721, 2.729033036157489, 8.480063863098621, 14.411145653575659, 24.334072843194008, 28.249012269079685, 28.329567946493626, 15.606521610170603, 4.0069766622036695, 1.156104588881135, 0.6929694686550647, 0.652122194878757, 3.168872259557247, 1.6733945813030005, 2.2516292659565806, 1.7907921317964792, 2.3528810078278184, 2.907342268154025, 3.1733211083337665, 2.5435101287439466, 5.8962357603013515, 4.808561224490404, 3.791696601547301, 3.0740478727966547, 2.800326473079622, 1.0791599052026868, 0.2026337751885876, 0.617774591082707, 0.1744998325011693, 0.13532571581890807, 0.15542510838713497, 0.041560551908332855, 0.13966668600915, 0.20548896573018283, 0.08743687809328549, 1.1673943768255413, 13.68291663005948, 37.64684468507767, 62.93537691235542, 65.53966596722603, 86.13065466284752, 55.38092628121376, 30.011023320257664, 29.36127718538046, 30.08074387907982, 32.508547604084015, 56.27482831478119, 54.00452233850956, 76.87196508049965, 71.14941135048866, 76.49124830961227, 85.22112786769867, 78.85474428534508, 16.062821075320244, 0.34642637183424085, 0.09173313388600945, 0.09670639905380085, 0.06397156379534863, 0.0709465793624986, 0.03629529615864158, 0.035903857788071036, 0.0764536194037646, 0.04092061280971393, 0.07928156570415013, 0.05584297614404932, 0.028457754706323612, 0.037229177687549964, 0.04381279199151322, 0.03739450221473817, 0.02476874640706228, 0.005646272511512507, 0.050268018458154984, 0.03605910394981038, 0.030493001941067632, 0.018979007472808007, 0.07897302522906102, 0.023746159677102696, 0.047678769115009345, 0.06623113629757427, 0.031026479955471586, 0.023127125023165718, 0.07198420571512543, 0.03942564537283033, 0.0402146114356583, 0.029440335965773556, 0.01307273372731288, 0.07909301566542126, 0.04118921460758429, 0.07180018277722411, 0.05573126436502207, 0.046626592957181856, 0.0855946152296383, 0.09785076108528301, 0.21114156319526955, 0.12552690255688503, 0.09613517540856265, 0.1875549671240151, 0.11373821325832978, 0.1345910638337955, 0.09758155443705618, 0.11469496777863242, 0.19784304866334423, 0.20872535300441086, 0.20526682608760893, 0.11065212573157623, 0.15011818846687675, 0.15504030481679365, 0.09515038997051306, 0.18829522974556312, 0.14184629952069372, 0.11887942644534633, 0.11452231454313733, 0.15995753783499822, 0.126192104362417, 0.15341241873102263, 0.10859725982300006, 0.2183735548169352, 0.18258854455780238, 0.21074668125947937, 0.18022048490820453, 0.15443229291122407, 0.21243233612040058, 0.17116690665716305, 0.19606032088631764, 0.2108521552872844, 0.1456462440546602, 5.977700063958764, 66.53588131070137, 103.07602018117905, 82.86231324076653, 86.54823705554008, 82.87376582622528, 76.5879075229168, 72.42323219776154, 39.00117941200733, 40.088498666882515, 33.348933309316635, 43.341564908623695, 55.3769288957119, 48.28908182680607, 52.525478303432465, 71.82291761040688, 62.6829032599926, 29.292966350913048, 6.967603471130133, 0.2863507642177865, 0.2663928992114961, 0.16291780164465308, 0.2576000225963071, 0.2994944964302704, 0.32384275866206735, 0.13733237923588604, 0.3511740983230993, 0.4101203056052327, 0.7672483578789979, 1.6114916279911995, 3.797801211476326, 4.9114316795021296, 4.178086705505848, 13.73253246769309, 10.055972300469875, 9.107693284749985, 6.927558369934559, 4.697304619476199, 2.1434611827135086, 1.80510537000373, 1.395113782491535, 0.4176086053485051, 0.9133479057345539, 1.0031670704483986, 0.978657198138535, 0.9347667032852769, 0.5363885394763201, 2.147697717882693, 16.393543928861618, 6.805385900661349, 11.398822143673897, 7.148691304028034, 11.986998282372952, 13.816836643964052, 23.827516324818134, 27.37227201461792, 28.38397342711687, 17.07989349961281, 4.825388146564364, 1.8188054161146283, 1.2076088064350188, 1.3411634461954236, 3.9111244305968285, 3.0923419911414385, 2.3748951265588403, 3.618692122399807, 4.986452478915453, 9.778308849781752, 3.3603974198922515, 2.8513389732688665, 11.283422335982323, 9.11189965903759, 7.422884115949273, 4.887797897681594, 2.9339175671339035, 1.1033808742649853, 0.14767460786970332, 0.5232042563147843, 0.14844074175925925, 0.2850754279643297, 0.21916149300523102, 0.45456257241312414, 0.7237900898326188, 0.42078853002749383, 0.3210287127876654, 1.423860783688724, 19.30521748960018, 52.26792052388191, 90.86649253964424, 77.52074986696243, 86.4122423529625, 64.54902872443199, 43.482085168361664, 41.540347561240196, 29.828483015298843, 29.78513304144144, 48.606687784194946, 56.67910002171993, 84.49151381850243, 82.84538894891739, 86.06019884347916, 92.9650667309761, 92.03154042363167, 21.311796717345715, 0.5195321689825505, 0.164633973618038, 0.1777672118623741, 0.19263047055574134, 0.21137403353350237, 0.160612735489849, 0.07899497053585947, 0.23754992347676307, 0.11630119057372212, 0.10664405330317095, 0.23506969562731683, 0.13664112804690376, 0.12323730275966227, 0.14695907360874116, 0.12004222342511639, 0.17839165491750464, 0.09659855757490732, 0.14103548834100366, 0.1389610519981943, 0.22403783368645236, 0.1644838965148665, 0.13041896192589775, 0.17002111970214173, 0.24379953421885148, 0.16083907568827271, 0.21005559334298596, 0.11684062803396955, 0.19416950672166422, 0.21039886632934213, 0.1567219669232145, 0.04196641020826064, 0.1873512179008685, 0.10563894786173478, 0.13896595017286018, 0.20405746676260605, 0.14821462420513853, 0.12157831326476298, 0.16903971845749766, 0.1156859278853517], [0.15241369575960562, 0.07320060060010292, 0.016398246443714015, 0.046772918503847905, 0.054720288535463624, 0.08638707309728488, 0.1431302892160602, 0.0482972341706045, 0.08809738952550106, 0.14508881693473086, 0.3288692358182743, 0.14458538847975433, 0.024505150395270903, 0.010223111148661701, 0.00783559238698217, 0.09820865438086912, 0.12059847795171663, 0.05528328176296782, 0.10834580534719862, 0.07625783342518844, 0.1005820649152156, 0.024014520276978146, 0.09878131037112325, 0.2068716165376827, 0.1612586117698811, 0.09347310653538443, 0.17031735536875203, 0.37891225365456194, 0.30737191904336214, 0.6767195812426507, 0.6089365622028708, 0.25347798597067595, 3.059982927516103, 47.26144976913929, 74.00338500738144, 69.34785962104797, 70.58410048484802, 60.23195117712021, 52.510719895362854, 23.291800171136856, 25.219700820744038, 27.948150113224983, 20.40223192423582, 36.86640836298466, 55.66294714808464, 50.041357800364494, 44.556823298335075, 45.305823907256126, 37.54282906651497, 15.53960720077157, 1.641702144406736, 0.02053801483270945, 0.02930984785052715, 0.06714671646477655, 0.10499430354684591, 0.11303485021926463, 0.07793570315698162, 0.12724947184324265, 0.10368001938331872, 0.37101381341926754, 0.48748044355306774, 1.609815324191004, 4.027842292562127, 4.265920417383313, 3.4558043628931046, 5.916245961561799, 9.285101015120745, 10.87310990318656, 3.290984407067299, 2.8866222174838185, 0.09374975692480803, 2.056047823280096, 0.2667099446989596, 0.7044966251123697, 1.9619818520732224, 3.296909714117646, 2.0351254334673285, 4.220737516880035, 4.094237554818392, 7.020173650234938, 3.9637136086821556, 6.160902958363295, 5.277292197570205, 11.009487435221672, 39.19021166861057, 67.37286999821663, 83.18422436714172, 80.05012214183807, 87.02035412192345, 85.6576256453991, 82.13010773062706, 57.525181621313095, 20.99698171019554, 9.020335972309113, 4.656310519203544, 1.0239103948697448, 3.0324904527515173, 3.4878986282274127, 1.1828507599420846, 2.4648664612323046, 0.3892976901261136, 5.0240980088710785, 3.288459680043161, 4.624391281977296, 2.754937196150422, 1.4570543775334954, 0.9489178564399481, 1.795212363358587, 0.7576604629866779, 0.6845988740678877, 0.20151880220510066, 0.4191453556995839, 0.10869225472561084, 0.11382780532585457, 0.04164503428910393, 0.15994101762771606, 0.2320240848348476, 0.03344023549288977, 0.08417974037001841, 0.20483500004047528, 0.7991149323061109, 11.239166110754013, 27.250214964151382, 29.336969889700413, 36.89063586294651, 43.4970373660326, 32.89003573358059, 25.76715264469385, 21.058728396892548, 9.798196982592344, 20.3634550049901, 33.01762908697128, 37.91996642947197, 56.72540433704853, 62.5856626778841, 70.6484006345272, 75.62847420573235, 17.438172474503517, 1.178276517894119, 0.3476250887615606, 0.31611002516001463, 0.13844123692251742, 0.07936350622912869, 0.2104158466681838, 0.22432888916227967, 0.4301863757427782, 0.38575829879846424, 0.34627286600880325, 0.5409970984328538, 0.5143211642280221, 0.2209976257290691, 0.1700088891084306, 0.07032734618405811, 0.03241137390432414, 0.05002245292416774, 0.14460346719715744, 0.06999874545726925, 0.019469533690426033, 0.009103562824748224, 0.10675311190425418, 0.09775978862307966, 0.03526610802509822, 0.003714501999638742, 0.00885784607817186, 0.09166585819912143, 0.16222730744630098, 0.32212649763096124, 0.05359170085284859, 0.025431369249417912, 0.05615929803752806, 0.05077218906080816, 0.06847726108389907, 0.07425142233842053, 0.06226285040611401, 0.07735741426586173, 0.18696967978030443, 0.1420444529503584, 0.059991147500113584, 0.06276714717387222, 0.062168682998162694, 0.07044476136798039, 0.09688247359008528, 0.07693553299759515, 0.03819627032498829, 0.054093069848022424, 0.10499408832401969, 0.22621183656156063, 0.09282892235205509, 0.007955851851875195, 0.034198881112388335, 0.023353023643721826, 0.025382634266861714, 0.014795079441682901, 0.03852954658214003, 0.018118451989721507, 0.09000136938993819, 0.05801568768220022, 0.026268060973961838, 0.02939145440905122, 0.20499289938015863, 0.08048429765040055, 0.10533068198128603, 0.14592637511668727, 0.30446365009993315, 0.20578603260219097, 0.3627019375562668, 0.2655655232956633, 0.1040675985859707, 4.328975658863783, 57.96485982835293, 88.78409788012505, 82.72408425807953, 80.43162927031517, 72.56773844361305, 62.916092947125435, 37.26350225508213, 42.5834371894598, 35.093864277005196, 23.132662810385227, 33.918317556381226, 40.04104681313038, 34.20255370438099, 46.976981833577156, 49.79682572185993, 41.97490744292736, 18.596720807254314, 2.2727050725370646, 0.009593089926056564, 0.036172652544337325, 0.008800458581390558, 0.13851525873178616, 0.39576117298565805, 0.4835280915722251, 0.41917670401744545, 0.5853190482594073, 1.5575036499649286, 1.2323824083432555, 4.31342831812799, 7.328549427911639, 4.122292874380946, 3.702534385956824, 7.413658685982227, 8.86591225862503, 7.827897733077407, 7.628363789990544, 4.141742130741477, 1.2561938306316733, 2.0855425531044602, 1.8593702581711113, 1.3796749734319746, 2.994327675551176, 4.892083117738366, 3.146382928825915, 4.690704848617315, 5.408672522753477, 8.336970191448927, 5.771139347925782, 5.176571952179074, 5.661421185359359, 12.582201194018126, 41.51116892695427, 69.65780898928642, 89.96616885066032, 90.15619665384293, 98.14542755484581, 94.62495446205139, 87.23514139652252, 56.80143445730209, 21.154483258724213, 9.366504997015, 5.955087002366781, 2.3376376507803798, 5.707124657928944, 5.765459602698684, 3.637593970634043, 2.91442746296525, 1.72292290488258, 2.7821541856974363, 2.2593540139496326, 6.715112719684839, 2.5113225309178233, 1.3718275632709265, 1.885856855660677, 2.6755288196727633, 1.4571766834706068, 1.9951135804876685, 1.483939359895885, 1.0277339396998286, 0.726505994098261, 0.263215527520515, 0.04903930763248354, 0.18353984429268166, 0.27481395984068513, 0.0073609193714219145, 0.014073684069444425, 0.3335618949495256, 1.2666647625155747, 13.361879456788301, 30.697868764400482, 35.66265195608139, 34.981922283768654, 36.65730178356171, 27.085421606898308, 21.283024661242962, 26.447701826691628, 18.58729161322117, 30.810713209211826, 49.84018139541149, 46.19824782013893, 62.595192566514015, 69.58802953362465, 78.54428574442863, 89.95580300688744, 23.740075416862965, 1.2263166275806725, 0.21319541236152872, 0.25762709614355117, 0.05277028067212086, 0.08365605128346942, 0.23864080634666607, 0.19376620883122087, 0.3598234732635319, 0.27040459332056344, 0.19908044632757083, 0.18664396600797772, 0.3690733347320929, 0.09478488223976456, 0.0885542259493377, 0.022055103836464696, 0.08409222631598823, 0.051851754178642295, 0.06661599923972972, 0.05717406624171417, 0.045216853759484366, 0.05600987402431201, 0.02918536185461562, 0.060527916939463466, 0.009398317906743614, 0.04374610631202813, 0.09381893250974827, 0.06990970257902518, 0.08505813151714392, 0.1133915115497075, 0.06830049635027535, 0.024726061783439945, 0.016830350796226412, 0.0639043326373212, 0.1019616358098574, 0.03816727832600009, 0.07941199073684402, 0.05478299630340189, 0.10523691162234172, 0.2577747538452968, 0.15163331263465807, 0.2528933814028278, 0.21239131019683555, 0.24130174715537578, 0.26213837438263, 0.19343065418070182, 0.11285316504654475, 0.1905755972256884, 0.37678407097700983, 0.3997594490647316, 0.34642856859136373, 0.14590975100873038, 0.15280286315828562, 0.11818166662123986, 0.22834616422187537, 0.11076810114900582, 0.11881539394380525, 0.1740756060462445, 0.21509094658540562, 0.17734666645992547, 0.13487177377101034, 0.2679144503781572, 0.46877710497938097, 0.37431355041917413, 0.27213640976697206, 0.4120477818651125, 0.44190592656377703, 0.301377295400016, 0.9021640964783728, 0.5718424776569009, 0.3953363379696384, 8.377915844321251, 73.76877799630165, 96.9859729707241, 86.71039715409279, 90.63554853200912, 78.53581219911575, 71.6358232498169, 38.293858766555786, 41.50641918182373, 43.08578163385391, 33.93410570919514, 52.56934694945812, 77.59594023227692, 64.76114094257355, 61.51227347552776, 62.574517875909805, 54.41623404622078, 24.19726688414812, 2.860927521251142, 0.13419187744148076, 0.19896425568731502, 0.3571845742408186, 0.2632360701682046, 0.3587378893280402, 0.435697267530486, 0.2263805564143695, 0.36301126470789313, 0.9238431206904352, 2.4402509070932865, 3.631723285652697, 13.420997634530067, 10.52746620029211, 11.458395346999168, 18.177172020077705, 25.798018388450146, 27.816386483609676, 13.57089389115572, 8.432121835649014, 1.7792109469883144, 3.722797748632729, 1.7521354998461902, 1.9043138902634382, 5.699305152520537, 7.975879367440939, 4.50347607024014, 7.892316151410341, 7.377628544345498, 11.29636064171791, 7.748546591028571, 11.058595050126314, 9.853106886148453, 15.6444644741714, 44.7737954556942, 64.23357725143433, 83.50833937525749, 82.22380310297012, 91.71292752027512, 86.45359173417091, 79.88280192017555, 58.420447781682014, 27.586550116539, 11.73464147374034, 7.961816322058439, 3.325526691041887, 7.719813957810402, 9.025334604084492, 6.22364186681807, 9.516072571277618, 8.511473927646875, 18.567675165832043, 12.944577299058437, 14.88592067733407, 11.558163743466139, 6.367484573274851, 7.332778126001358, 6.161324260756373, 3.7841046089306474, 3.173952824436128, 1.4881901443004608, 0.7270875410176814, 0.45069785322993994, 0.25235636334400624, 0.06423585742595606, 0.34587329369969666, 0.531752253882587, 0.13677664421265945, 0.20472355914535, 0.3485346055822447, 1.8617298128083348, 17.993313185870647, 41.95653922855854, 49.88720387220383, 56.5231753885746, 63.00244711339474, 47.68126644194126, 39.624623358249664, 32.16788448393345, 18.772180192172527, 33.02473470568657, 49.83661338686943, 54.96676370501518, 75.08363664150238, 83.00947174429893, 85.94293713569641, 101.98490113019943, 26.67703092098236, 1.7215005937032402, 0.4155124834505841, 0.3731385525316, 0.2466011862270534, 0.2811738388845697, 0.3193334396928549, 0.30921107972972095, 0.49711610306985676, 0.3920311387628317, 0.5795289308298379, 0.6696868711151183, 0.543167672585696, 0.23421555786626413, 0.22336650174111128, 0.2277921509812586, 0.17295775352977216, 0.19828579912427813, 0.2238747096271254, 0.22779145336244255, 0.08771545806666836, 0.15759743400849402, 0.2215592237189412, 0.21161278244107962, 0.1534049675683491, 0.12090603879187256, 0.25277279724832624, 0.27465451683383435, 0.2608337381388992, 0.4504553193692118, 0.14666191767901182, 0.09082545759156346, 0.1296420520520769, 0.19938679004553705, 0.14184021390974522, 0.19649659981951118, 0.16963783011306077, 0.1577343899407424, 0.3477568941889331], [0.28579991252627224, 0.01585853624419542, 0.020548223074001726, 0.18763553467579186, 0.004685903732024599, 0.0352090776868863, 0.10496476606931537, 0.017328352296317462, 0.10191786393988878, 0.06808085032389499, 0.26355166104622185, 0.008183147565432591, 0.0022394306142814457, 0.02704225273191696, 0.0436060185165843, 0.046181356301531196, 0.022007756670063827, 0.009130881280725589, 0.010097237336594844, 0.07663467375095934, 0.17075176408980042, 0.034578085178509355, 0.12010761405690573, 0.04052945274452213, 0.24577045580372214, 0.06985218613408506, 0.3305214346619323, 0.2661737578455359, 0.3411322762258351, 0.19153838540660217, 0.2130627163569443, 1.1851343186572194, 48.952917605638504, 64.91560265421867, 68.06909903883934, 64.47624742984772, 53.093867003917694, 44.529571160674095, 34.37213100492954, 25.6123698502779, 15.582414753735065, 39.65230867266655, 52.113561406731606, 36.85364864766598, 49.565942510962486, 81.19855731725693, 56.72054439783096, 31.028333231806755, 14.683173056691885, 0.8538479672279209, 0.06652213982306421, 0.054970002674963325, 0.09585756764863618, 0.05729313270421699, 0.19976982730440795, 0.16557172173634171, 0.5633199505973607, 1.1164616723544896, 2.3487682035192847, 2.675050045363605, 0.9718075906857848, 3.510100361891091, 4.778094459325075, 2.994053140282631, 4.40010879188776, 3.696802156046033, 6.531468098983169, 6.384687200188637, 4.647011943161488, 3.3102118503302336, 0.8778891584370285, 2.739336658269167, 7.907153405249119, 10.951070319861174, 17.317635342478752, 19.38512910157442, 22.581259198486805, 27.830223441123962, 41.597397699952126, 42.618478909134865, 38.12441445887089, 39.272595047950745, 42.14849732816219, 54.66682679951191, 75.03475606441498, 78.97538781166077, 57.52923600375652, 54.306906312704086, 54.2985999584198, 60.77783368527889, 62.97632731497288, 74.57630306482315, 58.067743107676506, 43.928253427147865, 27.06111241132021, 23.361496031284332, 19.876133054494858, 21.391904018819332, 15.640807170420885, 13.932868167757988, 9.46771826595068, 9.683903865516186, 5.043933894485235, 3.790588011033833, 3.0785632180050015, 2.7889600954949856, 1.9266621535643935, 2.6221290975809097, 3.6013733642175794, 0.41159103449899703, 0.9868983621709049, 1.1169209727086127, 0.2656245091930032, 0.3134344343561679, 0.1479931376525201, 0.13604356558062136, 0.0732792608323507, 0.11032486087060533, 0.09937748502125032, 0.06040131767804269, 0.14466003369307145, 0.2426107323844917, 6.315333321690559, 23.304084911942482, 50.919551476836205, 63.07200238108635, 54.94577743113041, 54.6390350908041, 35.048278123140335, 45.17645224928856, 19.803102873265743, 10.392009168863297, 34.85183246433735, 58.663459941744804, 72.78783783316612, 69.52240705490112, 70.5147922039032, 69.45201963186264, 22.44889710098505, 1.8942032265476882, 0.3883138397941366, 0.10347721268772148, 0.07904381869593635, 0.4080218682065606, 0.4734494589501992, 0.08947586204158142, 0.38064599968492985, 0.06771484535420313, 0.16865112993400544, 0.23887529532657936, 0.3997997922124341, 0.1460939520620741, 0.09115791006479412, 0.019921924649679568, 0.06964206928387284, 0.04058080194226932, 0.07116658161976375, 0.09964519995264709, 0.07700201458646916, 0.18253144371556118, 0.07229366645333357, 0.08878900436684489, 0.07602450219565071, 0.03855098722851835, 0.031156097902567126, 0.11682067168294452, 0.14548700884915888, 0.035716536003747024, 0.06990357243921608, 0.06266139855142683, 0.1270503833075054, 0.0065723308762244415, 0.027026159259548876, 0.04820387199288234, 0.06607451345189475, 0.11213766047148965, 0.10489185006008483, 0.08083782711764798, 0.036496336542768404, 0.13375341659411788, 0.03696156665682793, 0.06236779008759186, 0.15773550316225737, 0.06432751266402192, 0.04565656141494401, 0.09593507013050839, 0.1864144642604515, 0.12071980425389484, 0.11791013705078512, 0.06470453852671199, 0.05110143916681409, 0.03178971019224264, 0.03980260815296788, 0.007790389099682216, 0.04339578292274382, 0.12026375450659543, 0.1629381810198538, 0.06256540174945258, 0.16281979362247512, 0.049494566992507316, 0.15926394145935774, 0.052507122527458705, 0.21296182880178094, 0.3957085992442444, 0.3579385072225705, 0.09816147605306469, 0.20331238018115982, 1.465701526030898, 58.51261183619499, 76.44068822264671, 76.75936952233315, 71.95348620414734, 63.05785194039345, 52.86552965641022, 47.67584793269634, 29.5492796972394, 25.72882980108261, 48.48905749619007, 50.39402827620506, 31.45645435899496, 46.97904512286186, 60.53200967609882, 48.39935190975666, 30.99893420934677, 16.09204910695553, 1.399119005072862, 0.06019131214998197, 0.20026877318741754, 0.14039961621165276, 0.10830461615114473, 0.5324350297451019, 0.9142028004862368, 1.1519580613821745, 2.3575492948293686, 3.0989187257364392, 3.5031645465642214, 3.9065022161230445, 4.7516578529030085, 4.493431784212589, 7.3860664665699005, 7.186627993360162, 5.054218042641878, 5.2567471750080585, 6.455955225974321, 4.363400861620903, 3.6105859698727727, 2.071044431068003, 3.508573081344366, 7.917945776134729, 10.261920299381018, 18.85669905692339, 20.769088938832283, 23.378629311919212, 30.772998332977295, 46.053331196308136, 48.74287627637386, 42.37544395029545, 41.31351873278618, 48.46502758562565, 63.09218689799309, 86.26373872160912, 93.56336742639542, 72.0090240240097, 66.57555878162384, 65.20636305212975, 69.91137698292732, 77.16027081012726, 85.62207475304604, 64.65807527303696, 45.54352395236492, 30.547049157321453, 26.752076894044876, 22.663969360291958, 21.805967800319195, 16.317764595150948, 15.140239130705595, 10.510020386427641, 9.19787384569645, 5.233782632276416, 2.113551562651992, 1.9814993860200047, 0.416640488547273, 1.4518868923187256, 1.7366589303128421, 3.575997850857675, 2.605640357360244, 2.262999680824578, 2.870739782229066, 1.7813167464919388, 0.9334334498271346, 0.4145953373517841, 0.41974794992711395, 0.6243915797676891, 0.11599764475249685, 0.10869114892557263, 0.2543989912373945, 0.08642674831207842, 0.2335337022668682, 6.161093898117542, 26.339392438530922, 48.15358489751816, 49.2299797385931, 42.22972556948662, 38.02818462252617, 25.63137073069811, 33.56850452721119, 31.281069070100784, 21.994853764772415, 43.448084592819214, 63.61203320324421, 84.23163816332817, 80.6324864923954, 79.00295153260231, 82.50637114048004, 31.800886876881123, 2.2188954474404454, 0.38449296669568866, 0.1364312635269016, 0.07918660790892318, 0.3641021327348426, 0.3402721864404157, 0.15787106385687366, 0.16444347915239632, 0.12474096816731617, 0.1504053402459249, 0.23204676486784592, 0.326986139989458, 0.13728203193750232, 0.1358003044151701, 0.039597107461304404, 0.04591567114403006, 0.0522179483959917, 0.1827772578690201, 0.04616616824932862, 0.050060836802003905, 0.16982183820800856, 0.03180489453370683, 0.05592141373199411, 0.019464271863398608, 0.02998998352268245, 0.03492510601063259, 0.04602772431098856, 0.08599769047577865, 0.04672065275372006, 0.04322301836509723, 0.08904463713406585, 0.06626184636843391, 0.021757409849669784, 0.048482863858225755, 0.033893650615937077, 0.09446030395338312, 0.06058102873794269, 0.398147088708356, 0.23151780653279275, 0.18060696573229507, 0.36486823693849146, 0.2453288037213497, 0.14728374837432057, 0.3875808650627732, 0.20721598790260032, 0.1819578229333274, 0.2219690673518926, 0.4020981048233807, 0.20219966332660988, 0.1113747178169433, 0.13502887159120291, 0.15280949795851484, 0.1295178462169133, 0.1550245119142346, 0.04820194611966144, 0.13659754913533106, 0.22995929641183466, 0.4079959524096921, 0.13903905171900988, 0.28979519032873213, 0.16347932541975752, 0.4720123641891405, 0.202783124987036, 0.6153936625923961, 0.6279648130293936, 0.6146421935409307, 0.34187673940323293, 0.5666763579938561, 2.747441385872662, 70.6381107866764, 84.4634485244751, 86.70975118875504, 83.34760800004005, 72.38242238759995, 60.51216334104538, 50.685894414782524, 38.54554206132889, 23.94699141383171, 56.73636294901371, 70.3049598634243, 51.7277605086565, 67.1324796974659, 107.97771155834198, 77.73590952157974, 47.11200378835201, 24.313080869615078, 1.7197737051174045, 0.21299774874933064, 0.4038731736363843, 0.7110659976024181, 0.22848035936476663, 0.6706317735370249, 1.0963359335437417, 1.3411573902703822, 3.271353472955525, 4.798679379746318, 7.033323319628835, 5.018352717161179, 11.204679161310196, 14.892093446105719, 16.715084575116634, 18.56785375624895, 14.458671603351831, 16.69466447085142, 17.20016084611416, 15.301206093281507, 11.901099141687155, 3.318401360884309, 4.5895324274897575, 11.368756256997585, 15.899076461791992, 27.401481047272682, 30.639414601027966, 27.44639463722706, 36.497106179594994, 53.522328212857246, 54.9287049472332, 45.55822916328907, 46.905522868037224, 54.218735843896866, 69.35584679245949, 89.78599011898041, 92.47460424900055, 72.76531264185905, 70.05522966384888, 70.37423014640808, 77.07733646035194, 78.57750356197357, 83.83332073688507, 72.50360548496246, 56.13903500139713, 36.73251494765282, 31.658394522964954, 27.417007014155388, 28.545295670628548, 20.96285954117775, 19.833497442305088, 14.193554129451513, 13.87737499549985, 11.041776202619076, 11.506508365273476, 9.691757094115019, 8.185888398438692, 7.698008352890611, 13.101078551262617, 13.680025935173035, 6.570286341011524, 5.0714505929499865, 3.375371228903532, 1.6068292781710625, 0.7830644154455513, 0.34612796909641474, 0.30363033700268716, 0.7936436415184289, 0.18337651243200526, 0.6511929666157812, 0.4048542631790042, 0.4797060013515875, 0.500142581295222, 9.268874935805798, 35.51410272717476, 70.9866812825203, 90.35823181271553, 84.55698430538177, 77.73533955216408, 50.6886150687933, 64.75087389349937, 31.14940043538809, 20.176641829311848, 51.6847962141037, 76.50023102760315, 91.61863937973976, 89.063610881567, 87.78345957398415, 94.56343576312065, 37.81754292547703, 2.4135373905301094, 0.7461870380211622, 0.26164256036281586, 0.261645321152173, 0.841801188653335, 0.5875811737496406, 0.31679152452852577, 0.6379815505351871, 0.3791942400857806, 0.36428274179343134, 0.6294719665311277, 1.1070101545192301, 0.4766399518121034, 0.2675174904288724, 0.09964594210032374, 0.17298442631727085, 0.16792403301224113, 0.351827900740318, 0.1464878988917917, 0.15266344329575077, 0.3080955723999068, 0.11115752087789588, 0.17871355405077338, 0.23257303662830964, 0.138367140898481, 0.20318029273767024, 0.24052750901319087, 0.41131296660751104, 0.311547449673526, 0.12342845773673616, 0.23477519658626989, 0.16844610421685502, 0.19022508087800816, 0.16775756928836927, 0.19186116027412936, 0.22885913669597358, 0.24034915608353913], [0.048529155319556594, 0.027898190201085526, 0.03859949400066398, 0.04058220460137818, 0.032637502590660006, 0.01002996164970682, 0.10158048360608518, 0.07177106832386926, 0.12245509395143017, 0.036432875494938344, 0.07960657443618402, 0.0944756218814291, 0.010745934705482796, 0.0648318613821175, 0.03159317093377467, 0.028029743298247922, 0.054504601866938174, 0.025753060581337195, 0.027400875187595375, 0.11428038924350403, 0.08953571625170298, 0.048485721126780845, 0.03655203472590074, 0.11108216320280917, 0.08980303784483112, 0.04810202706721611, 0.18594247318105772, 0.0389471382368356, 0.13024451269302517, 0.3810177859850228, 0.33536822302266955, 40.06196849048138, 66.73765048384666, 69.75367784500122, 66.51640355587006, 63.275074884295464, 47.94561065733433, 32.03370988368988, 24.81880333274603, 35.09609095752239, 33.60751323401928, 32.81893014907837, 39.26555022597313, 51.82196505367756, 57.52236217260361, 39.944520592689514, 28.397103622555733, 9.723166208714247, 0.7694826973602176, 0.05289528431603685, 0.4604836937505752, 0.115565729647642, 0.04471000771445688, 0.29811056912876666, 0.49897729069925845, 0.5839076614938676, 1.2189546413719654, 2.1192256081849337, 2.1771209640428424, 3.7039426853880286, 2.266751267015934, 6.704513663426042, 4.203577637672424, 3.633863995783031, 2.5055791391059756, 8.626949731260538, 6.393924979493022, 8.502800893038511, 10.40914149954915, 14.892204590141773, 22.995818853378296, 28.124713338911533, 36.64442427456379, 35.88413827121258, 41.885361447930336, 48.364678770303726, 50.165930315852165, 50.864800214767456, 51.608868688344955, 51.660732105374336, 55.930882170796394, 61.04839436709881, 55.53067624568939, 46.798212826251984, 57.195363119244576, 45.2505786716938, 47.79023699462414, 53.49011734127998, 56.36889986693859, 57.000893354415894, 46.54164679348469, 33.72929289937019, 34.758110493421555, 46.33032113313675, 46.94560691714287, 49.45832468569279, 43.58060248196125, 44.34565722942352, 44.26942951977253, 36.33515127003193, 34.782524183392525, 32.98593498766422, 21.2743953242898, 15.982814468443394, 4.4779319409281015, 1.665712462272495, 1.2593562109395862, 0.5627223732881248, 0.27989378257188946, 1.271556168794632, 1.1121004563756287, 1.457966803573072, 0.6337041081860662, 1.2029273388907313, 0.3555892239091918, 0.46876511187292635, 0.1646997279021889, 0.11612644448177889, 0.0437794881145237, 0.1094621884112712, 0.16060476482380182, 0.16175758733879775, 0.02712899680773262, 0.5385185626801103, 11.351450085639954, 40.72817534208298, 50.79539693892002, 39.27712060511112, 52.68915072083473, 29.7813693434, 17.923579327762127, 26.953646577894688, 24.502255618572235, 44.87572878599167, 36.236345171928406, 51.73301562666893, 57.255681082606316, 70.89448302984238, 65.31281813979149, 27.821753695607185, 1.5719935786910355, 0.363314506248571, 0.01973446927877376, 0.20399947534315288, 0.04732807836262509, 0.08265650452813134, 0.011027489763364429, 0.11230922274990007, 0.023292982041311916, 0.031430288072442636, 0.1306089962599799, 0.02255388088087784, 0.0664949623751454, 0.05134343868121505, 0.06936314792255871, 0.052055781707167625, 0.09425026873941533, 0.03529389032337349, 0.08123534367769025, 0.08348123839823529, 0.039443367859348655, 0.017826515213528182, 0.010405446628283244, 0.057834225153783336, 0.04199958792014513, 0.07539645230281167, 0.10001572460168973, 0.08197506453143433, 0.12214755537570454, 0.010993990144925192, 0.06400527214282192, 0.030921931756893173, 0.16532231558812782, 0.015199704848782858, 0.05504542343260255, 0.020311522494012024, 0.03017007307789754, 0.04879104810243007, 0.04029987678222824, 0.10445479929330759, 0.027106403977086302, 0.036845476206508465, 0.07574582574306987, 0.04201787443889771, 0.04444179554411676, 0.12221896482515149, 0.09597050026059151, 0.03569379659893457, 0.028308666514931247, 0.05966401622572448, 0.061989832829567604, 0.0483603760949336, 0.007992314494913444, 0.02119265958754113, 0.045548994530690834, 0.05528913730813656, 0.12353225451079197, 0.0023146871717472095, 0.06840844172984362, 0.03128947668301407, 0.09831608025706373, 0.0519079681544099, 0.19739051669603214, 0.16901521274121478, 0.069141542626312, 0.43152120255399495, 0.7418210722971708, 47.2337606549263, 78.52712586522102, 77.62410432100296, 78.4731687605381, 70.6775526702404, 58.19811411201954, 43.59552428126335, 38.84853020310402, 39.94380623102188, 24.98453713953495, 33.523001968860626, 44.089535772800446, 48.70218425989151, 50.8297660946846, 46.58858187496662, 27.055494412779808, 11.033392902463675, 1.0814281459897757, 0.0681710361095611, 0.3131985798245296, 0.04899673804175109, 0.12049255121382885, 1.058810215909034, 2.1015432570129633, 2.4871848011389375, 2.470648563466966, 2.071569040417671, 2.748300852254033, 4.103482933714986, 4.756879722699523, 2.944996110163629, 4.12529518827796, 4.466820862144232, 5.278831589967012, 4.070531576871872, 4.127223584800959, 5.722446385771036, 8.806422650814056, 14.234061855822802, 21.360171921551228, 27.518851049244404, 35.85899882018566, 38.603378757834435, 42.47210696339607, 48.92545647919178, 52.66423165798187, 54.33656372129917, 57.37385094165802, 58.039263635873795, 58.30279849469662, 63.062951266765594, 59.32095766067505, 53.326418325304985, 64.18149724602699, 52.544085904955864, 52.09581255912781, 57.468078285455704, 60.8072517067194, 63.735477179288864, 54.80497218668461, 44.76732440292835, 43.273468762636185, 53.10436964035034, 52.53140598535538, 53.017240315675735, 47.474291548132896, 46.060953587293625, 44.550975412130356, 40.35793460905552, 36.86106964945793, 32.9190281778574, 25.189118161797523, 14.697104059159756, 4.873368171975017, 2.086220341734588, 1.4253269112668931, 0.7064804749097675, 1.1302846181206405, 3.511830694042146, 3.230447955429554, 2.7803402580320835, 3.4038894111290574, 3.413701909594238, 0.8283188589848578, 1.9333294895477593, 0.32771451340522617, 0.4707016720203683, 0.35784330451861024, 0.27582363691180944, 0.05522383202333003, 0.048297141402144916, 0.15162108204094693, 0.35987877810839564, 11.862630005925894, 39.523829966783524, 49.48375292122364, 43.98074381053448, 44.29743401706219, 34.798449128866196, 16.766881495714188, 25.88132131844759, 36.925677582621574, 59.05536711215973, 52.53200635313988, 61.24522380530834, 64.115130007267, 78.81993815302849, 80.41294187307358, 40.178375244140625, 2.1743331011384726, 0.280792701523751, 0.037050064056529664, 0.23007283016340807, 0.21731369371991605, 0.0561564778763568, 0.026014845752797555, 0.11284155785688199, 0.07346631173277274, 0.024752595418249257, 0.092010103398934, 0.032006094479584135, 0.07003614970017225, 0.013875677213945892, 0.024312982386618387, 0.013124148790666368, 0.1228171655384358, 0.020699654596683104, 0.026459601867827587, 0.13865319429896772, 0.03793682291870937, 0.03603447948989924, 0.039578401629114524, 0.045437564767780714, 0.033615452848607674, 0.12863167736213654, 0.06533506719279103, 0.029921089953859337, 0.08606578994658776, 0.0047066755178093445, 0.0740850847796537, 0.041504170949338004, 0.11659394556772895, 0.05326718193828128, 0.049429050195612945, 0.05892403562029358, 0.19134282949380577, 0.24805929861031473, 0.22595965478103608, 0.28086365084163845, 0.18228708417154849, 0.17479068017564714, 0.12497596180764958, 0.29149301641155034, 0.3467435063794255, 0.16591126914136112, 0.269293449819088, 0.20075890235602856, 0.12108070324757136, 0.14905711024766788, 0.17106459417846054, 0.1549529391922988, 0.11799706480815075, 0.13236847997177392, 0.09959693066775799, 0.31129378359764814, 0.2206239543738775, 0.16191743110539392, 0.13746087468462065, 0.24812926829326898, 0.1894632217590697, 0.1383798464667052, 0.32755720778368413, 0.422381327371113, 0.24172649311367422, 0.6849992775823921, 1.8399665993638337, 62.34324708580971, 85.04504531621933, 87.86370366811752, 89.96041595935822, 83.29212337732315, 66.40161171555519, 48.05125258862972, 39.453590735793114, 48.67014817893505, 44.07280147075653, 43.30364674329758, 54.18693155050278, 72.45023354887962, 77.18656539916992, 55.730256736278534, 42.28274792432785, 15.605412069708109, 1.948679715860635, 0.2505887456936762, 0.9264609427191317, 0.7001054857391864, 0.2986187918577343, 0.9701353835407645, 3.223761976696551, 2.9793488793075085, 4.816679488867521, 6.873591765761375, 8.42223571613431, 9.756002146750689, 7.67381695099175, 16.288941241800785, 11.964871119707823, 11.415856629610062, 12.344074621796608, 20.034191273152828, 15.133201908320189, 17.788954451680183, 17.859193682670593, 22.76682984083891, 30.997959561645985, 33.22401121258736, 42.505716159939766, 41.37228637933731, 45.404265224933624, 50.37967264652252, 53.48596416413784, 57.06253744661808, 58.3634964376688, 61.81988976895809, 66.69279769062996, 68.16157847642899, 68.46107840538025, 63.486214354634285, 69.28577095270157, 61.43612176179886, 58.929856047034264, 66.34705424308777, 69.09492999315262, 71.25007554888725, 61.97138763964176, 48.449991792440414, 49.453365951776505, 62.78678968548775, 58.25652837753296, 58.20070557296276, 51.01405240595341, 50.92453680932522, 48.72631676495075, 41.68950095772743, 39.90854412317276, 39.619546830654144, 25.46376172453165, 20.873796120285988, 7.366956816986203, 3.927057688124478, 3.9842674182727933, 3.246274581179023, 5.143518475815654, 8.810620475560427, 9.361732453107834, 8.024545256048441, 8.209147900342941, 5.583075564354658, 1.9118094630539417, 2.579324869439006, 0.3246916568605229, 0.44159594632219523, 0.6263207481242716, 0.31027799122966826, 0.305919298552908, 0.2670652256347239, 0.30924498103559017, 1.0055737663060427, 18.219207264482975, 58.28679755330086, 72.50216916203499, 59.905867874622345, 76.09410881996155, 49.214316979050636, 27.659055925905704, 39.64862287044525, 36.086880192160606, 60.5484551936388, 54.366202130913734, 65.49756422638893, 77.1880853176117, 87.13142976164818, 90.615204423666, 46.332452818751335, 2.8861232567578554, 0.6753965991083533, 0.239312746853102, 0.48276753863319755, 0.44870966929011047, 0.3030046768253669, 0.25054858066141605, 0.2371422023861669, 0.2185288121108897, 0.18055381311569363, 0.3229107102379203, 0.11849942457047291, 0.21825513773364946, 0.18443949054926634, 0.1242625575105194, 0.2051700500305742, 0.2227338356897235, 0.07380290539003909, 0.15066593798110262, 0.23591663455590606, 0.15003496402641758, 0.15306576155126095, 0.15059155994094908, 0.11805166461272165, 0.14468391600530595, 0.27786222752183676, 0.2526710933307186, 0.18435844802297652, 0.27460310084279627, 0.27376049605663866, 0.20932506769895554, 0.18205979402409866, 0.25398148864042014, 0.10995294840540737, 0.15083048696396872, 0.2474046649876982], [0.04543956856650766, 0.05406099051469937, 0.02556741234002402, 0.0612306194670964, 0.05778326929430477, 0.034501818372518755, 0.03275569702964276, 0.08732419039006345, 0.07033565081655979, 0.18185908760642633, 0.0304555179172894, 0.037677583313779905, 0.027872474784089718, 0.03944091506127734, 0.03205919885658659, 0.07531729483162053, 0.03317902177514043, 0.026892318492173217, 0.05122285452671349, 0.0307305949536385, 0.05798155631055124, 0.06916408165125176, 0.07405838230624795, 0.04014243386336602, 0.0007221567693704856, 0.07625382582773454, 0.08414200958213769, 0.135945824731607, 0.06026079201546963, 2.209418280981481, 44.41262483596802, 69.82541799545288, 72.09604695439339, 68.823943734169, 57.95578591525555, 45.55404178798199, 23.13041903078556, 20.051710233092308, 29.55590084195137, 16.43921557813883, 46.05716899037361, 58.139164075255394, 49.18567031621933, 41.181456819176674, 30.774858333170414, 10.338522288948298, 3.517537987791002, 0.5587532487697899, 0.09777530693099834, 0.029821000207448378, 0.16010109888156876, 0.1696750710834749, 0.23598127561854199, 0.5825662147253752, 0.8585038455203176, 0.5657559167593718, 1.6080864169634879, 1.1367471213452518, 1.1480669514276087, 4.140813080593944, 10.23370111361146, 5.021195439621806, 8.561028018593788, 13.112441841512918, 17.39964634180069, 13.618938513100147, 18.731345683336258, 28.571328073740005, 41.34909622371197, 44.85212445259094, 53.677340894937515, 55.34021906554699, 59.109791591763496, 63.47480356693268, 63.65172207355499, 66.24385938048363, 67.64710888266563, 73.50647807121277, 71.48156672716141, 66.50430500507355, 72.7258175611496, 67.04591274261475, 69.69004645943642, 42.98263616859913, 41.8788105994463, 44.216961935162544, 45.727232694625854, 47.99220755696297, 49.98515501618385, 50.59368096292019, 45.174749940633774, 28.893761672079563, 28.46011184155941, 47.11054086685181, 57.41605527698994, 73.25872376561165, 69.12443920969963, 69.63845282793045, 68.2386763393879, 65.80014958977699, 60.93916542828083, 55.137659534811974, 52.276318073272705, 29.43893361836672, 21.006209515035152, 10.770360566675663, 6.145030735060573, 2.78091283980757, 1.0102135548368096, 2.6385691529139876, 2.2963918140158057, 2.627631202340126, 3.372953371144831, 2.8301589097827673, 0.42778208444360644, 0.10675898971385323, 0.39246710599400103, 0.1199069076392334, 0.30733965046238154, 0.19041140447370708, 0.0700032502936665, 0.10963048523990437, 0.08777926792390645, 0.14411486685276031, 0.16095930361188948, 5.806226190179586, 23.007377833127975, 40.506692826747894, 37.95410759747028, 38.19083869457245, 47.02226020395756, 27.352571971714497, 17.52167299389839, 36.07417367398739, 34.52107921242714, 33.711517453193665, 56.506080105900764, 62.48444750905037, 73.98541197180748, 74.36716228723526, 31.583276353776455, 1.4436821825802326, 0.22962751187151298, 0.0867408252088353, 0.028144329044152983, 0.037905341014266014, 0.05442820147436578, 0.0451807705394458, 0.04624801229510922, 0.03584926169423852, 0.004189741366644739, 0.0602892608003458, 0.0488387793302536, 0.038523843177245, 0.08631362274172716, 0.0164111523918109, 0.014808005798840895, 0.05351953070203308, 0.03203324224159587, 0.05561675097851548, 0.15222091547911987, 0.010519983206904726, 0.036015962905366905, 0.03724777590832673, 0.048536328176851384, 0.08033300342503935, 0.06873477148474194, 0.05744060857978184, 0.07226941306726076, 0.16186561435461044, 0.04895082878647372, 0.09835383330937475, 0.0506850460806163, 0.030243853689171374, 0.03878073759551626, 0.027145995700266212, 0.04389759349578526, 0.031521104683633894, 0.0657712941756472, 0.027237060930929147, 0.08792135951807722, 0.07580334218800999, 0.0490848643676145, 0.06389021698851138, 0.05772104392235633, 0.10993030547979288, 0.037294649955583736, 0.03459433821262792, 0.03199132203008048, 0.05983680304780137, 0.0474654053687118, 0.10427194894873537, 0.04699473160144407, 0.06754894566256553, 0.055255094994208775, 0.04467355342057999, 0.029395805249805562, 0.08300012632389553, 0.08598480679211207, 0.010221322572760982, 0.07932320018881, 0.11746514530386776, 0.032322286497219466, 0.031757367396494374, 0.04360498322057538, 3.2340330630540848, 51.64919592440128, 82.71567150950432, 77.37994462251663, 78.50564941763878, 66.10151141881943, 61.88646599650383, 40.386923253536224, 34.44784954190254, 27.996871098876, 19.342316798865795, 36.081921458244324, 48.0813317745924, 46.20083928108215, 45.9891602396965, 34.141126200556755, 11.575769148766994, 4.405030477792025, 0.6283462175633758, 0.1816069651977159, 0.12976689613424242, 0.3350312582915649, 0.8017017622478306, 1.3687335792928934, 2.511553606018424, 1.895377601031214, 2.0972699113190174, 3.348922273144126, 1.9216721900738776, 1.4311892841942608, 3.5352552495896816, 6.343732047826052, 6.410767575725913, 9.123293347656727, 12.055312916636467, 13.190255016088486, 13.800609614700079, 19.310048930346966, 27.658672146499157, 41.306363716721535, 48.24024684727192, 57.31848791241646, 58.07791516184807, 62.304880544543266, 65.51686719059944, 65.34691751003265, 67.61742487549782, 73.33329856395721, 75.55506214499474, 74.23963353037834, 71.43303573131561, 74.91852030158043, 68.87635052204132, 73.63057941198349, 49.216992035508156, 50.20260214805603, 49.496721625328064, 53.23241516947746, 55.45320600271225, 58.29979665577412, 58.31928201019764, 54.84576679766178, 36.10306352376938, 37.105601727962494, 52.9639557749033, 61.98542408645153, 76.38736188411713, 73.2832020521164, 72.10974141955376, 72.6128040254116, 66.62204548716545, 65.87606951594353, 59.65385399758816, 54.716360941529274, 31.01009041070938, 23.07666901499033, 12.225440237671137, 7.913753176108003, 4.030920602381229, 2.8854661295190454, 1.742233349941671, 3.955285423435271, 4.17323294095695, 4.517292603850365, 3.3858106937259436, 2.854587798938155, 2.3339770222082734, 1.2122673564590514, 1.423399227205664, 0.7836095674429089, 0.5064076732378453, 0.3567360498709604, 0.05621620592137333, 0.09616235285648145, 0.10840248316526413, 0.04679520890931599, 5.429343888536096, 25.971251092851162, 37.07002803683281, 38.90032522380352, 29.708339162170887, 27.43499144911766, 21.604491211473942, 12.623085100203753, 40.94182267785072, 37.7475468814373, 40.94290941953659, 63.093642219901085, 71.30050644278526, 82.11248427629471, 88.59313532710075, 45.01725599169731, 2.1623031841591, 0.11942174343857914, 0.048533437511650845, 0.027443129365565255, 0.028219209889357444, 0.07448630465660244, 0.14111954398686066, 0.03184395747666713, 0.038446114340331405, 0.045415222411975265, 0.04677165314205922, 0.050805370483431034, 0.04610487798345275, 0.027392325646360405, 0.015252760058501735, 0.06377843470545486, 0.01449182584110531, 0.0334527777886251, 0.009780034142750083, 0.04004828129836824, 0.013304601998243015, 0.08553986699553207, 0.03117000946076587, 0.09651080603362061, 0.04282991016225424, 0.07163308080635034, 0.03835750190773979, 0.08288242170237936, 0.03208463967894204, 0.039667099408688955, 0.032373743306379765, 0.06301572953816503, 0.016416076541645452, 0.05681765353074297, 0.026853255549212918, 0.2987589983968064, 0.13907703483710065, 0.16060437890700996, 0.2610392536735162, 0.1922050566645339, 0.31694054778199643, 0.18099607375916094, 0.1954470545751974, 0.19886078545823693, 0.2820990595500916, 0.13313430215930566, 0.12408130278345197, 0.18806917156325653, 0.13220035383710638, 0.12201474804896861, 0.15180764312390238, 0.10905815579462796, 0.23610579315572977, 0.12566115707159042, 0.1017100403259974, 0.09148397264652885, 0.17463800555560738, 0.23528796125901863, 0.09696304114186205, 0.15202700713416561, 0.17735049594193697, 0.13927710300777107, 0.2524886734317988, 0.13993005937663838, 5.144557245075703, 68.73668521642685, 90.68486228585243, 91.47679299116135, 88.59388768672943, 77.2998221218586, 63.44242550432682, 36.89651794731617, 32.01004095375538, 44.065361469984055, 26.775006763637066, 63.352054953575134, 76.55793473124504, 66.71986743807793, 59.77160207927227, 44.64463658630848, 18.283737301826477, 6.350898463279009, 1.3994437688961625, 0.6495974084828049, 0.2269942531711422, 0.8824520604684949, 1.1892220680601895, 2.0018513314425945, 3.8803805178031325, 4.229007298126817, 2.5739749940112233, 5.591975636780262, 6.0616047866642475, 6.166427386924624, 10.028309784829617, 17.988601438701153, 8.790958430618048, 14.895516112446785, 21.252107620239258, 25.79978719353676, 18.06012500077486, 26.33169785141945, 35.459321066737175, 48.409938141703606, 51.55095599591732, 57.94197365641594, 58.1845298409462, 61.59530662000179, 65.69435566663742, 65.90876296162605, 67.16306045651436, 74.190973341465, 76.82094901800156, 76.12959891557693, 71.35523870587349, 77.69502371549606, 76.4869849383831, 76.2582828104496, 55.624345019459724, 55.28626196086407, 56.494084149599075, 59.0403351187706, 60.798253789544106, 63.53032998740673, 66.51284694671631, 61.792307049036026, 41.009645238518715, 43.91355201601982, 61.67563810944557, 65.35387873649597, 81.16894170641899, 74.82314541935921, 74.24160942435265, 73.53645086288452, 70.79627349972725, 66.94366782903671, 61.30997233092785, 56.77844949066639, 31.70938778668642, 23.90318736433983, 15.055184494704008, 9.540897589176893, 7.541403556242585, 5.04152862355113, 9.37677489593625, 9.617498628795147, 12.815768010914326, 13.600902780890465, 8.412705827504396, 6.3539359252899885, 3.6057611787691712, 3.4971131337806582, 1.3148789503611624, 0.7119111553765833, 0.4768518795026466, 0.302666257484816, 0.35914384410716593, 0.28638053918257356, 0.3789885761216283, 0.5198974837549031, 9.077378511428833, 38.028420209884644, 55.806492045521736, 55.17242766916752, 55.6124896556139, 71.21362030506134, 40.50799995660782, 29.6219127997756, 47.91815713047981, 46.10650174319744, 48.489935249090195, 73.002108335495, 84.05845105648041, 92.7958770096302, 99.52906250953674, 50.997644886374474, 3.2182256737723947, 0.27478828153107315, 0.21684823354007676, 0.26167186035308987, 0.23425968596711755, 0.21148168947547674, 0.22835336305433884, 0.12996197707252577, 0.17788500554161146, 0.1818252308294177, 0.13035203504841775, 0.11905688879778609, 0.12524641526397318, 0.15872062998823822, 0.1530403652577661, 0.249015778535977, 0.15863229957176372, 0.18728755647316575, 0.18338472058530897, 0.21936127915978432, 0.08459227057755925, 0.19594300218159333, 0.12887060438515618, 0.2149150872719474, 0.16834445967106149, 0.1705388122354634, 0.1487933361204341, 0.21649235888617113, 0.2990250731818378, 0.12375832753605209, 0.17518850101623684, 0.1598700979957357, 0.2225328769418411, 0.19388415093999356, 0.11952496875892393], [0.016244410362560302, 0.046977094461908564, 0.030961926095187664, 0.05756081052822992, 0.028007473301840946, 0.03545796804246493, 0.06542508970596828, 0.059236847155261785, 0.0657055398914963, 0.07060134710627608, 0.08378301048651338, 0.11626581981545314, 0.04618330443918239, 0.037776767640025355, 0.030227159077185206, 0.04251917664078064, 0.024765673915680964, 0.020931020990246907, 0.04799956615897827, 0.013780869703623466, 0.06828808021964505, 0.0628087148652412, 0.08481602068059146, 0.014955501155782258, 0.04840031106141396, 0.10448021042975597, 0.15506690338952467, 0.03684476745547727, 1.2352044694125652, 41.702135279774666, 66.67792528867722, 71.75349533557892, 71.66151747107506, 57.361763790249825, 45.90936452150345, 22.31788583099842, 21.38194665312767, 28.82695745676756, 33.01719971001148, 26.786831729114056, 41.04051858186722, 58.03625039756298, 39.51014310121536, 22.888413816690445, 4.855516729876399, 0.3619412361877039, 0.06540342641528696, 0.08652960255858488, 0.019029993018193636, 0.11125987788545899, 0.48317346372641623, 1.6788449138402939, 1.0334522766061127, 0.9859976917505264, 0.18086314026731998, 1.9763967348262668, 1.0928835812956095, 2.015935988165438, 6.592353656888008, 27.83704787492752, 34.2477522790432, 31.312559880316257, 34.48224529623985, 39.399515837430954, 46.373467817902565, 47.51231990754604, 60.37895008921623, 69.9749019742012, 72.80023276805878, 75.26918828487396, 74.6464017033577, 75.40643692016602, 70.03024980425835, 66.84985086321831, 65.04799515008926, 69.73313614726067, 71.61569952964783, 72.77662083506584, 67.65540763735771, 73.20136964321136, 76.0229766368866, 78.19140627980232, 74.87157002091408, 74.58790004253387, 30.351397655904293, 42.00253576040268, 55.926330015063286, 49.22640033066273, 56.45957440137863, 50.32804101705551, 30.700074546039104, 29.89230629056692, 50.01082643866539, 61.31337694823742, 74.46081966161728, 71.9074022769928, 70.73850139975548, 69.22027006745338, 74.69775974750519, 74.83658909797668, 67.4109135568142, 64.14250373840332, 62.7461052685976, 64.17703628540039, 52.02533774077892, 39.09669868648052, 26.154142878949642, 11.120945904403925, 6.750493571162224, 2.6338460063561797, 4.193891007453203, 1.6623609233647585, 3.3137466106563807, 3.69533970952034, 0.670624173944816, 1.8629699712619185, 1.1109874723479152, 0.4300170176429674, 1.0544717987067997, 0.3767237195279449, 0.1706422379356809, 0.16420858941273764, 0.1343007801915519, 0.02261795976664871, 0.046647751587443054, 0.06104918662458658, 1.392132961191237, 18.72924629598856, 41.659858748316765, 60.72663143277168, 60.61090864241123, 38.9468689262867, 66.56726002693176, 119.53206315636635, 113.49130690097809, 64.23635870218277, 40.87676256895065, 54.982502460479736, 57.54547253251076, 66.95306852459908, 78.71580854058266, 32.65899293124676, 1.835571185220033, 0.18794685078319162, 0.09141010668827221, 0.02334437391255051, 0.047963045071810484, 0.06218531823833473, 0.025077804530155845, 0.06616694794502109, 0.05962604052911047, 0.028821948835684452, 0.01747607864672318, 0.018056664484902285, 0.03479723025520798, 0.04650161157769617, 0.1214165028068237, 0.07424762996379286, 0.022639405979134608, 0.08645134308608249, 0.02405200615612557, 0.05543869119719602, 0.049449522339273244, 0.03185854438925162, 0.024920185351220425, 0.005170275226191734, 0.09156540108961053, 0.07548558423877694, 0.03459641622612253, 0.07530765433330089, 0.016969499774859287, 0.05551705828111153, 0.021929627073404845, 0.039249760084203444, 0.03334745590109378, 0.010800837862916524, 0.01091980877390597, 0.056279499985976145, 0.06794196480768733, 0.15641020552720875, 0.023708909429842606, 0.0444364966097055, 0.05546495951421093, 0.04823453011340462, 0.07769892836222425, 0.05289687622280326, 0.04038107144879177, 0.053293394594220445, 0.05929918756010011, 0.014028512323420728, 0.0395724310510559, 0.04656061973946635, 0.008568968805775512, 0.005850466095580487, 0.04168367049715016, 0.02592154109152034, 0.05569814602495171, 0.037335479210014455, 0.0506894284626469, 0.0319093852158403, 0.028789897332899272, 0.08016308871447109, 0.05712168916943483, 0.07088567872415297, 1.7621147143654525, 52.012638822197914, 78.29058855772018, 81.21283695101738, 82.49307945370674, 73.63566353917122, 64.70628708600998, 38.19639399647713, 23.426839224994183, 31.752937249839306, 41.52487859129906, 23.960047513246536, 38.60579162836075, 56.41955494880676, 44.3099619448185, 25.441308729350567, 6.219493439421058, 0.44209297746419907, 0.10437587930937298, 0.11666571866953745, 0.06269468387472443, 0.31747002562042326, 1.6431578225456178, 3.59947441611439, 2.4181470181792974, 1.5938551118597388, 1.3213489344343543, 1.8161127856001258, 1.1122590978629887, 2.673853822052479, 9.014633428305387, 24.69948023557663, 32.366929203271866, 32.70064629614353, 36.94720722734928, 39.68352399766445, 45.06042927503586, 49.22309830784798, 61.91167004406452, 72.77223587036133, 77.68232479691505, 78.35382476449013, 78.8527075946331, 78.51473852992058, 72.44440466165543, 68.92000257968903, 66.13320931792259, 70.68682417273521, 74.28978323936462, 75.64342260360718, 70.23588716983795, 74.33678671717644, 80.65368935465813, 80.3914426267147, 75.23100033402443, 75.25281116366386, 38.22315976023674, 48.33632089197636, 60.233144313097, 55.00734932720661, 61.93347327411175, 56.97797678411007, 37.65278376638889, 34.09389093518257, 53.3843994140625, 65.86990624666214, 76.85647711157799, 73.83798748254776, 73.26848924160004, 71.36520177125931, 77.76866376399994, 76.0148374736309, 68.0373327434063, 67.3404349386692, 64.2471045255661, 64.94144886732101, 52.66272693872452, 40.439387038350105, 27.715864777565002, 12.714018020778894, 6.26204545609653, 1.355567998252809, 1.7549605295062065, 2.183573255315423, 2.5544860772788525, 3.0531304702162743, 1.5316479373723269, 1.9532051542773843, 2.072053039446473, 1.862266177777201, 1.944977764505893, 1.377563236746937, 0.5232851800974458, 0.545367932645604, 0.21170826716115698, 0.10770789973321371, 0.059374474731157534, 0.0098551459814189, 1.4842096203938127, 18.89310870319605, 38.48585486412048, 53.12253266572952, 51.5565150976181, 23.27938623726368, 50.754796117544174, 104.12161007523537, 100.8187361061573, 68.58673766255379, 49.74997043609619, 63.73288191854954, 66.88707366585732, 76.50247290730476, 93.24897229671478, 45.59239313006401, 2.5369561929255724, 0.16398138832300901, 0.020852559282502625, 0.01766211094945902, 0.03495747107081115, 0.07243764310260303, 0.04645823304599617, 0.08060842927079648, 0.09971474661142565, 0.048948732219287194, 0.022704891234752722, 0.023612343029526528, 0.02643017014634097, 0.030668341751152184, 0.060768962794099934, 0.042307794428779744, 0.06311936303973198, 0.05582708676229231, 0.05030427979363594, 0.032363115751650184, 0.04513700980169233, 0.06726150444592349, 0.029317555054149125, 0.032943215483101085, 0.10558773225056939, 0.06399279664037749, 0.05265506966679823, 0.018457375990692526, 0.038753125991206616, 0.022431515571952332, 0.06168705142044928, 0.06552430742885917, 0.052649225253844634, 0.06178452509630006, 0.1493447963730432, 0.19096825271844864, 0.13749349949648604, 0.2775843971176073, 0.14370502321980894, 0.16818103875266388, 0.11409477068809792, 0.2376382242073305, 0.19219371664803475, 0.25650654220953584, 0.18543352314736694, 0.18181271821958944, 0.17792286991607398, 0.2690091775730252, 0.14910523110302165, 0.2030488138552755, 0.19835642189718783, 0.08093417272903025, 0.1404807181097567, 0.23802736192010343, 0.11836387129733339, 0.11845220171380788, 0.1911377889337018, 0.1413586045964621, 0.17644519452005625, 0.194358695007395, 0.27287520293612033, 0.16972337005427107, 2.356909504160285, 64.11313131451607, 89.30675983428955, 91.40294775366783, 92.13856548070908, 78.23350802063942, 65.14034539461136, 38.18518079817295, 32.19033747911453, 45.46062380075455, 52.055223137140274, 40.52191860973835, 57.52061806619167, 79.08583268523216, 58.71888376772404, 36.011777222156525, 8.084507938474417, 0.7784883922431618, 0.35940790025051683, 0.33870509709231555, 0.17480273265391588, 0.7631598960142583, 2.8977945679798722, 5.830437541007996, 4.155354425311089, 4.820048958063126, 2.468484342098236, 7.7220753114670515, 4.8469016421586275, 4.943649675697088, 9.879771955311298, 31.41698207706213, 38.545982837677, 38.46769943833351, 43.46579544246197, 41.73434995114803, 53.27642820775509, 52.92892545461655, 67.78545185923576, 76.8628379702568, 78.95565927028656, 81.35830834507942, 82.10731655359268, 78.86693403124809, 72.44885042309761, 66.72525554895401, 64.09254401922226, 71.07212349772453, 74.06376376748085, 75.22331714630127, 73.35287511348724, 78.46281051635742, 80.07339209318161, 81.7459711432457, 81.06129348278046, 79.23073410987854, 44.39373604953289, 53.409588262438774, 69.73483845591545, 60.96359811723232, 69.89281117916107, 63.77833127975464, 43.913685008883476, 41.045446917414665, 62.466265484690666, 72.30848595499992, 78.32577466964722, 79.21791359782219, 77.20776066184044, 75.06140023469925, 79.96032536029816, 78.02895739674568, 70.13672769069672, 66.08188927173615, 65.4920469224453, 69.11855712532997, 53.94326962530613, 42.930985540151596, 31.58491786569357, 15.388091281056404, 10.77985530719161, 6.08843894675374, 11.960895583033562, 10.385245531797409, 10.118732582777739, 11.665588729083538, 5.011413814499974, 6.143938293680549, 4.371712915599346, 3.316186317242682, 3.8822108320891857, 0.9904646489303559, 0.3601699077989906, 0.450245855608955, 0.2942217153031379, 0.12415895369485952, 0.2932813251391053, 0.32479974324814975, 2.6912063034251332, 28.941226825118065, 60.254054591059685, 86.41098082065582, 84.39351707696915, 57.730112224817276, 79.27101194858551, 123.90268743038177, 116.53681308031082, 72.00349912047386, 56.301844865083694, 75.98684817552567, 79.54905822873116, 87.35081478953362, 101.38852313160896, 52.27737441658974, 2.911055381409824, 0.3181889886036515, 0.19487610552459955, 0.10947912422125228, 0.14150045870337635, 0.13905935687944293, 0.15960227174218744, 0.16270020394586027, 0.23174509668024257, 0.16099918662803248, 0.11514010795508511, 0.19141695520374924, 0.11715654545696452, 0.19862779561663046, 0.16890089231310412, 0.09354271256597713, 0.23137764452258125, 0.21136684954399243, 0.19974270922830328, 0.13974566536489874, 0.2258217934286222, 0.27680662635248154, 0.250277251470834, 0.1763114149798639, 0.23007940559182316, 0.23489432613132522, 0.1722190494183451, 0.10733609859016724, 0.13611116039101034, 0.21563060668995604, 0.17934399365913123, 0.21426468389108777, 0.11791495358920656, 0.2527691755676642], [0.019011708354810253, 0.021563527479884215, 0.056126884737750515, 0.04501545714447275, 0.012909621727885678, 0.03651876795629505, 0.054414494006778114, 0.042736462637549266, 0.013813925888825906, 0.04110618683625944, 0.03898511022271123, 0.02070627084322041, 0.049237026905757375, 0.03765774570638314, 0.018397256462776568, 0.04700755591329653, 0.03099510751781054, 0.06615101403440349, 0.04344550681707915, 0.010786558013933245, 0.07221229738206603, 0.013365036938921548, 0.05498484933923464, 0.07908869636594318, 0.05488125294505153, 0.07172465440817177, 0.022996883672021795, 0.14683534274809062, 22.17147968709469, 67.75609463453293, 71.53638258576393, 72.85136282444, 46.50803379714489, 26.529842019081116, 10.525089427828789, 23.365784101188183, 36.0244457423687, 25.812486112117767, 21.462308540940285, 41.92726559937, 52.71817356348038, 41.47129386663437, 19.022172577679157, 3.0862342938780785, 0.13692774547962472, 0.023593691003043205, 0.07630840336787514, 0.019849511445499957, 0.40851551515515894, 0.27326717565301806, 0.6863942183554173, 0.8307715086266398, 0.8717781363520771, 1.4751067338511348, 0.7367723307106644, 1.7768161254934967, 11.512809377163649, 28.044528141617775, 47.9721712321043, 56.39395572245121, 59.01171125471592, 61.122798174619675, 66.9388496875763, 64.20819461345673, 64.49886381626129, 74.89429280161858, 72.1559089422226, 71.11517518758774, 67.32290267944336, 66.83421090245247, 65.67013576626778, 67.21580162644386, 70.40583685040474, 72.64659181237221, 66.75365522503853, 69.01475429534912, 67.3478901386261, 69.2569836974144, 65.62610372900963, 67.45274931192398, 65.86460933089256, 73.43017816543579, 69.39059972763062, 78.65973874926567, 61.21309272944927, 23.848305009305477, 49.58518847823143, 49.65499833226204, 56.66717246174812, 43.26426565647125, 28.14360212534666, 48.474937453866005, 64.19000118970871, 71.09189763665199, 73.01167622208595, 67.40995600819588, 66.19921937584877, 68.17445978522301, 68.91616478562355, 65.08659347891808, 67.4995855987072, 61.618914753198624, 66.91652968525887, 58.90755884349346, 61.706853434443474, 55.6568218767643, 53.0353881418705, 39.33713838458061, 22.426286414265633, 7.421515714377165, 7.18311270698905, 3.904665964655578, 3.011840460821986, 1.5940380957908928, 1.5506457304582, 2.467283131554723, 0.19188802602002397, 2.640898902900517, 1.7107854061760008, 0.8445551502518356, 0.6123376172035933, 0.2267224490060471, 0.11355752998497337, 0.13544077839469537, 0.06407693392247893, 0.08756447554333135, 0.08594084938522428, 0.14590440754545853, 7.497053286060691, 25.994661636650562, 45.207849964499474, 54.97457608580589, 57.98120275139809, 105.60049831867218, 104.51182633638382, 53.922849521040916, 36.98640212416649, 35.39110332727432, 55.38563422858715, 67.18108668923378, 70.51653251051903, 74.47332859039307, 20.198112577199936, 0.7370284607168287, 0.14569155959179625, 0.0579775375808822, 0.060833032403024845, 0.024994132945721503, 0.054904764183447696, 0.048889631289057434, 0.11834928809548728, 0.013757369597442448, 0.06270979400142096, 0.053187449302640744, 0.04820411319087725, 0.0373268814291805, 0.07106648074113764, 0.05013124806282576, 0.02949392088339664, 0.06827265839092433, 0.01272451432669186, 0.028739796798618045, 0.017364415107294917, 0.049096104194177315, 0.025983117084251717, 0.03696106570714619, 0.04550651770841796, 0.05896342881896999, 0.006866031644676696, 0.05753484649176244, 0.021451272077683825, 0.0684225648001302, 0.01964418144780211, 0.02895989739045035, 0.06925254565430805, 0.03287343875854276, 0.02343837248190539, 0.017813514641602524, 0.066689813247649, 0.04551217658445239, 0.045835890268790536, 0.043189109637751244, 0.10795840425998904, 0.016490465714014135, 0.04328670576796867, 0.05486942682182416, 0.05336658519809134, 0.019465576187940314, 0.03713126243383158, 0.04198448150418699, 0.07055303329252638, 0.10589439509203658, 0.09129879195825197, 0.0159041987353703, 0.05402552327723242, 0.050283028394915164, 0.07447767347912304, 0.008807880058157025, 0.013487073847500142, 0.07173477730248123, 0.01925262804434169, 0.019986198349215556, 0.046291305479826406, 0.11125339893624187, 26.710307635366917, 78.64208489656448, 80.19601911306381, 79.24838796257973, 55.50048686563969, 41.303696259856224, 23.39841865003109, 20.679932422935963, 28.613089732825756, 30.134429298341274, 26.70413486659527, 43.835409209132195, 52.21549093723297, 43.61689813435078, 20.544156208634377, 3.2485855696722865, 0.021767358339275233, 0.0873559172032401, 0.1237047444737982, 0.04180336407443974, 0.818961386103183, 1.0419403086416423, 2.4411334097385406, 3.0974938021972775, 1.8700790335424244, 1.9282317068427801, 1.273432436864823, 3.0783675285056233, 13.411819227039814, 30.758958086371422, 50.51926575601101, 59.33930687606335, 62.55340240895748, 64.09519627690315, 68.02582696080208, 65.0162060558796, 67.25679382681847, 78.28127905726433, 76.70961499214172, 74.2503109574318, 71.94768771529198, 72.93776258826256, 70.09422317147255, 71.77030563354492, 73.13704669475555, 72.84353524446487, 68.04960608482361, 70.65059691667557, 71.51836395263672, 71.64640188217163, 68.4680624306202, 70.83544179797173, 69.03294011950493, 75.52526414394379, 70.58034628629684, 80.47258347272873, 63.377327397465706, 30.850527472794056, 56.8067579716444, 54.709278121590614, 64.24502983689308, 50.33931881189346, 33.225861713290215, 51.66857108473778, 67.98000141978264, 76.3793671131134, 73.60654950141907, 70.410867780447, 69.11452934145927, 71.23136535286903, 73.81743058562279, 70.08192703127861, 68.43066483736038, 64.1263622045517, 68.21096822619438, 58.95243063569069, 62.42484390735626, 57.8377490490675, 56.88071720302105, 43.6200025677681, 25.432840883731842, 9.129380621016026, 6.435225438326597, 3.1629524147138, 2.2334985388442874, 0.5838115385267884, 0.03391562931938097, 1.3729526591487229, 1.1196182342246175, 1.7769161076284945, 3.3292288798838854, 2.9385402565822005, 1.868460439145565, 1.0942320339381695, 0.6351225008256733, 0.2097577546373941, 0.06200080177222844, 0.01816961565054953, 0.0785174875636585, 0.19924774125684053, 8.615518994629383, 27.92717333883047, 44.84964318573475, 51.02455884218216, 62.62744523584843, 110.63901275396347, 116.98648855090141, 68.07653144001961, 51.34053088724613, 49.709035232663155, 63.726878240704536, 76.4395634829998, 78.64757940173149, 87.9592913389206, 29.272228963673115, 0.8198769588489085, 0.09064899713848718, 0.11274406933807768, 0.008369960978598101, 0.08424597705015913, 0.04166014441580046, 0.02346414912608452, 0.007054571478875005, 0.01885263827716699, 0.01665286432398716, 0.049617952754488215, 0.016285029960272368, 0.04687421052949503, 0.03717123450769577, 0.037142513392609544, 0.009565172185830306, 0.08697879486135207, 0.015484526284126332, 0.060503129207063466, 0.052804423175984994, 0.08850162994349375, 0.06202938558999449, 0.07372598920483142, 0.04306209106289316, 0.02696631803701166, 0.021328747207007837, 0.023084225176717155, 0.04799511327291839, 0.03358214897161815, 0.029165386949898675, 0.0866123074956704, 0.015366449661087245, 0.010408981106593274, 0.07142846327042207, 0.11315167168504559, 0.210919349337928, 0.1673155461321585, 0.10024411312770098, 0.19821517635136843, 0.18419743166305125, 0.12488285196013749, 0.22940287861274555, 0.1911293136072345, 0.16936607047682628, 0.09108451908105053, 0.17203613970195875, 0.17102086683735251, 0.17341079015750438, 0.1998685032594949, 0.12891445046989247, 0.14412307500606403, 0.18400267726974562, 0.08626631082734093, 0.18864497425965965, 0.09275158314267173, 0.08442440419457853, 0.1773588970536366, 0.18763008731184527, 0.21584318747045472, 0.16361819609301165, 0.30096308793872595, 34.3047796189785, 92.50272274017334, 93.6846949160099, 92.02057421207428, 64.54639166593552, 41.63392893970013, 21.797074377536774, 36.29745349287987, 54.77200895547867, 38.540815114974976, 31.473828926682472, 59.08424936234951, 71.12222760915756, 59.8002677410841, 29.96494509279728, 5.844269748777151, 0.4761924367630854, 0.21495445078471676, 0.2081595396157354, 0.2179486010572873, 1.3660690910182893, 1.5966278943233192, 2.695464687421918, 4.1955500934273005, 4.2960376013070345, 6.703964592888951, 4.346150737255812, 5.352075509727001, 16.226966567337513, 32.41013668477535, 52.22381629049778, 60.565292090177536, 62.95437589287758, 66.94651767611504, 67.81194403767586, 66.45162463188171, 67.83437043428421, 80.92203855514526, 78.5068653523922, 75.54304718971252, 74.77436363697052, 74.5755735039711, 71.08327209949493, 74.30796906352043, 73.43004137277603, 72.7716127038002, 66.99631780385971, 72.25189939141273, 73.18924069404602, 75.9037010371685, 70.73377445340157, 74.42797422409058, 71.54696881771088, 78.96340325474739, 74.1622544825077, 84.61499959230423, 68.50896343588829, 38.161979243159294, 62.01931446790695, 59.78403881192207, 71.26772180199623, 56.827314868569374, 41.59473404288292, 58.269010707736015, 72.6478685438633, 78.41524466872215, 79.46997687220573, 74.43337753415108, 72.28485122323036, 75.56473642587662, 76.15508034825325, 71.712237149477, 71.80258110165596, 65.78900098800659, 68.0503736436367, 57.99325950443745, 63.49014334380627, 58.86223487555981, 58.45865473151207, 47.28390276432037, 29.162658043205738, 11.826281156390905, 12.168981917202473, 9.117144327610731, 7.909540627151728, 6.242472231388092, 5.788868246600032, 9.089588206261396, 6.449641864746809, 9.584399554878473, 5.007054023444653, 5.571619654074311, 2.8701073536649346, 0.7596120738890022, 0.32092816662043333, 0.40211817249655724, 0.20178343722363934, 0.15950628236168995, 0.26210848067421466, 0.44918675150256604, 12.316046375781298, 39.84276205301285, 62.85104043781757, 72.89121508598328, 67.21650838851929, 108.0213712155819, 105.0107091665268, 63.24525408446789, 49.601246416568756, 51.89218908548355, 74.28057253360748, 86.10033988952637, 88.71851339936256, 98.52842420339584, 33.654946088790894, 1.5550057590007782, 0.3757469047559425, 0.17948667897144333, 0.11519730527652428, 0.20735435391543433, 0.1563470042310655, 0.21461512602400035, 0.24000686273211613, 0.07635849091457203, 0.12163269042503089, 0.1920258131576702, 0.15980805444996804, 0.17379744909703732, 0.18834625981980935, 0.1114552779472433, 0.13956606562715024, 0.28607640706468374, 0.17067444714484736, 0.1603136202902533, 0.1815254773828201, 0.2504238998517394, 0.1028468695585616, 0.17659297096543014, 0.13503979600500315, 0.0975746673066169, 0.13050861336523667, 0.11720347887603566, 0.09784195179236121, 0.10541091556660831, 0.16769416019087657, 0.18766535416943952, 0.2040223334915936, 0.09925516424118541], [0.09767764029675163, 0.01525450967164943, 0.06935229772352614, 0.008202509270631708, 0.02879828174627619, 0.01161364913059515, 0.0011508247462188592, 0.0405635432980489, 0.011519814761413727, 0.03184337118000258, 0.036003717468702234, 0.05777063423010986, 0.003631664171734883, 0.08007361539057456, 0.009341298700746847, 0.05371567662223242, 0.03228884161217138, 0.04895081765425857, 0.041132024707621895, 0.052902382958563976, 0.04333536468038801, 0.03201064755558036, 0.07721815025433898, 0.023113996430765837, 0.12506297120125964, 0.04113422517548315, 0.02070612241368508, 11.977334450930357, 66.40793457627296, 76.28337666392326, 69.3724063038826, 64.85889449715614, 40.541715547442436, 29.542854242026806, 71.09796211123466, 76.34452298283577, 23.542531616985798, 36.49443872272968, 48.448224887251854, 44.640867188572884, 36.526349410414696, 17.19853263348341, 2.3951765382662416, 0.022971784237597603, 0.09246672459994443, 0.06709928580676205, 0.06282261529122479, 0.06217088346602395, 0.10182359634200111, 0.6505034817382693, 1.6377399070188403, 1.2187403091229498, 1.232901317998767, 1.2996984086930752, 4.297149991616607, 23.599125780165195, 46.90096691250801, 60.22991068661213, 65.43932095170021, 72.04729557037354, 72.80452653765678, 73.22151616215706, 75.22049769759178, 70.87549924850464, 80.25060698390007, 70.46490088105202, 66.9905573129654, 63.0392025411129, 63.55429910123348, 59.57340471446514, 57.65477366745472, 61.980024576187134, 65.64995124936104, 68.39955970644951, 70.4484249651432, 68.6236260831356, 69.17180746793747, 63.950895220041275, 61.21247336268425, 58.69236119091511, 62.18864098191261, 64.69741076231003, 69.26888465881348, 70.06242647767067, 63.11374694108963, 28.220756985247135, 28.492408208549023, 48.18038485944271, 44.47369895875454, 34.07898813486099, 42.26042412221432, 54.75785471498966, 63.34913671016693, 71.44861489534378, 65.12738808989525, 60.70041283965111, 63.01163122057915, 65.40434002876282, 76.7428632080555, 61.21163360774517, 56.90103851258755, 66.1269548535347, 65.0028383731842, 71.125009059906, 71.8407766520977, 68.52840319275856, 64.2615057528019, 61.14419482648373, 59.527548775076866, 46.11146807670593, 31.534979045391083, 21.108283437788486, 11.417774576693773, 8.770609572529793, 3.660421008244157, 2.5558369047939777, 1.781577744986862, 1.7187077435664833, 2.0908568054437637, 3.1245231768116355, 2.2177628707140684, 0.9973005414940417, 0.6337829539552331, 0.1817990478593856, 0.04712528650998138, 0.03446090377110522, 0.05561860263696872, 0.016392453981097788, 0.27180226519703865, 3.6463513132184744, 15.738086700439453, 32.359014227986336, 38.92292261123657, 37.54802718758583, 32.99769535660744, 29.266424775123596, 19.00473341345787, 16.636854372918606, 42.533618062734604, 59.24733281135559, 69.2242294549942, 73.29719290137291, 70.09454995393753, 7.403320865705609, 0.3835816984064877, 0.05809303060232196, 0.020869003419647925, 0.09198920452035964, 0.07277383600012399, 0.10871742095332593, 0.06863980626803823, 0.04085646156454459, 0.04892687968094833, 0.05901226955757011, 0.029107857517374214, 0.05778128404926974, 0.02952154176455224, 0.08060281863436103, 0.05305607061018236, 0.02914596308983164, 0.017713022280076984, 0.053056823890074156, 0.030162523580656853, 0.02178353715862613, 0.019885509318555705, 0.013352367550396593, 0.04368811489257496, 0.06786536774598062, 0.08938511964515783, 0.0637248442217242, 0.026588930377329234, 0.036174088600091636, 0.01384480572596658, 0.11385949503164738, 0.06028090792824514, 0.04079449223354459, 0.052095761202508584, 0.01208553259857581, 0.028013493974867743, 0.04104891530005261, 0.08966464956756681, 0.055990092077990994, 0.08650923060486093, 0.05353423264750745, 0.08198158058803529, 0.04780591385497246, 0.014099673153395997, 0.04756202928547282, 0.03371760576555971, 0.06473391273175366, 0.02871418899303535, 0.03977711166953668, 0.026990630794898607, 0.02690387929760618, 0.06919831692357548, 0.027720622092601843, 0.023148589789343532, 0.07965168959344737, 0.06752468485501595, 0.032468842109665275, 0.1141402791836299, 0.037853954709134996, 0.03896057853125967, 14.313060566782951, 77.3484519124031, 85.53546980023384, 78.18309992551804, 73.82324427366257, 48.30219492316246, 31.727246828377247, 52.61420354247093, 65.47658175230026, 27.47979674488306, 25.800807438790798, 35.22314094007015, 42.60276675224304, 41.3245989382267, 21.40966236591339, 2.30354065541178, 0.03635844179370906, 0.04825349569728132, 0.18939628003863618, 0.09394854117999785, 0.293555207317695, 0.8656419406179339, 2.8808163665235043, 3.0110370414331555, 1.8115675169974566, 1.2535599782131612, 0.986854723887518, 5.227783704176545, 23.740793578326702, 49.43298004567623, 64.13059517741203, 70.14821827411652, 74.75971162319183, 75.8531029522419, 75.35519286990166, 73.56688722968102, 71.68332070112228, 82.48837530612946, 74.02002811431885, 70.15634983778, 67.30010390281677, 67.72106811404228, 64.37147185206413, 61.94157063961029, 65.01413896679878, 68.67475613951683, 71.57978385686874, 70.80289274454117, 70.42134761810303, 70.86076363921165, 67.48827740550041, 62.9635713994503, 61.26114495098591, 64.55168098211288, 67.25569188594818, 72.41416588425636, 72.10166305303574, 66.18408858776093, 32.90147691965103, 34.393064081668854, 55.12771546840668, 51.77564553916454, 42.002068385481834, 45.45690380036831, 60.657988116145134, 70.3349706530571, 76.93681240081787, 69.82255294919014, 64.74496901035309, 64.50751215219498, 67.16032460331917, 76.63005486130714, 63.97639185190201, 58.59226696193218, 67.21501886844635, 64.14486721158028, 70.95962673425674, 73.33585202693939, 70.52512004971504, 68.23133513331413, 66.42919063568115, 62.63491563498974, 51.787994876503944, 32.8597741574049, 22.037394382059574, 14.295281320810318, 10.522743053734303, 4.65057710185647, 3.3905347902327776, 0.6472123833373189, 0.545775817008689, 1.069043066818267, 3.4214879292994738, 2.730538942851126, 2.8416784666478634, 2.2604445554316044, 0.4093873902456835, 0.35144177614711225, 0.06180099335324485, 0.052677779385703616, 0.12361560511635616, 0.09092105363379233, 4.175772629678249, 17.937942557036877, 36.37276545166969, 45.36644205451012, 47.68926881253719, 38.28964099287987, 29.053818583488464, 28.022343032062054, 26.210330463945866, 54.484694972634315, 65.01530930399895, 77.15778574347496, 80.72495073080063, 86.78289726376534, 14.227533806115389, 0.4276646173093468, 0.09723636670969427, 0.01924038260767702, 0.02563834310421953, 0.0794361624866724, 0.04020150510768872, 0.07978805180755444, 0.04723998543340713, 0.005897056735193473, 0.06555236061103642, 0.0023199879615276586, 0.026677353562263306, 0.012936408620589646, 0.009378635222674347, 0.06191380351083353, 0.04410755820572376, 0.05544587147596758, 0.014458460736932466, 0.024059357128862757, 0.05205941452004481, 0.04862178277107887, 0.021614550132653676, 0.04892704666417558, 0.014291258576122345, 0.004728567018901231, 0.011394196062610717, 0.0024238420201072586, 0.035891382285626605, 0.038153069908730686, 0.08666099980473518, 0.04094864001672249, 0.032665180988260545, 0.14223196398233995, 0.18766266759485006, 0.1589801293448545, 0.19613553013186902, 0.18812667316524312, 0.20489958173129708, 0.22879047319293022, 0.14161718368995935, 0.22748574789147824, 0.20706916140625253, 0.09693125495687127, 0.10802202858030796, 0.07498443417716771, 0.27150306093972176, 0.2084968308918178, 0.17919041361892596, 0.1272600845550187, 0.11326947278575972, 0.2836079348344356, 0.08705766289494932, 0.17644694598857313, 0.13904375693527982, 0.22432197234593332, 0.15056800417369232, 0.34487403638195246, 0.1622319532907568, 0.1251946430420503, 19.574440643191338, 92.86914467811584, 96.10506623983383, 87.27560922503471, 82.41412729024887, 56.89746670424938, 40.25369480252266, 85.59660851955414, 84.33395907282829, 33.5530773550272, 47.8317079693079, 64.76551830768585, 64.09192845225334, 55.22402510046959, 28.266035355627537, 3.928709886968136, 0.2790613303659484, 0.3524067165562883, 0.21194755041506141, 0.2933928550919518, 0.22011194669175893, 0.8222302794456482, 3.123758230358362, 5.398894222453237, 5.255487067624927, 4.602587576955557, 4.086968544870615, 7.472696118056774, 30.56613553315401, 51.64432838559151, 64.41035136580467, 71.57267063856125, 78.57391655445099, 80.12722000479698, 75.32232463359833, 73.35289791226387, 71.24970316886902, 85.32022655010223, 77.59103089570999, 73.61560061573982, 69.51864525675774, 68.16971763968468, 66.61911204457283, 64.01115998625755, 67.87923082709312, 72.21273869276047, 73.16158577799797, 71.62361830472946, 71.30321189761162, 72.78261691331863, 72.19585999846458, 66.60332769155502, 63.61569240689278, 66.3240198791027, 69.18954491615295, 77.31120631098747, 75.61870113015175, 71.22922226786613, 39.606186747550964, 40.29010824859142, 61.67122274637222, 56.494445130228996, 46.27694919705391, 48.183124512434006, 61.33597433567047, 70.38895055651665, 78.31510484218597, 73.19504678249359, 67.68448367714882, 66.38548538088799, 70.26997894048691, 78.8453359901905, 64.20521557331085, 58.1558071821928, 68.28630298376083, 66.06148436665535, 73.09551492333412, 76.50485917925835, 71.06860488653183, 70.52265778183937, 70.14047428965569, 69.69006165862083, 54.94263119995594, 38.810273855924606, 25.84400352090597, 15.078329052776098, 12.179051376879215, 5.474718203768134, 5.84734758362174, 5.700853569433093, 5.918572386726737, 7.4235752038657665, 7.708561336621642, 6.217173188924789, 4.419752787798643, 2.0878416672348976, 0.4257960378890857, 0.3393793827854097, 0.22817125485744327, 0.3566930053057149, 0.2797847759211436, 0.46370066644158214, 6.895636757835746, 27.103934213519096, 48.64813596010208, 57.174601033329964, 51.96622051298618, 43.0729953199625, 37.610321044921875, 29.656449146568775, 27.46392499655485, 55.71654327213764, 76.88781782984734, 88.287213742733, 88.8274535536766, 94.53609243035316, 18.839495480060577, 1.2400512280873954, 0.20073732070159167, 0.19228440709412098, 0.1653662952594459, 0.2248418319504708, 0.1842984528047964, 0.12241586402524263, 0.07313800044357777, 0.09618043899536133, 0.2219179630628787, 0.09576905911671929, 0.1502475151210092, 0.12300332586164586, 0.24940582166891545, 0.15413564164191484, 0.1981344900559634, 0.16124016197863966, 0.12570308841532096, 0.14066349423956126, 0.11874345756950788, 0.08568718330934644, 0.12830474646762013, 0.1259412436047569, 0.18573418201413006, 0.13862629886716604, 0.12921907240524888, 0.14309281075838953, 0.09599231940228492, 0.10977357873343863, 0.2376874879701063, 0.135620214859955, 0.14069080527406186], [0.02490696955646854, 0.06788183600292541, 0.05098592759168241, 0.008793726374278776, 0.008510470870533027, 0.03688789365696721, 0.05514674885489512, 0.031848395519773476, 0.04282297108147759, 0.06274057828704827, 0.022846287065476645, 0.034627441709744744, 0.05886345410544891, 0.009184324262605514, 0.09542522951960564, 0.10544696167926304, 0.061585473667946644, 0.05672457336913794, 0.06273931663599797, 0.0588359241373837, 0.08868709264788777, 0.019442534357949626, 0.03634225926361978, 0.03439453350438271, 0.049170890415553004, 0.041840697813313454, 2.4782676296308637, 58.80618788301945, 80.44233709573746, 74.00351420044899, 70.56851372122765, 53.688728883862495, 28.799597024917603, 39.41191457211971, 94.723399579525, 80.628542304039, 31.93137377500534, 47.62441769242287, 52.53186576068401, 44.69319798052311, 21.073363311588764, 1.555842189118266, 0.08580731475376524, 0.08691209062817506, 0.07782428452628665, 0.09599304670700803, 0.12212077126605436, 0.396836485597305, 0.23356429359409958, 1.1537313787266612, 2.10504453163594, 2.139418199658394, 0.8992038771975785, 5.488067362457514, 27.736788354814053, 54.827444180846214, 69.93932068347931, 70.2752834558487, 73.99864286184311, 74.20678049325943, 73.86197939515114, 77.11810067296028, 68.59084904193878, 70.84340617060661, 70.72921469807625, 66.87502831220627, 60.43777093291283, 54.33231934905052, 50.746349170804024, 53.508941531181335, 52.23135508596897, 54.881150498986244, 57.90085606276989, 63.69271047413349, 68.54683980345726, 69.3918764591217, 69.17645081877708, 68.59202697873116, 63.182910829782486, 58.65926116704941, 55.990892350673676, 59.05307203531265, 62.035797983407974, 68.93830239772797, 63.77740412950516, 56.80054910480976, 28.586323969066143, 26.053748466074467, 37.206326723098755, 40.05208522081375, 64.48029041290283, 70.78412935137749, 69.98199239373207, 63.889247328042984, 62.23008915781975, 57.49793328344822, 64.92592290043831, 66.28032222390175, 69.14830952882767, 70.31228587031364, 60.87660178542137, 66.83136105537415, 68.39919492602348, 64.671321362257, 66.70102044939995, 63.584442883729935, 67.8575111925602, 66.73342511057854, 65.65064281225204, 65.51336377859116, 67.582246363163, 59.7769445925951, 53.87602463364601, 46.465875059366226, 36.399975791573524, 25.833930261433125, 13.395302463322878, 3.6816716054454446, 3.268120321445167, 1.76976797869429, 2.4050951935350895, 1.980562023818493, 2.2180103324353695, 0.38611061114352196, 0.19976991636212915, 0.07794952936819755, 0.02137382711225655, 0.07820693586836569, 0.02664562860445585, 0.07961169525515288, 0.9636842797044665, 7.9292539693415165, 20.854620449244976, 34.42243270576, 54.97481547296047, 43.996056988835335, 32.704370096325874, 21.46477460861206, 13.683760184794664, 45.757828652858734, 60.55019170045853, 68.54085132479668, 79.24406379461288, 56.56326323747635, 2.3611137410625815, 0.15167220117291436, 0.043147178294020705, 0.0825537764467299, 0.05892242887057364, 0.03409210090467241, 0.057717169911484234, 0.05253316448943224, 0.04543673356238287, 0.11349040272762068, 0.05073082917078864, 0.016626089491182938, 0.03996727959020063, 0.039278588810702786, 0.005742833809563308, 0.05217663674557116, 0.07031207278487273, 0.028113717307860497, 0.022446508810389787, 0.0564000841404777, 0.043807470792671666, 0.08868946752045304, 0.03586118058592547, 0.023418134114763234, 0.04728986517875455, 0.05994903804094065, 0.07193837809609249, 0.10875581225263886, 0.09622052981285378, 0.023451909255527426, 0.049413617234677076, 0.03946828546759207, 0.0334378383558942, 0.00876194853844936, 0.05747285489633214, 0.08697057186509483, 0.007412970826408127, 0.03152098222926725, 0.04918404869385995, 0.11013430703314953, 0.016588935723120812, 0.041381738847121596, 0.023989125838852488, 0.012688754868577234, 0.05229000351391733, 0.02453547826007707, 0.03990426012023818, 0.026457579515408725, 0.061177099487395026, 0.02788827881886391, 0.060206930647837, 0.08699465455720201, 0.04457081049622502, 0.009250874500139616, 0.01772458308550995, 0.06305251037701964, 0.08906696835765615, 0.01568708714330569, 4.076225571334362, 70.14318734407425, 90.69860234856606, 83.10584217309952, 78.11663389205933, 65.61975046992302, 41.49723507463932, 47.09301620721817, 97.8612332046032, 94.51850697398186, 41.26762479543686, 45.466243699193, 52.49786138534546, 46.2467560172081, 23.915088325738907, 1.8287547072395682, 0.20196870696963742, 0.05911072286835406, 0.245607020042371, 0.5769201926887035, 0.9804583014920354, 0.9971129265613854, 2.3769710026681423, 3.0238834396004677, 2.1466226130723953, 1.2828757613897324, 0.7785989425610751, 6.2179051246494055, 29.181744419038296, 56.37963429093361, 71.98928028345108, 72.42781475186348, 76.19357228279114, 75.52556052803993, 75.99137753248215, 77.90554001927376, 68.55180993676186, 69.79452565312386, 73.18985626101494, 70.03143534064293, 64.63600605726242, 57.19184070825577, 54.60105612874031, 55.122825130820274, 55.167879313230515, 55.63805848360062, 61.194374933838844, 66.13594517111778, 71.47891446948051, 70.23472443223, 72.99741178750992, 71.90110221505165, 64.93446484208107, 60.62766574323177, 59.19559858739376, 62.28821083903313, 66.55443951487541, 72.10082709789276, 68.34814086556435, 64.1759267449379, 33.745757415890694, 32.562193125486374, 43.47945190966129, 43.684648498892784, 67.93525502085686, 73.40341240167618, 73.2994195818901, 65.85515543818474, 65.98501726984978, 61.44456870853901, 67.0399622619152, 68.67745399475098, 72.23673060536385, 68.8656122982502, 61.9143109023571, 66.84193208813667, 71.7515042424202, 68.3794891834259, 71.00104451179504, 68.61529693007469, 71.3444396853447, 70.16457259654999, 70.14938101172447, 70.86019366979599, 72.79706373810768, 62.94177956879139, 55.92435032129288, 51.38578645884991, 39.72148396074772, 29.373123049736023, 15.597033519297838, 5.024272324517369, 1.4684746647253633, 0.991049223812297, 1.2985045602545142, 2.1516126953065395, 3.765071192756295, 2.1739571588113904, 1.0157680255360901, 0.30716518638655543, 0.12247841223143041, 0.058882156226900406, 0.07880285076680593, 0.03496472185361199, 1.048584608361125, 8.279684465378523, 24.118404015898705, 37.528025060892105, 39.02654305100441, 27.97984231263399, 19.830024428665638, 23.41694075614214, 24.12186373025179, 53.93804870545864, 67.75950685143471, 74.10379081964493, 84.77092802524567, 76.36327117681503, 5.963534424081445, 0.19258934073150158, 0.012043354490742786, 0.04492859618039802, 0.02991592831676826, 0.035237379488535225, 0.062064782323432155, 0.04167751067143399, 0.03555698167474475, 0.06625153051572852, 0.0441806523303967, 0.029300533897185232, 0.05892154200410005, 0.014219292515917914, 0.019797538843704388, 0.03490004368359223, 0.025785457182792015, 0.019819293047476094, 0.018170367075072136, 0.07980298381880857, 0.031860021263128147, 0.0667479753610678, 0.03514572425046936, 0.05806750814372208, 0.02080573161947541, 0.05028869098168798, 0.051826231720042415, 0.0251903549360577, 0.055306481299339794, 0.04223927193379495, 0.019274543665233068, 0.06513213433208875, 0.06705438587232493, 0.11927450133953243, 0.1986302447039634, 0.14986878231866285, 0.07870708403061144, 0.13745658507104963, 0.12443070590961725, 0.27328804484568536, 0.16504190250998363, 0.16913414932787418, 0.07663732321816497, 0.08704533582204022, 0.1623878488317132, 0.11928330321097746, 0.18061083974316716, 0.16391204204410315, 0.1807059533894062, 0.15073046030011028, 0.1876329816877842, 0.14761283149709925, 0.20042413438204676, 0.10835713052074425, 0.10998060082783923, 0.16274865134619176, 0.17984552221605554, 0.08626721624750644, 6.7134232353419065, 84.04985591769218, 99.52523231506348, 95.20201429724693, 90.44451758265495, 74.49949398636818, 43.3125876635313, 50.83986595273018, 100.53312823176384, 88.07910650968552, 45.39715960621834, 69.93360579013824, 75.67996144294739, 65.15768006443977, 33.90512466430664, 2.9872353561222553, 0.3863427846226841, 0.34520785440690815, 0.6129892822355032, 0.5616716702934355, 0.49290376191493124, 1.2133444799110293, 2.5064578419551253, 4.767405157908797, 5.622829031199217, 7.012759298086166, 3.496027342043817, 7.446302734315395, 33.860537856817245, 58.565170615911484, 73.06927353143692, 75.83736419677734, 80.23268714547157, 78.61006781458855, 79.59821239113808, 81.14956274628639, 68.88032510876656, 71.5585657954216, 75.64940348267555, 73.2339794933796, 67.67885997891426, 59.31041702628136, 57.74975337088108, 57.058638855814934, 57.602279484272, 59.21714723110199, 64.29325684905052, 67.65312016010284, 74.14480581879616, 72.7838784456253, 74.42350566387177, 76.32555440068245, 69.73767310380936, 64.1778114438057, 62.47508481144905, 63.77396911382675, 69.91808742284775, 75.5478273332119, 72.1685242652893, 65.74558451771736, 39.218812733888626, 38.652567118406296, 48.96304026246071, 46.24299421906471, 67.65983060002327, 75.4825696349144, 76.80270999670029, 67.90448427200317, 68.14702525734901, 64.17771264910698, 69.74078133702278, 71.52413964271545, 75.1308985054493, 70.02040833234787, 61.550032049417496, 67.04742506146431, 74.05912801623344, 69.97890695929527, 74.08106803894043, 70.4901847243309, 74.83544915914536, 74.52398747205734, 73.63040462136269, 73.75770539045334, 75.88900342583656, 65.01318901777267, 59.18023981153965, 51.57673381268978, 39.95327912271023, 29.89174772053957, 15.693006869405508, 5.76629888266325, 9.372698664665222, 8.190419655293226, 8.24189929291606, 8.9009796269238, 6.867190534248948, 2.9926291666924953, 0.7814153039362282, 0.38387294684071094, 0.19809056975645944, 0.1953973455238156, 0.1606868315138854, 0.2255472878459841, 1.7803115816786885, 13.284603003412485, 34.820031970739365, 53.8781601190567, 81.9742400944233, 63.799465745687485, 46.761366203427315, 31.93535216152668, 24.893497824668884, 62.47808285057545, 78.04797917604446, 87.87376552820206, 92.5728289783001, 88.68773505091667, 8.38338565081358, 0.3354566573398188, 0.1578203306416981, 0.18151388503611088, 0.1517979655181989, 0.1344347230042331, 0.12740030593704432, 0.11787595372879878, 0.10613531107082963, 0.20454076817259192, 0.13048152497503906, 0.14239016018109396, 0.11690013343468308, 0.1020519774465356, 0.12352223551715724, 0.10452557791722938, 0.14854102075332776, 0.06930800635018386, 0.12902412505354732, 0.27532491367310286, 0.10476961833774112, 0.1312028628308326, 0.1502674343646504, 0.18371935497270897, 0.08057845392613672, 0.13055335002718493, 0.11173615115694702, 0.12945881579071283, 0.25716120551805943, 0.11388676153728738, 0.14191963855409995, 0.1440140386694111], [0.0791062852658797, 0.02353448060603114, 0.024317730276379734, 0.03210980961739551, 0.033831759210443124, 0.07554850351880305, 0.07405592579743825, 0.06577570995432325, 0.023192888584162574, 0.053547212810372, 0.05765319678175729, 0.04744895937619731, 0.02683310623979196, 0.083658225776162, 0.018685411996557377, 0.0334855547407642, 0.021808113378938287, 0.0579824283340713, 0.08220747549785301, 0.015117903476493666, 0.06294642778811976, 0.06893225698149763, 0.021391289847088046, 0.006482987892013625, 0.033004461220116355, 0.8690509514417499, 32.33112372457981, 75.52856236696243, 75.15947297215462, 59.70658376812935, 47.58944436907768, 35.18970273435116, 19.856921285390854, 24.954598546028137, 21.147632226347923, 34.2073680460453, 34.371070861816406, 42.78676047921181, 42.13417589664459, 17.29162573814392, 1.4046325092203915, 0.07306034953217022, 0.06858815278974362, 0.1553673396119848, 0.17570972617249936, 0.1461163055500947, 0.7050719379913062, 0.41392900748178363, 0.36188937490805984, 2.653665980324149, 2.1226119389757514, 0.8166006440296769, 14.944186750799417, 38.04692141711712, 62.94360727071762, 72.22565799951553, 64.72973182797432, 72.75816142559052, 67.68958300352097, 68.17063719034195, 70.69067716598511, 73.13273012638092, 68.84832322597504, 71.12236440181732, 75.52818238735199, 66.45749911665916, 55.12540139257908, 52.197521701455116, 54.33723248541355, 55.11861875653267, 56.61608040332794, 51.32494032382965, 51.01141534745693, 59.21128794550896, 64.3495774269104, 65.72403967380524, 67.27776870131493, 66.62655964493752, 60.99948339164257, 56.635873541235924, 55.35016693174839, 56.34950950741768, 61.26940190792084, 62.157072275877, 67.35685005784035, 67.86476880311966, 58.14830258488655, 22.825855873525143, 24.235779717564583, 60.64328670501709, 68.87737646698952, 64.31753754615784, 62.10411451756954, 58.41047331690788, 53.255981504917145, 53.28960970044136, 59.561898931860924, 66.10241577029228, 69.11715120077133, 63.80932241678238, 62.536117136478424, 67.02103927731514, 62.317913845181465, 63.8198858499527, 59.85272392630577, 61.318483874201775, 59.0609186142683, 61.30033224821091, 59.99951384961605, 61.36826500296593, 61.488874331116676, 64.00913849473, 58.670945540070534, 61.6220685839653, 63.18767957389355, 67.96423986554146, 59.28427442908287, 33.24896827340126, 13.361375033855438, 1.3697814918123186, 1.8592580454424024, 3.058007271029055, 3.2989031821489334, 0.8892237721011043, 1.1123874597251415, 0.2873292117146775, 0.01907783927890705, 0.053716886322945356, 0.03671144804684445, 0.12876395776402205, 0.0687844434287399, 0.15816347004147246, 1.3581950822845101, 15.706926472485065, 42.49686263501644, 61.90492540597916, 53.76524917781353, 35.86914427578449, 25.366623736917973, 33.320275247097015, 49.217265620827675, 57.81276918947697, 64.6020358800888, 82.60816007852554, 29.30213525891304, 0.339788306155242, 0.0895498764293734, 0.0664468044124078, 0.06319164822343737, 0.024497534104739316, 0.06575546416570432, 0.04551423975499347, 0.041352739426656626, 0.009189853262796532, 0.013706519494007807, 0.018452060357958544, 0.04522584487858694, 0.0423881430469919, 0.039661017508478835, 0.06610503056435846, 0.04755719048262108, 0.12083254390745424, 0.0098720103596861, 0.01884959918243112, 0.05172937031602487, 0.043239479200565256, 0.05475159974594135, 0.023731424334982876, 0.02366304655879503, 0.02910298902861541, 0.034029385715257376, 0.055352969429804944, 0.05286985091515817, 0.01902402986161178, 0.028187375464767683, 0.04528224810201209, 0.04103323371964507, 0.014443287527683424, 0.05194019962800667, 0.03975701431045309, 0.025999848803621717, 0.023741357981634792, 0.051328573463251814, 0.07576938151032664, 0.029406377143459395, 0.03779975566430949, 0.0025008660486491863, 0.04338601625931915, 0.04754173154651653, 0.0357266997161787, 0.03437754203332588, 0.05437619547592476, 0.04600508138537407, 0.012346016228548251, 0.028593870156328194, 0.020373905572341755, 0.017525130897411145, 0.010226601098111132, 0.0020018294844703632, 0.032979684619931504, 0.01012128013826441, 1.1292602168396115, 38.43627892434597, 88.10003578662872, 84.99593675136566, 69.61187705397606, 58.142397701740265, 52.55385138094425, 32.92568922042847, 26.45845714956522, 34.946204200387, 42.22932279109955, 32.25640453398228, 38.46395283937454, 40.20148180425167, 19.878555424511433, 2.137943641282618, 0.03427865827688947, 0.07888619395089336, 0.046007107448531315, 1.0028041899204254, 1.0077094892039895, 1.9630843866616488, 1.6019067610614002, 2.334246807731688, 1.6109045594930649, 0.37391100951936096, 1.7576224054209888, 15.32020602375269, 42.66715429723263, 64.82664182782173, 75.18700629472733, 69.38718751072884, 75.16590982675552, 70.06107375025749, 71.51010319590569, 71.8586128950119, 74.3728543817997, 69.41940978169441, 72.02909454703331, 78.11442241072655, 70.095294713974, 58.96463178098202, 54.8631926625967, 57.93644115328789, 57.64647111296654, 59.0754072368145, 55.16625680029392, 54.14935156702995, 61.846792325377464, 67.31403395533562, 71.19837552309036, 72.28269293904305, 69.69177916646004, 63.29020947217941, 59.68752019107342, 56.9317826628685, 59.462769851088524, 65.86058154702187, 64.71382588148117, 70.40972024202347, 70.74382871389389, 61.94879785180092, 27.125116176903248, 28.12268614768982, 61.95355899631977, 71.95344060659409, 67.58382707834244, 66.47728085517883, 60.6152556091547, 55.73600962758064, 56.51697792112827, 62.464677169919014, 67.60833576321602, 71.58276289701462, 66.19748666882515, 64.70891654491425, 68.72229918837547, 66.27705439925194, 65.7252936065197, 63.51986534893513, 65.21632611751556, 62.99704760313034, 66.72429040074348, 64.98857393860817, 65.69385409355164, 66.85196354985237, 66.75230249762535, 60.45290932059288, 62.6138723641634, 66.9987116754055, 70.68229481577873, 62.66418166458607, 38.57769973576069, 16.791878454387188, 2.880310518667102, 0.7944433798547834, 1.3358686678111553, 1.4095747377723455, 2.757041333243251, 2.033954383805394, 1.7051398591138422, 0.19354482617927715, 0.056089450808940455, 0.08196171329473145, 0.04788799909874797, 0.043275625503156334, 0.15449696365976706, 1.3615836692042649, 16.43315300345421, 46.52531526982784, 55.76629400253296, 47.10850417613983, 31.970842257142067, 27.83903516829014, 49.80039373040199, 57.44441695511341, 66.34105056524277, 71.0096700489521, 93.00130918622017, 40.86357727646828, 0.20530274603515863, 0.08652195101603866, 0.014835460624453845, 0.04061851046571974, 0.03338424787216354, 0.1011942996410653, 0.02750860348896822, 0.028183937465655617, 0.05828020024637226, 0.021342048348742537, 0.03479128936305642, 0.02321866893908009, 0.04595109756337479, 0.045455788203980774, 0.0758377333113458, 0.0363223808381008, 0.07200034000561573, 0.03787476824072655, 0.007250638082041405, 0.0816400368057657, 0.06677078155917116, 0.02681974943698151, 0.015316428907681257, 0.026160727866226807, 0.04647066773031838, 0.05068071564892307, 0.09119351831031963, 0.033930591016542166, 0.04767042366438545, 0.0457473260757979, 0.050966386843356304, 0.19085121602984145, 0.10520777490455657, 0.08740725897951052, 0.1644025868154131, 0.09285143169108778, 0.15877789410296828, 0.17252656572964042, 0.15227043157210574, 0.10563407937297598, 0.10050427299574949, 0.15643037710106, 0.11610538975219242, 0.08398238845984451, 0.15746044839033857, 0.05950901497271843, 0.14513272239128128, 0.1411139778792858, 0.20018268405692652, 0.18099694949341938, 0.11982826224993914, 0.06770097461412661, 0.1991099986480549, 0.07374377848464064, 0.17248447111342102, 0.08818194241030142, 2.1254522865638137, 51.92272424697876, 101.07326164841652, 95.78374028205872, 78.99104297161102, 65.41803449392319, 51.508649066090584, 33.06293785572052, 35.95003053545952, 29.167981557548046, 49.08183328807354, 50.59863969683647, 59.65570069849491, 59.03225675225258, 28.709209375083447, 3.1631438294425607, 0.2892748557496816, 0.2990480500739068, 0.5821727577131242, 0.9787639486603439, 1.2105038948357105, 1.8524175812490284, 2.1009744750335813, 0.9866671683266759, 8.74061968177557, 6.630515959113836, 3.2386042177677155, 18.94745908677578, 45.42767956852913, 67.6948419213295, 77.80619814991951, 74.19490233063698, 76.11050114035606, 73.00852999091148, 74.15235981345177, 74.98601227998734, 77.97673299908638, 70.67654192447662, 71.41478911042213, 82.98345074057579, 74.23329547047615, 61.97106845676899, 57.705234959721565, 59.75373163819313, 61.15148663520813, 61.54412716627121, 57.19209909439087, 55.786486119031906, 66.09700486063957, 70.06164371967316, 73.1683874130249, 74.61579814553261, 72.37584874033928, 68.09414729475975, 62.57597699761391, 58.13441053032875, 62.41773448884487, 67.97787353396416, 67.4568834900856, 73.3504356443882, 74.30200338363647, 61.97334833443165, 32.760907262563705, 33.95221933722496, 62.919299975037575, 73.86568799614906, 71.16494491696358, 69.66515779495239, 64.10100236535072, 58.3785018324852, 60.67601054906845, 65.2829897403717, 70.8710078895092, 73.29315751791, 66.48375570774078, 64.7737030684948, 73.3411717414856, 67.83895298838615, 71.29517912864685, 67.41630926728249, 69.33348879218102, 65.49415960907936, 69.77162808179855, 67.7620755136013, 68.99506375193596, 70.74950560927391, 70.5548344552517, 59.683435410261154, 63.892241567373276, 68.99216070771217, 72.71559610962868, 65.75623154640198, 45.981727838516235, 16.639255844056606, 4.380445322021842, 7.9201235342770815, 10.056573618203402, 10.169344916939735, 5.104903522878885, 4.430440189316869, 1.3495734636671841, 0.22212019830476493, 0.22055926878238097, 0.1684753448353149, 0.427818390307948, 0.12229612591909245, 0.4354527743998915, 2.907961872406304, 25.009950175881386, 62.68760360777378, 84.0041595697403, 73.01315054297447, 53.37979406118393, 36.339684426784515, 49.33668181300163, 64.96316850185394, 77.09417715668678, 81.60863891243935, 98.6774218082428, 50.415793508291245, 0.7389452797360718, 0.3289197612321004, 0.13322566053830087, 0.08586934345657937, 0.1417272590333596, 0.2696985733928159, 0.19990253815194592, 0.10156547738006338, 0.1402752916328609, 0.12377815030049533, 0.10680386738386005, 0.1372027408797294, 0.09782897905097343, 0.11691767780575901, 0.24177431710995734, 0.13710738974623382, 0.21588902251096442, 0.10104334680363536, 0.1695844400092028, 0.23438577685737982, 0.115756595187122, 0.17292457952862605, 0.11369979969458655, 0.1129306155780796, 0.19730583764612675, 0.06970644317334518, 0.14877847832394764, 0.09917381743434817, 0.1374499502708204, 0.15501717949518934, 0.09869161440292373], [0.0418024883401813, 0.04822576534934342, 0.01730128060444258, 0.03321336836961564, 0.07483710302039981, 0.03491297931759618, 0.046278521986096166, 0.07060210409690626, 0.04308313837100286, 0.028755567436746787, 0.0375134759087814, 0.036689131666207686, 0.025295199993706774, 0.01888837639853591, 0.06726275125402026, 0.014699213443236658, 0.01083216206097859, 0.03468246453849133, 0.034593243544804864, 0.043575453164521605, 0.025050688309420366, 0.020154864396317862, 0.03530994668835774, 0.08815944791422226, 0.0180978926437092, 12.8707130625844, 66.59071996808052, 76.22435823082924, 69.81619209051132, 65.18533498048782, 34.90548178553581, 16.63250930607319, 30.59872068464756, 40.05012072622776, 43.01156401634216, 46.572592332959175, 57.70933493971825, 47.461239248514175, 17.046540789306164, 1.5755349886603653, 0.05666870820277836, 0.06886579765705392, 0.07007103064097464, 0.20105219911783934, 0.35589593870099634, 0.8644875150639564, 2.329502524808049, 1.4902662578970194, 8.012747839093208, 1.5256938943639398, 3.0856277514249086, 22.455527745187283, 50.89755065739155, 67.64346107840538, 70.16438260674477, 64.59347113966942, 67.62501686811447, 72.26055532693863, 68.14678207039833, 63.21960166096687, 67.55632415413857, 70.52998378872871, 66.85338467359543, 65.04165709018707, 67.34913647174835, 64.64026182889938, 54.088125452399254, 50.11203020811081, 57.76313625276089, 60.78882649540901, 61.75801768898964, 55.25025509297848, 50.97505509853363, 48.39394859969616, 55.32450310885906, 57.163361236453056, 61.516647040843964, 56.550328731536865, 57.76988469064236, 51.83375962078571, 57.01653711497784, 52.86666959524155, 58.969115540385246, 57.13297426700592, 64.11576837301254, 59.734288081526756, 76.79656952619553, 27.875116132199764, 20.836455523967743, 72.84391522407532, 63.48432585597038, 66.63365766406059, 54.251972660422325, 52.76091746985912, 50.25510013103485, 55.93325324356556, 58.82241681218147, 66.3818147778511, 63.36004972457886, 64.59699735045433, 63.87611523270607, 66.98359608650208, 61.45960450172424, 55.27139335870743, 51.44201584160328, 51.59448646008968, 51.09057269990444, 52.830370143055916, 56.018760055303574, 59.14402395486832, 63.521818444132805, 62.24218010902405, 61.197376772761345, 57.59846828877926, 57.76984669268131, 69.0324917435646, 62.839242070913315, 64.49499562382698, 70.51217034459114, 43.288261368870735, 6.920625166967511, 0.8127877267543226, 3.662814642302692, 2.0290920697152615, 2.062012078240514, 0.9335466125048697, 0.29291200276929885, 0.029751190086244605, 0.10247023703414015, 0.09382717034895904, 0.03688471726491116, 0.12778472359059379, 0.03403948634513654, 0.20055144239449874, 9.37940625473857, 33.68434891104698, 44.354601949453354, 50.78160747885704, 32.951919212937355, 14.544296208769083, 26.95232044905424, 57.62197382748127, 59.6972818672657, 68.07975366711617, 54.549762681126595, 6.346865929663181, 0.16386990289902315, 0.11450048797996715, 0.02822768707119394, 0.034030910828732885, 0.03903302327671554, 0.053628259047400206, 0.1021708917687647, 0.03774013151996769, 0.016621888935333118, 0.01544856459076982, 0.07640600320883095, 0.007370787616309826, 0.033284113596891984, 0.04127311069169082, 0.044261865550652146, 0.049913075199583545, 0.06812700448790565, 0.0275756676637684, 0.029408030277409125, 0.03546941195963882, 0.014217131938494276, 0.06254303341847844, 0.08015663202968426, 0.024334224508493207, 0.0317948532756418, 0.019262090427218936, 0.06730801484081894, 0.053794218110851943, 0.020367996221466456, 0.09337496492662467, 0.032967246224870905, 0.03670613055874128, 0.020023687939101364, 0.013304298645380186, 0.0712491455487907, 0.035640202404465526, 0.034355158859398216, 0.02979888791742269, 0.032306920329574496, 0.04494670829444658, 0.02717776889767265, 0.049937013172893785, 0.01764240692864405, 0.03628714366641361, 0.02011266773479292, 0.02865294325602008, 0.025308855510957073, 0.025173968315357342, 0.02500139486073749, 0.06667359732091427, 0.010531805619393708, 0.07234238844830543, 0.07482346976757981, 0.04252487633493729, 0.01217881870616111, 15.57002741843462, 80.69946929812431, 85.40180817246437, 80.05526706576347, 74.94964063167572, 48.09604458510876, 28.712406903505325, 33.22896234691143, 32.72558435797691, 29.361360780894756, 44.75823909044266, 47.364314049482346, 46.56829096376896, 21.26057356595993, 2.3214125214144588, 0.1288157151429914, 0.0669053329329472, 0.45998746412806213, 0.8202622225508094, 1.3764367159456015, 2.2844355180859566, 3.362426273524761, 2.5917027052491903, 4.56608816049993, 1.1722381669096649, 3.60769503749907, 26.54656872153282, 55.2093730866909, 70.29368966817856, 72.3520240187645, 67.81874567270279, 71.43658474087715, 74.42658349871635, 69.48750212788582, 65.18078282475471, 70.06221368908882, 72.45212584733963, 68.47015231847763, 66.8027637898922, 70.54289549589157, 67.51849338412285, 55.998545140028, 53.02674740552902, 59.088695123791695, 64.19807195663452, 64.6441376209259, 57.5396778434515, 54.24919120967388, 51.653922870755196, 57.77247615158558, 59.33679141104221, 65.9258696436882, 61.35041356086731, 60.04302151501179, 53.9044015109539, 58.47994118928909, 56.16732448339462, 61.933222487568855, 60.56701339781284, 68.6214753985405, 63.31644706428051, 76.13961517810822, 31.280039325356483, 21.5105127543211, 74.56247940659523, 65.44828847050667, 69.84491094946861, 57.509746849536896, 55.11813998222351, 53.324583023786545, 58.1268185377121, 62.921933233737946, 69.44884300231934, 65.70536747574806, 65.08553713560104, 64.1400870680809, 69.93122711777687, 65.20982846617699, 57.96967417001724, 54.423613250255585, 54.870150089263916, 54.33953896164894, 56.44923895597458, 59.71840113401413, 63.49547825753689, 67.23236873745918, 68.60549345612526, 63.84686440229416, 62.73420810699463, 61.98740758001804, 71.05042666196823, 69.83811691403389, 72.32764452695847, 75.15483722090721, 49.38937358558178, 9.537853002548218, 0.791743149748072, 1.0543033014982939, 0.9029450139496475, 2.5861286418512464, 3.0136130657047033, 1.0688115167431533, 0.3024536173325032, 0.1326446479652077, 0.07688516343478113, 0.06485045960289426, 0.02057019250059966, 0.03851544206554536, 0.07438268599798903, 10.957555621862411, 34.277489483356476, 45.25885462760925, 40.70463180541992, 27.22967516630888, 26.277138479053974, 35.85374370217323, 65.45382097363472, 67.30140343308449, 72.13213741779327, 67.6221290230751, 11.453543957322836, 0.22467239963589236, 0.08403146668570116, 0.06268176308367401, 0.08243014948675409, 0.0218919018516317, 0.028301471393206157, 0.034631965099833906, 0.05694062369002495, 0.08203970559407026, 0.052781483391299844, 0.12501744786277413, 0.025348760791530367, 0.11864360159961507, 0.02670786139788106, 0.07546346823801287, 0.04041500615130644, 0.04447391940630041, 0.027937720697082113, 0.09078627219423652, 0.061596424056915566, 0.047595581781934015, 0.03560323973943014, 0.04610145668266341, 0.0505363196862163, 0.03685359530209098, 0.02041905783698894, 0.019092255497525912, 0.03693887178087607, 0.047265641478588805, 0.007468425956176361, 0.09975736815249547, 0.11650866537820548, 0.1438748266082257, 0.09787178612896241, 0.1944124116562307, 0.21544435730902478, 0.16964223847026005, 0.1306513135205023, 0.18081347574479878, 0.13581832376075909, 0.1258242514450103, 0.12552768923342228, 0.12106777503504418, 0.14047519653104246, 0.24453901016386226, 0.1622303354088217, 0.08171030334779061, 0.09607068277546205, 0.16514326503966004, 0.16253577370662242, 0.1807552616810426, 0.17884717031847686, 0.1484294908004813, 0.12171680544270203, 0.12419828010024503, 21.464050747454166, 93.95845502614975, 95.02356067299843, 89.44826424121857, 85.68885236978531, 51.18045687675476, 27.020940966904163, 43.75071935355663, 56.134809628129005, 57.90631636977196, 62.46774360537529, 78.67436796426773, 65.81237733364105, 26.301337480545044, 3.1100768269971013, 0.48734430398326367, 0.1512582163559273, 0.6909909623209387, 0.6929583067540079, 1.7715827375650406, 1.9519632146693766, 5.587658593431115, 5.321711339056492, 18.22263278067112, 7.550252331420779, 4.478117655962706, 28.174589462578297, 58.79126988351345, 73.72212409973145, 76.42076209187508, 69.72722366452217, 72.89064511656761, 77.67762824892998, 74.62142184376717, 69.40752401947975, 72.69149780273438, 75.423574000597, 68.73258143663406, 66.32681652903557, 72.81299248337746, 71.18531182408333, 58.89084354043007, 55.69451965391636, 63.5663178563118, 66.07270896434784, 66.90191566944122, 60.400107353925705, 55.861577689647675, 54.36881259083748, 60.32424822449684, 63.98592934012413, 69.04167965054512, 63.935589641332626, 63.8497294485569, 56.56864754855633, 61.76638104021549, 58.8169527053833, 65.36374300718307, 62.946894094347954, 70.41510835289955, 65.8575265109539, 77.01608374714851, 35.01253344118595, 27.101464346051216, 75.5880519747734, 71.51077955961227, 73.12956869602203, 61.448303908109665, 57.50131130218506, 55.433340668678284, 58.794780895113945, 65.02835780382156, 71.34113386273384, 67.45349407196045, 67.2941306233406, 67.43340075016022, 72.60325133800507, 68.70743438601494, 60.3874122351408, 57.468644455075264, 57.362337559461594, 55.92805132269859, 59.41889360547066, 63.65229204297066, 65.98942503333092, 70.38331165909767, 70.13175755739212, 66.73969477415085, 61.8933892250061, 63.358469009399414, 72.043237388134, 73.60002145171165, 74.73581090569496, 75.58897152543068, 51.30945235490799, 8.517673294991255, 4.737562034279108, 10.438467375934124, 10.50955206155777, 5.421275971457362, 2.8976183524355292, 0.6902698322664946, 0.2106257705600001, 0.22858501703012735, 0.2493323787348345, 0.30511394958011806, 0.20314003864768893, 0.12620265770237893, 0.8117658784613013, 16.86586618423462, 48.6450657248497, 59.68678303062916, 66.33383095264435, 45.11565551161766, 24.469712264835835, 40.89243292808533, 72.64780014753342, 79.29204761981964, 81.57026097178459, 76.52930706739426, 12.773215994238853, 0.5177486396860331, 0.1865831989562139, 0.16246195969870314, 0.19037024496356025, 0.1429803011706099, 0.20088211371330544, 0.19465176912490278, 0.13816606340697035, 0.19909140042727813, 0.15430979401571676, 0.2148779056733474, 0.07482315064407885, 0.29919487657025456, 0.1492271214374341, 0.13688422593986616, 0.10750029134214856, 0.1914431233308278, 0.18150647840229794, 0.18538332427851856, 0.19348768080817536, 0.19753308326471597, 0.1745618018321693, 0.19857133302139118, 0.14120934385573491, 0.13175331376260146, 0.11560470724361949, 0.22210915514733642, 0.1775510687730275, 0.13371923327213153, 0.1584075327264145], [0.027994081247015856, 0.054470158793265, 0.04591574535879772, 0.06401036327588372, 0.06626616566791199, 0.03229866022593342, 0.03634043729107361, 0.032634415256325155, 0.04782411131600384, 0.02213904444943182, 0.01848098741902504, 0.05598422168986872, 0.05088000085379463, 0.01903889136883663, 0.038088161672931165, 0.055140199401648715, 0.022623371878580656, 0.017920849604706746, 0.05043740995461121, 0.018778866942739114, 0.030504482965625357, 0.06334784062346444, 0.05213782613282092, 0.0731527766038198, 0.9996245917864144, 47.118163257837296, 79.04476448893547, 64.3595252931118, 54.64500077068806, 41.50918923318386, 19.911210872232914, 24.963619261980057, 31.922049075365067, 33.775164037942886, 60.547756031155586, 52.35900163650513, 34.145438969135284, 7.543532866984606, 0.9034903440624475, 0.12030172278173268, 0.02489897105988348, 0.14983967528678477, 0.2532732719555497, 0.1867208821931854, 0.4229564918205142, 1.3250039820559323, 1.52514957357198, 2.5748646212741733, 2.6920992555096745, 6.292301807552576, 29.941540248692036, 54.52152639627457, 70.06124094128609, 65.8834259212017, 67.82368540763855, 68.47313895821571, 70.84826990962029, 70.53059935569763, 63.627019599080086, 61.88700556755066, 68.10383677482605, 68.8629600405693, 66.86291456222534, 65.82692295312881, 70.59924647212029, 63.71184624731541, 50.930931866168976, 48.941016644239426, 61.92719981074333, 64.7732774913311, 65.46463519334793, 62.92914144694805, 55.22294595837593, 45.09440325200558, 47.91692979633808, 47.14248575270176, 52.104943469166756, 49.711444303393364, 51.922652050852776, 52.750791013240814, 60.52840746939182, 57.95870415866375, 64.99438002705574, 54.90106523036957, 68.07476833462715, 59.14294861257076, 72.66864582896233, 36.42934821546078, 34.97571721673012, 75.9499141573906, 56.447160467505455, 61.178708374500275, 48.50370950996876, 52.6751446723938, 48.69398050010204, 56.84363879263401, 59.410864636301994, 65.10027274489403, 66.68661922216415, 65.50040647387505, 63.16323168575764, 66.33230343461037, 55.103514567017555, 51.22991122305393, 46.91572532057762, 47.899002358317375, 46.20031110942364, 47.67322227358818, 47.81134106218815, 52.48412512242794, 59.33520309627056, 62.777012810111046, 63.43764916062355, 58.9538099616766, 64.80928435921669, 69.42255601286888, 68.11557054519653, 70.90786591172218, 67.57134854793549, 73.88506695628166, 73.38423863053322, 27.323228046298027, 1.1968450527638197, 1.925954797770828, 1.3104101526550949, 2.741334163583815, 1.1396889947354794, 0.06967707638978027, 0.18096463638357818, 0.1544706619461067, 0.12239759977092035, 0.011336912466504145, 0.039574765105498955, 0.13236092490842566, 0.23398982622893527, 14.732390865683556, 43.28899472951889, 48.905754536390305, 54.44329619407654, 27.266972064971924, 31.72812458127737, 45.2079601585865, 46.79375946521759, 63.79388764500618, 72.43098378181458, 33.039565309882164, 0.3945368668064475, 0.009439217665203614, 0.029881418449804187, 0.04496991525229532, 0.011807615919678938, 0.04073725038324483, 0.044878857443109155, 0.019176915993739385, 0.06682562627247535, 0.03757897786272224, 0.046780699922237545, 0.04605048226949293, 0.12135716067859903, 0.020541682897601277, 0.03693641527206637, 0.1402342360233888, 0.09622104931622744, 0.05845011124620214, 0.050752859824569896, 0.02593950106529519, 0.03732091456186026, 0.03520582708006259, 0.05224688102316577, 0.018498387071304023, 0.02899058148614131, 0.04372404597233981, 0.02492620231350884, 0.07567560372990556, 0.06470425651059486, 0.10541452982579358, 0.061973939737072214, 0.023476029055018444, 0.05038249844801612, 0.05220718354394194, 0.019558463391149417, 0.04591881785017904, 0.056227813111036085, 0.02502505823940737, 0.04597490937158, 0.0015040153766676667, 0.034280966356163844, 0.07982363778864965, 0.026693029576563276, 0.011710019789461512, 0.020668083634518553, 0.059176221111556515, 0.04806929464393761, 0.029308545381354634, 0.04080135709955357, 0.07163513655541465, 0.0820266586379148, 0.09323608683189377, 0.04768078033521306, 0.03690578312671278, 1.234734719619155, 58.54403614997864, 86.8143367767334, 75.68748503923416, 62.00136423110962, 52.33114153146744, 28.97801835089922, 29.102258384227753, 37.6269755512476, 30.91248694807291, 47.0582290738821, 47.51518875360489, 38.07722859084606, 10.180864948779345, 0.9135586163029075, 0.06250321719562635, 0.03841135956463404, 0.24529193382477388, 1.3201074698008597, 1.3247254095040262, 2.559823840856552, 2.627345980145037, 3.3739099698141217, 1.4485507900826633, 2.33214742038399, 6.902012340724468, 34.440854117274284, 58.07199127972126, 70.1809573173523, 67.82761439681053, 70.04085123538971, 70.82680106163025, 73.02109211683273, 71.67722582817078, 68.0195041000843, 63.74100208282471, 71.37746751308441, 71.0761208832264, 68.92422795295715, 65.97016006708145, 73.32579776644707, 65.60799390077591, 55.185046792030334, 50.99721930921078, 63.504643365740776, 67.28643983602524, 70.44877454638481, 65.54773673415184, 58.07463973760605, 48.5837522149086, 51.33502118289471, 50.56082412600517, 55.20420916378498, 52.591499760746956, 54.999875128269196, 55.11495195329189, 63.02064813673496, 60.68630799651146, 67.63064816594124, 58.53912681341171, 69.57694172859192, 61.85067191720009, 75.72049766778946, 37.91283421218395, 37.035955265164375, 77.12812453508377, 61.85568764805794, 64.19575408101082, 50.524543672800064, 55.26217505335808, 50.56880749762058, 57.81705915927887, 61.61963291466236, 68.56173500418663, 68.09911742806435, 67.00048997998238, 66.65228426456451, 67.76221230626106, 58.057289868593216, 53.4931305795908, 49.100566282868385, 50.16946032643318, 47.36540079116821, 49.237735122442245, 51.161226108670235, 56.40975907444954, 61.59005530178547, 67.04694628715515, 65.24125277996063, 60.81851050257683, 67.34864249825478, 73.32106322050095, 71.24047726392746, 74.41905230283737, 69.2908626794815, 77.57919073104858, 74.77815583348274, 32.97552354633808, 1.648116318974644, 0.960941183147952, 2.4381061596795917, 0.6671357830055058, 2.283220295794308, 0.9009199007414281, 0.6872650247532874, 0.3980111866258085, 0.24205648165661842, 0.028670715837506577, 0.09227819682564586, 0.08816675806883723, 0.3037543944083154, 13.669814933091402, 42.2165022790432, 43.08821730315685, 51.12433008849621, 21.31780419498682, 39.96668480336666, 55.472470968961716, 54.813046753406525, 69.53209653496742, 81.52560576796532, 45.818644389510155, 0.7600682275369763, 0.11828078044345602, 0.03565833678294439, 0.08265734315500595, 0.02932623818196589, 0.0068265934532973915, 0.0031330796218753676, 0.007406557742797304, 0.042362338572274894, 0.0420566071261419, 0.00943208562603104, 0.05610709165921435, 0.04630707611795515, 0.04061259183799848, 0.016601459465164226, 0.030012676543265115, 0.03389866011275444, 0.03782442094234284, 0.082496697868919, 0.018272720371896867, 0.030943910460337065, 0.04160253520240076, 0.03339893868542276, 0.007223186503324541, 0.03031993495824281, 0.03333760760142468, 0.025579377615940757, 0.046173849477781914, 0.03539203193213325, 0.07446188799804077, 0.104750745522324, 0.14487519714748487, 0.12851098930696025, 0.21351852861698717, 0.17853631434263662, 0.12891336693428457, 0.16401794651756063, 0.14943499700166285, 0.10672712189261802, 0.06249091980862431, 0.11435501219239086, 0.12291305843973532, 0.176711892709136, 0.14917221735231578, 0.0995543907629326, 0.16166271117981523, 0.12405596586177126, 0.19349030801095068, 0.1121509746008087, 0.15889659320237115, 0.16067221120465547, 0.23278578068129718, 0.16541508404770866, 0.11866487897350453, 2.5276640290394425, 68.4157620370388, 99.39394935965538, 85.71794360876083, 73.52116048336029, 57.53169447183609, 32.719265297055244, 35.966544449329376, 45.91454364359379, 49.085663482546806, 83.40112432837486, 73.06121796369553, 51.5269260853529, 12.699580695480108, 1.7895218124613166, 0.15114318346604705, 0.13367883075261489, 0.4016545380000025, 2.157529452815652, 1.3478105957619846, 3.02527891471982, 5.560219790786505, 7.3697971645742655, 8.725568689405918, 10.08027484640479, 8.596429768949747, 37.530065551400185, 60.980442613363266, 73.4655998647213, 73.82057681679726, 71.87477722764015, 72.61919528245926, 75.13389274477959, 76.01980000734329, 69.3621164560318, 68.24821382761002, 73.9873194694519, 74.15755793452263, 68.43579456210136, 67.55963757634163, 76.13713771104813, 69.5483748614788, 57.733798027038574, 54.502702206373215, 67.03004479408264, 70.68139806389809, 71.51528611779213, 69.3467652797699, 62.33656704425812, 51.205250546336174, 53.1289467215538, 52.71148972213268, 57.83244453370571, 56.217003017663956, 58.44652198255062, 57.68180921673775, 66.21376499533653, 65.21443381905556, 71.07798278331757, 61.51915870606899, 72.81818300485611, 65.08751302957535, 76.31254389882088, 42.08994247019291, 40.41159152984619, 79.24867674708366, 64.89421740174294, 66.68532729148865, 52.96088933944702, 56.94021441042423, 53.157589584589005, 62.131617441773415, 65.24870797991753, 70.35944133996964, 70.15818893909454, 68.6495178937912, 69.22692731022835, 71.77950873970985, 61.29704162478447, 56.02073214948177, 51.33194334805012, 53.359244763851166, 50.494479686021805, 53.36788550019264, 53.034913167357445, 59.107895493507385, 65.01651003956795, 70.50601467490196, 66.62798836827278, 63.07604156434536, 68.69563981890678, 74.78511705994606, 74.25172448158264, 75.26869431138039, 75.08911594748497, 79.81992289423943, 80.69292604923248, 30.22322293370962, 1.7429877282120287, 7.718672594055533, 8.279207590967417, 9.066436998546124, 5.365779474377632, 0.8695843478199095, 0.5258263531140983, 0.2967416332103312, 0.31769982422702014, 0.20942214061506093, 0.15802842885022983, 0.3421950020128861, 0.4829420620808378, 22.08687722682953, 62.16964580118656, 65.34691751003265, 74.13442477583885, 40.270326510071754, 45.25284335017204, 59.640311524271965, 66.11363276839256, 78.93394723534584, 93.87665301561356, 51.07834115624428, 1.0075926454737782, 0.20155242149485275, 0.20886766724288464, 0.15530173375736922, 0.08838416280923411, 0.2040565019706264, 0.06633802782744169, 0.09986853445298038, 0.15757530316477641, 0.137435344804544, 0.14032963168574497, 0.19529703684384003, 0.1537059381371364, 0.12237759146955796, 0.09265327083994634, 0.2443774594576098, 0.14996140234870836, 0.17234404193004593, 0.1841609922121279, 0.1471445956849493, 0.18067349185002968, 0.12039981986163184, 0.1484537887154147, 0.08574763123760931, 0.10986748267896473, 0.13358998083276674, 0.08461436431389302, 0.15885690314462408, 0.21430369117297232, 0.23409449873724952], [0.02999802654812811, 0.03317287679237779, 0.042148811553488486, 0.09746138588525355, 0.09263437576009892, 0.03913973669114057, 0.01967909949598834, 0.030845106484775897, 0.04143875805311836, 0.03724377202161122, 0.04558530781650916, 0.02833593487594044, 0.07277169119333848, 0.02754860710410867, 0.02358086669119075, 0.04902076878352091, 0.04440738586708903, 0.02407368243439123, 0.02106057585478993, 0.04169447245658375, 0.017992628272622824, 0.006811863213442848, 0.08730677218409255, 0.07708523160545155, 26.165086291730404, 77.30895683169365, 72.00159922242165, 73.88157114386559, 62.76757411658764, 49.95292514562607, 55.58353900909424, 30.852839648723602, 27.67571423202753, 46.442506313323975, 43.90523426234722, 27.851464301347733, 5.78829400241375, 0.6890297925565392, 0.036208045567036606, 0.013066912506474182, 0.014481635225820355, 0.11404986333218403, 0.21259489614749327, 0.7232085429131985, 2.2231566812843084, 2.5917627895250916, 2.1618738071992993, 2.244322020560503, 12.189655657857656, 39.195668175816536, 59.609947353601456, 69.0062503516674, 62.06097923219204, 64.22940507531166, 71.50029972195625, 66.51125863194466, 69.81817558407784, 66.15632727742195, 62.49689944088459, 58.767099380493164, 66.60075142979622, 66.47415742278099, 64.47981163859367, 65.53160279989243, 67.34156727790833, 61.45822137594223, 50.87776131927967, 46.082221046090126, 60.36197640001774, 62.86631561815739, 66.06509417295456, 63.71534585952759, 60.61009928584099, 49.85554397106171, 49.021184742450714, 47.80697889626026, 54.51386220753193, 51.758975833654404, 58.36394861340523, 56.123121455311775, 64.94543865323067, 62.15130038559437, 62.76670776307583, 59.17576365172863, 67.11457505822182, 60.05213342607021, 74.01733785867691, 38.32728557288647, 39.92854245007038, 71.25313818454742, 55.03026969730854, 58.65799583494663, 46.6838351637125, 50.07252372801304, 46.83786749839783, 50.29739186167717, 55.18710248172283, 61.69576182961464, 63.24743136763573, 67.9017636179924, 64.68887642025948, 61.12288936972618, 52.4722545593977, 46.946925446391106, 45.98755672574043, 47.94873408973217, 48.86360339820385, 48.71050201356411, 48.05455081164837, 50.87964981794357, 60.729652270674706, 63.65503929555416, 65.18679410219193, 59.74033735692501, 60.58816306293011, 69.25041005015373, 64.65860724449158, 64.54513013362885, 65.51483809947968, 65.54334416985512, 66.78478315472603, 82.79921382665634, 53.757140412926674, 8.01966156810522, 3.199745840393007, 4.550739359110594, 3.0083510605618358, 1.4077520230785012, 0.35452136246021837, 0.4661687824409455, 0.030446413620666135, 0.016450265429739375, 0.03866448387270793, 0.13114340195897967, 0.06150057197373826, 0.09990961974835955, 18.979567363858223, 48.107671961188316, 43.23591537773609, 45.46102657914162, 18.86452853679657, 23.26117381453514, 51.98291301727295, 59.42530006170273, 65.54768353700638, 53.91212649643421, 9.661854598671198, 0.15513990103499964, 0.1220166776329279, 0.041082875977735966, 0.01601201423909515, 0.06799948125262745, 0.031419040824403055, 0.03159633248287719, 0.04134610091568902, 0.037290575564838946, 0.02555653245508438, 0.07315829818253405, 0.04907136841211468, 0.024588096530351322, 0.021785709795949515, 0.02781290815619286, 0.07861608930397779, 0.0010108879314429942, 0.003948213579860749, 0.11226963659282774, 0.01137743929575663, 0.04010070661024656, 0.057122761572827585, 0.014910238496668171, 0.03806060201895889, 0.09916950555634685, 0.033669273398118094, 0.11277026715106331, 0.06494509827462025, 0.062455036968458444, 0.03165233494655695, 0.06984161052969284, 0.08710906404303387, 0.07679435424506664, 0.03726022914634086, 0.04758275375934318, 0.025692202616482973, 0.019207588957215194, 0.05390449383412488, 0.03182532214850653, 0.04831977690628264, 0.012486340583564015, 0.054919577451073565, 0.07764455120195635, 0.06969539259443991, 0.04639654202037491, 0.016742853440518957, 0.007848485347494716, 0.0182018025952857, 0.030309531903185416, 0.03050667786737904, 0.05457172912429087, 0.13014488678891212, 0.0974919401051011, 31.97251796722412, 89.80501189827919, 83.55484127998352, 82.56374046206474, 73.98163497447968, 54.392641112208366, 53.64512622356415, 36.23506084084511, 27.905541099607944, 43.972270265221596, 47.39213615655899, 31.633889637887478, 7.308125523850322, 0.5354530771728605, 0.040850394507288, 0.10394518132670783, 0.1136966678313911, 0.7512302580289543, 1.2073031603358686, 1.3781323749572039, 3.598263943567872, 2.4910043086856604, 2.3709810990840197, 1.2993783946149051, 11.602906342595816, 42.46823877096176, 60.17818786203861, 71.07898592948914, 64.31909546256065, 68.54476511478424, 71.17221012711525, 69.47297170758247, 73.16467881202698, 68.83641466498375, 65.08625149726868, 61.5360563993454, 69.03517439961433, 70.55548042058945, 64.59615379571915, 65.9110276401043, 71.29512593150139, 65.493855625391, 53.33310976624489, 47.75079891085625, 63.1206663697958, 67.8341044485569, 69.33605745434761, 65.81145018339157, 63.935004472732544, 53.87365736067295, 52.07293398678303, 51.08666650950909, 56.28926753997803, 55.90909793972969, 61.86684764921665, 59.40465956926346, 67.12757796049118, 64.26891535520554, 66.37522593140602, 60.89203655719757, 69.58188906311989, 61.33155897259712, 75.3608013689518, 39.66433882713318, 41.24478422105312, 72.8959496319294, 57.99368128180504, 62.24301226437092, 50.54032042622566, 51.68542318046093, 49.35528941452503, 52.38989017903805, 56.65816314518452, 64.0814258158207, 67.43454068899155, 69.71196368336678, 67.20949396491051, 64.19657483696938, 55.36918871104717, 50.12366518378258, 49.62796278297901, 51.669733822345734, 52.50293031334877, 52.36445054411888, 50.41881814599037, 53.33734653890133, 63.288051187992096, 67.24914103746414, 67.98447757959366, 63.030007034540176, 61.94654077291489, 69.19336751103401, 68.56125622987747, 67.6116643846035, 70.3095880150795, 69.21884134411812, 70.29238253831863, 83.98636132478714, 59.81248028576374, 10.090090669691563, 0.7273761474061757, 1.6373127861879766, 1.6453069634735584, 1.6157293505966663, 1.3370026694610715, 0.6259616673924029, 0.482766380882822, 0.10907617514021695, 0.17485025979112834, 0.14259045099606737, 0.11504120935569517, 0.24188906798372045, 19.88196574151516, 50.417499616742134, 44.71570797264576, 41.7079109698534, 25.91165319085121, 31.764813512563705, 59.562696889042854, 67.68544122576714, 72.39030316472054, 68.05512338876724, 15.720735881477594, 0.29096923826728016, 0.08817762311082333, 0.005717254762203083, 0.030775815866945777, 0.0460924729850376, 0.04109552959562279, 0.04407436936162412, 0.06383328684023581, 0.04893531047855504, 0.04492675936489832, 0.003988716289313743, 0.04843829417950474, 0.027142266408191063, 0.04231845909089316, 0.024738984429859556, 0.0639318663161248, 0.06976352175115608, 0.05654737447912339, 0.04062698208144866, 0.041500545557937585, 0.011494029768073233, 0.025738373478816357, 0.022432621371990535, 0.03557660777005367, 0.0552820683515165, 0.027859845286002383, 0.05457615974592045, 0.0452497568767285, 0.09556935459841043, 0.07646130805369467, 0.14591551007470116, 0.21640506747644395, 0.27834922482725233, 0.20482469903072342, 0.1087285383255221, 0.1396679031313397, 0.11929479165701196, 0.1818777748849243, 0.10908585274592042, 0.16244600352365524, 0.08504811252350919, 0.14563395408913493, 0.22162601700983942, 0.11082425946369767, 0.19913002179237083, 0.1185978927242104, 0.12106592708732933, 0.18409845884889364, 0.12321643356699497, 0.10898319887928665, 0.2087602487881668, 0.19631762348581105, 0.2640418050577864, 45.47880582511425, 102.92064651846886, 91.09186604619026, 93.16669911146164, 82.61857151985168, 64.84682634472847, 67.17015087604523, 41.306200325489044, 39.985964968800545, 64.88919407129288, 62.99012437462807, 41.920194178819656, 9.524798803031445, 1.2734260247088969, 0.17719062248943374, 0.3396249149227515, 0.2595044329063967, 0.5558889149688184, 1.3476026756688952, 2.900347081013024, 9.159467406570911, 9.813132081180811, 9.7699891962111, 5.690786484628916, 14.57371138036251, 44.769102707505226, 62.39195667207241, 74.39119219779968, 68.77453878521919, 69.71032977104187, 73.27453851699829, 71.98508530855179, 74.24458846449852, 71.08708709478378, 68.25721174478531, 64.30150240659714, 72.60316014289856, 71.17428481578827, 65.5687116086483, 67.74597957730293, 73.82371544837952, 67.86011785268784, 56.73955097794533, 50.865339785814285, 66.15407779812813, 70.28462335467339, 71.17252171039581, 70.08797630667686, 67.557722479105, 54.92429718375206, 56.162943318486214, 52.896577790379524, 58.95340338349342, 59.41866181790829, 64.24275755882263, 63.22960652410984, 70.52391931414604, 67.9058749973774, 68.50953340530396, 64.45955112576485, 72.20386996865273, 64.92922872304916, 74.85953986644745, 42.48626120388508, 44.94220241904259, 72.51921504735947, 61.81499183177948, 65.20931169390678, 54.13270466029644, 54.26428399980068, 52.59134776890278, 55.22603139281273, 61.89766399562359, 68.5677082836628, 70.10643571615219, 73.32373067736626, 70.8004380762577, 67.73108437657356, 57.54723943769932, 51.949182227253914, 51.7268181592226, 53.8213075697422, 55.42659983038902, 54.08748708665371, 53.681558668613434, 56.174050122499466, 67.41741880774498, 70.74077367782593, 72.81081900000572, 63.30130107700825, 63.31099055707455, 72.20732018351555, 71.58405482769012, 71.83945432305336, 72.36331701278687, 72.69576117396355, 71.30537778139114, 89.43401500582695, 60.64557418227196, 8.867144342511892, 9.939300511032343, 14.00003431364894, 12.288101725280285, 5.064670331776142, 1.2143874051980674, 1.0662580537609756, 0.3588441351894289, 0.18927930272184312, 0.39629537088330835, 0.3143874113447964, 0.19231162907090038, 0.33166273904498667, 31.38859760016203, 63.507196828722954, 57.58894219994545, 66.08197286725044, 28.499416932463646, 34.41615544259548, 68.00057351589203, 77.21379473805428, 81.30102261900902, 78.27168077230453, 17.61361476033926, 0.3744170948630199, 0.16448708774987608, 0.10259738919558004, 0.08710049965884537, 0.1425680232932791, 0.1538462337339297, 0.11971963409450836, 0.11664817429846153, 0.1972625110647641, 0.16197634278796613, 0.13003691914491355, 0.09749335018568672, 0.07611077686306089, 0.1282437567715533, 0.1729946827981621, 0.15997255890397355, 0.25495497859083116, 0.15617319324519485, 0.17857495055068284, 0.13410862331511453, 0.1401712276856415, 0.1718682807404548, 0.11134672400658019, 0.17280132364248857, 0.1464837131788954, 0.1063435577088967, 0.27754295559134334, 0.17949132481589913, 0.25577282533049583], [0.01918578280310612, 0.029051589735900052, 0.018230200876132585, 0.02237418095319299, 0.040977583776111715, 0.011481132169137709, 0.06238638830836862, 0.024513495845894795, 0.06387319212080911, 0.02989219628943829, 0.036018694008816965, 0.025122617262240965, 0.008455062124994583, 0.03799392747168895, 0.020381147078296635, 0.021515326843655203, 0.05378388741519302, 0.05424469432909973, 0.09151646387181245, 0.03196059711626731, 0.03154630059725605, 0.028921563607582357, 0.05968575373117346, 1.850768350996077, 53.213989958167076, 72.85335391759872, 67.9548391699791, 61.94441668689251, 46.97807237505913, 29.074099995195866, 41.73341520130634, 35.6238978356123, 57.07666888833046, 44.03557486832142, 32.05711282789707, 6.4979510474950075, 0.17996356822550297, 0.04636910482076928, 0.03730921831447631, 0.07632884211489, 0.10720523569034413, 0.28842165309470147, 1.0660497774370015, 1.775236597750336, 2.270405483432114, 1.929851013701409, 5.3000985737890005, 15.811244174838066, 51.341914013028145, 58.17370802164078, 65.87463319301605, 60.313532799482346, 62.1364089846611, 70.7182028889656, 63.505954295396805, 69.90528970956802, 68.3848012983799, 63.26389968395233, 55.42721539735794, 60.34132070839405, 68.59963417053223, 67.00079396367073, 63.99695634841919, 62.65445418655872, 67.48968333005905, 59.08930689096451, 49.528738707304, 45.38260258734226, 62.50499680638313, 63.57570335268974, 62.79625117778778, 64.51432138681412, 60.882829651236534, 56.58385053277016, 52.50313550233841, 54.9010918289423, 58.53087745606899, 58.80730502307415, 63.08427952229977, 62.30077676475048, 65.85950240492821, 62.98030950129032, 67.17048525810242, 60.45831263065338, 66.43031537532806, 57.488840371370316, 70.78852191567421, 35.77186569571495, 42.812929674983025, 73.476832062006, 55.34694850444794, 52.83203445374966, 44.884327724575996, 47.19917871057987, 46.10318452119827, 46.027929559350014, 45.36823935806751, 50.06290644407272, 53.963932916522026, 58.38458530604839, 54.993461072444916, 53.3554981648922, 47.3367465287447, 48.584143593907356, 49.81685444712639, 51.63879208266735, 49.89660456776619, 47.534480318427086, 45.499974489212036, 47.767407819628716, 55.167503133416176, 61.35086193680763, 64.16980147361755, 64.15416911244392, 59.92164082825184, 66.02168530225754, 68.27364966273308, 66.91352024674416, 60.04609175026417, 60.138263404369354, 67.01676070690155, 65.11635348200798, 73.78303483128548, 72.89691478013992, 22.391250394284725, 1.456004565116018, 2.056830106303096, 1.417727794032544, 0.9000475506763905, 1.4643803844228387, 0.3171070560347289, 0.14379997359355912, 0.053127064456930384, 0.11538300546817482, 0.16442626132629812, 0.221071038977243, 1.7058976809494197, 25.649433061480522, 42.12525017559528, 27.426481805741787, 25.28390407562256, 25.70072840899229, 39.003531485795975, 47.757554948329926, 65.86674481630325, 65.9894098341465, 42.96765737235546, 2.654308620840311, 0.1871107768965885, 0.13358043681364506, 0.03540501951647457, 0.032499092048965394, 0.05575979252171237, 0.04590898439346347, 0.01576461745571578, 0.037745059380540624, 0.03647704070317559, 0.07894776994362473, 0.048430189926875755, 0.0226540151561494, 0.01744755049003288, 0.01647643541218713, 0.028101432908442803, 0.04410083434777334, 0.06202124051924329, 0.07149118959205225, 0.021784984346595593, 0.02055829401797382, 0.030021146303624846, 0.03420807632210199, 0.03906685407855548, 0.012522378347057384, 0.022158433057484217, 0.02125171598891029, 0.024130070814862847, 0.028070186635886785, 0.011629755590547575, 0.06596756255021319, 0.03712316189194098, 0.028517304635897744, 0.0068908295816072496, 0.022970240570430178, 0.048437340519740246, 0.02950982696347637, 0.0042265685897291405, 0.06315276710665785, 0.016989832765830215, 0.05246776272542775, 0.10677541344193742, 0.04997312236810103, 0.0331155310414033, 0.03205159184290096, 0.04738969888421707, 0.04868511023232713, 0.07781122272717766, 0.04449501495400909, 0.033070894569391385, 0.01016442396576167, 0.0466980246710591, 2.3534668888896704, 65.08714824914932, 85.3752475976944, 75.25015890598297, 69.67544764280319, 57.17654652893543, 46.71138368546963, 46.92160740494728, 31.047290414571762, 42.44008228182793, 44.629893377423286, 37.452557310462, 7.083633570000529, 0.02207878205808811, 0.0612134016409982, 0.09756164261489175, 0.14263342134654522, 0.6115461909212172, 1.4814688987098634, 2.413694132119417, 2.822295231744647, 3.124900544062257, 1.1793277552351356, 4.243315905332565, 18.09602167457342, 53.62087592482567, 63.429908975958824, 69.80586424469948, 64.07120436429977, 64.51367542147636, 71.44011855125427, 64.38544750213623, 71.23342484235764, 70.89704409241676, 66.25265970826149, 58.84950935840607, 62.91257433593273, 70.70177257061005, 68.76389175653458, 65.56987434625626, 63.43979224562645, 70.92776164412498, 62.20041275024414, 52.36579567193985, 49.61866468191147, 63.76287370920181, 65.93308165669441, 64.30645734071732, 66.3279640674591, 63.90498608350754, 58.50087806582451, 55.027921423316, 55.28466984629631, 60.21501548588276, 61.4814343303442, 64.53148126602173, 65.45268103480339, 68.19918885827065, 63.199983313679695, 69.09258931875229, 63.342939242720604, 68.69487226009369, 60.039529502391815, 72.13148385286331, 37.68972918391228, 44.74319189786911, 75.72519421577454, 57.51948192715645, 55.57959482073784, 45.90920493006706, 50.137108862400055, 47.49189220368862, 48.516260236501694, 47.411382123827934, 51.439112797379494, 57.03243546187878, 61.8360161036253, 58.337578028440475, 55.61258465051651, 51.445682644844055, 50.96659675240517, 51.5758902579546, 53.20403449237347, 53.433033004403114, 51.21248155832291, 47.27539122104645, 50.65876767039299, 56.40811376273632, 63.783240616321564, 68.00950303673744, 65.93556672334671, 61.57933987677097, 68.47525164484978, 71.44504308700562, 68.79646360874176, 62.872737273573875, 61.69774912297726, 71.25160306692123, 68.30195814371109, 75.0461858510971, 75.97528919577599, 26.482652351260185, 1.1829291307367384, 1.0558426938951015, 2.690151622518897, 1.8517564167268574, 3.8228568295016885, 1.1959828552789986, 0.9562024218030274, 0.4238326119957492, 0.12829158076783642, 0.048194776973105036, 0.0715610924817156, 1.4916725386865437, 28.798441886901855, 42.92389132082462, 31.670025698840618, 25.271721929311752, 32.8945878893137, 47.915527671575546, 56.21709801256657, 72.08775579929352, 76.51829525828362, 58.56049686670303, 4.471397716552019, 0.4230713762808591, 0.021963264916848857, 0.039409767123288475, 0.041626332167652436, 0.01691275701887207, 0.018086869895341806, 0.013271623738546623, 0.054216399948927574, 0.057175665569957346, 0.05303373938659206, 0.04412431218952406, 0.0729704977129586, 0.027977911704510916, 0.10739911434939131, 0.021801307884743437, 0.06152200519863982, 0.05732643658120651, 0.030845984074403532, 0.05792790274426807, 0.01853721623774618, 0.017779179179342464, 0.028358171475701965, 0.024372847728955094, 0.0009030445971802692, 0.04066054571012501, 0.03228247398510575, 0.017310742987319827, 0.055847414187155664, 0.17349071946227923, 0.13556691381381825, 0.2841828914824873, 0.16095057595521212, 0.13298548670718446, 0.15979905962012708, 0.1052986879949458, 0.07454777674865909, 0.15358176198787987, 0.2732598135480657, 0.14481582533335313, 0.15237307059578598, 0.1680351176764816, 0.14272460161009803, 0.1315768013591878, 0.16592421219684184, 0.1662727989605628, 0.10501459386432543, 0.16085558105260134, 0.09692617866676301, 0.10422062943689525, 0.26793092605657876, 0.1807235719752498, 4.709885269403458, 78.69820028543472, 92.53942117094994, 88.16576465964317, 80.38159355521202, 63.74795950949192, 44.1881138831377, 50.29043823480606, 49.06172476708889, 77.22167551517487, 61.37009650468826, 48.93425300717354, 11.019259560853243, 0.3199947823304683, 0.15943842037813738, 0.2101010869955644, 0.32554720470216125, 0.6050860625691712, 1.3936249748803675, 3.445605472661555, 7.4846583511680365, 7.473910627886653, 7.688380144536495, 10.89510977268219, 20.066274851560593, 62.270724177360535, 64.03156489133835, 74.07805100083351, 67.33523681759834, 65.88219478726387, 71.0835912823677, 66.49318680167198, 74.83897536993027, 75.3540301322937, 68.98863449692726, 61.739345490932465, 67.24432289600372, 74.02680695056915, 72.67855569720268, 65.4781548678875, 66.02666303515434, 75.12820824980736, 65.29031574726105, 55.692748948931694, 50.43853908777237, 66.42938062548637, 69.77939486503601, 65.8418257534504, 68.0906742811203, 68.18202137947083, 61.672488078475, 57.00549490749836, 60.669273510575294, 61.92999646067619, 65.749391913414, 67.79503494501114, 69.63862761855125, 70.16470938920975, 67.57262527942657, 72.19918861985207, 64.94894966483116, 70.50949528813362, 63.884436786174774, 73.80251258611679, 41.401951387524605, 49.953118935227394, 78.97645175457001, 61.78321413695812, 57.64456741511822, 49.0691951662302, 52.51459188759327, 51.78474985063076, 50.81625021994114, 50.28459794819355, 53.194626197218895, 61.535684019327164, 64.87433686852455, 61.05346329510212, 58.79163086414337, 54.014181420207024, 54.0589240193367, 55.5484364926815, 56.15560591220856, 56.575984954833984, 53.911742717027664, 51.48575909435749, 52.20626503229141, 59.86185863614082, 68.69405150413513, 70.51666170358658, 67.99001008272171, 62.55883991718292, 69.61144387722015, 73.54060783982277, 73.12538132071495, 64.91430312395096, 65.09964197874069, 71.82325199246407, 69.43250387907028, 77.08323374390602, 82.11019679903984, 27.006950117647648, 2.1187463589012623, 6.808844665065408, 6.904771467670798, 5.363169489428401, 4.3188985995948315, 1.1489881644956768, 0.7441200676839799, 0.4616079287370667, 0.608828030526638, 0.4616114613600075, 0.42472550470847636, 2.521048109047115, 40.628385096788406, 60.051115080714226, 40.85154712200165, 37.35774099826813, 39.16769787669182, 52.950078919529915, 68.33057820796967, 80.11326715350151, 85.52945852279663, 63.913444429636, 4.639959521591663, 0.5842506524641067, 0.23664488922804594, 0.107109298260184, 0.08242408614023589, 0.168887993786484, 0.1440497805015184, 0.15018109290394932, 0.2570788864977658, 0.20247054722858593, 0.2503366529708728, 0.13283454871270806, 0.13414657674729824, 0.12035576597554609, 0.18867969192797318, 0.18023592157987878, 0.1847703251405619, 0.13738624431425706, 0.13136905938154086, 0.14384157839231193, 0.08554808999178931, 0.0832329603144899, 0.15519336535362527, 0.13023504288867116, 0.09515372963505797, 0.12526798207545653, 0.12868922349298373, 0.15157291665673256, 0.10731098431278951], [0.04180753865512088, 0.009632480341679184, 0.027637714920274448, 0.07432630503899418, 0.030212594429031014, 0.024705908763280604, 0.031812304878258146, 0.02096637133945478, 0.07817781399353407, 0.009527466445433674, 0.02124905167875113, 0.044089716975577176, 0.06742363402736373, 0.11247237649513409, 0.07086408964823931, 0.035816800154861994, 0.05120749949128367, 0.03580264739866834, 0.039893435896374285, 0.061716585187241435, 0.080594016762916, 0.12734246294712648, 0.0679145944013726, 19.626302160322666, 74.53474849462509, 70.65175205469131, 66.94903314113617, 52.27035239338875, 37.95466236770153, 12.665898352861404, 16.695652417838573, 46.721012368798256, 48.68198074400425, 40.629471838474274, 11.666412334889174, 0.09700656068162061, 0.16356225300114602, 0.12176340489531867, 0.14046010124729946, 0.16733638563891873, 0.32475824235007167, 2.5015976652503014, 2.454665908589959, 1.6981380223296583, 1.6783838323317468, 5.2421958558261395, 21.893313713371754, 48.045997470617294, 57.48087599873543, 61.86044879257679, 63.07479903101921, 66.88287869095802, 66.22947335243225, 64.95221748948097, 70.91728180646896, 64.93497401475906, 63.76602753996849, 52.620887383818626, 54.65922340750694, 60.87239161133766, 64.291090965271, 64.69899907708168, 60.786242634058, 63.63762862980366, 62.883627489209175, 56.72946251928806, 49.152802079916, 44.871712401509285, 57.57669925689697, 64.04022842645645, 63.65308620035648, 62.46933951973915, 62.64680899679661, 59.14724238216877, 59.90422636270523, 56.76219396293163, 61.50830268859863, 62.172993421554565, 64.9169097840786, 62.43755042552948, 63.919364511966705, 62.35498085618019, 66.05534389615059, 58.78246195614338, 63.75287264585495, 55.50889201462269, 67.69680261611938, 33.30984480679035, 43.797069266438484, 68.54392915964127, 52.63819545507431, 52.9231421649456, 48.35835210978985, 53.85737903416157, 50.614515244960785, 52.501501590013504, 47.007030621171, 43.51671651005745, 42.35149763524532, 47.17500060796738, 45.69062165915966, 44.768167957663536, 44.18567441403866, 47.58757866919041, 50.44163592159748, 54.760772958397865, 52.22028627991676, 51.16331219673157, 47.193486616015434, 49.4321820884943, 49.94932293891907, 56.87407895922661, 62.85425126552582, 66.91016122698784, 61.50808610022068, 62.8809030354023, 65.60499966144562, 64.93648633360863, 66.39940023422241, 57.583371698856354, 55.0057952105999, 68.7850946187973, 67.74046987295151, 66.8995825946331, 76.87138751149178, 43.008786365389824, 2.6600897731259465, 1.4311835845001042, 3.5269678942859173, 0.8318798616528511, 0.8677456027362496, 0.3640903771156445, 0.26646939979400486, 0.1515229552751407, 0.12534234527265653, 0.042597202336764894, 0.0741086331254337, 6.162370154634118, 37.929283529520035, 46.790126860141754, 41.34974218904972, 20.798031985759735, 28.318001367151737, 52.64433592557907, 51.675342321395874, 61.42718844115734, 66.3255549967289, 24.681279212236404, 1.2883615982718766, 0.08823905809549615, 0.03980604429671075, 0.012832545053242939, 0.12010553604341112, 0.02078989604342496, 0.038260837172856554, 0.040647758505656384, 0.017148427868960425, 0.041125230345642194, 0.06074980796256568, 0.040402797822025605, 0.03709804390382487, 0.03307127677544486, 0.04259080873453058, 0.014226486709958408, 0.013196536019677296, 0.0035813787962979404, 0.030822072076261975, 0.05242005376203451, 0.015553555294900434, 0.044431130882003345, 0.0029592336159112165, 0.05789035378256813, 0.014541610034939367, 0.008487252780469134, 0.04646205881726928, 0.014375315149663948, 0.04089030720933806, 0.03148170406348072, 0.09573693154379725, 0.014058388405828737, 0.01988063711905852, 0.07681862247409299, 0.04398628014314454, 0.023878278661868535, 0.014703757242386928, 0.022424954986490775, 0.06772140593966469, 0.04905375724774785, 0.02425971659249626, 0.02881756088754628, 0.05552344075113069, 0.07170039360062219, 0.07288049004273489, 0.07033926507574506, 0.06778940150979906, 0.064655534515623, 0.07295772535144351, 0.08581527799833566, 0.017595313947822433, 24.74228873848915, 86.52833372354507, 78.0449241399765, 77.34102711081505, 61.61965951323509, 48.84662590920925, 22.22910549491644, 22.573372721672058, 36.17804870009422, 45.68192392587662, 39.75828118622303, 12.886729203164577, 0.10100488128955476, 0.13534340861951932, 0.041850802153931, 0.11310735804727301, 0.2883821411523968, 1.527114068157971, 3.615792402997613, 3.0374819599092007, 1.7352560930885375, 0.6392909958958626, 5.0274028815329075, 24.51561000198126, 49.909584671258926, 60.928005427122116, 66.04098826646805, 64.93258774280548, 68.64463895559311, 68.96591931581497, 66.17850288748741, 74.09320458769798, 65.98105028271675, 66.90105691552162, 54.58017624914646, 57.273946702480316, 63.167647048830986, 66.82419463992119, 66.2688772380352, 60.77472545206547, 65.06477504968643, 64.88508269190788, 59.99094910919666, 50.567523166537285, 47.598981857299805, 61.19822032749653, 66.05763137340546, 65.12767687439919, 64.0957510471344, 64.95743840932846, 62.13310316205025, 61.41088351607323, 59.96410354971886, 65.5915179848671, 65.13860508799553, 67.84818649291992, 64.50091570615768, 66.29300594329834, 62.06800885498524, 67.40145966410637, 61.06292858719826, 66.71078592538834, 59.06370006501675, 68.32635283470154, 35.04877969622612, 45.99894851446152, 71.33210554718971, 55.77436476945877, 55.82740992307663, 51.11418083310127, 54.354445561766624, 53.66264708340168, 53.66052679717541, 49.13791447877884, 46.96228042244911, 45.32953463494778, 49.49471913278103, 48.82767252624035, 46.6483298689127, 46.058107540011406, 49.55045834183693, 53.07799145579338, 55.29878228902817, 54.96662311255932, 53.9213789999485, 50.48076242208481, 50.920444428920746, 53.49115088582039, 59.70330834388733, 64.87692072987556, 69.15321886539459, 61.928077563643456, 63.75421017408371, 69.74151849746704, 68.97708311676979, 69.54890683293343, 60.063669607043266, 57.36919619143009, 73.10272693634033, 73.09514254331589, 69.01916205883026, 81.64143115282059, 47.84446008503437, 3.5994953149929643, 1.0639193980023265, 0.986501342849806, 1.9347583316266537, 4.155636560171843, 2.598332636989653, 1.0288046509958804, 0.5034798115957528, 0.5585520970635116, 0.10061695327749476, 0.09975385037250817, 6.114566819742322, 40.16880355775356, 42.34340026974678, 33.837598487734795, 24.222121350467205, 38.0751197040081, 56.953483298420906, 57.555348202586174, 66.59994587302208, 78.1850378215313, 39.0398233383894, 1.9978632079437375, 0.11295331045403145, 0.0690327437769156, 0.059182566474191844, 0.04049694296554662, 0.027910409662581515, 0.07140833622543141, 0.011247019829170313, 0.03450797077675816, 0.028262107880436815, 0.011743495288101258, 0.03519212332321331, 0.025178389660140965, 0.06378529957146384, 0.02752035539742792, 0.06135732262919191, 0.05924143362790346, 0.015895138967607636, 0.023337423699558713, 0.03285296661488246, 0.04228635007166304, 0.038953364855842665, 0.035557734954636544, 0.027294864958093967, 0.019105308019788936, 0.025084047847485635, 0.04467449223739095, 0.0035025165607294184, 0.11786380477133207, 0.07624897960340604, 0.16523733967915177, 0.14968611008953303, 0.11785032736952417, 0.17656092502875254, 0.14233959023840725, 0.12136648947489448, 0.18004032113822177, 0.09527585745672695, 0.12326629104791209, 0.192382444802206, 0.2048754767747596, 0.20240074081812054, 0.1409196836175397, 0.22403210430638865, 0.24962125229649246, 0.14576647197827697, 0.17452506552217528, 0.2145405104965903, 0.15982176933903247, 0.16938668733928353, 0.14673875964945182, 31.712832301855087, 99.14103493094444, 88.93782243132591, 87.19053938984871, 70.28700202703476, 54.13655765354633, 23.075472079217434, 27.321174256503582, 65.57343095541, 68.01935970783234, 57.74593077600002, 18.88871043920517, 0.41465862770564854, 0.2948391524842009, 0.45784325106069446, 0.48299905902240425, 0.47272123396396637, 1.5721759689040482, 6.614665109664202, 7.285884842276573, 5.2051459439098835, 6.6951181925833225, 9.757152535021305, 26.087036579847336, 52.40274488925934, 61.86739481985569, 66.50815039873123, 65.30438259243965, 70.28110474348068, 68.65460962057114, 67.85423576831818, 79.129089564085, 68.97084385156631, 69.7544302046299, 57.69361898303032, 59.26545403897762, 66.39373853802681, 67.48220533132553, 66.65792316198349, 59.82552118599415, 67.73277148604393, 68.41136947274208, 63.09533312916756, 52.677036970853806, 50.3510145843029, 64.02265816926956, 69.46957468986511, 66.864502876997, 63.93049031496048, 67.45239213109016, 65.68664208054543, 65.35874247550964, 62.35911503434181, 66.76548019051552, 67.99616575241089, 71.23397201299667, 65.93878895044327, 66.95702791213989, 66.10470324754715, 68.64509493112564, 62.953308150172234, 68.2554942369461, 60.217044577002525, 69.57191839814186, 39.19459283351898, 49.212113097310066, 71.94617539644241, 57.584222853183746, 58.22314336895943, 53.70066024363041, 57.36209437251091, 55.3494031727314, 57.37888567149639, 52.823963686823845, 48.01016919314861, 46.44171595573425, 51.9658937305212, 51.13264784216881, 48.609465435147285, 49.4100558757782, 51.204342395067215, 55.23724839091301, 58.197046369314194, 58.74827899038792, 57.18170665204525, 52.62296587228775, 53.7740533053875, 56.974431574344635, 62.708779871463776, 68.22159245610237, 72.73169964551926, 61.96705587208271, 65.50539180636406, 72.76107206940651, 72.76130005717278, 73.18396657705307, 63.217792958021164, 59.96218465268612, 73.88833478093147, 74.22349199652672, 70.86881160736084, 84.58628833293915, 50.087817907333374, 3.6630699411034584, 5.903810653835535, 11.612124647945166, 5.217512855306268, 4.814515504986048, 2.207506983540952, 0.8334694232326001, 0.6954959768336266, 0.48817886388860643, 0.20951012964360416, 0.19366165506653488, 9.959993250668049, 55.295092687010765, 64.72217783331871, 60.12436755001545, 29.54411957412958, 43.472122102975845, 66.75076737999916, 69.81877595186234, 76.06245651841164, 88.18687632679939, 42.7874406427145, 2.999667814001441, 0.2334199013421312, 0.21423519094241783, 0.1659407769329846, 0.2399000379955396, 0.094923329888843, 0.1774495281279087, 0.11568830275791697, 0.13457537483191118, 0.19852057012030855, 0.10967179317958653, 0.11600653568166308, 0.10266300989314914, 0.1194306492106989, 0.12351177123491652, 0.13125021185260266, 0.20299214345868677, 0.17417925439076498, 0.14322109840577468, 0.16730708564864472, 0.12829118000809103, 0.12038348519126885, 0.08386232380871661, 0.15562100568786263, 0.1137746823951602, 0.061649992276215926, 0.1394145339145325, 0.19132590852677822], [0.0754016696009785, 0.025564586612745188, 0.06983625222346745, 0.03201626561349258, 0.0364356733916793, 0.012441531562217278, 0.027817424124805257, 0.008671107807458611, 0.03266471343522426, 0.0638809624069836, 0.07180471729952842, 0.05813009716803208, 0.06816752575105056, 0.05342340031347703, 0.03750536423467565, 0.02141487715562107, 0.02993430203787284, 0.020534218747343402, 0.049719868184183724, 0.03218752361135557, 0.09558013058267534, 0.12099255836801603, 0.8770478004589677, 50.639339312911034, 75.4960285127163, 63.81658002734184, 61.54047556221485, 49.566645473241806, 24.444853998720646, 27.85246554762125, 28.52079838514328, 40.45796424150467, 42.903030440211296, 20.661431215703487, 0.19601776613853872, 0.015292521547962679, 0.06240256712771952, 0.06895933795021847, 0.061421681675710715, 0.14104378555202857, 1.1272971471771598, 2.226002491079271, 1.842812409158796, 1.511557346675545, 2.7659278688952327, 21.902976594865322, 57.064779326319695, 67.11731851100922, 70.32440721988678, 67.22468554973602, 70.07768645882607, 60.36939740180969, 59.38566438853741, 70.38065180182457, 64.14553597569466, 63.983231484889984, 54.59309935569763, 49.77772034704685, 56.155191734433174, 64.73695904016495, 65.3557026386261, 63.72613348066807, 60.87784431874752, 61.31311096251011, 63.4598171710968, 56.990390717983246, 46.57824642956257, 43.217721953988075, 54.26109977066517, 63.2341168820858, 64.25817713141441, 58.5843937844038, 64.0281754732132, 64.28499609231949, 65.25552481412888, 63.121870905160904, 62.386515364050865, 61.47103048861027, 62.52344101667404, 59.97722804546356, 59.711177721619606, 58.99538733065128, 63.428693041205406, 57.114875838160515, 62.204463332891464, 53.9744583517313, 59.86506566405296, 33.090493977069855, 45.03413088619709, 68.6932535469532, 52.14263364672661, 54.50872868299484, 52.228459641337395, 61.42547853291035, 58.9223438501358, 62.442835941910744, 55.960801765322685, 49.679879397153854, 43.739445358514786, 44.521485194563866, 43.86218637228012, 46.43116012215614, 45.58822475373745, 51.24598056077957, 55.51973283290863, 58.924574330449104, 53.66694465279579, 50.11375151574612, 43.475724309682846, 47.12839610874653, 47.19226688146591, 55.64439654350281, 59.82374668121338, 63.40294562280178, 63.21706339716911, 60.35502277314663, 65.12462943792343, 67.10009783506393, 65.65366744995117, 65.96166372299194, 55.96728041768074, 54.063894152641296, 66.02906450629234, 70.30051410198212, 65.24445980787277, 68.43334749341011, 44.54554930329323, 1.4598045987077057, 1.1528240586631, 4.511918742209673, 1.954643614590168, 1.6982826520688832, 0.6032470799982548, 0.2218678532517515, 0.09338007832411677, 0.04993861250113696, 0.13577631820226088, 0.07256391952978447, 13.741640578955412, 41.13815434277058, 38.24006885290146, 27.36431334167719, 25.13656698167324, 51.32723540067673, 47.851820290088654, 57.23743826150894, 60.7057249546051, 65.72261855006218, 26.25973731279373, 0.3471368149621412, 0.09487393996096216, 0.00860324489622144, 0.025661715189926326, 0.009887847791105742, 0.0549859217426274, 0.10091863630805165, 0.06249516489333473, 0.03517644916428253, 0.022017833180143498, 0.015887526387814432, 0.04090091992111411, 0.09118162168306299, 0.006854262110209675, 0.03268564571044408, 0.06329128897050396, 0.042458862299099565, 0.047918749987729825, 0.02097144206345547, 0.04068101414304692, 0.09650100968428887, 0.01965526356798364, 0.056783321779221296, 0.03412420621316414, 0.0629006075905636, 0.03628927734098397, 0.0541372498992132, 0.014301322098617675, 0.13006080145714805, 0.041846757449093275, 0.05381087932619266, 0.07225944602396339, 0.01975566501641879, 0.021635664234054275, 0.0325706870353315, 0.05419117063865997, 0.030002781859366223, 0.026851164548133966, 0.06261942267883569, 0.08301046444103122, 0.010584192896203604, 0.0469646041165106, 0.03430622164160013, 0.011882677663379582, 0.025582808193576057, 0.04719555305200629, 0.02167371043469757, 0.06870454380987212, 0.0647012804984115, 1.2688685255125165, 63.57656970620155, 86.28922775387764, 75.81316709518433, 69.53040182590485, 57.92565353214741, 34.26330864429474, 31.07372559607029, 31.17317955940962, 44.017864018678665, 46.21423356235027, 24.120788387954235, 0.3233027126407251, 0.03361805036547594, 0.2405087772058323, 0.08913419951568358, 0.3559472062624991, 1.0163332452066243, 2.397475177422166, 2.9127263417467475, 1.8911812012083828, 0.2495126612484455, 4.2134409584105015, 25.237139984965324, 60.51174536347389, 68.86656984686852, 72.74886712431908, 68.45150291919708, 71.93525478243828, 62.20904968678951, 60.566291436553, 70.99479004740715, 69.53697547316551, 67.60861694812775, 57.38545551896095, 51.28623940050602, 57.33887001872063, 66.27117991447449, 69.3254180252552, 64.80882078409195, 61.66570924222469, 63.90766113996506, 66.42671316862106, 60.3234388679266, 49.264105707407, 45.38686975836754, 56.111193895339966, 65.15582576394081, 66.05468273162842, 59.46724981069565, 66.4792187511921, 65.95218703150749, 66.90560907125473, 64.96522799134254, 64.54445376992226, 62.6432029902935, 63.20912182331085, 62.00043328106403, 60.35413362085819, 60.29763825237751, 64.79853093624115, 58.123565912246704, 62.868903279304504, 57.19977468252182, 61.84358909726143, 35.4570297896862, 47.85982646048069, 70.31151831150055, 54.74505700170994, 57.48278349637985, 56.134277656674385, 64.06487390398979, 61.87166579067707, 63.68625462055206, 58.77365402877331, 53.21669161319733, 46.3092702627182, 45.68581871688366, 46.24202907085419, 47.02691115438938, 47.43697755038738, 52.47646853327751, 58.57857629656792, 61.898097172379494, 55.971486791968346, 52.3165313154459, 46.78237147629261, 50.125652477145195, 49.551089107990265, 58.968815356492996, 62.583067417144775, 65.08546113967896, 64.57969307899475, 61.89777038991451, 66.80068910121918, 70.58026269078255, 68.38589563965797, 68.4326559305191, 60.005958303809166, 55.02702087163925, 68.16407114267349, 73.18146631121635, 67.97358736395836, 70.97123891115189, 51.1116311699152, 2.7466493658721447, 0.72259267908521, 2.1902119740843773, 2.2575828339904547, 2.6403374830260873, 1.6649337415583432, 0.42353091412223876, 0.3622782602906227, 0.33042979426681995, 0.10530404630117118, 0.04124668652366381, 14.52099870890379, 45.42103372514248, 36.346174478530884, 26.942459978163242, 37.99652472138405, 60.58152861893177, 54.31296318769455, 64.33861881494522, 65.63084587454796, 80.30793830752373, 43.41200552880764, 1.0502750426530838, 0.15721830044640228, 0.029622854199260473, 0.04046093767101411, 0.0590448275761446, 0.039458630126318894, 0.041438483458478004, 0.07912369605037384, 0.026151592028327286, 0.035265814876765944, 0.052810954075539485, 0.026357144670328125, 0.0809816998662427, 0.015456159544555703, 0.009717472948977957, 0.05797617573989555, 0.05465736554469913, 0.040385264583164826, 0.03462671440502163, 0.026500865278649144, 0.060236523786443286, 0.014287014419096522, 0.04216460445604753, 0.028784080750483554, 0.011936969476664672, 0.04657573728763964, 0.10784737896756269, 0.11612902715569362, 0.21765061392216012, 0.17486657219706103, 0.23657765064854175, 0.09464775561355054, 0.08923551751649939, 0.16082576155895367, 0.11422678391681984, 0.17235802399227396, 0.12103274566470645, 0.14240921853343025, 0.14759197714738548, 0.1998533634468913, 0.22426304582040757, 0.20666616037487984, 0.095475079579046, 0.10415263386676088, 0.14390080177690834, 0.14119101280812174, 0.2205160609446466, 0.28516463411506265, 0.33363195369020104, 2.3999813804402947, 76.39938443899155, 94.68056827783585, 85.74752882122993, 81.56759351491928, 68.52112278342247, 34.484775960445404, 39.349350929260254, 41.600312143564224, 57.27116145193577, 60.21254941821098, 33.429128006100655, 0.8485244528856128, 0.1511849812231958, 0.3691694576991722, 0.20958661538315937, 0.5058704770635813, 0.9319371613673866, 4.688604986295104, 7.6556681748479605, 8.50965952500701, 6.561051411554217, 6.536090075969696, 26.983347684144974, 64.60622325539589, 72.00767129659653, 74.71235856413841, 70.8604596555233, 73.75869333744049, 64.36591655015945, 62.204695120453835, 75.1951302587986, 71.55386924743652, 70.96689954400063, 60.47722041606903, 54.38562668859959, 60.20577058196068, 70.04697650671005, 72.18021243810654, 65.61740979552269, 60.98073899745941, 66.80972501635551, 69.50853019952774, 63.31225968897343, 50.5448991805315, 47.81754232943058, 58.96900534629822, 68.70756357908249, 68.69286596775055, 59.57202918827534, 68.5690838098526, 70.02407893538475, 68.46002206206322, 68.76280501484871, 65.54192304611206, 64.68877762556076, 64.21425148844719, 64.33503940701485, 60.51580734550953, 61.93861819803715, 66.29184320569038, 61.1773556470871, 64.29285407066345, 60.436543598771095, 61.95297762751579, 38.96499015390873, 52.37779922783375, 72.59507417678833, 58.32607224583626, 57.89373904466629, 58.59236195683479, 67.40967482328415, 65.20042017102242, 66.91773802042007, 61.19680680334568, 55.956488996744156, 48.1700000166893, 48.754154071211815, 48.60143266618252, 50.34864731132984, 49.03498940169811, 55.94038926064968, 60.74987858533859, 64.21504184603691, 59.09419342875481, 54.79936368763447, 49.83172684907913, 51.606037840247154, 52.6578252017498, 62.07455210387707, 66.34877175092697, 68.21934297680855, 65.63260897994041, 62.02668607234955, 68.70222106575966, 72.77120232582092, 70.59621423482895, 69.77814093232155, 63.06010141968727, 57.37276799976826, 72.53372266888618, 77.66818195581436, 68.46810042858124, 73.54927137494087, 52.96194188296795, 2.184307803399861, 6.320819752290845, 16.144423596560955, 5.713676931336522, 4.095833469182253, 2.6666318345814943, 0.5387784924823791, 0.5570062331389636, 0.6183359515853226, 0.2828814910026267, 0.15919846919132397, 22.75256920605898, 61.86698444187641, 51.482753455638885, 41.94222919642925, 36.308788284659386, 64.01758924126625, 66.51760429143906, 76.00843101739883, 73.80632758140564, 86.82293191552162, 46.24627724289894, 1.4005290856584907, 0.33317514695227146, 0.1558699962333776, 0.14101830020081252, 0.14496618445264176, 0.13773015554761514, 0.266731763840653, 0.20326111261965707, 0.09463899084948935, 0.1682328703464009, 0.17477365530794486, 0.07150302684749477, 0.21847267606062815, 0.06309314296231605, 0.13503817812306806, 0.2544400765327737, 0.12292347077163868, 0.11282529740128666, 0.08443339160294272, 0.09248708913219161, 0.19312766497023404, 0.11128836893476546, 0.12181270576547831, 0.09862177088507451, 0.20739027386298403, 0.11097749069449492, 0.21426800871267915], [0.04205265890050214, 0.052601442075683735, 0.03946994045691099, 0.034921714395750314, 0.03939952177461237, 0.031194448383757845, 0.02036436340858927, 0.018164077373512555, 0.042101050639757887, 0.0745955562160816, 0.02980992736411281, 0.16680607659509405, 0.0285111837729346, 0.026591570567688905, 0.04350790288299322, 0.02516405136702815, 0.027345266062184237, 0.023241430608322844, 0.06821823670179583, 0.08240001829108223, 0.05136296087584924, 0.08678745434735902, 15.474668685346842, 77.5256896018982, 73.10961216688156, 61.2184352427721, 48.77689965069294, 27.51612849533558, 20.054993256926537, 33.61701272428036, 34.680222272872925, 35.237694159150124, 40.1092379540205, 2.2267391765490174, 0.1210148524842225, 0.050480205900385045, 0.11732145067071542, 0.20211401948472485, 0.25614490848965943, 0.7799340959172696, 1.7878389777615666, 2.270114324055612, 1.7425275966525078, 2.829776080325246, 29.962214939296246, 63.05104650557041, 70.48774525523186, 67.46602579951286, 66.53206631541252, 68.01911652088165, 67.61905878782272, 62.965262308716774, 61.088128834962845, 66.10696792602539, 63.49664859473705, 54.23766642808914, 48.202298283576965, 53.82558614015579, 59.67045150697231, 61.59670874476433, 62.92075529694557, 60.35999670624733, 62.47463643550873, 62.22886562347412, 59.995478466153145, 51.61554493010044, 43.45316872000694, 43.5557746142149, 53.5054799169302, 60.88510572910309, 64.64958652853966, 59.003860875964165, 57.629455626010895, 60.545723140239716, 62.50012926757336, 59.94789741933346, 60.049458369612694, 58.30983191728592, 60.59129789471626, 53.83913241326809, 59.10935461521149, 57.855573892593384, 64.99064862728119, 60.07138319313526, 60.96827566623688, 47.463838309049606, 63.93665358424187, 30.420384854078293, 45.55226728320122, 67.3147103190422, 52.95875385403633, 56.66407562792301, 53.49875807762146, 60.741640627384186, 61.624447256326675, 64.0184023976326, 62.01796554028988, 59.39113229513168, 54.79693941771984, 48.810657039284706, 44.29939091205597, 44.114789217710495, 47.53616362810135, 56.39880806207657, 59.20558825135231, 62.56367325782776, 58.476958349347115, 54.14612554013729, 45.134472101926804, 47.59411431849003, 44.900670647621155, 52.91670151054859, 59.1631331294775, 62.94987313449383, 59.91155996918678, 60.38118816912174, 62.09002487361431, 61.699101850390434, 67.63263925909996, 64.50739815831184, 61.94278657436371, 52.49863274395466, 57.26858139038086, 64.76696223020554, 74.70679566264153, 68.21118861436844, 72.43042141199112, 48.44016171991825, 3.5650036158040166, 2.0305127184838057, 3.8741904124617577, 3.429984748363495, 1.201364197768271, 0.34792001824826, 0.5528882041107863, 0.24855983268935233, 0.19473865977488458, 0.0259086908044992, 1.0303747979924083, 25.25139681994915, 40.12852571904659, 36.619030237197876, 14.105278216302395, 21.071098633110523, 37.41415277123451, 44.22165468335152, 58.96283447742462, 58.004894480109215, 65.69047227501869, 18.757841661572456, 0.5659083835780621, 0.035252307789050974, 0.06662114974460565, 0.01763753101840848, 0.055866821348899975, 0.020130321572651155, 0.01344074991720845, 0.0952269573463127, 0.10805011144839227, 0.022857122421555687, 0.07912044544355012, 0.0485761406889651, 0.022653657069895416, 0.07206135938758962, 0.06692493305308744, 0.026855602591240313, 0.007931635573186213, 0.05503763459273614, 0.012368105326459045, 0.0336745166714536, 0.06424148290534504, 0.05522350918909069, 0.03661258284409996, 0.03158779407385737, 0.021244246272544842, 0.015105658039828995, 0.016551067637919914, 0.022335004832712002, 0.07736808634945191, 0.07265349675435573, 0.07592134366859682, 0.07012271380517632, 0.03533971052092966, 0.0377949279936729, 0.013586317545559723, 0.009203713798342505, 0.018070828373311087, 0.025082357606152073, 0.09501127438852564, 0.024011360583244823, 0.014350259316415759, 0.008231047631852562, 0.0593508224847028, 0.06347359012579545, 0.059538233326748013, 0.0193699912779266, 0.13090346561511979, 0.04474229855986778, 18.871632255613804, 89.25074324011803, 81.3841013610363, 68.32585126161575, 60.53909249603748, 40.97999542951584, 27.856320440769196, 30.585911571979523, 28.121432214975357, 36.17763452231884, 39.76208858191967, 3.2290565175935626, 0.10420576421893202, 0.0807428544794675, 0.2840327104786411, 0.6467686383984983, 1.1217004037462175, 2.807171568274498, 4.131449908018112, 2.3280153796076775, 0.6629376020282507, 3.4518770361319184, 31.643248535692692, 65.02672389149666, 72.78094500303268, 70.18667221069336, 69.26343575119972, 70.93294456601143, 69.43935871124268, 65.38096368312836, 62.77771197259426, 69.07100647687912, 65.07637962698936, 56.922887340188026, 50.84098309278488, 55.55058337748051, 63.02849091589451, 65.12229636311531, 66.23342514038086, 61.76214046776295, 61.81524641811848, 63.48636254668236, 62.76636578142643, 54.27082344889641, 45.68385802209377, 46.470461413264275, 56.02046616375446, 64.85846891999245, 66.65856912732124, 59.57193799316883, 59.01370234787464, 61.89057357609272, 63.0975142121315, 61.91250219941139, 59.18715924024582, 60.02968803048134, 60.2276536077261, 55.828880444169044, 60.5215260386467, 60.47798417508602, 64.69237983226776, 63.52374494075775, 63.149294033646584, 50.69090634584427, 63.596020862460136, 32.07217141985893, 47.00846694409847, 68.72953400015831, 55.61678722500801, 60.04948116838932, 57.23282530903816, 64.03446033596992, 63.42898942530155, 66.7674332857132, 63.47084417939186, 62.82987557351589, 56.49042874574661, 50.086411982774734, 47.0344727486372, 45.84958232939243, 50.76595991849899, 59.031971767544746, 62.65821598470211, 64.58065822720528, 61.631932854652405, 56.60713568329811, 48.71559754014015, 50.38064919412136, 47.51947492361069, 55.644890516996384, 62.04995982348919, 65.92091470956802, 60.899028182029724, 60.42130261659622, 62.64436572790146, 63.906270414590836, 70.35141617059708, 68.18264454603195, 64.91577744483948, 54.61397543549538, 60.38954772055149, 66.20608940720558, 76.40503853559494, 71.39457419514656, 72.82779648900032, 54.064099341630936, 4.623677395284176, 1.0660044173710048, 1.8430432467721403, 3.5966457054018974, 3.129226374439895, 1.2777154007926583, 1.2031877436675131, 0.9267688449472189, 0.407043598825112, 0.03446956834523007, 0.9731238044332713, 28.102632723748684, 42.139210626482964, 27.89446659386158, 15.646293126046658, 33.38983431458473, 52.06130661070347, 53.84816452860832, 66.37680664658546, 62.34402984380722, 75.7319350540638, 33.485228195786476, 0.7121560641098768, 0.03451951117313001, 0.026591993591864593, 0.059184952478972264, 0.022193581171450205, 0.015194767711363966, 0.03765317036595661, 0.07129803081625141, 0.04733309157018084, 0.02372753919189563, 0.06894488091347739, 0.0397967600292759, 0.048933288126136176, 0.060021961471647955, 0.11336673123878427, 0.03743896057130769, 0.03875839523971081, 0.01428695968570537, 0.02796639542793855, 0.021158168274268974, 0.03380402515176684, 0.08424859683145769, 0.07325877013499849, 0.07289472443517298, 0.04755701978865545, 0.021573271878878586, 0.11595465213758871, 0.1205363601911813, 0.16455067496281117, 0.15658391261240467, 0.10434853116748855, 0.11787371986429207, 0.16084269736893475, 0.12590907892445102, 0.14679258019896224, 0.20551799854729325, 0.1079339801799506, 0.4199390974827111, 0.1759966107783839, 0.14775069284951314, 0.1822913737851195, 0.12455590622266755, 0.2690355386584997, 0.14193914219504222, 0.11433450665208511, 0.11344594066031277, 0.23221722134621814, 0.1562112951069139, 24.961181692779064, 102.44412928819656, 89.90622326731682, 81.67758241295815, 68.29670682549477, 43.857953399419785, 33.11683036386967, 46.32766127586365, 50.30054189264774, 48.11046861112118, 59.360133558511734, 4.291573315858841, 0.3472378064179793, 0.17772568127838895, 0.622966478113085, 1.4085443993099034, 1.2245265673846006, 3.186022164300084, 6.884219320490956, 9.684960208833218, 5.560485301539302, 4.623701618984342, 34.34931702911854, 66.85211554169655, 74.90396708250046, 71.97224959731102, 70.2771757543087, 73.22082459926605, 71.87989175319672, 66.60235494375229, 63.95598694682121, 71.29148572683334, 68.10359358787537, 58.53978417813778, 52.776466235518456, 60.74917182326317, 66.63854420185089, 68.10006737709045, 67.76532053947449, 61.99464239180088, 64.18780490756035, 65.62712207436562, 65.19429489970207, 56.35100282728672, 47.5561847537756, 48.596884310245514, 58.91292795538902, 67.79016360640526, 67.62028232216835, 59.62716802954674, 58.184742629528046, 63.9261357486248, 65.14525473117828, 63.442360907793045, 61.69797711074352, 61.02043926715851, 62.0709764957428, 56.9344425201416, 62.502135559916496, 61.65247455239296, 68.28556582331657, 65.20817175507545, 65.32522067427635, 54.3194380402565, 63.7768417596817, 37.605217918753624, 51.958788111805916, 71.6056376695633, 59.21742081642151, 62.51712575554848, 60.24434231221676, 66.47529736161232, 64.66781795024872, 67.7516108751297, 67.45587274432182, 64.49821785092354, 59.67718094587326, 54.04244810342789, 50.04137679934502, 47.253572791814804, 52.68701523542404, 62.13038630783558, 64.68319192528725, 69.06678110361099, 64.46987897157669, 58.61896052956581, 52.130231112241745, 53.0154924094677, 50.908482670784, 57.8714494407177, 67.38327383995056, 68.38319018483162, 62.374112829566, 61.33146017789841, 63.7307046353817, 68.17638248205185, 75.27198493480682, 69.56564113497734, 68.67686122655869, 56.96793772280216, 64.06213045120239, 67.90690094232559, 82.6104399561882, 72.48431771993637, 76.5092821419239, 55.63500724732876, 4.362067133188248, 7.013389114290476, 11.501715872436762, 10.882361456751823, 5.081599373370409, 1.5878327912651002, 1.5104011399671435, 1.4944013860076666, 0.8393255027476698, 0.18152798584196717, 2.1078129205852747, 39.84670624136925, 60.88791377842426, 48.761160895228386, 24.310198724269867, 32.9388403147459, 52.32152044773102, 60.90479627251625, 77.25363940000534, 71.44471630454063, 86.32698252797127, 37.001114934682846, 0.978867671219632, 0.3120358125306666, 0.23445378727046773, 0.10443300241604447, 0.15597591554978862, 0.1164716990024317, 0.10232775952317752, 0.2536399819655344, 0.24390517151914537, 0.05951901912339963, 0.21802107919938862, 0.12960789841599762, 0.13337033480638638, 0.15637284581316635, 0.19043876003706828, 0.2073179738363251, 0.1180078333709389, 0.2591813908657059, 0.1012090832227841, 0.10536155532463454, 0.19423558755079284, 0.153458105341997, 0.20364358584629372, 0.2193235929007642, 0.12594108033226803, 0.06854098930489272], [0.011003475719917333, 0.046019950314075686, 0.03869266321999021, 0.0193790436242125, 0.03707566072989721, 0.02438108185742749, 0.027186969673493877, 0.019025827714358456, 0.040096153534250334, 0.05203117209021002, 0.1526488526724279, 0.04300995889934711, 0.02319659190106904, 0.0818200595676899, 0.03975683619501069, 0.03153185469273012, 0.019064256121055223, 0.038631124334642664, 0.007098413852872909, 0.03651722057838924, 0.02066593511699466, 0.1994917742558755, 37.53569304943085, 83.6391207575798, 59.6375946700573, 56.76244094967842, 33.512153550982475, 20.66477883607149, 19.94447808712721, 38.286319971084595, 47.71295294165611, 60.35783462226391, 19.429121240973473, 0.05870279768714681, 0.09392715248395689, 0.11056364688556641, 0.11019536352250725, 0.24210173782194033, 0.4471452219877392, 2.225984917022288, 1.7336152936331928, 0.8384032803587615, 2.7897321665659547, 30.954772979021072, 73.0160839855671, 67.81077370047569, 68.81406426429749, 65.6259973347187, 67.19692423939705, 63.99960860610008, 67.40782052278519, 66.76860362291336, 66.09530255198479, 63.27436052262783, 57.35165633261204, 47.60595068335533, 51.21674492955208, 57.130739986896515, 61.5368315577507, 63.014579862356186, 62.526727840304375, 59.047816917300224, 63.30658279359341, 58.42720001935959, 57.40602761507034, 47.41159491240978, 44.36719447374344, 44.49946157634258, 54.27577458322048, 62.33268365263939, 64.60853353142738, 60.462424010038376, 59.57882322371006, 60.443565621972084, 59.448896795511246, 61.54973566532135, 63.593163415789604, 58.92640583217144, 59.25719328224659, 58.53571839630604, 59.50860299170017, 59.65695843100548, 61.0635631531477, 58.204053193330765, 59.04306337237358, 57.388578951358795, 60.56850291788578, 26.20861865580082, 40.4414389282465, 67.8493720293045, 54.68615636229515, 53.14098447561264, 51.06998920440674, 56.957393288612366, 59.98912900686264, 62.3013087362051, 59.675573632121086, 61.6997592151165, 60.455306991934776, 56.21059276163578, 51.10132612287998, 50.85477635264397, 55.09574398398399, 61.24446764588356, 62.42664881050587, 57.6406954228878, 62.16934181749821, 53.91887493431568, 43.31882692873478, 46.70406527817249, 46.21454134583473, 54.16823275387287, 59.14490930736065, 63.20296995341778, 60.024797692894936, 56.79573476314545, 58.05902257561684, 60.09873412549496, 63.589511811733246, 64.76608827710152, 60.42945317924023, 51.146262511610985, 51.696070209145546, 59.33148309588432, 64.46527361869812, 67.62093588709831, 65.96695303916931, 73.6742390692234, 50.503895580768585, 2.1632258221507072, 1.7305599013343453, 1.6254050564020872, 0.8157001517247409, 0.7114365964662284, 0.5303991108667105, 0.0778123656345997, 0.1089662779122591, 0.110422846628353, 0.0124069790217618, 6.381495846435428, 40.50113372504711, 43.75613026320934, 43.43918167054653, 19.735276512801647, 17.82337110489607, 31.95556327700615, 44.09115448594093, 55.67661501467228, 63.517042100429535, 62.38494984805584, 12.236425448209047, 0.37386597599834204, 0.09922576035023667, 0.04061487765284255, 0.06807979647419415, 0.042449578031664714, 0.014451710903813364, 0.09968270067474805, 0.07847865839721635, 0.11586024353164248, 0.035156177400494926, 0.025274967192672193, 0.0682801911898423, 0.0707119790604338, 0.02740182328125229, 0.01884565095679136, 0.05988540629914496, 0.02519041059713345, 0.028749943812726997, 0.09650380758102983, 0.10787451930809766, 0.028223297267686576, 0.025954095399356447, 0.04325910529587418, 0.024449871525575873, 0.03642192139523104, 0.0100361186923692, 0.025223187549272552, 0.03157625367748551, 0.05978740198770538, 0.02290574979269877, 0.0547541119158268, 0.06051209435099736, 0.03535671312420163, 0.024384098687733058, 0.015560537976853084, 0.05832934897625819, 0.009528940536256414, 0.010817816346389009, 0.07621648095664568, 0.03409162593015935, 0.041841514175757766, 0.03025424561201362, 0.025291094061685726, 0.02005734062549891, 0.011407406291255029, 0.025193709443556145, 0.0875356727920007, 49.052107483148575, 94.22066375613213, 65.419592410326, 67.20754086971283, 41.24576836824417, 29.796849712729454, 27.238925769925117, 33.454202860593796, 42.89115987718105, 47.96367488801479, 20.676288418471813, 0.12404610271914862, 0.07441088018822484, 0.2638917724834755, 0.6128181132953614, 0.7377374789211899, 2.1754628280177712, 3.6032252898439765, 3.1121334666386247, 0.851800114614889, 3.649740731343627, 33.25377881526947, 74.81170803308487, 71.19877070188522, 70.53903490304947, 68.48952367901802, 70.6083431839943, 66.13807305693626, 69.967180788517, 69.22725409269333, 69.34072360396385, 66.92100584506989, 61.2637934088707, 49.83902245759964, 53.631420359015465, 60.1413032412529, 63.79163056612015, 65.27163594961166, 63.213670179247856, 60.68081349134445, 65.62769204378128, 61.47481128573418, 61.0519015789032, 49.61332216858864, 47.67354145646095, 46.95377267897129, 55.48074312508106, 64.6689122915268, 65.90692386031151, 61.30021445453167, 59.73718352615833, 60.901859030127525, 61.00007615983486, 63.86874362826347, 65.86580246686935, 61.68284632265568, 59.59580071270466, 60.738011822104454, 60.594763308763504, 60.32371245324612, 64.95307624340057, 60.38065239787102, 60.30670076608658, 58.585940301418304, 64.0608537197113, 31.42532642930746, 40.99145941436291, 71.54971987009048, 56.45382151007652, 56.25284269452095, 53.40636983513832, 61.155161038041115, 61.2059985101223, 63.935673236846924, 61.00966304540634, 64.74784165620804, 62.136256992816925, 59.156988859176636, 52.141592502593994, 54.32918831706047, 56.02218747138977, 64.96559277176857, 64.40053269267082, 59.55213725566864, 63.81253704428673, 56.932611018419266, 44.64132696390152, 47.840664088726044, 50.21874748170376, 57.101086378097534, 61.45010881125927, 66.46040216088295, 61.7245414853096, 57.31276921927929, 57.68358372151852, 62.751250192523, 66.87893450260162, 67.10132136940956, 63.36891084909439, 53.667195439338684, 53.66502955555916, 61.42734423279762, 64.93505001068115, 69.263846129179, 68.25083568692207, 75.19548743963242, 54.15157824754715, 3.245466174557805, 0.6483380135614425, 1.099247052334249, 2.605435405857861, 3.1217630999162793, 1.7474571196362376, 1.4378835749812424, 0.15766099153552204, 0.2826500002993271, 0.0985032573225908, 6.6993046179413795, 40.22664785385132, 37.82741479575634, 28.773085847496986, 21.043128333985806, 27.91629072278738, 41.45355261862278, 50.77662594616413, 63.56711581349373, 68.01296085119247, 77.48928755521774, 21.74777962267399, 0.28599447396118194, 0.11329210086842068, 0.07309708584216423, 0.03375531799974851, 0.0871625728905201, 0.06441723089665174, 0.021537531902140472, 0.06442513476940803, 0.04528083802142646, 0.036847313022008166, 0.015164872147579445, 0.08364371678908356, 0.03596695518353954, 0.029599764129670803, 0.049425847828388214, 0.02573648471297929, 0.023441751109203324, 0.003477604982435878, 0.03991057208622806, 0.08500865995301865, 0.07407712895656005, 0.0696176452038344, 0.030562774954887573, 0.01758079568389803, 0.03274570401117671, 0.15979138581315055, 0.12937054474605247, 0.10435734788188711, 0.12680400512181222, 0.2092419916880317, 0.12085326467058621, 0.1361648621968925, 0.1396529414341785, 0.17391251167282462, 0.10347349452786148, 0.2536424162099138, 0.09073286724742502, 0.1012438751058653, 0.15998554648831487, 0.11920551871298812, 0.21469216095283628, 0.10762140242150053, 0.19334763754159212, 0.09244849003152922, 0.09362076423713006, 0.09031929061166011, 0.337994564906694, 61.54036156833172, 101.90214917063713, 76.38444364070892, 78.68474900722504, 49.97628629207611, 33.601539954543114, 27.41275694221258, 55.569525361061096, 63.760852217674255, 80.0775034725666, 29.973059557378292, 0.21474561042850837, 0.24712112004635856, 0.3524854138959199, 0.8131226431578398, 0.6154367665294558, 3.0630132649093866, 8.778728786855936, 10.588354133069515, 5.456885285675526, 5.063823452219367, 34.68196637928486, 78.46214175224304, 73.8485661149025, 74.77287411689758, 71.01106077432632, 74.67922434210777, 68.94324213266373, 73.81456553936005, 72.70428791642189, 71.40975818037987, 68.07957127690315, 64.20918256044388, 52.281865775585175, 58.12225878238678, 63.53803597390652, 67.1550352871418, 67.85514771938324, 64.40826907753944, 63.032689690589905, 69.78669807314873, 64.8127193748951, 64.2037108540535, 53.01161661744118, 49.805523455142975, 49.33051094412804, 58.44460308551788, 69.31311428546906, 67.86992132663727, 60.608552768826485, 60.189534053206444, 62.77466833591461, 63.05569365620613, 66.59802317619324, 69.4496637582779, 63.56433816254139, 59.52317900955677, 63.26174519956112, 62.42214225232601, 62.17588126659393, 66.33564725518227, 64.13019239902496, 64.5265719294548, 62.34469100832939, 68.66437509655952, 36.638033017516136, 45.672086253762245, 74.24044668674469, 60.3020878136158, 58.890934735536575, 56.552224829792976, 62.95774631202221, 64.05042707920074, 65.24496138095856, 63.15109893679619, 67.21468448638916, 63.75930190086365, 61.126297786831856, 55.624755397439, 56.0963024944067, 59.78737883269787, 68.98005455732346, 66.04279696941376, 62.634452059865, 66.99495747685432, 60.79508475959301, 48.53336691856384, 52.08271086215973, 53.27737435698509, 59.42013993859291, 65.26151329278946, 69.09824341535568, 61.89609467983246, 57.27087266743183, 58.986830189824104, 65.4024325311184, 69.90642204880714, 70.5265411734581, 66.02740779519081, 56.64019010961056, 56.288777366280556, 63.92975315451622, 68.84263873100281, 71.79256483912468, 70.50802856683731, 78.78575518727303, 56.173252165317535, 3.056648843921721, 7.993560768663883, 10.958550218492746, 7.402383740991354, 4.927305802702904, 1.743850044440478, 1.5597828151658177, 0.5893185711465776, 0.4597563296556473, 0.17237953143194318, 10.391954071819782, 58.126799538731575, 59.90374378859997, 60.184408128261566, 30.017574168741703, 27.885552272200584, 46.64823867380619, 58.745843321084976, 72.86460891366005, 75.42376399040222, 85.47578260302544, 22.97092068940401, 0.8568273042328656, 0.3620497084921226, 0.25499935902189463, 0.16424501402070746, 0.23775021429173648, 0.12658744642976671, 0.1435083689284511, 0.14133491524262354, 0.2118361392058432, 0.11040337267331779, 0.14507722458802164, 0.19854739133734256, 0.17609852249734104, 0.13316386932274327, 0.1709481660509482, 0.09636147107812576, 0.0657975216745399, 0.10191849476541393, 0.21104070532601327, 0.15188887860858813, 0.2169427089393139, 0.12908786069601774, 0.1528656340087764, 0.11806778406025842, 0.16246512124780566], [0.10765211249236017, 0.09280708836740814, 0.015069877244968666, 0.04951171802531462, 0.03311861837573815, 0.01545969031212735, 0.04406870677485131, 0.030530096337315626, 0.017162819967779797, 0.012335369192442158, 0.13785597926471382, 0.03855223403661512, 0.00790967264038045, 0.05349509548977949, 0.04739555442938581, 0.038479544382425956, 0.03845474180707242, 0.041546851862221956, 0.02879234085412463, 0.03319940486107953, 0.07050915010040626, 5.274175889790058, 74.06102031469345, 70.92486619949341, 67.23076522350311, 49.59729462862015, 39.676220789551735, 23.78581166267395, 35.26328958570957, 55.65166935324669, 46.31014421582222, 39.18449677526951, 1.2842680304311216, 0.0673539463605266, 0.03754172576009296, 0.10544309508986771, 0.1208438839239534, 0.7517903717234731, 1.5061938157305121, 2.8847296815365553, 2.634596941061318, 2.092087701894343, 36.109576374292374, 70.87068110704422, 66.82401984930038, 64.52961176633835, 63.70112702250481, 62.10543304681778, 58.50265637040138, 58.930654004216194, 63.503321036696434, 66.2663921713829, 66.66251331567764, 59.94212172925472, 52.4611059576273, 46.24125011265278, 57.01248273253441, 58.527879416942596, 65.5132345855236, 61.68719328939915, 56.659884452819824, 61.88297778367996, 58.748225793242455, 54.63488571345806, 51.361688151955605, 44.432338178157806, 46.730762645602226, 46.170235723257065, 53.93147125840187, 60.30375212430954, 63.682166039943695, 56.099342331290245, 59.91084560751915, 60.284118577837944, 60.983949825167656, 57.9176739603281, 61.392933279275894, 61.21901661157608, 61.034129932522774, 54.7644929587841, 60.78414894640446, 58.867113813757896, 62.31033705174923, 56.76970236003399, 60.564193949103355, 56.02822154760361, 61.21118903160095, 34.32678423821926, 34.35626685619354, 67.20174998044968, 50.459107384085655, 56.3373501598835, 47.99767926335335, 55.223781913518906, 54.28198345005512, 62.612721025943756, 59.571204632520676, 60.39848484098911, 58.6382444947958, 60.25228388607502, 55.40190875530243, 56.01667016744614, 55.35813510417938, 61.88964642584324, 54.17248472571373, 54.38043996691704, 62.99844212830067, 50.923161283135414, 45.227240324020386, 46.238195076584816, 49.29740332067013, 55.46046361327171, 59.467177614569664, 61.78481005132198, 57.59534865617752, 54.390505626797676, 57.2457180172205, 57.59583882987499, 63.54540377855301, 62.04664260149002, 60.68321876227856, 53.49666818976402, 51.88533805310726, 52.03265994787216, 58.5614962130785, 63.32757666707039, 68.48259285092354, 63.15424136817455, 72.0203398168087, 55.666131377220154, 2.3891590861603618, 3.7279944447800517, 2.9138755425810814, 1.4243960799649358, 1.117868428118527, 0.48214924056082964, 0.466541726491414, 0.11013485622243024, 0.10302712238626555, 0.13434063352178782, 19.744861498475075, 34.12424750626087, 38.400070667266846, 34.36384364962578, 17.183228954672813, 24.70470305532217, 43.598032146692276, 57.37453110516071, 51.98902688920498, 61.94651037454605, 48.3917561173439, 3.384898267686367, 0.190230646985583, 0.11153996441862546, 0.03241094345867168, 0.041450213102507405, 0.02635732278577052, 0.0324101864680415, 0.029720481870754156, 0.034965382365044206, 0.04367426641692873, 0.009604469832993345, 0.05083426229248289, 0.036984907201258466, 0.033549962026881985, 0.032463598836329766, 0.041405606316402555, 0.017903264415508602, 0.054685196082573384, 0.041909220308298245, 0.05162604109500535, 0.03486422021524049, 0.03255077150242869, 0.05746725910285022, 0.03206150322512258, 0.025002845759445336, 0.05290840177622158, 0.06969224588829093, 0.05532313138246536, 0.046419040227192454, 0.03273596703365911, 0.041837450917228125, 0.013481201604008675, 0.010517810569581343, 0.04012869670987129, 0.015312335035559954, 0.02883973440475529, 0.0852126615063753, 0.03570803841284942, 0.07243276719236746, 0.03286091501649935, 0.014278415710577974, 0.0435799913975643, 0.09092024469282478, 0.07802890948369168, 0.03243025414121803, 0.15048002998810261, 7.629688493907452, 84.17370647192001, 79.93819534778595, 75.5611190199852, 58.95678140223026, 49.20926325023174, 30.76872356235981, 22.47296690940857, 43.19561094045639, 49.356174767017365, 43.54097440838814, 2.083848319016397, 0.13194717757869512, 0.059556148771662265, 0.409495328203775, 0.731513116043061, 2.373056737706065, 2.879685452207923, 2.448486490175128, 0.6838769721798599, 3.0276609119027853, 37.833361476659775, 71.70839175581932, 70.07655411958694, 66.96794852614403, 68.19890007376671, 64.56385552883148, 64.16106954216957, 62.99798235297203, 67.28970006108284, 68.24405685067177, 69.3785011768341, 63.22163835167885, 54.203000888228416, 48.621229603886604, 60.02222903072834, 61.43843583762646, 67.01932176947594, 63.54820042848587, 57.3158660531044, 63.80896523594856, 62.34331168234348, 57.20650412142277, 52.942756712436676, 46.80058389902115, 48.16508308053017, 49.000897631049156, 56.37886293232441, 62.58559808135033, 66.01596280932426, 55.756642520427704, 60.20664073526859, 61.27882920205593, 62.34609693288803, 59.873941987752914, 64.47538867592812, 61.81625336408615, 61.79080232977867, 54.62953180074692, 62.98702374100685, 58.6532536894083, 64.31830510497093, 59.09457340836525, 63.55990380048752, 59.42217282950878, 63.49169746041298, 37.12438032031059, 36.607786640524864, 70.28207749128342, 53.6188468337059, 58.27314868569374, 49.62107375264168, 57.209555357694626, 57.31890968978405, 64.50742095708847, 61.368743777275085, 62.20590725541115, 62.79047928750515, 63.56841914355755, 57.9243578016758, 58.15174140036106, 59.54153202474117, 64.61696147918701, 56.80682636797428, 56.98816403746605, 64.77583855390549, 53.777739107608795, 47.193083837628365, 46.88860237598419, 52.34716907143593, 58.383395969867706, 62.55226247012615, 63.90190824866295, 58.872163742780685, 53.761274591088295, 57.25379638373852, 60.44429138302803, 66.37970209121704, 63.88214930891991, 63.6472687125206, 55.70097930729389, 55.721494406461716, 53.652197644114494, 61.33890777826309, 65.09711891412735, 70.71697935461998, 65.36313503980637, 73.98078382015228, 60.62822811305523, 3.3305602334439754, 1.2017902499064803, 1.4724447391927242, 1.3212623703293502, 2.339362045750022, 1.7515838169492781, 0.9446538321208209, 0.1638529819319956, 0.18740352446911857, 0.1025613653473556, 21.354988999664783, 35.468136593699455, 36.480626463890076, 30.02090658992529, 22.051827907562256, 37.51552753150463, 50.424103662371635, 62.31641672551632, 59.175030291080475, 66.96976482868195, 61.705671697854996, 6.849049832671881, 0.25206288846675307, 0.07182420609751716, 0.04065397028170992, 0.04792646461282857, 0.025809786639001686, 0.011556301524251467, 0.05299260214087553, 0.04145023165619932, 0.04004186543170363, 0.04751788263092749, 0.06604605208849534, 0.06504309887532145, 0.038203873627935536, 0.02914810975198634, 0.025205459496646654, 0.008437715350737562, 0.03550146160705481, 0.044213295695954, 0.044156803414807655, 0.010694890715967631, 0.04984304243407678, 0.01889677379949717, 0.047609467364964075, 0.032726003701100126, 0.2008232762455009, 0.1962253448436968, 0.20448071358259767, 0.16292013198835775, 0.13979099574498832, 0.22689302422804758, 0.21254025923553854, 0.10835044377017766, 0.12361243614577688, 0.1889415958430618, 0.27953440498095006, 0.22591355256736279, 0.1642505355994217, 0.17173751431982964, 0.11188856602529995, 0.16091818863060325, 0.18044936325168237, 0.18403920577839017, 0.1848088129190728, 0.1893320248927921, 0.22155238111736253, 10.040657222270966, 97.72237345576286, 88.42507794499397, 86.91947713494301, 67.35767841339111, 57.36736848950386, 33.528979048132896, 50.81332057714462, 72.16360732913017, 61.19489550590515, 59.42987881600857, 2.8196367993950844, 0.2016867502243258, 0.31877602741587907, 0.8222149615176022, 0.8631023112684488, 2.440087515860796, 5.772671615704894, 12.411875333637, 8.379227723926306, 4.332625837996602, 41.66961282491684, 76.44163057208061, 73.72290685772896, 70.52142664790154, 72.36498892307281, 66.31933093070984, 64.52861621975899, 66.83224260807037, 69.31470260024071, 71.05085223913193, 70.63233509659767, 67.1024689078331, 56.01674996316433, 51.389232873916626, 62.42406114935875, 63.9482581615448, 70.13539776206017, 64.27853643894196, 57.78585143387318, 65.18183156847954, 65.07489770650864, 60.81417113542557, 56.55711516737938, 48.861756697297096, 50.346188843250275, 51.9799567759037, 59.2407401651144, 64.80936795473099, 68.14880356192589, 55.97948536276817, 61.04019060730934, 63.31666745245457, 64.17631432414055, 61.92678943276405, 65.78054264187813, 65.29897168278694, 63.372919633984566, 56.94589510560036, 64.62594419717789, 62.90890373289585, 65.44426068663597, 62.49380260705948, 66.01169943809509, 62.58208326995373, 65.9450738132, 40.836040154099464, 41.733092218637466, 71.18896722793579, 55.794484689831734, 58.92526589334011, 52.9041013866663, 59.69486139714718, 60.02317138016224, 67.10074380040169, 63.10740128159523, 63.180509358644485, 65.07789954543114, 65.6955336034298, 60.091959089040756, 61.077265217900276, 62.41010829806328, 66.72280088067055, 59.250277653336525, 59.76764649152756, 67.18164145946503, 55.94859302043915, 48.79799611866474, 49.16967697441578, 53.624637722969055, 60.83719030022621, 65.39614006876945, 64.95826676487923, 59.100922867655754, 54.009826853871346, 59.8368863761425, 62.0180719345808, 70.26960656046867, 66.4230577647686, 66.63041263818741, 59.59766261279583, 58.5036139190197, 57.03379958868027, 63.57938535511494, 68.37934479117393, 74.1814586520195, 67.99185678362846, 75.30393362045288, 63.06631788611412, 2.6365730725228786, 7.713868701830506, 11.344885937869549, 6.2764856312423944, 4.450737750157714, 1.9785140524618328, 1.280609064269811, 0.31607894401531667, 0.4006831260630861, 0.29178515542298555, 30.588848814368248, 50.81444911658764, 56.061465963721275, 48.1568793207407, 30.18245492130518, 36.683961153030396, 57.723139598965645, 72.79660016298294, 68.17458137869835, 76.548290848732, 70.68632259964943, 8.248135708272457, 0.47126704012043774, 0.2136044396320358, 0.15297720849048346, 0.1615384459728375, 0.14739983511390164, 0.1242206187453121, 0.07969170619617216, 0.14863797492580488, 0.16619518515653908, 0.07698146451730281, 0.21731062122853473, 0.14329799974802881, 0.14609675738029182, 0.14150795439491048, 0.10200210512266494, 0.18449492898071185, 0.1250929242814891, 0.17968959698919207, 0.10782987912534736, 0.1195298224047292, 0.18570019165053964, 0.1729158964008093, 0.10847232668311335, 0.0982875372574199], [0.049359989643562585, 0.020345861667010467, 0.011234886642341735, 0.10201113705988973, 0.010096318001160398, 0.04398151555506047, 0.06468776598921977, 0.05172552599105984, 0.03225682536140084, 0.014801140932831913, 0.0379177385912044, 0.038780689355917275, 0.01139954694735934, 0.03219333462766372, 0.04672325769206509, 0.0008693067957210587, 0.06172044435516, 0.0413289758580504, 0.0748473075509537, 0.058097765504498966, 0.03972980717662722, 21.933851838111877, 78.48919630050659, 64.99746546149254, 57.50302121043205, 45.032660365104675, 30.005251429975033, 20.68563971668482, 63.0560128390789, 53.173514530062675, 47.29540854692459, 15.555440001189709, 0.06696595897665247, 0.052795524825342, 0.059862481357413344, 0.1150487495760899, 0.39181938918773085, 1.283002698328346, 2.5941345747560263, 1.9541413290426135, 0.5268317554146051, 31.25291258096695, 73.42046588659286, 65.32550945878029, 66.40320003032684, 60.721076130867004, 60.72117492556572, 59.927572309970856, 59.876883029937744, 55.02374924719334, 60.75763776898384, 62.874906957149506, 62.25283853709698, 55.255320221185684, 48.42666484415531, 56.422043815255165, 60.640178471803665, 62.089960277080536, 62.008948624134064, 55.53693450987339, 61.10982947051525, 59.47858080267906, 59.38461944460869, 54.05775748193264, 46.26448966562748, 43.33757132291794, 44.63759556412697, 44.44482430815697, 55.87519235908985, 60.55139243602753, 60.96262536942959, 57.4922563880682, 60.2128192037344, 58.68080981075764, 55.76968342065811, 55.619424283504486, 57.823237627744675, 58.46997432410717, 59.30982805788517, 56.76777586340904, 62.188101410865784, 57.62524165213108, 61.95556528866291, 53.746584579348564, 59.51585300266743, 51.33386604487896, 66.43620505928993, 37.71875202655792, 34.34131845831871, 66.17800131440163, 52.386698350310326, 58.15009988844395, 50.953783839941025, 52.1603748947382, 49.828291833400726, 57.89259910583496, 58.31984058022499, 61.586380898952484, 55.238186940550804, 60.50712861120701, 59.95523102581501, 62.06724509596825, 55.48210345208645, 57.587095499038696, 51.92905090749264, 60.084583684802055, 57.799253314733505, 48.71549874544144, 43.594737723469734, 44.651168435812, 52.89177484810352, 61.229492649436, 62.53303550183773, 61.51044197380543, 56.62721760571003, 54.960136860609055, 58.557077050209045, 60.13363145291805, 62.76087507605553, 63.09443637728691, 58.272791504859924, 48.92981864511967, 48.00555244088173, 53.46379995346069, 50.13751924037933, 54.37694415450096, 60.26164658367634, 67.72404715418816, 63.20888623595238, 68.37355390191078, 61.71156518161297, 6.601188657805324, 1.6172688617371023, 3.069469593465328, 2.966856574639678, 1.4023173647001386, 0.37813077215105295, 0.24701953487237915, 0.071358233835781, 0.01940745860338211, 1.9328475091606379, 26.060069426894188, 38.13449151813984, 30.048358216881752, 18.08294277638197, 10.915113799273968, 22.129630632698536, 40.88495872914791, 52.95510224997997, 56.39160364866257, 66.26354992389679, 36.920232474803925, 2.086585834622383, 0.36787399440072477, 0.05696687716408633, 0.043202067536185496, 0.0369549986498896, 0.09692782623460516, 0.018466335568518844, 0.026486948154342826, 0.049116153313661925, 0.04933792930387426, 0.04475076275411993, 0.03951454724301584, 0.03609717241488397, 0.05150515637069475, 0.015003327007434564, 0.07739058084553108, 0.011857321260322351, 0.02617860991449561, 0.022953128500375897, 0.03647668818302918, 0.045622578472830355, 0.04336811565735843, 0.037604103272315115, 0.09737357497215271, 0.06223260046681389, 0.007460825900125201, 0.011748514061764581, 0.01797018943761941, 0.055628376721870154, 0.012306148983043386, 0.028754138802469242, 0.10102341271704063, 0.027399407590564806, 0.033735706747393124, 0.039442106208298355, 0.0646146792860236, 0.03277652540418785, 0.07434250612277538, 0.02129572349076625, 0.061787746017216705, 0.041727583375177346, 0.009404649354110006, 0.07503797271056101, 0.08638492829049937, 0.09221510685165413, 28.377872854471207, 89.48904365301132, 72.12120160460472, 66.86263337731361, 51.99786141514778, 38.831700906157494, 22.637587375938892, 60.27102068066597, 63.63100178539753, 52.7542108297348, 16.10565047711134, 0.1148693502182141, 0.0325217757927021, 0.29050723649561405, 0.5381534260232002, 1.162196968216449, 3.4467230876907706, 3.635863638482988, 1.2325212196446955, 1.5667662466876209, 33.91028478741646, 74.97048631310463, 68.94722431898117, 67.98823177814484, 64.87863823771477, 63.3563981205225, 61.90146379172802, 62.77053415775299, 58.12741130590439, 62.67165206372738, 64.55484241247177, 65.28424367308617, 58.14101077616215, 50.0368170440197, 57.98046559095383, 63.66259329020977, 63.546824902296066, 64.45684567093849, 57.39514499902725, 60.86717829108238, 62.366475239396095, 62.12331488728523, 55.78506499528885, 48.70602585375309, 45.10374695062637, 47.81460888683796, 47.60024718940258, 57.72190846502781, 62.625951915979385, 62.63054206967354, 57.993806675076485, 60.891466587781906, 60.93677155673504, 58.503636717796326, 57.61229954659939, 60.25877773761749, 61.56914882361889, 60.47130033373833, 58.33286628127098, 63.63614670932293, 58.258591666817665, 63.31776559352875, 57.824833542108536, 62.499597296118736, 54.567462131381035, 69.31591853499413, 41.433953270316124, 35.601900815963745, 68.38316738605499, 53.708263635635376, 60.29606893658638, 53.28763000667095, 54.37674656510353, 52.5133341550827, 59.05654884874821, 60.72350800037384, 60.68508066236973, 55.79232260584831, 61.56886763870716, 63.41095559298992, 63.58665056526661, 59.575844183564186, 58.149214535951614, 55.43634630739689, 62.21910394728184, 59.52190227806568, 50.51682248711586, 45.3509084880352, 47.621225863695145, 55.64975805580616, 63.34376759827137, 64.95114594697952, 62.60081626474857, 56.106064170598984, 55.97456842660904, 59.246443659067154, 63.24584685266018, 64.5943982899189, 65.1293183863163, 61.16730898618698, 52.09742747247219, 51.917472928762436, 55.195663422346115, 53.460345938801765, 56.109392791986465, 62.97027803957462, 69.68121573328972, 66.67269676923752, 69.57387149333954, 66.0276509821415, 7.942842040210962, 0.3354953380767256, 1.4314148970879614, 1.26299855299294, 2.4703101441264153, 2.1499053994193673, 1.1828359169885516, 0.3573642927221954, 0.07186184040619992, 1.8895009788684547, 27.163644209504128, 40.42019806802273, 32.63186998665333, 24.11321349442005, 20.14315042644739, 35.71521073579788, 49.935214295983315, 58.17651987075806, 63.982099145650864, 71.94989159703255, 51.40935279428959, 2.4841741751879454, 0.346578779281117, 0.05693530991266016, 0.04741325094073545, 0.06197049988259096, 0.0573076045839116, 0.03545131468854379, 0.03144041467749048, 0.031069871474755928, 0.03855761831800919, 0.017529596771055367, 0.03329852981551085, 0.02369686437305063, 0.052819525881204754, 0.007390385881080874, 0.018937747772724833, 0.021856341845705174, 0.0198462923799525, 0.036539703942253254, 0.01548087955598021, 0.013261775438877521, 0.10287827724823728, 0.07162012290791608, 0.07268146087881178, 0.08972510491730645, 0.10900921857682988, 0.10313841485185549, 0.1446618148474954, 0.141525988583453, 0.11648610408883542, 0.16138684004545212, 0.28774989070370793, 0.08750304055865854, 0.0780791454599239, 0.16419263323768973, 0.15724668017355725, 0.08877825806848705, 0.09418012836249545, 0.1334939172375016, 0.17165277589811012, 0.21803874231409281, 0.07540054895798676, 0.13821161643136293, 0.3444738109828904, 0.16771854716353118, 35.27617089450359, 100.90659499168396, 81.989256888628, 77.8498350083828, 60.31249925494194, 45.75291931629181, 31.327519677579403, 81.24943658709526, 61.54118612408638, 65.04614844918251, 23.5504237934947, 0.14548482693498954, 0.344814783311449, 0.6219081161543727, 0.9964124578982592, 1.5991026302799582, 4.911010377109051, 10.195954889059067, 7.2833760268986225, 2.701622019521892, 34.551071003079414, 79.01239782571793, 71.64814218878746, 70.2024793624878, 67.20621854066849, 65.83397537469864, 65.2298229932785, 66.21381059288979, 61.369078159332275, 66.46851852536201, 67.44449615478516, 67.08356112241745, 60.107298865914345, 54.33416225016117, 62.59060621261597, 67.68945381045341, 66.03497698903084, 67.12600484490395, 60.89971974492073, 60.93453727662563, 65.99019259214401, 63.63205432891846, 59.22430984675884, 50.14391049742699, 48.67191128432751, 48.79343256354332, 50.046289935708046, 59.45395812392235, 63.48328851163387, 65.8550338447094, 58.908239006996155, 62.848521173000336, 63.93910825252533, 59.44481961429119, 60.86566977202892, 63.24933126568794, 62.088003382086754, 61.72429069876671, 60.653565153479576, 65.48273742198944, 62.225157022476196, 67.06839233636856, 59.971604347229004, 64.11928698420525, 57.99276553094387, 71.03930845856667, 45.36315143108368, 39.16085064411163, 68.69216680526733, 57.36604616045952, 62.738938853144646, 56.27546668052673, 56.84663683176041, 54.53267879784107, 62.50531978905201, 62.59050741791725, 62.70637460052967, 55.14988727867603, 62.21319526433945, 65.80413937568665, 66.70539781451225, 60.33396050333977, 59.72185514867306, 55.865951254963875, 65.58300644159317, 63.66823598742485, 54.753937125205994, 48.409972339868546, 49.26060609519482, 58.018022775650024, 66.40687823295593, 67.31197446584702, 64.63860511779785, 57.891531363129616, 56.23786769807339, 61.31590761244297, 65.14426678419113, 69.91549596190453, 67.0387615263462, 64.56914484500885, 53.07793065905571, 54.16882172226906, 58.00573043525219, 55.25229938328266, 59.49567228555679, 66.18735641241074, 73.00728365778923, 70.93932062387466, 67.94973224401474, 69.14048954844475, 6.7518130503594875, 5.22020073607564, 10.80917738378048, 8.518091272562742, 4.567168727517128, 1.9895738339982927, 1.5008945250883698, 0.6109562132041901, 0.10110181319760159, 3.2758115837350488, 38.98398153483868, 56.25550635159016, 43.1397957354784, 26.009019166231155, 17.66676250845194, 34.66201364994049, 54.91159066557884, 68.46405744552612, 71.19221985340118, 82.70006194710732, 58.90867978334427, 3.0094551388174295, 0.4899912478867918, 0.13685407990124077, 0.16671430261339992, 0.13583603140432388, 0.1549294576398097, 0.1197617435536813, 0.15381470730062574, 0.12930477561894804, 0.18589454528409988, 0.17558587656822056, 0.1406851501087658, 0.12767884880304337, 0.1023979889578186, 0.12869931670138612, 0.15074505092343315, 0.09026890620589256, 0.04492956097237766, 0.1383505019475706, 0.14932256162865087, 0.12906282063340768, 0.19344463624292985, 0.18327978090383112, 0.16133097116835415], [0.03466023350483738, 0.029548687671194784, 0.037915545544819906, 0.006778212382414495, 0.08963706393842585, 0.02734090779995313, 0.06558928987942636, 0.026704905794758815, 0.05815326701849699, 0.01621109349798644, 0.02250850597192766, 0.03906453486706596, 0.012056840241712052, 0.010558295653027017, 0.05454865575302392, 0.05075414002931211, 0.03233677693060599, 0.03261627345636953, 0.009193788500851952, 0.031237192379194312, 0.7055344444233924, 43.675825372338295, 71.03781133890152, 65.40785104036331, 63.54289211332798, 48.099756985902786, 27.573114037513733, 35.20961746573448, 30.516069419682026, 29.844761341810226, 40.1581147313118, 2.3065154207870364, 0.10565053278696723, 0.08789841231191531, 0.1576333391130902, 0.20102585287531838, 0.5065509374253452, 1.9711721339263022, 1.5268024848774076, 0.29672925418708473, 23.143843710422516, 70.01841723918915, 67.53573685884476, 63.50713223218918, 65.54702997207642, 59.15911674499512, 60.82826837897301, 57.8916871547699, 55.09852163493633, 51.98915608227253, 54.121791645884514, 56.21102213859558, 58.74476037919521, 49.771249294281006, 51.54308281838894, 61.19370236992836, 61.94393031299114, 60.888901725411415, 54.97652918100357, 60.75268283486366, 60.72993725538254, 56.66126377880573, 58.28261777758598, 52.73988179862499, 48.93575772643089, 43.2274304330349, 44.536885768175125, 44.34179283678532, 54.67504195868969, 61.35740518569946, 62.30801157653332, 58.062594383955, 62.76481166481972, 61.373915299773216, 53.52079689502716, 50.13833239674568, 55.33262327313423, 55.38863606750965, 60.1872693747282, 54.3908704072237, 58.7233979254961, 57.05564081668854, 59.72653649747372, 53.499886617064476, 53.9223213493824, 52.160663679242134, 63.624222949147224, 42.966262847185135, 33.19071739912033, 61.59073926508427, 56.31695665419102, 61.22298739850521, 55.89234843850136, 52.50604994595051, 46.698646768927574, 51.57979264855385, 55.316599532961845, 61.59965358674526, 54.4644458591938, 51.46812044084072, 51.132499650120735, 51.52112379670143, 52.67164885997772, 58.08152496814728, 59.341465160250664, 61.29851594567299, 52.74136371910572, 46.69752962887287, 44.05214957892895, 45.76158285140991, 57.03057736158371, 59.32503864169121, 58.99465397000313, 55.06963558495045, 55.35381853580475, 57.76398740708828, 59.37276028096676, 60.71900524199009, 60.712784975767136, 61.106626242399216, 56.16108521819115, 50.48422783613205, 47.694474533200264, 51.48732081055641, 54.486864656209946, 51.33891977369785, 53.8906804472208, 56.824134439229965, 67.31051534414291, 64.05096665024757, 65.08971691131592, 65.4521794617176, 13.924826849251986, 0.48210999579168856, 1.9441327848471701, 2.9291744716465473, 0.6852138473186642, 0.4332702961983159, 0.09899742377456278, 0.24952233885414898, 0.03618415583332535, 7.710828389972448, 28.136910684406757, 35.83418995141983, 30.444809943437576, 20.48352476209402, 14.394681137055159, 31.63660079240799, 43.92487920820713, 51.523468270897865, 58.80355082452297, 65.87580353021622, 18.798436783254147, 0.5609095736872405, 0.1525409147143364, 0.0916993290593382, 0.017679872398730367, 0.09019616089062765, 0.011429592796048382, 0.04460076357645448, 0.02823076141794445, 0.14976847363868728, 0.029197195399319753, 0.013809863557980862, 0.051917233868152834, 0.03282688383478671, 0.024142999027390033, 0.005192570270082797, 0.05523450039618183, 0.015074762432050193, 0.03618502785684541, 0.027895230887224898, 0.08261225768364966, 0.028113860171288252, 0.03280640798038803, 0.03726162809471134, 0.069659828877775, 0.0976861675735563, 0.04450346059456933, 0.03422822934226133, 0.06996434691245668, 0.02941338487289613, 0.03957795262977015, 0.04905651061562821, 0.03604844299843535, 0.030974596411397215, 0.04989169021428097, 0.01309989169385517, 0.015499216169700958, 0.040268855009344406, 0.09647999206208624, 0.021365086467994843, 0.03207632020348683, 0.030033742405066732, 0.05613906709186267, 0.035159275867044926, 1.072305548004806, 53.21688160300255, 80.38894236087799, 73.35319429636002, 69.98473584651947, 55.48490770161152, 36.30450591444969, 33.86447824537754, 32.83656880259514, 33.890970423817635, 41.19475990533829, 2.957193930633366, 0.0939405630924739, 0.0694750044203829, 0.6308114540297538, 1.167469066567719, 2.988091972656548, 3.2299506571143866, 1.675598225556314, 0.7433361816219985, 24.809347540140152, 73.64624977111816, 68.09176862239838, 68.32930147647858, 66.92544400691986, 62.19114884734154, 62.86777473986149, 59.76198099553585, 58.40810224413872, 56.37102395296097, 55.814114436507225, 59.78498496115208, 60.80293133854866, 51.40326552093029, 52.77539849281311, 64.39095720648766, 64.20615032315254, 63.62989604473114, 59.3823167681694, 63.34469474852085, 60.25600388646126, 60.79356864094734, 60.36088965833187, 56.5360376983881, 52.038348242640495, 46.42102986574173, 46.73979476094246, 46.42421029508114, 57.61528618633747, 62.75486379861832, 64.78729113936424, 58.4834636002779, 64.29062739014626, 64.31569084525108, 56.27821773290634, 53.50150153040886, 56.40157051384449, 57.902824357151985, 62.47022487223148, 55.09066365659237, 60.06849154829979, 61.39821879565716, 62.11551770567894, 54.318146109580994, 56.83440908789635, 55.261802673339844, 65.64447954297066, 45.85696153342724, 35.534663423895836, 62.743415012955666, 58.99868555366993, 64.92678925395012, 57.65331834554672, 55.77557310461998, 49.61844049394131, 54.23539415001869, 57.68722012639046, 63.32486741244793, 54.98476713895798, 50.74839346110821, 53.507938385009766, 53.49689997732639, 52.98416309058666, 58.029840141534805, 61.71129919588566, 63.070094883441925, 54.73213389515877, 49.98458504676819, 46.038477793335915, 48.80835436284542, 58.870704621076584, 61.971174851059914, 61.214939430356026, 56.47646829485893, 54.667020589113235, 57.69885890185833, 60.87698936462402, 62.940008863806725, 64.53161045908928, 63.0232547968626, 58.75579118728638, 52.65780620276928, 48.72842185199261, 53.864477053284645, 55.63801288604736, 52.94147998094559, 55.94015747308731, 59.545924589037895, 67.72720858454704, 67.96737089753151, 67.21460089087486, 71.54753878712654, 17.74082623422146, 0.24563416780438274, 1.6197658027522266, 3.190979710780084, 2.417583935894072, 1.7197250202298164, 0.36685152270365506, 0.35016845853533596, 0.027844570031447802, 8.150414451956749, 33.2801304012537, 41.81606076657772, 26.859208345413208, 15.359162483364344, 22.60011188685894, 43.91921751201153, 52.520941346883774, 59.602503553032875, 63.035923317074776, 77.01779365539551, 28.722292073071003, 0.8399017655756325, 0.14678262057714164, 0.06108184112235904, 0.031108349976420868, 0.03801834784098901, 0.013040388148510829, 0.026797208556672558, 0.01801045651518507, 0.13279922248329967, 0.030128360667731613, 0.03483120948658325, 0.08265375116025098, 0.06326254559098743, 0.026667850361263845, 0.028199474327266216, 0.015147119975154055, 0.022101386020949576, 0.008520293195033446, 0.013655743605340831, 0.04458377581613604, 0.046330023324117064, 0.007636239461135119, 0.02454809105984168, 0.11062944569857791, 0.17657777178101242, 0.13887986104236916, 0.11544862616574392, 0.1869624067330733, 0.11378954019164667, 0.1323170046089217, 0.14844890538370237, 0.13022702769376338, 0.11429831953137182, 0.18223609862616286, 0.16016640787711367, 0.1596076152054593, 0.1402094482909888, 0.2710818772902712, 0.06857545464299619, 0.1548098976491019, 0.1436516034300439, 0.1436891857883893, 0.12415810764650814, 1.313409497961402, 64.91251721978188, 91.54613927006721, 84.89784121513367, 79.26528945565224, 65.8971431851387, 38.09708632528782, 49.70940001308918, 41.352523639798164, 40.384274795651436, 60.010673850774765, 4.13560688495636, 0.1717899099458009, 0.2304341521812603, 0.8837954665068537, 1.8313854723237455, 4.81295901350677, 8.297451362013817, 7.401478914543986, 3.668129607103765, 26.02934617549181, 74.7343897819519, 72.78476759791374, 68.73761996626854, 70.87857708334923, 64.70624148845673, 67.18181625008583, 63.58864165842533, 62.5531630218029, 59.860471710562706, 58.7855663895607, 61.05519600212574, 64.15324196219444, 54.42930914461613, 56.85914196074009, 65.951769053936, 68.168456107378, 66.05782896280289, 62.845477536320686, 63.282176703214645, 60.90270638465881, 61.51008479297161, 65.02957373857498, 59.121031388640404, 53.8720690459013, 48.32609564065933, 49.025489911437035, 48.57137247920036, 58.14360983669758, 67.25274324417114, 65.30496016144753, 60.0757871568203, 66.82905077934265, 67.27652236819267, 58.814083859324455, 54.94654878973961, 58.7630145996809, 60.60705944895744, 64.2957267165184, 57.05368012189865, 62.10469588637352, 64.41353559494019, 64.32022020220757, 58.38495008647442, 58.39042939245701, 59.32367831468582, 68.25558543205261, 49.309688061475754, 39.93042714893818, 62.84346744418144, 61.406190767884254, 66.70357391238213, 60.294974595308304, 59.03349548578262, 52.61292681097984, 57.18936704099178, 60.22303305566311, 66.10756069421768, 55.30945971608162, 50.1917727291584, 52.3224475979805, 53.52037891745567, 53.96527424454689, 58.306894674897194, 64.39154997467995, 66.25851899385452, 56.465167701244354, 52.32276298105717, 50.50779037177563, 50.61639614403248, 64.23740744590759, 63.73137719929218, 63.109342977404594, 58.90585273504257, 55.0788538902998, 60.176029577851295, 63.42032589018345, 66.68664962053299, 68.03309977054596, 66.65136471390724, 61.52847200632095, 54.65712212026119, 52.05983608961105, 56.44440941512585, 58.438531011343, 54.92457456886768, 60.2043304592371, 62.42005996406078, 72.45436772704124, 70.63334584236145, 69.56089898943901, 72.37257331609726, 18.158304132521152, 1.449413225054741, 8.076520767062902, 10.80590670928359, 3.203249964863062, 2.6847048522904515, 0.5671281774993986, 0.6758667645044625, 0.17513885133666918, 12.127799727022648, 44.084352850914, 50.74420228600502, 41.382770016789436, 30.709678530693054, 23.58659215271473, 43.06226089596748, 58.307814225554466, 68.0926501750946, 71.12634658813477, 87.03768119215965, 30.860754624009132, 1.2368711549788713, 0.3154150483896956, 0.2746296994155273, 0.2150366362184286, 0.21050949086202309, 0.15635153133189306, 0.13072886795271188, 0.15380663273390383, 0.26004605228081346, 0.10925898095592856, 0.14285642188042402, 0.22267857537372038, 0.16733365453546867, 0.13120028015691787, 0.09770651726284996, 0.10779909483972006, 0.1383466279366985, 0.2463624521624297, 0.10817476257216185, 0.16448365902760997, 0.1021574811602477, 0.07197647995781153, 0.2062398410635069], [0.030769028926442843, 0.0676853524055332, 0.017981026649067644, 0.022821098573331255, 0.041731175369932316, 0.014062051832297584, 0.02490031434717821, 0.037032207983429544, 0.04801557428436354, 0.01777189871063456, 0.047317020362243056, 0.026267404173268005, 0.06146941290353425, 0.061025367394904606, 0.07939780087326653, 0.018941523449029773, 0.03190749645000324, 0.01722797125694342, 0.038983625927357934, 0.14328716439194977, 6.212486615404487, 68.21764066815376, 65.32110169529915, 67.17025727033615, 47.21038430929184, 31.86157152056694, 15.317869149148464, 46.80706635117531, 47.9316958039999, 62.75960214436054, 22.632788233458996, 0.14492940361378714, 0.026393739972263575, 0.12197890973766334, 0.29195659153629094, 0.653348044725135, 1.558998276013881, 2.840310540050268, 1.4884041203185916, 7.941184379160404, 63.10974955558777, 67.61688530445099, 68.45952048897743, 62.650468200445175, 62.20903068780899, 55.553729608654976, 58.49599152803421, 52.73119166493416, 54.76899191737175, 47.67447240650654, 50.2005198597908, 49.87087234854698, 49.64291878044605, 46.57093562185764, 51.436825320124626, 60.26308670639992, 61.680296659469604, 60.08461408317089, 60.932181403040886, 58.19493368268013, 55.11766120791435, 61.31012812256813, 59.517429918050766, 56.9676261395216, 53.8406827300787, 51.139187291264534, 43.879125863313675, 42.81347684562206, 51.28805190324783, 58.831756711006165, 59.732118397951126, 57.15929925441742, 59.2000063508749, 57.54754342138767, 52.96793036162853, 46.16827502846718, 52.1373101323843, 57.797186225652695, 59.94103118777275, 55.67724198102951, 56.446518301963806, 54.22492191195488, 57.869766131043434, 51.611072570085526, 51.34147323668003, 48.9340478181839, 62.984565272927284, 41.71678349375725, 32.83407233655453, 54.08097803592682, 52.781318575143814, 60.5902149528265, 57.68744431436062, 58.62980894744396, 49.53164555132389, 51.007250770926476, 51.58453859388828, 57.11750149726868, 57.60823376476765, 54.4197678565979, 51.25241361558437, 49.44988153874874, 49.792661145329475, 61.43755428493023, 56.91990070044994, 55.12688711285591, 46.7562934756279, 42.87037879228592, 42.60094664990902, 45.67362517118454, 53.88284906744957, 59.98992316424847, 58.17764461040497, 57.19605468213558, 54.804626405239105, 59.253990054130554, 60.19664727151394, 61.111315190792084, 59.13186080753803, 56.991298869252205, 53.62445153295994, 48.15875642001629, 48.01286704838276, 54.139654487371445, 50.839132592082024, 53.4710917621851, 53.7220910936594, 54.36320409178734, 56.33633181452751, 63.72899852693081, 65.98489567637444, 64.74044725298882, 64.49395447969437, 16.446053311228752, 0.19297825579997152, 2.6516668125987053, 3.2400148920714855, 3.8757160305976868, 0.35424869740381837, 0.03545571933500469, 0.11484433242003433, 0.06914425888680853, 20.622927881777287, 32.70351134240627, 45.71806378662586, 47.0499075204134, 23.40425133705139, 14.935307577252388, 30.411303341388702, 50.791156366467476, 54.33857761323452, 56.90923847258091, 58.6787199229002, 5.042170789092779, 0.20061728573637083, 0.07994163184775971, 0.04518867812294047, 0.04644995067792479, 0.01206231636388111, 0.012812501499865903, 0.09384444754687138, 0.00445962893536489, 0.055507722063339315, 0.021209853293839842, 0.040812277802615426, 0.016379045227949973, 0.055784750948078, 0.042049200492328964, 0.02291487078764476, 0.039426246512448415, 0.02609127026516944, 0.05277344222122338, 0.01419913578502019, 0.00544062199878681, 0.049297010991722345, 0.013642523172165966, 0.015961260614858475, 0.05062390795501415, 0.12420210216077976, 0.09924672602210194, 0.048305780001101084, 0.061584234281326644, 0.029525059544539545, 0.1236922170210164, 0.07716922045801766, 0.03934334861696698, 0.0678638686076738, 0.027840215479955077, 0.030640067780041136, 0.07413742845528759, 0.03339683098602109, 0.0642887206049636, 0.07476621307432652, 0.05634793713397812, 0.054758768892497756, 0.13779053668258712, 8.594166990369558, 83.42681854963303, 74.75747734308243, 73.9898881316185, 60.69150231778622, 47.15990021824837, 19.674907252192497, 38.56555558741093, 41.61902993917465, 51.09414450824261, 26.234244480729103, 0.09499943713308312, 0.08727911234018393, 0.4311659513041377, 0.9451247099786997, 1.5591173758730292, 3.5496816504746675, 2.8017098363488913, 0.41075024055317044, 10.274644866585732, 64.36556696891785, 70.57400822639465, 71.33351907134056, 65.20270764827728, 66.61215841770172, 58.36061239242554, 60.6979163736105, 56.40519551932812, 57.071888744831085, 50.22674985229969, 52.579545602202415, 53.05127128958702, 50.09770877659321, 47.45530016720295, 53.73828582465649, 62.60562300682068, 63.41873377561569, 63.32437723875046, 61.68032705783844, 57.954053208231926, 56.34311445057392, 62.643514573574066, 60.87736934423447, 61.20649628341198, 57.90577679872513, 52.07364074885845, 45.23193307220936, 45.17562009394169, 53.4421107172966, 60.626149624586105, 62.0805823802948, 57.89668008685112, 59.34853658080101, 60.533468797802925, 54.33217495679855, 48.51547367870808, 55.217307060956955, 58.9689901471138, 62.56051942706108, 56.75467036664486, 59.322925955057144, 56.81631065905094, 61.21255695819855, 53.70635613799095, 52.80524589121342, 52.541437447071075, 67.26170316338539, 45.78192695975304, 36.12007901072502, 54.723831340670586, 52.780152037739754, 63.21871630847454, 59.798455238342285, 60.322416722774506, 50.68753592669964, 53.568187952041626, 54.5171794295311, 58.480868339538574, 61.18608757853508, 56.485732197761536, 50.75383476912975, 49.937205389142036, 49.47063222527504, 64.64315727353096, 59.73006270825863, 57.2881693392992, 48.10083992779255, 45.40016144514084, 44.773825854063034, 48.54613043367863, 58.01333002746105, 63.34518112242222, 58.75490963459015, 57.948049530386925, 54.44580785930157, 60.20998075604439, 63.40790435671806, 61.73554189503193, 60.28406158089638, 60.09154871106148, 56.705178022384644, 50.88960908353329, 50.61985395848751, 55.65185934305191, 54.687402695417404, 55.36743700504303, 57.037397995591164, 57.532066851854324, 60.62603563070297, 66.71647042036057, 68.07342320680618, 65.12778326869011, 68.63797411322594, 19.402376376092434, 0.5834940180648118, 1.3126521511003375, 5.352643579244614, 7.90660148486495, 1.0606406489387155, 0.14564327546395361, 0.1058672324870713, 0.10796495000249706, 23.026348315179348, 36.97047337889671, 39.53567013144493, 38.19436490535736, 17.53708116710186, 23.039275221526623, 41.81006468832493, 56.05157129466534, 61.10114313662052, 62.3348343372345, 68.03787991404533, 7.365475846454501, 0.2402915951097384, 0.01433784967957763, 0.0647252518683672, 0.029922338617325295, 0.010366150836489396, 0.037143719382584095, 0.0383998822508147, 0.016799080403870903, 0.024904750534915365, 0.09331058361567557, 0.041912285378202796, 0.013635737159347627, 0.0025952549412977532, 0.042391742463223636, 0.025560770118318032, 0.02554122565925354, 0.08645791851449758, 0.017298321290581953, 0.07976301916642115, 0.06263223214773461, 0.03232836097595282, 0.02715373815590283, 0.1204397993569728, 0.19521235779393464, 0.24418461980530992, 0.17339689715299755, 0.19398932810872793, 0.21750862622866407, 0.08989784721052274, 0.21052710944786668, 0.16325273289112374, 0.09811662064748816, 0.15554156620055437, 0.11096881498815492, 0.1823674884508364, 0.17760377610102296, 0.16189138172194362, 0.14159478567307815, 0.11380283947801217, 0.20084459072677419, 0.15702353121014312, 0.31331978738307953, 12.326180431991816, 97.57189393043518, 83.51953357458115, 87.55599617958069, 63.58369432389736, 47.91811913251877, 23.40479090809822, 62.49545931816101, 61.14047482609749, 82.07710817456245, 35.869258269667625, 0.2594341663643718, 0.2613820368424058, 0.5978714372031391, 1.748648474458605, 2.2767278691753745, 5.084117213264108, 7.534234765917063, 5.4037935845553875, 9.984023161232471, 67.62373253703117, 70.4816959798336, 74.46132883429527, 66.36207863688469, 68.62512320280075, 60.01309432089329, 64.10661086440086, 58.896208852529526, 62.5039404630661, 53.14674876630306, 55.470996648073196, 54.29501295089722, 52.54235699772835, 51.040289998054504, 55.531459003686905, 66.6398361325264, 65.93184292316437, 65.2350515127182, 64.83318507671356, 57.656278386712074, 57.238513603806496, 66.1567984521389, 64.40811708569527, 64.94201123714447, 60.30838027596474, 56.049804389476776, 47.68835686147213, 46.94925472140312, 54.692547619342804, 64.3841403722763, 63.74107427895069, 61.022228971123695, 62.16459967195988, 63.9273364841938, 59.07751612365246, 51.569457203149796, 57.59966142475605, 61.8714340031147, 64.94879767298698, 57.51698926091194, 61.73372559249401, 60.66883273422718, 63.85842338204384, 58.36581811308861, 56.353278905153275, 57.40554504096508, 68.27767744660378, 50.8325969427824, 39.30878050625324, 54.32641826570034, 54.729481637477875, 64.89090397953987, 62.20327399671078, 63.4490979462862, 54.14871700108051, 56.0702358931303, 58.224127516150475, 60.947255194187164, 63.08518387377262, 58.191996440291405, 51.274889409542084, 49.754929170012474, 50.537854358553886, 66.80417731404305, 64.21811208128929, 60.19178353250027, 50.516955479979515, 47.72680699825287, 47.850509360432625, 50.86142599582672, 61.30246013402939, 66.35547459125519, 60.65492548048496, 59.34310667216778, 55.081810131669044, 62.4526622146368, 64.36136439442635, 65.70553466677666, 65.02173095941544, 63.02829332649708, 61.218351647257805, 54.07998248934746, 52.99784615635872, 57.525455206632614, 57.92978011071682, 58.847681656479836, 61.19149848818779, 60.49740493297577, 64.04197633266449, 69.60165560245514, 71.3328655064106, 68.18917259573936, 69.82537239789963, 22.142036966979504, 0.9427066147327423, 8.29642066732049, 9.228617046028376, 8.345991857349873, 1.0454615321941674, 0.18007619655691087, 0.44891850964631885, 0.3311349533032626, 31.106367744505405, 48.23854833841324, 60.82282707095146, 64.1817632317543, 35.53682930767536, 26.906650699675083, 42.887698262929916, 64.7207111120224, 69.59911733865738, 70.53259804844856, 80.44930592179298, 8.820737432688475, 0.3997504245489836, 0.18046949029667303, 0.2034126888611354, 0.1078319274529349, 0.104270880256081, 0.14054731844225898, 0.30756463995203376, 0.13963781646452844, 0.11799192172475159, 0.14723368309205398, 0.11592552284128033, 0.11981724135694094, 0.1670692570041865, 0.20247437671059743, 0.08398690071771853, 0.17494394851382822, 0.1479630361427553, 0.05735689432185609, 0.13234373676823452, 0.10689807560993358, 0.127506522112526, 0.13950148393632844], [0.027759328804677352, 0.04410579560499173, 0.0359702391870087, 0.03754821213078685, 0.027592378974077292, 0.033388051379006356, 0.08334063852089457, 0.02842498888639966, 0.043915341957472265, 0.061021578731015325, 0.06412351853214204, 0.030848579735902604, 0.016499878001923207, 0.02398548931523692, 0.0497970478318166, 0.062182030524127185, 0.036935524694854394, 0.09029007225763053, 0.049289541275356896, 0.04675604577641934, 28.867968656122684, 71.98700800538063, 67.34457671642303, 61.43731489777565, 31.35819923132658, 20.93141432851553, 30.278517566621304, 56.86012610793114, 56.28328666090965, 47.28046394884586, 3.0877653742209077, 0.1116961197112687, 0.07533180381869897, 0.3508041228633374, 0.5019493249710649, 0.8784981945063919, 2.953788600862026, 1.3465269771404564, 2.246607360430062, 49.37771201133728, 72.03009769320488, 65.74027240276337, 66.82866320014, 63.75599607825279, 57.24976859986782, 53.648211658000946, 50.949816852808, 48.3453606069088, 48.96137975156307, 47.58469082415104, 46.82346627116203, 47.02977240085602, 47.71940879523754, 45.45821852982044, 48.025254383683205, 57.334333062171936, 58.66396151483059, 59.27197068929672, 60.70204295217991, 57.28538028895855, 58.07200267910957, 56.452537178993225, 59.36655521392822, 60.93575321137905, 57.08735391497612, 58.087027072906494, 47.507794350385666, 42.121606171131134, 45.29243342578411, 55.397292003035545, 59.8347394913435, 58.82778212428093, 58.49751524627209, 55.113599225878716, 51.833539232611656, 43.30739714205265, 50.618322640657425, 56.10656954348087, 60.39884962141514, 54.78087767958641, 53.403972163796425, 55.17079375684261, 56.40539310872555, 49.91772763431072, 49.27936188876629, 50.642211958765984, 61.74373805522919, 43.176775351166725, 33.02777074277401, 55.69800026714802, 50.61578817665577, 57.58584916591644, 57.58377067744732, 57.9845579713583, 52.61578805744648, 53.083816543221474, 54.52422805130482, 59.34716485440731, 55.35362854599953, 56.53469257056713, 56.17257200181484, 52.73756392300129, 54.17551316320896, 60.440795570611954, 56.50642968714237, 52.02722243964672, 43.213982954621315, 43.591701686382294, 43.79276029765606, 44.16763678193092, 54.113124310970306, 61.80736184120178, 58.78519020974636, 57.46872425079346, 53.89867141842842, 61.69156685471535, 59.24998886883259, 59.207385554909706, 55.356843173503876, 53.304447904229164, 46.761168614029884, 48.60617481172085, 51.073143035173416, 52.511962428689, 58.15630875527859, 58.86844754219055, 57.2449466586113, 54.093794748187065, 53.09260547161102, 57.34034813940525, 62.85327851772308, 64.39804002642632, 65.7965549826622, 58.346857130527496, 12.438664846122265, 1.0162636614404619, 3.6560975527390838, 4.170563109219074, 0.835848095593974, 0.06900241962284781, 0.022566998341062572, 0.07117193992598914, 3.611147627234459, 33.27525146305561, 36.406750828027725, 32.143125012516975, 55.67807413637638, 32.98469625413418, 25.114492066204548, 38.10988783836365, 42.312678918242455, 51.46902099251747, 59.216372072696686, 25.66069945693016, 1.073510202113539, 0.10696542551158927, 0.03354724947712384, 0.05179069397854619, 0.02520575450034812, 0.01516334146799636, 0.04063764303282369, 0.024031741813814733, 0.010487529089004965, 0.05326390906702727, 0.044835456646978855, 0.07173876263550483, 0.01685251874732785, 0.08920596519601531, 0.04652857380278874, 0.048752831207821146, 0.047364161582663655, 0.044395556033123285, 0.025984551284636836, 0.06394117284798995, 0.02847491872671526, 0.044685847096843645, 0.03306644539406989, 0.021569062046182808, 0.049428556667407975, 0.05331073858542368, 0.031176800112007186, 0.06733155576512218, 0.06734464725013822, 0.043370175117161125, 0.06957556543056853, 0.035363140123081394, 0.060205446352483705, 0.12406240028212778, 0.01415502902091248, 0.029567046549345832, 0.033818229858297855, 0.0164967591263121, 0.08104985128738917, 0.1093727076658979, 0.02147505605535116, 0.020730054820887744, 38.66794869303703, 83.95319670438766, 72.5041526556015, 72.7343063056469, 37.15325117111206, 30.683501735329628, 30.1348814740777, 52.95851446688175, 48.50921541452408, 45.239863246679306, 4.0751806274056435, 0.11500592023367062, 0.0890203689050395, 0.7542744290549308, 1.0046548093669116, 3.9811370987445116, 3.2261784095317125, 1.090227048844099, 3.456144919618964, 50.83824723958969, 74.65810507535934, 68.0719792842865, 70.57364344596863, 68.18167939782143, 58.942703157663345, 57.079374343156815, 54.404447078704834, 51.30678489804268, 52.44519621133804, 50.90030550956726, 49.05853293836117, 49.34484377503395, 49.25757385790348, 47.91050814092159, 50.73563754558563, 59.05698202550411, 60.031888112425804, 60.62018394470215, 62.41652235388756, 57.30541281402111, 59.43025879561901, 58.66445168852806, 61.47991821169853, 62.775485292077065, 61.334279626607895, 60.02000235021114, 50.2579727768898, 44.47345197200775, 46.89722031354904, 57.28792995214462, 64.59135085344315, 60.22360302507877, 60.04332169890404, 58.85918743908405, 52.053722217679024, 46.91076658666134, 53.94502133131027, 60.187759548425674, 62.63759449124336, 55.270181223750114, 56.1176573485136, 59.07507665455341, 59.88317169249058, 52.79555641114712, 50.6745520234108, 52.11074955761433, 65.20227447152138, 46.11908666789532, 37.20386445522308, 55.420470759272575, 52.39720478653908, 56.830521896481514, 59.44578856229782, 61.979511603713036, 55.14073736965656, 56.495045498013496, 57.35322564840317, 60.959748923778534, 57.05595999956131, 57.81434990465641, 57.15750955045223, 53.85227590799332, 54.904150664806366, 60.54646410048008, 58.83156672120094, 53.67872402071953, 45.51585003733635, 44.40942160785198, 44.55832041800022, 46.080925315618515, 56.66916735470295, 63.67699831724167, 61.00387595593929, 57.04426422715187, 53.531124740839005, 62.295145466923714, 62.31024585664272, 60.738570392131805, 59.74106691777706, 54.12508226931095, 50.92655450105667, 51.3870669901371, 53.69163192808628, 55.723835080862045, 60.61737209558487, 60.07665351033211, 60.755547881126404, 57.405685633420944, 56.84965766966343, 58.493422865867615, 64.60919469594955, 68.10124531388283, 67.75467351078987, 63.101659789681435, 14.122167360037565, 0.40169292187783867, 3.224821169860661, 5.861702738329768, 2.077844641171396, 0.29371322540100664, 0.16504484141478315, 0.11981843621470034, 4.024852328002453, 37.45219253003597, 31.407457888126373, 26.404232159256935, 45.9030606597662, 34.8657701164484, 33.791404366493225, 49.10816207528114, 48.08395363390446, 57.308315858244896, 66.64757251739502, 32.86809951066971, 1.2566467188298702, 0.08368837923626415, 0.07207260292489082, 0.02852527530194493, 0.037833400929230265, 0.018340203860134352, 0.03645024917204864, 0.009158857465081383, 0.024932840824476443, 0.02176034318836173, 0.02031895510299364, 0.037402120360638946, 0.015069293731357902, 0.05020818280172534, 0.03108195920503931, 0.029646035181940533, 0.0048797615181683796, 0.026334648318879772, 0.059105357140651904, 0.06104462612711359, 0.0566264725785004, 0.048425117347505875, 0.14688313705846667, 0.1491383754182607, 0.171771697641816, 0.1777180371573195, 0.0847017670457717, 0.07841967992135324, 0.20503080828348175, 0.17914168420247734, 0.14198778255376965, 0.13372531888308004, 0.2526493335608393, 0.13996351539390162, 0.08228013175539672, 0.163079560152255, 0.13146254030289128, 0.22828683693660423, 0.1399069934268482, 0.403862664825283, 0.17160772753413767, 0.16578014648985118, 47.691191509366035, 94.46447387337685, 83.09654027223587, 78.40296372771263, 45.331871509552, 30.29316008090973, 44.89065818488598, 75.4421854019165, 66.79464742541313, 68.24574396014214, 5.80487203784287, 0.24776189035037532, 0.2440316037973389, 1.2848409684374928, 2.514780582860112, 5.562533866614103, 8.530459608882666, 7.442517662420869, 3.4390104515478015, 55.28840884566307, 74.73423779010773, 71.89108595252037, 72.67143487930298, 71.87688991427422, 61.69443570077419, 59.989562183618546, 57.23692528903484, 53.00232611596584, 53.32793444395065, 54.16710801422596, 51.995858922600746, 50.831012427806854, 51.94664016366005, 50.425106808543205, 52.54807569086552, 62.4138130992651, 61.91660597920418, 64.48714524507523, 63.415838330984116, 58.62917058169842, 59.58343617618084, 59.80462230741978, 63.787511587142944, 67.12540447711945, 62.551175728440285, 63.09748001396656, 53.47890794277191, 46.42655096948147, 48.53079445660114, 61.962412521243095, 66.52314439415932, 63.5028612613678, 62.90134213864803, 59.11106452345848, 56.169247180223465, 49.981640204787254, 56.14354155957699, 63.45103584229946, 64.13285225629807, 59.364438727498055, 58.416917771101, 61.875845566391945, 62.71724581718445, 54.37431089580059, 53.13287191092968, 56.40472054481506, 67.71194100379944, 48.3355837315321, 40.48580154776573, 55.15404425561428, 53.201614022254944, 56.982851922512054, 62.29172185063362, 63.310602977871895, 56.46641403436661, 58.5415168851614, 58.74494656920433, 63.903276175260544, 58.40863421559334, 59.240983352065086, 58.78429725766182, 53.05906467139721, 55.9505233168602, 64.7918888926506, 62.17937707901001, 55.77468775212765, 47.89779022336006, 47.19377540051937, 47.19023399055004, 48.52859437465668, 57.54408560693264, 68.38456571102142, 64.08483803272247, 56.63229413330555, 53.78898650407791, 64.93786945939064, 65.29042974114418, 62.73437909781933, 62.18594692647457, 58.02330069243908, 53.038412779569626, 53.79829220473766, 57.52246476709843, 57.78802111744881, 63.579100370407104, 63.13983254134655, 62.8782469779253, 60.04928357899189, 60.10234393179417, 62.28856422007084, 68.69516104459763, 71.3980396091938, 70.44655546545982, 64.26567032933235, 15.667322147637606, 5.032268995419145, 11.007690131664276, 8.935519773513079, 3.160223448649049, 0.2756621752632782, 0.2711034589447081, 0.1261320646153763, 5.9426630940288305, 54.24891762435436, 48.629342168569565, 40.541464760899544, 64.15549904108047, 43.68033953011036, 39.93553027510643, 53.06979909539223, 58.29578027129173, 65.76642259955406, 76.61872386932373, 40.52349932491779, 1.4388552540913224, 0.37422698631417006, 0.19563894427847117, 0.14642446010839194, 0.08727328648092225, 0.1666932849911973, 0.10893672559177503, 0.08899736232706346, 0.11529467505170032, 0.10890102086705156, 0.15589787130011246, 0.21443116245791316, 0.11738664092263207, 0.17862540174974129, 0.0755451267468743, 0.09877983349724673, 0.19484630087390542, 0.1034355782030616, 0.1122943649534136, 0.261671029147692, 0.08896233295672573, 0.08716151904081926], [0.028112036343372893, 0.08397590208915062, 0.014138108053884935, 0.03774358621740248, 0.06666066168691032, 0.06050526659237221, 0.056362160394201055, 0.019185623241355643, 0.03228172812669072, 0.09061512551852502, 0.0657937144569587, 0.05329681960574817, 0.01882350341475103, 0.06655342876911163, 0.04648119880585, 0.04918364422337618, 0.03080518450587988, 0.08048879506532103, 0.08886552721378393, 1.0405514831654727, 50.664638355374336, 75.02128958702087, 59.68558989465237, 52.9031628370285, 39.51407968997955, 22.958968430757523, 39.10751670598984, 31.402803137898445, 65.40982693433762, 29.942892976105213, 0.21422146121039987, 0.0725218397565186, 0.07891150860814378, 0.3688907070318237, 0.7701024797279388, 1.6405787109397352, 1.9692014646716416, 0.8000765182077885, 30.26757225394249, 75.21077021956444, 65.36140993237495, 69.52390417456627, 64.38126012682915, 63.414310812950134, 52.83277541399002, 50.667355209589005, 46.641064658761024, 49.16135162115097, 47.068830505013466, 47.9949814081192, 46.72239929437637, 46.947833597660065, 45.33854395151138, 45.84631830453873, 45.11030539870262, 46.35764166712761, 56.192520931363106, 59.341696947813034, 60.65495207905769, 57.27413289248943, 55.38341514766216, 56.55972182750702, 52.54703834652901, 56.950720846652985, 61.25528186559677, 58.74355964362621, 50.297627449035645, 43.851729333400726, 43.85071858763695, 45.46957992017269, 56.92482903599739, 58.554348796606064, 60.952419117093086, 53.0678915977478, 47.05153003334999, 41.693080365657806, 49.17259141802788, 56.14513747394085, 59.89075228571892, 53.66045840084553, 53.98015804588795, 54.935825765132904, 57.85163730382919, 48.147999197244644, 48.729740381240845, 52.39335939288139, 62.079146057367325, 44.22550767660141, 37.086215168237686, 58.312974348664284, 56.875294893980026, 58.23944069445133, 55.5847055464983, 57.30771169066429, 57.39068403840065, 59.097415655851364, 57.23029084503651, 57.05432988703251, 57.28159949183464, 56.26235358417034, 58.07386077940464, 55.18609933555126, 51.90163917839527, 60.904492288827896, 56.640874072909355, 51.00156627595425, 42.638526633381844, 42.25791625678539, 42.94787183403969, 42.51775771379471, 48.647907972335815, 59.286740496754646, 59.10957120358944, 57.99775466322899, 51.99502296745777, 59.75509196519852, 58.38169366121292, 58.30500237643719, 54.416857212781906, 50.929430946707726, 46.718584299087524, 47.40108087658882, 53.12035158276558, 57.020625695586205, 59.02848735451698, 63.08736875653267, 61.275872960686684, 58.54527488350868, 55.00560142099857, 53.375485092401505, 58.73509369790554, 59.1843967884779, 65.41352033615112, 64.19443175196648, 46.67826846241951, 2.348076165653765, 4.114193134009838, 4.549196166917682, 2.084737946279347, 0.22829114139312878, 0.12928721640491858, 0.08330424359883182, 0.09484262875048444, 12.941510863602161, 39.007141292095184, 84.03926968574524, 107.12093353271484, 84.29754942655563, 23.080945685505867, 18.149775490164757, 35.57018771767616, 51.173822432756424, 53.82573053240776, 47.27418668568134, 4.520973656326532, 0.4246274521574378, 0.04800232323759701, 0.05666654484230094, 0.09038131189299747, 0.045900267869001254, 0.06512607098557055, 0.02986955521919299, 0.041798937163548544, 0.1267206619377248, 0.02452598619129276, 0.032768358069006354, 0.053200807960820384, 0.0586983522225637, 0.028382226337271277, 0.1351581685594283, 0.08530379724106751, 0.02405982097116066, 0.04345721419667825, 0.015544821144430898, 0.04464356694370508, 0.05358245369279757, 0.013972606338938931, 0.020170501447864808, 0.02605999616207555, 0.010353974976169411, 0.04261988236976322, 0.0919646913826, 0.042481193522689864, 0.04821149013878312, 0.05650854160194285, 0.0813982005638536, 0.03277919713582378, 0.05532465278520249, 0.019669215944304597, 0.006604272912227316, 0.04030680844152812, 0.07441396752255969, 0.06793476597522385, 0.05447278970677871, 0.1044504132005386, 2.3707713978365064, 64.54014480113983, 81.04281887412071, 67.84179523587227, 61.66381314396858, 49.685693085193634, 26.96440950036049, 40.2994367480278, 42.30410657823086, 64.16553810238838, 32.28599734604359, 0.37185686349403113, 0.14565440767910331, 0.33915943989995867, 1.761033316142857, 2.3178749112412333, 3.7104690726846457, 0.8700362860690802, 1.105365555267781, 32.3983421176672, 77.55859583616257, 69.78562653064728, 71.63452371954918, 67.38926991820335, 66.46674782037735, 54.013763442635536, 52.67912305891514, 49.988844618201256, 51.01423479616642, 49.446480721235275, 50.8712712675333, 47.819784209132195, 49.98424306511879, 47.995995953679085, 46.68125510215759, 47.36079163849354, 49.2843472212553, 58.09642016887665, 62.1003907173872, 61.55162036418915, 57.08902582526207, 57.143423706293106, 56.18216268718243, 54.50221583247185, 59.5527908205986, 61.673137843608856, 60.27754493057728, 52.81148515641689, 43.81068013608456, 45.542695596814156, 48.21444243192673, 59.27621126174927, 61.3317109644413, 64.07511815428734, 55.73530286550522, 48.49007964134216, 44.07014541327953, 52.418194860219955, 57.72711418569088, 61.96692667901516, 56.05853632092476, 55.650164633989334, 58.858245089650154, 60.56102491915226, 49.93540808558464, 50.8448588848114, 55.205911472439766, 64.11837503314018, 47.05396570265293, 41.932087540626526, 59.472641721367836, 57.78682418167591, 58.72062787413597, 55.62000185251236, 59.71166789531708, 58.75373549759388, 60.37828892469406, 59.09567154943943, 58.12557980418205, 57.94058673083782, 58.90779823064804, 59.42941144108772, 55.79963721334934, 52.01723277568817, 63.445533737540245, 59.84436817467213, 53.12615007162094, 44.469826966524124, 43.36886264383793, 45.588931515812874, 44.93332229554653, 51.158026680350304, 61.22772954404354, 60.70830121636391, 57.02217601239681, 52.41827465593815, 62.2964183986187, 61.15604639053345, 60.3051732480526, 56.21085114777088, 53.36086727678776, 49.005810767412186, 50.83450824022293, 55.06072886288166, 59.803497567772865, 61.63318678736687, 63.75920310616493, 63.21129150688648, 62.372030541300774, 57.23097860813141, 56.772434413433075, 60.78535348176956, 63.687972128391266, 67.83517599105835, 68.50354492664337, 50.83597116172314, 3.8809146266430616, 1.7758368467912078, 4.19765280559659, 2.2673901077359915, 1.1581630096770823, 0.3326605714391917, 0.134219930623658, 0.0419474075170001, 17.709230929613113, 39.3045399338007, 78.30627411603928, 101.28963723778725, 81.97924822568893, 32.63951897621155, 24.55184105783701, 42.084725350141525, 56.94034740328789, 62.45759814977646, 58.26662823557854, 6.404913514852524, 0.3436452179448679, 0.06526504555949941, 0.10450856047100388, 0.031716779340058565, 0.10401092076790519, 0.020639416325138882, 0.026700634734879714, 0.08020021836273372, 0.05035454916651361, 0.0303302953398088, 0.0030077735527811456, 0.042110104841412976, 0.05319732357747853, 0.03445308895607013, 0.05381657902034931, 0.05001202574931085, 0.06989998044446111, 0.02561375018558465, 0.008672707135701785, 0.10500884964130819, 0.053529289943980984, 0.12217116309329867, 0.22530349233420566, 0.114668191090459, 0.08220026924391277, 0.22292738780379295, 0.19529213866917416, 0.12416745128575712, 0.12445877393474802, 0.11875041891471483, 0.29641265398822725, 0.1501709848525934, 0.13927646476076916, 0.17288380593527108, 0.19104568840702996, 0.16736047575250268, 0.15293457952793688, 0.18517277698265389, 0.24728926102397963, 0.31135232420638204, 3.2488973904401064, 76.91854298114777, 88.38305979967117, 79.62574571371078, 68.96385222673416, 54.99288730323315, 31.849792152643204, 50.5887184292078, 42.14201867580414, 82.43031442165375, 46.35725408792496, 0.5778775631915778, 0.3070336184464395, 0.45457667321898043, 2.059733150526881, 2.782333013601601, 6.636208053678274, 10.140870194882154, 3.3511470537632704, 35.30510254204273, 78.61393600702286, 72.3564925789833, 73.46514388918877, 70.55643796920776, 67.99210757017136, 57.04345107078552, 56.3353780657053, 52.42225684225559, 53.816489428281784, 52.43570052087307, 53.27914506196976, 50.88997006416321, 52.4876893311739, 50.96802167594433, 49.039005786180496, 50.46208642423153, 51.664075925946236, 62.39137530326843, 64.75548684597015, 64.55342128872871, 59.15814399719238, 56.78189970552921, 58.09040129184723, 54.40693974494934, 60.55194340646267, 68.02273392677307, 62.61688560247421, 56.08520708978176, 47.29537054896355, 47.231062799692154, 50.324640199542046, 61.17618151009083, 63.928050845861435, 66.28776982426643, 58.88159483671188, 50.75340539216995, 45.84214232861996, 54.03397835791111, 61.56664855778217, 65.12101203203201, 57.47476972639561, 57.929742112755775, 62.56375305354595, 65.33297225832939, 51.87879480421543, 53.84228244423866, 57.83641532063484, 65.64884930849075, 52.26514287292957, 43.91222968697548, 60.99105924367905, 61.583629846572876, 61.59628316760063, 58.46094220876694, 61.80923134088516, 61.680091470479965, 62.99044355750084, 61.024501249194145, 61.093668937683105, 59.71293702721596, 60.46959042549133, 62.35048949718475, 57.727779150009155, 53.689371049404144, 65.02215653657913, 62.30818256735802, 55.60781970620155, 47.82910890877247, 45.526352673769, 47.19681903719902, 46.77552044391632, 54.086472541093826, 64.29098457098007, 64.60319101810455, 59.764428064227104, 52.662175968289375, 63.37806835770607, 63.075198009610176, 63.74127186834812, 58.01640406250954, 55.398492738604546, 51.37599058449268, 53.15473213791847, 58.1621490418911, 62.57231779396534, 64.75026592612267, 66.20345994830132, 65.2997924387455, 64.36910077929497, 61.59190960228443, 60.374451130628586, 64.65878203511238, 63.263911083340645, 70.96538722515106, 68.33063140511513, 54.29969809949398, 2.836544942110777, 8.900772538036108, 12.979885954409838, 5.343024395406246, 1.11805010586977, 0.25245340657420456, 0.36739427014254034, 0.3232923522591591, 24.233991913497448, 53.50159652531147, 90.27920365333557, 104.39026325941086, 90.58900102972984, 32.93290123343468, 27.88046434521675, 50.2655191719532, 65.2541720867157, 69.9684727191925, 66.70248717069626, 8.471785057336092, 0.5773949297145009, 0.2731820067856461, 0.1751484101987444, 0.23642086453037336, 0.17429456929676235, 0.19773278036154807, 0.1590529637178406, 0.24871682660887018, 0.19683794322190806, 0.09541956693283282, 0.13695139030460268, 0.14550188148859888, 0.28683316020760685, 0.16651242360239848, 0.17768143443390727, 0.16514053393620998, 0.10923011883278377, 0.23551909573143348, 0.10644802241586149, 0.18135104299290106, 0.1385496201692149], [0.03270842964411713, 0.06084420543629676, 0.03999787833890878, 0.03841017583908979, 0.028401811614457984, 0.04737377239507623, 0.09342001329059713, 0.05601878721790854, 0.019967672487837262, 0.05797013465780765, 0.059667841996997595, 0.04352893534814939, 0.029585826596303377, 0.033469264599261805, 0.07502801308874041, 0.07279253812157549, 0.10719160985900089, 0.1058885469683446, 0.11552993586519733, 15.308399107307196, 76.96189105510712, 70.48201516270638, 62.598707377910614, 41.71945095062256, 24.66349046677351, 27.61476170271635, 42.23316818475723, 34.854632914066315, 41.78171060979366, 7.297984343022108, 0.06821874878369272, 0.12346612173132598, 0.3396817040629685, 0.8012943528592587, 0.5116860650014132, 3.014329089783132, 2.0184901636093855, 11.043244823813438, 76.14450171589851, 68.22460189461708, 69.54319193959236, 63.50978069007397, 63.91751781105995, 55.235443487763405, 51.49767525494099, 49.86958421766758, 52.91699409484863, 50.701142996549606, 49.84699822962284, 47.09789514541626, 46.312275901436806, 48.64322282373905, 47.85756938159466, 42.696503922343254, 44.297354221343994, 44.71258834004402, 55.07329858839512, 59.414527639746666, 62.00721971690655, 60.566758811473846, 60.148211270570755, 57.915481477975845, 55.743214040994644, 50.54603911936283, 59.59016941487789, 54.27062205970287, 51.67020499706268, 41.56301714479923, 43.918400555849075, 40.95248110592365, 49.58008535206318, 53.017316311597824, 55.95473349094391, 48.19468729197979, 44.92717422544956, 41.357660964131355, 50.667347609996796, 55.15332989394665, 60.53492411971092, 52.05179192125797, 53.78994405269623, 55.931972712278366, 55.47558680176735, 44.64145615696907, 45.67994423210621, 51.540096178650856, 62.49286785721779, 40.503614991903305, 38.960381001234055, 62.435103356838226, 54.452005326747894, 60.76801501214504, 56.79011486470699, 57.118614837527275, 52.527271807193756, 55.53824923932552, 55.78405424952507, 58.21499660611153, 57.77468383312225, 58.840408846735954, 56.17601841688156, 59.37197372317314, 53.454429656267166, 56.076995730400085, 59.06852200627327, 54.219370409846306, 44.98733639717102, 42.78734564781189, 42.94233173131943, 42.120492830872536, 43.150355368852615, 55.14610268175602, 57.041976749897, 59.98971797525883, 52.75981552898884, 57.835928946733475, 59.73387770354748, 56.146729588508606, 52.05079637467861, 47.94240362942219, 47.036072462797165, 47.97253601253033, 52.23136268556118, 56.54410466551781, 62.90418058633804, 69.70091387629509, 60.96399329602718, 61.248837411403656, 58.89447994530201, 56.69283248484135, 57.228463143110275, 60.74106305837631, 62.12117180228233, 69.37721684575081, 62.86523647606373, 23.816935792565346, 0.535660641035065, 4.8589759692549706, 5.920192524790764, 0.40877989784348756, 0.5521778797265142, 0.042205648933304474, 0.03698836560943164, 3.688955339603126, 21.823553256690502, 39.793186113238335, 67.01003506779671, 57.901186645030975, 34.873935878276825, 30.15537567436695, 28.992829956114292, 48.121210634708405, 54.24533821642399, 58.24980653822422, 15.761586539447308, 0.5811146332416683, 0.10349670890718699, 0.017527906529721804, 0.052181063656462356, 0.0858585600508377, 0.10513453235034831, 0.04366376502730418, 0.10545681740040891, 0.0361123048060108, 0.03266903273470234, 0.10589549347059801, 0.012745965177600738, 0.04212686253595166, 0.06695758012938313, 0.021249448727758136, 0.035543266785680316, 0.041944394397432916, 0.1105148061469663, 0.03669343983347062, 0.0028946788279426983, 0.07379255985142663, 0.003954599296775996, 0.009919087569869589, 0.10166941516217776, 0.020245317355147563, 0.02302694436366437, 0.04313435027142987, 0.030740202055312693, 0.05010676832171157, 0.05660187038301956, 0.01825150608055992, 0.037988554322510026, 0.013630875164380996, 0.01032788848533528, 0.14303332020062953, 0.021724606922362, 0.1156871672719717, 0.16334547166479751, 0.14740390208316967, 0.142624307773076, 20.904758758842945, 88.43516260385513, 77.53043934702873, 70.70755586028099, 50.63917212188244, 32.636935114860535, 35.063370913267136, 44.88734856247902, 32.514053508639336, 50.175946578383446, 9.041891265660524, 0.05975479201879352, 0.0804834219161421, 0.6685384421143681, 1.490582947153598, 3.3338570315390825, 2.09841578733176, 0.5228609091136605, 12.888466659933329, 77.32672467827797, 69.9111869931221, 72.2295793890953, 65.46930134296417, 67.27111145853996, 58.305591344833374, 55.56570276618004, 52.57077567279339, 56.559410244226456, 53.917788192629814, 52.12559536099434, 49.12488877773285, 48.20170171558857, 48.72300714254379, 51.21501982212067, 45.28374329209328, 46.00764624774456, 47.766739055514336, 58.18927578628063, 61.63200505077839, 65.01581087708473, 62.1850311756134, 61.994836181402206, 60.98876416683197, 55.25425627827644, 51.91311456263065, 61.39246590435505, 57.0234527438879, 53.58139604330063, 42.733274549245834, 47.120066955685616, 42.26156786084175, 51.18009589612484, 53.34517791867256, 57.188158705830574, 51.3710318505764, 46.87499910593033, 44.57597807049751, 54.88995462656021, 58.88676255941391, 62.04968623816967, 53.53959068655968, 56.41467221081257, 57.69530989229679, 57.09751456975937, 46.66283369064331, 48.06571461260319, 54.128171503543854, 64.76111054420471, 42.107166945934296, 41.33050762116909, 64.93657752871513, 55.71807838976383, 63.2000707089901, 59.31768983602524, 58.6577108502388, 54.831148982048035, 56.0878137499094, 57.93530501425266, 60.64553618431091, 57.8608176112175, 60.83738029003143, 58.451533913612366, 61.929817870259285, 54.25084412097931, 56.91216051578522, 61.61325305700302, 56.280657202005386, 47.64666169881821, 45.62767803668976, 44.992245733737946, 44.35484893620014, 45.97421944141388, 56.43969386816025, 59.58256982266903, 62.94681429862976, 53.066504672169685, 58.671735897660255, 62.02643908560276, 59.7286681830883, 54.31271620094776, 49.918776378035545, 49.94355484843254, 51.08818642795086, 55.29282420873642, 60.08799210190773, 65.28343811631203, 71.55652910470963, 62.44820885360241, 63.695655316114426, 62.86948464810848, 59.52839232981205, 59.253921657800674, 64.50772494077682, 64.3920287489891, 72.03009009361267, 64.70722183585167, 28.466789983212948, 0.7624216075055301, 0.7404885313007981, 9.562793914228678, 2.725879205390811, 0.9300693240948021, 0.1361810410162434, 0.05769264193077106, 3.3579710125923157, 30.0474139675498, 46.103435307741165, 83.44358325004578, 65.84258571267128, 40.683102160692215, 40.311634093523026, 36.95628874003887, 53.81543688476086, 59.908371940255165, 66.6493584215641, 21.990155316889286, 0.5510639457497746, 0.031392980308737606, 0.030835048528388143, 0.016127613016578835, 0.06468984400271438, 0.07853132861782797, 0.011704208773153368, 0.0871349724184256, 0.02410678964224644, 0.08137167620589025, 0.020559666991175618, 0.010646254067978589, 0.03815767864580266, 0.03247083106543869, 0.010280004189553438, 0.08897630759747699, 0.0440733340656152, 0.12003381489193998, 0.06453497262555175, 0.029914917140558828, 0.07200454798294231, 0.1524764666100964, 0.1594169277814217, 0.09263075407943688, 0.1645795741933398, 0.10457363197929226, 0.1371374021982774, 0.12164304338512011, 0.1445278275059536, 0.12558007001644, 0.20868690975476056, 0.15476823347853497, 0.17555693280883133, 0.205279249639716, 0.27146960492245853, 0.19526938442140818, 0.2830019564135, 0.4984629526734352, 0.32377501542214304, 0.19889535469701514, 27.206585705280304, 99.31237533688545, 86.13251656293869, 81.40890643000603, 56.08783274888992, 37.28812113404274, 38.414202108979225, 57.274056896567345, 47.401563450694084, 60.910845547914505, 11.660276614129543, 0.2073504650616087, 0.2708388090832159, 0.88902986375615, 2.4680901132524014, 5.176616124808788, 11.195124574005604, 6.128875901922584, 13.604604732245207, 82.24752143025398, 73.33102628588676, 75.79429730772972, 68.55401381850243, 70.44821977615356, 62.673688754439354, 58.04682523012161, 55.12547358870506, 59.06132519245148, 55.63945300877094, 53.849958032369614, 52.32818529009819, 51.74252651631832, 51.853328570723534, 54.80095200240612, 48.23831655085087, 49.30011257529259, 49.79635454714298, 60.12420415878296, 63.92783045768738, 68.0206136405468, 65.51711037755013, 64.084093272686, 62.91425384581089, 55.58181390166283, 52.531026005744934, 64.06189486384392, 61.18769869208336, 56.56912252306938, 45.98071709275246, 49.480181112885475, 45.77523931860924, 53.361346051096916, 55.656229108572006, 61.047953590750694, 52.601291835308075, 50.46441189944744, 46.49258002638817, 58.04590567946434, 60.372425839304924, 64.67770501971245, 54.746956899762154, 59.906802624464035, 61.29191569983959, 59.209802225232124, 50.248226299881935, 50.35534255206585, 56.693421453237534, 67.18840509653091, 45.75148679316044, 44.830097034573555, 68.03940743207932, 59.18042980134487, 64.13851395249367, 61.8860100209713, 60.061602517962456, 55.15581116080284, 57.85390958189964, 58.77266228199005, 61.652770936489105, 61.8375626206398, 64.03594225645065, 61.212347969412804, 63.55355054140091, 54.660880118608475, 60.13186454772949, 64.23339486122131, 59.00531239807606, 50.8753826469183, 46.85647509992123, 47.0766656845808, 46.47362284362316, 48.46279710531235, 59.869655817747116, 62.22364090383053, 65.37916257977486, 53.87097850441933, 60.623155385255814, 65.85852205753326, 61.73052616417408, 56.87447793781757, 51.01565212011337, 52.16988578438759, 53.604407608509064, 58.19879807531834, 61.08117140829563, 67.0860081911087, 74.30303692817688, 64.38640505075455, 67.8732043504715, 64.14808183908463, 63.19859258830547, 61.76692821085453, 66.17065250873566, 66.80296137928963, 72.7298453450203, 67.12882429361343, 32.6411946862936, 1.4016300765797496, 12.180705238133669, 14.138053357601166, 3.212738768197596, 0.774713116697967, 0.13637313852086663, 0.24467936513246968, 5.0988770462572575, 36.92116342484951, 49.578846618533134, 75.82398891448975, 64.6151527762413, 45.801476910710335, 45.17987206578255, 41.85758113861084, 63.30725535750389, 68.2055801153183, 73.6542597413063, 28.081078380346298, 0.8579872513655573, 0.3097308205906302, 0.10726609922130592, 0.19765010511036962, 0.2630382729694247, 0.181747171736788, 0.07905282094725408, 0.21985937899444252, 0.12003336218185723, 0.12501231220085174, 0.16358154884073883, 0.20895268768072128, 0.17129002895671874, 0.165945467306301, 0.11174504950759001, 0.17626920162001625, 0.19057175290072337, 0.23126235930249095, 0.22938738256925717, 0.10476158087840304, 0.15101583092473447], [0.024402596718573477, 0.03820014804659877, 0.058292542162234895, 0.03475034136499744, 0.029482447280315682, 0.01906171797600109, 0.059598217412712984, 0.0349817615642678, 0.07267596156452782, 0.019060118647757918, 0.04272126345313154, 0.03272473833931144, 0.04312983430281747, 0.009905089737003436, 0.04103024286450818, 0.04418966200319119, 0.09893884605844505, 0.04129202803596854, 0.14025155775016174, 34.64279808104038, 73.85399982333183, 61.68992534279823, 57.516658678650856, 39.003934264183044, 30.090285167098045, 28.707237280905247, 37.59230241179466, 44.723128974437714, 27.583242394030094, 0.7273784035351127, 0.05350117738998961, 0.3520783904241398, 0.5720370984636247, 1.6082164412364364, 1.953673241659999, 2.0314194448292255, 0.7517830689903349, 52.69586496055126, 70.8158652484417, 63.632240518927574, 63.69176812469959, 58.68745185434818, 56.536668464541435, 51.70677423477173, 55.324685499072075, 56.5549036860466, 58.39420638978481, 56.65976665914059, 53.52428510785103, 47.37351715564728, 46.180757358670235, 45.495334938168526, 44.907506480813026, 45.442031398415565, 45.29669679701328, 45.822409987449646, 52.69132800400257, 59.63431924581528, 61.599896773695946, 56.50443859398365, 56.35866321623325, 57.43254639208317, 59.637731462717056, 55.86755856871605, 58.35463531315327, 55.429594069719315, 49.01756353676319, 43.19878377020359, 43.268331438302994, 43.26931558549404, 43.014482259750366, 43.96065428853035, 47.48615451157093, 44.88161846995354, 43.016693741083145, 41.164574325084686, 53.853020668029785, 56.386276334524155, 56.7934662848711, 49.54128563404083, 53.59802395105362, 54.864070415496826, 54.49105963110924, 42.93194688856602, 45.513600558042526, 51.412145644426346, 61.528491005301476, 40.38148954510689, 43.113489747047424, 62.55862332880497, 52.01505929231644, 56.53511054813862, 53.781907483935356, 60.4467536509037, 53.91173891723156, 54.272510558366776, 47.578497156500816, 54.471137300133705, 56.55877187848091, 56.15430258214474, 51.609244868159294, 56.88966952264309, 55.15295371413231, 55.906126499176025, 53.5009391605854, 57.63422057032585, 46.03501617908478, 44.126450791954994, 41.63264460861683, 44.18612278997898, 42.02546373009682, 49.4464161247015, 54.93549898266792, 59.95977558195591, 55.651228576898575, 56.82843580842018, 59.427990317344666, 58.31164062023163, 51.383624374866486, 47.53237523138523, 46.20658837258816, 46.58407151699066, 50.91993905603886, 62.335347309708595, 61.02157540619373, 67.94971704483032, 62.8752451390028, 63.71384114027023, 58.679692670702934, 59.79999415576458, 60.606641471385956, 62.674220725893974, 61.011046171188354, 61.04388780891895, 62.66230836510658, 52.97425702214241, 7.599632581695914, 0.32390904729254544, 4.307674951851368, 2.9736734088510275, 0.4714500834234059, 0.23129349981900305, 0.0373102832963923, 0.27497865725308657, 12.11426580324769, 25.824096389114857, 24.85843900591135, 30.47992955893278, 35.50008527934551, 15.029133092612028, 24.09402832388878, 41.04192450642586, 49.11774896085262, 55.80739639699459, 40.9418036788702, 2.499016891233623, 0.13675712572876364, 0.07879190408857539, 0.01732744316541357, 0.050192245180369355, 0.05979940251563676, 0.032393699657404795, 0.060102347197243944, 0.016106062903418206, 0.045287855027709156, 0.0533273998007644, 0.05021885117457714, 0.01567003630043473, 0.03460741114395205, 0.013438192290777806, 0.06015680599375628, 0.02262310285004787, 0.005458235946207424, 0.03308363724499941, 0.05517866120499093, 0.04721660036011599, 0.04385725776955951, 0.04092005990969483, 0.015699525538366288, 0.02823574308422394, 0.014784267277718754, 0.028561256476677954, 0.05798099598905537, 0.03519524776493199, 0.02979298969876254, 0.03205680171959102, 0.03453882185567636, 0.036323271415312774, 0.09105943448957987, 0.04872448858805001, 0.08838284920784645, 0.051615710399346426, 0.041796447258093394, 0.017964207727345638, 0.19237962464103475, 45.852010399103165, 82.90941551327705, 67.85452455282211, 64.02158662676811, 42.91925556957722, 32.741741091012955, 27.01730266213417, 37.02835187315941, 42.24766820669174, 29.021115638315678, 0.917080967919901, 0.20065256743691862, 0.9938382741529495, 1.3900566101074219, 1.3617095374502242, 3.6639479314908385, 2.1613677218556404, 1.261972845532, 56.800389513373375, 73.52422311902046, 67.42709308862686, 66.73198878765106, 60.68614840507507, 61.06410652399063, 55.48915207386017, 57.94101990759373, 59.14873190224171, 60.88172011077404, 60.93173682689667, 57.34936885535717, 50.642341151833534, 49.273210018873215, 46.82013384997845, 46.75610728561878, 46.12911432981491, 49.093586057424545, 47.24115885794163, 54.84627217054367, 61.847651079297066, 63.97791936993599, 57.367003709077835, 56.90643422305584, 61.21411107480526, 61.161670088768005, 57.478831708431244, 60.56255243718624, 56.6158752143383, 50.46534284949303, 45.18607333302498, 45.8661874383688, 44.76041257381439, 46.387196481227875, 46.91505275666714, 50.495517030358315, 45.45325219631195, 45.77445276081562, 42.61477030813694, 55.610145181417465, 58.466060534119606, 58.65746006369591, 53.43604624271393, 57.79476575553417, 57.019812539219856, 55.87543174624443, 44.87743489444256, 49.11925747990608, 53.53811636567116, 65.65619811415672, 44.02400068938732, 45.92150866985321, 63.72913531959057, 53.62231604754925, 57.84359693527222, 54.5700915902853, 60.51408223807812, 54.79455694556236, 53.897645473480225, 47.846884354949, 55.738171711564064, 58.96709404885769, 58.15736509859562, 53.91046218574047, 57.68237918615341, 56.72334864735603, 56.618527472019196, 57.12836131453514, 59.86371673643589, 47.41343781352043, 45.76677717268467, 42.64975503087044, 46.251555159687996, 44.218660444021225, 51.91059149801731, 56.61770671606064, 62.61089712381363, 57.00249686837196, 56.53754621744156, 62.61622063815594, 61.246143355965614, 52.425680458545685, 49.69859339296818, 49.67713974416256, 47.85543009638786, 52.91026085615158, 64.26583752036095, 62.11901351809502, 67.7146464586258, 65.71565732359886, 65.7730570435524, 61.19568586349487, 61.96690768003464, 63.172396793961525, 64.21541422605515, 65.26504710316658, 64.30317431688309, 66.52140408754349, 57.725848853588104, 9.26907917484641, 0.694560514530167, 3.1507237209007144, 3.3113453770056367, 1.9423202821053565, 0.70490961545147, 0.05707175747375004, 0.1724571897648275, 14.253819845616817, 33.411789536476135, 23.887081928551197, 33.24019454419613, 33.3267804980278, 23.364758156239986, 32.170247957110405, 47.13455557823181, 55.584876537323, 62.61734537780285, 51.93987652659416, 3.4295387472957373, 0.16886615980183706, 0.03260583143855911, 0.04977975579095073, 0.006092511994211236, 0.03365152493643109, 0.0035437036694929702, 0.0503907585516572, 0.05247618610155769, 0.09562713821651414, 0.07967635116074234, 0.05031800581491552, 0.04083977437403519, 0.05096519940707367, 0.04566857678582892, 0.041693325838423334, 0.05404778028605506, 0.024072606320260093, 0.04847507501835935, 0.06387676927261055, 0.02329307666514069, 0.08686719069373794, 0.17452027124818414, 0.15378304728074, 0.08782764110947028, 0.24785826564766467, 0.22074516193242744, 0.14405539113795385, 0.11552636613487266, 0.10866205673664808, 0.20099704270251095, 0.1568544254405424, 0.1818056232878007, 0.14011108403792605, 0.11293941002804786, 0.13608435401692986, 0.07360203569987789, 0.16233794682193547, 0.09932690023561008, 0.2574396593263373, 54.31640200316906, 92.37796023488045, 78.84165778756142, 73.52988481521606, 52.16284856200218, 41.70690022408962, 37.54796639084816, 52.41316772997379, 61.3700395077467, 42.65780679881573, 1.5482947253622115, 0.37037782254628837, 0.9386394079774618, 2.324614324606955, 5.539165595546365, 9.51555959880352, 9.700995348393917, 1.1414321511983871, 60.686809569597244, 74.92108896374702, 70.12869492173195, 68.48174929618835, 65.35460069775581, 62.27596789598465, 57.59109668433666, 60.26234194636345, 62.841917127370834, 63.56204308569431, 62.66101263463497, 60.089702010154724, 51.90627112984657, 52.25197657942772, 49.14750516414642, 48.240269646048546, 50.06748899817467, 50.67804403603077, 49.93412375450134, 57.206363528966904, 65.01546889543533, 65.54798752069473, 59.5526198297739, 60.549340546131134, 64.93527799844742, 63.61207500100136, 58.7557265907526, 62.17214986681938, 61.47460609674454, 53.22362624108791, 48.51565606892109, 48.24468120932579, 47.731408551335335, 47.54226990044117, 49.46637265384197, 52.35181622207165, 49.56984490156174, 47.92884595692158, 46.55648119747639, 58.314406871795654, 62.59186394512653, 58.97467844188213, 55.015773475170135, 61.947783306241035, 60.66029079258442, 60.885797291994095, 48.85566182434559, 49.169673174619675, 56.8978276848793, 67.77984336018562, 48.972383961081505, 50.06814256310463, 66.80761232972145, 56.307555958628654, 61.28455549478531, 58.74316826462746, 63.784509748220444, 57.11265675723553, 56.60002626478672, 49.76115703582764, 58.25104907155037, 62.51381993293762, 60.34882910549641, 56.14093489944935, 61.37040048837662, 57.809611558914185, 57.28445313870907, 57.60547511279583, 63.479731902480125, 50.63315324485302, 47.69789054989815, 44.01576653122902, 49.16317172348499, 47.30906121432781, 54.90538939833641, 59.365973845124245, 65.60630679130554, 57.787504345178604, 58.47710274159908, 64.0844276547432, 62.5117452442646, 55.79187422990799, 52.47282072901726, 50.80888241529465, 50.6315953284502, 54.210684075951576, 67.47649803757668, 65.45495331287384, 70.54547935724258, 66.98757067322731, 69.24409478902817, 62.613287195563316, 64.70955491065979, 65.31680032610893, 67.2549395263195, 66.64404630661011, 68.67303103208542, 67.66556069254875, 61.653508096933365, 11.251896377652884, 1.6759246517904103, 10.39705054834485, 9.462866876274347, 3.203305061906576, 0.6474102102220058, 0.14726443769177422, 0.4019847046583891, 20.5285257473588, 41.64757780730724, 34.51293624937534, 42.27530412375927, 45.94772346317768, 24.231227561831474, 34.73533071577549, 57.69716799259186, 64.30261194705963, 71.82879969477654, 57.23515838384628, 3.787362934090197, 0.3008455317467451, 0.20251374022336677, 0.12727184017421678, 0.1178130715561565, 0.172979082853999, 0.10221815915429033, 0.10685509783797897, 0.14840611314866692, 0.13274084514705464, 0.1325177852413617, 0.16088946751551703, 0.15100883989362046, 0.13910845736972988, 0.13677419512532651, 0.1558355605811812, 0.1380526929278858, 0.07755847691441886, 0.09763012058101594, 0.13877547055017203, 0.08798865746939555], [0.0709736454882659, 0.05808273701404687, 0.03750527888769284, 0.039226660737767816, 0.015315479886339745, 0.03588354149542283, 0.03373907980858348, 0.016045666925492696, 0.015404173955175793, 0.050836173322750255, 0.017675441777100787, 0.010651862849044846, 0.10284954129019752, 0.02641003011376597, 0.010004768519138452, 0.10004236028180458, 0.0499290425068466, 0.05577452786383219, 5.212300959974527, 64.32584390044212, 67.82726481556892, 64.08339411020279, 54.56420950591564, 35.19755311310291, 22.79648344963789, 46.03955313563347, 38.85098487138748, 38.87999251484871, 7.465479830279946, 0.20378210028866306, 0.11397332564229146, 0.4695355799049139, 0.3855510614812374, 1.3111424446105957, 1.6659755981527269, 1.296255555935204, 20.542723685503006, 81.04007542133331, 65.04572287201881, 66.6974638402462, 59.07467007637024, 57.90383890271187, 54.86480377614498, 56.09636329114437, 56.578413024544716, 59.66068983078003, 57.864218428730965, 57.50901348888874, 56.14608742296696, 52.913505882024765, 46.849878653883934, 44.19968046247959, 46.59845754504204, 45.95866687595844, 48.18426065146923, 47.025721818208694, 50.318096950650215, 53.09073217213154, 56.29815526306629, 55.40380485355854, 53.86790066957474, 54.01720605790615, 57.30392329394817, 57.934184074401855, 56.56765200197697, 56.10080145299435, 48.4637850522995, 45.305162742733955, 45.63094966113567, 42.40311786532402, 43.881990909576416, 44.192232862114906, 43.021838665008545, 42.00011529028416, 42.70468108355999, 42.234593108296394, 50.439796820282936, 56.125351935625076, 59.710140377283096, 51.398192793130875, 54.88345317542553, 55.34297771751881, 49.724420607089996, 40.010249465703964, 46.88070259988308, 53.56303922832012, 62.56365805864334, 42.90030978620052, 43.62190626561642, 60.0566665828228, 51.833178251981735, 54.04037341475487, 53.4173284471035, 58.074320554733276, 57.6500391215086, 58.82989481091499, 50.39780527353287, 54.1203211247921, 55.58444336056709, 54.133533015847206, 49.65640805661678, 55.77722601592541, 57.6176268607378, 53.696043491363525, 52.283796072006226, 59.39036853611469, 47.059293016791344, 43.44902694225311, 43.638256788253784, 42.396973595023155, 42.44581617414951, 43.54348607361317, 51.69519245624542, 55.92785753309727, 56.50819659233093, 54.65064346790314, 58.84192496538162, 58.19511227309704, 52.32603460550308, 46.57033145427704, 47.434089705348015, 45.121328607201576, 51.08944036066532, 61.64718143641949, 61.79543428122997, 61.867793798446655, 61.159200221300125, 59.67366613447666, 61.140600219368935, 59.91841480135918, 61.84627555310726, 64.10907313227654, 66.8356092274189, 63.331919834017754, 54.46698032319546, 50.82080617547035, 36.846588626503944, 1.995223774574697, 2.668889625929296, 4.342547105625272, 1.7081814771518111, 0.2984611300053075, 0.08491326429066248, 0.04692411625001114, 2.3939997889101505, 24.951912090182304, 32.41274334490299, 44.92006480693817, 68.53159502148628, 21.969436928629875, 16.051393188536167, 35.27016341686249, 50.68650238215923, 48.794302716851234, 56.76584556698799, 12.530991341918707, 0.3381617262493819, 0.025683957355795428, 0.05234354946878739, 0.057497616653563455, 0.07859319404815324, 0.03256630094256252, 0.042871655969065614, 0.074256142397644, 0.03499322403513361, 0.03268264372309204, 0.05305069003952667, 0.041495988771202974, 0.050348315126029775, 0.0363373202708317, 0.017529422366351355, 0.05764917063061148, 0.07158925698604435, 0.008625728260085452, 0.04149400723690633, 0.07029845437500626, 0.09405214499565773, 0.040864317197701894, 0.06633797587710433, 0.00967693313214113, 0.0347853633138584, 0.05502543739567045, 0.030602119913964998, 0.03022932243766263, 0.0247190336449421, 0.03024204655957874, 0.05743409252318088, 0.02389000088442117, 0.09221881759003736, 0.010415427586849546, 0.010064719208457973, 0.03888908744556829, 0.01695014270808315, 0.19010439282283187, 7.053243750706315, 74.37794610857964, 76.06998011469841, 71.1705382168293, 62.88214556872845, 48.81479501724243, 33.99386130273342, 33.3607392758131, 35.35256579518318, 44.34021212160587, 9.527566954493523, 0.12959042825968936, 0.030862546955177095, 0.72724285768345, 2.026997907087207, 4.182120189070702, 1.2174426787532866, 0.9658965922426432, 23.910163789987564, 81.60648822784424, 66.45964980125427, 69.16536301374435, 61.66431851685047, 60.47046437859535, 55.89496269822121, 58.57351876795292, 60.192760080099106, 60.79568512737751, 59.863412752747536, 60.800362676382065, 58.67039076983929, 55.25804467499256, 49.263991713523865, 46.57568156719208, 47.89934054017067, 48.55510175228119, 49.73854064941406, 47.01095961034298, 52.94872239232063, 56.98294311761856, 58.90369065105915, 57.112508565187454, 55.67391335964203, 57.647094279527664, 60.28172470629215, 59.704505279660225, 58.56079705059528, 57.455816343426704, 51.0888247936964, 46.97836875915527, 46.34012080729008, 46.44896976649761, 45.018604919314384, 45.94546638429165, 45.13666458427906, 44.167929366230965, 44.40605878829956, 43.48303131759167, 53.595823869109154, 59.644590094685555, 59.96065713465214, 53.59556168317795, 57.77055725455284, 56.420713886618614, 53.212496638298035, 43.92134539783001, 47.88094572722912, 56.03824160993099, 63.91551151871681, 43.46258081495762, 47.46860705316067, 63.75560089945793, 53.637104853987694, 55.8646859228611, 54.67251129448414, 59.837007969617844, 58.14955651760101, 60.28230607509613, 52.97932215034962, 56.91232770681381, 57.154313921928406, 56.7666245251894, 51.72318555414677, 58.14935512840748, 59.275401905179024, 53.72742600739002, 53.763444274663925, 62.150354236364365, 49.80643540620804, 46.541437804698944, 44.984391555190086, 43.3494570851326, 45.12837342917919, 45.62591873109341, 53.426482155919075, 57.238118425011635, 57.323245257139206, 55.03372371196747, 60.34018076956272, 61.70600987970829, 55.74701003730297, 48.50421108305454, 48.676094859838486, 48.85016351938248, 54.68913160264492, 62.952004820108414, 64.89018201828003, 63.773277550935745, 61.87792405486107, 63.1426177918911, 62.81269669532776, 61.99210412800312, 63.97498592734337, 67.65065789222717, 68.43358308076859, 65.23768857121468, 56.506973057985306, 56.393480747938156, 42.2784199565649, 2.8687047539278865, 1.8516892078332603, 1.0823167045600712, 2.600432261824608, 2.300497256219387, 0.159628885157872, 0.15547407529084012, 1.5885058301500976, 33.16527396440506, 32.484639286994934, 39.863896518945694, 58.5835350304842, 24.332355335354805, 24.609216079115868, 40.1350499689579, 58.43988373875618, 54.77390505373478, 66.60223335027695, 15.904445573687553, 0.20137601299211383, 0.06653733158600517, 0.07775989579386078, 0.017770275262591895, 0.0748388544889167, 0.03152182085614186, 0.06736108582117595, 0.038503345058416016, 0.05638002017803956, 0.03445601301791612, 0.05603010125923902, 0.06306230672635138, 0.012350995111773955, 0.010699310205382062, 0.015698842762503773, 0.05666574332281016, 0.03434388563618995, 0.052365119991009124, 0.04377846395072993, 0.06054740573745221, 0.23121085425373167, 0.12117888938519172, 0.23759880132274702, 0.11203519214177504, 0.13497941487003118, 0.13584695581812412, 0.18159765866585076, 0.09962187425117008, 0.16325782402418554, 0.17703560268273577, 0.13877551507903263, 0.145085506956093, 0.18077912915032357, 0.08695482349139638, 0.10578096524113789, 0.15383937628939748, 0.13429120648652315, 0.40553297207225114, 9.502762835472822, 87.04358607530594, 84.68270435929298, 82.95980080962181, 70.47156572341919, 51.337513849139214, 33.35204154253006, 64.63054955005646, 55.367946177721024, 58.544359132647514, 12.579839620739222, 0.30563814332708716, 0.28679629031103104, 1.937860508915037, 4.107420472428203, 4.903371362015605, 9.192358441650867, 4.915277548134327, 26.39892764389515, 88.7615878880024, 69.93063434958458, 71.11167177557945, 65.00435069203377, 65.06769329309464, 60.07817342877388, 61.01168833673, 62.943816259503365, 64.84062507748604, 63.23114164173603, 63.77369552850723, 61.65022887289524, 57.40619860589504, 52.255343198776245, 47.376507595181465, 51.23963490128517, 50.76970651745796, 52.40052580833435, 50.83711490035057, 54.465323612093925, 58.22521045804024, 62.99854852259159, 60.1499629765749, 59.324119091033936, 59.965912252664566, 62.197707295417786, 62.25076384842396, 60.59708118438721, 59.18750882148743, 53.60461659729481, 49.335758462548256, 49.1479117423296, 48.23295883834362, 47.31524348258972, 49.81436178088188, 47.06742838025093, 46.12307645380497, 46.40715301036835, 45.505556389689445, 54.77111600339413, 62.82532341778278, 64.35588508844376, 56.21325261890888, 58.33499416708946, 60.265503376722336, 56.01205721497536, 45.356323197484016, 49.87145371735096, 59.30677682161331, 65.94750568270683, 47.97747574746609, 51.41824431717396, 64.83039602637291, 58.11135336756706, 59.847392812371254, 57.38985948264599, 61.60108990967274, 63.757386803627014, 61.4260371029377, 54.05369929969311, 58.010210394859314, 59.27899271249771, 59.55276042222977, 52.964803129434586, 60.746964141726494, 64.52572837471962, 55.05399562418461, 54.93042625486851, 64.99653071165085, 52.14884251356125, 48.02492380142212, 48.46673369407654, 45.54914765059948, 47.0805224776268, 47.44706600904465, 56.90859630703926, 60.698360949754715, 58.49264770746231, 56.54513821005821, 64.15950402617455, 64.09027174115181, 56.716353222727776, 50.59114269912243, 52.738057896494865, 51.772028133273125, 56.32441185414791, 65.17418637871742, 67.14820325374603, 67.32664167881012, 63.9398530125618, 65.1793996989727, 65.35736694931984, 65.89582845568657, 66.79185077548027, 68.7472714483738, 70.49381732940674, 64.41282123327255, 59.84517753124237, 56.80910624563694, 44.30438004434109, 2.9296233225613832, 6.555838566273451, 12.22324775531888, 5.315092569217086, 1.4614823274314404, 0.19074250623816624, 0.2138548402581364, 2.7129691606387496, 41.35584846138954, 47.98627607524395, 59.83310177922249, 77.28002518415451, 28.990259394049644, 26.20001781731844, 47.26510897278786, 66.70332312583923, 60.425729379057884, 74.90949958562851, 18.75793855637312, 0.4403440619353205, 0.23401085869409144, 0.21721773402532563, 0.19789072423009202, 0.14879483525874093, 0.08326611205120571, 0.1724259156617336, 0.15763656003400683, 0.14459328493103385, 0.1859117779531516, 0.11048644126276486, 0.2588290488347411, 0.0587533490761416, 0.20115161722060293, 0.13901326950872317, 0.13709294755244628, 0.17288266302784905, 0.14605746808229014, 0.06173965855850838, 0.17103812919231132], [0.03437352701439522, 0.015187699682428502, 0.04591876961058006, 0.022832163995190058, 0.06058334052795544, 0.04192120599327609, 0.06264508614549413, 0.030179062341630924, 0.03708123054821044, 0.04692964896094054, 0.040190231884480454, 0.08278500739834271, 0.04397289550979622, 0.03405753908737097, 0.06761361641110852, 0.05555023228225764, 0.14443084364756942, 0.0349289763107663, 16.63069110363722, 71.19381576776505, 63.7935608625412, 59.497655779123306, 38.07004697620869, 21.793346777558327, 24.808201901614666, 41.89037337899208, 37.096881195902824, 29.92143362760544, 0.8949127199593931, 0.07082278170855716, 0.16239473596215248, 0.9991151816211641, 0.8131435420364141, 1.3651295914314687, 0.8019656105898321, 1.173890484496951, 67.42960095405579, 67.92001783847809, 62.44296133518219, 61.157706901431084, 56.660587415099144, 57.18666918575764, 58.49252611398697, 56.61082148551941, 57.29423001408577, 58.10732938349247, 56.74272760748863, 55.94000168144703, 57.96490542590618, 53.86756248772144, 49.63878080248833, 43.01161341369152, 48.16929705440998, 50.181862860918045, 49.448194429278374, 47.431251257658005, 46.9803636521101, 49.41207356750965, 51.217402294278145, 48.93122836947441, 49.803524762392044, 54.32626627385616, 60.36293774843216, 57.77596436440945, 58.92724558711052, 54.22380477190018, 51.21189258992672, 48.19991961121559, 48.13511788845062, 44.455851316452026, 42.947560250759125, 42.8648766875267, 44.39612612128258, 41.629965752363205, 41.57184787094593, 42.24049799144268, 51.33510857820511, 54.95006740093231, 55.98639339208603, 50.15085272490978, 56.31554313004017, 51.64405860006809, 48.92406955361366, 38.03860746324062, 51.096192598342896, 53.003314062952995, 61.79465152323246, 40.05240820348263, 45.69721810519695, 60.182185247540474, 50.10609492659569, 51.15855485200882, 44.716399535536766, 50.79925373196602, 51.65263094007969, 56.80128626525402, 54.03762236237526, 55.11893793940544, 54.953088238835335, 53.18264923989773, 45.087601616978645, 51.51185229420662, 57.34979063272476, 53.89569237828255, 52.40707665681839, 60.908668264746666, 48.54809872806072, 42.51401871442795, 40.98855257034302, 41.99690066277981, 42.39742957055569, 44.03484910726547, 47.95634888112545, 53.814475536346436, 57.19518072903156, 56.331259086728096, 56.03974252939224, 58.321208506822586, 51.997040659189224, 46.286558881402016, 43.913761004805565, 44.45229470729828, 49.16810005903244, 65.09059086441994, 55.52141234278679, 57.87638157606125, 56.94162793457508, 56.33711837232113, 60.2531274408102, 61.753298342227936, 62.434510588645935, 62.51902185380459, 58.854996263980865, 62.0946454256773, 69.60727170109749, 62.33779817819595, 66.0111066699028, 42.57585659623146, 1.6091796895489097, 1.5708574396558106, 2.190647288225591, 1.4844496012665331, 0.05229440073890146, 0.061096973513485864, 0.18497821554774418, 10.609498098492622, 33.644717037677765, 33.54293189942837, 46.54322750866413, 21.311650425195694, 21.66069209575653, 29.448909983038902, 42.65035539865494, 48.9189550280571, 57.79003880918026, 21.3817148655653, 0.3755171358352527, 0.061447571497410536, 0.08645253052236512, 0.04849272329011001, 0.04571544712234754, 0.04433346795849502, 0.06337085462291725, 0.04145286628045142, 0.0037372342148955795, 0.02634171542013064, 0.04054586162965279, 0.015143272867135238, 0.05543974504689686, 0.016765169821155723, 0.05839568955707364, 0.11061830606195144, 0.06697336561046541, 0.009854939107754035, 0.06636246675043367, 0.04173569876002148, 0.05077217792859301, 0.012635113362193806, 0.02987185031088302, 0.058057129208464175, 0.01586015227076132, 0.032752145853010006, 0.017223902432306204, 0.020945934447809123, 0.04261777095962316, 0.030250382733356673, 0.0490755912323948, 0.03047319401957793, 0.051803670430672355, 0.10748522574431263, 0.11714156149537303, 0.1564870771835558, 0.09793529170565307, 0.08567450742702931, 21.652292646467686, 82.05414980649948, 68.01636546850204, 68.3487032353878, 44.55858260393143, 32.17592865228653, 25.19563291221857, 38.87040562927723, 35.323824137449265, 35.528967529535294, 1.2615060643292964, 0.13772546517429873, 0.060655777851934545, 1.5809810464270413, 3.050212701782584, 5.218952978029847, 1.067017181776464, 1.8278274382464588, 69.39755335450172, 70.72150111198425, 65.50236716866493, 63.76752465963364, 59.91109639406204, 59.458278492093086, 61.221687868237495, 60.14685854315758, 60.27422770857811, 60.952426716685295, 59.42501127719879, 59.144795313477516, 60.32066881656647, 56.285509541630745, 51.04093216359615, 46.56311944127083, 49.93003137409687, 51.462679132819176, 52.88480222225189, 49.582182839512825, 49.54445846378803, 51.73150710761547, 51.93547636270523, 50.92817321419716, 53.42811606824398, 56.306047439575195, 61.51601627469063, 57.84070909023285, 61.43396347761154, 57.30743430554867, 54.80961553752422, 52.29647219181061, 50.00820837914944, 46.6307558119297, 45.84939993917942, 45.50116382539272, 46.5786188095808, 44.17735666036606, 44.96981933712959, 43.834835439920425, 53.29702690243721, 56.518592834472656, 56.37337222695351, 52.956166192889214, 58.35255302488804, 54.318678081035614, 51.674836948513985, 42.065627574920654, 52.34063342213631, 56.2316170334816, 65.58462515473366, 42.637071311473846, 48.825286254286766, 62.35840067267418, 52.87643127143383, 53.62745717167854, 47.24596180021763, 52.17056214809418, 53.97277504205704, 59.403078854084015, 56.51524901390076, 57.30254776775837, 59.442893117666245, 55.48606663942337, 47.168233171105385, 54.11000847816467, 60.41263148188591, 55.37612333893776, 53.22296887636185, 62.949854135513306, 50.97986564040184, 44.297122433781624, 43.584884852170944, 44.48456637561321, 44.869242534041405, 46.43711820244789, 50.13291768729687, 56.150749772787094, 60.01445084810257, 57.3860976845026, 59.220316261053085, 60.381773337721825, 55.407452657818794, 47.71361030638218, 46.4734860509634, 46.592229679226875, 50.906130596995354, 66.83402851223946, 57.91126370429993, 60.185187086462975, 58.542877212166786, 59.132316783070564, 60.510787814855576, 63.782693445682526, 63.45959298312664, 60.54659329354763, 58.737662360072136, 63.21663782000542, 70.41258528828621, 65.9905269742012, 69.14995104074478, 46.945356130599976, 2.0564878871664405, 1.261036789510399, 0.9453304333146662, 3.2821038085967302, 0.7466538192238659, 0.04466673308343161, 0.41659316921141, 11.767312120646238, 41.027154698967934, 30.61353798955679, 45.21161936223507, 17.91855789721012, 29.66599803417921, 37.962839528918266, 48.50961819291115, 54.583968445658684, 63.81179988384247, 30.361303724348545, 0.4409280134132132, 0.050958813226316124, 0.06589040145627223, 0.01932398368808208, 0.04301004053559154, 0.029059374865028076, 0.009504602730885381, 0.04614421552105341, 0.03678061992104631, 0.021683081904484425, 0.04905661451630294, 0.06062957261747215, 0.0071133477194962325, 0.04223722360620741, 0.008396949178859359, 0.06972171657253057, 0.01993172656511888, 0.04667934852477629, 0.08159270262694918, 0.03537379736371804, 0.1523992684087716, 0.08641159365652129, 0.17622933344682679, 0.11417384652304463, 0.1909944653743878, 0.12652710982365534, 0.08938488957937807, 0.089569528499851, 0.10195618102443404, 0.16053010476753116, 0.13286059809615836, 0.22087037708843127, 0.1970102995983325, 0.17137662274762988, 0.2734413428697735, 0.29799853451550007, 0.2705410891212523, 0.2656883338931948, 27.175328582525253, 94.13886934518814, 77.23794624209404, 75.7760126888752, 52.196799740195274, 31.9773019105196, 34.8445026576519, 59.23333436250687, 50.34448653459549, 48.144894763827324, 1.908055858220905, 0.31003326061181724, 0.4533197422279045, 3.2387426728382707, 3.9587957225739956, 9.069394189864397, 9.454891104251146, 1.3247903622686863, 75.61810076236725, 71.48489534854889, 68.21711629629135, 66.80666238069534, 62.440119087696075, 61.15663915872574, 64.8569718003273, 61.96485958993435, 62.27905333042145, 64.39093440771103, 62.87468656897545, 62.319346368312836, 63.962978571653366, 57.75198385119438, 55.436711087822914, 48.267726972699165, 54.13779638707638, 55.883814096450806, 55.20276144146919, 52.97189734876156, 51.957131400704384, 54.80905316770077, 56.1779411137104, 53.27245742082596, 56.52887508273125, 60.06328962743282, 65.83225026726723, 59.48757492005825, 63.29909339547157, 60.17973057925701, 56.70870043337345, 53.67037206888199, 53.50384600460529, 49.309175089001656, 49.2145411670208, 47.58940637111664, 49.09255251288414, 46.93297639489174, 48.435354977846146, 46.81959807872772, 56.3749073445797, 59.5414712280035, 60.29564715921879, 56.112975999712944, 60.595048293471336, 56.52816832065582, 53.643040135502815, 42.857383489608765, 55.92764474451542, 59.01372514665127, 68.49977552890778, 46.10358729958534, 52.56299749016762, 64.36989113688469, 56.75664626061916, 56.861950010061264, 49.0630204975605, 56.07824966311455, 57.52562999725342, 63.71197544038296, 59.32671435177326, 58.05360406637192, 62.103001177310944, 58.37929978966713, 49.205338060855865, 56.965445056557655, 64.4290691614151, 57.682930156588554, 55.18485300242901, 66.34897693991661, 52.825164422392845, 47.454095631837845, 47.31523968279362, 45.57241000235081, 47.47147589921951, 49.620720371603966, 52.361555099487305, 58.875370770692825, 63.82801741361618, 58.686099126935005, 59.29367512464523, 63.26418846845627, 56.158193573355675, 50.37261262536049, 48.20020839571953, 48.7016598880291, 53.77905383706093, 70.75063034892082, 60.08695475757122, 63.77684935927391, 59.165743589401245, 60.48067823052406, 62.84976750612259, 66.69905975461006, 65.26915088295937, 63.19171875715256, 62.02408701181412, 68.52597132325172, 74.69967484474182, 69.33313921093941, 69.90465894341469, 46.52086950838566, 2.2653137566521764, 3.8497460866346955, 11.791275534778833, 4.647728679701686, 0.3815333411330357, 0.21727643790654838, 0.7018729252740741, 15.71535062044859, 50.58688312768936, 45.89059732854366, 58.61022859811783, 29.443092495203018, 32.45501607656479, 42.393139600753784, 60.87013453245163, 63.53212729096413, 73.05986523628235, 36.74014113843441, 0.8825863595120609, 0.1940000001923181, 0.15132760716369376, 0.1276594342198223, 0.12375874313875102, 0.12939594103954732, 0.17393284651916474, 0.17250482080271468, 0.08180584001820534, 0.1713286800077185, 0.11570509755983949, 0.18612429936183617, 0.18756293779006228, 0.07223289940156974, 0.2651162864640355, 0.24536565877497196, 0.15888121590251103, 0.11325589148327708, 0.1775573324994184, 0.1448490290204063], [0.05423687951406464, 0.045159277942730114, 0.05102627445012331, 0.04718031676020473, 0.029324087809072807, 0.04689085319114383, 0.0395235198084265, 0.03982108763011638, 0.0413772674073698, 0.055355463045998476, 0.03299830881587695, 0.029061107779853046, 0.07461091125151142, 0.08903545676730573, 0.10399478647741489, 0.005999587219776004, 0.041158211388392374, 0.3011516231345013, 39.30787235498428, 67.12919667363167, 60.0383135676384, 58.3740446716547, 45.360282585024834, 22.360998317599297, 38.703571781516075, 37.87952899932861, 41.66318356990814, 16.43069453537464, 0.023819066409487277, 0.04177069102297537, 0.08787564322119579, 0.37275400129146874, 2.4231653613969684, 4.722732855007052, 0.5624021810945123, 24.995174668729305, 79.1452918946743, 63.17132145166397, 67.07882657647133, 59.63325150310993, 59.45028752088547, 58.693508729338646, 59.58113729953766, 57.73530654609203, 58.72333712875843, 54.31505687534809, 51.743704453110695, 54.54607307910919, 56.26443587243557, 54.86208312213421, 48.903721645474434, 46.573158502578735, 50.37464551627636, 53.064095601439476, 54.73678104579449, 49.52928967773914, 45.65657928586006, 43.31484094262123, 46.516552940011024, 44.81370471417904, 50.90742252767086, 54.14125420153141, 57.79229208827019, 57.279836386442184, 57.674046233296394, 57.02077388763428, 54.9410542845726, 52.23454691469669, 50.64793065190315, 46.71225003898144, 43.84926326572895, 42.18587212264538, 41.08769305050373, 41.62202037870884, 41.70263685286045, 41.726727560162544, 50.71809008717537, 53.463089391589165, 52.72378586232662, 55.075791254639626, 53.51082243025303, 48.81375387310982, 44.083790481090546, 41.7650181055069, 50.12004777789116, 53.28230269253254, 62.598433792591095, 41.24803304672241, 44.32734601199627, 59.760054498910904, 51.42048619687557, 52.56485939025879, 44.559224769473076, 46.337863728404045, 45.39034657180309, 55.50465524196625, 53.77155303955078, 55.88865123689175, 55.48267722129822, 52.069012597203255, 44.2209517210722, 53.137104883790016, 54.56113927066326, 55.899891033768654, 50.79712584614754, 58.413554951548576, 50.37903808057308, 44.29743401706219, 42.870340794324875, 41.93184435367584, 42.857991456985474, 45.71316584944725, 48.77884894609451, 51.883069574832916, 54.893610030412674, 55.75464762747288, 54.884159937500954, 60.05945563316345, 54.21522103250027, 48.140369206666946, 41.948757246136665, 46.09344184398651, 47.56234422326088, 60.92050842940807, 55.785095393657684, 55.08669286966324, 61.47202603518963, 58.37504021823406, 55.89816592633724, 59.44864980876446, 55.72153240442276, 59.28345747292042, 58.86483393609524, 62.464935556054115, 61.26011520624161, 65.2742426097393, 57.38710083067417, 68.01715582609177, 33.341010734438896, 1.265764923300594, 2.566437148489058, 5.7395734917372465, 0.6123168964404613, 0.07711295824265108, 0.018400944936729502, 2.11189485155046, 25.139384530484676, 32.314370423555374, 30.146797634661198, 34.9356559664011, 13.679235577583313, 18.705383576452732, 37.373156771063805, 46.23112365603447, 53.34630645811558, 39.10294555127621, 3.5689751151949167, 0.11362323974026367, 0.03378857363713905, 0.05702765905880369, 0.06441110075684264, 0.028550346905831248, 0.041200179839506745, 0.03566532410332002, 0.03359750771778636, 0.04500337498029694, 0.03382949566002935, 0.019791956037806813, 0.04689782937930431, 0.06103427316702437, 0.07636285474291071, 0.0492590649810154, 0.032169875339604914, 0.012158247300249059, 0.023915885140013415, 0.034844586698454805, 0.0418830707349116, 0.07318244766793214, 0.06583318929187953, 0.05255606345599517, 0.030158013178152032, 0.03947884251829237, 0.026857704724534415, 0.045519067425630055, 0.048996953264577314, 0.0006432355098695552, 0.0246140846866183, 0.10049734133644961, 0.01493585186835844, 0.04147710853430908, 0.06198071554536, 0.014709505176142557, 0.00867893375470885, 0.4089980595745146, 48.426102474331856, 76.11590445041656, 68.00922185182571, 64.20754864811897, 54.3765489757061, 28.806556351482868, 36.83153383433819, 32.864949479699135, 45.053145065903664, 20.735382847487926, 0.07060281655867584, 0.06355253979563713, 0.3254255518550053, 1.2160540907643735, 3.7133664172142744, 2.0291476417332888, 0.12789074680767953, 26.73784475773573, 80.72770938277245, 63.61863724887371, 71.20112657546997, 62.03682392835617, 62.426124438643456, 61.69473968446255, 62.18072220683098, 61.14557795226574, 60.36114044487476, 54.65490683913231, 54.131773710250854, 57.61184737086296, 57.74667553603649, 58.173020258545876, 51.09032951295376, 49.02047038078308, 53.12459595501423, 54.78379972279072, 57.081373035907745, 51.37227438390255, 47.79584549367428, 45.4911133646965, 47.543713822960854, 48.34555059671402, 53.274288922548294, 56.708309054374695, 60.701533779501915, 58.28272417187691, 58.50919961929321, 60.349832251667976, 56.57854221761227, 55.498051196336746, 53.22967551648617, 49.096553698182106, 45.020679607987404, 44.90326590836048, 44.0453365445137, 42.29275278747082, 43.583847507834435, 44.057385697960854, 52.47156299650669, 55.2517332136631, 56.22542716562748, 56.53407700359821, 55.70438392460346, 51.824054941534996, 45.78707568347454, 43.26491542160511, 52.00944319367409, 55.17110913991928, 62.103996723890305, 42.291137874126434, 45.44966518878937, 63.61972019076347, 54.80071261525154, 55.98268859088421, 47.800671234726906, 49.6776907145977, 49.814707562327385, 58.09007830917835, 54.975005462765694, 58.956732004880905, 57.90827326476574, 53.92640992999077, 46.45374231040478, 54.223382994532585, 56.431889086961746, 57.05588400363922, 51.28076769411564, 60.587885677814484, 54.19583447277546, 45.52690364420414, 44.39515717327595, 44.90303032100201, 44.24677133560181, 47.432649582624435, 50.76234631240368, 54.028031677007675, 58.601196482777596, 56.63000665605068, 55.827835500240326, 62.05502115190029, 55.72073444724083, 50.180532932281494, 44.152467995882034, 47.07521416246891, 49.16466884315014, 64.32399719953537, 59.52622264623642, 59.759670719504356, 62.343725860118866, 59.961648881435394, 57.61139519512653, 60.23386247456074, 57.470909133553505, 59.82134900987148, 61.84923559427261, 64.79692742228508, 62.948516607284546, 66.88951313495636, 60.145570412278175, 70.5631636083126, 39.62412938475609, 1.261829046998173, 2.054248619824648, 1.1504143942147493, 2.844348535872996, 0.572303143562749, 0.06882989997393452, 1.4137448952533305, 31.05624843388796, 36.76422044634819, 29.030246548354626, 28.254464976489544, 18.647666573524475, 24.741015806794167, 45.22925041615963, 52.46789239346981, 60.266840904951096, 49.23274219036102, 5.187881570309401, 0.12728260131552815, 0.035073105100309476, 0.03472677446552552, 0.03835876726952847, 0.03226200926292222, 0.008837873956508702, 0.07431735473801382, 0.027351106764399447, 0.018695690741878934, 0.053307465714169666, 0.05662942261551507, 0.04832154692849144, 0.04610415438946802, 0.0564051307446789, 0.023241076232807245, 0.01739453146001324, 0.020365318923722953, 0.05378411748097278, 0.08076236554188654, 0.1445532831712626, 0.12458397424779832, 0.1894797122804448, 0.12303042167332023, 0.14716412901179865, 0.11221741166082211, 0.10253596905386075, 0.12055892890202813, 0.1332882681163028, 0.10824914803379215, 0.08447283675195649, 0.19146604085108265, 0.14028649806277826, 0.1680437265895307, 0.22310688364086673, 0.0557784872216871, 0.12895145395305008, 0.7279822742566466, 61.602606028318405, 86.02160811424255, 77.53539428114891, 74.0399694442749, 61.913687735795975, 31.053373888134956, 55.27004823088646, 52.62850597500801, 61.83734983205795, 27.0487117767334, 0.11678996161208488, 0.2394440773059614, 0.44144911982584745, 2.494672774337232, 5.930177439004183, 14.046205636113882, 2.7761393459513783, 28.80808386951685, 85.21915197372437, 67.05990359187126, 75.55788919329643, 65.29612943530083, 64.42881077528, 64.41375598311424, 64.74415585398674, 63.095922097563744, 63.76201495528221, 58.28418709337711, 57.629695013165474, 59.86380413174629, 58.82538825273514, 61.187257915735245, 54.33116041123867, 51.48111954331398, 53.73260512948036, 59.30338740348816, 60.9706961363554, 53.98295849561691, 50.97590245306492, 49.00553718209267, 51.67037978768349, 50.522263795137405, 55.93221589922905, 57.36034646630287, 61.76962986588478, 60.65213643014431, 61.10280744731426, 62.378026619553566, 58.951697275042534, 57.63308443129063, 55.595120787620544, 51.95812314748764, 48.32502789795399, 46.59880332648754, 45.012988820672035, 46.455995589494705, 46.04971759021282, 45.78986093401909, 56.09788320958614, 59.39052812755108, 59.49926309287548, 59.89746652543545, 57.59690277278423, 53.4359360486269, 48.25537383556366, 45.80827474594116, 55.146338269114494, 59.462351873517036, 64.9531902372837, 45.25224298238754, 50.634897351264954, 65.52982449531555, 59.16706211864948, 59.83206823468208, 50.895498767495155, 51.71403184533119, 51.06694936752319, 61.99198253452778, 57.169953882694244, 61.074795350432396, 58.34714591503143, 55.36829195916653, 49.0670520812273, 58.98710377514362, 58.45133252441883, 59.82879661023617, 53.8672699034214, 64.37190502882004, 55.46914994716644, 48.79810631275177, 45.59377245604992, 46.92920319736004, 47.3750826716423, 49.984531849622726, 53.90424571931362, 55.61941668391228, 60.96251517534256, 59.420443922281265, 56.5176010876894, 65.24368464946747, 57.314737513661385, 53.10075603425503, 45.76118007302284, 50.531687289476395, 51.080225855112076, 67.36373528838158, 61.22491769492626, 61.751710027456284, 64.49428886175156, 62.66864262521267, 59.542846754193306, 63.290726244449615, 57.220684960484505, 62.273802012205124, 64.98472854495049, 66.16822063922882, 65.83862632513046, 70.68642139434814, 62.841111570596695, 73.51403206586838, 38.98043252527714, 1.1972035397775471, 8.389003649353981, 15.630428977310658, 3.1297735450789332, 0.34027735178824514, 0.14678229403216392, 2.953390572220087, 39.630532041192055, 47.94960804283619, 43.62520828843117, 47.40384712815285, 21.746576987206936, 29.74862650036812, 52.265769839286804, 61.07027739286423, 66.80054470896721, 56.618056297302246, 5.726800952106714, 0.239691553870216, 0.15995808702427894, 0.27759870572481304, 0.17103624413721263, 0.09743806018377654, 0.1276776465238072, 0.2517527004238218, 0.16457639780128375, 0.16334882617229596, 0.0936924631241709, 0.21295722748618573, 0.31354991253465414, 0.12413461867254227, 0.21378218400059268, 0.101605753734475, 0.13961265765829012, 0.20235625648638234, 0.14563598757376894, 0.1908213074784726], [0.10631553421262652, 0.017883243126561865, 0.05622071446850896, 0.030993040636531077, 0.050026122844428755, 0.012594663530762773, 0.06864920927910134, 0.023023278154141735, 0.021703155143768527, 0.0016368351111850643, 0.017000161606119946, 0.06710759043926373, 0.03515979537041858, 0.12400179650285281, 0.05116096683195792, 0.06534953907248564, 0.06450901972129941, 9.988372977823019, 62.69151359796524, 61.82543367147446, 58.35375756025314, 51.23214550316334, 31.737648770213127, 21.298942007124424, 34.77083221077919, 36.27131849527359, 38.57413932681084, 4.835718367248774, 0.13084415317280218, 0.11194563718163408, 0.1393064029980451, 0.8290387422312051, 3.3679694635793567, 2.0746770361438394, 1.1774124205112457, 57.942862808704376, 69.27501752972603, 62.68325664103031, 57.665188908576965, 56.280638203024864, 57.47012637555599, 58.78169819712639, 56.888069808483124, 54.94741514325142, 52.43250109255314, 45.83558388054371, 47.53375455737114, 53.15743379294872, 55.88547080755234, 55.24363584816456, 51.29364900290966, 47.44922049343586, 54.33410905301571, 56.73289753496647, 54.882841408252716, 50.77867403626442, 46.25144496560097, 42.06927537918091, 44.383810982108116, 46.37391619384289, 53.846211433410645, 54.77889038622379, 58.21113981306553, 59.00967076420784, 54.80795502662659, 56.18839055299759, 58.458179756999016, 56.91976770758629, 53.96361753344536, 48.1219781935215, 42.75013044476509, 41.68834961950779, 42.67988741397858, 39.82115641236305, 40.88410757482052, 43.18694740533829, 50.909937992691994, 50.64438924193382, 55.097674280405045, 51.871286407113075, 53.141493648290634, 44.63930927217007, 41.00425712764263, 42.38375410437584, 49.4190613925457, 53.39343532919884, 58.56954798102379, 38.26509431004524, 40.93258537352085, 58.39554011821747, 51.82384215295315, 50.53740598261356, 44.05295133590698, 43.939014449715614, 40.35358764231205, 50.263216495513916, 53.20940360426903, 56.64851166307926, 53.46253842115402, 48.978190049529076, 41.1625262349844, 48.692224994301796, 56.28347285091877, 54.87471364438534, 48.02811563014984, 55.83714120090008, 51.46789625287056, 42.500373646616936, 41.536186784505844, 39.28511157631874, 45.79188622534275, 50.19726723432541, 51.69459588825703, 53.499723225831985, 56.33054852485657, 53.420375883579254, 54.64339345693588, 57.13640548288822, 55.0917199999094, 49.94080379605293, 43.57176415622234, 45.15741907060146, 46.67601518332958, 56.34377181529999, 57.21410371363163, 56.793462485075, 57.83651031553745, 60.98523795604706, 59.593627229332924, 58.50682474672794, 56.81493513286114, 64.32465836405754, 66.2691280245781, 59.63051564991474, 61.05197377502918, 57.42673650383949, 64.0747457742691, 58.86434756219387, 70.19171074032784, 27.932836934924126, 0.355380650726147, 5.313000306487083, 4.986588321626186, 0.2581242163432762, 0.031139158381847665, 0.0982253007532563, 13.827539719641209, 38.52070279419422, 30.11733401566744, 36.53866454958916, 25.93002710491419, 21.298453733325005, 34.74916957318783, 50.46164184808731, 48.70514050126076, 53.43324579298496, 14.22591794282198, 0.43042401142884046, 0.15021466766484082, 0.055170000341604464, 0.12938103871420026, 0.035799738179775886, 0.05508683898369782, 0.03206838664482348, 0.0266531651141122, 0.010162455419049365, 0.01120498736781883, 0.02658283177879639, 0.020778676625923254, 0.001203263509523822, 0.07024935388471931, 0.06617585371714085, 0.1233204678283073, 0.04987181178876199, 0.044364478599163704, 0.04923819207760971, 0.03558749878720846, 0.021021542597736698, 0.046505856662406586, 0.010080473148263991, 0.015520706911047455, 0.023781435811542906, 0.07456925450242124, 0.06779875257052481, 0.02689495126105612, 0.024427403004665393, 0.030282150364655536, 0.029273640320752747, 0.035164931032340974, 0.07096894027199596, 0.007742235311525292, 0.02077795117656933, 0.06910253534442745, 12.550422549247742, 72.38797768950462, 70.77964559197426, 64.72220823168755, 57.49456286430359, 40.40317878127098, 19.816728942096233, 36.17817409336567, 37.32959970831871, 46.19169317185879, 6.935752630233765, 0.3212260646978393, 0.015843071741983294, 0.4687215923331678, 1.640553893521428, 4.584898576140404, 0.5561389296781272, 1.4712450723163784, 60.29898338019848, 71.35275363922119, 67.34388515353203, 59.77491170167923, 58.96868996322155, 60.625146478414536, 60.571174174547195, 59.709657803177834, 58.27529937028885, 56.730218678712845, 48.56386788189411, 50.499514415860176, 56.67799808084965, 57.94643081724644, 57.36513800919056, 53.658509105443954, 51.23300425708294, 56.1299192905426, 60.47320023179054, 58.76833811402321, 55.49536474049091, 47.77647413313389, 44.95606407523155, 47.4923025816679, 48.92854191362858, 54.66394655406475, 58.114784583449364, 61.50076389312744, 59.86082889139652, 54.51244868338108, 57.86717846989632, 59.383631497621536, 59.373254254460335, 56.91796660423279, 50.84985561668873, 43.91958989202976, 44.849726781249046, 44.854278936982155, 42.35468186438084, 43.73209275305271, 45.415353029966354, 52.54913583397865, 52.92607560753822, 57.00813576579094, 53.162495121359825, 55.6138613820076, 47.19347141683102, 43.87529946863651, 43.53603847324848, 50.38271248340607, 56.3984052836895, 62.487677335739136, 40.766230300068855, 44.53997500240803, 62.845089957118034, 53.38739365339279, 53.860266879200935, 45.86471691727638, 45.879657715559006, 43.809228613972664, 51.60434693098068, 55.57479947805405, 58.13159488141537, 54.762942641973495, 51.319765001535416, 43.386763483285904, 51.43904820084572, 59.25957955420017, 57.39926017820835, 49.72808361053467, 59.40233789384365, 54.140460044145584, 44.89280886948109, 42.5477647036314, 42.58047714829445, 47.52056926488876, 50.22977828979492, 54.51996088027954, 55.64122371375561, 58.42885673046112, 54.88264761865139, 55.531493201851845, 60.421321615576744, 57.72570826113224, 50.72315141558647, 45.25788947939873, 46.809619814157486, 48.49536135792732, 57.67780043184757, 58.86376239359379, 58.49762164056301, 60.62580764293671, 62.585666477680206, 60.81582024693489, 59.518208876252174, 59.08375158905983, 65.24400383234024, 67.75176286697388, 60.44301085174084, 62.96938508749008, 60.60225270688534, 66.60719588398933, 59.463123232126236, 72.85232037305832, 33.000909984111786, 0.5759204307105392, 2.7726577827706933, 3.623411706648767, 1.3357988465577364, 0.14499227836495265, 0.16897936700843275, 13.714788369834423, 43.92917677760124, 35.061680004000664, 30.243198461830616, 21.788177154958248, 27.9746175929904, 38.22296217083931, 56.97047978639603, 53.94951269030571, 64.90500882267952, 19.683722779154778, 0.3601202729623765, 0.07347326565650292, 0.02840885459590936, 0.039510224232799374, 0.03994684084318578, 0.0697972226771526, 0.04935229728289414, 0.024881131685106084, 0.04627518603228964, 0.009001069447549526, 0.036981534140068106, 0.01583101555297617, 0.03591619599319529, 0.06326059374259785, 0.053969754590070806, 0.04571884615870658, 0.05329895699105691, 0.057401612430112436, 0.033154668199131265, 0.1602666571852751, 0.14478487777523696, 0.23524663847638294, 0.06855588420876302, 0.13359090109588578, 0.200767659698613, 0.24455686623696238, 0.18596214009448886, 0.10042877431260422, 0.1379347508191131, 0.14376190141774714, 0.1504682149970904, 0.18928512115962803, 0.20413850928889588, 0.18077204906148836, 0.16781204292783514, 0.25767278275452554, 16.032018028199673, 86.1066247522831, 79.82658013701439, 75.77922731637955, 66.24724119901657, 47.25874051451683, 28.37194137275219, 49.57073025405407, 50.488605201244354, 57.27119565010071, 8.227817248553038, 0.38741958152968436, 0.3021577082108706, 0.9286824578884989, 4.728501420468092, 10.909154769033194, 7.294808188453317, 2.056145193055272, 64.54555571079254, 73.05629342794418, 69.72780883312225, 61.61676786839962, 62.204816713929176, 62.33907870948315, 64.10129114985466, 62.4857622385025, 60.23710370063782, 58.03003013134003, 52.54505105316639, 52.24824137985706, 59.83608841896057, 61.204493790864944, 61.0872358828783, 56.284437999129295, 54.09681558609009, 59.83288899064064, 62.58893430233002, 60.29905177652836, 57.714145481586456, 51.25558644533157, 47.6228179782629, 50.617095306515694, 52.3190163820982, 58.21709789335728, 61.67585849761963, 62.4752102047205, 59.024391174316406, 54.85077492892742, 59.415101408958435, 61.76144130527973, 62.88855202496052, 60.73003225028515, 52.44776487350464, 46.20335094630718, 48.514778316020966, 47.183204367756844, 45.57320795953274, 45.32258100807667, 47.97695517539978, 56.456105187535286, 56.44659049808979, 59.627756997942924, 56.98342189192772, 58.66263538599014, 50.56370057165623, 45.514569506049156, 46.84430055320263, 53.4267595410347, 60.49744673073292, 63.241572082042694, 44.717683866620064, 47.0008559525013, 64.19326901435852, 56.65126271545887, 56.03529296815395, 47.48654589056969, 48.40756706893444, 46.038838773965836, 53.85035701096058, 58.68061602115631, 60.440145805478096, 57.51458019018173, 53.58827747404575, 45.64362198114395, 52.86608822643757, 62.805214896798134, 60.63301205635071, 51.048676148056984, 61.93847380578518, 56.994908675551414, 47.56840869784355, 45.41661836206913, 43.87909546494484, 50.096857622265816, 54.74952936172485, 57.315106093883514, 58.29972445964813, 60.097772777080536, 56.645213440060616, 57.821265533566475, 60.93280076980591, 61.060576513409615, 54.96624693274498, 47.65149503946304, 49.41672831773758, 50.064992532134056, 61.76237605512142, 61.59637436270714, 62.073830142617226, 63.901999443769455, 65.43848499655724, 63.32273192703724, 60.70189096033573, 60.92907316982746, 69.60275754332542, 69.98515382409096, 63.76724347472191, 66.00454062223434, 62.170918732881546, 69.35876503586769, 62.14251905679703, 75.37939757108688, 32.55761057138443, 0.4884387640049681, 14.248431734740734, 14.06641960144043, 1.3328510359860957, 0.12905208917800337, 0.21836227417225018, 18.00654787570238, 53.548694998025894, 46.34926691651344, 51.21114023029804, 37.044744193553925, 33.59460912644863, 46.42903983592987, 67.47740998864174, 61.65727749466896, 71.33323028683662, 22.081608809530735, 0.5438362585846335, 0.30826861155219376, 0.13774958497378975, 0.30371479340828955, 0.0855013272666838, 0.20529970322968438, 0.1512989157345146, 0.09212044591549784, 0.11413469081162475, 0.12067002098774537, 0.1229213408078067, 0.06592058460228145, 0.1295030181063339, 0.1468650286551565, 0.12767349049681798, 0.2735998062416911, 0.11897833246621303, 0.13585207663709298, 0.11994518019491807], [0.04668694811698515, 0.0484129609685624, 0.025713422473927494, 0.05640979885356501, 0.05128569217049517, 0.04848832235438749, 0.04787895974004641, 0.0409372406284092, 0.04322621702158358, 0.017189553982461803, 0.032226590265054256, 0.011726067805284401, 0.015314448301069206, 0.05315150337992236, 0.04339911887655035, 0.1368490481399931, 0.12489646294852719, 22.314298823475838, 75.50593078136444, 63.14740173518658, 56.7975814640522, 37.20585934817791, 35.38880065083504, 34.15975660085678, 45.267252177000046, 29.854114539921284, 39.65480513870716, 1.840882587712258, 0.07647397651453502, 0.06696549884509295, 0.42131696885917336, 0.4623900930164382, 1.7446398083120584, 0.9040060476399958, 4.6159804333001375, 70.49827829003334, 66.13129422068596, 64.10594210028648, 58.16302679479122, 55.31096063554287, 52.781071588397026, 49.09804701805115, 48.46828021109104, 48.9837871491909, 46.70159161090851, 47.77302771806717, 47.80618853867054, 52.97898776829243, 53.98013524711132, 54.507041573524475, 49.369656443595886, 50.40749475359917, 57.07739844918251, 56.41125999391079, 55.265336483716965, 52.88390927016735, 47.783271968364716, 44.68674972653389, 43.94467994570732, 51.93800702691078, 57.14449144899845, 59.12738464772701, 62.89718136191368, 58.28530043363571, 56.18323042988777, 55.02055361866951, 52.9699632525444, 55.263261795043945, 55.83858512341976, 47.81386412680149, 43.92886519432068, 41.22997261583805, 40.59164486825466, 40.599195063114166, 41.391771733760834, 40.84076710045338, 47.29456879198551, 50.433090180158615, 51.88891366124153, 49.7688440233469, 48.53371649980545, 38.93794320523739, 42.019365057349205, 40.83207316696644, 50.22269167006016, 50.973694771528244, 65.84823220968246, 36.54580436646938, 38.34722310304642, 60.441156551241875, 50.26030205190182, 51.57053254544735, 46.70997396111488, 47.45784603059292, 43.11807610094547, 45.451086312532425, 49.440967217087746, 52.48507507145405, 51.301791965961456, 45.38173623383045, 42.427235171198845, 49.830871894955635, 53.93256939947605, 52.805663868784904, 51.73425056040287, 56.741348281502724, 48.98297779262066, 42.8286874294281, 41.51399977505207, 42.49242827296257, 44.01163995265961, 48.22114147245884, 55.19934542477131, 55.13317197561264, 56.28780461847782, 54.297437220811844, 53.284126594662666, 56.93824231624603, 55.51109589636326, 52.95887924730778, 42.01800473034382, 44.23023082315922, 42.9979607462883, 56.75293765962124, 55.72635434567928, 58.13129849731922, 56.94312505424023, 57.4892545491457, 60.84970682859421, 58.58200751245022, 63.540084064006805, 64.80125918984413, 56.84900790452957, 58.83046478033066, 54.75506566464901, 56.772776395082474, 59.67260219156742, 62.57637217640877, 60.947126001119614, 68.80158573389053, 20.736923664808273, 0.22046250756829977, 3.7071736995130777, 1.0866021621041, 0.10776806564535946, 0.04673052331781946, 1.916812607087195, 37.68132023513317, 26.8507556989789, 33.5041169822216, 26.826343908905983, 12.819298021495342, 28.115952908992767, 36.10444284975529, 43.71435910463333, 57.01912097632885, 37.351273745298386, 1.599872326478362, 0.05696950065612327, 0.014820758678979473, 0.03847195221169386, 0.04123265993257519, 0.022795863696956076, 0.035513094771886244, 0.020577634386427235, 0.046472886751871556, 0.05820490936457645, 0.0849795232352335, 0.018730336050793994, 0.0130330687170499, 0.09852400035015307, 0.043965559380012564, 0.01236846712345141, 0.08833351123030297, 0.06603244852158241, 0.030084536847425625, 0.03914877976058051, 0.03075452179473359, 0.04800640876055695, 0.01072210434358567, 0.03353704494656995, 0.09408471043570898, 0.04521505776210688, 0.031971035423339345, 0.06828937155660242, 0.05408737015386578, 0.021030192328908015, 0.028432720209821127, 0.0537400710163638, 0.017004185901896562, 0.013435691253107507, 0.0892264855792746, 0.02071713774057571, 30.377019681036472, 87.93062567710876, 67.97149747610092, 64.2501899600029, 45.12734368443489, 43.896000757813454, 32.58053474128246, 37.120728716254234, 35.92562444508076, 45.016906410455704, 1.7536586243659258, 0.10549473372520879, 0.13428918784484267, 0.8962367114145309, 2.519975141622126, 3.5744905192404985, 0.07256515891640447, 4.629467809572816, 74.53661799430847, 69.52869191765785, 67.58033886551857, 60.95958173274994, 59.777172580361366, 54.03146669268608, 52.152269929647446, 50.06187669932842, 50.33778749406338, 49.74587805569172, 49.95159521698952, 50.71990638971329, 55.30645027756691, 55.658508986234665, 57.256726026535034, 52.09354408085346, 54.22679141163826, 58.98616522550583, 61.228075325489044, 58.645049929618835, 55.0809171795845, 50.499324426054955, 47.608173564076424, 46.764436438679695, 52.73472547531128, 58.432527333498, 61.91389672458172, 64.58283931016922, 59.84019219875336, 57.14421406388283, 55.56383706629276, 54.92538392543793, 57.50080592930317, 57.47611865401268, 50.65180264413357, 46.700140088796616, 44.05338831245899, 44.25289660692215, 41.99117437005043, 43.37008997797966, 43.88389080762863, 49.147797748446465, 51.50459848344326, 52.56291389465332, 52.04043813049793, 51.22796192765236, 41.666804775595665, 44.58600953221321, 41.58352084457874, 52.75994472205639, 52.467861995100975, 66.65489852428436, 38.35633501410484, 40.303118750452995, 62.679133862257004, 53.135277181863785, 54.741067215800285, 46.144777089357376, 48.97269934415817, 44.98398497700691, 46.82868719100952, 51.531649231910706, 54.76010039448738, 51.68473161756992, 48.1878362596035, 43.28028179705143, 52.46868655085564, 55.95235101878643, 55.404314026236534, 52.33464494347572, 58.98756355047226, 52.11090534925461, 44.09179665148258, 43.23018528521061, 43.88285346329212, 45.655158162117004, 51.110795214772224, 56.175619438290596, 57.48100899159908, 60.63761740922928, 56.38295151293278, 54.603674188256264, 59.24334302544594, 58.754845038056374, 54.1444194316864, 43.702906519174576, 46.74971602857113, 46.3170712441206, 58.93240571022034, 59.82685871422291, 59.72937114536762, 59.26280938088894, 60.01109942793846, 62.914557829499245, 61.804732382297516, 64.70451638102531, 65.96759140491486, 58.132544830441475, 61.32365919649601, 58.05364206433296, 59.58201885223389, 61.476114615798, 64.54111754894257, 61.95268124341965, 72.76655897498131, 25.126159340143204, 0.1846803174703382, 0.48109301598742604, 4.365507373586297, 1.3543023099191487, 0.03843373902782332, 1.2585563538596034, 44.02205519378185, 31.800459399819374, 37.051055654883385, 27.122843898832798, 18.881526924669743, 38.191959634423256, 41.99312746524811, 50.14755070209503, 62.26142607629299, 45.81349566578865, 1.9351399736478925, 0.10179488264839165, 0.009371605228807312, 0.02997663785208715, 0.03578826828743331, 0.04677727491070982, 0.010589907433313783, 0.03756186764803715, 0.044544627526192926, 0.016164390144695062, 0.06273136823438108, 0.027907723087992053, 0.022220517421374097, 0.10476385927177034, 0.05593381130893249, 0.01752162424963899, 0.011117830472358037, 0.03508225949190091, 0.0654799937910866, 0.13773499435046688, 0.11571409981115721, 0.12399012251989916, 0.20179931918391958, 0.18678665132028982, 0.15110563079360873, 0.1939481240697205, 0.1324813606333919, 0.18640247115399688, 0.153314113849774, 0.11171662525157444, 0.17009995062835515, 0.09806186499190517, 0.1415617749444209, 0.25600458320695907, 0.18397622712654993, 0.412819585762918, 41.36362284421921, 96.93615764379501, 77.51644089818001, 72.57115066051483, 53.93966741859913, 50.23939177393913, 45.131892040371895, 60.34334599971771, 44.93441663682461, 54.54175651073456, 2.996728434227407, 0.14133117481833324, 0.35857877286616713, 2.4548454489558935, 3.326844032853842, 8.633049353957176, 3.835666417144239, 5.608096271753311, 77.47576788067818, 71.37245938181877, 71.54001519083977, 64.04732644557953, 62.08121694624424, 56.09899654984474, 55.05025662481785, 52.99095332622528, 54.338110238313675, 51.60672940313816, 51.93801462650299, 54.26766961812973, 57.80002847313881, 59.118192940950394, 59.38790246844292, 53.325722962617874, 56.31157994270325, 64.45677727460861, 63.39959800243378, 62.13336534798145, 56.88987851142883, 53.12804616987705, 50.48122599720955, 48.40237654745579, 56.40266105532646, 62.0720100402832, 63.84180307388306, 64.02753710746765, 62.1653064340353, 59.62904512882233, 58.3646135777235, 57.80930757522583, 59.19175699353218, 60.67349128425121, 52.599087953567505, 48.702085465192795, 47.34976842999458, 45.956421196460724, 46.091652140021324, 45.421588495373726, 46.78765319287777, 52.96201407909393, 54.885524064302444, 56.31134055554867, 54.760567769408226, 54.83135797083378, 44.53406251966953, 46.957591474056244, 44.03813973069191, 54.842871353030205, 55.05532555282116, 68.7569609284401, 42.019494250416756, 42.96187028288841, 64.60167109966278, 55.02604432404041, 54.97464448213577, 50.22557571530342, 51.65860801935196, 50.2168969810009, 49.499313086271286, 54.088589027523994, 58.409762755036354, 55.2426441013813, 49.84153412282467, 45.60114026069641, 55.7724154740572, 58.83002020418644, 57.99138620495796, 54.49299372732639, 61.665264666080475, 54.048330187797546, 46.20910003781319, 47.33144961297512, 45.781942158937454, 47.907886281609535, 51.7167828977108, 59.13944140076637, 58.75267535448074, 62.160275503993034, 59.50836360454559, 55.68346984684467, 62.12090201675892, 61.365510150790215, 56.602499932050705, 46.41079321503639, 49.94716465473175, 49.01083029806614, 61.60643242299557, 63.45100164413452, 63.09285946190357, 60.8585299551487, 63.695431128144264, 64.88540187478065, 62.6424278318882, 66.18565410375595, 69.16234597563744, 60.02600982785225, 64.08934459090233, 61.81256376206875, 62.92457029223442, 65.64412996172905, 68.48111093044281, 64.46583598852158, 77.330691665411, 25.579849295318127, 0.5268691596575081, 16.83959249407053, 6.810605870559812, 0.9082579601090401, 0.21907537418883294, 2.159372828900814, 50.63396260142326, 40.88875472545624, 51.57816253602505, 37.56134167313576, 21.985757052898407, 41.68472461402416, 49.067876636981964, 57.26247511804104, 70.45170798897743, 52.44632475078106, 2.2216742858290672, 0.1653433035244234, 0.1621977551258169, 0.09692909530713223, 0.0834633303747978, 0.16203188512008637, 0.12560110248159617, 0.11233271914534271, 0.11748403296223842, 0.1556734458426945, 0.12836619629524648, 0.13358015479752794, 0.12931014876812696, 0.1816080932621844, 0.12934171973029152, 0.11384975063265301, 0.11356027593137696, 0.17643861909164116, 0.24113697552820668], [0.035117960505886, 0.0391695190774044, 0.05434864324342925, 0.08896963568986394, 0.04565160757920239, 0.05107044336909894, 0.038211020510061644, 0.022828152686997782, 0.05662141484208405, 0.00931535507334047, 0.03588061001210008, 0.07626840902958065, 0.033403358174837194, 0.0038886360516698915, 0.03764356326428242, 0.04742203796922695, 1.1225126101635396, 40.386452078819275, 64.25548687577248, 65.22559002041817, 50.215494856238365, 26.002107337117195, 20.111218839883804, 35.31076043844223, 42.38272815942764, 44.4822409003973, 33.048741817474365, 0.05749795433075633, 0.038758666123612784, 0.29314613551832736, 0.4942228551954031, 1.359556952957064, 2.848795484751463, 0.4570330632850528, 20.05522884428501, 78.36084678769112, 62.42198646068573, 68.70418176054955, 58.25821168720722, 60.26273712515831, 54.2420019954443, 53.58972519636154, 49.58188645541668, 48.60638380050659, 45.30537933111191, 46.690765991806984, 47.38667204976082, 50.30371092259884, 53.659504652023315, 51.62062905728817, 51.05397306382656, 55.318966805934906, 55.94846002757549, 58.828454688191414, 57.11054027080536, 52.89014853537083, 49.0275190025568, 48.492112532258034, 47.39870600402355, 53.651950657367706, 57.36164979636669, 61.771810948848724, 55.06312653422356, 55.17284944653511, 58.69673855602741, 57.713750302791595, 54.759272038936615, 52.2758848965168, 56.310667991638184, 50.904511883854866, 43.476469069719315, 39.88245092332363, 42.53486819565296, 39.79289352893829, 40.28710260987282, 41.24246634542942, 45.04921607673168, 46.69881395995617, 49.88335847854614, 47.01851360499859, 42.4532637745142, 38.5524994879961, 43.66209290921688, 41.336625292897224, 52.25678712129593, 50.80547399818897, 63.896390944719315, 33.95744405686855, 37.15277619659901, 61.105030328035355, 50.014063864946365, 52.19907581806183, 47.33360409736633, 48.789423778653145, 42.84414879977703, 42.65239208936691, 43.09310004115105, 46.73399247229099, 45.85713632404804, 43.68710316717625, 40.56455232203007, 49.83294278383255, 54.259021282196045, 53.37103933095932, 53.110787495970726, 56.16732068359852, 49.126925468444824, 41.65332689881325, 41.05106681585312, 41.454209983348846, 45.310178473591805, 52.057161033153534, 54.90222416818142, 53.91782999038696, 54.89527054131031, 56.904150545597076, 54.87280614674091, 54.686262756586075, 56.74837030470371, 50.29991112649441, 41.54970645904541, 43.80869664251804, 46.20675556361675, 55.29653660953045, 55.646376237273216, 57.27004051208496, 54.5418781042099, 55.490812584757805, 57.90970578789711, 58.867797777056694, 61.22831851243973, 57.80098982155323, 58.79986882209778, 55.67501150071621, 54.53309677541256, 51.160754933953285, 58.43335568904877, 61.11005745828152, 62.55052216351032, 62.051388546824455, 57.88404196500778, 5.710486527532339, 0.2561313420301303, 3.3114444091916084, 0.7188147911801934, 0.1509384546079673, 0.17816369683714584, 16.749962903559208, 38.80336582660675, 25.006066784262657, 38.11065539717674, 14.97033504769206, 18.104001246392727, 40.83094842731953, 51.21955677866936, 48.38792972266674, 49.570487067103386, 6.432523783296347, 0.12843217322370037, 0.05295828523230739, 0.009747776693984633, 0.08908944058930501, 0.04913662916806061, 0.028938751747773495, 0.03946016637200955, 0.04616116617398802, 0.05835835210746154, 0.01091047348381835, 0.025356449441460427, 0.04459835159650538, 0.02073677496809978, 0.030806731883785687, 0.04482055432163179, 0.055249677316169254, 0.03089311416260898, 0.03391063837625552, 0.04215462628053501, 0.021214044572843704, 0.04107433385797776, 0.046946317597758025, 0.1141256291884929, 0.003361307194609253, 0.022100126225268468, 0.060490709365694784, 0.024281008809339255, 0.03208668058505282, 0.010365520938648842, 0.030172128826961853, 0.030899956764187664, 0.04108716930204537, 0.034283445129403844, 0.06568234777660109, 2.3756847716867924, 55.462515503168106, 71.00350677967072, 73.87099251151085, 57.93266415596008, 38.224991261959076, 29.575570486485958, 37.56599262356758, 39.05532270669937, 47.98354782164097, 36.49908967316151, 0.10163457875023596, 0.04841060836042743, 0.525719424476847, 1.4431777596473694, 3.577244896441698, 0.6895444868132472, 0.35245258128270507, 21.251573748886585, 81.10110014677048, 65.37214055657387, 71.57339259982109, 61.89887993037701, 63.004202619194984, 58.11612211167812, 55.6878662109375, 52.9023002833128, 49.39227283000946, 47.20946855843067, 49.79519560933113, 48.71960252523422, 52.536892890930176, 57.50562407076359, 54.852218851447105, 53.295693174004555, 57.64064982533455, 57.538317516446114, 60.04894159734249, 57.272734567523, 55.182671919465065, 52.64095790684223, 50.03197990357876, 50.24470008909702, 55.761316269636154, 60.103388875722885, 64.27915200591087, 58.02928537130356, 56.78558170795441, 60.9412857145071, 59.06765565276146, 55.73697477579117, 53.00540015101433, 59.9103744328022, 52.69947476685047, 45.911830589175224, 41.77982211112976, 43.910778164863586, 41.92187748849392, 42.205756455659866, 44.748469814658165, 46.97559870779514, 48.83776478469372, 51.10949568450451, 48.52748863399029, 45.516051426529884, 40.83792865276337, 46.79899178445339, 41.88889905810356, 54.20021563768387, 53.88608269393444, 64.10922512412071, 34.37514044344425, 40.96678353846073, 63.8693667948246, 52.05771200358868, 53.09995427727699, 48.34589257836342, 50.472125485539436, 44.529932141304016, 43.945926278829575, 45.69121442735195, 49.854358434677124, 47.32776381075382, 45.784651413559914, 41.96003504097462, 52.18739524483681, 56.32527440786362, 55.440510883927345, 54.06902387738228, 57.87375971674919, 50.75534328818321, 42.85084784030914, 43.13240893185139, 43.618087470531464, 48.39628167450428, 53.67436945438385, 58.17049719393253, 58.24780024588108, 57.77859382331371, 57.95290566980839, 55.15233814716339, 55.594676211476326, 58.28629218041897, 52.622574493288994, 43.33447068929672, 46.216266453266144, 47.398649007081985, 56.21409997344017, 57.529228404164314, 60.24357855319977, 56.51971377432346, 57.13917933404446, 59.0339894592762, 61.33849360048771, 62.813122272491455, 59.64084729552269, 60.90630479156971, 56.44214853644371, 56.592346876859665, 52.315634563565254, 58.52356284856796, 62.146641835570335, 66.09161674976349, 62.45114989578724, 62.23115310072899, 7.6212880946695805, 0.7250135648064315, 2.4743925500661135, 1.314929653890431, 0.3004919132217765, 0.21395437710452825, 17.995283380150795, 43.548574000597, 28.717156648635864, 32.561182379722595, 20.28738498687744, 25.870659090578556, 43.480816036462784, 59.999475851655006, 53.53306643664837, 60.82365922629833, 9.178968910127878, 0.12834771681809798, 0.029894381914346013, 0.021353156444092747, 0.011829281993414043, 0.05726557305024471, 0.04522286886640359, 0.017492162842245307, 0.05327944963937625, 0.022340390969475266, 0.02815456326061394, 0.029571018894785084, 0.0728368666023016, 0.03870277127134614, 0.03827067805104889, 0.045287439425010234, 0.05443575653771404, 0.05124155664816499, 0.038166955491760746, 0.21835023653693497, 0.11869247202412225, 0.1021586982824374, 0.18815607705619186, 0.25930057978257537, 0.17430350475478917, 0.10041674409876578, 0.05567159940255806, 0.20126408227952197, 0.12641747976886109, 0.10763902100734413, 0.21860856330022216, 0.11750355144613422, 0.12805243110051379, 0.20015719870571047, 0.2080684929387644, 4.473373610526323, 70.39339631795883, 78.97572979331017, 83.06807979941368, 65.49580872058868, 40.17769508063793, 28.901878036558628, 45.50241015851498, 59.28917996585369, 63.84343698620796, 40.88254205882549, 0.39635886903852224, 0.16647651849780232, 0.9026631165761501, 2.637547245249152, 5.545352613553405, 10.41821826249361, 0.9312144876457751, 23.775210231542587, 83.13907518982887, 67.8506563603878, 73.39385211467743, 65.07542967796326, 66.76180198788643, 60.5682597309351, 59.35055047273636, 56.07052467763424, 53.9562763273716, 51.2291094660759, 49.98143881559372, 50.11391870677471, 56.31062239408493, 60.1156622171402, 56.463134810328484, 56.0480222851038, 60.556510761380196, 62.09101282060146, 60.81730976700783, 62.39148169755936, 58.18828023970127, 54.187144339084625, 53.034483790397644, 52.13995099067688, 59.18403200805187, 63.027955144643784, 65.57534605264664, 58.98276440799236, 60.27789071202278, 63.00688527524471, 62.32233300805092, 58.30862358212471, 55.2512164413929, 61.60175487399101, 55.478113666176796, 49.368189722299576, 44.55267772078514, 45.34057304263115, 45.17190769314766, 43.09066817164421, 47.4986482411623, 49.72657889127731, 51.96879677474499, 54.2294854670763, 52.00725831091404, 47.34246142208576, 42.65467956662178, 49.39228042960167, 45.87960071861744, 54.865544736385345, 57.74870082736015, 67.55385428667068, 38.502467572689056, 42.28223115205765, 66.16020306944847, 54.43807527422905, 56.14083990454674, 51.31489746272564, 53.09067137539387, 46.57144099473953, 45.315289199352264, 48.74011382460594, 50.57922653853893, 50.00012621283531, 46.96066550910473, 45.99025458097458, 54.03210885822773, 59.8253083974123, 57.35923692584038, 55.628813579678535, 60.472618862986565, 54.12441350519657, 46.620348170399666, 45.04569746553898, 45.81494718790054, 50.715574622154236, 57.35709384083748, 59.65451896190643, 58.15687492489815, 59.275120720267296, 60.89629612863064, 56.522271037101746, 58.534977436065674, 61.19130849838257, 54.73110415041447, 46.49866729974747, 47.98910692334175, 49.96742896735668, 59.46416437625885, 60.14949560165405, 63.67903120815754, 59.41883660852909, 60.31080834567547, 63.18641044199467, 62.97636531293392, 65.58076456189156, 61.60290241241455, 63.09480495750904, 59.4443104416132, 61.84290513396263, 55.553034245967865, 64.25094991922379, 64.71395507454872, 68.0487397313118, 63.272658213973045, 66.3202352821827, 7.617423702031374, 2.2009808337315917, 13.23914224281907, 1.6042442293837667, 0.32425275072455406, 0.16846305486978963, 22.089920863509178, 54.24245037138462, 38.40486980974674, 52.76808388531208, 23.279990404844284, 28.330890275537968, 53.57358746230602, 67.36740589141846, 63.19472819566727, 67.29004964232445, 11.518188938498497, 0.346009552013129, 0.12961080763489008, 0.10688189679058269, 0.11449130019173026, 0.14592925464967266, 0.10908316617133096, 0.14448916161200032, 0.15358541335444897, 0.16379316482925788, 0.10024674775195308, 0.12945252237841487, 0.17578147700987756, 0.12907754484331235, 0.18858408846426755, 0.11948719344218262, 0.09877633056021295, 0.1142656353476923, 0.13846688554622233], [0.024548901856178418, 0.02041322641161969, 0.059814501510118134, 0.03642582880274858, 0.03916677684173919, 0.038548419397557154, 0.03954520165279973, 0.04553683815174736, 0.029987246853124816, 0.028185484843561426, 0.03491885341645684, 0.01846247640060028, 0.0358158910239581, 0.040346583846258, 0.09887667634757236, 0.10562675437540747, 12.153550945222378, 70.94194248318672, 62.04105690121651, 58.124854043126106, 41.44166685640812, 22.241297140717506, 22.53308728337288, 49.00987654924393, 32.78161995112896, 55.1670927554369, 12.845270577818155, 0.20716136583359912, 0.10204639649600722, 0.24129714583978057, 0.3906402946449816, 2.383591909892857, 1.6644223127514124, 2.004019352607429, 58.65081422030926, 61.715471372008324, 56.97411999106407, 60.26312470436096, 67.55260035395622, 63.416852876544, 64.82941567897797, 62.153021693229675, 58.943440318107605, 56.69740743935108, 50.34570626914501, 45.19740052521229, 46.29128962755203, 46.073036938905716, 50.044899210333824, 49.81254927814007, 52.17047095298767, 55.47512702643871, 59.83536645770073, 54.33385826647282, 59.2984514683485, 53.54457601904869, 53.81974205374718, 50.278195291757584, 53.100710436701775, 53.90403293073177, 59.773235991597176, 54.26741503179073, 54.020280092954636, 55.03122344613075, 53.92124980688095, 52.63985596597195, 57.216379791498184, 52.57058948278427, 53.846845999360085, 52.54759691655636, 42.1924951672554, 41.53317354619503, 40.74142903089523, 39.18830417096615, 40.75899548828602, 40.38934372365475, 43.80818746984005, 44.085625782608986, 46.32508881390095, 41.310471296310425, 40.30870445072651, 40.16096457839012, 44.194239154458046, 45.045925453305244, 54.463290721178055, 50.681137070059776, 64.69934865832329, 31.585983708500862, 36.75148352980614, 61.40405908226967, 49.58343677222729, 53.67840863764286, 48.53411927819252, 50.90033210813999, 45.44859364628792, 45.03730371594429, 39.61466409265995, 43.028404712677, 42.368383929133415, 43.36152523756027, 41.769938841462135, 48.16544786095619, 53.055055886507034, 53.555143252015114, 54.94223602116108, 54.45123016834259, 46.05311080813408, 41.506149396300316, 41.41305059194565, 42.035726979374886, 43.724291771650314, 54.8287209123373, 55.85075967013836, 56.28632269799709, 55.953323766589165, 56.57945416867733, 55.80887831747532, 53.7912929803133, 57.35353723168373, 47.42658510804176, 43.04994955658913, 43.940842151641846, 44.257479161024094, 52.137975096702576, 55.60489006340504, 55.38390912115574, 53.61633516848087, 52.98969939351082, 54.93130400776863, 58.086985275149345, 56.90560206770897, 59.251178205013275, 54.07968610525131, 52.62696325778961, 49.41079683601856, 48.9054923504591, 52.93011859059334, 54.91477869451046, 61.456393674016, 62.10144326090813, 70.34442454576492, 35.411702021956444, 0.42238910507876426, 4.657617174088955, 2.6527029694989324, 0.27509514475241303, 0.08665541143273003, 3.118165167979896, 40.44648125767708, 30.278492867946625, 37.67090879380703, 19.623129330575466, 26.19604893028736, 43.89885440468788, 41.984019353985786, 46.94291666150093, 55.59301570057869, 27.60017428547144, 0.47530830139294267, 0.1011284785636235, 0.11734476895071566, 0.04431142246176023, 0.0355635867890669, 0.024818305173539557, 0.04407251028169412, 0.04222222480166238, 0.015931489360809792, 0.017987880382861476, 0.02532125679863384, 0.018750331364572048, 0.03663354480522685, 0.021664329688064754, 0.05765799476648681, 0.055205460157594644, 0.09037977564730681, 0.11071255881688558, 0.009233818091161083, 0.08796374357189052, 0.02071571838314412, 0.028622502213693224, 0.06729666740284301, 0.03567747677152511, 0.04640831990400329, 0.02089929603243945, 0.0010505031946195231, 0.13347488857107237, 0.057390502479393035, 0.029533358610933647, 0.04870840253715869, 0.032055165283964016, 0.05355293847969733, 0.08258921399828978, 16.845480278134346, 79.57578599452972, 68.2812188565731, 65.34188657999039, 48.9578041434288, 28.790285624563694, 24.412620328366756, 41.23650446534157, 31.622372455894947, 64.77374106645584, 14.20442819595337, 0.28379801369737834, 0.10734484108979814, 0.7622104813344777, 2.8507074946537614, 3.664452829398215, 0.45285637490451336, 1.7721420200541615, 61.18640296161175, 63.44054460525513, 62.57286496460438, 63.365878611803055, 71.59097045660019, 66.42531484365463, 67.45520398020744, 63.63785281777382, 62.42435373365879, 59.08839114010334, 52.045165076851845, 46.349244117736816, 48.68572734296322, 47.62023411691189, 53.188573122024536, 52.934378162026405, 55.15155918896198, 58.199508637189865, 61.5976282954216, 56.199740543961525, 58.96273948252201, 56.67776629328728, 57.242552787065506, 53.413490653038025, 54.16629485785961, 57.167613208293915, 61.83264568448067, 56.02453574538231, 56.73222877085209, 58.632385209202766, 57.82201409339905, 54.571862295269966, 59.5683965831995, 54.62146483361721, 58.16209204494953, 55.17727620899677, 45.534685626626015, 43.24617102742195, 42.664426043629646, 41.415885239839554, 44.22568626701832, 42.99488291144371, 45.02364344894886, 46.60338208079338, 49.05920930206776, 42.719572484493256, 43.08246821165085, 42.90292404592037, 45.47960378229618, 46.4972385764122, 56.40753239393234, 53.006650283932686, 65.49073219299316, 34.96452681720257, 37.579151317477226, 63.51051785051823, 51.31634518504143, 55.66568300127983, 51.34703993797302, 53.95930856466293, 47.02695295214653, 46.632815301418304, 41.86833456158638, 45.02909615635872, 44.27382968366146, 44.458704963326454, 42.221867591142654, 49.94282528758049, 55.594718009233475, 56.28372743725777, 57.08687514066696, 55.36502793431282, 47.388625144958496, 43.92821162939072, 42.87711963057518, 44.01925474405289, 46.830868273973465, 55.917814671993256, 56.379125118255615, 57.86027044057846, 58.73363837599754, 58.372323364019394, 57.4311176687479, 58.46290670335293, 59.1844841837883, 48.953381180763245, 43.7097043544054, 45.81470400094986, 46.38557396829128, 53.04041147232056, 58.63749213516712, 58.0693656206131, 55.945408791303635, 54.439382404088974, 56.88446380198002, 61.67426638305187, 58.689347952604294, 62.54992939531803, 55.509515181183815, 54.69098970293999, 51.479056254029274, 51.80065959692001, 53.762851506471634, 57.83984653651714, 63.37916649878025, 64.60029557347298, 71.11888378858566, 40.936662554740906, 0.40915545425377786, 1.3970477599650621, 5.377992019057274, 0.9671987348701805, 0.0715069379657507, 2.635666821151972, 47.11302973330021, 33.04342970252037, 40.70809721946716, 21.62251364439726, 28.883164040744305, 49.4375815987587, 47.841215059161186, 54.06485930085182, 61.98413595557213, 36.48299753665924, 0.703676106641069, 0.0745981908403337, 0.06082404499466065, 0.09139932328253053, 0.054753432850702666, 0.07079757095198147, 0.06596875740797259, 0.07481823762645945, 0.07182161600212567, 0.016027040874178056, 0.036051860588486306, 0.03383731789654121, 0.03518033801810816, 0.02500897960999282, 0.0558665282005677, 0.06409862689906731, 0.033877045061672106, 0.04499032802414149, 0.058712645986815915, 0.1350872340844944, 0.12564166827360168, 0.18264855461893603, 0.15614318079315126, 0.10101731226313859, 0.10730323629104532, 0.13191047095460817, 0.1256733579793945, 0.2846801304258406, 0.1590361911803484, 0.137509930646047, 0.14984187204390764, 0.16742323176003993, 0.19627759204013273, 0.16253871261142194, 21.20821427553892, 89.64317858219147, 76.35513201355934, 73.99379432201385, 55.248974561691284, 33.60766522586346, 32.74285443127155, 65.5194054543972, 50.0694914907217, 74.47749316692352, 15.678862128406763, 0.3282667603343725, 0.27072454802691936, 1.0582782444544137, 3.8722083438187838, 7.578107211738825, 6.762112397700548, 2.4744433723390102, 61.3151590526104, 63.28508734703064, 63.89401987195015, 68.43044444918633, 73.71120348572731, 67.69905969500542, 70.56251004338264, 66.40248566865921, 64.98942509293556, 61.27486601471901, 54.4934269040823, 50.28364039957523, 49.827870056033134, 51.691130474209785, 55.74110135436058, 55.61241365969181, 58.876810893416405, 61.82078652083874, 65.31733229756355, 60.34339539706707, 61.219157204031944, 59.05416637659073, 59.79158900678158, 56.18244767189026, 58.330468609929085, 60.06810776889324, 64.46961298584938, 57.945796251297, 61.430106684565544, 59.75254990160465, 61.361360773444176, 57.86797642707825, 62.371380776166916, 55.101474076509476, 61.26462556421757, 58.26963767409325, 47.141786590218544, 46.20750792324543, 44.51633647084236, 44.160151183605194, 46.04397609829903, 44.4533434510231, 48.26497972011566, 50.30679255723953, 51.5973325073719, 46.015660017728806, 46.55653819441795, 45.62161736190319, 47.13379181921482, 48.53188119828701, 61.76054835319519, 55.09816825389862, 67.42770865559578, 37.727347165346146, 40.71019470691681, 65.23014977574348, 54.62251357734203, 58.07270564138889, 52.87388540804386, 56.822223141789436, 51.69896945357323, 49.343107268214226, 44.85572285950184, 47.018502205610275, 47.16631427407265, 46.660325825214386, 46.38454422354698, 52.24976509809494, 57.78030753135681, 58.677693977952, 59.847795590758324, 59.57760348916054, 49.457971304655075, 46.81927889585495, 44.86253209412098, 46.62098653614521, 47.673165276646614, 57.770732045173645, 60.192725881934166, 61.15678355097771, 60.434400513768196, 61.10828675329685, 61.20067119598389, 59.39784653484821, 62.16098226606846, 50.554026290774345, 46.88612870872021, 49.61568184196949, 48.45738999545574, 56.52627222239971, 60.33341333270073, 59.96389836072922, 58.5213627666235, 57.90705733001232, 59.74124550819397, 64.77776125073433, 63.20346012711525, 66.26579940319061, 58.158261850476265, 58.11769902706146, 55.052380710840225, 55.946138352155685, 58.46912316977978, 60.234307050704956, 67.15895667672157, 67.53015875816345, 73.40624704957008, 41.90730147063732, 0.7154900289606303, 11.878367811441422, 8.679784946143627, 0.6951332744210958, 0.15690259082475677, 4.313645381480455, 51.07400178909302, 44.00521829724312, 53.62265042960644, 26.68270591646433, 37.85161189734936, 57.135147750377655, 57.45554655790329, 62.37022563815117, 71.52141898870468, 43.84872369468212, 0.819455300224945, 0.15372030611615628, 0.12531549436971545, 0.15517087827902287, 0.13694741239305586, 0.1923442241968587, 0.17166806414024904, 0.10676076344680041, 0.14595594228012487, 0.10713925134041347, 0.21429328626254573, 0.13041832367889583, 0.15279125596862286, 0.12035451174597256, 0.27283563162200153, 0.15029517584480345, 0.19674541224958375, 0.22066296165576205], [0.00690310377649439, 0.010268030564475339, 0.05558741759159602, 0.02509139882022282, 0.035902284434996545, 0.008680300234118477, 0.004746393869936583, 0.041508189679007046, 0.04630109811841976, 0.020573276124196127, 0.034363007071078755, 0.029900430417910684, 0.03911058884114027, 0.053269352720235474, 0.023355921730399132, 0.09780977969057858, 34.113969057798386, 67.82636046409607, 59.39715877175331, 50.079826936125755, 26.13107241690159, 20.39170078933239, 23.938143588602543, 36.584744676947594, 37.542319893836975, 43.083330765366554, 1.3541612424887717, 0.05008648171497043, 0.054129609488882124, 0.288263694383204, 1.9785765116102993, 1.7605781718157232, 0.2032641405821778, 30.433154068887234, 67.20523059368134, 62.65259988605976, 74.2613835632801, 55.34541718661785, 54.08562898635864, 62.49655745923519, 63.11954163014889, 61.91966861486435, 61.508914455771446, 57.179859951138496, 59.38305772840977, 49.435495510697365, 42.99960985779762, 43.79100859165192, 47.72061713039875, 50.795503333210945, 52.64860309660435, 53.98934595286846, 61.09643138945103, 58.61958369612694, 54.92354482412338, 56.74246162176132, 56.13091103732586, 52.49919131398201, 52.28671431541443, 55.620906203985214, 58.45485493540764, 53.2586869597435, 58.2708004117012, 51.51375599205494, 49.94513936340809, 49.87836554646492, 53.815444484353065, 54.803665056824684, 54.96057763695717, 51.531056463718414, 43.2629357278347, 40.53231865167618, 40.10267570614815, 40.463705733418465, 40.41401959955692, 37.69193306565285, 42.86340616643429, 40.229919478297234, 42.888313829898834, 39.30577486753464, 42.810623198747635, 43.15538629889488, 46.10682472586632, 47.674084827303886, 56.301312893629074, 51.90456502139568, 61.8072896450758, 30.706237815320492, 37.55543678998947, 61.81230537593365, 51.95633724331856, 54.95821416378021, 48.93639229238033, 52.05597169697285, 48.81448343396187, 47.76625648140907, 42.36034736037254, 42.79429167509079, 40.893124490976334, 43.19678507745266, 39.189656898379326, 45.01479372382164, 53.97421516478062, 56.351812183856964, 53.52241560816765, 51.45906552672386, 42.20545247197151, 40.75459152460098, 41.347610503435135, 42.2490019351244, 44.0560557693243, 52.69192077219486, 57.105117961764336, 55.51374435424805, 56.14478789269924, 54.48621869087219, 51.9431671500206, 53.87925446033478, 49.58369895815849, 46.05922468006611, 42.67952263355255, 44.781828224658966, 41.16344578564167, 49.715141505002975, 52.143849581480026, 52.8238382935524, 51.63551665842533, 52.16755650937557, 51.30902677774429, 54.02457006275654, 53.610954657197, 53.36923062801361, 51.61358043551445, 46.99996680021286, 47.9894907027483, 47.81409591436386, 49.54879783093929, 55.837217196822166, 60.16038581728935, 60.07170617580414, 60.66432237625122, 64.09371435642242, 7.042543524876237, 1.0141402878798544, 3.421954591758549, 0.5739915592130274, 0.31260527728591114, 0.07677303234231658, 23.860633447766304, 44.29681845009327, 32.0184651017189, 38.45540709793568, 16.50899313390255, 31.342724561691284, 38.563461899757385, 47.14101143181324, 46.80496126413345, 41.351049318909645, 4.754462577402592, 0.1214771882223431, 0.023634394092368893, 0.03243523395212833, 0.02980547447805293, 0.04433011716173496, 0.15166737721301615, 0.045712100036325864, 0.03681455462356098, 0.07509464310714975, 0.048010579630499706, 0.016956493636826053, 0.053852324563195, 0.03288117193733342, 0.11244053835980594, 0.03082350256590871, 0.12929552845889702, 0.04518671143159736, 0.029954126657685265, 0.050536553462734446, 0.013730517766816774, 0.07128617871785536, 0.026528354428592138, 0.011511683605931466, 0.119739189685788, 0.06345295842038468, 0.045910331391496584, 0.013579207770817447, 0.08271606187918223, 0.030379588788491674, 0.02773281743429834, 0.034088323372998275, 0.03128737269435078, 0.22216808167286217, 40.8921517431736, 77.09192767739296, 65.38341835141182, 57.99728348851204, 30.97821582108736, 25.123520381748676, 30.571698434650898, 39.466814026236534, 40.08818708360195, 50.80931179225445, 1.1281644506379962, 0.10121905026608147, 0.4587715590605512, 1.4955911971628666, 2.156998668797314, 0.6660571752581745, 0.16475293989060447, 34.48842756450176, 68.5616210103035, 61.35403856635094, 74.38716441392899, 58.90885077416897, 55.558186769485474, 65.06387069821358, 64.97373193502426, 65.15582576394081, 65.68503096699715, 60.69440536201, 61.77904576063156, 50.79094737768173, 45.5643430352211, 45.749305710196495, 50.184967294335365, 52.67090030014515, 54.98303823173046, 56.467242389917374, 63.639874309301376, 59.60314191877842, 57.094208747148514, 58.16902667284012, 57.72046074271202, 55.282667353749275, 55.37894658744335, 57.38582789897919, 60.218047723174095, 55.782386139035225, 58.68851579725742, 55.6017742305994, 52.46223829686642, 53.16344887018204, 56.23157523572445, 57.013071700930595, 55.951446667313576, 53.521059080958366, 45.27908854186535, 42.056914642453194, 42.68305644392967, 41.666565388441086, 42.685013338923454, 39.680020585656166, 44.73413698375225, 44.6514306217432, 44.438125267624855, 41.838593557477, 44.41238544881344, 45.687220841646194, 48.40355068445206, 50.38786120712757, 57.34389714896679, 52.94372946023941, 65.31024187803268, 31.994499787688255, 39.65323202311993, 63.431744277477264, 53.581529036164284, 57.97017574310303, 50.825464725494385, 54.331471994519234, 50.2890969067812, 50.65340995788574, 44.47880208492279, 42.408266589045525, 42.95899763703346, 45.52401959896088, 41.764828115701675, 46.288994550704956, 56.80919364094734, 58.56436885893345, 54.88697558641434, 54.19298842549324, 44.05569478869438, 41.157240718603134, 41.99289567768574, 44.877784475684166, 45.19683435559273, 54.269508719444275, 59.028833135962486, 58.13973784446716, 57.56970763206482, 56.93951524794102, 53.397592306137085, 56.53791479766369, 52.428477108478546, 48.199497833848, 44.964058846235275, 45.99564269185066, 42.96022117137909, 51.26787878572941, 53.68093550205231, 55.11908993124962, 53.910131603479385, 53.90378974378109, 53.606242910027504, 55.70597603917122, 57.4439761787653, 54.65741470456123, 53.91376420855522, 49.67321835458279, 51.270774230360985, 50.310953333973885, 51.726973950862885, 56.7954345792532, 62.69640773534775, 62.389627397060394, 61.21715851128101, 66.53351783752441, 9.694798830896616, 0.9691045107319951, 5.457887006923556, 1.0853481106460094, 0.4929787485161796, 0.02951136506453622, 25.19953530281782, 52.153136283159256, 25.01699309796095, 30.066770128905773, 22.430171705782413, 38.616172671318054, 43.321498185396194, 53.42955619096756, 53.00290748476982, 51.89169131219387, 7.156334118917584, 0.14134779892629012, 0.05102574381453451, 0.08764788552070968, 0.025448147353017703, 0.07245539527502842, 0.02360273036174476, 0.015550056068605045, 0.037189083159319125, 0.08332304219948128, 0.02649644393386552, 0.043666870915330946, 0.04887900002358947, 0.019537911466613878, 0.024609900829091202, 0.019474700893624686, 0.0764898287889082, 0.06127198306785431, 0.10772360357805155, 0.10958204526104964, 0.17242419387912378, 0.16473112074891105, 0.10336857711081393, 0.16028334066504613, 0.18619487760588527, 0.2902966149849817, 0.10692966883652844, 0.11182926842593588, 0.2204103791154921, 0.16901825554668903, 0.20607818645657972, 0.1440129106049426, 0.11614325412665494, 0.34334999159909785, 49.393819347023964, 86.50771602988243, 74.73161593079567, 67.76118636131287, 37.84776650369167, 30.455914847552776, 35.09576037526131, 51.34271577000618, 51.53372772037983, 56.91271908581257, 1.9500246061943471, 0.19571446522604674, 0.6416733493097126, 2.5007842713966966, 6.057124827057123, 7.363370759412646, 1.6838637320324779, 34.237880408763885, 70.89618533849716, 62.448436841368675, 71.7999592423439, 58.645125925540924, 59.51839126646519, 67.67050802707672, 67.04077541828156, 69.19972077012062, 66.35685011744499, 62.0166128128767, 63.26118662953377, 52.570068910717964, 48.193490356206894, 48.382427617907524, 52.843164056539536, 56.5410116314888, 57.571409940719604, 59.15239870548248, 65.6366291642189, 60.593718364834785, 61.423985213041306, 61.44836090505123, 59.40815158188343, 56.762425750494, 57.42491640150547, 60.59556506574154, 62.70681917667389, 59.043538346886635, 61.51147931814194, 56.84751458466053, 53.84087651968002, 55.98288618028164, 57.559413984417915, 58.719423338770866, 58.891132324934006, 57.89471939206123, 48.603298366069794, 45.26334598660469, 45.37906497716904, 45.03452606499195, 46.54983535408974, 41.92962147295475, 47.56362475454807, 46.940074414014816, 47.62378692626953, 44.773081094026566, 48.26664783060551, 49.17334757745266, 50.9908090531826, 54.8934580385685, 59.52383637428284, 56.06451719999313, 65.58162331581116, 34.78566661477089, 42.67804071307182, 65.42889431118965, 55.22128164768219, 60.49019291996956, 54.02878783643246, 56.797440871596336, 54.299128130078316, 54.03175927698612, 46.75411619246006, 46.18384659290314, 44.80806581676006, 47.93909780681133, 42.564233019948006, 49.22173798084259, 58.86065416038036, 61.14282310009003, 56.62587247788906, 57.47717499732971, 46.52284920215607, 44.470993503928185, 44.25707258284092, 48.046597838401794, 47.84769371151924, 57.09135890007019, 61.21563099324703, 59.525747671723366, 60.79066939651966, 59.528259336948395, 56.74833610653877, 59.24745820462704, 55.079469457268715, 50.24435430765152, 47.106148302555084, 48.867638781666756, 44.64044541120529, 55.10164126753807, 57.44879052042961, 56.95235475897789, 56.09225191175938, 57.29383483529091, 57.7903313934803, 57.69182167947292, 59.67315316200256, 57.616198137402534, 55.97277112305164, 52.54091687500477, 53.83866883814335, 53.06169793009758, 54.47974383831024, 60.990242287516594, 64.80553016066551, 65.62040403485298, 62.96169430017471, 70.33003851771355, 9.693587645888329, 1.9699648674577475, 12.778911888599396, 1.1935924272984266, 0.8272908360231668, 0.15465279982890934, 30.103525556623936, 60.20975276827812, 42.51351334154606, 50.96084006130695, 24.14162077009678, 43.35684008896351, 50.21590903401375, 60.11791929602623, 62.00148582458496, 59.911620765924454, 7.430072380229831, 0.27133251540362835, 0.16824222140712664, 0.20299177238484845, 0.1627847197232768, 0.17814364400692284, 0.19525994430296123, 0.09917837422108278, 0.3033726039575413, 0.23683327599428594, 0.11172225073096342, 0.08892555953934789, 0.19773853942751884, 0.12716216559056193, 0.19182654650649056, 0.0786302717460785, 0.2269774064188823, 0.1282316300785169], [0.04459566502191592, 0.08013577767997049, 0.012844582688558148, 0.056867611201596446, 0.007646483418284333, 0.13040107616689056, 0.033059877387131564, 0.028846977766079362, 0.048516316164750606, 0.030509588941640686, 0.07317644369322807, 0.017816984181990847, 0.03817511169472709, 0.07976733104442246, 0.020295189679018222, 1.2226700107567012, 53.66702064871788, 61.83120176196098, 56.809976398944855, 39.61366854608059, 33.784519135951996, 18.30766461789608, 39.38766807317734, 36.50082617998123, 43.4186589717865, 29.531116671860218, 0.14461413928074762, 0.04889360920060426, 0.19423156511038542, 1.18859498295933, 2.1824760641902685, 2.621535141952336, 9.7248419187963, 69.6883973479271, 61.40737630426884, 70.8036071062088, 61.64808578789234, 76.44031584262848, 60.12417376041412, 53.46008375287056, 62.34214134514332, 64.58215534687042, 61.3641270250082, 59.47796903550625, 56.42866685986519, 54.18905943632126, 45.9646325558424, 45.101372078061104, 43.40700499713421, 50.78750476241112, 53.05767394602299, 56.52176186442375, 56.55528366565704, 60.60156874358654, 63.23347091674805, 58.213966861367226, 57.09592625498772, 56.697582229971886, 55.48203505575657, 58.42328242957592, 55.105984434485435, 56.6550587117672, 53.750916346907616, 47.626807764172554, 43.571327179670334, 50.61226196587086, 55.272917076945305, 55.708012729883194, 55.364321172237396, 51.499483957886696, 42.54329614341259, 41.70153871178627, 41.69615060091019, 39.08380977809429, 41.62045866250992, 38.63592401146889, 40.34943826496601, 40.05242720246315, 41.15140423178673, 41.2773484736681, 42.832137644290924, 45.39931409060955, 49.94329646229744, 51.360540613532066, 54.95021939277649, 50.71286916732788, 59.68670703470707, 33.024932295084, 35.669328197836876, 59.85168658196926, 50.22653706371784, 54.370670691132545, 49.34442199766636, 51.99898235499859, 51.73316761851311, 51.506069004535675, 47.66616225242615, 43.40512789785862, 40.37448272109032, 43.48847262561321, 40.87570242583752, 41.904295831918716, 49.28932495415211, 53.86930659413338, 52.030003890395164, 48.360183611512184, 42.44288273155689, 41.8331940472126, 39.65879112482071, 42.22497962415218, 42.602341175079346, 51.24762587249279, 55.60771331191063, 58.441449254751205, 52.87864275276661, 52.76183322072029, 47.732841074466705, 47.508839294314384, 45.329249650239944, 43.018871024250984, 42.74882331490517, 43.62286761403084, 41.84630714356899, 44.31393273174763, 48.20632226765156, 49.451925829052925, 49.11235325038433, 47.63458974659443, 49.49813894927502, 50.35475738346577, 50.80870382487774, 48.10126170516014, 43.90392333269119, 42.4832783639431, 42.926824763417244, 48.58000561594963, 51.19514308869839, 56.624641343951225, 55.9433227032423, 60.8099115639925, 59.27290923893452, 66.23410910367966, 31.198085322976112, 0.07766944283503108, 4.858458722010255, 2.258639889769256, 0.06044630295946263, 0.11731422215234488, 5.321857156231999, 46.31430499255657, 48.75733070075512, 47.99810864031315, 19.521372690796852, 34.40726011991501, 26.770084127783775, 46.143713146448135, 46.25529795885086, 53.03375042974949, 11.72858839854598, 0.49940922064706683, 0.02481976720446255, 0.06256303429836407, 0.03703950329509098, 0.05603518868156243, 0.03438072213612031, 0.037235192794469185, 0.049804673399194144, 0.02199595281126676, 0.02609023496916052, 0.03115180086751934, 0.06295793107710779, 0.05287827800202649, 0.09915896705933847, 0.020730424039356876, 0.03225345601094887, 0.06188513805682305, 0.03074348234804347, 0.04299074469599873, 0.020786519271496218, 0.08424254090641625, 0.03728718023921829, 0.06651743460679427, 0.0023638859966013115, 0.03394884042791091, 0.06336899925372563, 0.06012612189806532, 0.007627668119312148, 0.01838271964516025, 0.018936565902549773, 0.05907015707634855, 0.0037957008407829562, 2.038247440941632, 62.27323204278946, 70.58678314089775, 64.2142666876316, 46.72404080629349, 39.9183551967144, 23.527275435626507, 35.99088214337826, 32.6406779140234, 50.90379752218723, 31.947952285408974, 0.2531899733003229, 0.014374220481840894, 0.621005545835942, 4.119939850643277, 3.9624119410291314, 1.5666894195601344, 11.15753224119544, 72.99735099077225, 64.31521207094193, 75.13848289847374, 62.81148076057434, 73.6123175919056, 62.81503736972809, 56.25980392098427, 62.46661126613617, 65.97299471497536, 64.86862197518349, 62.2994202375412, 59.11620944738388, 56.21658504009247, 47.935267612338066, 45.325681641697884, 44.43869523704052, 54.160785153508186, 55.5551203340292, 59.83982361853123, 59.28108260035515, 61.871806383132935, 65.11120095849037, 59.741234108805656, 58.46938155591488, 59.39177826046944, 57.72093951702118, 59.919930920004845, 55.88539481163025, 59.37735803425312, 56.91890135407448, 49.16507162153721, 45.9353057295084, 52.87526473402977, 56.01575441658497, 58.4049142152071, 58.29608425498009, 53.183401599526405, 44.19348679482937, 43.242538422346115, 44.14568915963173, 41.81473083794117, 43.11667017638683, 42.257695868611336, 42.63767547905445, 42.75660149753094, 44.48935031890869, 43.99251937866211, 46.42682455480099, 46.42010271549225, 52.16800108551979, 54.119040593504906, 58.38822551071644, 53.85931693017483, 60.82201771438122, 34.19588126242161, 36.9816979765892, 61.53377652168274, 52.28625454008579, 56.8563187122345, 51.73599846661091, 53.875264674425125, 53.49741294980049, 54.39323008060455, 50.58014988899231, 45.822185799479485, 42.54491105675697, 44.85910087823868, 44.04853597283363, 43.636318892240524, 52.402304112911224, 57.11304813623428, 53.33863086998463, 49.337635561823845, 44.41510230302811, 43.52458208799362, 42.8689918667078, 45.14403238892555, 45.82512304186821, 54.01490718126297, 57.375887632369995, 58.310401886701584, 57.728850692510605, 55.07430173456669, 51.11621752381325, 50.490337908267975, 46.1676936596632, 46.785316318273544, 45.01967266201973, 45.1242620497942, 43.650408536195755, 46.26208819448948, 51.01849816739559, 52.33057156205177, 51.464385241270065, 51.80575132369995, 51.54695101082325, 53.58475886285305, 53.5600183904171, 51.704954132437706, 46.627826169133186, 46.3364502042532, 45.85290715098381, 51.26268066465855, 54.698422104120255, 58.30048441886902, 59.36485290527344, 62.61402055621147, 61.70909911394119, 69.14461612701416, 36.442715898156166, 0.0645243153849151, 2.005995959043503, 5.522487815469503, 0.6295382254756987, 0.2784604876069352, 4.441160364076495, 50.91045096516609, 48.6135920137167, 40.162974670529366, 22.78472688049078, 42.82619096338749, 31.710157245397568, 52.21310466527939, 51.46229535341263, 63.30604702234268, 16.5189827978611, 0.43302779202349484, 0.08029033735510893, 0.012160391179349972, 0.044527962600113824, 0.10102704181917943, 0.06773325803806074, 0.028616251474886667, 0.03705375624122098, 0.014400126074178843, 0.036955826144549064, 0.044149838358862326, 0.0794496398884803, 0.04613883495039772, 0.08354706689715385, 0.03443360386881977, 0.022897695635037962, 0.026369943007011898, 0.22462197812274098, 0.21680505538824946, 0.1506529503967613, 0.14108064060565084, 0.08291043035569601, 0.2130203100387007, 0.11664619276416488, 0.16587193531449884, 0.17788576253224164, 0.15551369113381952, 0.130709765071515, 0.051123800076311454, 0.11799204788985662, 0.3197423630626872, 0.15675055445171893, 3.1719420198351145, 75.31514301896095, 77.44651705026627, 75.10084971785545, 53.37806135416031, 48.6544094234705, 26.679227203130722, 52.1496556699276, 51.07828035950661, 60.04573456943035, 37.135616317391396, 0.8895540575031191, 0.17602000327315181, 0.9105560649186373, 2.669079853221774, 6.074484195560217, 6.651218198239803, 9.53142849728465, 75.84115639328957, 65.48684880137444, 78.39560732245445, 64.90282014012337, 74.5246410369873, 59.50787343084812, 59.444884210824966, 66.56130954623222, 67.78906926512718, 67.42656871676445, 64.68961358070374, 61.52857840061188, 59.081946685910225, 51.56590819358826, 48.61382380127907, 47.501121908426285, 56.37977108359337, 57.970293536782265, 63.49053092300892, 60.26275992393494, 62.95510545372963, 65.69403648376465, 61.68820783495903, 62.76951961219311, 62.43452198803425, 61.37025989592075, 62.6425988227129, 59.31949093937874, 62.43411161005497, 59.42016273736954, 52.039814963936806, 49.389711767435074, 55.76182544231415, 60.02784512937069, 59.85628053545952, 62.0563130825758, 56.30105070769787, 46.066934466362, 47.08746090531349, 47.82454535365105, 45.717243030667305, 47.236241921782494, 45.45407675206661, 45.06096884608269, 45.70656940340996, 45.80119572579861, 46.6188358515501, 48.224637284874916, 50.03790758550167, 54.59198601543903, 56.527013182640076, 60.00077158212662, 57.624747678637505, 61.362705901265144, 37.64367565512657, 38.96340563893318, 62.851906791329384, 54.05628316104412, 57.32080578804016, 53.76302629709244, 55.014546141028404, 56.897983476519585, 58.32192286849022, 52.42249622941017, 48.299599662423134, 45.334497168660164, 47.593107372522354, 45.17415717244148, 46.222475320100784, 55.14642186462879, 60.88748440146446, 56.59173510968685, 52.8007697314024, 46.55106268823147, 46.29674233496189, 43.631234765052795, 48.21320369839668, 48.478418067097664, 55.95673218369484, 59.86957982182503, 60.9217319637537, 58.874040842056274, 57.087213322520256, 53.197137862443924, 51.8443800508976, 49.05724860727787, 47.55887880921364, 48.51502150297165, 47.964697033166885, 47.82358020544052, 49.05080035328865, 53.898838609457016, 54.42391723394394, 53.83387729525566, 53.70974935591221, 52.92164124548435, 56.852963492274284, 57.88782276213169, 52.479857951402664, 48.15479323267937, 47.0691154897213, 47.72430673241615, 54.21438127756119, 57.037948966026306, 61.63256362080574, 61.3322239369154, 65.5007104575634, 64.89493176341057, 71.32591187953949, 39.73153442144394, 0.10723148545366712, 12.108103483915329, 6.999809592962265, 0.3414778201840818, 0.291519911843352, 6.247962461784482, 59.449702352285385, 67.48694747686386, 63.44647228717804, 27.72854659706354, 47.30471804738045, 37.67102278769016, 63.20811867713928, 58.77669766545296, 73.88572052121162, 21.315486319363117, 0.6011285749264061, 0.2529679227154702, 0.1187687944911886, 0.2221629163250327, 0.20874124980764464, 0.16379656386561692, 0.13159914000425488, 0.12706087727565318, 0.15379560441942886, 0.13548204180551693, 0.09156851068837568, 0.2882792497985065, 0.14530586544424295, 0.27143852377776057, 0.29469158384017646, 0.1967180715291761, 0.11904313680133782], [0.02759903418336762, 0.009638867450121325, 0.06050727781257592, 0.042384395201224834, 0.04092375580512453, 0.15422466967720538, 0.02410806242551189, 0.045110529972589575, 0.061557531807920896, 0.04776353722263593, 0.017763250834832434, 0.03630635044828523, 0.03200688115612138, 0.051395604241406545, 0.08261933777248487, 9.424121305346489, 68.32642123103142, 55.63448287546635, 55.65309427678585, 40.85475794970989, 25.556611642241478, 32.88842462003231, 59.19032447040081, 42.97453120350838, 54.59113486111164, 13.063867148011923, 0.30853153963107616, 0.025417650649615098, 0.24390120845055208, 1.299811927601695, 1.1487578018568456, 0.4058203019667417, 47.366962507367134, 65.59713408350945, 65.71446418762207, 63.15124332904816, 66.81707382202148, 61.19233064353466, 71.11530438065529, 59.4968768209219, 54.54051777720451, 62.80305281281471, 61.456777453422546, 61.422928869724274, 57.384129390120506, 57.102826684713364, 49.31110918521881, 43.24254982173443, 41.989601254463196, 48.99348422884941, 54.17823001742363, 55.70361256599426, 57.78919145464897, 54.85339678823948, 55.8064616471529, 58.67359399795532, 58.654910400509834, 55.642242059111595, 57.545153349637985, 53.56987506151199, 54.85064193606377, 56.634991988539696, 51.826327219605446, 40.50503231585026, 43.37952487170696, 50.946203246712685, 57.63707421720028, 59.14475731551647, 58.105148300528526, 48.71342785656452, 41.35432094335556, 39.75418880581856, 38.71254310011864, 38.89335639774799, 40.01306891441345, 39.37985189259052, 41.44555784761906, 38.34751948714256, 42.951135858893394, 43.636284694075584, 46.51019588112831, 47.79855854809284, 55.96884973347187, 54.652862548828125, 57.20984414219856, 53.15847873687744, 55.084409192204475, 32.98750810325146, 36.515861973166466, 59.690571427345276, 51.70781157910824, 53.105418384075165, 51.60866729915142, 54.99317988753319, 53.07031586766243, 55.68861097097397, 51.721023470163345, 49.39786992967129, 39.6224270761013, 39.94192153215408, 40.6682525575161, 41.508566066622734, 43.16888317465782, 47.20670610666275, 45.3814360499382, 44.93777185678482, 40.06325662136078, 42.00751729309559, 39.48704034090042, 38.89459513127804, 40.58586537837982, 49.76826265454292, 56.516088768839836, 56.49598024785519, 55.11166512966156, 54.46535021066666, 45.59662230312824, 41.17171794176102, 42.91875779628754, 41.90945215523243, 41.516370847821236, 41.3754516094923, 42.82503962516785, 44.042938873171806, 44.98952887952328, 46.37374520301819, 48.22897285223007, 47.292239516973495, 47.75413133203983, 48.35689678788185, 47.78875507414341, 43.13789203763008, 44.41609025001526, 44.96841341257095, 50.31120032072067, 56.197878643870354, 55.91512441635132, 55.85132583975792, 56.46207466721535, 57.573838010430336, 59.874937534332275, 64.1959136724472, 55.81097960472107, 2.8198094526305795, 0.8367389102932066, 1.415352683980018, 0.13221815053839236, 0.18227743625175208, 0.12697253201622516, 32.08278805017471, 40.455095395445824, 30.346625111997128, 27.490348778665066, 25.943128801882267, 25.93538861721754, 34.71024826169014, 44.4395349919796, 56.26903362572193, 19.793747775256634, 1.5955582517199218, 0.05135777326358948, 0.018542791622166988, 0.08007979005924426, 0.10246189529425465, 0.042831906539504416, 0.05016731272917241, 0.029033403407083824, 0.05232467665337026, 0.034444301927578636, 0.019131951121380553, 0.021245201787678525, 0.0884935850626789, 0.04102426486497279, 0.029068096955597866, 0.001826444217840617, 0.06501609954284504, 0.029109289862390142, 0.025922661734512076, 0.03945254080463201, 0.018110052733391058, 0.017441954696550965, 0.12372424811474048, 0.023372241557808593, 0.019737115035241004, 0.011782749334088294, 0.03697370819281787, 0.016910281956370454, 0.008290728364954703, 0.010963960994558875, 0.03575617782189511, 0.09524334396701306, 13.69238382205367, 80.43454751372337, 62.02812619507313, 63.53469975292683, 45.81401243805885, 30.52290715277195, 31.15917731076479, 49.773931950330734, 39.216848239302635, 61.81908041238785, 14.17893536388874, 0.4065929667558521, 0.08166535146301612, 2.000530189834535, 5.978967295959592, 3.7229400034993887, 0.29162850289139897, 51.65757067501545, 68.55290427803993, 68.96104797720909, 65.90595871210098, 68.84720608592033, 63.397340923547745, 68.25294077396393, 63.164952993392944, 56.10653154551983, 63.434016555547714, 63.36125805974007, 62.62266509234905, 59.45138946175575, 59.30911369621754, 52.68698863685131, 45.18651030957699, 45.05716525018215, 49.979892298579216, 55.83232685923576, 57.83947415649891, 59.92206260561943, 57.16195151209831, 57.881317511200905, 59.462188482284546, 62.0479117333889, 59.3833427131176, 58.944036886096, 55.8763474971056, 57.87953160703182, 59.62875634431839, 54.128771871328354, 42.06949956715107, 45.72566717863083, 51.98619224131107, 59.38360869884491, 61.96663409471512, 61.68918818235397, 51.2603247910738, 42.37794041633606, 41.77550174295902, 41.28650978207588, 43.097462207078934, 42.428230717778206, 40.98197892308235, 42.462273091077805, 40.56047514081001, 43.93879026174545, 46.10214337706566, 50.406009033322334, 49.82969015836716, 57.26828120648861, 56.908170729875565, 57.991063222289085, 55.15636973083019, 55.422237664461136, 33.90145406126976, 38.73374596238136, 60.432812198996544, 54.07088577747345, 56.91897734999657, 53.05623382329941, 57.08955779671669, 54.429985508322716, 56.698258593678474, 54.35887612402439, 50.45562297105789, 42.18311347067356, 42.28597395122051, 43.77011351287365, 44.11878280341625, 44.21840585768223, 48.807149827480316, 47.78573043644428, 46.049189418554306, 43.217482566833496, 43.387922421097755, 41.60593964159489, 41.88043691217899, 43.21922667324543, 50.907350331544876, 57.53038354218006, 57.076828479766846, 57.83116400241852, 57.42718107998371, 48.112087324261665, 44.58953574299812, 43.9980024844408, 43.871134892106056, 43.40540908277035, 43.88256847858429, 44.50472429394722, 44.74818482995033, 47.372441813349724, 48.07968646287918, 49.69296209514141, 48.463112488389015, 48.8697324693203, 50.94246044754982, 49.393674954771996, 45.38861766457558, 44.893416836857796, 46.58955082297325, 52.4730259180069, 59.434772953391075, 58.57449151575565, 58.42083156108856, 57.986450269818306, 59.4437974691391, 61.12701594829559, 65.63871145248413, 56.68202966451645, 5.929446928203106, 1.8491645995527506, 3.9961462933570147, 0.8043726033065468, 0.22119738219771534, 0.11628186504822224, 32.79816046357155, 47.412119284272194, 29.680118076503277, 29.4327874481678, 33.049847558140755, 33.079835548996925, 39.95864063501358, 49.41485121846199, 63.46235543489456, 30.013932064175606, 2.08035868126899, 0.09470873046666384, 0.06607853589230217, 0.018214077717857435, 0.04283515714632813, 0.02323420951142907, 0.01640101836528629, 0.03634916494775098, 0.05354124223231338, 0.04116527292353567, 0.03245101572247222, 0.048056837695185095, 0.04525151205598377, 0.041616977396188304, 0.0298743995881523, 0.05767592505435459, 0.0581460273679113, 0.10152936447411776, 0.1438105120905675, 0.1313753824797459, 0.14971883880207315, 0.10212366149062291, 0.20936426793923602, 0.12810371350497007, 0.14495122275548056, 0.1745433223550208, 0.14304909826023504, 0.1281196845229715, 0.1754342409549281, 0.14076472318265587, 0.11498008607304655, 0.267446095822379, 17.841300442814827, 92.50878721475601, 72.68844276666641, 72.74802356958389, 53.16955894231796, 35.64592905342579, 43.264516443014145, 76.04743212461472, 58.26375558972359, 71.68688490986824, 16.048718132078648, 0.5537874496076256, 0.15558753482764587, 2.272132965736091, 3.990605240687728, 5.31170885078609, 1.0121900425292552, 50.78626602888107, 72.81755983829498, 70.9198048710823, 69.15977731347084, 72.43416041135788, 65.07635682821274, 69.36166808009148, 60.52437208592892, 60.85924431681633, 65.1438944041729, 65.06322473287582, 66.4900253713131, 62.2325324267149, 63.638517782092094, 55.54847069084644, 46.518456637859344, 47.50459872186184, 53.49289499223232, 60.720699951052666, 60.85151553153992, 63.814657330513, 60.611759796738625, 60.55230438709259, 61.11692748963833, 63.41684527695179, 61.852571815252304, 63.09430718421936, 57.94847510755062, 59.42166365683079, 61.95732839405537, 57.00485274195671, 44.03236024081707, 47.81539924442768, 54.909276589751244, 63.12317803502083, 62.90014520287514, 63.457788079977036, 55.15425704419613, 45.252888947725296, 44.59735192358494, 43.567417189478874, 46.014303490519524, 46.10868662595749, 44.36943635344505, 46.55053451657295, 41.785229220986366, 47.38414138555527, 47.915227487683296, 52.24667966365814, 52.7512089908123, 61.637446358799934, 59.56564173102379, 60.04027046263218, 56.08733877539635, 56.060136035084724, 35.76025351881981, 41.48343041539192, 61.612519696354866, 56.320281475782394, 58.32426734268665, 55.33097416162491, 58.81949856877327, 56.31185732781887, 59.61858429014683, 56.62515431642532, 53.04845944046974, 44.30808484554291, 45.22670455276966, 46.13188438117504, 44.87952098250389, 46.679978370666504, 51.022993326187134, 50.21229162812233, 48.503929898142815, 45.12174278497696, 46.23690314590931, 42.748040556907654, 43.020364344120026, 44.49121221899986, 52.80541308224201, 61.257162764668465, 60.29170677065849, 60.76339825987816, 60.57558573782444, 51.71367846429348, 46.22800022363663, 46.49984523653984, 45.82310155034065, 46.63237452507019, 45.80877251923084, 45.916777923703194, 47.441628500819206, 49.57358010113239, 49.418852403759956, 53.71407352387905, 52.48107008635998, 53.16611632704735, 53.33649918437004, 52.005692794919014, 47.98629127442837, 49.30091433227062, 49.51618418097496, 55.688873156905174, 62.03163720667362, 61.45046979188919, 59.9845502525568, 62.351887822151184, 61.4066581428051, 65.2068342268467, 66.83845907449722, 62.33125112950802, 6.894579464569688, 7.33559662476182, 11.489358935505152, 0.4480147222056985, 0.4782847291789949, 0.2156213892158121, 38.146552070975304, 54.4924845546484, 43.72247166931629, 37.13741362094879, 35.88771387934685, 36.23174361884594, 48.9375664293766, 58.30007404088974, 71.35754898190498, 37.79237687587738, 2.8654058184474707, 0.20904414996039122, 0.2223233092809096, 0.15617314871633425, 0.2326845665811561, 0.2211365260882303, 0.13972317829029635, 0.20270752982469276, 0.23998808639589697, 0.13096491544274613, 0.11306349711958319, 0.1110250326746609, 0.13274298253236338, 0.12501992663601413, 0.08688006695592776, 0.15147622965741903, 0.2039196647820063], [0.09087216094485484, 0.019884589055436663, 0.05242430997896008, 0.05450922544696368, 0.04848092685278971, 0.036208078963682055, 0.06408468194422312, 0.02117602991347667, 0.03782162304560188, 0.027920269094465766, 0.05096803441119846, 0.07977375804330222, 0.07904764817794785, 0.17346772772725672, 0.19228983961511403, 29.564247094094753, 66.71827152371407, 58.07487532496452, 57.907809689641, 43.97739239037037, 24.37045779079199, 40.86320109665394, 36.94703243672848, 40.28695061802864, 50.91588847339153, 3.4297294495627284, 0.4275648726616055, 0.6967074587009847, 1.6269339993596077, 19.16654773056507, 3.9542229054495692, 5.256012389436364, 71.8878485262394, 60.014352053403854, 68.71875777840614, 55.51254741847515, 65.85228279232979, 62.74114653468132, 64.76741820573807, 63.618967831134796, 63.473830819129944, 53.185031712055206, 66.98917418718338, 58.741811737418175, 61.93715147674084, 56.543477699160576, 58.95703598856926, 45.72865381836891, 42.653946205973625, 42.40523435175419, 49.28354926407337, 50.22862695157528, 51.73927769064903, 47.71843604743481, 51.07890732586384, 48.962762877345085, 55.15900298953056, 54.26718324422836, 53.04981216788292, 54.59646977484226, 55.41393131017685, 52.05640107393265, 44.77810822427273, 39.71131570637226, 44.31218862533569, 51.339702531695366, 55.251676216721535, 54.75907824933529, 53.24686959385872, 42.40653768181801, 40.87645098567009, 38.31399388611317, 41.77751563489437, 39.47507858276367, 41.07766538858414, 38.4754054248333, 39.6005592495203, 39.646266996860504, 44.890107214450836, 48.38649719953537, 52.000411078333855, 49.95236657559872, 54.4815069437027, 54.9057237803936, 59.2909050732851, 50.65213322639465, 54.569571018218994, 32.934991121292114, 36.35028585791588, 58.53944979608059, 51.47777572274208, 53.86948138475418, 50.98849877715111, 53.42269375920296, 51.39044500887394, 53.57662729918957, 52.7815617620945, 50.453069508075714, 44.748059436678886, 40.7427703589201, 42.445869371294975, 42.929894998669624, 41.89694702625275, 42.410668060183525, 42.72526077926159, 40.86747966706753, 41.76427334547043, 41.1428926885128, 42.05965429544449, 41.78272135555744, 41.57965645194054, 47.06138290464878, 53.4280476719141, 55.72550319135189, 53.8250807672739, 49.6584827452898, 42.32313975691795, 42.37080819904804, 41.06508806347847, 40.887261405587196, 41.50653697550297, 41.553407460451126, 43.63824538886547, 41.570213958621025, 45.36258526146412, 43.07833023369312, 42.01586924493313, 45.959578827023506, 43.08291658759117, 43.456257954239845, 40.98700985312462, 43.12408357858658, 42.307036221027374, 51.617513224482536, 51.42336644232273, 55.934476777911186, 56.19532898068428, 55.313255712389946, 58.326634615659714, 62.04813592135906, 57.640467435121536, 62.79900223016739, 62.229367196559906, 13.15958021208644, 1.301946819294244, 5.8959887735545635, 0.7376530522014946, 0.27790770633146167, 0.16631830745609477, 10.560869257897139, 57.5112933665514, 41.13338179886341, 36.753109842538834, 27.797813080251217, 16.665668226778507, 35.192290395498276, 47.09775075316429, 48.38645160198212, 41.0880122333765, 6.235643047839403, 0.21253349084872752, 0.01497594639658928, 0.06709589419187978, 0.034389241991448216, 0.0373809728625929, 0.01876243950391654, 0.015079836866789265, 0.046979562102933414, 0.05319888579833787, 0.0483771300787339, 0.05148220916453283, 0.086961413762765, 0.04250811121892184, 0.007318132238651742, 0.07876072646467946, 0.04567921547277365, 0.04349322320194915, 0.005787618247268256, 0.05464852285513189, 0.04616152982634958, 0.032013738600653596, 0.005455882874230156, 0.04613748053088784, 0.029189328633947298, 0.0726832717191428, 0.04949345006025396, 0.033179949459736235, 0.007773387887937133, 0.0568805245711701, 0.04443111232831143, 0.10200807941146195, 36.92465163767338, 76.41587555408478, 63.34037438035011, 64.36174437403679, 49.7416602820158, 29.716269336640835, 34.94101367890835, 34.76918309926987, 41.797069385647774, 59.47279751300812, 2.8359391121193767, 0.38324375404044986, 0.10351928503951058, 2.971192141994834, 14.820757023990154, 2.9422778310254216, 7.5358539540320635, 75.18086582422256, 65.75791865587234, 69.26434010267258, 61.0136566311121, 65.42805835604668, 65.70710778236389, 63.70276093482971, 63.48102763295174, 65.83221986889839, 57.259796261787415, 67.4941822886467, 61.473059579730034, 63.69850516319275, 58.79724696278572, 61.205352544784546, 48.74340444803238, 45.10592043399811, 45.6574722379446, 52.496991232037544, 52.846705466508865, 54.600296169519424, 49.91348326206207, 54.87940639257431, 53.45457784831524, 56.240360364317894, 55.355064868927, 56.07698813080788, 57.9728963971138, 58.765024691820145, 54.5332145690918, 46.915607526898384, 42.149618268013, 47.15276800096035, 55.06041347980499, 56.91384382545948, 57.19310224056244, 56.96964383125305, 46.64281636476517, 43.152566850185394, 41.508060693740845, 43.396779745817184, 40.227244421839714, 43.32323469221592, 40.23868180811405, 43.63623909652233, 40.92240571975708, 46.832213401794434, 49.38665293157101, 53.96972380578518, 52.016943991184235, 56.74932025372982, 57.53715477883816, 59.61975462734699, 49.96264882385731, 55.7724192738533, 34.20854598283768, 38.83045457303524, 59.65272165834904, 53.67178559303284, 55.91263934969902, 53.087779730558395, 55.508683025836945, 53.23093704879284, 55.083200857043266, 55.33346302807331, 54.13172051310539, 45.77170170843601, 42.82887741923332, 43.377332389354706, 44.84924800693989, 42.09856040775776, 44.61050681769848, 45.36070056259632, 42.965601682662964, 42.27324463427067, 43.041707798838615, 42.883529886603355, 43.048688024282455, 43.072064369916916, 47.51417800784111, 55.71383021771908, 58.195135071873665, 56.41000986099243, 52.9425211250782, 44.39695447683334, 43.95901657640934, 42.91453242301941, 42.9971057921648, 43.82536254823208, 44.667914137244225, 44.51418958604336, 43.86994555592537, 47.06435814499855, 45.781565979123116, 45.78441962599754, 47.497641295194626, 46.20905824005604, 45.708625093102455, 43.36676515638828, 46.081198900938034, 44.69032533466816, 53.76892738044262, 54.974853470921516, 58.0484439432621, 58.942539766430855, 58.85724574327469, 59.511984810233116, 64.13954749703407, 61.13483212888241, 62.845587730407715, 65.09318232536316, 18.232310861349106, 1.1345635447651148, 5.0063833594322205, 3.711427333764732, 0.6839139014482498, 0.2209457496064715, 9.741534423083067, 63.348213359713554, 39.4392579048872, 30.012613534927368, 30.672324635088444, 21.82739295065403, 38.907275050878525, 54.53504227101803, 53.79342086613178, 54.95982527732849, 10.35285321995616, 0.33763382176402956, 0.12357293162494898, 0.1095924353285227, 0.05527078770683147, 0.0228761529433541, 0.04361231935035903, 0.02893179225793574, 0.01862257249740651, 0.044055700636818074, 0.10141293634660542, 0.04063557986228261, 0.08203259581932798, 0.03778550642891787, 0.08429763052845374, 0.07683447474846616, 0.044690700742648914, 0.2571439283201471, 0.13807871262542903, 0.1602244289824739, 0.19658522709505633, 0.11955872905673459, 0.06608951225643978, 0.2410890773171559, 0.15148494247114286, 0.1545732415979728, 0.16589442238910124, 0.10080451625981368, 0.15631384507287294, 0.20845605729846284, 0.2843435516115278, 0.34768636047374457, 47.5384359061718, 84.78312537074089, 74.84258517622948, 72.30430617928505, 56.489041820168495, 34.52288791537285, 54.98868092894554, 51.97930321097374, 56.332425624132156, 61.87671571969986, 4.7440169379115105, 0.6654806155711412, 1.0711086122319102, 2.277999850921333, 34.922797456383705, 9.536407180130482, 5.308856153860688, 80.3187221288681, 64.79321882128716, 73.48241776227951, 61.92218787968159, 70.99427327513695, 67.07344606518745, 67.47387617826462, 60.43923385441303, 64.8798617720604, 57.821094542741776, 70.20881742238998, 63.50361742079258, 66.85311108827591, 61.536972150206566, 64.41853612661362, 51.51953548192978, 46.96169525384903, 47.873061150312424, 54.516518265008926, 54.41886730492115, 57.7428225427866, 52.262897193431854, 57.042269334197044, 53.7953245639801, 60.229435712099075, 57.83581115305424, 57.17353709042072, 60.31696781516075, 61.757603511214256, 57.46715113520622, 50.696347653865814, 44.26544353365898, 50.8837877959013, 56.56640186905861, 60.078348219394684, 58.9615311473608, 58.071592301130295, 49.08315181732178, 46.302259638905525, 42.19650015234947, 47.67033442854881, 43.70056204497814, 47.10726164281368, 44.42542254924774, 45.71950390934944, 42.919168174266815, 48.946290761232376, 52.86158166825771, 57.304816246032715, 55.8857785910368, 58.68101879954338, 60.81653080880642, 62.2805542498827, 52.84170873463154, 55.80182209610939, 35.90925112366676, 43.73173177242279, 61.653549894690514, 56.12146474421024, 56.904123947024345, 55.68402461707592, 56.956766322255135, 55.18749386072159, 55.19574321806431, 58.29711399972439, 54.5557701587677, 48.62948656082153, 46.67781628668308, 45.73213443160057, 46.79294250905514, 43.789815455675125, 46.61019891500473, 48.009553626179695, 45.24922974407673, 44.965662360191345, 46.10299073159695, 46.481575816869736, 46.70159921050072, 46.28678686916828, 51.537155136466026, 58.393454030156136, 60.97745597362518, 60.16215652227402, 54.946605786681175, 45.59634491801262, 45.66384829580784, 44.66841571033001, 43.85215111076832, 45.965905487537384, 46.9848208129406, 48.220202922821045, 45.26790954172611, 49.37720283865929, 46.65817894041538, 46.89153961837292, 50.79789340496063, 47.24780470132828, 47.33575478196144, 47.06000357866287, 47.82949648797512, 46.2091988325119, 57.6781690120697, 55.52179612219334, 61.78006410598755, 62.36188888549805, 61.61890335381031, 63.73768486082554, 66.52717217803001, 62.42156848311424, 67.02714174985886, 67.62925744056702, 21.9809066131711, 3.2499430468305945, 14.996568839997053, 6.0374832060188055, 0.7068997586611658, 0.19093495997367427, 12.54313264042139, 72.54772871732712, 55.424156561493874, 49.48601000010967, 33.934284299612045, 23.92297100275755, 46.984277442097664, 63.177336528897285, 61.05065904557705, 63.73982034623623, 13.13149306923151, 0.48765657003968954, 0.21542420057812706, 0.17777835892047733, 0.17787224060157314, 0.11652859946480021, 0.18124953203368932, 0.06948063732124865, 0.2413046415313147, 0.1453857056912966, 0.20282790617784485, 0.14466637163423002, 0.20544151280773804, 0.22974098625127226, 0.1563483994686976, 0.1375887615722604, 0.1830715936375782], [0.043170555945835076, 0.050453959847800434, 0.02800529695377918, 0.05010285720345564, 0.11181431415025145, 0.04940297112625558, 0.06600180524401367, 0.023109161338652484, 0.026088795202667825, 0.10114816774148494, 0.06663993350230157, 0.029388543334789574, 0.03568584819731768, 0.05089756377856247, 1.4931020932272077, 50.14514543116093, 62.968400940299034, 55.276431888341904, 45.21654009819031, 29.831064976751804, 12.861618250608444, 33.12233246862888, 41.23667545616627, 51.66005574166775, 39.67215120792389, 0.28168105229269713, 0.08906549890525639, 0.22439076943555847, 3.0163626931607723, 7.881506206467748, 1.1330045596696436, 29.699077159166336, 74.565200060606, 61.22801072895527, 66.2776243686676, 51.00300259888172, 59.46349561214447, 60.14067627489567, 65.72665393352509, 59.07922603189945, 68.57289120554924, 61.9101919233799, 60.48759005963802, 58.920759335160255, 60.801160633563995, 57.11977377533913, 57.210832089185715, 50.102979093790054, 44.83914814889431, 42.957686707377434, 43.71625520288944, 43.02846550941467, 43.47516193985939, 40.88491313159466, 43.93902964890003, 43.04820165038109, 44.79766197502613, 45.87262809276581, 48.905917927622795, 49.47950094938278, 47.591701447963715, 42.18202292919159, 43.0766811221838, 40.329846516251564, 42.6805105805397, 48.43332588672638, 55.44687934219837, 52.18285828828812, 48.92867110669613, 40.124771520495415, 42.038839012384415, 39.454320296645164, 42.02254168689251, 38.249420151114464, 39.43024478852749, 39.13428246974945, 41.4894150942564, 41.90677709877491, 50.19064038991928, 50.65762013196945, 52.21102237701416, 51.864169389009476, 55.86359918117523, 54.80917476117611, 58.24135959148407, 48.995802104473114, 55.64799875020981, 35.58301962912083, 36.75291985273361, 53.28719303011894, 52.19131663441658, 52.23965764045715, 50.39498582482338, 51.10069155693054, 49.68233406543732, 51.72355033457279, 52.49278865754604, 52.51279838383198, 49.483319744467735, 45.4867397993803, 40.084254294633865, 42.78927594423294, 40.470944344997406, 40.12469172477722, 41.57112970948219, 42.09323309361935, 38.805231526494026, 40.64915098249912, 41.331453770399094, 42.09161438047886, 42.052035704255104, 44.189641401171684, 48.202393278479576, 50.87400332093239, 53.473903611302376, 47.652509585022926, 41.69792890548706, 43.24783153831959, 41.108208149671555, 40.43247900903225, 41.55680067837238, 41.69800490140915, 42.88868620991707, 42.40086458623409, 44.12309557199478, 42.62141615152359, 42.31583654880524, 43.5356242954731, 44.82103452086449, 42.66596496105194, 40.955638736486435, 41.97289355099201, 48.94931919872761, 53.73363487422466, 55.12254014611244, 58.41844528913498, 57.56276920437813, 60.649670362472534, 60.13071320950985, 56.75571151077747, 60.05973681807518, 59.77639742195606, 62.36499711871147, 34.89676505327225, 1.0025328607298434, 1.5329228877089918, 3.020459823310375, 0.07799261104082689, 0.05583602222031914, 0.7635171955917031, 36.413826048374176, 44.4491408765316, 40.17693892121315, 17.22460113465786, 15.65846387296915, 25.80818474292755, 40.17465904355049, 46.85578353703022, 52.299865409731865, 26.63170125335455, 1.7034908663481474, 0.06293176295002922, 0.08049329990171827, 0.0584100167179713, 0.05157240237167571, 0.11861107326694764, 0.016455432632938027, 0.04600672153173946, 0.07039465897832997, 0.028560215614561457, 0.05081258044810966, 0.08718122306163423, 0.01992592111491831, 0.02930739319708664, 0.0356051062408369, 0.0257795070137945, 0.04098026663996279, 0.04363604952231981, 0.025283852555730846, 0.03187946182151791, 0.010391233572590863, 0.08783610901446082, 0.0204063634009799, 0.02117534342687577, 0.013174439500289736, 0.023362480460491497, 0.05482976273924578, 0.05736473140132148, 0.10174270966672339, 0.04948526417138055, 2.0671736262738705, 59.41583476960659, 70.16800001263618, 62.42910347878933, 53.275516256690025, 36.288181990385056, 19.25604622811079, 34.678611159324646, 36.078543439507484, 58.18980015814304, 45.295017287135124, 0.13733408617554232, 0.05138302483828738, 0.8261016779579222, 4.305483419448137, 4.3212345242500305, 0.5701938411220908, 34.34582121670246, 75.88936820626259, 63.88378322124481, 68.83121654391289, 53.29592116177082, 62.33041897416115, 61.38429634273052, 67.13030621409416, 58.89327920973301, 66.80376693606377, 62.332140281796455, 63.780367970466614, 61.92205108702183, 62.72270232439041, 60.34130170941353, 58.48178789019585, 53.96463207900524, 45.821688026189804, 45.122966319322586, 45.19521564245224, 45.496440678834915, 45.41443727910519, 43.687840327620506, 45.29495649039745, 45.30739702284336, 46.58820189535618, 48.43333348631859, 51.3020845502615, 52.41950199007988, 49.821250811219215, 45.274429991841316, 43.92072603106499, 42.06106781959534, 44.9214593321085, 51.731545105576515, 57.16721422970295, 55.06365850567818, 51.988878697156906, 42.95905463397503, 42.92242459952831, 41.61917433142662, 43.85319225490093, 40.283223018050194, 42.1492724865675, 41.550637409090996, 43.5825327783823, 44.008037745952606, 52.612911611795425, 54.28264461457729, 54.14924897253513, 54.17028084397316, 58.13397355377674, 56.50081738829613, 58.7766482681036, 49.792429357767105, 56.878843903541565, 36.718474701046944, 40.680100321769714, 57.4841096252203, 53.803782910108566, 53.69958870112896, 50.80664053559303, 51.56860984861851, 51.210722252726555, 52.30437956750393, 53.34818735718727, 55.866183042526245, 54.36250872910023, 47.74843543767929, 42.0094133913517, 44.20322947204113, 41.77903935313225, 43.300686702132225, 42.307594791054726, 43.48105922341347, 41.70557789504528, 41.678500548005104, 42.30186469852924, 44.6178138256073, 43.786239847540855, 45.41045889258385, 51.03612922132015, 52.38722652196884, 55.568856596946716, 49.734752252697945, 43.26906859874725, 43.54372926056385, 42.06110581755638, 41.869565695524216, 42.45183505117893, 44.253458976745605, 45.47546200454235, 44.3888571113348, 45.276375487446785, 43.69493454694748, 44.61225092411041, 44.647239446640015, 46.81939668953419, 45.30464977025986, 43.38880017399788, 43.30519326031208, 51.31456308066845, 55.36893792450428, 57.66994245350361, 60.57671807706356, 59.273817390203476, 61.168882101774216, 61.90692029893398, 58.806176483631134, 61.42261728644371, 62.38785669207573, 61.62954658269882, 37.210236713290215, 2.286676447838545, 2.9028855822980404, 4.511721627786756, 0.2725759689928964, 0.023520980939792935, 0.6655964499805123, 39.66403104364872, 49.62534852325916, 35.0362403690815, 19.558979272842407, 20.75693529099226, 34.07716803252697, 44.99074101448059, 51.50278598070145, 59.54768769443035, 40.91724559664726, 2.410235130228102, 0.028405540906533133, 0.06903989808051847, 0.0211277977359714, 0.13368393672863021, 0.07303458958631381, 0.01666446780291153, 0.04072061143233441, 0.03213827840227168, 0.024666005338076502, 0.0204549647969543, 0.0631758404779248, 0.018540355522418395, 0.02416811516013695, 0.06368364018271677, 0.06095415090385359, 0.10299483896233141, 0.18257732328493148, 0.18561683362349868, 0.07420335343340412, 0.12175754935014993, 0.1671281983726658, 0.15677111194236204, 0.10310483266948722, 0.09862302511464804, 0.26461943343747407, 0.10916571525740437, 0.19051830342505127, 0.17949322471395135, 0.13165126845706254, 3.2287361472845078, 68.59132021665573, 77.49993458390236, 73.58120486140251, 61.13648124039173, 41.824184730648994, 20.41593588888645, 46.73474483191967, 57.604004591703415, 66.8629677593708, 49.236070811748505, 0.3381800127681345, 0.18928574456367642, 1.3914494728669524, 6.207201099023223, 22.906852327287197, 3.7082606786862016, 34.00323919951916, 81.2472403049469, 65.88420107960701, 70.73549956083298, 57.34050013124943, 64.86965551972389, 64.6413941681385, 70.71238160133362, 60.0873651355505, 67.15347737073898, 60.80996096134186, 66.04372411966324, 64.76338282227516, 66.20542824268341, 62.24292866885662, 61.66009694337845, 54.92712043225765, 49.06178556382656, 48.165656849741936, 46.21525190770626, 47.543140053749084, 47.90851704776287, 46.2496742606163, 48.31473425030708, 46.829203963279724, 49.544914439320564, 51.34602539241314, 54.18003112077713, 56.071182042360306, 51.5280432254076, 46.72912873327732, 47.74755388498306, 44.497706070542336, 47.8636072576046, 52.905290722846985, 59.85398165881634, 58.179460912942886, 54.81339253485203, 44.34192582964897, 47.5320066511631, 43.570453226566315, 45.61162769794464, 42.61098191142082, 43.927926644682884, 43.96594360470772, 45.911788791418076, 44.89066578447819, 54.90568198263645, 55.94264633953571, 57.12704658508301, 55.727805867791176, 60.75719699263573, 59.58662040531635, 62.315968349575996, 50.370560735464096, 57.555503994226456, 38.441249057650566, 43.02189186215401, 59.32230658829212, 56.195340380072594, 55.70786453783512, 53.97648364305496, 53.82125437259674, 52.947745844721794, 53.74118506908417, 56.07817366719246, 57.01901078224182, 54.74670611321926, 50.008721351623535, 44.55631412565708, 46.05419375002384, 45.08063659071922, 44.87914480268955, 45.21359145641327, 45.499750301241875, 44.60877411067486, 43.43882828950882, 44.42832559347153, 46.65170028805733, 46.61414310336113, 50.14478825032711, 52.870716378092766, 55.11714443564415, 59.447156488895416, 53.563145622611046, 44.660538733005524, 46.45093806087971, 45.220997259020805, 44.226541221141815, 44.69463050365448, 46.659261882305145, 47.20839701592922, 46.9043031334877, 47.283055409789085, 45.12646213173866, 46.1417980492115, 46.584656685590744, 49.82033506035805, 46.56278505921364, 44.26227830350399, 46.503854021430016, 52.607569098472595, 60.16696326434612, 60.32613292336464, 63.53877313435078, 61.10762558877468, 64.71454784274101, 62.95481286942959, 62.119465693831444, 64.67265889048576, 65.12041926383972, 62.08166532218456, 41.68146438896656, 3.4533620439469814, 9.857856631278992, 11.277683693915606, 0.24959863163530827, 0.24502766988007352, 0.9222821169532835, 44.71619054675102, 59.44288171827793, 56.21661923825741, 22.193700894713402, 24.28445890545845, 38.34287993609905, 53.365092650055885, 58.843342289328575, 69.31559175252914, 47.171208411455154, 2.9451735131442547, 0.15141374082304537, 0.12946908711455762, 0.19448612176347524, 0.27449735964182764, 0.25699585501570255, 0.11087940845754929, 0.1294426221284084, 0.22372340055881068, 0.09760863540577702, 0.11687317863106728, 0.184137154428754, 0.12218212461448275, 0.21831514779478312, 0.18834489426808432, 0.12611348123755306], [0.03169214374793228, 0.04579198110150173, 0.02545925173762953, 0.05936577304964885, 0.03235991709516384, 0.019934741540055256, 0.02246810901851859, 0.07501120344386436, 0.021970422931190114, 0.01363632067295839, 0.0707939121639356, 0.12732306320685893, 0.029846188699593768, 0.04140408862440381, 7.295616595074534, 58.15157040953636, 64.10666406154633, 61.078336760401726, 45.53735688328743, 28.20241156965494, 24.30813353508711, 34.749758541584015, 34.66143608093262, 58.377092108130455, 20.75012605637312, 0.46354523103218526, 0.42284217139240354, 0.7079068233724684, 5.3081797901540995, 3.1064943317323923, 0.9066217322833836, 56.30932666361332, 63.21618564426899, 68.06142345070839, 60.02708896994591, 53.41648869216442, 48.08971792459488, 64.7182260453701, 61.8361908942461, 63.56807716190815, 59.49615105986595, 61.15431368350983, 55.7280832529068, 60.00825718045235, 57.595257461071014, 58.205348923802376, 54.890687987208366, 56.43198028206825, 46.75921551883221, 42.131409645080566, 42.3460753262043, 43.53595867753029, 42.132754772901535, 43.34572188556194, 42.97784082591534, 41.862517073750496, 41.08956255018711, 42.01279900968075, 41.7339813709259, 41.978555247187614, 41.15744210779667, 40.8344404399395, 39.86394211649895, 42.44982495903969, 41.110719814896584, 41.64592109620571, 43.493172973394394, 44.21076826751232, 42.281919568777084, 41.554513201117516, 40.77383369207382, 40.67049063742161, 40.858242362737656, 39.268282279372215, 40.162708684802055, 38.269118294119835, 40.716209784150124, 44.72099728882313, 51.27736307680607, 52.76293136179447, 53.416990265250206, 51.33551515638828, 55.472676157951355, 53.50576490163803, 56.19443602859974, 49.59008261561394, 53.973253816366196, 31.709767766296864, 32.494545355439186, 54.96422924101353, 48.21219675242901, 53.85051280260086, 51.27003327012062, 52.99308121204376, 52.05210730433464, 54.85517889261246, 48.620982617139816, 53.07644873857498, 53.44282507896423, 53.43087092041969, 41.03746734559536, 41.184458658099174, 41.949752792716026, 42.21844017505646, 39.34208571910858, 39.81560491025448, 39.346204698085785, 41.06146685779095, 40.33238098025322, 42.693726271390915, 42.79637396335602, 42.16536842286587, 43.95946495234966, 47.20787264406681, 46.36092089116573, 42.849426716566086, 39.81444217264652, 41.674392968416214, 40.401423275470734, 40.00823937356472, 41.18681453168392, 42.528697326779366, 42.14853912591934, 41.34281516075134, 41.98578245937824, 43.33336874842644, 41.20695725083351, 42.68785558640957, 42.698742002248764, 40.91166749596596, 40.564464926719666, 47.630504965782166, 52.197905480861664, 55.162407606840134, 54.81567621231079, 58.32680180668831, 56.47894576191902, 56.28455199301243, 55.27005583047867, 58.951115906238556, 60.84166266024113, 59.09923955798149, 56.07604958117008, 54.26502116024494, 12.01841214671731, 2.052775723859668, 4.094819873571396, 0.08940957341110334, 0.3087869274895638, 0.20414210128365085, 15.890972446650267, 52.49611347913742, 37.68392689526081, 33.233305513858795, 14.272877722978592, 13.554818853735924, 35.756100341677666, 47.75731936097145, 48.985500857234, 45.35257279872894, 8.327477350831032, 0.15683679201174527, 0.045942681608721614, 0.06978695877478458, 0.05506893096026033, 0.05552352980885189, 0.04963224280800205, 0.029727699256909546, 0.08650099276565015, 0.037262767291394994, 0.06738173236954026, 0.052142204804113135, 0.028810300827899482, 0.046596710380981676, 0.05051826694398187, 0.06859833505586721, 0.02310065447090892, 0.028261833285796456, 0.043264964551781304, 0.09723362818476744, 0.021036190737504512, 0.05223041647695936, 0.048234893765766174, 0.01493245468736859, 0.0723581516649574, 0.020667788630817086, 0.08563503259210847, 0.12342021247604862, 0.031040814537846018, 0.0791972057777457, 10.285586379468441, 70.12294963002205, 69.37967151403427, 67.59084150195122, 51.84014327824116, 31.84509750455618, 18.571220375597477, 33.49722035229206, 37.08474084734917, 65.2660046517849, 21.862949542701244, 0.4163699608761817, 0.4164320934796706, 1.2793829175643623, 10.208068639039993, 2.7438118681311607, 1.4924814202822745, 56.83124765753746, 67.11221158504486, 69.27503272891045, 63.41307207942009, 53.91727142035961, 51.08626373112202, 66.75360202789307, 64.71217676997185, 65.78844621777534, 60.55165082216263, 61.53596520423889, 57.08581879734993, 59.47978913784027, 58.30697447061539, 60.24298958480358, 57.94375956058502, 58.05570535361767, 49.039286971092224, 43.882701471447945, 44.06444571912289, 45.36447376012802, 44.99869778752327, 43.28275166451931, 45.61418876051903, 43.3646372705698, 42.43787840008736, 43.70568037033081, 41.91881485283375, 43.246072232723236, 44.24853444099426, 42.7347032725811, 42.049858421087265, 43.770839273929596, 43.15581567585468, 43.57813261449337, 46.18726260960102, 46.01630598306656, 43.59674021601677, 42.89840988814831, 42.45647840201855, 42.74066515266895, 42.94580474495888, 41.39451898634434, 43.2695359736681, 40.90776510536671, 43.31124633550644, 47.18360714614391, 53.01649935543537, 54.06092271208763, 56.74349136650562, 53.2591999322176, 58.38801272213459, 54.55163978040218, 56.657938957214355, 50.9327557682991, 54.67112056910992, 32.557751163840294, 35.66347271203995, 58.86662743985653, 50.24396672844887, 54.15152885019779, 52.21278168261051, 55.93254268169403, 52.3138714581728, 56.32848143577576, 51.33257791399956, 54.190324768424034, 55.813650861382484, 55.391554310917854, 41.68489560484886, 43.32028605043888, 44.24202539026737, 42.20112070441246, 42.141133323311806, 41.277842447161674, 41.128445863723755, 43.90522666275501, 43.21338638663292, 44.52449083328247, 45.06884582340717, 44.928720742464066, 45.51412872970104, 49.07122045755386, 48.21704909205437, 44.88255321979523, 42.18496777117252, 43.34099493920803, 43.04159760475159, 43.06298665702343, 43.03096957504749, 43.53733420372009, 43.86522240936756, 42.94295869767666, 43.97868052124977, 45.201610699296, 44.213215336203575, 44.24051307141781, 43.938250690698624, 43.41863617300987, 43.810155764222145, 48.81325230002403, 54.04148295521736, 56.58828489482403, 57.98085317015648, 58.34705092012882, 57.64082081615925, 58.06278057396412, 57.7438522875309, 61.31252959370613, 64.24737051129341, 58.9004760235548, 57.67565354704857, 56.29811726510525, 16.29891950637102, 1.2336135422810912, 6.38095342554152, 1.5926359710283577, 0.14756080694496632, 0.16828315827297047, 16.53298694640398, 59.999586045742035, 36.871602684259415, 33.32285910844803, 20.69468893110752, 22.67414141446352, 43.257433623075485, 55.14043338596821, 52.96552889049053, 57.295727133750916, 13.250398188829422, 0.45769799791742116, 0.032040808437159285, 0.05456420003611129, 0.034148615450249054, 0.015158630685618846, 0.024691336693649646, 0.026527899863140192, 0.03770014089241158, 0.026815213059308007, 0.04831774713238701, 0.05052497595897876, 0.0071437470160162775, 0.012277358291612472, 0.023897465034679044, 0.013668080882780487, 0.13264378707390279, 0.12317286207689904, 0.10260052848025225, 0.18208127177786082, 0.08823151787510142, 0.13954886264400557, 0.15068671811604872, 0.13511460449080914, 0.17819353117374703, 0.17349423724226654, 0.19095081224804744, 0.2744868508307263, 0.22323750163195655, 0.21052559546660632, 13.714663926512003, 80.86191818118095, 79.4180716574192, 75.25771290063858, 60.418912544846535, 40.84270119667053, 34.96398724615574, 50.67566156387329, 51.18200719356537, 71.3555958867073, 27.066285833716393, 0.4334326187381521, 0.8803966676350683, 1.3032253319397569, 17.85620704293251, 14.661192186176777, 1.346889620181173, 62.1259481459856, 66.33251622319221, 72.79293715953827, 65.98070070147514, 57.65656717121601, 52.616323828697205, 72.55436316132545, 65.43530076742172, 68.08180555701256, 63.03207412362099, 64.04476538300514, 57.21332095563412, 60.88541731238365, 61.2812914699316, 63.902333825826645, 59.53561194241047, 61.18711732327938, 51.75386890769005, 46.168924793601036, 46.35817363858223, 46.90202705562115, 45.749374106526375, 45.13391353189945, 46.715267077088356, 46.323705688118935, 43.92115920782089, 47.58314810693264, 46.002797707915306, 45.51730155944824, 47.21033491194248, 45.17403557896614, 45.316060557961464, 46.02754198014736, 45.518677085638046, 45.53162679076195, 47.00104974210262, 49.11959566175938, 45.18230013549328, 44.96398665010929, 46.035597547888756, 45.112847462296486, 45.01151829957962, 43.400313556194305, 45.92026233673096, 40.55476024746895, 45.63838966190815, 50.30991978943348, 56.11583724617958, 58.87859679758549, 59.4121565669775, 55.56502640247345, 59.7085976600647, 58.63793671131134, 59.08776417374611, 53.37249465286732, 55.08054479956627, 36.22719146311283, 39.003402292728424, 61.08825422823429, 52.76620298624039, 57.042364329099655, 55.97477741539478, 57.608720138669014, 54.709133729338646, 58.52545514702797, 51.61307506263256, 55.941198617219925, 57.24970780313015, 58.36583711206913, 43.902107030153275, 44.328440353274345, 46.53477296233177, 45.61796195805073, 42.991850674152374, 44.30260933935642, 45.075476467609406, 45.53594335913658, 44.806884080171585, 45.89008055627346, 47.271203845739365, 47.68838346004486, 47.57050238549709, 53.13624992966652, 51.139187291264534, 46.656081452965736, 43.776858150959015, 45.685609728097916, 46.90736196935177, 44.74224574863911, 45.2234823256731, 45.98659157752991, 47.28474251925945, 45.60247398912907, 47.4874160438776, 47.78799891471863, 45.34805864095688, 47.35793799161911, 46.73756808042526, 46.056184843182564, 46.29531741142273, 52.9739036411047, 58.03447209298611, 58.53824146091938, 59.45994660258293, 61.07404299080372, 60.64747788012028, 60.3307268768549, 59.944652393460274, 64.25012156367302, 65.29528588056564, 62.417943477630615, 59.527487978339195, 57.82939709722996, 17.23490048199892, 4.418691219761968, 14.259317200630903, 2.3032898688688874, 0.6688950886018574, 0.2808584558079019, 20.04208344966173, 68.599953353405, 51.518254950642586, 43.07047985494137, 23.17616857588291, 24.02107033878565, 49.51646916568279, 63.46348017454147, 60.43831430375576, 66.30138829350471, 17.489348128437996, 0.8427636057604104, 0.24478204868501052, 0.3076646220870316, 0.12366210066829808, 0.13744806521572173, 0.10460486155352555, 0.1883136943797581, 0.29335966624785215, 0.08760462573263794, 0.1873179548420012, 0.1635416955105029, 0.12711637507891282, 0.16492204566020519, 0.10922665300313383, 0.22012359841028228], [0.0481998087343527, 0.06212390180735383, 0.04131681576836854, 0.0344834390853066, 0.02330763018107973, 0.06827380129834637, 0.01632331364817219, 0.0516128605522681, 0.06598948559258133, 0.02709851680265274, 0.03821127655101009, 0.05942082185356412, 0.031070680415723473, 0.16301183175528422, 17.19451054930687, 62.71539531648159, 59.364773109555244, 53.395757004618645, 36.90746895968914, 27.675142362713814, 41.41800172626972, 44.66295160353184, 40.05524285137653, 60.866194143891335, 7.522761756554246, 0.27831119718030095, 0.3397686540847644, 0.7568912417627871, 4.9518125876784325, 1.3177582458592951, 14.429261181503534, 69.76819306612015, 63.26668493449688, 66.68177828192711, 57.36712150275707, 54.153937920928, 47.79366061091423, 53.245159685611725, 60.96580199897289, 63.26913200318813, 63.49912606179714, 59.2792396992445, 61.17571413516998, 57.125868648290634, 54.509655833244324, 57.674468010663986, 56.156479865312576, 57.1353567391634, 49.37093697488308, 41.64164252579212, 42.44476743042469, 41.88071429729462, 43.36828887462616, 42.88260653614998, 41.76291301846504, 41.945257633924484, 42.870074808597565, 42.30608247220516, 42.09871619939804, 42.235383465886116, 40.859690085053444, 41.014755964279175, 40.01500681042671, 39.94088798761368, 41.3928584754467, 42.28603474795818, 40.66737100481987, 38.68874117732048, 42.85558998584747, 40.09536109864712, 42.59113937616348, 41.03583723306656, 40.30313014984131, 39.882333129644394, 39.6574991941452, 40.58242276310921, 40.941446498036385, 45.190948471426964, 53.726673647761345, 52.20962405204773, 53.81696060299873, 54.418829306960106, 56.216668635606766, 51.05214536190033, 57.69342139363289, 49.078432470560074, 54.7141532599926, 30.497744902968407, 34.19297821819782, 53.92270512878895, 47.303961887955666, 53.88469196856022, 52.126826494932175, 53.32810543477535, 50.83768866956234, 55.1117867231369, 50.910264775156975, 50.85815817117691, 51.06418691575527, 55.89000016450882, 49.61900666356087, 40.715723410248756, 41.347678899765015, 43.004534393548965, 41.399173736572266, 39.97105076909065, 40.62188744544983, 40.72724439203739, 41.35243244469166, 41.366940066218376, 41.39606170356274, 42.39227704703808, 41.07090175151825, 43.259911090135574, 44.01165895164013, 43.660295605659485, 42.68405959010124, 41.10050216317177, 41.52683548629284, 42.00050286948681, 41.70001119375229, 40.319077894091606, 41.291263327002525, 41.42917312681675, 41.90450482070446, 40.71699634194374, 41.462295949459076, 42.50725507736206, 40.2102555334568, 40.79631708562374, 45.7004327327013, 50.70267431437969, 56.53448738157749, 56.5145118534565, 55.630785673856735, 55.197730511426926, 57.2574669867754, 57.26652950048447, 62.67343796789646, 58.99060718715191, 59.96473051607609, 57.93500483036041, 63.88971850275993, 62.471459805965424, 47.11450405418873, 5.8219668455421925, 3.9972558338195086, 4.322608625516295, 0.05578383439569734, 0.05775735720817465, 1.0422856151126325, 43.283621817827225, 46.96660839021206, 49.06631112098694, 26.480321176350117, 16.466574110090733, 29.216360561549664, 43.94019238650799, 45.67179746925831, 53.56063015758991, 22.43913732469082, 1.4929153094999492, 0.1467455577221699, 0.02223845513071865, 0.09156717482255772, 0.01397264622937655, 0.044460553326644, 0.09306320353061892, 0.025913583413057495, 0.10275445732986555, 0.05831406444485765, 0.035544814163586125, 0.01906743251311127, 0.09347999366582371, 0.006696764457956306, 0.04542757546005305, 0.03697885498695541, 0.04399119316076394, 0.03508419278659858, 0.10728408145951107, 0.023084330932761077, 0.02561534580308944, 0.04025157781143207, 0.022639736234850716, 0.045109108759788796, 0.034103563375538215, 0.006270212297749822, 0.05738029794883914, 0.033349055229336955, 0.21914749610004947, 24.406538754701614, 74.90595817565918, 66.8433304131031, 60.16476698219776, 44.12290558218956, 34.05691131949425, 37.99388766288757, 47.24837847054005, 44.683770686388016, 69.95876803994179, 8.2540681399405, 0.5529452604241669, 0.6459507916588336, 2.8996510058641434, 5.0246176309883595, 0.45089864870533347, 16.006415002048016, 73.26673373579979, 67.46145084500313, 68.25198322534561, 60.67950256168842, 54.794131368398666, 49.600627049803734, 54.89370122551918, 63.22526715695858, 65.90642228722572, 65.41975200176239, 60.9964207559824, 61.771613359451294, 59.67062629759312, 56.236169189214706, 59.739433005452156, 58.11052121222019, 58.855706825852394, 50.76203852891922, 42.40544334053993, 45.61616085469723, 45.231492295861244, 45.00209480524063, 44.77609433233738, 44.02796007692814, 43.77970039844513, 44.052730947732925, 43.07760067284107, 43.42978477478027, 44.40861605107784, 41.723322942852974, 45.348123237490654, 41.33752964437008, 43.52397032082081, 42.31252692639828, 42.62056119740009, 42.3362110555172, 42.203552573919296, 43.85416880249977, 42.2662378102541, 43.82879376411438, 42.80466131865978, 42.755716145038605, 43.19636330008507, 42.775893062353134, 41.97795107960701, 43.5181338340044, 47.86929175257683, 55.78371986746788, 54.32276666164398, 55.691738203167915, 54.44287821650505, 58.50348852574825, 53.241644874215126, 58.50275136530399, 51.712500527501106, 56.191722974181175, 33.851817324757576, 37.00358860194683, 55.61118632555008, 49.75257329642773, 56.45956680178642, 53.65195445716381, 54.37436029314995, 52.09516279399395, 54.1226352006197, 50.98359704017639, 51.71631932258606, 52.7799316495657, 58.20880673825741, 50.3067659586668, 42.316315323114395, 42.78222732245922, 45.45620083808899, 42.91781164705753, 42.69870400428772, 41.97885923087597, 42.618513107299805, 42.289363369345665, 42.10231840610504, 43.293877467513084, 44.850197955965996, 43.25579211115837, 45.75271412730217, 45.29436372220516, 44.150659292936325, 43.172075003385544, 42.73508705198765, 44.784313291311264, 44.327076226472855, 44.30080063641071, 41.56752750277519, 43.697427213191986, 44.21560160815716, 44.05878782272339, 42.05487035214901, 43.55103246867657, 43.6589352786541, 43.27200584113598, 43.42299073934555, 47.530175149440765, 52.18990311026573, 58.313996493816376, 57.97930285334587, 58.15406687557697, 56.91408321261406, 57.826049476861954, 57.28420615196228, 65.17670944333076, 59.63471822440624, 60.88627986609936, 59.183982610702515, 67.09062874317169, 63.466071635484695, 53.66810359060764, 6.262380313128233, 4.321650126948953, 5.997064774855971, 0.2705426624743268, 0.05918878196098376, 1.1441320250742137, 49.73062947392464, 49.55345258116722, 35.999291092157364, 23.00751082599163, 21.541131511330605, 33.63872095942497, 48.1623700261116, 51.00382715463638, 61.63516268134117, 32.17883549630642, 2.4896256951615214, 0.2018356102053076, 0.029867323210055474, 0.051554071324062534, 0.029039615183137357, 0.011810903633886483, 0.052670881123049185, 0.027088939386885613, 0.06511692772619426, 0.028417584107955918, 0.050019120681099594, 0.011554162283573532, 0.09452447004150599, 0.009117544886976248, 0.11258546495810151, 0.09869004847132601, 0.17476094973972067, 0.10002902388805524, 0.2478480091667734, 0.14325280295452103, 0.12651545810513198, 0.0758539121306967, 0.25697418430354446, 0.11958891962422058, 0.12334740778896958, 0.2041261302656494, 0.26712694263551384, 0.12433479074388742, 0.32926364277955145, 31.39449868351221, 86.42024472355843, 75.31630575656891, 70.71020051836967, 51.06157265603542, 40.16413740813732, 54.1752889752388, 61.490812227129936, 55.65466359257698, 74.60531070828438, 10.332987885922194, 0.8000937954057008, 0.4617978888563812, 2.778389062732458, 15.724004656076431, 4.718223921954632, 17.40958660840988, 77.29846939444542, 69.5249605178833, 71.790611743927, 62.96478733420372, 58.41311037540436, 52.56012864410877, 58.07440035045147, 67.08933681249619, 68.27475160360336, 68.27782943844795, 63.64583618938923, 63.370749950408936, 62.695890963077545, 57.05847546458244, 63.78254905343056, 59.21325623989105, 61.27119921147823, 53.24175886809826, 45.00175662338734, 47.18451149761677, 46.95054665207863, 47.88489371538162, 48.92574906349182, 47.35783539712429, 47.684750854969025, 46.23255617916584, 44.48692984879017, 46.61404050886631, 46.15481615066528, 44.984691739082336, 46.790195256471634, 43.129714876413345, 45.66582798957825, 44.83871877193451, 45.52593469619751, 44.8958221077919, 42.53005005419254, 48.236108869314194, 45.62365785241127, 46.70406527817249, 45.394883528351784, 45.881637409329414, 44.82217065989971, 45.62086500227451, 44.493803679943085, 45.66041328012943, 49.532523304224014, 57.87027910351753, 57.167039439082146, 57.932322174310684, 57.601766511797905, 61.649742498993874, 56.34423919022083, 61.34274937212467, 52.74864412844181, 58.060804679989815, 36.13664232194424, 39.03413124382496, 57.68538862466812, 52.453259378671646, 57.530292347073555, 57.006357461214066, 57.451066598296165, 54.29089777171612, 58.255814015865326, 52.097138687968254, 54.726403802633286, 56.16321310400963, 60.59729777276516, 53.35926756262779, 45.306466072797775, 43.80352132022381, 47.96343930065632, 45.4986597597599, 43.46914306282997, 44.759299233555794, 44.322866052389145, 44.860419407486916, 44.53820429742336, 45.113926604390144, 45.767149552702904, 44.73316043615341, 47.6502601057291, 48.78027006983757, 48.11170734465122, 46.42419509589672, 45.226837545633316, 46.56055077910423, 45.874493792653084, 47.64813221991062, 43.37859772145748, 46.33869968354702, 46.82296849787235, 47.73473337292671, 45.28794966638088, 43.76906096935272, 45.89323438704014, 44.75303336977959, 44.6353954821825, 50.2866118401289, 55.857694298028946, 60.806605741381645, 61.61378122866154, 60.16770422458649, 59.81145814061165, 61.7424651235342, 60.561294704675674, 67.11943879723549, 61.50445729494095, 62.85427026450634, 61.27174258232117, 70.9586463868618, 64.9906562268734, 55.4667142778635, 9.058114495128393, 9.102204479277134, 10.659456867724657, 0.285763755091466, 0.25455507973674685, 1.3637457531876862, 56.08051434159279, 62.698497623205185, 63.592555448412895, 36.915790513157845, 25.026646479964256, 39.4379735738039, 57.580286264419556, 60.84557645022869, 70.35027623176575, 40.41712783277035, 3.103696731850505, 0.29870764177758247, 0.14897388580720872, 0.19877560174791142, 0.15989580599125475, 0.1192186250409577, 0.159893445961643, 0.1190786188817583, 0.2562777529237792, 0.145787445071619, 0.15236646548146382, 0.11191440760740079, 0.1435976938228123, 0.10735555028077215, 0.24708475481020287], [0.07350055442657322, 0.022260849436861463, 0.023514036292908713, 0.06095035852922592, 0.010980214028677437, 0.06284882794716395, 0.02758186645223759, 0.029541874755523168, 0.04956103744916618, 0.07368260325165465, 0.03401914407731965, 0.02279846121382434, 0.058052331223734654, 1.5465753176249564, 37.88232184946537, 64.7273987531662, 56.14383414387703, 53.76652590930462, 30.07861979305744, 14.990677256137133, 34.70114395022392, 27.642405219376087, 49.000912830233574, 46.4604527503252, 1.118234870955348, 0.07957922629429959, 2.2088924841955304, 4.884219914674759, 5.416543800383806, 3.5339730558916926, 36.462729424238205, 64.423498660326, 63.868006467819214, 61.35596886277199, 58.55973310768604, 49.76505942642689, 48.910831063985825, 44.42517936229706, 52.0132277905941, 60.725844874978065, 58.540517538785934, 59.23732414841652, 58.44529464840889, 59.440088868141174, 54.23148036003113, 52.979971915483475, 55.62176875770092, 58.47759671509266, 51.03084750473499, 43.004336804151535, 40.85611067712307, 42.92733773589134, 43.46198044717312, 42.27251507341862, 42.920566499233246, 40.7721883803606, 41.535476222634315, 42.34642490744591, 41.6264471411705, 43.08646559715271, 43.11667017638683, 41.82575784623623, 41.71712547540665, 40.056530982255936, 42.32552982866764, 40.03734201192856, 42.37058401107788, 41.80905394256115, 40.62540605664253, 40.01077003777027, 41.68754406273365, 38.092005997896194, 41.814795434474945, 38.71869497001171, 40.48329748213291, 39.05476413667202, 41.543562188744545, 44.79784816503525, 55.13629540801048, 52.535057589411736, 54.128935262560844, 51.16078533232212, 53.04125502705574, 51.522677913308144, 54.895601123571396, 48.167936727404594, 56.81108973920345, 24.68354009091854, 35.8425685018301, 48.65611173212528, 49.56362843513489, 56.5512140840292, 50.188618898391724, 51.93576134741306, 51.183367520570755, 53.43198426067829, 52.82758869230747, 51.93743705749512, 51.00965604186058, 53.11249740421772, 51.57128870487213, 43.17275516688824, 39.12297047674656, 41.56801387667656, 43.46734955906868, 41.3483514636755, 40.067326202988625, 40.02730295062065, 40.892071947455406, 41.06869027018547, 42.19590738415718, 40.85155472159386, 40.41503794491291, 41.41299359500408, 40.26352107524872, 41.4389044046402, 40.43386213481426, 41.94471426308155, 43.21219705045223, 40.38312345743179, 43.4119713306427, 42.94798202812672, 42.42346577346325, 42.345212772488594, 40.56555546820164, 39.17791932821274, 42.263783141970634, 40.65653018653393, 40.407024174928665, 41.54315561056137, 47.63373479247093, 52.63227917253971, 54.01439040899277, 53.328914791345596, 57.176394537091255, 55.463697239756584, 55.96382260322571, 57.30159401893616, 56.60937376320362, 56.67910382151604, 60.33241778612137, 59.0110082924366, 62.6801598072052, 56.20720714330673, 67.49730572104454, 17.76399739086628, 1.6750237438827753, 2.47652898542583, 0.32799465931020677, 0.4371757444459945, 0.06607815739698708, 19.860096015036106, 49.61593262851238, 53.02042834460735, 40.79504035413265, 19.905389584600925, 21.13517079502344, 28.464103527367115, 45.44333852827549, 47.19080775976181, 44.93643432855606, 6.465223878622055, 0.18999010208062828, 0.0715141961700283, 0.05952486353635322, 0.0665448495419696, 0.0688724398787599, 0.06632127755437978, 0.07746029819827527, 0.017868511495180428, 0.016083614791568834, 0.06217133246536832, 0.03734753539902158, 0.009099343715206487, 0.018974587983393576, 0.0315164996573003, 0.0524272711481899, 0.06829588761320338, 0.029193985610618256, 0.02346968925849069, 0.008647824779473012, 0.047098324284888804, 0.057705867002368905, 0.045217725783004425, 0.02925218483142089, 0.023070710667525418, 0.04039699422719423, 0.07267785404110327, 0.04841815971303731, 1.6422120295464993, 51.4160480350256, 72.54715114831924, 63.58640357851982, 59.894574880599976, 38.08835819363594, 20.945688262581825, 29.216696843504906, 31.683666966855526, 53.58969859778881, 52.776850014925, 1.088413477409631, 0.09825748027651571, 3.557418747805059, 7.060533184558153, 4.070973778143525, 3.6147780949249864, 40.30647777020931, 67.87403270602226, 66.29059687256813, 63.195849135518074, 56.84366159141064, 53.215901255607605, 49.762133583426476, 47.10334025323391, 54.17884558439255, 63.123561814427376, 61.10807776451111, 61.42609030008316, 60.58388829231262, 60.826421678066254, 56.76515780389309, 56.1979166418314, 56.89164541661739, 62.1365799754858, 53.87544326484203, 44.2446206510067, 43.53208288550377, 45.118790343403816, 45.67228764295578, 44.70102556049824, 43.62636722624302, 43.91277685761452, 43.467782735824585, 44.591561034321785, 42.72725187242031, 44.09547485411167, 43.96113306283951, 44.68755528330803, 45.02641350030899, 42.84550532698631, 44.64254669845104, 42.62190632522106, 43.50720942020416, 43.399010226130486, 41.62214197218418, 42.21687085926533, 44.467452093958855, 40.90931162238121, 42.940048053860664, 41.01646967232227, 42.66462743282318, 41.7814864218235, 43.87795552611351, 47.472361251711845, 57.94618383049965, 54.12771932780743, 55.7183063775301, 54.40688654780388, 57.12285540997982, 52.278179973363876, 57.35043279826641, 50.10624311864376, 57.52145782113075, 26.605817042291164, 37.494092881679535, 51.324446350336075, 50.3498974442482, 57.673936039209366, 51.99724204838276, 53.90775293111801, 53.02403435111046, 54.11752827465534, 53.88623468577862, 52.04698517918587, 51.39880836009979, 54.048816561698914, 52.70357854664326, 46.25150576233864, 41.5316916257143, 43.4190009534359, 45.122597739100456, 43.49359855055809, 41.65369547903538, 41.86554171144962, 43.79630170762539, 44.0547676384449, 43.81932087242603, 43.314141780138016, 41.87635213136673, 42.91989013552666, 42.40366503596306, 42.55123391747475, 42.16666415333748, 44.437198117375374, 44.745057597756386, 43.071539998054504, 44.8106686770916, 44.91335816681385, 43.593400195240974, 43.89150179922581, 42.486994564533234, 43.20878863334656, 42.76885583996773, 42.97064021229744, 42.88338169455528, 43.04499842226505, 48.86626325547695, 55.7739581912756, 56.26608118414879, 56.8230514973402, 59.70914103090763, 55.979014188051224, 57.7020051330328, 58.4430755674839, 57.76108056306839, 58.957324773073196, 62.52326242625713, 62.57599979639053, 65.35152286291122, 59.69879798591137, 68.87750566005707, 21.047064922749996, 0.8976420422550291, 5.034662866964936, 0.9627388429362327, 0.6434735027141869, 0.06323726061964408, 21.16537917405367, 55.87435260415077, 46.84591926634312, 34.85248222947121, 22.87152372300625, 27.501223795115948, 34.341622442007065, 50.70092260837555, 52.20863230526447, 56.37333802878857, 9.171862341463566, 0.3807184926699847, 0.04503460084379185, 0.03514696363708936, 0.03994053629867267, 0.06119046185631305, 0.06380463993991725, 0.07301438090507872, 0.023679607584199402, 0.07523622261942364, 0.12764983082888648, 0.0148338325379882, 0.05953642619715538, 0.057369147179997526, 0.04720488555904012, 0.1290301067638211, 0.15968939987942576, 0.1139468235487584, 0.17586994101293385, 0.10368422736064531, 0.12479088502004743, 0.11449807600001805, 0.08791937798378058, 0.09029164561070502, 0.19099939323496073, 0.17056288750609383, 0.1238619684590958, 0.18161616782890633, 2.1051703998818994, 61.81294374167919, 84.52904060482979, 72.08188131451607, 69.67970341444016, 40.51642030477524, 26.506570167839527, 44.2351895570755, 41.16446413099766, 62.078804075717926, 59.10564221441746, 1.724243809003383, 0.3176517627434805, 3.3929421985521913, 10.85874667391181, 15.881524253636599, 4.843331258744001, 45.53112521767616, 69.95710372924805, 70.58106824755669, 65.91688692569733, 62.388529255986214, 55.55732801556587, 52.85741329193115, 48.51749897003174, 57.1333846449852, 66.53083518147469, 63.87718677520752, 64.59274917840958, 63.59500251710415, 62.49918311834335, 59.57888022065163, 58.62721748650074, 59.45246480405331, 65.56844562292099, 56.234102100133896, 47.84607879817486, 45.572793781757355, 47.20936596393585, 47.95834757387638, 46.60267531871796, 46.010188311338425, 45.358971655368805, 46.79695889353752, 46.99148565530777, 45.6306266784668, 48.11094358563423, 46.094175204634666, 46.672314181923866, 46.11570864915848, 44.894324988126755, 45.88930919766426, 44.524167850613594, 47.705794125795364, 45.29211424291134, 44.762627854943275, 43.42094644904137, 46.536285281181335, 43.12544010579586, 46.390711292624474, 42.656450271606445, 43.814939707517624, 44.562276005744934, 46.26067467033863, 48.41056890785694, 59.76737290620804, 57.14371249079704, 58.27778823673725, 57.147812470793724, 58.43714788556099, 55.67219965159893, 59.22987274825573, 53.09701703488827, 59.885079190135, 29.776456207036972, 41.09659977257252, 52.95753791928291, 52.632556557655334, 59.4997076690197, 54.966174736618996, 54.39359866082668, 54.547448605298996, 55.21975792944431, 56.43277443945408, 55.12879841029644, 53.21611404418945, 57.214707881212234, 54.96750086545944, 49.33706559240818, 43.721555918455124, 45.794333294034004, 49.14316579699516, 45.419453009963036, 43.46720516681671, 43.187296986579895, 45.257133319973946, 45.87754502892494, 46.7891351133585, 45.101098492741585, 44.138378351926804, 44.23300087451935, 44.440234154462814, 45.645905658602715, 44.38720420002937, 46.103005930781364, 45.517054572701454, 45.29879808425903, 46.57237574458122, 47.99166038632393, 48.264295756816864, 45.63293315470219, 44.572850838303566, 45.116936042904854, 45.51235802471638, 44.77873519062996, 43.821304365992546, 44.68933738768101, 51.0967967659235, 58.09464566409588, 59.76509302854538, 56.28582112491131, 62.23353557288647, 58.85938502848148, 59.926166385412216, 60.69931089878082, 59.593995809555054, 61.12130865454674, 64.63013157248497, 66.04809388518333, 67.63649985194206, 61.84846043586731, 71.98673442006111, 22.48164564371109, 5.186763480305672, 10.572872813791037, 0.6931113079190254, 0.6902624701615423, 0.2668354567140341, 25.154313929378986, 64.61003065109253, 70.77370271086693, 55.25039568543434, 28.959678635001183, 31.17094147950411, 43.58190581202507, 61.242370158433914, 59.69116039574146, 63.51504720747471, 11.63294468075037, 0.536411456996575, 0.14906046475516632, 0.15665135899325833, 0.25823898205999285, 0.14469225774519145, 0.17499600275186822, 0.12929631513543427, 0.11986746249021962, 0.13008891401113942, 0.1421243228833191, 0.18426147900754586, 0.11869095062138513, 0.1548926322720945, 0.1904209188069217], [0.013386505415837746, 0.05123135582834948, 0.03699928260175511, 0.08568396980990656, 0.06963288891711272, 0.0222306978321285, 0.03201136372808833, 0.011042639780498575, 0.037815177493030205, 0.048500823832000606, 0.11096980204456486, 0.09549764828989282, 0.08639440551633015, 4.5598849933594465, 54.472509026527405, 58.44742253422737, 54.84262056648731, 36.20849646627903, 20.04008285701275, 31.769599355757236, 60.79883135855198, 30.87955791503191, 60.534832924604416, 27.549475505948067, 0.3780028555775061, 0.36184241180308163, 9.083728920668364, 14.153314288705587, 0.7968329172581434, 6.505682682618499, 44.50979322195053, 69.13031369447708, 61.23933032155037, 60.24330876767635, 55.389806404709816, 58.18897180259228, 54.12415511906147, 45.68363003432751, 43.45537640154362, 50.22430658340454, 52.93843254446983, 54.90187458693981, 57.04362206161022, 57.19337962567806, 57.996945306658745, 56.0535129904747, 58.29799935221672, 55.32997481524944, 49.6566778421402, 40.67066162824631, 42.55180388689041, 40.51145017147064, 40.144135281443596, 41.473930925130844, 41.88391372561455, 42.82530941069126, 42.21312426030636, 40.82536272704601, 40.794880762696266, 42.03425645828247, 40.754302740097046, 41.52394384145737, 41.91764831542969, 39.66109000146389, 40.0361792743206, 40.6222902238369, 40.978114530444145, 39.27694581449032, 40.55030308663845, 40.25347821414471, 41.192711815238, 40.29603973031044, 41.141976937651634, 39.522655829787254, 40.37692219018936, 42.26276859641075, 42.779795452952385, 44.27691511809826, 53.35259132087231, 53.49353715777397, 52.46019400656223, 50.27963921427727, 56.858606189489365, 51.130690947175026, 55.2902327477932, 47.623961716890335, 54.570627361536026, 24.164786227047443, 33.284842148423195, 49.50628951191902, 51.124945655465126, 55.73208823800087, 51.29624426364899, 52.823226526379585, 50.24617820978165, 53.306917771697044, 52.542835772037506, 52.231393083930016, 50.310193374753, 53.00427921116352, 52.59851038455963, 46.663198471069336, 40.02301298081875, 41.61875255405903, 39.481564834713936, 41.26283325254917, 39.42037671804428, 42.331655099987984, 42.15240351855755, 41.53120905160904, 41.226203218102455, 43.67949977517128, 40.90656816959381, 42.05395460128784, 40.71995258331299, 40.30428908765316, 42.69751086831093, 41.507821306586266, 39.87023837864399, 42.47360408306122, 42.70725354552269, 40.35001963376999, 42.98556961119175, 43.87567184865475, 39.57374028861523, 42.94859379529953, 41.98136329650879, 40.95936253666878, 42.60764189064503, 41.96334846317768, 48.82697716355324, 53.20545941591263, 54.13836635649204, 52.92824909090996, 56.280752196908, 52.76929222047329, 57.30244517326355, 56.037052273750305, 60.30990779399872, 59.61954563856125, 60.13866998255253, 59.295324236154556, 59.2138946056366, 55.122483149170876, 67.9732757806778, 41.57830752432346, 1.2816589954309165, 4.975586961954832, 1.669873595237732, 0.07814820972271264, 0.10813614862854593, 5.045100906863809, 46.73316031694412, 40.64605414867401, 39.54877182841301, 21.759498193860054, 15.020201671868563, 25.808171443641186, 36.10242895781994, 44.80464220046997, 50.139818117022514, 17.060820423066616, 0.6419313792139292, 0.041357912195962854, 0.032260202133329585, 0.04198455200821627, 0.014078141593927285, 0.013145723951311084, 0.02902189826272661, 0.011100603369413875, 0.0719990189827513, 0.18548798194387928, 0.05033638881286606, 0.00950363144511357, 0.01560129487188533, 0.041165306320181116, 0.05669851656421088, 0.14805739279836416, 0.0741667952388525, 0.05728581141738687, 0.0819003747892566, 0.03559044511348475, 0.0771045422879979, 0.0050874789121735375, 0.03285945669631474, 0.06034632824594155, 0.15443175856489688, 0.05641838550218381, 0.10134419120731764, 6.98166461661458, 65.83191588521004, 64.61313888430595, 61.22644141316414, 44.266013503074646, 24.925752393901348, 34.90463823080063, 69.32832106947899, 30.639519095420837, 66.22014865279198, 30.15856560319662, 0.2021031841286458, 0.46641478955280036, 8.896694406867027, 14.488746989518404, 2.3282291181385517, 7.7662550657987595, 47.00670003890991, 70.54006844758987, 62.43375062942505, 61.8040332198143, 57.83470541238785, 62.30021819472313, 56.19384326040745, 48.306906670331955, 45.62081180512905, 53.404306545853615, 55.68114057183266, 56.303319185972214, 59.74994704127312, 57.95833557844162, 60.203787088394165, 58.52064460515976, 59.79774847626686, 57.507645562291145, 51.37086845934391, 43.26429225504398, 44.631006717681885, 43.110145926475525, 42.852341160178185, 44.16523531079292, 43.783503994345665, 44.81054328382015, 44.322569668293, 43.03487956523895, 43.81544128060341, 42.55142390727997, 43.01311433315277, 42.64325737953186, 45.15137739479542, 41.36864997446537, 43.08983601629734, 42.521082535386086, 42.93504752218723, 42.16374211013317, 44.774726405739784, 42.93164670467377, 44.14893418550491, 42.79710732400417, 42.54285156726837, 41.55477538704872, 41.821783259510994, 43.240532130002975, 44.16607886552811, 47.08488084375858, 56.0391079634428, 54.649389535188675, 52.73524224758148, 52.40647628903389, 58.851857632398605, 53.978208750486374, 56.69980511069298, 50.03023199737072, 55.2935803681612, 24.675682112574577, 33.22880655527115, 52.31608673930168, 54.02049668133259, 57.16225929558277, 53.62478591501713, 54.2867673933506, 51.55940294265747, 55.28025068342686, 53.43628942966461, 55.244832783937454, 52.17996284365654, 53.96925263106823, 54.33817483484745, 46.62222906947136, 40.83907999098301, 43.121910095214844, 42.11322762072086, 41.96139536798, 42.133362740278244, 41.97583459317684, 43.41070979833603, 43.82537014782429, 42.27917231619358, 42.83221364021301, 42.41088084876537, 43.177170529961586, 43.21363717317581, 41.657981649041176, 42.848826348781586, 44.30144280195236, 42.00402148067951, 43.88758420944214, 44.45564992725849, 41.97692133486271, 44.526466727256775, 44.935434982180595, 43.21813993155956, 44.86181013286114, 44.587924629449844, 43.014284670352936, 43.816072046756744, 44.49963256716728, 50.63264787197113, 55.79806789755821, 55.40225833654404, 54.04877096414566, 57.60103315114975, 56.82398244738579, 58.063814118504524, 57.919494062662125, 62.40668848156929, 60.27427330613136, 61.0230915248394, 60.36844365298748, 59.19358849525452, 57.97448471188545, 69.14783075451851, 44.05285634100437, 1.11658540321514, 4.361208379268646, 2.3722597304731607, 0.3891839931020513, 0.10183834281633608, 3.8320198003202677, 54.34238500893116, 44.41098712384701, 33.845908641815186, 20.173725485801697, 27.20895867794752, 36.97588428854942, 42.61869929730892, 51.04564391076565, 60.288682132959366, 24.803045578300953, 0.700624514138326, 0.20714244106784463, 0.011706977911671856, 0.029458672579494305, 0.08201908873161301, 0.029635253631568048, 0.035371645135455765, 0.017062750630429946, 0.013684324640053092, 0.1165118046628777, 0.022651616163784638, 0.03932370396796614, 0.009721846981847193, 0.03760304571187589, 0.1174276445817668, 0.14459282479947433, 0.26540361635852605, 0.16605684882961214, 0.2174906068830751, 0.1542273859377019, 0.1861791143892333, 0.07074403984006494, 0.1380254264222458, 0.1669440566911362, 0.3046724310843274, 0.21937649318715557, 0.27553158695809543, 9.597863182425499, 76.23112186789513, 71.27888560295105, 68.48211407661438, 51.01795859634876, 29.664329923689365, 40.61428785324097, 74.56590682268143, 44.98765558004379, 76.04477986693382, 36.3561337441206, 0.5404340161476284, 0.4189636482624337, 14.618802610784769, 22.710292674601078, 5.287245763465762, 9.987114295363426, 52.312959507107735, 71.7631696164608, 66.42350614070892, 63.42186480760574, 61.74806982278824, 64.89894434809685, 58.80741901695728, 50.8531728386879, 48.70258703827858, 56.47079139947891, 57.90383130311966, 59.27227467298508, 61.075369119644165, 59.89196062088013, 60.16331546008587, 59.64891046285629, 64.13968428969383, 60.404412522912025, 53.12727101147175, 43.64459104835987, 48.41708555817604, 44.47468310594559, 44.52088102698326, 47.605688497424126, 45.64310520887375, 47.932771146297455, 47.429081574082375, 45.74406199157238, 45.84922894835472, 45.69455064833164, 44.58844520151615, 45.77150031924248, 46.975127533078194, 43.51501800119877, 44.43193159997463, 43.54649931192398, 44.68802645802498, 44.55851420760155, 46.61257378757, 44.3479523062706, 46.60976193845272, 45.07475070655346, 45.325229465961456, 43.45851503312588, 43.69013920426369, 46.58803850412369, 46.42883464694023, 50.52195981144905, 57.98306465148926, 58.461831361055374, 55.15610374510288, 55.2121127396822, 61.501083076000214, 55.832421854138374, 57.88117691874504, 49.95281495153904, 56.870362758636475, 28.386633284389973, 37.01842300593853, 53.54009605944157, 56.31652347743511, 60.09202368557453, 55.648397728800774, 57.6047607511282, 54.52757187187672, 57.07909315824509, 56.22695468366146, 56.21404677629471, 54.184545278549194, 57.2470897436142, 57.346104830503464, 48.43973994255066, 43.94382879137993, 45.354795679450035, 44.54021818935871, 45.23678161203861, 43.30487407743931, 45.273932218551636, 46.340531185269356, 46.16022326052189, 45.49275867640972, 46.43586426973343, 45.59124559164047, 46.299652978777885, 44.799466878175735, 44.8380234092474, 46.35752387344837, 46.22879818081856, 44.61579993367195, 45.4116216301918, 47.3855435103178, 43.34441855549812, 47.785829231143, 48.267195001244545, 45.54451569914818, 46.6811753064394, 47.148622423410416, 44.11971375346184, 45.94453163444996, 46.746691390872, 53.0784360319376, 58.605782836675644, 60.34725978970528, 56.32338210940361, 59.99464251101017, 55.63968859612942, 61.33860759437084, 59.97547633945942, 64.49172019958496, 63.52449730038643, 65.56259393692017, 63.7304500490427, 63.3084636926651, 59.85894039273262, 72.85515502095222, 47.111696004867554, 3.7173122679814696, 14.620898198336363, 2.93493733741343, 0.46055983810219914, 0.18664231844013557, 5.775232203304768, 57.004385367035866, 56.76986575126648, 53.43253903090954, 28.331897221505642, 25.28142850846052, 35.99375858902931, 50.581825599074364, 59.988068863749504, 68.76728117465973, 28.6706680431962, 0.8774676185566932, 0.24565730796894059, 0.259969670441933, 0.1701587435672991, 0.13685969053767622, 0.10428523339214735, 0.10712133589549921, 0.08659404324134812, 0.16130446165334433, 0.2822566917166114, 0.12581093731569126, 0.08344501417013817, 0.08174476868589409, 0.12029506571707316], [0.02951395515992772, 0.03681664005853236, 0.06954659940674901, 0.0626936077605933, 0.051723663200391456, 0.026724463241407648, 0.023169503510871436, 0.04241741706209723, 0.03985335621109698, 0.041878729171003215, 0.06045224756235257, 0.04136973089771345, 0.10682024658308364, 11.4592588506639, 59.91894297301769, 58.31451706588268, 56.831509843468666, 33.433501571416855, 24.72242720425129, 38.02978813648224, 26.73200447112322, 38.73464651405811, 62.8290244191885, 15.158378407359123, 0.2281408416456543, 0.3110508341342211, 7.090555848553777, 3.589671179652214, 1.6694958717562258, 8.819246012717485, 60.88054597377777, 64.91121008992195, 61.11015625298023, 57.81572923064232, 59.5842569321394, 62.09603235125542, 61.16756357252598, 53.650164753198624, 45.2957658469677, 44.7947171330452, 45.28604976832867, 46.60671830177307, 47.59581662714481, 50.8937356621027, 51.78329452872276, 55.92786133289337, 56.66240751743317, 52.69098222255707, 44.47159767150879, 42.46054798364639, 43.15021097660065, 42.1585363894701, 42.16344952583313, 41.532432585954666, 41.9194608181715, 40.15580825507641, 41.42679065465927, 41.06569983065128, 39.54261235892773, 41.38832151889801, 41.27042904496193, 40.43093629181385, 42.29853607714176, 41.304794400930405, 40.976974591612816, 40.39848983287811, 40.940067172050476, 40.05887545645237, 41.533006355166435, 42.40239970386028, 40.94746917486191, 40.32744504511356, 41.27848461270332, 40.06012558937073, 40.34532688558102, 40.18078051507473, 42.964461743831635, 43.04336450994015, 52.60331332683563, 52.05237329006195, 54.28531587123871, 48.87105479836464, 53.547091484069824, 49.48688395321369, 56.81276924908161, 45.71455657482147, 51.6071929782629, 24.136601239442825, 32.21764661371708, 57.48458839952946, 49.66410644352436, 56.59583888947964, 50.71562401950359, 53.55131305754185, 49.8686570674181, 52.351333647966385, 52.929867804050446, 54.12610441446304, 50.73803901672363, 55.3947689384222, 50.777674689888954, 49.54671174287796, 40.479999259114265, 39.839646220207214, 40.15411354601383, 40.95358304679394, 41.69807329773903, 42.32355393469334, 42.40990050137043, 42.24237509071827, 41.02436564862728, 42.264854684472084, 42.27088116109371, 42.11587227880955, 42.193106934428215, 42.31945015490055, 41.884168311953545, 42.27153092622757, 43.20270135998726, 41.77991330623627, 40.82214429974556, 41.819434985518456, 43.0545587092638, 44.98746559023857, 46.67765289545059, 46.55125267803669, 43.430780321359634, 43.710221126675606, 40.55819146335125, 43.355251774191856, 46.81428596377373, 53.456143364310265, 50.84019273519516, 44.19310301542282, 47.89892636239529, 52.93166510760784, 61.20845317840576, 59.15179833769798, 57.620632499456406, 57.532454431056976, 56.38918697834015, 56.82361766695976, 54.76172670722008, 57.63144671916962, 60.441981106996536, 58.92463132739067, 5.795324575155973, 2.7663114108145237, 2.9101412929594517, 0.22506272478494793, 0.22427980351494625, 0.07792899414198473, 26.27922646701336, 49.64403972029686, 40.60720883309841, 52.26247921586037, 23.487451672554016, 14.340582489967346, 34.20645609498024, 48.85906644165516, 49.92807827889919, 35.887858271598816, 2.2043194295838475, 0.059865442526643164, 0.02249996756290784, 0.008989901980385184, 0.03865254271659069, 0.06484956902568229, 0.07091947612934746, 0.06213508968357928, 0.030035592208150774, 0.06080277875298634, 0.01096130410587648, 0.04666621251089964, 0.03190603070834186, 0.01857829967775615, 0.015527560644841287, 0.06457227296778001, 0.06102574217948131, 0.03747964139620308, 0.04117952586966567, 0.01929483398271259, 0.0598349365463946, 0.04137036914471537, 0.07579871860798448, 0.03505503380438313, 0.041514453405397944, 0.07341810924117453, 0.04189144216070417, 16.577991731464863, 72.53392025828362, 65.3120581805706, 63.57049763202667, 41.273624673485756, 28.8761705160141, 39.45166423916817, 35.23537628352642, 39.08136650919914, 71.19358777999878, 15.947394669055939, 0.23103597457520664, 0.7234552328009158, 12.137968931347132, 5.479900175705552, 1.367355678230524, 10.529751777648926, 63.97623226046562, 68.63707736134529, 63.29233355820179, 61.3353131711483, 61.21081285178661, 64.33747887611389, 62.82421387732029, 55.75707569718361, 46.560106202960014, 47.015466168522835, 49.33389276266098, 49.648348689079285, 50.388731360435486, 52.75828421115875, 55.85589699447155, 58.46328288316727, 58.46067622303963, 53.93119387328625, 46.531672328710556, 44.78264898061752, 44.44214165210724, 43.989506140351295, 43.73773545026779, 43.86595197021961, 43.72188650071621, 41.492770314216614, 43.346641436219215, 44.14673790335655, 42.55807355046272, 43.63533474504948, 43.08330416679382, 42.588046342134476, 43.07602375745773, 43.518350422382355, 42.81624309718609, 41.117719039320946, 43.408030942082405, 43.78265284001827, 43.54190915822983, 42.79053367674351, 42.62178473174572, 42.45564624667168, 43.581765219569206, 41.64558671414852, 41.49454861879349, 42.342237532138824, 44.21484164893627, 45.015253499150276, 54.54409338533878, 52.860494926571846, 55.55034399032593, 51.91899284720421, 55.09485103189945, 51.30541317164898, 57.63222947716713, 49.01788271963596, 52.968618124723434, 24.57047525793314, 34.43296954035759, 58.47614899277687, 52.10150845348835, 58.53181980550289, 53.59296262264252, 54.26085278391838, 52.725708559155464, 54.094839692115784, 54.61248591542244, 55.56354068219662, 53.25289987027645, 55.618196949362755, 52.037516087293625, 51.616844460368156, 42.69204296171665, 41.70098774135113, 41.52058482170105, 42.417553290724754, 44.14495959877968, 43.55873845517635, 43.64532060921192, 44.79980506002903, 42.844889760017395, 44.68879021704197, 43.2858294993639, 43.79574313759804, 44.15705434978008, 44.680578857660294, 43.1403961032629, 43.3712413161993, 42.856775522232056, 43.13954874873161, 42.43213310837746, 42.912358939647675, 44.750707894563675, 46.20977260172367, 48.604867681860924, 49.876070469617844, 45.988818258047104, 46.09023101627827, 42.988567650318146, 46.47021822631359, 49.00950036942959, 55.13536065816879, 53.12112674117088, 46.13808184862137, 49.577064514160156, 55.792839378118515, 63.394031301140785, 60.7527170330286, 59.508055821061134, 59.74540628492832, 56.85840480029583, 59.43841315805912, 55.209221094846725, 59.93641823530197, 62.57845066487789, 61.263029649853706, 6.3143733981996775, 0.7552603574004024, 4.3545478116720915, 0.9899232967291027, 0.4841132601723075, 0.146427191211842, 26.397259533405304, 57.824711948633194, 43.20749290287495, 41.49292230606079, 24.974403083324432, 18.569056391716003, 40.991714000701904, 55.04239484667778, 57.255810275673866, 44.63764116168022, 3.5650221398100257, 0.04318633771617897, 0.015114119451027364, 0.032527379007660784, 0.03434049773204606, 0.0532292656134814, 0.04004828129836824, 0.0717237193020992, 0.043917969160247594, 0.04112101123610046, 0.04584500384225976, 0.04473419059650041, 0.008951823310781037, 0.01958996756002307, 0.20333136431872845, 0.18579831841634586, 0.1349377358565107, 0.12047905896906741, 0.10708391680964269, 0.07947587480884977, 0.11832150208647363, 0.12307179640629329, 0.14392268029041588, 0.08797059359494597, 0.14435778663028032, 0.16794751456473023, 0.21242457325570285, 22.07575522363186, 86.05109453201294, 71.94673776626587, 73.50989788770676, 43.58259737491608, 36.91921412944794, 47.62759052217007, 37.20595434308052, 52.69259713590145, 73.9604777097702, 19.70966398715973, 0.35343948926310986, 0.8958450355567038, 17.00530920177698, 10.787484347820282, 5.433303276076913, 13.102806508541107, 66.1835566163063, 69.76474285125732, 64.83272150158882, 62.878284975886345, 64.84637796878815, 67.32663407921791, 65.9783524274826, 59.283567667007446, 49.56931672990322, 49.043789729475975, 50.504237562417984, 51.39020562171936, 50.63267447054386, 53.53968568146229, 58.60549405217171, 59.350865855813026, 62.34507478773594, 57.62606620788574, 48.4736493229866, 47.783203572034836, 46.923556700348854, 46.21410816907883, 46.12760581076145, 45.27939632534981, 46.90159387886524, 41.23833976686001, 45.7125198841095, 46.34171672165394, 44.478513300418854, 46.39621339738369, 44.741994962096214, 42.92726933956146, 46.52045913040638, 47.195390313863754, 45.95299378037453, 44.1387203335762, 44.70590829849243, 45.51248721778393, 45.960821360349655, 45.19429989159107, 44.97983179986477, 44.48833577334881, 46.45692653954029, 43.94486993551254, 43.69025319814682, 44.99419502913952, 46.56329423189163, 47.87040129303932, 58.46199855208397, 57.058604657649994, 57.41361580789089, 52.8373883664608, 57.13906913995743, 54.90205317735672, 59.27146911621094, 51.19229704141617, 53.13017025589943, 27.91272271424532, 36.6997455060482, 59.846116080880165, 53.92433904111385, 61.232072710990906, 56.65529429912567, 56.57611034810543, 54.11516100168228, 57.89835199713707, 58.80916312336922, 57.58391126990318, 54.59424689412117, 59.343988224864006, 54.12982441484928, 54.249122813344, 45.79766571521759, 43.35672229528427, 43.622822016477585, 44.04477797448635, 45.362710654735565, 45.52228309214115, 46.35173678398132, 46.69615790247917, 44.030597135424614, 46.01719133555889, 45.58178789913654, 45.58570168912411, 46.20440348982811, 46.7530370503664, 45.632674768567085, 45.835116505622864, 46.50380842387676, 45.2083895355463, 43.656856790184975, 45.98254859447479, 46.298281252384186, 46.86544641852379, 51.16671301424503, 52.280323058366776, 48.2951956987381, 47.876157984137535, 44.51393499970436, 48.641467317938805, 51.74023523926735, 57.416439056396484, 56.007296070456505, 51.03035353124142, 54.946947768330574, 58.908900171518326, 63.48181799054146, 62.90975108742714, 62.427161782979965, 62.28057324886322, 61.92563809454441, 62.659044340252876, 58.78451764583588, 62.72389926016331, 64.72898706793785, 65.44302955269814, 8.708581700921059, 6.949557289481163, 7.347096707671881, 1.1122878338210285, 0.5494775308761746, 0.2401068151812069, 30.853751599788666, 63.93381133675575, 57.36985735595226, 63.984759002923965, 32.15244211256504, 23.140268102288246, 48.729330003261566, 61.09603241086006, 65.13212263584137, 53.2284139841795, 4.6738646272569895, 0.14424098742892966, 0.11251401097979397, 0.17284006375120953, 0.11322396429022774, 0.16214662115089595, 0.14995549485320225, 0.17531600198708475, 0.11855564967845567, 0.186531872022897, 0.1771451733657159, 0.2854543982539326, 0.13326131331268698, 0.17928478511748835], [0.03507447436277289, 0.057027362199733034, 0.060904193233000115, 0.04476980626350269, 0.024341723910765722, 0.03806377841101494, 0.04423742291692179, 0.04078523023054004, 0.03875854737998452, 0.018336741741222795, 0.027345733615220524, 0.05286896033794619, 0.39695784158539027, 31.273368783295155, 67.43913844227791, 51.92520551383495, 51.72187462449074, 24.185804799199104, 24.756404981017113, 53.04777927696705, 39.71755497157574, 47.28793054819107, 58.4119438380003, 3.462977665476501, 0.07672838473808952, 0.09987125813495368, 11.43144529312849, 7.062194170430303, 1.3389208540320396, 26.998734958469868, 69.82917979359627, 62.57549822330475, 60.85131034255028, 57.45772384107113, 64.07484456896782, 61.29482254385948, 61.38611264526844, 56.05602465569973, 46.715472266077995, 43.05135928094387, 44.589999318122864, 43.48574057221413, 43.6904925853014, 43.9286258071661, 47.43571601808071, 47.58480861783028, 47.35076017677784, 45.09864382445812, 41.878594011068344, 43.508163169026375, 41.993784829974174, 41.360301822423935, 42.471783980727196, 42.05867774784565, 41.52592733502388, 42.20196805894375, 41.68772645294666, 40.5050665140152, 42.14506231248379, 38.53040747344494, 42.06988334655762, 41.85632340610027, 41.633009389042854, 42.180149629712105, 40.76838098466396, 40.24363674223423, 40.537615567445755, 41.168054938316345, 42.48106308281422, 39.837468937039375, 41.30370765924454, 39.76795546710491, 40.58208838105202, 38.362467885017395, 40.58539420366287, 40.57610370218754, 43.40146489441395, 40.432201623916626, 45.16828268766403, 51.71104520559311, 54.0012127161026, 51.74966633319855, 54.42758783698082, 50.82237549126148, 53.75540390610695, 45.7549674063921, 53.02477911114693, 19.971690326929092, 34.44045513868332, 57.050879672169685, 49.97172653675079, 55.06308853626251, 48.8069674372673, 50.80144241452217, 50.52381031215191, 51.16479031741619, 50.05200482904911, 52.372471913695335, 50.16180753707886, 52.83208005130291, 50.86347408592701, 49.60965536534786, 42.20683179795742, 39.17672999203205, 39.25184056162834, 41.00188225507736, 41.23938471078873, 41.09378792345524, 41.920665353536606, 43.76130558550358, 39.80133667588234, 41.67603828012943, 43.73403824865818, 42.02717363834381, 40.996912121772766, 42.36920088529587, 41.811588406562805, 42.66891360282898, 42.39000476896763, 43.19363884627819, 40.86537078022957, 41.46839082241058, 45.324363112449646, 49.19741928577423, 47.302191182971, 48.22752892971039, 48.96010302007198, 44.31473068892956, 40.60246288776398, 41.40507102012634, 45.77944949269295, 52.73919403553009, 49.80401113629341, 49.75567013025284, 47.048797979950905, 47.895236760377884, 52.96595446765423, 58.250205516815186, 60.03834776580334, 54.997648447752, 52.96482592821121, 53.332771584391594, 48.6213967949152, 59.477699249982834, 57.610145062208176, 68.3200603723526, 17.281757667660713, 1.2103520217351615, 3.6990711092948914, 0.5560758768115193, 0.08407791028730571, 0.1607387966942042, 7.3566308710724115, 50.201029032468796, 27.59456768631935, 71.67594149708748, 67.11623176932335, 22.264852076768875, 37.274259477853775, 46.54993794858456, 51.252200827002525, 48.3884084969759, 5.179582815617323, 0.324788136058487, 0.08615484766778536, 0.04025678768812213, 0.055717211798764765, 0.060039773015887477, 0.028223547742527444, 0.040525541626266204, 0.04122869315324351, 0.02470380477461731, 0.011884166597155854, 0.015582846936013084, 0.023036696184135508, 0.08993600844405591, 0.03299949996289797, 0.06875337712699547, 0.034986611499334686, 0.033880807750392705, 0.019986268853244837, 0.009614250411686953, 0.0576241342787398, 0.010139513778995024, 0.019458253045741003, 0.040847496420610696, 0.045451290789060295, 0.05618291317659896, 0.5620696989353746, 40.82526013255119, 77.02749833464622, 59.36942405998707, 57.434746474027634, 33.11113826930523, 28.967268727719784, 49.10093866288662, 37.15685337781906, 53.02996963262558, 63.91599029302597, 3.8021208671852946, 0.3565165225882083, 0.23487979487981647, 14.43905420601368, 9.700905103236437, 1.6466598096303642, 29.102243185043335, 72.77833834290504, 64.9247981607914, 61.00280441343784, 60.89854560792446, 65.30199632048607, 64.75533485412598, 63.67572158575058, 58.29526349902153, 48.92566926777363, 44.923822805285454, 46.208233684301376, 45.968933925032616, 45.49722723662853, 46.390943080186844, 49.57800306379795, 49.907927960157394, 49.19656813144684, 47.247785702347755, 44.159338027238846, 44.056648537516594, 44.346352592110634, 43.443129658699036, 42.954874858260155, 44.31413792073727, 43.785742074251175, 44.11730468273163, 44.14239473640919, 42.81272068619728, 43.54594834148884, 40.73810800909996, 44.3423780053854, 43.170387893915176, 43.864025473594666, 44.02960538864136, 43.192844688892365, 42.84498855471611, 41.6814985871315, 43.728159964084625, 44.14970934391022, 41.539067029953, 43.72984707355499, 41.82977043092251, 43.88721562922001, 40.87631419301033, 42.96256564557552, 42.76391990482807, 44.63106371462345, 43.22908714413643, 47.332551553845406, 54.13351021707058, 56.0124371945858, 54.254913702607155, 56.237016543745995, 54.59453567862511, 53.11846308410168, 48.12852144241333, 53.92442263662815, 22.262612096965313, 36.903289183974266, 60.07782004773617, 52.55391977727413, 55.67702159285545, 50.349354073405266, 53.27244222164154, 51.92230246961117, 52.56372705101967, 52.40887016057968, 53.71863707900047, 52.75028944015503, 53.71003054082394, 54.35019738972187, 50.376081839203835, 43.00535894930363, 41.38960964977741, 40.3675252944231, 41.704988926649094, 42.516382187604904, 44.031885266304016, 43.03315445780754, 44.12827089428902, 41.99148215353489, 42.80723378062248, 44.32581089437008, 42.630509063601494, 41.82296879589558, 45.2628406137228, 43.07217836380005, 44.91404592990875, 43.930164724588394, 44.426627084612846, 41.87630653381348, 43.236698135733604, 46.709214001894, 50.426478534936905, 49.92918781936169, 51.01853236556053, 49.070449098944664, 46.660933792591095, 43.85945811867714, 43.54295790195465, 48.1917804479599, 54.09936144948006, 54.04445439577103, 53.561884090304375, 51.25674158334732, 52.88426265120506, 55.19442468881607, 59.629653096199036, 60.431037694215775, 59.26266498863697, 56.312769278883934, 55.95914885401726, 51.346519365906715, 61.12400270998478, 60.163429453969, 69.97332885861397, 19.044215194880962, 0.3231003734981641, 3.9572772290557623, 2.112834588624537, 0.26188254123553634, 0.14912682760041207, 6.227240273728967, 55.6388146430254, 31.683381982147694, 61.905962750315666, 53.8496882468462, 25.58579597622156, 43.1827562302351, 51.90999113023281, 57.08222039043903, 58.19383554160595, 8.368772584944963, 0.43722526053898036, 0.10811566535267048, 0.027490485808812082, 0.05389974779973272, 0.04041597836476285, 0.02552130270487396, 0.05489676754223183, 0.03666612508823164, 0.04009446143754758, 0.02339176931855036, 0.03418448344746139, 0.050556587739265524, 0.022549240602529608, 0.15597953723045066, 0.13579144317191094, 0.1613197202095762, 0.09230779367499053, 0.1210114460263867, 0.16889459890080616, 0.15578144317260012, 0.16589642618782818, 0.16951715690083802, 0.1194730110000819, 0.1289634470595047, 0.09937134745996445, 0.7265879865735769, 47.02988259494305, 88.57646182179451, 65.6005235016346, 69.18085098266602, 36.10675312578678, 35.04304960370064, 62.656152695417404, 55.711846724152565, 61.48776859045029, 68.92385557293892, 5.75029794126749, 0.6302032491657883, 0.24934262037277222, 17.69673530012369, 15.468036141246557, 3.899971079081297, 31.818261444568634, 75.06111904978752, 67.1200543642044, 65.13719156384468, 63.98499459028244, 68.5877788066864, 65.40393725037575, 66.82834401726723, 61.86532773077488, 50.96686653792858, 48.80937650799751, 48.15940618515015, 48.30419361591339, 48.13455171883106, 48.16488169133663, 53.07193838059902, 52.13878445327282, 52.29739174246788, 49.45466548204422, 46.17001533508301, 46.630235239863396, 46.356095150113106, 45.819107964634895, 43.92629273235798, 46.08632482588291, 46.72234609723091, 46.974048390984535, 48.08027163147926, 45.25027468800545, 46.40861593186855, 41.91677436232567, 46.09734803438187, 48.583911806344986, 46.88687726855278, 47.4571468681097, 45.372434332966805, 45.32125487923622, 42.80729077756405, 45.253455117344856, 46.86635836958885, 43.59268203377724, 44.58970293402672, 44.03071112930775, 44.59996238350868, 42.826145365834236, 44.83745723962784, 45.54647259414196, 47.479349076747894, 46.70053906738758, 49.927755296230316, 57.33538180589676, 58.90146017074585, 57.76873715221882, 59.7823479026556, 58.04862253367901, 55.80027557909489, 50.13564974069595, 56.29454925656319, 23.91739670187235, 40.170186683535576, 62.62503236532211, 56.098734363913536, 60.098080560564995, 53.48586916923523, 55.55712282657623, 54.79769937694073, 54.437942281365395, 55.098498836159706, 55.97996033728123, 54.313267171382904, 55.62909856438637, 55.827637910842896, 53.80373351275921, 45.93400999903679, 42.45168685913086, 42.3527667671442, 43.50009240210056, 45.4167627543211, 44.59655776619911, 45.29923506081104, 47.03161910176277, 44.59548242390156, 45.26852510869503, 47.58721008896828, 45.90068958699703, 44.5441547781229, 47.64312408864498, 46.367414742708206, 46.11851289868355, 45.51399953663349, 46.159474700689316, 44.24686633050442, 44.59067568182945, 50.346215441823006, 53.465319871902466, 51.2257694453001, 52.05579310655594, 52.38290995359421, 49.59984429180622, 45.475370809435844, 47.05903463065624, 50.25473915040493, 58.01265746355057, 54.44441333413124, 53.61165761947632, 51.60004176199436, 55.227520912885666, 62.0855563133955, 62.39462412893772, 62.735344246029854, 60.3404201567173, 58.318943828344345, 58.43589775264263, 54.143154099583626, 63.905601650476456, 62.09235794842243, 72.7588301897049, 20.626338198781013, 3.545430628582835, 9.792637880891562, 2.230670778080821, 0.3481966909021139, 0.27798147581052035, 8.92065117135644, 60.98549634218216, 39.750901982188225, 80.51916137337685, 75.25419428944588, 35.56084021925926, 49.59841176867485, 60.816466212272644, 65.6342200934887, 65.89403495192528, 10.747394599020481, 0.5987915815785527, 0.34474021231289953, 0.1347359162173234, 0.19381032208912075, 0.15179869282292202, 0.10585215204628184, 0.10583875628071837, 0.18132444442017004, 0.10560155104030855, 0.09914808717439882, 0.06003031063301023, 0.28107281774282455, 0.17573546385392547], [0.02836523301084526, 0.037067716039018705, 0.01291248734560213, 0.022268434186116792, 0.06399170568329282, 0.039723283698549494, 0.039251010603038594, 0.03470260642643552, 0.03099531531916, 0.06531667677336372, 0.03099544333963422, 0.08016698498977348, 0.9163774119224399, 53.540145456790924, 66.41094401478767, 50.91936148703098, 45.972543731331825, 20.602310188114643, 28.768868073821068, 47.10577592253685, 38.92739497125149, 55.90601250529289, 42.120291441679, 0.20437853469047695, 0.06869891833048314, 1.062040280085057, 4.812938589602709, 3.5430512437596917, 1.2151508079841733, 44.66367356479168, 65.21862879395485, 63.483341708779335, 58.47657836973667, 62.02733963727951, 63.408025950193405, 60.989007353782654, 58.70279923081398, 57.2036998718977, 53.07051345705986, 47.75752454996109, 43.66449058055878, 42.81621649861336, 41.99659287929535, 43.12940329313278, 40.76692186295986, 41.72313675284386, 42.59913794696331, 41.674214377999306, 41.57230764627457, 42.33485832810402, 41.64809077978134, 41.62062965333462, 40.99842444062233, 41.10752418637276, 41.77598051726818, 43.03449958562851, 40.32815560698509, 40.910645350813866, 39.06810902059078, 38.39323103427887, 41.538177877664566, 41.672208085656166, 39.77486349642277, 41.001335084438324, 41.70512191951275, 42.24560111761093, 40.820468589663506, 38.39738041162491, 41.90154857933521, 41.32874071598053, 41.555455550551414, 40.67704148590565, 40.43124407529831, 40.30376471579075, 42.078919261693954, 40.558761432766914, 42.07076109945774, 39.83752213418484, 42.56352625787258, 44.3810523301363, 52.1878208220005, 50.75060494244099, 54.39423322677612, 50.389897897839546, 54.26507815718651, 48.00854668021202, 56.28082059323788, 19.390927590429783, 33.26226755976677, 56.31007522344589, 49.880204647779465, 54.15192022919655, 47.715700194239616, 51.357572972774506, 48.117095455527306, 54.614522606134415, 51.14041842520237, 52.6495910435915, 51.10767938196659, 52.92135626077652, 49.096629694104195, 47.80667491257191, 43.87721076607704, 41.405432000756264, 39.19669032096863, 41.197381764650345, 41.08334228396416, 42.82693192362785, 41.53764970600605, 41.333308070898056, 41.60960264503956, 41.513805985450745, 41.36741504073143, 40.496402978897095, 41.41736336052418, 41.78369030356407, 41.67850814759731, 41.56340092420578, 41.7618490755558, 41.75809867680073, 42.271527126431465, 47.110255882143974, 47.31113210320473, 51.565915793180466, 51.25242881476879, 48.8978623598814, 48.72674234211445, 45.29906406998634, 41.71469360589981, 41.379597187042236, 43.98438401520252, 51.13170929253101, 56.24625004827976, 58.20289805531502, 56.07452966272831, 54.09242682158947, 57.765594720840454, 54.81990538537502, 55.22353492677212, 56.50228410959244, 53.318066373467445, 52.18046061694622, 48.135634660720825, 59.98459964990616, 56.84223286807537, 63.50639507174492, 33.43038573861122, 1.5962755819782615, 1.9803658593446016, 1.8681361502967775, 0.42963463347405195, 0.06530435712193139, 1.5121511835604906, 43.4155735373497, 47.710726261138916, 56.32840543985367, 45.336925238370895, 14.314227104187012, 27.234987281262875, 44.041738137602806, 49.292676374316216, 55.18380045890808, 15.163326691836119, 0.3202458657324314, 0.084266541962279, 0.07746859540930018, 0.04218408212182112, 0.0350846083892975, 0.05549146531848237, 0.00770717208069982, 0.021992431320541073, 0.04522475763224065, 0.053997948780306615, 0.01640653623326216, 0.09244324304745533, 0.01202762003231328, 0.030428331192524638, 0.032055669944384135, 0.08820497867418453, 0.1144677889533341, 0.028073075445718132, 0.03528560424456373, 0.010613692338665714, 0.05192570919462014, 0.014699463918077527, 0.06678179503069259, 0.036669746768893674, 0.04126909567276016, 1.9994997326284647, 62.816021516919136, 74.21844586730003, 58.78350310027599, 53.55485446751118, 24.788385964930058, 29.663704857230186, 46.06690786778927, 40.079253762960434, 64.57405418157578, 47.630805149674416, 0.17925058695254847, 0.013391449047048809, 3.505680486559868, 14.609129279851913, 5.50294641405344, 1.6628919448703527, 47.4015748500824, 67.03443735837936, 67.01241374015808, 59.92825247347355, 61.96366265416145, 63.62430654466152, 62.86047153174877, 60.179749578237534, 59.42723035812378, 55.42564608156681, 48.459012508392334, 45.275611728429794, 45.56198336184025, 45.57244040071964, 45.4376008361578, 44.29673105478287, 44.772575721144676, 44.56718534231186, 43.49584423005581, 43.867259100079536, 44.9981240183115, 44.78478826582432, 42.97575853765011, 42.63026587665081, 42.128681391477585, 42.82529041171074, 43.52708615362644, 42.105726823210716, 42.513897120952606, 41.760652139782906, 41.92528210580349, 42.26415932178497, 43.596694618463516, 41.842123568058014, 42.21236810088158, 42.910079061985016, 42.31707528233528, 43.39127004146576, 41.844414845108986, 44.02747370302677, 43.745737820863724, 43.60890336334705, 40.86268812417984, 41.07863053679466, 40.62390893697739, 43.27401973307133, 42.36895389854908, 43.244605511426926, 42.625542730093, 43.289161920547485, 46.74003794789314, 55.903432443737984, 52.25074924528599, 55.02521596848965, 52.53700688481331, 56.82368226349354, 52.37773463129997, 57.2229116410017, 21.268897019326687, 34.87063765525818, 58.29063154757023, 50.72108432650566, 54.82127711176872, 50.146456360816956, 51.22192025184631, 50.31437315046787, 56.29336751997471, 52.05803118646145, 53.791463971138, 52.7025032043457, 55.02370744943619, 51.265671104192734, 49.281520172953606, 44.91177745163441, 41.770736798644066, 40.65342575311661, 41.854807287454605, 42.49688163399696, 43.944949731230736, 42.84610569477081, 43.82987670600414, 42.9532865434885, 44.744757413864136, 43.78217786550522, 43.32622513175011, 41.15195520222187, 44.1963442414999, 42.72051863372326, 43.14613379538059, 43.68171885609627, 44.451527148485184, 43.76004405319691, 47.92194552719593, 50.48833541572094, 54.48977530002594, 53.06501515209675, 51.76681861281395, 49.63219955563545, 47.75521047413349, 43.56204427778721, 42.30149991810322, 45.87878376245499, 53.04834924638271, 57.29758903384209, 61.017030850052834, 57.149450182914734, 57.251805290579796, 60.90860366821289, 58.051354587078094, 57.30352811515331, 57.76335284113884, 55.72405166924, 54.221855476498604, 50.72402536869049, 61.455223336815834, 60.9009774774313, 67.43178203701973, 36.25084899365902, 1.466907961294055, 2.607891974039376, 3.986676726490259, 0.5143743613734841, 0.08432107497355901, 0.852070078253746, 47.399796545505524, 49.62472915649414, 58.9900828152895, 45.99424436688423, 19.66570034623146, 33.87282259762287, 49.33574706315994, 54.19336840510368, 64.07682806253433, 22.575331516563892, 0.4258737259078771, 0.06226901023183018, 0.05690995072654914, 0.07297082425793633, 0.02933316798589658, 0.04683652427047491, 0.026988140889443457, 0.018310562481929082, 0.03176032114424743, 0.012677443610300543, 0.0819374895945657, 0.014972216176829534, 0.024100919254124165, 0.12053236001520418, 0.13641441677464172, 0.16350354911992326, 0.2034294613986276, 0.18906128942035139, 0.13359716482227668, 0.12572434352478012, 0.1263012149138376, 0.15406577585963532, 0.22566393861779943, 0.16085391864180565, 0.2078876760788262, 2.855602581985295, 73.01822707056999, 82.42115691304207, 66.44685208797455, 61.63276121020317, 30.83273682743311, 38.75929199159145, 57.785524651408195, 52.420261949300766, 70.89812323451042, 52.80732057988644, 0.45243064931128174, 0.11589649744564667, 2.2733914107084274, 13.858264870941639, 8.042760528624058, 3.6575495498254895, 50.983547642827034, 69.7644616663456, 68.98653700947762, 62.9492499679327, 65.5134853720665, 67.83155858516693, 64.63096752762794, 63.46636801958084, 64.02768909931183, 57.46106006205082, 52.5537183880806, 48.056511506438255, 47.04393424093723, 46.80638238787651, 48.73317539691925, 45.68590611219406, 46.734885424375534, 46.106513142585754, 46.358880400657654, 46.25888876616955, 47.33053386211395, 46.06056600809097, 45.487427562475204, 43.61060947179794, 44.13166791200638, 46.08474411070347, 46.28745183348656, 44.564172104001045, 44.828485921025276, 43.421056643128395, 43.027644753456116, 44.66962404549122, 46.08405254781246, 43.60640309751034, 43.852303102612495, 46.015162244439125, 45.18693968653679, 45.660500675439835, 42.800302952528, 45.2108746021986, 45.85475005209446, 46.41927435994148, 43.144720271229744, 43.76010484993458, 44.29029040038586, 46.6251815110445, 44.75499026477337, 46.24359838664532, 43.716540187597275, 46.363614946603775, 49.843168035149574, 57.55379408597946, 54.02438007295132, 58.18683251738548, 53.44473637640476, 56.61511145532131, 55.20267404615879, 58.819528967142105, 24.679307118058205, 37.63365559279919, 60.16328126192093, 54.14132259786129, 58.030413910746574, 51.93514958024025, 54.181535840034485, 53.89212056994438, 59.37892735004425, 55.27352124452591, 56.89633056521416, 55.75394846498966, 57.005183324217796, 51.89167611300945, 53.53531211614609, 48.1956372410059, 44.75362993776798, 42.10157744586468, 44.192935824394226, 42.59611330926418, 47.20259852707386, 44.67450678348541, 44.42418001592159, 46.542106568813324, 46.57074563205242, 46.05402655899525, 45.13771712779999, 44.61097039282322, 47.248188480734825, 45.380014926195145, 45.013365000486374, 46.18234947323799, 47.04966053366661, 45.09075164794922, 50.78450292348862, 51.62643514573574, 56.26913242042065, 54.572538658976555, 53.300762102007866, 52.2042815387249, 51.22135788202286, 45.56530058383942, 46.007752642035484, 48.93395282328129, 55.877802819013596, 61.881796047091484, 63.91906052827835, 59.25390645861626, 57.548436373472214, 61.66941784322262, 61.78354471921921, 60.20680792629719, 61.263979598879814, 58.29949267208576, 56.74615882337093, 52.080024406313896, 66.56962350010872, 63.56363520026207, 69.27333801984787, 38.45022037625313, 2.326011462137103, 8.074411880224943, 7.521441802382469, 0.8960764668881893, 0.2117485657799989, 2.3219765536487103, 53.42501163482666, 61.25473089516163, 67.76510015130043, 51.77212692797184, 23.74060168862343, 38.38633440434933, 57.62753292918205, 60.460835695266724, 71.04556292295456, 26.21815424412489, 0.8504266664385796, 0.15867972280830145, 0.15463776391698048, 0.26144773175474256, 0.15184144052909687, 0.19539494096534327, 0.11512597746332176, 0.11109499493613839, 0.13073300913674757, 0.12887762510217726, 0.1936200651107356, 0.20381153386551887, 0.10540430303080939], [0.008550446655135602, 0.017599811362742912, 0.0377886865317123, 0.05359275470254943, 0.01645233602175722, 0.05056639893155079, 0.01101766280044103, 0.05500593004398979, 0.05375972679757979, 0.03530463662173133, 0.041057041817111894, 0.07121229049516842, 4.233071180060506, 60.08557543158531, 60.071026012301445, 51.05822503566742, 43.534241169691086, 25.10385073721409, 33.020752519369125, 41.54967226088047, 33.426255360245705, 63.999190628528595, 25.004964843392372, 0.08924658293835819, 0.2875315211713314, 2.4038445856422186, 5.669108172878623, 2.111532208509743, 7.965811332687736, 58.1403686106205, 63.72208669781685, 63.07040646672249, 61.046072691679, 62.71368160843849, 58.24666790664196, 60.67406505346298, 60.20459644496441, 59.587479159235954, 57.12237283587456, 54.28559325635433, 51.17173254489899, 44.61029402911663, 42.29258939623833, 41.44022673368454, 41.47432990372181, 42.64421112835407, 41.841188818216324, 42.08116494119167, 40.39542719721794, 42.82084085047245, 41.613391041755676, 40.498633459210396, 41.121663227677345, 39.73571419715881, 40.08109666407108, 40.79942911863327, 41.0606575012207, 40.101429373025894, 39.14251282811165, 39.9503418803215, 40.53118631243706, 42.106444984674454, 40.13500437140465, 38.350403532385826, 41.45865574479103, 41.5572414547205, 40.16835518181324, 39.808674082159996, 40.79634368419647, 39.08126771450043, 42.5155196338892, 40.24410031735897, 38.85235279798508, 39.730603471398354, 41.70618586242199, 37.957573011517525, 41.011472940444946, 41.636148020625114, 41.4896696805954, 39.81617487967014, 46.506563276052475, 48.94835025072098, 55.441411435604095, 49.162331968545914, 57.346226423978806, 51.36977031826973, 59.97207552194595, 21.367851309478283, 31.492282636463642, 57.32584051787853, 44.00673821568489, 52.32101507484913, 47.31957145035267, 52.8962168097496, 49.27830174565315, 53.55148404836655, 51.050538048148155, 51.35806694626808, 48.55257868766785, 53.46868269145489, 46.947389021515846, 48.02145838737488, 41.574131548404694, 41.311938017606735, 39.035791754722595, 40.42204096913338, 40.25896891951561, 42.325643822550774, 39.41848061978817, 41.3968026638031, 41.090698689222336, 41.56948819756508, 42.474690824747086, 40.8137733489275, 41.264242976903915, 40.517507046461105, 41.56846605241299, 42.921782433986664, 39.528264328837395, 41.18831545114517, 43.660185411572456, 51.06698356568813, 51.73396557569504, 51.91876485943794, 50.73976792395115, 50.04777565598488, 45.27656547725201, 42.68691323697567, 40.18485389649868, 42.42284640669823, 41.94779209792614, 43.30923244357109, 48.6567272990942, 54.72445070743561, 58.30112278461456, 56.894651055336, 56.78758420050144, 57.67997391521931, 56.49162948131561, 56.597655192017555, 53.71909685432911, 47.61103481054306, 48.84271211922169, 58.91926981508732, 60.73405623435974, 61.554739996790886, 51.622468158602715, 6.64972772821784, 1.9064143463037908, 2.833610074594617, 0.4794201557524502, 0.07227750989841297, 0.023708725748292636, 29.676985144615173, 49.63682770729065, 32.05503433942795, 26.898978911340237, 11.920168418437243, 19.41460222005844, 38.84513318538666, 49.487503319978714, 58.84251393377781, 26.628952100872993, 0.445687614264898, 0.0892151084553916, 0.08290301630040631, 0.03846637126116548, 0.015212149737635627, 0.037352440995164216, 0.044280122383497655, 0.017672098401817493, 0.026280792517354712, 0.06855823681689799, 0.04717976014944725, 0.045507107715820894, 0.033909647609107196, 0.08290309793665074, 0.0369979801325826, 0.03465273039182648, 0.09059681673534214, 0.005764501274825307, 0.05077942871139385, 0.08980859653092921, 0.051530949713196605, 0.014642826918134233, 0.01842625959397992, 0.02390121102507692, 0.16310989914927632, 6.71930911950767, 72.93424397706985, 65.93629628419876, 57.94653341174126, 49.964902102947235, 31.655719466507435, 30.241722241044044, 39.37275767326355, 35.74660085141659, 73.5805892944336, 27.51479096710682, 0.035170808841940016, 0.07721313333604485, 2.953400071710348, 10.465349033474922, 4.088907865807414, 8.946558181196451, 59.479302763938904, 66.57679751515388, 65.99337682127953, 62.769466415047646, 64.04230311512947, 60.14518663287163, 63.943941593170166, 62.535277381539345, 61.94294236600399, 59.78204771876335, 57.15970203280449, 53.61847825348377, 46.94925472140312, 43.93679916858673, 43.231040239334106, 43.52637179195881, 44.809319749474525, 43.30688036978245, 44.42277029156685, 41.867920383811, 43.80927041172981, 44.373733922839165, 42.20043674111366, 42.0579481869936, 42.38471545279026, 42.97873757779598, 42.23608262836933, 43.52503426373005, 43.03609549999237, 41.316858753561974, 42.430476397275925, 43.26830103993416, 43.84321019053459, 42.9023502767086, 40.37506029009819, 44.22520749270916, 42.751581966876984, 41.509485617280006, 41.32145270705223, 42.354792058467865, 40.860119462013245, 43.121663108468056, 43.149230629205704, 41.865431517362595, 41.24370887875557, 42.94947534799576, 40.04462622106075, 42.59080119431019, 44.089638367295265, 42.94698268175125, 41.86217129230499, 48.17208990454674, 52.26448550820351, 56.67321793735027, 51.230633184313774, 58.83040398359299, 51.857591941952705, 62.41705432534218, 23.380173929035664, 33.56339380145073, 57.82258786261082, 47.8154182434082, 53.907437548041344, 49.432090893387794, 55.9357725083828, 52.28141739964485, 56.2249293923378, 53.70898559689522, 54.91862788796425, 51.92514471709728, 55.90623289346695, 50.17440006136894, 48.396988436579704, 43.09295944869518, 42.37224072217941, 41.00435212254524, 41.85939364135265, 42.5827494263649, 42.511659041047096, 40.77423647046089, 43.77227559685707, 42.67941243946552, 43.36834207177162, 43.329017981886864, 43.88639487326145, 42.88087382912636, 43.37832413613796, 43.111251667141914, 44.009341076016426, 41.21316611766815, 43.24121989309788, 45.0243616104126, 52.982947155833244, 54.45963151752949, 54.11716349422932, 52.30859354138374, 54.11491401493549, 48.535255417227745, 45.00811368227005, 42.90908731520176, 43.73809263110161, 44.38875071704388, 47.0138094574213, 50.932098403573036, 56.78987167775631, 58.58036980032921, 58.25546443462372, 58.829647824168205, 60.04902899265289, 59.14706379175186, 57.24604859948158, 55.53856082260609, 50.842168629169464, 50.73909915983677, 59.77359317243099, 62.62252449989319, 63.04342031478882, 54.79625925421715, 7.82840833067894, 1.0352274938486516, 3.891384252347052, 0.5038572382181883, 0.11250617390032858, 0.11635252492851578, 30.599007569253445, 56.084317937493324, 37.56734915077686, 30.383528731763363, 18.511485680937767, 27.29262638837099, 43.31363260746002, 56.422883570194244, 65.29934406280518, 37.21486486494541, 0.544460671953857, 0.0478726774599636, 0.07001656442298554, 0.06856478255940601, 0.0290706128362217, 0.015350589965237305, 0.1208957155176904, 0.04304592337575741, 0.04747969542222563, 0.03272352863859851, 0.02404260500043165, 0.04016637183667626, 0.031859123264439404, 0.08056473161559552, 0.20192821539239958, 0.11215215461561456, 0.25486975035164505, 0.14583955868147314, 0.18650269077625126, 0.1576610212214291, 0.38635649951174855, 0.14298353693448007, 0.2105757943354547, 0.3129760839510709, 0.27878145163413137, 9.910631999373436, 82.04244643449783, 73.90185445547104, 65.65777882933617, 54.94104288518429, 36.68585725128651, 42.02051259577274, 53.52493107318878, 45.07449232041836, 77.44932889938354, 32.581522688269615, 0.1528814120683819, 0.2910785417770967, 3.253501793369651, 9.597500301897526, 5.688981106504798, 10.795512367039919, 65.04723519086838, 67.56298899650574, 67.72126570343971, 66.43100693821907, 66.5954165160656, 62.86851570010185, 66.36283859610558, 63.20286735892296, 65.33850476145744, 63.47076818346977, 59.80191685259342, 57.34607823193073, 50.840591713786125, 46.2661387771368, 45.336564257740974, 44.986610636115074, 47.71863743662834, 46.14962562918663, 46.373365223407745, 44.21222738921642, 48.56980316340923, 46.2735103815794, 43.62380236387253, 45.57429850101471, 44.513672813773155, 44.17976953089237, 46.083661168813705, 44.793789982795715, 46.01032890379429, 43.644123673439026, 44.699976816773415, 44.356593042612076, 47.44464933872223, 44.90428425371647, 41.24626234173775, 46.63907736539841, 44.936875104904175, 43.53590168058872, 44.0624014288187, 43.16878817975521, 42.24414199590683, 46.952780932188034, 45.95549404621124, 43.42253476381302, 44.136166870594025, 46.97947070002556, 42.52520151436329, 44.60845872759819, 46.48121863603592, 45.79711474478245, 43.577623441815376, 50.57622089982033, 53.71102228760719, 59.98099744319916, 53.781907483935356, 61.377293318510056, 55.32523266971111, 62.552315667271614, 27.86323606967926, 36.11091390252113, 59.99198265373707, 49.81256067752838, 56.39087028801441, 52.969176694750786, 57.397120893001556, 53.632560297846794, 60.07839381694794, 56.94791279733181, 57.42164857685566, 52.06126481294632, 58.21049004793167, 51.98368817567825, 52.46704883873463, 46.167492270469666, 44.41194087266922, 43.51244553923607, 45.18861919641495, 45.169570818543434, 45.93723602592945, 42.34138637781143, 46.72721363604069, 43.902072831988335, 47.40057930350304, 46.8997585773468, 43.973452001810074, 45.849240347743034, 43.80209259688854, 45.391041934490204, 47.29877896606922, 43.292669132351875, 45.25578059256077, 47.04693987965584, 56.27168968319893, 56.354540437459946, 55.29236823320389, 55.46310447156429, 54.61160436272621, 49.76725950837135, 48.34604077041149, 45.908376574516296, 45.76686456799507, 47.29640409350395, 49.678678661584854, 53.02083112299442, 59.5621345192194, 61.423590034246445, 61.38923987746239, 59.18430559337139, 60.55871084332466, 61.84045046567917, 60.64670272171497, 58.73930387198925, 53.72208349406719, 53.78704480826855, 62.691680788993835, 66.63938015699387, 65.57744354009628, 57.40038111805916, 8.580776508897543, 5.001498721539974, 8.74121529981494, 0.790943173924461, 0.24583482969319448, 0.20385257463203743, 34.76542130112648, 62.268717885017395, 44.115165397524834, 37.26219892501831, 18.319837264716625, 29.177619740366936, 50.687919706106186, 63.85458558797836, 72.70624101161957, 46.5161007642746, 1.0493788844905794, 0.20912799780489877, 0.25875578401610255, 0.19274110993137583, 0.1680165046127513, 0.11910983361303806, 0.18053064326522872, 0.058368868340039626, 0.13586693443357944, 0.10446205749758519, 0.13412964093731716, 0.22022274933988228, 0.2466269684373401], [0.05933717809966765, 0.033850832405732945, 0.04015194448584225, 0.07785394816892222, 0.08110040638712235, 0.012980531155335484, 0.023657454476051498, 0.08986600165371783, 0.04095962751307525, 0.05776306061306968, 0.08810553830699064, 0.03067369820200838, 12.633962016552687, 68.5959179699421, 56.05921648442745, 51.70885272324085, 33.5090035200119, 16.05927586555481, 30.455483570694923, 41.86409018933773, 39.565069153904915, 60.90212121605873, 11.928474772721529, 0.17321315623121336, 0.13184240116970614, 9.581926837563515, 12.579895667731762, 4.036986976861954, 17.307761572301388, 59.15046460926533, 64.50029253959656, 64.44342479109764, 60.145209431648254, 60.00561252236366, 57.88072094321251, 58.77102077007294, 57.44710721075535, 57.99508340656757, 60.149582996964455, 58.02965775132179, 55.454615727066994, 52.75120139122009, 48.95818792283535, 41.752197593450546, 40.75190506875515, 40.733164474368095, 42.74892210960388, 42.288952991366386, 39.603682681918144, 41.48148111999035, 41.774912774562836, 41.3341174274683, 41.41119249165058, 40.750065967440605, 40.67508839070797, 40.10446920990944, 41.45809717476368, 40.12054614722729, 40.97505949437618, 40.61235375702381, 40.69276884198189, 41.33645050227642, 40.6858304142952, 40.430408120155334, 40.43956562876701, 38.67871731519699, 41.844346448779106, 40.87168604135513, 40.723790377378464, 39.1952957957983, 42.611472085118294, 39.02872413396835, 40.176205560564995, 39.67406250536442, 41.460741832852364, 40.53649462759495, 41.300154849886894, 40.290290638804436, 41.1182776093483, 41.7253178358078, 41.636208817362785, 42.17194966971874, 46.66722625494003, 46.85783162713051, 55.492321103811264, 48.3048889786005, 63.23271095752716, 27.61221583932638, 28.4420096129179, 58.963248655200005, 45.85659295320511, 54.08980496227741, 50.090158581733704, 53.96773651242256, 50.72412796318531, 51.79408214986324, 50.70380285382271, 52.18839839100838, 49.50131177902222, 52.908824533224106, 48.272229731082916, 47.04224333167076, 41.32731959223747, 41.21550299227238, 38.817622661590576, 41.96402482688427, 39.824519231915474, 42.31746286153793, 41.784697249531746, 43.24913866817951, 40.26972234249115, 41.38014815747738, 41.28570042550564, 41.975675001740456, 40.070054456591606, 42.145883068442345, 44.056108966469765, 40.65733574330807, 41.15400709211826, 43.585853800177574, 47.82941289246082, 53.89606475830078, 52.01100870966911, 51.721167862415314, 52.33098194003105, 48.02115440368652, 42.40741923451424, 42.41582438349724, 41.53804488480091, 42.232518419623375, 42.69879899919033, 43.327011689543724, 44.78976599872112, 49.14143688976765, 54.43278595805168, 55.42660363018513, 55.32731495797634, 53.822964280843735, 55.394358560442924, 53.161868155002594, 49.175239875912666, 45.31056605279446, 51.11244432628155, 56.49790294468403, 60.10098360478878, 57.49651975929737, 57.2661305218935, 17.996740601956844, 1.9113279576413333, 2.9697907296940684, 0.7529779861215502, 0.24205094523495063, 0.09661839518230408, 14.297123271971941, 59.57230657339096, 37.443019822239876, 34.8109732568264, 21.238333359360695, 22.75544375181198, 37.797328010201454, 45.23972645401955, 55.00166483223438, 31.813084222376347, 1.753263445571065, 0.02258205095131416, 0.021379235513450112, 0.042522701842244714, 0.027734116192732472, 0.024931100488174707, 0.08892722937162034, 0.0016667255727043084, 0.012091560693079373, 0.04772070416947827, 0.04106814434635453, 0.025154449831461534, 0.06061613603378646, 0.07148156393668614, 0.0105206529951829, 0.03375102096470073, 0.043867970671271905, 0.027877645698026754, 0.03627710240834858, 0.0360389583511278, 0.05753824923885986, 0.022243063867790624, 0.05368600926885847, 0.11223143825191073, 0.06106387372710742, 17.654798850417137, 76.86045929789543, 63.91298845410347, 58.526625484228134, 42.46478095650673, 24.011359959840775, 30.13199932873249, 45.046525821089745, 42.762266993522644, 69.52223986387253, 12.231515161693096, 0.2631843276321888, 0.11812655473477207, 7.197858290746808, 10.21388042718172, 4.26180143840611, 18.800929449498653, 59.25628513097763, 64.7945411503315, 66.9344875216484, 60.80632455646992, 62.36413836479187, 59.78576011955738, 60.51943615078926, 58.39026600122452, 60.2959169447422, 61.440183743834496, 61.18706792593002, 59.219476506114006, 55.25955319404602, 50.27092628180981, 44.71789665520191, 43.21875549852848, 43.13637211918831, 43.839972764253616, 43.91390919685364, 41.981017515063286, 44.16019678115845, 43.37849132716656, 43.07966396212578, 43.02271641790867, 42.37792141735554, 43.1509443372488, 40.99479183554649, 43.570248037576675, 42.52474933862686, 43.67943897843361, 43.49461309611797, 42.87257507443428, 43.97430695593357, 42.616446018218994, 42.29652598500252, 42.46023640036583, 41.01009361445904, 44.06891047954559, 41.753903701901436, 42.57351212203503, 42.19104364514351, 44.3017315864563, 40.223634615540504, 41.68296530842781, 41.52486339211464, 43.26051525771618, 41.17789261043072, 43.019232004880905, 41.24432824552059, 44.36405584216118, 43.150020986795425, 43.74030791223049, 43.88469636440277, 48.70327100157738, 48.92897129058838, 55.815375968813896, 51.9500295817852, 64.63486611843109, 28.64241275936365, 31.434236951172352, 59.78812359273434, 48.96270588040352, 56.64291076362133, 52.624778375029564, 57.454444617033005, 53.00851218402386, 52.82528601586819, 52.7494914829731, 52.916070744395256, 52.766647562384605, 54.25128869712353, 49.79387708008289, 49.07035410404205, 44.04676526784897, 42.792425975203514, 39.321817606687546, 43.501878306269646, 42.05819137394428, 44.26122955977917, 43.58545482158661, 44.21191580593586, 40.49126945436001, 43.62965025007725, 43.94269645214081, 43.684450909495354, 41.7741946130991, 42.66049325466156, 44.528928995132446, 41.53885804116726, 42.91042864322662, 43.98711986839771, 50.27269698679447, 57.18823850154877, 54.89995189011097, 54.26996469497681, 54.389312490820885, 49.82476182281971, 45.20056955516338, 43.603089675307274, 43.28862614929676, 43.40941786766052, 43.2395213842392, 45.18699288368225, 46.429275423288345, 50.924088433384895, 55.41146904230118, 57.76276007294655, 57.04528257250786, 56.06776982545853, 57.70887516438961, 54.436030983924866, 51.562545374035835, 48.29286262392998, 53.988696187734604, 59.085092917084694, 60.9357950091362, 58.33731584250927, 60.94943627715111, 20.032868944108486, 1.184538819361478, 2.8117165993899107, 2.0645935647189617, 0.1813002207200043, 0.02385775271250168, 15.454217232763767, 65.27408301830292, 44.41288322210312, 37.79713802039623, 22.391030006110668, 24.756201691925526, 41.78982697427273, 49.95516322553158, 60.51182135939598, 44.591466039419174, 3.39396386872977, 0.1091645129781682, 0.0451400711608585, 0.023641509433218744, 0.08472453613649122, 0.07035790782538243, 0.04272313366527669, 0.04255254360032268, 0.04717042022093665, 0.06918249433510937, 0.04344721004599705, 0.007561364645880531, 0.042688252724474296, 0.18807344633387402, 0.10419129976071417, 0.1161060131562408, 0.14294179854914546, 0.10269199818139896, 0.10627303883666173, 0.11394125744118355, 0.20590344036463648, 0.07971345112309791, 0.15119569783564657, 0.2883168321568519, 0.1256854401435703, 21.31392080336809, 87.96777248382568, 72.08326444029808, 68.93268629908562, 46.88425160944462, 25.398815609514713, 42.7231252938509, 57.408311292529106, 51.39805220067501, 75.81882119178772, 16.224561296403408, 0.35597039095591754, 0.2909346838714555, 18.823013864457607, 23.523124158382416, 7.695843419060111, 20.187779031693935, 61.94963760674, 67.24775031208992, 69.22733768820763, 63.2167936116457, 63.62686760723591, 61.034988686442375, 63.42436887323856, 60.23060604929924, 61.655069813132286, 64.06726017594337, 63.35824862122536, 60.99199399352074, 57.727171182632446, 54.82110992074013, 46.93812131881714, 44.525600373744965, 44.842761754989624, 47.38479495048523, 46.15567110478878, 43.97773817181587, 47.60798737406731, 46.0048533976078, 44.96029704809189, 45.42011417448521, 45.281246826052666, 46.38737887144089, 43.715966418385506, 46.14424131810665, 44.99646730720997, 45.03877803683281, 44.899941086769104, 45.03886163234711, 45.6217959523201, 45.345835760235786, 45.55069036781788, 43.89943577349186, 42.99699179828167, 44.97697435319424, 44.00318160653114, 43.315692096948624, 44.204665794968605, 46.95943057537079, 43.10435503721237, 44.338388219475746, 44.447214379906654, 44.33030225336552, 43.914368972182274, 45.9004919975996, 44.59587760269642, 45.93180611729622, 45.95548264682293, 46.34736321866512, 45.09022727608681, 51.160652339458466, 50.5365814268589, 58.383232578635216, 55.16372613608837, 67.03537970781326, 31.93963073194027, 34.27991755306721, 60.45025326311588, 50.482612922787666, 57.57022060453892, 54.547790586948395, 57.30393089354038, 54.16549690067768, 55.84228992462158, 53.87839950621128, 55.628513395786285, 55.4829204082489, 56.86528243124485, 51.80935353040695, 51.38701759278774, 46.28639928996563, 45.69400727748871, 40.97075432538986, 45.30353643000126, 43.49041052162647, 47.05733232200146, 46.27151168882847, 47.974815890192986, 42.93397977948189, 45.67709818482399, 44.700542986392975, 43.995361626148224, 43.74509945511818, 44.97930362820625, 47.7380657941103, 44.61725905537605, 45.04627503454685, 48.66603299975395, 51.68977774679661, 59.388483837246895, 55.96745900809765, 54.97560203075409, 57.842548191547394, 52.82462105154991, 47.02076308429241, 46.657168194651604, 44.98346820473671, 46.78088195621967, 44.33917857706547, 48.39429438114166, 49.261084869503975, 53.53910431265831, 60.021537467837334, 60.78981064260006, 59.665496572852135, 59.07685495913029, 60.719077438116074, 58.12678433954716, 53.60107898712158, 50.651061683893204, 56.39352634549141, 62.5615643709898, 63.92181158065796, 62.871707528829575, 64.5649042725563, 21.035101264715195, 4.04666505753994, 7.428632257506251, 3.050564182922244, 0.5362537654582411, 0.3012179711367935, 18.965960294008255, 70.96237018704414, 52.33287423849106, 50.92413783073425, 28.461943343281746, 30.524238981306553, 49.596314281225204, 60.19934892654419, 68.13876450061798, 55.231396704912186, 5.117970546707511, 0.36222915980033576, 0.16567878396017477, 0.1830844476353377, 0.22326647507725284, 0.12155490592704155, 0.18518669967306778, 0.1435279319412075, 0.15886555658653378, 0.13317681237822399, 0.12638691812753677, 0.13576453289715573, 0.20970188576029614], [0.04869081363722216, 0.029871490369259845, 0.05045126956247259, 0.018384311551926658, 0.08315004757605493, 0.03527542568917852, 0.0062689752303413115, 0.0036387836871654144, 0.020671286001743283, 0.10997165052685887, 0.04853658792853821, 0.01966803592949873, 21.229954808950424, 62.07480289041996, 50.215665847063065, 42.39688619971275, 18.823853619396687, 20.844775177538395, 42.865154072642326, 37.02756151556969, 48.61339442431927, 54.403675720095634, 3.638147790916264, 0.14789078064495698, 0.10045769580756314, 1.2613433855585754, 5.802734652534127, 7.793128173798323, 33.17969799041748, 64.51289266347885, 60.126328244805336, 59.44001667201519, 61.549568474292755, 62.44831904768944, 60.86353428661823, 61.70479774475098, 60.65759673714638, 57.448433339595795, 60.7943020015955, 58.90099659562111, 59.53503057360649, 56.64835587143898, 53.40564787387848, 49.300838336348534, 42.53662370145321, 40.54855138063431, 41.5025319904089, 40.060767754912376, 41.961646154522896, 41.22522287070751, 41.375531405210495, 40.578759759664536, 40.632405281066895, 41.841747388243675, 39.81508433818817, 40.20708650350571, 39.30601425468922, 39.54741530120373, 42.87877634167671, 42.402753084897995, 41.90743066370487, 40.31399376690388, 41.0294421762228, 38.57253201305866, 41.97111524641514, 39.57581117749214, 39.99778613448143, 38.62934656441212, 40.137652829289436, 38.855404034256935, 40.56462451815605, 37.92288847267628, 42.200060561299324, 44.6656646579504, 45.58105833828449, 45.395708084106445, 44.04071979224682, 43.19813020527363, 44.212983548641205, 42.13052049279213, 45.33136233687401, 42.16941520571709, 48.38226042687893, 46.25461019575596, 52.576441168785095, 46.7622097581625, 59.39979203045368, 33.24297979474068, 31.85417901724577, 56.79896458983421, 47.64146737754345, 52.45028793811798, 50.10309688746929, 53.163935244083405, 47.76820957660675, 51.37933440506458, 48.91387090086937, 50.89501619338989, 50.65930724143982, 52.30759419500828, 45.2053876966238, 46.98395825922489, 41.67769879102707, 40.216415002942085, 39.7499368339777, 39.37441438436508, 41.582133919000626, 42.64888107776642, 41.99830658733845, 40.736937671899796, 41.176296696066856, 39.43224348127842, 41.8401400744915, 41.8932194262743, 40.318314135074615, 41.83234669268131, 41.10947348177433, 42.221696600317955, 41.802814677357674, 45.09514421224594, 49.750240221619606, 54.545149728655815, 53.1672752648592, 53.633118867874146, 51.00041873753071, 45.41833207011223, 41.62797465920448, 40.52744351327419, 40.90443268418312, 41.522587314248085, 43.3780961483717, 43.38691547513008, 44.974846467375755, 41.622917130589485, 45.1764028519392, 46.74812771379948, 49.12490397691727, 48.283564522862434, 46.46332539618015, 43.28956089913845, 43.37474852800369, 44.19984005391598, 49.169870764017105, 53.769489750266075, 60.8402681350708, 56.34871155023575, 60.41127495467663, 33.582966551184654, 3.725008280016482, 1.9027690356597304, 1.136966678313911, 0.2182982861995697, 0.04416144925926346, 2.9451697133481503, 48.03040310740471, 45.550241991877556, 39.7430744022131, 35.025673136115074, 21.97982557117939, 34.19216886162758, 44.12368834018707, 50.51378645002842, 47.28369377553463, 5.250346418470144, 0.10525385485379957, 0.0342919538525166, 0.08696941411471926, 0.011628823267528787, 0.11440744492574595, 0.052220516226952896, 0.05110352831252385, 0.05065297045803163, 0.0763755825755652, 0.035102664842270315, 0.02737652903306298, 0.016562832533963956, 0.020748035203723703, 0.03712239376909565, 0.009604317692719633, 0.03757341175514739, 0.035434256424196064, 0.03355214023031294, 0.02102876183926128, 0.03791873677982949, 0.05689635087037459, 0.12673694465775043, 0.0366589188342914, 0.052742075349669904, 28.03582850843668, 72.14248806238174, 54.744684621691704, 50.25987267494202, 26.477473229169846, 17.738020084798336, 45.979421362280846, 42.117920368909836, 52.16995418071747, 61.158729046583176, 3.1975345965474844, 0.25613730889745057, 0.03567454157746397, 5.894591398537159, 8.49551573395729, 5.226019648835063, 36.141734048724174, 64.6736392378807, 61.47481508553028, 61.1777014285326, 64.56770092248917, 63.662863075733185, 62.026708871126175, 60.409652441740036, 61.085719764232635, 59.190586656332016, 61.67545571923256, 59.55458052456379, 60.34878350794315, 59.1791682690382, 55.782317742705345, 50.41304625570774, 44.93736907839775, 43.75878632068634, 43.00581872463226, 42.34997011721134, 44.060353338718414, 44.29866135120392, 42.792881950736046, 42.55159489810467, 43.12591128051281, 44.084554240107536, 42.48450569808483, 42.43194691836834, 40.54791301488876, 41.70615926384926, 44.05997335910797, 44.09765973687172, 46.06975011527538, 41.16204746067524, 43.74286137521267, 40.5224771797657, 43.51870760321617, 41.766500025987625, 41.165250688791275, 40.14691673219204, 41.98618523776531, 42.13033810257912, 43.26181858778, 39.73148122429848, 43.94859753549099, 46.54913239181042, 47.196385860443115, 47.95583210885525, 47.54528693854809, 45.60921862721443, 45.36369480192661, 45.34863620996475, 46.793299689888954, 45.070441737771034, 50.15531748533249, 48.337571024894714, 54.467561691999435, 48.00932563841343, 61.39417581260204, 35.27566932141781, 34.845585599541664, 58.516594022512436, 49.415428787469864, 56.18534691631794, 52.60227598249912, 54.32055898010731, 51.22358076274395, 54.09555405378342, 50.66741220653057, 52.02339604496956, 51.83026760816574, 52.809171080589294, 47.30679653584957, 49.1167838126421, 42.75036983191967, 43.22005122900009, 40.97769275307655, 42.061238810420036, 43.51509399712086, 43.93539324402809, 42.86181405186653, 43.618938624858856, 42.23658800125122, 41.07163891196251, 43.797893822193146, 43.63642908632755, 42.170726135373116, 41.98787994682789, 43.09556230902672, 42.873616218566895, 43.00254710018635, 46.43316641449928, 52.240379601716995, 55.41605159640312, 54.03687000274658, 55.58515012264252, 53.097359016537666, 48.04855473339558, 43.1484554708004, 42.64563985168934, 43.356691896915436, 43.375375494360924, 44.16694901883602, 45.409702733159065, 46.174943670630455, 43.675722777843475, 45.08320905268192, 47.44271144270897, 50.169779509305954, 48.51479351520538, 50.724656134843826, 45.225583612918854, 44.735512509942055, 46.754678562283516, 50.89609153568745, 56.501140370965004, 62.644791305065155, 59.27740819752216, 63.96574482321739, 36.88851557672024, 4.221944427117705, 1.39804010046646, 3.2276950031518936, 0.4120630701072514, 0.03377145971171558, 3.0561023857444525, 52.841697335243225, 49.982377365231514, 42.04716436564922, 29.23748552799225, 27.297169044613838, 41.82456851005554, 49.77229043841362, 55.60114726424217, 57.72508889436722, 7.783475741744041, 0.2358541011926718, 0.0852744749863632, 0.08105831177090295, 0.04008338859421201, 0.02443132339976728, 0.06148571417725179, 0.07899019110482186, 0.07103715848643333, 0.040033323311945423, 0.04611624768585898, 0.03760631487239152, 0.05041390242695343, 0.13858625257853419, 0.12889807869214565, 0.1516908736084588, 0.11534752338775434, 0.14712185628013685, 0.21353176853153855, 0.10925760798272677, 0.12131857642089017, 0.2062527247471735, 0.17172283463878557, 0.1608684053644538, 0.14992367156082764, 35.216677486896515, 81.14282950758934, 63.07986415922642, 57.86937475204468, 27.824069671332836, 30.399216189980507, 52.32997119426727, 51.07427917420864, 60.98576992750168, 67.10739344358444, 4.863122021779418, 0.47727255849167705, 0.19838779990095645, 9.057784862816334, 16.890568658709526, 11.182899679988623, 38.76285620033741, 66.90912008285522, 62.24969610571861, 61.18408888578415, 66.24911829829216, 66.22190415859222, 62.93671064078808, 60.9833000600338, 61.88178464770317, 60.37594445049763, 63.81427735090256, 63.99200141429901, 64.36856880784035, 62.101097479462624, 59.659853875637054, 54.53912705183029, 46.6533911973238, 45.80722600221634, 44.45636808872223, 42.56231792271137, 44.896692261099815, 46.84689201414585, 45.69616936147213, 44.528336226940155, 45.86725518107414, 46.286859065294266, 45.088646560907364, 44.64492157101631, 42.20273941755295, 44.34702895581722, 47.73583151400089, 47.37324357032776, 46.98170877993107, 44.751684442162514, 45.91191418468952, 42.188288792967796, 46.27469211816788, 44.44074712693691, 44.324161782860756, 43.703772872686386, 44.44706238806248, 43.384217619895935, 45.64971685409546, 42.48015873134136, 47.66653463244438, 49.29044969379902, 49.61776413023472, 49.30585786700249, 49.00456823408604, 48.909922912716866, 48.42337802052498, 47.45416022837162, 50.90730093419552, 47.03912749886513, 52.036881521344185, 50.280581563711166, 57.43451088666916, 49.11728158593178, 64.96424004435539, 38.1415743380785, 37.31828011572361, 58.91603618860245, 50.50677202641964, 57.272221595048904, 55.65524496138096, 57.57682465016842, 53.2812425494194, 55.26555307209492, 52.764538675546646, 54.037223383784294, 54.320650175213814, 55.85172101855278, 48.985402062535286, 50.984482392668724, 46.78268685936928, 45.735440254211426, 43.30069050192833, 44.09272000193596, 46.424309089779854, 45.81710547208786, 46.7045858502388, 45.926228016614914, 43.90188664197922, 42.686350867152214, 45.855912789702415, 46.59820295870304, 44.90768887102604, 44.538489282131195, 45.8664496243, 44.948297291994095, 44.99528557062149, 49.350326880812645, 53.72499793767929, 60.368052273988724, 56.88653089106083, 57.50360257923603, 57.16979429125786, 50.56862510740757, 44.8233637958765, 44.34886045753956, 46.04581519961357, 44.3841377645731, 46.65680721402168, 48.057678043842316, 49.215327724814415, 45.36783277988434, 48.78760367631912, 51.062534004449844, 52.40538954734802, 51.692475602030754, 53.41847598552704, 47.63617806136608, 48.70570667088032, 49.372741878032684, 55.47561340034008, 57.835218384861946, 66.41068562865257, 60.93567341566086, 66.05571627616882, 39.84742820262909, 5.849283104762435, 6.66457780636847, 4.9426028318703175, 0.6875635462347418, 0.08802986892987974, 3.8121801149100065, 59.55116830766201, 56.269937977194786, 57.85407677292824, 46.45416408777237, 34.71317030489445, 47.49855324625969, 58.35233263671398, 62.90687844157219, 66.48900702595711, 10.292645450681448, 0.612913464428857, 0.16845017118612304, 0.2182577649364248, 0.08203060686355457, 0.14998043101513758, 0.16794319526525214, 0.20298068469855934, 0.2860428619896993, 0.16227700165472925, 0.09391235405928455, 0.15368625638075173, 0.14156576769892126], [0.034333113362663426, 0.04946337823639624, 0.04215662265778519, 0.0560494490491692, 0.06999663033639081, 0.007349482875724789, 0.050763806502800435, 0.053678843833040446, 0.0425437973899534, 0.14524664205964655, 0.05853789989487268, 0.2087594917975366, 35.49513414502144, 63.84030595421791, 51.019436717033386, 30.667550191283226, 18.21896217763424, 39.93887409567833, 59.096678495407104, 37.18616120517254, 55.97486861050129, 40.320115238428116, 0.6694974156562239, 0.03883020544890314, 0.11578413628740236, 4.2513728979974985, 6.389738554134965, 11.745230555534363, 50.66457375884056, 60.93990258872509, 62.099083587527275, 62.798534855246544, 60.42750768363476, 61.312806978821754, 61.01711064577103, 58.297805562615395, 60.69226987659931, 61.86966709792614, 56.238783448934555, 56.57793045043945, 56.05765096843243, 56.54947757720947, 56.460486352443695, 52.12817162275314, 45.85408128798008, 40.5163861066103, 43.19485478103161, 40.41025400161743, 40.59897467494011, 40.823348835110664, 40.441195741295815, 38.827312141656876, 40.75105011463165, 41.46529018878937, 42.913628071546555, 40.98100997507572, 43.23256015777588, 43.07275213301182, 45.45697599649429, 45.3778338432312, 45.727559477090836, 42.83292040228844, 41.63456730544567, 39.89183261990547, 41.26893192529678, 40.62316797673702, 42.0863326638937, 39.45380352437496, 41.14890016615391, 40.639575496315956, 40.18336057662964, 38.979539573192596, 47.56838209927082, 52.05637827515602, 51.61137655377388, 50.18912807106972, 51.72695115208626, 50.923480466008186, 52.89172925055027, 48.54417733848095, 49.46503132581711, 49.91979092359543, 54.0860203653574, 51.31140545010567, 54.742678329348564, 49.164896830916405, 60.20797446370125, 35.935097336769104, 34.03458371758461, 58.902554512023926, 48.348229452967644, 54.31130267679691, 49.995353668928146, 51.62061385810375, 49.15521115064621, 49.408543556928635, 50.069442093372345, 49.98443305492401, 50.04789724946022, 51.177983209490776, 47.06805534660816, 45.22201560437679, 41.28008432686329, 39.640609100461006, 38.26984025537968, 41.59719631075859, 40.46753212809563, 41.486512050032616, 40.66588148474693, 39.085759073495865, 39.13101464509964, 40.380604192614555, 40.157392770051956, 40.23521639406681, 40.93726672232151, 40.25044597685337, 41.39044560492039, 42.48806230723858, 47.14940518140793, 46.81636445224285, 51.45088456571102, 52.61843651533127, 51.15086026489735, 52.873923406004906, 50.10135278105736, 44.05859023332596, 42.743967175483704, 40.69844953715801, 40.76834298670292, 42.19776548445225, 40.61627894639969, 41.36929973959923, 41.99415720999241, 42.13737532496452, 42.182053327560425, 42.96806015074253, 40.99400907754898, 40.891042202711105, 41.72306835651398, 42.37293228507042, 45.40170416235924, 45.54819770157337, 46.08515068888664, 50.9042838960886, 59.13657255470753, 55.232141464948654, 57.645961940288544, 50.92283830046654, 8.635029997676611, 1.1953229969367385, 3.780715665780008, 0.1222879029228352, 0.13410215178737417, 0.39067113830242306, 33.943175822496414, 56.04591719806194, 35.790640488266945, 35.74471615254879, 14.246857669204473, 24.558266513049603, 38.08427721261978, 45.21426402032375, 51.57584846019745, 12.370785288512707, 0.19975609757239, 0.04215331638988573, 0.013614746439998271, 0.09971171122742817, 0.04385974767501466, 0.03537870667059906, 0.04224796990456525, 0.06469477928476408, 0.0886921095661819, 0.024047113547567278, 0.03223812695068773, 0.05385417622164823, 0.06554855339345522, 0.09222253574989736, 0.015908096866041888, 0.07057295253616758, 0.010572664559731493, 0.06521683564642444, 0.04293157697247807, 0.030533053795807064, 0.03641569477622397, 0.058996268853661604, 0.08631177479401231, 0.6117423553951085, 45.6607286632061, 70.60205072164536, 58.10190327465534, 39.26816828548908, 21.249231174588203, 35.22982858121395, 60.89194916188717, 43.402920216321945, 63.34318622946739, 44.00265343487263, 0.6631066929548979, 0.09322729238192551, 0.2550679334672168, 3.9948738366365433, 2.4815601529553533, 11.301828548312187, 52.764470279216766, 60.91529130935669, 65.09759768843651, 62.95835807919502, 62.93113254010677, 63.17565701901913, 61.79400935769081, 60.9524305164814, 62.84867696464062, 63.31563010811806, 58.534061685204506, 58.879307359457016, 58.5729905962944, 58.79979282617569, 58.60296718776226, 54.09100949764252, 48.055850341916084, 43.55971120297909, 44.656681939959526, 40.772302374243736, 42.698305025696754, 42.83085711300373, 41.77361324429512, 40.98465397953987, 43.72727461159229, 43.09283405542374, 45.35141386091709, 43.206865936517715, 47.362676337361336, 45.33076576888561, 48.098856434226036, 47.54193551838398, 46.99257239699364, 44.782538786530495, 44.011286571621895, 41.09266318380833, 41.80818758904934, 42.076646983623505, 44.48481336236, 41.569476798176765, 42.54938341677189, 42.78922654688358, 41.93124018609524, 41.744085028767586, 49.355471804738045, 52.66504481434822, 54.30181838572025, 51.6788799315691, 53.785019516944885, 53.38370405137539, 54.36847060918808, 49.760530069470406, 52.111726105213165, 52.086746245622635, 56.419273763895035, 52.58919708430767, 57.27029509842396, 50.645669773221016, 62.85819165408611, 37.911352291703224, 35.88476903736591, 60.50862193107605, 51.110255643725395, 55.92455551028252, 52.66610115766525, 55.747089833021164, 51.098335683345795, 52.261981442570686, 51.496789902448654, 51.20035640895367, 51.975518614053726, 52.03674852848053, 49.26485426723957, 46.95740148425102, 42.67225742340088, 41.42711363732815, 39.55850690603256, 44.17202554643154, 42.68741101026535, 42.847367227077484, 43.871374279260635, 40.33563360571861, 41.86799257993698, 41.91747732460499, 41.90960414707661, 43.176980540156364, 43.932490199804306, 42.14823514223099, 43.516952097415924, 44.25325758755207, 49.58830811083317, 50.55537521839142, 54.77965034544468, 55.07895268499851, 53.08233842253685, 54.83534775674343, 52.246888652443886, 46.540522053837776, 43.647193908691406, 43.28092776238918, 43.33029851317406, 43.68087150156498, 43.162822499871254, 43.1704942882061, 44.199897050857544, 43.986736088991165, 44.15159784257412, 45.037736892700195, 43.213640972971916, 43.131318390369415, 44.11258913576603, 44.13413017988205, 48.10813933610916, 45.981906428933144, 48.540331944823265, 51.837912797927856, 61.912179216742516, 57.4604444950819, 59.3424417078495, 53.38424742221832, 10.580082926899195, 1.1692017735913396, 4.513137526810169, 0.3228372079320252, 0.11603006918448955, 0.4527191666420549, 35.631486028432846, 59.95357431471348, 40.5918500572443, 36.82750225067139, 19.999371841549873, 31.9118732213974, 43.30089949071407, 51.21174439787865, 61.04517214000225, 18.342345356941223, 0.29319660156033933, 0.05309078827849589, 0.07841792845283635, 0.02922391828178661, 0.021153129091544542, 0.07471259290468879, 0.044038946653017774, 0.0863852770999074, 0.023870693912613206, 0.03284489946963731, 0.02391019657807192, 0.06152129273687024, 0.11153033134178258, 0.23999895143788308, 0.1144080534868408, 0.16463763982756063, 0.10689681395888329, 0.11275877128355205, 0.22007828287314624, 0.24835096264723688, 0.1476002743584104, 0.15470529935555533, 0.14930368139175698, 0.8041780418716371, 56.04644916951656, 80.04669472575188, 66.6194312274456, 44.9016509950161, 26.980666927993298, 52.24043279886246, 70.86477622389793, 52.09036745131016, 68.28449428081512, 49.72224712371826, 1.0799501440487802, 0.2298126183450222, 0.3907783341128379, 9.37693353742361, 12.92975714430213, 15.74926570057869, 52.237617149949074, 62.93565429747105, 66.82063043117523, 65.35611301660538, 66.0939422249794, 65.77165871858597, 67.00159192085266, 63.94372880458832, 66.65217027068138, 63.92419025301933, 58.94830785691738, 61.92932389676571, 60.055522844195366, 60.1786058396101, 59.87561009824276, 55.945598781108856, 51.149959713220596, 44.72186744213104, 47.88031876087189, 44.0695146471262, 44.511742517352104, 44.44889008998871, 43.60890336334705, 43.32080662250519, 46.20739012956619, 45.60977719724178, 47.335329204797745, 45.561037212610245, 49.60372768342495, 48.004537895321846, 51.531417444348335, 50.5683933198452, 49.00807544589043, 47.67100319266319, 47.02371172606945, 43.459438383579254, 44.65020328760147, 44.047988802194595, 47.92196452617645, 43.8445059210062, 45.21103419363499, 45.14255806803703, 45.049732849001884, 43.49128067493439, 52.620594799518585, 54.26222451031208, 54.98877212405205, 54.380823746323586, 56.14481829106808, 56.69292747974396, 59.58646461367607, 52.096264734864235, 53.65441672503948, 56.437383592128754, 59.061279594898224, 56.30688339471817, 58.420516178011894, 54.09042052924633, 66.06136277318001, 40.58928519487381, 38.61838415265083, 62.518505081534386, 53.99852246046066, 57.03383378684521, 55.024399012327194, 57.11656294763088, 53.439173474907875, 51.742366924881935, 53.08184064924717, 52.79315873980522, 53.20642076432705, 54.492275565862656, 51.963762044906616, 50.2559968829155, 46.369360238313675, 43.737997636199, 42.33808435499668, 46.80864326655865, 44.32523712515831, 45.47423467040062, 45.7776065915823, 40.797821804881096, 42.78991051018238, 45.024213418364525, 43.51234674453735, 44.875383004546165, 46.3831876963377, 43.700375854969025, 46.394134908914566, 47.38392099738121, 52.20533028244972, 52.93773718178272, 56.689598858356476, 56.88210792839527, 54.55218695104122, 58.754639849066734, 55.41390851140022, 47.964833825826645, 46.456861943006516, 45.723451897501945, 45.212155133485794, 47.661435306072235, 45.005750209093094, 44.97546963393688, 46.76614634692669, 45.74250407516956, 46.307431161403656, 47.665972262620926, 46.213428005576134, 46.263722106814384, 46.5944829583168, 47.261643558740616, 50.92971213161945, 49.05189849436283, 51.29744879901409, 54.893173053860664, 64.15378913283348, 60.93591660261154, 62.5125166028738, 57.5373599678278, 11.423187386244535, 3.7220052536576986, 9.289033804088831, 0.35097523243166506, 0.4946942673996091, 0.6338552094530314, 42.40019202232361, 65.58939769864082, 52.81305447220802, 47.56320297718048, 23.220648989081383, 36.04101665318012, 53.32739107310772, 57.94770374894142, 71.2393145263195, 23.866758719086647, 0.7276729471050203, 0.20395493163960055, 0.21642247826093808, 0.15480940783163533, 0.1813437105738558, 0.18310889397980645, 0.23806519660865888, 0.09919782591168769, 0.14224437269149348, 0.18039300455711782, 0.09163508875644766, 0.3290980844758451], [0.02166862857848173, 0.07337407019804232, 0.05005081409763079, 0.008477128958475078, 0.050964368201675825, 0.08907313560484909, 0.03193480377376545, 0.03741210966836661, 0.029150161790312268, 0.08689293579664081, 0.09234253360773437, 3.6374621652066708, 50.72101593017578, 55.17544850707054, 42.53038823604584, 34.30797524750233, 22.322029508650303, 29.062746204435825, 45.28905160725117, 37.426897287368774, 64.16451215744019, 28.91720451414585, 0.16943488240940496, 0.04291898643714376, 0.14946423762012273, 3.6688482435420156, 6.621605437248945, 22.432392686605453, 63.35813082754612, 59.4635184109211, 64.52224016189575, 57.36982695758343, 60.59556886553764, 57.594356909394264, 58.15888501703739, 56.61029331386089, 57.572713270783424, 55.885261818766594, 58.06056909263134, 57.77642413973808, 58.55160154402256, 56.21236726641655, 57.716862335801125, 53.09812657535076, 46.14305958151817, 41.08177296817303, 43.66722643375397, 41.835128143429756, 44.117190688848495, 39.5961856842041, 41.058339625597, 41.255659237504005, 44.75212141871452, 43.25687125325203, 44.24837864935398, 46.925650388002396, 48.73804293572903, 47.76506334543228, 47.97456510365009, 47.791494727134705, 48.87053802609444, 45.39826914668083, 45.23638263344765, 41.17335185408592, 41.188969016075134, 40.25155171751976, 42.63517141342163, 40.01275733113289, 41.468014642596245, 40.79417400062084, 40.111901611089706, 44.32950049638748, 53.508082777261734, 56.662354320287704, 56.411161199212074, 52.57175602018833, 54.446921199560165, 53.49232502281666, 56.09860137104988, 52.51644618809223, 52.68147133290768, 51.556971073150635, 54.3204639852047, 51.96051321923733, 55.953684747219086, 49.801955446600914, 57.5942163169384, 35.59760324656963, 33.53435575962067, 58.231065943837166, 50.81542946398258, 54.57440435886383, 49.45398151874542, 51.44248701632023, 51.02300092577934, 53.18111792206764, 50.531326308846474, 51.95835493505001, 49.58107329905033, 50.02461589872837, 45.34322530031204, 43.83535601198673, 40.29885157942772, 39.80587363243103, 40.74554800987244, 38.808050975203514, 41.094582080841064, 40.94970345497131, 39.40260127186775, 39.52481031417847, 40.1187564432621, 38.67202207446098, 40.48916436731815, 39.69764024019241, 41.59897081553936, 42.30382539331913, 44.83911395072937, 49.243282824754715, 50.288325548172, 52.6265224814415, 52.94000566005707, 51.036482602357864, 52.70093768835068, 53.54368306696415, 46.92129582166672, 41.342594772577286, 40.7719299942255, 42.61479690670967, 40.445561707019806, 41.338357999920845, 42.96951547265053, 42.473155707120895, 42.436426877975464, 41.50961481034756, 41.73144690692425, 42.902232483029366, 45.002911761403084, 47.263003885746, 48.462770506739616, 51.391383558511734, 52.51503266394138, 53.65145668387413, 49.12373743951321, 47.94907607138157, 53.776108995079994, 59.71533089876175, 58.72582979500294, 60.401368886232376, 25.84048680961132, 0.3235696186311543, 2.3007413931190968, 0.7983692223206162, 0.08735380950383842, 0.018970010787597857, 21.34779218584299, 59.78113196790218, 41.073538810014725, 39.71193127334118, 17.183496840298176, 19.685685373842716, 40.11671595275402, 45.356494188308716, 62.48766213655472, 19.53450098633766, 0.27850899437908083, 0.0247252751069027, 0.027925072645302862, 0.02064031061308924, 0.055261785455513746, 0.045753942322335206, 0.04161881050094962, 0.06197336086188443, 0.041875986935338005, 0.014944112899684114, 0.012165481384727173, 0.042253951614839025, 0.0259992550854804, 0.1073845311475452, 0.07077643458615057, 0.009098550544877071, 0.03953090788854752, 0.021674265190085862, 0.018764565757010132, 0.07042109427857213, 0.035900150760426186, 0.12676761019974947, 0.22892446053447202, 4.836304960772395, 60.75566567480564, 61.29942409694195, 49.611277878284454, 35.907605811953545, 19.745701253414154, 24.983830377459526, 48.560474663972855, 44.61555674672127, 70.72047516703606, 31.004316620528698, 0.14366194896865636, 0.03372028862941079, 1.174593090545386, 4.499290119856596, 1.3130102818831801, 24.36380624771118, 64.99662190675735, 63.33891145884991, 64.90316972136497, 61.7497493326664, 61.93623572587967, 58.28196041285992, 60.095249712467194, 58.840701431035995, 62.096606120467186, 57.52324752509594, 60.89821122586727, 58.696525767445564, 60.62857009470463, 58.512391448020935, 59.11906689405441, 54.658702835440636, 49.6636238694191, 43.20147022604942, 45.73100209236145, 43.500213995575905, 45.461075976490974, 41.66585862636566, 43.3106953650713, 42.63861022889614, 47.08976738154888, 46.93058252334595, 49.20078970491886, 48.368786349892616, 51.226510405540466, 49.311173781752586, 50.365233421325684, 49.11664701998234, 49.988578632473946, 47.89327226579189, 47.81112067401409, 41.84509500861168, 43.34822975099087, 41.6961620002985, 43.713591545820236, 41.05187997221947, 43.262707740068436, 41.23565711081028, 41.15157902240753, 44.827885553240776, 54.60308142006397, 60.36419168114662, 57.25323021411896, 55.27949832379818, 56.85693047940731, 55.34149579703808, 56.200743690133095, 54.951948300004005, 55.77382519841194, 55.19380912184715, 56.15901432931423, 52.79592879116535, 56.55277960002422, 50.70855639874935, 59.16061386466026, 36.50030940771103, 35.16227960586548, 58.8033152371645, 52.44783706963062, 55.19971780478954, 52.61199586093426, 54.83465239405632, 52.57675275206566, 54.53641019761562, 52.25047945976257, 54.557951241731644, 50.75633883476257, 51.13551668822765, 47.117502093315125, 45.44368430972099, 42.51272678375244, 41.67577609419823, 42.052430883049965, 41.3666170835495, 42.29763552546501, 41.50735393166542, 41.261043548583984, 43.1875591725111, 42.74869032204151, 40.02497747540474, 41.42761521041393, 42.97208413481712, 45.69875702261925, 45.940591245889664, 46.455060839653015, 50.38149654865265, 51.92585527896881, 55.37753686308861, 54.849156215786934, 51.477882117033005, 54.27207738161087, 54.991599172353745, 49.650757759809494, 42.80591905117035, 42.03091263771057, 43.472920060157776, 43.052271232008934, 43.102865517139435, 45.80523490905762, 43.829321935772896, 45.20772837102413, 43.705657571554184, 43.604222014546394, 44.27314572036266, 46.533986404538155, 48.6954890191555, 50.604103803634644, 52.56616272032261, 55.05333065986633, 56.13181918859482, 51.23805418610573, 50.338076278567314, 55.641968473792076, 63.23730491101742, 62.109844610095024, 63.595538288354874, 29.915798529982567, 1.0529198194853961, 3.127794088795781, 2.3827652167528868, 0.11544642198714428, 0.10185317834839225, 22.359504997730255, 64.72043752670288, 46.44502177834511, 40.58566778898239, 21.15115463733673, 23.458501026034355, 47.23186835646629, 52.230800315737724, 68.62543478608131, 26.715699546039104, 0.15234967810101807, 0.010558287303865654, 0.015920442492642906, 0.039557599229738116, 0.015335912139562424, 0.06404118466889486, 0.04969012661604211, 0.05902175049413927, 0.020455248668440618, 0.027412159543018788, 0.07314627539017238, 0.05865868071850855, 0.1833831175463274, 0.1552003712276928, 0.20469449664233252, 0.0902874450548552, 0.1089525333372876, 0.14773522649193183, 0.14157510391669348, 0.17192679166328162, 0.12978553888387978, 0.384710356593132, 0.48463887884281576, 6.0513728857040405, 70.79814299941063, 70.77562540769577, 56.24414496123791, 44.43055987358093, 31.72189101576805, 38.20419877767563, 58.33397202193737, 51.7327344417572, 77.50437274575233, 35.53898759186268, 0.3709241026081145, 0.19368151493836194, 1.235353492666036, 15.169314220547676, 15.71280475705862, 25.506701320409775, 67.53452852368355, 64.65976998209953, 69.02436017990112, 62.933116033673286, 65.72075664997101, 61.79393336176872, 63.721638321876526, 61.63925126194954, 65.24477899074554, 61.34511284530163, 63.58765751123428, 62.180942595005035, 64.47173327207565, 59.217219427227974, 62.602282986044884, 56.99405752122402, 51.641866117715836, 45.1922632008791, 47.737085446715355, 44.62977558374405, 47.415387108922005, 43.75750198960304, 46.83051489293575, 45.847766026854515, 50.56577526032925, 48.71886916458607, 49.75767642259598, 49.42157685756683, 54.174787402153015, 53.55254419147968, 52.59387843310833, 51.590466275811195, 53.74399691820145, 50.87516985833645, 50.54003544151783, 42.62950971722603, 45.87803140282631, 44.13799077272415, 46.956075355410576, 43.978691920638084, 45.25600478053093, 43.161940947175026, 44.933709874749184, 47.58123300969601, 58.13432313501835, 59.770944714546204, 60.95230132341385, 58.59628714621067, 60.32394424080849, 57.88079313933849, 59.81333523988724, 55.48942185938358, 57.57259547710419, 56.708936020731926, 58.99611309170723, 55.9419471770525, 60.39316512644291, 53.92165258526802, 62.28446803987026, 38.24632331728935, 37.039762660861015, 63.33212502300739, 56.06135576963425, 58.11705686151981, 54.464901834726334, 57.70933873951435, 54.96396325528622, 56.952350959181786, 55.76728954911232, 56.04803368449211, 52.60387569665909, 53.689705431461334, 48.73653821647167, 47.99787685275078, 44.21945460140705, 44.55774664878845, 45.199482813477516, 41.83785639703274, 44.324359372258186, 43.45523200929165, 44.90271873772144, 44.35938589274883, 44.87739309668541, 41.3310319930315, 43.547179475426674, 44.604320749640465, 46.09053499996662, 47.706728875637054, 47.53215104341507, 53.85720044374466, 54.26999509334564, 58.245026394724846, 58.099915981292725, 53.51390786468983, 55.37148758769035, 58.40603895485401, 51.221380680799484, 44.23482097685337, 43.86295773088932, 47.128958478569984, 46.2818319350481, 45.08637048304081, 48.796601593494415, 46.74010254442692, 48.21504659950733, 46.033025085926056, 45.58610446751118, 46.067394241690636, 49.607873260974884, 51.500099524855614, 53.62329639494419, 56.312803477048874, 57.70407222211361, 59.1546443849802, 54.254537522792816, 53.235272616147995, 58.820258527994156, 66.53888314962387, 65.2812722325325, 65.82731813192368, 31.717475652694702, 1.806667917408049, 9.13785606622696, 2.997862435877323, 0.46217026887461543, 0.2520772267598659, 26.816378943622112, 69.68191489577293, 55.9582407027483, 50.12302301824093, 26.037162356078625, 29.76770717650652, 56.47145256400108, 59.79309752583504, 78.50880324840546, 34.63353417813778, 0.4440149321453646, 0.06403378545655869, 0.10803891243995167, 0.14875483349896967, 0.13556339603383094, 0.132680612441618, 0.11251018891925924, 0.13905390951549634, 0.11081628137617372, 0.10470560067915358, 0.14986976195359603, 0.10948106122668833], [0.010703897605708335, 0.025800365074246656, 0.03699891152791679, 0.043558688048506156, 0.05381265676987823, 0.028141269540356006, 0.0641894583532121, 0.03570379703887738, 0.029793268004141282, 0.04586238123010844, 0.0624702287313994, 6.253042314201593, 56.55918225646019, 52.85663813352585, 48.882199600338936, 55.171625912189484, 41.30193695425987, 28.798096105456352, 36.53285086154938, 42.05229789018631, 67.46666416525841, 17.371524050831795, 0.04584379043080844, 0.04241257825924549, 0.5982286180369556, 1.968813647981733, 4.176492691040039, 54.593008160591125, 62.24358603358269, 61.792356446385384, 59.404142796993256, 59.436976835131645, 54.05087225139141, 53.913912400603294, 50.310926735401154, 50.228178575634956, 49.686122462153435, 53.13599534332752, 51.89347721636295, 51.971650421619415, 54.16872672736645, 50.65347455441952, 49.12557274103165, 45.698274448513985, 41.636079624295235, 41.363672241568565, 41.4377074688673, 37.666394636034966, 40.39932578802109, 40.67286550998688, 41.010682582855225, 44.70054678618908, 46.54412046074867, 46.885174959897995, 47.33798526227474, 48.79294618964195, 50.80246075987816, 51.13979905843735, 51.12420089542866, 51.57350778579712, 51.537960693240166, 48.26653763651848, 46.00569315254688, 42.573595717549324, 40.49664616584778, 40.804270058870316, 41.69782251119614, 38.635065257549286, 39.997394755482674, 40.79570151865482, 39.19513240456581, 45.95395512878895, 54.18087847530842, 53.69219809770584, 48.572736606001854, 51.65711469948292, 54.86612230539322, 51.1378725618124, 51.65027506649494, 51.936354115605354, 54.123892933130264, 52.695652171969414, 51.346990540623665, 52.29159705340862, 56.81340001523495, 51.42072558403015, 54.39316168427467, 40.219614431262016, 35.14182150363922, 57.3837798088789, 53.085773438215256, 52.44560278952122, 49.16047006845474, 51.64558991789818, 48.30975651741028, 50.9547071903944, 47.54111476242542, 48.71646769344807, 48.364222794771194, 48.648268952965736, 45.56256093084812, 42.58081153035164, 39.320233091712, 38.01158331334591, 38.542521223425865, 42.039010003209114, 41.60416513681412, 40.52894063293934, 38.50757449865341, 41.35899469256401, 39.01694096624851, 40.50287023186684, 39.1742867231369, 43.65069352090359, 45.12917898595333, 48.453404009342194, 50.61673812568188, 53.123022839426994, 51.94722533226013, 51.93277470767498, 50.13093799352646, 52.220502868294716, 53.20519722998142, 49.68957647681236, 45.79447768628597, 41.08735106885433, 41.443908736109734, 39.855331778526306, 42.339965254068375, 41.947795897722244, 41.17819659411907, 41.42033860087395, 43.671117424964905, 48.13645541667938, 50.975625067949295, 51.37512803077698, 52.796206176280975, 55.39570748806, 56.730560660362244, 56.66722185909748, 60.013717487454414, 58.720510080456734, 57.412399873137474, 51.97256617248058, 50.84568724036217, 55.25595098733902, 57.33551099896431, 61.36113278567791, 46.97258546948433, 3.0054470663890243, 2.0532506983727217, 1.3303276151418686, 0.0314775703009218, 0.08290429279441014, 10.918796751648188, 57.64611393213272, 45.23724898695946, 43.62640142440796, 26.580073423683643, 24.65404037386179, 36.73465423285961, 44.93275612592697, 52.19185620546341, 32.90523111820221, 1.1541650304570794, 0.024835482181515545, 0.005139634267834481, 0.007675868291698862, 0.0071908395329955965, 0.05151462246431038, 0.033768906723707914, 0.059430488327052444, 0.02655391213920666, 0.07848541194107383, 0.04927560003125109, 0.04178029441391118, 0.047415562730748206, 0.041201727217412554, 0.08784761230344884, 0.056966279735206626, 0.012390416140988236, 0.020454454570426606, 0.025598185493436176, 0.05012027540942654, 0.03515550204610918, 0.05299597149132751, 0.035211857029935345, 7.992590870708227, 67.50909268856049, 59.12781402468681, 54.3720880150795, 58.73160548508167, 46.73157200217247, 32.56411202251911, 40.44703982770443, 45.65524935722351, 71.86797559261322, 19.192078560590744, 0.02736193098826334, 0.03535149953677319, 2.1497030602768064, 0.9735582873690873, 4.851090917363763, 57.00926810503006, 64.8718897998333, 62.67550125718117, 61.03022754192352, 60.009590908885, 58.30049201846123, 56.5573887526989, 52.194991037249565, 52.76711493730545, 51.8226034194231, 56.35670632123947, 55.362390875816345, 53.81098352372646, 55.32149747014046, 54.48467217385769, 51.22803412377834, 49.01172325015068, 44.01999570429325, 42.86596342921257, 43.2423560321331, 39.539576321840286, 42.496068477630615, 41.878115236759186, 42.37039402127266, 47.315391674637794, 48.623201698064804, 50.26592195034027, 50.44598288834095, 52.207279577851295, 50.58796226978302, 52.583729177713394, 52.42908887565136, 53.74724194407463, 53.012034595012665, 50.52644357085228, 47.5067114084959, 44.144716411828995, 43.39902922511101, 43.04968737065792, 42.660101875662804, 41.15816026926041, 41.67737580835819, 42.49852694571018, 40.36557599902153, 48.738685101270676, 56.2970495223999, 55.295719653367996, 51.10410377383232, 53.09103615581989, 54.51040059328079, 53.11888486146927, 54.172207340598106, 52.97892317175865, 55.79245559871197, 54.08853583037853, 53.83796587586403, 53.47354643046856, 57.20210015773773, 54.12193223834038, 56.49987883865833, 42.20490150153637, 37.09493190050125, 59.12890076637268, 54.87885922193527, 56.1211721599102, 51.211862191557884, 53.787861764431, 50.577607825398445, 51.679605692625046, 50.508345142006874, 50.31125731766224, 49.3041517585516, 48.79601642489433, 47.14604236185551, 44.60427515208721, 42.03701891005039, 39.441062808036804, 40.39207957684994, 42.90532171726227, 42.43715263903141, 42.99146309494972, 41.71150557696819, 42.37541735172272, 39.8705879598856, 42.99106031656265, 40.48821821808815, 45.20381458103657, 47.150362730026245, 50.02593822777271, 51.60275101661682, 54.985375106334686, 53.85161854326725, 55.89379996061325, 52.28158079087734, 55.04460632801056, 54.123155772686005, 51.95287182927132, 48.41916024684906, 44.08303812146187, 42.26640120148659, 42.17916168272495, 43.6176048964262, 45.37688009440899, 43.64023648202419, 44.0229519456625, 44.921945706009865, 51.370598673820496, 52.16132864356041, 53.92496220767498, 55.655894726514816, 57.158387303352356, 60.0721887499094, 59.14552867412567, 61.71915337443352, 59.243194833397865, 59.76807586848736, 54.27044726908207, 52.151806354522705, 58.66216041147709, 59.79365609586239, 64.93704870343208, 50.63126474618912, 4.5455901604145765, 2.0371452625840902, 2.4061814602464437, 0.2649861137615517, 0.05102773277030792, 11.185181457549334, 62.78461240231991, 52.47843682765961, 39.535905718803406, 24.99797321856022, 32.251901775598526, 44.47742275893688, 52.47272193431854, 57.06674002110958, 43.21017175912857, 2.046415340155363, 0.08436484684352763, 0.05397522050770931, 0.03824788669589907, 0.015871991381573025, 0.03825403910013847, 0.06594681952265091, 0.04803701493074186, 0.023072013136697933, 0.017526162482681684, 0.019490376907924656, 0.049075966016971506, 0.09046542691066861, 0.11663575816783123, 0.18439441249938682, 0.23485230572987348, 0.0958553263626527, 0.11516133337863721, 0.1075804210267961, 0.08650597257656045, 0.11553723117685877, 0.16872111445991322, 0.20753423566929996, 11.077283397316933, 75.75101003050804, 66.34010061621666, 61.45276106894016, 66.53949111700058, 55.36889232695103, 38.118992149829865, 50.9870358556509, 53.076528534293175, 79.51008751988411, 21.93814180791378, 0.11665848272969015, 0.23153480171458796, 4.139191517606378, 10.055928602814674, 5.623380001634359, 59.54691633582115, 67.87644937634468, 66.9249576330185, 65.1354968547821, 64.55459162592888, 60.467268750071526, 59.11957606673241, 54.73088376224041, 54.76663984358311, 52.97800362110138, 58.12748350203037, 57.201579585671425, 55.77515132725239, 59.70471426844597, 56.81324802339077, 54.87149901688099, 51.209787502884865, 46.88952952623367, 45.692023783922195, 46.7171897739172, 40.33070906996727, 44.536414593458176, 43.8716896623373, 45.343381091952324, 51.211698800325394, 52.201747074723244, 52.146102860569954, 52.21364043653011, 54.19574707746506, 54.551829770207405, 54.632883220911026, 54.45224851369858, 57.36201837658882, 56.139817759394646, 53.53571489453316, 51.41297020018101, 46.46563187241554, 45.98639018833637, 44.8983945697546, 46.220659017562866, 42.122069746255875, 44.02874283492565, 44.3379208445549, 43.45894441008568, 51.011631935834885, 56.76650293171406, 58.750422075390816, 52.3359102755785, 54.76000539958477, 57.768125385046005, 55.36205269396305, 55.20509451627731, 55.450842529535294, 59.39939685165882, 56.007759645581245, 55.275557935237885, 55.31273514032364, 59.974264204502106, 57.21097268164158, 57.72929526865482, 43.57190854847431, 40.36466024816036, 62.636800333857536, 59.44369487464428, 59.10758391022682, 53.27797092497349, 54.0262533724308, 52.310550436377525, 55.175623297691345, 54.35462795197964, 53.87860469520092, 52.3460291326046, 52.535836547613144, 49.854787811636925, 47.301568016409874, 45.367084220051765, 42.74160750210285, 42.250662446022034, 45.45762576162815, 44.46361429989338, 44.915668442845345, 43.311440125107765, 44.40392330288887, 40.442996844649315, 45.2303409576416, 43.82253170013428, 47.852850034832954, 49.09336946904659, 53.338106498122215, 56.2519421428442, 57.341879457235336, 56.47216312587261, 58.06731753051281, 54.25146348774433, 56.56222589313984, 56.60767525434494, 54.88827891647816, 52.37290509045124, 45.143622010946274, 44.76509392261505, 43.572364524006844, 47.67416462302208, 46.04279816150665, 46.7868210375309, 45.22852845489979, 47.53644861280918, 53.17990578711033, 55.072728618979454, 55.32309718430042, 58.19290839135647, 59.17631462216377, 62.288982197642326, 61.44950084388256, 64.55535918474197, 61.45238108932972, 63.65204505622387, 56.962477415800095, 56.052555441856384, 63.10848422348499, 64.15467828512192, 66.8093678355217, 54.107565209269524, 4.751472612842917, 9.124232847243547, 4.6329279989004135, 0.3738543391227722, 0.25014179467689246, 14.28513016551733, 68.39605629444122, 59.808840081095695, 58.76937545835972, 37.0794553309679, 38.37917558848858, 51.23852916061878, 63.1049732118845, 65.45901149511337, 52.32623979449272, 2.997087277472019, 0.1440087694209069, 0.27154352283105254, 0.18108639313140884, 0.11024424878996797, 0.1732288155471906, 0.11617725933319889, 0.20372942264657468, 0.12247258637216873, 0.19380555750103667, 0.08686929097166285, 0.17622464307351038], [0.07822062849299982, 0.037030074308859184, 0.028864950727438554, 0.023517147747043055, 0.08776661430601962, 0.06859661327325739, 0.04491415398661047, 0.022926620840735268, 0.050850229599745944, 0.019429886306170374, 0.06905714559252374, 8.84128862991929, 58.57109449803829, 51.13190308213234, 44.845140427351, 20.86079891771078, 11.315289326012135, 17.424808591604233, 42.48215742409229, 50.26474021375179, 59.992032051086426, 9.94718223810196, 0.19218899658881128, 0.0325727464951342, 1.3140757684595883, 1.5968746435828507, 17.89906494319439, 64.71371948719025, 58.49002204835415, 64.26482677459717, 56.75048679113388, 55.3493195772171, 48.88933941721916, 46.56329423189163, 45.382408797740936, 43.49104508757591, 42.8410329669714, 42.153566256165504, 43.40084932744503, 41.817394495010376, 40.42323410511017, 41.25707656145096, 40.9252517670393, 40.8930978924036, 38.980782106518745, 40.4519909620285, 42.197746485471725, 42.84735582768917, 40.876678973436356, 40.97641222178936, 40.34981444478035, 44.16213467717171, 45.90664766728878, 48.58497954905033, 49.45710875093937, 51.48063696920872, 51.25199183821678, 52.885318994522095, 53.55844907462597, 52.5067301094532, 49.28644470870495, 46.61059409379959, 47.11003549396992, 42.41512522101402, 39.24131512641907, 39.282387122511864, 40.43042331933975, 40.449984669685364, 41.414703503251076, 38.43739226460457, 39.00391906499863, 49.58167366683483, 53.033773228526115, 51.01271867752075, 52.063396498560905, 53.87581564486027, 53.51796604692936, 54.64822679758072, 52.65046499669552, 51.151947006583214, 52.36480392515659, 49.948901161551476, 53.54979693889618, 51.53642177581787, 54.81783449649811, 51.45286425948143, 55.789229571819305, 46.83022990822792, 38.635038658976555, 53.31345722079277, 52.13469207286835, 54.67963971197605, 48.98856729269028, 48.9996512979269, 48.378019854426384, 48.223109766840935, 45.629862919449806, 47.414486557245255, 46.8581698089838, 44.93779085576534, 44.16767098009586, 40.1907853782177, 39.51970338821411, 38.44275377690792, 38.707439973950386, 41.47163964807987, 41.37080445885658, 41.15314073860645, 41.17441959679127, 40.90665936470032, 39.53362584114075, 39.999230057001114, 41.276805102825165, 45.76252140104771, 48.08406002819538, 50.78218124806881, 54.54506993293762, 53.6720135807991, 53.833649307489395, 53.46824571490288, 53.472980260849, 52.798854634165764, 51.925653889775276, 48.826863169670105, 42.12916016578674, 40.73286049067974, 42.060972824692726, 41.80768221616745, 40.68448148667812, 40.70892557501793, 41.90655671060085, 45.15534818172455, 52.21383422613144, 55.63047029078007, 55.029638931155205, 55.92781573534012, 57.4046216905117, 58.19776073098183, 58.716326504945755, 55.6551955640316, 58.09135504066944, 59.07346174120903, 59.55299220979214, 57.979306653141975, 55.27806960046291, 57.25191928446293, 58.8840115070343, 56.963738948106766, 62.0268988609314, 12.97681761905551, 0.9377491276245564, 1.6659746482037008, 0.16507743654074147, 0.027141372120240703, 2.6192771131172776, 50.77103644609451, 54.54445816576481, 43.9384900778532, 31.721072159707546, 13.682007528841496, 29.91431660950184, 48.60273219645023, 51.41455091536045, 44.40216399729252, 2.91980963665992, 0.19884647685103118, 0.037896171779721044, 0.056675484011066146, 0.07370229242951609, 0.03331868283567019, 0.05891553431865759, 0.06659758655587211, 0.03610676467360463, 0.020093208622711245, 0.019776330118475016, 0.12287805875530466, 0.12633952457690611, 0.027236975583946332, 0.04517880384810269, 0.06265966934734024, 0.0643359286186751, 0.066572071518749, 0.026383271979284473, 0.10343001209548675, 0.03726808849023655, 0.021405693078122567, 0.052150605915812775, 11.45434856414795, 67.5889340043068, 57.22520291805267, 52.414661049842834, 31.751956902444363, 25.322813987731934, 23.886101581156254, 46.79251313209534, 52.68045298755169, 67.55407467484474, 11.379079353064299, 0.21014288475271314, 0.07338908384554088, 3.824243280105293, 2.0837934594601393, 18.352895490825176, 69.15744423866272, 60.860954225063324, 68.30202654004097, 58.03644418716431, 57.527324706315994, 51.18838705122471, 50.597853139042854, 47.16069057583809, 46.448019817471504, 46.052841022610664, 44.059521183371544, 44.43582259118557, 44.33600194752216, 42.90746860206127, 42.856311947107315, 43.26129801571369, 44.559369161725044, 42.23664879798889, 43.09438817203045, 43.9276834577322, 44.78675656020641, 42.63063445687294, 43.242230638861656, 43.324937000870705, 46.60198375582695, 49.58669699728489, 50.94487711787224, 50.45601435005665, 54.241055846214294, 54.65358451008797, 55.94877541065216, 55.0191704928875, 53.21617864072323, 51.785756796598434, 50.280520766973495, 49.79680672287941, 44.231127575039864, 40.7156740128994, 41.24436244368553, 41.809855699539185, 43.048251047730446, 43.40456932783127, 40.31040295958519, 41.876158341765404, 51.041258946061134, 56.33609622716904, 54.03704859316349, 53.91378700733185, 54.699022471904755, 55.26633583009243, 55.038146674633026, 54.08530220389366, 52.44231976568699, 53.25332924723625, 52.167909890413284, 54.81532663106918, 54.15305636823177, 56.85865938663483, 53.411579355597496, 56.53888374567032, 49.56984490156174, 39.493636786937714, 56.027491986751556, 51.802555695176125, 55.84065601229668, 51.1950670927763, 52.16381751000881, 50.65864987671375, 49.03331749141216, 48.82692776620388, 49.55294720828533, 49.813506826758385, 47.69014276564121, 44.740718230605125, 41.680069863796234, 42.43746042251587, 40.84167905151844, 42.0774981379509, 42.39996023476124, 43.16525436937809, 43.280004411935806, 42.76884064078331, 43.28921511769295, 40.72631724178791, 42.24499315023422, 42.70659998059273, 47.19112314283848, 49.92117404937744, 54.53582122921944, 56.24949507415295, 55.075000897049904, 54.81417529284954, 55.4408148676157, 56.21531970798969, 54.5043209195137, 55.16960822045803, 51.037880927324295, 43.14733453094959, 41.50729313492775, 43.498637080192566, 42.89986900985241, 41.7771090567112, 42.68602788448334, 43.61692473292351, 48.31491284072399, 54.24875423312187, 57.755878642201424, 58.73643882572651, 57.89568454027176, 61.03357516229153, 60.694295167922974, 60.080947279930115, 56.90059773623943, 58.328162133693695, 59.028479754924774, 61.860786974430084, 60.52363112568855, 56.81460075080395, 58.927317783236504, 60.61240576207638, 59.15398322045803, 64.71214637160301, 14.830483552068472, 1.593953431583941, 2.294508540071547, 0.4339570499723777, 0.0764589554455597, 2.566481796093285, 53.17929022014141, 59.95134763419628, 42.26129047572613, 25.78976333141327, 18.202813044190407, 36.0849042981863, 55.71344643831253, 55.63406489789486, 52.2950092703104, 4.936953485012054, 0.30634336173534393, 0.020384464478411246, 0.01716188486170722, 0.05861808895133436, 0.021118144250067417, 0.05854816008650232, 0.12812584434868768, 0.03430961696722079, 0.019581191663746722, 0.03139545166050084, 0.09143343238974921, 0.2500078221783042, 0.1131191136664711, 0.11143739960971288, 0.15980734198819846, 0.127764091885183, 0.16624753625364974, 0.10235432841000147, 0.19613230921095237, 0.16955579310888425, 0.130337726441212, 0.22619245166424662, 16.131122410297394, 78.7154133617878, 64.03551667928696, 60.77176161110401, 32.69134059548378, 19.65356569737196, 24.411007314920425, 57.54862256348133, 60.39868623018265, 73.05938646197319, 13.895117193460464, 0.42277561558876187, 0.19279651867691427, 5.9533091727644205, 7.647193679586053, 20.012714825570583, 71.30604654550552, 63.3139505982399, 69.35783788561821, 60.697023421525955, 59.74319480359554, 54.48578171432018, 52.0458984375, 49.75835278630257, 47.32526734471321, 47.50676080584526, 46.426881551742554, 47.607599794864655, 46.0351225733757, 45.41901983320713, 45.36141112446785, 44.96741026639938, 46.72094777226448, 43.92818123102188, 45.14576509594917, 47.0340433716774, 47.15840309858322, 45.067037120461464, 45.944983810186386, 44.256871193647385, 49.713104814291, 52.52964287996292, 53.65157067775726, 54.34457369148731, 56.42871245741844, 55.96302464604378, 58.15606936812401, 58.051586374640465, 55.67869730293751, 53.891865983605385, 51.515921875834465, 52.67448350787163, 47.23407603800297, 42.56552875041962, 43.877659142017365, 44.494867622852325, 45.11967949569225, 45.20010598003864, 42.766032591462135, 43.61919701099396, 53.937220349907875, 57.54704184830189, 56.50849677622318, 54.0501768887043, 58.20697523653507, 56.809315234422684, 57.752690613269806, 55.831274315714836, 52.97244071960449, 55.098096057772636, 54.10061538219452, 57.247329130768776, 54.788728058338165, 59.40518394112587, 55.65959952771664, 59.58907887339592, 51.57718598842621, 43.68995301425457, 60.28522431850433, 54.56339254975319, 60.44371381402016, 52.1756424754858, 54.524311646819115, 53.054987490177155, 52.30993866920471, 50.68567022681236, 52.21589371562004, 51.991200372576714, 50.43636940419674, 46.53466276824474, 43.02125349640846, 45.17381899058819, 42.616643607616425, 43.84474530816078, 45.08092537522316, 45.92543385922909, 46.13273933529854, 44.38112832605839, 43.911883905529976, 42.79871843755245, 44.932866320014, 44.53570403158665, 51.38742037117481, 51.993035674095154, 57.173898071050644, 58.41998800635338, 57.785832434892654, 58.563798889517784, 58.038423880934715, 58.3895668387413, 56.33679538965225, 57.083052545785904, 54.208514392375946, 45.451713278889656, 45.02567633986473, 46.16757586598396, 46.24004177749157, 45.125709772109985, 46.24799095094204, 46.538884341716766, 50.44728621840477, 56.278126537799835, 60.1210693269968, 60.520674884319305, 59.916723892092705, 63.40199567377567, 62.6316212117672, 62.972679510712624, 58.38091850280762, 60.29672250151634, 61.9474071264267, 64.41373318433762, 62.266650795936584, 60.79395242035389, 62.154032438993454, 62.21673287451267, 62.58086733520031, 68.59410166740417, 16.450430676341057, 3.1896200962364674, 7.019196152687073, 0.8725516917183995, 0.20816948439460248, 3.9208564208820462, 59.62592929601669, 65.9519362449646, 60.896824300289154, 40.36304913461208, 23.452162966132164, 42.68749840557575, 63.773216754198074, 63.40172588825226, 63.801601231098175, 7.671194616705179, 0.40556681400630623, 0.1581907959189266, 0.19129175489069894, 0.17624140076804906, 0.12734957272186875, 0.13894585281377658, 0.20411168807186186, 0.08811819934635423, 0.07966530800331384, 0.18731617368757725, 0.297409002087079], [0.07374630178674124, 0.008305082428705646, 0.0908920876099728, 0.009010542962641921, 0.058870289285550825, 0.02129749165760586, 0.03992165977251716, 0.07922531833173707, 0.059072309304610826, 0.12362227702396922, 0.04106253742065746, 15.306901037693024, 59.848764538764954, 52.19846785068512, 36.61595240235329, 14.557549897581339, 19.829558953642845, 27.397077083587646, 43.203221932053566, 51.595569401979446, 57.62428790330887, 4.507706668227911, 0.23755594971589744, 0.07082574287778698, 0.20459752762690187, 1.4221773552708328, 37.18991160392761, 67.36061945557594, 60.776515156030655, 61.8203267455101, 55.69122903048992, 52.735930010676384, 47.90337212383747, 47.775083407759666, 42.39545367658138, 44.04390402138233, 41.29843354225159, 42.9673457890749, 40.82516513764858, 42.01732836663723, 41.55734784901142, 43.53794977068901, 40.715860202908516, 41.91784970462322, 40.264813005924225, 41.11637771129608, 41.594069078564644, 42.90538631379604, 40.01196697354317, 41.34952940046787, 38.67450334131718, 42.14432515203953, 46.87598705291748, 46.8104899674654, 49.82247814536095, 49.06574495136738, 51.97630517184734, 52.26173825562, 50.74251897633076, 52.06397786736488, 49.260191917419434, 51.2331410497427, 44.574427753686905, 41.96009963750839, 39.410672038793564, 41.173576042056084, 41.0920400172472, 41.11636631190777, 41.49874359369278, 39.393831342458725, 39.614094123244286, 49.152334704995155, 52.30286344885826, 51.61299146711826, 52.72764265537262, 53.2699191570282, 50.79388082027435, 53.67241255939007, 54.92471136152744, 54.35378819704056, 53.447388634085655, 52.420174553990364, 54.46467004716396, 52.42378056049347, 52.31247313320637, 48.491846546530724, 53.6191850155592, 47.06314980983734, 37.51079298555851, 54.61309768259525, 50.85375040769577, 52.790658473968506, 48.345451802015305, 48.675502091646194, 46.51239596307278, 47.50558666884899, 46.443270072340965, 44.34370793402195, 43.53664644062519, 44.36154417693615, 42.988016679883, 41.14049881696701, 40.12619264423847, 39.54755589365959, 38.715685531497, 40.84153465926647, 41.08665190637112, 42.10608020424843, 40.409304052591324, 42.1088008582592, 40.8106043189764, 40.35953052341938, 41.61451578140259, 46.16372287273407, 48.299033492803574, 51.66426971554756, 52.291323468089104, 51.44304558634758, 53.627749755978584, 53.46546046435833, 51.87133580446243, 50.900446102023125, 46.31025820970535, 42.07486867904663, 40.29038183391094, 43.002934679389, 40.75673080980778, 40.91174729168415, 41.77357144653797, 41.00166566669941, 46.55835069715977, 52.16409869492054, 54.273977279663086, 55.71043699979782, 53.97877871990204, 54.857732355594635, 53.516434729099274, 52.76043489575386, 54.50748614966869, 54.10969689488411, 55.32543785870075, 53.81338119506836, 59.883726462721825, 56.82592794299126, 58.96018221974373, 56.02952487766743, 58.50652456283569, 59.68874752521515, 64.21773210167885, 21.588038094341755, 0.728655788116157, 0.8324222825467587, 0.07458313266397454, 0.1272429112577811, 1.0707882419228554, 41.95248864591122, 59.1270312666893, 38.9731977134943, 34.8920077085495, 18.946106359362602, 29.142004251480103, 43.05793672800064, 48.476901948451996, 51.98010876774788, 10.775395296514034, 0.32037306984420866, 0.1494981092400849, 0.044736064519383945, 0.020583040932251606, 0.03675539803225547, 0.05818713492772076, 0.05218773556407541, 0.02127682470018044, 0.057377774646738544, 0.07050975866150111, 0.07214275814476423, 0.013204503902670695, 0.03065616125240922, 0.073243340884801, 0.06367247086018324, 0.05265690648229793, 0.01663779501541285, 0.048046154479379766, 0.07816634039045312, 0.1318250349140726, 0.06632210875977762, 0.06307472285698168, 22.215741612017155, 68.69031250476837, 59.992176443338394, 44.390225037932396, 18.347429484128952, 21.091330647468567, 24.152360893785954, 48.91518943011761, 55.03080926835537, 65.16574323177338, 5.674493433907628, 0.2368705318076536, 0.19333255710080266, 3.0376873863860965, 1.0517902113497257, 40.799330323934555, 69.62292686104774, 61.37073487043381, 61.38923227787018, 57.374352514743805, 55.322618409991264, 50.375405475497246, 48.19977901875973, 45.46957612037659, 46.12800478935242, 43.52021612226963, 45.422120466828346, 44.068363308906555, 43.76182235777378, 43.13221134245396, 43.681126087903976, 43.46582964062691, 43.743218556046486, 42.93411277234554, 44.52086962759495, 46.09833598136902, 44.107147827744484, 42.299353033304214, 42.34056182205677, 40.7531476020813, 44.06364396214485, 47.962534949183464, 48.92048254609108, 51.37048847973347, 50.057275146245956, 54.338478818535805, 53.528913259506226, 54.233965426683426, 53.63309606909752, 51.74779683351517, 52.30381719768047, 45.20054295659065, 44.43934880197048, 40.08262798190117, 42.809224873781204, 41.63534626364708, 41.82671159505844, 42.6148197054863, 41.826327815651894, 42.027390226721764, 49.61177945137024, 54.70614328980446, 53.18012237548828, 54.941897839307785, 56.03286489844322, 54.36280891299248, 54.49629954993725, 55.733912140131, 55.19434489309788, 56.269850581884384, 54.04746763408184, 56.728280782699585, 55.48373356461525, 53.78413796424866, 49.88039083778858, 54.82387617230415, 48.97397227585316, 39.729866310954094, 55.46480678021908, 52.27984808385372, 55.430031046271324, 50.22714503109455, 51.269094720482826, 49.46882352232933, 50.11906363070011, 49.252193346619606, 47.67365925014019, 44.45307366549969, 46.77285298705101, 45.398751720786095, 42.55737438797951, 41.49913117289543, 41.750343292951584, 42.16738611459732, 41.94099806249142, 43.807058930397034, 43.5307377576828, 42.68452316522598, 43.064156994223595, 41.382485032081604, 42.210673391819, 42.09987513720989, 46.87897749245167, 50.1644179970026, 54.08494122326374, 52.40764282643795, 54.49646674096584, 55.74318744242191, 55.73260121047497, 54.67914953827858, 54.43356491625309, 49.880428835749626, 44.40725192427635, 42.39899508655071, 45.54208002984524, 43.494768887758255, 42.25753627717495, 43.77774730324745, 43.45561198890209, 49.31177794933319, 55.663893297314644, 55.64079433679581, 58.53604897856712, 55.200131982564926, 56.431520506739616, 55.111874118447304, 54.99654270708561, 54.26913633942604, 54.27046246826649, 57.04633891582489, 56.12095557153225, 61.65272533893585, 60.22510774433613, 62.75041803717613, 59.64718155562878, 60.61471603810787, 61.51314742863178, 65.84844499826431, 24.783961102366447, 0.8637858589645475, 3.1822297303006053, 1.201640039216727, 0.24100920738419518, 1.133317449130118, 45.26823632419109, 63.300913497805595, 43.65843750536442, 33.96333374083042, 21.440727598965168, 33.945379704236984, 51.535859405994415, 53.76986972987652, 61.86500854790211, 15.954065211117268, 0.473481371300295, 0.08374592536711134, 0.04295817925594747, 0.055923911058926024, 0.07264249812578782, 0.06487525475677103, 0.024200205625675153, 0.012804363850591471, 0.02709357038838789, 0.03457499042269774, 0.06411266833310947, 0.11881592829013243, 0.0911228361655958, 0.2746577822836116, 0.178670568857342, 0.13888389832573012, 0.11780311935581267, 0.21553443919401616, 0.15631573012797162, 0.24299157288623974, 0.20222841412760317, 0.13343844912014902, 28.274584896862507, 79.79001849889755, 64.14919897913933, 52.690507248044014, 24.240687154233456, 30.882538855075836, 35.96237987279892, 58.39500434696674, 60.76562114059925, 72.78411403298378, 6.064132126048207, 0.3901499428320676, 0.3611805645050481, 9.18352011591196, 3.1907918583601713, 41.18320092558861, 73.59475493431091, 64.99655351042747, 65.80018758773804, 59.85330909490585, 57.882681638002396, 52.37420082092285, 52.849046140909195, 47.58387006819248, 47.868474796414375, 45.47597877681255, 47.417222410440445, 45.811002999544144, 46.71218544244766, 44.48039039969444, 46.90778374671936, 45.726719722151756, 45.585287511348724, 45.09829044342041, 46.82391844689846, 48.16823311150074, 46.2001933157444, 44.85420674085617, 43.691218346357346, 43.25092077255249, 45.95175884664059, 50.07064662873745, 52.708560079336166, 54.96786564588547, 51.29467114806175, 55.93906693160534, 56.23541682958603, 54.50818911194801, 55.30722163617611, 52.53671810030937, 55.83485372364521, 47.42809362709522, 47.227950766682625, 42.777120396494865, 43.25524114072323, 43.94279144704342, 43.631398156285286, 44.4972462952137, 44.07926492393017, 43.899507969617844, 53.5898581892252, 58.511224910616875, 53.698076382279396, 57.49025009572506, 59.87439416348934, 55.80700881779194, 56.901361495256424, 58.43301750719547, 58.86049076914787, 57.366695925593376, 56.66339546442032, 59.15955752134323, 57.163976803421974, 56.36972442269325, 52.521207332611084, 58.11497837305069, 52.32171803712845, 42.897790521383286, 56.8169604241848, 54.46747049689293, 58.94864983856678, 52.586936205625534, 53.375982865691185, 51.504473090171814, 52.14164189994335, 52.5805601477623, 49.64355334639549, 46.89521782100201, 49.09698307514191, 49.81605648994446, 44.24560099840164, 42.894222512841225, 43.22311766445637, 42.84157633781433, 44.51823636889458, 43.945181518793106, 45.96358761191368, 44.55236993730068, 46.42301715910435, 43.218166530132294, 44.78967860341072, 45.13645559549332, 49.62290145456791, 53.52672077715397, 55.093901082873344, 55.45348338782787, 56.156316474080086, 56.320847645401955, 58.14788080751896, 57.43283897638321, 56.64611779153347, 51.78509563207626, 47.407437935471535, 44.57244426012039, 49.3158171325922, 44.700706377625465, 45.27623489499092, 46.14331416785717, 47.29776442050934, 52.28021666407585, 58.14435839653015, 57.8649365901947, 61.0159707069397, 57.160272002220154, 59.17982183396816, 55.927796736359596, 58.02568316459656, 55.42714320123196, 56.38824462890625, 56.79859980940819, 57.8228310495615, 62.40962952375412, 61.77052281796932, 64.54088196158409, 62.88327410817146, 63.503955602645874, 65.45306101441383, 68.35759475827217, 26.203194446861744, 2.0302890054881573, 6.480621602386236, 1.9634332554414868, 0.3854109736857936, 1.7184812994673848, 48.86825054883957, 71.45068198442459, 54.72541205585003, 43.43923106789589, 30.44547490775585, 41.211205422878265, 61.18743650615215, 63.640543073415756, 72.43393242359161, 20.636614747345448, 0.5821713921613991, 0.2151378503185697, 0.179610246559605, 0.12807508144760504, 0.2795509103452787, 0.22941886447370052, 0.21668576257070526, 0.15742353396490216, 0.20517681841738522, 0.20359779533464462, 0.2109960577217862], [0.030096563350525685, 0.05008475993236061, 0.04526436605374329, 0.03345126380736474, 0.014912070673744893, 0.018678343039937317, 0.04081176572071854, 0.017798870212573092, 0.01879715346149169, 0.049347595777362585, 0.08765957434661686, 26.359827741980553, 59.27584648132324, 49.86536644399166, 39.78448458015919, 20.728822499513626, 43.71711775660515, 43.69539812207222, 35.913180112838745, 57.00977347791195, 48.14922273159027, 4.383342191576958, 0.4049280029721558, 0.2562990377191454, 1.8869595089927316, 5.590116586536169, 54.06688079237938, 64.12441670894623, 61.3316235691309, 59.29200321435928, 57.90582239627838, 53.401407301425934, 48.999077528715134, 45.65704666078091, 44.28917706012726, 41.546324640512466, 41.75419628620148, 41.4360773563385, 40.34488990902901, 39.53737623989582, 40.52908882498741, 40.143363922834396, 41.47232361137867, 40.00165052711964, 39.39310938119888, 40.51293209195137, 39.704012498259544, 40.99937058985233, 40.48118099570274, 40.67836381494999, 41.72201581299305, 39.92068827152252, 42.58747257292271, 45.52274666726589, 47.21256919205189, 50.27166344225407, 51.448657885193825, 53.22901055216789, 49.82577256858349, 51.05461522936821, 51.0289666056633, 47.34410673379898, 41.62544399499893, 41.22734695672989, 39.25038903951645, 40.25035098195076, 39.847021624445915, 42.135703414678574, 40.83692170679569, 40.65853267908096, 37.69322119653225, 49.19787146151066, 50.75180567800999, 49.875017926096916, 53.53960208594799, 49.64408151805401, 50.46826869249344, 49.82100762426853, 50.372061654925346, 50.80106623470783, 53.20650056004524, 53.78752738237381, 50.942764431238174, 46.57661631703377, 46.089406460523605, 50.22131234407425, 53.776667565107346, 48.95225644111633, 34.76857513189316, 52.516184002161026, 54.484238997101784, 53.71581383049488, 50.86245574057102, 51.65424585342407, 48.92560087144375, 49.22995314002037, 47.7613091468811, 45.48280321061611, 45.672078654170036, 43.135270178318024, 40.80632574856281, 40.53562827408314, 39.1808869689703, 40.90308755636215, 38.41386392712593, 40.10175995528698, 42.03420326113701, 42.90710762143135, 41.37127563357353, 41.08108900487423, 40.66693402826786, 41.764064356684685, 41.39289267361164, 43.181319907307625, 49.42982621490955, 53.731005415320396, 51.250034943223, 54.33927297592163, 52.17750817537308, 50.24022772908211, 46.190671026706696, 40.64210616052151, 41.38637222349644, 41.61450818181038, 40.99412687122822, 41.235687509179115, 41.53913922607899, 42.4102196842432, 41.56943500041962, 45.84385983645916, 49.42381873726845, 52.08124794065952, 55.186274126172066, 53.68563584983349, 48.91627997159958, 50.680973678827286, 53.536493852734566, 55.17380699515343, 56.49293281137943, 58.59673172235489, 58.85794870555401, 59.67609040439129, 56.873425394296646, 58.35177406668663, 58.08245971798897, 64.28335458040237, 68.21328610181808, 57.5293044000864, 65.9754265844822, 27.71822825074196, 0.7627076015342027, 1.5808887826278806, 0.4121423017932102, 0.09726649790536612, 0.09670533036114648, 27.80223224312067, 65.29311999678612, 43.036460280418396, 40.1670328527689, 28.00765112042427, 30.28559658676386, 49.34313006699085, 53.160823211073875, 58.510153368115425, 19.969676434993744, 0.2801038103643805, 0.040631809752085246, 0.006498450538856559, 0.017001219166559167, 0.040721375844441354, 0.030224574547901284, 0.05631803971482441, 0.0026366857991888537, 0.022617755676037632, 0.07209895658888854, 0.059173534536967054, 0.020217104611219838, 0.05607949860859662, 0.046525467914761975, 0.03187255984812509, 0.010771970173664158, 0.0032354192353523104, 0.032372559580835514, 0.04999743512598798, 0.014096747236180818, 0.0709761019970756, 0.19184443226549774, 35.0959237664938, 65.67831292748451, 56.59119173884392, 42.913354486227036, 26.502717174589634, 37.599157243967056, 38.43779504299164, 44.864998161792755, 60.754229351878166, 55.86559787392616, 4.5843409560620785, 0.38828204618766904, 0.4403407667996362, 2.16616733931005, 5.741870943456888, 59.22439344227314, 65.95623761415482, 63.68444211781025, 61.166951805353165, 59.21984888613224, 54.086221754550934, 52.20879949629307, 47.8215891122818, 45.569552555680275, 43.339858800172806, 44.27708990871906, 44.29155573248863, 42.870272397994995, 42.31767185032368, 43.25268007814884, 42.26442530751228, 43.061611130833626, 42.63769447803497, 41.91861726343632, 42.71389938890934, 42.890054136514664, 42.2618642449379, 42.354381680488586, 42.412305772304535, 42.468550354242325, 42.56569594144821, 45.072379633784294, 48.15349370241165, 49.92214299738407, 51.24831363558769, 54.40934121608734, 53.0631722509861, 51.96335166692734, 54.47519548237324, 53.79091680049896, 49.307066202163696, 44.59058828651905, 42.80336178839207, 41.49501219391823, 41.59958638250828, 42.99807474017143, 44.13627326488495, 41.56766429543495, 41.78035408258438, 40.23602195084095, 49.32031989097595, 51.169475466012955, 52.875602915883064, 53.58615718781948, 51.27161018550396, 52.96101853251457, 52.85641014575958, 51.821927055716515, 52.06508360803127, 54.64718945324421, 55.730746909976006, 54.80437561869621, 49.611646458506584, 48.66897404193878, 50.68941682577133, 56.20012432336807, 50.97224324941635, 36.56281225383282, 54.98993866145611, 56.097062453627586, 54.26976330578327, 51.42498515546322, 53.96324895322323, 52.24951431155205, 52.706473991274834, 51.5084932744503, 48.94795887172222, 47.19069376587868, 45.75274832546711, 41.71602353453636, 41.266712844371796, 40.22017680108547, 41.67430557310581, 42.151586562395096, 42.00217477977276, 43.43510828912258, 44.391364976763725, 42.95992098748684, 42.786312103271484, 41.079439893364906, 42.329504415392876, 44.23881836235523, 46.49905867874622, 51.87217175960541, 55.40678009390831, 54.09268140792847, 56.18530131876469, 56.15704603493214, 52.58830413222313, 47.84078948199749, 43.42520222067833, 43.99577580392361, 43.81430134177208, 42.60975457727909, 42.70249620079994, 43.254226595163345, 44.992382526397705, 43.24924126267433, 47.20671370625496, 51.8328058719635, 54.175429567694664, 57.29807160794735, 54.66185286641121, 49.31100659072399, 50.59229023754597, 54.04585652053356, 57.093840166926384, 57.77114622294903, 59.61985342204571, 60.38008622825146, 61.29675284028053, 58.76632422208786, 59.871996492147446, 60.90865306556225, 63.70818704366684, 70.18407315015793, 62.59335346519947, 65.89835152029991, 30.286046862602234, 1.642688785213977, 2.8244663402438164, 1.1024536052718759, 0.09827584101003595, 0.021530236590479035, 31.38576865196228, 69.70724433660507, 52.03683592379093, 39.518916830420494, 30.54188523441553, 37.72145748138428, 57.369549572467804, 59.057741984725, 66.52195885777473, 25.536653213202953, 0.508001153357327, 0.046149900372256525, 0.03479618011624552, 0.015513586931774626, 0.056366728313150816, 0.01822504294977989, 0.0541869812150253, 0.04754916786623653, 0.008515009103575721, 0.09460539382416755, 0.11995988214039244, 0.0833076129492838, 0.17116186005296186, 0.18122412089724094, 0.09708700948976912, 0.18528203596360981, 0.13406562327872962, 0.15499703760724515, 0.11073338348069228, 0.2250159694813192, 0.1244882149330806, 0.49159749294631183, 45.00947020947933, 77.74140402674675, 63.60628791153431, 50.84491588175297, 29.655719585716724, 55.035623610019684, 53.54813262820244, 49.85456362366676, 67.2496198117733, 62.11687423288822, 6.110164280980825, 0.5887212906964123, 0.8341273223049939, 7.848248966038227, 7.064003348350525, 60.42884141206741, 68.10455113649368, 67.08456426858902, 62.52374120056629, 63.54306310415268, 58.48797395825386, 54.88997742533684, 50.32660849392414, 48.21552537381649, 45.503926277160645, 46.686726808547974, 47.16376841068268, 44.85168367624283, 44.19906869530678, 45.63590079545975, 42.15951293706894, 45.92995561659336, 44.315190464258194, 41.912184208631516, 44.1887104511261, 44.86815959215164, 45.385923609137535, 43.976780623197556, 45.21383464336395, 46.287698820233345, 44.96959134936333, 46.24678261578083, 50.453191101551056, 52.03047886490822, 52.32909344136715, 57.1300408244133, 56.50937832891941, 54.46563519537449, 56.31362423300743, 57.29748263955116, 50.29899537563324, 47.05975279211998, 44.807655438780785, 43.49007993936539, 44.5787101238966, 45.28601936995983, 48.04015338420868, 43.4677105396986, 44.76946748793125, 41.76436074078083, 52.75150537490845, 53.37739638984203, 56.301407888531685, 54.46506142616272, 54.05646935105324, 56.120659187436104, 56.18449196219444, 54.310755506157875, 55.94132401049137, 54.26007002592087, 58.18571537733078, 55.69829665124416, 50.38236290216446, 49.23776172101498, 54.71193037927151, 58.60482908785343, 54.2080470174551, 41.53730392456055, 54.89211291074753, 58.98567885160446, 57.109704315662384, 53.897782266139984, 58.21465462446213, 53.80026429891586, 55.31953677535057, 53.973595798015594, 50.073542073369026, 50.90516924858093, 47.96148620545864, 44.65152181684971, 44.059771969914436, 42.45582103729248, 45.360464975237846, 43.23414847254753, 44.63214285671711, 45.63231758773327, 46.513216719031334, 44.72451210021973, 44.19673562049866, 44.21177141368389, 45.18824681639671, 45.72697430849075, 48.09193700551987, 54.89175572991371, 56.28647468984127, 56.34673945605755, 57.85561949014664, 57.647162675857544, 55.31377628445625, 50.367437303066254, 44.0443029999733, 45.478501841425896, 45.91655373573303, 44.121811240911484, 45.19072808325291, 46.21289603412151, 47.36614175140858, 45.03220818936825, 50.19199311733246, 53.37699741125107, 56.709080412983894, 58.53351831436157, 56.618200689554214, 50.50320781767368, 51.21000409126282, 55.290658324956894, 58.18489462137222, 59.480032324790955, 63.21089252829552, 61.97893783450127, 63.1373892724514, 59.93449553847313, 62.16155603528023, 62.308524549007416, 66.76250115036964, 69.05496373772621, 64.49195578694344, 67.9542464017868, 33.28280545771122, 2.215497954748571, 5.126354796811938, 1.581869248766452, 0.15707781189121306, 0.2500910614617169, 34.836162105202675, 75.73473930358887, 59.18941631913185, 54.954554960131645, 39.90390457212925, 43.03413860499859, 64.05531361699104, 67.14835524559021, 75.27083739638329, 33.0006667971611, 0.7988992345053703, 0.12887902033980936, 0.10205513899563812, 0.09083544689929113, 0.21827658580150455, 0.11561840728973038, 0.1330933059216477, 0.12787217827280983, 0.12948640884133056, 0.16405190719524398, 0.13748705765465274], [0.042152540845563635, 0.025043626774277072, 0.04844417198910378, 0.01380021656586905, 0.02404101123829605, 0.01521684103863663, 0.054199382502702065, 0.08598350061220117, 0.024171907534764614, 0.054579770294367336, 0.41752619727049023, 32.1201628446579, 57.94301860034466, 49.013132974505424, 34.21073466539383, 12.210957314819098, 47.15204983949661, 50.77814966440201, 36.905132085084915, 63.417673632502556, 36.39307156205177, 2.462038700468838, 0.3780958318384364, 0.6570440588984638, 1.4188145357184112, 11.265237461775541, 67.93749690055847, 62.14876972138882, 64.6014355123043, 57.04400584101677, 54.58787463605404, 53.4301033616066, 49.83708456158638, 45.95740534365177, 42.824842035770416, 42.62927033007145, 43.961490243673325, 43.95370826125145, 46.27609804272652, 47.227650582790375, 48.331293761730194, 45.01428835093975, 46.40580028295517, 42.25007347762585, 40.198913142085075, 39.85221594572067, 41.74314267933369, 40.216080620884895, 40.176471546292305, 38.67210566997528, 41.009687036275864, 38.77557031810284, 41.2353341281414, 41.70698381960392, 45.63931681215763, 48.65056782960892, 52.05979809165001, 53.22214812040329, 52.51895025372505, 51.43601596355438, 50.10112479329109, 40.76648488640785, 39.89237979054451, 39.4080463796854, 39.765265211462975, 38.73611323535442, 40.728293135762215, 42.072763592004776, 39.46224667131901, 40.12150749564171, 39.25604313611984, 43.652072846889496, 53.12329642474651, 47.87213400006294, 51.43657073378563, 54.94018413126469, 50.124459341168404, 48.64694282412529, 50.40387734770775, 48.311922401189804, 48.12054947018623, 47.32338264584541, 46.02333940565586, 41.93959213793278, 47.068898901343346, 51.15809507668018, 53.46364416182041, 52.16884844005108, 32.00512021780014, 48.301195576786995, 50.3962055593729, 53.777336329221725, 50.21574184298515, 51.41794413328171, 50.71756191551685, 52.44820944964886, 50.19105836749077, 50.36692813038826, 45.75552597641945, 45.36764658987522, 42.648227512836456, 39.82686750590801, 37.97634020447731, 38.87462340295315, 39.466806426644325, 40.310843735933304, 42.358306869864464, 41.01316764950752, 44.21924561262131, 39.36546206474304, 40.03835655748844, 41.71154737472534, 41.969842314720154, 40.816463604569435, 46.28530874848366, 53.09623807668686, 50.98175793886185, 52.38966219127178, 55.07560886442661, 49.80154126882553, 42.313587069511414, 42.1596497297287, 41.382872611284256, 42.16415248811245, 41.19336538016796, 40.80347590148449, 43.578470796346664, 42.95696094632149, 44.80763643980026, 47.55521580576897, 51.37181840837002, 54.70881834626198, 55.80799296498299, 52.01340638101101, 54.55391965806484, 57.26344406604767, 56.77347555756569, 59.03823763132095, 56.27305381000042, 56.53742842376232, 57.64221154153347, 56.10199838876724, 58.917157128453255, 58.712948486208916, 63.42300474643707, 57.71858364343643, 54.50180925428867, 57.08010010421276, 62.5581331551075, 30.409126058220863, 1.5339946676976979, 1.4508468168787658, 0.49017197568900883, 0.18540104676503688, 0.054009448358556256, 17.699385657906532, 63.754711747169495, 48.72801527380943, 46.57485321164131, 26.48979026824236, 16.896312050521374, 39.4127581268549, 46.194014847278595, 58.799925819039345, 30.495178140699863, 0.6321581255178899, 0.06529718055389822, 0.00837404000776587, 0.0658941493020393, 0.015422695178131107, 0.08601594730862416, 0.023632445954717696, 0.02064133106614463, 0.04122664853639435, 0.008818366604828043, 0.08131805603625253, 0.03987874137237668, 0.0414584249665495, 0.01323735970800044, 0.022161596461955924, 0.02372078935877653, 0.08286617608973756, 0.06260434223804623, 0.19072555558523163, 0.04706479034211952, 0.05106031305331271, 0.7954385108314455, 42.328603863716125, 66.3820731639862, 51.54604285955429, 40.49853466451168, 13.175372164696455, 39.06279690563679, 52.76168502867222, 40.89109160006046, 68.16722497344017, 43.139465153217316, 2.969250208698213, 0.4404984583379701, 0.6951586261857301, 1.6898943646810949, 13.75060809776187, 70.46920984983444, 63.689986020326614, 66.4049631357193, 58.27350206673145, 57.43000812828541, 56.580058336257935, 51.441179886460304, 47.54655987024307, 43.56128431856632, 44.736044481396675, 45.32101169228554, 46.04519963264465, 45.93320444226265, 48.46393704414368, 49.522104263305664, 48.22516165673733, 47.53740236163139, 45.161424055695534, 42.304919734597206, 41.117494851350784, 43.10455642640591, 41.37149602174759, 41.83865815401077, 41.10077954828739, 41.257939115166664, 42.27501533925533, 43.31690423190594, 44.360556229949, 48.70599165558815, 49.75015662610531, 52.94828161597252, 54.12256680428982, 54.8414958268404, 53.07705670595169, 50.27339234948158, 43.739855736494064, 40.64193516969681, 43.32435943186283, 41.21490262448788, 42.07306757569313, 43.6868903785944, 43.64190459251404, 41.352554038167, 41.204586178064346, 40.02373494207859, 45.1086562871933, 55.369181111454964, 51.31571061909199, 54.63267043232918, 56.99616640806198, 53.03265608847141, 50.764641389250755, 51.96788102388382, 51.3915241509676, 49.731450229883194, 49.45655018091202, 48.67318041622639, 43.32472421228886, 47.93088264763355, 53.79238732159138, 55.52863955497742, 55.06021969020367, 33.93600940704346, 48.40304151177406, 52.55285203456879, 56.644172295928, 52.379630729556084, 53.55532564222813, 53.52509826421738, 53.13527338206768, 52.17863291501999, 50.9278654307127, 46.9984544813633, 46.48020789027214, 43.191533759236336, 42.31900937855244, 40.63184291124344, 40.88217727839947, 40.97219064831734, 42.03852362930775, 42.12114259600639, 43.48480962216854, 45.02506457269192, 42.09729887545109, 41.91140905022621, 42.45305858552456, 42.991550490260124, 41.506996750831604, 48.430920615792274, 55.87285168468952, 53.489004001021385, 55.179936066269875, 55.97835302352905, 52.9955168813467, 45.80115392804146, 43.01874183118343, 42.865154072642326, 43.65589924156666, 43.00469398498535, 43.033792823553085, 45.12988954782486, 46.05366937816143, 46.10438145697117, 49.175574257969856, 52.474678829312325, 56.541881784796715, 57.119420394301414, 52.49077096581459, 54.827280789613724, 57.19899572432041, 58.60041372478008, 59.384779036045074, 57.71742470562458, 58.20444457232952, 59.5510733127594, 58.95070552825928, 59.43783558905125, 59.72428321838379, 61.41217924654484, 58.45984406769276, 56.69105798006058, 59.71514850854874, 62.63971857726574, 33.20416867733002, 2.7352910628542304, 4.142359597608447, 3.8439753837883472, 0.5768526275642216, 0.07354955101618543, 17.294595278799534, 67.75937765836716, 54.55241493880749, 45.11880934238434, 33.21649521589279, 25.42770355939865, 45.10105289518833, 52.4388125538826, 65.16983941197395, 40.14109164476395, 1.1336686927825212, 0.01849894739279989, 0.07036179667920806, 0.04112483329663519, 0.019989230022474658, 0.0673515121161472, 0.039655714863329194, 0.036083899103687145, 0.04085298831341788, 0.07831410941435024, 0.11217678649700247, 0.14704032393638045, 0.1552711721160449, 0.11509600954013877, 0.100296738819452, 0.11938666211790405, 0.23156561568612233, 0.1888586237328127, 0.25531907624099404, 0.1808061878546141, 0.14420686347875744, 1.6131383646279573, 52.90200009942055, 73.73834922909737, 61.272460743784904, 47.57474675774574, 19.875580184161663, 58.259465619921684, 61.98804594576359, 49.56196412444115, 73.30359175801277, 47.718261256814, 3.791439877822995, 0.7153417181689292, 1.9276826363056898, 6.502444306388497, 13.75627264380455, 73.79229873418808, 63.19317787885666, 71.1289532482624, 60.93335933983326, 60.56260943412781, 58.33454579114914, 53.96450288593769, 50.85971228778362, 46.76895059645176, 46.37976408004761, 48.69535602629185, 48.3637136220932, 48.67566168308258, 50.948004350066185, 54.78819988667965, 49.80900026857853, 50.18755875527859, 44.98245365917683, 44.633905962109566, 43.431266695261, 46.72641567885876, 42.45759554207325, 45.6050768494606, 43.071935176849365, 43.755446299910545, 44.447807148098946, 44.799679666757584, 46.12729802727699, 49.220062270760536, 52.710779160261154, 55.54666578769684, 56.543793082237244, 57.90078766644001, 56.02644324302673, 53.86162720620632, 44.896931648254395, 42.78438560664654, 44.047225043177605, 44.26592230796814, 43.42212438583374, 47.30983257293701, 46.00953854620457, 42.80826352536678, 42.805083096027374, 43.189398273825645, 48.243613466620445, 57.52403028309345, 53.624603524804115, 56.65295362472534, 57.62559123337269, 56.02474093437195, 53.779137432575226, 55.233144611120224, 53.73841121792793, 50.92624291777611, 52.24602609872818, 51.329952254891396, 45.94290152192116, 50.724861323833466, 55.342411547899246, 58.637674525380135, 56.380721032619476, 37.15341456234455, 48.700918927788734, 54.167241007089615, 60.143476724624634, 54.3351311981678, 54.6573007106781, 54.54407438635826, 57.095512077212334, 53.55685696005821, 55.16141206026077, 48.730530738830566, 49.31203253567219, 46.66774682700634, 44.056481346488, 43.67306292057037, 42.42620162665844, 43.98965813219547, 43.83101284503937, 46.0519290715456, 45.25184780359268, 48.69986638426781, 43.554110303521156, 43.38368184864521, 44.147725850343704, 45.832604840397835, 43.33032511174679, 51.150807067751884, 58.6771772056818, 55.002816170454025, 56.72943972051144, 59.5623093098402, 53.55191722512245, 46.42497405409813, 45.597336664795876, 45.29527947306633, 46.31460137665272, 45.69473683834076, 45.656024515628815, 48.79669278860092, 48.12536001205444, 49.82203356921673, 51.91061809659004, 54.92481015622616, 59.339021891355515, 58.41501407325268, 54.57325682044029, 56.06760263442993, 59.02470275759697, 62.34347507357597, 63.779083639383316, 60.008074790239334, 61.55049942433834, 61.99015103280544, 61.815827786922455, 63.04610297083855, 62.31189876794815, 60.86190417408943, 59.69529077410698, 60.54275169968605, 60.34711919724941, 65.88280275464058, 34.854503720998764, 3.3938978472724557, 7.461640611290932, 4.711079830303788, 0.6741390447132289, 0.24828474823152646, 21.115966625511646, 73.42936500906944, 60.00638388097286, 59.353084936738014, 37.18133166432381, 28.847322463989258, 53.767354264855385, 62.453452572226524, 73.34367960691452, 49.003504291176796, 1.7912913300096989, 0.16084324655821547, 0.08955945013440214, 0.1658067005337216, 0.10888202930800617, 0.19712589652044699, 0.25202177348546684, 0.12096859441953711, 0.08156162890372798, 0.17186795419547707, 0.2017722901655361], [0.04699411190813407, 0.05638688504404854, 0.02051682837191038, 0.05141910063684918, 0.0009277712183575204, 0.024457530489598867, 0.06287055803113617, 0.029929789779998828, 0.04629219605703838, 0.05082992815005127, 0.59542644652538, 41.68956935405731, 60.25897152721882, 48.70787635445595, 33.911713510751724, 28.418380580842495, 55.97271792590618, 50.37610083818436, 42.464115992188454, 58.20834316313267, 39.0105877071619, 0.8800109883304685, 0.043980984919471666, 0.42886324517894536, 0.5641838104929775, 29.613598845899105, 70.99099025130272, 62.394396141171455, 59.08405177295208, 57.7133247256279, 57.299637123942375, 53.552639186382294, 49.171542674303055, 44.01029482483864, 44.01141196489334, 43.5890494287014, 46.94694444537163, 49.447225481271744, 54.192418456077576, 55.313821882009506, 50.68209081888199, 52.82888062298298, 48.63643638789654, 47.214556485414505, 43.08470629155636, 40.48209674656391, 38.74402441084385, 39.27771717309952, 38.59925217926502, 39.54875282943249, 39.70631517469883, 39.77227583527565, 39.5038316398859, 43.56664963066578, 44.47494149208069, 48.01270365715027, 51.71639531850815, 52.4188332259655, 51.71833701431751, 50.55591098964214, 43.945394307374954, 39.13714371621609, 40.13525515794754, 39.42266799509525, 39.62676644325256, 40.1543453335762, 41.41426272690296, 39.46255825459957, 38.88078287243843, 40.04321649670601, 37.98879213631153, 39.665809348225594, 50.496846958994865, 54.78634178638458, 49.9864811450243, 51.01619929075241, 52.87108115851879, 49.93435934185982, 49.921341240406036, 48.68893437087536, 47.19890512526035, 43.528864458203316, 43.24342757463455, 45.490729585289955, 51.81545980274677, 52.850881442427635, 54.226324036717415, 49.19762447476387, 33.66642527282238, 45.52227929234505, 46.423640325665474, 49.147565960884094, 50.55934980511665, 52.91695609688759, 52.38378010690212, 51.867744997143745, 52.070376724004745, 51.449250653386116, 49.89200301468372, 48.107120990753174, 42.74498552083969, 38.931088373064995, 38.45563508570194, 38.71085599064827, 40.398774817585945, 39.06801402568817, 40.56732997298241, 40.0298336148262, 42.506582513451576, 41.09199821949005, 41.352147459983826, 41.204103603959084, 40.36290854215622, 40.41943430900574, 42.468747943639755, 51.59757189452648, 52.315626963973045, 53.46874348819256, 52.8594271838665, 50.48250652849674, 45.11366821825504, 41.84805124998093, 41.269380301237106, 41.56117804348469, 41.43289312720299, 41.31404310464859, 42.30610527098179, 44.9101435393095, 45.2390006929636, 51.075259521603584, 53.87311778962612, 54.971163868904114, 53.684355318546295, 55.03085866570473, 53.9718022942543, 54.01786722242832, 53.112406209111214, 54.70903493463993, 52.97663189470768, 52.69790545105934, 53.595318496227264, 57.05126345157623, 55.86552947759628, 61.34106986224651, 51.525098383426666, 40.42200677096844, 52.75791563093662, 55.9140794724226, 58.76016095280647, 35.98037950694561, 2.7524193562567234, 1.8570316024124622, 0.9176996815949678, 0.1440208070562221, 0.1437931161490269, 7.920373370870948, 61.57187707722187, 55.419433414936066, 46.44996531307697, 26.507920995354652, 17.216247282922268, 28.03406350314617, 41.61931872367859, 53.75380799174309, 41.95458613336086, 1.3232522760517895, 0.14658811851404607, 0.06492398417321965, 0.04431580855452921, 0.08137944649206474, 0.08434526156634092, 0.12879546935437247, 0.03348237834870815, 0.020810613095818553, 0.043813771626446396, 0.03561965604603756, 0.05455593622173183, 0.03572012057702523, 0.020348461039247923, 0.03392811595404055, 0.048959289269987494, 0.007903290170361288, 0.035525548009900376, 0.05544661733438261, 0.029822143114870414, 0.036819849847233854, 1.456141120288521, 52.82317332923412, 67.51191213726997, 52.93924570083618, 42.0211623609066, 33.614789843559265, 61.03938885033131, 52.610373347997665, 45.900066420435905, 64.57670643925667, 42.67666518688202, 1.136990545783192, 0.091882446577074, 0.7569893239997327, 0.18039812537608668, 31.71885497868061, 72.35702455043793, 64.18464347720146, 61.904093250632286, 61.55898816883564, 59.04908984899521, 55.280273482203484, 51.38931266963482, 46.43827334046364, 47.01755605638027, 46.897395104169846, 48.06415669620037, 51.5013724565506, 55.50381548702717, 56.75200670957565, 54.5859557390213, 54.461250230669975, 50.76456539332867, 49.33617644011974, 45.195675417780876, 42.75771103799343, 42.38514482975006, 40.18553026020527, 41.19615063071251, 40.63794158399105, 42.880425453186035, 41.8355955183506, 42.00399108231068, 45.469325333833694, 45.75322709977627, 51.25510387122631, 53.655526265501976, 52.036976516246796, 52.61322699487209, 51.564749255776405, 46.743263974785805, 41.83488875627518, 41.23801678419113, 40.94550088047981, 41.113113686442375, 40.59184245765209, 41.97445146739483, 41.85414232313633, 41.35679841041565, 42.09235914051533, 39.751741737127304, 41.06840908527374, 51.62053786218166, 56.47245191037655, 53.355737552046776, 52.666412740945816, 52.93970927596092, 51.40886262059212, 51.56210459768772, 50.78304760158062, 50.11732332408428, 46.61404050886631, 45.69531820714474, 46.10227257013321, 52.69809164106846, 55.3227362036705, 56.51964917778969, 50.01857802271843, 35.12490101158619, 45.29883608222008, 48.98117668926716, 51.91244199872017, 50.25484174489975, 55.34265473484993, 54.55690249800682, 54.332501739263535, 53.19983571767807, 53.1553591042757, 51.44808791577816, 48.98722596466541, 45.50898760557175, 42.182380110025406, 40.632276087999344, 41.07287384569645, 40.97766995429993, 40.96311293542385, 42.540085315704346, 42.45471149682999, 43.709962740540504, 43.39784748852253, 43.014919236302376, 41.853040382266045, 42.2222513705492, 41.192673817276955, 45.68377062678337, 54.17625792324543, 53.094003796577454, 53.477783203125, 53.28769460320473, 52.30222128331661, 46.91764421761036, 44.13885332643986, 41.80355943739414, 42.8880250453949, 42.83673159778118, 42.51573622226715, 45.102872997522354, 46.349422708153725, 46.892721354961395, 52.60519042611122, 56.47316247224808, 57.186057418584824, 55.00945061445236, 55.99070616066456, 56.555276066064835, 54.687721878290176, 55.73928505182266, 56.07794567942619, 55.887784883379936, 54.09852549433708, 54.706466272473335, 58.31102505326271, 58.55273388326168, 60.6003338098526, 52.911275401711464, 43.441807329654694, 54.45911854505539, 56.706473752856255, 59.9950946867466, 38.77637967467308, 2.7664142427966, 3.4400304593145847, 3.4121401933953166, 0.2849595044972375, 0.09399960094015114, 8.247708231210709, 65.67943766713142, 59.68869812786579, 47.56753474473953, 29.594924747943878, 22.968325428664684, 33.93949382007122, 48.18863421678543, 59.11773696541786, 50.648523420095444, 2.3358792951330543, 0.17580485466169193, 0.015520969445788069, 0.017656079144217074, 0.085763149545528, 0.07010373708908446, 0.05289182219712529, 0.04413861708599143, 0.037987392861396074, 0.01674882587394677, 0.0398197777394671, 0.10747650550911203, 0.22157037077704445, 0.11038943513995036, 0.20969349949155003, 0.15206914627924562, 0.2100090161547996, 0.1516435097437352, 0.16550863918382674, 0.20163669978501275, 0.08231073050410487, 2.5003363704308867, 65.28697192668915, 72.5098067522049, 64.06273081898689, 46.553479358553886, 39.30365078151226, 68.02032485604286, 60.44467516243458, 54.861634746193886, 68.61104115843773, 49.60673712193966, 1.441312178503722, 0.21028819726780057, 2.287423345260322, 4.266109457239509, 34.73910391330719, 75.33376201987267, 68.86594668030739, 64.06012415885925, 64.07701805233955, 62.404283210635185, 58.85194502770901, 52.30148792266846, 49.466855227947235, 49.54905241727829, 48.952446430921555, 51.36412762105465, 54.87523801624775, 59.59402620792389, 59.197164103388786, 56.56838916242123, 57.16229349374771, 52.91146919131279, 52.30824016034603, 48.0560365319252, 44.61516156792641, 44.56910043954849, 42.71202228963375, 42.65536352992058, 43.98019663989544, 43.80520462989807, 44.83933053910732, 43.81094992160797, 48.42394798994064, 48.002436608076096, 52.86880888044834, 56.48456186056137, 55.07790394127369, 56.06639809906483, 54.424806386232376, 48.644005581736565, 43.21065053343773, 44.645901918411255, 42.58365757763386, 43.037170842289925, 43.46640340983868, 45.2721843123436, 43.92136059701443, 42.753820046782494, 42.898869663476944, 40.75010396540165, 42.75833040475845, 53.066196888685226, 59.35060366988182, 55.27996949851513, 55.99765978753567, 53.87758634984493, 54.80924695730209, 54.85677860677242, 55.5407989025116, 51.297384202480316, 47.989410907030106, 47.6200707256794, 48.32627423107624, 55.43024003505707, 56.99090749025345, 59.03860621154308, 53.08302618563175, 37.316646203398705, 45.531368404626846, 50.43089769780636, 53.80931541323662, 52.5372538715601, 57.352503687143326, 56.06912635266781, 56.37309864163399, 55.42342700064182, 57.00864873826504, 54.34133246541023, 52.61507749557495, 47.0708329975605, 43.3994510024786, 42.80749976634979, 43.7059311568737, 44.729603826999664, 43.06789219379425, 45.19194781780243, 44.24553640186787, 47.21384972333908, 45.65937213599682, 44.71432104706764, 44.26691025495529, 44.01644289493561, 43.873638957738876, 46.629429683089256, 57.08767309784889, 56.8379732966423, 56.69539734721184, 56.72191612422466, 54.73363481462002, 48.60207483172417, 46.360149532556534, 44.526637718081474, 44.63962085545063, 45.877590626478195, 44.38618965446949, 48.062059208750725, 49.08089093863964, 50.056587383151054, 55.82826867699623, 58.56648154556751, 58.75859923660755, 58.15881662070751, 58.00715535879135, 58.087046071887016, 57.765416130423546, 58.42672884464264, 59.77534107863903, 57.50632703304291, 56.790665835142136, 58.79058972001076, 60.95364645123482, 61.044104397296906, 64.6854642033577, 55.318047255277634, 47.021184861660004, 56.48640476167202, 56.95685371756554, 60.91542050242424, 41.336393505334854, 4.399771085008979, 7.60934486053884, 5.720210205763578, 0.4831912158988416, 0.199049424554687, 9.788101874291897, 72.82543301582336, 66.53018921613693, 60.59239983558655, 36.657970547676086, 30.632753558456898, 39.551272094249725, 57.72998683154583, 65.61385318636894, 63.055233880877495, 4.411527179181576, 0.2687712153419852, 0.2599591319449246, 0.12894955405499786, 0.13900474965339527, 0.17209923709742725, 0.19702356919879094, 0.1084456242097076, 0.06208480546774808, 0.18013775028521195, 0.1814953758730553], [0.02687053089175606, 0.08257823763415217, 0.010411422772449441, 0.032515641942154616, 0.08471795328659937, 0.015029086025606375, 0.04909490191494115, 0.02253233818919398, 0.023128809698391706, 0.04643613559892401, 2.7544520096853375, 43.35507698357105, 56.779422238469124, 49.68292683362961, 25.623014979064465, 14.133968576788902, 21.458466947078705, 46.096291691064835, 43.79205733537674, 59.16565239429474, 34.59283836185932, 0.4284509673016146, 0.040112566130119376, 0.3006634977646172, 0.29838872607797384, 42.284887209534645, 65.71530774235725, 60.33670395612717, 58.98582324385643, 57.8933172672987, 57.70107038319111, 54.13581669330597, 47.437570318579674, 44.16838154196739, 44.357090815901756, 48.679541274905205, 53.99425908923149, 55.45730598270893, 55.225222036242485, 49.146562814712524, 50.090150982141495, 51.57182067632675, 51.252679601311684, 49.398261308670044, 44.57171089947224, 39.62279185652733, 40.12263223528862, 39.364204332232475, 37.47979424893856, 39.228099435567856, 38.58781099319458, 39.25059422850609, 39.426194205880165, 40.69022297859192, 42.19842664897442, 47.78980381786823, 50.02757593989372, 51.05646952986717, 51.59164801239967, 49.908931106328964, 41.845896765589714, 40.315175503492355, 39.51020769774914, 39.363330379128456, 40.238624811172485, 39.37863975763321, 42.41121523082256, 40.44956289231777, 40.37363536655903, 41.688543409109116, 39.40784119069576, 36.90830111503601, 41.687772050499916, 51.214202865958214, 54.32233728468418, 50.35899795591831, 48.47241438925266, 51.08416244387627, 50.58323912322521, 48.77837397158146, 47.053547725081444, 46.61545783281326, 45.63321813941002, 46.33245661854744, 51.02667532861233, 53.38190294802189, 53.44854757189751, 47.98461936414242, 31.16851720958948, 50.33834606409073, 51.950709745287895, 52.0723108202219, 51.541175320744514, 50.43922685086727, 50.93201860785484, 51.34311854839325, 52.53049783408642, 53.006589487195015, 51.63027673959732, 46.79662451148033, 42.514204904437065, 39.55316819250584, 38.0506794154644, 38.82644958794117, 39.34194512665272, 41.84770926833153, 40.99930979311466, 41.631037294864655, 42.65737742185593, 41.29582308232784, 40.392858535051346, 40.12188747525215, 39.94191013276577, 40.42798765003681, 41.86161272227764, 49.53316546976566, 51.21017508208752, 48.84114280343056, 51.41671679913998, 50.911389514803886, 45.464138612151146, 40.90401470661163, 40.01034826040268, 41.54755957424641, 40.3492596745491, 39.90258604288101, 41.69897384941578, 44.29653346538544, 49.821026623249054, 52.88167878985405, 53.6051219701767, 54.4838248193264, 53.47201891243458, 55.36044158041477, 53.53511832654476, 54.19777236878872, 51.9304758310318, 48.97809125483036, 46.130626648664474, 50.77916420996189, 50.928169414401054, 54.75553683936596, 55.50486043095589, 57.69947066903114, 48.755430802702904, 56.58453069627285, 60.237160697579384, 56.12921632826328, 56.23068988323212, 37.17152439057827, 3.379184086807072, 3.0628135381266475, 3.3307293243706226, 1.072335233911872, 0.04490940424147993, 2.5053333397954702, 49.97193172574043, 60.44202670454979, 49.694337621331215, 45.51592983305454, 23.67764286696911, 35.795040652155876, 46.28573052585125, 50.32008424401283, 49.642440006136894, 3.1226304033771157, 0.22958368062973022, 0.020923478914482985, 0.0691293936688453, 0.036978331772843376, 0.06287891461397521, 0.031501597331953235, 0.011514509333210299, 0.03552870584826451, 0.009753028316481505, 0.00928287869101041, 0.04334500517870765, 0.007546432634626399, 0.10349375515943393, 0.08877063621184789, 0.02497498739103321, 0.06953826508834027, 0.03813869821897242, 0.010437535238452256, 0.09664129043812864, 0.020419430766196456, 5.120326420292258, 57.35733322799206, 59.97105337679386, 58.071352913975716, 28.34504261612892, 17.116358242928982, 31.507430523633957, 48.18759307265282, 48.749985694885254, 63.55892725288868, 37.55104802548885, 0.34556019643787295, 0.05522909385035746, 1.0404454451054335, 0.7612064445856959, 44.85666140913963, 67.54535034298897, 62.296714782714844, 59.39270541071892, 59.207032173871994, 59.372456297278404, 56.56028039753437, 49.77932766079903, 46.160417050123215, 46.18759699165821, 52.236914187669754, 55.72810985147953, 57.575038745999336, 58.0214311927557, 52.279783487319946, 52.41767428815365, 52.42622382938862, 54.757805317640305, 50.415595918893814, 45.95412231981754, 43.673724085092545, 41.96260750293732, 40.546662881970406, 38.67045275866985, 40.690485164523125, 40.87425470352173, 43.116559982299805, 41.279772743582726, 43.069165125489235, 43.52946862578392, 48.10516409575939, 51.52148097753525, 53.46053212881088, 53.66809979081154, 51.781607419252396, 42.87479795515537, 41.72572061419487, 40.932836160063744, 41.35372817516327, 43.13774764537811, 39.799421578645706, 43.34432736039162, 42.412932738661766, 42.45344616472721, 42.56605692207813, 40.797821804881096, 39.00314390659332, 43.34840074181557, 54.07591670751572, 57.218017503619194, 51.86216689646244, 50.78402794897556, 54.25923407077789, 52.08981268107891, 50.84034092724323, 48.83728601038456, 48.293485790491104, 47.448950707912445, 49.09831680357456, 53.28248888254166, 56.88527695834637, 55.11121295392513, 50.268524810671806, 33.81104551255703, 51.61455698311329, 53.24912287294865, 53.880409598350525, 52.701587453484535, 52.65145294368267, 53.04385408759117, 51.67732201516628, 54.85491670668125, 53.57683248817921, 54.05295453965664, 50.23491941392422, 45.25990717113018, 40.74330992996693, 40.59978023171425, 42.74861052632332, 40.05626879632473, 44.106703251600266, 44.23581272363663, 44.0895813703537, 45.206702426075935, 43.075981959700584, 42.716829031705856, 41.32488392293453, 41.3406340777874, 42.81598851084709, 44.04441699385643, 51.15084506571293, 53.72602008283138, 51.2189944088459, 53.92694190144539, 52.73902304470539, 47.275520414114, 42.5066053122282, 42.96690881252289, 43.090808764100075, 43.1586579233408, 42.46329143643379, 43.16029943525791, 46.48182660341263, 50.498545467853546, 56.108724027872086, 55.14601148664951, 55.80401457846165, 54.60616685450077, 57.32034981250763, 55.28642915189266, 55.37486560642719, 52.550955936312675, 52.813939824700356, 48.81909258663654, 52.65063218772411, 53.16992372274399, 56.60363607108593, 58.94577719271183, 60.33109925687313, 51.298619136214256, 59.0594594925642, 63.243073001503944, 57.38743521273136, 56.41855180263519, 38.44080068171024, 3.1677886052057147, 3.017849363386631, 5.107679273933172, 1.9818914774805307, 0.049605558888288215, 2.0780486427247524, 54.58119459450245, 64.94138047099113, 49.84905771911144, 46.95379167795181, 29.74101170897484, 40.24782791733742, 56.14795692265034, 56.81752659380436, 60.12515410780907, 5.479047121480107, 0.29900423367507756, 0.01873377219453687, 0.022071132370911073, 0.06498582733911462, 0.012826266483898507, 0.024643343858770095, 0.02626713514473522, 0.05048175327829085, 0.07203081258921884, 0.02194168326241197, 0.1944834945606999, 0.18145288049709052, 0.14630522666266188, 0.22160814609378576, 0.16709802264813334, 0.1064612994377967, 0.1541499502491206, 0.11014936520950869, 0.3144064103253186, 0.20343159878393635, 9.147734586149454, 70.89813083410263, 68.17796319723129, 65.90635389089584, 35.938099175691605, 21.48754108697176, 28.963221944868565, 58.72164621949196, 56.44700847566128, 68.48940968513489, 43.04241456091404, 0.6335482571739703, 0.18377010303083807, 2.0716958586126566, 0.9650175331626087, 45.967740789055824, 68.72535422444344, 65.34859701991081, 60.82753501832485, 63.41061741113663, 62.979317754507065, 60.76681427657604, 51.902585327625275, 49.524068757891655, 48.689359948039055, 54.41234305500984, 59.0796934068203, 60.639608502388, 61.27761706709862, 55.035779401659966, 53.433188796043396, 54.67004902660847, 57.54433259367943, 54.61557894945145, 48.6766192317009, 45.73453210294247, 45.03342032432556, 44.46224257349968, 41.01006701588631, 43.13650131225586, 42.50443562865257, 44.10337083041668, 43.197218254208565, 44.322102293372154, 47.708898559212685, 52.18679867684841, 55.89193806052208, 55.60669116675854, 57.76927292346954, 53.96936662495136, 45.86578845977783, 45.27042120695114, 42.780034840106964, 44.30998854339123, 44.65515822172165, 41.71177916228771, 47.38483674824238, 44.359834268689156, 42.891684249043465, 46.84613585472107, 41.42701864242554, 41.385452672839165, 45.24224951863289, 56.77808091044426, 60.30307196080685, 54.76502113044262, 52.73407571017742, 55.30746102333069, 54.37242239713669, 52.48809590935707, 50.85143633186817, 50.61790846288204, 50.661670714616776, 51.602857410907745, 56.50840178132057, 61.245303601026535, 57.79520273208618, 51.64880074560642, 38.78647193312645, 53.88314165174961, 54.11318890750408, 55.693334117531776, 55.414090901613235, 54.73865434527397, 55.49786880612373, 55.13491988182068, 57.844049111008644, 56.5177758783102, 56.77138566970825, 52.85768307745457, 46.623380407691, 42.629600912332535, 43.321695774793625, 44.65546600520611, 43.764596208930016, 45.11864975094795, 44.46595497429371, 46.222809702157974, 46.797509863972664, 46.21089354157448, 43.8673160970211, 42.50746786594391, 43.62270802259445, 44.407597705721855, 47.17380367219448, 52.55127891898155, 56.34104736149311, 52.01413594186306, 56.819297298789024, 55.66607438027859, 47.63913810253143, 43.90638940036297, 45.75052544474602, 46.05005957186222, 46.730477660894394, 43.26284073293209, 44.43325012922287, 49.78823818266392, 54.606478437781334, 58.308429792523384, 58.532731756567955, 58.29264543950558, 56.84536769986153, 58.970065489411354, 57.90556401014328, 58.61841335892677, 56.68608784675598, 54.39557835459709, 50.96340112388134, 56.072888150811195, 55.52926652133465, 59.8199088871479, 61.08235314488411, 62.79614098370075, 54.41551208496094, 62.00153902173042, 65.76326116919518, 59.52348679304123, 57.707575634121895, 42.05516293644905, 5.293658869341016, 8.816920537501574, 10.510138180106878, 2.5427494570612907, 0.1608763463445939, 2.887961408123374, 60.210406333208084, 69.97844338417053, 64.40006911754608, 56.91442899405956, 32.26315297186375, 45.74114374816418, 63.806214183568954, 64.94480788707733, 69.90117073059082, 8.950832951813936, 0.5110053671523929, 0.13101572287268937, 0.18880024639656767, 0.2582518954295665, 0.10890985242440365, 0.1538173493463546, 0.16845748876221478, 0.14714299264596775, 0.1509120935224928, 0.10755172959761694], [0.026151089223276358, 0.020758124701387715, 0.032780729670776054, 0.04828416866075713, 0.03831466514384374, 0.04645525332307443, 0.03099487930739997, 0.030416141416935716, 0.1056789570429828, 0.043403913150541484, 7.572812670841813, 53.222471103072166, 53.360358104109764, 47.2575131803751, 34.03811752796173, 33.188524916768074, 24.987943656742573, 36.53915472328663, 49.06965114176273, 60.005604922771454, 31.990650594234467, 0.026045999256893992, 0.04500056224060245, 0.21399895049398765, 2.1457776334136724, 52.80287101864815, 63.398602455854416, 60.565831661224365, 59.1003604978323, 57.33475483953953, 55.60593880712986, 49.732213988900185, 45.08626028895378, 45.23063354194164, 48.98406073451042, 54.04825799167156, 53.13139759004116, 55.75081363320351, 47.25975885987282, 50.30072048306465, 52.550731748342514, 53.335997611284256, 54.12263140082359, 48.02399665117264, 42.80014716088772, 38.573656752705574, 38.40656451880932, 38.10391455888748, 38.311831802129745, 39.77049373090267, 38.550246208906174, 39.59719642996788, 39.18873354792595, 41.09971180558205, 40.93538582324982, 45.166834965348244, 47.57103815674782, 47.57000841200352, 48.76038573682308, 46.163897663354874, 43.448103591799736, 40.317147597670555, 39.51935760676861, 39.9324182420969, 40.63737541437149, 39.3141458183527, 38.16442251205444, 40.92008404433727, 42.034552842378616, 42.68840655684471, 40.69727160036564, 39.85373206436634, 39.57615315914154, 43.8322401791811, 52.00492523610592, 53.85815039277077, 50.807518288493156, 50.250969752669334, 50.38113556802273, 48.652779310941696, 50.03457136452198, 46.34527713060379, 46.17470808327198, 44.58317868411541, 47.594178915023804, 52.31477960944176, 53.814638927578926, 54.409189224243164, 35.38984939455986, 51.1196069419384, 52.32959881424904, 51.91609360277653, 52.054546773433685, 53.465300872921944, 53.27002175152302, 50.28571888804436, 51.39121636748314, 53.65184426307678, 51.10645964741707, 47.614671215415, 44.599776193499565, 39.333418384194374, 41.48659944534302, 39.615097269415855, 38.27200993895531, 43.26746888458729, 42.84786120057106, 41.60095430910587, 42.91597254574299, 42.637010514736176, 39.99673739075661, 41.33710406720638, 41.533063352108, 39.104400873184204, 38.74036520719528, 44.8932496458292, 51.16948686540127, 50.150031968951225, 49.28981892764568, 49.343251660466194, 46.52170546352863, 42.095410376787186, 40.68981260061264, 41.22896566987038, 40.30998878180981, 40.30566081404686, 41.384039148688316, 43.278716281056404, 51.87839962542057, 55.76705776154995, 54.89411920309067, 52.1727242320776, 55.72480782866478, 53.255810514092445, 53.95808503031731, 48.94577778875828, 45.369683280587196, 44.209031760692596, 46.11656740307808, 46.676121577620506, 50.87989680469036, 52.18815520405769, 57.172218561172485, 54.62896563112736, 61.303983852267265, 58.09578940272331, 58.29861491918564, 62.52552330493927, 61.9009318202734, 45.694322660565376, 4.596384884789586, 2.085501942783594, 2.703285380266607, 0.3162206645356491, 0.1149249222362414, 0.3510881873080507, 42.067402079701424, 63.11566583812237, 51.09063729643822, 36.37538731098175, 13.830403815954924, 22.017405554652214, 40.15143848955631, 52.05229349434376, 52.71225728094578, 10.434721726924181, 0.2867537207202986, 0.04717223848274443, 0.029912353020336013, 0.015282025724445703, 0.05370934239181224, 0.11514684665598907, 0.02624083343107486, 0.09888778629829176, 0.055799538240535185, 0.06843368959380314, 0.0772075226996094, 0.03416734354686923, 0.07092317202477716, 0.13846172019839287, 0.030614387615059968, 0.059706459651351906, 0.06972167946514674, 0.05149751596036367, 0.07392467698082328, 0.15200916590401903, 12.039994038641453, 65.35520866513252, 57.59013533592224, 53.8721564412117, 36.896206364035606, 31.258021406829357, 25.266474410891533, 42.628263384103775, 53.603868037462234, 64.47120890021324, 35.08984409272671, 0.022024568170309067, 0.0715651446080301, 1.2036494188942015, 3.2206670427694917, 56.23979799449444, 65.43966293334961, 61.00084751844406, 60.46945743262768, 58.72782088816166, 56.262623369693756, 52.31554716825485, 45.75971335172653, 47.55981355905533, 49.92337793111801, 55.472717955708504, 56.060360223054886, 58.79990302026272, 49.47365306317806, 51.65619894862175, 53.27413313090801, 54.073830619454384, 54.31397393345833, 50.70768624544144, 44.21603858470917, 41.1146792024374, 40.38749322295189, 41.22865028679371, 40.48265151679516, 42.39038474857807, 40.880315378308296, 42.90839575231075, 40.79400680959225, 42.849571108818054, 41.66176624596119, 46.11217483878136, 48.75633515417576, 49.98936519026756, 50.53304001688957, 48.76049593091011, 44.73995067179203, 41.97703532874584, 42.29176864027977, 41.48917190730572, 41.78996376693249, 42.30033338069916, 39.13441926240921, 43.305926620960236, 43.64322692155838, 43.37678141891956, 40.232484340667725, 42.42446132004261, 41.24667651951313, 46.19652271270752, 53.91731321811676, 54.87264655530453, 53.738722801208496, 53.78808215260506, 52.569426745176315, 51.46707929670811, 50.8253089338541, 50.277990102767944, 49.495452493429184, 47.44919769465923, 49.597515016794205, 53.69565211236477, 55.955098271369934, 55.63154563307762, 37.83242292702198, 53.33008512854576, 54.07069578766823, 52.76580020785332, 53.27200524508953, 54.7874741256237, 55.07490590214729, 53.00814360380173, 52.619652450084686, 54.81412969529629, 53.205843195319176, 48.8579872995615, 45.89093931019306, 40.89520677924156, 41.43731988966465, 42.028993740677834, 40.047947242856026, 43.53723160922527, 44.67204071581364, 44.32898752391338, 44.88102190196514, 43.73837761580944, 41.9071114808321, 41.9975770264864, 43.08675818145275, 42.50020645558834, 40.93978978693485, 47.005107924342155, 52.9387441277504, 53.15331481397152, 52.37635910511017, 50.596849992871284, 50.52791029214859, 43.215252086520195, 42.881223410367966, 42.69641272723675, 42.57879763841629, 42.49723881483078, 44.60907809436321, 44.9060245603323, 53.609810918569565, 58.04717481136322, 57.272624373435974, 54.08242955803871, 57.22083695232868, 55.85009850561619, 54.80581574141979, 50.33542022109032, 47.96568498015404, 45.37684969604015, 49.562116116285324, 47.99676351249218, 54.05418187379837, 53.465988636016846, 59.099516943097115, 57.225658893585205, 63.437265381217, 58.71930554509163, 60.134216621518135, 64.5037579536438, 64.05545800924301, 48.13052013516426, 6.0365494061261415, 3.396496195346117, 5.084916595369577, 2.1359748719260097, 0.294197432231158, 0.3865805687382817, 44.54541631042957, 66.54082104563713, 56.416469514369965, 37.50051833689213, 19.160777740180492, 26.924899220466614, 46.7797040194273, 59.86188903450966, 59.51467886567116, 16.550443209707737, 0.3414684097515419, 0.09617111019906588, 0.08401912476983853, 0.018623591095092706, 0.03271099747507833, 0.034388403364573605, 0.03819723511696793, 0.06814055610448122, 0.022653816631645896, 0.088860376708908, 0.17664327373495325, 0.1332237309543416, 0.11337508782162331, 0.19634974363725632, 0.15758324414491653, 0.13413347041932866, 0.1887630351120606, 0.22922238829778507, 0.2488504131906666, 0.23735735099762678, 15.541829131543636, 75.57341516017914, 67.55765408277512, 62.87401780486107, 44.033469781279564, 43.95952194929123, 32.74135731160641, 50.715202242136, 58.80099356174469, 70.29334008693695, 38.269376680254936, 0.0892957131145522, 0.11175485327839851, 2.0410714019089937, 4.473698493093252, 59.7755728662014, 65.79786971211433, 65.8987694978714, 62.56532236933708, 62.10851468145847, 58.96882675588131, 54.62359271943569, 49.29875984787941, 52.1325945854187, 52.21030421555042, 59.59575891494751, 57.28772476315498, 61.32327541708946, 49.97280187904835, 51.90954655408859, 54.99272771179676, 58.6088340729475, 56.867626905441284, 52.03385688364506, 46.583421751856804, 42.91890598833561, 42.87549331784248, 44.5901171118021, 43.28179031610489, 44.02227558195591, 40.91936208307743, 44.37177702784538, 43.71669217944145, 46.32219336926937, 44.84032228589058, 49.25706088542938, 51.23043939471245, 52.96848513185978, 53.46918046474457, 50.91464214026928, 47.83269211649895, 44.94176544249058, 43.67109462618828, 43.59729118645191, 43.429777175188065, 44.91727955639362, 41.234881952404976, 44.571897089481354, 46.314943358302116, 47.38782338798046, 42.77373857796192, 45.33188670873642, 43.181088119745255, 47.96675272285938, 56.57329469919205, 57.71823026239872, 54.00048315525055, 56.47388443350792, 55.5206485837698, 54.519208520650864, 54.75073769688606, 50.85118554532528, 51.87394626438618, 49.55641262233257, 50.86942836642265, 57.17219956219196, 58.076497837901115, 57.010609433054924, 41.7874027043581, 55.302209705114365, 55.212625712156296, 55.482570827007294, 55.12249454855919, 58.34379069507122, 58.128976821899414, 55.944139659404755, 53.81168268620968, 56.83347813785076, 55.00455267727375, 51.678549349308014, 46.46886549890041, 43.04538980126381, 45.12201637029648, 44.671257957816124, 41.41483649611473, 46.00826181471348, 46.71463631093502, 45.151058211922646, 46.39909744262695, 46.428914442658424, 43.890745639801025, 43.544291630387306, 45.663707703351974, 44.1229397803545, 42.47595615684986, 50.39067305624485, 55.316033363342285, 55.04098892211914, 53.31686943769455, 52.45170146226883, 51.83419279754162, 45.22185601294041, 45.02278469502926, 45.97119860351086, 44.66909967362881, 44.01384383440018, 47.51889355480671, 47.301062643527985, 55.94597116112709, 60.31582027673721, 59.75214712321758, 55.29254302382469, 59.31757964193821, 58.245771154761314, 58.0151691287756, 53.639335334300995, 50.56335099041462, 47.586419731378555, 50.37892408668995, 50.20552799105644, 56.0279593616724, 57.711185440421104, 62.269652634859085, 61.79148629307747, 66.88236951828003, 62.61943906545639, 63.97769898176193, 68.15282374620438, 63.44294607639313, 52.774296551942825, 6.363274399191141, 6.130600059404969, 9.338811133056879, 1.328984743449837, 0.31560301955323666, 0.5223331530578434, 50.89892618358135, 71.3039642572403, 66.62003919482231, 45.85342772305012, 24.052021577954292, 34.05351050198078, 56.73665553331375, 66.70699372887611, 70.94682902097702, 22.31143567711115, 0.5106744880322367, 0.2802759292535484, 0.12595663574757054, 0.13782850495772436, 0.23717274918453768, 0.16574501321883872, 0.14314657193608582, 0.1360821127309464, 0.19770153594436124, 0.1872696855571121], [0.07849634377635084, 0.04872318611887749, 0.02559958815254504, 0.03267011255957186, 0.04816586289962288, 0.06094547890825197, 0.08024427967029624, 0.014893324951117393, 0.16192063718335703, 0.09501494801952504, 11.941926050931215, 55.04503570497036, 50.895696356892586, 42.79013089835644, 25.806911811232567, 21.191675662994385, 41.51321321725845, 34.61735464632511, 49.849350303411484, 59.52464573085308, 27.88953635841608, 0.1358353189425543, 0.11413933665608056, 0.30002887244336307, 4.066222608089447, 47.60595828294754, 63.31910692155361, 57.90900282561779, 58.77179212868214, 55.55261246860027, 52.52288684248924, 42.155891731381416, 45.25616817176342, 48.07426415383816, 50.75213626027107, 53.618558049201965, 54.2648159712553, 49.585963636636734, 48.479421213269234, 51.57929487526417, 50.949942246079445, 55.92812351882458, 53.96699175238609, 46.56634546816349, 40.08349433541298, 38.69520083069801, 37.36162059009075, 37.353443428874016, 36.29711531102657, 40.3763560205698, 39.73180800676346, 39.92655135691166, 39.77218084037304, 40.9056182205677, 40.175529196858406, 39.2131320387125, 41.40039727091789, 43.625660464167595, 45.37713088095188, 42.80663721263409, 39.811349138617516, 37.213014364242554, 39.049588814377785, 39.520512744784355, 39.00712989270687, 39.770033955574036, 41.373703703284264, 40.92796102166176, 41.47207662463188, 40.36324292421341, 41.53676055371761, 40.969158411026, 38.57634320855141, 41.06770232319832, 46.05963505804539, 50.00613749027252, 51.502759382128716, 52.449220195412636, 48.15359249711037, 49.3690674751997, 48.854810670018196, 50.28331741690636, 49.34384062886238, 50.291650369763374, 46.89360290765762, 50.130805000662804, 51.4470049738884, 55.331038758158684, 39.333608373999596, 52.76847526431084, 51.645817905664444, 49.60791885852814, 50.044317841529846, 51.48355521261692, 53.70582416653633, 53.29435184597969, 52.51456528902054, 51.97912082076073, 50.09894751012325, 48.5076043009758, 39.694425612688065, 36.96272559463978, 39.00869160890579, 38.27801741659641, 38.67798775434494, 40.87870046496391, 42.05096796154976, 40.678720995783806, 42.627370432019234, 43.19797441363335, 41.06092348694801, 39.295044243335724, 40.28698481619358, 39.14051033556461, 42.58622244000435, 40.30299715697765, 45.69731689989567, 45.72421945631504, 50.90510085225105, 47.91203945875168, 47.87258617579937, 44.351284727454185, 39.21134613454342, 38.76498408615589, 39.59433138370514, 41.36582292616367, 41.777219250798225, 44.071011766791344, 51.68161578476429, 52.84289427101612, 54.021651819348335, 56.06168635189533, 56.77632920444012, 50.46569623053074, 48.527614027261734, 43.77823367714882, 42.568777576088905, 42.180715799331665, 44.23969231545925, 49.26468327641487, 51.46011807024479, 48.76310259103775, 51.59425467252731, 52.713473215699196, 55.35378813743591, 59.581802263855934, 57.014219239354134, 61.112542524933815, 66.72236010432243, 54.49576757848263, 9.092975724488497, 2.1484629018232226, 2.9224747186526656, 3.1506914226338267, 0.25907113740686327, 0.10393240896519274, 30.661060139536858, 67.25614786148071, 50.83184838294983, 46.708655431866646, 27.928368374705315, 21.48131512105465, 40.43626740574837, 50.14284275472164, 53.86089384555817, 25.80467563122511, 0.7179358508437872, 0.031000534472696017, 0.07051452324958518, 0.07249630245496519, 0.0773091301380191, 0.020901869429508224, 0.03290070526418276, 0.003546826951605908, 0.018865542369894683, 0.06131317597464658, 0.03968167147831991, 0.02829873286827933, 0.08254794316599146, 0.012754372783092549, 0.01636198881897144, 0.05147703268448822, 0.009177799856843194, 0.009040450586326187, 0.12429037320544012, 0.058393322105985135, 15.260808560997248, 63.573286682367325, 56.59284844994545, 50.098263546824455, 29.737859778106213, 25.41928891092539, 36.74818530678749, 38.77115495502949, 55.20606346428394, 65.90621709823608, 31.992482095956802, 0.14257376751629636, 0.31853643245995045, 2.2981002973392606, 5.221986165270209, 52.13930502533913, 63.49944144487381, 60.911917090415955, 61.036823987960815, 57.36872881650925, 55.98403751850128, 46.06707885861397, 45.757897049188614, 48.54940965771675, 52.945997938513756, 55.07215104997158, 56.96343496441841, 51.46437004208565, 48.67606446146965, 51.526177525520325, 52.3077841848135, 57.16911792755127, 55.06701372563839, 49.53384943306446, 41.34985998272896, 40.58148421347141, 40.94770856201649, 38.65648850798607, 39.21106494963169, 42.74518311023712, 41.91601060330868, 41.782500967383385, 42.783876433968544, 42.30168230831623, 42.55924388766289, 41.96590192615986, 43.36598239839077, 46.73090323805809, 47.46244378387928, 44.27655413746834, 41.38967044651508, 38.509387001395226, 40.95283068716526, 40.79604350030422, 41.29557229578495, 42.10280478000641, 42.37627990543842, 42.36994184553623, 43.224067613482475, 42.30175830423832, 42.473550885915756, 41.42474256455898, 40.70525497198105, 43.19369204342365, 49.151905328035355, 54.734729155898094, 53.921956568956375, 54.99852240085602, 49.33750256896019, 50.39943918585777, 50.95647029578686, 52.79821626842022, 52.20321759581566, 51.857523545622826, 49.09769743680954, 52.55281023681164, 54.90470163524151, 56.50669187307358, 43.06068018078804, 52.5935934484005, 53.16631771624088, 52.7431458234787, 53.12811076641083, 53.98026064038277, 56.07491344213486, 56.25286549329758, 54.849122017621994, 54.26514275372028, 53.24100650846958, 50.356976464390755, 41.6637497395277, 40.01961596310139, 40.71217820048332, 40.64585655927658, 40.637937784194946, 43.16560015082359, 44.25307899713516, 43.35993692278862, 44.41953666508198, 44.05372269451618, 41.47791691124439, 41.63394033908844, 43.36699694395065, 41.12955540418625, 43.74240159988403, 42.648337706923485, 48.101067915558815, 47.81449109315872, 52.39002697169781, 50.37949025630951, 49.154246002435684, 46.125420928001404, 40.26295490562916, 41.62748068571091, 42.099791541695595, 42.3489935696125, 42.89543844759464, 45.1185167580843, 55.20509071648121, 54.0237683057785, 57.25737579166889, 55.895449072122574, 58.398169577121735, 52.78721205890179, 50.69660983979702, 46.30244582891464, 44.97512385249138, 44.6087247133255, 47.2667770832777, 51.94560281932354, 55.00760391354561, 51.218705624341965, 53.511187210679054, 54.7577141225338, 57.675581350922585, 60.72625145316124, 59.07674856483936, 63.22680227458477, 68.05778324604034, 54.91906866431236, 10.620228722691536, 2.9805291909724474, 6.117177279666066, 4.998400462791324, 0.13471201906213537, 0.1067029130354058, 33.174959644675255, 73.26308593153954, 55.174498558044434, 44.46497842669487, 26.44884556531906, 26.158237159252167, 48.248629197478294, 56.781515926122665, 62.305632904171944, 33.527512326836586, 1.0277449828572571, 0.12104084991733544, 0.041651186693343334, 0.09165129726170562, 0.026977797206200194, 0.03660771806607954, 0.03767638103454374, 0.023259090012288652, 0.0565439643105492, 0.04517543078691233, 0.1716904918430373, 0.09611242116079666, 0.11004904910805635, 0.1818487569107674, 0.1086465606931597, 0.19143209501635283, 0.17084606137359515, 0.1408587978221476, 0.172978192276787, 0.12692260032054037, 19.375477619469166, 74.97316136956215, 63.492533415555954, 59.843235835433006, 36.21236465871334, 32.2367899864912, 53.83561000227928, 49.999734833836555, 58.58012281358242, 71.9268648326397, 35.390917137265205, 0.2766678447369486, 0.15485101263038814, 2.4838317185640335, 7.727922247722745, 53.051316887140274, 63.66369143128395, 63.0819084495306, 61.95140451192856, 61.54733419418335, 57.94849410653114, 47.47578866779804, 48.60323756933212, 53.22117917239666, 54.7436548769474, 57.62456148862839, 58.54789674282074, 54.64941993355751, 50.21186605095863, 54.39429022371769, 54.83347445726395, 60.02738535404205, 58.56935039162636, 51.21153920888901, 43.80997337400913, 42.87103995680809, 44.031953662633896, 39.95892561972141, 40.51722966134548, 45.669616386294365, 43.20345751941204, 45.89005395770073, 44.73496533930302, 45.45547127723694, 46.893097534775734, 45.60300976037979, 46.00025184452534, 49.03625853359699, 49.9347735196352, 48.02929736673832, 44.679868295788765, 40.01627594232559, 42.61367976665497, 42.43530593812466, 42.43513494729996, 43.605791330337524, 44.34909224510193, 45.65075799822807, 44.6236427128315, 45.6965721398592, 43.469515442848206, 43.92651692032814, 41.771207973361015, 45.67646361887455, 49.46523271501064, 55.459547862410545, 56.23246818780899, 56.70323632657528, 51.89212068915367, 53.26765447854996, 51.53148964047432, 57.530790120363235, 55.98137006163597, 55.47448106110096, 51.305333375930786, 53.35264451801777, 55.763178169727325, 59.77746516466141, 46.48259036242962, 55.46873576939106, 55.45685760676861, 54.62382830679417, 56.315075755119324, 56.82269051671028, 59.59442898631096, 59.749285876750946, 57.19622567296028, 56.67616277933121, 55.52504874765873, 52.74707481265068, 44.44936506450176, 41.13530069589615, 43.54362666606903, 42.52334341406822, 42.48767852783203, 44.244077280163765, 45.945018008351326, 45.42154289782047, 46.13183878362179, 46.725454330444336, 43.06283086538315, 43.62942226231098, 44.446750804781914, 41.963781639933586, 46.28473877906799, 44.50412392616272, 51.681756377220154, 50.38887955248356, 55.23610845208168, 52.84894734621048, 52.376811280846596, 49.50163476169109, 43.38979572057724, 43.662001714110374, 43.972209468483925, 44.857022389769554, 44.88702178001404, 47.87184901535511, 56.064270213246346, 56.4607485383749, 60.00508055090904, 58.71146656572819, 60.12339860200882, 54.68269854784012, 52.61098511517048, 48.58970269560814, 46.776288002729416, 46.835618019104004, 49.048626869916916, 55.39728060364723, 57.37119488418102, 54.11585256457329, 58.89228366315365, 58.02873820066452, 60.359487533569336, 65.61514511704445, 62.275002747774124, 68.2343065738678, 68.63450109958649, 61.33723586797714, 11.646926030516624, 4.66973852366209, 12.504064086824656, 8.108751587569714, 0.3713796625379473, 0.33120047010015696, 37.63545289635658, 76.11451372504234, 63.739953339099884, 59.76634316146374, 37.89048381149769, 33.6838511377573, 55.508622229099274, 65.36193430423737, 70.39151161909103, 41.62749968469143, 1.8511422746814787, 0.20246898871846497, 0.15716189722297713, 0.18429339135764167, 0.14298536261776462, 0.16079635766800493, 0.2043153185513802, 0.13450595433823764, 0.15429842431331053, 0.14366215677000582], [0.06588302450836636, 0.01851891487604007, 0.045420799651765265, 0.018479777718312107, 0.03777249286940787, 0.015418368457176257, 0.049229063661186956, 0.01788057510566432, 0.09467761963605881, 0.1452467608032748, 10.010861121118069, 56.902056857943535, 52.45846129953861, 40.66609047353268, 25.254942029714584, 20.86086731404066, 34.91938903927803, 39.75116416811943, 55.71303226053715, 59.72082920372486, 23.732831105589867, 0.17922925762832165, 0.29387064976617694, 0.446019324590452, 6.4805361069738865, 50.99768288433552, 60.72905570268631, 58.28178942203522, 58.07735279202461, 55.14410778880119, 51.22557185590267, 45.285525396466255, 49.801085293293, 51.499217972159386, 57.79851995408535, 53.059456050395966, 54.98370319604874, 47.79112234711647, 53.67025047540665, 51.07237547636032, 55.00945441424847, 52.01476290822029, 53.64023968577385, 42.90791317820549, 38.64890791475773, 38.533500507473946, 38.60828049480915, 38.44013191759586, 38.97452764213085, 38.83254066109657, 39.33787554502487, 39.6726755797863, 40.54319366812706, 39.07277137041092, 40.684405490756035, 39.45035330951214, 37.039428278803825, 40.099989250302315, 40.15244163572788, 39.113079607486725, 41.247915253043175, 39.132956340909004, 40.54268069565296, 37.49930240213871, 40.35358764231205, 40.213481560349464, 40.81452950835228, 40.02612881362438, 39.61745694279671, 39.52208586037159, 40.410565584897995, 40.40852129459381, 40.64577676355839, 42.03604616224766, 41.0193195194006, 49.79603536427021, 50.31700260937214, 49.716083854436874, 47.557590678334236, 49.342214316129684, 52.1748711168766, 52.00713291764259, 51.70601427555084, 52.021222561597824, 48.918746039271355, 48.44940662384033, 50.66466115415096, 55.1090432703495, 44.241797402501106, 53.33748713135719, 52.80050754547119, 46.969203650951385, 46.03451080620289, 48.332057520747185, 50.72996445000172, 53.14237520098686, 52.22581498324871, 50.39238676428795, 47.250194773077965, 41.21279373764992, 39.22752566635609, 38.8586338609457, 38.270995393395424, 39.12268169224262, 39.54467184841633, 40.030057802796364, 42.06553258001804, 39.351505413651466, 43.593597784638405, 41.78949259221554, 41.41611322760582, 41.25504747033119, 39.50352005660534, 39.97886694967747, 42.39149808883667, 41.47815249860287, 40.89979313313961, 45.645510479807854, 46.91084638237953, 45.76824389398098, 45.75661651790142, 43.755282908678055, 39.42237161099911, 40.35222351551056, 38.50209139287472, 40.056359991431236, 42.739586010575294, 40.09689621627331, 52.33117572963238, 54.603993371129036, 52.94094420969486, 54.46694232523441, 52.37637810409069, 49.45892885327339, 43.17537322640419, 43.99544522166252, 42.3170942813158, 43.008907958865166, 49.06905077397823, 50.19953191280365, 49.52802434563637, 51.63675919175148, 51.05536758899689, 52.82819665968418, 55.17238587141037, 55.011597499251366, 55.75933277606964, 59.99579384922981, 66.5556326508522, 63.161506578326225, 17.050427980720997, 2.141516637057066, 3.0895472411066294, 2.979700122959912, 0.1632651564432308, 0.16095105092972517, 19.39124297350645, 68.27712267637253, 54.829511269927025, 47.946499809622765, 32.8947626799345, 27.50294130295515, 38.465799540281296, 51.0571800917387, 59.96797934174538, 35.215974524617195, 0.9699295414611697, 0.025669277674751356, 0.06512354026199318, 0.046321429254021496, 0.03063822539843386, 0.02009545176406391, 0.06619475621846505, 0.03701361347339116, 0.02841289373463951, 0.08658872946398333, 0.00704093265994743, 0.02609122388093965, 0.03803031497227494, 0.011434109692345373, 0.06420755933504552, 0.028488004645623732, 0.039219521277118474, 0.0895808165660128, 0.07599739154102281, 0.18542353383963928, 13.792857080698013, 67.89828300476074, 58.63417871296406, 47.949372455477715, 29.117567762732506, 22.808433808386326, 38.615872487425804, 45.57462528347969, 59.16855163872242, 64.64321807026863, 26.35829072445631, 0.2659289084840566, 0.359595901099965, 1.5763952862471342, 8.587014824151993, 52.74942308664322, 60.39603777229786, 59.6433399617672, 59.21418718993664, 57.75110989809036, 52.3180740326643, 47.19430357217789, 51.44084170460701, 53.46883088350296, 59.63186077773571, 54.428362995386124, 56.388069838285446, 49.7793884575367, 52.197658494114876, 51.83436378836632, 56.39416091144085, 54.33781385421753, 55.2391254901886, 45.024110823869705, 39.757376834750175, 40.58864302933216, 40.98020821809769, 40.24359494447708, 41.430499255657196, 40.59668339788914, 42.456888779997826, 42.40520395338535, 43.08664798736572, 42.164559066295624, 42.17745557427406, 40.174172669649124, 40.42877420783043, 42.17845872044563, 43.222524896264076, 42.0737287402153, 42.852496951818466, 40.812063440680504, 40.40232002735138, 38.33140455186367, 42.34896697103977, 41.61616109311581, 41.96225792169571, 43.05879928171635, 42.721510380506516, 42.108040899038315, 40.96276335418224, 41.59518621861935, 44.010952189564705, 43.83448205888271, 42.450755909085274, 51.37724071741104, 51.40291973948479, 51.30715727806091, 49.642337411642075, 50.52955560386181, 55.65526396036148, 52.607139721512794, 53.28134134411812, 55.31084284186363, 52.14235246181488, 50.226084887981415, 53.86693932116032, 56.2339311093092, 47.05704353749752, 53.48127901554108, 53.183040618896484, 48.58901873230934, 48.01013499498367, 48.64689342677593, 52.50796504318714, 53.677758872509, 53.526887968182564, 52.48955503106117, 47.38513693213463, 42.7452477067709, 40.61236895620823, 40.876713171601295, 39.781000167131424, 39.82406325638294, 42.09054283797741, 44.05873842537403, 45.01113831996918, 41.75974778831005, 44.55279551446438, 42.13781230151653, 42.65510894358158, 43.309810012578964, 42.146122455596924, 41.066190004348755, 44.418651312589645, 43.04654113948345, 42.247713804244995, 45.9417349845171, 47.36593656241894, 49.30590346455574, 48.505731001496315, 44.58077721297741, 40.097956359386444, 42.71525211632252, 41.009542644023895, 41.92509971559048, 43.01610857248306, 41.65968395769596, 53.343456611037254, 56.78596928715706, 56.79221995174885, 56.27947546541691, 55.075498670339584, 52.288108840584755, 46.41758345067501, 45.89274041354656, 43.547240272164345, 45.27851477265358, 51.80878736078739, 52.46759220957756, 53.00242491066456, 53.97036597132683, 53.75701121985912, 55.567036494612694, 57.3234124481678, 59.10664916038513, 58.111159577965736, 61.44127808511257, 67.39795625209808, 65.89110150933266, 17.583068199455738, 1.041983412578702, 5.752946399152279, 5.330821825191379, 0.7077190303243697, 0.13547557027777657, 20.452793911099434, 72.459816634655, 61.15624777972698, 53.11164624989033, 32.53765404224396, 34.30165238678455, 44.033256992697716, 56.76564037799835, 67.6933827996254, 44.40356232225895, 1.6390067827887833, 0.042989950597984716, 0.0947932165581733, 0.012838356997235678, 0.06964182437513955, 0.017993344445130788, 0.023706749780103564, 0.020918387781421188, 0.00457893102975504, 0.013971915213915054, 0.1458646878018044, 0.11054015049012378, 0.13188381301006302, 0.17364366125548258, 0.08020409237360582, 0.09529079688945785, 0.12767252570483834, 0.198637948196847, 0.2562074566958472, 0.21817296714289114, 20.58343280106783, 78.80832597613335, 67.58685171604156, 57.02591881155968, 36.97396919131279, 31.786576844751835, 46.54575817286968, 56.18620187044144, 65.26104211807251, 69.49282944202423, 30.805213004350662, 0.38455370406154543, 0.21579868829576299, 0.7236800144892186, 11.238942872732878, 58.98084171116352, 60.46327516436577, 62.57555902004242, 62.329412028193474, 61.72459468245506, 54.27157960832119, 49.99755375087261, 53.31894792616367, 56.11669220030308, 63.21961686015129, 57.741583809256554, 58.60418312251568, 49.38414886593819, 53.558008298277855, 53.268235847353935, 58.86338621377945, 57.35549412667751, 57.99585856497288, 46.50160454213619, 42.45801351964474, 43.826346695423126, 42.594433799386024, 42.743249014019966, 44.29716423153877, 42.53484159708023, 45.441507026553154, 45.117270424962044, 45.843331664800644, 44.22348618507385, 43.85751262307167, 44.21844765543938, 40.55905021727085, 44.90536339581013, 45.087696611881256, 44.058628231287, 45.28475783765316, 43.684941083192825, 42.80811533331871, 41.3641320168972, 43.65460351109505, 44.211809411644936, 43.017096519470215, 44.26399201154709, 43.74101847410202, 44.3079898506403, 43.060820773243904, 43.79357725381851, 44.948658272624016, 46.37809596955776, 44.50861908495426, 51.85925245285034, 53.75635385513306, 53.058950677514076, 52.821098640561104, 53.052798807621, 58.6514525860548, 55.90504735708237, 56.168886199593544, 56.93414993584156, 53.047467693686485, 52.487328350543976, 54.59017351269722, 59.54825386404991, 49.204034730792046, 57.03961327672005, 56.63021184504032, 51.644180193543434, 50.75685180723667, 51.58716805279255, 56.59202389419079, 56.93113289773464, 55.41607439517975, 56.99555084109306, 50.544773787260056, 45.988339483737946, 42.66898199915886, 44.87667493522167, 42.022401094436646, 41.940549686551094, 44.776656702160835, 45.3720885515213, 46.229911521077156, 43.36833827197552, 48.17632667720318, 46.04067027568817, 45.645597875118256, 44.19239245355129, 43.085200265049934, 44.58027943968773, 46.097766011953354, 47.648402005434036, 45.12158699333668, 49.56862136721611, 49.57902900874615, 50.420037880539894, 50.88865153491497, 46.81650884449482, 42.51931942999363, 45.84013983607292, 43.29341769218445, 45.58397278189659, 46.47908695042133, 43.77714693546295, 56.17047071456909, 60.36959499120712, 58.14878135919571, 57.64764904975891, 58.48559908568859, 53.86960297822952, 48.91774669289589, 48.36641527712345, 46.66672848165035, 47.02499605715275, 54.839930310845375, 53.84755276143551, 55.336046889424324, 56.67834386229515, 56.66777282953262, 58.807111233472824, 61.16554968059063, 60.84024153649807, 62.175094708800316, 66.06034442782402, 70.26767626404762, 67.16182172298431, 21.804364286363125, 5.020367559045553, 10.781075991690159, 10.265936683863401, 0.8140521089080721, 0.27626761933788657, 23.312699049711227, 77.17718750238419, 67.59033992886543, 62.31924757361412, 42.93637365102768, 38.91208939254284, 50.06292924284935, 67.28930488228798, 73.41358825564384, 55.20303122699261, 2.470175251364708, 0.15613933646818623, 0.15107622690265998, 0.18717853497946635, 0.10303497430868447, 0.1779043607530184, 0.11690628583892249, 0.11970474661211483, 0.1405970868654549, 0.10543102034716867], [0.012931039182149107, 0.02547276068071369, 0.06398284444003366, 0.06912864409969188, 0.031862474061199464, 0.04565542592899874, 0.04537306842394173, 0.005130691388330888, 0.05843973602168262, 0.1698968099663034, 12.418511677533388, 61.251846849918365, 45.876397490501404, 45.88097624480724, 23.540265038609505, 21.63614921271801, 33.1187454611063, 37.14408986270428, 58.11517596244812, 57.7337334305048, 20.434585288167, 1.5218792553059757, 10.380226001143456, 26.828581988811493, 3.4482788667082787, 50.27330495417118, 56.50786221027374, 59.89031910896301, 57.904857248067856, 54.13831315934658, 50.791730135679245, 53.20867784321308, 54.13343042135239, 56.291228234767914, 54.507383555173874, 56.86118625104427, 51.473003178834915, 50.491040870547295, 54.231598153710365, 53.148903250694275, 54.46291834115982, 53.150145784020424, 48.806762248277664, 42.02650487422943, 39.832324013113976, 38.311463221907616, 39.06028904020786, 39.085363894701004, 38.55567991733551, 39.06981132924557, 40.267875641584396, 41.35451853275299, 41.86300724744797, 41.638439297676086, 40.8950699865818, 40.08137404918671, 37.862122133374214, 37.78051011264324, 40.24291858077049, 38.965947702527046, 40.66811576485634, 38.39449256658554, 39.699699729681015, 38.653175085783005, 39.71793495118618, 39.37630668282509, 39.1092836111784, 40.41342683136463, 40.585481598973274, 43.30659918487072, 42.06653192639351, 39.93148349225521, 41.13595426082611, 40.589144602417946, 40.025669038295746, 42.98266276717186, 48.29052194952965, 49.20762553811073, 48.62102821469307, 50.05879506468773, 54.00119751691818, 54.89601530134678, 52.831802666187286, 53.719617426395416, 50.66425837576389, 49.46144811809063, 50.487936437129974, 51.549724861979485, 47.31324099004269, 52.28837102651596, 52.22840264439583, 47.23054602742195, 41.614375188946724, 40.00605069100857, 41.06437370181084, 40.16831338405609, 41.60434752702713, 40.34972324967384, 39.23933543264866, 39.765926375985146, 39.078820645809174, 39.30921368300915, 39.93543528020382, 39.41876940429211, 39.83848728239536, 40.50774157047272, 41.09639458358288, 42.484106719493866, 41.396567076444626, 41.45319923758507, 42.26255960762501, 40.69223307073116, 38.8953360915184, 41.95269003510475, 39.413939863443375, 39.36632841825485, 39.717269986867905, 42.20331318676472, 43.14697355031967, 46.252026334404945, 46.10412687063217, 43.558552265167236, 41.10525190830231, 39.72931534051895, 41.17469698190689, 40.50363399088383, 41.50563642382622, 41.88886106014252, 46.24008737504482, 55.6248389929533, 54.555378779768944, 53.250468000769615, 48.380660712718964, 42.35728472471237, 38.97866941988468, 40.43813310563564, 41.499837934970856, 49.338399320840836, 50.22712603211403, 52.026565074920654, 51.503899320960045, 50.72350099682808, 51.54766537249088, 52.33809895813465, 54.20322127640247, 55.22989958524704, 55.665952786803246, 56.52874208986759, 60.986864268779755, 67.41329222917557, 27.32467956840992, 0.9245650819502771, 7.329439530149102, 3.7454271968454123, 0.39702246780507267, 0.0770946271950379, 8.785457275807858, 65.84718346595764, 55.041197910904884, 52.22489543259144, 28.912184983491898, 13.552807811647654, 30.637195520102978, 46.4483617991209, 59.22663152217865, 42.26034052670002, 3.1671590264886618, 0.1988123232149519, 0.019345311156939715, 0.03424676448048558, 0.08471475463011302, 0.09272617942770012, 0.03318893686810043, 0.03950910730054602, 0.028840357808803674, 0.0893554040521849, 0.026714255000115372, 0.035935955675086007, 0.0485183756245533, 0.05373871659685392, 0.028874847266706638, 0.07515417077229358, 0.07678570822463371, 0.017475176937296055, 0.20542980171740055, 0.12234807625645772, 17.930386662483215, 71.16048395633698, 53.040194883942604, 53.982308730483055, 28.8019946962595, 19.75754901766777, 34.13091614842415, 47.90019929409027, 61.87708429992199, 64.00773257017136, 20.103742741048336, 1.0930799832567573, 7.244363520294428, 20.397649370133877, 6.638382012024522, 51.58063620328903, 56.832581385970116, 58.49661849439144, 61.73375219106674, 56.0658623278141, 53.13493140041828, 55.772396475076675, 56.36851988732815, 55.73963463306427, 56.28108277916908, 60.002158507704735, 53.38418282568455, 50.69923169910908, 54.78118546307087, 56.33628621697426, 55.75975075364113, 57.57331743836403, 49.87610846757889, 43.10109481215477, 41.43162779510021, 40.7597516477108, 40.20753487944603, 41.34830206632614, 40.52241638302803, 41.897889375686646, 42.312542125582695, 43.99200260639191, 44.87669013440609, 43.83668594062328, 43.84260602295399, 42.281038016080856, 41.06033451855183, 40.88134132325649, 41.4476553350687, 41.014448180794716, 42.405215352773666, 40.73691487312317, 41.02792225778103, 40.897266268730164, 41.5398345887661, 41.11617252230644, 40.248504281044006, 42.65166252851486, 42.88542218506336, 42.83224403858185, 42.740710750222206, 41.16843491792679, 42.78324946761131, 43.173078149557114, 41.86923511326313, 45.126310139894485, 49.34623830020428, 51.7425911128521, 52.03061565756798, 52.50994473695755, 55.55415898561478, 55.74574090540409, 55.54464429616928, 54.69282880425453, 52.14178629219532, 52.43123196065426, 54.861239567399025, 52.50705689191818, 48.65066282451153, 55.11880114674568, 54.38351020216942, 49.319335743784904, 43.111510053277016, 41.80902734398842, 42.46628947556019, 43.71031612157822, 42.1086298674345, 42.730626091361046, 42.502851113677025, 42.02766761183739, 40.89679129421711, 40.87514005601406, 41.488655135035515, 42.09920257329941, 41.34666055440903, 41.99533514678478, 43.3000635355711, 44.99338947236538, 43.39992597699165, 43.472566679120064, 42.50052943825722, 42.97703146934509, 40.630630776286125, 43.578607589006424, 40.55204339325428, 41.761389300227165, 40.91395877301693, 43.38227592408657, 45.563282892107964, 46.792296543717384, 46.540271267294884, 45.661393627524376, 43.480835035443306, 42.26307637989521, 42.41323672235012, 42.66231715679169, 42.37970732152462, 44.59677815437317, 47.95898213982582, 55.35069890320301, 57.013569474220276, 55.61134971678257, 50.17234057188034, 45.21851219236851, 41.12688794732094, 41.699125841259956, 43.19145396351814, 50.35736784338951, 52.18967892229557, 54.2277717590332, 55.15900298953056, 54.000813737511635, 53.41376043856144, 54.2119038105011, 55.48960044980049, 59.195268005132675, 60.35455919802189, 61.655016615986824, 60.52339553833008, 68.48142251372337, 28.816998191177845, 0.11114353881566785, 3.544522002339363, 7.341361865401268, 0.8321654400788248, 0.08362810200196691, 10.381459034979343, 70.86053565144539, 60.2113638818264, 55.49587391316891, 33.622446432709694, 19.983492493629456, 37.476454228162766, 52.86769174039364, 65.49662187695503, 52.06679731607437, 4.7463438380509615, 0.26158396038226783, 0.0629339819715824, 0.06578068976523355, 0.07233893004013225, 0.06479634219431318, 0.07204771129181609, 0.07769621952320449, 0.017712905391817912, 0.021150798747839872, 0.07535878088674508, 0.07659852373762988, 0.23066021036356688, 0.18411330180242658, 0.20247952721547335, 0.17294274730375037, 0.20947845478076488, 0.18569136009318754, 0.38922543462831527, 0.39683497161604464, 24.121679440140724, 82.82712712883949, 59.54067327082157, 62.303824201226234, 36.068382784724236, 32.70015612244606, 43.60573813319206, 53.28378461301327, 68.16465631127357, 69.62468236684799, 24.577366188168526, 1.5825319569557905, 14.61720859631896, 32.861373871564865, 5.9610474575310946, 55.11546492576599, 55.29910907149315, 59.566074907779694, 62.04376995563507, 58.850307315588, 54.79958787560463, 59.40897233784199, 58.691954612731934, 59.24224488437176, 58.760221749544144, 62.77325861155987, 53.83746810257435, 50.6101530790329, 56.18232227861881, 58.00948843359947, 57.038686126470566, 58.737472370266914, 51.78707912564278, 47.475670874118805, 44.558434411883354, 43.828387185931206, 44.240672662854195, 44.0396748483181, 43.37457373738289, 44.5362664014101, 45.25887742638588, 45.34045524895191, 48.150298073887825, 46.012665778398514, 46.43383517861366, 44.55597214400768, 43.16827900707722, 43.07111442089081, 44.71131920814514, 44.69392754137516, 46.05910688638687, 42.30518952012062, 42.84494675695896, 42.69973374903202, 44.26711544394493, 43.04833844304085, 42.93451935052872, 45.64381577074528, 44.50338676571846, 45.98549723625183, 45.25733470916748, 43.395442217588425, 45.64962565898895, 47.08809547126293, 44.60706040263176, 48.02626512944698, 53.28588590025902, 54.29273687303066, 55.32168745994568, 53.41737024486065, 57.2928012907505, 58.59806165099144, 57.1597970277071, 57.103480249643326, 56.05087973177433, 55.114978551864624, 54.9658327549696, 52.80312180519104, 52.55427695810795, 58.04482273757458, 57.438975647091866, 51.538576260209084, 45.64506970345974, 44.32610347867012, 44.202632904052734, 44.02796767652035, 43.14193122088909, 44.694497510790825, 44.50928404927254, 44.61391903460026, 42.15256690979004, 43.82586792111397, 43.92636872828007, 46.29402548074722, 44.25891928374767, 44.330522641539574, 46.58336475491524, 46.06173634529114, 45.96520632505417, 44.78237919509411, 45.56890279054642, 44.74226474761963, 43.31180490553379, 45.937840193510056, 41.75649896264076, 43.38750444352627, 43.489281982183456, 45.352694392204285, 48.17079797387123, 50.97143009305, 50.42789205908775, 48.18762347102165, 46.000464633107185, 44.91124548017979, 45.552480071783066, 43.037341833114624, 46.30113109946251, 47.45532676577568, 49.92567300796509, 59.27893951535225, 58.25499325990677, 57.34739676117897, 52.63569138944149, 46.808316484093666, 43.61278675496578, 43.668168783187866, 46.581947430968285, 53.18158149719238, 53.80957379937172, 55.95411792397499, 56.64202161133289, 56.705299615859985, 56.6116726398468, 57.22793497145176, 57.89041042327881, 61.98894649744034, 62.05097436904907, 63.97817015647888, 64.00074854493141, 68.36158454418182, 32.93734319508076, 3.071336718276143, 16.597118005156517, 11.474333591759205, 1.107234579976648, 0.24424102302873507, 11.108103543519974, 77.0273919403553, 64.39062282443047, 67.49963119626045, 40.30714273452759, 22.77194056659937, 44.1971991956234, 64.48730483651161, 73.13393846154213, 63.7356785684824, 6.9599649310112, 0.4056485096225515, 0.13842079817550257, 0.17320491839200258, 0.20967458956874907, 0.2060121501563117, 0.21065078093670309, 0.1289595730486326, 0.09758810760104097, 0.22121535701444373], [0.04983219594578259, 0.038305262132780626, 0.029703779837291222, 0.023374777847493533, 0.015829286348889582, 0.03052221658435883, 0.026487202339922078, 0.055543055714224465, 0.05188407842069864, 0.16752045310568064, 15.825920887291431, 58.935320153832436, 52.36163109540939, 49.45192962884903, 26.537052132189274, 33.38319607079029, 35.03611497581005, 43.552240803837776, 57.697183191776276, 56.73034407198429, 13.169421683996916, 0.8392465382348746, 15.080986060202122, 44.520858228206635, 1.7664361512288451, 14.522456880658865, 63.7518846988678, 59.39681679010391, 58.58758561313152, 57.96770967543125, 58.59813004732132, 55.339614897966385, 57.466706559062004, 55.154648423194885, 55.97709909081459, 49.4213792681694, 50.32761164009571, 52.93580308556557, 53.665584325790405, 54.045670330524445, 55.05483157932758, 51.60463571548462, 45.57050250470638, 38.25366072356701, 40.06243206560612, 38.6078093200922, 38.21893818676472, 37.92114816606045, 40.33967658877373, 40.40068991482258, 40.224356576800346, 43.82650248706341, 44.25599344074726, 43.246953785419464, 43.08882147073746, 40.59807412326336, 39.756073504686356, 39.193430095911026, 38.40441383421421, 37.2025915235281, 38.882682770490646, 38.80398519337177, 38.329238668084145, 38.59682410955429, 40.44360101222992, 40.40513947606087, 40.62366954982281, 40.44973388314247, 42.320130318403244, 40.34238204360008, 42.08404898643494, 41.031779050827026, 42.408129796385765, 41.185283213853836, 40.1094089448452, 39.49732258915901, 46.78574189543724, 45.61345919966698, 49.308350533246994, 49.46616366505623, 52.80104711651802, 54.089094400405884, 53.039149940013885, 51.824746504426, 51.424673572182655, 50.58028668165207, 51.314232498407364, 55.46677887439728, 49.13335092365742, 50.37963464856148, 53.32836002111435, 48.96878555417061, 45.40675409138203, 41.5122252702713, 40.29977113008499, 39.90380197763443, 42.44720309972763, 40.10899096727371, 39.14038114249706, 39.79811444878578, 39.5011717826128, 38.33469517529011, 39.48343813419342, 39.35048706829548, 41.90997652709484, 40.784640312194824, 39.80921745300293, 42.19268135726452, 41.025577783584595, 41.64658986032009, 41.289188638329506, 39.2636389285326, 39.93209145963192, 38.58114615082741, 39.97493036091328, 39.69180755317211, 39.211703315377235, 40.69513991475105, 41.44316017627716, 46.01038970053196, 42.361848279833794, 41.95973865687847, 42.591416761279106, 41.129973381757736, 39.07723993062973, 38.49808640778065, 40.764805376529694, 40.035727098584175, 42.25703850388527, 45.05009762942791, 45.98218761384487, 44.507661536335945, 42.6980846375227, 39.06972013413906, 40.73678568005562, 41.485972478985786, 46.11851669847965, 52.23321698606014, 52.02954411506653, 51.50469347834587, 52.04301819205284, 54.57999765872955, 50.512471720576286, 54.958715736866, 54.54389199614525, 59.546490758657455, 59.11088213324547, 61.71104080975056, 51.51668943464756, 57.0879390835762, 38.56975056231022, 0.5984653334598988, 3.5882282070815563, 3.5312806628644466, 1.2377793062478304, 0.12035715379170142, 5.296470718458295, 55.467565432190895, 63.41957353055477, 49.38514441251755, 35.597151070833206, 22.762900851666927, 30.5103013291955, 48.16577464342117, 49.119398072361946, 54.13811556994915, 5.734588634222746, 0.38702796504367143, 0.1502590926247649, 0.03615541245380882, 0.023216299632622395, 0.03420356035348959, 0.036051307688467205, 0.05215656907239463, 0.09534071374218911, 0.008097701320366468, 0.05869099382834975, 0.03247184409701731, 0.05920476782193873, 0.025587674826965667, 0.011595419200602919, 0.0018452472249919083, 0.03197833073500078, 0.014692353215650655, 0.046117342353682034, 0.13595887168776244, 20.82838475704193, 67.83952295780182, 59.41559158265591, 55.000741481781006, 32.08343781530857, 35.01349858939648, 36.95102982223034, 52.42603003978729, 62.38644316792488, 61.49762146174908, 14.69629755243659, 1.0090769408270717, 16.504361182451248, 42.65038579702377, 0.581166286719963, 17.25997533649206, 64.01273310184479, 59.202924594283104, 60.93012951314449, 59.06066782772541, 60.77221378684044, 58.501508831977844, 58.472387194633484, 58.71454440057278, 57.71277755498886, 49.86714854836464, 49.0205729752779, 54.83369864523411, 54.188386872410774, 54.4643584638834, 56.96152366697788, 54.631956070661545, 47.59375713765621, 41.26202009618282, 41.898333951830864, 40.3258491307497, 39.59055058658123, 40.612133368849754, 43.57437841594219, 42.16019690036774, 40.984631180763245, 43.93004693090916, 46.64978139102459, 45.5287579447031, 45.70373095571995, 43.168260008096695, 41.452541872859, 39.933535382151604, 40.75505129992962, 39.45176303386688, 41.38326779007912, 40.64000487327576, 39.620139598846436, 40.22401839494705, 42.73776590824127, 42.85050965845585, 41.38139069080353, 43.694664761424065, 42.75867238640785, 42.46680244803429, 42.66362428665161, 40.996338352561, 42.76228219270706, 43.396384567022324, 41.15235038101673, 42.62213431298733, 48.78102242946625, 48.19921664893627, 50.7549899071455, 51.628650426864624, 54.32760000228882, 56.18751659989357, 53.37811455130577, 54.763155430555344, 53.31427037715912, 52.6007104665041, 54.57984186708927, 57.450861409306526, 49.76292014122009, 52.047099173069, 53.90495628118515, 51.36212132871151, 47.80333869159222, 44.735368117690086, 42.123802453279495, 43.02843511104584, 43.65857049822807, 40.283849984407425, 42.25978195667267, 40.87340734899044, 42.06631153821945, 40.61314411461353, 41.657586470246315, 42.54176862537861, 43.89637693762779, 42.80089192092419, 42.65904173254967, 43.72030958533287, 43.93659397959709, 43.20499263703823, 41.62376068532467, 41.117985025048256, 42.67680957913399, 41.133119612932205, 41.76849111914635, 42.69454702734947, 39.996118023991585, 42.31910437345505, 42.98572540283203, 48.14839817583561, 44.00427594780922, 44.992682710289955, 44.083953872323036, 44.17535416781902, 41.43980115652084, 40.46719774603844, 42.033694088459015, 42.98966959118843, 43.609093353152275, 47.711326628923416, 49.23990100622177, 46.473033875226974, 44.93258513510227, 40.81087030470371, 42.680107802152634, 43.160018250346184, 48.05486999452114, 53.74646298587322, 52.316105738282204, 52.89604961872101, 54.50574964284897, 56.85200974345207, 53.28774020075798, 55.19252099096775, 56.95317931473255, 61.30112640559673, 60.389353930950165, 64.49593037366867, 56.77795551717281, 54.86899875104427, 41.9983521848917, 0.7416709803510457, 3.2203091494739056, 6.531661888584495, 2.437480380758643, 0.1178108154272195, 5.108339488506317, 62.242708280682564, 68.10735538601875, 55.72475843131542, 36.49178646504879, 23.900388814508915, 31.87037944793701, 54.65701952576637, 53.65951985120773, 62.426527217030525, 8.79870431497693, 0.4562558268662542, 0.0622342369024409, 0.05059703849838115, 0.06227976395166479, 0.09910761786159128, 0.04547839402221143, 0.07083076721755788, 0.06380210179486312, 0.027630540207610466, 0.17206345073645934, 0.14050397701794282, 0.11178808665135875, 0.12549987353850156, 0.045609564913320355, 0.12964850873686373, 0.08229527898947708, 0.19297019607620314, 0.15657249838113785, 0.3107433771947399, 28.03154043853283, 80.36376491189003, 64.93369728326797, 62.1700219810009, 33.68691757321358, 48.03161904215813, 47.165121138095856, 57.43119366466999, 65.81012025475502, 66.15807518362999, 17.332224659621716, 1.2976124393753707, 19.25763264298439, 47.974979281425476, 1.5576207311823964, 20.135906115174294, 64.11081343889236, 59.586707800626755, 63.04495543241501, 61.50258779525757, 63.75995546579361, 60.842441618442535, 62.09053784608841, 59.98188279569149, 59.056906029582024, 52.39063873887062, 50.17605297267437, 53.89826484024525, 56.66321687400341, 57.0214768499136, 59.13971118628979, 55.74589289724827, 51.30702808499336, 42.38695353269577, 44.390893802046776, 42.87050798535347, 41.80548593401909, 43.39993737637997, 45.81625431776047, 45.34188777208328, 43.77019330859184, 48.395882695913315, 49.79933738708496, 48.221935629844666, 47.53269821405411, 46.40932649374008, 43.89581076800823, 43.69219869375229, 43.050804510712624, 40.62250681221485, 43.739023581147194, 42.89817430078983, 43.18338319659233, 42.87406839430332, 44.424799382686615, 44.408806040883064, 43.66499975323677, 45.23331239819527, 45.651548355817795, 45.1431318372488, 46.80840387940407, 44.61538575589657, 46.19061782956123, 44.82955366373062, 43.50118674337864, 43.37001398205757, 52.247891798615456, 49.28951494395733, 53.611121848225594, 53.58317814767361, 58.441681042313576, 57.90745250880718, 56.747986525297165, 56.384099051356316, 54.5916972309351, 56.46079033613205, 55.94067044556141, 58.926804810762405, 53.24874669313431, 54.36441622674465, 56.10126122832298, 54.004723727703094, 50.07236033678055, 45.850304290652275, 45.00511184334755, 44.33776505291462, 46.72724023461342, 44.00098532438278, 42.250989228487015, 43.7839599698782, 44.32321183383465, 42.39435933530331, 43.86812165379524, 45.18691688776016, 46.28304786980152, 45.18268011510372, 44.38758037984371, 46.51575118303299, 46.158034577965736, 44.8723241686821, 44.23941493034363, 42.73183822631836, 44.708321169018745, 42.16658815741539, 42.91718848049641, 44.91965062916279, 42.115997672080994, 43.688782677054405, 45.52633747458458, 51.7342771589756, 45.09040966629982, 48.06805908679962, 47.275835797190666, 48.450318574905396, 44.60796095430851, 43.7879079580307, 44.05504122376442, 44.44085732102394, 45.639396607875824, 51.08621433377266, 50.96700333058834, 48.94462265074253, 46.53109855949879, 43.01707752048969, 44.556599110364914, 45.54080329835415, 50.558236464858055, 55.42989045381546, 55.74207790195942, 56.02998845279217, 56.15660905838013, 60.312358662486076, 55.836597830057144, 58.20908412337303, 58.514724522829056, 64.3679228425026, 64.1422301530838, 68.1896361708641, 58.06487426161766, 57.28517509996891, 43.06200250983238, 1.4344337163493037, 10.152299981564283, 8.786822352558374, 3.1879220623522997, 0.24489501840434968, 6.385438134893775, 66.0472959280014, 75.53920939564705, 66.1512279510498, 44.86648008227348, 34.496027156710625, 42.918431013822556, 64.15840968489647, 62.49108575284481, 71.97238638997078, 12.985352911055088, 0.7722485926933587, 0.1319827709812671, 0.16153761476743966, 0.11222775719943456, 0.1342147949617356, 0.21894996607443318, 0.24394072039285675, 0.1706509359064512, 0.16291913751047105], [0.059540953297982924, 0.030951756816648412, 0.09666569967521355, 0.0859850442793686, 0.003685349975057761, 0.0472949006507406, 0.05420498571766075, 0.022962659531913232, 0.05804113592603244, 0.2861342945834622, 18.213572166860104, 54.20296669006348, 49.99793753027916, 40.725120306015015, 20.1837170496583, 28.718393482267857, 28.64459004253149, 48.40104661881924, 57.46816188097, 57.40820109844208, 7.220883155241609, 0.48423758475109935, 9.440790060907602, 9.242428354918957, 1.202154674101621, 2.3859045607969165, 45.69602116942406, 57.7534581720829, 63.23219418525696, 56.02140471339226, 59.302243664860725, 56.5554166585207, 55.95527306199074, 53.07283893227577, 51.66870787739754, 49.39799912273884, 52.94119879603386, 51.54092073440552, 54.63862091302872, 53.48456583917141, 51.38573706150055, 50.50638064742088, 43.567041009664536, 39.98682752251625, 38.747288435697556, 38.08184154331684, 38.875812739133835, 37.77209356427193, 40.88535010814667, 40.32110318541527, 43.36102366447449, 42.37173534929752, 45.090215876698494, 44.814122691750526, 45.753979459404945, 41.42494775354862, 40.28336361050606, 38.14896874129772, 38.556979447603226, 38.636547178030014, 38.26067894697189, 40.76457738876343, 39.710833132267, 37.67275929450989, 39.16906580328941, 40.53663142025471, 38.867377191782, 39.436347261071205, 39.94023822247982, 40.46418830752373, 41.09648957848549, 38.80673244595528, 39.11293521523476, 39.50955793261528, 39.153752624988556, 39.286821484565735, 39.194570034742355, 44.15236920118332, 45.62850259244442, 47.88365118205547, 49.164262264966965, 49.45782691240311, 49.717911556363106, 52.690001875162125, 52.18637689948082, 52.33297683298588, 51.834652572870255, 55.35845808684826, 44.876249358057976, 50.76687566936016, 52.46787339448929, 52.013531774282455, 51.542710438370705, 50.48207335174084, 47.44607426226139, 39.13708671927452, 41.66602961719036, 40.032991245388985, 39.49959106743336, 39.60341289639473, 37.99746707081795, 39.26380231976509, 38.626223132014275, 38.459932655096054, 41.3479258865118, 41.173241659998894, 40.51267750561237, 39.79514300823212, 40.03757379949093, 42.39705719053745, 42.548376470804214, 39.578619226813316, 40.724888518452644, 40.4081717133522, 38.58669385313988, 39.78118635714054, 40.07341727614403, 40.02079389989376, 40.6679979711771, 42.46677964925766, 42.82831124961376, 40.0883162766695, 41.34634517133236, 40.055740624666214, 40.037425607442856, 39.21774499118328, 39.41873520612717, 41.061637848615646, 40.09284183382988, 39.64123226702213, 41.05591915547848, 40.24481847882271, 41.08892038464546, 41.781129240989685, 40.39043806493282, 43.575829938054085, 51.363584250211716, 53.547821044921875, 55.34654952585697, 52.61931046843529, 56.07611037790775, 53.85004922747612, 55.57968981564045, 55.05837678909302, 59.89973500370979, 58.588949739933014, 63.93090829253197, 59.289962723851204, 44.883632361888885, 41.36594831943512, 40.284982323646545, 1.7152257054112852, 0.9689207549672574, 9.146237466484308, 0.4932042129803449, 0.042418033044668846, 2.300325552932918, 51.32629685103893, 61.34399190545082, 53.63815739750862, 33.738640397787094, 22.14827623218298, 31.495451666414738, 42.18150235712528, 50.767153054475784, 54.86350044608116, 11.930609308183193, 0.5195783008821309, 0.039225640284712426, 0.060829303110949695, 0.03190414565324318, 0.025140829566225875, 0.053001263004262, 0.03767754620639607, 0.02673358794709202, 0.10599612127407454, 0.06282432965235785, 0.024828277782944497, 0.03423490124987438, 0.04909771465463564, 0.05535557436814997, 0.016576001944486052, 0.055301007960224524, 0.08924125431803986, 0.01663692484726198, 0.43361008109059185, 25.794264189898968, 65.73346316814423, 56.41493819653988, 45.87919034063816, 23.216416016221046, 32.686438858509064, 36.06069199740887, 54.63998503983021, 60.891713574528694, 62.62503996491432, 8.29635227099061, 0.5325040791649371, 12.08757508546114, 12.438586000353098, 1.7789036384783685, 3.042485578916967, 50.052745789289474, 54.98837694525719, 64.36244353652, 57.86437042057514, 61.12947441637516, 57.74188779294491, 57.839094176888466, 54.546152874827385, 52.527777180075645, 49.24737520515919, 51.85009114444256, 53.21167588233948, 56.236450374126434, 56.03109419345856, 53.77364292740822, 51.52971513569355, 44.64595891535282, 42.22212217748165, 40.4538718611002, 40.254496559500694, 41.39288127422333, 40.23807764053345, 42.85357229411602, 42.11387738585472, 45.39726220071316, 43.691328540444374, 46.68421134352684, 45.838239938020706, 47.548474967479706, 41.78345091640949, 42.54023350775242, 41.95742838084698, 40.768931955099106, 39.87815335392952, 41.19930066168308, 41.04888193309307, 40.68223960697651, 38.28141823410988, 42.22972936928272, 42.25466363132, 40.487956032156944, 39.890875071287155, 42.35519103705883, 41.140210032463074, 43.56470413506031, 41.43282473087311, 40.84178164601326, 42.6540981978178, 40.402658209204674, 40.573417246341705, 42.13257618248463, 45.38870885968208, 47.37936124205589, 49.603260308504105, 49.318735376000404, 50.847176760435104, 52.58657902479172, 52.91150338947773, 55.13967722654343, 52.43402861058712, 52.55648083984852, 55.794648081064224, 48.226077407598495, 52.3315367102623, 56.51436746120453, 51.89820796251297, 52.842563688755035, 53.040761053562164, 47.40625619888306, 41.190333142876625, 44.40944440662861, 42.39204525947571, 41.82635821402073, 41.18443205952644, 41.30585454404354, 41.15525722503662, 40.9737903624773, 41.90680369734764, 43.06432418525219, 41.076240465044975, 42.2302271425724, 41.798460111021996, 41.999488323926926, 43.808046877384186, 44.51143853366375, 41.13797575235367, 42.31077142059803, 41.835177540779114, 40.883700996637344, 43.153889179229736, 41.34218439459801, 41.661933436989784, 42.1272336691618, 44.68929558992386, 44.49812024831772, 42.703149765729904, 43.99704113602638, 42.77599945664406, 42.0618961751461, 42.17329479753971, 42.76924341917038, 43.39682914316654, 42.7556287497282, 41.0339867323637, 43.554684072732925, 42.51332715153694, 42.08028718829155, 44.01784881949425, 42.01005555689335, 47.01747626066208, 52.71957188844681, 54.680388271808624, 56.672298386693, 54.29759681224823, 57.809071987867355, 57.10704065859318, 58.23266185820103, 57.193132638931274, 61.17869317531586, 60.66155232489109, 65.0269290804863, 62.95471787452698, 51.32120132446289, 40.15937626361847, 42.45790712535381, 2.497914475388825, 1.9537334446795285, 8.217921629548073, 3.0801009479910135, 0.041282966412836686, 2.5014706095680594, 56.4826999604702, 67.36273214221, 59.24835495650768, 39.32734631001949, 29.58412952721119, 38.009649217128754, 52.904519364237785, 57.37549625337124, 64.01910915970802, 16.361201964318752, 0.5429027555510402, 0.04756768816150725, 0.06424631428672001, 0.07937509857583791, 0.0267587782946066, 0.02560239161539357, 0.032353831484215334, 0.08558644418371841, 0.09362620417959988, 0.09785444213775918, 0.15896884870016947, 0.15736481524072587, 0.20266439620172605, 0.22041935910237953, 0.10499967669602484, 0.0986804228159599, 0.14658828178653494, 0.24431813217233866, 0.5275836400687695, 33.48004907369614, 77.14523881673813, 63.77422749996185, 55.61873272061348, 29.534783475100994, 40.855001136660576, 39.42586362361908, 60.60810059309006, 66.58072650432587, 68.75467345118523, 9.615007862448692, 0.5660089000593871, 12.456667330116034, 12.08240071311593, 2.218697383068502, 4.3236317206174135, 52.87860855460167, 56.261320039629936, 64.2919497191906, 61.50263339281082, 64.18611779808998, 59.26437869668007, 57.959342524409294, 54.95344161987305, 51.896745041012764, 49.715760871768, 52.755894139409065, 55.03460146486759, 57.220787554979324, 57.837224677205086, 57.28090412914753, 54.982654452323914, 47.27607138454914, 44.30071324110031, 43.7091039866209, 44.342879578471184, 43.27014394104481, 42.011415883898735, 46.19124859571457, 44.31028872728348, 48.73546667397022, 46.600976809859276, 49.20697957277298, 49.15217511355877, 51.159896180033684, 44.06587064266205, 44.47811812162399, 43.692282289266586, 42.010112553834915, 41.62260174751282, 43.451686799526215, 44.73103255033493, 44.36239913105965, 40.252756252884865, 44.030760526657104, 43.31305503845215, 41.65473282337189, 40.93045748770237, 44.646338894963264, 43.43974784016609, 45.5874989926815, 43.933170363307, 42.71221227943897, 45.71680225431919, 43.17626617848873, 41.72200061380863, 42.8623004257679, 47.403098568320274, 49.092187732458115, 53.41846078634262, 51.30816802382469, 53.663722425699234, 54.77864719927311, 55.80351300537586, 57.863344475626945, 55.632499381899834, 57.3704881221056, 58.38651180267334, 50.37055313587189, 56.927397698163986, 57.95725263655186, 55.772799253463745, 55.68278208374977, 55.640364959836006, 50.81429332494736, 43.10095801949501, 46.756821647286415, 45.36586068570614, 44.0508196502924, 44.066030234098434, 43.08854028582573, 43.674495443701744, 41.93959213793278, 44.08266194164753, 44.71627414226532, 45.67714378237724, 43.718683272600174, 43.909980207681656, 43.34395118057728, 45.85960619151592, 46.349054127931595, 42.57944740355015, 44.76802736520767, 44.75636199116707, 42.44587317109108, 44.32323843240738, 43.80073606967926, 44.51323203742504, 44.668480306863785, 46.648508459329605, 46.42007991671562, 43.20624276995659, 47.49949559569359, 46.156799644231796, 45.26249103248119, 43.995912596583366, 44.072942063212395, 46.11093610525131, 45.29332257807255, 41.60611443221569, 44.70335863530636, 43.9422594755888, 44.44102831184864, 45.36070056259632, 44.654527455568314, 48.855718821287155, 54.442186653614044, 57.24106326699257, 59.43270966410637, 58.20441797375679, 59.62295025587082, 59.48317475616932, 61.46967776119709, 60.019299387931824, 65.40737226605415, 61.121890023350716, 68.43602254986763, 65.01059755682945, 54.13792558014393, 42.584717720746994, 45.84208533167839, 2.570789339952171, 4.109823843464255, 21.648981124162674, 2.6150560146197677, 0.16420015861513093, 2.9060574620962143, 61.60115450620651, 72.84505516290665, 67.71928980946541, 43.75185549259186, 33.885388523340225, 44.64288108050823, 61.39252670109272, 66.00704088807106, 75.21773144602776, 21.31627667695284, 0.754544927040115, 0.08614528138423339, 0.16753813106333837, 0.1360159576870501, 0.13506168936146423, 0.10730172230978496, 0.15541167551418766, 0.17349027417367324, 0.2114347560564056], [0.07892714565969072, 0.05056538218923379, 0.04552448881440796, 0.07417671775328927, 0.026009658140537795, 0.05718880158383399, 0.17745751363690943, 0.08637274222564884, 0.043878078722627833, 0.48733901989180595, 30.39086613804102, 59.550073966383934, 52.40623690187931, 43.813431188464165, 25.90210620313883, 29.604473635554314, 31.011578030884266, 49.26727093756199, 56.7505893856287, 54.787458926439285, 7.065831525251269, 0.6674256362020969, 4.861964508891106, 5.546844033524394, 1.2661483464762568, 0.18806513427989557, 45.43243311345577, 37.768601551651955, 43.95779304206371, 58.13729837536812, 56.49840071797371, 57.110658064484596, 55.57789631187916, 52.683888003230095, 50.35347305238247, 50.97830772399902, 52.086541056632996, 53.495152071118355, 55.59724107384682, 52.08265386521816, 51.98908008635044, 45.422230660915375, 39.91936594247818, 38.27600732445717, 37.348712682724, 39.28435921669006, 37.57754400372505, 38.51899668574333, 39.596223682165146, 40.62811151146889, 42.305622696876526, 42.863831743597984, 44.565912410616875, 44.2818358540535, 43.82286608219147, 41.993089467287064, 40.25888912379742, 39.505024775862694, 39.34595011174679, 37.31027014553547, 37.756415605545044, 39.319792315363884, 38.73230583965778, 39.827752858400345, 39.69734385609627, 40.340121164917946, 40.64783625304699, 42.0811003446579, 40.85499733686447, 40.10535076260567, 38.65204654633999, 39.20925244688988, 38.98789532482624, 42.107311338186264, 39.20637220144272, 39.40957389771938, 39.74797993898392, 37.26024203002453, 39.449802339076996, 40.63709422945976, 42.242044508457184, 40.73745444417, 46.45311914384365, 50.4846116155386, 49.55663301050663, 52.43137255311012, 50.269398763775826, 58.313274532556534, 46.54717929661274, 44.89283546805382, 56.181965097784996, 50.70614352822304, 54.5139230042696, 52.66692951321602, 51.11396424472332, 41.39372102916241, 40.110066309571266, 40.68097047507763, 40.92508837580681, 41.958515122532845, 39.792946726083755, 40.651373863220215, 40.5270217359066, 40.22766999900341, 40.21839089691639, 42.12884858250618, 39.65859733521938, 40.671611577272415, 40.29419302940369, 40.528002083301544, 41.6532889008522, 41.27238214015961, 40.40676198899746, 40.21192744374275, 41.69969581067562, 41.02746248245239, 39.525357484817505, 39.17110249400139, 40.67171797156334, 39.56206351518631, 41.479444429278374, 41.464902609586716, 40.96501663327217, 39.8775339871645, 39.93982404470444, 37.56242461502552, 37.81823068857193, 40.83846442401409, 41.943346336483955, 42.39695839583874, 41.63155406713486, 41.39094717800617, 41.08477860689163, 40.9957379847765, 43.08864668011665, 53.31584729254246, 53.67836304008961, 58.44046130776405, 56.04466326534748, 53.57792682945728, 56.63136698305607, 57.08055607974529, 57.320277616381645, 55.18406264483929, 60.312408059835434, 60.265845358371735, 62.0439637452364, 65.85018530488014, 61.985127702355385, 32.24109135568142, 45.019539669156075, 4.675816297531128, 1.100043822079897, 7.1272870525717735, 1.8135297554545105, 0.07558367389719933, 1.5624430286698043, 48.233091831207275, 61.65747128427029, 57.14997835457325, 43.720347583293915, 24.446617104113102, 15.16574526205659, 35.64557947218418, 55.822595581412315, 55.14018639922142, 16.12129993736744, 0.32761085021775216, 0.00662958432258165, 0.03577780400519259, 0.015526241477346048, 0.02670826215762645, 0.11767509888159111, 0.006493323689937824, 0.03982377049396746, 0.008562925868318416, 0.03910831415851135, 0.041297894713352434, 0.07018968521151692, 0.03359546681167558, 0.08870098565239459, 0.013806366187054664, 0.03195123121258803, 0.1059689067187719, 0.06922317887074314, 0.6661443330813199, 39.434948936104774, 71.06556504964828, 58.61465536057949, 48.78699190914631, 29.96603563427925, 33.50124813616276, 36.594829335808754, 53.448718562722206, 61.20412901043892, 57.0865673571825, 7.720632813870907, 0.9803894895594567, 6.94388466887176, 10.210069231688976, 1.9386926642619073, 0.4095769941341132, 47.84244619309902, 40.08151464164257, 46.1056961864233, 59.636538326740265, 58.368181586265564, 58.38531866669655, 54.51953150331974, 52.21770241856575, 50.50959527492523, 50.74392110109329, 53.21921467781067, 56.983513087034225, 56.32245495915413, 53.25147494673729, 55.29715217649937, 47.03274764120579, 41.52678608894348, 41.622787937521935, 39.23001453280449, 40.05598001182079, 40.597162172198296, 42.631800994277, 42.73649677634239, 44.229455664753914, 43.301697447896004, 44.992287531495094, 46.09190292656422, 46.45474545657635, 46.87585026025772, 43.28594349324703, 42.03792706131935, 40.90215660631657, 39.85625132918358, 39.68377098441124, 40.70172876119614, 42.131246253848076, 41.01928912103176, 41.58483177423477, 41.51538670063019, 42.97830820083618, 41.3538383692503, 42.73699834942818, 43.17432068288326, 41.66270099580288, 40.20533099770546, 40.49758471548557, 41.009645238518715, 43.00856217741966, 41.889613419771194, 41.07101574540138, 40.30161403119564, 39.297350719571114, 41.6507962346077, 42.110981941223145, 43.77799428999424, 43.41740503907204, 49.92870904505253, 52.40815959870815, 52.46962510049343, 53.48296232521534, 52.68310904502869, 59.36067312955856, 48.22242200374603, 47.96418406069279, 56.30413994193077, 51.548953503370285, 54.84359711408615, 53.75258065760136, 53.3269464969635, 44.54264625906944, 41.86734661459923, 42.91968494653702, 44.873281717300415, 42.618615701794624, 41.15484304726124, 41.71044543385506, 42.62848757207394, 40.60701884329319, 41.62691831588745, 41.874942407011986, 41.62863202393055, 41.785039231181145, 41.958480924367905, 42.60006509721279, 43.28149393200874, 43.185351490974426, 42.03844003379345, 41.84664912521839, 41.84841603040695, 41.71673409640789, 43.7396277487278, 41.228946670889854, 42.798764035105705, 40.70957534015179, 44.69343736767769, 43.95679369568825, 42.56970852613449, 42.877552807331085, 42.81645588576794, 40.38589350879192, 40.91918349266052, 43.21103811264038, 42.857322692871094, 45.03823846578598, 43.28039579093456, 41.58990450203419, 41.99883475899696, 42.49304763972759, 45.93137674033642, 52.97588333487511, 55.04389576613903, 59.56200152635574, 57.02715754508972, 54.967322275042534, 58.097985684871674, 58.005221262574196, 57.82012939453125, 57.333637699484825, 63.211234509944916, 61.16363078355789, 64.19775277376175, 64.89074438810349, 61.42153434455395, 38.291388899087906, 45.34091502428055, 6.458380920812488, 1.4642009628005326, 16.187479086220264, 7.399076018482447, 0.06406383501598611, 1.7094389721751213, 53.292056769132614, 67.57300525903702, 63.25793780386448, 39.65633265674114, 28.620924912393093, 23.65588143467903, 41.97503663599491, 63.00396703183651, 64.86658528447151, 21.75806377083063, 0.5138930934481323, 0.01755675380991306, 0.04150536209635902, 0.0148956914745213, 0.0807304606132675, 0.08638339204480872, 0.030339837503561284, 0.05188953691686038, 0.05510760427569039, 0.16727186331991106, 0.112337921600556, 0.1565672439755872, 0.11620684133959003, 0.23130077286623418, 0.11674670924548991, 0.3652874019462615, 0.2603739924961701, 0.18638639623532072, 0.9843415743671358, 50.86022146046162, 79.83973503112793, 68.41262340545654, 58.50665755569935, 37.70642548799515, 41.831921115517616, 42.1937794983387, 62.483242973685265, 65.01554489135742, 65.10799393057823, 9.030845258384943, 0.8458949939813465, 7.396916309371591, 12.670787740498781, 4.512326270341873, 0.7060494949109852, 53.54022145271301, 46.75814017653465, 49.498412534594536, 59.28418703377247, 59.22098882496357, 60.53420975804329, 55.53234435617924, 52.634965628385544, 52.04651020467281, 52.40283228456974, 55.04312440752983, 57.762851268053055, 59.753769636154175, 56.19681090116501, 55.84809601306915, 49.18565891683102, 44.57461014389992, 44.41602945327759, 39.84876953065395, 42.61125549674034, 42.95524723827839, 44.43311333656311, 45.51693297922611, 45.98504886031151, 47.824062779545784, 46.65337219834328, 50.518893375992775, 49.64228801429272, 49.472634717822075, 45.958119705319405, 43.02532307803631, 42.91841581463814, 42.651521936059, 41.60754695534706, 42.67337076365948, 44.716878309845924, 43.04719090461731, 43.441860526800156, 43.51820223033428, 44.11337949335575, 44.62350971996784, 45.66429667174816, 45.83219066262245, 45.0707571208477, 43.40046554803848, 41.98807753622532, 43.2541885972023, 44.50473949313164, 43.780631348490715, 43.69395039975643, 44.41469192504883, 40.57560592889786, 43.510469645261765, 43.774791061878204, 47.034864127635956, 45.914395451545715, 52.578816041350365, 54.76313263177872, 55.31083524227142, 56.002177745103836, 55.25122784078121, 61.89586669206619, 51.148063614964485, 49.7881355881691, 58.341263830661774, 53.63252989947796, 59.902429059147835, 54.1394454985857, 54.647622630000114, 45.998287349939346, 46.273943558335304, 45.4427495598793, 46.27916447818279, 46.308073326945305, 43.066429272294044, 44.694721698760986, 44.24792267382145, 44.110708236694336, 45.14305204153061, 44.71939757466316, 42.05455496907234, 43.736819699406624, 43.57144117355347, 46.08685299754143, 46.10858403146267, 44.74176697432995, 43.46662759780884, 43.1125245988369, 44.782006815075874, 45.58843374252319, 45.44101685285568, 43.129483088850975, 45.316816717386246, 42.180981785058975, 45.93522593379021, 45.71845516562462, 46.64600059390068, 44.208970963954926, 44.77253772318363, 42.57312074303627, 42.87513613700867, 45.807146206498146, 46.2989804148674, 49.2535612732172, 46.45207799971104, 45.113892406225204, 45.65724425017834, 43.4940355271101, 48.21717448532581, 55.4213485121727, 55.15356548130512, 63.306419402360916, 61.6356148570776, 57.78222642838955, 61.826710402965546, 59.711819887161255, 61.867569610476494, 59.438109174370766, 66.85063362121582, 63.01627837121487, 66.99835449457169, 64.88705098628998, 64.11982655525208, 37.995517775416374, 52.507246881723404, 6.597022656351328, 3.6516396794468164, 19.648869149386883, 5.589403649792075, 0.3127099497942254, 1.7061807657591999, 58.68264131247997, 71.5878926217556, 73.0548495054245, 52.8243550658226, 36.69420160353184, 25.086489468812943, 48.63193742930889, 69.728963971138, 76.21058776974678, 27.98730131238699, 0.6459896801970899, 0.15171223261859268, 0.14447096415096894, 0.16084899078123271, 0.18017690599663183, 0.23631126416148618, 0.11700945178745314, 0.18806630687322468, 0.15743276628199965], [0.010238625745842, 0.040870907469070517, 0.048981898798956536, 0.04761074385896791, 0.050051266807713546, 0.023665553162572905, 0.09220653504598886, 0.03605310739658307, 0.02914885561040137, 1.0081912321038544, 34.3548609316349, 61.03100650012493, 47.69254423677921, 45.89955724775791, 15.867959931492805, 20.3709140047431, 38.18895399570465, 51.234269589185715, 56.30420833826065, 55.7840808480978, 3.253521742299199, 0.07149592449422926, 1.3423251151107252, 8.436845932155848, 3.0186138348653913, 2.453892887569964, 59.17236663401127, 49.91669028997421, 56.110798716545105, 54.51487295329571, 58.46487119793892, 56.48271135985851, 60.60742422938347, 55.34183777868748, 55.90847097337246, 52.138419672846794, 57.61910878121853, 53.546346724033356, 57.3496500402689, 51.481149941682816, 45.092514753341675, 39.00486521422863, 39.07989218831062, 38.25911343097687, 38.21723207831383, 37.876736149191856, 39.98665273189545, 38.53022888302803, 41.92363679409027, 40.68112626671791, 42.86266900599003, 41.592568159103394, 43.82693186402321, 42.972034737467766, 40.59531927108765, 41.108637526631355, 38.65172356367111, 37.325469329953194, 40.250046998262405, 38.79533685743809, 39.666531309485435, 37.784055322408676, 39.886535704135895, 40.18995322287083, 40.05174323916435, 38.88923741877079, 37.86572813987732, 36.52715876698494, 42.01089911162853, 39.15647327899933, 39.01142746210098, 37.22878731787205, 39.13476884365082, 38.870067447423935, 38.84878858923912, 39.638181030750275, 38.01359720528126, 38.94024208188057, 40.050527304410934, 39.007012099027634, 42.33276084065437, 41.76914468407631, 48.75049486756325, 51.91642038524151, 52.18076840043068, 51.96487158536911, 54.4511541724205, 47.44002878665924, 31.98457472026348, 43.67923378944397, 50.41192911565304, 53.94915550947189, 51.70868173241615, 53.35782364010811, 51.43998675048351, 42.3297818005085, 40.28207167983055, 40.238358825445175, 39.059073105454445, 40.05046650767326, 39.78107236325741, 37.73480236530304, 40.46145625412464, 38.3943747729063, 38.44978719949722, 40.99399007856846, 40.719538405537605, 39.23577502369881, 42.011792063713074, 41.44745014607906, 44.657555893063545, 38.23970407247543, 40.49097307026386, 40.89022524654865, 41.80414840579033, 41.21443524956703, 41.252699196338654, 38.04559148848057, 41.03215143084526, 39.278613924980164, 40.041396394371986, 39.605844765901566, 40.11444367468357, 39.48674775660038, 40.63884973526001, 36.253725439310074, 38.24510358273983, 36.651974469423294, 40.81905506551266, 38.14992628991604, 42.301146537065506, 38.837130814790726, 40.84614001214504, 42.90914811193943, 47.79244087636471, 52.67221122980118, 56.42560042440891, 54.96253453195095, 51.95614345371723, 57.35502675175667, 57.13770121335983, 56.3735394179821, 58.907775431871414, 57.90075346827507, 58.09314474463463, 55.130063742399216, 57.20086142420769, 50.00542692840099, 37.930423468351364, 36.23108625411987, 56.09126776456833, 11.529787816107273, 0.5994601675774902, 9.770466070622206, 8.79028681665659, 0.09224494860973209, 0.8495107968337834, 46.65045015513897, 60.51471680402756, 57.53709018230438, 52.31753446161747, 45.36838375031948, 19.26716063171625, 35.862285643815994, 48.15505541861057, 59.17759895324707, 27.520093582570553, 0.907951898407191, 0.09789767223992385, 0.022590283224417362, 0.057941877385019325, 0.0663192143838387, 0.023574033366458025, 0.06801218682085164, 0.03770486837311182, 0.013635867962875636, 0.08115864271530882, 0.03973089813371189, 0.04989215776731726, 0.020796330463781487, 0.017002089334710035, 0.07602746336488053, 0.03783341948292218, 0.00983375543000875, 0.04265326417225879, 1.1613364331424236, 44.344638884067535, 67.6645727455616, 53.48099023103714, 51.456177681684494, 21.608594991266727, 30.842629596590996, 37.46058627963066, 55.62718726694584, 61.24385207891464, 58.53454425930977, 4.091632319614291, 0.31701473286375403, 2.439862615428865, 15.326543133705854, 0.939028412103653, 2.4153028707951307, 60.85929751396179, 50.53684741258621, 57.7281591296196, 56.309330463409424, 59.60302792489529, 58.34101304411888, 62.33601987361908, 55.95903106033802, 57.39289551973343, 52.98704333603382, 59.098453000187874, 56.0783826559782, 58.02016206085682, 52.44119502604008, 47.22249425947666, 42.04662099480629, 41.23270086944103, 39.84988287091255, 40.78733056783676, 38.67069214582443, 41.335485354065895, 41.092670783400536, 44.328250363469124, 43.17329093813896, 45.119861885905266, 44.11901079118252, 46.603024899959564, 45.639715790748596, 44.2273885756731, 42.75014564394951, 39.62350621819496, 40.007464215159416, 42.22425766289234, 40.38348063826561, 40.03785498440266, 40.003288239240646, 41.48370400071144, 41.731994077563286, 41.492899507284164, 41.4113786816597, 40.45526258647442, 40.89922696352005, 42.27080136537552, 40.59477210044861, 39.16271634399891, 39.45210121572018, 40.87102107703686, 39.88892577588558, 40.176798328757286, 41.612334698438644, 41.031931042671204, 40.12090712785721, 40.93007370829582, 40.54150275886059, 43.78194607794285, 42.75800362229347, 48.42498533427715, 53.452738747000694, 54.728976264595985, 53.5919176787138, 55.92585124075413, 46.91669046878815, 34.11299630999565, 45.40894657373428, 52.45460830628872, 55.04956506192684, 53.99351812899113, 55.09599097073078, 53.560504764318466, 43.468778282403946, 41.18116803467274, 41.7196561396122, 40.44755280017853, 42.670178934931755, 41.80426999926567, 40.06463974714279, 41.59147001802921, 39.80622701346874, 41.178945153951645, 41.60697318613529, 42.97973312437534, 40.920034646987915, 43.927653059363365, 43.25347803533077, 44.51693303883076, 41.75479285418987, 43.16369265317917, 42.30449415743351, 44.18461047112942, 42.91048564016819, 42.19905361533165, 39.71265323460102, 42.0162758231163, 40.71097746491432, 41.824519112706184, 41.82653680443764, 41.06247000396252, 41.851626858115196, 42.966304644942284, 38.14602389931679, 38.76517787575722, 39.82630133628845, 41.096607372164726, 41.046845242381096, 43.474428579211235, 40.87952882051468, 42.785232961177826, 43.48616234958172, 50.819111466407776, 54.441483691334724, 57.226988822221756, 56.81443735957146, 54.92468096315861, 58.40679511427879, 59.53873537480831, 57.42753066122532, 60.54627791047096, 61.62343271076679, 61.20765142142773, 58.63822169601917, 58.03928263485432, 49.799151197075844, 38.89151729643345, 39.70898263156414, 57.44293123483658, 13.319095652550459, 0.8664084901101887, 13.774701654911041, 13.892615027725697, 0.1560874455026351, 1.2376955919899046, 48.435818552970886, 66.77909106016159, 63.220616206526756, 50.73992371559143, 43.83181840181351, 22.498987913131714, 41.520391032099724, 55.78830622136593, 70.43168306350708, 33.93463008105755, 1.1406322941184044, 0.08097605212242343, 0.10251406085444614, 0.03651445236755535, 0.06716604941175319, 0.06403738487279043, 0.029812320790369995, 0.05772387892648112, 0.01990232824027771, 0.15326707653002813, 0.12128937290981412, 0.0937865006562788, 0.1215601603325922, 0.15981945383828133, 0.1904184400336817, 0.22197982849320397, 0.12220284537761472, 0.12813976703910157, 2.1435238793492317, 52.59140856564045, 77.58292213082314, 58.22816289961338, 60.643146112561226, 24.781215749680996, 28.605106361210346, 49.137112721800804, 63.99346813559532, 64.86210912466049, 66.65936708450317, 3.991841124370694, 0.32294787699356675, 3.2791573042050004, 15.510230977088213, 7.314247470349073, 3.9867436978965998, 63.419755920767784, 51.94487325847149, 61.67930491268635, 59.28238593041897, 63.62236484885216, 60.95839999616146, 64.53039452433586, 57.21995919942856, 59.90405537188053, 56.11269101500511, 62.683663219213486, 57.94475130736828, 62.84531034529209, 55.05580432713032, 50.97731977701187, 43.43764275312424, 43.55943001806736, 42.644959688186646, 42.015823647379875, 41.63131467998028, 44.00822773575783, 42.93590247631073, 47.44964987039566, 45.544230714440346, 47.53112889826298, 46.55736654996872, 49.13418307900429, 48.70093412697315, 45.25441266596317, 46.63768284022808, 42.32937902212143, 42.33657203614712, 45.29106169939041, 42.169259414076805, 42.032519951462746, 39.80312258005142, 45.41430048644543, 43.63645948469639, 43.936536982655525, 42.74253085255623, 41.328265741467476, 41.66746973991394, 45.14579929411411, 43.649576380848885, 42.76334993541241, 41.28347374498844, 43.31437736749649, 42.36299201846123, 41.22542425990105, 44.95390959084034, 42.405952513217926, 42.310672625899315, 43.81647862493992, 40.62921345233917, 46.39755852520466, 45.67700318992138, 52.50022865831852, 55.54780952632427, 58.099676594138145, 56.802988573908806, 59.03366267681122, 50.28254225850105, 39.07676115632057, 48.429222106933594, 52.47854322195053, 57.412966042757034, 54.99959774315357, 57.56792172789574, 55.70512868463993, 46.907658353447914, 44.42047901451588, 45.84844999015331, 42.63640254735947, 45.30415579676628, 42.89804890751839, 42.44680032134056, 44.32469755411148, 42.220153883099556, 42.56315387785435, 44.727065563201904, 45.00075727701187, 43.61999496817589, 46.135266199707985, 46.11600883305073, 48.38864408433437, 43.14801849424839, 45.07983863353729, 45.77195629477501, 45.11321984231472, 45.09621575474739, 45.39586767554283, 41.91740892827511, 45.116259679198265, 43.21257323026657, 45.29449671506882, 44.39308628439903, 44.10284645855427, 44.83672387897968, 44.57921929657459, 40.76899655163288, 42.69895479083061, 40.8928357064724, 45.07673420011997, 43.68682578206062, 46.68707258999348, 42.718310952186584, 44.43827345967293, 47.194626554846764, 54.339474365115166, 56.45821787416935, 59.560846388339996, 58.66873785853386, 57.69881710410118, 60.606922656297684, 61.45951330661774, 59.815398529171944, 62.16833107173443, 63.24776574969292, 62.406897470355034, 60.99237397313118, 59.983592703938484, 53.81639443337917, 43.58693674206734, 41.24674491584301, 58.27179975807667, 16.647193618118763, 2.217852878384292, 17.340449318289757, 14.163250755518675, 0.17536300962092355, 1.1333529534749687, 54.97796930372715, 71.54740199446678, 73.78809615969658, 65.48799633979797, 55.19206501543522, 29.78959210216999, 51.17536894977093, 65.57941183447838, 78.36318746209145, 41.631166487932205, 1.706406141165644, 0.25889806856866926, 0.17304819164564833, 0.10352678815252148, 0.14636591949965805, 0.19290656433440745, 0.13364308892050758, 0.20676266925875098, 0.08353365628863685], [0.09643662837333977, 0.0248957352960133, 0.020729010248032864, 0.020245339619577862, 0.08037739869905636, 0.023486231730203144, 0.0231510091907694, 0.13500396511517465, 0.04187071026535705, 1.928694925736636, 46.187661588191986, 61.53440348803997, 50.027568340301514, 48.472064808011055, 20.5012147128582, 26.988321617245674, 48.45423996448517, 54.843061342835426, 56.226924285292625, 55.41333094239235, 3.902691970579326, 0.3326490829931572, 2.7407580194994807, 17.621197253465652, 0.18695606879191473, 15.216233152896166, 26.802840270102024, 24.813686907291412, 62.020070627331734, 54.45939972996712, 58.609924614429474, 53.042030185461044, 59.91449721157551, 56.493981555104256, 56.59465715289116, 54.62282136082649, 55.497158244252205, 51.809931099414825, 50.34477151930332, 43.229717910289764, 39.77893307805061, 38.523586839437485, 40.30038669705391, 36.71549566090107, 38.094434067606926, 36.81370139122009, 37.70191133022308, 37.31742896139622, 41.07427217066288, 40.27915723621845, 41.649166122078896, 40.249522626399994, 41.1661284416914, 40.41992448270321, 39.74361017346382, 39.79419305920601, 40.976005643606186, 37.138428166508675, 40.06584048271179, 38.87490838766098, 37.67069600522518, 35.69916419684887, 39.10587899386883, 36.62632204592228, 39.32644575834274, 38.48020076751709, 39.07953880727291, 37.627195939421654, 38.82668897509575, 37.41943068802357, 37.68295794725418, 37.57743760943413, 40.560520738363266, 37.809084579348564, 39.528100937604904, 37.61851720511913, 40.92275910079479, 39.22456942498684, 39.45022791624069, 38.35860349237919, 42.10464388132095, 40.41548632085323, 48.80633667111397, 51.48358181118965, 53.366000801324844, 51.46447643637657, 53.72802257537842, 47.516822665929794, 29.06864158809185, 46.65122531354427, 54.62056428194046, 52.246998846530914, 50.88932029902935, 53.77204321324825, 46.84738978743553, 40.174997225403786, 40.031516924500465, 41.49846240878105, 40.1338492333889, 39.487712904810905, 39.81131114065647, 39.088323935866356, 38.825313448905945, 39.031478986144066, 38.09515222907066, 39.99923385679722, 40.117988884449005, 39.14913587272167, 40.52982598543167, 40.71419969201088, 43.27325597405434, 40.0300882011652, 40.2984070032835, 40.69190628826618, 40.54250210523605, 39.99974682927132, 41.0916106402874, 38.46521437168121, 40.512867495417595, 39.82327289879322, 39.92024749517441, 38.97570177912712, 40.443923994898796, 39.029738679528236, 40.31702980399132, 36.52400493621826, 38.485410287976265, 38.80936570465565, 40.0010197609663, 39.70937021076679, 39.64774891734123, 39.50623691082001, 43.43109950423241, 41.480344980955124, 52.601421028375626, 54.97263818979263, 57.637309804558754, 51.695751026272774, 57.195473313331604, 57.664485946297646, 59.81446757912636, 59.43519473075867, 59.66407924890518, 56.39740973711014, 59.227296486496925, 55.90346284210682, 63.94297644495964, 52.41750329732895, 59.026595056056976, 54.079002141952515, 64.31378334760666, 28.750049583613873, 0.902376469457522, 15.095075704157352, 22.5752954185009, 0.24291528010508046, 0.32833560195285827, 38.19221422076225, 61.768330335617065, 52.62436419725418, 47.20319889485836, 53.21815453469753, 22.48985320329666, 30.299889519810677, 36.387113481760025, 57.92276568710804, 32.40988589823246, 1.0245235869660974, 0.09732605525641702, 0.021904494242335204, 0.025574989667802583, 0.07774369471007958, 0.06376402961905114, 0.04603457433404401, 0.031014542510092724, 0.04417352771270089, 0.04494870838243514, 0.021137087569513824, 0.02742121745541226, 0.03626172510848846, 0.04735334849101491, 0.019841043540509418, 0.02273234884341946, 0.11121769421151839, 0.08135577940265648, 3.3975432766601443, 56.43804095685482, 69.22566577792168, 57.08983898162842, 54.15797710418701, 25.899841524660587, 23.009690009057522, 43.032257705926895, 59.2326769977808, 61.12545423209667, 59.567534029483795, 3.753466852940619, 0.20922318566590548, 1.3135411846451461, 9.992071129381657, 0.589474244043231, 17.672562897205353, 29.13835644721985, 27.875165529549122, 67.39355608820915, 55.97407445311546, 62.26810611784458, 54.28532347083092, 62.18413822352886, 57.76355803012848, 58.32937426865101, 55.22959940135479, 58.26225087046623, 54.646277502179146, 52.888757809996605, 45.10465130209923, 42.125903740525246, 41.25888526439667, 42.82900281250477, 38.76439891755581, 40.285521894693375, 38.82807210087776, 39.84820336103439, 39.40149553120136, 43.25008101761341, 42.51481667160988, 44.3447794765234, 41.24129980802536, 43.48132140934467, 41.85733415186405, 42.1431852132082, 41.27265952527523, 42.42581784725189, 37.51801639795303, 41.66568763554096, 40.02115488052368, 39.82502080500126, 37.645795941352844, 41.673519015312195, 37.9858510941267, 41.43501341342926, 40.91073274612427, 41.29283644258976, 38.518039137125015, 40.55436126887798, 38.68865378201008, 39.95742470026016, 39.55503009259701, 40.919134095311165, 40.726089254021645, 41.58312186598778, 39.87445995211601, 43.10175597667694, 40.737838223576546, 41.13547548651695, 40.93868404626846, 45.14358401298523, 43.999324813485146, 49.66041684150696, 53.99367392063141, 56.180205792188644, 53.642682954669, 55.619526877999306, 48.29312860965729, 31.602723710238934, 48.00403632223606, 55.25823466479778, 54.66198965907097, 53.415926322340965, 55.00167243182659, 48.52460838854313, 42.40771181881428, 42.0480003207922, 44.98258285224438, 41.99222311377525, 42.09753826260567, 41.8887622654438, 41.2219550460577, 41.80408760905266, 40.54038941860199, 39.860776886343956, 41.64201870560646, 42.53153957426548, 39.60582956671715, 41.49974673986435, 43.506886437535286, 44.77153457701206, 41.86247527599335, 42.07999840378761, 41.863022446632385, 41.773875430226326, 40.89248612523079, 43.09341162443161, 41.36666648089886, 41.288234889507294, 39.94629509747028, 42.110871747136116, 40.61245635151863, 41.92536950111389, 40.54838418960571, 42.10445009171963, 40.17506942152977, 39.876272454857826, 39.39828850328922, 41.88798330724239, 41.68011166155338, 41.610518395900726, 40.64858101308346, 44.540427178144455, 43.43370996415615, 54.72616821527481, 56.50631569325924, 58.582220301032066, 54.72257740795612, 58.20454716682434, 59.06015485525131, 60.08272938430309, 59.9493033438921, 61.36913135647774, 58.0065093934536, 61.63296639919281, 56.34409859776497, 63.9334237575531, 55.05898095667362, 60.31062215566635, 55.76652579009533, 66.95927739143372, 28.918323554098606, 0.36594126373529434, 7.642183173447847, 9.967257510870695, 0.6796713103540242, 0.2879431756446138, 42.954179495573044, 66.44994512200356, 58.839911073446274, 42.63576798141003, 48.554961159825325, 25.890906304121017, 35.37496939301491, 45.90939112007618, 66.05683341622353, 40.49592800438404, 1.1726998421363533, 0.09775938786333427, 0.05354319036996458, 0.023976943484740332, 0.056657798631931655, 0.03135886749078054, 0.01278828522117692, 0.0038886409220140195, 0.028349471649562474, 0.15582034655380994, 0.11562780287931673, 0.1298886677250266, 0.17008788330713287, 0.18473842763341963, 0.11918879812583327, 0.141481593309436, 0.3584203094942495, 0.22914234024938196, 4.794314363971353, 65.16194343566895, 74.24194380640984, 65.68943113088608, 58.81179258227348, 28.943595997989178, 36.35058604180813, 59.73299615085125, 67.69429475069046, 66.8318322300911, 65.87010383605957, 4.492842815816402, 0.5462949047796428, 5.569920195266604, 32.30795256793499, 1.813433098141104, 20.525641702115536, 31.3413243368268, 28.221321254968643, 69.91396844387054, 57.49537602066994, 65.98518446087837, 54.90801505744457, 65.86474612355232, 61.95979446172714, 60.25250427424908, 58.84544737637043, 61.37581519782543, 55.41918642818928, 55.375990346074104, 48.05546656250954, 44.22485791146755, 43.07348549365997, 45.08243769407272, 40.75706139206886, 42.72513918578625, 41.89814396202564, 42.28618673980236, 42.12067902088165, 46.750183403491974, 45.8671335875988, 47.159839421510696, 44.58371065557003, 47.320563197135925, 45.626028925180435, 42.45200224220753, 43.70143219828606, 45.14927230775356, 39.49560508131981, 44.354335963726044, 41.19152247905731, 40.35914674401283, 38.95903207361698, 44.05371889472008, 38.66615518927574, 42.772176861763, 42.803171798586845, 42.79465265572071, 41.244073659181595, 43.1317325681448, 40.61684511601925, 41.97143442928791, 41.29702761769295, 44.536061212420464, 42.52680882811546, 43.92956055700779, 40.52744351327419, 46.13980695605278, 44.31840509176254, 41.40721410512924, 42.9634016007185, 47.52373069524765, 46.2439289689064, 52.28715129196644, 56.7986986041069, 58.73723678290844, 55.0706235319376, 56.975358724594116, 51.01008541882038, 34.85890008509159, 51.685195192694664, 58.742446303367615, 58.22388052940369, 56.54282793402672, 58.58940191566944, 51.54565908014774, 45.1142305880785, 44.01500657200813, 48.20363961160183, 45.11510454118252, 44.84002210199833, 43.78211706876755, 42.94176176190376, 44.019296541810036, 44.56256479024887, 41.67312763631344, 43.76008205115795, 44.35742899775505, 41.90637432038784, 42.90184870362282, 44.86154034733772, 47.2137775272131, 42.811086773872375, 43.89755107462406, 43.37916389107704, 43.857592418789864, 43.53712521493435, 44.118057042360306, 41.60251222550869, 44.11426484584808, 43.98282989859581, 44.56427089869976, 43.44124875962734, 44.037630558013916, 42.84416399896145, 44.25945125520229, 41.008702889084816, 42.700972482562065, 43.74527424573898, 45.366255864501, 43.76247592270374, 43.406385630369186, 41.919593811035156, 47.220567762851715, 46.03347346186638, 57.47034676373005, 58.9831367880106, 62.066447138786316, 57.91682280600071, 59.93020176887512, 60.15072673559189, 61.17920994758606, 63.524417504668236, 62.11821176111698, 60.101621970534325, 60.83127781748772, 60.10588154196739, 65.84545835852623, 59.786862060427666, 62.31498420238495, 57.76776060461998, 66.52560666203499, 34.068873077631, 0.943289645947516, 22.629108130931854, 32.26678177714348, 1.1728871008381248, 0.3215227456530556, 46.30294740200043, 74.52030926942825, 66.54035747051239, 60.00457137823105, 60.850656777620316, 35.94102121889591, 43.84457811713219, 56.21699541807175, 75.4719378054142, 52.02567212283611, 2.094348818063736, 0.2557744877412915, 0.17923994455486536, 0.18185558466939256, 0.1624069071840495, 0.14981171116232872, 0.10669201830751263, 0.14840911142528057, 0.07415969288558699], [0.03415159146243241, 0.017071598886104766, 0.027813603919639718, 0.012529117975645931, 0.05266081388981547, 0.04446593018656131, 0.014678320130769862, 0.08653689044876955, 0.04339907434768975, 4.4341563899070024, 54.428260400891304, 57.08893083035946, 51.120047718286514, 29.24101933836937, 20.914567932486534, 48.32201465964317, 40.72784475982189, 53.446195498108864, 55.58326542377472, 53.30389693379402, 4.972105398774147, 0.37082682189065963, 1.226134356111288, 13.338750097900629, 0.11303289837087505, 27.318227514624596, 30.22813607007265, 33.47716882824898, 64.49165940284729, 54.04298007488251, 52.9604447633028, 49.496482238173485, 52.8502506762743, 52.81743563711643, 53.13538737595081, 51.34438768029213, 49.29432928562164, 43.24472710490227, 39.104495868086815, 39.77667219936848, 40.446796640753746, 38.78811724483967, 39.45830248296261, 37.23995491862297, 38.19418251514435, 38.62707048654556, 38.11829298734665, 37.58889019489288, 39.463975578546524, 41.38484850525856, 42.0142163336277, 41.15320533514023, 39.50890436768532, 39.41572196781635, 38.552032113075256, 37.786103412508965, 37.416968420147896, 38.536517545580864, 39.58275340497494, 38.43221314251423, 38.18597875535488, 37.826905623078346, 38.022203743457794, 38.4468499571085, 39.19799365103245, 40.540127232670784, 40.6038536131382, 38.00501726567745, 39.76628735661507, 39.76647734642029, 37.638352140784264, 38.173770010471344, 39.302446246147156, 38.970173075795174, 37.77958296239376, 38.30232471227646, 38.39837595820427, 38.868577927351, 38.19867007434368, 37.72196665406227, 40.200045481324196, 39.89302955567837, 44.21358771622181, 55.85337392985821, 52.17655062675476, 53.74929763376713, 48.48887890577316, 57.95290187001228, 44.646578282117844, 48.10047894716263, 53.03190752863884, 49.23471808433533, 51.6179995983839, 45.0630397349596, 39.907905757427216, 39.385521188378334, 38.490760400891304, 39.55080471932888, 40.41893653571606, 41.09750032424927, 38.79501387476921, 41.2745176255703, 42.859218791127205, 40.606429874897, 39.71672281622887, 39.10416528582573, 39.53841358423233, 39.588985070586205, 41.48439936339855, 39.660915210843086, 43.416356295347214, 40.03654785454273, 38.81620153784752, 41.101288720965385, 40.799527913331985, 39.1458984464407, 40.199376717209816, 40.14719791710377, 40.421782582998276, 40.27375392615795, 40.27128025889397, 39.09832499921322, 39.16544459760189, 39.080560952425, 39.50184054672718, 39.26222540438175, 38.514797911047935, 36.98873519897461, 39.001232609152794, 39.20813150703907, 40.10311648249626, 41.44659899175167, 41.50487266480923, 44.90316331386566, 53.37540529668331, 56.9984994828701, 54.035619869828224, 46.636622697114944, 54.09256361424923, 53.940092995762825, 56.06546714901924, 52.76352792978287, 55.503469705581665, 54.47975143790245, 54.068951681256294, 61.30322389304638, 59.0951319783926, 61.639213263988495, 64.94410872459412, 59.172157645225525, 71.40281215310097, 45.09788766503334, 0.366903769900091, 9.435298405587673, 11.209178119897842, 0.6752244208473712, 0.5399610009044409, 30.531162209808826, 61.62401407957077, 50.26969134807587, 65.8522979915142, 63.35470341145992, 32.66580976545811, 34.14083741605282, 44.93805304169655, 56.72527514398098, 33.16892556846142, 0.7759211550001055, 0.0769821324502118, 0.06854937557363883, 0.12973084260011092, 0.05215850607783068, 0.03983591574069578, 0.08093302240013145, 0.0748001440661028, 0.0826753031287808, 0.0191989559243666, 0.04113356466405094, 0.0032443498230350087, 0.07707433687755838, 0.07311655237572268, 0.009904826274578227, 0.04780111958098132, 0.10690590526792221, 0.07138966378988698, 5.886264620348811, 62.376768887043, 64.15062010288239, 55.547349750995636, 38.06656256318092, 28.96350122988224, 39.993005990982056, 42.28199556469917, 58.37213717401028, 58.399028331041336, 60.29485300183296, 4.262040350586176, 0.3296713490271941, 1.8199189938604832, 4.828056078404188, 0.11180146015249193, 30.942695327103138, 34.01809640228748, 35.95639519393444, 66.377954185009, 55.205721482634544, 58.193292170763016, 52.38781549036503, 56.15249387919903, 54.87437546253204, 54.76643085479736, 53.209555596113205, 53.3781373500824, 46.311546340584755, 42.960654348134995, 41.38200245797634, 42.27876953780651, 39.941511154174805, 40.921801552176476, 39.12859037518501, 40.25307923555374, 39.60820443928242, 40.17587497830391, 39.63008366525173, 41.87330849468708, 43.159581273794174, 44.14802983403206, 42.83500649034977, 40.47306463122368, 42.19654954969883, 40.58703191578388, 39.45987939834595, 39.139465391635895, 40.62568724155426, 42.117456793785095, 39.981515407562256, 39.515436217188835, 39.989369586110115, 39.698738381266594, 39.14526768028736, 41.082586124539375, 40.363531708717346, 43.06584410369396, 40.130440816283226, 41.6369953751564, 41.00224703550339, 40.209727361798286, 39.63835962116718, 41.05924777686596, 42.071726247668266, 40.59834010899067, 39.8633037507534, 40.35527095198631, 40.28436295688152, 41.085150986909866, 40.303126350045204, 43.52154605090618, 42.74690441787243, 46.46865651011467, 57.81514026224613, 55.55273026227951, 55.861801877617836, 51.43788926303387, 58.66055689752102, 48.29263463616371, 49.659007117152214, 54.43289615213871, 51.426284685730934, 52.998374328017235, 47.668879106640816, 42.289302572607994, 40.22364221513271, 40.72894290089607, 41.43876001238823, 42.73916803300381, 43.34931269288063, 42.55035996437073, 41.44933484494686, 46.00916996598244, 42.0776691287756, 41.250719502568245, 41.87408745288849, 42.47837282717228, 41.85324937105179, 42.857949659228325, 41.89319282770157, 44.48514774441719, 42.49677523970604, 41.66104428470135, 42.58581966161728, 41.85259200632572, 41.783530712127686, 41.65439464151859, 42.32217840850353, 42.284245043992996, 41.08365386724472, 41.950136572122574, 41.242074966430664, 40.237321481108665, 40.668138563632965, 40.7341980189085, 40.70648230612278, 40.50177589058876, 40.01041665673256, 41.185461804270744, 40.295405164361, 42.300158590078354, 43.61492983996868, 42.92308196425438, 45.14920391142368, 55.42391337454319, 57.61864900588989, 57.7897310256958, 51.59191019833088, 54.97063189744949, 55.09423166513443, 57.47980445623398, 53.48101682960987, 57.15354636311531, 54.98767778277397, 56.94967970252037, 61.8641421943903, 60.86794964969158, 63.79568874835968, 65.64471513032913, 59.44797344505787, 75.28590738773346, 46.72273747622967, 0.49701148993335664, 4.957732670009136, 5.409649545326829, 0.6454198295250535, 0.32499160326551646, 34.58525396883488, 64.78654637932777, 58.79549905657768, 64.89257588982582, 59.858248829841614, 32.830656319856644, 43.61900322139263, 52.72595934569836, 65.23714900016785, 43.23616996407509, 1.2590955686755478, 0.15199574787402526, 0.07171070203185081, 0.05243337531283032, 0.07686088778427802, 0.0277402630308643, 0.05548927227209788, 0.10915651262621395, 0.06332147211651318, 0.15464965312276036, 0.06801081384764984, 0.11621222191024572, 0.18654162384336814, 0.18292582099093124, 0.16197675839066505, 0.10337309679016471, 0.23318219144130126, 0.20966075593605638, 7.69292232580483, 73.26174080371857, 70.5864791572094, 62.64641761779785, 41.72614999115467, 32.047271355986595, 59.22327630221844, 53.58454987406731, 64.12648379802704, 66.551513671875, 63.79353806376457, 6.4608564879745245, 0.6329308496788144, 4.577795332297683, 26.53114914894104, 0.6400659761857241, 34.60711419582367, 35.14687903225422, 39.202663600444794, 68.6594657599926, 57.87986978888512, 59.11651723086834, 55.54253540933132, 57.23722547292709, 57.95712724328041, 58.300883397459984, 55.42523570358753, 54.81897063553333, 47.4579144269228, 45.02900116145611, 43.82850497961044, 45.181182995438576, 43.116415590047836, 43.20511043071747, 41.73686541616917, 41.74696147441864, 42.701736241579056, 41.96454919874668, 41.545055508613586, 43.774449080228806, 46.03773683309555, 45.49199491739273, 45.713462233543396, 44.171299785375595, 44.64368283748627, 41.124243289232254, 43.34598407149315, 41.119098365306854, 41.70341581106186, 44.47959244251251, 41.8170715123415, 41.89089015126228, 42.16163322329521, 41.251012086868286, 42.38580979406834, 42.81649388372898, 43.869341388344765, 44.248743429780006, 42.53553315997124, 43.78088593482971, 43.27431231737137, 40.80306552350521, 41.79624862968922, 44.09273520112038, 43.174879252910614, 42.611103504896164, 43.03293026983738, 41.614435985684395, 44.20215032994747, 42.61950105428696, 42.6900252699852, 45.30186451971531, 44.5673069357872, 48.884848058223724, 60.474195778369904, 57.02775411307812, 58.515556678175926, 53.091948106884956, 62.0527146756649, 50.88256426155567, 53.9645978808403, 58.2549362629652, 53.69462996721268, 53.67281533777714, 50.22291585803032, 44.02511402964592, 42.89687097072601, 42.161473631858826, 44.66666780412197, 44.28025133907795, 45.97147598862648, 44.19208467006683, 44.370887875556946, 48.56882281601429, 44.445010498166084, 44.08898860216141, 43.710821494460106, 43.776386976242065, 43.5993392765522, 44.54413577914238, 45.06435066461563, 47.784617096185684, 44.324461966753006, 43.208864629268646, 43.58677715063095, 44.6068362146616, 44.56127665936947, 44.73599508404732, 44.69067491590977, 46.22573934495449, 44.81155022978783, 45.108739882707596, 43.19260910153389, 43.348982110619545, 42.721422985196114, 43.82459118962288, 43.32915097475052, 42.97476679086685, 42.325841411948204, 43.04340250790119, 41.93762764334679, 44.04898814857006, 45.42042575776577, 45.52098736166954, 49.060056656599045, 59.09134738147259, 62.301320135593414, 59.33041915297508, 53.31875033676624, 56.70792907476425, 55.711983516812325, 59.569430127739906, 54.98010478913784, 57.94218644499779, 55.46591252088547, 57.60084696114063, 65.2283562719822, 63.08106489479542, 66.39701396226883, 69.69478100538254, 64.3004384636879, 74.7867813706398, 50.045328587293625, 0.6719675799831748, 18.584500662982464, 24.434624947607517, 1.3386022648774087, 0.4334746836684644, 36.405645087361336, 72.47136041522026, 65.77295824885368, 78.86343821883202, 68.43362867832184, 46.22018404304981, 49.018296897411346, 62.80667021870613, 75.38049191236496, 54.71952237188816, 2.618566076271236, 0.23655201686779037, 0.11232540899072774, 0.11070538967032917, 0.23334074387094006, 0.12660470878472552, 0.17625280015636235, 0.18409268493996933, 0.28577494667842984], [0.03273993752372917, 0.034511985795688815, 0.028563058040163014, 0.046740705583943054, 0.04726958599349018, 0.008084179389697965, 0.0816104473778978, 0.06863262970000505, 0.034859711668104865, 4.789133816957474, 52.94806122779846, 56.04619078338146, 47.68736511468887, 27.528265044093132, 13.931522089987993, 32.54519283771515, 39.3265825510025, 53.68323437869549, 53.516658917069435, 51.72142244875431, 3.0006023263558745, 0.0730621455295477, 0.876680170185864, 2.7099248114973307, 0.2545810252195224, 38.588871136307716, 57.457856833934784, 57.90821246802807, 59.847077429294586, 54.081076830625534, 53.29721309244633, 43.80839265882969, 44.70028840005398, 43.113592341542244, 43.76374885439873, 41.46408565342426, 39.69060301780701, 36.79641231894493, 39.60018686950207, 39.35109503567219, 40.776778534054756, 40.418309569358826, 42.666071355342865, 39.78438198566437, 39.44004066288471, 37.316870391368866, 39.160611256957054, 38.57904866337776, 40.94693340361118, 38.65890897810459, 39.72259730100632, 39.90302301943302, 39.07756671309471, 37.45998591184616, 38.2732068747282, 38.000491708517075, 37.91062653064728, 37.18202702701092, 39.00113381445408, 38.17050978541374, 38.587583005428314, 37.95330584049225, 38.83160591125488, 39.06850799918175, 37.68164701759815, 39.33260902762413, 38.325929045677185, 39.131611213088036, 41.25258520245552, 39.782200902700424, 39.32056367397308, 40.69148451089859, 39.510298892855644, 38.35500128567219, 37.34992101788521, 38.38686637580395, 40.01224435865879, 38.48620064556599, 39.12327826023102, 38.88543762266636, 39.95064206421375, 40.17236016690731, 39.47170436382294, 46.2230034917593, 48.727794885635376, 49.41313371062279, 48.95785354077816, 53.657308369874954, 47.94771574437618, 50.912810638546944, 52.56794102489948, 49.13617417216301, 44.08502161502838, 40.40501028299332, 40.713390335440636, 39.52625423669815, 39.71453033387661, 39.307716563344, 43.368893042206764, 42.03725829720497, 41.081180199980736, 43.83414767682552, 43.36382411420345, 43.45199838280678, 40.197917595505714, 38.30770142376423, 37.97365374863148, 38.88329453766346, 39.72933053970337, 39.95628856122494, 40.558119267225266, 41.80385202169418, 39.5035732537508, 39.15094457566738, 39.55946445465088, 39.93045374751091, 40.21100029349327, 39.26644317805767, 40.04842981696129, 40.086492374539375, 37.905265018343925, 40.57297646999359, 40.9837344288826, 39.69270050525665, 37.052651569247246, 38.23586627840996, 37.99509599804878, 38.39982368052006, 38.078585118055344, 39.99156206846237, 40.46137645840645, 39.1814911365509, 39.53481137752533, 47.93711431324482, 52.62817919254303, 55.833820179104805, 48.60858388245106, 50.381097570061684, 54.307145699858665, 51.9947911798954, 54.30744208395481, 53.408911898732185, 57.36464023590088, 58.93398642539978, 58.98846410214901, 57.25380778312683, 57.126305624842644, 57.36206777393818, 59.21730302274227, 60.13286009430885, 65.91138482093811, 62.11192689836025, 2.205257504247129, 0.43370454164687544, 3.1988550256937742, 0.5629109381698072, 0.21493096923222765, 25.548765063285828, 65.14527752995491, 57.29809820652008, 44.82226565480232, 60.36505423486233, 45.27966991066933, 23.842907398939133, 40.33145383000374, 58.06830167770386, 43.340424969792366, 2.4029259849339724, 0.22375445201760158, 0.0726793754438404, 0.09205413502058946, 0.07320164702832699, 0.05768994422396645, 0.11008673536707647, 0.02322148167877458, 0.03981516529165674, 0.011867634329973953, 0.05491903568326961, 0.1310332227149047, 0.11369330590241589, 0.02809482037264388, 0.05406177348049823, 0.09062732642632909, 0.060030614913557656, 0.012605232641362818, 6.12692803144455, 61.05414345860481, 64.55865740776062, 55.092578753829, 38.94670553505421, 22.67880756407976, 32.5991727411747, 43.28366361558437, 58.45965027809143, 57.85294063389301, 57.98223249614239, 3.1894483929499984, 0.253834959003143, 1.2964346213266253, 3.256076630204916, 0.5275565071497113, 39.658813923597336, 61.16676181554794, 59.14965905249119, 61.440293937921524, 57.38830916583538, 56.56789518892765, 45.1883190125227, 46.642858162522316, 44.84039448201656, 45.45716978609562, 43.239958360791206, 42.59945333003998, 40.3839898109436, 42.080993950366974, 41.659661158919334, 42.686248272657394, 40.609621703624725, 43.32734227180481, 42.32499785721302, 41.15495704114437, 40.34811593592167, 41.06309317052364, 41.45462416112423, 42.344141229987144, 40.18636241555214, 42.93268024921417, 41.51532590389252, 40.51352106034756, 38.854195699095726, 41.35715939104557, 41.17475017905235, 40.246608182787895, 39.78276327252388, 40.22176891565323, 40.521006658673286, 40.06898291409016, 38.44643197953701, 40.920927599072456, 39.0182138979435, 41.0552503913641, 40.236025750637054, 40.07404804229736, 41.11383944749832, 42.76749171316624, 40.60148634016514, 41.24286912381649, 41.05710469186306, 41.315718814730644, 39.829580560326576, 39.6549229323864, 40.23710489273071, 41.51114232838154, 41.4400215446949, 41.50329574942589, 40.475720688700676, 42.84407660365105, 42.2095600515604, 41.23534932732582, 46.69297367334366, 50.960087701678276, 51.56059987843037, 49.65164311230183, 55.22249758243561, 49.83302257955074, 51.853423565626144, 54.034035354852676, 50.16662187874317, 45.62223292887211, 41.88372753560543, 42.52806656062603, 42.215822115540504, 40.52215039730072, 41.3083054125309, 43.977320194244385, 44.78616379201412, 44.27889101207256, 44.55262832343578, 45.778856724500656, 46.111426278948784, 41.79634742438793, 39.834638088941574, 40.93862324953079, 40.662666857242584, 40.59210084378719, 41.7550740391016, 42.046085223555565, 42.28396385908127, 40.34609064459801, 40.030316188931465, 42.404383197426796, 42.26753354072571, 42.0940500497818, 40.925985127687454, 41.60877428948879, 40.9239636361599, 39.69861298799515, 42.88773626089096, 42.44741968810558, 40.88358320295811, 40.10867938399315, 40.183949545025826, 40.144838243722916, 40.775775387883186, 40.116651356220245, 43.37539829313755, 41.8199859559536, 40.270197317004204, 41.452158093452454, 49.870549365878105, 53.84295500814915, 57.49751150608063, 51.94542422890663, 50.87510526180267, 54.2249371111393, 53.406571224331856, 54.28289920091629, 55.23475952446461, 56.68231084942818, 60.39818465709686, 59.70359332859516, 58.23803476989269, 59.27891291677952, 60.58228477835655, 63.278574496507645, 63.58703814446926, 66.12480416893959, 65.55697023868561, 2.6418163161724806, 1.4125563902780414, 3.325542127713561, 0.3069656080333516, 0.16724833723856136, 28.12584947794676, 70.24032533168793, 62.45104730129242, 54.9175601452589, 59.85063023865223, 53.11173364520073, 32.220986634492874, 45.72843722999096, 66.3507704436779, 53.887526616454124, 4.058628715574741, 0.19321001367643476, 0.020324586148490198, 0.08549153091735207, 0.03321513839182444, 0.08961537096183747, 0.1583702175412327, 0.016719427549105603, 0.06310886165010743, 0.09748252225108445, 0.15461400034837425, 0.15156150242546573, 0.18199105630628765, 0.08872825215803459, 0.21659039659425616, 0.22270705900155008, 0.21713320340495557, 0.22691704012686387, 8.44824817031622, 70.35884857177734, 69.26299497485161, 63.25423680245876, 39.85154338181019, 21.149154044687748, 42.07978941500187, 54.86259609460831, 64.25614044070244, 63.627859354019165, 62.603905498981476, 4.4057871121913195, 0.24466410657623783, 2.465036027133465, 6.849539531394839, 0.5558979988563806, 43.67734529078007, 61.63468770682812, 60.72566628456116, 64.6979047358036, 58.16040873527527, 58.80156733095646, 49.22530598938465, 48.412423208355904, 45.23369997739792, 48.488004952669144, 44.74713608622551, 45.08708864450455, 41.24659292399883, 44.42087039351463, 43.28542672097683, 45.4960872977972, 44.81363631784916, 47.72591024637222, 43.27556625008583, 44.9612507969141, 41.66308477520943, 43.854651376605034, 45.5354455858469, 45.02851478755474, 43.92334409058094, 44.3344060331583, 45.579705610871315, 44.70387540757656, 42.54428029060364, 42.667838260531425, 43.029282465577126, 40.573751628398895, 42.45167165994644, 42.736371383070946, 42.84288726747036, 42.82292313873768, 39.71581846475601, 42.76377931237221, 41.846250146627426, 41.233647018671036, 42.48906925320625, 42.03246295452118, 44.06631521880627, 45.07386915385723, 42.85303272306919, 44.253724962472916, 43.50483454763889, 44.406693354249, 41.811029836535454, 41.51858612895012, 43.131094202399254, 45.23223705589771, 43.49256880581379, 42.77283042669296, 44.816041588783264, 43.598032146692276, 45.332190692424774, 42.460893765091896, 49.46635365486145, 53.73686470091343, 54.38879951834679, 53.119774013757706, 57.63739340007305, 53.78174029290676, 56.43811695277691, 55.428685918450356, 52.1597783267498, 47.695204094052315, 45.40759764611721, 45.10693117976189, 44.65499863028526, 43.86098563671112, 43.98056901991367, 48.748142793774605, 47.88946107029915, 45.96688963472843, 47.22432196140289, 46.778206899762154, 47.87009350955486, 43.47518093883991, 42.68314003944397, 41.19342617690563, 42.06136040389538, 43.53490613400936, 43.284419775009155, 43.57236832380295, 43.774578273296356, 42.89504326879978, 40.815494656562805, 43.841249495744705, 43.62487010657787, 45.28842844069004, 43.278503492474556, 45.12665972113609, 43.10404345393181, 41.36298827826977, 44.78221580386162, 45.51193244755268, 43.99299815297127, 41.1145082116127, 43.010579869151115, 43.49605321884155, 43.06280806660652, 41.08945235610008, 45.22185601294041, 44.12444069981575, 41.52205914258957, 42.23687298595905, 52.79773369431496, 56.530964970588684, 60.31372658908367, 55.554998740553856, 53.46770614385605, 55.894309133291245, 54.42432381212711, 56.63563035428524, 56.56177371740341, 59.43686664104462, 62.472576946020126, 62.14164510369301, 61.921226531267166, 62.172681838274, 62.57364772260189, 66.08767256140709, 65.44035449624062, 70.32683908939362, 68.90527456998825, 3.0110992630943656, 3.6813317611813545, 8.272220715880394, 1.26516277436167, 0.14614002458984032, 31.629892252385616, 78.12573820352554, 67.665606290102, 61.67524293065071, 68.58793079853058, 56.91012762486935, 36.88244730234146, 55.98072029650211, 76.13114923238754, 67.37895727157593, 6.462024450302124, 0.43688927544280887, 0.09596801406587474, 0.25300301145762205, 0.1330723476712592, 0.2194699295796454, 0.4009799851337448, 0.18586045101983473, 0.13364148588152602], [0.021087970380904153, 0.015926591186143924, 0.06977840923354961, 0.07343707111431286, 0.01868388873845106, 0.0328365799941821, 0.05081393857835792, 0.09758649714058265, 0.05557496435358189, 6.876111505553126, 54.33746047317982, 52.49500013887882, 37.08159081637859, 22.14218705892563, 30.577002950012684, 51.86335243284702, 45.80859012901783, 51.56085826456547, 54.06646281480789, 50.0296164304018, 2.411492387764156, 0.14968878182116896, 0.7381936919409782, 1.1051703407429159, 1.8597405008040369, 43.40671621263027, 64.40829947590828, 57.408714070916176, 58.74450959265232, 52.97948934137821, 45.75029365718365, 41.946013793349266, 41.70586667954922, 40.49330614507198, 39.719834849238396, 40.368273854255676, 41.19712337851524, 43.087240755558014, 43.32756645977497, 43.596462830901146, 44.88542966544628, 45.99468894302845, 43.957694247365, 41.57869890332222, 42.81720444560051, 39.52190726995468, 38.741387352347374, 38.36869575083256, 39.5094895362854, 37.83310309052467, 39.412172958254814, 37.79670104384422, 37.97749154269695, 38.35788533091545, 38.98242361843586, 38.357767537236214, 38.31772908568382, 38.230170384049416, 37.796393260359764, 37.49754689633846, 35.77530451118946, 38.74974690377712, 37.96123221516609, 37.34482169151306, 38.20123113691807, 38.47002491354942, 38.61912131309509, 39.23275798559189, 39.76387828588486, 38.94136302173138, 40.697928965091705, 39.60723549127579, 39.02778938412666, 36.958314031362534, 37.24484145641327, 37.617662250995636, 37.97105088829994, 37.41768658161163, 37.43474766612053, 37.90599077939987, 38.4564558416605, 39.74164567887783, 41.15046568214893, 41.390118822455406, 42.723474875092506, 47.4507974088192, 48.02167497575283, 55.27968071401119, 49.440161660313606, 49.88442242145538, 53.5571913421154, 49.75057080388069, 42.452917993068695, 41.481864899396896, 42.483418956398964, 38.30292887985706, 39.5232941955328, 38.74115936458111, 42.85478822886944, 44.8193322122097, 45.753208100795746, 43.36496025323868, 45.36062076687813, 44.27028067409992, 41.87594175338745, 38.88611398637295, 39.97961550951004, 40.70617452263832, 40.8232956379652, 43.23921360075474, 40.869998931884766, 39.259542748332024, 38.49414221942425, 40.89041143655777, 40.21666198968887, 38.65439862012863, 37.96506620943546, 38.05219553411007, 40.08233919739723, 38.58227089047432, 39.65830475091934, 39.9686075001955, 39.911659955978394, 38.91450986266136, 38.70086632668972, 39.144146740436554, 37.790271788835526, 38.863121420145035, 38.585398122668266, 39.41351808607578, 38.745384737849236, 39.21152092516422, 42.80406855046749, 48.424567356705666, 54.14373926818371, 50.10940834879875, 47.5375809520483, 56.53911553323269, 52.57617138326168, 56.758679151535034, 54.545818492770195, 57.20630653202534, 57.46701814234257, 56.62758618593216, 54.43155862390995, 59.2403943836689, 52.37977892160416, 56.365791633725166, 54.47030894458294, 62.6804181933403, 57.03318402171135, 73.4979285299778, 7.589972550049424, 2.2029061429202557, 1.7489601764827967, 0.5023211112711579, 0.13442517898511142, 25.378114320337772, 59.114575535058975, 62.25446864962578, 47.996467128396034, 55.267506167292595, 26.617009341716766, 19.297843985259533, 47.241371646523476, 52.03808605670929, 43.16326707601547, 4.509891550987959, 0.09967572448658757, 0.052125198490102775, 0.14039176428923383, 0.07869214459788054, 0.056519287900300696, 0.04955312244419474, 0.03936494882509578, 0.06392877898178995, 0.06620795902563259, 0.04963665487593971, 0.07115264408639632, 0.04581072775181383, 0.06207098667800892, 0.10661760315997526, 0.046279702000902034, 0.15921878919471055, 0.08083353750407696, 9.418171774595976, 64.40006151795387, 59.319274351000786, 43.58310654759407, 28.840239644050598, 26.50889754295349, 46.98608994483948, 51.57293401658535, 56.70814946293831, 58.74985210597515, 54.620062708854675, 3.3215822651982307, 0.23588322306750342, 1.2291559064760804, 1.8477023905143142, 1.885842012707144, 47.300257086753845, 65.5206061899662, 60.65294198691845, 59.55219425261021, 55.604529082775116, 47.94589564204216, 43.34088854491711, 43.704920411109924, 43.06399740278721, 41.79163187742233, 41.87030665576458, 43.44693325459957, 43.99360612034798, 46.23758710920811, 44.965970143675804, 48.138644099235535, 47.96520620584488, 45.94797044992447, 43.96195761859417, 44.678572565317154, 40.482940301299095, 41.21116362512112, 41.116921082139015, 40.34984104335308, 40.07978953421116, 39.95083585381508, 40.34612864255905, 38.892345651984215, 39.514406472444534, 40.130759999156, 38.8316211104393, 39.766868725419044, 38.5380944609642, 39.60730388760567, 39.824450835585594, 38.60743314027786, 39.656857028603554, 39.85432103276253, 37.7449706196785, 38.72909501194954, 39.925107434391975, 41.20427459478378, 41.98228284716606, 41.55944913625717, 42.69395425915718, 41.78701892495155, 41.640890166163445, 41.77694946527481, 40.693357810378075, 40.46996019780636, 39.701132252812386, 40.078748390078545, 41.40222117304802, 39.80083130300045, 38.997638002038, 40.21606162190437, 42.10736833512783, 42.84949891269207, 42.298779264092445, 46.06726124882698, 49.54912841320038, 49.6258956938982, 58.0633657425642, 54.3355605751276, 51.98226325213909, 55.75354188680649, 51.05321690440178, 45.32057851552963, 42.47405245900154, 43.47587250173092, 41.04070857167244, 41.18221677839756, 41.167781352996826, 45.31168319284916, 46.20985619723797, 47.28004977107048, 45.19005171954632, 47.57664665579796, 46.205197647213936, 42.50861540436745, 40.659615620970726, 41.05713129043579, 42.30206988751888, 43.189630061388016, 44.51149933040142, 41.81019768118858, 42.53011465072632, 40.09261004626751, 41.75295755267143, 41.19679279625416, 41.67732261121273, 39.37868915498257, 40.99438525736332, 40.97004756331444, 40.15556126832962, 41.99225731194019, 42.13096886873245, 40.949988439679146, 40.39010748267174, 40.86401425302029, 40.4640819132328, 40.401955246925354, 41.38135269284248, 39.894811660051346, 41.73589266836643, 41.40908740460873, 42.54901863634586, 44.813358932733536, 51.93096600472927, 56.351135820150375, 52.111125737428665, 49.61652919650078, 56.08073092997074, 55.139247849583626, 58.655313178896904, 55.876902267336845, 59.27271164953709, 58.51985804736614, 61.44294239580631, 58.018178567290306, 61.9171417504549, 54.66481290757656, 60.27000993490219, 56.256980672478676, 64.23993051052094, 60.00510714948177, 76.29693433642387, 7.638115966692567, 1.7961226520128548, 3.743543210439384, 0.76056475401856, 0.09546442233840935, 26.689192168414593, 67.49529182910919, 66.46855652332306, 57.45215333998203, 62.63850264251232, 36.85130037367344, 21.56329572200775, 55.363367423415184, 61.1445140093565, 51.19414374232292, 6.75105594098568, 0.2545709616970271, 0.011153062077937648, 0.04748915780510288, 0.06810085120378062, 0.053286681868485175, 0.026138587745663244, 0.031104982481338084, 0.0597673677111743, 0.11241809581406415, 0.09528753886115737, 0.1349922243389301, 0.22551556845428422, 0.1394563910434954, 0.17092645080992952, 0.21178212569793686, 0.1755834126379341, 0.21692507551051676, 11.51103962212801, 76.43557369709015, 66.3006891310215, 51.75409309566021, 31.97114624083042, 41.64380460977554, 60.65084829926491, 58.80030199885368, 64.06032174825668, 65.02920895814896, 61.96251891553402, 3.8456254452466965, 0.26262059225700796, 3.034844663925469, 5.331561835482717, 2.416516193188727, 48.33142675459385, 68.24617713689804, 63.2725366204977, 63.91931131482124, 58.82522486150265, 48.69972959160805, 46.466122046113014, 44.63055074214935, 45.21484538912773, 44.10454876720905, 44.452119916677475, 45.6988900154829, 46.66858658194542, 47.99696870148182, 47.96397507190704, 50.88849574327469, 50.30683055520058, 48.18179078400135, 45.774619951844215, 48.44778411090374, 43.25254708528519, 43.09956729412079, 43.63827958703041, 44.48101356625557, 41.913897916674614, 42.53913916647434, 43.24511468410492, 41.816938519477844, 41.772013530135155, 42.59397782385349, 42.17523269355297, 42.28411965072155, 42.271888107061386, 42.37484738230705, 42.238856479525566, 39.65458855032921, 42.75129318237305, 40.43596722185612, 38.54181446135044, 41.87729828059673, 42.94066742062569, 42.694224044680595, 42.17060074210167, 43.43554526567459, 44.4833542406559, 44.823356196284294, 44.34093028306961, 43.77351053059101, 42.68803797662258, 41.73554688692093, 42.93266125023365, 42.89935603737831, 43.26575517654419, 42.628673762083054, 41.99235990643501, 43.36224339902401, 43.806279972195625, 43.97500991821289, 44.56001132726669, 47.21699595451355, 53.107854053378105, 51.86097756028175, 59.430106803774834, 56.66867338120937, 55.63522383570671, 58.31865504384041, 53.382868096232414, 46.975610107183456, 45.41819527745247, 46.33599802851677, 42.48726435005665, 43.53282004594803, 43.852800875902176, 48.11559833586216, 48.351626470685005, 49.26070109009743, 46.10977716743946, 50.47130472958088, 49.232236817479134, 45.57424530386925, 42.99752376973629, 45.26477091014385, 44.92319583892822, 43.587681502103806, 46.872381046414375, 45.01657582819462, 43.99734511971474, 41.11676909029484, 43.5401726514101, 43.41673247516155, 42.10058569908142, 41.28916583955288, 42.52235546708107, 42.919312566518784, 41.170361414551735, 43.78248944878578, 43.96143704652786, 43.18726658821106, 43.23941498994827, 42.761393040418625, 41.80037520825863, 42.58015416562557, 43.68111848831177, 43.07715229690075, 44.859982430934906, 43.409300073981285, 44.460506066679955, 47.1442374587059, 55.313571095466614, 57.31493130326271, 54.39307428896427, 52.53040283918381, 57.90961839258671, 56.23622618615627, 60.54480358958244, 57.20731347799301, 61.4014296233654, 62.37484999001026, 62.084925547242165, 60.86326450109482, 64.52428445219994, 57.16881014406681, 62.74576708674431, 59.31659169495106, 67.28461593389511, 62.010468542575836, 78.61401200294495, 9.851561319082975, 3.579695289954543, 7.457567704841495, 1.18296321015805, 0.2128282719058916, 29.306856505572796, 72.99552708864212, 72.16746792197227, 66.15806758403778, 70.31798556447029, 34.796142652630806, 30.736372098326683, 66.6311801970005, 69.04519066214561, 64.33350428938866, 9.942357446998358, 0.3716234432067722, 0.11840114195365459, 0.23409963439917192, 0.23700002173427492, 0.12766835483489558, 0.20592358225258067, 0.20080199145013466, 0.18429952149745077], [0.01032917425618507, 0.05270678251690697, 0.0722963159205392, 0.10882561124162748, 0.06853914877865463, 0.0354620461439481, 0.11574981937883422, 0.0974582762864884, 0.0759282530634664, 8.804596848785877, 60.100679621100426, 50.014542639255524, 47.92998969554901, 23.394848741590977, 53.10010626912117, 79.01558965444565, 45.256867334246635, 45.668613240122795, 55.08092477917671, 48.636314794421196, 2.2980922227725387, 0.2526125527219847, 1.0923526785336435, 3.2857031654566526, 3.9036958292126656, 66.12162753939629, 61.09294317662716, 56.54119782149792, 55.55188670754433, 49.54804927110672, 44.74728427827358, 43.5333938151598, 45.36809876561165, 48.27143557369709, 48.93503196537495, 50.25329902768135, 47.0066012442112, 47.37741194665432, 45.135133266448975, 47.41319462656975, 48.05433802306652, 49.34870816767216, 46.9059294462204, 46.37764759361744, 46.65590666234493, 40.449334904551506, 38.32887388765812, 40.280015990138054, 37.842382192611694, 38.43910217285156, 35.33056877553463, 37.230364233255386, 37.75322377681732, 36.80471487343311, 38.11654508113861, 36.7120910435915, 37.804342433810234, 38.19639019668102, 38.801439329981804, 36.67008049786091, 35.352052822709084, 38.662256598472595, 36.75632826983929, 38.53158921003342, 37.307393699884415, 36.75988107919693, 38.39560590684414, 38.86673882603645, 38.83063316345215, 40.72001338005066, 40.185328871011734, 39.604704827070236, 39.02261026203632, 39.24552150070667, 38.13847750425339, 38.1572674959898, 38.62850300967693, 39.656591042876244, 37.27635696530342, 37.68325813114643, 37.5122407078743, 39.246038272976875, 38.0752032995224, 41.91955581307411, 46.460464149713516, 49.7770781815052, 50.68293437361717, 50.532150864601135, 48.72577719390392, 50.66474474966526, 52.26470589637756, 51.10989086329937, 42.79427267611027, 40.70338547229767, 40.39576157927513, 38.74606870114803, 38.4686303883791, 41.512829437851906, 43.83311793208122, 44.08895440399647, 44.83545854687691, 44.63859111070633, 45.151453390717506, 45.94346009194851, 40.93635477125645, 38.75772647559643, 39.338460713624954, 39.45990979671478, 41.95029616355896, 39.77153867483139, 38.243135288357735, 41.942153200507164, 39.176809787750244, 40.93204200267792, 40.06455235183239, 39.29281376302242, 38.814252242445946, 37.52250775694847, 39.597732201218605, 40.26219114661217, 39.44554656744003, 40.83218336105347, 39.775957837700844, 39.96016055345535, 37.677026465535164, 38.38405832648277, 37.727544754743576, 39.35620576143265, 37.41993226110935, 39.958842024207115, 38.70610624551773, 40.015249997377396, 41.71806402504444, 48.70921388268471, 50.01230075955391, 51.690169125795364, 52.440104484558105, 53.82458679378033, 55.331794917583466, 55.191916823387146, 53.77300836145878, 55.97220875322819, 53.17873165011406, 56.21912330389023, 48.99989068508148, 50.43010354042053, 44.55344907939434, 48.37355889379978, 49.427504539489746, 64.52524200081825, 55.958058312535286, 78.50910723209381, 16.179737001657486, 0.2223150565987453, 3.3791874116286635, 0.08380202430998906, 0.0750878821418155, 23.296333327889442, 64.08898741006851, 61.66075050830841, 51.845706179738045, 45.389841198921204, 39.34891775250435, 27.488994151353836, 44.05194818973541, 47.95760661363602, 45.09550139307976, 7.213780861347914, 0.24226726643973961, 0.013201000037952326, 0.04708503984147683, 0.12796568888006732, 0.014990329218562692, 0.033324738760711625, 0.011140788810735103, 0.01492976347435615, 0.017195721229654737, 0.03204147637006827, 0.04430515873536933, 0.05107133023557253, 0.09617344796424732, 0.028794556164939422, 0.0776030651468318, 0.15625515603460371, 0.07150877849198878, 12.296386230736971, 70.5542340874672, 54.696347415447235, 54.250798523426056, 28.219993226230145, 51.40452705323696, 80.09932950139046, 51.064490899443626, 53.72713342308998, 60.40923826396465, 54.138073772192, 2.3870592238381505, 0.45531671319622546, 0.8743450767360628, 1.7098000715486705, 4.421012420207262, 68.47839787602425, 62.42452472448349, 58.76400254666805, 57.68000431358814, 50.168468579649925, 46.21911250054836, 44.4705755263567, 47.50738777220249, 50.05429610610008, 51.53450287878513, 51.144058629870415, 48.69268856942654, 49.628608748316765, 46.88525855541229, 50.35772502422333, 50.13092279434204, 51.015104949474335, 50.245798230171204, 47.34046272933483, 47.33693651854992, 43.536410853266716, 40.69944508373737, 43.06606829166412, 40.58167040348053, 40.80432705581188, 39.01127927005291, 39.292790964245796, 39.2806164175272, 37.715563997626305, 40.39287753403187, 39.631500989198685, 39.53188553452492, 39.12945672869682, 41.67416878044605, 38.10616783797741, 38.39881293475628, 39.640153124928474, 38.61636646091938, 39.30680461227894, 39.565145149827, 39.117426574230194, 42.61769235134125, 41.129517406225204, 40.01449763774872, 41.05907678604126, 41.40119522809982, 41.08608193695545, 42.92640298604965, 40.94954766333103, 40.630057007074356, 41.11888937652111, 40.1581147313118, 40.812690407037735, 39.96589444577694, 39.151917323470116, 39.395761638879776, 41.43583796918392, 41.52279630303383, 45.118395164608955, 49.23789471387863, 53.71963642537594, 51.715844348073006, 53.305135667324066, 49.782413095235825, 52.483555153012276, 53.621825873851776, 52.931889295578, 44.848560243844986, 42.16443747282028, 42.25787825882435, 40.0741658359766, 41.77656188607216, 41.98508709669113, 45.02588152885437, 45.91972276568413, 45.79651057720184, 46.97575829923153, 46.58832348883152, 47.51904934644699, 43.791726753115654, 40.34212365746498, 39.89081807434559, 41.73322141170502, 42.32113726437092, 41.9898596405983, 42.311949357390404, 43.19480538368225, 40.679157972335815, 42.13614039123058, 41.422291696071625, 41.75719812512398, 39.337043389678, 39.597128033638, 39.66246172785759, 41.961319372057915, 42.02537253499031, 41.574013754725456, 41.152069196105, 40.67699208855629, 39.314244613051414, 39.913787841796875, 40.750917121768, 40.45723848044872, 39.56240929663181, 41.265485510230064, 40.554851442575455, 41.806572675704956, 43.90492267906666, 51.57867930829525, 51.94010071456432, 54.253541976213455, 54.26371403038502, 56.768961399793625, 56.11154347658157, 57.70114257931709, 56.173723340034485, 59.00115542113781, 54.664250537753105, 59.886488914489746, 51.66934244334698, 53.57101500034332, 46.28912754356861, 51.16029515862465, 52.39864870905876, 68.03327456116676, 57.8211173415184, 82.10483148694038, 17.739106826484203, 0.7156439800746739, 4.150718674063683, 0.5036123294848949, 0.09346744394861162, 25.372631214559078, 70.83214357495308, 64.3526628613472, 57.6614461094141, 51.318294480443, 37.46057488024235, 30.29218353331089, 52.04241782426834, 55.81816501915455, 56.79816283285618, 9.529231265187263, 0.15598364872857928, 0.021290253862389363, 0.1273965506698005, 0.09079879222554155, 0.024706814183446113, 0.09327772131655365, 0.007063328357617138, 0.05130262426973786, 0.10722364837420173, 0.11879050973220728, 0.18349087738897651, 0.1910476922057569, 0.18502192804589868, 0.11986182216787711, 0.26950033090543, 0.4114252683939412, 0.19552558864234015, 15.496379770338535, 81.96224793791771, 60.31539469957352, 64.25011396408081, 33.3914340287447, 64.59812209010124, 84.18670937418938, 57.28449873626232, 58.45930449664593, 64.60882231593132, 58.207868188619614, 3.3766783587634563, 0.5130206840112805, 4.214143920689821, 7.144662570208311, 5.193628761917353, 69.1351318359375, 63.98735046386719, 61.96199454367161, 59.35087725520134, 54.584226831793785, 49.26999159157276, 46.99166424572468, 51.361988335847855, 52.68976628780365, 54.751493856310844, 54.26165834069252, 51.600927114486694, 53.7834046036005, 48.98238122463226, 52.25719749927521, 52.00570039451122, 52.75598153471947, 53.19138117134571, 51.04393020272255, 51.796768605709076, 44.65148001909256, 41.842955723404884, 45.43661668896675, 43.494065925478935, 44.14500519633293, 40.52850365638733, 41.50603540241718, 41.61888934671879, 39.66784983873367, 43.453126922249794, 41.65943697094917, 41.99350364506245, 41.61728963255882, 42.74082854390144, 41.18235357105732, 41.44368834793568, 41.456919237971306, 39.00736168026924, 41.29455395042896, 40.99055886268616, 40.57917393743992, 44.57492172718048, 41.85118608176708, 42.93387718498707, 44.840713664889336, 43.28986868262291, 43.21530528366566, 43.98756064474583, 42.325526028871536, 42.62474477291107, 43.885429725050926, 43.818336725234985, 43.758790120482445, 42.45623141527176, 41.63082830607891, 42.390388548374176, 44.22142669558525, 42.169491201639175, 47.10876636207104, 52.154679000377655, 53.48076604306698, 54.60455574095249, 55.12691751122475, 51.708598136901855, 55.24719625711441, 56.362994983792305, 56.53401620686054, 46.854210421442986, 44.6176428347826, 45.34094922244549, 41.61405600607395, 44.046092703938484, 44.43177580833435, 48.34590017795563, 48.82039211690426, 49.03262212872505, 49.07817028462887, 48.69889743626118, 50.396311953663826, 45.91774307191372, 41.64221629500389, 42.204099744558334, 42.564343214035034, 45.50777167081833, 43.98452840745449, 44.27411466836929, 45.280714854598045, 41.936837285757065, 44.47273761034012, 44.10504654049873, 43.8790612667799, 41.694296300411224, 40.82417719066143, 43.78117851912975, 43.587225526571274, 44.24979977309704, 43.95501919090748, 44.60930608212948, 43.550979271531105, 41.28756232559681, 40.946986600756645, 42.35111765563488, 43.66612829267979, 41.20700664818287, 43.99150103330612, 43.24746295809746, 44.82372097671032, 47.18560203909874, 53.38839299976826, 54.12645399570465, 54.93356488645077, 56.854054033756256, 58.2903503626585, 60.41480876505375, 60.55149883031845, 58.60939644277096, 61.78895942866802, 57.66898110508919, 63.488726019859314, 53.62101651728153, 56.07397869229317, 49.74299021065235, 53.691677525639534, 55.09040907025337, 69.44711029529572, 61.406319960951805, 82.34685570001602, 21.46603424102068, 1.2147222622297704, 10.690826084464788, 0.6366769736632705, 0.2159379151999019, 28.60422670841217, 76.79925218224525, 69.61623162031174, 64.05444726347923, 60.956173315644264, 49.096622094511986, 40.13994790613651, 59.85368147492409, 66.65625125169754, 69.91261571645737, 13.16340945661068, 0.4375715466449037, 0.18014653731370345, 0.18906074023107067, 0.15820966131286696, 0.08470227912766859, 0.1739195769187063, 0.09209381765685976, 0.09316042487625964], [0.005239993506620522, 0.08148342880303971, 0.039180480598588474, 0.0983493062085472, 0.02137260999006685, 0.029745019128313288, 0.01445216546926531, 0.24158299143891782, 0.02924803993664682, 13.680484760552645, 57.290118634700775, 51.61042280495167, 41.65991574525833, 22.488671466708183, 48.07674542069435, 74.83629271388054, 37.89823539555073, 45.836883410811424, 58.21697250008583, 46.21951527893543, 2.3983553051948547, 0.6623245880473405, 0.5744394601788372, 0.9464409830980003, 13.93419524654746, 67.39056184887886, 58.29220466315746, 57.82421797513962, 49.93462912738323, 48.29102352261543, 49.31802861392498, 53.25942412018776, 53.8389690220356, 54.44042734801769, 53.59710820019245, 53.0963558703661, 52.53921076655388, 52.815174758434296, 51.26518853008747, 51.25492908060551, 50.460847690701485, 49.45291377604008, 47.480147033929825, 46.491770669817924, 45.5953873693943, 44.055482000112534, 41.73522390425205, 39.92758870124817, 37.41169050335884, 38.38745914399624, 35.95364034175873, 39.0145318955183, 38.16670618951321, 36.244172751903534, 38.41463528573513, 37.875113636255264, 38.026980087161064, 39.208709076046944, 37.34265960752964, 36.42025910317898, 35.95872066915035, 36.514136865735054, 38.518810495734215, 37.81144805252552, 36.23732931911945, 37.559760957956314, 38.115355744957924, 39.54692132771015, 39.67964060604572, 39.67642977833748, 39.2301969230175, 38.61771538853645, 39.59951430559158, 39.36425752937794, 37.59300917387009, 38.125877380371094, 39.04496446251869, 41.10965207219124, 38.43327708542347, 37.143299505114555, 38.43265011906624, 38.988833874464035, 40.13797581195831, 39.89166922867298, 48.57985742390156, 53.36301416158676, 51.73442915081978, 52.9104470461607, 48.844999596476555, 50.194459185004234, 52.18304067850113, 51.24523960053921, 44.71905179321766, 39.09824140369892, 38.26043576002121, 38.04933808743954, 39.69146557152271, 39.014543294906616, 41.66742414236069, 41.948601454496384, 43.11203442513943, 44.91193704307079, 45.211710557341576, 43.904242515563965, 40.982332304120064, 41.24418765306473, 38.772576078772545, 39.9637171626091, 40.24392932653427, 40.289819464087486, 40.7558910548687, 40.31946927309036, 40.68041950464249, 39.6289437264204, 39.67760771512985, 39.48836266994476, 37.86975972354412, 37.78568543493748, 37.97568663954735, 38.87414462864399, 39.008444622159004, 39.68466393649578, 39.599472507834435, 38.21102701127529, 39.98946078121662, 38.91082786023617, 38.63889545202255, 38.80879573523998, 38.31636495888233, 40.030772164464, 38.99546831846237, 38.96567031741142, 39.81267906725407, 46.175939217209816, 47.25984625518322, 53.18195387721062, 50.21130368113518, 52.742336466908455, 49.290069714188576, 50.94747617840767, 48.01350921392441, 50.480990409851074, 45.123566687107086, 45.51122948527336, 41.24586336314678, 46.621461510658264, 45.20301662385464, 54.69249062240124, 54.19190168380737, 63.65502789616585, 57.91349798440933, 75.4751980304718, 24.514145180583, 0.7232946914155036, 2.153081316500902, 1.233863141387701, 0.14503530808724463, 21.705054715275764, 66.12255468964577, 59.00101862847805, 58.41463029384613, 41.09105207026005, 52.64143668115139, 30.269565246999264, 36.67172580957413, 56.92746229469776, 46.086362823843956, 7.855059150606394, 0.24908046412747353, 0.03309735213406384, 0.005510318942469894, 0.05076408851891756, 0.024389878162764944, 0.039278095282497816, 0.02975965242512757, 0.07216090365545824, 0.07135680149076506, 0.06796602523536421, 0.021908911876380444, 0.08935340767493472, 0.07141782087273896, 0.038041491716285236, 0.04670360933232587, 0.15553295728750527, 0.09035006747581065, 16.049409694969654, 65.66575080156326, 55.07150128483772, 52.85952977836132, 22.60432966053486, 51.75801828503609, 88.47911864519119, 44.7676207870245, 52.34316028654575, 62.14373119175434, 51.28824569284916, 1.9378189486451447, 0.516543451230973, 1.4961663912981749, 1.288357323501259, 14.221372436732054, 69.1688284277916, 58.52667108178139, 59.8642411082983, 51.20225250720978, 51.06347635388374, 50.62238082289696, 55.28972737491131, 55.400799214839935, 55.56116960942745, 55.69099344313145, 55.29260002076626, 54.85821112990379, 53.79419602453709, 54.09518547356129, 52.350338101387024, 50.79466737806797, 51.20783060789108, 48.85045610368252, 49.4067120552063, 48.03401291370392, 46.153273433446884, 43.1512825191021, 43.11297297477722, 40.740874260663986, 42.488480284810066, 37.67803721129894, 41.17761142551899, 39.86914403736591, 39.60950016975403, 39.66568395495415, 39.703480526804924, 39.614667892456055, 40.9186477214098, 39.89399470388889, 38.05310748517513, 37.90077745914459, 39.5118872076273, 38.93801920115948, 38.55829417705536, 39.38068404793739, 38.51292081177235, 39.51070927083492, 40.027770325541496, 41.70476853847504, 41.80213451385498, 42.43656367063522, 39.68227006494999, 40.36570519208908, 40.44045478105545, 39.36830051243305, 41.39429859817028, 41.22996501624584, 41.292274072766304, 40.98911873996258, 40.09365878999233, 40.344038754701614, 40.20651273429394, 42.603781297802925, 42.295811623334885, 48.53072226047516, 55.15012286603451, 53.8283371925354, 54.06283400952816, 50.47749079763889, 53.32106441259384, 55.57285398244858, 52.7460602670908, 48.431254997849464, 41.59216918051243, 41.410405933856964, 41.14682547748089, 41.375360414385796, 41.48324802517891, 44.14272911846638, 44.02145482599735, 45.1734884083271, 45.53636513650417, 47.52615876495838, 46.4625958353281, 44.7404408454895, 40.74053227901459, 40.7206479460001, 42.28714808821678, 41.343692913651466, 42.83352077007294, 42.42956064641476, 41.10441215336323, 41.94508284330368, 40.91481752693653, 41.9074534624815, 41.329747661948204, 39.37024600803852, 39.650735557079315, 39.69122238457203, 41.18095904588699, 40.44011279940605, 42.38701052963734, 40.82789719104767, 41.0303845256567, 42.0020417869091, 42.06928677856922, 41.059202179312706, 41.736451238393784, 40.76887495815754, 42.80870050191879, 40.53185887634754, 40.03030098974705, 42.98969618976116, 48.2042171806097, 48.093251734972, 54.79170709848404, 51.75217419862747, 53.98516237735748, 51.560178101062775, 54.72837969660759, 50.85578329861164, 52.3733876645565, 47.29940593242645, 48.8531843572855, 43.02172467112541, 47.755427062511444, 47.485356554389, 57.65361852943897, 54.52629514038563, 68.7064616382122, 59.69217874109745, 77.79587790369987, 25.78243352472782, 0.45455562591087073, 3.2442459650337696, 0.8611715398728848, 0.1567118291859515, 22.835083678364754, 71.64990529417992, 64.07538414001465, 61.81853324174881, 49.94028702378273, 64.92490455508232, 39.05381038784981, 43.612832352519035, 63.046976923942566, 57.91450873017311, 10.435714423656464, 0.2581647672923282, 0.0276477951410925, 0.02221158010797808, 0.012420633611327503, 0.03705279515997972, 0.0802867156744469, 0.10610751021886244, 0.03925631695892662, 0.12993687763810158, 0.2318345700041391, 0.11845468048704788, 0.2470595366321504, 0.18325903045479208, 0.15985638310667127, 0.1194866665173322, 0.4992192902136594, 0.1616237632697448, 18.785031102597713, 74.73709523677826, 63.56485493481159, 57.82590888440609, 31.539994776248932, 56.7541877925396, 76.70672714710236, 49.826403334736824, 58.12076546251774, 67.97205984592438, 58.75723510980606, 2.7876458410173655, 0.7166495604906231, 3.414266654290259, 2.2273340821266174, 16.271492578089237, 72.72100701928139, 61.54336340725422, 64.05153661966324, 54.027860686182976, 53.467170372605324, 52.54185542464256, 59.53257590532303, 58.72627817094326, 59.30872231721878, 58.43139499425888, 57.689515203237534, 57.22272165119648, 55.28837464749813, 56.13195218145847, 53.77507545053959, 53.32342028617859, 53.456006571650505, 52.349756732583046, 52.307806983590126, 51.188983619213104, 48.29540468752384, 46.25227332115173, 45.051929131150246, 43.14891904592514, 44.28208664059639, 39.80395473539829, 45.35821549594402, 43.24774794280529, 40.90619958937168, 43.84666420519352, 40.1311019808054, 42.62567572295666, 44.56355653703213, 40.83618834614754, 41.056371331214905, 38.97448964416981, 41.54709979891777, 43.46698857843876, 41.264311373233795, 41.9300052523613, 40.55882602930069, 42.96528249979019, 42.009922564029694, 43.517742455005646, 43.79006244242191, 43.71795371174812, 41.04038938879967, 42.194847241044044, 43.5071562230587, 41.40591077506542, 43.42357590794563, 43.953130692243576, 45.16917943954468, 43.274395912885666, 41.17913134396076, 42.58715718984604, 43.55696015059948, 45.647140592336655, 43.680909499526024, 51.87678851187229, 56.79952695965767, 56.56798638403416, 55.07758475840092, 53.51826623082161, 54.82387237250805, 58.3972842246294, 56.98296211659908, 49.10172142088413, 43.76410223543644, 43.05814191699028, 42.44318671524525, 43.4011685103178, 42.803935557603836, 45.29449671506882, 46.023821979761124, 46.758588552474976, 48.959084674715996, 50.160082429647446, 48.526930063962936, 46.56235188245773, 44.64934453368187, 41.882086023688316, 44.04960751533508, 43.74372012913227, 45.60152404010296, 44.744601622223854, 43.97067055106163, 44.292338490486145, 43.340356573462486, 42.98764809966087, 43.18593665957451, 40.838441625237465, 42.08189830183983, 41.183147728443146, 42.5696325302124, 43.22542034089565, 44.472255036234856, 44.81072187423706, 42.07665838301182, 44.64925713837147, 45.0241906195879, 44.33681510388851, 44.43737290799618, 42.20823012292385, 45.507201701402664, 42.85618655383587, 42.14638464152813, 44.920144602656364, 49.61081810295582, 51.98536388576031, 57.24808149039745, 55.714426785707474, 55.30611589550972, 53.71722735464573, 56.59224808216095, 54.02280695736408, 56.40275225043297, 49.80900786817074, 51.63164086639881, 46.33571684360504, 50.923453867435455, 51.13909609615803, 58.86818155646324, 57.85766378045082, 70.82309246063232, 63.75902831554413, 77.12228044867516, 29.431590512394905, 0.8953127672430128, 10.192338433116674, 2.897548293694854, 0.21975601266603917, 25.712061300873756, 77.87115186452866, 71.99232771992683, 70.56626424193382, 56.753002256155014, 70.41715264320374, 43.10779385268688, 53.96565802395344, 72.21253350377083, 71.5761436522007, 14.560605883598328, 0.4506330192089081, 0.17564808338647708, 0.08113739502732642, 0.13399507472058758, 0.15059543395182118, 0.18877851631259546, 0.3061816922854632, 0.13811739336233586], [0.015303074887924595, 0.06154183538455982, 0.02649437519721687, 0.03637483583588619, 0.046369809861062095, 0.022271859197644517, 0.05697295906429645, 0.07821986408089288, 0.028780696557078045, 12.560142427682877, 61.71601474285126, 51.266263872385025, 37.11205378174782, 29.025255516171455, 41.65850222110748, 41.922515854239464, 32.281202003359795, 50.42981095612049, 56.642811968922615, 46.38011746108532, 1.0138490097597241, 0.44250098057091236, 0.5112488509621471, 0.576346245361492, 24.07929841428995, 71.74283310770988, 56.655495688319206, 56.05650722980499, 51.221449077129364, 55.90671926736832, 56.352602541446686, 56.54386907815933, 54.28614802658558, 55.28384909033775, 55.17583228647709, 54.087981060147285, 54.5263597369194, 53.45015488564968, 50.21933265030384, 49.28250432014465, 49.63844262063503, 46.91485896706581, 45.42937807738781, 45.334831550717354, 44.91822950541973, 44.07475456595421, 41.37025348842144, 38.79430331289768, 38.18039305508137, 37.77017466723919, 36.657043397426605, 38.23935829102993, 36.163343489170074, 37.802636325359344, 38.529256135225296, 38.34354490041733, 38.47287856042385, 38.34664173424244, 36.65037855505943, 36.24644123017788, 37.82697781920433, 36.52172885835171, 37.910409942269325, 37.108261585235596, 37.1501125395298, 37.5270789116621, 38.558043390512466, 38.88316534459591, 39.617342948913574, 39.323835298419, 39.978220984339714, 38.71111057698727, 40.82220509648323, 37.990741431713104, 38.85635778307915, 38.555854707956314, 39.340554401278496, 39.800705909729004, 38.86857412755489, 37.924670577049255, 39.69130218029022, 38.36619168519974, 39.04802329838276, 38.34535360336304, 44.166994616389275, 52.50748246908188, 52.205349281430244, 52.95586220920086, 52.07900986075401, 49.66977573931217, 51.385391280055046, 51.0564049333334, 45.47972157597542, 41.305162981152534, 40.295279771089554, 40.553137734532356, 39.86902244389057, 41.761062517762184, 40.73363184928894, 41.54126711189747, 43.76243032515049, 44.30444844067097, 43.388332799077034, 43.57008844614029, 42.729467153549194, 40.752167254686356, 39.20531965792179, 39.42466288805008, 40.39198458194733, 41.12097546458244, 40.1750960201025, 41.590888649225235, 41.34950280189514, 39.16792966425419, 41.47069729864597, 40.65955862402916, 37.44556948542595, 38.22150684893131, 39.80998121201992, 38.63918423652649, 39.98670592904091, 39.89394150674343, 38.68632450699806, 39.61515426635742, 38.11191312968731, 39.266344383358955, 37.941401079297066, 37.80300110578537, 39.39495608210564, 39.30537208914757, 40.66940389573574, 40.109610334038734, 40.40091410279274, 43.26102823019028, 43.965597823262215, 47.30554640293121, 45.221605226397514, 44.03581045567989, 44.074450582265854, 44.52868200838566, 43.09676684439182, 42.76061028242111, 39.49855752289295, 42.98116944730282, 43.697598204016685, 45.47926940023899, 46.204175502061844, 53.86250115931034, 55.65226972103119, 68.24429243803024, 58.71685467660427, 74.4770447909832, 34.680746644735336, 0.12210560918902047, 1.9171688379719853, 0.5781973397824913, 0.0323632678919239, 19.397487938404083, 66.72002702951431, 59.55594465136528, 61.59968018531799, 30.85276935249567, 12.691331338137388, 13.765004575252533, 40.421816781163216, 54.548014774918556, 49.5685263723135, 4.621992660686374, 0.25033671234268695, 0.07914387504570186, 0.03829056760878302, 0.04759439434565138, 0.11704134187311865, 0.05031764587329235, 0.05743879402871244, 0.10902235459070653, 0.025918999235727824, 0.05821325852593873, 0.10790639455080964, 0.00928186937017017, 0.07923212382593192, 0.047438580440939404, 0.04684173043642659, 0.17115092079620808, 0.04562608512060251, 15.058515965938568, 68.19876328110695, 56.53323344886303, 44.47480849921703, 28.646318949759007, 46.40850193798542, 49.22614574432373, 41.09468087553978, 57.64016345143318, 61.73307962715626, 50.45830562710762, 1.4369918103329837, 0.3746659815078601, 0.7252179819624871, 0.4287004179786891, 27.166866436600685, 72.84696266055107, 58.091837614774704, 59.76024828851223, 54.03081692755222, 58.857678920030594, 57.814988270401955, 57.98401840031147, 54.798820316791534, 55.46283848583698, 56.96436211466789, 56.60416804254055, 56.49283401668072, 55.0481553375721, 53.35599213838577, 52.307841181755066, 50.55430367588997, 49.87276464700699, 48.54381635785103, 47.81664937734604, 48.61391119658947, 45.80374538898468, 43.34288343787193, 43.007920011878014, 40.66642865538597, 39.38736408948898, 40.38176313042641, 39.739513993263245, 38.42130772769451, 39.263916313648224, 39.37861695885658, 40.520250499248505, 39.86459568142891, 38.53469364345074, 39.06291089951992, 37.08695612847805, 38.575526252388954, 39.03303310275078, 39.25920456647873, 39.59984868764877, 38.26149210333824, 39.60813984274864, 39.919723123312, 39.114356338977814, 41.42087057232857, 40.44612027704716, 40.39224296808243, 40.313837975263596, 42.539560943841934, 40.27291797101498, 41.56244717538357, 41.18283234536648, 41.79634362459183, 40.67201055586338, 40.173298716545105, 39.133465513587, 41.78400568664074, 39.79424625635147, 40.98658427596092, 40.80275774002075, 45.0092726200819, 52.49210849404335, 54.53554384410381, 54.32877413928509, 52.42372736334801, 51.919787004590034, 54.38833214342594, 52.70657278597355, 49.040692895650864, 43.21039594709873, 41.125968396663666, 42.29623340070248, 41.653839871287346, 44.26838077604771, 42.655481323599815, 43.87581244111061, 44.39888097345829, 47.10749343037605, 45.46113297343254, 46.236865147948265, 44.72280979156494, 42.2150469571352, 41.09618939459324, 41.30509078502655, 41.55761383473873, 43.031391352415085, 42.627989798784256, 43.179613798856735, 43.90863128006458, 41.67685903608799, 42.249788492918015, 41.60623982548714, 39.71879370510578, 39.84362840652466, 40.90905703604221, 40.61567097902298, 42.021405547857285, 41.17394462227821, 42.75908276438713, 42.50123240053654, 40.11269576847553, 40.672356337308884, 39.91527356207371, 40.44411018490791, 41.21962197124958, 41.495395973324776, 41.51048496365547, 39.97805759310722, 41.40507102012634, 44.387899562716484, 44.70316104590893, 49.62618827819824, 47.13461257517338, 47.31077492237091, 46.11257381737232, 46.16337329149246, 43.849267065525055, 44.83652248978615, 40.94054214656353, 44.86060559749603, 44.44389335811138, 46.69658727943897, 48.33237290382385, 57.28943087160587, 58.23448196053505, 71.27786725759506, 60.165481343865395, 77.58043706417084, 37.220021188259125, 0.18450807983754203, 2.402919572778046, 0.531647284515202, 0.0658915814710781, 20.6152218952775, 72.20476672053337, 63.689944222569466, 66.34516954421997, 39.05790276825428, 20.357704013586044, 18.48472561687231, 47.57820837199688, 61.26529812812805, 58.267836570739746, 6.483883252367377, 0.1557163122924976, 0.02047155736363493, 0.04484945355216041, 0.06794104454456829, 0.01614276767213596, 0.03799663631070871, 0.07359354553045705, 0.015405315934913233, 0.12975288438610733, 0.17275064979912713, 0.1787363231414929, 0.20362074254080653, 0.15722226351499557, 0.08196569120627828, 0.25203741795849055, 0.384321411838755, 0.12905664596473798, 18.269622959196568, 78.96150335669518, 61.89157672226429, 50.90159364044666, 40.225006341934204, 53.44401441514492, 47.53352276980877, 45.104176327586174, 62.78458960354328, 67.31688380241394, 56.35402366518974, 1.8170395796187222, 0.6238631112501025, 2.8931752033531666, 0.9908034838736057, 27.91707158088684, 73.35993513464928, 61.23846396803856, 61.70869253575802, 56.79212495684624, 61.951298117637634, 60.89953735470772, 61.47381953895092, 58.034753277897835, 58.711987137794495, 59.57790747284889, 58.12078446149826, 58.710049241781235, 57.58704990148544, 56.05623744428158, 54.08814825117588, 54.23730164766312, 53.219906240701675, 50.37355877459049, 49.606303945183754, 49.64298337697983, 48.34153801202774, 46.30078911781311, 44.16963167488575, 43.05866628885269, 42.95374631881714, 43.949262499809265, 41.09232880175114, 40.57674966752529, 42.109849601984024, 41.9938950240612, 42.36265383660793, 42.54898443818092, 40.71611858904362, 41.68206475675106, 41.10668443143368, 41.44531466066837, 41.07973247766495, 41.410405933856964, 40.044113248586655, 41.13110572099686, 40.32324247062206, 41.80906534194946, 40.80852583050728, 44.14673790335655, 43.502615466713905, 43.797852024436, 40.93895763158798, 44.68780606985092, 42.22923919558525, 42.723577469587326, 44.90496061742306, 44.979957193136215, 44.031619280576706, 42.79158242046833, 40.28098873794079, 44.54849414527416, 42.70586282014847, 44.91629920899868, 43.45547519624233, 49.50579173862934, 57.613154500722885, 57.15777553617954, 56.84760197997093, 56.07701852917671, 55.00514544546604, 56.662510111927986, 54.71055865287781, 51.171439960598946, 45.97316309809685, 43.62812653183937, 45.73590762913227, 43.8109727203846, 46.037501245737076, 45.46643748879433, 46.81835554540157, 47.06941567361355, 49.67742092907429, 47.34622702002525, 48.336225897073746, 48.119436129927635, 45.58572828769684, 43.18752497434616, 42.83828191459179, 44.04236130416393, 44.563666731119156, 44.53329496085644, 46.25913955271244, 45.24742864072323, 43.07405926287174, 45.852945148944855, 44.28309738636017, 41.610791981220245, 42.433922812342644, 43.77033770084381, 41.19964264333248, 45.64147889614105, 43.039667308330536, 44.82913188636303, 44.878065660595894, 42.44898520410061, 42.58662901818752, 41.32833793759346, 41.653520688414574, 42.96275943517685, 44.13112834095955, 45.42114391922951, 42.19954378902912, 45.09977616369724, 46.55101329088211, 46.231796219944954, 51.797916144132614, 49.034047052264214, 48.88699874281883, 48.94450485706329, 48.68226572871208, 47.977164164185524, 47.42537297308445, 42.984391674399376, 46.26367270946503, 46.62828594446182, 47.93149821460247, 50.11713333427906, 60.68652078509331, 60.04812844097614, 73.11010614037514, 62.475654780864716, 77.11044028401375, 40.29347866773605, 0.24718749773455784, 7.984456457197666, 1.3161883363500237, 0.12513981317169964, 23.218190521001816, 79.79210838675499, 69.98443946242332, 74.8727023601532, 41.742025539278984, 23.59740637242794, 23.24288159608841, 56.986720114946365, 70.01471623778343, 73.20858165621758, 9.706790037453175, 0.3686052473494783, 0.18070233170874417, 0.18127086135791615, 0.12389041497954167, 0.22251254209550098, 0.1691704848781228, 0.17173270520288497, 0.14731064380612224], [0.06039684623829089, 0.09380636794958264, 0.028861599930678494, 0.014566570316674188, 0.040558752734796144, 0.03512436152959708, 0.04070050665177405, 0.0885360804386437, 0.14181760809151456, 13.255588710308075, 59.59684185683727, 49.39827270805836, 44.51632507145405, 30.507535077631474, 48.42626966536045, 65.61118572950363, 33.94544430077076, 52.3866755515337, 52.39929847419262, 48.013163432478905, 0.9193862567190081, 0.16960090084467083, 1.010216879658401, 0.1650036225328222, 35.943665876984596, 66.64718493819237, 56.80806890130043, 55.043606981635094, 52.03975796699524, 55.3194759786129, 55.100178346037865, 56.02618865668774, 53.71219642460346, 55.10876588523388, 53.36595140397549, 51.05536758899689, 53.788963705301285, 52.99918368458748, 50.340751335024834, 50.93774110078812, 49.69258591532707, 48.44849847257137, 45.05882956087589, 44.869337528944016, 43.3943934738636, 40.69656863808632, 39.63586315512657, 38.272823095321655, 36.96594402194023, 37.187460735440254, 37.424461618065834, 39.40465696156025, 39.5608551800251, 38.65899637341499, 38.19905385375023, 35.616454035043716, 37.85878211259842, 36.818667724728584, 34.758076295256615, 35.31729608774185, 37.73833617568016, 37.49205619096756, 35.169514417648315, 38.92128109931946, 36.653030812740326, 36.07041947543621, 39.0658937394619, 38.03692415356636, 39.019456431269646, 37.35185891389847, 39.229300171136856, 36.57739207148552, 37.87760250270367, 37.04793222248554, 40.244069918990135, 40.57457618415356, 38.66648577153683, 38.87005604803562, 40.25474354624748, 38.30828279256821, 36.53617188334465, 38.0721140652895, 39.11942146718502, 41.083809658885, 39.0646056085825, 46.58289737999439, 48.08826260268688, 55.3184500336647, 49.99687738716602, 50.85607968270779, 54.555276185274124, 52.10709795355797, 48.67590107023716, 43.41504916548729, 39.77052792906761, 39.76089544594288, 40.14876343309879, 38.88594679534435, 39.23406131565571, 40.04880979657173, 40.84858328104019, 41.67229548096657, 42.67811290919781, 43.750738352537155, 41.232275292277336, 39.305113703012466, 39.277979359030724, 40.991132631897926, 38.98139387369156, 41.36733144521713, 41.88247360289097, 40.238153636455536, 39.924917444586754, 38.66854526102543, 39.08103212714195, 39.731188639998436, 39.11895789206028, 37.85668462514877, 38.57166565954685, 38.80952149629593, 38.595832362771034, 40.85371680557728, 38.12984436750412, 38.3093923330307, 38.31577979028225, 37.56090089678764, 37.633628994226456, 40.06476894021034, 38.329565450549126, 38.79610441625118, 39.197853058576584, 40.10511137545109, 39.72705066204071, 39.66858319938183, 39.569013342261314, 42.34425142407417, 39.56604190170765, 40.827251225709915, 38.474246487021446, 42.33591467142105, 40.7109584659338, 43.17402429878712, 40.31620144844055, 46.24700300395489, 43.14600460231304, 46.799903735518456, 48.36556792259216, 55.461022183299065, 55.006733760237694, 66.58595502376556, 60.000125616788864, 72.58478432893753, 41.93011924624443, 1.0033886460587382, 1.9949463894590735, 0.6251691724173725, 0.02073904779535951, 15.082195345312357, 67.18584403395653, 61.91643878817558, 57.96640254557133, 36.5561094135046, 27.66074113547802, 32.77001917362213, 44.67169493436813, 50.57193472981453, 47.8094145655632, 5.227295430377126, 0.2702192048309371, 0.07027254599961452, 0.07360826231888495, 0.025150928340735845, 0.06045505288057029, 0.024160304055840243, 0.04431316650880035, 0.037849913715035655, 0.05645551886118483, 0.05468292139994446, 0.031467217340832576, 0.022788865244365297, 0.008518196627846919, 0.05267375323455781, 0.078310843964573, 0.1711022507515736, 0.021086076048959512, 15.51154475659132, 69.80591744184494, 55.697114914655685, 52.172488644719124, 41.97238817811012, 46.90415494143963, 51.46787725389004, 36.9223565608263, 58.005168065428734, 59.87893871963024, 51.81389808654785, 1.0242896620184183, 0.2759982494171709, 1.3952827546745539, 0.08277884757262655, 39.01836208999157, 69.00739029049873, 58.39775159955025, 55.66240377724171, 53.97082194685936, 55.845303162932396, 57.387268021702766, 56.3933477550745, 55.83686001598835, 57.97376275062561, 56.25094659626484, 52.93282404541969, 54.02225598692894, 53.374052569270134, 52.53778584301472, 51.75213240087032, 52.164368480443954, 51.43958777189255, 47.20796383917332, 47.576061487197876, 45.094711035490036, 44.081981778144836, 42.72991172969341, 40.786297023296356, 37.506153434515, 39.16743949055672, 39.0888749063015, 39.356984719634056, 41.283219158649445, 38.920718729496, 39.21445056796074, 38.85058209300041, 39.84435796737671, 39.16686572134495, 38.2202985137701, 37.934189066290855, 37.47743457555771, 40.44578969478607, 38.92576485872269, 40.17284654080868, 38.529890701174736, 39.34790700674057, 40.8693415671587, 40.429226383566856, 40.15328899025917, 40.32416582107544, 39.90861251950264, 38.85601580142975, 39.05338481068611, 39.160140082240105, 42.07285858690739, 43.10666151344776, 41.64774879813194, 41.29325442016125, 41.99659667909145, 40.35734944045544, 39.70242038369179, 38.77953730523586, 42.314050644636154, 42.51523844897747, 40.45791104435921, 49.044431895017624, 51.04396440088749, 55.05861237645149, 52.49348022043705, 53.77051569521427, 57.405788227915764, 53.199797719717026, 49.806226417422295, 43.7337950617075, 42.5020607560873, 42.29703135788441, 41.05194836854935, 40.895841345191, 40.69561488926411, 42.80476771295071, 43.30518566071987, 44.48229029774666, 46.487191915512085, 45.02436921000481, 42.66674391925335, 40.938505455851555, 40.65477468073368, 42.17009536921978, 40.91742418706417, 42.179857045412064, 41.97823606431484, 41.50960721075535, 41.26735121011734, 41.23855635523796, 40.87262079119682, 41.77398942410946, 40.977050587534904, 38.80372300744057, 38.84064182639122, 39.97718743979931, 39.30975325405598, 42.66564577817917, 40.609724298119545, 40.70246212184429, 40.02595782279968, 40.78964464366436, 39.35114063322544, 41.663639545440674, 41.556527093052864, 41.62921719253063, 41.05316810309887, 41.74266770482063, 41.93537436425686, 41.28006532788277, 40.796655267477036, 44.11445863544941, 40.241041481494904, 44.32602748274803, 43.200254291296005, 43.96778650581837, 43.75847853720188, 43.479907885193825, 44.98867392539978, 47.17786565423012, 45.77590808272362, 49.42889906466007, 49.88761804997921, 58.133437782526016, 58.022130355238914, 68.9587453007698, 61.18283495306969, 74.01951134204865, 47.763463631272316, 1.2712058750912547, 1.2344985385425389, 1.3772619841620326, 0.10240569987217896, 15.709643326699734, 72.16527923941612, 67.93447226285934, 64.78237420320511, 41.88890665769577, 23.859383314847946, 31.90797083079815, 50.41390880942345, 58.66966500878334, 57.54244789481163, 7.055259067565203, 0.22487273497972637, 0.0360045004345011, 0.09890954606817104, 0.02789220478007337, 0.07494821737054735, 0.07824230662663467, 0.02676171719940612, 0.039692057835054584, 0.21950329653918743, 0.15282202541129664, 0.16561420226935297, 0.19548466661944985, 0.12298316170927137, 0.14168182475259528, 0.18080887442920357, 0.2658425224944949, 0.18369682336924598, 19.164526239037514, 77.64779224991798, 62.71637566387653, 57.24770911037922, 41.1909981071949, 58.31720732152462, 71.64409160614014, 46.78451456129551, 64.10705164074898, 64.84798908233643, 58.05250592529774, 0.9895303146913648, 0.299148655612953, 4.221504600718617, 0.6346051942091435, 42.544808462262154, 70.56686460971832, 61.729314029216766, 58.296870812773705, 57.633631601929665, 58.43601554632187, 59.38270814716816, 59.044214710593224, 57.931843400001526, 60.42460463941097, 57.403379157185555, 53.289203122258186, 56.11231863498688, 56.49089232087135, 55.19584581255913, 54.570334777235985, 54.266567677259445, 51.549253687262535, 49.127852618694305, 49.19514700770378, 46.883742436766624, 47.288698107004166, 44.475667253136635, 42.26105108857155, 40.349518060684204, 41.156093180179596, 40.96930280327797, 42.34750784933567, 43.493602350354195, 41.08293570578098, 42.81435079872608, 40.36132402718067, 42.234695702791214, 40.63567690551281, 39.272697642445564, 39.666736498475075, 39.83812250196934, 41.970237493515015, 39.78785499930382, 43.36938701570034, 40.99927939474583, 41.65176518261433, 42.590447813272476, 42.321186661720276, 43.395844995975494, 42.1316984295845, 42.272325083613396, 40.46386532485485, 41.760317757725716, 41.55593812465668, 45.02129137516022, 45.49493595957756, 43.03437799215317, 43.72210308909416, 46.23116545379162, 43.398573249578476, 41.56858764588833, 42.34823741018772, 42.9015789180994, 45.16401171684265, 43.481006026268005, 51.51131272315979, 52.64191545546055, 58.97478483617306, 53.18637304008007, 53.44282887876034, 58.882590383291245, 56.084808111190796, 53.22203412652016, 47.40942522883415, 45.54706156253815, 44.623460322618484, 44.61535915732384, 43.317459002137184, 42.21265688538551, 43.75452674925327, 44.70951810479164, 45.996262058615685, 49.338973090052605, 47.930122688412666, 44.953263625502586, 42.72285930812359, 42.4506951123476, 45.00354252755642, 41.74134157598019, 43.37367698550224, 44.10001941025257, 44.19456593692303, 43.73819522559643, 42.46753200888634, 43.147026747465134, 43.907605335116386, 43.53636525571346, 43.336461782455444, 42.20804773271084, 41.93653330206871, 41.405963972210884, 45.1149183511734, 43.253687024116516, 42.860883101820946, 42.11686782538891, 42.68427237868309, 41.47998780012131, 46.207967698574066, 43.777321726083755, 43.39273676276207, 44.7019375115633, 44.52496200799942, 43.82706105709076, 42.79557600617409, 43.82073059678078, 46.45125724375248, 42.82257355749607, 45.94383247196674, 44.12084989249706, 47.61397585272789, 46.54694750905037, 46.45675554871559, 46.45944580435753, 50.42135640978813, 47.74658493697643, 50.96090465784073, 52.19019189476967, 59.24036778509617, 60.60754582285881, 71.77934154868126, 65.30595570802689, 74.71571758389473, 50.44843755662441, 2.3252545902505517, 5.469833565875888, 2.520405943505466, 0.20622896117856726, 17.570965848863125, 80.01829504966736, 73.92719149589539, 72.71019279956818, 48.849680945277214, 40.08133605122566, 44.840489476919174, 62.16412469744682, 65.69575399160385, 71.06734335422516, 11.744563691318035, 0.3992091614054516, 0.16707802918972448, 0.18469254806404933, 0.09354528039693832, 0.13776039064396173, 0.1945586592773907, 0.13201039371779189, 0.09574948126100935], [0.03596614995331038, 0.053711101281805895, 0.022139907196105924, 0.0794719488476403, 0.013948724954389036, 0.08498103721649386, 0.009356623122585006, 0.11313789742416702, 0.054965319723123685, 11.688144318759441, 58.47026310861111, 53.07367108762264, 37.55594976246357, 26.30867298692465, 62.15153977274895, 95.22278398275375, 51.601998656988144, 51.428910344839096, 52.711740508675575, 48.53207878768444, 1.5585396881215274, 0.24581341131124645, 0.2469444740563631, 0.015712607746536378, 42.37768203020096, 69.35160622000694, 54.92971569299698, 53.574480414390564, 56.00990653038025, 55.12540899217129, 55.273620039224625, 53.81720378994942, 51.38725697994232, 49.46743659675121, 50.42963236570358, 47.55336530506611, 48.137614354491234, 47.93584518134594, 47.152198031544685, 46.18892692029476, 44.62837725877762, 41.51004038751125, 42.112885639071465, 38.57817471027374, 39.495335295796394, 35.93103915452957, 37.543262243270874, 36.6261700540781, 38.39828096330166, 38.22190962731838, 37.68172301352024, 37.74731509387493, 37.5066664069891, 37.325058951973915, 37.197906374931335, 38.48618924617767, 37.76037499308586, 37.28255823254585, 37.1622034907341, 36.162013560533524, 37.054243683815, 37.86070100963116, 38.40782605111599, 38.20350721478462, 36.13863721489906, 37.00283624231815, 39.33305360376835, 39.35336731374264, 38.60237181186676, 38.078106343746185, 39.1871452331543, 38.70535768568516, 37.894352003932, 37.80458942055702, 38.042836636304855, 39.89035449922085, 41.37233577668667, 40.13321466743946, 39.75417360663414, 37.20948055386543, 37.36332289874554, 39.153486639261246, 38.06575320661068, 39.217490404844284, 41.273100301623344, 44.34564583003521, 49.363154992461205, 52.13038690388203, 51.54062435030937, 50.66273085772991, 52.3368564248085, 50.35745143890381, 45.96282385289669, 42.545933201909065, 39.24344301223755, 37.95363262295723, 40.79890854656696, 39.88237872719765, 42.84047059714794, 40.77177420258522, 39.64032791554928, 41.11915536224842, 41.398333981633186, 43.844490721821785, 40.354613587260246, 38.3418083935976, 38.942768946290016, 41.425601318478584, 38.57773773372173, 39.61214862763882, 38.907814621925354, 39.4406296312809, 40.64945496618748, 39.16880361735821, 38.592693731188774, 37.820635959506035, 36.363566145300865, 38.331510946154594, 36.71417333185673, 37.5422552973032, 39.47109639644623, 38.919426798820496, 38.936206698417664, 38.47725212574005, 38.134487718343735, 37.750028148293495, 38.535472601652145, 37.680089101195335, 37.04736605286598, 39.499879851937294, 40.55784948170185, 40.35005383193493, 40.67731127142906, 40.82256227731705, 38.134324327111244, 39.5575113594532, 39.08366538584232, 40.58412507176399, 39.03654791414738, 41.35989524424076, 40.612201765179634, 42.882021367549896, 44.90966476500034, 51.21535040438175, 50.39166860282421, 53.752683252096176, 52.41236977279186, 53.04892681539059, 52.15605452656746, 62.63615436851978, 60.126506835222244, 69.41833063960075, 51.09770871698856, 2.4534568609669805, 0.7772295910399407, 0.3130714350845665, 0.19165797508321702, 12.235139217227697, 66.25401243567467, 60.88998846709728, 64.39147397875786, 41.58516235649586, 28.195604234933853, 20.535226687788963, 48.1277234852314, 51.62484683096409, 56.488399654626846, 8.725225757807493, 0.5028118193149567, 0.03854639333439991, 0.024583660342614166, 0.07787302136421204, 0.03261216566897929, 0.0559352028358262, 0.03645521414000541, 0.05907915190618951, 0.014253369154175743, 0.009853939063759753, 0.03655832442746032, 0.03532211048877798, 0.038092499526101165, 0.21238562534563243, 0.04319267194659915, 0.14568832382792607, 0.007619354673806811, 13.903403598815203, 67.80399486422539, 59.63146559894085, 41.7047381401062, 26.480197682976723, 61.24198257923126, 86.85668930411339, 50.24447590112686, 56.62379398941994, 59.02675464749336, 52.5171909481287, 1.6520789125934243, 0.3268977056723088, 0.44174820533953607, 0.1375207956880331, 45.83342179656029, 71.21351391077042, 57.13823698461056, 57.052122205495834, 58.62030565738678, 58.07304382324219, 56.308764293789864, 56.228862181305885, 52.88015127182007, 52.09734007716179, 51.35354898869991, 50.38014002144337, 50.895259380340576, 49.838357493281364, 49.51842226088047, 47.1025612950325, 46.68641522526741, 44.07495595514774, 43.8573644310236, 41.10118992626667, 42.0142163336277, 39.18864235281944, 39.11526449024677, 39.585641250014305, 39.657681584358215, 40.57597070932388, 39.81709063053131, 39.775254875421524, 39.08868111670017, 38.92322279512882, 40.04144199192524, 39.29524943232536, 38.99580270051956, 40.40320158004761, 39.138222858309746, 38.33742342889309, 39.22250993549824, 40.06560489535332, 40.44205069541931, 38.93310226500034, 39.00154419243336, 38.55188012123108, 40.348351523280144, 39.22383986413479, 40.701436176896095, 39.31218892335892, 40.85788518190384, 40.80026127398014, 40.328630581498146, 39.413031712174416, 39.11479331552982, 42.90884792804718, 42.74903230369091, 43.09446796774864, 42.25746028125286, 40.36700092256069, 39.36681479215622, 40.28094694018364, 39.77680139243603, 40.11713393032551, 42.86888547241688, 45.99831774830818, 49.90833833813667, 54.30021487176418, 54.33652572333813, 51.40801526606083, 53.34417097270489, 52.31247693300247, 48.30604791641235, 44.156241193413734, 41.75459526479244, 41.65705069899559, 42.74931728839874, 41.54718339443207, 44.91555444896221, 41.809642910957336, 42.906708642840385, 42.63066105544567, 43.76335747539997, 44.427896216511726, 42.90529891848564, 40.10327607393265, 40.11148743331432, 41.955874264240265, 40.23566097021103, 41.13396696746349, 41.10363319516182, 40.77186159789562, 41.40976756811142, 40.56769475340843, 39.89436328411102, 39.52562727034092, 39.46679122745991, 40.10712526738644, 38.88337053358555, 38.24281610548496, 40.77310413122177, 41.22137367725372, 41.08909137547016, 39.991934448480606, 40.04952035844326, 40.797221437096596, 41.24413065612316, 39.2986274510622, 38.812587931752205, 42.446196153759956, 41.769577860832214, 41.65075823664665, 41.78358390927315, 41.54234245419502, 41.015151143074036, 40.79592190682888, 42.03911639750004, 42.40674667060375, 41.85533545911312, 42.80161768198013, 43.03625889122486, 44.403721913695335, 45.933671817183495, 52.02367722988129, 53.565588891506195, 55.64719319343567, 53.32921877503395, 55.43682888150215, 55.897356569767, 65.16464129090309, 63.46278861165047, 71.8803097307682, 57.5325608253479, 4.160404354333878, 1.0150682693347335, 1.83048527687788, 0.19100160483503714, 13.98905860260129, 71.09093248844147, 64.96395885944366, 66.41921237111092, 49.75500896573067, 34.55932796001434, 23.399501591920853, 55.657703429460526, 59.49998125433922, 67.72157728672028, 11.676977667957544, 0.44953202828764915, 0.06844049508799799, 0.008596341067459434, 0.03906942562025506, 0.010737255288404413, 0.042169959051534534, 0.05380833004892338, 0.019548164236766752, 0.12317635759245604, 0.1371241474407725, 0.1380443066591397, 0.17088972934288904, 0.10657807637471706, 0.2623962558573112, 0.16289840190438554, 0.32929947366937995, 0.08184218298993073, 17.01100319623947, 79.05972048640251, 67.7592408657074, 50.06135232746601, 34.27143640816212, 72.12713688611984, 94.10695105791092, 63.89316111803055, 62.78851859271526, 64.7115384042263, 59.90276724100113, 2.2385292313992977, 0.5645329167600721, 1.3243588479235768, 0.21207913319813088, 50.7061093300581, 72.69084423780441, 60.328728184103966, 59.549902975559235, 62.45532967150211, 59.82223816215992, 59.110502153635025, 57.570345997810364, 55.29525987803936, 54.76628266274929, 54.14531618356705, 52.73472547531128, 52.12706208229065, 52.107610926032066, 54.253412783145905, 49.964909702539444, 50.10527417063713, 47.06012897193432, 45.38723073899746, 42.479242980480194, 43.97706180810928, 41.02859862148762, 41.85565464198589, 41.864454969763756, 42.77871251106262, 43.65300379693508, 42.087332010269165, 42.69063703715801, 43.242504224181175, 41.23593829572201, 41.26762479543686, 42.389066219329834, 41.75375550985336, 41.80771641433239, 41.56654715538025, 41.51213027536869, 40.632971450686455, 42.53365986049175, 41.71227693557739, 41.230455189943314, 41.385144889354706, 41.09820708632469, 42.40958511829376, 42.69130580127239, 41.85735695064068, 41.374570056796074, 42.18532495200634, 42.630740851163864, 42.52496212720871, 41.46332189440727, 40.486139729619026, 47.26189814507961, 45.99460534751415, 45.97513899207115, 44.362775310873985, 42.068260833621025, 40.95833279192448, 42.8507224470377, 44.12887126207352, 42.99231044948101, 46.10095024108887, 47.59833209216595, 53.44292767345905, 56.57777465879917, 57.15760834515095, 53.55589181184769, 56.67732171714306, 54.241211637854576, 50.65618380904198, 47.343107387423515, 44.31668758392334, 41.824640706181526, 45.06073325872421, 43.845486268401146, 47.43220120668411, 44.845721796154976, 43.99290315806866, 45.092917531728745, 46.0278345644474, 47.22934529185295, 46.08859330415726, 42.78496317565441, 42.329538613557816, 44.26256328821182, 40.670068860054016, 42.61369116604328, 43.842245042324066, 43.99419888854027, 44.71959516406059, 42.43155553936958, 42.09107480943203, 42.03611455857754, 41.363774836063385, 41.88826069235802, 39.76976417005062, 40.935625210404396, 42.84030340611935, 43.01931940019131, 44.870032891631126, 42.01906107366085, 42.466749250888824, 42.81097277998924, 44.25495229661465, 41.620242074131966, 42.53542296588421, 43.74263718724251, 46.064650788903236, 44.30825583636761, 46.04998737573624, 44.92329083383083, 43.8886671513319, 43.968497067689896, 43.932163417339325, 43.66959750652313, 44.12708915770054, 45.39617545902729, 44.847598895430565, 46.93078391253948, 48.90813700854778, 54.597860500216484, 55.832927227020264, 57.169843688607216, 56.930585727095604, 57.062370255589485, 58.448205292224884, 68.77906814217567, 67.74120703339577, 72.40569233894348, 61.29661604762077, 5.697765285149217, 2.233099085278809, 2.7716064266860485, 0.2527935476973653, 14.907806552946568, 78.58173653483391, 69.71206247806549, 78.26829135417938, 52.4325542896986, 39.802902191877365, 32.191618010401726, 67.3634997010231, 66.55414313077927, 81.0272017121315, 16.85765102505684, 0.6789425807073712, 0.1269501488422975, 0.20510249974904582, 0.2070816740160808, 0.10509787767659873, 0.17948379943845794, 0.23404389910865575, 0.15396834671264514], [0.03309405699837953, 0.08136130098137073, 0.073395785439061, 0.059527687408262864, 0.12357449013506994, 0.128398880478926, 0.005331135735104908, 0.07919695344753563, 0.031103756082302425, 5.629748934879899, 55.84044702351093, 57.7876753360033, 41.62783406674862, 41.26610867679119, 29.18822307139635, 53.99578280746937, 44.929887279868126, 49.44465681910515, 52.855262607336044, 49.813138246536255, 2.7771211182698607, 0.21541379566770047, 0.5577940971124917, 0.236751506163273, 47.32945092022419, 63.73356208205223, 56.574871614575386, 54.701697528362274, 55.11816278100014, 53.947031423449516, 51.9536317884922, 49.343878626823425, 45.80223686993122, 45.22138103842735, 43.39810587465763, 41.62590377032757, 43.229049146175385, 40.8400147408247, 41.33032903075218, 39.68942128121853, 38.24074521660805, 38.1119891256094, 37.825085520744324, 38.20687383413315, 37.785890623927116, 36.24528229236603, 38.96199591457844, 37.718463242053986, 37.49898321926594, 35.47253295779228, 35.81095039844513, 37.771645188331604, 38.03296856582165, 38.362426087260246, 37.55668692290783, 37.28739157319069, 37.85261504352093, 37.69777715206146, 36.44241191446781, 36.38702608644962, 36.979752480983734, 35.53704969584942, 36.435982659459114, 37.463694512844086, 37.50962644815445, 35.971860364079475, 38.8707210123539, 37.34439991414547, 40.6493865698576, 37.9376544803381, 39.090862199664116, 38.629886135458946, 38.99319604039192, 38.58386680483818, 37.20523238182068, 38.22377152740955, 40.897619649767876, 41.32531709969044, 39.25133138895035, 37.2822542488575, 37.39604294300079, 36.988826394081116, 38.65789823234081, 38.11331905424595, 39.092800095677376, 44.517248421907425, 49.936388432979584, 54.53802891075611, 49.849916473031044, 47.212447598576546, 50.8853343129158, 51.39251969754696, 45.54940223693848, 42.09352947771549, 38.905109167099, 39.080306366086006, 39.21669624745846, 38.576882779598236, 40.848062708973885, 40.13746663928032, 38.873548060655594, 39.22596774995327, 39.53780561685562, 40.91943047940731, 39.89250898361206, 39.372693076729774, 38.98339256644249, 37.758972868323326, 39.81791138648987, 38.42225767672062, 38.691807612776756, 39.28742565214634, 38.15553858876228, 36.395492032170296, 40.383252650499344, 36.544930413365364, 38.31177860498428, 37.64800742268562, 37.986960634589195, 36.6741918772459, 36.822467520833015, 37.96002388000488, 37.32158213853836, 38.394591361284256, 39.85320009291172, 39.7318422049284, 37.134020403027534, 40.23603715002537, 40.35383082926273, 38.475120440125465, 37.33449384570122, 39.404379576444626, 39.50396843254566, 40.44657625257969, 41.74541115760803, 41.310197710990906, 40.57129316031933, 40.31786575913429, 40.58668613433838, 42.764736860990524, 42.68557570874691, 46.219302490353584, 52.65405960381031, 55.633787512779236, 54.95824836194515, 55.729375183582306, 55.30038200318813, 56.846515238285065, 53.872502222657204, 59.070524498820305, 57.446624636650085, 68.38170066475868, 50.37149168550968, 3.413818278349936, 0.33237941621337086, 1.0987989138811827, 0.10307477568858303, 9.996035266667604, 66.1399957537651, 60.271746441721916, 67.91769996285439, 40.00114135444164, 36.47903434932232, 30.749192610383034, 36.78947389125824, 49.21843595802784, 57.43801049888134, 7.952925274148583, 0.3917021892266348, 0.03016970385942841, 0.06323544977931306, 0.11265918248682283, 0.08377627920708619, 0.05599873809842393, 0.04006354727607686, 0.11392530126613565, 0.03572788344172295, 0.03380263733561151, 0.07150089688366279, 0.07961558410897851, 0.04538141016382724, 0.05483321372594219, 0.06409892375813797, 0.24183508416172117, 0.03752771401195787, 7.574139274656773, 65.19550323486328, 63.20819467306137, 48.37707370519638, 40.53160808980465, 51.17200993001461, 70.40242463350296, 51.34665235877037, 55.44804587960243, 57.504799515008926, 53.93138766288757, 2.9398594982922077, 0.26374013687018305, 0.4440857033478096, 0.2230001479620114, 51.815642192959785, 64.25371617078781, 59.332737028598785, 54.74810063838959, 58.05350907146931, 56.69328086078167, 54.090458527207375, 53.477410823106766, 49.920106306672096, 48.64321142435074, 46.88133716583252, 45.37566035985947, 45.81644810736179, 44.238761365413666, 42.11584948003292, 40.79283647239208, 39.97865416109562, 39.92056667804718, 39.84216548502445, 38.85056309401989, 40.120587944984436, 39.118087738752365, 38.82666237652302, 40.07231533527374, 40.483373478055, 39.17580284178257, 38.42714801430702, 39.725253358483315, 40.589581578969955, 40.694448351860046, 39.6610140055418, 38.91356371343136, 40.557226315140724, 39.346744269132614, 38.19194823503494, 37.49249316751957, 38.19115407764912, 38.18696290254593, 38.21207955479622, 39.16293293237686, 40.03684803843498, 38.27297128736973, 38.9878611266613, 39.05701741576195, 41.90474420785904, 40.88476113975048, 39.76136662065983, 39.55996982753277, 41.46940536797047, 41.19766674935818, 38.866552636027336, 40.76192133128643, 42.039173394441605, 43.159170895814896, 40.33597558736801, 39.71293821930885, 38.943943083286285, 38.45013678073883, 40.1838431507349, 39.330769926309586, 41.98126830160618, 46.405838280916214, 52.57276676595211, 56.00851960480213, 51.817990466952324, 49.700075313448906, 53.31274665892124, 52.772092670202255, 48.70756857097149, 42.738009095191956, 41.67936310172081, 41.601402685046196, 40.43533265590668, 40.90268857777119, 42.67691217362881, 41.69821389019489, 41.81110963225365, 40.91764077544212, 42.51808449625969, 43.40053014457226, 42.914418429136276, 39.4449158012867, 40.667169615626335, 40.28807535767555, 41.66522026062012, 40.25502473115921, 41.06215462088585, 41.26947529613972, 40.201785787940025, 39.649268835783005, 41.73161029815674, 39.544086679816246, 39.77088890969753, 40.66374219954014, 38.411397859454155, 39.162868335843086, 37.85261504352093, 39.52234424650669, 38.973775282502174, 39.85574595630169, 42.658688351511955, 40.287228003144264, 39.384347051382065, 41.42863355576992, 42.16656535863876, 39.566877856850624, 40.063982382416725, 42.21550673246384, 42.155621945858, 42.756377309560776, 42.22929619252682, 43.340424969792366, 43.85381542146206, 43.12550090253353, 42.32939802110195, 44.501676857471466, 45.19896604120731, 47.21219681203365, 55.65118297934532, 57.98066318035126, 57.972900196909904, 58.11924174427986, 57.30779528617859, 58.176405876874924, 54.89053599536419, 60.8911170065403, 62.00877383351326, 69.11653563380241, 56.15460656583309, 3.7243639770895243, 1.0024478402920067, 1.0280462354421616, 0.06836027634562925, 10.347614251077175, 72.19715192914009, 63.747765719890594, 75.61366260051727, 45.203434601426125, 39.14845570921898, 36.87975324690342, 46.754078194499016, 56.59613527357578, 67.71931260824203, 10.62822064384818, 0.47527977323625237, 0.10706523695262149, 0.14844007382635027, 0.0803991436259821, 0.13303240528330207, 0.03889094281475991, 0.027624317299341783, 0.06799720285926014, 0.12796880590030923, 0.22702252899762243, 0.18085614923620597, 0.11930563443456776, 0.2771334978751838, 0.22527952096424997, 0.18407891067909077, 0.5146511527709663, 0.09564788866555318, 9.338830132037401, 75.77761620283127, 71.14522397518158, 55.929879024624825, 49.86022911965847, 42.63811245560646, 63.160313442349434, 56.96170225739479, 62.69349329173565, 63.148488476872444, 61.453004255890846, 3.287953594699502, 0.23839810921344906, 1.7661806149408221, 0.6197061343118548, 57.41074316203594, 65.8455191552639, 61.47368274629116, 57.182607203722, 61.1951918900013, 59.60803985595703, 56.62928469479084, 55.16309157013893, 50.409440249204636, 50.250840559601784, 48.03299456834793, 47.060991525650024, 49.525767266750336, 45.482780411839485, 45.28919979929924, 43.51179197430611, 41.810285076498985, 41.581506952643394, 42.43255488574505, 42.008406445384026, 42.584307342767715, 41.15701273083687, 42.50247113406658, 42.02551692724228, 42.48700596392155, 38.332016319036484, 42.2086139023304, 41.6716381162405, 42.312705516815186, 42.75228872895241, 41.484855338931084, 43.75797316431999, 43.377039805054665, 40.732024535536766, 40.816626995801926, 40.78294560313225, 39.427539333701134, 40.81204064190388, 40.408798679709435, 41.32635444402695, 41.60284660756588, 38.843183889985085, 41.578463315963745, 39.47731286287308, 43.541897758841515, 40.65943703055382, 41.947985887527466, 42.46151693165302, 43.19260910153389, 44.484509378671646, 40.95827579498291, 42.29727454483509, 45.11411279439926, 45.291065499186516, 43.15040476620197, 42.464708760380745, 41.99286907911301, 41.52725726366043, 43.132519125938416, 41.2193787842989, 43.311303332448006, 50.44624887406826, 54.640710800886154, 59.90871772170067, 53.329598754644394, 52.57046028971672, 55.05945973098278, 55.42823374271393, 50.61776787042618, 44.98965427279472, 43.986306712031364, 43.11136566102505, 44.37991999089718, 41.409668773412704, 45.39205268025398, 43.15533310174942, 43.68248261511326, 43.72043877840042, 44.5880576223135, 46.29522621631622, 45.83501771092415, 41.770934388041496, 40.99515661597252, 41.68560616672039, 43.33344854414463, 41.43138840794563, 42.101653441786766, 42.61620283126831, 41.34790688753128, 40.461528450250626, 44.395111575722694, 40.609785094857216, 42.92868286371231, 41.93822801113129, 41.787645891308784, 41.1049023270607, 39.715126901865005, 42.35503904521465, 41.48336581885815, 41.49252712726593, 45.567956641316414, 43.20129543542862, 41.65787145495415, 44.19906869530678, 45.153372287750244, 41.75209119915962, 42.043520361185074, 45.00565901398659, 44.46931779384613, 45.62242291867733, 46.384297236800194, 46.483908891677856, 45.52812717854977, 44.10280466079712, 45.40027543902397, 47.18508906662464, 47.990611642599106, 50.24316117167473, 58.08229252696037, 60.6570989638567, 60.84019213914871, 59.64816190302372, 61.26903332769871, 61.13796316087246, 57.9159564524889, 63.76414284110069, 64.49512481689453, 71.06852129101753, 61.312294006347656, 5.011823242530227, 2.1547829126939178, 4.607351571321487, 0.19178896414814517, 12.300811093300581, 79.05100375413895, 68.82189184427261, 84.27484184503555, 50.15861950814724, 49.768521040678024, 44.66715797781944, 55.53581357002258, 65.71777001023293, 77.7415332198143, 16.055223383009434, 0.7686366490088403, 0.22400372457923368, 0.2260097794351168, 0.18434905243339017, 0.167309015232604, 0.09941406548023224, 0.1608009441406466, 0.21209060680121183], [0.00782552237069467, 0.03645265373052098, 0.039344780961982906, 0.07366906647803262, 0.015515459926973563, 0.02814767613017466, 0.07310125671210699, 0.11081540564191528, 0.02518499477446312, 4.947328353300691, 50.582589358091354, 56.530030220746994, 43.99212419986725, 23.59670151025057, 14.209420178085566, 18.039657399058342, 34.50565204024315, 49.93235304951668, 50.60617469251156, 49.377301633358, 3.5359525121748447, 0.26002206606790423, 0.07947101374156773, 0.07000610756222159, 43.93407091498375, 67.08169162273407, 56.50637648999691, 55.7173678278923, 51.02764427661896, 51.534643471241, 45.212884694337845, 42.62815698981285, 40.604655370116234, 40.03438197076321, 40.35660468041897, 39.97539393603802, 38.70363637804985, 37.862817496061325, 38.85258458554745, 39.05618146061897, 38.21553736925125, 39.259337559342384, 38.96456077694893, 38.86457294225693, 39.25309829413891, 38.37421305477619, 37.79098615050316, 37.92032741010189, 38.798969462513924, 38.4852658957243, 37.50771515071392, 37.7205341309309, 38.1686706840992, 37.49069586396217, 36.34849235415459, 35.886098966002464, 36.384746208786964, 35.5240011960268, 36.09603010118008, 35.2511340379715, 36.22689887881279, 37.22675062716007, 38.35950784385204, 37.14922338724136, 35.87077438831329, 37.151951640844345, 39.53548014163971, 38.130182549357414, 38.88330593705177, 40.327642634510994, 40.30769370496273, 39.88772124052048, 39.24390658736229, 39.32814046740532, 36.80551663041115, 40.2346920222044, 40.63370481133461, 40.50363399088383, 39.63496260344982, 38.62371526658535, 39.48555462062359, 37.648968771100044, 37.65363112092018, 36.66393242776394, 38.303658440709114, 44.90172319114208, 50.67311190068722, 53.86351950466633, 46.58171184360981, 49.295317232608795, 52.83693619072437, 49.09774303436279, 41.681270599365234, 40.13229511678219, 39.79686811566353, 38.48936967551708, 39.6229362487793, 40.430339723825455, 42.1816049516201, 40.30431568622589, 37.848325073719025, 39.571714997291565, 37.68889702856541, 38.06297555565834, 38.768229112029076, 39.33379456400871, 37.64223173260689, 40.0562459975481, 40.13754643499851, 40.15900768339634, 40.14331452548504, 36.50841437280178, 38.80465395748615, 37.52142861485481, 38.456022664904594, 36.89509302377701, 38.650997802615166, 36.93287819623947, 38.76133248209953, 38.014813140034676, 37.55973435938358, 38.5156224668026, 38.57872188091278, 40.05963161587715, 38.549870029091835, 37.837161272764206, 37.27403149008751, 38.809475898742676, 38.78408946096897, 40.06039917469025, 40.02129167318344, 41.503584533929825, 40.26661790907383, 40.76675087213516, 40.17077185213566, 40.990840047597885, 41.18330731987953, 39.57031287252903, 41.84203617274761, 42.46454916894436, 43.44876475632191, 50.72534769773483, 55.45223705470562, 58.96036460995674, 58.149214535951614, 59.411233216524124, 54.23433780670166, 56.95777326822281, 60.47681763768196, 59.870092794299126, 56.78213529288769, 70.54631531238556, 45.15125200152397, 1.2401831522583961, 0.9118807688355446, 0.8947561564855278, 0.1245018481859006, 9.122417494654655, 66.2464128434658, 59.48899604380131, 66.06592252850533, 51.1732030659914, 46.745794638991356, 26.776876263320446, 30.951415859162807, 49.42623920738697, 50.495775416493416, 6.704269526526332, 0.22141172928968444, 0.04717423114925623, 0.09840205806540325, 0.03209026144759264, 0.09591582624125294, 0.09383300362969749, 0.04678263692767359, 0.034360517165623605, 0.04163203928328585, 0.07890197201049887, 0.04531200080236886, 0.047000093618407845, 0.02185043991630664, 0.03734831836482044, 0.03734235891897697, 0.18917862296802923, 0.05207861016970128, 5.630135089159012, 59.73953180015087, 62.70289018750191, 50.20075924694538, 30.02828199416399, 17.264745980501175, 33.55622358620167, 42.22632475197315, 55.985891819000244, 55.49712024629116, 54.902493953704834, 4.504577536135912, 0.36929149646312, 0.291115649160929, 0.04430007131304592, 45.253394320607185, 68.6529453098774, 59.88368846476078, 58.48249465227127, 53.604589998722076, 53.36267597973347, 48.2061854749918, 44.079424515366554, 42.45056211948395, 42.701546251773834, 42.54577361047268, 40.74093885719776, 41.4747516810894, 38.89238744974136, 41.08293950557709, 39.504272416234016, 39.628567546606064, 40.62362775206566, 41.24028526246548, 39.926908537745476, 42.12575174868107, 40.39397567510605, 40.72683021426201, 38.80070976912975, 40.13580232858658, 39.99807491898537, 39.679496213793755, 39.50926534831524, 40.17061986029148, 39.22775745391846, 37.25484251976013, 36.947955787181854, 40.36912500858307, 37.14875601232052, 37.83309929072857, 36.23640976846218, 38.71230751276016, 36.97873033583164, 37.97301538288593, 38.63818109035492, 38.60715575516224, 37.71159701049328, 39.63979974389076, 39.792122170329094, 42.22652994096279, 40.562739819288254, 42.13925622403622, 40.637987181544304, 42.08534471690655, 42.09702529013157, 40.25458015501499, 42.54572421312332, 42.313108295202255, 41.19085751473904, 42.50814042985439, 39.46255825459957, 39.73781168460846, 39.515478014945984, 38.92293781042099, 40.41622348129749, 41.433276906609535, 46.82717487215996, 52.55469113588333, 54.76319722831249, 48.29071193933487, 51.23724862933159, 53.74855287373066, 50.986773669719696, 43.01611237227917, 42.20017455518246, 41.739985048770905, 41.152578368783, 41.185720190405846, 39.883165284991264, 43.15628305077553, 41.856008023023605, 41.16653501987457, 40.07432542741299, 40.425031408667564, 40.047149285674095, 40.13883076608181, 42.23224103450775, 40.12907288968563, 41.071771904826164, 41.897133216261864, 41.347842290997505, 42.122947499156, 38.78211736679077, 41.01514734327793, 39.65696722269058, 40.325902327895164, 39.47293169796467, 40.8443047106266, 37.888739705085754, 39.74989503622055, 40.19681565463543, 38.69396209716797, 40.71017190814018, 39.27377298474312, 40.412457883358, 41.797969937324524, 39.79511260986328, 39.892349392175674, 41.19295880198479, 40.899591743946075, 41.824253126978874, 41.830959767103195, 42.95397810637951, 42.47858941555023, 41.83632127940655, 41.213880479335785, 41.96407422423363, 42.54980519413948, 41.09496206045151, 44.40258577466011, 43.96273657679558, 45.480234548449516, 53.47194291651249, 57.74974577128887, 59.5962642878294, 60.25034599006176, 61.01807579398155, 56.6644936054945, 60.46349935233593, 62.068863809108734, 62.62197732925415, 60.421940982341766, 71.72190383076668, 50.9804318100214, 1.0563623160123825, 2.0696898037567735, 0.7125668576918542, 0.03287805862782989, 9.920072592794895, 72.58693501353264, 62.521617114543915, 74.16858494281769, 47.441164925694466, 49.48425829410553, 36.527721136808395, 36.68234623968601, 57.620461508631706, 59.84493054449558, 10.382055602967739, 0.3477774665225297, 0.08563524039345793, 0.11459414701675996, 0.01161580228654202, 0.05552475435251836, 0.06524972020997666, 0.07960979535710067, 0.08667328977026045, 0.10454013885464519, 0.19819401029963046, 0.23117615142837167, 0.2408903301693499, 0.11900240031536669, 0.18578317860374227, 0.2437263139290735, 0.42074014199897647, 0.1603559375507757, 6.9047819171100855, 67.10914894938469, 72.13058710098267, 57.33664333820343, 36.275988444685936, 20.303106643259525, 28.15874621272087, 45.523597821593285, 63.119066655635834, 60.835305601358414, 61.06069430708885, 5.110941398888826, 0.4834102385211736, 0.842479036655277, 0.1757309219101444, 50.65700076520443, 70.97856491804123, 63.158702328801155, 61.65081784129143, 57.06793695688248, 56.55139647424221, 51.17253430187702, 46.79887779057026, 44.97944802045822, 44.986105263233185, 45.581301525235176, 43.590561747550964, 43.09188410639763, 40.3116112947464, 43.27808551490307, 41.87824442982674, 41.4763817936182, 43.00681047141552, 43.571954146027565, 42.58701279759407, 44.7784274071455, 41.3577863574028, 43.134935796260834, 42.18277528882027, 42.199752777814865, 41.86604328453541, 41.38914227485657, 41.38395935297012, 42.15625271201134, 42.828064262866974, 39.79347109794617, 39.22842621803284, 41.75091706216335, 38.66029970347881, 39.35303673148155, 38.82882446050644, 39.86751772463322, 41.749032363295555, 41.79648421704769, 40.908046290278435, 40.330549478530884, 40.490547493100166, 43.615902587771416, 42.157844826579094, 44.48192551732063, 42.87963509559631, 45.22907942533493, 44.336226135492325, 44.67195712029934, 42.989472001791, 41.13730698823929, 44.40814107656479, 45.964628756046295, 44.03484150767326, 44.53693896532059, 43.80978338420391, 44.1541513055563, 42.56743624806404, 40.2649611979723, 42.07098908722401, 43.73955935239792, 50.394921228289604, 55.87038941681385, 57.80364967882633, 52.406977862119675, 53.43567006289959, 56.54637694358826, 53.46374295651913, 46.88631109893322, 44.782884567976, 44.29801158607006, 44.20702546834946, 43.52725334465504, 43.33898484706879, 47.469917982816696, 44.05972637236118, 41.83678485453129, 42.959145829081535, 43.07795025408268, 42.4754735827446, 43.47771920263767, 43.657783940434456, 42.664502039551735, 44.31381493806839, 44.585249572992325, 44.151833429932594, 43.66096056997776, 39.356616139411926, 42.39271402359009, 42.06726908683777, 43.52618560194969, 40.92724286019802, 43.042908534407616, 41.244202852249146, 42.93234966695309, 42.28861480951309, 41.42456017434597, 43.182193860411644, 42.2997672110796, 43.76212254166603, 44.342305809259415, 42.16491624712944, 42.33788676559925, 43.83825145661831, 42.21131555736065, 44.48415979743004, 44.37407210469246, 43.930096328258514, 44.68678392469883, 43.61789748072624, 43.55991259217262, 44.54014599323273, 46.20876185595989, 43.47925052046776, 47.442236468195915, 46.54659792780876, 48.303562849760056, 55.99234767258167, 61.1554080247879, 62.688515558838844, 63.920177668333054, 63.74694876372814, 59.85732927918434, 63.344637751579285, 64.9250565469265, 63.941752910614014, 63.08550305664539, 73.83123904466629, 57.168179377913475, 2.25034445989877, 2.794044460169971, 3.1307303812354803, 0.18142301647458225, 11.170891374349594, 78.94949600100517, 69.0002390742302, 79.55652862787247, 62.53003366291523, 58.01054857671261, 39.38734509050846, 48.52181933820248, 64.56125646829605, 70.99093705415726, 14.856913983821869, 0.6324843142647296, 0.17967781168408692, 0.41220609680749476, 0.17513640224933624, 0.13763082650257275, 0.16750373994000256, 0.1862532104132697, 0.13611985836178064], [0.047363964913529344, 0.015776560467202216, 0.034962042700499296, 0.03867320410790853, 0.04273110433132388, 0.06178016868943814, 0.0033532407451275503, 0.02622528358187992, 0.004144259773966041, 1.1472249403595924, 38.65235812962055, 55.21178595721722, 43.55974160134792, 35.867449566721916, 36.40168569982052, 31.338611282408237, 28.62908497452736, 43.83477084338665, 48.27119238674641, 51.34527303278446, 4.956896239891648, 0.4745626507792622, 0.45711841026786715, 0.043297889933455735, 36.382200345396996, 63.39147783815861, 57.5986734777689, 52.84802779555321, 46.71626262366772, 44.21567380428314, 42.22996115684509, 43.50250907242298, 41.49124659597874, 42.040974497795105, 39.42626640200615, 40.643614679574966, 38.90267729759216, 39.32230398058891, 36.99303276836872, 39.6622109413147, 39.14278641343117, 37.96417325735092, 36.958701610565186, 37.941264286637306, 38.29982824623585, 38.33304226398468, 38.089133352041245, 39.11558747291565, 39.734635055065155, 38.865796476602554, 36.264247074723244, 36.56343922019005, 35.73007553815842, 36.11888587474823, 35.04353977739811, 34.74052123725414, 35.79182222485542, 36.7635440826416, 37.19608627259731, 35.56399405002594, 35.1614398509264, 36.549596562981606, 37.958747148513794, 36.545283794403076, 36.23995117843151, 36.19261711835861, 39.09706346690655, 36.932916194200516, 38.06154303252697, 39.30044375360012, 38.44589240849018, 38.05249571800232, 38.5790790617466, 37.9097905755043, 39.57460284233093, 38.015713691711426, 39.50926914811134, 41.17832578718662, 38.56679052114487, 38.22032891213894, 37.458994165062904, 37.69032575190067, 37.21423789858818, 38.56208257377148, 38.8126677274704, 41.93933755159378, 48.00573483109474, 51.510434970259666, 53.0583731085062, 53.61753970384598, 51.64215490221977, 48.382024839520454, 40.319780856370926, 40.96677213907242, 41.49237893521786, 37.9546357691288, 39.09309267997742, 39.24595847725868, 39.33423154056072, 40.205456390976906, 38.78656692802906, 39.39674958586693, 40.35942792892456, 40.40345996618271, 38.47011610865593, 42.0157590508461, 41.91914923489094, 41.897391602396965, 39.87088434398174, 39.05948728322983, 40.05553163588047, 39.62376840412617, 36.31104916334152, 38.10050614178181, 38.30914154648781, 38.19901205599308, 37.44374178349972, 37.13801398873329, 36.92348890006542, 36.447971016168594, 36.52623161673546, 37.02494725584984, 36.86488464474678, 39.66063782572746, 37.196207866072655, 38.32249402999878, 36.24144069850445, 37.27951839566231, 38.326187431812286, 38.96791599690914, 40.51049642264843, 42.11400277912617, 43.10963295400143, 41.329835057258606, 43.656180426478386, 43.62499549984932, 42.8138530254364, 43.44585411250591, 42.26065210998058, 43.62051174044609, 42.642284631729126, 54.69335697591305, 55.040160566568375, 59.71971586346626, 54.278358444571495, 60.54146356880665, 55.371935963630676, 60.20290933549404, 57.69030936062336, 65.79411551356316, 58.036691173911095, 74.00932788848877, 38.73140148818493, 0.2626843278994784, 1.7943405476398766, 0.0626423476205673, 0.1174199856177438, 7.666904171928763, 62.11165331304073, 61.13001398742199, 68.70231986045837, 50.612337961792946, 27.31445051729679, 38.8919048756361, 37.8661423176527, 41.145620942115784, 49.435563907027245, 7.312920866534114, 0.25789465522393584, 0.026050331543956418, 0.00878948963872972, 0.0373454944929108, 0.05050863757787738, 0.007307763507924392, 0.0671981398772914, 0.04503805554122664, 0.014554243243765086, 0.02722788427490741, 0.03220180624339264, 0.041014398011611775, 0.0368137531040702, 0.054498980098287575, 0.0651872759044636, 0.03635008521087002, 0.06529949605464935, 1.5946670807898045, 47.314149141311646, 64.50908526778221, 49.63466942310333, 37.32279807329178, 22.73735862225294, 29.45642028003931, 35.575017258524895, 49.78240929543972, 55.866441428661346, 55.823024958372116, 6.185007439926267, 0.5660488572902977, 0.3094246401451528, 0.07024500489933416, 39.73219558596611, 65.98719075322151, 60.10550536215305, 53.588038086891174, 49.75053660571575, 45.63022390007973, 44.21384610235691, 45.39762698113918, 45.13109028339386, 43.430274948477745, 42.920007929205894, 42.23667159676552, 41.68925777077675, 40.81965163350105, 41.20071418583393, 41.75556801259518, 41.718497201800346, 39.74346958100796, 40.26424303650856, 40.62636740505695, 39.73738230764866, 40.768160596489906, 40.35490237176418, 40.7984259724617, 42.75055982172489, 39.494031965732574, 38.12378749251366, 37.23757244646549, 38.83371479809284, 36.62225626409054, 37.28372856974602, 36.100255474448204, 37.20515638589859, 37.98667185008526, 37.55249194800854, 37.49217018485069, 37.66774736344814, 37.590056732296944, 40.16770921647549, 39.35452625155449, 39.154865965247154, 37.814632281661034, 39.881132394075394, 37.86704286932945, 40.09302422404289, 41.317253932356834, 40.39295352995396, 39.319226145744324, 39.376466274261475, 41.20940051972866, 40.54947853088379, 41.274430230259895, 43.17543402314186, 43.15013878047466, 42.21215911209583, 40.022640600800514, 39.42367114126682, 37.989498898386955, 38.93047660589218, 42.09411844611168, 40.15217185020447, 43.93280178308487, 50.47845974564552, 53.047194108366966, 53.467326164245605, 54.80761304497719, 52.667647674679756, 52.164197489619255, 42.925255447626114, 42.158737778663635, 43.03352303802967, 41.25741474330425, 42.63030767440796, 40.96096985042095, 41.18409387767315, 41.401719599962234, 40.73015123605728, 41.85904026031494, 41.7472692579031, 42.534913793206215, 39.81547951698303, 42.165520414710045, 41.91788390278816, 43.57435941696167, 41.439432576298714, 40.37066772580147, 40.07875218987465, 40.11565200984478, 38.30232471227646, 38.445295840501785, 39.709476605057716, 40.40015794336796, 38.916151374578476, 39.02765639126301, 38.914513662457466, 38.45058515667915, 39.49915029108524, 38.86347860097885, 39.20346535742283, 40.36849804222584, 40.02003014087677, 40.04145339131355, 38.65175776183605, 38.957713544368744, 40.94718039035797, 41.06924504041672, 42.572524175047874, 43.695033341646194, 44.79812175035477, 44.260746985673904, 45.250829458236694, 45.1683434844017, 43.53733040392399, 45.58533310890198, 44.9563604593277, 45.296947583556175, 45.934530571103096, 56.54256954789162, 58.28127644956112, 60.62689058482647, 56.52847610414028, 62.44163140654564, 58.5142457485199, 63.67052346467972, 60.955660343170166, 67.82015919685364, 61.39666847884655, 74.25012856721878, 39.86650697886944, 0.1555861544329673, 2.9364057211205363, 0.10121670507942326, 0.08815253109787591, 8.36446551606059, 68.75978797674179, 65.47063127160072, 73.68700638413429, 54.09435711801052, 32.94627271592617, 41.40007048845291, 43.02615903317928, 49.66051183640957, 59.60735969245434, 9.650971982628107, 0.15909646841464564, 0.06905022135470062, 0.08050591641222127, 0.05231305833149236, 0.13046944281086326, 0.030507856026815716, 0.02820605346641969, 0.07024253354757093, 0.09348543360829353, 0.11759033077396452, 0.13500576111255214, 0.20953283936250955, 0.16176661185454577, 0.2164899988565594, 0.19272120553068817, 0.1692238452960737, 0.10887457072385587, 2.049799533560872, 55.97610354423523, 73.59927669167519, 56.061792746186256, 48.45650464296341, 44.648611173033714, 42.648679688572884, 43.181525096297264, 56.0603716224432, 60.189287066459656, 62.56644330918789, 7.448996314778924, 0.7576563069596887, 2.1975541301071644, 0.14014272921485826, 43.17201040685177, 67.85618126392365, 63.32243554294109, 56.52803912758827, 52.791927605867386, 47.339923158288, 46.3938195258379, 47.12933085858822, 47.43573121726513, 44.92788478732109, 45.18490679562092, 45.11818237602711, 43.645974174141884, 43.85268688201904, 42.433246448636055, 44.07034680247307, 43.87249521911144, 42.2309985011816, 42.51107767224312, 43.45112822949886, 42.05822557210922, 42.77568407356739, 42.420726120471954, 42.7610282599926, 44.471605271101, 43.66440698504448, 41.40458084642887, 40.431206077337265, 40.50437495112419, 39.241706505417824, 40.079082772135735, 37.278264462947845, 39.93424594402313, 41.17112137377262, 40.30750371515751, 38.62495020031929, 39.71347019076347, 39.21552591025829, 43.63940432667732, 40.13626970350742, 41.25394932925701, 38.61760139465332, 42.99175947904587, 39.17610302567482, 41.62844963371754, 45.01901909708977, 41.380615532398224, 40.027485340833664, 42.18283228576183, 42.7340193092823, 42.5920133292675, 42.45436191558838, 45.27806639671326, 45.7844652235508, 44.62525762617588, 42.93475493788719, 42.99443453550339, 41.31374292075634, 41.23332783579826, 45.47896161675453, 43.27713556587696, 46.80605560541153, 51.70465014874935, 56.12724423408508, 56.82551756501198, 57.10036441683769, 56.38844981789589, 52.66687251627445, 45.093954876065254, 46.367714926600456, 45.296012833714485, 43.21437433362007, 45.26910647749901, 42.1611962467432, 43.731811568140984, 44.819902181625366, 44.374497681856155, 44.490691646933556, 43.99801388382912, 44.52799804508686, 41.21149800717831, 45.037797689437866, 45.31838223338127, 45.081282556056976, 44.56645578145981, 41.325830072164536, 43.97138111293316, 43.14463287591934, 40.14678753912449, 41.73038676381111, 43.29619914293289, 41.55091479420662, 41.25594422221184, 40.97630962729454, 41.70041777193546, 40.535487681627274, 40.35387642681599, 41.93882077932358, 40.23794084787369, 42.47709609568119, 42.19655714929104, 41.74007624387741, 40.31284622848034, 40.1130947470665, 44.30518180131912, 43.494632095098495, 44.31609861552715, 45.84600672125816, 48.06391730904579, 45.82050248980522, 47.836111932992935, 47.114663645625114, 47.29175694286823, 47.20808543264866, 47.35324904322624, 47.56294459104538, 47.7138838917017, 59.37344804406166, 60.49351014196873, 64.61297169327736, 57.391219809651375, 64.56530705094337, 60.60335844755173, 66.06814920902252, 62.90385000407696, 69.01359155774117, 63.51807564496994, 77.75952905416489, 45.00624418258667, 0.6888840941246599, 4.803183563053608, 1.641410628799349, 0.22103923052782193, 8.647456280887127, 75.48943966627121, 70.90107187628746, 81.92703902721405, 65.06021529436111, 38.93481597304344, 53.28727662563324, 52.88606755435467, 57.21136786043644, 70.81465691328049, 15.529456045478582, 0.5137204402126372, 0.10541090814513154, 0.19216631655581295, 0.11255592748057097, 0.16346096468623728, 0.11250909796217456, 0.13657201925525442, 0.23525408963905647], [0.02835913070157403, 0.02694740625884151, 0.015030494250822812, 0.01938305864314316, 0.06619966181460768, 0.09902321340632625, 0.04075197830388788, 0.010509686835575849, 0.11608985660132021, 0.26526976260356605, 28.64836134016514, 55.51286660134792, 43.13074842095375, 37.28417694568634, 21.135184094309807, 32.40180753171444, 29.07716453075409, 47.87413269281387, 46.632978692650795, 54.9307644367218, 8.192304354161024, 0.43279250152409077, 0.6340945966076106, 0.3447605768451467, 25.64437173306942, 69.5544545352459, 57.12419293820858, 52.91368827223778, 46.678804233670235, 47.401495054364204, 45.18418863415718, 44.93388086557388, 43.2155978679657, 43.63950692117214, 42.58631743490696, 41.86162032186985, 40.36880202591419, 41.35480351746082, 38.23397397994995, 38.38881567120552, 38.37674371898174, 38.306462690234184, 39.04146105051041, 39.556888192892075, 38.46076861023903, 38.36705423891544, 38.4064657241106, 36.20547562837601, 37.332966327667236, 36.970955953001976, 36.99392572045326, 36.201280653476715, 35.35451129078865, 36.781118139624596, 35.19561141729355, 35.400614216923714, 35.63517563045025, 36.443426460027695, 34.59163762629032, 36.375220119953156, 37.83129058778286, 36.916383281350136, 37.48657688498497, 36.88126176595688, 36.01463466882706, 35.77311582863331, 37.833456471562386, 37.42644891142845, 38.1324016302824, 38.9519302546978, 39.815129935741425, 38.773681819438934, 39.16407287120819, 38.39710682630539, 37.43931122124195, 38.0427036434412, 38.856167793273926, 38.058176413178444, 37.080709263682365, 37.96997554600239, 37.3274490237236, 39.226666912436485, 36.497467160224915, 38.0069437623024, 39.309597462415695, 41.72869585454464, 47.29990370571613, 51.987214386463165, 52.48978681862354, 53.67976516485214, 50.22820137441158, 48.49616691470146, 42.885441184043884, 39.10712532699108, 38.96293446421623, 39.239529222249985, 38.63125026226044, 37.101323157548904, 39.136558547616005, 39.43519972264767, 40.02805531024933, 39.506784081459045, 37.69081972539425, 40.713800713419914, 39.44648891687393, 41.399105340242386, 41.93411283195019, 40.774840638041496, 38.31452585756779, 38.351250886917114, 39.41195257008076, 38.19388993084431, 37.31941245496273, 37.60052137076855, 37.84559302031994, 37.21259258687496, 37.83027604222298, 36.98984853923321, 37.577494606375694, 35.7394078373909, 39.34420980513096, 37.80428923666477, 37.250385358929634, 37.506981790065765, 37.82889671623707, 36.935025081038475, 36.72653026878834, 37.2962336987257, 39.14182506501675, 37.658950835466385, 38.337180241942406, 38.98988261818886, 39.422318413853645, 39.79827024042606, 39.83061030507088, 40.72260484099388, 40.17611816525459, 41.69550463557243, 41.282018423080444, 42.229980155825615, 45.60741372406483, 55.753420293331146, 54.43935960531235, 58.18085543811321, 56.02354019880295, 59.03413765132427, 56.52038633823395, 61.04278586804867, 56.82188116014004, 63.54363687336445, 54.636056050658226, 71.8717297911644, 32.63614475727081, 0.07201304557383992, 0.574476330075413, 0.27567666198592633, 0.04883961424638983, 6.894775154069066, 65.43344646692276, 59.21829856932163, 68.1903125345707, 47.18278259038925, 30.51373064517975, 38.510397747159004, 46.56037598848343, 47.355259135365486, 56.789104118943214, 7.082138825207949, 0.2839460573159158, 0.04708008600573521, 0.0538268280797638, 0.028786136499547865, 0.04572739569994155, 0.07423803399433382, 0.040621527296025306, 0.05593671681708656, 0.039259905242943205, 0.0401468867494259, 0.03454515979683492, 0.020198799538775347, 0.061956417630426586, 0.04734688438475132, 0.027421575541666243, 0.05284318554913625, 0.050961629676749, 0.4401122743729502, 34.03065852820873, 63.25372762978077, 46.101094633340836, 43.96340914070606, 23.911854699254036, 39.87109713256359, 38.36926952004433, 52.61741816997528, 51.99538394808769, 58.67176249623299, 9.207402784377337, 0.5682864028494805, 0.24042104050749913, 0.3675226023187861, 28.060580380260944, 71.07369661331177, 58.773635029792786, 55.32866768538952, 46.960353925824165, 49.44894678890705, 47.170197665691376, 47.10991010069847, 46.46524429321289, 43.335732221603394, 44.81018230319023, 42.863360568881035, 42.70524725317955, 42.32871025800705, 39.82628993690014, 40.97221724689007, 39.91622731089592, 38.784340247511864, 41.36652208864689, 40.19568711519241, 40.88285744190216, 40.536680817604065, 39.2383436858654, 38.097416907548904, 38.30995850265026, 38.55297826230526, 37.75592543184757, 38.04906450212002, 38.555151745676994, 37.75087930262089, 37.96713709831238, 37.66810454428196, 39.30907689034939, 38.46081800758839, 37.9289985448122, 37.661591693758965, 38.85312035679817, 38.805907890200615, 39.37728323042393, 36.842515245079994, 38.24184715747833, 38.22030611336231, 39.54969897866249, 38.221757635474205, 39.23856407403946, 40.42296051979065, 40.819267854094505, 39.04464527964592, 39.02406558394432, 39.83956262469292, 39.12021942436695, 38.85778270661831, 39.716532826423645, 39.99031573534012, 41.25370994210243, 39.851360991597176, 40.51024183630943, 42.38400109112263, 39.096744284033775, 40.43238401412964, 40.82032799720764, 42.765903398394585, 50.877206549048424, 54.82911229133606, 53.19090619683266, 53.436137437820435, 52.779817655682564, 51.21049806475639, 43.04689072072506, 40.9342572838068, 40.24084769189358, 40.1431967318058, 41.27976134419441, 39.818260967731476, 40.972498431801796, 40.915395095944405, 41.87327429652214, 41.468983590602875, 40.05875766277313, 40.98214231431484, 41.38356797397137, 42.07521826028824, 42.00564779341221, 41.192031651735306, 39.92189280688763, 39.39813271164894, 41.58608950674534, 39.74905148148537, 38.57200764119625, 39.41394366323948, 39.64701175689697, 39.884666204452515, 39.20502707362175, 37.558013051748276, 38.8676393777132, 37.130042016506195, 39.862524792551994, 38.92743676900864, 40.349673852324486, 39.99023213982582, 39.8982010781765, 39.08577807247639, 38.59835542738438, 40.22961929440498, 41.56851164996624, 40.78728877007961, 40.15157148241997, 41.731427907943726, 40.93128964304924, 40.51843039691448, 41.78396388888359, 43.16719226539135, 41.56979218125343, 43.9778483659029, 42.94052682816982, 42.37261690199375, 47.78204843401909, 58.28900523483753, 55.50908200442791, 60.567408576607704, 58.734789714217186, 61.37948960065842, 58.27046602964401, 63.94591748714447, 59.05024878680706, 66.72467038035393, 55.77609367668629, 73.20744931697845, 34.660584926605225, 0.24639478011522442, 2.0567588601261377, 0.5791056691668928, 0.03621112547989469, 7.139894776046276, 71.33919596672058, 64.97634619474411, 73.05744856595993, 52.22085244953632, 33.40585805475712, 44.71855401992798, 53.77229019999504, 56.34267367422581, 65.95806911587715, 9.708378352224827, 0.2287730178795755, 0.0380416995176347, 0.02027796443144325, 0.025070312549360096, 0.09325333434389904, 0.01932316732563777, 0.06708505141432397, 0.09583473918610252, 0.17665177874732763, 0.14793686801567674, 0.09116052984609269, 0.17144218407338485, 0.2150676876772195, 0.20333848893642426, 0.1577391248429194, 0.09726603035232984, 0.2032607267028652, 0.45837320387363434, 40.15659861266613, 70.11468887329102, 55.59483580291271, 52.01336458325386, 29.052851535379887, 41.80838517844677, 43.46222743391991, 61.093668937683105, 55.75176738202572, 64.71733689308167, 10.771446358412504, 0.5326291755773127, 1.646286598406732, 0.3849738190183416, 30.536480024456978, 73.8652016222477, 60.777320712804794, 58.06008271872997, 50.36864943802357, 50.94405636191368, 50.43096989393234, 50.05896985530853, 49.630854427814484, 46.42241679131985, 46.49582885205746, 46.434017568826675, 45.081734731793404, 45.806792825460434, 42.89470888674259, 42.441993579268456, 42.06441543996334, 41.425259336829185, 43.4400974214077, 43.561561703681946, 43.74664597213268, 42.82052926719189, 41.80898554623127, 40.538926497101784, 41.25691697001457, 40.84634520113468, 41.03558264672756, 40.982583090662956, 40.36518841981888, 41.89122453331947, 40.15505209565163, 39.7622025758028, 40.76177313923836, 40.91714680194855, 38.25046509504318, 40.07828861474991, 40.9311680495739, 40.97643882036209, 42.00822785496712, 38.54213744401932, 40.53429454565048, 38.59691150486469, 41.937471851706505, 39.82245594263077, 40.35734184086323, 42.661766186356544, 42.45878867805004, 40.34748896956444, 41.800568997859955, 41.993724033236504, 40.37177726626396, 41.38010635972023, 41.75117164850235, 41.432847529649734, 42.12630271911621, 42.680073603987694, 43.2253747433424, 44.97314415872097, 41.67709842324257, 42.21391461789608, 44.200892597436905, 46.349833086133, 53.527777120471, 58.23914811015129, 56.80619180202484, 56.62523791193962, 57.2951153665781, 53.89531999826431, 45.08959650993347, 42.766632959246635, 41.00051812827587, 42.342640310525894, 45.01279503107071, 42.890475913882256, 44.37060289084911, 43.31302464008331, 45.956850573420525, 43.568754717707634, 42.941172793507576, 43.281030356884, 43.59047055244446, 44.63876970112324, 44.9238608032465, 45.07842890918255, 39.554444923996925, 41.64370961487293, 44.622027799487114, 40.787068381905556, 41.07455715537071, 40.89179456233978, 41.935902535915375, 41.91648557782173, 41.64774879813194, 39.40866194665432, 41.607189774513245, 38.043881580233574, 42.19539441168308, 41.08012765645981, 42.424601912498474, 42.7479113638401, 42.93947048485279, 41.25681817531586, 41.24622814357281, 41.41173966228962, 43.42662334442139, 42.83538267016411, 42.26380214095116, 42.77775876224041, 42.77572587132454, 43.250453397631645, 43.26273433864117, 45.83519250154495, 43.57855059206486, 46.87130190432072, 45.30204311013222, 46.39065809547901, 50.82544572651386, 61.08196936547756, 58.43933276832104, 63.078773617744446, 60.88253706693649, 63.6492408066988, 59.70368452370167, 66.23675376176834, 61.718260422348976, 67.58760407567024, 59.077899903059006, 73.15290704369545, 38.33249509334564, 0.47499659936875105, 3.9120867289602757, 1.2570289545692503, 0.16702975990483537, 8.113639075309038, 78.14305767416954, 68.51701900362968, 81.8937224149704, 59.237225353717804, 44.02181960642338, 51.04334503412247, 62.96856813132763, 64.38470274209976, 78.705123513937, 14.553570561110973, 0.43942816264461726, 0.137633869308047, 0.24688379606232047, 0.11644994665402919, 0.1593448207131587, 0.25335247395560145, 0.15549167903373018, 0.10331923913327046], [0.08161465535522439, 0.017036079698300455, 0.07172632424044423, 0.017831892073445488, 0.05022244688007049, 0.028806942609662656, 0.07629678133525886, 0.03888146558892913, 0.06103212093876209, 0.1640845023212023, 12.974025718867779, 54.23444040119648, 50.63518613576889, 40.39491422474384, 17.301968783140182, 21.84852361679077, 31.1186258867383, 50.19420839846134, 53.247697949409485, 55.25974698364735, 12.49262860044837, 0.5641672457568347, 0.6632504321169108, 0.5757113825529814, 17.06110540777445, 65.87410882115364, 56.783754006028175, 55.88064506649971, 48.78914639353752, 50.623562559485435, 48.52521255612373, 48.86565908789635, 49.15476277470589, 49.485523626208305, 49.11718659102917, 48.688888773322105, 47.090808525681496, 48.11877876520157, 46.752638071775436, 40.816171020269394, 37.39816702902317, 39.06248152256012, 38.181437999010086, 38.543163388967514, 37.1787516027689, 35.9585914760828, 36.49862989783287, 36.848895102739334, 36.907601952552795, 38.80257926881313, 37.6174608618021, 36.90505988895893, 35.71484595537186, 35.58624565601349, 37.26234331727028, 36.241702884435654, 35.17074555158615, 36.18569768965244, 34.80075180530548, 35.26876889169216, 36.77446089684963, 36.59103713929653, 35.61070874333382, 35.9946895390749, 35.73979161679745, 36.23910382390022, 37.060239762067795, 36.446394100785255, 37.90311053395271, 38.85144084692001, 40.02252660691738, 41.1661322414875, 39.952667355537415, 37.79754839837551, 37.13369362056255, 38.84674049913883, 37.33783006668091, 38.3941163867712, 38.41058470308781, 36.172588393092155, 38.31236757338047, 37.06519089639187, 36.31010301411152, 37.5382275134325, 39.712949618697166, 40.10629691183567, 47.03425996005535, 51.86769559979439, 52.9071070253849, 51.398527175188065, 49.69729766249657, 49.94441740214825, 39.45309676229954, 40.05966581404209, 38.34666833281517, 38.432501927018166, 37.41669863462448, 38.896377235651016, 40.50940588116646, 38.896084651350975, 37.853299006819725, 39.48710113763809, 38.612125888466835, 37.99111381173134, 38.10692019760609, 40.31189247965813, 40.65726354718208, 38.677657172083855, 38.39925371110439, 37.96174518764019, 37.54987768828869, 37.866222113370895, 38.07284742593765, 38.280909061431885, 36.18198148906231, 38.491463363170624, 36.72336503863335, 37.20064602792263, 36.464469730854034, 36.01786449551582, 36.37257546186447, 37.02247738838196, 36.99791930615902, 35.50368748605251, 37.4731370061636, 37.54000961780548, 36.8496360629797, 39.234908670187, 37.8926382958889, 38.05785343050957, 39.535537138581276, 40.59758394956589, 40.10390684008598, 39.85940895974636, 40.841812044382095, 41.5999511629343, 38.95573765039444, 41.77332445979118, 40.85706442594528, 42.547981292009354, 46.26146882772446, 56.006004139781, 54.3878685683012, 59.008998200297356, 52.8027456253767, 60.08809469640255, 52.30592228472233, 59.375526532530785, 58.52793261408806, 68.25551703572273, 55.113359838724136, 62.66207657754421, 30.18421422690153, 0.11894835712155327, 0.5413147970102727, 0.40309751057066023, 0.08241515068220906, 6.769754737615585, 62.377741634845734, 62.479667365550995, 64.27263915538788, 53.14866006374359, 20.869791135191917, 27.22017377614975, 47.93826185166836, 43.16791042685509, 53.402076065540314, 3.728997828438878, 0.28611467219889164, 0.08690389731782489, 0.032410568674094975, 0.07391059843939729, 0.03776886376726907, 0.04473929657251574, 0.05103593350213487, 0.06061068124836311, 0.060842465099995025, 0.057770819767029025, 0.043258032892481424, 0.034922174527309835, 0.03174974553985521, 0.05874534501344897, 0.008938617720559705, 0.07868355052778497, 0.1235918044403661, 0.09028645799844526, 17.564789280295372, 64.53482508659363, 56.65636584162712, 46.2791682779789, 20.325863622128963, 29.049967490136623, 37.81414210796356, 52.52774678170681, 55.26687540113926, 60.47477334737778, 13.032823763787746, 0.5697674327529967, 0.8534632378723472, 0.6215290271211416, 18.908041901886463, 67.72792294621468, 57.03341580927372, 58.18486802279949, 51.40729710459709, 53.53963628411293, 50.40608122944832, 52.281652987003326, 50.809197798371315, 51.240429058671, 50.425338596105576, 50.27055390179157, 48.40472102165222, 49.567527025938034, 48.319187611341476, 42.999499663710594, 38.46349686384201, 40.4862917214632, 41.39558672904968, 41.223425567150116, 40.01691810786724, 37.2282325476408, 38.06779369711876, 38.614192977547646, 38.804262578487396, 39.967235773801804, 39.3120027333498, 39.396833181381226, 38.80265146493912, 36.749834418296814, 36.94088816642761, 38.727111518383026, 36.272017657756805, 38.85732673108578, 37.04886317253113, 36.78497113287449, 37.19172030687332, 38.63023951649666, 36.61758251488209, 38.830226585268974, 38.09762589633465, 38.57097789645195, 38.18974435329437, 39.52777035534382, 39.077939093112946, 41.28439709544182, 42.231591269373894, 42.41462744772434, 41.4982496201992, 40.52262917160988, 38.58745761215687, 41.1163093149662, 40.1226132363081, 40.15888229012489, 39.51846085488796, 38.66771310567856, 39.17863368988037, 40.15568286180496, 40.45701429247856, 40.03390319645405, 41.795629262924194, 42.723319083452225, 49.36474330723286, 54.995904341340065, 54.021986201405525, 52.618151530623436, 52.309744879603386, 51.918844655156136, 43.23599137365818, 41.393223255872726, 40.92032343149185, 38.69653455913067, 39.045644626021385, 40.48434242606163, 41.70613646507263, 40.87435729801655, 39.27365139126778, 41.28844007849693, 39.94119577109814, 39.67967100441456, 39.74203325808048, 41.14679127931595, 41.63261421024799, 40.412340089678764, 40.80447144806385, 40.01896619796753, 39.74095031619072, 38.88514123857021, 39.61765453219414, 40.2847733348608, 39.281402975320816, 40.77327512204647, 39.3489595502615, 40.231971368193626, 38.908251598477364, 38.693316131830215, 37.95854575932026, 38.727521896362305, 39.22260493040085, 38.29333059489727, 39.069355353713036, 39.07621778547764, 39.250917211174965, 41.223706752061844, 39.76244196295738, 40.2129951864481, 41.315874606370926, 40.96458725631237, 42.06318810582161, 41.10474273562431, 42.914255037903786, 43.254226595163345, 41.18400648236275, 44.40259337425232, 41.988495513796806, 44.314875081181526, 48.15978616476059, 58.19332256913185, 56.285783126950264, 61.021989583969116, 57.02843427658081, 60.65646439790726, 55.37777625024319, 63.23671214282513, 61.496857702732086, 69.63279113173485, 55.964050590991974, 64.81305375695229, 32.563025280833244, 0.07174685946665704, 2.171705304645002, 0.5004701355937868, 0.027356231294106692, 7.463418440893292, 67.7269198000431, 65.99400758743286, 71.86998188495636, 58.039221838116646, 26.807139739394188, 30.74605207890272, 53.80340293049812, 50.87998799979687, 64.27712291479111, 7.366270003840327, 0.30898267636075616, 0.011531525851751212, 0.01442092197976308, 0.05941096613241825, 0.05073223925137427, 0.10474846712895669, 0.02597311293357052, 0.1321551570435986, 0.14863585238344967, 0.10765948201878928, 0.16372119134757668, 0.10623986483551562, 0.20022293814690784, 0.10227038408629596, 0.14970690506743267, 0.1562338712392375, 0.2160322866984643, 0.29000210110098124, 21.63640759885311, 74.79641765356064, 62.12016485631466, 52.800252959132195, 24.649241231381893, 30.908829644322395, 43.2449246942997, 59.97611850500107, 63.29302132129669, 66.7465192079544, 15.167905446141958, 0.5573348561301827, 1.4730090089142323, 0.6664373923558742, 21.763185895979404, 71.32246166467667, 60.043329298496246, 59.77753356099129, 53.47840256989002, 56.30646161735058, 53.13167877495289, 53.905184268951416, 54.612010940909386, 53.73731687664986, 52.88588136434555, 52.412517964839935, 52.5886233150959, 52.679145857691765, 52.170235365629196, 46.55718415975571, 41.15932300686836, 42.192430570721626, 42.44165539741516, 43.225268349051476, 40.741782411932945, 38.89947406947613, 40.64586415886879, 42.09819182753563, 40.898835584521294, 42.68983907997608, 40.98629169166088, 41.9289793074131, 39.879479482769966, 39.38704490661621, 41.08824402093887, 41.434580236673355, 38.76068651676178, 40.53994484245777, 41.63273200392723, 38.49246270954609, 40.21861128509045, 41.7380927503109, 37.892718091607094, 41.60818912088871, 39.64615300297737, 39.82392646372318, 40.013224706053734, 40.17892621457577, 40.850095599889755, 43.70209716260433, 43.31018999218941, 45.76804630458355, 42.60136842727661, 41.76297001540661, 40.433314964175224, 44.113383293151855, 44.09011334180832, 42.95204780995846, 41.152232587337494, 40.62695637345314, 42.53873638808727, 40.99512621760368, 42.712721452116966, 42.00374409556389, 44.90581177175045, 45.92936284840107, 51.85980722308159, 55.908543169498444, 57.03802116215229, 53.99507224559784, 54.199562072753906, 56.331825256347656, 45.68179853260517, 45.554999336600304, 44.10610668361187, 42.95433908700943, 41.49454861879349, 43.40955086052418, 46.39008432626724, 43.224428594112396, 41.82291179895401, 43.51154878735542, 43.29628273844719, 42.1336667239666, 41.358105540275574, 43.41006003320217, 45.596177726984024, 42.05730602145195, 42.85880081355572, 42.22956597805023, 41.073899790644646, 41.37282595038414, 40.23142799735069, 41.29944048821926, 41.16118110716343, 42.68423058092594, 41.586515083909035, 42.00342871248722, 40.896958485245705, 41.569484397768974, 42.0245061814785, 41.10608786344528, 41.54999524354935, 41.12859785556793, 42.00042687356472, 42.56211653351784, 41.28655917942524, 44.679404720664024, 43.375025913119316, 43.219059482216835, 45.038800835609436, 44.82322700321674, 44.374129101634026, 44.20207053422928, 44.948605075478554, 44.087100103497505, 43.917405009269714, 46.79765805602074, 44.27882641553879, 46.73877261579037, 49.78913493454456, 60.94604305922985, 58.444329500198364, 63.157038018107414, 57.782093435525894, 64.92472216486931, 58.28299015760422, 65.70358157157898, 62.348373010754585, 70.53525030612946, 59.45795550942421, 66.80314376950264, 35.425225496292114, 0.24824439024087042, 4.201575145125389, 1.7127797054126859, 0.19190911785699427, 7.181749530136585, 75.09290814399719, 72.45918586850166, 79.65865954756737, 66.21325582265854, 31.23806867748499, 38.8580296933651, 61.83492936193943, 58.60371574759483, 74.93003368377686, 11.585574522614479, 0.6276641541626304, 0.2219130055163987, 0.1651393316569738, 0.2329153151367791, 0.16505307925399393, 0.19225117372116074, 0.1544588469550945, 0.2536018058890477], [0.009178593954857206, 0.028045614126313012, 0.034485350115573965, 0.03909258062776644, 0.03221825594664551, 0.034842816676246, 0.05935440705798101, 0.07190248041297309, 0.14521357195917517, 0.0177133506804239, 5.3601154033094645, 53.767517656087875, 46.47083759307861, 44.614405408501625, 33.818861693143845, 30.542206317186356, 36.89284734427929, 53.35234813392162, 52.21363663673401, 57.63724900782108, 16.329467967152596, 0.4895283852238208, 0.31331586884334683, 0.6929480948019773, 10.896944124251604, 65.47652095556259, 57.02939182519913, 56.36726215481758, 51.99895955622196, 52.936992421746254, 54.222775027155876, 53.35657350718975, 49.27981026470661, 52.31849581003189, 53.40054094791412, 52.73735873401165, 52.41632916033268, 50.14485664665699, 52.94609293341637, 48.61427217721939, 38.56111742556095, 38.142976462841034, 38.1185095757246, 38.506711944937706, 37.22268104553223, 38.39490294456482, 37.80325949192047, 38.794158920645714, 39.372651278972626, 40.24728074669838, 40.17242856323719, 37.712185978889465, 36.36779151856899, 35.28677612543106, 34.89462576806545, 35.86985103785992, 35.9185416251421, 36.82779103517532, 36.73348769545555, 36.65158689022064, 36.7359309643507, 36.73569917678833, 37.042962089180946, 36.17392212152481, 36.442457512021065, 36.04529522359371, 36.87632203102112, 37.921900525689125, 39.390897899866104, 39.41743567585945, 39.48593460023403, 38.16647060215473, 38.55605609714985, 38.810650035738945, 36.95955276489258, 36.91539913415909, 38.43670070171356, 38.26552748680115, 39.023229628801346, 37.27332852780819, 37.26581633090973, 35.53699269890785, 36.704001277685165, 38.340003490448, 38.812329545617104, 38.18932257592678, 44.30504880845547, 51.83535173535347, 52.078325897455215, 51.83326944708824, 51.79115250706673, 48.55044700205326, 38.34580957889557, 38.37383307516575, 37.05646276473999, 37.133214846253395, 37.12833970785141, 38.355195075273514, 40.24047911167145, 41.51920549571514, 38.92050974071026, 38.468318805098534, 37.88781255483627, 37.52026967704296, 37.83219113945961, 37.15768553316593, 36.88885375857353, 41.15265816450119, 40.35261109471321, 37.576293870806694, 38.777542412281036, 40.16837798058987, 37.85823114216328, 38.575587049126625, 36.399143636226654, 37.35630847513676, 37.49397128820419, 36.13741748034954, 36.577346473932266, 36.42209440469742, 36.452302783727646, 37.990270256996155, 36.59670643508434, 37.80675150454044, 36.585166454315186, 37.313104793429375, 36.7291559278965, 38.408832997083664, 36.28922313451767, 37.064373940229416, 39.580203741788864, 41.32188968360424, 40.486181527376175, 40.83938017487526, 40.609321519732475, 41.73904649913311, 38.938102796673775, 42.399777844548225, 39.485284835100174, 41.41457051038742, 44.53411191701889, 53.96439269185066, 50.58153681457043, 57.363538295030594, 54.13295544683933, 56.4471984654665, 52.46194191277027, 61.35399676859379, 56.077501103281975, 64.40158143639565, 58.355106487870216, 60.103027895092964, 27.38298363983631, 0.023273400474863593, 0.8184577350039035, 0.19471048784907907, 0.07221923646284267, 5.98426753655076, 62.22239077091217, 61.64194531738758, 63.0388605594635, 52.733368948102, 26.0939959064126, 27.351698018610477, 43.1991333514452, 44.08896200358868, 49.23197843134403, 4.513206398114562, 0.2420091920066625, 0.017981828168558422, 0.03143704903777689, 0.04297356768802274, 0.05001772915420588, 0.022313556764856912, 0.03075076652748976, 0.015570269388263114, 0.040526599186705425, 0.02674082017620094, 0.012900298497697804, 0.02957703771244269, 0.050928370328620076, 0.013885249063605443, 0.032828872790560126, 0.11286271648714319, 0.150113794952631, 0.0457716277014697, 7.305622408166528, 61.91607020795345, 51.65775306522846, 50.353640243411064, 31.80891014635563, 28.310779854655266, 42.41559639573097, 60.2812497317791, 56.75452217459679, 61.67533412575722, 16.89155090600252, 0.6603247672319412, 0.43486632930580527, 0.6686298153363168, 12.13264636695385, 67.77302652597427, 60.16359284520149, 58.11726965010166, 54.063274785876274, 55.50269454717636, 55.586065873503685, 54.6292620152235, 52.03952617943287, 54.80396144092083, 55.937493816018105, 54.31183084845543, 55.21006464958191, 53.57273630797863, 55.76155185699463, 50.11377051472664, 39.390365928411484, 39.42361034452915, 40.25952368974686, 39.36145707964897, 38.299372270703316, 40.72250224649906, 39.409437105059624, 39.525916054844856, 40.04524938762188, 41.09946481883526, 40.961220636963844, 40.46053670346737, 37.82718300819397, 37.952127903699875, 37.4821463227272, 36.88602291047573, 38.72512422502041, 39.81112875044346, 38.09185020625591, 38.087032064795494, 37.71160461008549, 38.20638746023178, 39.66628812253475, 37.55750007927418, 36.89883582293987, 37.587735056877136, 39.222730323672295, 38.98233242332935, 40.03495953977108, 41.4641160517931, 41.22919745743275, 39.03155878186226, 40.196082293987274, 40.60046039521694, 38.21072302758694, 38.81638012826443, 40.1119814068079, 39.79737348854542, 39.58570584654808, 36.93214103579521, 39.0199314057827, 37.631200924515724, 40.679963529109955, 39.64227341115475, 39.57755908370018, 40.93277536332607, 47.74445325136185, 53.65965284407139, 53.27801272273064, 53.39262217283249, 53.33318956196308, 48.6104191839695, 41.66595742106438, 41.88354514539242, 39.3463034927845, 38.03630478680134, 39.28951174020767, 39.38075244426727, 41.27125360071659, 41.52044042944908, 40.60188911855221, 41.35483391582966, 37.8587631136179, 39.17339377105236, 38.950288742780685, 40.281114131212234, 39.654945731163025, 43.25989969074726, 42.822448164224625, 38.13936285674572, 38.98678578436375, 40.59762954711914, 37.751966044306755, 38.01306523382664, 37.936856523156166, 40.116753950715065, 39.435712695121765, 39.73651975393295, 38.688779175281525, 38.378537222743034, 38.77529673278332, 39.33141969144344, 39.223425686359406, 39.37776580452919, 38.28837566077709, 39.05870072543621, 37.85375118255615, 39.26780350506306, 39.45621259510517, 39.861058071255684, 41.61931112408638, 42.72923156619072, 42.91616253554821, 43.69187571108341, 41.84520900249481, 44.83977131545544, 41.881801038980484, 44.37892444431782, 41.94170482456684, 43.83144982159138, 47.22934149205685, 56.708043068647385, 54.92346502840519, 60.67335449159145, 57.059858590364456, 59.688477739691734, 54.585359171032906, 63.41315947473049, 57.99840822815895, 68.494653403759, 60.120221972465515, 61.92580908536911, 30.332467071712017, 0.202155104780104, 1.5321470168419182, 0.9980182279832661, 0.04485130892135203, 6.869434313848615, 67.66142651438713, 65.72074145078659, 68.43929797410965, 59.29649077355862, 24.03336837887764, 30.08107826113701, 49.598715752363205, 50.39214737713337, 60.61678312718868, 6.892008427530527, 0.2839156292611733, 0.017577149883436505, 0.017550070770084858, 0.06337593091302551, 0.023385639178741258, 0.07546611028374173, 0.023971000737219583, 0.061167574021965265, 0.13361626770347357, 0.12109734961995855, 0.08183634970919229, 0.15730225219158456, 0.13764532806817442, 0.12135264099924825, 0.16776999284047633, 0.2341499223257415, 0.28582790633663535, 0.15764873125590384, 8.268030490726233, 71.02830424904823, 59.7933255136013, 58.60174745321274, 43.43530207872391, 42.03579917550087, 51.664984077215195, 65.77152192592621, 60.43993301689625, 68.41465249657631, 20.275622718036175, 0.6035907834302634, 0.7986342580989003, 1.0193278407678008, 14.617454633116722, 69.88553836941719, 63.29421065747738, 61.4476465433836, 56.59939929842949, 57.55144581198692, 57.76523754000664, 57.43688955903053, 53.46761494874954, 57.116505950689316, 59.413437098264694, 57.776408940553665, 57.31348738074303, 56.761251613497734, 58.57717037200928, 52.2832603007555, 42.640095949172974, 43.017601892352104, 42.25143000483513, 41.82893067598343, 39.69735145568848, 42.19328932464123, 41.27287991344929, 43.46219703555107, 44.33669351041317, 45.08144214749336, 42.88428604602814, 42.707489132881165, 40.35729244351387, 38.718877360224724, 40.70147417485714, 40.81130348145962, 40.85629686713219, 40.901624634861946, 41.61966070532799, 40.54799661040306, 39.98681992292404, 41.15027189254761, 40.33747270703316, 38.55359002947807, 39.656917825341225, 39.55383315682411, 40.645423382520676, 41.21178299188614, 43.12382899224758, 43.20800207555294, 43.02462011575699, 40.462463200092316, 42.349088564515114, 43.910949155688286, 40.5476014316082, 40.126907005906105, 42.05544792115688, 43.067200630903244, 42.5998979061842, 40.21623641252518, 42.88935877382755, 39.713652580976486, 43.36078807711601, 41.311713829636574, 42.839820832014084, 42.44090683758259, 48.10051694512367, 55.85937760770321, 56.123326644301414, 55.588896721601486, 56.76792025566101, 50.77473744750023, 43.0739376693964, 45.166956558823586, 41.062055826187134, 40.32079540193081, 43.356304317712784, 42.13302455842495, 44.670520797371864, 45.4383759945631, 43.611965999007225, 43.61650675535202, 40.85274785757065, 41.49425223469734, 39.91885297000408, 40.21990701556206, 40.88501192629337, 45.47348231077194, 44.21088986098766, 39.85081762075424, 42.59160295128822, 43.509322106838226, 40.59520527720451, 41.55427001416683, 39.69129838049412, 41.79685279726982, 41.726453974843025, 40.36271475255489, 41.36826239526272, 41.733263209462166, 41.75356552004814, 41.89706102013588, 42.934629544615746, 41.84654273092747, 41.725382432341576, 41.40714950859547, 40.91275043785572, 43.35441201925278, 42.0330823212862, 41.63350336253643, 44.595832005143166, 46.47779121994972, 45.17448775470257, 46.28720484673977, 44.467547088861465, 46.069571524858475, 43.79412442445755, 45.772526264190674, 43.59375737607479, 46.54539719223976, 49.64491747319698, 59.240398183465004, 55.87020702660084, 63.455823585391045, 58.83103474974632, 63.08283559978008, 57.585001811385155, 65.5280613899231, 60.51393024623394, 70.26297211647034, 62.329206839203835, 61.94273717701435, 33.42772588133812, 0.46716156823094934, 4.500545002520084, 3.3340679202228785, 0.177713317098096, 7.140229158103466, 74.62529763579369, 69.57149282097816, 75.35029873251915, 65.8592364192009, 38.37969236075878, 39.55840811133385, 57.72789314389229, 59.81314904987812, 72.98192381858826, 9.689452517777681, 0.5211727903224528, 0.09760493951034732, 0.08771860477281734, 0.19357246375875548, 0.16959064436377957, 0.10859886286198162, 0.15746487159049138, 0.1397000826545991], [0.03492220050247852, 0.043524445354705676, 0.038847467803861946, 0.014507370124192676, 0.04041397085529752, 0.06558298904565163, 0.07252894953126088, 0.05781587926321663, 0.08045802562264726, 0.021696496223739814, 2.385747106745839, 45.92917665839195, 54.76646885275841, 48.74487116932869, 28.243076987564564, 24.19578116387129, 30.5980272218585, 46.893751099705696, 55.657798424363136, 57.08871804177761, 25.309917479753494, 0.4109175503253937, 0.5881915159989148, 0.23213110252982005, 6.894266456365585, 59.73588779568672, 58.18312391638756, 57.912848219275475, 53.25580291450024, 53.46552886068821, 53.93242880702019, 51.52997352182865, 54.19446274638176, 54.27931219339371, 53.55037830770016, 52.30308383703232, 51.851854249835014, 54.29315485060215, 50.96125803887844, 49.310273230075836, 38.697955682873726, 38.957139775156975, 36.21021777391434, 36.787034422159195, 39.683535397052765, 42.0915611833334, 39.416067749261856, 40.34562326967716, 44.19307641685009, 44.028127267956734, 41.19401894509792, 39.46897991001606, 37.28522948920727, 35.12667551636696, 35.56881219148636, 35.65578952431679, 35.68157494068146, 37.364409640431404, 35.82699313759804, 37.045336961746216, 37.09922567009926, 34.94492746889591, 35.98236680030823, 36.55443750321865, 35.04546247422695, 36.365933418273926, 37.38201029598713, 38.6641488969326, 36.774738281965256, 38.00884746015072, 39.44890558719635, 39.41500760614872, 37.29225531220436, 37.067527770996094, 38.050751611590385, 36.8442327529192, 38.64732339978218, 38.54511268436909, 38.8589758425951, 37.698704302310944, 35.83266623318195, 37.83597953617573, 37.97319397330284, 40.45377306640148, 40.49584440886974, 40.35459078848362, 44.698973670601845, 50.29442422091961, 53.428454250097275, 53.814038559794426, 52.345295771956444, 47.46784709393978, 39.75354664027691, 38.52852277457714, 37.5072667747736, 35.5128487944603, 38.032759577035904, 38.17280866205692, 37.4152585119009, 38.3279163390398, 38.76895487308502, 37.83688388764858, 37.597055956721306, 39.229839742183685, 37.430507093667984, 38.48057694733143, 39.51745770871639, 38.349681571125984, 39.313268065452576, 37.25006617605686, 38.118418380618095, 36.75395719707012, 36.64542742073536, 36.54433384537697, 35.58683082461357, 36.604632809758186, 36.73949517309666, 37.00582668185234, 36.61043129861355, 36.371678709983826, 36.42834886908531, 37.11302272975445, 36.38860680162907, 35.700961500406265, 36.436909809708595, 35.99869832396507, 35.43314427137375, 37.21883565187454, 38.05661849677563, 37.53348916769028, 37.652631774544716, 38.59170578420162, 38.88420268893242, 40.959677919745445, 42.56854198873043, 41.92718580365181, 39.75201532244682, 41.017362624406815, 40.945580676198006, 41.95896729826927, 44.027355909347534, 50.45207016170025, 52.1924489736557, 55.469727516174316, 52.45294779539108, 57.1258420497179, 56.09196312725544, 63.21044035255909, 58.75184319913387, 66.25149697065353, 55.480693727731705, 66.77689477801323, 25.508133843541145, 0.03524894214933738, 1.027154945768416, 0.1829266521963291, 0.10729329893365502, 8.03603108972311, 64.79701861739159, 59.930315762758255, 65.71687325835228, 44.42700706422329, 33.741102665662766, 34.75560262799263, 48.583877608180046, 51.54861532151699, 42.09318369626999, 3.9775496162474155, 0.2464158571092412, 0.015633012408216018, 0.0782822267501615, 0.03989707613072824, 0.028752250036632176, 0.07193762110546231, 0.025085515444516204, 0.043760834232671186, 0.014816546990914503, 0.021953440736979246, 0.08264116433565505, 0.07049541294691153, 0.030703239390277304, 0.017703294579405338, 0.0520387011783896, 0.03676355423522182, 0.0806511176051572, 0.09369785111630335, 2.9260937869548798, 54.48978289961815, 60.16192093491554, 53.76464881002903, 31.751489527523518, 24.25773873925209, 34.51327443122864, 53.282523080706596, 59.62333023548126, 62.721915766596794, 25.934115685522556, 0.5625866493210196, 0.6645509123336524, 0.37991174845956266, 7.830184260383248, 61.605246886610985, 59.23520006239414, 59.357458502054214, 55.54429091513157, 54.87607017159462, 55.77621527016163, 53.847377970814705, 55.4900336265564, 55.63230559229851, 54.557240679860115, 53.049113005399704, 52.41987057030201, 56.161537393927574, 53.83577339351177, 50.527169331908226, 41.218554228544235, 41.18921220302582, 38.806200474500656, 39.10337492823601, 41.816425547003746, 42.68609628081322, 42.476355135440826, 43.37602525949478, 45.30230529606342, 45.578333884477615, 44.30980995297432, 41.6691530495882, 38.458389937877655, 36.62252604961395, 37.844639271497726, 36.62877671420574, 37.22278743982315, 38.65074321627617, 38.10294561088085, 39.03681389987469, 37.91598044335842, 37.213941514492035, 38.89036975800991, 39.10180181264877, 36.96106508374214, 37.278640642762184, 40.126546025276184, 38.663259744644165, 38.54464150965214, 40.16533814370632, 40.11608138680458, 40.11723652482033, 39.922439977526665, 40.42131520807743, 38.960149213671684, 38.41592721641064, 40.79189032316208, 40.38215830922127, 39.970169216394424, 39.40443277359009, 38.86834233999252, 41.321327313780785, 40.13313487172127, 41.74643710255623, 42.92359113693237, 42.53257691860199, 46.47172674536705, 52.226658537983894, 55.744783356785774, 54.12800811231136, 53.342350870370865, 48.635619431734085, 42.80778855085373, 40.95882296562195, 40.160197019577026, 37.58205436170101, 38.28619457781315, 40.284457951784134, 38.72694052755833, 39.52950306236744, 40.7888200879097, 40.188828483223915, 40.94751477241516, 40.44428497552872, 40.95504976809025, 41.113843247294426, 41.606779396533966, 39.978555366396904, 42.0121606439352, 39.55558866262436, 40.41857935488224, 39.83418211340904, 40.191674530506134, 38.9028786867857, 38.48789915442467, 39.601471200585365, 37.26969972252846, 38.12487803399563, 38.4849239140749, 38.005602434277534, 37.601934894919395, 39.306656420230865, 38.568470031023026, 39.08891290426254, 37.68234997987747, 38.27535755932331, 36.868198066949844, 39.9019780755043, 38.915285021066666, 40.040864422917366, 40.31383037567139, 42.452944591641426, 40.30230179429054, 43.59124191105366, 43.14328394830227, 43.067554011940956, 41.56428627669811, 43.26094463467598, 42.24930211901665, 43.35368625819683, 46.050139367580414, 53.65802273154259, 54.069004878401756, 59.67416010797024, 54.7525729984045, 58.26404817402363, 58.12002070248127, 64.92305785417557, 62.765263840556145, 67.29018643498421, 56.43666923046112, 66.53386741876602, 28.16871117800474, 0.10548251797445118, 1.0090477298945189, 0.3460550308227539, 0.0846413710678462, 7.923365710303187, 69.13729771971703, 64.26475837826729, 70.40968224406242, 48.83751019835472, 32.20052093267441, 38.63916143774986, 52.61600464582443, 59.36306320130825, 53.045263811945915, 5.195835493505001, 0.2251405909191817, 0.034618387508089654, 0.032443160089314915, 0.04158737312536687, 0.08707999411853962, 0.008970975359261502, 0.03377147084393073, 0.060751039927708916, 0.12088093935744837, 0.05697458065696992, 0.12806601240299642, 0.13199022214394063, 0.132303616264835, 0.11154477353557013, 0.119860649574548, 0.167447603889741, 0.16009100567316636, 0.15501930203754455, 4.290576819330454, 64.17245373129845, 68.43792244791985, 61.49167478084564, 40.012958720326424, 33.58305774629116, 42.60905921459198, 58.81750367581844, 65.6487201154232, 67.18121588230133, 30.886294953525066, 0.6283864716533571, 1.9994294364005327, 0.46180958510376513, 10.826865434646606, 65.50621256232262, 59.718936905264854, 63.22756603360176, 57.45579354465008, 57.10531175136566, 58.83300684392452, 55.86512669920921, 57.59285978972912, 57.938804626464844, 57.89748564362526, 54.53265979886055, 54.15775291621685, 59.24834355711937, 55.46604171395302, 53.11054430902004, 42.880151867866516, 43.42297174036503, 39.44891318678856, 41.202697679400444, 44.88956764340401, 45.36425717175007, 45.2475768327713, 46.44291669130325, 48.73143129050732, 48.37219096720219, 45.68331465125084, 44.760260581970215, 40.226560458540916, 38.800120800733566, 40.77965497970581, 39.25676129758358, 39.87112753093243, 41.96753963828087, 39.29312914609909, 40.842925384640694, 40.14571599662304, 38.21696989238262, 40.344038754701614, 40.70429742336273, 37.82245606184006, 39.025973081588745, 43.22089098393917, 41.6956452280283, 41.888002306222916, 42.647239565849304, 41.940507888793945, 42.12434962391853, 41.660630106925964, 42.179439067840576, 41.047950983047485, 40.52937760949135, 42.76020370423794, 42.12143898010254, 44.04494896531105, 42.70694196224213, 40.81827990710735, 42.440295070409775, 42.65335723757744, 46.33283659815788, 46.36747553944588, 44.393834844231606, 47.3815955221653, 54.536558389663696, 57.383931800723076, 58.18854242563248, 57.89042182266712, 51.796647012233734, 45.47612316906452, 42.658293172717094, 42.72369146347046, 40.61587996780872, 42.02585130929947, 41.48402318358421, 41.82545006275177, 43.13797943294048, 43.35019424557686, 43.24873208999634, 42.56695747375488, 42.08343341946602, 41.27693049609661, 43.201223239302635, 43.62204685807228, 41.7938357591629, 44.5401231944561, 40.51214553415775, 42.79876783490181, 41.281273663043976, 42.6026451587677, 41.078546941280365, 40.012187361717224, 41.81541100144386, 41.02693811058998, 42.301378324627876, 40.167614221572876, 39.85235653817654, 40.80473743379116, 41.83564491569996, 41.06609880924225, 42.18094378709793, 41.45550951361656, 40.157202780246735, 39.993769749999046, 43.18525269627571, 42.0398573577404, 42.80108571052551, 42.42710217833519, 43.24880808591843, 43.89265313744545, 45.7746921479702, 45.57681016623974, 44.947928711771965, 43.131557777523994, 45.69848723709583, 45.32253161072731, 46.225150376558304, 48.88573721051216, 57.62796230614185, 56.37848675251007, 63.136089742183685, 58.53832885622978, 61.412357836961746, 60.40549546480179, 68.30673828721046, 64.09627541899681, 68.97238656878471, 58.80963049829006, 67.28896290063858, 30.718136876821518, 0.4102753847837448, 4.7035030368715525, 1.7040889780037105, 0.19741362717468292, 9.008788391947746, 77.20330730080605, 69.1350482404232, 78.97935479879379, 58.3134151250124, 47.1963706612587, 45.80462694168091, 63.37350860238075, 68.51998284459114, 67.12410494685173, 7.497786646708846, 0.27505937323439866, 0.12589701160322875, 0.18909670470748097, 0.08587741802330129, 0.1420762317138724, 0.16227620013523847, 0.21692877140594646, 0.172017096192576], [0.04978663178917486, 0.028723727446049452, 0.03286867788119707, 0.05742869710957166, 0.007552187526016496, 0.028715792032016907, 0.05812352173961699, 0.026978543064615224, 0.050993575423490256, 0.0313102531072218, 0.6033682578708977, 33.6707304418087, 51.3347551971674, 43.48791025578976, 30.716216079890728, 25.015266090631485, 29.711768478155136, 46.794124245643616, 53.33592161536217, 54.25900988280773, 33.73493939638138, 0.08727019172511064, 0.1565627465606667, 0.13520455278921872, 5.10957489721477, 49.33649942278862, 53.38018923997879, 56.31590411067009, 54.713556692004204, 56.564186587929726, 51.728680059313774, 49.492374658584595, 47.677181661129, 49.313161075115204, 53.18155109882355, 50.67023925483227, 53.472334295511246, 51.71426363289356, 53.38084280490875, 42.89400212466717, 36.74869067966938, 36.299680173397064, 38.350772112607956, 38.44174683094025, 42.54148744046688, 46.57594755291939, 44.89228069782257, 45.46058960258961, 44.85019035637379, 45.62777683138847, 44.03331018984318, 39.11810673773289, 37.67660468816757, 35.569477155804634, 35.33506393432617, 34.732351675629616, 35.446492955088615, 37.015622556209564, 36.8420896679163, 37.45169095695019, 38.04229326546192, 35.71120575070381, 37.095072492957115, 36.270619332790375, 35.34783124923706, 35.13387233018875, 37.67040342092514, 38.08713085949421, 39.18545812368393, 37.94851429760456, 38.40960435569286, 37.637014612555504, 39.12941113114357, 37.862141132354736, 38.68716046214104, 37.58195176720619, 37.03061655163765, 36.997512727975845, 38.9397557079792, 38.83957788348198, 36.92372828722, 35.92231102287769, 39.559065476059914, 39.89470146596432, 39.9945031106472, 40.00331863760948, 41.77460879087448, 50.60359463095665, 53.130808621644974, 52.58911728858948, 52.453817948699, 45.61987325549126, 40.90562202036381, 38.622313141822815, 37.08206579089165, 37.30619676411152, 36.62863992154598, 36.942263692617416, 38.39389979839325, 38.862494453787804, 39.11643862724304, 38.753265514969826, 36.97702802717686, 38.651529774069786, 38.60644519329071, 38.87761764228344, 38.85817788541317, 40.82712583243847, 37.98934690654278, 37.192674055695534, 36.58542484045029, 38.62056903541088, 37.93354690074921, 37.3778685182333, 36.88374683260918, 37.087028324604034, 36.12902753055096, 36.94792538881302, 35.669677779078484, 35.20943887531757, 38.05034123361111, 35.91508001089096, 36.066315695643425, 36.82042323052883, 35.709210857748985, 35.74975088238716, 36.67152442038059, 37.37864747643471, 36.4779020100832, 37.62779250741005, 37.492926344275475, 39.00933377444744, 39.078908041119576, 40.509257689118385, 40.83001747727394, 43.08070130646229, 41.39158934354782, 40.3893019258976, 40.18708057701588, 41.16694159805775, 40.22561430931091, 49.26129765808582, 48.168829679489136, 51.07708342373371, 51.59910701215267, 60.22962190210819, 54.93427164852619, 59.345489144325256, 57.43749372661114, 62.77811475098133, 54.792569652199745, 68.66693615913391, 21.547262482345104, 0.03826490785286296, 0.41399963025469333, 0.1833379504387267, 0.04518789515714161, 7.93077721260488, 66.118124127388, 61.91078469157219, 62.84254029393196, 47.43721693754196, 29.523239694535732, 34.15083847939968, 51.55140057206154, 53.673609495162964, 44.44158688187599, 3.164265244267881, 0.20448397903237492, 0.017898772566695698, 0.010330365403206088, 0.03914340661140159, 0.07984076655702665, 0.045099501658114605, 0.07569443943793885, 0.03447420305747073, 0.02768644248135388, 0.0710147678910289, 0.02922771622252185, 0.0929956606705673, 0.020521528022072744, 0.04793472100573126, 0.061507462814915925, 0.032330409303540364, 0.07561627644463442, 0.06878659565700218, 1.0161247313953936, 43.9616422355175, 59.47206795215607, 49.81362462043762, 35.93958869576454, 23.49837228655815, 32.894747480750084, 52.84382522106171, 60.25945030152798, 60.605072155594826, 37.83645451068878, 0.10430171649204567, 0.04270914047083352, 0.23296916537219658, 6.895838622003794, 52.43510015308857, 55.0967813283205, 58.7208216637373, 56.56018540263176, 59.67013232409954, 53.174156695604324, 51.744399815797806, 50.21861828863621, 49.537428840994835, 53.583485931158066, 51.74230992794037, 54.043766632676125, 54.138959124684334, 56.02513991296291, 46.47618390619755, 39.705718606710434, 37.631611302495, 38.38337056338787, 40.18925026059151, 44.56835947930813, 46.84561148285866, 48.20862494409084, 46.73656113445759, 47.914402931928635, 47.8006674349308, 45.93443937599659, 40.95565773546696, 39.26308795809746, 38.52827958762646, 37.74295672774315, 36.52490548789501, 37.46852025389671, 38.73201705515385, 38.60576502978802, 38.927854746580124, 37.62730233371258, 36.95214316248894, 38.98742035031319, 37.85803735256195, 37.61048823595047, 37.919825837016106, 38.39879773557186, 39.9778638035059, 40.196401476860046, 39.04661737382412, 41.11459940671921, 39.83941823244095, 41.9125983864069, 40.043976455926895, 39.21362981200218, 39.97523054480553, 39.78568531572819, 40.657890513539314, 39.25728186964989, 41.077809780836105, 37.764322981238365, 38.858242481946945, 40.52875444293022, 41.34050868451595, 42.7504800260067, 42.30326682329178, 45.653676241636276, 52.3640363663435, 53.40340219438076, 54.52726788818836, 52.75047183036804, 48.09503763914108, 41.54099352657795, 40.43505147099495, 39.63720828294754, 40.1456817984581, 38.45396317541599, 39.01536405086517, 40.4495020955801, 40.11954680085182, 39.830830693244934, 40.13688147068024, 39.32858504354954, 40.45591615140438, 39.89815168082714, 40.95477618277073, 39.58996161818504, 42.16700233519077, 40.50480432808399, 39.69607472419739, 38.10725077986717, 39.294436275959015, 39.87937308847904, 39.50947053730488, 38.36763560771942, 38.917367309331894, 37.770463451743126, 39.8616736382246, 37.234152629971504, 38.160599917173386, 39.870705753564835, 38.965647518634796, 38.305562138557434, 39.22003246843815, 38.05792562663555, 37.11634375154972, 38.789238184690475, 39.70161482691765, 37.72767394781113, 40.12482091784477, 40.095171108841896, 39.94947172701359, 40.15075832605362, 42.82027468085289, 42.574017494916916, 44.84674394130707, 43.96923042833805, 42.62563772499561, 41.47307597100735, 43.35094280540943, 41.002330631017685, 51.09784930944443, 51.34177342057228, 54.24711272120476, 54.296453073620796, 59.97007682919502, 57.89283089339733, 63.57124999165535, 59.7099693864584, 66.55758574604988, 54.9901020526886, 69.57998916506767, 25.75290910899639, 0.1387396693462506, 1.2761771958321333, 0.7447624113410711, 0.05172591561859008, 8.866662718355656, 72.25369289517403, 63.688587695360184, 68.52308347821236, 52.22414307296276, 39.19372268021107, 41.409763768315315, 57.378726080060005, 60.945788472890854, 55.13276159763336, 4.4795796275138855, 0.26349686086177826, 0.06755014052032493, 0.02954113075247733, 0.06622167391469702, 0.07220006678835489, 0.04160000076808501, 0.05950962353381328, 0.017412417219020426, 0.15815647901035845, 0.15171018429100513, 0.1180575424223207, 0.1934848606470041, 0.18165134562877938, 0.15065409330418333, 0.13615114730782807, 0.18245200422825292, 0.3345191170228645, 0.13305133004905656, 1.2554754316806793, 52.38464646041393, 65.51126629114151, 55.88065646588802, 43.30468788743019, 35.26696018874645, 42.67186224460602, 57.443349212408066, 64.34285178780556, 63.9020374417305, 42.974983379244804, 0.16087248717667535, 0.8475939778145403, 0.6721572729293257, 8.410927522927523, 55.10085470974445, 55.13623081147671, 60.395904779434204, 58.48308742046356, 61.88551224768162, 54.63265523314476, 52.690028473734856, 50.61987295746803, 50.076319724321365, 53.25649827718735, 53.929400369524956, 57.155685648322105, 56.56152293086052, 57.93873243033886, 48.125876784324646, 40.721578896045685, 40.22168152034283, 41.222156435251236, 43.60178254544735, 46.50827698409557, 48.21902118623257, 49.44759786128998, 48.69929641485214, 50.993066132068634, 50.77027268707752, 49.282591715455055, 44.03125450015068, 42.63267494738102, 39.99414972960949, 40.800926238298416, 39.67645637691021, 39.98169779777527, 42.489293441176414, 43.44729043543339, 42.118201553821564, 40.8452470600605, 38.97131681442261, 40.64677231013775, 41.352291852235794, 39.59263667464256, 40.054471492767334, 40.88010638952255, 42.303931787610054, 43.10125060379505, 40.96095085144043, 42.183649241924286, 41.03362575173378, 43.57911676168442, 41.33256331086159, 42.33502171933651, 42.25858502089977, 40.490923672914505, 42.71619066596031, 41.82603903114796, 45.22575840353966, 39.76094104349613, 40.68781390786171, 44.4481111317873, 44.22904908657074, 43.654257729649544, 44.77240853011608, 46.90754435956478, 54.609780460596085, 56.930654123425484, 55.12444764375687, 55.3082437813282, 50.828861743211746, 44.48435738682747, 42.87879154086113, 42.0388276129961, 43.29444743692875, 40.23853361606598, 40.16316466033459, 43.66378001868725, 41.983236595988274, 42.14083693921566, 41.89229987561703, 40.06239406764507, 43.07039625942707, 41.78649455308914, 43.561827689409256, 41.48036018013954, 45.46278588473797, 43.126310259103775, 41.46569676697254, 40.22932291030884, 40.80517441034317, 41.607953533530235, 40.553753301501274, 40.96368670463562, 41.132990419864655, 39.062606915831566, 41.702682450413704, 39.39776413142681, 40.19187591969967, 42.713131830096245, 40.168298184871674, 41.52756504714489, 43.576088324189186, 40.920361429452896, 40.63656605780125, 41.73461213707924, 43.232461363077164, 41.44786812365055, 42.087271213531494, 42.31208994984627, 42.125972136855125, 43.41686926782131, 46.216654032468796, 45.17816595733166, 46.784940138459206, 46.88890255987644, 43.984429612755775, 45.24589732289314, 46.44498758018017, 43.896954506635666, 54.85063053667545, 54.22477371990681, 57.16944471001625, 56.47696606814861, 63.914819955825806, 60.05260080099106, 64.57256466150284, 61.929175704717636, 68.51422995328903, 56.714054346084595, 72.3989287018776, 27.295191250741482, 0.241980352147948, 2.9032316012308, 2.92934522498399, 0.11292246679659002, 9.63360596448183, 80.89980214834213, 70.24294719099998, 74.0208488702774, 58.99474136531353, 44.82872150838375, 45.88237836956978, 67.49365791678429, 71.30337908864021, 69.84842956066132, 6.2632400169968605, 0.4671701177721843, 0.19105955172562972, 0.14280500588938594, 0.07989454257767648, 0.22149633412482217, 0.18486727931303903, 0.11093751862063073, 0.1479357251082547], [0.04061761988850776, 0.025971509894588962, 0.04539283181657083, 0.05110611098643858, 0.03717657054949086, 0.08059506319114007, 0.027985832275589928, 0.0259060135067557, 0.07655998400878161, 0.11575877710129134, 0.15544793684966862, 25.84701295942068, 59.51752111315727, 49.09374184906483, 39.01228241622448, 20.879854895174503, 24.956120364367962, 46.45422488451004, 53.95339988172054, 55.584238171577454, 41.144971176981926, 0.9490027581341565, 0.32674755435436964, 0.18188676971476525, 4.031313406303525, 32.75127857923508, 52.7361162006855, 48.61590228974819, 51.40630155801773, 50.21439291536808, 45.38512945175171, 51.04223929345608, 52.99227565526962, 48.22487287223339, 48.936411291360855, 52.12311029434204, 54.53572243452072, 49.1279362142086, 42.4585834890604, 37.575583308935165, 38.0909838527441, 36.49057053029537, 39.73693013191223, 43.63832138478756, 45.08888594806194, 48.47481206059456, 47.45784603059292, 46.973619014024734, 49.692905098199844, 48.04054856300354, 45.253170132637024, 39.07838746905327, 37.313834354281425, 33.63144055008888, 36.80158384144306, 34.989255890250206, 36.15502193570137, 35.7308354973793, 36.06753543019295, 35.51581263542175, 36.53866834938526, 34.00789774954319, 36.97871893644333, 35.60744471848011, 36.19938835501671, 36.660858392715454, 39.95224177837372, 37.774647027254105, 37.99747847020626, 37.502718418836594, 39.80938844382763, 38.29526089131832, 38.02732966840267, 39.457964301109314, 40.014015063643456, 38.71204912662506, 38.267944157123566, 37.823003232479095, 38.0055720359087, 37.85949267446995, 35.96866853535175, 36.61122165620327, 38.509197011590004, 38.436582908034325, 40.66112793982029, 38.45083214342594, 45.20807795226574, 51.3254114985466, 52.9581268876791, 54.22650262713432, 51.528449803590775, 45.55157572031021, 40.385885909199715, 38.98330897092819, 38.503451719880104, 38.312800750136375, 36.96992240846157, 37.159969210624695, 38.108975887298584, 38.66484425961971, 37.727176174521446, 38.23304682970047, 38.17470856010914, 39.38736788928509, 39.48618158698082, 38.569051399827, 39.85617533326149, 42.36299201846123, 38.90370324254036, 37.73261368274689, 38.05120378732681, 37.40177683532238, 36.224801391363144, 36.47585391998291, 38.1371133774519, 37.15691797435284, 36.062911078333855, 36.58162124454975, 35.98102927207947, 37.8882647305727, 36.25867657363415, 34.828855097293854, 35.40839619934559, 36.59580588340759, 35.78217074275017, 36.12504154443741, 37.344874888658524, 38.90612371265888, 37.98188790678978, 38.200858756899834, 36.482967138290405, 38.50462205708027, 37.10858456790447, 41.929119899868965, 40.40800452232361, 41.21977776288986, 40.58945618569851, 49.77020435035229, 49.49108652770519, 50.691134333610535, 46.18879772722721, 49.80059891939163, 50.592297837138176, 56.059262081980705, 51.08549237251282, 57.2417776286602, 55.8457325398922, 63.06944891810417, 56.79820463061333, 66.60537198185921, 53.823967427015305, 61.06229022145271, 19.18671514838934, 0.06508264792500995, 0.3311667765956372, 0.15482385002542287, 0.12167590568424203, 8.524918556213379, 64.81095626950264, 61.2001696228981, 62.32723854482174, 45.40594853460789, 22.121523767709732, 24.33247122913599, 48.63149285316467, 59.39220003783703, 41.39340564608574, 1.644867374561727, 0.12009587328066118, 0.06812448860728182, 0.021966868043818977, 0.020108346579945646, 0.007610266611663974, 0.05177322753297631, 0.04777086593094282, 0.04945503649651073, 0.04225768832839094, 0.03564541599189397, 0.034872736359830014, 0.011033203372790013, 0.03451882097579073, 0.07405361029668711, 0.06335562575259246, 0.012862495350418612, 0.0694068158918526, 0.06526224766275845, 0.18111505487468094, 31.165021397173405, 66.3341273367405, 53.01127463579178, 41.27959795296192, 23.902362808585167, 30.89850179851055, 50.54989971220493, 59.783423244953156, 58.52140076458454, 44.85301360487938, 0.8787921443581581, 0.17666301486315206, 0.04323077009757981, 4.614668553695083, 38.891376703977585, 52.055808305740356, 49.061223194003105, 52.330700755119324, 51.827303767204285, 47.60023958981037, 50.474329367280006, 51.760089173913, 47.130691185593605, 50.81346116960049, 54.07857656478882, 57.03646704554558, 52.989619597792625, 47.13132955133915, 39.85111400485039, 38.66230599582195, 38.322095051407814, 41.07348181307316, 44.27395887672901, 46.683709770441055, 50.01013107597828, 48.316432759165764, 49.36549186706543, 51.21684372425079, 49.08959627151489, 47.68647976219654, 43.287995383143425, 38.52704465389252, 35.39487652480602, 37.55266293883324, 38.81305530667305, 38.85368652641773, 37.21744492650032, 37.211711034178734, 36.53159312903881, 37.77435444295406, 36.69839657843113, 38.32849010825157, 36.769068986177444, 36.06845498085022, 38.85956861078739, 40.49070328474045, 38.69911462068558, 41.07192389667034, 39.93186727166176, 39.73539501428604, 40.030262991786, 39.07737672328949, 40.01787185668945, 40.52965119481087, 40.7795599848032, 39.967254772782326, 39.607121497392654, 40.77551320195198, 39.445975944399834, 37.40900784730911, 38.689235150814056, 40.05923643708229, 41.90467581152916, 43.22849817574024, 40.56248903274536, 46.77102528512478, 53.15290063619614, 54.6081617474556, 55.89352257549763, 53.63998509943485, 48.037911504507065, 41.40650734305382, 42.47270733118057, 40.99683992564678, 39.983529299497604, 39.368414506316185, 38.85243259370327, 41.06841288506985, 41.178869158029556, 39.90460753440857, 40.92349626123905, 40.402152836322784, 41.7314051091671, 39.42617900669575, 40.844794884324074, 41.0098922252655, 42.99755796790123, 40.82393780350685, 39.21102695167065, 40.32812900841236, 38.855115249753, 38.37534159421921, 38.846280723810196, 38.725413009524345, 39.942635893821716, 39.34879615902901, 38.724151477217674, 36.87204726040363, 39.06643331050873, 38.253417536616325, 39.07551862299442, 38.1651596724987, 38.64499032497406, 38.583038449287415, 39.12038281559944, 40.600240007042885, 40.494054704904556, 41.07586048543453, 40.73680467903614, 39.15299266576767, 40.29856279492378, 39.28945094347, 44.284355118870735, 41.83894693851471, 43.56030777096748, 42.6191970705986, 50.07567375898361, 53.00236411392689, 51.18291154503822, 47.46432088315487, 51.9609197974205, 53.86389568448067, 56.41377925872803, 53.95300470292568, 60.37549987435341, 58.02094481885433, 64.27501022815704, 58.513102009892464, 68.14209312200546, 56.44749104976654, 65.13390094041824, 21.340534575283527, 0.10423940577311441, 1.5846586553379893, 1.0155158140696585, 0.10250113264191896, 9.911279864609241, 70.68468108773232, 66.4613825082779, 69.4321770966053, 53.275292068719864, 28.049262687563896, 27.729838527739048, 56.47737264633179, 67.1880555152893, 52.05691784620285, 2.3892666678875685, 0.13930116343544796, 0.037568791885860264, 0.05388336117903236, 0.12453698145691305, 0.015221104677038966, 0.07716145759331994, 0.05024372054322157, 0.03334082110086456, 0.15719051443738863, 0.21376413496909663, 0.21619043836835772, 0.18459146755049005, 0.14516931027173996, 0.1426856982288882, 0.14838349248748273, 0.08819212467642501, 0.18481915845768526, 0.21742681186879054, 0.2766193973366171, 37.98029959201813, 76.13228917121887, 59.88753765821457, 50.09571388363838, 31.09767571091652, 36.46856211125851, 58.18851962685585, 65.00586301088333, 64.43557441234589, 49.553661569952965, 1.4672469743527472, 0.4379014758160338, 0.2118080563377589, 6.366474777460098, 41.88676357269287, 55.95226362347603, 50.49879625439644, 52.936316058039665, 52.48038612306118, 47.90829285979271, 51.56486324965954, 52.95439548790455, 50.58162800967693, 55.05741164088249, 58.920295760035515, 58.55278708040714, 56.071592420339584, 47.46741771697998, 41.821851655840874, 41.80525794625282, 40.72071634232998, 43.57280910015106, 45.98354794085026, 49.64939743280411, 51.43072284758091, 49.43340942263603, 50.737491846084595, 54.18852746486664, 53.680616319179535, 50.14334812760353, 44.50684078037739, 41.89949668943882, 38.73308099806309, 41.04235768318176, 40.47296583652496, 41.89440496265888, 39.16406527161598, 40.48609793186188, 37.24398650228977, 41.09556242823601, 38.113212659955025, 41.34488984942436, 39.1739447414875, 37.18606241047382, 40.77596537768841, 43.37889410555363, 41.73648543655872, 42.99371637403965, 41.38596564531326, 40.634164586663246, 41.61709204316139, 40.88720440864563, 41.096709966659546, 43.2167150080204, 43.63088518381119, 42.55947187542915, 42.08788298070431, 43.83580058813095, 42.25838743150234, 40.306770354509354, 40.73830559849739, 42.39741437137127, 43.369451612234116, 45.80198988318443, 41.67226888239384, 49.46704521775246, 56.08229264616966, 58.672541454434395, 56.72296106815338, 55.018216744065285, 48.554584980010986, 43.52263659238815, 44.945732429623604, 43.492660000920296, 41.94667115807533, 42.3616848886013, 41.293740794062614, 42.69350588321686, 42.08493813872337, 40.87230160832405, 43.557153940200806, 42.256992906332016, 43.54311749339104, 42.978619784116745, 43.374474942684174, 43.618072271347046, 45.69407947361469, 44.34780031442642, 41.237161830067635, 42.3101482540369, 42.070198729634285, 40.78891508281231, 40.49174442887306, 42.099886536598206, 40.92448800802231, 40.88890291750431, 39.61604721844196, 38.841169998049736, 41.50796189904213, 41.061387062072754, 39.67103786766529, 39.92537721991539, 42.36031696200371, 41.67410418391228, 40.9075903147459, 43.2236572355032, 42.85609155893326, 44.005978256464005, 44.604218155145645, 39.64740693569183, 42.54798889160156, 41.01462297141552, 45.934101194143295, 44.30783025920391, 45.338160172104836, 44.39988411962986, 54.44280982017517, 54.7975929826498, 54.32153932750225, 50.35546414554119, 55.00208280980587, 56.82172916829586, 59.840781167149544, 55.440811067819595, 62.92085789144039, 60.466136410832405, 68.33608031272888, 60.631765723228455, 70.6973572075367, 59.36532407999039, 66.44571214914322, 25.143497809767723, 0.32102990022394806, 2.1092770295217633, 1.8803150905296206, 0.19974137336248532, 11.099006831645966, 77.62014493346214, 69.64078590273857, 76.74205005168915, 59.819703698158264, 33.00266169011593, 37.37416751682758, 64.54581409692764, 73.3675043284893, 65.26614904403687, 4.068920938298106, 0.30508871655911207, 0.1539273653179407, 0.25630473741330206, 0.22282042948063463, 0.1337783527560532, 0.14566838974133134, 0.15286002337234095, 0.12457677541533485], [0.04612716467818245, 0.02023630582698388, 0.12383020453853533, 0.122452652285574, 0.024448784279229585, 0.11275272277998738, 0.07132925296900794, 0.055973338094190694, 0.016983637688099407, 0.20747116795973852, 0.06446627201512456, 15.803700629621744, 56.026333048939705, 52.471061423420906, 35.2558533847332, 20.350689589977264, 34.01093378663063, 44.99149717390537, 55.083816424012184, 52.65024460852146, 49.80819471180439, 2.234829654917121, 0.11008522138581611, 0.04683846498664934, 1.6698420094326138, 19.591005854308605, 51.78729571402073, 47.24046349525452, 52.23911426961422, 45.717569813132286, 50.445139333605766, 54.956819638609886, 53.52206602692604, 53.79816301167011, 54.3521922826767, 50.79837217926979, 47.35755801200867, 41.004431918263435, 36.318082585930824, 37.41034537553787, 37.11406007409096, 41.6803852468729, 44.36035484075546, 47.89060100913048, 47.48683087527752, 45.59108220040798, 49.991329684853554, 46.239513605833054, 49.822580739855766, 48.0442875623703, 45.46725444495678, 37.677980214357376, 37.18477427959442, 35.18437162041664, 37.5916488468647, 36.47088758647442, 35.52037239074707, 34.77191135287285, 36.70884981751442, 36.43232725560665, 35.50148740410805, 37.045507952570915, 36.97921670973301, 36.834790259599686, 38.087659031152725, 37.7708700299263, 38.244594410061836, 36.942248493433, 39.16556239128113, 37.86812961101532, 40.39905600249767, 38.19419011473656, 40.20684331655502, 39.36796613037586, 39.2707559466362, 37.25519970059395, 38.41004513204098, 38.57243701815605, 38.75519581139088, 36.26324012875557, 35.0603386759758, 35.21315887570381, 38.89321580529213, 39.02137152850628, 40.30549742281437, 39.19732868671417, 45.09775087237358, 52.211516350507736, 50.15296161174774, 50.211421474814415, 52.639665976166725, 47.46997497975826, 38.937004655599594, 40.67921496927738, 38.9076816290617, 37.21593260765076, 37.53321938216686, 36.976477056741714, 38.4787492454052, 37.41768658161163, 38.6085806787014, 37.612087950110435, 38.777876794338226, 38.999997675418854, 36.79431103169918, 38.39601248502731, 39.11132410168648, 39.29750271141529, 37.7719833701849, 37.285012900829315, 38.07355038821697, 38.03757391870022, 37.3447684943676, 37.985193729400635, 36.61007031798363, 37.1406814455986, 36.887725219130516, 38.50633196532726, 35.86774215102196, 35.2444501966238, 37.892144322395325, 37.26494997739792, 35.85931800305843, 38.55370782315731, 36.94212689995766, 37.227635979652405, 38.200482577085495, 39.793957471847534, 38.62042464315891, 39.31635729968548, 37.04156756401062, 38.5723952203989, 36.975998282432556, 38.71057480573654, 41.01566031575203, 40.75711838901043, 43.69844175875187, 55.97106121480465, 53.14505785703659, 54.52931597828865, 51.5390208363533, 55.37062123417854, 50.81496208906174, 55.03439247608185, 56.089858040213585, 61.623983681201935, 57.81924024224281, 60.14795668423176, 54.266472682356834, 59.3802572786808, 52.98756770789623, 63.55768471956253, 16.957074590027332, 0.19499796617310494, 2.253529876470566, 0.552676246734336, 0.1264983441797085, 9.491752926260233, 65.8335117995739, 60.196008905768394, 60.52776150405407, 50.194417387247086, 41.441594660282135, 35.98637938499451, 54.84549701213837, 54.42082419991493, 36.148740872740746, 1.2653216533362865, 0.08184729638742283, 0.03413777638343163, 0.026559281577647198, 0.07975606524269097, 0.04676190503232647, 0.09207948678522371, 0.07932936001452617, 0.07515615230659023, 0.026208718845737167, 0.035978599480586126, 0.021498335372598376, 0.10148460554773919, 0.05609969615761656, 0.07330195570830256, 0.052305573772173375, 0.021724386133428197, 0.017361659884045366, 0.09270205220673233, 0.04970013818820007, 19.973613023757935, 64.37424570322037, 58.007835522294044, 42.827627286314964, 22.723607160151005, 41.2276129424572, 51.61182872951031, 61.556890681385994, 56.23909883201122, 56.45852945744991, 2.3939772276207805, 0.14345065952511504, 0.15884538501268253, 2.051188596524298, 22.104426585137844, 55.05771182477474, 47.50298760831356, 51.91462688148022, 47.219306230545044, 50.908858850598335, 55.321907848119736, 56.829811334609985, 56.40660524368286, 56.00070722401142, 52.87065178155899, 50.698388144373894, 44.13719281554222, 39.54049587249756, 38.96911673247814, 38.75746048986912, 43.672789335250854, 46.65830433368683, 49.14811313152313, 51.355908662080765, 47.92837478220463, 50.673795863986015, 48.08196634054184, 51.74672149121761, 49.86982740461826, 48.164627104997635, 40.91009058058262, 38.17975468933582, 37.21739552915096, 38.60679857432842, 38.333270251750946, 39.19836223125458, 37.185454443097115, 36.857197657227516, 36.72516614198685, 37.061064317822456, 37.73122675716877, 38.640107586979866, 38.18501740694046, 39.768696427345276, 38.426635041832924, 39.632591530680656, 38.134092539548874, 40.7649801671505, 40.0454393774271, 39.8779633641243, 40.67046783864498, 41.07395678758621, 40.031718313694, 40.32907135784626, 38.282409980893135, 40.2486714720726, 40.72877191007137, 39.70773629844189, 38.44208121299744, 37.20998972654343, 39.099111557006836, 40.79086817800999, 41.07699282467365, 42.34900116920471, 41.88358314335346, 47.6605499535799, 53.01340252161026, 52.94014245271683, 53.95890198647976, 52.46501214802265, 49.48649637401104, 42.08271525800228, 43.482943922281265, 40.70131078362465, 39.26008231937885, 39.637436270713806, 38.2660898566246, 40.20096883177757, 38.63075248897076, 40.0197983533144, 39.37137454748154, 40.851338133215904, 39.29705813527107, 39.255393370985985, 39.883689656853676, 41.6551697999239, 40.54440200328827, 40.69977946579456, 40.0397776812315, 39.35340151190758, 38.95183525979519, 37.699091881513596, 39.722441509366035, 39.197013303637505, 38.83040517568588, 37.580838426947594, 39.123525246977806, 38.73093791306019, 37.40573242306709, 38.01442176103592, 38.69457766413689, 37.36799664795399, 39.70893703401089, 37.63034977018833, 39.6090441942215, 40.503573194146156, 41.29917450249195, 41.1020714789629, 41.89801096916199, 39.57769587635994, 40.72334960103035, 39.06463220715523, 41.8570339679718, 42.638614028692245, 44.537117555737495, 45.88036447763443, 58.075126111507416, 55.94646133482456, 57.02210761606693, 53.21972385048866, 56.970358192920685, 52.73853287100792, 56.60510279238224, 59.00726929306984, 61.448296308517456, 59.102055206894875, 62.44662053883076, 55.948315635323524, 62.97839440405369, 54.89437758922577, 63.84256303310394, 19.286450296640396, 0.06345234985928982, 3.0480985902249813, 0.7952241192106158, 0.14633001439506188, 10.197084378451109, 73.05777534842491, 63.748331889510155, 69.09537076950073, 50.73645830154419, 33.55725713074207, 36.69516675174236, 62.684263586997986, 60.15946626663208, 45.850680470466614, 1.6589257889427245, 0.14729997172253206, 0.11488586300401948, 0.08171884546754882, 0.11943218545638956, 0.06320210508420132, 0.007170755161496345, 0.03143226960673928, 0.0926621766120661, 0.10275625332724303, 0.1347132510272786, 0.23501115501858294, 0.28333841648418456, 0.1927754416828975, 0.22383737959899008, 0.17644939507590607, 0.19998404080979526, 0.13956245878944173, 0.33598019799683243, 0.08913572833989747, 23.9354058355093, 73.38106960058212, 65.32707497477531, 49.142120853066444, 27.845958396792412, 47.57661625742912, 56.56678184866905, 64.0774816274643, 60.87882086634636, 62.367615178227425, 2.9969314858317375, 0.2886914386181161, 0.2633562090341002, 2.443565991707146, 25.438886359333992, 56.99517086148262, 51.80709645152092, 52.61759676039219, 50.402194038033485, 51.1364134401083, 56.22270651161671, 58.16717617213726, 60.10680869221687, 60.080373510718346, 55.089348927140236, 50.972083657979965, 45.38479886949062, 40.59477970004082, 42.75013044476509, 40.08194401860237, 46.96145586669445, 48.16898927092552, 52.29220502078533, 51.80561073124409, 49.08829294145107, 50.617292895913124, 51.026663929224014, 54.82486791908741, 53.47700424492359, 50.062803849577904, 41.77117757499218, 41.217148303985596, 39.06412683427334, 41.79213345050812, 40.90414769947529, 41.83240748941898, 39.34858337044716, 39.76872302591801, 38.68505537509918, 38.81665751338005, 39.458230286836624, 39.46812115609646, 39.50270690023899, 42.50964514911175, 40.80609776079655, 41.48662604391575, 39.88599233329296, 43.65794353187084, 42.338935509324074, 41.40714190900326, 41.549649462103844, 42.74793416261673, 42.5182668864727, 43.75764258205891, 39.60709109902382, 41.46839842200279, 41.57567426562309, 41.7878282815218, 39.85066942870617, 40.679355561733246, 41.720381900668144, 43.81559707224369, 43.919396102428436, 45.55989347398281, 43.109100982546806, 50.94668962061405, 54.91359695792198, 54.47674199938774, 54.693201184272766, 56.56204730272293, 51.880546510219574, 44.43373650312424, 45.79302616417408, 44.16010178625584, 41.27107501029968, 43.76615792512894, 39.85016405582428, 42.98521243035793, 41.159702986478806, 42.02522054314613, 40.40537126362324, 42.55017377436161, 40.9162500500679, 41.40922039747238, 41.52908116579056, 43.26532579958439, 42.44040906429291, 41.34077467024326, 41.09669856727123, 42.18544274568558, 41.722844168543816, 40.33863164484501, 42.067352682352066, 41.43261954188347, 41.3309445977211, 40.10478079319, 41.46461762487888, 39.87387478351593, 39.786110892891884, 41.55150756239891, 41.35313920676708, 39.768042862415314, 43.27855668962002, 40.931920409202576, 41.8746118247509, 43.941811099648476, 44.83471378684044, 43.36934521794319, 44.362209141254425, 40.78843250870705, 43.70787665247917, 42.34749265015125, 43.592818826437, 45.07853530347347, 46.19794003665447, 48.577007576823235, 59.86722394824028, 57.666868418455124, 59.500011652708054, 55.16333095729351, 60.78554347157478, 53.64178240299225, 61.584507599473, 61.523714661598206, 63.393164947628975, 62.273467630147934, 64.69260782003403, 57.86440081894398, 64.57097634673119, 54.91950184106827, 63.284543976187706, 21.311105154454708, 0.38839509012177587, 4.873999413102865, 1.8503304244950414, 0.3353015484753996, 11.60195354372263, 79.18409541249275, 69.45118367671967, 73.3633853495121, 63.386184722185135, 55.007558315992355, 46.56693063676357, 71.86850756406784, 69.59565192461014, 56.051381304860115, 2.6703192992135882, 0.25055772392079234, 0.1741315788240172, 0.28466617804951966, 0.1556746184360236, 0.17514956794911996, 0.19979182456154376, 0.17137012153398246, 0.28785670059733093], [0.02384237541264156, 0.029254596811369993, 0.023949391252244823, 0.058346971272840165, 0.054313346699927934, 0.05382810086302925, 0.006749565018253634, 0.06336667633149773, 0.032578171594650485, 0.13919163728132844, 0.09207711191265844, 5.793980872258544, 47.017225474119186, 48.92876610159874, 31.467580161988735, 23.71486186981201, 24.291032552719116, 38.51148068904877, 58.8294730335474, 51.96986451745033, 53.28478775918484, 6.806790875270963, 0.3669769159751013, 0.03901708565535955, 0.26287247717846185, 11.880027372390032, 42.43841037154198, 51.30255572497845, 47.64157377183437, 51.88837788999081, 56.00897178053856, 54.066679403185844, 51.66088409721851, 49.622787460684776, 47.450812608003616, 43.441567942500114, 40.76545134186745, 37.42216274142265, 38.97913299500942, 40.158471912145615, 45.24789981544018, 46.71375095844269, 50.7183712720871, 51.13083153963089, 50.42608715593815, 45.21750524640083, 46.18091695010662, 49.716505631804466, 49.92279656231403, 47.96448044478893, 42.92690835893154, 36.656982600688934, 37.56473869085312, 36.82250551879406, 35.85291534662247, 37.503740563988686, 34.473912343382835, 35.728760808706284, 35.316980704665184, 35.53438223898411, 36.36114187538624, 36.1494742333889, 36.54170818626881, 36.27361737191677, 36.52487128973007, 35.95125027000904, 37.80238933861256, 36.50419279932976, 38.44563402235508, 37.550645247101784, 37.064552530646324, 38.29383596777916, 37.363801673054695, 38.0174919962883, 38.65861639380455, 38.61434876918793, 35.81148996949196, 37.56769873201847, 38.321483284235, 38.25654856860638, 35.025802329182625, 35.72322450578213, 39.130205288529396, 39.1302090883255, 41.261104345321655, 38.15423525869846, 44.45475697517395, 53.07988375425339, 50.78061193227768, 51.96875497698784, 51.18129663169384, 45.22761270403862, 39.9708341807127, 39.613638147711754, 37.80642472207546, 37.31797993183136, 38.09176281094551, 39.14074972271919, 39.57147181034088, 39.44202035665512, 38.00472468137741, 37.5550302118063, 38.71721684932709, 38.285180032253265, 38.03144484758377, 39.05580908060074, 38.84874299168587, 40.53033895790577, 38.422820046544075, 38.41688856482506, 37.80821442604065, 37.7727547287941, 37.508851289749146, 35.871940925717354, 35.884126871824265, 37.10814759135246, 35.881615206599236, 35.720940828323364, 37.29525335133076, 36.95508420467377, 35.359899401664734, 37.18490727245808, 36.118015721440315, 37.06920348107815, 38.07129330933094, 40.27127645909786, 39.371287152171135, 40.91992825269699, 39.89529803395271, 38.75036247074604, 37.086127772927284, 39.10369411110878, 38.35102289915085, 37.615302577614784, 38.39228108525276, 39.895978197455406, 42.4584124982357, 52.91499920189381, 53.137405067682266, 58.101048320531845, 53.481130823493004, 57.613496482372284, 55.06938099861145, 59.6298772841692, 51.783974692225456, 53.118383288383484, 48.81281532347202, 55.43452240526676, 51.47249020636082, 58.205827698111534, 50.57786241173744, 60.35769023001194, 21.288213282823563, 0.17384392238454893, 1.5139614301733673, 0.42572728532832116, 0.18688649986870587, 9.372629318386316, 66.18313863873482, 59.20533746480942, 62.60072506964207, 44.74915757775307, 31.570541337132454, 24.39019203186035, 43.7211911380291, 55.63671715557575, 29.42251469939947, 0.6859333743341267, 0.06851469501270913, 0.07461636603693478, 0.0028738066203004564, 0.13489080243743956, 0.05768147631897591, 0.026185773494944442, 0.0676604310865514, 0.04709587148681749, 0.04346806068497244, 0.038330966417561285, 0.05645433142490219, 0.027353346195013728, 0.02078133536997484, 0.02991291148646269, 0.03235169409890659, 0.09300561287091114, 0.04149334301473573, 0.10074601275846362, 0.11593601680942811, 8.471825905144215, 56.88882976770401, 55.529296919703484, 37.24570021033287, 25.589861758053303, 33.444330990314484, 44.457435831427574, 64.1649529337883, 56.049485206604004, 59.48535203933716, 6.959551703184843, 0.41236022603698075, 0.11908647822565399, 0.22200074221473187, 12.97822069376707, 45.4520096629858, 52.45046652853489, 49.51247178018093, 52.19166621565819, 57.09238864481449, 55.80467954277992, 54.53066110610962, 51.68639212846756, 49.48088027536869, 46.98160998523235, 42.56166435778141, 39.8212818056345, 39.98031847178936, 41.28023251891136, 47.372175827622414, 47.10008762776852, 50.11207580566406, 51.45641326904297, 51.733175218105316, 46.6968684643507, 48.71038801968098, 52.93579928576946, 50.66854074597359, 51.133031621575356, 45.59965454041958, 39.5022889226675, 38.43529477715492, 37.944813296198845, 37.9885945469141, 38.08027982711792, 37.90888622403145, 36.653862968087196, 36.83140084147453, 37.09613263607025, 38.150652050971985, 38.02887238562107, 37.8320087492466, 37.571236342191696, 37.729927226901054, 38.14388081431389, 38.59341189265251, 39.17708337306976, 40.32889276742935, 38.77088516950607, 37.82929189503193, 40.51229752600193, 37.595125660300255, 39.1729985922575, 42.36675001680851, 41.45186930894852, 38.6349892616272, 41.071996092796326, 38.69891323149204, 38.12816485762596, 37.382777854800224, 37.75779873132706, 40.74687033891678, 42.202788814902306, 43.85422959923744, 41.991383358836174, 46.05056494474411, 55.43830320239067, 53.270112946629524, 52.912677526474, 54.467227309942245, 49.61133487522602, 41.66704796254635, 42.26386293768883, 39.937103390693665, 40.028043910861015, 38.61589528620243, 39.897118136286736, 40.74699953198433, 41.24215096235275, 40.19889034330845, 41.15018829703331, 40.90551182627678, 40.454453229904175, 39.716540426015854, 42.1234642714262, 40.17916940152645, 41.78265295922756, 40.972308441996574, 39.42642219364643, 38.16596142947674, 38.74042980372906, 39.65830095112324, 37.812078818678856, 36.68097451329231, 38.74049060046673, 38.41290257871151, 37.75819391012192, 38.818135634064674, 38.41027311980724, 37.28790074586868, 39.6641830354929, 37.61705808341503, 39.09885697066784, 40.38435839116573, 42.82493703067303, 41.67475014925003, 43.650571927428246, 42.65978269279003, 40.88614046573639, 39.70373511314392, 41.71066962182522, 40.74961759150028, 39.913221672177315, 41.08217194676399, 42.516169399023056, 45.35114027559757, 56.2032363563776, 55.44538602232933, 59.47622112929821, 56.60041384398937, 58.68698067963123, 57.333664298057556, 62.65753202140331, 55.47522962093353, 57.282633036375046, 52.11104214191437, 57.34252542257309, 52.69894279539585, 61.13787196576595, 51.124645471572876, 60.876047015190125, 20.440360978245735, 0.23286741692572832, 2.9400753742083907, 1.4046618388965726, 0.14216175681212917, 10.679733529686928, 73.03344145417213, 65.52219450473785, 67.13969931006432, 53.07504661381245, 37.94429272413254, 32.48283438384533, 51.888529881834984, 64.00835573673248, 38.1774216145277, 1.620784504339099, 0.10104877190315165, 0.07991438760655001, 0.04161244287388399, 0.0615083311276976, 0.08115945165627636, 0.04788410653418396, 0.03918727124982979, 0.03601286072807852, 0.27331859164405614, 0.09306304767960683, 0.1294343694462441, 0.1447480672504753, 0.1213644040399231, 0.12845069722970948, 0.10287740151397884, 0.32515353988856077, 0.09687749377917498, 0.2440667073824443, 0.17482749070040882, 11.289210375398397, 68.53059187531471, 61.34282536804676, 46.642504781484604, 33.393858298659325, 36.39733113348484, 49.28250432014465, 69.75789561867714, 60.74746571481228, 65.19602760672569, 9.14510227739811, 0.5561633908655494, 0.23340269835898653, 0.6900373916141689, 15.34638661891222, 47.820582166314125, 55.22246338427067, 51.211349219083786, 54.21194180846214, 59.488813653588295, 57.839333564043045, 56.747085973620415, 53.54378566145897, 51.028499230742455, 48.98471049964428, 46.56235188245773, 42.992306649684906, 43.437452763319016, 45.25351591408253, 50.76322786509991, 51.692897379398346, 51.81819185614586, 55.43728865683079, 53.13531517982483, 50.078918784856796, 50.7585921138525, 55.60702174901962, 54.79662783443928, 52.278419360518456, 49.12118397653103, 42.142470851540565, 41.985991448163986, 39.62478294968605, 39.984532445669174, 41.302058547735214, 40.151962861418724, 39.906214848160744, 38.92776735126972, 39.369512647390366, 40.80328211188316, 39.75675746798515, 41.14275209605694, 39.790716245770454, 40.29098600149155, 39.27601866424084, 41.82510048151016, 43.1013759970665, 42.125801146030426, 39.441233798861504, 39.476161524653435, 43.05434212088585, 40.245244055986404, 41.308206617832184, 42.65036679804325, 42.906218469142914, 39.39750574529171, 43.0320905148983, 42.658456563949585, 40.773586705327034, 38.40333849191666, 40.082795172929764, 44.22164708375931, 44.68339450657368, 46.759701892733574, 43.915254324674606, 49.92906242609024, 58.481039330363274, 53.797007873654366, 56.10674433410168, 57.15526767075062, 49.64562803506851, 44.20943073928356, 44.583072289824486, 41.286391988396645, 41.40088364481926, 41.50958061218262, 42.98174701631069, 43.308833464980125, 43.18896509706974, 42.791080847382545, 42.85598136484623, 43.17501604557037, 42.19670534133911, 41.0929861664772, 44.061949253082275, 42.33563348650932, 44.90451984107494, 41.789986565709114, 42.52475693821907, 41.525820940732956, 40.75193926692009, 40.21166905760765, 39.69047002494335, 38.53735730051994, 41.87506780028343, 39.795758575201035, 39.0777301043272, 41.862414479255676, 40.837506875395775, 38.69239658117294, 41.74368605017662, 40.54190173745155, 41.27031125128269, 42.26256720721722, 46.3447717577219, 43.32313969731331, 46.27690739929676, 45.06056226789951, 44.57755118608475, 41.592723950743675, 45.25618717074394, 43.77579040825367, 43.068435564637184, 42.660968229174614, 44.22947086393833, 47.50511169433594, 57.86366745829582, 57.67613232135773, 62.225935980677605, 58.25127325952053, 62.72752806544304, 58.6960393935442, 63.72636526823044, 56.88146196305752, 58.516001254320145, 55.19561402499676, 60.512870103120804, 53.53753499686718, 62.94654071331024, 53.198406994342804, 64.18530464172363, 22.828886210918427, 0.32958407246042043, 5.742947235703468, 4.408734804019332, 0.2079148089978844, 11.312499325722456, 79.96789455413818, 68.1895449757576, 73.73540818691254, 59.50752004981041, 45.37155278027058, 36.90435312688351, 61.17284148931503, 72.62184754014015, 48.52354824542999, 2.4072097800672054, 0.32141391711775213, 0.14025828160811216, 0.10159537850995548, 0.31916378473397344, 0.22669899713946506, 0.2178596769226715, 0.18771651783026755, 0.12980827828869224], [0.004978153137926711, 0.054816845658933744, 0.02024545094172936, 0.03227925677492749, 0.08942141808802262, 0.07975654021720402, 0.07823461797670461, 0.012470971632865258, 0.036550973454723135, 0.02348298112337943, 0.04227105811878573, 4.114935994148254, 50.17751969397068, 48.84795963764191, 42.80548967421055, 29.16326031088829, 24.78790909051895, 39.14655961096287, 54.7578889131546, 50.92647850513458, 55.56621953845024, 12.00998704880476, 0.46627867966890335, 0.4322690499247983, 0.21890681760851294, 6.2445564195513725, 39.78855796158314, 50.01087203621864, 49.376678466796875, 56.232806369662285, 52.24465437233448, 52.39648662507534, 48.83538231253624, 44.714039862155914, 39.625128731131554, 37.790100798010826, 37.266336902976036, 42.603815495967865, 45.441609621047974, 48.949668779969215, 51.41726776957512, 51.83082617819309, 51.40819385647774, 48.06876964867115, 48.64678703248501, 48.21618653833866, 44.348548874258995, 48.821547254920006, 49.411252811551094, 46.14299118518829, 36.951326206326485, 36.35260373353958, 35.21605812013149, 36.44319087266922, 37.04406023025513, 36.70818105340004, 37.32708044350147, 34.33203935623169, 36.687270775437355, 36.32060185074806, 36.57266892492771, 36.39859266579151, 37.14531719684601, 35.09081304073334, 35.727115496993065, 35.70405453443527, 37.508387714624405, 36.678747832775116, 38.53546500205994, 37.53674939274788, 39.15862396359444, 39.58116888999939, 41.14844799041748, 38.69180381298065, 38.635768219828606, 38.35600443184376, 39.11590285599232, 37.54700504243374, 38.06807108223438, 38.545359671115875, 37.251578494906425, 34.396597892045975, 37.55468063056469, 40.24148225784302, 40.997159108519554, 39.622522071003914, 44.06698778271675, 50.28291463851929, 51.460140869021416, 52.85121962428093, 50.41464976966381, 48.19476708769798, 41.42172932624817, 41.694828271865845, 37.93246775865555, 38.05837020277977, 36.52494728565216, 37.31777474284172, 39.0659811347723, 40.4146883636713, 37.00864993035793, 38.19138206541538, 38.74420680105686, 39.03346627950668, 39.08349059522152, 40.04926577210426, 38.9323765039444, 37.69851431250572, 36.476157903671265, 39.720750600099564, 36.63867138326168, 37.68756330013275, 37.40603260695934, 37.07603171467781, 35.5588985234499, 36.77506126463413, 36.651495695114136, 37.453754246234894, 35.17675682902336, 36.42416529357433, 35.66491663455963, 37.1044085919857, 35.28040386736393, 36.411226987838745, 36.01326294243336, 39.882462322711945, 40.61494141817093, 42.51925863325596, 40.43038912117481, 40.127609968185425, 37.291221767663956, 39.07106526196003, 36.35934077203274, 39.84790317714214, 37.729129269719124, 40.52748151123524, 40.023943930864334, 48.591868579387665, 53.006391897797585, 54.9309316277504, 54.43371690809727, 58.17620448768139, 52.63976477086544, 50.170243084430695, 49.39452990889549, 56.193334087729454, 57.84648098051548, 59.983961284160614, 59.36606124043465, 63.37362639605999, 53.62448953092098, 55.63243858516216, 15.807382632046938, 0.39837852003984153, 2.2499644802883267, 0.24482150125550106, 0.16201405873289332, 11.0014508664608, 64.88592624664307, 62.16557241976261, 60.510582625865936, 51.26018799841404, 38.254496678709984, 25.320936888456345, 43.813689574599266, 52.383001148700714, 23.91759619116783, 0.5774692632257938, 0.08348552801180631, 0.09997114379075356, 0.074678995879367, 0.052662973539554514, 0.01637846635276219, 0.0736811337992549, 0.039071199353202246, 0.039174858829937875, 0.03871493136102799, 0.031955509693943895, 0.04463214529096149, 0.030544206420017872, 0.04510617356572766, 0.09061673597898334, 0.01237421041878406, 0.007141859641706105, 0.08812588799628429, 0.08392187373829074, 0.07240674007334746, 4.74661267362535, 59.680247381329536, 54.34928543865681, 45.29311738908291, 30.102630704641342, 29.439222402870655, 46.1047500371933, 63.65122050046921, 53.62077713012695, 61.45950570702553, 13.470508977770805, 0.4568737687077373, 0.4416797496378422, 0.3517892200034112, 7.593529159203172, 40.74197240173817, 51.91137805581093, 50.79953871667385, 58.00533525645733, 54.405313432216644, 54.62527222931385, 51.47174544632435, 46.845197305083275, 41.98974184691906, 39.797628074884415, 38.986003026366234, 43.62354777753353, 46.949976682662964, 50.51936835050583, 51.03108309209347, 52.301142141222954, 52.674411311745644, 51.31395511329174, 49.1022913902998, 49.6968986839056, 47.08224378526211, 52.98718772828579, 52.19360411167145, 48.814464434981346, 39.49999384582043, 39.15494576096535, 37.571844309568405, 38.279913514852524, 38.696367368102074, 37.61813722550869, 38.83717641234398, 37.45725005865097, 38.35196524858475, 38.45319181680679, 39.07019890844822, 38.096303567290306, 38.49523276090622, 36.82657890021801, 38.1988562643528, 38.057944625616074, 38.28256957232952, 38.39257746934891, 39.140924513339996, 39.042042419314384, 40.32766543328762, 41.66734054684639, 42.40328885614872, 40.05738973617554, 39.34231370687485, 39.3648236989975, 40.175502598285675, 39.48743171989918, 39.257760643959045, 41.29723660647869, 38.738678097724915, 36.1162032186985, 40.09686581790447, 41.853066980838776, 43.01718391478062, 40.53250104188919, 46.05966165661812, 52.6393885910511, 54.88170146942139, 54.03311960399151, 52.095390781760216, 48.63316856324673, 43.56511451303959, 44.12163645029068, 40.14338292181492, 40.11241838335991, 38.62756446003914, 39.19778846204281, 39.29347112774849, 40.27404651045799, 39.94186073541641, 39.994119331240654, 39.27710920572281, 42.192738354206085, 40.84167145192623, 41.77332445979118, 40.02618961036205, 40.55576719343662, 37.43284396827221, 41.46311290562153, 38.8575205206871, 39.39488388597965, 39.63654711842537, 38.28568920493126, 37.49191179871559, 38.54730896651745, 39.936788007617, 40.229535698890686, 38.42207528650761, 38.42182829976082, 37.960472255945206, 39.739814177155495, 38.16092289984226, 39.65915210545063, 39.034830406308174, 42.37765163183212, 43.35382305085659, 44.176186323165894, 43.155165910720825, 42.202796414494514, 40.44224068522453, 39.71633903682232, 38.52110557258129, 40.09281523525715, 39.723771438002586, 42.48666778206825, 41.43908679485321, 50.41015461087227, 54.47021394968033, 57.04476200044155, 54.67499256134033, 59.65769559144974, 53.96486006677151, 53.94816376268864, 52.09317930042744, 57.46449887752533, 58.99122655391693, 60.74539102613926, 60.83791986107826, 64.65669974684715, 55.49410700798035, 56.72597050666809, 17.09966193884611, 0.33305512683000416, 2.305789184756577, 1.3847120781429112, 0.20691078709205613, 11.475429832935333, 71.45222470164299, 68.0746391415596, 68.47120866179466, 53.43270242214203, 36.855677738785744, 26.692218706011772, 50.03615587949753, 60.50219267606735, 32.466597855091095, 0.7374709588475525, 0.0804378763132263, 0.03907469486875925, 0.014743490901309997, 0.031829804720473476, 0.013787793013761984, 0.1756872984697111, 0.06378670965204947, 0.026214548415737227, 0.11687764636008069, 0.1419119053753093, 0.0948626444733236, 0.11922895573661663, 0.19205771066481248, 0.15609097812557593, 0.12692561344010755, 0.08874107646988705, 0.14988847891800106, 0.1949848746880889, 0.13151097286026925, 6.233326122164726, 69.51525583863258, 60.32140597701073, 57.21418350934982, 40.3425682336092, 36.73989035189152, 52.35418349504471, 67.85280704498291, 59.097674041986465, 66.28257930278778, 15.952152013778687, 0.6245692202355713, 1.0438513685949147, 0.6603471504058689, 7.9226708225905895, 44.428382590413094, 53.80294695496559, 51.58647648990154, 60.64296372234821, 56.86621718108654, 58.81889820098877, 53.7858896702528, 48.251194059848785, 44.18689414858818, 41.11065901815891, 41.94740071892738, 46.68072313070297, 50.55581979453564, 54.179932326078415, 56.129740700125694, 53.821060582995415, 56.51033967733383, 53.271503672003746, 51.2057863175869, 51.68596275150776, 49.253394082188606, 54.511422738432884, 52.79586799442768, 51.8707088381052, 43.24802912771702, 40.09612865746021, 38.042699843645096, 41.47290877997875, 40.86343668401241, 40.126340836286545, 41.632675006985664, 40.015618577599525, 42.14576527476311, 40.90002492070198, 39.65660624206066, 40.14802627265453, 41.407464891672134, 39.2058402299881, 39.00628253817558, 40.05553163588047, 40.40916346013546, 40.262369737029076, 42.43977069854736, 41.3245115429163, 42.43204191327095, 43.527226746082306, 45.31490921974182, 42.5704874843359, 41.26310683786869, 42.579709589481354, 40.56477651000023, 40.83074703812599, 42.7542570233345, 43.52707855403423, 41.388883888721466, 38.29230085015297, 43.85327585041523, 45.52143573760986, 46.16181157529354, 42.68161632120609, 47.88867451250553, 54.595177844166756, 54.10329803824425, 56.05767376720905, 54.12702776491642, 51.07745200395584, 46.05648122727871, 47.32541933655739, 42.03006908297539, 41.547574773430824, 42.61629782617092, 41.225929632782936, 42.12137058377266, 42.84770920872688, 40.934166088700294, 41.93950094282627, 41.95981465280056, 43.59441474080086, 42.83585384488106, 44.344243705272675, 41.95194147527218, 42.41835504770279, 38.396863639354706, 43.48187617957592, 41.0616834461689, 40.92878557741642, 42.039629369974136, 40.71757011115551, 38.58129434287548, 39.712957218289375, 39.86824348568916, 42.1139457821846, 39.50629010796547, 39.7916965931654, 39.455042257905006, 42.69368827342987, 41.52720406651497, 42.74410776793957, 39.36606243252754, 44.76441755890846, 46.066125109791756, 48.237697184085846, 45.34099481999874, 44.72521126270294, 42.114059776067734, 42.56522476673126, 41.09277717769146, 44.330849424004555, 41.74313127994537, 44.43357311189175, 43.05139347910881, 51.54551848769188, 58.70567947626114, 60.35721145570278, 56.682926416397095, 60.13677008450031, 55.278286188840866, 57.944139540195465, 54.474051743745804, 57.8957225382328, 59.62883993983269, 62.078648284077644, 61.02820225059986, 67.31329679489136, 58.567237704992294, 59.98834244906902, 20.00966738909483, 0.8525289630051702, 5.11556432582438, 3.6532279942184687, 0.3325504367239773, 13.099712524563074, 76.15527033805847, 73.86207818984985, 75.99483534693718, 65.14684304594994, 50.71124665439129, 38.82448509335518, 60.55544301867485, 68.36504235863686, 43.703848868608475, 1.481579092796892, 0.19335044285980985, 0.1493211367051117, 0.10539015027461573, 0.09444773197174072, 0.1267989882035181, 0.18214168259873986, 0.16059048590250313, 0.19320029154187068], [0.023305297982005868, 0.016891507475520484, 0.03305394762719516, 0.03955959931772668, 0.02188263984862715, 0.018735284320428036, 0.017624190913920756, 0.020884304649371188, 0.05040823984018061, 0.031025593088997994, 0.0620885421813, 2.137395995669067, 43.5929062217474, 52.41468384861946, 39.68559488654137, 30.659293234348297, 27.41959847509861, 33.876280412077904, 58.68955694139004, 51.39844737946987, 58.020450845360756, 19.548387341201305, 0.20864773920038715, 0.1502032089047134, 0.13256376871140674, 2.847688556648791, 26.060424707829952, 49.94912914931774, 52.116559445858, 54.78327915072441, 51.02654613554478, 50.489095374941826, 45.31046345829964, 38.997151628136635, 35.570001527667046, 41.315316036343575, 44.80341486632824, 52.72498279809952, 52.062169164419174, 50.233065113425255, 51.025326400995255, 49.96337078511715, 49.27553549408913, 49.93039235472679, 47.76757501065731, 49.086947813630104, 44.85408894717693, 47.008390948176384, 47.286760210990906, 41.40346370637417, 36.10971696674824, 37.56267540156841, 35.928546488285065, 37.16902032494545, 37.746931314468384, 37.74526700377464, 37.54303425550461, 38.44412550330162, 37.51373402774334, 35.389682203531265, 34.45186212658882, 36.273765563964844, 37.63197608292103, 36.44836239516735, 36.14588342607021, 34.90828603506088, 37.71688252687454, 36.081473082304, 36.848621517419815, 38.81313890218735, 38.69196720421314, 38.93853597342968, 40.969872772693634, 38.33610109984875, 39.331199303269386, 39.891270250082016, 37.57843695580959, 37.6828857511282, 38.04949767887592, 38.568709418177605, 37.639039903879166, 34.38794955611229, 37.132648676633835, 40.55396229028702, 40.83630993962288, 41.40301153063774, 43.40609684586525, 49.28418383002281, 52.48206943273544, 52.728676199913025, 51.57380796968937, 48.503397926688194, 40.137728825211525, 40.493496134877205, 39.92054767906666, 36.474751979112625, 36.941731721162796, 39.00410145521164, 38.6046326905489, 38.66053529083729, 38.87387864291668, 37.988571748137474, 38.29408295452595, 38.18493761122227, 37.675175964832306, 39.37123015522957, 39.41546358168125, 39.30477552115917, 39.20634940266609, 38.17718982696533, 37.82318562269211, 39.40510153770447, 36.829242557287216, 36.77730694413185, 35.02601891756058, 37.27077506482601, 36.29565238952637, 37.35804118216038, 35.80938868224621, 38.094981238245964, 35.75780265033245, 36.28379322588444, 35.577658116817474, 37.85090893507004, 38.33247609436512, 40.92172175645828, 42.43275627493858, 42.272271886467934, 40.75963765382767, 40.95127657055855, 39.57169219851494, 38.48652742803097, 38.121051639318466, 40.12331999838352, 38.52872036397457, 39.67763431370258, 37.59914964437485, 46.79689049720764, 49.978493973612785, 55.67592725157738, 54.78942722082138, 48.96520994603634, 46.21286183595657, 55.11180192232132, 54.436236172914505, 61.87855862081051, 57.13911093771458, 62.08604268729687, 54.250969514250755, 60.78755356371403, 58.21683190762997, 66.94401741027832, 23.367176726460457, 0.49267274618614465, 1.6050985897891223, 0.711962393252179, 0.16878376656677574, 12.120252382010221, 64.96688470244408, 61.89841255545616, 55.57955302298069, 56.992499604821205, 46.22521497309208, 35.706045627593994, 45.28217397630215, 56.57533138990402, 26.341520324349403, 0.5542048334609717, 0.09675871304352768, 0.07819697624654509, 0.04234748819726519, 0.11480212648166344, 0.03378449924639426, 0.0491090546711348, 0.10223098346614279, 0.02277554554893868, 0.08864805568009615, 0.019034032156923786, 0.03841058773105033, 0.07537697834777646, 0.02855804854334565, 0.028712600797007326, 0.07650618572370149, 0.024030253807723057, 0.05084799944597762, 0.04004744267149363, 0.04339257313404232, 2.8462695702910423, 52.03953377902508, 57.72864170372486, 47.44768537580967, 34.407978281378746, 30.869887433946133, 39.99105669558048, 64.31652680039406, 56.32450684905052, 62.91763186454773, 21.51527389883995, 0.24375401088036597, 0.16799389879452065, 0.18710736301727593, 4.286642130464315, 30.804565139114857, 51.66013553738594, 53.02648141980171, 56.827273070812225, 54.52600635588169, 52.51720234751701, 46.69590711593628, 39.751631543040276, 37.27562740445137, 43.74600000679493, 46.07609197497368, 52.902710661292076, 53.51640433073044, 50.635797902941704, 51.53851166367531, 51.114724203944206, 50.64181677997112, 51.401597410440445, 49.118041545152664, 50.39275914430618, 46.69637069106102, 49.09498058259487, 49.44449722766876, 42.23561145365238, 38.07404436171055, 39.610833898186684, 38.0171500146389, 38.43572415411472, 38.40936116874218, 40.197944194078445, 39.32359591126442, 40.34826032817364, 37.633663192391396, 36.327388286590576, 36.89078785479069, 36.476963460445404, 39.397912323474884, 38.52369323372841, 37.220492362976074, 36.286114901304245, 39.49693500995636, 38.44969980418682, 37.40158684551716, 40.74056647717953, 40.26475600898266, 40.699429884552956, 41.48249186575413, 41.19872689247131, 39.91447560489178, 41.633560359478, 39.638686403632164, 40.221054553985596, 39.37406860291958, 40.38833297789097, 39.63342368602753, 36.86501003801823, 39.640609100461006, 44.28098849952221, 42.931498512625694, 44.144819006323814, 45.58482773602009, 51.86095096170902, 53.402060866355896, 55.47010749578476, 52.82408528029919, 50.34580126404762, 43.820335417985916, 43.4199471026659, 42.75513477623463, 38.56881961226463, 38.165015280246735, 39.406085684895515, 40.56859150528908, 40.51946774125099, 41.25373654067516, 39.54774588346481, 40.1972222328186, 38.8087273389101, 39.16228696703911, 42.256863713264465, 39.2944248765707, 39.966130033135414, 40.181874856352806, 40.21472789347172, 39.843609407544136, 40.12993164360523, 37.859986647963524, 38.3536409586668, 37.12779253721237, 38.85779410600662, 37.975648641586304, 38.57070431113243, 36.71357676386833, 39.14585664868355, 38.09074066579342, 38.295435681939125, 37.427189871668816, 39.218143969774246, 41.57889649271965, 44.20070640742779, 43.45892161130905, 44.80931214988232, 42.44255594909191, 42.79750630259514, 40.72039715945721, 40.337658897042274, 39.60540398955345, 43.13341207802296, 40.87166704237461, 42.172842621803284, 39.47413623332977, 49.32031989097595, 51.28478027880192, 57.987419217824936, 56.61926083266735, 50.36116763949394, 49.33544307947159, 55.79629719257355, 55.10215424001217, 61.72648698091507, 58.27613912522793, 64.60784196853638, 56.21366299688816, 63.804739862680435, 59.31745044887066, 69.16999876499176, 25.806602127850056, 0.6352522876113653, 2.464664359577, 0.8234459173399955, 0.2023080614162609, 12.441205009818077, 70.61362490057945, 66.87495231628418, 60.20012408494949, 64.86584052443504, 56.20724134147167, 40.50368718802929, 52.777530178427696, 63.05915147066116, 32.247030436992645, 0.5973926628939807, 0.12315472398768179, 0.05010675718949642, 0.012841960124205798, 0.0627480962430127, 0.03210288909031078, 0.017204660398419946, 0.07996602624189109, 0.08335658727446571, 0.1557274890365079, 0.09609051296138205, 0.16263867990346625, 0.24167598254280165, 0.0769844999013003, 0.1627537127933465, 0.13999020302435383, 0.12433251977199689, 0.14554716733982787, 0.26169219519943, 0.10844146818271838, 3.577199773862958, 57.839341163635254, 65.71395501494408, 53.06981049478054, 41.88674457371235, 38.409467563033104, 46.81572988629341, 70.84877908229828, 62.32140585780144, 67.9401795566082, 25.07716476917267, 0.39023445860948414, 0.4040143598103896, 0.297432453953661, 4.159705191850662, 32.936252653598785, 53.41840758919716, 55.0275794416666, 59.52948287129402, 56.61177143454552, 55.81259071826935, 48.813210502266884, 43.008383587002754, 40.02765253186226, 45.83769656717777, 48.86056736111641, 55.908474773168564, 56.76031306385994, 54.17132578790188, 54.472303837537766, 53.26969116926193, 53.592533245682716, 53.97356539964676, 50.795313343405724, 52.99932807683945, 50.38637548685074, 52.3574361205101, 50.906784161925316, 45.65900355577469, 39.78917732834816, 43.15822474658489, 39.12807360291481, 40.18860049545765, 41.81525520980358, 42.19494603574276, 41.65711149573326, 41.98999643325806, 40.917591378092766, 37.33273074030876, 37.67343185842037, 38.83055716753006, 41.048224568367004, 41.42617888748646, 39.11669321358204, 39.26238499581814, 42.12647370994091, 39.56071458756924, 40.755750462412834, 43.408897295594215, 42.83016934990883, 44.43383149802685, 45.049972236156464, 43.457724675536156, 42.446906715631485, 45.860164761543274, 41.64172612130642, 41.16054654121399, 41.73385597765446, 42.42036134004593, 43.43256242573261, 39.25016105175018, 42.47799664735794, 47.16283746063709, 46.471293568611145, 46.071972995996475, 47.19917491078377, 54.08858522772789, 55.107363760471344, 55.97002387046814, 54.947377145290375, 53.75841334462166, 46.51794746518135, 44.94199723005295, 44.39654789865017, 40.99800646305084, 42.16469965875149, 43.659695237874985, 42.594733983278275, 42.413548305630684, 42.71138772368431, 40.67277431488037, 41.92085914313793, 40.69555029273033, 41.565129831433296, 44.0681429207325, 41.917355731129646, 41.787303909659386, 42.62688785791397, 41.99091598391533, 41.39687106013298, 43.86185199022293, 40.733259469270706, 40.67953035235405, 38.911416828632355, 41.20817318558693, 40.71518763899803, 42.20243163406849, 37.94598363339901, 41.8570339679718, 39.96512308716774, 41.70159570872784, 39.57137681543827, 41.58086858689785, 44.119728952646255, 46.41366206109524, 48.39074157178402, 47.70333185791969, 45.28254255652428, 46.28535434603691, 44.49911579489708, 42.4918507039547, 42.08365760743618, 46.53663486242294, 41.901225596666336, 43.93695496022701, 40.99181279540062, 51.73901930451393, 52.112763449549675, 61.71387165784836, 58.15365269780159, 53.225085362792015, 51.48196689784527, 56.26047648489475, 54.70734402537346, 61.30487680435181, 60.90156264603138, 67.77020707726479, 58.1801600754261, 65.95475569367409, 61.737270802259445, 71.82661101222038, 28.6918044090271, 1.0914782504551113, 4.819745924323797, 4.396588280797005, 0.2676075277850032, 14.170364923775196, 77.61188417673111, 70.86948797106743, 67.80233815312386, 72.46652707457542, 58.47867585718632, 47.750711515545845, 60.8015102148056, 73.66366043686867, 40.2299764752388, 0.7566083944402635, 0.2671697793994099, 0.15525447379332036, 0.16972314740996808, 0.20493425487075, 0.1960534485988319, 0.07727496908046305, 0.15212848840747029, 0.12867804674897343], [0.04036533420730848, 0.08420173762715422, 0.10294860316207632, 0.03456793630903121, 0.05085513890662696, 0.07107992845703848, 0.04223688221827615, 0.047047728367033415, 0.034287931412109174, 0.03653505067632068, 0.0989186522201635, 0.5989108595531434, 30.58383498340845, 54.738631546497345, 47.05091826617718, 32.840133011341095, 23.617594689130783, 35.210426822304726, 52.005461007356644, 52.00048327445984, 56.562256291508675, 28.217954635620117, 0.23569488083012402, 0.290188587969169, 0.47126374498475343, 1.4002614375203848, 15.878760851919651, 49.35482203960419, 52.64424093067646, 55.201948285102844, 47.69220605492592, 46.94205030798912, 40.520858466625214, 39.65099774301052, 43.98340366780758, 51.37326993048191, 52.11101934313774, 51.67490154504776, 49.30499151349068, 53.03482577204704, 51.126788556575775, 50.684317499399185, 47.154272720217705, 45.32157406210899, 47.072748094797134, 46.8988998234272, 44.51140433549881, 46.84594206511974, 42.674389109015465, 36.838039085268974, 35.44398508965969, 38.79947103559971, 36.86726711690426, 37.76837736368179, 36.55204363167286, 36.32327690720558, 36.579592153429985, 35.34545637667179, 37.095182687044144, 37.230181843042374, 37.22524590790272, 35.981842428445816, 37.253979966044426, 34.98906970024109, 35.15695609152317, 37.43610419332981, 36.776478588581085, 37.02521704137325, 37.65790969133377, 38.828056901693344, 39.91270110011101, 38.34041766822338, 39.182118102908134, 39.090543016791344, 40.013122111558914, 38.38747054338455, 37.2783100605011, 38.11427280306816, 38.77194531261921, 38.49957212805748, 38.260131776332855, 35.279438719153404, 36.00361905992031, 41.67574189603329, 41.73295542597771, 41.904447823762894, 46.41240052878857, 50.416652262210846, 50.58362290263176, 52.6471933722496, 51.07487194240093, 47.991227209568024, 40.97716838121414, 43.95078621804714, 40.04680350422859, 36.95792265236378, 36.02638363838196, 36.77004933357239, 38.55133295059204, 39.19911079108715, 37.20007225871086, 39.90213766694069, 37.818466275930405, 37.763730213046074, 37.896457090973854, 39.93956185877323, 38.32120209932327, 38.73658061027527, 36.97602108120918, 38.84170576930046, 36.93294659256935, 38.023009300231934, 38.22034031152725, 38.04473273456097, 37.11455024778843, 37.238416001200676, 37.14414685964584, 36.53172232210636, 36.04533702135086, 37.21472047269344, 37.599225640296936, 36.405591890215874, 35.981652438640594, 38.81985314190388, 40.74553281068802, 43.31879273056984, 42.68014200031757, 45.327919721603394, 42.58088752627373, 44.122745990753174, 39.93023715913296, 39.1950374096632, 37.98611328005791, 41.296434849500656, 36.29129022359848, 38.68587613105774, 35.3094457089901, 46.162157356739044, 45.237400978803635, 52.00404368340969, 48.45077455043793, 50.95543675124645, 58.60412232577801, 55.28779707849026, 49.19365368783474, 58.8122333586216, 54.5891285687685, 56.58480428159237, 53.42049367725849, 62.15181715786457, 53.048444241285324, 63.828594982624054, 34.810300692915916, 0.5580141290556639, 1.8769481149502099, 0.7435641693882644, 0.08403532585361972, 10.607068128883839, 64.97986480593681, 58.26225087046623, 55.68223491311073, 38.833597004413605, 19.459468312561512, 21.23358741402626, 42.25789725780487, 52.06318750977516, 17.65732951462269, 0.381033667945303, 0.03641404720838182, 0.039033134598867036, 0.03390281242900528, 0.10717909724917263, 0.08225665020290762, 0.05543219740502536, 0.027262119547231123, 0.03810082271229476, 0.042874687642324716, 0.032333682174794376, 0.060833778261439875, 0.022397228349291254, 0.023883579451648984, 0.03081482685956871, 0.02514481860998785, 0.007813041302142665, 0.03993585334683303, 0.01155127903984976, 0.05916672533203382, 0.6393305968958884, 38.47023390233517, 61.24564938247204, 50.66080816090107, 35.99024377763271, 28.580880761146545, 46.400795951485634, 59.670128524303436, 57.762680277228355, 60.510324239730835, 30.96214648336172, 0.10156548480154015, 0.19647405337309465, 1.6847053868696094, 2.1296584233641624, 18.158372528851032, 51.816652938723564, 54.51276406645775, 57.50774435698986, 49.784822165966034, 49.21571150422096, 40.58536380529404, 41.97372570633888, 44.91862468421459, 53.964077308773994, 53.611688017845154, 53.78817334771156, 52.580009177327156, 53.97556409239769, 52.54527524113655, 51.803080067038536, 49.196537733078, 49.04364533722401, 48.17450277507305, 50.1729903370142, 47.069001495838165, 48.537691086530685, 45.703358575701714, 39.32991877198219, 37.89342865347862, 39.81849655508995, 39.77218843996525, 38.81851181387901, 38.17589029669762, 37.95234069228172, 38.17645266652107, 38.21005046367645, 38.56462083756924, 39.134594053030014, 37.42326848208904, 37.58634813129902, 37.633233815431595, 37.88954146206379, 37.67867937684059, 38.05639050900936, 38.2027168571949, 37.74260714650154, 40.43076530098915, 39.806967973709106, 41.55365064740181, 39.2304553091526, 41.24007627367973, 40.047191083431244, 41.40487343072891, 39.42640699446201, 39.34985250234604, 39.13771368563175, 40.16777001321316, 40.59951804578304, 39.84951809048653, 36.93928085267544, 38.30862857401371, 42.71380439400673, 43.03728103637695, 45.022480711340904, 46.91921353340149, 52.88150779902935, 53.735215589404106, 53.5682487487793, 52.420474737882614, 49.698369204998016, 42.48032212257385, 45.50567798316479, 42.146973609924316, 39.244769141077995, 38.13043713569641, 38.83738540112972, 41.418415904045105, 41.25180244445801, 38.442164808511734, 41.94200500845909, 39.972502291202545, 40.40370315313339, 38.91322933137417, 41.09162583947182, 39.7501952201128, 40.03423757851124, 38.133476972579956, 40.24392552673817, 38.7563319504261, 39.04576241970062, 39.36268821358681, 39.4469790905714, 38.06973159313202, 39.52841632068157, 38.38001534342766, 37.114238664507866, 37.027515918016434, 38.57465609908104, 38.876808285713196, 39.64457608759403, 39.25444722175598, 39.29478965699673, 41.69657237827778, 45.336264073848724, 45.17068415880203, 47.330860644578934, 44.087297692894936, 47.08318993449211, 41.39456458389759, 41.014687567949295, 40.33355891704559, 41.36997610330582, 36.715225875377655, 40.125337690114975, 38.455114513635635, 47.83801943063736, 47.22983926534653, 55.19986979663372, 50.55431887507439, 55.39143651723862, 58.611022755503654, 55.81382945179939, 49.613911136984825, 58.93011823296547, 56.224283427000046, 58.617634400725365, 55.6513387709856, 64.79494392871857, 54.98336881399155, 67.4834668636322, 35.93101255595684, 0.8739956736098975, 1.0243107983842492, 0.815333827631548, 0.07095185603247955, 11.423245333135128, 70.75273543596268, 62.94152498245239, 62.478706017136574, 47.4373385310173, 26.27224814146757, 27.639110796153545, 50.102903097867966, 61.71286091208458, 22.985135726630688, 0.41076683497522026, 0.027217436690989416, 0.1027934868761804, 0.0035840370765072294, 0.12204694241518155, 0.04250195881468244, 0.03015599268110236, 0.04402610007673502, 0.027990225789835677, 0.16566444566706195, 0.1601366774411872, 0.1630711738835089, 0.11627897067228332, 0.17309576331172138, 0.13448331883409992, 0.22838756121927872, 0.13593720097560436, 0.15280658873962238, 0.14887592231389135, 0.18537231080699712, 0.8711010008119047, 47.17739447951317, 70.11835187673569, 60.987362042069435, 42.26664438843727, 33.64877142012119, 48.54411654174328, 64.22572687268257, 61.17545194923878, 66.63798183202744, 35.96269905567169, 0.2653671323787421, 0.8223358425311744, 2.187115615233779, 2.2283462528139353, 20.204585529863834, 56.16305351257324, 57.96758808195591, 59.990892112255096, 50.871753841638565, 51.476252004504204, 43.84533807635307, 45.46198032796383, 47.60607987642288, 55.61429835855961, 58.30146476626396, 55.084751173853874, 52.691426798701286, 55.5559790879488, 54.45274628698826, 56.003488674759865, 52.93890751898289, 50.84055371582508, 50.44538252055645, 51.644506976008415, 48.63198682665825, 52.09894739091396, 47.274205684661865, 40.85804857313633, 40.839984342455864, 42.96841353178024, 41.26229748129845, 41.12638257443905, 40.69871932268143, 39.24114793539047, 41.256157010793686, 39.73183460533619, 40.13086259365082, 43.099761083722115, 39.0456560254097, 38.79343695938587, 40.66083535552025, 38.146305084228516, 39.717577770352364, 39.96212124824524, 38.72292794287205, 40.603944808244705, 42.173477187752724, 41.56301334500313, 43.36366452276707, 42.384289875626564, 42.49286524951458, 42.82872162759304, 43.06631147861481, 41.53938241302967, 41.62874221801758, 42.05610528588295, 41.216658130288124, 42.788774371147156, 42.72283650934696, 40.12174688279629, 40.96192739903927, 47.25358039140701, 46.24680921435356, 48.28098826110363, 50.62820591032505, 55.405301973223686, 54.10970829427242, 54.79214407503605, 54.28653560578823, 52.05637067556381, 44.78582940995693, 48.314152881503105, 45.88663414120674, 40.871910229325294, 40.770482271909714, 41.97569020092487, 44.21282395720482, 43.29862341284752, 39.88221153616905, 43.895582780241966, 41.63118168711662, 40.76133616268635, 41.07078395783901, 42.5527386367321, 41.425396129488945, 41.67704522609711, 40.91381438076496, 42.74581387639046, 40.343609377741814, 41.47842988371849, 40.886961221694946, 41.59404247999191, 40.17391428351402, 41.70598827302456, 40.737614035606384, 38.99828016757965, 39.71260383725166, 40.23097962141037, 42.251316010951996, 43.14379692077637, 41.16583585739136, 43.64392228424549, 44.660599529743195, 47.43038110435009, 48.14422219991684, 49.98274974524975, 47.57157772779465, 49.31946873664856, 44.40826267004013, 42.530369237065315, 41.56345032155514, 43.79005864262581, 39.9136358499527, 42.37868897616863, 38.64801116287708, 48.91832426190376, 50.19686445593834, 57.27471046149731, 53.064977154135704, 57.24289856851101, 56.91640108823776, 55.60268618166447, 50.28471954166889, 60.684134513139725, 59.47405144572258, 60.506448447704315, 59.615187272429466, 69.00446444749832, 59.439454302191734, 69.32726472616196, 40.33594138920307, 1.2384707503952086, 5.0405606254935265, 5.005374513566494, 0.26513825403526425, 12.639792803674936, 77.6226831972599, 67.75766015052795, 67.03246146440506, 51.597248911857605, 32.16909661889076, 33.52609880268574, 57.43490606546402, 72.36781597137451, 29.556848891079426, 0.5354386498220265, 0.15401437471155077, 0.11965568322921172, 0.0824084342457354, 0.2412025220110081, 0.16369917924748734, 0.14234340487746522, 0.10976240198942833, 0.16020961571484804], [0.026407087498228066, 0.04547774835373275, 0.029263333744893316, 0.0653719222464133, 0.04894343328487594, 0.06911832082550973, 0.044317085048533045, 0.037451647585839964, 0.07762242777971551, 0.021673582414223347, 0.07594696260639466, 0.3308580134762451, 17.80830681324005, 54.92273546755314, 44.20404262840748, 36.08716517686844, 20.559554882347584, 32.541218250989914, 52.58681461215019, 53.35482940077782, 52.921189069747925, 40.582308769226074, 0.371617951313965, 0.276526955422014, 0.4990642110351473, 1.0451320186257362, 4.732464132830501, 41.188053265213966, 52.014132142066956, 52.65459917485714, 45.94714969396591, 41.3225394487381, 41.05403445661068, 46.1944480240345, 52.87928871810436, 51.438033655285835, 49.84269306063652, 51.00283920764923, 51.23162493109703, 49.890262708067894, 49.09308448433876, 45.88210478425026, 45.27449458837509, 45.96706822514534, 45.731796249747276, 43.80959339439869, 43.657259568572044, 42.455961629748344, 37.11587257683277, 37.17664651572704, 37.24578380584717, 35.455145090818405, 35.44732891023159, 36.672143787145615, 36.55673258006573, 35.63741751015186, 35.295192673802376, 36.237545907497406, 34.46268394589424, 36.042604967951775, 35.75991913676262, 35.96272565424442, 35.47132462263107, 35.68154074251652, 35.627009868621826, 35.46487256884575, 39.23830568790436, 37.85004638135433, 36.74902506172657, 37.246140986680984, 38.87962393462658, 37.79691383242607, 38.13132628798485, 38.5826812684536, 39.34771701693535, 39.40286345779896, 38.60169164836407, 37.42644511163235, 37.843077555298805, 38.55175092816353, 36.92777507007122, 34.11464162170887, 36.811448112130165, 40.867715254426, 40.26579335331917, 41.9613915681839, 43.554710671305656, 51.59553520381451, 48.37224796414375, 50.79062059521675, 51.62986256182194, 47.62725993990898, 41.81729570031166, 42.76547782123089, 39.8504376411438, 36.42052508890629, 34.123890325427055, 37.4041973054409, 37.68862344324589, 39.34187673032284, 38.977787867188454, 39.373327642679214, 37.747231498360634, 38.235657289624214, 38.395731300115585, 40.075104385614395, 39.94653068482876, 37.94395834207535, 37.98821836709976, 38.06990258395672, 37.53433272242546, 38.874140828847885, 36.52354896068573, 37.25373297929764, 35.8736090362072, 36.24975085258484, 37.10400201380253, 36.42680995166302, 35.752995908260345, 37.40092948079109, 35.94570256769657, 37.21406690776348, 36.621739491820335, 37.27493204176426, 39.34461638331413, 44.08935718238354, 44.354267567396164, 48.82447689771652, 47.5174306333065, 48.70737858116627, 44.55883339047432, 45.16661077737808, 41.539325416088104, 43.897623270750046, 40.80711230635643, 40.54960772395134, 36.094741970300674, 39.78321544826031, 43.87544386088848, 48.09837386012077, 48.146756663918495, 58.81771646440029, 53.09390500187874, 55.10010614991188, 55.967223420739174, 59.35019709169865, 54.68913920223713, 54.06606003642082, 51.36327646672726, 56.60408444702625, 53.14331755042076, 67.31743097305298, 40.21834149956703, 1.9226338947191834, 1.3704800605773926, 0.26641177944839, 0.06426201813155785, 9.89617282524705, 61.94567061960697, 61.13546669483185, 54.857793152332306, 40.41044019162655, 37.92592830955982, 30.11625487357378, 46.40932269394398, 57.706306502223015, 14.642463941127062, 0.5446644953917712, 0.0698120285233017, 0.17007857677526772, 0.0319658441003412, 0.0658630978432484, 0.12610779638634995, 0.0683667256089393, 0.036953176677343436, 0.14262749900808558, 0.08012703518033959, 0.0358896790567087, 0.023284950148081407, 0.09806402464164421, 0.04336749225331005, 0.05897392278711777, 0.057729118489078246, 0.1352638058597222, 0.024095345725072548, 0.06961632418096997, 0.05469542658829596, 0.30197148851584643, 23.797142654657364, 64.18240159749985, 50.00683285295963, 41.7543862760067, 23.843904845416546, 36.7451074719429, 57.71710932254791, 59.199402183294296, 58.56564179062843, 44.23847638070583, 0.2758594084298238, 0.3036244888789952, 2.6953027211129665, 1.2705507664941251, 5.841760458424687, 44.483840614557266, 54.868915155529976, 55.15987314283848, 49.89981919527054, 45.07677599787712, 41.56674474477768, 47.62192502617836, 54.10889133810997, 54.48906473815441, 52.00229577720165, 54.01114158332348, 53.3656170219183, 52.53608353435993, 51.1824631690979, 48.68139557540417, 48.43990333378315, 48.63944202661514, 45.582285672426224, 45.37638232111931, 44.34756092727184, 44.272374361753464, 38.90868857502937, 37.74367868900299, 38.92335578799248, 38.44315655529499, 36.37237787246704, 36.93769633769989, 37.52499282360077, 36.76893599331379, 38.244225829839706, 36.91962070763111, 37.88131110370159, 38.60634259879589, 37.41005279123783, 37.20408484339714, 37.83276870846748, 38.38549464941025, 38.334771171212196, 37.98496954143047, 40.86083002388477, 40.8750868588686, 37.996589317917824, 38.49497437477112, 40.0176552683115, 40.250947549939156, 41.40738129615784, 41.11125938594341, 42.66968876123428, 41.81805185973644, 40.26369586586952, 40.35513795912266, 40.50169609487057, 39.688414335250854, 39.28455300629139, 38.022359535098076, 39.181673526763916, 42.40270368754864, 44.65527221560478, 43.71392972767353, 45.48149608075619, 52.106417790055275, 51.94620318710804, 51.84937298297882, 54.10003401339054, 51.0784475505352, 43.20183880627155, 42.61423833668232, 41.50612659752369, 39.22089122235775, 36.71040393412113, 38.9763705432415, 37.61006645858288, 40.48962414264679, 39.183174446225166, 41.91270858049393, 41.186423152685165, 39.90962706506252, 39.82937917113304, 40.19710063934326, 40.16249589622021, 38.81801784038544, 41.48423597216606, 39.11984324455261, 39.76648114621639, 39.47562575340271, 37.06723898649216, 38.91193360090256, 37.71492563188076, 39.30723778903484, 37.98643246293068, 37.35292665660381, 35.814419612288475, 37.89987310767174, 39.271181523799896, 39.03119020164013, 38.47251757979393, 39.746896997094154, 39.95426706969738, 45.2305119484663, 46.6617127507925, 50.933967903256416, 49.27904650568962, 50.44848695397377, 47.25131191313267, 47.01480120420456, 44.318313896656036, 45.14567770063877, 42.65596389770508, 41.27442263066769, 38.0001725256443, 43.24769474565983, 45.95539905130863, 49.91338826715946, 51.108557134866714, 59.42818410694599, 53.72182510793209, 57.08019129931927, 56.78354121744633, 60.023726150393486, 56.59713841974735, 57.086859941482544, 53.7630794942379, 59.72248211503029, 56.27521589398384, 69.6733045578003, 41.517210602760315, 2.1132133807986975, 2.0435702428221703, 0.213145732996054, 0.15263951645465568, 10.63309483230114, 67.3454962670803, 67.19509273767471, 60.98024122416973, 48.55043180286884, 38.10314320027828, 32.30910390615463, 52.109822407364845, 65.01717120409012, 18.69982637465, 0.4843328765127808, 0.036980328150093555, 0.13921722653321922, 0.06173483830934856, 0.05057492991909385, 0.06753814741387032, 0.04375416232505813, 0.10312234735465609, 0.13347799074836075, 0.10516930196899921, 0.20992727600969374, 0.13595986616564915, 0.19998136907815933, 0.20264334889361635, 0.23739086638670415, 0.13830797688569874, 0.20052635780302808, 0.22403642360586673, 0.22452166944276541, 0.23017719096969813, 0.43196574901230633, 27.784245908260345, 73.22265610098839, 56.38604834675789, 49.036133140325546, 31.477877609431744, 45.08740022778511, 65.09996876120567, 62.766859754920006, 63.635071367025375, 49.905511289834976, 0.5591346533037722, 0.5243450263515115, 2.3918400797992945, 3.1716532353311777, 7.124225841835141, 47.30993136763573, 57.54263028502464, 59.81712743639946, 52.39823453128338, 47.376876175403595, 45.112889260053635, 49.53698046505451, 56.48590698838234, 54.63239684700966, 53.54727387428284, 55.119754895567894, 54.32513393461704, 55.167966708540916, 54.89935152232647, 51.01781040430069, 50.41835077106953, 51.626378148794174, 48.6901693046093, 47.67541095614433, 49.13269355893135, 48.00654798746109, 41.23560391366482, 39.65664803981781, 42.139871791005135, 40.277504324913025, 39.32779848575592, 40.59229463338852, 40.62377214431763, 39.33362737298012, 40.96463285386562, 40.31471572816372, 40.03571569919586, 41.22438311576843, 40.24830289185047, 40.1184106618166, 38.829557821154594, 40.36493003368378, 41.13259144127369, 39.732826352119446, 43.34970027208328, 42.03508481383324, 38.727187514305115, 39.636011347174644, 41.26747280359268, 41.31800629198551, 42.85888820886612, 43.084257915616035, 44.368725791573524, 43.77765990793705, 42.19606317579746, 42.06492841243744, 42.62936532497406, 41.96618691086769, 42.735934406518936, 39.178234711289406, 41.343803107738495, 47.02857926487923, 46.64935201406479, 44.73716922104359, 48.173305839300156, 55.15355408191681, 53.3351806551218, 53.93776372075081, 57.13399261236191, 53.7116302549839, 47.27290615439415, 44.84805107116699, 44.35320362448692, 41.7329478263855, 38.203431218862534, 40.61160899698734, 40.87091088294983, 41.98843091726303, 42.090599834918976, 42.420228347182274, 42.25315511226654, 41.53389930725098, 41.14983111619949, 43.43239143490791, 42.849863693118095, 39.49175588786602, 42.624155804514885, 42.34362065792084, 41.8967342376709, 42.19543620944023, 39.858914986252785, 40.83407185971737, 39.636182337999344, 40.15944465994835, 40.483909249305725, 40.60491755604744, 39.092746898531914, 42.03399047255516, 42.85639934241772, 41.915417835116386, 40.01691430807114, 41.97224758565426, 42.56398603320122, 49.29039649665356, 49.63963195681572, 52.092723324894905, 52.3183324187994, 54.576520845294, 49.40706163644791, 50.05693316459656, 47.402517199516296, 48.9839543402195, 44.837350845336914, 44.650659263134, 42.01051153242588, 45.90871475636959, 47.4150375276804, 53.192080333828926, 52.69460342824459, 59.13005590438843, 54.38182309269905, 61.81263975799084, 57.235002592206, 62.02482417225838, 57.072815895080566, 60.394001081585884, 56.31481736898422, 64.43632677197456, 56.69864997267723, 72.96304643154144, 43.789507672190666, 3.4744031773880124, 2.850967780686915, 3.128826920874417, 0.24197529070079327, 11.37439800426364, 73.45377489924431, 73.59639644622803, 67.28129491209984, 56.39607600867748, 51.903751865029335, 43.831727206707, 60.102830305695534, 73.51080983877182, 26.073059029877186, 0.615704592783004, 0.17836131592048332, 0.2858776302309707, 0.1570637259283103, 0.12309245037613437, 0.25246091710869223, 0.19463581294985488, 0.16100671200547367, 0.24567557964473963], [0.03608343155065086, 0.027022942049370613, 0.03959121480875183, 0.05897842020203825, 0.04619219165761024, 0.058567121959640644, 0.03354698230396025, 0.026031670240627136, 0.027688767258950975, 0.0501801518839784, 0.1314366838778369, 0.021746247948613018, 12.834968380630016, 54.73219469189644, 47.32253149151802, 30.548662170767784, 31.098352074623108, 45.92627361416817, 44.53954942524433, 58.01743380725384, 48.08018043637276, 47.15293899178505, 1.1980430572293699, 0.49294731114059687, 3.396024783141911, 0.8368830650579184, 0.9089958923868835, 31.543728075921535, 57.04749785363674, 51.77773542702198, 44.6006615459919, 38.48364718258381, 44.216422364115715, 53.32849681377411, 52.76659816503525, 48.55260528624058, 54.705675914883614, 51.01826637983322, 48.085845932364464, 46.110373735427856, 45.672831013798714, 43.35075281560421, 41.1777900159359, 40.13596571981907, 40.496737360954285, 40.0576139241457, 38.680085241794586, 35.98846547305584, 35.0185789167881, 35.31750127673149, 35.46165034174919, 36.52093090116978, 37.03523330390453, 37.31720097362995, 36.261290833353996, 37.21783250570297, 37.959940284490585, 35.719192922115326, 36.239012628793716, 35.96496753394604, 36.36909104883671, 35.51845729351044, 37.49703772366047, 34.98943068087101, 36.99582561850548, 35.509915351867676, 36.589452624320984, 38.5156224668026, 35.94784565269947, 38.825416043400764, 40.110681876540184, 38.22027951478958, 38.02165277302265, 37.51165173947811, 38.38830269873142, 39.34757262468338, 37.34928645193577, 36.4163339138031, 39.98875021934509, 38.1351450830698, 36.961806043982506, 34.959275498986244, 39.24686282873154, 40.38759581744671, 41.028374433517456, 42.28156998753548, 47.535954639315605, 52.13890604674816, 50.127563774585724, 47.42358326911926, 51.01238049566746, 50.37349037826061, 42.721620574593544, 42.44704730808735, 40.03820076584816, 36.196914687752724, 34.58800122141838, 37.219694405794144, 38.31536941230297, 37.86717586219311, 39.043079763650894, 38.870667815208435, 38.61536331474781, 38.362528681755066, 38.281277641654015, 37.881383299827576, 39.944588989019394, 38.430666625499725, 37.63348840177059, 37.93097443878651, 37.602645456790924, 39.089475274086, 37.535905838012695, 36.88918054103851, 35.44985957443714, 36.21189348399639, 36.1246919631958, 35.51184944808483, 34.79695200920105, 35.86694799363613, 37.82100833952427, 37.47736617922783, 38.91465425491333, 35.8953020721674, 39.908479526638985, 43.049501180648804, 49.518882036209106, 48.52101758122444, 51.26433737576008, 51.3977026194334, 51.39354944229126, 50.96642576158047, 48.17750461399555, 47.97086030244827, 45.8123367279768, 44.51999947428703, 41.24216616153717, 39.92141403257847, 39.20145906507969, 40.54309867322445, 47.52821445465088, 49.86017972230911, 49.2444683611393, 56.16017326712608, 54.80423882603645, 59.24852594733238, 53.900989294052124, 57.28214666247368, 49.81285326182842, 56.07852324843407, 53.72948929667473, 64.21147003769875, 47.31656201183796, 1.7826429940760136, 0.6123527570161968, 0.34534206439275295, 0.1152175288007129, 9.945920705795288, 63.81635203957558, 60.189655646681786, 58.85505326092243, 44.50580343604088, 24.662662111222744, 30.64899578690529, 49.52940747141838, 57.017015889286995, 9.666382055729628, 0.43303040438331664, 0.013068406078673434, 0.172081544296816, 0.05715412844438106, 0.13138810289092362, 0.0726409544586204, 0.04197887457848992, 0.08756457944400609, 0.09223753455444239, 0.02087185697746463, 0.032625602252664976, 0.13641820172779262, 0.06971010938286781, 0.0703363335924223, 0.07093032632838003, 0.02342553147173021, 0.018269939173478633, 0.05378005051170476, 0.009320746776211308, 0.11298662546323612, 0.05789477327198256, 15.11121153831482, 61.19542367756367, 51.68584495782852, 37.79873013496399, 26.575990542769432, 47.02817268669605, 53.39710973203182, 61.5484057366848, 54.41593386232853, 50.84267780184746, 1.4520680950954556, 0.5883797840215266, 3.008436793461442, 1.234988474752754, 0.8413841610308737, 35.96299163997173, 59.85593855381012, 54.047102853655815, 47.31740176677704, 41.05181537568569, 45.63012130558491, 54.47698898613453, 54.65293474495411, 50.68560563027859, 54.21294495463371, 53.45227137207985, 50.68903684616089, 49.18779820203781, 49.40301485359669, 45.8368606120348, 44.71318870782852, 42.58733578026295, 42.49772138893604, 41.58399201929569, 40.26058383285999, 38.570852503180504, 37.51502975821495, 38.190226927399635, 36.844042763113976, 37.4255483597517, 38.80916811525822, 39.02471914887428, 38.58515873551369, 39.24082115292549, 39.04621459543705, 37.56773293018341, 37.98647426068783, 38.320149555802345, 39.00608114898205, 37.55785346031189, 38.393056243658066, 36.93973682820797, 39.49097312986851, 38.72366890311241, 39.5687435567379, 39.381440207362175, 38.682802096009254, 40.038926526904106, 41.47607780992985, 39.2853357642889, 39.492230862379074, 39.37453217804432, 39.265683218836784, 40.09205907583237, 38.31930220127106, 38.95580604672432, 40.23727968335152, 39.53362204134464, 38.10195006430149, 36.70178979635239, 40.06914630532265, 42.10067309439182, 43.65548886358738, 43.680696710944176, 48.73800113797188, 53.72102715075016, 51.59543260931969, 48.507292717695236, 53.98279510438442, 51.107056215405464, 44.0441358089447, 43.39169941842556, 41.57804913818836, 38.878685384988785, 38.548239916563034, 39.273761585354805, 39.465073719620705, 39.704681262373924, 39.65716101229191, 40.67714408040047, 39.19388227164745, 41.383351385593414, 40.55912621319294, 39.527424573898315, 41.60678319633007, 39.83605161309242, 40.00514633953571, 39.443654268980026, 39.61464509367943, 39.68662463128567, 38.982077836990356, 38.72578538954258, 37.165706902742386, 38.35213623940945, 38.50330352783203, 37.94363155961037, 36.92551799118519, 38.227632120251656, 37.894579991698265, 39.9543696641922, 40.75030915439129, 39.66164857149124, 42.30265885591507, 45.66962778568268, 50.6440282613039, 50.3817967325449, 53.59573267400265, 55.28497762978077, 52.157354056835175, 52.627445831894875, 50.40378235280514, 50.104916989803314, 48.25461387634277, 46.624299958348274, 42.40203112363815, 41.012913063168526, 41.36642329394817, 44.32378560304642, 49.56001862883568, 51.79012656211853, 51.61393001675606, 57.98502154648304, 56.93944685161114, 61.53287597000599, 56.14445351064205, 59.86226141452789, 51.283370554447174, 58.678784519433975, 54.62516963481903, 64.7798739373684, 48.31437706947327, 2.452157805673778, 0.8985215169377625, 0.4792820865986869, 0.2197793309460394, 10.196402315050364, 68.65617513656616, 65.80553770065308, 65.45553848147392, 49.59337703883648, 29.75742492824793, 36.712892800569534, 55.86489491164684, 65.40539637207985, 13.876255005598068, 0.5142956937197596, 0.02775905049929861, 0.1069086289498955, 0.012392117514536949, 0.005515658231161069, 0.03666749063995667, 0.04664451953431126, 0.03392910301045049, 0.026967195626639295, 0.10947833012323827, 0.13786136725684628, 0.3098696912638843, 0.22130977304186672, 0.11831621057353914, 0.15462406387086958, 0.11856605458888225, 0.13311910297488794, 0.10314826315152459, 0.15985460195224732, 0.28713750012684613, 0.15668012463720515, 18.293005004525185, 71.64264008402824, 59.2608866840601, 44.607493579387665, 40.49345813691616, 58.61343562602997, 58.17605249583721, 66.82550936937332, 58.889392018318176, 56.97798818349838, 2.584245130419731, 1.144538247026503, 4.70831785351038, 3.3705219766125083, 1.7558023030869663, 39.169985353946686, 62.88279913365841, 56.991298869252205, 49.35979597270489, 43.64734970033169, 49.66230534017086, 55.40535897016525, 56.123653426766396, 52.65770360827446, 57.17718489468098, 56.480123698711395, 53.55480507016182, 51.46978095173836, 50.208214446902275, 47.60291464626789, 46.77602581679821, 43.99894863367081, 45.46087458729744, 44.89199571311474, 42.868866473436356, 41.29898451268673, 39.36600923538208, 41.09863266348839, 39.61413972079754, 40.827722400426865, 40.84983341395855, 40.46260379254818, 39.4188492000103, 42.44290933012962, 42.709427028894424, 40.828649550676346, 40.144872441887856, 41.056036949157715, 40.84666818380356, 39.9090912938118, 40.54130896925926, 37.6502151042223, 41.34722292423248, 40.61822064220905, 41.73925168812275, 42.43625968694687, 38.63822288811207, 43.4833163022995, 43.14795769751072, 42.59934313595295, 42.464039996266365, 40.12985184788704, 40.54756723344326, 43.586378172039986, 40.05725294351578, 42.4187920242548, 44.501855447888374, 42.23417893052101, 41.82462550699711, 40.11760890483856, 44.01507876813412, 45.10386474430561, 45.69330431520939, 47.45815761387348, 52.277545407414436, 56.92366249859333, 52.033374309539795, 48.0709583312273, 56.83829627931118, 53.04813265800476, 46.37142352759838, 46.59779258072376, 43.5633248090744, 41.531376242637634, 40.59150047600269, 41.48680843412876, 42.06553258001804, 41.77457079291344, 41.78592078387737, 42.49231047928333, 41.37988977134228, 42.17632703483105, 42.892011031508446, 41.00805312395096, 43.31479154527187, 42.95716613531113, 40.976074039936066, 42.45612122118473, 41.42374701797962, 43.66362042725086, 41.21553339064121, 40.80615095794201, 38.01964268088341, 40.22000581026077, 40.33312574028969, 39.930115565657616, 38.675392493605614, 39.43352781236172, 40.68496026098728, 43.76845680177212, 43.91109734773636, 41.69473707675934, 44.45033401250839, 47.55349449813366, 53.66061419248581, 52.75942035019398, 55.367946177721024, 57.40452289581299, 55.231772884726524, 55.591081604361534, 53.48604395985603, 53.002987280488014, 50.90955801308155, 49.16501462459564, 44.6255312114954, 43.169392347335815, 43.1220430880785, 46.819404289126396, 50.67976154386997, 55.301499143242836, 54.737309217453, 59.44920837879181, 60.66920891404152, 64.98184069991112, 57.90005050599575, 63.501485735177994, 54.09909546375275, 61.67422458529472, 57.154853492975235, 68.49586173892021, 49.906761422753334, 2.9120079427957535, 2.023139214143157, 1.5441528288647532, 0.44429587956983596, 11.716160215437412, 74.84725892543793, 70.00178933143616, 70.67924737930298, 58.93201433122158, 35.73415271937847, 43.148356676101685, 63.7463103979826, 75.46924754977226, 18.971686586737633, 0.5677460005972534, 0.07924298144644126, 0.39123977185226977, 0.13228672498371452, 0.255941916257143, 0.11620082994340919, 0.13258190680062398, 0.308475136407651, 0.12069414078723639], [0.031201884703477845, 0.02025727149884915, 0.03478559337963816, 0.06108706955274101, 0.090321836178191, 0.01417222551026498, 0.02100794645230053, 0.05573067806835752, 0.013075226415821817, 0.020406890325830318, 0.12835363915655762, 0.04868165553489234, 7.379157487303019, 52.970917001366615, 45.444569662213326, 30.508790910243988, 18.86427205055952, 27.436513267457485, 46.51196278631687, 56.50080218911171, 48.98838110268116, 52.75914676487446, 2.920476500876248, 0.4635789542226121, 3.2369011966511607, 1.0552148963324726, 0.12784357590135187, 18.46200853586197, 58.82966682314873, 50.256544053554535, 47.50658221542835, 40.16955591738224, 50.61052165925503, 53.25788140296936, 51.213594898581505, 51.54989205300808, 50.97101591527462, 49.26334194839001, 47.78520226478577, 42.311436384916306, 41.77497737109661, 38.19933123886585, 38.04049216210842, 36.39483466744423, 36.565692499279976, 35.633765906095505, 34.35870252549648, 35.23775115609169, 37.18330755829811, 35.67111790180206, 36.4546624571085, 35.732860788702965, 35.16625799238682, 36.26094125211239, 35.6253569573164, 37.00163170695305, 35.41665315628052, 36.44434981048107, 36.56548351049423, 36.57486520707607, 35.623783841729164, 34.8673128336668, 36.82711087167263, 34.86046940088272, 35.76996959745884, 38.052286729216576, 37.29733943939209, 38.508931025862694, 38.38342756032944, 37.32456497848034, 38.86156730353832, 37.74915799498558, 39.003626480698586, 37.804942801594734, 37.800595834851265, 37.595562636852264, 38.888735845685005, 36.40102453529835, 37.81629279255867, 36.486850529909134, 36.696850061416626, 34.00701239705086, 36.817835569381714, 40.64665451645851, 42.98754170536995, 43.1816390901804, 45.40535196661949, 50.71823067963123, 49.75449979305267, 47.35196851193905, 51.33157856762409, 49.1498838365078, 44.338756799697876, 42.79013849794865, 40.89198835194111, 36.46471291780472, 35.1484065502882, 37.340383529663086, 37.04244911670685, 37.99188517034054, 37.63393297791481, 38.756343349814415, 38.21714088320732, 38.424286767840385, 38.77908132970333, 38.767970725893974, 39.86898444592953, 40.02097249031067, 37.34993241727352, 40.21423391997814, 38.75475883483887, 38.043505400419235, 37.36776486039162, 39.29971419274807, 35.88095024228096, 36.938258707523346, 35.69964297115803, 36.42840586602688, 34.685503989458084, 36.45934760570526, 36.71027474105358, 36.52060031890869, 36.28616809844971, 37.4025671929121, 38.07102732360363, 42.78508476912975, 45.281528010964394, 49.58317078649998, 47.88242384791374, 49.64818149805069, 48.353495970368385, 48.64764578640461, 48.349198400974274, 49.79471303522587, 50.57684786617756, 48.902007937431335, 44.670623391866684, 45.454088151454926, 41.446097418665886, 40.2433555573225, 41.28801830112934, 44.83460359275341, 44.59498085081577, 47.312777414917946, 50.92805162072182, 56.33168086409569, 52.79429107904434, 54.320976957678795, 49.1070107370615, 54.47672680020332, 54.41409096121788, 64.61622431874275, 39.00222435593605, 0.8942030486650765, 1.2699875654652715, 0.3351377119543031, 0.19257834210293368, 12.158670220524073, 66.18925631046295, 58.1326512247324, 56.76128961145878, 40.69460794329643, 37.71561719477177, 36.290230080485344, 49.71092753112316, 49.94322046637535, 5.01774332486093, 0.5336786911357194, 0.036363711042213254, 0.13887558627175167, 0.05333778986823745, 0.09038970558322035, 0.037418276915559545, 0.028006220927636605, 0.04055425903061405, 0.014663657148048515, 0.05596923772827722, 0.09994662323151715, 0.0026984116129824542, 0.057542464637663215, 0.004491214740482974, 0.02142729514162056, 0.10150950460229069, 0.03911275591235608, 0.02189966842706781, 0.012908409244118957, 0.09094712528167292, 0.030936062248656526, 9.12856176495552, 61.60408794879913, 55.24043262004852, 36.04701653122902, 28.594926707446575, 40.792581886053085, 51.48371480405331, 61.29453755915165, 53.34490053355694, 58.36129255592823, 3.791499249637127, 0.35496748227160424, 2.141870493069291, 1.1681421054527164, 0.09760135493706912, 22.958647347986698, 60.7734639197588, 53.69863875210285, 48.314563259482384, 41.84937357902527, 51.434697434306145, 54.2035860568285, 52.47544638812542, 55.11810578405857, 51.83275267481804, 50.54062061011791, 48.99606429040432, 44.826620221138, 43.11546564102173, 40.81166446208954, 38.86885151267052, 38.33360083401203, 39.025045931339264, 37.74801805615425, 36.380836218595505, 36.47119536995888, 39.0759252011776, 36.96529045701027, 37.45968572795391, 36.64599359035492, 37.71467864513397, 38.73042494058609, 37.73755341768265, 39.92582559585571, 38.53098504245281, 37.42410443723202, 39.266207590699196, 39.395073875784874, 37.21000112593174, 36.27167567610741, 37.7726711332798, 37.10797280073166, 37.88139849901199, 38.81705269217491, 38.118862956762314, 40.833330899477005, 40.66521652042866, 39.55693759024143, 39.24688942730427, 40.3382782638073, 40.09871631860733, 39.92021329700947, 40.53778275847435, 39.830127730965614, 39.0878451615572, 38.873779848217964, 39.629099518060684, 38.57826970517635, 39.50683727860451, 35.085090547800064, 39.798091650009155, 42.74152010679245, 44.021276235580444, 45.39273664355278, 47.01836161315441, 52.977502048015594, 51.83209531009197, 49.60229896008968, 52.379828318953514, 50.969818979501724, 46.76157899200916, 44.33643892407417, 42.9645187407732, 38.33191752433777, 37.06184707581997, 39.14082571864128, 39.462508857250214, 38.82960341870785, 41.06864847242832, 40.70153497159481, 40.8446428924799, 40.837936252355576, 39.99642960727215, 41.103724390268326, 41.43332630395889, 42.283420488238335, 39.17491748929024, 41.579800844192505, 40.48864759504795, 39.30341139435768, 39.56491716206074, 40.39527900516987, 37.93030947446823, 38.63848887383938, 38.581590726971626, 38.24389524757862, 37.52012148499489, 38.45626965165138, 37.53637321293354, 38.447868302464485, 38.65629851818085, 38.77633407711983, 39.748124331235886, 44.954677149653435, 47.747265100479126, 51.82889588177204, 50.20139381289482, 51.706470251083374, 51.042452082037926, 50.43852388858795, 52.0958087593317, 51.720757484436035, 52.19072386622429, 50.883749797940254, 46.771887838840485, 47.41296663880348, 42.856270149350166, 42.38101825118065, 43.2699653506279, 45.79911343753338, 47.089676186442375, 50.422978922724724, 51.7367622256279, 58.12548100948334, 54.74754586815834, 55.88890582323074, 51.65114142000675, 57.62222461402416, 56.31933152675629, 67.28318721055984, 42.384555861353874, 1.4596263645216823, 1.7567989183589816, 0.6976574077270925, 0.2904934622347355, 12.623320687562227, 71.60781875252724, 62.28089243173599, 64.298295378685, 48.217090889811516, 37.58779585361481, 41.040514782071114, 54.70945671200752, 58.985697850584984, 8.160571306943893, 0.5026462906971574, 0.06078377235098742, 0.1198174714227207, 0.017618153542571235, 0.07808344991644844, 0.044288842618698254, 0.048150077418540604, 0.05857408330484759, 0.01665583662543213, 0.0900294745224528, 0.21377500001108274, 0.08554774118238129, 0.1515984020079486, 0.1194347013370134, 0.11723435964086093, 0.14197737764334306, 0.1300244065350853, 0.07445891940733418, 0.17587544774869457, 0.23912519129225984, 0.1949857355793938, 10.147157907485962, 71.01868316531181, 62.110532373189926, 43.73091861605644, 28.68326246738434, 38.56632314622402, 58.25577221810818, 67.11000770330429, 59.98450845479965, 64.78042110800743, 4.974720133468509, 0.623315762495622, 8.413785919547081, 3.9864216651767492, 0.3294122207444161, 23.753144815564156, 64.50079411268234, 56.18363320827484, 52.769383415579796, 46.17071449756622, 54.48899634182453, 55.60376912355423, 55.26694379746914, 59.01570104062557, 54.61169935762882, 53.16756784915924, 52.06398166716099, 45.89237183332443, 45.801100730895996, 41.67546071112156, 42.92957201600075, 40.94335399568081, 41.29738099873066, 39.6938556432724, 37.91634142398834, 38.771770521998405, 42.341507971286774, 40.16106717288494, 40.289956256747246, 38.93951632082462, 37.80450202524662, 40.94882570207119, 39.85389545559883, 43.26240375638008, 40.15313699841499, 41.257057562470436, 41.22076191008091, 42.08996906876564, 39.12829779088497, 38.148037791252136, 40.50535909831524, 40.191332548856735, 40.20341210067272, 40.756214037537575, 38.792240023612976, 41.93381264805794, 42.06198737025261, 42.327163740992546, 43.725450709462166, 41.607961133122444, 41.445238664746284, 42.18834958970547, 41.73249565064907, 41.26464955508709, 42.669586166739464, 40.47794356942177, 41.76505610346794, 39.06763404607773, 40.130741000175476, 38.46157416701317, 41.90078862011433, 44.49599616229534, 46.712865605950356, 48.65538217127323, 48.467246666550636, 53.63509476184845, 52.49519392848015, 49.39239822328091, 54.18836787343025, 53.296061754226685, 49.8953278362751, 46.929131001234055, 45.48715777695179, 40.810076147317886, 38.79113048315048, 42.56786182522774, 40.910284370183945, 41.3133629411459, 42.553547993302345, 42.153034284710884, 42.41389788687229, 42.685469314455986, 41.8788143992424, 42.973201274871826, 42.74614445865154, 44.314943477511406, 40.602314695715904, 45.181730166077614, 43.202868551015854, 42.73120366036892, 40.50149470567703, 42.49929450452328, 39.702735766768456, 41.7453807592392, 39.885635152459145, 40.05017772316933, 37.36758626997471, 41.497128680348396, 40.498435869812965, 40.030221194028854, 40.009504705667496, 41.56942740082741, 42.01857469975948, 46.62384778261185, 49.720278829336166, 54.82616364955902, 54.47875589132309, 53.48243035376072, 51.21511481702328, 52.24007561802864, 54.76525291800499, 54.601987078785896, 55.711804926395416, 53.52289438247681, 51.04217849671841, 50.73499158024788, 45.08451238274574, 44.34148885309696, 44.27332431077957, 48.74709025025368, 50.43082170188427, 53.89427125453949, 54.80852119624615, 60.78642122447491, 56.894681453704834, 57.52449005842209, 54.48402240872383, 59.34343725442886, 59.874945133924484, 68.22486788034439, 43.82247470319271, 2.0226490404456854, 2.8887980757281184, 1.8882073857821524, 0.5397900694515556, 14.333744756877422, 77.65435829758644, 68.17961230874062, 71.48450776934624, 54.08450424671173, 48.237765580415726, 51.136504635214806, 62.565265372395515, 68.9620891213417, 12.479238118976355, 0.7239733706228435, 0.24053412897046655, 0.27614753984380513, 0.16339565569069237, 0.21960354584734887, 0.149307748361025, 0.19971113826613873, 0.16771491063991562, 0.1000800242763944], [0.04640794883016497, 0.037496425065910444, 0.0662013390683569, 0.09095640212763101, 0.05165365641005337, 0.030827101982140448, 0.04199624454486184, 0.10597391621558927, 0.0472454365080921, 0.04339393497502897, 0.0906765011313837, 0.02216102871898329, 3.5775678791105747, 47.10790380835533, 51.20509095489979, 38.52880395948887, 16.879195868968964, 31.309050768613815, 39.15194392204285, 58.1331679970026, 46.34366601705551, 56.378216966986656, 10.177501179277897, 0.382167135248892, 1.668730687815696, 0.15277997532393783, 0.1454678614391014, 8.103639911860228, 60.04698850214481, 50.217132568359375, 46.82411603629589, 42.94617712497711, 54.01080720126629, 52.48454309999943, 53.75223107635975, 48.62739287316799, 48.45050476491451, 45.28968997299671, 44.331654980778694, 37.73344583809376, 37.82718300819397, 35.707683339715004, 35.96453055739403, 33.88009160757065, 36.93940244615078, 34.521273002028465, 35.98493546247482, 34.049114137887955, 36.54832363128662, 34.64056760072708, 35.852288380265236, 37.29733183979988, 39.10641476511955, 38.71549554169178, 38.88683594763279, 37.45556674897671, 39.40809577703476, 36.83972619473934, 37.013452872633934, 35.46207211911678, 36.79533317685127, 34.658578634262085, 37.46315494179726, 35.38082107901573, 35.891141295433044, 35.290218740701675, 37.18627139925957, 36.973467618227005, 37.891817539930344, 37.801557183265686, 37.114812433719635, 38.08760963380337, 40.201193019747734, 38.36146093904972, 38.8481730222702, 37.19395838677883, 36.087719947099686, 36.563359424471855, 37.34972722828388, 38.25981639325619, 36.78288124501705, 36.424191892147064, 36.506472676992416, 40.94084993004799, 42.73561142385006, 41.23818777501583, 48.34452085196972, 52.370978593826294, 50.60473456978798, 47.823454812169075, 52.74686962366104, 48.54598984122276, 43.077482879161835, 41.89447335898876, 41.63995161652565, 36.83390490710735, 36.40181489288807, 37.85074174404144, 38.41113567352295, 38.572011440992355, 37.42917716503143, 38.56182038784027, 38.71855057775974, 38.952253237366676, 39.11514289677143, 39.489958584308624, 38.896692618727684, 40.04315949976444, 36.90716877579689, 37.74052865803242, 37.22752198576927, 38.156765922904015, 36.110134944319725, 35.234376937150955, 37.373612746596336, 38.000396713614464, 36.15291304886341, 37.27512963116169, 37.40969941020012, 36.57483860850334, 35.0292981415987, 36.42627418041229, 35.869026482105255, 37.21308656036854, 37.17783585190773, 41.045139133930206, 43.90652619302273, 50.57832978665829, 50.90607739984989, 49.3977065384388, 46.73713490366936, 46.581537052989006, 46.601208597421646, 47.78949223458767, 46.6629096865654, 51.03469289839268, 51.805523335933685, 49.920877665281296, 42.79239557683468, 42.920471504330635, 40.15037074685097, 39.7310708463192, 39.04366113245487, 42.51315236091614, 40.77804006636143, 49.01008553802967, 46.5696968883276, 50.66845715045929, 45.63655436038971, 56.46504230797291, 53.3653624355793, 67.22584828734398, 29.91402592509985, 0.25875786202959716, 0.9901654743589461, 0.41801402578130364, 0.31968067574780434, 15.737878661602736, 67.12497130036354, 57.58834183216095, 54.116099551320076, 39.074944853782654, 24.04774110764265, 22.170362547039986, 48.09579759836197, 40.441701114177704, 3.794820746406913, 0.44715240597724915, 0.029456403462972958, 0.11342063342453912, 0.021918704514973797, 0.1735068834386766, 0.030592763287131675, 0.09084394449018873, 0.016239326650975272, 0.01872997425380163, 0.017513187885924708, 0.04104176099644974, 0.008113915391732007, 0.05516586286830716, 0.02128020703821676, 0.00706972845364362, 0.006832158633187646, 0.036094871757086366, 0.01993022557144286, 0.04482302567339502, 0.07145103940274566, 0.028363785822875798, 4.4493066519498825, 53.63518215715885, 56.140820905566216, 44.927493408322334, 19.927572794258595, 35.10797291994095, 45.52085816860199, 63.3865837007761, 52.59957432746887, 60.92981792986393, 9.478834569454193, 0.36371226771734655, 2.668034671805799, 3.0007319943979383, 0.4315247945487499, 9.634425770491362, 63.98512378334999, 51.20385222136974, 49.21106055378914, 44.742458537220955, 57.63378359377384, 53.464993089437485, 55.93326844274998, 51.530592888593674, 51.592377573251724, 48.17283846437931, 46.130763441324234, 40.620519518852234, 40.69721080362797, 36.667264848947525, 38.974478244781494, 36.70242816209793, 37.9556655138731, 35.61641223728657, 38.807408809661865, 36.630357429385185, 36.84066854417324, 37.2851724922657, 38.81779745221138, 38.462736904621124, 41.14809460937977, 40.0089917331934, 40.631360337138176, 37.6875215023756, 40.72839953005314, 38.224588483572006, 38.41172844171524, 37.69947566092014, 39.117650762200356, 35.26632182300091, 37.93249435722828, 38.11760522425175, 36.15589588880539, 35.9121997654438, 40.56221164762974, 39.493063017725945, 40.42297571897507, 39.008839800953865, 39.439185708761215, 38.64019118249416, 41.60153567790985, 39.409463703632355, 40.34749276936054, 39.005108401179314, 38.23639824986458, 37.99586355686188, 40.135817527770996, 40.67270591855049, 39.61911365389824, 37.10693545639515, 38.528724163770676, 42.484790682792664, 43.15251365303993, 44.190629348158836, 49.844000190496445, 54.34871166944504, 51.556256711483, 48.78064624965191, 54.78453688323498, 49.291141256690025, 45.29892347753048, 44.605726674199104, 43.175316229462624, 39.234255105257034, 38.79950523376465, 39.02171730995178, 40.07671929895878, 39.965617060661316, 39.244161173701286, 40.706691294908524, 38.808841332793236, 41.69013932347298, 41.17529734969139, 40.81938944756985, 42.400541603565216, 41.981720477342606, 38.64020638167858, 40.120656341314316, 41.1476918309927, 39.16734829545021, 38.97121042013168, 38.53192359209061, 38.42724300920963, 39.46532070636749, 38.322250843048096, 39.18098196387291, 38.43975953757763, 38.46014924347401, 38.60631600022316, 37.929807901382446, 38.47431108355522, 38.725591599941254, 39.577125906944275, 42.59331665933132, 46.73729069530964, 53.27950984239578, 52.146764025092125, 49.39516447484493, 48.12730930745602, 46.5899346023798, 46.62684582173824, 49.398880675435066, 49.436703845858574, 52.92675197124481, 52.4553644657135, 51.25154346227646, 44.704642966389656, 44.94803510606289, 42.212007120251656, 42.18894615769386, 41.540320962667465, 44.22152929008007, 43.51588815450668, 49.777758345007896, 48.74010622501373, 53.29759307205677, 48.208978325128555, 58.88738192617893, 55.380322113633156, 68.90200674533844, 32.78798080980778, 0.3526244033128023, 1.3416456640698016, 0.3557764826109633, 0.3882276319200173, 16.878937482833862, 72.53432303667068, 61.79926447570324, 61.537545919418335, 40.61875261366367, 27.624496780335903, 30.51065471023321, 55.66241517663002, 48.39062757790089, 5.581771284341812, 0.4533104505389929, 0.11058220799895935, 0.12348092015599832, 0.03870015891152434, 0.06458428091718815, 0.022837451797386166, 0.07452278121490963, 0.0391248566302238, 0.1048486348008737, 0.2052269282285124, 0.20141558430623263, 0.1630529764224775, 0.2411793521605432, 0.08657907412271015, 0.10900886976742186, 0.0870011631923262, 0.1766517639043741, 0.10779180694953538, 0.15349896799307317, 0.23477908544009551, 0.0862812799459789, 5.103132342919707, 61.69574663043022, 64.23385843634605, 54.10074457526207, 23.847127072513103, 43.377066403627396, 50.11184401810169, 67.54364803433418, 56.680612340569496, 68.33904415369034, 12.665267586708069, 0.6519704998936504, 6.744968192651868, 3.3511240174993873, 0.40088867128361017, 10.983912907540798, 66.33368656039238, 55.17741680145264, 50.439033061265945, 47.32126235961914, 59.006467536091805, 57.1576539427042, 56.25810161232948, 54.13651965558529, 52.223478108644485, 49.752786085009575, 49.00644913315773, 43.26268874108791, 43.35033103823662, 39.04132045805454, 40.05100227892399, 38.21176037192345, 42.05397740006447, 37.92048700153828, 40.062815845012665, 40.48906557261944, 40.28899870812893, 39.779681637883186, 39.94251810014248, 40.76013922691345, 43.96003872156143, 42.394127547740936, 43.72961528599262, 39.60257314145565, 43.46200704574585, 40.64241014420986, 41.038459092378616, 38.954525515437126, 41.251061484217644, 36.501567140221596, 41.1151921749115, 39.43337582051754, 39.29522663354874, 38.2169508934021, 42.454692497849464, 42.2636691480875, 42.64108769595623, 41.28981560468674, 41.33327767252922, 41.609188467264175, 43.576156720519066, 42.57050268352032, 41.56414948403835, 40.83011247217655, 40.18168866634369, 39.63679410517216, 41.638146713376045, 42.694961205124855, 43.671014830470085, 41.43593296408653, 41.3683307915926, 44.82890009880066, 46.260017305612564, 45.91632194817066, 52.97392264008522, 55.824009105563164, 52.51641198992729, 49.93322320282459, 57.12355077266693, 51.89511112868786, 47.69246444106102, 45.92577964067459, 46.86206839978695, 41.24384567141533, 39.982130974531174, 43.17425608634949, 42.474588230252266, 42.539990320801735, 42.099396362900734, 41.71509638428688, 40.18936425447464, 44.061888456344604, 44.110278859734535, 42.12579354643822, 43.10923017561436, 44.16728340089321, 38.86517331004143, 41.66442230343819, 42.17201806604862, 41.424924954771996, 39.79501761496067, 39.18751761317253, 41.13169848918915, 42.858808413147926, 40.56702218949795, 41.70060396194458, 40.17661593854427, 40.74638396501541, 40.09531930088997, 40.076715499162674, 39.27672162652016, 41.18114523589611, 41.28245159983635, 44.403885304927826, 48.29986944794655, 55.33655986189842, 53.92316870391369, 51.93078741431236, 49.99465070664883, 48.36049519479275, 47.669126093387604, 51.0008405148983, 51.09170883893967, 54.35141712427139, 53.995095044374466, 53.43278981745243, 48.36835317313671, 46.62748798727989, 43.60853098332882, 45.2398594468832, 42.74657383561134, 45.19720673561096, 46.30073592066765, 53.3764236420393, 50.33251717686653, 56.270409151911736, 48.484816923737526, 62.29938603937626, 58.5460614413023, 71.52183696627617, 34.60214786231518, 0.5906084831804037, 2.937828032299876, 2.1503943856805563, 0.48565247445367277, 18.323334977030754, 77.88581907749176, 67.39107862114906, 66.11264482140541, 53.44814859330654, 36.9804098457098, 34.49777506291866, 64.58292290568352, 60.92031843960285, 8.398486990481615, 0.5686904874164611, 0.19373064511455595, 0.44147390755824745, 0.053365646381280385, 0.367066478356719, 0.1127930881921202, 0.13687475613551214, 0.20721861510537565, 0.22546838270500302], [0.05025351689255331, 0.04279935223166831, 0.006660426124653895, 0.09391693311044946, 0.10245907513308339, 0.039002250123303384, 0.014610392281610984, 0.058344102872069925, 0.041999936729553156, 0.010610378649289487, 0.04849047829338815, 0.013369276457524393, 1.6037067957222462, 42.27889493107796, 53.3872264623642, 40.61427645385265, 32.47291311621666, 35.56329108774662, 38.46809081733227, 53.605893328785896, 49.20671358704567, 55.7410329580307, 19.820211455225945, 0.25289228302426636, 1.1393850110471249, 0.445358160068281, 0.41018359595909715, 2.272937335073948, 49.87806536257267, 52.97962233424187, 49.87421236932278, 46.598643735051155, 51.85327157378197, 49.304877519607544, 54.08879801630974, 48.66713874042034, 47.47671581804752, 42.466715052723885, 39.83244180679321, 35.24921894073486, 36.49174086749554, 35.208462327718735, 35.54535984992981, 34.688266441226006, 35.15016205608845, 34.902749732136726, 34.283937737345695, 34.342883974313736, 35.11885553598404, 34.68824744224548, 36.10455684363842, 36.27250783145428, 37.46045708656311, 36.03059381246567, 36.665919721126556, 37.120755314826965, 38.538216054439545, 37.20397084951401, 36.913757622241974, 37.26014323532581, 37.23287969827652, 35.521276742219925, 35.31533159315586, 36.594126373529434, 34.72883306443691, 35.27864836156368, 35.49978889524937, 38.23874652385712, 39.9340483546257, 37.51821018755436, 38.117810413241386, 38.09585519134998, 40.3369977325201, 38.73638682067394, 38.25649917125702, 37.402073219418526, 38.954609110951424, 38.085884526371956, 39.15347523987293, 38.06365951895714, 36.88293747603893, 34.01870056986809, 37.91068732738495, 42.74391397833824, 43.468725085258484, 41.41756854951382, 46.46840952336788, 52.68373221158981, 47.624220103025436, 46.4269233494997, 50.92811621725559, 48.590797036886215, 42.47120261192322, 42.32725493609905, 39.21440877020359, 36.887603625655174, 34.95976947247982, 37.112684547901154, 36.46612264215946, 39.265588223934174, 38.18129740655422, 38.56751628220081, 39.93340238928795, 38.6774405837059, 37.48344585299492, 40.4945220798254, 38.88296015560627, 40.02323716878891, 38.66983339190483, 38.464161828160286, 39.002862721681595, 38.48479472100735, 37.13463976979256, 37.736873254179955, 36.14214062690735, 35.623381063342094, 35.723247304558754, 37.78669238090515, 37.06579886376858, 36.02037616074085, 37.62951761484146, 37.63849653303623, 35.49850836396217, 38.05084280669689, 35.0128336250782, 37.20778204500675, 40.28911270201206, 46.389863938093185, 49.2966053634882, 52.04111069440842, 50.36984257400036, 50.81629581749439, 48.76462250947952, 51.32084794342518, 48.78310091793537, 47.962827533483505, 47.015732154250145, 54.434058889746666, 50.48861660063267, 49.12471778690815, 44.18398730456829, 46.14684417843819, 42.85525180399418, 44.3335472792387, 39.1438427567482, 42.753573060035706, 40.04746086895466, 46.81956768035889, 43.83274935185909, 58.831680715084076, 54.61591713130474, 69.3423119187355, 19.13116592913866, 0.03670274636533577, 0.722598081920296, 0.3207913739606738, 0.18420418520690873, 21.977944672107697, 64.25924107432365, 54.97968681156635, 45.73599882423878, 40.25250926613808, 31.882402002811432, 26.18008028715849, 49.710938930511475, 31.76283571869135, 2.6105874544009566, 0.22000909986672923, 0.015745516429888085, 0.14200075529515743, 0.0316759389534127, 0.10476832700078376, 0.025514476801618002, 0.11224942049011588, 0.036474925582297146, 0.04365845496067777, 0.056698008193052374, 0.03046475765586365, 0.007553798450317117, 0.0030095881038505468, 0.06512188527267426, 0.030714701861143112, 0.06833749241195619, 0.037504217616515234, 0.02870708478440065, 0.02506085944332881, 0.07344309735344723, 0.03289782202045899, 1.5643901866860688, 48.917400911450386, 59.86723154783249, 45.33679984509945, 27.59068999439478, 35.69026507437229, 43.68388094007969, 59.03116621077061, 53.266769126057625, 60.49466148018837, 22.508153021335602, 0.19855242309859022, 1.1248037684708834, 3.5004776157438755, 1.2308685458265245, 2.747836564667523, 54.24285314977169, 55.792763382196426, 52.13987119495869, 48.2413449883461, 55.927462354302406, 50.70066422224045, 56.730150282382965, 51.1525359749794, 49.494285956025124, 46.029628068208694, 43.12634065747261, 38.95869769155979, 38.03711034357548, 37.280631735920906, 39.01975281536579, 36.803130358457565, 37.0794515311718, 37.2067105025053, 35.987792909145355, 36.94046638906002, 36.39162763953209, 37.32100076973438, 38.46432901918888, 38.87765944004059, 38.59071023762226, 37.41882272064686, 37.671976536512375, 39.23075549304485, 38.32115650177002, 39.542661756277084, 38.19759093225002, 39.59244668483734, 38.75765047967434, 36.62546329200268, 37.55787245929241, 36.40977166593075, 36.288550570607185, 36.617810502648354, 37.880285158753395, 39.49943147599697, 40.703742653131485, 38.52748163044453, 40.4382698982954, 39.952264577150345, 41.650613844394684, 40.62284119427204, 40.09942688047886, 38.65893937647343, 40.35250850021839, 40.19376441836357, 40.78896827995777, 40.134514197707176, 39.35965217649937, 35.597485452890396, 38.75031307339668, 43.16734805703163, 44.936464726924896, 44.38963606953621, 48.35777074098587, 53.588193878531456, 52.731522247195244, 48.692601174116135, 53.29022906720638, 50.34941866993904, 47.60924130678177, 43.83892402052879, 41.17929473519325, 37.96248994767666, 36.3783473521471, 38.22798930108547, 38.8798975199461, 40.251794904470444, 39.7274724394083, 40.83458483219147, 41.90729767084122, 40.40987402200699, 40.49020551145077, 42.30493113398552, 40.486857891082764, 40.91347999870777, 41.718307211995125, 40.84955982863903, 40.53587906062603, 39.387090504169464, 37.45377704501152, 39.027439802885056, 38.92566226422787, 38.135817646980286, 38.25617618858814, 39.99314658343792, 38.58065217733383, 38.90805020928383, 38.68791662156582, 39.2466576397419, 37.01202034950256, 39.17696937918663, 37.9083314538002, 39.39082570374012, 43.2509283721447, 47.9087982326746, 52.28057004511356, 53.94300363957882, 52.63346090912819, 50.70979133248329, 50.450763031840324, 51.628840416669846, 50.025125071406364, 49.08534049987793, 50.70004865527153, 56.05703540146351, 50.93894563615322, 51.051841378211975, 46.88732944428921, 47.9828030616045, 46.45195260643959, 46.98654592037201, 41.20100677013397, 44.587590247392654, 42.724082842469215, 49.402034506201744, 47.78269819915295, 61.411962658166885, 55.60479126870632, 70.90131506323814, 19.89203330129385, 0.017938189885171596, 1.284375968389213, 0.9207198664080352, 0.2230386802693829, 22.846146784722805, 71.24815285205841, 61.16177648305893, 51.37658715248108, 45.498583763837814, 30.731922537088394, 28.032083809375763, 56.271248906850815, 41.602337434887886, 4.3770041316747665, 0.2924042253289372, 0.0516234176029684, 0.06360804502037354, 0.023724674501863774, 0.05894779918889981, 0.03127201765892096, 0.08219542301958427, 0.045902653873781674, 0.011445026684668846, 0.17679406329989433, 0.1274756932980381, 0.09381839074194431, 0.26136312691960484, 0.1835282816318795, 0.1634749022196047, 0.19876524136634544, 0.20084623829461634, 0.12744023348204792, 0.11531944051967002, 0.15156678651692346, 0.15432744228746742, 1.7630476830527186, 53.41137036681175, 65.44978559017181, 55.138476490974426, 42.407187446951866, 48.014896139502525, 51.53608359396458, 64.65473145246506, 58.07182028889656, 65.63526883721352, 27.356461063027382, 0.27829587925225496, 2.915112851187587, 5.41890537366271, 1.754616885446012, 3.7435907078906894, 56.458221673965454, 58.62963795661926, 55.79362213611603, 51.00481890141964, 56.244467943906784, 54.49967756867409, 58.480670750141144, 51.55372604727745, 53.425220623612404, 47.93652154505253, 45.08343704044819, 40.33738911151886, 40.23828282952309, 39.470245242118835, 39.80669818818569, 39.08808834850788, 38.99946190416813, 39.976815059781075, 38.71080279350281, 39.42071110010147, 38.88849265873432, 38.899816051125526, 40.31954526901245, 40.11221319437027, 41.03196904063225, 39.33149188756943, 40.16355603933334, 43.24856109917164, 42.314616814255714, 41.3066753000021, 40.94432674348354, 41.31614439189434, 41.0800364613533, 38.11505936086178, 38.3318605273962, 39.376698061823845, 37.671315371990204, 38.66788029670715, 39.94761362671852, 41.40433385968208, 42.966631427407265, 41.52617432177067, 42.722821310162544, 43.39084066450596, 43.48457783460617, 42.51418210566044, 42.16366991400719, 40.60798019170761, 42.947389259934425, 41.622248366475105, 43.68956923484802, 42.2520037740469, 42.722186744213104, 37.753827944397926, 42.936445847153664, 47.00989566743374, 47.113516107201576, 46.10829144716263, 50.97052574157715, 56.005700156092644, 52.55072794854641, 49.28367845714092, 54.56848047673702, 52.71061196923256, 49.20457050204277, 46.25729285180569, 42.39371716976166, 41.92305162549019, 40.17968997359276, 41.805181950330734, 40.18553406000137, 43.140434101223946, 41.22021093964577, 42.82138042151928, 44.633073806762695, 43.05307298898697, 40.86465261876583, 44.85759615898132, 41.89109534025192, 42.12289050221443, 43.251927718520164, 40.4567901045084, 43.54561775922775, 41.975872591137886, 39.883936643600464, 42.86408632993698, 40.08072808384895, 38.618129566311836, 39.38118562102318, 42.40899235010147, 40.48880338668823, 40.713663920760155, 41.314407885074615, 41.28096207976341, 39.64975140988827, 42.13048629462719, 40.08823648095131, 40.91215007007122, 44.58439081907272, 50.20128361880779, 55.158155634999275, 55.843175277113914, 54.75021332502365, 53.41815300285816, 51.622829139232635, 54.41392756998539, 52.166538164019585, 52.903584614396095, 53.139684945344925, 56.431459710001945, 51.83568611741066, 54.67238590121269, 50.045001804828644, 50.30665956437588, 48.11860777437687, 50.84771253168583, 44.24018628895283, 46.70005649328232, 43.3815311640501, 52.27870434522629, 47.57474295794964, 65.04483371973038, 59.06796343624592, 73.43271642923355, 22.64654539525509, 0.16794521390693262, 1.7915164679288864, 1.7836875817738473, 0.25574254570528865, 26.328253336250782, 77.197957187891, 66.09524935483932, 59.74267043173313, 55.53184278309345, 42.992853820323944, 39.92670334875584, 65.44662415981293, 52.86202244460583, 6.595361195504665, 0.5047546431887895, 0.1080750698747579, 0.1483852884848602, 0.12827013269998133, 0.21477418311405927, 0.09908573192660697, 0.29502991412300617, 0.12005940414383076, 0.1287443353794515], [0.038286303970380686, 0.08300545494421385, 0.056620078976266086, 0.0214670352943358, 0.07705054362304509, 0.012806247978005558, 0.06943177431821823, 0.015657096955692396, 0.027015416671929415, 0.060222189204068854, 0.015384855851152679, 0.03704623828525655, 0.2861809608293697, 25.516829676926136, 56.35560818016529, 45.668913424015045, 31.47265288978815, 27.69178356975317, 35.20905129611492, 49.641824439167976, 53.10483321547508, 52.38415248692036, 33.35965633392334, 0.18256549345096573, 0.7862482289783657, 4.187415204942226, 1.5141923865303397, 0.38148346880916506, 40.29796242713928, 56.49868190288544, 49.39487189054489, 49.080670550465584, 51.22375935316086, 52.20200926065445, 50.611540004611015, 49.45110887289047, 45.984908267855644, 43.32024805247784, 37.92295686900616, 35.43597511947155, 35.382067412137985, 35.01520089805126, 36.721776723861694, 35.28414286673069, 36.37377239763737, 34.66353356838226, 34.06874768435955, 34.57907170057297, 37.38285765051842, 35.78302949666977, 36.67783588171005, 35.54746873676777, 36.47621110081673, 36.170855686068535, 38.45690421760082, 36.52075611054897, 37.341960445046425, 37.0516712218523, 35.85590198636055, 36.462987810373306, 35.43106958270073, 38.22374872863293, 37.99395985901356, 37.01366566121578, 36.88130736351013, 35.92927224934101, 37.469850182533264, 37.960901632905006, 36.887425035238266, 37.61466421186924, 37.38963268697262, 38.39168071746826, 37.92518734931946, 37.97198183834553, 37.14249774813652, 38.2769762724638, 37.75657519698143, 38.152358159422874, 38.9888870716095, 38.03424909710884, 35.517940521240234, 33.46644200384617, 35.41311174631119, 40.34261003136635, 41.29071615636349, 42.577661499381065, 47.22973667085171, 50.51748365163803, 48.39339762926102, 44.39148657023907, 51.515545696020126, 49.98632535338402, 43.18504750728607, 41.2252988666296, 39.65219467878342, 37.35358402132988, 34.98510651290417, 38.024407625198364, 39.379844292998314, 39.37354803085327, 37.565901428461075, 38.00439029932022, 39.80229802429676, 39.71541188657284, 38.58547031879425, 38.69967319071293, 39.974310994148254, 38.4580859541893, 38.720602467656136, 37.82248266041279, 37.66820713877678, 37.47360818088055, 36.72396540641785, 38.317979872226715, 37.1351033449173, 35.541085079312325, 36.56986087560654, 38.318443447351456, 36.43395356833935, 36.151054948568344, 35.39982005953789, 35.54793991148472, 35.458762496709824, 37.014877796173096, 38.009033650159836, 36.82269550859928, 37.75971382856369, 42.37431161105633, 44.67948451638222, 49.031037613749504, 47.951036766171455, 48.995125740766525, 49.91683468222618, 54.100167006254196, 52.837221175432205, 55.251474827528, 47.042076140642166, 44.63647082448006, 48.315387815237045, 54.84172001481056, 51.24695710837841, 47.071015387773514, 47.03103393316269, 48.907992616295815, 45.45310780405998, 43.930955082178116, 39.71470892429352, 44.38637584447861, 46.247086599469185, 59.26242180168629, 54.30995374917984, 61.362493112683296, 8.962368182837963, 0.04171782413322944, 0.22970564517891034, 0.440756221069023, 0.3179754875600338, 24.235251545906067, 66.82879999279976, 57.212025225162506, 51.41614302992821, 29.481360241770744, 23.37211076170206, 33.58037129044533, 48.901046589016914, 34.350095987319946, 0.578188612125814, 0.22958115732762963, 0.04368468617030885, 0.1085884876374621, 0.019485766315483488, 0.06653255957644433, 0.0384920607029926, 0.04996544485038612, 0.021595373036689125, 0.03206220455467701, 0.028873377814306878, 0.03654054999060463, 0.03387385011592414, 0.053892474752501585, 0.02919159218436107, 0.03818609176960308, 0.0927256302384194, 0.02175748406443745, 0.07607858249684796, 0.02551220026361989, 0.0634780281689018, 0.08768767205765471, 0.477861140971072, 30.591917149722576, 62.34939515590668, 49.51451987028122, 34.24040347337723, 35.634058490395546, 45.44091045856476, 53.42129163444042, 57.140231877565384, 58.54819692671299, 35.23031875491142, 0.20963397924788296, 0.9234272805042565, 2.9364924039691687, 2.307758666574955, 0.7836200168821961, 44.118999391794205, 59.310561418533325, 52.94453501701355, 51.53679035604, 52.3152431845665, 53.21926027536392, 52.35435448586941, 51.93168796598911, 47.80240014195442, 44.19416315853596, 39.94268909096718, 37.810954079031944, 37.85510390996933, 36.29440985620022, 38.23927849531174, 36.86521142721176, 38.48495811223984, 36.292091980576515, 36.813883781433105, 36.88294127583504, 39.5101734995842, 37.93315552175045, 39.29561421275139, 37.736702263355255, 37.95929431915283, 40.08786790072918, 39.771903455257416, 38.63489426672459, 39.57453064620495, 40.22955849766731, 38.27408082783222, 39.52490530908108, 38.790446519851685, 38.05721886456013, 38.59152339398861, 37.836861088871956, 36.64558321237564, 36.78863413631916, 38.70105251669884, 39.64850127696991, 38.934785574674606, 40.315912663936615, 39.28760424256325, 41.21567018330097, 41.12228259444237, 39.1162334382534, 39.80194844305515, 39.971867725253105, 38.35790432989597, 40.10751284658909, 40.85761159658432, 39.37851816415787, 38.42470094561577, 35.549490228295326, 38.759189397096634, 43.69247987866402, 43.39268356561661, 44.49579857289791, 50.38588151335716, 53.33967961370945, 50.03445357084274, 47.266685888171196, 53.03960591554642, 53.977859169244766, 45.3562206029892, 42.68054477870464, 40.87484747171402, 39.200159534811974, 37.47670121490955, 39.749864637851715, 40.76390102505684, 40.71483425796032, 41.302563920617104, 40.70617072284222, 42.58754476904869, 41.143204271793365, 40.851862505078316, 40.01660272479057, 41.713872849941254, 40.06514512002468, 39.27366279065609, 40.3839860111475, 37.32163913547993, 39.80485908687115, 37.54106596112251, 40.719033032655716, 38.67076434195042, 37.6776572316885, 38.01169350743294, 39.8241962492466, 37.31337457895279, 38.664905056357384, 39.35183219611645, 37.49557100236416, 38.42881232500076, 38.63832548260689, 38.10494430363178, 38.45940448343754, 39.780365601181984, 44.88057352602482, 46.98460042476654, 51.517456993460655, 50.17383769154549, 51.133810579776764, 52.787193059921265, 55.71036100387573, 54.238004609942436, 58.11929494142532, 48.62528778612614, 48.299994841217995, 50.8568624407053, 53.404032960534096, 51.71142138540745, 51.07957608997822, 47.92137935757637, 52.47685991227627, 47.36683331429958, 46.42228379845619, 41.357805356383324, 46.28916934132576, 47.83472880721092, 62.25250795483589, 57.09259383380413, 64.7232037782669, 9.469884149730206, 0.11708856472978368, 1.9287064438685775, 0.1786076941061765, 0.4066505574155599, 25.57390071451664, 71.41631662845612, 62.51132346689701, 56.45389370620251, 36.18005879223347, 31.07335701584816, 39.3995576351881, 57.887697368860245, 44.0202920883894, 1.3389630080200732, 0.21649403613992035, 0.05850324530911166, 0.15972908993717283, 0.02438266819808632, 0.12738562625600025, 0.06652903437498026, 0.04351568430138286, 0.022794563083152752, 0.07750472315819934, 0.10298436725861393, 0.11395331734092906, 0.11170112178660929, 0.1666890102205798, 0.15134017914533615, 0.15203456219751388, 0.1547971327090636, 0.14700293453643098, 0.19237267813878134, 0.16930940008023754, 0.10066908173030242, 0.12191599045763724, 0.5086052615661174, 34.894165992736816, 71.45020321011543, 57.85859853029251, 42.19748429954052, 38.05560775101185, 50.17039507627487, 60.02619981765747, 64.16745319962502, 63.01200360059738, 41.97171941399574, 0.30790629505645484, 3.348760069347918, 12.73054713383317, 3.848580024205148, 0.9887841297313571, 44.78912763297558, 61.874139457941055, 53.719256445765495, 52.737852707505226, 56.53341203927994, 55.41914843022823, 55.54422251880169, 54.79235306382179, 50.7479564845562, 48.22410151362419, 42.292141020298004, 41.09132565557957, 41.04283645749092, 40.053802728652954, 41.99616350233555, 39.63205575942993, 41.50590240955353, 39.443859457969666, 38.642079681158066, 39.283074885606766, 41.6861305385828, 41.59129902720451, 43.2965487241745, 40.12772776186466, 39.739418998360634, 41.54240325093269, 41.22929625213146, 40.79111896455288, 41.21257334947586, 42.41412207484245, 41.26548931002617, 41.72434888780117, 40.36051467061043, 40.69700561463833, 40.73973812162876, 41.37388229370117, 40.19366942346096, 39.69906896352768, 39.71450753509998, 41.87727548182011, 40.06853833794594, 41.924077570438385, 41.59837044775486, 42.884681224823, 41.27187676727772, 40.88173650205135, 40.95502316951752, 41.51394657790661, 41.245445385575294, 42.12207354605198, 43.61695133149624, 42.664494439959526, 41.81481823325157, 37.72064432501793, 40.652000829577446, 46.19030624628067, 45.290009155869484, 47.96384587883949, 53.00265669822693, 53.25924172997475, 50.092681646347046, 48.83572429418564, 56.81860573589802, 56.03863678872585, 46.94030620157719, 44.6527149528265, 43.52337755262852, 42.81841278076172, 39.533846229314804, 43.07840622961521, 43.26012767851353, 43.417051658034325, 42.888572216033936, 41.387451365590096, 44.60832953453064, 43.08058351278305, 42.372259721159935, 42.434283792972565, 44.35637645423412, 41.68489180505276, 40.86243353784084, 40.4583366215229, 39.0335688740015, 41.6125550866127, 40.27615159749985, 43.258307576179504, 42.533013895154, 39.613098576664925, 40.43010413646698, 42.27624647319317, 39.36416633427143, 40.251711308956146, 41.46572716534138, 39.94289048016071, 40.719048231840134, 39.985193610191345, 41.40137001872063, 40.18090210855007, 41.26536011695862, 47.84351013600826, 48.34894381463528, 53.59906889498234, 54.391824156045914, 52.96836733818054, 54.9492010474205, 57.86452241241932, 57.70846098661423, 60.41837677359581, 51.40057526528835, 50.026086419820786, 51.206846460700035, 54.99157257378101, 54.16570208966732, 52.074887081980705, 51.697441935539246, 54.898420572280884, 51.58391922712326, 49.00094322860241, 43.448042795062065, 48.443904519081116, 51.07599288225174, 64.41776856780052, 61.07147432863712, 65.43661549687386, 11.439488511532545, 0.10776992101455107, 2.84530489705503, 1.1349358060397208, 0.5626119417138398, 29.535733424127102, 78.83177071809769, 68.79121989011765, 61.21901661157608, 42.85874381661415, 34.81670714914799, 46.98152258992195, 66.21178910136223, 55.43916575610638, 2.5715336250141263, 0.30147416051477194, 0.12926940486067906, 0.17689457978121936, 0.15620682737790048, 0.17023218650138006, 0.15906112734228373, 0.09945318408426829, 0.12233183064381592, 0.19601340231020004], [0.05188461276702583, 0.040249804078484885, 0.02999049745994853, 0.053515025865635835, 0.027043842783314176, 0.02251978661661269, 0.06859990098746493, 0.025227002188330516, 0.03375168518687133, 0.07768269759253599, 0.04990385401470121, 0.07099594702594914, 0.019715208691195585, 14.113652966916561, 51.4712742716074, 43.87287139892578, 29.85016655176878, 18.38470548391342, 36.35165378451347, 52.8551372140646, 54.89198371767998, 48.273635655641556, 46.89283914864063, 1.5958782657980919, 0.5682606948539615, 2.562498184852302, 0.5246922327205539, 0.08339652224094607, 22.469773180782795, 59.11017157137394, 52.02460058033466, 53.72206449508667, 51.24785006046295, 55.83554908633232, 47.9914627969265, 47.749115601181984, 42.60400928556919, 40.847899317741394, 37.38285765051842, 36.54517740011215, 35.95403932034969, 36.03312447667122, 35.53949676454067, 37.080975249409676, 35.925905629992485, 35.30349142849445, 35.246365293860435, 35.527329817414284, 36.57285891473293, 36.02709800004959, 34.59056608378887, 35.90333104133606, 36.86149522662163, 38.54300759732723, 37.860176637768745, 38.78739908337593, 38.91371950507164, 36.9547688215971, 36.490350142121315, 36.75835736095905, 36.07179880142212, 37.37491227686405, 36.85287348926067, 35.25240316987038, 35.945782363414764, 36.36820949614048, 37.11311012506485, 39.54731270670891, 37.30551280081272, 38.95565025508404, 36.729349717497826, 37.75825470685959, 38.303350657224655, 37.840007320046425, 38.3388901501894, 39.40674304962158, 36.551644653081894, 37.87661075592041, 37.1947905421257, 37.27295994758606, 35.27191512286663, 33.82214091718197, 34.30140919983387, 39.84962448477745, 41.460665836930275, 39.95472304522991, 44.92339342832565, 54.1641403734684, 45.77908471226692, 46.30259022116661, 52.626879662275314, 48.77562291920185, 43.968326076865196, 42.04340636730194, 39.51382130384445, 37.43388891220093, 34.20563913881779, 38.37568737566471, 38.94168220460415, 42.024046406149864, 39.87389758229256, 38.63674856722355, 39.1546493768692, 37.87969619035721, 39.834406301379204, 39.30770896375179, 40.09736739099026, 38.80154572427273, 37.579527497291565, 37.80271992087364, 37.02154263854027, 36.69123016297817, 36.882245913147926, 36.45495504140854, 36.29768908023834, 37.042506113648415, 37.7848494797945, 35.774715542793274, 35.81627771258354, 36.830314099788666, 37.88767956197262, 38.07958446443081, 37.19524271786213, 38.65509778261185, 35.39695501327515, 35.48805512487888, 34.85417313873768, 36.529556438326836, 38.81150878965855, 41.99563153088093, 44.790514558553696, 45.79299956560135, 46.39584481716156, 48.08919355273247, 47.998089641332626, 50.296050533652306, 52.62371063232422, 51.18282414972782, 48.30398082733154, 47.03702621161938, 46.61985419690609, 48.53580258786678, 50.35956412553787, 52.86055192351341, 50.28288044035435, 49.449387565255165, 41.31288416683674, 43.60135696828365, 45.907088443636894, 55.85264056921005, 55.29422253370285, 55.07831811904907, 3.2834527362138033, 0.10737938806414604, 0.4816974507411942, 0.6534150161314756, 0.2893568779109046, 23.815235383808613, 63.100193068385124, 49.70174342393875, 46.04165442287922, 39.45289917290211, 28.255819603800774, 33.804053887724876, 48.34777347743511, 27.936469539999962, 0.3270671528298408, 0.06992872382397763, 0.06839737630798481, 0.07825031440006569, 0.0515316807286581, 0.04571930257952772, 0.010303477392881177, 0.02772948890196858, 0.022923481556063052, 0.016164289954758715, 0.037395255494629964, 0.06101103652326856, 0.04414845425344538, 0.02255939874885371, 0.007730838242423488, 0.018750145827652887, 0.010098389520862838, 0.028156472435512114, 0.03525690168316942, 0.00665871872115531, 0.028612462810997386, 0.07327537940000184, 0.04891320189926773, 19.162295758724213, 57.66423895955086, 52.7065309882164, 36.44914135336876, 21.99387151747942, 44.1912867128849, 57.31821812689304, 60.17270475625992, 53.79314348101616, 49.221004620194435, 1.4095594198442996, 0.39731751603540033, 1.6246540029533207, 2.0719081722199917, 0.43851805210579187, 25.43236020952463, 61.07837475836277, 54.264261201024055, 55.24889476597309, 53.99150803685188, 57.129847034811974, 49.53840918838978, 51.270344853401184, 45.19820608198643, 43.90135087072849, 41.229805424809456, 38.75005088746548, 37.751795053482056, 39.61697056889534, 36.77622400224209, 39.41973075270653, 37.3784688860178, 37.37236641347408, 37.76158332824707, 38.43411684036255, 38.03341694176197, 38.54968003928661, 37.0250878483057, 39.45754632353783, 38.66707094013691, 39.76491943001747, 40.48292130231857, 39.87631805241108, 39.78853136301041, 38.44064489006996, 39.053354412317276, 38.40841501951218, 38.405154794454575, 38.89605425298214, 38.8590594381094, 36.931293681263924, 37.57483094930649, 38.69136683642864, 39.65034797787666, 39.91602972149849, 40.60759261250496, 40.221996903419495, 38.26579347252846, 39.53908994793892, 39.338213726878166, 41.490798220038414, 38.99073377251625, 41.93195454776287, 40.14442406594753, 39.30732898414135, 39.652681052684784, 38.93024101853371, 36.09947271645069, 35.11421978473663, 38.260971531271935, 42.730926275253296, 42.71749019622803, 42.69012026488781, 46.644229888916016, 54.621100053191185, 47.58741907775402, 48.9756365865469, 53.454437255859375, 49.56340044736862, 45.417188331484795, 45.27782700955868, 41.89455695450306, 39.330313950777054, 35.74258826673031, 39.10357251763344, 40.668343752622604, 41.854643896222115, 40.3325329720974, 39.77982982993126, 40.11068947613239, 39.88811641931534, 41.875508576631546, 40.38215450942516, 40.80618895590305, 39.28135737776756, 39.14061293005943, 40.89633911848068, 39.19310711324215, 39.531763941049576, 38.62385205924511, 39.142911806702614, 37.8514751046896, 38.94920200109482, 38.32584545016289, 37.43776470422745, 37.37799771130085, 38.36946330964565, 40.779050812125206, 39.526182040572166, 39.29392710328102, 39.36283640563488, 37.319074273109436, 36.458192467689514, 37.78636559844017, 38.861552104353905, 40.99397487938404, 45.0860171020031, 48.01745340228081, 48.47636617720127, 48.21738347411156, 50.97232684493065, 50.56997023522854, 53.83495643734932, 54.56543684005737, 52.7619244158268, 49.28446501493454, 51.74300529062748, 47.21475027501583, 51.08642712235451, 52.160549685359, 54.98895451426506, 51.466957703232765, 50.559847578406334, 45.15288211405277, 45.37469521164894, 47.609229907393456, 60.11886544525623, 58.8568277657032, 59.469005316495895, 3.7173284171149135, 0.03752933560463134, 6.787386741489172, 0.7250646245665848, 0.4012939432868734, 26.230646073818207, 71.38863891363144, 57.02949821949005, 54.74239334464073, 46.118972674012184, 28.229599110782146, 35.03848984837532, 56.94688305258751, 36.26972638070583, 0.6520822376478463, 0.10595807878416963, 0.03740276602911763, 0.07566033033072017, 0.03725830698385835, 0.07637225033249706, 0.03680981229990721, 0.008825061704555992, 0.05920187715673819, 0.02916603632911574, 0.12398302016663365, 0.20152514014625922, 0.17442536540329456, 0.1719619843061082, 0.16408230556407943, 0.17233725870028138, 0.12011824903311208, 0.09814621749683283, 0.24105945078190416, 0.156056304986123, 0.11648671264993027, 0.14981046435423195, 0.13542936416342854, 21.095119044184685, 66.38915598392487, 58.757744282484055, 43.39783988893032, 27.34290149062872, 50.58711491525173, 63.03441099822521, 67.08920001983643, 58.333915024995804, 55.647960752248764, 2.4156066169962287, 1.4669866883195937, 5.97267578355968, 2.100136619992554, 0.6092806218657643, 26.993263252079487, 63.067815005779266, 56.08535908162594, 58.05885158479214, 55.66751830279827, 60.207028314471245, 52.3795585334301, 53.068476766347885, 46.78120493888855, 45.68068899214268, 42.43295006453991, 41.39451898634434, 40.48098720610142, 41.70917630195618, 40.309027433395386, 41.8202443420887, 39.40165892243385, 39.85989153385162, 40.88687002658844, 40.47649584710598, 41.20361343026161, 40.467049553990364, 39.18153673410416, 41.69373773038387, 41.28296077251434, 43.80903862416744, 41.64999067783356, 42.99834452569485, 42.386117577552795, 40.67369006574154, 40.757973343133926, 41.78836405277252, 40.675247982144356, 41.34010210633278, 41.96105718612671, 37.425054386258125, 38.90919774770737, 41.38386055827141, 41.1680169403553, 42.86879047751427, 41.62619635462761, 42.87984408438206, 39.61888566613197, 40.757046192884445, 41.85748994350433, 41.65145359933376, 41.63857229053974, 43.58258217573166, 41.58913314342499, 40.873471945524216, 41.25782512128353, 41.70643664896488, 38.796013221144676, 38.14339444041252, 40.68375952541828, 44.16040576994419, 44.78939361870289, 44.098358899354935, 48.5442229360342, 56.44082620739937, 50.2623425424099, 51.03838250041008, 55.171017944812775, 51.98703579604626, 48.013968989253044, 47.473732978105545, 42.68949329853058, 41.3698773086071, 38.202188685536385, 42.91170537471771, 41.84542179107666, 44.5312924683094, 43.222156316041946, 40.960688665509224, 41.81974656879902, 41.41645520925522, 45.693053528666496, 41.71693168580532, 42.89868727326393, 41.92329861223698, 40.52572600543499, 40.99158100783825, 41.745601147413254, 40.5472594499588, 40.96237197518349, 40.631196945905685, 39.71576526761055, 41.35821953415871, 41.22665919363499, 40.09221866726875, 38.76937285065651, 39.806436002254486, 42.91406884789467, 42.745384499430656, 41.453214436769485, 41.45810477435589, 38.96909013390541, 38.29414375126362, 39.041829630732536, 41.586249098181725, 42.29352414608002, 45.63916862010956, 50.245087668299675, 50.06121173501015, 51.08113020658493, 52.53851540386677, 52.40110717713833, 55.47727771103382, 55.93222729861736, 54.74175117909908, 53.377844765782356, 52.89154306054115, 50.310455560684204, 53.06710124015808, 53.14312756061554, 59.054633751511574, 53.49046692252159, 53.920858427882195, 46.48620776832104, 47.184424102306366, 51.45142413675785, 64.67333525419235, 59.616969376802444, 60.791752338409424, 4.12946498952806, 0.1983688899781555, 7.42904738523066, 1.9367305445484817, 0.42047234543133527, 28.965123742818832, 74.21277657151222, 62.670234739780426, 63.7210151553154, 55.005327835679054, 37.39106900990009, 44.9642526358366, 64.89711284637451, 45.82690514624119, 1.3588590966537595, 0.20896505186101422, 0.1611252033035271, 0.15011921263067052, 0.11797033264883794, 0.20034516986925155, 0.09594672184903175, 0.13007172587094828, 0.1789573792484589, 0.09976717192330398], [0.007590073237224715, 0.02465045177814318, 0.03903713106410578, 0.017682152647466864, 0.010707379205996403, 0.010163911883864785, 0.01852187604526989, 0.03711545839905739, 0.07865862178732641, 0.07425764895742759, 0.03028598912351299, 0.13245661742985249, 0.05762636072176974, 8.777301963418722, 53.71035732328892, 48.92691560089588, 31.74530155956745, 26.023648381233215, 35.649698451161385, 42.87537932395935, 57.6062198728323, 46.482586562633514, 54.584295228123665, 5.334201268851757, 0.20689276774646714, 0.8970430993940681, 2.41751981433481, 0.8892208628822118, 9.354869071394205, 50.86949296295643, 50.77561900019646, 54.610517621040344, 50.23037485778332, 53.63154195249081, 49.72183294594288, 49.110616743564606, 43.70115101337433, 40.82486115396023, 37.91389815509319, 37.17823103070259, 37.04826280474663, 36.63627751171589, 36.51956297457218, 38.47949780523777, 36.5231803804636, 36.2663521617651, 34.80084300041199, 36.74188904464245, 35.65616950392723, 37.52357929944992, 38.173257037997246, 41.93063221871853, 44.12285998463631, 45.72665512561798, 45.74926771223545, 47.74932458996773, 45.76219841837883, 40.31822293996811, 40.15925467014313, 38.851657435297966, 37.27613277733326, 38.03831867873669, 35.33014699816704, 35.740646570920944, 36.739939749240875, 36.22619591653347, 35.2700038254261, 37.3189564794302, 38.75108823180199, 39.013323560357094, 38.83294723927975, 38.02999712526798, 38.96886594593525, 36.720465794205666, 38.315434008836746, 39.59866315126419, 37.957736402750015, 37.379905208945274, 37.75910586118698, 39.40877594053745, 34.278602823615074, 34.801732152700424, 36.00836120545864, 38.958804085850716, 40.57986170053482, 41.53288476169109, 46.538401767611504, 53.61538141965866, 45.84755323827267, 49.47989992797375, 51.463382095098495, 46.50413900613785, 42.250423058867455, 42.452591210603714, 40.32297648489475, 37.98372320830822, 35.350278317928314, 34.78915102779865, 39.03920017182827, 38.83094474673271, 38.99196870625019, 39.24157351255417, 38.427003622055054, 38.71577672660351, 38.4161514043808, 39.449467957019806, 36.929743364453316, 37.60211728513241, 39.53734964132309, 38.117396235466, 37.39697769284248, 36.97744980454445, 36.32342129945755, 37.27112464606762, 37.18727834522724, 37.949829027056694, 36.69384442269802, 37.86402203142643, 37.68808387219906, 37.635532692074776, 37.0252588391304, 36.714488714933395, 36.29772327840328, 36.52382634580135, 36.0524882376194, 36.30813091993332, 35.89666619896889, 36.35301411151886, 35.34579835832119, 35.502110570669174, 37.283819764852524, 39.94312606751919, 41.73305422067642, 43.980192840099335, 47.52675153315067, 48.25027830898762, 49.56679746508598, 50.73083460330963, 52.11321182549, 52.61544607579708, 51.32118612527847, 55.116000697016716, 53.92416425049305, 53.38721126317978, 53.196925073862076, 53.351793363690376, 46.86124764382839, 44.12031792104244, 45.51380954682827, 53.21721978485584, 58.71693827211857, 43.75022158026695, 0.6225516472477466, 0.25103617168497294, 5.181233827024698, 0.27203847595956177, 0.24568846332840621, 32.13179022073746, 55.92540666460991, 44.58372585475445, 48.04560229182243, 24.863954409956932, 26.397022046148777, 41.067527532577515, 49.35383789241314, 19.320760555565357, 0.30123314063530415, 0.023391869508486707, 0.10036672334535979, 0.10874565225094557, 0.05576886898779776, 0.014363737645908259, 0.014079407883400563, 0.0009184587725030724, 0.03497131954645738, 0.08283233415568247, 0.023377547913696617, 0.035665205359691754, 0.039021026459522545, 0.043580848578130826, 0.020882950229861308, 0.020410510151123162, 0.03665353455289733, 0.06526506782392971, 0.04209078302665148, 0.005265125873847865, 0.028297576973272953, 0.09166808464215137, 0.03764169305213727, 11.79919146001339, 60.83661273121834, 52.43200711905956, 38.451538905501366, 28.231827691197395, 42.500974014401436, 49.72824700176716, 60.746827349066734, 53.472934663295746, 58.14154654741287, 5.946888942271471, 0.35314099746756256, 1.4253410417586565, 5.069204438477755, 1.4034270239062607, 12.307995557785034, 53.469169065356255, 51.66200503706932, 55.20192548632622, 49.90655243396759, 55.276895463466644, 53.18470112979412, 50.45752286911011, 45.14710262417793, 43.13500419259071, 40.60228429734707, 40.07918156683445, 39.50353905558586, 38.8142978399992, 39.11321260035038, 39.534514993429184, 38.64842914044857, 38.11455398797989, 37.304528653621674, 39.28109899163246, 37.41041757166386, 38.03264178335667, 39.72026042640209, 43.01583878695965, 45.20614005625248, 47.247580513358116, 47.27452866733074, 49.21487934887409, 47.045951932668686, 42.51193642616272, 41.48523151874542, 41.96038842201233, 38.34457844495773, 38.17155472934246, 37.77286112308502, 37.234015837311745, 40.60896433889866, 37.610218450427055, 36.807579919695854, 38.48757617175579, 39.92702253162861, 39.99451071023941, 40.16183093190193, 39.92885783314705, 40.95221891999245, 40.01323230564594, 39.75912094116211, 40.52207440137863, 39.297567307949066, 40.21240621805191, 39.57964517176151, 42.16537222266197, 36.20433188974857, 36.609709337353706, 37.14780606329441, 41.88446469604969, 42.72667050361633, 44.73167471587658, 47.11923860013485, 55.6334987282753, 47.57829576730728, 48.2666440308094, 54.203453063964844, 47.945135682821274, 44.8886176943779, 44.06684719026089, 42.76836186647415, 40.00570870935917, 36.34369321167469, 36.0587465018034, 39.83025312423706, 38.703906163573265, 40.380148217082024, 39.0246507525444, 39.856011942029, 40.21821230649948, 40.826187282800674, 40.79277567565441, 38.994115591049194, 40.57333365082741, 40.245156660676, 38.822801783680916, 39.445101991295815, 39.82124000787735, 37.34873168170452, 39.05636765062809, 39.01285998523235, 39.451550245285034, 38.54945585131645, 38.371762186288834, 40.14362990856171, 39.63429383933544, 38.73457811772823, 38.986364006996155, 38.53511922061443, 38.953100591897964, 37.18971021473408, 38.04485812783241, 38.053023889660835, 38.18497560918331, 38.11596751213074, 38.40334989130497, 39.65007819235325, 42.63053186237812, 44.89276707172394, 47.542668879032135, 48.961235359311104, 50.56039094924927, 51.37416288256645, 53.460748717188835, 54.32826116681099, 52.95298956334591, 51.56838946044445, 56.128273978829384, 55.47430247068405, 55.85942320525646, 54.881013706326485, 56.230895072221756, 47.88297101855278, 47.05112345516682, 47.53990262746811, 58.535399213433266, 58.360695987939835, 47.29320466518402, 0.8556496642995626, 1.008853584062308, 6.418052259832621, 0.25554145337082446, 0.1723981148097664, 34.16177809238434, 61.62358470261097, 51.17743983864784, 55.35627320408821, 34.83972631394863, 30.764826871454716, 44.383415803313255, 58.288150280714035, 27.46398389339447, 0.18829487351467833, 0.07456019287928939, 0.04691194131737575, 0.08339742766111158, 0.04886595306743402, 0.03391657184693031, 0.022700761182932183, 0.043923846969846636, 0.07289339599083178, 0.04642584201064892, 0.0835316970187705, 0.11383538265363313, 0.13505542563507333, 0.1148518206900917, 0.17423255543690175, 0.10016245461883955, 0.0662085750082042, 0.1003487262642011, 0.13012334966333583, 0.17279988387599587, 0.15849868330406025, 0.1817460882011801, 0.148216865491122, 12.601128928363323, 69.73501324653625, 61.17030702531338, 46.399314031004906, 35.04208065569401, 48.07677201926708, 54.160492569208145, 66.95545479655266, 56.887651830911636, 66.42606720328331, 7.303642239421606, 0.6272211216855794, 4.90365207195282, 9.314764123409986, 1.809590079355985, 12.03422024846077, 55.30293546617031, 51.70268565416336, 57.68655136227608, 51.68757006525993, 57.66351319849491, 56.201602444052696, 54.19477432966232, 48.36564391851425, 45.415843203663826, 45.84642469882965, 42.978293001651764, 43.05234342813492, 41.52674809098244, 42.282915115356445, 43.799710124731064, 41.98835112154484, 40.83703190088272, 38.74619409441948, 41.359830647706985, 38.71912054717541, 40.777926072478294, 42.64258861541748, 45.65453499555588, 48.90724405646324, 48.99101436138153, 50.52233599126339, 51.86663545668125, 49.05262045562267, 44.41446393728256, 45.08612349629402, 44.33178037405014, 40.345060899853706, 40.70385284721851, 39.22994613647461, 38.63176703453064, 41.64684444665909, 40.47172710299492, 38.1034129858017, 39.21129293739796, 42.850608453154564, 42.34056942164898, 42.65833497047424, 42.476472929120064, 41.00999101996422, 41.043003648519516, 41.15277975797653, 43.71771812438965, 40.735212564468384, 39.92853485047817, 42.13462047278881, 44.58932675421238, 38.45292583107948, 38.99997867643833, 39.732499569654465, 42.81897135078907, 44.14690509438515, 46.30892068147659, 51.873619481921196, 55.538207441568375, 50.456432327628136, 52.421736270189285, 55.42764097452164, 50.6967618316412, 45.68923853337765, 46.38110160827637, 45.12427344918251, 43.368087485432625, 39.22304190695286, 39.11038175225258, 42.518217489123344, 41.004542112350464, 42.86301478743553, 41.454981341958046, 41.360962986946106, 40.80749608576298, 42.21128135919571, 41.80529214441776, 39.66879218816757, 41.66094928979874, 42.58054934442043, 40.68435229361057, 40.03343962132931, 42.51914083957672, 38.60658958554268, 42.948555797338486, 41.40135481953621, 42.29871466755867, 40.05463868379593, 41.964628994464874, 43.185119703412056, 42.0288797467947, 41.52661509811878, 42.05654226243496, 40.55052727460861, 40.80473743379116, 39.46004278957844, 40.993085727095604, 40.093806982040405, 40.76884835958481, 40.01243434846401, 39.34044420719147, 42.25464083254337, 43.57217453420162, 46.70876182615757, 48.081293776631355, 51.71115919947624, 52.50538118183613, 55.42249985039234, 56.91246069967747, 56.477387845516205, 57.18690097332001, 53.68840590119362, 58.607112765312195, 57.52599477767944, 56.59842275083065, 57.071915343403816, 59.34822499752045, 52.32319235801697, 49.18642267584801, 49.65850554406643, 59.78548273444176, 60.85418298840523, 52.165364027023315, 1.0939324437640607, 0.9875560831278563, 13.891058061271906, 0.6060933053959161, 0.42334905825555325, 37.9181045293808, 68.50604519248009, 57.51000143587589, 65.08758142590523, 37.72322058677673, 38.99503134191036, 51.74639470875263, 69.24841895699501, 36.629198491573334, 0.6446082168258727, 0.1494231226388365, 0.24604276462923735, 0.1954382230178453, 0.1589105901075527, 0.1115259452490136, 0.14550554769812152, 0.1549149857601151, 0.1270198216661811, 0.2291726050316356], [0.012656315593631007, 0.020307908234826755, 0.009616397073841654, 0.021672493312507868, 0.03746417503862176, 0.03457400707702618, 0.06003314563713502, 0.0637149959220551, 0.031612763632438146, 0.04099282006791327, 0.05418071377789602, 0.08527588506694883, 0.04516373825026676, 4.826618805527687, 41.29069335758686, 46.41307309269905, 35.96369840204716, 16.226377598941326, 33.467175364494324, 45.67545287311077, 57.0111034065485, 47.039674669504166, 52.87064418196678, 12.843119893223047, 0.43583777092862874, 0.4876868793508038, 2.5079091265797615, 1.2109869439154863, 2.478147461079061, 37.670749202370644, 51.4184533059597, 53.417890816926956, 50.28307043015957, 53.15082974731922, 49.91623051464558, 48.12996156513691, 42.719675078988075, 41.44322097301483, 36.173317953944206, 36.192723512649536, 35.01065634191036, 36.96632020175457, 36.02375417947769, 35.894101336598396, 35.001312643289566, 35.07094770669937, 35.561854764819145, 37.70533874630928, 37.60403998196125, 41.00866109132767, 47.37467609345913, 49.87891271710396, 47.36430644989014, 50.32458320260048, 50.282732248306274, 51.17426700890064, 47.441704496741295, 47.53527447581291, 44.79599766433239, 40.3616888076067, 37.55278833210468, 37.815886214375496, 35.297901928424835, 36.00415863096714, 35.71100436151028, 35.277922600507736, 35.977332070469856, 38.63814689218998, 38.72312553226948, 37.851722091436386, 38.44184182584286, 38.07499811053276, 39.14565905928612, 38.06558981537819, 38.49099598824978, 39.407096430659294, 38.951994851231575, 38.24180155992508, 38.141673132777214, 38.455809876322746, 35.77912710607052, 34.955236315727234, 35.6945588439703, 38.43533277511597, 40.225409120321274, 41.088529005646706, 48.362121507525444, 50.16448639333248, 43.693935200572014, 46.18071936070919, 52.342681512236595, 50.27628019452095, 42.67032712697983, 42.17258423566818, 40.22411718964577, 37.72268861532211, 35.49606129527092, 36.81261084973812, 38.974949419498444, 39.53634649515152, 39.38118562102318, 39.612095430493355, 40.26700168848038, 40.466810166835785, 39.68353159725666, 41.07876352965832, 40.188098922371864, 37.70236350595951, 39.31468538939953, 38.84716987609863, 38.98490488529205, 36.43141150474548, 36.82668909430504, 36.05952546000481, 37.480527609586716, 36.738499626517296, 37.712820544838905, 38.02069902420044, 35.78214414417744, 36.70836344361305, 35.668632835149765, 37.744488045573235, 35.85479624569416, 36.53015300631523, 36.126067489385605, 34.12127986550331, 34.78836067020893, 35.37054643034935, 35.31769886612892, 35.29376395046711, 36.11720636487007, 36.42378531396389, 38.29171188175678, 41.586370691657066, 41.29280984401703, 43.64127762615681, 47.20256432890892, 45.915371999144554, 47.94501028954983, 52.60653555393219, 52.082707062363625, 50.64432084560394, 54.14463222026825, 53.058718889951706, 55.421139523386955, 52.505061998963356, 52.751881554722786, 47.932736948132515, 49.148303121328354, 52.39381156861782, 59.99690338969231, 29.799617864191532, 0.17374722054228187, 0.07975041749887168, 8.238654267042875, 0.3606099123135209, 0.2943725197110325, 36.7889267206192, 65.0472503900528, 49.37162093818188, 46.472365111112595, 30.226082280278206, 23.431963250041008, 33.502969443798065, 47.19627566635609, 15.400299075990915, 0.20001011987915263, 0.08410549591644667, 0.046252149768406525, 0.01835177023167489, 0.022881290460645687, 0.01495409107519663, 0.07563435516203754, 0.03756375270313583, 0.022438187479565386, 0.03978008768172003, 0.03017011575138895, 0.040015433842199855, 0.02200179351348197, 0.03426061295613181, 0.02286319504491985, 0.05591672706941608, 0.09609473578166217, 0.10581550479400903, 0.01875462654425064, 0.06396383803803474, 0.021146702092664782, 0.03161817759973928, 0.09342089644633234, 6.053709760308266, 51.77301608026028, 54.62011210620403, 41.14000864326954, 20.442095585167408, 37.291495352983475, 50.66991627216339, 62.38306134939194, 51.58213712275028, 58.23180690407753, 13.372388742864132, 0.17168957157991827, 0.5669612833298743, 4.3886723555624485, 2.691269237548113, 2.957449466921389, 38.90790581703186, 51.53846986591816, 54.03599984943867, 52.14067295193672, 54.01593692600727, 51.43492542207241, 49.43025939166546, 44.81134504079819, 42.746756225824356, 39.062287732958794, 38.004067316651344, 37.56147466599941, 38.069112226367, 37.20858760178089, 36.96701556444168, 36.34363241493702, 36.88973531126976, 38.15081924200058, 39.02454815804958, 38.83217208087444, 44.2110912501812, 48.56330171227455, 51.57431714236736, 50.57133436203003, 51.12121045589447, 51.07416898012161, 53.12777638435364, 48.452685847878456, 49.15456898510456, 45.379448756575584, 41.23620808124542, 40.40958523750305, 39.64509665966034, 37.29288227856159, 36.563967391848564, 38.6542010307312, 37.067444175481796, 37.30093404650688, 39.374889358878136, 40.39553739130497, 41.12585060298443, 38.197446539998055, 39.94463078677654, 41.643865406513214, 40.62404192984104, 40.24279698729515, 40.64337149262428, 39.93654482066631, 39.591124355793, 39.18375961482525, 39.64614920318127, 37.64416202902794, 36.618327274918556, 37.780194729566574, 40.14742970466614, 42.469355911016464, 43.45696471631527, 48.07339400053024, 54.49713550508022, 46.18464075028896, 48.58423098921776, 53.907703533768654, 52.20907688140869, 45.88639855384827, 44.1947977244854, 42.55503371357918, 38.852975964546204, 36.46445833146572, 40.09724199771881, 40.49347333610058, 40.74900582432747, 40.85395239293575, 39.94170494377613, 42.31305509805679, 40.87385952472687, 40.483479872345924, 40.978407114744186, 41.489316299557686, 39.34474557638168, 40.29350146651268, 39.838574677705765, 39.767434895038605, 39.37574051320553, 39.43293124437332, 39.01836208999157, 40.07508158683777, 38.944741040468216, 38.8905331492424, 38.78663532435894, 38.60351175069809, 38.284990042448044, 37.201774567365646, 38.38715896010399, 36.96269519627094, 39.153099060058594, 37.97238081693649, 36.95848502218723, 36.98343068361282, 37.78517246246338, 36.59053936600685, 37.53861129283905, 39.029738679528236, 38.71273688971996, 40.97070872783661, 41.39087878167629, 43.65560665726662, 46.363143771886826, 49.09730605781078, 48.9223026484251, 51.50871366262436, 54.33394946157932, 54.6822539716959, 52.63711631298065, 55.20858272910118, 53.93731154501438, 56.6519732773304, 53.923533484339714, 55.87101258337498, 49.543208330869675, 52.44413986802101, 54.11939017474651, 61.04319624602795, 31.679515689611435, 0.13690319523448125, 0.9499274741392583, 6.160600874572992, 0.45499239466153085, 0.23085011111106724, 40.757422372698784, 69.137624502182, 53.08902986347675, 55.449033826589584, 33.860803842544556, 26.41944084316492, 38.956075832247734, 55.67128770053387, 21.921251714229584, 0.17052236624294892, 0.02250530360470293, 0.06358924641972408, 0.03635288310761098, 0.07256444645463489, 0.01817486077925423, 0.12020588925224729, 0.023840432841097936, 0.026358556606282946, 0.021117943870194722, 0.1538521412294358, 0.16178786696400493, 0.09154308470897377, 0.16270994092337787, 0.1526252820622176, 0.08493916524457745, 0.17085939034586772, 0.15912973147351295, 0.22929850296350196, 0.18564200727269053, 0.15487819007830694, 0.18119238666258752, 0.18605958408443257, 6.287935841828585, 58.43795344233513, 61.72684036195278, 49.138237461447716, 25.855404809117317, 43.79350885748863, 58.134114146232605, 68.99360463023186, 57.76105776429176, 62.44695112109184, 16.843097805976868, 0.4345141357043758, 2.5071505922824144, 5.622462825849652, 2.2162054292857647, 4.123645601794124, 40.180879309773445, 50.74411489069462, 56.90182887017727, 52.919748947024345, 56.82592794299126, 54.713473096489906, 53.28546792268753, 46.96471989154816, 45.73347955942154, 40.93007750809193, 39.64111067354679, 40.92138737440109, 41.47755593061447, 40.76015442609787, 39.89158943295479, 38.159004002809525, 39.41846542060375, 40.54904915392399, 41.99653208255768, 41.604009345173836, 47.07659348845482, 51.532044410705566, 55.07055513560772, 52.94626772403717, 52.60828346014023, 54.2516078799963, 56.36414252221584, 51.00030854344368, 51.44238822162151, 46.83603219687939, 44.22381676733494, 42.533139288425446, 42.35232599079609, 37.709776908159256, 37.883518785238266, 40.67662350833416, 38.89498271048069, 38.837130814790726, 41.70861393213272, 43.01584638655186, 41.88561223447323, 41.268126368522644, 40.937494710087776, 44.377609714865685, 42.17175967991352, 42.54959620535374, 43.56324501335621, 43.15588787198067, 42.272891253232956, 41.2432187050581, 41.024377048015594, 41.12420529127121, 39.76016968488693, 41.07055976986885, 42.256495133042336, 45.116730853915215, 45.734703093767166, 52.70142026245594, 56.1342054605484, 49.159588515758514, 48.501384034752846, 54.75688196718693, 55.016605630517006, 47.03097313642502, 46.52112789452076, 44.65240716934204, 41.9281205534935, 38.906055316329, 41.04941390454769, 43.60666908323765, 43.04827004671097, 42.18670807778835, 43.58783349394798, 43.69464196264744, 44.208712577819824, 42.34795622527599, 44.312678799033165, 43.60104538500309, 41.15360431373119, 41.69971100986004, 42.27265566587448, 41.451618522405624, 41.23305805027485, 40.85281625390053, 40.31303621828556, 41.504260897636414, 40.032862052321434, 42.5932976603508, 42.36441694200039, 39.9683453142643, 41.24147079885006, 39.42407011985779, 41.559563130140305, 39.160630255937576, 40.98348744213581, 40.15197046101093, 37.468778640031815, 38.43882858753204, 39.08418595790863, 38.13095010817051, 39.755944311618805, 41.09843127429485, 40.409030467271805, 42.64089770615101, 44.42922994494438, 45.421166718006134, 48.47712233662605, 51.799778044223785, 52.7173376083374, 52.470461055636406, 57.88715399801731, 56.63171276450157, 53.02577845752239, 58.7347175180912, 56.80271878838539, 58.967656418681145, 55.978596210479736, 56.89870923757553, 53.285566717386246, 54.76103514432907, 57.27314114570618, 63.404545336961746, 35.39257004857063, 0.28719081601593643, 1.575292395427823, 19.2414778098464, 1.032488790806383, 0.3558512910967693, 44.33710388839245, 74.8735611140728, 56.2202138453722, 59.04577262699604, 42.72453121840954, 35.64965285360813, 48.25091667473316, 65.3730221092701, 28.64079214632511, 0.26061670447234064, 0.12311278522247449, 0.20482962689129636, 0.07444041766575538, 0.129041328036692, 0.09720584959723055, 0.33172068593557924, 0.09589315362973139, 0.13415502238785848, 0.09815875979256816], [0.05902479329961352, 0.06618569459533319, 0.12373891295283101, 0.044518678332678974, 0.059339211584301665, 0.04978895100066438, 0.08489497777190991, 0.031134612727328204, 0.047436480163014494, 0.02650695274496684, 0.06829223624663427, 0.07759035215713084, 0.027132375435030553, 1.0942768002860248, 23.80201019346714, 51.32168769836426, 38.08912955224514, 28.61460205167532, 33.30335855484009, 44.54496793448925, 56.473348662257195, 49.72821280360222, 54.5002855360508, 23.971769884228706, 0.2982269675703719, 0.46204448968637735, 2.240782747976482, 3.3704158198088408, 0.5194591416511685, 17.66734767705202, 45.623498260974884, 51.42097257077694, 48.50169941782951, 48.13748516142368, 48.54365296661854, 46.46657042205334, 44.44074332714081, 40.42278192937374, 37.303225323557854, 37.50387355685234, 34.25784073770046, 36.334383711218834, 35.14405958354473, 35.065616592764854, 34.932581931352615, 35.863615572452545, 38.09161841869354, 42.13954500854015, 45.92895247042179, 48.74988690018654, 48.069271221756935, 48.0721590667963, 51.007319167256355, 52.29624040424824, 53.02294380962849, 51.753557324409485, 51.02810025215149, 50.3875420242548, 50.39794586598873, 46.76897719502449, 38.571008294820786, 36.583707332611084, 37.59116627275944, 36.325355395674706, 36.581100672483444, 36.342051699757576, 37.42971673607826, 38.546089231967926, 38.84333208203316, 37.38585568964481, 37.47832752764225, 37.35714063048363, 38.45487132668495, 38.48284162580967, 39.58687238395214, 38.67396757006645, 38.08801241219044, 38.704179748892784, 38.85778270661831, 38.645689487457275, 35.136087611317635, 34.637037590146065, 35.51824450492859, 39.32528302073479, 39.529157280921936, 40.013509690761566, 45.287866070866585, 52.16716133058071, 46.70413367450237, 49.0138853341341, 54.79712940752506, 49.35702592134476, 44.12893205881119, 43.48570257425308, 42.16954059898853, 35.70941984653473, 34.31269459426403, 35.129434168338776, 37.038056552410126, 37.80444122850895, 39.37580890953541, 38.114386796951294, 40.14435946941376, 42.58243024349213, 37.44430795311928, 38.871944546699524, 39.6598094701767, 38.89249384403229, 37.843385338783264, 37.65241898596287, 39.146985188126564, 38.0132894217968, 36.51145040988922, 37.99224995076656, 36.275532469153404, 37.30822965502739, 36.23962439596653, 36.266101375222206, 36.58083848655224, 36.06966331601143, 36.94832056760788, 36.06052100658417, 37.542817667126656, 38.12931999564171, 37.368201836943626, 36.646761149168015, 36.86587259173393, 36.21223546564579, 35.3306295722723, 35.49952670931816, 36.08019255101681, 34.61235411465168, 36.80027671158314, 35.93814097344875, 38.401681780815125, 38.38332116603851, 41.557515040040016, 43.45209337770939, 46.92689672112465, 48.2036168128252, 50.36089025437832, 49.51478585600853, 52.77249164879322, 52.76016891002655, 53.53153511881828, 53.6232203990221, 52.711979895830154, 51.22087150812149, 51.3540505617857, 52.085906490683556, 58.832725659012794, 11.50055218487978, 0.12197054573334754, 1.5441840584389865, 2.0716305496171117, 0.11639525037026033, 1.3807592215016484, 45.409991517663, 57.460927069187164, 50.53880050778389, 31.827392354607582, 23.848876878619194, 25.75675070285797, 44.447480365633965, 43.842123448848724, 5.782093685120344, 0.17870785435661674, 0.008664279121148866, 0.07636772323166952, 0.03982775582699105, 0.027140906422573607, 0.06839157271315344, 0.14803714700974524, 0.04057689082401339, 0.11441886657848954, 0.00968717569776345, 0.006079820805098279, 0.06022834531904664, 0.030969043291406706, 0.059298541891621426, 0.003871972980959981, 0.03805312859185506, 0.043460453671286814, 0.05462248460389674, 0.07723097456619143, 0.020938101079082116, 0.12155990800238214, 0.07968057398102246, 0.042370821320218965, 1.9502325262874365, 32.2907280921936, 57.158953472971916, 44.09883767366409, 27.95581430196762, 40.75675740838051, 51.60698018968105, 59.876077473163605, 54.10226449370384, 59.31188374757767, 24.652338065207005, 0.2037536315037869, 1.0796646843664348, 3.1942328112199903, 4.61013444699347, 0.8459604217205197, 22.033585086464882, 46.635490357875824, 51.871430799365044, 49.671098068356514, 50.94832353293896, 50.015667378902435, 50.4548554122448, 47.25537769496441, 43.00894595682621, 39.715092703700066, 39.146616607904434, 35.92464789748192, 37.76456616818905, 37.058826237916946, 37.72281400859356, 35.46332225203514, 37.870037108659744, 39.53174874186516, 44.75054070353508, 46.751908510923386, 50.02236261963844, 48.8458963483572, 51.57797634601593, 53.017016127705574, 52.93859973549843, 52.48342216014862, 53.61523322761059, 52.38501884043217, 51.15830026566982, 50.88362820446491, 48.72703492641449, 39.01426590979099, 38.19757953286171, 38.45220386981964, 37.17351168394089, 38.303445652127266, 38.49494017660618, 38.48687320947647, 39.96603883802891, 40.77302433550358, 40.9627291560173, 38.82826589047909, 39.22056823968887, 39.901054725050926, 40.846766978502274, 41.461573988199234, 38.48718859255314, 40.06835214793682, 42.073569148778915, 40.575415939092636, 40.19201651215553, 37.9962283372879, 35.1409475505352, 37.466042786836624, 41.90265811979771, 43.02055433392525, 40.23695670068264, 47.15901866555214, 54.27279934287071, 47.16534532606602, 50.04151739180088, 55.19051469862461, 50.59493109583855, 45.52778139710426, 44.14937876164913, 42.56145916879177, 38.53261515498161, 37.01335407793522, 36.97405658662319, 40.02265200018883, 39.52571466565132, 41.77382983267307, 39.0218199044466, 41.142767295241356, 43.43176826834679, 39.94727164506912, 40.31691960990429, 40.60872495174408, 40.99352650344372, 39.40016560256481, 39.75891575217247, 41.48813456296921, 38.80070596933365, 38.02713967859745, 38.08547414839268, 38.16970802843571, 38.25150243937969, 38.828718066215515, 37.12958984076977, 37.99137219786644, 38.33979070186615, 39.82744127511978, 37.66077093780041, 40.252551063895226, 39.97499495744705, 38.92512649297714, 38.772883862257004, 37.92823478579521, 36.33599862456322, 37.55513660609722, 35.79941041767597, 37.888561114668846, 36.17815509438515, 38.2489375770092, 38.23720000684261, 40.4852581769228, 40.794914960861206, 44.61870677769184, 45.35237900912762, 50.05420871078968, 50.42895220220089, 52.12289750576019, 50.81617422401905, 55.296756997704506, 54.06464271247387, 55.07576085627079, 53.41585032641888, 55.845010578632355, 53.420710265636444, 54.020709469914436, 53.807039335370064, 60.5161227285862, 13.981879837810993, 0.08337143764947541, 2.2951347939670086, 4.472281169146299, 0.26198691688477993, 1.570437562186271, 48.65908317267895, 64.41115692257881, 53.78251165151596, 40.50540089607239, 30.903848111629486, 27.582771219313145, 48.817249685525894, 53.47196191549301, 11.00049426779151, 0.34012366784736514, 0.026544356987869833, 0.03550225570506882, 0.05782161606475711, 0.027077065024059266, 0.043956471781712025, 0.019086685679212678, 0.10147698369110003, 0.010296481723344186, 0.01993514786590822, 0.10766928578959778, 0.17596554447663948, 0.23718539538094774, 0.14528143394272774, 0.11553064832696691, 0.09418347544851713, 0.16104472480947152, 0.12622186448425055, 0.18260659358929843, 0.13615923671750352, 0.30202922760508955, 0.17607692599995062, 0.11397958936868235, 2.0452946377918124, 39.85891878604889, 65.65874397754669, 51.61864936351776, 38.96826557815075, 46.08363077044487, 56.45206980407238, 66.18157312273979, 59.82141740620136, 66.2274594604969, 29.49222195893526, 0.3112138691358268, 2.9932984057813883, 7.9039606265723705, 6.981062823906541, 0.9557465650141239, 22.827531583607197, 48.13856050372124, 52.61673800647259, 53.1099059432745, 52.781645357608795, 52.106186002492905, 53.258990943431854, 49.908186346292496, 44.48469176888466, 42.513433545827866, 41.964226216077805, 38.807948380708694, 39.85981173813343, 39.6079308539629, 39.72020722925663, 38.135319873690605, 39.6090441942215, 42.04741135239601, 47.018631398677826, 49.201291278004646, 52.69094802439213, 51.28002293407917, 52.7157036960125, 54.41048115491867, 57.42153458297253, 56.53235949575901, 55.62572054564953, 54.692103043198586, 54.635592475533485, 53.618721440434456, 51.381120309233665, 41.68727807700634, 40.16785740852356, 41.026478335261345, 38.762122839689255, 39.27575647830963, 39.27080534398556, 40.82994908094406, 41.57428354024887, 43.059388250112534, 42.248880341649055, 40.93524143099785, 40.88680163025856, 42.25394167006016, 43.0451276153326, 43.69465336203575, 41.534636467695236, 43.33156004548073, 44.289876222610474, 43.26426565647125, 42.79893882572651, 39.06725026667118, 37.69693739712238, 40.263931453228, 44.13594648241997, 44.42287288606167, 43.936631977558136, 49.63188797235489, 55.74183851480484, 51.31438449025154, 52.793633714318275, 58.10414515435696, 54.37913663685322, 48.96608389914036, 47.072706297039986, 44.68398727476597, 41.918742656707764, 39.81733001768589, 39.2534364759922, 42.78269089758396, 41.659987941384315, 42.30090714991093, 41.91720373928547, 43.24941225349903, 45.86532488465309, 40.63676364719868, 42.06330589950085, 43.50254327058792, 43.478878140449524, 40.15632122755051, 42.097621858119965, 43.77502664923668, 42.50203415751457, 39.824572429060936, 40.02346895635128, 40.32321587204933, 41.30498819053173, 39.66571435332298, 39.684230759739876, 40.60225769877434, 40.381504744291306, 41.56566180288792, 40.04677690565586, 43.113611340522766, 43.306963965296745, 41.1078167706728, 40.139222145080566, 39.980915039777756, 40.01042805612087, 37.99823082983494, 38.92772175371647, 39.38173659145832, 37.71429866552353, 40.602272897958755, 39.78796139359474, 42.535438165068626, 42.53408923745155, 47.295575737953186, 48.294986709952354, 50.86754746735096, 52.66550078988075, 55.443299934268, 53.640536069869995, 56.93451091647148, 56.177933514118195, 55.78950695693493, 56.675269827246666, 57.11244396865368, 57.46772110462189, 57.27129824459553, 57.1452172100544, 63.854365199804306, 15.298260301351547, 0.14383127738256007, 4.652164941653609, 10.871582385152578, 0.3915646841051057, 1.5659178234636784, 53.849684447050095, 68.52385863661766, 60.29276691377163, 42.79179520905018, 36.925764977931976, 36.909076273441315, 59.15562853217125, 63.13974894583225, 15.559218898415565, 0.5918504227884114, 0.11835890632937662, 0.16094138816697523, 0.11337706193444319, 0.18676186358788982, 0.1012114952027332, 0.2549919078592211, 0.17636235599638894, 0.22031986678484827, 0.07416776003083214], [0.030267062502389308, 0.021442562974698376, 0.04699621960753575, 0.01639036854612641, 0.0750506114854943, 0.016660365581628866, 0.053485555181396194, 0.05836773656483274, 0.029739267483819276, 0.041168850075337104, 0.06419674624339677, 0.052430039359023795, 0.08284672439913265, 0.28683960204944015, 21.804140098392963, 50.39683632552624, 42.674791887402534, 20.82614667713642, 27.514743469655514, 43.2318951934576, 53.620134964585304, 52.06605635583401, 48.914433270692825, 27.527556382119656, 0.14137417485471815, 0.4507470427779481, 3.6546854535117745, 4.000945910811424, 0.10408604837721214, 3.7245520669966936, 29.333061799407005, 47.611912563443184, 48.64851213991642, 48.73960845172405, 49.57278594374657, 49.17599983513355, 44.3964909017086, 40.732640102505684, 37.451310977339745, 35.13229541480541, 34.805942326784134, 35.74374720454216, 34.263905212283134, 37.83128298819065, 39.952496364712715, 43.83150301873684, 43.88370841741562, 47.45317228138447, 47.811200469732285, 50.9865190833807, 50.847176760435104, 50.059125646948814, 47.54085257649422, 47.965871170163155, 47.98813797533512, 50.49712434411049, 51.26944810152054, 52.24079757928848, 50.81811212003231, 50.44086456298828, 42.547544315457344, 36.610047519207, 35.142554864287376, 36.092006117105484, 35.76423190534115, 36.82757444679737, 36.03116758167744, 37.33674332499504, 39.20244701206684, 37.55836263298988, 36.43266923725605, 38.239225298166275, 37.19377599656582, 37.963808476924896, 38.64731580018997, 38.080488815903664, 40.299277156591415, 35.82528702914715, 40.20270153880119, 38.507122322916985, 36.135593578219414, 34.57354299724102, 35.965051129460335, 37.04827420413494, 40.84589682519436, 40.972376838326454, 44.399458542466164, 52.85957157611847, 47.93568558990955, 48.286927342414856, 53.59922468662262, 48.117266446352005, 44.534089118242264, 42.151320576667786, 39.59307745099068, 36.594897732138634, 35.77556289732456, 35.85451886057854, 37.27157682180405, 39.10513423383236, 39.8657888174057, 39.68380518257618, 39.784233793616295, 39.45931702852249, 40.33958539366722, 37.21244439482689, 37.34500788152218, 38.881113454699516, 38.41956362128258, 37.841740027070045, 37.51954011619091, 36.54399946331978, 36.62714660167694, 35.986120998859406, 36.933729350566864, 37.67163835465908, 36.59817315638065, 36.40762858092785, 37.139286920428276, 36.36959262192249, 36.68661721050739, 37.700832188129425, 36.72523453831673, 36.824181228876114, 36.002463921904564, 36.56398259103298, 37.358717545866966, 36.43248684704304, 37.87392430007458, 37.53566265106201, 34.73605267703533, 36.7745178937912, 35.5637014657259, 35.14776058495045, 36.730592250823975, 37.95391380786896, 38.54133188724518, 39.91743564605713, 42.71114453673363, 44.01236571371555, 47.56739795207977, 47.992754727602005, 50.2320771664381, 50.58696672320366, 53.39025869965553, 53.08016873896122, 55.738996267318726, 54.95642825961113, 56.55515067279339, 54.420672208070755, 45.64210966229439, 2.0482268929481506, 0.1215294873691164, 0.5791617161594331, 4.680604515597224, 0.6552809535060078, 1.9815789442509413, 46.570928022265434, 57.87227779626846, 52.445181012153625, 38.50477784872055, 21.48502752184868, 22.777110189199448, 41.89418837428093, 37.82736159861088, 1.8094066204503179, 0.10945677815470845, 0.02030983225267846, 0.013836925973009784, 0.02158942101232242, 0.08953205746365711, 0.032641955476719886, 0.026432077465869952, 0.06781821168260649, 0.03151403943775222, 0.05764222783909645, 0.04238069930579513, 0.02384184848779114, 0.051001835527131334, 0.033255503803957254, 0.09678486632765271, 0.0724750102381222, 0.10902613212238066, 0.11089542400441132, 0.016918532783165574, 0.07734839717159048, 0.07418285531457514, 0.053701531287515536, 0.09949836603482254, 0.4208633681992069, 28.569027297198772, 59.28643651306629, 50.14114424586296, 23.38650818914175, 29.87958837300539, 49.47458401322365, 59.624755159020424, 56.21371619403362, 54.65840645134449, 29.451178461313248, 0.13205205788835883, 0.24980180198326707, 2.744801715016365, 6.824145019054413, 0.3044335189042613, 5.50252178683877, 33.2782457023859, 49.49285723268986, 51.976966336369514, 50.32740265130997, 51.456443667411804, 50.73189474642277, 45.640365555882454, 43.64361070096493, 39.44475620985031, 36.69306546449661, 37.16917611658573, 37.0138518512249, 36.05166748166084, 39.71839852631092, 40.16756482422352, 46.30432292819023, 45.63992477953434, 49.95940379798412, 49.86922323703766, 52.23817951977253, 53.54225814342499, 51.86565510928631, 48.087141662836075, 48.57750155031681, 47.983460426330566, 52.709791213274, 51.61386162042618, 52.230697721242905, 52.14016757905483, 52.24697224795818, 43.3227901160717, 39.1754874587059, 37.05393590033054, 37.06175968050957, 38.168659284710884, 38.251711428165436, 36.6722197830677, 38.588107377290726, 40.084862262010574, 39.06457521021366, 38.668944239616394, 41.334288418293, 40.16352564096451, 38.78522180020809, 40.96999056637287, 40.827046036720276, 41.684633418917656, 37.48455159366131, 42.27826036512852, 38.217273876070976, 37.05497704446316, 37.171330600976944, 38.21562856435776, 39.51281815767288, 44.066254422068596, 42.267590537667274, 46.01421609520912, 53.641805201768875, 49.97189752757549, 48.80699023604393, 54.87386628985405, 50.323371067643166, 46.30812652409077, 44.039044082164764, 42.247189432382584, 39.60183598101139, 38.0140645802021, 38.471647426486015, 40.10465919971466, 41.25500567257404, 41.437050104141235, 41.370815858244896, 41.669084653258324, 40.49878545105457, 41.6707793623209, 40.23336589336395, 37.68942140042782, 40.19134774804115, 39.44101721048355, 40.1736368983984, 39.56165313720703, 39.12427380681038, 39.026812836527824, 38.40391606092453, 38.65093320608139, 39.259105771780014, 38.620443642139435, 38.26879531145096, 39.12148095667362, 39.07435208559036, 38.653973042964935, 39.2744417488575, 37.862080335617065, 38.63545283675194, 37.83319428563118, 38.87466140091419, 39.105525612831116, 39.10282775759697, 40.30493885278702, 38.498831167817116, 37.45711326599121, 38.551602736115456, 37.021489441394806, 36.18945948779583, 38.362665474414825, 38.32033954560757, 39.67268317937851, 40.849829614162445, 46.867904886603355, 47.01911777257919, 50.7171743363142, 49.15096677839756, 53.19236911833286, 51.88523925840855, 57.73057579994202, 54.48558032512665, 57.9423688352108, 56.3238874822855, 59.47899878025055, 56.44216753542423, 49.663236290216446, 2.615794837474823, 0.4164391290396452, 2.445098734460771, 4.536973172798753, 0.6311033258680254, 2.375860749743879, 51.52732886373997, 63.60170155763626, 56.74402333796024, 45.0919371843338, 26.35334149003029, 25.36784917116165, 46.98638252913952, 47.476142048835754, 4.244753178209066, 0.17438267706893384, 0.09216446269419976, 0.11412736581405625, 0.026250694718328305, 0.11079510790295899, 0.007781463382343645, 0.09328081607236527, 0.07499538085539825, 0.08008476987015456, 0.013055312738288194, 0.12842108553741127, 0.09235080113285221, 0.18259768781717867, 0.08537535512004979, 0.11414086548029445, 0.12116043959395029, 0.20538347685942426, 0.16284707497106865, 0.13374908245168626, 0.18806060717906803, 0.2294483277364634, 0.22453339537605643, 0.23509020858909935, 0.46525401121471077, 35.9217144548893, 66.59290865063667, 58.585571721196175, 29.59618628025055, 37.21603140234947, 55.61910890042782, 64.08517241477966, 61.00824952125549, 61.439222395420074, 33.823064267635345, 0.2935625397367403, 1.3445561891421676, 11.257812660187483, 8.848918620496988, 0.41415093932300806, 6.054811226204038, 34.5072365552187, 51.567716896533966, 53.187311589717865, 53.55669356882572, 54.504906088113785, 52.67079010605812, 48.97774167358875, 45.48711217939854, 41.240942627191544, 37.70864836871624, 40.2340080589056, 40.31827613711357, 37.2207735478878, 42.56205953657627, 41.95442274212837, 49.29915502667427, 48.36430639028549, 52.403641641139984, 52.09292471408844, 56.089523658156395, 55.75668051838875, 52.46373921632767, 48.298254534602165, 50.99914960563183, 48.814764618873596, 53.10752347111702, 55.203285813331604, 54.933382496237755, 55.507353097200394, 55.639711394906044, 45.351330265402794, 41.56751610338688, 39.215852692723274, 39.33469131588936, 38.89366798102856, 39.97909873723984, 39.99316558241844, 40.83964616060257, 42.59084299206734, 41.89902551472187, 39.860955476760864, 43.090508580207825, 41.964062824845314, 40.26028364896774, 42.79882103204727, 40.98725683987141, 43.29678811132908, 39.950395077466965, 45.4724145680666, 40.8980680257082, 40.36815606057644, 39.788109585642815, 40.913681387901306, 42.127773240208626, 45.415121242403984, 44.79779876768589, 47.942589819431305, 55.39351500570774, 52.389510199427605, 51.40641175210476, 58.19725535809994, 51.70950248837471, 47.91173927485943, 46.65899209678173, 44.73977588117123, 41.13803654909134, 39.703241139650345, 41.77424781024456, 41.00246362388134, 44.429009556770325, 44.543368220329285, 43.65073911845684, 43.27638320624828, 43.476727455854416, 42.68365681171417, 43.17148983478546, 39.96391475200653, 42.31045603752136, 42.10057809948921, 40.43161265552044, 41.29585728049278, 41.48762919008732, 40.4729126393795, 42.07996420562267, 40.45343868434429, 42.17199146747589, 40.115389823913574, 40.763228461146355, 42.13682435452938, 39.67881605029106, 39.49780896306038, 42.42023974657059, 41.20958290994167, 38.9220030605793, 39.19395446777344, 40.529366210103035, 39.90498751401901, 39.13754269480705, 41.68196976184845, 40.78062392771244, 38.21478120982647, 41.30837380886078, 39.09675568342209, 39.43492613732815, 41.07324622571468, 41.63842789828777, 41.23617768287659, 43.39586779475212, 49.47904497385025, 49.875857681035995, 53.07784326374531, 52.44609676301479, 56.27122610807419, 54.68180939555168, 58.76528687775135, 56.161222010850906, 59.253724068403244, 60.238756611943245, 63.2245147973299, 57.163642421364784, 51.23896233737469, 3.786174072884023, 0.44906471273861825, 4.132791711017489, 14.298017174005508, 1.4496000087819993, 2.5012435717508197, 54.862501099705696, 68.51198047399521, 61.98868431150913, 53.13232474029064, 33.84682819247246, 35.85745610296726, 54.66533347964287, 57.710927054286, 7.065800176933408, 0.3407806169707328, 0.15830804040888324, 0.21727633400587365, 0.15786183153977618, 0.20104500028537586, 0.05995902363792993, 0.16383012378355488, 0.08908345145755447, 0.17009638831950724, 0.1394294510828331], [0.05931211948336568, 0.03051911626243964, 0.020306999103922863, 0.027930328906222712, 0.04342569147411268, 0.04453499444935005, 0.027834415595862083, 0.04318939536460675, 0.052552590204868466, 0.048857444344321266, 0.011530863484949805, 0.013009225367568433, 0.029399593913694844, 0.11504650829010643, 17.80427522957325, 47.53838650882244, 40.773237124085426, 23.451441004872322, 27.441793084144592, 38.52797940373421, 50.68768411874771, 52.23689518868923, 49.274144768714905, 35.70546045899391, 0.1477784788585268, 0.3785892412997782, 1.204299540258944, 4.906862424686551, 1.5507924975827336, 0.3407794889062643, 14.617316890507936, 45.81030763685703, 50.128388330340385, 51.61378562450409, 50.92283450067043, 48.811375200748444, 44.723721742630005, 38.915627002716064, 36.104853227734566, 36.41729526221752, 37.39736147224903, 35.50967216491699, 37.932885736227036, 43.62560726702213, 45.617977157235146, 49.87948648631573, 47.65945561230183, 48.64400938153267, 49.781102165579796, 49.86358813941479, 46.863797307014465, 44.72768872976303, 47.18931443989277, 50.20219936966896, 50.22654086351395, 49.90384317934513, 51.919452622532845, 48.82661998271942, 48.99147413671017, 49.94107358157635, 46.70831345021725, 35.613862574100494, 36.55881106853485, 37.21743352711201, 39.57434065639973, 37.05529622733593, 35.44855244457722, 36.773210763931274, 37.692814618349075, 37.43222460150719, 39.1718852519989, 38.77357542514801, 38.59457083046436, 38.19198243319988, 39.00013066828251, 39.29941400885582, 39.90363858640194, 38.326236829161644, 38.25800009071827, 38.92946965992451, 35.85147902369499, 33.53610746562481, 33.713789731264114, 36.307929530739784, 38.368239775300026, 37.05605998635292, 42.443692088127136, 52.498613744974136, 50.15701599419117, 49.18279767036438, 53.569365888834, 48.257615715265274, 41.23751901090145, 40.702268332242966, 39.41705569624901, 36.07120603322983, 35.69613955914974, 34.84384909272194, 36.957474276423454, 38.28425668179989, 40.899986922740936, 39.288288205862045, 39.290389493107796, 38.587719798088074, 38.35275560617447, 39.34007182717323, 38.377138897776604, 39.6267132461071, 37.26847618818283, 40.02812750637531, 37.55918338894844, 38.45707520842552, 37.20234453678131, 38.59461262822151, 37.629984989762306, 39.058978110551834, 36.96954242885113, 37.259303480386734, 36.7187824845314, 38.10363717377186, 38.26069414615631, 36.397224739193916, 38.726708739995956, 38.469477742910385, 40.90594880282879, 39.54948239028454, 39.601539596915245, 38.140233010053635, 37.54394240677357, 36.83080047369003, 37.50099331140518, 36.17248959839344, 36.06536954641342, 35.69520480930805, 35.98720774054527, 35.49094296991825, 35.1034739613533, 37.462269589304924, 39.389921352267265, 38.63127686083317, 41.685077995061874, 45.288508236408234, 48.14286947250366, 49.61931824684143, 49.95245397090912, 53.41574773192406, 55.13348735868931, 58.169083669781685, 52.01323539018631, 57.07380764186382, 25.01517489552498, 0.12259872179129161, 0.5949730833526701, 1.186381601728499, 1.2804278614930809, 0.3947159618837759, 2.9179731477051973, 47.24490165710449, 57.15384654700756, 53.416329100728035, 33.975702077150345, 22.26989820599556, 25.663593001663685, 47.3801402002573, 32.38943159580231, 1.31534205051139, 0.0897827920562122, 0.05501577092218213, 0.043004363105865195, 0.06217527326953132, 0.04234836764226202, 0.05439496067992877, 0.016387628165830392, 0.06866914336569607, 0.03023149136424763, 0.021442757788463496, 0.01789567595551489, 0.06263684088480659, 0.030716011751792394, 0.07624468998983502, 0.012095964411855675, 0.05819219637487549, 0.05786747336969711, 0.025861942922347225, 0.04957673387252726, 0.0523715210147202, 0.03504934524244163, 0.007520315530200605, 0.07431402991642244, 0.2474751096451655, 21.653348989784718, 54.924969747662544, 47.1685865521431, 25.755736157298088, 31.631664857268333, 46.361152678728104, 56.44071601331234, 56.45533002912998, 53.95881839096546, 39.47480879724026, 0.25803171505685896, 0.3397314279573038, 1.2018296727910638, 6.727001331746578, 2.9898213548585773, 0.8560717385262251, 17.317880429327488, 47.47022956609726, 49.95144322514534, 51.55656449496746, 54.140418246388435, 51.774934977293015, 45.80409497022629, 41.09154984354973, 37.875079438090324, 38.164042532444, 38.79840329289436, 36.94126054644585, 41.37057647109032, 46.09309986233711, 48.548786491155624, 50.274414494633675, 49.52791415154934, 52.67242021858692, 51.37920141220093, 49.57977756857872, 46.512601152062416, 46.11113369464874, 49.03940476477146, 50.53201787173748, 51.93697348237038, 51.61551833152771, 52.391372099518776, 51.37799687683582, 50.746717751026154, 52.02792540192604, 48.27488198876381, 37.196074873209, 38.1656726449728, 38.114850372076035, 39.5196083933115, 37.734566777944565, 36.98036804795265, 37.844358086586, 41.01813778281212, 39.11389656364918, 40.96751309931278, 40.62066771090031, 41.15224398672581, 39.7026027739048, 40.22058717906475, 40.10242871940136, 40.69968067109585, 40.52102945744991, 40.858189165592194, 40.364603251218796, 37.55719989538193, 36.905132085084915, 37.47656062245369, 38.22927363216877, 40.071391984820366, 39.387812465429306, 45.922910794615746, 54.65930700302124, 51.43162339925766, 51.16743877530098, 53.629980236291885, 49.35952238738537, 43.35670709609985, 45.52161052823067, 40.96483424305916, 39.44200895726681, 37.67458699643612, 37.820293977856636, 39.18940991163254, 40.04272632300854, 41.5594757348299, 40.31813554465771, 40.68041950464249, 39.93977464735508, 40.245700031518936, 40.1117230206728, 39.05126452445984, 39.21734221279621, 37.73154973983765, 41.44642420113087, 40.04439063370228, 38.17267566919327, 38.88766050338745, 40.23240454494953, 37.98528112471104, 40.9811619669199, 39.058267548680305, 39.470553025603294, 39.37764801084995, 40.2306642383337, 41.40491522848606, 38.61836135387421, 41.61185212433338, 40.464237704873085, 41.84927098453045, 41.759846583008766, 40.279795601964, 40.147718489170074, 40.47159790992737, 38.401579186320305, 37.244408279657364, 37.32893094420433, 38.07073473930359, 39.5926708728075, 38.62942636013031, 38.41585122048855, 38.12504902482033, 38.70678260922432, 41.12525783479214, 40.34160688519478, 44.89759661257267, 47.588855400681496, 50.740991458296776, 51.85978442430496, 53.25658567249775, 54.550819024443626, 57.02060669660568, 57.41770438849926, 53.8724110275507, 56.51798486709595, 29.05835174024105, 0.08287261793157086, 1.6044382564723492, 4.892072668299079, 3.5377624025568366, 0.28239909501280636, 3.099384200759232, 52.88700230419636, 62.7302411198616, 57.5530531257391, 42.009375393390656, 24.58248071372509, 29.51045148074627, 54.5332145690918, 40.58688372373581, 2.4984414596110582, 0.14527738181641325, 0.05268987639283296, 0.04299742773582693, 0.04543297829513904, 0.03710672703164164, 0.06555875050253235, 0.06417430369765498, 0.05254635616438463, 0.01613193231605692, 0.026662688724172767, 0.2687312284251675, 0.09886408210149966, 0.10536750734900124, 0.26016782387159765, 0.09715269698062912, 0.1964556035818532, 0.16772625065641478, 0.1665705189225264, 0.11503957663080655, 0.1435684086754918, 0.13335476454813033, 0.14390007447218522, 0.16013035434298217, 0.3262444376014173, 25.292218029499054, 63.17844606935978, 55.39329841732979, 34.33867000043392, 37.480003237724304, 51.11020624637604, 62.298705875873566, 63.4671887755394, 58.93924154341221, 45.22951640188694, 0.5092611419968307, 1.0933852731250226, 4.537607738748193, 10.848970748484135, 3.2160982629284263, 0.9363025333732367, 20.521625317633152, 48.49332846701145, 51.563924700021744, 54.35569569468498, 56.740234941244125, 54.67663787305355, 49.491952881217, 42.7948996424675, 40.53265683352947, 40.4352680593729, 41.67874753475189, 39.246714636683464, 43.99413429200649, 47.851820290088654, 49.76290114223957, 52.610768526792526, 52.12867319583893, 53.869185000658035, 53.79061661660671, 52.38159142434597, 47.1709044277668, 46.672751158475876, 50.75407795608044, 52.642648816108704, 53.32421064376831, 52.47189737856388, 54.32720862329006, 53.211219906806946, 54.32699203491211, 54.85097251832485, 50.83425745368004, 39.80471849441528, 39.24573428928852, 40.749241411685944, 42.76521943509579, 39.78364862501621, 39.50268790125847, 39.70793388783932, 41.760796532034874, 41.41241602599621, 44.075514525175095, 42.514436691999435, 43.211881667375565, 41.9100297242403, 43.015458807349205, 42.655944898724556, 44.43636976182461, 42.059582099318504, 43.74096527695656, 43.39232638478279, 41.39168433845043, 38.89658622443676, 38.56513760983944, 40.93873344361782, 42.506985291838646, 41.397973001003265, 45.3599938005209, 56.54245175421238, 51.867505609989166, 51.876055151224136, 56.56160272657871, 52.94714167714119, 45.49708664417267, 46.91455498337746, 44.59444507956505, 40.98685026168823, 41.77941553294659, 39.807017371058464, 41.643633618950844, 42.32464447617531, 44.37441408634186, 42.435484528541565, 42.21309766173363, 41.20885714888573, 41.503926515579224, 43.55647757649422, 41.75997957587242, 42.32077248394489, 40.10672628879547, 43.02854150533676, 42.075301855802536, 41.26271925866604, 40.82032419741154, 41.09763711690903, 40.33801607787609, 43.443027064204216, 39.34969671070576, 42.77184247970581, 41.77134856581688, 42.46298365294933, 43.147551119327545, 39.59234029054642, 43.57033543288708, 42.6229702681303, 45.04380136728287, 45.231116116046906, 42.64621742069721, 44.09102149307728, 42.354621067643166, 40.34913048148155, 40.416003093123436, 40.21147906780243, 40.98615109920502, 41.08154118061066, 40.35134956240654, 40.03587529063225, 40.18906407058239, 40.75960725545883, 44.03261862695217, 42.402015924453735, 47.18039631843567, 48.91388230025768, 53.98103579878807, 54.63287942111492, 55.268646106123924, 56.1927755177021, 57.737776413559914, 60.134285017848015, 54.14477661252022, 57.69944787025452, 31.44034892320633, 0.33379685890395194, 1.2759626260958612, 8.134916983544827, 7.90683944709599, 0.7849610480479896, 3.643359448760748, 57.8387825936079, 68.24424684047699, 64.71074804663658, 47.46185101568699, 32.148277536034584, 36.97444796562195, 63.99461567401886, 49.68353100121021, 3.546059732325375, 0.2640764188254252, 0.10178141266806051, 0.1949624766712077, 0.18048593628918752, 0.11462177717476152, 0.126227475120686, 0.17300770006841049, 0.21838320273673162, 0.12199776028865017, 0.1834965919260867], [0.08894101105397567, 0.0662660098168999, 0.02503846142644761, 0.019425218197284266, 0.11465075804153457, 0.0173017852648627, 0.05257229051494505, 0.04369380716525484, 0.03555224306182936, 0.03245124578825198, 0.0544274667481659, 0.05040813593950588, 0.02803994411806343, 0.052280177478678524, 10.094977207481861, 48.58861595392227, 44.839657321572304, 25.490707978606224, 21.46500449627638, 36.3341823220253, 47.92147435247898, 54.84727531671524, 47.57562071084976, 43.691123351454735, 1.4250196027569473, 0.34978708368726075, 1.2166900816373527, 4.623650796711445, 1.777087098453194, 0.43361025920603424, 9.815692193806171, 47.850946336984634, 52.98611618578434, 52.124083042144775, 49.38935458660126, 48.901114985346794, 41.619436517357826, 35.693156719207764, 36.05704039335251, 38.6223853379488, 36.601038202643394, 40.90744972229004, 47.49372370541096, 49.86401751637459, 48.226917162537575, 48.95281121134758, 49.35213178396225, 49.387595281004906, 49.30435694754124, 48.60177464783192, 46.93138048052788, 51.43357269465923, 52.175121903419495, 48.746204897761345, 49.15663607418537, 47.94135108590126, 47.581172212958336, 51.03862568736076, 50.345846861600876, 49.097290858626366, 45.15030965209007, 35.413761511445045, 35.56380406022072, 34.79386277496815, 38.05723026394844, 36.24543808400631, 37.77778185904026, 37.354256585240364, 38.477700501680374, 37.80557356774807, 36.25183694064617, 38.6054914444685, 38.67643743753433, 37.62784190475941, 37.24772170186043, 40.19673205912113, 39.303749576210976, 40.00956170260906, 41.73172049224377, 38.16219203174114, 35.51184184849262, 33.63294906914234, 35.859131813049316, 35.1120463013649, 36.38152778148651, 38.104431331157684, 43.87708157300949, 50.835678577423096, 50.7495030015707, 52.72588334977627, 51.84763267636299, 49.29796189069748, 40.629019662737846, 41.10297203063965, 38.9367538690567, 36.53274066746235, 35.519631430506706, 36.12890973687172, 37.942670211195946, 39.644131511449814, 37.80906178057194, 37.749986350536346, 38.2202985137701, 39.07947041094303, 39.37367342412472, 38.632739782333374, 39.36871849000454, 38.136425614356995, 38.173903003335, 37.150306329131126, 39.24966707825661, 38.28720912337303, 38.47945220768452, 36.15957409143448, 38.76514747738838, 36.82229273021221, 37.708275988698006, 37.8545643389225, 38.456881418824196, 42.01864309608936, 42.13827967643738, 44.39416162669659, 46.22281730175018, 48.252394795417786, 49.828402027487755, 47.14907459914684, 47.28003077208996, 45.13544864952564, 41.02464683353901, 38.86154070496559, 36.61974839866161, 36.80055409669876, 36.99207901954651, 35.29835790395737, 35.46024061739445, 36.64209499955177, 35.15156798064709, 35.500697046518326, 36.81880831718445, 35.39351999759674, 37.56889566779137, 39.02667984366417, 41.756312772631645, 45.388925448060036, 48.85331355035305, 51.38070993125439, 50.61927258968353, 54.86073799431324, 53.178659453988075, 50.92530816793442, 17.121246680617332, 0.04771220657858066, 1.8196460022591054, 1.4146999502554536, 2.679121526889503, 0.11949528285185806, 2.4723297357559204, 51.014838963747025, 54.612713903188705, 48.76651480793953, 39.58784893155098, 29.985135309398174, 27.854886017739773, 42.804938703775406, 22.74667952209711, 0.012729470945487265, 0.09378361370181665, 0.02587570605101064, 0.03894554261933081, 0.022321180476865266, 0.015958356962073594, 0.019116289950034115, 0.08819429174764082, 0.012605118536157534, 0.04020635875349399, 0.05569073939113878, 0.009204680445691338, 0.08168094398570247, 0.014583343781851, 0.022341420699376613, 0.020727301453007385, 0.03276876625022851, 0.022327755905280355, 0.09244825254427269, 0.06582263595191762, 0.06044458488759119, 0.01974009475816274, 0.08812540560029447, 0.056215085278381594, 0.10670605232007802, 14.636606555432081, 56.47508516907692, 51.55262030661106, 31.406137458980083, 24.065716043114662, 45.82289636135101, 55.843175277113914, 60.94723239541054, 51.24487861990929, 48.937346041202545, 1.3361255102790892, 0.2590740763116628, 1.301295510493219, 5.898622507229447, 4.645939925685525, 0.3360063215950504, 11.322392094880342, 47.36608475446701, 52.70093388855457, 54.51597109436989, 52.51300737261772, 50.482449531555176, 45.48898547887802, 38.36713023483753, 38.53959158062935, 39.65533331036568, 37.94130228459835, 42.05909192562103, 47.89100758731365, 51.54426835477352, 50.1258310675621, 52.54174903035164, 50.67745126783848, 52.04592123627663, 50.282295271754265, 48.53978097438812, 47.290936186909676, 51.35523609817028, 55.04758536815643, 51.56559661030769, 50.37746496498585, 52.423913553357124, 50.03970108926296, 51.40192039310932, 51.9676948338747, 50.64847022294998, 45.79788230359554, 37.582734525203705, 38.33800099790096, 36.31084397435188, 38.73678579926491, 38.0081444978714, 38.793809339404106, 39.36869189143181, 40.21306358277798, 38.95453691482544, 40.5960526317358, 40.859408900141716, 39.44008246064186, 40.14887362718582, 38.61036658287048, 41.84666432440281, 40.36775328218937, 41.16798274219036, 43.19298908114433, 39.70454066991806, 36.53659366071224, 35.39466753602028, 37.96184778213501, 38.742724880576134, 39.75119076669216, 39.186723455786705, 45.12665972113609, 53.14028151333332, 53.008466586470604, 53.59593786299229, 54.1596832126379, 50.99109023809433, 43.1003500521183, 43.79794701933861, 42.18120217323303, 39.64350454509258, 37.859652265906334, 37.96113722026348, 39.984961822628975, 39.862995967268944, 40.04345588386059, 38.05571414530277, 40.370226949453354, 42.76286356151104, 40.17995595932007, 40.621009692549706, 39.47127878665924, 40.044413432478905, 39.92172561585903, 40.32581493258476, 41.17911234498024, 40.75519189238548, 39.588722884655, 39.509193152189255, 39.14638862013817, 38.89840632677078, 39.22019965946674, 38.52599211037159, 39.90524969995022, 43.84475290775299, 43.22066679596901, 47.21099607646465, 47.62671656906605, 50.283735394477844, 51.16131350398064, 49.896292984485626, 48.0977088958025, 46.439272686839104, 41.32728919386864, 40.68237639963627, 39.87266264855862, 38.185389786958694, 38.2245846837759, 37.79218688607216, 38.36549252271652, 37.91667960584164, 38.03707994520664, 38.056933879852295, 37.84425929188728, 38.165676444768906, 40.36204978823662, 40.665668696165085, 44.686590135097504, 49.45098727941513, 50.57914674282074, 52.92637579143047, 54.41079653799534, 57.6730202883482, 53.61294575035572, 52.20331259071827, 18.911138735711575, 0.09389336250023916, 3.971753502264619, 5.5237137246876955, 5.364646660163999, 0.03478010148683097, 3.0435590213164687, 56.18799537420273, 59.242431074380875, 55.949345380067825, 40.916508436203, 24.75365962833166, 32.55786895751953, 50.47975927591324, 29.835404343903065, 0.3365835640579462, 0.053866447633481584, 0.054591451698797755, 0.027597189946391154, 0.10924711401457898, 0.03540954290656373, 0.010750544370239368, 0.0741831299092155, 0.038050430885050446, 0.02346117682463955, 0.045729714911431074, 0.17946686362847686, 0.13591634662589058, 0.1113735229591839, 0.09752195997862145, 0.2393210440641269, 0.12451029382646084, 0.16342186834663153, 0.15079300850629807, 0.1321114000165835, 0.1762584553216584, 0.3584562294417992, 0.22597409697482362, 0.12254150962689891, 0.150584761868231, 16.578911282122135, 66.21615886688232, 59.134091287851334, 38.46074961125851, 31.421933211386204, 49.122707694768906, 59.77936126291752, 65.47324553132057, 57.12550386786461, 55.32565824687481, 1.949356673285365, 0.45987335150130093, 5.1787155121564865, 12.207196466624737, 3.9137185038998723, 1.3842702331021428, 13.749016933143139, 52.89739854633808, 55.195971205830574, 58.165644854307175, 55.12844882905483, 53.91963109374046, 47.12018474936485, 40.164551585912704, 38.680385425686836, 43.11783291399479, 40.13059660792351, 44.28392194211483, 52.03211657702923, 54.80952054262161, 52.41247236728668, 55.13480208814144, 52.404276207089424, 52.22557559609413, 52.291308268904686, 50.03983788192272, 49.004739224910736, 54.93504300713539, 55.854365676641464, 54.17172856628895, 53.03373143076897, 54.65673454105854, 51.95395477116108, 53.812416046857834, 54.09843809902668, 52.533727660775185, 47.88742437958717, 38.8943063467741, 40.181479677557945, 38.65375265479088, 40.70473439991474, 39.690223038196564, 40.58382108807564, 40.970860719680786, 42.04785592854023, 41.048593148589134, 40.44643186032772, 42.089106515049934, 41.62015847861767, 40.70134878158569, 40.34261763095856, 44.71671111881733, 43.50056357681751, 43.51168937981129, 46.83745712041855, 41.80744282901287, 40.35775601863861, 38.139161467552185, 41.41826771199703, 40.25033578276634, 41.90943695604801, 41.6981340944767, 47.39268332719803, 53.2297895103693, 53.799177557229996, 54.89730343222618, 56.21794916689396, 53.861972987651825, 44.91954043507576, 44.699832424521446, 44.73061837255955, 42.475560978055, 40.724546536803246, 41.39953851699829, 42.59316846728325, 42.7022910118103, 41.97472125291824, 38.71190473437309, 41.9654231518507, 44.69603642821312, 42.54607379436493, 43.304752483963966, 42.76920922100544, 42.79437147080898, 41.6022652387619, 40.302647575736046, 43.051370680332184, 42.78185494244099, 42.00899541378021, 39.364914894104004, 42.35391430556774, 40.48219934105873, 42.49746300280094, 41.18289314210415, 42.89057470858097, 45.584276765584946, 46.27061113715172, 47.55529560148716, 50.018650218844414, 52.60489024221897, 54.91936884820461, 51.719051375985146, 51.528385207057, 50.49680136144161, 43.10058183968067, 42.414646446704865, 40.874919667840004, 40.03236427903175, 41.16070993244648, 39.116450026631355, 40.26982493698597, 40.460190922021866, 39.834090918302536, 39.93950866162777, 41.42512634396553, 40.707215666770935, 41.8406530469656, 42.6706463098526, 47.22608886659145, 51.95302002131939, 53.00337105989456, 54.60246205329895, 56.95724509656429, 60.23143820464611, 55.9777906537056, 52.83851310610771, 23.410422205924988, 0.24448750511510298, 6.1525120586156845, 9.324570447206497, 8.293029349297285, 0.5063294211868197, 3.144613173790276, 60.864617228507996, 63.84592965245247, 60.66613107919693, 52.39306300878525, 40.85226908326149, 41.431604996323586, 57.1429867297411, 37.615868747234344, 0.8206417271867394, 0.2100083333789371, 0.13135616085492074, 0.12269128987099975, 0.16323183401254937, 0.08625995062175207, 0.09346834194730036, 0.19269402808276936, 0.11718882888089865, 0.11181460358784534, 0.13104238081723452], [0.05752692406531423, 0.058872549125226215, 0.07321061217226088, 0.032428068516310304, 0.02942837068985682, 0.03869001746352296, 0.018358729721512645, 0.031791476503713056, 0.020477817379287444, 0.037970316043356434, 0.033012702770065516, 0.05656389839714393, 0.05121513990161475, 0.02736533002462238, 4.210628159344196, 42.886299937963486, 47.46592439711094, 33.002391904592514, 21.798784285783768, 30.787697844207287, 38.752216771245, 50.73508657515049, 47.5043061375618, 49.51758250594139, 5.69837705232203, 0.17441116069676355, 0.755025363760069, 1.642014558892697, 5.730509553104639, 0.2778386865975335, 17.52663552761078, 50.44735461473465, 53.93052510917187, 50.928093418478966, 49.94251750409603, 46.42608739435673, 39.07621018588543, 38.23570288717747, 37.36674651503563, 37.350981160998344, 41.24649412930012, 48.53826105594635, 50.3330909460783, 49.951808005571365, 49.00272153317928, 48.5503938049078, 48.3794903755188, 47.13272027671337, 50.436023622751236, 50.39780147373676, 49.730884060263634, 47.73810379207134, 47.483578249812126, 46.22247911989689, 47.00379699468613, 46.2352654337883, 47.23587714135647, 51.147033870220184, 48.50467845797539, 48.83425757288933, 41.319594606757164, 35.13447269797325, 36.91061519086361, 35.47807686030865, 37.962752133607864, 36.30352936685085, 37.13858015835285, 37.32294626533985, 40.49002692103386, 39.01656098663807, 38.65504838526249, 38.8178164511919, 38.42979647219181, 37.22529150545597, 39.89967919886112, 38.973946273326874, 38.830260783433914, 39.83015812933445, 37.67087459564209, 35.900686383247375, 35.2458219230175, 35.967281609773636, 35.47826685011387, 35.660280883312225, 35.86751036345959, 36.955399587750435, 41.61885894834995, 53.242389634251595, 53.10429744422436, 52.16738551855087, 52.190222293138504, 50.21384954452515, 43.695496916770935, 42.52874672412872, 38.406028747558594, 36.5678545832634, 35.12464262545109, 36.95690430700779, 37.62119226157665, 39.87854853272438, 38.9417278021574, 37.88922607898712, 36.18488073348999, 38.21920417249203, 39.09742444753647, 36.53635047376156, 38.60539264976978, 38.844787403941154, 39.23500366508961, 38.90930034220219, 38.08299668133259, 38.11240330338478, 35.87643228471279, 36.837757900357246, 37.24908962845802, 35.683938413858414, 39.485474824905396, 37.88336679339409, 41.406651735305786, 46.34089596569538, 47.76420459151268, 47.68033929169178, 51.50762692093849, 48.992861062288284, 48.19884426891804, 48.79832290112972, 48.38956743478775, 49.41593416035175, 49.07396391034126, 45.24752363562584, 42.70452529191971, 39.47877198457718, 38.28977398574352, 36.18656024336815, 37.474147751927376, 35.777538791298866, 35.39384298026562, 35.890609323978424, 37.794774547219276, 35.97288630902767, 36.47751063108444, 36.24554827809334, 39.00810644030571, 39.661933556199074, 44.26606670022011, 45.91053865849972, 49.938755705952644, 51.569662392139435, 55.15787065029144, 46.965430453419685, 13.361847158521414, 0.01612039006431587, 3.299091747030616, 5.627308515831828, 2.330637713894248, 0.23046748945489526, 5.39775475859642, 51.293523609638214, 55.70734776556492, 44.70811977982521, 28.876468800008297, 23.741956315934658, 29.66066502034664, 48.39100755751133, 15.626554135233164, 0.09446060081245378, 0.049094601345132105, 0.06269788995268755, 0.02981933965202188, 0.03562344099918846, 0.04354674689238891, 0.0347238578251563, 0.02132985115167685, 0.023970856018422637, 0.05612015345832333, 0.0676542341534514, 0.04008799733128399, 0.08908938121749088, 0.067614618310472, 0.03574316426238511, 0.03745158821402583, 0.04994237518985756, 0.04750489504658617, 0.015939562072162516, 0.012774455299222609, 0.030801609209447633, 0.05516689816431608, 0.01906551406136714, 0.03784473352425266, 0.0468739953066688, 6.1596062779426575, 51.0649848729372, 51.78275875747204, 35.20092353224754, 24.935312680900097, 36.66498877108097, 46.1942770332098, 56.68606124818325, 51.15845985710621, 53.492237627506256, 5.168383866548538, 0.21982075762934983, 0.7643336767796427, 4.410708798095584, 4.864232987165451, 0.47888373141177, 16.746223904192448, 52.59873457252979, 55.154382437467575, 52.9332572221756, 51.61550313234329, 48.928230330348015, 41.19243822991848, 40.50642304122448, 39.50382024049759, 39.3666286021471, 43.101288601756096, 49.47492219507694, 51.89416877925396, 52.17473052442074, 50.622832998633385, 48.937809616327286, 49.90509711205959, 47.56074070930481, 50.72431795299053, 50.22643826901913, 50.57000443339348, 49.84853334724903, 49.343270659446716, 49.61136907339096, 48.282758966088295, 48.66301216185093, 49.549280405044556, 52.219465523958206, 51.01617269217968, 50.53740978240967, 42.927383333444595, 37.198172360658646, 36.88090078532696, 36.996775567531586, 39.595330730080605, 39.465647488832474, 38.34401607513428, 39.767769277095795, 41.843582689762115, 39.910375624895096, 40.94089172780514, 40.664304569363594, 40.36679193377495, 39.161743596196175, 41.0437636077404, 41.21419966220856, 40.676061138510704, 42.59395882487297, 40.356053709983826, 39.29154463112354, 36.9193509221077, 39.113755971193314, 36.494218334555626, 38.473155945539474, 38.8527175784111, 39.838548079133034, 43.0980359762907, 53.58255498111248, 54.9150712788105, 54.921093955636024, 54.8402114957571, 50.829709097743034, 45.74842035770416, 43.310832157731056, 40.72653762996197, 38.63410770893097, 38.212866112589836, 38.665634617209435, 39.68106172978878, 40.2460952103138, 39.26496885716915, 39.872465059161186, 37.61765465140343, 39.45728413760662, 41.14670768380165, 38.48907329142094, 39.77787293493748, 40.35969391465187, 40.10260351002216, 41.354727521538734, 40.45737907290459, 39.71755117177963, 38.850867077708244, 37.487952411174774, 39.15480896830559, 37.5219301879406, 40.19956670701504, 40.14948159456253, 42.77352958917618, 49.07803729176521, 48.092510774731636, 49.20308858156204, 54.14032705128193, 50.752326250076294, 50.582513362169266, 51.26623347401619, 51.35159209370613, 50.58441326022148, 50.90397231280804, 48.127427101135254, 44.145590364933014, 39.924214482307434, 40.042939111590385, 37.17110641300678, 38.86627145111561, 37.2909177839756, 37.98973448574543, 37.75101609528065, 39.53432880342007, 37.386953830718994, 36.804665476083755, 38.08417461812496, 41.45479515194893, 41.508216485381126, 46.083136796951294, 48.88108626008034, 52.295757830142975, 52.98339933156967, 57.22527511417866, 49.61452670395374, 15.09782675653696, 0.13807345821987838, 6.902967039495707, 6.113519025966525, 5.826995875686407, 0.025941775747924112, 5.370155889540911, 56.68196126818657, 60.63228249549866, 51.38733297586441, 38.406921699643135, 28.87370064854622, 35.16197942197323, 55.94413585960865, 21.998404674232006, 0.028661578144237865, 0.0627788582642097, 0.03157983082928695, 0.07049194711726159, 0.039576405251864344, 0.022419882407120895, 0.07380085706245154, 0.02785385244351346, 0.03484073866275139, 0.06070628471206874, 0.030847464659018442, 0.0978834081615787, 0.24990798847284168, 0.1622314634732902, 0.13051640591584146, 0.17612093535717577, 0.18646028445800766, 0.062431993283098564, 0.13181369489757344, 0.13183615228626877, 0.11843223051982932, 0.12233725574333221, 0.14228668995201588, 0.20115531311603263, 0.17642359802266583, 8.849100060760975, 59.74514789879322, 58.258660063147545, 44.53028552234173, 31.993770226836205, 41.43703490495682, 51.991295367479324, 60.81611283123493, 55.772404074668884, 59.7030271589756, 6.981261363252997, 0.4783348389901221, 2.5416159303858876, 8.185906447470188, 12.741606440395117, 1.8051379057578743, 21.763691268861294, 55.54972842335701, 56.864556670188904, 57.710482478141785, 55.40709167718887, 50.87669737637043, 43.92136439681053, 43.25723223388195, 42.38494724035263, 41.705710887908936, 46.28968991339207, 52.394613325595856, 54.21096906065941, 54.431330636143684, 52.96979986131191, 51.82487569749355, 50.082331001758575, 50.40616102516651, 51.94237679243088, 52.991625890135765, 52.95357093214989, 51.387602761387825, 51.37245297431946, 49.9283404648304, 50.78099571168423, 51.781075447797775, 50.82433618605137, 55.64030796289444, 54.635600075125694, 52.11766518652439, 45.911161825060844, 39.011241272091866, 41.994016617536545, 39.402122497558594, 41.813389509916306, 40.69513991475105, 39.57837224006653, 41.47214502096176, 43.8728030025959, 41.049090921878815, 41.52527377009392, 41.54041215777397, 41.91916063427925, 41.29695542156696, 43.517750054597855, 42.630775049328804, 41.79337598383427, 44.80836220085621, 43.42965178191662, 39.945755526423454, 38.517643958330154, 40.84287218749523, 39.57852803170681, 41.7429830878973, 39.73444126546383, 42.540427297353745, 44.30998854339123, 56.54780566692352, 56.5923772752285, 54.89692345261574, 56.73215277493, 53.77766311168671, 49.32866804301739, 46.271937265992165, 44.37203161418438, 39.92071107029915, 40.35873256623745, 42.11192429065704, 42.78515696525574, 43.41091878712177, 41.1646731197834, 40.269444957375526, 39.49747458100319, 40.44589228928089, 42.46352322399616, 39.61267299950123, 40.994449853897095, 43.58106225728989, 43.25935252010822, 43.407430574297905, 40.911656096577644, 43.0306313931942, 39.211847707629204, 39.70943860709667, 39.89689774811268, 38.27548295259476, 43.17388750612736, 42.46325723826885, 44.61374044418335, 52.23644681274891, 51.13257184624672, 52.002143785357475, 56.0042068362236, 52.994908913969994, 52.433888018131256, 53.38915675878525, 53.07887300848961, 53.98877218365669, 53.28280806541443, 50.309349820017815, 46.559042260050774, 43.31255346536636, 41.45702563226223, 39.90430735051632, 42.05874614417553, 40.126804411411285, 39.478407204151154, 40.09588927030563, 40.23871600627899, 40.40982082486153, 38.600977286696434, 41.83589190244675, 42.45840109884739, 43.50980848073959, 48.25631998479366, 52.03554019331932, 54.934754222631454, 57.43030071258545, 57.87382431328297, 54.118352830410004, 18.435523957014084, 0.14922289119567722, 9.986588973551989, 15.063127968460321, 10.551534108817577, 0.3095262253191322, 6.428197715431452, 62.12207615375519, 65.40007665753365, 56.322956532239914, 45.423807576298714, 33.84122349321842, 42.861156687140465, 66.81754499673843, 29.102982245385647, 0.2517016703495756, 0.13901525846449658, 0.09840198385063559, 0.1504767348524183, 0.13996406458318233, 0.13682329561561346, 0.1973420544527471, 0.12195167291793041, 0.11341376855853014, 0.20059368544025347, 0.18216737575130537], [0.012705284352705348, 0.037625677505275235, 0.041508200811222196, 0.07039888922008686, 0.013852378415322164, 0.0459692430740688, 0.13113739056279883, 0.027490389329614118, 0.05690007645171136, 0.03175750840455294, 0.002759652711574745, 0.04034511439385824, 0.06390751645085402, 0.011356866034475388, 5.174534786492586, 38.90349045395851, 51.59320592880249, 24.508282095193863, 43.64019088447094, 41.44689537584782, 27.38545160740614, 59.54852744936943, 45.11983908712864, 55.079100877046585, 15.906700752675533, 0.043284727944410406, 0.21950500347884372, 4.2398015689104795, 3.8123981282114983, 0.979524739086628, 27.71507441997528, 54.957625195384026, 52.5344268232584, 49.26715314388275, 48.23395058512688, 43.161321580410004, 39.22668591141701, 36.84753857553005, 37.68782168626785, 39.178242310881615, 45.23176588118076, 49.08705800771713, 51.44519627094269, 52.03372769057751, 48.75581458210945, 46.775026470422745, 47.883411794900894, 50.40782153606415, 50.8539479970932, 48.9403934776783, 48.158950209617615, 47.074644193053246, 45.533519089221954, 43.68656739592552, 41.5275764465332, 43.42120863497257, 43.573918640613556, 45.209119096398354, 44.35855753719807, 40.37735156714916, 36.39813669025898, 36.42506584525108, 35.366366654634476, 36.56333662569523, 35.68253628909588, 37.3163878172636, 36.310897171497345, 37.243868708610535, 38.35536986589432, 37.93100483715534, 40.59993602335453, 39.1790858656168, 39.83256720006466, 40.33189460635185, 39.32260796427727, 37.38583289086819, 37.766336873173714, 38.45147430896759, 37.951417341828346, 37.862277925014496, 35.99399797618389, 34.48113575577736, 34.8390157520771, 34.6441014111042, 38.23405757546425, 37.090535536408424, 43.90046551823616, 51.69127106666565, 51.982567235827446, 53.17674055695534, 51.37721411883831, 48.20814996957779, 42.75385044515133, 39.46800336241722, 38.346261754631996, 37.803460881114006, 35.923659950494766, 35.847956612706184, 39.51194800436497, 38.18537838757038, 38.721803203225136, 36.5203533321619, 38.75371389091015, 39.645830020308495, 37.3781269043684, 36.984753012657166, 37.941237688064575, 38.19561503827572, 38.77800978720188, 38.50700452923775, 39.240387976169586, 38.13059292733669, 37.279541194438934, 36.68234623968601, 38.705133497714996, 36.05452112853527, 36.50606229901314, 37.54730902612209, 45.93071177601814, 46.95302791893482, 51.89193829894066, 48.83068576455116, 48.60753893852234, 45.88401608169079, 48.089106157422066, 48.780232071876526, 48.294842317700386, 50.913574397563934, 51.87903419137001, 49.475397169589996, 46.6519358754158, 45.118729546666145, 42.57033549249172, 40.43539345264435, 37.86186374723911, 36.53350442647934, 36.07467904686928, 34.84001889824867, 36.038155406713486, 36.676209568977356, 36.72642007470131, 36.610343903303146, 37.346444204449654, 36.77779711782932, 37.50713758170605, 42.97118358314037, 50.88099494576454, 50.840386524796486, 56.52589984238148, 42.59087339043617, 5.423344485461712, 0.07429442237480544, 2.275659888982773, 3.2952608400955796, 6.346371481195092, 0.03888807070325129, 9.822335187345743, 59.00703750550747, 50.14430567622185, 44.552818313241005, 24.532446898519993, 24.8246094211936, 34.27383407950401, 43.20813126862049, 10.048363208770752, 0.1549164848984219, 0.03504541557049379, 0.03998116517323069, 0.029540171526605263, 0.004672416125686141, 0.05909019135287963, 0.031708905153209344, 0.018452258882462047, 0.036797919383388944, 0.006412348884623498, 0.03466456022579223, 0.02356870289077051, 0.026998245230061002, 0.04288509997422807, 0.0505171091936063, 0.012420941602613311, 0.04589749594742898, 0.08415462609264068, 0.030913064947526436, 0.0607386497722473, 0.01814420636947034, 0.0749827123945579, 0.06850658333860338, 0.09270531023503281, 0.02489283349859761, 5.673002013936639, 47.53851190209389, 58.23953188955784, 32.30670243501663, 41.73205107450485, 40.898166820406914, 35.77669143676758, 63.091301545500755, 50.35554014146328, 60.53652383387089, 16.4021048694849, 0.071205566637218, 0.7021725154481828, 4.3915193527936935, 4.233150025829673, 1.1377419554628432, 31.613718420267105, 55.63527323305607, 55.18312409520149, 51.02371148765087, 51.49769805371761, 45.805018320679665, 40.837867856025696, 38.65700148046017, 40.29443621635437, 40.60847796499729, 48.38233262300491, 51.79886609315872, 53.346629440784454, 52.44483523070812, 50.626845583319664, 47.281349301338196, 49.26572062075138, 52.13826388120651, 52.82799907028675, 51.02197118103504, 49.32305194437504, 49.21300984919071, 48.387257158756256, 47.52482123672962, 44.13889892399311, 45.29169626533985, 46.222372725605965, 47.70980291068554, 47.48551994562149, 41.79528348147869, 37.691313698887825, 37.32273727655411, 37.796461656689644, 38.34698371589184, 38.629559352993965, 38.22760172188282, 38.34411486983299, 39.159273728728294, 41.519878059625626, 39.4450905919075, 41.2228973954916, 39.495491087436676, 40.5782125890255, 42.339794263243675, 40.48342287540436, 38.53035807609558, 39.72013123333454, 40.0361754745245, 40.36270335316658, 39.04026411473751, 39.5551934838295, 36.7924415320158, 36.23636797070503, 36.091569140553474, 39.85866039991379, 38.09026949107647, 46.1505413800478, 52.683116644620895, 53.244867101311684, 55.60464307665825, 52.65912093222141, 49.93011116981506, 46.85505397617817, 42.58452773094177, 41.00435972213745, 39.17469710111618, 36.729923486709595, 39.21108394861221, 40.18945924937725, 40.69354020059109, 40.03736101090908, 39.279446080327034, 41.671212539076805, 42.04665519297123, 38.62425483763218, 38.48290242254734, 38.34117002785206, 39.58381734788418, 41.32739558815956, 41.66310757398605, 40.302259996533394, 38.77060018479824, 37.90528021752834, 38.30831319093704, 39.67774450778961, 38.6398795992136, 38.79651099443436, 39.307401180267334, 48.3653399348259, 48.94091784954071, 54.24159161746502, 49.468622133135796, 50.18254302442074, 49.05428856611252, 49.158790558576584, 49.807693138718605, 50.415759310126305, 51.961067989468575, 54.38167490065098, 51.693136766552925, 49.001703187823296, 47.82991446554661, 43.68787072598934, 41.99203312397003, 38.729452192783356, 39.51558820903301, 38.47800448536873, 37.46299535036087, 37.342621609568596, 38.954825699329376, 39.64805670082569, 38.68214853107929, 39.75298047065735, 38.66302415728569, 40.6130301207304, 45.620815604925156, 53.185844868421555, 53.77322494983673, 56.40196189284325, 44.840584471821785, 8.454005811363459, 0.6979623413644731, 5.864659929648042, 6.789178820326924, 3.930726391263306, 0.13478895009029657, 10.1691216789186, 62.73157484829426, 55.165504440665245, 51.85143247246742, 29.716706313192844, 25.26587024331093, 38.77973489463329, 51.6304287314415, 14.023047778755426, 0.13174090505344793, 0.04252927355992142, 0.05757479630119633, 0.0224962364154635, 0.01476740382713615, 0.018678053602343425, 0.05963219664408825, 0.10491874549188651, 0.05927244797931053, 0.05393599429226015, 0.004573915039145504, 0.1219445260358043, 0.1382687914883718, 0.14963312074542046, 0.1353469560854137, 0.18921535927802324, 0.16276716050924733, 0.30127758043818176, 0.08344515517819673, 0.16942679299972951, 0.17149374849395826, 0.21489895298145711, 0.17177475529024377, 0.18705082620726898, 0.16302789183100685, 7.636449756100774, 55.30179172754288, 65.69671913981438, 36.857068464159966, 49.99125748872757, 53.108925595879555, 38.37424345314503, 69.89899724721909, 55.406707897782326, 66.20589941740036, 21.173987612128258, 0.1384894468355924, 2.0133984368294477, 12.91506428271532, 9.450411144644022, 2.23102914635092, 34.10782478749752, 57.33562119305134, 57.81238541007042, 54.07316945493221, 54.99335467815399, 48.259606808423996, 42.57755510509014, 41.28047950565815, 41.924970522522926, 43.26974116265774, 50.729413479566574, 53.63708585500717, 56.325016021728516, 55.32190404832363, 49.912525713443756, 47.05686874687672, 49.781299754977226, 55.26318959891796, 54.470510333776474, 53.5107958316803, 52.29116387665272, 53.55597160756588, 49.299698397517204, 49.20169025659561, 47.076992467045784, 48.14701125025749, 46.31328284740448, 50.22540092468262, 47.29703865945339, 44.82338659465313, 39.78410080075264, 40.656074211001396, 39.431905299425125, 40.500468760728836, 38.56617495417595, 40.85738740861416, 39.580975100398064, 39.35175620019436, 43.19120317697525, 42.643819749355316, 43.11222821474075, 42.155230566859245, 43.43079552054405, 44.840918853878975, 43.11383552849293, 40.53952306509018, 41.45379580557346, 42.019357457756996, 42.292802184820175, 41.34113185107708, 41.28633499145508, 38.45670662820339, 40.49030050635338, 38.902327716350555, 42.96824634075165, 39.94863957166672, 47.85230666399002, 55.80561049282551, 55.040016174316406, 56.50188513100147, 54.77608993649483, 52.12430723011494, 48.460342437028885, 43.688911870121956, 43.87714996933937, 42.293763533234596, 38.89752097427845, 41.405390202999115, 43.86074244976044, 43.99251937866211, 43.81666101515293, 40.79673886299133, 43.76369945704937, 43.52811969816685, 40.5129586905241, 39.978213384747505, 40.22502154111862, 40.89878238737583, 43.54482740163803, 42.72129379212856, 42.56796821951866, 41.64152093231678, 40.818899273872375, 40.13403922319412, 42.830895110964775, 39.3733998388052, 40.73475278913975, 40.71458727121353, 50.53362138569355, 50.832300558686256, 56.42492026090622, 52.09763266146183, 52.27486275136471, 51.76059074699879, 49.370891377329826, 52.89625860750675, 51.42177052795887, 53.26296553015709, 56.051157116889954, 54.217394515872, 51.076023280620575, 49.609700962901115, 46.2871478497982, 44.00596305727959, 41.815859377384186, 41.369425132870674, 38.627982437610626, 38.52553233504295, 40.07006585597992, 40.09362459182739, 41.91358633339405, 40.45025445520878, 40.83311051130295, 41.82656340301037, 41.85972802340984, 47.23382145166397, 54.59534503519535, 57.558486834168434, 58.51893849670887, 49.00318890810013, 10.20605854690075, 0.6572342861909419, 9.348822645843029, 11.700844187289476, 15.655257795006037, 0.16783782513812184, 11.367646716535091, 71.64333164691925, 57.829739078879356, 56.83284357190132, 35.20598866045475, 36.765964552760124, 47.10305146872997, 59.74501110613346, 18.028064221143723, 0.2861770719755441, 0.10310280660632998, 0.12807043560314924, 0.11837700731121004, 0.08463029080303386, 0.1898065986461006, 0.2556341327726841, 0.1460841705556959, 0.1337927652639337, 0.13433750165859237, 0.14175072574289516], [0.04896248792647384, 0.06755299036740325, 0.045219184103189036, 0.030993975742603652, 0.04998277028789744, 0.030986706406110898, 0.045004666317254305, 0.009231235417246353, 0.06418315751943737, 0.04853800171986222, 0.09363723991555162, 0.052281646931078285, 0.004841524678340647, 0.050546260754344985, 1.3903575064614415, 36.85963712632656, 50.192745476961136, 43.90440210700035, 55.34001387655735, 64.09826651215553, 37.91680879890919, 45.7897013425827, 50.71199521422386, 52.17928268015385, 33.90712335705757, 0.28539235470816493, 0.2169816568493843, 2.7599534019827843, 2.415911788120866, 0.18160512467147782, 23.563857972621918, 57.47359558939934, 52.28872440755367, 50.95364324748516, 46.22322767972946, 44.179488345980644, 40.09822994470596, 37.706345692276955, 37.367540672421455, 43.61964538693428, 49.66372646391392, 50.63525453209877, 51.87764346599579, 47.84596860408783, 44.578767120838165, 46.130660846829414, 52.41316772997379, 50.23289792239666, 47.20817282795906, 48.18701930344105, 43.67674872279167, 43.01570579409599, 41.485079526901245, 42.442593947052956, 39.53234151005745, 39.67522144317627, 41.55745044350624, 39.25854340195656, 38.64276364445686, 35.86335338652134, 34.833084270358086, 35.47714211046696, 38.259736597537994, 36.478190794587135, 36.905261278152466, 37.49954178929329, 36.831146255135536, 36.68594464659691, 38.67609165608883, 37.9705835133791, 37.373988926410675, 38.50608877837658, 39.949726313352585, 39.87519711256027, 37.76314124464989, 38.2030588388443, 37.74470463395119, 38.78227695822716, 37.11604356765747, 37.01216474175453, 35.93335323035717, 35.831047520041466, 35.232705026865005, 35.315396189689636, 36.584900468587875, 36.440158635377884, 44.171273186802864, 51.669186651706696, 50.73093719780445, 50.90209521353245, 51.79962985217571, 51.10151991248131, 44.37711954116821, 41.808818355202675, 40.17915420234203, 38.73050093650818, 37.49044127762318, 36.34204789996147, 38.66879224777222, 37.856601029634476, 36.604047641158104, 39.21160452067852, 38.015421107411385, 38.204848542809486, 35.91633774340153, 38.26793275773525, 36.93725936114788, 37.72151827812195, 38.45239005982876, 37.983058243989944, 38.33979070186615, 37.060095369815826, 35.79710394144058, 37.04073540866375, 37.24364452064037, 36.819260492920876, 36.13853842020035, 38.53317752480507, 45.15424244105816, 47.16191031038761, 47.52299353480339, 49.50214013457298, 49.463340416550636, 50.92845439910889, 49.878308549523354, 47.43514604866505, 47.2699499130249, 45.63776649534702, 48.853575736284256, 49.08339500427246, 48.78390647470951, 47.43986539542675, 45.911222621798515, 46.120739579200745, 43.60953412950039, 43.025414273142815, 37.670639008283615, 35.805003717541695, 37.738932743668556, 37.071061581373215, 37.926068902015686, 38.84023904800415, 40.40991961956024, 39.574580043554306, 38.37591916322708, 43.9372893422842, 51.59569099545479, 49.83412832021713, 57.258519530296326, 40.169115141034126, 2.056897315196693, 0.3035317501053214, 6.5508651081472635, 4.360173409804702, 4.101476166397333, 0.12513295572716743, 16.023918762803078, 57.75910846889019, 47.45132178068161, 39.4609547406435, 22.902355268597603, 24.69669308513403, 36.31994068622589, 39.7956445813179, 3.8157400488853455, 0.15334945492213592, 0.03166516667988617, 0.05908195722440723, 0.023971809678187128, 0.012471443824324524, 0.04821164227905683, 0.05567123203945812, 0.06726340434397571, 0.02194287440943299, 0.030602897313656285, 0.01657324486586731, 0.0175714409124339, 0.02242396421934245, 0.05509659822564572, 0.05528795729333069, 0.021907880291109905, 0.011656061942630913, 0.032770413818070665, 0.02925956363469595, 0.004215424778521992, 0.1033460306643974, 0.04139677475905046, 0.04313439851102885, 0.059383907428127714, 0.06142627928056754, 2.5587418489158154, 43.73856380581856, 57.03015558421612, 41.27962455153465, 54.49706710875034, 59.19652573764324, 37.839243561029434, 57.12643101811409, 55.37451222538948, 58.02001006901264, 34.037296772003174, 0.1801467896439135, 0.1335832866607234, 7.638895399868488, 3.7200312595814466, 0.5012284324038774, 26.81223526597023, 58.213974460959435, 55.89348457753658, 52.922724187374115, 49.3116145581007, 46.06117017567158, 40.16951031982899, 40.398611426353455, 40.66552430391312, 45.62521196901798, 51.0578640550375, 52.670786306262016, 52.7803610265255, 51.598141863942146, 47.02987119555473, 46.36193163692951, 51.476852372288704, 52.696503326296806, 50.03526292741299, 49.21449176967144, 47.772294357419014, 46.60304009914398, 43.7456314265728, 43.088133707642555, 42.081921100616455, 42.131417244672775, 44.71443124115467, 40.91951407492161, 40.010181069374084, 36.3493625074625, 36.78816296160221, 37.72226303815842, 40.13917274773121, 39.30464632809162, 38.58786039054394, 38.640673756599426, 39.490729942917824, 38.02652791142464, 39.58148047327995, 39.21905592083931, 40.561086907982826, 39.26170863211155, 40.976252630352974, 41.282140016555786, 39.30147349834442, 39.74272862076759, 39.264870062470436, 40.839908346533775, 41.03189304471016, 40.222555473446846, 39.38462443649769, 36.825340166687965, 37.27027729153633, 36.75515413284302, 38.15597176551819, 38.47333453595638, 45.56161858141422, 53.8845893740654, 53.64479564130306, 52.48762093484402, 53.08826610445976, 53.296054154634476, 45.178010165691376, 44.58987392485142, 42.1088882535696, 40.78493669629097, 38.496669083833694, 38.845912143588066, 40.04968374967575, 40.80376088619232, 39.52647462487221, 40.45268252491951, 39.459199234843254, 40.24826489388943, 38.27464319765568, 39.21110674738884, 38.62340368330479, 38.83559949696064, 39.91450600326061, 40.61039686203003, 39.72484678030014, 39.92919981479645, 37.005769684910774, 39.502076134085655, 38.63107927143574, 39.02037978172302, 36.782995238900185, 41.60052493214607, 46.69306866824627, 48.27843859791756, 49.90965686738491, 52.57645256817341, 52.44603216648102, 51.57445393502712, 50.83185218274593, 49.54007349908352, 47.40527585148811, 48.51740397512913, 51.410473734140396, 52.58903369307518, 51.81672893464565, 49.272514656186104, 48.298049345612526, 47.53166846930981, 45.72509340941906, 45.50753228366375, 39.4811886548996, 38.05476799607277, 39.1694799810648, 38.562869131565094, 39.758148193359375, 41.31963640451431, 42.79032848775387, 41.145468950271606, 40.220549181103706, 45.7276126742363, 53.59326280653477, 52.74660363793373, 57.91033275425434, 42.7196104824543, 2.3044426320120692, 0.8537844987586141, 7.223368221893907, 7.763015264645219, 5.417393054813147, 0.29059273190796375, 16.325462982058525, 65.9962722659111, 52.32772171497345, 48.47075767815113, 30.094295851886272, 30.19924432039261, 41.289694011211395, 50.1223960518837, 6.141366781666875, 0.1903118973132223, 0.04998621385311708, 0.0374161840591114, 0.013803995025227778, 0.05121608242916409, 0.040055862336885184, 0.03811150963883847, 0.04177005648671184, 0.06570284589543007, 0.04189394319837447, 0.051846095302607864, 0.11518221741425805, 0.1646515922038816, 0.13101935939630494, 0.1416438416345045, 0.10274549960740842, 0.13184853130951524, 0.17280712723731995, 0.16856700007338077, 0.1579016848700121, 0.29136245779227465, 0.164261934987735, 0.12114415687392466, 0.09351982473162934, 0.17868631723104045, 2.926205168478191, 50.500319972634315, 65.94787806272507, 52.88029186427593, 64.27967637777328, 69.81246069073677, 48.60376574099064, 58.53890262544155, 59.94940213859081, 62.400251626968384, 38.91528882086277, 0.5178165016695857, 0.8469387504737824, 12.057515848428011, 7.890298934653401, 0.5872805742546916, 29.723918326199055, 60.83134241402149, 57.20472201704979, 55.86858071386814, 51.09340734779835, 47.93338671326637, 43.2986918091774, 42.7601733058691, 42.0271660387516, 48.52067559957504, 53.90179485082626, 53.62539388239384, 55.38869306445122, 50.63911512494087, 47.39897578954697, 47.283028811216354, 55.109491646289825, 55.5724436044693, 52.37526476383209, 51.813301518559456, 48.070183172822, 48.45970407128334, 45.99871672689915, 46.15151412785053, 45.25922700762749, 44.71107602119446, 46.16110861301422, 44.11994554102421, 42.400412410497665, 39.07648757100105, 38.71477358043194, 39.26179602742195, 43.69541712105274, 40.934321880340576, 40.12783035635948, 40.818230509757996, 41.05856001377106, 39.21601988375187, 42.111821696162224, 40.97375236451626, 41.51067495346069, 42.13257998228073, 43.54491479694843, 42.79629796743393, 41.57145269215107, 41.930784210562706, 41.56903602182865, 42.22847543656826, 42.16640956699848, 41.141410768032074, 42.02486716210842, 39.18106935918331, 40.60389541089535, 39.58590343594551, 40.85629686713219, 40.43336436152458, 48.66795189678669, 55.29121309518814, 53.20792928338051, 53.87453131377697, 54.13660325109959, 55.49199812114239, 49.58890847861767, 46.939413249492645, 44.43271815776825, 42.37005963921547, 42.47781045734882, 39.786069095134735, 42.41271995007992, 41.363482251763344, 42.15650349855423, 42.861380875110626, 41.37086145579815, 40.25814816355705, 40.42464762926102, 41.855776235461235, 40.468919053673744, 40.393439903855324, 43.23145441710949, 41.675662100315094, 41.232925057411194, 41.74659289419651, 39.82316270470619, 40.44274985790253, 41.52411103248596, 40.00248648226261, 38.09109404683113, 43.46576124429703, 48.907719030976295, 50.2804409712553, 51.26163192093372, 54.141026213765144, 53.964077308773994, 52.38104425370693, 52.60000750422478, 50.568860694766045, 48.6677885055542, 47.9714834690094, 51.53921842575073, 53.19858558475971, 53.85060779750347, 51.17082439363003, 50.18611863255501, 50.24971202015877, 47.638796120882034, 48.193585351109505, 41.67399398982525, 39.23523925244808, 42.33277224004269, 40.86204215884209, 43.628559708595276, 43.21315459907055, 45.68403281271458, 43.920080065727234, 41.361434161663055, 48.40293511748314, 57.678522393107414, 57.10373863577843, 59.3990358710289, 45.811458975076675, 3.661189042031765, 0.5658247286919504, 14.659921154379845, 13.109326008707285, 10.371472220867872, 0.2563266456127167, 18.891244903206825, 71.93259492516518, 56.49329759180546, 53.20244997739792, 34.38920348882675, 38.768502697348595, 48.99627327919006, 57.21291057765484, 8.567386977374554, 0.27594347891863436, 0.13380361546296626, 0.11630273424088955, 0.06798585542128421, 0.14767155022127554, 0.10221324613667093, 0.14980770356487483, 0.1387997981510125, 0.16394094127463177, 0.12666471884585917, 0.19800485169980675], [0.017526143928989768, 0.07813911841367371, 0.0329947353748139, 0.053523460373980924, 0.03206171473721042, 0.017964430371648632, 0.025224580931535456, 0.21418858406832442, 0.08825739656458609, 0.068367942731129, 0.010769928339868784, 0.017109051368606742, 0.06305128583335318, 0.03663556715764571, 0.7466816646046937, 25.853259824216366, 52.687285020947456, 39.821475595235825, 58.055496364831924, 77.09989205002785, 57.0670136064291, 39.16945718228817, 53.35745885968208, 47.00934089720249, 46.96378894150257, 4.199894685298204, 0.2313564339419827, 5.062289759516716, 2.4314945144578815, 0.3917812724830583, 27.66236174851656, 59.08870652318001, 52.174308747053146, 50.393610298633575, 45.78854240477085, 41.28119766712189, 38.83214548230171, 39.35521021485329, 41.21751308441162, 47.02273137867451, 48.32605384290218, 51.997272446751595, 48.70960146188736, 45.544709488749504, 47.24477246403694, 51.02370768785477, 50.70734426379204, 50.49420230090618, 45.89237183332443, 44.344680681824684, 41.95155389606953, 41.764132753014565, 38.64930309355259, 39.091196581721306, 37.48459339141846, 37.166178077459335, 38.974907621741295, 38.03856946527958, 36.102554351091385, 35.87402321398258, 37.68879823386669, 37.89987690746784, 37.04484298825264, 37.485311552882195, 36.4335697889328, 38.372997120022774, 36.461889669299126, 38.68301868438721, 38.32014575600624, 39.13514882326126, 38.96620608866215, 39.09694567322731, 39.164411053061485, 38.70278142392635, 39.1842307895422, 39.86414350569248, 39.55194465816021, 38.925350680947304, 38.05484779179096, 38.42030078172684, 34.557804241776466, 36.104397252202034, 36.32711850106716, 37.30057306587696, 36.5721445530653, 37.80463881790638, 43.697400614619255, 51.682854518294334, 51.54329560697079, 52.65331484377384, 52.60091185569763, 50.667913779616356, 45.4142776876688, 43.6627122759819, 42.044420912861824, 40.411226749420166, 36.46533228456974, 37.55175478756428, 37.0044207572937, 38.594099655747414, 37.74945817887783, 36.91323325037956, 38.270543217659, 38.122328370809555, 37.94509448111057, 37.638146951794624, 37.40323595702648, 37.38971248269081, 37.59142845869064, 38.279666528105736, 37.425525560975075, 37.559814155101776, 36.69406101107597, 37.23249591886997, 36.88924893736839, 37.24695414304733, 37.161546126008034, 38.56714770197868, 43.94350200891495, 48.493047282099724, 47.04764284193516, 49.260340109467506, 51.566994935274124, 48.33600550889969, 48.002976179122925, 50.32756224274635, 47.89829179644585, 47.68850885331631, 49.17753875255585, 50.00773340463638, 48.54055613279343, 49.36416193842888, 48.81789185106754, 47.641136795282364, 46.976586654782295, 44.99857239425182, 43.19420501589775, 41.12890183925629, 39.0418866276741, 38.827954307198524, 37.74878941476345, 36.30941525101662, 40.49075648188591, 40.77777788043022, 40.70996291935444, 46.757851392030716, 51.736792623996735, 51.42753481864929, 57.141793593764305, 34.39741864800453, 1.9688060483895242, 1.4195588207803667, 3.4238882130011916, 5.493653062731028, 2.221963070333004, 0.2952508069574833, 21.57924346625805, 57.65849746763706, 48.76916706562042, 40.72012357413769, 22.032492645084858, 24.12872426211834, 36.39617219567299, 27.74995844811201, 1.1861164472065866, 0.11320495788822882, 0.04021067434223369, 0.02650822738360148, 0.0522376227308996, 0.04007859432022087, 0.09757999592693523, 0.07491185213439167, 0.05543787112401333, 0.008672194126120303, 0.009268635021726368, 0.013897160533815622, 0.047208997057168745, 0.06700023135636002, 0.04474453613511287, 0.07174081096309237, 0.08216753310989588, 0.02370308542595012, 0.06568694167071953, 0.1003279906581156, 0.14539370604325086, 0.029243249373394065, 0.005938936128586647, 0.05312996625434607, 0.07094854605384171, 0.06069575363653712, 0.889301192946732, 33.89942117035389, 58.54136869311333, 46.579648554325104, 59.86611060798168, 75.1861323416233, 56.354369446635246, 44.1042485833168, 58.25014851987362, 52.08180271089077, 50.5348677188158, 3.9662207616493106, 0.08051355311181396, 5.491670519113541, 3.8413898600265384, 0.5511712899897248, 28.385917022824287, 59.40179832279682, 53.82161535322666, 52.6381004601717, 47.3859690874815, 43.35421442985535, 40.95974251627922, 40.962713956832886, 43.11370633542538, 49.00893799960613, 51.70043997466564, 53.23198199272156, 51.0955124348402, 48.38483668863773, 48.67903970181942, 52.21442699432373, 52.72141478955746, 52.44703911244869, 48.13605643808842, 46.70443005859852, 44.28859569132328, 44.05085004866123, 42.485254257917404, 42.41487443447113, 38.45883831381798, 40.85609927773476, 39.46814015507698, 40.027846321463585, 37.7213890850544, 39.375060349702835, 38.842670917510986, 39.95576038956642, 39.06146317720413, 40.13087399303913, 39.843290224671364, 39.28222753107548, 38.20994406938553, 41.02492041885853, 39.04836907982826, 39.494788125157356, 39.71139170229435, 41.49930976331234, 40.607262030243874, 39.254785403609276, 41.10641464591026, 40.06228767335415, 38.325731456279755, 40.51268510520458, 39.469850063323975, 40.17324931919575, 37.498124465346336, 39.051329120993614, 37.84463167190552, 38.23072515428066, 39.37952511012554, 41.00302219390869, 44.25991103053093, 52.658410370349884, 52.88282252848148, 53.59846092760563, 55.33617988228798, 52.388514652848244, 47.7450118213892, 45.14888092875481, 45.22184461355209, 42.20771715044975, 38.85093167424202, 38.975207805633545, 38.580997958779335, 40.36685653030872, 38.718542978167534, 40.43830789625645, 40.16372323036194, 39.77199465036392, 39.447298273444176, 39.535373747348785, 39.93922367691994, 38.94705131649971, 38.51932346820831, 38.61431077122688, 38.776907846331596, 38.99824596941471, 38.14836077392101, 38.951831459999084, 37.76608608663082, 38.74052859842777, 38.15876081585884, 40.912830233573914, 46.45331293344498, 51.53223820030689, 49.15708065032959, 51.04975908994675, 52.72983893752098, 51.63684278726578, 50.400468930602074, 51.89042218029499, 49.965365678071976, 51.123212948441505, 49.996372014284134, 52.084534764289856, 50.771492421627045, 51.28362514078617, 49.640699699521065, 51.65948197245598, 49.448513612151146, 46.82590574026108, 45.54532505571842, 42.24616348743439, 40.6710834056139, 40.10775603353977, 38.26118811964989, 37.6316948980093, 41.62173919379711, 42.54079967737198, 41.51409476995468, 48.186510130763054, 53.83119083940983, 54.068077728152275, 57.91848711669445, 37.89433680474758, 2.569045233540237, 2.080702087841928, 8.68265949189663, 6.714813010767102, 3.704260680824518, 0.3859428263967857, 22.464003190398216, 63.34659464657307, 52.99267463386059, 46.69970691204071, 23.588758036494255, 26.180756650865078, 40.299516543745995, 36.535765305161476, 2.259013932198286, 0.09819675033213571, 0.026822302424989175, 0.03530593909090385, 0.07843296436476521, 0.031198014403344132, 0.08888826661859639, 0.019072781542490702, 0.037619974100380205, 0.021278386921039782, 0.04404182618600316, 0.025247967860195786, 0.1523476594593376, 0.10533431108342484, 0.1338118829880841, 0.15013000345788896, 0.2744240948231891, 0.1439296267926693, 0.12569902144605294, 0.4230805195402354, 0.2931490744231269, 0.17145422170870006, 0.11784374451963231, 0.14226181316189468, 0.1838509229128249, 0.10921995140961371, 1.2722528376616538, 39.63693089783192, 66.59296944737434, 51.83173432946205, 66.91367983818054, 79.82396587729454, 62.41855904459953, 49.77776974439621, 63.791782557964325, 56.06454759836197, 56.28793001174927, 5.850508539006114, 0.5622339807450771, 8.260768130421638, 3.933874284848571, 1.1681605107150972, 32.168583646416664, 62.72523678839207, 57.78249241411686, 55.692870542407036, 50.543736442923546, 46.25566653907299, 42.94255591928959, 43.082567006349564, 45.455991849303246, 53.115742430090904, 53.947331607341766, 55.031671822071075, 51.1328112334013, 50.59754155576229, 50.14742150902748, 54.29307885468006, 54.86519515514374, 54.969545155763626, 50.770515874028206, 49.845759496092796, 46.92217357456684, 47.81448729336262, 44.7792861610651, 44.9678548425436, 41.42101876437664, 42.119634076952934, 42.062713131308556, 41.67012199759483, 39.55688439309597, 41.840136274695396, 42.13899403810501, 42.666964307427406, 40.94584286212921, 40.7661809027195, 40.23991674184799, 41.65212996304035, 39.65290904045105, 43.65597143769264, 41.15817166864872, 41.532698571681976, 41.73702500760555, 42.95474946498871, 43.4314376860857, 42.286327332258224, 42.963321805000305, 44.417655766010284, 42.015018090605736, 42.94067122042179, 41.95207066833973, 42.62607090175152, 38.542057648301125, 42.650568187236786, 39.78007681667805, 40.86844481527805, 41.65054924786091, 42.94646590948105, 46.40281744301319, 53.75445015728474, 54.00692380964756, 55.001041665673256, 56.46870531141758, 54.33242194354534, 50.27700215578079, 46.88425540924072, 47.89853498339653, 45.36091335117817, 40.68616099655628, 41.14334486424923, 40.71139544248581, 41.08446702361107, 41.13334380090237, 40.99810145795345, 42.89979301393032, 41.14429861307144, 41.59291014075279, 41.31536543369293, 40.51585413515568, 41.39863796532154, 39.93992283940315, 40.26586554944515, 40.75768455862999, 40.96854664385319, 41.09703294932842, 40.50640404224396, 40.73599152266979, 41.05209656059742, 40.92091999948025, 42.45440371334553, 48.05662930011749, 53.163258880376816, 51.19831211864948, 53.69532153010368, 55.25752790272236, 52.52996206283569, 51.97430267930031, 53.24040614068508, 51.22734256088734, 50.895874947309494, 50.62390074133873, 53.840097561478615, 52.04136148095131, 53.982403725385666, 52.13769771158695, 52.62020342051983, 51.9412824511528, 49.668791592121124, 47.88998544216156, 43.94876852631569, 44.240399077534676, 44.288101717829704, 41.186525747179985, 39.606711119413376, 43.90225142240524, 45.134035125374794, 45.08277587592602, 51.275011003017426, 56.08850911259651, 56.352241560816765, 60.16949772834778, 39.306234642863274, 3.9957838878035545, 3.4350273152813315, 11.911342442035675, 15.147392246872187, 9.244696833193302, 0.41654353437479585, 25.656048506498337, 68.87799203395844, 57.112166583538055, 52.34616972506046, 31.760500743985176, 34.58951734006405, 48.32331798970699, 43.42922620475292, 3.1769807869568467, 0.22120851441286504, 0.15291140967747197, 0.10148365559871309, 0.18109506141627207, 0.1234060745628085, 0.26433530962094665, 0.10473991016624495, 0.14097328152274713, 0.08448310807580128, 0.147478191065602, 0.10814481691340916], [0.071782898157835, 0.02598851620859932, 0.03495476223179139, 0.0363576810923405, 0.06979110738029703, 0.03036005175090395, 0.06694969109958038, 0.05621060641715303, 0.039055707020452246, 0.062435726285912097, 0.048303991425200365, 0.06927020134753548, 0.030569535920221824, 0.04374767966510262, 0.13372379005886614, 15.641378089785576, 48.373904675245285, 34.033945351839066, 41.930347234010696, 56.415405571460724, 62.94203035533428, 46.13671012222767, 51.0517767816782, 47.66727179288864, 50.018916204571724, 10.137566272169352, 0.30681328964419663, 6.8892269767820835, 3.033006275072694, 0.7320319663267583, 26.345952786505222, 58.93163815140724, 51.14117078483105, 52.62134335935116, 44.62029129266739, 40.70884197950363, 40.57000882923603, 38.97580437362194, 45.46141415834427, 47.51822479069233, 51.39539234340191, 49.75439339876175, 47.52914920449257, 50.55125243961811, 48.05967293679714, 49.521830677986145, 49.763007536530495, 47.84201681613922, 43.46594363451004, 43.15080374479294, 41.30463860929012, 41.11079581081867, 38.334873765707016, 39.74808633327484, 37.376002818346024, 36.589737609028816, 35.83411395549774, 37.4327489733696, 36.034845784306526, 35.63426747918129, 36.470044031739235, 37.519217133522034, 36.23836286365986, 37.05968879163265, 37.69901968538761, 36.256761476397514, 36.5210372954607, 37.57997587323189, 38.46157796680927, 37.5762140750885, 39.740159958601, 39.96881648898125, 38.72879482805729, 39.04500626027584, 37.485269755125046, 37.48243510723114, 37.410854548215866, 37.78676077723503, 39.73323293030262, 37.44008257985115, 36.67655535042286, 37.15984761714935, 34.445991441607475, 36.38899818062782, 37.071851938962936, 40.4559313505888, 44.071194157004356, 50.91342240571976, 52.93880492448807, 52.69176498055458, 52.518137097358704, 49.01545464992523, 45.65094418823719, 44.034336134791374, 45.807529985904694, 43.749495819211006, 40.04162818193436, 38.13520587980747, 36.80177763104439, 36.2704711407423, 38.107440769672394, 38.62115040421486, 38.982985988259315, 37.68140763044357, 39.17328357696533, 38.29049974679947, 37.78714835643768, 39.00533638894558, 38.64181749522686, 38.70244704186916, 39.654516354203224, 38.556945249438286, 37.5772438198328, 37.31280840933323, 37.36787125468254, 36.800926476716995, 36.01809248328209, 37.1483988314867, 41.24280072748661, 44.77233253419399, 44.437027126550674, 46.05056494474411, 46.62550829350948, 47.4088666588068, 46.20702154934406, 45.848203003406525, 47.86039263010025, 50.71128845214844, 51.96019783616066, 49.224519431591034, 48.48838873207569, 50.89300990104675, 49.237039759755135, 49.8016020655632, 49.62775379419327, 48.656301721930504, 48.31445686519146, 46.77820309996605, 45.334113389253616, 41.84664152562618, 39.76975657045841, 37.838274613022804, 38.42494033277035, 38.883796110749245, 42.82442405819893, 46.27401955425739, 52.986910343170166, 49.959354400634766, 52.73112706840038, 29.96768094599247, 0.24322851095348597, 1.8241136125288904, 6.0301149263978004, 5.7237098179757595, 2.9137183260172606, 0.4472354968311265, 28.408894389867783, 57.7100683003664, 46.62446714937687, 34.11268092691898, 23.22744682431221, 32.19153821468353, 41.962751895189285, 23.818788193166256, 0.20266822568373755, 0.10967506605084054, 0.022721429995726794, 0.0597705552354455, 0.053899565973551944, 0.0026031302877527196, 0.07998386747203767, 0.01994960675801849, 0.03544206381775439, 0.011853616088046692, 0.01709316755295731, 0.021253191007417627, 0.028566560977196787, 0.04646029250579886, 0.03737614519195631, 0.019384938132134266, 0.046848005295032635, 0.04149709828197956, 0.02244820090709254, 0.040458032162860036, 0.021645931847160682, 0.030448168799921405, 0.04016783015686087, 0.10163802973693237, 0.005896217180634267, 0.0677952570549678, 0.22316840768326074, 20.176210552453995, 58.26507791876793, 37.52631515264511, 52.75009945034981, 65.2117283642292, 64.2046532034874, 50.115191638469696, 58.93706426024437, 50.75968265533447, 55.57228021323681, 9.977438114583492, 0.4010618885513395, 3.0852256854996085, 3.5876496881246567, 0.8690911461599171, 29.120780490338802, 59.30569767951965, 52.614541724324226, 53.9179477840662, 47.17121601104736, 42.53312408924103, 41.10989145934582, 40.66642105579376, 46.59832455217838, 51.118075624108315, 51.89267925918102, 51.16714999079704, 49.63749647140503, 50.13650469481945, 49.85108681023121, 52.12171196937561, 51.226920783519745, 50.39544180035591, 46.903045400977135, 45.247348845005035, 44.29116815328598, 43.30200143158436, 41.23601049184799, 41.37599878013134, 39.59370821714401, 37.93230056762695, 38.46708387136459, 38.994518369436264, 37.28682540357113, 36.94561131298542, 38.12270075082779, 38.88562001287937, 37.518206387758255, 37.9849049448967, 37.98381060361862, 38.63408111035824, 38.67791935801506, 39.9759791046381, 39.87495392560959, 38.932786881923676, 42.07478508353233, 41.51502951979637, 40.75772635638714, 40.14268755912781, 39.429203644394875, 40.151613280177116, 39.34321045875549, 38.576297610998154, 40.63091576099396, 38.7818817794323, 39.57413926720619, 39.275365099310875, 36.807640716433525, 38.76901187002659, 38.713356256484985, 41.934067234396935, 45.866939797997475, 51.50529004633427, 54.19350519776344, 53.37656803429127, 53.88266287744045, 51.144043430686, 46.26282915472984, 47.69301921129227, 47.88205146789551, 45.723964869976044, 39.27971586585045, 40.28552949428558, 39.73159521818161, 39.799759760499, 39.55522768199444, 40.08743852376938, 40.73706306517124, 39.28800322115421, 39.884031638503075, 39.98968496918678, 39.15594130754471, 39.60642613470554, 40.565544068813324, 41.20793379843235, 41.13269403576851, 40.72507090866566, 39.308267533779144, 39.260830879211426, 39.361297488212585, 38.232381865382195, 38.51059913635254, 39.51975278556347, 44.59393210709095, 46.59332402050495, 48.697445914149284, 47.06214666366577, 48.36914733052254, 48.79231922328472, 48.68293069303036, 48.32980804145336, 48.40211436152458, 52.68921531736851, 53.2385366410017, 49.29980859160423, 50.07365606725216, 50.58414347469807, 52.97722086310387, 50.93983858823776, 49.58186745643616, 49.69735085964203, 49.717079401016235, 48.008360490202904, 48.001604452729225, 44.291643127799034, 41.95897489786148, 39.44838121533394, 40.69944888353348, 42.008775025606155, 43.443464040756226, 47.66008257865906, 56.35305091738701, 51.552228927612305, 53.99628438055515, 32.335869669914246, 0.9633596939966083, 1.946942259091884, 11.349867470562458, 6.955127790570259, 3.3442701352760196, 0.32106089231092483, 30.63019249588251, 63.627661764621735, 51.8865729868412, 45.9821268171072, 30.714200288057327, 34.51608628034592, 47.03877031803131, 28.89379397034645, 0.4467689531156793, 0.16027125850087032, 0.0405931772547774, 0.03644888362032361, 0.02310772342752898, 0.0248771667611436, 0.07868007727665827, 0.06372868854668923, 0.04561503454169724, 0.003211198782082647, 0.046594906962127425, 0.024650949017086532, 0.1963576697744429, 0.20351350220153108, 0.10466833002283238, 0.10092268101288937, 0.12202769110444933, 0.11939410585910082, 0.14283107011578977, 0.12441152139217593, 0.11401706040487625, 0.24787126807495952, 0.28951988322660327, 0.17682962701655924, 0.1486575379385613, 0.144523716007825, 0.20732444536406547, 23.636352382600307, 65.29698058962822, 45.290472730994225, 53.82620930671692, 63.09947490692139, 69.8698528110981, 55.567553266882896, 63.82433921098709, 54.3615435808897, 61.57470412552357, 11.879783235490322, 0.3593457379611209, 15.48104664310813, 9.063737243413925, 1.2303489237092435, 30.418293066322803, 61.02520041167736, 55.61985746026039, 58.76622162759304, 48.47007751464844, 44.860856384038925, 43.80152642726898, 42.745494693517685, 50.077984035015106, 51.69916324317455, 55.61246305704117, 52.17794895172119, 50.75322300195694, 53.526770174503326, 51.28298297524452, 53.37632104754448, 54.17223013937473, 51.43789306282997, 49.32804487645626, 48.201089948415756, 45.98633699119091, 45.844764187932014, 44.00852411985397, 43.7969096750021, 43.30592282116413, 39.48132924735546, 41.548433527350426, 41.77486717700958, 39.375976100564, 38.77857215702534, 40.119033828377724, 42.128073424100876, 40.7112130522728, 40.87149605154991, 40.54139256477356, 39.75051440298557, 40.21065451204777, 42.51719914376736, 40.77053926885128, 40.61747968196869, 44.09681998193264, 43.802867755293846, 42.470856830477715, 43.36226239800453, 41.38492450118065, 41.740353628993034, 41.571996062994, 40.34298621118069, 42.09433503448963, 41.336556896567345, 41.45238608121872, 42.49779358506203, 39.642581194639206, 41.24826483428478, 39.975245743989944, 45.427238792181015, 46.86674974858761, 52.75551415979862, 55.923096388578415, 54.27580498158932, 56.21544890105724, 53.13541017472744, 47.78701476752758, 48.81038725376129, 50.50695061683655, 46.7801333963871, 42.313305884599686, 44.55216854810715, 42.466946840286255, 40.3353638201952, 42.58340299129486, 42.06554017961025, 42.98077426850796, 41.31038770079613, 42.366172447800636, 41.473664939403534, 41.55262470245361, 42.15547755360603, 42.52759538590908, 42.72146098315716, 43.02180826663971, 43.2829150557518, 40.25140352547169, 40.88222287595272, 41.85997501015663, 40.16145095229149, 39.6749896556139, 42.07997180521488, 45.30076637864113, 49.48770470917225, 49.363276585936546, 49.81418319046497, 50.12978285551071, 50.395726785063744, 49.983365312218666, 50.52927441895008, 50.35808600485325, 54.05296213924885, 55.442775562405586, 52.20311880111694, 51.19919367134571, 53.13197895884514, 53.375211507081985, 52.16341473162174, 53.17560821771622, 53.35204795002937, 52.8162956982851, 51.19775354862213, 50.4913030564785, 46.56923711299896, 43.58112685382366, 42.05985948443413, 42.57046848535538, 42.95017451047897, 45.42575687170029, 49.42064970731735, 57.83964514732361, 54.99458961188793, 51.89559370279312, 35.75895018875599, 1.2297732545994222, 5.246916627511382, 17.25755486637354, 14.037425257265568, 8.501735050231218, 0.7460921024903655, 33.927406668663025, 68.99839997291565, 55.55059477686882, 48.28266017138958, 34.22513969242573, 42.07462549209595, 56.3695914298296, 36.07085645198822, 0.8864191663451493, 0.23961432598298416, 0.12889782636193559, 0.13723915064474568, 0.17767295910743997, 0.10253746819216758, 0.1602710210136138, 0.20728895586216822, 0.14880335511406884, 0.20868978928774595, 0.14451773429755121, 0.11674499488435686], [0.011839595063065644, 0.0431256003503222, 0.10335581217077561, 0.025549791898811236, 0.02412959212961141, 0.03487785717879888, 0.039434232021449134, 0.01973517060832819, 0.025958555706893094, 0.026051467029901687, 0.05409680656157434, 0.10042903406429105, 0.018315777924726717, 0.03405721625313163, 0.004549952018351178, 4.441613964736462, 45.99744379520416, 44.56779330968857, 31.355963051319122, 42.06073723733425, 56.558304503560066, 46.14427551627159, 51.2919694930315, 44.28405873477459, 52.557730972766876, 14.873386099934578, 0.07309697452001274, 1.0058719315566123, 2.7403946639969945, 0.1998868936789222, 19.629019014537334, 60.314235761761665, 52.48589962720871, 52.49556250870228, 44.30695250630379, 43.41592311859131, 36.834265887737274, 41.93942874670029, 47.903273329138756, 50.94916708767414, 51.611885726451874, 51.027351692318916, 50.867380276322365, 47.59585462510586, 48.695534616708755, 50.05355894565582, 46.70673653483391, 45.98407991230488, 44.953898191452026, 43.88291426002979, 41.78676813840866, 42.3617684841156, 39.18290466070175, 37.8942646086216, 36.54563717544079, 37.33609355986118, 38.59612874686718, 35.07238022983074, 36.43041215837002, 38.147076442837715, 37.65753351151943, 35.6122400611639, 38.81544157862663, 40.21860748529434, 37.57928051054478, 37.85373978316784, 38.41686196625233, 39.01126027107239, 37.80833601951599, 39.02588188648224, 37.01442942023277, 38.68051461875439, 38.0815489590168, 38.64025577902794, 38.2334990054369, 37.850699946284294, 38.266040459275246, 37.98031099140644, 39.97885175049305, 39.610792100429535, 36.57801143825054, 35.30558131635189, 35.70128448307514, 37.248413264751434, 40.83567537367344, 42.14974366128445, 44.38071794807911, 49.57921139895916, 51.200869381427765, 53.41294728219509, 54.00726579129696, 50.51717966794968, 48.79689797759056, 49.95710112154484, 48.79739195108414, 47.43983119726181, 43.569408282637596, 38.26168209314346, 36.23920641839504, 37.13560491800308, 37.72905707359314, 38.391931504011154, 37.8308992087841, 40.26373766362667, 38.76862049102783, 39.77044053375721, 37.92422220110893, 40.93668155372143, 38.63041050732136, 39.586439207196236, 39.5035732537508, 36.661158576607704, 37.05126464366913, 36.461528688669205, 37.47119531035423, 35.75808383524418, 38.629335165023804, 37.04168155789375, 37.86660589277744, 44.44453552365303, 44.69904586672783, 45.12806944549084, 44.66975323855877, 44.0399332344532, 41.42110235989094, 45.54665118455887, 46.35358348488808, 47.708119601011276, 48.06721173226833, 49.32674154639244, 49.97386582195759, 49.486568570137024, 47.12575905025005, 50.05897365510464, 51.20835117995739, 49.109245017170906, 49.21992547810078, 48.79099689424038, 48.47121745347977, 48.361521139740944, 46.252223923802376, 44.48643587529659, 40.39540059864521, 38.679990246891975, 39.05925549566746, 46.68676100671291, 53.15790876746178, 51.70090354979038, 53.086176216602325, 25.095966160297394, 0.7614843640476465, 0.9222888853400946, 7.520988676697016, 3.3748399699106812, 1.3339118915610015, 0.8217158820480108, 36.520816907286644, 51.83720223605633, 44.80388984084129, 33.540108650922775, 18.176106177270412, 25.31314730644226, 41.004576310515404, 10.187724530696869, 0.12070208176737651, 0.08328220181283541, 0.08235269153374247, 0.04419984426931478, 0.036602797626983374, 0.05839427205501124, 0.03712138073751703, 0.0049003672484104754, 0.018272738925588783, 0.056187833615695126, 0.020936076871294063, 0.026364580990048125, 0.042164830811088905, 0.01893343032861594, 0.06196679285494611, 0.054691623081453145, 0.02878432751458604, 0.06847688258858398, 0.037522385391639546, 0.006269626464927569, 0.03517964782076888, 0.0409340308397077, 0.059746724873548374, 0.079396769287996, 0.05877315328689292, 0.03897050475643482, 0.02055740900686942, 7.956431536003947, 54.29860755801201, 50.02102889120579, 37.09829472005367, 55.18753185868263, 65.28792187571526, 50.81155747175217, 55.68156614899635, 49.70607899129391, 57.153249979019165, 15.984919555485249, 0.28325128834694624, 3.241024212911725, 6.02282359264791, 0.031466148648178205, 22.754463404417038, 59.87219028174877, 54.481358751654625, 53.549895733594894, 47.81888745725155, 43.98257151246071, 40.063784793019295, 42.9608291387558, 49.444653019309044, 51.751893013715744, 52.41153381764889, 51.61141835153103, 51.55060641467571, 49.838425889611244, 51.18970178067684, 51.44272640347481, 48.95269721746445, 46.99841268360615, 46.792159751057625, 46.07891142368317, 43.05238142609596, 43.86879421770573, 41.81777447462082, 41.240961626172066, 38.6714369058609, 39.494959115982056, 39.63633053004742, 37.804198041558266, 37.98579029738903, 39.860792085528374, 38.8479146361351, 38.09422507882118, 38.981724455952644, 40.39214417338371, 38.267453983426094, 38.90689127147198, 41.102291867136955, 40.39879001677036, 39.13764148950577, 40.8217529207468, 39.04649958014488, 40.74361391365528, 40.79256288707256, 39.58827830851078, 41.26921311020851, 38.995137736201286, 39.121990129351616, 40.47172710299492, 41.153589114546776, 39.478392004966736, 38.293797969818115, 37.937027513980865, 39.08083833754063, 38.54631721973419, 42.323903515934944, 44.2708620429039, 47.48928554356098, 52.189040556550026, 53.08835729956627, 56.05976365506649, 55.16304597258568, 53.96221920847893, 50.474534556269646, 50.47735780477524, 48.60700696706772, 48.98418232798576, 45.21937474608421, 39.70770210027695, 39.15952451527119, 37.44678921997547, 41.20174013078213, 39.93581905961037, 40.563537776470184, 40.34191086888313, 39.47725586593151, 39.74691219627857, 39.50470179319382, 41.38360597193241, 39.60980035364628, 39.931057915091515, 41.67887292802334, 40.086260586977005, 39.480063915252686, 39.689451679587364, 39.562052115798, 37.38385319709778, 38.808351159095764, 39.70702953636646, 41.354358941316605, 46.78841695189476, 47.39251993596554, 47.95703284442425, 45.58663263916969, 46.56055457890034, 46.01838827133179, 48.20886813104153, 48.90390023589134, 48.93150195479393, 49.169494584202766, 51.96611791849136, 50.80908000469208, 51.23471416532993, 49.66762885451317, 51.21260695159435, 51.80255949497223, 51.99888356029987, 51.65106922388077, 50.18968664109707, 49.104708060622215, 50.15754796564579, 48.236333057284355, 45.68408980965614, 41.98662981390953, 39.09790322184563, 41.361304968595505, 49.535867124795914, 56.2608602643013, 54.33946296572685, 52.982517778873444, 28.272466510534286, 1.2964751129038632, 3.0232856841757894, 11.245647612959146, 8.989564273506403, 2.234315969981253, 0.7686207967344671, 39.814958944916725, 56.76118701696396, 50.992663353681564, 38.52517135441303, 18.328620493412018, 29.000429548323154, 48.383423164486885, 15.479500126093626, 0.05763004177424591, 0.04159813055593986, 0.0559427504776977, 0.011003523031831719, 0.03166341892210767, 0.07411566126393154, 0.010620706561894622, 0.01956853247975232, 0.07398137706331909, 0.021014861413277686, 0.006224193575690151, 0.052622385483118705, 0.07563474107882939, 0.20308731647673994, 0.19180943258106709, 0.23835325380787253, 0.24677864857949317, 0.18309541657799855, 0.15219635039102286, 0.18617331079440191, 0.14599064510548487, 0.15066000079968944, 0.13806943577947095, 0.18889022438088432, 0.11183291979250498, 0.16254087968263775, 0.10854234831640497, 8.400481883436441, 62.24409520626068, 57.46834807097912, 43.54463741183281, 54.2129335552454, 64.49050426483154, 57.31301620602608, 61.96438081562519, 52.88134440779686, 62.78465420007706, 20.01190546900034, 0.2738206693902612, 3.9649426052346826, 6.89641666598618, 0.5839906039182097, 24.159221425652504, 64.25649002194405, 55.74509114027023, 57.871559634804726, 49.33114930987358, 49.30160589516163, 42.17287302017212, 45.4462605714798, 51.47198863327503, 55.569593757390976, 55.079401060938835, 54.835427552461624, 53.000715002417564, 50.924586206674576, 52.17003397643566, 52.62794740498066, 51.37616917490959, 49.430426582694054, 50.80581597983837, 47.180248126387596, 45.77989026904106, 47.63291783630848, 45.08290886878967, 43.48041705787182, 40.56259922683239, 42.177413776516914, 43.351957350969315, 39.85988013446331, 40.97302280366421, 42.65204630792141, 42.19753369688988, 39.657483994960785, 43.64333711564541, 43.35079461336136, 40.44992387294769, 41.1699890345335, 42.99747437238693, 41.51969566941261, 42.24822297692299, 42.582103461027145, 40.113288536667824, 41.15464545786381, 42.7292999625206, 41.71301409602165, 43.528967052698135, 41.572623029351234, 41.05329729616642, 41.22422732412815, 43.48421685397625, 42.25231155753136, 40.520189702510834, 39.79969136416912, 40.14629356563091, 41.6330473870039, 45.02398543059826, 47.5403206050396, 47.78516806662083, 52.56854519248009, 56.80577762424946, 55.44109225273132, 56.556545197963715, 56.36574983596802, 52.59894736111164, 54.044701382517815, 52.217208445072174, 51.233559027314186, 47.498481050133705, 41.6746361553669, 39.88761104643345, 41.00969463586807, 43.021196499466896, 42.38151602447033, 41.551853343844414, 42.36930347979069, 42.15868078172207, 41.95679001510143, 40.17731890082359, 44.978832453489304, 42.39120550453663, 42.808514311909676, 43.78939747810364, 41.118353605270386, 42.07753613591194, 40.02373494207859, 40.41990928351879, 40.01758687198162, 41.95361338555813, 41.973349526524544, 41.95953726768494, 49.350155889987946, 51.89815476536751, 49.29563641548157, 48.88689994812012, 49.164269864559174, 47.46059328317642, 50.39063885807991, 50.2248727530241, 50.665341317653656, 51.81749649345875, 53.549853935837746, 52.973291873931885, 53.11465568840504, 48.61790478229523, 53.141752034425735, 55.195139050483704, 53.61076086759567, 52.4356435239315, 52.58771136403084, 51.969807520508766, 53.01632456481457, 50.867053493857384, 50.08205361664295, 44.378305077552795, 41.551408767700195, 44.17578734457493, 52.79053308069706, 58.01288165152073, 55.58463715016842, 53.77816468477249, 31.639754623174667, 1.6476267389953136, 3.897230951115489, 19.26510114222765, 15.540130622684956, 5.130370231345296, 1.062843343243003, 43.87973763048649, 62.74839274585247, 56.51570878922939, 45.643960162997246, 28.267000503838062, 36.10220856964588, 53.908938467502594, 19.103277325630188, 0.2780023153172806, 0.24754751357249916, 0.18270057917106897, 0.19410127366427332, 0.1310012658359483, 0.11818285405752249, 0.09532441617920995, 0.08601346853538416, 0.1704925615922548, 0.1694669431890361, 0.14776507567148656, 0.19207231613108888], [0.07132554965210147, 0.03610894287703559, 0.061275560219655745, 0.03586393024306744, 0.03631232844782062, 0.04842606729653198, 0.03677421518659685, 0.022681140653730836, 0.04972983522748109, 0.08734483693842776, 0.0650596636114642, 0.03415024446439929, 0.07671045445022173, 0.09716581073007546, 0.0293057864473667, 0.6751709268428385, 26.79523877799511, 51.445621848106384, 32.21081458032131, 27.26860787719488, 38.306584283709526, 39.90376017987728, 53.90969842672348, 49.04891565442085, 51.589223742485046, 28.040713146328926, 0.3522254840936512, 1.7167139193043113, 4.559264676645398, 0.03521285150782205, 12.143170852214098, 53.11755873262882, 54.483004063367844, 50.571357160806656, 47.28200286626816, 41.173929423093796, 40.087229534983635, 44.995916336774826, 48.229394629597664, 51.697989106178284, 51.391907930374146, 49.698384404182434, 47.1910585463047, 46.90205745398998, 51.637336760759354, 49.566660672426224, 44.87201638519764, 45.33413238823414, 41.27175137400627, 41.09268218278885, 39.301792681217194, 38.717874214053154, 37.656788751482964, 37.607611790299416, 37.78042271733284, 36.68896548449993, 36.10657833516598, 35.031205639243126, 38.482142463326454, 37.81698815524578, 36.971905902028084, 36.31181292235851, 35.719827488064766, 37.502551227808, 37.24912382662296, 36.73428185284138, 38.62816862761974, 38.59197556972504, 38.7545270472765, 39.179116263985634, 39.986367747187614, 39.869273230433464, 38.87224853038788, 37.61624872684479, 39.05195988714695, 38.435252979397774, 37.24788889288902, 37.987568601965904, 37.84387931227684, 37.38068416714668, 36.50243729352951, 38.345600590109825, 36.63718566298485, 38.29163208603859, 43.96468587219715, 45.96174471080303, 49.329222813248634, 55.69985456764698, 53.12618426978588, 52.853153720498085, 53.908870071172714, 50.923351272940636, 49.01918604969978, 50.812138840556145, 50.7068806886673, 50.46519085764885, 48.403197303414345, 44.0724290907383, 37.47233144938946, 37.56928704679012, 37.157430946826935, 39.33773875236511, 37.12403453886509, 37.938897013664246, 40.15741176903248, 38.59922558069229, 38.47557261586189, 37.699768245220184, 38.452739641070366, 38.010747358202934, 39.63852681219578, 36.48006409406662, 36.81283123791218, 35.798479467630386, 37.464576065540314, 36.63070321083069, 38.75712230801582, 36.028807908296585, 36.68395735323429, 42.36361138522625, 43.20203259587288, 43.54715287685394, 42.354149892926216, 42.58048094809055, 39.597356021404266, 39.02178570628166, 40.99209778010845, 44.40415509045124, 47.726324424147606, 47.99721948802471, 50.288872718811035, 49.41865101456642, 47.437555119395256, 47.066470831632614, 49.949235543608665, 49.50923055410385, 50.96241697669029, 51.59382529556751, 52.921918630599976, 50.166006311774254, 48.93720164895058, 51.50839067995548, 47.08411708474159, 41.18771508336067, 40.78997142612934, 45.41373431682587, 52.811477556824684, 51.85477629303932, 53.728166967630386, 20.59151876717806, 0.3044416231568903, 5.51452249288559, 10.798352714627981, 7.409928711131215, 1.8229418504051864, 1.4231187547557056, 41.155990585684776, 50.71969360113144, 34.609656259417534, 34.92980808019638, 36.45894482731819, 40.525764003396034, 34.12156865000725, 4.149145558476448, 0.05982931106700562, 0.06156994051707443, 0.04327647897298448, 0.03795748059928883, 0.023448523206752725, 0.015393793164548697, 0.05375375250878278, 0.019328833623148967, 0.023068564005370717, 0.05758530140155926, 0.02195084136474179, 0.03785959503147751, 0.02752588810835732, 0.027943665299972054, 0.07155774539569393, 0.05776605146820657, 0.05528004970983602, 0.054052756386226974, 0.04697933574789204, 0.05891724125831388, 0.05361256262403913, 0.06588718053535558, 0.026448215467098635, 0.023917321195767727, 0.05606329010333866, 0.06539270238135941, 0.07218517930596136, 1.0786518012173474, 38.034921661019325, 54.63624604046345, 34.15400370955467, 33.464234322309494, 49.79931078851223, 50.03396339714527, 57.90646456182003, 53.90085630118847, 56.291562616825104, 27.719434686005116, 0.252079987549223, 1.4067881810478866, 5.0817803386598825, 0.08218633913202211, 14.095872770994902, 55.01441314816475, 54.52295891940594, 54.36912417411804, 49.21876274049282, 43.3253587782383, 41.28624379634857, 46.7989955842495, 50.28304383158684, 53.61056707799435, 52.62114576995373, 51.935343369841576, 47.664342150092125, 49.29958440363407, 51.569935977458954, 50.04586435854435, 47.15625241398811, 48.77885654568672, 43.66107456386089, 44.697594344615936, 42.417906671762466, 41.50515764951706, 39.16834384202957, 41.07683323323727, 39.0111842751503, 38.186514526605606, 38.521956726908684, 37.692480236291885, 38.62904638051987, 39.118080139160156, 39.94752623140812, 37.86664389073849, 37.47909128665924, 38.976005762815475, 40.21678738296032, 40.563761964440346, 40.27229480445385, 40.34052774310112, 40.58325491845608, 40.562105253338814, 41.80857516825199, 42.387531101703644, 40.51205813884735, 40.25323882699013, 39.60312411189079, 39.53591711819172, 38.43083381652832, 40.31528189778328, 39.07482326030731, 40.330834463238716, 40.026782378554344, 39.63097281754017, 39.08978305757046, 41.529062166810036, 44.870177283883095, 47.79999487102032, 50.85850775241852, 54.844398871064186, 56.712709218263626, 54.06412594020367, 54.58120219409466, 51.61701165139675, 49.4792577624321, 52.546111196279526, 52.67427071928978, 51.53427489101887, 50.55421628057957, 44.801978543400764, 40.10796122252941, 39.59854915738106, 39.338931888341904, 39.35378909111023, 38.854169100522995, 39.958971217274666, 40.418719947338104, 39.89928022027016, 40.17315432429314, 39.480398297309875, 40.923568457365036, 40.507395789027214, 41.225910633802414, 39.059399887919426, 39.543364718556404, 38.68939474225044, 37.65889763832092, 38.176000490784645, 39.59544852375984, 37.86556474864483, 39.33654561638832, 44.74230654537678, 44.17612552642822, 45.70873148739338, 44.42045621573925, 43.90297718346119, 41.81867502629757, 41.81918039917946, 43.949399292469025, 46.19967274367809, 49.34973791241646, 50.51081120967865, 51.8850302696228, 49.586419612169266, 48.72477404773235, 47.747709676623344, 53.3476097881794, 51.37982077896595, 52.94513538479805, 54.10335883498192, 54.137708991765976, 51.28301337361336, 52.18615651130676, 53.361327052116394, 49.17325258255005, 44.16203588247299, 42.081191539764404, 48.60175184905529, 53.98791342973709, 52.65519194304943, 55.78822262585163, 23.040665946900845, 0.23693753289990127, 8.97759871557355, 8.346328139305115, 6.753524858504534, 1.0633278172463179, 1.4206006773747504, 47.17286132276058, 54.391843155026436, 41.605681255459785, 39.232077822089195, 32.187510430812836, 43.92600394785404, 43.17816227674484, 6.49249691516161, 0.05651858286000788, 0.04546308351564221, 0.03886072998284362, 0.007576333764518495, 0.04705034072685521, 0.04166715771134477, 0.0514401442342205, 0.03265785599069204, 0.02481547573552234, 0.04431303663295694, 0.039506899411207996, 0.03675963569548912, 0.14546469988999888, 0.17140577430836856, 0.16251374676357955, 0.20186020497931167, 0.08201724078389816, 0.10152252929401584, 0.12558167305542156, 0.11016545497113839, 0.16596667788689956, 0.1821730160736479, 0.10889361423323862, 0.0981921935454011, 0.2064346251427196, 0.2038596398779191, 0.206146597629413, 1.6062186984345317, 41.60727337002754, 65.71172073483467, 42.06085883080959, 38.519779443740845, 50.14247417449951, 50.62232002615929, 62.02541694045067, 57.07116298377514, 60.09746499359608, 34.29136633872986, 0.4941650864202529, 5.4776302725076675, 12.287322767078876, 0.16340969712473452, 16.60377524793148, 55.95246501266956, 58.84601354598999, 56.07033088803291, 54.64476138353348, 45.4080156236887, 43.81207466125488, 48.46747845411301, 52.899340242147446, 55.09612776339054, 53.78080554306507, 51.21563918888569, 47.70405761897564, 49.59992028772831, 54.440385550260544, 51.66840389370918, 49.16434966027737, 50.968720838427544, 46.33472129702568, 47.34490089118481, 43.61164681613445, 43.914585560560226, 42.308202758431435, 43.05919826030731, 41.22425392270088, 40.61317831277847, 40.65973341464996, 40.13379983603954, 42.66536459326744, 41.68107680976391, 41.65806144475937, 39.6674470603466, 40.53260363638401, 40.971305295825005, 41.733878776431084, 41.65950536727905, 43.42932499945164, 42.86366455256939, 42.889951542019844, 42.23209664225578, 43.447374030947685, 43.919977471232414, 42.58997663855553, 41.209776699543, 43.6714556068182, 41.133590787649155, 40.769007951021194, 42.45962083339691, 40.79537853598595, 42.63996295630932, 42.15397283434868, 43.81321080029011, 42.367217391729355, 43.433782160282135, 47.42177836596966, 49.65990386903286, 54.5116051286459, 58.877042680978775, 58.39857995510101, 54.226092249155045, 55.25877803564072, 53.48410226404667, 51.963796243071556, 54.71308171749115, 55.318803414702415, 55.20734019577503, 51.90717928111553, 48.29169988632202, 43.648561835289, 43.46148267388344, 41.282284408807755, 41.91575601696968, 40.56682839989662, 41.66768632829189, 43.676760122179985, 41.3222848623991, 41.152069196105, 40.758391320705414, 41.654979810118675, 40.04777245223522, 41.63603022694588, 38.83114993572235, 41.342226192355156, 39.29295435547829, 39.34708625078201, 40.89332967996597, 42.27740541100502, 38.96841756999493, 40.650275722146034, 46.369584426283836, 47.07098498940468, 48.14356103539467, 46.89659334719181, 47.84359373152256, 44.88705217838287, 44.34038691222668, 44.96857300400734, 47.834003046154976, 51.40257015824318, 52.72045724093914, 54.25912007689476, 51.519121304154396, 50.918806716799736, 48.52618910372257, 53.4344769269228, 53.184138759970665, 54.670296013355255, 54.89221170544624, 54.455531537532806, 56.08023315668106, 54.097328558564186, 57.72008456289768, 52.57933661341667, 46.976791843771935, 44.28316578269005, 51.37868843972683, 57.67819941043854, 54.799918457865715, 55.87361924350262, 25.132111720740795, 0.7328372856136411, 11.758672334253788, 19.704393669962883, 19.45541203022003, 3.435578760690987, 1.9102019118145108, 50.13904295861721, 61.711846366524696, 47.61261932551861, 49.915576949715614, 49.17147047817707, 52.42017075419426, 51.25653639435768, 9.140856005251408, 0.310249492758885, 0.13035406853305176, 0.23634209297597408, 0.14310584287159145, 0.12404609529767185, 0.12377420207485557, 0.19349624519236386, 0.09114013562793843, 0.11865827385918237, 0.13529065676266328, 0.15027286688564345, 0.1264718791935593], [0.035078578439424746, 0.02778360816591885, 0.025969023699872196, 0.03933967127522919, 0.0493859907874139, 0.020539372962957714, 0.015226253326545702, 0.07525831635575742, 0.017679287957435008, 0.05708572098228615, 0.06973454830585979, 0.035392083882470615, 0.06435716146370396, 0.04880871492787264, 0.05673601357557345, 0.034901735780294985, 8.884896039962769, 51.275713965296745, 42.37499937415123, 34.651674404740334, 28.598150834441185, 27.04807911068201, 41.65158659219742, 45.513634756207466, 48.77803958952427, 39.24857273697853, 0.5696040415205061, 0.6235741486307234, 4.013584032654762, 0.1971300970762968, 5.96582000143826, 50.59797093272209, 55.4025699198246, 51.695203855633736, 48.64833354949951, 43.03317345678806, 41.84970796108246, 49.86009992659092, 50.08588761091232, 49.71084773540497, 50.313096418976784, 48.17076377570629, 46.41185715794563, 51.232863664627075, 50.65126687288284, 47.22874492406845, 44.577129408717155, 41.24992534518242, 39.401180148124695, 38.11152175068855, 37.831089198589325, 39.30005997419357, 38.33259768784046, 37.70573392510414, 36.55042111873627, 36.31074137985706, 36.12892493605614, 36.211072728037834, 36.403619796037674, 36.9500532746315, 36.244860514998436, 37.366742715239525, 38.62141638994217, 36.953309699893, 39.43906411528587, 37.90365390479565, 38.14150594174862, 38.47097106277943, 39.988203048706055, 40.078311413526535, 38.80965068936348, 39.74300600588322, 38.11148375272751, 38.84932056069374, 38.176327273249626, 39.21618327498436, 37.436168789863586, 38.915585204958916, 38.051754757761955, 37.58678510785103, 37.18487307429314, 36.437715366482735, 37.217988297343254, 42.83269241452217, 47.876834347844124, 49.588235914707184, 52.581380903720856, 50.75931787490845, 56.45601399242878, 50.96966318786144, 57.27608598768711, 52.719286903738976, 50.4676379263401, 52.29011133313179, 51.272951513528824, 52.38932780921459, 49.99080151319504, 49.123254865407944, 38.948616832494736, 36.002163738012314, 37.71938659250736, 36.77172504365444, 37.45029263198376, 40.54371803998947, 39.34187673032284, 36.13705649971962, 39.17334817349911, 37.69166707992554, 38.3443808555603, 38.961779326200485, 38.20028118789196, 38.41810069978237, 38.09710532426834, 35.938733741641045, 37.01398864388466, 35.86299240589142, 35.864215940237045, 38.31083245575428, 36.52375414967537, 38.5225722938776, 41.80192932486534, 42.99548327922821, 42.7974721044302, 42.111240327358246, 40.646871104836464, 38.87081980705261, 35.50858162343502, 40.47883652150631, 42.287786453962326, 46.05712719261646, 46.466483026742935, 48.50162722170353, 49.02912251651287, 48.29042315483093, 47.9083726555109, 47.52495802938938, 49.421269074082375, 47.27344572544098, 49.388495832681656, 55.08469417691231, 53.49825270473957, 48.70264783501625, 50.88766738772392, 47.80365787446499, 43.685378059744835, 44.70473036170006, 48.9337894320488, 51.908786594867706, 48.820715099573135, 13.509513884782791, 2.325680167414248, 13.206773679703474, 6.98177196085453, 4.536277810111642, 1.922273151576519, 2.2622663201764226, 37.55840063095093, 49.65073116123676, 36.951292008161545, 28.26968315988779, 24.747323468327522, 34.21862684190273, 31.389072574675083, 0.7334935816470534, 0.11193178128451109, 0.003828053145298327, 0.020605694990081247, 0.07718920649494976, 0.11829822091385722, 0.0323643514275318, 0.01632837695069611, 0.030360964592546225, 0.03759770224860404, 0.03603518824093044, 0.026133743376703933, 0.03268261032644659, 0.06980000573094003, 0.051757033870671876, 0.033191285765497014, 0.020125156224821694, 0.029420340651995502, 0.04565894741972443, 0.03228054069040809, 0.11601110731135122, 0.06812145322328433, 0.06778938666684553, 0.04682283164584078, 0.0596849485009443, 0.03669441575766541, 0.028376843911246397, 0.11020787613233551, 0.06624929665122181, 13.202154077589512, 62.04580284655094, 43.2725416123867, 33.091101944446564, 40.51281809806824, 33.580086305737495, 49.51543942093849, 53.04035447537899, 54.5479653775692, 41.89487233757973, 0.8613663981668651, 1.3333863322623074, 6.855061585083604, 0.11743236464099027, 6.612309236079454, 54.672963470220566, 55.2621940523386, 53.66682305932045, 50.44435277581215, 44.64343585073948, 44.09067951142788, 50.99173240363598, 52.47846342623234, 51.2775644659996, 51.09509065747261, 49.87008959054947, 46.927861869335175, 52.396387830376625, 51.85151606798172, 48.91695253551006, 45.97641572356224, 43.59883390367031, 41.88622020184994, 40.63939690589905, 40.73778882622719, 41.68678790330887, 40.471476316452026, 40.96356891095638, 40.154774710536, 39.01918664574623, 36.71948924660683, 38.014984130859375, 38.65893937647343, 39.4216800481081, 38.267343789339066, 39.65506352484226, 39.12605211138725, 41.31549462676048, 40.65811090171337, 38.77778559923172, 38.351003900170326, 40.561865866184235, 40.28299123048782, 40.46849727630615, 40.21636180579662, 41.60034254193306, 40.19303485751152, 39.967931136488914, 39.908015951514244, 40.71846306324005, 38.408027440309525, 40.769266337156296, 39.537338241934776, 39.22485440969467, 39.18094776570797, 38.50933760404587, 38.45664583146572, 46.433417201042175, 48.989441245794296, 52.46887654066086, 52.31082782149315, 52.922921776771545, 54.73445937037468, 54.74145859479904, 56.27190627157688, 54.82832953333855, 53.791802152991295, 52.18016803264618, 54.55848701298237, 54.60875451564789, 53.199299946427345, 48.64392578601837, 38.787832260131836, 36.736801117658615, 39.35095064342022, 39.85742546617985, 39.9382509291172, 41.4419936388731, 41.62951357662678, 38.73482130467892, 40.33190220594406, 40.22385120391846, 40.21824650466442, 40.163772627711296, 41.15536741912365, 39.590144008398056, 38.87378744781017, 39.451774433255196, 38.77141334116459, 36.9207264482975, 38.37612435221672, 39.653384014964104, 38.34264814853668, 40.24435110390186, 43.695394322276115, 45.544409304857254, 44.9367269128561, 43.48449423909187, 43.977962359786034, 40.41026160120964, 38.395054936409, 41.65683031082153, 45.44249877333641, 47.86431021988392, 48.690321296453476, 49.739296808838844, 50.68102687597275, 49.3544040620327, 49.086537435650826, 48.7196709215641, 49.909265488386154, 49.063187688589096, 51.791973263025284, 56.21040657162666, 55.29270261526108, 50.72736918926239, 52.868417501449585, 48.81579056382179, 45.776231065392494, 47.25932948291302, 52.6444461196661, 52.352260798215866, 50.23099422454834, 16.478571966290474, 5.6391073577106, 17.760742865502834, 11.303655300289392, 6.030117301270366, 0.9926164022181183, 2.2927969694137573, 42.35427148640156, 52.22046487033367, 44.793865978717804, 36.39843687415123, 30.00764150172472, 41.51408717036247, 38.03662396967411, 1.4377185213379562, 0.12155273143434897, 0.11580914666410536, 0.03297489776741713, 0.04413352595292963, 0.05597713417955674, 0.04852207894145977, 0.04520377340668347, 0.0029196358627814334, 0.012868503963545663, 0.08570782985771075, 0.0824287319846917, 0.011400678722566226, 0.2566174487583339, 0.15370262815849856, 0.07405030773952603, 0.17113092733779922, 0.10366147311287932, 0.15413665096275508, 0.19059744605328888, 0.21204158052569255, 0.19431661523412913, 0.182821148482617, 0.23158590600360185, 0.1301295985467732, 0.09764817703398876, 0.19403425772907212, 0.16909239609958604, 0.14876826637191698, 16.319107823073864, 69.20461490750313, 53.231070041656494, 46.921911388635635, 40.042209550738335, 37.027310729026794, 53.3347474783659, 56.813741996884346, 58.27877998352051, 48.5929287225008, 1.3467250415124, 4.520914284512401, 17.04922154545784, 0.33730395196471363, 7.854389436542988, 57.269436344504356, 58.46735626459122, 58.18329110741615, 53.103541284799576, 48.174343183636665, 46.6925784945488, 55.8206082880497, 53.72295364737511, 54.106930643320084, 52.23614662885666, 51.234432980418205, 49.19824004173279, 54.75853867828846, 55.332942456007004, 51.00446932017803, 48.44589941203594, 45.82171082496643, 43.59371937811375, 43.58557641506195, 42.23688818514347, 44.9218925088644, 43.35869438946247, 43.40453512966633, 41.44298158586025, 40.5191333591938, 39.8910004645586, 39.22948256134987, 40.79831197857857, 41.715932339429855, 40.03389559686184, 41.284556686878204, 40.912617444992065, 42.04923905432224, 42.542418390512466, 39.98811185359955, 40.79028680920601, 43.02833251655102, 43.61638516187668, 43.611760810017586, 42.27965489029884, 43.02910007536411, 41.92527450621128, 42.331537306308746, 41.137200593948364, 43.3214145898819, 39.45706754922867, 43.13437722623348, 41.87205836176872, 42.91523538529873, 41.12799748778343, 39.99041832983494, 40.37847250699997, 49.80184145271778, 51.64137974381447, 54.874272868037224, 54.614720195531845, 54.73009340465069, 56.214430555701256, 55.080309212207794, 56.03285349905491, 54.93907079100609, 54.57935929298401, 54.941658452153206, 55.47886982560158, 54.97323855757713, 55.417263731360435, 51.48811876773834, 41.394465789198875, 39.577486887574196, 42.387591898441315, 41.53646036982536, 40.05325935781002, 43.97545449435711, 44.34701755642891, 38.2858107984066, 43.10153938829899, 41.59156121313572, 41.6014064848423, 42.28884279727936, 41.657996848225594, 42.778792306780815, 42.10508465766907, 40.311102122068405, 41.49153158068657, 38.9809150993824, 40.72541669011116, 41.119630336761475, 39.69816841185093, 42.10280857980251, 45.508265644311905, 47.59962782263756, 47.75990702211857, 46.751171350479126, 45.73526546359062, 42.533568665385246, 38.99997107684612, 44.304463639855385, 46.97249427437782, 50.51854379475117, 50.07548376917839, 51.07981167733669, 51.96824200451374, 52.42036834359169, 50.01812964677811, 49.19097103178501, 51.024194061756134, 51.726673766970634, 53.80485825240612, 56.1055625975132, 57.52863563597202, 54.24861364066601, 55.5313678085804, 52.99306981265545, 48.037105947732925, 48.86434815824032, 54.524980410933495, 54.86426800489426, 52.50950016081333, 20.203327797353268, 10.1534285210073, 30.63199359923601, 17.535568848252296, 15.754478070884943, 3.71065407525748, 2.869819519110024, 48.819206580519676, 60.00810518860817, 48.92957925796509, 39.29058328270912, 34.16720040142536, 46.78829915821552, 45.60519464313984, 2.036874289624393, 0.46170544694177806, 0.19632581679616123, 0.14909144199918956, 0.12746671331115067, 0.17706871731206775, 0.12896197760710493, 0.15498577180551365, 0.15913032519165426, 0.09749582895892672, 0.22218469093786553, 0.19102621445199475, 0.12708324560662732], [0.0328601060755318, 0.02519933677831432, 0.05266690692224074, 0.06052421733329538, 0.032027082415879704, 0.06717914089676924, 0.09419717549462803, 0.003673131441246369, 0.04466833983315155, 0.03335692199470941, 0.029497575960704125, 0.03632307474617846, 0.03015094051079359, 0.056627533849678, 0.05548427390749566, 0.13681955519132316, 0.8694328903220594, 22.418500632047653, 52.26630561053753, 24.90939237177372, 23.304354697465897, 37.57730841636658, 41.31256118416786, 47.22872972488403, 48.749548718333244, 42.89408951997757, 2.465714765712619, 0.6991215166635811, 3.490872443653643, 3.4942383505403996, 2.252894598059356, 41.105156913399696, 56.09536774456501, 53.898135647177696, 49.128084406256676, 49.84801657497883, 47.9985836148262, 50.35756163299084, 48.947806879878044, 53.55920523405075, 47.639157101511955, 45.664068683981895, 46.58220961689949, 50.12528769671917, 49.55851010978222, 44.742466136813164, 42.14570067822933, 39.083950370550156, 36.79959274828434, 37.86462999880314, 36.89058266580105, 39.15736623108387, 38.84510278701782, 37.62955941259861, 35.82809127867222, 36.33427731692791, 36.22464179992676, 37.86924295127392, 38.277265056967735, 39.32266116142273, 36.37199029326439, 36.66969291865826, 38.72539781033993, 37.977734729647636, 38.51368837058544, 36.47907614707947, 37.8328675031662, 37.38149732351303, 39.2984564602375, 39.29921641945839, 38.417101353406906, 38.703271597623825, 38.68181794881821, 37.25278303027153, 38.86206887662411, 38.82435970008373, 39.226940497756004, 38.60959902405739, 36.82863458991051, 37.97485448420048, 38.135954439640045, 38.40271532535553, 38.76633681356907, 45.47648414969444, 50.67098781466484, 50.67248113453388, 51.16962745785713, 62.93307423591614, 62.92053870856762, 40.1038384437561, 52.96242065727711, 55.04880130290985, 49.65355060994625, 53.73504459857941, 52.73316375911236, 53.6319675296545, 49.261727035045624, 49.250323846936226, 43.83896201848984, 39.0783266723156, 35.19936561584473, 36.683470979332924, 39.09598812460899, 38.98738615214825, 38.120219483971596, 39.48597639799118, 38.78385007381439, 39.64203402400017, 37.18898065388203, 37.62889064848423, 37.80006766319275, 37.78996780514717, 37.289694249629974, 37.62653477489948, 36.74019433557987, 37.85468593239784, 35.67258462309837, 37.44862452149391, 35.6401951611042, 38.5332041233778, 40.651381462812424, 42.806747406721115, 40.342925414443016, 40.50053335726261, 40.5568653345108, 37.751673460006714, 37.74252735078335, 38.14794659614563, 39.437684789299965, 40.0521270185709, 45.733099579811096, 45.722695738077164, 46.930966302752495, 48.121913596987724, 46.80984780192375, 49.09947194159031, 46.962318420410156, 48.74791480600834, 43.255127146840096, 43.636672273278236, 52.585154101252556, 54.473246186971664, 51.11104980111122, 48.72552640736103, 49.248393550515175, 51.39152035117149, 48.209122717380524, 53.92387166619301, 38.236687034368515, 23.78879450261593, 2.814287873916328, 1.6260074428282678, 9.715479221194983, 1.155910324305296, 0.7245930342469364, 1.7127737682312727, 41.10460974276066, 52.41779588162899, 33.05955223739147, 26.632493510842323, 25.371983349323273, 43.53301003575325, 15.928966607898474, 0.07696383108850569, 0.01708844934910303, 0.053325032349675894, 0.017573351942701265, 0.03130581135337707, 0.016398025654780213, 0.037160154242883436, 0.051588121059467085, 0.04832084188819863, 0.009266530105378479, 0.041104780466412194, 0.03346002857142594, 0.03205659020750318, 0.02785490814858349, 0.006047858360034297, 0.07656091169337742, 0.03968386081396602, 0.031704225912108086, 0.023132214300858323, 0.0262456499694963, 0.022905321202415507, 0.03817087032075506, 0.05569676934101153, 0.04662270781409461, 0.08598907414125279, 0.05995051491481718, 0.024260028294520453, 0.06564082461409271, 0.057799177229753695, 1.6677623335272074, 32.903186827898026, 57.48679608106613, 31.309155263006687, 26.336202509701252, 40.72284422814846, 45.51034793257713, 51.15944400429726, 52.74818055331707, 47.198433950543404, 2.7721364982426167, 0.3537924843840301, 4.670983431860805, 2.8893176978453994, 3.416569330729544, 44.865442737936974, 57.800822630524635, 55.786964893341064, 50.48878379166126, 53.25730763375759, 49.47864219546318, 51.154074892401695, 52.068172842264175, 54.139354303479195, 48.36044579744339, 47.99436204135418, 48.636185601353645, 50.60975030064583, 51.170710399746895, 48.722399175167084, 42.96215906739235, 41.439185589551926, 36.982788518071175, 39.86937962472439, 37.994070053100586, 41.3415802270174, 40.4463254660368, 39.26997698843479, 38.893580585718155, 39.97018061578274, 38.73915687203407, 39.78285066783428, 39.950885251164436, 39.498261138796806, 38.269984647631645, 37.94569484889507, 40.562105253338814, 41.26482434570789, 40.28660863637924, 38.12152661383152, 37.86283649504185, 39.96533587574959, 40.122533440589905, 41.079173907637596, 40.78707218170166, 40.903706923127174, 40.56662321090698, 37.700497806072235, 38.40985894203186, 39.53551433980465, 41.216813921928406, 40.737503841519356, 39.52710539102554, 41.051731780171394, 39.76561479270458, 39.38946917653084, 41.169187277555466, 46.597382202744484, 52.48149186372757, 52.864686101675034, 52.97321207821369, 55.11988028883934, 55.26925407350063, 46.09279587864876, 54.5090326666832, 52.37262770533562, 51.9604030251503, 56.37223608791828, 54.71530839800835, 53.82283888757229, 51.39544554054737, 51.9703508913517, 45.29546566307545, 39.03651371598244, 37.92636148631573, 37.41759538650513, 40.906906351447105, 41.200315207242966, 39.433569610118866, 39.516234174370766, 40.59548266232014, 40.645465180277824, 36.93345196545124, 37.49541521072388, 39.243207424879074, 38.397201821208, 37.166219875216484, 39.87653084099293, 39.470408633351326, 38.69092985987663, 37.968334034085274, 38.33063319325447, 37.41860993206501, 38.79244901239872, 42.73481346666813, 44.80539835989475, 43.22456918656826, 43.18986564874649, 41.53661236166954, 40.082677379250526, 38.12171660363674, 39.74694639444351, 41.47965721786022, 43.12248766422272, 47.8736425191164, 47.29355804622173, 48.73693719506264, 50.426383540034294, 49.236861169338226, 50.86019866168499, 48.41183803975582, 50.902452394366264, 44.523886665701866, 45.314878821372986, 52.31054663658142, 55.607945099473, 53.355976939201355, 52.92506866157055, 51.811637207865715, 53.39590899646282, 50.6350227445364, 55.994141176342964, 39.814727157354355, 27.565721534192562, 3.7377953063696623, 5.164447752758861, 11.861823499202728, 5.609300332143903, 0.43398382666055113, 1.6739124222658575, 46.999662816524506, 56.16269253194332, 45.12926258146763, 29.333008602261543, 26.739117689430714, 49.7710707038641, 23.778666146099567, 0.0512089095718693, 0.0503084506635787, 0.04414894036017358, 0.012545289373520063, 0.08183056095731445, 0.019241813097323757, 0.04831277845369186, 0.03443299530772492, 0.05964924377622083, 0.03816632837697398, 0.005685017722498742, 0.07487641458283179, 0.019878199163940735, 0.12915389699628577, 0.11753075115848333, 0.16443782398710027, 0.1287348655750975, 0.19668658962473273, 0.19319144514156505, 0.13548227929277346, 0.0805816896900069, 0.1604243041947484, 0.1202788126829546, 0.11962628675973974, 0.12479386845370755, 0.1888163510011509, 0.11933500863960944, 0.12143127154558897, 0.2783273166278377, 2.2599771805107594, 39.69010144472122, 66.14283040165901, 35.98046310245991, 33.08929704129696, 49.8773206025362, 52.118113562464714, 58.30667428672314, 55.85343472659588, 53.12022238969803, 3.793418384157121, 1.1956412298604846, 11.123847048729658, 5.308709386736155, 4.721795255318284, 48.39422218501568, 58.54256182909012, 59.94642309844494, 52.75616392493248, 55.8388739079237, 53.152418062090874, 54.47894208133221, 52.42262922227383, 57.77808465063572, 46.84681601822376, 46.754549369215965, 50.72684481739998, 54.967048689723015, 52.014740109443665, 50.22337183356285, 45.50569698214531, 45.10982662439346, 39.11320120096207, 42.56230652332306, 40.61687171459198, 43.38313087821007, 42.580363154411316, 42.37654589116573, 40.59112809598446, 42.78785482048988, 40.41651226580143, 41.73819914460182, 43.2774243503809, 42.91180036962032, 39.973376244306564, 40.131656751036644, 42.97589153051376, 42.39004276692867, 43.37526150047779, 40.94050034880638, 40.94792515039444, 41.5808267891407, 42.23340757191181, 43.338065296411514, 42.977411448955536, 42.9624592512846, 40.12116551399231, 40.14581099152565, 41.81062325835228, 41.28668077290058, 42.350418493151665, 43.52642498910427, 40.25939829647541, 43.53863753378391, 41.21657833456993, 42.682399079203606, 44.0005749464035, 50.31715840101242, 54.16481293737888, 54.56425130367279, 54.30809184908867, 57.948083728551865, 57.683256939053535, 44.61555294692516, 56.12442098557949, 52.40644209086895, 52.06501521170139, 57.744175270199776, 57.120811119675636, 56.334602907299995, 53.48039746284485, 52.97082960605621, 47.111243829131126, 43.65532927215099, 38.84549416601658, 38.25898423790932, 44.36896897852421, 44.0018592774868, 42.220229879021645, 42.784161418676376, 42.56170615553856, 44.85636882483959, 38.684603199362755, 39.7683734446764, 41.438387632369995, 40.41338883340359, 39.93434853851795, 41.2433934956789, 41.28229960799217, 39.60579916834831, 39.648934453725815, 40.57844817638397, 39.56080958247185, 42.433641627430916, 44.486428275704384, 47.93047986924648, 43.53434756398201, 43.05161766707897, 44.38781216740608, 42.74366319179535, 41.29910230636597, 41.81245096027851, 43.48072104156017, 44.48804318904877, 50.18174506723881, 49.57571938633919, 50.68840228021145, 51.82403974235058, 50.585933178663254, 53.19030962884426, 49.24468494951725, 52.64409653842449, 46.54193937778473, 46.583208963274956, 51.2616091221571, 56.64892964065075, 57.76112236082554, 53.67664933204651, 54.18158523738384, 56.319570913910866, 54.02324393391609, 55.94952777028084, 42.09124580025673, 31.61995578557253, 4.283321583643556, 6.8336421344429255, 23.007444329559803, 11.22655838727951, 1.292225990910083, 2.2431039484217763, 52.71376959979534, 63.69799979031086, 46.64443127810955, 35.55006019771099, 36.69707424938679, 57.68386870622635, 29.400867260992527, 0.3096178063424304, 0.13374415459111333, 0.06825331802247092, 0.1326630829134956, 0.11932521971175447, 0.10569397811195813, 0.16323876567184925, 0.14031412079930305, 0.12202117504784837, 0.13010065478738397, 0.10924584494205192, 0.1980314651154913, 0.12020919923088513], [0.09432999766431749, 0.03487779409624636, 0.04358650745416526, 0.03555742325261235, 0.023629414281458594, 0.044276508124312386, 0.042983787061530165, 0.020692056859843433, 0.00530039180375752, 0.09638743882533163, 0.00935876236326294, 0.01487654963057139, 0.05408778946730308, 0.14778855722397566, 0.17882450512843207, 0.09592488044290803, 0.10913326113950461, 11.71925799921155, 47.48572513461113, 36.811440512537956, 26.361296363174915, 23.611309826374054, 45.78482240438461, 53.69868814945221, 51.513957381248474, 45.30199371278286, 8.052687495946884, 0.8041262696497142, 3.0208875378593802, 8.184603117406368, 18.16480178385973, 36.39966040849686, 47.73762881755829, 56.77134767174721, 50.00689744949341, 53.060569390654564, 49.517312720417976, 52.53421023488045, 52.24078617990017, 51.058479622006416, 46.35841302573681, 48.52125696837902, 49.289142563939095, 50.05166284739971, 45.574499890208244, 44.745802357792854, 39.37250688672066, 38.85847806930542, 36.65819093585014, 37.80140519142151, 35.73935464024544, 38.445922806859016, 36.88669167459011, 38.061546832323074, 37.1772924810648, 38.82290057837963, 37.3604616522789, 38.485915660858154, 38.71582232415676, 40.26852160692215, 38.460354432463646, 36.97589948773384, 36.852102130651474, 37.79276825487614, 37.833996042609215, 36.54508240520954, 38.0639711022377, 37.55259454250336, 39.349111542105675, 37.666934207081795, 39.39041152596474, 38.3475498855114, 37.15644299983978, 37.09903568029404, 39.49215866625309, 39.03481140732765, 40.88270165026188, 38.01776558160782, 36.68222464621067, 38.45255345106125, 39.58325497806072, 38.78866821527481, 38.52661147713661, 48.26250225305557, 53.83703872561455, 51.632894799113274, 51.70586608350277, 56.48263916373253, 61.20554253458977, 43.490190133452415, 42.393173798918724, 59.033609479665756, 53.41194413602352, 52.33976326882839, 52.017544358968735, 50.81539906561375, 49.437159821391106, 48.82766492664814, 44.952765852212906, 38.80860194563866, 35.747387409210205, 36.24919228255749, 37.933322712779045, 40.28958007693291, 37.14000128209591, 38.06975059211254, 38.04137371480465, 38.869425281882286, 38.54053013026714, 39.20509546995163, 38.19969981908798, 36.91349923610687, 37.661789283156395, 37.820635959506035, 35.63004590570927, 38.38364414870739, 35.851182639598846, 39.2634641379118, 35.89800372719765, 36.406215056777, 37.44718439877033, 40.630870163440704, 41.09197922050953, 40.85258446633816, 38.62545557320118, 36.79369926452637, 35.94220295548439, 35.05156874656677, 35.36442495882511, 37.395168989896774, 37.838627994060516, 44.59403470158577, 42.38359071314335, 45.049459263682365, 44.12679277360439, 47.4485669285059, 46.46824613213539, 47.158551290631294, 50.90459547936916, 46.672553569078445, 44.612604305148125, 50.28270944952965, 52.91892059147358, 52.954118102788925, 47.638685926795006, 49.61025193333626, 49.226081147789955, 51.69868066906929, 27.720335237681866, 7.8975090477615595, 2.3487145313993096, 3.8274051854386926, 6.147458329796791, 3.827509442344308, 0.2682358893798664, 2.489283476024866, 44.846637547016144, 44.36155557632446, 33.580796867609024, 28.61726950854063, 30.09416475892067, 39.912723898887634, 4.948283052071929, 0.22885078011313453, 0.06810615755966865, 0.02114530128892511, 0.012946429469593568, 0.046715576463611796, 0.03222465697035659, 0.035022564843529835, 0.05426622032246087, 0.02553693233494414, 0.05418548949819524, 0.04398572724312544, 0.00570663880353095, 0.06930900824954733, 0.025309785050922073, 0.03496235811326187, 0.09076326561626047, 0.02512492905225372, 0.020155326383246575, 0.012948278344993014, 0.03898840535839554, 0.015609412112098653, 0.04656425255234353, 0.050070280631189235, 0.06603986999834888, 0.037840365985175595, 0.0876990269171074, 0.09598326520062983, 0.07726639727479778, 0.05764809080574196, 0.07396018874715082, 17.604896128177643, 55.980279520154, 35.75217895209789, 27.241821214556694, 37.660683542490005, 51.12191341817379, 56.69365704059601, 55.19580401480198, 50.61337150633335, 8.45531864091754, 0.6293022225145251, 5.310329524800181, 9.995347503572702, 16.082015745341778, 40.75538568198681, 52.32063129544258, 57.96596936881542, 52.322614789009094, 55.09303092956543, 50.98376043140888, 54.68452624976635, 54.04317386448383, 51.86821237206459, 47.38254927098751, 48.54860030114651, 50.617824867367744, 50.12251764535904, 47.295883521437645, 46.50219351053238, 41.7705088108778, 39.991531670093536, 38.169723227620125, 40.570818185806274, 37.69133649766445, 40.52387550473213, 39.9625164270401, 41.27794124186039, 39.06258411705494, 39.628252163529396, 38.4839853644371, 39.62621547281742, 41.116047129034996, 43.016119971871376, 39.72185634076595, 38.28936740756035, 37.72142708301544, 39.54789027571678, 39.19502601027489, 38.40716868638992, 37.35415779054165, 39.49975825846195, 41.256069615483284, 39.987473487854004, 42.214511185884476, 40.00639267265797, 39.3341289460659, 38.926673009991646, 41.14673808217049, 39.87360119819641, 41.236683055758476, 38.539321795105934, 40.54314807057381, 39.53445419669151, 40.7182464748621, 39.942248314619064, 40.465446040034294, 50.426273345947266, 56.68382316827774, 51.970776468515396, 56.95583917200565, 55.971460193395615, 57.47112192213535, 46.53237149119377, 48.253093957901, 57.92115457355976, 54.16766278445721, 55.031337440013885, 52.705763429403305, 52.64733396470547, 50.45256793498993, 50.19934952259064, 47.29533635079861, 39.47248712182045, 37.16446816921234, 38.79813730716705, 39.34043660759926, 41.23557731509209, 38.877184465527534, 40.420642644166946, 39.25545036792755, 39.73919101059437, 38.06904762983322, 40.72816014289856, 40.52638716995716, 38.68306428194046, 38.447826504707336, 40.127834156155586, 37.91041374206543, 38.97744968533516, 38.48298221826553, 40.8551075309515, 37.421520575881004, 38.023275285959244, 39.352774545550346, 42.734448686242104, 43.15615385770798, 42.818469777703285, 40.1726071536541, 39.55530367791653, 38.595300391316414, 38.11917833983898, 37.784104719758034, 38.55203591287136, 42.757946625351906, 46.1655467748642, 45.80356299877167, 48.122479766607285, 46.978585347533226, 48.266389444470406, 49.46984186768532, 50.41911453008652, 52.08153672516346, 47.2743234783411, 47.45677448809147, 50.23196317255497, 54.752360209822655, 51.94775350391865, 51.281732842326164, 51.84380628168583, 50.74996277689934, 52.7041295170784, 32.57830046117306, 10.316479671746492, 5.27284643612802, 9.78185310959816, 11.491976995021105, 4.619973544031382, 0.29601153801195323, 2.6357630034908652, 49.519497603178024, 51.61237210035324, 41.23292125761509, 29.546771831810474, 32.750051245093346, 46.53410419821739, 8.487168531864882, 0.13063753925962374, 0.038994791539153084, 0.05269348694127984, 0.03840239442070015, 0.02642334053234663, 0.04227583012834657, 0.04156894930929411, 0.05504475178895518, 0.05694790786947124, 0.04607401948305778, 0.021585827162198257, 0.02304547579115024, 0.11622830425039865, 0.19933296949602664, 0.14278481947258115, 0.21446053666295484, 0.18994425219716504, 0.13722536154091358, 0.07925811383756809, 0.14701742125907913, 0.17766127770300955, 0.23036749247694388, 0.2045601382269524, 0.20899576193187386, 0.1075221475912258, 0.20237139629898593, 0.2602919703349471, 0.2728708687936887, 0.20595007692463696, 0.16626844997517765, 21.531662419438362, 65.8188445866108, 47.65522263944149, 35.86981303989887, 35.479163601994514, 55.42894430458546, 64.69167307019234, 61.575688272714615, 54.25507329404354, 10.956655070185661, 1.258421817328781, 10.332532860338688, 13.119586408138275, 22.2131235525012, 44.77777384221554, 51.93702667951584, 61.9506711512804, 54.47608843445778, 58.873037695884705, 55.15581116080284, 57.13686525821686, 56.183773800730705, 52.608674839138985, 45.863622575998306, 49.966007843613625, 51.68082542717457, 54.11120541393757, 50.12815274298191, 48.5713192820549, 44.23849917948246, 42.6885661482811, 41.232024505734444, 44.00155529379845, 40.00725522637367, 42.21276707947254, 41.979094818234444, 43.165258169174194, 40.735410153865814, 43.69707763195038, 40.62493868172169, 41.78492523729801, 42.74095393717289, 46.010693684220314, 41.39255069196224, 39.91433881223202, 39.6143639087677, 40.96280515193939, 41.00381255149841, 39.30044375360012, 40.93049168586731, 40.456364527344704, 43.35870958864689, 40.922443717718124, 43.343195021152496, 42.4329424649477, 39.531763941049576, 39.87442955374718, 43.97778756916523, 42.94974893331528, 45.448909029364586, 40.60579150915146, 41.48564949631691, 41.33888617157936, 43.78939747810364, 42.45142847299576, 41.173895224928856, 52.11541570723057, 59.00481082499027, 53.59315261244774, 55.32699577510357, 59.929012432694435, 60.40566265583038, 42.29972541332245, 52.5571496039629, 57.76163153350353, 53.35514098405838, 56.60039484500885, 57.270473688840866, 54.936692118644714, 51.587035059928894, 53.70770126581192, 50.42061924934387, 42.78330646455288, 40.16041360795498, 40.56875489652157, 42.45306618511677, 43.618741035461426, 39.68953147530556, 42.82990336418152, 41.915733218193054, 41.52118518948555, 40.08470267057419, 42.856714725494385, 42.37830899655819, 40.499412417411804, 41.3363479077816, 42.18459539115429, 39.25454221665859, 42.401784136891365, 40.72082653641701, 42.55245745182037, 38.96743722259998, 40.544329807162285, 41.542825028300285, 44.26816038787365, 45.80588087439537, 46.37156791985035, 41.85312777757645, 41.30243852734566, 40.355297550559044, 40.08816808462143, 39.03798423707485, 40.61034366488457, 43.70368927717209, 48.57171446084976, 48.05890917778015, 48.35090830922127, 49.734847247600555, 51.02314531803131, 51.50404371321201, 53.49924825131893, 54.06742416322231, 49.505461156368256, 47.64084041118622, 51.15692853927612, 53.771366849541664, 55.59904217720032, 54.142485335469246, 54.137743189930916, 52.41146922111511, 52.789491936564445, 34.76992025971413, 11.166879739612341, 4.685447830706835, 11.639128848910332, 18.586381562054157, 12.492562104016542, 0.6446810660418123, 3.4413800993934274, 55.08282467722893, 54.32266786694527, 47.721814066171646, 39.546735137701035, 39.53336365520954, 54.744768217206, 12.758549731224775, 0.5543758242856711, 0.24900142539991066, 0.11466658805147745, 0.09793586315936409, 0.20698290900327265, 0.16366469906643033, 0.16352976177586243, 0.12442251259926707, 0.1503598317503929, 0.12581792834680527, 0.1213523218757473, 0.1364413122064434, 0.2156811617896892], [0.04079559803358279, 0.02227481294539757, 0.10278767585987225, 0.02815628318785457, 0.00443518862084602, 0.09913338522892445, 0.015360171091742814, 0.05521462197066285, 0.028703956631943583, 0.015188882480288157, 0.01720896856568288, 0.07291708534467034, 0.027944182947976515, 0.017221859670826234, 0.038098570294096135, 0.03772934811422601, 0.12069520947989076, 2.7352623268961906, 35.03507763147354, 43.880831971764565, 19.82991423457861, 26.927275992929935, 40.94862051308155, 49.563104063272476, 47.86916255950928, 50.553562715649605, 13.63718893378973, 0.08908666495699435, 0.8501823514234275, 5.383304134011269, 18.00695065408945, 19.419416561722755, 34.36144217848778, 57.77179978787899, 54.5836378633976, 54.47580724954605, 52.2152591496706, 52.491736114025116, 49.7637864947319, 45.93741461634636, 46.60634212195873, 46.18738040328026, 48.7896403670311, 49.24813896417618, 45.931692123413086, 42.830553129315376, 38.57866868376732, 37.282972410321236, 36.297407895326614, 37.48273529112339, 37.0558699965477, 38.47444407641888, 36.669297739863396, 38.35392214357853, 40.51264710724354, 39.536050111055374, 38.81653591990471, 38.65832380950451, 38.75165440142155, 38.104552924633026, 37.201257795095444, 36.3359834253788, 37.40752972662449, 39.083357602357864, 38.80018539726734, 37.61116839945316, 38.71333725750446, 37.676091715693474, 37.85857692360878, 39.51781488955021, 39.37241569161415, 37.45700687170029, 38.07135030627251, 35.50858162343502, 37.9367159307003, 38.81459802389145, 38.095384016633034, 38.696291372179985, 38.87099839746952, 38.55289466679096, 40.587221905589104, 38.72045807540417, 38.23897071182728, 46.0490982234478, 52.00401708483696, 48.55831637978554, 56.371202543377876, 33.913814797997475, 32.46620647609234, 53.464719504117966, 36.75347842276096, 44.3549819290638, 58.60372714698315, 52.70482487976551, 51.15491084754467, 52.39503890275955, 48.766879588365555, 46.79683730006218, 44.01701666414738, 38.9436960965395, 35.455274283885956, 36.78079515695572, 37.037019208073616, 38.836538046598434, 38.472487181425095, 37.97679618000984, 39.71824273467064, 37.81163804233074, 38.22724834084511, 36.921623200178146, 37.01425842940807, 36.247064396739006, 37.094909101724625, 37.23754584789276, 36.57740727066994, 36.19390904903412, 37.047145664691925, 37.78296858072281, 37.143101915717125, 37.78147906064987, 35.29655680060387, 38.26564148068428, 38.52950692176819, 37.71405927836895, 36.86479724943638, 37.28006176650524, 35.65072439610958, 36.87569126486778, 34.65315252542496, 34.5634089410305, 36.04759410023689, 35.70014834403992, 36.4520899951458, 37.54704684019089, 39.05923269689083, 41.454878747463226, 43.046921119093895, 46.072246581315994, 44.56343114376068, 50.71804828941822, 49.58888567984104, 44.16841574013233, 44.32699643075466, 49.643667340278625, 52.589706256985664, 53.71753893792629, 52.63226017355919, 44.75993759930134, 14.365336261689663, 1.9388893037103117, 2.5834571477025747, 5.795629983767867, 7.2888220846652985, 4.107566764578223, 0.03663142226287164, 3.2155494298785925, 55.26629023253918, 38.12374949455261, 31.489138305187225, 29.218334555625916, 39.83456589281559, 38.21653671562672, 2.108902749605477, 0.20063261850737035, 0.04638615937437862, 0.03046851106773829, 0.029141619670554064, 0.03899150382494554, 0.019658723831526004, 0.061265689655556343, 0.0737178701092489, 0.033859530376503244, 0.04790834878804162, 0.058564116261550225, 0.039735139507683925, 0.008313427879329538, 0.013303260566317476, 0.04049947739986237, 0.0988079237868078, 0.06366936868289486, 0.01927253801113693, 0.0609946499025682, 0.059442744895932265, 0.10841991621418856, 0.07147263590013608, 0.03159524894726928, 0.022597264978685416, 0.07208591705420986, 0.017394023088854738, 0.016332286213582847, 0.07908877800218761, 0.011836220146506093, 0.11354854999808595, 4.530794229358435, 45.636645555496216, 49.786813259124756, 24.122616089880466, 28.778888136148453, 51.58679947257042, 54.42948393523693, 53.83992277085781, 54.25571545958519, 16.16295900195837, 0.10096906524267979, 3.475230820477009, 8.688704017549753, 24.910830594599247, 23.16315807402134, 37.48637169599533, 60.41979789733887, 57.72448092699051, 55.61102673411369, 53.81699860095978, 54.019181951880455, 50.619223192334175, 47.08239197731018, 44.62186820805073, 47.911967262625694, 51.54272563755512, 51.42026200890541, 48.70573326945305, 45.057340040802956, 41.0427338629961, 39.627283215522766, 38.259865790605545, 39.44244213402271, 39.74919967353344, 41.107402592897415, 39.06420283019543, 38.65105479955673, 42.9761803150177, 39.6370866894722, 40.77937759459019, 40.702473521232605, 40.22190950810909, 39.088597521185875, 39.5279261469841, 37.02081687748432, 39.065547958016396, 40.32780222594738, 41.43968716263771, 38.88124264776707, 40.93029409646988, 38.93624849617481, 40.20179718732834, 39.861377254128456, 40.204118862748146, 37.70664967596531, 40.06565049290657, 37.61011965572834, 40.176429748535156, 39.04842987656593, 41.32013417780399, 39.65743079781532, 40.87569862604141, 41.33469879627228, 43.56447994709015, 39.65884432196617, 39.80805091559887, 46.34242348372936, 56.66548155248165, 47.76611968874931, 57.767798602581024, 36.25774182379246, 35.694710835814476, 52.349293157458305, 39.913761243224144, 47.59943403303623, 54.95326682925224, 54.18250858783722, 51.534119099378586, 54.74439963698387, 50.62808811664581, 48.90262350440025, 46.285168156027794, 41.60685919225216, 37.385145127773285, 38.82392272353172, 39.58397313952446, 40.68301476538181, 37.38839015364647, 39.38085503876209, 40.113778710365295, 39.102899953722954, 39.66775484383106, 39.739540591835976, 37.585899755358696, 37.740517258644104, 38.11240330338478, 39.14023295044899, 37.47826673090458, 38.13725396990776, 39.84465815126896, 38.8886446505785, 38.686240911483765, 38.760690316557884, 37.08891682326794, 41.0678581148386, 40.786965787410736, 40.101953744888306, 38.27495478093624, 37.72737756371498, 38.133423775434494, 37.85506211221218, 37.56370894610882, 36.85961052775383, 37.67150156199932, 38.27702946960926, 37.35671505331993, 40.036437660455704, 42.28376626968384, 44.48249168694019, 44.85432833433151, 47.42518678307533, 47.2464519739151, 52.1634641289711, 50.778772830963135, 46.4324064552784, 45.39864532649517, 50.523806512355804, 53.08703497052193, 55.03837466239929, 52.41341471672058, 46.48905761539936, 17.694835402071476, 2.99989081453532, 7.9939511977136135, 9.591173641383648, 8.182733617722988, 2.7239531837403774, 0.13664332480402663, 4.208138342946768, 58.39712083339691, 44.28547985851765, 36.70820765197277, 30.27303636074066, 43.821380361914635, 44.69198204576969, 3.19465815089643, 0.1601578583358787, 0.08650526753626764, 0.0695146202633623, 0.06733556336257607, 0.03195345765561797, 0.03864847945806105, 0.013890741884097224, 0.07509927410865203, 0.052331337428768165, 0.007918839091871632, 0.07462548703188077, 0.057926774679799564, 0.1822179605369456, 0.1725666713900864, 0.20677283668192104, 0.24766410497250035, 0.16424162982730195, 0.08289825171232224, 0.3149019868578762, 0.16095807164674625, 0.2580355148529634, 0.1432727964129299, 0.13649151107529178, 0.09682405172497965, 0.18979315093019977, 0.09034748480189592, 0.053905822278466076, 0.1799073876463808, 0.1245846421807073, 0.3371570067247376, 5.110727185383439, 51.85881927609444, 57.49908082187176, 29.636882096529007, 37.37225241959095, 55.57946562767029, 59.92226019501686, 57.41103574633598, 58.181740790605545, 19.457595013082027, 0.12576703185914084, 6.408989271149039, 10.248020645231009, 21.865349113941193, 24.33427233248949, 39.3594241887331, 60.98344825208187, 60.51084481179714, 59.260027930140495, 57.16801218688488, 56.80932283401489, 52.30512052774429, 46.28549113869667, 45.59682369232178, 48.80373761057854, 52.220278680324554, 55.658167004585266, 51.030824705958366, 48.24105620384216, 42.1906902641058, 42.75358825922012, 39.40054178237915, 42.668343633413315, 40.623494759202, 44.10264506936073, 40.67793443799019, 42.089577689766884, 44.61727425456047, 43.83234277367592, 43.62953245639801, 41.308601796627045, 42.70336635410786, 43.3311078697443, 41.38095371425152, 38.86632464826107, 41.13854952156544, 41.571475490927696, 41.68184816837311, 41.51465713977814, 42.02581711113453, 43.36884364485741, 40.90034030377865, 41.740878000855446, 42.527469992637634, 39.467167407274246, 43.10758486390114, 39.20238621532917, 40.74453726410866, 41.443771943449974, 44.82556387782097, 44.57188569009304, 42.80753016471863, 43.98544795811176, 44.58683408796787, 42.41997756063938, 42.20594644546509, 50.22730462253094, 56.67861744761467, 51.44815631210804, 57.4509222060442, 40.84837049245834, 40.610856637358665, 51.8984891474247, 39.66321028769016, 52.68227308988571, 54.63076673448086, 54.77478660643101, 53.97702321410179, 55.52329324185848, 53.234945833683014, 51.22387334704399, 48.75837564468384, 43.22773061692715, 39.77536886930466, 40.216810181736946, 42.35134944319725, 42.85455264151096, 40.928891971707344, 41.158278062939644, 44.24847364425659, 40.893048495054245, 40.87659537792206, 41.01338803768158, 39.627754390239716, 40.02664938569069, 40.89984253048897, 40.44665604829788, 39.403391629457474, 39.53364484012127, 42.30758339166641, 41.11560635268688, 41.53412729501724, 42.072060629725456, 39.67750132083893, 43.208298459649086, 42.126640900969505, 42.67099969089031, 39.367137774825096, 40.39501681923866, 39.82235334813595, 38.50469805300236, 39.21359561383724, 38.52146275341511, 40.045435577631, 39.415767565369606, 39.877609983086586, 42.73017391562462, 42.66818404197693, 46.10177859663963, 47.568214908242226, 50.52092246711254, 49.733114540576935, 55.26144169270992, 52.714476361870766, 49.641007483005524, 46.95094183087349, 50.28197608888149, 53.07383447885513, 59.45338435471058, 54.01462219655514, 48.505996987223625, 18.471669517457485, 5.101176872849464, 7.5241586565971375, 17.136236876249313, 19.19286321848631, 12.088190652430058, 0.20336777408374473, 4.99360179528594, 66.7937658727169, 48.43125879764557, 43.82970571517944, 40.46264559030533, 53.054926693439484, 53.38417522609234, 4.473100025206804, 0.423481457401067, 0.18942332389997318, 0.1395609596511349, 0.14911027770722285, 0.1145954235107638, 0.18020910036284477, 0.07816023251507431, 0.1788934803334996, 0.1285216020187363, 0.19324444932863116, 0.17191171122249216, 0.19587819784646854, 0.32502874033525586], [0.038883695742697455, 0.03715530430781655, 0.03295222886663396, 0.05722741552744992, 0.04485900128202047, 0.0406365335220471, 0.0028402153930073837, 0.04254576408129651, 0.024170063297788147, 0.02643707954121055, 0.06424844425055198, 0.019868363851855975, 0.036566257986123674, 0.03143939422443509, 0.00393774929762003, 0.06429906614357606, 0.07151583631639369, 0.3775481862248853, 14.11017520353198, 43.61684113740921, 36.58453568816185, 36.318709552288055, 33.52662697434425, 50.13359025120735, 48.15351650118828, 55.07290720939636, 16.565385907888412, 0.033394671336282045, 2.7298640040680766, 1.9956617010757327, 0.6674877984914929, 2.9299845406785607, 31.97202019393444, 54.72608841955662, 51.89853094518185, 55.584393963217735, 51.91004432737827, 46.60590894520283, 48.58149893581867, 51.19559146463871, 47.59041711688042, 46.92793786525726, 52.7300289273262, 47.86336787045002, 44.77430462837219, 41.21931418776512, 39.974174201488495, 36.010774075984955, 36.104963421821594, 36.691336557269096, 36.381136402487755, 35.36419317126274, 38.315073028206825, 38.026147931814194, 40.04592575132847, 41.746494099497795, 41.27130679786205, 41.5219147503376, 41.36519595980644, 38.14205691218376, 38.150978833436966, 37.125866040587425, 37.36004747450352, 38.978388234972954, 38.42391438782215, 37.396909296512604, 37.57676884531975, 39.21372100710869, 38.44652317464352, 38.303411453962326, 38.4722325950861, 38.91062647104263, 38.52644808590412, 37.44289442896843, 38.05691108107567, 36.15878753364086, 37.669662460684776, 38.54301139712334, 39.76920560002327, 39.84789177775383, 40.82236468791962, 38.30069459974766, 39.31326046586037, 39.99359495937824, 49.87504072487354, 51.181490421295166, 54.92463156580925, 46.48433446884155, 40.06687022745609, 46.31170213222504, 50.541874542832375, 50.56027315557003, 53.48174259066582, 52.818252593278885, 54.03591625392437, 50.01629814505577, 48.95830571651459, 50.44856294989586, 44.22842971980572, 37.85397917032242, 36.56217388808727, 36.85781702399254, 37.71655194461346, 35.78140698373318, 37.01286390423775, 37.543212845921516, 39.072440788149834, 38.40858981013298, 39.77297879755497, 38.55949491262436, 38.80314543843269, 36.95407345890999, 37.16192610561848, 37.26810000836849, 36.06065399944782, 35.47944858670235, 36.44064120948315, 36.026877611875534, 36.294022276997566, 36.5123775601387, 36.74153186380863, 38.1750201433897, 37.02168323099613, 37.39082582294941, 38.678257539868355, 37.52404287457466, 34.49390687048435, 35.66482923924923, 34.7334536164999, 32.796613946557045, 35.19768610596657, 34.00503270328045, 34.237914606928825, 33.23735989630222, 34.0687894821167, 34.35392238199711, 33.44638668000698, 35.98761811852455, 40.18234983086586, 43.74135285615921, 47.19635546207428, 47.79574669897556, 45.292007848620415, 44.00085233151913, 44.83029082417488, 46.8869798630476, 47.25821614265442, 29.65270634740591, 2.193199801258743, 2.273942856118083, 13.49138980731368, 8.698659483343363, 6.02344723418355, 1.0547794634476304, 0.12597713386639953, 10.837071686983109, 51.13425135612488, 30.262697115540504, 28.893377892673016, 27.40561332553625, 41.360336020588875, 24.26861945539713, 0.15072842681547627, 0.09108914266107604, 0.05818091573019046, 0.024862837744876742, 0.021384011233749334, 0.04668874040362425, 0.02018569877691334, 0.032630144196446054, 0.041359129318152554, 0.04804141957720276, 0.04990668530808762, 0.02162896635127254, 0.036210327671142295, 0.020136130733590107, 0.0416802529070992, 0.02824889208568493, 0.01133992373070214, 0.015032828305265866, 0.032072320027509704, 0.008476377533952473, 0.05072520740213804, 0.012434173168003326, 0.08827588346321136, 0.008066342797974357, 0.031347753829322755, 0.03722200111951679, 0.05190709242015146, 0.0249396667277324, 0.024560727979405783, 0.026176869578193873, 0.08651654818095267, 0.35496130760293454, 21.67812366038561, 49.99200984835625, 35.91342709958553, 36.42440848052502, 39.44675110280514, 56.83607719838619, 51.4320033788681, 60.86248554289341, 15.5080546438694, 0.0676134902460035, 2.268030373379588, 4.84829711727798, 2.2713205218315125, 4.460586821660399, 35.71149453520775, 54.651164039969444, 54.02018129825592, 55.736355409026146, 52.85552479326725, 48.1566247344017, 49.336890801787376, 51.02515920996666, 46.91259428858757, 48.0192469060421, 56.286641880869865, 49.62994247674942, 49.107280522584915, 45.29680319130421, 42.35667295753956, 37.58421264588833, 38.595300391316414, 38.74596230685711, 39.734764248132706, 38.59905458986759, 40.988601967692375, 41.02519400417805, 41.89391478896141, 44.025410413742065, 43.011583015322685, 42.52682022750378, 42.707025557756424, 39.19955916702747, 40.31144790351391, 38.00527565181255, 39.54578518867493, 40.55022329092026, 41.038759276270866, 40.712326392531395, 39.09424401819706, 38.7139680236578, 39.18057158589363, 40.555375814437866, 39.8970041424036, 38.359861224889755, 39.719568863511086, 38.50640416145325, 39.21174131333828, 37.832734510302544, 39.26118426024914, 39.43529471755028, 41.07622146606445, 41.72536343336105, 40.568279922008514, 39.9861853569746, 43.12318302690983, 42.27082036435604, 51.006828993558884, 51.44995741546154, 55.970080867409706, 45.32942824065685, 39.185412526130676, 48.35100710391998, 47.809262573719025, 48.847803846001625, 55.46750083565712, 54.31039832532406, 53.86138781905174, 51.75841346383095, 50.5495311319828, 52.92315736413002, 46.725325137376785, 40.13147436082363, 37.972141429781914, 40.11923521757126, 41.02840483188629, 37.654269486665726, 38.73186506330967, 38.56859542429447, 40.3710363060236, 40.3793540596962, 41.40249475836754, 39.58717256784439, 41.04640446603298, 39.4047025591135, 37.47995384037495, 38.29506330192089, 38.2260400056839, 37.657081335783005, 38.06068807840347, 37.28627063333988, 38.01235847175121, 37.54591070115566, 38.16973462700844, 38.85902523994446, 40.72603985667229, 39.69561114907265, 40.10908596217632, 40.522625371813774, 36.59824535250664, 36.9408767670393, 36.623419001698494, 34.263057857751846, 36.86487324535847, 35.82967199385166, 36.49146728217602, 35.670194551348686, 36.34213529527187, 37.334550842642784, 37.453112080693245, 39.200246930122375, 42.99129590392113, 46.943547427654266, 49.483319744467735, 50.4011756926775, 47.137337028980255, 43.97516191005707, 46.23179242014885, 50.705033987760544, 50.41497655212879, 33.40958945453167, 2.924711611121893, 4.319976316764951, 8.878356590867043, 4.168988568708301, 2.5630738539621234, 0.7174538704566658, 0.25723301572725177, 10.799427106976509, 58.24032984673977, 37.985657304525375, 34.986622631549835, 29.99698117375374, 47.4342492967844, 30.93889933079481, 0.5093893257435411, 0.07951801395392977, 0.03436398670601193, 0.04168384490185417, 0.023091778384696227, 0.012299025293032173, 0.008942218992160633, 0.04039904997625854, 0.04694196119089611, 0.03956360320444219, 0.03463034350716043, 0.027276929104118608, 0.04631801537470892, 0.048003347401390783, 0.19017544604139403, 0.08235006433096714, 0.07913155539426953, 0.17657158226938918, 0.17191846476634964, 0.13721170602366328, 0.06792253538151272, 0.1790185915888287, 0.13613094604806975, 0.09274045092752203, 0.1078867944306694, 0.1161497479188256, 0.23150576889747754, 0.0838590954663232, 0.07457580024492927, 0.1343628385802731, 0.2508935902733356, 0.377962690545246, 27.48605500906706, 58.71768303215504, 47.24364012479782, 46.887739822268486, 43.34438435733318, 61.81540980935097, 56.40829235315323, 63.6507835239172, 20.921293571591377, 0.22396347048925236, 6.943336073309183, 3.903672555461526, 1.0187435033731163, 5.618829745799303, 38.56796845793724, 54.79505091905594, 53.40447373688221, 56.67367771267891, 53.76720227301121, 47.56683178246021, 50.39506942033768, 50.539260283112526, 49.06976133584976, 49.49694201350212, 56.06916815042496, 51.716710701584816, 51.54199227690697, 46.78334802389145, 44.01955872774124, 39.623456820845604, 41.650879830121994, 42.413445711135864, 41.51686482131481, 40.65205402672291, 44.541320130228996, 42.21374362707138, 43.93198102712631, 48.17846976220608, 45.88658094406128, 45.34733667969704, 45.88284194469452, 41.49082861840725, 43.132982701063156, 41.31793409585953, 41.35127350687981, 43.15318241715431, 43.37505631148815, 41.58207692205906, 40.28933688998222, 41.341907009482384, 40.23433864116669, 40.921801552176476, 42.406336292624474, 42.15521156787872, 42.8439512103796, 42.41181179881096, 40.93174181878567, 39.63286131620407, 40.65598301589489, 40.61627134680748, 43.67458663880825, 43.565711081027985, 45.24964012205601, 41.523624658584595, 44.67744022607803, 43.03176753222942, 52.86938264966011, 54.660819321870804, 57.55869582295418, 49.78349603712559, 45.89547626674175, 48.882404789328575, 47.92797200381756, 50.95581293106079, 57.70054221153259, 51.073553413152695, 56.903557777404785, 53.9533656835556, 52.49967388808727, 55.67189186811447, 48.71748223900795, 42.9361342638731, 42.105571031570435, 42.67821550369263, 42.6193680614233, 39.87638644874096, 40.785293877124786, 41.57130070030689, 42.92548343539238, 41.69009752571583, 43.102865517139435, 42.11928069591522, 43.617452904582024, 39.67750892043114, 40.33758670091629, 41.07331082224846, 39.95187699794769, 39.745046496391296, 40.631299540400505, 39.84242007136345, 38.91811206936836, 39.34401981532574, 38.98550905287266, 41.34192980825901, 42.39147149026394, 40.90933442115784, 42.206140235066414, 42.404751777648926, 37.53266841173172, 39.322220385074615, 38.58863174915314, 35.004227086901665, 38.673420399427414, 37.860811203718185, 37.55873501300812, 37.60813616216183, 39.102318584918976, 38.048110753297806, 37.818568870425224, 40.326742082834244, 44.45800580084324, 48.10542248189449, 52.42746636271477, 51.87334209680557, 50.41059158742428, 47.95927092432976, 45.880755856633186, 48.89518350362778, 52.008291855454445, 34.49685551226139, 5.081196594983339, 5.031435890123248, 27.896203100681305, 21.20881464332342, 13.661956004798412, 9.00246363133192, 0.302514829672873, 14.20263659209013, 63.21896709501743, 42.69661031663418, 41.7071396112442, 37.45626971125603, 52.95903503894806, 36.10055945813656, 1.022124015726149, 0.20615715096937492, 0.1259212353033945, 0.18449942639563233, 0.12978485610801727, 0.15823575522517785, 0.055331339535769075, 0.13371467648539692, 0.1793188348528929, 0.10200145945418626, 0.11234525401960127, 0.13540695130359381, 0.08755506511079147, 0.11309920926578343], [0.0195088471082272, 0.06754009184078313, 0.13170633581466973, 0.011692871539707994, 0.02901709100115113, 0.05337492693797685, 0.0288483414624352, 0.039993399477680214, 0.014350093260873109, 0.041764512643567286, 0.07901365039288066, 0.014418950649996987, 0.0949133257381618, 0.03319247691251803, 0.04308956536988262, 0.03314126872282941, 0.08839034489938058, 0.08909605312510394, 4.7229347191751, 42.35607638955116, 31.321061924099922, 26.871595680713654, 32.17230744659901, 42.28688970208168, 49.22083742916584, 51.07743300497532, 36.0311333835125, 1.8080657673999667, 5.463313590735197, 6.47692060098052, 1.6541194031015038, 0.33328168967273086, 15.660779848694801, 47.41412177681923, 52.50853881239891, 50.59966184198856, 47.48288668692112, 47.409866005182266, 48.466019332408905, 53.81549388170242, 39.10138003528118, 43.50135773420334, 49.37045820057392, 48.79503607749939, 48.14346224069595, 42.79707692563534, 41.81440785527229, 38.84089641273022, 37.20360986888409, 36.87241204082966, 38.308468982577324, 38.47329653799534, 40.3571480512619, 41.466608718037605, 42.5172333419323, 43.15269984304905, 45.615241304039955, 44.373433738946915, 44.71345469355583, 42.257893458008766, 38.81654351949692, 38.10450732707977, 38.33084598183632, 38.05284529924393, 39.79216776788235, 39.59585890173912, 38.51724497973919, 38.46665069460869, 37.254477739334106, 37.60893411934376, 38.94752249121666, 36.95920318365097, 37.23674029111862, 35.91222256422043, 37.21850126981735, 37.34620861709118, 40.471176132559776, 41.22571304440498, 47.43970960378647, 44.958655536174774, 43.6884330958128, 41.28880865871906, 41.45124614238739, 38.180108070373535, 45.74207849800587, 49.80616942048073, 51.85629241168499, 51.177785620093346, 52.780281230807304, 43.51655691862106, 53.85751962661743, 48.862459659576416, 33.208264857530594, 49.48782630264759, 51.68592095375061, 53.134676814079285, 51.10090434551239, 46.21597006917, 45.35942383110523, 39.006609320640564, 36.36215642094612, 34.940306916832924, 38.751608803868294, 38.71943973004818, 38.02865579724312, 38.82078789174557, 39.1120308637619, 37.88523629307747, 37.651343643665314, 37.005632892251015, 37.470252960920334, 38.72725211083889, 36.3112011551857, 36.606414914131165, 37.00722500681877, 35.25146082043648, 35.537467673420906, 38.34545239806175, 36.51605196297169, 35.88057026267052, 36.771394461393356, 36.53658986091614, 38.83568309247494, 36.246798411011696, 35.900393798947334, 36.33003294467926, 35.479634776711464, 35.78821241855621, 34.233499243855476, 35.11022239923477, 33.47111575305462, 33.06950010359287, 34.66240882873535, 36.166113540530205, 38.437046483159065, 39.05196748673916, 38.154835626482964, 38.763486966490746, 36.45512603223324, 37.52882681787014, 40.87935023009777, 46.59796357154846, 47.16772399842739, 49.36008095741272, 44.30246114730835, 46.562541872262955, 40.517883226275444, 8.425925318151712, 0.6828163540922105, 4.096690323203802, 3.659077067859471, 3.0766932433471084, 3.609266490675509, 0.14056328946026042, 0.34281327039934695, 14.65325916185975, 48.81144739687443, 24.98982075601816, 20.96555169671774, 22.66732268035412, 46.16755686700344, 7.544184057042003, 0.07980216003488749, 0.07800001767463982, 0.041614053334342316, 0.05578185657213908, 0.13437698391498998, 0.04293385907658376, 0.11600198631640524, 0.07076746944221668, 0.06783628297853284, 0.017129478983406443, 0.04474231711355969, 0.08607059164205566, 0.10004970754380338, 0.01885378860606579, 0.03871962915582117, 0.006632717577303993, 0.02715531336434651, 0.07730598343187012, 0.05470992444315925, 0.018215246600448154, 0.009241117113560904, 0.1162053867301438, 0.06071241485187784, 0.02288223669893341, 0.025314197118859738, 0.01941811955475714, 0.03078099420235958, 0.0754314148798585, 0.0684225425356999, 0.0291889742584317, 0.05971341728582047, 0.06173502013552934, 8.611682150512934, 51.67782358825207, 39.59033399820328, 30.67997172474861, 36.93312518298626, 52.65751741826534, 53.245057091116905, 55.59293210506439, 36.30963183939457, 1.2404487817548215, 1.3232985860668123, 8.979579359292984, 3.8203216530382633, 0.9625388192944229, 19.892413280904293, 51.07987627387047, 54.131534323096275, 51.65576957166195, 47.091082111001015, 48.45336601138115, 49.61167685687542, 53.38205114006996, 39.96165007352829, 47.1515216678381, 50.98632529377937, 50.45738987624645, 49.58973303437233, 44.7837433218956, 43.52118507027626, 39.345596730709076, 38.691849410533905, 39.13740210235119, 39.54102784395218, 40.5551478266716, 40.995874777436256, 43.875025883316994, 44.01092939078808, 44.83162075281143, 46.210220977663994, 45.70536106824875, 46.15141533315182, 42.44630254805088, 39.7130636125803, 39.07418109476566, 39.9273607134819, 39.963458776474, 40.963914692401886, 41.40533320605755, 41.107497587800026, 39.61058311164379, 39.90565627813339, 39.535749927163124, 39.891106858849525, 39.848085567355156, 38.10241363942623, 38.19950982928276, 39.219413101673126, 39.96895328164101, 40.88873192667961, 42.88114741444588, 47.792634665966034, 45.7830972969532, 44.69234302639961, 43.63523595035076, 43.70552837848663, 41.03988401591778, 47.815102860331535, 50.23312970995903, 53.741470053792, 53.656795397400856, 52.05631747841835, 45.368661135435104, 53.48422385752201, 49.265416637063026, 38.26311081647873, 50.80511301755905, 54.18303295969963, 51.64608769118786, 52.4649665504694, 48.4169639647007, 47.685875594615936, 40.06766818463802, 37.058199271559715, 36.29180319607258, 40.498280078172684, 39.13968198001385, 40.28518371284008, 39.271565303206444, 39.51016589999199, 39.548296853899956, 38.70926387608051, 37.89641909301281, 39.78581830859184, 39.2539456486702, 38.163316771388054, 37.10806779563427, 39.88486759364605, 38.116282895207405, 38.08335766196251, 39.85433243215084, 38.10912027955055, 36.7278677970171, 36.294432654976845, 38.77874694764614, 39.76054586470127, 38.476902544498444, 37.72068612277508, 38.55710104107857, 36.52616702020168, 37.87041708827019, 35.60135744512081, 35.93130134046078, 34.46549579501152, 35.023134872317314, 35.5901138484478, 38.52031521499157, 41.01581610739231, 39.764657244086266, 40.27020491659641, 38.385654240846634, 37.94636361300945, 40.22960789501667, 42.966821417212486, 48.98865848779678, 49.55025315284729, 51.46147079765797, 44.20116238296032, 47.41889052093029, 42.0731283724308, 11.959100179374218, 0.7961784617509693, 6.117537785321474, 4.001228995621204, 1.7480712616816163, 1.0644584940746427, 0.5971873551607132, 0.21780438692076132, 17.43433468043804, 55.20677022635937, 31.076919324696064, 26.94133523851633, 26.264473758637905, 52.96116292476654, 12.612004894763231, 0.09621329387300648, 0.05176901955564972, 0.04128252483496908, 0.09254392280126922, 0.021464513847604394, 0.01894529355922714, 0.07795295809046365, 0.04009233889519237, 0.053786232601851225, 0.06130988083896227, 0.011741889466065913, 0.03990613033238333, 0.04046655201818794, 0.030387396182049997, 0.0839459638518747, 0.1669911979115568, 0.2333344949875027, 0.1373149684513919, 0.17517497908556834, 0.17364557599648833, 0.1716363595915027, 0.17365422943839803, 0.16947291005635634, 0.18315480323508382, 0.1547050618682988, 0.1586269264225848, 0.11776734041632153, 0.18193036346929148, 0.2099286564043723, 0.10857559653231874, 0.17761376540875062, 0.22353232721798122, 11.329505313187838, 58.97298753261566, 43.802514374256134, 39.18204590678215, 44.10712502896786, 55.95432311296463, 56.79018326103687, 61.63972623646259, 45.16303516924381, 2.6768069760873914, 8.844715096056461, 17.118189744651318, 3.1130157317966223, 1.159422998316586, 22.646927274763584, 52.09189876914024, 53.94479714334011, 51.6962867975235, 47.44947127997875, 48.07937867939472, 50.23172378540039, 53.839368000626564, 42.63023167848587, 49.323082342743874, 53.23089525103569, 50.46766072511673, 52.65578471124172, 45.639996975660324, 46.65846772491932, 42.44938038289547, 40.43450430035591, 42.59334325790405, 43.26393887400627, 43.817709758877754, 44.225298687815666, 45.15089102089405, 47.09656901657581, 47.34463110566139, 50.7780546694994, 48.48500691354275, 49.4137454777956, 45.26005916297436, 41.580796390771866, 41.181757003068924, 41.07157811522484, 41.93255491554737, 43.4232073277235, 45.16745053231716, 42.31148198246956, 41.660766899585724, 41.39565512537956, 40.87570622563362, 41.67718581855297, 42.61660560965538, 40.10407403111458, 39.18125554919243, 40.7270810008049, 41.49739846587181, 44.56663437187672, 46.66497677564621, 52.86806792020798, 48.95435392856598, 48.46991412341595, 45.284358859062195, 45.72451964020729, 42.19764769077301, 49.257516860961914, 51.158285066485405, 54.5152073353529, 55.629850924015045, 55.05054160952568, 47.61461041867733, 52.26328857243061, 52.81499236822128, 41.08937256038189, 52.69271492958069, 51.987411975860596, 54.45392042398453, 54.05331552028656, 51.74494318664074, 49.50090900063515, 42.057705000042915, 39.12732124328613, 39.430206790566444, 43.34895931184292, 41.036126017570496, 42.08734340965748, 41.794230937957764, 41.967459842562675, 41.032892391085625, 42.86652199923992, 41.073607206344604, 41.40333071351051, 42.46888853609562, 39.75030541419983, 39.87168990075588, 39.437882378697395, 40.15158288180828, 39.07852806150913, 42.33127512037754, 39.498344734311104, 39.90144990384579, 38.74725803732872, 41.25765413045883, 43.18513870239258, 40.35347364842892, 41.06530845165253, 39.93779495358467, 38.697936683893204, 39.93922747671604, 36.50329224765301, 37.493082135915756, 35.23785375058651, 37.114512249827385, 38.286122381687164, 40.6455297768116, 42.87760220468044, 42.477502673864365, 43.47705043852329, 41.09384872019291, 40.4337215423584, 41.443574354052544, 44.848757833242416, 53.71194563806057, 50.853625014424324, 51.1777438223362, 44.94570203125477, 48.476035594940186, 42.910960614681244, 14.615111108869314, 1.946319923736155, 10.146143361926079, 13.376377578824759, 10.830795373767614, 6.60637347958982, 4.409692827612162, 0.3381584904855117, 19.078134074807167, 61.19926907122135, 33.926677107810974, 34.024290069937706, 32.17541567981243, 62.97415763139725, 18.935981802642345, 0.39093451166991144, 0.21000628505134955, 0.09941157928551547, 0.13989179424243048, 0.21716076676966622, 0.10309239427442662, 0.31549074745271355, 0.15362468780949712, 0.1829959242604673, 0.19299378152936697, 0.13316237018443644, 0.11960603354964405, 0.2322226093383506, 0.11494535356177948], [0.015571672047371976, 0.03651341707154643, 0.026624564598023426, 0.09769293596036732, 0.057867777650244534, 0.08155514253303409, 0.022423966074711643, 0.03426038660109043, 0.026271137176081538, 0.047488901764154434, 0.043534219439607114, 0.006292979996942449, 0.015843292530917097, 0.035708732320927083, 0.032158401736523956, 0.06940150953596458, 0.04409621447848622, 0.040718770906096324, 0.6303792272228748, 24.843065030872822, 45.32920025289059, 19.417161382734776, 18.584747649729252, 32.52398617565632, 41.96680627763271, 50.46803690493107, 42.66497701406479, 1.406738783698529, 0.34470924991182983, 6.976098865270615, 3.917307648807764, 0.303299457882531, 5.308615816757083, 40.030479580163956, 54.58597473800182, 49.65750239789486, 48.50294955074787, 48.000601306557655, 46.9317414611578, 47.31826812028885, 51.47929564118385, 52.15272210538387, 49.60296772420406, 47.1408898383379, 48.04601266980171, 44.33206155896187, 41.21069625020027, 39.931453093886375, 37.626287788152695, 36.651271507143974, 38.36819797754288, 39.957280308008194, 42.21295326948166, 44.856243431568146, 45.32468989491463, 45.13831749558449, 47.87860885262489, 48.263695389032364, 47.629543617367744, 47.64511898159981, 42.99063853919506, 41.66952542960644, 38.62791784107685, 40.79674646258354, 39.24710601568222, 40.45403905212879, 38.95747795701027, 38.00738833844662, 38.74000042676926, 38.96013401448727, 37.32315145432949, 38.093172535300255, 37.7177868783474, 38.42516452074051, 37.39624433219433, 38.33892434835434, 42.23613202571869, 49.89351153373718, 49.5486306399107, 51.54573127627373, 48.098753839731216, 48.94843004643917, 47.779608964920044, 42.20795273780823, 41.28821589052677, 44.2240409553051, 51.89525172114372, 53.125819489359856, 51.96445360779762, 50.59393174946308, 44.59170922636986, 40.539390072226524, 38.64415816962719, 45.23069053888321, 50.69145731627941, 51.3708570599556, 51.01989269256592, 49.25198435783386, 45.268726497888565, 39.11109231412411, 36.07817105948925, 35.295158475637436, 36.312071308493614, 37.93560639023781, 38.05506058037281, 35.582966431975365, 37.318337112665176, 35.90468376874924, 37.15661019086838, 37.44999244809151, 36.76884479820728, 37.63262964785099, 35.349062383174896, 35.72935737669468, 37.75505527853966, 37.10598550736904, 34.994032233953476, 35.715856701135635, 36.241189911961555, 36.34297885000706, 41.68674610555172, 41.96725845336914, 43.528366684913635, 42.097690254449844, 39.91107478737831, 39.39636580646038, 36.38175956904888, 35.9208595007658, 34.746046140789986, 35.34724608063698, 37.06899829208851, 36.79896578192711, 38.933394849300385, 43.08488868176937, 42.56661929190159, 46.1628071218729, 45.52006781101227, 45.25418847799301, 46.924286261200905, 44.86919693648815, 43.92311230301857, 43.52930523455143, 47.78121627867222, 48.348195254802704, 49.126959666609764, 48.883544728159904, 23.818030133843422, 1.0900520207360387, 3.921520672738552, 9.626426249742508, 1.7885588016360998, 0.5744896293617785, 0.3464729490224272, 0.6246148177888244, 0.3152611566474661, 18.349181190133095, 42.216646671295166, 26.542620733380318, 25.6101830676198, 28.818406015634537, 43.32728147506714, 3.8586354721337557, 0.10107330730534159, 0.057412021051277407, 0.04424433231179137, 0.0911788312077988, 0.03191262097971048, 0.02025002999289427, 0.005277760938042775, 0.06263768693315797, 0.05227624780673068, 0.02581564403953962, 0.0147453713179857, 0.028887241132906638, 0.047391313055413775, 0.02056722205452388, 0.03683427348732948, 0.03162869754305575, 0.014130275612842524, 0.0204153712184052, 0.014840686271782033, 0.05779281331342645, 0.07037778254016303, 0.057488265592837706, 0.02668862864084076, 0.06396650976967067, 0.030626215593656525, 0.04167344370216597, 0.02474683820764767, 0.026568341345409863, 0.07345143167185597, 0.02153872490453068, 0.052664179529529065, 0.02371829017647542, 1.415725420229137, 32.1291683614254, 47.71829165518284, 24.51322752982378, 29.1724007204175, 42.20794893801212, 49.25898738205433, 53.84030655026436, 48.55838097631931, 1.6385838179849088, 0.6894484825897962, 2.0532383490353823, 8.293507173657417, 1.8759250198490918, 6.939004780724645, 43.31113614141941, 53.084340915083885, 51.52214214205742, 47.0667178183794, 46.46822713315487, 46.80262818932533, 48.63213121891022, 51.35956786572933, 52.577375918626785, 50.060531571507454, 48.46557475626469, 49.662746116518974, 47.71925300359726, 42.51271538436413, 40.783268585801125, 39.63481821119785, 40.22147633135319, 40.906803756952286, 43.231948390603065, 44.24947299063206, 46.57795764505863, 47.47170768678188, 47.27600298821926, 49.250323846936226, 51.887089759111404, 49.60547558963299, 49.70265917479992, 44.74291831254959, 43.85473497211933, 41.89247086644173, 41.658057644963264, 41.02291412651539, 41.30004085600376, 40.14463685452938, 40.046206936240196, 40.6741726398468, 40.951162576675415, 38.9952365309, 39.97354343533516, 38.85994479060173, 40.26377186179161, 40.41860215365887, 40.76342985033989, 44.73954789340496, 50.248336493968964, 51.712751314044, 51.16328179836273, 50.32810941338539, 48.946967124938965, 48.807594403624535, 42.88633793592453, 43.355798944830894, 47.780296728014946, 53.789434880018234, 53.62592585384846, 54.18471246957779, 50.511175990104675, 47.17075243592262, 41.54679201543331, 39.517879486083984, 45.776299461722374, 53.671405613422394, 52.67626941204071, 52.36911289393902, 51.22823931276798, 46.4285534620285, 41.51837334036827, 38.040967136621475, 36.67794607579708, 38.39588709175587, 38.3796201646328, 40.13351485133171, 37.950353398919106, 38.34801726043224, 39.01690676808357, 38.66031110286713, 38.976081758737564, 39.68358859419823, 38.982651606202126, 38.06732252240181, 37.05594979226589, 38.887037336826324, 38.51354397833347, 37.84685455262661, 38.907267451286316, 37.703568041324615, 37.908479645848274, 42.87270046770573, 44.24611397087574, 43.83786007761955, 43.903007581830025, 41.0476204007864, 41.570951119065285, 37.92054399847984, 37.451869547367096, 35.2962452173233, 36.61992318928242, 37.2589311003685, 39.3168018758297, 39.780768379569054, 44.64121676981449, 44.779289960861206, 47.319525852799416, 48.14623989164829, 47.4190729111433, 49.641626849770546, 46.35020546615124, 46.54008887708187, 46.18516132235527, 49.18600469827652, 50.232859924435616, 48.904546201229095, 49.66787204146385, 27.003507502377033, 2.110541411675513, 4.420082895085216, 10.60022659599781, 2.4411607207730412, 0.6220112449955195, 0.6262435647659004, 0.6298018363304436, 0.37009117542766035, 19.576369039714336, 50.178655833005905, 32.99681760370731, 29.069734029471874, 31.224303916096687, 50.95235511660576, 5.550609631463885, 0.13675442431122065, 0.15433609572937712, 0.06816936627728865, 0.05060382543888409, 0.0407970340893371, 0.02881784846977098, 0.05349682098312769, 0.05892411354579963, 0.029132522795407567, 0.050147868460044265, 0.05805501037684735, 0.031661775065003894, 0.031851976382313296, 0.05715752377000172, 0.11709032361977734, 0.13157374371076003, 0.1340089677250944, 0.17087482701754197, 0.14639723813161254, 0.16844696510815993, 0.16606180637609214, 0.1408082724083215, 0.09918399227899499, 0.18952159909531474, 0.1888351867091842, 0.07291092551895417, 0.10790193424327299, 0.07549132846179418, 0.12912081205286086, 0.14055055420612916, 0.1910082544782199, 0.18043674674117938, 1.7497492278926075, 39.13674473762512, 58.35064172744751, 30.23771345615387, 28.53683352470398, 45.020166635513306, 50.88686183094978, 58.90731565654278, 52.226426750421524, 1.8203296093270183, 1.1964295688085258, 19.477762430906296, 8.55369821190834, 1.516202122438699, 9.974393527954817, 44.84039448201656, 53.85568432509899, 50.61526380479336, 48.373570293188095, 48.2441758364439, 46.10105283558369, 49.7165322303772, 51.23035579919815, 53.71349975466728, 52.29135386645794, 51.87350168824196, 53.38423602283001, 50.06776638329029, 45.53744047880173, 43.830769658088684, 42.456998974084854, 42.49313123524189, 42.16564200818539, 44.83987011015415, 46.85607232153416, 49.21607248485088, 49.88555856049061, 50.14714792370796, 51.28129206597805, 54.17464680969715, 51.64274387061596, 52.16062568128109, 47.0836117118597, 47.6185318082571, 43.02109770476818, 44.79081854224205, 43.44905734062195, 42.80713118612766, 42.409227937459946, 42.63914220035076, 43.035609126091, 43.059004470705986, 41.7318344861269, 42.26251021027565, 41.39243669807911, 41.874144449830055, 43.674753829836845, 42.350589483976364, 45.87336905300617, 52.79230758547783, 53.05592603981495, 53.14684756100178, 54.57028917968273, 52.24786140024662, 51.322466656565666, 46.76057584583759, 44.97609280049801, 48.168761283159256, 56.52893587946892, 56.24641343951225, 55.18428683280945, 52.226916924118996, 47.91428133845329, 44.82860371470451, 39.797088503837585, 49.77855250239372, 55.77109694480896, 54.921420738101006, 55.23434154689312, 53.63557733595371, 50.0772924721241, 44.01063300669193, 40.99767588078976, 37.42423743009567, 41.225002482533455, 41.95301681756973, 41.46315470337868, 39.37306545674801, 39.80056531727314, 39.64981980621815, 40.80729089677334, 40.92528596520424, 40.644188448786736, 41.02335870265961, 37.924833968281746, 37.64409363269806, 41.52807801961899, 40.58328151702881, 39.1489002853632, 40.35216271877289, 40.113083347678185, 40.13626590371132, 46.14909365773201, 44.802776500582695, 46.50721304118633, 46.282922476530075, 44.4870438426733, 43.24799492955208, 39.770470932126045, 40.23749627172947, 37.96214036643505, 37.924267798662186, 40.41636787354946, 40.93692474067211, 42.998549714684486, 47.73465737700462, 47.15696677565575, 50.80081544816494, 50.693740993738174, 48.56473043560982, 52.674027532339096, 49.92269776761532, 48.49452920258045, 47.104898169636726, 52.17317260801792, 52.52185329794884, 49.4950345158577, 51.61894574761391, 30.746319964528084, 3.076849984936416, 9.44490049034357, 16.326215341687202, 4.485053233802319, 2.4982828181236982, 2.277799886651337, 1.3894218066707253, 0.21500928065506741, 22.31745645403862, 54.80705827474594, 36.86727471649647, 36.161834970116615, 39.408521354198456, 59.845755100250244, 8.371208254247904, 0.3301996097434312, 0.3312669665319845, 0.11228930350625888, 0.14596594643080607, 0.14396682323422283, 0.10774525202577934, 0.17210670310305431, 0.21167022467125207, 0.141661875823047, 0.09389901766553521, 0.14455862663453445, 0.1602573654963635, 0.13287649489939213, 0.07616087925271131], [0.04858379965298809, 0.04094967160199303, 0.03780081322474871, 0.014921536767360521, 0.05535746684472542, 0.04374619165901095, 0.06777455855626613, 0.028303343460720498, 0.08793494082055986, 0.044484906902653165, 0.07594069888000377, 0.10793458131956868, 0.037773713702335954, 0.018472914707672317, 0.04978504359314684, 0.01098807244488853, 0.014137167381704785, 0.04178487346507609, 0.052367680400493555, 9.061776548624039, 43.39367151260376, 29.312265515327454, 22.929079234600067, 33.14505524933338, 42.786502093076706, 45.606820955872536, 47.18921184539795, 1.9839162938296795, 0.6398569873999804, 2.7474812837317586, 8.470835108309984, 1.2517792987637222, 1.6124787437729537, 24.17354855686426, 49.525330290198326, 50.515393763780594, 51.978638246655464, 52.13471867144108, 46.88096098601818, 53.87560285627842, 44.72742274403572, 49.303369000554085, 51.44746474921703, 51.60919167101383, 48.4888257086277, 45.550610572099686, 42.72613853216171, 39.014353305101395, 38.708621710538864, 40.99679432809353, 40.475523099303246, 43.05169366300106, 44.200163036584854, 46.02533809840679, 48.364994153380394, 49.089649468660355, 47.15107709169388, 49.619287848472595, 48.09274636209011, 47.14788906276226, 45.34609034657478, 40.659991800785065, 39.77356776595116, 36.835253834724426, 38.89918528497219, 38.482613638043404, 39.19909939169884, 37.61670470237732, 38.90758663415909, 39.649637416005135, 38.09669874608517, 37.299908101558685, 38.04795116186142, 39.778214916586876, 36.03368304669857, 36.97906091809273, 47.47299201786518, 50.14554440975189, 52.82884642481804, 51.47120587527752, 52.31184996664524, 52.44124062359333, 49.72167335450649, 48.80273826420307, 43.44662927091122, 42.85872481763363, 46.763767674565315, 50.78126169741154, 51.35762996971607, 52.3543468862772, 47.229717671871185, 44.54799637198448, 50.14797627925873, 49.967208579182625, 49.47652570903301, 51.602933406829834, 49.908418133854866, 48.43029364943504, 44.84012849628925, 39.33623783290386, 36.3433588296175, 35.87492756545544, 36.262240782380104, 38.774848356842995, 37.953302040696144, 35.920597314834595, 36.04010470211506, 38.336458280682564, 38.07241804897785, 38.123304918408394, 38.92725817859173, 36.053426787257195, 36.68076932430267, 36.54754847288132, 35.27012541890144, 35.03007709980011, 37.163339629769325, 37.902768552303314, 34.12688456475735, 39.18623328208923, 41.86424978077412, 46.282029524445534, 47.557218298316, 45.79839147627354, 45.29297299683094, 43.65810312330723, 41.810250878334045, 38.79127487540245, 36.846193447709084, 35.74950389564037, 35.668169260025024, 35.9387793391943, 36.36281758546829, 40.84951423108578, 45.74340082705021, 47.626568377017975, 47.77107082307339, 46.61081448197365, 47.51510515809059, 49.03993293642998, 48.18601995706558, 46.70216917991638, 49.6967238932848, 49.76032108068466, 45.495901107788086, 41.351212710142136, 5.830258000642061, 0.1462461517076008, 0.6741069245617837, 4.96281917206943, 3.522581742145121, 0.2385678977589123, 0.2724333282094449, 0.29029501194600016, 0.45019337092526257, 23.21503859013319, 35.3138192743063, 22.8288197144866, 22.68512662500143, 31.193430572748184, 32.284933403134346, 0.6879127712454647, 0.04347190129919909, 0.040905896021286026, 0.034264913701917976, 0.0409068311273586, 0.028361166041577235, 0.06035151585820131, 0.02164691519283224, 0.07660840172320604, 0.0244374052999774, 0.01827233259973582, 0.012398395156196784, 0.02437859195197234, 0.04190474144706968, 0.0436220860137837, 0.06732950743753463, 0.09929379302775487, 0.015253700730681885, 0.02708197989704786, 0.07731640318525024, 0.04036646227177698, 0.06869814649689943, 0.05959868125501089, 0.053724515601061285, 0.010105137498612748, 0.0232232257258147, 0.0466099836921785, 0.06047061200661119, 0.013151453331374796, 0.037613272506860085, 0.010474162081663962, 0.007478270081264782, 0.027056646686105523, 0.028802556516893674, 14.97376911342144, 51.92096874117851, 31.817883364856243, 20.984242893755436, 38.51643942296505, 47.7685933560133, 52.19955079257488, 50.82497835159302, 1.9058363023214042, 0.435614800080657, 1.287973306607455, 3.7283644499257207, 3.465656996704638, 3.169478802010417, 28.26627854257822, 50.30304595828056, 51.52325928211212, 50.29413163661957, 50.85910812020302, 49.745832458138466, 55.35503827035427, 47.66939967870712, 52.07929104566574, 51.21036887168884, 51.89869053661823, 51.303574070334435, 48.474979251623154, 44.93223935365677, 42.62393161654472, 39.88210894167423, 41.86492994427681, 42.32165023684502, 44.6003195643425, 46.155845895409584, 47.43306756019592, 50.12990064918995, 50.65676137804985, 51.17433160543442, 52.56177395582199, 50.14224998652935, 48.89517970383167, 47.50197686254978, 41.98070593178272, 40.85981547832489, 38.98610562086105, 39.27234806120396, 40.564027950167656, 41.98568746447563, 40.26074342429638, 39.15448218584061, 40.11844106018543, 39.86357733607292, 37.909912168979645, 38.72616916894913, 41.57333739101887, 36.67366750538349, 39.42927964031696, 49.34252589941025, 51.99424400925636, 54.46681693196297, 53.79971332848072, 55.12072004377842, 53.412650898098946, 49.99279260635376, 49.6905530244112, 44.34853747487068, 44.07533973455429, 50.64955696463585, 52.51781791448593, 52.30192869901657, 53.81703279912472, 45.95192603766918, 46.9001005589962, 50.53884610533714, 50.49753852188587, 51.61515735089779, 53.067412823438644, 51.465095803141594, 50.63814617693424, 45.79421930015087, 41.502554789185524, 37.82556429505348, 37.7953939139843, 38.91002990305424, 39.591291546821594, 39.930886924266815, 38.04689101874828, 38.790986090898514, 40.395199209451675, 38.73718857765198, 40.21539285778999, 39.5048575848341, 38.00429530441761, 38.498325794935226, 37.25922368466854, 37.59748913347721, 37.54790939390659, 37.90173500776291, 38.757483288645744, 37.269011959433556, 41.130041778087616, 44.3134805560112, 47.628145292401314, 49.15353164076805, 48.214818611741066, 46.487416103482246, 45.84865517914295, 43.17645616829395, 39.55701358616352, 39.00145299732685, 36.79223634302616, 37.15473689138889, 36.79558016359806, 37.95607969164848, 43.88097636401653, 47.91544407606125, 49.12372604012489, 48.543196991086006, 48.257649913430214, 48.284157291054726, 52.07958742976189, 49.23333875834942, 50.13341926038265, 50.5471258610487, 50.81954464316368, 46.31172493100166, 42.68330343067646, 7.724010832607746, 0.28954867855645716, 3.363596610724926, 3.4867361281067133, 0.23212369589600712, 0.2412257215473801, 0.4939400078728795, 0.2169170306297019, 0.20535980234853923, 25.05866926163435, 42.09313429892063, 31.574185341596603, 28.693772703409195, 35.31214736402035, 40.14949679374695, 1.2833865964785218, 0.047877312172204256, 0.03971108279074542, 0.016783601058705244, 0.05484199333295692, 0.006944317556190072, 0.012295933320274344, 0.07852642302168533, 0.0044142183105577715, 0.08053227749769576, 0.03463677050604019, 0.0573669170262292, 0.05456595892610494, 0.0544101598643465, 0.03801704166107811, 0.19575488258851692, 0.3031262703007087, 0.18633849802426994, 0.1549555960809812, 0.20220206788508222, 0.1720935819321312, 0.1480419561266899, 0.10958707702229731, 0.31137945712544024, 0.20453640434425324, 0.14264590427046642, 0.17910816881339997, 0.11146972014103085, 0.11754233608371578, 0.14854872424621135, 0.08407578032347374, 0.11129808364785276, 0.18871176755055785, 0.2025508921360597, 17.354132384061813, 58.294891119003296, 39.612764194607735, 31.832590475678444, 45.176912024617195, 53.34442175924778, 55.026724487543106, 56.600486040115356, 2.5653520692139864, 1.3969968189485371, 9.4957759603858, 23.232382759451866, 3.6999471997842193, 4.6140852849930525, 31.229363344609737, 51.61514215171337, 51.95267803966999, 52.44042746722698, 51.019641906023026, 48.16836230456829, 56.51150241494179, 48.90848658978939, 53.21438133716583, 51.618265584111214, 52.61238344013691, 52.548459470272064, 50.9048842638731, 48.24448361992836, 43.32198455929756, 41.60293400287628, 47.25069634616375, 43.02957884967327, 47.21737213432789, 48.46402443945408, 50.34095652401447, 51.98412515223026, 53.36574241518974, 50.62592223286629, 53.756034672260284, 52.501186206936836, 50.535023510456085, 50.31797915697098, 43.21559026837349, 43.345714285969734, 39.237781316041946, 42.29763172566891, 41.42606109380722, 44.31396692991257, 43.078041449189186, 40.94933107495308, 43.358827382326126, 41.41325198113918, 40.41718862950802, 41.323067620396614, 44.45914953947067, 39.311877340078354, 40.67688949406147, 51.75411969423294, 54.238441586494446, 56.44506298005581, 55.800188183784485, 57.047034278512, 55.86033135652542, 55.06318733096123, 51.773802638053894, 46.87890909612179, 46.911028772592545, 52.86949284374714, 54.64154675602913, 55.08713744580746, 56.761817783117294, 47.102470099925995, 47.32579171657562, 51.549295485019684, 53.06981809437275, 53.67214277386665, 54.828584119677544, 53.745034262537956, 54.13169011473656, 49.85687769949436, 43.568351939320564, 39.25405204296112, 40.38457877933979, 41.51736259460449, 42.1356426179409, 41.60973183810711, 38.92005756497383, 39.527253583073616, 41.63849629461765, 39.91316847503185, 41.736443638801575, 41.368687972426414, 39.24722760915756, 41.463204100728035, 39.90777276456356, 39.12487417459488, 38.00287418067455, 40.93910202383995, 41.00463330745697, 38.656777292490005, 42.50664710998535, 47.94315978884697, 50.185446068644524, 52.54678376019001, 49.27265904843807, 49.03612174093723, 48.67655463516712, 45.23319460451603, 42.500210255384445, 41.350756734609604, 38.006734773516655, 39.5371026545763, 39.48458947241306, 39.95358310639858, 44.62341472506523, 48.76394994556904, 52.78590872883797, 49.427975714206696, 51.11161597073078, 50.08124426007271, 53.94275665283203, 51.78346171975136, 52.054185792803764, 51.692365407943726, 52.85889521241188, 45.27425140142441, 46.01558402180672, 9.814283419400454, 0.21584243047982454, 3.3050826005637646, 13.097700532525778, 11.200328394770622, 0.5882034497335553, 0.6634534243494272, 0.5313963198568672, 0.42373408447019756, 29.365740045905113, 48.09223718941212, 33.34810495376587, 33.54950174689293, 42.47917838394642, 50.196655467152596, 2.1735971281304955, 0.17429038358386606, 0.15007171517936513, 0.06603686430025846, 0.2534645382547751, 0.09664449651609175, 0.1253585092490539, 0.0920649481122382, 0.11881065162015148, 0.11345700608217157, 0.07751083103357814, 0.10239156195893884, 0.13095105212414637, 0.1585399467148818, 0.18805382394930348], [0.05499128375959117, 0.04460968790226616, 0.07973443163791671, 0.027334284131939057, 0.06348495982820168, 0.024114921725413296, 0.08719329780433327, 0.03628049773396924, 0.05385547126934398, 0.02190655555750709, 0.005555768530030036, 0.04041335858346429, 0.01815889718272956, 0.09048319392604753, 0.04299314554373268, 0.07923763056169264, 0.031342258225777186, 0.02041140072833514, 0.059817291985382326, 2.005984322167933, 33.82018782198429, 41.589079946279526, 28.16776692867279, 30.378744788467884, 37.371123880147934, 34.03261922299862, 55.450500547885895, 5.941409161314368, 0.5098271335009485, 0.8099609159398824, 3.795138029381633, 4.461116893216968, 0.3063529799692333, 12.058581691235304, 41.49372786283493, 55.77365800738335, 48.37071664631367, 53.30333076417446, 45.1487897336483, 48.57100769877434, 51.11708007752895, 47.622966170310974, 47.0823197811842, 49.16053846478462, 49.365317076444626, 45.1906368881464, 41.87841162085533, 40.60374341905117, 38.88998977839947, 38.97455424070358, 41.78078345954418, 44.395001381635666, 44.762259274721146, 49.649154245853424, 50.6680353730917, 51.73775777220726, 51.228079721331596, 49.36851650476456, 48.67496632039547, 48.90114538371563, 45.3245797008276, 43.02435413002968, 39.305052906274796, 38.853998109698296, 38.377363085746765, 38.1695294380188, 37.49160781502724, 38.420323580503464, 37.90437966585159, 38.62256392836571, 38.16707096993923, 37.795716896653175, 37.161770313978195, 38.43048803508282, 38.433744460344315, 38.82432550191879, 45.35671837627888, 53.72919671237469, 51.62148781120777, 50.33460706472397, 48.471095860004425, 48.49413402378559, 62.05450817942619, 49.56823758780956, 49.10294495522976, 43.10367867350578, 45.75009226799011, 50.70001445710659, 54.296692460775375, 50.46321116387844, 49.523339197039604, 46.366719380021095, 50.7869727909565, 51.94764330983162, 51.077831983566284, 50.699288696050644, 49.27903890609741, 43.968231081962585, 42.718303352594376, 38.47788669168949, 35.63392549753189, 35.03806047141552, 36.037828624248505, 37.82726660370827, 37.65773870050907, 38.26759457588196, 36.73669092357159, 36.75759740173817, 38.41462388634682, 36.54551558196545, 37.838008627295494, 35.9315787255764, 37.04806141555309, 37.02794909477234, 37.203378081321716, 36.27932086586952, 37.18516945838928, 36.75106555223465, 36.02468132972717, 36.216586232185364, 45.579698011279106, 47.90643475949764, 50.41260547935963, 47.151324078440666, 46.8450453132391, 48.44582341611385, 43.924856409430504, 43.7007862329483, 40.282546654343605, 38.99452216923237, 35.63877783715725, 35.31698450446129, 34.87970396876335, 39.77688878774643, 42.44708530604839, 47.29609251022339, 47.15337976813316, 46.642728969454765, 47.07124337553978, 48.82826529443264, 48.47657136619091, 50.53300961852074, 48.03698055446148, 47.0345601439476, 47.83085681498051, 21.49895567446947, 0.8426515711471438, 0.4967222601408139, 1.5009731333702803, 1.3510910072363913, 0.607518347678706, 0.1503587927436456, 0.027662788379529957, 0.34472887229640037, 1.0841746861115098, 31.39082048088312, 33.76235872507095, 18.85997638106346, 18.23740068823099, 37.659551203250885, 17.513638325035572, 0.12466195912566036, 0.06754584348527715, 0.01582181292178575, 0.02078672892821487, 0.03494819793559145, 0.022507398316520266, 0.038837838437757455, 0.009631410721340217, 0.009526072135486174, 0.051764240124612115, 0.03816336720774416, 0.0700489294831641, 0.036974635877413675, 0.022616282512899488, 0.024666150056873448, 0.03041604308236856, 0.027364517372916453, 0.03741517102753278, 0.04821377595362719, 0.016199669989873655, 0.033076816907851025, 0.02048262278549373, 0.030032955728529487, 0.043118843095726334, 0.04764143537613563, 0.03695527324452996, 0.026137934655707795, 0.03478361184534151, 0.07794081655447371, 0.03521848811942618, 0.04227062025165651, 0.019508028890413698, 0.049588530309847556, 0.09484095891821198, 3.692411254160106, 40.92435881495476, 44.789784997701645, 29.797457680106163, 39.004002660512924, 47.06733338534832, 41.502486392855644, 59.128638580441475, 5.593343563377857, 0.3501906635938212, 0.44492652697954327, 1.6373776202090085, 2.6598914712667465, 0.5525364261120558, 14.975298531353474, 43.43767315149307, 54.02022309601307, 49.09036003053188, 53.06912653148174, 47.37521566450596, 50.48223294317722, 52.358838245272636, 49.93176408112049, 49.105787202715874, 51.01204231381416, 49.91786442697048, 48.776610866189, 45.696344152092934, 42.20712438225746, 40.920703411102295, 40.749499797821045, 42.76832386851311, 45.10956823825836, 47.836472913622856, 51.46625854074955, 50.5509028583765, 52.51396872103214, 52.23437212407589, 51.18739910423756, 52.30893552303314, 50.122677236795425, 47.21100367605686, 43.62664461135864, 42.484114319086075, 40.891152396798134, 40.74677534401417, 40.174370259046555, 40.010507851839066, 42.064582630991936, 40.22751420736313, 40.79135835170746, 39.84069496393204, 39.54581938683987, 39.5662584900856, 38.976142555475235, 39.78816658258438, 41.36921614408493, 48.25649097561836, 52.85253435373306, 54.314467906951904, 50.64275152981281, 50.324879586696625, 50.5659082531929, 61.04034259915352, 52.57471226155758, 50.3407247364521, 44.264759570360184, 48.78088943660259, 52.667716071009636, 54.93930637836456, 51.107390597462654, 50.801453813910484, 48.085762336850166, 51.80504076182842, 52.23278000950813, 50.69681502878666, 52.76720993220806, 51.67686603963375, 47.56284959614277, 43.68343636393547, 41.173104867339134, 36.71333357691765, 36.091937720775604, 37.354856953024864, 39.09725725650787, 38.20758439600468, 40.04232734441757, 38.08140076696873, 38.5604752600193, 40.389651507139206, 38.67541529238224, 38.042338863015175, 37.86072760820389, 37.87292115390301, 38.80686543881893, 40.768768563866615, 38.167013972997665, 38.37444484233856, 38.096911534667015, 38.32807593047619, 38.293136805295944, 46.0017641633749, 49.39421832561493, 53.44975970685482, 48.38357515633106, 48.22295397520065, 50.38982190191746, 47.16965429484844, 44.690519124269485, 41.58161714673042, 39.24011439085007, 36.22014284133911, 36.60583734512329, 36.489707976579666, 39.98951397836208, 44.31844308972359, 47.33794346451759, 50.05175404250622, 47.945565059781075, 50.018635019659996, 50.697814375162125, 48.31473425030708, 52.7704131603241, 47.5741083920002, 47.831533178687096, 47.56139427423477, 24.98469863086939, 2.0133497519418597, 3.9271607575938106, 2.516022641211748, 2.341424860060215, 0.4081992118153721, 0.28525606670882553, 0.15287409449229017, 0.4230602440657094, 0.809292389312759, 34.211802408099174, 38.886558562517166, 26.161757670342922, 20.138241089880466, 42.24601909518242, 23.450500555336475, 0.2838320634327829, 0.08710539041203447, 0.008129103443934582, 0.04291029959858861, 0.026866668013099115, 0.07398154033580795, 0.02192220930737676, 0.02839478347596014, 0.05768539856944699, 0.009000224326882744, 0.05973654260742478, 0.03011006301676389, 0.03115872881608084, 0.03169900119246449, 0.011340977580402978, 0.10650661497493275, 0.14921552909072489, 0.2175546542275697, 0.14524011116009206, 0.17985855432925746, 0.11292119030258618, 0.1772914655157365, 0.20399644738063216, 0.2628757426282391, 0.0728282576892525, 0.11536831094417721, 0.11180776098626666, 0.1779972034273669, 0.17217113636434078, 0.15368122461950406, 0.15396347822388634, 0.10120254490175284, 0.15121696778805926, 0.2103352197445929, 4.788449378684163, 49.617813527584076, 51.90050683915615, 37.450034245848656, 43.4453259408474, 50.79124756157398, 44.644640386104584, 67.90809407830238, 6.389654483646154, 0.5709406198002398, 2.504445849917829, 15.405238810926676, 12.105198539793491, 1.5846371627412736, 18.141433037817478, 44.27927479147911, 55.91245695948601, 48.97945538163185, 53.73875319957733, 48.12504082918167, 52.11289644241333, 55.59149198234081, 52.94563315808773, 50.75057074427605, 53.02390895783901, 53.25864136219025, 49.61424931883812, 45.963591411709785, 45.367316007614136, 44.9699941277504, 44.454221203923225, 44.19242665171623, 48.295074105262756, 49.85696129500866, 54.75924924015999, 53.05109649896622, 55.162031427025795, 55.00071108341217, 53.36519904434681, 53.66966150701046, 52.46744781732559, 49.04678776860237, 46.6251815110445, 44.57763858139515, 43.08668598532677, 43.04933778941631, 42.173074409365654, 40.97626022994518, 44.30137060582638, 41.957785561680794, 42.46210590004921, 41.1638979613781, 41.034032329916954, 42.16790668666363, 41.633944138884544, 42.179739251732826, 44.24326792359352, 47.88070634007454, 55.58407478034496, 57.1438454836607, 50.78017495572567, 52.19048447906971, 52.079321444034576, 63.48799645900726, 54.903079122304916, 53.752098083496094, 45.52394360303879, 51.547684371471405, 54.65493343770504, 57.32062339782715, 52.23659500479698, 50.68685956299305, 50.451165810227394, 54.9915611743927, 55.213089287281036, 53.72922331094742, 53.80521543323994, 52.365962862968445, 48.87967273592949, 46.38149678707123, 43.95879618823528, 38.92632722854614, 37.891604751348495, 38.1829921156168, 41.11749865114689, 40.54628290235996, 42.143147215247154, 39.97068598866463, 39.87893991172314, 42.164817452430725, 40.423633083701134, 40.21371714770794, 39.616161212325096, 41.91081628203392, 39.19200137257576, 42.39594005048275, 40.43028272688389, 41.22686818242073, 39.77175526320934, 40.808541029691696, 39.31638389825821, 49.86234940588474, 53.04467864334583, 55.64498171210289, 49.96542647480965, 50.751684084534645, 52.69903779029846, 48.52798640727997, 47.1335144340992, 43.13368186354637, 43.62046614289284, 38.45570348203182, 39.05319482088089, 39.53617550432682, 42.47697450220585, 46.24792255461216, 51.13422475755215, 51.880812495946884, 49.44073162972927, 50.09981766343117, 51.64711743593216, 51.16350598633289, 51.965665742754936, 49.25532437860966, 47.297281846404076, 48.027921840548515, 27.91154857724905, 2.4205477768555284, 3.703387677669525, 4.460800560191274, 5.892282072454691, 2.0822652289643884, 0.43664819619152695, 0.24884236830985174, 0.9630399174056947, 2.1169941779226065, 38.05509477853775, 44.99416463077068, 29.502946883440018, 23.613224923610687, 52.559273689985275, 30.00745341181755, 0.4923128936206922, 0.28987581725232303, 0.13513431593310088, 0.18844260543119162, 0.15551864868029952, 0.22938025795156136, 0.15402268676552922, 0.107157634338364, 0.13177485088817775, 0.12282638301257975, 0.196718709776178, 0.11736245432985015, 0.10155447133001871, 0.15375732444226742, 0.1428406438208185], [0.02762153795629274, 0.04303148489270825, 0.07240630220621824, 0.03297388473583851, 0.025994772513513453, 0.026922935794573277, 0.037245404746499844, 0.06088751717470586, 0.028157079141237773, 0.012180532139609568, 0.004869018930548918, 0.08883523274562322, 0.059164090707781725, 0.06491644395282492, 0.011768988060794072, 0.012166002743470017, 0.0587213476683246, 0.019889791510649957, 0.01562651861604536, 0.14954899088479578, 21.409339383244514, 45.296810790896416, 30.971051305532455, 26.45584098994732, 31.68612163513899, 32.936115860939026, 59.381606206297874, 10.42236004024744, 0.33155788842123, 0.30947198916692287, 0.5161541502457112, 2.129531605169177, 0.5866997397970408, 4.249401278793812, 24.916376397013664, 50.588266253471375, 55.3170745074749, 52.63731770217419, 52.754366621375084, 47.73639768362045, 49.03174437582493, 51.29700802266598, 50.203738287091255, 49.593407437205315, 44.82351578772068, 45.60811668634415, 43.1010340154171, 40.995908975601196, 37.48609811067581, 37.817504927515984, 40.543395057320595, 42.99039535224438, 44.01929274201393, 46.2557577341795, 46.53815858066082, 49.10807088017464, 46.84663362801075, 47.915869653224945, 47.486922070384026, 47.34510987997055, 45.16056910157204, 42.51767411828041, 40.228581950068474, 37.9450336843729, 38.61622206866741, 38.78258854150772, 39.51575919985771, 39.10318873822689, 39.685036316514015, 38.92793834209442, 38.37984435260296, 38.87196734547615, 38.35367135703564, 37.35518753528595, 38.30607131123543, 37.01241172850132, 43.44070538878441, 49.709859788417816, 50.63498094677925, 45.848571583628654, 51.32672242820263, 44.53175224363804, 49.46310102939606, 51.72835327684879, 51.66064091026783, 46.22920475900173, 45.292608216404915, 50.60504995286465, 52.48114988207817, 53.15693221986294, 50.58506302535534, 49.06474180519581, 50.45058824121952, 50.18127389252186, 48.05171996355057, 47.86469779908657, 44.301902577281, 41.45290665328503, 40.357493832707405, 38.161713257431984, 35.93613848090172, 35.22933080792427, 36.54136620461941, 35.02443440258503, 39.071601033210754, 37.21977420151234, 37.47125990688801, 35.254211872816086, 37.37194463610649, 36.3159205019474, 35.60069628059864, 36.73111282289028, 36.29912540316582, 37.86102019250393, 37.38509953022003, 37.259322479367256, 36.27709038555622, 36.73917979001999, 37.68475145101547, 36.31134554743767, 41.07453815639019, 48.388267904520035, 48.23818355798721, 49.18929912149906, 48.33064019680023, 46.455995589494705, 48.30041281878948, 46.550519317388535, 42.5598518550396, 40.7976546138525, 37.27927900850773, 34.56424109637737, 33.40161748230457, 32.981219440698624, 38.77066098153591, 42.01205424964428, 44.02042128145695, 48.06256838142872, 46.60978853702545, 47.48491957783699, 49.14931766688824, 49.073777720332146, 48.10253083705902, 47.4188107252121, 39.79494921863079, 6.083727674558759, 0.11891233327332884, 2.7915230579674244, 2.8426730632781982, 0.48662572691682726, 0.010780476113723125, 0.25494672590866685, 0.08034761631279252, 0.34309288195800036, 4.052563291043043, 33.25808398425579, 32.26762153208256, 25.257011018693447, 26.88400961458683, 44.947233349084854, 7.0064853597432375, 0.04744512618344743, 0.09744882874656469, 0.029191829671617597, 0.08542142022633925, 0.031630389639758505, 0.059336272679502144, 0.042335454272688366, 0.07103370749973692, 0.030491628967865836, 0.06598725914955139, 0.012839333849115064, 0.08027289688470773, 0.07371625222731382, 0.07288636785233393, 0.028368786042847205, 0.03743425535503775, 0.02451380198181141, 0.013681212258234154, 0.09396469031344168, 0.03011353255715221, 0.03598669260099996, 0.04573057951347437, 0.014319063138827914, 0.0335531458404148, 0.03552799338649493, 0.04325909416365903, 0.08726886328076944, 0.07538347213994712, 0.052961940309614874, 0.011042187998100417, 0.07364599310676567, 0.03366968529007863, 0.03772518837649841, 0.03546958636434283, 0.4119445342803374, 29.097356647253036, 50.44350162148476, 33.27888406813145, 33.52561242878437, 42.047183364629745, 34.98446814715862, 63.89982596039772, 10.65714469179511, 0.3793622029479593, 0.14802942867390811, 0.43708523211535066, 0.7196111453231424, 0.6384625809732825, 5.7561154291033745, 30.057194642722607, 53.78439635038376, 55.141314938664436, 52.95602560043335, 52.92071029543877, 49.34895135462284, 50.15536308288574, 53.03300566971302, 51.00294940173626, 50.31084693968296, 47.50080272555351, 46.587460935115814, 45.88469244539738, 41.18102744221687, 40.00210650265217, 39.547696486115456, 43.01567539572716, 44.58609312772751, 46.623718589544296, 48.10406595468521, 49.92213539779186, 49.621552526950836, 48.12861643731594, 50.46499706804752, 50.09500712156296, 48.4683296084404, 48.21590155363083, 44.0552844107151, 43.754443153738976, 40.08987419307232, 38.592078164219856, 39.32371370494366, 41.142345517873764, 41.101288720965385, 40.174602046608925, 40.38105256855488, 40.03210589289665, 40.82770340144634, 39.00109201669693, 38.5892853140831, 40.2117108553648, 38.80077436566353, 45.25699272751808, 52.13490106165409, 52.19284035265446, 47.44038976728916, 53.14361773431301, 46.9207676500082, 53.843125998973846, 54.69796612858772, 51.808874756097794, 46.836320981383324, 46.01019591093063, 51.32749758660793, 54.57726940512657, 53.58728192746639, 52.522674053907394, 53.684518709778786, 53.46155047416687, 53.17172862589359, 48.66235479712486, 49.06778544187546, 45.91537579894066, 44.12507526576519, 41.702211275696754, 39.118448719382286, 36.49570785462856, 37.256491631269455, 36.60669229924679, 38.69443327188492, 40.82546152174473, 39.697590842843056, 38.31994816660881, 37.16829836368561, 39.71540428698063, 38.02443042397499, 37.001164332032204, 37.7712120115757, 37.680286690592766, 38.73837411403656, 38.71510036289692, 39.10260356962681, 38.13560865819454, 37.772047966718674, 39.88519437611103, 37.72670120000839, 42.2882766276598, 49.49370838701725, 49.1205608099699, 50.06177790462971, 50.03238648176193, 47.17709809541702, 49.02637526392937, 47.86347046494484, 43.462535217404366, 41.7565293610096, 40.086165592074394, 36.55845008790493, 35.8525125682354, 35.39084114134312, 39.48967359960079, 44.38276223838329, 45.506601333618164, 48.81106361746788, 47.67149716615677, 49.83886666595936, 49.438497349619865, 49.33233484625816, 46.90929986536503, 47.545267939567566, 44.04307946562767, 7.737481584772468, 0.41438812972046435, 7.810288527980447, 6.330863563343883, 0.639382665976882, 0.15846384689211845, 0.27982820640318096, 0.03042307678697398, 0.9399890480563045, 5.360101629048586, 38.72509762644768, 40.2334950864315, 23.50520431995392, 27.142249457538128, 50.83535939455032, 10.111594665795565, 0.07399817928671837, 0.05294485607009847, 0.029010714097239543, 0.03590791362512391, 0.05188572969927918, 0.008983731950138463, 0.011894201361428713, 0.03353199463163037, 0.038755111236241646, 0.022795377590227872, 0.05218442929617595, 0.033757499913917854, 0.03042383377760416, 0.05113341459946241, 0.023887379247753415, 0.15189677505986765, 0.2843157952884212, 0.1306355354608968, 0.2434615750098601, 0.08234038672526367, 0.13669588370248675, 0.19507638149661943, 0.15918448712909594, 0.244317835313268, 0.1374190769274719, 0.11214053258299828, 0.20498638332355767, 0.17477882065577433, 0.11057063049520366, 0.08876270265318453, 0.15265343914506957, 0.13059887336567044, 0.10780298369354568, 0.16074231447419152, 0.5718634952791035, 34.45305146276951, 57.684260085225105, 41.31382271647453, 36.15022659301758, 44.462470561265945, 39.97448958456516, 71.3170051574707, 12.76188025251031, 0.47816978534683585, 1.0596891562454402, 2.268901951611042, 8.507388196885586, 1.5436706109903753, 7.469564136117697, 30.45908197760582, 54.10970449447632, 56.48196280002594, 54.110525250434875, 53.54454942047596, 51.21288813650608, 51.78243197500706, 55.68295307457447, 54.39162276685238, 55.02073600888252, 48.15059445798397, 49.791528806090355, 49.03212055563927, 45.0851621478796, 41.14281289279461, 41.45797938108444, 44.762369468808174, 45.76485067605972, 48.81455563008785, 50.615381598472595, 51.827999129891396, 53.11120547354221, 50.63509874045849, 53.1743048876524, 53.26540119946003, 52.66444444656372, 50.99934719502926, 46.16957075893879, 47.23412923514843, 42.01069392263889, 42.18070439994335, 42.657692804932594, 43.414805978536606, 42.38142862915993, 42.780266627669334, 42.852941527962685, 41.8037798255682, 43.38397443294525, 42.374531999230385, 39.66103680431843, 42.84041740000248, 39.628559947013855, 47.39791564643383, 53.03278148174286, 56.076136976480484, 48.849734142422676, 54.903884679079056, 45.757015496492386, 51.20345704257488, 55.55171951651573, 56.056723818182945, 49.98730570077896, 47.151631861925125, 53.1749926507473, 55.659667924046516, 57.322413101792336, 52.88192197680473, 54.361083805561066, 54.9851281195879, 54.03300940990448, 50.49987159669399, 52.073154374957085, 46.644742861390114, 46.27706699073315, 44.080952033400536, 41.29448935389519, 38.72479364275932, 38.80268186330795, 39.535183757543564, 38.22604760527611, 43.3529756963253, 42.13133744895458, 40.911450907588005, 38.86475533246994, 40.78585244715214, 39.378635957837105, 38.577817529439926, 39.66106340289116, 38.87416362762451, 41.645905897021294, 41.6706083714962, 41.234581768512726, 41.02019727230072, 40.12615844607353, 41.81452564895153, 41.231348142027855, 43.694793954491615, 53.53945389389992, 51.687152087688446, 51.96519836783409, 51.72932602465153, 49.959327802062035, 53.03371623158455, 50.08138485252857, 45.45237064361572, 43.89988794922829, 41.90886318683624, 38.167492747306824, 37.638568729162216, 36.640886664390564, 41.624896824359894, 45.83759017288685, 47.79181011021137, 52.2500766813755, 49.76048447191715, 52.19993457198143, 53.349836468696594, 50.14088585972786, 48.03212821483612, 46.24209366738796, 45.6841392070055, 9.567052535712719, 0.3391763905528933, 4.761015800759196, 5.907856486737728, 1.4191021327860653, 0.335328325163573, 0.8929971477482468, 0.5672269721981138, 2.3893284145742655, 8.623614460229874, 41.32785156369209, 46.8848367780447, 35.196337178349495, 35.7182277739048, 59.39160346984863, 14.936937689781189, 0.29760543373413384, 0.2530291647417471, 0.19791564554907382, 0.12001096416497603, 0.2876614563865587, 0.18249555345391855, 0.08667837348184548, 0.16059888701420277, 0.17321094463113695, 0.2395384933333844, 0.09104719647439197, 0.13056823750957847, 0.14497034047963098, 0.11075238246121444, 0.07950098166475073], [0.022979190871410538, 0.02903513261117041, 0.02251452850032365, 0.025650601528468542, 0.06381307815900072, 0.01413781676092185, 0.028465918330766726, 0.0939305589417927, 0.06800893621402793, 0.0237014527010615, 0.0859375690924935, 0.06416898249881342, 0.07014888935373165, 0.01459422366679064, 0.0199163622528431, 0.02889918971050065, 0.10072929959278554, 0.11508065450470895, 0.03889523613906931, 0.12313547267694958, 6.617802791297436, 43.17585960030556, 41.76780715584755, 22.81819738447666, 32.319636940956116, 29.07038949429989, 54.838797971606255, 11.886997148394585, 0.25891626602970064, 0.29429299116600305, 0.13105363177601248, 0.16547159117180854, 0.9605183370877057, 0.6814066891092807, 8.203442506492138, 33.6434593051672, 49.76842224597931, 51.90767325460911, 49.92357552051544, 55.09039007127285, 49.51129004359245, 50.35376563668251, 44.96297970414162, 46.278111934661865, 44.2102362960577, 43.12025338411331, 39.13302853703499, 38.400815427303314, 37.483347058296204, 36.987203881144524, 37.935097217559814, 39.39862668514252, 39.58595283329487, 39.676957949995995, 40.71237578988075, 42.09622733294964, 42.86189004778862, 42.68363781273365, 44.485846906900406, 44.690450727939606, 43.111783638596535, 44.309882149100304, 39.76638235151768, 39.10510003566742, 37.81943902373314, 39.47700507938862, 39.79018807411194, 39.27322581410408, 37.48389042913914, 39.6519210934639, 39.72402982413769, 37.59574502706528, 38.8053797185421, 38.43853980302811, 38.28129284083843, 36.76840782165527, 42.69771225750446, 48.73045854270458, 52.09233574569225, 48.474173694849014, 52.833352982997894, 45.15920117497444, 37.902605161070824, 54.13374960422516, 51.88678577542305, 50.904546082019806, 49.64806750416756, 51.0151619464159, 51.64388380944729, 50.61339430510998, 50.21212823688984, 49.573523104190826, 49.650594368577, 47.95546352863312, 45.83238825201988, 45.85300974547863, 42.932433262467384, 39.82563257217407, 39.07023310661316, 37.10297226905823, 36.709507182240486, 36.70117422938347, 36.73348769545555, 36.596752032637596, 36.71090930700302, 37.0920554548502, 37.889735251665115, 37.62184202671051, 36.749997809529305, 38.07371757924557, 37.40375652909279, 38.00486147403717, 35.40004804730415, 35.57437129318714, 36.077566891908646, 36.40284463763237, 35.50449304282665, 35.674412325024605, 36.1920053511858, 36.56867153942585, 37.4890011548996, 45.06465844810009, 46.26276455819607, 46.44754484295845, 49.30241525173187, 48.25570821762085, 46.99916124343872, 48.157646879553795, 46.13727629184723, 45.08558012545109, 41.17144055664539, 38.70278522372246, 34.31547224521637, 35.12769006192684, 33.01726430654526, 35.43143816292286, 38.23996625840664, 44.41989004611969, 42.87205450236797, 43.56179729104042, 46.54904119670391, 48.88089247047901, 47.05696754157543, 48.51235784590244, 22.871356531977654, 0.41057455935515463, 0.8387722761835903, 10.158466100692749, 3.790324875153601, 0.7056354952510446, 0.10026918287621811, 0.20819148165173829, 0.05654747466905974, 0.9029255993664265, 5.330021968111396, 33.14372532069683, 23.17170761525631, 19.123667031526566, 25.575354136526585, 34.51976828277111, 1.4637011708691716, 0.051382761375862174, 0.023862916204961948, 0.05330565858457703, 0.05872690635442268, 0.03192347117874306, 0.021417660209408496, 0.06598741500056349, 0.06881333523779176, 0.02926443026808556, 0.04318229672207963, 0.09888935222988948, 0.07015882671112195, 0.01901654901303118, 0.04925413340970408, 0.0715511105954647, 0.031383521636598743, 0.03461751919530798, 0.028012165530526545, 0.026902163081103936, 0.11673438959405757, 0.06671797775197774, 0.15831498691113666, 0.0694366279640235, 0.041147999436361715, 0.04062637352035381, 0.08318871347000822, 0.027084800058219116, 0.04067167792527471, 0.0585886665066937, 0.02172838074329775, 0.054797520133433864, 0.01788765333913034, 0.06117894001363311, 0.04686356071033515, 0.07578185701277107, 10.527912676334381, 51.08605474233627, 44.624026492238045, 23.607673421502113, 38.71150575578213, 35.80414496362209, 58.71787682175636, 14.194161146879196, 0.2149030941654928, 0.6226578634232283, 0.24949027807451785, 0.23538089299108833, 0.889363830210641, 0.9005527454428375, 9.04317369684577, 37.25166589021683, 51.53726153075695, 53.051111698150635, 51.04043059051037, 56.83212161064148, 50.97732737660408, 52.465262934565544, 46.95382587611675, 47.79004320502281, 45.1669679582119, 45.289101004600525, 41.23621188104153, 40.85593208670616, 39.34655427932739, 40.84677457809448, 42.02166773378849, 43.01715351641178, 42.15458080172539, 43.769638538360596, 43.9337707310915, 43.77254158258438, 44.45848077535629, 45.298509299755096, 45.91602936387062, 47.68229618668556, 45.272910073399544, 46.44232012331486, 41.65409445762634, 41.101759895682335, 40.16781561076641, 41.62029527127743, 40.75065493583679, 41.15380570292473, 39.90160949528217, 40.89665450155735, 43.10112901031971, 40.06991766393185, 40.12957826256752, 39.92644876241684, 40.177740678191185, 38.779153525829315, 44.576331451535225, 49.49425555765629, 52.527005821466446, 50.639939680695534, 53.56097973883152, 45.14228828251362, 38.17274406552315, 54.55269232392311, 54.54541191458702, 49.98953618109226, 49.72926914691925, 53.329002186656, 53.6605191975832, 53.06978389620781, 52.70290598273277, 51.964370012283325, 50.30547022819519, 51.93438582122326, 49.14032734930515, 49.19678092002869, 44.490862637758255, 41.93875998258591, 41.25932604074478, 38.61965328454971, 37.96092063188553, 38.57387714087963, 38.019828870892525, 39.17224243283272, 38.24445001780987, 38.41789171099663, 39.366370216012, 39.28865298628807, 37.95813538134098, 38.95558565855026, 38.560091480612755, 39.66918356716633, 36.64088286459446, 38.44113126397133, 38.63006092607975, 37.611050605773926, 36.52878887951374, 36.82985432446003, 38.35024394094944, 38.417416736483574, 38.50211799144745, 47.32168413698673, 48.20271246135235, 47.33921259641647, 51.3575691729784, 49.708727449178696, 49.35011029243469, 50.6468591094017, 48.89980025589466, 46.91165953874588, 42.40517735481262, 39.909912049770355, 37.10006922483444, 36.57786704599857, 34.38960626721382, 37.5074415653944, 39.52568046748638, 47.73994289338589, 45.94661392271519, 45.23755297064781, 47.103397250175476, 50.287295803427696, 46.76592595875263, 46.92233316600323, 25.227767787873745, 1.4185993722639978, 2.638639211654663, 13.275051265954971, 7.927061961963773, 1.0522034391760826, 0.1437811230425723, 0.20069604244781658, 0.08917968574678525, 1.2185062654316425, 6.324237193912268, 39.81892593204975, 32.268750071525574, 20.44318612664938, 27.57429577410221, 42.460893765091896, 2.900987109169364, 0.08794222128926776, 0.03702907240949571, 0.010306141703040339, 0.0615815662604291, 0.033869653270812705, 0.01669159701123135, 0.0654550279432442, 0.05923744829487987, 0.07680835857172497, 0.10519622708670795, 0.06558888911968097, 0.038752435793867335, 0.012356106653896859, 0.009834372340264963, 0.059969769936287776, 0.18716363265411928, 0.13364527083467692, 0.11717690998921171, 0.10278074420057237, 0.2597728231921792, 0.2011398467584513, 0.26730523619335145, 0.21064392349217087, 0.16757241828599945, 0.16317359026288614, 0.14102603337960318, 0.15997475566109642, 0.1963851143955253, 0.13822257053107023, 0.10506379083381034, 0.15503119124332443, 0.240569707530085, 0.17144417302915826, 0.22782182204537094, 0.37517657910939306, 13.006983250379562, 58.134414330124855, 52.34240032732487, 33.120421171188354, 44.90141920745373, 39.55495409667492, 63.645368814468384, 16.39772180467844, 0.37304186553228647, 1.4503889414481819, 0.5441854242235422, 1.1263403110206127, 4.114931719377637, 2.1708591375499964, 11.872739363461733, 40.21327257156372, 51.940754279494286, 53.551928624510765, 50.91841533780098, 60.08466348052025, 53.00346985459328, 55.847909823060036, 48.415812626481056, 49.897877499461174, 48.098092675209045, 47.449646070599556, 43.88064958155155, 41.95926748216152, 41.42824597656727, 42.67147086560726, 42.97814480960369, 44.326244071125984, 42.101250663399696, 44.8072412610054, 44.57995645701885, 46.53665006160736, 46.47611930966377, 47.62651517987251, 48.02170157432556, 49.13784608244896, 46.82537756860256, 48.54826591908932, 43.41659188270569, 43.661291152238846, 41.77607171237469, 44.19058755040169, 43.7649267911911, 43.48379507660866, 39.56481836736202, 43.55073228478432, 44.12326656281948, 42.059050127863884, 42.716468051075935, 41.00969463586807, 42.321657836437225, 41.217729672789574, 46.534259989857674, 52.450926303863525, 55.68658947944641, 54.44494530558586, 53.26020687818527, 47.18922324478626, 40.35192333161831, 54.85754236578941, 56.98390066623688, 52.38731391727924, 54.24120403826237, 54.293151050806046, 56.40748679637909, 53.87752175331116, 53.529023453593254, 52.67305478453636, 53.87664780020714, 52.620492205023766, 50.2595990896225, 50.325487554073334, 47.68696613609791, 43.75492952764034, 44.77366626262665, 41.14427961409092, 40.50087533891201, 40.78221224248409, 40.64006567001343, 41.17194212973118, 39.852337539196014, 40.755218490958214, 42.4278811365366, 41.607755944132805, 38.956231623888016, 41.80176593363285, 39.824648424983025, 41.21276713907719, 39.06525157392025, 39.62360501289368, 39.67522904276848, 39.1061107814312, 38.374258652329445, 40.61692491173744, 40.038728937506676, 40.851330533623695, 41.18522621691227, 48.296385034918785, 49.55135129392147, 49.419194385409355, 51.84502221643925, 52.710744962096214, 50.15972524881363, 52.46658906340599, 49.53614071011543, 49.23655338585377, 45.23104391992092, 41.14110678434372, 38.39731961488724, 39.94800880551338, 35.52275866270065, 38.016561046242714, 42.20014035701752, 49.836909770965576, 47.357839196920395, 48.02153438329697, 50.51309868693352, 51.937349662184715, 48.57145607471466, 48.81579056382179, 28.48057184368372, 1.4664607727900147, 1.9564218004234135, 17.577484399080276, 11.302796546369791, 2.503604432567954, 0.30853991105686873, 0.6201800401322544, 0.25709067180287093, 2.333833579905331, 9.585168063640594, 42.28255793452263, 36.122628673911095, 27.669157683849335, 34.69050072133541, 50.41208490729332, 3.5369326220825315, 0.16790574649348855, 0.137439857062418, 0.13204640272306278, 0.15804413269506767, 0.14238615258364007, 0.24748866126174107, 0.28250139264855534, 0.21766465535620227, 0.16283626930089667, 0.19425703561864793, 0.21178876049816608, 0.16550326603464782, 0.11627060666796751, 0.14853245636913925, 0.10591228827252053], [0.022897975795785896, 0.007920596126496093, 0.06993076473008841, 0.03184915993188042, 0.057478806920698844, 0.045637313814950176, 0.0022356563295033993, 0.052913192339474335, 0.07980132140801288, 0.04551520825771149, 0.01776419892848935, 0.011733945702872006, 0.024012522044358775, 0.02192527252191212, 0.038328328082570806, 0.003022359537681041, 0.041734581827768125, 0.031894712956273, 0.019182344803994056, 0.05047969381848816, 0.9594318922609091, 26.467303074896336, 43.386026322841644, 28.7628073990345, 33.60548034310341, 29.43069566041231, 45.46543814241886, 12.83332021906972, 0.1492321235127747, 0.23756929353112355, 0.3130845265695825, 0.2679396537132561, 0.5977955600246787, 0.06822347626439296, 0.7702653366141021, 11.528811268508434, 37.443920373916626, 50.55666334927082, 52.56078980863094, 51.70043617486954, 49.85224574804306, 50.01087963581085, 44.537296146154404, 42.060019075870514, 38.42311643064022, 38.94570618867874, 37.50408634543419, 37.03722819685936, 37.90924720466137, 37.19422057271004, 34.51912611722946, 37.774346843361855, 36.43960006535053, 37.52291813492775, 37.17427924275398, 39.369212463498116, 38.17872874438763, 37.75996461510658, 40.12354038655758, 41.288288086652756, 42.241007164120674, 42.98847645521164, 41.93196214735508, 39.46066215634346, 39.334877505898476, 39.4632688164711, 38.483008816838264, 38.87074761092663, 38.167055770754814, 37.53910906612873, 36.42435908317566, 38.537513092160225, 38.57090950012207, 38.42256546020508, 36.60566255450249, 36.22394643723965, 37.57902592420578, 46.29586458206177, 49.11932587623596, 47.79465615749359, 51.56146243214607, 45.56838981807232, 44.27097223699093, 51.025535389781, 50.012733936309814, 51.89401678740978, 49.824267849326134, 50.13735204935074, 51.79499410092831, 51.67420998215675, 49.430392384529114, 50.26759386062622, 48.74568812549114, 49.79632414877415, 44.24245856702328, 43.510169461369514, 38.740084022283554, 38.28742951154709, 36.7883263528347, 37.75395713746548, 35.84275849163532, 35.78945495188236, 35.73758773505688, 36.64016090333462, 36.370477974414825, 37.49239817261696, 37.78157785534859, 36.5976107865572, 37.35747501254082, 37.23229832947254, 36.596288457512856, 36.647232323884964, 36.06726944446564, 36.36412851512432, 36.73177778720856, 35.458093732595444, 35.40730565786362, 36.127963587641716, 36.12517073750496, 35.94379886984825, 36.32744148373604, 36.48566499352455, 44.47625622153282, 47.10355684161186, 47.25134611129761, 46.26044288277626, 46.05626843869686, 46.344311982393265, 47.86118298768997, 45.785681158304214, 43.92190396785736, 42.99503870308399, 38.12367729842663, 35.70652440190315, 35.85940159857273, 34.059840962290764, 36.03399842977524, 35.996042266488075, 39.398839473724365, 43.552214205265045, 48.35758835077286, 46.43276743590832, 49.87634785473347, 40.66565729677677, 5.703208493068814, 0.7384631806053221, 2.002820516936481, 15.192522425204515, 7.884402126073837, 0.3330231551080942, 0.05549815577978734, 0.16538614028831944, 0.28278029174543917, 0.6703996297437698, 13.951887097209692, 33.0471421033144, 25.49363572150469, 23.521872125566006, 31.128664948046207, 20.2495314180851, 0.12010669379378669, 0.034710951877059415, 0.06675973098026589, 0.07466225302778184, 0.0417924841895001, 0.1568182383198291, 0.03471691503364127, 0.04161016448051669, 0.03337000234751031, 0.06776990529033355, 0.06796957270125858, 0.060569733250304125, 0.06389483314706013, 0.015718411341367755, 0.010405207285657525, 0.03103625032963464, 0.020271899229555856, 0.04128094034967944, 0.012683447585004615, 0.03683503047795966, 0.05981263871944975, 0.0371566661488032, 0.0426842673914507, 0.08221106007113121, 0.02200890699896263, 0.027338766703906003, 0.02105810821376508, 0.018523649778217077, 0.019703690559254028, 0.03883582721755374, 0.06362147047184408, 0.050281057992833667, 0.014441310631809756, 0.12156086537288502, 0.06121523474575952, 0.07222075044410303, 1.944015584886074, 35.03182500600815, 50.017046704888344, 30.092960223555565, 38.368513360619545, 34.786589965224266, 51.78509943187237, 13.25827706605196, 0.16843908349983394, 1.0582642327062786, 0.5065177485812455, 0.15569229639368132, 0.47630984452553093, 0.2701797819463536, 1.1935626226477325, 15.769297275692225, 41.429469510912895, 52.407441437244415, 52.628068998456, 55.565964952111244, 50.89955694973469, 51.371533423662186, 46.105312407016754, 44.253922551870346, 39.933930560946465, 41.65855921804905, 39.72007043659687, 39.095440953969955, 39.08206947147846, 38.4351921826601, 37.72870369255543, 39.34044040739536, 37.7954813092947, 38.60095448791981, 39.70727652311325, 41.846162751317024, 40.46715594828129, 40.70747025310993, 42.704418897628784, 43.49555544555187, 43.23870822787285, 44.86260809004307, 44.411800280213356, 40.18697798252106, 41.08409084379673, 40.97937226295471, 39.383875876665115, 40.36242976784706, 40.59593103826046, 40.4136548191309, 39.2425462603569, 40.66995866596699, 38.70621643960476, 40.214572101831436, 38.81210535764694, 37.57473975419998, 39.19341489672661, 47.80902698636055, 49.82548378407955, 51.159778386354446, 52.896296605467796, 46.69108897447586, 43.85125815868378, 50.91948688030243, 54.62460346519947, 51.93470120429993, 51.7919846624136, 52.32730373740196, 53.66422779858112, 51.92311182618141, 53.021587282419205, 52.776698023080826, 51.92371219396591, 50.61663553118706, 46.273001208901405, 45.095885172486305, 40.4015638679266, 40.170118287205696, 38.96960690617561, 39.546605944633484, 37.21953481435776, 37.242401987314224, 38.867734372615814, 39.13944639265537, 38.19794051349163, 39.178208112716675, 37.89102338254452, 39.553320184350014, 38.651332184672356, 38.858542665839195, 39.0252473205328, 39.93034355342388, 36.537376418709755, 37.75117188692093, 38.75029407441616, 36.54951676726341, 37.10801459848881, 38.43872219324112, 38.299414068460464, 37.71431766450405, 38.07259663939476, 40.288033559918404, 46.54468283057213, 47.79015339910984, 48.06875444948673, 48.34580898284912, 46.7130745947361, 47.19326622784138, 49.157179445028305, 48.46913896501064, 46.86802268028259, 44.609568268060684, 39.69201274216175, 38.573614954948425, 37.86646530032158, 36.35921537876129, 35.85753209888935, 38.333646431565285, 40.35306707024574, 45.805542692542076, 48.58370661735535, 49.23447109758854, 48.58985088765621, 43.49185824394226, 7.792076105251908, 0.855235249036923, 5.696557424962521, 17.11881671100855, 8.470305036753416, 2.054252182133496, 0.024228713373304345, 0.14350934856338426, 0.3673383715795353, 2.01562131755054, 14.954711236059666, 39.22107741236687, 29.900878630578518, 23.7152798473835, 35.428690910339355, 27.173339389264584, 0.26688437908887863, 0.036205151191097684, 0.010317810119886417, 0.09637835493776947, 0.04968783709045965, 0.024541209495509975, 0.05015501534217037, 0.018286103149876, 0.041112884719041176, 0.03054415818041889, 0.03664090691017918, 0.03990106146375183, 0.037965417868690565, 0.030476539250230417, 0.07037195668090135, 0.0038742242395528592, 0.1510035409592092, 0.09693751868326217, 0.07214816840132698, 0.13302718056365848, 0.08830261562252417, 0.16459229460451752, 0.08994111442007124, 0.25225130491890013, 0.26461744448170066, 0.08899286491214298, 0.11611776135396212, 0.10149072084459476, 0.13125346245942637, 0.09479553205892444, 0.09938154456904158, 0.11357421346474439, 0.13255854399176314, 0.15768376062624156, 0.1373092390713282, 0.17750591650838032, 2.2006728127598763, 39.04990039765835, 57.89783902466297, 39.286323711276054, 44.149029180407524, 39.27960567176342, 54.26109977066517, 16.529569029808044, 0.20476074074395, 2.603845428675413, 1.2139890203252435, 0.4267792054452002, 1.4687710488215089, 1.3727619568817317, 1.5006000408902764, 16.50222759693861, 42.698099836707115, 51.90744146704674, 55.350641906261444, 58.90941694378853, 53.64017128944397, 55.42244665324688, 49.29955780506134, 46.000137850642204, 41.22344836592674, 43.44793640077114, 42.86691717803478, 41.535605415701866, 40.96475064754486, 42.51926243305206, 40.230649039149284, 40.53315460681915, 40.22615008056164, 41.07004299759865, 41.79116070270538, 44.510207399725914, 40.47026038169861, 41.01612389087677, 43.76142717897892, 46.77330896258354, 45.88338531553745, 46.65127091109753, 46.84194467961788, 41.675251722335815, 42.87678524851799, 44.01491917669773, 40.60937851667404, 42.018696293234825, 43.62981364130974, 41.477065756917, 39.196800515055656, 43.58391210436821, 41.7049091309309, 41.987070590257645, 41.81374669075012, 39.4171316921711, 39.496501833200455, 50.0152949988842, 52.81610570847988, 51.37549661099911, 55.032503977417946, 47.826696038246155, 44.52992454171181, 50.83982415497303, 54.41040895879269, 54.22980844974518, 54.80707727372646, 53.83841425180435, 56.635436564683914, 52.9233093559742, 51.499381363391876, 52.94806122779846, 52.991120517253876, 53.95132899284363, 48.06968539953232, 46.306230425834656, 42.644488513469696, 42.45520547032356, 41.77129156887531, 41.404516249895096, 37.99895279109478, 39.03377026319504, 40.549166947603226, 41.20647467672825, 40.54292768239975, 40.71285076439381, 41.17220811545849, 39.90322060883045, 40.47280244529247, 40.70961333811283, 41.33580073714256, 41.172470301389694, 37.323223650455475, 39.08955127000809, 40.895225778222084, 37.864952981472015, 39.69192914664745, 40.84713935852051, 40.587119311094284, 40.257927775382996, 39.41499620676041, 40.57621389627457, 49.148869290947914, 49.73567560315132, 52.11384259164333, 52.31997773051262, 49.323701709508896, 48.484258353710175, 52.664079666137695, 49.042425602674484, 48.58403339982033, 47.05014690756798, 42.392007261514664, 40.31333640217781, 40.18948584794998, 37.78852388262749, 39.0962503105402, 40.02533845603466, 43.11429150402546, 46.901346892118454, 53.342084884643555, 50.6568867713213, 51.774422004818916, 43.404257744550705, 9.318688362836838, 1.1383929080329835, 7.302899854257703, 26.66873786598444, 19.51556660234928, 2.4251780658960342, 0.15291506104404107, 0.41198787570465356, 0.8807168004568666, 3.9160045562312007, 21.431121714413166, 44.14242513477802, 36.77719295024872, 30.03863073885441, 44.94691036641598, 32.774293944239616, 0.5222034850157797, 0.13064577709883451, 0.1927777868695557, 0.2205172335379757, 0.11403807060560212, 0.2519583347020671, 0.11441450275015086, 0.12608128687134013, 0.17709706735331565, 0.16009202983696014, 0.18156884849304333, 0.10197744355536997, 0.10500735050300136, 0.12721329956548288, 0.1551078847842291, 0.13032585207838565], [0.0057187692073057406, 0.02818674092850415, 0.014888867426634533, 0.05208869595662691, 0.013836034468113212, 0.054791185903013684, 0.06668935311608948, 0.03631005005445331, 0.016842379154695664, 0.018119800843123812, 0.0535119793494232, 0.03231963703001384, 0.047257322003133595, 0.08106050110654905, 0.002671925753929827, 0.03340832314279396, 0.021563883710769005, 0.04365872584457975, 0.036058250479982235, 0.011355985661793966, 0.062362394673982635, 6.848440915346146, 43.0912571400404, 31.4258735999465, 28.1528964266181, 30.837226286530495, 40.62779612839222, 23.267105296254158, 0.08074753743130714, 0.8295064140111208, 0.3356347430963069, 0.058787053712876514, 0.028830693190684542, 0.17977345967665315, 0.3837854921584949, 1.2932331743650138, 14.993552751839161, 47.28674501180649, 54.288469702005386, 54.45151895284653, 48.79111848771572, 47.770375460386276, 43.255298137664795, 42.47130900621414, 40.96243277192116, 39.81473855674267, 39.04952421784401, 37.15624921023846, 39.028313755989075, 41.554479002952576, 42.10006892681122, 47.48589612543583, 46.79773025214672, 46.090804785490036, 41.192366033792496, 37.48061500489712, 38.685503751039505, 38.136991783976555, 39.82479281723499, 42.29621820151806, 44.1434358805418, 44.27338510751724, 42.6540981978178, 40.78643001616001, 36.45710572600365, 38.75502482056618, 38.33386681973934, 38.6529964953661, 38.513057604432106, 38.7605307251215, 37.402407601475716, 39.20734114944935, 39.231538251042366, 37.33947537839413, 36.126470267772675, 36.61944441497326, 38.63236740231514, 42.4397175014019, 48.889677599072456, 49.061918556690216, 51.45642086863518, 48.65296170115471, 46.38263672590256, 51.97363771498203, 51.6968909651041, 52.118801325559616, 50.026796981692314, 51.07422977685928, 51.700280383229256, 48.713747039437294, 49.30751457810402, 49.11622904241085, 51.37426547706127, 48.02890978753567, 43.375899866223335, 41.93724386394024, 39.38098423182964, 38.216354325413704, 37.49209798872471, 35.706372410058975, 36.05406515300274, 35.3641589730978, 34.83620770275593, 35.21024823188782, 36.00974053144455, 36.06482617557049, 37.53225043416023, 36.30773574113846, 36.24527469277382, 38.2636009901762, 37.84902423620224, 36.41724206507206, 36.802993565797806, 36.35220855474472, 36.170316115021706, 35.6655739992857, 35.333908796310425, 34.715484380722046, 35.93342162668705, 37.172892317175865, 35.72125241160393, 33.94386738538742, 39.38516780734062, 42.4308829754591, 45.19643157720566, 47.347009778022766, 44.81704093515873, 45.35411171615124, 47.03855372965336, 46.12294726073742, 46.277750954031944, 46.596398055553436, 44.64932933449745, 40.49620918929577, 37.9047292470932, 36.19969233870506, 36.95833683013916, 37.167086228728294, 38.32287020981312, 42.60529741644859, 48.140676990151405, 45.07726617157459, 52.48616561293602, 24.88705337047577, 0.4411864886060357, 0.31529672036413103, 4.315108302980661, 13.705410473048687, 5.535175809636712, 1.9905936042778194, 0.16833543515531346, 0.41687126678880304, 0.3501724067609757, 0.6024066125974059, 24.998881369829178, 31.821951046586037, 34.67664286494255, 32.61724837124348, 28.312751948833466, 4.531076839193702, 0.10896456355112605, 0.1069483338505961, 0.009152367383649107, 0.03816454722255003, 0.10023000490036793, 0.07633764398633502, 0.06101904058596119, 0.17469230107963085, 0.0344916064204881, 0.027414473188400734, 0.05700952468032483, 0.07888960783020593, 0.03660934708022978, 0.11570604008738883, 0.040320745974895544, 0.04557033498713281, 0.01502868897659937, 0.06845173862529919, 0.038928714420762844, 0.03942216470022686, 0.03841697020106949, 0.05094605570775457, 0.028850844355474692, 0.025928936593118124, 0.03134854792733677, 0.011969224142376333, 0.007815252902219072, 0.021055942997918464, 0.10148345521884039, 0.03079942358453991, 0.02619899300043471, 0.04774894659931306, 0.07331095053814352, 0.00795093512351741, 0.08373336080694571, 0.05274993098282721, 0.12478463613661006, 12.414651084691286, 49.50020983815193, 35.12857921421528, 33.00264649093151, 39.94262829422951, 47.98233188688755, 24.398745372891426, 0.06047959941497538, 1.6429545334540308, 0.5190088064409792, 0.10138273835764267, 0.20514406001893803, 0.1467016077367589, 0.4746446432545781, 1.8137824418954551, 18.49814459681511, 49.252398535609245, 54.168700128793716, 55.885227620601654, 51.28773272037506, 49.11622904241085, 44.85051713883877, 45.225879997015, 43.25969450175762, 41.23432718217373, 40.40303438901901, 39.764288663864136, 39.80719596147537, 41.84491641819477, 43.26991595327854, 45.81501558423042, 46.90933406352997, 48.55133235454559, 41.61024481058121, 38.582772463560104, 40.695098116993904, 41.09021991491318, 43.572451919317245, 44.44625683128834, 46.556933373212814, 47.103302255272865, 46.11539326608181, 44.47113409638405, 38.893873170018196, 41.36842578649521, 39.54332672059536, 40.85415378212929, 40.58972217142582, 40.380501598119736, 38.669005036354065, 41.53746351599693, 40.28739519417286, 39.650796353816986, 38.7012805044651, 38.48850332200527, 39.98043246567249, 43.45824144780636, 48.80691044032574, 52.20370776951313, 54.464867636561394, 49.90041196346283, 48.39759260416031, 51.67204789817333, 54.03485231101513, 54.11647193133831, 52.14859552681446, 53.03817719221115, 51.603252589702606, 48.563769087195396, 52.02397741377354, 52.47884340584278, 52.64783933758736, 49.410979226231575, 45.8550426363945, 42.49096155166626, 40.70807822048664, 39.99513387680054, 38.61154071986675, 37.09788054227829, 38.598062843084335, 37.76233948767185, 38.38280439376831, 35.44657275080681, 38.07707279920578, 37.93583057820797, 38.63011412322521, 38.417838513851166, 38.196716979146004, 40.44173911213875, 38.42581048607826, 39.098013415932655, 37.86295048892498, 36.58434569835663, 37.235387563705444, 36.55247300863266, 36.81274764239788, 37.392752319574356, 37.53469370305538, 39.008942395448685, 36.69430039823055, 36.0791590064764, 40.61386987566948, 44.630345553159714, 47.221031337976456, 48.66372652351856, 47.869512140750885, 48.14366742968559, 46.72622188925743, 48.615647703409195, 48.63739773631096, 48.8647585362196, 45.52994728088379, 41.417823135852814, 39.87512491643429, 37.42668069899082, 37.85828813910484, 38.777052238583565, 38.75259295105934, 44.14640732109547, 49.23384793102741, 46.28704525530338, 52.95995458960533, 27.25109461694956, 0.6898737628944218, 2.3226201441138983, 8.259832430630922, 10.96124142408371, 9.152618274092674, 2.7300406945869327, 0.037053002961329184, 0.24820320104481652, 0.41337791830301285, 1.9779339898377657, 26.289905793964863, 36.30627281963825, 35.58691821992397, 35.93652606010437, 36.0816440731287, 7.604533368721604, 0.07714262188528664, 0.08565571624785662, 0.04764349483593833, 0.1170224096858874, 0.04423787562700454, 0.023251722341228742, 0.004289857552066678, 0.10139909529243596, 0.01780788916221354, 0.043913197150686756, 0.03545579354977235, 0.036756574336322956, 0.05781495900009759, 0.11804769412265159, 0.005249349669611547, 0.05949672500719316, 0.21159834024729207, 0.14665529772173613, 0.10716823962866329, 0.1586083578877151, 0.12199854696518742, 0.2221684972755611, 0.14582036674255505, 0.12078448984539136, 0.2324487714213319, 0.12505589111242443, 0.0886931485729292, 0.06599013868253678, 0.17794399143895134, 0.22236717020859942, 0.13106746540870517, 0.09489197414950468, 0.12221598881296813, 0.18265407619765028, 0.16293504915665835, 0.13956432900158688, 0.19900517771020532, 13.41687485575676, 57.64927916228771, 42.72738866508007, 38.63281577825546, 43.18597465753555, 50.62706597149372, 31.052927412092686, 0.30622835853137076, 3.189306613057852, 0.7719016831833869, 0.26382346521131694, 0.48677777813281864, 1.261698785237968, 1.1458445456810296, 2.1544005582109094, 19.679972380399704, 50.807233303785324, 56.27155289053917, 58.61002340912819, 52.7798480540514, 53.0882129073143, 48.73607464134693, 48.23562249541283, 44.54278685152531, 43.87282960116863, 42.18850538134575, 41.010606586933136, 42.835413068532944, 44.21894922852516, 46.62176929414272, 51.970749869942665, 49.69908356666565, 52.526147067546844, 44.43968318402767, 41.078470945358276, 42.91885659098625, 42.04847529530525, 43.92625093460083, 45.308308973908424, 48.887979090213776, 49.02868553996086, 49.11809094250202, 45.33737361431122, 40.630767568945885, 43.34716960787773, 41.063275560736656, 42.64879368245602, 42.4920254945755, 42.72349387407303, 41.34412229061127, 44.46366749703884, 43.3640369027853, 40.74439287185669, 39.71514590084553, 40.92356085777283, 42.74170249700546, 45.235368087887764, 50.92042163014412, 52.75022864341736, 56.08303360641003, 52.238415107131004, 48.705003708601, 54.04684826731682, 57.13224470615387, 55.12827403843403, 53.718416690826416, 54.5949612557888, 53.708229437470436, 48.211345598101616, 51.72644957900047, 53.920353055000305, 54.88866649568081, 52.03262194991112, 46.75022140145302, 43.9777609705925, 42.646604999899864, 41.44635580480099, 42.25107282400131, 39.76070165634155, 42.0359967648983, 39.424248710274696, 38.23025777935982, 37.384081184864044, 39.39326137304306, 37.51797080039978, 41.52744725346565, 40.840216130018234, 40.28970927000046, 42.635380402207375, 41.46490640938282, 40.242132022976875, 39.462896436452866, 39.21225048601627, 38.343955278396606, 38.2095754891634, 39.03896078467369, 39.65877592563629, 40.73732525110245, 42.131443843245506, 38.966958448290825, 37.95522853732109, 42.14122451841831, 45.94451263546944, 48.716387897729874, 52.16684974730015, 50.65608501434326, 49.01981681585312, 50.120165571570396, 50.84775052964687, 49.43279765546322, 52.049230858683586, 48.0554323643446, 45.88903181254864, 42.00993396341801, 39.4984283298254, 40.393132120370865, 40.35313546657562, 40.9773925691843, 47.62619599699974, 52.32275538146496, 49.22141119837761, 54.22458752989769, 28.51805493235588, 1.2634408730082214, 1.3793734833598137, 11.753047686070204, 21.027549169957638, 12.483990713953972, 6.9458334892988205, 0.5453302315436304, 0.5403403274249285, 1.6237457329407334, 4.485525358468294, 34.50994201004505, 43.25140714645386, 45.80826334655285, 39.871503710746765, 46.28561273217201, 9.235054850578308, 0.2504874870646745, 0.1992995134787634, 0.10498763906070963, 0.1676247693831101, 0.18685865448787808, 0.12566755438456312, 0.14788563014008105, 0.22178543033078313, 0.11529848226928152, 0.11400836985558271, 0.12295827749767341, 0.15787636279128492, 0.1319502352271229, 0.2890607906738296, 0.12540995492599905, 0.16351463680621237], [0.020350240338302683, 0.06440302619012073, 0.01750414667185396, 0.024681525501364376, 0.03245418098231312, 0.05604892583505716, 0.03868925305141602, 0.03674168685392942, 0.08490374995744787, 0.02781273375148885, 0.015770777281431947, 0.01357643863229896, 0.05711500984034501, 0.07228211121400818, 0.05705062852939591, 0.04586098970321473, 0.05485829089593608, 0.04185277997748926, 0.07309750144486316, 0.024315078953804914, 0.07201041837106459, 1.1769931367598474, 28.500830456614494, 39.655709490180016, 25.241948626935482, 28.011289425194263, 36.72361962497234, 27.420058250427246, 1.4220806979574263, 0.114565544645302, 0.28213097190018743, 0.014764737661607796, 0.07949119273689575, 0.08030170705751516, 0.14941001631086692, 0.0642316420271527, 3.156632878817618, 28.660323098301888, 56.57125040888786, 52.35462427139282, 49.14549507200718, 47.03429415822029, 42.705524638295174, 40.96784368157387, 40.33676594495773, 42.030924037098885, 44.72934544086456, 46.096918657422066, 48.96014481782913, 49.595105946063995, 52.03633055090904, 51.50489866733551, 51.84141241014004, 52.814437597990036, 49.22701209783554, 40.54380923509598, 37.47711539268494, 40.95496617257595, 42.29581922292709, 43.69417458772659, 45.39811335504055, 45.5163212120533, 45.801134929060936, 41.54401056468487, 37.39165797829628, 38.96223530173302, 39.24697682261467, 40.61966076493263, 39.10845905542374, 38.01404558122158, 38.32206845283508, 37.966886311769485, 37.62660697102547, 37.724440321326256, 36.71874448657036, 37.85837173461914, 37.30894781649113, 40.75670801103115, 45.39321921765804, 48.69979418814182, 49.29185561835766, 46.436631828546524, 50.64264513552189, 49.86979320645332, 49.935582876205444, 50.95210053026676, 51.08304910361767, 52.28311210870743, 52.38688834011555, 48.6961729824543, 49.24699902534485, 50.14433227479458, 51.18668474256992, 46.80947542190552, 43.98414462804794, 39.908452928066254, 39.083015620708466, 37.07488797605038, 38.36085297167301, 38.52424420416355, 37.78734594583511, 37.810251116752625, 35.28512701392174, 36.5142622590065, 37.16261386871338, 37.2367212921381, 36.7748598754406, 36.05476051568985, 36.51590757071972, 37.352953255176544, 35.81657789647579, 37.11227796971798, 37.53253161907196, 36.947955787181854, 35.4987021535635, 36.731116622686386, 37.72705838084221, 38.06129224598408, 37.60180950164795, 35.36555349826813, 36.84315361082554, 34.61768142879009, 37.61808782815933, 41.8018951267004, 44.12599101662636, 46.27332419157028, 46.982768923044205, 46.28146335482597, 47.210509702563286, 45.608793050050735, 44.47514668107033, 44.731173142790794, 45.57741433382034, 44.50103089213371, 40.81356815993786, 39.10108745098114, 37.549136728048325, 36.48118123412132, 41.12969219684601, 43.77396650612354, 48.18665832281113, 47.14776746928692, 49.29496385157108, 11.028874944895506, 0.2620752027723938, 1.993237193673849, 5.294458726420999, 11.996084544807673, 5.692050866782665, 1.5459979861043394, 0.12571327068144456, 0.23351158626610413, 0.2950292610330507, 3.3319820696488023, 28.99740871042013, 26.095920503139496, 36.86324693262577, 35.60457207262516, 18.73117469251156, 0.5535935412626714, 0.08198333947802894, 0.09011747839394957, 0.07279756988282315, 0.0361506589979399, 0.04351924289949238, 0.06907094953930937, 0.06886466217110865, 0.015522632784268353, 0.05093904612294864, 0.03442234177782666, 0.058689283177955076, 0.02901056010159664, 0.03133402409730479, 0.022469112773251254, 0.03537249860528391, 0.02222997609351296, 0.015387915354949655, 0.026572625392873306, 0.00878091133927228, 0.025330650532850996, 0.02089615118165966, 0.027025585950468667, 0.04617039849108551, 0.03256569238146767, 0.03596745242248289, 0.03871506865834817, 0.04685338957642671, 0.0322256069193827, 0.06455104754422791, 0.09712212791782804, 0.027086798290838487, 0.059798790243803523, 0.04717551877547521, 0.03773873999307398, 0.04863579451921396, 0.05495078847161494, 0.12082990186172538, 2.293208772316575, 37.76009760797024, 41.93517677485943, 27.97991070896387, 35.2886988222599, 44.437619894742966, 30.761541947722435, 1.598527911119163, 0.4963355715153739, 0.22408265940612182, 0.08586532843764871, 0.10057683277409524, 0.1666218161699362, 0.1187921201926656, 0.4710569232702255, 4.480784637853503, 32.28335648775101, 56.31503015756607, 54.54013779759407, 52.38256797194481, 49.30236965417862, 44.99224953353405, 42.59161435067654, 42.57261537015438, 43.29065904021263, 45.34541018307209, 48.776595667004585, 49.82266813516617, 51.05532579123974, 53.17571081221104, 53.09341482818127, 53.77896264195442, 52.87060618400574, 49.53853078186512, 41.90508618950844, 39.91868957877159, 42.527093812823296, 42.31539197266102, 45.41880324482918, 46.631648764014244, 48.13382215797901, 46.78740240633488, 42.419920563697815, 39.42563943564892, 40.19603289663792, 40.83194017410278, 41.29738099873066, 40.802168771624565, 40.503573194146156, 39.82081823050976, 39.971328154206276, 38.896058052778244, 39.96345117688179, 39.049341827631, 39.09140557050705, 40.005894899368286, 42.56258390843868, 45.71967490017414, 50.019672363996506, 52.40446239709854, 47.16383680701256, 51.502185612916946, 51.68840982019901, 51.34721852838993, 53.10498520731926, 52.66765907406807, 54.144096449017525, 53.558479472994804, 49.2825461179018, 49.93388056755066, 53.65942865610123, 54.49427805840969, 49.441043213009834, 46.179788410663605, 42.101885229349136, 41.027447283267975, 39.917200058698654, 39.85048323869705, 41.33970692753792, 40.47714941203594, 38.730523735284805, 36.98503419756889, 36.965313255786896, 37.51784160733223, 38.30834358930588, 36.961179077625275, 38.79287078976631, 39.16883021593094, 38.71811360120773, 37.45781622827053, 38.30607891082764, 39.82820883393288, 37.2477824985981, 37.28252023458481, 38.26032176613808, 38.046043664216995, 40.88450275361538, 39.42836008965969, 37.262529507279396, 38.5161392390728, 37.375926822423935, 38.19679297506809, 43.84984843432903, 45.96562050282955, 48.2879950851202, 48.62076222896576, 48.46473500132561, 48.434899002313614, 47.63680882751942, 47.3406945168972, 47.076889872550964, 46.60436622798443, 46.72267287969589, 43.02104830741882, 40.98217651247978, 40.49314275383949, 38.108360320329666, 43.14709134399891, 46.09547093510628, 49.44049224257469, 47.58633233606815, 50.7012227922678, 13.80795557051897, 0.11478645974420942, 5.868813581764698, 9.085402730852365, 9.534020908176899, 7.566036209464073, 2.9751467797905207, 0.036292642980697565, 0.14219157630577683, 0.6977893318980932, 4.793552029877901, 36.757851988077164, 34.675567522645, 40.706881284713745, 39.1774595528841, 26.61079477518797, 0.9050243929959834, 0.11827604554127902, 0.08189785890863277, 0.03398177323106211, 0.04907232207187917, 0.02658093930222094, 0.1106485708442051, 0.03264559942181222, 0.01632274033909198, 0.021707975392928347, 0.05771498799731489, 0.031715747754788026, 0.010660744501365116, 0.021233472143649124, 0.019939741760026664, 0.05854954419191927, 0.027451172391010914, 0.07064589823130518, 0.11870501431985758, 0.2217394023318775, 0.11002853614627384, 0.11247189409914427, 0.15831589233130217, 0.11797136423410848, 0.1184376778837759, 0.20792834577150643, 0.16394687845604494, 0.21121794503415003, 0.12401396772474982, 0.14091396908042952, 0.19817317079287022, 0.20176393358269706, 0.11252180353039876, 0.12834197259508073, 0.22587190323974937, 0.11753778671845794, 0.19598435465013608, 0.18538399221142754, 2.565775983966887, 45.70632241666317, 51.24370448291302, 34.553343281149864, 39.286376908421516, 47.716710940003395, 34.67449598014355, 3.031204459257424, 1.5768327377736568, 1.2501884903758764, 0.29676401638425887, 0.41780747123993933, 0.7355460058897734, 1.307153133675456, 0.743370617274195, 5.491481479257345, 32.17701159417629, 57.713491916656494, 56.2162696570158, 54.661419689655304, 52.01808013021946, 47.344479113817215, 45.787611454725266, 44.16610546410084, 47.4053518474102, 48.818906396627426, 51.01101256906986, 52.438645362854004, 55.12454263865948, 56.455444023013115, 55.32149367034435, 55.42528510093689, 55.450705736875534, 51.672823056578636, 43.79924654960632, 41.958317533135414, 45.36015339195728, 47.17179358005524, 48.41407231986523, 49.96732257306576, 50.585161820054054, 49.75998669862747, 45.61481952667236, 40.899899527430534, 42.646004632115364, 43.126610442996025, 44.064460918307304, 43.82235310971737, 43.32322709262371, 41.73916049301624, 43.058001324534416, 40.35477317869663, 41.32696621119976, 39.8675899207592, 42.870272397994995, 41.21960677206516, 43.733080700039864, 48.380721509456635, 51.76792435348034, 53.6844427138567, 49.72206853330135, 53.4495735168457, 52.740964740514755, 52.21009522676468, 54.48487736284733, 56.65167689323425, 54.735690504312515, 55.851964205503464, 48.875766545534134, 53.49045552313328, 53.099380508065224, 55.3023236989975, 48.94320532679558, 49.47924256324768, 42.8972053527832, 43.65368776023388, 40.47345981001854, 42.55543269217014, 43.32992233335972, 41.70631505548954, 43.16791422665119, 38.496300503611565, 39.331704676151276, 40.154083147645, 41.043303832411766, 39.51628737151623, 40.14669254422188, 40.7065013051033, 40.88091194629669, 39.41406525671482, 41.327501982450485, 42.053392231464386, 40.05201302468777, 38.21960315108299, 39.160330072045326, 40.874980464577675, 43.71571563184261, 43.19829739630222, 39.57991115748882, 39.82034705579281, 38.08451659977436, 41.365180760622025, 45.59164457023144, 49.58951644599438, 49.85620893537998, 51.747314259409904, 50.80716870725155, 50.360020101070404, 48.94832745194435, 49.74043294787407, 48.34463484585285, 48.98724116384983, 48.98615442216396, 44.36415083706379, 43.343578800559044, 41.54661722481251, 40.90358532965183, 44.35925289988518, 49.253264889121056, 51.60455971956253, 50.393739491701126, 50.20425885915756, 14.789019227027893, 0.9596741292625666, 5.565247870981693, 13.083818927407265, 22.14814703911543, 15.985457226634026, 5.057257879525423, 0.3614576527616009, 1.134741185232997, 1.8223095405846834, 8.662649765610695, 41.368585377931595, 38.667538315057755, 44.578193351626396, 45.842260122299194, 35.903190448880196, 1.3387829926796257, 0.31828514125663787, 0.1672410493483767, 0.1362632858217694, 0.17337452882202342, 0.11406374149373733, 0.19660467136418447, 0.14453590207267553, 0.09134720225119963, 0.14133285207208246, 0.1287650561425835, 0.11665592974168248, 0.14410478848731145, 0.11215024729608558, 0.1457815375761129, 0.154807003273163, 0.12454691139282659], [0.11112997235613875, 0.06673048294032924, 0.03539555342285894, 0.02944301511888625, 0.0051237513798696455, 0.033987944188993424, 0.03685048199258745, 0.04112058821192477, 0.032486905984114856, 0.047760119632584974, 0.02168203362089116, 0.04037634025735315, 0.06891316894325428, 0.06185719990753569, 0.039168008806882426, 0.03454944941040594, 0.010842418541869847, 0.021937840792816132, 0.013203045582486084, 0.03974308419856243, 0.013141441759216832, 0.053235362356645055, 9.595816042274237, 46.562215089797974, 30.69683901965618, 29.827859848737717, 34.314731284976006, 29.27089713513851, 4.1454654559493065, 0.437536962563172, 1.2949024722911417, 0.11018552264431491, 0.049247676724917255, 0.05933472159085795, 0.14275170484324917, 0.12037177410093136, 0.02241850015707314, 8.467747773975134, 49.09062601625919, 53.935411646962166, 51.04632407426834, 48.383423164486885, 44.467322900891304, 45.6968305259943, 47.152000442147255, 49.709027633070946, 50.34730218350887, 51.67435437440872, 51.03269420564175, 50.790297612547874, 50.14597378671169, 51.54561348259449, 52.32494406402111, 50.299686938524246, 48.7470218539238, 39.58311438560486, 37.022260800004005, 39.13805566728115, 41.62711210548878, 44.704889953136444, 47.673089280724525, 45.79264238476753, 45.81457860767841, 40.79852856695652, 38.46819341182709, 38.34359049797058, 40.12899689376354, 40.24038031697273, 38.0511049926281, 39.70475345849991, 39.665132984519005, 38.1618994474411, 37.79390059411526, 37.29783721268177, 38.005705028772354, 35.99724680185318, 37.473110407590866, 41.0592819750309, 45.41889823973179, 47.24632278084755, 48.8487233966589, 47.81202882528305, 49.90790136158466, 49.48703974485397, 50.794522985816, 50.251467525959015, 50.52549362182617, 51.19697839021683, 48.93261909484863, 47.34459690749645, 50.260188058018684, 50.239984542131424, 51.75390310585499, 45.691928789019585, 41.4697777479887, 39.08916749060154, 40.47816015779972, 39.725241959095, 43.180590346455574, 42.50589095056057, 41.91372312605381, 38.22110407054424, 37.41922549903393, 37.34298638999462, 35.81650950014591, 38.01646985113621, 36.77185423672199, 38.27701047062874, 37.898995354771614, 38.308100402355194, 34.77946914732456, 37.3414246737957, 35.43476678431034, 36.394523084163666, 37.0622992515564, 37.36992694437504, 46.05200506746769, 45.19078508019447, 42.28617154061794, 37.92447678744793, 36.64034329354763, 35.628791972994804, 39.887428656220436, 45.804615542292595, 45.79360373318195, 47.82855413854122, 47.67371244728565, 46.39576122164726, 46.44474059343338, 47.89226531982422, 43.13633032143116, 44.75873686373234, 45.240136831998825, 43.04408647119999, 43.590158969163895, 40.40643900632858, 39.91918735206127, 40.118733644485474, 43.154272958636284, 46.62133231759071, 46.37278765439987, 47.508797496557236, 41.42590530216694, 2.918202797882259, 0.3587480419082567, 6.426129201427102, 9.50923578813672, 6.4728690683841705, 9.335917588323355, 1.034910804592073, 0.0325471386895515, 0.022064718359615654, 0.06842525879619643, 9.408363550901413, 32.41761468350887, 25.70335976779461, 37.95133374631405, 35.2417903393507, 8.392669502645731, 0.050061133661074564, 0.02625381173857022, 0.017786515309126116, 0.10328473668778315, 0.04368329464341514, 0.035263120880699717, 0.06537328037666157, 0.028154375868325587, 0.03838102056761272, 0.031481366386287846, 0.06052275901311077, 0.03596341142838355, 0.0512082898785593, 0.009636157683416968, 0.03334156695927959, 0.02247689048090251, 0.04720726043160539, 0.09354585927212611, 0.05432550678960979, 0.017942436825251207, 0.043692757026292384, 0.052192526127328165, 0.04830245517950971, 0.08259788970462978, 0.0443435426132055, 0.07257675126311369, 0.03685223717184272, 0.03955422987928614, 0.01871908323664684, 0.055356056764139794, 0.05907799415581394, 0.025320857894257642, 0.0509666540165199, 0.02816423530020984, 0.05933194224780891, 0.027692622716131154, 0.02441921526042279, 0.02368014564126497, 0.08139095720252953, 15.306547656655312, 52.3226185888052, 30.55432576686144, 32.99530528485775, 42.30968087911606, 32.391240298748016, 5.262165209278464, 1.5107192541472614, 2.0747950673103333, 0.10044642258435488, 0.0546059384214459, 0.2543804969172925, 0.21928304195171222, 1.1759743164293468, 0.02426800267130602, 11.796950530260801, 50.6716413795948, 55.463712438941, 53.00214372575283, 50.080735087394714, 46.5895926207304, 47.434826865792274, 49.15322005748749, 49.87430736422539, 52.8201524913311, 52.23923586308956, 53.95357467234135, 53.23640115559101, 52.64520987868309, 52.688732743263245, 53.086974173784256, 53.02562266588211, 52.39120110869408, 42.13981479406357, 39.5613681524992, 41.137132197618484, 44.52166758477688, 47.0456213504076, 49.10593159496784, 47.95773960649967, 48.479884788393974, 44.786251187324524, 40.357786417007446, 39.62184950709343, 41.12629137933254, 42.39338658750057, 40.444592759013176, 40.57589091360569, 39.38867121934891, 40.29524937272072, 40.53221985697746, 39.48514424264431, 38.53151701390743, 38.50329592823982, 39.67369392514229, 42.62423940002918, 48.12339551746845, 49.2879456281662, 51.223113387823105, 50.287937968969345, 51.235641315579414, 50.79140715301037, 51.742306128144264, 51.84440664947033, 53.120552971959114, 53.83467525243759, 51.54615305364132, 49.24466215074062, 51.86829216778278, 52.46060438454151, 51.26835376024246, 47.93379709124565, 42.20668360590935, 40.805075615644455, 41.28329515457153, 42.68625967204571, 43.80256377160549, 43.60467039048672, 43.43005836009979, 39.45163004100323, 41.777648627758026, 39.04192842543125, 37.66757257282734, 39.421520456671715, 37.50549226999283, 39.98767867684364, 39.1157166659832, 39.47444021701813, 37.22486212849617, 39.801359474658966, 37.46911682188511, 38.17329503595829, 37.52516761422157, 39.392159432172775, 47.274642661213875, 47.319902032613754, 42.844289392232895, 39.51985917985439, 37.673177272081375, 36.31933271884918, 40.574701577425, 46.41904257237911, 47.30831265449524, 49.34623830020428, 49.61338296532631, 48.413015976548195, 49.484022706747055, 48.865442499518394, 44.69371855258942, 45.69253295660019, 47.15408653020859, 45.250521674752235, 45.707853734493256, 42.21795380115509, 42.29740373790264, 41.60793073475361, 45.69431506097317, 47.2302458435297, 49.46072615683079, 47.60916531085968, 42.65654906630516, 3.3225210523232818, 0.7474392489530146, 10.338574536144733, 14.31100107729435, 7.716542808339, 7.90685654617846, 2.576844790019095, 0.09064052181201987, 0.1012985194392968, 0.04935995253617875, 10.649767387658358, 37.012039348483086, 28.77431508153677, 39.869668409228325, 40.17752788960934, 14.429691508412361, 0.06267794102313928, 0.0488469021365745, 0.04182221833616495, 0.05852144277014304, 0.011989081231149612, 0.013411860891210381, 0.01147005932580214, 0.018657260479812976, 0.021439509037008975, 0.05698255503375549, 0.07374175984296016, 0.0524496469006408, 0.008733866598049644, 0.03897269780281931, 0.03308798994112294, 0.014609069403377362, 0.03358394496899564, 0.30789566750172526, 0.1312081320793368, 0.11462030030088499, 0.07062871009111404, 0.10677214799216017, 0.21342933730920777, 0.182017803308554, 0.13349666318390518, 0.13989483704790473, 0.19870503834681585, 0.2380530402297154, 0.10606634328723885, 0.2477881030063145, 0.207238148432225, 0.13476711610564962, 0.2018001800752245, 0.13769154902547598, 0.19014941150089726, 0.06175554051878862, 0.09787775299628265, 0.09654621389927343, 0.2165017247898504, 17.402121908962727, 62.57385291159153, 39.5878679305315, 38.791252076625824, 45.19193261861801, 38.60850468277931, 7.59167960844934, 4.124426459893584, 4.3873771000653505, 0.22593403584323823, 0.24350427818717435, 0.3974052082048729, 0.5182480753865093, 1.6724530630744994, 0.1639443403109908, 12.709710951894522, 53.072113171219826, 57.066170051693916, 53.47798839211464, 53.622965812683105, 48.74174393713474, 51.610772386193275, 52.04030893743038, 52.99469232559204, 54.60963226854801, 55.23163989186287, 56.300112158060074, 55.25131143629551, 52.85430505871773, 55.89971624314785, 53.70765566825867, 56.313362047076225, 53.561507910490036, 44.282443821430206, 42.272237688302994, 42.25347049534321, 46.83559142053127, 50.347252786159515, 51.82880848646164, 50.19164353609085, 51.49862140417099, 46.48392789065838, 42.762035205960274, 42.43300326168537, 43.10409665107727, 44.74813163280487, 41.04803457856178, 42.896126210689545, 42.07719035446644, 42.494301572442055, 42.47357368469238, 41.15053787827492, 41.75951600074768, 40.07606953382492, 41.9788022339344, 45.271804332733154, 49.580442532896996, 50.87961941957474, 54.110662043094635, 53.1781654804945, 54.024516865611076, 53.15971367061138, 53.16034443676472, 53.13601814210415, 54.07652847468853, 56.38166718184948, 48.76564845442772, 49.806348010897636, 54.75074149668217, 54.159694612026215, 54.21457126736641, 50.28554029762745, 44.83083799481392, 42.56689287722111, 43.78644123673439, 45.39061635732651, 47.38037958741188, 47.19412878155708, 46.465848460793495, 40.93870684504509, 43.470028415322304, 41.601934656500816, 38.87202054262161, 41.644252985715866, 39.90010477602482, 42.750837206840515, 40.89366406202316, 42.034294456243515, 38.17526713013649, 41.912928968667984, 37.71578058600426, 40.539716854691505, 40.32347425818443, 40.67467801272869, 51.250897496938705, 49.70843866467476, 45.52534572780132, 42.50926896929741, 39.69894357025623, 38.35931785404682, 43.66963930428028, 49.29575800895691, 47.63761818408966, 52.77421295642853, 52.37816780805588, 50.36715231835842, 49.931441098451614, 52.277192026376724, 46.02879971265793, 48.35818871855736, 50.15097051858902, 46.68335638940334, 47.035764679312706, 43.99752750992775, 43.53452995419502, 43.64929139614105, 47.36396066844463, 49.757296442985535, 51.82228043675423, 48.47892723977566, 44.460000693798065, 4.022077526897192, 0.8222561655566096, 16.88413940370083, 19.034314826130867, 13.02283599972725, 15.662963781505823, 4.622603952884674, 0.21618463477352634, 0.34707391052506864, 0.12457296077627689, 16.261896193027496, 43.523666337132454, 35.4187848418951, 44.15502905845642, 48.070498555898666, 18.332718573510647, 0.22482405009213835, 0.16389374068239704, 0.1363052023225464, 0.15863149805227295, 0.22537862736498937, 0.09846113302046433, 0.1500391200534068, 0.10186460000113584, 0.1204619079362601, 0.284277381724678, 0.156428120972123, 0.13623483187984675, 0.17837687133578584, 0.16550963366171345, 0.19667928689159453, 0.08679577382281423, 0.1445042123668827], [0.005733116777264513, 0.011956086273130495, 0.033611011094762944, 0.02323987580894027, 0.034777199689415284, 0.03032233023986919, 0.05224860280577559, 0.006485215262728161, 0.12198585623991676, 0.04881094137090258, 0.056248767650686204, 0.037023706681793556, 0.04818661334866192, 0.0507881600788096, 0.00453265765827382, 0.01805858850275399, 0.05028820116422139, 0.16541551449336112, 0.02070345995889511, 0.06186546372191515, 0.029616532956424635, 0.05974121442704927, 1.3005342450924218, 28.607002459466457, 39.2253065854311, 25.6295620277524, 35.885335206985474, 30.876259692013264, 5.311914989724755, 1.0419423272833228, 1.4531100704334676, 0.06617838444071822, 0.07747583877062425, 0.10351272445404902, 0.18622014031279832, 0.23357269470579922, 0.09719011606648564, 0.6754531804472208, 28.14157873392105, 56.61883145570755, 53.85344624519348, 50.63427038490772, 48.62511299550533, 49.40703123807907, 50.30713453888893, 51.747717037796974, 52.89505407214165, 53.299739956855774, 52.35060028731823, 52.362284660339355, 53.32170657813549, 53.2554267346859, 51.410070955753326, 51.01698964834213, 46.40501752495766, 39.26979839801788, 38.80784198641777, 39.819811284542084, 43.39872524142265, 45.77583208680153, 46.60628892481327, 46.79175317287445, 44.740957617759705, 39.85163077712059, 38.3089629560709, 37.7831319719553, 39.12519335746765, 39.32663194835186, 38.219416961073875, 39.552051052451134, 39.67041090130806, 39.74923387169838, 38.05018924176693, 37.699924036860466, 36.768890395760536, 37.5175566226244, 37.39960715174675, 38.42277444899082, 42.80322879552841, 46.3915890455246, 50.2897846698761, 47.434731870889664, 48.1495077162981, 49.216064885258675, 50.49950681626797, 50.5695104598999, 50.48183396458626, 51.30222514271736, 49.25989933311939, 46.98114641010761, 48.3002570271492, 50.844836086034775, 50.16938053071499, 46.82573854923248, 42.006278559565544, 42.47434884309769, 43.26377548277378, 44.424757584929466, 47.18070790171623, 44.874326661229134, 45.374577417969704, 42.00374409556389, 37.03015677630901, 36.61119885742664, 36.97900392115116, 37.391749173402786, 38.221818432211876, 35.18345206975937, 35.691006034612656, 36.9856383651495, 35.74168011546135, 36.03329546749592, 36.35637693107128, 36.80392451584339, 34.87822964787483, 43.953841254115105, 50.47272205352783, 48.56285333633423, 47.0561657845974, 44.05324012041092, 35.806668028235435, 34.80306588113308, 40.615667179226875, 46.94899633526802, 47.568556889891624, 47.62415170669556, 44.584409818053246, 45.99223807454109, 46.4429546892643, 45.49826458096504, 42.7742325514555, 42.282641530036926, 41.59312292933464, 40.288755521178246, 41.446541994810104, 41.42299845814705, 41.594430059194565, 43.17978858947754, 44.23472598195076, 48.61417718231678, 47.26613111793995, 50.60938932001591, 24.379991479218006, 0.42354727105703205, 0.5850934947375208, 5.853991052135825, 13.37538868188858, 4.913464095443487, 5.007773609831929, 2.4310235772281885, 0.40565848408732563, 0.011038971715606749, 0.13594296004157513, 26.70448064804077, 31.833886206150055, 26.69312495738268, 47.96480342745781, 28.7490027397871, 1.5045160870067775, 0.09686574558145367, 0.04064772139827255, 0.01629767801205162, 0.018717290950007737, 0.025417246179131325, 0.03820857142272871, 0.05663833209837321, 0.04214982458506711, 0.021838546999788377, 0.01838059524743585, 0.04622792235750239, 0.03095126143307425, 0.02729203552007675, 0.020577849609253462, 0.012984492368559586, 0.04075111370184459, 0.005922625578023144, 0.05681663678842597, 0.028707047677016817, 0.014198221088008722, 0.02598230628791498, 0.044537510329973884, 0.037992591605870984, 0.06367638197843917, 0.009575565036357148, 0.08990342073957436, 0.04662276718590874, 0.10741151563706808, 0.01816370258893585, 0.04942744715663139, 0.05752884993853513, 0.020534005379886366, 0.02055045508313924, 0.019662204504129477, 0.007307584000955103, 0.04584943446388934, 0.038361398183042184, 0.024227199392043985, 0.06778264054446481, 2.8145405603572726, 38.8203015178442, 41.41822591423988, 28.680574111640453, 43.661530539393425, 34.964876398444176, 7.6800011191517115, 2.365901484154165, 1.7646206798963249, 0.20537298289127648, 0.031238628434948623, 0.05453407997265458, 0.3420445241499692, 1.0963475704193115, 0.641078146873042, 1.0558548057451844, 32.36923947930336, 58.59647333621979, 54.04918134212494, 52.88413725793362, 51.23911052942276, 51.21374689042568, 52.100767493247986, 53.53274345397949, 52.53818102180958, 53.725199326872826, 53.411689549684525, 51.95888310670853, 56.023091822862625, 55.30719503760338, 53.1472123414278, 53.03434319794178, 47.46286176145077, 39.017149955034256, 41.09266698360443, 41.48379899561405, 45.494176000356674, 47.0504204928875, 47.019334360957146, 48.68095099925995, 46.75413139164448, 41.54012717306614, 38.545359671115875, 40.34595005214214, 41.81648254394531, 41.69715374708176, 39.789010137319565, 40.45694209635258, 40.08192881941795, 40.47983966767788, 38.86417016386986, 37.92494036257267, 38.064351081848145, 38.14943231642246, 38.29822473227978, 40.03877453505993, 45.706128627061844, 47.53066912293434, 52.14994065463543, 48.76368775963783, 49.37783740460873, 50.99122703075409, 51.97063967585564, 51.08243353664875, 51.64445757865906, 54.05291274189949, 49.54915501177311, 48.05860139429569, 50.28489053249359, 52.223390713334084, 52.348263412714005, 48.01304183900356, 43.97883251309395, 43.48897039890289, 44.646004512906075, 46.435013115406036, 47.90461465716362, 46.77189543843269, 47.4087792634964, 43.63618589937687, 39.15146894752979, 38.29816773533821, 37.25621424615383, 37.29377903044224, 39.11956965923309, 37.95544132590294, 37.47555747628212, 37.888963893055916, 36.46678000688553, 38.59658472239971, 37.95974649488926, 37.717775478959084, 35.991702899336815, 44.826684817671776, 51.032530814409256, 50.4130120575428, 47.67224572598934, 44.26676966249943, 38.104020953178406, 36.60195395350456, 42.005241215229034, 48.84833961725235, 49.88802842795849, 49.59208510816097, 46.49516008794308, 47.99861781299114, 47.20758005976677, 46.12766660749912, 45.703324377536774, 44.81239378452301, 43.18699300289154, 41.91815368831158, 44.0371859818697, 44.201663956046104, 43.10084782540798, 44.40771169960499, 46.36070430278778, 49.76596377789974, 47.935138419270515, 51.20706684887409, 27.20111969858408, 0.5736617487855256, 3.730123518034816, 8.811920955777168, 14.088667407631874, 8.389797806739807, 5.695076929405332, 2.388341655023396, 0.5203452066052705, 0.007538322815889842, 0.18038680020254105, 29.136576242744923, 39.63664971292019, 29.128340184688568, 48.05181875824928, 35.33143512904644, 3.3867615927010775, 0.18613465974340215, 0.019636637516668998, 0.024087914971460123, 0.040246601711260155, 0.026702744289650582, 0.09278310215449892, 0.05842670761921909, 0.0494902105856454, 0.02873957229894586, 0.018003472905547824, 0.0536111525434535, 0.01553235584651702, 0.0045079051778884605, 0.03013041085068835, 0.04396431628265418, 0.015272478922270238, 0.03293496651167516, 0.14406756235985085, 0.05804663524031639, 0.09209276380715892, 0.262959070969373, 0.1648586810915731, 0.13924961385782808, 0.14038735593203455, 0.13808003364829347, 0.17181296105263755, 0.1311284996336326, 0.2097885389230214, 0.14064163056900725, 0.09967561316443607, 0.1924287251313217, 0.14170487585943192, 0.08977810910437256, 0.14360101864440367, 0.21257053886074573, 0.13245399022707716, 0.2701880346285179, 0.11947415390750393, 0.20963691815268248, 3.475475669838488, 45.56242413818836, 50.643310099840164, 34.332001358270645, 48.683622255921364, 40.42408525943756, 12.95869829133153, 3.587979320436716, 4.350182320922613, 0.4073601693380624, 0.2088657525018789, 0.4893957485910505, 0.6479608244262636, 1.4027238241396844, 0.5563648988027126, 1.243915620725602, 32.750222235918045, 61.120415702462196, 58.35393235087395, 54.384973123669624, 52.05055698752403, 53.61132703721523, 53.8136737793684, 56.28869377076626, 54.50297959148884, 56.53782360255718, 54.28094230592251, 52.91653431952, 56.02765537798405, 58.67275044322014, 54.86290767788887, 55.8234429359436, 49.53337825834751, 41.17448799312115, 41.81110963225365, 44.09921005368233, 47.78649039566517, 49.251129403710365, 48.77728722989559, 50.78820012509823, 49.33623343706131, 42.888435423374176, 42.23748475313187, 41.889537423849106, 43.828763365745544, 44.775790348649025, 41.72830827534199, 42.55078174173832, 42.4466597288847, 44.15877565741539, 41.89307123422623, 40.189292058348656, 39.33524988591671, 40.201827585697174, 41.477430537343025, 41.62399247288704, 47.89513796567917, 49.16237376630306, 54.06179666519165, 50.993898287415504, 50.71326054632664, 53.75420317053795, 53.81747357547283, 52.010032162070274, 53.548584803938866, 56.87589146196842, 52.02115796506405, 47.9220025241375, 52.057624608278275, 54.692445024847984, 54.23949413001537, 50.98337285220623, 46.6936956346035, 47.6408252120018, 48.43296870589256, 49.114021360874176, 50.87517745792866, 49.90065515041351, 48.5115484893322, 45.73083870112896, 40.30737832188606, 39.753782227635384, 41.13588586449623, 40.03587529063225, 41.068823263049126, 39.09846179187298, 39.03825022280216, 40.010720640420914, 39.70890283584595, 39.663795456290245, 40.47922030091286, 39.68617245554924, 37.67060860991478, 47.06490531563759, 53.170854672789574, 53.30040492117405, 49.963693767786026, 46.33218303322792, 39.03950795531273, 38.373992666602135, 43.40414755046368, 50.55899262428284, 53.18601205945015, 51.45435757935047, 47.273031547665596, 47.997101694345474, 49.581780061125755, 49.1239882260561, 47.12250642478466, 46.63961313664913, 45.73854088783264, 41.87643192708492, 46.218857914209366, 45.50605796277523, 45.58095954358578, 47.17796064913273, 48.20973828434944, 52.721661776304245, 51.69030211865902, 51.77227512001991, 27.550554648041725, 0.7196717639453709, 3.516528191976249, 12.434644661843777, 24.534384794533253, 13.444737810641527, 11.133337039500475, 5.418846951797605, 0.5639444233383983, 0.12243625824339688, 0.6948490021750331, 37.454586401581764, 43.002208918333054, 37.390461042523384, 53.535000532865524, 43.276102021336555, 3.84870161768049, 0.4820039280457422, 0.1781689957715571, 0.11262373751378618, 0.24228770518675447, 0.12301976443268359, 0.2818021707935259, 0.22614094661548734, 0.17847427079686895, 0.13577876728959382, 0.17878128244774416, 0.12296263390453532, 0.1279215607792139, 0.08934994184528477, 0.14630711171776056, 0.07090862593031488, 0.1187599851982668, 0.08543060059309937], [0.02410665234492626, 0.01185175979117048, 0.03749162708118092, 0.06156795898277778, 0.015494407980440883, 0.03645045326265972, 0.038331274408847094, 0.04318065657571424, 0.021365596694522537, 0.03638383437646553, 0.03810185058682691, 0.006752977042197017, 0.008301803991344059, 0.026886577979894355, 0.05763687324360944, 0.05143316062458325, 0.03850481451081578, 0.025933148281183094, 0.04002783512987662, 0.04770658852066845, 0.019164336590620223, 0.018719894032983575, 0.09381562995258719, 11.481177024543285, 39.44270431995392, 27.058718539774418, 25.283560194075108, 38.19329336285591, 18.67854181677103, 2.036269884556532, 2.5214751111343503, 0.04750591921037994, 0.03583981786505319, 0.056522200829931535, 0.45570838905405253, 1.1283156112767756, 1.0082891955971718, 0.09279088728362694, 5.837281448766589, 43.00799980759621, 53.47904093563557, 53.785688281059265, 50.63831716775894, 53.77068288624287, 51.928731724619865, 54.06461611390114, 51.61610350012779, 51.49970054626465, 52.34156437218189, 53.70698310434818, 51.4662129431963, 54.361228197813034, 49.374379590153694, 45.28251975774765, 39.12411421537399, 39.30882230401039, 40.42126581072807, 43.495601043105125, 42.114378958940506, 46.08447052538395, 45.16073249280453, 47.76917092502117, 45.912601947784424, 39.944607987999916, 38.23079355061054, 39.189664497971535, 38.75652574002743, 37.823166623711586, 39.83308397233486, 39.32989217340946, 40.048384219408035, 39.07649517059326, 37.11216777563095, 38.53179819881916, 36.70234076678753, 37.20193035900593, 36.566007882356644, 38.975671380758286, 41.922379061579704, 46.45107105374336, 48.0826199054718, 50.826133489608765, 47.88060374557972, 49.91961993277073, 48.47565181553364, 50.916515439748764, 50.23134760558605, 53.654298931360245, 50.67896358668804, 43.59218426048756, 50.42001128196716, 49.454266503453255, 49.653562009334564, 46.04915902018547, 42.90525332093239, 43.38172495365143, 45.552848652005196, 47.16955929994583, 48.170577585697174, 48.884779661893845, 47.61926516890526, 44.5582178235054, 36.71049512922764, 36.51093363761902, 37.16245047748089, 36.73862121999264, 37.019217163324356, 36.36524185538292, 35.67452251911163, 35.991463512182236, 35.672398433089256, 35.79634018242359, 36.25085659325123, 36.4261943846941, 35.35711795091629, 43.152825236320496, 47.62888625264168, 49.02257926762104, 48.67226846516132, 47.63387158513069, 39.60682511329651, 34.18363831937313, 38.54604743421078, 44.47961904108524, 47.32655547559261, 47.49265596270561, 47.59166345000267, 44.96174097061157, 45.7174976170063, 43.10402065515518, 42.21634268760681, 39.266849756240845, 38.53297993540764, 38.903106674551964, 40.298418402671814, 40.37054233253002, 41.14514596760273, 44.11961495876312, 46.081191301345825, 46.20175123214722, 47.51730144023895, 46.71037673950195, 9.292363375425339, 0.2426297462079674, 3.133671898394823, 6.39537887647748, 15.54089818149805, 6.922432444989681, 4.704927485436201, 1.2863018712960184, 0.3486659360351041, 0.14845727680949494, 4.216698808595538, 36.592849642038345, 28.799712918698788, 30.45252352952957, 42.435716316103935, 14.162864126265049, 0.1623795070918277, 0.09371546228067018, 0.05488430688274093, 0.043698107911041006, 0.14143424428766593, 0.026057615723402705, 0.032554189092479646, 0.014834959674772108, 0.03267430198320653, 0.0333237925224239, 0.025200110467267223, 0.04213708562019747, 0.04096023978490848, 0.01629431608307641, 0.06464441714342684, 0.03371750186488498, 0.0095962691011664, 0.0585990899708122, 0.05662265793944243, 0.024872261165000964, 0.03094201241765404, 0.07568937056930736, 0.047183144342852756, 0.0368510237603914, 0.024237045836343896, 0.025835728411038872, 0.027648266404867172, 0.027811147410830017, 0.08424944287980907, 0.03977981679781806, 0.03207531088264659, 0.014822504581388785, 0.017421330412616953, 0.03738491366675589, 0.04206218807667028, 0.05162721368833445, 0.06807644938817248, 0.013683929446415277, 0.03291069828264881, 0.03948771489376668, 0.021290632357704453, 18.666866943240166, 45.422667637467384, 30.05537834018469, 32.834695503115654, 46.595763489603996, 18.196809366345406, 3.0826617730781436, 3.477870016358793, 0.18738283339189366, 0.1688980424660258, 0.1913889910792932, 1.187936905771494, 2.5763142434880137, 2.183904550038278, 0.14129204879282042, 7.360893292352557, 45.20026937127113, 56.40733100473881, 54.40027870237827, 52.078204303979874, 54.6437544375658, 53.88062238693237, 54.959665685892105, 54.4659885764122, 53.96223820745945, 53.861106634140015, 55.179062113165855, 53.4939019382, 54.29076477885246, 51.27657271921635, 47.70531915128231, 41.10618285834789, 41.028724014759064, 41.04257807135582, 44.61740344762802, 44.57874812185764, 48.86640004813671, 48.300234228372574, 50.305276438593864, 47.897056862711906, 40.317740365862846, 40.2738831192255, 39.9614030867815, 40.46388052403927, 39.544367864727974, 41.94472186267376, 41.67482614517212, 40.237853452563286, 40.173332914710045, 38.87051962316036, 39.28767643868923, 40.04801943898201, 40.48887558281422, 38.889568001031876, 39.6738763153553, 44.30284112691879, 48.219902738928795, 50.27596861124039, 51.71666510403156, 49.67307776212692, 49.7516043484211, 49.69382844865322, 53.075551986694336, 51.84578217566013, 55.19595980644226, 53.124428763985634, 45.468888357281685, 52.33602046966553, 51.30380965769291, 52.02594950795174, 48.256604969501495, 45.21776743233204, 44.99079801142216, 49.03361387550831, 47.72665500640869, 49.929073825478554, 50.805948972702026, 50.114435479044914, 45.7891009747982, 39.517032131552696, 38.752106577157974, 37.26702846586704, 38.48550148308277, 38.63849267363548, 38.46994511783123, 37.37354055047035, 38.94244596362114, 38.713930025696754, 38.182182759046555, 37.60980047285557, 37.75709576904774, 36.342332884669304, 45.07360316812992, 49.846276268363, 48.84118840098381, 50.79096257686615, 47.95847676694393, 41.36953912675381, 36.2359955906868, 40.713656321167946, 46.94442518055439, 49.99962463974953, 49.29510824382305, 48.76725196838379, 47.52529241144657, 46.81309662759304, 45.02659969031811, 43.63896735012531, 42.43505895137787, 40.84606781601906, 41.37037128210068, 41.25895366072655, 42.705817222595215, 43.99901323020458, 46.522264033555984, 48.01747240126133, 48.48001778125763, 46.65082633495331, 47.967645674943924, 10.51669092848897, 0.6527960649691522, 8.331999108195305, 9.864460676908493, 12.837619688361883, 7.317876750603318, 7.133343452587724, 4.308007434010506, 0.6456226436421275, 0.09684377801022492, 4.1969697922468185, 43.9842814207077, 32.825708985328674, 31.920472159981728, 47.61084482073784, 21.368734762072563, 0.30777478648815304, 0.05877682691789232, 0.06281666326685809, 0.011928449621336767, 0.04481411619053688, 0.008439299836027203, 0.1270168976043351, 0.03343823169416282, 0.0736165075795725, 0.01202826384542277, 0.027767620449594688, 0.042922782522509806, 0.03591783613956068, 0.03775625838898122, 0.08871764686773531, 0.06338232822599821, 0.033339359069941565, 0.02042501171672484, 0.18353513907641172, 0.09898235075525008, 0.1644468039739877, 0.14127661212114617, 0.19689234264660627, 0.09281019054469652, 0.12743518687784672, 0.161795332969632, 0.09055524904397316, 0.12645166309084743, 0.12733486335491762, 0.218343943124637, 0.22243526967940852, 0.11883679006132297, 0.11467876669485122, 0.1311050180811435, 0.13340723438886926, 0.17480386071838439, 0.15945476246997714, 0.2339140381081961, 0.07200305626611225, 0.200323291355744, 0.2370314739528112, 22.126406505703926, 52.3061578720808, 37.76887133717537, 35.71744881570339, 49.609374180436134, 29.286200813949108, 4.415562087669969, 6.693768315017223, 0.4275818233145401, 0.2207055757753551, 0.5787889799103141, 1.7851101304404438, 3.837709045037627, 1.9696702645160258, 0.19581933069275692, 7.82663525082171, 46.08144208788872, 56.092867478728294, 56.7876335978508, 55.33875614404678, 57.56877288222313, 54.69953544437885, 56.967990919947624, 54.36761945486069, 54.7124395519495, 55.15570096671581, 56.627916768193245, 54.76578488945961, 56.259663328528404, 54.14985314011574, 47.26335346698761, 43.58054168522358, 45.13039492070675, 43.55407990515232, 49.1894169151783, 45.876389890909195, 52.244916558265686, 48.9910713583231, 53.50335203111172, 49.57465924322605, 41.66132166981697, 42.05059938132763, 41.84440724551678, 42.914296835660934, 41.00427232682705, 43.76101680099964, 42.92826108634472, 43.508326560258865, 43.57062041759491, 42.31075242161751, 42.13815428316593, 42.55056515336037, 41.59938119351864, 39.40763980150223, 41.97649955749512, 46.792057156562805, 50.377252176404, 52.31131039559841, 55.236378237605095, 50.765807926654816, 51.947666108608246, 52.62628309428692, 54.08803045749664, 53.744236305356026, 57.090264558792114, 53.928602412343025, 46.13572217524052, 54.661404490470886, 53.347659185528755, 54.45230171084404, 49.447518065571785, 46.207306534051895, 48.18475462496281, 50.67438863217831, 52.6485650986433, 52.30562210083008, 52.34667889773846, 52.12954714894295, 48.33847917616367, 40.460969880223274, 39.987458288669586, 41.19041293859482, 40.16893655061722, 42.94463820755482, 39.98188778758049, 38.48953306674957, 39.25984673202038, 39.69221033155918, 38.93223971128464, 39.7537974268198, 39.62994687259197, 39.450178518891335, 47.22774937748909, 51.62413626909256, 51.33527956902981, 53.24403874576092, 51.05988174676895, 44.57277104258537, 37.014406621456146, 42.72195875644684, 48.40458042919636, 51.28180503845215, 51.180589869618416, 51.12073168158531, 47.46088586747646, 49.18234929442406, 46.74080930650234, 47.96139881014824, 43.27107489109039, 42.66993194818497, 43.09673644602299, 43.8179225474596, 43.38663049042225, 46.347424015402794, 49.2021918296814, 50.74867084622383, 48.08183714747429, 48.973147720098495, 47.3161668330431, 11.755418758839369, 0.4032964655198157, 9.354825373739004, 16.906789988279343, 26.308636888861656, 17.887870743870735, 8.155035953968763, 7.601863536983728, 1.3915887591429055, 0.36374453629832715, 8.215427063405514, 48.00450749695301, 39.21214409172535, 38.15296992659569, 52.806556820869446, 25.63937120139599, 0.40508349775336683, 0.19833354890579358, 0.11576334130950272, 0.0886104213714134, 0.16442477703094482, 0.08536004461348057, 0.1257744088070467, 0.14677319530164823, 0.15887541230767965, 0.11131347579066642, 0.06867516218335368, 0.21325637237168849, 0.07551103990408592, 0.08706376334885135, 0.1284549423144199, 0.26978861074894667, 0.13033688039286062, 0.16142997366841882], [0.02452240532875294, 0.06984957377426326, 0.024178917119570542, 0.01607495578355156, 0.10535112072830088, 0.028858019068138674, 0.022303986770566553, 0.03001016993948724, 0.08390760223846883, 0.03977455497079063, 0.01591523818206042, 0.009329128406534437, 0.04661249215132557, 0.05348569990019314, 0.11362997101969086, 0.05938827867794316, 0.026423789531691, 0.03215627548343036, 0.08971216186182573, 0.08287645483505912, 0.06789452672819607, 0.04588346564560197, 0.04575389779347461, 1.8540452001616359, 28.035024851560593, 36.66059620678425, 21.620110273361206, 37.50240683555603, 27.077626325190067, 6.052035950124264, 1.268435230012983, 0.15892862429609522, 0.19096491305390373, 0.11136889937915839, 0.4070286371279508, 1.5798698435537517, 0.6403852184303105, 0.1858205086318776, 0.3956599737284705, 16.606309711933136, 48.81352588534355, 53.580845072865486, 53.56297083199024, 50.62376394867897, 51.71786963939667, 48.395548313856125, 49.84661445021629, 51.184028685092926, 52.46590130031109, 53.043067529797554, 51.315862610936165, 47.44988165795803, 44.967858642339706, 41.74141377210617, 38.39813657104969, 38.48004877567291, 39.17606122791767, 40.834892615675926, 45.77401578426361, 46.64131164550781, 46.89927600324154, 45.8137084543705, 43.90591822564602, 40.6345521658659, 37.41955608129501, 38.818899393081665, 39.949228540062904, 38.63787330687046, 38.459317088127136, 39.64907884597778, 39.221385195851326, 39.39705356955528, 37.908350452780724, 37.60538510978222, 36.56040318310261, 38.45627345144749, 35.53704969584942, 39.08661022782326, 38.82746793329716, 45.891482681035995, 47.51983590424061, 47.75126248598099, 50.237343683838844, 48.55427719652653, 47.81319536268711, 47.54686005413532, 48.72643455862999, 49.04611140489578, 50.57292267680168, 45.82735352218151, 51.42705984413624, 50.66102854907513, 48.893997967243195, 46.564935743808746, 43.62384796142578, 47.26055681705475, 46.46587125957012, 47.96929478645325, 49.22879800200462, 49.540765061974525, 50.71858026087284, 48.528582975268364, 39.49147090315819, 35.16194902360439, 37.23763704299927, 36.07969857752323, 37.55333550274372, 35.758038237690926, 34.76452074944973, 36.99483387172222, 36.548240035772324, 34.73046317696571, 34.30359788239002, 35.93531392514706, 33.53211767971516, 41.235831901431084, 47.153664752840996, 49.33506689965725, 48.3439014852047, 45.63416428864002, 45.13819970190525, 37.476891204714775, 36.501711532473564, 39.462691247463226, 44.105133935809135, 46.76307611167431, 44.391604363918304, 44.61649909615517, 43.07142220437527, 42.59422481060028, 41.45734861493111, 36.712319031357765, 36.4107596129179, 35.846345499157906, 38.331503346562386, 40.4664795845747, 43.72130513191223, 45.763676539063454, 46.87470652163029, 44.90792065858841, 50.13634130358696, 28.182016164064407, 0.8301432360894978, 1.1343444627709687, 7.505649849772453, 8.925872091203928, 8.463667742908001, 6.7869155667722225, 6.437424095347524, 2.3904313053935766, 0.7784521160647273, 0.03039418312255293, 11.533230431377888, 37.255952060222626, 30.65386712551117, 33.257229030132294, 32.4169497191906, 3.5582537529990077, 0.17660591402091086, 0.049458094144938514, 0.08357428145245649, 0.03669502431876026, 0.08702425140654668, 0.04221100723952986, 0.036145029807812534, 0.04508923775574658, 0.05582317564403638, 0.0011946834706577647, 0.09813725235289894, 0.029660944928764366, 0.029300652640813496, 0.03561463912774343, 0.0633193644171115, 0.03347125355503522, 0.027596189902396873, 0.03797838318860158, 0.05195690908294637, 0.07274363801116124, 0.06097817051340826, 0.049155364686157554, 0.08543058575014584, 0.07263257561135106, 0.0382106976758223, 0.05159231790457852, 0.11840773964649998, 0.04444116471859161, 0.03009269119502278, 0.04043495137011632, 0.053109267755644396, 0.14139955630525947, 0.11160720299812965, 0.05008686021028552, 0.0464632722287206, 0.02215172218711814, 0.05708930184482597, 0.05085962147859391, 0.025599087202863302, 0.0840388733195141, 0.035747580041061155, 5.510327517986298, 36.639875918626785, 38.57431411743164, 22.558146938681602, 44.7252606600523, 34.376755356788635, 7.520939754322171, 2.989719472825527, 0.2162881346885115, 0.31094675534404814, 0.6510777259245515, 1.804769088048488, 3.880598768591881, 4.33397714048624, 2.293061292730272, 0.6683222099673003, 20.3852354362607, 50.79447738826275, 56.752257496118546, 55.43545715510845, 52.43421100080013, 52.80490770936012, 50.95476798713207, 51.0747579485178, 51.07172571122646, 54.57493253052235, 53.84195186197758, 54.11455303430557, 50.02483628690243, 47.27228298783302, 44.31366294622421, 41.49960994720459, 40.759094282984734, 41.545724272727966, 43.731777369976044, 46.54999874532223, 47.24810868501663, 47.79828876256943, 47.70182713866234, 46.254708990454674, 42.72967614233494, 40.082050412893295, 40.255921483039856, 41.27929016947746, 42.006536945700645, 41.1761637032032, 41.131816282868385, 41.14256210625172, 40.950888991355896, 39.20922964811325, 39.846421256661415, 37.39054083824158, 39.314484000205994, 36.8786209076643, 40.746026784181595, 40.73997750878334, 46.94179192185402, 49.7464632242918, 51.37074686586857, 51.44806891679764, 50.04359968006611, 48.99839736521244, 50.62769673764706, 52.40085259079933, 52.35643297433853, 52.45935045182705, 45.171869695186615, 54.42499257624149, 51.908699199557304, 50.86052164435387, 47.23010905086994, 46.26471005380154, 47.90731631219387, 47.65479326248169, 50.654895678162575, 51.497150883078575, 52.033047527074814, 52.35561981797218, 49.49875831604004, 39.85545717179775, 37.47366137802601, 38.62875759601593, 38.4550005197525, 38.99830676615238, 37.21787050366402, 37.845752611756325, 38.02540697157383, 37.718273252248764, 36.42537742853165, 36.17285817861557, 37.47470252215862, 35.669464990496635, 44.24005709588528, 49.4122863560915, 50.1811408996582, 50.10960213840008, 47.59856767952442, 45.70812352001667, 38.91157642006874, 37.33924359083176, 42.035229206085205, 45.949931144714355, 49.56763722002506, 45.85389889776707, 46.61922723054886, 45.26906467974186, 43.95335108041763, 43.46305578947067, 38.56011427938938, 38.94860163331032, 38.264908120036125, 39.5582827180624, 42.05324783921242, 45.01794375479221, 46.109469383955, 48.552757278084755, 46.71517588198185, 50.960729867219925, 29.639374762773514, 1.3804649747908115, 2.320229597389698, 9.775895029306412, 7.382290419191122, 11.877547055482864, 7.425183467566967, 8.46683582291007, 5.355796460062265, 0.4454213910503313, 0.15853343065828085, 14.529307913035154, 47.47361518442631, 34.93800804018974, 36.53440497815609, 39.18520733714104, 6.577334962785244, 0.21672928211046383, 0.03360718532348983, 0.07227906098705716, 0.01904792330606142, 0.039303328303503804, 0.059003890710300766, 0.0316777535044821, 0.039128979260567576, 0.010126976121682674, 0.04475272573472466, 0.03005376369401347, 0.04466943079023622, 0.027179746721230913, 0.054363634626497515, 0.036671078923973255, 0.0316064887738321, 0.06012303085299209, 0.01374479390506167, 0.22113514569355175, 0.22706990770529956, 0.13027482200413942, 0.20922667375998572, 0.20327087928308174, 0.18557052360847592, 0.08951419396908022, 0.08718381315702572, 0.2030050419853069, 0.19060707913013175, 0.17844678164692596, 0.19450424500973895, 0.15140913950745016, 0.25674830423668027, 0.27952633041422814, 0.1365924728452228, 0.1317103730980307, 0.09158696047961712, 0.14180430880514905, 0.15572362986858934, 0.09952402950148098, 0.17039786354871467, 0.15582300344249234, 5.752860903739929, 41.8193855881691, 48.79329577088356, 32.251198813319206, 45.73826730251312, 41.39478497207165, 11.809909734874964, 5.317686405032873, 0.44804093486163765, 0.4987399815581739, 0.703774307621643, 1.2267838837578893, 2.757478072308004, 4.167792582884431, 1.6949712485074997, 0.7012222101911902, 19.955225810408592, 50.392983332276344, 57.62938342988491, 56.68986864387989, 54.28903967142105, 53.64710971713066, 49.824457839131355, 51.87347888946533, 51.5963027626276, 57.16021120548248, 55.98223641514778, 55.56276172399521, 51.002843007445335, 47.62784890830517, 46.27658061683178, 43.148622661828995, 42.46162712574005, 42.8341743350029, 45.94817563891411, 49.68100033700466, 50.343384593725204, 50.52195221185684, 48.997037038207054, 48.73276501893997, 45.83440974354744, 41.34762190282345, 41.97692513465881, 43.06588590145111, 42.90953189134598, 43.07747147977352, 42.37855978310108, 43.430404141545296, 43.77758011221886, 41.50353513658047, 42.97671228647232, 39.453773126006126, 41.99122376739979, 39.10872124135494, 43.85459437966347, 41.71638831496239, 50.04944756627083, 52.30683423578739, 52.192023396492004, 54.332057163119316, 52.6771205663681, 50.30254818499088, 52.07039192318916, 53.05546626448631, 54.204011633992195, 54.488065391778946, 47.39402465522289, 55.358412489295006, 54.729284048080444, 51.92848853766918, 50.64795345067978, 47.35480695962906, 51.89593568444252, 49.43988427519798, 51.99954092502594, 54.4138477742672, 53.21759216487408, 54.03588965535164, 50.66303104162216, 43.19289788603783, 38.462565913796425, 41.04413598775864, 40.36308333277702, 41.16504929959774, 39.04078088700771, 38.57577323913574, 41.25047251582146, 40.44541731476784, 37.39629752933979, 36.84905469417572, 38.915961384773254, 37.489992901682854, 45.38158804178238, 51.39706425368786, 51.321178525686264, 51.189488992094994, 49.34463478624821, 48.821254670619965, 41.02436564862728, 40.823854207992554, 43.34807015955448, 48.48528049886227, 51.85102969408035, 48.736644610762596, 47.782010436058044, 47.738947346806526, 46.09599530696869, 45.77231727540493, 39.71030116081238, 40.91478332877159, 39.13023568689823, 41.23887933790684, 44.10217009484768, 47.68462546169758, 48.637789115309715, 50.75988784432411, 46.73462323844433, 52.51434110105038, 29.94854137301445, 1.4041404356248677, 2.5018617510795593, 16.599295288324356, 16.890025287866592, 17.257714457809925, 13.807434048503637, 13.282874096184969, 9.562944006174803, 2.255887887440622, 0.14547663362463936, 18.939105235040188, 49.57160800695419, 37.77193397283554, 44.08693291246891, 45.029719322919846, 7.02790386043489, 0.3036216687178239, 0.1861153490608558, 0.30379933887161314, 0.18136224942281842, 0.16740350547479466, 0.1688920013839379, 0.15711588406702504, 0.09344216639874503, 0.13625282153952867, 0.16489360656123608, 0.1904307893710211, 0.17445473960833624, 0.135169078130275, 0.13261791580589488, 0.12372853030683473, 0.16425099573098123, 0.19060589169384912, 0.07047079590847716], [0.07860955098294653, 0.04970984176907223, 0.025581093832443003, 0.05137910629855469, 0.04873633326496929, 0.013262617776490515, 0.017546393428347073, 0.07301081117475405, 0.044073489916627295, 0.05370723840314895, 0.037903426273260266, 0.01495816546594142, 0.03275181930803228, 0.03248568515118677, 0.0596286454674555, 0.09017686505103484, 0.006779076056773192, 0.05278630735119805, 0.0639901620161254, 0.02172433047235245, 0.06518187306937762, 0.0072295133122679545, 0.059462356148287654, 0.19615540484664962, 9.18631011620164, 39.55389395356178, 32.217950597405434, 32.963880971074104, 39.01660658419132, 14.420994725078344, 1.7032890021800995, 0.07623766927281395, 0.10905655275564641, 0.11388328828616068, 1.9933694740757346, 3.209449569694698, 4.564690310508013, 2.431392394937575, 0.05500227496668231, 1.3878245861269534, 28.86713270097971, 52.423940151929855, 50.30071288347244, 49.639369770884514, 50.51810301840305, 50.327623039484024, 52.12186396121979, 50.04395306110382, 54.75649818778038, 50.89851960539818, 49.89019811153412, 45.368687734007835, 44.93467502295971, 41.19655720889568, 38.63961361348629, 38.91293294727802, 40.73401182889938, 41.428637355566025, 44.604012966156006, 43.262551948428154, 45.85587479174137, 43.026204630732536, 42.25708790123463, 40.06167970597744, 40.03084056079388, 39.350346475839615, 40.74657015502453, 38.39451916515827, 38.29266183078289, 39.57908660173416, 37.79549650847912, 37.327236235141754, 37.4507600069046, 37.69310720264912, 36.38554036617279, 37.720477133989334, 36.20797969400883, 38.04131671786308, 39.0369962900877, 39.8237706720829, 45.916736125946045, 46.392770782113075, 47.232058346271515, 47.43977800011635, 46.85418762266636, 46.55325897037983, 48.39555971324444, 49.42694216966629, 51.78721971809864, 48.0785009264946, 53.33658277988434, 51.73730179667473, 48.40725928544998, 47.937144711613655, 46.47769622504711, 45.918803215026855, 50.76953552663326, 51.33899576961994, 50.71437768638134, 51.23806178569794, 50.804892629384995, 48.27100619673729, 38.45846973359585, 35.23269362747669, 37.438414469361305, 36.11681878566742, 36.58765532076359, 36.32102742791176, 36.591348722577095, 36.048718839883804, 36.61317095160484, 37.80450202524662, 36.03947013616562, 35.329227447509766, 33.34274344146252, 37.91463151574135, 44.93181757628918, 48.85513745248318, 49.61436711251736, 47.5177726149559, 46.59853734076023, 43.72274525463581, 36.36139266192913, 35.15559956431389, 36.10062025487423, 41.76599845290184, 42.365074306726456, 42.455748841166496, 41.73770137131214, 42.084991335868835, 38.3291170746088, 37.92563192546368, 35.82134284079075, 37.42379665374756, 37.5921656191349, 40.688273683190346, 42.50708408653736, 46.140015944838524, 47.626157999038696, 47.16645486652851, 39.513832703232765, 11.275970935821533, 0.23532258986961097, 2.6615581568330526, 7.446425277739763, 6.933152144774795, 9.880134835839272, 4.096907386556268, 8.186490666121244, 4.572738753631711, 0.19940521015087143, 0.6181164539884776, 25.997302494943142, 29.143860451877117, 25.60706913471222, 33.92070382833481, 16.462373435497284, 1.0918648797087371, 0.155632434762083, 0.05788750022475142, 0.05763074310380034, 0.10810028805281036, 0.047007355533423834, 0.03094066727499012, 0.041403231443837285, 0.021094271214678884, 0.08529621249181218, 0.028616834060812835, 0.04289634722226765, 0.01918441354064271, 0.030145266791805625, 0.03829125038464554, 0.03896305359376129, 0.060478374871308915, 0.027922725603275467, 0.07685884687816724, 0.04100467216630932, 0.05045552577939816, 0.06533281106385402, 0.06029466363543179, 0.01613922206161078, 0.07488503833883442, 0.021493952990567777, 0.07832259958377108, 0.025334147903777193, 0.044745968480128795, 0.04253889921528753, 0.01624307635211153, 0.015666744875488803, 0.06841933645773679, 0.016271726963168476, 0.07051404085359536, 0.010131357576028677, 0.029092346630932298, 0.016995489786495455, 0.009942547785612987, 0.06478906914708205, 0.040877709252526984, 0.05086220786324702, 0.29041007452178746, 16.28833707422018, 44.97121386229992, 33.11406031250954, 37.2872281819582, 43.26856702566147, 17.92286116629839, 2.65689414460212, 0.007379300514003262, 0.2361540772835724, 1.0577319050207734, 4.209657786414027, 7.603396279737353, 8.143361080437899, 5.376799833029509, 0.1644567635958083, 2.0309895928949118, 33.50910231471062, 54.24892522394657, 53.390836268663406, 53.290514051914215, 52.45832450687885, 49.98012028634548, 51.53728812932968, 50.31817674636841, 55.72035826742649, 52.92086988687515, 51.4385200291872, 48.06243538856506, 45.756791308522224, 42.60637655854225, 40.27168683707714, 40.521880611777306, 43.255700916051865, 43.24255742132664, 46.196853294968605, 46.67844705283642, 46.86109945178032, 46.59234367311001, 45.39036177098751, 42.45953343808651, 41.96622110903263, 40.563701167702675, 41.188353449106216, 40.04531778395176, 39.94663707911968, 41.02505721151829, 39.58790212869644, 40.18625222146511, 38.640122786164284, 39.54210698604584, 38.13371255993843, 40.28190068900585, 38.3390611410141, 38.97013507783413, 40.53375877439976, 42.54469446837902, 46.71992942690849, 48.19118767976761, 48.56492042541504, 47.96938978135586, 49.70186501741409, 49.89406630396843, 50.89284650981426, 51.806518882513046, 53.59321340918541, 49.54269535839558, 53.01525302231312, 53.68062011897564, 50.30689515173435, 49.53882336616516, 48.47952760756016, 48.64696942269802, 50.393507704138756, 52.50435143709183, 50.55401489138603, 53.04801866412163, 52.352807968854904, 50.848814472556114, 39.670148715376854, 37.020623087882996, 37.68207639455795, 37.251920476555824, 38.77653926610947, 38.39642286300659, 37.36023746430874, 37.4569346755743, 38.054224625229836, 39.33568686246872, 38.35441991686821, 37.36199676990509, 36.32113762199879, 40.502053275704384, 46.266587153077126, 51.16575926542282, 50.907897502183914, 47.044485211372375, 48.55143114924431, 45.384061709046364, 38.22030611336231, 35.93639686703682, 38.83653424680233, 43.721384927630424, 44.95659984648228, 44.546567648649216, 42.545169442892075, 43.45400087535381, 40.30390530824661, 39.06125418841839, 36.49767614901066, 38.92863370478153, 38.71909774839878, 42.519752606749535, 43.959457352757454, 47.36927278339863, 48.8043075799942, 48.992621675133705, 42.26282179355621, 13.887943178415298, 0.8131057815626264, 3.1081956904381514, 9.544496946036816, 7.358433874323964, 9.846423994749784, 8.12807260081172, 6.502180220559239, 0.60124387498945, 0.16598726506344974, 0.4559063643682748, 30.732876285910606, 37.0291156321764, 27.893691435456276, 39.883089289069176, 23.15503790974617, 1.7247154586948454, 0.14049024728592485, 0.044517542846733704, 0.024242623076133896, 0.02764969689451391, 0.048476206793566234, 0.04604399589879904, 0.04690120986197144, 0.05168705676624086, 0.061213178996695206, 0.024618383577035274, 0.029579188085335772, 0.005678138941220823, 0.035619522459455766, 0.009441509973839857, 0.024328164872713387, 0.03124093280348461, 0.05367361911339685, 0.07588333828607574, 0.22323120821965858, 0.11510189477121457, 0.11736951215425506, 0.188009220873937, 0.1029195703449659, 0.21134589129360393, 0.08674348951899447, 0.28030763380229473, 0.1580220166943036, 0.12780344055499882, 0.17638696561334655, 0.09354462730698287, 0.09937282433384098, 0.13058414915576577, 0.0900294522580225, 0.15382033278001472, 0.07015265204245225, 0.1288319830200635, 0.14049520483240485, 0.09956371213775128, 0.17261557892197743, 0.09537482284940779, 0.14462032879237086, 0.34023317915853113, 17.076350189745426, 53.69652986526489, 44.02395889163017, 41.951964274048805, 49.429776817560196, 24.685362093150616, 3.527021328918636, 0.19502581155393273, 0.4483559913933277, 1.6120030567981303, 5.170117523521185, 9.058658815920353, 12.395689152181149, 6.148166516795754, 0.14431236719246954, 2.6974538806825876, 34.02632296085358, 55.066143572330475, 53.21484871208668, 51.126214787364006, 54.26801539957523, 52.597184255719185, 52.761742025613785, 51.219469383358955, 58.31442587077618, 55.24952553212643, 54.045370146632195, 49.310717806220055, 48.79551485180855, 45.45167528092861, 43.28052878379822, 41.9310349971056, 45.64475432038307, 44.44752216339111, 48.74403901398182, 50.1226544380188, 50.25834135711193, 47.12081931531429, 47.009310498833656, 44.87106643617153, 44.77822221815586, 42.052525877952576, 43.93277898430824, 43.040009289979935, 40.65941423177719, 42.28187017142773, 41.51744619011879, 42.25761987268925, 40.57861916720867, 41.65707729756832, 40.820966362953186, 41.632496416568756, 38.7796550989151, 42.075412049889565, 43.17688934504986, 43.51996153593063, 49.782644882798195, 51.77145816385746, 51.40295393764973, 48.66138964891434, 51.01648807525635, 52.50832982361317, 52.4704572558403, 53.03097277879715, 54.52951356768608, 49.59926292300224, 56.45401909947395, 56.11314319074154, 52.51726694405079, 51.55606672167778, 50.81576764583588, 51.043094247579575, 54.31607902050018, 55.19611939787865, 52.037181705236435, 55.27142375707626, 55.34838102757931, 52.20266282558441, 42.02592730522156, 39.077213332057, 40.45766405761242, 39.31601531803608, 40.562405437231064, 39.99091610312462, 40.57450398802757, 39.87515531480312, 40.73661468923092, 43.72253246605396, 40.80723010003567, 39.987792670726776, 36.8296567350626, 43.57988812029362, 48.168202713131905, 52.875773906707764, 51.89220808446407, 49.49291802942753, 51.51915170252323, 48.12137022614479, 39.79252874851227, 39.53413501381874, 39.544189274311066, 45.59279590845108, 46.57337509095669, 46.24636843800545, 43.5272191464901, 44.9899772554636, 41.39470897614956, 41.368953958153725, 38.58586169779301, 42.04135827720165, 40.53658962249756, 45.540826097130775, 45.20598046481609, 49.67301696538925, 51.194721311330795, 49.87314082682133, 41.08911417424679, 13.560670539736748, 0.6782434182241559, 6.059985598549247, 14.518337901681662, 16.438115537166595, 20.584057867527008, 13.237495981156826, 16.415303461253643, 11.064230147749186, 0.7041614118497819, 0.9166759927757084, 36.364371702075005, 38.72054547071457, 35.32987721264362, 46.42389491200447, 28.073119707405567, 1.7862200271338224, 0.34114239912014455, 0.21391909540398046, 0.16772696311818436, 0.20863921934505925, 0.1541027644998394, 0.22463079483713955, 0.1591490866849199, 0.11450510413851589, 0.2365356747759506, 0.1268664197414182, 0.11526159010827541, 0.09985090844566002, 0.10386977912276052, 0.15026179404230788, 0.09626088780350983, 0.15805633360287175, 0.16343990253517404, 0.18302998883882537], [0.034023507905658334, 0.05117018801684026, 0.0478570738050621, 0.03333065738843288, 0.04130671513848938, 0.05834462237544358, 0.019907209716620855, 0.027706220716936514, 0.1113634297507815, 0.00460726437268022, 0.06718438045936637, 0.09830573471845128, 0.15872109011979774, 0.06834887695731595, 0.019525352472555824, 0.021023527842771728, 0.09188810174237005, 0.11642892161034979, 0.009989126829168526, 0.03366023032867815, 0.017947251508303452, 0.060473658522823825, 0.09398909212904982, 0.1102629212255124, 0.6253756675869226, 21.764025650918484, 28.784711323678493, 28.255639113485813, 37.996342331171036, 23.21103360503912, 1.528720313217491, 0.08992337709059939, 0.14414449338801205, 1.0360680799931288, 5.704219713807106, 7.430139826610684, 9.17239336296916, 5.640148026868701, 0.7767502823844552, 0.015279820618161466, 7.971836384385824, 41.995388343930244, 54.130504578351974, 52.04713337123394, 51.115161180496216, 54.16445955634117, 51.67996287345886, 54.01292368769646, 52.026052102446556, 52.604593858122826, 51.000578328967094, 46.75446577370167, 43.79454620182514, 41.41659960150719, 42.4603845924139, 39.35378149151802, 39.60238695144653, 40.65694436430931, 43.05512487888336, 41.44687257707119, 42.97984331846237, 42.16555841267109, 39.81037259101868, 40.160546600818634, 38.58410619199276, 38.46461400389671, 40.30113145709038, 39.26841527223587, 39.318625777959824, 38.63381512463093, 38.15844543278217, 37.870732471346855, 38.140973970294, 37.71068125963211, 36.47470258176327, 36.40189468860626, 36.82345166802406, 36.659376472234726, 37.495669797062874, 39.06835600733757, 41.00811392068863, 44.07576151192188, 43.73767465353012, 46.14410072565079, 46.317755207419395, 45.28236776590347, 49.15095157921314, 51.62982076406479, 52.22200758755207, 48.4345456212759, 52.74836674332619, 50.19071638584137, 48.9349939674139, 50.74884183704853, 48.086936473846436, 48.542535826563835, 48.85598100721836, 51.15318953990936, 48.47197741270065, 53.163695856928825, 50.66072836518288, 48.86522591114044, 38.94423186779022, 35.684299394488335, 36.335003077983856, 36.471544951200485, 36.69291727244854, 34.87666793167591, 36.15480154752731, 34.33549717068672, 37.46025949716568, 37.744187861680984, 35.35151705145836, 34.80183854699135, 35.57823568582535, 36.083741560578346, 42.855703979730606, 47.02775850892067, 49.53855738043785, 47.3654729872942, 46.06936253607273, 46.65018416941166, 44.69007834792137, 40.73344945907593, 35.78712187707424, 33.3368955552578, 35.58822914958, 38.08847978711128, 37.06759236752987, 38.12909580767155, 37.029028236866, 36.323520094156265, 36.312740072607994, 39.273058623075485, 37.3440807312727, 41.452792659401894, 42.057078033685684, 43.88878874480724, 44.863755628466606, 46.26066707074642, 25.599448643624783, 3.5392490727826953, 0.5652018589898944, 2.8621512930840254, 8.669306058436632, 3.449357533827424, 8.246096167713404, 6.787143554538488, 5.42891688644886, 1.5980285941623151, 0.14471379487076774, 4.598214011639357, 35.60559801757336, 38.07200387120247, 38.53074565529823, 31.03081449866295, 7.0914336014539, 0.4231500142486766, 0.10117254729266278, 0.015120534390007379, 0.005362960882848711, 0.02548394670156995, 0.08835432105115615, 0.05206329595239367, 0.14234852569643408, 0.03567061561625451, 0.06407216933439486, 0.011523088560352335, 0.031705164728919044, 0.05639349386910908, 0.05870481261808891, 0.04315982077969238, 0.023590189921378624, 0.020852229026786517, 0.01028867711283965, 0.04767313992488198, 0.03838929922494572, 0.05141874440596439, 0.0649122879258357, 0.033332401435473, 0.013386791142693255, 0.027207740531594027, 0.03416234518226702, 0.054374065512092784, 0.039273330694413744, 0.06610697499127127, 0.08024747090530582, 0.0408046262600692, 0.0485773578111548, 0.04129114488023333, 0.04791963685420342, 0.020386342112033162, 0.06019893400662113, 0.059585515555227175, 0.04678562036133371, 0.040164939491660334, 0.02728475690673804, 0.02459744573570788, 0.09635468784836121, 0.07752505800453946, 2.7154326159507036, 31.013221442699432, 34.094099923968315, 31.77977330982685, 45.71182832121849, 27.18682486563921, 2.274062312208116, 0.19142547505907714, 1.0285745258443058, 1.4777597039937973, 5.853537926450372, 10.540556497871876, 9.224348925054073, 7.398468526080251, 3.0106373503804207, 0.3242807148490101, 9.742196537554264, 44.495543986558914, 54.289780631661415, 53.91830876469612, 52.11134992539883, 52.43414640426636, 53.50807897746563, 53.43727357685566, 55.24249970912933, 52.841560542583466, 51.82145208120346, 49.87480513751507, 45.701671466231346, 44.084064066410065, 43.20194520056248, 40.53057074546814, 41.75064727663994, 42.19515882432461, 44.69208464026451, 43.32219734787941, 45.394507348537445, 44.56185422837734, 41.05214975774288, 40.8293791115284, 40.747561901807785, 39.634863808751106, 40.86762025952339, 40.55446766316891, 40.97339518368244, 40.31668022274971, 40.18728956580162, 40.4069671779871, 39.24255385994911, 38.662883564829826, 39.243978783488274, 38.26450914144516, 38.652171939611435, 38.08865837752819, 38.94931599497795, 39.730356484651566, 42.30348341166973, 45.36578468978405, 45.870636999607086, 47.37711176276207, 47.80721068382263, 47.50369817018509, 50.67307390272617, 52.667149901390076, 53.60018603503704, 49.91969972848892, 53.3459834754467, 52.4521042406559, 52.28227615356445, 52.11699642241001, 51.706496849656105, 50.10429762303829, 50.61463683843613, 52.865776643157005, 50.98724864423275, 54.5498538762331, 51.677401810884476, 49.484786465764046, 41.16070993244648, 35.83272323012352, 38.7638783454895, 38.93670827150345, 39.49243225157261, 36.957595869898796, 39.56688545644283, 36.755701303482056, 39.69110079109669, 39.308594316244125, 36.77554003894329, 36.58281058073044, 37.728528901934624, 37.892934679985046, 45.33217169344425, 49.792695343494415, 50.76444000005722, 48.310782462358475, 47.5176852196455, 48.648447543382645, 44.53145585954189, 41.89706861972809, 37.06124670803547, 35.73457829654217, 38.81553277373314, 41.75268016755581, 39.07062068581581, 40.23322910070419, 38.08761723339558, 37.525281608104706, 38.890312761068344, 41.49356447160244, 39.76968057453632, 43.42713251709938, 43.506764844059944, 46.52696818113327, 45.6073909252882, 48.54368336498737, 27.250013574957848, 5.100029334425926, 2.0404209243133664, 6.402370976284146, 7.690612999722362, 7.056946652010083, 10.731440205127, 7.991639971733093, 5.62630251981318, 0.88979059481062, 0.21713406429626048, 4.993762336671352, 40.644686222076416, 33.26835863292217, 37.2851686924696, 38.74856896698475, 11.522596701979637, 0.6384847860317677, 0.19530484423739836, 0.02788298730592942, 0.033942650916287675, 0.03020882431883365, 0.06499069582787342, 0.0705982449289877, 0.033292284642811865, 0.009930729083862389, 0.048734548399806954, 0.06668069225270301, 0.06876367071527056, 0.09794505836907774, 0.07441561509040184, 0.05040316355007235, 0.016714182420400903, 0.032381880955654196, 0.03749697425519116, 0.010892709251493216, 0.15396303293528035, 0.13900308724259958, 0.14859789895126596, 0.1614801280084066, 0.15128839208045974, 0.1882344181649387, 0.13306789478519931, 0.15569262293865904, 0.18941470014397055, 0.2292333127115853, 0.1447449205443263, 0.1312801500898786, 0.2577328967163339, 0.15484709409065545, 0.0880286814935971, 0.06993954433710314, 0.23809221078408882, 0.1840416103368625, 0.15419913979712874, 0.08741914076381363, 0.18919741414720193, 0.19250274694059044, 0.1725406665354967, 0.14593231229810044, 2.927969223819673, 34.63422194123268, 41.22190184891224, 38.12692232429981, 47.10572652518749, 34.964549615979195, 3.789253570139408, 0.23939798993524164, 1.3965853722766042, 4.1616991348564625, 13.87202963232994, 17.699467353522778, 14.784696009010077, 12.638866603374481, 2.754464359022677, 0.22310256434138864, 10.908018629997969, 45.1030857861042, 54.18067328631878, 53.94364960491657, 53.59267383813858, 54.25068832933903, 55.57679437100887, 56.318104192614555, 56.09488137066364, 56.221349984407425, 54.24828305840492, 51.99849598109722, 48.93600091338158, 46.69732443988323, 46.6168637573719, 43.44790980219841, 44.89911653101444, 44.38918009400368, 47.64722026884556, 45.947563871741295, 46.99734874069691, 45.64941667020321, 43.3982502669096, 43.37290562689304, 42.925684824585915, 40.93130484223366, 43.24281960725784, 43.29699710011482, 42.549071833491325, 42.9700930416584, 41.87610134482384, 43.49387213587761, 41.90673530101776, 40.275684222579, 40.826726853847504, 40.43320097029209, 40.91865912079811, 40.74944660067558, 41.155698001384735, 42.44429625570774, 45.13568803668022, 47.54712983965874, 47.33652614057064, 49.85439643263817, 50.012228563427925, 49.71416115760803, 53.4872180968523, 55.56423604488373, 56.18455655872822, 50.72185568511486, 55.85049368441105, 53.25190432369709, 53.88555072247982, 54.694641306996346, 54.3898406624794, 52.66387827694416, 53.77220660448074, 55.297235772013664, 51.91702455282211, 56.738038659095764, 54.91449370980263, 53.85879635810852, 43.09538371860981, 38.425153121352196, 39.34572972357273, 40.5885898321867, 41.330279633402824, 37.96285092830658, 42.18218632042408, 38.37958976626396, 40.81003054976463, 41.04355841875076, 39.31656628847122, 38.22161324322224, 39.88910436630249, 41.707348600029945, 48.1134894490242, 51.12207680940628, 53.27073611319065, 49.16556939482689, 49.64120887219906, 51.41740836203098, 47.734144404530525, 44.43828485906124, 39.09826420247555, 38.417948707938194, 38.59055444598198, 42.18104638159275, 40.28756618499756, 42.5238373875618, 40.86064763367176, 39.631637781858444, 40.17641834914684, 42.342427521944046, 41.54591046273708, 46.387489065527916, 45.26381716132164, 47.72102750837803, 46.0201171785593, 49.28713247179985, 27.124101631343365, 5.105828773230314, 1.6042012441903353, 8.684322852641344, 16.666582077741623, 13.062107842415571, 15.741030592471361, 15.001275837421417, 13.804814089089632, 5.253634667024016, 0.3346570674329996, 6.564274588599801, 49.88471120595932, 48.77582810819149, 47.54445858299732, 46.07342071831226, 13.092939388006926, 0.6445631536189467, 0.2816446276847273, 0.15230535704176873, 0.1554981802473776, 0.13413373759249225, 0.18937036424176767, 0.12814511050237343, 0.2546377253020182, 0.2112155850045383, 0.12441791870514862, 0.23577494372148067, 0.1063980461913161, 0.20009148895042017, 0.23018517647869885, 0.12366026756353676, 0.08644873072626069, 0.09112209401791915, 0.16597653360804543, 0.12131147406762466], [0.03220746140868869, 0.014843613116681809, 0.05323126199073158, 0.04682952210714575, 0.010631408331391867, 0.0890652317320928, 0.03654711428680457, 0.02666585955012124, 0.07960083763464354, 0.05394567931944039, 0.04455148497072514, 0.06783932578400709, 0.02850602955732029, 0.026786844464368187, 0.06606452414416708, 0.05328123450453859, 0.047367798106279224, 0.07208445502328686, 0.03272680893132929, 0.028351640576147474, 0.07452345656929538, 0.027027968244510703, 0.05125721596414223, 0.07863260951125994, 0.04433713045727927, 7.213503001257777, 31.26073446124792, 28.24990712106228, 31.05425164103508, 35.05842737853527, 7.484038984403014, 0.3395280794939026, 0.8091552404221147, 0.9666480019222945, 5.624048290774226, 8.874382004141808, 6.833966542035341, 6.262421160936356, 2.1940324315801263, 0.3760054096346721, 0.23191270331153646, 20.809026695787907, 45.271298959851265, 52.083744406700134, 50.21078310906887, 53.22401762008667, 52.42387555539608, 51.91246099770069, 52.89339356124401, 53.44194732606411, 50.297593250870705, 48.280186504125595, 45.809357687830925, 45.4605858027935, 39.665159583091736, 39.138891622424126, 39.565403535962105, 40.53509250283241, 39.658179357647896, 40.558419451117516, 39.61448550224304, 39.17561665177345, 39.0136693418026, 40.07583774626255, 39.1985522210598, 39.042532593011856, 40.14279395341873, 39.316148310899734, 39.214583560824394, 39.190865233540535, 38.663791716098785, 37.55552418529987, 38.331845328211784, 37.77411125600338, 38.017556592822075, 36.951687186956406, 36.90279521048069, 36.182167679071426, 36.750100404024124, 37.81758852303028, 38.35917726159096, 39.29727092385292, 40.69884091615677, 44.40891243517399, 45.42889170348644, 43.30062970519066, 48.185738772153854, 50.32115578651428, 51.4980324357748, 49.22299571335316, 50.03586709499359, 52.18325346708298, 51.80715724825859, 53.91855575144291, 47.610008865594864, 52.313191294670105, 50.38146235048771, 50.35408101975918, 49.98985156416893, 51.443854942917824, 48.57328377664089, 49.11098912358284, 43.00863437354565, 36.8628441542387, 34.99338626861572, 36.347375214099884, 35.687096044421196, 35.19648157060146, 37.11629055440426, 38.67761917412281, 41.45585149526596, 42.33520790934563, 40.45253813266754, 35.8676927536726, 35.50545059144497, 36.03624030947685, 37.05750770866871, 45.11173792183399, 46.862588971853256, 48.685810938477516, 49.15609270334244, 47.46918082237244, 44.94047351181507, 46.28826878964901, 45.595235377550125, 38.31373929977417, 33.04310292005539, 33.234935626387596, 33.11787150800228, 34.40746910870075, 35.96704222261906, 39.85756225883961, 39.99666899442673, 37.69917167723179, 38.67841713130474, 41.73384837806225, 42.61367976665497, 47.04393424093723, 49.67000752687454, 41.756305173039436, 11.209480203688145, 0.8418172784149647, 2.3075601272284985, 2.78832932934165, 4.857584293931723, 4.841715870425105, 8.239274583756924, 5.2510265819728374, 2.9861875623464584, 0.12766112631652504, 0.04638004407752305, 11.772414296865463, 43.14783230423927, 37.73312285542488, 34.8317239433527, 20.874738469719887, 1.482515148818493, 0.08826176039292477, 0.02580074913566932, 0.0441352811321849, 0.03704280956299044, 0.035583487479016185, 0.043490878015290946, 0.0738955476845149, 0.10802743141539395, 0.03663650968519505, 0.05269752051390242, 0.045867138396715745, 0.04950225935317576, 0.0564522274362389, 0.04460866744921077, 0.0245724539126968, 0.005842213877258473, 0.03454293335380498, 0.00951215872191824, 0.029883654169680085, 0.12940527725731954, 0.0666429169359617, 0.06699301025946625, 0.024037237417360302, 0.03369541926076636, 0.08318807522300631, 0.04663682346290443, 0.028522881875687744, 0.06444826009101234, 0.02842569949280005, 0.04093297327926848, 0.03920182847650722, 0.04037597660499159, 0.0594332639593631, 0.06409864916349761, 0.051711484557017684, 0.002985186752084701, 0.05450818644021638, 0.019739835006475914, 0.04833032282476779, 0.035699726358870976, 0.010264113880111836, 0.056151119570131414, 0.030574495322071016, 0.029165453743189573, 12.73692699149251, 37.05258697271347, 29.390850998461246, 35.85555620491505, 42.70509526133537, 8.22101941332221, 0.27892453770618886, 0.4675408353796229, 0.8221791009418666, 2.1546283084899187, 7.8035966120660305, 8.174587804824114, 12.107538264244795, 3.871985343284905, 1.6815712675452232, 1.2722708866931498, 22.79306173324585, 49.693676456809044, 52.78581753373146, 52.045670449733734, 54.266172498464584, 52.29307897388935, 52.33616106212139, 53.567116409540176, 54.50537346303463, 52.95449048280716, 49.45065289735794, 48.145316541194916, 46.91306546330452, 43.328710198402405, 41.97976738214493, 42.26627200841904, 41.9522150605917, 41.54424995183945, 43.09876173734665, 42.38202519714832, 42.77507610619068, 40.95144376158714, 41.711566373705864, 40.59304319322109, 40.24418391287327, 42.42173686623573, 41.13784275949001, 40.923044085502625, 40.40171205997467, 40.50861552357674, 39.36070092022419, 38.28774869441986, 39.530331417918205, 39.571354016661644, 39.64670017361641, 38.40776905417442, 36.854666993021965, 38.914992436766624, 40.284389555454254, 41.301047801971436, 42.02161833643913, 43.28354202210903, 45.029932111501694, 45.82796908915043, 45.9435398876667, 49.864203706383705, 51.95496931672096, 52.46124655008316, 50.089045241475105, 50.545716136693954, 54.00555208325386, 52.36089013516903, 52.82110624015331, 48.970514461398125, 52.751862555742264, 52.8212696313858, 52.29890786111355, 50.42812764644623, 51.82271361351013, 51.500623896718025, 51.301430985331535, 43.75048756599426, 37.474387139081955, 37.501768469810486, 38.600430116057396, 37.22553089261055, 37.0628160238266, 39.05892871320248, 40.93327693641186, 43.61085265874863, 43.87222923338413, 40.99194958806038, 37.79636666178703, 37.654440477490425, 38.19415211677551, 40.14495603740215, 46.44802741706371, 50.66296644508839, 49.09767843782902, 50.60154274106026, 48.360920771956444, 47.85708300769329, 48.31214278936386, 45.32248221337795, 38.5627057403326, 33.58500324189663, 35.925571247935295, 34.34103347361088, 36.056960597634315, 36.95826843380928, 42.07222782075405, 41.74035742878914, 40.71751311421394, 39.861521646380424, 43.58477085828781, 44.54993426799774, 47.603560611605644, 50.49483686685562, 42.32488386332989, 13.793200012296438, 1.7020887415856123, 3.847089079208672, 4.565655933693051, 9.64683685451746, 7.182477191090584, 9.584264662116766, 7.202293127775192, 2.3865284398198128, 0.153463062888477, 0.1025232337997295, 14.131255522370338, 47.623190358281136, 40.543129071593285, 39.87570248544216, 28.023598864674568, 3.0825423169881105, 0.08413258430664428, 0.05716045525332447, 0.06261709975660779, 0.011196669747732813, 0.02604381734272465, 0.038682640515617095, 0.030148465448291972, 0.05280377379676793, 0.047067948180483654, 0.03148658368445467, 0.040003039975999855, 0.06921820648130961, 0.04271716679795645, 0.08430989080807194, 0.025311258214060217, 0.05249457652098499, 0.026593533548293635, 0.07588398395455442, 0.057301841807202436, 0.2327607703045942, 0.1537359060603194, 0.1585977600188926, 0.1277668823604472, 0.10522722659516148, 0.14198571938322857, 0.14580981340259314, 0.10124324428034015, 0.1392155047506094, 0.07523251188104041, 0.11978323615039699, 0.12672461016336456, 0.08027496005524881, 0.20232854469213635, 0.15419361821841449, 0.10738575569121167, 0.11305546708172187, 0.13432487030513585, 0.15248604031512514, 0.104353919159621, 0.12002893898170441, 0.11661470343824476, 0.21701972902519628, 0.19505330070387572, 0.1661846911883913, 13.092910889536142, 45.873908624053, 38.50703112781048, 40.58214917778969, 48.43033544719219, 14.169471971690655, 0.5780686216894537, 3.2974754087626934, 2.538418401964009, 11.734807714819908, 17.427666038274765, 11.235245671123266, 16.308010518550873, 5.510024959221482, 1.0472726100124419, 0.7340643228963017, 23.986910171806812, 48.22288177907467, 54.13614347577095, 52.289301976561546, 55.66629096865654, 52.22001649439335, 53.36435928940773, 55.66623017191887, 56.35391727089882, 54.77556936442852, 51.13006018102169, 51.35565407574177, 51.05552338063717, 44.559429958462715, 44.05365809798241, 44.94355134665966, 44.22649182379246, 44.67786580324173, 44.08746488392353, 43.068933337926865, 43.39639216661453, 43.3528009057045, 44.76830095052719, 43.79853218793869, 41.38504609465599, 44.29893113672733, 42.72173456847668, 42.99850031733513, 43.48225615918636, 43.54337587952614, 42.09142059087753, 40.430100336670876, 40.99740989506245, 41.45901292562485, 42.6291411370039, 41.61732383072376, 39.206463396549225, 40.27025431394577, 41.775015369057655, 42.80309960246086, 43.459928557276726, 45.82283176481724, 48.38479109108448, 48.80082316696644, 46.29963018000126, 51.27186477184296, 54.96870160102844, 54.16239246726036, 52.69228555262089, 52.83817112445831, 54.94404472410679, 53.74357894062996, 55.222691372036934, 49.901643097400665, 56.37957729399204, 55.16264319419861, 53.8067277520895, 53.38038682937622, 53.786227852106094, 53.13672490417957, 53.78720819950104, 46.44313707947731, 40.15107370913029, 39.70957159996033, 39.72350925207138, 38.1279406696558, 38.813488483428955, 40.91661863029003, 41.71176016330719, 45.24762623012066, 47.196051478385925, 43.3587171882391, 39.53527495265007, 38.831727504730225, 40.57101957499981, 42.708594873547554, 48.85755032300949, 51.714917197823524, 51.04073457419872, 52.3142134398222, 49.418654814362526, 48.782872930169106, 50.53721219301224, 48.05786803364754, 42.05784559249878, 36.39457628130913, 37.38315023481846, 35.12327089905739, 38.5464122146368, 39.92532022297382, 45.0465752184391, 45.244981572031975, 41.22161686420441, 43.45153100788593, 46.20055049657822, 47.63717360794544, 51.65708430111408, 52.13813088834286, 43.78650203347206, 12.94264605268836, 1.7131660971790552, 6.367579568177462, 8.372695874422789, 16.514736525714397, 12.76598023250699, 16.15665704011917, 13.685538489371538, 9.450025465339422, 0.5554145341739058, 0.19701951707247645, 18.49714905023575, 56.03365145623684, 44.646863266825676, 44.91223722696304, 37.628157287836075, 3.60554791521281, 0.27322202338837087, 0.19388599146623164, 0.12884382769698277, 0.14518954121740535, 0.11620635894360021, 0.12824335601180792, 0.15077795775141567, 0.2500009350478649, 0.11672100867144763, 0.22847883054055274, 0.13087982079014182, 0.17646995256654918, 0.14487861102679744, 0.17723917379043996, 0.13164067058824003, 0.1262730429880321, 0.20514089846983552, 0.17135931586381048, 0.11682920638122596], [0.02526124859286938, 0.038602963541052304, 0.05586769708315842, 0.04090892769454513, 0.08664254259201698, 0.049885612024809234, 0.06371521856635809, 0.04672903902246617, 0.03464745001110714, 0.023946819710545242, 0.031415574994753115, 0.06901613451191224, 0.08681568564497866, 0.009857185959845083, 0.030979665280028712, 0.03324906938360073, 0.027451365349406842, 0.011131212322652573, 0.06392766576027498, 0.05135298641107511, 0.042791934465640225, 0.014280439918366028, 0.05558179582294542, 0.1258426418644376, 0.06605345872230828, 0.9079572418704629, 20.385168939828873, 36.41043663024902, 30.879649110138416, 37.90492683649063, 18.78982074558735, 0.5429249606095254, 0.3431588737294078, 1.4223990496248007, 0.9890701237600297, 8.069648835808039, 3.3762461319565773, 12.243076991289854, 7.755561964586377, 3.3548931777477264, 0.11619412834988907, 5.167765449732542, 31.26120563596487, 48.64028178155422, 54.65150982141495, 52.1174143999815, 52.66239255666733, 52.19884783029556, 53.21608364582062, 53.12309503555298, 50.045491978526115, 49.900347366929054, 49.59214210510254, 45.50178699195385, 46.00432902574539, 41.29588767886162, 39.3871209025383, 38.14135394990444, 38.591861575841904, 38.052396923303604, 38.98960903286934, 38.79186764359474, 39.345311746001244, 39.93557967245579, 39.508995562791824, 40.94022676348686, 40.96309393644333, 39.484779462218285, 41.44143506884575, 39.180070012807846, 39.1080866754055, 37.9448626935482, 37.131903916597366, 36.35126620531082, 38.405420780181885, 36.89245216548443, 36.69710464775562, 37.33599476516247, 37.88992904126644, 38.7773372232914, 39.99606862664223, 40.036954432725906, 42.56096139550209, 42.00438626110554, 43.27509507536888, 45.81321068108082, 48.51880609989166, 49.19105842709541, 53.62618423998356, 48.36867235600948, 49.32763449847698, 51.316721364855766, 52.444341257214546, 50.984379798173904, 49.77919086813927, 51.770785599946976, 50.746204778552055, 48.669627606868744, 50.41559971868992, 50.58603957295418, 51.02250315248966, 49.34666007757187, 47.812264412641525, 38.31747829914093, 33.97558808326721, 36.26444846391678, 35.409148558974266, 37.22296603024006, 36.45752750337124, 40.991482213139534, 44.643329456448555, 47.11128182709217, 43.403322994709015, 38.87122258543968, 35.95367453992367, 36.06769502162933, 35.459062680602074, 38.94332371652126, 44.37606319785118, 46.39970161020756, 48.9837871491909, 47.284966707229614, 46.61526024341583, 48.52658808231354, 45.30678905546665, 46.001467779278755, 42.23504528403282, 36.46932207047939, 33.121477514505386, 32.52990245819092, 37.31953784823418, 40.00377081334591, 42.82677233219147, 41.702469661831856, 42.93698541820049, 43.155971467494965, 42.05403819680214, 44.64437820017338, 47.22656764090061, 31.25612910836935, 3.684204644523561, 1.6704002232290804, 3.6018984485417604, 5.410589519888163, 6.691184928640723, 5.587694216519594, 7.313122730702162, 4.862613324075937, 2.6455168426036835, 0.06921600972418673, 0.2971435210201889, 26.258528977632523, 35.096375942230225, 25.077292062342167, 34.47768174111843, 10.728681553155184, 0.263024884625338, 0.0980185680964496, 0.009389784136146773, 0.03639635440777056, 0.020655413318309, 0.03866259881760925, 0.038303918845485896, 0.04857440035266336, 0.0453995890711667, 0.07521280043874867, 0.09545064065605402, 0.04743423516629264, 0.020678256623796187, 0.035364943541935645, 0.035073724793619476, 0.039466571106459014, 0.028989792954234872, 0.06685870379442349, 0.029508318548323587, 0.012915003226225963, 0.0037775298187625594, 0.04655646000173874, 0.055018936182023026, 0.039934402448125184, 0.054595548353972845, 0.027565852760744747, 0.08853160528815351, 0.05261189151497092, 0.039120912115322426, 0.03651794417237397, 0.07232771618873812, 0.050938363347086124, 0.07454650767613202, 0.05094701307825744, 0.07115154570783488, 0.053853734643780626, 0.059574201513896696, 0.03341034549521282, 0.025329502059321385, 0.029246900739963166, 0.023898359322629403, 0.015611250782967545, 0.0417157535412116, 0.02657365326740546, 0.09720979040139355, 1.8780867476016283, 27.89721004664898, 39.37381021678448, 32.05243907868862, 49.08141911029816, 21.501256451010704, 0.24788907961919904, 0.47075528476852924, 1.1377943214029074, 1.670336457900703, 9.26350962370634, 4.864273834973574, 15.33251641318202, 6.969370851293206, 4.105761861428618, 0.9279180457815528, 7.086064014583826, 32.69716568291187, 50.83981655538082, 55.73227822780609, 51.925156116485596, 54.29026700556278, 51.16735517978668, 53.42150442302227, 54.63237784802914, 51.618387177586555, 51.938189417123795, 52.10759572684765, 47.03758478164673, 46.80192142724991, 44.16133671998978, 42.49412298202515, 40.972574427723885, 40.30099466443062, 40.99965937435627, 39.14728917181492, 39.186886847019196, 41.629638969898224, 41.23544052243233, 39.46221247315407, 42.2785909473896, 42.01574005186558, 40.40727496147156, 43.14017951488495, 41.837913393974304, 41.41852989792824, 40.27431629598141, 39.82360728085041, 39.37526173889637, 39.57256615161896, 38.55531133711338, 39.832658395171165, 39.62492734193802, 39.73421707749367, 40.11954680085182, 41.14648349583149, 42.14317761361599, 43.89152839779854, 43.46425272524357, 45.91113142669201, 48.17813917994499, 49.67772111296654, 51.284373700618744, 54.337107092142105, 49.293310940265656, 49.88120399415493, 52.83209525048733, 52.99074053764343, 51.59289434552193, 51.85554005205631, 53.40710699558258, 52.42889128625393, 49.807761535048485, 51.77330106496811, 51.663019582629204, 51.91203162074089, 50.440963357687, 48.47392290830612, 38.836496248841286, 35.09280413389206, 38.2213244587183, 37.71597437560558, 38.474417477846146, 38.62441062927246, 41.69233180582523, 45.814270824193954, 47.878996431827545, 44.3913421779871, 40.62398873269558, 37.595460042357445, 37.7652957290411, 36.92255415022373, 41.30711227655411, 47.07638069987297, 49.20375734567642, 49.2557879537344, 48.586921244859695, 47.35911212861538, 48.13468091189861, 48.164182528853416, 47.18060530722141, 42.99654722213745, 36.8228816986084, 35.289010405540466, 35.102052837610245, 39.35022868216038, 42.51145005226135, 44.54652205109596, 43.42851564288139, 45.016188248991966, 44.15631718933582, 44.40847545862198, 46.63678228855133, 48.14012601971626, 32.57038928568363, 5.024795271456242, 2.795182974077761, 5.600416883826256, 4.314814293757081, 3.8658291986212134, 5.954048233106732, 10.063778031617403, 5.243365243077278, 1.2323523662053049, 0.13517192797735333, 0.5454460065811872, 27.227121703326702, 41.06748193502426, 29.6401347219944, 39.59771700203419, 17.089999057352543, 0.5548164225183427, 0.06982046674238518, 0.03994611724920105, 0.060485158101073466, 0.020840966935793404, 0.023219453760248143, 0.03855866474623326, 0.07931183048640378, 0.023488588049076498, 0.06163768746773712, 0.0362634431803599, 0.058059333387063816, 0.04482311473111622, 0.031647971118218265, 0.04112054739380255, 0.009475543010921683, 0.042710814013844356, 0.042755717659019865, 0.020866400336672086, 0.053395150462165475, 0.0837385855265893, 0.1458247602568008, 0.15315532393287867, 0.129852109530475, 0.1967642331146635, 0.11121547518996522, 0.18075607804348692, 0.17112859699409455, 0.20446327311219648, 0.1977186943986453, 0.19239182554883882, 0.18408554547932, 0.1753082688082941, 0.08744926453800872, 0.18462985142832622, 0.17760649236151949, 0.1389834054862149, 0.09059273492312059, 0.13182185852201656, 0.07842047401936725, 0.17615097749512643, 0.15381475182948634, 0.11455229730927385, 0.181881248136051, 0.17191812337841839, 1.4723505754955113, 30.59850599616766, 48.73436473309994, 39.34431999921799, 53.49569544196129, 28.56378547847271, 0.9987380518577993, 1.680319590959698, 5.2294432651251554, 7.0716846361756325, 20.17954297363758, 7.897277735173702, 27.406464479863644, 17.72369295358658, 5.999553641304374, 0.45884512073826045, 7.09090780466795, 34.55181196331978, 50.78977324068546, 57.27132864296436, 52.98712693154812, 54.88160267472267, 52.943623065948486, 55.75023226439953, 57.97665059566498, 52.84946031868458, 55.389787405729294, 55.74318744242191, 47.859891057014465, 50.9354954212904, 45.51502168178558, 44.765603095293045, 42.16331273317337, 42.49820776283741, 42.46407799422741, 42.15160936117172, 41.26452036201954, 42.50063203275204, 44.23040561378002, 42.78447300195694, 44.668035730719566, 44.60645243525505, 41.90015785396099, 45.85670314729214, 44.9353551864624, 43.33488866686821, 41.996923461556435, 40.85359901189804, 40.06508432328701, 41.50944001972675, 40.77504962682724, 41.3782824575901, 42.359234020113945, 41.948962435126305, 43.09246927499771, 42.54003591835499, 42.29001313447952, 46.72167733311653, 45.58939889073372, 47.63283044099808, 50.26431083679199, 53.319042921066284, 54.1264083981514, 57.69011177122593, 51.672108694911, 51.860867366194725, 55.00701494514942, 54.240843057632446, 54.04052160680294, 53.378084152936935, 55.58325782418251, 54.51814837753773, 50.389012545347214, 53.22880156338215, 54.184081703424454, 54.84379470348358, 53.020576536655426, 52.299702018499374, 42.45259501039982, 36.479638516902924, 40.8776631206274, 38.59086602926254, 40.73718085885048, 39.13383789360523, 45.184534415602684, 48.589467108249664, 51.62432625889778, 46.976183876395226, 41.58893555402756, 40.38759581744671, 39.01220642030239, 38.568443432450294, 43.14696215093136, 47.66485892236233, 51.53213560581207, 51.23707003891468, 48.717581033706665, 48.14273647964001, 51.127799302339554, 48.76678079366684, 50.04370987415314, 45.19867345690727, 39.86567482352257, 37.39668890833855, 36.97291664779186, 41.01789839565754, 44.054847434163094, 46.79073482751846, 46.43157809972763, 45.55724881589413, 47.199824675917625, 46.062823086977005, 48.33870716392994, 49.20925945043564, 33.18506330251694, 4.964690571650863, 4.245458515360951, 7.947650207206607, 11.718263402581215, 13.934384286403656, 12.013633903115988, 17.115064412355423, 14.48811337351799, 7.0613292418420315, 0.20538016688078642, 0.6136251543648541, 37.60310523211956, 43.066300079226494, 33.91193389892578, 49.66994673013687, 21.499312855303288, 0.5939830583520234, 0.15893796051386744, 0.07157503001508303, 0.12614353821845725, 0.09498224899289198, 0.16751482762629166, 0.15021158033050597, 0.2316570037510246, 0.12958578241523355, 0.13092108420096338, 0.1924120564945042, 0.13543022505473346, 0.11065938393585384, 0.09812671385589056, 0.15381911565782502, 0.1352660174597986, 0.09866114924079739, 0.15610163536621258, 0.10550922044785693, 0.11915146067622118], [0.0535212079557823, 0.0890653653186746, 0.03990662757132668, 0.03598223971494008, 0.06433739064959809, 0.011674076649796916, 0.023442565616278443, 0.029101183754391968, 0.023840616522647906, 0.07295202565728687, 0.058636928370106034, 0.08181167329894379, 0.0036953021754015936, 0.04681139143940527, 0.04880656641034875, 0.047572445328114554, 0.09235164718120359, 0.1191108429338783, 0.04306599475967232, 0.01629114711249713, 0.06862784284749068, 0.0681054599408526, 0.017271941651415545, 0.057378924975637347, 0.025718992292240728, 0.14193739072652534, 4.656025534495711, 32.82164700329304, 28.179791383445263, 31.696553975343704, 37.07118697464466, 2.2224332951009274, 0.08598015352617949, 0.3576801507733762, 0.4668895265785977, 4.037533197551966, 8.054157067090273, 9.867414068430662, 5.531515181064606, 4.063727566972375, 1.6699987510219216, 0.4108898533741012, 13.994595855474472, 40.05699835717678, 50.26532918214798, 54.64867137372494, 52.6368161290884, 52.57282376289368, 52.94610433280468, 54.785426035523415, 51.811131834983826, 48.43230754137039, 49.516412168741226, 48.71492877602577, 44.954376965761185, 42.96173729002476, 37.94379875063896, 38.99955689907074, 38.01954388618469, 43.791255578398705, 45.925061479210854, 48.7712911516428, 44.8343376070261, 41.401506811380386, 37.98328623175621, 38.95451411604881, 39.95900921523571, 39.65868853032589, 40.37881828844547, 40.9957379847765, 40.21206043660641, 39.20954503118992, 38.41451369225979, 37.91643641889095, 39.421528056263924, 37.46887743473053, 37.75117948651314, 37.11062505841255, 38.20485234260559, 38.310965448617935, 41.59970037639141, 41.12966559827328, 42.486249804496765, 42.59357504546642, 45.954304710030556, 45.85267536342144, 49.32049088180065, 49.4795161485672, 51.407384499907494, 48.86032797396183, 48.422663658857346, 54.70526933670044, 52.63705551624298, 50.75941666960716, 51.638761684298515, 53.816242441534996, 51.2821052223444, 50.22567071020603, 48.06865945458412, 50.45787625014782, 51.161989867687225, 49.75290767848492, 47.331711798906326, 42.11229287087917, 35.14833055436611, 34.51188750565052, 37.62642838060856, 37.34191484749317, 36.686130836606026, 42.3648539185524, 45.63250757753849, 48.558365777134895, 48.198422491550446, 43.27148526906967, 39.23514045774937, 34.07593309879303, 35.36059856414795, 35.21204933524132, 38.38438890874386, 47.769243121147156, 48.33337604999542, 47.24675215780735, 46.253432258963585, 46.20579041540623, 46.43796555697918, 45.64533568918705, 46.9165650755167, 44.63918387889862, 38.81759226322174, 32.605431005358696, 38.20386819541454, 44.67219650745392, 44.91266280412674, 40.945854261517525, 41.87362387776375, 45.880394876003265, 45.14650605618954, 46.696469485759735, 45.364758744835854, 19.531229361891747, 0.7481526012998074, 1.879576148930937, 4.334733299911022, 1.705779768526554, 3.0993568897247314, 5.6763220857828856, 6.916446341201663, 5.177358984947205, 0.1312689288170077, 0.21495283290278167, 5.674275420606136, 42.00973637402058, 29.29331213235855, 33.17655175924301, 21.06615509837866, 2.105928221717477, 0.13456874003168195, 0.0353672330675181, 0.04029388022900093, 0.08056859820499085, 0.05868504180398304, 0.05404100818850566, 0.037569333653664216, 0.07017441181233153, 0.07303663049242459, 0.04026958231406752, 0.028102744654461276, 0.11778256928664632, 0.07461873348802328, 0.06659936771029606, 0.01616580022528069, 0.07328887906624004, 0.018399516302451957, 0.0649061355215963, 0.05858450305822771, 0.03254395858675707, 0.03218988735170569, 0.09484445443376899, 0.028283875071792863, 0.09117995185079053, 0.06547902157763019, 0.043297440934111364, 0.05211722782405559, 0.035245813996880315, 0.028281938066356815, 0.01818885953980498, 0.010567277495283633, 0.08890607816283591, 0.018094708830176387, 0.05995150197122712, 0.009025696690514451, 0.011328041946399026, 0.0727189467579592, 0.06900581123773009, 0.04190935018414166, 0.08250604150816798, 0.0643790845060721, 0.04608834664395545, 0.08230586201534607, 0.0917564299015794, 0.027209881627641153, 0.1320072470116429, 7.592405369505286, 40.31487911939621, 29.10257376730442, 37.818492874503136, 43.0278879404068, 2.3860572651028633, 0.03209219103155192, 0.21290293196216226, 0.713993621757254, 4.972265940159559, 8.121359311044216, 9.56036964431405, 8.245710488408804, 9.801223520189524, 3.0262210266664624, 1.0788072366267443, 17.049871310591698, 43.3278476446867, 53.10018226504326, 55.24129897356033, 53.20446766912937, 52.059554904699326, 54.36200335621834, 55.94238415360451, 53.90146806836128, 50.33906042575836, 51.73052676022053, 51.23661786317825, 48.38908486068249, 44.7370932251215, 40.63754640519619, 39.89972099661827, 39.32810626924038, 44.39669989049435, 45.89309759438038, 49.19908359646797, 45.03736071288586, 42.592891082167625, 40.8758582174778, 42.26346395909786, 41.73507571220398, 41.33673168718815, 42.07345135509968, 41.65624514222145, 42.5802643597126, 40.65955862402916, 40.045443177223206, 39.7456506639719, 41.42520993947983, 38.65529157221317, 38.434971794486046, 39.87788736820221, 39.946492686867714, 41.3766523450613, 43.337457329034805, 43.45310792326927, 45.75321950018406, 44.4116634875536, 47.716779336333275, 47.22044616937637, 51.24890640377998, 50.20142801105976, 52.5910209864378, 50.21905146539211, 49.736990332603455, 55.75975455343723, 53.27974162995815, 52.255153208971024, 52.694299444556236, 54.06211584806442, 53.71028512716293, 49.752846881747246, 51.244415044784546, 52.46300585567951, 51.38844631612301, 51.34148843586445, 49.046232998371124, 43.65857049822807, 36.06324166059494, 36.43559128046036, 39.71487231552601, 39.682308062911034, 37.553441897034645, 44.81136403977871, 48.20004880428314, 51.510244980454445, 49.674856066703796, 44.781877622008324, 40.090641751885414, 36.40556909143925, 36.650336757302284, 37.95916512608528, 41.45419858396053, 48.226856365799904, 49.062921702861786, 48.438801392912865, 49.710125774145126, 47.11265355348587, 48.433964252471924, 48.56794886291027, 48.957344368100166, 44.76413257420063, 38.8664386421442, 33.27637240290642, 38.99598129093647, 46.18466354906559, 47.047555446624756, 43.341975286602974, 43.586549162864685, 47.039150297641754, 46.47026002407074, 46.68072693049908, 48.164687901735306, 21.35598074644804, 2.1748482109978795, 3.5821791691705585, 5.287212990224361, 5.4175683204084635, 6.885436680167913, 6.035142531618476, 9.341572634875774, 1.332464050501585, 0.44438876677304506, 0.12013722574920394, 5.613603601232171, 46.92662313580513, 32.22273074090481, 35.255393609404564, 28.384585194289684, 4.08402512781322, 0.03060681770875817, 0.028411272141966037, 0.026763281275634654, 0.06248878242331557, 0.04150803011725657, 0.049820581334643066, 0.12219859287142754, 0.0702026134240441, 0.043606382168945856, 0.05630174957332201, 0.022971220205363352, 0.03034937966731377, 0.054861474709468894, 0.08173981113941409, 0.0824200340139214, 0.0947558568441309, 0.03752062650164589, 0.05546052889258135, 0.0888831086922437, 0.06384558422723785, 0.18297973059816286, 0.21168336068512872, 0.12964359571924433, 0.12579475849634036, 0.1715257647447288, 0.15301542909583077, 0.12578232010127977, 0.10456982476171106, 0.08630318072391674, 0.14724416221724823, 0.0952134131512139, 0.17849226045655087, 0.11810121039161459, 0.11620842953561805, 0.07070074294460937, 0.20524263207335025, 0.24082148855086416, 0.27395045617595315, 0.17979085561819375, 0.1459957065526396, 0.24188795476220548, 0.08844358657370321, 0.18397226405795664, 0.14690693031297997, 0.19059915299294516, 0.22663999639917165, 7.868776889517903, 47.1755363792181, 37.12652340531349, 40.186700597405434, 50.69131292402744, 3.711824412457645, 0.18556466064183041, 1.4233577856794, 2.1072493633255363, 9.01150619611144, 19.727289341390133, 20.540177822113037, 12.934457492083311, 8.817398361861706, 3.2259634835645556, 1.0238742968067527, 16.921438202261925, 45.353294759988785, 52.9212536662817, 57.96871282160282, 53.47173772752285, 55.83109192550182, 56.62630945444107, 58.98447431623936, 56.1814521253109, 52.36058235168457, 53.70441064238548, 54.55164358019829, 48.6336587369442, 47.200527638196945, 41.637546345591545, 41.75047628581524, 42.04626001417637, 48.01674664020538, 50.50160050392151, 54.04093578457832, 48.49224552512169, 45.13991340994835, 42.2015804797411, 42.839076071977615, 44.17947694659233, 43.34853753447533, 43.65907587110996, 44.30544778704643, 45.13293318450451, 44.103538021445274, 41.53180941939354, 42.09399685263634, 43.60957972705364, 41.32198087871075, 40.32444700598717, 41.29896931350231, 42.59791061282158, 42.68665865063667, 44.72605861723423, 43.937198147177696, 48.14372442662716, 47.36772246658802, 49.96139109134674, 49.437562599778175, 54.15449269115925, 52.71715521812439, 54.70847636461258, 51.74067601561546, 52.15041182935238, 58.65285091102123, 55.46557433903217, 54.248172864317894, 54.74824883043766, 56.08053334057331, 53.28866735100746, 51.915679425001144, 52.641527876257896, 54.20878417789936, 53.810865730047226, 52.19044268131256, 49.73306894302368, 46.179583221673965, 37.895617336034775, 37.481994330883026, 41.0706851631403, 41.20023161172867, 39.1554207354784, 46.284936368465424, 49.850182458758354, 51.48129813373089, 52.44557999074459, 47.54937931895256, 42.59833998978138, 36.96251280605793, 38.46005044877529, 41.244005262851715, 42.68057897686958, 50.90834207832813, 50.99173240363598, 50.223854407668114, 49.55422393977642, 48.16547065973282, 49.64646399021149, 47.963959872722626, 50.71561262011528, 47.47829273343086, 41.88870146870613, 35.510318130254745, 42.09590055048466, 47.780072540044785, 50.33958099782467, 44.71905559301376, 46.805656626820564, 51.12730912864208, 49.91471439599991, 49.07040350139141, 49.52154569327831, 20.839588455855846, 1.8441417440772057, 4.689391069114208, 11.538675539195538, 7.49486175365746, 11.141974925994873, 13.688677120953798, 17.560258023440838, 10.332099683582783, 1.7146350746043026, 0.3793720289831981, 9.689642507582903, 54.525326192379, 35.80511391162872, 45.44361591339111, 36.09428979456425, 5.235742377117276, 0.20323574601206928, 0.2057072610477917, 0.12302689647185616, 0.24479974148562178, 0.13830144598614424, 0.09191878212732263, 0.22553600720129907, 0.1221365641686134, 0.120541518117534, 0.15367607411462814, 0.15071615169290453, 0.19931968505261466, 0.23891663295216858, 0.21335121884476393, 0.24620403331937268, 0.2621234720572829, 0.09748894924996421, 0.12357886138488539, 0.2182796286069788, 0.23087896581273526], [0.0724650728807319, 0.03884025783918332, 0.0609431485645473, 0.07736117695458233, 0.007421859900205163, 0.07605050705024041, 0.022812918250565417, 0.055658593264524825, 0.03433937337831594, 0.05475357385876123, 0.011939868491026573, 0.05841810241690837, 0.048755469542811625, 0.08261560476967134, 0.042553571474854834, 0.04060700717673171, 0.007663524984309333, 0.02817457527271472, 0.012823611450585304, 0.013878343379474245, 0.04890778422122821, 0.041094947009696625, 0.07953814099892043, 0.008565892603655811, 0.01728547842503758, 0.04039965111587662, 0.14299140369985253, 19.42576602101326, 37.43975579738617, 23.020770214498043, 38.73778894543648, 16.948620043694973, 0.08795759858912788, 0.3184260305715725, 0.604103934019804, 6.623081183061004, 4.607330672442913, 5.6311277858912945, 2.215806688182056, 7.713303007185459, 3.83722267113626, 0.25625204492826015, 3.5314136557281017, 23.610376976430416, 46.09284147620201, 52.18362584710121, 51.328793317079544, 50.79511195421219, 50.147220119833946, 54.1086595505476, 49.4011415541172, 50.03345802426338, 51.657772064208984, 50.7023361325264, 45.603819116950035, 42.21405141055584, 38.69448646903038, 42.03749768435955, 48.04808735847473, 50.39803706109524, 52.98285596072674, 52.57345832884312, 50.764402002096176, 47.521667405962944, 42.180791795253754, 38.332035318017006, 40.37510968744755, 39.18374061584473, 39.31856878101826, 40.48745445907116, 43.34346480667591, 42.19418987631798, 39.4835901260376, 37.466411367058754, 39.03144858777523, 37.47702419757843, 36.56124293804169, 38.358489498496056, 39.14047233760357, 39.875223711133, 42.31550216674805, 44.749165177345276, 45.39272524416447, 44.7041679918766, 44.77620452642441, 46.161575987935066, 48.80507133901119, 49.93284322321415, 53.443547040224075, 47.843392342329025, 48.33857797086239, 52.64740616083145, 50.82666926085949, 48.844425827264786, 54.22807194292545, 50.28775177896023, 50.641664788126945, 47.30138562619686, 51.37573979794979, 50.25074176490307, 52.348453402519226, 50.85343882441521, 48.3515352755785, 42.05018140375614, 36.72039359807968, 34.659342393279076, 36.654341742396355, 37.174153849482536, 35.198499262332916, 40.71179062128067, 48.01327742636204, 50.32072260975838, 48.53063866496086, 46.67938180267811, 45.032968148589134, 39.03690509498119, 35.934926345944405, 36.18089474737644, 35.05137495696545, 40.83277992904186, 44.54358100891113, 47.1873689442873, 47.639217898249626, 46.040571480989456, 45.15669330954552, 46.27653121948242, 47.72127449512482, 46.49555526673794, 44.46966737508774, 35.25416247546673, 38.8720965385437, 40.70149317383766, 46.110286340117455, 43.840820118784904, 44.22346718609333, 45.992393866181374, 45.78731507062912, 44.884479716420174, 37.70572632551193, 8.002270851284266, 0.7790634676348418, 3.133524893783033, 3.6287812935188413, 3.106104377657175, 3.003551918081939, 3.752078264951706, 7.85174572840333, 1.8575044395402074, 0.20917473826557398, 0.05413448539911769, 17.362617328763008, 33.256355077028275, 19.830254316329956, 35.04903428256512, 12.762392275035381, 0.27629130869172513, 0.07727775213425048, 0.052501764221233316, 0.13569113449193537, 0.053770833037560806, 0.061436060786945745, 0.028792784287361428, 0.04764965837239288, 0.03997180669102818, 0.03469443538051564, 0.025835722844931297, 0.03939348811400123, 0.10740524448920041, 0.03548557964677457, 0.023519465103163384, 0.0557307263079565, 0.06077128571632784, 0.04678087803767994, 0.038444748788606375, 0.036977712079533376, 0.07238509904709645, 0.023805488817743026, 0.024189761752495542, 0.04474108885915484, 0.050135567362303846, 0.009862790102488361, 0.08144017643644474, 0.0053691494667873485, 0.055079079829738475, 0.016796835407149047, 0.03495017204841133, 0.02721892098634271, 0.020818394514208194, 0.036488477198872715, 0.045187887735664845, 0.014203299233486177, 0.030679921110277064, 0.005365378428905387, 0.036542138186632656, 0.009868954566627508, 0.09298921882873401, 0.06524181633722037, 0.03492881303827744, 0.04183266035397537, 0.009984395637729904, 0.03330286395794246, 0.05548550216190051, 0.37578760413452983, 25.724950209259987, 40.75561746954918, 24.843027032911777, 52.32657417654991, 16.20912842452526, 0.1515452197054401, 0.04185747035080567, 0.604371641529724, 1.1888677370734513, 7.082248069345951, 5.970487575978041, 7.825230276212096, 13.898618705570698, 5.695971781387925, 0.8990561601240188, 4.439991926774383, 28.00978660583496, 46.97412058711052, 53.59840773046017, 51.557305455207825, 54.39386084675789, 52.32041850686073, 56.06418661773205, 51.23876854777336, 51.97168081998825, 53.00951153039932, 51.733019426465034, 47.595140263438225, 43.525254651904106, 40.393561497330666, 42.173271998763084, 47.222729846835136, 53.03522855043411, 52.78066121041775, 54.123311564326286, 50.78724257647991, 48.861961886286736, 44.009409472346306, 40.15934966504574, 42.14202247560024, 41.30063742399216, 42.87148453295231, 43.75372879207134, 44.545032531023026, 42.79360011219978, 40.93775309622288, 39.92710992693901, 40.57951591908932, 38.93918573856354, 38.350445330142975, 40.354689583182335, 41.64912052452564, 42.09742046892643, 44.622027799487114, 45.37751846015453, 45.66011309623718, 45.525269731879234, 47.436259388923645, 48.114135414361954, 49.75179813802242, 50.753245800733566, 54.54788938164711, 48.18555638194084, 50.06968528032303, 54.46189619600773, 53.037975803017616, 51.31639838218689, 53.07951897382736, 51.837054044008255, 51.799143478274345, 50.26428043842316, 53.901418671011925, 52.54766531288624, 53.42763349413872, 52.73773491382599, 51.14812821149826, 43.73533017933369, 39.619641825556755, 36.65194407105446, 38.59487481415272, 39.7217271476984, 36.96423031389713, 44.05821405351162, 49.9624702334404, 52.00099624693394, 48.66612799465656, 48.69096726179123, 44.720214530825615, 40.772214978933334, 37.1989931166172, 36.56896032392979, 38.7663634121418, 43.55878405272961, 46.793934255838394, 49.622099697589874, 49.41715009510517, 46.93193905055523, 45.845269560813904, 47.299390733242035, 49.61066611111164, 48.41151885688305, 46.12759441137314, 37.71233417093754, 40.88596187531948, 44.24226097762585, 47.954817563295364, 45.60677155852318, 46.17371253669262, 47.9341808706522, 47.192270681262016, 46.104309260845184, 39.27250385284424, 9.921305626630783, 0.9081333386711776, 2.7132890559732914, 5.610693907365203, 5.800765408203006, 6.215099450200796, 5.397151065990329, 4.745256146416068, 0.6455936701968312, 0.25930345931556076, 0.04985549196135253, 18.898301124572754, 43.67765687406063, 25.162880569696426, 39.81058157980442, 17.269488126039505, 0.5298493278678507, 0.1384497864637524, 0.017837337582022883, 0.08778588788118213, 0.07992422848474234, 0.04516031694947742, 0.05110152080305852, 0.028777473780792207, 0.0031004279071567, 0.07806644731317647, 0.03137572166451719, 0.08821080453344621, 0.1337513979524374, 0.07216607642476447, 0.004672810391639359, 0.06961944120121188, 0.025159296055790037, 0.05860574332473334, 0.03680351146613248, 0.03770382194488775, 0.03540790647093672, 0.11213865494937636, 0.10857889908947982, 0.14482796686934307, 0.13785084360279143, 0.13413133303401992, 0.280128835584037, 0.141288471641019, 0.195162040181458, 0.14044513955013826, 0.11446649019489996, 0.13159832364181057, 0.1297985264682211, 0.21552541467826813, 0.1820313252392225, 0.09465846480452456, 0.13724900636589155, 0.10193709298619069, 0.11755718645872548, 0.0967852448229678, 0.1564574654912576, 0.15261306631146, 0.1858899142825976, 0.13478399254381657, 0.15651658497517928, 0.11494021789985709, 0.15585010667564347, 0.4174681019503623, 30.179939456284046, 50.867851451039314, 30.315179899334908, 50.72122111916542, 22.817678712308407, 0.2648653811775148, 0.8842212217859924, 2.0762855373322964, 14.222356583923101, 11.090225502848625, 13.690694812685251, 10.198323111981153, 16.525909826159477, 7.363448655232787, 1.06800690991804, 5.192956672981381, 26.368124596774578, 51.20863996446133, 53.54225814342499, 54.46216598153114, 54.81380291283131, 54.12935324013233, 59.01917405426502, 55.11500895023346, 54.02564540505409, 55.02944514155388, 55.53989835083485, 50.27496926486492, 45.377047285437584, 42.91498839855194, 45.92010274529457, 52.60584019124508, 54.81406889855862, 56.05425775051117, 56.947540417313576, 52.99256443977356, 50.784818306565285, 47.158919870853424, 41.40968017280102, 44.581400379538536, 42.814267203211784, 45.411245450377464, 46.45090386271477, 47.95984849333763, 45.280053690075874, 43.30755673348904, 41.17642968893051, 42.15871877968311, 41.229368448257446, 40.37968464195728, 43.288690745830536, 43.342070281505585, 42.85378888249397, 47.22806856036186, 48.58462996780872, 48.664543479681015, 48.31156522035599, 49.13609057664871, 50.34056894481182, 53.08770373463631, 54.129630625247955, 58.23746100068092, 49.372270703315735, 51.383631974458694, 55.071185901761055, 53.80713813006878, 52.84099817276001, 56.545423194766045, 51.83256648480892, 54.82467032968998, 52.7171628177166, 55.48333838582039, 53.78467753529549, 55.79653277993202, 54.82395216822624, 51.464864015579224, 45.690454468131065, 41.64018340408802, 38.449916392564774, 40.26231274008751, 41.41962043941021, 38.85132685303688, 46.60249672830105, 51.07270985841751, 53.17335493862629, 50.54590232670307, 51.03564664721489, 47.468614652752876, 43.1497398018837, 40.13085879385471, 39.507426247000694, 39.90898869931698, 44.627773091197014, 48.39101515710354, 50.65992660820484, 52.62024141848087, 48.32036554813385, 48.06936241686344, 47.591503858566284, 51.18733070790768, 50.97231924533844, 48.168476298451424, 39.73987117409706, 42.74484492838383, 46.03373944759369, 49.794777631759644, 49.77638281881809, 46.73476003110409, 51.10221907496452, 48.950645327568054, 47.851033732295036, 38.90548914670944, 10.66305622458458, 1.475618400145322, 6.823828211054206, 10.004364419728518, 9.11857970058918, 9.302631374448538, 10.237644352018833, 18.142031505703926, 6.283832062035799, 2.044443958438933, 0.113259008503519, 26.47977590560913, 44.17357586324215, 28.53947628289461, 47.96516440808773, 22.324782460927963, 0.6622001447249204, 0.2942972065648064, 0.10689671005820855, 0.18992249242728576, 0.20953828672645614, 0.2750611840747297, 0.1360423187725246, 0.1141810676199384, 0.13500441040378064, 0.1238138995540794, 0.11141730967210606, 0.12867982790339738, 0.2425651645171456, 0.1501622868818231, 0.10948013354209252, 0.1848105643875897, 0.15227760071866214, 0.14424685039557517, 0.11273771655396558, 0.1678795338375494, 0.15041331091197208], [0.05802177700388711, 0.037139255364309065, 0.021442100987769663, 0.029608399017888587, 0.06362937434460036, 0.0532102555007441, 0.09385726443724707, 0.018275423644809052, 0.09661239862907678, 0.012687891194218537, 0.03209702241292689, 0.03639473652583547, 0.0270574482055963, 0.01667306001763791, 0.027919463864236604, 0.05425943709269632, 0.0191955253467313, 0.02760192484856816, 0.06617326362174936, 0.057823690367513336, 0.0004315019083378502, 0.025820399350777734, 0.024416376545559615, 0.0834534820751287, 0.01612309704796644, 0.05118579538248014, 0.1090990036027506, 3.770526275038719, 35.89071951806545, 27.96193577349186, 32.566000521183014, 35.47645054757595, 1.913761014584452, 0.17027705674991012, 0.4508414736483246, 1.0601589060388505, 5.65375367179513, 4.51877879910171, 6.972706597298384, 17.129971012473106, 4.533082656562328, 1.398257757537067, 0.5091467325109988, 8.482359889894724, 30.932682864367962, 48.86418476700783, 51.11321188509464, 47.98729062080383, 50.713146552443504, 50.18523707985878, 50.93910522758961, 51.40352010726929, 49.75193873047829, 49.00895319879055, 42.91170917451382, 41.460624039173126, 43.25531713664532, 45.99760338664055, 53.028901889920235, 52.816683277487755, 53.946944028139114, 52.77618125081062, 50.1202529668808, 45.26857830584049, 40.45307770371437, 39.73524682223797, 40.68021051585674, 39.782364293932915, 40.99166080355644, 42.83355876803398, 45.34116581082344, 45.5303880572319, 42.20582105219364, 39.27339680492878, 39.626587852835655, 37.73819178342819, 37.01630271971226, 37.47761696577072, 39.11535568535328, 40.11065907776356, 43.80458526313305, 43.483886271715164, 43.27834390103817, 46.136098355054855, 46.05157569050789, 47.447791770100594, 50.71718953549862, 50.33597119152546, 52.29373253881931, 47.239365354180336, 44.32561710476875, 49.79641154408455, 49.763607904314995, 50.85488274693489, 51.271503791213036, 50.18241763114929, 52.81079739332199, 51.54516510665417, 47.730378806591034, 49.305565282702446, 50.73159836232662, 47.17366687953472, 48.80727902054787, 41.74476519227028, 36.89647234976292, 37.654904052615166, 37.915125489234924, 37.26893976330757, 36.6258242726326, 43.233396112918854, 47.55159839987755, 48.85643318295479, 50.29326528310776, 47.48786821961403, 45.57481907308102, 46.52943044900894, 40.18226243555546, 37.10654407739639, 36.674442663788795, 35.57144545018673, 39.48072507977486, 44.659930765628815, 45.13431251049042, 49.16200898587704, 48.997200429439545, 45.73700197041035, 48.72662454843521, 47.49359451234341, 47.23639391362667, 38.40680770576, 38.29885549843311, 44.5790559053421, 44.91861708462238, 45.93465596437454, 44.05137062072754, 46.51149921119213, 46.4970637857914, 43.391368836164474, 24.066874980926514, 2.6479757856577635, 0.7167160569224507, 1.7372481361962855, 3.0663252621889114, 3.3049225341528654, 8.102940749377012, 4.427015148103237, 4.059606213122606, 0.2270422107540071, 0.12728098343359306, 1.0746499034576118, 32.27605327963829, 25.51395893096924, 20.401152782142162, 28.826807364821434, 3.1232158094644547, 0.08319849497638643, 0.03779848659178242, 0.04395583724544849, 0.05402975722972769, 0.07034278285573237, 0.0198987455223687, 0.034762902214424685, 0.008611774028395303, 0.06326779999653809, 0.023817365035938565, 0.05485260233399458, 0.0165670720525668, 0.03982011912739836, 0.012332999885984464, 0.05139517008501571, 0.06625543421250768, 0.03268371241574641, 0.10290656791767105, 0.02216254641098203, 0.05780516265076585, 0.08418465338763781, 0.038377662349375896, 0.029292386971064843, 0.04357849968073424, 0.03412448822928127, 0.02962644062790787, 0.02940732338174712, 0.05049955740105361, 0.018870700296247378, 0.03144302703731228, 0.03892107772117015, 0.002578074454504531, 0.04311638287617825, 0.04244406758516561, 0.1031278095615562, 0.05980276073387358, 0.024050059873843566, 0.009355813253932865, 0.012216130180604523, 0.13618249562568963, 0.05392032384406775, 0.026931459360639565, 0.026910801680060104, 0.035795500516542234, 0.07018131378572434, 0.04110755609872285, 0.027267672667221632, 0.08402793406276032, 5.608389331027865, 44.070008620619774, 26.811087727546692, 39.91948753595352, 41.081385388970375, 1.695183680858463, 0.1692154590273276, 0.2680804836563766, 1.4065406005829573, 4.152217693626881, 6.4446584321558475, 7.924780659377575, 9.367678184062243, 8.286971524357796, 1.9255237584002316, 1.1259989230893552, 10.187244806438684, 32.42852009832859, 51.636797189712524, 50.77468045055866, 49.09549355506897, 50.88043637573719, 53.68870988488197, 53.4139010310173, 51.63407653570175, 52.19152182340622, 51.279965937137604, 46.57800704240799, 44.278419837355614, 43.592062667012215, 48.076361641287804, 55.669725984334946, 55.07256902754307, 54.5171832293272, 54.802532717585564, 52.45396614074707, 46.60608373582363, 41.869436502456665, 41.986702010035515, 42.185799926519394, 41.47380173206329, 42.166215777397156, 43.712656795978546, 45.91698691248894, 46.35351128876209, 45.13176664710045, 40.93619517982006, 41.861426532268524, 39.47560295462608, 39.4279383122921, 40.31291842460632, 41.24569997191429, 41.66842348873615, 44.87543240189552, 44.709221720695496, 45.6735035777092, 48.57223503291607, 47.22739219665527, 49.378186985850334, 51.562545374035835, 50.963404923677444, 54.298930540680885, 49.044656082987785, 44.95195269584656, 52.824127078056335, 52.17981465160847, 50.81071391701698, 52.16866984963417, 52.66452804207802, 55.21017104387283, 52.625481337308884, 49.08865012228489, 50.86373247206211, 52.75973193347454, 49.88321028649807, 50.18089771270752, 43.60274389386177, 39.07214440405369, 38.268244341015816, 38.239362090826035, 39.05606746673584, 37.18622960150242, 43.91444496810436, 48.24425183236599, 50.108458399772644, 52.32516065239906, 48.737932741642, 47.41231307387352, 47.564183324575424, 41.94813407957554, 38.086997866630554, 38.236379250884056, 37.990175262093544, 42.96278603374958, 45.823059752583504, 48.47623698413372, 49.733517318964005, 49.539659321308136, 45.34572936594486, 50.64844362437725, 46.80178843438625, 48.17516773939133, 39.838206097483635, 40.496171191334724, 47.172230556607246, 47.210490703582764, 47.15441711246967, 45.2077891677618, 47.36590996384621, 48.05115379393101, 43.82062420248985, 26.977725885808468, 2.862953287549317, 2.736131055280566, 3.424762641079724, 5.480877198278904, 7.235056394711137, 8.005746714770794, 6.405839715152979, 3.229264081455767, 0.46707458852324635, 0.37439408828504384, 1.2201723572798073, 36.859367340803146, 31.565842889249325, 21.521136984229088, 36.51976056396961, 5.971497846767306, 0.020267203290131874, 0.035353284401935525, 0.037920536487945355, 0.07674453387153335, 0.03375294683792163, 0.031943208596203476, 0.012233711659064284, 0.026973451931553427, 0.04904229848762043, 0.06032185963704251, 0.05463901594339404, 0.0630704258219339, 0.030772945610806346, 0.04353323980467394, 0.02603640143206576, 0.060721521003870293, 0.08885486997314729, 0.053343612016760744, 0.05585715487541165, 0.021082523016957566, 0.07800064850016497, 0.14047353412024677, 0.21758612128905952, 0.09810260889935307, 0.1329484090092592, 0.12981215229956433, 0.11363308803993277, 0.20342741307104006, 0.13606470194645226, 0.1873586096917279, 0.09541535895550624, 0.152550874336157, 0.11577859244425781, 0.11163679984747432, 0.14191466616466641, 0.20712362020276487, 0.12113453121855855, 0.10888583652558737, 0.12672355631366372, 0.24570605222834274, 0.19212328683352098, 0.1665470373700373, 0.16322606010362506, 0.07996473490493372, 0.18926290125818923, 0.193887950736098, 0.13885857624700293, 0.2512961905449629, 6.157486466690898, 49.871020540595055, 36.88965551555157, 42.09338888525963, 46.54018007218838, 3.215865050442517, 0.39799120801035315, 1.539823436178267, 3.6780560994520783, 13.591479286551476, 12.875761091709137, 14.704922139644623, 27.097546756267548, 14.847365096211433, 2.906467840075493, 1.4324970077723265, 9.546869918704033, 33.505173325538635, 52.92157664895058, 52.120351642370224, 48.64307463169098, 54.99703288078308, 55.29096230864525, 56.48795127868652, 55.25337852537632, 54.34469148516655, 53.455767184495926, 46.66573293507099, 47.3248303681612, 46.66830539703369, 49.307176396250725, 57.182607203722, 57.51644589006901, 56.065744534134865, 56.32107563316822, 54.43858824670315, 49.35053586959839, 43.21596644818783, 44.95484434068203, 44.572250470519066, 44.1310865432024, 43.81471551954746, 44.97429169714451, 49.01001334190369, 49.22993794083595, 47.14704550802708, 42.74968966841698, 45.44512443244457, 40.725686475634575, 41.8156161904335, 41.50517284870148, 44.74263332784176, 44.362938702106476, 49.14194606244564, 47.68070787191391, 48.699718192219734, 51.617323234677315, 49.77049693465233, 52.45376855134964, 56.03403523564339, 53.39652456343174, 55.7112767547369, 51.17126516997814, 47.28769116103649, 51.798003539443016, 53.418738171458244, 50.905454233288765, 54.43644516170025, 53.66540193557739, 56.22795782983303, 54.10221889615059, 50.761039182543755, 52.17605285346508, 54.72931444644928, 50.63523553311825, 51.617315635085106, 45.03331013023853, 38.87762904167175, 40.97641222178936, 41.27002626657486, 41.359040290117264, 39.10588659346104, 46.45537242293358, 50.573192462325096, 52.25601576268673, 53.4752943366766, 50.81552445888519, 48.446442782878876, 52.34511338174343, 42.74264484643936, 40.74998997151852, 40.697123408317566, 39.328231662511826, 42.92119346559048, 46.590086594223976, 50.39719730615616, 51.65685631334782, 51.08195476233959, 45.97447022795677, 50.18366016447544, 49.5375732332468, 50.306640565395355, 42.6782801002264, 41.90555736422539, 49.40174572169781, 49.0230618417263, 49.201572462916374, 47.08375230431557, 50.07971294224262, 50.080605894327164, 44.24652814865112, 28.42598207294941, 3.813430960290134, 2.450953982770443, 6.930940663442016, 6.760806692764163, 9.716176483780146, 16.374373957514763, 10.370335131883621, 11.748034805059433, 1.8889947747811675, 0.520225988002494, 2.6493042893707752, 44.802141934633255, 34.8800041526556, 30.67584704607725, 44.02232497930527, 6.681074146181345, 0.1259252429008484, 0.1288572754128836, 0.14893030689563602, 0.19630567490821704, 0.15227665076963603, 0.15702378354035318, 0.16291751962853596, 0.12752420007018372, 0.11744052826543339, 0.2471801356296055, 0.0896798116446007, 0.12132550808019005, 0.14670358184957877, 0.07335273345233873, 0.17046682391082868, 0.19880454550730065, 0.1686443021753803, 0.27736846182961017, 0.11777762658311985, 0.20028195373015478, 0.23899204999906942], [0.034751116909319535, 0.027931315962632652, 0.016010951112548355, 0.038531928876182064, 0.008379018890991574, 0.021644056068907958, 0.036553912359522656, 0.030316541487991344, 0.052558304741978645, 0.05634658271446824, 0.06115618576586712, 0.038793012718087994, 0.03397622196644079, 0.06371835042955354, 0.06647982256254181, 0.027307162345096003, 0.05035764021158684, 0.04995046088879462, 0.05204603359743487, 0.06174720620037988, 0.03701860441651661, 0.01895431621960597, 0.04989488144929055, 0.02638702168042073, 0.04831548729271162, 0.126713314675726, 0.03908070255420171, 0.0510235322144581, 16.40531949698925, 41.17574952542782, 27.51924242824316, 44.54921990633011, 13.476977180689573, 0.1268628574325703, 0.1305376907112077, 0.26637591887265444, 3.9563714526593685, 2.920957412570715, 9.561961758881807, 8.12752353027463, 6.3652075454592705, 2.2673625592142344, 0.43694208667147905, 1.8513170653022826, 14.86964900046587, 35.45832931995392, 48.15231576561928, 48.10519069433212, 48.082597106695175, 48.998872339725494, 53.58729712665081, 53.16846840083599, 48.981841653585434, 45.867232382297516, 43.02639842033386, 42.04047292470932, 48.07407036423683, 49.47952374815941, 53.554740473628044, 54.80034023523331, 53.3670761436224, 52.23954364657402, 45.78025504946709, 44.29506674408913, 40.61669312417507, 41.62069424986839, 41.11401043832302, 40.390730649232864, 42.48677037656307, 44.616670086979866, 47.85509951412678, 47.76417799293995, 44.655393809080124, 40.05020812153816, 37.39351987838745, 36.41484059393406, 37.26066380739212, 37.3425418138504, 38.7732220441103, 38.21185156702995, 41.522184535861015, 42.513064965605736, 44.591089859604836, 44.58137758076191, 48.169532641768456, 47.016435116529465, 50.90405970811844, 50.386801064014435, 54.22013036906719, 44.883639961481094, 45.9872717410326, 47.08514302968979, 45.9763815253973, 43.81154648959637, 47.817606925964355, 50.35696506500244, 51.03725016117096, 57.46945761144161, 54.403565526008606, 45.6644182652235, 49.60090443491936, 49.30869251489639, 46.39891505241394, 41.494202837347984, 36.85914695262909, 34.51506033539772, 36.143295764923096, 36.86839945614338, 38.263912573456764, 42.27043658494949, 46.847290992736816, 48.300697803497314, 49.13791827857494, 48.98930445313454, 48.95329378545284, 45.1325798034668, 45.09820304811001, 41.66209302842617, 41.319397017359734, 36.482169181108475, 33.83413307368755, 37.087731286883354, 44.15599040687084, 47.65506684780121, 46.04991897940636, 46.04531742632389, 47.86179095506668, 47.729736641049385, 46.95416025817394, 41.4045200496912, 40.65320536494255, 43.08188684284687, 44.33831222355366, 44.82606925070286, 46.56984128057957, 43.72668944299221, 47.64100380241871, 34.06386874616146, 10.46086622402072, 1.046959483064711, 1.389554562047124, 1.4541375590488315, 5.581842055544257, 6.7921507358551025, 5.513233412057161, 4.633205384016037, 1.667118149343878, 0.5231612117495388, 0.211377699743025, 7.046316722407937, 34.59554001688957, 19.365094676613808, 33.029678240418434, 14.31450068950653, 0.7538770535029471, 0.1477026313659735, 0.050708356939139776, 0.058774144054041244, 0.024912619155657012, 0.03501152168610133, 0.018269859392603394, 0.04288679949240759, 0.042893827630905434, 0.040749343679635786, 0.04175745110842399, 0.05353914566512685, 0.07371242274530232, 0.038422243160312064, 0.04176968170213513, 0.05727037103497423, 0.060776239552069455, 0.0759937401744537, 0.02639108493895037, 0.017545488008181565, 0.039178239312605, 0.06675822442048229, 0.04825844582228456, 0.024421816488029435, 0.019197833426005673, 0.05033266694226768, 0.06776471025659703, 0.01128286092352937, 0.025326286704512313, 0.11047568012145348, 0.04176244947302621, 0.030116465895844158, 0.048334252496715635, 0.030996953610156197, 0.026828937225218397, 0.03296576192951761, 0.04242871997121256, 0.06141162557469215, 0.012255440815351903, 0.056918481714092195, 0.044041150831617415, 0.004994173323211726, 0.03198013415385503, 0.01575927028170554, 0.035864034143742174, 0.025534841333865188, 0.03524831132381223, 0.06668639936833642, 0.0698830297915265, 0.23831320751924068, 21.999278627336025, 44.6774972230196, 27.903228923678398, 53.51393446326256, 12.191907986998558, 0.14095408958382905, 0.15377065341454, 0.3249921079259366, 1.9743531569838524, 4.965137522667646, 12.899798601865768, 9.117726646363735, 5.261020520702004, 2.3998866230249405, 0.6380749423988163, 2.289039446040988, 17.05209419131279, 38.041799291968346, 51.25175625085831, 49.1151537001133, 52.219780907034874, 51.82701498270035, 55.967139825224876, 53.10289531946182, 51.763968765735626, 46.608223021030426, 44.84247297048569, 43.91266666352749, 49.07121665775776, 51.82036533951759, 56.117444559931755, 56.03271670639515, 55.1056120544672, 52.785110771656036, 49.42272439599037, 44.28597383201122, 42.377765625715256, 42.55739338696003, 42.77678221464157, 42.239506244659424, 43.63009862601757, 48.036703169345856, 50.31567268073559, 48.88986758887768, 46.13190338015556, 42.764360681176186, 41.08628712594509, 38.97378288209438, 40.584771037101746, 39.963257387280464, 39.4904525578022, 41.07315123081207, 43.163525462150574, 45.33868834376335, 46.590531170368195, 46.990083530545235, 49.67013671994209, 49.10867124795914, 52.04454571008682, 51.902011558413506, 54.07772921025753, 47.5109937787056, 46.7785032838583, 48.08538615703583, 49.42676357924938, 46.78002320230007, 50.62889747321606, 52.55602486431599, 53.85845057666302, 56.20348334312439, 54.45377603173256, 46.88084319233894, 50.567181184887886, 49.95208539068699, 47.87616178393364, 42.961022928357124, 38.09301294386387, 35.79537123441696, 38.22505205869675, 39.531729742884636, 39.948799163103104, 44.703989401459694, 50.54221272468567, 51.623239517211914, 50.29871419072151, 49.74281162023544, 50.887925773859024, 46.45800568163395, 47.82802976667881, 42.47459962964058, 42.681601122021675, 37.810980677604675, 36.4054398983717, 39.402449280023575, 45.90656407177448, 49.3571475148201, 48.68470139801502, 48.38912285864353, 48.10372397303581, 48.42996306717396, 47.93185159564018, 43.3837616443634, 42.1809171885252, 46.09555833041668, 47.23185695707798, 47.357634007930756, 47.50709518790245, 44.99155417084694, 46.45005650818348, 36.72205790877342, 13.00875585526228, 2.0953500643372536, 3.2357676699757576, 2.9022419918328524, 7.02574510127306, 8.564033657312393, 9.229061622172594, 5.151025447994471, 1.0388362314552069, 0.19881766667822376, 0.15544480498647317, 7.18260258436203, 45.92997841536999, 22.080183885991573, 35.631098449230194, 19.9942497164011, 0.9517468046396971, 0.10194853690336458, 0.05269341643725056, 0.07700294969254173, 0.028783025045413524, 0.04342873799032532, 0.08082806787570007, 0.11491873272461817, 0.06606245355214924, 0.033203108177985996, 0.04529895384621341, 0.06612526893150061, 0.0370647066301899, 0.058181583663099445, 0.04572496145556215, 0.00863380468217656, 0.05352710060833488, 0.048262620402965695, 0.025162476158584468, 0.010857264278456569, 0.04001932269602548, 0.02791808161418885, 0.1750908640678972, 0.12545271747512743, 0.08932264565373771, 0.2586867049103603, 0.20892576256301254, 0.14295205503003672, 0.12295696389628574, 0.15101499971933663, 0.1248610921902582, 0.14458083169301972, 0.14457367738941684, 0.14255608955863863, 0.1280807811417617, 0.1621978441835381, 0.10827550169778988, 0.2445236625499092, 0.1066047788481228, 0.17691914486931637, 0.10511360378586687, 0.16531639324966818, 0.14894681225996464, 0.11600753015954979, 0.12300255402806215, 0.10348230382078327, 0.16649654164211825, 0.21684489387553185, 0.13456931890686974, 0.39350747829303145, 26.07516411691904, 55.95990501344204, 34.934117048978806, 57.97772593796253, 17.88570675998926, 0.26720356196165085, 0.9026836592238396, 0.5676973750814795, 9.238121286034584, 9.027298148721457, 18.99982027709484, 16.781062334775925, 12.231803946197033, 5.539023578166962, 1.1699917749501765, 2.904967158101499, 17.23532035946846, 39.19836603105068, 52.353229746222496, 52.96763397753239, 53.21342758834362, 53.50560910999775, 58.804565370082855, 57.04387664794922, 53.334074914455414, 50.828276574611664, 46.33309878408909, 46.758029982447624, 51.23151473701, 54.836415499448776, 59.00610275566578, 59.303383603692055, 56.82610273361206, 54.33866120874882, 50.34009777009487, 47.61923097074032, 44.04763162136078, 45.83638183772564, 45.562598928809166, 44.26744982600212, 47.843323945999146, 50.8379090577364, 53.087540343403816, 51.54231905937195, 47.81925603747368, 45.03437027335167, 41.77335485816002, 40.22487714886665, 43.3420816808939, 41.99275888502598, 41.312135607004166, 42.14152090251446, 44.93101201951504, 48.1603067368269, 48.18329930305481, 48.56028467416763, 52.739627212285995, 51.916074603796005, 54.73020739853382, 55.38884125649929, 56.309554651379585, 47.93888121843338, 47.78758093714714, 47.863466665148735, 51.8142818659544, 48.73045474290848, 54.676675871014595, 52.33930729329586, 53.524805679917336, 56.90711058676243, 55.336613059043884, 47.8371112793684, 51.57659702003002, 52.02987089753151, 49.66128699481487, 44.15594860911369, 39.81520213186741, 36.67735330760479, 39.953165128827095, 42.54148744046688, 42.386349365115166, 45.616510435938835, 51.602557227015495, 52.441252022981644, 51.00723937153816, 52.225818783044815, 51.65666252374649, 47.65277557075024, 50.430559515953064, 44.81533482670784, 46.41720727086067, 40.2555301040411, 38.131846860051155, 40.40355496108532, 47.38115094602108, 49.935487881302834, 49.286091327667236, 49.31184634566307, 49.261350855231285, 50.632112100720406, 50.14741010963917, 45.46736463904381, 46.00950814783573, 47.982601672410965, 48.88380691409111, 47.77748487889767, 48.66959720849991, 46.84995085000992, 49.058479741215706, 38.61215628683567, 13.49180018529296, 1.8665192183107138, 2.895551025867462, 4.815657818689942, 12.19631290063262, 14.083875864744186, 8.625391814857721, 13.259286861866713, 3.5468151792883873, 1.0651772492565215, 0.3803732158849016, 11.177251283079386, 47.81232140958309, 26.16360057145357, 46.448912769556046, 24.590380489826202, 1.1405374179594219, 0.30515553953591734, 0.1919677623664029, 0.21711322478950024, 0.1178132942004595, 0.222305690695066, 0.1389316629501991, 0.18473162956070155, 0.12030129975755699, 0.08215484238462523, 0.07861200749175623, 0.14999243896454573, 0.12845678284065798, 0.2169624055386521, 0.10014643907197751, 0.11816912432550453, 0.16584934433922172, 0.1710259134415537, 0.1302232130547054, 0.1002581619832199, 0.10693441116018221, 0.1409145479556173], [0.05632979533402249, 0.014704566183354473, 0.07083668213454075, 0.05900620250031352, 0.024161439541785512, 0.05910918291192502, 0.039009378451737575, 0.04071019167895429, 0.08781650889432058, 0.039712221987429075, 0.06636688995058648, 0.09294421499362215, 0.03966778218455147, 0.04551805439405143, 0.0082073360135837, 0.04192539170617238, 0.03741766093298793, 0.04517086286796257, 0.04119590506888926, 0.055653888048254885, 0.0514566533092875, 0.03476570753264241, 0.005288161210046383, 0.07577519994811155, 0.07453454425558448, 0.016337689048668835, 0.11372365232091397, 0.015164139276748756, 2.2138208197429776, 37.74903640151024, 30.206866711378098, 32.45386093854904, 36.51097923517227, 1.3304462400265038, 0.22249989589909092, 0.4514325497439131, 1.332813750486821, 4.103747494518757, 9.216482397168875, 9.409228004515171, 5.10482800193131, 2.123947092331946, 0.7440198480617255, 0.09875158735667355, 3.588704844005406, 18.996890634298325, 37.688365057110786, 46.19003266096115, 47.97136187553406, 49.04203042387962, 50.67381866276264, 50.48247613012791, 49.87178809940815, 42.163289934396744, 43.265553787350655, 44.44000616669655, 49.25315849483013, 54.5387052744627, 54.996265321969986, 51.40328072011471, 51.833957210183144, 48.63713555037975, 44.7379519790411, 44.24566559493542, 42.5089193880558, 40.26783764362335, 41.33258230984211, 39.84150052070618, 43.48710469901562, 49.26966480910778, 51.229390650987625, 48.02449822425842, 45.15172317624092, 42.3290940374136, 39.26254838705063, 40.46046070754528, 38.762765005230904, 36.68557606637478, 37.41058476269245, 37.16785378754139, 38.85677956044674, 40.637466609478, 43.558499068021774, 42.74997465312481, 45.79548843204975, 45.84763303399086, 48.45189169049263, 50.98100557923317, 54.030433148145676, 47.375333458185196, 46.66328966617584, 47.82550670206547, 40.20507261157036, 52.7512089908123, 54.487928599119186, 51.661047488451004, 44.97113026678562, 35.838840901851654, 45.21830700337887, 47.99123100936413, 52.32961781322956, 49.7579538077116, 42.261982038617134, 38.856783360242844, 35.19446387887001, 36.9465346634388, 36.57510079443455, 35.88951498270035, 37.10785120725632, 44.46611076593399, 45.04860430955887, 47.992788925766945, 44.60977345705032, 47.77346849441528, 48.32602724432945, 47.480078637599945, 43.99829886853695, 42.09092661738396, 40.870530903339386, 40.653885528445244, 36.4659820497036, 36.61831587553024, 38.33816818892956, 41.264706552028656, 46.41425862908363, 45.498481169342995, 45.46747103333473, 45.6023333966732, 46.98524259030819, 46.191810965538025, 41.58203512430191, 46.63283810019493, 44.41481351852417, 50.19844517111778, 43.561090528964996, 46.62048876285553, 39.923709109425545, 21.35651271790266, 4.3705259542912245, 1.4517322881147265, 3.6480811703950167, 1.430162745527923, 5.830050436779857, 8.305603824555874, 10.734948366880417, 4.459452107548714, 0.9364879515487701, 0.4196235362906009, 0.20038232178194448, 20.103828236460686, 35.13847008347511, 21.275668255984783, 34.10430617630482, 5.63513514585793, 0.05253048533631954, 0.021581123801297508, 0.1635671066469513, 0.07415457206661813, 0.01061351422322332, 0.044427932225517, 0.020185418616165407, 0.0309959795413306, 0.04469309787964448, 0.02227028955530841, 0.040701304460526444, 0.05972758859570604, 0.006366117258949089, 0.13716882473090664, 0.056817208242136985, 0.03846310581138823, 0.041298662836197764, 0.07109512021997944, 0.05338537637726404, 0.04570237790176179, 0.04709822038421407, 0.02841894223820418, 0.016655040672048926, 0.012820274569094181, 0.0293825838889461, 0.01815270952647552, 0.054339158596121706, 0.04275443003280088, 0.03644090553279966, 0.07546732740593143, 0.04598793406330515, 0.03083798186708009, 0.03095199430390494, 0.011340040618961211, 0.04150644192122854, 0.021014163794461638, 0.01176196827145759, 0.05759550964285154, 0.026222179549222346, 0.03796818607952446, 0.041864004961098544, 0.056828017623047344, 0.042570121368044056, 0.0020462623297134996, 0.015158714177232469, 0.023984268482308835, 0.07189631316578016, 0.016443391286884435, 0.15186541189905256, 0.06374158707330935, 3.4862421546131372, 47.49647855758667, 28.953154385089874, 42.78070740401745, 39.14248622953892, 0.7396536448504776, 0.18300040683243424, 0.5007453833241016, 0.8928891504183412, 1.2535888329148293, 12.446433529257774, 10.362688042223454, 4.406440677121282, 2.6885941810905933, 1.5096848784014583, 0.41550776339136064, 5.242897868156433, 20.632592663168907, 41.106399446725845, 47.78027392923832, 48.90269190073013, 51.74796402454376, 54.5651176571846, 53.968690261244774, 49.94911015033722, 45.2576956897974, 44.89055939018726, 46.79681450128555, 51.93345107138157, 55.368573144078255, 56.941700130701065, 54.042531698942184, 53.627441972494125, 52.87364602088928, 45.95913425087929, 45.810851007699966, 45.262114852666855, 41.50092087686062, 43.3837616443634, 41.00528687238693, 44.95692662894726, 51.06325216591358, 53.22827719151974, 51.808122396469116, 48.48838493227959, 44.2152938246727, 41.71695068478584, 40.25233447551727, 39.42286178469658, 37.90006309747696, 37.41031117737293, 40.00836856663227, 41.109264492988586, 43.087001368403435, 46.04628637433052, 45.771952494978905, 49.322413578629494, 48.41347195208073, 51.84259794652462, 51.302563324570656, 55.445329025387764, 48.1607361137867, 48.158444836735725, 49.118075743317604, 43.05371515452862, 53.39235618710518, 54.25281621515751, 52.964578941464424, 47.52378389239311, 38.76145027577877, 47.563411965966225, 47.77658812701702, 52.4726877361536, 52.08021439611912, 44.60870951414108, 40.389332324266434, 37.4062529951334, 38.7458673119545, 37.89059020578861, 37.65978679060936, 39.81672964990139, 45.94455063343048, 46.894256472587585, 51.55998431146145, 48.667579516768456, 49.202875792980194, 49.95751149952412, 47.92734883725643, 46.94221369922161, 43.36460307240486, 41.47644639015198, 41.762829422950745, 36.935291066765785, 38.496764078736305, 38.99874374270439, 44.23917934298515, 48.2923686504364, 47.58651852607727, 47.21308596432209, 46.27982184290886, 48.38159166276455, 48.27664129436016, 41.1417755484581, 47.833771258592606, 47.16988608241081, 50.668263360857964, 45.421307310462, 45.62772363424301, 41.21313191950321, 26.347706392407417, 5.994610106572509, 1.9791026646271348, 5.208824621513486, 3.470714050345123, 5.246565146371722, 7.594881411641836, 11.724920645356178, 1.988814587239176, 0.6042730843182653, 0.35863939148839563, 0.09241125648259185, 22.380572967231274, 41.535312831401825, 21.52195204049349, 39.99310478568077, 9.247963707894087, 0.055390911729773507, 0.06404730738722719, 0.11779728607507423, 0.10905089759035036, 0.06813776562921703, 0.03789085429161787, 0.0847143390274141, 0.10136413271538913, 0.029328149212233257, 0.02313549273821991, 0.04440903714566957, 0.1252817118074745, 0.047859214901109226, 0.09204807909554802, 0.05928264137764927, 0.08615828381152824, 0.08777481503784657, 0.046809079649392515, 0.06695954682072625, 0.041709667930263095, 0.0355060888978187, 0.06609395029954612, 0.1353413751348853, 0.08212249958887696, 0.14820133976172656, 0.16446912777610123, 0.13132916152244434, 0.26471460645552725, 0.14119824132649228, 0.1443802737048827, 0.13171766098821536, 0.20085435739019886, 0.1195796427782625, 0.16244910570094362, 0.14378395804669708, 0.09432976017706096, 0.07631682674400508, 0.09029911903780885, 0.17188227764563635, 0.12627550691831857, 0.1497056582593359, 0.1479693889268674, 0.1720518435467966, 0.18284791032783687, 0.08959888044046238, 0.14893717918312177, 0.17096072318963706, 0.13206893432652578, 0.27784397068899125, 0.2698723546927795, 5.192286958917975, 55.62375605106354, 38.56220796704292, 43.35413083434105, 45.74582889676094, 1.4968476234935224, 0.5192392878234386, 2.358850250020623, 3.4677065117284656, 10.34640021622181, 23.16239431500435, 20.28634574264288, 14.50207382440567, 5.227060317993164, 2.4100251914933324, 0.374621749506332, 4.955581510439515, 21.306298412382603, 41.581172570586205, 49.79570858180523, 50.92197194695473, 53.986648097634315, 55.91787926852703, 56.246500834822655, 53.68139907717705, 47.45478339493275, 46.52917966246605, 50.08619539439678, 55.183306485414505, 58.01543891429901, 58.48757117986679, 55.102047845721245, 56.14703357219696, 54.21890303492546, 50.38926713168621, 49.098525792360306, 48.3179222792387, 42.98436887562275, 44.77987892925739, 42.45144747197628, 47.11444705724716, 53.29732708632946, 56.036615297198296, 54.07872095704079, 50.056382194161415, 46.777925714850426, 44.02786888182163, 43.6362124979496, 41.688972786068916, 39.79008547961712, 40.228334963321686, 41.719378754496574, 42.68884353339672, 45.208811312913895, 49.474135637283325, 46.47223211824894, 50.306872352957726, 50.55051527917385, 53.0930994451046, 53.75701881945133, 55.59347927570343, 50.703886449337006, 50.71171022951603, 47.87777289748192, 47.23112739622593, 54.23835799098015, 52.83675380051136, 51.72327674925327, 48.30958932638168, 44.92856115102768, 50.21905146539211, 50.52275776863098, 54.869462326169014, 53.91987048089504, 45.63147023320198, 41.867962181568146, 38.194710686802864, 40.8581967651844, 39.70730312168598, 40.45752726495266, 40.36361910402775, 48.931205570697784, 48.349498584866524, 52.053619623184204, 49.47972513735294, 52.43020601570606, 54.06874269247055, 50.79241789877415, 48.70191067457199, 45.267723351716995, 44.782162606716156, 43.468307107687, 40.03478094935417, 40.10196514427662, 41.63842409849167, 45.43575033545494, 50.104806795716286, 49.66614693403244, 47.6817262172699, 46.83920882642269, 50.13841599225998, 49.16914880275726, 45.10338217020035, 50.3601036965847, 49.506232514977455, 51.47961102426052, 47.05616198480129, 46.04251317679882, 43.07498261332512, 27.04012803733349, 4.991258271038532, 2.7551468973979354, 7.1531973872333765, 4.555877633392811, 12.314134128391743, 14.878140594810247, 21.903149485588074, 8.51886548101902, 2.3001756984740496, 0.6673048145603389, 0.2501792582916096, 29.25250042229891, 44.91976462304592, 28.59012756496668, 48.304265812039375, 10.625465791672468, 0.14020275411894545, 0.14748185727512464, 0.34556037455331534, 0.17564673267770559, 0.11742593022063375, 0.13489025324815884, 0.1555068336892873, 0.18120415712473914, 0.10972100499202497, 0.08202381621231325, 0.13986817910335958, 0.2682078955695033, 0.08822489049634896, 0.2615351864369586, 0.15034169366117567, 0.25540863862261176, 0.16847501829033718, 0.11778544139815494, 0.2199771726736799, 0.22071353159844875, 0.14422525389818475, 0.1586909737670794], [0.028796992264688015, 0.029988714450155385, 0.023358773432846647, 0.1017197105102241, 0.07412811450194567, 0.02101246613165131, 0.048819665316841565, 0.030381382930499967, 0.052398987900232896, 0.027677371581376065, 0.03976049127231818, 0.0077183052235341165, 0.03757421698537655, 0.040074326971080154, 0.03323801880469546, 0.060788700211560354, 0.03611689498939086, 0.0371118478506105, 0.022209546623344067, 0.046954614808782935, 0.06176970069645904, 0.01726138831145363, 0.04315901554946322, 0.04995149247406516, 0.020780917911906727, 0.02629526068631094, 0.06635137906414457, 0.18526763829868287, 0.1651776858489029, 15.272995457053185, 39.93657901883125, 24.258213713765144, 46.31056599318981, 11.03937093168497, 0.11432998697273433, 0.3732626693090424, 0.5784490169025958, 2.455804659985006, 7.680835174396634, 11.369131486862898, 3.2126948330551386, 0.3163828980177641, 1.0687827807851136, 0.28049985005054623, 0.3725841682171449, 5.5691369622945786, 20.03644835203886, 42.690751031041145, 47.870686277747154, 49.30598706007004, 52.73319415748119, 52.73800849914551, 47.673020884394646, 43.14712934195995, 45.4213947057724, 46.04397989809513, 49.595903903245926, 52.554668337106705, 55.31811565160751, 53.21883849799633, 52.96175189316273, 48.752721548080444, 46.39688976109028, 47.95596890151501, 46.39436289668083, 43.099692687392235, 40.6065970659256, 41.253094375133514, 46.29116803407669, 50.794029012322426, 52.87770040333271, 51.69363833963871, 48.38678978383541, 41.69279918074608, 39.879513680934906, 40.07478520274162, 36.4476328343153, 36.57056763768196, 39.50225472450256, 37.240551486611366, 37.59243160486221, 37.6784323900938, 43.15650723874569, 42.67293758690357, 43.32473561167717, 43.026288226246834, 48.407133892178535, 49.3645229190588, 55.56710109114647, 47.114998027682304, 47.2870109975338, 43.550420701503754, 50.71278177201748, 54.45594571530819, 44.209571331739426, 44.475728049874306, 45.4267980158329, 42.56683208048344, 45.739829018712044, 51.79054453969002, 50.79507775604725, 49.22790884971619, 40.2383778244257, 36.53656706213951, 37.017457857728004, 35.818758979439735, 36.46108031272888, 36.750571578741074, 38.40216435492039, 42.390130162239075, 43.963257148861885, 45.94052664935589, 43.81055474281311, 41.821201890707016, 41.485543102025986, 44.10173311829567, 41.28676436841488, 43.613945692777634, 40.973474979400635, 40.11296555399895, 37.59282298386097, 37.614763006567955, 35.86926206946373, 38.46041902899742, 42.7325563877821, 44.180020317435265, 49.44998413324356, 49.8870974779129, 45.91431565582752, 45.28320752084255, 44.27125722169876, 46.51994235813618, 47.34723776578903, 48.60538825392723, 45.94597555696964, 39.35336731374264, 30.298867374658585, 9.062375016510487, 1.214332189410925, 1.2358422414399683, 3.763004341162741, 3.4409150993451476, 3.4641396906226873, 6.3129726983606815, 12.48238530009985, 2.121785245835781, 0.1555834530154243, 0.32743629708420485, 1.3645232864655554, 31.98718138039112, 24.518258459866047, 25.30447617173195, 24.701047651469707, 0.885976490098983, 0.016890316328499466, 0.11838911916129291, 0.04715505405329168, 0.026054422633023933, 0.044569378151209094, 0.0671931378019508, 0.06508385762572289, 0.034170571889262646, 0.022882758057676256, 0.03707949392264709, 0.12365067901555449, 0.03492245283268858, 0.06709953813697211, 0.03897837523254566, 0.021141928227734752, 0.04492233245400712, 0.02270460179715883, 0.056802873659762554, 0.006839819452579832, 0.03388298224308528, 0.09474717371631414, 0.06294105463894084, 0.05860251869307831, 0.08659883009386249, 0.06794495566282421, 0.09343833691673353, 0.05364981843740679, 0.021337211401259992, 0.033285868776147254, 0.03465301982942037, 0.1001008489402011, 0.019142576820740942, 0.036695695962407626, 0.027490179672895465, 0.043512923512025736, 0.02393997710896656, 0.00804190201961319, 0.026375021152489353, 0.054745822126278654, 0.03973243809014093, 0.02487564164766809, 0.06034906306012999, 0.02831424932082882, 0.05884074067580514, 0.04734996058687102, 0.02374195169977611, 0.018895220855483785, 0.05563012819038704, 0.02682625621673651, 0.025650111711001955, 0.22742553002899513, 23.84242482483387, 43.579097762703896, 26.87701229006052, 54.33158218860626, 10.014204941689968, 0.24732880265219137, 0.1260893020662479, 0.530360103584826, 0.5743976030498743, 6.324407234787941, 16.160470135509968, 4.763642409816384, 4.958243742585182, 3.0846348172053695, 1.2051861989311874, 1.5185095486231148, 6.831956449896097, 24.193679876625538, 46.94895073771477, 51.17296367883682, 52.5906790047884, 55.311693996191025, 54.21834446489811, 50.520059913396835, 45.34543678164482, 47.05589599907398, 48.639119043946266, 52.95725293457508, 55.26501730084419, 56.746941581368446, 54.33934897184372, 54.90379348397255, 50.175122022628784, 48.162465021014214, 48.757019117474556, 49.37158294022083, 45.83907209336758, 41.987705156207085, 41.586952060461044, 48.1936689466238, 51.99050880968571, 54.54782858490944, 51.86115235090256, 49.02106694877148, 44.46865662932396, 41.69945642352104, 41.13724239170551, 39.74623963236809, 39.85144078731537, 39.91044022142887, 38.969223126769066, 40.29751405119896, 39.82907138764858, 44.31427851319313, 45.95990560948849, 45.14612227678299, 45.89006155729294, 49.56407681107521, 50.88143192231655, 56.30316719412804, 49.7050454467535, 47.57285065948963, 45.92410773038864, 50.218960270285606, 55.04217065870762, 45.703677758574486, 46.42664976418018, 46.85467779636383, 43.17464366555214, 47.27358631789684, 53.10659632086754, 53.71359474956989, 50.42806684970856, 41.83227449655533, 39.06793802976608, 38.06363672018051, 36.98673650622368, 37.95731462538242, 38.68584953248501, 40.542418509721756, 44.82062414288521, 46.009314358234406, 48.04518811404705, 45.06798326969147, 44.726632386446, 43.64456444978714, 46.43573887646198, 45.13437330722809, 45.74882313609123, 42.52711281180382, 41.522621512413025, 39.15989689528942, 40.41080877184868, 37.4226339161396, 39.81505773961544, 45.68295747041702, 46.95337750017643, 50.120910331606865, 49.312013536691666, 46.67437367141247, 46.56743600964546, 46.02556988596916, 47.7778572589159, 50.3623303771019, 48.60826849937439, 47.37612001597881, 42.32880525290966, 36.465704664587975, 10.682549178600311, 2.395521607249975, 3.805540921166539, 3.799540805630386, 3.876109072007239, 5.103536071255803, 7.850494645535946, 5.5338131077587605, 1.554952086880803, 0.2889987174421549, 0.3941050556022674, 1.2380115687847137, 40.58572098612785, 29.337467662990093, 26.340992152690887, 32.31768384575844, 1.5478576300665736, 0.03817291493760422, 0.10308659067959525, 0.04370003007352352, 0.04877276158367749, 0.030809210657025687, 0.03943129311664961, 0.05282751139020547, 0.051026107466896065, 0.048271318373735994, 0.035799771576421335, 0.10380602863733657, 0.00967823467362905, 0.055446947590098716, 0.03408503565879073, 0.03232252398447599, 0.06961964900256135, 0.01655444997595623, 0.041408589750062674, 0.06118825767771341, 0.0402648065937683, 0.07478372033801861, 0.03773485484998673, 0.13769193494226784, 0.12134969467297196, 0.21334486606065184, 0.12547612481284887, 0.16505104576935992, 0.08435273499344476, 0.15276952588465065, 0.09404257871210575, 0.12760473793605343, 0.12470270303310826, 0.13691481726709753, 0.0933651537343394, 0.12097384882508777, 0.15239644824760035, 0.1312427458469756, 0.084493572358042, 0.11728046185453422, 0.09149446661467664, 0.09947042417479679, 0.13114199187839404, 0.1449188354308717, 0.1834270081599243, 0.1116090286814142, 0.08778980642091483, 0.10698961952584796, 0.09912694338709116, 0.14666310511529446, 0.2082827064441517, 0.45040654542390257, 27.966774813830853, 55.57940483093262, 30.31579166650772, 57.31290601193905, 13.675063401460648, 0.2528045017970726, 1.0039985133334994, 1.2770517426542938, 6.888764351606369, 21.282479390501976, 22.19453115016222, 10.176621526479721, 8.02735235542059, 4.048536932095885, 1.3418822013773024, 1.1200091382488608, 6.456407876685262, 23.907255046069622, 48.60212042927742, 52.82788887619972, 55.60175523161888, 58.42380300164223, 57.603772804141045, 52.1024964004755, 48.26068215072155, 49.94910255074501, 51.68408565223217, 56.756228283047676, 58.089702129364014, 58.92409175634384, 57.21959441900253, 57.637173011898994, 53.309345841407776, 51.17025062441826, 52.5839039683342, 52.23481670022011, 48.807731196284294, 45.56886859238148, 45.685085356235504, 50.7094569504261, 54.999609142541885, 56.842297464609146, 55.294553115963936, 53.30212242901325, 45.934332981705666, 42.49053597450256, 43.53292644023895, 40.424491837620735, 42.38447226583958, 42.29118727147579, 40.927991420030594, 41.73121891915798, 41.484615951776505, 46.25056341290474, 48.50581079721451, 46.29539340734482, 48.571083694696426, 52.48006694018841, 54.0390282869339, 57.961838990449905, 52.718257158994675, 48.20718862116337, 47.697537168860435, 51.29377819597721, 52.71362900733948, 50.072751715779305, 48.23429636657238, 50.208085253834724, 45.08042000234127, 47.92353004217148, 55.02471059560776, 56.681649684906006, 52.22773388028145, 44.34468448162079, 41.82799972593784, 41.126568764448166, 38.78529779613018, 40.24100348353386, 41.56889542937279, 41.4692609757185, 46.80180363357067, 47.384532764554024, 50.138089209795, 47.61666610836983, 45.41245378553867, 45.247280448675156, 46.88834398984909, 45.70376895368099, 47.68636956810951, 44.772693514823914, 43.9566683024168, 41.668700873851776, 42.587753757834435, 40.79701244831085, 42.472160160541534, 47.73886755108833, 48.75240616500378, 52.57398650050163, 52.449554577469826, 46.91624969244003, 47.7761435508728, 48.21989133954048, 50.586164966225624, 51.41808472573757, 51.315391436219215, 46.278773099184036, 44.9222306907177, 36.9084645062685, 9.874066561460495, 2.487175539135933, 4.816134218126535, 7.70254815928638, 8.762050531804562, 8.222544081509113, 15.34341897815466, 24.538252986967564, 5.677081095054746, 0.7683519017882645, 0.44203847413882613, 2.1142139146104455, 45.479170605540276, 32.2622562199831, 34.92106854915619, 37.44414836168289, 2.0283499220386147, 0.15079409204190597, 0.3273673664079979, 0.20100489462492988, 0.1161547277297359, 0.19303641049191356, 0.16476126678753644, 0.355253565357998, 0.10016755317337811, 0.1476506216567941, 0.14734892378328368, 0.17788093857234344, 0.16546382830711082, 0.1281321674468927, 0.13195700361393392, 0.13766876509180292, 0.146778954367619, 0.0768939801491797, 0.1172913565824274, 0.1076289352204185, 0.10586696531390771, 0.1320349142770283, 0.11532935561263002], [0.018691735094762407, 0.01676599174970761, 0.010489656269783154, 0.04633761549484916, 0.057671119648148306, 0.006775873225706164, 0.06835642459918745, 0.08024766386370175, 0.022124969618744217, 0.05084516444185283, 0.05853503149410244, 0.0344791234965669, 0.09766428163857199, 0.03261482997913845, 0.058139099419349805, 0.02377020711719524, 0.04745089267089497, 0.028176232117402833, 0.11188128555659205, 0.017761005838110577, 0.02656261382071534, 0.032366466548410244, 0.01501652053775615, 0.03214448275684845, 0.04837824701098725, 0.05358429050829727, 0.06293085752986372, 0.1483312452910468, 0.27966199500951916, 2.5995758827775717, 33.07420805096626, 30.724454037845135, 39.551648274064064, 29.794885218143463, 0.6384004780557007, 0.13634947885293514, 0.19660588848637417, 0.44995665550231934, 1.1561019765213132, 6.9914585910737514, 4.472939483821392, 2.2357335314154625, 3.0549698090180755, 1.3825125899165869, 1.1414124397560954, 1.0260249814018607, 8.335917647928, 26.52756594121456, 48.94281014800072, 49.65977467596531, 53.791870549321175, 52.96920709311962, 50.48460401594639, 45.19667476415634, 44.504291117191315, 48.59689950942993, 49.911032393574715, 55.69833844900131, 52.982434183359146, 53.146399185061455, 50.15722878277302, 49.83807250857353, 50.00069618225098, 51.241781786084175, 50.50722800195217, 43.065889701247215, 39.633541479706764, 38.60145226120949, 45.89368276298046, 51.31104826927185, 53.42639096081257, 52.11918890476227, 50.16768962144852, 43.617574498057365, 39.12816479802132, 41.314605474472046, 39.69991631805897, 36.847378984093666, 38.13152767717838, 38.42214748263359, 36.244902312755585, 39.391790851950645, 37.74279333651066, 40.77566519379616, 41.01968050003052, 42.590755596756935, 49.05503332614899, 48.885877802968025, 52.812233716249466, 48.94984357059002, 46.73353269696236, 48.47128584980965, 50.16002543270588, 44.55588474869728, 47.78755433857441, 50.249453634023666, 50.609868094325066, 54.182702377438545, 53.2786700874567, 53.19750264286995, 50.47727420926094, 45.28764188289642, 38.29436793923378, 35.727757662534714, 35.3766755014658, 35.0652290135622, 36.72977529466152, 36.969523429870605, 36.83785289525986, 41.65047325193882, 43.40233124792576, 42.817861810326576, 40.42337849736214, 38.88695754110813, 38.07332620024681, 39.802609607577324, 39.29901123046875, 41.16125710308552, 40.47067455947399, 37.975306659936905, 38.253151550889015, 37.469834983348846, 39.037756249308586, 39.851805567741394, 41.58244930207729, 45.39711020886898, 47.11627095937729, 45.785183385014534, 44.92453716695309, 47.11852043867111, 46.85075260698795, 49.81745861470699, 50.15375956892967, 46.92331351339817, 42.12002545595169, 36.10255815088749, 17.878411151468754, 1.6281453031115234, 2.0310800755396485, 3.4229855239391327, 2.391651514917612, 3.132006637752056, 3.4624513937160373, 3.697031568735838, 3.824640833772719, 0.7633985707070678, 0.12636063125682995, 0.19795891275862232, 7.919646659865975, 38.5537002235651, 20.704093426465988, 31.300552524626255, 10.73078854009509, 0.060309324762783945, 0.13179478497477248, 0.032504702685400844, 0.023945114626258146, 0.047271986841224134, 0.052223681486793794, 0.02961782243801281, 0.035714298428501934, 0.07792768054059707, 0.031414209443028085, 0.03461093263467774, 0.04890572476142552, 0.04518957241089083, 0.00719181035492511, 0.02796829903672915, 0.07955475026392378, 0.089680056553334, 0.017160228017019108, 0.06416811418603174, 0.035789362955256365, 0.0368050106044393, 0.0009893142782857467, 0.017743396529112943, 0.06592414691112936, 0.02310816871613497, 0.059247463577776216, 0.01353101270069601, 0.06863021772005595, 0.05123570481373463, 0.041798606907832436, 0.07316091796383262, 0.01695097020274261, 0.018311497588001657, 0.013685592784895562, 0.04622677945008036, 0.09934543908457272, 0.020892575885227416, 0.031058188214956317, 0.009868534325505607, 0.055729101004544646, 0.005391461672843434, 0.058235908873029985, 0.0066924664952239254, 0.06501460040453821, 0.026640884425432887, 0.05311056651407853, 0.05159821426786948, 0.04282740912458394, 0.07176508661359549, 0.055417339608538896, 0.19722017896128818, 0.2641134965233505, 5.617782426998019, 43.99932861328125, 29.90135170519352, 45.61319701373577, 31.860247291624546, 0.5834322120063007, 0.2394503855612129, 0.13712322717765346, 0.6235286104492843, 0.5570341378916055, 9.36389833688736, 7.704989528283477, 4.372651465237141, 4.583201967179775, 1.902159999590367, 2.068298365920782, 2.258158028125763, 9.360047243535519, 30.860792621970177, 50.675809755921364, 52.81476438045502, 55.1583494246006, 54.38121132552624, 50.59897027909756, 47.850486561656, 46.80902324616909, 50.015777572989464, 53.88593450188637, 56.690772995352745, 55.14174431562424, 54.014474004507065, 53.91822136938572, 51.22071571648121, 52.12646171450615, 52.29352355003357, 51.17210492491722, 44.576092064380646, 41.401309221982956, 40.494723469018936, 47.74703711271286, 53.243882954120636, 54.36955355107784, 54.01515796780586, 51.12523443996906, 45.08537873625755, 41.21160440146923, 42.678967863321304, 41.808088794350624, 38.36136594414711, 38.894910514354706, 40.94057634472847, 39.01697136461735, 40.34890629351139, 39.31305527687073, 42.92088948190212, 43.4410435706377, 45.48238903284073, 50.110996663570404, 51.890064999461174, 53.56314182281494, 51.22271440923214, 47.68748290836811, 48.53639155626297, 52.26577743887901, 45.03470465540886, 49.87908370792866, 50.47206848859787, 53.47982369363308, 52.88461983203888, 54.95126433670521, 53.88249568641186, 51.33363425731659, 47.48275749385357, 40.80778107047081, 38.89618344604969, 37.439151629805565, 37.159824818372726, 38.454848527908325, 37.98468455672264, 38.99551771581173, 42.99462832510471, 43.62465351819992, 42.26860508322716, 42.31555916368961, 41.354009360075, 40.14934100210667, 40.534777119755745, 41.6869854927063, 43.30665238201618, 42.99794174730778, 39.670885875821114, 40.25136552751064, 39.3311233073473, 40.979691445827484, 40.84297478199005, 43.359967321157455, 46.636090725660324, 48.36992248892784, 48.567679077386856, 45.819149762392044, 47.79372900724411, 48.702925220131874, 49.975929111242294, 50.76345205307007, 47.35299825668335, 44.09979522228241, 37.6975529640913, 20.68210780620575, 2.2562158573418856, 2.964296224527061, 5.70446765050292, 2.9097387520596385, 3.6339782271534204, 4.727057022973895, 5.593527853488922, 0.504030603915453, 0.5912863905541599, 0.12920728710014373, 0.1501792375347577, 7.267875233665109, 45.46215511858463, 19.42287627607584, 33.85926112532616, 15.527707189321518, 0.15398954245029017, 0.03127027732261922, 0.029240037729323376, 0.029493970978364814, 0.034966595776495524, 0.027152355905855075, 0.059128790453542024, 0.013755506806774065, 0.0718635473458562, 0.06460051910835318, 0.01759070706611965, 0.007936235033412231, 0.05198570070206188, 0.02984478975122329, 0.04228050194797106, 0.0594024574093055, 0.07930698426207528, 0.03526738080836367, 0.049196346080861986, 0.01348100122413598, 0.04159435302426573, 0.03180795218213461, 0.014606757613364607, 0.11712333434843458, 0.07813614982296713, 0.11300289334030822, 0.11101315089035779, 0.16477253258926794, 0.17875986406579614, 0.13246262882603332, 0.1870660699205473, 0.1054459078295622, 0.11958709394093603, 0.14681021362775937, 0.09006076346850023, 0.23415995616232976, 0.12565648154122755, 0.10317275402485393, 0.09355403031804599, 0.12871978513430804, 0.08971265910076909, 0.2988954645115882, 0.09171863974188454, 0.16829708096338436, 0.10030327714048326, 0.09583025661413558, 0.2690094447461888, 0.09933149412972853, 0.20735503669129685, 0.15211933030514047, 0.33233862777706236, 0.35325433826074004, 7.816704483702779, 54.19119872152805, 36.94578230381012, 50.34825973212719, 39.26570601761341, 0.8936216204892844, 0.3871476883068681, 1.000936352647841, 1.3333421596325934, 7.11655642837286, 17.427479848265648, 11.661724336445332, 9.46702005341649, 6.502327937632799, 3.6796197155490518, 2.29112078435719, 1.6977639799006283, 10.077523794025183, 31.72134194523096, 52.34696768224239, 56.59917511045933, 57.95370362699032, 58.94987337291241, 55.445663407444954, 49.66014325618744, 49.61155526340008, 53.08933384716511, 55.20687662065029, 58.78452904522419, 55.74389800429344, 55.980309918522835, 55.1020972430706, 54.49132941663265, 54.968823194503784, 54.663623571395874, 53.908923268318176, 47.14173339307308, 43.26629854738712, 40.96948519349098, 49.756285697221756, 55.65230771899223, 56.195135191082954, 56.73651494085789, 53.426121175289154, 46.902437433600426, 43.07611495256424, 44.76067095994949, 45.23999243974686, 39.368372708559036, 41.794223338365555, 42.14356139302254, 40.560098960995674, 43.324636816978455, 42.45013274252415, 44.28113669157028, 46.94036699831486, 46.469697654247284, 54.583265483379364, 53.95520098507404, 56.05135850608349, 52.29933723807335, 51.745376363396645, 46.409603878855705, 48.76448951661587, 49.72781382501125, 51.169509664177895, 51.472839787602425, 52.22637355327606, 55.877639427781105, 58.37811045348644, 56.55952423810959, 53.7350407987833, 49.73517023026943, 43.60241711139679, 39.75622549653053, 39.430894553661346, 39.898626655340195, 39.3974943459034, 40.5089271068573, 39.72072400152683, 46.74748934805393, 45.33312924206257, 44.928420558571815, 43.424693048000336, 42.663001120090485, 42.39253543317318, 42.329907193779945, 43.14025171101093, 44.837936013937, 44.82856571674347, 42.00853943824768, 42.434052005410194, 41.39765381813049, 42.052370086312294, 43.28946590423584, 45.31061924993992, 48.291950672864914, 51.00633502006531, 49.878205955028534, 47.11212918162346, 50.360115095973015, 48.924525529146194, 51.27150759100914, 51.91517025232315, 46.8922995775938, 47.37170085310936, 41.139868050813675, 19.246976114809513, 2.6056344201788306, 4.363289242610335, 7.672195388004184, 5.515145659446716, 7.585486890748143, 9.065541196614504, 10.61662271618843, 9.341891817748547, 2.45227322448045, 0.9260521677788347, 0.2975542552303523, 11.252882424741983, 51.23154133558273, 26.091795824468136, 44.14235673844814, 17.882323041558266, 0.2546859945869073, 0.21686936990590766, 0.11293792573269457, 0.17828867450589314, 0.14875461085466668, 0.15357135707745329, 0.12867656245362014, 0.08766879182076082, 0.1861914637265727, 0.15907638589851558, 0.25337168073747307, 0.10538790898863226, 0.1376267446903512, 0.09194910628139041, 0.10158945617149584, 0.1261841633822769, 0.20729857409605756, 0.1508792460663244, 0.18728310358710587, 0.1251632798812352, 0.13779681525193155, 0.09940102594555356, 0.06495131747215055], [0.03338395101309288, 0.07026994848274626, 0.019753620399569627, 0.06623449822654948, 0.05867496343853418, 0.03549658940755762, 0.034699704629019834, 0.08089839378953911, 0.024011249261093326, 0.014370223088917555, 0.03583140191040002, 0.046803112782072276, 0.06261065791477449, 0.07306038663955405, 0.024939637041825335, 0.06928453964064829, 0.03291873574198689, 0.07456677572918124, 0.017402761877747253, 0.005831980124639813, 0.028979775815969333, 0.043804980887216516, 0.03884169018419925, 0.018721799497143365, 0.05438244064862374, 0.0370777424541302, 0.035925328120356426, 0.018574152927612886, 0.02131786175596062, 0.236965125950519, 19.46592416614294, 35.42610324919224, 22.577415704727173, 44.13178190588951, 8.83375458419323, 0.03138084248348605, 0.12739301804685965, 0.3913072479190305, 0.6865023344289511, 6.271580569446087, 3.394477078691125, 4.315979881212115, 4.021485233679414, 2.03426169231534, 2.1073688194155693, 0.794789339415729, 1.7399253300391138, 12.32784854248166, 39.373061656951904, 52.9268279671669, 50.75689360499382, 52.65878655016422, 51.144263818860054, 46.36095888912678, 49.095850735902786, 49.044895470142365, 54.016567692160606, 55.18342807888985, 54.55085702240467, 53.868550434708595, 54.185385033488274, 52.90724381804466, 53.65260422229767, 54.61053282022476, 50.729500874876976, 44.177740439772606, 38.757209703326225, 40.196887850761414, 47.0669762045145, 50.311390310525894, 52.96187348663807, 53.248461708426476, 53.14142145216465, 51.016708463430405, 43.531512916088104, 38.724204674363136, 39.162849336862564, 39.54880602657795, 39.15792480111122, 40.792391896247864, 38.387257754802704, 38.805805295705795, 39.180712178349495, 40.83055704832077, 42.823812291026115, 43.485079407691956, 47.056344375014305, 49.55805793404579, 52.943938449025154, 45.982225611805916, 50.26795104146004, 51.4415180683136, 52.54769571125507, 55.471099242568016, 54.47433292865753, 54.58924636244774, 51.91700175404549, 52.124744206666946, 50.28774797916412, 50.65513126552105, 49.23568323254585, 39.794094264507294, 37.149405777454376, 37.30490863323212, 36.240323558449745, 36.5343251824379, 36.748831272125244, 35.412355586886406, 37.96770706772804, 39.220165461301804, 39.594395980238914, 38.01069036126137, 36.74413092434406, 36.85357265174389, 36.73477582633495, 34.45970870554447, 35.41622377932072, 35.99371679127216, 36.82729706168175, 37.27284595370293, 37.740749046206474, 38.3247397094965, 40.92752404510975, 39.6099903434515, 44.8195905983448, 45.169768407940865, 50.700010657310486, 45.82936741411686, 44.40945200622082, 46.46648682653904, 46.73993535339832, 44.42246250808239, 46.67952999472618, 43.227301239967346, 46.26526482403278, 17.444316744804382, 2.2500153025612235, 0.6316440249793231, 1.8240872514434159, 2.3495122510939837, 3.230444868095219, 2.4199466966092587, 4.152473229914904, 4.527040980756283, 0.5496879445854574, 0.5374222621321678, 0.27829362312331796, 0.08244835436926223, 18.854498974978924, 34.028029069304466, 24.753809720277786, 32.92239099740982, 2.5404261192306876, 0.07841798782465048, 0.03245990665163845, 0.121637135889614, 0.021568236406892538, 0.0752811819256749, 0.10684527180274017, 0.052601430943468586, 0.06203435426868964, 0.027799556919489987, 0.01127761115640169, 0.023251761303981766, 0.03962722381402273, 0.0774416331842076, 0.02287978019012371, 0.04309915020712651, 0.02145345955796074, 0.011578715311770793, 0.08408931709709577, 0.07537985788076185, 0.005731587489208323, 0.042548120400169864, 0.026488781259104144, 0.08959119179053232, 0.003043065457859484, 0.08341599619598128, 0.03348578109580558, 0.03805161832133308, 0.01882821790786693, 0.023751525404804852, 0.013248970608401578, 0.0702091443235986, 0.10301490663550794, 0.04304372661863454, 0.019497625835356303, 0.03290190754341893, 0.046582605864387006, 0.08627399205579422, 0.013817880608257838, 0.06946735287783667, 0.024645906123623718, 0.013936278210167075, 0.0035223284248786513, 0.06310322132776491, 0.11316641073790379, 0.06823425967013463, 0.014099164782237494, 0.025052569653780665, 0.06204476288985461, 0.04358026970294304, 0.009898735097522149, 0.02808438763167942, 0.0920859063626267, 0.3512892796425149, 30.794229693710804, 37.79897332191467, 30.221691615879536, 55.29405154287815, 7.129239672794938, 0.05704019764380064, 0.11957720111240633, 0.25515886140055954, 0.5903290794230998, 2.52706793602556, 10.297285001724958, 5.513977697119117, 3.456921265460551, 2.794554582796991, 3.1223045708611608, 1.6103822062723339, 2.641926985234022, 14.908380322158337, 44.91985961794853, 54.87926959991455, 52.70555064082146, 54.41960446536541, 52.524106577038765, 48.341370820999146, 49.089915454387665, 53.30478608608246, 54.77334268391132, 57.07941614091396, 55.0455828756094, 54.716946110129356, 55.48775754868984, 55.708107724785805, 56.02868512272835, 57.35663786530495, 52.89585582911968, 45.347720459103584, 39.97003622353077, 42.29603961110115, 48.762361630797386, 54.04788941144943, 54.81518603861332, 55.63100226223469, 54.82400916516781, 51.1828887462616, 44.51609328389168, 41.321490705013275, 40.31833313405514, 41.87653832137585, 41.60256162285805, 41.19428873062134, 39.934994503855705, 40.57554893195629, 40.71254678070545, 42.47832342982292, 44.5013614743948, 44.08524960279465, 50.17528921365738, 51.51088334619999, 54.44923907518387, 48.65058682858944, 50.68413130939007, 51.195861250162125, 54.89617869257927, 55.177758783102036, 57.78599962592125, 54.73812237381935, 52.69524559378624, 53.020644932985306, 51.98622263967991, 52.16622658073902, 50.25432497262955, 42.173142805695534, 37.26535275578499, 37.69850671291351, 37.72811472415924, 39.069594740867615, 38.8518588244915, 39.14162367582321, 38.41061890125275, 42.14512690901756, 41.00555665791035, 40.63963629305363, 37.818861454725266, 38.40771205723286, 39.01447109878063, 38.89088273048401, 37.26088419556618, 37.600570768117905, 39.62661825120449, 39.90031756460667, 40.14188200235367, 39.93116430938244, 41.40806905925274, 41.61594070494175, 45.946192145347595, 47.41964668035507, 50.6339056044817, 48.328774496912956, 43.90165485441685, 47.23865479230881, 48.33448179066181, 46.76653012633324, 47.851033732295036, 44.58087220788002, 47.1856514364481, 22.99131229519844, 4.522035224363208, 1.0735278949141502, 4.295601099729538, 5.254037920385599, 3.463224177248776, 2.1399601455777884, 5.756821716204286, 4.295537928119302, 0.5795164627488703, 0.28787617455236614, 0.3025164327118546, 0.10088104652822949, 20.655256547033787, 40.93572400510311, 25.508795008063316, 38.387474343180656, 4.277218636125326, 0.04969744048139546, 0.02822534559527412, 0.06584760922123678, 0.029072239995002747, 0.025041945809789468, 0.09068757397471927, 0.06054848185158335, 0.019834753838949837, 0.05056139314547181, 0.005114812674946734, 0.05449734366266057, 0.032443494055769406, 0.02651123679243028, 0.0071602523803449, 0.07048591345665045, 0.06080408493289724, 0.014917784283170477, 0.03620065748691559, 0.06059265448129736, 0.041129007877316326, 0.047834367796895094, 0.033977168204728514, 0.05331946624210104, 0.15209846111247316, 0.2331320964731276, 0.1256203092634678, 0.11865768014104106, 0.196545640937984, 0.13282414380228147, 0.19125550839817151, 0.19975446484750137, 0.16084890172351152, 0.17147111298982054, 0.13022414816077799, 0.16911179583985358, 0.14756162330741063, 0.14071967481868342, 0.15716988273197785, 0.21736684633651748, 0.15506393479881808, 0.10451649402966723, 0.11375776142813265, 0.15846417343709618, 0.20507967128651217, 0.09993152052629739, 0.13710546016227454, 0.18824739090632647, 0.15466191340237856, 0.14692374737933278, 0.15074772265506908, 0.17950324370758608, 0.15396505157696083, 0.9327514457982033, 37.4359218031168, 49.11410115659237, 31.809892393648624, 55.040863528847694, 13.021201137453318, 0.1093879365362227, 0.6096476584207267, 0.7534024945925921, 2.5481017073616385, 18.019123300909996, 14.906463325023651, 12.955130282789469, 10.792579874396324, 6.831478625535965, 5.783895263448358, 1.8881629756651819, 2.836945583112538, 15.087982434779406, 44.6538320928812, 58.222011029720306, 56.62447415292263, 57.17517480254173, 55.60287997126579, 49.57130402326584, 53.984615206718445, 54.97594401240349, 58.825376853346825, 58.441749438643456, 57.85270504653454, 56.649389415979385, 57.293017879128456, 58.12293514609337, 59.36297580599785, 60.084925666451454, 54.86895315349102, 48.89875151216984, 40.91219946742058, 43.85697305202484, 51.34867005050182, 55.5913095921278, 57.24491246044636, 57.988996133208275, 56.53377301990986, 53.47039259970188, 49.16259415447712, 44.289739429950714, 42.55061075091362, 44.88583244383335, 43.3052084594965, 43.68242181837559, 42.37391643226147, 45.12871541082859, 43.20875823497772, 44.97084528207779, 47.83352427184582, 47.207439467310905, 52.80480891466141, 53.8985650241375, 55.28865963220596, 50.46487167477608, 52.063559889793396, 48.84094901382923, 57.38728702068329, 55.889095813035965, 61.02654553949833, 57.48640850186348, 55.80409437417984, 55.33530592918396, 53.64981137216091, 54.52142380177975, 52.84719564020634, 43.24059672653675, 39.416409730911255, 40.215541049838066, 39.30836632847786, 39.734893441200256, 41.30283750593662, 40.39027087390423, 41.69497266411781, 44.366590306162834, 43.97841073572636, 41.683432683348656, 39.264345690608025, 39.723889231681824, 40.36716811358929, 39.70618598163128, 39.618973061442375, 39.315601140260696, 41.01737402379513, 41.14613391458988, 42.391707077622414, 43.48938077688217, 43.16579394042492, 44.16612446308136, 48.8272013515234, 49.09068301320076, 53.3955442160368, 49.02981787919998, 44.99592013657093, 48.55538293719292, 50.3711649030447, 47.52457804977894, 49.7377160936594, 49.723862037062645, 49.015371054410934, 19.018405079841614, 3.5694215912371874, 1.5639097499661148, 3.639710219576955, 7.00062844902277, 8.023355919867754, 3.6655469331890345, 12.49594772234559, 14.250144492834806, 2.1243394212797284, 1.4946641656570137, 0.8487997599877417, 0.38624013075605035, 25.452611222863197, 45.83610825240612, 32.21735782921314, 46.69037461280823, 5.133452340960503, 0.15146814024774358, 0.12867319310316816, 0.23442003439413384, 0.12738860968966037, 0.16121581953484565, 0.20575676229782403, 0.08450678258668631, 0.1697358232922852, 0.08378358936170116, 0.05425964489404578, 0.1254752342356369, 0.10567166173132136, 0.13366109342314303, 0.15757778193801641, 0.24558815464843065, 0.11456885462393984, 0.12883943418273702, 0.2104590693488717, 0.16262082383036613, 0.10294150080881082, 0.10794667090522125, 0.15038787008961663, 0.1459373885882087], [0.013418197904684348, 0.03785676744882949, 0.09195134756737389, 0.0336329749552533, 0.03303362762380857, 0.05565220708376728, 0.03715309270774014, 0.04441472570761107, 0.0637815888330806, 0.0329251961375121, 0.0338079511129763, 0.0473110349412309, 0.06067992733733263, 0.03500027072732337, 0.026155169180128723, 0.049059750090236776, 0.01981569548661355, 0.0340285841957666, 0.02988022730278317, 0.04612958036886994, 0.03320764641102869, 0.036262530338717625, 0.04015576654637698, 0.03376409018528648, 0.037428696668939665, 0.050194208160974085, 0.033418334714951925, 0.021649321606673766, 0.03506206194288097, 0.2555695956107229, 7.63111911714077, 42.58322060108185, 22.041553258895874, 34.26478676497936, 29.191701784729958, 1.1253233905881643, 0.05623147189908195, 0.16584306576987728, 0.09837178586167283, 0.6740265944972634, 5.420453790575266, 4.080510791391134, 2.4622020917013288, 1.15442484151572, 1.719760880805552, 1.596193767618388, 0.2767471654806286, 4.810235034674406, 23.584931641817093, 52.24646307528019, 55.29467090964317, 53.41284088790417, 51.68240614235401, 50.36349691450596, 51.70540630817413, 53.2724080234766, 53.811276108026505, 55.8021754771471, 52.64527067542076, 51.45929351449013, 55.160830691456795, 54.539902210235596, 53.32612954080105, 55.32576844096184, 51.288534477353096, 43.28474275767803, 41.00832670927048, 40.40591463446617, 43.96388031542301, 49.487427324056625, 51.9910179823637, 54.09470669925213, 52.906928434967995, 53.62405635416508, 48.828356489539146, 41.397843807935715, 37.9530094563961, 40.7947401702404, 40.285727083683014, 40.25494113564491, 38.66575241088867, 39.679222628474236, 44.139237105846405, 45.37505619227886, 45.74675604701042, 45.93299925327301, 50.84908805787563, 50.54583393037319, 53.429886773228645, 46.55153766274452, 47.4378477036953, 54.1674879938364, 51.125914603471756, 51.29737660288811, 50.27095668017864, 48.93249750137329, 50.66069036722183, 49.260845482349396, 50.24520166218281, 46.31592370569706, 39.32148702442646, 37.129947021603584, 36.81230306625366, 35.59343867003918, 36.634396612644196, 36.44452080130577, 38.83751079440117, 35.702838599681854, 38.43318969011307, 37.386285066604614, 37.81392551958561, 39.05327461659908, 40.406458005309105, 39.016849771142006, 39.830815494060516, 36.84909649193287, 36.92686691880226, 35.424412339925766, 34.986432641744614, 35.09441904723644, 37.54583090543747, 38.967885598540306, 42.132044211030006, 43.04667413234711, 44.072771072387695, 46.580773293972015, 46.82064302265644, 47.22001679241657, 47.323264852166176, 44.101387336850166, 45.26314839720726, 45.093210116028786, 42.705714628100395, 43.321490585803986, 19.456854052841663, 1.884795050136745, 0.9002175321802497, 0.7394096266943961, 5.493223685771227, 4.495155466720462, 1.561975060030818, 2.5024300580844283, 3.815813669934869, 2.2913661086931825, 0.13419152121059597, 0.3066085756290704, 0.1135117320518475, 1.6553947096690536, 35.21989971399307, 26.892450861632824, 27.019255757331848, 19.835441038012505, 0.37465413683094084, 0.07637407601578161, 0.03631486288213637, 0.0315742424572818, 0.05954542102699634, 0.02564512447861489, 0.015437535348610254, 0.0037296763684935286, 0.02594269044493558, 0.026259489168296568, 0.05530392831133213, 0.02614367887872504, 0.09117512789089233, 0.040189408100559376, 0.004664776179197361, 0.05203791079111397, 0.007853538445488084, 0.044186262966832146, 0.08226476187701337, 0.03714283993758727, 0.03133729325782042, 0.06899076790432446, 0.030134511216601823, 0.06684047664748505, 0.033986957132583484, 0.03815028685494326, 0.005676559094354161, 0.048797471390571445, 0.02267495856358437, 0.017060377613233868, 0.05295985858538188, 0.06194361558300443, 0.035673183447215706, 0.02240780395368347, 0.06096211414842401, 0.015124631045182468, 0.010439728284836747, 0.07512168696848676, 0.02465989931806689, 0.03463770932285115, 0.019378370125195943, 0.06578690896276385, 0.02393065944488626, 0.011975501784036169, 0.002962456392197055, 0.10177664807997644, 0.024847855638654437, 0.0428987703344319, 0.01956786454684334, 0.013523626475944184, 0.04981781683454756, 0.08242516967584379, 0.13076760806143284, 0.27883634087629616, 12.322842311114073, 47.999229580163956, 21.96269989013672, 44.414570331573486, 31.599423587322235, 0.4413983866106719, 0.08597531472332776, 0.0732880923897028, 0.02300387841387419, 0.7677042740397155, 2.697427519597113, 5.547402128577232, 6.502866083756089, 4.93603678420186, 3.1100761145353317, 3.0206894734874368, 0.9981296095065773, 5.897317752242088, 26.64687003940344, 54.62165482342243, 54.667423367500305, 55.57173304259777, 55.32302878797054, 52.63314172625542, 53.14913883805275, 54.00358758866787, 55.305055752396584, 56.80371053516865, 54.10873934626579, 52.341704964637756, 55.79171843826771, 56.04427568614483, 56.11331798136234, 57.15513467788696, 55.481267496943474, 45.654010623693466, 43.09643246233463, 41.448567286133766, 45.9756937623024, 50.6859590113163, 54.0822471678257, 56.23180702328682, 53.96936282515526, 54.32718202471733, 50.31844653189182, 43.58388550579548, 39.39461030066013, 40.639944076538086, 41.32698900997639, 40.246178805828094, 40.9163374453783, 41.603880152106285, 45.81364385783672, 45.694356858730316, 46.34562291204929, 49.067842438817024, 52.4843493103981, 54.46467764675617, 53.39469686150551, 49.13528881967068, 49.679674208164215, 52.57062368094921, 54.93417665362358, 53.7583639472723, 52.36107252538204, 52.18919634819031, 53.04622896015644, 52.0121144503355, 51.789925172924995, 48.7468546628952, 42.41251476109028, 37.54295825958252, 39.27263304591179, 37.410432770848274, 38.4850987046957, 38.618099167943, 40.13818860054016, 38.87565694749355, 40.13944633305073, 38.35860729217529, 39.95251156389713, 39.813989996910095, 41.35836772620678, 40.615161806344986, 40.79686425626278, 38.96036580204964, 38.52178953588009, 37.00953908264637, 36.38356067240238, 38.35583724081516, 38.47616918385029, 40.16730643808842, 43.72329242527485, 44.98536430299282, 44.34104427695274, 48.17383021116257, 48.67955647408962, 48.62048864364624, 45.975081995129585, 46.33483529090881, 46.537615209817886, 46.48204319179058, 43.73811163008213, 46.07620216906071, 24.300874024629593, 2.8953365748748183, 2.2611206816509366, 2.0307141076773405, 3.7967415433377028, 5.620735818520188, 6.148455301299691, 5.1223555114120245, 3.725791987963021, 1.505020153708756, 0.27134676463901997, 0.21007784293033183, 0.22206823312444612, 1.7675599409267306, 37.50757075846195, 30.774470753967762, 28.655440360307693, 26.40073634684086, 0.7608689751941711, 0.12733974668662995, 0.048579662179690786, 0.11669358631479554, 0.04180339747108519, 0.06883128036861308, 0.04647246372769587, 0.039754234967404045, 0.016486714157508686, 0.016714254779799376, 0.04516918561421335, 0.07300739729544148, 0.05053273882367648, 0.019952410220867023, 0.023694127703492995, 0.015307919256883906, 0.02561213230364956, 0.13332395057659596, 0.10617396212182939, 0.06529153281007893, 0.0529776701296214, 0.03423935784667265, 0.017543580688652582, 0.039232983835972846, 0.11268289410509169, 0.1784591903560795, 0.14245612226659432, 0.0898582165245898, 0.10111514216987416, 0.2282878165715374, 0.1438522950047627, 0.18263022357132286, 0.15317748446250334, 0.15435494628036395, 0.113748788862722, 0.18048863770673051, 0.1320362204569392, 0.1319264419726096, 0.11534678124007769, 0.14682566514238715, 0.12535983027191833, 0.16110250842757523, 0.12763252394506708, 0.1309487663093023, 0.1754556890227832, 0.1528162811882794, 0.19077600678429008, 0.11351718683727086, 0.1177362518501468, 0.12567861238494515, 0.10762692400021479, 0.1236340994364582, 0.19555288483388722, 0.2815356804057956, 16.38479869812727, 58.85932803153992, 29.40005410462618, 43.88761080801487, 37.89119057357311, 2.2491539362818003, 0.19850298122037202, 0.37043882708530873, 0.3033818065887317, 2.964509488083422, 13.615907225757837, 10.666513089090586, 5.220475746318698, 7.499108975753188, 7.664508875459433, 4.479977656155825, 1.0034177382476628, 6.475731264799833, 27.73964200168848, 56.469438672065735, 59.25734527409077, 58.82335916161537, 57.154355719685555, 55.052456706762314, 54.78915363550186, 57.00365200638771, 58.31317573785782, 60.082277208566666, 54.751759842038155, 53.41071680188179, 58.544727712869644, 58.801795318722725, 57.89998970925808, 60.05785971879959, 58.74341145157814, 46.96819290518761, 45.559357702732086, 43.15473273396492, 47.33470983803272, 51.6948276758194, 55.899172872304916, 57.59196683764458, 57.518759965896606, 57.82602287828922, 53.536604046821594, 44.99202534556389, 41.91583201289177, 43.85888434946537, 43.04062105715275, 43.27498488128185, 42.57276736199856, 43.275896832346916, 48.77099096775055, 49.69352826476097, 49.61759693920612, 51.43831104040146, 54.218169674277306, 56.923024132847786, 55.1285932213068, 51.298531740903854, 50.330959260463715, 54.644810780882835, 54.280604124069214, 54.854696318507195, 53.94759759306908, 53.20556960999966, 55.86196526885033, 52.838851287961006, 55.724101066589355, 49.321205243468285, 43.03119756281376, 40.38644827902317, 40.39581097662449, 38.50472845137119, 39.88318428397179, 39.850160256028175, 43.002596497535706, 40.86855500936508, 41.55324786901474, 41.43731229007244, 40.7830785959959, 43.60066540539265, 44.55743886530399, 42.497447803616524, 44.643002673983574, 42.07643419504166, 40.444163382053375, 38.95631521940231, 38.88099566102028, 39.58793252706528, 39.80806231498718, 43.262236565351486, 45.68600870668888, 46.36240281164646, 46.7715572565794, 49.67027731239796, 50.61673052608967, 50.50065815448761, 47.60987587273121, 45.97013846039772, 47.968968003988266, 47.02265538275242, 45.457124188542366, 46.21791556477547, 21.21243204921484, 3.3301650546491146, 2.2078275913372636, 2.27410648483783, 10.508025493472815, 8.483851309865713, 3.925045458599925, 5.647791316732764, 12.424511555582285, 7.573841465637088, 1.2456488027237356, 1.224640323780477, 0.32492160389665514, 3.094975962303579, 46.39790050685406, 35.698123052716255, 37.23422862589359, 28.640442565083504, 0.8708223688881844, 0.21815894055180252, 0.13725641299970448, 0.19275503262178972, 0.13323916762601584, 0.20023871620651335, 0.12447701592464, 0.11601326696109027, 0.05462541608721949, 0.11778498126659542, 0.14329774741781875, 0.1150363111810293, 0.21519336296478286, 0.0929600078961812, 0.13652109308168292, 0.10761106430436485, 0.11208545038243756, 0.35220131976529956, 0.17172624851809815, 0.16958402440650389, 0.13821966131217778, 0.09562768740579486, 0.07555175412562676, 0.2615706907818094], [0.02305859510670416, 0.05573933151026722, 0.10473785441718064, 0.030263130975072272, 0.06857984073576517, 0.08635302336188033, 0.06804211021517403, 0.00690843100528582, 0.02802427738060942, 0.020967078235116787, 0.03034929803106934, 0.0135803469675011, 0.006956810220799525, 0.013825787264067912, 0.026009133071056567, 0.011624474282143638, 0.027686459179676604, 0.020247399079380557, 0.014544987734552706, 0.027936872793361545, 0.07524817119701765, 0.016693368888809346, 0.022280403172771912, 0.10249371858662926, 0.06149257162178401, 0.09632809669710696, 0.03096505610301392, 0.01610069717571605, 0.08250339204096235, 0.07828170724678785, 0.43252090516034514, 27.556417733430862, 40.256324261426926, 31.616855151951313, 46.08972184360027, 12.808896079659462, 0.3121912479400635, 0.08746045612497255, 0.07612948640598916, 0.13529767747968435, 2.3241989593952894, 3.8534736866131425, 6.8320823181420565, 1.8151310132816434, 2.115646912716329, 1.587514914572239, 0.37832853966392577, 1.4846017118543386, 13.850774522870779, 40.42748227715492, 57.59298138320446, 54.471205696463585, 52.37508997321129, 53.175159841775894, 55.15741467475891, 52.07240581512451, 55.552304685115814, 54.894898161292076, 52.47288912534714, 54.37750652432442, 52.39771015942097, 51.96245111525059, 53.91532212495804, 55.41179962456226, 51.71139858663082, 46.09006382524967, 42.621659338474274, 39.624547362327576, 42.950098514556885, 47.68823906779289, 51.58467158675194, 52.78357185423374, 56.75354562699795, 53.42321053147316, 55.05804620683193, 46.92948818206787, 41.839543506503105, 38.43729346990585, 39.92218539118767, 39.915227964520454, 39.218588545918465, 42.28158138692379, 47.32799559831619, 49.46918070316315, 52.91298151016235, 51.06372334063053, 53.69146853685379, 49.45513665676117, 52.62404501438141, 48.51902648806572, 44.40265417098999, 60.03596529364586, 49.439131915569305, 49.04039651155472, 48.353134989738464, 46.13705590367317, 45.28043366968632, 45.00024050474167, 41.167557165026665, 38.76958563923836, 36.13419525325298, 36.969599425792694, 37.957436218857765, 37.907734885811806, 36.40729419887066, 36.08689919114113, 37.632565051317215, 37.37994700670242, 36.26370370388031, 37.14155539870262, 41.13318420946598, 46.49489790201187, 46.425099447369576, 48.05308789014816, 48.815775364637375, 45.830058977007866, 44.366126731038094, 40.48747345805168, 35.63327193260193, 33.426460549235344, 35.691803991794586, 39.08246465027332, 42.439231127500534, 44.18764270842075, 46.85775563120842, 45.985098257660866, 47.11674213409424, 47.574226185679436, 45.06074845790863, 47.23010525107384, 46.51669733226299, 47.067071199417114, 41.64918892085552, 19.457017444074154, 2.109475093893707, 0.5965694726910442, 3.1358475191518664, 0.7897092495113611, 3.657467379234731, 5.585791943594813, 11.17333559319377, 2.6417474448680878, 2.648963020183146, 0.9248649096116424, 0.07198954175692052, 0.05397825960244518, 0.07989999736309983, 11.44497161731124, 38.49357984960079, 23.182309046387672, 32.69508719444275, 7.297766804695129, 0.03089436282607494, 0.07262179220560938, 0.061940283339936286, 0.06189578416524455, 0.04505304321355652, 0.024406797274423297, 0.013627934404212283, 0.053918661433272064, 0.018522796308388934, 0.06341976215480827, 0.024512072777724825, 0.016319782880600542, 0.04250011086696759, 0.0945239579596091, 0.016140899315360002, 0.0286593795317458, 0.007073866854625521, 0.08026863695704378, 0.041298814976471476, 0.016551101034565363, 0.11312128815916367, 0.05064005708845798, 0.048548172853770666, 0.04658730736991856, 0.034338965197093785, 0.04901957021502312, 0.013189010642236099, 0.024127519682224374, 0.06386289853253402, 0.07158319363952614, 0.041894818932632916, 0.02158678453270113, 0.004477801812754478, 0.010081193959194934, 0.031648442381992936, 0.0224794379028026, 0.04209149177768268, 0.04250432626577094, 0.04066503570356872, 0.03567324281902984, 0.03786063032748643, 0.0532925633888226, 0.05392096580180805, 0.03461609056103043, 0.005847725251442171, 0.04666935550631024, 0.03771749230509158, 0.04689132074418012, 0.05629440973279998, 0.028983538504689932, 0.049249146177317016, 0.023619868406967726, 0.016025230033847038, 0.05431186611531302, 1.6784116183407605, 37.880782932043076, 38.94719950854778, 29.232173413038254, 52.2917490452528, 13.527098391205072, 0.3304160200059414, 0.05418409426056314, 0.0499204335937975, 0.05535871365282219, 0.42794939421582967, 2.7466253796592355, 8.478650338947773, 7.607840616255999, 3.844740567728877, 2.7494678646326065, 1.2215186725370586, 2.1285177720710635, 15.86844440549612, 43.340371772646904, 57.52959318459034, 56.59835435450077, 55.79304076731205, 52.443189918994904, 56.80637799203396, 55.865187495946884, 57.22327262163162, 56.64315775036812, 52.63169400393963, 55.12000948190689, 54.19146850705147, 54.46225717663765, 55.51700837910175, 55.98841868340969, 53.64676013588905, 47.898006811738014, 44.55357447266579, 41.486382856965065, 45.48436492681503, 48.83756719529629, 53.296852111816406, 55.20786456763744, 56.346230283379555, 55.32262600958347, 55.54070770740509, 47.9047704488039, 42.388089671730995, 39.3346381187439, 41.622787937521935, 42.031258419156075, 41.56867504119873, 44.29878294467926, 48.579751029610634, 51.12450107932091, 53.589634001255035, 52.14463613927364, 55.03640256822109, 53.394290283322334, 54.02697153389454, 50.53006857633591, 45.79425349831581, 60.34039355814457, 50.165037363767624, 51.45134054124355, 50.21092750132084, 48.43511939048767, 47.75356136262417, 47.934066876769066, 45.772955641150475, 41.38358697295189, 37.97203503549099, 39.030620232224464, 39.11840312182903, 39.312504306435585, 37.47419334948063, 37.38603428006172, 38.74709464609623, 39.60156239569187, 39.098674580454826, 38.76211903989315, 42.98174321651459, 47.602078691124916, 47.639267295598984, 49.15398381650448, 49.85384166240692, 48.23083095252514, 44.747827649116516, 41.1231679469347, 37.20117039978504, 35.35221241414547, 39.107410311698914, 41.51311442255974, 43.93347054719925, 46.70349530875683, 48.38417172431946, 47.231955751776695, 49.05957408249378, 46.696469485759735, 46.12827077507973, 46.451458632946014, 46.23096406459808, 47.345611453056335, 43.61859664320946, 23.650362230837345, 3.7207422964274883, 1.3710533548146486, 5.3141022473573685, 3.7961523374542594, 4.531984515488148, 7.405351381748915, 12.352519668638706, 4.822881231084466, 2.2125493129715323, 0.35562089877203107, 0.16602802381385118, 0.1521314718411304, 0.010631240420480026, 11.487412489950657, 46.4290626347065, 23.935196846723557, 36.48334711790085, 11.327809654176235, 0.028287580244068522, 0.1505665940931067, 0.02358830301091075, 0.047040889476193115, 0.015104859303392004, 0.031156591430772096, 0.025985740576288663, 0.03139242369798012, 0.057085557709797285, 0.030161254508129787, 0.019240868714405224, 0.04575770130031742, 0.034981412754859775, 0.02493281299393857, 0.07188754840171896, 0.06625560490647331, 0.06148595166450832, 0.027045197202824056, 0.0374502449267311, 0.028840244631282985, 0.13786141178570688, 0.01050553451932501, 0.044120816673967056, 0.019086190295638517, 0.13995006767800078, 0.16210335394134745, 0.12488332693465054, 0.14479933481197804, 0.14314906555227935, 0.18398485088255256, 0.16955778206465766, 0.15379866206785664, 0.1500380810466595, 0.10570052385446616, 0.13045324914855883, 0.09233759832568467, 0.09907292245770805, 0.08120676357066259, 0.12485159269999713, 0.11443031049566343, 0.11933869711356238, 0.12284299969905987, 0.11206357929040678, 0.10123895466676913, 0.16633082006592304, 0.12206929590320215, 0.1737536772270687, 0.20284260070184246, 0.12102532418793999, 0.22981111920671538, 0.13910532550653443, 0.11438262750743888, 0.19363806961337104, 0.24957330955658108, 2.3389034578576684, 43.45924839377403, 51.637997925281525, 38.499097153544426, 58.36151674389839, 18.951887749135494, 0.8714683342259377, 0.3085405641468242, 0.3451543307164684, 1.1500218277797103, 7.121334196999669, 12.960168812423944, 18.70200365781784, 8.357235454022884, 6.526501765474677, 4.181057196110487, 1.3565579638816416, 2.985528535209596, 16.909109763801098, 43.25253188610077, 59.00775946676731, 58.7588956207037, 56.78800977766514, 54.55686829984188, 60.53315341472626, 57.28741317987442, 58.73095951974392, 58.10684680938721, 53.61073426902294, 56.74234002828598, 55.556834042072296, 56.26058667898178, 57.0694150775671, 58.81568357348442, 55.65953113138676, 50.10571874678135, 47.1099328994751, 43.778803646564484, 46.57120920717716, 52.57231079041958, 56.58760853111744, 57.4428628385067, 59.59790959954262, 57.51987710595131, 59.42549765110016, 50.59131748974323, 46.493940353393555, 42.644264325499535, 44.17706407606602, 44.151635840535164, 41.86923511326313, 47.4585147947073, 50.92033043503761, 53.75908210873604, 57.76087537407875, 55.02461940050125, 57.47988045215607, 55.19445888698101, 57.218952253460884, 54.223280400037766, 47.75624781847, 61.42446778714657, 53.86214017868042, 52.318165227770805, 52.44418926537037, 49.08776476979256, 48.59872341156006, 50.123319402337074, 45.80075114965439, 43.12294363975525, 40.834326446056366, 41.11556455492973, 42.271956503391266, 41.46396026015282, 40.10380804538727, 39.20393653213978, 39.891175255179405, 42.37881436944008, 41.08866959810257, 39.83993120491505, 44.93334889411926, 51.046559661626816, 50.3330909460783, 51.183777898550034, 52.668616622686386, 51.58741123974323, 48.195986822247505, 44.578071758151054, 39.39791992306709, 36.49260722100735, 40.10747864842415, 43.68272580206394, 45.89622862637043, 48.074381947517395, 51.51109993457794, 49.396220818161964, 52.52240426838398, 49.58988502621651, 46.60907797515392, 48.17413419485092, 47.631181329488754, 46.77139386534691, 44.94660258293152, 21.399437114596367, 3.0269087897613645, 1.2633483717218041, 7.193132294341922, 3.7924076383933425, 8.599403109401464, 14.13545049726963, 21.537635698914528, 10.299167800694704, 7.3910014517605305, 3.3592102210968733, 0.62638581963256, 0.5329784005880356, 0.25139605393633246, 16.583079658448696, 49.989281594753265, 30.788792185485363, 47.230044454336166, 14.243720937520266, 0.1665797215537168, 0.3346783819142729, 0.1898741043987684, 0.08524336415575817, 0.10877026186790317, 0.13370428641792387, 0.0973901768156793, 0.12293984997086227, 0.2617299556732178, 0.1331374785513617, 0.13864218082744628, 0.1319761510239914, 0.18722662614891306, 0.09041455268743448, 0.18831540131941438, 0.16437079320894554, 0.20332630287157372, 0.18013987282756716, 0.16208154964260757, 0.0543951091094641, 0.2221644896781072, 0.1765134127344936, 0.1509127762983553, 0.15363052109023556], [0.14623188762925565, 0.06162292615044862, 0.043304613791406155, 0.03849117012578063, 0.0956296912045218, 0.02013807330513373, 0.0403503910638392, 0.022429485798056703, 0.022776447258365806, 0.007919679574115435, 0.05189618284930475, 0.059567588978097774, 0.04991334608348552, 0.0225705996126635, 0.003251001321586955, 0.03396967251319438, 0.03672456550702918, 0.04313409423048142, 0.06548737816046923, 0.035568510938901454, 0.06814270091126673, 0.09472078294493258, 0.031964738300303, 0.06166740306071006, 0.021172654996917117, 0.054607185229542665, 0.029775803413940594, 0.02055006360023981, 0.06425496772862971, 0.09128045348916203, 0.08792443200945854, 6.152997957542539, 40.992770344018936, 31.091421246528625, 37.20868639647961, 32.09541857242584, 8.306169994175434, 0.9416195168159902, 0.05992344878904987, 0.15402990044094622, 0.3203224256867543, 1.4071011892519891, 6.7354905512183905, 7.317653512582183, 1.6159499762579799, 2.482448830269277, 0.8426779322326183, 0.2810627839062363, 4.690040834248066, 24.303114004433155, 50.6520040333271, 57.98801578581333, 56.392143219709396, 53.52461189031601, 52.56653510034084, 54.65611517429352, 56.688534915447235, 54.09766674041748, 55.000722482800484, 55.28830245137215, 53.5550444573164, 53.63287568092346, 55.91532960534096, 53.998951837420464, 52.63170540332794, 45.44551581144333, 43.03625509142876, 40.13349585235119, 41.879084184765816, 45.1794008910656, 50.626195818185806, 53.919577896595, 56.29718251526356, 55.1727544516325, 53.77100586891174, 51.23835436999798, 46.20595760643482, 37.89570473134518, 40.11920101940632, 40.17023608088493, 42.36664742231369, 42.82526761293411, 52.129372358322144, 53.89433965086937, 56.30657561123371, 52.40997590124607, 54.598890244960785, 52.51180663704872, 51.97097785770893, 46.82008445262909, 48.65409404039383, 56.441422775387764, 50.65427251160145, 49.302871227264404, 46.063191667199135, 44.06682439148426, 40.343035608530045, 41.402886137366295, 38.95996302366257, 37.510823383927345, 38.30250330269337, 39.309092089533806, 37.38356441259384, 37.239932119846344, 35.79746872186661, 37.207637652754784, 37.079603523015976, 37.33638234436512, 37.58598335087299, 43.24591264128685, 49.508675783872604, 50.34086912870407, 52.40301467478275, 50.76736964285374, 48.9383339881897, 50.79150214791298, 46.66537955403328, 43.86336050927639, 39.12493497133255, 36.839642599225044, 37.74935558438301, 40.32642289996147, 43.03694665431976, 45.944064259529114, 44.55789864063263, 47.48935014009476, 47.05869644880295, 44.112858921289444, 45.30944511294365, 47.035703882575035, 46.965635642409325, 41.98181167244911, 16.61325953900814, 2.768634748645127, 0.24211209820350632, 0.9985625487752259, 2.8371436474844813, 4.486168473958969, 2.6372924214228988, 4.434429025277495, 16.70278463512659, 12.596693616360426, 1.182046509347856, 0.39570708526298404, 0.26777655933983624, 0.1418357016518712, 1.2508126068860292, 27.494720444083214, 28.527088947594166, 25.035589300096035, 25.578819550573826, 1.4224808639846742, 0.00552826221792202, 0.019003071611223277, 0.029303602677828167, 0.06435471979784779, 0.05387798431911506, 0.01955064115463756, 0.03417018597247079, 0.026527282025199383, 0.049379945994587615, 0.009334859641967341, 0.04422946338308975, 0.05244201391178649, 0.08728145752684213, 0.0462778726068791, 0.07821495848475024, 0.018207298198831268, 0.021137755502422806, 0.041695990148582496, 0.014162487605062779, 0.014236304396035848, 0.0681799344602041, 0.035714265031856485, 0.01759240843966836, 0.03973951817897614, 0.04616886595613323, 0.07869532098993659, 0.029726485845458228, 0.005475436146298307, 0.04388401961477939, 0.06028347946994472, 0.019830941055261064, 0.0432210999133531, 0.03415415558265522, 0.041278168428107165, 0.008027472813409986, 0.03835296738543548, 0.09005778003484011, 0.020576001661538612, 0.030055780480324756, 0.07084348020725884, 0.02392748119746102, 0.009827513040363556, 0.015746425560791977, 0.03377385684871115, 0.007493087523471331, 0.03574828137061559, 0.06650443217949942, 0.017407376180926803, 0.01997636860323837, 0.037700901593780145, 0.057487415833747946, 0.056256957250298, 0.023211961779452395, 0.09557744400808588, 0.11688003607559949, 10.591228678822517, 48.1061976402998, 33.039033338427544, 46.63961313664913, 37.02983379364014, 7.756590759381652, 0.5600826430600137, 0.1693160497234203, 0.3338760312180966, 0.1181353120773565, 0.6129940913524479, 4.995757704600692, 8.774308674037457, 5.83582422696054, 4.263082444667816, 2.067025196738541, 0.7674362102989107, 5.813711788505316, 28.633057661354542, 52.87365362048149, 58.49234752357006, 56.777237355709076, 56.290259286761284, 53.69606249034405, 55.45946046710014, 58.857576325535774, 54.37588021159172, 54.72368314862251, 56.16656452417374, 54.57495532929897, 53.74711275100708, 56.294017285108566, 54.03251923620701, 54.66752216219902, 48.55400361120701, 45.54762773215771, 43.03805239498615, 43.407669961452484, 46.70531541109085, 52.28114761412144, 53.95742766559124, 58.7145671993494, 57.103427052497864, 55.92193745076656, 52.33352020382881, 48.30174654722214, 39.64263439178467, 41.670509576797485, 43.463032990694046, 43.864325657486916, 44.20257210731506, 54.173715859651566, 53.992830365896225, 58.42572569847107, 52.0170845836401, 56.5062814950943, 53.547213077545166, 53.43641862273216, 49.11470912396908, 48.69965739548206, 58.70286762714386, 52.195264622569084, 50.44140413403511, 48.663316145539284, 44.777196273207664, 42.06234075129032, 43.17311234772205, 40.50594046711922, 39.921368435025215, 39.574982821941376, 39.71394136548042, 39.24740619957447, 38.02016705274582, 37.621306255459785, 38.53605397045612, 40.146236568689346, 38.01638625562191, 38.986800983548164, 43.809562996029854, 50.78156568109989, 53.01329232752323, 53.34226727485657, 53.4349063038826, 50.77695272862911, 51.88839688897133, 48.95073652267456, 46.65348619222641, 42.17171788215637, 37.49437786638737, 39.11055274307728, 41.78238697350025, 45.38015931844711, 46.703081130981445, 46.73086903989315, 47.45460860431194, 48.561375215649605, 45.839611664414406, 46.302130445837975, 48.01301144063473, 46.43891550600529, 44.583277478814125, 20.953337252140045, 4.606324676424265, 1.4611728815361857, 2.3747835075482726, 4.304813705384731, 4.343297090381384, 4.559722552075982, 8.522579781711102, 20.215785428881645, 12.397396210581064, 0.4302194161573425, 0.2859049412654713, 0.20524643186945468, 0.3241913305828348, 1.1415210901759565, 31.180480867624283, 36.2242466211319, 26.94438647478819, 32.487040758132935, 2.645095777697861, 0.04414800525410101, 0.03661961840407457, 0.07184221060015261, 0.031609561265213415, 0.055733334957039915, 0.03976072504883632, 0.07843243743991479, 0.11102612363174558, 0.010374521334597375, 0.020676557105616666, 0.041256813128711656, 0.05547428831050638, 0.025961284954973962, 0.013019454017921817, 0.030907487707736436, 0.056252853173646145, 0.05982498805678915, 0.01263011499759159, 0.029991972478455864, 0.029434330135700293, 0.03545271363691427, 0.016572456333960872, 0.04915791025268845, 0.05870282737305388, 0.26698038331232965, 0.22112659615231678, 0.13542994303861633, 0.20154336729319766, 0.21708491927711293, 0.1495980320032686, 0.09276922399294563, 0.13444843789329752, 0.09620296317734756, 0.13875817850930616, 0.08714885800145566, 0.10926163784461096, 0.16162236803211272, 0.06520395196275786, 0.08018201348022558, 0.11859201491461135, 0.1308375332155265, 0.1739962407737039, 0.14435622812015936, 0.18113337107934058, 0.1855887210695073, 0.15748597827041522, 0.2740276692202315, 0.16140074789291248, 0.14688782743178308, 0.1944848007406108, 0.1401620398974046, 0.10368606788688339, 0.15562036744086072, 0.3181135863997042, 0.2545671322150156, 11.81780856102705, 56.6423711925745, 42.41586618125439, 48.70336599647999, 40.05773551762104, 12.495434749871492, 1.58760373480618, 0.3173362906090915, 0.5773629283066839, 0.8724309888202697, 7.466422654688358, 16.151310727000237, 13.721209075301886, 6.383447041735053, 7.504350794479251, 2.9509981255978346, 0.7452368515077978, 6.872074697166681, 29.46319531649351, 53.79819341003895, 62.55189009010792, 60.91224767267704, 58.08948554098606, 56.91946752369404, 58.6997289955616, 60.127073004841805, 53.80717612802982, 55.28705611824989, 58.31854484975338, 54.69055272638798, 56.15991108119488, 59.90044556558132, 56.46982625126839, 56.987852454185486, 50.86036205291748, 47.1672186255455, 44.483745619654655, 45.673347786068916, 48.90456140041351, 54.0733290463686, 57.92248070240021, 61.67493894696236, 58.860346376895905, 59.85561557114124, 54.992055147886276, 51.87080003321171, 40.15869230031967, 42.82358430325985, 44.9696559458971, 46.73292472958565, 45.940241664648056, 55.74813857674599, 57.29975871741772, 60.90785130858421, 55.38948342204094, 58.17367382347584, 56.7671412974596, 53.2440235465765, 49.719849452376366, 51.86378940939903, 59.253860861063, 55.54687097668648, 52.14957967400551, 50.383552238345146, 45.93665465712547, 44.50324237346649, 44.20404642820358, 43.892683535814285, 41.3961187005043, 43.69294725358486, 41.68191276490688, 41.29300743341446, 39.875018522143364, 40.62675878405571, 40.07334508001804, 41.34996257722378, 40.76157934963703, 41.753303334116936, 47.13239349424839, 53.65236483514309, 54.35566149652004, 55.80025278031826, 55.55610828101635, 52.41520442068577, 54.386447444558144, 48.773130252957344, 47.88642503321171, 42.86908686161041, 40.26437222957611, 40.4325246065855, 44.95586268603802, 47.26524576544762, 48.70167128741741, 47.90148362517357, 52.67088510096073, 49.38382588326931, 46.65665902197361, 46.84998884797096, 50.09053856134415, 47.9734555631876, 45.96286565065384, 19.177175760269165, 4.17732342146337, 1.0081933694891632, 2.702105543576181, 6.543801287189126, 9.194288738071918, 9.778249002993107, 10.587365236133337, 24.5925235748291, 25.115293823182583, 4.93254192173481, 0.6050572078675032, 0.6117206846829504, 0.3951256274012849, 2.9282546835020185, 35.550751760602, 38.42550650238991, 33.45105282962322, 39.97819438576698, 3.085711821913719, 0.1266924454830587, 0.16026747354771942, 0.16748867434216663, 0.11232611403102055, 0.14282541495049372, 0.11236239763093181, 0.2027363993693143, 0.241563695599325, 0.1533047776320018, 0.09669781982665882, 0.1079596510680858, 0.17566696362337098, 0.14947235671570525, 0.08850563011947088, 0.20610874809790403, 0.13884158106520772, 0.07878934367909096, 0.1400348506285809, 0.07559114732430317, 0.09078281378606334, 0.16925369447562844, 0.14191453257808462, 0.151948309794534, 0.19873361103236675], [0.04204948250844609, 0.05871126188139897, 0.06581472465768456, 0.035875901085091755, 0.06718190168612637, 0.02672144641110208, 0.07923006065539084, 0.02091688678774517, 0.012175190531706903, 0.00952978009081562, 0.05930275729042478, 0.092058439477114, 0.062208194940467365, 0.028838795587944333, 0.026112438172276597, 0.06894292164361104, 0.006209001812749193, 0.023633423734281678, 0.0713705163798295, 0.01178368629553006, 0.044423594372347, 0.04469539853744209, 0.017587076108611654, 0.04367263740277849, 0.023712994952802546, 0.016878150672710035, 0.05867087049409747, 0.004383384857646888, 0.06511035229777917, 0.14019721769727767, 0.028460905123210978, 0.3015428240178153, 21.493753753602505, 34.8877177387476, 24.552893601357937, 38.87439541518688, 26.99822198599577, 10.538540706038475, 0.9040889306925237, 0.2853107184637338, 0.02738060527917696, 0.5604698660317808, 3.105092206969857, 9.496347829699516, 4.800419686362147, 2.383742951788008, 1.482605750206858, 1.0819881409406662, 0.4012495034839958, 7.569338232278824, 27.995784357190132, 49.34232071042061, 56.12495295703411, 55.70814572274685, 55.738122314214706, 56.08492210507393, 54.59697514772415, 54.38648164272308, 55.87766222655773, 56.05380937457085, 55.11695824563503, 55.31221076846123, 56.10964737832546, 55.068054869771004, 51.49287611246109, 49.368866086006165, 44.04931493103504, 42.45924465358257, 41.595254614949226, 43.827916011214256, 48.41800890862942, 53.20562660694122, 55.401106998324394, 54.89888794720173, 54.14555177092552, 54.70816858112812, 49.84033338725567, 40.30894383788109, 40.26797063648701, 42.73562662303448, 41.32929548621178, 42.292809784412384, 48.717383444309235, 53.12941409647465, 53.18998284637928, 53.496326208114624, 54.00263763964176, 53.62744577229023, 50.955850929021835, 51.076331064105034, 49.48520064353943, 54.013410061597824, 52.46046759188175, 48.837248012423515, 49.2965217679739, 45.7563429325819, 39.988940209150314, 39.868999645113945, 40.09470373392105, 38.462121337652206, 38.5243733972311, 39.499298483133316, 36.98710508644581, 36.4388857036829, 37.32366822659969, 36.719075068831444, 38.05265910923481, 37.487944811582565, 40.028370693325996, 47.950702384114265, 51.77092619240284, 53.14647138118744, 50.408410504460335, 48.512650430202484, 50.373399183154106, 51.59149222075939, 48.64465534687042, 44.005514681339264, 43.531383723020554, 40.481978952884674, 37.697932943701744, 40.13913094997406, 42.75883957743645, 44.585181176662445, 47.77619294822216, 46.285418942570686, 46.952602341771126, 46.122301295399666, 47.29185573756695, 44.8150422424078, 41.13919548690319, 19.202163219451904, 4.247786840423942, 1.3634146959520876, 1.1238833866082132, 1.7492252122610807, 3.27301065903157, 3.125945725478232, 2.311395783908665, 7.422768697142601, 13.62908586859703, 6.147798411548138, 0.47698041948024184, 0.05061999683675822, 0.05515405529877171, 0.6410674599464983, 13.095048274844885, 39.201645255088806, 24.4419414550066, 28.574612997472286, 12.064201589673758, 0.1781416402081959, 0.047078334537218325, 0.014588599115086254, 0.026702211798692588, 0.03410553377761971, 0.017774384905351326, 0.049247583956457675, 0.044553106563398615, 0.039555933108204044, 0.025597011044737883, 0.0861796947719995, 0.07951642575790174, 0.04806316450412851, 0.06916645652381703, 0.05459837593662087, 0.09900081538944505, 0.03845385494059883, 0.016087095464172307, 0.02846327071893029, 0.035681168956216425, 0.021314627847459633, 0.0383464327751426, 0.054582775992457755, 0.08957295722211711, 0.0412929000594886, 0.03374163279659115, 0.017829457829066087, 0.04938670695992187, 0.018477041048754472, 0.03393617567780893, 0.01742504671710776, 0.017310973053099588, 0.029099346938892268, 0.024688791127118748, 0.08677969890413806, 0.06075100653106347, 0.02267011790536344, 0.02721207096328726, 0.028158138557046186, 0.045123187301214784, 0.04569706041365862, 0.06570859753992409, 0.05858771655766759, 0.057461618780507706, 0.03450354386586696, 0.02805083327984903, 0.05233940086327493, 0.08368144757696427, 0.02370164009334985, 0.016111593758978415, 0.02232351638667751, 0.022491941235784907, 0.044497976123238914, 0.03341186689794995, 0.09453577295062132, 0.02971894748043269, 1.258810821454972, 31.02260883897543, 38.381337672472, 28.862552046775818, 43.43319319188595, 33.68036672472954, 9.506768770515919, 0.9710076148621738, 0.268178922124207, 0.08924403737182729, 0.08963008775026537, 1.899378311354667, 7.559174727648497, 7.149388566613197, 3.1052159378305078, 1.9105529179796576, 2.2394682560116053, 1.6283115441910923, 10.645619910210371, 31.288847252726555, 54.484102204442024, 58.80895793437958, 56.664729192852974, 56.732156574726105, 56.52296259999275, 54.02563400566578, 54.941099882125854, 57.0743852108717, 56.68711379170418, 55.938926339149475, 56.692281514406204, 57.481320574879646, 56.939161866903305, 51.9616911560297, 50.069708079099655, 45.70670619606972, 44.013258665800095, 43.386318907141685, 46.77127607166767, 49.456075206398964, 55.80639325082302, 56.7661077529192, 55.26722118258476, 56.44858919084072, 57.4810241907835, 52.18044921755791, 42.461843714118004, 42.06720069050789, 42.987401112914085, 40.5378283560276, 44.91758733987808, 51.87844522297382, 53.95881839096546, 55.42947627604008, 55.135679841041565, 54.75575342774391, 54.357952773571014, 50.57384982705116, 50.769451931118965, 50.84831289947033, 57.362690940499306, 53.278233110904694, 50.71147084236145, 50.98025321960449, 45.24506136775017, 41.55320227146149, 40.44299304485321, 42.04845629632473, 39.547191113233566, 39.46818195283413, 41.054125651717186, 39.267845302820206, 37.963945269584656, 39.76147681474686, 38.28144483268261, 39.8822533339262, 39.46698501706123, 41.3506693392992, 48.04744519293308, 52.60265216231346, 53.231165036559105, 51.32348120212555, 49.782302901148796, 51.90598614513874, 52.34295889735222, 50.75373217463493, 45.98953261971474, 45.00448487699032, 41.60558246076107, 38.46681788563728, 40.59515208005905, 44.65398408472538, 46.527701541781425, 49.343654438853264, 48.97765427827835, 47.50116750597954, 46.2705959379673, 48.15546579658985, 45.74394799768925, 42.64366775751114, 23.612521961331367, 6.5228834096342325, 2.6804089453071356, 3.0435169860720634, 3.0286443466320634, 4.007710497826338, 4.2503156047314405, 5.493947546929121, 7.829208187758923, 7.816058993339539, 5.976238092407584, 0.7681072899140418, 0.06181175820529461, 0.09517183803836815, 0.5015005334280431, 12.615476958453655, 43.891782984137535, 26.671975292265415, 30.964308567345142, 17.17911947518587, 0.3780404379358515, 0.09554757256410085, 0.06730431152391247, 0.011491462864796631, 0.06678857826045714, 0.01950570040207822, 0.020720037682622205, 0.03472318247077055, 0.04163443642028142, 0.009650874471844872, 0.015257455997925717, 0.07210021823993884, 0.034069409739458933, 0.08955947239883244, 0.014919264867785387, 0.05571088127908297, 0.04660947532102, 0.023129679866542574, 0.030843609201838262, 0.01861575587099651, 0.02469303992256755, 0.01572338744153967, 0.12037670938298106, 0.08305704162921757, 0.02191551884607179, 0.09521664891508408, 0.14048980199731886, 0.17015442426782101, 0.12908723729196936, 0.23177041875896975, 0.18987524730619043, 0.2750382962403819, 0.1199277768319007, 0.11579146128497086, 0.1845594067708589, 0.17174340697238222, 0.1270232058595866, 0.12273978180019185, 0.0928076301352121, 0.15611523151164874, 0.1529436040436849, 0.08825746335787699, 0.15329759364249185, 0.14206217543687671, 0.1473901723511517, 0.12552917352877557, 0.110209672129713, 0.16129797528265044, 0.11339120726916008, 0.10995000950060785, 0.06834123283624649, 0.10323994065402076, 0.14015936816576868, 0.08707384913577698, 0.30430545390117913, 0.11602399841649458, 1.3822797336615622, 33.77991758286953, 49.2053646594286, 34.681989178061485, 47.70243510603905, 37.5631807744503, 14.755720663815737, 2.031288114376366, 0.43314816837664694, 0.2449485717806965, 1.498542451299727, 7.499160273000598, 16.8625907599926, 12.173780109733343, 6.652275966480374, 6.405926635488868, 4.059046218171716, 1.4336175913922489, 9.902264848351479, 31.349951773881912, 54.114366844296455, 59.87423077225685, 59.83310177922249, 58.458590134978294, 56.02424696087837, 53.835089430212975, 56.407490596175194, 58.73336099088192, 58.121457025408745, 57.55842603743076, 58.117820620536804, 58.27192895114422, 60.52616938948631, 54.60922949016094, 54.12215642631054, 49.201040491461754, 45.76592601835728, 45.75362227857113, 48.007786720991135, 52.93341301381588, 58.491519168019295, 58.709080293774605, 57.00761139392853, 56.1299154907465, 60.53110912442207, 53.270071148872375, 45.464917570352554, 45.434082224965096, 47.302966341376305, 44.67870555818081, 46.45433887839317, 51.95044755935669, 55.731020495295525, 55.74981048703194, 56.34200870990753, 56.10235936939716, 54.76907931268215, 51.51773817837238, 51.152034401893616, 52.416264563798904, 58.100687339901924, 56.63297049701214, 52.63656534254551, 53.519892543554306, 50.07700368762016, 43.17161902785301, 43.7296798825264, 44.25264582037926, 42.288386821746826, 41.11123278737068, 42.89749413728714, 40.02361334860325, 40.70229113101959, 42.03337490558624, 41.33647330105305, 42.10240200161934, 41.32244825363159, 44.09009054303169, 51.21688552200794, 55.14184691011906, 54.623330533504486, 53.102169558405876, 50.051674246788025, 53.907764330506325, 53.424810245633125, 53.41838479042053, 47.88732558488846, 46.79598994553089, 43.5198475420475, 40.193004459142685, 42.86439411342144, 46.90417394042015, 48.613607212901115, 52.02054239809513, 49.95897822082043, 49.93049114942551, 47.74449124932289, 48.50508503615856, 46.54712609946728, 43.952245339751244, 21.59954197704792, 5.412636185064912, 2.1515960711985826, 2.972219749353826, 3.9380020508542657, 10.114297270774841, 8.7675934843719, 8.827967494726181, 16.583174653351307, 19.589622728526592, 13.697008173912764, 0.909489628393203, 0.3708533907774836, 0.25365488429088145, 1.328529599122703, 19.395605139434338, 50.40800392627716, 33.003987818956375, 40.37774294614792, 19.756635166704655, 0.4524886258877814, 0.17162936856038868, 0.1590636803302914, 0.09928110972396098, 0.1051024196203798, 0.124858969647903, 0.19188532460248098, 0.13574399024946615, 0.10324786679120734, 0.16048556106397882, 0.21887125389184803, 0.11896947122295387, 0.19195695669623092, 0.21205612662015483, 0.14824567566392943, 0.1988113732659258, 0.1447893603472039, 0.19671056099468842, 0.0755067057616543, 0.11569096706807613, 0.11205736009287648, 0.10459266806719825, 0.23160063021350652, 0.22839113837108016, 0.13476857071509585], [0.03125903007457964, 0.051402316967141815, 0.07333852874580771, 0.03531194306560792, 0.03724431007867679, 0.07655058841919526, 0.11520676765940152, 0.024967812678369228, 0.030181388974597212, 0.04616815349436365, 0.050389604512020014, 0.053367379296105355, 0.007955913079058519, 0.059058709448436275, 0.038679909412167035, 0.05589679298282135, 0.03427237599680666, 0.05212551390286535, 0.013083208214084152, 0.0324158527655527, 0.020739773244713433, 0.02719023141253274, 0.04391496717289556, 0.03236174277844839, 0.03791374954744242, 0.03169682669977192, 0.11166399213834666, 0.052214593888493255, 0.027853603824041784, 0.07097687383065931, 0.04513893567491323, 0.0552276021335274, 3.198390263132751, 34.030574932694435, 32.41906240582466, 27.73538053035736, 37.35163852572441, 29.808606281876564, 12.180766984820366, 0.7916444737929851, 0.15655680937925354, 0.17719301220495254, 1.8058121320791543, 7.4790451023727655, 5.420743050053716, 2.959513943642378, 1.7853426304645836, 2.1052034106105566, 0.16550304339034483, 0.5505380895920098, 6.742067048326135, 24.72772601991892, 44.66558866202831, 51.57463252544403, 56.10877722501755, 55.62643110752106, 51.97411648929119, 57.924502193927765, 55.55389679968357, 55.23152969777584, 53.456872925162315, 56.20450168848038, 58.098475858569145, 55.910997837781906, 52.919045984745026, 47.545902505517006, 45.16977220773697, 43.28164592385292, 40.148987621068954, 41.751194447278976, 46.06707505881786, 52.31161057949066, 57.192558869719505, 55.366798639297485, 54.36654791235924, 56.952848732471466, 52.1104721724987, 42.068158239126205, 37.75169625878334, 41.31316535174847, 41.23333543539047, 41.467516869306564, 50.064623951911926, 51.983802169561386, 54.21242818236351, 52.29079529643059, 52.981206849217415, 54.81262117624283, 57.23960794508457, 51.415386870503426, 41.558825969696045, 50.534491539001465, 56.164505034685135, 51.6593261808157, 52.81239330768585, 49.77950245141983, 45.3110334277153, 39.018685072660446, 39.55066792666912, 42.669981345534325, 41.28510385751724, 36.595558896660805, 37.73017801344395, 36.72841116786003, 40.8004854619503, 36.68706938624382, 38.423712998628616, 38.194532096385956, 42.054710760712624, 48.669825196266174, 52.860939502716064, 51.299322098493576, 49.794606640934944, 50.18288500607014, 50.89709848165512, 50.5514158308506, 48.475040048360825, 45.266085639595985, 43.00711065530777, 38.53412367403507, 39.74902868270874, 40.741258040070534, 43.19783382117748, 47.21391811966896, 47.74224556982517, 48.6435230076313, 49.13192979991436, 46.93949684500694, 45.29279440641403, 41.878852397203445, 23.936844058334827, 6.409336477518082, 0.8343944360967726, 1.0520193865522742, 3.2004628144204617, 2.3464660020545125, 2.384229563176632, 2.4352064402773976, 2.3131622141227126, 5.746454922482371, 8.112324345856905, 1.1864053504541516, 0.06119017612945754, 0.059603991321637295, 0.5744801892433316, 8.25784893706441, 33.19503016769886, 31.002880297601223, 25.80308921635151, 28.51696439087391, 2.5828634295612574, 0.008151353958965046, 0.07311621098779142, 0.060425849369494244, 0.0494653337955242, 0.014399768915609457, 0.03810804751992691, 0.025247607918572612, 0.06021122768288478, 0.03100706537225051, 0.03178663027938455, 0.03682910813950002, 0.060307339517748915, 0.023459846524929162, 0.036482543728197925, 0.02859328014892526, 0.02368157984165009, 0.0592561652592849, 0.06641922620474361, 0.0491951252479339, 0.03069187525397865, 0.04112431008252315, 0.013837536389473826, 0.03339736162160989, 0.024236348217527848, 0.009302922244387446, 0.04962907754816115, 0.04931700816086959, 0.04169621650362387, 0.0410755435586907, 0.05905914360482711, 0.041901049262378365, 0.023307311057578772, 0.07798893740982749, 0.026906606690317858, 0.03598590592446271, 0.002185393450417905, 0.06335257552564144, 0.04462801523914095, 0.030141710049065296, 0.019457644484646153, 0.0162342299518059, 0.021226332682999782, 0.01651068181672599, 0.04488650898565538, 0.08389827344217338, 0.06547987504745834, 0.022781150619266555, 0.03268407235736959, 0.06013548409100622, 0.019886199515894987, 0.05024353871704079, 0.07980613052495755, 0.02167766051570652, 0.06770377251086757, 0.003958544275519671, 0.035419684354565106, 0.059345271220081486, 6.960673592984676, 41.08144998550415, 32.35079526901245, 30.4420854896307, 44.240931048989296, 36.93246401846409, 11.036075558513403, 0.8503016887698323, 0.07596883369842544, 0.1183956055319868, 0.23121581180021167, 1.7047753161750734, 6.081224558874965, 5.909474724903703, 5.7438834104686975, 4.897335385903716, 0.8510956086684018, 0.4383442411199212, 9.090219922363758, 30.044697113335133, 47.41195969283581, 56.72599710524082, 58.330597802996635, 57.378186509013176, 53.88503395020962, 58.435779958963394, 55.43674908578396, 56.1773369461298, 56.160690039396286, 57.12993822991848, 58.65902557969093, 59.95679274201393, 55.235382691025734, 50.72384297847748, 47.84370392560959, 45.2907083183527, 40.245483443140984, 45.42818874120712, 48.729113414883614, 54.15149085223675, 58.52903835475445, 56.18498593568802, 55.41218340396881, 58.344497457146645, 52.905256524682045, 43.476803451776505, 40.023609548807144, 43.73298950493336, 42.96673022210598, 44.11529839038849, 52.22747549414635, 55.545658841729164, 55.27324005961418, 53.45976456999779, 54.90484222769737, 54.7502551227808, 55.91974496841431, 50.999810770154, 43.265614584088326, 52.299572825431824, 58.025139793753624, 54.500300735235214, 53.3506990224123, 52.05350562930107, 46.88047841191292, 41.19654580950737, 40.30680075287819, 42.53765344619751, 43.12083475291729, 39.74604204297066, 38.76385934650898, 39.01165544986725, 41.56891442835331, 38.54630962014198, 40.305691212415695, 41.136592626571655, 41.722509786486626, 51.17378443479538, 54.299299120903015, 51.18172600865364, 49.62999567389488, 51.31411090493202, 51.941259652376175, 51.88275799155235, 48.83150652050972, 46.115499660372734, 45.33791698515415, 42.014459520578384, 40.17865262925625, 42.397615760564804, 44.801404774188995, 48.05707387626171, 49.67757672071457, 48.68335247039795, 51.71740986406803, 47.876287177205086, 45.85330232977867, 43.30905005335808, 27.999356165528297, 7.261639293283224, 1.6658559045754373, 2.8981714602559805, 4.350074026733637, 4.90994025953114, 3.5318183340132236, 4.600149057805538, 5.908258315175772, 7.097349409013987, 2.7866291580721736, 0.6816552788950503, 0.010777931474876823, 0.06294815699220635, 0.6070012785494328, 7.1229505352675915, 36.88963271677494, 36.76410645246506, 25.727573968470097, 34.09997820854187, 4.671601848676801, 0.04029900846944656, 0.05666794007993303, 0.04526162752881646, 0.021635100201820023, 0.01191688510516542, 0.07668824939173646, 0.023715392089798115, 0.05010459753975738, 0.025304243063146714, 0.03223194114980288, 0.04871810240729246, 0.025283470349677373, 0.0638832185359206, 0.08743144557229243, 0.013277877260406967, 0.03496343793813139, 0.07538578764069825, 0.041017496478161775, 0.019791486629401334, 0.029821337884641252, 0.04171041749941651, 0.026671679843275342, 0.05777633392426651, 0.021234080704743974, 0.06406841406715102, 0.1422981041832827, 0.15693168301368132, 0.16057985834777355, 0.17210653983056545, 0.1674937951611355, 0.12350808276096359, 0.19580028718337417, 0.16449406393803656, 0.08374601442483254, 0.1725629754946567, 0.2377194448490627, 0.20447943708859384, 0.0832305038056802, 0.12894140527350828, 0.17803382099373266, 0.1909787318436429, 0.10443318053148687, 0.113184645306319, 0.1278236715006642, 0.18567553750472143, 0.1598340889904648, 0.15494107967242599, 0.12121336956624873, 0.09181364206597209, 0.1484146181610413, 0.15864786983001977, 0.18896911467891186, 0.13188792450819165, 0.11194180769962259, 0.13367249281145632, 0.11940936441533267, 0.17680541815934703, 7.261212291195989, 48.69293935596943, 42.556078657507896, 36.65889389812946, 47.01073922216892, 40.088403671979904, 16.31356582045555, 1.653643953613937, 0.3518072987208143, 0.28099489223677665, 3.7318882858380675, 15.580029431730509, 12.149158380925655, 5.463756266981363, 3.264733040705323, 3.065577889792621, 1.508347587659955, 1.59692392218858, 8.696118369698524, 29.254841096699238, 47.15162046253681, 54.711147621273994, 59.29403230547905, 55.96996307373047, 54.07885015010834, 59.63961996138096, 56.51805706322193, 57.66366899013519, 54.988426342606544, 60.196533277630806, 61.103916987776756, 62.2480583935976, 58.00584062933922, 51.93877078592777, 49.43055957555771, 46.02995865046978, 41.808920949697495, 46.746068224310875, 50.368296056985855, 57.67076700925827, 62.06447124481201, 56.95251055061817, 56.522939801216125, 59.749285876750946, 55.9115906059742, 45.451815873384476, 40.64032785594463, 45.22266536951065, 44.529897943139076, 45.84167115390301, 54.48963090777397, 57.2410898655653, 57.5553710013628, 56.16100162267685, 55.80795496702194, 56.54364489018917, 56.78547151386738, 51.99477218091488, 43.26597936451435, 54.716619327664375, 60.083614736795425, 57.01522618532181, 55.90489536523819, 53.25238309800625, 48.81137900054455, 43.93108427524567, 44.528894796967506, 45.374243035912514, 44.807860627770424, 40.963922291994095, 40.115055441856384, 41.209096536040306, 44.52015906572342, 41.05229414999485, 42.145172506570816, 44.480914771556854, 44.08934958279133, 52.32780151069164, 56.76364168524742, 52.56914176046848, 51.324841529130936, 52.90350861847401, 53.44443619251251, 53.18971686065197, 49.93083693087101, 48.27690728008747, 46.892060190439224, 44.192840829491615, 43.252193704247475, 45.270330011844635, 47.054448276758194, 50.7635622471571, 52.03107923269272, 51.21872082352638, 53.948368951678276, 47.0962156355381, 46.31357543170452, 43.3847039937973, 27.428142316639423, 7.326455265283585, 1.519131527747959, 2.572697075083852, 6.6428382229059935, 6.215623347088695, 5.7401548605412245, 5.833499226719141, 9.875476285815239, 15.165860205888748, 18.2546878606081, 3.804738214239478, 0.1771816870314069, 0.13471003010636196, 1.206016216892749, 12.465389762073755, 42.940545827150345, 41.22097849845886, 34.10891152918339, 41.58608190715313, 4.988402249291539, 0.18678926368011162, 0.23430115717928857, 0.22058702510548756, 0.14303185074822977, 0.1342939375899732, 0.14317633205791935, 0.15421058371430263, 0.13188149750931188, 0.08499167961417697, 0.0906990995281376, 0.09423199706361629, 0.17157954076537862, 0.0785584318509791, 0.2046769522712566, 0.0986372891929932, 0.09814393168198876, 0.16569843603065237, 0.1421432921779342, 0.09503182445769198, 0.07525941473431885, 0.09406588957062922, 0.136113936023321, 0.11490870630950667, 0.08648081377032213, 0.08821812210953794], [0.008745729828660842, 0.1126455789199099, 0.07209964678622782, 0.019641476319520734, 0.033774465409806, 0.020914933083986398, 0.004493801125136088, 0.017398774689354468, 0.08739013021113351, 0.034497836750233546, 0.043180767897865735, 0.022027742706995923, 0.04077934499946423, 0.12933334830449894, 0.027587146832956932, 0.06339509316603653, 0.04844837625569198, 0.03356864188390318, 0.034714291541604325, 0.035418248298810795, 0.047971561216400005, 0.03570547800336499, 0.0336162655003136, 0.022180051819304936, 0.007148193408283987, 0.019214129133615643, 0.07069640880217776, 0.06891388140502386, 0.06981015831115656, 0.030882560822647065, 0.036373362672748044, 0.06093679949117359, 0.08372510070330463, 11.762943305075169, 39.18429538607597, 29.44953314960003, 35.44160641729832, 37.44164049625397, 38.124771639704704, 12.306031063199043, 1.3109499611891806, 0.0024181638946174644, 0.09514594450592995, 1.788169085048139, 2.447960455901921, 6.26133774407208, 13.061347883194685, 6.3875664956867695, 0.8508031431119889, 0.6285240361467004, 0.2767986705293879, 2.9988406458869576, 15.41215443983674, 32.58144669234753, 46.049721390008926, 52.398660108447075, 55.07844351232052, 56.44344426691532, 56.55314818024635, 55.00163823366165, 58.97182859480381, 57.76491075754166, 56.03565014898777, 54.80111539363861, 52.16049648821354, 49.97807219624519, 47.22233846783638, 42.88377307355404, 43.067937791347504, 42.26660639047623, 50.54754003882408, 53.697920590639114, 56.625009924173355, 53.449790105223656, 56.125994101166725, 55.638598054647446, 53.86155121028423, 45.53309351205826, 42.64435552060604, 39.20216962695122, 40.248785465955734, 40.70168696343899, 42.584873512387276, 47.60858774185181, 51.40285134315491, 53.286243081092834, 54.9825556576252, 54.303338304162025, 54.726548194885254, 56.81279964745045, 39.99668799340725, 51.95669822394848, 54.35196429491043, 55.49764841794968, 52.024782970547676, 51.44941784441471, 51.54278643429279, 45.34648172557354, 42.67581403255463, 40.67808263003826, 38.432836309075356, 37.665604278445244, 37.352740466594696, 36.74970142543316, 38.94065245985985, 37.94214203953743, 38.747098445892334, 39.420714899897575, 42.58992724120617, 50.20939618349075, 48.96939352154732, 50.73591873049736, 50.411419942975044, 51.2873375415802, 50.851789712905884, 48.341173231601715, 46.138378232717514, 43.86273354291916, 40.4302067309618, 39.30229425430298, 40.594084337353706, 41.22961163520813, 44.9649365991354, 46.867939084768295, 47.90272995829582, 47.917834147810936, 49.55624923110008, 47.96498581767082, 49.24762599170208, 30.387115739285946, 7.511332919821143, 0.744061111472547, 1.2422098685055971, 4.074355121701956, 3.812198876403272, 3.857767218723893, 2.3156819539144635, 4.460000703111291, 5.150048900395632, 4.114749804139137, 1.2308630836196244, 0.1624047104269266, 0.12376444283290766, 0.39107409480493516, 7.593901539221406, 28.33092637360096, 38.30552414059639, 23.686963766813278, 30.078581795096397, 9.815473705530167, 0.07681638860958628, 0.07042339493636973, 0.05991685851768125, 0.0358978463918902, 0.05037139591877349, 0.09965524863218889, 0.0020403167991389637, 0.050664232549024746, 0.030227812167140655, 0.0864882352470886, 0.0249245955637889, 0.05449951073387638, 0.04017010855022818, 0.03909087368811015, 0.010053254882222973, 0.06623855035286397, 0.08154074486810714, 0.08065934060141444, 0.031517995084868744, 0.022441742366936523, 0.0036519966988635133, 0.07993162769707851, 0.05436124120024033, 0.05438984357169829, 0.04027405004308093, 0.06936943391337991, 0.025436514188186266, 0.04074417091032956, 0.016083765076473355, 0.05068987746199127, 0.03617695329012349, 0.024508677452104166, 0.03260655874328222, 0.03226447319320869, 0.11127742967801169, 0.010583541661617346, 0.04848675642278977, 0.005238840394667932, 0.021457012589962687, 0.04058357015310321, 0.04233708699757699, 0.06333268596790731, 0.06366916830302216, 0.033047884280676953, 0.03736083097464871, 0.023959386126080062, 0.06796830362873152, 0.023679577898292337, 0.012321555041125976, 0.049068310763686895, 0.0035288041271996917, 0.026052578396047466, 0.03675932028272655, 0.02340220020414563, 0.05788090253190603, 0.04876951839833055, 0.0390623789280653, 0.03497219156997744, 0.18199050711700693, 18.798163197934628, 44.18975539505482, 29.76639624685049, 35.415836200118065, 45.98130226135254, 43.008539378643036, 10.659191831946373, 0.9956463833805174, 0.16579166462179273, 0.03445973117777612, 0.7953991473186761, 4.461541045457125, 7.973939571529627, 13.662591520696878, 6.485347123816609, 2.6926122279837728, 0.9152188897132874, 0.5531777010764927, 4.33648738078773, 21.26452535390854, 37.13797219097614, 49.63286831974983, 55.22704593837261, 57.304208278656006, 57.04315468668938, 57.21724234521389, 56.05503670871258, 58.57270561158657, 58.9684733748436, 59.93420295417309, 55.06921000778675, 52.64809772372246, 51.43429085612297, 49.6377282589674, 44.890912771224976, 43.91949109733105, 44.77410323917866, 51.985671669244766, 53.83196219801903, 58.898823112249374, 54.77665990591049, 56.69972911477089, 57.46273577213287, 54.30108122527599, 47.197062224149704, 43.640821650624275, 41.37594558298588, 41.298577934503555, 42.556394040584564, 45.27065299451351, 51.553737446665764, 54.05135862529278, 57.32647888362408, 56.44943654537201, 54.50308218598366, 56.19315169751644, 56.87415115535259, 43.3498864620924, 52.69479341804981, 54.964202642440796, 57.27975659072399, 54.569639414548874, 52.7326849848032, 53.220643401145935, 45.18019884824753, 43.32942456007004, 42.68354281783104, 39.55617383122444, 39.19509060680866, 38.38829129934311, 40.35880096256733, 40.892189741134644, 41.316421777009964, 41.65926977992058, 40.4448701441288, 44.49910059571266, 52.6421282440424, 52.02752262353897, 51.146057322621346, 50.06045937538147, 52.382556572556496, 53.17666836082935, 50.49432769417763, 47.225344106554985, 45.14212489128113, 41.91058449447155, 41.244408041238785, 40.2061403542757, 42.95803248882294, 45.827235728502274, 49.960125759243965, 49.40168112516403, 50.31874671578407, 49.619861617684364, 46.37957789003849, 47.4075785279274, 33.972031474113464, 9.954455997794867, 1.900831377133727, 2.42456226143986, 5.008941097185016, 3.662040908820927, 4.620999014005065, 3.0226601427420974, 5.549677731469274, 7.704073777422309, 3.0681441770866513, 0.4425993893528357, 0.03963173607189674, 0.1795814512297511, 0.4012242704629898, 6.896975710988045, 31.904581412672997, 46.58034771680832, 25.97076091915369, 32.186807468533516, 16.06165073812008, 0.09972388987080194, 0.037553321817540564, 0.057743415964068845, 0.022578330936084967, 0.062039638360147364, 0.06945693312445655, 0.06292370322626084, 0.054170349685591646, 0.09351050335681066, 0.11019884419511072, 0.0433320250158431, 0.03911291547410656, 0.08737133903196082, 0.1091298101528082, 0.02613585107610561, 0.10774341149954125, 0.058424124945304357, 0.08493072702549398, 0.016397543258790392, 0.07860815574531443, 0.06507475147373043, 0.03511759314278606, 0.03729786345502362, 0.016210655630857218, 0.06722895384882577, 0.037426640919875354, 0.09531755873467773, 0.21864627924514934, 0.20630540238926187, 0.09084482022444718, 0.20542816899251193, 0.06518290465464815, 0.13560267048887908, 0.09030763147165999, 0.27433957904577255, 0.06747415201971307, 0.15111925662495196, 0.11279736296273768, 0.1760557302623056, 0.18597065994981676, 0.16243973979726434, 0.13209140655817464, 0.1373056767624803, 0.1626204972853884, 0.14750510134035721, 0.11633226429694332, 0.12979477120097727, 0.11326893843943253, 0.13394895766396075, 0.19489053287543356, 0.09234800323611125, 0.08906515751732513, 0.11105464436695911, 0.09801037478609942, 0.1579413897707127, 0.1065491400368046, 0.10093543110997416, 0.16253330977633595, 0.2091755991568789, 18.744335286319256, 51.96893736720085, 39.97967250645161, 44.533009976148605, 47.485215961933136, 47.37479388713837, 16.7577163875103, 1.6497467877343297, 0.17036553559591994, 0.4008466360392049, 3.5939051024615765, 6.725912215188146, 15.167112238705158, 22.789497524499893, 15.33360030502081, 3.2933241315186024, 1.8587392545305192, 0.7261522568296641, 3.9509978285059333, 18.25919631868601, 36.77643679082394, 48.472133204340935, 54.993932247161865, 57.14649394154549, 59.09272290766239, 57.525310814380646, 57.32823818922043, 60.58732710778713, 60.25268666446209, 60.05231201648712, 57.43148624897003, 53.086537197232246, 54.56328995525837, 52.828200459480286, 48.516055047512054, 46.23731352388859, 46.05221405625343, 55.22510424256325, 57.76635468006134, 59.001527801156044, 54.73675824701786, 57.421747371554375, 59.48562942445278, 57.266947478055954, 49.63020846247673, 47.35244728624821, 42.531946152448654, 43.49291458725929, 45.02673648297787, 46.33658319711685, 50.82810178399086, 54.99657690525055, 59.1896291077137, 58.95472951233387, 57.2768497467041, 57.58844442665577, 60.13998091220856, 42.45916485786438, 52.8181803971529, 58.36270987987518, 59.27507512271404, 57.563050389289856, 53.90434071421623, 55.11559031903744, 48.40966075658798, 45.814597606658936, 43.458522632718086, 40.80298192799091, 41.37507162988186, 40.830792635679245, 41.16479471325874, 43.38293708860874, 41.67794957756996, 44.38048616051674, 42.55674362182617, 47.068332731723785, 53.57929855585098, 52.56740905344486, 52.63794466853142, 50.24671018123627, 53.50288845598698, 55.58349721133709, 53.05953964591026, 49.207944720983505, 46.13791085779667, 44.21439327299595, 43.67502361536026, 42.71144852042198, 44.738575145602226, 49.52045135200024, 50.79545013606548, 51.98593385517597, 51.460638642311096, 51.8406068533659, 48.18471662700176, 49.72030162811279, 33.97653803229332, 9.280798695981503, 1.2799216574057937, 2.6500079641118646, 8.624648004770279, 9.428694359958172, 7.709509860724211, 6.0751420352607965, 9.673255886882544, 12.35808826982975, 11.724153086543083, 4.109237249940634, 0.3212091437308118, 0.3026637638686225, 0.7958173030056059, 10.539372861385345, 38.426087871193886, 49.85106021165848, 31.557080559432507, 41.31813548505306, 17.819217927753925, 0.2729533362435177, 0.19352858798811212, 0.12501663150032982, 0.12508290528785437, 0.1300373941194266, 0.30505977279972285, 0.18826000741682947, 0.13688575476408005, 0.12715964228846133, 0.31855017703492194, 0.10030136239947751, 0.10046165887615643, 0.11773562102462165, 0.1874840326490812, 0.07072711145156063, 0.16629383142571896, 0.23466761485906318, 0.2603196376003325, 0.2867800818057731, 0.10957132864859886, 0.1637536528869532, 0.17920349026098847, 0.13104610639857128, 0.17389801010722294, 0.19078143930528313, 0.2670698566362262], [0.08464879996608943, 0.015948629261401948, 0.010529688643146073, 0.0914487725822255, 0.010679233255359577, 0.03739867308468092, 0.019237772103224415, 0.03915779685485177, 0.003725969572769827, 0.04373755306005478, 0.013477668981067836, 0.01760846294928342, 0.057513557985657826, 0.0023646130694032763, 0.037966876188875176, 0.04001737826911267, 0.005741786917496938, 0.06429447224945761, 0.03390474201296456, 0.06924591085407883, 0.06333216646453366, 0.02735535741521744, 0.028352764929877594, 0.0618375886551803, 0.04205089258903172, 0.055190728526213206, 0.08532005769666284, 0.01741940825013444, 0.051443276097415946, 0.03259495897509623, 0.07246318040415645, 0.038789101599832065, 0.035101128596579656, 0.47624981962144375, 20.134777575731277, 35.44428147375584, 27.813223153352737, 27.107268534600735, 38.37482862174511, 37.735535725951195, 14.116612058132887, 1.8833335535600781, 0.14666944305645302, 0.5013052001595497, 7.390661844983697, 7.995974589139223, 14.721688739955425, 9.119017627090216, 3.5399779211729765, 0.5789193010423332, 0.43075331719592214, 0.11092023400124162, 0.7642054336611181, 8.471068795770407, 23.235863372683525, 41.01398080587387, 52.12320528924465, 56.28285348415375, 56.57988354563713, 54.08078044652939, 54.06402334570885, 55.93242488801479, 55.61251625418663, 54.31593842804432, 52.04959183931351, 49.57440845668316, 47.21444629132748, 44.04509335756302, 42.16553181409836, 45.23026876151562, 51.4765901863575, 57.19817876815796, 55.01661702990532, 54.61929515004158, 56.2237324565649, 56.56336583197117, 54.40856985747814, 45.88710531592369, 40.50519570708275, 42.14363358914852, 40.08735492825508, 40.59286080300808, 40.296009331941605, 41.79991543292999, 47.032968029379845, 51.585465744137764, 52.74592727422714, 54.51691344380379, 53.27563405036926, 54.741846174001694, 47.280585542321205, 56.12549252808094, 56.8945674598217, 53.795601949095726, 53.63077439367771, 54.27898161113262, 51.03463590145111, 47.92841657996178, 42.81734123826027, 38.964344188570976, 39.92533162236214, 38.74410040676594, 37.206087335944176, 38.639575615525246, 40.10107599198818, 40.04924677312374, 42.306994423270226, 39.30560387670994, 44.389788061380386, 50.21965183317661, 51.044184789061546, 52.37857058644295, 51.61926493048668, 51.06607921421528, 51.9310761988163, 48.69158282876015, 46.02403476834297, 42.13614419102669, 40.77677093446255, 39.01545524597168, 40.596690997481346, 42.93617606163025, 46.144013330340385, 47.67978832125664, 48.13992843031883, 49.80879507958889, 48.608701676130295, 46.37480154633522, 39.56625089049339, 13.177063073962927, 1.878919021692127, 0.8179457718506455, 1.7067030002363026, 2.5904967449605465, 1.745468401350081, 3.76018441747874, 2.7151469187811017, 4.932181891053915, 6.825141040608287, 2.90122602134943, 0.38027964590582997, 0.07219154693302698, 0.2179266928578727, 7.516463119536638, 27.788754366338253, 34.34346914291382, 20.232787616550922, 29.244306161999702, 21.514916718006134, 1.0489069973118603, 0.003070744319302321, 0.03995015824330039, 0.02643135387188522, 0.033130489027826115, 0.005384809246606892, 0.013289393536979333, 0.011859841779369162, 0.0459543036413379, 0.017069673012883868, 0.0697204252355732, 0.03740432824997697, 0.05082866278826259, 0.04287867668608669, 0.05333799395884853, 0.06283894254011102, 0.05471561300510075, 0.02667124012077693, 0.035956999272457324, 0.10115624230820686, 0.019740823918255046, 0.05517805264389608, 0.050800034441635944, 0.04401863036036957, 0.05516164375876542, 0.025929342918971088, 0.035920185036957264, 0.0745682674460113, 0.015601296727254521, 0.016006553887564223, 0.06346490699797869, 0.03256823794799857, 0.010216764858341776, 0.04485557627049275, 0.04428454929438885, 0.03056098081287928, 0.09200718675856479, 0.04028342336823698, 0.10362411339883693, 0.019776113040279597, 0.033349537625326775, 0.04104424348042812, 0.04658653182559647, 0.03625018100137822, 0.046123724823701195, 0.017427219354431145, 0.04806244091014378, 0.04935957404086366, 0.04573807891574688, 0.033653083446552046, 0.07131438032956794, 0.036699744377983734, 0.019067666289629415, 0.05441800436528865, 0.06125354069808964, 0.021666810316673946, 0.015944013102853205, 0.055003547749947757, 0.057882015753421, 0.03926846962713171, 1.204370311461389, 28.55671975761652, 41.44294358789921, 30.154515020549297, 29.57505751401186, 47.225146517157555, 44.656347557902336, 13.942908179014921, 1.1901044519618154, 0.165731847519055, 0.14660595974419266, 1.4483057032339275, 1.6125512961298227, 7.267614472657442, 9.096630178391933, 6.782542001456022, 1.9462966499850154, 0.6740155513398349, 0.1230765313084703, 1.520798213314265, 11.630844343453646, 27.662633433938026, 44.42587852478027, 52.74593107402325, 58.16151827573776, 57.371977642178535, 56.87688700854778, 54.692950397729874, 56.30158647894859, 58.69864605367184, 56.24479852616787, 53.857789412140846, 50.267563462257385, 49.103917703032494, 45.18674969673157, 44.6941327303648, 46.62693701684475, 53.59775796532631, 58.10081273317337, 58.55527214705944, 55.500296875834465, 57.07814700901508, 58.03316496312618, 55.61484932899475, 47.45150417089462, 42.514512687921524, 44.34610940515995, 41.48688443005085, 42.93388478457928, 41.56416468322277, 43.72016899287701, 50.50059735774994, 53.88797499239445, 53.89515660703182, 56.81891351938248, 55.56376487016678, 54.9312774091959, 49.60426725447178, 54.416291043162346, 57.12190926074982, 55.5201356112957, 55.73850229382515, 55.56757986545563, 54.42205533385277, 50.10168336331844, 43.06905873119831, 39.40222129225731, 40.068329349160194, 40.712558180093765, 39.965860247612, 40.84919884800911, 42.24658906459808, 43.17442327737808, 42.125576958060265, 39.855004996061325, 45.025877729058266, 51.886926367878914, 52.66986295580864, 53.247637152671814, 52.8931275755167, 51.85359075665474, 53.687672540545464, 50.33190160989761, 47.748405039310455, 44.7209706902504, 42.385414615273476, 40.848989859223366, 42.682604268193245, 45.31311571598053, 48.20831336081028, 48.365750312805176, 50.73901556432247, 50.17078645527363, 48.898132145404816, 47.1199681609869, 42.29781411588192, 17.044825181365013, 2.978398692794144, 1.4422394474968314, 3.0565232131630182, 3.8441508868709207, 3.962648003362119, 5.187591835856438, 3.6405497370287776, 5.975114302709699, 5.330357300117612, 0.2818684000521898, 0.1015549611474853, 0.06675898883258924, 0.26382242620456964, 7.117862133309245, 29.242518357932568, 40.079656541347504, 27.62036830186844, 31.01664885878563, 27.239541336894035, 2.2907987516373396, 0.01256888039279147, 0.08344056128407829, 0.038152966008055955, 0.007745153343421407, 0.047113107866607606, 0.019715470298251603, 0.03478047998214606, 0.03421340123168193, 0.04888422103249468, 0.05902026248804759, 0.025283978720835876, 0.025357091399200726, 0.07673143496504053, 0.007499110051867319, 0.05613650297163986, 0.049975263464148156, 0.05607128674455453, 0.0019602599377321894, 0.06821541654062457, 0.1308358262758702, 0.02210026537795784, 0.03870573615131434, 0.04607353337632958, 0.08287284057587385, 0.038964816194493324, 0.04973412484105211, 0.22854071081383154, 0.10913899794104509, 0.16731234005419537, 0.16283120785374194, 0.2426769764861092, 0.12352904101135209, 0.10972093077725731, 0.17816109932027757, 0.06049087634892203, 0.23799558315658942, 0.09756855200976133, 0.20628232159651816, 0.1795481881708838, 0.13504629721865058, 0.131624432397075, 0.12396850375807844, 0.14780111436266452, 0.12124841377953999, 0.11005201027728617, 0.1909841495216824, 0.14307465782621875, 0.15742185671115294, 0.05522878585907165, 0.12767740903655067, 0.0937817212252412, 0.27694517048075795, 0.17492855637101457, 0.12370916025247425, 0.09772453660843894, 0.08248718353570439, 0.128403838025406, 0.1645694364560768, 0.12096067570382729, 1.0349173354916275, 29.794672429561615, 48.466490507125854, 41.01516634225845, 33.75217907130718, 47.97931104898453, 48.56462404131889, 18.812190145254135, 2.8873897762969136, 0.46497042174451053, 1.2882158998399973, 11.099071428179741, 18.46498377621174, 23.705098293721676, 22.86178294569254, 10.551119931042194, 1.1788329505361617, 0.7139152509626001, 0.2756905253045261, 1.3139975164085627, 9.861755222082138, 25.47227706760168, 44.349191039800644, 52.94613853096962, 58.278229013085365, 59.37662847340107, 56.76906779408455, 54.70110096037388, 58.138548508286476, 59.33054454624653, 59.437182024121284, 55.34440264105797, 52.06963196396828, 52.16296635568142, 47.63860613107681, 46.57163858413696, 49.70457047224045, 55.0602462887764, 62.08427578210831, 60.000486597418785, 55.7601535320282, 58.098304867744446, 60.13413682579994, 58.784525245428085, 48.78282733261585, 43.167728036642075, 46.275136694312096, 43.10571916401386, 44.55346427857876, 43.36700454354286, 44.91405352950096, 51.740626618266106, 56.64393670856953, 55.477650091052055, 59.59080398082733, 56.23511664569378, 57.723147198557854, 50.815148279070854, 55.8765184879303, 59.97205652296543, 56.011130064725876, 57.567560747265816, 56.4507132768631, 56.880018040537834, 51.84130981564522, 46.675365418195724, 41.476966962218285, 41.90939515829086, 42.77143970131874, 41.6802104562521, 43.218998685479164, 44.68297652900219, 45.96910111606121, 45.526238679885864, 41.79521128535271, 46.66034862399101, 53.449695110321045, 54.73013520240784, 54.22663561999798, 53.348586335778236, 51.903820261359215, 57.23288990557194, 51.66064091026783, 48.310911655426025, 46.48361250758171, 44.74655091762543, 42.111890092492104, 44.1428355127573, 47.85604186356068, 50.3290593624115, 51.206941455602646, 52.19516962766647, 53.24827551841736, 49.9066436290741, 47.62692555785179, 41.97191700339317, 16.3328592851758, 2.5417705345898867, 1.6678931890055537, 3.988489229232073, 6.511037545278668, 5.236301897093654, 9.401203785091639, 8.757880255579948, 12.066472917795181, 15.421429742127657, 6.826901771128178, 0.7257382571697235, 0.27142783685121685, 0.49473440274596214, 10.713055841624737, 37.245574817061424, 42.55973406136036, 29.67807948589325, 38.89674201607704, 31.62071194499731, 2.700811713002622, 0.17304036940913647, 0.15586597379297018, 0.16209498251555488, 0.14429201750317588, 0.13494475657353178, 0.10775174581795, 0.10581623209873214, 0.08188573221559636, 0.17423639976186678, 0.12593555875355378, 0.2399460956803523, 0.1909672433976084, 0.16019947797758505, 0.0886760198045522, 0.13962543744128197, 0.2854395256144926, 0.14016021421412006, 0.16346244898159057, 0.11841905739856884, 0.1289185619680211, 0.16437502345070243, 0.16261325392406434, 0.13820420979755, 0.1812750322278589, 0.054337377441697754, 0.18265040998812765], [0.042393185940454714, 0.07262169572641142, 0.07131506310543045, 0.04303037538193166, 0.038635488162981346, 0.03070253434998449, 0.03350945560669061, 0.024560802194173448, 0.025858499357127585, 0.037332621941459365, 0.05837341770529747, 0.0393035064189462, 0.012868174635514151, 0.0016993121175801207, 0.020414269129105378, 0.01479866958106868, 0.035648302946356125, 0.0417510537954513, 0.027535576846275944, 0.07789034309098497, 0.04131001769565046, 0.043020267330575734, 0.02048400874627987, 0.06219488081114832, 0.07052852015476674, 0.02423187677777605, 0.04828035773243755, 0.06924018889549188, 0.042359344006399624, 0.041687852499308065, 0.04736991693789605, 0.016026077937567607, 0.06717142256093211, 0.1377557299565524, 1.954486754257232, 22.64444600790739, 38.62382926046848, 30.80151580274105, 27.371931932866573, 38.30978751182556, 40.32685227692127, 18.300595097243786, 1.747003044001758, 0.28392245701979846, 0.7988190825562924, 0.9659468207973987, 4.33314498513937, 2.9622034868225455, 5.22288054227829, 3.4624817920848727, 0.4952986427815631, 0.3346198709914461, 0.10212954672169872, 0.9197363129351288, 7.411869456991553, 23.993903696537018, 45.23687660694122, 52.287200689315796, 57.064650133252144, 54.741196408867836, 56.43876671791077, 55.138981863856316, 56.45139344036579, 56.35838583111763, 52.90940970182419, 50.897007286548615, 47.21938222646713, 44.841416627168655, 47.178044244647026, 53.50174471735954, 55.73326997458935, 57.073834240436554, 57.140258476138115, 53.67125742137432, 56.98275312781334, 55.40259271860123, 54.01174195110798, 47.44871512055397, 41.70479893684387, 39.55978363752365, 42.39864930510521, 40.925506353378296, 39.7128926217556, 40.33370330929756, 42.03695811331272, 45.24413041770458, 51.04013040661812, 53.10145899653435, 55.14945410192013, 52.2291512042284, 46.58456169068813, 56.188379153609276, 55.32890327274799, 53.38408023118973, 52.14163810014725, 51.04904092848301, 48.33494156599045, 45.66669434309006, 41.47887825965881, 39.74109470844269, 40.99926419556141, 39.35727350413799, 38.894120156764984, 38.71274448931217, 41.2743504345417, 41.21922679245472, 43.134662210941315, 42.38142482936382, 43.34878832101822, 48.756426349282265, 51.26404479146004, 52.78994791209698, 50.989661514759064, 51.25001594424248, 51.115769147872925, 48.91923241317272, 45.775452107191086, 42.63916879892349, 42.26518526673317, 42.162518575787544, 43.63182373344898, 46.93321578204632, 48.94944839179516, 47.974945083260536, 51.353043615818024, 48.93813259899616, 49.000107273459435, 39.563089460134506, 20.862964801490307, 5.231419634073973, 0.5285464727785438, 0.7369006925728172, 3.534620446152985, 3.318324415013194, 2.224654513411224, 2.9548648931086063, 1.878709439188242, 3.848858359269798, 4.5457488019019365, 0.3234267106745392, 0.011087514667451615, 0.27707798522897065, 6.993162324652076, 22.36204706132412, 40.661732107400894, 37.03650243580341, 19.24483872950077, 29.008412919938564, 7.635697396472096, 0.06738534662872553, 0.06312776415143162, 0.051694225912797265, 0.041042569937417284, 0.06728792490321212, 0.04052983866131399, 0.06877668798551895, 0.06183829369547311, 0.026757702180475462, 0.03560456447303295, 0.05684769195795525, 0.04062688931298908, 0.11152030492667109, 0.026055582238768693, 0.017540003536851145, 0.02290169766638428, 0.02263707934616832, 0.05294033639074769, 0.05656512665154878, 0.059408168235677294, 0.029818829425494187, 0.03850985369354021, 0.02174830555304652, 0.062434472056338564, 0.029899161345383618, 0.06414211675291881, 0.05611517364741303, 0.04774276450916659, 0.05681305592588615, 0.05818935023853555, 0.03513674055284355, 0.007515705865444033, 0.02976026098622242, 0.048769459026516415, 0.027256039502390195, 0.09044820166309364, 0.030000121259945445, 0.019507472279656213, 0.05689306686690543, 0.023086817127477843, 0.06069930852390826, 0.035558985473471694, 0.014596181081287796, 0.056683102156966925, 0.03129607066512108, 0.03246325744839851, 0.019501472015690524, 0.043580492347246036, 0.040517990273656324, 0.024303534846694674, 0.04352756979642436, 0.06610775424633175, 0.012877268727606861, 0.02420224653178593, 0.05138359258126002, 0.05837715812958777, 0.04052263240737375, 0.058902765667880885, 0.0466149189742282, 0.013481250771292252, 0.09705204691272229, 4.496238408610225, 31.014040298759937, 40.60282766819, 28.202913142740726, 28.79687637090683, 47.93348550796509, 45.99237106740475, 16.761913262307644, 1.4692380675114691, 0.1651628577383235, 0.20995421597035602, 0.549818443832919, 1.172646526247263, 4.303322760388255, 8.734661601483822, 7.4804144538939, 2.5981929944828153, 0.9881181560922414, 0.28261307103093714, 1.4349171216599643, 10.152060594409704, 27.380893751978874, 46.936950981616974, 56.342996656894684, 58.00884246826172, 54.43961039185524, 57.82215468585491, 57.23608173429966, 58.70022676885128, 58.082379922270775, 55.0415550917387, 51.81913800537586, 48.14600050449371, 46.41892857849598, 47.85342760384083, 53.52864347398281, 57.038024961948395, 57.7164975553751, 59.03650492429733, 55.05738504230976, 57.013303488492966, 56.83744132518768, 55.91853283345699, 48.81278492510319, 42.89569303393364, 41.87317930161953, 43.27661879360676, 41.316284984350204, 41.16504929959774, 43.37203927338123, 43.901442065835, 47.00823135674, 51.86893433332443, 55.18432483077049, 56.61419190466404, 52.37300768494606, 49.06354106962681, 58.263565599918365, 56.19332268834114, 54.10530053079128, 54.49589677155018, 53.628076538443565, 51.27246893942356, 48.849707543849945, 42.11507812142372, 41.309038773179054, 41.87369987368584, 42.67891466617584, 39.2471744120121, 41.25144526362419, 43.30557703971863, 43.79214093089104, 44.99303609132767, 45.010484755039215, 46.67405068874359, 52.16430388391018, 52.99932427704334, 53.897242695093155, 50.864002257585526, 53.41412901878357, 52.67886087298393, 50.54004684090614, 47.76848316192627, 44.6608617156744, 43.60114797949791, 43.35557095706463, 44.3299450725317, 48.15423846244812, 49.68656703829765, 51.023646891117096, 51.68897219002247, 51.504541486501694, 47.4445391446352, 42.020573392510414, 22.71358709782362, 7.285606982186437, 1.3667549542151392, 2.7331432281062007, 4.083864586427808, 3.5367478569969535, 3.0555621022358537, 4.345927974209189, 3.2367207063362002, 4.028583727777004, 1.1480339406989515, 0.19319022801937535, 0.14639588742284104, 0.38160348893143237, 6.722784033045173, 27.89985090494156, 49.26988899707794, 35.7595581561327, 18.153364397585392, 33.617689087986946, 11.175064500421286, 0.01974613027414307, 0.14269133855123073, 0.06606246839510277, 0.02987375577504281, 0.02831544046784984, 0.020425165712367743, 0.06982619612244889, 0.03621622403443325, 0.033237729367101565, 0.02870114018151071, 0.022464194189524278, 0.03251182359235827, 0.09298996839788742, 0.05742384717450477, 0.023127570311771706, 0.052854848399874754, 0.04357354584499262, 0.04060596074850764, 0.047625694423913956, 0.02326516820176039, 0.034656615534913726, 0.05280335077259224, 0.07462985828169622, 0.015338612629420822, 0.052180625789333135, 0.14562464755726978, 0.038999704556772485, 0.16149194299941882, 0.1548657813691534, 0.11594930867431685, 0.08234388224082068, 0.10454433198901825, 0.09911816378007643, 0.10131274641025811, 0.11344034486683086, 0.11515095073264092, 0.13875767384888604, 0.12542089418275282, 0.1437438523862511, 0.17088521708501503, 0.11778202751884237, 0.09092325781239197, 0.2544694655807689, 0.1349231303902343, 0.18522346566896886, 0.07900692653493024, 0.13446944067254663, 0.12428609843482263, 0.13922274811193347, 0.15962639154167846, 0.13117601192789152, 0.13099632313242182, 0.05353712331270799, 0.1881966131622903, 0.17228941986104473, 0.182562910777051, 0.14554134890204296, 0.14264064986491576, 0.15674524067435414, 0.2458101458614692, 0.22769577568396926, 3.527737590484321, 34.01069439947605, 51.24290272593498, 41.79516948759556, 34.410695135593414, 48.886713758111, 50.415063947439194, 22.302422560751438, 3.1947042234241962, 0.4862081946339458, 1.1934599094092846, 3.596378294751048, 10.478829760104418, 8.227953091263771, 8.828238230198622, 8.135859332978725, 2.2443745052441955, 0.9632458188571036, 0.2823956811334938, 1.5586572443135083, 9.05059564858675, 26.946242675185204, 47.02056549489498, 56.65715999901295, 58.61171431839466, 56.51038147509098, 59.74600285291672, 59.57970477640629, 59.99105550348759, 60.4700767993927, 56.997807919979095, 54.906267151236534, 51.60114750266075, 50.41424699127674, 50.799705907702446, 57.28664942085743, 59.869253039360046, 60.695195719599724, 59.71329800784588, 55.12410566210747, 58.82733374834061, 59.202514216303825, 57.70708926022053, 52.89241701364517, 47.16080076992512, 43.52929763495922, 46.44217953085899, 44.10539612174034, 42.28540778160095, 43.55502225458622, 46.85239031910896, 47.372931987047195, 54.54636186361313, 57.19954289495945, 60.25575689971447, 54.775006994605064, 50.32883137464523, 57.997606471180916, 58.43615233898163, 56.61146365106106, 56.45633317530155, 56.15786299109459, 52.54139184951782, 50.234676226973534, 44.113246500492096, 43.890137672424316, 44.00276742875576, 43.74050930142403, 41.91349133849144, 42.32227720320225, 45.79686775803566, 44.73485514521599, 47.8626649081707, 47.96617515385151, 48.17736782133579, 52.584124356508255, 54.963917657732964, 55.9161389619112, 51.11011125147343, 52.178055346012115, 54.26657907664776, 53.03125396370888, 49.25518378615379, 45.998465940356255, 46.96794971823692, 45.6770183891058, 47.66592666506767, 51.31598800420761, 53.321907967329025, 51.57127730548382, 56.23005531728268, 52.24588930606842, 48.99267107248306, 40.82326903939247, 23.410040326416492, 6.539600612595677, 2.01762143522501, 2.4904464511200786, 6.530386107042432, 7.724739918485284, 6.438949713483453, 8.000660687685013, 5.917038219049573, 11.204234585165977, 10.025107506662607, 1.5652287541888654, 0.3890656353905797, 0.6602753105107695, 9.776965621858835, 30.531494691967964, 51.61967910826206, 43.357695043087006, 27.828165851533413, 40.537539571523666, 11.58190581947565, 0.1646603792323731, 0.2313033555401489, 0.13929372711572796, 0.2059146319516003, 0.18418368708807975, 0.14002144744154066, 0.13967747683636844, 0.1489596365718171, 0.13669493375346065, 0.09250415852875449, 0.15503006317885593, 0.17704879806842655, 0.21589098178083077, 0.08668696755194105, 0.17872538388473913, 0.12363557631033473, 0.08717862554476596, 0.1585984427947551, 0.08085706358542666, 0.1249045820441097, 0.1223372780077625, 0.13034931878792122, 0.11761404239223339, 0.143362982198596, 0.1740642957156524, 0.20399166794959456, 0.22162144538015127], [0.0649841500853654, 0.046456796990241855, 0.02759935330686858, 0.05028125837270636, 0.04857418512983713, 0.03924386743165087, 0.027752731111831963, 0.02872067350836005, 0.02553135509515414, 0.0708300992846489, 0.04207087491522543, 0.03710101249453146, 0.031370797514682636, 0.06263731585931964, 0.03782781997870188, 0.04624051660357509, 0.06834042389527895, 0.08244602402555756, 0.07839594603865407, 0.02263255781144835, 0.08190712091163732, 0.017757261703081895, 0.12154061216278933, 0.021897377046116162, 0.04937055040500127, 0.05508049362106249, 0.07496591017115861, 0.03314109802886378, 0.020078712623217143, 0.029458097415044904, 0.101051747915335, 0.135278144152835, 0.017867242422653362, 0.018218471232103184, 0.010460873927513603, 3.264443543739617, 24.1176288574934, 37.69624203443527, 28.930207416415215, 21.800203509628773, 36.208887845277786, 40.99191538989544, 20.135718025267124, 3.2298893854022026, 0.35660005873069167, 0.07412378035951406, 1.5053116693161428, 3.031222983263433, 3.713236986659467, 7.0445669163018465, 2.4588718079030514, 0.5869035632349551, 0.40302216773852706, 0.028799790161428973, 1.972316347528249, 12.939440924674273, 30.934539064764977, 47.28077933192253, 54.927971586585045, 54.83887776732445, 53.945735692977905, 59.372216910123825, 57.58926518261433, 55.81108599901199, 54.357739984989166, 49.04614180326462, 48.09661075472832, 50.72653703391552, 55.74966989457607, 55.21686628460884, 55.81860199570656, 57.72599704563618, 55.154990404844284, 55.436429902911186, 55.83871811628342, 57.14294493198395, 55.891265496611595, 52.69641973078251, 48.86831894516945, 41.43921598792076, 41.61431819200516, 42.24072217941284, 42.49317683279514, 43.37965786457062, 50.00613369047642, 51.917712315917015, 55.74164092540741, 51.781881004571915, 56.61025531589985, 48.99581350386143, 41.958849504590034, 58.1442292034626, 53.95542897284031, 55.1036361604929, 52.825764790177345, 53.0003996193409, 49.64266799390316, 45.94389706850052, 40.2276623994112, 41.7976925522089, 42.91142039000988, 39.02689643204212, 40.57136915624142, 41.25261940062046, 40.7087317854166, 43.5700998455286, 45.454285740852356, 45.925259068608284, 45.21582953631878, 49.78666886687279, 50.30000612139702, 53.322249948978424, 52.56053142249584, 51.89692363142967, 50.42378067970276, 51.26320123672485, 47.39590935409069, 43.406385630369186, 43.03675286471844, 45.675825253129005, 48.03705655038357, 48.62632133066654, 48.01371440291405, 49.264797270298004, 49.771112501621246, 50.5048493295908, 41.076213866472244, 22.978142201900482, 5.7847582921385765, 0.9543614799622446, 0.6084183056373149, 2.7146448707208037, 2.053244523704052, 2.513432130217552, 3.6471207719296217, 2.962788655422628, 1.746149396058172, 2.6817032508552074, 0.953888880321756, 0.04710728571808431, 0.5214205489028245, 6.576560279354453, 30.72041105479002, 28.185758963227272, 28.990215696394444, 50.47580748796463, 29.49955366551876, 16.122076995670795, 0.8558268891647458, 0.029391168682195712, 0.02563487727456959, 0.012064745969837531, 0.09380727336974815, 0.073948551871581, 0.042393059775349684, 0.006860932162453537, 0.07253293486428447, 0.01520480340332142, 0.03896701666235458, 0.03431410324992612, 0.010024294424511027, 0.039899462135508657, 0.048654930797056295, 0.0338023738731863, 0.023696133357589133, 0.08476105722365901, 0.014450253511313349, 0.01667563155933749, 0.01880003670521546, 0.04072359857673291, 0.14450836839387193, 0.04956103002768941, 0.02899829611124005, 0.10095966223161668, 0.01901164898299612, 0.02276622788485838, 0.07756675928249024, 0.051547774201026186, 0.07662078816792928, 0.033945500763366, 0.035773198978859, 0.030402023912756704, 0.036585895213647746, 0.02552219884819351, 0.05092822932056151, 0.029640077591466252, 0.036514378152787685, 0.009221884356520604, 0.030417727757594548, 0.034384855898679234, 0.008671242321725003, 0.04973060335032642, 0.01449674349714769, 0.009526190879114438, 0.02988093976455275, 0.057190100342268124, 0.020975546140107326, 0.050765836276696064, 0.012514619193098042, 0.020775743287231307, 0.03378448811417911, 0.049794724909588695, 0.02796152693917975, 0.03473894568742253, 0.015339007823058637, 0.02226033921033377, 0.01580591797392117, 0.04975631134584546, 0.006426614818337839, 0.02954457617306616, 0.09058641182491556, 6.725462414324284, 32.446284145116806, 40.72595626115799, 27.502637319266796, 24.923453517258167, 44.0967021882534, 50.12944087386131, 18.90773981809616, 2.6176505628973246, 0.28962069656699896, 0.3848908469080925, 0.10442054917803034, 2.6776291569694877, 5.421972284093499, 11.363252252340317, 4.513706071302295, 2.4459475139155984, 1.1427044891752303, 0.4824082204140723, 3.675385555252433, 14.787962883710861, 34.42375883460045, 47.86325767636299, 56.637511253356934, 54.53409232199192, 56.90441273152828, 59.75294888019562, 59.12885516881943, 59.06283751130104, 56.20073989033699, 50.93713693320751, 49.793801084160805, 52.10082069039345, 58.4487334638834, 58.09518523514271, 57.53315359354019, 59.181436747312546, 56.95846863090992, 53.472265899181366, 56.51188239455223, 58.92814613878727, 56.79052524268627, 54.56945322453976, 50.049360170960426, 42.35598139464855, 42.4368030577898, 44.91922125220299, 44.169506281614304, 45.16601800918579, 50.636451467871666, 52.790966257452965, 58.532328978180885, 52.59988211095333, 58.89546409249306, 50.81662639975548, 44.64552953839302, 60.115848407149315, 55.4914927482605, 56.027978360652924, 55.22538922727108, 54.20874238014221, 51.88202083110809, 46.837289929389954, 41.276531517505646, 42.97229312360287, 42.891779243946075, 41.014558374881744, 41.700695157051086, 43.38237851858139, 44.04451958835125, 44.57486093044281, 46.79889678955078, 46.732081174850464, 46.35791525244713, 51.039321050047874, 53.327721655368805, 53.78690421581268, 53.07426765561104, 52.46341623365879, 53.12787517905235, 53.09067517518997, 48.979098200798035, 44.81623537838459, 42.83759415149689, 47.52792187035084, 49.18605409562588, 49.883335679769516, 51.279460564255714, 50.581981390714645, 51.45639047026634, 48.630284518003464, 43.874444514513016, 25.823830403387547, 7.756369421258569, 1.6027302481234074, 1.926830888260156, 3.4100327314808965, 2.782882796600461, 4.838002044707537, 3.3638231735676527, 3.954895231872797, 4.0434186067432165, 0.1100511642289348, 0.33989395829848945, 0.018448076880304143, 0.5491421988699585, 5.88162649422884, 33.73546376824379, 34.225299283862114, 35.51400013267994, 50.76738864183426, 31.708738021552563, 22.483372651040554, 1.3639197126030922, 0.10130970360478386, 0.07316185306990519, 0.043725051582441665, 0.04026674730994273, 0.046815573441563174, 0.07265061722137034, 0.014361507492139935, 0.010056283772428287, 0.10895967279793695, 0.03567236337403301, 0.04857887179241516, 0.01719672312901821, 0.008200622360163834, 0.02667494714842178, 0.04442452576768119, 0.01150858885011985, 0.07298267635633238, 0.027524902907316573, 0.02810688212775858, 0.11231366821448319, 0.05619029012450483, 0.06450970249716192, 0.015835830236028414, 0.020949882673448883, 0.057406373307458125, 0.07801483094226569, 0.0644796529377345, 0.16085179609945044, 0.12273000771529041, 0.15398136398289353, 0.1449299231171608, 0.10796351023600437, 0.09769810130819678, 0.15693493362050503, 0.0629672450304497, 0.09752359270351008, 0.1698207695153542, 0.10706145199947059, 0.14674263366032392, 0.1635712626739405, 0.22446130315074697, 0.06249445243156515, 0.10449429639265873, 0.16548196639632806, 0.22045042540412396, 0.12921411485876888, 0.15296543802833185, 0.18995113932760432, 0.12240655007190071, 0.2795119327493012, 0.08782919219811447, 0.19862852292135358, 0.1710440663737245, 0.29056185856461525, 0.1389369321987033, 0.07083863398293033, 0.10951076197670773, 0.12249965249793604, 0.20929541147779673, 0.14123381988611072, 0.15687861945480108, 0.1707957437611185, 5.2130604442209005, 35.89304879307747, 49.90536689758301, 39.54768508672714, 30.47024767845869, 44.90005508065224, 51.64530113339424, 25.62738474458456, 4.019344998523593, 0.7473678840324283, 0.49649216467514634, 3.901887363754213, 9.340409897267818, 10.622438304126263, 13.91871202737093, 7.082106051966548, 2.159305145032704, 1.16988965542987, 0.3618454991374165, 3.002205127850175, 15.331487618386745, 34.2608729749918, 49.96524788439274, 55.65231531858444, 55.05547374486923, 55.46569973230362, 63.67692992091179, 64.39327508211136, 60.8319465816021, 59.779486656188965, 54.25155468285084, 51.973725110292435, 56.275580674409866, 60.90134225785732, 59.52798955142498, 59.80861969292164, 62.08337523043156, 55.752177760005, 54.078728556632996, 56.43472373485565, 61.13077774643898, 58.25020931661129, 57.030942142009735, 53.13699848949909, 45.08754841983318, 44.84602577984333, 47.22372159361839, 45.89859589934349, 48.33148755133152, 54.33428764343262, 56.14053592085838, 61.27671271562576, 55.01542769372463, 60.31645864248276, 53.35801362991333, 46.71388775110245, 61.535676419734955, 56.45989738404751, 59.30166229605675, 56.58528685569763, 56.44062481820583, 54.01791661977768, 48.92140589654446, 43.58797788619995, 46.51123322546482, 45.2336809784174, 43.543562069535255, 44.97593700885773, 45.56135639548302, 45.38952201604843, 48.08708846569061, 49.808867275714874, 50.419787093997, 48.68945874273777, 53.30765873193741, 55.870632603764534, 55.79209081828594, 52.07267940044403, 53.735515773296356, 53.52937303483486, 54.82028916478157, 50.85980728268623, 47.16100595891476, 46.08390815556049, 50.14175221323967, 50.62608562409878, 52.05660246312618, 53.51604714989662, 55.86659722030163, 52.92457088828087, 49.97088298201561, 42.403619438409805, 24.928974620997906, 6.9578812178224325, 2.0039376569911838, 2.0268428279086947, 5.873844986781478, 5.627027805894613, 5.2084774151444435, 9.911166820675135, 10.077592190355062, 9.142078589648008, 8.876952566206455, 2.5542115420103073, 0.1500417769420892, 1.0873887198977172, 9.638946577906609, 41.910991072654724, 35.99754698574543, 39.482807368040085, 54.45105917751789, 41.198358312249184, 25.6622326746583, 1.1367434402927756, 0.17609506408916786, 0.16023729782318696, 0.1412652275757864, 0.24585457082139328, 0.21360411308705807, 0.11537746162503026, 0.08380018378375098, 0.151980311202351, 0.1364801562158391, 0.19232774851843715, 0.14886596269207075, 0.08948148009949364, 0.20547191117657349, 0.14130662457318977, 0.1702619911520742, 0.12088067960576154, 0.1998288874165155, 0.1284114524605684, 0.15815049730008468, 0.17784641386242583, 0.10989975125994533, 0.18346758879488334, 0.1357729043229483, 0.16421969194198027, 0.28020195197314024, 0.11824682718724944, 0.11407485886593349], [0.03400787456484977, 0.010942676199192647, 0.019750982064579148, 0.045684670258197, 0.06375191776896827, 0.036099012941122055, 0.016439142491435632, 0.014186089756549336, 0.049483835537103005, 0.07669468381209299, 0.045518020997405984, 0.03186484522302635, 0.03839997873001266, 0.07881180106778629, 0.033006205267156474, 0.03189382980053779, 0.050311248560319655, 0.03248320637794677, 0.011924895661650226, 0.03257161471992731, 0.011957094666286139, 0.05250221693131607, 0.017286307775066234, 0.020548178545141127, 0.056159038285841234, 0.08402524748817086, 0.09766825955011882, 0.04499189024500083, 0.030891600181348622, 0.022058463910070714, 0.06117064651334658, 0.027874029583472293, 0.04278999003872741, 0.04460429248865694, 0.08041003835387528, 0.014348497643368319, 3.816246371716261, 23.887028731405735, 37.59625419974327, 26.733492091298103, 21.070382371544838, 32.98944599926472, 40.1032342761755, 23.150255866348743, 4.46587803773582, 0.18316771660465747, 0.010625955401337706, 2.3010807624086738, 10.097906850278378, 8.685742076486349, 4.62411199696362, 2.7105479780584574, 2.3001581244170666, 0.27319744345732033, 1.4970246702432632, 3.737927586771548, 18.032458685338497, 33.90350215137005, 48.373270109295845, 57.95800119638443, 57.87331514060497, 57.83647991716862, 58.13755676150322, 56.56763680279255, 54.59831267595291, 50.1556708663702, 54.330856427550316, 57.912076860666275, 60.115248039364815, 57.49314174056053, 57.103514447808266, 54.46217358112335, 57.455645352602005, 55.257379710674286, 56.58186323940754, 58.26053336262703, 58.235036730766296, 57.18957982957363, 56.92381829023361, 52.05817177891731, 43.948027566075325, 42.197412103414536, 42.84323304891586, 45.28118222951889, 55.85127644240856, 55.448665246367455, 58.44815969467163, 52.696320936083794, 56.85498498380184, 54.589842930436134, 41.0597113519907, 53.405609875917435, 54.125618040561676, 56.867885291576385, 52.49567650258541, 56.345588117837906, 51.27033345401287, 52.50157378613949, 48.937748819589615, 46.933538764715195, 39.772047847509384, 39.63124640285969, 39.05953288078308, 40.25063216686249, 44.106034487485886, 46.345554515719414, 46.88700646162033, 46.54945157468319, 48.78188118338585, 50.91821014881134, 51.61419220268726, 53.85657347738743, 51.77456259727478, 53.938694670796394, 51.814080476760864, 51.91201262176037, 48.44446308910847, 44.20284949243069, 45.02337746322155, 50.34512870013714, 50.03674864768982, 52.10384152829647, 50.60005322098732, 50.6842453032732, 50.911157727241516, 41.662632599473, 23.050665110349655, 7.464725095778704, 0.4594886815175414, 1.0779464640654624, 0.6899898941628635, 3.43504655174911, 3.3278110809624195, 3.9158133789896965, 1.2643525865860283, 2.4431919492781162, 1.8991950899362564, 0.1467412681085989, 0.2187281975056976, 0.47067344072274864, 8.848126363009214, 26.014359779655933, 37.484437599778175, 25.357152745127678, 24.369466044008732, 39.68295022845268, 19.203981421887875, 2.868832997046411, 0.06310058670351282, 0.030092032538959756, 0.06699439807562158, 0.04012331984995399, 0.08834469539579004, 0.012260419698577607, 0.06018790940288454, 0.04074843454873189, 0.01196827326566563, 0.03697351523442194, 0.029739484562014695, 0.0158177737830556, 0.047660809141234495, 0.025906020928232465, 0.041755695929168724, 0.058274674956919625, 0.04856021791056264, 0.006773032191631501, 0.03761616688279901, 0.030421594346989878, 0.02118192071066005, 0.04250279002008028, 0.04515099186392035, 0.05070250510470942, 0.04782237469044048, 0.03186103800544515, 0.06869887380162254, 0.06976301709073596, 0.022286546300165355, 0.011975505494774552, 0.03474070457741618, 0.03632741259934846, 0.02164533256291179, 0.04168923660472501, 0.037214386684354395, 0.01894661458209157, 0.024575025454396382, 0.02777903097012313, 0.05011693574488163, 0.06264196170377545, 0.022540550053236075, 0.039205431603477336, 0.058916031557600945, 0.01790088583220495, 0.005553446999329026, 0.015320004204113502, 0.068303939915495, 0.009872239497781266, 0.014750038499187212, 0.10230942105408758, 0.021135068927833345, 0.05931796389631927, 0.0244168886274565, 0.0347405895445263, 0.09608460546587594, 0.045049651598674245, 0.041499398939777166, 0.05721894762245938, 0.07069536237395369, 0.011275469132669969, 0.018715225924097467, 0.05527058361622039, 0.05286733132379595, 0.08880080451490358, 7.323418278247118, 32.15693347156048, 40.767370238900185, 27.403447441756725, 23.582925349473953, 43.92612934112549, 52.808441519737244, 22.807970233261585, 3.8370010955259204, 0.431214309646748, 0.10018088956712745, 0.9497371281031519, 1.378621004987508, 9.977713599801064, 8.982261065393686, 9.004220087081194, 3.757862742058933, 0.37002150260377675, 1.724473221693188, 6.20651476085186, 20.74246946722269, 36.94563791155815, 50.94167768955231, 56.970384791493416, 55.58902211487293, 61.85130648314953, 60.91242626309395, 57.20067523419857, 55.810899809002876, 53.86145621538162, 54.55000586807728, 57.98948250710964, 60.34454293549061, 60.068787932395935, 58.346435353159904, 55.014443546533585, 57.44578868150711, 55.50150901079178, 57.27069027721882, 59.82242435216904, 59.82474222779274, 58.82247380912304, 58.08846719563007, 51.632647812366486, 45.44618457555771, 44.14451502263546, 45.89066952466965, 48.15361529588699, 57.449333891272545, 57.26825840771198, 59.74619284272194, 53.771222457289696, 58.124132081866264, 54.88550506532192, 42.826050370931625, 54.46933999657631, 56.038450598716736, 59.927648305892944, 55.10625422000885, 56.71694219112396, 53.51618394255638, 55.082608088850975, 49.76015768945217, 46.12017720937729, 40.359089747071266, 41.76868490874767, 40.80824464559555, 42.81715884804726, 45.17381139099598, 48.32421854138374, 48.878604993224144, 48.82263399660587, 50.51465280354023, 51.50095447897911, 54.97337155044079, 53.24202485382557, 50.49706734716892, 52.36511170864105, 52.681178748607635, 53.55637438595295, 50.361179038882256, 45.69335751235485, 46.85541495680809, 50.476233065128326, 53.08750234544277, 52.24002242088318, 52.46570371091366, 51.16362378001213, 50.668358355760574, 43.02576385438442, 27.089859768748283, 9.49838737025857, 1.9014470628462732, 1.3619828852824867, 2.0667266752570868, 4.647113112732768, 2.399442046880722, 4.478423539549112, 4.356356039643288, 3.065554853528738, 0.5839546245988458, 0.3570767550263554, 0.19401720317546278, 0.20831360947340727, 7.99460856243968, 27.770268358290195, 45.46041861176491, 27.625765912234783, 23.817139081656933, 44.64082159101963, 27.358644045889378, 5.180649608373642, 0.06775476547772996, 0.019520406058290973, 0.08862813643645495, 0.05733516423788387, 0.006026037362971692, 0.01823988219257444, 0.03216747449187096, 0.02088264409394469, 0.03531458511133678, 0.014462948875006987, 0.0703293870901689, 0.043252618925180286, 0.058480594962020405, 0.020544013241305947, 0.047255002791644074, 0.01130686290707672, 0.02427558742056135, 0.009930833912221715, 0.08784329300397076, 0.04339271785283927, 0.005632684715237701, 0.07687216100748628, 0.044795774010708556, 0.021888875744480174, 0.05068527243565768, 0.008336351893376559, 0.055646600158070214, 0.009658246781327762, 0.11859954029205255, 0.24995281419251114, 0.13645630358951166, 0.16436006175354123, 0.12132137431763113, 0.19349348440300673, 0.09204446483636275, 0.057000500164576806, 0.1031538144161459, 0.19525325013091788, 0.24784964189166203, 0.1804138589068316, 0.06782397817005403, 0.1279071779572405, 0.076488277700264, 0.18005152756813914, 0.09834066760959104, 0.17640773090533912, 0.12202231053379364, 0.06995665826252662, 0.09405067554325797, 0.24110583501169458, 0.24283450475195423, 0.17831166624091566, 0.11854698139359243, 0.19652725051855668, 0.1674438634654507, 0.2069790053064935, 0.16748382069636136, 0.15658710384741426, 0.12746070191496983, 0.17023165215505287, 0.08402493578614667, 0.1154145912732929, 0.142311759700533, 0.1254081292427145, 6.636409442871809, 36.70691192150116, 49.93746757507324, 38.09151202440262, 28.474644161760807, 41.877678260207176, 50.98800480365753, 29.80273749679327, 6.816608123481274, 0.7358613889664412, 0.16979506151983514, 4.630904132500291, 18.85550022125244, 17.912394627928734, 9.14532931521535, 4.753877883777022, 4.6427984442561865, 1.2204733723774552, 2.4499104637652636, 4.840078158304095, 20.64538847655058, 37.2017365694046, 51.2762763351202, 57.93925300240517, 58.893104419112206, 62.822511568665504, 63.82218852639198, 61.45289786159992, 59.144878908991814, 55.38783051073551, 59.08078394830227, 62.025663927197456, 65.00929042696953, 63.41261230409145, 58.66862006485462, 55.64642943441868, 55.720457062125206, 55.904564782977104, 58.94750989973545, 60.937926694750786, 63.08483809232712, 63.44117157161236, 61.373254135251045, 57.426960691809654, 47.95823737978935, 46.44310288131237, 45.97078822553158, 49.7583793848753, 60.786839202046394, 60.28335481882095, 61.90516859292984, 56.83062829077244, 58.34361590445042, 57.089082822203636, 46.45391710102558, 54.72956903278828, 56.074423268437386, 60.56471452116966, 56.42031870782375, 59.05674263834953, 54.92525093257427, 58.6621680110693, 52.60487884283066, 50.4992750287056, 42.91262112557888, 43.27841989696026, 42.4689569324255, 43.310908153653145, 48.277956023812294, 51.848115250468254, 51.162134259939194, 51.57101131975651, 53.51389266550541, 54.86736863851547, 56.5187182277441, 56.61969020962715, 51.15880183875561, 54.394928589463234, 55.175262317061424, 56.95217616856098, 52.839691042900085, 47.06970065832138, 49.12986271083355, 54.04067359864712, 55.28706751763821, 56.33271440863609, 55.41090287268162, 52.63163320720196, 51.84407986700535, 42.005473002791405, 25.672191940248013, 9.925410356372595, 1.4337054616771638, 2.386887283064425, 2.051403047516942, 6.377550708130002, 8.254678007215261, 9.299383498728275, 5.356468548998237, 9.929987210780382, 9.108230955898762, 2.1342514269053936, 0.4458379140123725, 0.6510183541104198, 12.410376314073801, 34.77122738957405, 48.074552938342094, 35.06117843091488, 32.01242342591286, 51.27158358693123, 30.331978797912598, 5.348033951595426, 0.23920479405205697, 0.15311431285226718, 0.18180065089836717, 0.11492703735711984, 0.15762075228849426, 0.12155900258221664, 0.18389525881502777, 0.1643970949226059, 0.16466043860418722, 0.12920382869197056, 0.17053455230779946, 0.13398504088399932, 0.11889460336533375, 0.10125584594788961, 0.11616085044806823, 0.08858958186465316, 0.2197484130738303, 0.1340043218806386, 0.19176037661964074, 0.08331735734827816, 0.17950812703929842, 0.216836626350414, 0.10818586510140449, 0.2802197338314727, 0.0968410617497284, 0.11540293213329278, 0.16809805179946125, 0.19124684011330828], [0.03319320050650276, 0.07407796758343466, 0.01269050633709412, 0.02944623789517209, 0.06515732282423414, 0.0372203164442908, 0.028763389673258644, 0.01815449068089947, 0.02291594133566832, 0.04176195965555962, 0.03666544973384589, 0.03292792724096216, 0.03253499344282318, 0.0879655840981286, 0.015722671269031707, 0.01968636512174271, 0.02707528015889693, 0.038312924807542004, 0.03798606441705488, 0.02315277735760901, 0.030198467648006044, 0.059540700967772864, 0.026040331104013603, 0.05469125200761482, 0.04406884778290987, 0.08496227572322823, 0.0513775552099105, 0.03760100109502673, 0.046393187512876466, 0.04033615667140111, 0.01313816888796282, 0.024744494876358658, 0.01792266601114534, 0.02276408122270368, 0.03993923011876177, 0.09089928644243628, 0.11360289005097002, 4.190497314557433, 22.652932852506638, 38.45729939639568, 24.104986935853958, 16.6708929464221, 29.054532945156097, 46.654211953282356, 26.33304487913847, 4.393185563385487, 0.2016419096617028, 0.2807571674929932, 0.06621462351176888, 8.753038365393877, 10.42773675173521, 11.734156999737024, 1.8687346181832254, 0.583694635424763, 0.34227601485326886, 1.148198638111353, 4.531891420483589, 14.007252026349306, 31.155170425772667, 42.71305963397026, 55.78360587358475, 61.30687929689884, 58.55917073786259, 57.2467515617609, 55.90545013546944, 53.34314122796059, 56.466170847415924, 60.15127770602703, 59.88933876156807, 57.88540989160538, 55.422811433672905, 58.07352639734745, 55.38914144039154, 57.814714685082436, 58.383977338671684, 58.15570838749409, 56.57434344291687, 57.2937398403883, 56.14147067070007, 60.609643310308456, 51.692236214876175, 44.40968379378319, 43.82245950400829, 48.32602344453335, 55.599965527653694, 56.330605521798134, 54.5845840126276, 58.20824816823006, 55.905396938323975, 49.03519079089165, 46.22429542243481, 52.06556238234043, 54.28211644291878, 56.0486264526844, 57.26005084812641, 56.33987322449684, 56.535562723875046, 54.028225466609, 54.1342131793499, 51.93205274641514, 47.049440145492554, 38.79306077957153, 41.43853202462196, 42.07576923072338, 46.37580469250679, 46.95606015622616, 50.37065573036671, 48.187539875507355, 51.47008493542671, 53.07878941297531, 53.93184743821621, 53.81746217608452, 52.37833119928837, 53.56380678713322, 54.44048434495926, 50.020246133208275, 49.74967785179615, 46.85369364917278, 49.892424792051315, 49.133065938949585, 52.634247466921806, 50.4075213521719, 51.72519564628601, 51.16628743708134, 42.35160402953625, 22.067247480154037, 7.448537489399314, 0.2990522951586172, 0.911857495084405, 1.2035930156707764, 1.833266846369952, 2.6095463102683425, 0.9659858874510974, 5.296481167897582, 3.270572852343321, 2.6569349924102426, 0.7734486751724035, 0.03444739668339025, 0.6712810043245554, 9.375968389213085, 29.075196236371994, 36.196975484490395, 21.24493930488825, 19.280788600444794, 29.04543813318014, 18.26370097696781, 3.561605173163116, 0.10016269210609607, 0.06177528164698742, 0.034396032642689534, 0.06340542386169545, 0.039417800871888176, 0.014169140031299321, 0.032910831869230606, 0.043585546372924, 0.05974222003715113, 0.03505293352645822, 0.016314864296873566, 0.028939096846443135, 0.03895004374498967, 0.05419221706688404, 0.08551064864150248, 0.06043212422810029, 0.02889619328925619, 0.04975443742296193, 0.0762466418382246, 0.024838029603415634, 0.03917418347555213, 0.03491430034046061, 0.09077420487301424, 0.0668832020892296, 0.04175325797405094, 0.07255170377902687, 0.027710857284546364, 0.024944386786955874, 0.03530272930220235, 0.01977064341190271, 0.042165313207078725, 0.0378004161757417, 0.03720378139405511, 0.05239121390332002, 0.025805344885156956, 0.0041403718478250084, 0.023380360653391108, 0.016559893629164435, 0.027356797181710135, 0.005335365049177199, 0.07801224084687419, 0.03448030351137277, 0.027459673692646902, 0.036516626860247925, 0.01196008459373843, 0.08139940284308977, 0.046148019027896225, 0.019926464738091454, 0.024622845739941113, 0.03796568875259254, 0.020100631954846904, 0.007480710819436354, 0.10561306175077334, 0.052528373926179484, 0.07619601252372377, 0.08651821059174836, 0.025087766007345635, 0.10272973639075644, 0.05440016684588045, 0.048261781776091084, 0.021267119263939094, 0.022357901943905745, 0.07206158945336938, 0.05163683934370056, 0.016608995974820573, 0.28928975807502866, 7.915638349950314, 31.84298101812601, 42.04179145395756, 23.963066451251507, 17.837519645690918, 37.4726278334856, 57.40903325378895, 26.454165279865265, 3.4548565512523055, 0.17505052092019469, 0.23763901088386774, 0.052598031907109544, 5.072135981172323, 10.465497225522995, 12.669785544276237, 6.196984872221947, 0.5393397936131805, 0.8357790461741388, 1.3695981516502798, 6.383305499330163, 16.115132868289948, 33.60225431621075, 47.32573091983795, 57.77166299521923, 60.5496559292078, 59.817499816417694, 58.52594152092934, 56.89641036093235, 55.707499757409096, 59.23275679349899, 60.873645544052124, 60.64245454967022, 58.70562247931957, 55.00387631356716, 58.85207802057266, 56.509055346250534, 58.29594746232033, 57.75495529174805, 58.18369388580322, 56.99247680604458, 58.90979312360287, 58.83390739560127, 61.11686289310455, 52.85664573311806, 46.55050791800022, 46.37681923806667, 49.76190559566021, 58.24279211461544, 57.178066447377205, 56.379862278699875, 59.12130117416382, 55.778749734163284, 50.086104199290276, 48.155811578035355, 52.82828405499458, 55.77617347240448, 57.54046060144901, 57.97467850148678, 57.59895846247673, 59.034578427672386, 55.13726815581322, 56.43477313220501, 52.81274288892746, 48.40852841734886, 40.49874745309353, 43.92232574522495, 44.35467414557934, 47.76898093521595, 48.88523183763027, 51.69011972844601, 49.62423138320446, 51.72396831214428, 54.046905264258385, 55.297991931438446, 54.66072052717209, 53.585800006985664, 55.51214464008808, 55.6973847001791, 52.63812705874443, 51.35986804962158, 47.224785536527634, 50.76777242124081, 51.643374636769295, 53.06861735880375, 51.6887442022562, 53.11502806842327, 52.46124655008316, 43.92184317111969, 25.262024849653244, 9.277295283973217, 1.7534751654602587, 1.8527150340378284, 3.418804560787976, 3.2861988013610244, 3.928269585594535, 3.484081970527768, 5.1855280715972185, 3.9326514629647136, 0.6653722026385367, 0.1188223552890122, 0.032438488269690424, 0.34118259383831173, 8.45835467800498, 30.297539345920086, 43.19275349378586, 28.00002682954073, 22.055722698569298, 30.999186895787716, 27.83786103129387, 6.647452600300312, 0.09713044739328325, 0.09325904888100922, 0.03300444637716282, 0.05451089527923614, 0.030647442872577813, 0.040387479893979616, 0.08652750970213674, 0.005778323311460554, 0.05287893109198194, 0.04766283149365336, 0.03320439580420498, 0.006146071864350233, 0.019979888238594867, 0.03149311087327078, 0.024621808588563, 0.03550945453753229, 0.0432340912084328, 0.062206198563217185, 0.10159097757423297, 0.04562339854601305, 0.02434908972645644, 0.08794403212959878, 0.029564178148575593, 0.0542036461411044, 0.03539042518241331, 0.06986384527408518, 0.022438603082264308, 0.017452233441872522, 0.025288040123996325, 0.15630673529813066, 0.21801137190777808, 0.10042985042673536, 0.15016902558272704, 0.19639845821075141, 0.08002077447599731, 0.13270712195662782, 0.11204025358892977, 0.14763306244276464, 0.13541508524212986, 0.10865133270272054, 0.1406039739958942, 0.06150731067464221, 0.18415379337966442, 0.11826693938928656, 0.14785486069740728, 0.2396233653416857, 0.11536503065144643, 0.09097872592974454, 0.069623886665795, 0.19242149661295116, 0.09618301424779929, 0.10168037668336183, 0.13742266892222688, 0.1546618837164715, 0.15467800316400826, 0.15354032046161592, 0.0739264432922937, 0.2116687106899917, 0.07943818112835288, 0.12055158164002933, 0.09400329683558084, 0.09122258081333712, 0.13659989432198927, 0.1171918716863729, 0.21802379545988515, 0.2203634160105139, 6.921793604269624, 34.50000174343586, 52.784981578588486, 33.762909695506096, 24.914921075105667, 37.03174889087677, 57.48184874653816, 34.114466831088066, 5.946659529581666, 0.36218332475982606, 0.5916420870926231, 1.5973410685546696, 16.81047845631838, 22.315231673419476, 21.15864973515272, 6.2140184082090855, 2.20483073964715, 1.4111479721032083, 2.3420131159946322, 5.049582291394472, 15.367064159363508, 33.01088444888592, 46.0639326274395, 54.601789489388466, 63.1206663697958, 62.626594081521034, 61.5881934016943, 60.652201026678085, 58.36377762258053, 61.59312553703785, 64.07239750027657, 62.835442274808884, 60.120624750852585, 56.496337428689, 60.21071791648865, 56.445427760481834, 59.99451331794262, 59.23179544508457, 58.35725337266922, 56.8018714338541, 60.70146918296814, 60.114005506038666, 66.1404137313366, 57.30752930045128, 50.06959028542042, 48.764873296022415, 52.23147287964821, 59.63154159486294, 59.98724430799484, 57.27279916405678, 61.6786665469408, 56.207552924752235, 49.11357678472996, 52.302111089229584, 53.14992159605026, 57.25165329873562, 57.40517646074295, 58.92621964216232, 58.40219736099243, 61.427997797727585, 57.18739874660969, 58.413467556238174, 56.583728939294815, 51.613979414105415, 41.90525338053703, 45.861460492014885, 47.456033527851105, 51.55849479138851, 51.89121253788471, 55.246189311146736, 51.565418019890785, 55.9750472009182, 56.97867974638939, 56.89248897135258, 56.00784324109554, 53.477247431874275, 54.837889820337296, 56.942171305418015, 53.20392429828644, 54.08260054886341, 49.32540401816368, 53.9439307898283, 53.03075239062309, 56.0705778747797, 54.0056698769331, 54.788701459765434, 52.80338019132614, 42.41813085973263, 25.252350568771362, 8.15466072410345, 0.9447072667535394, 1.6558141121640801, 2.7781549002975225, 6.743091568350792, 8.141755666583776, 4.129263600334525, 11.561740301549435, 9.94020676240325, 7.029817057773471, 2.2476005321368575, 0.31528383668046445, 1.0641775466501713, 12.97599971294403, 39.18370261788368, 46.776895970106125, 32.073964923620224, 30.607684403657913, 39.86455388367176, 30.262326635420322, 6.349360020831227, 0.2670909039443359, 0.16179787111468613, 0.16690669697709382, 0.1166851629386656, 0.11890626992681064, 0.1618377838167362, 0.12564432516228408, 0.1226448685338255, 0.11254586395807564, 0.13084121426800266, 0.09853957060840912, 0.09090465217013843, 0.1468372278031893, 0.1039286091690883, 0.232346058182884, 0.10974300967063755, 0.11774051177781075, 0.1620146821369417, 0.242646919505205, 0.1582588953897357, 0.12951786105986685, 0.14470361260464415, 0.16244591446593404, 0.18199886369984597, 0.12097868762793951, 0.26550460781436414, 0.1446439142455347, 0.04731848239316605, 0.1807479589479044], [0.05750196934968699, 0.04881323089648504, 0.1074156716640573, 0.03866725579428021, 0.02491274346539285, 0.02251199221063871, 0.023563899339933414, 0.03614483313867822, 0.05355070832592901, 0.017019303450069856, 0.04954739677486941, 0.06692350812954828, 0.01460201621739543, 0.06940024788491428, 0.044762722463929094, 0.026823152184078936, 0.025335307509521954, 0.0748770973586943, 0.00971242820014595, 0.07040004697046243, 0.016314784515998326, 0.023966226872289553, 0.030388038139790297, 0.04218917325488292, 0.050001631971099414, 0.021464534256665502, 0.024276991935039405, 0.03738415296538733, 0.010055539769382449, 0.06741691016941331, 0.016405981477873866, 0.06417256707209162, 0.027684540727932472, 0.002333876791453804, 0.06023747373546939, 0.034135464593418874, 0.026751534933282528, 0.042743334925035015, 2.9249213123694062, 25.39640463888645, 43.19369964301586, 29.02887672185898, 19.38088472932577, 29.18709073215723, 42.47261993587017, 28.506241366267204, 7.502147387713194, 0.6301528424955904, 0.14007805846631527, 4.399871779605746, 8.753002267330885, 21.50392010807991, 8.241163082420826, 0.5249326885677874, 1.1022088746540248, 0.4584075207822025, 0.5986499204300344, 2.1885797241702676, 11.596921663731337, 28.295890353620052, 47.331958785653114, 57.09338419139385, 60.302889570593834, 58.809102326631546, 56.57429784536362, 57.18878947198391, 57.4895965307951, 59.54040348529816, 60.55753670632839, 58.98345597088337, 59.853791669011116, 60.86179777979851, 59.14960965514183, 57.51806080341339, 59.2549704015255, 57.48924694955349, 57.02206961810589, 56.6580605506897, 58.31519342958927, 57.79111035168171, 55.54682157933712, 47.73426219820976, 43.33636298775673, 43.383446261286736, 53.593570590019226, 60.21975763142109, 58.33568572998047, 55.6348742544651, 56.24310381710529, 39.359488785266876, 38.10095451772213, 55.38680836558342, 55.18112160265446, 53.34593027830124, 55.96623167395592, 54.92912672460079, 57.063270807266235, 57.59405292570591, 55.94760127365589, 56.140117943286896, 46.96776732802391, 40.46902924776077, 41.02552838623524, 43.09834375977516, 47.76508994400501, 49.402061104774475, 50.69209188222885, 51.033446565270424, 52.839398458600044, 54.615860134363174, 53.4680937230587, 54.432299584150314, 54.517965987324715, 56.50592811405659, 52.843730226159096, 52.786619290709496, 50.30945621430874, 48.056880086660385, 50.94454653561115, 52.41170480847359, 51.444584503769875, 53.41066360473633, 51.14598512649536, 38.22765491902828, 19.227304570376873, 4.163324497640133, 0.36310421128291637, 1.019360851496458, 1.2776058004237711, 2.4804009776562452, 1.2342226970940828, 3.5522500751540065, 2.211933033540845, 1.8384184199385345, 3.3558424143120646, 1.3103937660343945, 0.013302775387273869, 0.5866249313112348, 11.331721544265747, 34.752194210886955, 34.25351656973362, 24.167694970965385, 21.5776152536273, 25.595249868929386, 13.902602791786194, 2.373675866983831, 0.06834480256657116, 0.05058884518803097, 0.025415170021005906, 0.040685685962671414, 0.009554501957609318, 0.042197329457849264, 0.019439276329649147, 0.08755873874179088, 0.09081720490939915, 0.04803454728971701, 0.05807727480714675, 0.06481784221250564, 0.018144339956052136, 0.052888233913108706, 0.011497238629090134, 0.05241230202955194, 0.05854030074260663, 0.04820052119612228, 0.014955667211324908, 0.08801346746622585, 0.02641983202920528, 0.06136379415693227, 0.027531020059541333, 0.05161825225513894, 0.04077223151398357, 0.00898300000699237, 0.05789291419205256, 0.017132800094259437, 0.033382930560037494, 0.05172032724658493, 0.05804622334835585, 0.01878531249531079, 0.05175649581360631, 0.04556932195555419, 0.01693018635705812, 0.036001435364596546, 0.04435417016793508, 0.02622623353090603, 0.054731695345253684, 0.02645720658620121, 0.05235720869677607, 0.034524435322964564, 0.07222789732622914, 0.0601238026865758, 0.06346618349198252, 0.029349810647545382, 0.020491586074058432, 0.09302268968895078, 0.04969985988282133, 0.034973724104929715, 0.02256109826703323, 0.033387787916581146, 0.06721725017996505, 0.06579090913874097, 0.08041060238610953, 0.01886571120849112, 0.10861936840228736, 0.08811434017843567, 0.024426391828455962, 0.058508388392510824, 0.018373704406258184, 0.02390542271314189, 0.1062978117261082, 0.09768018586328253, 0.01721957014524378, 0.033820641838246956, 0.014501397690764861, 0.18072517501423135, 6.697252728044987, 32.798175662755966, 43.13791863620281, 25.356852561235428, 17.389170303940773, 38.84433522820473, 53.22333745658398, 26.317399218678474, 7.020032107830048, 0.39631442923564464, 0.2254985287436284, 0.569397546350956, 2.7009881660342216, 5.1633895095437765, 7.354344818741083, 1.621616540942341, 1.4940269873477519, 1.1167838238179684, 1.6145111597143114, 3.9053722517564893, 15.075814537703991, 31.069217137992382, 48.519459664821625, 60.27076229453087, 61.36247791349888, 61.802194118499756, 59.00978475809097, 58.189062997698784, 59.18900594115257, 60.30651457607746, 60.94209127128124, 59.20603662729263, 59.896140396595, 62.0562294870615, 60.854737758636475, 60.66767379641533, 58.90909396111965, 59.28386025130749, 56.88163295388222, 58.46090041100979, 59.81875754892826, 60.42961277067661, 57.82590128481388, 49.43087495863438, 44.68353509902954, 46.169627755880356, 56.66630990803242, 62.768831849098206, 58.51188987493515, 57.58372128009796, 58.245926946401596, 40.569370463490486, 42.54564441740513, 55.10994002223015, 54.84094485640526, 54.31520126760006, 56.901920065283775, 56.91402241587639, 57.61696569621563, 58.487077206373215, 57.15784773230553, 57.64595814049244, 49.906016662716866, 41.067896112799644, 42.23456650972366, 45.26474051177502, 48.44362333416939, 50.683948919177055, 52.598358392715454, 51.68322689831257, 54.24932800233364, 55.76630920171738, 55.664778649806976, 55.709008276462555, 54.55855540931225, 55.51486909389496, 55.773631408810616, 53.22247490286827, 52.66079664230347, 48.665915206074715, 51.93727746605873, 52.9473202675581, 53.48019987344742, 53.02240423858166, 52.806085646152496, 39.69589613378048, 23.446282781660557, 6.851023826748133, 1.215225972700864, 2.097868141718209, 3.0988443922251463, 5.748980361968279, 4.744571708142757, 5.7584162056446075, 3.1674720346927643, 3.08493975084275, 0.9068139782175422, 0.1704714252264239, 0.07612723769852892, 0.6027995946351439, 9.776995070278645, 35.40195174515247, 42.735900208353996, 30.318470522761345, 21.881462149322033, 28.74777540564537, 21.371546611189842, 5.236846217885613, 0.17469090584199876, 0.0356932808062993, 0.0488517928897636, 0.03346408069774043, 0.0110629736991541, 0.057141626966767944, 0.04368885332951322, 0.04034111421788111, 0.049654355098027736, 0.026489801712159533, 0.012949067804584047, 0.03614961256971583, 0.08953569398727268, 0.12294567583012395, 0.024481468462909106, 0.0449607571499655, 0.0053474745800485834, 0.02715347654884681, 0.026611736575432587, 0.0495186274201842, 0.01997249088162789, 0.010825819481397048, 0.040678583609405905, 0.035712268654606305, 0.032194640807574615, 0.04096600998309441, 0.03401140718779061, 0.042819523805519566, 0.03217214631149545, 0.07395425898721442, 0.1932144517195411, 0.10378432081779465, 0.2645367878722027, 0.11973996894084848, 0.16318803245667368, 0.08987809866084717, 0.06782167751225643, 0.11061255441745743, 0.1602925729821436, 0.0872231915127486, 0.1324551776633598, 0.17500691232271492, 0.2740100654773414, 0.14329759898828343, 0.2044355167890899, 0.09870213805697858, 0.27623817091807723, 0.20692374499049038, 0.1820413739187643, 0.13753154198639095, 0.10442737693665549, 0.1552296563750133, 0.1914556953124702, 0.1493118895450607, 0.17547879950143397, 0.18731785094132647, 0.19157587870722637, 0.1288332446711138, 0.14801218116190284, 0.1474518745089881, 0.07821242776117288, 0.18454540986567736, 0.11287801957223564, 0.235169603547547, 0.08671799674630165, 0.08399939848459326, 0.15119468851480633, 0.1423550714389421, 5.247420100495219, 36.40388958156109, 53.865582793951035, 39.59523193538189, 27.278232760727406, 36.98867440223694, 53.75411197543144, 36.17083288729191, 10.43733598664403, 0.7324684085324407, 0.3900168609106913, 6.642332375049591, 16.729766987264156, 37.75262340903282, 18.314243964850903, 1.7698957468383014, 2.687203693203628, 1.1982392217032611, 1.5386711480095983, 2.982165003195405, 13.825722467154264, 30.735539942979813, 50.949315279722214, 57.590272128582, 63.50264847278595, 64.48390781879425, 61.51803396642208, 62.00063847005367, 62.20273442566395, 64.51737642288208, 63.80062848329544, 60.251808911561966, 61.816599145531654, 64.03108611702919, 62.82132223248482, 61.68408885598183, 61.4127454161644, 60.47380059957504, 59.08730439841747, 59.47104200720787, 61.04630067944527, 63.61427128314972, 61.4819511026144, 51.2814212590456, 48.34187999367714, 47.70486697554588, 58.851728439331055, 64.97897565364838, 63.38498778641224, 58.71162995696068, 59.12664748728275, 44.08862382173538, 44.80052702128887, 55.63953660428524, 53.96536163985729, 53.95704008638859, 57.3307878524065, 57.436034604907036, 61.096283197402954, 60.01947037875652, 57.892739698290825, 61.59936100244522, 51.239448711276054, 44.672192707657814, 44.419149085879326, 47.93264575302601, 52.450257539749146, 51.65439784526825, 54.52291712164879, 54.90827724337578, 56.95695251226425, 57.73045800626278, 56.80607780814171, 56.401471719145775, 54.060162752866745, 56.98706589639187, 56.49421714246273, 56.72294966876507, 55.555640906095505, 51.35757677257061, 53.698745146393776, 55.950416922569275, 53.6389097571373, 55.01221306622028, 51.79019495844841, 38.658680990338326, 21.597881466150284, 5.300346985459328, 0.9116418566554785, 1.9539866060949862, 5.178716462105513, 7.649489231407642, 6.611979128792882, 8.86471152305603, 9.186453558504581, 8.877342995256186, 8.914426155388355, 3.211408839561045, 0.21398142096586525, 0.9646434313617647, 15.617647413164377, 42.81744383275509, 43.20194140076637, 35.485277473926544, 31.995210349559784, 37.11264654994011, 21.851673647761345, 4.871918074786663, 0.21161303477128968, 0.23209328268421814, 0.15881685685599223, 0.19432696077274159, 0.12490741704823449, 0.19368687324458733, 0.12492203735746443, 0.18868203711463138, 0.25537497480399907, 0.1788171727093868, 0.1355751368100755, 0.12552667991258204, 0.2603470970643684, 0.193334961659275, 0.17104841535910964, 0.1597121244412847, 0.08539399044821039, 0.14309246937045828, 0.11670534935547039, 0.13152985309716314, 0.16266607999568805, 0.11804520792793483, 0.0929625757271424, 0.09671980966231786, 0.1022677643049974, 0.09326871906523593, 0.1632910277112387, 0.11778525586123578, 0.10603446804452688, 0.1666214005672373], [0.009848647550825262, 0.034829027572413906, 0.017560967353347223, 0.04343704633356538, 0.032953464542515576, 0.008246042725659208, 0.011178459299117094, 0.04767585618537851, 0.037401018271339126, 0.021941809427517, 0.07235488621518016, 0.04351889409008436, 0.019095563620794564, 0.04692401234933641, 0.022483054017357063, 0.040621686857775785, 0.07701977418037131, 0.07630230291397311, 0.04552209167741239, 0.04531972655968275, 0.03081923150602961, 0.03271920562838204, 0.020932071129209362, 0.11127267251140438, 0.08834956388454884, 0.05667887562594842, 0.025545047719788272, 0.06860122201032937, 0.030284640270110685, 0.10243420576443896, 0.041223969383281656, 0.010935432837868575, 0.030441480193985626, 0.050631767298909836, 0.023852054873714224, 0.01698766940535279, 0.017466905701439828, 0.01814483905036468, 0.03063455176743446, 4.3678029254078865, 18.98952852934599, 34.87535700201988, 27.627836801111698, 21.524976678192616, 28.01421146839857, 37.2994901239872, 32.501206398010254, 8.823058158159256, 1.1144215380772948, 0.17999966628849506, 1.0560484766028821, 2.2993663419038057, 4.033669754862785, 2.048309538513422, 1.0168845718726516, 0.31978766375686973, 0.5108412040863186, 0.24941573676187545, 2.68387483432889, 11.430724281817675, 24.837238043546677, 46.147459745407104, 59.32105265557766, 59.74232845008373, 58.17006401717663, 58.25115546584129, 58.04673783481121, 57.94115670025349, 59.42019693553448, 58.29985745251179, 58.94790127873421, 57.92338505387306, 59.225168600678444, 58.20415958762169, 59.06800143420696, 59.73254777491093, 59.53645549714565, 56.53867855668068, 56.40224687755108, 56.9703733921051, 57.43925683200359, 51.24869741499424, 45.68812899291515, 42.32579581439495, 45.623395666480064, 52.64840170741081, 59.78665307164192, 57.14654713869095, 56.59103214740753, 57.08529822528362, 38.06951120495796, 57.211003080010414, 55.828838646411896, 58.66862766444683, 56.168852001428604, 57.89637990295887, 57.20184177160263, 59.47311669588089, 57.552133575081825, 56.701765805482864, 49.45835888385773, 43.800732269883156, 43.45046706497669, 44.341602846980095, 48.417963311076164, 51.22016094624996, 51.632689610123634, 52.33386978507042, 54.07474637031555, 54.31508727371693, 56.9507360458374, 56.923331916332245, 56.04552201926708, 54.023950695991516, 55.10116249322891, 53.67496222257614, 53.251007571816444, 51.156476363539696, 51.93114459514618, 50.76704666018486, 55.106489807367325, 49.8065759986639, 33.787657767534256, 13.504390809684992, 2.3811056558042765, 0.3346106386743486, 0.3551314672222361, 1.8867837684229016, 1.8668648810125887, 6.059804633259773, 3.4689200716093183, 3.7381807481870055, 1.8572911759838462, 2.2704921662807465, 0.8166058093775064, 0.11911765584954992, 0.8587904926389456, 12.79610501602292, 33.86737748980522, 32.28076122701168, 19.59343772381544, 23.319025710225105, 28.754274956882, 12.373100314289331, 1.4962388249114156, 0.022738876032235567, 0.05353143475076649, 0.03580133008654229, 0.08035094855586067, 0.01962770020327298, 0.04446666862349957, 0.04418686039571185, 0.03998559208412189, 0.04319500229030382, 0.00806123403890524, 0.01347538409390836, 0.029292644867382478, 0.030932878435123712, 0.018219606718048453, 0.08411762260948308, 0.048974588644341566, 0.07734095343039371, 0.048900433248491026, 0.061702046514255926, 0.03739709973160643, 0.02847318766725948, 0.07259572797920555, 0.05831565635162406, 0.04918445316434372, 0.037259820965118706, 0.06116149954323191, 0.10043472633697093, 0.04312951146857813, 0.06709025386953726, 0.033413102573831566, 0.008860002944857115, 0.05303352045302745, 0.054616206034552306, 0.1142395414353814, 0.037260013923514634, 0.008144715447997442, 0.046257623107521795, 0.061687826964771375, 0.04938812075124588, 0.057866779461619444, 0.040472604232490994, 0.04932376541546546, 0.06408752436982468, 0.08380078492336906, 0.01361650625767652, 0.03366037875821348, 0.018162964151997585, 0.027612077428784687, 0.09547103487420827, 0.02468308030074695, 0.02458328555803746, 0.021723627287428826, 0.043616078328341246, 0.01559354870551033, 0.0055768232596165035, 0.06190090127347503, 0.022236314034671523, 0.032729536324040964, 0.026900591583398636, 0.013120429703121772, 0.02326397705473937, 0.037709039243054576, 0.03881701748468913, 0.0627555770915933, 0.046177111216820776, 0.022362339987012092, 0.03152994737320114, 0.04795335633389186, 0.03558258576958906, 0.04806235927389935, 7.426644014194608, 29.19789545238018, 39.20296758413315, 26.72196350991726, 20.10790541768074, 37.24412329494953, 50.34636743366718, 37.39708788692951, 8.230754490941763, 0.48793722060509026, 0.3308302868390456, 0.3773007245035842, 2.3387939762324095, 3.3216271502897143, 4.001439884305, 2.8118949523195624, 0.9071578003931791, 1.055823101196438, 1.7679527448490262, 3.1782325822860003, 15.187938921153545, 29.30985264480114, 48.08981291949749, 61.18745930492878, 61.36381924152374, 58.47776770591736, 59.55299600958824, 59.58410494029522, 59.51147183775902, 60.66480495035648, 61.535615622997284, 61.57179348170757, 60.09865052998066, 61.43745169043541, 59.17103670537472, 59.98054526746273, 61.39118157327175, 59.68255005776882, 56.59727901220322, 57.89568834006786, 58.93429420888424, 58.9490108191967, 53.08670058846474, 47.93592117726803, 44.970438703894615, 48.755791783332825, 56.562548875808716, 61.70923590660095, 58.03033411502838, 57.14666113257408, 56.23428829014301, 38.78639213740826, 55.96352241933346, 55.84576293826103, 57.062070071697235, 56.78802117705345, 56.90790094435215, 58.56275014579296, 60.09893171489239, 59.366635009646416, 58.05583834648132, 51.184226274490356, 45.22252857685089, 45.05922473967075, 47.0614019036293, 50.62297739088535, 52.65927292406559, 52.52778097987175, 52.47983135282993, 54.625671207904816, 55.58010019361973, 57.03112073242664, 56.39373153448105, 55.67252643406391, 54.71321851015091, 56.367444545030594, 54.27680432796478, 53.82621690630913, 53.0041766166687, 54.71600756049156, 52.52626486122608, 57.29046821594238, 52.489532232284546, 39.416470527648926, 16.19424842298031, 4.432571874931455, 1.136978908907622, 1.517627639696002, 3.9635630417615175, 3.452813448384404, 4.638579245656729, 3.8134162360802293, 6.209784485399723, 2.682910398580134, 0.6604867335408926, 0.26566123066004366, 0.09271285787690431, 0.5215715314261615, 10.321722440421581, 36.40477493405342, 42.337924763560295, 24.409367702901363, 23.36846485733986, 30.75158078223467, 18.97845972329378, 3.2266165735200047, 0.07006475207163021, 0.06243508803891018, 0.014698286686325446, 0.029227181876194663, 0.05683664508978836, 0.040863571339286864, 0.0324134407856036, 0.03454200937994756, 0.016593045365880243, 0.041221913634217344, 0.057041433319682255, 0.038487518759211525, 0.04456409777048975, 0.005272939761198359, 0.09968359867343679, 0.0234500780061353, 0.05974683619569987, 0.0943123790784739, 0.010766737104859203, 0.05282636848278344, 0.0465294680907391, 0.07120644237147644, 0.03893313762091566, 0.0391839278745465, 0.02438665909721749, 0.027672859323502053, 0.05968982070044149, 0.04009387514088303, 0.02232978011306841, 0.048471397676621564, 0.07369334212853573, 0.14883897820254788, 0.21828776254551485, 0.13149446749594063, 0.08182985591702163, 0.1122078305343166, 0.09318473763414659, 0.1702105306321755, 0.14356474246596918, 0.13390239531872794, 0.1363337304792367, 0.2065649165888317, 0.15570728777674958, 0.13143815333023667, 0.19684852624777704, 0.1299360761186108, 0.11576763092307374, 0.14511410932755098, 0.14661229768535122, 0.18053561565466225, 0.1562846638262272, 0.14817027345998213, 0.14794425980653614, 0.0863181498425547, 0.25285974727012217, 0.16621167567791417, 0.11002246537827887, 0.11869529218529351, 0.14015426218975335, 0.07715691564953886, 0.16127685375977308, 0.17541185778100044, 0.1473606051877141, 0.12819703115383163, 0.14541712822392583, 0.15799887652974576, 0.07625208178069443, 0.20734846126288176, 0.18221972684841603, 0.13009258022066206, 6.185170831158757, 31.514150463044643, 49.77172426879406, 38.54440212249756, 30.83999253809452, 37.233715653419495, 45.97018785774708, 42.41723790764809, 11.508071981370449, 1.8681353190913796, 0.41371057857759297, 2.429851577617228, 4.896419635042548, 8.462386261671782, 7.0993319526314735, 2.0149449538439512, 1.7036508140154183, 1.9651266583241522, 1.0426407773047686, 3.2229915680363774, 13.772016149014235, 26.996681168675423, 50.0310717523098, 60.39879262447357, 63.99653077125549, 62.37654849886894, 63.405727073550224, 60.928089022636414, 60.93921482563019, 63.22067320346832, 64.06406074762344, 62.0611160248518, 61.10833615064621, 63.184924721717834, 61.74918316304684, 61.50075629353523, 63.552080020308495, 60.662088096141815, 58.679521679878235, 59.904169365763664, 61.61055140197277, 61.64901293814182, 56.671196445822716, 50.85015960037708, 47.55122981965542, 49.94648829102516, 57.56920985877514, 64.98408257961273, 61.77653029561043, 57.680391892790794, 58.70004057884216, 41.98835872113705, 56.844774931669235, 55.87740384042263, 59.08918909728527, 57.724435329437256, 59.79101903736591, 59.09850999712944, 61.843387708067894, 61.12528704106808, 61.517600789666176, 55.15913598239422, 48.59408386051655, 47.11213298141956, 48.72017249464989, 53.31235907971859, 55.501699000597, 55.78941196203232, 55.65598212182522, 57.05078847706318, 57.34900787472725, 59.41581577062607, 58.17323684692383, 56.52054212987423, 56.20344914495945, 57.936429753899574, 54.95878033339977, 55.14956049621105, 54.45816859602928, 56.68472371995449, 54.929445907473564, 59.005069211125374, 51.06284938752651, 37.14605435729027, 14.929175656288862, 3.3983659325167537, 0.6123690248932689, 1.2263922672718763, 4.872603463009, 4.788649342954159, 11.383686605840921, 7.042999975383282, 11.153991781175137, 6.795374387875199, 5.98056891001761, 1.8407015036791563, 0.26905839680694044, 1.2853696150705218, 17.455013170838356, 42.279210314154625, 41.7881740629673, 27.537289559841156, 33.25671225786209, 39.92505803704262, 19.672116301953793, 2.437492967583239, 0.14032016188139096, 0.12332060883636586, 0.12394432458677329, 0.1826287541189231, 0.10501963304704987, 0.09131327125942335, 0.1732750068185851, 0.08975839766208082, 0.14416607504244894, 0.11128566751722246, 0.17199702851939946, 0.16468518180772662, 0.12545096600661054, 0.12462502985727042, 0.22610630316194147, 0.20140756911132485, 0.1827169509488158, 0.21581354609224945, 0.171256112807896, 0.1123415507026948, 0.1282709787483327, 0.24294796428875998, 0.1467707016854547, 0.1453571775346063, 0.23799294111086056, 0.22258852317463607, 0.20676504413131624, 0.15392401081044227, 0.14940918510546908, 0.12998842721572146, 0.1216506355558522], [0.04313168967200909, 0.0170572717252071, 0.05622076270810794, 0.04366145694802981, 0.013607673772639828, 0.05157025014341343, 0.014976678339735372, 0.04016150705865584, 0.042923572909785435, 0.055544295100844465, 0.026179385458817706, 0.007548602488895995, 0.04657558514736593, 0.028231651995156426, 0.02427833893307252, 0.025260955444537103, 0.024569258966948837, 0.05583876816672273, 0.011029313591279788, 0.011077537419623695, 0.04269588942406699, 0.0022387438957593986, 0.03035134079254931, 0.028697841335088015, 0.02382862898230087, 0.04548565222648904, 0.03704542192281224, 0.053225732990540564, 0.04853066559007857, 0.02675741088751238, 0.049177135588251986, 0.02461031086568255, 0.04690356247010641, 0.04548217897536233, 0.017563366345711984, 0.04563212249195203, 0.03190231254848186, 0.013849209444742883, 0.0739289665943943, 0.016299535236612428, 1.456112265586853, 17.87393119186163, 37.902855947613716, 33.195060566067696, 18.43258861452341, 21.566628143191338, 37.18209162354469, 32.55806654691696, 13.322866950184107, 1.8967340094968677, 0.17159476963570341, 0.9956941776908934, 1.9282841915264726, 1.9879076234064996, 3.299541072919965, 0.8107303746510297, 1.0778029030188918, 0.9791854291688651, 0.18248780543217435, 1.9031213480047882, 10.07112493738532, 19.064874686300755, 37.800861820578575, 55.385835617780685, 60.09924329817295, 61.211200430989265, 58.45503732562065, 59.357260912656784, 60.2538987994194, 56.67602598667145, 57.043565064668655, 56.53730683028698, 56.033013090491295, 57.018490210175514, 58.02858620882034, 56.609145775437355, 58.75678673386574, 58.911670222878456, 61.133680790662766, 59.87689062952995, 59.18932892382145, 55.96893712878227, 45.17613686621189, 45.871913731098175, 45.38762591779232, 46.83739632368088, 55.87102398276329, 55.8382773399353, 60.68894125521183, 55.74381820857525, 38.002824783325195, 55.34116521477699, 58.10500010848045, 57.90785528719425, 57.82793417572975, 58.86043757200241, 60.051225274801254, 57.02341854572296, 55.056427493691444, 53.19095939397812, 49.87930029630661, 44.313811138272285, 44.021808207035065, 48.19335736334324, 49.69128638505936, 52.57748991250992, 52.678537890315056, 54.61490258574486, 55.53766407072544, 56.46691180765629, 56.083880960941315, 56.156795248389244, 56.778616681694984, 55.9380903840065, 55.89118950068951, 55.29210224747658, 54.7900465875864, 51.244627833366394, 56.975940093398094, 52.335762083530426, 47.90181800723076, 30.860840119421482, 10.488694980740547, 0.891452293144539, 0.5028982646763325, 0.9890615742187947, 1.0276720742695034, 3.3819928485900164, 1.4588878978975117, 3.07779542170465, 3.2649197056889534, 7.212277092039585, 1.3966448628343642, 0.4379486170364544, 0.11444846342783421, 1.2898232135921717, 16.07273854315281, 33.48140940070152, 28.994676657021046, 23.43643371015787, 20.99063605070114, 27.338643819093704, 10.035718437284231, 0.7251166936475784, 0.06899942876771092, 0.04284709088096861, 0.08063488683546893, 0.03815833173575811, 0.06975226337090135, 0.08856750297127292, 0.057154755559167825, 0.10948728784569539, 0.10155528027098626, 0.06561702393810265, 0.05055398651165888, 0.10249533646856435, 0.027140435158798937, 0.056754723118501715, 0.028322984398982953, 0.03334960441861767, 0.0268905076518422, 0.04428075691976119, 0.06709600551403128, 0.04093275805644225, 0.04803006842848845, 0.014710421728523215, 0.04297344152291771, 0.14429198781726882, 0.07893127200077288, 0.054411992969107814, 0.012470102392398985, 0.04714179929578677, 0.018853697692975402, 0.024902067671064287, 0.022210659844859038, 0.025914384932548273, 0.07729007920715958, 0.02671450547495624, 0.040813309387885965, 0.027799599592981394, 0.05033475608797744, 0.08550943151931278, 0.028261269253562205, 0.042989063731511123, 0.07662190138944425, 0.04194155197183136, 0.03057618741877377, 0.019939756602980196, 0.01686329658696195, 0.007610236925756908, 0.007665438797630486, 0.03172133241605479, 0.001324788336205529, 0.011872567756654462, 0.0023857944279370713, 0.05820391859742813, 0.02778781985398382, 0.011857329609483713, 0.010579206591501134, 0.01642843144509243, 0.03602299104386475, 0.03524465253576636, 0.05093723528261762, 0.019415757669776212, 0.04781306073709857, 0.05368263620766811, 0.033423856293666176, 0.05367639474570751, 0.02204119969974272, 0.0497677886596648, 0.07321314289583825, 0.009936794285749784, 0.07425772317219526, 0.0888868268521037, 0.01783162118954351, 0.1981450433959253, 3.550208159722388, 25.34910287708044, 42.157373651862144, 31.145118065178394, 19.079065024852753, 26.257432736456394, 48.50547641515732, 44.27509881556034, 13.619749769568443, 0.9492913645226508, 0.03307818988105282, 0.24923474178649485, 0.8472722419537604, 4.185578003525734, 2.832787181250751, 1.8984997272491455, 2.2828445909544826, 2.834163182415068, 1.2235859991051257, 2.7457376522943377, 10.92261839658022, 25.616747215390205, 44.01327006518841, 57.34664440155029, 62.551278322935104, 61.72232620418072, 58.878148421645164, 59.52931568026543, 60.99223718047142, 56.903489381074905, 57.6475540548563, 57.902653366327286, 58.10705579817295, 59.254788011312485, 59.94572773575783, 60.102085545659065, 62.00507663190365, 59.530995190143585, 61.849330589175224, 59.46748539805412, 60.86766466498375, 55.81527337431908, 46.944987550377846, 47.380090802907944, 49.26544323563576, 50.82377381622791, 58.926265239715576, 59.594466984272, 62.09134340286255, 57.02150344848633, 40.67526698112488, 55.978714004158974, 58.36041860282421, 58.33120957016945, 57.76446618139744, 60.81704378128052, 61.75134904682636, 59.98649574816227, 57.44601666927338, 54.68009948730469, 52.350072115659714, 46.1446250975132, 45.450778529047966, 49.20149266719818, 51.75715573132038, 54.39163416624069, 54.7228167951107, 56.092464700341225, 57.925368547439575, 57.439917996525764, 54.90121342241764, 56.32289193570614, 56.59198209643364, 56.25793442130089, 57.13029161095619, 56.063677445054054, 54.81776989996433, 53.010773062705994, 55.58210268616676, 54.04127396643162, 49.02126453816891, 35.31138360500336, 13.25086746364832, 2.944549871608615, 1.3538994127884507, 2.4823317490518093, 4.596079476177692, 3.5660670837387443, 3.5834383266046643, 4.410201050341129, 5.173966242000461, 3.3320431038737297, 0.6450507743284106, 0.21022625762270764, 0.1353526854654774, 1.0672874422743917, 14.615363795310259, 42.035734578967094, 41.50620259344578, 24.863848015666008, 21.87896568328142, 31.15377400070429, 15.979048870503902, 1.7679956112988293, 0.058979778332286514, 0.1188467199972365, 0.03470523362921085, 0.029079893392918166, 0.04834183353523258, 0.023853663478803355, 0.02436480841424782, 0.08134724470437504, 0.06376894263667054, 0.04001891451480333, 0.019433871639193967, 0.12899981229566038, 0.006925834832145483, 0.08184848382370546, 0.025426645479456056, 0.028480362379923463, 0.04831114572880324, 0.06635261845076457, 0.0862872987636365, 0.05058415852545295, 0.06332306773401797, 0.02730286531004822, 0.02685753774130717, 0.024084282158582937, 0.04079628080944531, 0.051789543649647385, 0.0763966076192446, 0.005724411848859745, 0.07253045609104447, 0.05187057133298367, 0.0397304083162453, 0.028804027824662626, 0.16477673314511776, 0.07194882753537968, 0.08961240979260765, 0.12899163382826373, 0.14883802825352177, 0.21202642587013543, 0.07098939386196434, 0.1830859764595516, 0.18147431372199208, 0.11635248782113194, 0.12091542695998214, 0.11969245664658956, 0.15345804597018287, 0.1392617405508645, 0.12299210458877496, 0.1493697622208856, 0.055430995125789195, 0.1189189829165116, 0.08359031926374882, 0.19201551214791834, 0.1403981022303924, 0.13019659963902086, 0.1611398532986641, 0.07223491062177345, 0.10079213723656721, 0.11760035718907602, 0.17858483595773578, 0.15392467874335125, 0.09268267473089509, 0.12549338716780767, 0.19065485859755427, 0.19945214356994256, 0.1126604070304893, 0.19290286843897775, 0.14894338353769854, 0.12285218006582, 0.18358995410380885, 0.17726084450259805, 0.15277890663128346, 0.30098089948296547, 3.248898102901876, 29.0298380702734, 53.87668959796429, 44.02596898376942, 27.813616432249546, 28.51578075438738, 45.64193867146969, 42.893287762999535, 16.39495935291052, 2.4108789581805468, 0.3785018459893763, 2.65404406003654, 6.855264874175191, 5.399825172498822, 7.902759416028857, 2.6125279627740383, 3.4168471908196807, 3.4781780373305082, 0.9055710292886943, 2.6259144069626927, 11.096457168459892, 22.038329131901264, 42.059935480356216, 57.25072614848614, 65.19858106970787, 64.22855392098427, 61.48379020392895, 62.47019827365875, 64.64492797851562, 59.2348238825798, 61.70360080897808, 60.16031742095947, 59.08440135419369, 61.35746978223324, 62.27440997958183, 62.71577909588814, 62.78972692787647, 62.26723216474056, 63.97952288389206, 62.73434489965439, 63.167483657598495, 58.94461825489998, 49.20348756015301, 49.89612579345703, 52.318697199225426, 52.56540656089783, 60.51488019526005, 62.045985236763954, 65.43617472052574, 59.8714417219162, 45.20140931010246, 54.2439778894186, 58.67498092353344, 58.01605828106403, 61.27467602491379, 63.068567365407944, 64.11557078361511, 62.30534791946411, 57.69773416221142, 55.93566231429577, 53.19326587021351, 48.0384586751461, 48.33555333316326, 53.08744914829731, 53.99960160255432, 57.06903509795666, 56.920520067214966, 58.50109465420246, 61.412958204746246, 59.67400811612606, 57.904659658670425, 56.884896978735924, 56.400932148098946, 58.400065675377846, 58.5434889793396, 58.25383812189102, 57.58412405848503, 54.748347625136375, 60.2048472315073, 55.79078748822212, 49.03342008590698, 34.039227068424225, 12.21376346424222, 2.0987905422225595, 1.5307536791078746, 2.9710327880457044, 3.2619266537949443, 7.951298011466861, 5.355932302772999, 7.182773575186729, 9.524150937795639, 16.176288686692715, 6.863224972039461, 1.6856362181715667, 0.3161351691232994, 1.658117501065135, 21.529787220060825, 42.32905983924866, 37.75815971195698, 32.39237643778324, 31.609979420900345, 40.011381804943085, 15.431166719645262, 1.405479982495308, 0.2557927742600441, 0.22412828664528206, 0.1847103299223818, 0.12201451056171209, 0.1820474150008522, 0.12144760621595196, 0.08774806061410345, 0.23449647560482845, 0.12798191222827882, 0.2094388092518784, 0.2428998879622668, 0.31549629871733487, 0.15044664818560705, 0.29043227958027273, 0.23406732128933072, 0.10063055684440769, 0.14069579250644892, 0.19943906692788005, 0.30770817131269723, 0.1353215894778259, 0.11160836816998199, 0.12388426257530227, 0.12844853015849367, 0.18036842462606728, 0.23303508292883635, 0.12910264427773654, 0.12037866123137064, 0.19809143064776435, 0.10797575567266904, 0.1527529611485079, 0.18543962360126898, 0.1190499794029165], [0.03969049190345686, 0.04644208020181395, 0.07780708896461874, 0.042994091782020405, 0.012826780421164585, 0.06387317727785558, 0.02359250356676057, 0.06662045954726636, 0.02278659612784395, 0.06682556690066122, 0.0740141280402895, 0.00793546969362069, 0.06268336612265557, 0.05747528171923477, 0.0434522455179831, 0.05010091277654283, 0.044677883852273226, 0.016188879162655212, 0.015726617639302276, 0.06726714476826601, 0.041209326809621416, 0.01685601797362324, 0.018925079311884474, 0.016539033713343088, 0.03282816775026731, 0.04953216790454462, 0.007794130451657111, 0.06500058865640312, 0.09129614249104634, 0.0219821562859579, 0.07516413781559095, 0.10667579495930113, 0.05476455393363722, 0.06749087260686792, 0.06661757259280421, 0.015106995761016151, 0.022872349436511286, 0.0029796976423313026, 0.01775455843016971, 0.04254958614183124, 0.05687356322596315, 1.1003934033215046, 15.49217814579606, 37.21092447638512, 28.05038172751665, 20.512686297297478, 21.52915645390749, 29.952685050666332, 29.75693665444851, 18.970119170844555, 3.281306801363826, 0.19954641116783023, 0.22881941695231944, 4.707150366157293, 3.448303802870214, 1.0080633452162147, 0.987335576210171, 3.462972678244114, 0.9793171752244234, 0.40368683519773185, 0.1823161615175195, 1.989094940945506, 10.689534153789282, 29.402202889323235, 48.96617889404297, 58.34861643612385, 60.08256979286671, 60.26722468435764, 60.96489004790783, 61.27724468708038, 59.889171570539474, 59.70398850739002, 59.681634306907654, 57.63200528919697, 57.837369069457054, 56.87643863260746, 61.80740363895893, 57.75908187031746, 59.34889756143093, 59.941369369626045, 59.43546451628208, 55.296635404229164, 50.553699508309364, 47.63648584485054, 49.333459585905075, 49.18060518801212, 55.525884702801704, 58.843384087085724, 62.17461213469505, 62.33990706503391, 40.56668780744076, 56.759735494852066, 58.07478792965412, 59.416978508234024, 60.15505090355873, 58.214479833841324, 55.12875661253929, 53.86243276298046, 53.07699590921402, 53.43163847923279, 53.02433833479881, 49.65320102870464, 50.60043700039387, 52.002546563744545, 54.75782431662083, 54.40478906035423, 55.292664617300034, 55.88714651763439, 58.38503748178482, 56.97762340307236, 60.073632672429085, 56.69196993112564, 56.11555226147175, 57.54707224667072, 55.35445310175419, 56.18502393364906, 56.90861150622368, 56.05288602411747, 51.785893589258194, 41.155363619327545, 26.061621643602848, 7.954951515421271, 0.6060148752294481, 0.4733428271720186, 0.6895016797352582, 1.9221028732135892, 5.582798654213548, 2.085949368774891, 3.986779795959592, 2.993449210189283, 3.1922611920163035, 0.8708006388042122, 0.8734224981162697, 0.11682824158924632, 1.5668080444447696, 16.091418340802193, 37.185918018221855, 29.014116413891315, 20.333411917090416, 19.897930584847927, 23.33978209644556, 11.520951390266418, 0.3410577052272856, 0.08603575523011386, 0.05148705167812295, 0.0172622139507439, 0.018417108913126867, 0.04316658174502663, 0.03194536824594252, 0.022341524600051343, 0.0698927890334744, 0.028023505547025707, 0.03628047546953894, 0.027442003156465944, 0.039169956944533624, 0.018682209629332647, 0.04453904657566454, 0.062190234966692515, 0.008971223051048582, 0.06803654410759918, 0.027959769904555287, 0.06258635257836431, 0.03459937739535235, 0.02813634910125984, 0.037442790053319186, 0.012531873198895482, 0.03376869521162007, 0.08657688478706405, 0.03475926198007073, 0.036639956961153075, 0.04028280367492698, 0.013229849173512775, 0.048557650079601444, 0.008989945581561187, 0.06775357061997056, 0.015658872544008773, 0.018090532394126058, 0.04431254310475197, 0.04793270978552755, 0.04537394786893856, 0.05061975934950169, 0.007239807364385342, 0.03353089625306893, 0.0467799132457003, 0.03469388248049654, 0.08214328714529984, 0.07649890525499359, 0.01649759775318671, 0.019450877953204326, 0.039284967569983564, 0.052404286834644154, 0.011854925978695974, 0.004485545196075691, 0.018176968478655908, 0.007184819787653396, 0.03460619402176235, 0.01312741052970523, 0.014254840461944696, 0.04498233880440239, 0.04245423500833567, 0.007514975313824834, 0.06324901623884216, 0.041134388447972015, 0.009246224017260829, 0.03089685458689928, 0.07421198461088352, 0.02730092830461217, 0.04552035505184904, 0.016500725905643776, 0.025516799723845907, 0.04224361720844172, 0.054107679025037214, 0.05570501089096069, 0.015043181265355088, 0.05635488734696992, 0.05087548117444385, 0.08744135324377567, 3.1655692867934704, 26.675070226192474, 42.18593671917915, 26.245026402175426, 17.825749777257442, 21.56779658049345, 38.669715598225594, 37.594095915555954, 16.75987847149372, 2.7384978532791138, 0.3053423826349899, 0.4582506010774523, 0.41259982099290937, 2.7074307203292847, 1.4256350509822369, 3.700408162549138, 3.97919112816453, 1.2812889902852476, 2.0060733798891306, 1.110911713913083, 2.890989133156836, 14.402689207345247, 35.19026890397072, 53.630983382463455, 62.39653542637825, 62.51725874841213, 61.76276743412018, 62.38113485276699, 62.49212309718132, 61.74417123198509, 59.72828060388565, 59.516844749450684, 58.58772620558739, 60.018125250935555, 57.71143242716789, 63.636880069971085, 59.24782678484917, 59.83626700937748, 60.50799496471882, 62.09649212658405, 56.65038876235485, 50.75022116303444, 49.2888917773962, 50.25525592267513, 51.14544175565243, 58.449843004345894, 59.62438277900219, 63.449006751179695, 62.116387858986855, 42.66410306096077, 57.22478114068508, 57.919315472245216, 59.19076904654503, 61.79857671260834, 59.37547713518143, 57.12656021118164, 55.398937314748764, 57.00631186366081, 54.87618796527386, 54.580050855875015, 52.40458399057388, 49.54630136489868, 53.2029477506876, 56.15640386939049, 56.06238931417465, 57.0639243721962, 56.33795812726021, 58.81619654595852, 56.712819412350655, 58.97742949426174, 56.33077271282673, 57.186084017157555, 57.60735601186752, 56.792345345020294, 56.79238334298134, 59.653732404112816, 57.74341531097889, 53.070673048496246, 44.41018536686897, 30.94479091465473, 11.063520535826683, 2.175861094146967, 0.7604099123273045, 2.588631045073271, 2.5688094086945057, 9.437387343496084, 8.224628269672394, 4.055998306721449, 6.416872898116708, 3.5053482418879867, 0.7502361363731325, 0.5958197254221886, 0.09663343109423295, 1.233842361252755, 13.302686233073473, 40.30860185623169, 32.56028562784195, 19.952396862208843, 22.50342797487974, 28.630549795925617, 16.340700164437294, 0.9364070871379226, 0.030912226320651826, 0.06375361728714779, 0.015546308222837979, 0.04774237117089797, 0.048751027788966894, 0.028330997738521546, 0.033808418666012585, 0.045428992962115444, 0.07851106056477875, 0.039934576852829196, 0.037576710601570085, 0.020938303314324003, 0.0244119533454068, 0.045557718476629816, 0.06790341023588553, 0.04016903243609704, 0.024559444063925184, 0.02201271607191302, 0.018737774225883186, 0.027131479291711003, 0.01742932519846363, 0.02941603619547095, 0.012479795768740587, 0.04487748446990736, 0.039105842806748115, 0.027581688336795196, 0.023485656565753743, 0.04862501853494905, 0.0665794410451781, 0.008185576243704418, 0.026064742196467705, 0.021329903102014214, 0.05376684399379883, 0.08495109897921793, 0.1804164267377928, 0.20555381459416822, 0.10482459663762711, 0.11014408111805096, 0.12414204757078551, 0.10163628568989225, 0.15441952797118574, 0.0700574716029223, 0.19281579967355356, 0.24294686591019854, 0.1153552788309753, 0.23470305983209983, 0.20569918648106977, 0.1351009341306053, 0.17314021795755252, 0.1248401339398697, 0.10649555697455071, 0.07741689740214497, 0.17291623778874055, 0.10242175994790159, 0.15464848052943125, 0.2050596778281033, 0.10379026542068459, 0.15874050470301881, 0.1274001129786484, 0.11913537833606824, 0.1539726066403091, 0.20945918862707913, 0.14769526926102117, 0.18573017441667616, 0.19245943520218134, 0.1680182560812682, 0.1860101125203073, 0.1495852819061838, 0.1415999510209076, 0.1711491247988306, 0.12804925470845774, 0.1282169800833799, 0.10583419949398376, 0.189383129181806, 3.1354559026658535, 28.494912274181843, 51.516419649124146, 39.12047781050205, 30.641576685011387, 29.18000791221857, 35.80158390104771, 41.225397661328316, 24.11876879632473, 4.408480217680335, 0.49151057261042297, 1.18292081868276, 9.958021156489849, 8.61806770786643, 2.8070107894018292, 4.525982737541199, 6.6374629363417625, 2.881930419243872, 0.6597454764414579, 0.45046386891044676, 3.1780699035152793, 12.950354889035225, 32.78732344508171, 53.82527455687523, 63.75633046030998, 64.05317813158035, 65.98384693264961, 66.94157034158707, 65.94416186213493, 63.33063170313835, 62.82820366322994, 62.77623005211353, 62.00493983924389, 62.50940077006817, 60.46018213033676, 65.69187059998512, 59.49837774038315, 59.780953377485275, 63.80068928003311, 63.82614031434059, 59.65529792010784, 54.25082892179489, 52.61576145887375, 54.15850147604942, 54.47288900613785, 60.45149199664593, 63.397333323955536, 66.03695288300514, 65.3286024928093, 46.36274479329586, 57.9154396802187, 58.600869700312614, 61.0446135699749, 62.57684715092182, 62.05002062022686, 58.759682178497314, 56.765043810009956, 58.99131774902344, 56.948475167155266, 58.885618820786476, 53.899188190698624, 53.53768318891525, 56.28423660993576, 59.67333175241947, 58.42603728175163, 59.683933183550835, 59.164740443229675, 60.92335447669029, 58.72161202132702, 60.09450875222683, 56.427618116140366, 56.43869072198868, 58.23779158294201, 56.69700086116791, 58.614100590348244, 60.851846113801, 57.943599969148636, 54.03802514076233, 44.26526874303818, 29.82695359736681, 8.935461826622486, 1.7259616730734706, 1.940436651930213, 2.1904950588941574, 3.820851962082088, 11.403162460774183, 6.193827241659164, 10.242949817329645, 10.075942128896713, 9.579013343900442, 5.230557080358267, 3.2695203088223934, 0.30323747370857745, 2.5209925370290875, 21.44919164478779, 47.92717404663563, 37.6733672618866, 29.11524038761854, 30.524799451231956, 36.148079708218575, 17.761616818606853, 0.6557197705842555, 0.19085985462879762, 0.1530231029028073, 0.10243575685308315, 0.16306458361214027, 0.14704234257806093, 0.18597765098093078, 0.09807869690121152, 0.19428826519288123, 0.15826492162887007, 0.10436997181386687, 0.07628166378708556, 0.11812208700575866, 0.08875519954017363, 0.07620055446750484, 0.14453008363489062, 0.08014279839699157, 0.15173998894169927, 0.10726164633524604, 0.13393889414146543, 0.2258847572375089, 0.09383422817336395, 0.1537715588347055, 0.07167956151533872, 0.1097236767236609, 0.2508182474412024, 0.17079558048862964, 0.10278966481564566, 0.10843326745089144, 0.13084971928037703, 0.10987566114636138, 0.12235818430781364, 0.14149747526971623, 0.10090713301906362], [0.00440150392932992, 0.11229227951844223, 0.020290744214435108, 0.01611331925232662, 0.05210407325648703, 0.014413151693588588, 0.04366569461126346, 0.03180368112225551, 0.02947502023744164, 0.02780677801638376, 0.064790627657203, 0.026050578308058903, 0.061747959480271675, 0.01867912600573618, 0.04948049958329648, 0.02203269839810673, 0.06506566758616827, 0.05837581855303142, 0.06412634611479007, 0.08777809533057734, 0.0806596597249154, 0.04102161910850555, 0.03607672995713074, 0.05564252947806381, 0.04725581544335, 0.012977217465959257, 0.023239942602231167, 0.031136097022681497, 0.019104575148958247, 0.01966289655683795, 0.028782702211174183, 0.016498421537107788, 0.036409798412933014, 0.08099565966404043, 0.06599002736038528, 0.03409017503145151, 0.03715521525009535, 0.03894939807651099, 0.006761406912119128, 0.03589730091334786, 0.13364623562665656, 0.12570276187034324, 0.5230023327749223, 14.152571428567171, 37.387588396668434, 32.31719747185707, 23.66825547069311, 23.092580661177635, 46.388758197426796, 37.03496351838112, 23.583432622253895, 6.237663589417934, 0.4699789092410356, 0.23292800586204976, 0.9543465776368976, 1.2043998786248267, 3.9246868528425694, 2.711033639498055, 2.5272959237918258, 4.278272604569793, 0.5142169666942209, 0.10758672186057083, 0.23978169512702152, 5.017855418846011, 19.282042533159256, 42.55118831992149, 56.53622008860111, 60.26011526584625, 64.42104399204254, 62.86844730377197, 63.97371679544449, 61.435168012976646, 62.00461305677891, 58.98853249847889, 60.50553649663925, 58.053892850875854, 61.294225975871086, 62.18293368816376, 62.233679965138435, 61.293967589735985, 62.552916035056114, 56.922362968325615, 55.17059996724129, 54.20066021382809, 54.234307408332825, 53.893872275948524, 58.122767955064774, 57.735367342829704, 64.77011606097221, 58.75980757176876, 30.11514913290739, 55.673730969429016, 59.70152243971825, 59.19759348034859, 59.74970005452633, 56.73776127398014, 56.122958064079285, 54.09032553434372, 54.031033515930176, 55.30724063515663, 54.081145226955414, 55.090325474739075, 55.42964726686478, 52.55304582417011, 56.00361026823521, 56.32687412202358, 57.58017227053642, 58.49934294819832, 59.15228471159935, 59.366281628608704, 58.76742236316204, 56.62874132394791, 57.46652036905289, 58.14003422856331, 56.51684872806072, 53.34276504814625, 49.05460774898529, 42.20070652663708, 32.853759080171585, 18.798818662762642, 6.053420025855303, 0.6533005472738296, 0.5303514946717769, 0.31605347350705415, 2.039603730663657, 1.483068612869829, 9.885357655584812, 9.41822687163949, 2.259788140654564, 5.3287590108811855, 3.388851243071258, 0.9493240783922374, 0.04617696649802383, 2.498844712972641, 19.041004367172718, 39.87806975841522, 45.95480628311634, 47.024418488144875, 39.8873982578516, 26.14143256098032, 13.880310337990522, 0.7643875863868743, 0.08768587606027722, 0.06126423133537173, 0.06330343792797066, 0.00937493654419086, 0.07701127658947371, 0.022766270558349788, 0.028885793944937177, 0.055516798529424705, 0.02452734246617183, 0.02238315537397284, 0.049251187083427794, 0.023372655305138323, 0.08509416278684512, 0.04218022295390256, 0.05809414753457531, 0.04144117745454423, 0.015474829197046347, 0.05245985143119469, 0.01017328149828245, 0.044992272451054305, 0.03903978424204979, 0.012223970970808296, 0.020286424914957024, 0.06125074280134868, 0.058909868021146394, 0.0641067311516963, 0.02839356820913963, 0.07507964430260472, 0.026909495500149205, 0.022720557972206734, 0.061251507213455625, 0.008747421925363597, 0.025092998148465995, 0.04538975190371275, 0.06910640935529955, 0.12005396420136094, 0.02285124090121826, 0.012105739424441708, 0.07243833329994231, 0.024676567954884376, 0.0469000669545494, 0.05737526989832986, 0.020335035587777384, 0.014951726407161914, 0.028727000317303464, 0.05984253242786508, 0.04879040614468977, 0.04685920801421162, 0.02808372340950882, 0.016720763414923567, 0.03297892020782456, 0.04699856479419395, 0.07084768818458542, 0.10769840024295263, 0.10553554442594759, 0.039135380284278654, 0.03939905422157608, 0.06695308271446265, 0.07218431099317968, 0.0960388001112733, 0.03386012038390618, 0.01401842839186429, 0.021015178681409452, 0.02658611578226555, 0.059508684717002325, 0.025948677721316926, 0.08952025731559843, 0.04685815416451078, 0.04659849524614401, 0.06726476247422397, 0.07092815183568746, 0.03600837444537319, 0.04701847290562, 0.09734328050399199, 0.02792714880342828, 0.1157333808077965, 1.8613289343193173, 23.54980442672968, 42.38536521792412, 30.249876603484154, 19.14767414331436, 17.335433587431908, 52.14729979634285, 48.368235379457474, 22.612599916756153, 3.7849780870601535, 0.2149560983525589, 0.24113470455631614, 0.6833251705393195, 1.326281544752419, 1.8507220409810543, 4.6608042530715466, 3.196839946322143, 3.438555425964296, 1.5169676626101136, 0.35405164235271513, 1.4814342255704105, 7.326711276546121, 25.482753105461597, 45.632948353886604, 58.878809586167336, 62.365000918507576, 66.57778546214104, 63.59597146511078, 63.69041919708252, 62.56893217563629, 63.43166068196297, 60.911016538739204, 63.88635188341141, 61.010514199733734, 64.37656357884407, 63.622714430093765, 62.392534241080284, 63.43012556433678, 65.14868974685669, 59.24044378101826, 56.56242348253727, 54.28289920091629, 55.586939826607704, 56.52129448950291, 60.099076107144356, 61.03470370173454, 65.24515137076378, 59.38769727945328, 35.91913819313049, 56.52138188481331, 59.55967225134373, 60.58064326643944, 60.62555305659771, 59.276336655020714, 58.193968534469604, 57.55810305476189, 57.032777443528175, 58.1199637055397, 56.336145624518394, 55.462781488895416, 56.2133514136076, 53.54517638683319, 55.61852753162384, 58.61072637140751, 59.67563822865486, 59.94153656065464, 59.541277438402176, 57.853757590055466, 57.5480791926384, 56.268771439790726, 56.05326980352402, 57.042603716254234, 58.620704635977745, 54.63098332285881, 51.21346950531006, 44.946154206991196, 36.45816206932068, 22.315991632640362, 8.7578166089952, 1.5319744823500514, 1.0361770866438746, 1.8475410179235041, 3.776160185225308, 6.965991407632828, 7.356931054964662, 13.628616593778133, 5.418745782226324, 1.3060785038396716, 0.4816875356482342, 0.06826176366303116, 0.1954062216100283, 1.7869241768494248, 19.313124865293503, 45.84480218589306, 51.51808016002178, 42.39959925413132, 36.168720200657845, 28.616448752582073, 19.578666016459465, 1.9286270043812692, 0.10499356882064603, 0.01027496407914441, 0.1341233029961586, 0.06167434956296347, 0.06044753492460586, 0.011646177463262575, 0.046467962602037005, 0.012663550605793716, 0.024250564056274015, 0.04509721213253215, 0.030054669114178978, 0.04794809079612605, 0.041907646955223754, 0.08417363991611637, 0.045966048128320836, 0.02198687448981218, 0.04292717974749394, 0.0795154609659221, 0.021819577705173288, 0.041336820358992554, 0.03907461323251482, 0.10759193915873766, 0.03557450749212876, 0.05656996545440052, 0.04223435520543717, 0.03526378139213193, 0.04975514988473151, 0.05695129577361513, 0.01910806695377687, 0.037776055178255774, 0.04271541904017795, 0.02127520681824535, 0.04371370414446574, 0.041396359156351537, 0.1378994542756118, 0.3100115602137521, 0.09209809242747724, 0.0967913304339163, 0.24467970652040094, 0.1031998053076677, 0.15341981052188203, 0.12053807455231436, 0.09227243775967509, 0.10514092224184424, 0.1483619850478135, 0.17488172685261816, 0.18347590084886178, 0.1473271194845438, 0.2276276019983925, 0.1104351737012621, 0.09583395250956528, 0.1039237184158992, 0.18496824108297005, 0.16608978534350172, 0.25218424445483834, 0.19020434527192265, 0.10258023816277273, 0.2199747384293005, 0.2007328678155318, 0.10986861074343324, 0.14112908800598234, 0.1333288339083083, 0.15235359664075077, 0.13006176624912769, 0.14383605681359768, 0.11780495988205075, 0.13613109447760507, 0.23669465765124187, 0.14524784433888271, 0.12291094331885688, 0.12870725768152624, 0.10511657979805022, 0.10203522717347369, 0.17351285030599684, 0.23816880042431876, 0.21702781843487173, 1.5025485050864518, 24.122312106192112, 52.267802730202675, 45.76014272868633, 35.105389058589935, 29.37035109847784, 58.84810723364353, 48.30469898879528, 30.552051588892937, 8.161398712545633, 0.7748607150278986, 1.0720174759626389, 2.1979922940954566, 3.596491813659668, 8.176600746810436, 11.208157874643803, 5.403824457898736, 8.709725439548492, 1.9179942249320447, 0.12329968027188443, 1.070679947733879, 6.079956851899624, 22.648006416857243, 43.98223713040352, 59.736130982637405, 63.05447392165661, 68.99488896131516, 65.81163257360458, 68.35128709673882, 63.285186141729355, 65.83414256572723, 62.73990020155907, 66.34597510099411, 62.44435966014862, 65.6073023378849, 66.22131139039993, 66.41257032752037, 66.11559346318245, 68.47486406564713, 60.644491240382195, 59.35313433408737, 58.16113069653511, 59.248666539788246, 58.51416975259781, 62.89954483509064, 63.520746901631355, 68.85680437088013, 59.90164250135422, 38.249043971300125, 55.29964104294777, 60.398401245474815, 61.03980302810669, 62.12109200656414, 60.19307166337967, 60.61728470027447, 59.32637996971607, 58.411658853292465, 60.072226747870445, 59.149237275123596, 59.30700480937958, 58.57189245522022, 56.71160727739334, 60.52533343434334, 60.35490117967129, 60.725886672735214, 62.38058768212795, 60.241587460041046, 59.43741001188755, 59.33563247323036, 57.94842191040516, 57.990865632891655, 57.58428364992142, 57.427998036146164, 55.39018638432026, 50.79582631587982, 45.45754976570606, 34.31806370615959, 21.023908965289593, 7.185034928843379, 1.2217990262433887, 1.1715140682645142, 1.827319571748376, 5.1263481471687555, 7.891073143109679, 16.713937036693096, 18.26544888317585, 7.335740067064762, 10.304984338581562, 7.284382497891784, 1.7389263398945332, 0.2853441151091829, 3.8454884150996804, 25.35147774964571, 48.52023482322693, 56.02377198636532, 54.21871304512024, 49.1613744199276, 39.725887924432755, 21.781770698726177, 1.5976703446358442, 0.21248961507808417, 0.14192472968716174, 0.17432904947781935, 0.16864071018062532, 0.13880521582905203, 0.11777646883274429, 0.13728451071074232, 0.12315350686549209, 0.15715012676082551, 0.15610447037033737, 0.185094183543697, 0.18278012255905196, 0.2167802379699424, 0.16322065726853907, 0.23611217562574893, 0.12125316352467053, 0.14658946922281757, 0.1456696810782887, 0.06247893412364647, 0.19035792531212792, 0.1822071845526807, 0.13840767700457945, 0.13959474221337587, 0.07678164125536568, 0.20644007250666618, 0.13129177212249488, 0.2114733328926377, 0.14852953230729327, 0.1367985672550276, 0.10470482884556986, 0.1533089781878516, 0.11591816073632799, 0.09279313599108718, 0.12758900440530851], [0.021905459034314845, 0.020633132189686876, 0.032407585240434855, 0.10521840988076292, 0.026389092272438575, 0.04369873131508939, 0.03817769807938021, 0.050320603331783786, 0.007797129655955359, 0.0508697369514266, 0.08808567843516357, 0.04057528778503183, 0.015870167553657666, 0.016939498455030844, 0.004797652154593379, 0.040294822756550275, 0.013099343432259047, 0.016642149566905573, 0.11018324425094761, 0.043943525015492924, 0.0212641302641714, 0.03744915025890805, 0.02411879202554701, 0.02089496745611541, 0.06961853578104638, 0.05194916848267894, 0.10005348507547751, 0.08032143334276043, 0.030094518733676523, 0.057472049666102976, 0.05215401979512535, 0.047621586636523716, 0.06420509540475905, 0.03438142346567474, 0.024319414951605722, 0.05296334296872374, 0.027298508903186303, 0.03031612217455404, 0.060502242340589873, 0.013874655833205907, 0.09867901273537427, 0.009407479719811818, 0.008075441528490046, 0.4573676531435922, 17.8084759041667, 36.563993990421295, 33.436081632971764, 26.81411426514387, 15.111115593463182, 23.256384171545506, 36.498504504561424, 27.512224204838276, 11.370096635073423, 1.1369290365837514, 0.542420003330335, 0.3743119473801926, 2.0966498320922256, 2.803917992860079, 0.4309635824756697, 7.196260951459408, 1.340550254099071, 0.4724607104435563, 0.1724714390002191, 0.08679325052071363, 1.4238219545222819, 10.63785882666707, 30.452175848186016, 45.052795484662056, 56.81932769715786, 61.76891170442104, 62.63893201947212, 63.19710686802864, 63.16049203276634, 62.00498163700104, 62.60560780763626, 60.453787073493004, 61.9238255918026, 57.72461012005806, 58.40941697359085, 60.74896663427353, 60.65411992371082, 57.76235729455948, 62.67205484211445, 58.976943120360374, 59.83775652945042, 58.62577736377716, 62.33239866793156, 58.6861789226532, 66.33570805191994, 44.38930928707123, 37.05017790198326, 49.391068294644356, 61.09073169529438, 62.342456728219986, 61.8528264015913, 57.052122205495834, 57.70676627755165, 57.78705596923828, 57.80586875975132, 56.9527917355299, 57.077816426754, 59.81145814061165, 57.569745630025864, 59.37379002571106, 60.51428362727165, 59.425657242536545, 59.22074943780899, 60.21185025572777, 58.999977484345436, 60.78439973294735, 57.95586571097374, 56.687326580286026, 55.33792778849602, 49.56650868058205, 39.921695217490196, 34.86572451889515, 27.87783868610859, 19.396674782037735, 9.47991656139493, 3.1835368601605296, 0.18446828587912023, 0.5849312909413129, 0.9064534131903201, 1.6541217779740691, 3.3948382968083024, 8.385190553963184, 4.850946050137281, 20.911379903554916, 11.040513720363379, 2.7030647546052933, 0.9962918143719435, 0.11200825960258953, 4.925361732020974, 21.79247472435236, 33.48620094358921, 19.722997471690178, 15.858837570995092, 22.362345345318317, 30.345431976020336, 19.458244778215885, 1.7004516231827438, 0.09884641898679547, 0.053593474585795775, 0.030209176838980056, 0.05857792391907424, 0.08936712256399915, 0.01959973422344774, 0.005944455851931707, 0.017373947994201444, 0.022069071055739187, 0.007040171958578867, 0.011568409663595958, 0.022761272193747573, 0.020155716010776814, 0.029292442632140592, 0.0654649653006345, 0.022649233869742602, 0.06798224116209894, 0.021818507157149725, 0.04060640603711363, 0.02146835446183104, 0.07953506850753911, 0.020844148893957026, 0.032938718068180606, 0.010527725662541343, 0.03667995501018595, 0.04267265278031118, 0.035490533482516184, 0.028087220780435018, 0.031821206939639524, 0.06249659723835066, 0.0697663270693738, 0.07295598872588016, 0.0951587465533521, 0.01748761162161827, 0.030572235482395627, 0.010911674835369922, 0.03331847874505911, 0.012326657306402922, 0.061404411899275146, 0.0348515369114466, 0.016982613524305634, 0.0647671015758533, 0.028757734507962596, 0.03173305834934581, 0.0521907264192123, 0.05439202177512925, 0.05560692494327668, 0.023442372657882515, 0.030274411619757302, 0.019392244576010853, 0.06961380830034614, 0.02237589160358766, 0.016546169463254046, 0.020432958262972534, 0.048935915328911506, 0.0543909493717365, 0.023443328173016198, 0.0270398092106916, 0.0133394189288083, 0.0719640935130883, 0.026643995879567228, 0.028568099078256637, 0.06429508081055246, 0.054934795189183205, 0.01194078968183021, 0.023900839951238595, 0.05421914218459278, 0.031509850014117546, 0.05125588380906265, 0.03769739865674637, 0.046311157930176705, 0.05756332269811537, 0.015197496959444834, 0.05872588590136729, 0.07319462631130591, 0.031158795609371737, 0.06835419815615751, 0.03789545931795146, 1.5721819060854614, 26.016348972916603, 42.47394986450672, 36.90527647733688, 25.313707776367664, 23.271619454026222, 35.93001700937748, 52.602363377809525, 34.93914797902107, 8.694275468587875, 0.6432007486000657, 0.19897377002052963, 0.664726534159854, 1.490919585339725, 1.538346502929926, 3.4864333318546414, 3.1824263697490096, 6.159366890788078, 1.9892569072544575, 0.8548765245359391, 0.34659700642805547, 2.9419771721586585, 16.16986133158207, 35.57580381631851, 49.87169690430164, 59.45919044315815, 64.26522195339203, 64.9988029897213, 65.14185771346092, 64.89145115017891, 64.04036521911621, 63.8300921022892, 62.944276034832, 62.3343251645565, 59.56063359975815, 61.69340215623379, 63.25940452516079, 62.94016845524311, 60.35770922899246, 64.88017335534096, 60.07871299982071, 60.65823130309582, 59.8515497893095, 64.18130725622177, 60.93038409948349, 67.73872956633568, 50.02059951424599, 33.4518887847662, 53.476939648389816, 59.39861789345741, 63.63749563694, 62.18207873404026, 59.70301195979118, 59.22805264592171, 58.51220525801182, 60.32951474189758, 59.61514167487621, 58.1405396014452, 62.03440725803375, 59.14579086005688, 61.57227985560894, 62.04648680984974, 61.13676242530346, 59.98033627867699, 59.87755559384823, 57.343817353248596, 60.645091608166695, 57.485006377100945, 58.020819425582886, 55.108496099710464, 50.7766867429018, 43.17058928310871, 39.67907063663006, 32.39347077906132, 24.297349713742733, 13.402940053492785, 5.658362824469805, 1.332728136330843, 1.8515306850895286, 2.665964257903397, 3.097071312367916, 5.855779806151986, 9.460684843361378, 7.851639334112406, 6.821197802200913, 6.578695764765143, 1.3269077986478806, 0.6963366223499179, 0.13459870795486495, 4.001510180532932, 24.892192594707012, 45.54558724164963, 31.578851491212845, 24.029825069010258, 28.96458227187395, 36.77382253110409, 26.15451905876398, 3.3211103780195117, 0.08302032758365385, 0.06123749917605892, 0.022815265292592812, 0.03351934101374354, 0.02055184104392538, 0.05201318614126649, 0.044178663374623284, 0.07188996038166806, 0.06649565257248469, 0.02305484355019871, 0.02625958193675615, 0.01604811601282563, 0.06714539544191211, 0.07538895661127754, 0.08934814584790729, 0.07439587396220304, 0.047813780620344914, 0.0207255054556299, 0.025273776045651175, 0.020896329297102056, 0.050494150855229236, 0.03595198977563996, 0.057198007925762795, 0.012586636275955243, 0.050682949513429776, 0.029480280209099874, 0.043713700433727354, 0.018627708159328904, 0.03144891597912647, 0.07722721187747084, 0.012911505855299765, 0.0681984139373526, 0.017902796862472314, 0.027916215112782083, 0.04029306386655662, 0.06602889363421127, 0.13354735187022015, 0.1638764189556241, 0.22032856475561857, 0.14945613336749375, 0.1283355604391545, 0.12797891395166516, 0.12100822510547005, 0.13595480471849442, 0.1093232657876797, 0.15075576753588393, 0.23181040567578748, 0.10422296720207669, 0.14083690446568653, 0.09693059444543906, 0.15489316661842167, 0.12022240945952944, 0.14668171817902476, 0.15831700555281714, 0.20286888757254928, 0.19027695700060576, 0.13484144961694255, 0.22319046431221068, 0.10756060568382964, 0.0948589485778939, 0.1437970346887596, 0.22160660242661834, 0.2231151660089381, 0.1878682870301418, 0.1807368267327547, 0.14115727477474138, 0.10251685132971033, 0.14861284580547363, 0.16003809054382145, 0.18348283250816166, 0.12782558624166995, 0.1489625161048025, 0.102779898152221, 0.2513104397803545, 0.11003468855051324, 0.12338549480773509, 0.17076381656806916, 0.17415504553355277, 1.1712045036256313, 26.634387709200382, 51.41360856592655, 47.3361499607563, 37.40756772458553, 25.25329291820526, 32.74068474769592, 48.61645705997944, 34.92418818175793, 14.135002121329308, 1.4522335049696267, 1.1205128487199545, 1.5667470102198422, 5.116020301356912, 9.689791649580002, 6.084717996418476, 15.340856965631247, 5.952650858089328, 1.8237122590653598, 0.42817423527594656, 0.1944214807008393, 2.4890262773260474, 14.436185359954834, 33.27308177947998, 47.7921786904335, 59.835833832621574, 64.4749402999878, 64.96374607086182, 66.46213486790657, 67.08027809858322, 67.36036106944084, 65.2568319439888, 63.4533005207777, 63.68603803217411, 60.267954245209694, 63.55675756931305, 66.68384537100792, 64.77364987134933, 62.35158383846283, 69.53901216387749, 64.18036490678787, 64.10879954695702, 64.82252284884453, 65.34374088048935, 64.37716394662857, 68.44535484910011, 50.2035216987133, 41.83484695851803, 55.479219406843185, 61.104532554745674, 65.23886650800705, 64.42292109131813, 62.20171608030796, 62.06452064216137, 60.84469869732857, 62.88478642702103, 61.871506199240685, 59.87920470535755, 64.47355717420578, 61.33678749203682, 64.37980860471725, 64.27438706159592, 64.75650519132614, 61.7358572781086, 61.17328606545925, 58.320349752902985, 60.45870400965214, 57.01190896332264, 57.687174528837204, 56.25891096889973, 52.968979105353355, 42.40013502538204, 38.13472330570221, 30.039538890123367, 21.884610280394554, 10.41204359382391, 4.459295840933919, 0.6184480455704033, 1.3903268706053495, 2.181004830636084, 4.549237489700317, 10.458764936774969, 13.150871079415083, 15.287850759923458, 30.001514330506325, 22.577434703707695, 4.669631654396653, 1.9806180708110332, 0.28426559641957283, 7.0549835823476315, 29.058961607515812, 41.42251968383789, 29.670168310403824, 25.989416018128395, 31.39489956200123, 42.5604522228241, 28.029232062399387, 3.1333945132791996, 0.260027379845269, 0.14615376916481182, 0.16174765740288422, 0.13237895909696817, 0.18130206124624237, 0.23901499720523134, 0.1066531371907331, 0.1634750803350471, 0.1750329468632117, 0.09968894213670865, 0.09770569347892888, 0.0974423201114405, 0.19467348436592147, 0.14106698508840054, 0.16910268226638436, 0.15524202055530623, 0.12640774279134348, 0.17133653193013743, 0.14869568432914093, 0.06981194688705727, 0.2386931871296838, 0.13841597421560436, 0.18452329386491328, 0.15599795733578503, 0.10005812349845655, 0.14421781757846475, 0.09171584926662035, 0.1038136579154525, 0.14360876666614786, 0.11893384813447483, 0.1540520164417103, 0.13929010543506593, 0.21870519092772156, 0.1825149977230467, 0.09352231092634611], [0.031681133987149224, 0.002002256915147882, 0.0884207506896928, 0.085051296337042, 0.023532627092208713, 0.018557957409939263, 0.056153910045395605, 0.04817166649445426, 0.09242266329238191, 0.028127541663707234, 0.03535713614837732, 0.05824567924719304, 0.07048990621115081, 0.0381946747074835, 0.08790389678324573, 0.020725819013023283, 0.01599753122718539, 0.03464587665803265, 0.019377468415768817, 0.061419017365551554, 0.10460404519108124, 0.031103581677598413, 0.058680113943410106, 0.04338799037213903, 0.023278506450878922, 0.017054397758329287, 0.04394843432237394, 0.007360332610915066, 0.07105239477823488, 0.03397200285689905, 0.031762313810759224, 0.10417751065688208, 0.06024385991622694, 0.03301556374935899, 0.01710728320176713, 0.0550379982450977, 0.006135181774880039, 0.09570363879902288, 0.04710962348326575, 0.023439814103767276, 0.06030191812897101, 0.0074229963138350286, 0.00571470362956461, 0.025390814589627553, 0.5151058221235871, 11.261289473623037, 31.332476511597633, 38.269160091876984, 24.745626859366894, 12.963553480803967, 15.733598191291094, 32.575272023677826, 32.419313192367554, 16.476898156106472, 2.239669170230627, 0.23184752790257335, 0.24261444312287495, 1.4170875283889472, 3.3690258068963885, 0.5436626554001123, 4.170436765998602, 7.560826689004898, 1.1467999569140375, 0.21839624969288707, 0.03653781888715457, 0.33384886861313134, 2.6939934538677335, 13.257562704384327, 26.816536635160446, 38.79546605050564, 47.92657367885113, 53.871567472815514, 55.5160166323185, 58.692383989691734, 62.53601834177971, 63.44785541296005, 64.3278805911541, 62.8179632127285, 58.298979699611664, 62.15811342000961, 61.44797332584858, 66.04794949293137, 57.793405428528786, 61.932983100414276, 61.057525277137756, 64.38714981079102, 62.33188949525356, 64.14427444338799, 59.9556490033865, 41.87162138521671, 50.66626086831093, 43.98596853017807, 60.11288456618786, 63.237396106123924, 62.62770362198353, 61.817226111888885, 61.9404610991478, 58.88391651213169, 58.56690712273121, 57.96908900141716, 60.80447405576706, 59.6453158557415, 59.8581500351429, 62.647834941744804, 59.700200110673904, 61.7232571542263, 63.462306037545204, 56.32773667573929, 50.729371681809425, 40.71157023310661, 33.55999298393726, 30.000140704214573, 25.445080026984215, 18.370222561061382, 11.995605770498514, 8.243669997900724, 5.7356692012399435, 2.042690352536738, 1.0511242970824242, 0.5453008424956352, 1.090673643629998, 1.5916647668927908, 2.2608029237017035, 2.6982577750459313, 4.478514734655619, 9.19911827892065, 6.0254183784127235, 2.7161094546318054, 1.371967087034136, 0.0320687799830921, 0.4549605119973421, 7.795484522357583, 22.279642783105373, 30.158842988312244, 25.396786518394947, 22.0007586479187, 30.042698420584202, 33.15737418830395, 19.757355228066444, 2.260301113128662, 0.01596263173269108, 0.06048968149116263, 0.03359522561368067, 0.02904647077230038, 0.034344405139563605, 0.03012469631357817, 0.038255007602856494, 0.012760054851241875, 0.039139098444138654, 0.0500325090251863, 0.0865265449101571, 0.016885945078684017, 0.01915147888212232, 0.05841839185450226, 0.08209711071685888, 0.07520762766944245, 0.01589506289747078, 0.0010113557164004305, 0.013509940345102223, 0.039998876527533866, 0.03268789441790432, 0.014772419817745686, 0.09023996244650334, 0.06842986011179164, 0.04261881738784723, 0.04126766332774423, 0.03451565200521145, 0.02664743944478687, 0.012111696087231394, 0.04694843642937485, 0.03374158826773055, 0.03836920557660051, 0.0306039122006041, 0.028281464947212953, 0.05499726546986494, 0.06853101484011859, 0.05313392561220098, 0.039707861869828776, 0.017335677293885965, 0.013621995367429918, 0.05086035991553217, 0.04371055372757837, 0.03462535998551175, 0.05600719487119932, 0.04563683884043712, 0.008616163831902668, 0.054372310332837515, 0.06506927442387678, 0.02125739527400583, 0.13111960870446637, 0.0552821128803771, 0.05640689705614932, 0.014397986833500909, 0.019275547419965733, 0.00908471598449978, 0.034992211003554985, 0.09536015801131725, 0.033033872532541864, 0.04221508163027465, 0.013766997108177748, 0.06493686043540947, 0.04234169202391058, 0.0772682749084197, 0.023060491294017993, 0.07866719359299168, 0.02254815335618332, 0.045828016081941314, 0.02967341115436284, 0.013146225828677416, 0.023592486868437845, 0.05936077839578502, 0.06312507015536539, 0.028560043065226637, 0.038796274457126856, 0.0857009130413644, 0.04884965921519324, 0.029211906621640082, 0.02345151220652042, 0.12027063421555795, 0.09041009237989783, 1.4628322049975395, 18.49491287022829, 39.87923249602318, 40.37340737879276, 21.164349429309368, 13.669967874884605, 26.05483900755644, 43.32625553011894, 41.52580574154854, 15.48768488690257, 1.244258196093142, 0.30153623374644667, 0.2809635439189151, 0.8994285995140672, 1.9492103811353445, 2.0737838465720415, 9.810192938894033, 10.522842798382044, 6.0889785178005695, 2.3896969947963953, 0.05503435430000536, 0.5780988419428468, 5.0278792809695005, 18.549094162881374, 33.25122535228729, 43.22084918618202, 50.417833998799324, 57.621172070503235, 60.798151195049286, 63.01002390682697, 65.61196088790894, 67.45065182447433, 67.00820356607437, 63.73632453382015, 60.03035679459572, 64.07910794019699, 63.36532764136791, 65.53463503718376, 62.265271469950676, 63.61750490963459, 62.31976434588432, 66.75651267170906, 64.92912232875824, 64.98536691069603, 63.55718694627285, 45.80506391823292, 47.66892470419407, 49.43661265075207, 63.56764778494835, 65.44733852148056, 63.42961259186268, 62.9815786331892, 62.57577560842037, 60.48542037606239, 61.91427670419216, 60.397911071777344, 62.155757546424866, 62.311697378754616, 61.53454028069973, 61.39300927519798, 60.346074253320694, 61.765526086091995, 64.188884049654, 58.516833409667015, 55.92460870742798, 47.102530896663666, 40.50068534910679, 35.51685757935047, 30.736972466111183, 24.378266371786594, 17.626038193702698, 13.047628719359636, 8.597794845700264, 3.597710835747421, 1.9582458212971687, 1.4772762986831367, 1.6539843915961683, 2.7910060482099652, 5.861975373700261, 5.652982788160443, 4.596799062564969, 9.144890438765287, 4.449459118768573, 1.1762287840247154, 1.3106056046672165, 0.10554436856182292, 0.33216564799658954, 6.879320433363318, 29.72543254494667, 45.38807049393654, 27.75926034897566, 19.341011568903923, 25.222573466598988, 31.95393316447735, 25.433391854166985, 3.632677271962166, 0.025609616423025727, 0.02153875644580694, 0.021812805607623886, 0.03520293270412367, 0.027850919104821514, 0.03192703348759096, 0.021002929534006398, 0.03846099069050979, 0.03018979936314281, 0.013678060913662193, 0.01559007174364524, 0.022636819594481494, 0.07856253592763096, 0.06222008043550886, 0.06460650081862696, 0.05169202915567439, 0.07445131981512532, 0.006215548482941813, 0.06604144335142337, 0.07064721925416961, 0.03016271468368359, 0.0509410016820766, 0.013216356928751338, 0.010106457593792584, 0.04389666581118945, 0.031886527067399584, 0.04507793113589287, 0.06137490039691329, 0.009785612310224678, 0.028557137557072565, 0.005145783889020095, 0.014534275760524906, 0.01755930123181315, 0.01439509616830037, 0.027082078231615014, 0.03915280591172632, 0.152775774768088, 0.1202700033900328, 0.12374156242003664, 0.16748067399021238, 0.10526038575335406, 0.19095761032076553, 0.19413746078498662, 0.2067575484397821, 0.18603916018037125, 0.12306227465160191, 0.13069459557300434, 0.19904229993699118, 0.14323261653771624, 0.1951126428321004, 0.15698948147473857, 0.16425641340902075, 0.06775714035029523, 0.12225564918480814, 0.11546727633685805, 0.12468999746488407, 0.2521116327261552, 0.15663819329347461, 0.11124038908747025, 0.15567254042252898, 0.14612926344852895, 0.16889158578123897, 0.17127187602454796, 0.13319968536961824, 0.13311159244040027, 0.18447167007252574, 0.1207903231261298, 0.21041338273789734, 0.17804085655370727, 0.14488583954516798, 0.12384581932565197, 0.09333497058833018, 0.0850028489367105, 0.1234481691790279, 0.2293131232727319, 0.2228411502437666, 0.10784567944938317, 0.09689858561614528, 0.16544790181796998, 0.16632417042274028, 1.2178220646455884, 19.29176051169634, 48.35145927965641, 52.28843942284584, 34.94662217795849, 22.212517485022545, 21.385320872068405, 38.51693719625473, 43.501046150922775, 19.560865871608257, 3.509374838322401, 0.5793100269511342, 0.8580909739248455, 3.196100411005318, 14.241144675761461, 3.626724178902805, 9.348657354712486, 13.756305892020464, 3.9307451527565718, 1.1317854188382626, 0.20720062544569373, 0.557138929143548, 4.130152752622962, 16.922167763113976, 30.309035629034042, 39.709313213825226, 50.90387351810932, 55.440708473324776, 59.144305139780045, 64.07504215836525, 66.31090298295021, 66.75686985254288, 66.98274493217468, 64.45545494556427, 60.453855469822884, 66.33283540606499, 68.26958388090134, 70.0825197994709, 64.21372711658478, 65.51824271678925, 65.35669818520546, 67.60968089103699, 67.33052507042885, 66.88253670930862, 62.91212975978851, 52.69271492958069, 48.11962611973286, 51.42292946577072, 64.37705755233765, 65.53053885698318, 66.63209214806557, 63.552843779325485, 64.8469403386116, 64.55004706978798, 63.984432220458984, 62.43207111954689, 63.81800875067711, 63.87163907289505, 64.37731593847275, 64.64429721236229, 62.43169113993645, 62.9796939343214, 65.63108906149864, 57.74725690484047, 54.17128399014473, 44.03922647237778, 37.65938401222229, 32.93618805706501, 27.251204811036587, 20.814333111047745, 13.900797888636589, 9.667742382735014, 7.085091741755605, 3.039357396773994, 1.1816076328977942, 1.0357009246945381, 2.257332047447562, 3.2863241946324706, 6.014940440654755, 8.545767087489367, 8.70496429502964, 17.017593942582607, 11.897782869637012, 7.703410713002086, 2.884813752025366, 0.15678236290114, 0.9248560632113367, 11.501489784568548, 28.962101005017757, 39.891270250082016, 35.371545776724815, 31.666303798556328, 39.72103178501129, 45.133487954735756, 28.62878669053316, 3.1592269521206617, 0.13562969950726256, 0.16566900245379657, 0.0841985760780517, 0.2848250273382291, 0.12328671495197341, 0.13865280838217586, 0.10885843643336557, 0.13386175531195477, 0.12185937201138586, 0.12607224751263857, 0.19077927223406732, 0.10956069367239252, 0.16159427032107487, 0.16467165987705812, 0.2843617490725592, 0.13329825742403045, 0.0939116119116079, 0.06874961443827488, 0.14451130729867145, 0.17181493516545743, 0.09772544202860445, 0.10034442922915332, 0.1653305534273386, 0.11694619854097255, 0.07941968680825084, 0.08161887075402774, 0.18902533978689462, 0.09021285179187544, 0.12901425448944792, 0.11089448889833875, 0.1202341725002043, 0.19776286702835932, 0.11319080513203517, 0.17711902008159086, 0.15646484243916348, 0.14077006664592773], [0.0918627722421661, 0.034644266197574325, 0.034920716207125224, 0.007722103164269356, 0.04930045826768037, 0.08083552645985037, 0.05280804856738541, 0.060046233411412686, 0.07037116258288734, 0.03157683997415006, 0.051437513320706785, 0.008986089196696412, 0.014215617029549321, 0.049580266495468095, 0.05271947695291601, 0.0616801865544403, 0.017457870053476654, 0.052589541737688705, 0.02326415888092015, 0.011375490230420837, 0.11650570420897566, 0.03812015937000979, 0.06045702699339017, 0.017131787062680814, 0.07736809377092868, 0.026525445209699683, 0.07415447558742017, 0.02326322934095515, 0.0759940296120476, 0.036728369013872, 0.07474197453120723, 0.06637314625550061, 0.02234359890280757, 0.06795317123760469, 0.05678439418261405, 0.07137712891562842, 0.02781614206469385, 0.03580783130018972, 0.09083373995963484, 0.030349168155225925, 0.038486416669911705, 0.051645477942656726, 0.05077876819996163, 0.03556041410774924, 0.02508616296836408, 0.1333931929548271, 5.832964880391955, 28.931742534041405, 40.86828142404556, 23.64888411015272, 19.421930126845837, 21.558530777692795, 25.186754688620567, 34.70364801585674, 24.65167500078678, 5.779700763523579, 0.4226843314245343, 0.23491611558711156, 1.1320633976720273, 2.2786783520132303, 22.036389335989952, 5.916083045303822, 8.215295020490885, 5.410048998892307, 0.3424551693024114, 0.13576822879258543, 0.1362739282194525, 0.09156152707873844, 1.8810484511777759, 7.883687289431691, 22.256241738796234, 33.00867676734924, 41.48818016052246, 46.72561772167683, 44.95648965239525, 50.888750329613686, 51.20538353919983, 55.20693361759186, 56.91159054636955, 61.04252748191357, 62.82332472503185, 64.89791080355644, 68.55669647455215, 65.09508982300758, 63.78947988152504, 66.63617312908173, 62.44787447154522, 68.44661638140678, 49.84852954745293, 37.47898489236832, 35.33494994044304, 41.16875410079956, 50.904090106487274, 66.49147689342499, 63.18848133087158, 66.76021367311478, 65.59982433915138, 62.941012009978294, 62.426956593990326, 61.428229585289955, 64.61865618824959, 64.74970355629921, 63.27346757054329, 65.33738002181053, 59.02770459651947, 47.026922553777695, 31.251736544072628, 17.66608614474535, 8.57968121767044, 5.999813452363014, 3.029581233859062, 2.159375441260636, 1.805566807743162, 1.6067310771904886, 0.631891367956996, 0.752263565082103, 0.0782351077941712, 0.34186688368208706, 0.7131593290250748, 1.8101680045947433, 1.996770054101944, 3.2483359705656767, 5.5754374992102385, 3.9667705446481705, 4.006688827648759, 8.131449669599533, 3.8725659996271133, 1.300553244072944, 0.25817260437179357, 1.7176892794668674, 14.02792576700449, 26.807154938578606, 30.932490974664688, 21.35485030710697, 21.11042082309723, 27.89301887154579, 30.6794473528862, 15.699230935424566, 1.4642209117300808, 0.028365965881675947, 0.01072839404514525, 0.05562676626141183, 0.10812801469000988, 0.08649734139908105, 0.045873506023781374, 0.027403571039030794, 0.01961522470082855, 0.014006633809913183, 0.041102212635450996, 0.12425342167261988, 0.06743150821421295, 0.12294456260860898, 0.04571091631078161, 0.03407161762879696, 0.03224749285436701, 0.03492547337373253, 0.031881914619589224, 0.04072678981174249, 0.04106831875105854, 0.021539897497859783, 0.004808959702131688, 0.021145946957403794, 0.023381748469546437, 0.026156328785873484, 0.03913529864803422, 0.018079183100780938, 0.015482907474506646, 0.04886889939371031, 0.031703064450994134, 0.01987968531466322, 0.050320855661993846, 0.04342895692388993, 0.05172241268155631, 0.028815217556257267, 0.046146479071467184, 0.021010879790992476, 0.04386730273836292, 0.09095114772208035, 0.021412218411569484, 0.04037691171106417, 0.043286160289426334, 0.04556677638902329, 0.026935682180919684, 0.09752342200954445, 0.04870188276981935, 0.046332041965797544, 0.07086574463755824, 0.08020658598979935, 0.09034397444338538, 0.10436671378556639, 0.08567672644858249, 0.01794293220882537, 0.03542772181390319, 0.06204005396284629, 0.01988170581171289, 0.028888992601423524, 0.013093721663608449, 0.014592908210033784, 0.026769765790959354, 0.10282885021297261, 0.02996833878569305, 0.08017813946935348, 0.02349276819586521, 0.03121751062280964, 0.022853847694932483, 0.04925892768369522, 0.07818480502464809, 0.12676738755544648, 0.08485122074489482, 0.0979674415430054, 0.07383126285276376, 0.11622310921666212, 0.02969662924442673, 0.06776950453058816, 0.04026561924547423, 0.05092081155453343, 0.06549885918502696, 0.030058416959946044, 0.040454391928506084, 0.09020085868542083, 0.06090765535191167, 0.7304361707065254, 12.9761878028512, 39.73856784403324, 42.535677552223206, 23.222282901406288, 11.028589960187674, 20.95815349370241, 36.31841316819191, 43.71056690812111, 24.27896250039339, 3.311415435746312, 0.36636387230828404, 0.29472456488292664, 1.6738895047456026, 3.522457773797214, 7.519983630627394, 9.21990791335702, 8.564773667603731, 5.7656424678862095, 1.438286709599197, 0.888711690204218, 0.28426672448404133, 0.3613764321198687, 4.2700897436589, 12.804146334528923, 28.4402959048748, 39.18395720422268, 44.34395872056484, 49.67325635254383, 49.24410738050938, 53.8761880248785, 54.32850435376167, 58.69706533849239, 59.41116861999035, 62.287762463092804, 64.380272179842, 68.71084660291672, 69.38349410891533, 67.95366123318672, 65.00107526779175, 68.87099280953407, 65.60821428894997, 68.03706675767899, 52.245900705456734, 41.70874312520027, 39.29529123008251, 44.59936961531639, 54.14224594831467, 65.20510911941528, 63.90796512365341, 67.18519046902657, 67.4026907980442, 63.661096170544624, 63.55625979602337, 63.44257369637489, 64.82373118400574, 64.50176686048508, 65.49780741333961, 65.76300278306007, 59.7836322337389, 51.17299407720566, 38.9974670112133, 23.482895717024803, 13.752639088779688, 9.70546580851078, 5.968276094645262, 5.130364056676626, 4.869320914149284, 3.6279166024178267, 1.7097650421783328, 2.085874085314572, 0.47352037858217955, 1.4161203615367413, 3.436826281249523, 4.960429100319743, 5.875623766332865, 5.365452216938138, 11.76589859649539, 6.603252897039056, 3.0070071201771498, 2.3447119211778045, 0.17198724701302126, 0.2965389675227925, 0.09759387408848852, 1.254106555134058, 13.504553250968456, 37.798160165548325, 37.46358051896095, 19.290726967155933, 19.829059280455112, 28.12511421740055, 37.53521807491779, 23.860532753169537, 2.9407576750963926, 0.12053310958435759, 0.07008156171650626, 0.04983654493116774, 0.08406222870689817, 0.08069645540672354, 0.013555482237279648, 0.04613648234226275, 0.05643610056722537, 0.04912348202196881, 0.06853699655039236, 0.09413787789526395, 0.05218166479608044, 0.045711424681940116, 0.021103638973727357, 0.025988839042838663, 0.06312976795015857, 0.04643187567126006, 0.06695387681247666, 0.02235649742942769, 0.010562440547801089, 0.010821669020515401, 0.03965419346059207, 0.024370931132580154, 0.0359808852954302, 0.036107402920606546, 0.026568526882329024, 0.06238504502107389, 0.04909350296657067, 0.04986471314623486, 0.0225898323697038, 0.060762068242183886, 0.015389959971798817, 0.051058743410976604, 0.03832628717646003, 0.027087417984148487, 0.07861604477511719, 0.08113291987683624, 0.2150174739654176, 0.16333395353285596, 0.16074488230515271, 0.11575452459510416, 0.15520454209763557, 0.19005085428943858, 0.1046044756367337, 0.1768053142586723, 0.08554401560104452, 0.17577450082171708, 0.12047416821587831, 0.10843503376236185, 0.17212491540703923, 0.20038848160766065, 0.1546546700410545, 0.13892603747081012, 0.15994866174878553, 0.14825122692855075, 0.1222967344801873, 0.07597746487590484, 0.18728029826888815, 0.11289263245998882, 0.0947546397219412, 0.1304777103359811, 0.23204646800877526, 0.2252698878874071, 0.10871210717596114, 0.08333808553288691, 0.14892877807142213, 0.15881510538747534, 0.1138281541352626, 0.26705388561822474, 0.12769263790687546, 0.16630664089461789, 0.21142917510587722, 0.19817321532173082, 0.12426846500602551, 0.18927606695797294, 0.18735985649982467, 0.18159354716772214, 0.12677210761466995, 0.1840663535404019, 0.2090958776534535, 0.15633498143870384, 0.1632882669218816, 0.5708374315872788, 12.443390842527151, 44.376101195812225, 54.34784151613712, 35.2459055185318, 28.089662119746208, 30.16096707433462, 33.34731459617615, 44.356061071157455, 31.355731263756752, 7.852559834718704, 0.7558574597351253, 1.1655530193820596, 2.2609363915398717, 7.7320953737944365, 34.116841703653336, 13.410274609923363, 18.57795361429453, 11.226970665156841, 1.3641429506242275, 0.5930510989855975, 0.26025783154182136, 0.21259226894471794, 3.1795964716002345, 9.58327766507864, 25.967460796236992, 36.97430357336998, 44.214792251586914, 49.4691427052021, 47.0090027153492, 53.07002708315849, 53.4671475738287, 56.689674854278564, 57.46276997029781, 60.335218235850334, 64.1652949154377, 70.29739066958427, 73.26997876167297, 71.85289800167084, 68.64790678024292, 69.28310349583626, 65.64577147364616, 67.05210641026497, 53.24323318898678, 43.66566091775894, 40.103762447834015, 47.560197338461876, 55.014470145106316, 66.50030001997948, 64.20292809605598, 69.1219237446785, 67.19510033726692, 63.15611846745014, 64.0542496740818, 64.55440163612366, 68.35251063108444, 65.93729943037033, 65.64046695828438, 67.39686191082001, 59.34679627418518, 49.621164947748184, 34.09860648214817, 20.076051726937294, 10.105763878673315, 7.897943649441004, 4.049307815730572, 3.1027752812951803, 2.749519874341786, 2.451230180449784, 0.8441300480626523, 1.214333139359951, 0.31800152210053056, 0.8081284642685205, 2.661429913714528, 5.213970495387912, 6.488187471404672, 8.398672230541706, 14.03082026168704, 8.739112112671137, 12.45247520506382, 14.635440967977047, 8.27898720279336, 3.231187015771866, 0.46722791623324156, 2.777609867043793, 18.22451937943697, 36.36840708553791, 37.576012685894966, 29.345167949795723, 32.84168712794781, 37.44988225400448, 44.0998712182045, 22.338180541992188, 2.4824184319004416, 0.13502915360732004, 0.236486277426593, 0.1289926579920575, 0.25091282674111426, 0.27189907093998045, 0.13839906809153035, 0.10546554505708627, 0.11489947399240918, 0.08303792390506715, 0.1231854414800182, 0.19813159568002447, 0.23511229490395635, 0.1836203970015049, 0.16235699033131823, 0.108976482442813, 0.2979172545019537, 0.17310692521277815, 0.10304343479219824, 0.14874491840600967, 0.14049985067686066, 0.17787047429010272, 0.13023945124587044, 0.13584418018581346, 0.14571363106369972, 0.13845471432432532, 0.13759134424617514, 0.20611710468074307, 0.21706657338654622, 0.21033394325058907, 0.15286490670405328, 0.1590685933479108, 0.07458984167897142, 0.12393174518365413, 0.08932358075981028, 0.16865289624547586, 0.15806549170520157, 0.12607533484697342], [0.035784394276561216, 0.042983360326616094, 0.03651286046078894, 0.05872844260011334, 0.03328887076349929, 0.025841893802862614, 0.022184426779858768, 0.015097080668056151, 0.10776470371638425, 0.08273504601675086, 0.03528876950440463, 0.02688290991500253, 0.024658643233124167, 0.0388007125002332, 0.06626536414842121, 0.015962603902153205, 0.02290472748427419, 0.015232368623401271, 0.019507041834003758, 0.096635145455366, 0.026220839972666, 0.0596981179114664, 0.015667782026866917, 0.048971556971082464, 0.005842314531037118, 0.009616144743631594, 0.03618578484747559, 0.08216641988838091, 0.028225213864061516, 0.0406830105202971, 0.018421524691802915, 0.04780398427101318, 0.023379002523142844, 0.03269076281867456, 0.05142413610883523, 0.02696136049053166, 0.03235219875932671, 0.06036662598489784, 0.06889682685141452, 0.03359244255989324, 0.023888536998128984, 0.00891353683982743, 0.08562550341594033, 0.0214518973371014, 0.06927306603756733, 0.06525720105855726, 0.20341065537650138, 3.3656145399436355, 27.583884559571743, 39.9806072562933, 35.5035050958395, 19.614015519618988, 22.45898175984621, 21.8487611040473, 30.470450967550278, 30.87921403348446, 9.928897619247437, 1.7291385401040316, 0.03256789284932893, 0.28323778125923127, 1.5040168887935579, 9.189398400485516, 9.065872728824615, 5.365248927846551, 0.4789356520632282, 1.0778330639004707, 0.274033309542574, 0.13540512562030926, 0.12811190681532025, 0.1043764952919446, 3.5767703969031572, 8.589973915368319, 13.459177035838366, 17.065440975129604, 17.2598784416914, 20.2297667786479, 22.26553224027157, 29.525120593607426, 35.92349275946617, 48.54245223104954, 59.2413405328989, 64.28399294614792, 58.36988769471645, 60.73304548859596, 56.68054014444351, 72.50919878482819, 67.27051109075546, 64.32723462581635, 38.64478513598442, 34.99445401132107, 29.080048575997353, 40.71401730179787, 51.20279587805271, 67.57023900747299, 63.03392082452774, 67.73526415228844, 66.47018283605576, 65.37742227315903, 64.11661952733994, 62.98661716282368, 62.8037291765213, 59.11556348204613, 51.41233563423157, 37.12298959493637, 20.604772455990314, 8.243650998920202, 2.253528689034283, 0.34867006237618625, 0.23526499920990318, 0.13748429686529562, 0.029487981846614275, 0.18413105397485197, 0.315753705217503, 0.69946622941643, 0.6501027813646942, 1.1790532199665904, 1.269191864412278, 1.0849684872664511, 3.8640138460323215, 3.790385196916759, 3.2048321049660444, 3.2269162824377418, 10.73912339285016, 6.720419134944677, 1.6557668522000313, 1.2482073716819286, 0.3334058361360803, 0.8911923039704561, 2.868260177783668, 19.33838400989771, 27.30686042457819, 24.56472236663103, 21.033566147089005, 31.22999031096697, 29.871105328202248, 30.455871149897575, 6.7323181964457035, 0.2643793635070324, 0.003511895451993041, 0.06276736981817521, 0.041230808274121955, 0.03091986302024452, 0.015222674319375074, 0.007725546729488997, 0.021198988251853734, 0.016543314050068147, 0.02761677336820867, 0.03812401853792835, 0.030744298710487783, 0.0434406271961052, 0.006977449811529368, 0.08134418705594726, 0.02290639175043907, 0.020460814776015468, 0.041759707237361, 0.05619820141873788, 0.08821030729450285, 0.040728314925218, 0.0825373972475063, 0.036320436411187984, 0.022389337464119308, 0.038287265051621944, 0.0523758366034599, 0.0217307593266014, 0.046667340575368144, 0.043396109467721544, 0.03741431384696625, 0.05616074522549752, 0.02928111374785658, 0.04449940846825484, 0.01876123722468037, 0.04205295947031118, 0.03554107745003421, 0.08455940085696056, 0.027165107858309057, 0.04844064678763971, 0.055253959508263506, 0.038394987786887214, 0.029886708107369486, 0.03234875519410707, 0.06636585094383918, 0.03057717447518371, 0.027195461698283907, 0.05442360015877057, 0.03841548961645458, 0.052639484565588646, 0.06442968413466588, 0.03481749459751882, 0.006296280234892038, 0.057757565009524114, 0.04313735968025867, 0.04811314443941228, 0.043250206945231184, 0.059260466005071066, 0.05593879483058117, 0.07761299508274533, 0.03211858180293348, 0.07984924930497073, 0.02336461784580024, 0.0529523517616326, 0.06394128417014144, 0.012698024293058552, 0.016530471184523776, 0.07161978894146159, 0.014742325729457662, 0.05333037952368613, 0.016936032625380903, 0.10859522633836605, 0.02394334089331096, 0.030347014071594458, 0.015640734454791527, 0.04334717967140023, 0.03238284574763384, 0.10138689438463189, 0.07050179541693069, 0.047910990833770484, 0.06328751886030659, 0.05755657657573465, 0.02353332471102476, 0.005110038346174406, 0.019013767814612947, 0.0100835474950145, 0.0962919689482078, 8.22567606344819, 37.118490636348724, 42.743093222379684, 31.894158571958542, 16.49263121187687, 19.20124176889658, 29.893520325422287, 43.31672944128513, 31.864149682223797, 9.594448115676641, 1.2929892749525607, 0.09708905781735666, 0.5606005433946848, 1.8103951611556113, 3.220565873198211, 5.221477467566729, 5.419950317591429, 2.8720818227156997, 2.20341460313648, 1.1268992372788489, 0.5410592607222497, 0.38623457949142903, 0.12419179372955114, 4.991290094330907, 11.866017524152994, 17.153738737106323, 22.29412380605936, 23.540882505476475, 25.221522822976112, 29.164525642991066, 35.651172772049904, 40.987693816423416, 51.511521711945534, 63.149259835481644, 65.22603079676628, 61.39107137918472, 63.35737086832523, 60.28826415538788, 70.78176587820053, 66.72228410840034, 66.24185308814049, 44.554414227604866, 37.113801687955856, 32.06124700605869, 45.199900791049004, 55.60167543590069, 68.54444593191147, 63.7109000980854, 68.32828313112259, 67.99819484353065, 65.95920905470848, 63.84719118475914, 63.27246442437172, 66.40155851840973, 62.283818274736404, 56.13382928073406, 41.63679398596287, 27.304540649056435, 12.896801512688398, 4.7006835881620646, 1.2212444934993982, 1.1279945285059512, 0.5625714501366019, 0.12259690352948382, 1.1552210175432265, 1.5114096296019852, 1.2787867058068514, 2.2673504473641515, 3.970494819805026, 2.8284865245223045, 3.3666506968438625, 4.379354305565357, 6.916157081723213, 5.653511909767985, 5.766753908246756, 7.247960977256298, 5.190464481711388, 0.18921834271168336, 0.4783177102217451, 0.155307715467643, 0.820146210025996, 3.0055242497473955, 22.26176094263792, 40.99177099764347, 30.70649240165949, 17.689283899962902, 23.031250052154064, 31.094122901558876, 34.666493609547615, 12.513443883508444, 0.7555383956059813, 0.027653752731566783, 0.06220790179213509, 0.03676840045955032, 0.0029526261823775712, 0.025344653004140127, 0.015864415909163654, 0.030763657632633112, 0.018363592644163873, 0.034554306766949594, 0.05499013714143075, 0.029599723311548587, 0.055765295546734706, 0.03259284756495617, 0.07545678890892304, 0.06501293799374253, 0.016467019413539674, 0.03211927200027276, 0.052462081584963016, 0.037830565925105475, 0.041637969043222256, 0.027343006222508848, 0.022855330134916585, 0.03897835296811536, 0.09082755786948837, 0.03035818339412799, 0.014393292749446118, 0.0857169805385638, 0.029612662656290922, 0.04094754905963782, 0.07130515543394722, 0.04710885164968204, 0.019959427227149718, 0.04249536483257543, 0.028899805693072267, 0.010504524270800175, 0.018568245432106778, 0.03141502951621078, 0.005170980266484548, 0.14569580467650667, 0.09359252551803365, 0.12511791981523857, 0.14079662068979815, 0.14731321163708344, 0.11790747274062596, 0.1336387250921689, 0.09719162262626924, 0.14072292542550713, 0.15805021830601618, 0.13957056304207072, 0.10758738237200305, 0.1914096376276575, 0.21956404874799773, 0.16468997608171776, 0.1305212892475538, 0.14594681386370212, 0.08442154692602344, 0.10522842887439765, 0.20500716345850378, 0.11524328132509254, 0.1325358491158113, 0.10317344422219321, 0.13910781912272796, 0.11745361975044943, 0.12374128782539628, 0.13457973866024986, 0.1942730660084635, 0.0924402373493649, 0.09555450422340073, 0.09037260650075041, 0.1958409568760544, 0.11646666724118404, 0.07107988392817788, 0.21396365395048633, 0.24363884440390393, 0.12920541688799858, 0.20100250490941107, 0.16253847512416542, 0.08234174485551193, 0.1403814781224355, 0.1667236685170792, 0.174830726464279, 0.10170282665058039, 0.15670197346480563, 0.18255445029353723, 0.3472149185836315, 8.339276667684317, 39.52248103916645, 56.0277009755373, 47.10544154047966, 28.61726950854063, 31.816699728369713, 28.948712423443794, 41.60161167383194, 38.59866701066494, 14.42448578774929, 2.4612595047801733, 0.14931521436665207, 1.6300171776674688, 5.5325354263186455, 19.570365361869335, 20.59259980916977, 12.473967801779509, 3.3429012587293983, 2.975639090873301, 1.29852605285123, 0.34124736848752946, 0.24780823005130515, 0.32159321999643, 4.010384129360318, 9.710937514901161, 15.895580649375916, 19.756110794842243, 20.651139467954636, 22.084669545292854, 27.056917436420918, 32.40096017718315, 40.928325802087784, 52.565292567014694, 67.154351323843, 68.02296191453934, 59.68815095722675, 65.59417024254799, 63.00829879939556, 68.16812172532082, 66.63380965590477, 64.95588809251785, 48.26623745262623, 42.33946368098259, 35.36274544894695, 48.46516817808151, 57.314539924263954, 65.94129681587219, 64.25463572144508, 68.08968633413315, 68.64495813846588, 63.988710790872574, 64.74882200360298, 62.20591105520725, 63.47534313797951, 60.847825929522514, 53.83781388401985, 38.38614821434021, 22.03704860061407, 9.733637496829033, 3.4276915714144707, 0.659451229730621, 0.5670439882669598, 0.354729401296936, 0.1465516196913086, 0.6507540901657194, 1.4309808891266584, 1.3858401426114142, 1.7950908886268735, 3.0083919083699584, 2.801059358753264, 3.1275297654792666, 7.798345293849707, 10.427322573959827, 10.207960344851017, 8.170862104743719, 19.871052727103233, 16.240146160125732, 5.379835870116949, 4.37717417255044, 0.9592150663957, 1.4067394961602986, 5.3941083792597055, 25.518026612699032, 36.022933423519135, 31.957045197486877, 29.39339306205511, 40.228163972496986, 41.02749668061733, 40.933626517653465, 12.69051818177104, 0.9774600842501968, 0.10509005544008687, 0.17195947584696114, 0.15143621305469424, 0.1425345821189694, 0.15924290899420157, 0.07833924595615827, 0.10907952964771539, 0.11083224497269839, 0.13299323472892866, 0.11629088956397027, 0.13928623142419383, 0.12636305065825582, 0.053601404433720745, 0.1183534886513371, 0.1574826386058703, 0.08905287497327663, 0.14475051633780822, 0.1591167735750787, 0.12612881400855258, 0.16687132621882483, 0.13674339599674568, 0.1363507701898925, 0.08378793092560954, 0.20312666514655575, 0.20513852359727025, 0.20847229548962787, 0.1430858494131826, 0.15161795017775148, 0.21964949963148683, 0.20478886814089492, 0.10950380063150078, 0.09176705003483221, 0.147498466540128, 0.1828490532352589, 0.19558650412363932, 0.1886629787622951, 0.11281288869213313, 0.14808682637521997], [0.022027880004316103, 0.14053648308617994, 0.0442047535761958, 0.044655367091763765, 0.04474537847272586, 0.06353309552650899, 0.03978890068538021, 0.018385742041573394, 0.04603461886290461, 0.08223212222219445, 0.009829139271460008, 0.02998511688929284, 0.05220884966547601, 0.022303109180938918, 0.05089698490337469, 0.016103517336887307, 0.041955363340093754, 0.0397286828228971, 0.027603067755990196, 0.032239882129943, 0.040507147496100515, 0.016804290280560963, 0.02906477398937568, 0.10146214815904386, 0.05593685040366836, 0.0680694954644423, 0.028766625437128823, 0.01759221362590324, 0.025864011658995878, 0.023892500066722278, 0.09153060178505257, 0.12007098164758645, 0.10797872426337563, 0.01901967902085744, 0.011931555509363534, 0.03683944625663571, 0.019915228622267023, 0.03842005011392757, 0.033556077323737554, 0.035335072097950615, 0.056391961334156804, 0.03991657977167051, 0.067220493365312, 0.03721499153471086, 0.058727414725581184, 0.059548103890847415, 0.11654442205326632, 0.06530575978104025, 2.324992404319346, 20.230747126042843, 41.254021525382996, 34.89236868917942, 28.196122907102108, 16.68542716652155, 30.791368447244167, 31.532645970582962, 29.14001315832138, 16.93511176854372, 5.82401018589735, 0.7615983579307795, 0.21449844556627795, 0.7782187254633754, 3.026416953653097, 3.2830836810171604, 2.6207922818139195, 1.945647003594786, 0.6472231296356767, 0.9819716890342534, 0.7766572467517108, 0.19860400236211717, 0.07081343806930818, 0.18970716570038348, 0.6252988404594362, 0.8274056611116976, 1.4290832472033799, 1.2395161692984402, 0.9018502570688725, 2.122426461428404, 2.5947282928973436, 8.145834747701883, 22.79032588005066, 41.717904433608055, 53.249936029314995, 61.08692429959774, 57.11127743124962, 56.30117230117321, 65.15198037028313, 54.04225051403046, 39.372256100177765, 36.489510387182236, 27.984485663473606, 33.00847537815571, 41.800534799695015, 67.50229865312576, 68.05438622832298, 55.52286006510258, 55.58447375893593, 55.84301948547363, 50.72464093565941, 44.04660947620869, 32.47924357652664, 21.20913002640009, 12.036012802273035, 3.217156743630767, 0.5885581963229924, 0.04447512168553658, 0.06385339162079617, 0.1843948132591322, 0.2018539115670137, 0.3601327113574371, 1.4907294767908752, 2.4376026866957545, 2.865264513529837, 1.7746751778759062, 2.90325487498194, 6.664171228185296, 3.4497619746252894, 4.197166431695223, 3.51411912124604, 7.279405714944005, 5.023538488894701, 6.5138052217662334, 6.6199511010199785, 3.5954297706484795, 0.4447356762830168, 0.7368950522504747, 0.9463559626601636, 9.139160346239805, 29.201284870505333, 26.951860673725605, 23.072787523269653, 16.388775184750557, 27.03326180577278, 30.6042417883873, 21.37656044214964, 4.057743838056922, 0.27706875291187316, 0.12159841062384658, 0.0354521087865578, 0.03717304534802679, 0.02896513880841667, 0.042860019093495794, 0.03719379208632745, 0.04674480594985653, 0.059871754492633045, 0.07632182881934568, 0.02039018272625981, 0.03251209076552186, 0.027224665209359955, 0.061722826649202034, 0.07670703314943239, 0.01912968571559759, 0.01910370683617657, 0.033078434789786115, 0.06064982953830622, 0.034615968106663786, 0.03532393617206253, 0.05590409942669794, 0.08038606698391959, 0.06640748542849906, 0.01751334930304438, 0.049594749507377855, 0.04209345846902579, 0.037099424298503436, 0.11467052143416367, 0.04695148665632587, 0.008018303578865016, 0.05366584882722236, 0.053288771014194936, 0.011224556874367408, 0.03491200339340139, 0.022857749536342453, 0.12047925192746334, 0.03029882827831898, 0.03375734406290576, 0.03155181104375515, 0.03571028712030966, 0.07799801387591287, 0.04696494550444186, 0.01620025072043063, 0.0666700943838805, 0.04674494695791509, 0.026910438027698547, 0.05426042785984464, 0.07203142115031369, 0.06717497744830325, 0.047964640689315274, 0.02360686969041126, 0.043372561121941544, 0.03671738893899601, 0.028481521985668223, 0.02772926069155801, 0.0356616096541984, 0.043138766050105914, 0.043912414184887893, 0.04693378272349946, 0.0032725391429266892, 0.0012735631003124581, 0.023069226372172125, 0.019940489473810885, 0.030291813127405476, 0.024840257901814766, 0.04303433102904819, 0.04194845765596256, 0.03508116482407786, 0.1019406552950386, 0.01522417995147407, 0.050147879592259414, 0.056257476753671654, 0.01492021574449609, 0.03506036984617822, 0.08736110481549986, 0.09730208388646133, 0.03664186428068206, 0.020858390707871877, 0.009468539919907926, 0.03870312008075416, 0.033268632396357134, 0.08782928125583567, 0.019258875072409865, 0.0318190658435924, 0.016870367398951203, 0.09001414175145328, 0.1320097703137435, 6.946210619062185, 30.263648964464664, 46.644769459962845, 34.16123852133751, 23.163298666477203, 12.552362345159054, 30.473374910652637, 42.884498834609985, 33.697522804141045, 18.64930048584938, 5.108707118779421, 0.2859090082347393, 0.1447054828167893, 0.401270788279362, 1.7284972057677805, 2.814015713520348, 3.858643309213221, 3.8374986313283443, 6.837937328964472, 3.508220175281167, 2.9538995074108243, 1.459209811873734, 0.19937570235924795, 0.7139866158831865, 1.1437991866841912, 1.5486335009336472, 2.8342674393206835, 2.7096391143277287, 2.14440471958369, 3.822690825909376, 5.6154930498450994, 13.78316380083561, 30.78623492270708, 52.0109973102808, 58.911978006362915, 65.09034767746925, 58.92250344157219, 60.53857572376728, 68.39220330119133, 57.87834607064724, 45.298748686909676, 41.52093060314655, 28.657705038785934, 37.43003211915493, 46.56698003411293, 66.46744698286057, 67.68830627202988, 59.15501296520233, 60.786805003881454, 59.574506655335426, 55.04261903464794, 46.98380246758461, 38.60285438597202, 27.44897659868002, 18.11554502695799, 6.470529343932867, 1.8062517209909856, 0.36462410003878176, 0.27872997627127916, 0.5162600101903081, 0.5135871504899114, 1.8260573269799352, 2.7754606073722243, 6.012217411771417, 5.523965461179614, 5.951435873284936, 4.365188665688038, 7.7172723691910505, 5.43787538073957, 5.921152923256159, 6.83419500477612, 5.592689998447895, 3.3003224059939384, 3.6726706009358168, 0.5115053371991962, 0.6501358514651656, 0.15120829950319603, 0.23667456029215828, 1.6799269057810307, 6.90586818382144, 28.969628401100636, 40.46961821615696, 24.584648497402668, 13.460889793932438, 21.41250841319561, 35.742474272847176, 29.240059889853, 8.276003412902355, 0.5160916910972446, 0.11606620435486548, 0.06364809873048216, 0.05307160747179296, 0.05242718951194547, 0.07674060791032389, 0.04495828950894065, 0.02825524115905864, 0.03373355451913085, 0.06734381604474038, 0.04051267278555315, 0.014232589946914231, 0.022699549626850057, 0.03127271156699862, 0.034543809088063426, 0.1032455958193168, 0.024077615817077458, 0.02150995369447628, 0.04898854844213929, 0.007836022832634626, 0.038643451407551765, 0.03581256249162834, 0.019694517613970675, 0.09503911234787665, 0.102893699076958, 0.07810360664734617, 0.022369837533915415, 0.023858463318902068, 0.09634924790589139, 0.03745141380932182, 0.05184779853152577, 0.039932120344019495, 0.024748845717113, 0.028352074732538313, 0.04417319745698478, 0.036317041085567325, 0.020837549345742445, 0.07895758113591, 0.044639232801273465, 0.07107409517630003, 0.11915845170733519, 0.1866771251661703, 0.17920694866916165, 0.17455307417549193, 0.17837648541899398, 0.3025047364644706, 0.1544363153516315, 0.1355685168527998, 0.1455705746775493, 0.11372307344572619, 0.20795184216694906, 0.14595105894841254, 0.14292251755250618, 0.1357364351861179, 0.06737716073985212, 0.1632258523022756, 0.11741915441234596, 0.09977667883504182, 0.11547039335709997, 0.10244273304124363, 0.09836092824116349, 0.12477006035624072, 0.10252227642922662, 0.20863065496087074, 0.17974736576434225, 0.1927221703226678, 0.1722618713392876, 0.19602327287429944, 0.0721438268374186, 0.17134561581769958, 0.12820920237572864, 0.20262387493858114, 0.28680662100668997, 0.14244024030631408, 0.05168906798644457, 0.1720188625040464, 0.14307747798739, 0.1461530863889493, 0.16946164425462484, 0.11302222628728487, 0.1287370771751739, 0.12176347911008634, 0.18161077983677387, 0.12009616271825507, 0.19307328038848937, 0.21897709899349138, 0.19502297654980794, 0.18291736050741747, 5.433011641725898, 30.324964374303818, 56.71838991343975, 46.59623086452484, 39.13168340921402, 23.684155717492104, 40.22693283855915, 43.861555606126785, 37.5134452432394, 22.364729717373848, 7.680320302024484, 1.1005322146229446, 0.6038032157812268, 1.3203333201818168, 6.258309781551361, 10.070320330560207, 8.820448648184538, 4.864741684868932, 8.529662601649761, 3.9081563148647547, 2.8124893829226494, 0.6788070942275226, 0.20291377266403288, 0.4512101726140827, 0.7895842124707997, 1.0471067251637578, 1.8302772380411625, 1.6906479117460549, 1.0881838272325695, 2.6908035250380635, 3.4744281135499477, 11.021163258701563, 26.581882126629353, 52.55725979804993, 66.56212270259857, 71.12874045968056, 67.47260704636574, 64.53340396285057, 65.66391170024872, 58.59577797353268, 52.22319692373276, 47.78356075286865, 33.741136863827705, 41.556226909160614, 52.183371260762215, 68.74662548303604, 70.00663787126541, 57.892173528671265, 57.08057127892971, 57.07273229956627, 51.40963397920132, 44.86145295202732, 35.11035919189453, 24.381802082061768, 14.184525813907385, 4.5807273499667645, 1.2561611761339009, 0.2794175612507388, 0.1632001146208495, 0.21543500624829903, 0.6157638458535075, 0.842529977671802, 3.495727158151567, 5.137317683547735, 6.732628829777241, 5.871161380782723, 6.513413367792964, 11.741641648113728, 4.794369461014867, 9.602592028677464, 12.014789041131735, 15.507439076900482, 13.60521649941802, 16.71265460550785, 13.524619974195957, 8.439208455383778, 1.1478301766328514, 1.291239825077355, 2.134097060188651, 12.466381508857012, 36.73165239393711, 37.30697952210903, 29.119190275669098, 23.363874703645706, 36.91109776496887, 42.0192776620388, 33.57512757182121, 6.82775910012424, 0.3860493691172451, 0.4428760026348755, 0.14307667646789923, 0.14034229272510856, 0.12529458064818755, 0.15474439569516107, 0.06114289390097838, 0.2518939459696412, 0.16896296554477885, 0.22545303509104997, 0.06667265479336493, 0.12427671768818982, 0.0973974795488175, 0.21515678992727771, 0.19325620494782925, 0.19652760674944147, 0.07305673527298495, 0.17520744062494487, 0.20097140892175958, 0.11111763786175288, 0.13068793108686805, 0.1085498662723694, 0.11130399114335887, 0.22899278264958411, 0.2033194899559021, 0.16644907387671992, 0.13343350641662255, 0.1103522906487342, 0.19716618029633537, 0.13003758707782254, 0.17434334324207157, 0.14548445586115122, 0.11593530434765853, 0.13826948910718784, 0.14635374827776104, 0.1194073903025128, 0.24438059132080525, 0.28766012052074075, 0.08751383880735375, 0.18422735505737364], [0.025374151518917643, 0.04371161499875598, 0.07860259705921635, 0.02906461071688682, 0.06267226359341294, 0.006500950648842263, 0.0392787186865462, 0.042772608940140344, 0.04835133673623204, 0.0642119676922448, 0.044958523285458796, 0.009489484255027492, 0.011511112152220448, 0.005526003305931226, 0.06196759808517527, 0.02423621463094605, 0.08029584409086965, 0.01449304110792582, 0.04362198582384735, 0.033250731794396415, 0.019285163798485883, 0.019557788036763668, 0.01755123223119881, 0.03153177305648569, 0.03208963062206749, 0.04440214630449191, 0.02749538398347795, 0.026526179935899563, 0.07114766427548602, 0.04251795580785256, 0.03732863660843577, 0.045104744931450114, 0.03330465253384318, 0.08652049640659243, 0.09315609815530479, 0.02187365615100134, 0.02529045581468381, 0.13656136201461777, 0.06465439160820097, 0.023828011144360062, 0.017171838917420246, 0.03408598560781684, 0.036672596615972, 0.0471976310655009, 0.033507685584481806, 0.02960437472211197, 0.02016645117691951, 0.05078973343188409, 0.13568706752266735, 1.4650388178415596, 14.620599914342165, 34.11136619746685, 43.17796468734741, 31.0543542355299, 26.790177449584007, 23.851057961583138, 21.61098886281252, 31.73942707479, 23.81918527185917, 14.531540293246508, 3.329335986636579, 0.581450677709654, 0.4255217401077971, 1.9456775207072496, 3.483530762605369, 5.2099845092743635, 4.2844838462769985, 4.196213632822037, 3.0233965907245874, 0.9518844285048544, 0.8885041263420135, 0.22761924541555345, 0.013363355974433944, 0.12198402313515544, 0.2717752510216087, 0.02391450288996566, 0.2124410044052638, 0.36198131216224283, 0.13423450640402734, 0.17539428372401744, 0.3554306417936459, 4.2324242647737265, 16.059648245573044, 22.689494490623474, 36.99535444378853, 36.782421469688416, 33.35045322775841, 19.56811398267746, 22.807369865477085, 30.709163658320904, 37.86891616880894, 26.757512502372265, 42.854142263531685, 41.06137566268444, 31.063798628747463, 29.364318922162056, 28.977334387600422, 23.302158415317535, 18.686050213873386, 14.441957250237465, 8.334502223879099, 3.0315827764570713, 0.6441480258945376, 0.09327015141025186, 0.07560789759736508, 0.12659482337767258, 0.8577260747551918, 1.4837186154909432, 2.110125571489334, 4.065493522211909, 1.3501960365101695, 6.515007857233286, 4.992478480562568, 5.530946161597967, 4.898746060207486, 5.726483194157481, 6.962145064026117, 3.185675907880068, 2.533398396335542, 2.5348741421476007, 0.9729279368184507, 3.035048902966082, 0.3938471444416791, 0.7912786246743053, 1.6286164778284729, 4.617865132167935, 19.127179943025112, 38.72562199831009, 18.73718596994877, 21.726920641958714, 23.036222085356712, 27.006838023662567, 33.401773273944855, 20.44244136661291, 2.3065529437735677, 0.038349145324900746, 0.06545587399159558, 0.06242002986255102, 0.07417634667945094, 0.04899539846519474, 0.05968934572592843, 0.04670061847718898, 0.033183103587361984, 0.03944696727558039, 0.10917778257862665, 0.05640953910187818, 0.01030210256431019, 0.02512472310627345, 0.036697978066513315, 0.024342150645679794, 0.04339725608588196, 0.03385829841136001, 0.04164968755503651, 0.02617540754727088, 0.13587477151304483, 0.01575998088810593, 0.0371001627354417, 0.03605322242947295, 0.031879424714134075, 0.01615649183804635, 0.12146576656959951, 0.020888295548502356, 0.07628320003277622, 0.06539417925523594, 0.02684436462004669, 0.032374385264120065, 0.015018049361970043, 0.0196352645434672, 0.0478764178842539, 0.09777039391337894, 0.013453769042826025, 0.01930330374307232, 0.04862097011937294, 0.07614564296090975, 0.04060729290358722, 0.10192107001785189, 0.02754357163212262, 0.052443338645389304, 0.04269707314961124, 0.044408558460418135, 0.04925387736875564, 0.0468312809971394, 0.05257573408016469, 0.035098108055535704, 0.056433562422171235, 0.08982651939732023, 0.022805253720434848, 0.04076640936546028, 0.07711038299021311, 0.0768093233637046, 0.0628779646649491, 0.0102719787901151, 0.07393307809252292, 0.015202564900391735, 0.036941710495739244, 0.0487446304759942, 0.032086402279674076, 0.006897361872688634, 0.02094686027703574, 0.030858980935590807, 0.03474411103525199, 0.0644587614806369, 0.04326561022025999, 0.02888284947403008, 0.047000780105008744, 0.06833991181338206, 0.074461880576564, 0.09758316489751451, 0.10001875998568721, 0.07179400068707764, 0.07194351375801489, 0.05583944723184686, 0.11973987246165052, 0.13641294732224196, 0.07989970792550594, 0.0022781097277402296, 0.05407403747085482, 0.03424785172683187, 0.05240915903414134, 0.03532422932039481, 0.07333322981139645, 0.08945874069468118, 0.026111183942703065, 0.0707243506622035, 0.30589724192395806, 3.754101418890059, 24.304554127156734, 42.198510244488716, 44.664235934615135, 29.330120757222176, 27.991792671382427, 26.677388101816177, 32.288672402501106, 40.13066500425339, 30.27914073318243, 14.343886412680149, 3.304468458518386, 0.16295502777211368, 0.13016347016673535, 0.6413326738402247, 1.0405988618731499, 1.8962832586839795, 3.598667196929455, 5.612671701237559, 2.780855605378747, 4.439213918522, 1.7275472567416728, 1.1470234324224293, 0.7272666064091027, 0.5911636096425354, 1.2386455410160124, 0.06164381389680784, 1.1786202806979418, 1.1327470047399402, 0.7719092234037817, 0.8397336839698255, 0.629801539471373, 8.464761134237051, 23.52883905172348, 32.301998287439346, 47.370693907141685, 43.30284498631954, 41.17902494966984, 28.90341315418482, 31.48151971399784, 41.36946313083172, 40.04879839718342, 35.003892704844475, 49.054774940013885, 51.05475962162018, 38.8371080160141, 34.702724665403366, 33.59341599047184, 29.166854918003082, 22.86029152572155, 19.045571722090244, 10.396092999726534, 5.250584855675697, 1.5058295102789998, 0.11760125518776476, 0.7921035366598517, 0.7898738875519484, 2.9163525346666574, 3.717579203657806, 3.7726387241855264, 5.688742194324732, 3.963620513677597, 6.868783598765731, 5.3317641746252775, 8.992420770227909, 8.04329914972186, 7.761377077549696, 9.282233119010925, 6.21615294367075, 4.0942527540028095, 2.229736503213644, 1.1038686730898917, 1.0335982125252485, 0.1452326006256044, 0.13279876235174015, 0.7625874329824001, 5.4500974249094725, 16.39136664569378, 41.685438975691795, 38.155318200588226, 20.64242273569107, 15.608368311077356, 21.197643242776394, 38.014273568987846, 26.156099773943424, 4.499363265931606, 0.09193094592774287, 0.09220534760970622, 0.08521886586095206, 0.014454488391493214, 0.03853267102385871, 0.02243301656562835, 0.045790010699420236, 0.02799963993311394, 0.05479774648847524, 0.04779786897415761, 0.10216660215519369, 0.06149491680844221, 0.04722384372144006, 0.1195744848519098, 0.04512645646173041, 0.07641134667210281, 0.06891508368426003, 0.07141278911149129, 0.02568399446317926, 0.06077371253923047, 0.034762100694933906, 0.0653869062080048, 0.011372198805474909, 0.036307619520812295, 0.038875387399457395, 0.02573553290858399, 0.024692974984645844, 0.04707481675723102, 0.04500594281125814, 0.050235864910064265, 0.048139338541659527, 0.04406221669341903, 0.03481093772279564, 0.09188969735987484, 0.02053757696558023, 0.05337368755135685, 0.0380404156021541, 0.020252375179552473, 0.0223338767682435, 0.12653963727643713, 0.03948697274609003, 0.14632139063905925, 0.11382479962776415, 0.12352624311461113, 0.10462043923325837, 0.17123536235885695, 0.09959288596292026, 0.2205123205203563, 0.1917870790930465, 0.20298831397667527, 0.2144871500786394, 0.131448216852732, 0.13617646938655525, 0.2469570015091449, 0.14430444105528295, 0.18348246143432334, 0.0940644794900436, 0.15625616535544395, 0.06761837357771583, 0.13446693221339956, 0.13981800992041826, 0.08183300262317061, 0.14870019658701494, 0.10590930483886041, 0.09853219366050325, 0.12866483652032912, 0.2003832717309706, 0.09128475052420981, 0.12476676522055641, 0.11855711170937866, 0.16459024627692997, 0.16419407300418243, 0.17935839132405818, 0.16382904024794698, 0.26554964133538306, 0.17582694097654894, 0.1543897233204916, 0.11947129663894884, 0.2553450217237696, 0.3064667957369238, 0.1359155451063998, 0.1654057329869829, 0.16825393249746412, 0.11564897635253146, 0.2140068617882207, 0.18174200638895854, 0.16934144601691514, 0.1212529483018443, 0.23309219861403108, 0.30102527991402894, 2.7828934835270047, 23.55204440653324, 49.892656579613686, 57.01266132295132, 43.96749012172222, 39.65294323861599, 33.63406240940094, 32.98666834831238, 41.58558793365955, 30.953942723572254, 19.059834256768227, 4.49617238715291, 0.7672456267755479, 1.2672661989927292, 4.582390710711479, 10.280372109264135, 14.359395280480385, 10.340160001069307, 12.372186463326216, 9.42589771002531, 2.9679461661726236, 2.531459075398743, 0.7987192191649228, 0.40117656521033496, 0.31234374444466084, 0.8720671583432704, 0.1046105167188216, 0.6777223118115216, 0.6488489673938602, 0.37844030710402876, 0.5381212464999408, 0.4903245612513274, 5.725743183866143, 22.475689463317394, 30.993149019777775, 44.54358100891113, 44.87604796886444, 41.18387348949909, 25.409363843500614, 31.17233220487833, 46.055508479475975, 46.733213514089584, 39.01760973036289, 57.13985949754715, 47.52886801958084, 34.56182822585106, 31.88201442360878, 32.43435278534889, 25.151897259056568, 20.573775619268417, 16.037917211651802, 8.359094504266977, 3.5384793765842915, 0.9312472015153617, 0.12239294650498778, 0.46178417396731675, 0.4307245515519753, 2.929694331251085, 4.943711897358298, 5.607493054121733, 11.250183619558811, 5.623199036344886, 12.883257139474154, 9.833478089421988, 11.423241533339024, 12.545516062527895, 13.055549394339323, 17.777361273765564, 11.098885238170624, 9.95489677414298, 8.368772584944963, 6.350477635860443, 6.226200554519892, 1.6042416170239449, 1.1730683036148548, 1.9371653837151825, 5.552396010607481, 24.52121090143919, 47.93577678501606, 28.868447430431843, 29.277400486171246, 32.39717558026314, 37.42064282298088, 46.75431378185749, 29.951343722641468, 3.9052394963800907, 0.10696199678932317, 0.25337928032968193, 0.1722296472871676, 0.2289240894606337, 0.19628818990895525, 0.19916267629014328, 0.14682704553706571, 0.09569472560542636, 0.21907253918470815, 0.25580648914910853, 0.194287033227738, 0.17324828950222582, 0.10458152843057178, 0.24461715831421316, 0.19742845528526232, 0.19032675510970876, 0.10227816179394722, 0.1860267811571248, 0.15182769595412537, 0.14619052031775936, 0.129425092600286, 0.14358577493112534, 0.10282819712301716, 0.16629090736387298, 0.11786163770011626, 0.39151237753685564, 0.10017035849159583, 0.16101493500173092, 0.1499218904064037, 0.172239963139873, 0.11540886189322919, 0.0877945932734292, 0.0869816224440001, 0.17274719139095396, 0.31621404457837343, 0.16039080364862457, 0.07227081572636962, 0.15745120123028755, 0.11296569689875469, 0.1979929328081198, 0.11027264336007647], [0.026237862984999083, 0.026291618596587796, 0.018484260290279053, 0.054127338516991585, 0.04303900284867268, 0.027491385662870016, 0.03026339443749748, 0.021077700912428554, 0.030105597143119667, 0.0730104252579622, 0.028129352504038252, 0.043465325870784, 0.08253017615061253, 0.018800418911268935, 0.06392347262590192, 0.0626846426166594, 0.023274777158803772, 0.04279300686903298, 0.0039645301603741245, 0.05526009335881099, 0.04619419916707557, 0.011644121714198263, 0.025446408872085158, 0.01323504235188011, 0.04763247765367851, 0.05105776377604343, 0.04389515182992909, 0.04969571869878564, 0.03362412113347091, 0.040564378214185126, 0.05700664514733944, 0.039835711650084704, 0.025406950735487044, 0.002519744430173887, 0.01733433957269881, 0.05400053887569811, 0.04648290945624467, 0.04494440021517221, 0.0070785372827231186, 0.068741220748052, 0.02840037370333448, 0.05142641079146415, 0.00632075765679474, 0.04417531999933999, 0.014132653268461581, 0.005148060890860506, 0.023824719719414134, 0.05507468631549273, 0.028828824833908584, 0.04348118556663394, 0.27148471504915506, 7.691453229635954, 23.79283368587494, 44.49557438492775, 37.49948099255562, 38.83267745375633, 20.074560306966305, 13.899159226566553, 20.2134732529521, 27.74526759982109, 24.831207767128944, 10.807233788073063, 3.559444514103234, 0.5129560874775052, 0.6538962246850133, 1.352370826061815, 7.201886074617505, 3.9725253358483315, 3.816246371716261, 9.284018073230982, 0.22686005802825093, 1.2374021764844656, 0.35534737282432616, 0.9949159319512546, 1.5687671955674887, 3.126666024327278, 0.6796698260586709, 1.1953630135394633, 0.3766281309071928, 0.3993115184130147, 0.33771106449421495, 1.211974653415382, 0.7185704167932272, 4.906353252008557, 5.207691332325339, 5.081424107775092, 3.5055816918611526, 0.0527892165700905, 1.4327291515655816, 6.181838884949684, 10.247346181422472, 7.2847506031394005, 6.879518972709775, 1.3715698895975947, 2.1024758694693446, 4.002497177571058, 4.368864493444562, 3.2366316486150026, 2.704170257784426, 1.290416931733489, 0.7989726180676371, 0.678535527549684, 0.21764918899862096, 0.34025648259557784, 0.7739057787694037, 1.0000405507162213, 3.008188856765628, 4.236168013885617, 1.6919065942056477, 4.040446691215038, 4.275721991434693, 7.792478408664465, 5.242450442165136, 10.72280041873455, 3.8708872022107244, 7.018662756308913, 8.811031803488731, 7.1522716619074345, 4.704214073717594, 2.0277089439332485, 0.9558899479452521, 0.030233035031415056, 0.5564215988852084, 5.367683647200465, 15.954467989504337, 31.09773650765419, 47.3506385833025, 12.66427394002676, 15.491201598197222, 23.64819634705782, 31.054553724825382, 32.92748652398586, 16.96656458079815, 1.3642159779556096, 0.1547431043582037, 0.03818874123680871, 0.04217820802296046, 0.036113024689257145, 0.0246245749440277, 0.040247922734124586, 0.027806312318716664, 0.018451657742843963, 0.02438087776681641, 0.011174876581208082, 0.07733186212135479, 0.03417450156121049, 0.029352098317758646, 0.048094638987095095, 0.029768222375423647, 0.07572917194920592, 0.017849479118012823, 0.06332101940643042, 0.03843209888145793, 0.03830540314083919, 0.04801033101102803, 0.02029521194344852, 0.03826507483609021, 0.006282813501456985, 0.030660478696518112, 0.01630448536161566, 0.02272250610985793, 0.055615960591239855, 0.02789914571621921, 0.05675924650859088, 0.0027524749839358265, 0.0516631447680993, 0.04839032546442468, 0.09350291118607856, 0.03884274774463847, 0.02349249360122485, 0.03940528455132153, 0.021122925536474213, 0.049100980104412884, 0.019692450732691213, 0.05320637035765685, 0.03366156619449612, 0.015189795321930433, 0.007287877197086345, 0.07387814432149753, 0.054630421873298474, 0.09039505646796897, 0.02373984028963605, 0.019115978248009924, 0.03250350782764144, 0.08273623345303349, 0.06269468387472443, 0.030431848972511943, 0.02097658329148544, 0.09090753170312382, 0.012733208586723777, 0.03911420681106392, 0.050294045577174984, 0.09657007394707762, 0.04212755273329094, 0.03514238087518606, 0.06434780298150145, 0.037444968256750144, 0.02546409610658884, 0.048333254308090545, 0.06430647277738899, 0.08000638423254713, 0.03534540279360954, 0.06844007948529907, 0.029056938765279483, 0.025710162590257823, 0.04341416963143274, 0.04012724952190183, 0.0452001814119285, 0.025932298522093333, 0.029682919921469875, 0.07994368759682402, 0.023827448967495002, 0.03584333935577888, 0.062208940798882395, 0.03956051958084572, 0.039633476408198476, 0.052345924341352656, 0.10831605264684185, 0.10878357599722221, 0.028273872776480857, 0.053511066507780924, 0.058484543187660165, 0.027343258552718908, 0.041053806053241715, 0.046499797026626766, 0.07112132545444183, 1.186877356376499, 15.457719694823027, 35.110568180680275, 47.287136390805244, 37.80004866421223, 34.613524451851845, 19.43976826965809, 20.055960305035114, 28.917179815471172, 37.540811374783516, 31.0973584279418, 11.540017817169428, 2.094526458531618, 0.275740071083419, 0.46513330831658095, 0.5732709041330963, 0.5073456291574985, 1.3930246070958674, 1.0550593421794474, 2.28914940264076, 2.3753138165920973, 2.3092101886868477, 4.850410278886557, 3.364305035211146, 2.9787117009982467, 4.268196020275354, 2.9287857050076127, 3.8273762119933963, 3.890930889174342, 3.644896703772247, 1.0032362979836762, 1.449834646191448, 1.3266363507136703, 10.271846316754818, 8.93386971205473, 8.769169449806213, 5.9110326413065195, 0.5568594066426158, 3.2370691001415253, 12.839362844824791, 17.937110401690006, 13.349412325769663, 13.093087580054998, 4.077113773673773, 3.8698553200811148, 6.58887779340148, 6.989613315090537, 5.745671214535832, 4.147264659404755, 2.149297194555402, 2.1137626888230443, 1.37904551345855, 1.780119810719043, 2.5230881245806813, 2.62134135235101, 4.13916539400816, 4.4520743284374475, 5.908549949526787, 4.726825235411525, 6.6052686888724566, 5.952857946977019, 4.647994665428996, 5.45690000988543, 4.748115967959166, 6.568759297952056, 4.681834699586034, 4.121675407513976, 0.7231443026103079, 0.4822853207588196, 0.16568917402764782, 0.13882313127396628, 0.163594699697569, 0.4499671049416065, 3.656677259132266, 17.066246531903744, 30.63114244490862, 52.931642308831215, 27.751978039741516, 11.89296567812562, 18.685605637729168, 29.100757464766502, 37.10494816303253, 23.701142705976963, 3.491492522880435, 0.00983384170467616, 0.019291177050035913, 0.07644565615919419, 0.0430059772770619, 0.11536532008904032, 0.05913989669352304, 0.024633211687614676, 0.022928476209926885, 0.07685616030357778, 0.03488441405352205, 0.03221711303922348, 0.03729484662471805, 0.0260305495976354, 0.07322454228415154, 0.016264544829027727, 0.04262607930286322, 0.045707728786510415, 0.04368532441731077, 0.017263297486351803, 0.02884442848881008, 0.03190142197126988, 0.016515702445758507, 0.07337917617405765, 0.07188906238297932, 0.048351214281865396, 0.025259764297516085, 0.034980963755515404, 0.023781678864907008, 0.01027764879836468, 0.07155966755817644, 0.023352138632617425, 0.024342601500393357, 0.06504062752355821, 0.046343415378942154, 0.034141156866098754, 0.015967767394613475, 0.05364460856071673, 0.09839429520070553, 0.06281839247094467, 0.03625669705797918, 0.06010131190123502, 0.08228243241319433, 0.0953400309663266, 0.13981343829073012, 0.17314790660748258, 0.1616686038323678, 0.11865832580951974, 0.11088453669799492, 0.06849113924545236, 0.08940897969296202, 0.1471922712516971, 0.17268292140215635, 0.11967399201239459, 0.2099532214924693, 0.3259163489565253, 0.13543693406973034, 0.24509299371857196, 0.1985301438253373, 0.137717924953904, 0.1083851614384912, 0.11525859183166176, 0.15657227573683485, 0.1743206483661197, 0.19913410360459238, 0.11571773633477278, 0.10662276850780472, 0.1543075527297333, 0.11800004824181087, 0.23743147670757025, 0.11313873605104163, 0.187743992137257, 0.2561184286605567, 0.1395831350237131, 0.19385381194297224, 0.13059614226222038, 0.18365999800153077, 0.2129505926859565, 0.10560249356785789, 0.12771567417075858, 0.17598075850401074, 0.1146866928320378, 0.19642398809082806, 0.14726322056958452, 0.16040585440350696, 0.14605252537876368, 0.15125941863516346, 0.12666802882449701, 0.10756197123555467, 0.09838559722993523, 0.11250322757405229, 0.1357318041846156, 0.2150014287326485, 0.7261667435523123, 13.890713229775429, 36.98875419795513, 60.354357808828354, 50.060147792100906, 51.939561143517494, 30.67001435905695, 23.128414638340473, 28.48569966852665, 36.547366082668304, 33.5362708568573, 14.103117082268, 4.316982077434659, 0.7636362360790372, 1.7061914526857436, 4.072754457592964, 14.406973477452993, 12.391750663518906, 7.414592960849404, 21.243879161775112, 5.400097807869315, 3.921956936828792, 3.4803807316347957, 2.4253386072814465, 3.8674854347482324, 6.166073530912399, 3.802806017920375, 3.2868231553584337, 1.5082698105834424, 1.9430577987805009, 1.0584039939567447, 5.073040807619691, 4.054955737665296, 14.664035383611917, 8.021293580532074, 6.710509741678834, 4.323597522452474, 0.3024045762140304, 2.5933413673192263, 10.340629275888205, 15.353397242724895, 12.09207309409976, 10.365114212036133, 2.551846168935299, 2.637219512835145, 4.876029454171658, 5.109900254756212, 3.365087080746889, 3.8110038405284286, 1.8079771846532822, 1.618183187674731, 1.2339207320474088, 1.1580085242167115, 1.7566184280440211, 2.7812448469921947, 3.8398625794798136, 8.470124546438456, 9.332066494971514, 6.8686567805707455, 14.3592575378716, 9.584425203502178, 19.154538474977016, 11.980860661715269, 20.203945264220238, 10.326075106859207, 17.592782378196716, 25.123980157077312, 13.795826621353626, 8.775585405528545, 4.07141930423677, 2.3046171851456165, 0.32719685055781156, 1.1788730858825147, 7.437309566885233, 20.390576049685478, 38.66109386086464, 57.22534351050854, 21.445177160203457, 23.039370216429234, 33.134203031659126, 40.74768349528313, 45.36401018500328, 24.312142319977283, 2.6609784504398704, 0.3592219774145633, 0.126048335514497, 0.14243229932617396, 0.12452896626200527, 0.21340178878745064, 0.14053280203370377, 0.1415797497611493, 0.13060475117526948, 0.26590649562422186, 0.10119101192685775, 0.18158324615797028, 0.15415272588143125, 0.12945446680532768, 0.1367375033441931, 0.11989310369244777, 0.15382803627289832, 0.2019312433549203, 0.1635519668343477, 0.15285997884348035, 0.11261352556175552, 0.09894891700241715, 0.14306641998700798, 0.236422497255262, 0.10277362700435333, 0.11401726078474894, 0.10516367648961022, 0.1287843074533157, 0.20819921483052894, 0.14406020025489852, 0.1759873636183329, 0.04520417787716724, 0.1349860496702604, 0.27006623335182667, 0.17379278840962797, 0.07704426505370066, 0.0919137206801679, 0.2598483144538477, 0.14855809014989063, 0.12188286840682849, 0.08964948749053292, 0.30136289773508906, 0.17519194458145648], [0.004046170579385944, 0.028410225713741966, 0.07621747543453239, 0.0569238363095792, 0.041694702522363514, 0.030276053621491883, 0.009733405931910966, 0.045986256809555925, 0.04712672998721246, 0.06881980676553212, 0.08125725187710486, 0.03788135480135679, 0.034625126208993606, 0.04030588817840908, 0.07742251546005718, 0.09107970996410586, 0.006178864587127464, 0.09261420418624766, 0.043793195582111366, 0.05614382796920836, 0.02069612568448065, 0.023130635381676257, 0.03070706701691961, 0.0630254739371594, 0.01658132314332761, 0.08321646979311481, 0.03394972358364612, 0.03681594615045469, 0.012969526960660005, 0.02662944607436657, 0.062303156446432695, 0.014172396204230608, 0.023135555820772424, 0.03962549089919776, 0.05433509162685368, 0.04139668570132926, 0.02173176864744164, 0.02337679463380482, 0.019019172505068127, 0.06959926962736063, 0.05746908107539639, 0.028743674520228524, 0.048945348025881685, 0.016042060087784193, 0.044257742920308374, 0.04587823721522, 0.04709292887127958, 0.037350407510530204, 0.030078007803240325, 0.03462019834842067, 0.03797986377321649, 0.12538525625132024, 4.492066707462072, 20.81512536853552, 41.64607688784599, 42.857109904289246, 37.99409665167332, 20.226880833506584, 21.46171387284994, 17.253386490046978, 24.941158667206764, 31.210753843188286, 25.94787284731865, 13.411231208592653, 5.624617785215378, 1.1166535620577633, 0.11582995648495853, 1.3419031002558768, 0.3074471728177741, 2.9866126645356417, 1.0539328213781118, 3.12763758469373, 8.961388785392046, 4.4262950867414474, 3.608744256198406, 4.322210596874356, 2.8051526891067624, 7.354253623634577, 6.999617228284478, 7.586854817345738, 0.570398080162704, 1.3106228224933147, 3.210999174043536, 4.025207133963704, 0.9702250943519175, 1.7381998663768172, 0.37416915816720575, 0.07701615992118604, 0.010896160238189623, 0.20994930295273662, 0.37210465176030993, 0.12185698971734382, 0.05530540889594704, 0.127328495727852, 0.18935788131784648, 0.027812672524305526, 0.4936702223494649, 0.7299677864648402, 0.16100862674647942, 0.18449638359015808, 1.312590166926384, 0.6862473324872553, 1.5888918656855822, 2.2609544405713677, 2.8604976693168283, 4.867966286838055, 4.191535608842969, 4.047003239393234, 4.053847147151828, 2.5682418141514063, 5.846355361863971, 2.4466272024437785, 2.129710908047855, 4.7155417408794165, 5.935393134132028, 2.334213084541261, 2.4718236504122615, 0.9064785274676979, 0.3968672698829323, 0.613403816241771, 1.1068796552717686, 5.356904100626707, 18.288716934621334, 32.22424305975437, 37.146240547299385, 51.22078411281109, 12.717327643185854, 14.149859324097633, 27.80048243701458, 37.72114209830761, 33.519973531365395, 13.107969481498003, 0.6670359196141362, 0.14788793079787865, 0.09947814251063392, 0.03982679845648818, 0.04799817834282294, 0.03362347917573061, 0.011917237625311827, 0.0750814848288428, 0.0539513419062132, 0.021593688361463137, 0.1447049484704621, 0.027044540402130224, 0.007708663333687582, 0.04248706391081214, 0.02699181823118124, 0.032002836451283656, 0.04831134239793755, 0.042848441589740105, 0.020314574576332234, 0.03185151254001539, 0.053689504784415476, 0.03977175336331129, 0.0446236439893255, 0.009016025578603148, 0.048514330919715576, 0.0818372996582184, 0.0252018637911533, 0.012365298152872128, 0.0735508868820034, 0.03627493162639439, 0.014261016985983588, 0.011643937104963697, 0.060547238754224963, 0.03172789671225473, 0.04582525529258419, 0.04219384507450741, 0.006266513619266334, 0.07889874366810545, 0.039180781168397516, 0.036146510392427444, 0.02510466285457369, 0.03269133056164719, 0.030277263322204817, 0.06815738801378757, 0.03574789545382373, 0.011571007180464221, 0.02393271519395057, 0.11335674935253337, 0.0892461599141825, 0.00977131483523408, 0.047517544953734614, 0.07963880590978079, 0.04260749963577837, 0.013205300783738494, 0.03214954420400318, 0.028657921211561188, 0.032349300672649406, 0.025316892970295157, 0.015313786861952394, 0.009173152157018194, 0.018977755098603666, 0.037163950328249484, 0.05081111470644828, 0.04212906300381292, 0.05648875594488345, 0.06283314636675641, 0.05579186814429704, 0.03771493189560715, 0.007073939677866292, 0.037070940670673735, 0.03404443275940139, 0.04445974438567646, 0.016292291875288356, 0.05387439603509847, 0.014172999199217884, 0.03401938527531456, 0.07022853664238937, 0.1323502231389284, 0.02933448715339182, 0.01980629804165801, 0.042800621304195374, 0.05900741591176484, 0.049972621418419294, 0.05209039547480643, 0.07054161906125955, 0.03987437012256123, 0.023774930887157097, 0.04344951441453304, 0.027817941772809718, 0.055325866196653806, 0.10924026399152353, 0.02484139895386761, 0.04840436689846683, 0.014410517069336493, 0.18560522643383592, 0.1960953205707483, 8.767723627388477, 31.896031871438026, 48.65907557308674, 44.22923527657986, 33.07947836816311, 13.886096477508545, 16.86206068843603, 23.184577524662018, 34.71784025430679, 41.234752759337425, 28.90818379819393, 12.664609272032976, 3.322915518656373, 1.1076394957490265, 0.2975216304184869, 0.24275162169942632, 0.42714265000540763, 1.0693208081647754, 0.391690552351065, 1.6706894827075303, 1.6055720206350088, 5.292929308488965, 3.2827958464622498, 4.582438683137298, 6.917906412854791, 7.032830771058798, 11.621335353702307, 15.502988565713167, 2.086612433195114, 5.794918946921825, 6.079831458628178, 5.619783019647002, 2.4442601669579744, 2.4745552288368344, 0.9699184389319271, 0.16649581433739513, 0.20645070006139576, 0.754157347837463, 1.1391801782883704, 0.46578711073379964, 0.3133911523036659, 0.3991981182480231, 0.1507740985834971, 0.6262160756159574, 1.1572910752147436, 0.9276723058428615, 0.7397355185821652, 1.1532426299527287, 1.8072885903529823, 2.8130876133218408, 3.956710584461689, 5.08534787222743, 5.652643656358123, 6.16419168189168, 5.109251439571381, 8.032994102686644, 6.008195327594876, 5.523730348795652, 7.87321837618947, 3.7613122444599867, 1.629163648467511, 2.7227828465402126, 0.6278124055825174, 0.5054440093226731, 0.5104678741190583, 0.6482995406258851, 0.017100769000535365, 0.4157317435601726, 0.8044448588043451, 4.126802757382393, 15.164628122001886, 36.32173039019108, 42.271637320518494, 52.65488035976887, 25.814173221588135, 9.457097835838795, 20.130455307662487, 36.59089654684067, 40.45554377138615, 19.058359935879707, 1.4714770973660052, 0.08312488134833984, 0.05105735188408289, 0.004006151657449664, 0.037948537719785236, 0.0563177317235386, 0.024371025756408926, 0.024935447618190665, 0.04698469034337904, 0.013014857340749586, 0.03872883549774997, 0.060403117386158556, 0.053732846208731644, 0.019110885259578936, 0.035716183483600616, 0.017895679666253272, 0.017420170806872193, 0.00818986492959084, 0.02607055506814504, 0.08779536510701291, 0.00993184879916953, 0.030910779132682364, 0.005344198461898486, 0.07135395906516351, 0.010851176812138874, 0.02233360217360314, 0.033951452787732705, 0.03084133451920934, 0.044312335303402506, 0.03446377217187546, 0.01808841170714004, 0.049900369631359354, 0.0511128125799587, 0.025208257393387612, 0.049956383227254264, 0.04989998742530588, 0.044506195408757776, 0.04891556563961785, 0.06407919005141594, 0.012963101817149436, 0.012363734076643595, 0.02789771151583409, 0.04556515108561143, 0.03199599756044336, 0.14391932578291744, 0.18423866538796574, 0.15614836098393425, 0.23132337868446484, 0.15224264556309208, 0.1715181503095664, 0.10985951943439431, 0.17544733243994415, 0.1069458996062167, 0.1143088580283802, 0.1525039112311788, 0.06965084889088757, 0.152775997412391, 0.1367569327703677, 0.14025476382812485, 0.1544653926976025, 0.1692497165640816, 0.16958455875283107, 0.15169523743679747, 0.14977963553974405, 0.18004845507675782, 0.1686572897597216, 0.12229311279952526, 0.13679718686034903, 0.1761007192544639, 0.11806698254076764, 0.11731204023817554, 0.15532077726675197, 0.08328925963724032, 0.11868279441841878, 0.16641149151837453, 0.11291230679489672, 0.18963201582664624, 0.1952866616193205, 0.07862278347602114, 0.1475862180814147, 0.132759487896692, 0.1678575959522277, 0.2664525975706056, 0.3136507555609569, 0.19994473666884005, 0.11761066562030464, 0.14522437762934715, 0.1671969806193374, 0.158151091018226, 0.08224615623475984, 0.19324161432450637, 0.11112903725006618, 0.11920471719349734, 0.14182413899106905, 0.3172651631757617, 0.16735021927161142, 7.29722248390317, 31.917295530438423, 58.4320143610239, 55.812347531318665, 50.84069050848484, 29.174874387681484, 30.793521031737328, 27.474269941449165, 32.31291510164738, 41.294531151652336, 33.31419937312603, 17.805479764938354, 7.248911401256919, 1.7274344502948225, 0.41290137043688446, 2.535109492018819, 2.193434201180935, 7.784170154482126, 6.51782208122313, 8.136222213506699, 17.16153021901846, 12.599608059972525, 8.705969341099262, 11.486938465386629, 9.007220976054668, 16.334970071911812, 13.89438383281231, 13.745143041014671, 1.0647990508005023, 5.482163904234767, 6.900124317035079, 8.991603814065456, 2.272877488285303, 3.6380069609731436, 1.6943597188219428, 0.15923830767860636, 0.1865114481188357, 0.825672954088077, 0.810557899530977, 0.4273795732297003, 0.3042196616297588, 0.5092206504195929, 0.41297576331999153, 0.32400567492004484, 1.1632325313985348, 1.331831740681082, 0.822998135117814, 0.7758123858366162, 2.0474723959341645, 2.8043447574600577, 5.132035966962576, 7.674046363681555, 12.64634745195508, 14.590469431132078, 12.014281768351793, 12.632686235010624, 10.644955895841122, 12.044491097331047, 17.570779658854008, 8.434443511068821, 11.188720017671585, 12.71927883848548, 16.7906017228961, 10.284725725650787, 4.696551784873009, 2.3906733049079776, 1.8070313916541636, 0.9954644681420177, 1.8540381942875683, 7.483351696282625, 23.4135627374053, 41.13496631383896, 45.290799513459206, 59.88716907799244, 21.60138677805662, 22.879229709506035, 36.20963640511036, 49.642911180853844, 45.73799751698971, 18.259065225720406, 0.9147111419588327, 0.2750433428445831, 0.21348553273128346, 0.0697489533922635, 0.15880490827839822, 0.11417212474043481, 0.08537739602616057, 0.1682385997264646, 0.15049849462229759, 0.11867276058183052, 0.2646607859060168, 0.1818897679913789, 0.1714802414062433, 0.12686340662185103, 0.218183490796946, 0.13948784326203167, 0.14421391388168558, 0.10773343703476712, 0.1387501336284913, 0.15035260323202237, 0.10479537086212076, 0.1907252290402539, 0.1124930898367893, 0.18625926633831114, 0.12928730546263978, 0.19900240207789466, 0.1042573360609822, 0.21710801491281018, 0.18767721368931234, 0.11371863540261984, 0.0963684769521933, 0.15762943541631103, 0.11030357607523911, 0.1882177495281212, 0.15998994000256062, 0.216630888171494, 0.16915810585487634, 0.2222355577396229, 0.17968463944271207, 0.10604338865960017, 0.09228854236425832, 0.09180022403597832, 0.17312314856098965, 0.20223585044732317], [0.028842411702498794, 0.0892091564310249, 0.03405275594559498, 0.08147206652211025, 0.06571393358171917, 0.008532078500138596, 0.03845097169687506, 0.029303402297955472, 0.033414820645703, 0.020517813572951127, 0.06208548082213383, 0.02859145446564071, 0.008112562827591319, 0.03595492125896271, 0.01691422647127183, 0.05663488853315357, 0.0314192300720606, 0.03783675543672871, 0.025017788902914617, 0.0385658932646038, 0.07433358550770208, 0.02722648532653693, 0.024615353759145364, 0.06665349996183068, 0.08031834600842558, 0.02501511902664788, 0.033743959429557435, 0.01798067598429043, 0.01622518688236596, 0.014855669305688934, 0.07578346005175263, 0.014734516480530147, 0.052023168027517386, 0.02849441865691915, 0.021888769988436252, 0.040888485236791894, 0.05460964544909075, 0.07132219514460303, 0.018683632697502617, 0.04663306077418383, 0.04527098601101898, 0.014232913708838169, 0.030366447208507452, 0.0711783446604386, 0.03651769926364068, 0.05301228760799859, 0.01805975738534471, 0.027118020443595015, 0.03981425616075285, 0.05367963793105446, 0.022420476125262212, 0.036129377913312055, 0.0341902573563857, 0.8609817281831056, 10.599288996309042, 37.019319757819176, 39.65289384126663, 43.18203426897526, 37.36333429813385, 21.196142323315144, 21.4336371794343, 22.991297096014023, 29.445222280919552, 32.70100727677345, 29.175786338746548, 18.097013421356678, 7.941382918506861, 3.2686798414215446, 0.5778066732455045, 0.176233934762422, 0.012933434463775484, 1.6519397450610995, 3.535774159245193, 5.064913518726826, 3.3135162480175495, 2.752053625881672, 6.097753196954727, 2.756449277512729, 17.672162018716335, 17.08529680967331, 3.5322424862533808, 0.16435934929177165, 0.47310038236901164, 0.29733918083366007, 0.4610057797981426, 0.4085170291364193, 1.767006714362651, 0.3531776595627889, 0.20038235146785155, 0.09882009500870481, 0.04501083356444724, 0.17106748855439946, 0.3282236563973129, 0.3875800932291895, 0.2904938184656203, 1.0203137691132724, 0.9787890035659075, 0.7560567709151655, 0.31318409310188144, 1.102948528714478, 2.1742423810064793, 2.6539338659495115, 3.9571003010496497, 5.017182854935527, 2.1192381950095296, 4.261398185044527, 1.8853426957502961, 7.210878292098641, 3.6499162344262004, 3.33626966457814, 3.768942472524941, 1.6642032307572663, 1.3047663867473602, 0.9596355375833809, 0.5995589029043913, 0.5003118503373116, 0.47415458830073476, 0.6576265557669103, 1.9255882361903787, 5.846101250499487, 18.74494705349207, 29.922793954610825, 36.45553261041641, 29.638536907732487, 35.80330140888691, 20.906535163521767, 19.265663512051105, 34.12662997841835, 34.390183836221695, 28.509210906922817, 6.374297607690096, 0.13665044942172244, 0.012659184922085842, 0.042112709779758006, 0.03675133106298745, 0.04633282864233479, 0.014109617004578467, 0.0420211510208901, 0.01810244757507462, 0.03707874806423206, 0.04047027759952471, 0.06338007951853797, 0.05360428025596775, 0.032655369795975275, 0.00527377374964999, 0.01937687655299669, 0.01883751330751693, 0.0741943289176561, 0.07391171908238903, 0.1195519755128771, 0.010050999680970563, 0.037801280777784996, 0.05266219799523242, 0.009166524778265739, 0.06508356076665223, 0.056083357776515186, 0.062220084146247245, 0.010007517248595832, 0.05748621726525016, 0.020288753403292503, 0.05558374024985824, 0.020405144423421007, 0.07615350230480544, 0.06317693143500946, 0.030146543285809457, 0.031609594661858864, 0.008642183529445902, 0.08026033974601887, 0.0034946813366332208, 0.0052377628890099, 0.0755516353819985, 0.03946785502193961, 0.030682618817081675, 0.009169140848825919, 0.04696873416833114, 0.05908112601900939, 0.02906190373323625, 0.0742374180117622, 0.07595140064950101, 0.037168970957282, 0.03421072578930762, 0.015446476372744655, 0.03251144880778156, 0.009243752665497595, 0.03409097655094229, 0.0237590841788915, 0.029304083218448795, 0.042399694575578906, 0.05014574220695067, 0.015394802485388936, 0.022038481583877, 0.023248594188771676, 0.04334486788138747, 0.028990256796532776, 0.030337028474605177, 0.07690942424233072, 0.06078999154851772, 0.04889515657851007, 0.037416120976558886, 0.04246214259183034, 0.03419446533371229, 0.015123903740459355, 0.011904185103048803, 0.0482017346075736, 0.02761366562481271, 0.04526629934844095, 0.0399864307109965, 0.005867040572411497, 0.017261473658436444, 0.053661570345866494, 0.05684069721610285, 0.07857416538172401, 0.03747564864170272, 0.05193112316192128, 0.02899750386859523, 0.05449522483104374, 0.060089118414907716, 0.07813669159077108, 0.058145745351794176, 0.06068560847779736, 0.04769997969560791, 0.03425712486205157, 0.04756052643642761, 0.010556860524957301, 0.04459841838979628, 0.09822041742154397, 0.061540328824776225, 0.09136026405030861, 0.15964947233442217, 3.499511992558837, 19.16642803698778, 48.013224229216576, 46.715901643037796, 42.29004733264446, 34.68132421374321, 18.402843810617924, 18.28022249042988, 31.30640421062708, 41.97041988372803, 45.72537459433079, 35.318249836564064, 16.755518205463886, 6.520368894562125, 2.533254004083574, 0.24968353332951665, 0.24031987093621865, 0.15580945182591677, 0.14114081393927336, 0.6075356248766184, 1.7307406291365623, 1.2338187312707305, 1.5350979147478938, 3.641995321959257, 2.660198067314923, 12.138054426759481, 18.718473874032497, 10.13227790594101, 2.2519987961277366, 0.8006218483205885, 1.5556412748992443, 1.2862648232840002, 3.0233709421008825, 3.731658635661006, 1.5050478209741414, 1.0617754817940295, 0.5124371184501797, 0.3119945788057521, 0.4405003285501152, 1.057836280670017, 1.1125735309906304, 1.307034152559936, 2.3490249272435904, 2.9171493044123054, 1.8701197626069188, 2.879051361232996, 2.4481568578630686, 4.214891530573368, 5.181056661531329, 4.052720032632351, 6.225932193920016, 3.655912787653506, 4.4374180398881435, 5.60961714014411, 3.1463475432246923, 3.2912767538800836, 2.228064355440438, 1.3139768550172448, 1.706574757117778, 0.5100488278549165, 0.5170625983737409, 0.6141417485196143, 0.34702424600254744, 0.1253420187276788, 0.493062284658663, 1.3370711845345795, 5.740759028121829, 19.682263657450676, 37.103131860494614, 52.32188902795315, 44.43710312247276, 39.083950370550156, 30.302796363830566, 13.532311711460352, 29.86475396901369, 36.480497270822525, 37.244776859879494, 11.481160875409842, 0.5459506076294929, 0.028870804417238105, 0.04612755059497431, 0.010824480832525296, 0.02741253061685711, 0.025845253876468632, 0.06293086495134048, 0.020587892722687684, 0.016785222651378717, 0.0802604659111239, 0.024802996522339527, 0.025767348779481836, 0.011354454982210882, 0.014455782511504367, 0.034552941215224564, 0.049264820336247794, 0.03820227058895398, 0.01842283829319058, 0.025830911872617435, 0.04902498047158588, 0.01812231115764007, 0.07113821673556231, 0.06807174417190254, 0.06087672634748742, 0.04220829468977172, 0.00593265895076911, 0.016958881496975664, 0.0023011895927993464, 0.005383880634326488, 0.01476631472542067, 0.021265180403133854, 0.05243021005298942, 0.035102653710055165, 0.023289466116693802, 0.055575899459654465, 0.028540602506836876, 0.030373672016139608, 0.016799325312604196, 0.014549493498634547, 0.030408821985474788, 0.026283937368134502, 0.04295047947380226, 0.03869989544909913, 0.012637162617465947, 0.01995574803004274, 0.08227618352975696, 0.32786864263471216, 0.1642002773587592, 0.14485964173218235, 0.2623750304337591, 0.10379877785453573, 0.22929719678359106, 0.13392353168455884, 0.14976966107496992, 0.08478659452521242, 0.2494309062603861, 0.19876242120517418, 0.11724612268153578, 0.18161403044359758, 0.07986228141817264, 0.11641049408353865, 0.17972029221709818, 0.14072958991164342, 0.09432399368961342, 0.24290751724038273, 0.17711134627461433, 0.1857816200936213, 0.1115556237346027, 0.23281650559511036, 0.17298358026891947, 0.12986160902073607, 0.12169457811978646, 0.08692055111168884, 0.10734234005212784, 0.13444670126773417, 0.14111010386841372, 0.12122500644181855, 0.09555748765706085, 0.10780210053781047, 0.14461608370766044, 0.12887186603620648, 0.2020286428160034, 0.1454593415837735, 0.14149478869512677, 0.1988572083064355, 0.1913328401860781, 0.15654751769034192, 0.15389221720397472, 0.08963471133029088, 0.16155645047547296, 0.16996149555779994, 0.2124821936013177, 0.15606788248987868, 0.13366852974286303, 0.14137886522803456, 0.18458677717717364, 0.1859425028669648, 0.19439832569332793, 2.4526285054162145, 17.092075645923615, 53.745547235012054, 55.31666412949562, 56.3850262016058, 51.0246804356575, 32.348036617040634, 29.836384691298008, 33.3458136767149, 37.993933260440826, 44.17780123651028, 38.62110860645771, 23.38759683072567, 10.42767595499754, 4.515534723177552, 0.9353465284220874, 0.4789151391014457, 1.5333023923449218, 4.670053906738758, 7.702554808929563, 14.080001972615719, 10.734396446496248, 10.829620286822319, 15.000598523765802, 11.62617914378643, 29.546769931912422, 29.593942500650883, 9.912344757467508, 1.2415541661903262, 1.685178461484611, 0.9022739343345165, 1.1874222708866, 2.3713888647034764, 6.03630336932838, 1.73838225658983, 1.046225766185671, 0.4354840633459389, 0.45024983352050185, 0.6603956571780145, 0.8752340509090573, 1.3442322565242648, 1.1854641884565353, 2.8756598057225347, 3.1353354966267943, 2.704608659259975, 2.600943809375167, 2.973885484971106, 6.167367836460471, 9.072498623281717, 12.06208985298872, 12.729253303259611, 11.923206355422735, 14.957829918712378, 11.730970870703459, 17.018224708735943, 12.0875408872962, 10.604451969265938, 10.54959336295724, 6.40740760602057, 4.650778966024518, 2.7002241695299745, 3.425765549764037, 1.3252767361700535, 1.0420746076852083, 1.0122618824243546, 2.8276622062548995, 9.15215564891696, 24.788908436894417, 39.90846432745457, 47.598655074834824, 39.57383148372173, 45.261316895484924, 31.451503224670887, 27.365645170211792, 42.679773420095444, 46.914957761764526, 39.38783526420593, 10.567764937877655, 0.44401181512512267, 0.22383074479876086, 0.12984027969650924, 0.11753734885132872, 0.1478655921528116, 0.08948890899773687, 0.14044564421055838, 0.18282981676748022, 0.2268896548775956, 0.22201686166226864, 0.1562880480196327, 0.1470207906095311, 0.07843437444535084, 0.09554373566061258, 0.20377160632051528, 0.12076061495463364, 0.09535773860989138, 0.2598210034193471, 0.2562505012610927, 0.11457851738668978, 0.10539206501562148, 0.11928802327020094, 0.12675229227170348, 0.17139110947027802, 0.1412592755514197, 0.14552162261679769, 0.10800441741594113, 0.13114061148371547, 0.14803846803260967, 0.0996856321580708, 0.09248105547158048, 0.1911436370573938, 0.2236432337667793, 0.09380429735756479, 0.16076401487225667, 0.10990890194079839, 0.12570547813083977, 0.12868091143900529, 0.11624781531281769, 0.15049015288241208, 0.16403345740400255, 0.10771939560072497, 0.16335670778062195, 0.1082127753761597, 0.1568799404776655], [0.03916288427717518, 0.06311922203167342, 0.07103525858838111, 0.06139720935607329, 0.014302408417279366, 0.006302858910203213, 0.03290380373073276, 0.04897926417470444, 0.01942652066645678, 0.060894623238709755, 0.11628686712356284, 0.012726232398563297, 0.02288506799231982, 0.012623534930753522, 0.029606651260110084, 0.02807526663673343, 0.0302701405598782, 0.010233436278213048, 0.04170666594291106, 0.05828243411087897, 0.017798471308196895, 0.025574622304702643, 0.032231169316219166, 0.0403086489677662, 0.021506289340322837, 0.023756453265377786, 0.041814177166088484, 0.03647790530521888, 0.06500847768620588, 0.037634824475389905, 0.04562461566820275, 0.06763815923477523, 0.05753216733864974, 0.008258333618869074, 0.03296971015515737, 0.04165576945524663, 0.05516531738976482, 0.027019457666028757, 0.03856126968457829, 0.050214312941534445, 0.05030221291235648, 0.016046058408392128, 0.04067454632604495, 0.04241775102855172, 0.04906466681859456, 0.13840043364325538, 0.035376602681935765, 0.050595617285580374, 0.026432298254803754, 0.04232095270708669, 0.06346492926240899, 0.10771501692943275, 0.04079974663909525, 0.042673621283029206, 0.31337550783064216, 4.60671273060143, 20.236272029578686, 35.539755150675774, 45.16567222774029, 37.11185619235039, 26.174467988312244, 30.925225764513016, 16.6596170514822, 15.48251811414957, 25.494686365127563, 38.159269988536835, 33.804171681404114, 23.171838708221912, 18.748228177428246, 10.84178913384676, 4.108312949538231, 0.8401679887901992, 0.5044914479367435, 0.5323120707180351, 0.6167297065258026, 1.0101218847557902, 4.626621762290597, 2.343763397075236, 12.596613820642233, 20.395297296345234, 14.190710932016373, 4.698142949491739, 1.406032140366733, 2.722323783673346, 1.0762329935096204, 3.2022480061277747, 0.8818537706974894, 1.8957360880449414, 2.2774930531159043, 0.4030223161680624, 0.8250064461026341, 0.1550290093291551, 0.5900487257167697, 1.0258786892518401, 0.6786244665272534, 1.9193205912597477, 1.6175158484838903, 1.1743002687580884, 2.2601182479411364, 3.114807098172605, 2.9441188322380185, 4.221762036904693, 3.3799112727865577, 4.259662153199315, 3.3690718794241548, 2.1476447582244873, 3.113619899377227, 1.7312932619825006, 2.0734945870935917, 1.772991749458015, 0.9702564426697791, 1.4588801795616746, 0.06593591737328097, 0.8134419447742403, 0.49369940359611064, 2.791953384876251, 5.331444991752505, 13.524898309260607, 26.287540420889854, 32.859230786561966, 28.804384768009186, 23.713151961565018, 17.448699809610844, 23.714443892240524, 24.329875968396664, 20.841689743101597, 38.445527628064156, 36.10216677188873, 21.799570843577385, 1.950327402446419, 0.06387407527654432, 0.01997857278183801, 0.026196716462436598, 0.07111932165571488, 0.0395501220918959, 0.05048407991125714, 0.0763201886729803, 0.01176182448034524, 0.056933940650196746, 0.019922056380892172, 0.02419151693175081, 0.05969635531073436, 0.05575519120611716, 0.05616607755655423, 0.0891137013968546, 0.02394602746790042, 0.06394408948835917, 0.034255755599588156, 0.05124934919876978, 0.0799347076099366, 0.03350006743858103, 0.03609914281696547, 0.05565870458667632, 0.0010089658849210537, 0.03591000277083367, 0.0215759027923923, 0.045580561782117, 0.1309982081875205, 0.016749209935369436, 0.036608111404348165, 0.12185421408503316, 0.032652902154950425, 0.06367821508320048, 0.0258176626812201, 0.024319591211678926, 0.016140767584147397, 0.05160341301234439, 0.033606699216761626, 0.024627220700494945, 0.03527330685756169, 0.04709301792900078, 0.045554482712759636, 0.013404329019977013, 0.06389458081685007, 0.023350095871137455, 0.013933273439761251, 0.04016603787022177, 0.026614005691953935, 0.031662394758313894, 0.059641803745762445, 0.062339269352378324, 0.04525028380157892, 0.05710296107281465, 0.01707163784885779, 0.01799985493562417, 0.044275335530983284, 0.0559464463731274, 0.006695724987366702, 0.05170017793716397, 0.06457403185777366, 0.037126494135009125, 0.020167295369901694, 0.11063527155783959, 0.14027474244358018, 0.016324502939824015, 0.03330397346871905, 0.030917573494662065, 0.04520379938185215, 0.020662589886342175, 0.011173603797942633, 0.013232323308329796, 0.04958026278472971, 0.026219732317258604, 0.026011745430878364, 0.009338269810541533, 0.00393644126233994, 0.05867127125384286, 0.010602834718156373, 0.051920298938057385, 0.016323126255883835, 0.04102980499737896, 0.051072595597361214, 0.017599330822122283, 0.02279157593875425, 0.007934504901641048, 0.05626745863992255, 0.03626881632953882, 0.05198815721087158, 0.03157859515340533, 0.060516280063893646, 0.02699533786653774, 0.046409091737587005, 0.05104666866827756, 0.04969200053892564, 0.03827824053587392, 0.012666099883062998, 0.03425819355470594, 0.10804741745232604, 0.042764475001604296, 0.08260375267127529, 1.1627026973292232, 11.836200524121523, 29.430631063878536, 43.951698169112206, 48.353066593408585, 37.278462052345276, 24.445051588118076, 25.227615796029568, 19.941445849835873, 21.395909003913403, 38.38649779558182, 47.79454216361046, 45.824819058179855, 29.237356334924698, 20.5065743252635, 8.472210634499788, 2.8554783761501312, 0.6444461911451072, 0.34234162070788443, 0.251549530075863, 0.5725400371011347, 0.4591844306560233, 0.958716165041551, 0.49372644745744765, 2.218327377922833, 7.247179644182324, 6.902183331549168, 0.6012542056851089, 1.0737823625095189, 1.4501982391811907, 2.2140794433653355, 1.6773158521391451, 3.5182202886790037, 3.105561244301498, 2.8426889749243855, 1.3448209874331951, 1.697548816446215, 1.045202671084553, 1.857085986994207, 1.625733976252377, 3.083349298685789, 3.235782631672919, 4.180091097950935, 2.47181486338377, 3.3188131637871265, 2.8937363857403398, 3.577240859158337, 3.8431353913620114, 2.059079585596919, 2.6458015898242593, 1.6441832925193012, 2.819109340198338, 0.6196619023103267, 1.511448696255684, 0.5782271444331855, 0.37201975006610155, 0.540513158775866, 0.42196747614070773, 0.17517440021038055, 0.1503268803935498, 0.27326162438839674, 0.9654413885436952, 5.711305383592844, 12.528743762522936, 22.516088895499706, 35.11743061244488, 44.18059788644314, 35.29471769928932, 25.130441710352898, 21.49508748203516, 28.649387285113335, 21.523561254143715, 36.30436532199383, 42.98163682222366, 30.165473632514477, 4.603503327816725, 0.08807904363493435, 0.0981165464327205, 0.04401304940984119, 0.06264046256546862, 0.015552335389656946, 0.05278773598547559, 0.06404105850378983, 0.029743386403424665, 0.02502730694686761, 0.11291873379377648, 0.09066751372301951, 0.043220840161666274, 0.00984364176474628, 0.03294177571660839, 0.1270966636366211, 0.025320462700619828, 0.0742313324008137, 0.04116597796382848, 0.03906755540810991, 0.06279598703258671, 0.025560395333741326, 0.0643732215394266, 0.04618415790901054, 0.08181558441719972, 0.04606896545737982, 0.044199517724337056, 0.04444427431735676, 0.08602279733167961, 0.03498551312077325, 0.01947324813954765, 0.032330260874005035, 0.02095511110383086, 0.019222533956053667, 0.07119983725715429, 0.020083109848201275, 0.04073851945577189, 0.03798112542426679, 0.028297352473600768, 0.016376865169149823, 0.06440207624109462, 0.07564632600406185, 0.044816591253038496, 0.012466723765101051, 0.007007244721535244, 0.021228238147159573, 0.017221577654709108, 0.1297690038336441, 0.14843821845715865, 0.19833476602798328, 0.15222265210468322, 0.11178864326211624, 0.12660218548262492, 0.16249980923021212, 0.09303278289735317, 0.0972761532466393, 0.1115708526049275, 0.19262196554336697, 0.11403807060560212, 0.1772523543331772, 0.13870535243768245, 0.11650371525320224, 0.11287275032373145, 0.13839966180967167, 0.25569846213329583, 0.1500400700024329, 0.13655748800374568, 0.16263826430076733, 0.12644057540455833, 0.10874539992073551, 0.10929185809800401, 0.16565077530685812, 0.1288389740511775, 0.19604139612056315, 0.12761575140757486, 0.1425408458453603, 0.08670685710967518, 0.17169816565001383, 0.12864839052781463, 0.11012208386091515, 0.06662126848823391, 0.14012497704243287, 0.13586116052465513, 0.09633295034291223, 0.09813568642130122, 0.13505552953574806, 0.2241848679841496, 0.150535409047734, 0.168372631596867, 0.11977364018093795, 0.12744056002702564, 0.09711058009997942, 0.16826499049784616, 0.2911729726474732, 0.17734118941007182, 0.15877537080086768, 0.13455919601256028, 0.18991838092915714, 0.18963318841997534, 0.1418446222669445, 0.16161470906808972, 0.7976193563081324, 8.486907295882702, 31.7037545889616, 51.92391358315945, 61.53579041361809, 51.1907809227705, 38.08486618101597, 43.210236355662346, 27.582959309220314, 22.059530094265938, 37.36444763839245, 50.73550835251808, 45.34308470785618, 31.12801518291235, 24.951756298542023, 13.460442367941141, 5.359660852700472, 1.1732321698218584, 1.1593798943795264, 1.243048554752022, 1.9307342288084328, 4.363826438784599, 11.200151704251766, 11.112144626677036, 26.0854634642601, 37.127040177583694, 24.63299710303545, 12.247422058135271, 2.21101775765419, 8.107623048126698, 4.557247934862971, 8.817217871546745, 3.831844534724951, 7.085097441449761, 6.097779320552945, 2.097027199342847, 2.5778040010482073, 0.9428239334374666, 3.5158838890492916, 5.049244584515691, 3.904268885962665, 8.060768712311983, 6.045477502048016, 3.6943845357745886, 6.8127024080604315, 8.791314661502838, 9.467456080019474, 13.433447666466236, 10.714294575154781, 11.863015685230494, 9.595909137278795, 9.590254090726376, 11.077553182840347, 7.8618954587727785, 9.764677081257105, 7.1960467379540205, 4.692660318687558, 3.22253939229995, 0.6397540960460901, 1.3491077511571348, 0.7990508701186627, 4.215531796216965, 8.158586863428354, 17.66323059797287, 34.09129947423935, 40.00855475664139, 37.15659499168396, 32.343955636024475, 26.946945637464523, 32.22488522529602, 36.91126115620136, 30.90536803007126, 50.60572251677513, 48.90459559857845, 31.311098858714104, 3.7709843879565597, 0.1371022392413579, 0.18639626679942012, 0.10457304568262771, 0.20563151745591313, 0.19251626887125894, 0.0984126039838884, 0.14829633466433734, 0.1512072901823558, 0.15376513183582574, 0.23797584202839062, 0.14151218463666737, 0.20924553915392607, 0.25298796070273966, 0.13594417716376483, 0.2486424782546237, 0.09609109183656983, 0.1494570536306128, 0.11460567999165505, 0.1302684543770738, 0.145106005074922, 0.11947238759603351, 0.16679724503774196, 0.22289934946456924, 0.19850759737892076, 0.13200871646404266, 0.18713131954427809, 0.1410113982274197, 0.211459499259945, 0.11776028259191662, 0.08348880830453709, 0.23545736388769, 0.1899586053332314, 0.14773757167859003, 0.094909919280326, 0.16309048456605524, 0.1085449309903197, 0.2080904901959002, 0.16047677403548732, 0.11699627866619267, 0.16016302368370816, 0.1299733913037926, 0.15340085607022047, 0.1152609741257038, 0.16390018252423033, 0.10413996540592052, 0.13522809371352196], [0.042289296397939324, 0.02913845812145155, 0.05026016653573606, 0.06901272805407643, 0.026922772522084415, 0.05299176351400092, 0.014210785648174351, 0.020564656078931876, 0.04297782761568669, 0.06406771644833498, 0.05792339790787082, 0.03170102725562174, 0.07880225704866461, 0.04046473746711854, 0.01847802624979522, 0.06531066537718289, 0.0660329828679096, 0.05858005017216783, 0.07026992621831596, 0.055683002501609735, 0.014843894205114339, 0.06213296714122407, 0.08792389766313136, 0.04152788627834525, 0.03383164788829163, 0.05559840508794878, 0.060921648546354845, 0.04207863035844639, 0.02174668581574224, 0.016264324040093925, 0.0555386213818565, 0.01752154632413294, 0.040967635286506265, 0.03896298680047039, 0.037563307414529845, 0.04539767433016095, 0.03145881251839455, 0.030513843303197064, 0.04591951546899509, 0.05502633910509758, 0.014476363194262376, 0.0643579258758109, 0.014664166446891613, 0.048318518965970725, 0.0462134245026391, 0.0024029359519772697, 0.02885593734390568, 0.014997526195656974, 0.03463307089987211, 0.009335560971521772, 0.026429168246977497, 0.03748362301848829, 0.042456108931219205, 0.14435786084504798, 0.09768098738277331, 0.04276221887266729, 1.4009991916827857, 12.876722440123558, 31.747843623161316, 46.35220415890217, 40.636881440877914, 37.62370012700558, 22.978687472641468, 19.706523455679417, 24.858093224465847, 14.348769150674343, 21.67934149503708, 31.56904611736536, 30.19011151045561, 33.950311839580536, 33.24418053030968, 27.001829892396927, 16.003103479743004, 10.56477639824152, 2.8740629414096475, 0.4944042657734826, 0.2008765476057306, 0.08125738546368666, 1.3336796290241182, 6.022782269865274, 10.387581456452608, 1.30016032140702, 0.7580955990124494, 1.4231700520031154, 2.373765162192285, 1.814121336210519, 2.333181439898908, 1.7897160770371556, 1.140089042019099, 1.0540778073482215, 1.0493518109433353, 0.31795022485312074, 1.9542303867638111, 0.7241532078478485, 2.5621163053438067, 1.8753474508412182, 4.678233917802572, 2.924595004878938, 2.9951467690989375, 1.3754919916391373, 3.5242313286289573, 1.6605429584160447, 0.5647061043418944, 2.3180701257660985, 0.8128850965294987, 1.1709470674395561, 1.69946106383577, 1.07365305069834, 0.35055378160905093, 0.6031284551136196, 0.2028637519106269, 2.332053850404918, 5.541153838858008, 10.57689679786563, 18.129210993647575, 28.217576555907726, 27.311195991933346, 50.27689956128597, 58.53135623037815, 15.024845022708178, 20.080016814172268, 21.920320764183998, 26.41326617449522, 32.36204646527767, 32.890202924609184, 42.16390550136566, 27.098502404987812, 11.099488455802202, 0.5576264904811978, 0.0938042082998436, 0.08203730845707469, 0.048924014990916476, 0.047231717908289284, 0.021775924578832928, 0.01588659313711105, 0.0037895751074756845, 0.020537172495096456, 0.04140250413911417, 0.024288122294819914, 0.027309388788125943, 0.0325007507490227, 0.013209555145294871, 0.03530303729348816, 0.08039439388085157, 0.062190234966692515, 0.02056281555269379, 0.02202240480983164, 0.05520486272871494, 0.012090293475921499, 0.03423138718062546, 0.004014866326542688, 0.025316583123640157, 0.030602273909607902, 0.04288320749765262, 0.05823178253194783, 0.02343895692320075, 0.040759704061201774, 0.019599728657340165, 0.031201665769913234, 0.03042886182811344, 0.0667122780578211, 0.016936071588133927, 0.025262784838560037, 0.046718730591237545, 0.0576744407590013, 0.09181456232909113, 0.036404967031558044, 0.03725999536982272, 0.019803041868726723, 0.05421588786703069, 0.03158632462145761, 0.00995631555269938, 0.029453440438373946, 0.018515541814849712, 0.07795399709721096, 0.018125791830243543, 0.04422578975209035, 0.029440057660394814, 0.012077499777660705, 0.017485203352407552, 0.033852724882308394, 0.04346354471636005, 0.06186103310028557, 0.009384138247696683, 0.039529905989184044, 0.04220596805680543, 0.058885265825665556, 0.0017678998983683414, 0.01475433275118121, 0.028355946888041217, 0.04024290210509207, 0.01636529323150171, 0.01394825925672194, 0.0791822886094451, 0.04514895837928634, 0.05885879712877795, 0.027144860214320943, 0.036382004982442595, 0.12116501122363843, 0.022404445735446643, 0.012156203611084493, 0.035484210384311154, 0.0398568257514853, 0.018171686242567375, 0.03541607380611822, 0.03266953739512246, 0.03330000297864899, 0.1313010192825459, 0.013077103121759137, 0.017618357633182313, 0.007046549326332752, 0.03606792066420894, 0.01528466869785916, 0.04812295192095917, 0.0560996219428489, 0.04571464189211838, 0.03171725431457162, 0.051256447841296904, 0.030346084531629458, 0.04806238524906803, 0.017030953313224018, 0.0146806133670907, 0.031968074254109524, 0.050129760056734085, 0.04688745415478479, 0.04541019436146598, 0.08235376022639684, 0.022678292662021704, 0.035774698117165826, 0.08092925971141085, 0.07194556208560243, 0.14243142359191552, 3.9114704495295882, 21.360777989029884, 43.31204429268837, 51.81169420480728, 40.97454272210598, 38.89366418123245, 21.182210370898247, 16.06285147368908, 21.837329417467117, 22.79620986431837, 27.454604096710682, 42.08567909896374, 45.48146568238735, 50.54702326655388, 41.132348254323006, 23.443852812051773, 13.640014082193375, 5.981926387175918, 1.2738669198006392, 0.21614320809021592, 0.04565798633848317, 0.17414849979104474, 0.11487823372590356, 0.9159388323314488, 0.9631011297460645, 0.8669472299516201, 0.3918040415737778, 0.6588882068172097, 0.9158310131169856, 0.677032470703125, 0.1095847541000694, 1.3025983655825257, 1.703127035871148, 0.8874512265902013, 1.4071783726103604, 1.8308970797806978, 1.5131954150274396, 1.6084785084240139, 1.4551010448485613, 2.3896597092971206, 2.262713508680463, 2.198725654743612, 1.6699199052527547, 0.6105071841739118, 0.585853453958407, 0.9290751430671662, 1.0298083908855915, 1.5403956617228687, 0.1679759833496064, 0.5737951572518796, 0.2964746084762737, 0.5290158663410693, 0.19624906388344243, 0.27133444498758763, 0.14683468965813518, 1.275326160248369, 3.7664139457046986, 9.78755185380578, 16.33787501603365, 35.682327300310135, 37.27656975388527, 50.49271658062935, 64.17047023773193, 25.55763378739357, 20.974458418786526, 17.325356528162956, 19.380098171532154, 27.94196594506502, 34.06052112579346, 42.58803114295006, 36.71644560992718, 18.80485463887453, 1.7990608443506062, 0.009558396377542522, 0.07507481292122975, 0.017431991363991983, 0.01713951838610228, 0.007987047101778444, 0.013748773671977688, 0.006606054994335864, 0.054259322059806436, 0.034720959738478996, 0.016013580170692876, 0.06382056642905809, 0.008423675772064598, 0.06243112497031689, 0.04857451538555324, 0.04490545601584017, 0.07709381083259359, 0.11387817488866858, 0.08850942991557531, 0.02295844598847907, 0.041632228530943394, 0.07817644102033228, 0.051907882807427086, 0.05751305703597609, 0.08139166224282235, 0.04314804660680238, 0.02408510037639644, 0.050703503293334506, 0.017081515834433958, 0.006823706962677534, 0.06219495502591599, 0.044488970161182806, 0.01937375211127801, 0.012159485759184463, 0.078059248480713, 0.032107264050864615, 0.029523076154873706, 0.046280047099571675, 0.0849285747972317, 0.07034004433080554, 0.04409865985508077, 0.016684438996890094, 0.08138927994878031, 0.01815097846701974, 0.07836667573428713, 0.06328622010187246, 0.08320563443703577, 0.041567231237422675, 0.15743692230898887, 0.12378011699183844, 0.2082336207968183, 0.1581272087059915, 0.14212271984433755, 0.1271484061726369, 0.16097834712127224, 0.10985059881932102, 0.11856209152028896, 0.10561861301539466, 0.18403237801976502, 0.09419431822607294, 0.09922999059199356, 0.1206643509794958, 0.10685077111702412, 0.18391810212051496, 0.15048880217364058, 0.13441271090414375, 0.16109516116557643, 0.17856953287264332, 0.12028751807520166, 0.23556188796646893, 0.23513402498792857, 0.19642002502223477, 0.12444577892892994, 0.08483715704642236, 0.15411956672323868, 0.08657083628349937, 0.11776181141613051, 0.15753976913401857, 0.10183961931033991, 0.14856721856631339, 0.0976416387129575, 0.0809521104383748, 0.1610244790208526, 0.11626307386904955, 0.14617790380725637, 0.1545646326849237, 0.11818998609669507, 0.1835087186191231, 0.09791192147531547, 0.14001660863868892, 0.09027765612700023, 0.12931096513057128, 0.09842700164881535, 0.1754825992975384, 0.08492435939842835, 0.13031513546593487, 0.10939843792584725, 0.11842518011690117, 0.12655694416025653, 0.10326865434763022, 0.23776556190568954, 0.23316353384871036, 0.1641960025881417, 0.13639311713632196, 2.2322137327864766, 19.03458271175623, 44.284852892160416, 62.30160132050514, 56.0049743950367, 52.74275824427605, 35.4120934009552, 27.092236541211605, 34.194300547242165, 23.904699683189392, 30.058351680636406, 43.76687988638878, 41.07076495885849, 45.15209935605526, 43.132503926754, 34.40105885267258, 20.697572976350784, 13.47308523952961, 4.35151937417686, 1.0391982807777822, 0.42057924438267946, 0.3272519772872329, 3.311621812172234, 14.61542459204793, 18.560808934271336, 7.236899770796299, 3.1127112731337547, 6.365421758964658, 7.338351001963019, 7.727922247722745, 10.476621128618717, 7.755241356790066, 5.841559544205666, 6.654060445725918, 4.04949258081615, 3.860472198575735, 7.376391235738993, 5.802767425775528, 13.780264556407928, 9.33365860953927, 14.934496320784092, 9.870579298585653, 11.611299142241478, 7.960294503718615, 11.04854078963399, 10.635988377034664, 6.648360751569271, 7.281061476096511, 3.4291169699281454, 3.536830027587712, 3.8686522096395493, 2.898061266168952, 0.834498277399689, 0.8036296244245023, 0.47700571187306195, 3.043058873154223, 7.402990758419037, 15.158993024379015, 24.232160411775112, 36.125261932611465, 37.061645686626434, 57.00019419193268, 71.04637607932091, 20.547465831041336, 26.74276739358902, 29.896826148033142, 37.374950274825096, 44.64707985520363, 46.08985483646393, 56.067408844828606, 38.76214563846588, 17.41909559816122, 1.400017300620675, 0.09869439003523439, 0.15024454653030261, 0.145715560647659, 0.22448248404543847, 0.17400450829882175, 0.11074974783696234, 0.06338397579384036, 0.07932933775009587, 0.1689930076827295, 0.11764827024308033, 0.22600010182941332, 0.06596411156351678, 0.08971334929810837, 0.07519665130530484, 0.16909085243241861, 0.14179933641571552, 0.24442056339466944, 0.16973738180240616, 0.19637813820736483, 0.10022835733252577, 0.20961535134119913, 0.09574297262588516, 0.11642959696473554, 0.21785158751299605, 0.20939505222486332, 0.11869851310621016, 0.13929129287134856, 0.1060546915687155, 0.10974015982355922, 0.13090900203678757, 0.12320670401095413, 0.1356517116073519, 0.1156588394951541, 0.1986825215863064, 0.10499947631615214, 0.1191804044356104, 0.23862801172072068, 0.18071016878820956, 0.2160407620249316, 0.13640350720379502, 0.12565524957608432, 0.10291911763488315, 0.10596574516966939, 0.19708807667484507, 0.2775091730291024, 0.3027094207936898, 0.19034952420042828], [0.08905165042961016, 0.04128083644900471, 0.0174648091342533, 0.05200928986596409, 0.04599875086569227, 0.004729400543510565, 0.06712643356877379, 0.01230957399457111, 0.06087170200771652, 0.015618367979186587, 0.00853681154694641, 0.03363513089425396, 0.0056350707200181205, 0.07541619343101047, 0.024049694366112817, 0.02854921513062436, 0.016786181877250783, 0.01062551846189308, 0.02473996220942354, 0.0603995216806652, 0.014122488628345309, 0.07153723243391141, 0.0438545600627549, 0.13926070154411718, 0.023607793664268684, 0.036164218035992235, 0.1225323292601388, 0.050157876321463846, 0.042150210501858965, 0.0024236193758042646, 0.013401524629443884, 0.03911894171324093, 0.04762140481034294, 0.03547158274159301, 0.01614890523342183, 0.019978747186542023, 0.05048043967690319, 0.01607239722943632, 0.05205221568758134, 0.018374771243543364, 0.051096867537125945, 0.1078010318451561, 0.013486918924172642, 0.02823625887685921, 0.027175585128134117, 0.01655319945712108, 0.015730987033748534, 0.06330512260319665, 0.046770346962148324, 0.06670945047517307, 0.03200360828486737, 0.03689144112286158, 0.0310693909341353, 0.029068636868032627, 0.017097282761824317, 0.14175096323015168, 0.04494147615332622, 0.20719505933811888, 2.514681788161397, 17.101172357797623, 34.253649562597275, 46.25693567097187, 48.72236877679825, 43.64309012889862, 32.36615404486656, 25.178119651973248, 32.807770147919655, 23.796373195946217, 23.053193874657154, 24.605777263641357, 31.340879760682583, 32.9269203543663, 38.89051795005798, 34.10877473652363, 31.365527138113976, 28.196109607815742, 17.661306001245975, 9.390483610332012, 4.408117337152362, 1.9045099359937012, 0.451957099721767, 0.15561064530629665, 0.3254062560154125, 0.47721864888444543, 1.0148586868308485, 0.20677472173701972, 0.7176871423143893, 1.2945094308815897, 2.156440573744476, 0.20216368400724605, 1.0132845025509596, 1.1932107852771878, 0.9233338292688131, 0.817873397609219, 0.5385435582138598, 1.6784356045536697, 1.4114557555876672, 1.9746223487891257, 1.3073439546860754, 1.4696807437576354, 1.0648889397270977, 0.4554006946273148, 0.5770977144129574, 0.30797011975664645, 0.16654104081680998, 0.5924269231036305, 2.2697286447510123, 4.237772477790713, 7.535296808928251, 15.473955273628235, 23.58989417552948, 29.373622722923756, 34.19783055782318, 37.883499786257744, 33.886520862579346, 24.40697953104973, 16.69393301010132, 52.208924889564514, 49.3815004080534, 30.006241276860237, 30.681164860725403, 33.52734133601189, 39.165816977620125, 42.12114259600639, 37.00137332081795, 17.863867431879044, 4.367848047986627, 0.12648047326365486, 0.1385551565908827, 0.030516195911332034, 0.016024276374082547, 0.03146335446217563, 0.02269748831167817, 0.03635692410171032, 0.016137782295118086, 0.07560090656625107, 0.035955232960986905, 0.04272851423593238, 0.00912220093596261, 0.08447769039776176, 0.05958507397735957, 0.007413548773911316, 0.025534529631840996, 0.019310860661789775, 0.03698065469507128, 0.02191595485783182, 0.05801000283099711, 0.024776082536845934, 0.052019921131432056, 0.05241750077402685, 0.027420592195994686, 0.03514439951686654, 0.050959514555870555, 0.0380237284116447, 0.05797295110824052, 0.020312656124588102, 0.0025462959229116677, 0.03789581925957464, 0.06975895012146793, 0.029513940316974185, 0.038145243961480446, 0.06443659352953546, 0.09755803577718325, 0.013458757202897687, 0.02531866299250396, 0.030269192466221284, 0.02811552258208394, 0.004025025400551385, 0.0669165096769575, 0.02806141445034882, 0.040128882246790454, 0.030846266090520658, 0.10753262671642005, 0.05353339030989446, 0.07572701972094364, 0.10610120196361095, 0.04305019443563651, 0.009612277226551669, 0.05501311403349973, 0.03386367156053893, 0.0138845282526745, 0.017091579356929287, 0.051014277632930316, 0.013915582494519185, 0.007892466874181991, 0.03100043428275967, 0.023668263856961858, 0.04951012240780983, 0.03606169033446349, 0.03055870798561955, 0.04473908134968951, 0.02371387254243018, 0.014922246446076315, 0.09727508455398493, 0.03289778862381354, 0.046274135893327184, 0.05445938280900009, 0.03797834237047937, 0.047330308516393416, 0.05197028258407954, 0.03438638101215474, 0.0881282777118031, 0.059692366266972385, 0.024125246854964644, 0.03234069547033869, 0.03938137997465674, 0.06437905482016504, 0.021875426173210144, 0.05699818466382567, 0.035312774271005765, 0.05469915588037111, 0.07780650266795419, 0.02763700802461244, 0.03622507043473888, 0.12553125154227018, 0.047169462850433774, 0.054316181704052724, 0.01400359564286191, 0.01759679267706815, 0.03580561598937493, 0.0566884196450701, 0.03673551218525972, 0.036015183650306426, 0.050059953646268696, 0.046677775171701796, 0.00862084214531933, 0.05610339947452303, 0.06693705974612385, 0.05024495621910319, 0.008591693367634434, 0.026222782544209622, 0.07328735766350292, 0.06248530917218886, 1.3065204676240683, 7.162463190034032, 28.215602561831474, 43.781129121780396, 49.29539702832699, 47.000263184309006, 40.12066774070263, 30.44477004557848, 20.96951298415661, 23.520122319459915, 21.0553427785635, 23.39787907898426, 30.445890985429287, 45.23380257189274, 53.84323239326477, 52.9996320605278, 46.01184882223606, 40.68481586873531, 28.363587521016598, 16.073943078517914, 7.381972661241889, 3.6523842019960284, 0.9508529619779438, 0.3426977328490466, 0.10829495338839479, 0.1817567751277238, 0.08601873036241159, 0.301315994001925, 0.412402261281386, 0.289135331986472, 0.954000202473253, 0.7208081998396665, 0.7827570475637913, 0.9419421432539821, 0.31633528182283044, 0.24293794529512525, 0.46897914726287127, 0.20801084290724248, 0.6803667324129492, 0.38236540742218494, 0.5016189208254218, 0.4926839377731085, 0.5975298711564392, 0.08880147244781256, 0.25204570032656193, 0.2957508363761008, 0.18881776108173653, 0.23349812370724976, 0.10246808480587788, 0.8048637269530445, 3.624910251237452, 5.823654429987073, 12.3658911511302, 19.253502264618874, 31.458122469484806, 39.50786702334881, 49.321478828787804, 46.40655644237995, 38.80395099520683, 21.094279289245605, 56.42246179282665, 58.15517641603947, 19.190330654382706, 18.42568438500166, 27.882208451628685, 40.20577557384968, 47.877392917871475, 43.98432321846485, 28.113745227456093, 8.030056860297918, 0.2252944975043647, 0.061655636309296824, 0.08929142350098118, 0.01695047852990683, 0.01568908537592506, 0.009444562983844662, 0.043120108457515016, 0.02248645861982368, 0.030636887677246705, 0.07174092970672064, 0.06181284174090251, 0.016049396217567846, 0.04993969603674486, 0.059636916703311726, 0.05361678915505763, 0.019905636363546364, 0.05019466458179522, 0.03624614742875565, 0.03774040982534643, 0.02617639460368082, 0.05931787112785969, 0.05806527056847699, 0.00838775767988409, 0.013743026665906655, 0.06602738707442768, 0.03337929032568354, 0.0201561835638131, 0.0436351441021543, 0.01727435734210303, 0.0746158094261773, 0.05345422541722655, 0.03810753543803003, 0.026753163947432768, 0.02061898685496999, 0.021804183706990443, 0.07720139998127706, 0.05257189346593805, 0.05160715343663469, 0.0282096361843287, 0.02422995832603192, 0.020762436579389032, 0.032909247383940965, 0.04295020116842352, 0.032919173609116115, 0.026007055057561956, 0.08471456167171709, 0.08484911304549314, 0.06162108933494892, 0.02366055665333988, 0.1791676742141135, 0.16172330011613667, 0.08817507012281567, 0.13958458963315934, 0.15934290597215295, 0.11167695745825768, 0.15847117931116372, 0.07213578195660375, 0.1662598707480356, 0.09739253684529103, 0.13684881065273657, 0.09173147147521377, 0.1507557526929304, 0.21055410878034309, 0.21208051359280944, 0.1545671559870243, 0.20606806356227025, 0.23138267628382891, 0.25182658864650875, 0.2045973198255524, 0.20216432225424796, 0.14944851893233135, 0.11148737583425827, 0.18733128381427377, 0.10846302757272497, 0.16201609221752733, 0.21378009114414454, 0.13501726440154016, 0.15603812236804515, 0.09787275834241882, 0.10131756294867955, 0.13471501733874902, 0.10476171446498483, 0.1075224370288197, 0.1297950532170944, 0.1764876305242069, 0.13923616614192724, 0.15246626950101927, 0.12668858631514013, 0.08735841081943363, 0.13379304728005081, 0.12973278702702373, 0.14162551058689132, 0.12450185560737737, 0.12036448621074669, 0.10383612272562459, 0.1297055947361514, 0.09213629818987101, 0.12558001064462587, 0.20980550441890955, 0.14605579082854092, 0.14691496035084128, 0.11665615238598548, 0.1341790086007677, 0.15492377278860658, 0.31477424839977175, 0.20835984527366236, 1.0712476610206068, 5.068645868450403, 26.986742801964283, 46.437900960445404, 61.78561180830002, 63.366573974490166, 57.514504194259644, 47.65866905450821, 37.43708074092865, 44.242268577218056, 33.40581625699997, 31.95748597383499, 32.578349858522415, 42.42901727557182, 46.8495062738657, 49.81291405856609, 46.69632129371166, 41.636774986982346, 36.88300207257271, 23.497842215001583, 13.041953723877668, 6.494383038952947, 3.145090523175895, 0.6163746037054807, 0.4352423013187945, 1.0838823392987251, 0.8615471259690821, 2.4072031304240227, 1.163038385566324, 3.553118803538382, 3.4302725829184055, 6.409948244690895, 2.8954650554805994, 4.921355796977878, 6.599311083555222, 3.918943698517978, 4.765850091353059, 5.747931618243456, 4.852503966540098, 6.3062038365751505, 5.062096919864416, 5.364481369033456, 3.3127866871654987, 1.9783466239459813, 1.1095132702030241, 0.9675295546185225, 0.6906746292952448, 0.7174383150413632, 0.952798695070669, 3.234353670850396, 6.245744805783033, 10.12478755787015, 20.702702701091766, 29.520513340830803, 36.517370492219925, 43.899963945150375, 50.07542297244072, 43.07386927306652, 34.82502870261669, 21.721158251166344, 59.53077860176563, 60.152284651994705, 35.8339087665081, 40.730060040950775, 46.47129736840725, 52.68005020916462, 57.01586075127125, 50.51689088344574, 27.109404020011425, 6.499212104827166, 0.18761686224024743, 0.21401624253485352, 0.18310588086023927, 0.10401196719612926, 0.06750603468390182, 0.10032302569015883, 0.13847019552486017, 0.09766707211383618, 0.15148997423239052, 0.1602598442696035, 0.14449498004978523, 0.08313818805618212, 0.17484815209172666, 0.2044091557036154, 0.1350335916504264, 0.121574149816297, 0.1202191217453219, 0.08691554161487147, 0.12178465258330107, 0.1858474189066328, 0.12462445098208264, 0.12125449196901172, 0.10886383184697479, 0.11949172796448693, 0.23757646267767996, 0.12948174815392122, 0.10661527281627059, 0.15587976289680228, 0.2139074436854571, 0.14342195325298235, 0.20668682176619768, 0.2448426524642855, 0.10423465602798387, 0.16024894954171032, 0.1580563632887788, 0.24340729432879016, 0.09220316569553688, 0.19196434848709032, 0.25497967726550996, 0.1250191399594769, 0.11041002973797731, 0.1558977080276236, 0.10865914009627886, 0.05742850415117573, 0.19847792631480843, 0.17572863609530032, 0.25690522394143045, 0.1807181246113032, 0.1775295168044977], [0.03288017374870833, 0.07414105013594963, 0.03536631280439906, 0.034141271898988634, 0.036522133596008644, 0.005106944054205087, 0.007832756455172785, 0.11856632176204585, 0.05893681911402382, 0.13892850140109658, 0.0451425499340985, 0.03577387433324475, 0.04200137649604585, 0.06728588399710134, 0.023078083904692903, 0.08949322087573819, 0.05502145206264686, 0.03376608656253666, 0.04059224957018159, 0.014213594677130459, 0.0626377240405418, 0.05051956199167762, 0.02611521751532564, 0.0492887879954651, 0.028800599102396518, 0.023674332769587636, 0.028969576851523016, 0.028738167784467805, 0.05916363428696059, 0.03381391055881977, 0.031192834212561138, 0.02102590642607538, 0.037110623306944035, 0.03994760525529273, 0.019083928600593936, 0.0376388098084135, 0.06662617408437654, 0.015596986704622395, 0.056903828008216806, 0.05799887432658579, 0.010179506261920324, 0.016289326995320152, 0.04972344533598516, 0.013464870644384064, 0.025310328674095217, 0.005202785005167243, 0.010450023728481028, 0.0052141482137813, 0.05241203114564996, 0.09940060292137787, 0.06281563910306431, 0.051331501235836186, 0.05575578863499686, 0.01549858256112202, 0.028024017628922593, 0.026541581355559174, 0.056421569315716624, 0.022080164308135863, 0.04440392003743909, 0.6217975064646453, 2.940854332409799, 11.221428662538528, 30.94972874969244, 39.54143442213535, 47.24810108542442, 54.22000877559185, 43.75456854701042, 39.87779997289181, 32.469333708286285, 33.44988249242306, 26.406394243240356, 17.581711672246456, 22.175334580242634, 27.852552942931652, 21.483551301062107, 27.412595450878143, 30.589010305702686, 31.24688610434532, 36.25365324318409, 30.101517364382744, 24.995723739266396, 16.064302995800972, 9.11612218245864, 5.180680006742477, 2.4782500555738807, 1.0909056686796248, 0.44524746132083237, 0.28503407549578696, 0.1071071311889682, 0.0445865069195861, 0.03685846379084978, 0.06552789942361414, 0.12936901592183858, 0.11403311305912212, 0.0775199594500009, 0.19316829013405368, 0.24380784627282992, 0.2518751547904685, 0.4291467455914244, 1.9683919893577695, 3.681596084497869, 6.43796319141984, 8.225166890770197, 11.985023338347673, 15.368123352527618, 24.85242012888193, 27.777799554169178, 36.586040407419205, 36.73575237393379, 34.923827201128006, 28.46977472305298, 29.209739416837692, 29.88125268369913, 24.07435867935419, 25.319643057882786, 37.69670180976391, 32.27877773344517, 34.773837849497795, 39.27817314863205, 40.03371700644493, 42.676866576075554, 42.74080194532871, 35.537304282188416, 20.407475642859936, 6.75890869461, 0.3374635137151927, 0.07163402333389968, 0.05125209143443499, 0.08945499284891412, 0.056067360783345066, 0.06086518224037718, 0.0514201581972884, 0.04654135729651898, 0.013673267567355651, 0.03710475291882176, 0.02426732546155108, 0.04243130635586567, 0.08946875968831591, 0.08909070966183208, 0.048766668551252224, 0.1180771944927983, 0.059782210664707236, 0.07618729228852317, 0.08657291429699399, 0.020309804422140587, 0.039507964393123984, 0.013392436103458749, 0.025247222001780756, 0.045647926526726224, 0.02781487855827436, 0.07048113402561285, 0.05580897835898213, 0.008705603759153746, 0.04788588026713114, 0.03789034592045937, 0.0059678571597032715, 0.03402521484531462, 0.01852291876275558, 0.04170569372945465, 0.05426732241176069, 0.031885358184808865, 0.053216348533169366, 0.05426834657555446, 0.05649070779327303, 0.05617667171463836, 0.021491175502887927, 0.020170948591839988, 0.0824457494309172, 0.018203281324531417, 0.050004192380583845, 0.05696144464309327, 0.07443477734341286, 0.023817454093659762, 0.01388885497362935, 0.010295173688064096, 0.0502152517583454, 0.012893775947304675, 0.030494183811242692, 0.027342334578861482, 0.01604322525963653, 0.02927721190644661, 0.020590284293575678, 0.014426057641685475, 0.0540461772470735, 0.010345742703066207, 0.052292745749582537, 0.017896419958560728, 0.07120686539565213, 0.046702195541001856, 0.06393672738340683, 0.025651738869783003, 0.07431575912050903, 0.014510045566566987, 0.03554150418494828, 0.053655488445656374, 0.04345562971138861, 0.0071318661593977595, 0.03477630169072654, 0.046921233006287366, 0.04788294878380839, 0.04423809456056915, 0.051901581973652355, 0.027769108455686364, 0.01751486699504312, 0.007072693333611824, 0.01930112553964136, 0.058735826969495974, 0.07720927416812629, 0.02539266995881917, 0.015458877660421422, 0.043658514332491904, 0.012284720396564808, 0.03680009387608152, 0.016575410081713926, 0.05333081368007697, 0.05066753139544744, 0.03180523963237647, 0.04598118051944766, 0.049575665179872885, 0.020761553423653822, 0.017563195651746355, 0.0637345366703812, 0.030490380304399878, 0.0419213803979801, 0.015106923401617678, 0.06626380563830025, 0.01596708461875096, 0.03571504799765535, 0.03319846604426857, 0.02413465172139695, 0.07503118205931969, 0.08450086766970344, 0.00622029869191465, 0.05536038719583303, 0.03504295906168409, 2.3266524402424693, 9.513336718082428, 23.89832552522421, 44.13090795278549, 48.61943610012531, 50.59680059552193, 52.11016058921814, 44.207135662436485, 35.142760053277016, 25.007685497403145, 21.37541100382805, 24.048594161868095, 20.533340089023113, 28.001968525350094, 34.392763897776604, 34.55617792904377, 45.24996690452099, 49.80603642761707, 51.32996365427971, 44.40710373222828, 34.420266821980476, 20.26453871279955, 14.638353511691093, 6.782395709306002, 2.874004519544542, 0.71446776506491, 0.7057897432241589, 0.07852516137063503, 0.14486370870145038, 0.1402042681002058, 0.08384231550735421, 0.0820691762783099, 0.057629073271527886, 0.13918429001932964, 0.10401754814665765, 0.01734455338009866, 0.19205532094929367, 0.17034157906891778, 0.23112742201192304, 0.3825008642161265, 1.9421144993975759, 2.7094365376979113, 5.990666868165135, 8.166323248296976, 14.839308578521013, 18.992309980094433, 28.668023385107517, 33.46992641687393, 38.74493636190891, 47.64068841934204, 50.34930847585201, 47.526975721120834, 44.594099298119545, 39.12221051752567, 35.28625175356865, 27.79953058809042, 26.061534248292446, 17.386177964508533, 36.04996137320995, 43.46126988530159, 41.091667637228966, 41.66064530611038, 46.34021960198879, 44.47277560830116, 31.624709330499172, 13.632586430758238, 1.5264444728381932, 0.10857576722628437, 0.029500102973543108, 0.07873280686908402, 0.013423223172139842, 0.03746748872799799, 0.06446133673307486, 0.05695711421140004, 0.017241552559426054, 0.011680320894811302, 0.03704794522491284, 0.03598724179028068, 0.09939959360053763, 0.028332866095297504, 0.03059789894905407, 0.07080143011990003, 0.04959781828802079, 0.05770236406533513, 0.008754497375775827, 0.05791770192445256, 0.04867300951445941, 0.00760129961236089, 0.03130112469079904, 0.04258476765244268, 0.030276988727564458, 0.028751322352036368, 0.0638291085488163, 0.029152325150789693, 0.0669871324498672, 0.03742818829778116, 0.05081795359728858, 0.04881261120317504, 0.04165097518125549, 0.049752860359149054, 0.0108524106326513, 0.02619223017973127, 0.006479072599177016, 0.0173203760641627, 0.02593807799712522, 0.04785059114510659, 0.02226899450761266, 0.05406502037658356, 0.01254785720448126, 0.06348553870338947, 0.045528696791734546, 0.027542460265976842, 0.05431839330412913, 0.03980378445703536, 0.023697567557974253, 0.03987355376011692, 0.039888637911644764, 0.10744279716163874, 0.15792731865076348, 0.19933562638470903, 0.11020734178600833, 0.08117082878015935, 0.12726904969895259, 0.1570637259283103, 0.155669616360683, 0.11225438545807265, 0.18911003367975354, 0.14170870534144342, 0.14052986312890425, 0.1300460920901969, 0.13689178100321442, 0.1059553625236731, 0.17327319597825408, 0.11111328145489097, 0.148227003228385, 0.1348513350239955, 0.11510447002365254, 0.2062476336141117, 0.1052218682889361, 0.1698138378560543, 0.18789006164297462, 0.17221219197381288, 0.14191395370289683, 0.09836695448029786, 0.1662714927806519, 0.12471687805373222, 0.11497424537083134, 0.2083320147357881, 0.12368017196422443, 0.13670599175384268, 0.14614072220865637, 0.15127693332033232, 0.12099436178687029, 0.19564893358619884, 0.15040740341646597, 0.21116759773576632, 0.13500498927896842, 0.1390807455754839, 0.11693732245475985, 0.1483988549443893, 0.096723141905386, 0.10302220194716938, 0.22159242740599439, 0.1823968774988316, 0.1173406648740638, 0.1757908725994639, 0.1678980578435585, 0.17273083445616066, 0.15927449479931965, 0.11714815918821841, 0.0827298361400608, 0.16736973775550723, 0.14744264219189063, 0.22906392492586747, 0.16682494198903441, 0.16411875985795632, 1.4836137648671865, 6.456805430352688, 20.477904863655567, 44.69397313892841, 54.88089211285114, 63.23726311326027, 68.26408177614212, 58.668836653232574, 53.21441173553467, 45.107368156313896, 44.90455023944378, 37.66861371695995, 28.72777707874775, 30.77905710786581, 36.91424019634724, 29.619102850556374, 39.35966357588768, 41.72770030796528, 44.93711069226265, 47.4460818618536, 40.32845199108124, 33.10080282390118, 22.729487344622612, 13.042806778103113, 6.705328719690442, 4.096013959497213, 1.886936710216105, 0.7897109712939709, 0.408258643001318, 0.24274258234072477, 0.17506192030850798, 0.2480429268325679, 0.1891205573338084, 0.4736244276864454, 0.4195487278047949, 0.24270790920127183, 0.37191199022345245, 0.39604087360203266, 0.4972928232746199, 0.9242036263458431, 3.0172592075541615, 5.323093989863992, 8.972465191036463, 10.851652454584837, 17.13837806135416, 21.482633650302887, 33.71487647294998, 34.75829668343067, 45.21199554204941, 47.278047278523445, 45.629646331071854, 37.85372458398342, 39.21265706419945, 36.86907961964607, 34.10046838223934, 35.1406017690897, 51.19655281305313, 42.43112616240978, 47.12143488228321, 54.21434707939625, 51.245118007063866, 55.72845183312893, 58.198102712631226, 49.63228315114975, 30.517433546483517, 10.818635076284409, 1.1736704525537789, 0.15935534436721355, 0.18463615968357772, 0.14293575746705756, 0.09244646396837197, 0.11325797691824846, 0.15502884605666623, 0.15033893287181854, 0.10489358668564819, 0.17272083030547947, 0.12994538265047595, 0.10284698830218986, 0.2615509496536106, 0.0919210234133061, 0.1041431343764998, 0.2738722338108346, 0.13658310694154352, 0.18274681497132406, 0.09722835151478648, 0.21501263516256586, 0.17929992493009195, 0.05412185775639955, 0.11960189978708513, 0.14636824984336272, 0.08191630127839744, 0.08608670366811566, 0.15816706203622743, 0.114343694440322, 0.16633366991300136, 0.2349887421587482, 0.14485251711448655, 0.1863595750182867, 0.14851779153104872, 0.14836303889751434, 0.17545549606438726, 0.09772526391316205, 0.07780840998748317, 0.06153226910100784, 0.1203105914464686, 0.13674048677785322, 0.0835885752167087, 0.13183257513446733, 0.17114339541876689, 0.1717375885345973, 0.1736153260571882, 0.16920123947784305, 0.12305702024605125, 0.07712947102845646, 0.12071681339875795, 0.18025901721557602, 0.1154928062169347], [0.05028849060181528, 0.06252930368646048, 0.06641569358180277, 0.02924945187260164, 0.02318088991160039, 0.039118017739383504, 0.06203413904586341, 0.05083069256215822, 0.026635737631295342, 0.0458346583036473, 0.011686839734466048, 0.04118721823033411, 0.04103174571355339, 0.010779706135508604, 0.04432646579516586, 0.029341806584852748, 0.04067427544214297, 0.02833723177900538, 0.08278731547761708, 0.02545260951592354, 0.00970236282228143, 0.03493379284918774, 0.04656493532820605, 0.05833120063471142, 0.06874641578178853, 0.01577537117555039, 0.06274264887906611, 0.013669198742718436, 0.03717603991390206, 0.07355841968092136, 0.013632041263917927, 0.05249778630968649, 0.06512305786600336, 0.024204456276493147, 0.019821012974716723, 0.04216482338961214, 0.060117965695098974, 0.05649147591611836, 0.04529332094534766, 0.08141840182361193, 0.023600591121066827, 0.007271683998624212, 0.057346515386598185, 0.07003099177381955, 0.06426850450225174, 0.03320458505186252, 0.027487240768095944, 0.0321376549982233, 0.03717752049851697, 0.06718525619362481, 0.014260402858781163, 0.011839232338388683, 0.10079696119646542, 0.09067826744285412, 0.04153803143708501, 0.06840475325589068, 0.04607967093761545, 0.07682166527956724, 0.04755572103022132, 0.00979949325483176, 0.1346869344706647, 0.15081868681591004, 0.7093958090990782, 7.0471845008432865, 9.381479993462563, 33.07036265730858, 53.07714030146599, 46.289499923586845, 50.0471942871809, 47.43912823498249, 46.60541497170925, 43.11394952237606, 39.19816464185715, 32.824561446905136, 28.539709970355034, 27.061640582978725, 21.186975315213203, 26.946293972432613, 29.24099273979664, 47.387200221419334, 55.521495938301086, 31.56344711780548, 34.58091840147972, 35.99665403366089, 31.125843599438667, 23.570313826203346, 20.70924025028944, 18.30096747726202, 17.362528033554554, 15.86090276017785, 14.578865803778172, 15.086103435605764, 14.021483212709427, 15.171061176806688, 15.160435996949673, 16.297146901488304, 19.403181932866573, 21.865333914756775, 25.78714907169342, 27.617964930832386, 25.063593797385693, 24.469355084002018, 28.00632879137993, 26.431339904665947, 33.61022628843784, 26.48166250437498, 30.763797126710415, 33.484532833099365, 27.02457547187805, 22.334994412958622, 25.93122784048319, 29.11659501492977, 28.288022875785828, 28.245189674198627, 38.255192041397095, 42.106900960206985, 44.05889041721821, 39.846497252583504, 43.2199714332819, 42.99066133797169, 33.46988461911678, 15.414040088653564, 4.8169549740850925, 0.47221663291566074, 0.03208780493878294, 0.05291037217830308, 0.03433255304116756, 0.04180922704108525, 0.0920375480200164, 0.006570770510734292, 0.04270921468560118, 0.02149073021428194, 0.03114729974186048, 0.02127748892235104, 0.09525490662781522, 0.04708246829977725, 0.09431395985302515, 0.05277147181914188, 0.023267056967597455, 0.040978088436531834, 0.022751661381334998, 0.050449002301320434, 0.022115030405984726, 0.00615134435975051, 0.03455416204815265, 0.030953745772421826, 0.03718166168255266, 0.02660344121977687, 0.026867115157074295, 0.01931999093358172, 0.057116241805488244, 0.04913090349873528, 0.048859266316867433, 0.03659184352727607, 0.0404127797082765, 0.0451634191267658, 0.03022402906935895, 0.04238504829118028, 0.09932382774422877, 0.02410242766927695, 0.008938090795709286, 0.019701389901456423, 0.06606084309169091, 0.06041481363354251, 0.03798884376010392, 0.01618414797121659, 0.08556626518839039, 0.031172896415228024, 0.0643990482785739, 0.017575520869286265, 0.04207461162877735, 0.06620559157454409, 0.046827544283587486, 0.02079225792840589, 0.04715573682915419, 0.10143157167476602, 0.017652316455496475, 0.012696872108790558, 0.04396089498186484, 0.023171579668996856, 0.03918441027053632, 0.07731135658104904, 0.07058904229779728, 0.06200716568855569, 0.01834402406529989, 0.030510950782627333, 0.12837280140956864, 0.07534641670645215, 0.060912226981599815, 0.05519715552509297, 0.06862455513328314, 0.024484667119395453, 0.0190945598660619, 0.05056583489931654, 0.013087942188576562, 0.027967000278295018, 0.04986567051673774, 0.05063902550318744, 0.07627526647411287, 0.11518710816744715, 0.09948176419129595, 0.015620360645698383, 0.006165177992443205, 0.03263102735218126, 0.024562657563365065, 0.06676857738057151, 0.018022065560217015, 0.03273299473221414, 0.02080787642626092, 0.0294303893315373, 0.037172592637944035, 0.03349913975398522, 0.06683423518552445, 0.032893870084080845, 0.032648838896420784, 0.04536576569080353, 0.0022231495177038596, 0.06008707750879694, 0.027825452307297383, 0.05849206485436298, 0.02661629521753639, 0.03843841084744781, 0.0861907824582886, 0.04125977800867986, 0.06347389440634288, 0.0408901662012795, 0.027982785759377293, 0.04889743868261576, 0.043405141404946335, 0.08684915650519542, 0.03387521195691079, 0.02920684331911616, 0.0368019344023196, 0.0320352052222006, 0.07478576866560616, 0.0391732595016947, 0.12050644421833567, 0.5920359597075731, 5.67141892388463, 17.520320266485214, 26.122150495648384, 48.140281811356544, 59.35610957443714, 52.642238438129425, 51.19595244526863, 47.31803633272648, 42.447199299931526, 34.50832709670067, 29.066783487796783, 27.312886901199818, 18.352266624569893, 21.072833240032196, 18.912280574440956, 24.977509416639805, 36.57846361398697, 47.71977737545967, 60.14536142349243, 48.19402612745762, 52.89264500141144, 46.70977257192135, 40.071692168712616, 31.087030582129955, 23.94838973879814, 18.702026456594467, 15.476766172796488, 15.198816787451506, 13.518697042018175, 14.386857356876135, 12.724052332341671, 14.396726377308369, 13.834201712161303, 17.899490520358086, 23.34328930824995, 30.402238927781582, 27.17642292380333, 29.23896174877882, 40.56215465068817, 42.98659935593605, 46.5801577270031, 42.70446069538593, 44.62256357073784, 40.26906497776508, 42.63646334409714, 44.37063328921795, 31.287319734692574, 25.284322053194046, 21.575493067502975, 22.876433059573174, 25.755057893693447, 20.185721442103386, 30.95206942409277, 42.55468413233757, 40.938573852181435, 42.37671688199043, 46.124470978975296, 48.37843783199787, 44.503880739212036, 27.535881735384464, 10.718820132315159, 1.730470487382263, 0.024004560655157547, 0.061598717293236405, 0.04115956951864064, 0.028479688880906906, 0.08292473154142499, 0.02448764684231719, 0.0038235318424995057, 0.05475166653923225, 0.06809741506003775, 0.03815224612480961, 0.03410297336813528, 0.04542256967397407, 0.05577356678259093, 0.019001785840373486, 0.019698721880558878, 0.03648433601483703, 0.04635911180230323, 0.03417851658014115, 0.02070538954285439, 0.036446096855797805, 0.029981851439515594, 0.0630502171406988, 0.0488461933855433, 0.03788884307141416, 0.05096385611977894, 0.0352209631819278, 0.030818214763712604, 0.044020942150382325, 0.0495540612610057, 0.04070688541105483, 0.0569925777381286, 0.02854175469110487, 0.05088257610623259, 0.1306970149744302, 0.029877264278184157, 0.031464827625313774, 0.0661133203539066, 0.016811489113024436, 0.008638179642730393, 0.03838612654362805, 0.038583593486691825, 0.01138555746365455, 0.07747166047920473, 0.038583181594731286, 0.06599191241548397, 0.047287078414228745, 0.020245879532012623, 0.051266203372506425, 0.015750911843497306, 0.08567365395720117, 0.06439177523134276, 0.03524553198076319, 0.09544873333652504, 0.08231891639297828, 0.13958703872049227, 0.09349357496830635, 0.11348806496243924, 0.19559404434403405, 0.14631828846177086, 0.14982814231188968, 0.21565340546658263, 0.11026239430066198, 0.13878854719223455, 0.17540672211907804, 0.2060924208490178, 0.13937052455730736, 0.16329798905644566, 0.10484416707186028, 0.14291619445430115, 0.1398889592383057, 0.21114706993103027, 0.12157113669672981, 0.1026695704786107, 0.1446584306540899, 0.13476454827468842, 0.21753457171143964, 0.20400305249495432, 0.15325910586398095, 0.18905158212874085, 0.07402203933452256, 0.13923983235144988, 0.20271072105970234, 0.06534875981742516, 0.15320032776799053, 0.1407033920986578, 0.08707783446880057, 0.08869541954481974, 0.1391981533379294, 0.1739595044637099, 0.12547315622214228, 0.16363001108402386, 0.11620988414506428, 0.07552955648861825, 0.1148716508760117, 0.11459692264907062, 0.16077997104730457, 0.12601162889041007, 0.11134310232591815, 0.09220181498676538, 0.12019210756989196, 0.11422178184147924, 0.13328785251360387, 0.09707111268653534, 0.1322586866444908, 0.27857483772095293, 0.17497246182756498, 0.1961125383968465, 0.10832763015059754, 0.11920556324184872, 0.12502328114351258, 0.1562184197246097, 0.082773081085179, 0.181258630764205, 0.2927504520630464, 4.145129173994064, 15.52702322602272, 24.42876186221838, 49.05722200870514, 69.73811388015747, 61.86115175485611, 65.64276203513145, 61.35085813701153, 64.128847271204, 54.592502787709236, 49.2631633579731, 46.35134540498257, 34.60682161152363, 40.561265498399734, 28.009214736521244, 37.433577328920364, 37.25844852626324, 57.04088240861893, 69.19017568230629, 43.945865482091904, 49.91324007511139, 51.47011153399944, 44.09044772386551, 35.02006083726883, 30.72495561093092, 26.877608858048916, 22.86680057644844, 22.15121917426586, 20.782458521425724, 22.030165269970894, 19.316350892186165, 22.662284150719643, 21.475324742496014, 23.69233477860689, 26.683604568243027, 31.82631131261587, 36.253725439310074, 37.09886468946934, 37.19948709011078, 34.654402658343315, 39.01991240680218, 36.61736972630024, 42.64692038297653, 34.72434550523758, 39.533040672540665, 41.631732657551765, 34.36938375234604, 33.02693098783493, 34.522336944937706, 38.829010650515556, 41.7970085889101, 35.985547229647636, 53.28215830028057, 57.63414837419987, 60.52447088062763, 53.70597615838051, 58.11552554368973, 59.03907738626003, 49.89313915371895, 25.636441558599472, 7.890049573034048, 1.0567457391880453, 0.1334560677059926, 0.11690446015563793, 0.07143656010157429, 0.21344239910831675, 0.2502025320427492, 0.0893813866423443, 0.18020470684859902, 0.1402123278239742, 0.14619200461311266, 0.10832158164703287, 0.1726069996948354, 0.25226712750736624, 0.20069656195119023, 0.15180001384578645, 0.12445297776139341, 0.21063918858999386, 0.27803428703919053, 0.07943112330394797, 0.12233045024913736, 0.0954838220786769, 0.09224068126059137, 0.1611691087600775, 0.1074775074084755, 0.16032910149078816, 0.13122347969328985, 0.0670829437149223, 0.1369506333139725, 0.11248004288063385, 0.09178177424473688, 0.11169738136231899, 0.12486441701184958, 0.13477989588864148, 0.19703219295479357, 0.22713995160302147, 0.1265228053671308, 0.1335830640164204, 0.15928166394587606, 0.09199495616485365, 0.21634942124364898, 0.16045068012317643, 0.12244209152413532, 0.08985308086266741, 0.19737082009669393, 0.1731655845651403, 0.14798302960116416, 0.1691494375700131, 0.11106034406111576, 0.18294582929229364, 0.08136411372106522, 0.2666853053960949, 0.12681362335570157, 0.3109312889864668], [0.021565638890024275, 0.12640435859793797, 0.0628903140022885, 0.06244391217478551, 0.06588595599168912, 0.030120673873170745, 0.034920200414489955, 0.014426176385313738, 0.02759218230494298, 0.0455458812211873, 0.03500451952277217, 0.00611753118391789, 0.024782817527011503, 0.06722548801917583, 0.05569300665229093, 0.03130485398287419, 0.04010064723843243, 0.03543405233358499, 0.025071318159461953, 0.05484479494043626, 0.03423525377002079, 0.07579553479445167, 0.04843784146942198, 0.02697456886380678, 0.03918205024092458, 0.011133439693367109, 0.06882840083562769, 0.06509521248517558, 0.03709393240569625, 0.0553819057677174, 0.07137375956517644, 0.07321285345824435, 0.021551836798607837, 0.04406292544445023, 0.028421181668818463, 0.013969422525406117, 0.04802738185389899, 0.010937655570160132, 0.04102986436919309, 0.062467994866892695, 0.024940854164015036, 0.01851715598604642, 0.03827916822046973, 0.023233602805703413, 0.05293401329254266, 0.03269463311880827, 0.027784808589785825, 0.04256515640008729, 0.032059859368018806, 0.01886379275674699, 0.00887874773980002, 0.06911820208188146, 0.0327926708268933, 0.06707697684760205, 0.03180988918757066, 0.03905781100911554, 0.07308601299882866, 0.023539983631053474, 0.049487405267427675, 0.01792645467503462, 0.03501556639093906, 0.01218055811477825, 0.06642802807618864, 0.24152054713340476, 1.4467673795297742, 1.1559178051538765, 8.937834799289703, 18.414739072322845, 24.100541174411774, 37.87733271718025, 42.04509347677231, 46.40097074210644, 45.33329263329506, 52.14714400470257, 52.841526344418526, 46.978155970573425, 51.18420347571373, 58.20960849523544, 37.61046163737774, 53.663954213261604, 87.17193558812141, 16.7587461322546, 22.769020423293114, 28.569654263556004, 19.775071777403355, 19.69683777540922, 24.055849872529507, 25.372644513845444, 25.774092972278595, 28.08542724698782, 29.31274238973856, 24.72117707133293, 31.647806391119957, 35.40953993797302, 36.47289387881756, 29.91683017462492, 35.25953158736229, 17.262568697333336, 43.27722676098347, 77.58850023150444, 35.91269753873348, 29.139452688395977, 27.476713210344315, 33.63455258309841, 32.36433394253254, 32.42005035281181, 29.53685626387596, 37.22216807305813, 36.302887201309204, 45.737275555729866, 52.018315717577934, 50.788865089416504, 46.99091948568821, 48.48710440099239, 46.712736412882805, 37.330211475491524, 37.767271623015404, 36.498607099056244, 25.774702839553356, 14.096104558557272, 2.988637243397534, 0.2405062539037317, 0.026057695504277945, 0.10093860008055344, 0.03334123670356348, 0.02303600969753461, 0.04227650548273232, 0.014109225521679036, 0.04408041786518879, 0.05757193903264124, 0.05482620785187464, 0.0984140882792417, 0.048894911669776775, 0.053984649493941106, 0.0228839436385897, 0.08084832850727253, 0.011871029655594612, 0.05094579224532936, 0.055566763621754944, 0.04806866381841246, 0.03596993861719966, 0.11681474192300811, 0.05213014119362924, 0.024348028455278836, 0.07940424271509983, 0.02126300776581047, 0.0014992707338024047, 0.012900344881927595, 0.045763363887090236, 0.052266681523178704, 0.03131567078526132, 0.048286684541380964, 0.09134631167398766, 0.04972241003997624, 0.04322859189414885, 0.04082843064679764, 0.04103986851987429, 0.0254460674841539, 0.045495289014070295, 0.015165753447945463, 0.03315486486826558, 0.03132987178105395, 0.08804699027677998, 0.08993991956231184, 0.06944842811208218, 0.09510385731118731, 0.0627517921384424, 0.028936321214132477, 0.0459388781018788, 0.07655875204363838, 0.05022312965593301, 0.018826908017217647, 0.08135797615977935, 0.03701948757225182, 0.05290549997880589, 0.09264463224099018, 0.032645224637235515, 0.02473925345839234, 0.04448273983143736, 0.04177862829237711, 0.033818322626757436, 0.04045865556690842, 0.05671023507602513, 0.015863397311477456, 0.0335197937238263, 0.02984140741318697, 0.02465613291860791, 0.06206206977367401, 0.033306251862086356, 0.023860758410592098, 0.037321664131013677, 0.0925259331415873, 0.05679421279637609, 0.017101826560974587, 0.03541947284247726, 0.04582236462738365, 0.09244153610779904, 0.013318294622877147, 0.043024363985750824, 0.08776905597187579, 0.03680504400108475, 0.026826434332178906, 0.12458143610274419, 0.027717640514310915, 0.042020616674562916, 0.012701593095698627, 0.09166848540189676, 0.06716798641718924, 0.035742277395911515, 0.020379146990308072, 0.06501750962343067, 0.047376303118653595, 0.014323453870019875, 0.025661394211056177, 0.019566070404835045, 0.0766199421195779, 0.10044438909972087, 0.061966941284481436, 0.030185077448550146, 0.010713822903198889, 0.04296691062336322, 0.058656439432525076, 0.01723317000141833, 0.019127344239677768, 0.04186924823443405, 0.018289114414073993, 0.019955818534072023, 0.026104563985427376, 0.046737057928112336, 0.09515098368865438, 0.010339491036575055, 0.04283637797925621, 0.02601745440188097, 0.09504925008513965, 0.012020209687761962, 0.050481998187024146, 0.06402082755812444, 0.13109044230077416, 0.07778308790875599, 0.6390032800845802, 1.8550979811698198, 5.818987805396318, 19.87594686448574, 31.4847856387496, 39.26381751894951, 48.30504097044468, 53.449360728263855, 53.64973917603493, 49.50620211660862, 51.920326575636864, 48.191947638988495, 39.66610573232174, 32.335964664816856, 41.4187540858984, 27.388215959072113, 49.11454953253269, 84.80936676263809, 18.60603790730238, 28.86608775705099, 39.247014820575714, 36.884601786732674, 32.94300489127636, 39.23097588121891, 38.432843908667564, 44.355498701334, 39.866822361946106, 40.556515753269196, 41.650830432772636, 47.05455847084522, 45.433386862277985, 48.48176568746567, 43.23827505111694, 49.138872027397156, 32.14712239801884, 52.266267612576485, 68.27914416790009, 29.940432608127594, 26.922473050653934, 24.953361712396145, 21.90976683050394, 25.302809961140156, 21.886846460402012, 20.971291288733482, 29.782742969691753, 27.99122080206871, 32.524274960160255, 41.31058529019356, 44.55349087715149, 43.97134691476822, 48.147151842713356, 51.73087254166603, 47.87414029240608, 48.44770051538944, 44.479945823550224, 37.73541033267975, 23.42875052243471, 7.968945689499378, 0.5813435115851462, 0.0849906331859529, 0.04272976846550591, 0.06820228052674793, 0.0821535881550517, 0.05974361898552161, 0.06520775918033905, 0.010642073921189876, 0.03830112094874494, 0.05281211553665344, 0.06213933105755132, 0.03472555734333582, 0.04813096711586695, 0.0433511687151622, 0.10004820840549655, 0.01579336454597069, 0.040069176466204226, 0.044845475640613586, 0.04183100536465645, 0.038198904949240386, 0.043390658393036574, 0.09041960671311244, 0.01586354945175117, 0.10680645005777478, 0.02062997064058436, 0.012010970876872307, 0.022688871977152303, 0.026042459212476388, 0.029849710190319456, 0.07775001038680784, 0.028732213904731907, 0.06407294858945534, 0.04362913270597346, 0.04781352457939647, 0.013237042439868674, 0.030101919801381882, 0.06377683908795007, 0.046653250901727006, 0.013739098849328002, 0.019254344260843936, 0.07405594806186855, 0.012300333328312263, 0.05134985825861804, 0.029154987605579663, 0.06250543621717952, 0.024837421042320784, 0.06717201627907343, 0.0811107073968742, 0.07462181340088136, 0.040871478922781534, 0.04165209211350884, 0.07154521052143537, 0.06918382277945057, 0.05877878618775867, 0.032970641550491564, 0.13100833108182997, 0.20872048451565206, 0.17129693093011156, 0.14263419318012893, 0.20913574582664296, 0.2680910815251991, 0.22892713226610795, 0.08513737804605626, 0.1567957067163661, 0.1327705755829811, 0.11799572152085602, 0.14005931181600317, 0.07922790842712857, 0.15894982003374025, 0.18171356728998944, 0.15648572647478431, 0.16206850268645212, 0.12565557612106204, 0.15050604968564585, 0.16183380590518937, 0.13213807280408219, 0.12174639487056993, 0.1343362993793562, 0.23537323402706534, 0.1300546564743854, 0.15032855764729902, 0.20941589173162356, 0.11168225639266893, 0.14101546519668773, 0.1478328337543644, 0.14651353267254308, 0.2646675246069208, 0.13778857741272077, 0.10567126839305274, 0.09296916599851102, 0.14570784231182188, 0.16676298750098795, 0.11872462928295135, 0.20925399963743985, 0.14192032132996246, 0.13474967563524842, 0.15653907204978168, 0.2393092736019753, 0.11737851440557279, 0.14718444901518524, 0.13197696738643572, 0.12944179092301056, 0.11853590855025686, 0.0862402243365068, 0.1462843277840875, 0.1428411781671457, 0.09942307515302673, 0.21118932781973854, 0.22516824334161356, 0.12029523641103879, 0.10016888903919607, 0.3727274917764589, 0.1685261374223046, 0.15169231337495148, 0.16187719185836613, 0.13574494019849226, 0.2581278677098453, 0.17945305968169123, 0.429429147625342, 1.7073279479518533, 4.533685874193907, 15.053284596651793, 27.871531024575233, 38.541020303964615, 51.74406163394451, 61.40473924577236, 66.85417503118515, 64.73946690559387, 70.26441603899002, 70.67106261849403, 60.155552476644516, 65.37641912698746, 68.0855293571949, 48.39487574994564, 60.4808796197176, 100.73457062244415, 21.158900521695614, 30.48361726105213, 40.59715457260609, 29.546350054442883, 30.954541191458702, 36.017161533236504, 38.680332228541374, 39.686647430062294, 39.42995220422745, 39.44027625024319, 35.448275059461594, 47.14513801038265, 47.85532370209694, 52.52870053052902, 41.90269611775875, 45.33369921147823, 24.978615157306194, 55.66541701555252, 89.22209277749062, 38.6550559848547, 36.33693717420101, 34.840030297636986, 41.42908193171024, 43.8958677649498, 43.09592328965664, 37.8824320435524, 50.88480994105339, 46.27532668411732, 56.64623938500881, 64.4709201157093, 64.87898781895638, 61.38973765075207, 66.03707447648048, 60.67884139716625, 57.63010919094086, 54.557848647236824, 51.38711258769035, 37.54320524632931, 20.137462131679058, 5.780871100723743, 0.39637302921619266, 0.11467179792816751, 0.19732317421585321, 0.154568595753517, 0.13367958774324507, 0.1381118717836216, 0.11377717601135373, 0.14605674077756703, 0.17165469063911587, 0.21320280415238813, 0.1234917703550309, 0.11424008320318535, 0.29171159374527633, 0.15057282813359052, 0.22014777758158743, 0.17436289141187444, 0.13531642412999645, 0.14300348586402833, 0.13436972571071237, 0.13001651008380577, 0.19532256672391668, 0.20708829397335649, 0.1784040784696117, 0.24831352871842682, 0.08451219284324907, 0.11804713009041734, 0.12750009511364624, 0.14652619371190667, 0.10209123705863021, 0.21858426538528875, 0.12642689020140097, 0.16482706560054794, 0.157010187394917, 0.10851873317733407, 0.085944099992048, 0.0851954659447074, 0.1623531905352138, 0.12719265301711857, 0.18633742933161557, 0.049740329195628874, 0.22726915951352566, 0.18647488992428407, 0.13522843510145321, 0.15691131848143414, 0.19196385866962373, 0.12382772576529533, 0.12421890438417904, 0.28526960348244756, 0.1585596878430806, 0.16130103293107823, 0.18131150136468932, 0.15355206123786047, 0.22496526595205069, 0.15284872788470238, 0.13025396765442565], [0.05800406193884555, 0.02971322366647655, 0.05018261952500325, 0.041161057524732314, 0.0519289486692287, 0.010857726265385281, 0.047684253586339764, 0.007489119352612761, 0.057121971185551956, 0.08188564315787517, 0.05700041481759399, 0.029554888315033168, 0.08201632052077912, 0.05850378336617723, 0.07000228550168686, 0.051970939384773374, 0.034670374952838756, 0.040370759306824766, 0.02215612868894823, 0.11185191135155037, 0.03709052594786044, 0.018779132260533515, 0.028613691065402236, 0.02369654339418048, 0.020489086891757324, 0.06650896670180373, 0.023324174508161377, 0.01941242728207726, 0.009591325469955336, 0.011144122909172438, 0.020278188931115437, 0.021521403177757747, 0.018924196156149264, 0.032311258182744496, 0.02873335310141556, 0.027942527958657593, 0.01634485448448686, 0.053078724668012, 0.08625355330877937, 0.06104723106545862, 0.02375307092734147, 0.03963062656112015, 0.06540130387293175, 0.016561624688620213, 0.041820270198513754, 0.04594542755512521, 0.005667584209732013, 0.010295156989741372, 0.07531811119406484, 0.0296989595881314, 0.040289189855684526, 0.008911635086406022, 0.07304445272893645, 0.030863422689435538, 0.06520349183119833, 0.03619930677814409, 0.05966402364720125, 0.053872540665906854, 0.033236282179132104, 0.030729288773727603, 0.07840474048862234, 0.021676964752259664, 0.06820072201662697, 0.10445623905980028, 0.05302012097672559, 0.044541102324728854, 0.03999452754214872, 0.31296429864596575, 1.593138612806797, 3.0191795295104384, 8.506143763661385, 10.15525622293353, 12.549687288701534, 10.197165124118328, 29.183384031057358, 48.625869154930115, 51.11062042415142, 52.418768629431725, 49.077421724796295, 54.69382055103779, 70.35957053303719, 41.4531384408474, 43.24324518442154, 31.02982845157385, 36.49664260447025, 37.11790166795254, 28.68733774870634, 29.81131363660097, 31.82163756340742, 33.150279968976974, 26.57405834645033, 23.955666348338127, 28.527550622820854, 35.17742179334164, 36.11277960240841, 32.882607132196426, 43.529445827007294, 33.90947923064232, 42.15664029121399, 99.4673690199852, 55.71521334350109, 43.04302252829075, 42.63134501874447, 46.14141047000885, 49.283902645111084, 53.267198503017426, 54.90374028682709, 55.035152435302734, 50.76452359557152, 45.51730535924435, 41.68199636042118, 38.130535930395126, 29.188095778226852, 16.907492950558662, 14.908015541732311, 7.667772900313139, 4.519974309951067, 3.3012265199795365, 0.7118268474005163, 0.001961142165782803, 0.06788999962736852, 0.07471285265637562, 0.02020125975832343, 0.015097718915058067, 0.03972170663473662, 0.020685334857262205, 0.018718203791650012, 0.013126606227160664, 0.017728158381942194, 0.03135347207717132, 0.05429675969935488, 0.0360452888708096, 0.03620591560320463, 0.026500427411519922, 0.03400138077267911, 0.01638161120354198, 0.04181399162916932, 0.06786200581700541, 0.016666644150973298, 0.03531349415425211, 0.0038742627384635853, 0.04271331134077627, 0.03607831815315876, 0.02145436497812625, 0.05847835367603693, 0.034383905949653126, 0.05512684445420746, 0.018610058032209054, 0.0703673850512132, 0.06923760622157715, 0.04213949760014657, 0.05438902720925398, 0.0822241218702402, 0.03661758863017894, 0.0054316183559421916, 0.07516189652960747, 0.01894216169603169, 0.025854864688881207, 0.07415695436066017, 0.05592209279711824, 0.03022601431439398, 0.007403092376989662, 0.03797885074163787, 0.01678562712186249, 0.05456440783746075, 0.0038233388841035776, 0.011850377541122725, 0.028148004530521575, 0.024432375394098926, 0.04989864784874953, 0.03219376136257779, 0.05873435380635783, 0.061134214483899996, 0.023705614294158295, 0.03246103100536857, 0.01222195140144322, 0.05016026974772103, 0.04510040336754173, 0.04717201954917982, 0.04367799570900388, 0.021903935776208527, 0.02255498111480847, 0.04360828206699807, 0.010247940626868512, 0.027851253071276005, 0.08098984864773229, 0.005452675868582446, 0.004267703516234178, 0.028338545380393043, 0.039655199070693925, 0.03334308094053995, 0.041721315938048065, 0.064841665152926, 0.010521270833123708, 0.04770802828716114, 0.02681250607565744, 0.04703361642896198, 0.054928746685618535, 0.007237865720526315, 0.029422006773529574, 0.019218745292164385, 0.0361747379793087, 0.0038969000979705015, 0.026603049736877438, 0.024422527094429825, 0.060528395624714904, 0.023392106995743234, 0.04950712413119618, 0.07345497171627358, 0.04268512457201723, 0.044357628576108254, 0.04160714022873435, 0.06720340170431882, 0.07116485983715393, 0.02882131615479011, 0.0646531670645345, 0.029414869168249425, 0.017557718601892702, 0.0951178022660315, 0.047790280514163896, 0.05315511021763086, 0.027590618228714447, 0.03224000829504803, 0.019383826765988488, 0.04791676103195641, 0.047799034146009944, 0.07550773734692484, 0.0426124274963513, 0.0357805462408578, 0.03300735559605528, 0.047444079755223356, 0.04242588496708777, 0.039586643179063685, 0.03976924119342584, 0.059780351584777236, 0.03498163539916277, 0.12032910060952418, 0.041538072255207226, 0.057827349155559205, 0.07013380891294219, 0.15589475427987054, 0.1633078744634986, 0.12959051731741056, 2.0348162250593305, 5.0439809169620275, 10.607719793915749, 17.607185505330563, 21.438434422016144, 27.864296212792397, 32.34780862927437, 47.4075823277235, 58.98103170096874, 60.93121625483036, 58.59349049627781, 45.91213837265968, 58.71848098933697, 80.5504184961319, 28.875686042010784, 26.847390979528427, 22.830670215189457, 21.431756280362606, 22.99456302076578, 20.185660645365715, 27.273671105504036, 24.049924090504646, 27.387197613716125, 24.060814306139946, 18.272767290472984, 26.132250353693962, 32.041370272636414, 36.95848882198334, 24.568060487508774, 30.61369188129902, 14.059218987822533, 41.69810749590397, 105.53087085485458, 44.06301699578762, 27.588514611124992, 25.9988946095109, 32.908194959163666, 40.82555651664734, 49.83810670673847, 51.210327073931694, 52.26180285215378, 55.86243264377117, 53.628255128860474, 52.609807178378105, 52.40165814757347, 42.5448502600193, 30.479357689619064, 27.13791199028492, 16.947637796401978, 11.693357639014721, 8.228969536721706, 2.6180963264778256, 0.13714963279198855, 0.06103257735958323, 0.0559643729502568, 0.020798371369892266, 0.052516143332468346, 0.0071995736834651325, 0.04570094926748425, 0.057222899558837526, 0.008666735629958566, 0.027861606031365227, 0.043922147451667115, 0.04036334154079668, 0.06119026889791712, 0.06468394392868504, 0.07840786493034102, 0.018415086560708005, 0.03314833767944947, 0.008538889560441021, 0.08589597171521746, 0.022398892615456134, 0.04212728927086573, 0.0405392194079468, 0.02322635758901015, 0.0826180464355275, 0.03858958632918075, 0.007049497971820529, 0.03957556662498973, 0.10529175633564591, 0.03221988125005737, 0.02993619451444829, 0.021613587196043227, 0.046093337587080896, 0.07482424160116352, 0.09099686401896179, 0.05053420456533786, 0.029496132483473048, 0.12018018867820501, 0.05491250478371512, 0.0315858385147294, 0.01291435755774728, 0.027262201183475554, 0.047337306968984194, 0.04548413824522868, 0.021920886429143138, 0.017757723690010607, 0.054052229461376555, 0.012598184093803866, 0.02991107467096299, 0.019931541028199717, 0.01891835174319567, 0.00789658579378738, 0.007563565577584086, 0.018726810849329922, 0.07524223401560448, 0.04018062478280626, 0.03227893394068815, 0.05798187914479058, 0.12513151596067473, 0.07835343581973575, 0.17491737962700427, 0.2220973846851848, 0.13352351408684626, 0.08518951392034069, 0.09944004064891487, 0.15806840092409402, 0.12297832290641963, 0.1349719488644041, 0.141857698909007, 0.10284855423378758, 0.12266337769688107, 0.15556274709524587, 0.16988045303151011, 0.10674949022359215, 0.14729919988894835, 0.11780079643358476, 0.1045434562547598, 0.1880422464455478, 0.15730161394458264, 0.1540302121429704, 0.16214230185141787, 0.09096633206354454, 0.11638769530691206, 0.09265251384931616, 0.07431601887219585, 0.09909741333103739, 0.10974477598210797, 0.1074156716640573, 0.08713005197932944, 0.16928683879086748, 0.13255839556222782, 0.16665469331201166, 0.119844982837094, 0.17092119640437886, 0.17277813894907013, 0.13441026181681082, 0.11447555923950858, 0.23486797988880426, 0.12466504645999521, 0.09339488417026587, 0.16204855375690386, 0.16944374365266412, 0.155855079065077, 0.08967778558144346, 0.08186235456378199, 0.08768636587774381, 0.1340366795193404, 0.083630959270522, 0.16074084502179176, 0.08519939190591685, 0.14834892324870452, 0.17194804677274078, 0.20852528483374044, 0.10340962529880926, 0.11421971867093816, 0.16801096819108352, 0.15427529899170622, 0.12018373614409938, 0.26864133949857205, 0.10450241548824124, 0.19536222709575668, 0.20004793972475454, 0.24221855186624452, 0.13667704799445346, 0.17099955235607922, 1.1570585751906037, 2.953351861797273, 6.749801533296704, 13.510948307812214, 16.523954831063747, 26.176468580961227, 30.40797472000122, 50.36607317626476, 68.05386185646057, 71.03982523083687, 74.23635050654411, 64.41564068198204, 69.26335215568542, 83.4591244161129, 48.13198685646057, 56.13591156899929, 45.93723602592945, 45.139636024832726, 49.04657118022442, 38.413001373410225, 42.75865338742733, 41.07993766665459, 45.47295033931732, 38.50481204688549, 31.058072336018085, 42.02099896967411, 45.47917440533638, 50.25739900767803, 42.92360633611679, 55.74139393866062, 42.58917108178139, 51.148124411702156, 113.9259883761406, 59.74248044192791, 53.595250099897385, 53.07385727763176, 59.608412235975266, 61.60653121769428, 69.81873795390129, 69.13231998682022, 72.43691146373749, 68.81938397884369, 63.765525966882706, 56.82899817824364, 54.25810933113098, 41.51236966252327, 27.9227826744318, 23.288503848016262, 14.883276969194412, 9.187062475830317, 5.118052242323756, 1.4658959093503654, 0.23266494419658557, 0.1943073680740781, 0.11807927250629291, 0.15867319190874696, 0.249554340261966, 0.14502561563858762, 0.11179328910657205, 0.15282398468116298, 0.09984194330172613, 0.12165486579760909, 0.14714515971718356, 0.13319009682163596, 0.09773276702617295, 0.2148811414372176, 0.10864807467442006, 0.13042672479059547, 0.12460741127142683, 0.1256968395318836, 0.22278100659605116, 0.1166269562963862, 0.20151978184003383, 0.13769315206445754, 0.10356110506108962, 0.1419064134825021, 0.08679140257299878, 0.14188983390340582, 0.20190503069898114, 0.26497343787923455, 0.0851294890162535, 0.15773548831930384, 0.1686300232540816, 0.1674356107832864, 0.24247564666438848, 0.21121402649441734, 0.15216077183140442, 0.13317661941982806, 0.20887091784970835, 0.17650596157182008, 0.08945440655224957, 0.1528675339068286, 0.09796817626920529, 0.06886247283546254, 0.14408719958737493, 0.09981801646063104, 0.09745512958033942, 0.17439055867725983, 0.1009676032117568, 0.08684239553986117, 0.18310280836885795, 0.14955685765016824, 0.1488034738576971, 0.15941885736538097, 0.1762172661256045, 0.22038596245693043, 0.09275493022869341, 0.15152902604313567, 0.1364725863095373], [0.017177770532725845, 0.044538360089063644, 0.0811294985760469, 0.06564895113115199, 0.016867562080733478, 0.0071929653222468914, 0.03945560958527494, 0.04604878275131341, 0.05670031256158836, 0.010117038764292374, 0.021332405995053705, 0.03215669850760605, 0.024054971036093775, 0.11537526486790739, 0.010486855589988409, 0.034482092087273486, 0.011550589770195074, 0.013756376047240337, 0.058227956760674715, 0.0711298082023859, 0.034933006172650494, 0.06968757035792805, 0.021652715076925233, 0.019401389690756332, 0.09856219869107008, 0.04579459346132353, 0.01806022864911938, 0.017618730562389828, 0.04393871218780987, 0.10086367285111919, 0.019198304689780343, 0.06847516080597416, 0.04302048997487873, 0.09700358466943726, 0.025118750672845636, 0.04068631307745818, 0.028670313222391997, 0.05006643259548582, 0.019328052512719296, 0.013492715097527253, 0.04824707611987833, 0.04611424017639365, 0.04574678801873233, 0.04474058419873472, 0.0303463628370082, 0.029181840363889933, 0.05373647902160883, 0.028097685062675737, 0.0636393265449442, 0.07418750858050771, 0.06183764802699443, 0.05489600313012488, 0.03471864423772786, 0.02434939957311144, 0.06866708761663176, 0.032052100214059465, 0.04024264977488201, 0.023376280696538743, 0.02742578537436202, 0.02384271123446524, 0.04041679472720716, 0.03901176074577961, 0.027292692320770584, 0.07655886336578988, 0.02080040670989547, 0.06712411064654589, 0.04812339349882677, 0.06686262975563295, 0.024225926608778536, 0.10728862340329215, 0.02547617827076465, 0.06580102461157367, 0.5524512275587767, 1.8559946143068373, 2.045885268598795, 7.355563128367066, 13.91174890100956, 28.728890419006348, 39.20045591890812, 46.48277275264263, 46.91692605614662, 51.05239994823933, 58.67262125015259, 63.97164970636368, 55.033738911151886, 48.70370797812939, 52.270614579319954, 50.6522586196661, 58.846910297870636, 56.60379946231842, 55.48520028591156, 60.25359481573105, 56.11048333346844, 49.834439903497696, 44.56420250236988, 50.80227456986904, 53.57924535870552, 54.60315361618996, 52.010203152894974, 55.09625315666199, 52.759830728173256, 55.24291388690472, 53.36442768573761, 54.08600136637688, 45.82971319556236, 30.344425030052662, 29.339295364916325, 24.679977782070637, 16.728463657200336, 12.414336651563644, 6.08416180126369, 1.209038479719311, 1.1570647498592734, 0.7514435809571296, 0.015629220033588354, 0.08955920522566885, 0.014583374395442661, 0.03427001225645654, 0.02359752976190066, 0.04217900954245124, 0.0508984432235593, 0.04173099354375154, 0.007177527259045746, 0.01836565581470495, 0.0372215113020502, 0.028886998079542536, 0.08380094077438116, 0.03043871754925931, 0.030811988144705538, 0.011599899917200673, 0.005240235632300028, 0.03658158704638481, 0.06440990589908324, 0.038191557687241584, 0.003369112268956087, 0.08714804163901135, 0.03979271532443818, 0.03918685564713087, 0.030833235832687933, 0.030630384608230088, 0.026828566151380073, 0.05761220425483771, 0.043245754059171304, 0.052501741956803016, 0.03498181722534355, 0.09960234834579751, 0.02476949041010812, 0.1057275157654658, 0.061884625974926166, 0.04390392772620544, 0.022493503456644248, 0.03289482003310695, 0.07010809349594638, 0.03119670451269485, 0.004233709441905376, 0.02438826770230662, 0.052858714989270084, 0.024728412536205724, 0.07245792599860579, 0.02972950453113299, 0.022676162698189728, 0.015723641627118923, 0.039266606836463325, 0.015341779744630912, 0.05464843750814907, 0.04801412709639408, 0.10889667188166641, 0.06546089833136648, 0.023768066021148115, 0.08293460952700116, 0.055426920735044405, 0.043862207894562744, 0.03762120977626182, 0.03176256985170767, 0.04305046903027687, 0.07846836480894126, 0.018837622774299234, 0.02674909141205717, 0.02702675854379777, 0.056595038913656026, 0.020410819997778162, 0.03655074709968176, 0.03878438154060859, 0.02087872926495038, 0.052795083247474395, 0.008078884166025091, 0.027341709319443908, 0.048721030179876834, 0.05560719582717866, 0.09933294131769799, 0.0037905378121649846, 0.04976757714757696, 0.04951990762492642, 0.049515324863023125, 0.05721698093111627, 0.042911902637570165, 0.0354433662869269, 0.030216448030842002, 0.03960297042794991, 0.022541089965670835, 0.025185081976815127, 0.053154594424995594, 0.06798719870857894, 0.03679145156638697, 0.03833561968349386, 0.058344778226455674, 0.02679272227396723, 0.0284777648630552, 0.041685362593852915, 0.11359412528690882, 0.012766234158334555, 0.029124464927008376, 0.08768761268584058, 0.0781505623308476, 0.025236867186322343, 0.03825842148216907, 0.08382627769606188, 0.02443812703859294, 0.03833722272247542, 0.009286950298701413, 0.04137282565352507, 0.01463894548578537, 0.05009933200199157, 0.019964074926974718, 0.029674381512450054, 0.00970865716226399, 0.03482037041976582, 0.0342219062440563, 0.05446940180263482, 0.04333338685682975, 0.06153346024802886, 0.006639460452788626, 0.041713742321007885, 0.028430295242287684, 0.05560820143728051, 0.03175313715473749, 0.05154591883183457, 0.037021858734078705, 0.029646589937328827, 0.022472639830084518, 0.027042852016165853, 0.08835668850224465, 0.03462221327936277, 0.03014972524397308, 0.07078701761201955, 0.1104031055001542, 0.20574249821947888, 0.24837459262926131, 1.0017015365883708, 2.456293646246195, 6.40826778486371, 18.206172063946724, 27.552507743239403, 41.91353313624859, 53.45398128032684, 60.35994350910187, 60.183549374341965, 58.56657274067402, 59.25712488591671, 57.588877603411674, 51.53540723025799, 47.128555700182915, 45.998226553201675, 46.51041626930237, 50.539841651916504, 53.00480358302593, 48.656423315405846, 46.11364535987377, 47.988571152091026, 47.345987632870674, 44.367506057024, 46.07394888997078, 50.58720991015434, 47.94949024915695, 50.34233585000038, 66.11913487315178, 57.795305326581, 53.987693041563034, 57.01570115983486, 58.13454732298851, 58.82652819156647, 45.416143387556076, 45.04315160214901, 38.979547172784805, 28.38353455066681, 21.81989785283804, 13.587282411754131, 6.416669609025121, 4.5303164049983025, 2.070376379415393, 0.6380998785607517, 0.27934966958127916, 0.19129420397803187, 0.09031052584759891, 0.030291321454569697, 0.046622633599326946, 0.04796002453076653, 0.03152287099510431, 0.028888178094348405, 0.022521319151564967, 0.036505093885352835, 0.06193371162225958, 0.008090590617939597, 0.05743490888562519, 0.02644777203386184, 0.01790447968232911, 0.05013527421397157, 0.04887338938715402, 0.06286410134634934, 0.04356126330094412, 0.023064567540131975, 0.06318887259112671, 0.019632845142041333, 0.01149749838077696, 0.04439150761754718, 0.029595496780530084, 0.08363581291632727, 0.041295690534752794, 0.04741975215438288, 0.00940946682021604, 0.05225197586696595, 0.10628474250552244, 0.03226380154956132, 0.031562798540107906, 0.06350709809339605, 0.014288959773693932, 0.0336249189422233, 0.009840849434112897, 0.018501509657653514, 0.028814679499191698, 0.007931958407425554, 0.05945907214481849, 0.02035785662883427, 0.04391342350572813, 0.036338604186312295, 0.06390249953255989, 0.04140171004110016, 0.027327658608555794, 0.05811646762595046, 0.03275709597801324, 0.03298212628578767, 0.023773908578732517, 0.034956888484884985, 0.03690398341859691, 0.05634002955048345, 0.04674010444432497, 0.049153138243127614, 0.03317688810057007, 0.05746210488723591, 0.03552526599378325, 0.08740845383726992, 0.052714545381604694, 0.12005970842437819, 0.09582494283677079, 0.11063279278459959, 0.20774309086846188, 0.14129610091913491, 0.23820886155590415, 0.1882808023947291, 0.11535080368048511, 0.19759656657697633, 0.056062781732180156, 0.1825582649325952, 0.11857669698656537, 0.12157339282566682, 0.22960529197007418, 0.10364614776335657, 0.10903219546889886, 0.15158093185164034, 0.1379402427119203, 0.16287794831441715, 0.15744480391731486, 0.1404076610924676, 0.14636580075602978, 0.1079388264042791, 0.08445241284789518, 0.2000243097427301, 0.18721193162491545, 0.10139039732166566, 0.16365622373996302, 0.1475302898325026, 0.22651029867120087, 0.10037012238171883, 0.15122349868761376, 0.23691939481068403, 0.13614938099635765, 0.1243084148154594, 0.10657616163371131, 0.1658191834576428, 0.16398067586123943, 0.08104735767119564, 0.11067885789088905, 0.15191540296655148, 0.10002673807321116, 0.10772833105875179, 0.09571612172294408, 0.09953299464541487, 0.10684728302294388, 0.10253593936795369, 0.06513210464618169, 0.2163202251540497, 0.1696557307150215, 0.11916494549950585, 0.2943170367507264, 0.08948463422711939, 0.12514270754763857, 0.15740956674562767, 0.05769166971731465, 0.15432938671438023, 0.15697024500695989, 0.2105774567462504, 0.13816168473567814, 0.15554030454950407, 0.14668692805571482, 0.10797923634527251, 0.29907452990300953, 0.1321068432298489, 0.25932103337254375, 0.1079249482427258, 0.19434704328887165, 0.16496271535288543, 0.26224571862258017, 0.20413542195456102, 0.19735416630282998, 0.731804275419563, 2.4428972275927663, 5.374963581562042, 13.952261377125978, 26.60119269043207, 44.74063463509083, 61.676850244402885, 68.18964377045631, 73.75984847545624, 74.43257957696915, 75.9614959359169, 81.34453788399696, 73.07134062051773, 62.91470602154732, 68.87642651796341, 66.9901393353939, 74.66014176607132, 73.81488472223282, 72.16790869832039, 73.77472087740898, 70.53765177726746, 66.04016751050949, 63.202624171972275, 67.58261874318123, 73.54974254965782, 68.92970725893974, 65.74349462985992, 68.4902836382389, 68.56773868203163, 71.10015839338303, 71.36371985077858, 70.50431236624718, 64.3137301504612, 48.44310276210308, 43.744692876935005, 34.77686628699303, 24.195355586707592, 16.364623680710793, 8.715428933501244, 3.4090488217771053, 2.14018979575485, 0.956403692252934, 0.3764094942016527, 0.21541204419918358, 0.13851362600689754, 0.2150856624939479, 0.15018380916444585, 0.14538447372615337, 0.16836500231875107, 0.18503246654290706, 0.13684682169696316, 0.11725086500518955, 0.17760021379217505, 0.1986929858685471, 0.18959452252602205, 0.14946808194508776, 0.12397804035572335, 0.11992548359557986, 0.14421885658521205, 0.06845702271675691, 0.13196487037930638, 0.1459193098708056, 0.18155151192331687, 0.18775450094835833, 0.11504077891004272, 0.13959514297312126, 0.20592189015587792, 0.11103200144134462, 0.24769506737357005, 0.16983697802061215, 0.23447740240953863, 0.12638534477446228, 0.12495014991145581, 0.1630465197376907, 0.16957151179667562, 0.19110408058622852, 0.13327428605407476, 0.1664176958729513, 0.1690380708896555, 0.0946842618577648, 0.18423569679725915, 0.18549365195212886, 0.06135419447673485, 0.13322137092472985, 0.1389193136128597, 0.37398739135824144, 0.17183117335662246, 0.14174900396028534, 0.1597872149432078, 0.0930154463276267, 0.12080301385140046, 0.11230418356717564, 0.19598604674683884, 0.10085173169500194, 0.15461214497918263, 0.1504805198055692, 0.13865380286006257, 0.15928991662804037, 0.11514574827742763, 0.12312264094362035, 0.1953443858656101, 0.1556531703681685, 0.22099458292359486, 0.14169687550747767], [0.02353784439037554, 0.002142301109415712, 0.005535686013899976, 0.04525968681264203, 0.013471395050146384, 0.03725211005075835, 0.09743374088429846, 0.02143694306141697, 0.05162313187611289, 0.036067018954781815, 0.035968476586276665, 0.048264134384226054, 0.015585346118314192, 0.011243562348681735, 0.0076961507238593185, 0.07580139033962041, 0.06723416372551583, 0.03155786696879659, 0.12520979769760743, 0.0155868712317897, 0.046237677888711914, 0.028829769216827117, 0.07863456878112629, 0.011337773357809056, 0.007476482433048659, 0.0420577574550407, 0.016951059260463808, 0.04352805219241418, 0.025182311910612043, 0.05905142526898999, 0.057180370786227286, 0.06831644510384649, 0.04640938488591928, 0.005938712092756759, 0.06776355250622146, 0.01903337164549157, 0.04093592331628315, 0.043390658393036574, 0.04369002963358071, 0.04126024927245453, 0.005949255228188122, 0.04572531768644694, 0.011283244057267439, 0.009962168314814335, 0.039715847378829494, 0.013350193985388614, 0.07903903926489875, 0.05150024335307535, 0.09660917770816013, 0.08833101019263268, 0.04996984207537025, 0.019331553594383877, 0.02359103596973, 0.05170569580513984, 0.06079222170228604, 0.08771936176344752, 0.07242572421091609, 0.014217373136489186, 0.025049966570804827, 0.036868772222078405, 0.03809732348599937, 0.08223618919146247, 0.04063632200995926, 0.07563174280221574, 0.06855277460999787, 0.0403094690409489, 0.04274968770914711, 0.09526348585495725, 0.04874755453784019, 0.01559070256917039, 0.019800451773335226, 0.06579837514436804, 0.02082756003801478, 0.09035898066940717, 0.08645159541629255, 0.0668399126152508, 0.08335886566783302, 1.181533180642873, 3.0688324151560664, 9.954282157123089, 16.23676624149084, 25.808847807347775, 23.463463559746742, 28.822205811738968, 37.09579065442085, 50.74078246951103, 49.886816293001175, 45.76141186058521, 54.73355121910572, 56.51915140450001, 53.060432597994804, 51.71016365289688, 47.24778190255165, 46.63986772298813, 42.41677053272724, 41.64254687726498, 39.598203375935555, 42.38991737365723, 49.88729506731033, 44.73070576786995, 34.3771543353796, 33.414464592933655, 22.89318636059761, 14.211603160947561, 4.899751581251621, 1.4897532854229212, 0.8231975650414824, 0.2102486407966353, 0.06483804347226396, 0.1237929413036909, 0.040223053365480155, 0.016542280609428417, 0.0963698944542557, 0.03560786703019403, 0.023521947587141767, 0.14816248090937734, 0.05073487387562636, 0.08341299791936763, 0.07488296774681658, 0.07793708355166018, 0.10703822277719155, 0.037224131083348766, 0.08201734468457289, 0.020528378045128193, 0.04810292135516647, 0.05999056120344903, 0.024333829314855393, 0.021265788964228705, 0.0968408613698557, 0.008871823501976905, 0.05077601483208127, 0.015241297587635927, 0.03420856985030696, 0.09329884283943102, 0.01677548196312273, 0.05656588364217896, 0.029165767300582957, 0.04337397120252717, 0.05413445571321063, 0.04292084551707376, 0.0363428975106217, 0.033881987765198573, 0.050431572963134386, 0.08876513689756393, 0.04555579260340892, 0.025379812250321265, 0.03207319576176815, 0.03769281589484308, 0.02044174343609484, 0.023023678913887125, 0.027449658409750555, 0.03997099403932225, 0.10190900269662961, 0.01249722603461123, 0.04184147706837393, 0.020298432864365168, 0.09272386392694898, 0.014021287515788572, 0.05101044815091882, 0.02909723923949059, 0.030104504330665804, 0.015694595822424162, 0.021630124101648107, 0.05306608960381709, 0.02625206583616091, 0.04139591757848393, 0.032011727380449884, 0.02834061782778008, 0.011650385440589162, 0.05629901475913357, 0.047114332410274073, 0.06686142747639678, 0.05014081805711612, 0.031100976739253383, 0.024053768756857608, 0.07581284909974784, 0.054598613423877396, 0.06889031079481356, 0.04303211942897178, 0.020011800588690676, 0.0623438112961594, 0.04160243501246441, 0.032058159849839285, 0.04650104383472353, 0.027738483731809538, 0.06313571997452527, 0.07105045035132207, 0.04035623176605441, 0.02342227344342973, 0.049952449844568036, 0.04907531292701606, 0.09328527637990192, 0.049264386179856956, 0.02656663997186115, 0.05624783625535201, 0.015097728191904025, 0.03147855735733174, 0.017264618509216234, 0.04115761767025106, 0.04848863776715007, 0.052613320149248466, 0.01650127138418611, 0.044269012432778254, 0.017536263112560846, 0.03579855074349325, 0.11855622113216668, 0.022141300578368828, 0.052684228649013676, 0.0259298271703301, 0.029383090404735412, 0.06020405111485161, 0.034487691591493785, 0.035939937297371216, 0.04391609152662568, 0.03757087732083164, 0.0722988169582095, 0.015049865232867887, 0.03618824135628529, 0.019089860215899535, 0.05258306649920996, 0.011007598350261105, 0.08657778278575279, 0.0323724519694224, 0.06338033184874803, 0.0737714977003634, 0.022546220061485656, 0.04300940971006639, 0.020102943744859658, 0.02389567089267075, 0.06498262126115151, 0.04813333827769384, 0.08452958878478967, 0.041025448590517044, 0.012529982577689225, 0.08981296778074466, 0.04680870486481581, 0.04664271240471862, 0.03679549627122469, 0.029660716718353797, 0.039656104490859434, 0.041964669871958904, 0.02561207478720462, 0.028791930817533284, 0.009978178295568796, 0.018939610563393217, 0.0275725246683578, 0.05518194520846009, 0.02688967273570597, 0.039609364030184224, 0.13217651605373248, 0.15583667380269617, 0.0528227245376911, 0.25395678996574134, 3.417553952895105, 8.300085570663214, 18.847596645355225, 27.738053686916828, 36.994674280285835, 41.77066460251808, 51.36010743677616, 50.37076212465763, 59.17324438691139, 62.12429143488407, 59.84493814408779, 65.29021695256233, 67.72464752197266, 67.27366492152214, 66.2810517847538, 62.599961310625076, 56.902752220630646, 53.62991563975811, 56.20048530399799, 52.455934435129166, 54.33989234268665, 60.007124841213226, 55.06439946591854, 48.5578566044569, 46.69191353023052, 33.06907832622528, 25.290587916970253, 11.40438124537468, 5.189622826874256, 2.40890187676996, 1.4589409762993455, 0.37896111665759236, 0.19184101838618517, 0.051517201427486725, 0.11269713591900654, 0.018864579433284234, 0.05302524550643284, 0.037235626950860023, 0.14200728619471192, 0.031951479832059704, 0.058180722771794535, 0.02430771684885258, 0.024917316950450186, 0.03849838009045925, 0.04594458521751221, 0.0297777942250832, 0.013465579395415261, 0.06835758234956302, 0.013674646106665023, 0.03890045714797452, 0.026280235906597227, 0.03126275936665479, 0.03886420323397033, 0.06861746762297116, 0.04054169447044842, 0.055137917297543027, 0.09397988207638264, 0.042602193279890344, 0.00835434711916605, 0.052057065622648224, 0.05329070059815422, 0.020255349336366635, 0.06333368044579402, 0.06926233458216302, 0.03277688905654941, 0.04169445390289184, 0.04769572718942072, 0.06017283638357185, 0.02005745565838879, 0.03062467378185829, 0.06820922702900134, 0.039498498299508356, 0.047367512379423715, 0.045625699203810655, 0.007469705697076279, 0.09112110696150921, 0.02555184022639878, 0.1113698270637542, 0.10837205511052161, 0.0739225915458519, 0.024164647475117818, 0.01337054089162848, 0.06839604786364362, 0.0396406641084468, 0.05039289222622756, 0.040452165485476144, 0.050281195290153846, 0.007443044041792746, 0.03094770469033392, 0.03164094297972042, 0.04964950887369923, 0.031096675993467215, 0.032848714108695276, 0.04510978040343616, 0.04396812350023538, 0.05719643828342669, 0.07707571727223694, 0.03863312071189284, 0.02873609719244996, 0.09147664764896035, 0.108255953527987, 0.08841966715408489, 0.10921402907115407, 0.17033779411576688, 0.10278947185724974, 0.19338198413606733, 0.15788387332577258, 0.11946804603212513, 0.19639701844425872, 0.14764545630896464, 0.10649430274497718, 0.09459040244109929, 0.1859359274385497, 0.13545982190407813, 0.22797587706008926, 0.09504199930233881, 0.12296032582526095, 0.23363988875644282, 0.12138954800320789, 0.1416718799737282, 0.09926454498781823, 0.19739407900488004, 0.171236282621976, 0.10962894899421372, 0.15338196099037305, 0.12184270337456837, 0.12927592091728002, 0.10480081080459058, 0.21588641015114263, 0.19810198398772627, 0.21526091324631125, 0.09904126985929906, 0.109518094395753, 0.16200703801587224, 0.1297020769561641, 0.11951181048061699, 0.1356911493348889, 0.1746903418097645, 0.17317149206064641, 0.07988573328475468, 0.10143898573005572, 0.12836673064157367, 0.27067820832598954, 0.13269717717776075, 0.15495932166231796, 0.15578433754853904, 0.16673143138177693, 0.17702889366773888, 0.14209169807145372, 0.07137276508728974, 0.1163639168953523, 0.13500009110430256, 0.1973236640333198, 0.118742722843308, 0.173023478128016, 0.17823837173637003, 0.12915456492919475, 0.19861851877067238, 0.12115275094402023, 0.16780736739747226, 0.2328220271738246, 0.09994323903811164, 0.10228458137135021, 0.2685496100457385, 0.11992097133770585, 0.16953808546531945, 0.1252389492583461, 0.1590927576762624, 0.11873440336785279, 0.10799702562508173, 0.09896731484332122, 0.15446825738763437, 0.1477433752734214, 0.14806494786171243, 0.11159704299643636, 0.19891370058758184, 1.9741951092146337, 5.154679901897907, 15.139037445187569, 23.404236137866974, 37.397597059607506, 42.84793719649315, 49.711736887693405, 55.5973132699728, 66.80185183882713, 68.61484095454216, 64.03648942708969, 72.91716009378433, 74.30112943053246, 72.3612043261528, 69.76830706000328, 65.23727059364319, 64.4791504740715, 60.709209367632866, 60.78712798655033, 57.84063309431076, 59.531424567103386, 65.48127070069313, 61.64734862744808, 53.770595490932465, 46.09220691025257, 32.03937917947769, 20.407276153564453, 7.616722164675593, 3.094422142021358, 1.2294039619155228, 0.6310129025951028, 0.18933910498162732, 0.15771187318023294, 0.2024675637949258, 0.26374064153060317, 0.1824451467837207, 0.19390466390177608, 0.08005051975487731, 0.16505391045939177, 0.14840980904409662, 0.12806734826881438, 0.2023134642513469, 0.1457165105966851, 0.12773063586791977, 0.15835464728297666, 0.224036097060889, 0.11500984619488008, 0.17979564989218488, 0.14910168363712728, 0.24669275240739807, 0.14810974389547482, 0.2091949840541929, 0.08423472609138116, 0.16711938165826723, 0.12947883893502876, 0.16506223735632375, 0.2167014664155431, 0.17641237674979493, 0.22638735448708758, 0.15543330169748515, 0.13156752451322973, 0.1069643568189349, 0.16064065508544445, 0.13988674763822928, 0.11890062960446812, 0.11577467390452512, 0.14489998487988487, 0.13252473174361512, 0.0773721607401967, 0.09665099772973917, 0.11778012019931339, 0.13756639324128628, 0.1350607690983452, 0.17874282435514033, 0.09252559917513281, 0.2329278871184215, 0.10996258148225024, 0.21125908970134333, 0.1425227225990966, 0.15415704518090934, 0.105608178419061, 0.1306637073867023, 0.12041534559102729, 0.12677382939727977, 0.09304101331508718, 0.15904395404504612, 0.0978884770302102, 0.08412927432800643, 0.10265833436278626, 0.11942687910050154, 0.1054904812190216, 0.09433012382942252, 0.1158907383796759, 0.1224453272880055, 0.0934419957047794, 0.1315511972643435, 0.11713957253959961, 0.14361765759531409, 0.1589198224246502], [0.03014662492205389, 0.14035076805157587, 0.028175441730127204, 0.058192645374219865, 0.011138664413010702, 0.005312993007464684, 0.03971940226620063, 0.006432157733797794, 0.06853471073554829, 0.01767474601365393, 0.059270299461786635, 0.03013247773196781, 0.014488906417682301, 0.04241059301421046, 0.017827654410211835, 0.006588065798496245, 0.016138455794134643, 0.08584232928114943, 0.04882906832790468, 0.03613352280808613, 0.050127292415709235, 0.06369934402755462, 0.03405583214771468, 0.07090493003488518, 0.0354521533154184, 0.03609978477470577, 0.06810269915149547, 0.028127749465056695, 0.008625090013083536, 0.03055116034374805, 0.046296812215587124, 0.05486585338076111, 0.028233336670382414, 0.03625776203989517, 0.04354574499302544, 0.071885989891598, 0.0583747832570225, 0.04578454478178173, 0.01600500279892003, 0.020029825500387233, 0.004954700343660079, 0.021712641646445263, 0.08449560584267601, 0.06644109729677439, 0.05928652280999813, 0.013926593182986835, 0.04187950471532531, 0.06884970047394745, 0.09290076966863126, 0.01995030623220373, 0.028368925195536576, 0.04904981644358486, 0.0465828507731203, 0.056361091701546684, 0.020277921757951844, 0.04129729357373435, 0.018432853576086927, 0.04164522724749986, 0.021193986176513135, 0.06842865783255547, 0.022416885985876434, 0.12336932340986095, 0.02995113580254838, 0.029960574065626133, 0.02465540932462318, 0.09447957010706887, 0.018962444592034444, 0.022551485599251464, 0.033405172725906596, 0.06482757919002324, 0.019689476575877052, 0.0639564981975127, 0.015383517202280927, 0.1190020218200516, 0.018792797054629773, 0.06273617735132575, 0.03383133247552905, 0.04651653245673515, 0.030788135518378112, 0.024866721032594796, 0.07419806192046963, 0.2619455347303301, 0.8212438167538494, 1.429138700477779, 3.6409845761954784, 5.048937276005745, 4.9456521682441235, 4.0516237914562225, 5.88406833820045, 6.3022995460778475, 6.303640399128199, 4.78690286166966, 3.832621593028307, 4.34532618150115, 4.590673791244626, 2.6096265809610486, 2.7150547737255692, 4.188426425680518, 2.941973372362554, 2.092320676892996, 1.1281617195345461, 0.2630313561530784, 0.11961582247749902, 0.05411002421169542, 0.07896600451203994, 0.1297001919010654, 0.03666543489089236, 0.05811499446281232, 0.03266784900915809, 0.037559863849310204, 0.058416157989995554, 0.026678073445509654, 0.03729414158442523, 0.08597018648288213, 0.013424419885268435, 0.026639427960617468, 0.004921541185467504, 0.11302657527267002, 0.016114358259073924, 0.013923617170803482, 0.034898637313744985, 0.04503169904637616, 0.019152154236508068, 0.023330321346293204, 0.021675669704563916, 0.05451272096252069, 0.037203451138339005, 0.027687342335411813, 0.10176307419897057, 0.04227812336466741, 0.04302456436562352, 0.049849677234306, 0.026811196185008157, 0.03717793610121589, 0.0516649370547384, 0.07286192150786519, 0.0068439745518844575, 0.014352085927384906, 0.03467825285042636, 0.01863856949057663, 0.029081099382892717, 0.04553004750050604, 0.053712077206000686, 0.02333303575142054, 0.019578473547881003, 0.03224526641133707, 0.04554301282041706, 0.039501010469393805, 0.022088006953708827, 0.05743429661379196, 0.038189205079106614, 0.037513501883950084, 0.061831777638872154, 0.043243538748356514, 0.022721786226611584, 0.024781513202469796, 0.017884022381622344, 0.04587768060446251, 0.003379767886144691, 0.052206871841917746, 0.04187286991509609, 0.030294314165075775, 0.025156759766105097, 0.05755261721787974, 0.022403072762244847, 0.07928649356472306, 0.08067974966252223, 0.05093321655294858, 0.036346018241601996, 0.08239802933530882, 0.021218714537099004, 0.015075790306582348, 0.1141898101195693, 0.0686220615170896, 0.02583103247161489, 0.04428172171174083, 0.01856071819929639, 0.04865992545092013, 0.00872235681526945, 0.04099438228877261, 0.04987711443391163, 0.01741951400617836, 0.028687881713267416, 0.0343185116071254, 0.005496489948200178, 0.033345533738611266, 0.05186230380786583, 0.08822167699690908, 0.02172409112972673, 0.01964417773706373, 0.014893859297444578, 0.020047210309712682, 0.009805082554521505, 0.020829001659876667, 0.05574236318352632, 0.044863951407023706, 0.06884265749249607, 0.025246201548725367, 0.025246854638680816, 0.037539551267400384, 0.030537304446625058, 0.027042865003750194, 0.04323553468566388, 0.06872990299598314, 0.06162641795526724, 0.029984283828525804, 0.06473042463767342, 0.028902260346512776, 0.0152381388215872, 0.06921016902197152, 0.02676782136404654, 0.017504786774225067, 0.07661763404030353, 0.020813629926124122, 0.0465629760583397, 0.04024138812383171, 0.10644471985870041, 0.08572049089707434, 0.01097290758480085, 0.023557173626613803, 0.0312450071942294, 0.041499454600852914, 0.04769020189996809, 0.04004842972790357, 0.006337952754620346, 0.0242285018612165, 0.024794172386464197, 0.008434038936684374, 0.007016489098532475, 0.029923006550234277, 0.02381591413723072, 0.05028057930758223, 0.026462366367923096, 0.0558894345886074, 0.010705529402912362, 0.02750471463514259, 0.06959373320569284, 0.11034866896807216, 0.0408528064872371, 0.007459266462319647, 0.06045234404155053, 0.1008111065311823, 0.0511531817028299, 0.05745186696003657, 0.05982259091979358, 0.05740744571085088, 0.05091512299259193, 0.05318928240740206, 0.039825269632274285, 0.056517117118346505, 0.06435738410800695, 0.03252773152780719, 0.06491405423730612, 0.02361568454944063, 0.018510378322389442, 0.06692368624499068, 0.4827546252636239, 1.8389146495610476, 2.9207918839529157, 4.02667623013258, 8.786654211580753, 12.24328313022852, 12.920831423252821, 11.604695096611977, 14.148984421044588, 14.942326750606298, 14.578410778194666, 11.638087704777718, 10.694220252335072, 11.01596798747778, 10.412652511149645, 7.547098975628614, 7.713347654789686, 9.610269516706467, 7.455701055005193, 6.164308525621891, 4.06299420632422, 1.7665963363833725, 0.5658339313231409, 0.13698070513783023, 0.1313053088961169, 0.09340543008875102, 0.01622827236133162, 0.03671742233564146, 0.06405270280083641, 0.0166023723068065, 0.054640715461573564, 0.08414351614192128, 0.0718488528218586, 0.11583229425013997, 0.1448546099709347, 0.06250457532587461, 0.08799662813544273, 0.0940108296344988, 0.021872732177143916, 0.021136603318154812, 0.09393200612976216, 0.07769512856611982, 0.04486894606088754, 0.02601844516902929, 0.033633609491516836, 0.04027750102977734, 0.06289878190727904, 0.013183437113184482, 0.1013551972573623, 0.02558029973442899, 0.012939150856254855, 0.01073857260053046, 0.0116067991075397, 0.01934703850565711, 0.04658457255573012, 0.011837591264338698, 0.08443051206995733, 0.0458415194589179, 0.07334333786275238, 0.021102410719322506, 0.04896326718153432, 0.040774910667096265, 0.040160638745874166, 0.020402528352860827, 0.033204495994141325, 0.04526072210865095, 0.03404585397220217, 0.05510817572940141, 0.03920279697922524, 0.05838662793394178, 0.02124021641066065, 0.008827740857668687, 0.059081100043840706, 0.0432565114897443, 0.007008673355812789, 0.011814395438705105, 0.016431503936473746, 0.04800100592547096, 0.037427468414534815, 0.05318895957316272, 0.06184041252708994, 0.02626779009005986, 0.014773510774830356, 0.0817589065991342, 0.01495689732109895, 0.04982995094906073, 0.036065089370822534, 0.12329758741543628, 0.02131696746801026, 0.09381857627886347, 0.010522492593736388, 0.02946808857814176, 0.028679454626399092, 0.015657878066122066, 0.04368005887954496, 0.08291553633171134, 0.10470692912349477, 0.2578630397329107, 0.1561055242200382, 0.13981787633383647, 0.1456625119317323, 0.12154128009569831, 0.13911071349866688, 0.08476895367493853, 0.09378709437442012, 0.0846983828523662, 0.20643257681513205, 0.21769998158561066, 0.08507654420100152, 0.08202788318158127, 0.14912019280018285, 0.103049861791078, 0.07334540103329346, 0.10976881414535455, 0.11679217321216129, 0.19997994415462017, 0.1444051504950039, 0.2575792127754539, 0.1466142272693105, 0.15666253573726863, 0.11508848416269757, 0.14761251979507506, 0.22412494698073715, 0.16156059165950865, 0.16630757600069046, 0.153769985481631, 0.3006113396259025, 0.17880845989566296, 0.16938017128268257, 0.13902817183407024, 0.09174195802188478, 0.10049516684375703, 0.10656143000232987, 0.08799597504548728, 0.1638852950418368, 0.2098003390710801, 0.27592807193286717, 0.10937115657725371, 0.07846633132430725, 0.2214758805348538, 0.09641051219659857, 0.10559169531916268, 0.07174158279667608, 0.1768907651421614, 0.17292259057285264, 0.08339710853761062, 0.07389746242552064, 0.11530309842783026, 0.14225155668100342, 0.1400921741151251, 0.1283435311052017, 0.13844543747836724, 0.09670124112744816, 0.1412435865495354, 0.08837284505716525, 0.09987662386265583, 0.27685133332852274, 0.1940240160911344, 0.10995118951541372, 0.18148479284718633, 0.1639195080497302, 0.26449959143064916, 0.14454060728894547, 0.19625198794528842, 0.10911286692135036, 0.22497728874441236, 0.22516331548104063, 0.1940274448134005, 0.11286958877462894, 0.26783943409100175, 0.17465589131461456, 0.14048775366973132, 0.10319972367142327, 0.2615679003065452, 0.1529079512692988, 0.11223076289752498, 0.20324374636402354, 0.9279632871039212, 1.6468049143441021, 2.770474087446928, 5.695621250197291, 7.7680528443306684, 8.753246404230595, 8.120726644992828, 9.194167144596577, 9.863271340727806, 9.710589833557606, 7.452186718583107, 6.976530142128468, 6.908165160566568, 6.451262952759862, 4.582783039659262, 4.875437160953879, 6.266549164429307, 4.531806875020266, 3.9325671549886465, 2.7676458517089486, 0.8901530003640801, 0.35163066757377237, 0.2101292143925093, 0.20439805317437276, 0.18830300745321438, 0.15098773321369663, 0.19257757026934996, 0.10026769858086482, 0.055771136248949915, 0.19123155187116936, 0.12154572556028143, 0.12888451223261654, 0.23055072873830795, 0.26402384508401155, 0.17057020508218557, 0.17497768654720858, 0.2055766133707948, 0.08271540878922679, 0.1322800011257641, 0.20720871485536918, 0.20460162428207695, 0.14069784083403647, 0.12272030042367987, 0.12604876596014947, 0.12985338602447882, 0.20389367477037013, 0.09414790431037545, 0.25652034615632147, 0.16148925642482936, 0.12236765411216766, 0.15194635052466765, 0.13813256286084652, 0.1281991833820939, 0.10738280936493538, 0.10858820562134497, 0.11478410713607445, 0.13621016289107502, 0.12234651774633676, 0.07076861234963872, 0.10221219970844686, 0.09389151455252431, 0.18156304489821196, 0.10957161066471599, 0.14649414777522907, 0.09861941827693954, 0.19759062939556316, 0.17671484645688906, 0.2294196659931913, 0.18595851841382682, 0.11801339205703698, 0.10883265422307886, 0.196785859297961, 0.13067265768768266, 0.16193625197047368, 0.15528668300248682, 0.1154082830180414, 0.16820107673993334, 0.1235263841226697, 0.18794777104631066, 0.14417324418900535, 0.11957757960772142, 0.15138993272557855, 0.16948891076026484, 0.08628148032585159, 0.20115145394811407, 0.22631713247392327, 0.18210775160696357, 0.0826034854981117, 0.1399320038035512, 0.12536137393908575, 0.10207092447672039, 0.19034073717193678, 0.11386503887479194, 0.13379319570958614, 0.17316340265097097], [0.0692074082326144, 0.10869023608393036, 0.07090608036378399, 0.035826934181386605, 0.06227024219697341, 0.046445297411992215, 0.040225854972959496, 0.0705289506004192, 0.027053409066866152, 0.08185789425624534, 0.05325183803506661, 0.021250433928798884, 0.015194425395748112, 0.05915562651352957, 0.020399372369865887, 0.0036454555947784684, 0.031199610020848922, 0.05485711830260698, 0.03932242747396231, 0.0865242442523595, 0.028121298346377444, 0.02528414384869393, 0.043041199605795555, 0.02453313678415725, 0.024490105206496082, 0.05036622686020564, 0.03095856045547407, 0.04004638140031602, 0.023951677067088895, 0.02722312339756172, 0.03929332044208422, 0.03444519250479061, 0.0663512825849466, 0.004459366400624276, 0.02768968010059325, 0.02470592546160333, 0.06649185277638026, 0.02212139246694278, 0.027156840333191212, 0.0024756506536505185, 0.04068260233907495, 0.0737095951626543, 0.04503608142840676, 0.024874417104001623, 0.033723186716088094, 0.06506415360490791, 0.057085464941337705, 0.06328343704808503, 0.04389495887153316, 0.11693954147631302, 0.07096219414961524, 0.011502186898724176, 0.00933051993342815, 0.06707342938170768, 0.039537583506898955, 0.021744969599239994, 0.02028487197094364, 0.02230133359262254, 0.023723182785033714, 0.0180204755088198, 0.08848494646372274, 0.006467100829468109, 0.014215693099686177, 0.029973474447615445, 0.06229489634279162, 0.0783291453262791, 0.03284942657046486, 0.03152675984892994, 0.030659389594802633, 0.057274044665973634, 0.02163476252462715, 0.017442939897591714, 0.06769268482457846, 0.07616174014401622, 0.014219004933693213, 0.029681190717383288, 0.03350838691403624, 0.04792301362613216, 0.02575032205641037, 0.0675686274189502, 0.09820490653510205, 0.03443309920839965, 0.03039396418898832, 0.0615951104555279, 0.012769065451720962, 0.03430083364946768, 0.08781961849308573, 0.14986855967435986, 0.04444520571269095, 0.09416009037522599, 0.020214713040331844, 0.04864147937041707, 0.048005978314904496, 0.046020443842280656, 0.014686563536088215, 0.08723801220185123, 0.08671447896631435, 0.012156355751358205, 0.017738943643053062, 0.08266935852589086, 0.00838215817566379, 0.05395716034399811, 0.11899811812327243, 0.03279015865700785, 0.02560040265962016, 0.020483656226133462, 0.04454288718989119, 0.012074292772012996, 0.029272903739183675, 0.019853468947985675, 0.03743852270417847, 0.05179621926799882, 0.021484370008693077, 0.006261770831770264, 0.051638464647112414, 0.014796267805650132, 0.04550459183519706, 0.06742403478710912, 0.06560887515661307, 0.0381681169528747, 0.05556519026868045, 0.022789514623582363, 0.0357237348362105, 0.030015179436304606, 0.041923655080609024, 0.020178498089080676, 0.01996364077058388, 0.03275020884757396, 0.021989739179844037, 0.012091151584172621, 0.019757657682930585, 0.019198941081413068, 0.06413208291633055, 0.028378664028423373, 0.0299584125605179, 0.0570181187504204, 0.09130426158662885, 0.077841116435593, 0.033369620141456835, 0.01121302575484151, 0.019245796574978158, 0.07173588310251944, 0.022247103006520774, 0.14220236713299528, 0.03431994395214133, 0.019493822328513488, 0.048031441401690245, 0.00615650785221078, 0.04125480932998471, 0.09401251430972479, 0.019636151409940794, 0.04851308411161881, 0.12567616329761222, 0.09365583071485162, 0.03426227907766588, 0.025103701773332432, 0.03136250401439611, 0.0342101988644572, 0.051297061872901395, 0.051641333047882654, 0.03009772852237802, 0.019195571730961092, 0.04133830465434585, 0.11237349273869768, 0.01497566066973377, 0.0063305201456387294, 0.06350776602630503, 0.03333600085170474, 0.06391297123627737, 0.028353341949696187, 0.010521063959458843, 0.024257781442429405, 0.019012533994100522, 0.06109795314841904, 0.15995255060261115, 0.014623104343627347, 0.059526804252527654, 0.028230375501152594, 0.015300529321393697, 0.05740807653637603, 0.05296904266288038, 0.01533258453491726, 0.03643894255219493, 0.06331667784252204, 0.04132597387069836, 0.022420476125262212, 0.05123269911564421, 0.020702296642411966, 0.03702378831803799, 0.07658663453185, 0.03328192055050749, 0.018123890076822136, 0.03235292235331144, 0.023412465961882845, 0.013890902373532299, 0.056324336837860756, 0.03968593511672225, 0.05170209267816972, 0.05347038939362392, 0.05573792885115836, 0.011639718923106557, 0.04298671854485292, 0.036197221343172714, 0.0112820575486694, 0.016104090645967517, 0.03126434385194443, 0.03357965535542462, 0.027307186464895494, 0.06569636694621295, 0.030392077278520446, 0.05439986627607141, 0.050672218058025464, 0.024513727767043747, 0.09100916140596382, 0.06144970146124251, 0.004920080082229106, 0.020008609353681095, 0.07342388315009885, 0.04962444283592049, 0.0291669306170661, 0.08513014952768572, 0.03935665532480925, 0.08713810428162105, 0.03624663353548385, 0.0281192500187899, 0.04965011743479408, 0.07520390208810568, 0.06186731538036838, 0.0362703711289214, 0.019878577659255825, 0.012614282204594929, 0.029289357153174933, 0.04724853868538048, 0.02912244999606628, 0.06308869007625617, 0.03810694543062709, 0.04331594638642855, 0.02559008866228396, 0.056320136282010935, 0.0481763049174333, 0.0687600564560853, 0.06299373228102922, 0.04987807922589127, 0.02636488527059555, 0.05263669780106284, 0.056441021006321535, 0.041858565018628724, 0.04012318626337219, 0.06281999550992623, 0.050816272632800974, 0.03495097356790211, 0.029548288766818587, 0.1031988998875022, 0.08039437161642127, 0.015791457226441707, 0.021998225638526492, 0.0628880801377818, 0.012981393902009586, 0.09280615326133557, 0.06728505279170349, 0.12328699696809053, 0.08857369990437292, 0.116685118409805, 0.11823297129012644, 0.04822107497602701, 0.1124518338474445, 0.23116835887776688, 0.08739237891859375, 0.07460282184183598, 0.03469949311693199, 0.04337093581852969, 0.028471987243392505, 0.03507481575070415, 0.0405239274550695, 0.05690190584573429, 0.04260961475665681, 0.005364235985325649, 0.03466424110229127, 0.1145532621012535, 0.0323830535489833, 0.03956699853006285, 0.0454083093063673, 0.011178237582498696, 0.017347358698316384, 0.04813708983419929, 0.02659470799699193, 0.04935267577820923, 0.007685050049985875, 0.03277454015915282, 0.005296720955811907, 0.0813316299172584, 0.030145224118314218, 0.04724267571873497, 0.05107514116389211, 0.0340521325415466, 0.07771636883262545, 0.016592553693044465, 0.04282520865672268, 0.06644803637755103, 0.013894101957703242, 0.04095338605111465, 0.06981695638387464, 0.026188552837993484, 0.058438262858544476, 0.013807356026518391, 0.0360918103979202, 0.03175320765876677, 0.06453194466303103, 0.002314051012035634, 0.02746182963164756, 0.04126262785575818, 0.05851919035194442, 0.058215700191794895, 0.026736667859950103, 0.06079925355152227, 0.02125499813701026, 0.05812424533360172, 0.08673413103679195, 0.014568188198609278, 0.014741236627742182, 0.021015160127717536, 0.09575678399414755, 0.06994751500315033, 0.05187922106415499, 0.02302965320268413, 0.09366325961309485, 0.009234842254954856, 0.016360734589397907, 0.0573081129550701, 0.08602034824434668, 0.036448267637751997, 0.05764583096606657, 0.03190901785274036, 0.0635500684438739, 0.036789874502574094, 0.009233556484105065, 0.027715922442439478, 0.059098919009556994, 0.02937295452284161, 0.07697166816797107, 0.045450199831975624, 0.028324741433607414, 0.0071454901353718014, 0.07692680534091778, 0.0455359215993667, 0.015169444704952184, 0.005330922367647872, 0.042958116173394956, 0.042687102395575494, 0.03688709213747643, 0.07969595128088258, 0.03076637389312964, 0.10652475306414999, 0.1481985196005553, 0.14030031685251743, 0.14211578818503767, 0.12311870013945736, 0.12815964175388217, 0.12675359845161438, 0.16104086564155295, 0.11645780599792488, 0.245282523392234, 0.13497242383891717, 0.1258333947043866, 0.07662243573577143, 0.21652801166055724, 0.12416634548571892, 0.08047686133068055, 0.08108892536256462, 0.17329315975075588, 0.09168674965621904, 0.2805930934846401, 0.11490358549053781, 0.14390026743058115, 0.13869583810446784, 0.1106858415005263, 0.07285853731445968, 0.1825250018737279, 0.10065459500765428, 0.08760904893279076, 0.08441576559562236, 0.05615376532659866, 0.12911149067804217, 0.15974316105712205, 0.14594037202186882, 0.11634013106231578, 0.1502501720096916, 0.10008951634517871, 0.1612618623767048, 0.1450548562570475, 0.12518667237600312, 0.07532191841164604, 0.11717569286702201, 0.2191457149456255, 0.20730351679958403, 0.09996589680667967, 0.13354724796954542, 0.15820767235709354, 0.19601263047661632, 0.14356901723658666, 0.09731018071761355, 0.18339549656957388, 0.14764771243790165, 0.08146239633788355, 0.10929645199212246, 0.1455112177063711, 0.07214786412077956, 0.0761018562479876, 0.12538932322058827, 0.1456000082544051, 0.18490180402295664, 0.0852397721610032, 0.19231504295021296, 0.10773966365377419, 0.14967150462325662, 0.12752510549034923, 0.16638345317915082, 0.14082412468269467, 0.11555173274246044, 0.13481841335305944, 0.0887080434767995, 0.23297274252399802, 0.16307305893860757, 0.14258489973144606, 0.19956373289460316, 0.21450245316373184, 0.14173756004311144, 0.1442743098596111, 0.2065271115861833, 0.2149962485418655, 0.1128410457749851, 0.27884782932233065, 0.20172961667412892, 0.12460190453566611, 0.13442793977446854, 0.16411755757872015, 0.19726736471056938, 0.11976360634434968, 0.2991213742643595, 0.2478851907653734, 0.1314289655419998, 0.3338138689287007, 0.2174045325955376, 0.12283278774702922, 0.13720223621930927, 0.1626963893068023, 0.1709742599632591, 0.33895567583385855, 0.16121513675898314, 0.1597398956073448, 0.23238329915329814, 0.12384662084514275, 0.10849008627701551, 0.23009031516266987, 0.23255415639141575, 0.31385273847263306, 0.10396155310445465, 0.1900561829097569, 0.18068327335640788, 0.16741500876378268, 0.15786303381901234, 0.1984775997698307, 0.09592283211532049, 0.09421503156772815, 0.1101612915226724, 0.11682700962410308, 0.19299394480185583, 0.10203553887549788, 0.13448014244204387, 0.19549542776076123, 0.1257224881555885, 0.25271479098591954, 0.10527833830565214, 0.11096730100689456, 0.16251664113951847, 0.18249547923915088, 0.1655697327805683, 0.163156624766998, 0.12249804945895448, 0.151204009889625, 0.06162736790429335, 0.11975633329711854, 0.16260229982435703, 0.20756504964083433, 0.24962858471553773, 0.12052182893967256, 0.14427298883674666, 0.16299326322041452, 0.28496389801148325, 0.15248203271767125, 0.10897176238358952, 0.08136316377203912, 0.1595843562972732, 0.17254848877200857, 0.13015692442422733, 0.3341337642632425, 0.1195708780142013, 0.21016630693338811, 0.1397220353828743, 0.11794497346272692, 0.10965403358568437, 0.18815098592313007, 0.13175411528209224, 0.09844073880231008, 0.23486581281758845, 0.16027038276661187, 0.13779374276055023, 0.11749005920137279, 0.09887804189929739, 0.09762133355252445, 0.1807337097125128, 0.12751777307130396, 0.08863191396812908, 0.08570296136895195, 0.09077457594685256, 0.24351169966394082, 0.12135345736169256, 0.10872409286093898, 0.1354957715375349, 0.2534688723972067, 0.132206721464172, 0.10147368855541572, 0.06645991074037738, 0.22063885669922456, 0.17493707622634247, 0.1327490236144513, 0.20923684118315578, 0.11789391370257363], [0.04748060084239114, 0.020059973394381814, 0.15036719385534525, 0.05660981136315968, 0.061701022350462154, 0.0758987304288894, 0.028357332848827355, 0.0453625410591485, 0.024543838553654496, 0.019832811267406214, 0.019605359702836722, 0.035083202019450255, 0.026652829292288516, 0.041118666049442254, 0.018603276657813694, 0.01934069314302178, 0.07554152733064257, 0.008843403884384315, 0.035465048131300136, 0.053442948483279906, 0.020149680494796485, 0.03309208659629803, 0.021292892197379842, 0.0600822609703755, 0.012842821015510708, 0.02359357040404575, 0.09898462172714062, 0.021577769293799065, 0.05065283316071145, 0.03301856944744941, 0.03388584322237875, 0.07931505882879719, 0.03519889171002433, 0.05175318212423008, 0.013878316476620967, 0.04497078727581538, 0.08181407785741612, 0.038897340127732605, 0.03538015385856852, 0.012155594122305047, 0.014922231603122782, 0.03155259029881563, 0.025270790756621864, 0.015154812335822498, 0.04586202870996203, 0.0208171978010796, 0.06162308942293748, 0.07773412100505084, 0.028070828593627084, 0.027616676889010705, 0.021128645639691968, 0.088549513311591, 0.08714938492630608, 0.07438980319420807, 0.026215943653369322, 0.014921334532118635, 0.054791531001683325, 0.04532327031483874, 0.06805289362091571, 0.019037173296965193, 0.013146796354703838, 0.031840521332924254, 0.04378372948849574, 0.019880392210325226, 0.047197601379593834, 0.02225539465143811, 0.016235448929364793, 0.03187002170307096, 0.027655049634631723, 0.022203609441930894, 0.03328224709548522, 0.026084587225341238, 0.08602183253969997, 0.03637759291450493, 0.03947265671740752, 0.07030197957647033, 0.026660221083147917, 0.04390277368656825, 0.010591442751319846, 0.03909796861989889, 0.06012021069182083, 0.07767483082716353, 0.08179474491043948, 0.03019244883034844, 0.03101278362009907, 0.052306479192338884, 0.025912392266036477, 0.033433185089961626, 0.01838484218751546, 0.058041050579049625, 0.05455450758745428, 0.05214658347540535, 0.04439021256985143, 0.04752519649628084, 0.05014859576476738, 0.04340368679550011, 0.027426113774708938, 0.037801922735525295, 0.028139165551692713, 0.055814355218899436, 0.03751477837795392, 0.03612143322243355, 0.04888070696324576, 0.02979549073643284, 0.005495245459314901, 0.03722553374245763, 0.06934336226549931, 0.03234175674151629, 0.045652312619495206, 0.08234559660195373, 0.045622923571499996, 0.02440720174490707, 0.021451249813253526, 0.026065328493132256, 0.014408342576643918, 0.052270700252847746, 0.043920896932831965, 0.012964259567525005, 0.01833124057156965, 0.017321570921922103, 0.03717706407769583, 0.0246211666308227, 0.03956560329243075, 0.049897204371518455, 0.01796539330825908, 0.01751000963849947, 0.06313436184427701, 0.059910899071837775, 0.027280439462629147, 0.02006817412620876, 0.04461683849513065, 0.021715730836149305, 0.044560546593857, 0.023609829004271887, 0.03438682259002235, 0.022416080755647272, 0.023768694991304073, 0.038241433721850626, 0.02495137225196231, 0.022787573907407932, 0.06818968628067523, 0.011349707092449535, 0.029536108268075623, 0.018116670835297555, 0.08252471394371241, 0.0326277433487121, 0.05213839016505517, 0.024276683943753596, 0.046458002980216406, 0.09400295544764958, 0.030486829127767123, 0.05082172741822433, 0.027332592035236303, 0.04564832728647161, 0.029490911474567838, 0.049570752162253484, 0.023703191181994043, 0.024507204288966022, 0.030797549661656376, 0.04427678642969113, 0.039828724329709075, 0.05023348261602223, 0.03917745634680614, 0.008583359049225692, 0.04322946762840729, 0.021487190169864334, 0.04325037392845843, 0.06267593722441234, 0.013101436288707191, 0.0227623724276782, 0.01835739200032549, 0.06059990897483658, 0.046532262276741676, 0.02089316774799954, 0.010745431900431868, 0.038620890118181705, 0.011291013415757334, 0.02277223000419326, 0.1464082664460875, 0.031197721255011857, 0.0520703945949208, 0.04306774622818921, 0.0496569303504657, 0.021195982553763315, 0.02900072664488107, 0.0023529889494966483, 0.021330062663764693, 0.05845939551363699, 0.021277275554894004, 0.010850412400031928, 0.003544208793755388, 0.04276790743460879, 0.017226130730705336, 0.019241365953348577, 0.01267548990654177, 0.04826836462598294, 0.01073177360012778, 0.03925597557099536, 0.018245299870613962, 0.041105184936895967, 0.03675644074974116, 0.019702436329680495, 0.044209132247488014, 0.034401543089188635, 0.04802006427780725, 0.0138335139490664, 0.04245215328410268, 0.01819319553760579, 0.01642713454202749, 0.0964503877912648, 0.056263169026351534, 0.16558931063627824, 0.029853300329705235, 0.03356107197760139, 0.018819816796167288, 0.032833036239026114, 0.023359083279501647, 0.056899341725511476, 0.047171459227683954, 0.06027546798577532, 0.044692559822578914, 0.04793975276697893, 0.015520951819780748, 0.08993860596092418, 0.004560966417557211, 0.038915218465263024, 0.05504010594449937, 0.018486124936316628, 0.013251138607301982, 0.02345723787584575, 0.025429630768485367, 0.07471842618542723, 0.07809970295056701, 0.03936232904379722, 0.05807035428006202, 0.01615917841263581, 0.02161484142561676, 0.05011498389649205, 0.05299478776578326, 0.037501672049984336, 0.04591732984408736, 0.0419735682226019, 0.0668731534096878, 0.05101757276861463, 0.010191298060817644, 0.0724773554247804, 0.036758741407538764, 0.05213196687691379, 0.03127023279375862, 0.022046864141884726, 0.07943576172692701, 0.08861416921718046, 0.10219403193332255, 0.025653061748016626, 0.056743245804682374, 0.031236917784553953, 0.023219229260575958, 0.04880950160440989, 0.08605579321738333, 0.01780231006705435, 0.0035100020477329963, 0.03060534825635841, 0.03349236023495905, 0.07359098512097262, 0.006710189445584547, 0.03371487466210965, 0.06146848892967682, 0.034117081595468335, 0.015917776327114552, 0.0047362760778923985, 0.03023919114639284, 0.05633458589727525, 0.021449778505484574, 0.03163369219691958, 0.06499988361611031, 0.016185832646442577, 0.02474675842677243, 0.02000248663534876, 0.023330555122811347, 0.11860059414175339, 0.06571886886376888, 0.03235281474189833, 0.018575594549474772, 0.01151783322711708, 0.060919065872440115, 0.06702317856252193, 0.0756580445158761, 0.08125656910124235, 0.04031022974231746, 0.02714023106818786, 0.020628666316042654, 0.07769913616357371, 0.037541710917139426, 0.046042715694056824, 0.03188927301380318, 0.025823588730418123, 0.07665494180400856, 0.030182628361217212, 0.03249215296818875, 0.03542254904459696, 0.06806315752328373, 0.17208176694111899, 0.05360159739211667, 0.013475070536514977, 0.03661266448034439, 0.012006992037640885, 0.06989356828853488, 0.04204559365462046, 0.031161619481281377, 0.038829908589832485, 0.052603898584493436, 0.009531532487017103, 0.08749639091547579, 0.08371721909497865, 0.05247522873105481, 0.011235841229790822, 0.025058972532860935, 0.005417405300249811, 0.021322720967873465, 0.06650971627095714, 0.06515535613289103, 0.054237632793956436, 0.10574063693638891, 0.0267867312868475, 0.03235418029362336, 0.04176793394435663, 0.027010377489204984, 0.021152785848244093, 0.01826233958126977, 0.02651000853802543, 0.030538933460775297, 0.04817108390852809, 0.03329314924485516, 0.01305655305259279, 0.046264521370176226, 0.04855747196415905, 0.030876582823111676, 0.050249301493749954, 0.01863449881057022, 0.02151686308934586, 0.05233339317783248, 0.06610442942474037, 0.05990725883748382, 0.027243068616371602, 0.015311257066059625, 0.032944662671070546, 0.01966695981536759, 0.0304749937276938, 0.03414487873669714, 0.02689693650609115, 0.08325745860929601, 0.03786029636103194, 0.14263892808230594, 0.10439865582156926, 0.2703966078115627, 0.11725339572876692, 0.12649389129364863, 0.11705106400768273, 0.18114120815880597, 0.11094174144091085, 0.12560234928969294, 0.13213223952334374, 0.09498280560364947, 0.08778887131484225, 0.09803206034121104, 0.11658391915261745, 0.15386547020170838, 0.11782957692048512, 0.16993244789773598, 0.10206429709796794, 0.12827053345972672, 0.11422913652495481, 0.08678332800627686, 0.14515624847263098, 0.14280997827881947, 0.11985023724264465, 0.1224528304010164, 0.08878113017999567, 0.20181180210784078, 0.12975110323168337, 0.10349454183597118, 0.07878736214479432, 0.17281876411288977, 0.10781948905787431, 0.07177002189564519, 0.2187954806140624, 0.13959612260805443, 0.30203949892893434, 0.16911299811908975, 0.08785624348092824, 0.10559860471403226, 0.11458626540843397, 0.11475212799268775, 0.12599714216776192, 0.09379151757457294, 0.128614533750806, 0.07250132679473609, 0.14881919254548848, 0.10164607461774722, 0.2223934867652133, 0.10632590943714604, 0.12992046133149415, 0.11626585692283697, 0.1529880438465625, 0.11290455135167576, 0.29286207107361406, 0.11404241959098727, 0.2072587949805893, 0.15075599018018693, 0.18218128359876573, 0.28188048221636564, 0.09261151019018143, 0.14233877387596294, 0.12180182588053867, 0.17215025232871994, 0.20781102706678212, 0.14239528100006282, 0.11593632108997554, 0.1597611655597575, 0.16747254005167633, 0.06726026505930349, 0.12676329090027139, 0.08936596481362358, 0.1597610319731757, 0.2961494884220883, 0.22648985992418602, 0.13562725041992962, 0.2580489922547713, 0.19598482962464914, 0.14920096815330908, 0.14818452269537374, 0.1165041902277153, 0.13648607855429873, 0.15465523407328874, 0.18928936624433845, 0.13423676253296435, 0.19345688167959452, 0.09623043748433702, 0.09042398538440466, 0.16735091689042747, 0.1521138532552868, 0.13846154208295047, 0.13086859951727092, 0.16758792917244136, 0.15868778253206983, 0.1258843654068187, 0.14582452276954427, 0.12188761073048227, 0.11945712161832489, 0.12038427186780609, 0.16126864560646936, 0.10475979972397909, 0.09036919262143783, 0.1337797479936853, 0.22109367448138073, 0.2423857874237001, 0.18575178575702012, 0.14168302703183144, 0.16641201102174819, 0.15341761376475915, 0.13255087018478662, 0.1380513867479749, 0.23137390409829095, 0.19373312388779595, 0.11944603393203579, 0.1619435695465654, 0.1515471047605388, 0.1431978988694027, 0.13760505913523957, 0.057217084831791, 0.17037329846061766, 0.1337828056421131, 0.18053074716590345, 0.07919503870652989, 0.10351418648497202, 0.1620208568056114, 0.1408185437321663, 0.17826397583121434, 0.12995396187761799, 0.15486975928070024, 0.16206900734687224, 0.12922631576657295, 0.1603711218922399, 0.08683930820552632, 0.22517719364259392, 0.11084015626693144, 0.10118543097632937, 0.07907697785412893, 0.14545698155416176, 0.1545525505207479, 0.22429688775446266, 0.10772775960504077, 0.21680089936126024, 0.16012322972528636, 0.1098417078901548, 0.08075980513240211, 0.16923331510042772, 0.1329775308840908, 0.34797018743120134, 0.13949648186098784, 0.10534435234148987, 0.2068754460196942, 0.12046365940477699, 0.14185569511028007, 0.10168560140300542, 0.13401051139226183, 0.10196990333497524, 0.10123732936335728, 0.12486193823860958, 0.13405514415353537, 0.10267089892295189, 0.136612169444561, 0.11430265367380343, 0.14251921966206282, 0.14811312808888033, 0.06554002611665055, 0.13793577498290688, 0.11042602302040905, 0.16011818312108517, 0.11834656441351399, 0.09900792516418733, 0.12050373537931591, 0.11883267114171758, 0.15315327560529113, 0.12211831475724466, 0.10039554836112075, 0.318024706793949, 0.12784226972144097], [0.02679423996596597, 0.048001629329519346, 0.03132169702439569, 0.015578301281493623, 0.019345218388480134, 0.02929760426923167, 0.029025241638009902, 0.04006713927083183, 0.06271089980145916, 0.01512772023488651, 0.01746823785651941, 0.014829243282292737, 0.022337878799589816, 0.031140123173827305, 0.06761530108633451, 0.025692527306091506, 0.016551277294638567, 0.027344058216840494, 0.03929725382477045, 0.051116753384121694, 0.013518615123757627, 0.0799518586427439, 0.041171273187501356, 0.029124440807208885, 0.02701151854125783, 0.09160100191365927, 0.056328066129935905, 0.036607606743928045, 0.07365863188169897, 0.016463590691273566, 0.043240996892564, 0.03142228400975, 0.047989740123739466, 0.03366206343343947, 0.04233127969200723, 0.018312527317903005, 0.03274806404078845, 0.05986543881590478, 0.017170540158986114, 0.009251310511899646, 0.007256578510350664, 0.014236906463338528, 0.03638173409854062, 0.06504395234514959, 0.020778233192686457, 0.08408088629948907, 0.019515448511810973, 0.03114109167654533, 0.004034457633679267, 0.0493482340243645, 0.05761709871876519, 0.08038521351409145, 0.009724741357786115, 0.026356641865277197, 0.041712410165928304, 0.03971981044742279, 0.06703641105559655, 0.02768363159702858, 0.12376591970678419, 0.04978331438906025, 0.039844042257755063, 0.02214587220805697, 0.0027063015704698046, 0.025710459449328482, 0.10313580249203369, 0.014429422353714472, 0.09831984294578433, 0.014101714059506776, 0.03696604551805649, 0.006345636302285129, 0.02622268792038085, 0.05547427346755285, 0.0400845203694189, 0.04934167714964133, 0.11362061253748834, 0.04251356229360681, 0.06419403740437701, 0.03262670063122641, 0.0507278049190063, 0.012358177245914703, 0.06054465236957185, 0.06540098474943079, 0.06996337469900027, 0.03948877987568267, 0.024946244011516683, 0.04965091895428486, 0.05339858660590835, 0.08418417841312476, 0.058120749818044715, 0.036798676374019124, 0.013460647824103944, 0.017748446844052523, 0.039952021033968776, 0.0913932450930588, 0.07851572867366485, 0.02372613838815596, 0.07104347416316159, 0.029617189757118467, 0.05411356425611302, 0.032599931364529766, 0.02091385696985526, 0.08488629464409314, 0.02801785223709885, 0.02764335153187858, 0.04321177853853442, 0.04431095119798556, 0.04204648794257082, 0.02210789651144296, 0.04550079574983101, 0.05360652525268961, 0.08503802673658356, 0.024848325047059916, 0.031345000461442396, 0.023152851572376676, 0.031146219916990958, 0.02559222419222351, 0.08024894777918234, 0.02679412493307609, 0.061500245428760536, 0.022185115121828858, 0.025537555738992523, 0.06617444363655522, 0.05668231548042968, 0.07222811997053213, 0.0510986041626893, 0.0188211860586307, 0.0756988552166149, 0.027364415327610914, 0.030863060892443173, 0.09029790191561915, 0.12512977933511138, 0.0026749878088594414, 0.01657188116951147, 0.022995861363597214, 0.016794286129879765, 0.04591680291923694, 0.02568447500379989, 0.003988601256423863, 0.058469911746215075, 0.04192610787868034, 0.02026858554017963, 0.026165110248257406, 0.024854438488546293, 0.04893393379461486, 0.014460087895713514, 0.04349067763541825, 0.04953543335432187, 0.06676955701550469, 0.04393614064611029, 0.020503898304014, 0.01305478674112237, 0.03671781567391008, 0.04899454128462821, 0.03445204252784606, 0.016669532960804645, 0.03611237531004008, 0.042042947898153216, 0.03128233351162635, 0.06130627771199215, 0.042126821717829444, 0.014725000291946344, 0.04049915456562303, 0.07159062253776938, 0.07875680792494677, 0.009630349450162612, 0.05747514071117621, 0.04537846383755095, 0.03969482975662686, 0.02399936376605183, 0.029137445089872926, 0.065758811251726, 0.046622529698652215, 0.035136154256179, 0.04429944419825915, 0.02864096128178062, 0.03569585605873726, 0.019200879942218307, 0.05037173359596636, 0.0662309062317945, 0.05534558506042231, 0.05896630093047861, 0.04936029392411001, 0.013839647799613886, 0.04164552410657052, 0.03670304693514481, 0.022662809606117662, 0.013152930205251323, 0.0259322836791398, 0.022646250436082482, 0.03221099774236791, 0.04446910657861736, 0.03918047688785009, 0.022026941187505145, 0.016203132108785212, 0.0702148959680926, 0.052582046046154574, 0.013772209767921595, 0.019423251505941153, 0.014968857958592707, 0.004427108488016529, 0.033579065348021686, 0.01952160833752714, 0.014297092784545384, 0.03671009362733457, 0.039662312556174584, 0.013281786523293704, 0.015861345273151528, 0.050692449003690854, 0.0178351649446995, 0.09499783409410156, 0.021352635085349903, 0.01589811497979099, 0.004176450429440592, 0.10706137036322616, 0.061644470697501674, 0.05104160351038445, 0.01743222699587932, 0.030966215708758682, 0.05670743717928417, 0.014631534213549457, 0.07029551547020674, 0.018521877900639083, 0.021728341780544724, 0.024535671218473, 0.04304530368244741, 0.03041263476916356, 0.018877364782383665, 0.057662625767989084, 0.05121967442391906, 0.0347015043371357, 0.08465639955829829, 0.04003838846983854, 0.04850385550525971, 0.05091992839879822, 0.0611025655962294, 0.06946485184016638, 0.014171095590427285, 0.02448204733809689, 0.010513804827496642, 0.026440985093358904, 0.07124541996745393, 0.017984134392463602, 0.02309406605490949, 0.03702649715705775, 0.016257349707302637, 0.03277869618614204, 0.005597783829216496, 0.05766562775534112, 0.031663923582527786, 0.013373028941714438, 0.05101221817312762, 0.04276225226931274, 0.055608913899050094, 0.04221019087708555, 0.08325188508024439, 0.030281688377726823, 0.03296200666227378, 0.08575816231314093, 0.024383983654843178, 0.06753787281922996, 0.026652033338905312, 0.0025647907068560016, 0.07800009188940749, 0.04091310969670303, 0.06851545942481607, 0.024011180612433236, 0.0642703969788272, 0.03798003446718212, 0.04384424049931113, 0.049059082157327794, 0.1225692214211449, 0.05642963275022339, 0.0404425695160171, 0.05051450425526127, 0.09400849929079413, 0.03419160064368043, 0.03991012679762207, 0.0627168221399188, 0.09481478336965665, 0.01269300737476442, 0.024584126040281262, 0.013318443980097072, 0.033306136829196475, 0.048075280064949766, 0.07990880665602162, 0.030825608409941196, 0.05409536308434326, 0.043524248685571365, 0.05513598400284536, 0.02017696369875921, 0.05552991970034782, 0.014743807241757168, 0.08950285395258106, 0.048114721503225155, 0.049736737200873904, 0.06695085627143271, 0.06895540456753224, 0.025164815779135097, 0.03599376155762002, 0.027915003556699958, 0.038711892266292125, 0.037483652704395354, 0.009271745548176114, 0.02616363522975007, 0.044152142727398314, 0.06566027630469762, 0.0879283357062377, 0.04698071243183222, 0.02058188503724523, 0.029342409579840023, 0.0404352890473092, 0.03279497890616767, 0.020505074608081486, 0.09195404156344011, 0.04610451062035281, 0.05241298480541445, 0.024296361989399884, 0.04221809474984184, 0.021277609521348495, 0.04527531644271221, 0.020939867390552536, 0.03617997012042906, 0.05957679903076496, 0.0963651150232181, 0.02728953077166807, 0.0520647282974096, 0.025669953029137105, 0.020763449610967655, 0.033808407533797435, 0.031904661445878446, 0.04212411287880968, 0.12554722256027162, 0.007759054697089596, 0.03030000087164808, 0.038968397057033144, 0.047329781591542996, 0.005674926369465538, 0.062454153812723234, 0.022526022512465715, 0.0637088212533854, 0.03364734664501157, 0.09340574179077521, 0.027168273118149955, 0.034790228091878816, 0.028417329922376666, 0.03896907983289566, 0.02937096927780658, 0.04597402992658317, 0.06889488984597847, 0.038705558035871945, 0.014418163045775145, 0.027624215254036244, 0.10334539983887225, 0.160384243063163, 0.12247393708094023, 0.09518547129118815, 0.18723689747275785, 0.1000526687130332, 0.08532027291948907, 0.16593188600381836, 0.14720625331392512, 0.19005042384378612, 0.10954697878332809, 0.13849317241692916, 0.07574447503429838, 0.16064911556895822, 0.22081798146246, 0.1540715794544667, 0.045679887116421014, 0.11118109890958294, 0.11088214698247612, 0.115653948741965, 0.05643835298542399, 0.2265496621839702, 0.10446461048559286, 0.1691040032892488, 0.08985949301859364, 0.1597504786332138, 0.11104305944172665, 0.1386665678001009, 0.1242215464299079, 0.05995031453494448, 0.09384337885421701, 0.10639060245011933, 0.18877829366829246, 0.19187345023965463, 0.09999749745475128, 0.15289306378690526, 0.15258250467013568, 0.1831803034292534, 0.14842733857221901, 0.10813395187142305, 0.08815573717583902, 0.13541907799663022, 0.11685052086249925, 0.13942667545052245, 0.13366091530770063, 0.13261551124742255, 0.130612647626549, 0.11727045770385303, 0.17032424249919131, 0.13453213730826974, 0.14981821237597615, 0.15835301455808803, 0.17255591024877504, 0.1461173000279814, 0.20942317962180823, 0.15150184859521687, 0.11926532097277232, 0.1592582417652011, 0.1915474544512108, 0.13550604286137968, 0.19593653065385297, 0.12462232843972743, 0.0680208254198078, 0.14871221937937662, 0.1506442078971304, 0.16732963209506124, 0.13458235102007166, 0.12829575163777918, 0.0984200180391781, 0.06290246295975521, 0.10959213846945204, 0.2074574975995347, 0.10034251448814757, 0.18656302738236263, 0.21324936649762094, 0.11082489771069959, 0.2083958245930262, 0.1727286376990378, 0.19902500789612532, 0.13057620817562565, 0.1464405350270681, 0.27358401333913207, 0.10518968134419993, 0.1645942241884768, 0.13526505266781896, 0.11737320804968476, 0.14988865703344345, 0.17449824430514127, 0.22596793714910746, 0.14390905445907265, 0.11235695768846199, 0.17734552355250344, 0.14682968758279458, 0.19817391294054687, 0.19710133143234998, 0.1259989381651394, 0.2641593909356743, 0.10302098482497968, 0.19979439239250496, 0.1402097154641524, 0.1435861608479172, 0.1954581867903471, 0.1668747400981374, 0.14369561278726906, 0.10427316607092507, 0.08240336537710391, 0.10588934848783538, 0.13601610611658543, 0.14764137449674308, 0.24100650596665218, 0.1656132671632804, 0.0950162393564824, 0.2286524188821204, 0.1232447539223358, 0.1978025125572458, 0.18702243163716048, 0.24848091270541772, 0.15510686062043533, 0.16953222249867395, 0.15000020182924345, 0.20577921968651935, 0.13566961220931262, 0.11423100673709996, 0.18612946470966563, 0.18572515749838203, 0.09595377967343666, 0.09566041611833498, 0.132687826117035, 0.17987262544920668, 0.23217738285893574, 0.24790087976725772, 0.10474384354893118, 0.13540214218664914, 0.10616491534165107, 0.2221158641623333, 0.16616199631243944, 0.11786926697823219, 0.15324910171329975, 0.15017221681773663, 0.1215057386434637, 0.06700412021018565, 0.170657837879844, 0.13484369090292603, 0.12967844697413966, 0.12952909717569128, 0.1508945194655098, 0.10232704706140794, 0.2619936258997768, 0.10783161575091071, 0.13310716924024746, 0.07250524533446878, 0.20605436351615936, 0.08912527890061028, 0.09064881902304478, 0.1379488516249694, 0.1608356914948672, 0.12126713816542178, 0.17136146809207276, 0.09038825097377412, 0.1504906575428322, 0.10286945311236195, 0.15451562125235796, 0.11735822408809327, 0.22538717690622434, 0.05376799432269763, 0.18158891616621986, 0.1373015801073052, 0.12682150496402755, 0.07141253678128123, 0.11382640266674571, 0.08822095711366273, 0.1469427315169014, 0.09879506236757152, 0.11442766844993457, 0.14975281432271004, 0.11798495295806788], [0.05131261357746553, 0.019872644188581035, 0.03775979843339883, 0.047303810133598745, 0.06878414656966925, 0.06912422089953907, 0.04197833652142435, 0.047802511107875034, 0.024584545353718568, 0.01560878870805027, 0.010926887935056584, 0.03892463631927967, 0.06808282443671487, 0.030867747555021197, 0.048308277328033, 0.03195113102265168, 0.05593313595454674, 0.030703604898008052, 0.10284799020155333, 0.028544535889523104, 0.041156515580951236, 0.03852774687402416, 0.023308808340516407, 0.08085055495030247, 0.09130559745244682, 0.032028551868279465, 0.04739276395412162, 0.021889953713980503, 0.06816911394707859, 0.03264494262111839, 0.015959846823534463, 0.045753344893455505, 0.002943911745205696, 0.02964684597827727, 0.02860437896742951, 0.05853867172845639, 0.03877381335769314, 0.1093122226302512, 0.05388898294768296, 0.10158180462894961, 0.020980490699002985, 0.08963455547927879, 0.08348832590854727, 0.024621584088890813, 0.017877788341138512, 0.10503408266231418, 0.06978913326747715, 0.022917770729691256, 0.01392428603139706, 0.07420699737849645, 0.023444721555279102, 0.05558887591178063, 0.08033292178879492, 0.0192318441986572, 0.023242078132170718, 0.02142272536730161, 0.010160384827031521, 0.04078323385328986, 0.05528645444428548, 0.06593449987121858, 0.010799045576277422, 0.028803317218262237, 0.06766753343981691, 0.020865173937636428, 0.050268363556824625, 0.022311979701044038, 0.020833730995946098, 0.04043398657813668, 0.029674346260435414, 0.04398994264192879, 0.009055720274773194, 0.006529289557875018, 0.02373833929596003, 0.022685801341140177, 0.057075193617492914, 0.07253260089782998, 0.05101633338199463, 0.009405944401805755, 0.034773321967804804, 0.020915079658152536, 0.006309945492830593, 0.03604746707424056, 0.02431609384075273, 0.05587727078818716, 0.04742860226542689, 0.055876803235150874, 0.12434414922608994, 0.01701998437056318, 0.04395348092657514, 0.05975040221528616, 0.09433979401364923, 0.06563483548234217, 0.04570919081743341, 0.016288861297653057, 0.01379687226290116, 0.006665113251074217, 0.025591025623725727, 0.06249152836971916, 0.06387314017047174, 0.014026689423189964, 0.014505376529996283, 0.03288682710262947, 0.059731106375693344, 0.0474127982306527, 0.058883944802801125, 0.040112302667694166, 0.059796266941702925, 0.016490992638864554, 0.05705285497242585, 0.04387820117699448, 0.033277241309406236, 0.04405179694003891, 0.02187098070862703, 0.06014194448653143, 0.047953812754713, 0.018719454310485162, 0.016626545912004076, 0.011821263087767875, 0.06538954825373366, 0.041781849213293754, 0.04460404015844688, 0.09435506741283461, 0.0532101887074532, 0.06584107090020552, 0.020518468518275768, 0.024003831495065242, 0.016376718594983686, 0.046073518533376046, 0.02773472104308894, 0.025036073566298, 0.03417794512643013, 0.026762457491713576, 0.03130550707282964, 0.009679246777523076, 0.03743691966519691, 0.051365595500101335, 0.04338863604061771, 0.06222607698873617, 0.04024022666271776, 0.01771195173205342, 0.05677492808899842, 0.0724451091082301, 0.04746376893308479, 0.01515540512627922, 0.049548075839993544, 0.06123760307673365, 0.06128714143414982, 0.04734368201752659, 0.01374691830278607, 0.11899619596078992, 0.03907354825059883, 0.045332769805099815, 0.02610047104099067, 0.057953191426349804, 0.05034420362790115, 0.014082200214033946, 0.0366446213593008, 0.03579931886633858, 0.024189704236050602, 0.024537168501410633, 0.03813232688116841, 0.09186957773636095, 0.015382170204247814, 0.023346238558588084, 0.08273491985164583, 0.04492536041652784, 0.03690307057695463, 0.0457306166208582, 0.027838536370836664, 0.060207706192159094, 0.03577915842470247, 0.0309094655312947, 0.030282812731456943, 0.0777985542663373, 0.040428101347060874, 0.03082069910306018, 0.021845372903044336, 0.02602917476906441, 0.020323812459537294, 0.08163674909155816, 0.03387383527297061, 0.022602300450671464, 0.025640988860686775, 0.01027648455419694, 0.030678935909236316, 0.009919098702084739, 0.007029677062746487, 0.03570670996850822, 0.047787927906028926, 0.014625557141698664, 0.020527144224615768, 0.03442952947807498, 0.02019027782807825, 0.01795720927475486, 0.06742784942616709, 0.04372166367829777, 0.04540184891084209, 0.021274190075928345, 0.011706770110322395, 0.059834101630258374, 0.06383051120792516, 0.02864423415303463, 0.023480756535718683, 0.049330749025102705, 0.046399544007726945, 0.023504766868427396, 0.018809658649843186, 0.06625050635193475, 0.0674039671139326, 0.031799829375813715, 0.04241603295668028, 0.020083213748876005, 0.019704425285453908, 0.022207134643394966, 0.06127952328824904, 0.042097228579223156, 0.029629652271978557, 0.024115196320053656, 0.03570481749193277, 0.005831676307934686, 0.03689748220494948, 0.047750341836945154, 0.04397935590532143, 0.01417413746821694, 0.0114622333785519, 0.013631974470627028, 0.04924422573822085, 0.06845314870588481, 0.11375824382412247, 0.051266318405396305, 0.03788932546740398, 0.020114395083510317, 0.025405125052202493, 0.02422387828119099, 0.04332091877586208, 0.03843370563117787, 0.043150414057890885, 0.040868896248866804, 0.02070557136903517, 0.03610731757362373, 0.034453044427209534, 0.03131217526970431, 0.036506459437077865, 0.05780172650702298, 0.043889890002901666, 0.020502629231486935, 0.07272118062246591, 0.037590982101392, 0.03738365201570559, 0.00832658708532108, 0.029646519433299545, 0.013403472767095082, 0.03921111274394207, 0.05454356090922374, 0.07442407557391562, 0.053057488112244755, 0.06305023198365234, 0.046018054126761854, 0.017968450956686866, 0.025955043493013363, 0.02840553534042556, 0.02184497585403733, 0.03810203983448446, 0.011789244053943548, 0.023854041974118445, 0.04426706429512706, 0.041298421638202854, 0.03517144708894193, 0.03565519378753379, 0.028476493935158942, 0.023625699832336977, 0.026763683890749235, 0.036902580759488046, 0.048047954187495634, 0.02321342381037539, 0.03792430659814272, 0.03866250975988805, 0.05304127960698679, 0.05279338744003326, 0.060841099548269995, 0.03206343280908186, 0.03800878155743703, 0.07145400057197548, 0.06166555511299521, 0.10703358435421251, 0.026310131470381748, 0.03585892445698846, 0.056625355646247044, 0.049010208022082224, 0.015278164701157948, 0.06610639611608349, 0.0615034403745085, 0.019316148463985883, 0.019374839357624296, 0.016493773837282788, 0.022966713513596915, 0.042251175982528366, 0.01433096904293052, 0.04762033982842695, 0.05634766996081453, 0.015154388383962214, 0.002836118969753443, 0.03509999682137277, 0.03442388915573247, 0.02877096143492963, 0.038195023516891524, 0.05884706748474855, 0.018063501520373393, 0.03266701038228348, 0.05908557890506927, 0.10136096374480985, 0.09716909102280624, 0.02882624772610143, 0.028460752982937265, 0.04827880664379336, 0.05311361303029116, 0.042460227850824594, 0.04470556596061215, 0.049779885666794144, 0.011554530574358068, 0.02894532161008101, 0.018832952810043935, 0.04052197189594153, 0.03456951708358247, 0.03686477575683966, 0.0471332942834124, 0.07052204862702638, 0.02800151014525909, 0.020732765515276697, 0.028544572996906936, 0.05655296285112854, 0.05433472426375374, 0.043627255072351545, 0.017449129409214947, 0.027218663090025075, 0.037739597173640504, 0.03140365610306617, 0.07108529418474063, 0.04797391011379659, 0.012614364768523956, 0.011585323209146736, 0.01778245761670405, 0.021687295447918586, 0.056623195996508, 0.009430958489247132, 0.037104415241628885, 0.010955160978483036, 0.024417562126473058, 0.023898474355519284, 0.012865443532064091, 0.03709215496201068, 0.06805263386922888, 0.12831711064791307, 0.08454078779323027, 0.10803765821037814, 0.08892287296475843, 0.1539218140533194, 0.08038709114771336, 0.11577796161873266, 0.11258003985858522, 0.23969392874278128, 0.1656368377734907, 0.1352548852446489, 0.09329786320449784, 0.13477119791787118, 0.17194420244777575, 0.09589917986886576, 0.12486183433793485, 0.17935392359504476, 0.11049513923353516, 0.18318157992325723, 0.14178340992657468, 0.21344830660382286, 0.12261973941349424, 0.08014862425625324, 0.21242228744085878, 0.15291866788174957, 0.08359140279935673, 0.0987721819547005, 0.13485816278262064, 0.13978407892864197, 0.145864732330665, 0.07051038948702626, 0.16247246850980446, 0.2835277235135436, 0.1319377968320623, 0.1385272221523337, 0.14089933392824605, 0.13246132264612243, 0.1645374795771204, 0.1299966502119787, 0.1695832674158737, 0.09602950100088492, 0.15088291227584705, 0.18215658492408693, 0.07913928115158342, 0.07906784943770617, 0.25516657973639667, 0.08365990302991122, 0.08292389291455038, 0.08388748261495493, 0.13345287647098303, 0.20729990996187553, 0.18082396971294656, 0.18003972742008045, 0.11081911638029851, 0.15913960203761235, 0.1204768028401304, 0.09308836975833401, 0.12135920900618657, 0.168791098985821, 0.15352871327195317, 0.12683536828262731, 0.14755941170733422, 0.11741061229258776, 0.16225467785261571, 0.1374865826801397, 0.14721964165801182, 0.10861702321562916, 0.1810865118750371, 0.16223618353251368, 0.21096367039717734, 0.10262128635076806, 0.10085153873660602, 0.11142366245621815, 0.12769786262651905, 0.1219248294364661, 0.10795822614454664, 0.16199446603422984, 0.24752287426963449, 0.2016497467411682, 0.12031263977405615, 0.1431028891238384, 0.16263241617707536, 0.12646232033148408, 0.23084056709194556, 0.14612580504035577, 0.13263930450193584, 0.24072707252344117, 0.1236599484400358, 0.21864860958885401, 0.1469945185817778, 0.2262490923749283, 0.11086097350926138, 0.08594841187004931, 0.10981825602357276, 0.15294066513888538, 0.07755397207802162, 0.15642748272512108, 0.22520619677379727, 0.14926878560800105, 0.14596563472878188, 0.20002374571049586, 0.12390585907269269, 0.13164712727302685, 0.20755108242155984, 0.22848681604955345, 0.12471684836782515, 0.17359334364300594, 0.12053961821948178, 0.19286270340671763, 0.11025202649761923, 0.122652416175697, 0.1703244206146337, 0.11743695853510872, 0.22614410816458985, 0.24777833634288982, 0.16793308721389621, 0.05833678529597819, 0.09860944381216541, 0.14305564400274307, 0.16653234284603968, 0.0953894728445448, 0.1774488898809068, 0.09942933887941763, 0.21324148488929495, 0.10746681306045502, 0.11774296086514369, 0.07387289733742364, 0.11530381088959984, 0.14320388057967648, 0.1564846429391764, 0.1739663173793815, 0.1398245556629263, 0.0976364807866048, 0.15867268724832684, 0.2416522041312419, 0.17855584766948596, 0.16673609206918627, 0.13206945382989943, 0.1571342596434988, 0.11855563483550213, 0.22841021156636998, 0.15130556537769735, 0.21330830786610022, 0.067277505149832, 0.12046768184518442, 0.10091152653330937, 0.12283202333492227, 0.1419353423989378, 0.2331795048667118, 0.16720564890420064, 0.14597002824302763, 0.14915440580807626, 0.10252791675156914, 0.14098698156885803, 0.12546675890916958, 0.11541365616722032, 0.17141037562396377, 0.14514202892314643, 0.07141764275729656, 0.11352296816767193, 0.18944886862300336, 0.19027112371986732, 0.11363272438757122, 0.13392301218118519, 0.13633782713441178, 0.1144999684765935, 0.08185370112187229, 0.12440060439985245, 0.08111421775538474, 0.12755626084981486, 0.170829541166313, 0.11107748025096953, 0.10143428051378578, 0.08786106744082645, 0.09017178133944981, 0.13032300223130733], [0.002818297220983368, 0.0229473731451435, 0.032406746613560244, 0.028362631783238612, 0.07704628369538113, 0.036797370194108225, 0.0166246590015362, 0.047758720684214495, 0.0527762920683017, 0.03892043205269147, 0.08644976231153123, 0.10123097657924518, 0.015671669025323354, 0.03958616820455063, 0.005188773720874451, 0.02325495439436054, 0.012291227176319808, 0.04588047479046509, 0.08746623745537363, 0.019962785445386544, 0.010249271854263498, 0.04686212836531922, 0.05381529510486871, 0.0829279821482487, 0.059563377290032804, 0.042068470356753096, 0.011351844477758277, 0.01937839981110301, 0.03673501865705475, 0.028472146805142984, 0.0358829292235896, 0.006014795217197388, 0.06375260054483078, 0.11112120759207755, 0.029946859176561702, 0.04881320863205474, 0.0052695852536999155, 0.027754113361879718, 0.04847929783863947, 0.05581976176472381, 0.04494676395552233, 0.026242983803967945, 0.01728512219415279, 0.033177448422065936, 0.008459421314910287, 0.04951686110871378, 0.05057111528003588, 0.025287708012911025, 0.032226141265709884, 0.03959924113587476, 0.07988170342287049, 0.07761477623716928, 0.038101564859971404, 0.047906263353070244, 0.04249774712661747, 0.03288177678768989, 0.01780615253665019, 0.04159198928391561, 0.029318315755517688, 0.05596627284830902, 0.06408764311345294, 0.05467818278702907, 0.04671014023188036, 0.022607673599850386, 0.01085521687855362, 0.04703483726189006, 0.04836803134821821, 0.021345592103898525, 0.03644859047199134, 0.03227251065254677, 0.0029311196703929454, 0.06257091590669006, 0.017908377813000698, 0.0724551577877719, 0.052172306313877925, 0.042680000042309985, 0.02180623574531637, 0.018377938358753454, 0.011297117580397753, 0.07917824390460737, 0.03866040948196314, 0.011949493218708085, 0.017664472834439948, 0.012103769022360211, 0.02165126603358658, 0.06905601752805524, 0.0903121214651037, 0.06087162037147209, 0.002850453552127874, 0.04239930123731028, 0.08523194992449135, 0.041172237979481, 0.038563199268537574, 0.0317178331897594, 0.010313520506315399, 0.05594088768702932, 0.047778814332559705, 0.013383816058194498, 0.030561754501832183, 0.05819860853080172, 0.029589554033009335, 0.02394875857135048, 0.010397315472800983, 0.03888673112669494, 0.029605252311739605, 0.01804771789466031, 0.011898556840606034, 0.03206842375220731, 0.025079975312110037, 0.08640328160254285, 0.020284384008846246, 0.05604639882221818, 0.04458805429749191, 0.038660175705445, 0.05246515778708272, 0.03605621328460984, 0.030291169314295985, 0.061322760811890475, 0.013201969468354946, 0.08422919709119014, 0.03820609264948871, 0.008621941451565363, 0.0616981799248606, 0.07152117235818878, 0.01698089916317258, 0.051102604338666424, 0.022581921075470746, 0.040813643354340456, 0.023722622463537846, 0.0062195732425607275, 0.012206678929942427, 0.05794102391519118, 0.02974572231323691, 0.017810035824368242, 0.00716525863026618, 0.11865138672874309, 0.032433278393000364, 0.01963700673513813, 0.05435414997918997, 0.03728261603100691, 0.06481505915871821, 0.05876455550605897, 0.02730203039391199, 0.07740893415757455, 0.05414920589828398, 0.003548245845195197, 0.017463141157350037, 0.06636504200287163, 0.033492386210127734, 0.01750127641571453, 0.05819057107146364, 0.040553624494350515, 0.053119962103664875, 0.005396025417212513, 0.00948865026657586, 0.027624855356407352, 0.04927197463985067, 0.043910466047236696, 0.03161258551699575, 0.07207419112091884, 0.01704972037259722, 0.05188721028389409, 0.0091259654800524, 0.05990447949443478, 0.0186145628686063, 0.04664708365453407, 0.026800811683642678, 0.07075834102579392, 0.030303553903650027, 0.06299601067439653, 0.05485760440933518, 0.017751474806573242, 0.06616206461330876, 0.02738804159889696, 0.0021951318194624037, 0.041808232563198544, 0.03392599341168534, 0.04410219989949837, 0.0196532801783178, 0.004712685986305587, 0.03457056722254492, 0.007228706226669601, 0.01776985780452378, 0.05671581602655351, 0.014712338324898155, 0.028833470678364392, 0.014438777125178603, 0.019032366035389714, 0.003655262148640759, 0.03542546939570457, 0.0229365730410791, 0.028795480138796847, 0.05011925495637115, 0.051781257570837624, 0.04084642030647956, 0.020070728969585616, 0.0191618411190575, 0.04241650050971657, 0.04552340156806167, 0.03433155856328085, 0.06194601272, 0.06175601178256329, 0.029730428504990414, 0.028724267358484212, 0.0410418574756477, 0.05931172985583544, 0.020646501980081666, 0.023677958160988055, 0.03995598781330045, 0.0041682677874632645, 0.05115885542181786, 0.027243402582826093, 0.026891374109254684, 0.040486927682650276, 0.03590968364733271, 0.011185916955582798, 0.08606937451986596, 0.03070294809731422, 0.06414297764422372, 0.03789333306485787, 0.035692690798896365, 0.03592010340071283, 0.00769496421526128, 0.054381019435822964, 0.013429713253572118, 0.05672483312082477, 0.04924843000480905, 0.04624337758286856, 0.02295156071340898, 0.05071421248430852, 0.027183501988474745, 0.059549996367422864, 0.009069109546544496, 0.02959643374197185, 0.05522674495296087, 0.03871982582495548, 0.048713593860156834, 0.026123201168957166, 0.021457769580592867, 0.051358823402551934, 0.02725065151025774, 0.01716823950118851, 0.015069623059389414, 0.009593921131454408, 0.04536320899205748, 0.024419888759439345, 0.023712649854132906, 0.019802368369710166, 0.015330448077293113, 0.06006388910464011, 0.04690119872975629, 0.07141675960156135, 0.039066631434252486, 0.07672118590562604, 0.02117614680173574, 0.13443907198961824, 0.005099136660646764, 0.026141057242057286, 0.006248656618481618, 0.03628835336712655, 0.01756577090418432, 0.08759102216572501, 0.06631743322941475, 0.03334337037813384, 0.03624200624471996, 0.021740670708823018, 0.1019034514320083, 0.02471730073011713, 0.039974144456209615, 0.07082022129907273, 0.029657102459168527, 0.028041142686561216, 0.08025028364500031, 0.03882388977217488, 0.020191289004287682, 0.03765823181311134, 0.042532067745923996, 0.062095355096971616, 0.028984894779569004, 0.06754711997928098, 0.028966303980269004, 0.046729988971492276, 0.07000556579441763, 0.01547233187011443, 0.08804819997749291, 0.04153646921622567, 0.007673413638258353, 0.03454830279224552, 0.019631266222859267, 0.0050658230429689866, 0.06391022528987378, 0.061671841103816405, 0.050175788055639714, 0.033415340149076656, 0.04759566341817845, 0.08450106804957613, 0.03572028756025247, 0.03177415477694012, 0.03820815953076817, 0.13828856230247766, 0.021676406286132988, 0.03850361223157961, 0.011235524889343651, 0.0460813185054576, 0.017670354354777373, 0.07188442396000028, 0.016438843776995782, 0.07671586470678449, 0.016577037240494974, 0.05376741915824823, 0.06379353741067462, 0.009486277249379782, 0.02009321418881882, 0.03560940698662307, 0.01870652980869636, 0.034078809039783664, 0.05024010257329792, 0.03898015267623123, 0.026237866695737466, 0.02513456955057336, 0.09537134217680432, 0.07463908317731693, 0.044560108726727776, 0.039529494097223505, 0.03384030133020133, 0.02430305987218162, 0.0867249358270783, 0.022719745320500806, 0.05478976097947452, 0.0510663801105693, 0.027649969633785076, 0.013368690160859842, 0.01731694177578902, 0.011849739294120809, 0.03342273565067444, 0.025851441532722674, 0.05200935665925499, 0.05937409994658083, 0.047154200583463535, 0.039995295664994046, 0.045746813993901014, 0.03620111761847511, 0.038421304343501106, 0.07701141759753227, 0.005028179457440274, 0.046016506748856045, 0.03336393529025372, 0.0661802694958169, 0.04322134853282478, 0.07330497624934651, 0.027816238543891814, 0.012590167971211486, 0.1573165162699297, 0.09939551178831607, 0.08425476407865062, 0.11962701406446286, 0.23286977695534006, 0.13074143993435428, 0.060958336616749875, 0.17771211481885985, 0.12177331998827867, 0.09124834075919352, 0.08102289648377337, 0.2860659873113036, 0.13752919679973274, 0.14720546663738787, 0.12193130838568322, 0.11729154954082333, 0.09589515742845833, 0.18231357884360477, 0.23529193917056546, 0.08690614602528512, 0.07981588976690546, 0.12977281847270206, 0.1891587334102951, 0.165129505621735, 0.1130644693330396, 0.16076080879429355, 0.10373481956776232, 0.1312425232026726, 0.13259234139695764, 0.1568077295087278, 0.07395333872409537, 0.11559842867427506, 0.11746441057766788, 0.15728019556263462, 0.11142496121465228, 0.15001008723629639, 0.22021106793545187, 0.17105553997680545, 0.1508495898451656, 0.10807535189087503, 0.13270786410430446, 0.07188403804320842, 0.18288878782186657, 0.10923087582341395, 0.08931874937843531, 0.14316473971121013, 0.15396171191241592, 0.1894427533261478, 0.08989038120489568, 0.12260048068128526, 0.15025938948383555, 0.12897551438072696, 0.08274339517811313, 0.26264155050739646, 0.12284309617825784, 0.11950205123866908, 0.0994093602639623, 0.10455035080667585, 0.07467587885912508, 0.11867653069202788, 0.19799692556262016, 0.09677465437562205, 0.18188694783020765, 0.128710983262863, 0.1999213738599792, 0.12285287026315928, 0.12722034996841103, 0.15502345806453377, 0.21543781156651676, 0.11556290948647074, 0.10701978040742688, 0.17359181481879205, 0.12679527746513486, 0.1307177505805157, 0.13653238856932148, 0.17977957497350872, 0.17194852174725384, 0.17878298938740045, 0.13640527351526543, 0.29543260345235467, 0.13950289401691407, 0.14925521914847195, 0.1274266670225188, 0.1347492600325495, 0.05502160049218219, 0.11077596791437827, 0.22897467424627393, 0.18296966707566753, 0.1433841185644269, 0.09014848532387987, 0.21492492815013975, 0.20516926335403696, 0.17339207319309935, 0.1436913083307445, 0.10185141203692183, 0.15022369218058884, 0.12281471645110287, 0.12034231825964525, 0.1246332676964812, 0.1483621631632559, 0.19639770122012123, 0.2815248747356236, 0.21080287668155506, 0.10830381463165395, 0.10454430230311118, 0.0878642215684522, 0.10687659043469466, 0.09292180955526419, 0.21756571222795174, 0.1670521727646701, 0.1222198479808867, 0.2421846060315147, 0.1481764778145589, 0.11033171831513755, 0.17952780879568309, 0.16812772286357358, 0.16205968597205356, 0.09575832023983821, 0.0914525352709461, 0.2398534756503068, 0.1230343921633903, 0.09140710841165856, 0.1375430155894719, 0.2339656322146766, 0.05765671085100621, 0.07097564928699285, 0.2013759090914391, 0.12837447866331786, 0.12354464837699197, 0.14675441896542907, 0.13911136658862233, 0.10216815324383788, 0.04958838930178899, 0.16348343691788614, 0.1140227378346026, 0.18065395852318034, 0.1247819495620206, 0.1312013340066187, 0.10705935172154568, 0.09417198700248264, 0.13115659734467044, 0.14959264401113614, 0.07085640841978602, 0.16473351046442986, 0.25225504534319043, 0.18433005345286801, 0.17691331158857793, 0.14010136190336198, 0.07566252708784305, 0.11452708655269817, 0.15281120489817113, 0.10924292088020593, 0.1867318808217533, 0.16161968145752326, 0.1280050672357902, 0.12992991629289463, 0.08460424884106033, 0.10926476228632964, 0.14723114494699985, 0.15372714871773496, 0.1824336138088256, 0.12441549188224599, 0.10549100814387202, 0.17454879940487444, 0.09085557394428179, 0.09261546583729796, 0.1618003350449726, 0.3088876814581454, 0.061622792563866824, 0.11489137716125697, 0.18920885806437582, 0.13772245205473155, 0.15901949285762385, 0.21425423445180058, 0.08170164990588091, 0.14243598037865013], [0.024245959029940423, 0.04155285954766441, 0.04889613250270486, 0.04929220929625444, 0.050057014741469175, 0.057496021036058664, 0.028547866277222056, 0.06570804835064337, 0.05736168859584723, 0.02112006641254993, 0.03476844976830762, 0.032598083416814916, 0.043843631938216276, 0.02233036640973296, 0.03969100769609213, 0.035229264103691094, 0.03430088559980504, 0.041586063234717585, 0.026506937902013306, 0.025837717366812285, 0.01952688686287729, 0.011319252134853741, 0.045810790834366344, 0.05902094897464849, 0.013309849910001503, 0.053065050597069785, 0.01972758400370367, 0.06223219599633012, 0.0864223696407862, 0.033729751012288034, 0.03071934770559892, 0.01908754657051759, 0.02407354513707105, 0.028196962157380767, 0.00973280293692369, 0.037689001255785115, 0.07767753966618329, 0.09195009333780035, 0.040259889865410514, 0.039069110207492486, 0.0281068338881596, 0.05601107630354818, 0.03695305422297679, 0.007228989170471323, 0.039426361545338295, 0.03873978217598051, 0.03429014301218558, 0.016392587567679584, 0.07976494875038043, 0.03930981838493608, 0.02930501832452137, 0.11410166524001397, 0.04764200311910827, 0.05666683427989483, 0.06300689798081294, 0.008629724725324195, 0.005860729997948511, 0.06697024116874672, 0.006744545316905715, 0.03673294064356014, 0.029966637412144337, 0.054171748633962125, 0.05316836126439739, 0.07300764220417477, 0.036464298027567565, 0.041016394388861954, 0.03441249718889594, 0.0721201003761962, 0.022704000657540746, 0.021808994679304305, 0.05924029814195819, 0.12458202982088551, 0.04622871274477802, 0.052715176207129844, 0.06464826146839187, 0.02721755728998687, 0.03717661136761308, 0.05955679815087933, 0.02060440365312388, 0.03372152059455402, 0.035442876469460316, 0.0392142928467365, 0.03346854842675384, 0.025676198201836087, 0.024624233556096442, 0.04549111443338916, 0.06984764419030398, 0.048053141799755394, 0.06430296241887845, 0.04465819838515017, 0.017765857628546655, 0.0782799260923639, 0.01766903147654375, 0.011837458605441498, 0.0135546074307058, 0.009415786207682686, 0.028542342843138613, 0.034969479020219296, 0.04898391001916025, 0.043186311741010286, 0.026003116108768154, 0.04878331492363941, 0.06417357639293186, 0.04712823654699605, 0.08219360475777648, 0.018141597720386926, 0.06871992110973224, 0.08263139025075361, 0.15198173612589017, 0.02204606633313233, 0.049196297841263004, 0.039332157030003145, 0.03737709514098242, 0.035914288673666306, 0.07868767686886713, 0.035914481632062234, 0.03899386756529566, 0.012608587148861261, 0.02723913152294699, 0.0016058198320934025, 0.011991501560260076, 0.01930306254507741, 0.020842044905293733, 0.008385029359487817, 0.026983020070474595, 0.01792093495168956, 0.04194156681478489, 0.07432831625919789, 0.004802033608939382, 0.06351004441967234, 0.04739798867376521, 0.01075059260983835, 0.05139874352607876, 0.030507876435876824, 0.014886449880577857, 0.0237636650854256, 0.09314256138168275, 0.04169250576524064, 0.042553653111099266, 0.03752329452254344, 0.011840748175018234, 0.014760523190489039, 0.03116381623840425, 0.017511759251647163, 0.02931679064204218, 0.05891487751796376, 0.07012656555161811, 0.013050271700194571, 0.04065438588440884, 0.04945378968841396, 0.03538763470714912, 0.046240030496846884, 0.015024528311187169, 0.03668509438284673, 0.049284216365776956, 0.03465538356977049, 0.05664109659846872, 0.06912995770107955, 0.06496649439213797, 0.07422332462738268, 0.039352206149487756, 0.0649830220208969, 0.024576884534326382, 0.03182803098752629, 0.08642605069326237, 0.025312117249995936, 0.048053453501779586, 0.0688442234240938, 0.016695227968739346, 0.04455899921595119, 0.034971590430359356, 0.04857635962252971, 0.07179355539847165, 0.025656342040747404, 0.08096056350041181, 0.09559294747305103, 0.03362908239068929, 0.02003796871576924, 0.08522086223820224, 0.033980726802838035, 0.030224563415686134, 0.07685026022954844, 0.00606592177064158, 0.04832050792174414, 0.08140036021359265, 0.03225289940019138, 0.06070275579986628, 0.016754054304328747, 0.04964391308021732, 0.024089605212793685, 0.04776457994012162, 0.0483715528389439, 0.03223271298338659, 0.058477277561905794, 0.07413305720547214, 0.027716595941456035, 0.03280717610323336, 0.02192156363889808, 0.03096483716944931, 0.027653127472149208, 0.09103210861212574, 0.029986957415530924, 0.027554802181839477, 0.04647650472179521, 0.08730917674256489, 0.02056806995824445, 0.026492651559237856, 0.03569245702237822, 0.023426555635523982, 0.052177768520778045, 0.045786210903315805, 0.06007552598020993, 0.05846541062055621, 0.04747077480715234, 0.005358612361305859, 0.04332729382440448, 0.053667262618546374, 0.030267205365817063, 0.029985183682583738, 0.037043718693894334, 0.03021118805918377, 0.0662509367975872, 0.05734519807447214, 0.03678072382172104, 0.05835574345837813, 0.016979893553070724, 0.02123482099705143, 0.0443280948093161, 0.06375542070600204, 0.01679344379226677, 0.07943306773086078, 0.028184035800222773, 0.0771022638946306, 0.04569411037664395, 0.03419865846808534, 0.03266741114202887, 0.020764664877788164, 0.07282414619112387, 0.05139765627973247, 0.0106912235787604, 0.034658942167880014, 0.02327627815247979, 0.011143991177959833, 0.06708532600896433, 0.019435387475823518, 0.025935684570868034, 0.015423463300976437, 0.0890046353742946, 0.020430488766578492, 0.07335752772632986, 0.057087186723947525, 0.08648427959997207, 0.0030928199657864752, 0.019643333544081543, 0.06264314171858132, 0.05758055536716711, 0.020450549018278252, 0.015256511615007184, 0.04437474621227011, 0.03865872851747554, 0.011003973886545282, 0.05195158417336643, 0.020217952514940407, 0.014210954486770788, 0.033448907488491386, 0.058275981136830524, 0.060388014680938795, 0.07172875106334686, 0.022675322215945926, 0.03456765800365247, 0.024542873761674855, 0.05618067931209225, 0.04603599925758317, 0.035109930468024686, 0.014568684509868035, 0.05650055980368052, 0.03797124001721386, 0.05505513814568985, 0.02722570236073807, 0.08655928104417399, 0.03605356010666583, 0.03971673795604147, 0.020217327255522832, 0.020600577881850768, 0.06623350374866277, 0.036151182212051935, 0.040696851574466564, 0.03988520176790189, 0.027313246100675315, 0.08455232076812536, 0.057911445619538426, 0.03966787124227267, 0.05190246884012595, 0.028186267809360288, 0.011773265614465345, 0.07164710739743896, 0.07810261216945946, 0.06318629733868875, 0.02411249490251066, 0.020978184475097805, 0.006639874663960654, 0.009291228780057281, 0.10581690745311789, 0.025196115857397672, 0.02396824180323165, 0.024681217510078568, 0.02827862808771897, 0.08808144077192992, 0.013924112554377643, 0.032404854136984795, 0.03769312759686727, 0.017827975389081985, 0.030350978995556943, 0.04132038178795483, 0.0239601969224168, 0.020596486792783253, 0.03240502854168881, 0.03777159858145751, 0.05545698513742536, 0.06739135802490637, 0.03443367808358744, 0.0372990842879517, 0.052716014834004454, 0.014883924723108066, 0.003172361266479129, 0.005306536322677857, 0.06826838362030685, 0.02834027458447963, 0.016640323883621022, 0.006504713337562862, 0.024588189298810903, 0.044912309749634005, 0.03409841287066229, 0.05072952670161612, 0.006332473849397502, 0.04041354412038345, 0.015178450667008292, 0.01498732630352606, 0.024936661029641982, 0.02365768454183126, 0.023530298603873234, 0.01987840139918262, 0.02227825465524802, 0.018877574439102318, 0.04055708290252369, 0.017487234981672373, 0.01169487997685792, 0.05892143439268693, 0.07393405772745609, 0.053994460686226375, 0.026094329768966418, 0.03951828766730614, 0.20839454809902236, 0.17502405593404546, 0.17703251534840092, 0.14805702172452584, 0.1850459142588079, 0.23711552959866822, 0.11995809356449172, 0.13727122626733035, 0.15432196523761377, 0.15930434397887439, 0.23318556079175323, 0.08873387763742357, 0.17203366092871875, 0.2491871255915612, 0.18155275873141363, 0.22847486747195944, 0.11340357144945301, 0.12454716372303665, 0.2521803556010127, 0.14449692447669804, 0.11921587167307734, 0.18294853070983663, 0.11803582718130201, 0.15337667689891532, 0.1254629294271581, 0.09552234696457162, 0.1840761350467801, 0.23265036841621622, 0.2370650932425633, 0.18337940680794418, 0.10145485284738243, 0.07425363393849693, 0.14601256814785302, 0.08922961744247004, 0.13058750366326421, 0.20737001323141158, 0.184084654902108, 0.13725084689212963, 0.10228072962490842, 0.11039475633879192, 0.12525925441877916, 0.09702759314677678, 0.11403552503907122, 0.1394238107604906, 0.14022295537870377, 0.1769705311744474, 0.11405305456719361, 0.20937538531143218, 0.24274105351651087, 0.057661330720293336, 0.1101243548328057, 0.14988001843448728, 0.1669586027855985, 0.2025706777931191, 0.10851980929146521, 0.07719191533396952, 0.10427434608573094, 0.15466402110178024, 0.24888492305763066, 0.1318903884384781, 0.13976522837765515, 0.11101775962742977, 0.1549756489112042, 0.11638050389592536, 0.12256032307050191, 0.15071297530084848, 0.13379864307353273, 0.18923861818620935, 0.1640509275603108, 0.18841661541955546, 0.15654155082302168, 0.1865139268920757, 0.08488593841320835, 0.12592739512911066, 0.12747129978379235, 0.2795271319337189, 0.1229435161803849, 0.16292269981931895, 0.14308573066955432, 0.18200215883553028, 0.13661772070918232, 0.07924248420749791, 0.1463110896293074, 0.13123006996465847, 0.09012881098897196, 0.15013129479484633, 0.15930247376672924, 0.12328460725257173, 0.08261998344096355, 0.10263947639032267, 0.12821249751141295, 0.22966432239627466, 0.20572280162014067, 0.05542539191083051, 0.10086498645250686, 0.07005772393313237, 0.1208636027877219, 0.17232560698175803, 0.1271164492936805, 0.16029313701437786, 0.15599414269672707, 0.12892932310933247, 0.14267309656133875, 0.15239632950397208, 0.17686857492662966, 0.09577694814652205, 0.21629551163641736, 0.13932053348980844, 0.2678535645827651, 0.15593441465171054, 0.17894344171509147, 0.1722718754899688, 0.12044910588883795, 0.14314455329440534, 0.1613979128887877, 0.13845018722349778, 0.15045219945022836, 0.13818730367347598, 0.1276181559660472, 0.15880789171205834, 0.25775522051844746, 0.26071638974826783, 0.15715956687927246, 0.12069481614162214, 0.0992529749055393, 0.11290390568319708, 0.16149633651366457, 0.12544222350697964, 0.0894715056347195, 0.09239742284989916, 0.16232819500146434, 0.11348350817570463, 0.12436275486834347, 0.20606830104952678, 0.12463761668186635, 0.09329252716270275, 0.29077773448079824, 0.15203269198536873, 0.20892058237222955, 0.10497132665477693, 0.0650892530393321, 0.12466555112041533, 0.1673075309372507, 0.1363842113642022, 0.10814885419677012, 0.15559004328679293, 0.12600184738403186, 0.08090171118965372, 0.10082066539325751, 0.08816159272100776, 0.15401964396005496, 0.14607622957555577, 0.06302643130766228, 0.058310810127295554, 0.10952674041618593, 0.10366795948357321, 0.15596687619108707, 0.1890053611714393, 0.11983287840848789, 0.106739961047424, 0.1381056971149519, 0.21976226154947653, 0.06397175675374456, 0.0950423555332236, 0.15568284143228084, 0.10110225106473081, 0.14881868788506836, 0.15093781636096537, 0.1250715207424946, 0.13927128456998616, 0.08993963012471795, 0.2723108738427982, 0.18399034277535975, 0.09836290977546014, 0.2723413018975407, 0.14423702436033636], [0.10006780110416003, 0.08241624163929373, 0.06983294224482961, 0.040557962347520515, 0.035933061299147084, 0.04236001936078537, 0.019685359511640854, 0.054155395409907214, 0.07246075358125381, 0.06703477090923116, 0.044821066403528675, 0.03335379013151396, 0.05852523143403232, 0.04410201436257921, 0.041266564949182793, 0.026592455578793306, 0.024251042741525453, 0.01080985959561076, 0.04639495753508527, 0.030910471141396556, 0.053004984874860384, 0.012960525637026876, 0.04297630250221118, 0.07124935335014015, 0.04380554863018915, 0.0634397630346939, 0.018793823073792737, 0.01974164213606855, 0.05341536656487733, 0.06693219867884181, 0.022674116225971375, 0.036114483009441756, 0.030304335014079697, 0.02340330229344545, 0.0061888061190984445, 0.02302890548889991, 0.013647286832565442, 0.08657528174808249, 0.09328910586191341, 0.03792438823438715, 0.09452844795305282, 0.01897399612062145, 0.017753953579813242, 0.018232471848023124, 0.033914516097866, 0.07663446594960988, 0.0056057215624605305, 0.018664056697161868, 0.01352650229819119, 0.021196027082623914, 0.10617241845466197, 0.02141493281669682, 0.036071954236831516, 0.07902585130068474, 0.046018432622076944, 0.033172190305776894, 0.08872075646650046, 0.04218598573061172, 0.013407965543592582, 0.010797543654916808, 0.03882841316226404, 0.03260317083913833, 0.035898083879146725, 0.03868118961690925, 0.012568182773975423, 0.0722940375271719, 0.018745509260043036, 0.048386525668320246, 0.022560734614671674, 0.024745867849560454, 0.03802544277277775, 0.05971162870991975, 0.02653478513821028, 0.03973101316660177, 0.02443403223878704, 0.05924128519836813, 0.028919724936713465, 0.021525212250708137, 0.02273347690788796, 0.00962700793024851, 0.09311108689871617, 0.013287978817970725, 0.01596188772964524, 0.013145590364729287, 0.03931672777980566, 0.0254268124626833, 0.024142303263943177, 0.0330342621600721, 0.03345164601341821, 0.020823212907998823, 0.034913970084744506, 0.04774921006173827, 0.0215968833072111, 0.01796405002096435, 0.02320688548934413, 0.04943690582877025, 0.05962100134638604, 0.05603313293249812, 0.05709448203560896, 0.025673812197055668, 0.08880029243300669, 0.06659834354650229, 0.02250562458357308, 0.04766895421198569, 0.02542781065130839, 0.02941238668427104, 0.039605957572348416, 0.025728120708663482, 0.05406710952229332, 0.030819172134215478, 0.06504269811557606, 0.036984550970373675, 0.03282827165094204, 0.01166382202427485, 0.020268296102585737, 0.042547548946458846, 0.04250178812071681, 0.02463242686644662, 0.06055183264834341, 0.07276995456777513, 0.06200749965501018, 0.05579816526733339, 0.04133948095841333, 0.06550566467922181, 0.024572698821430095, 0.063971393101383, 0.053456982495845295, 0.03521896680467762, 0.014780104756937362, 0.02104838607920101, 0.0488530768052442, 0.02463342505507171, 0.07145703595597297, 0.038610537158092484, 0.04694910065154545, 0.037622638410539366, 0.09182288922602311, 0.013682036042155232, 0.062033534195506945, 0.039550530273118056, 0.04365121902083047, 0.0399709161138162, 0.02527793578337878, 0.032783037750050426, 0.052450812072493136, 0.0064247005411743885, 0.025894087193591986, 0.07313158086617477, 0.05430787707155105, 0.04499423172092065, 0.02188253780332161, 0.015525653325312305, 0.04564222683256958, 0.06069368675525766, 0.00402806078454887, 0.04220705530315172, 0.10512538166949525, 0.015513943162659416, 0.0676740198105108, 0.019351890296093188, 0.027951244483119808, 0.03667874159873463, 0.025090177987294737, 0.06421979735023342, 0.03141895547742024, 0.025478018797002733, 0.07940462863189168, 0.05985283343761694, 0.024505287692591082, 0.037054390777484514, 0.044424752122722566, 0.0865847960812971, 0.02053438758593984, 0.059167018480366096, 0.014795739953115117, 0.011580348964344012, 0.026691591665439773, 0.02933414391009137, 0.006885629445605446, 0.011101878008048516, 0.019183482145308517, 0.06978943754802458, 0.017723295459290966, 0.03140422013530042, 0.09853978583123535, 0.03890570042131003, 0.07009819324593991, 0.028821702071581967, 0.004699809724115767, 0.028937590286659542, 0.06645918343565427, 0.01586993006640114, 0.06442596597480588, 0.02091585334710544, 0.009050131902768044, 0.02660365087649552, 0.06809527025325224, 0.009443121361982776, 0.053653492068406194, 0.005439618707896443, 0.02938767687737709, 0.031542107462882996, 0.024848393695720006, 0.027431481357780285, 0.022244737410801463, 0.027113853284390643, 0.012212172678118804, 0.06982525359489955, 0.005485970468726009, 0.015494051749556093, 0.03993251368228812, 0.015783775997988414, 0.04993161775928456, 0.09402135328855366, 0.05907583821681328, 0.0372792986308923, 0.0362957117613405, 0.06948103065951727, 0.012709960810752818, 0.02903995100496104, 0.0193629761270131, 0.025890955330396537, 0.06005344708682969, 0.04051853946293704, 0.013168347395549063, 0.022935417146072723, 0.02102930175169604, 0.04082057130290195, 0.052606317985919304, 0.053140330346650444, 0.02319187184184557, 0.030195393301255535, 0.02565559247159399, 0.0023333361832555966, 0.025493854373053182, 0.029965292269480415, 0.06207005528267473, 0.021905984103796072, 0.05174342659302056, 0.040285883587785065, 0.022888973544468172, 0.031370682481792755, 0.03185044013662264, 0.07859775083488785, 0.028412992069206666, 0.05411951999121811, 0.03798924451984931, 0.017002080057864077, 0.07049565785564482, 0.027585291463765316, 0.05520583865290973, 0.03200715575076174, 0.04959777375916019, 0.016740107494115364, 0.023168217740021646, 0.06748400031938218, 0.021510833139473107, 0.026812441137735732, 0.01991323966649361, 0.02825875151756918, 0.03405915696930606, 0.01746290181472432, 0.03865468010189943, 0.06407944980310276, 0.02869861687941011, 0.023652823474549223, 0.0070314494041667785, 0.015348604720202275, 0.021585125832643826, 0.04560287816275377, 0.010077085244120099, 0.025937567770597525, 0.06082984487875365, 0.05353018794266973, 0.026057044269691687, 0.02539010954933474, 0.056327090205741115, 0.06643791348324157, 0.03613554887124337, 0.03591259286622517, 0.0349029937206069, 0.018860896525438875, 0.05634675711917225, 0.04741341050248593, 0.013131682517268928, 0.027944776666117832, 0.0881417773780413, 0.03914321365300566, 0.03699867032992188, 0.002186610108765308, 0.01634369673411129, 0.07199645857326686, 0.05148818345332984, 0.02018804952967912, 0.07615503112901933, 0.03040421324840281, 0.04819345966097899, 0.04220930401061196, 0.002895759348575666, 0.02855603175703436, 0.04001101435278542, 0.015252055018208921, 0.050385288923280314, 0.00980251843429869, 0.08263601383077912, 0.021256484287732746, 0.03611501364503056, 0.0528127426514402, 0.07333694797125645, 0.05174332269234583, 0.03876023576594889, 0.015880288592597935, 0.08269307756563649, 0.04690965921327006, 0.020741923617606517, 0.028935458467458375, 0.05311534594511613, 0.030254364355641883, 0.02593374199932441, 0.053704652018495835, 0.08414312280365266, 0.018812170819728635, 0.01006857744869194, 0.024472403129038867, 0.042062674183398485, 0.020330001971160527, 0.019133789792249445, 0.03564954975445289, 0.03859047319565434, 0.11710998311173171, 0.07143062292016111, 0.05459943349706009, 0.04251875732734334, 0.01919099267979618, 0.022893478380865417, 0.011374408550182125, 0.03733118959644344, 0.019474485670798458, 0.09860667560133152, 0.04145132261328399, 0.019687027488544118, 0.008239889393735211, 0.04311054588470142, 0.008725773477635812, 0.03760976585908793, 0.0598914844886167, 0.08460493161692284, 0.09151355465291999, 0.01777252025931375, 0.05038884009991307, 0.03644420066848397, 0.04258276014297735, 0.18602393131004646, 0.09505673093372025, 0.15967813407769427, 0.0835057589574717, 0.06411136215319857, 0.18109936587279662, 0.15391148335766047, 0.11962236822000705, 0.24985980824567378, 0.195694976428058, 0.1435220244457014, 0.148060925421305, 0.11674362191115506, 0.18600459094159305, 0.18693160760449246, 0.10374810401117429, 0.18946803087601438, 0.07812995288986713, 0.13502142042852938, 0.08404034277191386, 0.11137552675791085, 0.09646408041589893, 0.09402461131685413, 0.2682683657621965, 0.12095968864741735, 0.13293393712956458, 0.1082216069335118, 0.11484690025099553, 0.14894866762915626, 0.16935208841459826, 0.13075536262476817, 0.21922736603301018, 0.07334425070439465, 0.0984983443049714, 0.1325704628834501, 0.12869391386630014, 0.09185243412503041, 0.17183121788548306, 0.177522896847222, 0.16782598046120256, 0.26856201875489205, 0.10327683281502686, 0.07701822309172712, 0.11462197013315745, 0.10871397738810629, 0.1280461228452623, 0.11744780131266452, 0.1202636060770601, 0.1024696730019059, 0.12058201711624861, 0.2299306940403767, 0.16536650306079537, 0.18087155622197315, 0.13705871970159933, 0.07828331770724617, 0.13966144644655287, 0.17639944853726774, 0.10109965354786254, 0.12084813643014058, 0.09107349076657556, 0.0981376605341211, 0.058630445710150525, 0.10387047674157657, 0.22512925090268254, 0.11632913985522464, 0.10836542773176916, 0.1493276230758056, 0.109793238225393, 0.07923013487015851, 0.13760400528553873, 0.14304013311630115, 0.1631578864180483, 0.10035619226982817, 0.13918207841925323, 0.0992952253727708, 0.1542462661745958, 0.12687486538197845, 0.09154669896815903, 0.14509698055917397, 0.10421024679089896, 0.22687249642331153, 0.1379758954863064, 0.16547086386708543, 0.1621007564244792, 0.12006471049971879, 0.09541876541334204, 0.10629799726302736, 0.13893271679989994, 0.14448674221057445, 0.1788249652599916, 0.10000377602409571, 0.10845075245015323, 0.11718014575308189, 0.07686378216021694, 0.09664216617238708, 0.1724568780628033, 0.1562132395338267, 0.1717429913696833, 0.16032291197916493, 0.08285232761409134, 0.13207689014961943, 0.12313536877627485, 0.241606280033011, 0.14414863457204774, 0.0907312122581061, 0.10478504016646184, 0.20366371289128438, 0.22797434823587537, 0.1688197162002325, 0.1329969009384513, 0.21838588931132108, 0.104852375225164, 0.12223187819472514, 0.10057462117401883, 0.08224891702411696, 0.11741787049686536, 0.1470147940563038, 0.06514321459690109, 0.17004234512569383, 0.13699974864721298, 0.1097001061134506, 0.0932744558667764, 0.18564727652119473, 0.16417879960499704, 0.10359192645410076, 0.10376267237006687, 0.16292724176310003, 0.06405202744645067, 0.1812808061367832, 0.13034695875830948, 0.11748535398510285, 0.22489882889203727, 0.20639313908759505, 0.1144578070670832, 0.10556393157457933, 0.06410958842025138, 0.11631274581304751, 0.14873345964588225, 0.15105417027371004, 0.16042850475059822, 0.1254325607442297, 0.14226059603970498, 0.13462931412504986, 0.14367360068717971, 0.1818355021532625, 0.10528026788961142, 0.08770068932790309, 0.12094707213691436, 0.12635764782316983, 0.12884808762464672, 0.16368497454095632, 0.10115484707057476, 0.08708007575478405, 0.2157958087627776, 0.14316022745333612, 0.11490032746223733, 0.22281061828834936, 0.1477260238607414, 0.13168846489861608, 0.0947248944430612, 0.10980106788338162, 0.1900464014033787, 0.13871265517082065, 0.12911609199363738, 0.13892614137148485, 0.10120496430317871, 0.10040884764748625, 0.08477771101752296, 0.12236398790264502, 0.093801684997743, 0.2592910506064072, 0.2965679409680888, 0.1122377984574996, 0.15533060330199078, 0.13448288838844746, 0.1200616973801516], [0.06366605870425701, 0.06342463806504384, 0.02601394404337043, 0.10164464969420806, 0.003066768263124686, 0.0275077444530325, 0.022244455394684337, 0.053777534631080925, 0.0792116108641494, 0.032437089321319945, 0.029251309097162448, 0.0669477169867605, 0.0281575819462887, 0.03857600131595973, 0.02071541781333508, 0.0070511153899133205, 0.051791105870506726, 0.005727574325646856, 0.014784597533434862, 0.0744568117079325, 0.0720272131729871, 0.041397138411412016, 0.053931882794131525, 0.08195511560188606, 0.020255852141417563, 0.038629012924502604, 0.05332980435923673, 0.07763614266877994, 0.03208141875802539, 0.0341301025764551, 0.023908318944450002, 0.009208610117639182, 0.07009995213593356, 0.05622276650683489, 0.04831960250157863, 0.015323279858421301, 0.04982804362953175, 0.0005681486027242499, 0.02540725687140366, 0.01154231575128506, 0.014313308711280115, 0.029938511870568618, 0.02553434038418345, 0.06801738185458817, 0.04461622622329742, 0.024002584686968476, 0.029762572776235174, 0.09152369981165975, 0.05838326229422819, 0.01990005541301798, 0.0335966356942663, 0.02286240465764422, 0.016028415702749044, 0.03586516591894906, 0.07632853783434257, 0.03417440508201253, 0.017968647625821177, 0.025413541006855667, 0.026108248748641927, 0.010069399377243826, 0.03757972001039889, 0.02028997794695897, 0.04795115215529222, 0.02323396645806497, 0.04973849980160594, 0.05565164676227141, 0.04946190878399648, 0.047797234437894076, 0.016998681021505035, 0.043610545617411844, 0.0610558882181067, 0.01659884896071162, 0.025484690704615787, 0.045690247497987, 0.011362770746927708, 0.02819978974002879, 0.006867451002108282, 0.06257438915781677, 0.07735855717328377, 0.059333519311621785, 0.030047095497138798, 0.10782903307699598, 0.04223590258334298, 0.04779428811161779, 0.054438020088127814, 0.05669690610375255, 0.02502239392924821, 0.009794562611205038, 0.036094203824177384, 0.030751575468457304, 0.040496404908481054, 0.030903290862625, 0.07668102087336592, 0.015446610887011047, 0.07362795891822316, 0.01743198579788441, 0.02195772478444269, 0.05634064553305507, 0.03395119674678426, 0.029515574897232, 0.05371519051550422, 0.059655414734152146, 0.05138249420269858, 0.06131649708549958, 0.02198749418312218, 0.026455160113982856, 0.015207047472358681, 0.050389905081829056, 0.020219149228069, 0.02036576421232894, 0.020104394643567502, 0.043317775780451484, 0.05841407626576256, 0.02775527667836286, 0.06576708619832061, 0.022710928606102243, 0.030798100706306286, 0.030124277000140864, 0.025823789110290818, 0.06835109597886913, 0.006528235708174179, 0.03630476596299559, 0.0524547157692723, 0.06612914294237271, 0.04495336164836772, 0.05469371964863967, 0.012988309790671337, 0.0612158358853776, 0.04515165237535257, 0.01578760547999991, 0.0492274383577751, 0.0241067321258015, 0.015101066001079744, 0.0781543918128591, 0.03184114473697264, 0.024898201081668958, 0.054272829147521406, 0.04183049328275956, 0.02301752094354015, 0.004498050848269486, 0.01638512341742171, 0.024423397262580693, 0.009223993911291473, 0.04440009797690436, 0.035921906819567084, 0.031536771421087906, 0.051648312946781516, 0.007100089251252939, 0.06011963923810981, 0.019846591094392352, 0.04064829285198357, 0.05627161466691177, 0.05339993360394146, 0.01655960048083216, 0.037487600930035114, 0.027170096946065314, 0.02044011627731379, 0.10326642048312351, 0.022186434289324097, 0.02781423845590325, 0.024555477284593508, 0.03574969887267798, 0.04197113768896088, 0.01571252796566114, 0.061372840937110595, 0.06611760254600085, 0.004477179336390691, 0.04975935044058133, 0.03253096729167737, 0.01946143871464301, 0.023552869170089252, 0.05513319352758117, 0.012090703512512846, 0.028623513389902655, 0.011350635704729939, 0.015855385827308055, 0.08591545309172943, 0.011325491741445148, 0.063022022950463, 0.019551056757336482, 0.036969667198718525, 0.048215627612080425, 0.05650407387292944, 0.013774824910797179, 0.023482661999878474, 0.03534823779773433, 0.06085550834541209, 0.08227754166000523, 0.027870324411196634, 0.050029759368044324, 0.03736728765943553, 0.017266939576074947, 0.05040929368988145, 0.00905619896002463, 0.026930080821330193, 0.07783333130646497, 0.04990116001863498, 0.07295236704521812, 0.035530193854356185, 0.0492825242690742, 0.013239883010101039, 0.05736271647037938, 0.03625637051300146, 0.050177509838249534, 0.023328775823756587, 0.035214851595810615, 0.04757747708936222, 0.03361528586538043, 0.03467436028586235, 0.05619607516564429, 0.10145088977878913, 0.01728650815493893, 0.07698030676692724, 0.03264088307332713, 0.06936319245141931, 0.06676618766505271, 0.03609921332099475, 0.019240009678469505, 0.02350955743168015, 0.059243066352792084, 0.03905676458089147, 0.02460552401316818, 0.0468184455530718, 0.07607448584167287, 0.0175116627724492, 0.007577007263535052, 0.035725063280551694, 0.06407685970771126, 0.043448594151414, 0.038678094861097634, 0.02841365072526969, 0.014399032334040385, 0.03966318086895626, 0.05723846239561681, 0.022078000947658438, 0.04437737341504544, 0.06612486075027846, 0.020984693110221997, 0.04848116805078462, 0.03752602933673188, 0.01799900332116522, 0.09006071893963963, 0.009443317103432491, 0.011770762721425854, 0.02345977416553069, 0.033622844639467075, 0.035862234435626306, 0.008067168437264627, 0.012454518218874, 0.020019706316816155, 0.04674919575336389, 0.04497773748880718, 0.0466609543946106, 0.0773076681070961, 0.013977469261590159, 0.05503458436578512, 0.0573633769818116, 0.024966124292404857, 0.021642310166498646, 0.015486969805351691, 0.06742034631315619, 0.04065244887897279, 0.06613626756006852, 0.014490769208350684, 0.031146093751885928, 0.028664437268162146, 0.07054466928821057, 0.017702381737763062, 0.02353582574869506, 0.023729476197331678, 0.05387034390878398, 0.08327398623805493, 0.009175936138490215, 0.0603524695179658, 0.01536304691398982, 0.0400074780191062, 0.05203898690524511, 0.02995681694301311, 0.009932475913956296, 0.06488039784017019, 0.03030149258847814, 0.030390409301617183, 0.02739728875894798, 0.017910793503688183, 0.04627006521332078, 0.0636058408417739, 0.054341073337127455, 0.029137806886865292, 0.057867985451593995, 0.030244096742535476, 0.02138210020348197, 0.1044271765567828, 0.033558363138581626, 0.084954846824985, 0.011055182076233905, 0.06003372080158442, 0.007786655169184087, 0.03571325200027786, 0.02201412986323703, 0.09350865540909581, 0.02178478767746128, 0.0342336358880857, 0.021916598670941312, 0.04107097192900255, 0.0490682217059657, 0.07385056611383334, 0.033113356548710726, 0.029057307983748615, 0.04905669986328576, 0.07900467782747, 0.04365210588730406, 0.019788237877946813, 0.041725965493242256, 0.061388722897390835, 0.0915927640744485, 0.04603466710250359, 0.01790557063941378, 0.038158647148520686, 0.03547038788383361, 0.033486122483736835, 0.041248241323046386, 0.02902648844610667, 0.04664631553168874, 0.01604012679308653, 0.015880503815424163, 0.14196203002939, 0.03422524590860121, 0.0028827437017753255, 0.036348196445032954, 0.012228621453687083, 0.0337234947073739, 0.03058229343878338, 0.006268195047596237, 0.10603301343508065, 0.013630803732667118, 0.04699922530562617, 0.01976865816686768, 0.03132417579763569, 0.05186171751120128, 0.019892958625860047, 0.047522628665319644, 0.03144930560665671, 0.11717892863089219, 0.019944183513871394, 0.07303712030989118, 0.030544909604941495, 0.02206549390393775, 0.013948549622000428, 0.0404890019854065, 0.01771782397554489, 0.021603568202408496, 0.02885233421693556, 0.19826083327643573, 0.1289657477173023, 0.14575257897377014, 0.23359148588497192, 0.08926253911340609, 0.22590906999539584, 0.22033922199625522, 0.05866951607458759, 0.20357017259811983, 0.1602863537846133, 0.08828418067423627, 0.20611318614101037, 0.20910889492370188, 0.13479815272148699, 0.12203259670059197, 0.07599737669806927, 0.2451012167148292, 0.11224838890484534, 0.0949777515779715, 0.16488995519466698, 0.19502460927469656, 0.16678958607371897, 0.11438536603236571, 0.12212290122988634, 0.11118365189759061, 0.16812877671327442, 0.15439941576914862, 0.3400053398218006, 0.1086450763978064, 0.14749128255061805, 0.17341565864626318, 0.1321941494825296, 0.1447114793700166, 0.21092613256769255, 0.19718189898412675, 0.2046037171385251, 0.21438909752760082, 0.05352965359634254, 0.09597132404451258, 0.1821401686174795, 0.1296388014452532, 0.19380934245418757, 0.07236037068651058, 0.14121756685199216, 0.15912892995402217, 0.16854296933161095, 0.08361855798284523, 0.21126014355104417, 0.13560571329435334, 0.06852714082924649, 0.15568178758258, 0.06285598225076683, 0.11379734016372822, 0.1562549630762078, 0.17770994774764404, 0.1663409874890931, 0.11518351617269218, 0.11095568639575504, 0.1503319715266116, 0.1423068912117742, 0.11950882704695687, 0.10735542411566712, 0.2119023387786001, 0.16798439930425957, 0.10528457234613597, 0.23042576591251418, 0.17735419183736667, 0.13538893195800483, 0.14912365120835602, 0.14897609740728512, 0.1119968453713227, 0.20055849279742688, 0.060399696085369214, 0.10333903963328339, 0.15809871023520827, 0.12354305275948718, 0.1411132060457021, 0.2393437537830323, 0.20295169641030952, 0.13620891608297825, 0.08979859980172478, 0.1851941508357413, 0.19724950863746926, 0.201731457200367, 0.14272231579525396, 0.15656926261726767, 0.11145389013108797, 0.10785356847918592, 0.12119186212657951, 0.13887061388231814, 0.14267533784732223, 0.12032394268317148, 0.116823707066942, 0.10925427573965862, 0.15767310338560492, 0.11768517724703997, 0.1305966469226405, 0.12255281995749101, 0.1128103950759396, 0.1196995515783783, 0.16686371178366244, 0.16762024228228256, 0.09782007327885367, 0.20478600345086306, 0.13826049427734688, 0.06983135404880159, 0.1416015243739821, 0.1719613460591063, 0.10717986908275634, 0.11826156624010764, 0.17784926370950416, 0.13210362230893224, 0.16929565550526604, 0.12239362185937352, 0.15801352652488276, 0.14232551911845803, 0.07279289435246028, 0.20668713346822187, 0.12172063492471352, 0.13496507657691836, 0.08289997349493206, 0.12542438227683306, 0.07852324662962928, 0.16265383455902338, 0.12634955841349438, 0.18443233624566346, 0.1061895620659925, 0.07480337240849622, 0.23058210674207658, 0.10712086834246293, 0.13151177437976003, 0.14852421852992848, 0.2371853360091336, 0.14073641767026857, 0.10511591928661801, 0.09439820103580132, 0.13443843374261633, 0.17383310187142342, 0.15593955031363294, 0.07614134592586197, 0.11251223724684678, 0.10861286718863994, 0.2149615902453661, 0.12861897179391235, 0.12608602177351713, 0.2115380036411807, 0.11593134127906524, 0.12062398556736298, 0.15947388019412756, 0.21939853497315198, 0.16400466207414865, 0.1223178708460182, 0.12447156856069341, 0.10086516456794925, 0.0993498251773417, 0.1694710843730718, 0.08925137721234933, 0.19644794461783022, 0.07860707220970653, 0.14398994855582714, 0.11958243325352669, 0.09377352791489102, 0.16322744049830362, 0.08541748684365302, 0.15465005388250574, 0.11626225750660524, 0.32574420038145036, 0.1392963988473639, 0.14496147923637182, 0.11309197332593612, 0.07439598528435454, 0.1370470382971689, 0.15175152191659436, 0.19111168017843738, 0.10922665300313383, 0.08617106359452009], [0.06798442307626829, 0.02733033776166849, 0.01547512512843241, 0.046251459571067244, 0.051128471895935945, 0.034386722400086, 0.0548594152496662, 0.03360915943630971, 0.009422087041457416, 0.042491271888138726, 0.030903940241842065, 0.052634905514423735, 0.02093488015816547, 0.05463618836074602, 0.030338130563904997, 0.04139816628594417, 0.06518427020637318, 0.04411838614032604, 0.030789712582190987, 0.08543747288058512, 0.03752577329578344, 0.027461764693725854, 0.05157241350389086, 0.06156855641165748, 0.03661300957901403, 0.03683221773826517, 0.06235458728042431, 0.03643406664195936, 0.035689993092091754, 0.07863323291530833, 0.03358524372742977, 0.07431962570990436, 0.04645159453502856, 0.005093404497529264, 0.03552440139173996, 0.036036204983247444, 0.01761216997692827, 0.03438658510276582, 0.011152350543852663, 0.010944835848931689, 0.04783964075613767, 0.01939190689881798, 0.04300127206079196, 0.03900490701198578, 0.019290342133899685, 0.005634214467136189, 0.020540636469377205, 0.05859469645656645, 0.05509961134521291, 0.02430834952974692, 0.0480151178635424, 0.08104858221486211, 0.005220820121394354, 0.034639193618204445, 0.04858188491198234, 0.03780013415962458, 0.019473392858344596, 0.02440155400108779, 0.03427622403251007, 0.04869889933615923, 0.004772424699694966, 0.02131570396159077, 0.02234189938462805, 0.0211990402021911, 0.04658505866245832, 0.04494660439377185, 0.017705712125462014, 0.019776419176196214, 0.014525499864248559, 0.027882914946530946, 0.0891000013507437, 0.0379237796732923, 0.027898119697056245, 0.02920226426795125, 0.04093640571227297, 0.09478935739025474, 0.05476007136167027, 0.025521286006551236, 0.05876061099115759, 0.0354126042657299, 0.0841082344413735, 0.0540244211879326, 0.017752166859281715, 0.014156650613585953, 0.006689326282867114, 0.032784470095066354, 0.002985209712278447, 0.013709901832044125, 0.02705343133129645, 0.04898130508081522, 0.012659958611038746, 0.027666333990055136, 0.027178088021173608, 0.048442721090395935, 0.04162823948718142, 0.021622914136969484, 0.035739097293117084, 0.032531757678953, 0.03286399492935743, 0.0871573036420159, 0.09388526566908695, 0.03591283777495846, 0.03512132243486121, 0.027793794142780825, 0.027182192097825464, 0.025473267196503002, 0.10247587735648267, 0.14094062702497467, 0.03914290195098147, 0.07229232316603884, 0.017406485603714827, 0.022368091631506104, 0.031975065285223536, 0.015274399229383562, 0.03415614824916702, 0.013059178399998927, 0.06729814427671954, 0.01782897914381465, 0.0420421760645695, 0.02772357769572409, 0.020127586758462712, 0.05904379970161244, 0.030515140206262004, 0.025653484772192314, 0.03199118102202192, 0.033731610092218034, 0.04534694853646215, 0.008644466561236186, 0.027193678688490763, 0.05884806567337364, 0.042484748410061, 0.014739735634066164, 0.03187998132489156, 0.00753536860429449, 0.017796489773900248, 0.01669144672632683, 0.0578410492016701, 0.03527761873556301, 0.03205549925041851, 0.07574313916848041, 0.05011632718378678, 0.036754945322172716, 0.048019266469054855, 0.038499085130752064, 0.045151407466619276, 0.0328781439748127, 0.034750085324048996, 0.029194273192842957, 0.017104520557040814, 0.05455660415464081, 0.08532534920959733, 0.05353103770175949, 0.027888824297406245, 0.0054498900317412335, 0.08086552406894043, 0.06547800483531319, 0.06700825397274457, 0.04318220024288166, 0.029991157971380744, 0.03985094794188626, 0.02033900236710906, 0.06215748027898371, 0.02999721204105299, 0.03337186513817869, 0.018661572357814293, 0.017782029026420787, 0.06228999074664898, 0.021924554494034965, 0.030257800499384757, 0.04846793926844839, 0.022538173325301614, 0.020431407174328342, 0.06965840395423584, 0.053509162898990326, 0.043520322724361904, 0.023024241090752184, 0.08424866362474859, 0.008748465570533881, 0.03869371706969105, 0.054350565405911766, 0.04387518063595053, 0.031796511975699104, 0.015478072382393293, 0.031733340365462936, 0.021604553403449245, 0.03546593499777373, 0.02524662828363944, 0.08031879871850833, 0.030542178501491435, 0.04802053554158192, 0.03283033482148312, 0.04287585281417705, 0.06996220210567117, 0.004513076091825496, 0.10132650582818314, 0.020270116219762713, 0.02252696875075344, 0.06378283564117737, 0.05204506509471685, 0.0040319668005395215, 0.04922883730614558, 0.019731480279006064, 0.03458831939497031, 0.05330471976776607, 0.0910420533909928, 0.049188898628926836, 0.0920861067424994, 0.050625510993995704, 0.0600358730298467, 0.007350893883995013, 0.07048268511425704, 0.013304764343047282, 0.014158593185129575, 0.005117538676131517, 0.05164719230378978, 0.021236216234683525, 0.04921326704788953, 0.021606043264910113, 0.0631606338720303, 0.03301300333987456, 0.020452608478080947, 0.026059294832521118, 0.014933110560377827, 0.029177908836572897, 0.04612433709553443, 0.02130147513526026, 0.03472210264590103, 0.04767000435094815, 0.017261575703741983, 0.04367563196865376, 0.07662271033041179, 0.06842856877483428, 0.04957309734891169, 0.042716023890534416, 0.04180737538263202, 0.04800820104719605, 0.10932900258922018, 0.08155778457876295, 0.051048865425400436, 0.05138302854902577, 0.03224007879907731, 0.04836791260458995, 0.015532982961303787, 0.04679827768995892, 0.026850372305489145, 0.05485434267029632, 0.050113659162889235, 0.08337132632732391, 0.056719248459558, 0.008166964107658714, 0.028648199076997116, 0.07352176500717178, 0.016194261588680092, 0.02911044575739652, 0.06281229201704264, 0.027496122420416214, 0.0528854916774435, 0.0711523398058489, 0.03026819984370377, 0.044055748876417056, 0.05045198202424217, 0.022802344501542393, 0.04940256665577181, 0.025430962923564948, 0.012648002611967968, 0.03876520073390566, 0.024539970108889975, 0.031409147995873354, 0.020619613969756756, 0.004033567520309589, 0.03779587794269901, 0.047705415927339345, 0.055535218634759076, 0.07128511744667776, 0.029744931925961282, 0.029726333705184516, 0.0460262993874494, 0.04554383660433814, 0.0687289382040035, 0.022210912175069097, 0.026441482332302257, 0.07414064937620424, 0.06688638590276241, 0.07273460607393645, 0.006900775752001209, 0.032129550745594315, 0.020582398974511307, 0.03623704127676319, 0.035148099123034626, 0.03167237664456479, 0.030855492841510568, 0.03289208150818013, 0.0718363921623677, 0.018325678174733184, 0.030663384204672184, 0.03727700168383308, 0.03614511886553373, 0.03384644631296396, 0.043208034403505735, 0.05627538477710914, 0.02538984794227872, 0.009698422945803031, 0.03805729575105943, 0.03449371040915139, 0.07606629995279945, 0.061453697926481254, 0.05058429582277313, 0.030672976463392843, 0.016952454498095904, 0.016050075282691978, 0.024428262040601112, 0.06504424920422025, 0.010871773265535012, 0.05396264481532853, 0.01743087257636944, 0.0940111190720927, 0.032850710485945456, 0.09005838117445819, 0.056024049044935964, 0.024443967740808148, 0.04009382319054566, 0.013925286075391341, 0.03927182042389177, 0.029043515169178136, 0.029104380555509124, 0.05011049761378672, 0.013173699207982281, 0.04478696842852514, 0.030691775064042304, 0.03281645665992983, 0.061245551478350535, 0.048821260934346355, 0.017602739135327283, 0.05870814115041867, 0.011151228045491735, 0.03138286112516653, 0.025626505848777015, 0.030438836292887572, 0.0446261227625655, 0.05714461782190483, 0.028746118041453883, 0.011434551270212978, 0.02267836873215856, 0.02266246450744802, 0.022264124163484666, 0.036350871887407266, 0.026294705930922646, 0.015792386766406707, 0.04531266873527784, 0.028939614494447596, 0.05643413387588225, 0.020360526505101006, 0.18211057176813483, 0.11989470673142932, 0.12128226313507184, 0.20709347416413948, 0.19592188065871596, 0.13065885374089703, 0.16278899449389428, 0.11754486680729315, 0.11151896906085312, 0.1444629637990147, 0.11328763313940726, 0.20727550814626738, 0.13091900618746877, 0.1320214368752204, 0.14151150186080486, 0.1167174315196462, 0.23573805898195133, 0.12312911989283748, 0.16378433327190578, 0.1576697191921994, 0.11664388468489051, 0.16691762139089406, 0.08421008678851649, 0.11030171328457072, 0.17924919171491638, 0.12542479787953198, 0.13505696930224076, 0.14825146441580728, 0.13880453305318952, 0.2467067344696261, 0.1245797736919485, 0.19995953509351239, 0.20422398985829204, 0.191802857152652, 0.1392456062603742, 0.2419236965943128, 0.11553683041711338, 0.08203250676160678, 0.21467320650117472, 0.07402755349176005, 0.14100241824053228, 0.10173375936574303, 0.24185178248444572, 0.09007073793327436, 0.10735802163253538, 0.17547820578329265, 0.12514814006863162, 0.13215051119914278, 0.13198829255998135, 0.12155987089499831, 0.15445852041011676, 0.193374399386812, 0.13728862220887095, 0.1024683000287041, 0.17796171392546967, 0.06691754126222804, 0.12330471203313209, 0.14061639754800126, 0.1347353818709962, 0.12290761107578874, 0.10784023208543658, 0.14682318636914715, 0.15470482438104227, 0.07512520474847406, 0.16707225528080016, 0.08441351688816212, 0.09351679676910862, 0.15011688228696585, 0.13490852492395788, 0.09069228661246598, 0.11566422748728655, 0.15740023052785546, 0.10691072180634364, 0.11955173060414381, 0.11481201188871637, 0.18007441540248692, 0.1550078284344636, 0.1614700793288648, 0.16924826195463538, 0.17510472738649696, 0.15374445560155436, 0.15346607600804418, 0.10348049298045225, 0.13383782847085968, 0.10500519085326232, 0.12951618380611762, 0.19067885965341702, 0.11005415508407168, 0.13929921900853515, 0.18115156854037195, 0.13017798657529056, 0.07250148264574818, 0.0866777278133668, 0.1051880708837416, 0.11082380675361492, 0.10145995882339776, 0.1044283936789725, 0.17971759079955518, 0.13749560719588771, 0.1532054040580988, 0.1697058553691022, 0.16210880130529404, 0.14599941729102284, 0.16718443832360208, 0.1690030563622713, 0.1785641151946038, 0.22744329704437405, 0.2437731286045164, 0.10814871318871155, 0.21605222078505903, 0.06947436617338099, 0.12311852202401496, 0.12536009744508192, 0.07692391838645563, 0.15804592869244516, 0.09075094596482813, 0.1825442086555995, 0.18463201849954203, 0.1597685573506169, 0.12612624617759138, 0.10616354978992604, 0.11886944455909543, 0.1902758883079514, 0.09242219573934563, 0.08793171247816645, 0.11232203964027576, 0.20021343865664676, 0.12339410372078419, 0.14502953417832032, 0.1355843839701265, 0.16205628693569452, 0.08061156113399193, 0.11665114288916811, 0.14169504982419312, 0.08186015780665912, 0.07718715816736221, 0.1684223851771094, 0.15706314705312252, 0.10503101759240963, 0.2130340546136722, 0.19242648384533823, 0.1561754642170854, 0.14481880876701325, 0.089334045042051, 0.1276743513881229, 0.09091086394619197, 0.1608393428614363, 0.09772626581252553, 0.19685455248691142, 0.1180748493061401, 0.12579027592437342, 0.13726726319873706, 0.11420352500863373, 0.13512110570445657, 0.1306880943593569, 0.11494515318190679, 0.17572854703757912, 0.11343098638462834, 0.16874185006599873, 0.1192549234838225, 0.08756768904277124, 0.16693694691639394, 0.08029717995668761, 0.27645977621432394, 0.17948767344933003, 0.10430593931232579, 0.10929398064035922, 0.12108551236451603, 0.19564223941415548, 0.12660778127610683, 0.07437337204464711, 0.09701844246592373, 0.21862015564693138, 0.0728602145682089, 0.14683724264614284, 0.10880811882088892], [0.05887696490390226, 0.0759491890494246, 0.04530585210886784, 0.04422141479153652, 0.060904916826984845, 0.0338387353986036, 0.05705488845705986, 0.030456892745860387, 0.04555296131002251, 0.053866310336161405, 0.034573198136058636, 0.05607868966762908, 0.08644081943202764, 0.050266871839994565, 0.035294090703246184, 0.018397549611108843, 0.03727125375007745, 0.004923408614558866, 0.013724637174163945, 0.02564726186392363, 0.012399373863445362, 0.08881549903890118, 0.03693009588459972, 0.06777714865165763, 0.05217134523263667, 0.09626616447349079, 0.041208154216292314, 0.028861941318609752, 0.025109856032941025, 0.04880334920017049, 0.02454571433190722, 0.08378470258321613, 0.02327402944501955, 0.09239546358003281, 0.004211922769172816, 0.04453192566870712, 0.02119382104865508, 0.042345540059613995, 0.026428938181197736, 0.041771477699512616, 0.01244075880094897, 0.037357431938289665, 0.03418462445551995, 0.026692031387938187, 0.06495093897683546, 0.04163188343227375, 0.052016280897078104, 0.09674369939602911, 0.023837319531594403, 0.0039149440272012725, 0.023483715849579312, 0.014756337477592751, 0.006722868574797758, 0.03592838947952259, 0.048600568479741924, 0.036599572995328344, 0.01312554031756008, 0.03319903007650282, 0.023191010950540658, 0.07321094613871537, 0.06934316930710338, 0.026184595335507765, 0.032119958486873657, 0.07224553075502627, 0.032442573792650364, 0.009930349660862703, 0.03571111461496912, 0.019768378006119747, 0.02163809105695691, 0.03323605582409073, 0.09591759997420013, 0.07677467248868197, 0.04447725907084532, 0.015498796856263652, 0.05402065478847362, 0.05142308596987277, 0.07906933373305947, 0.053085637773619965, 0.03465468966169283, 0.01920986920595169, 0.04796864457603078, 0.025793342501856387, 0.0327784178807633, 0.07968615493155085, 0.05058884518803097, 0.04047281574457884, 0.02526793905417435, 0.118714216951048, 0.04990137153072283, 0.06697389995679259, 0.03137557694572024, 0.03514543110213708, 0.02152053486497607, 0.03458876097283792, 0.014095353853917914, 0.04370418238977436, 0.019335153010615613, 0.02992409008584218, 0.09220343286870047, 0.023042614811856765, 0.06011723467963748, 0.033498609118396416, 0.022409727971535176, 0.025486466292932164, 0.06028853720636107, 0.04661672981455922, 0.01867910188593669, 0.008789656621956965, 0.06884460934088565, 0.07554481504485011, 0.09901288271066733, 0.013996855086588766, 0.01170752617326798, 0.06165238199173473, 0.041147116280626506, 0.04667481029173359, 0.04235938853526022, 0.02441898705001222, 0.1353946019662544, 0.04063390260853339, 0.053418468742165715, 0.0452836396289058, 0.028908579733979423, 0.09429368437849917, 0.01947951372130774, 0.08051932702073827, 0.017060891550499946, 0.04699254597653635, 0.0548109233204741, 0.018476451041351538, 0.06332533128443174, 0.04670226604503114, 0.06852974576759152, 0.033808325897553004, 0.037139084670343436, 0.09627032050048001, 0.00910996848688228, 0.000968953166875508, 0.043489096860866994, 0.04754441441036761, 0.037013791588833556, 0.013744217812927673, 0.06139583267213311, 0.06623213819693774, 0.016234810682362877, 0.04488246428081766, 0.0621852588665206, 0.024386653531109914, 0.024685256648808718, 0.015074421971803531, 0.06378499529091641, 0.01340815386356553, 0.03761566222237889, 0.03903318283846602, 0.03406844123674091, 0.028915066104673315, 0.022771261501475237, 0.04929113689286169, 0.05861422236193903, 0.03299140684248414, 0.029552340893133078, 0.007985384690982755, 0.0357578179682605, 0.08640150786959566, 0.027237207505095284, 0.007847644865250913, 0.04600705920893233, 0.00953168369960622, 0.05037506212829612, 0.05470701893500518, 0.021520412410609424, 0.05970089725451544, 0.014504613973258529, 0.06839809619123116, 0.017326218621747103, 0.025993778035626747, 0.03811743197729811, 0.07988370722159743, 0.0806087780802045, 0.042995457333745435, 0.048109248164109886, 0.0812648143619299, 0.045667504382436164, 0.05046859871072229, 0.012619175740837818, 0.03669102043204475, 0.00947062813793309, 0.04194064284092747, 0.0054811706286272965, 0.02835813251294894, 0.040301364788319916, 0.008887386338756187, 0.06225011886272114, 0.039961427755770274, 0.028983562624489423, 0.0977693177992478, 0.03974580416979734, 0.0781509185617324, 0.025712513343023602, 0.07436357569531538, 0.10946733149467036, 0.029647873852809425, 0.03329036619106773, 0.023490708736062516, 0.07444319329806603, 0.04966009932104498, 0.024042853619903326, 0.030915417555661406, 0.029317106054804754, 0.022192512478795834, 0.04604267487593461, 0.030691131250932813, 0.04638438193069305, 0.030174268067639787, 0.03749602801690344, 0.04471284271858167, 0.03155935126414988, 0.02803112925903406, 0.024776115933491383, 0.02333099484530976, 0.048013793129939586, 0.05892245484574232, 0.036336585544631816, 0.030792671896051615, 0.07131727470550686, 0.04757756243634503, 0.05199827268370427, 0.013386519331106683, 0.06462773366365582, 0.028986918987357058, 0.06540752307046205, 0.08085488167125732, 0.01724336154438788, 0.011043091562896734, 0.057760481649893336, 0.12539983203168958, 0.031644367991248146, 0.017726338264765218, 0.018196700330008753, 0.046931559991207905, 0.11553436648682691, 0.037717035884270445, 0.020093726270715706, 0.02170794385165209, 0.046948176677688025, 0.04154088499490172, 0.020798751720576547, 0.03184022076311521, 0.04375800293928478, 0.03722128865774721, 0.01794519390386995, 0.017747081292327493, 0.07298473210539669, 0.04810027930943761, 0.03172645694576204, 0.016765926811785903, 0.00953778971961583, 0.0210663590405602, 0.032900100413826294, 0.11075096495915204, 0.10834697794052772, 0.02210792063124245, 0.01470884930313332, 0.09633739580749534, 0.03581913792004343, 0.05762868364399765, 0.07160612600273453, 0.03721651293744799, 0.05974085819616448, 0.012804664420400513, 0.027862752649525646, 0.0350585144769866, 0.038736921196687035, 0.03944500058423728, 0.053267515904735774, 0.01933023813762702, 0.018697620325838216, 0.02827275027811993, 0.035023403470404446, 0.04802338909939863, 0.04501094859733712, 0.08505428719217889, 0.010275325876136776, 0.024140935856848955, 0.013047565644228598, 0.04017764134914614, 0.059317418417776935, 0.029483733051165473, 0.03274948896432761, 0.040271767938975245, 0.07073990607750602, 0.008911672193789855, 0.014186681619321462, 0.009201622797263553, 0.06877176754642278, 0.018475206088623963, 0.047248679693439044, 0.04710111104941461, 0.07685897304327227, 0.0424513740290422, 0.03157098442898132, 0.022384969925042242, 0.016085592615127098, 0.04475879279198125, 0.04056369172758423, 0.0031658431225878303, 0.06575217645149678, 0.10140633123228326, 0.12665861839195713, 0.06819264744990505, 0.05662142226356082, 0.07497559519833885, 0.023434049471688922, 0.0420640657102922, 0.043790509007521905, 0.06631861324422061, 0.03564389087841846, 0.0961110185016878, 0.03082120561884949, 0.043431513622635975, 0.09809543975279666, 0.009104397740884451, 0.07893221452832222, 0.014306118227978004, 0.06795874476665631, 0.028142354931333102, 0.033015088774845935, 0.04426728322869167, 0.015682723314967006, 0.10360115877119824, 0.04147331615968142, 0.02046303194219945, 0.015387880102935014, 0.07010421206359752, 0.028559143211168703, 0.06336395264952444, 0.027639638938126154, 0.04328194489062298, 0.041935948756872676, 0.028877839977212716, 0.027381273212085944, 0.0370294286403805, 0.04567880729155149, 0.02002383265789831, 0.01103314400097588, 0.02354537162318593, 0.014064268998481566, 0.08407196568441577, 0.043798646656796336, 0.09076823058421724, 0.046499726522597484, 0.07818752870662138, 0.18330566701479256, 0.17741907038725913, 0.14392443175893277, 0.1581113861175254, 0.19010903866728768, 0.17635961004998535, 0.13480555935529992, 0.16268058156128973, 0.1497452295734547, 0.163418706797529, 0.15125129953958094, 0.19403664744459093, 0.11803599045379087, 0.11332779817166738, 0.09443809147342108, 0.10803575831232592, 0.17905802931636572, 0.0940160766185727, 0.127419542404823, 0.14482630445854738, 0.16291544161504135, 0.25290457298979163, 0.10818359412951395, 0.1724447513697669, 0.15251391538186, 0.10966302099404857, 0.1166528052999638, 0.07595025032060221, 0.16534883994609118, 0.1357858770643361, 0.1608355579082854, 0.15042583836475387, 0.17865893198177218, 0.16430863091954961, 0.07946189274662174, 0.10567011806415394, 0.10892385675106198, 0.11674640496494249, 0.1318023697240278, 0.09439205605303869, 0.10893149345065467, 0.1270488099544309, 0.13517382787540555, 0.12964499095687643, 0.14054748171474785, 0.15971853659721091, 0.1922516041668132, 0.2328983644838445, 0.14796725154155865, 0.16242697485722601, 0.09707299032015726, 0.07597477087983862, 0.18214810959761962, 0.07600143624586053, 0.14535364491166547, 0.2278428545105271, 0.16567838320042938, 0.10900849127210677, 0.16057565779192373, 0.19903228094335645, 0.14752240822417662, 0.2053250401513651, 0.1257464149966836, 0.08950385585194454, 0.2252638468053192, 0.07609571868670173, 0.10766023158794269, 0.09882440688670613, 0.11056752831791528, 0.09771103694220074, 0.20315008732723072, 0.1435589388711378, 0.17918864730745554, 0.09618072843295522, 0.1357795688090846, 0.14492783026071265, 0.24997166474349797, 0.16454083408461884, 0.11601708160014823, 0.07014750895905308, 0.09302116086473688, 0.09552603543852456, 0.10198849413427524, 0.18454814096912742, 0.2321390583529137, 0.1006091533054132, 0.08812846324872226, 0.21102911297930405, 0.10669952884200029, 0.0923364183108788, 0.23540015914477408, 0.21016025100834668, 0.08896624407498166, 0.09802656102692708, 0.12813268695026636, 0.09460062181460671, 0.12989205191843212, 0.12149141519330442, 0.16480876423884183, 0.11109376297099516, 0.15955743117956445, 0.1622350703109987, 0.1892431898158975, 0.12236009162734263, 0.20377286797156557, 0.17788549535907805, 0.09062204975634813, 0.11154850653838366, 0.16429475275799632, 0.11669115207041614, 0.22321730037219822, 0.18611405772389844, 0.09853111012489535, 0.11902314334292896, 0.1420827180845663, 0.14617015578551218, 0.05982019007205963, 0.13381185330217704, 0.21154468297027051, 0.1504951698007062, 0.1560598227661103, 0.08802617303445004, 0.12368561932817101, 0.09948711507604457, 0.1431213686009869, 0.17924776679137722, 0.1289294270100072, 0.1235498434107285, 0.09529181363177486, 0.10291653496096842, 0.1174771755177062, 0.11570162430871278, 0.12908512959256768, 0.10533761364058591, 0.15353470982518047, 0.20175118348561227, 0.1432077249046415, 0.10378918930655345, 0.09395577711984515, 0.12906651652883738, 0.10261235089274123, 0.17063699837308377, 0.1984406853443943, 0.1664520424674265, 0.20493927178904414, 0.1438598203822039, 0.23238942929310724, 0.10878852612222545, 0.1619093120098114, 0.1278494982398115, 0.2007929966202937, 0.1366358736413531, 0.16504732018802315, 0.13261577842058614, 0.12274830907699652, 0.0950523819483351, 0.07216134894406423, 0.0913544233480934, 0.2036653010873124, 0.1332668645773083, 0.13045060710282996, 0.17541028442792594, 0.1426604948937893, 0.31120739760808647, 0.07392306652036496, 0.09999117435654625, 0.23079868027707562, 0.09545125663862564, 0.2518007025355473, 0.15828185743885115, 0.1244386839971412, 0.13180671870941296, 0.11623568861978129, 0.15078083728440106, 0.13676787202712148, 0.10939443032839336], [0.04053061791637447, 0.044768232910428196, 0.0698036645189859, 0.029608727418235503, 0.032504795453860424, 0.02353646585106617, 0.023388973277178593, 0.02375309690251015, 0.04400350539071951, 0.02766918569250265, 0.006746500412191381, 0.016073525293904822, 0.038508781290147454, 0.014612910017604008, 0.07717162501649, 0.047531809032079764, 0.0528185202711029, 0.02597525959572522, 0.04933431133395061, 0.010229202325717779, 0.08532351610483602, 0.004976445734428125, 0.05821935526910238, 0.014153496485960204, 0.019323725791764446, 0.06169405358377844, 0.027020236921089236, 0.027574997875490226, 0.02322679545613937, 0.06299382133875042, 0.059071882569696754, 0.04214245876937639, 0.06837289285613224, 0.025217556503775995, 0.018978179978148546, 0.0399462842324283, 0.013603203260572627, 0.01947676963027334, 0.05304920574417338, 0.04450595792150125, 0.10824649114510976, 0.033578501315787435, 0.05595622045802884, 0.059024477886850946, 0.03342137009894941, 0.030418137794185895, 0.04424550861585885, 0.036285859750933014, 0.07295418530702591, 0.02792436018353328, 0.05473677534610033, 0.029128032801963855, 0.03181554806360509, 0.029311758880794514, 0.01023933635224239, 0.011663488985504955, 0.05800192826427519, 0.04925506480503827, 0.011877928845933639, 0.010829108123289188, 0.014180193393258378, 0.07879700264311396, 0.03800378319283482, 0.013414663426374318, 0.05101486392959487, 0.06406681844964623, 0.018909505342890043, 0.01861377248133067, 0.038168272803886794, 0.02596577123767929, 0.046221313532441854, 0.08279681496787816, 0.029330338547879364, 0.011757235224649776, 0.07634600799065083, 0.026450408513483126, 0.07566870175651275, 0.05506289358891081, 0.03693746170029044, 0.04955547134159133, 0.003919084747394663, 0.01485683447754127, 0.09802034182939678, 0.03788716210692655, 0.021465575118782, 0.02273154732392868, 0.021557239633693825, 0.02037059373833472, 0.052938117369194515, 0.009827014873735607, 0.026913673791568726, 0.03022513301402796, 0.04831400299735833, 0.045047874154988676, 0.039899840630823746, 0.03487146728730295, 0.049597458346397616, 0.010292243132425938, 0.042652136107790284, 0.0564663913246477, 0.0399995778570883, 0.02197284047724679, 0.04165508667938411, 0.027105240660603158, 0.06630566276726313, 0.023330161784542724, 0.04680748774262611, 0.06375107172061689, 0.02584776604635408, 0.06751704073394649, 0.008407918121520197, 0.03507735760649666, 0.03851670742733404, 0.04948139758198522, 0.015777881490066648, 0.03416660510993097, 0.031055477520567365, 0.026594071605359204, 0.05705127419787459, 0.06027975017786957, 0.041363593336427584, 0.042744299717014655, 0.04143455378653016, 0.08870613615727052, 0.017939212193596177, 0.04836602383875288, 0.03316052745503839, 0.04312586381274741, 0.027085301007900853, 0.030001052655279636, 0.010527697832003469, 0.02514430096198339, 0.04431641340488568, 0.026298297925677616, 0.03889404870278668, 0.07033048546873033, 0.01236888550920412, 0.024881317222025245, 0.05543699910049327, 0.05614049201540183, 0.015557849546894431, 0.03709761345817242, 0.06781099058571272, 0.0402238177775871, 0.03746974856767338, 0.05601914344879333, 0.026810639574250672, 0.01079313437003293, 0.06665801964118145, 0.02915985980507685, 0.02716940303798765, 0.08027000993024558, 0.013475776504492387, 0.09084173289011233, 0.021317748578439932, 0.13110657659126446, 0.023274617597053293, 0.018967669311678037, 0.056116947380360216, 0.027255338172835764, 0.07640109761268832, 0.03233241310226731, 0.02955127591121709, 0.04946715205733199, 0.07019483571639284, 0.019749076600419357, 0.11152425315231085, 0.00511435764565249, 0.033566211350262165, 0.040537167369620875, 0.01852924000559142, 0.004059323291585315, 0.08944737841375172, 0.049442683448432945, 0.046428094428847544, 0.04956444761774037, 0.005863103478986886, 0.019165041630913038, 0.07418854016577825, 0.02737556609645253, 0.0935598932846915, 0.08197217757697217, 0.04459190975467209, 0.02261147525132401, 0.07579520082799718, 0.02620858525915537, 0.02387815806287108, 0.013347307030926459, 0.055898229038575664, 0.02366616728977533, 0.1055936397460755, 0.01125703511206666, 0.04661972438043449, 0.015230762801365927, 0.04056594414578285, 0.017777104876586236, 0.13089608866721392, 0.044742584286723286, 0.05609689083939884, 0.04070111892360728, 0.020370638267195318, 0.006297957024798961, 0.018047298581223004, 0.07380070121143945, 0.014527855255437316, 0.046028258657315746, 0.043013164977310225, 0.0255365204429836, 0.04166405553405639, 0.015613397445122246, 0.010663346656656358, 0.05417827211203985, 0.039006818042253144, 0.03729755917447619, 0.04203160417091567, 0.05457371808006428, 0.09320303157437593, 0.04267363983672112, 0.025380021907039918, 0.032365653896704316, 0.03718422580277547, 0.024885634666134138, 0.030989643455541227, 0.012266553549125092, 0.06506299585453235, 0.035279644798720255, 0.06298607331700623, 0.025041517219506204, 0.01976384904992301, 0.030112666099739727, 0.03855615257634781, 0.011010804428224219, 0.027500222786329687, 0.021745305421063676, 0.020040063427586574, 0.04288005337002687, 0.023939951133797877, 0.09946987498551607, 0.07773390578222461, 0.011884705581906019, 0.031613335086149164, 0.02265383332996862, 0.056628019956406206, 0.04372158946353011, 0.07787823866237886, 0.045166521304054186, 0.0427110700547928, 0.01218114904986578, 0.028048311833117623, 0.02587491566373501, 0.03446144182817079, 0.03132241690764204, 0.05233970885456074, 0.03253627735830378, 0.07036996030365117, 0.02239908186311368, 0.02223138802946778, 0.03785881206567865, 0.03664022413431667, 0.02169440336729167, 0.027145491039846092, 0.03081019956880482, 0.05529068468604237, 0.02889445109758526, 0.04441280725586694, 0.017586261601536535, 0.04824977382668294, 0.03072135707043344, 0.024189956566260662, 0.0452441128436476, 0.03610914325690828, 0.008735717328818282, 0.03205393331882078, 0.041355515058967285, 0.06074244585761335, 0.054465687353513204, 0.09257363839424215, 0.10895257044467144, 0.08241722869570367, 0.029028058088442776, 0.06304067312157713, 0.02742172211583238, 0.018140963184123393, 0.05756374572229106, 0.027386867150198668, 0.058300828241044655, 0.06745357226463966, 0.010048163749161176, 0.05169812589883804, 0.010903345155384159, 0.03938589965400752, 0.015527831528743263, 0.026068885235872585, 0.047026543761603534, 0.028052471570845228, 0.030418586793530267, 0.017266182585444767, 0.04595020327542443, 0.03273699861892965, 0.04166619291936513, 0.09070194937521592, 0.029931075550848618, 0.07202513515949249, 0.025718710276123602, 0.0780069938628003, 0.034923573475680314, 0.0267166614139569, 0.009272041479562176, 0.08786421414697543, 0.029998230638739187, 0.021430399174278136, 0.10317638312699273, 0.04634709272067994, 0.003824744790108525, 0.02344823191378964, 0.024675163440406322, 0.080975525197573, 0.037925712967989966, 0.04872378725849558, 0.04310779622755945, 0.04005937269539572, 0.07153561455197632, 0.034394566901028156, 0.04958706827892456, 0.030232688077376224, 0.0668012244568672, 0.02729885029111756, 0.03650828140962403, 0.05368564561649691, 0.028307944776315708, 0.07346576254349202, 0.034694164496613666, 0.008625509326520842, 0.037279421085258946, 0.02386244679655647, 0.07166345691075549, 0.03278388008766342, 0.06609517484321259, 0.014750560785614653, 0.02111807745677652, 0.017483691226516385, 0.016732916083128657, 0.1408967809402384, 0.014451212737185415, 0.013577263343904633, 0.0505760913802078, 0.06337349666864611, 0.06511513172881678, 0.01574296529724961, 0.013485647996276384, 0.008089184248092351, 0.007421783366226009, 0.20253941853297874, 0.09313810849562287, 0.2565671014599502, 0.11413751839427277, 0.2442506412626244, 0.1855381511268206, 0.16757139412220567, 0.10574106738204136, 0.15834865072974935, 0.12466754007618874, 0.10442797807627358, 0.1022503015701659, 0.12774053611792624, 0.15212692989734933, 0.16988407471217215, 0.18031325336778536, 0.11382422817405313, 0.08480691452859901, 0.2374673669692129, 0.09224505251040682, 0.14576037152437493, 0.07400120724923909, 0.20223303028615192, 0.10088495764648542, 0.11990117825916968, 0.16737509606173262, 0.0745572910818737, 0.12701596249826252, 0.09104019060032442, 0.15313644369598478, 0.1608862614375539, 0.1460248581133783, 0.12753908755257726, 0.10207044208073057, 0.12184294828330167, 0.13249653013190255, 0.09614198832423426, 0.1567765444633551, 0.12899368215585127, 0.1595437608193606, 0.21076248900499195, 0.10235910041956231, 0.15967041574185714, 0.15685018035583198, 0.07892276698839851, 0.12286116747418419, 0.11350750923156738, 0.055854776292108, 0.15680504293413833, 0.14985405810875818, 0.2600340888602659, 0.13844401255482808, 0.06845223586424254, 0.07263936626259238, 0.16840254014823586, 0.06967196299228817, 0.20057836751220748, 0.06254054722376168, 0.11002656203345396, 0.16390757431508973, 0.17565928981639445, 0.30494028702378273, 0.17901260987855494, 0.10343238696805201, 0.07573555441922508, 0.12377282910165377, 0.0960165134165436, 0.1648995585856028, 0.08685061853611842, 0.17732300679199398, 0.10796477188705467, 0.16034559201216325, 0.16462065948871896, 0.13774373685009778, 0.19169831823091954, 0.12023200542898849, 0.13442764291539788, 0.1665457311901264, 0.19732421322260052, 0.10133709627552889, 0.09863167855655774, 0.12801627366570756, 0.22209462389582768, 0.12657987652346492, 0.1659961263067089, 0.09004084422485903, 0.15048589295474812, 0.11952939195907675, 0.13532809069147334, 0.2264165208907798, 0.15609477792168036, 0.23209530132589862, 0.09329461259767413, 0.19513420964358374, 0.18522291647968814, 0.139762912876904, 0.16313784843077883, 0.12113552569644526, 0.1723797689191997, 0.13788861891953275, 0.14413984754355624, 0.16851850814418867, 0.15243873582221568, 0.07834615535102785, 0.2247602105489932, 0.0844403900555335, 0.130345162760932, 0.13768899603746831, 0.1314666963298805, 0.20494590658927336, 0.12512710760347545, 0.11101017487817444, 0.09723787326947786, 0.21748940460383892, 0.13439378613838926, 0.16169349546544254, 0.11233585843001492, 0.14891458820784464, 0.21239582245470956, 0.13955989095848054, 0.12643202586332336, 0.16343585040885955, 0.14809264481300488, 0.13422672869637609, 0.1289670538972132, 0.1342153738369234, 0.12278641093871556, 0.17130580701632425, 0.1527387712849304, 0.10400821192888543, 0.09583361112163402, 0.10516413662116975, 0.17358470504404977, 0.09589092718670145, 0.17217809770954773, 0.24924438970629126, 0.08787897546426393, 0.0988128590688575, 0.20543113758321851, 0.12979579536477104, 0.10786071536131203, 0.14998887665569782, 0.10823705844813958, 0.10237312701065093, 0.18836522911442444, 0.21388694556662813, 0.11662868550047278, 0.1433170135715045, 0.11214839192689396, 0.191827422240749, 0.08235260247602127, 0.11800079781096429, 0.08488958977977745, 0.1898551796330139, 0.1878288938314654, 0.17432670429116115, 0.06323473731754348, 0.11258570244535804, 0.1217423946945928, 0.16403356130467728, 0.112594474630896, 0.17563877685461193, 0.12134690419770777, 0.09329755150247365, 0.19633349060313776, 0.14684530236991122, 0.24177243205485865, 0.11055849638069049, 0.17017110774759203, 0.1496980438241735, 0.13310954411281273, 0.11388327344320714, 0.12708443304290995, 0.12600900168763474, 0.09503670036792755, 0.11673986664391123], [0.05204052686167415, 0.02842248784872936, 0.03558182135748211, 0.049869778304127976, 0.05923328484641388, 0.059777368151117116, 0.015858174447203055, 0.009650956108089304, 0.05691062608093489, 0.02466187157551758, 0.04172370565356687, 0.04612258191627916, 0.007750283439236227, 0.01891242940473603, 0.04647979614674114, 0.014722293308295775, 0.01664537234319141, 0.05230532886344008, 0.033277471375185996, 0.0398557644803077, 0.08111461851513013, 0.011809389652626123, 0.016681796951161232, 0.0645588400948327, 0.03701977700984571, 0.024653900909470394, 0.12509795604273677, 0.04501192823227029, 0.0418754785641795, 0.013293253632582491, 0.056341057425015606, 0.023036425300233532, 0.01652329276112141, 0.0709873900632374, 0.003330603617541783, 0.020666432355938014, 0.03263720944232773, 0.004377299710540683, 0.009048909214470768, 0.026319712596887257, 0.043626119586406276, 0.027322153728164267, 0.02831688580045011, 0.014460955280810595, 0.022436797808040865, 0.02571321096183965, 0.0440107895701658, 0.024400320180575363, 0.030244013250921853, 0.04665694308641832, 0.014745507687621284, 0.06725697734509595, 0.048863043848541565, 0.06522716634208336, 0.017349137997371145, 0.0816463673254475, 0.08482790988637134, 0.009575209733156953, 0.01607927137229126, 0.05870215572940651, 0.03505477034195792, 0.06014568862156011, 0.06483578734332696, 0.06223546515684575, 0.02341787807381479, 0.0295195583748864, 0.03512051349389367, 0.009428293251403375, 0.023617744009243324, 0.07392350438749418, 0.07186043774709105, 0.02231836402643239, 0.08349496070877649, 0.1073720704880543, 0.04405694373417646, 0.05103463845443912, 0.039557491618325, 0.04325652262195945, 0.02393629605649039, 0.09028318512719125, 0.07813733725924976, 0.05901858152355999, 0.03191342992067803, 0.06380058781360276, 0.04644481872674078, 0.03874936330248602, 0.045737819164060056, 0.0424124001438031, 0.02579185449576471, 0.039837192234699614, 0.05791621391836088, 0.031312535211327486, 0.07126904252800159, 0.05052633037848864, 0.012696005651378073, 0.05464215522806626, 0.0496804119029548, 0.028095592206227593, 0.04236275046423543, 0.019645803040475585, 0.04281825844373088, 0.048260234398185275, 0.021176241425564513, 0.02729910262132762, 0.020568808395182714, 0.053044897576910444, 0.029409509006654844, 0.07598945056088269, 0.034757232206175104, 0.04402416307129897, 0.07158300068113022, 0.038476078552776016, 0.030561023486370686, 0.031810571963433176, 0.01931487196998205, 0.03679131426906679, 0.03898225666489452, 0.03822823091468308, 0.06303233880316839, 0.04679923877120018, 0.05743266017816495, 0.02349387028516503, 0.022751338547095656, 0.022589262771361973, 0.05184184650715906, 0.06465901518822648, 0.01468425638449844, 0.03159467378281988, 0.041004828017321415, 0.04485528312216047, 0.0681638224341441, 0.03611518804973457, 0.01379334242301411, 0.015226321975205792, 0.03764892157050781, 0.051890724353143014, 0.07028128107776865, 0.033300121722277254, 0.009635289370635292, 0.04125169973121956, 0.02527370183088351, 0.0058458286002860405, 0.07711389334872365, 0.04465082885872107, 0.03532315320626367, 0.05440539156552404, 0.04366215827758424, 0.012366773171379464, 0.045937393806525506, 0.05333702174539212, 0.12104211156838574, 0.07148459932068363, 0.04259024470229633, 0.044695016331388615, 0.09376108209835365, 0.01148256173109985, 0.04853310725593474, 0.0996706036676187, 0.014172767278068932, 0.054612109379377216, 0.007320812319449033, 0.02158407383831218, 0.04145577178860549, 0.02630519804370124, 0.0073093971604976105, 0.06815812273998745, 0.01981088636966888, 0.04635780191165395, 0.034845391928683966, 0.07583225626149215, 0.02577563856902998, 0.037014630215708166, 0.053211528284009546, 0.002320595363016764, 0.0608812014979776, 0.05096725515613798, 0.010683755717764143, 0.037874634654144756, 0.0892967966501601, 0.05145440831256565, 0.0705026785726659, 0.09225495276041329, 0.06879069973365404, 0.06090288334235083, 0.05540069323615171, 0.06437262782128528, 0.050017870162264444, 0.034478303423384205, 0.021112713584443554, 0.07083637043251656, 0.03532399554387666, 0.06906560607603751, 0.0364307826384902, 0.054463256819872186, 0.04062402091221884, 0.013256387446745066, 0.07324121092096902, 0.015836735656193923, 0.05853731359820813, 0.022643899683316704, 0.07703461713390425, 0.08291609294246882, 0.04950933944201097, 0.00815905930721783, 0.01366319105727598, 0.034762776049319655, 0.0565928532887483, 0.04557318112347275, 0.025840910457191058, 0.049605629392317496, 0.011649565367406467, 0.036576072889147326, 0.04470158433832694, 0.036265168673708104, 0.06192159235069994, 0.034247272851644084, 0.04386265318316873, 0.04721416611573659, 0.05603370438620914, 0.05299748918332625, 0.019083227271039505, 0.01714406032988336, 0.09195271311909892, 0.02748007718764711, 0.0437845347187249, 0.05267284039291553, 0.02684730352484621, 0.057999865093734115, 0.02102284321154002, 0.00349455980995117, 0.027596366162470076, 0.10599683373584412, 0.027022943904739805, 0.05932230917096604, 0.03984277689596638, 0.0367009911860805, 0.03837975149508566, 0.04510813654633239, 0.011274681528448127, 0.028222553264640737, 0.03935844390070997, 0.007839491445338354, 0.08100123319309205, 0.03603087636292912, 0.04695620300481096, 0.04993693895812612, 0.059773776156362146, 0.07179367414209992, 0.05413838538515847, 0.08765525504713878, 0.05515364340681117, 0.019272740246378817, 0.07366107354755513, 0.04171459950157441, 0.048874176063691266, 0.024673330335645005, 0.033963846653932706, 0.08037893494474702, 0.027887230535270646, 0.07644227938726544, 0.02559891465352848, 0.016250369808403775, 0.04196447320282459, 0.040091574483085424, 0.09127520650508814, 0.02328210957784904, 0.027310502009640913, 0.05679554495145567, 0.04673440103942994, 0.014687647999380715, 0.04680768441176042, 0.027151689828315284, 0.03160481894155964, 0.009775956968951505, 0.03213676442101132, 0.03674244013382122, 0.017743491152941715, 0.05668818957929034, 0.06354538549203426, 0.030122874341032002, 0.017559360603627283, 0.052526481449604034, 0.02471516334480839, 0.026754397767945193, 0.06464245045208372, 0.026133880674024113, 0.06516898938571103, 0.07942317490233108, 0.039615160203538835, 0.1267936744261533, 0.03171085329086054, 0.029140905353415292, 0.03173838325892575, 0.0034550499549368396, 0.04430555578437634, 0.033818597221397795, 0.02008557192311855, 0.04678023607993964, 0.045270971168065444, 0.07329821528401226, 0.08608348274719901, 0.0296404208347667, 0.035664752649609, 0.05657766152580734, 0.04722261546703521, 0.006765653388356441, 0.018029936036327854, 0.07211257499875501, 0.048742719445726834, 0.047379665047628805, 0.04207320154819172, 0.03034002675121883, 0.022544398088939488, 0.066865806147689, 0.022803574611316435, 0.017982462704821955, 0.02851940120308427, 0.03754588178708218, 0.08623002722742967, 0.027930662872677203, 0.0477318066987209, 0.03345341232488863, 0.06571248639374971, 0.054034258355386555, 0.01572106637468096, 0.06196783186169341, 0.10951721124001779, 0.07006259984336793, 0.014937197011022363, 0.015144034496188397, 0.017397167939634528, 0.030173373779689427, 0.04951695016643498, 0.059933137526968494, 0.0004133569484565669, 0.06216395922820084, 0.008962501888163388, 0.04920407554891426, 0.026728006996563636, 0.029026781594438944, 0.07903688703663647, 0.06784464698284864, 0.10918940461124294, 0.042480484771658666, 0.034440550371073186, 0.02512180646590423, 0.03470386436674744, 0.07201923508546315, 0.008830736351228552, 0.03554319257091265, 0.025777046794246417, 0.05472398072015494, 0.11165200645336881, 0.08378862854442559, 0.15206270443741232, 0.11765614442992955, 0.11290757189271972, 0.2188913364079781, 0.1646658414392732, 0.1868619050947018, 0.18431970791425556, 0.12081036853487603, 0.15700763440690935, 0.13735059153987095, 0.11999551265034825, 0.13436426350381225, 0.12713184143649414, 0.14885781391058117, 0.12281572577194311, 0.18793239374645054, 0.10444904022733681, 0.12030110679916106, 0.2241466919076629, 0.1457566607859917, 0.19348653790075332, 0.13161709997802973, 0.11310335787129588, 0.20542822836432606, 0.1656797487521544, 0.07464369933586568, 0.08867805328918621, 0.09336983668617904, 0.2783450984861702, 0.15252354845870286, 0.10652650453266688, 0.15832375909667462, 0.11176626750966534, 0.15447495155967772, 0.08408884212258272, 0.08998828532639891, 0.1736323509248905, 0.15829227719223127, 0.1682736142538488, 0.06928080663783476, 0.17981049284571782, 0.08176687726518139, 0.09769758180482313, 0.09542767860693857, 0.15391243330668658, 0.11405022698454559, 0.13393093831837177, 0.12250223517185077, 0.1446783053688705, 0.16905260214116424, 0.08370451352675445, 0.12836019974201918, 0.11277652345597744, 0.22327492071781307, 0.17614498094189912, 0.156428343616426, 0.14687267277622595, 0.22700545960105956, 0.08595362174673937, 0.21801819966640323, 0.10345473303459585, 0.13787520088953897, 0.14819353236816823, 0.19991494686109945, 0.17707573802908882, 0.15170576109085232, 0.09983509327867068, 0.19917008292395622, 0.24356042908038944, 0.11949001360335387, 0.08882869442459196, 0.2468579396372661, 0.19730994914425537, 0.14682759472634643, 0.10917434643488377, 0.20145442831562832, 0.17004875728162006, 0.16581866395426914, 0.16013439162634313, 0.22710374963935465, 0.1432296182611026, 0.21785375458421186, 0.16891733830561861, 0.11393888256861828, 0.1646026549860835, 0.23334772005910054, 0.19730424945009872, 0.2798871329287067, 0.22889237006893381, 0.12754180381307378, 0.14018268644576892, 0.134343423997052, 0.11959447831031866, 0.10600869325571693, 0.07547001398052089, 0.17659841832937673, 0.24229149013990536, 0.12544571160105988, 0.11045397230191156, 0.1375110587105155, 0.18668024218641222, 0.0921033023041673, 0.10375944402767345, 0.1581198614439927, 0.16427760914666578, 0.16313085739966482, 0.17351173708448187, 0.1326068429625593, 0.18165516026783735, 0.14866207988234237, 0.13427943602437153, 0.20796193537535146, 0.15658995369449258, 0.2524976682616398, 0.10309785648132674, 0.16753534058807418, 0.13325727602932602, 0.12456574710085988, 0.17782036447897553, 0.16756012832047418, 0.09093720276723616, 0.17796333180740476, 0.20281113364035264, 0.20766651607118547, 0.17241331399418414, 0.15543241112027317, 0.1652727698092349, 0.2265094971517101, 0.14413785858778283, 0.1235486930818297, 0.16277899034321308, 0.0863478060637135, 0.15670663415221497, 0.06880889719468541, 0.13883856794564053, 0.12506721628597006, 0.11984346885583363, 0.08172380301402882, 0.12405191373545676, 0.07216036188765429, 0.2601916319690645, 0.11379051982657984, 0.09805776091525331, 0.12800542346667498, 0.21461088093928993, 0.19837589585222304, 0.1982938143191859, 0.21576910628937185, 0.22081913921283558, 0.1635749140405096, 0.17030335846357048, 0.17834500351455063, 0.14391937031177804, 0.08010963181732222, 0.33286884776316583, 0.23254630446899682, 0.08072331373114139, 0.10040675479103811, 0.11114278182503767, 0.11489986733067781, 0.12558861955767497, 0.09566783017362468, 0.2676037873607129, 0.15048865374410525, 0.1581793965306133, 0.12389336130581796, 0.1813745393883437, 0.125880224222783, 0.20267441519536078, 0.14376964943949133, 0.12345353490673006, 0.09367587612359785, 0.2228242441196926, 0.1380377757595852], [0.06240052622160874, 0.011812540997198084, 0.06191236745507922, 0.02116828374710167, 0.0649073971726466, 0.07847675107768737, 0.0484520684403833, 0.0738745449052658, 0.033080408902605996, 0.018526432832004502, 0.0010288432667948655, 0.03801698228926398, 0.010111673964274814, 0.037463596163433976, 0.057977637770818546, 0.04020536427560728, 0.029044374205113854, 0.03331630796310492, 0.0255802088213386, 0.030166278847900685, 0.028605304796656128, 0.04773253029270563, 0.08897641891962849, 0.012360199598333566, 0.03241683240048587, 0.031970771960914135, 0.10220584692433476, 0.040491792460670695, 0.08879828863427974, 0.0075450104941410245, 0.03611230851674918, 0.035189893169444986, 0.06175712500407826, 0.06190758431330323, 0.018825926526915282, 0.03425279814109672, 0.029806409584125504, 0.0228150463590282, 0.0787717622006312, 0.02565559247159399, 0.01091669268134865, 0.03097199889452895, 0.03343891447002534, 0.07723597664153203, 0.03272956972068641, 0.042353744502179325, 0.017679647899058182, 0.06370939270709641, 0.031305017255363055, 0.008959281894931337, 0.009721225433168001, 0.05790714858449064, 0.035387976095080376, 0.02981184396048775, 0.049875158874783665, 0.032470530495629646, 0.034442268442944624, 0.040313836580025963, 0.021152492699911818, 0.060803791784564964, 0.05920453775615897, 0.03405144234420732, 0.02440958774968749, 0.03381688286026474, 0.015280034913303098, 0.079008618631633, 0.03213701675122138, 0.029594055158668198, 0.07256817203597166, 0.02532804002839839, 0.018219077937828843, 0.05255347707134206, 0.02334971180971479, 0.03192878866684623, 0.025344387686345726, 0.019821406312985346, 0.03814645366219338, 0.09191513076075353, 0.08415838878136128, 0.0256825472752098, 0.04030635944218375, 0.006443665661208797, 0.07426425407174975, 0.060150627614348195, 0.05468409770401195, 0.012137635076214792, 0.04352370320702903, 0.024278864002553746, 0.07170946264523081, 0.01161709918960696, 0.014315867265395354, 0.01857616785855498, 0.07745216425973922, 0.02373672141402494, 0.08255539432866499, 0.017034155680448748, 0.05481358391989488, 0.03074957352509955, 0.00939572038987535, 0.05852944312209729, 0.04908460090518929, 0.02856806753698038, 0.09627111459849402, 0.013111273456161143, 0.043230321098235436, 0.030753295395697933, 0.05793364696728531, 0.01904619966808241, 0.011423496980569325, 0.041662192743388005, 0.03554999435436912, 0.019545067625585943, 0.060670123566524126, 0.042801356030395254, 0.03362121191457845, 0.02329975599423051, 0.020380974528961815, 0.06054169120034203, 0.05600054522801656, 0.019221580296289176, 0.0552343074377859, 0.02126852748915553, 0.06167524385091383, 0.06746939485310577, 0.03507872315822169, 0.07335127142141573, 0.03158907427859958, 0.04220227216137573, 0.0035683585110746208, 0.005905401721975068, 0.03651102364528924, 0.07334520807489753, 0.0662200634542387, 0.11171620964887552, 0.005467739611049183, 0.011403458065615268, 0.05097651715914253, 0.041271696900366805, 0.023841449583414942, 0.06282849310082383, 0.05852459689776879, 0.024888647785701323, 0.07255112490383908, 0.03344235061376821, 0.0411558810446877, 0.014406117061298573, 0.11016459407983348, 0.03755408622964751, 0.0356423991615884, 0.03505604683596175, 0.03716116727446206, 0.030582080071326345, 0.0626114742772188, 0.061897042105556466, 0.03954691972467117, 0.028819677863793913, 0.03542643789842259, 0.033111738666775636, 0.05614784298813902, 0.017613585623621475, 0.08590207216911949, 0.03270438493927941, 0.027575994208746124, 0.023144036713347305, 0.014258915780374082, 0.05367083977034781, 0.02983832007885212, 0.07911907247034833, 0.032129984901985154, 0.020136199382250197, 0.036572629323927686, 0.018561634751677047, 0.05186165071791038, 0.05396876382292248, 0.10069475261843763, 0.067924242321169, 0.07740070373984054, 0.03412227662920486, 0.08650641044368967, 0.007975310036272276, 0.11075375543441623, 0.0140984996323823, 0.031072335405042395, 0.034979152915184386, 0.025742149155121297, 0.06047702416253742, 0.012454877232812578, 0.06269867662922479, 0.04055444456753321, 0.021013219411543105, 0.049805512026068754, 0.0607498933095485, 0.00640990953797882, 0.046489329033647664, 0.038382137499866076, 0.03675553161883727, 0.047140385504462756, 0.08111420291243121, 0.034185236727353185, 0.029033735518169124, 0.04064994784130249, 0.01369092233289848, 0.06606817551073618, 0.07448375909007154, 0.019731365246116184, 0.058800004189834, 0.019419314412516542, 0.02533960639993893, 0.03831582289421931, 0.037347275647334754, 0.04498642432736233, 0.0015964382737365668, 0.08562846458517015, 0.06956031429581344, 0.039601181852049194, 0.02217174904217245, 0.05838015269546304, 0.04947300018102396, 0.05073017608083319, 0.09222381966537796, 0.06018604661221616, 0.05901727534364909, 0.017699285126582254, 0.03157754130370449, 0.05328766150341835, 0.05765924528532196, 0.014961936503823381, 0.03083965912082931, 0.02371168135141488, 0.045275286756805144, 0.006126314965513302, 0.02574107489635935, 0.029120930448698346, 0.03018455423443811, 0.006023370733601041, 0.05897836083022412, 0.03950531121517997, 0.05149235803401098, 0.025299148219346534, 0.11020306701539084, 0.044580888861673884, 0.04862753441557288, 0.05693423008779064, 0.041605214355513453, 0.05288011481752619, 0.07033637069980614, 0.02240709334728308, 0.016198020566662308, 0.05776244091975968, 0.06870309662190266, 0.04259547684341669, 0.01856190006947145, 0.03863692421873566, 0.05994171304337215, 0.017457825524616055, 0.03822991930064745, 0.05475449041114189, 0.03374236010131426, 0.06911994612892158, 0.008471126839140197, 0.010346515464334516, 0.006978618694120087, 0.061841176939196885, 0.011188392018084414, 0.05371795501559973, 0.021568622323684394, 0.03166771224641707, 0.04012708624941297, 0.06111439914093353, 0.011447197466623038, 0.05380444861657452, 0.014802441546635237, 0.05297548450471368, 0.02001801236474421, 0.026494844605622347, 0.023515470493293833, 0.057200772425858304, 0.02222653438366251, 0.04677251403336413, 0.06124984851339832, 0.053449924671440385, 0.027515835718077142, 0.06074358876503538, 0.03405441464565229, 0.025303213333245367, 0.02457792725181207, 0.05700606998289004, 0.04753605411679018, 0.08005184819921851, 0.041507109854137525, 0.08898321699234657, 0.04157626688538585, 0.021356299439503346, 0.04139060380111914, 0.06945831351913512, 0.1085895043797791, 0.016904530311876442, 0.04158092757279519, 0.022858786687720567, 0.02440610151097644, 0.012959878113179002, 0.04594625504978467, 0.07567673921585083, 0.01779295715095941, 0.06783423465094529, 0.07245029672048986, 0.021573683770839125, 0.06812253675889224, 0.044109855152782984, 0.06305035814875737, 0.03685945826873649, 0.03392328828340396, 0.006136738893474103, 0.01915513952553738, 0.07568921471829526, 0.03543178507243283, 0.049549983159522526, 0.008735964092920767, 0.03734516794793308, 0.046947512455517426, 0.03577578165277373, 0.020237009011907503, 0.04696270792919677, 0.024638766662974376, 0.03494421260256786, 0.06376136530889198, 0.0463454637065297, 0.04050345902214758, 0.04998861470085103, 0.06613194826059043, 0.04941667488310486, 0.0661454553483054, 0.02496253600838827, 0.03979497145337518, 0.06704967323457822, 0.024243508087238297, 0.03608285267546307, 0.03096818611084018, 0.03174251702148467, 0.02642701416334603, 0.09639920186600648, 0.034839410218410194, 0.07949320395709947, 0.037791810973430984, 0.041900373907992616, 0.07662585703656077, 0.057081368286162615, 0.05010804110497702, 0.02680973044334678, 0.05539198413316626, 0.048929877957561985, 0.011354278722137678, 0.20929950813297182, 0.12727443769108504, 0.16437391022918746, 0.1068005796696525, 0.18176663084886968, 0.20014419627841562, 0.1250594831071794, 0.19433662353549153, 0.09342094097519293, 0.12326874013524503, 0.1417368178954348, 0.1413003311608918, 0.13246016489574686, 0.1329479637206532, 0.11398844319046475, 0.08691510374774225, 0.17439673334592953, 0.1552656653802842, 0.19575040001654997, 0.15102596866199747, 0.1241660857340321, 0.13596184027846903, 0.20343925774795935, 0.16771709255408496, 0.16026269411668181, 0.14860315335681662, 0.25264458381570876, 0.2669908624375239, 0.15909735899185762, 0.13721078576054424, 0.08773907320573926, 0.16617988207144663, 0.16996069403830916, 0.12497027695644647, 0.12556822533952072, 0.07987204808159731, 0.24424967647064477, 0.19967382308095694, 0.35162921296432614, 0.08509569903253578, 0.14329436322441325, 0.11601643593166955, 0.19184057309757918, 0.14828169951215386, 0.10715697382693179, 0.21780590090202168, 0.14623653347371146, 0.18591333646327257, 0.19322404026752338, 0.17406327155185863, 0.16465739579871297, 0.14051941368961707, 0.10172725073061883, 0.12593282765010372, 0.12117109683458693, 0.1118188189866487, 0.12234691850608215, 0.17236937885172665, 0.14451305876718834, 0.19406668958254158, 0.15355007228208706, 0.1453386089997366, 0.08457944626570679, 0.13247788738226518, 0.13752265105722472, 0.1312192642944865, 0.1166369381826371, 0.09402337193023413, 0.2344667600118555, 0.12909462908282876, 0.11936366296140477, 0.1360097384895198, 0.14067321637412533, 0.13924326107371598, 0.11579385842196643, 0.1866228147991933, 0.11391055479180068, 0.12888466066215187, 0.15171241073403507, 0.1321401953464374, 0.21940801962045953, 0.07988559969817288, 0.16929169243667275, 0.17113535053795204, 0.14861948060570285, 0.11197905609151348, 0.10748017914011143, 0.10484103520866483, 0.09912157023791224, 0.12727574387099594, 0.07990775280632079, 0.20553110487526283, 0.09169518045382574, 0.07510365277994424, 0.23802945477655157, 0.10428973080706783, 0.13212076592026278, 0.17924067185958847, 0.17689210100797936, 0.1527232603984885, 0.1202069282589946, 0.12833327462431043, 0.1114886077994015, 0.1231100170116406, 0.22194840596057475, 0.13087383907986805, 0.12957564467797056, 0.11558037222130224, 0.11639811506029218, 0.08454281385638751, 0.24391991057200357, 0.16748680413002148, 0.1572906450019218, 0.13177930377423763, 0.2257902521523647, 0.11583691040868871, 0.1769132967456244, 0.19848135503707454, 0.14206299179932103, 0.37292908877134323, 0.15410130989039317, 0.10312505619367585, 0.09667236416134983, 0.2529903355753049, 0.13358474127016962, 0.1868839914095588, 0.15087623294675723, 0.1742302399361506, 0.13608150416985154, 0.11959180657868274, 0.11043403079384007, 0.13356430252315477, 0.1789151955745183, 0.22598475421546027, 0.10802227348904125, 0.12313559142057784, 0.12134556091041304, 0.15243170026224107, 0.12611878017196432, 0.14018642687005922, 0.1490857423050329, 0.15544205904006958, 0.20822072227019817, 0.12163317282102071, 0.21920099010458216, 0.18398936314042658, 0.20532710332190618, 0.12465894600609317, 0.10606966068735346, 0.13803084410028532, 0.15218429791275412, 0.14134401397313923, 0.1477960529155098, 0.1619507683790289, 0.102649539912818, 0.10714647243730724, 0.1529055170249194, 0.160416912403889, 0.18634097679750994, 0.05581032906775363, 0.20544642582535744, 0.10494529211428016, 0.09518605016637594, 0.12077858977136202, 0.21812794846482575, 0.3119578573387116, 0.18122130073606968, 0.20048718724865466, 0.1172167484764941, 0.1394829896162264, 0.15906486776657403, 0.21348210400901735, 0.20006748789455742, 0.1883964883745648, 0.21851638855878264, 0.26595206349156797], [0.05722348214476369, 0.0314370898558991, 0.019888748793164268, 0.06280126370256767, 0.06166271268739365, 0.021819416288053617, 0.032693582979845814, 0.04071317511261441, 0.046461936362902634, 0.07515757723012939, 0.012441661438060692, 0.019743644079426304, 0.01795937820133986, 0.029935246420791373, 0.062032651039771736, 0.037722349661635235, 0.05872888788871933, 0.014844665111013455, 0.009106556462938897, 0.04483638804231305, 0.04238809480739292, 0.0329681553557748, 0.019600660052674357, 0.015064130238897633, 0.02414579692413099, 0.051389889704296365, 0.055178516486193985, 0.039511638024123386, 0.030714302956766915, 0.020224869331286754, 0.01062844437910826, 0.04238749737851322, 0.048913984865066595, 0.046708711597602814, 0.062047019018791616, 0.011616002666414715, 0.08447026149951853, 0.1016035866632592, 0.03794490861764643, 0.035251079534646124, 0.06899765503476374, 0.01130383308918681, 0.03399940294912085, 0.06505676181404851, 0.035236359035479836, 0.019887320158886723, 0.0241253674539621, 0.010724143394327257, 0.06653441494563594, 0.022093029438110534, 0.027524478027771693, 0.03535630865371786, 0.028460875437303912, 0.060836750562884845, 0.04031014068459626, 0.011749623572541168, 0.03186259280482773, 0.04149978485656902, 0.06242068295250647, 0.058381091512274, 0.07691816674196161, 0.039300816133618355, 0.07872558577219024, 0.005401550706665148, 0.026379282935522497, 0.060066338191973045, 0.09999360117944889, 0.08782747041550465, 0.02445353031362174, 0.03090850073931506, 0.06521510644233786, 0.04749921761685982, 0.019434244568401482, 0.007146494353946764, 0.014746854685654398, 0.045903136269771494, 0.08137958750012331, 0.05961353534075897, 0.03303998411865905, 0.05192123404412996, 0.05730411648983136, 0.06481857693870552, 0.04976063806680031, 0.04760491428896785, 0.023574460101372097, 0.0270072753119166, 0.0078090680290188175, 0.02645918255439028, 0.02394320359599078, 0.04530525839072652, 0.04532873623247724, 0.004787118296007975, 0.018715576588874683, 0.042740373755805194, 0.05609863859717734, 0.04830927551665809, 0.023961853767104913, 0.015305586130125448, 0.02241548332676757, 0.032153729916899465, 0.1116288366029039, 0.018230657296953723, 0.016542774137633387, 0.03216056509700138, 0.048524108715355396, 0.01007288190521649, 0.0472614817408612, 0.01870601401606109, 0.04747937258798629, 0.015759055058879312, 0.04972618386091199, 0.03276952324085869, 0.00902031426448957, 0.03995508981461171, 0.020758905811817385, 0.0257647011676454, 0.04973794690158684, 0.03192108888470102, 0.04475713038118556, 0.037361688155215234, 0.03700943889271002, 0.07935157991596498, 0.02972515554574784, 0.03725220281921793, 0.08552525410777889, 0.04274188031558879, 0.07019428652711213, 0.018971548888657708, 0.03387686323549133, 0.03247038206609432, 0.017235448394785635, 0.02032775697443867, 0.0091544936367427, 0.07874825096223503, 0.08624829148175195, 0.04479030809307005, 0.05430920922663063, 0.028226991307747085, 0.005760203312092926, 0.02695601146115223, 0.05813248688355088, 0.06610194323002361, 0.08476844901451841, 0.03864132515445817, 0.026845251486520283, 0.02483753050910309, 0.018089493387378752, 0.03510996015393175, 0.052974805439589545, 0.0350090948631987, 0.05986894546367694, 0.039747752307448536, 0.045717803441220894, 0.047211694763973355, 0.05888713974854909, 0.05342862874385901, 0.02703667549212696, 0.036276015162002295, 0.06315882303169928, 0.012421412866387982, 0.07025235216133296, 0.004795345003003604, 0.04049918796226848, 0.03572627298126463, 0.0283265151665546, 0.03148045725538395, 0.036676207164418884, 0.03491752868285403, 0.034117745817638934, 0.06367727997712791, 0.0535535210656235, 0.02840690460288897, 0.07001229707384482, 0.05654566382872872, 0.03101437552686548, 0.06590427961782552, 0.04789037768205162, 0.01353625597403152, 0.0049203672006115085, 0.06232972533325665, 0.03770878320210613, 0.011220503820368322, 0.03919173155736644, 0.03740207954251673, 0.08208835337427445, 0.10828216618392617, 0.023715815113973804, 0.05209124894463457, 0.020372378603497054, 0.0244550888237427, 0.06410023735952564, 0.011924552418349776, 0.04530259036982898, 0.06453862399212085, 0.06159297678095754, 0.01634970998566132, 0.04230855141940992, 0.08365195462829433, 0.02940397444035625, 0.008275923446490197, 0.03511021990561858, 0.06343554763589054, 0.08230400664615445, 0.09301380618126132, 0.014677279268653365, 0.04263314083800651, 0.024891004104574677, 0.058263394312234595, 0.05078692440292798, 0.025401957936992403, 0.012271672512724763, 0.016377657411794644, 0.04450954991625622, 0.07481868291506544, 0.009192242978315335, 0.03455753510934301, 0.06401334670954384, 0.03611039006500505, 0.04525789452600293, 0.056211886621895246, 0.022423862174036913, 0.010996153505402617, 0.05006294450140558, 0.07222944099339657, 0.01822940306738019, 0.018654503401194233, 0.045212686600279994, 0.07405832293443382, 0.04764607750985306, 0.02109257911797613, 0.0029837803822374553, 0.01857225117419148, 0.04070057344506495, 0.050245253078173846, 0.0452954138017958, 0.015130346509977244, 0.01356745307930396, 0.01641750888666138, 0.06849941419204697, 0.008966264576883987, 0.0492162170849042, 0.04645647044526413, 0.07940202369354665, 0.04071073344675824, 0.033280580973951146, 0.025944325025193393, 0.03909218357875943, 0.07969730941113085, 0.03838402255496476, 0.02383936971455114, 0.04522577808529604, 0.019795707594312262, 0.05176011378352996, 0.038509300793521106, 0.05158627682249062, 0.028606147134269122, 0.02860126565792598, 0.0584783388330834, 0.08814938439172693, 0.07421987364068627, 0.012489546661527129, 0.04936536650347989, 0.09150674915872514, 0.069134328950895, 0.046799004994682036, 0.05048824335972313, 0.03876520444464404, 0.0377882004249841, 0.04463625307835173, 0.07704236515564844, 0.01987816947803367, 0.07166246985434555, 0.043443636604934, 0.05431703888461925, 0.04657916600990575, 0.03632719366578385, 0.08471407927572727, 0.028791010554414243, 0.07513435542932712, 0.02802131806674879, 0.04377429679152556, 0.048862824914976954, 0.046582628128817305, 0.04101832768355962, 0.04540751891909167, 0.06715682451613247, 0.05489227383804973, 0.035047237543039955, 0.04090290887688752, 0.04814408457605168, 0.028866570464742836, 0.07426538955769502, 0.034486370568629354, 0.043654039182001725, 0.0431120561552234, 0.01637975212361198, 0.05657190988131333, 0.09374267683597282, 0.11109217477496713, 0.043486287831910886, 0.010018287666753167, 0.03638163019786589, 0.10775579794426449, 0.0193306630171719, 0.04009722964838147, 0.019035364312003367, 0.019993358218926005, 0.027336176608514506, 0.011060039432777558, 0.02153609399101697, 0.05907455430133268, 0.042409182933624834, 0.08204189492971636, 0.018230369714729022, 0.03374558473296929, 0.04282467802113388, 0.05698770553863142, 0.05129264980496373, 0.08701588740223087, 0.03257379292335827, 0.05548648921831045, 0.06170153443235904, 0.05610994150629267, 0.06358644852298312, 0.019758182752411813, 0.040561736168456264, 0.07463928355718963, 0.04070395021699369, 0.021290459808369633, 0.048909082979662344, 0.027901088287762832, 0.06831378079368733, 0.01438986866560299, 0.02730870601226343, 0.008668789523653686, 0.03706249874085188, 0.0673580207512714, 0.06881982160848565, 0.07129149991669692, 0.02890204883442493, 0.08840507653076202, 0.04124907252844423, 0.03816122611169703, 0.012067800835211528, 0.04724047154013533, 0.08887130112270825, 0.04477769158256706, 0.0006632793531480274, 0.04670518268540036, 0.021794457861687988, 0.03316116570204031, 0.0389644228562247, 0.08772185537964106, 0.21631063660606742, 0.12209294814965688, 0.14644777838839218, 0.14134561701212078, 0.0819051987491548, 0.18405764072667807, 0.11412179228500463, 0.20359132380690426, 0.2129261611844413, 0.09058699070010334, 0.10393220858532004, 0.1939531706739217, 0.09705435499199666, 0.1928000512998551, 0.09718396366224624, 0.1883849108708091, 0.16212218964938074, 0.13568162015872076, 0.14380056731170043, 0.14989002258516848, 0.1619400962954387, 0.1462365928455256, 0.09541118066408671, 0.08999921716167592, 0.2007100245100446, 0.17971131223021075, 0.12552253872854635, 0.11229670271859504, 0.13222977257100865, 0.10137795892660506, 0.25887954456266016, 0.2040235951426439, 0.14032670762389898, 0.10832173749804497, 0.1398021576460451, 0.2159211426624097, 0.26109164929948747, 0.10926025002845563, 0.09556732111377642, 0.11410064849769697, 0.09454964369069785, 0.12029201549012214, 0.1662565310834907, 0.12529783125501126, 0.09026368148624897, 0.10681572690373287, 0.16229840519372374, 0.09407808305695653, 0.1079390045197215, 0.1084233597794082, 0.1679521455662325, 0.15451299404958263, 0.16870054212631658, 0.14457756624324247, 0.103506178711541, 0.29278877656906843, 0.11630677152425051, 0.07195967031293549, 0.1538711995817721, 0.18132782861357555, 0.11709634985891171, 0.15091256849700585, 0.08503152552293614, 0.2581968280719593, 0.17422578705009073, 0.2213663246948272, 0.18875601439503953, 0.08870710837072693, 0.22644908633083105, 0.13343963655643165, 0.15022176259662956, 0.16721580148441717, 0.1329305677791126, 0.10912773956079036, 0.09810986710363068, 0.18859680887544528, 0.16676168132107705, 0.12860102666309103, 0.13034192699706182, 0.1591131222085096, 0.21881489519728348, 0.22591289947740734, 0.1416870197863318, 0.10795614813105203, 0.0712277197453659, 0.14341592701384798, 0.09996519918786362, 0.09453322738409042, 0.1247063692426309, 0.1438787451479584, 0.15222416608594358, 0.14403759443666786, 0.13984135788632557, 0.19047006382606924, 0.13416195404715836, 0.10245025841868483, 0.20467383525101468, 0.16074414015747607, 0.13874029275029898, 0.26109568658284843, 0.06617681108764373, 0.16555552807403728, 0.10484128011739813, 0.15493953600525856, 0.17915617092512548, 0.16946309886407107, 0.21688311448087916, 0.13325503474334255, 0.12328814729698934, 0.0987996933690738, 0.0781147537054494, 0.11933897170820273, 0.1278794216341339, 0.14667557319626212, 0.08502961820340715, 0.12861028866609558, 0.16255299153272063, 0.11430920683778822, 0.0944918897585012, 0.12036992615321651, 0.15832220058655366, 0.20501124527072534, 0.17407048522727564, 0.1617696843459271, 0.13875253818696365, 0.16118648985866457, 0.11480833825771697, 0.08837657805997878, 0.06314768339507282, 0.10240057163173333, 0.15950218570651487, 0.11375301910447888, 0.13656482042279094, 0.20738558348966762, 0.13601858488982543, 0.24546314729377627, 0.07823104082490318, 0.10339492335333489, 0.1488266882370226, 0.19108628388494253, 0.2685730322264135, 0.22141407447634265, 0.2046037171385251, 0.24261384940473363, 0.0887413733289577, 0.06937772370292805, 0.1722490618703887, 0.13111230597132817, 0.09899762415443547, 0.1456675585359335, 0.17680525488685817, 0.14887109835399315, 0.14354733168147504, 0.16001739946659654, 0.1408085841103457, 0.10902863316005096, 0.07115401705959812, 0.1659102746634744, 0.08524144941475242, 0.17988055158639327, 0.1795559807214886, 0.1722252240870148, 0.2805718086892739, 0.15713651577243581, 0.15343411912908778, 0.1278272338095121, 0.07861503545427695, 0.19109377957647666, 0.17100737459259108, 0.12764531857101247, 0.1603361518937163, 0.18546300125308335, 0.1323188451351598, 0.08260741145932116, 0.14387890842044726], [0.024571589310653508, 0.03010872344020754, 0.07208712675492279, 0.066793699079426, 0.06930370931513608, 0.06928365648491308, 0.0510763397323899, 0.024085022450890392, 0.05368446931242943, 0.059338625287637115, 0.043720116300391965, 0.057209255173802376, 0.019037403362744953, 0.03191700336174108, 0.0635251916537527, 0.013538323782995576, 0.05567419320868794, 0.04099442681763321, 0.011639554722933099, 0.07703587136347778, 0.041823609863058664, 0.037236706775729544, 0.02866229431674583, 0.07712621300015599, 0.015384981088573113, 0.047967798527679406, 0.05412876344053075, 0.011064175050705671, 0.03356605549925007, 0.027079747887910344, 0.04608294751960784, 0.04313571953389328, 0.03223135856387671, 0.016688385367160663, 0.023441433841071557, 0.01812075079214992, 0.03774767174036242, 0.042951826471835375, 0.004109678475288092, 0.07635664296685718, 0.0824867605115287, 0.02004250138270436, 0.02558230538852513, 0.10775991686386988, 0.017784737865440547, 0.07125701231416315, 0.029508951229217928, 0.022657844638160896, 0.03354421780386474, 0.041124280396616086, 0.09016953263198957, 0.026325759245082736, 0.061032803714624606, 0.04940604732837528, 0.006473578387158341, 0.06126855063484982, 0.04533684790658299, 0.06398308192729019, 0.06823564748628996, 0.027929826101171784, 0.02030854462645948, 0.046648130082758144, 0.03961560549214482, 0.02449764171615243, 0.027673495715134777, 0.07153228230890818, 0.05082980198494624, 0.007007748918113066, 0.020102329617657233, 0.011182469679624774, 0.010981343020830536, 0.010312004669685848, 0.07923993121949024, 0.01411422666933504, 0.04723080877738539, 0.019080431229667738, 0.04646115339710377, 0.06680657534161583, 0.06594641134142876, 0.009292993236158509, 0.03604539277148433, 0.0279525302539696, 0.05860279328771867, 0.06563634204212576, 0.05156707746209577, 0.08525699740857817, 0.05233056188444607, 0.009482600835326593, 0.07382904383121058, 0.07763491812511347, 0.024629105755593628, 0.036953095041099004, 0.015727779100416228, 0.04651660296076443, 0.05936331654083915, 0.04453024470421951, 0.028054937356500886, 0.02337694306334015, 0.04106156891793944, 0.07273811643244699, 0.05075749824754894, 0.04471803033084143, 0.041335235873702914, 0.07602519239299, 0.011571453396754805, 0.036562955428962596, 0.032564950233791023, 0.03899634633853566, 0.018392269230389502, 0.043604912716546096, 0.021255046376609243, 0.10198840507655405, 0.0676864804700017, 0.03999853885034099, 0.0065181309037143365, 0.06100487669755239, 0.05441477602289524, 0.041142745030811056, 0.06699894744087942, 0.12545619072625414, 0.005017856647100416, 0.02869960393582005, 0.06289924203883857, 0.04049644572660327, 0.05692455990356393, 0.04302193716284819, 0.006519749249491724, 0.05581818470091093, 0.052938024600734934, 0.037910792088950984, 0.0907101426855661, 0.0212495897358167, 0.01323454232988297, 0.008242755011451663, 0.03568002604879439, 0.02674840492545627, 0.02157910701498622, 0.007592864176331204, 0.02471422452799743, 0.059543272509472445, 0.06640433872235008, 0.04429782260558568, 0.02547628217143938, 0.08961059153079987, 0.06375021825078875, 0.02324420438526431, 0.05999784538289532, 0.010421211700304411, 0.030066127874306403, 0.08393892829190008, 0.04433662579685915, 0.017345651758660097, 0.015127153419598471, 0.055405643361154944, 0.021286745359248016, 0.06705874227918684, 0.056635912696947344, 0.02544334751291899, 0.0026875748653765186, 0.0286581178806955, 0.022430942262872122, 0.04439535936398897, 0.05986099706206005, 0.11346646846504882, 0.053210793557809666, 0.021538732326007448, 0.013506863215297926, 0.03973367376602255, 0.03952415063395165, 0.020078655106772203, 0.05304905731463805, 0.010040880497399485, 0.07631256681634113, 0.018453910161042586, 0.026852027294808067, 0.08416275260969996, 0.08155417031957768, 0.044411037233658135, 0.016748425114201382, 0.024889740598155186, 0.03254877883591689, 0.045303610822884366, 0.05780219034932088, 0.02010159303608816, 0.02261516186990775, 0.009926717775670113, 0.04008866526419297, 0.017734490756993182, 0.04687768749136012, 0.04050838317198213, 0.030858149730192963, 0.006223060872798669, 0.08030806726310402, 0.053396482617245056, 0.020230171976436395, 0.055550710967509076, 0.023702894322923385, 0.05795562938146759, 0.03449785159318708, 0.0202985367650399, 0.06613717298023403, 0.0367766160343308, 0.06583611335372552, 0.06002487811201718, 0.02751699346845271, 0.03858861040498596, 0.02174491764890263, 0.009764051992533496, 0.014622708222304936, 0.03155375918140635, 0.04232437400787603, 0.02495384731446393, 0.02387735468801111, 0.03614741952333134, 0.018579683783173095, 0.05494251352502033, 0.03627266807598062, 0.03520155973092187, 0.027971527379122563, 0.04249471545335837, 0.02650531259860145, 0.04713567286671605, 0.010493658301129472, 0.04510423284955323, 0.061838445835746825, 0.03696503990795463, 0.09243119799066335, 0.006886181417939952, 0.016177579964278266, 0.004202138015898527, 0.009309827000834048, 0.06889819982461631, 0.0021656762100974447, 0.028663312914432026, 0.08770244079641998, 0.05175163474632427, 0.06572499900357798, 0.01351262784737628, 0.03059110644244356, 0.037347724646679126, 0.031446307330043055, 0.006854091416244046, 0.07072664389852434, 0.01867200138804037, 0.06528886849991977, 0.038086109634605236, 0.047005555825307965, 0.0014363905324898951, 0.08089474984444678, 0.04151499146246351, 0.019294242119940463, 0.06009346368955448, 0.03604435747547541, 0.013798799063806655, 0.019752881962631363, 0.07112531078746542, 0.07935979549074546, 0.045192014076747, 0.019053437463298906, 0.033760772785171866, 0.06501195835880935, 0.0665397806733381, 0.08088346919976175, 0.04248263699992094, 0.04444345053343568, 0.022609738625760656, 0.02020178668317385, 0.05103777402837295, 0.008453687296423595, 0.036050391136086546, 0.08260511080152355, 0.09169962591840886, 0.01003894070890965, 0.07573815935757011, 0.0674829093622975, 0.03899776012985967, 0.06608383482671343, 0.1298110539210029, 0.04402493861562107, 0.032667325795046054, 0.05272145848721266, 0.030705040953762364, 0.012756653959513642, 0.06937655853107572, 0.057917022859328426, 0.032263129905913956, 0.026233951866743155, 0.0793717366468627, 0.11796947175753303, 0.04917974794807378, 0.02893377750297077, 0.04279776774637867, 0.018205437263532076, 0.08262275165179744, 0.03222958112019114, 0.05019590396841522, 0.036493687075562775, 0.04479615621676203, 0.05515935423318297, 0.044067441413062625, 0.060371375730028376, 0.06509357976028696, 0.07241780549520627, 0.0316411248059012, 0.03032517823157832, 0.02336942510737572, 0.029439990867103916, 0.020267275649530347, 0.03468549621175043, 0.043850481961271726, 0.05150995435542427, 0.004100734204257606, 0.023123026512621436, 0.06820268870797008, 0.05726753603084944, 0.034993027365999296, 0.050455039672669955, 0.09132084858720191, 0.03427873620239552, 0.06247737561352551, 0.011488875552458921, 0.042156752533628605, 0.08033075471757911, 0.07179017862654291, 0.05759495674283244, 0.02679071661987109, 0.0756731175351888, 0.038529153243871406, 0.013659894066222478, 0.06776759721105918, 0.07499559607822448, 0.017814948841987643, 0.05423457514552865, 0.008520347928424599, 0.050046721153194085, 0.032815640297485515, 0.058456668120925315, 0.08327669507707469, 0.03502371517242864, 0.032935241106315516, 0.05164270602108445, 0.0610516616870882, 0.016301893410854973, 0.03783333413593937, 0.08109361573588103, 0.02722904388065217, 0.013351517791306833, 0.023757757589919493, 0.03950358572183177, 0.029783043064526282, 0.03591937609598972, 0.02869223440939095, 0.13233808160293847, 0.15928095148410648, 0.16100070060929283, 0.1099457050440833, 0.1477498616441153, 0.11708260528394021, 0.11195909231901169, 0.13326457876246423, 0.28190271696075797, 0.15190741745755076, 0.18567860999610275, 0.11410573963075876, 0.12032996150082909, 0.11794152247603051, 0.09466763032833114, 0.06937958649359643, 0.23475011199479923, 0.1407793434918858, 0.1392577329534106, 0.15952900692354888, 0.2167814550921321, 0.11542279200511985, 0.20898416958516464, 0.1033847856160719, 0.0973578637058381, 0.1427024559234269, 0.2749580255476758, 0.13250450079794973, 0.15255077043548226, 0.13419916533166543, 0.16809119435492903, 0.12322150243562646, 0.14171308401273564, 0.1473783573601395, 0.13937340409029275, 0.14068571414100006, 0.1264519599499181, 0.12187123153125867, 0.08585903502535075, 0.1506368606351316, 0.15149972605286166, 0.07584073158795945, 0.12771417503245175, 0.1947365075466223, 0.10514926398172975, 0.14772779017221183, 0.1787524574319832, 0.10501644181204028, 0.1515740595641546, 0.18327877158299088, 0.24160890723578632, 0.07859897537855431, 0.13855058496119455, 0.1320644369116053, 0.09969790728064254, 0.1286234098370187, 0.10551270854193717, 0.15712033695308492, 0.1570538998930715, 0.17150565254269168, 0.16429601440904662, 0.14109174313489348, 0.11393552806111984, 0.1703916591941379, 0.0921514380024746, 0.19032733398489654, 0.1486600612406619, 0.0999259841046296, 0.11574673946597613, 0.1891021669143811, 0.14753435680177063, 0.13289945694850758, 0.1519666556851007, 0.07259310077643022, 0.14155660959659144, 0.23877834115410224, 0.08196553535526618, 0.16743040090659633, 0.13362075027544051, 0.18052733328659087, 0.13902389706345275, 0.15395298425573856, 0.08899874272174202, 0.1693563483422622, 0.15580394509015605, 0.10983582265907899, 0.20491066941758618, 0.11176790765603073, 0.09808065617107786, 0.10954978410154581, 0.09508170420303941, 0.16437646321719512, 0.1345779129769653, 0.1401991324382834, 0.18254811235237867, 0.1302704878617078, 0.09497133200056851, 0.13206602510763332, 0.08735717143281363, 0.16915720043471083, 0.14109465235378593, 0.24955419183243066, 0.120393808465451, 0.17646791908191517, 0.17108020896557719, 0.1182780419185292, 0.1343202096177265, 0.22331839572871104, 0.20045757555635646, 0.13660724158398807, 0.09953554763342254, 0.19464378361590207, 0.2764400647720322, 0.17722351447446272, 0.07374521082965657, 0.14128614129731432, 0.10163687940803356, 0.231391730485484, 0.15716085821622983, 0.2196733671007678, 0.10612213052809238, 0.13570557668572292, 0.12430481539922766, 0.13945174519903958, 0.08513633903930895, 0.24430024641333148, 0.09280888436478563, 0.15721985895652324, 0.11835138837341219, 0.14490385889075696, 0.16247427935013548, 0.08697414901689626, 0.10342262772610411, 0.07989818652276881, 0.11511323478771374, 0.11304105457384139, 0.10406474873889238, 0.14424030465306714, 0.15047910972498357, 0.17876121477456763, 0.13170473277568817, 0.28328495216555893, 0.10946190639515407, 0.1403702568495646, 0.13675310328835621, 0.14582189556676894, 0.12152527197031304, 0.13967490900540724, 0.183462482818868, 0.13382816570810974, 0.17517312371637672, 0.15811263292562217, 0.14624987728893757, 0.14969672280130908, 0.23455313115846366, 0.17786493786843494, 0.14695956342620775, 0.13572763331467286, 0.10044987357105128, 0.1700753706973046, 0.10235133755486459, 0.1330438195145689, 0.12111401825677603, 0.2515747334109619, 0.11476487808977254, 0.15254340833052993, 0.07247851317515597, 0.11738244036678225, 0.22749665746232495, 0.06440140830818564, 0.1781473695882596, 0.10236284826532938, 0.19616767996922135, 0.1106102389167063, 0.07205545931356028, 0.11279828322585672], [0.03207073925295845, 0.03981310212111566, 0.04782924697792623, 0.013876131779397838, 0.03548063323250972, 0.05838878387294244, 0.04654001029848587, 0.10190158864133991, 0.04376116077764891, 0.01977576052013319, 0.010348936721129576, 0.05235653334239032, 0.006951721406949218, 0.04756468617415521, 0.012780599354300648, 0.006409680863725953, 0.03916911831765901, 0.050044208983308636, 0.05897361108509358, 0.033771318703657016, 0.015712227395852096, 0.026434801147843245, 0.04401988087920472, 0.012630764376808656, 0.0792365321831312, 0.0546925841626944, 0.020698682383226696, 0.08240058232331648, 0.009011763795570005, 0.07267726032296196, 0.025792804444790818, 0.06930853327503428, 0.046904913178877905, 0.007992139162524836, 0.044149081368232146, 0.08285956355393864, 0.015419134724652395, 0.045435111969709396, 0.025523983713355847, 0.04203645781672094, 0.04716070550784934, 0.06445884311688133, 0.02736161186476238, 0.023590820746903773, 0.029677402053494006, 0.0199148352839984, 0.05237296820268966, 0.040988140826812014, 0.029765268627670594, 0.01678584420005791, 0.07463791058398783, 0.1020531500398647, 0.03237682692997623, 0.016156864767253865, 0.041691032602102496, 0.035269269574200734, 0.01184685512271244, 0.07749698255793191, 0.04774318011186551, 0.02046143632469466, 0.054969279080978595, 0.02503925181372324, 0.02956485350296134, 0.05829313588037621, 0.05162148430827074, 0.03458158069406636, 0.06635916419327259, 0.05536894786928315, 0.08947607726440765, 0.01353130492134369, 0.09134165840805508, 0.03241970822273288, 0.021827873060829006, 0.04130621047806926, 0.026210952710243873, 0.04307198018068448, 0.05876020652067382, 0.05148327414644882, 0.05382151801313739, 0.04277592262951657, 0.028166769734525587, 0.015446603465534281, 0.0250113303627586, 0.03561742960300762, 0.057149271087837406, 0.048026313161244616, 0.04197658876364585, 0.0522048903076211, 0.07596904892125167, 0.03341239753353875, 0.044626942835748196, 0.014754674139112467, 0.019735704954655375, 0.043913000481552444, 0.05935675224463921, 0.0036014988836541306, 0.06844308518338948, 0.05346288256987464, 0.06437294694478624, 0.06270689220400527, 0.004686521106123109, 0.02928949259512592, 0.04727846579044126, 0.07122001625248231, 0.08755073838983662, 0.04200770701572765, 0.008625820100860437, 0.02627878315252019, 0.05482922097144183, 0.0612475070374785, 0.03825261417659931, 0.07339603776927106, 0.027754970542446245, 0.028278518620936666, 0.04020231404865626, 0.024984104675240815, 0.07749545373371802, 0.02771358282188885, 0.08021050452953205, 0.060474267083918676, 0.02295114511071006, 0.01388831042277161, 0.053429107429110445, 0.049372212815796956, 0.009359841260447865, 0.031899989626253955, 0.052691720629809424, 0.005197841837798478, 0.10348848591092974, 0.050991898169741035, 0.02388447002886096, 0.007932304433779791, 0.035407565083005466, 0.09354237859952264, 0.07449228636687621, 0.055167914906633087, 0.10300622350769117, 0.10753826703876257, 0.02325844619917916, 0.027287911034363788, 0.06377421188517474, 0.06085696295485832, 0.05014515219954774, 0.015614692492817994, 0.10114541437360458, 0.01639029989746632, 0.0299686820289935, 0.014514050380967092, 0.02734316763962852, 0.0948215220705606, 0.03001635574037209, 0.010948884264507797, 0.04333117525675334, 0.06234665372176096, 0.03156656493956689, 0.016785022271506023, 0.0285527922824258, 0.06548446894157678, 0.006547544071509037, 0.05805730361316819, 0.01189311782582081, 0.05478934166603722, 0.033054574741981924, 0.04599036830768455, 0.00724616200386663, 0.06497219408629462, 0.03571725588699337, 0.08800237977993675, 0.043979515467071906, 0.1330836580018513, 0.05388940597185865, 0.030783331967541017, 0.015873392185312696, 0.028542366962938104, 0.026031529232568573, 0.04751556713017635, 0.029303936644282658, 0.01966807118151337, 0.020503202540567145, 0.03674382794997655, 0.008716709999134764, 0.06680278296698816, 0.027247308134974446, 0.018850294945877977, 0.030658267096441705, 0.06265349467867054, 0.08796419628197327, 0.04266097879735753, 0.05293793925375212, 0.02267806816234952, 0.01751010240695905, 0.02906210040237056, 0.022490135961561464, 0.1510854295338504, 0.019017584309040103, 0.013542806354962522, 0.07581012541777454, 0.04992975867935456, 0.09531815245281905, 0.024855217743606772, 0.05454759448184632, 0.059438522075652145, 0.009965777935576625, 0.037808004635735415, 0.044578217130037956, 0.0471436064253794, 0.09259530168492347, 0.04411954389070161, 0.06463418292696588, 0.10303112998371944, 0.031477993325097486, 0.11084242723882198, 0.06827682926086709, 0.03215650925994851, 0.07196331425802782, 0.05771988246124238, 0.03306596299808007, 0.03918146023352165, 0.008138280099956319, 0.029804218393110204, 0.02908969716372667, 0.1027312726364471, 0.06802973861340433, 0.03090276208240539, 0.03554053939296864, 0.02579054460511543, 0.02760101757303346, 0.07414697247440927, 0.012803784975403687, 0.03152495643007569, 0.031947739407769404, 0.015744655538583174, 0.024040087264438625, 0.039694503211649135, 0.05995487132167909, 0.01569258460222045, 0.042330574651714414, 0.07754056146950461, 0.03885348291078117, 0.012979892908333568, 0.07922735181637108, 0.03572566442016978, 0.026795108278747648, 0.05027993363910355, 0.04314016870921478, 0.045821704115951434, 0.01923364576214226, 0.020225227417540736, 0.034322864303248934, 0.018183931679232046, 0.02991360168380197, 0.02321060179383494, 0.08839283851557411, 0.02700885608646786, 0.061086739297024906, 0.0945054116891697, 0.02288383046106901, 0.04510697508521844, 0.09370801853947341, 0.03395363470190205, 0.034321569255553186, 0.05824674793984741, 0.03512834315188229, 0.04450300046300981, 0.028153557650512084, 0.03182655411364976, 0.021465773643285502, 0.028382179953041486, 0.09029517823364586, 0.019745215577131603, 0.12578623864101246, 0.04014453043055255, 0.04133195929171052, 0.06525386881548911, 0.07445056282449514, 0.03333803062560037, 0.04033832374261692, 0.01461719870349043, 0.01618436504941201, 0.014572590062016388, 0.03458364757534582, 0.06076949342968874, 0.037096693195053376, 0.025171190827677492, 0.017797929540392943, 0.07981048693181947, 0.02348807596717961, 0.05596512994088698, 0.029566786797659006, 0.051649047672981396, 0.030124694458208978, 0.058768477756530046, 0.008043452180572785, 0.015547679340670584, 0.03897019305441063, 0.035769187670666724, 0.02194361099100206, 0.021352210205805022, 0.01682893514953321, 0.03479887040157337, 0.06993343646172434, 0.03327593884023372, 0.026215845318802167, 0.04371141461888328, 0.03379819558176678, 0.06282162081333809, 0.022423236914619338, 0.06665868015261367, 0.06795344583224505, 0.025940046543837525, 0.02655966378370067, 0.032934127884800546, 0.05721634268411435, 0.06254127452848479, 0.01836475781601621, 0.059623914276016876, 0.16005554585717618, 0.020432384953892324, 0.08787300117546692, 0.019171628191543277, 0.0598448516393546, 0.0720781616109889, 0.03196274192305282, 0.00399087918594887, 0.008853854251356097, 0.05025667473091744, 0.044822120253229514, 0.06574222425115295, 0.05315337359206751, 0.017807202675612643, 0.01632130613870686, 0.023206913319882005, 0.05810460810607765, 0.02750508014287334, 0.028481136068876367, 0.061322931505856104, 0.07503109300159849, 0.07282905920874327, 0.046514116766047664, 0.02464419732859824, 0.049926270585274324, 0.09086090998607688, 0.020581419339578133, 0.09138471039477736, 0.07353411434451118, 0.029482495519914664, 0.0438794368528761, 0.030157523360685445, 0.04541332622466143, 0.009364887864649063, 0.030525778893206734, 0.043250459275441244, 0.09313092450611293, 0.1226549840066582, 0.19250758574344218, 0.09691460116300732, 0.10077484519570135, 0.15267530281562358, 0.11553980642929673, 0.12461205711588264, 0.15519352862611413, 0.1534426983562298, 0.20972803904442117, 0.19138441944960505, 0.28314412222243845, 0.191351943067275, 0.09135824540862814, 0.13587017019744962, 0.18359936453634873, 0.298241424607113, 0.20362598210340366, 0.14310078142443672, 0.159574352146592, 0.20236490992829204, 0.19002951012225822, 0.15395843161968514, 0.15575373137835413, 0.12072335171978921, 0.11137328547192737, 0.20057489426108077, 0.09993405124987476, 0.1487502915551886, 0.16366073599783704, 0.15748918434837833, 0.22234653850318864, 0.16558736620936543, 0.15050866204546764, 0.18001327727688476, 0.10594592982670292, 0.11565587832592428, 0.12154087933595292, 0.10748312546638772, 0.08895910461433232, 0.19633510848507285, 0.046258714064606465, 0.13424795411992818, 0.09497856051893905, 0.22425482282415032, 0.16471994400490075, 0.08059576823143288, 0.19688094325829297, 0.12323159564402886, 0.1508348062634468, 0.1543075972585939, 0.11964984994847327, 0.07442291040206328, 0.2024718385655433, 0.18587762431707233, 0.12544372264528647, 0.18722987675573677, 0.10691636212868616, 0.21976557152811438, 0.12006584598566405, 0.23517668363638222, 0.13126172998454422, 0.15432995074661449, 0.19357368088094518, 0.17755555134499446, 0.1479068852495402, 0.14671746001113206, 0.16623849689494818, 0.14425688423216343, 0.09479997752350755, 0.12159424717538059, 0.12868818448623642, 0.12587317381985486, 0.1347439907840453, 0.07644166340469383, 0.13474143779603764, 0.12660571810556576, 0.16852802247740328, 0.16542541474336758, 0.1497554563684389, 0.1777729412424378, 0.26943620934616774, 0.11107875674497336, 0.08984633474028669, 0.18943249684525654, 0.1213113330595661, 0.18373174883890897, 0.18682018155232072, 0.14242410601582378, 0.12087477211025544, 0.14171903603710234, 0.17132050154032186, 0.138771180936601, 0.2631738781929016, 0.13687747239600867, 0.08694353542523459, 0.1241646459675394, 0.2889575727749616, 0.12943859968800098, 0.14249719271901995, 0.1256290517630987, 0.08247894569649361, 0.18293879373231903, 0.1410318518173881, 0.1243616861756891, 0.15012743562692776, 0.1048757677199319, 0.11400574265280738, 0.16243688995018601, 0.10451115798787214, 0.15231488621793687, 0.11332094814861193, 0.07184604008216411, 0.18958352389745414, 0.1443895505508408, 0.26218973100185394, 0.07848605760955252, 0.19085949839791283, 0.12791535642463714, 0.13998533453559503, 0.09819591912673786, 0.08771990353125148, 0.1879405722138472, 0.0995876092929393, 0.16131609852891415, 0.13322469574632123, 0.12421730134519748, 0.19727073406102136, 0.17618038138607517, 0.08420958954957314, 0.09669763428973965, 0.1657449983758852, 0.19410145177971572, 0.09563059662468731, 0.15067292901221663, 0.2128422836540267, 0.17720119067234918, 0.15141660551307723, 0.12152940573287196, 0.18261183315189555, 0.08912539764423855, 0.14225535647710785, 0.17356521624606103, 0.19764819036936387, 0.16607721336185932, 0.1118543159100227, 0.12005871394649148, 0.06342855660477653, 0.17036633711541072, 0.14968284463975579, 0.15373547561466694, 0.13176146254409105, 0.07073006519931369, 0.0953374408709351, 0.17622822022531182, 0.18239033175632358, 0.09402067051269114, 0.1491705104126595, 0.1787614225759171, 0.18116345774615183, 0.1296679233200848, 0.12505422870162874, 0.19531508587533608, 0.13872007664758712, 0.16292851825710386, 0.14859488583169878, 0.18160338804591447, 0.13541328924475238, 0.1875929205561988, 0.19961964630056173, 0.1592967740725726, 0.13472436839947477, 0.10967973415972665, 0.15173231513472274, 0.12183653612737544], [0.02270701006636955, 0.012630591827473836, 0.021055128490843344, 0.06631159252719954, 0.03733470366569236, 0.04596824859618209, 0.03271103458246216, 0.04617614271410275, 0.016584245349804405, 0.02929111975390697, 0.0820604560431093, 0.04074535834661219, 0.0812853941170033, 0.027840141265187413, 0.029799216317769606, 0.017742092204571236, 0.03247265674872324, 0.011961092986894073, 0.06713366208714433, 0.01308726312345243, 0.0602849006827455, 0.014575753466488095, 0.02643009964231169, 0.009603158086974872, 0.010129787006007973, 0.005083688856757362, 0.013002363284613239, 0.05696927801182028, 0.03042038093553856, 0.05224977539910469, 0.013888234352634754, 0.038499096262967214, 0.03485007859126199, 0.09543933032546192, 0.039437516024918295, 0.03923359981854446, 0.039155637205112725, 0.10574292275123298, 0.04867404109972995, 0.07931338157504797, 0.0033436450075896573, 0.062187975127017125, 0.04221548239002004, 0.008233164608100196, 0.0053855472197028575, 0.01570889144204557, 0.10764370395918377, 0.005487449661814026, 0.05877231094927993, 0.06712651520501822, 0.044302179012447596, 0.03402276575798169, 0.010301727779733483, 0.05464282687171362, 0.09642472432460636, 0.021138065349077806, 0.06450352040701546, 0.014334454353956971, 0.05027522471209522, 0.05974617197352927, 0.031171627342700958, 0.02589728399470914, 0.03496976845781319, 0.01925950033182744, 0.023771286942064762, 0.017518741005915217, 0.04614110221154988, 0.032745121425250545, 0.028640861091844272, 0.10916920335148461, 0.038364556021406315, 0.01369453009829158, 0.03949013429519255, 0.03542702419508714, 0.0798800632765051, 0.005278990120132221, 0.04536449290753808, 0.03349448277731426, 0.056434055950376205, 0.0694939069217071, 0.020709011223516427, 0.04710727458586916, 0.03891992739227135, 0.01921676375786774, 0.03221339487936348, 0.08742911522858776, 0.06327439768938348, 0.03985858093074057, 0.02883522214688128, 0.027769531479862053, 0.06183289457112551, 0.038215874155866913, 0.042761146469274536, 0.028316499883658253, 0.011740133359126048, 0.017827389092417434, 0.031102013890631497, 0.01504077948993654, 0.024173273086489644, 0.021441399658215232, 0.03684153540234547, 0.019250820914749056, 0.0622458997531794, 0.009695287371869199, 0.044467774423537776, 0.028404110416886397, 0.07295059331227094, 0.04197338639642112, 0.0509752851939993, 0.033061658541555516, 0.007226516891023493, 0.06895774233271368, 0.055834712329669856, 0.06755800728569739, 0.05463263347337488, 0.045562271552626044, 0.006614578096559853, 0.025305187446065247, 0.01838362506532576, 0.04022582899779081, 0.018145499561796896, 0.059161634198972024, 0.048101236679940484, 0.1154280464106705, 0.024442678259219974, 0.05157879597391002, 0.01745008306897944, 0.027461581012175884, 0.021175775727897417, 0.03931823062885087, 0.0286426032835152, 0.024618146089778747, 0.08986044296761975, 0.04613161385350395, 0.058686756165116094, 0.04473173037695233, 0.06447514067986049, 0.02161760778108146, 0.04509086305915844, 0.017949952925846446, 0.0151531963092566, 0.028797830891562626, 0.023150094493757933, 0.03271265246439725, 0.09175383238471113, 0.019424835991230793, 0.022175125814101193, 0.02845437978976406, 0.03468340706604067, 0.0380334653891623, 0.046250427985796705, 0.0384060791839147, 0.024710669640626293, 0.06569040750036947, 0.10433299059513956, 0.038872218428878114, 0.013792378558719065, 0.06853224680526182, 0.014614376686949981, 0.02619471080834046, 0.02040351912000915, 0.06384142820024863, 0.02467206126311794, 0.008403946703765541, 0.02130962020601146, 0.02181818246754119, 0.08468952160910703, 0.005330625508577214, 0.06442700498155318, 0.04424260310770478, 0.07758609965094365, 0.033722073494573124, 0.06834548534243368, 0.014376034105225699, 0.05883857360458933, 0.019296759855933487, 0.031017171568237245, 0.011886147203767905, 0.016045444281189702, 0.08802317475783639, 0.02271812187245814, 0.022336949259624816, 0.05114827610668726, 0.08909399737603962, 0.03303196521301288, 0.031006499484647065, 0.023969189896888565, 0.04050485797051806, 0.032655874456395395, 0.049836288890219294, 0.02402844296739204, 0.026629156636772677, 0.02074112395348493, 0.027023910552088637, 0.0430314960249234, 0.044596989755518734, 0.048311735736206174, 0.019437033188296482, 0.043385815879446454, 0.0192306270764675, 0.0045367891016212525, 0.02937560399004724, 0.08196693059289828, 0.051012670883210376, 0.0232613813932403, 0.005997836678943713, 0.009856740671239095, 0.029040242297924124, 0.02248182390758302, 0.032911518355831504, 0.04297105180739891, 0.025350033574795816, 0.01759206334099872, 0.02853996611520415, 0.08401836035773158, 0.06579925087862648, 0.04901951084320899, 0.03193638454831671, 0.023611626857018564, 0.04204194228805136, 0.025585511466488242, 0.01880336338217603, 0.0288279138476355, 0.03385232783330139, 0.031054098981257994, 0.021341680985642597, 0.010790378219098784, 0.010522311695240205, 0.0016316216397171956, 0.1030166655255016, 0.0693115167086944, 0.020995029371988494, 0.03193795419065282, 0.028529655828606337, 0.025485583137196954, 0.021300655062077567, 0.050692096483544447, 0.03758204293262679, 0.02089617159072077, 0.05578514428634662, 0.012545618701551575, 0.09182531604892574, 0.03601304626499768, 0.0614296523417579, 0.012709992352029076, 0.04417652227857616, 0.08359074228792451, 0.03640499671746511, 0.04887882932962384, 0.0942413110169582, 0.010449223136674846, 0.03589984276914038, 0.031431056195287965, 0.03999391527031548, 0.07706235119258054, 0.012703198917733971, 0.03881605269270949, 0.03967317759816069, 0.023277799555216916, 0.04647596295399126, 0.013759915163973346, 0.029509982814488467, 0.038513787076226436, 0.024035634378378745, 0.06101980870880652, 0.04332293741754256, 0.011183432616235223, 0.024872378053260036, 0.06165458617033437, 0.04566768249787856, 0.03747659859072883, 0.07190295538748614, 0.029640274260600563, 0.03497008015983738, 0.039650389953749254, 0.04493872278544586, 0.025440642384637613, 0.029855643660994247, 0.014442236461036373, 0.05279850825900212, 0.02971947440528311, 0.06091362221923191, 0.01780593731382396, 0.03358328074682504, 0.04155065165832639, 0.11227276845602319, 0.03295982845884282, 0.02009768006246304, 0.0413238847249886, 0.03390961421246175, 0.007670657023481908, 0.01461037094486528, 0.03531503039994277, 0.01110842375055654, 0.07732822559773922, 0.08226044257753529, 0.019139641626679804, 0.049111173502751626, 0.06744516373146325, 0.09744623122969642, 0.022415910061681643, 0.08301456109620631, 0.04490176754188724, 0.03952320810640231, 0.01876904090750031, 0.03423561742238235, 0.06120387988630682, 0.02607054393592989, 0.02124379541783128, 0.026146985146624502, 0.0682488948223181, 0.020487572910496965, 0.020831430338148493, 0.03596673624997493, 0.016862483935256023, 0.007382050634987536, 0.045700967821176164, 0.006786703943362227, 0.03981688336352818, 0.020970564473827835, 0.0361480689025484, 0.027111747440358158, 0.021458469054778107, 0.05813038289488759, 0.07757023253361695, 0.04440081786015071, 0.012888543806184316, 0.04108113935217261, 0.004826981830774457, 0.04978340715751983, 0.03716819912369829, 0.045920892152935266, 0.051401467208052054, 0.05035283480538055, 0.03529597204760648, 0.048762928126961924, 0.004846068477490917, 0.023910218842502218, 0.02763059215794783, 0.0498614291427657, 0.0465499402343994, 0.03792172392422799, 0.031001803545223083, 0.027247306279605255, 0.011917723732040031, 0.01703835623629857, 0.010745269555627601, 0.05436516716144979, 0.08415567994234152, 0.01224504610945587, 0.04506796038185712, 0.016714991361368448, 0.09623952879337594, 0.05241476967057679, 0.06881041859742254, 0.16101566230645403, 0.11144384887302294, 0.10381057058111764, 0.20860545162577182, 0.2315964296576567, 0.08272435166873038, 0.17154056316940114, 0.20375490799779072, 0.18603289645398036, 0.16868224076461047, 0.15565593115752563, 0.08285442789201625, 0.15699647250585258, 0.08502451222739182, 0.1994720776565373, 0.12432805204298347, 0.16906983481021598, 0.08977674355264753, 0.11178581567946821, 0.16699710540706292, 0.11004135303664953, 0.08158355936757289, 0.129343738371972, 0.12394983132253401, 0.18579610681626946, 0.10085121961310506, 0.1296820241259411, 0.07604392420034856, 0.19807551900157705, 0.10270368700730614, 0.1643591860192828, 0.1270541682606563, 0.16514200338860974, 0.11309753943351097, 0.11434724932769313, 0.12692602904280648, 0.18824511993443593, 0.09494546815403737, 0.08537415284081362, 0.12469746347051114, 0.11157485278090462, 0.14206336287315935, 0.12394366407534108, 0.24117086199112236, 0.12211552428198047, 0.07872224610764533, 0.18969621160067618, 0.09077194874407724, 0.08933471297495998, 0.09115161665249616, 0.21268398355459794, 0.1442191534442827, 0.10949104311293922, 0.16141836647875607, 0.10752866364782676, 0.1044074131641537, 0.1639400061685592, 0.19613539654528722, 0.15526354283792898, 0.13775111379800364, 0.12480997305829078, 0.09028606466017663, 0.1791243179468438, 0.1618280468392186, 0.14479687088169158, 0.09507423077593558, 0.16876478242920712, 0.1617890247143805, 0.07269644484040327, 0.18826937332050875, 0.13673970010131598, 0.10140096550458111, 0.13489083212334663, 0.1935731020057574, 0.09482084671617486, 0.158671410754323, 0.0951004285889212, 0.1104167387529742, 0.13237882551038638, 0.09431427155504934, 0.12071316203218885, 0.08766742626903579, 0.08952731514000334, 0.1677501032827422, 0.13308128312928602, 0.16044846852310002, 0.14895473839715123, 0.19729075720533729, 0.10545304729021154, 0.14882676245179027, 0.07183970214100555, 0.10597312953905202, 0.24394613807089627, 0.12121990788727999, 0.10554171909461729, 0.10265877222991548, 0.08767537467065267, 0.12486045394325629, 0.15390922722872347, 0.11255891091423109, 0.09644534860854037, 0.10447194290463813, 0.12116491474444047, 0.14212316513294354, 0.12311520462390035, 0.16770483227446675, 0.13203736336436123, 0.14490924688288942, 0.12891863618278876, 0.13252908072900027, 0.15900698024779558, 0.12955379585037008, 0.12520279182353988, 0.17793367558624595, 0.16873465123353526, 0.13224967697169632, 0.19902496336726472, 0.08846664510201663, 0.14212749927537516, 0.1377742094337009, 0.2194427521317266, 0.10468041218700819, 0.12410563038429245, 0.10495005670236424, 0.09348455787403509, 0.08367965157958679, 0.1500593955279328, 0.15459179528988898, 0.1327354571549222, 0.22922462958376855, 0.12554790533613414, 0.2097066948772408, 0.12762093159835786, 0.1510064204921946, 0.12204195518279448, 0.11396777437767014, 0.11998815796687268, 0.09817563623073511, 0.11040018885978498, 0.0783206699998118, 0.11860212296596728, 0.2105261743417941, 0.11816098296549171, 0.07980647933436558, 0.19172801898093894, 0.26114941807463765, 0.13485290837706998, 0.1472461808589287, 0.15232692385325208, 0.05440548062324524, 0.1686066307593137, 0.21562757872743532, 0.1277470076456666, 0.15440597635461017, 0.10054507627501152, 0.11708430480211973, 0.15555725520243868, 0.17027578025590628, 0.18094216415192932, 0.12074346392182633, 0.11161808288306929, 0.1369039373821579, 0.12219290802022442, 0.15216651605442166, 0.11512229641084559, 0.17232376645551994, 0.10515162401134148, 0.1319102186243981, 0.10256989262416027, 0.1689191788318567, 0.11917952127987519, 0.21123263955814764, 0.114844406634802], [0.04596029277308844, 0.0660376955056563, 0.015665091741539072, 0.036190415848977864, 0.09333738998975605, 0.11160433088662103, 0.0661379967641551, 0.055573075587744825, 0.04596165832481347, 0.04526258861005772, 0.04285562186851166, 0.004499032338571851, 0.03370917125721462, 0.02418286348984111, 0.07206737820524722, 0.037870374726480804, 0.023053414915921167, 0.013178759727452416, 0.047757366264704615, 0.01329275824900833, 0.041216143436031416, 0.02689036107767606, 0.05075193585071247, 0.05306059028953314, 0.02735403639235301, 0.02866470629669493, 0.12143442567321472, 0.04454809706658125, 0.019332813390064985, 0.021582344634225592, 0.01821674388338579, 0.021759703085990623, 0.04091096117917914, 0.03403868853638414, 0.031367584015242755, 0.07160217777709477, 0.04075025281053968, 0.033620365866227075, 0.029602270733448677, 0.03172216733219102, 0.012853016269218642, 0.02801249207550427, 0.0565978108352283, 0.04956007636792492, 0.0159782743503456, 0.05193198405322619, 0.04646232599043287, 0.03341663148603402, 0.08392085699597374, 0.068929607514292, 0.03071343835472362, 0.09330587097792886, 0.05610574837191962, 0.048224303318420425, 0.04459658528503496, 0.05050010287959594, 0.07328015883103944, 0.02102144240780035, 0.04127519241592381, 0.06253564904909581, 0.05746341106714681, 0.01260981354789692, 0.0401060983131174, 0.03472983582469169, 0.022677075539832003, 0.03631679617683403, 0.04159498384979088, 0.00707755208168237, 0.016196460201172158, 0.06119522644439712, 0.039865883663878776, 0.047265344619518146, 0.025514172521070577, 0.0017686657020021812, 0.019751624022319447, 0.04261009715264663, 0.08205574340536259, 0.009083735421882011, 0.07637107773916796, 0.02861266133550089, 0.05586801991739776, 0.05093473053420894, 0.0229771629528841, 0.07435372739564627, 0.025743878359207883, 0.01347582659946056, 0.03983001195592806, 0.021413736103568226, 0.016537163501197938, 0.020638340211007744, 0.06038982181053143, 0.0776501841028221, 0.0456791375472676, 0.03269151980930474, 0.06920484782312997, 0.0210294650241849, 0.05185313828405924, 0.03529945643094834, 0.03844081540592015, 0.022344624921970535, 0.06360995233990252, 0.03805047912464943, 0.0454708315373864, 0.03571184191969223, 0.017946546468010638, 0.0804391156998463, 0.04901753673038911, 0.018039895658148453, 0.03010456926858751, 0.018291320448042825, 0.011264769218541915, 0.028395911540428642, 0.060436361891333945, 0.07068536564474925, 0.02049447673925897, 0.033073762970161624, 0.03716427687322721, 0.0896801901399158, 0.028752430007443763, 0.04175216701696627, 0.026835579446924385, 0.0552063989744056, 0.03694483493745793, 0.03604738914873451, 0.006903940084157512, 0.030031337846594397, 0.025165042134176474, 0.032994753928505816, 0.011055131981265731, 0.03752408119908068, 0.024907284969231114, 0.04502024399698712, 0.061230459905345924, 0.1022739167092368, 0.008599684442742728, 0.017854406978585757, 0.01024704912197194, 0.06731554021826014, 0.050240373457199894, 0.0322657756623812, 0.013974032190162688, 0.07309615815756842, 0.06758855408406816, 0.011463849405117799, 0.028431605132936966, 0.02425472379400162, 0.10277871813741513, 0.05261716076347511, 0.012286797482374823, 0.024456725259369705, 0.037704230126109906, 0.06361506573739462, 0.03241513288230635, 0.0508691395225469, 0.029611916797875892, 0.052641102447523735, 0.04018872532469686, 0.047146708602667786, 0.05233314826909918, 0.05563534919929225, 0.050862244970630854, 0.044292861348367296, 0.032624889790895395, 0.019228819946874864, 0.009850259866652777, 0.01756183752149809, 0.009632078654249199, 0.0659607867419254, 0.12380009560729377, 0.09482116583967581, 0.05686871700163465, 0.04601987238856964, 0.0340407776820939, 0.024647397840453777, 0.06083040148951113, 0.02483322605257854, 0.004561982696031919, 0.06052241391444113, 0.03938381792977452, 0.0151379915587313, 0.028431835198716726, 0.07028850959613919, 0.027119452788610943, 0.014089361011428991, 0.02634590298839612, 0.021353304873628076, 0.07029612403130159, 0.01307444437770755, 0.036847231385763735, 0.010212143133685458, 0.02256335996207781, 0.04933693111524917, 0.05872675792488735, 0.03561525511031505, 0.033195682990481146, 0.08643473382107913, 0.024619840041850694, 0.0064847296198422555, 0.0194943065798725, 0.06950637500267476, 0.018159316496166866, 0.0840114286984317, 0.025893972160702106, 0.029650582691829186, 0.050476866235840134, 0.04184225261269603, 0.05141116336744744, 0.054522769642062485, 0.030439003276114818, 0.031529631960438564, 0.04112074777367525, 0.0862664295709692, 0.10741130783571862, 0.030702859039593022, 0.0003844236545091917, 0.015238187061186181, 0.01995902832277352, 0.03905500198015943, 0.06723800062900409, 0.022883112433191855, 0.020715232276415918, 0.025335068166896235, 0.047256828474928625, 0.003264784859311476, 0.04737698589451611, 0.0069436018475244055, 0.03861733894154895, 0.020478359147091396, 0.04307241062633693, 0.047449712656089105, 0.037230947709758766, 0.0507181124703493, 0.041143064154312015, 0.04582436100463383, 0.08027196177863516, 0.06282844857196324, 0.044607595045818016, 0.028075878908566665, 0.04654565804230515, 0.07588186883367598, 0.05923303993768059, 0.013647323939949274, 0.03649717145890463, 0.029981497063999996, 0.053834397986065596, 0.04029916432045866, 0.04775696179422084, 0.0628585352387745, 0.04799446389370132, 0.03271272296842653, 0.01799897177988896, 0.03743460416444577, 0.04292487537895795, 0.03565881917893421, 0.12291989361983724, 0.02916261688369559, 0.03149131858663168, 0.021977399119350594, 0.03304836296592839, 0.026737977750599384, 0.006554010033141822, 0.03633195454312954, 0.021295717924658675, 0.024706094300199766, 0.029428699090203736, 0.08048378556850366, 0.03800196122028865, 0.005518762263818644, 0.02327325946680503, 0.02850932283763541, 0.060361033902154304, 0.02687340856937226, 0.09274704119889066, 0.03430024364206474, 0.03174614241288509, 0.01628831396374153, 0.04104369800188579, 0.06443555452278815, 0.04510797698458191, 0.10250580075080507, 0.04236048320308328, 0.04891844146186486, 0.027965770168520976, 0.031081857159733772, 0.03182792708685156, 0.020350308986962773, 0.06581197871128097, 0.05753861289122142, 0.0768068445904646, 0.07267410619533621, 0.030334544135257602, 0.03847745894745458, 0.06359171777148731, 0.027771012064476963, 0.03692685269925278, 0.04969692097802181, 0.05930931045440957, 0.014240696982597001, 0.024439134504063986, 0.038071463350206614, 0.010029429158748826, 0.014646997788076987, 0.03737345490662847, 0.04291592507797759, 0.012104470351914642, 0.026326564475311898, 0.044741574965883046, 0.0304907513782382, 0.037594440509565175, 0.05868261127034202, 0.05098602036014199, 0.04706932857516222, 0.01386970849125646, 0.05141268477018457, 0.03411809462704696, 0.010888667329709278, 0.020220084334141575, 0.026105272736458573, 0.01294106188652222, 0.029421103208733257, 0.022103148621681612, 0.03237499011447653, 0.009280753365601413, 0.04487672747927718, 0.03635880544607062, 0.01929567075421801, 0.018849157604563516, 0.05099050664284732, 0.024967640129034407, 0.06448383865063079, 0.06001314475724939, 0.06199417439347599, 0.07816798795829527, 0.05088223842903972, 0.066910646710312, 0.05175144920940511, 0.05030022395658307, 0.013409960993158165, 0.07080168245011009, 0.0329710534424521, 0.07506587004172616, 0.050216264789924026, 0.006299070246313931, 0.059764811012428254, 0.09483125904807821, 0.017405951257387642, 0.034915840296889655, 0.03094994226557901, 0.01793277777323965, 0.07314634960494004, 0.0673258857568726, 0.02656691456650151, 0.1525605222559534, 0.137656178267207, 0.14961811451939866, 0.12053429702064022, 0.13032187416683882, 0.11888848806847818, 0.1874966046307236, 0.12046472809743136, 0.07901108998339623, 0.12521913391537964, 0.10459971847012639, 0.14201715675881132, 0.08380255123483948, 0.08332878642249852, 0.14964799338486046, 0.10893198326812126, 0.15486358461203054, 0.200821747421287, 0.12931439385283738, 0.16226033301791176, 0.1499388855881989, 0.13471593760186806, 0.11127449077321216, 0.12752935057505965, 0.07959744601976126, 0.12397731305100024, 0.18468573514837772, 0.1281421715975739, 0.0998357315256726, 0.13946805760497227, 0.10865183736314066, 0.10249394865240902, 0.2018580527510494, 0.13892989663872868, 0.21371614770032465, 0.2257485137670301, 0.1590002712327987, 0.14688987575937063, 0.10107333699124865, 0.125488800695166, 0.1648946455679834, 0.07493073237128556, 0.2396253394545056, 0.17946619569556788, 0.16759612248279154, 0.13078761636279523, 0.14198640215909109, 0.0984646582219284, 0.21597479993943125, 0.15194580133538693, 0.12694195553194731, 0.17324361397186294, 0.156993281270843, 0.13167898025130853, 0.10299533620127477, 0.11212847268325277, 0.14566929516149685, 0.09285074891522527, 0.3003348154015839, 0.1561140886042267, 0.14022403891431168, 0.14306005235994235, 0.1392977495561354, 0.14593155530747026, 0.14022800198290497, 0.06791394131141715, 0.1529394183307886, 0.08791820539045148, 0.17829982156399637, 0.10094704572111368, 0.16988569259410724, 0.18228004861157387, 0.147951414110139, 0.12793591391528025, 0.1091833486862015, 0.17256618157261983, 0.1591487304540351, 0.11433173101977445, 0.17253691126825288, 0.12987668946152553, 0.17067075124941766, 0.11442334172897972, 0.1334714301628992, 0.15133476146729663, 0.0765097257681191, 0.11582862061914057, 0.08238337191869505, 0.06720964316627942, 0.2083022249280475, 0.19116544135613367, 0.12911526078823954, 0.16567065002163872, 0.08551175444154069, 0.10715390133555047, 0.1617021785932593, 0.14121188200078905, 0.12311286685871892, 0.09230699215549976, 0.13076021627057344, 0.16936172149144113, 0.133483512327075, 0.147895070258528, 0.16300951625453308, 0.21522266295505688, 0.10287651835824363, 0.1707426059874706, 0.1726323366165161, 0.09072199478396215, 0.08823332871543244, 0.09068321756785735, 0.2968302753288299, 0.1557114883325994, 0.16651816782541573, 0.20377669745357707, 0.12312124570598826, 0.10570423459284939, 0.20497346995398402, 0.10880241170525551, 0.15530743345152587, 0.1335706256213598, 0.24984484654851258, 0.2099795380490832, 0.18145182664738968, 0.093550089513883, 0.1145741980872117, 0.18081414367770776, 0.1264730517868884, 0.1376452686963603, 0.09304636419983581, 0.25587847747374326, 0.12877598055638373, 0.1138888840796426, 0.16230432753218338, 0.22554094990482554, 0.10164814520976506, 0.1622499874792993, 0.12734743533656, 0.15126053185667843, 0.15243526257108897, 0.05675440770573914, 0.0751274757203646, 0.16448717680759728, 0.12126192828873172, 0.07022637699265033, 0.08582707072491758, 0.13005477521801367, 0.1747386556235142, 0.09369143896037713, 0.11790252261562273, 0.0861472035467159, 0.11224752059206367, 0.12334112179814838, 0.11318967706756666, 0.08548641751985997, 0.1866115044686012, 0.1133955191471614, 0.14109632960753515, 0.11840035527711734, 0.1536919263890013, 0.26913596608210355, 0.18378006265265867, 0.12998241581954062, 0.16566178877837956, 0.1408601485309191, 0.2598348370520398, 0.11845430941320956, 0.13489396398654208, 0.15108611230971292, 0.18961362540721893, 0.1279345780494623, 0.12324143652222119, 0.2223133051302284, 0.1345017389394343, 0.16127142123878002, 0.15808937401743606, 0.09530850453302264], [0.03325645375298336, 0.07296856812899932, 0.047091106898733415, 0.020912932995997835, 0.08801052113994956, 0.02084788189677056, 0.029102005682943854, 0.05897760383959394, 0.053487358600250445, 0.04436848990735598, 0.04212953426758759, 0.04071054048836231, 0.071511472488055, 0.047722411109134555, 0.018670778699743096, 0.055624636297579855, 0.047495992985204794, 0.043797737525892444, 0.07971627870574594, 0.031801792356418446, 0.058564735954860225, 0.014875028227834264, 0.03334473221912049, 0.033726184992701747, 0.018376231419097167, 0.012652361801883671, 0.043047314902651124, 0.054999046624288894, 0.006420403506126604, 0.04862703717662953, 0.015965184720698744, 0.04326203306845855, 0.031875569256953895, 0.03144681570120156, 0.03773355238081422, 0.05673166087944992, 0.0352618184115272, 0.0068821348577330355, 0.008479221814923221, 0.048716818491811864, 0.03180362175044138, 0.0472949674440315, 0.014407067010324681, 0.024409109064436052, 0.01781744616891956, 0.03320644413179252, 0.029026633164903615, 0.004016890070488444, 0.046733499330002815, 0.015226464838633547, 0.0538218260044232, 0.039368039870169014, 0.01394016335325432, 0.08279013563878834, 0.03897830843925476, 0.09051546250702813, 0.07093999651260674, 0.08110589085845277, 0.014638194988947362, 0.03263545055233408, 0.022963937881286256, 0.03577741066692397, 0.029500010205083527, 0.033421136322431266, 0.024789129493001383, 0.012458526744012488, 0.04636675221263431, 0.006563327233379823, 0.05243882638751529, 0.06272146798437461, 0.01714421061478788, 0.03583515346690547, 0.03198538484866731, 0.03932994914066512, 0.007957810194056947, 0.04974958748789504, 0.08814225235255435, 0.06293875398114324, 0.03221733568352647, 0.012601248236023821, 0.038414302180171944, 0.05335699665010907, 0.060547424291144125, 0.06039211504685227, 0.03188613372913096, 0.015066239793668501, 0.018370884245086927, 0.10137379547813907, 0.01893973116239067, 0.07432640893966891, 0.10255031476845033, 0.03851672598102596, 0.06656393015873618, 0.07097647307091393, 0.02584715748525923, 0.02364414405747084, 0.029258177673909813, 0.02478345577401342, 0.01053715464877314, 0.07213793418486603, 0.042231642655679025, 0.10622184548992664, 0.024927920385380276, 0.05447305316920392, 0.041225323802791536, 0.034902860134025104, 0.05150547920493409, 0.010253699692839291, 0.032727358120610006, 0.04249391764460597, 0.055074500778573565, 0.01725533980788896, 0.056156596619985066, 0.023893941688584164, 0.05204035245697014, 0.06785741192288697, 0.04343941378465388, 0.0260200148113654, 0.05157096260518301, 0.0067624301482283045, 0.052158019971102476, 0.0896018193452619, 0.036161037933197804, 0.0012890088169115188, 0.021794261192553677, 0.0405146320554195, 0.03647265832114499, 0.035891337756766006, 0.022216942124941852, 0.009193918376695365, 0.024257184013549704, 0.09930931133567356, 0.06782921031117439, 0.06373772048391402, 0.05975394225970376, 0.08835696309688501, 0.047431455823243596, 0.004212263229419477, 0.08294878454762511, 0.010673471406335011, 0.041394474101252854, 0.009197398121614242, 0.016257900751952548, 0.026455926381458994, 0.06652868556557223, 0.04230885569995735, 0.03266269850428216, 0.027712623596016783, 0.049328786044497974, 0.02958775618026266, 0.04524997581029311, 0.044567463410203345, 0.029664444155059755, 0.02147274797607679, 0.01361919283226598, 0.01277901208595722, 0.026635396243364085, 0.005965246655250667, 0.0302729069153429, 0.04365828797745053, 0.02395246374362614, 0.028730970807373524, 0.07235101962578483, 0.022793112184444908, 0.08662074571475387, 0.0185113839324913, 0.031126719986787066, 0.06341594009427354, 0.04394707619212568, 0.030901843674655538, 0.041417161555727944, 0.03290530657977797, 0.054729814000893384, 0.027053422054450493, 0.045188782023615204, 0.0194119318985031, 0.05782171254395507, 0.03711496487085242, 0.036107228515902534, 0.047209720651153475, 0.06558601700817235, 0.027683041589625645, 0.0441742995462846, 0.02075918782793451, 0.04197007270704489, 0.024881818171706982, 0.04089964342711028, 0.0686359619430732, 0.023822663970349822, 0.10049002376035787, 0.06084550048399251, 0.03731318880454637, 0.0507917001232272, 0.07751779237878509, 0.049492077087052166, 0.041603459176258184, 0.022852945985505357, 0.01555015904159518, 0.05289747736242134, 0.02679125282156747, 0.019290058262413368, 0.07121564500266686, 0.03779694663535338, 0.04867070514592342, 0.021939907674095593, 0.01547093756016693, 0.08030430457438342, 0.024986206808534916, 0.026585457126202527, 0.030622070698882453, 0.031232832261594012, 0.004270211975381244, 0.058832120630540885, 0.011014128322131, 0.02847317467967514, 0.02860446802515071, 0.01159233372163726, 0.03929339465685189, 0.055892388336360455, 0.04123830396565609, 0.060610599612118676, 0.040579800042905845, 0.02301104013895383, 0.006304016660578782, 0.062314310926012695, 0.03442382236244157, 0.02772667616227409, 0.03783361615205649, 0.11440441696322523, 0.06715304698445834, 0.020809366287721787, 0.03406239273317624, 0.0869441514078062, 0.039309562343987636, 0.044500054136733525, 0.03973359212977812, 0.03482323882053606, 0.09057340939762071, 0.04145421327848453, 0.080843356117839, 0.03209430615243036, 0.09112863976042718, 0.010886593954637647, 0.06944742621271871, 0.05415636762336362, 0.02482307347236201, 0.017441796990169678, 0.03079302256082883, 0.06386879118508659, 0.03912421838322189, 0.017714706955302972, 0.1247680714004673, 0.0813477642077487, 0.048355941762565635, 0.030481596986646764, 0.007709330802754266, 0.021805484320793767, 0.016510377536178567, 0.023169304986367933, 0.062432683480437845, 0.07064111137879081, 0.018216038843092974, 0.01280038686672924, 0.14010593353305012, 0.0601206374267349, 0.03461314794549253, 0.03821876482106745, 0.013597126926470082, 0.04662949104385916, 0.01204368567414349, 0.04518066663877107, 0.02414222533843713, 0.050513532041804865, 0.017415894180885516, 0.02173944616515655, 0.06587951414985582, 0.022521628998219967, 0.015278074715752155, 0.02606531179480953, 0.11080989148467779, 0.0553495926578762, 0.009199479845847236, 0.021459120289364364, 0.044500410367618315, 0.03496245088172145, 0.07068545470247045, 0.04721821824205108, 0.04436726536368951, 0.050535978298285045, 0.03007006125699263, 0.05030183441704139, 0.12698118545813486, 0.09950960957212374, 0.040932116098701954, 0.04086932669451926, 0.023611630567756947, 0.030818231462035328, 0.03847001520625781, 0.040575796156190336, 0.02008642168220831, 0.05001555837225169, 0.05524434869585093, 0.02806912536470918, 0.07372562555246986, 0.05398899476858787, 0.05769667921413202, 0.036319634891697206, 0.0528617874806514, 0.06203551572980359, 0.02830220983014442, 0.0023377992738460307, 0.02147640861949185, 0.029210843495093286, 0.04203631680866238, 0.03380509384442121, 0.03193080730852671, 0.006414084582502255, 0.019696903618751094, 0.03216736688045785, 0.04933876793074887, 0.03680788642668631, 0.013184771123633254, 0.013049740136921173, 0.030432310959440656, 0.03924006021406967, 0.03619245304435026, 0.03826914180535823, 0.002022463972934929, 0.017375460120092612, 0.04212399413518142, 0.08947252237703651, 0.048236077491310425, 0.047267225963878445, 0.0646023299486842, 0.06961580467759632, 0.047357263320009224, 0.04344708017015364, 0.026745690520328935, 0.07553737130365334, 0.0015711339369772759, 0.02173535878682742, 0.03521811704558786, 0.022583507416129578, 0.01852688739745645, 0.07615506823640317, 0.022384240764949936, 0.0321629733662121, 0.04460808115254622, 0.038374975774786435, 0.040924301283666864, 0.0207806136313593, 0.054243495760601945, 0.11514511745190248, 0.23831590893678367, 0.1342709013260901, 0.08636877915705554, 0.20888533035758883, 0.13147019926691428, 0.133689918438904, 0.16850753920152783, 0.09831867035245523, 0.13223829242633656, 0.11108656413853168, 0.13363917038077489, 0.18701305089052767, 0.16726641595596448, 0.19438539748080075, 0.13873316813260317, 0.281778333010152, 0.1911433253553696, 0.13152461353456602, 0.1776198361767456, 0.14459698082646355, 0.1111639552982524, 0.1141441977233626, 0.1403001684229821, 0.09921410121023655, 0.14333947096019983, 0.14482384052826092, 0.13878029451007023, 0.09236202240572311, 0.1478017822955735, 0.15290643728803843, 0.12071003759047017, 0.1098116509092506, 0.12251471809577197, 0.11049417444155551, 0.13757083128439263, 0.12696540739852935, 0.14313800755189732, 0.08791861357167363, 0.10292391190887429, 0.06423642887966707, 0.1285860501229763, 0.12746258697006851, 0.11017725511919707, 0.10954326062346809, 0.18611355306347832, 0.1470857285312377, 0.12077227409463376, 0.17108543368522078, 0.12823220895370468, 0.18368022894719616, 0.08973235570010729, 0.22222800267627463, 0.16291458072373644, 0.09505399240879342, 0.1556759691447951, 0.24757648701779544, 0.1536294969264418, 0.1256015626131557, 0.1696552854264155, 0.07451711862813681, 0.1960144264739938, 0.15053719020215794, 0.19566673028748482, 0.11581552913412452, 0.13688324630493298, 0.0842521591403056, 0.18438506143866107, 0.10381202519056387, 0.11848817361169495, 0.1720730244414881, 0.17075773095712066, 0.09120773043832742, 0.11343863792717457, 0.1271151876426302, 0.15138981398195028, 0.29637471539899707, 0.15051600930746645, 0.1681019554962404, 0.10676699006580748, 0.09428296034457162, 0.1149732805788517, 0.10878600282012485, 0.18331374158151448, 0.13652965746587142, 0.0677981588523835, 0.12055579703883268, 0.24040785996476188, 0.1633338347892277, 0.17261649918509647, 0.15283229673514143, 0.09781007654964924, 0.16750243376009166, 0.1024947056430392, 0.16825250757392496, 0.21573024743702263, 0.10763511731056497, 0.14080197899602354, 0.1125598608632572, 0.14428072201553732, 0.11104964971309528, 0.18582288350444287, 0.06527375095174648, 0.2580454299459234, 0.13501626992365345, 0.12757116317516193, 0.1275696640368551, 0.1355664388393052, 0.10374602599767968, 0.12437924538971856, 0.22243074257858098, 0.13188792450819165, 0.2056023955810815, 0.13570492359576747, 0.1620212575653568, 0.18403933936497197, 0.4822407028404996, 0.16494013922056183, 0.12625567673239857, 0.10488492582226172, 0.1242427941178903, 0.2675716672092676, 0.17523849208373576, 0.14911251899320632, 0.12585510994540527, 0.1521110034082085, 0.1803635264514014, 0.1822303989320062, 0.1591509865829721, 0.12173048322438262, 0.08914513877243735, 0.16494248440722004, 0.2074868866475299, 0.1315639028325677, 0.0886646872095298, 0.18031792889814824, 0.1501533217378892, 0.1300141352112405, 0.15050892921863124, 0.09603958678781055, 0.09007257103803568, 0.0687004100473132, 0.17994894791627303, 0.41937699483241886, 0.1331576649681665, 0.15160617971559986, 0.18508276931243017, 0.14208638429408893, 0.11424315569456667, 0.13095094822347164, 0.17104007361922413, 0.1064958464121446, 0.11316121570416726, 0.09537245539831929, 0.1684208563528955, 0.07835452677682042, 0.09975983950425871, 0.17388420616043732, 0.13342549122171476, 0.14837840135442093, 0.13524977926863357, 0.07686667653615586, 0.26372728287242353, 0.08804015509667806, 0.18642236071173102, 0.10909829114098102, 0.165850828634575, 0.15316077129682526, 0.15920954203465953, 0.08848163648508489, 0.1675746447290294, 0.18580597738036886, 0.1320578614831902, 0.11452614402514882, 0.15155087487073615, 0.20700495078926906], [0.033196495642187074, 0.022400499365176074, 0.06819747140980326, 0.04542084418062586, 0.054409458534792066, 0.0838901023962535, 0.0449887991999276, 0.04041869833599776, 0.03938973655749578, 0.046887216667528264, 0.03990649769548327, 0.027627393501461484, 0.03348083839227911, 0.055425473547074944, 0.007021813544270117, 0.023574604820169043, 0.032455795153509825, 0.045553057789220475, 0.033631071346462704, 0.014213472222763812, 0.017001228443405125, 0.08358053033589385, 0.027059129170083907, 0.04263686641934328, 0.058133110287599266, 0.02110188564984128, 0.03665990960143972, 0.01647716086154105, 0.008131684262480121, 0.028427771940187085, 0.023518196030636318, 0.06146419560536742, 0.06076436518924311, 0.025346623406221624, 0.021404130857263226, 0.027731503832910676, 0.07204785229987465, 0.017568487164680846, 0.025472996312601026, 0.026580672129057348, 0.07691355800488964, 0.06093765296100173, 0.05273428279906511, 0.03168892282701563, 0.0342461410764372, 0.03209500377124641, 0.05148479183844756, 0.07976638109539635, 0.08172634858055972, 0.04998203556169756, 0.06565148927620612, 0.083478514716262, 0.0757522824278567, 0.005431641548057087, 0.10955714620649815, 0.031160079524852335, 0.04320015279517975, 0.017971087436308153, 0.013677027473022463, 0.0562452943995595, 0.030438025496550836, 0.04176259048108477, 0.009325365717813838, 0.06142076512333006, 0.04849817807553336, 0.016314072054228745, 0.07874765724409372, 0.015574854005535599, 0.02758319489657879, 0.03830851645034272, 0.021779624185001012, 0.03501048639009241, 0.031091866876522545, 0.04150572574872058, 0.038107657892396674, 0.049663487225188874, 0.03846001847705338, 0.04030983640404884, 0.04322904089349322, 0.050634427898330614, 0.0612164555786876, 0.0198578457639087, 0.03485663917672355, 0.020441992055566516, 0.058532879265840165, 0.06426214429666288, 0.03756437239644583, 0.015110726908460492, 0.07522382875322364, 0.04055264114867896, 0.07386709374259226, 0.04376360615424346, 0.0214550180680817, 0.010303764975105878, 0.07405306110740639, 0.021973144757794216, 0.08916605249396525, 0.026650697473087348, 0.039768855276633985, 0.07254509866470471, 0.05253155031823553, 0.03122279842500575, 0.048167499335249886, 0.014878969031997258, 0.07322535864659585, 0.01105385734263109, 0.06040407475666143, 0.024431957936030813, 0.015524467744398862, 0.07268480054335669, 0.07290464694960974, 0.037658959117834456, 0.017503671697340906, 0.039364600015687756, 0.0817589733924251, 0.06266801850870252, 0.04219318456307519, 0.04969548121152911, 0.0518627528072102, 0.0719688952085562, 0.04471006337553263, 0.03217371224309318, 0.03142336012388114, 0.033779923905967735, 0.032871527728275396, 0.06496315472759306, 0.05459690648422111, 0.017741518895491026, 0.04807276047358755, 0.0830807384045329, 0.08670679031638429, 0.021247335462248884, 0.03726556147739757, 0.08738592223380692, 0.029370434931479394, 0.08682910367497243, 0.01284271433178219, 0.07864721497753635, 0.06709700741339475, 0.05524093852727674, 0.034898166049970314, 0.01040851262587239, 0.008232265681726858, 0.022103022456576582, 0.040221079252660275, 0.03951036153011955, 0.024129399171215482, 0.06734843220328912, 0.028625628510781098, 0.01869407842605142, 0.016647685988573357, 0.05783416949270759, 0.0791336853581015, 0.026569564033707138, 0.06638783335802145, 0.03155231199343689, 0.024767167487880215, 0.05545043197344057, 0.03434535508858971, 0.03254371367802378, 0.035960695167887025, 0.035246422557975166, 0.020577003560902085, 0.04912815013085492, 0.08441875645075925, 0.04753605411679018, 0.06821352406404912, 0.018425727103021927, 0.027542027964955196, 0.04055464123666752, 0.02596470068965573, 0.033395717764506117, 0.044127655564807355, 0.033560979209141806, 0.07919353214674629, 0.03919281138223596, 0.048446049622725695, 0.12073420191882178, 0.009571874707035022, 0.028045534345437773, 0.026370625782874413, 0.08735953888390213, 0.020452272656257264, 0.055060752492863685, 0.01609723134606611, 0.007559440164186526, 0.027171403125976212, 0.016754041316744406, 0.03814670599240344, 0.04142061254242435, 0.01970113571587717, 0.019692782843776513, 0.046723973864573054, 0.038324747220030986, 0.04000206776254345, 0.05654779750329908, 0.007276392461790238, 0.03718122010468505, 0.039313658999162726, 0.039008231833577156, 0.06273490827879868, 0.04632749631127808, 0.05957869521807879, 0.019156566304445732, 0.02398593831458129, 0.01834698337916052, 0.04460617754375562, 0.0096946454141289, 0.06351285715936683, 0.01634720894799102, 0.03047301033802796, 0.08309233817271888, 0.05560954101383686, 0.061398753023240715, 0.05608569183095824, 0.07576462434371933, 0.05317248389474116, 0.06957535762921907, 0.01970852379599819, 0.009148778171947924, 0.028463929374993313, 0.05080356706457678, 0.015041471542645013, 0.06533046587719582, 0.04368616675492376, 0.052281197931733914, 0.05895194408367388, 0.09771894081495702, 0.045146427655708976, 0.023237209643411916, 0.056494919481338, 0.006883565347379772, 0.025395432603545487, 0.031944652073434554, 0.019253795071563218, 0.041341662872582674, 0.02913439486292191, 0.03940926988434512, 0.029649653151864186, 0.04390113725094125, 0.05681719339918345, 0.03621264317189343, 0.027318493084749207, 0.019454100729490165, 0.03998586667876225, 0.02524295650800923, 0.03801133825618308, 0.028163608185423072, 0.07445930532412603, 0.0484738244995242, 0.04480388939555269, 0.056692512589506805, 0.020003180543426424, 0.034250671888003126, 0.002978833967972605, 0.05352137864974793, 0.04808486490219366, 0.022132828962639906, 0.009964873443095712, 0.02535630286729429, 0.05797095102025196, 0.07243563930387609, 0.031790110951988026, 0.06414559000404552, 0.06000098837830592, 0.06937672922504134, 0.041439552151132375, 0.007161320145314676, 0.04952339571900666, 0.022857246731291525, 0.04764639292261563, 0.05753287608968094, 0.036388305816217326, 0.060273623748798855, 0.030488979500660207, 0.03709214011905715, 0.031849772203713655, 0.057209726437577046, 0.046135257798596285, 0.02535319326852914, 0.011455517869762843, 0.03389181751117576, 0.07241344908834435, 0.012125111334171379, 0.04034869525639806, 0.06202466553077102, 0.08186239167116582, 0.059577630236162804, 0.015694428839196917, 0.08581769739976153, 0.02259636326925829, 0.059461484124767594, 0.07692488317843527, 0.06448653264669701, 0.11292255585431121, 0.025578754211892374, 0.0025722182135723415, 0.041316956776427105, 0.0182922778185457, 0.032797416861285456, 0.0542929042421747, 0.05791527881228831, 0.028392933672876097, 0.043529688628041185, 0.08893310718121938, 0.04685889260144904, 0.023127134300011676, 0.05004971942980774, 0.01721274238661863, 0.04944677639286965, 0.0489193617249839, 0.0257757665895042, 0.017773639046936296, 0.016985402144200634, 0.018750210765574593, 0.03905673118424602, 0.01620765178813599, 0.04711448826128617, 0.007547077375420486, 0.03334341861773282, 0.054409677468356676, 0.03509282396407798, 0.0485921413928736, 0.07442641333909705, 0.016640795147395693, 0.004944100155626074, 0.01562826451845467, 0.01149921830801759, 0.08288680779514834, 0.07920413743704557, 0.05659674214257393, 0.027694581985997502, 0.007835682372387964, 0.01182206089652027, 0.03449414827628061, 0.06910222364240326, 0.024712562117201742, 0.028876758296974003, 0.03141693683573976, 0.06947599147679284, 0.006562535918419599, 0.052468541980488226, 0.046343931171577424, 0.025656115685706027, 0.04903649118205067, 0.026594611517793965, 0.06493519802461378, 0.005099526288177003, 0.06908602998009883, 0.026344004945713095, 0.05626355123240501, 0.08554078725865111, 0.19351494731381536, 0.27777637587860227, 0.24218156322604045, 0.12780238670529798, 0.15013908734545112, 0.2117016472038813, 0.15014535107184201, 0.24162992485798895, 0.10904199923970737, 0.1753860607277602, 0.07770430893287994, 0.10619164007948712, 0.13644981721881777, 0.13520956970751286, 0.10510382970096543, 0.11742699149181135, 0.09451601697946899, 0.09016775889904238, 0.06288790944381617, 0.16018821217585355, 0.1208650425542146, 0.14146186702419072, 0.18420280481223017, 0.11519963562022895, 0.12675989186391234, 0.09731450001709163, 0.1698027946986258, 0.11594408395467326, 0.08419479854637757, 0.10978595775668509, 0.20049523212946951, 0.08045231850701384, 0.11590426773182116, 0.08075203484622762, 0.0881877237407025, 0.16133894183440134, 0.14805847633397207, 0.11002970873960294, 0.17436824971809983, 0.12281801158678718, 0.16956680658040568, 0.14115492958808318, 0.13224509049905464, 0.08819283713819459, 0.12758798024151474, 0.18857280781958252, 0.08746913925278932, 0.226840034883935, 0.15731616003904492, 0.12361328219412826, 0.09924885598593391, 0.2146835223538801, 0.12990995252039284, 0.11997430206974968, 0.20849755819654092, 0.10820999974384904, 0.08140143632772379, 0.0677917392749805, 0.1089662556478288, 0.10687060872442089, 0.11069988293456845, 0.12010466030915268, 0.13631924375658855, 0.13586029963335022, 0.1651375653455034, 0.1382140803616494, 0.22840705001726747, 0.1009163653361611, 0.08434875708189793, 0.06936512203537859, 0.056479601553292014, 0.07598779557156377, 0.185183196736034, 0.15237940853694454, 0.11282021368970163, 0.20171456591924652, 0.09527437316137366, 0.11250081559410319, 0.11586511202040128, 0.16697890794603154, 0.15099295793334022, 0.13898560224333778, 0.12068595489836298, 0.16054894047556445, 0.14852659340249375, 0.13474250648869202, 0.11560674814973027, 0.13718519650865346, 0.12744530977215618, 0.20254231290891767, 0.16682653018506244, 0.13361074612475932, 0.1244214216421824, 0.06923431108589284, 0.16202642291318625, 0.1608678710181266, 0.12408792274072766, 0.10754338785773143, 0.10925367460004054, 0.12029799720039591, 0.13532414246583357, 0.17409770720405504, 0.08962260690168478, 0.07165447692386806, 0.0939512945478782, 0.10031193800386973, 0.164919477829244, 0.09780478503671475, 0.14320901624159887, 0.18503945757402107, 0.18743108783382922, 0.110499911243096, 0.06101261358708143, 0.1373334479285404, 0.14740868151420727, 0.19814045692328364, 0.25554258143529296, 0.15271536394720897, 0.2304646247648634, 0.10249952218146063, 0.1574373379116878, 0.21063099527964368, 0.13249267096398398, 0.1779255861765705, 0.21097101765917614, 0.18987232324434444, 0.17294157471042126, 0.07247517351061106, 0.2918388572288677, 0.16251312335953116, 0.12356928025837988, 0.14435317047173157, 0.07928340623038821, 0.18562774319434538, 0.14175482239807025, 0.14408996037673205, 0.2043677438632585, 0.14112242351984605, 0.28260654013138264, 0.22116987820481881, 0.1260708225890994, 0.12620357796549797, 0.07347483158810064, 0.12854199623689055, 0.14096333674388006, 0.15946368308505043, 0.11061682176659815, 0.25641754386015236, 0.09623192920116708, 0.10554949680226855, 0.06403037157724611, 0.13627112290123478, 0.2188082307111472, 0.08933958146371879, 0.3023550601210445, 0.1611160155152902, 0.10734999901615083, 0.0729409973428119, 0.1589625107590109, 0.0962907072971575, 0.15417662303661928, 0.08603607435361482, 0.1046499321819283, 0.14423123560845852, 0.145070856960956, 0.10868205019505695, 0.12740861799102277, 0.15652419941034168, 0.1623312378069386, 0.05471916789247189, 0.1757288587396033, 0.1156240921409335, 0.18306982732610777, 0.16845849808305502, 0.18583273922558874, 0.24919632822275162], [0.038218275003600866, 0.029762828817183618, 0.11638718322501518, 0.034517871026764624, 0.03046499885385856, 0.0240432358259568, 0.031853523760219105, 0.05798178266559262, 0.016890416518435813, 0.02821979247528361, 0.014622183152823709, 0.021024639208917506, 0.034309691181988455, 0.015536850478383712, 0.02571800709119998, 0.09631919834646396, 0.03146723589452449, 0.0447012392396573, 0.004271310353942681, 0.07722713766270317, 0.012941172280989122, 0.025342471089970786, 0.0150589806617063, 0.025146789012069348, 0.04223323085170705, 0.04273324171663262, 0.029916163948655594, 0.025909132382366806, 0.08949440831202082, 0.07690842234296724, 0.03331227067974396, 0.013717712936340831, 0.035087205906165764, 0.032765307842055336, 0.021078758472867776, 0.02191228308220161, 0.021202660027483944, 0.03997581428848207, 0.0591068414360052, 0.029975142424518708, 0.057806004988378845, 0.021975779382046312, 0.08058557112235576, 0.04966083404724486, 0.08196394715923816, 0.038446021571871825, 0.07763140034512617, 0.012847511388827115, 0.06747798150172457, 0.052099631502642296, 0.014863939613860566, 0.0289317792703514, 0.06494350265711546, 0.022108634948381223, 0.025289960431109648, 0.04640100974938832, 0.0408089195843786, 0.04124430794036016, 0.019497356806823518, 0.034679176824283786, 0.036412622284842655, 0.048109040362760425, 0.026787096794578247, 0.05387346835050266, 0.06293355894740671, 0.015136620440898696, 0.0733956741169095, 0.01482425604990567, 0.07712142614764161, 0.03699208748003002, 0.02570328288129531, 0.034251165416208096, 0.056692913349252194, 0.004966464312019525, 0.02705881190195214, 0.03277326737588737, 0.028760502718796488, 0.061529404410975985, 0.03491280491289217, 0.06015498402121011, 0.036211463157087564, 0.03646493627456948, 0.06056580357835628, 0.05286998821247835, 0.04648200403607916, 0.013560789520852268, 0.04489620514505077, 0.01146524557043449, 0.018187636851507705, 0.005572369909714325, 0.05003524755011313, 0.05499969229276758, 0.07260802536620758, 0.032959130840026774, 0.04492624357226305, 0.05642397387418896, 0.0270854234622675, 0.1043463715177495, 0.018457029036653694, 0.02298993531439919, 0.06016099170665257, 0.04128064349060878, 0.060788952541770414, 0.05207318135944661, 0.017647494350967463, 0.014005348966747988, 0.07438192900735885, 0.08876397914718837, 0.04836934866034426, 0.04161743381700944, 0.04901877240627073, 0.0065698423622961855, 0.019024759021704085, 0.009365334080939647, 0.0525853374711005, 0.033198391829500906, 0.09961220406694338, 0.019496687018545344, 0.032687300699763, 0.06382166480761953, 0.010306467320333468, 0.06947472240426578, 0.047124822667683475, 0.02973962928081164, 0.05782645857834723, 0.004187560380159994, 0.0342107740289066, 0.07856795360567048, 0.021171988919377327, 0.037983722941135056, 0.03044873839826323, 0.00351973485066992, 0.04710851397248916, 0.07155006416724063, 0.04938408346788492, 0.01991973531403346, 0.05763803841546178, 0.024393737330683507, 0.0372836810129229, 0.027638366154860705, 0.051606656197691336, 0.03517349170579109, 0.03839910299575422, 0.012381076212477637, 0.04247098899213597, 0.020236736272636335, 0.05690162011887878, 0.01810366284189513, 0.047243941080523655, 0.013071024004602805, 0.08388115209527314, 0.05829381123476196, 0.06402262355550192, 0.05735165104852058, 0.07187893948866986, 0.05884995814994909, 0.04357117097242735, 0.06998995842877775, 0.02259091033920413, 0.02721306915191235, 0.023090214308467694, 0.030823689958197065, 0.014002731968503213, 0.010272601266478887, 0.041510323353577405, 0.046495904462062754, 0.032676828996045515, 0.043972079147351906, 0.01795515723642893, 0.026334815302107017, 0.020488374429987743, 0.035738262376980856, 0.0195442364201881, 0.017562138091307133, 0.029084927009535022, 0.01344087608231348, 0.017987579813052434, 0.019964843049820047, 0.019921843013435137, 0.037847204876015894, 0.054401320885517634, 0.017052740913641173, 0.011693336309690494, 0.021947954410279635, 0.025594595354050398, 0.051601227387436666, 0.04975898307748139, 0.04303220106521621, 0.021502979361684993, 0.05196876860281918, 0.03435914790316019, 0.06577389169251546, 0.05724743867176585, 0.018500259138818365, 0.025953958102036268, 0.07232438394566998, 0.0492992337240139, 0.021273410820867866, 0.09999398709624074, 0.034079636534443125, 0.06340879321214743, 0.008593178590672323, 0.009377176902489737, 0.08447030602837913, 0.047761210589669645, 0.0337323707935866, 0.08441970639978535, 0.04779355338541791, 0.029605192939925473, 0.08040818298468366, 0.02402930385869695, 0.028134057720308192, 0.050107406568713486, 0.02899349627114134, 0.0627430496388115, 0.022872763183841016, 0.04468169478059281, 0.04587018120219, 0.09101036368519999, 0.03494580822007265, 0.05236901626631152, 0.030906085048627574, 0.01806004311220022, 0.023548948774987366, 0.013996696452522883, 0.023024048132356256, 0.04416983552800957, 0.03984822797065135, 0.012355002709227847, 0.03181979314831551, 0.017947062260645907, 0.026379416522104293, 0.01463114644138841, 0.07170086857513525, 0.04556424937618431, 0.05241607585048769, 0.011144052405143157, 0.011753700746339746, 0.03780283557716757, 0.017182112096634228, 0.06536928020068444, 0.0543908825784456, 0.05659786649630405, 0.046186566178221256, 0.11083915436756797, 0.04250397003488615, 0.01594110388396075, 0.008440533656539628, 0.02025259967922466, 0.03208437621651683, 0.02696005245525157, 0.027272808329144027, 0.02422874120384222, 0.04760006064316258, 0.06523020914755762, 0.014867817335471045, 0.02379772409767611, 0.030246365859056823, 0.0034225026047352003, 0.029446052358252928, 0.06590190474526025, 0.03642485287855379, 0.07794748846208677, 0.02067991161311511, 0.03759530882234685, 0.04013736870547291, 0.05657698988215998, 0.076229245896684, 0.030699383933097124, 0.05609967018244788, 0.01206272547278786, 0.08016944892005995, 0.05172628298169002, 0.06425456696888432, 0.0415197300753789, 0.007108989457265125, 0.023065493369358592, 0.05438947249785997, 0.016387707946705632, 0.057984884842881, 0.017272607728955336, 0.020307819177105557, 0.04480783019971568, 0.06588952572201379, 0.012699141225311905, 0.008245727312896634, 0.021482850461325143, 0.024528565154469106, 0.007414403635266353, 0.017794625127862673, 0.06861342291813344, 0.0038423965406764182, 0.1465520352940075, 0.010072059976664605, 0.023657207711949013, 0.013747811663051834, 0.03190357419953216, 0.054334234446287155, 0.038221429131226614, 0.011132333893328905, 0.0386129231628729, 0.03213522817532066, 0.025178940704790875, 0.0884600325662177, 0.047283486419473775, 0.007547990217062761, 0.036068625704501756, 0.03272082351031713, 0.01626142595341662, 0.0445078503980767, 0.00606293184318929, 0.04431969740835484, 0.028896018884552177, 0.07742480869637802, 0.023079293605405837, 0.02057093835901469, 0.10609478238620795, 0.064126316428883, 0.028437453256628942, 0.04220264694595244, 0.022454514728451613, 0.03833360104181338, 0.05142174268257804, 0.03472243290161714, 0.039917949034133926, 0.012015600950689986, 0.07131900390959345, 0.026641734184522647, 0.0564751115598483, 0.008722964448679704, 0.04432897796505131, 0.056334422624786384, 0.03554351540515199, 0.05067628502729349, 0.04616665806679521, 0.04773408880282659, 0.03391409307369031, 0.06125357780547347, 0.02947284017864149, 0.027072129742009565, 0.015846342757868115, 0.04562071197142359, 0.016656001753290184, 0.03659177302324679, 0.042533340529189445, 0.07676299850572832, 0.0668150358251296, 0.060301361518213525, 0.04277876505511813, 0.009737239124660846, 0.02005159083637409, 0.051480123729561456, 0.12941164488438517, 0.11782784771639854, 0.3542496176669374, 0.14231803826987743, 0.16651273530442268, 0.13158192217815667, 0.13213376834755763, 0.16055551590397954, 0.09871176371234469, 0.20276516501326114, 0.1629925359156914, 0.1596151405829005, 0.09969228922273032, 0.12948844232596457, 0.08254662214312702, 0.1772089535370469, 0.16616150649497285, 0.12368549316306598, 0.11480920657049865, 0.20629732782253996, 0.15171514183748513, 0.11264390166616067, 0.22834601579234004, 0.10395054705440998, 0.14663520036265254, 0.09824596214457415, 0.16386374307330698, 0.14157093304675072, 0.1895128417527303, 0.16499232704518363, 0.14025516458787024, 0.1409239138592966, 0.11679937204462476, 0.14143762848107144, 0.11392963540856726, 0.11598257915466093, 0.18137293634936213, 0.14758014731341973, 0.1134313945658505, 0.16408534836955369, 0.18788614310324192, 0.11536008794791996, 0.21403847727924585, 0.14893937594024464, 0.16821678058477119, 0.10566228098468855, 0.13367348728934303, 0.09557590776239522, 0.16560296615352854, 0.17365494190016761, 0.16846942249685526, 0.16965728922514245, 0.13233508332632482, 0.09303181810537353, 0.14810612221481279, 0.1458955611451529, 0.15309642709326, 0.20563297206535935, 0.11962215299718082, 0.10757466196082532, 0.11214107435080223, 0.1649715765961446, 0.20400691166287288, 0.08722324346308596, 0.19602906162617728, 0.1442618269356899, 0.23068830807460472, 0.17083408311009407, 0.20778837671969086, 0.1850722753442824, 0.15437467256560922, 0.123932702554157, 0.09105916731641628, 0.14561038347892463, 0.10263851159834303, 0.11806292299297638, 0.1643886195961386, 0.17554922931594774, 0.12122899919631891, 0.15076394600328058, 0.11376590278814547, 0.10401331048342399, 0.15891030809143558, 0.1155347227177117, 0.16707645583664998, 0.1536845791270025, 0.16267010243609548, 0.07462702327757142, 0.18210828595329076, 0.10760804376332089, 0.2790331287542358, 0.14416082063689828, 0.1031629131466616, 0.09526777546852827, 0.15139465278480202, 0.18766924302326515, 0.15481715585337952, 0.18855879607144743, 0.10555484768701717, 0.113573812704999, 0.16957088839262724, 0.18724126130109653, 0.10241675045108423, 0.16463890147861093, 0.14197007491020486, 0.1102714633452706, 0.15833408979233354, 0.21160399541258812, 0.1371277097496204, 0.09243245222023688, 0.11633208618150093, 0.20033529930515215, 0.08354523379239254, 0.10799989031511359, 0.1403970186947845, 0.08925013782572933, 0.3006058477330953, 0.15369208966149017, 0.16131630633026361, 0.11160509529872797, 0.14061192981898785, 0.1631312136305496, 0.20980848785256967, 0.0503530017886078, 0.08589103643316776, 0.08841034577926621, 0.10932998964563012, 0.23511530802352354, 0.14073983154958114, 0.11507768591400236, 0.14126145746558905, 0.10187628140556626, 0.13861246523447335, 0.18544164224294946, 0.10913566569797695, 0.18160932522732764, 0.11711760496837087, 0.11651143358903937, 0.08190109467250295, 0.09224056251696311, 0.24245056207291782, 0.11987449805019423, 0.08845511212712154, 0.10885908952332102, 0.14583017793484032, 0.10771748828119598, 0.17146192520158365, 0.1168337112176232, 0.05340076852007769, 0.10931756609352306, 0.276042926707305, 0.11872394650708884, 0.11152144783409312, 0.07181980516179465, 0.2661382535006851, 0.21762208576546982, 0.0960064870014321, 0.2047731791390106, 0.10330293414881453, 0.14333583443658426, 0.13520241540390998, 0.12252410626388155, 0.08674089942360297, 0.08479601980070584, 0.10390106064733118, 0.15318750345613807, 0.13436997804092243, 0.1500958201359026, 0.09672324580606073, 0.09684056451078504, 0.231449410202913, 0.20884396304609254, 0.15876772667979822, 0.0834959997155238, 0.2089438115945086, 0.1732846992672421], [0.07388607045868412, 0.03954008825530764, 0.08428637956967577, 0.02907064808823634, 0.036023169159307145, 0.03926433957531117, 0.0444611952843843, 0.014743335050297901, 0.0024898068886614055, 0.02640404098201543, 0.022366152770700864, 0.0361480689025484, 0.05343589436961338, 0.027206580925849266, 0.0793656955647748, 0.0213211420486914, 0.0447489556245273, 0.029730302339885384, 0.027766125022026245, 0.0382863893173635, 0.033911161590367556, 0.02873148103390122, 0.00868144128617132, 0.01852670371590648, 0.06610683398321271, 0.017727859667502344, 0.02063682066363981, 0.041887542174663395, 0.011548881902854191, 0.05124047311255708, 0.00866217791553936, 0.010539549930399517, 0.05842355720233172, 0.0075558653315965785, 0.03525097192323301, 0.0266550241940422, 0.03757644342840649, 0.03994998383859638, 0.025808306054386776, 0.05604943791695405, 0.08402267965720966, 0.03648096666438505, 0.08094251446891576, 0.04287476927856915, 0.03010480861121323, 0.036282234359532595, 0.09926204395014793, 0.049223107926081866, 0.015853814329602756, 0.01667334759986261, 0.018266764636791777, 0.057034950659726746, 0.05859710101503879, 0.05740688538935501, 0.05632541295199189, 0.036281006105127744, 0.04276040803233627, 0.02506675766198896, 0.06821909759310074, 0.04196076246444136, 0.05045845726272091, 0.015720693445473444, 0.05132149708515499, 0.027039484521083068, 0.07118300534784794, 0.05922939599258825, 0.04773057844431605, 0.018249969834869262, 0.05165694412426092, 0.12504493701271713, 0.04015562553831842, 0.0640704549732618, 0.06534920510603115, 0.01978320797206834, 0.05770099480287172, 0.05269374298222829, 0.027960708721366245, 0.04305303315049969, 0.0351224542100681, 0.031653904588893056, 0.03479663282632828, 0.08069877090747468, 0.032946106148301624, 0.08926688067731448, 0.0239856043481268, 0.031839571383898146, 0.041559887686162256, 0.02555974595452426, 0.07431186284520663, 0.020324838478700258, 0.05622079239401501, 0.058840050478465855, 0.05315647205861751, 0.03229439658753108, 0.041896447946783155, 0.07397273846436292, 0.07535933749750257, 0.039097341505112126, 0.047305301850428805, 0.06009628013998736, 0.014431021681957645, 0.040907695729401894, 0.03413031779928133, 0.050052940350724384, 0.0032441758821732947, 0.046646823902847245, 0.07810667171725072, 0.05450294687761925, 0.03541083795425948, 0.016700482374290004, 0.06752957560820505, 0.013911209389334545, 0.006524935006382293, 0.03625391771493014, 0.03694207043736242, 0.10499529802473262, 0.03440890148340259, 0.015247770970745478, 0.02825153413141379, 0.0624590742518194, 0.030096125483396463, 0.01687710053374758, 0.033855285291792825, 0.03351902560098097, 0.00187321274097485, 0.044879466004204005, 0.061191949862404726, 0.10005191914387979, 0.02038258498942014, 0.026971991755999625, 0.025094918455579318, 0.009013879844133044, 0.04314055462600663, 0.030209280739654787, 0.04501059236645233, 0.034633983741514385, 0.04669236208428629, 0.019845561364491004, 0.03897162539942656, 0.06371544863213785, 0.016970587021205574, 0.05999260210955981, 0.08245472941780463, 0.017687566614768002, 0.03567310923244804, 0.004869951253567706, 0.031762970611453056, 0.020726299553643912, 0.042091361901839264, 0.05092717176012229, 0.02533118302380899, 0.019303552362543996, 0.03958058725402225, 0.00516871810759767, 0.01271530984013225, 0.06707522537908517, 0.03241183774662204, 0.01983913065487286, 0.050222702921018936, 0.01911661649501184, 0.06943020096514374, 0.07184678222984076, 0.04463807876163628, 0.06276115804212168, 0.02381654310738668, 0.03326383070088923, 0.028453255436033942, 0.012412973719619913, 0.024498792045051232, 0.03067528083192883, 0.11896568626980297, 0.02494739805115387, 0.018687248812057078, 0.045458244712790474, 0.032029000867623836, 0.041649123522802256, 0.029348669595492538, 0.03089101202931488, 0.07411724945995957, 0.03850340443023015, 0.027292773957015015, 0.028833791657234542, 0.027660411651595496, 0.017144563134934288, 0.04967530221620109, 0.04725213810161222, 0.023647429916309193, 0.038940614758757874, 0.032394400986959226, 0.021583450434263796, 0.039467101742047817, 0.08914345409721136, 0.047179470711853355, 0.047662234064773656, 0.011191373596375342, 0.026212321972707286, 0.05399351073720027, 0.048922393398243, 0.02468896738719195, 0.01739147752232384, 0.0429440747393528, 0.016294284541800153, 0.03876336762914434, 0.05921771458815783, 0.02293598674441455, 0.05613491477561183, 0.013821045868098736, 0.018018211958406027, 0.020262555590306874, 0.027644967558444478, 0.062181147368391976, 0.06499856259324588, 0.02136658746167086, 0.02040378072706517, 0.02084301711875014, 0.028178054089949, 0.0232036608576891, 0.031027175718918443, 0.07355937705142424, 0.04504645665292628, 0.06305457354756072, 0.028153010316600557, 0.02175789781176718, 0.06820910828537308, 0.013056964016868733, 0.04869296586548444, 0.014699698622280266, 0.05922461656155065, 0.03469338524155319, 0.07967263300088234, 0.0403905375424074, 0.047081800366868265, 0.08127337132464163, 0.0072708398056420265, 0.06659889273578301, 0.054487595552927814, 0.019107924090349115, 0.026235998338961508, 0.03412083686271217, 0.03356518347573001, 0.025035837934410665, 0.02050478145974921, 0.123079781915294, 0.040596383332740515, 0.05211225914536044, 0.09649345462094061, 0.024533784308005124, 0.017494029343652073, 0.027754371258197352, 0.03983934446296189, 0.03762618587643374, 0.0380608432169538, 0.08329139702254906, 0.049942119148909114, 0.05583243393630255, 0.03456545753579121, 0.03053238400752889, 0.0942500757810194, 0.048041070767794736, 0.04057987796841189, 0.01791401442460483, 0.07074271139572375, 0.07011115114437416, 0.020034072440466844, 0.0395210855640471, 0.02424531150609255, 0.02845778439223068, 0.025869841228995938, 0.05320352051057853, 0.09866970620350912, 0.047827989037614316, 0.018762949730444234, 0.13544952089432627, 0.03228330890124198, 0.014721418501721928, 0.011609756566031137, 0.0275756008704775, 0.049824666857603006, 0.012761502039211337, 0.037713065394200385, 0.03662334398541134, 0.06286138508585282, 0.06581979352631606, 0.08856533590005711, 0.022337771188176703, 0.030195677172741853, 0.01504513960753684, 0.039187401125673205, 0.02365690714213997, 0.02682780359464232, 0.04067056470375974, 0.05733206577133387, 0.03586678751162253, 0.0385331163124647, 0.017047085748345125, 0.025785269790503662, 0.05137258653121535, 0.018515398951421957, 0.0445839168241946, 0.013166124663257506, 0.03054202450584853, 0.029970620889798738, 0.03030975454748841, 0.050244826343259774, 0.03750004674657248, 0.017319210892310366, 0.03152110839437228, 0.012361182944005122, 0.08033421312575229, 0.025299691842519678, 0.03234056930523366, 0.04545369163679425, 0.03581546799978241, 0.0059232911917206366, 0.0353989487484796, 0.0070587938353128266, 0.06000025365210604, 0.051221281173639, 0.011860673912451603, 0.028928216961503495, 0.024156979234248865, 0.037664822084479965, 0.01935186803166289, 0.059211543630226515, 0.05687789736839477, 0.012948146613780409, 0.03600884570914786, 0.03227674460504204, 0.00552300363779068, 0.018701852422964294, 0.04654732416383922, 0.023940257269714493, 0.04744622827274725, 0.04277695421478711, 0.06580306551768444, 0.07114926731446758, 0.07691179911489598, 0.05720951121475082, 0.0772011031222064, 0.06915827805642039, 0.007976146807777695, 0.044234884771867655, 0.08749891421757638, 0.012229754156578565, 0.05923740747675765, 0.012501267956395168, 0.03464440720563289, 0.025128122142632492, 0.026095430002897047, 0.051123558878316544, 0.04551274803816341, 0.015544407397101168, 0.12394416131428443, 0.10503680634428747, 0.15021270839497447, 0.09275292642996646, 0.1444828385137953, 0.08814775908831507, 0.09825401444686577, 0.1001292435103096, 0.15978521114448085, 0.12177668933873065, 0.08995932672405615, 0.20413953345268965, 0.1311845169402659, 0.14530527172610164, 0.35176244331523776, 0.14917431020876393, 0.12177554643130861, 0.08155171381076798, 0.1172923955891747, 0.21164999372558668, 0.15942498750519007, 0.1102738530607894, 0.1001171168172732, 0.10249423809000291, 0.13762910471996292, 0.20235120988218114, 0.13237273989943787, 0.16613888583378866, 0.11640192227787338, 0.13821514905430377, 0.13840905739925802, 0.05462032866489608, 0.11524369692779146, 0.07678909983951598, 0.1682963833445683, 0.10240984105621465, 0.17436734429793432, 0.07265076565090567, 0.09580909056239761, 0.17276335536735132, 0.2621532173361629, 0.11292766925180331, 0.281948700430803, 0.18680955399759114, 0.1426866333349608, 0.0970207282807678, 0.1269284336012788, 0.16827900224598125, 0.07613761292304844, 0.1669189424137585, 0.14739254722371697, 0.21359869540901855, 0.17125369340647012, 0.16602814255747944, 0.12327433592872694, 0.1595406437991187, 0.17366383282933384, 0.11857592515298165, 0.20332272571977228, 0.11976955094723962, 0.10488001280464232, 0.12135200275224634, 0.14205585233867168, 0.11020859601558186, 0.26144010247662663, 0.16681980632711202, 0.16714599507395178, 0.10001617731177248, 0.12832380481995642, 0.272052992368117, 0.14818916853982955, 0.1011608584667556, 0.17216561478562653, 0.12542257143650204, 0.2278209017822519, 0.12488794309319928, 0.12492502079112455, 0.18561644770670682, 0.1884022622834891, 0.14425977860810235, 0.09603684826288372, 0.15271471085725352, 0.12406648209434934, 0.166538339399267, 0.12839637201977894, 0.20958057430107147, 0.1762869834783487, 0.14472295297309756, 0.14937630796339363, 0.2644293842604384, 0.1570760752656497, 0.17592006566701457, 0.19169552775565535, 0.1603545868420042, 0.09783169531146996, 0.16989341092994437, 0.26395402383059263, 0.22351010731654242, 0.07276659263879992, 0.1921081024920568, 0.1871254268917255, 0.17079586250474676, 0.14131802396150306, 0.20180614694254473, 0.15064959588926286, 0.10247880141832866, 0.2609998901607469, 0.16967149393167347, 0.09249703391105868, 0.1343526117852889, 0.1200069417245686, 0.1027857165900059, 0.09343481913674623, 0.15623753744876012, 0.11397462440072559, 0.16274568275548518, 0.12051664874888957, 0.08415110089117661, 0.09263024199754, 0.12214735499583185, 0.2644805330783129, 0.17117009789217263, 0.14163462416036054, 0.09164426912320778, 0.08573257306125015, 0.1143363917071838, 0.17075445066438988, 0.19817394262645394, 0.23750827414914966, 0.1514483694336377, 0.09562400635331869, 0.11489413052913733, 0.1025679407757707, 0.10959403094602749, 0.10254995853756554, 0.13792651297990233, 0.19196874200133607, 0.18245917337480932, 0.12583404779434204, 0.15641862148186192, 0.22265496023464948, 0.14330721722217277, 0.1737909478833899, 0.11241033294936642, 0.07108427744242363, 0.11739631852833554, 0.09635018301196396, 0.20222275896230713, 0.2171327284304425, 0.12066518218489364, 0.1311834779335186, 0.15829624026082456, 0.14858271460980177, 0.20287464663852006, 0.09629358683014289, 0.14847324782749638, 0.07450813121977262, 0.12166558983153664, 0.18645364965777844, 0.14327603217680007, 0.14538539398927242, 0.15748557751066983, 0.1495711217285134, 0.1636754602077417, 0.1292385018314235, 0.1636420635622926, 0.1731919456506148, 0.14392173034138978, 0.16595689638052136, 0.14195312425727025, 0.17071683862013742, 0.0816164216666948, 0.13123505719704553, 0.19715209433343261, 0.169133614981547, 0.09653807253926061], [0.042621106913429685, 0.055110120156314224, 0.022545876818185207, 0.041474648314761, 0.008762161905906396, 0.045914854781585746, 0.024204994333558716, 0.012647005351027474, 0.07647573540452868, 0.029173951334087178, 0.018148275194107555, 0.05686387819878291, 0.028236468533577863, 0.0110569094249513, 0.013054976916464511, 0.01628758109291084, 0.029568625468527898, 0.006923856080902624, 0.034322419014642946, 0.024566902648075484, 0.05877383235201705, 0.06559403220308013, 0.024165358081518207, 0.012773903326888103, 0.024434139850200154, 0.013172204708098434, 0.048248449093080126, 0.04993917282263283, 0.06724859107634984, 0.023181709984783083, 0.018639565823832527, 0.02259561741084326, 0.032862462394405156, 0.0175689176103333, 0.017429948602512013, 0.027524299912329298, 0.07059253039187752, 0.023736842013022397, 0.05618397073703818, 0.014980610794737004, 0.022052500753488857, 0.03807772707659751, 0.006675183267361717, 0.08232994470745325, 0.023861630434112158, 0.031036051805131137, 0.03194159442500677, 0.05335285546607338, 0.037618894275510684, 0.0069224200251483126, 0.037390171783044934, 0.06695988078718074, 0.03609504616179038, 0.042136243282584473, 0.028620572629733942, 0.03544030121702235, 0.042947948750224896, 0.036276349128456786, 0.006359905019053258, 0.030555281118722633, 0.058401712085469626, 0.04718406831671018, 0.03960511152399704, 0.036184738419251516, 0.06717846554238349, 0.009774994960025651, 0.055317372316494584, 0.09059430085471831, 0.008227026119129732, 0.02615995046653552, 0.016812016037874855, 0.07643608987564221, 0.019155349182256032, 0.025254534011764918, 0.023743257879687008, 0.02198553120251745, 0.03968018718296662, 0.06614144775085151, 0.059135161791346036, 0.014065809882595204, 0.047044767197803594, 0.03052826323255431, 0.01914452681376133, 0.043594570888672024, 0.0062801491912978236, 0.02310395888343919, 0.12205796330817975, 0.03230940652429126, 0.048307156685041264, 0.02750631025264738, 0.015868250957282726, 0.030617152115155477, 0.053991488384781405, 0.07935356887173839, 0.05203148008149583, 0.08602267116657458, 0.060846802953165025, 0.06513505097245798, 0.006616489126827219, 0.031983110166038387, 0.05009320557292085, 0.031581823495798744, 0.05538572782825213, 0.06301026733126491, 0.035495227566570975, 0.02898281305533601, 0.003992025804109289, 0.0397551960486453, 0.06381469604093581, 0.050210160625283606, 0.02166955997381592, 0.06251083163078874, 0.024201756714319345, 0.05435369355836883, 0.013477596621669363, 0.08176728544640355, 0.11031309040845372, 0.03654690648545511, 0.048585261683911085, 0.030601906546507962, 0.02742850349022774, 0.08201431672205217, 0.08777810275205411, 0.040830879734130576, 0.013198752258176683, 0.013869124049961101, 0.008373783966817427, 0.0313888650998706, 0.038799510220997036, 0.06086404675443191, 0.10724656589445658, 0.11081422562710941, 0.008522258031007368, 0.017043308216670994, 0.01978299089387292, 0.03563547492376529, 0.008222703108913265, 0.031508243264397606, 0.039904772202135064, 0.03278003576269839, 0.037048505546408705, 0.033731944058672525, 0.047308893845183775, 0.008833333868096815, 0.042854742423514836, 0.015036849817988696, 0.03244830317271408, 0.04206092642561998, 0.0635203454294242, 0.059991941598127596, 0.014989284645707812, 0.032474189283675514, 0.022578171374334488, 0.05263994469714817, 0.0034126065293094143, 0.041135765131912194, 0.0687452283455059, 0.029626288487634156, 0.0417347859183792, 0.09514189980109222, 0.043381055002100766, 0.08209280626033433, 0.018269686843268573, 0.02588094004750019, 0.06491891530458815, 0.019472609892545734, 0.06358885308145545, 0.05614660360151902, 0.02244941617391305, 0.08060206164373085, 0.034234329796163365, 0.03927775760530494, 0.014006233050167793, 0.07228606686112471, 0.04627635491488036, 0.009988837391574634, 0.03918013921065722, 0.021409641303762328, 0.028875633943243884, 0.030929358799767215, 0.032238605635939166, 0.06507406127639115, 0.057708932072273456, 0.048053049031295814, 0.0342932822968578, 0.03567602587281726, 0.049144072909257375, 0.020809601919609122, 0.013390257900027791, 0.008490280742989853, 0.01586243808560539, 0.08003785871551372, 0.011748062279366422, 0.014757206718059024, 0.061131390611990355, 0.1151380522060208, 0.025364700268255547, 0.036538108324748464, 0.025798871502047405, 0.028900282522954512, 0.023348281320068054, 0.006478802642959636, 0.03797856130404398, 0.0833098022849299, 0.01006162816338474, 0.005689897343472694, 0.04486891266424209, 0.031281413248507306, 0.03629051301686559, 0.035205396634410135, 0.010480114106030669, 0.019582228815124836, 0.03799608341068961, 0.02191067447711248, 0.03646901066531427, 0.02434486505080713, 0.013593623061751714, 0.02263518315885449, 0.021311406926542986, 0.03980285306170117, 0.05669410078553483, 0.026750742690637708, 0.029690883166040294, 0.05563434729992878, 0.02253698588901898, 0.0677779279067181, 0.04848697906709276, 0.02303915640368359, 0.03186946880305186, 0.045661871481570415, 0.03539560908393469, 0.028624836268136278, 0.03804230065725278, 0.05704368944861926, 0.019387665524845943, 0.06013496458763257, 0.018801730657287408, 0.004378917592475773, 0.007412251870846376, 0.02820770660036942, 0.016385555718443356, 0.02385559491813183, 0.054386403717217036, 0.10711942115449347, 0.01933346091391286, 0.03386597221833654, 0.0488324933394324, 0.0455179950222373, 0.050776612260960974, 0.01457133026633528, 0.02965503928862745, 0.08605822746176273, 0.011223404690099414, 0.05218917161982972, 0.06220410570676904, 0.018072464808938093, 0.11214323400054127, 0.036285481255617924, 0.019088468689005822, 0.0052091591260250425, 0.04176596354227513, 0.04723146186734084, 0.030439817783189937, 0.028289188849157654, 0.03819229983491823, 0.041505376939312555, 0.012015707634418504, 0.03408344375202432, 0.03252435846661683, 0.03984040202340111, 0.051602696839836426, 0.02073609775834484, 0.06557929315022193, 0.05530819566047285, 0.020848451495112386, 0.05297571457049344, 0.08702977298526093, 0.03239574798499234, 0.05354813678422943, 0.04035165642562788, 0.04147419931541663, 0.09370953994221054, 0.013834407309332164, 0.012894902156403987, 0.08900816799723543, 0.013059358370810514, 0.022983493472565897, 0.026190237513219472, 0.016318775415129494, 0.012974798992217984, 0.09824839638895355, 0.09318399548646994, 0.16087361524114385, 0.06380742299370468, 0.01908353340695612, 0.044606285155168734, 0.02342036797926994, 0.03355706809088588, 0.058961566028301604, 0.07161728048231453, 0.022878156742081046, 0.014712311422044877, 0.03985622461186722, 0.046258012735052034, 0.02881734566472005, 0.0371639243530808, 0.01958558332262328, 0.07182351590017788, 0.03848503256449476, 0.09676918474724516, 0.05258442091871984, 0.03728740288352128, 0.023484868033847306, 0.05884549784241244, 0.04245323681971058, 0.03535997857397888, 0.11584537089220248, 0.034519340479164384, 0.018932413586298935, 0.045071938293403946, 0.046939983367337845, 0.06035170139512047, 0.015366658390121302, 0.03165876194543671, 0.0589554136240622, 0.03697876221849583, 0.06296922656474635, 0.014106794060353423, 0.013718346544919768, 0.026005939980677795, 0.04360515020380262, 0.011596318126976257, 0.015699904033681378, 0.0037638005505868932, 0.06303001588094048, 0.01373346873151604, 0.0207577517721802, 0.046824995006318204, 0.037624471515300684, 0.02794782689306885, 0.03477093967376277, 0.05010050459532067, 0.05452496639918536, 0.021726057821069844, 0.03570779721485451, 0.04571556215523742, 0.0513843495718902, 0.01586253085406497, 0.07235488621518016, 0.01605627592653036, 0.015469849386136048, 0.02699396118259756, 0.18643016810528934, 0.13834037905326113, 0.1277808495797217, 0.09279441248509102, 0.13129769446095452, 0.223877900862135, 0.14009282720508054, 0.1946916224551387, 0.12636112107429653, 0.07200117863249034, 0.18289883650140837, 0.07979361791512929, 0.0877377373399213, 0.11735462467186153, 0.08983529900433496, 0.12452035734895617, 0.17984492849791422, 0.09395356551976874, 0.14959022460971028, 0.289437297033146, 0.1592418848304078, 0.13259061961434782, 0.17574527504621074, 0.08689383379532956, 0.1593553740531206, 0.12679774139542133, 0.2320806513307616, 0.13234149548225105, 0.12964555498911068, 0.11849565446027555, 0.12691223993897438, 0.11817381469882093, 0.10356559505453333, 0.218379091238603, 0.14195325784385204, 0.15562253451207653, 0.12916480656713247, 0.12382434899336658, 0.18228534754598513, 0.16632365091936663, 0.09251707189832814, 0.11358337156707421, 0.15841746266232803, 0.14640676730778068, 0.13785963063128293, 0.16361616260837764, 0.17867545218905434, 0.14413407363463193, 0.11024876104784198, 0.1065257920708973, 0.1258254240383394, 0.13299921643920243, 0.08377272431971505, 0.13838073704391718, 0.08979086662293412, 0.12491132074501365, 0.13616452080896124, 0.16628108132863417, 0.14798438030993566, 0.17197826702613384, 0.24128789867972955, 0.12785298633389175, 0.09235279008862562, 0.11093100256402977, 0.17242259084014222, 0.17212699342053384, 0.12455289310310036, 0.25560765294358134, 0.150907225033734, 0.08591842168243602, 0.13928136293543503, 0.12684553570579737, 0.09915356422425248, 0.10870642974623479, 0.09856311895418912, 0.15800233493791893, 0.10420096994494088, 0.19781141832936555, 0.10550644481554627, 0.20691846089903265, 0.14297860907390714, 0.08263790630735457, 0.08481478129397146, 0.08963640342699364, 0.15568757633445784, 0.14697832491947338, 0.13379812357015908, 0.12066968702129088, 0.20826214895350859, 0.10933754470897838, 0.13627386884763837, 0.18067310593323782, 0.10914058613707311, 0.18214019830338657, 0.14834878966212273, 0.21699703414924443, 0.22845125233288854, 0.15566376823699102, 0.12714481417788193, 0.12544213444925845, 0.18167870119214058, 0.12410383438691497, 0.12984685512492433, 0.09177318759611808, 0.12182145568658598, 0.22970186022575945, 0.255958124762401, 0.12763345905113965, 0.10995549397193827, 0.17545156268170103, 0.09176333187497221, 0.19597610196797177, 0.056047493490041234, 0.10689225717214867, 0.1430764389806427, 0.17304661829257384, 0.3381519892718643, 0.17117358598625287, 0.14213774091331288, 0.11768170399591327, 0.14079752610996366, 0.14746127009857446, 0.21224804600933567, 0.11103747849119827, 0.12929906108183786, 0.1405490402248688, 0.13579456019215286, 0.11136936693219468, 0.1419784760219045, 0.18234289367683232, 0.20475110766710714, 0.270383664756082, 0.14843461161945015, 0.18772937182802707, 0.12363325338810682, 0.12363075235043652, 0.12257532187504694, 0.10760977296740748, 0.12619081302545965, 0.11382001277524978, 0.1897907760576345, 0.08664421242428944, 0.10119574682903476, 0.1534029934555292, 0.1604619310819544, 0.2941419492708519, 0.12236130874953233, 0.1430167257785797, 0.17789109115255997, 0.11779813954490237, 0.09062044671736658, 0.12557796231703833, 0.0970142196456436, 0.16468034300487489, 0.1210842136060819, 0.10420183825772256, 0.17419791198335588, 0.12844176177168265, 0.19735398818738759, 0.12847248668549582, 0.18824326456524432, 0.1608523156028241, 0.1334169862093404, 0.11158134657307528, 0.16075062652816996, 0.244679736206308, 0.12357295388937928, 0.1229200791567564, 0.11940994329052046, 0.16642839764244854, 0.15124675759579986, 0.17405791324563324, 0.20314665860496461, 0.2202058580587618, 0.12176679651020095, 0.0929957497282885], [0.02533066537580453, 0.053874021250521764, 0.031199350269162096, 0.030335119299707003, 0.029724187043029815, 0.021396258525783196, 0.020066736215085257, 0.017755771841621026, 0.03133124475425575, 0.09836881727096625, 0.01985453021916328, 0.03487269925244618, 0.038492075545946136, 0.029357384264585562, 0.014246179598558228, 0.08262226183433086, 0.030782675166847184, 0.06253668805584311, 0.07629497049492784, 0.02559470111009432, 0.045853460615035146, 0.04827162265428342, 0.07465526199666783, 0.002664406406438502, 0.03303002449683845, 0.023807724537618924, 0.047006876848172396, 0.035613303261925466, 0.04314089601393789, 0.022550337125721853, 0.11430822720285505, 0.05530413240194321, 0.02992024390550796, 0.056180144965765066, 0.02110499524860643, 0.03159692249028012, 0.06703369479510002, 0.051611016315291636, 0.05548280074435752, 0.02684366514586145, 0.05509596368938219, 0.07871092835557647, 0.03893360888469033, 0.031659915985073894, 0.020393485283420887, 0.01851347493357025, 0.056712238874752074, 0.093276185070863, 0.010696778554120101, 0.040001744928304106, 0.033604023774387315, 0.01515121106422157, 0.03590893036744092, 0.017449294537073, 0.07090271101333201, 0.019838770713249687, 0.010819828494277317, 0.050995709098060615, 0.080752658250276, 0.11707692785421386, 0.06919435385498218, 0.04980470679583959, 0.03447205825068522, 0.022307176150206942, 0.0877760915318504, 0.029089609961374663, 0.05576059775194153, 0.04679120873333886, 0.03985618008300662, 0.007939113638713025, 0.047630915432819165, 0.06306815485004336, 0.06348441806039773, 0.029916186213085894, 0.026816406061698217, 0.004575296825350961, 0.0374640117661329, 0.00752701387682464, 0.0670331010769587, 0.038624296576017514, 0.01342283632766339, 0.047381568656419404, 0.06441310455556959, 0.09349849540740252, 0.018345764401601627, 0.035751929026446305, 0.034744070217129774, 0.07938872440718114, 0.02228668916359311, 0.08005524723557755, 0.03550112021912355, 0.004057607538925367, 0.03925989039998967, 0.010395973113190848, 0.07246203007525764, 0.08309251628816128, 0.025071355266845785, 0.01288593144636252, 0.019107810912828427, 0.04712970228865743, 0.01588380637258524, 0.059781969466712326, 0.02674490384379169, 0.047970047235139646, 0.047118351139943115, 0.046849359714542516, 0.05931176696321927, 0.009924056248564739, 0.059381120663601905, 0.03178395483701024, 0.07583258280646987, 0.0346253488532966, 0.018788919333019294, 0.03502689527522307, 0.04234336185618304, 0.04426579151186161, 0.008473885773128131, 0.1177683200512547, 0.0330218905583024, 0.0331267745787045, 0.04162688877840992, 0.08222458200179972, 0.049144841032102704, 0.0404066495684674, 0.025540921378706116, 0.050364460548735224, 0.04581312859954778, 0.011946701815759297, 0.053347619614214636, 0.007043883160804398, 0.029054725309833884, 0.025359705614391714, 0.0279587049226393, 0.06789271588786505, 0.01872410943178693, 0.03372700135514606, 0.046937055594753474, 0.07565385880297981, 0.022082676478021313, 0.052247793864808045, 0.06162121550005395, 0.0633430018206127, 0.030701448959007394, 0.03660157308331691, 0.04719109274446964, 0.03973639744799584, 0.0348037982621463, 0.03871251938107889, 0.0268315922585316, 0.05850585766893346, 0.025234204731532373, 0.027854099207615945, 0.042100590508198366, 0.03404946452064905, 0.02469074297550833, 0.061523515469161794, 0.0453427554020891, 0.06894451726111583, 0.023039816915115807, 0.03569180393242277, 0.05133425831445493, 0.0851814764610026, 0.037656766071449965, 0.007024341020951397, 0.025050103868125007, 0.055153661960503086, 0.007654365026610321, 0.050921149231726304, 0.06895312617416494, 0.027606305375229567, 0.026526653055043425, 0.06516387598821893, 0.02610766801808495, 0.03256468306062743, 0.02732802226091735, 0.01803228307835525, 0.02998772182763787, 0.018679346794669982, 0.05846666856086813, 0.02463394084770698, 0.09011593472678214, 0.01643613308260683, 0.005536119706448517, 0.08233461281633936, 0.017336553028144408, 0.06576221770956181, 0.060615820621023886, 0.06704380284645595, 0.023573077851324342, 0.03237776574678719, 0.039340673174592666, 0.050798130832845345, 0.042560447473078966, 0.09192271551000886, 0.07631460030097514, 0.04652007621189114, 0.10395298872026615, 0.03251702604757156, 0.05183484805456828, 0.07902758792624809, 0.012534147881524405, 0.03645411205070559, 0.01797605425963411, 0.0262796885726857, 0.026527109475864563, 0.05413478225818835, 0.021582849294645712, 0.035105774441035464, 0.05100288937683217, 0.031174621908576228, 0.01913979933306109, 0.017175095090351533, 0.041755963102332316, 0.057980253841378726, 0.06955066637601703, 0.038560390239581466, 0.03337991001899354, 0.010125710759893991, 0.005271784330034279, 0.06991802205448039, 0.07447031879564747, 0.021559245287789963, 0.025497310925857164, 0.10728060820838436, 0.007022243989922572, 0.023895823032944463, 0.06840503527200781, 0.04912148193398025, 0.038344967033481225, 0.08194194248062558, 0.04535389132797718, 0.04059033111843746, 0.022645187309535686, 0.05832212416862603, 0.025955139972211327, 0.03226223932870198, 0.0380925143690547, 0.052893762913299724, 0.04365452899946831, 0.02563169902714435, 0.015127068072615657, 0.07682925745029934, 0.09603809507098049, 0.046643896130262874, 0.016838742631080095, 0.02596399008325534, 0.010168137487198692, 0.028286702654440887, 0.04096670760191046, 0.027828493257402442, 0.04042239052068908, 0.004385037527754321, 0.045381061354419217, 0.0288050074595958, 0.04177478767815046, 0.029959060084365774, 0.03796608951233793, 0.03541261168720666, 0.004162950299360091, 0.10986015768139623, 0.07396755827357993, 0.10621748908306472, 0.051715365989366546, 0.056705366587266326, 0.02752373959083343, 0.014052311144041596, 0.05865326675120741, 0.07372574429609813, 0.05651288687658962, 0.010643627792887855, 0.05341217161912937, 0.0212969740096014, 0.01857176877820166, 0.029878384921175893, 0.02273277372296434, 0.04013847079477273, 0.03655509608506691, 0.0554840215772856, 0.030528200150001794, 0.028911624394822866, 0.04974978415702935, 0.010579218651400879, 0.03234951589547563, 0.05465438953251578, 0.08726791333174333, 0.1061019441112876, 0.023236714259837754, 0.03168990988342557, 0.05866804291144945, 0.02236744410765823, 0.022534557210747153, 0.02215072585386224, 0.0502568380034063, 0.010833726137207123, 0.029393241129582748, 0.029832757682015654, 0.02738718070759205, 0.06353216784191318, 0.018785039756039623, 0.030803438603470568, 0.025049380274140276, 0.017693563167995308, 0.025510025770927314, 0.026084839555551298, 0.041898904455592856, 0.029031071208009962, 0.041705215044203214, 0.033795175040722825, 0.01627030946110608, 0.04767507693031803, 0.02538228545745369, 0.011667414946714416, 0.09317522330093198, 0.025967138644773513, 0.019289742849650793, 0.053732812812086195, 0.047598735909559764, 0.08846311990055256, 0.025314425329270307, 0.07610875079990365, 0.0030686586524097947, 0.03875535985571332, 0.05809656693600118, 0.06683720377623104, 0.09110885410336778, 0.05530957605515141, 0.037785602908115834, 0.031581663934048265, 0.0184676955541363, 0.005414803608800867, 0.06350025549181737, 0.031150587456068024, 0.04283895694243256, 0.06698302095173858, 0.0508003980939975, 0.009066103848454077, 0.06785416131606326, 0.06243497671675868, 0.02094361338095041, 0.08915591475670226, 0.037981288696755655, 0.058502937317825854, 0.03781930383411236, 0.012912869551655604, 0.02871089571272023, 0.020397947446326725, 0.028829414841311518, 0.02071161801723065, 0.030086993356235325, 0.00981304672677652, 0.052303874253993854, 0.009259439812012715, 0.12710651935776696, 0.1071293065615464, 0.1266842076438479, 0.1111320874770172, 0.1312684389995411, 0.10981211846228689, 0.11531155148986727, 0.19864211906678975, 0.19760821829549968, 0.1892060527461581, 0.13190442987252027, 0.11679377625114284, 0.11248589842580259, 0.09348607927677222, 0.10998301280778833, 0.22087352379458025, 0.0956856639822945, 0.2018069039331749, 0.15480920003028587, 0.1918746525188908, 0.18514153256546706, 0.11099490890046582, 0.20082202943740413, 0.13651552697410807, 0.19766868848819286, 0.12856997520430014, 0.151682635769248, 0.09315120740211569, 0.09641406708396971, 0.11269076087046415, 0.24861734913429245, 0.31094613193999976, 0.17988031409913674, 0.10332698715501465, 0.09748860044055618, 0.08494239358697087, 0.1289422216359526, 0.08637219303636812, 0.20987942232750356, 0.07994717569090426, 0.13573771168012172, 0.1854931769776158, 0.07793561409926042, 0.24871552042895928, 0.18524170765886083, 0.10026188756455667, 0.11286640496109612, 0.25355261634103954, 0.0771664002968464, 0.13952732551842928, 0.12207783802296035, 0.157982757082209, 0.13871305593056604, 0.18058156943880022, 0.15363325219368562, 0.0698158580053132, 0.10021761103416793, 0.145678379049059, 0.13662134238984436, 0.35789026762358844, 0.14489717956166714, 0.14801713870838284, 0.13466049917042255, 0.18626570818014443, 0.19415257091168314, 0.15216990024782717, 0.19957378157414496, 0.12185345709440298, 0.13657705101650208, 0.12303705647354946, 0.119192620186368, 0.11069782718550414, 0.17420858406694606, 0.06409788475139067, 0.11856273718876764, 0.045783490932080895, 0.1500036899233237, 0.13379469484789297, 0.17124747420893982, 0.08848685378325172, 0.15967507642926648, 0.1848646521102637, 0.20658989727962762, 0.2233307302230969, 0.1443801846471615, 0.1093631042749621, 0.10763292797491886, 0.17553489102283493, 0.22390871483366936, 0.14285146433394402, 0.14063379348954186, 0.24292276095366105, 0.12829785933718085, 0.12140491046011448, 0.14771104732062668, 0.14540247822878882, 0.15619395853718743, 0.11483905575005338, 0.05481703490659129, 0.2787090477067977, 0.11622600359260105, 0.20080230315215886, 0.0952370060258545, 0.10991186311002821, 0.1497508105239831, 0.1587629472487606, 0.12693493481492624, 0.10218425042694435, 0.31587951409164816, 0.12880231195595115, 0.16007113095838577, 0.08944394227000885, 0.0819945681723766, 0.10480199081939645, 0.13473670289386064, 0.12463007646147162, 0.13470492413034663, 0.133972498588264, 0.12887096061604097, 0.15582439868012443, 0.09142730224994011, 0.14944384340196848, 0.09527029877062887, 0.1382568132248707, 0.17655470583122224, 0.17101823963457718, 0.16187760746106505, 0.1633880115696229, 0.13941726501798257, 0.12579619826283306, 0.14803612284595147, 0.1638835435733199, 0.08799394898233004, 0.11641549615887925, 0.08730908768484369, 0.13663424091646448, 0.18418870400637388, 0.24482383159920573, 0.12610116158612072, 0.18319011462153867, 0.1711800871999003, 0.16579423245275393, 0.07483308057999238, 0.13030887173954397, 0.11879366385983303, 0.09920834956574254, 0.1882986436248757, 0.1531967060873285, 0.12364181035081856, 0.168572744296398, 0.12651183642446995, 0.15314796182792634, 0.29171114845667034, 0.20378535089548677, 0.11916806251974776, 0.15337223885580897, 0.10535149180213921, 0.2722170960623771, 0.21602505818009377, 0.08026672221603803, 0.16016752109862864, 0.15302372630685568, 0.1377791224513203, 0.22799907659646124, 0.10956290527246892, 0.07262695755343884, 0.14189449459081516, 0.09866975815384649, 0.19476405606837943, 0.10257631220156327, 0.09941577241988853, 0.15109789761481807, 0.08980693412013352, 0.10178746859310195, 0.1312101210351102, 0.11421982999308966], [0.07065717887599021, 0.09226546899299137, 0.02850093471352011, 0.03771896917896811, 0.0275753578171134, 0.03731453951331787, 0.022070238082960714, 0.0384303140162956, 0.010610908357193694, 0.005984127819829155, 0.04745559417642653, 0.013029976744292071, 0.03688662458444014, 0.007735810631857021, 0.043835401520482264, 0.07814014257746749, 0.025802120253501926, 0.086000889132265, 0.07386291545117274, 0.07514301629271358, 0.09646762046031654, 0.021406973282864783, 0.058388112229295075, 0.04444444501132239, 0.065714415977709, 0.04406860658491496, 0.06719630677253008, 0.06520893177366816, 0.04498898473684676, 0.05791133800812531, 0.05043373261287343, 0.034150741703342646, 0.05444313719635829, 0.038060999067965895, 0.017410786349500995, 0.02041102408838924, 0.02301116444868967, 0.023426121479133144, 0.07586902225739323, 0.04720962417195551, 0.03752717966563068, 0.06067994960176293, 0.004985322748325416, 0.017082050180761144, 0.033290150968241505, 0.0390326336491853, 0.06050301788491197, 0.04716141054814216, 0.03343518517795019, 0.03136980303679593, 0.10906385548878461, 0.05426764524600003, 0.04583750443998724, 0.023755210168019403, 0.02711165652726777, 0.012897881879325723, 0.049121329793706536, 0.05247615270491224, 0.02566660965385381, 0.05834444426000118, 0.0500617459329078, 0.03285492959548719, 0.03919366114132572, 0.05102415932924487, 0.02082413873722544, 0.05697937864169944, 0.0913793001382146, 0.034447582220309414, 0.03321813295769971, 0.04262935217411723, 0.10278949412168004, 0.03881707314576488, 0.07981199349160306, 0.016825192869873717, 0.034086761152138934, 0.04344526561908424, 0.09016277166665532, 0.029757745105598588, 0.07195386671810411, 0.03709286742378026, 0.0562601670389995, 0.029705353190365713, 0.02472762585966848, 0.04952387811499648, 0.05333889195753727, 0.05168363175471313, 0.039102595910662785, 0.033882622301462106, 0.03944914918974973, 0.08596556290285662, 0.01591082982486114, 0.0034192958310086397, 0.07990271362359636, 0.04356023171567358, 0.01754578115651384, 0.04667812398110982, 0.03882244258420542, 0.009092056752706412, 0.026062012948386837, 0.02207087818533182, 0.012597340828506276, 0.0386353657086147, 0.027429471992945764, 0.015284270721167559, 0.0189060840421007, 0.05478939361637458, 0.03837415199086536, 0.030083421770541463, 0.04441779077751562, 0.025496956550341565, 0.06649370814557187, 0.06928987568244338, 0.04711313755251467, 0.03493031959806103, 0.02951008857053239, 0.026816862482519355, 0.05940137016295921, 0.01546686316942214, 0.04400052195705939, 0.008839442671160214, 0.035273262328701094, 0.018681909059523605, 0.04109692483325489, 0.07444066999596544, 0.10287118231644854, 0.030845290166325867, 0.03669436751806643, 0.013500423228833824, 0.05319023235642817, 0.04032908771478105, 0.04506206401856616, 0.09777806772035547, 0.06969534064410254, 0.02578282441390911, 0.02950338883238146, 0.0007652688236703398, 0.04211951898469124, 0.07594061724375933, 0.013906404910812853, 0.024514262113370933, 0.03003691694175359, 0.017660760240687523, 0.03265976702095941, 0.034633594113984145, 0.0828187602746766, 0.019095227798970882, 0.02939373651315691, 0.041927903876057826, 0.03311777603812516, 0.013291313844092656, 0.09418209505383857, 0.021745199665019754, 0.12307778553804383, 0.09625723643694073, 0.08421922262641601, 0.07361536467215046, 0.02479762893926818, 0.08596816041972488, 0.0209492147405399, 0.011627035619312664, 0.03133925623842515, 0.01569184987602057, 0.03488772774289828, 0.06940009945537895, 0.04694374976679683, 0.017382657097186893, 0.03258425720559899, 0.04371773400634993, 0.02825608720741002, 0.01769047954439884, 0.06539852824062109, 0.035035567270824686, 0.05153053411049768, 0.0644538484630175, 0.030308901077660266, 0.04261961148586124, 0.028436354878067505, 0.03863861260470003, 0.036621536855818704, 0.050186333974124864, 0.06351368094328791, 0.041116187276202254, 0.03720070148119703, 0.045194144040578976, 0.027881814712600317, 0.0568153231870383, 0.0221340256757685, 0.03901437681633979, 0.008201468408515211, 0.05435433180537075, 0.033336720734951086, 0.029653853707714006, 0.030369939013326075, 0.05043866789492313, 0.02906386856921017, 0.01368512615954387, 0.017536723244120367, 0.013152245574019616, 0.027152860566275194, 0.09332753426861018, 0.027778646908700466, 0.05892880020837765, 0.055885812907945365, 0.056115856423275545, 0.043673490872606635, 0.02756712925474858, 0.02647381214046618, 0.04505829761910718, 0.014680329495604383, 0.04156455208430998, 0.07819128397386521, 0.01353338757326128, 0.012474851209844928, 0.0014499706753667851, 0.06431701127439737, 0.0076687970158673124, 0.03292666187917348, 0.04777560454385821, 0.0310824044936453, 0.023810494603822008, 0.025691159898997284, 0.011087120401498396, 0.030884889310982544, 0.020773617034137715, 0.0171497173505486, 0.013775633851764724, 0.013790634511678945, 0.05879479431314394, 0.031734958247398026, 0.027091674201074056, 0.04948477435391396, 0.012890127363789361, 0.021147666884644423, 0.005564466964642634, 0.012451861330191605, 0.0578058602695819, 0.0607778017729288, 0.0181332596912398, 0.025814445471041836, 0.026744326823973097, 0.018404186266707256, 0.05841339720063843, 0.08557031731470488, 0.02684554649022175, 0.026738269043562468, 0.027946214577241335, 0.05792468182335142, 0.04022757304483093, 0.03208898866432719, 0.03437168648815714, 0.019216184882679954, 0.05890009393624496, 0.033200169273186475, 0.011660226318781497, 0.0204624679099652, 0.03319907089462504, 0.06096525343309622, 0.05332713633833919, 0.020187800910207443, 0.04964254010701552, 0.006931654197614989, 0.02856355713447556, 0.05687181917892303, 0.06628735398408026, 0.045609153021359816, 0.05322356963006314, 0.021897321385040414, 0.03837888318230398, 0.06416458898456767, 0.03495149307127576, 0.033862057389342226, 0.028939076437382028, 0.04316550934163388, 0.025294279730587732, 0.011415979024604894, 0.06929665891220793, 0.05867011350346729, 0.05176059989025816, 0.03673743434774224, 0.04352795200247783, 0.028530561248771846, 0.07153247526730411, 0.046256142522906885, 0.03261595804360695, 0.040395498799625784, 0.08321256609633565, 0.028146169570391066, 0.03767188361962326, 0.016074723862402607, 0.0688357035687659, 0.024658379770698957, 0.026580978264973965, 0.02323005348443985, 0.0162509839356062, 0.0511858250683872, 0.026186198374489322, 0.014510835953842616, 0.03184936031175312, 0.039298255724133924, 0.09531297226203606, 0.0723521105828695, 0.049297571313218214, 0.059574464976321906, 0.041329280138597824, 0.06418890174245462, 0.04145748243900016, 0.02566129402111983, 0.13741337723331526, 0.03478220918623265, 0.02941162969364086, 0.03213456024241168, 0.030732353843632154, 0.03506088934955187, 0.04022108296339866, 0.036271885110181756, 0.00865029520355165, 0.017155793684651144, 0.07921482436358929, 0.03190259827533737, 0.027255592358415015, 0.11005521635524929, 0.02625621073093498, 0.03870059677865356, 0.05070727340353187, 0.03814662806689739, 0.02040038540144451, 0.016541540317120962, 0.01980394357815385, 0.0538186607445823, 0.11726245735189877, 0.05127392170834355, 0.039896122470963746, 0.047572801558999345, 0.050321015223744325, 0.019950896239606664, 0.031096241837076377, 0.04889500072749797, 0.05815679221996106, 0.05482094602484722, 0.06355591656756587, 0.04748987026687246, 0.008023675800359342, 0.046950310352258384, 0.039696866951999255, 0.03735439655429218, 0.04310197036829777, 0.04466862556000706, 0.05574461189098656, 0.018410223638056777, 0.023448051942978054, 0.026093522683368064, 0.03427247989748139, 0.11405627548811026, 0.1476192139671184, 0.149025168211665, 0.18666173302335665, 0.2104912488721311, 0.13734848384046927, 0.1039476007281337, 0.07669765982427634, 0.1611026271712035, 0.09076833448489197, 0.13641971570905298, 0.1415025960886851, 0.12372616285574622, 0.12120732848416083, 0.09558583769830875, 0.1198397358530201, 0.11335934686940163, 0.1797444565454498, 0.14894149848259985, 0.1446980464970693, 0.12537876988062635, 0.07181872162618674, 0.1305965578649193, 0.21457527269376442, 0.1400815910892561, 0.1819843621342443, 0.13670930173248053, 0.11812617623945698, 0.1258416028576903, 0.16673555772285908, 0.11520970656420104, 0.11213841004064307, 0.1572323270374909, 0.13467176497215405, 0.11592171562369913, 0.08240035225753672, 0.14048117824131623, 0.16584827564656734, 0.19270789140136912, 0.18373569706454873, 0.1210433361120522, 0.09047878556884825, 0.17622143699554726, 0.09568627996486612, 0.09158940956695005, 0.11472233818494715, 0.09601884376024827, 0.21634011471178383, 0.09697446279460564, 0.135010659287218, 0.21343432454159483, 0.2884725050535053, 0.20674766303272918, 0.12301419090363197, 0.1847967752837576, 0.15274347650120035, 0.16428020666353405, 0.1461046835174784, 0.09730394667712972, 0.18904386379290372, 0.10716232471168041, 0.10893383121583611, 0.26405169046483934, 0.1462429011007771, 0.13409145001787692, 0.19279104162706062, 0.18521643010899425, 0.1483952481066808, 0.17911452159751207, 0.14730771974427626, 0.23832273669540882, 0.1357326057041064, 0.15117568953428417, 0.07213230870547704, 0.07472420009435154, 0.2078625321155414, 0.24820894526783377, 0.09816932797548361, 0.13429372978862375, 0.1688856931286864, 0.1632471222546883, 0.15396978647913784, 0.09670668849139474, 0.1462218092638068, 0.11863773121149279, 0.09406106561073102, 0.13988759368658066, 0.11629947621258907, 0.18377540196524933, 0.18711539305513725, 0.15366673789685592, 0.16850550571689382, 0.21519931498914957, 0.18001358897890896, 0.11829672919702716, 0.10767845131340437, 0.19156783382641152, 0.13673947745701298, 0.1277072582161054, 0.17048462061211467, 0.18551754910731688, 0.10906715062446892, 0.10991644958266988, 0.1200557008269243, 0.13058679120149463, 0.17887497117044404, 0.15305310051189736, 0.13570700160926208, 0.11399888520827517, 0.22662071540253237, 0.15362266916781664, 0.09355078713269904, 0.0802320490765851, 0.17436735914088786, 0.0946879800176248, 0.1469803584041074, 0.1191630307585001, 0.12185500076157041, 0.10450180692714639, 0.09514034871244803, 0.13265490444609895, 0.15834027930395678, 0.13585878565208986, 0.1816837181104347, 0.12940374843310565, 0.10285599055350758, 0.14356296131154522, 0.0978524234960787, 0.1504498245776631, 0.14634145831223577, 0.10656022030161694, 0.25009762204717845, 0.18887260579504073, 0.0993822718737647, 0.11198790249181911, 0.10129142450750805, 0.1730798665084876, 0.16072634345619008, 0.15849391871597618, 0.08810568673652597, 0.09381983050843701, 0.2091975073562935, 0.0972105325490702, 0.06631287644268014, 0.16625204851152375, 0.041231439099647105, 0.16349909623386338, 0.14456272328970954, 0.1666105948970653, 0.05950443221081514, 0.08230002131313086, 0.06606180788367055, 0.24962594266980886, 0.23549073084723204, 0.16164348955499008, 0.15755274187540635, 0.09683879819931462, 0.22393998893676326, 0.1370882720220834, 0.09239319260814227, 0.16851076012244448, 0.15313368290662766, 0.1538967146188952, 0.1644068319001235, 0.0891433130891528, 0.14912442304193974, 0.16079289925983176, 0.1620224746875465, 0.13126400095643476, 0.10650468539097346, 0.13093612011289224, 0.1473510017967783, 0.21483054180862382, 0.14213498012395576, 0.1095252858067397, 0.18495376920327544], [0.032358607204514556, 0.02534971630666405, 0.022521222672367003, 0.058820264821406454, 0.07755573096801527, 0.04257867462001741, 0.04084389700437896, 0.0346365255973069, 0.0439444601215655, 0.04120072531804908, 0.023065406167006586, 0.002153706527678878, 0.026528721791692078, 0.01401950636136462, 0.13011358299991116, 0.09347810118924826, 0.05556946875003632, 0.06041779706720263, 0.08528435297193937, 0.01343909214483574, 0.0008163527616034116, 0.0253818846977083, 0.04841787027544342, 0.05150736054929439, 0.025494017645542044, 0.06157675714348443, 0.03690321900648996, 0.09471908342675306, 0.032512921970919706, 0.05676342851074878, 0.0708943470090162, 0.023196645706775598, 0.038765597782912664, 0.0208392637068755, 0.058387744866195135, 0.050033032239298336, 0.012898675977339735, 0.050631021440494806, 0.06798047485062853, 0.08133317358442582, 0.037707970550400205, 0.05420480760221835, 0.004834618066524854, 0.036966694897273555, 0.022476947997347452, 0.016069808989414014, 0.03400903973670211, 0.023054101402522065, 0.0268474612312275, 0.015638678705727216, 0.036369692752487026, 0.06658657308435068, 0.08900046450435184, 0.014494979968731059, 0.03731501077709254, 0.04393002534925472, 0.06468879015301354, 0.03749077732209116, 0.026194002057309262, 0.05557919459533878, 0.0222600442066323, 0.06172323483042419, 0.027854750442202203, 0.027047620314988308, 0.034582549196784385, 0.03417226027522702, 0.06834846135461703, 0.02211395800259197, 0.033913213628693484, 0.03664422802103218, 0.010007955115725053, 0.052038270732737146, 0.006529462107209838, 0.017676439965725876, 0.03018597544723889, 0.04651203504181467, 0.02431696957501117, 0.01926704240759136, 0.03354445529112127, 0.03653219340776559, 0.03379015441169031, 0.034060195976053365, 0.037776170211145654, 0.025624719128245488, 0.036683921789517626, 0.029364195324887987, 0.05923237942624837, 0.02053760108537972, 0.05403543837019242, 0.062117248453432694, 0.029779708966088947, 0.00662864596961299, 0.023902585853647906, 0.05115135973028373, 0.061627787217730656, 0.027366445101506542, 0.07537058103480376, 0.024238365003839135, 0.0488882880017627, 0.08947384339990094, 0.08455063609289937, 0.07474601181456819, 0.034568548580864444, 0.0555529411212774, 0.028388091159285977, 0.03836165422399063, 0.03852260750136338, 0.04149435604631435, 0.009847049150266685, 0.04879983884165995, 0.019941806785936933, 0.029919238295406103, 0.038617836180492304, 0.06549372352310456, 0.07651744410395622, 0.02385787887760671, 0.0447320457897149, 0.029945232017780654, 0.030809956515440717, 0.026325421567889862, 0.05093154300993774, 0.04794448766915593, 0.0030296033628474106, 0.029880683723604307, 0.02725100588577334, 0.03770750299736392, 0.04504710974288173, 0.08583691902458668, 0.03458345832768828, 0.02455598565575201, 0.011286770186416106, 0.05165540045709349, 0.030797859508311376, 0.010643106434145011, 0.041562733822502196, 0.023275398707482964, 0.027765599952545017, 0.015826596063561738, 0.012505894319474464, 0.06268528086366132, 0.027689605885825586, 0.0348242926702369, 0.068923410581192, 0.05186602567846421, 0.0399914105219068, 0.022814755066065118, 0.01154767591287964, 0.0773735782422591, 0.03499065249343403, 0.027502621778694447, 0.040454599729855545, 0.02385050007433165, 0.03859964243019931, 0.05224088075920008, 0.04100982267118525, 0.05877579533262178, 0.05109203986648936, 0.031176469856291078, 0.031965365415089764, 0.0718513538595289, 0.045794842080795206, 0.02862021268811077, 0.02495153181371279, 0.029871488513890654, 0.041678694396978244, 0.06073643446143251, 0.07836153265088797, 0.031083475041668862, 0.04760257281304803, 0.013066314149909886, 0.039550300207338296, 0.01461565410863841, 0.07081195377395488, 0.03144407717627473, 0.026161388377659023, 0.035335691791260615, 0.012586585253302474, 0.03150833974359557, 0.05287743937515188, 0.05385465861763805, 0.04114847441087477, 0.041957189023378305, 0.07043112811516039, 0.016067688302427996, 0.02675372983503621, 0.03352507410454564, 0.04924608481815085, 0.03501634193526115, 0.040054519049590454, 0.039581110468134284, 0.01703913734672824, 0.07773334917146713, 0.0711362945730798, 0.05171824181161355, 0.04105765408894513, 0.004385424372230773, 0.06019198379362933, 0.04252616396115627, 0.04177347778750118, 0.036692653156933375, 0.05923119198996574, 0.06348143462673761, 0.07986144279129803, 0.03127494914224371, 0.026888631873589475, 0.05870141729246825, 0.016550802320125513, 0.029732038965448737, 0.03420587585424073, 0.032758710149209946, 0.03841345984255895, 0.05964878735539969, 0.029854515596525744, 0.051425728015601635, 0.027474817215988878, 0.03835464834992308, 0.04304100293666124, 0.053530803925241344, 0.03885331221681554, 0.032761886541265994, 0.0307928963957238, 0.07008579937973991, 0.09558726262184791, 0.06012890866259113, 0.047562634135829285, 0.006470061998697929, 0.04123285289097112, 0.007135679870771128, 0.03378853281901684, 0.024844523395586293, 0.012643058980756905, 0.0410519729484804, 0.02482468949892791, 0.007460681181328255, 0.006347999578792951, 0.03428981275646947, 0.05271051180898212, 0.06579361055628397, 0.05379853741033003, 0.01931992228492163, 0.03407596661418211, 0.04756386610097252, 0.054483792046085, 0.019043323845835403, 0.026112627419934142, 0.03893919725669548, 0.03978373533755075, 0.06219549308298156, 0.007368937813225784, 0.041794324715738185, 0.006679185298708035, 0.05186540227441583, 0.01208237197715789, 0.022910013431101106, 0.02682810416445136, 0.049355547889717855, 0.06047226328519173, 0.05167692645045463, 0.04136826886679046, 0.03929185098968446, 0.02897606693295529, 0.021431601453514304, 0.05059451890701894, 0.024475475620420184, 0.0301827415387379, 0.056550031367805786, 0.024758155959716532, 0.024308021129400004, 0.019395239141886123, 0.04294265352655202, 0.05607267827144824, 0.03870216271025129, 0.02084677980747074, 0.02052368210570421, 0.04316598431614693, 0.09895208597299643, 0.05493797900271602, 0.03763713626540266, 0.027545914963411633, 0.06737105286447331, 0.03251556401664857, 0.06514155960758217, 0.02176764221076155, 0.09097842907067388, 0.008624517631687922, 0.0400751136476174, 0.029727207584073767, 0.026044713486044202, 0.04142244935792405, 0.0596472585311858, 0.021013096957176458, 0.017058171579265036, 0.05393891093262937, 0.06996042837272398, 0.011742508231691318, 0.02150200158212101, 0.05123702583659906, 0.039422298286808655, 0.04216732813802082, 0.048964180023176596, 0.025455377726757433, 0.031463888808502816, 0.011405437744542724, 0.04428244530572556, 0.0390499405330047, 0.023350886258413084, 0.02635453231050633, 0.0422320693905931, 0.022376412962330505, 0.018369377685303334, 0.06329776049824432, 0.01342049021332059, 0.04910134004603606, 0.005738514046242926, 0.014932204212527722, 0.03180824904120527, 0.04365178305306472, 0.036200483082211576, 0.03878752082528081, 0.02412409652606584, 0.014922947775630746, 0.027783146178990137, 0.005747091418015771, 0.027762603531300556, 0.009467551008128794, 0.019586167763918638, 0.018342079638387077, 0.005631485219055321, 0.007874555140006123, 0.028898722157464363, 0.052880177900078706, 0.07015811424935237, 0.01468286207455094, 0.09175619983579963, 0.059678721881937236, 0.1378419081447646, 0.020064062628080137, 0.04912754156976007, 0.08972599549451843, 0.03651209975942038, 0.07959035108797252, 0.018682387744775042, 0.04016147737274878, 0.02731678800046211, 0.028229570270923432, 0.041509852089802735, 0.021078129502711818, 0.036255127415643074, 0.012246115729794838, 0.04962317747413181, 0.014631897865911014, 0.05420597648480907, 0.15732306201243773, 0.14244950230931863, 0.14809163549216464, 0.14095389662543312, 0.20440646912902594, 0.10433311676024459, 0.23673642572248355, 0.09663495249697007, 0.12043041118886322, 0.16163363383384421, 0.09736135179991834, 0.15584102278808132, 0.10208236097241752, 0.10616800267598592, 0.20266981387976557, 0.23319209169130772, 0.22284739912720397, 0.08362287728232332, 0.12295013613766059, 0.10377094731666148, 0.1884952385444194, 0.21666845568688586, 0.11745940850232728, 0.15523747861152515, 0.13268754410091788, 0.12756932264892384, 0.14639428438385949, 0.15067567495862022, 0.12275345216039568, 0.2040647843386978, 0.17474566149758175, 0.05798324469651561, 0.14575533976312727, 0.15434011816978455, 0.10589389785309322, 0.11672903870930895, 0.07016717587248422, 0.1998881998588331, 0.17265938047785312, 0.2180120992125012, 0.16528267005924135, 0.17377745563862845, 0.07670887367567047, 0.12120271232561208, 0.17191557039041072, 0.18105314491549507, 0.1964013822725974, 0.16289466148009524, 0.14362809219164774, 0.12854083848651499, 0.08643687862786464, 0.1459917434840463, 0.2699152211425826, 0.061206328973639756, 0.12869180616689846, 0.1141353439015802, 0.20292263390729204, 0.09034439746756107, 0.061086438727215864, 0.11863683321280405, 0.08300807472551242, 0.14313443040009588, 0.10359670588513836, 0.19846361770760268, 0.16532886133063585, 0.1378181594191119, 0.23977360571734607, 0.09360512718558311, 0.14699247025419027, 0.15182248607743531, 0.18272829096531495, 0.08762437428231351, 0.14694644225528464, 0.13841880921972916, 0.1021500893693883, 0.12502423109253868, 0.08396099976380356, 0.1162180255050771, 0.13383874873397872, 0.11591111033339985, 0.09291709691751748, 0.16436809179140255, 0.11670595791656524, 0.12524261546786875, 0.11551726740435697, 0.18365817231824622, 0.18831327877705917, 0.10976689198287204, 0.12311662954743952, 0.23350941919488832, 0.10176626543398015, 0.06033150384610053, 0.06851468759123236, 0.20648886129492894, 0.18066045973682776, 0.2191201553796418, 0.14524147671181709, 0.08930181356845424, 0.1762812986271456, 0.14640507521107793, 0.16097327083116397, 0.2239954867400229, 0.132442872854881, 0.2216255123494193, 0.05928211445279885, 0.1300203544087708, 0.19011686090379953, 0.16889977909158915, 0.1320883637527004, 0.19728817453142256, 0.12381434484268539, 0.18837354116840288, 0.12167833992862143, 0.08856192202074453, 0.14342584210680798, 0.05963281262665987, 0.1477378685376607, 0.1480067931697704, 0.11647688661469147, 0.16525112878298387, 0.21851083729416132, 0.17914683470735326, 0.09139971662079915, 0.15119636576855555, 0.12991657247766852, 0.11228185234358534, 0.12598387256730348, 0.18049662321573123, 0.09450458790524863, 0.10575401043752208, 0.10146644519409165, 0.188619667023886, 0.11907364649232477, 0.12071500255842693, 0.1320771870086901, 0.12065154893207364, 0.12585049378685653, 0.08372086304007098, 0.08394113989197649, 0.20249070395948365, 0.11663730925647542, 0.17827078874688596, 0.16862355172634125, 0.1422210395685397, 0.05505570959940087, 0.0600501259759767, 0.07409868092508987, 0.1664047676604241, 0.09980985283618793, 0.08693907511769794, 0.12210085202241316, 0.1812758931191638, 0.09932922315783799, 0.15813419973710552, 0.0939364664372988, 0.1445679331663996, 0.10304941650247201, 0.24601347948191687, 0.14165973843773827, 0.19630086579127237, 0.0832282922056038, 0.2096462988993153, 0.1023964601336047, 0.12887152464827523, 0.1663472066866234, 0.11620977282291278, 0.1566453475970775, 0.13893650175305083, 0.10110524934134446, 0.10481336794327945, 0.1175627822522074, 0.14749057008884847, 0.13891468261135742, 0.18192862684372813, 0.1264265933423303, 0.12471739755710587], [0.026451519879628904, 0.023193797715066466, 0.050543919278425165, 0.05792467811261304, 0.00997729885057197, 0.07074522727634758, 0.031942989662638865, 0.009053257272171322, 0.025674726894067135, 0.024798324702715036, 0.017618049641896505, 0.05629136321658734, 0.03239868688979186, 0.03841287725663278, 0.06018020962073933, 0.03793047755607404, 0.06027233612257987, 0.05351970510673709, 0.043527302623260766, 0.0485157855291618, 0.12517524330178276, 0.024777251419436652, 0.03837168434984051, 0.02659948371729115, 0.009758681626408361, 0.019435728863754775, 0.03413470389205031, 0.04008105825050734, 0.02669152858288726, 0.02209170655987691, 0.041213275035261177, 0.06486102036433294, 0.025226436300727073, 0.05602024553809315, 0.016620048409095034, 0.16412269324064255, 0.08593227015808225, 0.009409542890352895, 0.015380332461063517, 0.14768669003387913, 0.014002806183270877, 0.0615133999963291, 0.007165525339587475, 0.03167656235746108, 0.12333111022599041, 0.02813053251884412, 0.03269840693974402, 0.07924652149085887, 0.017513473612780217, 0.013938566808064934, 0.025362073065480217, 0.06804734977777116, 0.04320764106523711, 0.014842547207081225, 0.05397206266934518, 0.062285931198857725, 0.03180798557878006, 0.06936796446098015, 0.006598211421078304, 0.03445896305493079, 0.024915986650739796, 0.023072133735695388, 0.09965340068447404, 0.02178438320697751, 0.01349108237263863, 0.07954503555083647, 0.03594932917621918, 0.013489388420566684, 0.0635290211357642, 0.06045816247933544, 0.014523534100590041, 0.03789974893152248, 0.07664860386285, 0.09677837253548205, 0.04615893973095808, 0.03691789126605727, 0.07053657987853512, 0.02855108348740032, 0.03271838926593773, 0.007198194680313463, 0.07678869165829383, 0.01832715319324052, 0.021561095090874005, 0.033695337624521926, 0.08272506413049996, 0.037380716821644455, 0.015623080616933294, 0.010067543080367614, 0.055575428195879795, 0.0349260114307981, 0.04767052756506018, 0.030011218223080505, 0.06774644600227475, 0.07722043606918305, 0.051865765926777385, 0.09217878614435904, 0.039342324453173205, 0.027254041269770823, 0.030112469430605415, 0.008769406194915064, 0.08155021467246115, 0.04339263621659484, 0.02575264126789989, 0.06281636640778743, 0.0325504375359742, 0.018928764075099025, 0.0018138646987608809, 0.06620320928050205, 0.015304025764635298, 0.0251789351386833, 0.029505149577744305, 0.03305541707959492, 0.0423038647568319, 0.023818535773898475, 0.017876599049486686, 0.031749886547913775, 0.10430408394313417, 0.10034032515250146, 0.04646077490178868, 0.030283265441539697, 0.11181239198776893, 0.03242296625103336, 0.035214050076319836, 0.057865024282364175, 0.005658392710756743, 0.041526825007167645, 0.09168282369500957, 0.022192217475094367, 0.06504211924038827, 0.0547402560187038, 0.03082564737269422, 0.02030208423093427, 0.06603329456993379, 0.056548858774476685, 0.012481120502343401, 0.0214676772520761, 0.052536775037879124, 0.05860897166712675, 0.02991516019392293, 0.04500334900512826, 0.04800331029400695, 0.017462894393247552, 0.025968147965613753, 0.020849748398177326, 0.03454807272646576, 0.017853807694336865, 0.03267662861617282, 0.0444644050730858, 0.017197877168655396, 0.015397969600599026, 0.059214757129666395, 0.03612445005273912, 0.012649171494558686, 0.04336623431299813, 0.03218988735170569, 0.059120448713656515, 0.03658811423520092, 0.030198846143321134, 0.05498180653376039, 0.023627325135748833, 0.024931245206971653, 0.043804980887216516, 0.07186506132711656, 0.029113162017893046, 0.036508192351902835, 0.028066800587112084, 0.007816938505129656, 0.022288936015684158, 0.029508570878533646, 0.04219527370878495, 0.03423059679334983, 0.04746357226395048, 0.0622167964320397, 0.045265635126270354, 0.03486556721327361, 0.05631163869111333, 0.01545586361316964, 0.024323719408130273, 0.048523325749556534, 0.06019985055900179, 0.09824982131249271, 0.05084259661089163, 0.03818803990725428, 0.04987867294403259, 0.036221597183612175, 0.024543858962715603, 0.07531917988671921, 0.041512824391247705, 0.026592962094582617, 0.05549527624680195, 0.04627264046575874, 0.05110561003675684, 0.02118755175615661, 0.027755180199164897, 0.046256120258476585, 0.0430042517837137, 0.014479493202088634, 0.026727739823400043, 0.037586948528769426, 0.03122036789136473, 0.010663958928489592, 0.07795443496434018, 0.014768107939744368, 0.043261294631520286, 0.034048581364913844, 0.03273850517871324, 0.018240193894598633, 0.024861609490471892, 0.02198099853558233, 0.042749498461489566, 0.047013726871227846, 0.049638885029708035, 0.058334900240879506, 0.017873083124868572, 0.028246973633940797, 0.0990448692755308, 0.02385013271123171, 0.08737520562135614, 0.021817752021888737, 0.02367911220062524, 0.021086339511384722, 0.06820267386501655, 0.03178851162374485, 0.044894420279888436, 0.05094326894322876, 0.04779213217261713, 0.0270233650735463, 0.0383025904011447, 0.04599901432811748, 0.03950779740989674, 0.042095150565728545, 0.012899778066639556, 0.02300307318364503, 0.0766238383948803, 0.030526537739206105, 0.010859792218980147, 0.05786800400528591, 0.021375122159952298, 0.04070653289090842, 0.029966958391014487, 0.031304007934522815, 0.039850836619734764, 0.016161475359695032, 0.02398677508608671, 0.027532363346836064, 0.016401009088440333, 0.029103421329637058, 0.039053020445862785, 0.0390095936745638, 0.011292234248685418, 0.04588202587910928, 0.06557250992045738, 0.06769565341528505, 0.03729338088305667, 0.06489781604614109, 0.06072584401408676, 0.023199938987090718, 0.023084618514985777, 0.014201069079717854, 0.03364845986652654, 0.04737365365144797, 0.07085180710419081, 0.034628592038643546, 0.02897975911764661, 0.014070136603550054, 0.07101228169631213, 0.010448255561641417, 0.04074365882843267, 0.011478148735477589, 0.02870049822377041, 0.07857561999117024, 0.01641108374315081, 0.09524314358714037, 0.05019349198846612, 0.027932247357966844, 0.020971332596673165, 0.0743314778083004, 0.04519981404882856, 0.037426102862809785, 0.0686207998660393, 0.032714274057070725, 0.014815678678132826, 0.06934689488844015, 0.13153199048247188, 0.030508139898302034, 0.02283721431012964, 0.0076272135538602015, 0.04304881033021957, 0.013861881616321625, 0.03648379795777146, 0.04479568495298736, 0.04271919657185208, 0.055070162925403565, 0.03108270506345434, 0.02526137475797441, 0.06756856804713607, 0.07626347374753095, 0.06477531715063378, 0.05413932049123105, 0.04840844128921162, 0.026251559320371598, 0.013538491693907417, 0.0681091558362823, 0.06173054869577754, 0.02801214883220382, 0.03223406369215809, 0.09960235576727428, 0.00616546232777182, 0.037991708450135775, 0.02742650525760837, 0.030886477507010568, 0.03299182986665983, 0.0645207753404975, 0.03640949784312397, 0.03563669204595499, 0.027839386129926424, 0.00835990673294873, 0.02232020826340886, 0.028409607875801157, 0.017404426143912133, 0.008874176110111875, 0.04662337574700359, 0.047692654698039405, 0.02361784419917967, 0.005409551986303995, 0.030692797372466885, 0.06055932833987754, 0.029937339277239516, 0.009992518444050802, 0.02223607098130742, 0.04055724246427417, 0.03301210163044743, 0.033578067159396596, 0.026031920715468004, 0.04636318619304802, 0.02541670070058899, 0.03688220138428733, 0.0472262037510518, 0.03573965761461295, 0.06516513021779247, 0.014166979453875683, 0.03089493613515515, 0.020467434733291157, 0.05470972406328656, 0.01759864990162896, 0.016972412704490125, 0.030656649214506615, 0.021396880074462388, 0.07865355291869491, 0.013845607245457359, 0.014283206273830729, 0.06283509079366922, 0.08520582632627338, 0.07836867953301407, 0.16821531113237143, 0.13409294915618375, 0.268578672548756, 0.1559329600422643, 0.15137523820158094, 0.13524872541893274, 0.11558063197298907, 0.0987673134659417, 0.14648426236817613, 0.2002587096649222, 0.09211895419866778, 0.08778686009463854, 0.2161734431865625, 0.09221127736964263, 0.07009984823525883, 0.1242541267129127, 0.07711724043474533, 0.13666140352142975, 0.15718113369075581, 0.13041422702372074, 0.11399731927667744, 0.07548203677288257, 0.07885965474997647, 0.1856177390436642, 0.0817765474494081, 0.1509776696912013, 0.12833838060032576, 0.10240007439278997, 0.18130980926798657, 0.13918856478994712, 0.10582087794318795, 0.13133143249433488, 0.11945998630835675, 0.23472542816307396, 0.14844503137283027, 0.11615190756856464, 0.10282683157129213, 0.27251814084593207, 0.13049613044131547, 0.17055907286703587, 0.06327574839815497, 0.088489800109528, 0.16634420841000974, 0.1979888361529447, 0.099570680904435, 0.1484982285182923, 0.11521671985974535, 0.11609551918809302, 0.07557625242043287, 0.11886041262187064, 0.1369270181749016, 0.2067355511826463, 0.22804945358075202, 0.14072626509005204, 0.06637056358158588, 0.16596097819274291, 0.118877815984888, 0.09072983186342753, 0.12269289290998131, 0.1815948385046795, 0.15011513081844896, 0.09664546130807139, 0.07400255795801058, 0.1838872881489806, 0.15390535321785137, 0.07962506875628605, 0.1503915511420928, 0.10667488953913562, 0.12332609330769628, 0.13514553720597178, 0.23306975606828928, 0.17929150897543877, 0.1335172652034089, 0.200960113434121, 0.19698613526998088, 0.21064365631900728, 0.17436361871659756, 0.11798351319157518, 0.12617074535228312, 0.12212981804623269, 0.1788516974193044, 0.13086573482723907, 0.17692235094727948, 0.20724534726468846, 0.1345555149600841, 0.10508480845601298, 0.1606863713823259, 0.3052871668478474, 0.09414089101483114, 0.14328008430311456, 0.14161494240397587, 0.16043663868913427, 0.12928599928272888, 0.16713179036742076, 0.2733992482535541, 0.13299739075591788, 0.1731530125834979, 0.07597527554025874, 0.24860045785317197, 0.17224692448507994, 0.08393891344894655, 0.15606866916641593, 0.12592445622431114, 0.11848965048557147, 0.1292349395225756, 0.2228339365683496, 0.1099406584398821, 0.09011460628244095, 0.12754242721712217, 0.1376085472293198, 0.20594923087628558, 0.11957845534197986, 0.09383836935739964, 0.1534039285616018, 0.31705106841400266, 0.1398140171659179, 0.10934105506748892, 0.06768305916921236, 0.10573179053608328, 0.13880428072297946, 0.16198757890379056, 0.14564415119821206, 0.08914291232940741, 0.08817213121801615, 0.24352689884835854, 0.10407710549770854, 0.1431500748731196, 0.13334237068193033, 0.20528109016595408, 0.0949196339934133, 0.09117897963733412, 0.09390168197569437, 0.0927193665120285, 0.15606262808432803, 0.22671652666758746, 0.11761482906877063, 0.12345020266366191, 0.09782705688849092, 0.07269951733178459, 0.15104897523997352, 0.13310332491528243, 0.17155120556708425, 0.10324773320462555, 0.17098847951274365, 0.25387859728652984, 0.1401083974633366, 0.09579293400747702, 0.12429332695319317, 0.1640820235479623, 0.06725305138388649, 0.09717064211145043, 0.1142369958688505, 0.08775410169619136, 0.19511326623614877, 0.10275434600771405, 0.13200577755924314, 0.09221530723152682, 0.11676535199512728, 0.1376511761918664, 0.17202563089085743, 0.13455165579216555, 0.13873716088710353, 0.1359416835475713, 0.1061465842940379, 0.14106063230428845, 0.11565175940631889, 0.11196168241440319, 0.16096875857328996, 0.17574511177372187, 0.13662827404914424, 0.19367623084690422, 0.17375113908201456, 0.19901015009963885, 0.10219678530120291], [0.05657430330757052, 0.04233008483424783, 0.04783562573720701, 0.03902611388184596, 0.04349776885646861, 0.024393735475314315, 0.019556672959879506, 0.03121295383607503, 0.016465943299408536, 0.10679871687898412, 0.04806459313840605, 0.03026481565029826, 0.002960446331599087, 0.03858326323097572, 0.03195706078258809, 0.07654615037608892, 0.03250834663049318, 0.023671109993301798, 0.03526279062498361, 0.06356492624036036, 0.10854081949219108, 0.059467681057867594, 0.06880534230731428, 0.025018839041877072, 0.03326472869957797, 0.015549652525805868, 0.028411346356733702, 0.012399237493809778, 0.0184472456749063, 0.01837716652516974, 0.03493820862786379, 0.01317121857937309, 0.07131253980332986, 0.005798433658128488, 0.03424017420911696, 0.05286960229568649, 0.04205554214422591, 0.1010804987163283, 0.07251377261127345, 0.02763194472208852, 0.0699721320415847, 0.017744600663718302, 0.01150739584772964, 0.05864568942342885, 0.048839692171895877, 0.02080271478916984, 0.028095664565626066, 0.11837363796075806, 0.053025494125904515, 0.03910318591806572, 0.07269031470059417, 0.048862171825021505, 0.04892591488896869, 0.061715527626802213, 0.036501353461062536, 0.05218787657213397, 0.02708244188397657, 0.03488163842121139, 0.08334868340170942, 0.019708770560100675, 0.07243456318974495, 0.04926354013150558, 0.08568707198719494, 0.07852596289012581, 0.05752365861553699, 0.05867376487003639, 0.04311775213864166, 0.0053772783030581195, 0.035710168376681395, 0.024797256010060664, 0.03549160588590894, 0.020956610242137685, 0.08044047383009456, 0.03744201821973547, 0.00855139660416171, 0.00983753110631369, 0.016722943473723717, 0.052408832489163615, 0.026815988603630103, 0.04985783343727235, 0.00802398379164515, 0.020077851731912233, 0.08206818180042319, 0.016367285898013506, 0.02714327387366211, 0.01042615625920007, 0.07061703610816039, 0.030312322378449608, 0.04533223545877263, 0.05380312759371009, 0.04421480596647598, 0.015472568429686362, 0.013056733951088972, 0.03943167903344147, 0.03397134605620522, 0.08395560435019433, 0.001215463953485596, 0.06935851692105643, 0.014598730358557077, 0.019350495058461092, 0.029246325575513765, 0.04032706536236219, 0.09737304062582552, 0.07490128395147622, 0.030324705112434458, 0.04066877612785902, 0.04436205548699945, 0.03867481085762847, 0.017592495642020367, 0.012236343500262592, 0.04353079442807939, 0.020918087211612146, 0.08012466030777432, 0.058945524506270885, 0.007477064555132529, 0.0800124327361118, 0.028894144961668644, 0.05712977857911028, 0.028892688496853225, 0.01499229498222121, 0.04287764510081615, 0.018931992417492438, 0.033627111988607794, 0.036120668810326606, 0.0777812028536573, 0.04541378635622095, 0.10841902563697658, 0.030561986422981136, 0.037897986330790445, 0.02734696929110214, 0.01971185418369714, 0.0016079622037068475, 0.03960452522733249, 0.050202330967294984, 0.06142163343611173, 0.05941370465734508, 0.023180481730378233, 0.09205725946230814, 0.05241168604698032, 0.06674149641185068, 0.020651505910791457, 0.08578307621064596, 0.08127460328978486, 0.01551384482809226, 0.03472752032394055, 0.04016129925730638, 0.0710184860508889, 0.059507263504201546, 0.05501694722624961, 0.014440872764680535, 0.08049181560636498, 0.009750488316058181, 0.0687249973998405, 0.04722013298305683, 0.035691726006916724, 0.04217009263811633, 0.031595746186212637, 0.04834526225749869, 0.0194793894115719, 0.023834328676457517, 0.01624471649847692, 0.018515875781304203, 0.04636537552869413, 0.03833687020232901, 0.03427415344049223, 0.024051221334957518, 0.018574783753138036, 0.09301651502028108, 0.052063114126212895, 0.017960780860448722, 0.047677874827058986, 0.044482520897872746, 0.06879569438751787, 0.0774874682247173, 0.02327174363017548, 0.058265194020350464, 0.016834510533954017, 0.04883169924141839, 0.032672836241545156, 0.03135626255243551, 0.06578139480552636, 0.04150015964114573, 0.03915460933058057, 0.027918170671910048, 0.04628827009582892, 0.0794202285760548, 0.06091293202189263, 0.05466907663503662, 0.04388535919133574, 0.05437798405182548, 0.031116296522668563, 0.033495028255856596, 0.05624454854114447, 0.019681466947076842, 0.03614137844124343, 0.07009849752648734, 0.042522965304669924, 0.009922465269482927, 0.03295880800578743, 0.050495100804255344, 0.024576246287324466, 0.01003143574052956, 0.0075415929040900664, 0.031127922266023234, 0.018684057577047497, 0.02237179309304338, 0.05151416604348924, 0.025173042486130726, 0.023019031214062124, 0.048094375524669886, 0.03041618037968874, 0.06906881957547739, 0.04361968887678813, 0.009200978056469467, 0.12014260631985962, 0.027430256814113818, 0.06519866787130013, 0.018239277342217974, 0.03055087276152335, 0.010517195514694322, 0.02274085571116302, 0.044352819459163584, 0.007979418751347112, 0.020844686951022595, 0.047191211488097906, 0.04396730713779107, 0.08093636206467636, 0.07876094168750569, 0.031302493953262456, 0.030307841661851853, 0.03717118626809679, 0.027541267263586633, 0.03594121750211343, 0.08782130316831172, 0.023018663850962184, 0.0436338379222434, 0.04605536931194365, 0.015958861622493714, 0.013417038298939588, 0.020846629522566218, 0.02591603250039043, 0.03435042395722121, 0.03655711843748577, 0.013152984938642476, 0.015336461328843143, 0.05881106590095442, 0.0164849404245615, 0.013643725451402133, 0.02431634802633198, 0.05727042669604998, 0.05512184237886686, 0.05541109072510153, 0.008891964462236501, 0.06020866356266197, 0.030547126771125477, 0.010930017015198246, 0.08939303836086765, 0.020231040289218072, 0.05784445194876753, 0.0026287367018085206, 0.01089395884264377, 0.058685932381195016, 0.02676794752915157, 0.07014674454694614, 0.03875432084896602, 0.02980140008730814, 0.033268621264141984, 0.045045369406579994, 0.02609367853438016, 0.0112603460183891, 0.036320573708508164, 0.04046115660457872, 0.023088930392987095, 0.03136442246614024, 0.07290578243555501, 0.021647985740855802, 0.10411305513116531, 0.012873324212705484, 0.03953514926251955, 0.02836922762071481, 0.032591047856840305, 0.029723261213803198, 0.03589075888157822, 0.03294572394224815, 0.054380629808292724, 0.016479572841490153, 0.02861051652871538, 0.01324919603575836, 0.04132490146730561, 0.02779030975943897, 0.04943459774949588, 0.07302788057131693, 0.029561968403868377, 0.057510941915097646, 0.06529538455652073, 0.03676775850181002, 0.05344369063095655, 0.02809976678690873, 0.010944092773570446, 0.015330846053984715, 0.0441248799324967, 0.09721674432512373, 0.05288981097692158, 0.04712603236839641, 0.055729353334754705, 0.060277479205979034, 0.04183860495686531, 0.021863277215743437, 0.05803601510706358, 0.00699661113685579, 0.06918750383192673, 0.12760227400576696, 0.019359655016160104, 0.03197138423274737, 0.022618837356276345, 0.11548361100722104, 0.029401697902358137, 0.07974592750542797, 0.04013698278868105, 0.04323264402046334, 0.015507610787608428, 0.03750399497221224, 0.05552534064918291, 0.013701471962122014, 0.021931510273134336, 0.01667639040533686, 0.08641000546049327, 0.027539424881979357, 0.07001797450357117, 0.07630956853972748, 0.023513175401603803, 0.022252787857723888, 0.03489490060019307, 0.018712585733737797, 0.029795782029395923, 0.023260732014023233, 0.020996289167669602, 0.01341238132226863, 0.0160702988068806, 0.03111978090601042, 0.02984402348374715, 0.03473759126791265, 0.011921433542738669, 0.02521635607990902, 0.0446901070245076, 0.013781908710370772, 0.021565486749750562, 0.058931638923240826, 0.11692516607581638, 0.05270830020890571, 0.05501581916178111, 0.07674296793993562, 0.13728611374972388, 0.1615461939945817, 0.0990012903639581, 0.1550752154435031, 0.16244892758550122, 0.151628548046574, 0.10435976728331298, 0.1757275080308318, 0.17581638763658702, 0.27293344668578357, 0.19779892056249082, 0.1238126156385988, 0.20165529800578952, 0.15085000544786453, 0.11419295682571828, 0.12193927163025364, 0.1433882597484626, 0.0861460309533868, 0.19008104485692456, 0.2717738557839766, 0.19203004339942709, 0.14005840639583766, 0.18563157267635688, 0.10236417670967057, 0.11805248097516596, 0.09337318377220072, 0.127293570258189, 0.10089433097164147, 0.09772765362868086, 0.12870307196862996, 0.1479378476506099, 0.08348657444003038, 0.1948596743750386, 0.1213013289088849, 0.15062517923070118, 0.17491745384177193, 0.13079484488116577, 0.2748861559666693, 0.22940624796319753, 0.14424845343455672, 0.2614144538529217, 0.14715667784912512, 0.08684679647558369, 0.180537307751365, 0.14372624864336103, 0.08155574367265217, 0.11417616202379577, 0.1953114938805811, 0.13815834507113323, 0.15173060819506645, 0.22590642794966698, 0.1069927068601828, 0.09306065054261126, 0.17392808193108067, 0.13089686050079763, 0.13925044506322592, 0.07224147120723501, 0.24249734706245363, 0.22525323409354314, 0.07528824717155658, 0.17280006199143827, 0.2513248077593744, 0.1876736810663715, 0.24416692700469866, 0.17170030303532258, 0.14366978604812175, 0.13024590793065727, 0.13694244000362232, 0.18883983255364, 0.11523666136781685, 0.10521581236389466, 0.11812855111202225, 0.1634575062780641, 0.219807309913449, 0.13531165954191238, 0.2083975909044966, 0.09179410873912275, 0.14622425835113972, 0.1602207330870442, 0.18424181209411472, 0.15806886105565354, 0.13395683927228674, 0.29463078710250556, 0.15124417492188513, 0.21087952569359913, 0.19250440935138613, 0.13892585935536772, 0.17741950083291158, 0.12318914479692467, 0.1847180927870795, 0.11272168616415001, 0.07594572321977466, 0.1259152387501672, 0.2273331326432526, 0.15896411379799247, 0.168977006978821, 0.08163464139215648, 0.15444734366610646, 0.11167062693857588, 0.14198876218870282, 0.26137182489037514, 0.11797852595918812, 0.16150773590197787, 0.13484216207871214, 0.14250752341467887, 0.14019910275237635, 0.15699893643613905, 0.17461157025536522, 0.13770008372375742, 0.12661256070714444, 0.11122602852992713, 0.0795625131286215, 0.14733267074916512, 0.1455432636430487, 0.177644134091679, 0.16590352111961693, 0.1665687674540095, 0.11829223920358345, 0.13811653247103095, 0.1885949238203466, 0.15660895267501473, 0.13388057617703453, 0.10431863745907322, 0.1482613052939996, 0.10613450955133885, 0.207272628613282, 0.21020831249188632, 0.14322549192002043, 0.14135002536932006, 0.21334449498681352, 0.1323956425767392, 0.061255915570654906, 0.14757686702068895, 0.14648966520326212, 0.1742227145587094, 0.36539305408950895, 0.12976199795957655, 0.22400339803425595, 0.06706494663376361, 0.1539996505016461, 0.10534320943406783, 0.17053959891200066, 0.2010530896950513, 0.12322041147854179, 0.16060553665738553, 0.10104808912728913, 0.16178210789803416, 0.1130459675914608, 0.17204408068209887, 0.09193077523377724, 0.2491322363493964, 0.09243470092769712, 0.14324036455946043, 0.10987993591697887, 0.1555389241548255, 0.1264889634330757, 0.10563885138253681, 0.08735426221392117, 0.11816135403933004, 0.09580471931258217, 0.09433131126570515, 0.0654078199295327, 0.1724086978356354, 0.07311373221455142, 0.08899127671611495, 0.14490844536339864, 0.12013344079605304, 0.10502155520953238, 0.14536155620589852, 0.08217995666200295, 0.09001150712720118, 0.12341334761003964, 0.18050974438665435, 0.11327417800202966, 0.1441275278921239, 0.15340188023401424], [0.05088725905807223, 0.06297812491538934, 0.019284727786725853, 0.03915932567906566, 0.026927720791718457, 0.00534372627043922, 0.043503787674126215, 0.0629460641357582, 0.10327387906727381, 0.036643652856582776, 0.025933777251339052, 0.04630969589925371, 0.021656952740158886, 0.06792177839088254, 0.008091900508588878, 0.05958457673841622, 0.03203795487934258, 0.027582230104599148, 0.04226542521791998, 0.05408365570474416, 0.01595824935066048, 0.03700046261656098, 0.05456141327158548, 0.030400003415707033, 0.041322051620227285, 0.05334299603418913, 0.04803034673386719, 0.014480501595244277, 0.05417201580712572, 0.05082055111415684, 0.06219640592462383, 0.024674916676303837, 0.025978619669331238, 0.03529752684698906, 0.008392944364459254, 0.003341351075505372, 0.02725878915953217, 0.045603998805745505, 0.03796627504925709, 0.02072631996270502, 0.02074645999528002, 0.04248865952831693, 0.0560909239720786, 0.040548217948526144, 0.042229842947563156, 0.09534110708045773, 0.08145595449605025, 0.06597429382964037, 0.017542586210765876, 0.02550689019699348, 0.0601757901313249, 0.04489429782552179, 0.028428508521756157, 0.016931952668528538, 0.038935761112952605, 0.05945979202806484, 0.0270782747247722, 0.04691954833106138, 0.054630343947792426, 0.06538637928315438, 0.06617936407565139, 0.036696567985927686, 0.009007890712382505, 0.05938899113971274, 0.0245597724642721, 0.11661155673209578, 0.04955295175022911, 0.06674584539723583, 0.033109386058640666, 0.052640449357568286, 0.04020752021460794, 0.028945714948349632, 0.025204016019415576, 0.007152252956075245, 0.010149262816412374, 0.05702994116290938, 0.05176260368898511, 0.019531963152985554, 0.030506432958645746, 0.0530868920031935, 0.030320395089802332, 0.023676503551541828, 0.040869115182431415, 0.006633770035477937, 0.043196178594371304, 0.04506304736423772, 0.02090301419229945, 0.010316319330740953, 0.044378779784892686, 0.04957173550792504, 0.03151661469019018, 0.03390497207874432, 0.03273599300882779, 0.0066744606010615826, 0.030936735747673083, 0.09555503114825115, 0.09152422673651017, 0.07476866216165945, 0.026198712839686777, 0.06153155663923826, 0.043763398352894, 0.04767973761772737, 0.015345881965913577, 0.011969575734838145, 0.031184707695501857, 0.08284564828500152, 0.04014158039353788, 0.03549038876371924, 0.13323152350494638, 0.04157728733844124, 0.04452490495168604, 0.09795882520847954, 0.07106805409421213, 0.023327697854256257, 0.09005291896755807, 0.055349321773974225, 0.02642451127030654, 0.0224590102880029, 0.07108995487214997, 0.059553384271566756, 0.0901026205974631, 0.03610172920161858, 0.041454228121438064, 0.07180442044045776, 0.03990246412286069, 0.07976336797582917, 0.03658254812762607, 0.08009277764358558, 0.012502869140007533, 0.009998028890549904, 0.05468723327794578, 0.03811874186794739, 0.027688891568686813, 0.05582101599429734, 0.01147355855209753, 0.036468027319642715, 0.06029512747772969, 0.05233243209659122, 0.05579051372478716, 0.049939963209908456, 0.03937971756386105, 0.03596767506678589, 0.11540679872268811, 0.05596259550657123, 0.03078953446674859, 0.055286639981204644, 0.09744299546582624, 0.03876405782648362, 0.05833925664774142, 0.028140764879935887, 0.04116417083423585, 0.043166054820176214, 0.03382951421372127, 0.019824193077511154, 0.06290451128734276, 0.0744420949195046, 0.04042155560455285, 0.015190953072306002, 0.03749654380953871, 0.05333370434527751, 0.05808831425383687, 0.027564286829147022, 0.11937937422771938, 0.07762237582937814, 0.04570812212477904, 0.03082572529820027, 0.07375060624326579, 0.04200985924398992, 0.04442971709067933, 0.05333199740562122, 0.012354178925306769, 0.018601107731228694, 0.021634118711517658, 0.021430868582683615, 0.05742236287915148, 0.035033285166719, 0.02337541609449545, 0.023826510150684044, 0.024864318329491653, 0.017500764333817642, 0.04021483407996129, 0.01759936050802935, 0.05708346114261076, 0.0724683902808465, 0.022326937687466852, 0.03819793273578398, 0.012353597267065197, 0.005506992729351623, 0.06476952097727917, 0.009012370501295663, 0.05104050513182301, 0.16839523741509765, 0.0431379496876616, 0.029163271829020232, 0.03819696794380434, 0.03753093122213613, 0.03972618549596518, 0.06337935221381485, 0.012368594216241036, 0.051525795497582294, 0.023571224337501917, 0.013881643153581535, 0.035026134573854506, 0.03127623305772431, 0.0419382234395016, 0.04165731312241405, 0.05410578283772338, 0.027072643679275643, 0.004523240268099471, 0.060067944941692986, 0.023083861524355598, 0.0347834819694981, 0.07381307281320915, 0.03241551137762144, 0.007179586255006143, 0.06328937422949821, 0.029572451239801012, 0.02770902789052343, 0.025112726289080456, 0.04019883708679117, 0.03380768765055109, 0.03223815292585641, 0.03064982516661985, 0.05438314197817817, 0.04426631843671203, 0.02467461981723318, 0.028199045736982953, 0.011001175989804324, 0.02066994085907936, 0.03291011569672264, 0.04020857406430878, 0.025810493534663692, 0.02801314702082891, 0.005157660107215634, 0.03506853347062133, 0.04879426160186995, 0.056946460681501776, 0.071331761428155, 0.04389640234876424, 0.018646610660653096, 0.06737338320817798, 0.02825705385475885, 0.024177670311473776, 0.022425365023082122, 0.07098065878381021, 0.01628972775506554, 0.059158869698876515, 0.053781297319801524, 0.05463709378091153, 0.033991239324677736, 0.03244683000957593, 0.020822652586502954, 0.0671176020114217, 0.028735937630699482, 0.03447798058914486, 0.06796674511861056, 0.034889067319454625, 0.028818048849643674, 0.05479632156493608, 0.04572840131004341, 0.03457528357103001, 0.009523558110231534, 0.022131036676000804, 0.030219581749406643, 0.05174279576749541, 0.015628132787242066, 0.024008840991882607, 0.0151003897190094, 0.11040441910154186, 0.0067337299060454825, 0.06598711072001606, 0.0786711715045385, 0.049514486236148514, 0.037180741419433616, 0.04583203110087197, 0.05302872246829793, 0.041289356304332614, 0.0447110207460355, 0.021206621240708046, 0.024940058210631832, 0.03557544630893972, 0.07911643042461947, 0.020827702901442535, 0.06002841815643478, 0.15867584879742935, 0.007784442641423084, 0.03442318040470127, 0.10092376454849727, 0.03848136264423374, 0.13092703622533008, 0.052712010947288945, 0.06651520816376433, 0.07775225167279132, 0.08000912275747396, 0.037065407959744334, 0.032984653298626654, 0.010735034411482047, 0.07325012411456555, 0.01675380568485707, 0.04796399131009821, 0.04292837460525334, 0.055740485549904406, 0.05745292080973741, 0.04545634852547664, 0.009522526524960995, 0.013961519580334425, 0.035643679366330616, 0.06630263480474241, 0.011993522057309747, 0.07086037148837931, 0.03713499172590673, 0.1049982888798695, 0.012249627943674568, 0.039190900351968594, 0.06568889351910912, 0.030946064543968532, 0.019740005700441543, 0.027288467645121273, 0.018905972719949204, 0.030686370373587124, 0.045537439291365445, 0.08307304233312607, 0.03137883497402072, 0.05841999489348382, 0.033104313479270786, 0.03480922707240097, 0.009922379922500113, 0.0474660473264521, 0.054932156854192726, 0.07179419364547357, 0.016619117013760842, 0.049668307474348694, 0.022854068483866286, 0.009629650903661968, 0.05177195846044924, 0.047038618504302576, 0.053683983205701225, 0.07323778219870292, 0.07337087896303274, 0.0355524545739172, 0.03450407079071738, 0.06748221916495822, 0.04370652757643256, 0.017588144801266026, 0.06965797350858338, 0.03591060762119014, 0.059349883667891845, 0.016123690766107757, 0.05822764505865052, 0.03621328141889535, 0.024192619021050632, 0.03069836904614931, 0.1130691151774954, 0.14061672409297898, 0.18853699177270755, 0.10885790950851515, 0.08990771035314538, 0.08550423648557626, 0.1374630120699294, 0.16911246377276257, 0.24174749589292333, 0.13768918899586424, 0.10965976296574809, 0.18443776876665652, 0.11751083191484213, 0.19534300547093153, 0.1274660008493811, 0.31698377046268433, 0.10437642107717693, 0.1869755279039964, 0.08739697281271219, 0.21487245830940083, 0.10722646111389622, 0.1497314849984832, 0.19594818237237632, 0.10734777999459766, 0.11979677292401902, 0.12209764594445005, 0.08759744916460477, 0.14610104699386284, 0.19767683726968244, 0.12156418277299963, 0.11573531039175577, 0.10893825441598892, 0.22241883852984756, 0.13816000748192891, 0.18883204000303522, 0.08239805902121589, 0.10750663670478389, 0.15443702781340107, 0.10953980963677168, 0.22038278606487438, 0.06923157998244278, 0.06872522746562026, 0.1621172172599472, 0.09654808411141858, 0.13251438620500267, 0.1968230854254216, 0.21459758165292442, 0.0995528619387187, 0.14379157248185948, 0.13477011438226327, 0.1581573102157563, 0.12314791107201017, 0.11821969426819123, 0.062126428820192814, 0.06879973167087883, 0.17484102747403085, 0.10030551842646673, 0.13436672743409872, 0.1509705005446449, 0.18679175729630515, 0.19056192686548457, 0.2161140862153843, 0.09706245182314888, 0.10903554255492054, 0.10753389578894712, 0.1751686114585027, 0.11927266081329435, 0.150004951574374, 0.12235754606081173, 0.18449212366249412, 0.14922060538083315, 0.11599332545301877, 0.178033524134662, 0.10469352593645453, 0.08891966688679531, 0.13240057043731213, 0.18153111770516261, 0.05223658743489068, 0.08372067008167505, 0.18680432927794755, 0.1362685699132271, 0.12417891004588455, 0.21732099645305425, 0.12275196044356562, 0.1148318346531596, 0.07054291039821692, 0.11439032357884571, 0.11860476501169614, 0.16906692559132352, 0.14650550263468176, 0.1376939981128089, 0.06652265932643786, 0.22063054464524612, 0.07269559137057513, 0.26212172058876604, 0.2229574299417436, 0.2152741828467697, 0.15936640236759558, 0.2423989531234838, 0.1680525581468828, 0.15514481405261904, 0.17951033863937482, 0.06260218258830719, 0.08594090875703841, 0.1737992005655542, 0.17691344517515972, 0.16159755061380565, 0.18609710707096383, 0.2200112075661309, 0.1187170074263122, 0.1753272084170021, 0.27832416992168874, 0.1624335057567805, 0.22619034396484494, 0.17379427270498127, 0.13138275942765176, 0.1512177544645965, 0.195444620330818, 0.18278398172697052, 0.09627610925235786, 0.12199971213703975, 0.09951024781912565, 0.17978761985432357, 0.15686144615756348, 0.1732741013984196, 0.24161868874216452, 0.10686571797123179, 0.19723098463146016, 0.1149608199193608, 0.18134451209334657, 0.16492730006575584, 0.10818396520335227, 0.09387304249685258, 0.1628676027758047, 0.055010123178362846, 0.10867525954381563, 0.11249719391344115, 0.14922976348316297, 0.15595218166708946, 0.1429950402234681, 0.19727465260075405, 0.09044621270732023, 0.24882541765691712, 0.1080902319517918, 0.11131774313980713, 0.200023582438007, 0.1797057461226359, 0.11629611428361386, 0.08244174183346331, 0.12242287732078694, 0.17209482874022797, 0.1284983431105502, 0.12589808029588312, 0.12034130893880501, 0.1382139467750676, 0.22810750437201932, 0.14833801367785782, 0.07775010686600581, 0.17278499639360234, 0.21490319806616753, 0.13748245633905753, 0.13836933765560389, 0.15973447792930529, 0.17775748972781003, 0.09813590906560421, 0.10188920961809345, 0.16483361134305596, 0.13543072971515357, 0.1441566794528626, 0.12709330912912264, 0.13068500702502206, 0.07543373038060963, 0.10045264178188518, 0.16966147493803874, 0.19038115453440696, 0.13035893702181056], [0.019265897644800134, 0.11809658681158908, 0.025365364490426145, 0.025351710828545038, 0.03575294576876331, 0.07513150558224879, 0.04296546343539376, 0.0661416481307242, 0.0819713760574814, 0.01952015001734253, 0.03345252545841504, 0.015779946515976917, 0.04748670129629318, 0.05368770878703799, 0.024895716742321383, 0.026422231021570042, 0.04989761255274061, 0.010114769647771027, 0.02771782976196846, 0.03709936121595092, 0.036692170760943554, 0.04412842739839107, 0.037164399327593856, 0.03343088072142564, 0.014574185679521179, 0.01844508973590564, 0.016637735643598717, 0.0611961170216091, 0.06003504553518724, 0.06898585488670506, 0.04482728189032059, 0.044299596338532865, 0.02770374936517328, 0.035364026989554986, 0.01862723318481585, 0.04361058272479568, 0.04909562921966426, 0.08238169466494583, 0.05697546381270513, 0.038415185335907154, 0.03840512552415021, 0.02150857515516691, 0.07760069769574329, 0.05069690560048912, 0.06380908540450037, 0.017112350215029437, 0.04057770347571932, 0.001942346232226555, 0.04085538173967507, 0.014325915017252555, 0.03079867772612488, 0.02321816427865997, 0.027314431681588758, 0.052508087319438346, 0.0595351385709364, 0.01763734733685851, 0.010337794301449321, 0.042022175184683874, 0.03730423850356601, 0.038244521056185476, 0.03838706164970063, 0.016529623280803207, 0.06079380618757568, 0.07350640255026519, 0.059086777473567054, 0.022265832958510146, 0.052838610208709724, 0.03118784326943569, 0.01654139003221644, 0.01504054942415678, 0.05263210019620601, 0.057191662563127466, 0.015433303251484176, 0.010685350407584338, 0.016928184413700365, 0.014058783599466551, 0.05258233177301008, 0.02233578408777248, 0.016230346664087847, 0.059484297744347714, 0.05358958202123176, 0.03326844314869959, 0.017590081806702074, 0.02573296136688441, 0.01917843739647651, 0.07312404064578004, 0.020289068816055078, 0.045699891707045026, 0.041088404977926984, 0.06491931606433354, 0.027030575038224924, 0.014403702298295684, 0.02754166431259364, 0.030402048032556195, 0.0398798211972462, 0.026017096315626986, 0.0436575421190355, 0.0405431602121098, 0.04843524395255372, 0.07087485821102746, 0.04670060734497383, 0.014025947275513317, 0.04442888588528149, 0.04331321528297849, 0.06224818556802347, 0.020597188122337684, 0.05736170343880076, 0.02298158244229853, 0.04142422680160962, 0.05002804500691127, 0.022815816337242723, 0.06727982065058313, 0.063576028769603, 0.07858648503315635, 0.09816936508286744, 0.054013808476156555, 0.06903692948981188, 0.031166009284788743, 0.026131060512852855, 0.08467136867693625, 0.08975450138677843, 0.007555877391496324, 0.05652706189721357, 0.027915252176171634, 0.08180816294043325, 0.019952582770201843, 0.011921155237359926, 0.05113673942105379, 0.05495056953805033, 0.02700680404814193, 0.05949554870312568, 0.023705656967649702, 0.018490806032787077, 0.06662165440502577, 0.03689393102831673, 0.04734932605060749, 0.04590941854985431, 0.03767989881453104, 0.03347484554979019, 0.050691384021774866, 0.037399790016934276, 0.048955734382616356, 0.011152606584801106, 0.02867258790502092, 0.015719005059509072, 0.04653503048757557, 0.02033298726018984, 0.04171851433056872, 0.024925270918174647, 0.004388580819068011, 0.021006840652262326, 0.07971312457812019, 0.022425164643209428, 0.08836730863549747, 0.014483056438621134, 0.01843953476054594, 0.08171851150109433, 0.07617382230819203, 0.06518711263197474, 0.035847372928401455, 0.024749300282564946, 0.03748573813936673, 0.13267414091387764, 0.04955940101353917, 0.04084908090590034, 0.03358963724167552, 0.019727014405361842, 0.022794507422077004, 0.03331612242618576, 0.08566143820644356, 0.04951610782882199, 0.025206541176885366, 0.038283042231341824, 0.02612762436910998, 0.08157641248544678, 0.05574691625952255, 0.05688115539669525, 0.05806961213238537, 0.024936412410170306, 0.03966858370404225, 0.02479048020177288, 0.05698709326679818, 0.060113364379503764, 0.04281682980945334, 0.0355569037492387, 0.060908805680810474, 0.0568513989856001, 0.02742207649134798, 0.036270575219532475, 0.10761985875433311, 0.034718926253844984, 0.07929182218504138, 0.01726075934129767, 0.05854486495081801, 0.025408865476492792, 0.06609489282709546, 0.04065212604473345, 0.030560986378986854, 0.07127067525289021, 0.03875805385177955, 0.021807707053085323, 0.022363009775290266, 0.029316567997739185, 0.04544834446278401, 0.022200408930075355, 0.08140672041918151, 0.04151761495450046, 0.06919280276633799, 0.028040660290571395, 0.04372475101263262, 0.016557290546188597, 0.02621670992084546, 0.04511578808887862, 0.013566706293204334, 0.03315668313007336, 0.03929254860850051, 0.016431413023383357, 0.020878048344457056, 0.019936162752856035, 0.02597216112917522, 0.07114088846719824, 0.04300586966564879, 0.022642997973889578, 0.018761931132758036, 0.025878637534333393, 0.019039045364479534, 0.022438909218180925, 0.0389892551174853, 0.021748112594650593, 0.011709704376698937, 0.09737805012264289, 0.09365920748678036, 0.016220338802668266, 0.05150857767148409, 0.018133343182853423, 0.022568504900846165, 0.12724307453026995, 0.04362620864412747, 0.04497262409131508, 0.03756535203137901, 0.07194749166956171, 0.004927012205371284, 0.025622926841606386, 0.029155549782444723, 0.053343693653005175, 0.03461649874225259, 0.014298220849013887, 0.016427049195044674, 0.05103236006107181, 0.08197038900107145, 0.050771621317835525, 0.028847551075159572, 0.06867257950943895, 0.011767776504711946, 0.02307082941115368, 0.07834865638869815, 0.04205638819257729, 0.049308473462588154, 0.05719251603295561, 0.04222623982059304, 0.014387638511834666, 0.07159799206419848, 0.01809128010791028, 0.023603366753377486, 0.0350157779030269, 0.04765734702232294, 0.05666520897648297, 0.034181414666818455, 0.011601569749473128, 0.041877293115248904, 0.07473246761946939, 0.04302718414692208, 0.1321131069562398, 0.025325255119241774, 0.04915111589070875, 0.04377663826744538, 0.021651765127899125, 0.02737013728619786, 0.025773668166948482, 0.06200745883688796, 0.04945552260323893, 0.02223669067461742, 0.029903573413321283, 0.04573352212901227, 0.02934353207820095, 0.030969555373303592, 0.029990204311616253, 0.05508299465873279, 0.0865205706213601, 0.027348854346200824, 0.015230414919642499, 0.05338296068657655, 0.029785735205223318, 0.060132712169433944, 0.011051104902435327, 0.05040434356487822, 0.05566995925619267, 0.009980971553886775, 0.034661721510929056, 0.05923330711084418, 0.093516626075143, 0.016797089592728298, 0.022684385694446974, 0.07782176122418605, 0.07774335332214832, 0.01874420493550133, 0.029867475350329187, 0.03303810277429875, 0.06967592606088147, 0.03647173805802595, 0.02334267624974018, 0.03592643763113301, 0.04224846343277022, 0.0642108841566369, 0.057720275799511, 0.042137497512158006, 0.05616494207060896, 0.11952191853197291, 0.028366134720272385, 0.06034635051037185, 0.05018709838623181, 0.06938088525203057, 0.014379371914401418, 0.022643834745394997, 0.038460044452222064, 0.004521781020230264, 0.053448132384801283, 0.029032546226517297, 0.08159755627275445, 0.03369183839822654, 0.018059415997413453, 0.07945294244564138, 0.05975876250886358, 0.05708890108508058, 0.03800544189289212, 0.07101142080500722, 0.021953038121864665, 0.056743809836916625, 0.09234847078914754, 0.016811828645586502, 0.031084232032299042, 0.03382522088941187, 0.008381172974623041, 0.018556356226326898, 0.0068412828750297194, 0.03640947557869367, 0.05354593260562979, 0.0595498776237946, 0.017800102177716326, 0.00564415367989568, 0.008135313364618924, 0.034478774687158875, 0.10565294476691633, 0.19862202170770615, 0.09074064495507628, 0.17844719724962488, 0.12436609453288838, 0.16417501465184614, 0.1510689835413359, 0.14995792909758165, 0.13753032486420125, 0.10533758395467885, 0.1006214358494617, 0.12356878301943652, 0.15341516467742622, 0.1832308288430795, 0.17479364876635373, 0.1321136116166599, 0.1394718128722161, 0.129824620380532, 0.20852092100540176, 0.14188855740940198, 0.09693997519207187, 0.10847957746591419, 0.1638753354200162, 0.08735055889701471, 0.11524861736688763, 0.20386171789141372, 0.24592062196461484, 0.17017557547660545, 0.1353616951382719, 0.10027537980931811, 0.13250929507194087, 0.15461106144357473, 0.078206735488493, 0.13443338713841513, 0.1412044753669761, 0.21437266637803987, 0.2168526715831831, 0.1595216745045036, 0.07685128439334221, 0.13503317604772747, 0.08208977829781361, 0.10807768965605646, 0.14635690982686356, 0.12539840710815042, 0.25081133062485605, 0.1245528188883327, 0.17037289770087227, 0.11103086595539935, 0.16494310781126842, 0.0995307756238617, 0.1095400916528888, 0.08477952185785398, 0.08143951592501253, 0.12155126940342598, 0.17034147516824305, 0.16866232152096927, 0.19045140623347834, 0.15639086515875533, 0.13077884417725727, 0.11117985952296294, 0.24624624667922035, 0.09622542056604289, 0.12111148753319867, 0.1801911849179305, 0.12838641239795834, 0.1258042876725085, 0.17674110364168882, 0.09041780329425819, 0.13492179452441633, 0.1284944245708175, 0.10942887340206653, 0.13094490714138374, 0.1455037368577905, 0.10385120316641405, 0.10130034512258135, 0.13851324009010568, 0.3370781906414777, 0.07901446675532497, 0.08641963111585937, 0.20455961872357875, 0.18528516782680526, 0.13661328266607597, 0.17944127437658608, 0.07564030718640424, 0.1247508981032297, 0.1726772217079997, 0.14426779380301014, 0.10715744137996808, 0.08070378782576881, 0.1285995720536448, 0.14075541665079072, 0.08334786703926511, 0.0864543933130335, 0.20012718625366688, 0.1393984441529028, 0.16437517188023776, 0.17963537567993626, 0.09994427804485895, 0.16329163627233356, 0.20969891716958955, 0.18855069181881845, 0.1493683669832535, 0.20005119033157825, 0.1638056625961326, 0.17454401997383684, 0.15541464410489425, 0.14954829326597974, 0.15090241591678932, 0.09118820453295484, 0.11912371177459136, 0.09455201856326312, 0.12947325798450038, 0.15328380453865975, 0.19155778514686972, 0.25094919197726995, 0.16900531249120831, 0.18347371893469244, 0.17381252953782678, 0.1039311102067586, 0.15117790113436058, 0.19748822785913944, 0.1813801351818256, 0.09239019433152862, 0.17027343506924808, 0.16950706369243562, 0.11143676136271097, 0.08735281502595171, 0.13309962901985273, 0.1590136595768854, 0.118754099967191, 0.15000263607362285, 0.14174217620166019, 0.06046750240784604, 0.1626110274810344, 0.06964426604099572, 0.09641641969210468, 0.10979398037306964, 0.1144726129132323, 0.18272296234499663, 0.106389214633964, 0.10581194990663789, 0.17968174506677315, 0.08692878152942285, 0.14591484214179218, 0.07818574013072066, 0.2142350870417431, 0.13411836029263213, 0.11561451843590476, 0.10295583168044686, 0.09559433528920636, 0.0796356592036318, 0.13885746302548796, 0.09783059693290852, 0.2441041116253473, 0.09826093126321211, 0.11998160480288789, 0.20334343163995072, 0.10695372926420532, 0.08496803478919901, 0.1352326653432101, 0.11498520689201541, 0.17584181361598894, 0.18119890271918848, 0.16937083506491035, 0.1358326175250113, 0.12821087962947786, 0.08877908185240813, 0.11994580359896645, 0.1114875242637936, 0.17790578567655757, 0.10350185199058615, 0.18102285044733435, 0.08419113233685493, 0.12925128161441535, 0.15766992699354887, 0.12082430606824346], [0.03450988922850229, 0.03126048468402587, 0.030070042703300714, 0.038535487474291585, 0.07908203187980689, 0.02904225908423541, 0.03636081295553595, 0.054717535167583264, 0.06893532947287895, 0.06420998615794815, 0.05774566838226747, 0.013819927080476191, 0.05878479016246274, 0.006230183635125286, 0.016478344587085303, 0.032458663554280065, 0.03877992865454871, 0.01631606101000216, 0.06965851527638733, 0.011919560547539731, 0.013977725302538602, 0.023681436978222337, 0.030331577399920207, 0.03619114686443936, 0.05603029050689656, 0.037427616844070144, 0.00877016596859903, 0.026178057014476508, 0.08033203121158294, 0.057027662769542076, 0.03945452604966704, 0.06830063735833392, 0.032431987056043, 0.05423857532150578, 0.07645124453119934, 0.06493549488368444, 0.04960642349033151, 0.024046124635788146, 0.050942575035151094, 0.024456484061374795, 0.05823530402267352, 0.07339816031162627, 0.01695162329269806, 0.013524416863219813, 0.0224742150385282, 0.04671100483392365, 0.023738489580864552, 0.012003446427115705, 0.047470184799749404, 0.03631493338616565, 0.018938039065687917, 0.035942757458542474, 0.04807290148164611, 0.02188106835092185, 0.03231040471291635, 0.06497254289570265, 0.028033650705765467, 0.026984903270204086, 0.04516569009865634, 0.027815921275760047, 0.025542665425746236, 0.027661452513711993, 0.07125146104954183, 0.03716267012350727, 0.1242490133154206, 0.02419643737084698, 0.05364491655200254, 0.016330505059158895, 0.013390298718150007, 0.011247558813920477, 0.026607430263538845, 0.09799451509024948, 0.04322263615904376, 0.03695424536999781, 0.12324562965659425, 0.03373952509718947, 0.10989903879817575, 0.09540480561554432, 0.03626686448114924, 0.02318190108780982, 0.02913984593760688, 0.03937509398383554, 0.05769935836724471, 0.019985452490800526, 0.01001556491246447, 0.018344129821343813, 0.06648454262176529, 0.048841721945791505, 0.046703501720912755, 0.06144879233033862, 0.014699253333674278, 0.04005400696769357, 0.05337337213859428, 0.0440671371325152, 0.02736467693466693, 0.030504379064950626, 0.013455353528115666, 0.024542797691538, 0.03236966149415821, 0.02391078287473647, 0.0918220951280091, 0.03633111220551655, 0.03653332889371086, 0.03172798576997593, 0.049667517087073065, 0.07435115214320831, 0.01970124889339786, 0.021615546465909574, 0.041793693890213035, 0.029487913197954185, 0.04847005067858845, 0.00686955406308698, 0.09851343216723762, 0.05575635266723111, 0.06813360218075104, 0.03370908962097019, 0.057475675057503395, 0.07683709452976473, 0.03128966964141, 0.06571664242073894, 0.05101103444758337, 0.03365775155543815, 0.025907870731316507, 0.0256542621718836, 0.05419059918494895, 0.005559413866649265, 0.07142790665966459, 0.008783338162174914, 0.04647170673706569, 0.01564281432365533, 0.02129834141669562, 0.03358172223670408, 0.027085508809250314, 0.04376789947855286, 0.01426249942596769, 0.08673236472532153, 0.016566459780733567, 0.05805469125334639, 0.02990153807331808, 0.03716214319865685, 0.012544614019134315, 0.015358632062998367, 0.040989825502038, 0.029044387192698196, 0.010163984243263258, 0.0148397641532938, 0.004898551769656478, 0.08320636916323565, 0.06377719531883486, 0.017060889695130754, 0.034130165659007616, 0.04031775511975866, 0.04945023851178121, 0.01688701377133839, 0.025596116756787524, 0.1043936240603216, 0.03469489551207516, 0.07681663351831958, 0.029549583814514335, 0.01970767589227762, 0.02801513226586394, 0.02496646196959773, 0.06106129476393107, 0.03859849210130051, 0.06965993277844973, 0.008769280029810034, 0.0604623333492782, 0.035063015602645464, 0.04272528589353897, 0.05056349342339672, 0.023108918285288382, 0.037709966927650385, 0.01894833636470139, 0.042778909773915075, 0.046251207240857184, 0.06630020056036301, 0.026051782442664262, 0.05919586947129574, 0.029316649633983616, 0.027462512407510076, 0.05127758049638942, 0.026660100484150462, 0.042935911114909686, 0.020659673245972954, 0.004822188484467915, 0.04979934106813744, 0.04441905242856592, 0.029337958549149334, 0.04525805779849179, 0.05429105629445985, 0.01868454182840651, 0.05178109429834876, 0.05672501865774393, 0.01831908790336456, 0.08199214877095073, 0.03520321100950241, 0.015756921384308953, 0.011200513145013247, 0.03667119766760152, 0.016500701785844285, 0.05650139100907836, 0.032292975374730304, 0.03131132179987617, 0.0400402995001059, 0.035529184533515945, 0.02926181234215619, 0.03088012101216009, 0.01480164188251365, 0.012774688148056157, 0.04756063033710234, 0.02519640158425318, 0.03890287654940039, 0.01081815680663567, 0.010292795104760444, 0.035087758806184866, 0.02601807780592935, 0.06739180331351236, 0.05317252842360176, 0.036300435531302355, 0.03122991562122479, 0.021683354643755592, 0.06645601446507499, 0.0025610641978346393, 0.029236545924504753, 0.010509720232221298, 0.039958318157005124, 0.028469391581893433, 0.04762451440910809, 0.045829314840375446, 0.0569684764923295, 0.061703538231085986, 0.07836545119062066, 0.03663712566776667, 0.031405867703142576, 0.04673195566283539, 0.03801006547291763, 0.046556474844692275, 0.05292721150908619, 0.021377068442234304, 0.044654187076957896, 0.05737477265938651, 0.043077646478195675, 0.004777709718837286, 0.0315284074167721, 0.007320959357457468, 0.02986611165397335, 0.0863144316826947, 0.06887793177156709, 0.06682092847768217, 0.03805307664151769, 0.04647975161788054, 0.028997474182688165, 0.07821993829566054, 0.10663228284101933, 0.041511228773742914, 0.05426671385066584, 0.05023434350732714, 0.02966510281112278, 0.06300256383838132, 0.07770868018269539, 0.04692910719313659, 0.014982717566454085, 0.01915478329465259, 0.047501618464593776, 0.01770321850926848, 0.03441700573603157, 0.04314541569328867, 0.03266467261710204, 0.07759094587527215, 0.07375515560852364, 0.02301302352861967, 0.02497101690096315, 0.04017430168460123, 0.010029874447354814, 0.05852454494743142, 0.008686912769917399, 0.03965824187616818, 0.03974104700319003, 0.02933351122919703, 0.037374887251644395, 0.014562642500095535, 0.02180074756324757, 0.08629551433841698, 0.027059691346948966, 0.03875973852700554, 0.07342472177697346, 0.034556351383798756, 0.008798249764367938, 0.06625597598031163, 0.04440692202479113, 0.05437519728729967, 0.04743285848235246, 0.04220117749355268, 0.08647667258628644, 0.06351763659040444, 0.025197195682267193, 0.02615455876366468, 0.012199719440104673, 0.053597445075865835, 0.03190485069353599, 0.04146170897001866, 0.030551219715562183, 0.05247844223049469, 0.015291139297914924, 0.031024446470837574, 0.0818063372571487, 0.009312472757301293, 0.04790772909473162, 0.06597290601348504, 0.029356942686717957, 0.022010471075191163, 0.050675717284320854, 0.053169274106039666, 0.02227701712399721, 0.03944215444789734, 0.08620161781436764, 0.0264873303603963, 0.026877271448029205, 0.05479200597619638, 0.026630494357959833, 0.027507362246979028, 0.03045956076675793, 0.03610559208027553, 0.077773744269507, 0.04615409721736796, 0.06522126626805402, 0.029256524539960083, 0.021325522575352807, 0.0020148474504821934, 0.025133189155894797, 0.03997376225015614, 0.04250474928994663, 0.025773304514586926, 0.03605361947847996, 0.038402335048886016, 0.05230267568549607, 0.0473313957627397, 0.03467898386588786, 0.04383428458822891, 0.031339950146502815, 0.03870065986120608, 0.014714435819769278, 0.12374951082165353, 0.09325317849288695, 0.094344536337303, 0.021796127693960443, 0.041130028330371715, 0.030909756824257784, 0.018931515587610193, 0.03639593880507164, 0.050991530806641094, 0.0953722772828769, 0.09438827109988779, 0.1631326533970423, 0.18976405874127522, 0.133738825970795, 0.1734508216031827, 0.1002362760482356, 0.13732391875237226, 0.14548703853506595, 0.11369282350642607, 0.24762625544099137, 0.24641268071718514, 0.1477238567895256, 0.1803488764562644, 0.15592458861647174, 0.2034771369653754, 0.24683521507540718, 0.16832304128911346, 0.12845691642723978, 0.21118794742505997, 0.1278351599466987, 0.1328474620822817, 0.13410713901976123, 0.16552662884350866, 0.16671908204443753, 0.15392824105219916, 0.08402227147598751, 0.1440174673916772, 0.1157976730610244, 0.11595494899665937, 0.1625302224420011, 0.10081116590299644, 0.14135421108221635, 0.1345990938716568, 0.20756982907187194, 0.20107430027564988, 0.10699553444283083, 0.09609836488380097, 0.14363422233145684, 0.11708003745297901, 0.15238077408866957, 0.22657514753518626, 0.10585974421701394, 0.14117916813120246, 0.10737502423580736, 0.1284460662282072, 0.15384997415822, 0.13967143575428054, 0.12313919825828634, 0.1292694642324932, 0.18085758900269866, 0.15322426945203915, 0.17534994782181457, 0.12585384829435498, 0.14751512033399194, 0.13266863417811692, 0.2744963503209874, 0.13316950964508578, 0.2545274421572685, 0.15932577720377594, 0.11500936379889026, 0.12874584936071187, 0.14181024598656222, 0.13512339151930064, 0.09740280074765906, 0.290089437039569, 0.10761993296910077, 0.15111392800463364, 0.1676351742935367, 0.1273604526068084, 0.13416541245533153, 0.13187579781515524, 0.18393701204331592, 0.12193449219921604, 0.08481314114760607, 0.2071398583939299, 0.109307398670353, 0.2001773554366082, 0.2701972075738013, 0.17837145365774632, 0.1368308358360082, 0.10989859350956976, 0.23727805993985385, 0.16429381765192375, 0.08716523720067926, 0.17308138048974797, 0.19932680967031047, 0.14209766493877396, 0.22413034981582314, 0.09820627950830385, 0.13479123590514064, 0.18128708470612764, 0.11939063260797411, 0.22766019712435082, 0.1703332076431252, 0.09629910098738037, 0.09496130558545701, 0.1394610368879512, 0.17314297874690965, 0.15777137858094648, 0.10325278723030351, 0.19243077345890924, 0.13730355422012508, 0.15068213164340705, 0.1476851463667117, 0.13019771286053583, 0.11214776852284558, 0.10455440293299034, 0.20409889344591647, 0.09687491852673702, 0.24269348185043782, 0.12512498506112024, 0.11182378395460546, 0.18344277137657627, 0.1309125346597284, 0.21620054641971365, 0.13158817106159404, 0.2094084702548571, 0.29365643626078963, 0.1654908127966337, 0.10816615365911275, 0.1857250535977073, 0.12056692183250561, 0.09408613535924815, 0.09255469878553413, 0.10154445233638398, 0.1066399269620888, 0.20618164184270427, 0.1233524692361243, 0.16009207436582074, 0.10127141620614566, 0.07686338140047155, 0.12435795317287557, 0.15299681603210047, 0.1936870810459368, 0.12568906182423234, 0.2069335858686827, 0.12485607527196407, 0.14712396397953853, 0.0883993916795589, 0.15196932741673663, 0.11828307367977686, 0.14014645479619503, 0.13418358023045585, 0.05750986580096651, 0.08857486507622525, 0.13797420338960364, 0.10467280517332256, 0.25068531394936144, 0.20497029356192797, 0.2142550953431055, 0.10247762882499956, 0.09707917241030373, 0.16429355047876015, 0.07692576633417048, 0.2000854181824252, 0.17502828617580235, 0.07344469297095202, 0.17222114227479324, 0.10566105644102208, 0.21613934892229736, 0.1252018567174673, 0.2156039487454109, 0.1404068892588839, 0.13016657234402373, 0.14000264141941443, 0.13020997314015403, 0.20069503312697634, 0.13269833492813632, 0.17949461995158345, 0.11221988301258534, 0.12322930240770802, 0.11409788028686307, 0.0779733300441876, 0.0950598627969157, 0.15436397079611197, 0.161805248062592], [0.05378500805818476, 0.024020693090278655, 0.032138193055288866, 0.036598470906028524, 0.019831213794532232, 0.04139771357586142, 0.019136383598379325, 0.04554749539238401, 0.04266600684786681, 0.012792201905540423, 0.061017174084554426, 0.030462445865850896, 0.04623056069249287, 0.04881553897575941, 0.02834065493516391, 0.05904014462430496, 0.07408115139696747, 0.040313688150490634, 0.05188880590139888, 0.048449125824845396, 0.031249207750079222, 0.04818217159481719, 0.016291818756144494, 0.025466764127486385, 0.05824651787406765, 0.058505646156845614, 0.03936315653845668, 0.056358765068580396, 0.009763238413142972, 0.022274425173236523, 0.02362360326515045, 0.06563302464201115, 0.00602093417001015, 0.004989295093764667, 0.06981834420002997, 0.018758118349069264, 0.03218369041860569, 0.019225675096095074, 0.05432218938949518, 0.042915182930300944, 0.008408331868849928, 0.02147010964108631, 0.030996387722552754, 0.056172270778915845, 0.08733655457035638, 0.0459728499117773, 0.040158297269954346, 0.07221176303573884, 0.07798629536409862, 0.03980090121331159, 0.03114826453384012, 0.004988982000213582, 0.016154705117514823, 0.06694717521895654, 0.005403665827543591, 0.05809252223116346, 0.03614070679759607, 0.02136624050763203, 0.06133446819148958, 0.021655794989783317, 0.012418764326866949, 0.025343604720546864, 0.02812407026794972, 0.023336878221016377, 0.024304406870214734, 0.0638660675031133, 0.08678209604113363, 0.05633799977658782, 0.0274318097581272, 0.031876990469754674, 0.06886891467729583, 0.02988977688801242, 0.02245456667878898, 0.06693973147775978, 0.014175635678839171, 0.06715953335515223, 0.05160920547496062, 0.0217072109808214, 0.033716945254127495, 0.04110571928322315, 0.047269508067984134, 0.044176759765832685, 0.005540131014640792, 0.0481062350445427, 0.07447621886967681, 0.06958031517569907, 0.02788521560432855, 0.03577776318707038, 0.024691668804734945, 0.026810630297404714, 0.0396871856355574, 0.0384023387596244, 0.018683632697502617, 0.036571620003087446, 0.01900545204989612, 0.014708805701957317, 0.081365137884859, 0.014014110947755398, 0.012200017226859927, 0.034397019699099474, 0.010161836653423961, 0.007724330071141594, 0.0640471292717848, 0.02142787958291592, 0.09102230484131724, 0.040667911525815725, 0.018518920442147646, 0.018260063043271657, 0.014646613726654323, 0.04790237078850623, 0.03225053194910288, 0.07499434184865095, 0.044481441073003225, 0.050881192000815645, 0.06809617567341775, 0.04335845660534687, 0.11359335345332511, 0.09397557761985809, 0.04644429180189036, 0.044403541542124, 0.031054304927238263, 0.03724376831087284, 0.03513662923069205, 0.02074850275675999, 0.05205887646297924, 0.0012448193729142076, 0.05853277907590382, 0.03230700196581893, 0.03724372749275062, 0.010601278063404607, 0.019851520810334478, 0.007935583798825974, 0.045262777857715264, 0.026362553071521688, 0.038182195494300686, 0.02747960592387244, 0.05414005892816931, 0.06746160972397774, 0.05117891567351762, 0.003090594450441131, 0.021277910091157537, 0.04517224326264113, 0.03671751881483942, 0.012993902801099466, 0.05348771112039685, 0.026791020900418516, 0.04429238637385424, 0.0034792720316545456, 0.0373766127449926, 0.0444382666319143, 0.025165008737531025, 0.05279448210785631, 0.05764793124399148, 0.008545816581317922, 0.021029138479207177, 0.03989195902249776, 0.024268978595500812, 0.023687348184466828, 0.08289667835924774, 0.02065673248580424, 0.07434689221554436, 0.037927156445221044, 0.05220920960709918, 0.11358294112142175, 0.03744305722648278, 0.046532317937817425, 0.031890326863504015, 0.05289388165692799, 0.0434690662950743, 0.051138995549990796, 0.035546732615330257, 0.06702665923512541, 0.06839131296146661, 0.044086696434533224, 0.05046229045547079, 0.024392401464865543, 0.06723957398207858, 0.039946911347215064, 0.030693695371155627, 0.008781415072007803, 0.025454539099882822, 0.05613718203676399, 0.047598587480024435, 0.04535488951660227, 0.04212888488837052, 0.03676821492263116, 0.02974359791551251, 0.0681563193211332, 0.03314161753223743, 0.023822359689802397, 0.016478854813612998, 0.05608537270745728, 0.029469402179529425, 0.026261387210979592, 0.013032670740358299, 0.02515570777177345, 0.06395888049155474, 0.010461578967806417, 0.04261141446477268, 0.016774982868810184, 0.06610376891330816, 0.05323286874045152, 0.07709015946602449, 0.04201175914204214, 0.03748944516701158, 0.07793342476361431, 0.017236652529390994, 0.05508392605406698, 0.017917953373398632, 0.024244849519163836, 0.0458322240592679, 0.030786040806560777, 0.03311046959424857, 0.027392659612814896, 0.07698320114286616, 0.02432740046060644, 0.06029039628629107, 0.01683931222942192, 0.02927875186287565, 0.06636802543653175, 0.02250714969704859, 0.056189852257375605, 0.03553748545527924, 0.07239262442453764, 0.02252327471069293, 0.06416401010937989, 0.03383339564607013, 0.015459854512300808, 0.062134521940606646, 0.01910728769871639, 0.012907251493743388, 0.046250131126726046, 0.04361406339739915, 0.03029887466254877, 0.017112886416725814, 0.04066443827468902, 0.04241005866788328, 0.05988310193060897, 0.03441646396822762, 0.07823969426681288, 0.04467300794203766, 0.04084504362253938, 0.05684876065060962, 0.05980968868243508, 0.08299876819364727, 0.05645567100145854, 0.012847003017668612, 0.05195067875320092, 0.042040331827593036, 0.010175753777730279, 0.06173365458380431, 0.05177612190891523, 0.02177725673391251, 0.02721348104387289, 0.04806624070624821, 0.025196256865456235, 0.052029810249223374, 0.02971411609905772, 0.010626406256051268, 0.057501657647662796, 0.07557187374914065, 0.04084586740646046, 0.024365585813939106, 0.01775859756889986, 0.03996938728960231, 0.026942530348605942, 0.005605651522273547, 0.06322403554804623, 0.03818611403403338, 0.04275409606634639, 0.018544348276918754, 0.04175626738287974, 0.07272420116350986, 0.03867889266985003, 0.010677538375603035, 0.03465837813564576, 0.045861227190471254, 0.057295771039207466, 0.08990255984826945, 0.04724551814433653, 0.07676922512473539, 0.036936341057298705, 0.08203313758713193, 0.009092923210118897, 0.02385910898738075, 0.019728359548025765, 0.04154971655225381, 0.11044943035813048, 0.012956706359545933, 0.030851542760501616, 0.05524113519641105, 0.07884401027695276, 0.10876287749852054, 0.038208634505281225, 0.051486584125086665, 0.02687219515792094, 0.01685297702351818, 0.04451368367881514, 0.0616471646935679, 0.043215893747401424, 0.03523619947372936, 0.028043330166838132, 0.09043138459674083, 0.04087498557055369, 0.06806763267377391, 0.04665286869567353, 0.032583759966655634, 0.034508564494899474, 0.042824778211070225, 0.05746629431087058, 0.021517440109164454, 0.039132077727117576, 0.002827723192240228, 0.03251182730309665, 0.03167140814184677, 0.08900868007913232, 0.09670412808191031, 0.05266591615509242, 0.0315071374643594, 0.10346731985919178, 0.024909778585424647, 0.020069307756784838, 0.017032645409926772, 0.01580691616254626, 0.06407145687262528, 0.04253863575286232, 0.04909479430352803, 0.03323600387375336, 0.07465440852683969, 0.02545529237977462, 0.0459780301025603, 0.04599347048497293, 0.012181726069684373, 0.02217344670498278, 0.04948778005200438, 0.07398952584480867, 0.011781326265918324, 0.056337027563131414, 0.04771531617734581, 0.06442937985411845, 0.01978793545276858, 0.05811015565996058, 0.062627675361, 0.03578842784918379, 0.008324934879055945, 0.06238885966013186, 0.004200431540084537, 0.023287389958568383, 0.018941812886623666, 0.01608379476238042, 0.07435369028826244, 0.07073900807881728, 0.13979510724311695, 0.11587346118176356, 0.10684982858947478, 0.09244367349310778, 0.11143054216518067, 0.15606966364430264, 0.125327680434566, 0.11551667368621565, 0.13720228074816987, 0.13248435891000554, 0.15292939933715388, 0.14788888074690476, 0.15026627661427483, 0.13362162600969896, 0.12085730195394717, 0.19389382854569703, 0.15327191533287987, 0.08103809566819109, 0.16475342970807105, 0.17242247209651396, 0.15948109386954457, 0.12109123432310298, 0.14755248004803434, 0.0990040140459314, 0.15985915873898193, 0.1784666712046601, 0.15924875711789355, 0.20259445620467886, 0.14286544639617205, 0.19482363568386063, 0.10543677199166268, 0.19830576289677992, 0.0837460886396002, 0.17390117165632546, 0.1266789235523902, 0.10181497258599848, 0.07197906263172626, 0.12423561754985712, 0.16815976880025119, 0.0642972849891521, 0.12493420857936144, 0.08544157695723698, 0.13216176215792075, 0.1719383691670373, 0.132227219583001, 0.13983948767418042, 0.158921766851563, 0.24420361878583208, 0.08168796470272355, 0.1383203559089452, 0.0755316270806361, 0.06389910791767761, 0.1112089071830269, 0.16763570863986388, 0.10656080659828149, 0.12102778811822645, 0.2040756939095445, 0.06222125673957635, 0.13435002911137417, 0.09879115124931559, 0.08761763558140956, 0.11585726751945913, 0.12574070045957342, 0.22573187481611967, 0.10567903125775047, 0.1605196701711975, 0.1384435227373615, 0.1897161456872709, 0.11459123037639074, 0.07825556138413958, 0.13066269806586206, 0.16006513440515846, 0.15470639773411676, 0.16532175155589357, 0.19033423595828936, 0.21141874050954357, 0.17995058064116165, 0.12399287588777952, 0.1047853592899628, 0.11556998957530595, 0.16403094894485548, 0.11746900447178632, 0.07424380048178136, 0.12689932656940073, 0.16532241948880255, 0.15829002106329426, 0.10836254819878377, 0.1766444611712359, 0.1345588843105361, 0.3034135705092922, 0.15077377203851938, 0.14424601919017732, 0.1629931593197398, 0.11354766684235074, 0.11962624223087914, 0.13818295468809083, 0.1959944181726314, 0.17502651986433193, 0.11049872380681336, 0.08710084104677662, 0.06384693493600935, 0.12998250487726182, 0.18236281292047352, 0.20650541118811816, 0.1944195362739265, 0.15759302565129474, 0.15577887534163892, 0.11014535019057803, 0.11676040929160081, 0.13337441661860794, 0.15988403552910313, 0.20862550445599481, 0.07885181767051108, 0.2171864896081388, 0.23359150072792545, 0.16165002045454457, 0.30791012453846633, 0.21252025093417615, 0.12237120157806203, 0.1401850613183342, 0.08686258195666596, 0.1466048465226777, 0.17216004867805168, 0.11156101914821193, 0.19396997289732099, 0.15749780810438097, 0.15833661309443414, 0.13553327968111262, 0.15360033052274957, 0.17603218933800235, 0.10001415124861524, 0.15218008251395077, 0.12596123706316575, 0.09900265591568314, 0.08332733923452906, 0.08328682539286092, 0.15093064721440896, 0.1278396276757121, 0.16778778954176232, 0.17654470168054104, 0.15794680744875222, 0.12286625118576922, 0.25325629161670804, 0.09779481057194062, 0.1270958621171303, 0.21324644243577495, 0.13628690096084028, 0.06885456154122949, 0.1336490409448743, 0.11819273946457542, 0.11711907442077063, 0.07495202458812855, 0.20194504730170593, 0.07591919886181131, 0.12691912706941366, 0.1393480077967979, 0.1789524662308395, 0.0935512175783515, 0.13430097314994782, 0.21544263552641496, 0.11094858404248953, 0.12897610809886828, 0.109275174618233, 0.23168717947555706, 0.11197444735444151, 0.16356471693143249, 0.14524083846481517, 0.15518483065534383, 0.17271572432946414, 0.09288715125876479, 0.15207830438157544, 0.10781205273815431, 0.08336725935805589, 0.10336143022868782, 0.30926867038942873, 0.1809160108678043]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05501236446434632, 0.04952136594511103, 0.031189824803732336, 0.022935788219911046, 0.06376933597493917, 0.033359166991431266, 0.08310344812343828, 0.06808638674556278, 0.023943530140968505, 0.022523545594594907, 0.057466390790068544, 0.028156939988548402, 0.05244017709628679, 0.09501174194156192, 0.023202261909318622, 0.035625786185846664, 0.037055114371469244, 0.03231545502785593, 0.04022115346742794, 0.05319962052453775, 0.015400295305880718, 0.04921037638268899, 0.0591804068244528, 0.10241303229122423, 0.055975416107685305, 0.0270456740327063, 0.016445790279249195, 0.016862532174855005, 0.050239627598784864, 0.08216169240768068, 0.08154875264153816, 0.058618615876184776, 0.06896977254655212, 0.04746942409838084, 0.031251608597813174, 0.05588230997091159, 0.07162108027841896, 0.005816884377054521, 0.05349191909772344, 0.048514419977436773, 0.05242369770712685, 0.038204686279641464, 0.06303714792011306, 0.037948411554680206, 0.030069909116718918, 0.02450575710099656, 0.06312697747489437, 0.045031955087324604, 0.04965021391399205, 0.010100263443746371, 0.04548541102849413, 0.03537569355103187, 0.02627103698614519, 0.09271937393350527, 0.05072168591141235, 0.04198978414933663, 0.04441460325324442, 0.06637218888499774, 0.020406727053341456, 0.04181808828434441, 0.06388305526343174, 0.020070632490387652, 0.05228183988947421, 0.009105950684897834, 0.041025712052942254, 0.022819478836026974, 0.031174484611256048, 0.06519591450341977, 0.02580469736130908, 0.027198216921533458, 0.06634481847868301, 0.04573684695060365, 0.041052177039091475, 0.040837143460521474, 0.02933498253696598, 0.06659556049271487, 0.057256555955973454, 0.06004470087646041, 0.03379344583663624, 0.034296332523808815, 0.01142684684964479, 0.050061801593983546, 0.038603846696787514, 0.06058437211322598, 0.011975268935202621, 0.03749074021470733, 0.031006258286652155, 0.015705555488239042, 0.04557449101412203, 0.05525978536752518, 0.0748760806163773, 0.049602345388848335, 0.039134578764787875, 0.01911342711537145, 0.03020245483639883, 0.08595962572144344, 0.052731863397639245, 0.072790742124198, 0.029704612898058258, 0.05508609312528279, 0.029699104306928348, 0.027648088289424777, 0.011062794656027108, 0.016705189445929136, 0.023359137085208204, 0.03266443141910713, 0.042361010127933696, 0.10585624127998017, 0.037151500800973736, 0.05736065701057669, 0.0625171918363776, 0.015151946718106046, 0.03330971398099791, 0.031743092185934074, 0.0047318936958618, 0.03431947268836666, 0.07715893429121934, 0.01727827031572815, 0.04726246879727114, 0.013170160091249272, 0.047736549022374675, 0.09605248531443067, 0.05883751233341172, 0.04436822644493077, 0.012304697156650946, 0.05107809491164517, 0.05452720768516883, 0.04961268350598402, 0.06082646068534814, 0.024099947040667757, 0.012440427617548266, 0.010345679620513692, 0.03871477922075428, 0.04304291396692861, 0.044046130642527714, 0.08014692473807372, 0.012036333773721708, 0.02984296592330793, 0.025436477080802433, 0.05424302820756566, 0.02233936309494311, 0.008818130045256112, 0.08320875887875445, 0.04047504218760878, 0.02275083759741392, 0.05190675474295858, 0.0371075545263011, 0.018398501415504143, 0.01750374591210857, 0.011546670302777784, 0.03374620071554091, 0.027847295568790287, 0.012865036278526532, 0.0204699042296852, 0.023799484843038954, 0.026068541992572136, 0.07458348147338256, 0.008554492287657922, 0.024729299402679317, 0.043599906930467114, 0.03794966949499212, 0.05084378775791265, 0.07053683963022195, 0.036172318577882834, 0.0252877135790186, 0.020355155211291276, 0.0078112898336257786, 0.03477132187981624, 0.017484700547356624, 0.06320571934338659, 0.013064573813608149, 0.038265256662270986, 0.025803220487432554, 0.02710134252993157, 0.05826101572893094, 0.02730699721723795, 0.057398844219278544, 0.018440529238432646, 0.04279567860066891, 0.022072765095799696, 0.0320960464887321, 0.02739770250627771, 0.014863477626931854, 0.09736461724969558, 0.04915250370686408, 0.03868892279569991, 0.02546943214838393, 0.0606673182483064, 0.06742209036019631, 0.011748997385438997, 0.046691003954038024, 0.010067264774988871, 0.02284905898704892, 0.03666132710350212, 0.09094497305341065, 0.050692530639935285, 0.02402563208306674, 0.0869752028665971, 0.05760575870226603, 0.0978563197713811, 0.03227390960091725, 0.013864352040400263, 0.04536852276942227, 0.04197016547550447, 0.032169107216759585, 0.032684402613085695, 0.050462809958844446, 0.018251175824843813, 0.025395488264621235, 0.01747490790876327, 0.015218983990052948, 0.056439599793520756, 0.02309848368895473, 0.08503682445734739, 0.11361417069565505, 0.040155718306778, 0.016084690905699972, 0.05120187401189469, 0.043746911542257294, 0.042515714521869086, 0.033936016116058454, 0.025202509459631983, 0.046666012131026946, 0.011359889358573128, 0.039525122847408056, 0.011882825165230315, 0.025207789840351325, 0.01067049724952085, 0.04658481746446341, 0.037165534813539125, 0.013897403587179724, 0.03908776037860662, 0.053086075640749186, 0.030964271281845868, 0.008131572940328624, 0.023705478852207307, 0.029273755353642628, 0.010417346038593678, 0.01789666301192483, 0.026390253733552527, 0.057881963803083636, 0.05223670988925733, 0.04313979763537645, 0.05038300310843624, 0.022061495583329815, 0.015454304175364086, 0.037823003440280445, 0.020966762822354212, 0.06250784819712862, 0.03920547984307632, 0.060760105261579156, 0.03311795415356755, 0.06247983954381198, 0.04620251493179239, 0.010018266330007464, 0.05395887099439278, 0.02209378086263314, 0.02195471908635227, 0.048840022427611984, 0.05045847952715121, 0.044322662288323045, 0.04868365191214252, 0.027099186590930913, 0.031073366990312934, 0.022582778256037273, 0.06884374102810398, 0.02481446455931291, 0.03428918564168271, 0.017791105492506176, 0.0281154205367784, 0.03777163197810296, 0.030471765385300387, 0.04611624026438221, 0.049905935738934204, 0.024090840888675302, 0.12000197675661184, 0.04904917819658294, 0.0581070089538116, 0.04549036857497413, 0.0367140715388814, 0.00992930137726944, 0.02899550563597586, 0.03603359262342565, 0.0892846254282631, 0.06684934531222098, 0.053645128064090386, 0.03463931607257109, 0.022463285058620386, 0.062324352184077725, 0.06535026637720875, 0.07085093879140913, 0.0038976348241703818, 0.038039046339690685, 0.055091173126129434, 0.03871492765028961, 0.03544360748492181, 0.05316971197316889, 0.09930487329256721, 0.08574227293138392, 0.013887904096918646, 0.024821674523991533, 0.008385005239688326, 0.09112273226492107, 0.027725160325644538, 0.039162695029517636, 0.042301289504393935, 0.04364051725133322, 0.03719801490660757, 0.005871852936252253, 0.021832108868693467, 0.03474395147350151, 0.07346962171141058, 0.05614003930531908, 0.00739763063393184, 0.019279057778476272, 0.026167277319473214, 0.014302758154371986, 0.03186671914590988, 0.05500521387148183, 0.02649541977007175, 0.027109734364785254, 0.033925974857993424, 0.00990974114756682, 0.022943925869185477, 0.040576267419965006, 0.020657585955632385, 0.03754311357624829, 0.01505879698015633, 0.07488758390536532, 0.018192063762398902, 0.014185872678353917, 0.03988751726865303, 0.037658153887605295, 0.024084131873678416, 0.022439686617872212, 0.04834665007365402, 0.018219183693872765, 0.020593438421201427, 0.03284256541519426, 0.027403942112869117, 0.03313556902867276, 0.04038156497699674, 0.04714767339464743, 0.05715599865652621, 0.04992299771402031, 0.031872596955508925, 0.042443061975063756, 0.030429282996919937, 0.039052872016327456, 0.047710681465105154, 0.016305257195199374, 0.012268750306247966, 0.07986615542904474, 0.11653204303001985, 0.13774096121778712, 0.18031031446298584, 0.12251066596945748, 0.17739777074893937, 0.2441367958090268, 0.1997237844625488, 0.14964487636461854, 0.14243228448322043, 0.16980975604383275, 0.1809067340218462, 0.1026794855715707, 0.19353963114554062, 0.15699052048148587, 0.10626213668729179, 0.13299273006850854, 0.14065105584450066, 0.18972012359881774, 0.12801291915820912, 0.114332539960742, 0.15860954532399774, 0.14941727451514453, 0.2003316776244901, 0.16583767777774483, 0.12596643209690228, 0.13315683376276866, 0.19089492852799594, 0.12513684458099306, 0.16710520663764328, 0.26088752900250256, 0.12232164837769233, 0.19531869271304458, 0.11448758203187026, 0.08926115871872753, 0.14707529393490404, 0.09056442941073328, 0.21525693533476442, 0.2220190584193915, 0.1618729022447951, 0.1300340544548817, 0.20183811866445467, 0.1308436633553356, 0.16233423608355224, 0.09611950867110863, 0.07537647368735634, 0.15545881673460826, 0.1689207967137918, 0.13516918203094974, 0.1273023127578199, 0.10335524071706459, 0.08960455787018873, 0.1311659484053962, 0.13818691775668412, 0.08925916234147735, 0.15400940232211724, 0.2378114266321063, 0.18289992003701627, 0.07497070444514975, 0.1493218046380207, 0.1720084872795269, 0.07959503403981216, 0.1475058138021268, 0.0978302035946399, 0.16241021716268733, 0.1741971995215863, 0.11755812156479806, 0.14024024741956964, 0.11664828562061302, 0.07181278444477357, 0.09906651030178182, 0.16107501927763224, 0.1533485495019704, 0.1722931009135209, 0.1498619100311771, 0.3065644920570776, 0.1096357470669318, 0.16755978693254292, 0.12971890886547044, 0.17400654178345576, 0.14982518856413662, 0.10354128229664639, 0.20354986743768677, 0.10316812302335165, 0.08693860014318489, 0.12047090276610106, 0.08636809638119303, 0.08625590591691434, 0.06087738314818125, 0.12163458290160634, 0.1409906180924736, 0.2112180192489177, 0.14587213896447793, 0.12017609944450669, 0.16848341940203682, 0.21551863144850358, 0.16703507368220016, 0.19804396288236603, 0.10169834407861345, 0.15307257446693256, 0.11393134234822355, 0.13761207985226065, 0.14129390416201204, 0.1205216656671837, 0.13595158379757777, 0.09391466213855892, 0.2117735316278413, 0.12280884606298059, 0.1295308634871617, 0.17665390128968284, 0.13596371049061418, 0.08181882760254666, 0.14830495842033997, 0.13403583347098902, 0.15864245215198025, 0.12126975794672035, 0.2280536838225089, 0.07532421906944364, 0.11211201184778474, 0.18893132451921701, 0.13948101550340652, 0.18248909676913172, 0.27198266645427793, 0.09421184033271857, 0.11539030820131302, 0.11610153058427386, 0.29730370617471635, 0.13133808213751763, 0.15159737784415483, 0.07770110285491683, 0.13041532540228218, 0.12441803002730012, 0.12395239915349521, 0.11114724955405109, 0.0908848294056952, 0.19587672839406878, 0.1759719121037051, 0.10478515148861334, 0.09281574923079461, 0.10537346679484472, 0.09874504161416553, 0.07005370149272494, 0.19949462410295382, 0.16055904852692038, 0.10806813079398125, 0.1583359600044787, 0.17508853372419253, 0.14325623167678714, 0.11150312420795672, 0.08399218480917625, 0.10918769025010988, 0.23279939166968688, 0.1339935013675131, 0.12296784378122538, 0.058128130476688966, 0.1421518565621227, 0.18641643837327138, 0.07344755766098388, 0.1225554323173128, 0.1469416479812935, 0.15885883272858337, 0.15037096396554261, 0.1732281773001887, 0.1546295260777697, 0.1724567890050821, 0.11853794945636764, 0.19845913513563573, 0.2213956692139618, 0.12165454667410813, 0.11712208754033782, 0.09192784375045449, 0.07554426585556939, 0.11234017772949301, 0.1038829077151604, 0.14235608075978234, 0.15014837903436273], [0.024445593044220004, 0.015106200735317543, 0.07112958555808291, 0.05301573117321823, 0.02933153711637715, 0.03335120745759923, 0.01665498686634237, 0.023840100730012637, 0.004105712623641011, 0.03434662787185516, 0.015230675599013921, 0.06634196121012792, 0.02283499899931485, 0.029789735381200444, 0.01897158599604154, 0.03583997742680367, 0.05032502282119822, 0.02335229262826033, 0.02288555224367883, 0.04123442624404561, 0.036093643502681516, 0.019462628006294835, 0.057635715493233874, 0.0976366589020472, 0.03925511096895207, 0.050143601110903546, 0.05155942963028792, 0.12984676606720313, 0.09178398584481329, 0.06212482949194964, 0.04466039143153466, 0.017571103235241026, 0.0399944421951659, 0.018389530705462676, 0.015739664595457725, 0.005477038257595268, 0.005627053669741144, 0.05722478832467459, 0.08876170075382106, 0.039051194762578234, 0.05796867633762304, 0.0868487409024965, 0.05331202621164266, 0.015292644930013921, 0.020368352452351246, 0.04289280346711166, 0.017642460734350607, 0.011730671903933398, 0.007258887053467333, 0.05019798569264822, 0.006201570131452172, 0.07044200800010003, 0.07517199715948664, 0.02678464585187612, 0.024656457608216442, 0.057820591900963336, 0.03079233421885874, 0.07003862105193548, 0.04235022672219202, 0.039870703913038597, 0.029859382229915354, 0.017060474092431832, 0.09610702574718744, 0.029967349873913918, 0.0427470122667728, 0.027675523633661214, 0.06085721899580676, 0.023993367212824523, 0.018481414153939113, 0.014989620467531495, 0.03416789273614995, 0.08316088293213397, 0.049353540380252525, 0.023583555121149402, 0.03163991139444988, 0.03572236928448547, 0.030592843068006914, 0.04011825469206087, 0.02632460335007636, 0.019916872479370795, 0.025889704811561387, 0.01299311612456222, 0.02002862693188945, 0.028099241717427503, 0.0893231354712043, 0.046011296872165985, 0.010644210378814023, 0.05238657548034098, 0.048589002108201385, 0.01868354549515061, 0.0557815634238068, 0.04910693212877959, 0.1168425650394056, 0.0020839532271565986, 0.07437216234393418, 0.01384176477586152, 0.008131539543683175, 0.06342864566249773, 0.04468590646865778, 0.015048298373585567, 0.018794730349327438, 0.04008875803265255, 0.02048884012765484, 0.03131727011350449, 0.00486658190311573, 0.05456950268126093, 0.05214487282501068, 0.023738788295304403, 0.0660945737035945, 0.05412276317656506, 0.05628551880363375, 0.020735986436193343, 0.013418470643955516, 0.04373839539766777, 0.04120826182770543, 0.06381522296578623, 0.02550360619352432, 0.07516971134464256, 0.045253311764099635, 0.04909425253572408, 0.04921000901958905, 0.03609323161072098, 0.04018368243123405, 0.019535106148396153, 0.03237542427086737, 0.04907515707600396, 0.02408329695754219, 0.05502534462721087, 0.0291383801959455, 0.04842944777919911, 0.045443821072694845, 0.05543512888834812, 0.026834614654944744, 0.03126817704469431, 0.02626668800076004, 0.013232928158686263, 0.038821210619062185, 0.03754534373001661, 0.00443843319771986, 0.021572661462414544, 0.03628621969255619, 0.013967030954518123, 0.05285329360049218, 0.026081843134306837, 0.015351167912740493, 0.05386449207435362, 0.034873471086029895, 0.03735121645149775, 0.05696651351172477, 0.04399629913677927, 0.027157315307704266, 0.028566043329192325, 0.04201153278700076, 0.049542431806912646, 0.027361114625819027, 0.023726789622742217, 0.0470600814151112, 0.04929713344608899, 0.04393391420308035, 0.042992440503439866, 0.07766195456497371, 0.04121767226024531, 0.015991783293429762, 0.02571961384091992, 0.055478284775745124, 0.031167204142548144, 0.04362108411442023, 0.054755763194407336, 0.027765436680056155, 0.05922456461121328, 0.015621208549418952, 0.047151424951152876, 0.021461992400872987, 0.034556132450234145, 0.016622093025944196, 0.061675629767705686, 0.057930986367864534, 0.01526176880361163, 0.010010461719502928, 0.046170131317921914, 0.005404702515079407, 0.055302970940829255, 0.01338491536444053, 0.024551254464313388, 0.043778270992334, 0.035571609405451454, 0.0055821356454544, 0.030626191473857034, 0.052463513929978944, 0.0338691003707936, 0.05727341755118687, 0.05510126633453183, 0.0658396830840502, 0.013092132539895829, 0.013332873186300276, 0.03340146940900013, 0.030337277094076853, 0.03954427767894231, 0.08030736222281121, 0.008220681684178999, 0.06318594852928072, 0.022677721208310686, 0.01639617399632698, 0.009147015571215888, 0.04761960881296545, 0.04768228318425827, 0.03489649621769786, 0.06591175304492936, 0.04722892372228671, 0.02707836563786259, 0.006525943399537937, 0.024880923883756623, 0.004301825611037202, 0.06590285469428636, 0.028429541962395888, 0.06308061550953425, 0.037575378446490504, 0.006484767191068386, 0.05385688506066799, 0.04349586153693963, 0.03265001520048827, 0.005563217837334378, 0.010972903874062467, 0.03621505886258092, 0.015723979304311797, 0.009543162868794752, 0.013038916840741877, 0.11849089729366824, 0.014834151661489159, 0.06484194716904312, 0.03369178273715079, 0.028816670310334302, 0.027371591895644087, 0.06149228218419012, 0.024433915350527968, 0.058785369037650526, 0.028833346368628554, 0.028755391176673584, 0.02303467754245503, 0.010483916685188888, 0.03017280232597841, 0.020529057110252324, 0.06593180587515235, 0.04006934344943147, 0.05051017753430642, 0.043933543129242025, 0.02554922230046941, 0.021064436878077686, 0.020780708255188074, 0.03600651165470481, 0.03179633757099509, 0.04042784530611243, 0.04805603617569432, 0.03389531673747115, 0.04237641711370088, 0.06695070784189738, 0.03580287375370972, 0.020515633514150977, 0.01101595864383853, 0.08113274176139385, 0.08000329689821228, 0.030091665175859816, 0.057525332158547826, 0.0387096175836632, 0.013974750218039844, 0.037439391016960144, 0.05901053664274514, 0.03652497231087182, 0.06367354697431438, 0.025552235420036595, 0.05018025949539151, 0.028578589335666038, 0.0372086090646917, 0.013416241417871788, 0.0571462616790086, 0.054021623291191645, 0.04380731494165957, 0.021325991983758286, 0.08493684974382631, 0.060353987209964544, 0.01079168718206347, 0.015690879517933354, 0.019771576662606094, 0.04041015621623956, 0.03675022526294924, 0.027715530959540047, 0.051468783713062294, 0.007310523369596922, 0.03771433075598907, 0.05523931322386488, 0.01014292301988462, 0.035907538840547204, 0.07382403433439322, 0.058316146169090644, 0.05411448822997045, 0.020391195757838432, 0.03415086415770929, 0.04981032485375181, 0.015980899697751738, 0.05365224526030943, 0.04015535094367806, 0.060095074150012806, 0.03735717589734122, 0.05162306879356038, 0.07789761613821611, 0.055879983337945305, 0.05469701478432398, 0.08744149425183423, 0.028652017426793464, 0.04966778797097504, 0.08479828335111961, 0.028313549846643582, 0.0892436143476516, 0.02170951534935739, 0.023043464570946526, 0.015586208864988293, 0.037926469958620146, 0.02237144984974293, 0.010368958937760908, 0.028176052146591246, 0.04911858755804133, 0.05863401915121358, 0.01794589523342438, 0.07396010711090639, 0.021860173183085863, 0.12944516027346253, 0.047401354313478805, 0.024615973452455364, 0.012552191346912878, 0.0655034530791454, 0.04731916887976695, 0.03154380698106252, 0.028614769034902565, 0.015626514905306976, 0.06932265634532087, 0.048596082197036594, 0.002331478958694788, 0.03651751372672152, 0.03355299370014109, 0.00518682187248487, 0.03182607913913671, 0.026498653678572737, 0.037693257472710684, 0.002328226728423033, 0.027498933304741513, 0.016693344769009855, 0.014378069445228903, 0.023484658377128653, 0.05471769472933374, 0.07699569148826413, 0.020811043541471008, 0.04052453972690273, 0.2504829748068005, 0.09181160858133808, 0.1117530869669281, 0.10210318563622423, 0.11793180034146644, 0.1553164134384133, 0.12995462981052697, 0.0824347508023493, 0.10215829752269201, 0.10671509167877957, 0.08889345423085615, 0.10838561414857395, 0.13439203466987237, 0.1462874299613759, 0.12673115590587258, 0.2150455568335019, 0.16929138073464856, 0.11285194792435504, 0.12714064330793917, 0.12982337357243523, 0.07469090734957717, 0.16823552723508328, 0.18117686093319207, 0.23768934333929792, 0.14112093922449276, 0.15058235730975866, 0.17139976291218773, 0.20043133321451023, 0.15627954300725833, 0.208796628867276, 0.12453601666493341, 0.14306766679510474, 0.1836610518512316, 0.06650837298366241, 0.06651629169937223, 0.1751437346683815, 0.2331843733554706, 0.28016202442813665, 0.14401478081708774, 0.18262507306644693, 0.10409312104457058, 0.19282954424852505, 0.24918427574448287, 0.12188217820948921, 0.13660979457199574, 0.24983122071716934, 0.14273139968281612, 0.05472739088872913, 0.12344701142865233, 0.24624669196782634, 0.08640940432087518, 0.16909441474126652, 0.12517194816609845, 0.08831197410472669, 0.0919125926156994, 0.18629793223226443, 0.07954772212542593, 0.19949965586420149, 0.09315521499956958, 0.08639565974590369, 0.16420017345808446, 0.1301868775044568, 0.17481300397776067, 0.06705537292873487, 0.18732329830527306, 0.17559334257384762, 0.1686057698680088, 0.13028034358285367, 0.1278953332803212, 0.1178575558878947, 0.0697463187680114, 0.14973629411542788, 0.17131414875620976, 0.13305713364388794, 0.1511149521684274, 0.20024232304422185, 0.25438471231609583, 0.11199338696314953, 0.09402965049957857, 0.14461415412370116, 0.10678877952159382, 0.10554938548011705, 0.15132647909922525, 0.25122630991972983, 0.15301997103961185, 0.09478488223976456, 0.18678883323445916, 0.2174589320202358, 0.10527618607738987, 0.13195905194152147, 0.12399912477121688, 0.14698065526317805, 0.2484952806844376, 0.18853798625059426, 0.24353673972655088, 0.0909828967996873, 0.08194137102691457, 0.1485146299819462, 0.15284872788470238, 0.18704588350374252, 0.11491778277559206, 0.11676374895614572, 0.16378520900616422, 0.10420855469419621, 0.12225458791363053, 0.11591208996833302, 0.09416445420356467, 0.12302760151214898, 0.14111074211541563, 0.11703537500579841, 0.19198198191588745, 0.09845771914115176, 0.09682797768618912, 0.12581783928908408, 0.15779702720465139, 0.11647414808976464, 0.15544164343737066, 0.144785798038356, 0.24907443788833916, 0.19673653616337106, 0.12728804867947474, 0.0833210012933705, 0.12338786968030035, 0.11139460737467743, 0.0988044950645417, 0.21182604599744081, 0.09637301147449762, 0.1329494034871459, 0.18116572871804237, 0.15505338145885617, 0.12313910177908838, 0.20113986160140485, 0.12560488743474707, 0.14316931134089828, 0.2572681935271248, 0.11793093202868477, 0.13705543940886855, 0.08211199819925241, 0.1383714601979591, 0.14449477224843577, 0.11764818118535914, 0.08178760544979014, 0.24699633533600718, 0.12296380649786443, 0.08064060137257911, 0.16547016624826938, 0.24041734461206943, 0.15495351806748658, 0.11086346712545492, 0.17791924823541194, 0.10851275888853706, 0.23462216573534533, 0.1004693697905168, 0.16932928963797167, 0.1350966890458949, 0.1082670412142761, 0.16912746999878436, 0.18555599235696718, 0.16986418515443802, 0.1363902524462901, 0.11634876966127194, 0.17517652275273576, 0.10948466806439683, 0.20756865647854283, 0.2243403033935465, 0.09816566918743774, 0.10921223307377659, 0.1853578834561631, 0.21492342901183292, 0.13134673557942733, 0.0866295253217686, 0.14852683088975027, 0.1422116142930463, 0.21828716882737353, 0.11067137704230845, 0.18928797100670636], [0.058879228454316035, 0.027108986651001032, 0.04437995608896017, 0.04998602089472115, 0.01768198566423962, 0.05047082515375223, 0.04131652633077465, 0.0421538544469513, 0.023778324357408565, 0.047630707631469704, 0.03621856179961469, 0.0386292355688056, 0.0062371078729484, 0.021285003167577088, 0.07502902983105741, 0.02481504900060827, 0.07176749117206782, 0.049132072381326, 0.02725804144574795, 0.03214732147171162, 0.041778349986998364, 0.01834560669522034, 0.0799568384536542, 0.06362415704643354, 0.0834129385475535, 0.03870395499689039, 0.06469883141107857, 0.022754780256946106, 0.03338914975756779, 0.015622390419594012, 0.04736717470223084, 0.05180745538382325, 0.05293489644827787, 0.05504163847945165, 0.043272527036606334, 0.061865678944741376, 0.014194738560036058, 0.03783635467698332, 0.021456253743963316, 0.028211445169290528, 0.07319982134504244, 0.03162950277328491, 0.027722347585950047, 0.018789939786074683, 0.06027495961461682, 0.05743858993810136, 0.06583867376320995, 0.05012244248064235, 0.034000282394117676, 0.04335181809437927, 0.03369894817296881, 0.02160415820981143, 0.051669319436769, 0.026643647070159204, 0.04829060308111366, 0.04280058048607316, 0.05977692657324951, 0.04778338596224785, 0.025557992630638182, 0.02606254358397564, 0.01718430699838791, 0.041533882831572555, 0.010198289091931656, 0.02344689975871006, 0.07193541692686267, 0.03369130405189935, 0.042200635725748725, 0.07617907671374269, 0.05177917584660463, 0.07101175477146171, 0.005725384062316152, 0.08160016863257624, 0.09268935405998491, 0.0496828684117645, 0.04170905565842986, 0.023929804119688924, 0.0767573359189555, 0.02045397774054436, 0.07484272107831202, 0.026252149327774532, 0.025167706444335636, 0.022093077677709516, 0.05431342462543398, 0.05431063043943141, 0.03931040097086225, 0.03199194914486725, 0.07088489204761572, 0.01750802624883363, 0.0034738687327262596, 0.06200038616952952, 0.009266894685424631, 0.03712883190019056, 0.04094371586688794, 0.016599414848315064, 0.10942320339381695, 0.05085717981273774, 0.0366514379857108, 0.027533007159945555, 0.05002170706575271, 0.0463286874582991, 0.05984088857076131, 0.023547946875623893, 0.045649340318050236, 0.012573118056025123, 0.014853102402412333, 0.0038978398424660554, 0.08307839321787469, 0.058935576016665436, 0.03211625888070557, 0.058138617023359984, 0.042990625952370465, 0.013267014073790051, 0.06864174327347428, 0.07316458417335525, 0.035496270284056664, 0.09530200331937522, 0.01557720846903976, 0.017344464322377462, 0.06411347727407701, 0.005450024546007626, 0.045448088421835564, 0.05469284762511961, 0.025156438787234947, 0.0720308200106956, 0.07229483904666267, 0.05104433832457289, 0.056825620486051776, 0.021668383669748437, 0.11272310366621241, 0.11030536465113983, 0.03355417742568534, 0.018883318662119564, 0.02655958214745624, 0.05547191343794111, 0.01819437926315004, 0.008095584344118834, 0.08368711016373709, 0.06767398270312697, 0.02322702366654994, 0.032028321802499704, 0.09157112304819748, 0.019385672858334146, 0.03550981076841708, 0.07715302679571323, 0.06003366885124706, 0.04743576770124491, 0.006285726431087824, 0.02894493383791996, 0.03480333813058678, 0.009322176338173449, 0.09305132174631581, 0.05652949614159297, 0.030190756733645685, 0.019644643434730824, 0.06399308607797138, 0.0533470741356723, 0.052483711478998885, 0.03198539969162084, 0.022467760209110565, 0.1299048020155169, 0.0435681059025228, 0.020686893367383163, 0.012432896673999494, 0.023468019426218234, 0.01157055818111985, 0.02423021065624198, 0.035798647222691216, 0.050364738854113966, 0.048980429346556775, 0.020216950615576934, 0.0011592346709221601, 0.09611144894734025, 0.03326522964925971, 0.05409688819781877, 0.0290523096191464, 0.08635014382889494, 0.011732895563909551, 0.06739773307344876, 0.03641005445388146, 0.07860803700168617, 0.03845550621917937, 0.03163487963320222, 0.011100960527983261, 0.028212085271661635, 0.023580347187817097, 0.04562476409773808, 0.025422877224627882, 0.08493474204442464, 0.023838009728933685, 0.008671305404277518, 0.04281874455045909, 0.07286849693628028, 0.08920869629946537, 0.06024665039149113, 0.026201176769973245, 0.04395024887344334, 0.05159635889867786, 0.06237920431885868, 0.10594503924949095, 0.0673764111706987, 0.029405135901470203, 0.062334957474377006, 0.025275894877268, 0.03415700914047193, 0.034692053086473607, 0.025436213618377224, 0.034066519074258395, 0.06819491100031883, 0.05423179951321799, 0.03736148777534254, 0.026928624356514774, 0.028067041785106994, 0.012079303196514957, 0.0694464094704017, 0.07673651867662556, 0.02018690105614951, 0.04710453606094234, 0.06620727624977008, 0.03350539234816097, 0.025115212483797222, 0.06483649238361977, 0.06389190908521414, 0.08092293661320582, 0.05356497611501254, 0.07000184763455763, 0.05003855752875097, 0.040091118062264286, 0.014241619101085234, 0.05637669535644818, 0.019823979710054118, 0.01143026629506494, 0.01143810522989952, 0.03647069162980188, 0.014288813199527794, 0.056665531810722314, 0.00806938096502563, 0.04284622256818693, 0.03716156061273068, 0.0015903962639640667, 0.05012540364987217, 0.06969453912461177, 0.051258811581647024, 0.0657625071471557, 0.07225536421174183, 0.04148402535065543, 0.055512071048724465, 0.023096272088878322, 0.018711990160227288, 0.05485961934027728, 0.074671559559647, 0.006671868650300894, 0.07925400233943947, 0.028757515574397985, 0.036259984772186726, 0.05365146600524895, 0.04070152710482944, 0.020909480153932236, 0.04011204291600734, 0.056933606683742255, 0.059800801464007236, 0.022042251694074366, 0.006217900627234485, 0.02333156815438997, 0.01948091266967822, 0.022828065484645776, 0.09431321028387174, 0.02796279044559924, 0.03385276941116899, 0.038091215610620566, 0.0022481128144136164, 0.07897571922512725, 0.06390268506947905, 0.010630852648318978, 0.09728042059578001, 0.05507964757271111, 0.03798371923039667, 0.017775850647012703, 0.06590015327674337, 0.02757393474894343, 0.05016476345190313, 0.09194745871354826, 0.023755980146233924, 0.01710014374111779, 0.06841624912340194, 0.005042241764385835, 0.023898984582046978, 0.04408054403029382, 0.0483968489425024, 0.027226648599025793, 0.10618904256261885, 0.02687091866391711, 0.019371657399460673, 0.03350013052113354, 0.02895917194109643, 0.05509172973688692, 0.04889460738922935, 0.04529245263256598, 0.020647064156946726, 0.04878543004451785, 0.04122748345253058, 0.04889911593636498, 0.0412793781288201, 0.06496349611552432, 0.0443318129691761, 0.008322746471094433, 0.025086858731810935, 0.024208571485360153, 0.03871653068927117, 0.03959272879001219, 0.012639787037187489, 0.04263879600330256, 0.021337677098927088, 0.04214333450363483, 0.06630161064094864, 0.047010409471113235, 0.031458690064027905, 0.03416736210056115, 0.1344171934761107, 0.007075338626236771, 0.08955093027907424, 0.10695427845348604, 0.015738746187707875, 0.06493867127574049, 0.07848470690078102, 0.05188452370930463, 0.044682852530968376, 0.04237130742694717, 0.022056053785490803, 0.04636828845832497, 0.01311267054916243, 0.053954488612362184, 0.04017234983621165, 0.05207187889027409, 0.0718709614011459, 0.04114852265047375, 0.025979740312322974, 0.03698913373227697, 0.060247630026424304, 0.0574749440420419, 0.027327450807206333, 0.03456110855040606, 0.03304546858998947, 0.00820562072476605, 0.01911251798446756, 0.07587010579300113, 0.060792065851273946, 0.022856217001390178, 0.03649114521977026, 0.01346577884760336, 0.03858993142785039, 0.05818085635837633, 0.08298841523355804, 0.14700289000757039, 0.22711700439685956, 0.13018220197409391, 0.11633075773715973, 0.11001963779563084, 0.15383919817395508, 0.1600722293369472, 0.13061898556770757, 0.17512927763164043, 0.13326993706868961, 0.15174074593232945, 0.16916469612624496, 0.1684032377670519, 0.13382893754169345, 0.13005211832933128, 0.18889662169385701, 0.1581012038514018, 0.13289386115502566, 0.1151209679665044, 0.19891340372851118, 0.20652423205319792, 0.12281369970878586, 0.17444519558921456, 0.20075088716112077, 0.1545883814105764, 0.13482669572113082, 0.20864652207819745, 0.20399086643010378, 0.13454980042297393, 0.1292538791312836, 0.11602803569985554, 0.13174529856769368, 0.19388204324059188, 0.21868193201953545, 0.14976624719565734, 0.14384537818841636, 0.09941458498360589, 0.21159798401640728, 0.15086493745911866, 0.07227403664728627, 0.15294381184503436, 0.1184811677376274, 0.11601896665524691, 0.14421044063055888, 0.11365023165126331, 0.15600000566337258, 0.19723085104487836, 0.13220695895142853, 0.1505956714390777, 0.1846922660479322, 0.13965832942631096, 0.08935352641856298, 0.11547717658686452, 0.13061888166703284, 0.1364601924433373, 0.10098056853166781, 0.18473152566002682, 0.09144218231085688, 0.11407057667383924, 0.1925208405009471, 0.18187488050898537, 0.11764659298933111, 0.08591570542193949, 0.18658077955478802, 0.20859898009803146, 0.12325454285019077, 0.14245851198211312, 0.23588052164996043, 0.18543622456490993, 0.1597448976826854, 0.2650530851678923, 0.18529251508880407, 0.17034105956554413, 0.11570642600418068, 0.10778703493997455, 0.14344601368065923, 0.18966159783303738, 0.08831493527395651, 0.20593164197634906, 0.23576971900183707, 0.1255514973308891, 0.11327529122354463, 0.10404673681478016, 0.13129898579791188, 0.20080041809706017, 0.10649131931131706, 0.19159466988639906, 0.11168497265316546, 0.08487881379551254, 0.1390265836380422, 0.12171220412710682, 0.10716687407693826, 0.07807043264620006, 0.12864329939475283, 0.21550837496761233, 0.17799487308366224, 0.07574415591079742, 0.1990574545925483, 0.13484297844115645, 0.15348201734013855, 0.14137344754999503, 0.16577355621848255, 0.15663531376048923, 0.16604990232735872, 0.18882156087784097, 0.09789033239940181, 0.22404458723030984, 0.1326669569243677, 0.10041792411357164, 0.11352076398907229, 0.14126078953268006, 0.13223863381426781, 0.13180581328924745, 0.1555266193463467, 0.13792211946565658, 0.17336630582576618, 0.09659862436819822, 0.11379601914086379, 0.1689999393420294, 0.09335100839962251, 0.13640206743730232, 0.07495811019907705, 0.10712775547290221, 0.18760230130283162, 0.21624439250444993, 0.17097804491641, 0.2114026655908674, 0.10215332513325848, 0.1581847548368387, 0.22186001617228612, 0.09097566085983999, 0.1890247905976139, 0.13504669797839597, 0.1760997247765772, 0.12014990905299783, 0.15530246106209233, 0.1801770247402601, 0.13062331971013919, 0.09812436866923235, 0.16589492704952136, 0.26869248831644654, 0.15262681088643149, 0.04955364936904516, 0.25862011942081153, 0.186804537079297, 0.1355976238846779, 0.16555106034502387, 0.19638705882243812, 0.09598793330951594, 0.11530223753652535, 0.15105278987903148, 0.16441416431916878, 0.1740660026553087, 0.12088053859770298, 0.1538235685438849, 0.12365156959276646, 0.10803764336742461, 0.19393705122638494, 0.09396279041538946, 0.14631359808845446, 0.07960333125083707, 0.10526777012273669, 0.15916171803837642, 0.08753404748858884, 0.08291278296383098, 0.15148859383771196, 0.1463121286360547, 0.15527970681432635, 0.12392430886393413, 0.12323402988840826, 0.07547982517280616, 0.1474595780018717, 0.15884314372669905, 0.1522850221954286, 0.13597469427622855, 0.2274484178633429], [0.07210645970189944, 0.0883435970172286, 0.031427349167643115, 0.03013867280969862, 0.031954062505974434, 0.01185019942568033, 0.02182093398005236, 0.026271753158653155, 0.020621619623852894, 0.015251143104251241, 0.060796459365519695, 0.08596920684794895, 0.03179252293193713, 0.021304391775629483, 0.034357106997049414, 0.018805504478223156, 0.05042137214331888, 0.068008743255632, 0.023822300317988265, 0.06156539486255497, 0.036766363264177926, 0.04316359460062813, 0.004002617642981932, 0.052323270283523016, 0.034563513108878396, 0.03905591482180171, 0.029807836363033857, 0.016203536579268984, 0.013134447017364437, 0.10558634443441406, 0.03650490834843367, 0.039281375575228594, 0.03307933278847486, 0.03785389162658248, 0.008146266536641633, 0.05426109208201524, 0.04986752959666774, 0.05885978047444951, 0.027386449692130554, 0.03393479157239199, 0.03719107211509254, 0.00182707434760232, 0.062284461746457964, 0.04029368355986662, 0.021631931231240742, 0.09150797370239161, 0.059961587758152746, 0.004160040616625338, 0.050892598810605705, 0.0013525374697564985, 0.06469578118412755, 0.04367886773252394, 0.04592165656504221, 0.08880392895662226, 0.02814936266076984, 0.048769540662760846, 0.023250694466696586, 0.01551830235257512, 0.02711043940507807, 0.03650294165709056, 0.0016061593646554684, 0.029112748270563316, 0.04006784802186303, 0.0766793436196167, 0.07122075097868219, 0.03221672341169324, 0.021434987502289005, 0.10295596526702866, 0.019212273764424026, 0.02657848464878043, 0.010365990347054321, 0.051102411380270496, 0.048336111576645635, 0.04033169636386447, 0.036013528660987504, 0.06488652055850253, 0.11156978391227312, 0.004034015128127066, 0.03409680983168073, 0.02161176707886625, 0.060845277839689516, 0.03999663524155039, 0.046507415172527544, 0.06400624435627833, 0.007065991276249406, 0.047937259150785394, 0.0360936917422805, 0.06741508448612876, 0.05420955734734889, 0.016139813924382906, 0.015040452944958815, 0.07796443911502138, 0.05804358501336537, 0.022833110233477782, 0.011924618283956079, 0.012974422352272086, 0.025015833343786653, 0.007487752409360837, 0.06318836050922982, 0.04823239643883426, 0.059665879016392864, 0.03904135759512428, 0.020635785367630888, 0.02618629856442567, 0.04273729384294711, 0.04844857663556468, 0.06825578195275739, 0.010425562541058753, 0.039335381661658175, 0.020062203548150137, 0.02598510789539432, 0.06453491325373761, 0.00913979354663752, 0.06428319902624935, 0.04313504046876915, 0.07147015712689608, 0.06890801843837835, 0.05881086552108172, 0.07372858672169968, 0.04472950393392239, 0.008749100106797414, 0.016646294461679645, 0.021621689593303017, 0.1584745041327551, 0.01061263756128028, 0.05710827113944106, 0.04078097401361447, 0.031484591017942876, 0.02249296725494787, 0.03992037585703656, 0.02475629316904815, 0.01879559495137073, 0.023469362713512965, 0.05179465704713948, 0.015453214145964012, 0.10315684237866662, 0.018868594452214893, 0.05777499434771016, 0.030648723077320028, 0.024007187857932877, 0.06961997554753907, 0.09715574720758013, 0.032946143255685456, 0.021311464442987926, 0.019994081812910736, 0.08244038370321505, 0.032580145707470365, 0.0008348314850081806, 0.02160722327971598, 0.01221272465045331, 0.02979684515594272, 0.01618700523977168, 0.007108459749360918, 0.0015754957939861924, 0.10660966960131191, 0.05746075046772603, 0.06119456222222652, 0.02247320571768796, 0.03379126021172851, 0.0232359294386697, 0.04452283064892981, 0.03380260764970444, 0.024027155341173057, 0.024212558673752937, 0.013887820605305023, 0.023946339169924613, 0.05869905355211813, 0.02802446106215939, 0.09137265791650862, 0.07616162882186472, 0.04143961894442327, 0.02054757555015385, 0.023188532177300658, 0.019628026748250704, 0.018810940709954593, 0.042325765534769744, 0.029225346916064154, 0.019108104061160702, 0.046565046650357544, 0.055327780937659554, 0.041415680971113034, 0.013195244682719931, 0.02391918213106692, 0.028088718063372653, 0.03408351054531522, 0.05327729741111398, 0.07474445330444723, 0.03655544118373655, 0.0630229951639194, 0.07039626201731153, 0.007424507975883898, 0.04144320351770148, 0.031380322980112396, 0.04726802377263084, 0.027264540804026183, 0.04446785605978221, 0.047982852993300185, 0.04119766024814453, 0.0344064635282848, 0.0753495708340779, 0.05024906771723181, 0.01044017913955031, 0.09745282150106505, 0.059249459955026396, 0.02842815785697894, 0.07971949962666258, 0.041825468942988664, 0.06002619171340484, 0.05057832895545289, 0.006000634111842373, 0.05185797708691098, 0.0029379947409324814, 0.06293424914474599, 0.015162695799517678, 0.03441789260250516, 0.019302285145386122, 0.04770536768774036, 0.005029212898080004, 0.057718502066563815, 0.052847849947283976, 0.02139156815246679, 0.010596737047308125, 0.028092345310142264, 0.052138267710688524, 0.06547177821630612, 0.04236908469465561, 0.004611376798493438, 0.04256665182765573, 0.02270468157803407, 0.03588744148146361, 0.04222240291710477, 0.12363044064841233, 0.021347167312342208, 0.0180998185169301, 0.0938995742762927, 0.08249775171861984, 0.025949238042812794, 0.025580236651876476, 0.04094580130185932, 0.011554516659089131, 0.03700709370605182, 0.01943877352459822, 0.03617371381551493, 0.02281176235555904, 0.037780289130751044, 0.06022533962095622, 0.03330527964862995, 0.03333869855850935, 0.03755006749997847, 0.04258935041434597, 0.04463315461180173, 0.008538191941624973, 0.06275217805523425, 0.07160444132750854, 0.025810784827626776, 0.1023209243430756, 0.010766947689262452, 0.048409268783871084, 0.023881247252575122, 0.02979504359245766, 0.00412202410188911, 0.01624982618523063, 0.02257732532598311, 0.02558401789428899, 0.051261290354887024, 0.06363617983879521, 0.032571907868259586, 0.037113985235919245, 0.04572328420181293, 0.018007402577495668, 0.06406674423487857, 0.02142839537555119, 0.0633789440325927, 0.021403427672339603, 0.03694861617987044, 0.033737855264917016, 0.026822899853868876, 0.02031991803960409, 0.023148825421230868, 0.017270987991651054, 0.03304134224890731, 0.051331586582819, 0.06742511090124026, 0.01704284622974228, 0.03509205213049427, 0.038987436855677515, 0.034803894741344266, 0.015945942686812486, 0.05889424581255298, 0.021286893788783345, 0.04145320024690591, 0.04283390662749298, 0.03730951888428535, 0.043575497693382204, 0.05698020242562052, 0.06993023038376123, 0.006771549751647399, 0.05705633193429094, 0.07147732627345249, 0.04643177548132371, 0.04006272349215578, 0.05094632288091816, 0.05578779375355225, 0.03957601191359572, 0.031774043454788625, 0.04012596189568285, 0.0744505257171113, 0.027695203534676693, 0.07609762600623071, 0.05724277056287974, 0.059322535526007414, 0.02688497865165118, 0.018621592862473335, 0.07418699649861082, 0.03868114137731027, 0.04374438081867993, 0.04336098732892424, 0.0592256444360828, 0.07319749100133777, 0.028269592439755797, 0.04267761774826795, 0.030161722061166074, 0.01612192816537572, 0.05919340554100927, 0.04207791047520004, 0.022481334090116434, 0.039133729005698115, 0.03903995493601542, 0.03708275195094757, 0.0432453792745946, 0.07174867030698806, 0.022639606359007303, 0.005199754723435035, 0.01785777261829935, 0.03904595891071949, 0.030050570603634696, 0.04542735652648844, 0.016677622370480094, 0.03284933009126689, 0.06086544199206401, 0.03690140074468218, 0.033504954481031746, 0.08366017020307481, 0.043860326550202444, 0.062483772926498204, 0.08456331197521649, 0.005900289252167568, 0.022930461454961915, 0.044457525364123285, 0.0586667478637537, 0.025828136240306776, 0.02112901671353029, 0.14491407084278762, 0.13148058933438733, 0.10513215005630627, 0.15725992008810863, 0.1134063396602869, 0.07663320429855958, 0.09358779061585665, 0.16142963228048757, 0.09274474054109305, 0.11250092691625468, 0.1309963082894683, 0.18820906640030444, 0.1855017858906649, 0.1374005974503234, 0.11543637330760248, 0.10038775581051596, 0.10998322803061455, 0.1379302385612391, 0.15036498225526884, 0.17404060636181384, 0.1990756075247191, 0.13939234369900078, 0.14698381681228057, 0.12383165172650479, 0.07629157888004556, 0.1255853837938048, 0.1298578389105387, 0.1308349653845653, 0.09167545416858047, 0.2080984163330868, 0.0902825320372358, 0.10732947863289155, 0.19657455501146615, 0.11851172937895171, 0.09250409173546359, 0.1722254912601784, 0.2532872243318707, 0.13568819558713585, 0.13207478245021775, 0.10688045702408999, 0.0717172329314053, 0.1111901605327148, 0.13181307149352506, 0.11461036294349469, 0.12595412728842348, 0.17177518573589623, 0.11596871583606116, 0.10079352505272254, 0.25226050755009055, 0.1391748053720221, 0.15981131989974529, 0.11197213185369037, 0.0865648991020862, 0.16026690951548517, 0.13693749730009586, 0.26978062523994595, 0.10962117870803922, 0.13911641319282353, 0.12771895446348935, 0.24230284499935806, 0.13670648157130927, 0.1869125640951097, 0.085227511881385, 0.1748204996692948, 0.10390630763140507, 0.1370531239081174, 0.11968030768912286, 0.15207257500151172, 0.1304931173217483, 0.14693436009110883, 0.10017868538852781, 0.14180411584675312, 0.12268531558220275, 0.12991927389521152, 0.0990969012491405, 0.1595959041151218, 0.3121312824077904, 0.13728424353757873, 0.1833637326490134, 0.19350624934304506, 0.1535500871250406, 0.14749744237633422, 0.122478902048897, 0.1737531874096021, 0.118363693181891, 0.12086136150173843, 0.08378784186788835, 0.16491967078763992, 0.16521687124622986, 0.15051020571263507, 0.1146547582175117, 0.1430828362936154, 0.19195517554180697, 0.07175716789788567, 0.14200685574905947, 0.1007160299923271, 0.15783125505549833, 0.17544250848004594, 0.18724948429735377, 0.12274168911972083, 0.15610746864695102, 0.14053954073460773, 0.11021525308024138, 0.09148795797955245, 0.11868915462400764, 0.09778406427358277, 0.1529028156073764, 0.10934908510535024, 0.1518245047191158, 0.1370261691045016, 0.14824996527750045, 0.23214011220261455, 0.15766721073305234, 0.18472983356332406, 0.13425996206933632, 0.176169041369576, 0.1825255955918692, 0.14268286322476342, 0.1829449090291746, 0.12218603573273867, 0.11186102492501959, 0.12250650994246826, 0.1375776738859713, 0.1870466404943727, 0.10044102717074566, 0.2242718476918526, 0.09940688891219907, 0.14605156058678403, 0.10701365768909454, 0.214529111108277, 0.13055544288363308, 0.10762199613964185, 0.12180426012491807, 0.1428326583118178, 0.12454897456336766, 0.16159240010892972, 0.08356953170732595, 0.14135315723251551, 0.10187288979068398, 0.19801430666120723, 0.1180289252079092, 0.238288568216376, 0.10700030645239167, 0.16587033227551728, 0.1455940562300384, 0.15353787137428299, 0.11649256077362224, 0.13687747239600867, 0.18147539725759998, 0.05337015121767763, 0.17971996567212045, 0.12581467773998156, 0.12458768498618156, 0.12649800279177725, 0.22917983355000615, 0.15740541071863845, 0.08913295270758681, 0.08790354055236094, 0.21078128018416464, 0.09150622223387472, 0.16082565765827894, 0.13256909733172506, 0.13733374478761107, 0.14025994401890785, 0.1190404428052716, 0.15918919234536588, 0.1625467574922368, 0.12626484967768192, 0.2117117404122837, 0.16813910740893334, 0.08990609989268705, 0.18803448358085006, 0.128880430420395, 0.09325892271590419, 0.1038038096157834, 0.16143102751811966], [0.009496438178757671, 0.0492777448380366, 0.04198189883027226, 0.06481738950242288, 0.016666308329149615, 0.04943960353557486, 0.04622790380381048, 0.014773376260563964, 0.03774831369810272, 0.040432428068015724, 0.0335177565284539, 0.012181969123048475, 0.05031141183280852, 0.028030928879161365, 0.01128942058130633, 0.013033246832492296, 0.04313536701374687, 0.047733209357829764, 0.04019243977381848, 0.032447705743834376, 0.11807023314759135, 0.02586011352832429, 0.06822778814239427, 0.03944321571907494, 0.036886973393848166, 0.05642010357405525, 0.04492093721637502, 0.04776058718562126, 0.010631431523506762, 0.02555447670602007, 0.02322311069292482, 0.02391437672486063, 0.06587394804228097, 0.04864379116042983, 0.08138693476212211, 0.04008210467873141, 0.028122829025960527, 0.02339797738386551, 0.008096649326034822, 0.020256338248145767, 0.042971942384610884, 0.07869276058045216, 0.07589041095343418, 0.035341109469300136, 0.035733497788896784, 0.08910637639928609, 0.06142809012089856, 0.0389942571928259, 0.006829618632764323, 0.06343694287352264, 0.07799282626365311, 0.07347446793573909, 0.029373830257100053, 0.04611137177562341, 0.022757578153687064, 0.019637980803963728, 0.05761485743278172, 0.040349470800720155, 0.06662061539827846, 0.020607427904906217, 0.0726681541709695, 0.013436357330647297, 0.054801078731543384, 0.06178387571708299, 0.04475049187021796, 0.05185365407669451, 0.014764337829547003, 0.029874039646529127, 0.049074541093432344, 0.017630647598707583, 0.008339099695149343, 0.030026988861209247, 0.028140145186625887, 0.010021817506640218, 0.02979252029035706, 0.02895483594329562, 0.025627058748796117, 0.018987557014042977, 0.05162816363736056, 0.05066492274636403, 0.09286029293434694, 0.024462716246489435, 0.04237890701915603, 0.03569796746887732, 0.03960953101341147, 0.018960908346343786, 0.0373983910685638, 0.06247397657716647, 0.045393362452159636, 0.03345547920616809, 0.023669074653298594, 0.05528577166842297, 0.07606203260365874, 0.046635131366201676, 0.043692987092072144, 0.020616595284081995, 0.06712572110700421, 0.0692818827519659, 0.06414628762286156, 0.051223926930106245, 0.06728261854732409, 0.06859250177512877, 0.02843832156941062, 0.008653844524815213, 0.07431361431372352, 0.018217335746157914, 0.018724072324403096, 0.031968282055458985, 0.05383038296713494, 0.02690553057618672, 0.05963865703961346, 0.00388638780805195, 0.03098134809988551, 0.0539110618410632, 0.028258924066904, 0.10322878617444076, 0.028374200010148343, 0.007073456818034174, 0.024050082138273865, 0.04279705528460909, 0.05539103047340177, 0.024664877273608, 0.01426534556230763, 0.033398883024347015, 0.027193977402930614, 0.027412454546720255, 0.03273390015237965, 0.012832504235120723, 0.03343955642776564, 0.0703241846349556, 0.08742720790905878, 0.029607193027914036, 0.02692417889193166, 0.04216048553644214, 0.056397171210846864, 0.06671021488728002, 0.018017132133536506, 0.03774056938709691, 0.0436761329183355, 0.07291160087333992, 0.039212923584273085, 0.05800718266982585, 0.02224089123046724, 0.02086347813019529, 0.023099639583961107, 0.025546815886627883, 0.020450354204513133, 0.07592037145514041, 0.06725098079186864, 0.02597779588541016, 0.04527636287093628, 0.11173593593412079, 0.05311510103638284, 0.028998622656217776, 0.08914647463825531, 0.00363181979082583, 0.08374440396437421, 0.03554774935764726, 0.030342319987539668, 0.10455203548190184, 0.05793704971438274, 0.044373132041073404, 0.08662720982101746, 0.0390963507379638, 0.055556173174409196, 0.14859433664241806, 0.05535105839953758, 0.10250266146613285, 0.039540945435874164, 0.012438575959095033, 0.0293425914060208, 0.0437813026655931, 0.05419566063210368, 0.0373518695414532, 0.05611640932329465, 0.046482582911266945, 0.023367994617728982, 0.032082810284919105, 0.07291920788702555, 0.04275439292541705, 0.07170937358750962, 0.04097025877854321, 0.03455633654084522, 0.01299011506489478, 0.05603229801636189, 0.03679285422549583, 0.021661644968844485, 0.006010956458339933, 0.11710844686604105, 0.017563635374244768, 0.012115309418732068, 0.05029958570958115, 0.11868635672726668, 0.021564011731243227, 0.05014375325117726, 0.0264358512868057, 0.08123169973259792, 0.007257867064254242, 0.04913066601147875, 0.023876855593698565, 0.04826681724807713, 0.010118690970557509, 0.030875104093865957, 0.021944050713500474, 0.05431876066722907, 0.0682665802014526, 0.026724956769612618, 0.04133243055548519, 0.06110333000833634, 0.013886554315831745, 0.022068967155064456, 0.03708194300998002, 0.021195043736952357, 0.014742568782821763, 0.028671929248957895, 0.0013956837324258231, 0.06914466706803069, 0.05503380511072464, 0.0632770026277285, 0.028455839965317864, 0.08148151406203397, 0.028790357464458793, 0.044716557167703286, 0.04890785101451911, 0.016309530110447668, 0.08537012297892943, 0.038714497204637155, 0.01593012009834638, 0.025947460599127226, 0.023691006972512696, 0.028580648795468733, 0.027272572697256692, 0.02801681879645912, 0.02052973988611484, 0.008021522644412471, 0.05270662666589487, 0.010102936103066895, 0.02038427337538451, 0.10458772536367178, 0.022787011730542872, 0.01897001449833624, 0.03693923543323763, 0.03392170008737594, 0.04050981180625968, 0.020922458461427595, 0.048073146390379407, 0.011458503158792155, 0.05170620417629834, 0.003232326334909885, 0.026449295291968156, 0.017050863280019257, 0.05181276545044966, 0.023171395987446886, 0.03928420315787662, 0.07195518774096854, 0.014026253411429934, 0.053367264263215475, 0.037229018125799485, 0.03905464574927464, 0.03307507657154929, 0.050703729648375884, 0.03716843290021643, 0.07413063780404627, 0.02929453919932712, 0.061606680537806824, 0.06011836274410598, 0.02066152675979538, 0.011565659078769386, 0.0384643303550547, 0.03236321223084815, 0.038492899329867214, 0.007950054750835989, 0.04318060091463849, 0.03196094221493695, 0.004799620701305685, 0.031900998947094195, 0.026845726461033337, 0.028936608796357177, 0.03421029534365516, 0.015887298177403864, 0.026833883639483247, 0.056518230339861475, 0.06042230190359987, 0.030263845292211045, 0.07389774444163777, 0.031248009181581438, 0.016815283343021292, 0.03130315075395629, 0.1370803904137574, 0.017852961645985488, 0.035626728713396005, 0.028956952919543255, 0.060470033131423406, 0.03465463400061708, 0.035177543832105584, 0.02783313724648906, 0.057458164083072916, 0.04156107512244489, 0.02608682665595552, 0.03972825608798303, 0.013830767074978212, 0.08490924927173182, 0.06684550098725595, 0.05034135378082283, 0.011231475546082947, 0.018871750435209833, 0.026299030796508305, 0.035303007607581094, 0.04739020725537557, 0.01669644880166743, 0.06497024223790504, 0.007463140937034041, 0.055787062738090754, 0.04060476960148662, 0.023763130739098415, 0.04098102363059297, 0.03101504160440527, 0.019939802987209987, 0.018219599296571687, 0.012832379925384885, 0.06579942899406888, 0.03174154851876665, 0.05938401503954083, 0.038884018576936796, 0.04353276854089927, 0.012805219175788807, 0.052491092137643136, 0.0806760166597087, 0.08335519203683361, 0.036898747566738166, 0.016643394519633148, 0.09122843635850586, 0.07112320308806375, 0.07103752213879488, 0.024613151435914915, 0.04618017628672533, 0.04723572179500479, 0.03563427264452912, 0.04305574198951945, 0.04134890252316836, 0.051558802515501156, 0.052597367684938945, 0.01610644510947168, 0.11896288095158525, 0.037238614095258527, 0.009737602777022403, 0.012463650346035138, 0.06766589329345152, 0.060551843780558556, 0.004699479468399659, 0.053959687356837094, 0.05107642507937271, 0.11779494830989279, 0.14705421694088727, 0.14855979708954692, 0.059131647722097114, 0.1343047432601452, 0.12096061633201316, 0.1572899176971987, 0.14779928867937997, 0.14943985064746812, 0.06661005463683978, 0.15537783358013257, 0.08379040969884954, 0.21664960513589904, 0.09520519757643342, 0.15374083392089233, 0.17142682161647826, 0.3018285508733243, 0.15618607692886144, 0.12100156061933376, 0.17169022466987371, 0.20827497326536104, 0.1415420338162221, 0.15763243369292468, 0.18745376786682755, 0.13548967108363286, 0.1666695362655446, 0.15536061575403437, 0.15955974668031558, 0.10117122626979835, 0.1390208097291179, 0.06492548331152648, 0.1542611833428964, 0.20157674909569323, 0.12091564960428514, 0.12611947779078037, 0.13445516175124794, 0.14693504286697134, 0.08682254308951087, 0.12923771515488625, 0.07113923347787932, 0.19226916338084266, 0.19010468968190253, 0.18955875100800768, 0.11528710514539853, 0.1292539236601442, 0.1426778463064693, 0.17732030537445098, 0.1353737773024477, 0.1405203784815967, 0.13019946432905272, 0.16139956045662984, 0.20510080765234306, 0.11280801278189756, 0.11126514713396318, 0.16995474201394245, 0.10233631648588926, 0.16081271460279822, 0.12055530722136609, 0.13942208897788078, 0.25236348796170205, 0.10083453613333404, 0.20705673785414547, 0.1573001593351364, 0.2507445076480508, 0.14400936313904822, 0.14234683359973133, 0.1448922517010942, 0.12489578017266467, 0.2489197297836654, 0.11178744098288007, 0.12737903598463163, 0.15750000486150384, 0.10844261851161718, 0.14362656336743385, 0.0849115350865759, 0.2107925756718032, 0.17399027390638366, 0.09822208725381643, 0.20920004550134763, 0.18060134025290608, 0.19281404820503667, 0.0827195870806463, 0.14109606243437156, 0.10033032100182027, 0.15969398635206744, 0.12022596434690058, 0.10609634831780568, 0.15915450436295941, 0.16180548554984853, 0.09544593543978408, 0.1973054962581955, 0.10881167370826006, 0.1582973831682466, 0.14388012554263696, 0.20447529590455815, 0.081735714484239, 0.11384370212908834, 0.10544041593675502, 0.1671996375080198, 0.1871601742459461, 0.23217423615278676, 0.15126066544326022, 0.18649785197339952, 0.04389131863717921, 0.11509727861266583, 0.15241865330608562, 0.134770440927241, 0.13207447074819356, 0.22324299352476373, 0.07320799981243908, 0.22085030941525474, 0.09285521664423868, 0.17151725973235443, 0.15446968231117353, 0.18860298354411498, 0.23452564200852066, 0.1696177921257913, 0.12840033508837223, 0.1257975192856975, 0.13578955811681226, 0.1906267015147023, 0.0824208281119354, 0.06589601209270768, 0.14135430013993755, 0.14755414245883003, 0.1866348969633691, 0.17030015238560736, 0.15889865637291223, 0.09759519511135295, 0.17186807293910533, 0.2657716325484216, 0.1661942055216059, 0.10067155308206566, 0.08564643198042177, 0.14810849708737805, 0.08310648350743577, 0.11616661693551578, 0.11244254958000965, 0.14164039806928486, 0.22678854467812926, 0.26479069143533707, 0.13581807143054903, 0.11890958732692525, 0.10303276270860806, 0.11531023046700284, 0.09708397410577163, 0.17673653201200068, 0.16763379389885813, 0.11733146966435015, 0.13445502816466615, 0.06355185701977462, 0.17347189859719947, 0.15357114927610382, 0.07799409533618018, 0.14532207394950092, 0.19989768450614065, 0.16984573536319658, 0.15644214756321162, 0.12427889960235916, 0.13543654815293849, 0.17038162535754964, 0.1313940846011974, 0.21228205121587962, 0.09474838341702707, 0.16677187843015417, 0.2508809737628326, 0.14551488391589373, 0.18330286169657484, 0.0900383951375261, 0.11409860759158619, 0.12893273698864505, 0.13197315274737775, 0.20868894323939458, 0.11552949057659134, 0.08042949746595696, 0.13592115574283525], [0.02180893159675179, 0.0548259740753565, 0.0675795815186575, 0.021322329484974034, 0.05622872224193998, 0.049313891140627675, 0.039631327890674584, 0.022551051442860626, 0.03506955392367672, 0.014592620627809083, 0.04416844771185424, 0.12006606862996705, 0.028083031356800348, 0.04804046962817665, 0.03745242313016206, 0.022924887925910298, 0.06119670331827365, 0.04923632928694133, 0.05005280676414259, 0.05972441962512676, 0.05752419296186417, 0.027454532464616932, 0.034574482051539235, 0.08678202182636596, 0.07007336840615608, 0.04598417137458455, 0.11374274778063409, 0.058239627032889985, 0.044718943172483705, 0.08698737408849411, 0.03133984995656647, 0.025745635393832345, 0.043653237662510946, 0.0017667223187345371, 0.03369356018083636, 0.035571735570556484, 0.035120543179800734, 0.02281246368511347, 0.032403740915469825, 0.011099526327598142, 0.025558098386682104, 0.014237802606658079, 0.05113405284646433, 0.013897001899749739, 0.025804760443861596, 0.04369484246126376, 0.01761527772032423, 0.02816785327013349, 0.018098857435688842, 0.016959016938926652, 0.029821812859154306, 0.12333729973761365, 0.08858311775838956, 0.019776200242631603, 0.019950395289924927, 0.060517760648508556, 0.02997218496602727, 0.07214709228719585, 0.06223811462405138, 0.003277850369158841, 0.05501257226569578, 0.010896994226641254, 0.02720061591389822, 0.05055363770225085, 0.01781173163180938, 0.05843678969540633, 0.0040868059477361385, 0.08356732752872631, 0.0523113884992199, 0.040570493511040695, 0.062854705756763, 0.02157884169719182, 0.12121489096898586, 0.035396273306105286, 0.036419910175027326, 0.04717688061646186, 0.023961454862728715, 0.05306720282533206, 0.0148870157681813, 0.031857954381848685, 0.026857795637624804, 0.04894384146609809, 0.03972043014073279, 0.03973011516791303, 0.08651475960505195, 0.044897541010868736, 0.04674420481023844, 0.04237586421368178, 0.03454292593232822, 0.028060032200301066, 0.03656801316537894, 0.055448116472689435, 0.05330800748197362, 0.047818255770835094, 0.03200763443601318, 0.06152117028250359, 0.004729663542093476, 0.01851629509474151, 0.03673566803627182, 0.01840866512793582, 0.013906904005125398, 0.04764456723933108, 0.08184013466234319, 0.027705489701475017, 0.028645293568843044, 0.020930777936882805, 0.05167455157788936, 0.02371357197262114, 0.06663324675173499, 0.021519286201510113, 0.050055018364218995, 0.024921732729126234, 0.027277866065560374, 0.06580411194590852, 0.024741177476244047, 0.08805070101516321, 0.02823343686031876, 0.03495249125990085, 0.05371405874029733, 0.03484366643533576, 0.06171116008772515, 0.05310900800395757, 0.04369484988274053, 0.004478209530134336, 0.06406037660781294, 0.040131156929419376, 0.07513707911130041, 0.01899244962260127, 0.03382555856660474, 0.02669184028491145, 0.028132660627306905, 0.013388393253990216, 0.01624571468710201, 0.03652735089417547, 0.037479466991499066, 0.0445250236953143, 0.02901092932006577, 0.06871922349091619, 0.0212511167046614, 0.07120179652702063, 0.04076608282048255, 0.09742775917402469, 0.020437962193682324, 0.057494551583658904, 0.02918284597399179, 0.03285734899691306, 0.010783609832287766, 0.028351961555017624, 0.0461198508128291, 0.027063702655141242, 0.03913432272383943, 0.032922216414590366, 0.03363429226737935, 0.031785784231033176, 0.05170106109289918, 0.022477836719190236, 0.03024976118467748, 0.01882077045593178, 0.01869280378741678, 0.05554821364057716, 0.03859113741782494, 0.028466365474741906, 0.051876749712391756, 0.02668747831194196, 0.08066243535722606, 0.05758937950304244, 0.05749356823798735, 0.013830735533701954, 0.005237037439655978, 0.03159373125527054, 0.029923427719040774, 0.027499784919200465, 0.060972830760874785, 0.03858645817672368, 0.04757718023029156, 0.010876892229134683, 0.01662292608671123, 0.02632593736052513, 0.07376348992693238, 0.06311726276180707, 0.02176373851398239, 0.010903447200689698, 0.016340067631972488, 0.021977376854920294, 0.0674373192305211, 0.06879272579681128, 0.0589231673075119, 0.05317178256518673, 0.07606253726407886, 0.04145290709857363, 0.05039493313233834, 0.015790377401572186, 0.05626405218208674, 0.03937943925848231, 0.045728523764410056, 0.021038814229541458, 0.029169400113460142, 0.02064978783892002, 0.015076718918862753, 0.03469816096185241, 0.04877468745689839, 0.06573331105755642, 0.05006833620427642, 0.08715303629287519, 0.039384140764013864, 0.015627830362063833, 0.03579641335818451, 0.013963057681394275, 0.04180550517048687, 0.0069694406465714565, 0.025061852065846324, 0.026419329224154353, 0.06344007473671809, 0.029362250897975173, 0.02351976938371081, 0.024960984919744078, 0.01724607038340764, 0.025675660144770518, 0.045429256424540654, 0.04331995027314406, 0.01235899917446659, 0.05876882656593807, 0.044879317574668676, 0.028738457222061697, 0.031622997848899104, 0.003439647607592633, 0.02612715310533531, 0.03448139817919582, 0.028840771556133404, 0.020246523345122114, 0.08051819895626977, 0.030521762018906884, 0.03754669814952649, 0.05834878953464795, 0.021710752880608197, 0.021075058866699692, 0.07830399394151755, 0.0444315835920861, 0.026821315368579235, 0.030173728155205026, 0.022928086582396645, 0.036475508168223314, 0.0407767623255495, 0.026307040425308514, 0.04192271255305968, 0.09251177296391688, 0.009502521006652387, 0.06387360030203126, 0.058825545202125795, 0.022173765828483738, 0.07443275870173238, 0.10556447334238328, 0.0017200570005115878, 0.05221937331953086, 0.019407081963436212, 0.004949598078383133, 0.0233989533080603, 0.03388768745935522, 0.07555832213256508, 0.08147336528054439, 0.03508670866722241, 0.057476305883028544, 0.07345831880229525, 0.04259484230715316, 0.06646410387475044, 0.052863858072669245, 0.08517129419487901, 0.012547302449092967, 0.05182150052860379, 0.01571806067659054, 0.033598528170841746, 0.019898096143151633, 0.004330194205977023, 0.039991095109144226, 0.015466148852283368, 0.01605426656169584, 0.019666228799906094, 0.0447111543326173, 0.05693235987564549, 0.03816916709183715, 0.032617590768495575, 0.03456770624325145, 0.02242726863187272, 0.03281692050222773, 0.029012827362748794, 0.029132454146747477, 0.04906956870399881, 0.027796361973742023, 0.03523118997691199, 0.06378707330441102, 0.012945103808306158, 0.08854803643771447, 0.09357451359392144, 0.009836650733632268, 0.03796503195189871, 0.046334476210176945, 0.06754295653081499, 0.04359331294836011, 0.046416138429776765, 0.014550463856721763, 0.05826130887726322, 0.08226217920309864, 0.0631012546364218, 0.05738248357374687, 0.032475428670295514, 0.01749338367517339, 0.012495994997152593, 0.0160669350225362, 0.04453533583728131, 0.0009744423346091935, 0.04215841865516268, 0.07886375882662833, 0.017078261516871862, 0.0330250780825736, 0.014854655346425716, 0.04459029558347538, 0.028189073127578013, 0.08079480481683277, 0.009202273104165215, 0.013436990011541639, 0.04224370626616292, 0.07049322361126542, 0.015541286666120868, 0.04256421758327633, 0.022371774539351463, 0.010328861626476282, 0.0029676147823920473, 0.009141485643340275, 0.058542141268844716, 0.043840956495841965, 0.02540800272981869, 0.015253342644427903, 0.03763906213862356, 0.041408671386307105, 0.06539565612911247, 0.052848673731205054, 0.049208921773242764, 0.024299094948219135, 0.0653746459283866, 0.022697989261359908, 0.039822378967073746, 0.09477118219365366, 0.019408907646720763, 0.046996683449833654, 0.062095559187582694, 0.054733075739932247, 0.0645231873204466, 0.0052633442555816146, 0.09576214230037294, 0.08140038247802295, 0.006452574680224643, 0.03934166765247937, 0.1239119224192109, 0.17440336814615875, 0.26390747632831335, 0.18295740679604933, 0.14532542845699936, 0.17375729890773073, 0.08396026503760368, 0.11972522988799028, 0.13014025578740984, 0.131837606895715, 0.08631239819806069, 0.211930688819848, 0.1660939265275374, 0.21617737656924874, 0.22433271864429116, 0.06940815917914733, 0.07950379440444522, 0.18067708384478465, 0.13211570447310805, 0.1000562087574508, 0.12180748846731149, 0.11395090536097996, 0.08805106466752477, 0.21918669634032995, 0.1766983262496069, 0.147198312333785, 0.1735877775354311, 0.22991735022515059, 0.20561426994390786, 0.15416007314343005, 0.16818664938909933, 0.19691960915224627, 0.10421656246762723, 0.08170596178388223, 0.06331226948532276, 0.07133495266316459, 0.10789505453431047, 0.14219582139048725, 0.13626828789710999, 0.18934556166641414, 0.10893497412325814, 0.20431071723578498, 0.15457766479812562, 0.1308813941432163, 0.13597326935268939, 0.1667309267213568, 0.11874520903802477, 0.10505159734748304, 0.18669346725801006, 0.12171439346275292, 0.07887851272244006, 0.18844253121642396, 0.16244713158812374, 0.15961291413987055, 0.15799031214555725, 0.16855157824466005, 0.10225502905086614, 0.08557983906939626, 0.10678417078452185, 0.11712757201166824, 0.1604129938641563, 0.16874833643669263, 0.11974006542004645, 0.17436407884815708, 0.07038370487862267, 0.09781896747881547, 0.1015363926126156, 0.17233377060620114, 0.1479529874632135, 0.1963298540795222, 0.13975283451145515, 0.1137460206518881, 0.18870544445235282, 0.08425320556852967, 0.20285098697058856, 0.1861167888273485, 0.10040142617071979, 0.18212816066807136, 0.09286604457884096, 0.12079231208190322, 0.10181911377003416, 0.16817624447867274, 0.15206110139843076, 0.1590253706672229, 0.17413851048331708, 0.1942215461167507, 0.14008408470544964, 0.12037879481795244, 0.1172786955430638, 0.11981399075011723, 0.1352572749601677, 0.1628231184440665, 0.1299469411605969, 0.1599449510104023, 0.09247722598956898, 0.10429937872686423, 0.07153561455197632, 0.1619202215806581, 0.0846051616827026, 0.07109793295967393, 0.11707279409165494, 0.09153036429779604, 0.20827178203035146, 0.14131324453046545, 0.08464029495371506, 0.08734851056942716, 0.08981732418760657, 0.08049521464272402, 0.16443258442450315, 0.13997691858094186, 0.1704652950866148, 0.12357241954305209, 0.12965391157194972, 0.1675839809468016, 0.14635253115557134, 0.15192727732937783, 0.17375056020682678, 0.15701024676673114, 0.10340279754018411, 0.1029719140205998, 0.23893738340120763, 0.12757598713506013, 0.09017790405778214, 0.12508428568253294, 0.20573699148371816, 0.09800912055652589, 0.2150410445756279, 0.11232432545511983, 0.17474255932029337, 0.11881727157742716, 0.09326731640612707, 0.09655716057750396, 0.16369526070775464, 0.1454400160582736, 0.17559145751874894, 0.19722222728887573, 0.1431533700088039, 0.17131687985965982, 0.0727439793990925, 0.32446993282064795, 0.18906289245933294, 0.2675599412759766, 0.0926523060479667, 0.13177988264942542, 0.10636008533765562, 0.11731560254702345, 0.15751128550618887, 0.08481557539198548, 0.1787911233259365, 0.10996526063536294, 0.1527437288314104, 0.08228770166169852, 0.12792243651347235, 0.23109362460672855, 0.2618140261620283, 0.11634228329057805, 0.1668517928919755, 0.14343366434331983, 0.13862233579857275, 0.12463102641049773, 0.14392334822332487, 0.07063058772473596, 0.18821642850525677, 0.14625778858317062, 0.1863775943638757, 0.13728443649597466, 0.08325988543219864, 0.084974454366602, 0.13654596987180412, 0.11744327421183698, 0.10765319602796808, 0.1246057340176776, 0.14979658619267866, 0.2719358814647421, 0.12705805711448193, 0.08514089582604356], [0.06389984264387749, 0.01670343983278144, 0.037679475790355355, 0.08684448839630932, 0.011823864315374522, 0.011146143406222109, 0.054763989901402965, 0.023367243193206377, 0.042115782271139324, 0.051150962681276724, 0.022055743938835803, 0.04556659085210413, 0.08669235554407351, 0.0024711912737984676, 0.04851618257816881, 0.043019016811740585, 0.02735329053393798, 0.01696492628980195, 0.02639740618178621, 0.03730143318534829, 0.05168944648175966, 0.009102567419176921, 0.07285988802323118, 0.005849063900313922, 0.04380148537165951, 0.027225661542615853, 0.06741097298800014, 0.05155176324478816, 0.11515052028698847, 0.011770544715545839, 0.02126673705788562, 0.026873831593547948, 0.032089856977108866, 0.032348747772630304, 0.05869225176866166, 0.020799026315216906, 0.08367413000087254, 0.05146441617398523, 0.05246043030638248, 0.05389192185248248, 0.020007878338219598, 0.046589949415647425, 0.04360463812190574, 0.04268061231414322, 0.0907313458446879, 0.02422690438834252, 0.034741465278784744, 0.04422231650096364, 0.040004060429055244, 0.04540295842161868, 0.06686257038381882, 0.045069314801367, 0.028293612049310468, 0.0796652931603603, 0.05329046311089769, 0.06222425501619, 0.054519968034583144, 0.029450332694977988, 0.017736648551363032, 0.12392408621963114, 0.011127509933430701, 0.01802102469810052, 0.028064319958502892, 0.023501677678723354, 0.04450995067600161, 0.011496477000036975, 0.02812512597301975, 0.07706093369051814, 0.010406118271930609, 0.05181287677260116, 0.07391154096694663, 0.03569231601431966, 0.03173516604874749, 0.030848603855702095, 0.03160054788168054, 0.07602688448969275, 0.070396247174358, 0.026232354393869173, 0.06714293893310241, 0.02882370215957053, 0.017303798340435605, 0.04144358943449333, 0.02151214674086077, 0.04872924204391893, 0.013296005145093659, 0.022012094523233827, 0.050540995216579176, 0.014716222540300805, 0.10720787031459622, 0.020922517833241727, 0.03104628045548452, 0.013693275868718047, 0.049895631018443964, 0.018194358854088932, 0.05106669181259349, 0.015092724261194235, 0.01797412653104402, 0.047630202971049584, 0.04822095623239875, 0.013644486152770696, 0.061209587001940235, 0.027268090125289746, 0.01922738203575136, 0.05522652601939626, 0.030173208651831374, 0.043933472625212744, 0.07545083688455634, 0.0305796996326535, 0.027006165801140014, 0.04196886671707034, 0.05060348776169121, 0.06334398145554587, 0.02606470137834549, 0.02297048362379428, 0.017178766865981743, 0.0251765008943039, 0.020631740662793163, 0.020666538111981936, 0.05541334314330015, 0.08307266383781098, 0.028698229107249063, 0.025445043320360128, 0.027505662728799507, 0.07453907135641202, 0.032895658659981564, 0.033401076070731506, 0.03117229527560994, 0.03905940291588195, 0.03351495492097456, 0.044323074180283584, 0.026157891006732825, 0.04550384597678203, 0.015736130117147695, 0.0554139739688253, 0.042317275365348905, 0.017636890916037373, 0.03161610700772144, 0.07852308335714042, 0.09007549509988166, 0.021002395187679213, 0.09332824673037976, 0.07176414408604614, 0.08010561679839157, 0.056434731304761954, 0.011324769075145014, 0.04850437500863336, 0.0760610455472488, 0.08643197303172201, 0.042011135737993754, 0.02722024200920714, 0.03735015146958176, 0.06730049688485451, 0.047069818392628804, 0.056337372661801055, 0.03164001529512461, 0.053100614313734695, 0.0826171187509317, 0.032017226694733836, 0.05241414255579002, 0.026987677047145553, 0.09127681696554646, 0.018553803238319233, 0.044720215955749154, 0.03284940430603456, 0.0636605074396357, 0.06851090263808146, 0.04996823161491193, 0.0418421041831607, 0.025190575724991504, 0.029744720413873438, 0.0090125838687527, 0.018890782812377438, 0.06137413227406796, 0.03868159408739302, 0.03524992549500894, 0.055988611493376084, 0.07540829697973095, 0.03258561162510887, 0.00853361567351385, 0.02643038722453639, 0.06321472901618108, 0.03419119988393504, 0.062362082971958444, 0.053019434490124695, 0.059542252056417055, 0.054297008318826556, 0.04268251592293382, 0.08597015679697506, 0.028610073095478583, 0.022379296206054278, 0.0543289132474456, 0.026786866728798486, 0.053814348866580985, 0.02975020859594224, 0.029321033871383406, 0.03320717143651564, 0.004415982766658999, 0.020761970881721936, 0.03343675110954791, 0.05363145399314817, 0.05281636804284062, 0.04522358132817317, 0.04578371357638389, 0.04072307165188249, 0.032738074733060785, 0.16780922276666388, 0.0352265849505784, 0.027341340100974776, 0.024051276996033266, 0.06880899367388338, 0.06790021900087595, 0.03474743956758175, 0.0903865514555946, 0.03959169720474165, 0.043213485478190705, 0.028413172040018253, 0.011239532486797543, 0.02671428839676082, 0.05733707897888962, 0.01841425349994097, 0.020108979260839988, 0.024815021170070395, 0.05528703703021165, 0.04483795026317239, 0.07589650398585945, 0.024106993732857518, 0.01691919514996698, 0.025937283899111208, 0.023415683172061108, 0.039969609933905303, 0.04367867106338963, 0.040081774423015304, 0.03005261893122224, 0.03503861007629894, 0.03568994114175439, 0.08958970749517903, 0.04779696726473048, 0.0032756464224803494, 0.015490570149268024, 0.0873969505482819, 0.042003595517599024, 0.004346723226262839, 0.05258920406049583, 0.025366373811266385, 0.09875759875285439, 0.03401698071684223, 0.01305937692450243, 0.008901846158551052, 0.016152525058714673, 0.0542018093256047, 0.03204833381460048, 0.0418985853320919, 0.008432442391494988, 0.025811690247792285, 0.05168215117009822, 0.06590747827431187, 0.01924232146848226, 0.08765106933424249, 0.008866444786690408, 0.07932882566819899, 0.03058714708458865, 0.018670901154109742, 0.021979710909363348, 0.013120913954480784, 0.06646380701567978, 0.028330433706287295, 0.02732692017161753, 0.054670668541803025, 0.030530209514836315, 0.030527923699992243, 0.022038991810404696, 0.020266297869966365, 0.0622817974362988, 0.020980607587262057, 0.03989640448708087, 0.007056064587231958, 0.029566961202363018, 0.03559142474841792, 0.014546279999194667, 0.05674329033354297, 0.04419508339196909, 0.024618695279059466, 0.11711479222867638, 0.022844029081170447, 0.03503040934447199, 0.04838353852392174, 0.0163181983953109, 0.018097528991347644, 0.0202091673418181, 0.019009140523849055, 0.01359764550215914, 0.022248804380069487, 0.026106528821401298, 0.0649285112740472, 0.04436990369867999, 0.054797497869003564, 0.011136744105897378, 0.014429857437789906, 0.10915930310147814, 0.04078249912708998, 0.020542645834211726, 0.003665631575131556, 0.04444050420715939, 0.028839713995694183, 0.030550358824257273, 0.07387119781924412, 0.02747725146036828, 0.004854778508160962, 0.047973546461435035, 0.045946974933031015, 0.03939913585782051, 0.07040366865112446, 0.0759741326328367, 0.06745647406205535, 0.11240019521210343, 0.047295019394368865, 0.0433413204154931, 0.04984743965906091, 0.01910865325044142, 0.039440280525013804, 0.025122470688074827, 0.005529429245143547, 0.03756053549295757, 0.013497453710442642, 0.045676491790800355, 0.012020381309412187, 0.05194441131607164, 0.05924429089645855, 0.05359379370929673, 0.10677608879632317, 0.04060638748342171, 0.02806543132464867, 0.04088915688043926, 0.025961997416743543, 0.052437267877394333, 0.06325530965114012, 0.04184483157587238, 0.025759437485248782, 0.06916899466887116, 0.023243764662765898, 0.03891778629622422, 0.005835028032379341, 0.02345208551560063, 0.03315376648970414, 0.06081785548303742, 0.06488777478807606, 0.02430025826470228, 0.004547116550384089, 0.02412089230347192, 0.0553422676603077, 0.06011726436554454, 0.06151228677481413, 0.15649452834622934, 0.08173555121175013, 0.0787568895611912, 0.14438582496950403, 0.0823294919973705, 0.13280504092108458, 0.128735770995263, 0.15799785236595199, 0.14861357311019674, 0.1213919822475873, 0.1602151818224229, 0.20477347599808127, 0.21041304134996608, 0.12696963764028624, 0.18705584312556311, 0.13424186850897968, 0.1149648052523844, 0.09152682425337844, 0.07236638950416818, 0.12644397444091737, 0.15135819849092513, 0.07763602392515168, 0.13844462111592293, 0.1570245553739369, 0.12937559135025367, 0.13418304588412866, 0.15838563936995342, 0.15461720642633736, 0.25400312966667116, 0.16203292412683368, 0.14366019750013947, 0.17526998883113265, 0.11669923405861482, 0.15840971464058384, 0.3151324385544285, 0.12253683409653604, 0.2301870912197046, 0.15894468437181786, 0.13501472625648603, 0.35799054661765695, 0.10298597771907225, 0.15720887517090887, 0.19744853780139238, 0.09770468415808864, 0.20205138222081587, 0.0704430544283241, 0.1394244490074925, 0.2136501856148243, 0.17243369336938486, 0.10553838685154915, 0.14515737653709948, 0.19494135514833033, 0.10003571806009859, 0.10181256802752614, 0.1191953438683413, 0.13128580525517464, 0.10972196978400461, 0.0804724232875742, 0.1048991602146998, 0.2159033904899843, 0.07267880399012938, 0.06406310028978623, 0.09099057802814059, 0.12497689691372216, 0.11499013475258835, 0.12855259410571307, 0.1690134167438373, 0.17083605722291395, 0.3016088157892227, 0.08745758401346393, 0.17659427714534104, 0.09157435139059089, 0.119912926456891, 0.13886250962968916, 0.08510124287568033, 0.21647077723173425, 0.1965713340905495, 0.11434523810748942, 0.1493438909528777, 0.18718821258516982, 0.17827898205723614, 0.12745304295094684, 0.07701234528212808, 0.16387165436754003, 0.08777414710493758, 0.15353027178207412, 0.13359121279790998, 0.1040467516577337, 0.23991186782950535, 0.12501488003181294, 0.13407829916104674, 0.06569221834070049, 0.1549338363111019, 0.08561394075513817, 0.1720911922166124, 0.11120325943920761, 0.07941977586597204, 0.1654669304843992, 0.08710599897312932, 0.09424598654732108, 0.16703357454389334, 0.10814475754159503, 0.09363569624838419, 0.1375036223907955, 0.11525941561558284, 0.09651303247665055, 0.26284822379238904, 0.1386895595351234, 0.10681564526748843, 0.12705413857474923, 0.11982820287812501, 0.131525504111778, 0.1625704616890289, 0.08263844065368176, 0.10698394209612161, 0.19352927076397464, 0.09296430493122898, 0.12741537153488025, 0.13355455070268363, 0.21413982496596873, 0.06720780264004134, 0.16147445800015703, 0.14573190273949876, 0.16011448722565547, 0.10510181848076172, 0.12681874417467043, 0.1718224902288057, 0.1554063765797764, 0.0929699229891412, 0.23780600895406678, 0.13326140237040818, 0.14581009541871026, 0.08167783438693732, 0.13016342563787475, 0.15121865988476202, 0.14426262845518067, 0.1509498688392341, 0.1847726703272201, 0.14629687007982284, 0.09494221012573689, 0.1469553034985438, 0.1937190824537538, 0.1629069514456205, 0.16999128536554053, 0.1530377528979443, 0.12751924252370372, 0.19305763591546565, 0.16982250614091754, 0.0900270625425037, 0.10293039085809141, 0.08401774437515996, 0.1307607357739471, 0.2214220748282969, 0.14166733802994713, 0.14601267204852775, 0.11715045242453925, 0.15393462352221832, 0.09173688173177652, 0.09817568075959571, 0.16208681889111176, 0.1608937422861345, 0.09135610060184263, 0.10321163514163345, 0.08452049005427398, 0.13881382474210113, 0.10777163537568413, 0.14520487398840487, 0.13568043272243813, 0.15098742151167244, 0.1457433614996262, 0.1353836478665471, 0.0932302387082018, 0.1084147063374985, 0.1206343385274522, 0.19834773876937106, 0.13093726302031428], [0.02931300383352209, 0.03674069979751948, 0.06672277944744565, 0.07785241192323156, 0.06053247743693646, 0.02317189508175943, 0.03374124316906091, 0.07513102318625897, 0.06979720783419907, 0.011000360555044608, 0.06380750462994911, 0.040142689904314466, 0.011094759884144878, 0.07152419289923273, 0.10190635322942398, 0.040322549393749796, 0.050488963242969476, 0.014894478063069982, 0.014888220830471255, 0.0710308799170889, 0.06829958350863308, 0.04008960408100393, 0.05943500429566484, 0.07580237739603035, 0.013683191009477014, 0.05737650557421148, 0.035344827629160136, 0.028260040999157354, 0.06519555085105821, 0.05834587660501711, 0.03642508294433355, 0.02667649823706597, 0.03497556834190618, 0.040996278476086445, 0.06361363339237869, 0.053565232155960985, 0.034130243584513664, 0.08473354580928572, 0.02014368394156918, 0.047312853203038685, 0.03271564331953414, 0.02727525556110777, 0.053551483870251104, 0.016802132486191113, 0.017357871220156085, 0.02841070068825502, 0.06263479255721904, 0.0352735480555566, 0.03221038918127306, 0.03352113701112103, 0.03553047215973493, 0.009865776319202268, 0.0467581794509897, 0.021650581402354874, 0.04736292590678204, 0.032975268841255456, 0.05941353025264107, 0.05794842683826573, 0.013223169844422955, 0.05199662140512373, 0.03876042501360644, 0.01992137731576804, 0.022398456603696104, 0.026357135393482167, 0.04663165811507497, 0.06199119095981587, 0.02165309171687113, 0.01438773499103263, 0.035489765359670855, 0.025158264470519498, 0.02444139990984695, 0.03613794229750056, 0.05260360543616116, 0.032797520761960186, 0.047598598612239584, 0.05391005994169973, 0.0805206257791724, 0.02315865331183886, 0.022294754453469068, 0.043838318160851486, 0.03760448547836859, 0.04823314229724929, 0.023637692938791588, 0.030669076477352064, 0.06335703583317809, 0.03595451307774056, 0.04752410182845779, 0.008237350320996484, 0.05771307696704753, 0.006078122678445652, 0.09224497829563916, 0.023659141006646678, 0.07084936543833464, 0.0592857546871528, 0.0538164046156453, 0.09618877331377007, 0.016020291041058954, 0.02157212711608736, 0.025095133678405546, 0.06643360160524026, 0.05967476623482071, 0.06721000681864098, 0.008807778012851486, 0.05029015301261097, 0.035133846176904626, 0.08806846803054214, 0.01760101364197908, 0.05012079120206181, 0.040399836652795784, 0.03395563850062899, 0.023708072658337187, 0.002723059960771934, 0.057285132352262735, 0.007151674544729758, 0.06243388575967401, 0.04623010798241012, 0.04585761664202437, 0.03631547144323122, 0.03867650666506961, 0.014883161238685716, 0.04403280538099352, 0.062195515347411856, 0.1135650924697984, 0.03519591940857936, 0.046923433474148624, 0.0821146996167954, 0.04934795942972414, 0.06868880285765044, 0.0248541490509524, 0.024113073777698446, 0.0711436418350786, 0.013231454067863524, 0.029809647203364875, 0.05242255479970481, 0.012307466295169434, 0.01883842058305163, 0.019216401960875373, 0.036405334394657984, 0.037820316865690984, 0.06995032032136805, 0.05928906466579065, 0.03815855066932272, 0.014467321980191628, 0.012021999191347277, 0.008947426085796906, 0.01956670494109858, 0.056830507528502494, 0.03220082289772108, 0.02258992513816338, 0.02065107360976981, 0.019256696868978906, 0.024936603513197042, 0.024841749618644826, 0.07004028346273117, 0.019876607257174328, 0.0709425495006144, 0.025296587809862103, 0.01596787871676497, 0.048341161891585216, 0.028870848946098704, 0.05957977133220993, 0.00793175338912988, 0.020372790495457593, 0.03623341959610116, 0.03362895251484588, 0.05608303865301423, 0.07516057550674304, 0.02992111592902802, 0.08269672893220559, 0.018604538308863994, 0.04476927933865227, 0.012237633909535361, 0.05195294230361469, 0.030325332227221224, 0.019342411214893218, 0.01947487715369789, 0.10468286869581789, 0.06873264152090997, 0.040881920940591954, 0.02940800059150206, 0.01901820029161172, 0.0010027557323155634, 0.05643698743369896, 0.026979229551216122, 0.05800147926493082, 0.006667505285804509, 0.08091785290162079, 0.03129569588054437, 0.11294959229417145, 0.03350876169861294, 0.030522348315571435, 0.01467868563850061, 0.03791607618040871, 0.008139179954014253, 0.04345316578110214, 0.07191285563749261, 0.07633742134203203, 0.027497872033563908, 0.01605849123734515, 0.03645111748483032, 0.03658929796074517, 0.018792709852277767, 0.011710109774867306, 0.037502985651372, 0.07270216679899022, 0.04481030897295568, 0.020872456261713523, 0.02812574752169894, 0.02003865891310852, 0.01714193964289734, 0.06254007224924862, 0.06586277871974744, 0.03008990257512778, 0.04794737833435647, 0.07679053960600868, 0.01038127951687784, 0.015385649949166691, 0.04823048540856689, 0.04791591869434342, 0.026096574765688274, 0.018037055087916087, 0.011495952858240344, 0.08604044560343027, 0.045260781480465084, 0.08773435314651579, 0.016256867311312817, 0.056548387510702014, 0.06311591205303557, 0.057992922302219085, 0.022110393838374875, 0.03520146325172391, 0.07626446822541766, 0.01380037148919655, 0.056099250869010575, 0.04868299140071031, 0.08129282301524654, 0.07925608777441084, 0.027800336174550466, 0.026187532384938095, 0.0135183776365011, 0.038933972537051886, 0.05438446671178099, 0.04908317969238851, 0.010222882010566536, 0.009769173739186954, 0.02975902345497161, 0.05730247634346597, 0.08479527765302919, 0.04545654890534934, 0.03581553479307331, 0.05324387107975781, 0.08071272328379564, 0.020209076428727712, 0.036818899898207746, 0.06363688487908803, 0.07212719530798495, 0.0541714220889844, 0.01723802550259279, 0.05311700464517344, 0.087055829790188, 0.07382529598544352, 0.018297951537533663, 0.03980319816037081, 0.03497149395116139, 0.0160058952315012, 0.05197276135731954, 0.023202004013000987, 0.06938475926290266, 0.05229438960668631, 0.04617073245754, 0.07245629327371716, 0.027089874492958188, 0.06883548834593967, 0.07632278618984856, 0.03197794110747054, 0.019366666456335224, 0.046830698411213234, 0.05431931356724817, 0.03877765397191979, 0.04009820557257626, 0.03553164475306403, 0.014224023707356537, 0.037731841730419546, 0.046946855654823594, 0.034882306354120374, 0.04472949280170724, 0.04434153139300179, 0.038589883188251406, 0.03843517137283925, 0.023358701073448174, 0.10112014424521476, 0.016987999661068898, 0.046952629563747905, 0.03383734016097151, 0.02621432206069585, 0.028931421184097417, 0.033075599785661325, 0.052047610661247745, 0.17553137324284762, 0.04583697009366006, 0.041851199202938005, 0.05203584019909613, 0.06838614761363715, 0.038891362128197215, 0.026996402848453727, 0.024883556652639527, 0.03268903361458797, 0.015087297306308756, 0.01298663810302969, 0.07911335793323815, 0.01678335429460276, 0.039031412816257216, 0.015014566833997378, 0.017009616567520425, 0.03320811396406498, 0.09532891359413043, 0.04501249597524293, 0.03415895356738474, 0.014207320746209007, 0.03082961786276428, 0.07231819443404675, 0.04167571838479489, 0.08918480656575412, 0.07404011063044891, 0.03564951264706906, 0.01745317040331429, 0.008696838067407953, 0.028484626018325798, 0.031845686680753715, 0.020788569454452954, 0.03149581600155216, 0.020590339954651427, 0.029836256908311043, 0.027194194481126033, 0.0296591006917879, 0.052379090921022, 0.013411340460152132, 0.05353195796487853, 0.02447330112772761, 0.024562312464695424, 0.036725645331898704, 0.004964543541063904, 0.06109450216172263, 0.07019395256065764, 0.04651756775274407, 0.02755183359113289, 0.013473535218508914, 0.04648711001209449, 0.03203987333108671, 0.026594385162752587, 0.053294266617740504, 0.032092576948343776, 0.2171839663060382, 0.16833185800351202, 0.24955318251159042, 0.09258784310077317, 0.1446935342391953, 0.0672873089206405, 0.07765186877804808, 0.12377164166537113, 0.10228219907730818, 0.13745376490987837, 0.20736232458148152, 0.11534828037838452, 0.20429250493180007, 0.12013813116936944, 0.15165053046075627, 0.1612035889411345, 0.2136161210364662, 0.1002966720261611, 0.22265691950451583, 0.12512283283285797, 0.17935138544999063, 0.09592259462806396, 0.16099566884804517, 0.19771360326558352, 0.09389019352965988, 0.13874851574655622, 0.1309919889899902, 0.15723208955023438, 0.1974096047342755, 0.17689046828309074, 0.17333975178189576, 0.10137264514924027, 0.11309468958643265, 0.14745604537893087, 0.2094504312844947, 0.14295653760200366, 0.12460174126317725, 0.16919411486014724, 0.1259297106298618, 0.1685334401554428, 0.09441991627682, 0.1706085741170682, 0.12876572407549247, 0.09999433590564877, 0.07026795210549608, 0.11991244406090118, 0.1687092104111798, 0.11400889678043313, 0.148058446648065, 0.11333247370203026, 0.1428264836431481, 0.15120203577680513, 0.09726341057103127, 0.20669977966463193, 0.17019981401972473, 0.16224792430875823, 0.09828102120081894, 0.11540367428096943, 0.19349988171597943, 0.1794660769519396, 0.2796996961114928, 0.12018872337648645, 0.10652020369889215, 0.14100488217081875, 0.10558813301031478, 0.1995062016067095, 0.1228595050633885, 0.13222931243944913, 0.1554364335606806, 0.09126227087108418, 0.10344890717533417, 0.1587569061666727, 0.10597237996989861, 0.1136111056257505, 0.12102197710191831, 0.16697921964805573, 0.12152625160524622, 0.11699073482304811, 0.08981916471384466, 0.12946122034918517, 0.16057867091149092, 0.16627417935524136, 0.12849797203671187, 0.14516016701236367, 0.2033976826351136, 0.2094662538729608, 0.21279324253555387, 0.059527587218326516, 0.16938452026806772, 0.11074076042859815, 0.15600095561239868, 0.20470270479563624, 0.21258572320220992, 0.17273408506298438, 0.12993056938285008, 0.11526926391525194, 0.25162793055642396, 0.15864104207139462, 0.1006996285286732, 0.11299688194412738, 0.28682184987701476, 0.12042031055898406, 0.14127769565675408, 0.13690169609617442, 0.20111844321945682, 0.17979861848289147, 0.11852283190819435, 0.18420235952362418, 0.10247045967844315, 0.1338866024161689, 0.09387365105794743, 0.13285083143273368, 0.15087503066752106, 0.16575151443248615, 0.22147215495351702, 0.1173101032327395, 0.06915243735420518, 0.08720399215235375, 0.07515682766097598, 0.10236094836727716, 0.10145928346901201, 0.1460908498847857, 0.2283858839655295, 0.1843935516080819, 0.11232183926040307, 0.21849750832188874, 0.18536211369792, 0.12368213123409078, 0.09917807736201212, 0.149632467655465, 0.1380692725069821, 0.08695357668329962, 0.18260993325384334, 0.23045803449349478, 0.07792284173774533, 0.11509378309710883, 0.08536949215340428, 0.199914071126841, 0.12707000569207594, 0.2491982578067109, 0.18768969661323354, 0.18944141746032983, 0.08654241944896057, 0.10395232078735717, 0.20142996712820604, 0.17024849890731275, 0.20775478711584583, 0.11083359568146989, 0.09048625899595208, 0.09810694304178469, 0.19678997079608962, 0.1639409561175853, 0.07983829520526342, 0.17653811140917242, 0.06695911637507379, 0.1652911602286622, 0.1536971511086449, 0.1332807872677222, 0.15106718754395843, 0.18244081264128909, 0.1516665460076183, 0.14517785981297493, 0.07800349092576653, 0.13490954908775166, 0.13731115381233394, 0.16750241891713813, 0.11705654847901314, 0.11312302478472702, 0.0881181177101098, 0.1155148034740705, 0.1154258793394547, 0.08804343538940884, 0.21491605206392705, 0.15953078807797283, 0.25169665343128145, 0.08166308791260235], [0.021822522176080383, 0.05786386282125022, 0.02742539389146259, 0.06680961072561331, 0.02366349370277021, 0.05678963003447279, 0.022238965357246343, 0.02236396529042395, 0.05616748763713986, 0.05038813134888187, 0.03549489731085487, 0.0436239450937137, 0.014967074021114968, 0.026440066685609054, 0.02644292952027172, 0.03239650497562252, 0.006945821332919877, 0.036385734274517745, 0.04148124600760639, 0.0322521424095612, 0.027330643897585105, 0.006959799684409518, 0.016547904233448207, 0.06756667557056062, 0.02536260370106902, 0.039402226902893744, 0.013284559372550575, 0.01099823337426642, 0.0490719398658257, 0.03565615486877505, 0.10944416164420545, 0.024477770712110214, 0.010993209962180117, 0.028487110357673373, 0.08014273902517743, 0.03368909987329971, 0.03852034395094961, 0.007207748903965694, 0.04829947545658797, 0.060059324896428734, 0.06454420494264923, 0.04015170699858572, 0.07395310123683885, 0.04384600310004316, 0.07822341154678725, 0.013596838416560786, 0.04886251321295276, 0.024390603612118866, 0.026357076021668036, 0.10948061593808234, 0.04031186988868285, 0.04604398847732227, 0.048057386884465814, 0.02083182924252469, 0.029523599368985742, 0.03869102307362482, 0.0610212299216073, 0.06121419202827383, 0.026066671780426987, 0.040808811972965486, 0.0501676466956269, 0.06395903634256683, 0.014701908366987482, 0.03970792495238129, 0.042956520555890165, 0.027721692640625406, 0.011649167390714865, 0.03245637773943599, 0.07590408873511478, 0.04277103187632747, 0.039494012016803026, 0.05821540704346262, 0.06254704101593234, 0.025150672299787402, 0.03498897895042319, 0.05208256952755619, 0.033708440241753124, 0.017484793315816205, 0.048941537097562104, 0.015622062019247096, 0.12784048856701702, 0.011593917279242305, 0.024473458834108897, 0.06480168565758504, 0.04909486109681893, 0.016812138492241502, 0.04331826559791807, 0.019699304466485046, 0.044090566734666936, 0.03676425927551463, 0.017949502071132883, 0.08671338058775291, 0.09540487240883522, 0.07831748618627898, 0.040082327323034406, 0.030566979221475776, 0.0345256227592472, 0.024454051672364585, 0.026862992526730523, 0.05268509325105697, 0.09606866413378157, 0.021417008974822238, 0.04516499990131706, 0.04280679226212669, 0.07518456914112903, 0.04091282025910914, 0.0458248322684085, 0.035232674272265285, 0.07116005814168602, 0.006014798000251176, 0.012795255843229825, 0.07780350439134054, 0.010608193024381762, 0.04001715191407129, 0.007141762698665843, 0.07430585887050256, 0.0017905217191582778, 0.04048276794492267, 0.0781222568184603, 0.051667167208506726, 0.03325705860333983, 0.03198367419827264, 0.05704344825062435, 0.02718232382903807, 0.03478908518445678, 0.04082530991581734, 0.04982240701792762, 0.028413700820237864, 0.04213020220049657, 0.05203342450840864, 0.03565867074939888, 0.02901344148995122, 0.01647214394324692, 0.0452156737446785, 0.11769246513722464, 0.030342423888214398, 0.02126215615135152, 0.0157750149446656, 0.027972024618065916, 0.06561110902111977, 0.047376106449519284, 0.006127026499598287, 0.06737918680300936, 0.07926523103378713, 0.037252889305818826, 0.037501980041270144, 0.021801337570650503, 0.014562531177944038, 0.023763381213939283, 0.044920102300238796, 0.04616117359546479, 0.020278161100577563, 0.019155826012138277, 0.04141479039390106, 0.051985860263812356, 0.10809719329699874, 0.04642527797841467, 0.02821959395078011, 0.03539887082297355, 0.022610439955315087, 0.008397756264457712, 0.03065888122364413, 0.029552151645475533, 0.022008146297594067, 0.0420967758691404, 0.028218478873895947, 0.019018951716134325, 0.07417340035317466, 0.015506616309721721, 0.0576658318459522, 0.008727049971639644, 0.03469887342362199, 0.050469500420149416, 0.012666519196500303, 0.06450385437346995, 0.016290111816488206, 0.018018831651716027, 0.05776871206762735, 0.027964733017142862, 0.041473854216746986, 0.018016523572441656, 0.024253476985904854, 0.02045397774054436, 0.04493532374908682, 0.02723158017033711, 0.12197732154163532, 0.014962066379666794, 0.05001181423722301, 0.012274219006940257, 0.043558881006902084, 0.0905924454855267, 0.07633147673914209, 0.054097018073662184, 0.003856486910081003, 0.021787709883938078, 0.03274255730502773, 0.008853022118273657, 0.03179118335538078, 0.03680012727272697, 0.05404599542089272, 0.0238644097771612, 0.01868612631369615, 0.020336748093541246, 0.04145847320614848, 0.02547931384469848, 0.05361522693419829, 0.029501262579287868, 0.015209622724796645, 0.016337078632204793, 0.030738623136130627, 0.013950511674920563, 0.04339257313404232, 0.025888977506838273, 0.027880547495442443, 0.03949267244024668, 0.05871603760169819, 0.08760779470321722, 0.0930786105163861, 0.017218197172041982, 0.028571010152518284, 0.09429707599338144, 0.027713575400412083, 0.05882452845980879, 0.04485484525503125, 0.009285597734560724, 0.07540523933130316, 0.05159719381481409, 0.017250747769139707, 0.04175946603936609, 0.012398078815749614, 0.033155929850181565, 0.017487500299466774, 0.0368838675058214, 0.027915727150684688, 0.03559473843779415, 0.06262573093408719, 0.04768249098560773, 0.05578263211646117, 0.0017571293642504315, 0.050438400721759535, 0.03983215305197518, 0.02177500988182146, 0.0342083397845272, 0.03446704875386786, 0.03800652913923841, 0.08234362248913385, 0.026106547375093214, 0.03029570754733868, 0.02927525078121107, 0.05904535450099502, 0.011992822583124507, 0.057045414941967465, 0.07758120147627778, 0.09827889865846373, 0.09635203095967881, 0.04003003559773788, 0.015918883982521947, 0.04992673442757223, 0.034388908024993725, 0.029327874617592897, 0.03830113208096009, 0.02666879845492076, 0.03068676927796332, 0.016644444658595603, 0.034761870629154146, 0.0264194962073816, 0.08245219869422726, 0.0187012531387154, 0.04035694793856237, 0.07412762468447909, 0.015216116516967304, 0.02268426695081871, 0.047747154312673956, 0.07240947117679752, 0.02874399178836029, 0.03404410992516205, 0.030803479421592783, 0.024567360924265813, 0.053175114808254875, 0.04871126722719055, 0.012508277541201096, 0.034936921001644805, 0.009461551671847701, 0.0449447787104873, 0.027501015028974507, 0.0051611644357763, 0.006933089789527003, 0.07410131554934196, 0.040401365477009676, 0.027894197446585167, 0.011583111609070329, 0.01750492592691444, 0.05338020731869619, 0.039391083555528894, 0.05104615287564229, 0.07793564378516749, 0.028649709347519092, 0.07970332822878845, 0.0083459701272659, 0.06147640393464826, 0.0300762210827088, 0.04904280314804055, 0.02197165675170254, 0.003507461351546226, 0.015639159246347845, 0.04413693612150382, 0.05002501704439055, 0.021807512239320204, 0.021874207195651252, 0.045821462917956524, 0.05430935023468919, 0.06640425708610564, 0.017160576826427132, 0.026179480082646478, 0.07571318608825095, 0.03694364750117529, 0.049262571628787555, 0.033010958723025396, 0.0313058484607609, 0.02802886756398948, 0.07213119548396207, 0.002075362635878264, 0.04614706165739335, 0.01650321024499135, 0.07237280166009441, 0.03615965382778086, 0.005971888876956655, 0.019605330016929656, 0.01918012392707169, 0.06143317754322197, 0.05070946644991636, 0.055383048675139435, 0.02026175778155448, 0.01936792254127795, 0.04077520381542854, 0.030775225859542843, 0.028293376417423133, 0.017021090170601383, 0.030861385494063143, 0.026368026410636958, 0.10718831472331658, 0.035528000807971694, 0.06979484780458733, 0.020185999346722383, 0.01531106132460991, 0.045105023236828856, 0.03181071297149174, 0.03544685438100714, 0.04115461568289902, 0.013741211187152658, 0.07088008293067105, 0.012639659016713267, 0.17323046311503276, 0.19826905627269298, 0.13456658780341968, 0.16435366444056854, 0.1959877833724022, 0.17574983183294535, 0.155005305132363, 0.1494166807970032, 0.17769243306247517, 0.1820824295282364, 0.12377331149764359, 0.15149519895203412, 0.12882637238362804, 0.12861149094533175, 0.15395840193377808, 0.12890422367490828, 0.17391010711435229, 0.15597168530803174, 0.09249754599295557, 0.10162386955926195, 0.09536655532428995, 0.21365508378949016, 0.10881090187467635, 0.15418468276038766, 0.09323980499175377, 0.16548024461371824, 0.1523701020050794, 0.10489078136743046, 0.16427652561105788, 0.14014001295436174, 0.18941372050903738, 0.16268703824607655, 0.07695607564528473, 0.09564902415149845, 0.26095815177541226, 0.10818626586114988, 0.18131028424249962, 0.14573414402548224, 0.09525013461825438, 0.1225298950157594, 0.22355180117301643, 0.202313968911767, 0.12802037032088265, 0.1468793224194087, 0.23006865929346532, 0.08731944806640968, 0.13845449168002233, 0.12419345614034683, 0.06959968523005955, 0.19951348949689418, 0.1086552809283603, 0.08944238375988789, 0.13981045485707, 0.18574798596091568, 0.13247249939013273, 0.1797555887605995, 0.14527742634527385, 0.1376391830854118, 0.12763921811711043, 0.21411494817584753, 0.19643372506834567, 0.1342435902915895, 0.08643399909487925, 0.16748385038226843, 0.072933494229801, 0.09902086821966805, 0.11921974568394944, 0.16492459864821285, 0.16362109046895057, 0.18621366878505796, 0.16174887452507392, 0.12830035295337439, 0.09454109414946288, 0.1313614152604714, 0.09883783233817667, 0.2622328052530065, 0.15402512100990862, 0.1711791817797348, 0.2014810565742664, 0.15561266394797713, 0.21955070493277162, 0.12400640523992479, 0.12556617701193318, 0.13474715233314782, 0.113935713598039, 0.1555484236450866, 0.09344613688881509, 0.09295281648519449, 0.13411322463070974, 0.14410370495170355, 0.2613221306819469, 0.19814118422800675, 0.14732119714608416, 0.19361590908374637, 0.17774920735973865, 0.1443297482910566, 0.10049962715129368, 0.1305555022554472, 0.16092372505227104, 0.10922651199507527, 0.1480303192511201, 0.10538724105572328, 0.22089142439654097, 0.09531174771836959, 0.1144937270146329, 0.13764264149358496, 0.14417535188840702, 0.1600549669819884, 0.13333864510059357, 0.10839912865776569, 0.15217980049783364, 0.13671517954207957, 0.15072201465955004, 0.12958671752130613, 0.06420485791750252, 0.21419282915303484, 0.13916699797846377, 0.13665819744346663, 0.11434122308855876, 0.2148239070083946, 0.08201252072467469, 0.1417775172740221, 0.09035359267727472, 0.14873133710352704, 0.20487139496253803, 0.13066520652500913, 0.30105832032859325, 0.08903980575269088, 0.16631961363600567, 0.1897392116370611, 0.16351350874174386, 0.10889487588428892, 0.17421891476260498, 0.09662589087383822, 0.28111188439652324, 0.23710117646260187, 0.11865920154377818, 0.10786332029965706, 0.15556856553303078, 0.08897083054762334, 0.14421398809645325, 0.12011183687718585, 0.1462495359010063, 0.13017849123571068, 0.16295321693178266, 0.235653632262256, 0.07393833249807358, 0.14630602818215266, 0.11756524618249387, 0.18618800531839952, 0.14631135680247098, 0.13946405000751838, 0.07698639979935251, 0.15288115973817185, 0.08948076021624729, 0.2644712710753083, 0.10346078895963728, 0.10247574376990087, 0.15693710069172084, 0.10592239632387646, 0.087842840293888, 0.11992598083452322, 0.11545311615918763, 0.08429069144767709, 0.29368582530878484, 0.11455587446107529, 0.16552201268495992, 0.08621718065114692, 0.11892848240677267, 0.17531766439788043, 0.11441893337178044, 0.09307881831773557, 0.18893243774073198, 0.10440258178277873, 0.14191043592290953, 0.08910052085411735], [0.06367350986693054, 0.058291106106480584, 0.026582204664009623, 0.04755629248393234, 0.015233867761708098, 0.03697253188875038, 0.04307323812099639, 0.032402557189925574, 0.01291244559979532, 0.0458786565286573, 0.023915658784972038, 0.022585030674235895, 0.056652518251212314, 0.028904774371767417, 0.031369569260277785, 0.02541236284741899, 0.007816865218046587, 0.020558403484756127, 0.016295963650918566, 0.03709559852723032, 0.04698548815213144, 0.04786802048329264, 0.041104550400632434, 0.036097613992751576, 0.050658985564950854, 0.030225860318751074, 0.11684968223562464, 0.03529823930875864, 0.01352292143565137, 0.05084496035124175, 0.04484026205318514, 0.033931392536032945, 0.05063031268946361, 0.03495749333524145, 0.049352197092957795, 0.006305609958872083, 0.0412223440798698, 0.04295926650229376, 0.05504937536898069, 0.018691145087359473, 0.0924775970634073, 0.04965072970662732, 0.06046796253940556, 0.045446633812389337, 0.060615223192144185, 0.12387424358166754, 0.010394806085969321, 0.048342434674850665, 0.07094021915690973, 0.01991684279346373, 0.03719596286828164, 0.02525930973206414, 0.04606163303833455, 0.025393512296432164, 0.025129374516836833, 0.03601241915021092, 0.03604323312174529, 0.019962909755122382, 0.01692769645160297, 0.13859713246347383, 0.0903234317956958, 0.061851975187892094, 0.005902954490011325, 0.08113030751701444, 0.0161218001449015, 0.009690023689472582, 0.05003893602406606, 0.04160619399044663, 0.019865526992361993, 0.017535251936351415, 0.010009917168645188, 0.0020820755935346824, 0.08828536068904214, 0.06232697196537629, 0.08696579243405722, 0.025204298035532702, 0.054441819884232245, 0.026578349206829444, 0.016230174114753027, 0.04058671314851381, 0.04670040696510114, 0.009708908564789454, 0.04656227843952365, 0.09701053117169067, 0.05557340584346093, 0.06708317378070205, 0.015215936546155717, 0.02725392252614256, 0.06901214175741188, 0.006651195199083304, 0.054129038035171106, 0.0643842424324248, 0.04849173623370007, 0.04447449457074981, 0.04683898077928461, 0.0051272032942506485, 0.0017021996518451488, 0.029768348540528677, 0.08258009300334379, 0.02545090814237483, 0.01564645270264009, 0.0719849404413253, 0.014891169012116734, 0.0217596418588073, 0.016214668794418685, 0.010367013583163498, 0.00579596555326134, 0.016826749524625484, 0.0443113185610855, 0.05706964977434836, 0.06017193467414472, 0.009751974466780666, 0.054336668690666556, 0.08953902623034082, 0.018451490759616718, 0.011421233430155553, 0.08714907322428189, 0.050129737792303786, 0.05225052125751972, 0.03270690081990324, 0.09550831295200624, 0.025162242382066324, 0.05393746374465991, 0.04029661133245099, 0.04938830257742666, 0.011009382287738845, 0.021770002240373287, 0.003339589402457932, 0.036827675794484094, 0.028671263171418104, 0.0647424029011745, 0.04690762943937443, 0.026233686548948754, 0.030533155841112603, 0.03597057315346319, 0.0228191634232644, 0.037816142285009846, 0.04694146766269114, 0.058789165123016573, 0.022062952048145235, 0.035766193104791455, 0.07246105786180124, 0.04371427930891514, 0.02835725863405969, 0.026548318201093934, 0.03833803166344296, 0.02213391249824781, 0.04999009157472756, 0.033259830524912104, 0.024149064229277428, 0.014994955581641989, 0.03632354972069152, 0.042553456441964954, 0.06851451689726673, 0.0457491851557279, 0.030507510928146075, 0.048072801291709766, 0.023912474971439224, 0.056200075341621414, 0.019327740810695104, 0.08692894480191171, 0.019761316470976453, 0.033439485923736356, 0.015767445038363803, 0.04602996188623365, 0.03751300464500673, 0.025067438582482282, 0.06255356449401006, 0.009219989096891368, 0.028515926096588373, 0.05606340884696692, 0.03201230625563767, 0.04287389725504909, 0.0407396252558101, 0.013000177659705514, 0.02527161082980456, 0.05880488381080795, 0.026177366817137226, 0.06761376484064385, 0.038227741097216494, 0.04936921824992169, 0.03311657375888899, 0.06522601601318456, 0.08484512029099278, 0.0479029088455718, 0.03623423966928385, 0.018067061973852105, 0.07267847744515166, 0.051067626918666065, 0.018468216912879143, 0.05114465813676361, 0.03295604350569192, 0.041434928571106866, 0.061271211234270595, 0.04573403421090916, 0.036630958420573734, 0.030907942273188382, 0.02796590004436439, 0.02891936499509029, 0.096345351630589, 0.0572405886487104, 0.0323434377060039, 0.04685406122007407, 0.017945674444490578, 0.00827053359898855, 0.018375205399934202, 0.07495013953302987, 0.02385607731412165, 0.014882766045047902, 0.05724215086956974, 0.031636586572858505, 0.04272643622243777, 0.0019159843350280426, 0.06411360343918204, 0.07131778678740375, 0.01748756338201929, 0.0882310577435419, 0.024577402182330843, 0.02286045466462383, 0.03593744368117768, 0.043070358588011004, 0.05511127419595141, 0.015484573596040718, 0.034582033404149115, 0.02870779724617023, 0.03909991675755009, 0.049466072232462466, 0.05861168050614651, 0.023791796193108894, 0.01856552917161025, 0.0681970186997205, 0.016539985517738387, 0.02589809664641507, 0.09074594388948753, 0.01090561334422091, 0.06921576481545344, 0.0024058709141172585, 0.03362466290127486, 0.0249071550933877, 0.05862687969056424, 0.033803253318183124, 0.04590379678120371, 0.06888478179462254, 0.03462909298832528, 0.06921926033101045, 0.06703413266222924, 0.02036975882219849, 0.03419211272557732, 0.09379224487929605, 0.008948867707658792, 0.09320630444562994, 0.06789494975237176, 0.040001997258514166, 0.01649166613788111, 0.0375787218217738, 0.019725190577446483, 0.03180460509611294, 0.022590513290197123, 0.08619530955911614, 0.017873187025543302, 0.029795188311254606, 0.04856276718783192, 0.05105147407448385, 0.018392410238448065, 0.040913859265856445, 0.06874841958051547, 0.03796702090767212, 0.05780659499578178, 0.060842212769784965, 0.057915186043828726, 0.03269235101470258, 0.017137971008196473, 0.024451687932014465, 0.023888104697107337, 0.08020003282581456, 0.0068641827692772495, 0.03405606221349444, 0.010088012440974126, 0.02507630539184902, 0.061973457341082394, 0.019427797160460614, 0.05479175364598632, 0.013431110346573405, 0.03368857294844929, 0.04913696684525348, 0.07191491880803369, 0.10951579373795539, 0.0203204468198237, 0.05497382844623644, 0.024114394800562877, 0.02174588244088227, 0.05249277310213074, 0.03238514269469306, 0.03783592794206925, 0.022584269972867332, 0.033010361294145696, 0.0967295392183587, 0.0057745912363316165, 0.06227705511264503, 0.043639155410346575, 0.04194885470496956, 0.09852147704805247, 0.038716575218131766, 0.05227412526437547, 0.033134470650111325, 0.05577814954449423, 0.0766495538118761, 0.036158343937131576, 0.025209589548467193, 0.025422480175620876, 0.04162245815678034, 0.0503598406794481, 0.031895685169729404, 0.025892098237818573, 0.08115272779832594, 0.020588158040482085, 0.03227848494134378, 0.029493149049812928, 0.016180307356989942, 0.026764752583403606, 0.07808536465745419, 0.008817312755127205, 0.059197197915636934, 0.0533935956627829, 0.020357671091915108, 0.023993148279259913, 0.052741010367753915, 0.020707014846266247, 0.040787007674225606, 0.06109363013820257, 0.02322880111023551, 0.03928785081370734, 0.042905189911834896, 0.05876885996258352, 0.031307013632613234, 0.039434187492588535, 0.036506470569293015, 0.10791792752570473, 0.003136863879262819, 0.04514444983215071, 0.05391398590290919, 0.01698027761449339, 0.0763089228712488, 0.03929207734472584, 0.016109586249513086, 0.08670460098073818, 0.10994647687766701, 0.03484317290713079, 0.03780694707529619, 0.043628999119391665, 0.0109417568637582, 0.03230177353543695, 0.15709361963672563, 0.1744188493466936, 0.17394559661624953, 0.13329245382919908, 0.08765866892645136, 0.09317251446191221, 0.2529292122926563, 0.18733998178504407, 0.1510002012946643, 0.144843255111482, 0.1952801604056731, 0.25639765430241823, 0.09359263684018515, 0.10740802012151107, 0.09867988846963271, 0.15593281161272898, 0.0797037586744409, 0.15250254567945376, 0.07422016307828017, 0.13829252537107095, 0.29443468200042844, 0.0921949501207564, 0.0998728240665514, 0.2025673381285742, 0.09923878504196182, 0.0913198095804546, 0.13380833552218974, 0.19576628197683021, 0.12738191551761702, 0.1208250259514898, 0.2423238626215607, 0.13126386736985296, 0.09302344667958096, 0.18791756563587114, 0.10863237825105898, 0.09756274099345319, 0.12769916880642995, 0.14641895337263122, 0.17193783482071012, 0.05487371643539518, 0.27524262433871627, 0.15194571227766573, 0.13083756290143356, 0.09567261702613905, 0.23733821843052283, 0.20346873585367575, 0.08868493299814872, 0.14415948477108032, 0.1424912703805603, 0.11497561834403314, 0.14264162949984893, 0.08254849977674894, 0.15333346906118095, 0.18105422845110297, 0.1888835895806551, 0.10775184229714796, 0.10304942392394878, 0.09596039963071235, 0.13761792797595263, 0.194559252995532, 0.18433179007843137, 0.16619383444776759, 0.054558941919822246, 0.22475093370303512, 0.1489972634590231, 0.14063616836210713, 0.12481844838475809, 0.09821770116104744, 0.2461231392226182, 0.10066160088172182, 0.06223242606210988, 0.11070465494412929, 0.18892132036853582, 0.1864561135880649, 0.30464577313978225, 0.10180478289839812, 0.10977138197631575, 0.18769257614621893, 0.10252428764943033, 0.195265926013235, 0.12866614270024002, 0.0868983608961571, 0.16582286451011896, 0.24777090002316982, 0.15900816768407822, 0.12259110735612921, 0.11558318496099673, 0.14243872632505372, 0.20537221105769277, 0.13715343258809298, 0.13566461013397202, 0.1330685627181083, 0.17354378302115947, 0.1242660307616461, 0.10879979192395695, 0.19699729717103764, 0.09958239199477248, 0.09069733321666718, 0.18805665895342827, 0.16083260416053236, 0.1674038913915865, 0.15230831078952178, 0.058812565039261244, 0.13095955713652074, 0.07591352885356173, 0.12910047720652074, 0.11527007285621949, 0.05552552247536369, 0.11707749188644812, 0.17652911657933146, 0.1936048362404108, 0.12457656761398539, 0.20028846978675574, 0.14987550617661327, 0.09351845175842755, 0.16618007502984256, 0.19355068914592266, 0.14562049153028056, 0.16419546824181452, 0.09486380964517593, 0.21006933791795745, 0.15326648281188682, 0.1669393217889592, 0.08976380049716681, 0.1417356898309663, 0.22904743440449238, 0.159140344185289, 0.08381207298953086, 0.15221551264403388, 0.26527602632995695, 0.19291014148620889, 0.14428524911636487, 0.1253177208127454, 0.11578383200685494, 0.14923155948054045, 0.09757641877513379, 0.15926128457067534, 0.21517014858545735, 0.20306763472035527, 0.0901747276657261, 0.19362174236448482, 0.16255394148174673, 0.08394783406401984, 0.07721694055362605, 0.15482833259738982, 0.10413972049718723, 0.15649620559997857, 0.11826354035292752, 0.15103166835615411, 0.20828607579460368, 0.14761205966351554, 0.1379266317235306, 0.11084890618803911, 0.22828985005617142, 0.13548511429689825, 0.11892854920006357, 0.13787689298624173, 0.18208385445177555, 0.10226160447928123, 0.10437478093081154, 0.20072105282451957, 0.13595090102171525, 0.13963376433821395, 0.11185864263097756, 0.18137023493181914, 0.07258797995746136, 0.14408224204089493, 0.11340427648974583, 0.08904439964680932, 0.20533149683615193, 0.1734965675859712, 0.10363428824348375, 0.18104161194059998, 0.1384315444738604, 0.15068569395225495, 0.13972049171570688], [0.041788829112192616, 0.039560582663398236, 0.030755764892091975, 0.0507639697752893, 0.00967309530096827, 0.02627019835927058, 0.06128510423877742, 0.0023666544393563527, 0.03571154134988319, 0.031725981971248984, 0.029673292410734575, 0.06330976844765246, 0.05687797529390082, 0.05681722308509052, 0.015612861243425868, 0.028381350603012834, 0.025575750369171146, 0.010613515150907915, 0.021353772426664364, 0.07393893363769166, 0.0724800345778931, 0.06072723554098047, 0.07877761774579994, 0.02188292557548266, 0.008301257585117128, 0.04585744965879712, 0.011579277488635853, 0.0682865662383847, 0.012620954112207983, 0.035764471322181635, 0.03991966339526698, 0.0560450444027083, 0.021105575979163405, 0.05364420409023296, 0.03780259066843428, 0.07420708643621765, 0.018125303868146148, 0.056371674727415666, 0.04549613506242167, 0.03024774068762781, 0.026995015032298397, 0.04100390404346399, 0.046244093755376525, 0.05053060143836774, 0.05874747868801933, 0.059915214660577476, 0.03134910453809425, 0.05471587646752596, 0.023716861542197876, 0.03138184067211114, 0.01947769917023834, 0.036525577161228284, 0.035079828958259895, 0.03066053250222467, 0.016065320851339493, 0.03918659589544404, 0.02500767157471273, 0.02735409390879795, 0.05183917848626152, 0.05391259808675386, 0.02982397621963173, 0.03953798055590596, 0.024014496157178655, 0.008470976554235676, 0.031924959184834734, 0.016634577805234585, 0.024910578249546234, 0.0880906062957365, 0.040453026376781054, 0.012828081034967909, 0.07027426036074758, 0.014254287561925594, 0.01797425269614905, 0.014209685414243722, 0.01862381188402651, 0.02052618128800532, 0.05012635730963666, 0.039673192441114224, 0.02370542690186994, 0.034910363247036, 0.01155511223259964, 0.046913670521462336, 0.03499562859360594, 0.06876938525238074, 0.03807421671808697, 0.026739907334558666, 0.03876282957207877, 0.08604355520219542, 0.008712724666111171, 0.05834628849697765, 0.018689621829253156, 0.0396102323429659, 0.03971173216996249, 0.01710811811790336, 0.006411031108655152, 0.036629811802413315, 0.05051018866652157, 0.1116936409380287, 0.039581203236593865, 0.018891781001002528, 0.06433362796087749, 0.03765156361623667, 0.05480400279338937, 0.05779609360615723, 0.05365309873013757, 0.024203474786190782, 0.0797424690972548, 0.03819169869530015, 0.030864669497532304, 0.06161413912195712, 0.07206179725471884, 0.028954841509403195, 0.046748305176151916, 0.02551221325120423, 0.009713723247841699, 0.018467933041392826, 0.04425695995450951, 0.061260631919139996, 0.038768718513892964, 0.035031459483434446, 0.046387105612666346, 0.03206838293408509, 0.011480498560558772, 0.018478968777344562, 0.049385122474632226, 0.00741928882234788, 0.04387676512124017, 0.09488419644185342, 0.0428764613752719, 0.022259660145209637, 0.018871338543249294, 0.014269777111621806, 0.009464083323109662, 0.06785225399653427, 0.04058164056914393, 0.008557760520488955, 0.03977923792263027, 0.031905555733828805, 0.05687821649189573, 0.05661507690092549, 0.02498590252798749, 0.011797666502388893, 0.05363296797440853, 0.027878046457772143, 0.014918380784365581, 0.061751529210596345, 0.0008019334120490385, 0.08062691616942175, 0.051117948241881095, 0.04610610252711922, 0.05880275013623759, 0.012174231305834837, 0.019038434948015492, 0.022458277417172212, 0.03575380666006822, 0.020481786013988312, 0.04341491548984777, 0.026795963603944983, 0.08714971889276057, 0.022547882472281344, 0.014390432697837241, 0.05948986014118418, 0.04627343085303437, 0.028133141167927533, 0.03165884358168114, 0.006976784197831876, 0.04988855835108552, 0.05275433562928811, 0.03167531183862593, 0.04235392261762172, 0.057203262331313454, 0.02180895571655128, 0.04496457921050023, 0.047259515049518086, 0.024413554529019166, 0.0530092076951405, 0.01906811899971217, 0.06558782784850337, 0.03807571956713218, 0.04046270398248453, 0.00417435293456947, 0.03277095558587462, 0.06563779665157199, 0.018035401953966357, 0.012232235712872352, 0.022417277468775865, 0.033508936103316955, 0.06729122003889643, 0.006493784749181941, 0.01745251731335884, 0.007710873078394798, 0.022761641412216704, 0.016873857348400634, 0.011843150878121378, 0.03161932050716132, 0.051101995777571574, 0.021865455419174396, 0.008276239786937367, 0.06573066901182756, 0.06968953704927117, 0.014910231075191405, 0.021653889525623526, 0.03005457820108859, 0.03270701214205474, 0.005642547394018038, 0.040504783755750395, 0.03645198208687361, 0.08301461304654367, 0.042974205935024656, 0.05525768508960027, 0.017534723156131804, 0.08027286719880067, 0.028320876699581277, 0.011066982224292587, 0.043201288281125017, 0.019977144147560466, 0.04314933794375975, 0.026186268878518604, 0.01498741257819347, 0.027523663520696573, 0.027281836555630434, 0.028374923604133073, 0.021282329580571968, 0.03840890305582434, 0.02341926774533931, 0.037559084594249725, 0.01554008902530768, 0.07520165338064544, 0.060531301132868975, 0.021910598406975623, 0.04388080611533951, 0.08499344592564739, 0.06591108511202037, 0.010307278116670204, 0.02376693424594123, 0.019002080844074953, 0.016419039566244464, 0.012774071237799944, 0.006324747628241312, 0.023067623333190568, 0.035490707887220196, 0.04030532785691321, 0.021486058394657448, 0.02007528946705861, 0.012743853767460678, 0.03521229860780295, 0.022431853249145206, 0.02009444244322367, 0.01862926295871148, 0.007011066318227677, 0.022000131102686282, 0.045973436208441854, 0.016888674326764885, 0.020308129023760557, 0.01921433322422672, 0.0537660090776626, 0.06717967524309643, 0.06056030797481071, 0.03444422771281097, 0.05220804443524685, 0.044614122234634124, 0.08164828948793001, 0.05630087383906357, 0.0809916817524936, 0.018954691004182678, 0.06282876027398743, 0.01693475427600788, 0.09265307046007365, 0.04995334784325678, 0.01947167478647316, 0.018950726080220193, 0.025623065994295757, 0.05833788738527801, 0.05653619773511309, 0.008532072006346425, 0.042765758917084895, 0.053209988327580504, 0.039439983665943146, 0.04258753586327657, 0.04491906700422987, 0.053343211257015355, 0.060834661417175084, 0.015958405201672576, 0.02044131855654996, 0.06398333425750025, 0.017998331677517854, 0.023121152589737903, 0.04204134856991004, 0.03467270529654343, 0.03790604605455883, 0.03458893908828031, 0.011741147318389267, 0.07302456317120232, 0.03206544031854719, 0.049343016726197675, 0.04995006383978762, 0.019768227721215226, 0.060158683627378196, 0.04104469247977249, 0.09411801802343689, 0.009141345562966308, 0.01073717829058296, 0.017963185418921057, 0.0114597991341725, 0.01889609844511142, 0.027092325435660314, 0.14105505135376006, 0.011309592155157588, 0.07667264202609658, 0.09981983472243883, 0.038203205695026554, 0.06505622004624456, 0.034220663146697916, 0.026507501934247557, 0.028787949195248075, 0.02888730050472077, 0.028997186600463465, 0.026995976113539655, 0.024568236658524256, 0.027036887004214805, 0.042079943959834054, 0.007947414560476318, 0.04024081295938231, 0.0154968830429425, 0.10214244524831884, 0.020895692905469332, 0.019916573764930945, 0.06283276044996455, 0.04709614979219623, 0.05350546329282224, 0.012648502633965109, 0.0863294601731468, 0.08593720544013195, 0.04735084003186785, 0.08140425648889504, 0.04054719378473237, 0.022892995984875597, 0.06317772553302348, 0.05824156032758765, 0.0570007228088798, 0.025971274262701627, 0.011353337122272933, 0.05991634272504598, 0.05918243659834843, 0.022595198097405955, 0.037425817135954276, 0.026742744194052648, 0.03545015322742984, 0.027460759083623998, 0.047448851764784195, 0.06157791489386, 0.03954314219299704, 0.09110244194744155, 0.1356280074105598, 0.06688649722491391, 0.17217273940332234, 0.15779926849063486, 0.10234617220703512, 0.14621242851717398, 0.11151663871714845, 0.14808096340857446, 0.11592527051107027, 0.11992986226687208, 0.10386569731053896, 0.12420466257026419, 0.13869687711121514, 0.15088337240740657, 0.06591719298739918, 0.06020685643306933, 0.13337842421606183, 0.15398957213619724, 0.148978739453014, 0.19416584051214159, 0.09872733397060074, 0.22463533678092062, 0.15773207443999127, 0.08840880211209878, 0.17548464762512594, 0.13977141788927838, 0.2001731251948513, 0.09110684288316406, 0.15523571230005473, 0.1460354559822008, 0.22992809652350843, 0.09575434974976815, 0.0943260568601545, 0.13776951906038448, 0.1923768935375847, 0.1286211537080817, 0.1283530454384163, 0.11071395405451767, 0.12842687428928912, 0.08715731106349267, 0.1074876674101688, 0.10418659454444423, 0.10142202765564434, 0.14217110787285492, 0.15380140801426023, 0.12309293277212419, 0.14566993340849876, 0.16765953158028424, 0.11391642517992295, 0.1198375242529437, 0.2085465399431996, 0.12876003922428936, 0.13049017841694877, 0.21601500950055197, 0.14124140463536605, 0.21751051128376275, 0.06115788528404664, 0.12375419377349317, 0.16595656983554363, 0.18813367903931066, 0.13515649130567908, 0.06699572651996277, 0.07380211871350184, 0.1669863739516586, 0.12365517643047497, 0.1764231824199669, 0.11989360093139112, 0.06371774928993545, 0.12404225097270682, 0.1758554988191463, 0.14794752525631338, 0.15784565272042528, 0.10721653117798269, 0.07777949591400102, 0.11140317175886594, 0.11865535721881315, 0.1637540536466986, 0.12270560589968227, 0.15859655773965642, 0.18360859685344622, 0.15448045829543844, 0.10327261741622351, 0.13442302675684914, 0.10217833550996147, 0.1692167206783779, 0.21054676151834428, 0.1278110995190218, 0.13108560349792242, 0.24103392090182751, 0.11267926500295289, 0.1495467050699517, 0.3065989870810881, 0.147421401925385, 0.061308173899305984, 0.07423650517011993, 0.16056002816185355, 0.17980685632210225, 0.1394620758946985, 0.09428061515791342, 0.2280237158993259, 0.3042823285795748, 0.13903476210543886, 0.10158651726669632, 0.20646367280278355, 0.16711000091163442, 0.15532300370978191, 0.11762805414036848, 0.11561987674213015, 0.1363488257629797, 0.1674608586472459, 0.11898138269316405, 0.1127830395125784, 0.13844435394275934, 0.11553095260751434, 0.09245293549611233, 0.21744358440628275, 0.16345686803106219, 0.21181178191909567, 0.14501565601676702, 0.1300736257690005, 0.20253297669114545, 0.17104630765970796, 0.17726206162478775, 0.15552955825114623, 0.12110573588870466, 0.15952157060382888, 0.18336730980081484, 0.14923213835572824, 0.09555760640068911, 0.2448103838833049, 0.1241272417246364, 0.20380748173920438, 0.1729589854949154, 0.1760216211550869, 0.17714913643430918, 0.13556407880969346, 0.06784037963370793, 0.12142473322455771, 0.15831281983992085, 0.10124949316377752, 0.0982951739570126, 0.13738051493419334, 0.16767333552706987, 0.11970908817602322, 0.1128410012461245, 0.06981285972869955, 0.19308720307890326, 0.19480039161862805, 0.12258108836249448, 0.07182589077274315, 0.17166405654279515, 0.1324819543515332, 0.11933048896025866, 0.12187821514089592, 0.17813856771681458, 0.19683510821778327, 0.08714468713151291, 0.12841569754527882, 0.09790700845769607, 0.17916004493599758, 0.23974068404641002, 0.14589661499485373, 0.23309610231081024, 0.1232658234948758, 0.0916246764245443, 0.10895485625951551, 0.20432331890333444, 0.13164219941245392, 0.1173905297764577, 0.20192161027807742, 0.1907922004465945, 0.10693141288356856, 0.17049679183401167, 0.14182188286213204, 0.15795710845850408], [0.08003792550880462, 0.00874175098942942, 0.03721043103723787, 0.024239717567979824, 0.027544721961021423, 0.05124266986967996, 0.02201558632805245, 0.03723921523487661, 0.03012897665030323, 0.06899541374878027, 0.030838137718092185, 0.040595741375000216, 0.010376123445894336, 0.07936106456327252, 0.054841418168507516, 0.004675949676311575, 0.028760601053363644, 0.03183331136824563, 0.011520354673848487, 0.04119153010833543, 0.0664666345983278, 0.09599464232451282, 0.08016350431717001, 0.0290475951260305, 0.06449279637308791, 0.02988921471114736, 0.010179829096159665, 0.025331047581858, 0.0572772173472913, 0.02483032425516285, 0.04336380006861873, 0.022334264540404547, 0.027864361254614778, 0.05805170781968627, 0.01939334295457229, 0.01824279697757447, 0.08694710515555926, 0.013293759220687207, 0.054786528926342726, 0.03268141175794881, 0.09503351655439474, 0.039346432240563445, 0.032859133862075396, 0.01787193279596977, 0.06514045380754396, 0.02065693657641532, 0.045612307148985565, 0.06067897367756814, 0.017571552234585397, 0.017976323288166896, 0.034598431157064624, 0.033772532115108334, 0.08490187974530272, 0.03105683565081563, 0.030020893973414786, 0.018408728210488334, 0.04867308001848869, 0.027786183418356813, 0.025970778879127465, 0.07937365880934522, 0.050571645915624686, 0.049862720479723066, 0.06785698147723451, 0.05865558596269693, 0.02280915741721401, 0.03275293995102402, 0.06056619320588652, 0.05354157248802949, 0.07182549001299776, 0.02018825547565939, 0.03386360105650965, 0.04079970211023465, 0.022448321506089997, 0.04571761419356335, 0.06343758854200132, 0.046262751347967423, 0.026656567861209624, 0.03363519768754486, 0.026353946013841778, 0.017960689947358333, 0.03622870695835445, 0.031665047936257906, 0.031114684206841048, 0.07399528491077945, 0.007728061218585935, 0.04843806411372498, 0.03527324377500918, 0.05318796509527601, 0.05759830011811573, 0.027241480420343578, 0.04088976544153411, 0.07974283274961635, 0.046032399841351435, 0.00965892213571351, 0.020871652886853553, 0.055554291830048896, 0.04373354546260089, 0.0812335847876966, 0.026632221706677228, 0.010425644177303184, 0.0346979197638575, 0.083907119842479, 0.02464189110469306, 0.14262631157180294, 0.03758376471523661, 0.02011746200878406, 0.01123797304899199, 0.030746296943107154, 0.03620755574957002, 0.0180728618579451, 0.02650149239343591, 0.020638080459320918, 0.026861053665925283, 0.0511362273391569, 0.019210427672078367, 0.0388100969576044, 0.02659069483343046, 0.012289889455132652, 0.03402739675948396, 0.00940570876991842, 0.02870761170925107, 0.04854941966186743, 0.025636613900132943, 0.03278013966337312, 0.03233958224882372, 0.009917513289110502, 0.04419973665790167, 0.03221972168830689, 0.0387077362393029, 0.03976976811827626, 0.024375397006224375, 0.033532632878632285, 0.01292963745072484, 0.06232142070075497, 0.02159468840545742, 0.01721349010040285, 0.010032125937868841, 0.028405897137417924, 0.01223088407641626, 0.017433659340895247, 0.03324544399220031, 0.017394585265719797, 0.13331893365830183, 0.006619900223086006, 0.07287185886525549, 0.06775871370336972, 0.06231802166439593, 0.027205198675801512, 0.014246412447391776, 0.010297384360455908, 0.03127431460598018, 0.0036358642637424055, 0.06020566157530993, 0.04817850538529456, 0.08642521206638776, 0.10182435333263129, 0.04470568099350203, 0.07273848008480854, 0.025156210576824378, 0.05056928588601295, 0.013074590024189092, 0.062336664414033294, 0.008666564935992938, 0.00918447361982544, 0.04465713711397257, 0.04625494024367072, 0.03323954020743258, 0.03896536167303566, 0.011635434875643114, 0.031145355314947665, 0.020055685636179987, 0.027456554817035794, 0.01311587755481014, 0.03082112398260506, 0.05057299662439618, 0.04328723640355747, 0.12437133409548551, 0.006966247556192684, 0.09192420722683892, 0.029401594001683407, 0.06271399455727078, 0.05010947716073133, 0.05633055232465267, 0.0436215999070555, 0.04925882378302049, 0.06001366054988466, 0.035143471832270734, 0.0457417043071473, 0.05149814307515044, 0.012763607883243822, 0.060807476547779515, 0.030520956788677722, 0.04968569970515091, 0.022553003291250207, 0.03679188201203942, 0.012094598860130645, 0.022023955898475833, 0.026100741924892645, 0.015609755355399102, 0.09509803145192564, 0.05811813745822292, 0.04117650161788333, 0.0421432751318207, 0.021351479190343525, 0.04220036855258513, 0.023533406347269192, 0.06452153975260444, 0.024561388490838, 0.016963794514595065, 0.04582231638778467, 0.022894220528542064, 0.014496693402179517, 0.029948423252790235, 0.07953841559356079, 0.08257664201664738, 0.04983830382116139, 0.0557389381719986, 0.025398677644261625, 0.0403224826004589, 0.015669193962821737, 0.060350788553478196, 0.021519378969969694, 0.035744963970500976, 0.042206212965538725, 0.00911664596060291, 0.05940120689047035, 0.015331630875152769, 0.04334223696787376, 0.06536577726365067, 0.04904121866275091, 0.06962315193959512, 0.01450938969355775, 0.02768979327811394, 0.13432871463010088, 0.07080156370648183, 0.04262888091034256, 0.030020534031791613, 0.01750182931573363, 0.10010141297243536, 0.026890344379353337, 0.01672244066867279, 0.0056350512386416085, 0.0432149029802531, 0.0300693376630079, 0.03723187910509296, 0.015043016137497034, 0.10072262768517248, 0.004369495563878445, 0.019271118653705344, 0.09790473748580553, 0.14099511550739408, 0.017652038150117733, 0.028645423444686458, 0.036203555573592894, 0.02691410238185199, 0.04284812617697753, 0.042545251999399625, 0.0526641943724826, 0.003643550362539827, 0.030457087559625506, 0.029684695509786252, 0.024920779069361743, 0.06862851820187643, 0.04363833533716388, 0.029239568320917897, 0.008960856175690424, 0.020225134649081156, 0.009943571021722164, 0.040263125629280694, 0.023980756268429104, 0.010218964398518438, 0.04531499907898251, 0.03739292144018691, 0.06040800071787089, 0.03843727536150254, 0.003954616458941018, 0.04651103685318958, 0.0760263204574585, 0.04696259660704527, 0.06547787124873139, 0.04417597308929544, 0.022188562397786882, 0.04015718775917776, 0.03806535176408943, 0.09747724558110349, 0.017670244887995068, 0.02274894326546928, 0.04097288598131854, 0.007345934018303524, 0.04655896846088581, 0.02110068151523592, 0.02615500405227067, 0.019993384194094688, 0.0269357007346116, 0.05894709414860699, 0.03957826804253273, 0.01810431778721977, 0.011076953906012932, 0.02736134654696798, 0.008837052955641411, 0.058332673797849566, 0.0329054772737436, 0.05384578253142536, 0.022370741098711733, 0.07841904167435132, 0.01884500899905106, 0.03634817789134104, 0.05009743952541612, 0.015746191784273833, 0.03204795531928539, 0.021070438997412566, 0.02106393778376514, 0.024161983164958656, 0.040552637437940575, 0.02540263329137815, 0.04511604784056544, 0.04462382952624466, 0.06445182239986025, 0.03434783015109133, 0.006587173365915078, 0.03440949891228229, 0.054142979279276915, 0.03050906572752865, 0.05546234344365075, 0.010466269341122825, 0.028660841562668793, 0.025549214878992643, 0.01866745573352091, 0.04322186803619843, 0.011133878488180926, 0.04357446981885005, 0.08720172860193998, 0.014728114529134473, 0.07184627014794387, 0.029611538302560803, 0.05200407627853565, 0.03683525312226266, 0.07418321896693669, 0.03506063330860343, 0.026333559217164293, 0.026279543853888754, 0.02370144156884635, 0.04709222754172515, 0.02991346438648179, 0.024548966794100124, 0.027911548859265167, 0.0394825977855362, 0.06660481507424265, 0.02720367170695681, 0.0877262266294565, 0.026876963456743397, 0.012434326235961635, 0.15825543698156253, 0.12418847632943653, 0.2569030865561217, 0.11129865510156378, 0.0777539808768779, 0.09251887531718239, 0.1297535523190163, 0.15334920259192586, 0.13153058040188625, 0.18931397586129606, 0.15840777021367103, 0.2069602141273208, 0.11120002367533743, 0.13569947623182088, 0.2000411119661294, 0.15380033932160586, 0.09874283001408912, 0.10738532524555922, 0.06692661772831343, 0.16957795363850892, 0.13537775521399453, 0.16273480287054554, 0.1673681495594792, 0.14889555954141542, 0.1948343077674508, 0.10577165128779598, 0.13108119514072314, 0.12444829480955377, 0.13988416496431455, 0.21124684426467866, 0.2272456482751295, 0.0866405239503365, 0.17652825568802655, 0.1936320582171902, 0.084001535869902, 0.08767084756982513, 0.09035055729327723, 0.15980251802830026, 0.23323442379478365, 0.17591222858754918, 0.13062232523225248, 0.16447202215204015, 0.10377545215305872, 0.1226326082542073, 0.2631347521673888, 0.11571792929316871, 0.10974146600347012, 0.13772457459708676, 0.13670511601958424, 0.12734151299810037, 0.16907442128285766, 0.07782372791552916, 0.18202305771410465, 0.1786801722482778, 0.11209928401513025, 0.09011022018967196, 0.08371070303837769, 0.20573785237502307, 0.16235002898611128, 0.26780238607898355, 0.1180001298780553, 0.16525651677511632, 0.239196244510822, 0.1436659714090638, 0.13287063193274662, 0.21461288473801687, 0.17983145109610632, 0.15742362302262336, 0.1442694413708523, 0.08509651539498009, 0.19451922154985368, 0.1231021131388843, 0.21215354092419147, 0.2294037098181434, 0.2165166864870116, 0.14474477211479098, 0.08869769793818705, 0.11995077598839998, 0.07867323467507958, 0.12077741717803292, 0.17367965541779995, 0.07724303446593694, 0.11896721509401686, 0.12429032867657952, 0.13130582839949057, 0.09458649132284336, 0.13538167375372723, 0.16661850619129837, 0.16371037083445117, 0.07248307738336734, 0.12746513995807618, 0.17744320502970368, 0.18014702713117003, 0.12115941543015651, 0.07908613595645875, 0.14282062067650259, 0.08447952350252308, 0.24820487829856575, 0.16334544197889045, 0.12290244572795928, 0.15790687990374863, 0.2170305495383218, 0.08600269997259602, 0.17462152987718582, 0.14951967605156824, 0.22351871622959152, 0.13896595017286018, 0.12261759460670874, 0.15203347866190597, 0.15162474825046957, 0.19186166493454948, 0.1236958906520158, 0.14899629866704345, 0.13435848959488794, 0.0531288307684008, 0.09864497784292325, 0.12566192890517414, 0.11392420288757421, 0.15706053469330072, 0.06545084223034792, 0.12285272183362395, 0.15794833627296612, 0.10023606824688613, 0.19079592602793127, 0.1339586204267107, 0.1185046938189771, 0.11494363920064643, 0.11084146986831911, 0.12065384216839448, 0.08857061257003807, 0.20143355912296101, 0.1092566506122239, 0.08189926156774163, 0.2945894346339628, 0.1334448909619823, 0.1204941542528104, 0.141025499033276, 0.16419511201092973, 0.1721107997582294, 0.15300250088330358, 0.12083074791007675, 0.1374865381512791, 0.22428188152844086, 0.08715890668099746, 0.10763946629595011, 0.12086001079296693, 0.13748076424235478, 0.14046922966372222, 0.11193046026164666, 0.14990164461778477, 0.0952169531956315, 0.08406470748013817, 0.12382585555315018, 0.14701590727781877, 0.16644258750602603, 0.24137379485182464, 0.15602023660903797, 0.120494198781671, 0.12128556569223292, 0.08937890044762753, 0.1318226006696932, 0.15104502701433375, 0.10360777872847393, 0.1880346320103854, 0.10373458950198255, 0.18181981315137818, 0.14138143305899575, 0.09316695577581413, 0.09491416436503641, 0.12257219743332826, 0.13342400692636147, 0.12168084096629173, 0.06155250004667323, 0.1654567482182756, 0.20639254536945373, 0.12892251019366086], [0.06285150710027665, 0.027783806690422352, 0.06656243102042936, 0.03709688244271092, 0.047800481333979405, 0.07403150913887657, 0.03899858391378075, 0.06405178253771737, 0.04753381283080671, 0.01166258263765485, 0.011647370465652784, 0.029638914274983108, 0.047646626699133776, 0.08234785273089074, 0.02162139458960155, 0.04356338584329933, 0.03787824520259164, 0.023998636461328715, 0.055924371190485545, 0.006502716960312682, 0.02015984235185897, 0.04553196224151179, 0.025430731002415996, 0.03631486288213637, 0.04158904295763932, 0.04693307768320665, 0.09306999418186024, 0.04492693376960233, 0.016733450429455843, 0.013684895166079514, 0.026749132230179384, 0.0073604986664577154, 0.045573474271805026, 0.0641869795799721, 0.05357890251616482, 0.033962147135753185, 0.027860546615556814, 0.02242986058263341, 0.06153315225674305, 0.024326235288754106, 0.024870082961570006, 0.050088481802958995, 0.030738044260942843, 0.01618915190192638, 0.02873228440876119, 0.04591363023791928, 0.07722845126409084, 0.1256037296843715, 0.048134562821360305, 0.03289795931777917, 0.029626192008436192, 0.028155787804280408, 0.03791989081946667, 0.07052571483654901, 0.04413338494487107, 0.029431111070152838, 0.04178313312877435, 0.018052760788123123, 0.021897022670600563, 0.019477305831969716, 0.010131865019502584, 0.06755534297553822, 0.011269303740846226, 0.018162262822443154, 0.028342267250991426, 0.08198539522709325, 0.05336834779882338, 0.0680742526310496, 0.015082071658980567, 0.05305316881276667, 0.029697853788093198, 0.013111219650454586, 0.06121356120274868, 0.06341802552924491, 0.017304315988440067, 0.03590994710975792, 0.007474053754776833, 0.025820939263212495, 0.020239515615685377, 0.02516400312742917, 0.01566666323924437, 0.04775600813445635, 0.009024262490129331, 0.0016176372582776821, 0.014740793194505386, 0.024025630227697548, 0.04263584967702627, 0.04919311773846857, 0.11154031322803348, 0.07168966956669465, 0.06150309898657724, 0.08101074752630666, 0.04329843541199807, 0.06169086977024563, 0.03207271336577833, 0.04695619558333419, 0.017646735504968092, 0.07468407959095202, 0.01954934425157262, 0.06880187647766434, 0.014070704346522689, 0.033419299506931566, 0.02957549033453688, 0.08456944953650236, 0.045199673040769994, 0.015028749276098097, 0.045097746478859335, 0.0014571968745258346, 0.04000122913566884, 0.07865648440201767, 0.03836261901597027, 0.05402315211540554, 0.04751262080390006, 0.04563556605717167, 0.022317059701890685, 0.022888689672981855, 0.01637569257582072, 0.08387204594328068, 0.007058127293930738, 0.04995932584279217, 0.023195985195343383, 0.022526619941345416, 0.04145390528719872, 0.03817748285655398, 0.015540971253358293, 0.08437912576482631, 0.010466524454386672, 0.02954106210381724, 0.02834087015799014, 0.03024312823981745, 0.04197936439595651, 0.030788285803282633, 0.06141731784737203, 0.017925517713592853, 0.029314913008420262, 0.004655634775190265, 0.025423788210900966, 0.04983325350622181, 0.018863967161451, 0.034934705690830015, 0.09596765041351318, 0.04164770231000148, 0.07622352393809706, 0.02427695297228638, 0.0237915958132362, 0.016652984922984615, 0.019091934518655762, 0.013795392605970846, 0.026271779133821838, 0.04782511692610569, 0.07663356052944437, 0.01042678708472522, 0.03237280820030719, 0.027539469410839956, 0.028477985651989002, 0.05425199335149955, 0.06989882269408554, 0.014192280195857165, 0.05541136903048027, 0.03461989777861163, 0.06040617132384796, 0.07147477328544483, 0.01468039443352609, 0.014620568981627002, 0.023650060829822905, 0.03009202697285218, 0.03963194016250782, 0.023850067773310002, 0.028619771110243164, 0.06934923265362158, 0.005419563094619662, 0.021554771992668975, 0.05359179362130817, 0.019612118812801782, 0.011594230836635688, 0.06403957420843653, 0.012539802119135857, 0.05482775151904207, 0.05182046152185649, 0.061414853917085566, 0.015849890223762486, 0.05809770984342322, 0.006902687246110872, 0.0440224746853346, 0.03545850238879211, 0.04469833002076484, 0.008720787172933342, 0.04909532122837845, 0.044949420844204724, 0.06362696236465126, 0.09630140164517798, 0.027232340871705674, 0.049433399180998094, 0.05308950807375368, 0.034718365932349116, 0.03629417922638822, 0.021032177573943045, 0.060537245735758916, 0.04360934704891406, 0.018296953348908573, 0.06314199112239294, 0.018487763227312826, 0.03477768579614349, 0.05138268716109451, 0.05254846757452469, 0.07487757975468412, 0.007487936554753105, 0.04607067981851287, 0.054198109719436616, 0.019942660255765077, 0.05337506052455865, 0.054919889153097756, 0.04262682887201663, 0.10758809483377263, 0.043810131392092444, 0.042821004390134476, 0.029793119574605953, 0.044017339023412205, 0.022377973327820655, 0.023489651175623294, 0.02392398011579644, 0.04411031899508089, 0.06435015558963642, 0.04108899498532992, 0.11344605940394104, 0.0398388991743559, 0.012749510788125917, 0.032416075409855694, 0.11590050504310057, 0.03939846792491153, 0.030065671453485265, 0.00377778423626296, 0.021640326776832808, 0.0385164513863856, 0.029698707257921342, 0.02048960825050017, 0.0602898582292255, 0.030253427394200116, 0.03263365455495659, 0.07202228531241417, 0.07799413244356401, 0.04644795801141299, 0.03629024213296361, 0.03844012891931925, 0.04226138422382064, 0.02362432500376599, 0.015607287714374252, 0.04256837361026555, 0.03893781315127853, 0.04715689457952976, 0.014772099766560132, 0.03700227716763038, 0.018619678121467587, 0.02570762073446531, 0.0747855163353961, 0.05369730104575865, 0.04360040416941047, 0.01893214270239696, 0.06380095146596432, 0.024546480599383358, 0.030443261348409578, 0.022224667882255744, 0.016441099905932788, 0.07286253006896004, 0.03186397319950629, 0.015441187642863952, 0.05760957705206238, 0.07794210789143108, 0.03604722958698403, 0.022626845129707363, 0.01162167638540268, 0.05078009664430283, 0.07221177045721561, 0.048092835568240844, 0.05819465659442358, 0.04034341487567872, 0.032727770012570545, 0.0054691204695700435, 0.03861217730445787, 0.06550618418259546, 0.074935103621101, 0.01662369420955656, 0.05776894584414549, 0.05864449456566945, 0.0038775100983912125, 0.03320084091683384, 0.0008550117559025239, 0.05915209017985035, 0.02085418458591448, 0.01676088391832309, 0.02945721982541727, 0.012666106376855168, 0.061743643891531974, 0.012036418193019927, 0.01680954468611162, 0.015614931835443713, 0.0113444916496519, 0.05684438569005579, 0.024583725280535873, 0.06806790726841427, 0.04180571668257471, 0.04488490965741221, 0.025972112889576238, 0.001203111253289535, 0.06154285954835359, 0.02184602042689221, 0.02949919940874679, 0.03242402752221096, 0.02901330419263104, 0.028051824046997353, 0.062375946290558204, 0.04327594462665729, 0.02441196447762195, 0.052815072995144874, 0.03086526136030443, 0.04378421559522394, 0.08751866276725195, 0.014468143908743514, 0.10373067838372663, 0.02104237468302017, 0.03630931532825343, 0.01196431390781072, 0.03420604654820636, 0.031290879342122935, 0.0561826608463889, 0.03941293238312937, 0.07320989228901453, 0.02975535910081817, 0.02116763065714622, 0.022989766475802753, 0.05111605947604403, 0.05568575958022848, 0.02489224720193306, 0.0177415244615986, 0.0019946677593907225, 0.021767451107734814, 0.03854948437947314, 0.027187778614461422, 0.07264027168275788, 0.01987001141969813, 0.030971162123023532, 0.005477027589222416, 0.038800623442512006, 0.022870148968650028, 0.028576728400366846, 0.03998558837338351, 0.015039047502796166, 0.03224564490665216, 0.041384662908967584, 0.012621798305190168, 0.028081879172532354, 0.0692568278464023, 0.1314995437860489, 0.15766439057188109, 0.14176482654875144, 0.15039986319607124, 0.11243270128034055, 0.2036573749501258, 0.10616843312163837, 0.21536512562306598, 0.09972275438485667, 0.16620661423075944, 0.19149425730574876, 0.14991939679021016, 0.12082193861715496, 0.2699686854612082, 0.1337649198831059, 0.08531506304279901, 0.14532194036291912, 0.11651480293949135, 0.09810580755583942, 0.11304652420221828, 0.11650826461846009, 0.1959722873289138, 0.08781163298408501, 0.15165168821113184, 0.18638370966073126, 0.13676128175575286, 0.19252478872658685, 0.0777342842775397, 0.0666352357075084, 0.12506093771662563, 0.15111253276700154, 0.15942762955091894, 0.2010758884716779, 0.17761079681804404, 0.13425491546513513, 0.12050927922246046, 0.15313625073758885, 0.1304206540226005, 0.14654151163995266, 0.16244376223767176, 0.14672250661533326, 0.16481254919199273, 0.10821109070093371, 0.12176141593954526, 0.14854431588901207, 0.15990235173376277, 0.19703168829437345, 0.16206136322580278, 0.14742698287591338, 0.2964910544687882, 0.16951734985923395, 0.07981873961398378, 0.282761738053523, 0.14591105718864128, 0.16756487806560472, 0.13982467440655455, 0.12155468328273855, 0.12596825778018683, 0.16145369270816445, 0.08613846846856177, 0.15259240492014214, 0.133407115645241, 0.10057756007881835, 0.14968798030167818, 0.1954319592914544, 0.14036761480383575, 0.07913410838227719, 0.11809258663561195, 0.14665709371911362, 0.12722302170004696, 0.09188052441459149, 0.15845212095882744, 0.2039192640222609, 0.17035192460753024, 0.07047072169370949, 0.17302775289863348, 0.050971092059626244, 0.08828725316561759, 0.10014499188400805, 0.12308804201893508, 0.15446894016349688, 0.10547672180109657, 0.08842443174216896, 0.12263845637789927, 0.14132096286630258, 0.13256468897452578, 0.10435683579999022, 0.1794273071573116, 0.25314746308140457, 0.12467567401472479, 0.13051400135736912, 0.24271617672638968, 0.1132787051028572, 0.1655272819334641, 0.11551649557077326, 0.10466566571267322, 0.13348858861718327, 0.2053043490741402, 0.15131824126001447, 0.13446565571939573, 0.12386348986183293, 0.09060251642949879, 0.11520166168338619, 0.1763290780945681, 0.14421655592741445, 0.18769109185086563, 0.10266035300446674, 0.13849240058334544, 0.0779725359461736, 0.11444820367614739, 0.1307654261472635, 0.15813066711416468, 0.12420752726029605, 0.13701104413485155, 0.16051738435635343, 0.1099433153285645, 0.13134633481968194, 0.08969671776867472, 0.11227177397813648, 0.13892804126953706, 0.08801620599115267, 0.14204393344698474, 0.16275786882033572, 0.13053568691248074, 0.1313185488106683, 0.08799242015811615, 0.1166540892154444, 0.10991852017468773, 0.12290371480048634, 0.11446644566603936, 0.10319800931029022, 0.09744061317178421, 0.17017541220411658, 0.10837825946509838, 0.14111988537479192, 0.15330700407503173, 0.1017793791834265, 0.1499913405859843, 0.17201620561536402, 0.13334444869542494, 0.206997262139339, 0.14858988375635818, 0.151066089165397, 0.1602682750672102, 0.17345371597912163, 0.09497602237388492, 0.11572059360332787, 0.10920629589236341, 0.10649125251802616, 0.14359732274897397, 0.09348711828351952, 0.08924221168854274, 0.10476708761416376, 0.1224180385179352, 0.12811150605557486, 0.2591547626070678, 0.11384117140551098, 0.19389929075259715, 0.13736185734160244, 0.13651172717800364, 0.13893145514884964, 0.12598183908266947, 0.21874183817999437, 0.141132086282596, 0.09262119521736167, 0.11065872342442162, 0.14722746389452368, 0.14893756509991363, 0.13285477965837345, 0.13388856168603525, 0.1732897904003039, 0.1409816084196791, 0.15356585034169257, 0.13865870103472844, 0.20777644298505038, 0.16974588681478053], [0.03183990535035264, 0.01347753539448604, 0.02140648903150577, 0.06133188922831323, 0.03454739366134163, 0.05180794149055146, 0.04292493475077208, 0.011410065035306616, 0.015214644281513756, 0.043151241552550346, 0.028504925612651277, 0.01817551386920968, 0.04260074609192088, 0.010341031920688692, 0.04105248874111567, 0.034362409642199054, 0.019010044088645373, 0.016789571636763867, 0.029674025281565264, 0.03704325856233481, 0.05221603365498595, 0.025103301013587043, 0.020279964519431815, 0.04964097046467941, 0.024340028103324585, 0.08982273444416933, 0.07465030445018783, 0.016579491893935483, 0.014664476293546613, 0.03316926995466929, 0.014832528213446494, 0.05189604555198457, 0.02030671894317493, 0.02645567034051055, 0.021346258181438316, 0.02470171377353836, 0.043499242019606754, 0.04039176579681225, 0.09692992651253007, 0.02154200519726146, 0.037495645810849965, 0.04335729514423292, 0.012289220594539074, 0.02769300863292301, 0.0813674830715172, 0.01861680229922058, 0.06190620762936305, 0.07762794935842976, 0.06576163883437403, 0.03955222236982081, 0.019367150707694236, 0.04491416140808724, 0.010294246931152884, 0.017898462720040698, 0.026327724081056658, 0.06823682750109583, 0.029908189571870025, 0.04325390655139927, 0.03059956507058814, 0.04221822091494687, 0.026647478407539893, 0.032917693024501204, 0.013606147731479723, 0.05708579148631543, 0.044828409954789095, 0.04721869692730252, 0.02943428004073212, 0.031209194858092815, 0.043266022112220526, 0.021954715375613887, 0.026554342584859114, 0.028515914964373223, 0.025046038754226174, 0.053455316374311224, 0.0880349229555577, 0.0440876538050361, 0.04105491185327992, 0.0212083356018411, 0.01473375670684618, 0.03876319322444033, 0.022553702765435446, 0.07949639519210905, 0.08404834312386811, 0.08249394450103864, 0.03023226876393892, 0.03620767449319828, 0.07355282388743944, 0.017624669599172194, 0.05655757158820052, 0.12913878686958924, 0.07693225270486437, 0.011847949790535495, 0.05491825271747075, 0.012819306994060753, 0.05283596445224248, 0.07074206572724506, 0.0625694019254297, 0.012114464298065286, 0.1269327529007569, 0.09556768476613797, 0.08057811253820546, 0.029499574193323497, 0.043612163499346934, 0.07191639568191022, 0.0024079767581497435, 0.016145088738994673, 0.03856328832625877, 0.05344415447325446, 0.0828736495168414, 0.0455274240084691, 0.013209327862568898, 0.08067555652814917, 0.015844045810808893, 0.07416317355819046, 0.020269980777811725, 0.1307493363856338, 0.037629406797350384, 0.052056182466913015, 0.05978357992717065, 0.027047774310631212, 0.0900209101382643, 0.026350003354309592, 0.045756317194900475, 0.06067175629141275, 0.02701510125916684, 0.05459244617668446, 0.025308068834419828, 0.01612424366612686, 0.033204243663931265, 0.027719417957996484, 0.0279502945340937, 0.020946728545823134, 0.06084870656195562, 0.012555910434457473, 0.00999885081910179, 0.052225933904992417, 0.06065091678465251, 0.1206455375358928, 0.08138349861837924, 0.02559216482040938, 0.046470155648421496, 0.03477674697933253, 0.06718658463796601, 0.059627688096952625, 0.019724424309970345, 0.011148552603117423, 0.07927078971988522, 0.09112884014029987, 0.016742050065658987, 0.035006634643650614, 0.07188665782450698, 0.015378474308818113, 0.037541458586929366, 0.023363359905488323, 0.0766160903731361, 0.05213551805354655, 0.01985090482776286, 0.06382929408573546, 0.04554645267489832, 0.10160445497604087, 0.06287004594923928, 0.057481515759718604, 0.03686743264552206, 0.026354975743743125, 0.08552276791306213, 0.02148420302546583, 0.01687291111011291, 0.08027072239201516, 0.032668427884345874, 0.06702156068058684, 0.04698781107435934, 0.050666997049120255, 0.017839590000221506, 0.011291811224509729, 0.014249804062274052, 0.018456696925568394, 0.048904503928497434, 0.008222913693316514, 0.022841785939817782, 0.05089938575110864, 0.010578743676887825, 0.01643123490794096, 0.026720234855019953, 0.08764473139308393, 0.03350646104081534, 0.04879678490397055, 0.0378010803979123, 0.029620874520333018, 0.028492342498793732, 0.03513544179440942, 0.060042882614652626, 0.010909266566159204, 0.011291076498309849, 0.06762636650819331, 0.03614433961047325, 0.039269282278837636, 0.004639337676053401, 0.016348828685295302, 0.04483821743633598, 0.1150313091056887, 0.020699090564448852, 0.0490222976077348, 0.03377956025360618, 0.017288883027504198, 0.008308663291245466, 0.01981585875910241, 0.05282040532620158, 0.01643952840822749, 0.044422158316592686, 0.03420325978368055, 0.04026829839858692, 0.07901563192717731, 0.03517411139910109, 0.09948437655111775, 0.051299470142112114, 0.04654744661820587, 0.0558565685787471, 0.026165878371102735, 0.05110640042403247, 0.03155100952426437, 0.030414247084991075, 0.04544805131445173, 0.02261314137285808, 0.039415596693288535, 0.06842695831437595, 0.022396584536181763, 0.031544619632768445, 0.03755265388463158, 0.021643427098752, 0.015430224266310688, 0.04207375444821082, 0.018839060685422737, 0.055552800113218836, 0.06278582703089342, 0.02145891990949167, 0.03538211312843487, 0.03294726018793881, 0.02694541915843729, 0.031836161215323955, 0.024875719573174138, 0.04958032215654384, 0.029691193012695294, 0.013576528617704753, 0.015213038459478412, 0.11575501441257074, 0.022583307036256883, 0.034034525087918155, 0.057752574066398665, 0.06631656491663307, 0.01721880387776764, 0.039371264501824044, 0.03069992941163946, 0.00777566813667363, 0.018581758085929323, 0.0332692595111439, 0.039818052246118896, 0.03238206649257336, 0.05064837656391319, 0.02134610418579541, 0.006334319941743161, 0.05886526494577993, 0.013088039595459122, 0.054844227197463624, 0.03149087329802569, 0.04876965198491234, 0.08394375967327505, 0.04764271558087785, 0.06807105397456326, 0.010959156516037183, 0.06100985650846269, 0.02264563816424925, 0.07250504495459609, 0.043540980404941365, 0.027048592528444715, 0.05517790421436075, 0.027335761005815584, 0.05491780371812638, 0.008180065797205316, 0.0765952434448991, 0.01752564297930803, 0.016705454763723537, 0.03551130990672391, 0.03691878555400763, 0.028081808668503072, 0.05509779308340512, 0.010236177586193662, 0.04432468464074191, 0.04384240739454981, 0.027949281502515078, 0.05226732719165739, 0.07083337957737967, 0.14258562703616917, 0.013558980535890441, 0.022547010448761284, 0.06129634777607862, 0.06083537016820628, 0.03054803590202937, 0.0442381724860752, 0.04329166702518705, 0.0692257541231811, 0.04767076134157833, 0.06768723746063188, 0.019202577605028637, 0.020755139412358403, 0.025521901989122853, 0.058945569035131484, 0.022855331990285777, 0.04755688991281204, 0.03976247651735321, 0.016604416923655663, 0.05491247880854644, 0.05986568743537646, 0.03772948541154619, 0.0495390550349839, 0.048145854598260485, 0.03903159835317638, 0.04863602458499372, 0.0454151704616379, 0.015461384264199296, 0.009180687738989946, 0.030975412773841526, 0.052260094962548465, 0.08713972958503291, 0.02881596898077987, 0.028536140343931038, 0.01576591435878072, 0.04136519637540914, 0.06875057180877775, 0.012718725574814016, 0.03483437103568576, 0.041961137249018066, 0.03235380179830827, 0.036753164167748764, 0.013373400015552761, 0.028656336726271547, 0.008545222863176605, 0.04345900648331735, 0.04344349930761382, 0.0006374890836013947, 0.05122864698932972, 0.10888835982768796, 0.02687736792722717, 0.02069740032311529, 0.021976081807224546, 0.011293203679088037, 0.04842662390728947, 0.024661799216119107, 0.03215946300770156, 0.010145996438950533, 0.04437528798007406, 0.01453074035453028, 0.018954605657199863, 0.10843487048987299, 0.09419899375643581, 0.07996805230504833, 0.17038342135492712, 0.12384160392684862, 0.13108751823892817, 0.20480135106481612, 0.1419274607906118, 0.22757137689040974, 0.08327461706358008, 0.1203802197414916, 0.10269164937199093, 0.12398702776408754, 0.10433295348775573, 0.18111063167452812, 0.13439319242024794, 0.06759780124411918, 0.18527845881180838, 0.11760814973968081, 0.1227542017295491, 0.1261859742226079, 0.09823908243561164, 0.14341074682306498, 0.1775083804386668, 0.24563747778302059, 0.25695669930428267, 0.14750281552551314, 0.11178398999618366, 0.15854582452448085, 0.12826379475882277, 0.16889640974113718, 0.13020520855206996, 0.20819591969484463, 0.10493968889932148, 0.23010625649476424, 0.1480328870820813, 0.12975058372830972, 0.1819439893006347, 0.19498319743433967, 0.10928529009106569, 0.15822947665583342, 0.11652707806206308, 0.11318761389702559, 0.18084691691910848, 0.17535116494400427, 0.21394812822109088, 0.14145443070447072, 0.14117412152700126, 0.1845608465373516, 0.20647287543397397, 0.0995680240157526, 0.17572715179994702, 0.08369202318135649, 0.07887285755714402, 0.17275891732424498, 0.1356986301834695, 0.1430825245915912, 0.12263918368262239, 0.09155327439657412, 0.1522990784724243, 0.13984638964757323, 0.13584336382336915, 0.280299203004688, 0.14751322043593973, 0.2373382481164299, 0.12715596123598516, 0.07898328913142905, 0.08613347381469794, 0.22888278152095154, 0.20359270420158282, 0.1202291258960031, 0.10142709652427584, 0.18462545791408047, 0.09111547406064346, 0.20327123551396653, 0.08057277649641037, 0.12033280392643064, 0.12271800718735904, 0.09832362789893523, 0.13249753945274279, 0.1129702759499196, 0.19945518637541682, 0.1482940636924468, 0.19812503509456292, 0.11462309819762595, 0.13877214572858065, 0.1938675416749902, 0.13232613302534446, 0.20504486456047744, 0.1847386799636297, 0.1850702567026019, 0.20063407311681658, 0.12331495367106982, 0.17657683667493984, 0.10888812234043144, 0.23430276021827012, 0.1620346904383041, 0.09096627269173041, 0.20606656442396343, 0.2513592434115708, 0.16675304272212088, 0.1739749708212912, 0.11082681245170534, 0.16347077587852255, 0.08684109678142704, 0.08134766030707397, 0.1842040367773734, 0.1465936697786674, 0.13648282794747502, 0.1067598357622046, 0.1462251043994911, 0.21993064001435414, 0.19777478592004627, 0.16552487737499177, 0.16384817281505093, 0.25934181350748986, 0.08475057067698799, 0.09054117050254717, 0.19491797749651596, 0.11861865801620297, 0.16628237266559154, 0.11832368400064297, 0.12324493945925497, 0.19638990866951644, 0.09898465883452445, 0.17417670140275732, 0.08277559696580283, 0.07168759155320004, 0.11567206456675194, 0.10693867108784616, 0.1163518124667462, 0.11149867132189684, 0.09183718299027532, 0.12965122499736026, 0.13197917898651212, 0.14329673809697852, 0.12622784619452432, 0.29116059362422675, 0.12453129660570994, 0.1253413804806769, 0.12257858732482418, 0.11626366758719087, 0.2297222544439137, 0.15678702358854935, 0.07904202269855887, 0.14061368128750473, 0.2418813348049298, 0.1455908946809359, 0.0735757636721246, 0.11831837764475495, 0.11644130063359626, 0.12355863786069676, 0.08723891762201674, 0.10280409958795644, 0.15969070605933666, 0.12468771165004, 0.15089282736880705, 0.09966265526600182, 0.11916248899069615, 0.15797233732882887, 0.14365852024639025, 0.15343950712122023, 0.19037155114347115, 0.08712060443940572, 0.23352769087068737, 0.12013635743642226, 0.09398530717589892, 0.17774626845493913, 0.2016930139507167, 0.1638395935879089, 0.14936087129171938, 0.09805171241168864, 0.0835839961655438, 0.08588970798882656, 0.1159599213860929, 0.06611879740376025], [0.01877460330433678, 0.013085562677588314, 0.0832801683282014, 0.05819898702611681, 0.019177708236384206, 0.02612686552311061, 0.048871040489757434, 0.06307475254288875, 0.017866754460555967, 0.030795438251516316, 0.01859751202573534, 0.0737501164257992, 0.01885271991341142, 0.03930007769668009, 0.049747182929422706, 0.07264082829351537, 0.021039187158748973, 0.02372057228058111, 0.023881961569713894, 0.03201608749805018, 0.009518159913568525, 0.0450910708605079, 0.05168100084119942, 0.0409193585801404, 0.08894632483134046, 0.028767892654286698, 0.029039500150247477, 0.033553772955201566, 0.02374126335780602, 0.06419610799639486, 0.02284941521793371, 0.05274445764371194, 0.08659411745611578, 0.027034096528950613, 0.017500374706287403, 0.021248725133773405, 0.025794314715312794, 0.048558165872236714, 0.02761258579994319, 0.032223399030044675, 0.07032489709672518, 0.026372855936642736, 0.07124125651898794, 0.08468549916869961, 0.08026387236895971, 0.03577278337616008, 0.027229875086050015, 0.06917260150657967, 0.08982578467112035, 0.020507709232333582, 0.03309917410661001, 0.029232475244498346, 0.07109355428838171, 0.044754621922038496, 0.06758169663953595, 0.023782947937434074, 0.0025215854202542687, 0.032859007696970366, 0.032897391574806534, 0.004820897611352848, 0.023389286834571976, 0.04807382545550354, 0.016760880207584705, 0.01563067464303458, 0.03835421419353224, 0.10423019572044723, 0.0978649064199999, 0.041810585171333514, 0.006511301289719995, 0.03934540436603129, 0.08595189254265279, 0.015180377467913786, 0.022742009750800207, 0.02235777021269314, 0.018266727529407945, 0.020861912198597565, 0.018231531175842974, 0.025959691192838363, 0.008129584912239807, 0.1029607595410198, 0.10497836963622831, 0.03698673288454302, 0.04234074949636124, 0.016222140366153326, 0.07570801331894472, 0.01474643166147871, 0.033148426737170666, 0.04168119914538693, 0.03102742619375931, 0.00391700951695384, 0.08019407337997109, 0.072981830307981, 0.02311560503585497, 0.10655734076863155, 0.0347907847026363, 0.03345130091474857, 0.03860584678477608, 0.051272066339151934, 0.04937454315950163, 0.04882738365267869, 0.08536195193300955, 0.028815351142839063, 0.09089916027733125, 0.09171562662231736, 0.05264520652417559, 0.022686806951242033, 0.07201876753242686, 0.025796346344577614, 0.03867766812618356, 0.03872148823575117, 0.0158007767458912, 0.027110817900393158, 0.04288537456886843, 0.014481227972282795, 0.026925691017822828, 0.009792299988475861, 0.04432806141267065, 0.05796437559183687, 0.021155218237254303, 0.06248193240026012, 0.018969435623148456, 0.02879390121961478, 0.03745951435121242, 0.016155508492374793, 0.017795450767152943, 0.018608083919389173, 0.033504275415907614, 0.1158012353698723, 0.03008454426890239, 0.03514966134389397, 0.03552878748450894, 0.03933430554752704, 0.0422188109223498, 0.029502082652470563, 0.010636545848683454, 0.029567293313448317, 0.0472714413626818, 0.013627452008222463, 0.08622757071861997, 0.013557719812524738, 0.012691645533777773, 0.03790424634644296, 0.014675891452498036, 0.010807803846546449, 0.010817555667017587, 0.04013484540337231, 0.05519565267604776, 0.02333559430553578, 0.07750655626296066, 0.07914089903351851, 0.021284173817548435, 0.04049483897688333, 0.09134692765655927, 0.06590300312382169, 0.0257758556472254, 0.06432272581150755, 0.04945823886373546, 0.019135775037284475, 0.012752074908348732, 0.030778910622757394, 0.028194318256282713, 0.05417104359366931, 0.057000188462552615, 0.028964424491277896, 0.026466819253982976, 0.031018522277008742, 0.06957604782655835, 0.029307459990377538, 0.034147594997193664, 0.021902568369114306, 0.03816726719378494, 0.11174967308761552, 0.01045900000463007, 0.022789334652770776, 0.021956448290438857, 0.04147488209127914, 0.05161274180863984, 0.0356945201929193, 0.03966250551457051, 0.018890151986852288, 0.014440232662309427, 0.03274680610047653, 0.05769351024355274, 0.056241847123601474, 0.00896898176506511, 0.06133037524705287, 0.07414580730255693, 0.016464781838294584, 0.05023478137445636, 0.03587709965358954, 0.034266850707354024, 0.03905520978150889, 0.007084829303494189, 0.02520274509151932, 0.04172024724539369, 0.026441011068527587, 0.03575329086743295, 0.06314657017355785, 0.019090741516265552, 0.0257674007298192, 0.01394732971675694, 0.05262509061140008, 0.011147496898047393, 0.05028230480093043, 0.03159436208079569, 0.0331292978808051, 0.028784539026673883, 0.0724970742885489, 0.09531890202197246, 0.04316826270951424, 0.03195816287188791, 0.037054943677503616, 0.01860135449533118, 0.073200979095418, 0.056970947844092734, 0.04145163431530818, 0.03726203998667188, 0.027755731243814807, 0.09896990493871272, 0.05215401979512535, 0.0020234452313161455, 0.027039822198275942, 0.06915778081747703, 0.04505837925535161, 0.07314759641303681, 0.06842554081231356, 0.053771393359056674, 0.06364138971548527, 0.014802917448832886, 0.07004265091381967, 0.07208634749986231, 0.030491068646369968, 0.0306042220472591, 0.07457237894413993, 0.008129014386213385, 0.023947927365952637, 0.0103255377325695, 0.04873627389315516, 0.11543093336513266, 0.016691231503500603, 0.04091061979124788, 0.05645205674227327, 0.021430363922263496, 0.04232363928167615, 0.02800001842842903, 0.03338180991704576, 0.0761697776033543, 0.02100243971653981, 0.02438186482322635, 0.02111564506776631, 0.012847172783949645, 0.0358755596971605, 0.017067374210455455, 0.034656166535569355, 0.06310051991022192, 0.10281421506078914, 0.00404726246415521, 0.017042059553205036, 0.06943667991436087, 0.018602003874548245, 0.05948472819000017, 0.012449381629267009, 0.011932139022974297, 0.03769835973798763, 0.03091890936048003, 0.040829020654200576, 0.02730664098635316, 0.10271982129779644, 0.009378511840623105, 0.07045408274279907, 0.05721436486055609, 0.017778926849132404, 0.035186609165975824, 0.017627630768402014, 0.03473986595054157, 0.028962242577108555, 0.015894003481662367, 0.0285248838190455, 0.006525825119751971, 0.036187547448207624, 0.022357146808644757, 0.01644633575779153, 0.07139770124922507, 0.02508296431187773, 0.014709201823279727, 0.04390779802633915, 0.046404145323322155, 0.02931692793936236, 0.014209724376996746, 0.009198920452035964, 0.05401175643783063, 0.016355053448933177, 0.043349725237931125, 0.014219898293958977, 0.02207948524301173, 0.05593625668552704, 0.04374358672066592, 0.08440895267995074, 0.020615847570297774, 0.043158184344065376, 0.0467091791506391, 0.06865049319458194, 0.01757733913109405, 0.03143756854115054, 0.019359619764145464, 0.02787703342619352, 0.03144103437080048, 0.055047416099114344, 0.089491669787094, 0.009717492430354469, 0.05632039603369776, 0.059599067171802744, 0.013399467025010381, 0.0810735257982742, 0.03330600695335306, 0.039886838203528896, 0.05088457248348277, 0.040199401119025424, 0.02191591775044799, 0.05515851931704674, 0.053398363961605355, 0.03836293442873284, 0.03667196950118523, 0.013470104640873615, 0.03271612571552396, 0.09790879703359678, 0.024109960468194913, 0.037641251474269666, 0.05263368097075727, 0.02667430519068148, 0.025857740511128213, 0.03583058554795571, 0.050468973495299, 0.06532797968247905, 0.006484473578893812, 0.04213219115626998, 0.013891111102566356, 0.024194732286559884, 0.01011825681416667, 0.057363362138858065, 0.05196159574552439, 0.09693195999716409, 0.01699287928204285, 0.01381052128635929, 0.018489091671654023, 0.043367740872781724, 0.025542333314660937, 0.09553471114486456, 0.04265921990736388, 0.05546801345190033, 0.01910975533974124, 0.014411883548746118, 0.12699013575911522, 0.13020336802583188, 0.16209921275731176, 0.16926442593103275, 0.06197491937200539, 0.1374320051399991, 0.15168232406722382, 0.1788345241220668, 0.0956151747959666, 0.15329318528529257, 0.17279661842621863, 0.11807529459474608, 0.11360925025655888, 0.1802278618561104, 0.2224472924717702, 0.14949276577681303, 0.16937736596446484, 0.132247049768921, 0.0843793706735596, 0.18269384047016501, 0.16222445759922266, 0.17201055045006797, 0.12533962901216, 0.09774366917554289, 0.20588368439348415, 0.1012944895774126, 0.1693757183966227, 0.09682071206043474, 0.10830395563971251, 0.11449812052887864, 0.13405000849161297, 0.11280312202870846, 0.19170536863384768, 0.14485352643532678, 0.08691762704984285, 0.16743893560487777, 0.1947775186272338, 0.10131368151633069, 0.08209647989133373, 0.10339936139644124, 0.19234564912039787, 0.1918800553539768, 0.19776570203248411, 0.20236824959283695, 0.14709625218529254, 0.10101052161189727, 0.17923814855748788, 0.15436895802849904, 0.15712067834101617, 0.135529390827287, 0.12747983448207378, 0.2375694122747518, 0.20802219776669517, 0.08347394308657385, 0.15113932429812849, 0.11992835570708849, 0.11722986964741722, 0.22850339562864974, 0.11192027799552307, 0.1305979085736908, 0.09667543665273115, 0.10954555385978892, 0.2239313058089465, 0.05359255432267673, 0.07342556782532483, 0.17090320674469694, 0.22081600734964013, 0.2446612567291595, 0.05424487615528051, 0.16814446571515873, 0.1427744294051081, 0.05718068248825148, 0.15061449230415747, 0.30923384882044047, 0.16126116475788876, 0.13190618134103715, 0.10765960076241754, 0.13965748337795958, 0.12298989298869856, 0.20013189146993682, 0.1664384760078974, 0.1914826946449466, 0.1762211401364766, 0.1453660981496796, 0.15344321785960346, 0.16287061589537188, 0.08086624395218678, 0.13398456590948626, 0.13696175068616867, 0.09967452962882817, 0.15572916629025713, 0.18878041621064767, 0.18857393588405102, 0.15044318977743387, 0.11822132699307986, 0.12697048368863761, 0.14565936522558331, 0.12043263763189316, 0.17545218608574942, 0.12468435714254156, 0.1720106543507427, 0.08175623486749828, 0.13161383452825248, 0.16704037261661142, 0.12305229276535101, 0.10915433071204461, 0.20728983159642667, 0.09828718844801188, 0.10606838419334963, 0.15739859780296683, 0.18513927643653005, 0.07705952360993251, 0.12534347333712503, 0.11001896986272186, 0.09218249688274227, 0.1817198161734268, 0.13068294385448098, 0.10159323370316997, 0.06891647892189212, 0.21947067172732204, 0.12128046713769436, 0.14347273099701852, 0.13543414359446615, 0.0895199307706207, 0.10946091191726737, 0.1504561328329146, 0.13986028265208006, 0.21295967657351866, 0.15654024464311078, 0.11349987253197469, 0.20316856680437922, 0.13690378895262256, 0.16118787025334314, 0.1415035460377112, 0.2137251425301656, 0.10004664247389883, 0.10803961005876772, 0.2127053277217783, 0.19073907751590014, 0.17101025412557647, 0.10038575201178901, 0.12990509887458757, 0.17833586025517434, 0.1335230391123332, 0.12890748912468553, 0.12014252468361519, 0.16065972828073427, 0.10715735232224688, 0.10437982011353597, 0.16055223561124876, 0.10649685573298484, 0.15960109914885834, 0.18124409951269627, 0.14893689716700464, 0.13620376557810232, 0.20000060554593801, 0.15616057673469186, 0.08398074831347913, 0.1388557709287852, 0.08725930441869423, 0.1327105358359404, 0.13272436946863309, 0.16550083179026842, 0.21675785479601473, 0.16084550268715248, 0.21126842591911554, 0.10788521365611814, 0.15531766024651006, 0.15067758969962597, 0.11187899974174798, 0.16951711237197742, 0.21876490412978455, 0.21492908417712897, 0.12637612730031833, 0.1824417180614546, 0.08993407143861987], [0.031381135631818324, 0.01181620256829774, 0.031044677416502964, 0.04156904949923046, 0.009936492788256146, 0.08300739937112667, 0.06826499942690134, 0.03667834826046601, 0.027752219029935077, 0.03307346982182935, 0.027799048548331484, 0.06696111275232397, 0.0630801627994515, 0.000802217805357941, 0.07814993892679922, 0.148045607493259, 0.06029773983755149, 0.05871908782864921, 0.04503843032580335, 0.03876863316691015, 0.1208276605757419, 0.01761697538313456, 0.08801705946098082, 0.004321453097873018, 0.006294698996498482, 0.012369162886898266, 0.03657600609585643, 0.06835134830907919, 0.027947706294071395, 0.012481110297812847, 0.03374133964825887, 0.03922417825378943, 0.03559571807272732, 0.023845917312428355, 0.029778089228784665, 0.01592275428265566, 0.04431692177604418, 0.011239014838793082, 0.03319862560601905, 0.1265986677026376, 0.033507926782476716, 0.028685749894066248, 0.008952777898230124, 0.01572615194163518, 0.030773554171901196, 0.051467752127791755, 0.024436275380139705, 0.04807130215340294, 0.08523862925358117, 0.06162282596051227, 0.03702505367982667, 0.02042876512859948, 0.058414554951014, 0.026770053373184055, 0.06036077786120586, 0.07359666255069897, 0.02649713227583561, 0.052020206858287565, 0.07059083829517476, 0.038303881738102064, 0.03787388879572973, 0.04001211273134686, 0.019684595099533908, 0.042719682678580284, 0.047913228409015574, 0.019895789919246454, 0.007406890781567199, 0.028305362102400977, 0.06542138638906181, 0.0625323539134115, 0.057832443999359384, 0.01788914691132959, 0.056355551569140516, 0.026370052473794203, 0.026795555422722828, 0.08170235494617373, 0.06485756195615977, 0.05543998253415339, 0.03421475565119181, 0.06704474537400529, 0.01828709206165513, 0.020347902573121246, 0.018274143440066837, 0.03648749385320116, 0.02537840773584321, 0.03794050768192392, 0.02598954593850067, 0.04802220908459276, 0.02699791126360651, 0.09364256111439317, 0.056962743401527405, 0.03734015845111571, 0.08571617159759626, 0.033860001640277915, 0.004329796693127719, 0.06349186922307126, 0.01845283590228064, 0.06923489738255739, 0.030552049065590836, 0.054499199031852186, 0.03619345494371373, 0.07841320839361288, 0.0575995246617822, 0.03279142401879653, 0.04482111835386604, 0.043297374140820466, 0.04993210757675115, 0.04540540379821323, 0.07866185755119659, 0.07949311489937827, 0.006171017303131521, 0.02720857173699187, 0.08999332450912334, 0.04990695619198959, 0.0051103982877975795, 0.03029703970241826, 0.03937650777515955, 0.022853745649626944, 0.01659744815697195, 0.0033856976460810984, 0.01151977208792232, 0.005585901581071084, 0.06423087761504576, 0.035791518894257024, 0.03029511011845898, 0.016366358213417698, 0.054848004729137756, 0.038853364167152904, 0.0307451800108538, 0.05581850011367351, 0.019603931068559177, 0.04108336579520255, 0.015430096245836467, 0.11201534711290151, 0.038809458710602485, 0.049182816728716716, 0.06472087319707498, 0.10034580220235512, 0.024600731594546232, 0.04728931970021222, 0.044226001264178194, 0.013210395627538674, 0.06816374079789966, 0.035030182989430614, 0.08291757723782212, 0.019025966867047828, 0.02963114584417781, 0.04134086506383028, 0.020157165054115467, 0.004958122572134016, 0.012201392055430915, 0.06981606580666266, 0.012291449820622802, 0.08361943371710368, 0.08017146014026366, 0.03381364338565618, 0.0534852657438023, 0.03767257381696254, 0.03553269860276487, 0.057610653166193515, 0.01698849504464306, 0.023061803040036466, 0.04317150960559957, 0.007879078530095285, 0.05137113192176912, 0.01681394933257252, 0.04419684599270113, 0.02661647704371717, 0.019239874236518517, 0.028285635817155708, 0.005160428781891824, 0.06355829886160791, 0.06027113013260532, 0.013625287720060442, 0.012047630189044867, 0.05184616951737553, 0.021492238629434723, 0.0649842836719472, 0.017011143536365125, 0.02175023142626742, 0.04740673117339611, 0.07420081528834999, 0.07689104866585694, 0.08670190698467195, 0.06338923019939102, 0.037167438422329724, 0.03376487315108534, 0.020271774919820018, 0.0969611709297169, 0.032064148981589824, 0.016284016928693745, 0.0666995502251666, 0.020520772886811756, 0.040514479915145785, 0.015039061418065103, 0.09443729737540707, 0.04823351337108761, 0.030082813209446613, 0.06496097281342372, 0.021322145803424064, 0.01880880146927666, 0.04690038978878874, 0.015127779606700642, 0.07033936155494303, 0.03658238485513721, 0.043025892809964716, 0.0922584705404006, 0.07075296045513824, 0.05859961689566262, 0.04758857590786647, 0.025468235435255338, 0.07062577860779129, 0.035696375562110916, 0.059129721848876216, 0.012950784021086292, 0.07905274673248641, 0.030976201305747963, 0.05969133097096346, 0.014324591211334337, 0.04164661135291681, 0.03239590012526605, 0.04259054156136699, 0.03281840850831941, 0.05639852191961836, 0.0590100356930634, 0.09124376170802861, 0.02013807144976454, 0.04407836211612448, 0.014226791918190429, 0.05887816718313843, 0.011435450196586316, 0.06824021169450134, 0.03340923969517462, 0.032036607881309465, 0.025697401360957883, 0.029878134446335025, 0.029649367425008677, 0.04269408600521274, 0.0330623264744645, 0.051521446512197144, 0.04108022651053034, 0.044451695794123225, 0.04323848843341693, 0.05200577579671517, 0.016639238492643926, 0.06151708475954365, 0.0625757324451115, 0.06373389842337929, 0.0007819900486083498, 0.04774826011271216, 0.04551952013571281, 0.0254981662510545, 0.06656566678429954, 0.10194869275437668, 0.04328677256125957, 0.017958248281502165, 0.030994767985248473, 0.01788887046132004, 0.020370133606775198, 0.06292967009358108, 0.08663352549774572, 0.019043429601879325, 0.04491629879339598, 0.027433984250819776, 0.0502005572343478, 0.0995938507548999, 0.09818428967264481, 0.0038438421051978366, 0.0638152081228327, 0.07966372722876258, 0.022287559331743978, 0.08003319802810438, 0.015683996098232456, 0.03055783781746868, 0.047191968478728086, 0.038796330118202604, 0.03881129923684057, 0.0469887053623097, 0.0021124976183273247, 0.022091790051490534, 0.05832024282426573, 0.03466375499556307, 0.03447244787821546, 0.08256825574790128, 0.09410618818947114, 0.05751782162406016, 0.04764666751725599, 0.1118209415290039, 0.06467368002631702, 0.04107146545720752, 0.019170652267348487, 0.016702723660273477, 0.06423706712666899, 0.03621261348598637, 0.010046274055639515, 0.061051483571645804, 0.04867310228291899, 0.07309442895348184, 0.031948533505783416, 0.03470748233667109, 0.053239481276250444, 0.08369775998289697, 0.027471258617879357, 0.029249665240058675, 0.05259448073047679, 0.06606034585274756, 0.01668763765337644, 0.020858694988419302, 0.04698597425885964, 0.06421122554456815, 0.12988892005523667, 0.08925962247303687, 0.011729001143976348, 0.01868211129476549, 0.006220607610885054, 0.015610421432938892, 0.04154395006480627, 0.02229738536698278, 0.007655709705431946, 0.036394294947967865, 0.06213387256138958, 0.03925058015738614, 0.01411622954037739, 0.05557314980251249, 0.029555090550275054, 0.03422785455768462, 0.0376592151587829, 0.02592785491287941, 0.016956521467363928, 0.09096875888644718, 0.06587851967196912, 0.13123912416631356, 0.04283037400455214, 0.02075375901767984, 0.03080447575484868, 0.05950636179477442, 0.028691338266071398, 0.015775178217154462, 0.05645937802910339, 0.0270513625946478, 0.031611134618287906, 0.004988792288713739, 0.04860318083956372, 0.03506547582219355, 0.0728565186727792, 0.044190667613293044, 0.03573216934455559, 0.036456494344747625, 0.03762523963814601, 0.01740677689667791, 0.004448493009476806, 0.041071454324992374, 0.06799797469284385, 0.17073683207854629, 0.11528834453201853, 0.14259065879741684, 0.2359550035907887, 0.10179853401496075, 0.19718270050361753, 0.2456955731031485, 0.10167357118916698, 0.0995259293995332, 0.11752663223887794, 0.24719224747968838, 0.22932927240617573, 0.09592152593540959, 0.11718426467268728, 0.14861980715068057, 0.2255685132695362, 0.17404522252036259, 0.12292688465095125, 0.19702928373590112, 0.24356525304028764, 0.1610276850988157, 0.19156029360601678, 0.1540705404477194, 0.16235408111242577, 0.11347498832037672, 0.06649317379924469, 0.11388713261112571, 0.14560912182787433, 0.15624145598849282, 0.27290370140690356, 0.15570906893117353, 0.10990289796609432, 0.11288468405837193, 0.11706476405379362, 0.2867175335995853, 0.09561936793033965, 0.23226077057188377, 0.06114145784522407, 0.1523054312565364, 0.0819675020466093, 0.10103994776727632, 0.08847391814924777, 0.07950573140988126, 0.1113266711763572, 0.1045371925283689, 0.1028563838917762, 0.15033108094939962, 0.2583546086680144, 0.19771863502683118, 0.1472697959979996, 0.12251025778823532, 0.11214490383281372, 0.2274517872137949, 0.12179506491520442, 0.22230993577977642, 0.226946844777558, 0.15198942477582023, 0.1684609620133415, 0.13227433111751452, 0.14895879052346572, 0.12190030145575292, 0.18014635919826105, 0.20771257375599816, 0.10785215097712353, 0.12447627377696335, 0.14593441999750212, 0.1771364753949456, 0.17767367156920955, 0.17032732983352616, 0.1681283165817149, 0.15971230255672708, 0.12316618274780922, 0.1491665473440662, 0.1153364876518026, 0.15388509258627892, 0.14289915474364534, 0.27305548544973135, 0.12173841678304598, 0.10649678893969394, 0.12334477316471748, 0.1035656915337313, 0.16411096730735153, 0.14373760350281373, 0.13240129774203524, 0.1926448236918077, 0.14731790201039985, 0.2384820906445384, 0.1574617248843424, 0.15943763370160013, 0.3067244397243485, 0.11967199563514441, 0.1878327678423375, 0.20636596163967624, 0.11951759923249483, 0.16109026299091056, 0.14424435677938163, 0.15737464127596468, 0.10941769665805623, 0.1043998209934216, 0.0771121789875906, 0.16436804726254195, 0.12375382269965485, 0.1070894012809731, 0.14670389355160296, 0.14349244243931025, 0.13387337734457105, 0.11369557687430643, 0.1793230650946498, 0.09479201427893713, 0.14204007427906618, 0.19281182176200673, 0.18103922222508118, 0.21702281635953113, 0.14533862384269014, 0.0886364039615728, 0.2635074587306008, 0.10944162349915132, 0.18234789575217292, 0.07455691258655861, 0.1592761868960224, 0.13472957827616483, 0.1804544692276977, 0.13569843722507358, 0.15431767562404275, 0.16195431584492326, 0.18745492561720312, 0.10401371866464615, 0.21542247879551724, 0.20774743985384703, 0.06533519335789606, 0.15931114205159247, 0.2246537123573944, 0.23315835365792736, 0.19598304847022519, 0.1691374889924191, 0.11060858392738737, 0.2742630784632638, 0.0887875423359219, 0.16003381577320397, 0.1569624524563551, 0.11373346351319924, 0.16669223114149645, 0.10918587940977886, 0.13761075882939622, 0.059067110560135916, 0.08903721565729938, 0.08930789917940274, 0.14717836340423673, 0.11732977014617063, 0.197638334648218, 0.16988480201689526, 0.1287527513341047, 0.26775993523187935, 0.10670157716958784, 0.18117586645530537, 0.17753848194843158, 0.15748072386486456, 0.10890870951698162, 0.11605211097048596, 0.13165005133487284, 0.14551605650922284, 0.07485757145332173, 0.10447581691551022, 0.13889652967918664, 0.10138716155779548, 0.23023687448585406, 0.1684133309754543, 0.15752998762764037, 0.12412147523718886, 0.12522446253569797, 0.14505527185974643, 0.13135500310454518, 0.11222066968912259, 0.09636208706069738, 0.17371833615470678], [0.02322828531760024, 0.004963570863765199, 0.02268552860186901, 0.01805804673495004, 0.011493242163851392, 0.05217491867369972, 0.036191221079207025, 0.026361237614764832, 0.033741985316737555, 0.05466898757731542, 0.014852001240797108, 0.010447915101394756, 0.03722178589669056, 0.04116300195164513, 0.019564753092708997, 0.04679346486227587, 0.019516517204465345, 0.0471896418457618, 0.05458204497699626, 0.012481082467274973, 0.01540584100439446, 0.041138885862892494, 0.038161033153301105, 0.0683592447603587, 0.03281182194768917, 0.04416528987349011, 0.04746614009491168, 0.007484327397833113, 0.0387686442991253, 0.03383172952453606, 0.04543216935417149, 0.027586061441979837, 0.03232550370739773, 0.03810506408626679, 0.01814449395169504, 0.012819127023249166, 0.04096383920114022, 0.024543586223444436, 0.055876599144539796, 0.022761598738725297, 0.06000149303872604, 0.04358799174951855, 0.030715186112502124, 0.051151456209481694, 0.04034233876154758, 0.0633873970946297, 0.07399701411486603, 0.04191117957816459, 0.03956409673264716, 0.038060987935750745, 0.025717255666677374, 0.021147648330952507, 0.004492160051086103, 0.04183784425549675, 0.004252787275618175, 0.024533661853638478, 0.038492498570121825, 0.06602999201277271, 0.04074042306456249, 0.01842415746068582, 0.04375759846880101, 0.020644618780352175, 0.0496580584149342, 0.025864902236207854, 0.008645697598694824, 0.05077067879028618, 0.02628349764563609, 0.15397000912344083, 0.08957643047324382, 0.08063077533734031, 0.0036480746803135844, 0.016663178321323358, 0.034727282836684026, 0.00044647841946243716, 0.03567397754522972, 0.011318270644551376, 0.019422244040470105, 0.055388258551829495, 0.01569620999362087, 0.06324195099296048, 0.022766496913391165, 0.026626893086358905, 0.06787152015022002, 0.014635086317866808, 0.07036518087261356, 0.16486852196976542, 0.032890311485971324, 0.025150353176286444, 0.009688376121630426, 0.03552680223947391, 0.016896331435418688, 0.08520486153429374, 0.028612208625418134, 0.03013186731550377, 0.059227496094536036, 0.061919911386212334, 0.06446687315474264, 0.06854032137198374, 0.015946412095217966, 0.044934952675248496, 0.03028413004358299, 0.031087874122022185, 0.05139425724337343, 0.03618713926698547, 0.03290936983830761, 0.028005105850752443, 0.05982194154057652, 0.013223472269601189, 0.01825130941142561, 0.06050773794413544, 0.028340866447251756, 0.02913523348979652, 0.0750494611565955, 0.03170857118675485, 0.02573530284280423, 0.02086291409796104, 0.007911207958386512, 0.031825192272663116, 0.066912680194946, 0.02145134814782068, 0.037362241055234335, 0.045166510171839036, 0.020060491042386275, 0.03486571564280894, 0.025194470144924708, 0.07909467065474018, 0.04550930818368215, 0.0498086884181248, 0.04486695339437574, 0.03326588644995354, 0.07924134130007587, 0.01871857857622672, 0.03498746867990121, 0.03946565084333997, 0.0013677869810635457, 0.03721791188581847, 0.0222613726509735, 0.02430454045679653, 0.061196091046440415, 0.05477043545397464, 0.028234017590875737, 0.03398871973331552, 0.017904208798427135, 0.061151818226790056, 0.06168591964524239, 0.02461062071233755, 0.09526796100544743, 0.05669750724337064, 0.04860678767727222, 0.07464430789696053, 0.039489855989813805, 0.033060589848901145, 0.023611270626133773, 0.04178927811153699, 0.01640308339119656, 0.020075534375791904, 0.025940551204257645, 0.04513861655141227, 0.02318317572644446, 0.04699750352301635, 0.05650454884744249, 0.020036107780470047, 0.04298112646210939, 0.062073101798887365, 0.020458436192711815, 0.006511738229164621, 0.014144002561806701, 0.03326370082504582, 0.02044048178504454, 0.04812775361642707, 0.072990283370018, 0.02632181658555055, 0.032882704472285695, 0.047479068307438865, 0.023802204814273864, 0.044965581109863706, 0.020117421190661844, 0.03258120697864797, 0.038336038996931165, 0.03736175494850613, 0.011760594370571198, 0.061028339696349576, 0.03501742918160744, 0.03174487705109641, 0.019854205529554747, 0.05361752017051913, 0.038303447581711225, 0.034448691731086, 0.01927575151057681, 0.02197140442149248, 0.02228223813290242, 0.04519595859164838, 0.02175701651140116, 0.04242464929120615, 0.07155225350288674, 0.07369285973254591, 0.0045953417702548904, 0.05093802938063163, 0.06512710999231786, 0.03253829971072264, 0.029314293315110262, 0.056697321706451476, 0.096610580367269, 0.04731186985736713, 0.027163764571014326, 0.05832436174387112, 0.004990539582649944, 0.02790784368698951, 0.00854265224916162, 0.0434392319584731, 0.04129130073124543, 0.04520831906120293, 0.018619678121467587, 0.03632887834100984, 0.008037700536078773, 0.02739843723247759, 0.026262871506332885, 0.024540016493119765, 0.023930531424412038, 0.05956636443443131, 0.02752855983999325, 0.009427199511264917, 0.07165038026869297, 0.02004066642257385, 0.03665838448796421, 0.0289316679481999, 0.05698740867956076, 0.032386630700784735, 0.010982214116666, 0.033137865975731984, 0.040529352554585785, 0.05761458654887974, 0.05504751257831231, 0.07525263892603107, 0.054238538214121945, 0.047368417799589224, 0.011759087810787605, 0.014948185435059713, 0.015010182596597588, 0.012416112076607533, 0.0384923056117259, 0.07609312859131023, 0.04551729740342125, 0.028419580485206097, 0.03765717054193374, 0.06339077386655845, 0.04658047590055503, 0.027221830205235165, 0.02022602522629313, 0.05572082976868842, 0.01957042310095858, 0.01659859663050156, 0.04140699784329627, 0.04852419035159983, 0.059972972303512506, 0.02308269264176488, 0.027685325549100526, 0.05334808345651254, 0.06388152643921785, 0.02456833313772222, 0.06367700538248755, 0.04783565171237569, 0.033543958052177913, 0.07429782883264124, 0.052256662529543974, 0.01293307452215231, 0.022296932656900026, 0.07985903081134893, 0.012170930604042951, 0.06885194918140769, 0.04889079646090977, 0.06722424121107906, 0.05095913977129385, 0.014191540831234306, 0.018836760027625132, 0.10254833323415369, 0.02337592075491557, 0.08428827204625122, 0.009325746996182716, 0.05421121975814458, 0.02185672776249703, 0.042754511669045314, 0.09442718190257438, 0.03053905034903437, 0.043428333519841544, 0.03357500580023043, 0.04487645288463682, 0.06190867155964952, 0.08020829292945564, 0.04182694210612681, 0.011467331933090463, 0.026453635000507347, 0.009062553599505918, 0.05930094273935538, 0.028381090851326007, 0.042214005516143516, 0.027385095272620674, 0.08494636407704093, 0.05669492456945591, 0.06663498337729834, 0.053377502190414816, 0.009572154867782956, 0.05690537167538423, 0.044121310202172026, 0.014339876670419471, 0.020369129852042533, 0.057148695923388004, 0.020645774675358552, 0.04889328636636492, 0.06368545844452456, 0.054267548766802065, 0.05414356186520308, 0.0515250199532602, 0.02758086640824331, 0.026308782616979443, 0.018702872876019683, 0.018414761871099472, 0.07312312780413777, 0.015165998356678756, 0.06514269509352744, 0.027675562596414238, 0.008738293508940842, 0.014426865654968424, 0.026037292009277735, 0.04171534535998944, 0.023568062788399402, 0.03738682840776164, 0.016588035869062878, 0.032704841360100545, 0.05782125241239555, 0.04257959117239807, 0.04889527532213833, 0.03847862040856853, 0.03297942486824468, 0.03867669962346554, 0.05157067316758912, 0.04359875289082993, 0.01545771156088449, 0.07248188994708471, 0.02056477667792933, 0.043719682144001126, 0.04249990306561813, 0.006605817043237039, 0.06534843327244744, 0.04930137482006103, 0.07720604582573287, 0.04524448391748592, 0.020217158416926395, 0.057457451621303335, 0.05501637206180021, 0.016773767601989675, 0.036322432788438164, 0.17486240132711828, 0.09585990541381761, 0.20824540610192344, 0.07451548590324819, 0.18927602242911234, 0.21651074930559844, 0.09771082171937451, 0.11579444471863098, 0.08830153208691627, 0.18424904061248526, 0.1074206292105373, 0.11052336310967803, 0.09500622778432444, 0.10344386057113297, 0.09341602795757353, 0.11486099363537505, 0.12724194646580145, 0.09021169404149987, 0.17545056820381433, 0.11817830469226465, 0.05857656207808759, 0.09562718274537474, 0.31553388107568026, 0.1908585781347938, 0.09892433707136661, 0.2094259997829795, 0.1680215957458131, 0.1264403824461624, 0.221431129029952, 0.1325205311877653, 0.14265218283981085, 0.22054126427974552, 0.12233652101713233, 0.0802962522720918, 0.18434272933518514, 0.13917339529143646, 0.09559351892676204, 0.1538840535795316, 0.16738357138819993, 0.04726748200482689, 0.1429728203220293, 0.11457358210464008, 0.13093116256641224, 0.14638422086136416, 0.124251224915497, 0.21531847422011197, 0.1823321176925674, 0.1918316079536453, 0.09742651978740469, 0.1406407548347488, 0.13876678742235526, 0.18976681953063235, 0.11916952455067076, 0.08358969585970044, 0.08013854589080438, 0.15327906963648275, 0.165134685812518, 0.12267399783013389, 0.2097341840271838, 0.14971802243962884, 0.09525934467092156, 0.13253789744339883, 0.09928934014169499, 0.1622094216872938, 0.09497922103037126, 0.16244214435573667, 0.13054159440798685, 0.19243470684159547, 0.13964117097202688, 0.2657016331795603, 0.1418632798595354, 0.08048485426115803, 0.10604735172819346, 0.15375247079646215, 0.16840662196045741, 0.09062927827471867, 0.1665284688351676, 0.12179084951640107, 0.09163342634565197, 0.14617987792007625, 0.07414470150251873, 0.10899372995481826, 0.16878112452104688, 0.14254424488171935, 0.1460701588075608, 0.27850498678162694, 0.1671840820927173, 0.24561613361584023, 0.10975880999467336, 0.09670821731560864, 0.08381988038308918, 0.26649436564184725, 0.11131378007121384, 0.15972618071828038, 0.13977391150547192, 0.2553852758137509, 0.1242958873626776, 0.2214830496814102, 0.09466089162742719, 0.22795941622462124, 0.18135298741981387, 0.1272218194208108, 0.20963201997801661, 0.14126015128567815, 0.15551038115518168, 0.12871411512605846, 0.18727893271716312, 0.09867299391771667, 0.12956044549355283, 0.12238001087098382, 0.1374312481493689, 0.15894901851424947, 0.22486011846922338, 0.14886654156725854, 0.09891517896903679, 0.10941673928755336, 0.09702932977234013, 0.12601712078321725, 0.09802050510188565, 0.17209609039127827, 0.10876823580474593, 0.13808506540954113, 0.1750526434625499, 0.20110305107664317, 0.2770968060940504, 0.22948994737816975, 0.20375806954689324, 0.13827661372488365, 0.16065794712631032, 0.11645389487966895, 0.18763503001537174, 0.13654200680321082, 0.15623317362042144, 0.10643958419677801, 0.1520266805891879, 0.1176616660086438, 0.11874493444338441, 0.10085157584398985, 0.1040277155698277, 0.09781861866940744, 0.16955102852080017, 0.20849225926212966, 0.07969648562720977, 0.19245429954025894, 0.1672758857603185, 0.09902802252327092, 0.11570032555027865, 0.08498573501128703, 0.09764840709976852, 0.25459171214606613, 0.13858303165761754, 0.09176961044431664, 0.10853611427592114, 0.1212531264172867, 0.2087367227068171, 0.10680340725230053, 0.16562135657295585, 0.08387823545490392, 0.16311139828758314, 0.07927930957521312, 0.19257449777796865, 0.12140887352870777, 0.1629056452657096, 0.12698161590378731, 0.17418406350770965, 0.13020967628108338, 0.08396456207265146, 0.11186650939635001, 0.11523640903760679, 0.12061876084771939, 0.09615131712052971, 0.107188619003864, 0.12748697394272313, 0.2297866580192931, 0.11901952166226692, 0.1359246438369155], [0.023154712507675868, 0.030424314318224788, 0.032449401551275514, 0.039199943421408534, 0.019769578429986723, 0.006604044237974449, 0.021499274189409334, 0.026288291919627227, 0.0739213744236622, 0.027055123427999206, 0.04019825821160339, 0.02459119128616294, 0.03255195893871132, 0.028534149532788433, 0.05676892040355597, 0.013406923753791489, 0.008848022825986845, 0.06315983235253952, 0.02468758699251339, 0.0514231898705475, 0.00776440743720741, 0.05534298012207728, 0.05817163888423238, 0.016503156439284794, 0.05021556717110798, 0.07825825538020581, 0.08189460088033229, 0.04195063214865513, 0.020753313729073852, 0.070460695278598, 0.1070438111491967, 0.028771811194019392, 0.02596376001747558, 0.004658675725295325, 0.016745712564443238, 0.061412189606926404, 0.041937566638807766, 0.033619471578276716, 0.08854289335431531, 0.07911847133073024, 0.03639370494056493, 0.03865041275275871, 0.05042881217377726, 0.0872593341046013, 0.02851097782695433, 0.0753604136116337, 0.00538091668204288, 0.05348757382307667, 0.0161298338935012, 0.012226219678268535, 0.060505274013848975, 0.026879729812208097, 0.0769704658887349, 0.025641755128162913, 0.018605553195811808, 0.02144370402675122, 0.03878587325743865, 0.026204288224107586, 0.03355241111421492, 0.026333642708777916, 0.038746940190321766, 0.023132041751523502, 0.06339141953503713, 0.040774428271106444, 0.06905193571583368, 0.017900626080518123, 0.023961158003658056, 0.025912011915352196, 0.06796500849304721, 0.04181219563179184, 0.026992901766789146, 0.0970628228969872, 0.014740430469828425, 0.025507867976557463, 0.018014503075391985, 0.050966824710485525, 0.0473432812577812, 0.059480776253622025, 0.04428070496942382, 0.05607190643786453, 0.01879046485555591, 0.028049701504642144, 0.013654284357471624, 0.01601449115696596, 0.060974745501880534, 0.015871019168116618, 0.023418766795657575, 0.07235989571199752, 0.04219331072818022, 0.06510348001029342, 0.054224674895522185, 0.05772987919044681, 0.012561082276079105, 0.038084591942606494, 0.015953605361573864, 0.053639068428310566, 0.050415806035744026, 0.04646051886084024, 0.026768307470774744, 0.03576774419343565, 0.06279045803239569, 0.09309435889008455, 0.07964181902934797, 0.03208156718756072, 0.01996295428398298, 0.07513426637160592, 0.01631830229598563, 0.005755661832154146, 0.07105565280653536, 0.008411576909566065, 0.009316394080087775, 0.048495921946596354, 0.06885957845952362, 0.003977239903178997, 0.018180773840867914, 0.04158899471804034, 0.01208448802572093, 0.00906921251953463, 0.044477195988292806, 0.02325850186025491, 0.03794453754380811, 0.02693529997486621, 0.029884628238505684, 0.034391672525089234, 0.02643365824042121, 0.01969323740922846, 0.055597681493964046, 0.0306584452118841, 0.030635909897682723, 0.008356202488357667, 0.03780668732360937, 0.05782296306279022, 0.049214580649277195, 0.0437913736095652, 0.02910603925556643, 0.07784507208270952, 0.021424215228762478, 0.06659795762971044, 0.03409939250559546, 0.02648241919814609, 0.020524205319816247, 0.0938075924932491, 0.023916862919577397, 0.007897956911619985, 0.0228709078146494, 0.04097475248272531, 0.10295335290720686, 0.05692163955245633, 0.01869967978564091, 0.030568997863156255, 0.10064361864351667, 0.08222237782320008, 0.02646990102221025, 0.0488250792841427, 0.10419973055832088, 0.009748010470502777, 0.026465945375093725, 0.05068109414423816, 0.044887889380333945, 0.05024936828704085, 0.013024801191932056, 0.04026090289698914, 0.0036649040384872933, 0.02152558517991565, 0.032808259638841264, 0.005829361271025846, 0.10797775947139598, 0.04597733248374425, 0.05935367975325789, 0.10798746676300652, 0.04016079459688626, 0.08023274669540115, 0.033018899703165516, 0.03915921064617578, 0.06979073630645871, 0.05943318232311867, 0.017585653040441684, 0.0060947509609832196, 0.04827682510949671, 0.06400073019904085, 0.0487304443231551, 0.08106196313747205, 0.04313947109039873, 0.03729139563802164, 0.05427967174910009, 0.0395271934394259, 0.03603379300329834, 0.040187983177020214, 0.057363328742212616, 0.0764784071361646, 0.010585575146251358, 0.042065817178809084, 0.02011236716498388, 0.043719129243982024, 0.06088199559599161, 0.02293394398293458, 0.03292492525361013, 0.06004290116834454, 0.018765003624139354, 0.08084958273684606, 0.05962823357549496, 0.1069089183874894, 0.061615322847501375, 0.012174627427157247, 0.008295023544633295, 0.002384923564022756, 0.062013759670662694, 0.03510532544169109, 0.044454783128458075, 0.012897472770418972, 0.013486082152667223, 0.042937402831739746, 0.09915757182170637, 0.050238859475939535, 0.037045566641609184, 0.06550434365635738, 0.020940188369422685, 0.052883628886775114, 0.023167458894022275, 0.05942474781477358, 0.03760381012398284, 0.010795505531859817, 0.0241584987816168, 0.0636005493288394, 0.029199494201748166, 0.0767366893705912, 0.060541639250004664, 0.05256388940324541, 0.11436130560468882, 0.023143122016335838, 0.003940137621611939, 0.014968360719649354, 0.06403074265108444, 0.046400772262131795, 0.037031027968623675, 0.0170371539570624, 0.02016482216276927, 0.054919436443015, 0.022058187460061163, 0.05699461864423938, 0.022721604400430806, 0.009656225356593495, 0.02964849725685781, 0.017954186878341716, 0.03456805134192109, 0.03229801084671635, 0.045260150654939935, 0.05277171301713679, 0.07289082073839381, 0.028477473570092116, 0.08267585973953828, 0.024147932454070542, 0.02198405061790254, 0.07117241490050219, 0.012298677411308745, 0.019302129294374026, 0.01964227412827313, 0.02849016986147035, 0.01632752719160635, 0.02054497061180882, 0.0424544724955922, 0.028445665120671038, 0.03486721478111576, 0.052388623807928525, 0.019931092028855346, 0.0438006690092152, 0.032848253977135755, 0.06562469032360241, 0.07084830416715704, 0.025173498906951863, 0.01789121193723986, 0.036474509979598224, 0.06855250743683428, 0.04115813717362471, 0.02608889168186579, 0.026132732200494502, 0.1360306076821871, 0.08208051629480906, 0.021833576465724036, 0.027058160667365883, 0.027754618022299837, 0.021471042891789693, 0.06379257261869498, 0.06432418042095378, 0.06208063830854371, 0.059289855053066276, 0.05851881556736771, 0.05099530091683846, 0.07212205222458579, 0.014786016890866449, 0.05409552264609374, 0.03334445762448013, 0.0668816732650157, 0.027929974530707113, 0.011649253665382275, 0.043810131392092444, 0.027826109107991215, 0.019775064756686334, 0.02594767025584588, 0.04620484156475868, 0.02051765586656984, 0.0068833496607112465, 0.08493071960401721, 0.028041953482897952, 0.014477713903033873, 0.03237792530853767, 0.01828899567044573, 0.07607645253301598, 0.024573468799644616, 0.05805248336400837, 0.02236042153526796, 0.03613086591940373, 0.015982649310899433, 0.02454302775731776, 0.03264287945057731, 0.014100151838647434, 0.029690311712329276, 0.07468836920452304, 0.04511309780355077, 0.0485976073105121, 0.027676211975631304, 0.033687968098092824, 0.012719757160084555, 0.03075513035582844, 0.050134695338783786, 0.05006832136132289, 0.06246740114875138, 0.04732266068458557, 0.04041893582325429, 0.061730240704491735, 0.13907716842368245, 0.004708653341367608, 0.044170974724693224, 0.05829936621012166, 0.026390687889943365, 0.10207960760453716, 0.03490586212137714, 0.018291446613147855, 0.03768397691601422, 0.011873767252836842, 0.0008354761678219802, 0.023341251326201018, 0.06882866800879128, 0.01427003964636242, 0.04992829664843157, 0.1399508395115845, 0.020751742231368553, 0.05008874155464582, 0.032812256104080006, 0.07705986499786377, 0.04379693971714005, 0.03610274965467397, 0.11875274183694273, 0.09722357208374888, 0.14382122870301828, 0.1418317385832779, 0.11456204912974499, 0.11969338433118537, 0.11958653733017854, 0.11037482967367396, 0.16492961556650698, 0.08782079108641483, 0.19053905387409031, 0.09361009215353988, 0.13064589584246278, 0.17799062799895182, 0.08991116876131855, 0.15488624980207533, 0.054642863979097456, 0.12479760887799785, 0.09587381326127797, 0.08035219536395743, 0.10220308613497764, 0.19562018278520554, 0.19624306733021513, 0.1281966600799933, 0.14067958400119096, 0.19501653470797464, 0.133644855231978, 0.14611784921726212, 0.06624925954383798, 0.19579593819798902, 0.20809762965654954, 0.2599756669951603, 0.13348796521313488, 0.10920507134869695, 0.15512856101850048, 0.1420875420444645, 0.18846383085474372, 0.21937949146376923, 0.1409736229106784, 0.15187373879598454, 0.12422619227436371, 0.09557819357723929, 0.12025365387671627, 0.24358980328543112, 0.10257736605126411, 0.11041717662010342, 0.13904954568715766, 0.18595299683511257, 0.07707212527748197, 0.1383687142515555, 0.1207322945992928, 0.11341049568727612, 0.19139148469548672, 0.0923798191070091, 0.08527255282388069, 0.08830246719298884, 0.12820948439184576, 0.10144136802409776, 0.10253818807541393, 0.1673163624946028, 0.08752209148951806, 0.1401447330135852, 0.08799319941317663, 0.15435751411132514, 0.09135819345829077, 0.18460110062733293, 0.13584321539383382, 0.09335557260783389, 0.16685483569744974, 0.1617883864673786, 0.15306552406400442, 0.21479056973475963, 0.15692733402829617, 0.11989409817033447, 0.1725501214968972, 0.19764660217333585, 0.14200523786712438, 0.1470973208779469, 0.11850548049551435, 0.12431045572157018, 0.12018747656838968, 0.09027331456309184, 0.10421596132800914, 0.09241809908417054, 0.16996716556604952, 0.11478086395072751, 0.09508444272796623, 0.12262720541912131, 0.06924008499481715, 0.11001563761965372, 0.14497639640467241, 0.19720526179298759, 0.15788544667884707, 0.10932850535027683, 0.0528617429517908, 0.1673983401269652, 0.13841055653756484, 0.14588088146410882, 0.14853352506179363, 0.1206529738556128, 0.2059773137443699, 0.25739367585629225, 0.0906019598187413, 0.1192867467761971, 0.13368746935157105, 0.15919796453090385, 0.1280386419966817, 0.10124581211130135, 0.1590758070233278, 0.1340689035714604, 0.1395204829168506, 0.11505162910907529, 0.21783879288705066, 0.08014240505872294, 0.14510910725221038, 0.12134121192502789, 0.1227318482415285, 0.13475680025294423, 0.12511128501500934, 0.11568263274966739, 0.1703596577863209, 0.09095119967241772, 0.11933117915759794, 0.12560188915813342, 0.09536919737001881, 0.2071473392425105, 0.1809994431096129, 0.1752783899428323, 0.07939403076306917, 0.17708874045638368, 0.10914045255049132, 0.2311559798545204, 0.2155395006411709, 0.1189895388961304, 0.19767440302530304, 0.12217851777677424, 0.11706647099344991, 0.1572029379894957, 0.10774383452371694, 0.1715251710265875, 0.10328924894565716, 0.11868928078911267, 0.1331985869910568, 0.12454714888008311, 0.0919953420816455, 0.11911594148841687, 0.12987633323064074, 0.14658154308563098, 0.11497230094391853, 0.13828345632646233, 0.16879688773769885, 0.1967510674148798, 0.11973995409789495, 0.1231629098765552, 0.18009794148383662, 0.10836297864443623, 0.13847610302036628, 0.13206063711550087, 0.09945290948962793, 0.2090139445499517, 0.057291763441753574, 0.15269486582838, 0.12085805894457735, 0.18373206054093316, 0.20110763754928485, 0.0935174424375873, 0.149776236503385, 0.13970728148706257, 0.20851360342931002, 0.15175121021457016, 0.051546568211051635, 0.18823517515556887, 0.09947777885827236, 0.27723523147869855, 0.1666208216920495, 0.19018619233975187], [0.015163539992499864, 0.007315077837120043, 0.02343804037082009, 0.055536584186484106, 0.03925905919459183, 0.031373677047668025, 0.02134207617928041, 0.07619036477990448, 0.045369261206360534, 0.030869855254422873, 0.02572940462414408, 0.04679579891671892, 0.01347930819974863, 0.0438457507698331, 0.0719242772902362, 0.031121374668146018, 0.07438957312842831, 0.02852517325663939, 0.05261341662844643, 0.02209340422268724, 0.11536701218574308, 0.04664134314225521, 0.03222187762730755, 0.0457176253257785, 0.02911636809585616, 0.04169211984844878, 0.035203159059165046, 0.019866859147441573, 0.033642834387137555, 0.022707336611347273, 0.022156388440635055, 0.05941136689216364, 0.032112407134263776, 0.021343523367249873, 0.030894824813003652, 0.03067088546231389, 0.029956952384964097, 0.010119113067048602, 0.023673824398429133, 0.01229698995302897, 0.04926527675706893, 0.04682257931563072, 0.03375314721779432, 0.04358281155873556, 0.03379875961400103, 0.08569163619540632, 0.008949083858169615, 0.06339633255265653, 0.037053348059998825, 0.004395128880787524, 0.054401803281507455, 0.04867538809776306, 0.013707910093216924, 0.06463815341703594, 0.03924669130356051, 0.038785658034612425, 0.03861539822537452, 0.032461543087265454, 0.019772797495534178, 0.03920152048522141, 0.054695560174877755, 0.025662026891950518, 0.015325162130466197, 0.02970906763948733, 0.02573647172539495, 0.02185738085245248, 0.006553373177666799, 0.031333845981862396, 0.05673824744008016, 0.12547075166366994, 0.06603218876989558, 0.032056152340373956, 0.024771518328634556, 0.03303632533061318, 0.023366630921373144, 0.04888497060164809, 0.033298815542366356, 0.012596177512023132, 0.08698424964677542, 0.013682665939995786, 0.006174173286126461, 0.027251644132775255, 0.02035939472989412, 0.007355147317866795, 0.03750472598767374, 0.01900214763736585, 0.048809267827891745, 0.01260041424757219, 0.03627236008469481, 0.08242572628660128, 0.02694689046620624, 0.055647153058089316, 0.03832564892945811, 0.03756766011065338, 0.03483904656604864, 0.03549797351297457, 0.046999473925097845, 0.050514129470684566, 0.020018604227516335, 0.05753497636760585, 0.04529652331257239, 0.018174300457758363, 0.02437270486552734, 0.012511899221863132, 0.02364183783356566, 0.034617630517459475, 0.03804209285590332, 0.06071030344173778, 0.05584582228038926, 0.021904518362134695, 0.03031744319741847, 0.014545880167133873, 0.04654242227843497, 0.03861614779452793, 0.07752974837785587, 0.016841000615386292, 0.03525817075569648, 0.10796294620377012, 0.12691096344497055, 0.07623604396940209, 0.05903896832023747, 0.043057460061390884, 0.06286111049121246, 0.042220673713018186, 0.03320717143651564, 0.06366281551891007, 0.07122956769308075, 0.10882524758926593, 0.022336889887810685, 0.06720560588291846, 0.028723454706778284, 0.05090541941171978, 0.0529653653211426, 0.07104399366653524, 0.018238269876746926, 0.016083533155324403, 0.028858866971859243, 0.04722988109278958, 0.038231930520851165, 0.0316646731516812, 0.07476010519894771, 0.05066885241831187, 0.061664427048526704, 0.009813920605665771, 0.06066786743758712, 0.039713012374704704, 0.03200355262379162, 0.05421398796897847, 0.06577168009243906, 0.033587269790587015, 0.026009277789853513, 0.03995137165475171, 0.03079912672546925, 0.02812119259033352, 0.024642852185934316, 0.027305141848046333, 0.017954496724996716, 0.028883430204587057, 0.035754648997681215, 0.008355199661309598, 0.028696548142761458, 0.04392887502035592, 0.02617962109070504, 0.00951016698309104, 0.0069843258097535, 0.04413121787365526, 0.019441671611275524, 0.12357797822915018, 0.034005559064098634, 0.05718758446164429, 0.03590199128666427, 0.0027228343014940037, 0.024326094280695543, 0.02886461305024568, 0.048919732798822224, 0.03614244342315942, 0.023522556148236617, 0.024360772986256052, 0.07505218483856879, 0.03131122160993982, 0.036740232244483195, 0.10901712244958617, 0.04282517154933885, 0.04117190030228812, 0.04193932552880142, 0.007491703881896683, 0.0754966793465428, 0.011033178325305926, 0.08194692971301265, 0.007121566541172797, 0.10078683088067919, 0.056066303222905844, 0.05202605498197954, 0.016604394659225363, 0.04867811549047474, 0.03485928122245241, 0.036889348266413435, 0.01777787671016995, 0.042385545530123636, 0.07879566677729599, 0.06454340342315845, 0.05576355892117135, 0.06152065448986832, 0.04613775141478982, 0.02723186589719262, 0.02801464059302816, 0.06284446411882527, 0.03728487958142068, 0.02990939927258296, 0.023216600202431437, 0.054629056321573444, 0.04909862749627791, 0.03942486611776985, 0.065444007050246, 0.01701997323834803, 0.017830810393206775, 0.0246551829695818, 0.04249572848493699, 0.0556812176364474, 0.03515197313390672, 0.04373078467324376, 0.030071922192291822, 0.09796194965019822, 0.039481076382799074, 0.050939031279995106, 0.012895349300379166, 0.06663309832219966, 0.0631213074666448, 0.03921881623682566, 0.06257808505324647, 0.030247226750361733, 0.04932499366987031, 0.0411292342323577, 0.0502507301280275, 0.009025706895045005, 0.009699187357909977, 0.05239004873146769, 0.027939269930357113, 0.0033395010405001813, 0.005906188398512313, 0.027138470322825015, 0.008347196526301559, 0.03035277684830362, 0.029448000495904125, 0.0941880396567285, 0.06447992011089809, 0.06959767400985584, 0.030655754926556256, 0.019456369846011512, 0.028178187676530797, 0.035352100676391274, 0.0619439977890579, 0.08473960173432715, 0.04030580283142626, 0.08814546585199423, 0.024250807109638117, 0.03142206136544701, 0.038344896529451944, 0.033809980886871926, 0.043477185390656814, 0.032591656417935155, 0.051972304936498404, 0.08951343697845004, 0.012726404947898118, 0.03262831480242312, 0.052587764294003136, 0.023632551710761618, 0.05118451146699954, 0.05988884615362622, 0.041606041850172915, 0.015288944396161241, 0.013834739420417463, 0.022867245315865148, 0.025324923008156475, 0.04400909005198628, 0.022586570630664937, 0.023335269615927245, 0.04925609267957043, 0.028762610418198165, 0.026571773778414354, 0.03972576618252788, 0.050099257787223905, 0.025423795632377733, 0.029533883680414874, 0.03976039479312021, 0.03642767303972505, 0.01551592748000985, 0.038684636892867275, 0.02046112833340885, 0.03429311531363055, 0.010793472047225805, 0.10812388834892772, 0.051293666547280736, 0.017283144370594528, 0.08440596924629062, 0.04721530531242024, 0.07880313278292306, 0.03202199499355629, 0.02492270494258264, 0.015919627985567786, 0.055321814070339315, 0.02198103378759697, 0.03466147289145738, 0.019841579742205795, 0.006551384685735684, 0.021512964958674274, 0.01437021752280998, 0.0555399275617674, 0.033527686464367434, 0.07023482263321057, 0.0470880566717824, 0.01909689948661253, 0.0908489317225758, 0.036791507227462716, 0.03287134590209462, 0.1649229065515101, 0.038371806804207154, 0.033499881901661865, 0.004857066178374225, 0.04492991720326245, 0.009424225354450755, 0.0268378559849225, 0.02984154471050715, 0.020148194344074, 0.023273378210433293, 0.062232811978901736, 0.03524260420817882, 0.03543426013493445, 0.02072892675641924, 0.009395511660841294, 0.029740690551989246, 0.018240268109366298, 0.052986635273555294, 0.01570497846842045, 0.03711435630975757, 0.020458139333641157, 0.03461274718574714, 0.09288567438488826, 0.029971825024404097, 0.011073057630710537, 0.0642988360777963, 0.04863940877839923, 0.026468125433893874, 0.047631338456994854, 0.025896207880578004, 0.03501736980979331, 0.02942058927146718, 0.04785837256349623, 0.0324209216341842, 0.027790215135610197, 0.04913160111755133, 0.06426954350899905, 0.13892560702515766, 0.11078442097641528, 0.16367713746149093, 0.15105467493413016, 0.15456587949302047, 0.1547533756820485, 0.1092860396602191, 0.14477310731308535, 0.15222860412904993, 0.15551294898614287, 0.17923028179211542, 0.14198180084349588, 0.2301019520382397, 0.07486223214073107, 0.19433410023339093, 0.1540814500185661, 0.15049934067064896, 0.07858013967052102, 0.1664250431349501, 0.15467438148334622, 0.14599389571230859, 0.1090071108774282, 0.10658829574822448, 0.1473249969421886, 0.13004511245526373, 0.18105008726706728, 0.13351297558983788, 0.15289013972505927, 0.0946408165327739, 0.07002228638157248, 0.1528267899993807, 0.161423739627935, 0.11256439538556151, 0.13948502310086042, 0.11728743062121794, 0.1194804473198019, 0.1630880354787223, 0.19143396522849798, 0.15361906233010814, 0.09008241191622801, 0.2240412327228114, 0.12349945900496095, 0.20236703247064725, 0.0941686547594145, 0.1300282805459574, 0.2119452052284032, 0.17925889900652692, 0.11409326412831433, 0.19093303038971499, 0.10927346025709994, 0.14232795336283743, 0.20500511513091624, 0.16195151052670553, 0.23716344265267253, 0.11037585383746773, 0.18283220648299903, 0.08537086512660608, 0.09777100989595056, 0.2082466974388808, 0.0941187007992994, 0.12419265462085605, 0.10994177908287384, 0.12843508244259283, 0.05401932263339404, 0.13683853932889178, 0.15716428693849593, 0.17561562184710056, 0.07684485739446245, 0.15712476015323773, 0.21531759848585352, 0.18153370037907735, 0.06022905035933945, 0.13661381701240316, 0.18942255206638947, 0.11503999223350547, 0.12649421783862635, 0.12846813770011067, 0.1465354408719577, 0.28177340514957905, 0.16245318751316518, 0.17027230700477958, 0.14141865918645635, 0.12503827252658084, 0.1102813561738003, 0.1007269172987435, 0.18763019121252, 0.16626831638859585, 0.11539007813553326, 0.1310888392617926, 0.19726902712136507, 0.15878755686571822, 0.14560208626789972, 0.12215379683766514, 0.20109641627641395, 0.053622897030436434, 0.1683180095278658, 0.19672534457640722, 0.12899095105240121, 0.07913407869637012, 0.09962795986211859, 0.09458545231609605, 0.14691001764731482, 0.11643879959592596, 0.10001343136536889, 0.11807371382019483, 0.13990895269671455, 0.0916682330716867, 0.18636224674992263, 0.1480409171199426, 0.18591885804198682, 0.12044782197335735, 0.0929859014286194, 0.1198619334900286, 0.10153480441658758, 0.15288901166059077, 0.18301729811355472, 0.1419358915882185, 0.18660268775420263, 0.24909661326091737, 0.13232665252871811, 0.16059838235378265, 0.07377272966550663, 0.14107266993960366, 0.08033930425881408, 0.14198990509612486, 0.10527581500355154, 0.1381643713102676, 0.1424174860585481, 0.1071700949978549, 0.18754287011688575, 0.08058489576797001, 0.09268158377381042, 0.11222582761547528, 0.16892937594093382, 0.10588824268779717, 0.06793597567593679, 0.20855078502791002, 0.16788407578133047, 0.1456398912705481, 0.24477268278133124, 0.12293818756006658, 0.13751785678323358, 0.15532251389231533, 0.1609055424341932, 0.25795735185965896, 0.18159449711674824, 0.23194979585241526, 0.14048365701455623, 0.11687432895996608, 0.18861929595004767, 0.11435139051172882, 0.11960923962760717, 0.0797446806973312, 0.10016111133154482, 0.13033707335125655, 0.15415884117828682, 0.12585033051436767, 0.07952999963890761, 0.09771002019988373, 0.08450904613710009, 0.13199636712670326, 0.22786851797718555, 0.16056434746133164, 0.10944829540676437, 0.1955323718721047, 0.15846173919271678, 0.09928322484483942, 0.2532225090544671, 0.11193677593837492, 0.1344021427212283, 0.15555213438346982, 0.1561094872886315, 0.15561536536552012, 0.09080491494387388, 0.10863318719202653, 0.08321390938363038], [0.05797571560833603, 0.013303790274221683, 0.041819112448138185, 0.044608730531763285, 0.06957802193937823, 0.06528376252390444, 0.023498146911151707, 0.052267141654738225, 0.043615458635031246, 0.021291055381880142, 0.011672609052766347, 0.04309571406338364, 0.019028670139960013, 0.036501008362392895, 0.034408393112244084, 0.05263587401714176, 0.03272990739787929, 0.032939875818556175, 0.09281091042794287, 0.03281852354120929, 0.041518275465932675, 0.033003440767060965, 0.027688138288795017, 0.052704114496009424, 0.05592098328634165, 0.048885133874136955, 0.005001818371965783, 0.02828768228937406, 0.023716056311968714, 0.015925902844173834, 0.03542827471392229, 0.023273532206076197, 0.050940463625011034, 0.07377223242656328, 0.020515559299383312, 0.06414589428459294, 0.08275018582935445, 0.05722124085878022, 0.07720048713963479, 0.03255044866818935, 0.02158065439289203, 0.03427872135944199, 0.03820686077233404, 0.0416815590870101, 0.06776588284992613, 0.03995885250333231, 0.026999532856279984, 0.05610496911685914, 0.010342463338020025, 0.01181160125270253, 0.04274406594049651, 0.055055943375919014, 0.027913049852941185, 0.06947354981093667, 0.04948377616528887, 0.12373209261568263, 0.05656459972669836, 0.04239094094373286, 0.050297006746404804, 0.1111801786464639, 0.023441222328983713, 0.0371862555766711, 0.04813316758372821, 0.04105900850845501, 0.03701798472320661, 0.029748134293186013, 0.07169506498030387, 0.10287342360243201, 0.02148205636331113, 0.02703917652979726, 0.015427507078129565, 0.05061223026132211, 0.03052026473596925, 0.012205142684251769, 0.05835773241415154, 0.07240349688800052, 0.06094737138482742, 0.03711995952471625, 0.026627112019923516, 0.03257676893554162, 0.0523801744566299, 0.016421607397205662, 0.04950017391820438, 0.029753654016531073, 0.050217559837619774, 0.039043012584443204, 0.028111052997701336, 0.028865652056992985, 0.07466656490578316, 0.025108425543294288, 0.03020671476406278, 0.013430745766527252, 0.009768552190507762, 0.03931173312594183, 0.0029118936390659655, 0.02355167245696066, 0.06701801321469247, 0.023405131687468383, 0.12148804584285244, 0.025238718844775576, 0.09137498826021329, 0.04727206476673018, 0.027351275602995884, 0.02118887277902104, 0.053978853320586495, 0.05780142222647555, 0.03692216603667475, 0.052205621323082596, 0.01903733100334648, 0.03310321881144773, 0.05373787796997931, 0.02051262039458379, 0.034188264689873904, 0.031234628258971497, 0.029247288512124214, 0.0786788304685615, 0.02677160631719744, 0.0663798997993581, 0.03167689632391557, 0.01466430003347341, 0.06731742527335882, 0.04178091410722118, 0.008252558782260166, 0.022284998922259547, 0.03067570571147371, 0.12591363571118563, 0.045552553128800355, 0.02977919688419206, 0.03551745860022493, 0.05726046707422938, 0.009769550379132852, 0.009834641368797747, 0.06536151733598672, 0.025436490068386775, 0.04627642912964802, 0.0008778686867572105, 0.03329396931803785, 0.021221983697614633, 0.02235331918200245, 0.019773216808971483, 0.039307944462052546, 0.026387889993202407, 0.02698624099139124, 0.09069299165275879, 0.04307942763261963, 0.012091104272258235, 0.0036618292278944864, 0.09875840027234517, 0.05005629856896121, 0.07738383472315036, 0.024807401168800425, 0.04168408609984908, 0.014878382735332707, 0.03827994005405344, 0.013009081576456083, 0.02175118508603191, 0.06203574579558335, 0.014340101170091657, 0.032425623139715753, 0.0562513577460777, 0.056115993720595725, 0.03809232141065877, 0.04757793722092174, 0.021183969038247596, 0.026597823161864653, 0.016844908022903837, 0.043073720516986214, 0.03473303819191642, 0.009263182091672206, 0.030529728974215686, 0.054843562975293025, 0.004235354690536042, 0.011072632751165656, 0.07546572436694987, 0.04785312929016072, 0.021556432548095472, 0.014131142997939605, 0.054951274578343146, 0.050024916854454204, 0.08110394643153995, 0.03332916567160282, 0.06958220023079775, 0.034216611020383425, 0.027600637222349178, 0.017502658665762283, 0.05588138970779255, 0.039575867194798775, 0.03324361088743899, 0.03704144401126541, 0.05123658796946984, 0.010346906019549351, 0.005553154778681346, 0.00780968493927503, 0.022642465482931584, 0.049768894459703006, 0.06982065970078111, 0.030308862114907242, 0.023834736857679673, 0.010104294233315159, 0.05300661388901062, 0.024429443910776172, 0.07249287373269908, 0.024486238617100753, 0.009029606881085783, 0.02394848026597174, 0.04616124781023245, 0.03080420858168509, 0.050165301508968696, 0.020851895060332026, 0.03676864165754523, 0.07545881497208029, 0.06632212360273115, 0.05603023113508243, 0.06372525240294635, 0.04875611892202869, 0.03925295874068979, 0.034483743365854025, 0.04030622585560195, 0.05073721535154618, 0.011961264608544298, 0.031929838805808686, 0.05009524647903163, 0.011113131749880267, 0.04767898062709719, 0.022258545068325475, 0.07466277995263226, 0.025104944870690815, 0.053517482374445535, 0.026743543858174235, 0.03147607116261497, 0.024273123490274884, 0.020819966011913493, 0.04586288589052856, 0.08373044416657649, 0.05462002067361027, 0.05015070717490744, 0.029696933524974156, 0.010896142612182302, 0.046342049827217124, 0.04805072610906791, 0.063020783563843, 0.07120915863197297, 0.024987500000861473, 0.033285950412391685, 0.060941478732274845, 0.03927734200260602, 0.057795058310148306, 0.06394690222805366, 0.006121522083049058, 0.0267448797239922, 0.022312925939331762, 0.12574499007314444, 0.020201378501951694, 0.07623524987138808, 0.054543219521292485, 0.026735944265965372, 0.012573939056892414, 0.0394043828418944, 0.07299744509509765, 0.03060215702134883, 0.02845759143383475, 0.0012394218720146455, 0.05224369349889457, 0.042254779109498486, 0.034553746445453726, 0.03588377898267936, 0.008942901768023148, 0.04778204267495312, 0.04358338672318496, 0.04044351204356644, 0.0321412618359318, 0.035436712933005765, 0.10239582188660279, 0.03982195594289806, 0.04262875845597591, 0.04905088513623923, 0.024254269228549674, 0.027671356474456843, 0.01321193465628312, 0.05143480819242541, 0.09648030376411043, 0.00714576055543148, 0.08643184686661698, 0.07469091477105394, 0.023690394700679462, 0.04166276419709902, 0.041697377964737825, 0.023855622748669703, 0.08069415474892594, 0.022288759755610954, 0.07461000583134592, 0.06132542512204964, 0.05485673238581512, 0.026230769908579532, 0.08273884581285529, 0.01363190767733613, 0.06627567257964984, 0.029899166911491193, 0.04142639758356381, 0.010173784303333377, 0.04767169273691252, 0.09090352410566993, 0.04524803880485706, 0.03556933101208415, 0.0779895756568294, 0.032034348041634075, 0.03313937624625396, 0.02073473220661981, 0.060847997810924426, 0.019317846126796212, 0.014959300024202093, 0.03193436590663623, 0.028749685916409362, 0.04162312608968932, 0.02518997273000423, 0.01423538320523221, 0.03801679675234482, 0.015180948921624804, 0.019120130564260762, 0.05650544313539285, 0.029447250926750712, 0.030607760236307513, 0.019802173555945046, 0.03743058172403835, 0.02677802218386205, 0.05939495800703298, 0.02210639366239775, 0.05877680094272364, 0.030082540470175445, 0.02506349035684252, 0.0636406549892854, 0.036478595502558164, 0.03918805792636704, 0.010496618542674696, 0.05533522096811794, 0.03874108464515302, 0.038868247938808054, 0.023730107022856828, 0.03563731545000337, 0.03564730104699265, 0.02128363947122125, 0.04960367012245115, 0.027162927799508907, 0.12333854654571041, 0.020883981815131847, 0.04954557851306163, 0.039397911314154044, 0.010484554932190804, 0.0734948473109398, 0.04522151815763209, 0.04342600688687526, 0.010692873929656344, 0.11902126570930704, 0.17962546058697626, 0.1906561350915581, 0.13981786149088293, 0.1607363624498248, 0.1415603351779282, 0.097887148585869, 0.1325972395716235, 0.10087683112942614, 0.14777516887988895, 0.13369468302698806, 0.16293239226797596, 0.06975206299102865, 0.2072141325334087, 0.05256394506432116, 0.13771495636319742, 0.1192561851348728, 0.08493800007272512, 0.1652590252342634, 0.18360821093665436, 0.12223712517879903, 0.11800982232671231, 0.21321877517038956, 0.19503669143887237, 0.1314926566556096, 0.13387075014179572, 0.08403846513829194, 0.0648306219954975, 0.11964815043029375, 0.10456225485540926, 0.20366000215290114, 0.13042221253272146, 0.14337696426082402, 0.12894931656774133, 0.1954842361737974, 0.16445621440652758, 0.2575441834051162, 0.20932224753778428, 0.10081961154355668, 0.18143023014999926, 0.20389860263094306, 0.14419892249861732, 0.11284269334282726, 0.12768540938850492, 0.2046534707187675, 0.17060790618415922, 0.16525279119377956, 0.21145344333490357, 0.13213219499448314, 0.14301531569799408, 0.1150996312208008, 0.13408195052761585, 0.11815765072242357, 0.15227178228087723, 0.1927734081982635, 0.130384600488469, 0.22633503307588398, 0.2515150053659454, 0.28472183912526816, 0.1533554366324097, 0.24413148203166202, 0.09654078879975714, 0.2012432724586688, 0.1526130217825994, 0.15768294426379725, 0.1307369870482944, 0.12600247078808025, 0.13199213688494638, 0.149209042720031, 0.14338972920086235, 0.13994842011015862, 0.17577444144990295, 0.20557211595587432, 0.09474151855101809, 0.22515292541356757, 0.2996751054888591, 0.16224684077315032, 0.19640752725536004, 0.11522987071657553, 0.17104841535910964, 0.10761088618892245, 0.12274620879907161, 0.1715257647447288, 0.14529148262226954, 0.14183924911776558, 0.12191892194095999, 0.14608805940952152, 0.18434687051922083, 0.17922419618116692, 0.1872154197189957, 0.15874411154072732, 0.09739716784679331, 0.07380033755907789, 0.09634107685997151, 0.07006969477515668, 0.14091757591813803, 0.19759947579586878, 0.22458409890532494, 0.17185394244734198, 0.08517527210642584, 0.1762544477242045, 0.11673342480207793, 0.10012159196776338, 0.143813896283973, 0.20655808883020654, 0.103710454859538, 0.18856945331208408, 0.13931106368545443, 0.1086861097428482, 0.18812593101756647, 0.12727443769108504, 0.12812593340640888, 0.16151907591847703, 0.20515872485702857, 0.14117153885308653, 0.15937998367007822, 0.13023232662817463, 0.14190482528647408, 0.1302854940877296, 0.09782875640667044, 0.19865515117999166, 0.08021714675123803, 0.11676582696964033, 0.13437858695397153, 0.11411845262045972, 0.32497272302862257, 0.13190095662139356, 0.10464016551850364, 0.20436096063349396, 0.11473624603240751, 0.11662163509754464, 0.11574921823921613, 0.12861347990110517, 0.11905817271326669, 0.16868262668140233, 0.12159097430412658, 0.13140998140443116, 0.07079933726345189, 0.09214950841851532, 0.13253868411993608, 0.14621607988374308, 0.17035198397934437, 0.09588927961885929, 0.13408753147814423, 0.11532710690516979, 0.06564699186128564, 0.1525969320209697, 0.13318751414772123, 0.16137946309754625, 0.19031309959245846, 0.1428161677904427, 0.2008920139633119, 0.09644485136959702, 0.2064139340654947, 0.13491915247868747, 0.11143022304167971, 0.12176008749520406, 0.08648591974633746, 0.15336443146225065, 0.1317176313023083, 0.12425665743649006, 0.16165833250852302, 0.09959072631318122, 0.1307277992600575, 0.11377681978046894, 0.15084014972671866, 0.09961535819456913, 0.19325403787661344, 0.13957301212940365, 0.12128710193792358, 0.0898558490735013, 0.2056344860466197, 0.1881077335565351, 0.15529294672887772, 0.14001877570990473, 0.08928291106713004], [0.01209079999171081, 0.03387146040040534, 0.06138339427707251, 0.042476740636629984, 0.06264141251449473, 0.025116338692896534, 0.05331116532033775, 0.0025964064298023004, 0.018117659747076686, 0.025045222391781863, 0.023184491183201317, 0.036331980518298224, 0.005755629827035591, 0.037736153608420864, 0.035524479317246005, 0.05398426357714925, 0.03463444758381229, 0.003417110438022064, 0.05869745051313657, 0.030733515304746106, 0.04859135100559797, 0.050794100970961154, 0.05927607708144933, 0.12947799288667738, 0.05299911448673811, 0.026519983002799563, 0.022140784785733558, 0.027873977633134928, 0.04748007020680234, 0.030151599166856613, 0.04544482297205832, 0.03502360385027714, 0.0397540457197465, 0.0033844151221273933, 0.053292225711629726, 0.008750146535021486, 0.06320417567621917, 0.07448868695064448, 0.017565583511895966, 0.040457664799760096, 0.010663922748790355, 0.023233398715092335, 0.09961920251953416, 0.05724788396037184, 0.03507061148411594, 0.018321366296731867, 0.029628101183334365, 0.06438708485802636, 0.019112877926090732, 0.047105348712648265, 0.03435106962569989, 0.05501093211933039, 0.01736464702844387, 0.022769677016185597, 0.025932613934855908, 0.05687361517630052, 0.039323321761912666, 0.031409767689183354, 0.01576630584168015, 0.09644638761528768, 0.005713890977858682, 0.0503313570516184, 0.05205726600252092, 0.0562198647094192, 0.019102793994534295, 0.058180492706014775, 0.03607704536989331, 0.07928590726805851, 0.06562079404830001, 0.037327582758734934, 0.08345497379195876, 0.031439167869393714, 0.03366139550053049, 0.08589607561589219, 0.017545308037369978, 0.016549865358683746, 0.07138253917219117, 0.03455866317381151, 0.019731229804165196, 0.021189214166952297, 0.011456944648671197, 0.04539848698186688, 0.07269605150213465, 0.05607000282907393, 0.019517227810865734, 0.05989791519823484, 0.03464988054474816, 0.03511709219310433, 0.011827771722892066, 0.028811991069233045, 0.09636154529289342, 0.0446237775759073, 0.040782165160635486, 0.035768627349170856, 0.016006592850317247, 0.07097093664924614, 0.023087633489922155, 0.025213218650605995, 0.04635064018657431, 0.0286745397534105, 0.01505072983491118, 0.07306375599000603, 0.06045528294635005, 0.04157690884312615, 0.05887951789190993, 0.04875707258179318, 0.006811424418629031, 0.027656856764224358, 0.04629022936569527, 0.055316637590294704, 0.016104363385238685, 0.11140553178847767, 0.03848781932902057, 0.03474218145129271, 0.04491263629461173, 0.07355383320827968, 0.042094015079783276, 0.0010650993840499723, 0.021083539759274572, 0.023716009927738924, 0.039839489181758836, 0.04066251982294489, 0.030035269373911433, 0.03408832708373666, 0.010771413562906673, 0.0787928095087409, 0.033523497040732764, 0.04249251498549711, 0.06682245730189607, 0.04227072044159286, 0.04187482176348567, 0.018622461175255012, 0.01360959871817613, 0.012593478877533926, 0.1027896573941689, 0.04383832558232825, 0.007339390131164691, 0.05404139039455913, 0.029378752551565412, 0.0596218065766152, 0.0028108235619583866, 0.024459517590003088, 0.029898322718509007, 0.028624589504033793, 0.02718343705055304, 0.028525702036859002, 0.021831277663295623, 0.05645863959216513, 0.021702385165554006, 0.10988746129442006, 0.02631585899507627, 0.10295141590177082, 0.0301013186617638, 0.030339505392475985, 0.026812585856532678, 0.03210911942005623, 0.0752611736243125, 0.03863442318106536, 0.009341775530629093, 0.1082447545195464, 0.039068902406143025, 0.04117247175599914, 0.039317273258347996, 0.0462455372326076, 0.03038071870832937, 0.035900265793316066, 0.1323993830010295, 0.031452344701392576, 0.027104847322334535, 0.10871903883526102, 0.05068280479463283, 0.005441426301331376, 0.05244916821538936, 0.051212898615631275, 0.10914679049164988, 0.016846247599460185, 0.023478095936297905, 0.09916921611875296, 0.03562395679182373, 0.032297027501044795, 0.02583161691291025, 0.024265638930955902, 0.049550729017937556, 0.023848555647418834, 0.07598346142913215, 0.03817226555838715, 0.03773166361497715, 0.057885704227373935, 0.035158058744855225, 0.02789543868857436, 0.07578377917525358, 0.033491792491986416, 0.005963478024568758, 0.03627002231951337, 0.009362918390252162, 0.03254320901760366, 0.016216962030739523, 0.014215806277206866, 0.05594678033958189, 0.051746487952186726, 0.018765408094623126, 0.011936138271266827, 0.10584899049717933, 0.026763789646793157, 0.006223840127859148, 0.04087747176527046, 0.03379786532605067, 0.03312041066237725, 0.040892641263781115, 0.019312216936668847, 0.005240636392045417, 0.03110913294221973, 0.07763955654809251, 0.08168628744897433, 0.006419632600227487, 0.07962261224747635, 0.027703265113814268, 0.05651749190292321, 0.057348660193383694, 0.04277686144632753, 0.07037822040729225, 0.023583239708386827, 0.03780003396968823, 0.05338581424439326, 0.027435244046500884, 0.007117420254871831, 0.022063306423660833, 0.01631294213439105, 0.03608604762121104, 0.029812881111865863, 0.04401888269057963, 0.03639979426225182, 0.01806145504815504, 0.021740435076935682, 0.006694317689834861, 0.07419869274599478, 0.06814932829001918, 0.04738023279060144, 0.06140764395240694, 0.03850045439321548, 0.021630812443618197, 0.010279869675287046, 0.020374204286781605, 0.024581272482464556, 0.04508899655775167, 0.07277743541635573, 0.054298785762512125, 0.1074653139221482, 0.039454615107388236, 0.10793003195431083, 0.03156238664814737, 0.03678005959955044, 0.05882148565433454, 0.03742605091247242, 0.13074243441224098, 0.04738379881018773, 0.03047731108381413, 0.03659915368189104, 0.0843735522357747, 0.10875710358959623, 0.02603969656775007, 0.02233037754194811, 0.05506410700036213, 0.03128859352727886, 0.052656420375569724, 0.031214723858283833, 0.08931238175136968, 0.07935896428534761, 0.07004351180512458, 0.031740004851599224, 0.018851577005989384, 0.04861570458160713, 0.011505116526677739, 0.03363177638675552, 0.0770923488016706, 0.061295219711610116, 0.03444699221290648, 0.06350183626636863, 0.03474817058304325, 0.03441386274062097, 0.015643029546481557, 0.020170638745184988, 0.01850852666393621, 0.04802190109330695, 0.04438147378095891, 0.042858148881350644, 0.03652897990832571, 0.06244460979360156, 0.010656923368514981, 0.0205287083008443, 0.008904182996047894, 0.02470977164193755, 0.039840038371039554, 0.020378080153022893, 0.016060081288742367, 0.05687368939106818, 0.023198389753815718, 0.018748776565189473, 0.020020418778585736, 0.012297607790969778, 0.031714230062789284, 0.10673105527530424, 0.07290752648259513, 0.0036548386606227723, 0.022386235286830924, 0.03365245633176528, 0.035150151161360554, 0.028151273691037204, 0.02135316015483113, 0.032457457564305514, 0.049466758719063364, 0.023457970746676438, 0.042425903520779684, 0.011354263879184145, 0.019359083562449086, 0.03817142322077416, 0.0627391978923697, 0.008567114364268491, 0.0765369032160379, 0.037801900471094996, 0.06282623697188683, 0.03805899526923895, 0.0289153351332061, 0.10052051860839128, 0.06454955582739785, 0.08094468154013157, 0.06173857502290048, 0.16315894026774913, 0.025153277238132432, 0.0382851499307435, 0.028263820386200678, 0.050582384792505763, 0.027600679895840585, 0.017901935971167404, 0.06059753410227131, 0.05443100308184512, 0.04572762205498293, 0.03927318968635518, 0.054433314871857874, 0.03908194194082171, 0.02531826037738938, 0.026411115504743066, 0.07547871937276796, 0.039331663501798175, 0.043649723593262024, 0.03975038322096225, 0.10352051700465381, 0.03765893685340416, 0.05006084422348067, 0.06952619034564123, 0.022675709988106973, 0.005593807773038861, 0.13889396184822544, 0.15470283542526886, 0.1133446152380202, 0.11996944100246765, 0.11853940406581387, 0.12021617541904561, 0.19055457960348576, 0.08842030540108681, 0.13650007545948029, 0.18982868496095762, 0.15829298965400085, 0.07469713396858424, 0.09115442939219065, 0.1717353324056603, 0.15026695939013734, 0.21301176049746573, 0.10413779091322795, 0.10278291127178818, 0.15032128460006788, 0.11145438737003133, 0.11995075372396968, 0.19648542307550088, 0.1744848262751475, 0.30779138091020286, 0.27324719703756273, 0.12110909781767987, 0.1708008348941803, 0.1458534220000729, 0.16582081618253142, 0.09146368232904933, 0.17431457759812474, 0.1022084073338192, 0.1418051400105469, 0.14098689251113683, 0.1893473428208381, 0.12041079622576945, 0.31810061365831643, 0.24143779766745865, 0.1425229452433996, 0.19307675363961607, 0.08744027712964453, 0.1557308732299134, 0.1408104394795373, 0.1324733899673447, 0.1124435366364196, 0.1316375090391375, 0.10945069254375994, 0.20405592309543863, 0.10163856408325955, 0.08458349097054452, 0.054342301591532305, 0.08642786153359339, 0.12138068675994873, 0.17938610311830416, 0.13345375220524147, 0.10311177917174064, 0.08386105473618954, 0.11813830293249339, 0.08358462699106894, 0.18672106030862778, 0.09406464276253246, 0.10964051165501587, 0.15983077901182696, 0.12448510533431545, 0.11266474117292091, 0.18913008650997654, 0.17672654270427302, 0.24581854697316885, 0.13981722324388102, 0.14539744646754116, 0.17137853748863563, 0.15725352277513593, 0.13722271949518472, 0.18417540472000837, 0.07899773874669336, 0.15776137443026528, 0.12459135119570419, 0.07708160992478952, 0.16986017755698413, 0.07916501883300953, 0.07156095889513381, 0.10687132860766724, 0.17841774882981554, 0.21234724146779627, 0.10957667953334749, 0.13122664124239236, 0.11659800511552021, 0.17042661434970796, 0.11986116165644489, 0.16249676642473787, 0.15748296515084803, 0.08711567657883279, 0.2241598576074466, 0.0986022969300393, 0.09983946452848613, 0.18207484477898106, 0.12041843292536214, 0.15935439441818744, 0.19584147637942806, 0.1420818126644008, 0.136351675610058, 0.0965581031050533, 0.21812940307427198, 0.1235325810557697, 0.14113202691078186, 0.09182610272546299, 0.19432323519140482, 0.14260464085964486, 0.1505199130042456, 0.1614159025484696, 0.13293396681547165, 0.1861046621343121, 0.098942089243792, 0.09416381595656276, 0.18883759126765653, 0.21704162238165736, 0.21231062390143052, 0.112930348404916, 0.12816985370591283, 0.1312454917933792, 0.16136279446072876, 0.271330110845156, 0.11763505259295925, 0.06424621780752204, 0.13164197676815093, 0.16473319876240566, 0.1713919555186294, 0.14975461032008752, 0.19606615416705608, 0.13874507218133658, 0.16221979691181332, 0.1256559620378539, 0.12651606666622683, 0.07941089235828258, 0.1494134747190401, 0.08608217656728812, 0.10898604872636497, 0.20531619375105947, 0.1012427470413968, 0.09656343172537163, 0.12924509210279211, 0.117827832873445, 0.10634855236276053, 0.17163598851766437, 0.13458373141475022, 0.14766865584533662, 0.10689806076698005, 0.17323144274996594, 0.2395507981418632, 0.20265562401618809, 0.15846570226131007, 0.25219789997208863, 0.13298544217832386, 0.08313000958878547, 0.0710369655280374, 0.12025334959616885, 0.13723450480028987, 0.12892319296952337, 0.16215266223298386, 0.23633109434740618, 0.10271165767335333, 0.1757532308693044, 0.20446790411369875, 0.12493757792981341, 0.16012648033211008, 0.12493334768805653, 0.1962697401177138, 0.1003486594709102, 0.09440249064937234, 0.2050274537759833, 0.12584192940266803, 0.12375148493447341, 0.140859198581893, 0.16486139735206962, 0.2331604019855149, 0.08841623843181878], [0.043646866324706934, 0.01800787384127034, 0.02041479790932499, 0.06685509695671499, 0.03103926715994021, 0.03555439157935325, 0.08676216937601566, 0.05072559702966828, 0.09064896003110334, 0.028283977117098402, 0.04609429866832215, 0.03125311886833515, 0.08252785322838463, 0.02745542675256729, 0.06189554667798802, 0.04319224150094669, 0.015659601704101078, 0.008435901727352757, 0.026148261640628334, 0.062465115333907306, 0.04828643592190929, 0.02361353974265512, 0.015306970235542394, 0.0411107324907789, 0.03882624238030985, 0.02631500923598651, 0.03911251471436117, 0.05508660149644129, 0.06798942515160888, 0.014099193540459964, 0.021238019653537776, 0.017194264764839318, 0.07137367792893201, 0.07238374833832495, 0.01892785308882594, 0.04236631277308334, 0.06309506512479857, 0.03996081177319866, 0.023759733558108564, 0.018397640524199232, 0.017390920911566354, 0.028018811462970916, 0.02300871907209512, 0.044388130845618434, 0.01171230003819801, 0.016233680762525182, 0.012218920655868715, 0.05342564902093727, 0.07668200792977586, 0.05441189277917147, 0.03844737228064332, 0.09403841526363976, 0.029637381740030833, 0.06683658037218265, 0.012934380702063208, 0.041852082358673215, 0.04699352561146952, 0.05339123934390955, 0.06185451704368461, 0.026384685770608485, 0.046312226622831076, 0.012552703428809764, 0.04441345292434562, 0.03324633828015067, 0.03325404177303426, 0.02592175816971576, 0.07090964267263189, 0.014634083490818739, 0.02243425595224835, 0.012772110112564405, 0.0777357017796021, 0.05030684020312037, 0.04327987429860514, 0.07145731055061333, 0.053497618791880086, 0.04039032974105794, 0.026131002996407915, 0.00962467294812086, 0.03631444356869906, 0.06921888925717212, 0.011581200578802964, 0.012137815974710975, 0.02197735087975161, 0.03608775827160571, 0.025091736497415695, 0.0234305576668703, 0.04323691508034244, 0.01924151809362229, 0.01949513407453196, 0.01675510258792201, 0.05526538487174548, 0.03287902713054791, 0.023963900239323266, 0.032962448240141384, 0.07795227531460114, 0.04580980006721802, 0.07027131403447129, 0.03181728839990683, 0.06225006691238377, 0.07098137866705656, 0.021859657390450593, 0.02169247378333239, 0.03502572639263235, 0.030849268077872694, 0.051461722177919, 0.11992730185738765, 0.05297035997500643, 0.02063463874947047, 0.10582193179288879, 0.012392930166242877, 0.03514078154694289, 0.05765406138380058, 0.050382042027194984, 0.0527837729168823, 0.026293325536244083, 0.026219606152153574, 0.042152592795901, 0.06287954543950036, 0.112666581699159, 0.0578336351463804, 0.008794430486886995, 0.057591913937358186, 0.03015185891854344, 0.028063830141036306, 0.06878436921397224, 0.043973455831292085, 0.07100218848790973, 0.07789919691276737, 0.02953382245323155, 0.038304686968331225, 0.06635920130065642, 0.07768605210003443, 0.011169095250807004, 0.04249448909831699, 0.02656464359461097, 0.040774120279820636, 0.06930399875272997, 0.006538784873555414, 0.08465242164675146, 0.022352521373250056, 0.06495131747215055, 0.007318201814996428, 0.011896173618879402, 0.05054570785432588, 0.02654071489814669, 0.11021192083717324, 0.028864297637483105, 0.020858995558228344, 0.05037973394792061, 0.09515610450762324, 0.03767269998206757, 0.06018967571435496, 0.02270760749524925, 0.021295888618624303, 0.019766071782214567, 0.021327888171072118, 0.017907333240145817, 0.059824323834618554, 0.0050367067342449445, 0.028092734937672503, 0.028988512749492656, 0.038063993633841164, 0.053446366073330864, 0.06958058977033943, 0.07716576204984449, 0.16470524948090315, 0.062088582999422215, 0.054990623248158954, 0.005315618354870821, 0.03938021109206602, 0.028993410924158525, 0.0258161134479451, 0.029781953962810803, 0.05140933768416289, 0.055681477388134226, 0.023050025156408083, 0.029902975984441582, 0.027988390829705168, 0.0514536884293193, 0.011830746807390824, 0.03186534617270809, 0.021649941299983766, 0.026121073060494382, 0.038170981642906554, 0.03723161935340613, 0.027170395660505164, 0.02086646156385541, 0.0012343332900854875, 0.04723308346001431, 0.025325442511530127, 0.01616822148207575, 0.04561631845717784, 0.0042526012748567155, 0.033272031432716176, 0.00782359278673539, 0.04282858171791304, 0.00980252307272167, 0.0483373583847424, 0.03984342998592183, 0.03826902677246835, 0.019977600568381604, 0.08944604996941052, 0.021119828925293405, 0.04064337983436417, 0.023161837125371676, 0.03243167535401881, 0.02657471824932145, 0.06822644485509954, 0.04594392470608, 0.028240270185051486, 0.10252904481603764, 0.03103138369624503, 0.02762277734291274, 0.01993458568904316, 0.028003847910440527, 0.020523418643279, 0.047184072027448565, 0.05928093443799298, 0.010896201983996434, 0.057797537083388306, 0.010965726378344698, 0.020665977790486068, 0.01733292763674399, 0.038963510014582425, 0.05625977741146926, 0.11990375351160765, 0.041247862827731296, 0.017258627522096504, 0.031099715088203084, 0.01653010753216222, 0.02455325269693276, 0.05136306477652397, 0.05555891912081279, 0.016509321831108537, 0.046066505237831734, 0.053330038135754876, 0.030028556648176163, 0.018973955302499235, 0.011603896382439416, 0.020094904430152383, 0.05941793860984035, 0.03327361591800582, 0.07094659420545213, 0.02864079986466095, 0.037931668703095056, 0.04051553376484662, 0.035296821806696244, 0.031785531900823116, 0.019902966487279627, 0.061282710812520236, 0.016853351808094885, 0.022426708310376853, 0.03209877017070539, 0.06569536504684947, 0.02653703384567052, 0.07411652215523645, 0.045461424815584905, 0.02248041011625901, 0.004804277677976643, 0.02931463470304152, 0.0368769618216902, 0.010426652570458828, 0.03586733299016487, 0.017517063752165996, 0.03924045726307668, 0.05016468923713546, 0.03178856357408222, 0.028350770407996606, 0.05721800138417166, 0.015364204664365388, 0.05678512890881393, 0.06149710243334994, 0.018585901125334203, 0.009054458623722894, 0.014664928075944772, 0.097392410680186, 0.027287450902804267, 0.03255863826780114, 0.00915538792469306, 0.05805503264127765, 0.02572870143922046, 0.039023790959618054, 0.04145700375374872, 0.016814988339319825, 0.05539559468161315, 0.03369347483385354, 0.05244934633083176, 0.021684111634385772, 0.04147567247855477, 0.020728325616801158, 0.025708754365041386, 0.03340080518682953, 0.052195947428117506, 0.022453418205259368, 0.07498269755160436, 0.04409495282743592, 0.0179832493813592, 0.06637145415879786, 0.016676145496603567, 0.03598124152631499, 0.046332984493346885, 0.04395571108034346, 0.02301601809449494, 0.011643818361335434, 0.02698222411709139, 0.021289235264703166, 0.03328612852783408, 0.01324264936556574, 0.05649783241096884, 0.041865177554427646, 0.016869693899934646, 0.03578041636501439, 0.010181266079598572, 0.030931091714592185, 0.05780001956736669, 0.008020697005122202, 0.021232234612398315, 0.03920840390492231, 0.02725939772062702, 0.016134381403389852, 0.02983123813464772, 0.057010667587746866, 0.02061541712464532, 0.03763446453376673, 0.05917409485846292, 0.13504460512194782, 0.04807983685168438, 0.06973998824832961, 0.05187906892388128, 0.016308904851030093, 0.02789315472909948, 0.05085919845441822, 0.04130088185775094, 0.04037501181301195, 0.038714371039532125, 0.03889638275722973, 0.012955194233654765, 0.08873129496350884, 0.035866030520992354, 0.03682801347167697, 0.08114080148516223, 0.08963310086983256, 0.053410308828460984, 0.048292113351635635, 0.038965840358287096, 0.0015430043367814505, 0.06750763030140661, 0.01885162895632675, 0.021209940496191848, 0.01869906936917687, 0.05712411970307585, 0.07549270143499598, 0.10054658283479512, 0.11727060613338836, 0.14231400098651648, 0.14140752697130665, 0.13653918664203957, 0.1077575197268743, 0.17445658013457432, 0.09603094818885438, 0.1548876301967539, 0.09617675794288516, 0.14502053934847936, 0.07354615197982639, 0.1673547612153925, 0.09175654122373089, 0.163039677136112, 0.1315932473517023, 0.15894909272901714, 0.10268154874211177, 0.21416105038952082, 0.19987546460470185, 0.11885653118952177, 0.15608671819791198, 0.0820407371793408, 0.10732254697359167, 0.14398352155694738, 0.12548053317004815, 0.1189720984257292, 0.11116885347291827, 0.10201083277934231, 0.12951962737133726, 0.08997834054753184, 0.09407627221662551, 0.17437503294786438, 0.13994478358654305, 0.16293323831632733, 0.16547803301364183, 0.16532626381376758, 0.2035238774260506, 0.08972627008915879, 0.08696124306879938, 0.10340427441406064, 0.10773339250590652, 0.11528976945555769, 0.11667668019072153, 0.10134021329577081, 0.08631925564259291, 0.07552677343483083, 0.14048908953554928, 0.17326074274023995, 0.23759926145430654, 0.15028251480543986, 0.16762975661549717, 0.08824323638691567, 0.11369573272531852, 0.11969422295805998, 0.1148515980457887, 0.11060504388296977, 0.16425653215264902, 0.24982798495329916, 0.15285849454812706, 0.08805135410511866, 0.11120763068902306, 0.12786592938937247, 0.08061481174081564, 0.14411390206078067, 0.0940380293468479, 0.19308846472995356, 0.15284086111932993, 0.10652899814886041, 0.14412699354579672, 0.10335616098018363, 0.06085456952860113, 0.12093114564777352, 0.15068694076035172, 0.17095258925110102, 0.12176737538538873, 0.13377908006077632, 0.1715615956345573, 0.09584907747921534, 0.2818010130431503, 0.17414759437087923, 0.10390966213890351, 0.09519485203782097, 0.09861330298008397, 0.11420624126913026, 0.154079832136631, 0.1273953780764714, 0.1124743431864772, 0.134007201413624, 0.191170769976452, 0.10467238214914687, 0.09161574838799424, 0.1887088583316654, 0.13899829296860844, 0.24667403544299304, 0.16863088414538652, 0.18456835707183927, 0.1191457906679716, 0.149630434170831, 0.2068807152681984, 0.0764116361096967, 0.11900169527507387, 0.20751048694364727, 0.19373937277123332, 0.12663389003137127, 0.17852884833700955, 0.12523819226771593, 0.09685227560112253, 0.17346110776998103, 0.1194107744959183, 0.1132180642161984, 0.09716863831272349, 0.18780060316203162, 0.165253444283735, 0.13818053528666496, 0.12378040642943233, 0.2506354119395837, 0.1961845118785277, 0.1521373793366365, 0.1040365025983192, 0.08180304954294115, 0.15346856962423772, 0.11430678001488559, 0.1406491856323555, 0.14731744187884033, 0.20293792214943096, 0.10556825829553418, 0.14129846094874665, 0.3849538107169792, 0.06763970290194266, 0.253264395869337, 0.21448948042234406, 0.11663540193694644, 0.1062122495204676, 0.11016471282346174, 0.08393705065827817, 0.1633833657251671, 0.07253003306686878, 0.14251870015868917, 0.06695360963931307, 0.20765523542650044, 0.0762481483980082, 0.11170440207934007, 0.11777416075346991, 0.12220385469845496, 0.2306720253545791, 0.14415146957617253, 0.13429766317130998, 0.16022327123209834, 0.21921663457760587, 0.20139588770689443, 0.11842247127788141, 0.16320643771905452, 0.09103580450755544, 0.11157145374454558, 0.16188651323318481, 0.15172573970630765, 0.20969108009012416, 0.09045648403116502, 0.1006995617353823, 0.14671288838144392, 0.22996714833425358, 0.20824933948460966, 0.20501418417552486, 0.2043481363216415, 0.3475461539346725, 0.1916364231146872, 0.09135255313594826, 0.11357980183674954, 0.10910212062299252, 0.12966682494152337, 0.25797831011004746, 0.10696100973291323, 0.18206614680821076, 0.19732189772184938, 0.174471081700176], [0.04523226816672832, 0.0715066707925871, 0.038955179406912066, 0.051224272028775886, 0.020365777199913282, 0.07281069847522303, 0.029597791872220114, 0.07556718337582424, 0.011620586356002605, 0.02837889223883394, 0.021250112949928734, 0.08126799817546271, 0.027216726084589027, 0.03275215327448677, 0.04559392044029664, 0.03911257037543692, 0.05441921777673997, 0.0368721601262223, 0.034141260766773485, 0.05095581123896409, 0.04146127852436621, 0.027717800076061394, 0.02548148091591429, 0.05522629966435488, 0.02453403107210761, 0.036662896745838225, 0.05388417011999991, 0.017025921551976353, 0.02666620279342169, 0.01660192330746213, 0.08419139951001853, 0.029348515599849634, 0.016512693036929704, 0.02050873896223493, 0.03258091011957731, 0.03129117249045521, 0.038162788332556374, 0.020159641971986275, 0.048177470089285634, 0.014491647725662915, 0.05269857065286487, 0.062397305300692096, 0.0823715643491596, 0.047032844595378265, 0.0741533401014749, 0.026679103175411, 0.07485749723855406, 0.009962928088498302, 0.04065447865286842, 0.024701873335288838, 0.0564254693017574, 0.042844322670134716, 0.043608077976386994, 0.04639571823645383, 0.02873487821489107, 0.013819018877256894, 0.017928458473761566, 0.04242011847964022, 0.029818680995958857, 0.06670418864814565, 0.038952618997427635, 0.020482695144892205, 0.06108194502303377, 0.025967780602513812, 0.08890930650522932, 0.026545980435912497, 0.016138583814608864, 0.05850253284734208, 0.09718966335640289, 0.030479507840937003, 0.0367488411575323, 0.06570744721102528, 0.03979270419222303, 0.07529975788202137, 0.016992452547128778, 0.02353145264351042, 0.02339726863283431, 0.02959795885544736, 0.03949233847379219, 0.04032765908050351, 0.08940786647144705, 0.019943545266869478, 0.020936160362907685, 0.04418212549353484, 0.061262123635970056, 0.05081505179987289, 0.014918084852979518, 0.05941897019511089, 0.009284778589062626, 0.03179548410116695, 0.03703096488607116, 0.040227231656899676, 0.02567769177403534, 0.054781764338258654, 0.048211991088464856, 0.01880272142443573, 0.024860349694790784, 0.04796211367647629, 0.022354538159561343, 0.017714517707645427, 0.07956602348713204, 0.032063369726529345, 0.031142486914177425, 0.031771230715094134, 0.033493959563202225, 0.03906213401933201, 0.03820427067694254, 0.034654077389859594, 0.047557023499393836, 0.05762974120443687, 0.03495249125990085, 0.042988607310689986, 0.02108946951921098, 0.04877976745774504, 0.050703959714155644, 0.020571680506691337, 0.04258310895238537, 0.04272735648555681, 0.08144278137478977, 0.014867693025735207, 0.07331645727390423, 0.09763003894477151, 0.022321271389955655, 0.015264420126186451, 0.04398645454784855, 0.027978687248833012, 0.023434429822373204, 0.03523480423609726, 0.05030855827499181, 0.08419307676376775, 0.010474333703314187, 0.07110930266208015, 0.027447033062344417, 0.06181537617521826, 0.008319203643623041, 0.02562227560702013, 0.06718738615745679, 0.022296710012597032, 0.010585996315057855, 0.035215667958254926, 0.023942097795952577, 0.05601881319307722, 0.022772786614950746, 0.020136872881266754, 0.030178142078511883, 0.05618372582830489, 0.02106460200593574, 0.08824328091577627, 0.042898428946500644, 0.03142752357234713, 0.05227767273026984, 0.05790119284938555, 0.016349838006135542, 0.07310754270292819, 0.024921111180447042, 0.026275347008777317, 0.02936710268841125, 0.012623196325876052, 0.053323173269745894, 0.04891317592409905, 0.008762790876062354, 0.012086831357009942, 0.04128779037273489, 0.07250451802974567, 0.043280790850985795, 0.04728202438855078, 0.04793524793058168, 0.01008273762636236, 0.004651031140383566, 0.03518499499477912, 0.04465094760234933, 0.10005883596022613, 0.0227850134979235, 0.049895805423147976, 0.028874153358628973, 0.02450076244713273, 0.014248125880840234, 0.05116895605169702, 0.02160755539080128, 0.02864859241526574, 0.009193342284561368, 0.03834554590866901, 0.02653186849784106, 0.052222868835087866, 0.07492050557630137, 0.04738083021948114, 0.0384617847885238, 0.03943679614167195, 0.01062972551153507, 0.0171639925611089, 0.02960866804642137, 0.05842758706421591, 0.04476699723454658, 0.07509988266974688, 0.049476031854283065, 0.03260877405409701, 0.060448470030678436, 0.08827898564049974, 0.007074965233186958, 0.06295303290244192, 0.07052920293062925, 0.04481799391214736, 0.00788852978075738, 0.08558214714867063, 0.02247744894702919, 0.029050585981167387, 0.013411012987489812, 0.0324766940320842, 0.04887410927040037, 0.03563561964256223, 0.011628411375568248, 0.048731991701060906, 0.017004876099235844, 0.025741512763488572, 0.02702515179407783, 0.05583086429396644, 0.06719094846630469, 0.026443248643772677, 0.06447252089856192, 0.02889941977628041, 0.03635002583905589, 0.046951171243563294, 0.034977727991645224, 0.0570887637877604, 0.00942194232266047, 0.05062946293037385, 0.03376093976839911, 0.017023207146849018, 0.012218274987390032, 0.10283002280630171, 0.042533258892945014, 0.04146438812313136, 0.07929538449388929, 0.049950015600188635, 0.031381113367388025, 0.02506529006495839, 0.021801146467623767, 0.06948170601390302, 0.004916959351248806, 0.04160369666351471, 0.07454882317688316, 0.014330562717077555, 0.019848285046464298, 0.0820365959953051, 0.0025917329867297667, 0.06576951302122325, 0.06286384901613928, 0.02224235697212862, 0.025343144588987343, 0.030228940231609158, 0.05451965633255895, 0.05682781724317465, 0.03260734541981947, 0.023461173113901168, 0.022959206689847633, 0.03363166506460402, 0.020158849729341455, 0.037604767494485714, 0.030225606133171823, 0.022513068324769847, 0.05591937653662171, 0.031932247075019404, 0.06470040476415306, 0.026867731139645912, 0.030618228229286615, 0.013573701035056729, 0.017463963085901923, 0.03209846589015797, 0.01221378035552334, 0.06714134331559762, 0.03264526174461935, 0.042509584382059984, 0.054377728010877036, 0.0273872363686678, 0.04608977527823299, 0.02967498450743733, 0.06965913125895895, 0.04280144137737807, 0.02591494339867495, 0.011560719158296706, 0.03565205079212319, 0.1015725574688986, 0.06846723466878757, 0.01628600773983635, 0.012817827337130439, 0.14197979704476893, 0.05676349901477806, 0.005235434400674421, 0.029896699270466343, 0.05629461753414944, 0.07495862228097394, 0.013313889048731653, 0.05801743915071711, 0.005115768190080416, 0.01057542720445781, 0.04428851607372053, 0.03177212871378288, 0.06876291372464038, 0.0793283581151627, 0.019551561417756602, 0.03494863580272067, 0.039429998068953864, 0.028413071850081906, 0.11272161194938235, 0.0700639357091859, 0.050955302867805585, 0.026567450768197887, 0.03645046068413649, 0.03738613078894559, 0.06450923494412564, 0.0403206012560986, 0.055357559613185, 0.013623785798699828, 0.007712759988862672, 0.03693654514790978, 0.04602554239681922, 0.018128018273273483, 0.018121468820027076, 0.028528724433272146, 0.03365060096257366, 0.027340659180481452, 0.05282538513711188, 0.08748197098611854, 0.04815593296370935, 0.011307416734780418, 0.015512567406403832, 0.09706860422738828, 0.022628876758972183, 0.053614121134160087, 0.010386808517068857, 0.05990365199977532, 0.03629355211160146, 0.047648393010604195, 0.03675474494230002, 0.05130596393428277, 0.02451374446536647, 0.03809624737186823, 0.03922769603377674, 0.02118848500685999, 0.04896668477158528, 0.01856768511061091, 0.02687387055630097, 0.0469578542833915, 0.055014286626828834, 0.050323056129855104, 0.02219978367065778, 0.03357775916811079, 0.06060367537429556, 0.05581132725637872, 0.03145715381833725, 0.025885535796987824, 0.061059587824274786, 0.08733438007766381, 0.17086164647480473, 0.12560353672597557, 0.08450365814496763, 0.08054898324189708, 0.13778900785837322, 0.09379225230077282, 0.26707493292633444, 0.12300226459046826, 0.0904581909708213, 0.10846277524251491, 0.18052020866889507, 0.09723543160362169, 0.05768784394604154, 0.21639123384375125, 0.12325359290116467, 0.1453838057932444, 0.13911060959799215, 0.1756100112106651, 0.16814360482385382, 0.22161576052894816, 0.2462284648208879, 0.1419907363015227, 0.16986479371553287, 0.1370614508050494, 0.21098836907185614, 0.0660515959316399, 0.16473809693707153, 0.15841823449591175, 0.14548549486789852, 0.15629146189894527, 0.09769305470399559, 0.10374615958426148, 0.05815955300931819, 0.13982133474200964, 0.16194226336665452, 0.134028619795572, 0.14269199164118618, 0.12012151448288932, 0.12505927530582994, 0.11728658457286656, 0.11447321405285038, 0.11971634638030082, 0.2386034614755772, 0.11662280769087374, 0.08116400844301097, 0.18262148107169196, 0.08326997864060104, 0.14714925637235865, 0.25479069678112864, 0.1574836776126176, 0.1214001681364607, 0.19597392005380243, 0.2823112247278914, 0.12423773267073557, 0.1591453907894902, 0.22724870592355728, 0.14407624548766762, 0.11710862498148344, 0.15349426277680323, 0.1286094871466048, 0.16067080112406984, 0.17169537517474964, 0.09300685225753114, 0.14986864873208106, 0.12522241420811042, 0.10201269557001069, 0.10299377026967704, 0.12339504624833353, 0.25164125952869654, 0.1634057637420483, 0.18136999744456261, 0.10172577385674231, 0.13837772392435, 0.138385382888373, 0.1454813833697699, 0.09826254172367044, 0.08573894810979255, 0.12611802318133414, 0.11513611520058475, 0.146828752476722, 0.09552504838211462, 0.08647961891256273, 0.090818036114797, 0.09062731900485232, 0.13996355992276222, 0.15230318997055292, 0.1498046756023541, 0.10283467607223429, 0.15423085918882862, 0.08520555173163302, 0.13084903650451452, 0.14528401661664248, 0.14829274266958237, 0.10358181098126806, 0.13270992727484554, 0.2170992872561328, 0.2208756166510284, 0.14376411301782355, 0.11273302618064918, 0.10947376591502689, 0.15643540886230767, 0.15095286711584777, 0.106156209949404, 0.16235146875260398, 0.14703233842737973, 0.11848058144096285, 0.09307814296334982, 0.2099470913526602, 0.2510281268041581, 0.18924563890323043, 0.08707150394911878, 0.1244124787626788, 0.15057947777677327, 0.17148230457678437, 0.16237926960457116, 0.20148116047494113, 0.11420495735364966, 0.1297995654749684, 0.08485971091431566, 0.20077154855243862, 0.26211631775368005, 0.13804853690089658, 0.0636418275826145, 0.10451281297719106, 0.2183393418090418, 0.07881864366936497, 0.1604083925485611, 0.17751516366843134, 0.1904233975801617, 0.1624414764228277, 0.10656489583197981, 0.11870637987158261, 0.17390768771292642, 0.09583577077137306, 0.1883785135578364, 0.13774958497378975, 0.13261139974929392, 0.11644383135717362, 0.18573962937807664, 0.11398833186831325, 0.11413132888264954, 0.11385011428501457, 0.13812582415994257, 0.10732802402344532, 0.16415237914770842, 0.13133561820723116, 0.21741648117313161, 0.15913267037831247, 0.12930726923514158, 0.21724691527197137, 0.16221516591031104, 0.10214888709015213, 0.13153463252820075, 0.13932090456364676, 0.06921263295225799, 0.12690924166236073, 0.24087427009362727, 0.14229992986656725, 0.10464866310940124, 0.12049610610119998, 0.16445624409243464, 0.16993559460388497, 0.16819435288198292, 0.10967601599986665, 0.14373795973369852, 0.11309798472211696, 0.14950557524571195, 0.14401806110981852, 0.13576065888628364, 0.13853692944394425, 0.30882065067999065, 0.15489947487367317, 0.14652261656010523, 0.10663796769222245, 0.14039970526937395], [0.03264230057538953, 0.06017715568304993, 0.06386550347087905, 0.05783598775451537, 0.0828972201270517, 0.06897096740431152, 0.021183978315093555, 0.014829268329776824, 0.024037398834479973, 0.0241268498939462, 0.02608699734992115, 0.09039086333359592, 0.08207160310121253, 0.05322298333339859, 0.020967349119018763, 0.027170829816896003, 0.03751916818146128, 0.0027644954570860136, 0.023428420281561557, 0.08367968868697062, 0.02070450638711918, 0.0553539527754765, 0.04399783538246993, 0.050233556830789894, 0.03262364669353701, 0.04618610975740012, 0.04453146924788598, 0.010440991791256238, 0.04554744344204664, 0.016740866340114735, 0.023778626782586798, 0.08495337737258524, 0.008477534356643446, 0.0322862700704718, 0.014262159893405624, 0.023253794788615778, 0.06140431542007718, 0.02297690876730485, 0.04898149061773438, 0.03541971032973379, 0.011235202982788906, 0.006664126658506575, 0.08299669018015265, 0.015704110155638773, 0.038841096466057934, 0.028931328415637836, 0.010783528196043335, 0.028659811832767446, 0.10287936078384519, 0.052453253738349304, 0.033467668981757015, 0.0850777019513771, 0.04769970881170593, 0.038336992656695656, 0.0059949984279228374, 0.05857233925780747, 0.03584879043046385, 0.033959865031647496, 0.05358146292564925, 0.0243029318517074, 0.058246169064659625, 0.04607607894286048, 0.0382678653113544, 0.04565371898934245, 0.03704055714479182, 0.048571305596851744, 0.012611968559212983, 0.024900271673686802, 0.03727249684743583, 0.0315815897192806, 0.0673404021654278, 0.007102998933987692, 0.013543272980314214, 0.03551800036802888, 0.010652713535819203, 0.07568332948721945, 0.054143116576597095, 0.024330263295269106, 0.04961277256370522, 0.04096906392078381, 0.05829914727655705, 0.025216094472853, 0.0879420580167789, 0.020877063143416308, 0.0325204918772215, 0.041859897173708305, 0.05991040183289442, 0.023806735625839792, 0.029138799509382807, 0.058529654634185135, 0.027418122699600644, 0.026570044574327767, 0.050069341814378276, 0.06215327972313389, 0.03152942044835072, 0.020699116539617535, 0.04368877169326879, 0.008574417097406695, 0.04580817105306778, 0.06817570421844721, 0.09990516686229967, 0.01580329077114584, 0.020600073221430648, 0.03556406176357996, 0.02049456765234936, 0.04450173510122113, 0.04962494749634061, 0.02295369438797934, 0.014167835706757614, 0.05484155917656608, 0.03468878763669636, 0.04219630529405549, 0.04950157286657486, 0.0836212222930044, 0.03309519619506318, 0.04900569205346983, 0.02214465323049808, 0.008389890426769853, 0.02491419993020827, 0.021408090215118136, 0.01982892612431897, 0.04227203033224214, 0.08744410661165603, 0.04717636853456497, 0.04180657386314124, 0.04890556519967504, 0.028210857017256785, 0.07134450410376303, 0.04404385595989879, 0.00945665628023562, 0.06787533478927799, 0.01749757309880806, 0.03511181923386175, 0.007202929582490469, 0.010791243748826673, 0.013877961173420772, 0.06831671227701008, 0.01028685792334727, 0.024549491863581352, 0.01380169715048396, 0.06569893477717414, 0.03996919433120638, 0.054314322624122724, 0.014554233966919128, 0.022059508482925594, 0.038302690591081046, 0.02124094928149134, 0.027114083350170404, 0.019062230057897978, 0.029722339095314965, 0.06490333020337857, 0.023076562501955777, 0.030790710770816077, 0.06367444497300312, 0.03783509302593302, 0.02301665077538928, 0.09061815348104574, 0.07052059401758015, 0.05732242156227585, 0.022098254157754127, 0.037969065524521284, 0.0179150831172592, 0.033888140169437975, 0.06800770424888469, 0.031018620611575898, 0.046141421335050836, 0.020956510052201338, 0.034014650373137556, 0.03411288846109528, 0.003890245120601321, 0.019194222877558786, 0.09798321218113415, 0.016606448552920483, 0.026733168633654714, 0.030025244814169127, 0.018732688658928964, 0.04828579767490737, 0.06094776101235766, 0.09650588559452444, 0.024551310125389136, 0.04598851293849293, 0.015776742293382995, 0.030295126816781703, 0.030969245526648592, 0.050819382231566124, 0.015314404699893203, 0.01041498415361275, 0.03482943204289768, 0.09453362814383581, 0.043245386696071364, 0.030609778877987992, 0.05403139737609308, 0.045203287299955264, 0.027748202155635227, 0.02795472330035409, 0.05379073372751009, 0.054156579135451466, 0.03176328602421563, 0.032259007275570184, 0.032534804195165634, 0.01843286841904046, 0.03212831878045108, 0.05861116100277286, 0.006550102161781979, 0.06291502009844407, 0.05450427903269883, 0.023698372788203415, 0.08617556843091734, 0.00656712795716885, 0.07347726583248004, 0.030164349263941403, 0.018755413220787887, 0.026558316785667557, 0.08283312825369649, 0.0055946737666090485, 0.06421280631911941, 0.05316622387908865, 0.005683235176547896, 0.03302846598671749, 0.05781567146186717, 0.030308979003166314, 0.042150704030063935, 0.05024291531299241, 0.018652757498784922, 0.05226381683314685, 0.021982113612466492, 0.026748538512038067, 0.01568335785123054, 0.10794643341796473, 0.01448125116439769, 0.02568629883171525, 0.06579260123544373, 0.026930934291158337, 0.009000966474559391, 0.025730645866133273, 0.007366859335888876, 0.07933826578664593, 0.10029130629845895, 0.03392297287064139, 0.08353216457180679, 0.026156490202993155, 0.044637592654908076, 0.039542002996313386, 0.036816762512899004, 0.046262844116427004, 0.04219090616970789, 0.004277923817426199, 0.03665694472147152, 0.06548953781020828, 0.026668709397199564, 0.021629133334499784, 0.014168692887324141, 0.01867133345513139, 0.046237392161856405, 0.024033732624957338, 0.008780896496318746, 0.052659923312603496, 0.043530916882446036, 0.05470969066664111, 0.10874277271796018, 0.003727166053977271, 0.00884780482010683, 0.05594232745352201, 0.058002332734758966, 0.06774055334972218, 0.051608663707156666, 0.06456540068029426, 0.04869196025538258, 0.06530321421450935, 0.017022698775690515, 0.020150797427049838, 0.035220751669839956, 0.07422903916449286, 0.026003327620855998, 0.020245155938027892, 0.0293702790804673, 0.06084827982704155, 0.06333333905786276, 0.06463695855927654, 0.030246825990616344, 0.01677674361417303, 0.05198075799853541, 0.015562135449727066, 0.036575842823367566, 0.08203614328522235, 0.009704236745164962, 0.03026068559847772, 0.039414976999978535, 0.02639503130922094, 0.031451127579202875, 0.03996339444711339, 0.029592010541819036, 0.027827530320791993, 0.03955681255320087, 0.03611187064961996, 0.09939760464476421, 0.03250479916459881, 0.05271714660921134, 0.06515442102681845, 0.03185470377502497, 0.012218296324135736, 0.05760992215073202, 0.03243911538447719, 0.010312668891856447, 0.02637102283188142, 0.033604380005272105, 0.04730155400466174, 0.03611489119066391, 0.07256551514728926, 0.035632936778711155, 0.04768893282744102, 0.01980350942176301, 0.034455753266229294, 0.011809768147941213, 0.026059155679831747, 0.023222303607326467, 0.017620528415136505, 0.06378737016348168, 0.022872115659993142, 0.0009648322759403527, 0.1428482582559809, 0.04622095359081868, 0.030182689588400535, 0.030723240270162933, 0.03198106925992761, 0.025355659054184798, 0.030181290640030056, 0.022500329359900206, 0.0357272971450584, 0.055193778753164224, 0.029497151081159245, 0.024975197047751863, 0.0696547822735738, 0.04432323003129568, 0.08018381689907983, 0.014203570117388153, 0.055571665507159196, 0.017726883743307553, 0.003761110497180198, 0.04009230549854692, 0.03629202699812595, 0.09160891320789233, 0.05993118196784053, 0.0308496428624494, 0.03356400346092414, 0.07468817624612711, 0.037651084930985235, 0.03563142650818918, 0.04564163311442826, 0.05644763725285884, 0.023564567272842396, 0.012429100588633446, 0.205911559460219, 0.20800308004254475, 0.2508052746998146, 0.22741994907846674, 0.1953197762486525, 0.14439461199799553, 0.09168502045213245, 0.08051908211200498, 0.1264251535758376, 0.12375313250231557, 0.18933889718027785, 0.28423463401850313, 0.1675139370490797, 0.21712288755225018, 0.2072975054034032, 0.15394553309306502, 0.13815789978252724, 0.10942334440187551, 0.07978378445841372, 0.1463476032949984, 0.14888090954627842, 0.104107281222241, 0.11731409598723985, 0.15630691341357306, 0.12232849097927101, 0.13943578902399167, 0.10281053400831297, 0.2418981518712826, 0.11437778870458715, 0.18584473233204335, 0.19181145122274756, 0.19335868069902062, 0.07637613176484592, 0.11715737666236237, 0.09781968736206181, 0.12593177380040288, 0.15727678168332204, 0.1815897473716177, 0.11196785708307289, 0.14065435098018497, 0.12594835337949917, 0.07523994820076041, 0.17819440690800548, 0.2054589829640463, 0.12006733770249411, 0.14257813134463504, 0.10039858374511823, 0.11611983936745673, 0.15705152502050623, 0.20386075309943408, 0.1309935178142041, 0.22680984431644902, 0.15774889150634408, 0.0823394293547608, 0.13102449505822733, 0.15498458436923102, 0.15807841991772875, 0.21448712039273232, 0.0935611104068812, 0.06358273778459989, 0.10974737349897623, 0.15112736087758094, 0.14422301261220127, 0.12640101893339306, 0.09437675296794623, 0.18131393560906872, 0.1501226265099831, 0.18597949150716886, 0.20019573101308197, 0.13050775247393176, 0.09530698313028552, 0.09036398274474777, 0.23185864527476951, 0.11645240316283889, 0.10620634944643825, 0.2375359265715815, 0.14753860188648105, 0.11070171603932977, 0.08322719382704236, 0.13109761144733056, 0.1606198601075448, 0.08323114947415888, 0.22063300857553259, 0.20308047387516126, 0.13584539730800316, 0.21871604112675413, 0.1457420553197153, 0.15959884301992133, 0.11574235337320715, 0.09956564914318733, 0.19008387986104935, 0.15210836136247963, 0.13682731805602089, 0.07741922032437287, 0.1142579763836693, 0.07302693062229082, 0.27356341131962836, 0.11169633493409492, 0.1887795701622963, 0.15534652979113162, 0.195890799514018, 0.17590862174984068, 0.13157104229321703, 0.17557560524437577, 0.12034441853757016, 0.12769403314450756, 0.09617680989322253, 0.0943927165644709, 0.16492393071530387, 0.1257004908984527, 0.08426234882790595, 0.10042855166830122, 0.13945597544079646, 0.17371845489833504, 0.1710483559872955, 0.12245870821061544, 0.09056779133970849, 0.13988327438710257, 0.12649534590309486, 0.19589388684835285, 0.14038407563930377, 0.11514027122757398, 0.1894651958718896, 0.18154726683860645, 0.13401156524196267, 0.1944284568889998, 0.13069401669781655, 0.11929164495086297, 0.19341938837897032, 0.1477192554739304, 0.13827558956108987, 0.16622022521914914, 0.10389958377345465, 0.13306348642800003, 0.1750932092545554, 0.12782634323230013, 0.19008147530257702, 0.1041331524902489, 0.11539537706994452, 0.1439836699864827, 0.18160536215873435, 0.24330547166755423, 0.18069415324134752, 0.14843189535895362, 0.2380573595291935, 0.09509248018730432, 0.11451993224909529, 0.1785285960067995, 0.08753976944717579, 0.09159829307463951, 0.13563759595854208, 0.08182167002814822, 0.06852154503576458, 0.18130397598724812, 0.1283522736048326, 0.2592725562863052, 0.29926220420747995, 0.10247893500491045, 0.17871425166958943, 0.13307353510754183, 0.0882618642935995, 0.10948614493827336, 0.09342534933239222, 0.12188486478407867, 0.2563929045572877, 0.2824733394663781, 0.12967751186806709, 0.08779310155659914, 0.0812544317159336, 0.20606441219570115, 0.10777559102280065, 0.24587992258602753, 0.10102883781655692, 0.13963137462269515, 0.11765857867430896, 0.1047404519340489], [0.06725938190356828, 0.030564841836167034, 0.04867921015829779, 0.02598771283373935, 0.024968391553557012, 0.07085702440235764, 0.03880361058691051, 0.03150432472466491, 0.06768027611542493, 0.041053323657251894, 0.03245281914132647, 0.0016023621196836757, 0.06492365020676516, 0.07341091040871106, 0.026640426149242558, 0.047116043060668744, 0.014090367549215443, 0.013595576765510486, 0.07275177194969729, 0.026873187780438457, 0.04182969918474555, 0.08483222176437266, 0.06428936627344228, 0.06806062679970637, 0.13455288775730878, 0.026057693648908753, 0.032471320882905275, 0.0729222284280695, 0.034470110113034025, 0.027511419939401094, 0.027186969673493877, 0.024738984429859556, 0.04428424872457981, 0.029924989939900115, 0.013218748499639332, 0.0442351185483858, 0.08843131887260824, 0.11942727243877016, 0.02980467110319296, 0.014316065789898857, 0.03296697534096893, 0.006806446463087923, 0.021342248728615232, 0.010258686925226357, 0.06550512291141786, 0.04920822044368833, 0.09969131700927392, 0.05382829753216356, 0.08422001672443002, 0.026210251380689442, 0.04032002980238758, 0.08474716421915218, 0.043537377277971245, 0.07465864619007334, 0.026938687879010104, 0.05890513682970777, 0.017976814961002674, 0.02222589057055302, 0.030076093062234577, 0.014624415161961224, 0.03203808104444761, 0.014887658653606195, 0.021920346516708378, 0.034859414809034206, 0.03524629268213175, 0.012367089511826634, 0.02011833588767331, 0.02353052310354542, 0.017004323199216742, 0.026969592763634864, 0.05983967144857161, 0.058444400419830345, 0.023946767760207877, 0.04593979836499784, 0.009368103219458135, 0.02401925332378596, 0.05156548555532936, 0.054746775786043145, 0.04167853112448938, 0.021986661122355144, 0.0037152933145989664, 0.02856708048057044, 0.0344760027655866, 0.03402095120691229, 0.01666299649514258, 0.03617019232478924, 0.04179373470833525, 0.05796723657113034, 0.0711734316428192, 0.029152289898775052, 0.041313305409858, 0.018562896402727347, 0.01292709002882475, 0.046036555868340656, 0.0525432205904508, 0.04607014918292407, 0.01646152937610168, 0.034637312273844145, 0.01910692961246241, 0.019282332505099475, 0.02370808750129072, 0.025579292268957943, 0.036282256623962894, 0.02910728049755562, 0.022603526849707123, 0.04732236382551491, 0.06615786405745894, 0.0188159631943563, 0.06604559195693582, 0.06839327965280972, 0.05929255647060927, 0.06992953276494518, 0.017259087653656024, 0.045826294299331494, 0.002840333904714498, 0.029615384482895024, 0.048303805888281204, 0.03551912843249738, 0.033914156156242825, 0.09067219667485915, 0.054095448431326076, 0.06425978426705115, 0.05447192510473542, 0.05313571047736332, 0.02231855698482832, 0.038452277876785956, 0.025079338920477312, 0.02911558698542649, 0.036652569760917686, 0.06484856712631881, 0.032993043278111145, 0.02922354164184071, 0.036227115051588044, 0.020463941073103342, 0.06345214205794036, 0.04062167943629902, 0.08005020805285312, 0.009918652485794155, 0.025000400382850785, 0.028882624974357896, 0.028683094860753044, 0.058887399500235915, 0.036151078311377205, 0.02923066811490571, 0.04112841786991339, 0.014873705349600641, 0.02264442289742874, 0.044664491797448136, 0.04483166056161281, 0.020879846197203733, 0.09760888031451032, 0.007768400191707769, 0.006580884128197795, 0.05519170816114638, 0.032871594521566294, 0.023014177568256855, 0.004858104257436935, 0.06155222545203287, 0.0674594946030993, 0.015443959564436227, 0.05068582533567678, 0.020879816511296667, 0.06153563845145982, 0.06472030916484073, 0.024100256887322757, 0.07720104375039227, 0.06667556401225738, 0.04079521582752932, 0.00549964778656431, 0.015707451675552875, 0.026907955543720163, 0.02024902252742322, 0.03594215631892439, 0.008339791747857817, 0.0037262212072164402, 0.028536871359392535, 0.03243766819650773, 0.005003550359106157, 0.052595842571463436, 0.027487632250995375, 0.054751651696278714, 0.051856388890882954, 0.015572041265841108, 0.030186947660695296, 0.04620198429620359, 0.028895065224787686, 0.030357673167600296, 0.06817628309363499, 0.029940163149149157, 0.06580252374988049, 0.06344155903207138, 0.02374563460762147, 0.03811963615589775, 0.05544989762711339, 0.01679537152085686, 0.033563124015927315, 0.027741014455386903, 0.06749546650098637, 0.030766216186748352, 0.07396144297672436, 0.03074558077059919, 0.020611923464457504, 0.014416495996556478, 0.07449601936968975, 0.04928782691422384, 0.00930413658352336, 0.01230099569511367, 0.04840236309973989, 0.05808101523143705, 0.010927114290097961, 0.03089958383498015, 0.02753184198809322, 0.059883357971557416, 0.14007584686623886, 0.06550512291141786, 0.03115672130661551, 0.05960359798336867, 0.009881851237878436, 0.0452886417042464, 0.07982838753378019, 0.09603048805729486, 0.03362054027093109, 0.056152039833250456, 0.03925104399968404, 0.019023482527700253, 0.07718830849626102, 0.05342486605513841, 0.05680411675712094, 0.0541825765685644, 0.10656085854861885, 0.02568104628153378, 0.025631776952650398, 0.03621335192292463, 0.017564919289725367, 0.05477809812873602, 0.04430630535352975, 0.10978574995533563, 0.08107549991109408, 0.031809217543923296, 0.06304833208560012, 0.027023747279599775, 0.018916791377705522, 0.017606449873710517, 0.03701649300637655, 0.04258271190337837, 0.03659065238025505, 0.02026632570050424, 0.03612986402004026, 0.059808315709233284, 0.059106069602421485, 0.019414763191889506, 0.04830107107409276, 0.038265920884441584, 0.047006943641463295, 0.02966520671179751, 0.04514088752330281, 0.06431943809730001, 0.0032710425557525014, 0.05686775592039339, 0.04635108918591868, 0.027439637560746633, 0.06146406572952401, 0.06706331390887499, 0.03922245647117961, 0.012453504259610781, 0.049458520879852585, 0.03441176988417283, 0.012618740656762384, 0.05687762277375441, 0.06910461335792206, 0.04511094928602688, 0.04221068440529052, 0.039158275540103205, 0.016133537210407667, 0.03753571065317374, 0.04932656331220642, 0.05933138192631304, 0.03959783476602752, 0.09609771179384552, 0.021721155935665593, 0.04470687956199981, 0.010725380925578065, 0.008150561716320226, 0.006687589657303761, 0.08589491044403985, 0.042745242244564, 0.025213341104972642, 0.03831941859971266, 0.015137011923798127, 0.018567642437119503, 0.03402669542992953, 0.02773536671156762, 0.10252329317154363, 0.044820825205533765, 0.09724876799737103, 0.03574068919988349, 0.0662893132539466, 0.1348222279921174, 0.014203932842065115, 0.03821316531684715, 0.042772367742145434, 0.04224122007144615, 0.02642227555043064, 0.07976190594490618, 0.025771068794711027, 0.026447770178492647, 0.0467240517900791, 0.024248866393463686, 0.048962135406327434, 0.03005193058925215, 0.02595282447146019, 0.0342839646327775, 0.05174651763809379, 0.05060613351815846, 0.05288697597279679, 0.04246032804076094, 0.03851342342386488, 0.03160987296723761, 0.051141173753421754, 0.0467537748045288, 0.053243210568325594, 0.034471683466108516, 0.02706196788494708, 0.08698127363459207, 0.06051667711290065, 0.028233947086846456, 0.03992357822426129, 0.009860702812147792, 0.04304533336835448, 0.022567113373952452, 0.02593613728095079, 0.043272126276860945, 0.0192362043162575, 0.040156367685995065, 0.02309832412720425, 0.04225631164445076, 0.025937074242392555, 0.041399606052436866, 0.052422706939978525, 0.06896492632222362, 0.02183577136747772, 0.058298338335589506, 0.030017378048796672, 0.04197774651402142, 0.016018537717172876, 0.019055057200603187, 0.037248135849949904, 0.04279443179257214, 0.019422153127379715, 0.03324759622046258, 0.07555178381153382, 0.01486715218561585, 0.1457586052129045, 0.10093618067912757, 0.15417441143654287, 0.10578372603049502, 0.2265255869133398, 0.15670544671593234, 0.265222413581796, 0.12169348716270179, 0.12994983553653583, 0.12111841177102178, 0.16111355158500373, 0.17089796718209982, 0.12758035096339881, 0.2385989937465638, 0.18668524426175281, 0.18727839837083593, 0.08066731126746163, 0.12443020124919713, 0.19332693162141368, 0.13096154609229416, 0.07216586862341501, 0.13315724936546758, 0.1243306124524679, 0.19966733671026304, 0.20893639011774212, 0.08484333171509206, 0.12115212753997184, 0.179731483804062, 0.10259007904096507, 0.09368140512378886, 0.06890564356581308, 0.17517475644126534, 0.16029907419579104, 0.16231967514613643, 0.08607720417785458, 0.12055557439452969, 0.18638586188899353, 0.2520462346728891, 0.14141163846943527, 0.14818171737715602, 0.07976065913680941, 0.06341188054648228, 0.11767649411922321, 0.2388530902680941, 0.10571740771410987, 0.14364522096002474, 0.18216436263173819, 0.16239831311395392, 0.1327941461931914, 0.12719024845864624, 0.1585267810150981, 0.11227043811231852, 0.12162037819507532, 0.31619908288121223, 0.09382362288306467, 0.110468926577596, 0.1196463024825789, 0.09574479830916971, 0.12793472647899762, 0.12553718872368336, 0.4911452578380704, 0.11385093064745888, 0.08741298835957423, 0.16085365146864206, 0.12423658234183677, 0.116221587813925, 0.15054480463732034, 0.16055769781814888, 0.1306857046438381, 0.20673705032095313, 0.12419341161148623, 0.17943661368917674, 0.10014511804911308, 0.14022513729287311, 0.06163227721117437, 0.10552966661634855, 0.11864436601172201, 0.13865032960893586, 0.1110449073894415, 0.12419402017258108, 0.12877201748779044, 0.12007225814159028, 0.17277373059187084, 0.10265345103107393, 0.12191639121738262, 0.09314759314293042, 0.11631960325757973, 0.15211987949442118, 0.19614718185039237, 0.1668320517637767, 0.14184447383740917, 0.1358003934728913, 0.13293880561832339, 0.10065646521979943, 0.14914017141563818, 0.09042408928507939, 0.09076495771296322, 0.12340661633061245, 0.1244498830055818, 0.13819322601193562, 0.16281715157674626, 0.09882247730274685, 0.19329515285789967, 0.21570430195424706, 0.16939304012339562, 0.14184248488163576, 0.13308536494150758, 0.1166058867238462, 0.15892632363829762, 0.23503549746237695, 0.10358741419622675, 0.1437282672850415, 0.11205402784980834, 0.10380266670836136, 0.11737141205230728, 0.14260891563026235, 0.15540107764536515, 0.07945367717184126, 0.11757439686334692, 0.17731800471665338, 0.14794525428442284, 0.2431760262697935, 0.1307424937840551, 0.1932943958672695, 0.08708468449185602, 0.1408901609829627, 0.1304731980781071, 0.1774942796328105, 0.10279265567078255, 0.1238508807728067, 0.19915589306037873, 0.1421544243930839, 0.12178025906905532, 0.10972436692100018, 0.14127723552519456, 0.1878472842508927, 0.16218395117903128, 0.0749529671156779, 0.10223950332147069, 0.1620843994896859, 0.16855793102877215, 0.1245612496859394, 0.13676717440830544, 0.10748679909738712, 0.13939216558355838, 0.07635309550096281, 0.14984115958213806, 0.11303613413474523, 0.12502191559178755, 0.11642206416581757, 0.2500739030074328, 0.09274684824049473, 0.1455964014166966, 0.1352768379729241, 0.1395547849824652, 0.074926650559064, 0.1326417239033617, 0.14375056140124798, 0.11311738446238451, 0.12532937253126875, 0.14480078942142427, 0.12075303020537831, 0.10850008300621994, 0.11857392135425471, 0.08285232761409134, 0.1181637511763256, 0.10558304187725298, 0.19756909226998687, 0.08573239494580775, 0.07882814315962605, 0.1920515508390963, 0.1398189301835373, 0.09703100702608936, 0.14095910650212318, 0.1720182242570445, 0.09319540229626], [0.018522360296628904, 0.030547286332875956, 0.006716327006870415, 0.06642951237154193, 0.07008539119851775, 0.022794785727455746, 0.015930300069157965, 0.02682278853171738, 0.042209931125398725, 0.004886403739874368, 0.02713085588766262, 0.019456809568509925, 0.029692586394958198, 0.02672596794582205, 0.005535900309041608, 0.03163396679155994, 0.029805609920003917, 0.06456172704929486, 0.05131226105731912, 0.025485896694590338, 0.06159906610264443, 0.025464354002906475, 0.035358000750420615, 0.05603099925792776, 0.05944153148448095, 0.038421441640821286, 0.07831681083189324, 0.047950640073395334, 0.027042393739975523, 0.03723893692949787, 0.02787394423648948, 0.03604374891438056, 0.03576541013899259, 0.0122347924116184, 0.05391661310568452, 0.07525067223468795, 0.07733975857263431, 0.03783410968026146, 0.08660671912366524, 0.020891095300612506, 0.04781280840688851, 0.03175373458361719, 0.03341560732224025, 0.022114824460004456, 0.033646897645667195, 0.04424344915605616, 0.04742185614304617, 0.04660790567868389, 0.08493039305903949, 0.02223980027338257, 0.010741736932686763, 0.019874414210789837, 0.0724254793021828, 0.027572461585805286, 0.029499345982912928, 0.03781209758017212, 0.04642381223675329, 0.020322480304457713, 0.017229917539225426, 0.023502939329773653, 0.030229214826249518, 0.025312907637271564, 0.02606529880722519, 0.03412087768083438, 0.013330376787052955, 0.01777424204192357, 0.024813308664306533, 0.03799279569648206, 0.0664950514328666, 0.0851951319782529, 0.03722306610143278, 0.018157188387704082, 0.008191314900614088, 0.022842177422717214, 0.03181504340318497, 0.061111456525395624, 0.02148060917534167, 0.026213121636828873, 0.03205777764378581, 0.033181485705426894, 0.03354793596372474, 0.025819082038651686, 0.003472215830697678, 0.06113854862633161, 0.012665696340263821, 0.029346806804824155, 0.013155798606021563, 0.049510367316543125, 0.03141924120427575, 0.050459503690944985, 0.032304452688549645, 0.013677500592166325, 0.03805764456046745, 0.0335947766143363, 0.1367643245612271, 0.003984175737059559, 0.051115881360601634, 0.014352317848533858, 0.031528611507383175, 0.04374830677988939, 0.03418262807826977, 0.03246127591410186, 0.06479648320237175, 0.013589357567980187, 0.03910367944627069, 0.06270163037697785, 0.040670471935300156, 0.028989175116294064, 0.0559482609241968, 0.01322391477515339, 0.03388606586668175, 0.008874292998370947, 0.07577114782179706, 0.03559082731953822, 0.022972758306423202, 0.04325126079493202, 0.04105847045138944, 0.057283892965642735, 0.054948851466178894, 0.01574651090777479, 0.051971629582112655, 0.044653036748059094, 0.09245801920769736, 0.04062410254846327, 0.00933536894081044, 0.017348664878227282, 0.007698082163187792, 0.01778207726601977, 0.042633489647414535, 0.09393488566274755, 0.015543614226771751, 0.04189332350506447, 0.08345334848854691, 0.052953895428800024, 0.05178540617635008, 0.01623736181500135, 0.03827633321634494, 0.030529625073540956, 0.11114835535408929, 0.038340306346071884, 0.04370002636278514, 0.0328408955829218, 0.025509875486022793, 0.07170927710831165, 0.06109856170951389, 0.041155287326546386, 0.044442307626013644, 0.02544037706684321, 0.07405523560009897, 0.013303034211276099, 0.010303214858140564, 0.06781507981941104, 0.073046055767918, 0.061522747346316464, 0.09091173968045041, 0.015040267408039654, 0.03765977919101715, 0.04638923557649832, 0.039657080415054224, 0.011093950943177333, 0.022044203542463947, 0.04907463015115354, 0.04328089846239891, 0.05357758520403877, 0.0020616006668205955, 0.031258002200047486, 0.03357468667672947, 0.03416152510908432, 0.02289282714627916, 0.026590917477733456, 0.05075889719591942, 0.03605334117310122, 0.06972751274588518, 0.01568802967085503, 0.011328486307320418, 0.027219353287364356, 0.032703486940590665, 0.03780137725698296, 0.0174028398032533, 0.024850195259205066, 0.038573459460167214, 0.0902984214189928, 0.05910992877034005, 0.04022983288450632, 0.017744246288202703, 0.03399435634491965, 0.035414496742305346, 0.017305772453255486, 0.011320906196488068, 0.03682097049022559, 0.07302575802896172, 0.010418205074529396, 0.023347975184151437, 0.09957701884559356, 0.05583194782957435, 0.060080728435423225, 0.02360594015044626, 0.02040384195424849, 0.03997939144028351, 0.023359818005701527, 0.045139622161514126, 0.04252336606441531, 0.010643542445905041, 0.034349811685387976, 0.03798500314587727, 0.05279777353280224, 0.040543687136960216, 0.01823280024837004, 0.023069779272191226, 0.03946434095269069, 0.054463394117192365, 0.07108156860340387, 0.0595361553132534, 0.07692641200264916, 0.09876840442302637, 0.12185619561932981, 0.047662393626524135, 0.019169602128386032, 0.03467771479336079, 0.07570919333375059, 0.027487953229865525, 0.04012233279354405, 0.03787763664149679, 0.010560476639511762, 0.09886423053103499, 0.020280560092942324, 0.022318286100926343, 0.008702912546141306, 0.0649132824037224, 0.0481825241149636, 0.060282518388703465, 0.059619286985252984, 0.02773275806248421, 0.03857945601339452, 0.05131308855197858, 0.047216719103744254, 0.07838770077796653, 0.03629028666182421, 0.037600659707095474, 0.06528025958687067, 0.040774728840915486, 0.0412278545263689, 0.030637793097412214, 0.029735068783338647, 0.08526850811904296, 0.07917464448837563, 0.007087804851835244, 0.06511316503747366, 0.009945671299647074, 0.0369947258150205, 0.022620009949605446, 0.036739727584063075, 0.04310358825023286, 0.0048426086777908495, 0.030447374701907393, 0.012893206348962849, 0.021879940286453348, 0.011698872731358279, 0.011441188853495987, 0.052332231716718525, 0.052942971014999785, 0.057099283731076866, 0.018165834408137016, 0.027004041403415613, 0.042138447461184114, 0.09077390801394358, 0.04740559197671246, 0.004809242645933409, 0.025931819836841896, 0.0199923637410393, 0.018691022632992826, 0.03996323859610129, 0.05521246603166219, 0.011763125094148563, 0.06098202597058844, 0.023886646376922727, 0.022251828631851822, 0.04355238350399304, 0.04879807253018953, 0.0630171321972739, 0.01575427933858009, 0.036497668697847985, 0.055576726954313926, 0.08536036373698153, 0.03080401562328916, 0.05032249951909762, 0.005604189027508255, 0.04877961160673294, 0.022040941803425085, 0.04443229605385568, 0.06586061164853163, 0.08550819955416955, 0.06629017414525151, 0.011902848309546243, 0.010776934213936329, 0.08880937632056884, 0.06026952338288538, 0.037319860712159425, 0.04829154189792462, 0.004186576106803841, 0.04177569309831597, 0.010133319628948811, 0.028215519560035318, 0.024841642007231712, 0.033859704781207256, 0.022388346696970984, 0.07021692945272662, 0.005737533019782859, 0.05981347363558598, 0.01774077860318357, 0.07080668452545069, 0.029052613899693824, 0.03570066146494355, 0.021360258797358256, 0.021311546079232357, 0.07673001746297814, 0.0172045602084836, 0.01736440768581815, 0.04866316863626707, 0.03932671337679494, 0.030893314542481676, 0.015807521012902725, 0.041477182749076746, 0.028153618877695408, 0.0390338062425144, 0.030616905351052992, 0.08372768337721936, 0.014068912987568183, 0.12393122568028048, 0.03005586582730757, 0.03817791701294482, 0.0516942630201811, 0.027659977495204657, 0.0799704271776136, 0.03255874587921426, 0.026568278262857348, 0.04847671887546312, 0.06092087671277113, 0.016846479520609137, 0.03610825267969631, 0.014826149454165716, 0.10299169225618243, 0.0331136274326127, 0.006213055794432876, 0.0323457606282318, 0.07219516861368902, 0.03685050796775613, 0.037856719209230505, 0.038133833440952, 0.028581606165971607, 0.03216453558707144, 0.08038907268201001, 0.1544464085600339, 0.08960398641647771, 0.12938997417222708, 0.15662289020838216, 0.1893889921484515, 0.18212210474302992, 0.0639552365464624, 0.1750723400618881, 0.10909723729128018, 0.07326430655666627, 0.1574852064368315, 0.07667978890822269, 0.1183609694999177, 0.11686912650475278, 0.15371534856967628, 0.07663174226763658, 0.10100763465743512, 0.17581702588358894, 0.11319078286760487, 0.20156996586592868, 0.1013330441492144, 0.12461103295208886, 0.16814195725601166, 0.1395576645154506, 0.139243038429413, 0.13632703630719334, 0.09825999615713954, 0.14091557211941108, 0.0918939572875388, 0.0938299014524091, 0.12913497223053128, 0.1704982464434579, 0.0888842144922819, 0.10132873227121308, 0.10623766065691598, 0.17445894016418606, 0.17010278563247994, 0.17189756588777527, 0.21344064763979986, 0.12229567320900969, 0.17371395748341456, 0.13018325582379475, 0.1505798933794722, 0.3004780499031767, 0.21226377954008058, 0.111968361743493, 0.15390106360428035, 0.16107993229525164, 0.2536936243996024, 0.09946102858521044, 0.09884938015602529, 0.16878832335351035, 0.2452181643457152, 0.22008634259691462, 0.12427906287484802, 0.0837959980708547, 0.10236989124678075, 0.0723187807307113, 0.0709240477590356, 0.16131574229802936, 0.17312837328063324, 0.09303204817115329, 0.1852813086588867, 0.16930093959672377, 0.10456171308760531, 0.15201234229607508, 0.0957512624154333, 0.11607937747612596, 0.1416181930107996, 0.19007981289178133, 0.0626487894624006, 0.15622547012753785, 0.1580556805129163, 0.16716460813768208, 0.14699057035613805, 0.23879263491835445, 0.08378929647733457, 0.10957068298012018, 0.09279885052819736, 0.1595963494037278, 0.1361224113497883, 0.1271262308000587, 0.10023617956903763, 0.2120001835282892, 0.1010267598030623, 0.1949200258241035, 0.1321066205855459, 0.14387665229151025, 0.1455560582689941, 0.32785881659947336, 0.17506104457424954, 0.08104924272629432, 0.27619082189630717, 0.11265318593359552, 0.21898118080571294, 0.13664895028341562, 0.1610040699597448, 0.09962177035049535, 0.2021149397478439, 0.10888171760598198, 0.11269780385191552, 0.1615735495579429, 0.14735915057826787, 0.0975761516019702, 0.19926200533518568, 0.12396332356729545, 0.2437771065160632, 0.12810193235054612, 0.1703899967833422, 0.09469589873333462, 0.10419000842375681, 0.2167741523589939, 0.27257745328824967, 0.15202451351797208, 0.1439595501869917, 0.14188221946824342, 0.18480869417544454, 0.1305524297640659, 0.09160900968709029, 0.13127381214872003, 0.14767965447390452, 0.131465345621109, 0.19963168393587694, 0.07775979931466281, 0.08488414241583087, 0.1043736825522501, 0.12323148432187736, 0.10419000842375681, 0.12197997100884095, 0.15181803319137543, 0.13066707673715428, 0.10231932130409405, 0.19484812655718997, 0.10041466608527116, 0.12133258074754849, 0.16373204154660925, 0.12000683040241711, 0.1540578348794952, 0.16442957130493596, 0.150207988335751, 0.10021139183663763, 0.10299191490048543, 0.1585331337992102, 0.09333392416010611, 0.20872486318694428, 0.08772633053013124, 0.11219053107197396, 0.06791224179323763, 0.15026250650407746, 0.14852925029117614, 0.17198910238221288, 0.1475888304412365, 0.17681169672869146, 0.1941178532433696, 0.11988254293100908, 0.11979975635767914, 0.16098965745186433, 0.1881544740172103, 0.17590148228919134, 0.10929103431408294, 0.09452151629375294, 0.14491214125882834, 0.17183638323331252, 0.13263569766422734, 0.16358074732124805, 0.20330311817815527, 0.14921852736733854, 0.09160201123449951, 0.13779636996332556, 0.14655154547654092, 0.15269553376128897, 0.21693277900340036, 0.1780412276275456, 0.11979519214946777, 0.13861206447472796, 0.09999195361160673], [0.06094193515309598, 0.03725891925569158, 0.03222533232474234, 0.06392428898834623, 0.017896958015626296, 0.02420961049210746, 0.043313842397765256, 0.08471304769045673, 0.0519252750382293, 0.021394533032434992, 0.04158700205152854, 0.06322229892248288, 0.016771403861639556, 0.03923177042452153, 0.020171690739516634, 0.03942878836824093, 0.08683930820552632, 0.02066673663648544, 0.0515225634444505, 0.04605797796102706, 0.11675785630359314, 0.01836134022596525, 0.05760942862252705, 0.046358759282156825, 0.02458735809341306, 0.041787738155107945, 0.02743747791100759, 0.038353357012965716, 0.05370482642319985, 0.06261051690671593, 0.023816771317797247, 0.06425844097975641, 0.028205782582517713, 0.02864571288228035, 0.0035428123965175473, 0.03221935061446857, 0.026106213408638723, 0.015624757870682515, 0.023014524522295687, 0.049735033971956, 0.02508735782612348, 0.012207218842377188, 0.034876788486144505, 0.007344410760197206, 0.028647453218582086, 0.03306054160930216, 0.05682508613972459, 0.025296302083006594, 0.06516021720017307, 0.041567034568288364, 0.03252614704251755, 0.02177678547013784, 0.02924954464106122, 0.05268798762699589, 0.0515045032807393, 0.035248533968115225, 0.02035047597019002, 0.08197877526981756, 0.008676331599417608, 0.056610449610161595, 0.04379832011181861, 0.06539718495332636, 0.03592033346649259, 0.03782422798394691, 0.09214159712428227, 0.011899598630407127, 0.037798579360242, 0.04802869545528665, 0.023364729167951737, 0.0017196487033288577, 0.038063811807660386, 0.023579942717333324, 0.019657543816720136, 0.04965775413438678, 0.009650925494497642, 0.0328143823571736, 0.05791042887722142, 0.029903220893174876, 0.019046806373808067, 0.026821877545444295, 0.02368367826420581, 0.017135588714154437, 0.018368273740634322, 0.06349250004859641, 0.037505226937355474, 0.039888478349894285, 0.02770139490166912, 0.022568542008229997, 0.0403899178490974, 0.035496993878041394, 0.042853859267779626, 0.057658150617498904, 0.03483716522168834, 0.0895384993054904, 0.03783566447964404, 0.02621561896376079, 0.050571838874020614, 0.05760408515925519, 0.0553621423750883, 0.010992836105288006, 0.06846318254247308, 0.06468211824540049, 0.02571259312389884, 0.03809623623965308, 0.08416962489718571, 0.02290066608111374, 0.07910467480542138, 0.0425374668702716, 0.01207848126796307, 0.031697810045443475, 0.030055363022256643, 0.017147759936051443, 0.05137116902915295, 0.10159760495298542, 0.024468319461448118, 0.062056347815087065, 0.07657121270312928, 0.058860856588580646, 0.04889012110652402, 0.022930609884497244, 0.032497129068360664, 0.025109670496021863, 0.03178810715326108, 0.03996255210950039, 0.015630164416506886, 0.03498899008263834, 0.02175967896619113, 0.023752709130349103, 0.05458877254568506, 0.032042392922448926, 0.028630298475036398, 0.037640390582964756, 0.04054231416375842, 0.010946339625661494, 0.03271542809670791, 0.024956483794085216, 0.024018065887503326, 0.0566364099358907, 0.04648327310860623, 0.020336746238172054, 0.042418845696374774, 0.006599770858883858, 0.005141407073097071, 0.013070811564830365, 0.08481737138936296, 0.07725148752797395, 0.014602309365727706, 0.010073065586766461, 0.039683014765614644, 0.012036873686156468, 0.020046379104314838, 0.06256915701669641, 0.01541933510452509, 0.023308941927098203, 0.028031110705342144, 0.042017173109343275, 0.019983960773970466, 0.032370826666010544, 0.014896531956765102, 0.01778836882294854, 0.005951261346126557, 0.029338472486415412, 0.04535540530923754, 0.05841419872012921, 0.0542675413453253, 0.05563819533563219, 0.04520743590546772, 0.033408156159566715, 0.056588151783216745, 0.03734763929969631, 0.039042199932737276, 0.07591309840790927, 0.026416035943839233, 0.02650026599440025, 0.03324093544506468, 0.03132035373710096, 0.02569109867181396, 0.026734799503174145, 0.06819520785938948, 0.016757629600760993, 0.030365875754796434, 0.05615579510049429, 0.012410010695020901, 0.0755772394768428, 0.03312368724436965, 0.033962421730393544, 0.00780028100052732, 0.035431952055660076, 0.014309668476926163, 0.019904825567209627, 0.027719891077140346, 0.03441278662648983, 0.021070531765872147, 0.06928845818038099, 0.045055113805574365, 0.06108608991780784, 0.023202824086183682, 0.01012867007375462, 0.054615263507002965, 0.009378894046676578, 0.03518116180202924, 0.01830883884395007, 0.042936734898830764, 0.025368121569044888, 0.0376616048743017, 0.05291528890666086, 0.0687176501378417, 0.013056454718025634, 0.008883161663106875, 0.041440090208197944, 0.042167573046754114, 0.02789484497043304, 0.057877084182109684, 0.029850159189663827, 0.03331909843836911, 0.026697243119997438, 0.03172929194988683, 0.01121166484153946, 0.03314371781016234, 0.04997202027880121, 0.043138124092365615, 0.04221171227982268, 0.04420437879161909, 0.06926432353793643, 0.032763274357421324, 0.044309166332823224, 0.06888672622153535, 0.01792353989003459, 0.01245981900865445, 0.11399622831959277, 0.014623511597164907, 0.03333050895889755, 0.04934866075927857, 0.028793272249458823, 0.0510011341975769, 0.03374842715857085, 0.07352647764491849, 0.032361189878429286, 0.037223396357148886, 0.056113262617145665, 0.054427062277682126, 0.049710068124113604, 0.012605984993570019, 0.012221905944898026, 0.004298267940612277, 0.04315032500016969, 0.07521113802795298, 0.05231761882896535, 0.05916685149713885, 0.02531449583329959, 0.012654133679461665, 0.038439698473666795, 0.042164738042629324, 0.03920900133380201, 0.010650878575688694, 0.035394985679886304, 0.10330605859053321, 0.0211992832555552, 0.04076728509971872, 0.09731174664921127, 0.06377758865710348, 0.060921437034267, 0.02735202888288768, 0.02306341535586398, 0.04194954119157046, 0.044405471126083285, 0.023881226843514014, 0.020809260531677864, 0.04755796973768156, 0.08817498848657124, 0.030559173683286645, 0.03227577239158563, 0.03397854117793031, 0.020819338897126727, 0.08459745818981901, 0.058016596813104115, 0.0601218768133549, 0.039133717873482965, 0.032462530143675394, 0.03860681157675572, 0.02011709464568412, 0.038391718626371585, 0.035389720142120495, 0.03557830728823319, 0.047504086105618626, 0.021787349942314904, 0.04677117816754617, 0.06585726456250995, 0.028426558528735768, 0.017709181665850338, 0.0726048563956283, 0.03910155690391548, 0.10818505616043694, 0.030277272599050775, 0.017685748352960218, 0.022597036768274847, 0.0641708452894818, 0.04404802682984155, 0.04979802375601139, 0.024733041682338808, 0.011978288548561977, 0.032011215298553, 0.030829862771497574, 0.04989822853531223, 0.01846315175498603, 0.06477785529568791, 0.032541012260480784, 0.031815113907214254, 0.08032712561544031, 0.04002011308330111, 0.03961889691709075, 0.007340584061239497, 0.013211144269007491, 0.031966111273504794, 0.035070741359959356, 0.023940121827763505, 0.043279518067720346, 0.02866261529561598, 0.039414839702658355, 0.04444751379196532, 0.022729335723852273, 0.020718397536256816, 0.04305521506466903, 0.03919710099580698, 0.02114529015670996, 0.021558998523687478, 0.10979148675687611, 0.025674788121250458, 0.031091466116777156, 0.04885090602329001, 0.02750490944890771, 0.04751367094286252, 0.033103485984611325, 0.05705784962628968, 0.06006779280141927, 0.014446482473431388, 0.03935011329303961, 0.06170340835524257, 0.03604931873269379, 0.044598711538128555, 0.014256833128456492, 0.06816009685280733, 0.03678933273477014, 0.03345146789797582, 0.01964475290151313, 0.043060732932644896, 0.009440875437576324, 0.13301684986799955, 0.04333520140789915, 0.06091015638958197, 0.034829176001949236, 0.05188514340261463, 0.11996418659691699, 0.18933487473987043, 0.11544467051862739, 0.10820689014508389, 0.09583980805473402, 0.13177986780647188, 0.20417647756403312, 0.20087565702851862, 0.10004805997596122, 0.16424731467850506, 0.1015734406246338, 0.11235246027354151, 0.08248048194218427, 0.1262418579426594, 0.11885449770488776, 0.1384457343374379, 0.22511243383632973, 0.19829050434054807, 0.12484234553994611, 0.11154875886859372, 0.1975043473066762, 0.15212378319120035, 0.18170108436606824, 0.1547531085088849, 0.1050839846720919, 0.09390316627104767, 0.05625957332085818, 0.11164648487465456, 0.13083526224363595, 0.11294711352093145, 0.16761184117058292, 0.11346285420586355, 0.09468819524045102, 0.1611322833923623, 0.10739878038293682, 0.14412389136850834, 0.12116023179260083, 0.09831831412157044, 0.09254200806026347, 0.12059378015692346, 0.09831461080466397, 0.11501595407025889, 0.08436195246758871, 0.1545191984041594, 0.12007927885861136, 0.11337013769662008, 0.16988018585834652, 0.15452069754246622, 0.1351122444611974, 0.14101187320193276, 0.14232335204724222, 0.12618526176083833, 0.142773256811779, 0.14808235864620656, 0.14586713688913733, 0.13840605912264436, 0.17183990101329982, 0.14788937056437135, 0.15231484168907627, 0.12477866926928982, 0.24056423048023134, 0.1372096873819828, 0.14833929017186165, 0.08434522445895709, 0.19800511887297034, 0.12015268468530849, 0.11830584277049638, 0.08805696474155411, 0.11418990659876727, 0.08384322092751972, 0.13266058929730207, 0.19717404706170782, 0.1225989221711643, 0.10948802257189527, 0.11862766768899746, 0.12147565939812921, 0.11081910895882174, 0.11145063952426426, 0.13722791452892125, 0.17154381377622485, 0.16750391805544496, 0.16827362909680232, 0.13965484133223072, 0.19292422744911164, 0.13787848118226975, 0.12404763154336251, 0.18542581965448335, 0.09574640876962803, 0.16522677149623632, 0.12077579929609783, 0.11855664415634237, 0.14625311305280775, 0.1264826106489636, 0.1991190083208494, 0.1304680624161847, 0.09549370006425306, 0.1326940007857047, 0.25605113070923835, 0.21608134265989065, 0.17291530268266797, 0.18069997167913243, 0.13039930985542014, 0.09465052382438444, 0.10254628490656614, 0.19581928616389632, 0.1242340293538291, 0.24207917653257027, 0.11759044209611602, 0.1396577653940767, 0.11595575793762691, 0.12162153594545089, 0.1350331463618204, 0.13440508162602782, 0.14014298154506832, 0.17478030495112762, 0.14519268792355433, 0.12974945566384122, 0.1910812224377878, 0.18266158673213795, 0.0630320716300048, 0.12205809689476155, 0.14847584534436464, 0.12069014803273603, 0.08021594447200187, 0.14855932211503386, 0.09503167602815665, 0.13290955015690997, 0.11841703875688836, 0.14277224749093875, 0.1551545361871831, 0.10954176890663803, 0.22555375937372446, 0.13553541706642136, 0.09824482665862888, 0.20826952590141445, 0.07115093714674003, 0.09106809535296634, 0.11768330703489482, 0.090305946796434, 0.08609651486040093, 0.15014207077911124, 0.08697955927345902, 0.1490230011404492, 0.14549184765201062, 0.20783879823284224, 0.11315821742755361, 0.12831237574573606, 0.1590509747620672, 0.15084524085978046, 0.09606453037122265, 0.1791785837849602, 0.15216816362226382, 0.20885880599962547, 0.11264600936556235, 0.08915773301851004, 0.17415356123819947, 0.10126998386112973, 0.3117929521249607, 0.12853028514655307, 0.11316318981698714, 0.13148870842996985, 0.18018391187069938, 0.1467321693780832, 0.10748958215117455, 0.13905034720664844, 0.1048160322534386, 0.147703759430442, 0.1981562646687962, 0.16331807157257572, 0.13058187818387523, 0.16184415144380182, 0.21592520963167772, 0.1358019668259658, 0.1553270113072358, 0.12857646157499403, 0.11701446870574728], [0.016234829236054793, 0.01878942955954699, 0.03967362659750506, 0.033544785546837375, 0.02219750156655209, 0.07800178398611024, 0.040894121848396026, 0.06051795731764287, 0.030646906670881435, 0.059841181719093584, 0.061313361511565745, 0.02817302603943972, 0.05546174230403267, 0.09097597256186418, 0.07668566671782173, 0.06623368186410517, 0.0230407260460197, 0.07705283685936593, 0.0642948952736333, 0.058706667987280525, 0.031800081706023775, 0.04333397686423268, 0.06766040140064433, 0.05224494401772972, 0.020707849762402475, 0.047206265953718685, 0.05985064781270921, 0.029063605106784962, 0.03367092467669863, 0.03812577371718362, 0.06145411352918018, 0.041745094349607825, 0.07401776456390508, 0.028256829355086666, 0.04030336487630848, 0.032618084296700545, 0.06035419872205239, 0.02427640007226728, 0.036241208435967565, 0.03060437233216362, 0.047989109298214316, 0.023595308884978294, 0.031073174031917006, 0.061199679330457, 0.051817374187521636, 0.014962688856030582, 0.05516679055290297, 0.05286830353725236, 0.04981092599336989, 0.02158555627829628, 0.05359409056836739, 0.10637970030074939, 0.07733212929451838, 0.012271089926798595, 0.024116730710375123, 0.0587348028057022, 0.01637764256884111, 0.024712803315196652, 0.05819801110192202, 0.061989239111426286, 0.01103173670344404, 0.05311188753694296, 0.08838103836751543, 0.01634986027056584, 0.03569008957128972, 0.009699515758256894, 0.024942989693954587, 0.040227012723335065, 0.05292055073368829, 0.02425645670882659, 0.026969331156578846, 0.01031103709465242, 0.016734947712393478, 0.04254899613442831, 0.007787090253259521, 0.027926072689297143, 0.05636116962705273, 0.034357374170213006, 0.0241631464814418, 0.0467297626164509, 0.030612751179432962, 0.02405692659522174, 0.004203473881716491, 0.041774082637857646, 0.027189437314518727, 0.026533475247561, 0.03222535458917264, 0.01748522561683785, 0.05816381664772052, 0.056388232042081654, 0.03367223085660953, 0.012468269287637668, 0.03905425241100602, 0.03745684261957649, 0.033638429740676656, 0.070717025664635, 0.09468652540817857, 0.027228511389694177, 0.020418052226887085, 0.027781949465861544, 0.059917507896898314, 0.047305487387347966, 0.036647864544647746, 0.056428018579026684, 0.05758769853855483, 0.06712329428410158, 0.06765387792256661, 0.034107556130038574, 0.013544786961574573, 0.03540209545462858, 0.022243421954044607, 0.0170256673663971, 0.015190171961876331, 0.026371811363787856, 0.016161486491910182, 0.01962818445463199, 0.05970479724055622, 0.008079372128122486, 0.032392400898970664, 0.003920490653399611, 0.04685361964220647, 0.07893353555118665, 0.03596917420509271, 0.04704741295427084, 0.03285578677605372, 0.03201868130418006, 0.0268287813742063, 0.07535629469202831, 0.010076594498968916, 0.07936982190585695, 0.00518521744197642, 0.006360770084938849, 0.05712633872462902, 0.10417815632536076, 0.04908448587229941, 0.0197703799494775, 0.047288455098168924, 0.025250813996535726, 0.054570163192693144, 0.038522692848346196, 0.015034426705824444, 0.034837265411624685, 0.0774874236958567, 0.034518824686529115, 0.03630079547292553, 0.1046761151519604, 0.03537849144777283, 0.02476727509929333, 0.021121411555213854, 0.08490150124998763, 0.07887308762292378, 0.04245715907018166, 0.019870857468049508, 0.03226320040994324, 0.11411147643229924, 0.0843248821911402, 0.02132436668034643, 0.07297694697626866, 0.025673763957456686, 0.012273485208424972, 0.028602373313333374, 0.10218410941888578, 0.029305860662134364, 0.03494557815429289, 0.02979940556542715, 0.057837423810269684, 0.04168182254943531, 0.025318909756606445, 0.024069019891612697, 0.035238229247624986, 0.04686471846071072, 0.06958259356906638, 0.030479611741611734, 0.035637241235235706, 0.020210941074765287, 0.04198893810098525, 0.016837527364259586, 0.05224806474871002, 0.03995877457782626, 0.05479726038174704, 0.017159363414975815, 0.057039655875996687, 0.027033693913836032, 0.04910454612399917, 0.030194165046850685, 0.04035622063383926, 0.031590810904162936, 0.03669841964438092, 0.05416677624452859, 0.027856980595970526, 0.036895853190799244, 0.06208985207194928, 0.04215915709210094, 0.025872982369037345, 0.006345793080981821, 0.009877261982182972, 0.04202224197797477, 0.0651848416600842, 0.018842281606339384, 0.05673590967489872, 0.028610431181732565, 0.011238603874517139, 0.08487116225296631, 0.030233075849537272, 0.05627380400255788, 0.05942872943705879, 0.045448273958754726, 0.032590624832664616, 0.031193208997137845, 0.055197381880134344, 0.003649980144473375, 0.02335706834855955, 0.016478990255563986, 0.04840710542339366, 0.04255207233654801, 0.0362771209620405, 0.03764305489312392, 0.014429461316467496, 0.08812571730231866, 0.10022286543971859, 0.042103058149223216, 0.045702611678279936, 0.030720089853275567, 0.0536500596354017, 0.06786613957956433, 0.033607523000682704, 0.06530135142384097, 0.014202160036802525, 0.05354900880774949, 0.029526640319090802, 0.05229848997259978, 0.0029746498785243602, 0.024089627477223985, 0.03375639411387965, 0.029092919940012507, 0.052904883996234275, 0.06609664429561235, 0.04517065506661311, 0.049766976007958874, 0.03408672033401672, 0.06364856628351845, 0.010359503048675833, 0.024050163774518296, 0.020829443237744272, 0.04353861295385286, 0.03102598086115904, 0.022340667419484816, 0.018366679978498723, 0.08662285341415554, 0.014969134408602258, 0.05774260331236292, 0.0670466007431969, 0.03522943108691834, 0.027715629294107202, 0.026553342540864833, 0.02154313140636077, 0.04781895338965114, 0.05103077557578217, 0.03127166513877455, 0.020648244171752594, 0.04429426400747616, 0.046309621684486046, 0.030248514376580715, 0.11608689543209039, 0.025500055016891565, 0.060889506130479276, 0.03310797968879342, 0.029910334378655534, 0.021055907745903824, 0.0337892712559551, 0.06946343433810398, 0.028281158811296336, 0.0594785906287143, 0.04238340072333813, 0.028187575844640378, 0.05138699161761906, 0.028153728344477713, 0.062098086200421676, 0.007271526756085223, 0.03723655092471745, 0.053330531663959846, 0.024507382404408418, 0.10987330111674964, 0.03378913024789654, 0.02045111861662008, 0.015984536221367307, 0.04162433207966387, 0.05999908476951532, 0.02526406133256387, 0.03631803556345403, 0.023818444860808086, 0.07928920982521959, 0.04614126548403874, 0.03614238405134529, 0.037730669137090445, 0.04378116536827292, 0.03889216735842638, 0.08635792895802297, 0.046541498304577544, 0.07538606965681538, 0.08682839121320285, 0.013562536350946175, 0.02963944305520272, 0.05546787244384177, 0.07355607449426316, 0.046273690604721196, 0.03662020470073912, 0.049997720852843486, 0.029413950760499574, 0.015861343417782336, 0.044665248788078316, 0.017157641632365994, 0.06863992501166649, 0.03707269956066739, 0.07469059564755298, 0.005714776916647679, 0.048158066638279706, 0.04339121500379406, 0.05372715764679015, 0.05766790985944681, 0.0334353373182239, 0.014650904267909937, 0.017056102842616383, 0.023662508501729462, 0.04020428816147614, 0.04779830684128683, 0.06584699323866516, 0.06657901802100241, 0.030576721765100956, 0.043651055748341605, 0.0306515840566135, 0.025371793344675098, 0.07324302176130004, 0.021878224069951102, 0.07569771973066963, 0.03350637940457091, 0.025677597150206566, 0.07257662509800866, 0.0257442067595548, 0.02758764778263867, 0.057325468078488484, 0.04382938270282466, 0.047216871244017966, 0.024812779884086922, 0.03824151906883344, 0.003188928785675671, 0.03396277053980157, 0.11035462099243887, 0.05202324966376182, 0.03464122339210007, 0.010687030444387347, 0.02613106793432962, 0.1532221320667304, 0.15194629115285352, 0.21618034515995532, 0.1317941615707241, 0.08409658272285014, 0.22755772137315944, 0.08445195271633565, 0.16434046905487776, 0.09134145802818239, 0.18793867231579497, 0.1473115195403807, 0.1510139013407752, 0.10997323872288689, 0.16379861219320446, 0.16888671729248017, 0.144377468386665, 0.10436081371153705, 0.14787969295866787, 0.1579056479386054, 0.1109622692456469, 0.09599179989891127, 0.23506781057221815, 0.1198817414115183, 0.2269109248300083, 0.07664509350433946, 0.11509193514939398, 0.12321114947553724, 0.12242674391018227, 0.16418397979578003, 0.12592709827004, 0.12002062692772597, 0.08462697340291925, 0.19771268300246447, 0.14562834345269948, 0.09102458323468454, 0.10018109736847691, 0.1483778521651402, 0.07572548347525299, 0.16018770751543343, 0.16880383423995227, 0.14905979682225734, 0.12970483774552122, 0.2595268457662314, 0.1534817650099285, 0.1292132688104175, 0.09048850028193556, 0.1924617210170254, 0.22983443748671561, 0.2401588694192469, 0.19933062430936843, 0.1876201870618388, 0.16172456176718697, 0.18887817190261558, 0.1175291184335947, 0.14386259601451457, 0.1353195559931919, 0.1467961721937172, 0.13780214387224987, 0.14062677277252078, 0.1531085537862964, 0.1863602429511957, 0.1334562012925744, 0.17064274259610102, 0.1468420072342269, 0.1145917276153341, 0.0752079245285131, 0.173826823302079, 0.11577508208574727, 0.10965382578433491, 0.11521477543283254, 0.0993298391404096, 0.12388994742650539, 0.12968586845090613, 0.1216086967906449, 0.08984781161416322, 0.1676025494816713, 0.1693951923516579, 0.09740184337715618, 0.07756387974950485, 0.11166716110892594, 0.1595778253977187, 0.12909051758470014, 0.09279574835090898, 0.12301731534535065, 0.0996595827746205, 0.08126292930683121, 0.18546196224633604, 0.27230374922510237, 0.11812501848908141, 0.15330228401580825, 0.12622950860532, 0.1565763130201958, 0.1883021168760024, 0.11542427630047314, 0.25466500665061176, 0.13914658891735598, 0.19850440614391118, 0.12604354124050587, 0.1318116465699859, 0.09990487000322901, 0.1967116742162034, 0.13532728917198256, 0.13373655499890447, 0.11592766022658907, 0.1890678351628594, 0.1421521237352863, 0.24279499280964956, 0.16696250648237765, 0.12742380233248696, 0.10222602591966279, 0.13539372623199597, 0.18275209906278178, 0.13093810906866565, 0.13999241462443024, 0.08057092854869552, 0.15698749251896515, 0.2037047388148494, 0.12455887481337413, 0.16010118793928996, 0.07762046850984916, 0.12400808249367401, 0.17552884994074702, 0.15043526364024729, 0.21042077452875674, 0.18583005265099928, 0.14605832897359505, 0.1398952229646966, 0.14619317720644176, 0.16801527264760807, 0.17380472214426845, 0.1483028507209383, 0.12661057175137103, 0.1961038404260762, 0.18758293124847114, 0.12496306328102946, 0.07901728691649623, 0.23694342555245385, 0.11725786345778033, 0.18650628277100623, 0.14961404755013064, 0.11183861206518486, 0.23262482369318604, 0.10927471448667347, 0.20269451255444437, 0.14522077079163864, 0.23544887371826917, 0.10833108855877072, 0.06611592529225163, 0.1880651491228491, 0.17578867584234104, 0.16434320015832782, 0.10869208403164521, 0.07760478692944162, 0.10815712172188796, 0.1614094607066363, 0.14703490625834092, 0.16777143260696903, 0.07617216731887311, 0.13845814304659143, 0.13466468488331884, 0.10169513800065033, 0.1902478648116812, 0.14521173143293709, 0.09848526024143212, 0.1578245757264085, 0.15363579033873975, 0.12201341960462742, 0.14881022740155458, 0.0909085781313479, 0.12387811017106287, 0.1148978561104741, 0.2144134251284413, 0.16747202054830268, 0.19224318821216002, 0.05672217994288076, 0.1406380979460664], [0.02658471497852588, 0.03310792031697929, 0.06945033543161117, 0.05536789401958231, 0.05167383911611978, 0.04334451907197945, 0.04683779334300198, 0.06987453962210566, 0.03165932226693258, 0.022685443254886195, 0.045302163634914905, 0.04639133585442323, 0.023971447881194763, 0.08067879971349612, 0.020257093383406755, 0.095955738943303, 0.07309184627956711, 0.025842006980383303, 0.018670017998374533, 0.014050121808395488, 0.03604627963795792, 0.020603295997716486, 0.04227135126711801, 0.01782902552804444, 0.09903233440127224, 0.08522984222508967, 0.023998339602258056, 0.008016810006665764, 0.02619705042889109, 0.019560925466066692, 0.08470963381114416, 0.081881962105399, 0.05465039306727704, 0.046450863519567065, 0.03025743499165401, 0.016214722600125242, 0.06124251238361467, 0.066917860385729, 0.021893033626838587, 0.05112972612550948, 0.068296058307169, 0.0595580672234064, 0.12041427689837292, 0.02847336949344026, 0.027944494650000706, 0.029672797027160414, 0.09050294989719987, 0.07280373713001609, 0.024799198581604287, 0.02937432007456664, 0.03300665797723923, 0.046966307345428504, 0.03968996497860644, 0.028519326988316607, 0.013531497879739618, 0.027895824605366215, 0.043983244759147055, 0.04746610298752785, 0.03362696726981085, 0.028486477676779032, 0.02346393946936587, 0.08125679916702211, 0.0381623615976423, 0.004754566307383357, 0.04753454384626821, 0.05302716024743859, 0.015562933258479461, 0.07235165045130998, 0.014576093926734757, 0.025423066472285427, 0.030265394525486045, 0.023986205487744883, 0.03703981499711517, 0.03151618053379934, 0.021894497513130773, 0.116170550318202, 0.04235742555465549, 0.026353022039984353, 0.07368351609329693, 0.04769749350089114, 0.010751916415756568, 0.06083107684389688, 0.07251827002619393, 0.005820155856781639, 0.026965987781295553, 0.026048908475786448, 0.09428248537005857, 0.024318542928085662, 0.09855140786385164, 0.03652301304100547, 0.014375032205862226, 0.047305164553108625, 0.0487222101946827, 0.021281168119458016, 0.082810485328082, 0.06516930850921199, 0.050734209653455764, 0.0299909909881535, 0.05033616987930145, 0.049335843868902884, 0.027569274061534088, 0.023820968162908684, 0.029973884484206792, 0.07722644746536389, 0.015292586485884385, 0.03440021464484744, 0.07866707484936342, 0.020348609468783252, 0.06271295555052347, 0.05494919285411015, 0.04328782270022202, 0.04539322886557784, 0.0405412120744586, 0.01445284731744323, 0.019961317848355975, 0.007563759927506908, 0.0219127061063773, 0.06909886913490482, 0.05436590188764967, 0.04454574816918466, 0.0329643258737633, 0.05331634180038236, 0.045936269452795386, 0.03309286214062013, 0.06126009757281281, 0.020980442459404003, 0.020337909554655198, 0.03362723444297444, 0.021235518615867477, 0.07448882795870304, 0.06776411653845571, 0.021345916793507058, 0.05276432122627739, 0.028105047167628072, 0.008613921618234599, 0.01067220789991552, 0.032820423439261504, 0.02798570796585409, 0.06019315267622005, 0.0574276914994698, 0.07033775851596147, 0.04044179768243339, 0.0732258113566786, 0.03234560106648132, 0.025162841666315217, 0.05182909269933589, 0.044560268288478255, 0.09610787921701558, 0.05475706566357985, 0.020192188858345617, 0.037382416339823976, 0.05879946242203005, 0.037326710735214874, 0.022194818702701014, 0.05299937794916332, 0.0566083010926377, 0.03372478604433127, 0.0223992544124485, 0.04097303070011549, 0.061036610932205804, 0.04434819216839969, 0.010483450987521792, 0.019793792853306513, 0.029665685397048946, 0.04915439247270115, 0.021467979677254334, 0.04923523461911827, 0.03985252129496075, 0.02077215314784553, 0.10785466685774736, 0.10858655805350281, 0.04923936467093881, 0.047128002770477906, 0.0430307204806013, 0.06350813710014336, 0.027947635790042114, 0.021013045006839093, 0.06607987175812013, 0.04093330353498459, 0.023130715162551496, 0.020278591546230018, 0.06719097073073499, 0.032566100562689826, 0.014661232180515071, 0.019516276006470434, 0.0072237227050209185, 0.037561596764135174, 0.05040088886744343, 0.04317051141697448, 0.048066556119010784, 0.03273949594586156, 0.09146810552920215, 0.0715536561619956, 0.007616845750817447, 0.03513584997563157, 0.018363869094173424, 0.12102191030862741, 0.07007830368820578, 0.05670593061950058, 0.02299437521287473, 0.05656956469465513, 0.025260627044190187, 0.020397522566781845, 0.019466021476546302, 0.02430452746921219, 0.08832588937366381, 0.10491056702448986, 0.006772179649487953, 0.02014084893744439, 0.10062192566692829, 0.009133370258496143, 0.028612804198928643, 0.03204109787475318, 0.028986776123929303, 0.010648161387507571, 0.012692080617853208, 0.017613184863876086, 0.04649435337341856, 0.07249378657434136, 0.017538899592182133, 0.045952114305691794, 0.06184269834193401, 0.03798551893851254, 0.05955757740593981, 0.037665063282474875, 0.029084965972288046, 0.01068096338713076, 0.004334563136580982, 0.012063631820637966, 0.05296435971104074, 0.00963166676228866, 0.013725301396334544, 0.01953162733116187, 0.02523931998439366, 0.014717540780111449, 0.04539989335171413, 0.03168188726704102, 0.05625837846309878, 0.08111893781460822, 0.01991337881918298, 0.08561534341424704, 0.0742559420177713, 0.005101928063595551, 0.006436949688577442, 0.05995316067128442, 0.04563011127174832, 0.002662769970811496, 0.018379515422566328, 0.0225030975707341, 0.028101089665142354, 0.024085621735139284, 0.09524863547994755, 0.015992770349839702, 0.042436267613084055, 0.05413766179117374, 0.018798769488057587, 0.03253430695622228, 0.05736523977247998, 0.043555864176596515, 0.036432419074117206, 0.04239818801579531, 0.01946309370396193, 0.08580353722209111, 0.056317026683245786, 0.060478809027699754, 0.020827624975936487, 0.08815339941065758, 0.04592958641296718, 0.030924584934837185, 0.048521329372306354, 0.045714463776675984, 0.04582344074151479, 0.08408111636526883, 0.0018591500861475652, 0.06729196960804984, 0.04021643711894285, 0.00842802661281894, 0.07836326927645132, 0.011710939124895958, 0.03078407225984847, 0.044284849864197895, 0.03156266866426449, 0.010247057471133303, 0.05769189607235603, 0.06362458007060923, 0.030143810326990206, 0.0713222025660798, 0.031239493036991917, 0.014816942184552317, 0.042458691605133936, 0.002557487046033202, 0.01870936481282115, 0.017895740893436596, 0.010822591139003634, 0.008193191606551409, 0.0244144989119377, 0.012914172020828119, 0.024216271267505363, 0.02209567704994697, 0.0726656308688689, 0.029641420878760982, 0.025838953042693902, 0.02265365150378784, 0.038580906912102364, 0.018711455813900102, 0.0710876467928756, 0.0728564518794883, 0.09766864546691068, 0.014386423245014157, 0.038090228554210626, 0.04482687741983682, 0.07210297902929597, 0.029956948674225714, 0.008412377501372248, 0.021005723720008973, 0.05135723520652391, 0.02896156165661523, 0.06240489747142419, 0.012317507553234464, 0.010598717653920176, 0.04285077935492154, 0.041808922760537826, 0.016551548178540543, 0.0774060249386821, 0.04561182846373413, 0.011534904479049146, 0.040105897933244705, 0.033230085246032104, 0.023979043762665242, 0.024146464857039973, 0.08644903500680812, 0.06572977101313882, 0.02817807820974849, 0.04210623825201765, 0.04694529343396425, 0.07369619939709082, 0.059712942311307415, 0.02203720694524236, 0.03682727132400032, 0.07509214206947945, 0.033100365253631026, 0.023913643854029942, 0.05639015791530255, 0.053954547984176315, 0.012090119071217487, 0.06661163541139103, 0.06482176075223833, 0.020386204814712983, 0.004803493320650887, 0.028453233171603642, 0.06853930462966673, 0.027965597619186155, 0.1648722920799628, 0.1263577665667981, 0.16526414605323225, 0.14042412192793563, 0.10444886953337118, 0.2540667762514204, 0.14548384730005637, 0.14360101864440367, 0.1867547834990546, 0.10116263962117955, 0.18694723723456264, 0.10059748674393632, 0.11653577603283338, 0.16489295347128063, 0.09712155646411702, 0.1493650273187086, 0.1803121401462704, 0.14406067522941157, 0.08336164130014367, 0.10883163748076186, 0.25718249031342566, 0.09752828307682648, 0.1728335625375621, 0.10339306798414327, 0.17699116287985817, 0.13697741000214592, 0.19417384086409584, 0.1296890596859157, 0.12031963080517016, 0.13233469740953296, 0.21988921333104372, 0.20607086888048798, 0.1656152561190538, 0.22849106113426387, 0.1291697344277054, 0.1354389378684573, 0.09064298574230634, 0.09218380306265317, 0.11016921765985899, 0.12817769078537822, 0.11364766382030211, 0.20854382368270308, 0.24455838021822274, 0.07623969533597119, 0.11256100377067924, 0.19462615018710494, 0.1770416586077772, 0.23292380530619994, 0.06392702751327306, 0.07469947173376568, 0.1253893380635418, 0.20141312037594616, 0.1816786715062335, 0.1614279847126454, 0.0867820811981801, 0.10918554544332437, 0.09669728548033163, 0.11289297384792008, 0.19903075211914256, 0.13797599938698113, 0.11435404740041122, 0.3144713630899787, 0.16179726255359128, 0.071775684482418, 0.1507838800898753, 0.12346146846539341, 0.13056075666099787, 0.11075785951106809, 0.13301569211762398, 0.1277787864091806, 0.10225003439700231, 0.09233384305844083, 0.09372622342198156, 0.08717058808542788, 0.07226125686429441, 0.24559136072639376, 0.09856143427896313, 0.13789572869427502, 0.21134679671376944, 0.17065813473891467, 0.1108715491136536, 0.16168810747331008, 0.23712951166089624, 0.07784898320096545, 0.17018287820974365, 0.14038563414942473, 0.29207494924776256, 0.23654339311178774, 0.2985769050428644, 0.08757080606301315, 0.13147251476766542, 0.12993812444619834, 0.14184281142661348, 0.17066812404664233, 0.24230508628534153, 0.15336601965827867, 0.1396654688869603, 0.09575102492817678, 0.09269409638363868, 0.16663327493006364, 0.06781279400456697, 0.11894692477653734, 0.06424667793908156, 0.13310445297975093, 0.20443318644538522, 0.1945046309265308, 0.19032973854336888, 0.06035220605554059, 0.16827450483106077, 0.12488846259657294, 0.14619011955801398, 0.09545098946546204, 0.08102980587864295, 0.08278190522105433, 0.06949344679014757, 0.1961488591041416, 0.15397391282022, 0.1116476945753675, 0.3149398957611993, 0.09422644579899497, 0.1654228023835458, 0.20525268075289205, 0.08255430337158032, 0.16872956010047346, 0.16360595065634698, 0.11322396429022774, 0.13306744949659333, 0.08993963012471795, 0.10937871164060198, 0.1467702118679881, 0.2255670289741829, 0.2526277519064024, 0.13301594444783404, 0.12289709484321065, 0.14527993480442092, 0.10810057749040425, 0.14171903603710234, 0.1927990122931078, 0.14195380703313276, 0.25606487528420985, 0.1544610140263103, 0.18949712306493893, 0.1598134424421005, 0.12223547018948011, 0.24903581652324647, 0.15846077440073714, 0.07820936269126832, 0.24961107003036886, 0.221983450173866, 0.1203021161200013, 0.10795994792715646, 0.20034818298881873, 0.1039907343511004, 0.09778442050446756, 0.20268020394723862, 0.16620165668427944, 0.13116948102833703, 0.16295072331558913, 0.17505694791907445, 0.19257184088928625, 0.1945969244115986, 0.08412185285123996, 0.21977885597152635, 0.11767734016757458, 0.13266904978081584, 0.11032903916202486, 0.09979679845855571, 0.10336545266909525, 0.07794567020027898, 0.2958121377741918, 0.24606808670796454, 0.13665790058439597, 0.16665838920744136, 0.10815263172844425, 0.2250410837586969, 0.14645399758592248], [0.03166297363350168, 0.020742906963278074, 0.03265789680881426, 0.0582260123337619, 0.021899286221014336, 0.05828277178807184, 0.047886974934954196, 0.09149538687779568, 0.07530053713708185, 0.050170314716524445, 0.030380952484847512, 0.020045638812007383, 0.03469247982138768, 0.05061152151029091, 0.012368802017590497, 0.03668900179036427, 0.10867466582567431, 0.015792730009707157, 0.03729667601874098, 0.018522968857723754, 0.021614218021568377, 0.0362020044849487, 0.0408988419076195, 0.014549406296282541, 0.02652584411407588, 0.04356893339718226, 0.015670489010517485, 0.0570527102536289, 0.15154419554164633, 0.058518719088169746, 0.015974951384123415, 0.026530508512223605, 0.11451690428657457, 0.02959078599815257, 0.022266500891419128, 0.05724845912482124, 0.03604414967412595, 0.03920769515389111, 0.04146507832047064, 0.04251049722370226, 0.04701631325588096, 0.007572954209535965, 0.060869412482134067, 0.07149490775191225, 0.06231132007087581, 0.028869507514173165, 0.023641455627512187, 0.028946566562808584, 0.07103898416971788, 0.006792596595914802, 0.04210664272250142, 0.00647265116640483, 0.026854365059989505, 0.03392580045328941, 0.03571849156287499, 0.03933010499167722, 0.060450292003224604, 0.04822484879696276, 0.012864667987741996, 0.03793761701672338, 0.06744550511939451, 0.08014762235688977, 0.006036780878275749, 0.028843389482062776, 0.06299498651060276, 0.04266235919203609, 0.035598530812421814, 0.026088600388902705, 0.07856010910472833, 0.018373145940131508, 0.0025604813799873227, 0.01782326460670447, 0.02253635506349383, 0.040816626788000576, 0.024908676496124826, 0.01695489430858288, 0.023121059821278322, 0.030127696445561014, 0.058196100071654655, 0.039271530986297876, 0.05732511926908046, 0.01820052053517429, 0.07971400031237863, 0.054777704790467396, 0.040975335068651475, 0.020761479208886158, 0.05997385174850933, 0.04116801515920088, 0.0505004665319575, 0.013230160875536967, 0.015327155724662589, 0.03835285606328398, 0.006486187476184568, 0.022992961421550717, 0.013216236329753883, 0.0809436351119075, 0.06845188705483451, 0.029896163068769965, 0.08973798860097304, 0.017245343078684527, 0.031058954482432455, 0.021444583471748047, 0.04561313093290664, 0.08369252784177661, 0.05232553383393679, 0.030352333415066823, 0.06468729843618348, 0.039833600239944644, 0.017258998595934827, 0.030647522653453052, 0.016571140877204016, 0.04044314096972812, 0.03814739247900434, 0.00646628168397001, 0.02560674987762468, 0.03480913059320301, 0.03392309161426965, 0.03888479412125889, 0.019709766893356573, 0.014406156024051597, 0.03718238527653739, 0.06281681169639342, 0.04035078440210782, 0.037580625430564396, 0.059993444447172806, 0.02587225506431423, 0.048143294188776053, 0.0126057456509443, 0.02362449940847, 0.02434257181448629, 0.07039125252049416, 0.019535725841706153, 0.007227463129311218, 0.02003589441301301, 0.027307221716910135, 0.041589517932152376, 0.024016102906898595, 0.0694526509323623, 0.04325656344008166, 0.0074438001047383295, 0.06090795592172071, 0.03694787032145541, 0.027947338930971455, 0.0035554676378524164, 0.10243909651762806, 0.0239383963344153, 0.04451788423466496, 0.017201350419782102, 0.05142826987139415, 0.02172100194002269, 0.062097225309116766, 0.03226305569114629, 0.007945981287775794, 0.03660964022856206, 0.07413039289531298, 0.04238692963554058, 0.04673309485951904, 0.06219950439117383, 0.06044094836397562, 0.040513837957405485, 0.04703086677182, 0.026278044715581927, 0.03810637768765446, 0.001767848179952125, 0.054118788975756615, 0.08863426657626405, 0.031212705216603354, 0.027378612612665165, 0.006638481745540048, 0.039522688603028655, 0.05730355616833549, 0.03789004906138871, 0.04648240479582455, 0.05310874825227074, 0.015331857230194146, 0.05568197833781596, 0.06340971347526647, 0.04702127080236096, 0.06693453644402325, 0.04576365332468413, 0.020273743466532324, 0.059214849898125976, 0.08932852346333675, 0.03611563704907894, 0.06318722502328455, 0.033589793092687614, 0.02675527721294202, 0.025733911315910518, 0.02461343159666285, 0.06529519901960157, 0.0855311393388547, 0.004549997474896372, 0.0917998306977097, 0.03634824839537032, 0.032983287746901624, 0.042000452522188425, 0.02869133084459463, 0.021391566297097597, 0.020699541419162415, 0.04200899464194663, 0.01886208396172151, 0.07202566950581968, 0.019148732935718726, 0.024508386159141082, 0.08132359245792031, 0.08281830014311709, 0.05287304215016775, 0.022471682459581643, 0.04431623900018167, 0.01062295990777784, 0.07146295829443261, 0.042717927499325015, 0.050347854994470254, 0.023786022284184583, 0.06844974966952577, 0.0238873829584918, 0.03498939084238373, 0.0642219495784957, 0.04823462659260258, 0.024632658787595574, 0.026116213848581538, 0.041347173319081776, 0.047360053795273416, 0.027810616775241215, 0.07680155307753012, 0.037162447479204275, 0.03668303492304403, 0.017124831283581443, 0.05518958190805279, 0.044622029818128794, 0.05916191992582753, 0.0604021117760567, 0.031350381032098085, 0.06835116277216002, 0.027027669530070852, 0.007702626890022657, 0.027930629476031754, 0.04415486640937161, 0.0902776190196164, 0.057022015025722794, 0.008363597062270856, 0.05552455026190728, 0.0028514719178929226, 0.05840677724336274, 0.03414803657506127, 0.021912576230533887, 0.015012001786089968, 0.023331067204708233, 0.04628173919627443, 0.010750143610493978, 0.057901931286323816, 0.03053605763852829, 0.04573145153699443, 0.01292459362957743, 0.021845426708750892, 0.0708646017301362, 0.034088690736098215, 0.08088945833151229, 0.031395206751767546, 0.05416352934844326, 0.10164628241909668, 0.04878545973042492, 0.06099576312408317, 0.03646268385637086, 0.047766706193215214, 0.09482228648266755, 0.01848177595093148, 0.0489541758724954, 0.033537557028466836, 0.05179162908461876, 0.027620545333775226, 0.06423927130526863, 0.03968479220930021, 0.03432520948990714, 0.0462885409797309, 0.03349448277731426, 0.05072459884104319, 0.01225527568749385, 0.0423973048600601, 0.03433436759223696, 0.03504548607452307, 0.009760921984707238, 0.053601727267960086, 0.020073517589480616, 0.06929559764103033, 0.0600165512150852, 0.006897490357005154, 0.04320050902606454, 0.017917899567692075, 0.022978786400926765, 0.04024199297418818, 0.04235905456880573, 0.023392947477987036, 0.05787706562841777, 0.026409299098304473, 0.04757749193231575, 0.05626072364975698, 0.057024979905691, 0.05056226145825349, 0.03560918434232008, 0.06958228186704218, 0.05441766668809578, 0.07865949010010809, 0.022016393413650803, 0.060003337275702506, 0.04594274840201251, 0.010267536108585773, 0.0811036718368996, 0.02697632404306205, 0.01208860880069551, 0.006284317278186791, 0.06614463156438433, 0.018745138186204713, 0.027700435675797053, 0.017023001200868748, 0.034093017457053065, 0.04454827147128526, 0.03081623694015434, 0.08785349011304788, 0.015939500844979193, 0.04433121925103478, 0.014011097828188213, 0.03920776565792039, 0.032064148981589824, 0.017534871585667133, 0.01813913564546965, 0.022298305630101822, 0.05046626094554085, 0.04145429491472896, 0.0011026193556062935, 0.03219857047952246, 0.028761556568497326, 0.005476058622662094, 0.08907993367756717, 0.02982787620567251, 0.03210803959518671, 0.057707863379619084, 0.04954544492647983, 0.012732079594570678, 0.03887255610607099, 0.0746503786649555, 0.060490423638839275, 0.058309010419179685, 0.06002213587635197, 0.02620437171572121, 0.023347079040831886, 0.0925803548307158, 0.09590862740878947, 0.011979936116404133, 0.038402208883780986, 0.04958032215654384, 0.01428010966264992, 0.19042902305955067, 0.17788607423426583, 0.11628613239736296, 0.19020306877791882, 0.09456559986574575, 0.12393495126161724, 0.1487392483977601, 0.10745064166258089, 0.13671648572199047, 0.11153230545460247, 0.10827251826412976, 0.08842213850584812, 0.16591119492659345, 0.13026667322264984, 0.1210808294126764, 0.1206345166428946, 0.1591042461222969, 0.09235774021362886, 0.10735902353189886, 0.15444584452779964, 0.0733571640739683, 0.1576535403728485, 0.1448984708986245, 0.1713787452899851, 0.12079621577868238, 0.19480472576105967, 0.12181229016277939, 0.29112363466992974, 0.2246425801422447, 0.23528065852588043, 0.11486154282465577, 0.10398255588370375, 0.21266925934469327, 0.12255129855475388, 0.15179833659203723, 0.12384687317535281, 0.17057841323548928, 0.08657761951326393, 0.15607993496814743, 0.11712941253790632, 0.2526028157444671, 0.16680401342455298, 0.13303439423907548, 0.2000491420039907, 0.23188390798168257, 0.1780349639011547, 0.16929832723690197, 0.11979925911873579, 0.1838718811632134, 0.16915126325329766, 0.14151905692415312, 0.1140176912304014, 0.15646942891180515, 0.11565420849365182, 0.1484366154181771, 0.11677377537125722, 0.14606680430006236, 0.20748609997099265, 0.09839154183282517, 0.1656120500410907, 0.21029419382102787, 0.21303488581907004, 0.18818055308656767, 0.0966176827205345, 0.11887343731359579, 0.11270649440120906, 0.11152925522765145, 0.11284111998975277, 0.14849273662548512, 0.06446063169278204, 0.13244167057564482, 0.13147483026841655, 0.07844793348340318, 0.09654651075834408, 0.16199851816054434, 0.16110743628814816, 0.10661266787792556, 0.09955477667972445, 0.255702588474378, 0.2363044660887681, 0.16282399417832494, 0.1488006833824329, 0.1678340253420174, 0.12431444105459377, 0.20597027818439528, 0.2181591631961055, 0.10323991096811369, 0.1442033308558166, 0.1688446820480749, 0.15844933048356324, 0.08977488818345591, 0.08624549358501099, 0.10009823658037931, 0.13112395768985152, 0.11624246442806907, 0.14634306135121733, 0.1363842558930628, 0.16060589288827032, 0.17464765347540379, 0.1086144924920518, 0.14005579403601587, 0.08216354777687229, 0.09355727350339293, 0.18273973488248885, 0.1522605906939134, 0.13658613490406424, 0.13144958240445703, 0.2485548157710582, 0.15238081861753017, 0.11672515727696009, 0.15420325129525736, 0.12925033166538924, 0.12008941659587435, 0.08354739344213158, 0.1217464913497679, 0.10447899330756627, 0.10877114502363838, 0.11193632322829217, 0.11024919149349444, 0.1638562770676799, 0.15818938583834097, 0.16760905069531873, 0.15218420885503292, 0.18143780005630106, 0.18579643336124718, 0.1502708630869165, 0.14726595167303458, 0.07274340052390471, 0.11995327702607028, 0.19020308362087235, 0.09484210182563402, 0.21448821877129376, 0.12407123926095665, 0.11353966649039648, 0.0778309341694694, 0.13977563328808174, 0.07370197330601513, 0.11806637397967279, 0.2455824104254134, 0.1078446775500197, 0.22222631057957187, 0.14586096222046763, 0.18230587535072118, 0.14238892821595073, 0.15229999873554334, 0.1083264872431755, 0.18392822501482442, 0.1483170999563299, 0.09190451804897748, 0.15167787118116394, 0.22527650784468278, 0.22759257262805477, 0.075023545359727, 0.15245160466292873, 0.2381037437589839, 0.17090912908315659, 0.10660531319444999, 0.12777840049238876, 0.16900808812351897, 0.10204767299001105, 0.13824487949023023, 0.13083156634820625, 0.08382736123166978, 0.10390068215201609, 0.16326720477081835, 0.1504550492973067, 0.11312013783026487, 0.11222336368518881, 0.08305275943712331, 0.09296852033003233, 0.18743953347438946, 0.16149424365721643, 0.1573920965893194, 0.17165660538012162, 0.10233821638394147, 0.08806050478597172], [0.016606611825409345, 0.029759544813714456, 0.024415712323389016, 0.03324302459077444, 0.02125656777934637, 0.046021497691981494, 0.057022772016352974, 0.02238798675534781, 0.023806179015082307, 0.052619676644098945, 0.05800472245027777, 0.06219555616553407, 0.010830214851011988, 0.08292303202324547, 0.043455106497276574, 0.06581381181604229, 0.015821200649952516, 0.10018824425060302, 0.014093178433540743, 0.01768563703080872, 0.038201324350666255, 0.027673195145325735, 0.05488277805852704, 0.053464177617570385, 0.02830763864039909, 0.04275182509445585, 0.019236634761909954, 0.0316268495953409, 0.009808022387005622, 0.07506608526455238, 0.021780117713205982, 0.05113127721415367, 0.03157680657750461, 0.03894262968969997, 0.04141481265833136, 0.05093749874504283, 0.04262338159605861, 0.042816332570509985, 0.06237898167455569, 0.03006572154845344, 0.035405694870860316, 0.03714242062414996, 0.02537791235226905, 0.015259319716278696, 0.023932490694278385, 0.021357926598284394, 0.08773128807661124, 0.02366383694607066, 0.031003330514067784, 0.01505881924458663, 0.021274511054798495, 0.02359749636525521, 0.0679391594894696, 0.042563568204059266, 0.03896546557371039, 0.04309759540774394, 0.056404080605716445, 0.0353461412305478, 0.0252301266300492, 0.03737064958841074, 0.02316542169864988, 0.013768999979220098, 0.02620121573272627, 0.010642745564837242, 0.03583226651244331, 0.015228485335683217, 0.03043534634343814, 0.07925849975435995, 0.04643053609470371, 0.02602079592179507, 0.06781595555366948, 0.043600663921097293, 0.01237899541592924, 0.05237976256466936, 0.01975208786461735, 0.05739751577493735, 0.04268890952516813, 0.05520535254618153, 0.04924550965370145, 0.005298209889588179, 0.028118095979152713, 0.05881534809304867, 0.02510821032046806, 0.025818280519160908, 0.026529005663178395, 0.07067487909807824, 0.06234387066797353, 0.06977933691814542, 0.050449703630874865, 0.021282003035594244, 0.03380534617463127, 0.03464599540166091, 0.019796182568825316, 0.022426997747970745, 0.04851631987548899, 0.01563917780003976, 0.027419432590249926, 0.068187214928912, 0.051245879658381455, 0.03552166286681313, 0.053991132153896615, 0.024342176620848477, 0.06803668511565775, 0.07205969697679393, 0.024912229528126772, 0.013700579529540846, 0.05337404378224164, 0.05225127453741152, 0.059826001088367775, 0.07052309505525045, 0.009290554353356129, 0.015876273573667277, 0.017726002442941535, 0.0395265960105462, 0.07791827010805719, 0.04284869763068855, 0.06626181668252684, 0.05036069043853786, 0.04486872712732293, 0.058878115232801065, 0.036466442834353074, 0.05455608094052877, 0.11067336599808186, 0.04715127652161755, 0.03042359443497844, 0.018098148684657644, 0.04616160404111724, 0.052706055212183855, 0.05354436296329368, 0.035230184366810136, 0.03396579108084552, 0.04613387369317934, 0.061558196030091494, 0.03135761326120701, 0.028493127319961786, 0.026559288999123964, 0.039460225743823685, 0.08083307737251744, 0.033457293757237494, 0.04069407223141752, 0.02751928856014274, 0.013828691844537389, 0.09021216159453616, 0.019059014703088906, 0.06269812743994407, 0.06040655352990143, 0.020702227993751876, 0.02553848156821914, 0.04661952028982341, 0.035121415203320794, 0.043275421412545256, 0.04624342211172916, 0.030165245407260954, 0.020638525747926906, 0.04186871388810687, 0.006863765775051434, 0.02085237931169104, 0.0301318821584573, 0.04797401401447132, 0.05685776661266573, 0.01722168341075303, 0.02151060678443173, 0.03242259146645665, 0.021230570346233435, 0.02293797384481877, 0.09512445190921426, 0.06579164386494085, 0.004476388485272764, 0.023891093696875032, 0.02207367793744197, 0.029370744778134394, 0.026633724555722438, 0.021927012858213857, 0.03898232345818542, 0.03230043024814222, 0.09920035663526505, 0.04737306364404503, 0.029581360722659156, 0.025148612839984708, 0.03817520075244829, 0.04298373140045442, 0.0644636299693957, 0.0684387881483417, 0.030991044259280898, 0.03683253686176613, 0.004313484751037322, 0.03709731659910176, 0.022609636580455117, 0.01995580554648768, 0.022093784573371522, 0.022357308225764427, 0.04324801389884669, 0.03186149442626629, 0.0303526042989688, 0.041188921459252015, 0.019330622199049685, 0.06698452751152217, 0.037005160411354154, 0.0329568450251827, 0.057368917114217766, 0.01623080865101656, 0.029948024348414037, 0.015511625806539087, 0.046309206081787124, 0.06557694796356373, 0.09985350596252829, 0.06197473012434784, 0.04485875637328718, 0.044583920534932986, 0.01511974400273175, 0.025283086288254708, 0.06448671818361618, 0.029794898873660713, 0.056921075520222075, 0.016397569233959075, 0.06216958470758982, 0.03711312063387595, 0.0477720644994406, 0.029529718376579694, 0.02169384119042661, 0.08013565151486546, 0.03449768460995983, 0.02387567928963108, 0.07719834975432605, 0.028000127895211335, 0.020442634013306815, 0.00420695316279307, 0.03558254124072846, 0.06712845221045427, 0.03859090735204518, 0.009738461812958121, 0.0629090383881703, 0.04760649877425749, 0.03775279998080805, 0.02415249851765111, 0.04789811457158066, 0.04564535127428826, 0.03215217511751689, 0.036900020350003615, 0.023869938777352218, 0.030908274384273682, 0.026922740980808157, 0.05563349383010063, 0.04227579673170112, 0.06966261935303919, 0.02679391713172663, 0.06683684754534625, 0.07598815922392532, 0.038236658001551405, 0.02704121929127723, 0.023315278012887575, 0.043551964190555736, 0.07948063197545707, 0.030072499212110415, 0.018414054975437466, 0.03180191110004671, 0.08410760361584835, 0.033952176381717436, 0.02355556316615548, 0.03081452628975967, 0.03346308621985372, 0.09109648992307484, 0.023553025021101348, 0.07883098558522761, 0.022525677413796075, 0.07114938605809584, 0.0178296099693398, 0.014239600459404755, 0.009760092634678585, 0.0345837180793751, 0.025129458008450456, 0.049509944292367436, 0.0272273777591181, 0.042846949872910045, 0.029105974317644723, 0.05542958875594195, 0.016088264346763026, 0.005485012634380837, 0.02144093767128652, 0.05186082322325092, 0.02174995868699625, 0.03690392404678278, 0.02757021844445262, 0.03061950843402883, 0.017562909924890846, 0.04372285482531879, 0.03285778686404228, 0.01801942165911896, 0.036103684760746546, 0.0047310615627793595, 0.04208998892863747, 0.032887261259020306, 0.037974679871695116, 0.03194737575540785, 0.040025912967394106, 0.03454624333244283, 0.027810659448732622, 0.05716036990634166, 0.06379666927387007, 0.04561567278869916, 0.0559837392938789, 0.03213195159332827, 0.05008714222640265, 0.01888336133561097, 0.05308796440658625, 0.057729931140784174, 0.012924036091135349, 0.052894761101924814, 0.04999024742573965, 0.00892120322532719, 0.0292521829760517, 0.021146197432244662, 0.04867532501521055, 0.05378375011787284, 0.05767338690930046, 0.06139558776339982, 0.02582037337560905, 0.010732246719271643, 0.039038800896378234, 0.02528635730413953, 0.0719333760207519, 0.08026575000258163, 0.03812236725934781, 0.026142044298467226, 0.011404311535443412, 0.0495980372215854, 0.03031437812751392, 0.05984429131785873, 0.060505411311169155, 0.05305956241500098, 0.07053248322336003, 0.04010227625258267, 0.0154117856072844, 0.04089202899194788, 0.09214352670824155, 0.03670938858704176, 0.04334063021815382, 0.1118369644973427, 0.02559852317062905, 0.047939177602529526, 0.016777929195086472, 0.005897598966839723, 0.06237424677237868, 0.04191995918517932, 0.050196193406009115, 0.010368814218963962, 0.03333657230541576, 0.01605960074812174, 0.00423239166593703, 0.02714049824135145, 0.06819508169428445, 0.08306285264552571, 0.12809983949409798, 0.12872823077486828, 0.15892016381258145, 0.07852974784327671, 0.1497296296292916, 0.0954549154266715, 0.11125565506517887, 0.1281886745709926, 0.10591422527795658, 0.09028167114593089, 0.12902265560114756, 0.29242007760331035, 0.1601608269265853, 0.10737321339547634, 0.08369411603780463, 0.16496388794621453, 0.06452373650972731, 0.1556643916410394, 0.15438608679687604, 0.08413723757257685, 0.23303806636249647, 0.16890653263544664, 0.1098289132642094, 0.17495154810603708, 0.1671822415664792, 0.0860309015843086, 0.10092743075801991, 0.12354638500255533, 0.22219668404432014, 0.18103660986525938, 0.13777248765109107, 0.17995669593801722, 0.13142547744791955, 0.20926575525663793, 0.132677465735469, 0.1278387222555466, 0.09779785337741487, 0.10383589265984483, 0.23813374136807397, 0.11755015089875087, 0.1372892307699658, 0.11895229792571627, 0.11969643455813639, 0.0869530052295886, 0.10337273313780315, 0.14683090470498428, 0.15817852079635486, 0.21319631778169423, 0.17291686119278893, 0.1129376734024845, 0.08053628509514965, 0.0951155906659551, 0.17666562722297385, 0.1549664611229673, 0.20362146984552965, 0.186063829169143, 0.1244583805964794, 0.11031794405425899, 0.18816063384292647, 0.14379948377609253, 0.19686523941345513, 0.10604539245832711, 0.15627995860995725, 0.1147972654143814, 0.1286184522905387, 0.15222125686705112, 0.12956803024280816, 0.15076538576977327, 0.12887243006844074, 0.07563554259832017, 0.14420753141166642, 0.17314452241407707, 0.1404232461936772, 0.17965949547942728, 0.16455729492008686, 0.2289611820015125, 0.1925570869934745, 0.18976488994667307, 0.15258767001796514, 0.11987276884610765, 0.12249151113792323, 0.082366784918122, 0.11733561826986261, 0.2226379798958078, 0.18142821150831878, 0.16310112696373835, 0.0921565291355364, 0.19454173831036314, 0.10747188935056329, 0.17619917256524786, 0.13284789252793416, 0.1490824471693486, 0.10582888571661897, 0.11954931120271794, 0.11549302886123769, 0.15435620793141425, 0.11952549568377435, 0.16512791742570698, 0.1228443429863546, 0.13559688173700124, 0.08549933088943362, 0.09119836453464814, 0.1495321441325359, 0.1285919130896218, 0.1473855710355565, 0.13085613143630326, 0.15566253627184778, 0.1955955583252944, 0.12148686582804658, 0.23165396094555035, 0.08905029972083867, 0.0980075694678817, 0.1208425332151819, 0.12757695192703977, 0.2193565887864679, 0.13107052305713296, 0.11014235191396438, 0.11397155933082104, 0.11394985893275589, 0.1300957120838575, 0.11427180259488523, 0.12155717689893208, 0.18006919068284333, 0.13204401300754398, 0.17873755510663614, 0.18545290804468095, 0.2148805180331692, 0.14662604226032272, 0.140370434965007, 0.12010048943920992, 0.12327644362812862, 0.11867057866766118, 0.1994859558180906, 0.10696515833842568, 0.11467732692835853, 0.13039738027146086, 0.13938429881818593, 0.14170618203934282, 0.17239998502191156, 0.17066717409761623, 0.1385308735189028, 0.08300298359245062, 0.14055610547075048, 0.10977667348925024, 0.17035760945873335, 0.19430791726335883, 0.09071078093256801, 0.08370851370273158, 0.18637398752616718, 0.13030330563196912, 0.20241867110598832, 0.14308406825875863, 0.13466805423377082, 0.1239351367985364, 0.18549518077634275, 0.1059081545099616, 0.10740993486251682, 0.07242391337058507, 0.17508975084638223, 0.1634356426075101, 0.1095466893457342, 0.14122228691121563, 0.06769701896701008, 0.13959287200123072, 0.08966416717157699, 0.14167058863677084, 0.16552456567296758, 0.17036123113939539, 0.12802366545656696, 0.09285917229135521, 0.19309379335027188, 0.08815077962935902, 0.10179720557061955, 0.13385903905145824, 0.13011592818656936, 0.159529288939666], [0.04099212615983561, 0.045899878241471015, 0.07962275325553492, 0.03780035680392757, 0.07378556139883585, 0.07278310542460531, 0.027933015480812173, 0.02851053068297915, 0.03540555015206337, 0.041204951849067584, 0.06532790546771139, 0.05016499722842127, 0.015423133972944925, 0.05318760886439122, 0.019741154173971154, 0.04461968092073221, 0.019110135690425523, 0.01854687900049612, 0.07769885414745659, 0.032138111419044435, 0.04061039137013722, 0.11339131116983481, 0.03150275137159042, 0.05448164723929949, 0.10513765679206699, 0.014601318598579383, 0.017541940542287193, 0.03693749138619751, 0.07096352259395644, 0.03493046802759636, 0.03200625033059623, 0.035658963897731155, 0.021327791691874154, 0.043236989295110106, 0.009410494694748195, 0.04298852938518394, 0.03884218000166584, 0.0840178037469741, 0.04277533262211364, 0.07695591979427263, 0.03832964168395847, 0.007605227892781841, 0.03578605297661852, 0.01968850065168226, 0.05058321970864199, 0.058916146590490825, 0.023257015709532425, 0.025995156574936118, 0.01709134186967276, 0.028178645952721126, 0.05763559674960561, 0.04939918617310468, 0.013670364842255367, 0.0009781142261999776, 0.04836684020119719, 0.04324882283981424, 0.04594494886987377, 0.02167708720662631, 0.019016348633158486, 0.036042275751242414, 0.052590116902138107, 0.034676067225518636, 0.008556124084861949, 0.011747816442948533, 0.043908480802201666, 0.036044272128492594, 0.0815519290335942, 0.05086150282295421, 0.01788242305337917, 0.027588961384026334, 0.07684121344937012, 0.02886320296966005, 0.057540765119483694, 0.08531801679055206, 0.021396432930487208, 0.05085980701551307, 0.0016410394937338424, 0.07452512640156783, 0.06211440973856952, 0.0203712394068134, 0.10008731958805583, 0.03938905749237165, 0.03847576314001344, 0.006931341104063904, 0.017562956309120636, 0.07128043449483812, 0.027478826668811962, 0.026851233196794055, 0.06556488064234145, 0.025109247471846174, 0.058369039034005255, 0.029043149661447387, 0.00921435619602562, 0.006694398862236994, 0.011351776756782783, 0.03710480857989751, 0.008384441207454074, 0.03377608700247947, 0.07999132605618797, 0.05860193610715214, 0.020922272924508434, 0.01636025404877728, 0.015665772662032396, 0.08990293834358454, 0.07478259227355011, 0.011204852853552438, 0.01241401458173641, 0.009792166401894065, 0.05024857789976522, 0.04886519236606546, 0.012564843109430512, 0.008246701381722232, 0.04026956747111399, 0.009774141490197508, 0.031409400326083414, 0.04983270431694109, 0.04951279413944576, 0.0072863822333602, 0.029959850471641403, 0.03826484848104883, 0.04573092832288239, 0.01772498570062453, 0.027232368702243548, 0.05671725950378459, 0.03401635731279384, 0.053751437008031644, 0.062198829036788084, 0.014996217232692288, 0.04999582466552965, 0.020975776205887087, 0.041040206197067164, 0.01386615638693911, 0.008714866689842893, 0.07047118924674578, 0.06702983562718146, 0.032058560609584674, 0.016573374741710722, 0.011564824162633158, 0.03658128647657577, 0.05228578440437559, 0.018101193345501088, 0.06913855919265188, 0.008742552508920198, 0.06329632073175162, 0.014602369665226433, 0.03548353131918702, 0.027863761970365886, 0.01564059901284054, 0.04379562982649077, 0.014381553828570759, 0.05873881782463286, 0.041540666061337106, 0.018776759243337438, 0.01658001510804752, 0.03304528676380869, 0.013989832514198497, 0.029494950613297988, 0.024620322437840514, 0.035624272204586305, 0.021361258841352537, 0.012855862405558582, 0.03786701650824398, 0.0315928109921515, 0.03697614243719727, 0.07228476068121381, 0.013683272645721445, 0.0067293433494342025, 0.033406983566237614, 0.02918108151789056, 0.01331843563093571, 0.05225723027251661, 0.043087687736260705, 0.037025851488579065, 0.02417434920062078, 0.022160772678034846, 0.029097497135808226, 0.036025362205691636, 0.08159581222571433, 0.008013970364117995, 0.09370813728310168, 0.02660073609149549, 0.03638663598394487, 0.045340491851675324, 0.0033272982773269177, 0.03323996323160827, 0.03232246090192348, 0.03170419251546264, 0.026399589951324742, 0.051315812233951874, 0.162395418738015, 0.0070958891592454165, 0.036760774892172776, 0.015424337179865688, 0.03905986675817985, 0.08092138552456163, 0.06862825102871284, 0.02595469653897453, 0.05544334075239021, 0.03713897334819194, 0.035637148466776125, 0.08158755212207325, 0.024534519034205005, 0.06702890052110888, 0.030586614593630657, 0.03523176514136139, 0.025470059263170697, 0.07771196047542617, 0.01634675067180069, 0.05382290582929272, 0.024599451389804017, 0.05729058713768609, 0.021662288781953976, 0.015788731689099222, 0.05442925161332823, 0.045731024802080356, 0.07446956922649406, 0.016409413910878357, 0.00830488019346376, 0.03933835767384153, 0.026532588381087407, 0.045991889710421674, 0.015509711065533338, 0.05465897971589584, 0.040077414305415004, 0.052880693692713976, 0.044413953874027357, 0.012738409186567878, 0.05162395194929559, 0.03174640216457192, 0.03527805660269223, 0.06040192994987592, 0.005589046431850875, 0.0150334405770991, 0.03516804805258289, 0.062250415721791796, 0.030625835242972244, 0.09393078158609569, 0.04614198536728509, 0.04001364155556075, 0.03753997058083769, 0.045518640690715984, 0.06318539934, 0.083520431217039, 0.07879748503910378, 0.05169247444428038, 0.034903413034044206, 0.065694363147486, 0.04035301084513776, 0.032285642955685034, 0.014791411376791075, 0.03154560297844, 0.017419337746105157, 0.02556807656219462, 0.02661139333213214, 0.04244396368449088, 0.028008436238451395, 0.009884146329568466, 0.060749845069949515, 0.017527583695482463, 0.03255448224081192, 0.051757263936451636, 0.0641401055327151, 0.06097678269725293, 0.0197190344624687, 0.06682425329927355, 0.028972710570087656, 0.040843444294296205, 0.05086735836812295, 0.02869470390578499, 0.0035505683035808033, 0.055438305280404165, 0.043242551691946574, 0.046668238574056886, 0.026049511470773723, 0.07312268251553178, 0.02702709251025226, 0.04360354345408268, 0.054811075460747816, 0.08066429072641768, 0.0516531628818484, 0.07188440911704674, 0.055674118993920274, 0.02744710542174289, 0.007000054702075431, 0.01466191402869299, 0.06498861781437881, 0.03593134322727565, 0.04075866876519285, 0.014425801600737032, 0.034871244642999955, 0.019090184905508067, 0.07562924918602221, 0.037304149445844814, 0.0856923931860365, 0.01368758730677655, 0.08406648863456212, 0.026253173491568305, 0.007188290255726315, 0.03569967069779523, 0.029934064550616313, 0.0631794473156333, 0.017557948667672463, 0.04348438793385867, 0.01382334652589634, 0.04876463506661821, 0.07735085368040018, 0.0362362434680108, 0.04814823689230252, 0.02162096785468748, 0.03569418993720319, 0.08889422606443986, 0.036930993883288465, 0.052891317536705174, 0.020316316768003162, 0.019860250322381034, 0.019527775584720075, 0.055583758803550154, 0.026003097555076238, 0.03896721333148889, 0.06728856315021403, 0.0790112977847457, 0.05997458647470921, 0.07159199551097117, 0.02614365475892555, 0.08695558790350333, 0.04616458376403898, 0.02432857119856635, 0.02414664297248237, 0.005250894728305866, 0.02118010615959065, 0.03262807731516659, 0.03931075720174704, 0.04055805882671848, 0.01702364686934743, 0.022292900939646643, 0.04873012891039252, 0.046485417915391736, 0.016066610332927667, 0.058068617654498667, 0.033325907643302344, 0.01185297041956801, 0.02281082168337889, 0.04754067769681569, 0.008618097126600333, 0.05269733126624487, 0.04031835254863836, 0.014511681074509397, 0.024375595530727878, 0.061709801957476884, 0.03091207232500892, 0.045801610467606224, 0.03015815789694898, 0.1367992055020295, 0.1414110595942475, 0.12260679635801353, 0.15847723523620516, 0.12545150035293773, 0.21601306507363915, 0.10100851039169356, 0.10644325782777742, 0.07015686001977883, 0.10092731201439165, 0.11874227755470201, 0.14559242350514978, 0.14737329591298476, 0.2871782291913405, 0.11190292658284307, 0.16910133155761287, 0.08252545609138906, 0.18932365346699953, 0.17193535604747012, 0.3225250606192276, 0.18019853217992932, 0.2254926657769829, 0.11140723872813396, 0.1428279679385014, 0.2220106276217848, 0.1886439649388194, 0.14267741586081684, 0.09958701557479799, 0.2278940033284016, 0.16085918789030984, 0.16692035249434412, 0.11820643951068632, 0.08556363798561506, 0.10215178888756782, 0.15095381706487387, 0.14098373096203431, 0.09516273930785246, 0.17317444580839947, 0.18460454419255257, 0.18663477821974084, 0.1863730969489552, 0.08035779115743935, 0.1746094922418706, 0.1522037124959752, 0.14910990663338453, 0.097979879938066, 0.24327915511094034, 0.13140827446477488, 0.10042000212706625, 0.11304219005978666, 0.15430617233505473, 0.14352560159750283, 0.10788412269903347, 0.1265789265744388, 0.12828574748709798, 0.1338799824588932, 0.09322731464635581, 0.11506245704367757, 0.11407237267121673, 0.1391618771594949, 0.1366008145851083, 0.2254255162551999, 0.11260876097367145, 0.20090225560124964, 0.16210507572395727, 0.13156311615603045, 0.16658033011481166, 0.15241130604408681, 0.14521459612296894, 0.1283483995939605, 0.17742389434715733, 0.11692174477502704, 0.12492086476413533, 0.16875816247193143, 0.12978366867173463, 0.14291475468780845, 0.05787757399957627, 0.16148253256687894, 0.2619036182295531, 0.11534048040630296, 0.16197269142139703, 0.1440774032380432, 0.18195498792920262, 0.2647043648175895, 0.18223234335891902, 0.17060530866729096, 0.1335364719852805, 0.09084697245270945, 0.10917862862697802, 0.12080348882591352, 0.2246149128768593, 0.17996913433307782, 0.1339093566639349, 0.07219651932246052, 0.1014767239394132, 0.136067284620367, 0.13314334151800722, 0.17421628755982965, 0.24444036389468238, 0.09276811819290742, 0.15541963133728132, 0.11828597547719255, 0.1250078741577454, 0.15155771747231483, 0.2027034925413318, 0.14943922724341974, 0.09685083583462983, 0.1201598315674346, 0.2034372094203718, 0.16172365634702146, 0.15803012094693258, 0.11975679342867807, 0.11016949225449935, 0.07115927146514878, 0.16809067485155538, 0.15606109926011413, 0.07970568825840019, 0.12807417602743953, 0.20490669150603935, 0.19923494663089514, 0.11349849213729613, 0.07353704582783394, 0.1545813903794624, 0.14971036347560585, 0.08061938337050378, 0.13210307311965153, 0.208893746312242, 0.09719193432829343, 0.22354850603733212, 0.25508859485853463, 0.14573919062968343, 0.17306117922998965, 0.15713814849732444, 0.17791534453863278, 0.17607355664949864, 0.08298876404296607, 0.1317247113911435, 0.08256002533016726, 0.13856317178579047, 0.2074771496700123, 0.15918549644993618, 0.09796589787583798, 0.11000811966368929, 0.16247398249106482, 0.17588856891961768, 0.09340509612229653, 0.18524626444559544, 0.13747601449722424, 0.18616082787048072, 0.2126587208476849, 0.1861308451043442, 0.15195252519333735, 0.10797262380947359, 0.10248381091514602, 0.12589683348778635, 0.08429066918324679, 0.10414472999400459, 0.08862340153427795, 0.10756138493889011, 0.16575567045947537, 0.16086505085695535, 0.11772240337450057, 0.2191266862791963, 0.10704873158829287, 0.0775581800553482, 0.12246202561073005, 0.15152230218518525, 0.15993646084098145, 0.11293540985207073, 0.137504973099567, 0.1511833188124001, 0.14090905606281012, 0.1371338398894295, 0.12791789456969127, 0.06887926763738506, 0.08463839505566284], [0.022823608887847513, 0.054640900998492725, 0.05949976039119065, 0.036443688586587086, 0.04850001489103306, 0.0408133464952698, 0.041394956497242674, 0.0054084086150396615, 0.0261486234376207, 0.05442330329969991, 0.018469482274667826, 0.033087993651861325, 0.04955245822202414, 0.023794100561644882, 0.0490631751017645, 0.03801189115620218, 0.06152489215310197, 0.026562790080788545, 0.014131313691905234, 0.06801639479817823, 0.016368612486985512, 0.026435361469339114, 0.015722680545877665, 0.02825508901878493, 0.02274554793984862, 0.006945995737623889, 0.026518161030253395, 0.038806026277597994, 0.02059082420601044, 0.008404023701586993, 0.0593089059839258, 0.041230407514376566, 0.03926370132830925, 0.015689161446061917, 0.016457790807180572, 0.022659738970105536, 0.09612998037482612, 0.04627336405974347, 0.01696018582151737, 0.026529245005804114, 0.057697410229593515, 0.030008167996129487, 0.031987837646738626, 0.0334726079745451, 0.04974277086148504, 0.08702197301317938, 0.038623094296781346, 0.025182015051541384, 0.05965967837255448, 0.0006927365279807418, 0.021370112663134933, 0.026315554714528844, 0.018075854568451177, 0.048867485602386296, 0.025307449141109828, 0.011832317377411528, 0.07483391178539023, 0.06547062046593055, 0.05485158930241596, 0.057866285933414474, 0.06226688768947497, 0.022768090675526764, 0.028948544386366848, 0.015266853442881256, 0.011022760427294997, 0.016737630576244555, 0.04089279711479321, 0.04475735673622694, 0.11284826687187888, 0.09547603694954887, 0.06844403513241559, 0.0345638878934551, 0.03121087582258042, 0.07429212171700783, 0.041919354334822856, 0.018005205820372794, 0.009945686142600607, 0.024753786565270275, 0.04491090337978676, 0.06371863244567066, 0.11005060761817731, 0.03362757954164408, 0.06848228542366996, 0.0663403952785302, 0.012268643622519448, 0.16573232249356806, 0.027149821471539326, 0.02506973181880312, 0.013092063891235739, 0.038367116430890746, 0.024257905752165243, 0.023068753253028262, 0.03195210694684647, 0.027528121972864028, 0.04381782375276089, 0.04982847778592259, 0.00785585672929301, 0.03770984818402212, 0.02102400281728478, 0.06111340095230844, 0.01948345081473235, 0.019324584827700164, 0.05731358629418537, 0.03424882022954989, 0.02520573223591782, 0.011854961230710614, 0.02977693704451667, 0.0069054475716257, 0.03317739276099019, 0.0613552891445579, 0.02842326710378984, 0.07531342082074843, 0.026646003389032558, 0.08245394274126738, 0.07962262709042989, 0.018870303247240372, 0.07704358969931491, 0.04377914301585406, 0.09492525947280228, 0.07630280757439323, 0.04113453316676896, 0.04990891546185594, 0.07868781787692569, 0.06211574931512587, 0.02113081642164616, 0.09651539250626229, 0.02621170784550486, 0.02655292693816591, 0.054062500785221346, 0.024615834299765993, 0.033168357113027014, 0.05570829118369147, 0.0453680292412173, 0.060368459089659154, 0.0435341786214849, 0.07737595311482437, 0.0564354957168689, 0.04047674541652668, 0.050098062929464504, 0.011121216521132737, 0.01765460598107893, 0.025468693711445667, 0.0022290168908511987, 0.02132195841113571, 0.07286617401405238, 0.013788451669825008, 0.10964719840558246, 0.04932229967380408, 0.03846879808406811, 0.02750380735960789, 0.0857975184044335, 0.06366169487591833, 0.041896503607858904, 0.030457191460300237, 0.048102821165230125, 0.017559039624757133, 0.07219697203254327, 0.05488022507051937, 0.06345542977214791, 0.022985129908192903, 0.035196067838114686, 0.005597927620328846, 0.006711339774483349, 0.009369581948703853, 0.014242401139199501, 0.047996475113905035, 0.058406988755450584, 0.040545293886680156, 0.0295608570377226, 0.018872383116104174, 0.02086178974423092, 0.01971046265680343, 0.02264749909954844, 0.05933058782829903, 0.024308022984769195, 0.07495145313441753, 0.01498238452768419, 0.0528159969690023, 0.050399645770085044, 0.008540745857317233, 0.03354206186486408, 0.10043717542430386, 0.0435751229088055, 0.031605394106009044, 0.047181834452203475, 0.01971127901924774, 0.02293550434842473, 0.005396965625550365, 0.06067609785532113, 0.004783418689839891, 0.029389875489869155, 0.01883565422758693, 0.0037117500232852763, 0.015021627441456076, 0.025307573450845666, 0.024162064801203087, 0.013748125220445218, 0.0338486504915636, 0.088497236429248, 0.010290601130691357, 0.013836884227202972, 0.0571581471740501, 0.04970430163666606, 0.03603669108997565, 0.05344924189557787, 0.017461003772041295, 0.008222616834245855, 0.021333591575967148, 0.02914828415669035, 0.028338855227048043, 0.011640069587883772, 0.01208745568874292, 0.015005489440227393, 0.046960099280113354, 0.011253816046519205, 0.017509890894871205, 0.04985185914847534, 0.039690532721579075, 0.06326451970380731, 0.04671034803322982, 0.036061864739167504, 0.14347230055136606, 0.05733570971642621, 0.03482896448986139, 0.02912643347372068, 0.05010474596929271, 0.07018040836555883, 0.04563608927128371, 0.025498917675577104, 0.036027288078912534, 0.015911536720523145, 0.04269128810847178, 0.025855001986201387, 0.06410243411664851, 0.04432147856277879, 0.02218459932919359, 0.05364485346945003, 0.04098113495274447, 0.044020897621521726, 0.090949411096517, 0.026324638602091, 0.052696058482979424, 0.03759331244509667, 0.014397153772733873, 0.007334037391046877, 0.04277266460121609, 0.07159091939684004, 0.02127736090187682, 0.030103851240710355, 0.1473816970246844, 0.08627453382359818, 0.016529135318705812, 0.01677076561463764, 0.046121865743771195, 0.041762260225368664, 0.03649742378911469, 0.06980617297813296, 0.017621500628592912, 0.06254825813812204, 0.06306059978669509, 0.01157846576461452, 0.08008698147023097, 0.02422139950795099, 0.024470313983329106, 0.014547179853252601, 0.051253375349915586, 0.0635067789698951, 0.044676792895188555, 0.020810451678698882, 0.062065253587206826, 0.04683117338572629, 0.03541447076713666, 0.0167508333834121, 0.07562181286630221, 0.02873330857255496, 0.02496119457646273, 0.031086267372302245, 0.03634209599113092, 0.06114277144661173, 0.024280316756630782, 0.02556489831476938, 0.011413176489440957, 0.010566267246758798, 0.03579871030524373, 0.05529409485461656, 0.030769251570745837, 0.058291235982324, 0.07960552800795995, 0.036172203544992954, 0.007240202558023157, 0.09271731076296419, 0.03938736168493051, 0.056569171356386505, 0.08517468580976129, 0.07555816628155299, 0.03566640392818954, 0.0559286088537192, 0.09797019491088577, 0.09336755087133497, 0.06731158457114361, 0.04651976822060533, 0.039862154371803626, 0.053311091105570085, 0.04821903035917785, 0.05574524271651171, 0.03801220656896476, 0.02854571404895978, 0.03087158445850946, 0.012377336715871934, 0.07893011425039731, 0.020339134098321665, 0.04692911832535174, 0.05879559583263472, 0.08668455557199195, 0.011689735965774162, 0.04956779841450043, 0.09350530832307413, 0.017182531410071533, 0.02328197042515967, 0.04480698786210269, 0.06948082285816781, 0.012975777699466562, 0.07544058782514185, 0.05180539963475894, 0.055690416556899436, 0.028111054853070527, 0.045292500872164965, 0.054522161080967635, 0.0019674687428050674, 0.10071612647152506, 0.046728003726457246, 0.008116337576211663, 0.10672622389392927, 0.0247363850576221, 0.019658792480186094, 0.00836746457935078, 0.030147918114380445, 0.0634146413358394, 0.045586465566884726, 0.12601931754034013, 0.029123212552804034, 0.03199014943675138, 0.0178558578772936, 0.07261877166456543, 0.039481491985497996, 0.07034472728264518, 0.020833037087868433, 0.032621609498164617, 0.03852656685921829, 0.0362634654447902, 0.035358917302801274, 0.030983606084191706, 0.10223652730928734, 0.224137504119426, 0.17498717119451612, 0.1802724797744304, 0.19315231911605224, 0.2189379878109321, 0.1359465075074695, 0.12449545829440467, 0.17163301992695779, 0.10754536197055131, 0.14980941050453112, 0.09637416180339642, 0.21625877532642335, 0.14685590023873374, 0.1753892222768627, 0.11300329410005361, 0.1520264579448849, 0.11958975825109519, 0.09476981664192863, 0.21623830689350143, 0.11609802022576332, 0.09353540983283892, 0.12397672675433569, 0.14580920484149829, 0.0933687828364782, 0.12420688901329413, 0.15652982488973066, 0.13253690296551213, 0.11493547557620332, 0.11029237706679851, 0.08783862489508465, 0.09965755671146326, 0.1247979947947897, 0.10949758143397048, 0.09844108019024134, 0.08692501884070225, 0.23325821704929695, 0.1013343503291253, 0.09487258925219066, 0.10621150737279095, 0.2079925563884899, 0.0733808014774695, 0.10999761085258797, 0.08756474271649495, 0.1997491213842295, 0.2137810262502171, 0.17800708883441985, 0.11204371941857971, 0.11595148316700943, 0.08634253681520931, 0.09459314096602611, 0.07519151564338244, 0.0927306991070509, 0.14788191940169781, 0.08844506344757974, 0.11364119971403852, 0.14931850950233638, 0.16928771452512592, 0.13713400316191837, 0.1331701924209483, 0.147956594300922, 0.1466754692955874, 0.10558323483564891, 0.13710360479308292, 0.11684550394420512, 0.12976322992471978, 0.2303642121842131, 0.09823458502069116, 0.08740287288674153, 0.1450649939943105, 0.19521943788276985, 0.12359167085378431, 0.09219178857165389, 0.266533907270059, 0.191049087443389, 0.14206830557668582, 0.09291706723161042, 0.18486089684301987, 0.1552987948525697, 0.3146460943389684, 0.2403906124527566, 0.1765767327742651, 0.1941575581440702, 0.13494254497345537, 0.09522694992483594, 0.1905725395772606, 0.10831404142663814, 0.1348467040224932, 0.06841957394499332, 0.09289587891544215, 0.19397288211621344, 0.11235453828703612, 0.16520622884854674, 0.1983066534739919, 0.15438256901688874, 0.20657636050600559, 0.0799553764227312, 0.19795546919340268, 0.07840226171538234, 0.19295128615340218, 0.19628173322416842, 0.10273268271703273, 0.2192095248028636, 0.09890308938338421, 0.12136277131503448, 0.11370283507858403, 0.11747858559829183, 0.06008426476910245, 0.19547956064343452, 0.12438395802746527, 0.20386438962304965, 0.20274061476811767, 0.08081894688075408, 0.16331479127984494, 0.14753658324480057, 0.1231234944134485, 0.24463413865305483, 0.16711748176021501, 0.16804973798571154, 0.1454033688060008, 0.10401532912510447, 0.2650654938770458, 0.2389949740609154, 0.2640984457684681, 0.08296927524497733, 0.17751105217030272, 0.0808915808738675, 0.1197593093093019, 0.2688429068075493, 0.1425394951365888, 0.08971841816673987, 0.11109083890914917, 0.11312732924125157, 0.1712672004941851, 0.08743387981667183, 0.13081952871289104, 0.11449792014900595, 0.15855573961744085, 0.1109260153316427, 0.11938164519960992, 0.13701249874429777, 0.12953074474353343, 0.1108505685988348, 0.1434896668069996, 0.16405125410528854, 0.2225584365078248, 0.3117477404884994, 0.12915077997604385, 0.10972762494930066, 0.18924560921732336, 0.2093055343721062, 0.2346110186772421, 0.104957500443561, 0.2270387375028804, 0.19112420763121918, 0.1260472519788891, 0.15143530763452873, 0.16259266674751416, 0.15551198419416323, 0.1499858932220377, 0.12643631547689438, 0.12486216088291258, 0.0982565971207805, 0.16015913482988253, 0.12897020060336217, 0.12311799509916455, 0.14163867628667504, 0.18747463705949485, 0.15681788208894432, 0.1463561676791869, 0.10176397961913608, 0.11383486315025948, 0.11046195781091228, 0.1754606465692632, 0.06167685060063377, 0.09181223940686323], [0.02118816031725146, 0.07843400337151252, 0.09779028347111307, 0.04303469097067136, 0.07621845506946556, 0.05290478751703631, 0.0527607329422608, 0.027656828933686484, 0.04160372634942178, 0.017612303563510068, 0.018978076077473816, 0.030740062902623322, 0.009129942463914631, 0.05911859705520328, 0.048200053643085994, 0.05433278354757931, 0.03771371477341745, 0.03135641469270922, 0.002654156651260564, 0.009360069470858434, 0.06777450660592876, 0.025583273891243152, 0.019339368409418967, 0.04100613048649393, 0.01736765272653429, 0.029675177465833258, 0.06271756428759545, 0.010861008413485251, 0.05904977399040945, 0.0024743430822127266, 0.016071120735432487, 0.01775044136593351, 0.053592591430060565, 0.014733713105670176, 0.013494069517037133, 0.044094362820032984, 0.014831499411229743, 0.06654009237536229, 0.009604971710359678, 0.07536060657002963, 0.06714489820296876, 0.028993386804359034, 0.013450945170916384, 0.011529499788593967, 0.054179403887246735, 0.050029276972054504, 0.04929919290589169, 0.01439547002519248, 0.07372382955509238, 0.041187221941072494, 0.011232841097807977, 0.04293654565117322, 0.12607811047928408, 0.06644405846600421, 0.06775636109523475, 0.04244003401254304, 0.019264415204816032, 0.03840688441414386, 0.05805190448882058, 0.051513012003852054, 0.049593124203966, 0.04800367394636851, 0.01442292021238245, 0.05739541920775082, 0.046826464458717965, 0.015405496833409416, 0.05044630088377744, 0.0025129250207100995, 0.01017427504848456, 0.10250536288367584, 0.06198500515893102, 0.018180640254286118, 0.02772477440885268, 0.06702647369820625, 0.06314546437351964, 0.009030060518853134, 0.024787159090919886, 0.04062120817252435, 0.11312341812299564, 0.024003224789339583, 0.050485278479754925, 0.01836434777942486, 0.10644698340911418, 0.01545743511087494, 0.013221732860984048, 0.04683512532210443, 0.04471737724088598, 0.02244883173261769, 0.06963084058952518, 0.027427740933489986, 0.0022498025919048814, 0.06987819841015153, 0.058609320476534776, 0.04623068314685952, 0.04431611283507664, 0.03305415542854462, 0.015490144342038548, 0.04276809668226633, 0.08725328560103662, 0.030496953877445776, 0.06786289639421739, 0.0034537300916781533, 0.03863373298372608, 0.06778502283850685, 0.005979231500532478, 0.019126299666822888, 0.010843213567568455, 0.04141423378314357, 0.046750873007113114, 0.023675677912251558, 0.13318874611286446, 0.06260824593482539, 0.043424763789516874, 0.058462119195610285, 0.005857057758476003, 0.05897335504414514, 0.0185295980918454, 0.09511792843113653, 0.09061395292519592, 0.05809221423987765, 0.016881959745660424, 0.05990615303744562, 0.06903960122144781, 0.01831685032811947, 0.03492072362860199, 0.05009585875086486, 0.029117869089532178, 0.09749074524734169, 0.053625123473466374, 0.023707636646577157, 0.05062683572759852, 0.03348768470459618, 0.05046154088631738, 0.02971256686578272, 0.021451904758578166, 0.03049888531677425, 0.032462864110129885, 0.11304506959277205, 0.014209059227141552, 0.04553533530270215, 0.02878223836887628, 0.02821751779265469, 0.10319924127543345, 0.053851311531616375, 0.05563249935221393, 0.019910480732505675, 0.04879014268226456, 0.017267123257624917, 0.05959594273008406, 0.021631164963764604, 0.028927497078257147, 0.059676391538232565, 0.010887302705668844, 0.06165481994685251, 0.027374690362194087, 0.03107867705693934, 0.04336974838224705, 0.026119870781258214, 0.05359001246688422, 0.037031647661933675, 0.013950617430964485, 0.09242155007086694, 0.009268519988836488, 0.03089870067924494, 0.025651477262726985, 0.06340641833958216, 0.04953548530465923, 0.0261145403055707, 0.020211985647620168, 0.019186632562195882, 0.06063807762984652, 0.019401484314585105, 0.06760420597856864, 0.05600296091870405, 0.050660685083130375, 0.03105983207206009, 0.013527451319532702, 0.0054444751367555, 0.03177757236699108, 0.032382660210714675, 0.03421729379624594, 0.017793480365071446, 0.01956166761374334, 0.017002423301164526, 0.07525091714342125, 0.02548711752751842, 0.0707096116093453, 0.049300224491162226, 0.020877243114227895, 0.062334348913282156, 0.10892200880334713, 0.07854779687477276, 0.03943696683563758, 0.06814914275310002, 0.03201825456926599, 0.015839346160646528, 0.059412880873424, 0.037172926604398526, 0.10820107912877575, 0.006916461043147137, 0.04241316826664843, 0.02456849455484189, 0.03369593505340163, 0.04284237453248352, 0.04833758845052216, 0.0023478852926928084, 0.014840766052657273, 0.05437776511826087, 0.08049528143601492, 0.01229573943419382, 0.03431323122640606, 0.04868965959758498, 0.06880335335154086, 0.05665823278832249, 0.07348978586378507, 0.10499976575374603, 0.062332775560207665, 0.00824747414299054, 0.03965659059758764, 0.007039724350761389, 0.02266397848870838, 0.11439125868491828, 0.019531332327460404, 0.04506839453824796, 0.07264114741701633, 0.03313268949568737, 0.03906193363945931, 0.09550687318551354, 0.01130535356423934, 0.04870426877459977, 0.02934842097602086, 0.017044193227775395, 0.044044501628377475, 0.035257116905995645, 0.05252801398455631, 0.012685837300523417, 0.03082504066696856, 0.017803690461732913, 0.034297939273528755, 0.055649342393735424, 0.041869960696203634, 0.04717867290310096, 0.05934005392191466, 0.036490484708338045, 0.07972160732606426, 0.025306308089056984, 0.03757366037461907, 0.01973644339159364, 0.041132024707621895, 0.048284331933245994, 0.029256366833578795, 0.033144808767247014, 0.022125797113403678, 0.017571559656062163, 0.03759186154638883, 0.021085584376123734, 0.027113146388728637, 0.011735546886484371, 0.03368596801010426, 0.038658691410091706, 0.032036426055128686, 0.027017594875360373, 0.08085164590738714, 0.07707403259701096, 0.04778115951921791, 0.05950502221821807, 0.03519816069456283, 0.023971128757693805, 0.03070974060392473, 0.05328021776222158, 0.023625556968909223, 0.02788298916129861, 0.028985469944018405, 0.07460777196683921, 0.034094486909452826, 0.036245995288481936, 0.07986621480085887, 0.026140680602111388, 0.0643641673377715, 0.07108734251232818, 0.017222501628566533, 0.019019146529899444, 0.08972129027824849, 0.05588671461737249, 0.07351051404839382, 0.018555690148787107, 0.06142051279312, 0.023928735427034553, 0.04040582578454632, 0.08591718229581602, 0.06397233562893234, 0.0795802430366166, 0.008093224314507097, 0.06913645891472697, 0.06559262954397127, 0.05067213642178103, 0.007874504117353354, 0.01864008532720618, 0.07933151224278845, 0.03776824778469745, 0.07522158746724017, 0.014751179551240057, 0.0563407716981601, 0.02314972156455042, 0.04931865201797336, 0.056372168255620636, 0.040454150730511174, 0.06350421856041066, 0.07152525417041034, 0.029508810221159365, 0.0216356586679467, 0.018623420401127078, 0.033945070317713544, 0.026334846843383275, 0.11562757281353697, 0.01509028630607645, 0.026197473453066777, 0.04941684928780887, 0.10506005783099681, 0.05679955254890956, 0.0788683230348397, 0.012024206153000705, 0.10571522579994053, 0.12837241549277678, 0.02000932738155825, 0.08625338261481375, 0.01279109146707924, 0.04136966781516094, 0.04121674828638788, 0.09892493078950793, 0.05314693917171098, 0.020265058483346365, 0.007091925626809825, 0.017411419030395336, 0.007326805161937955, 0.07022269594017416, 0.03115154853730928, 0.0686310043965932, 0.004516162034633453, 0.04376571385364514, 0.04182586228125729, 0.07412149454466999, 0.04876969651377294, 0.05003788217436522, 0.02806639611662831, 0.01433087812984013, 0.0641175961936824, 0.0251349369136733, 0.021734286383434664, 0.030232869903557003, 0.037817678530700505, 0.09050096094142646, 0.0950734737853054, 0.17780163267161697, 0.1640948181739077, 0.10584683084744029, 0.14886992576066405, 0.14077481639105827, 0.1212902412225958, 0.10750586487120017, 0.15580400446197018, 0.11896639873157255, 0.14556091191479936, 0.10730354799306951, 0.08467688283417374, 0.25857434375211596, 0.1914204136119224, 0.33098426763899624, 0.16979151405394077, 0.2066722756717354, 0.20753910415805876, 0.09667260907008313, 0.2533117152052, 0.1280486461473629, 0.19945052568800747, 0.12244076307979412, 0.17294509249040857, 0.13876200799131766, 0.15294398996047676, 0.0956135569140315, 0.2269745120429434, 0.11932349050766788, 0.08092607589787804, 0.1386857300531119, 0.1150923062232323, 0.10367257564212196, 0.10500611853785813, 0.10187755047809333, 0.12071633100276813, 0.12302636954700574, 0.20159497624263167, 0.23479144962038845, 0.10577897628536448, 0.1125871273688972, 0.16679904103511944, 0.10294935273122974, 0.13907810352975503, 0.24500924977473915, 0.14928138727555051, 0.2824377460638061, 0.11763947579311207, 0.14770387817407027, 0.26055059395730495, 0.22495894285384566, 0.24719477078178898, 0.14508611551718786, 0.14300700364401564, 0.07885440776590258, 0.15581299929181114, 0.14248568943003193, 0.17325177759630606, 0.11375157933798619, 0.11690800020005554, 0.15184099524049088, 0.19027671951334924, 0.10679110244382173, 0.07468453230103478, 0.14546879654517397, 0.15936671406961977, 0.12428643240127712, 0.09511474461760372, 0.13723503914661705, 0.16677737032296136, 0.1371268488583155, 0.12106003443477675, 0.11814804733148776, 0.10535981869907118, 0.11160122128785588, 0.15357070398749784, 0.12641863751923665, 0.16117133520310745, 0.17794578743632883, 0.17869690025690943, 0.13137514499248937, 0.19387459207791835, 0.14038303663255647, 0.1336093805730343, 0.12132714822655544, 0.19017449609236792, 0.17234171158634126, 0.21768056700238958, 0.10102513449965045, 0.10523898221435957, 0.17195349413668737, 0.11765524643124081, 0.15567635506158695, 0.1177747841575183, 0.1006710558431223, 0.12928666721563786, 0.18400793167529628, 0.19946853019064292, 0.08105314642307349, 0.2638480154564604, 0.06651796895312145, 0.08874122489942238, 0.18065346870571375, 0.11318259697873145, 0.1152412107330747, 0.14724460750585422, 0.16132772056153044, 0.15786911942996085, 0.0676961061253678, 0.20459913066588342, 0.17894694465212524, 0.24893957481253892, 0.25592918100301176, 0.14408449816983193, 0.1976272914907895, 0.09467135590966791, 0.19952828792156652, 0.23609169234987348, 0.15799390414031222, 0.10470022752997465, 0.11163346760440618, 0.1599927304778248, 0.0684414895658847, 0.23762293596519157, 0.09790207317564636, 0.17212194681633264, 0.1293431594967842, 0.17153588763903826, 0.09582198166754097, 0.071405330527341, 0.1304420130327344, 0.12118285987526178, 0.12626018899027258, 0.08163091581081972, 0.12758293363731354, 0.17292192263994366, 0.17227692209417, 0.22983688657404855, 0.15794281469425187, 0.11211267978069372, 0.16859394003404304, 0.29649117321241647, 0.1266405248316005, 0.20252779650036246, 0.1202638509857934, 0.1812354609137401, 0.2733868395444006, 0.19412043591728434, 0.24522473977413028, 0.1443905450287275, 0.26645054924301803, 0.2556982246460393, 0.3014603565679863, 0.10186071856878698, 0.13555040844948962, 0.15886523004155606, 0.1178553442878183, 0.11011257694917731, 0.122084554459434, 0.09722317874548025, 0.2388449414866045, 0.11513387391460128, 0.22254650277318433, 0.06684829146252014, 0.11257155711064115, 0.16876444104127586, 0.17871138697955757, 0.13844444300048053, 0.14183653285726905, 0.24790813797153533, 0.12760605895891786, 0.11034810493583791, 0.1749274431494996, 0.11919184835278429, 0.20505179621977732], [0.04347090682131238, 0.026168358999711927, 0.05145423761860002, 0.011496481638459954, 0.026638355557224713, 0.05598990283033345, 0.09763510039192624, 0.008860295165504795, 0.06867375952424482, 0.029011298538534902, 0.022722428184351884, 0.029224152058304753, 0.07694444619119167, 0.011406107532820897, 0.013853009240847314, 0.0033149334012705367, 0.04460696793103125, 0.0500282602297375, 0.018940755326184444, 0.059538637797231786, 0.02427825915219728, 0.01656324071518611, 0.010879173405555775, 0.05693203704140615, 0.019577375169319566, 0.025947262074623723, 0.019953580958826933, 0.05327520826540422, 0.007369279201157042, 0.0256242293107789, 0.05727727300836705, 0.04067246460181195, 0.04313223886128981, 0.055295363927143626, 0.044636720631388016, 0.014141311348794261, 0.014951278335502138, 0.09321258301497437, 0.024999090492201503, 0.02550196604715893, 0.01887660222564591, 0.03273395210271701, 0.044868701152154244, 0.021196784073254094, 0.10976085090078413, 0.02778973645035876, 0.053475458262255415, 0.0517171471437905, 0.07218175800517201, 0.021648048823408317, 0.027858965841005556, 0.031320717389462516, 0.07481664943043143, 0.020225455627951305, 0.017115307673520874, 0.011555234686966287, 0.011032905586034758, 0.001248353967184812, 0.03491536161163822, 0.06868069860502146, 0.057893908669939265, 0.023621551226824522, 0.01644672538532177, 0.024764527297520544, 0.025751466819201596, 0.0450041356816655, 0.017959432007046416, 0.019784966862061992, 0.011440416092227679, 0.009735451476444723, 0.051011257091886364, 0.021998986339895055, 0.03309766012534965, 0.012507162464316934, 0.07090818806318566, 0.10503712546778843, 0.03467974456725642, 0.038393440408981405, 0.09631678636651486, 0.08767692575929686, 0.14953627047361806, 0.4628578538540751, 0.40814770676661283, 0.18949419900309294, 0.016534174501430243, 0.055441118020098656, 0.0933922866533976, 0.056901211937656626, 0.010195982868026476, 0.12113154778489843, 0.06883674999698997, 0.01455627394534531, 0.08072629716480151, 0.04838178705540486, 0.08315407743793912, 0.038298582803690806, 0.03191258387232665, 0.06989387999055907, 0.06159167431178503, 0.02058025787846418, 0.07636180831468664, 0.017533602513140067, 0.04134525115659926, 0.07061602678732015, 0.08625182410469279, 0.0786715277354233, 0.1865440877736546, 0.02218850117060356, 0.0033536558839841746, 0.04680854530306533, 0.018961466812470462, 0.005830496756971115, 0.03195290104486048, 0.042946902322000824, 0.04834369261516258, 0.046636623083031736, 0.024358127229788806, 0.010513861416256987, 0.03611328444094397, 0.03640688177256379, 0.011707993726304267, 0.10388842187239788, 0.013056047464488074, 0.0302751426352188, 0.04514037173066754, 0.026625000609783456, 0.03480373889033217, 0.046470660308841616, 0.020786480308743194, 0.014774695428059204, 0.045194370395620354, 0.03847623440378811, 0.13744062889600173, 0.030825139001535717, 0.07026298713753931, 0.06765413025277667, 0.09877473494270816, 0.01937555367476307, 0.06840953268692829, 0.02617991980514489, 0.03669023746624589, 0.06510849692858756, 0.0572121050208807, 0.024842057609930634, 0.044857134780613706, 0.05174936377443373, 0.024073470922303386, 0.04043941538839135, 0.03839667988358997, 0.0753568513027858, 0.055902429594425485, 0.01783524658094393, 0.018742692809610162, 0.057145619721268304, 0.04145312232139986, 0.02113520251441514, 0.02859959397028433, 0.07335691174375825, 0.04432250643731095, 0.015030357881187228, 0.04151875415118411, 0.0634753935446497, 0.05927378384512849, 0.02679139197425684, 0.11957216935115866, 0.021552938887907658, 0.031021210706967395, 0.04388062057842035, 0.03473741315247025, 0.020717584884550888, 0.008128444787871558, 0.07334721929510124, 0.037340447888709605, 0.032242735687759705, 0.033930223653442226, 0.014404038120119367, 0.008334337890119059, 0.026156699859711807, 0.05497909769474063, 0.027891666723007802, 0.05674096741131507, 0.01641119506530231, 0.017059648453141563, 0.009393709169671638, 0.06878604646772146, 0.025908922725648154, 0.05972968145215418, 0.025424727027711924, 0.025464482023380697, 0.04557855427265167, 0.05750226249801926, 0.017245985036424827, 0.032441531075164676, 0.037967803873470984, 0.06752576096914709, 0.05462954242830165, 0.051240165121271275, 0.03925501077901572, 0.04414729279233143, 0.019764518838201184, 0.05608384759398177, 0.05710813384212088, 0.03959679575928021, 0.06752282948582433, 0.020656682390836067, 0.01401360814270447, 0.05742619607190136, 0.030781137065787334, 0.04723112790088635, 0.028053512432961725, 0.05467451657750644, 0.023751549524604343, 0.035750689639826305, 0.03267616106313653, 0.010782970657601254, 0.028702314630209003, 0.03195066346961539, 0.08742765319766477, 0.01878908817161573, 0.038446826802100986, 0.04514112129982095, 0.055982392295845784, 0.10207174826064147, 0.03363743155205157, 0.013064083068456966, 0.03200391627615318, 0.018076915839628782, 0.09698136476799846, 0.037419735235744156, 0.04983900143997744, 0.0968545391515363, 0.04564568153000437, 0.033258453840971924, 0.023274990526260808, 0.06422563063097186, 0.062144080802681856, 0.022546164400409907, 0.032010706927394494, 0.018073899009323213, 0.048004657292040065, 0.09376359055750072, 0.07156561216106638, 0.012598339944815962, 0.04280474393453915, 0.06512956650112756, 0.0571654944360489, 0.040511392580810934, 0.03584500547731295, 0.043399438000051305, 0.031625947885913774, 0.02987665015098173, 0.013291809227666818, 0.036251156925573014, 0.017020275663526263, 0.0693372766545508, 0.05003747399314307, 0.17107378196669742, 0.2904865157324821, 0.2792676177341491, 0.09765313458046876, 0.051084599836030975, 0.11211121032829396, 0.03921662690117955, 0.06447829480748624, 0.011861809398396872, 0.030831708863843232, 0.023301464789255988, 0.01735575238853926, 0.0266810513130622, 0.022430689932662062, 0.13408291531959549, 0.08247331279562786, 0.09462748756050132, 0.1119337257114239, 0.11274892298388295, 0.030681605785503052, 0.08444513980066404, 0.0523813915788196, 0.03228963199944701, 0.025800214789342135, 0.023213223430502694, 0.05981371854431927, 0.09992705279728398, 0.06183970006532036, 0.0502092106762575, 0.04002606510766782, 0.04012773933936842, 0.04337198224675376, 0.03238178076571785, 0.06311787132290192, 0.045972656953381374, 0.0774033012567088, 0.027385776193113998, 0.043379689450375736, 0.025890148244798183, 0.029516394970414694, 0.10384757406427525, 0.06499268478364684, 0.017447133031964768, 0.042479208277654834, 0.0253119038825389, 0.02884793699195143, 0.09321995996288024, 0.02766768098808825, 0.04408343469549436, 0.02208125155448215, 0.04401099737151526, 0.022974147977947723, 0.09480154345510527, 0.06987133354414254, 0.0643234456947539, 0.008547646903025452, 0.011494384143588832, 0.05365986711694859, 0.049114398134406656, 0.0757534104923252, 0.0158512817506562, 0.011576501856325194, 0.05646469922794495, 0.03401090994884726, 0.09151814854703844, 0.020706554714706726, 0.015428998794959625, 0.07205221612821333, 0.024753738325671293, 0.0740785984089598, 0.01852265530033037, 0.019056192686548457, 0.04860065753746312, 0.019064822008658666, 0.06803730851970613, 0.022050877305446193, 0.021476931833603885, 0.0529999790887814, 0.002653585429470695, 0.024928506682044826, 0.029449642497638706, 0.05308470637828577, 0.04852601603488438, 0.07389733626041561, 0.025059697982214857, 0.04060062099597417, 0.002602575764285575, 0.037687509538955055, 0.0067349015716899885, 0.05282639445795212, 0.08173126901965588, 0.04079334561538417, 0.06901002663653344, 0.05155145154276397, 0.05558852710237261, 0.023322128035943024, 0.11611592082772404, 0.09020341909490526, 0.12977361999219283, 0.07042078257654794, 0.1125051052076742, 0.1502315144171007, 0.16059510206105188, 0.19256125786341727, 0.1353918411768973, 0.16646690026391298, 0.2677273697918281, 0.13663063407875597, 0.13643957558088005, 0.1255202677566558, 0.08694653370184824, 0.06578984786756337, 0.16613342362688854, 0.17159576411359012, 0.16731467039790004, 0.13228850613813847, 0.13738661538809538, 0.15888342750258744, 0.15516188344918191, 0.17529278760775924, 0.09577887773048133, 0.09554999196552671, 0.10561746268649586, 0.15794722305145115, 0.1202500173531007, 0.09153470586170442, 0.13805770984617993, 0.1236403186339885, 0.14047040225705132, 0.11410071529098786, 0.15181448572548106, 0.16547763225389645, 0.06919630570337176, 0.25331447599455714, 0.07811454590409994, 0.06161170487757772, 0.09995555126806721, 0.11083140634582378, 0.12186445572297089, 0.05932808679062873, 0.25208135310094804, 0.10670649018720724, 0.16160535800736398, 0.16115515638375655, 0.13605748827103525, 0.1438610820332542, 0.11085531834396534, 0.17958744778297842, 0.11373133354936726, 0.12010871243546717, 0.1358421318582259, 0.10359035310102627, 0.0691691653628368, 0.1234580842719879, 0.12933144840644673, 0.319822040037252, 0.20844450948061422, 0.13977970025734976, 0.12310252874158323, 0.1472962016123347, 0.3234945429721847, 0.2400627316092141, 0.09870325869997032, 0.15113178407773376, 0.1584845973411575, 0.17785425094189122, 0.23588926414959133, 0.2009861628175713, 0.13809048308758065, 0.28747538512106985, 0.2827691298443824, 0.13932670815847814, 0.11079455871367827, 0.1560702722053975, 0.14403676323127002, 0.18621867086039856, 0.45155821018852293, 0.9176587744150311, 0.5078916123602539, 0.4277343791909516, 0.15839976986171678, 0.227296574448701, 0.16509300679899752, 0.23333624645601958, 0.11902671307325363, 0.20273105590604246, 0.10319476612494327, 0.08905355032766238, 0.1777064151247032, 0.10802064076415263, 0.2715494896983728, 0.22982386930380017, 0.19217390130506828, 0.1491248089587316, 0.17519651621114463, 0.1959840429481119, 0.1971812904230319, 0.11328254200634547, 0.14622069604229182, 0.13609110756078735, 0.20855584647506475, 0.1414661863236688, 0.3427693055709824, 0.15588794136419892, 0.16808384709293023, 0.12195752104162239, 0.11440503294579685, 0.19118092255666852, 0.1798807890736498, 0.08353022756637074, 0.10255312008666806, 0.170814891171176, 0.1580275531159714, 0.20662216586060822, 0.1169056401704438, 0.11639179938356392, 0.1540861849207431, 0.2538259048014879, 0.08535576984286308, 0.11419509421102703, 0.154521276417654, 0.11081048520281911, 0.150872522208374, 0.08300072746351361, 0.18719210143899545, 0.13040903198998421, 0.13944019738119096, 0.1395207500900142, 0.28488422103691846, 0.1785717296297662, 0.15518906089710072, 0.13959852716652676, 0.20178312552161515, 0.10800288117025048, 0.19187103083822876, 0.10958796017803252, 0.11012818431481719, 0.11045064748032019, 0.16083371738204733, 0.08934859855799004, 0.2995410736184567, 0.16123545676236972, 0.14496685238555074, 0.1419385930057615, 0.1158659729117062, 0.1880229654489085, 0.12350497316219844, 0.1675186719512567, 0.10928336050710641, 0.12173595285275951, 0.1378036875394173, 0.13012312701903284, 0.15679730975534767, 0.15150658349739388, 0.14785546925850213, 0.058699161163531244, 0.06895337108289823, 0.1386642226134427, 0.20132959907641634, 0.17153636261355132, 0.20449062867555767, 0.2242355715134181, 0.07913404158898629, 0.15446046483702958, 0.10604934810544364, 0.12875561602413654, 0.11339741162373684, 0.16466959670651704, 0.1361284079030156, 0.1671366291702725, 0.11542531530722044, 0.08689108784892596], [0.04716016374004539, 0.01426252354576718, 0.05722774949390441, 0.016370853772968985, 0.030191077712515835, 0.0386613260343438, 0.023002618618193083, 0.027400485560065135, 0.062278094119392335, 0.034327009198023006, 0.05602480974630453, 0.03746454982319847, 0.012616113453987055, 0.039901536438264884, 0.056328351856791414, 0.03546621330315247, 0.05063380449428223, 0.05657163157593459, 0.03592086039134301, 0.06893876561662182, 0.0441830197814852, 0.056731861259322613, 0.05715316365240142, 0.07097850655554794, 0.032161923227249645, 0.02652410934388172, 0.011724163268809207, 0.012999898426642176, 0.02060428676486481, 0.06878195723402314, 0.004446313414518954, 0.06441823279601522, 0.04380531485367101, 0.04156051109021064, 0.0034656348361750133, 0.022369928447005805, 0.03562709978723433, 0.017029469017870724, 0.041656927205622196, 0.03268522639700677, 0.021210628838161938, 0.03552480586222373, 0.020480168132053223, 0.043350289270165376, 0.04616215323039796, 0.013825226942572044, 0.029672214441234246, 0.0255784387991298, 0.04796996188815683, 0.012698766440735199, 0.05127687174535822, 0.03130613418761641, 0.03285393882833887, 0.03360691815032624, 0.035166871748515405, 0.07321798912016675, 0.051001226966036484, 0.019014984936802648, 0.02397071129962569, 0.006317408715403872, 0.0996992431464605, 0.0709824993100483, 0.08537981542758644, 0.0668755431252066, 0.052481221573543735, 0.01959107150469208, 0.008160564939316828, 0.0030934830283513293, 0.07585558938444592, 0.07914545582025312, 0.0319342174771009, 0.09433045779587701, 0.021031687756476458, 0.40789510938338935, 2.320200386457145, 4.807436959818006, 9.216596391052008, 11.512666884809732, 14.64006057009101, 20.850161388516426, 20.826038382947445, 20.975712351500988, 23.171413131058216, 14.176454097032547, 13.230568002909422, 8.383182361721992, 6.512905620038509, 4.054893990978599, 6.287002516910434, 6.067287381738424, 5.750569626688957, 11.668313182890415, 7.963725244626403, 4.165488006547093, 2.243876731954515, 1.3550861366093159, 0.5541442148387432, 0.40544590330682695, 0.4863986000418663, 0.16545271093491465, 0.32536926737520844, 0.10148784131160937, 0.08819459602818824, 0.03574931666662451, 0.05694110237527639, 0.010000155143643497, 0.018686319272092078, 0.06405377149349079, 0.06429550383472815, 0.00708337051946728, 0.06120980964624323, 0.04718201627838425, 0.0347554176551057, 0.0429397814150434, 0.03852737951092422, 0.04601920816639904, 0.019066391650994774, 0.04465940437512472, 0.026827144938579295, 0.038420970377046615, 0.035820841148961335, 0.03953646286390722, 0.09287687251344323, 0.01992889156099409, 0.033890618942677975, 0.03459764448052738, 0.012762525275320513, 0.06263085175305605, 0.01590892436070135, 0.0653734733350575, 0.03886603262799326, 0.037931861661490984, 0.007955710843816632, 0.031920955298119225, 0.05877211056940723, 0.09074744302779436, 0.06871447374578565, 0.029382177563093137, 0.07454376172972843, 0.016822688121465035, 0.04584627291478682, 0.012575140408443986, 0.05954379572358448, 0.004698411703429883, 0.05379859678214416, 0.04371012328192592, 0.09843440086115152, 0.04764278608490713, 0.05299419404764194, 0.06812529754824936, 0.06232884217752144, 0.02553945749241393, 0.03393157065147534, 0.11047582112951204, 0.054837217612657696, 0.03857309951854404, 0.12354858918115497, 0.04738169111078605, 0.024186711525544524, 0.03522307830280624, 0.0401940279698465, 0.04718377145763952, 0.058086759454454295, 0.01454477436709567, 0.02692602683964651, 0.06888285963214003, 0.014530552962241927, 0.05361756469937973, 0.015548479932476766, 0.0776312370726373, 0.038103045444586314, 0.04518486348388251, 0.01542362193504232, 0.0039165081034298055, 0.06022958841640502, 0.016557073467993177, 0.05643544747726992, 0.020229296242177952, 0.024226774512499105, 0.08077442544163205, 0.05825993219332304, 0.0034890479719251744, 0.009207266830344452, 0.018500626501918305, 0.014028882469574455, 0.03432327619520947, 0.04066679088282399, 0.1048769180488307, 0.015271905613190029, 0.010438759782118723, 0.03019031515577808, 0.03323693155834917, 0.07251351285958663, 0.012278375033929478, 0.03152460390992928, 0.08655344034195878, 0.02937541103165131, 0.03819802921498194, 0.03599012874474283, 0.04602684857673012, 0.041298744472442195, 0.05814780481159687, 0.04153060996031854, 0.03965211544709746, 0.0509095977031393, 0.06849909506854601, 0.06301291679847054, 0.07190169373643585, 0.05529715621378273, 0.0329078224604018, 0.01911170347739244, 0.016645941941533238, 0.02360325728659518, 0.03435985665419139, 0.03912414416845422, 0.03829150642559398, 0.03989301658293698, 0.03237532037019264, 0.02424139853246743, 0.0279695718199946, 0.03448581766861025, 0.05950404629402328, 0.032143517964868806, 0.022562964768439997, 0.022598593423026614, 0.014050093977857614, 0.0470278350985609, 0.021164072059036698, 0.01968425371160265, 0.010010900514316745, 0.04074871656484902, 0.009141660048044287, 0.03997057843662333, 0.05364763281249907, 0.028993735613767058, 0.051742962750722654, 0.06986257620155811, 0.04130441076995339, 0.022731309836672153, 0.03884116325934883, 0.04794296626641881, 0.058597854294930585, 0.05933463995461352, 0.05029429048590828, 0.10670566640328616, 0.028641426979447715, 0.055736926951794885, 0.018858684925362468, 0.07286058564204723, 0.33457789511885494, 2.414683741517365, 4.7666584979742765, 9.40833980217576, 11.958543509244919, 14.680205415934324, 20.37388924509287, 21.847102493047714, 23.697168119251728, 24.436074569821358, 16.235219724476337, 14.539743103086948, 9.15830846875906, 7.144575649872422, 4.59651930257678, 5.733371749520302, 6.4161376375705, 7.869098922237754, 13.49698405712843, 9.511367473751307, 5.033581824973226, 2.6985168736428022, 1.335416492074728, 0.756399940000847, 0.3468192648142576, 0.4585860815132037, 0.19445976067800075, 0.2468475792557001, 0.0838303446653299, 0.08531382365617901, 0.021638117032125592, 0.027620448854577262, 0.053546652488876134, 0.028647570106841158, 0.08035412494791672, 0.03195591416442767, 0.050113911493099295, 0.06571387420990504, 0.025190785381710157, 0.011657078684947919, 0.036310339492047206, 0.05714600192732178, 0.03594842375605367, 0.02331634113943437, 0.05682336435711477, 0.018934562103822827, 0.01898813217849238, 0.02342345531360479, 0.04810757833183743, 0.07113889208994806, 0.03659447444078978, 0.0249229572727927, 0.09560505190165713, 0.039876622540759854, 0.019875959733326454, 0.02556729545176495, 0.025821900344453752, 0.05230991533608176, 0.030747534474357963, 0.028137046720075887, 0.03496390920190606, 0.03765782363188919, 0.03307500606752001, 0.05149260665348265, 0.028403121505107265, 0.03636988200014457, 0.06881623703520745, 0.05680698144715279, 0.046754854629398324, 0.06910655778483488, 0.030438574685831554, 0.06227618679986335, 0.020811800532101188, 0.007911581815278623, 0.06369716211338528, 0.0285242195968749, 0.056372201652266085, 0.008352978784387233, 0.020194198223180138, 0.013581242183136055, 0.06997668140684254, 0.02576796105131507, 0.03077466182730859, 0.06564419396454468, 0.0644251421908848, 0.03686139898491092, 0.028294741969148163, 0.037185082983342, 0.03572631751012523, 0.009810936244321056, 0.03198308790160809, 0.022414718914660625, 0.03349956648889929, 0.016160607046913356, 0.09057061150087975, 0.014046287687961012, 0.04424119302711915, 0.01338038269750541, 0.046413462987402454, 0.005752457609560224, 0.032842457803781144, 0.04545999618130736, 0.029694612458115444, 0.1259476409177296, 0.17242729605641216, 0.2458934742026031, 0.1939506028429605, 0.2148048486560583, 0.10384179273387417, 0.11605784777202643, 0.15807234914973378, 0.0966179721581284, 0.17273917619604617, 0.13592382747447118, 0.19969852175563574, 0.12274367807549424, 0.18476268101949245, 0.16697662213118747, 0.17464602075051516, 0.2701992855872959, 0.09055533810169436, 0.10843054376891814, 0.18437909457134083, 0.17864625609945506, 0.1782766220276244, 0.17712374014081433, 0.1803269682568498, 0.13295122917043045, 0.13100359617965296, 0.08765222708461806, 0.10776999522931874, 0.14718143589561805, 0.10894051054492593, 0.15567919006571174, 0.1778696579276584, 0.1559764498961158, 0.20864750171313062, 0.07259672987856902, 0.07471058168448508, 0.12310405014432035, 0.1419856451684609, 0.1306029106490314, 0.17202514107339084, 0.1571069486089982, 0.15703688986832276, 0.12824847683077678, 0.1858811272541061, 0.15969520347425714, 0.13330924120964482, 0.11019516314263456, 0.1220179170195479, 0.14469959016423672, 0.16800660436274484, 0.14918351283995435, 0.25225103774573654, 0.1707535155583173, 0.13037547207204625, 0.154214576468803, 0.07377842935966328, 0.09559537429595366, 0.1279812739812769, 0.13277244579512626, 0.1760511437896639, 0.23244992917170748, 0.18453157623298466, 0.16742725420044735, 0.17255917569855228, 0.13192077196436003, 0.08179177631973289, 0.2003345126286149, 0.10170673034735955, 0.27797304501291364, 0.2068933317787014, 0.1708294521085918, 0.18828923319233581, 0.15655369235901162, 0.8874397084582597, 4.800056330859661, 9.045160040259361, 15.618167035281658, 20.084027498960495, 23.072413243353367, 29.939722046256065, 33.355320766568184, 35.38235619664192, 34.64275248348713, 25.05272638052702, 22.558304630219936, 15.095628574490547, 11.057430412620306, 7.50801807269454, 9.775958675891161, 11.781575605273247, 15.552426762878895, 20.849751010537148, 15.044433921575546, 8.92944484949112, 5.69625866599381, 3.062675795517862, 1.8508302164264023, 1.1492454819381237, 1.0534498910419643, 0.3948141331784427, 0.6120100035332143, 0.19595297664636746, 0.20840974728344008, 0.10521348202018999, 0.19909528928110376, 0.1400524246855639, 0.15809915552381426, 0.2705091470852494, 0.11034656869014725, 0.13043212762568146, 0.24257779587060213, 0.1828700114856474, 0.12948008574312553, 0.150586795352865, 0.17992586712352931, 0.2169220327050425, 0.085692059219582, 0.11337975593050942, 0.12439581754733808, 0.10841573792276904, 0.15362149657448754, 0.17833930382039398, 0.23606230330187827, 0.1101538552029524, 0.14686581533169374, 0.1527269562939182, 0.11137472523842007, 0.18825625214958563, 0.1130963594187051, 0.21205384080531076, 0.1197232557751704, 0.13494487531716004, 0.119670006679371, 0.14859577640891075, 0.09792386263143271, 0.2017950444133021, 0.17270425072638318, 0.09493860328802839, 0.1849591571954079, 0.13928931875852868, 0.20766667934367433, 0.10940424152067862, 0.16520955367013812, 0.15484359115362167, 0.1133891663630493, 0.12095572557882406, 0.18858851166442037, 0.09018329947139136, 0.1474934199359268, 0.11646105660474859, 0.09626854676753283, 0.05010058252082672, 0.11480468689114787, 0.16815984301501885, 0.11266476343735121, 0.20736063248477876, 0.25763425044715405, 0.20588669751305133, 0.17740719602443278, 0.20841148390900344, 0.18393987673334777, 0.1954982479219325, 0.22795586875872687, 0.1572328168549575, 0.09655271511292085, 0.10751944617368281, 0.09112250962061808, 0.1403245108667761, 0.1031542374403216, 0.2599389455281198, 0.16221031226450577, 0.1430692253052257, 0.12439698271919042, 0.07654101471416652, 0.24085812096018344, 0.1036658146767877], [0.06246617660508491, 0.023048522307362873, 0.01777946119545959, 0.04683951883635018, 0.015954304835759103, 0.0367059487325605, 0.07396196990157478, 0.021072390845802147, 0.08006797506823204, 0.01995300208363915, 0.09237036414560862, 0.049552844138816, 0.06318580752122216, 0.07370258928858675, 0.09491085438639857, 0.04077683282957878, 0.08283605973701924, 0.024466265567753, 0.027412927665864117, 0.02130011886038119, 0.0307213663472794, 0.03803627812885679, 0.0406974193174392, 0.0932063118671067, 0.015558248451270629, 0.06641610918450169, 0.03609002553275786, 0.038801588234491646, 0.14120223408099264, 0.09477921965299174, 0.10508083054446615, 0.03476169993518852, 0.028429091107682325, 0.0746267857903149, 0.032598588077235036, 0.0054910374819883145, 0.016905257616599556, 0.011643990910670254, 0.04923546839563642, 0.04535705658781808, 0.04860293222009204, 0.07023920130450279, 0.09201614448102191, 0.08014726612600498, 0.045106362813385203, 0.0053322767871577526, 0.060599638090934604, 0.011430065915192245, 0.029634928941959515, 0.018893200358434115, 0.042223850105074234, 0.0356622516119387, 0.009189717820845544, 0.05805204178614076, 0.0313844159245491, 0.015421152438648278, 0.11281695566140115, 0.02271338140417356, 0.0266791254398413, 0.056698249391047284, 0.041075955450651236, 0.05657562433043495, 0.02090196776407538, 0.01696262748737354, 0.03640792449004948, 0.018558222727733664, 0.0313257677044021, 0.022964915660850238, 1.4156187884509563, 3.2821855042129755, 5.388029180467129, 11.468578800559044, 18.901646845042706, 27.201946154236794, 38.92546087503433, 54.55963835120201, 72.31332689523697, 61.20667487382889, 77.76110976934433, 65.61010658740997, 81.56158223748207, 77.72131830453873, 79.41476583480835, 82.12763026356697, 70.91604307293892, 61.65956877171993, 58.109331876039505, 63.61267536878586, 51.41034834086895, 63.41062121093273, 61.058528423309326, 68.2917594909668, 64.57187309861183, 58.470251709222794, 50.36136142909527, 53.5906333476305, 39.14330318570137, 35.87551653385162, 23.836449645459652, 24.502546302974224, 11.389936320483685, 2.7860207157209516, 1.7193560837768018, 0.35963532398454845, 0.08968091002316214, 0.2026927610859275, 0.072907689755084, 0.0640618237957824, 0.12507224804721773, 0.057871599710779265, 0.04440033917489927, 0.05079893606307451, 0.057288690950372256, 0.03450109848927241, 0.028802996239392087, 0.05747728551796172, 0.013023778883507475, 0.04162499630183447, 0.05611547050648369, 0.019311237301735673, 0.08445949293673038, 0.009281127222493524, 0.05094984808238223, 0.049491052923258394, 0.07109180281986482, 0.03160558706440497, 0.05938507631071843, 0.0501448071008781, 0.028689590508292895, 0.008975918062787969, 0.04125011524592992, 0.05226498942647595, 0.05204587032494601, 0.011238326496822992, 0.047385127254528925, 0.1185619505122304, 0.009968812391889514, 0.028998815614613704, 0.020593393892340828, 0.040985984887811355, 0.025340929278172553, 0.061074159893905744, 0.052938024600734934, 0.06817280984250829, 0.08192230525310151, 0.012192269205115736, 0.01714254449325381, 0.05075637389381882, 0.032123698911163956, 0.020395824903971516, 0.022659794631181285, 0.020508319648797624, 0.05886287151952274, 0.019108326705463696, 0.019450902073003817, 0.03593641951738391, 0.029888530079915654, 0.0869763531954959, 0.05317991650372278, 0.0479319676378509, 0.107225800602464, 0.0336249189422233, 0.04074519507412333, 0.04477300120925065, 0.05385062504501548, 0.06302564463112503, 0.09483442801865749, 0.047020094498293474, 0.008698100646142848, 0.024368498743569944, 0.020932063707732596, 0.048210900131380185, 0.013890381014789455, 0.05001956596970558, 0.025400998711120337, 0.022191150637809187, 0.02075201311527053, 0.05550764413783327, 0.036651445407187566, 0.03165495472785551, 0.07593278758577071, 0.06118144105130341, 0.03671453167044092, 0.11037834745366126, 0.05162607820238918, 0.020679427361756098, 0.01591887470567599, 0.035886001714970917, 0.07292279988178052, 0.0462071830406785, 0.11262961532338522, 0.01702652454696363, 0.014162113748170668, 0.0736586912535131, 0.039536804251838475, 0.05981229362078011, 0.018683515809243545, 0.03681782378407661, 0.01926278247992741, 0.06050824260455556, 0.03227556459023617, 0.07478151615941897, 0.05252727925835643, 0.06986117354244925, 0.09125397366005927, 0.0074791184488276485, 0.08589967503212392, 0.028776373546861578, 0.05005880331736989, 0.029465635780070443, 0.016613827356195543, 0.05463940557092428, 0.022423992049880326, 0.12374545127386227, 0.0061801206720701884, 0.030792393590672873, 0.05489543909789063, 0.024797339501674287, 0.012388097857183311, 0.040320931511814706, 0.030896375901647843, 0.02360429072723491, 0.05269277076877188, 0.037860634038224816, 0.056633111089468, 0.09462538728257641, 0.021914544777246192, 0.08601579887908883, 0.010940718784695491, 0.012943911733600544, 0.07570810979814269, 0.034933904171339236, 0.06703851133352146, 0.038062008388806134, 0.04020256637886632, 0.05094929518236313, 0.03976344502007123, 0.04341753156040795, 0.04859176289755851, 0.044227262915228494, 0.04715519135061186, 0.050591164399520494, 0.019613020522228908, 0.07022049176157452, 1.473279744386673, 2.9835543036460876, 6.268526008352637, 11.651945561170578, 20.317669361829758, 29.88596063107252, 44.5459558814764, 60.43499328196049, 78.95487651228905, 68.81755247712135, 82.50536039471626, 76.04857966303825, 93.87369677424431, 88.95704180002213, 89.46177631616592, 90.19334346055984, 82.23505049943924, 69.88510519266129, 64.65402469038963, 70.60375303030014, 58.56674373149872, 70.68916484713554, 68.43384146690369, 78.29567268490791, 72.83247783780098, 66.63542836904526, 60.71842387318611, 62.415842190384865, 48.24457101523876, 44.18795809149742, 31.974528059363365, 31.856817975640297, 15.545375291258097, 4.314145529642701, 1.6177642601542175, 0.1490117798675783, 0.1232698088278994, 0.16982652858132496, 0.13115239678882062, 0.12179329118225724, 0.056777640638756566, 0.021476900292327628, 0.021102776227053255, 0.0027813874339699396, 0.045518503393395804, 0.0737302639754489, 0.0047586870823579375, 0.01012836672089179, 0.023224173819471616, 0.06489853592938744, 0.0338325607299339, 0.08742921170778573, 0.01947989407199202, 0.013474801507982193, 0.024528023386665154, 0.06554201507242396, 0.0175339717316092, 0.011953081502724672, 0.06857382933958434, 0.052609843187383376, 0.02767673333437415, 0.04729480417154264, 0.07538063713582233, 0.03611966320022475, 0.024756643833825365, 0.02592463028122438, 0.06900634558405727, 0.035009666316909716, 0.029653875972144306, 0.021395262192527298, 0.02439221592794638, 0.02771375722659286, 0.031415975754498504, 0.08281573231215589, 0.030055374154471792, 0.039901250711409375, 0.08744909384404309, 0.08450534282019362, 0.02242335380287841, 0.03616235153458547, 0.015080359153216705, 0.03818782468442805, 0.008050064716371708, 0.01690153203526279, 0.04606239373970311, 0.04659374550101347, 0.031056817097123712, 0.04901031563349534, 0.06561656380654313, 0.050858641843660735, 0.013593599869636819, 0.067148163652746, 0.0286101139136008, 0.06201355186931323, 0.04829361991141923, 0.014634380349889398, 0.0722453229536768, 0.021087625282234512, 0.05161745073564816, 0.03518049757985864, 0.016661154113535304, 0.08811914929538034, 0.03328937542391941, 0.07074618464685045, 0.04909245282760821, 0.09821259518503211, 0.022510253729706164, 0.046539008399122395, 0.18175233708461747, 0.1600498758489266, 0.1574060638085939, 0.10844382821233012, 0.2366833176347427, 0.15196419175481424, 0.16919479763600975, 0.19193120417185128, 0.18979410087922588, 0.10099948587594554, 0.1495945587521419, 0.15592436597216874, 0.19361859565833583, 0.1681107425247319, 0.20372838363982737, 0.245301908289548, 0.14075802901061252, 0.18541517725680023, 0.11534968303749338, 0.13098146533593535, 0.09358238035929389, 0.1270520902471617, 0.18083364731865004, 0.23968344961758703, 0.1228566700592637, 0.16039240668760613, 0.12775577983120456, 0.1720054296310991, 0.19541313842637464, 0.10149984183954075, 0.18231090711196885, 0.09213869532686658, 0.14556244073901325, 0.11912603469681926, 0.10633804355165921, 0.19298824510769919, 0.11766214840463363, 0.17379486642312258, 0.17035090044373646, 0.11895525909494609, 0.1084867466124706, 0.20112740836339071, 0.18868191837100312, 0.19748193444684148, 0.16383678826969117, 0.16299882932798937, 0.15929027285892516, 0.16906576784094796, 0.10289824844221584, 0.16341596085112542, 0.16377579857362434, 0.15735893743112683, 0.14326724514830858, 0.1671493792673573, 0.21384464314905927, 0.18099225912010297, 0.2372974151512608, 0.1792917909915559, 0.12442404884495772, 0.17054470488801599, 0.15101149678230286, 0.13374731614021584, 0.10323646740289405, 0.16937589651206508, 0.13584480358986184, 0.17703916499158368, 0.13040080899372697, 0.14428925671381876, 2.282853377982974, 5.72585005313158, 10.96007488667965, 19.124223701655865, 28.909515626728535, 42.36663222312927, 61.655977964401245, 78.57449412345886, 97.181905657053, 86.8323478102684, 102.288778424263, 91.75078868865967, 111.18940562009811, 109.51531425118446, 109.23633322119713, 112.16620400547981, 102.88130342960358, 90.17051428556442, 83.52681398391724, 87.79976069927216, 78.65749686956406, 91.48899033665657, 92.53789365291595, 97.7031996846199, 90.695980489254, 83.7614817917347, 76.61204382777214, 77.57219150662422, 63.712686002254486, 57.146911919116974, 43.01833525300026, 42.355050444602966, 23.032940961420536, 7.64510284177959, 2.5040720449760556, 0.34033987030852586, 0.28669782215729356, 0.34633033792488277, 0.4559864866314456, 0.18194667587522417, 0.28537050588056445, 0.09154072467936203, 0.2160944786737673, 0.11034840179490857, 0.11834364777314477, 0.1604430508450605, 0.08721720980247483, 0.18439117673551664, 0.17401849036104977, 0.1774283472332172, 0.11071834756876342, 0.23322747729253024, 0.1605269729043357, 0.08504789730068296, 0.14101095293881372, 0.17202208342496306, 0.15779508277773857, 0.12331006291788071, 0.11183974755113013, 0.1242875233583618, 0.1005656634515617, 0.10141111066332087, 0.18167801841627806, 0.1296328494208865, 0.14018846035469323, 0.0660503788094502, 0.151067677361425, 0.2170790859963745, 0.1006749298539944, 0.10570918471785262, 0.08509077859343961, 0.1727978207054548, 0.12204582177218981, 0.14361972076585516, 0.17060070735169575, 0.16868512029759586, 0.1123439626826439, 0.10099083243403584, 0.07493378259823658, 0.17442282725824043, 0.12835498986532912, 0.1402075483929366, 0.0915640355378855, 0.08114636017126031, 0.13099431933369488, 0.22425495641073212, 0.11985927660134621, 0.07800878243870102, 0.09362430428154767, 0.15971365326549858, 0.13446117314742878, 0.18310027022380382, 0.22760544146876782, 0.12120519852032885, 0.15138484159251675, 0.10093747201608494, 0.1551631896290928, 0.18913452455308288, 0.17390066699590534, 0.10203387646470219, 0.09173590209684335, 0.15325983316870406, 0.08741330006159842, 0.18318316811928526, 0.18720345629844815, 0.14477560092927888, 0.15468196623260155, 0.11706906108884141], [0.019487760837364476, 0.01606491452548653, 0.053584694978781044, 0.01659050536545692, 0.05186905364098493, 0.0481683156976942, 0.045857842997065745, 0.036993260073359124, 0.044558995505212806, 0.030938348063500598, 0.04526996926870197, 0.02917802758020116, 0.09086760415812023, 0.042905475638690405, 0.043554350195336156, 0.009500449486949947, 0.0437163684546249, 0.023858778731664643, 0.09091951738810167, 0.05257707365672104, 0.017610557661100756, 0.05124459203216247, 0.05964279451291077, 0.04755696041684132, 0.03836830386717338, 0.08913057783502154, 0.027064684145443607, 0.014205381885403767, 0.024212747921410482, 0.054102665817481466, 0.004741397360703559, 0.05986119373119436, 0.02774740434688283, 0.047073985551833175, 0.04467337901587598, 0.014547192840836942, 0.03013901976373745, 0.022053762404539157, 0.013959331172372913, 0.06928627626621164, 0.03566372106433846, 0.04218285757815465, 0.05813689153001178, 0.030913465707271826, 0.021759118644695263, 0.02621938536321977, 0.08185137819964439, 0.06397701858077198, 0.008509900344506605, 0.053384456114144996, 0.029252086496853735, 0.028411602397682145, 0.025006697505887132, 0.012326929117989494, 0.0927233295806218, 0.06462818637373857, 0.020363740004540887, 0.02641610273713013, 0.03285905964730773, 0.02983748145197751, 0.018394497528788634, 0.027897063991986215, 0.05451685472507961, 0.20722649671370164, 0.44864281662739813, 0.7840995630249381, 4.618109269067645, 15.078251156955957, 33.827669620513916, 55.12245275080204, 60.43321877717972, 73.4190371632576, 76.20858907699585, 88.3282059431076, 80.17873004078865, 78.19900587201118, 76.9894927740097, 86.49621784687042, 80.95267251133919, 79.00829404592514, 72.43007183074951, 72.25256815552711, 73.40804055333138, 73.15424457192421, 80.35016924142838, 79.71475973725319, 83.7102073431015, 88.98084372282028, 91.67838737368584, 81.53978660702705, 78.90440762042999, 79.58764135837555, 85.33828318119049, 88.84672611951828, 86.90938487648964, 84.85949367284775, 89.35143023729324, 84.97777372598648, 87.23394066095352, 85.9404444694519, 75.12811705470085, 45.79089067876339, 27.703680731356144, 11.900654565542936, 2.8722931863740087, 1.3933582766912878, 0.27585765696130693, 0.07137853899621405, 0.006435928771679755, 0.06904800975462422, 0.0827545348147396, 0.06916191458003595, 0.04002002031484153, 0.06745700098690577, 0.03734036254172679, 0.02623360120196594, 0.009559884383634198, 0.015986745966074523, 0.030192651065590326, 0.030446883029071614, 0.030423683492699638, 0.007230648334370926, 0.04787810998095665, 0.03056224246392958, 0.023715783572697546, 0.06102625797211658, 0.045784099493175745, 0.045601212041219696, 0.04992214424419217, 0.003145195414617774, 0.007976682081789477, 0.03800649574259296, 0.021496075532922987, 0.06527129444293678, 0.02649920843396103, 0.07539323880337179, 0.08213640743633732, 0.02680913301446708, 0.03582334589737002, 0.017632692215556744, 0.042483167635509744, 0.014061229903745698, 0.05595173417532351, 0.003315589506200922, 0.01823018417780986, 0.020037835129187442, 0.017591549403732643, 0.04722628909803461, 0.03456745020230301, 0.024571401918365154, 0.046917756044422276, 0.010038926793640712, 0.06630279807723127, 0.008224757002608385, 0.04319470172049478, 0.037203566171228886, 0.08981474151369184, 0.05497949474374764, 0.016074627383204643, 0.08047675743000582, 0.05321382894180715, 0.03401423848117702, 0.018410691191093065, 0.02716685747145675, 0.06024327733030077, 0.019045698718400672, 0.059334758698241785, 0.015625733794877306, 0.034656693460419774, 0.024880812561605126, 0.020759412327606697, 0.021730740772909485, 0.023295616665564012, 0.04114809962629806, 0.026650931249605492, 0.03528504392306786, 0.0399623962584883, 0.04415299990796484, 0.043702078401111066, 0.04185191537544597, 0.09260701277526096, 0.054316768000717275, 0.0420757062966004, 0.0681055712630041, 0.0227974518929841, 0.06364717846736312, 0.018565475365903694, 0.07664983582799323, 0.0596950194449164, 0.08528021920938045, 0.023227854871947784, 0.04895213496638462, 0.039881672855699435, 0.010479142820258858, 0.03761784413654823, 0.038267160271061584, 0.013838740524079185, 0.03566546511137858, 0.01139305779361166, 0.07245557339047082, 0.04462051212613005, 0.07655796536710113, 0.06365224733599462, 0.00103963931223916, 0.041774253331823274, 0.02745408160990337, 0.053976007184246555, 0.07418350098305382, 0.025563562448951416, 0.06513568179798312, 0.02329554430616554, 0.03576838244043756, 0.058264321996830404, 0.02799991638312349, 0.003966856329498114, 0.008375051183975302, 0.020098592904105317, 0.0491610198514536, 0.053812890546396375, 0.05837069031258579, 0.02224360934633296, 0.04022588465886656, 0.028874787894892506, 0.0485029946139548, 0.018794719217112288, 0.07931200860184617, 0.03396401363715995, 0.02071983544738032, 0.04996236864826642, 0.06156289382488467, 0.04077845442225225, 0.025583331407688092, 0.021956811942800414, 0.05052152497228235, 0.012514956870290916, 0.01855789618275594, 0.047737283748574555, 0.041430909841437824, 0.008136485957948025, 0.1256630866555497, 0.399533836171031, 1.1126323090866208, 6.379120023921132, 17.039663158357143, 38.05889457464218, 62.25618615746498, 66.33768394589424, 84.58286851644516, 85.13722836971283, 97.65681937336922, 88.93228992819786, 90.34297943115234, 91.26071378588676, 96.61578923463821, 94.37485188245773, 90.44349923729897, 82.99311742186546, 84.98535811901093, 87.78278321027756, 87.32106238603592, 94.4483095407486, 93.93653780221939, 96.84321463108063, 101.3635964691639, 106.85057803988457, 95.71471318602562, 88.87490540742874, 88.17661687731743, 98.06277438998222, 99.20275881886482, 101.40105485916138, 97.85605028271675, 100.96933722496033, 95.78185558319092, 97.7202607691288, 101.18311375379562, 91.75520405173302, 58.72954599559307, 35.28833024203777, 15.333668701350689, 3.6999557493254542, 1.2231700401753187, 0.16148830647580326, 0.09212747405399568, 0.05905452373553999, 0.08319044267409481, 0.03148768577375449, 0.04006004433904309, 0.07377949805231765, 0.016785929547040723, 0.08618464489700273, 0.008985010299511487, 0.011211975615879055, 0.011529510920809116, 0.05407590768299997, 0.03534454932378139, 0.008919494430301711, 0.06775795671273954, 0.06700247264234349, 0.0708735223452095, 0.07060750693199225, 0.009315198294643778, 0.053053851588629186, 0.005556715232160059, 0.027821251751447562, 0.04602592089213431, 0.03563713362382259, 0.015011814393801615, 0.03621544849011116, 0.06596255305339582, 0.057590444484958425, 0.08413728210143745, 0.03879553602018859, 0.01603582604730036, 0.033273979570367374, 0.03200049868610222, 0.02672444097697735, 0.027762174941017292, 0.006769470346625894, 0.018542188627179712, 0.023898162653495092, 0.07972925886861049, 0.04254548948665615, 0.011456669126346242, 0.03971579542849213, 0.03586162216379307, 0.024608030616946053, 0.012467158849176485, 0.004542902079265332, 0.06924019631696865, 0.056903917065938, 0.03386631731700618, 0.07535271754022688, 0.03767294118006248, 0.03255568823078647, 0.05114097708428744, 0.041886417820933275, 0.029541321855504066, 0.05070684295787942, 0.013266400874272222, 0.05885113074327819, 0.0462697943294188, 0.026332575871492736, 0.023302702320506796, 0.06616517421207391, 0.03209118913218845, 0.022305827296804637, 0.045250268958625384, 0.02667936478246702, 0.027747892308980227, 0.05290830529702362, 0.021604911489703227, 0.13607595290523022, 0.09194618221954443, 0.10690043563954532, 0.09139245841652155, 0.2217198393191211, 0.15330464404542, 0.13048106484347954, 0.16019365953980014, 0.05763635374023579, 0.15638835669960827, 0.1765600047656335, 0.12343961221631616, 0.08973440402769484, 0.1487493416061625, 0.21434121415950358, 0.1565370088792406, 0.1816070542554371, 0.1265604916261509, 0.1626179294544272, 0.14325069525511935, 0.14000440773088485, 0.21645247587002814, 0.2114019382861443, 0.13984089775476605, 0.1377275283448398, 0.28647779021412134, 0.1453373028198257, 0.13112303742673248, 0.11358589486917481, 0.16956196777755395, 0.14852004765998572, 0.17472321895183995, 0.0943727527919691, 0.17262752749957144, 0.07051708365906961, 0.13256482256110758, 0.15511146193603054, 0.12755081348586828, 0.10154346527997404, 0.15487677999772131, 0.08645860871183686, 0.1148207469668705, 0.18878650182159618, 0.2035281521966681, 0.1514028460951522, 0.1067350925586652, 0.151786744245328, 0.11646631101029925, 0.07808171329088509, 0.16501469537615776, 0.1233356299053412, 0.12013489540549926, 0.16926564305322245, 0.11062420613598078, 0.14494581992039457, 0.1585550865274854, 0.11592602008022368, 0.12401902917190455, 0.13180838112020865, 0.09012254726258107, 0.06033194913470652, 0.24261377518996596, 0.12498397700255737, 0.535314918961376, 0.5514793109614402, 2.222858159802854, 8.842640407383442, 24.3381405249238, 49.39184345304966, 75.55364102125168, 83.97711262106895, 100.84267482161522, 100.33553123474121, 114.18850108981133, 106.43689423799515, 105.41062250733376, 103.26243817806244, 111.77895918488503, 104.45522457361221, 103.50897654891014, 94.2706310749054, 95.63547223806381, 96.79074704647064, 97.83176958560944, 105.1059852540493, 105.74934393167496, 109.94842261075974, 114.05415549874306, 116.85949176549911, 105.7209974527359, 104.46715593338013, 104.10623610019684, 112.02094539999962, 113.33932265639305, 114.07852739095688, 111.49490162730217, 116.48009732365608, 111.05478644371033, 115.36532074213028, 114.85778957605362, 107.59507209062576, 77.14467644691467, 44.83085699379444, 21.898578330874443, 6.523496601730585, 2.9115153942257166, 1.0464196745306253, 0.2154724847059697, 0.27644508169032633, 0.28513767931144685, 0.21068270812975243, 0.14731686300365254, 0.22501720144646242, 0.14861596282571554, 0.14767484535695985, 0.10289564350387082, 0.12048532269545831, 0.13294839416630566, 0.1181652800005395, 0.10347700488637201, 0.18323410913581029, 0.15727615827927366, 0.13554537668824196, 0.12977691512787715, 0.19046516565140337, 0.1297985264682211, 0.1865443104179576, 0.09301731653977185, 0.16227419633651152, 0.13040490564890206, 0.13726914825383574, 0.10618352840538137, 0.17186177952680737, 0.16559030511416495, 0.09861556653049774, 0.22226974106160924, 0.20528189168544486, 0.08786960956058465, 0.11649428997770883, 0.19656040967674926, 0.10508873441722244, 0.15084880316862836, 0.14694319164846092, 0.13883984443964437, 0.14355454535689205, 0.10904595488682389, 0.0925481085141655, 0.13175871659768745, 0.1207234630419407, 0.1342127614771016, 0.19984837621450424, 0.15350454894360155, 0.1464858654071577, 0.18817167700035498, 0.18790527567034587, 0.16048174642492086, 0.15867034206166863, 0.09346692444523796, 0.08838754700263962, 0.11032890557544306, 0.13090230786474422, 0.10320322660845704, 0.1480968453688547, 0.1499796740245074, 0.13194232393288985, 0.0964542395377066, 0.11564548083697446, 0.08936557889683172, 0.1817060270695947, 0.10217590126558207, 0.14629268436692655, 0.09357131493743509, 0.09018754455610178, 0.15346665488323197, 0.08793514862190932, 0.12512016110122204], [0.036362942919367924, 0.025731141249707434, 0.06214538327185437, 0.03403861803235486, 0.050023644071188755, 0.018087738208123483, 0.10513469562283717, 0.041412641876377165, 0.04312296943680849, 0.05052640088251792, 0.0210251939643058, 0.05031501124904025, 0.07538195815868676, 0.06501618117908947, 0.016391260978707578, 0.023354229633696377, 0.043562610298977233, 0.02916183577326592, 0.06604942886042409, 0.04762194286740851, 0.041481598527752794, 0.0423658340878319, 0.011806502698163968, 0.058979963869205676, 0.015633431721653324, 0.024441477835352998, 0.05612618711893447, 0.036722743534483016, 0.09050436739926226, 0.024052353110164404, 0.046670498413732275, 0.02949046433059266, 0.058336046859039925, 0.09700311711640097, 0.06181062643008772, 0.08611877929070033, 0.06054560231859796, 0.01150683367086458, 0.034919892423204146, 0.005249453570286278, 0.03991912162746303, 0.03512167124426924, 0.06105798478529323, 0.041920764415408485, 0.03399856803298462, 0.05710537305276375, 0.05856027935806196, 0.06170223205117509, 0.04245505508151837, 0.028418441288522445, 0.0561454347189283, 0.08160226148902439, 0.08075078803813085, 0.015247218998410972, 0.08025716335396282, 0.0736620754469186, 0.015776491818542127, 0.05068093829322606, 0.05470179792609997, 0.023471707900171168, 0.1961124938679859, 0.6970891600940377, 7.366952067241073, 21.072086580097675, 22.400280609726906, 45.66180020570755, 65.74794799089432, 71.11952215433121, 61.5488351136446, 84.52388808131218, 82.86773175001144, 79.29602980613708, 74.23103839159012, 68.86033818125725, 64.32593509554863, 57.21819989383221, 45.43475478887558, 60.11641837656498, 62.48015373945236, 60.61877802014351, 52.560216039419174, 35.86564086377621, 42.478764206171036, 44.22503650188446, 45.62244571745396, 53.877578750252724, 50.79999849200249, 55.705235078930855, 42.63381868600845, 42.8533861041069, 53.015549406409264, 63.73826242983341, 57.958270981907845, 63.47260728478432, 66.95750668644905, 76.17811471223831, 60.099820867180824, 70.950066447258, 64.85951006412506, 71.01903274655342, 75.48101931810379, 79.59756642580032, 91.12246960401535, 68.74803900718689, 45.676957592368126, 27.499730475246906, 15.884129013866186, 11.41780972480774, 5.185110569000244, 1.127274704631418, 0.08489196465234272, 0.048098297775140963, 0.027853548162966035, 0.10140406768186949, 0.06060707812139299, 0.04513647916610353, 0.057401438025408424, 0.10558680456597358, 0.07060737334541045, 0.044570617537829094, 0.005679741052517784, 0.05152965837623924, 0.021611063893942628, 0.02205410935857799, 0.057892647018888965, 0.04170340791461058, 0.04486007739615161, 0.05743591820646543, 0.053493358864216134, 0.04569688600895461, 0.031817110284464434, 0.09182046982459724, 0.0688082589476835, 0.00992123423202429, 0.039527223125332966, 0.03913278647814877, 0.055235539402929135, 0.05447717208880931, 0.029283163930813316, 0.010647760627762182, 0.059562048845691606, 0.031035038773552515, 0.09645776473917067, 0.05768810740846675, 0.04249022917065304, 0.011764675255108159, 0.06746689381543547, 0.0454981203074567, 0.02532331069232896, 0.05511208684765734, 0.05387970981246326, 0.04295753729820717, 0.02421425819193246, 0.03035558773262892, 0.04343457127106376, 0.050717730264295824, 0.023724151287751738, 0.03238351368054282, 0.05584073856880423, 0.03020681866473751, 0.06453126930864528, 0.019740443567570765, 0.012409221235429868, 0.03540878591593355, 0.02986628605867736, 0.021395282601588406, 0.03213854928617366, 0.0358773965126602, 0.03004413803864736, 0.022155815131554846, 0.0308521884289803, 0.028229952476976905, 0.020539248653221875, 0.028593482384167146, 0.0044398247246135725, 0.0363105176074896, 0.045527887850767, 0.027498680974531453, 0.050543403485789895, 0.0320873707823921, 0.00988314721325878, 0.06276737723965198, 0.03939782596717123, 0.10177738280617632, 0.04311249031161424, 0.03794355419813655, 0.14373334357514977, 0.054437790022348054, 0.03237272656406276, 0.018551851389929652, 0.05248040892183781, 0.016225287072302308, 0.020971829835616518, 0.03216846896975767, 0.04425723083841149, 0.03957412685849704, 0.06311343327979557, 0.03722509587532841, 0.021233809820841998, 0.02955351348646218, 0.03557663003448397, 0.025148666645691264, 0.037665130075765774, 0.029608135555463377, 0.04812615799892228, 0.03771052724914625, 0.03717867824889254, 0.06025603855960071, 0.018645230265974533, 0.06103776868258137, 0.058266470514354296, 0.03755452409677673, 0.04112373120733537, 0.053586175563395955, 0.016135806326929014, 0.044371688563842326, 0.028063418249075767, 0.054812864036648534, 0.06132278678705916, 0.07710543286520988, 0.028146499826107174, 0.029027141536062118, 0.019476524721540045, 0.00471454877697397, 0.010427416054881178, 0.038334821874741465, 0.02758146198175382, 0.028148420133220498, 0.02713106183364289, 0.019865148497046903, 0.0444328229787061, 0.04235624925058801, 0.024464091075060423, 0.06776894791983068, 0.06991925401962362, 0.015188586548902094, 0.13320296566234902, 0.7274314225651324, 7.280849637463689, 22.13837206363678, 28.4657184407115, 52.78123877942562, 77.5547656416893, 82.59837180376053, 74.50232863426208, 96.81799158453941, 92.96040818095207, 91.09387993812561, 87.14941039681435, 82.90616288781166, 78.53515103459358, 73.94711762666702, 60.69938309490681, 77.22008720040321, 79.07189503312111, 77.418162971735, 70.64390927553177, 53.29393766820431, 60.68416491150856, 61.20227470993996, 61.502773985266685, 72.56127119064331, 70.19756242632866, 72.54622399806976, 58.610680773854256, 57.41491533815861, 67.45835781097412, 80.04510641098022, 76.61834388971329, 75.99760919809341, 77.33210518956184, 89.34212073683739, 73.04555520415306, 85.3987455368042, 74.46688413619995, 83.33012893795967, 87.04645112156868, 90.84984183311462, 103.74340876936913, 81.58758044242859, 53.414452001452446, 31.603533066809177, 17.119808457791805, 11.511851828545332, 5.366426864638925, 1.114026834256947, 0.08840349575621076, 0.06079228849557694, 0.16889005695702508, 0.18574647197965533, 0.04613470860931557, 0.02729119503783295, 0.020198306010570377, 0.04836126296140719, 0.0045288731689652195, 0.042775607216754, 0.010634495665726718, 0.034456636421964504, 0.05863661666808184, 0.06432835129089653, 0.03149708136334084, 0.07075152811012231, 0.0443924983846955, 0.03459968538663816, 0.0252709818596486, 0.12796224531484768, 0.035235739342169836, 0.05321453769283835, 0.08843180126859806, 0.06180146461701952, 0.04608078415913042, 0.059057525722892024, 0.026818662190635223, 0.050494722308940254, 0.033539427240611985, 0.007956879726407351, 0.03527465756633319, 0.023179943673312664, 0.05447147981612943, 0.02694793318369193, 0.049544795547262765, 0.0667284346127417, 0.05751545417297166, 0.04889543488388881, 0.05434990118374117, 0.04002254732768051, 0.04213741958665196, 0.015597660203638952, 0.008937754046201007, 0.05954296080744825, 0.042228544189129025, 0.07443099239026196, 0.04686621017754078, 0.03198617523594294, 0.053552059034700505, 0.03046769470529398, 0.04406078805914149, 0.0483088079636218, 0.04094261006684974, 0.06176595656143036, 0.03245961350330617, 0.07597570598591119, 0.0680397947144229, 0.029134242722648196, 0.006727115978719667, 0.03566111612599343, 0.018382337439106777, 0.04870645439950749, 0.033706892863847315, 0.032104681376949884, 0.03269746070145629, 0.04079143829585519, 0.1107885992678348, 0.15653130918508396, 0.22896772774402052, 0.12489144603023306, 0.11747179494705051, 0.14731435454450548, 0.18201942119048908, 0.22080361348344013, 0.15695773239713162, 0.14661623106803745, 0.15481780894333497, 0.15446243894984946, 0.13054661132628098, 0.15984676487278193, 0.08225095793022774, 0.07903229314251803, 0.0825487966358196, 0.12198368916870095, 0.15440903400303796, 0.17788298689993098, 0.140544394380413, 0.17228346783667803, 0.0929523489321582, 0.1587353541981429, 0.15261826134519652, 0.16975850332528353, 0.10642979526892304, 0.16268423292785883, 0.18221776757854968, 0.17402583762304857, 0.1123207260388881, 0.1088532933499664, 0.11194082064321265, 0.21275509614497423, 0.1255665926146321, 0.189418054651469, 0.10268709258525632, 0.14434999407967553, 0.10861657792702317, 0.17149386723758653, 0.11558613128727302, 0.10220627736998722, 0.19701415876625106, 0.12532342050690204, 0.09266999884857796, 0.23697425436694175, 0.11015960684744641, 0.1724093360826373, 0.07322232326259837, 0.0946817830845248, 0.12232149252668023, 0.18870444997446612, 0.16320464172167704, 0.1367364643374458, 0.21370163129176944, 0.14853601867798716, 0.09937750728568062, 0.12550244136946276, 0.16228808934101835, 0.06726055449689738, 0.43356938171200454, 1.7115608020685613, 10.361485406756401, 28.00648458302021, 38.36282506585121, 66.13706231117249, 93.40470314025879, 98.19066032767296, 90.93731313943863, 111.2352691590786, 104.72972944378853, 102.03600838780403, 96.71868771314621, 91.57225906848907, 84.84289616346359, 80.6263992190361, 67.29591652750969, 83.02663162350655, 86.07963860034943, 84.0898297727108, 71.09561383724213, 54.600159376859665, 64.68464344739914, 64.94112208485603, 67.34175726771355, 75.38614600896835, 73.53084996342659, 79.39051553606987, 63.02573226392269, 62.61771775782108, 78.74849438667297, 86.29150003194809, 81.80090099573135, 90.24133488535881, 91.2568835914135, 100.03423780202866, 83.00716146826744, 97.3185083270073, 86.46616145968437, 95.33285647630692, 98.64581510424614, 104.18633580207825, 120.79404383897781, 94.98527392745018, 68.35054233670235, 43.71929883956909, 25.842709690332413, 16.526884473860264, 8.661795761436224, 2.503430829383433, 0.5485500837676227, 0.20843978942139074, 0.31444417079910636, 0.2823523397091776, 0.09394834822160192, 0.223632057022769, 0.15964540536515415, 0.170377736503724, 0.15801551548065618, 0.20385396986966953, 0.08110174967441708, 0.1362714939750731, 0.22185296576935798, 0.1155134750297293, 0.16809063032269478, 0.23183796904049814, 0.09506870177574456, 0.14583736192435026, 0.1629246145603247, 0.20504441927187145, 0.1317106551141478, 0.21714681439334527, 0.1213980901229661, 0.12886162439826876, 0.23312664910918102, 0.13378748117247596, 0.11981356772594154, 0.10292388964444399, 0.0986780108360108, 0.09578009485267103, 0.18583548517199233, 0.16433137032436207, 0.2715950575657189, 0.12794094567652792, 0.18723185086855665, 0.11898607306648046, 0.1963294533197768, 0.22859733668155968, 0.16992440301692113, 0.17375798168359324, 0.290573020465672, 0.13902002305258065, 0.16840895230416209, 0.11484531947644427, 0.1472329261014238, 0.1153452078870032, 0.134408540034201, 0.11880567180924118, 0.11891261528944597, 0.1252617480349727, 0.07740170563920401, 0.08913887504604645, 0.0804317239089869, 0.15679530595662072, 0.08953058058978058, 0.2142614926560782, 0.2605004544602707, 0.14234977250453085, 0.1020221431099344, 0.10883989758440293, 0.16600185568677261, 0.12991924420930445, 0.13896085903979838, 0.09753087317221798, 0.14920865680323914, 0.11275280441623181], [0.06433503061998636, 0.03169696770783048, 0.04068206799274776, 0.03582257035304792, 0.032453475942020305, 0.017189292375405785, 0.12047253549098969, 0.012339380500634434, 0.013205749783082865, 0.024141498033714015, 0.02534714662033366, 0.04703141225036234, 0.07680757931666449, 0.035678931380971335, 0.039476831298088655, 0.07198036881163716, 0.034375757168163545, 0.03675806234241463, 0.056906982135842554, 0.016143094217113685, 0.008885792576620588, 0.046074620622675866, 0.022369677972164936, 0.0058190069194097305, 0.018596356130728964, 0.021432992980408017, 0.04961272803484462, 0.03524461171764415, 0.012792307661584346, 0.0771901490224991, 0.01807056862162426, 0.046938272716943175, 0.028566445944306906, 0.030612498849222902, 0.008950146057031816, 0.02290304095367901, 0.03837487929558847, 0.050532983732409775, 0.03463284083409235, 0.03652199258795008, 0.03975289910158608, 0.06590818331460468, 0.02891158172133146, 0.026766689588839654, 0.024071389198070392, 0.061571521291625686, 0.028481557237682864, 0.010219949599559186, 0.021139542222954333, 0.03216827601136174, 0.05728282056224998, 0.055404051454388537, 0.020284654892748222, 0.03413985439692624, 0.039297431940212846, 0.08084771252470091, 0.051387466592132114, 0.20434783946257085, 0.49274025193881243, 5.558406338095665, 10.79032089561224, 24.337627552449703, 51.363052278757095, 60.267783254384995, 72.98260018229485, 86.99282079935074, 76.81227788329124, 70.32177776098251, 55.30150294303894, 57.97278240323067, 61.52715727686882, 53.74478727579117, 32.20176346600056, 39.02474194765091, 25.735716931521893, 19.243472702801228, 17.866730578243732, 22.423208579421043, 30.052254907786846, 27.66718178987503, 18.20286814123392, 13.970735985785723, 12.844063192605972, 19.37176901847124, 23.782927617430687, 19.227614253759384, 18.679050989449024, 19.341950118541718, 28.593338392674923, 28.76169215887785, 20.91549888253212, 16.507771499454975, 18.90555113554001, 24.66238472610712, 31.749238148331642, 28.565624579787254, 30.032172985374928, 42.1263787150383, 55.94894640147686, 64.6753491461277, 75.44754311442375, 82.98022091388702, 83.33854928612709, 76.09087139368057, 81.50573283433914, 71.45161673426628, 64.873516112566, 53.64558979868889, 42.989202216267586, 27.852484546601772, 11.050277296453714, 7.9470127914100885, 1.2810933007858694, 0.11730707527021877, 0.12292608313146047, 0.032560040926910006, 0.057318503022543155, 0.010540099119680235, 0.07503792076022364, 0.06931967291166075, 0.07183425477705896, 0.1582986448192969, 0.04704235521785449, 0.002110132950292609, 0.03331335792609025, 0.03761565109016374, 0.020110261320951395, 0.03420418746827636, 0.026498924562474713, 0.08272484890767373, 0.09364335521240719, 0.039361716771963984, 0.007305946637643501, 0.01991558114241343, 0.021107217980897985, 0.04058369260746986, 0.044184897415107116, 0.014042069506103871, 0.05541734703001566, 0.039220886828843504, 0.06419659781386144, 0.03926694822439458, 0.04438827556441538, 0.028521256572275888, 0.04544270414044149, 0.01256984332940192, 0.021579721142188646, 0.04899765088339336, 0.058932818938046694, 0.06843701441539451, 0.031448659938178025, 0.06193852816068102, 0.02889798557589529, 0.027946010486630257, 0.022219311431399547, 0.07315619048313238, 0.020110697332711425, 0.03393265047634486, 0.04738178016850725, 0.043299129320075735, 0.09254529577447101, 0.04551838093902916, 0.0483659978635842, 0.05340712501492817, 0.04836740052269306, 0.04220722970785573, 0.03785124215937685, 0.059049621850135736, 0.03884564954205416, 0.036241828129277565, 0.05470090363814961, 0.06179617681482341, 0.08737638563616201, 0.032257022030535154, 0.06695420335745439, 0.06113966184784658, 0.023993233626242727, 0.012723017043754226, 0.016335761320078745, 0.034537129758973606, 0.038207981415325776, 0.02158499224606203, 0.023235727203427814, 0.017227268072019797, 0.01654885974858189, 0.028753099795721937, 0.010150382531719515, 0.02466872345394222, 0.08018397275009193, 0.06439129283535294, 0.039253841896425, 0.035977311854367144, 0.02363366678764578, 0.013616928354167612, 0.03849106993584428, 0.0567664564732695, 0.021130630884726997, 0.09186830866383389, 0.023329957693931647, 0.045349271458690055, 0.0189337494521169, 0.04072067451488692, 0.04144948208704591, 0.021095991141919512, 0.006779350187571254, 0.04979705896403175, 0.05668834914104082, 0.027039618107664865, 0.08471743378322572, 0.04897620281553827, 0.03537741533364169, 0.04989026529074181, 0.05199840998102445, 0.048379445579485036, 0.054551379434997216, 0.0443589681526646, 0.02903525692090625, 0.04636125660908874, 0.003354510977260361, 0.06841362934210338, 0.06785494057112373, 0.05359511844289955, 0.05618125076580327, 0.020456712554732803, 0.01628507634450216, 0.16598980320850387, 0.023020537773845717, 0.05648208774800878, 0.021196162524574902, 0.0397744288056856, 0.04914959819871001, 0.01553818541651708, 0.016147131500474643, 0.23461469972971827, 0.735855451785028, 6.497409101575613, 12.638540770858526, 28.363756611943245, 64.59701254963875, 75.47238618135452, 86.43672823905945, 96.54509022831917, 89.20203745365143, 80.1111164689064, 65.63912183046341, 71.22698798775673, 76.03740066289902, 65.74148833751678, 48.16258281469345, 50.49501545727253, 42.11276024580002, 38.92862610518932, 30.027846917510033, 42.61171907186508, 50.454707220196724, 38.80343422293663, 30.89994002133608, 28.68102628737688, 30.463020466268063, 39.12062980234623, 36.88524015247822, 39.50372904539108, 38.19004073739052, 39.57440905272961, 35.52873954176903, 40.23427024483681, 39.20598462224007, 38.54461871087551, 35.59873938560486, 44.95710141956806, 48.05391624569893, 50.67879259586334, 42.575457617640495, 59.490512162446976, 72.4044232070446, 75.72659254074097, 83.1646478176117, 91.98975786566734, 94.38873633742332, 86.00247234106064, 96.51660695672035, 84.55071464180946, 72.93245807290077, 62.615095898509026, 48.69678474962711, 29.369395449757576, 10.770923886448145, 8.021162487566471, 1.0452348506078124, 0.07264681000378914, 0.15201502887066454, 0.04566190116747748, 0.05675756554410327, 0.010352991630497854, 0.11119829447125085, 0.03814506213529967, 0.07883805083110929, 0.10602548063616268, 0.05208883325394709, 0.05568721047893632, 0.049487509168102406, 0.0324401321267942, 0.03605682184570469, 0.00918909256142797, 0.02819663375703385, 0.04571289784507826, 0.05880043834622484, 0.06533053267048672, 0.03264799655880779, 0.026448723838257138, 0.03649630685686134, 0.01793898769392399, 0.07352416956564412, 0.0196709191732225, 0.030514796962961555, 0.03280445613199845, 0.03486017551040277, 0.04754391346068587, 0.017937221382453572, 0.014897277815180132, 0.019548659620340914, 0.05612838387605734, 0.06099063117289916, 0.026773988611239474, 0.008709844205441186, 0.02326387129869545, 0.07601901030284353, 0.04727118161099497, 0.08469381864415482, 0.04269030105206184, 0.019110950197500642, 0.08566300413804129, 0.0546164509432856, 0.044453165246522985, 0.052321054972708225, 0.03467863876721822, 0.05215136661718134, 0.0399652720807353, 0.08667939022416249, 0.05565654493693728, 0.05956614179012831, 0.03511693263135385, 0.05645829449349549, 0.04934920994855929, 0.06457117458921857, 0.09269753994885832, 0.06953205331228673, 0.016517607909918297, 0.030104713987384457, 0.040637969577801414, 0.001488027660343505, 0.03621941898018122, 0.10156709526199847, 0.05423310198239051, 0.14288126898463815, 0.08932772936532274, 0.10147260501980782, 0.07619918149430305, 0.24443619302473962, 0.1578006785712205, 0.08751222834689543, 0.09758481246535666, 0.06106468637881335, 0.1437228050781414, 0.20999626605771482, 0.13619445904623717, 0.12684691610047594, 0.16678832442266867, 0.08856399261276238, 0.12684017739957199, 0.13893589319195598, 0.10394353375886567, 0.08555302527383901, 0.14365139562869444, 0.09890695597277954, 0.12887235585367307, 0.11339097720338032, 0.23436844028765336, 0.10123171130544506, 0.16354932478861883, 0.10028135409811512, 0.1602406078018248, 0.08357367289136164, 0.1576599376858212, 0.2544279646826908, 0.18291618791408837, 0.12677982595050707, 0.10663801222108305, 0.11482232774142176, 0.1951547819771804, 0.20666305819759145, 0.18382880691206083, 0.1230788764951285, 0.17390268563758582, 0.10224094308796339, 0.14684090885566548, 0.1287472594412975, 0.17671668698312715, 0.11412315783672966, 0.11057515017455444, 0.12959676620084792, 0.20108138036448509, 0.15841128799365833, 0.2370984898880124, 0.14520441385684535, 0.07762483975966461, 0.14668410789454356, 0.19104801875073463, 0.19286510796518996, 0.46661083528306335, 1.4107995782978833, 9.43328546360135, 19.031691066920757, 39.085622280836105, 77.15846970677376, 91.59533903002739, 101.28297999501228, 112.56018206477165, 99.0939174592495, 92.46765822172165, 76.93582445383072, 82.69304752349854, 83.04531142115593, 74.65340092778206, 51.460619643330574, 59.38406467437744, 43.18314380943775, 35.12286812067032, 32.969060093164444, 40.003759413957596, 48.38109388947487, 47.947092577815056, 31.531523130834103, 27.795932181179523, 26.382307335734367, 35.21437481045723, 41.42136834561825, 32.498436346650124, 29.7260158136487, 35.547525733709335, 45.19293196499348, 45.28624355792999, 38.041704297065735, 32.870215997099876, 36.57496780157089, 45.778993517160416, 52.13120386004448, 46.14512287080288, 45.3387301415205, 64.05016109347343, 78.92304942011833, 88.96838039159775, 96.1486878991127, 105.25752112269402, 107.22915932536125, 98.58299687504768, 107.90168523788452, 94.84527423977852, 88.26083555817604, 75.35928145051003, 60.13176575303078, 38.29668961465359, 19.581299275159836, 14.19208550825715, 2.923650280572474, 0.47312211245298386, 0.2386400493560359, 0.15078661119332537, 0.14647454023361206, 0.11852781914058141, 0.3189266240224242, 0.1866349860210903, 0.3062411234714091, 0.25766260048840195, 0.20708890253445134, 0.1262099901214242, 0.15007524780230597, 0.137988333881367, 0.11250104565988295, 0.19173880980815738, 0.09697041808976792, 0.2189127102610655, 0.21261732385028154, 0.15343438630225137, 0.10514357170904987, 0.0824769122118596, 0.08238002483267337, 0.19422289682552218, 0.15695385838625953, 0.05542801911360584, 0.13186092517571524, 0.1632240563048981, 0.21027584793046117, 0.17554004152771086, 0.14010719518410042, 0.08153328628395684, 0.10146548040211201, 0.06852521866676398, 0.141386731993407, 0.2053755655651912, 0.1531431230250746, 0.11867056382470764, 0.15113876026589423, 0.20365557895274833, 0.18258002470247447, 0.15424929413711652, 0.10384287626948208, 0.1724426881992258, 0.14205708430381492, 0.12955995567608625, 0.10551141720497981, 0.09845763750490732, 0.19162963988492265, 0.13140910567017272, 0.18540719174779952, 0.09328683489002287, 0.15452553634531796, 0.13886010507121682, 0.18064310832414776, 0.17354403535136953, 0.11613227776251733, 0.17453970067435876, 0.14145975932478905, 0.1892972330097109, 0.12195795890875161, 0.16612193518085405, 0.12294477040995844, 0.14431358431465924], [0.05464225170726422, 0.014050786030566087, 0.058448233612580225, 0.04698658281995449, 0.047494824102614075, 0.038403652361012064, 0.08853015810018405, 0.05191622825805098, 0.047113920518313535, 0.010532004143897211, 0.04120078468986321, 0.003604087587518734, 0.019614465854829177, 0.006279869494392187, 0.056296736365766264, 0.03885857033310458, 0.03150340817228425, 0.08196544629754499, 0.09469194308621809, 0.01881450487417169, 0.07792405143845826, 0.06705007399432361, 0.03145466762362048, 0.03288320171122905, 0.07875049966969527, 0.061829425030737184, 0.042235268047079444, 0.04585119335388299, 0.026843566811294295, 0.048399249790236354, 0.0022169182602738147, 0.02240073499706341, 0.09883825536235236, 0.06492608445114456, 0.04204049881082028, 0.02937541103165131, 0.033461757775512524, 0.03664439129352104, 0.0649296393385157, 0.06469478670624085, 0.03515183212584816, 0.027344195514160674, 0.05787850539491046, 0.07425589006743394, 0.03909029110218398, 0.054124251182656735, 0.048626747739035636, 0.008880359127942938, 0.06570855301106349, 0.12474883493268862, 0.09039425494847819, 0.018219320991192944, 0.10499568394152448, 0.033200558900716715, 0.19435645372141153, 1.0720073827542365, 3.050550171174109, 8.496698420494795, 21.77920963615179, 44.017058461904526, 57.365434393286705, 72.66986936330795, 77.78590723872185, 75.12209817767143, 70.93511804938316, 72.36929029226303, 74.98604267835617, 51.467094495892525, 34.1711787879467, 35.61949007213116, 30.336359962821007, 24.813724905252457, 17.838853374123573, 17.25146759301424, 14.073488172143698, 29.161094427108765, 36.95190377533436, 28.70695609599352, 33.81001576781273, 46.49368196725845, 50.88634505867958, 49.226073548197746, 48.729474395513535, 51.021074429154396, 37.03454174101353, 40.0300008058548, 45.00516504049301, 47.02164463698864, 38.80097955465317, 34.27341230213642, 30.122820921242237, 21.986336521804333, 19.828189127147198, 15.210793744772673, 15.082633271813393, 18.572831489145756, 27.725219875574112, 20.432846881449223, 27.66285952180624, 34.01235111057758, 50.80282934010029, 49.587491154670715, 64.51698884367943, 58.42140153050423, 59.141732677817345, 65.53598016500473, 70.14464646577835, 73.41879397630692, 72.11196810007095, 71.88060611486435, 56.832881569862366, 38.04532550275326, 19.23341654241085, 9.261946957558393, 2.8334711445495486, 0.14896405977196991, 0.07160841923905537, 0.01737948627123842, 0.055058526049833745, 0.053175148204900324, 0.031038352462928742, 0.02948095370811643, 0.016273754881694913, 0.08017540094442666, 0.09487690855166875, 0.027658036779030226, 0.05064188277174253, 0.026262665560352616, 0.07156429113820195, 0.03895992173056584, 0.09991544560762122, 0.06310310258413665, 0.005938049262113054, 0.051775487372651696, 0.0030805453070570366, 0.03661588911199942, 0.037136353566893376, 0.06436376657802612, 0.06317149891401641, 0.00885334680788219, 0.060259073943598196, 0.06004927992762532, 0.03335343390062917, 0.030318274402816314, 0.04688790315412916, 0.07781262538628653, 0.06564969327882864, 0.033848413004307076, 0.038495585904456675, 0.012755646494042594, 0.019784096693911124, 0.04892697244940791, 0.0530069738306338, 0.0362976153701311, 0.03997085303126369, 0.033187018416356295, 0.040064181812340394, 0.03564348640793469, 0.041837714379653335, 0.03667535740532912, 0.04969549234374426, 0.030849347858747933, 0.05249263209407218, 0.07289229019079357, 0.012880903395853238, 0.047637813695473596, 0.025324650268885307, 0.009639196778152836, 0.08206323909689672, 0.08604708782513626, 0.058922169118886814, 0.04318724684708286, 0.010830624887603335, 0.046369212432182394, 0.02454171972203767, 0.009591595426172717, 0.027395260840421543, 0.0453673204901861, 0.04004691945738159, 0.07756539373076521, 0.05602325123618357, 0.016131294069055002, 0.07115286673069932, 0.024474041420035064, 0.03606311154726427, 0.010854722422664054, 0.013242136355984258, 0.023431696863553952, 0.043824028107337654, 0.040292403355124407, 0.028268674032005947, 0.0695593272394035, 0.01466419798816787, 0.10894828083110042, 0.11679519375320524, 0.053992360408301465, 0.01964943585335277, 0.02354851647396572, 0.025400878112122882, 0.042073713630088605, 0.02944005394965643, 0.04294415266485885, 0.15122533921385184, 0.04787388716067653, 0.09247430934919976, 0.1174150726001244, 0.038341430699802004, 0.011275853194092633, 0.032097452858579345, 0.0352976938302163, 0.006506034824269591, 0.040060096289380454, 0.031383636669488624, 0.0721241302380804, 0.06438937067287043, 0.06835700347437523, 0.016872645792318508, 0.006098718667999492, 0.015190545818768442, 0.1020444298046641, 0.0666886629187502, 0.03402075082703959, 0.05867997293535154, 0.014800536082475446, 0.028460090616135858, 0.06665410852292553, 0.04754911220516078, 0.048068174000945874, 0.03797556673816871, 0.01423035701009212, 0.26854376192204654, 1.1806568526662886, 2.577542527578771, 8.948231991380453, 24.422961473464966, 52.989927381277084, 70.76893776655197, 88.33984091877937, 90.77175602316856, 91.86276108026505, 82.86146968603134, 87.7017791569233, 87.42203056812286, 73.17607060074806, 50.080522298812866, 52.57191561162472, 46.3397142291069, 33.72124873101711, 26.59905530512333, 27.395332977175713, 26.62052795290947, 34.55966234207153, 35.42143329977989, 37.85769157111645, 41.111586168408394, 50.58234617114067, 42.22529120743275, 31.26148112118244, 34.696762785315514, 37.947412356734276, 38.616172671318054, 33.90391252934933, 34.736561849713326, 37.825807482004166, 42.710901349782944, 41.119356751441956, 31.710060350596905, 22.429761327803135, 23.8140232488513, 24.321275129914284, 27.147702164947987, 24.23766251653433, 40.53629703819752, 38.63252319395542, 36.65057994425297, 52.80709259212017, 71.12408950924873, 67.41813316941261, 77.9990454018116, 72.7018104493618, 67.90554821491241, 75.08620530366898, 82.18306928873062, 82.58897110819817, 83.92292752861977, 79.95494484901428, 64.57538411021233, 43.29643473029137, 20.531310997903347, 8.63452272489667, 2.77023873757571, 0.12861275259638205, 0.11881373895448633, 0.02852233639714541, 0.09384424716699868, 0.041077157729887404, 0.0367115705012111, 0.03720505046658218, 0.06889692333061248, 0.08375842313398607, 0.042951781942974776, 0.07568135537439957, 0.07750550241325982, 0.0569764879764989, 0.041953712061513215, 0.005137667112649069, 0.018785182619467378, 0.047923373567755334, 0.048323821611120366, 0.039627691367059015, 0.019631538962130435, 0.056975608531502075, 0.07311614419450052, 0.035859113704646006, 0.05690657766535878, 0.05309770880558062, 0.0529237122827908, 0.02624305616336642, 0.030324573381221853, 0.0016469421188958222, 0.0297108450831729, 0.05653337015246507, 0.08650974268675782, 0.023472206994483713, 0.06054651516024023, 0.0439888999244431, 0.023563518989249133, 0.04727704457764048, 0.035659019558806904, 0.055940724414540455, 0.017398958370904438, 0.07878469041315839, 0.06320499946014024, 0.04132270842092112, 0.055015147518133745, 0.06123977014794946, 0.07142534625018016, 0.0608860699867364, 0.03522482234984636, 0.03168991730490234, 0.043173917874810286, 0.050954660910065286, 0.017860117804957554, 0.05509568909474183, 0.041415361847612076, 0.06533059204230085, 0.05234452910372056, 0.009363940698676743, 0.036343468964332715, 0.08227788304793648, 0.020180457358947024, 0.03210699687770102, 0.1728017392451875, 0.14058683038456365, 0.14291322586359456, 0.20430546283023432, 0.14585588593035936, 0.10639478074153885, 0.14278422575443983, 0.1100322617276106, 0.18094603816280141, 0.10694273805711418, 0.19352809817064553, 0.0875964027363807, 0.11894625684362836, 0.10214198511675932, 0.1037376100430265, 0.16106848837807775, 0.10620571119943634, 0.22229866997804493, 0.2828919404419139, 0.14107072551269084, 0.08294155602925457, 0.16589964710874483, 0.08009156794287264, 0.09664615150541067, 0.1009589720342774, 0.12780752236722037, 0.19983151461929083, 0.13693639892153442, 0.13564633845817298, 0.17059349367627874, 0.09006838532513939, 0.11878193792654201, 0.16317949775839224, 0.1993293478153646, 0.08294649873278104, 0.11587013636017218, 0.16526064311619848, 0.19498941663186997, 0.1668357031303458, 0.16567829414270818, 0.13312024588230997, 0.1008696471399162, 0.10012598548200913, 0.22339169023325667, 0.15578043385175988, 0.1097681387909688, 0.17314033670118079, 0.1395989427692257, 0.10561743300058879, 0.1946455053985119, 0.1573524362174794, 0.23233829531818628, 0.18683967035030946, 0.197164666315075, 0.42160747514571995, 1.965108965523541, 4.619498094543815, 12.926883548498154, 33.60629349946976, 66.47983431816101, 87.7126769721508, 101.14787444472313, 106.86611920595169, 99.87545192241669, 90.98704487085342, 93.88551414012909, 98.60217064619064, 70.81247583031654, 56.043568924069405, 59.77804273366928, 47.08054527640343, 42.20264442265034, 32.50862739980221, 32.5549241155386, 26.668057702481747, 43.168791979551315, 57.52691812813282, 43.550276309251785, 50.48024944961071, 65.3970368206501, 72.79872804880142, 69.10972639918327, 66.47914275527, 70.17416328191757, 56.4533731341362, 59.337881952524185, 62.51926124095917, 67.9779115319252, 58.289814591407776, 55.84118038415909, 44.98170509934425, 35.291617065668106, 35.25349371135235, 31.983582973480225, 28.03341943770647, 30.199660398066044, 41.03147506713867, 38.795960023999214, 43.0948631465435, 53.38715046644211, 71.35583147406578, 67.30483084917068, 86.77794992923737, 80.82053080201149, 79.77894589304924, 89.5699717104435, 91.3065393269062, 94.56059351563454, 97.04002127051353, 97.65593022108078, 79.7409175336361, 57.261863350868225, 29.901499897241592, 16.85197412967682, 5.633681248873472, 0.7159907114692032, 0.276720299734734, 0.11314205345115624, 0.17794736078940332, 0.15651621390134096, 0.14704884379170835, 0.11026304739061743, 0.14220005163224414, 0.19213431514799595, 0.1846674783155322, 0.13528825220419094, 0.1395025081001222, 0.128533179522492, 0.2498083922546357, 0.1957962053711526, 0.14498172502499074, 0.2490869356552139, 0.14544083242071792, 0.18516900687245652, 0.09961058618500829, 0.08836231398163363, 0.1984222058672458, 0.16859088238561526, 0.16133543889736757, 0.15803185757249594, 0.12691583193372935, 0.2321538864634931, 0.15611811104463413, 0.17312421725364402, 0.18747508234810084, 0.1355511654401198, 0.1926018384983763, 0.14548632607329637, 0.15503427857765928, 0.1178132496715989, 0.1391387518378906, 0.12139839440351352, 0.12613154511200264, 0.1163106677995529, 0.1609780205762945, 0.15145736426347867, 0.2032671685446985, 0.12695210811216384, 0.19214378495234996, 0.10083291082992218, 0.25450550427194685, 0.24290539469802752, 0.12274305467144586, 0.12981832696823403, 0.07582864200230688, 0.1569476688746363, 0.09280020865844563, 0.08811629202682525, 0.3064590477151796, 0.21055550401797518, 0.20069175283424556, 0.10184968283283524, 0.1809498231159523, 0.1131620914384257, 0.08001111171324737, 0.11221976426895708], [0.027049726159020793, 0.07310535336728208, 0.018295624904567376, 0.015841509521123953, 0.07066710139042698, 0.04165926497080363, 0.034152266816818155, 0.042081517312908545, 0.013016944631090155, 0.010374920238973573, 0.013985906552989036, 0.0312641731579788, 0.012648116717173252, 0.07118624111171812, 0.038991314577287994, 0.10472704874700867, 0.06751606852049008, 0.043005454062949866, 0.08642066270112991, 0.019209177153243218, 0.04141734338190872, 0.015422436354128877, 0.03002535242558224, 0.004799494072358357, 0.006544989691974479, 0.028799829124181997, 0.04678608791437, 0.01449043616958079, 0.01843061971158022, 0.009007693115563598, 0.05096372995467391, 0.0169534953602124, 0.036474443186307326, 0.003508367003632884, 0.04987893269571941, 0.030345917548402213, 0.0172711104460177, 0.08110065871733241, 0.01628534351766575, 0.038846261813887395, 0.016077054206107277, 0.01888636703370139, 0.045620248129125684, 0.03188213726389222, 0.0330803198448848, 0.10965530265821144, 0.03571621316950768, 0.09997924804338254, 0.07887386687798426, 0.04439948570507113, 0.02727849318034714, 0.1886342724901624, 0.9456831612624228, 3.3904801681637764, 10.539697743952274, 22.816698364913464, 28.45289032906294, 43.76928895711899, 62.85492762923241, 54.1001708060503, 70.8258967101574, 57.48665548861027, 57.85218447446823, 44.64596651494503, 39.708112478256226, 40.97299240529537, 33.13448801636696, 26.902706511318684, 33.53136532008648, 29.79174468666315, 33.42877082526684, 39.38553258776665, 47.48356685042381, 42.04170785844326, 61.143731251358986, 65.65955713391304, 58.05971793830395, 83.30463230609894, 68.47351893782616, 51.906084939837456, 74.39607873558998, 92.58873492479324, 85.7716803252697, 88.82852509617805, 62.648701295256615, 81.20811000466347, 82.48487189412117, 74.71900060772896, 58.67668703198433, 64.23626750707626, 78.87085542082787, 87.74490684270859, 70.30288517475128, 46.40409417450428, 44.87539440393448, 53.336476385593414, 45.68946652114391, 36.952853724360466, 30.503095015883446, 21.421506330370903, 18.809744976460934, 13.594625517725945, 19.684516936540604, 28.85499805212021, 53.59102852642536, 48.10306280851364, 52.36922308802605, 60.167248249053955, 57.11902901530266, 71.67640507221222, 74.9078580737114, 68.41368734836578, 58.802163898944855, 48.37015427649021, 34.06209424138069, 20.254324860870838, 7.089353688061237, 1.5989513508975506, 0.2091989916516468, 0.15896749799139798, 0.2189929215819575, 0.01007753424346447, 0.06646471985732205, 0.06256287844735198, 0.022610395426454488, 0.08652671560412273, 0.029555676846939605, 0.053711939908680506, 0.011077887156716315, 0.02390473622654099, 0.09235693127266131, 0.042082734435098246, 0.03631216146459337, 0.04834119899896905, 0.021797359659103677, 0.0732907047495246, 0.04693111470260192, 0.006008169229971827, 0.014241169174056267, 0.05115021311212331, 0.00659215920677525, 0.024631434243929107, 0.045563017411041074, 0.07589403263409622, 0.02462098294927273, 0.03199801991286222, 0.031944399743224494, 0.017657296266406775, 0.03430352393479552, 0.04621242631401401, 0.026704432675614953, 0.03905339151970111, 0.05808621768665034, 0.02581068649305962, 0.06493012173450552, 0.03881021941197105, 0.016846772668941412, 0.07168439289671369, 0.06758701041690074, 0.02214167165220715, 0.06346142632537521, 0.013203479738876922, 0.037482461557374336, 0.08583343093050644, 0.03404875205887947, 0.036163138211122714, 0.06546973731019534, 0.04959043762937654, 0.044842570132459514, 0.00990915670627146, 0.01660168396483641, 0.030310841793834697, 0.04892407807346899, 0.06418394419597462, 0.05419283304945566, 0.028682380543614272, 0.014574819288100116, 0.01979266478883801, 0.010974422493745806, 0.028464105635066517, 0.048665350550436415, 0.03192274016328156, 0.08748424195800908, 0.020040629315190017, 0.029031258600298315, 0.04252053106029052, 0.02096754207741469, 0.039887858656584285, 0.06312743018497713, 0.007161729254221427, 0.022967425975366496, 0.046539282993762754, 0.10756399729871191, 0.014145404293230968, 0.05243004678050056, 0.004322038466852973, 0.03400166278879624, 0.037230224115774035, 0.04686172389483545, 0.029357926032389514, 0.06934987832210027, 0.038316060381475836, 0.10114220829564147, 0.04493061853281688, 0.05340896925190464, 0.013756048574578017, 0.010291863709426252, 0.038257052219705656, 0.03326230187667534, 0.05052972941484768, 0.0481756406952627, 0.02010066349612316, 0.07687840246944688, 0.03931262741389219, 0.02780961302050855, 0.023825372809369583, 0.059865568691748194, 0.04424578321049921, 0.05398815243097488, 0.04484460732783191, 0.02210056409239769, 0.11057345065637492, 0.01995687052840367, 0.08570365156629123, 0.0642009245348163, 0.052831815846730024, 0.02631206290971022, 0.20750143274199218, 0.8022575417999178, 3.057461050339043, 11.01858889684081, 24.991287477314472, 32.80820332467556, 52.61582985520363, 75.90348064899445, 69.8634235560894, 87.27669596672058, 70.20656794309616, 75.71810379624367, 65.10654240846634, 59.58364516496658, 58.29168789088726, 49.617726132273674, 34.64004322886467, 38.659452348947525, 43.222334906458855, 36.92996755242348, 47.16643966734409, 47.54264988005161, 36.072585359215736, 41.791153103113174, 50.38747362792492, 54.62716832756996, 56.62308722734451, 56.22223533689976, 50.66009759902954, 61.34900763630867, 68.44665437936783, 61.433803886175156, 67.96104043722153, 53.36080268025398, 58.94105784595013, 60.63789859414101, 63.84967625141144, 50.71637637913227, 52.73917503654957, 63.01026709377766, 62.627616226673126, 52.21245490014553, 43.43790113925934, 35.322881788015366, 50.75720518827438, 51.54180608689785, 30.44691503047943, 34.23844277858734, 35.94587355852127, 35.676650404930115, 27.323663122951984, 35.48621982336044, 46.937372758984566, 65.65590173006058, 58.277997225522995, 63.667510226368904, 69.12001624703407, 67.58948117494583, 82.08235949277878, 87.68921703100204, 80.4325944185257, 67.00679764151573, 56.803022772073746, 39.40044678747654, 24.234890565276146, 8.219797778874636, 1.7713846731930971, 0.18860797077650204, 0.17343881365377456, 0.14892569073708728, 0.04602135297318455, 0.02686275875021238, 0.0604032843693858, 0.03779386301175691, 0.0990510439442005, 0.01212834245961858, 0.04618944200046826, 0.013780910521745682, 0.05605716738500632, 0.07663459953619167, 0.021683209924958646, 0.02878361876355484, 0.02840932585968403, 0.02383178310992662, 0.09172552687232383, 0.01339251773970318, 0.0740850402507931, 0.041235201788367704, 0.027332345271133818, 0.07461044369847514, 0.046739213867112994, 0.05541834150790237, 0.03879254145431332, 0.05682897499355022, 0.0196371458878275, 0.16457494319183752, 0.07047911538393237, 0.02535410054406384, 0.06290234421612695, 0.03695803774462547, 0.09335192124126479, 0.013079777636448853, 0.014544025725626852, 0.05283491802401841, 0.024173746205633506, 0.03372821105585899, 0.023741569493722636, 0.05560958925343584, 0.055303831832134165, 0.029935778911749367, 0.03674898216559086, 0.07654263259610161, 0.0204469087839243, 0.00401683997552027, 0.015079364675329998, 0.02233989187516272, 0.008805755660432624, 0.007138115970519721, 0.02758907085080864, 0.04972951610398013, 0.013615228835988091, 0.02273991132824449, 0.09819148850510828, 0.0547837458725553, 0.006414191730073071, 0.1324222411494702, 0.16259195428574458, 0.08017223939532414, 0.11451847763964906, 0.17332622985122725, 0.11724456417141482, 0.14148895541438833, 0.16937746986513957, 0.13571973686339334, 0.09264303662348539, 0.10727536864578724, 0.10488062136573717, 0.1362865447299555, 0.10696405253838748, 0.187064808269497, 0.21831453923368827, 0.39220094215124846, 0.10203009893302806, 0.1873610884649679, 0.09853755938820541, 0.1261789831914939, 0.10113874246599153, 0.11367935352609493, 0.15920280333375558, 0.15649043169105425, 0.11033269052859396, 0.16022652183892205, 0.17746766621712595, 0.09048152409377508, 0.08865159572451375, 0.18651008256711066, 0.15030188485980034, 0.14335723797557876, 0.16092927631689236, 0.14983925968408585, 0.1625366197549738, 0.12549415900139138, 0.14286264107795432, 0.13351328729186207, 0.0850937249197159, 0.12314840831095353, 0.09780427295481786, 0.21008565032389015, 0.20413215650478378, 0.22775278746848926, 0.20209886482916772, 0.11264319662586786, 0.1286812825128436, 0.24840128025971353, 0.0882641426869668, 0.1557777324342169, 0.3414512216113508, 1.9833363499492407, 7.4005641136318445, 16.470750086009502, 31.832387186586857, 42.77770936489105, 66.06305748224258, 90.19619330763817, 83.61153423786163, 97.3464672267437, 81.30686670541763, 78.17426159977913, 62.55807615816593, 58.05867679417133, 62.504107654094696, 51.360840797424316, 40.921664759516716, 53.504343777894974, 48.735744059085846, 51.70304283499718, 62.73768492043018, 67.75318399071693, 60.82107536494732, 84.92374062538147, 93.08026894927025, 83.39466467499733, 106.79563298821449, 88.3000798523426, 74.30465564131737, 97.00905293226242, 114.82134193181992, 112.87629470229149, 114.10906255245209, 83.80630418658257, 105.60272499918938, 107.9678624868393, 97.33613178133965, 77.32347965240479, 82.65972331166267, 99.40299287438393, 112.8281132876873, 92.45287701487541, 68.3032576739788, 62.65494056046009, 76.43387898802757, 64.45935353636742, 55.14245107769966, 50.79322725534439, 38.1389144808054, 34.70949210226536, 29.211076945066452, 38.903475254774094, 48.67604546248913, 73.5028986632824, 69.67024952173233, 73.05316239595413, 82.35631719231606, 76.99230462312698, 94.66686621308327, 97.3826564848423, 93.29324752092361, 81.78073927760124, 72.0278862118721, 54.29500535130501, 38.25945161283016, 14.102947991341352, 3.60612025950104, 0.5167969688773155, 0.3267634066287428, 0.37795063806697726, 0.10268925965647213, 0.17819268512539566, 0.10565056989435107, 0.18106441071722656, 0.2361007613944821, 0.13533171237213537, 0.14065347524592653, 0.10307631935575046, 0.18516621639719233, 0.14857648056931794, 0.20215375407133251, 0.10592161706881598, 0.2696828992338851, 0.17496717773610726, 0.26311245805118233, 0.10554596417932771, 0.2347374806413427, 0.3018401877488941, 0.09208909759763628, 0.07695100677665323, 0.13537635997636244, 0.12097680257284082, 0.22658081754343584, 0.12749478133628145, 0.11270007482380606, 0.23910159099614248, 0.14567296137101948, 0.10816030553542078, 0.2517800114583224, 0.17110885586589575, 0.17882489104522392, 0.12597578315762803, 0.11509592048241757, 0.16969763237284496, 0.04623851280484814, 0.14425866538658738, 0.14627996395574883, 0.19474910921417177, 0.18349769030464813, 0.10550182865699753, 0.1264383044326678, 0.13321926322532818, 0.147232792514842, 0.10369154493673705, 0.07704794610617682, 0.15533076657447964, 0.11275983997620642, 0.18644257681444287, 0.11391028019716032, 0.17786594718927518, 0.14051545062102377, 0.1419197127688676, 0.18682234862353653, 0.12202510100905783, 0.12507238163379952], [0.08995969037641771, 0.024293827555084135, 0.02154558420443209, 0.06493061897344887, 0.04250987010891549, 0.02257148276839871, 0.028278655918256845, 0.042731445719255134, 0.0036558686224452686, 0.026693254076235462, 0.04208086051221471, 0.051115217138431035, 0.021309354888217058, 0.02319362887647003, 0.03563346741429996, 0.03070370694331359, 0.06752783156116493, 0.0387543245597044, 0.007015040055193822, 0.007576137095384183, 0.02209502024925314, 0.06557621323736385, 0.012820805204682983, 0.024069897481240332, 0.027327888674335554, 0.052163055443088524, 0.07559498422779143, 0.03341624185850378, 0.03683390241349116, 0.02797510638629319, 0.027030712335545104, 0.02207901212386787, 0.028167888522148132, 0.019534683124220464, 0.030894234805600718, 0.1040689492947422, 0.041228006666642614, 0.009407071538589662, 0.06899093859829009, 0.045181208406575024, 0.05768271570559591, 0.02570296375779435, 0.0401991413673386, 0.030268101509136613, 0.025160598524962552, 0.03684182112920098, 0.06293747006566264, 0.031950173652148806, 0.04507755635131616, 0.10129339862032793, 1.4041289174929261, 7.0694199576973915, 23.771372437477112, 37.45808221399784, 50.257702991366386, 53.569001108407974, 56.2910420447588, 67.42330849170685, 59.742818623781204, 62.66315571963787, 42.08176910877228, 34.68725569546223, 16.539575792849064, 28.955331668257713, 28.05632460862398, 19.709825478494167, 25.52512653172016, 44.10505034029484, 47.69938766956329, 39.09773223102093, 70.34041956067085, 52.658763751387596, 60.33408209681511, 61.122463792562485, 90.02532407641411, 76.26233339309692, 45.85653215646744, 65.22053629159927, 62.883403301239014, 38.95922586321831, 24.210879653692245, 18.160061538219452, 17.633155211806297, 11.222176272422075, 14.86320549622178, 13.848652336746454, 14.144125431776047, 14.313947819173336, 25.180405229330063, 37.18411311507225, 38.35893787443638, 44.51651506125927, 52.59032562375069, 73.93116608262062, 67.41394579410553, 58.1904499232769, 74.92978289723396, 72.87220850586891, 61.07889153063297, 66.53168633580208, 47.04261191189289, 34.06311258673668, 14.268820490688086, 12.786856312304735, 19.248252846300602, 23.012197874486446, 22.70244799554348, 29.954153671860695, 37.47555747628212, 60.67267432808876, 63.12424197793007, 69.23317417502403, 70.95343306660652, 72.91774526238441, 79.11351799964905, 70.52437528967857, 63.022092059254646, 26.606759391725063, 10.86099710315466, 3.37543155066669, 1.139040298294276, 0.06807985584600829, 0.024925335856096353, 0.006917239370523021, 0.02557939245889429, 0.021575529863184784, 0.0031306729761126917, 0.11849127578898333, 0.03715579783602152, 0.05930479077505879, 0.04573838319629431, 0.08725515581318177, 0.08363838074728847, 0.029627756084664725, 0.04113771326956339, 0.05646255813189782, 0.04943909516441636, 0.03252775008149911, 0.025336958788102493, 0.04472493972571101, 0.03758360515348613, 0.011312028254906181, 0.04202441647066735, 0.07668608974199742, 0.02264607603137847, 0.04073108313605189, 0.044056895494577475, 0.08999406665679999, 0.02513947143597761, 0.027665276429615915, 0.043552684073802084, 0.057391949667362496, 0.05237421872152481, 0.08055388883803971, 0.06072001073334832, 0.04841120578930713, 0.043804153392557055, 0.06910806434461847, 0.0779388275987003, 0.016453365751658566, 0.03079509686358506, 0.06216513553226832, 0.03997751009592321, 0.020745100009662565, 0.03790859904256649, 0.023182585719041526, 0.08075729667325504, 0.05173400502826553, 0.03793149800912943, 0.016590444138273597, 0.06085515582526568, 0.037896390713285655, 0.003992686315541505, 0.025855037238216028, 0.01714736659778282, 0.07158494510804303, 0.07734800383332185, 0.023128041575546376, 0.03623441778472625, 0.04185424942988902, 0.03159015781420749, 0.03706820585648529, 0.04560439214401413, 0.039427530427929014, 0.06157967378385365, 0.050248017578269355, 0.03178651524649467, 0.05482589614985045, 0.11465631672763266, 0.013355760092963465, 0.003625879362516571, 0.05137488718901295, 0.03408954420592636, 0.02531908787204884, 0.028080927368137054, 0.07031849236227572, 0.05798078818770591, 0.02339244838367449, 0.021061542502138764, 0.029399742343230173, 0.011805954436567845, 0.018666752548597287, 0.039548441127408296, 0.04593773890519515, 0.02890404335630592, 0.050215288865729235, 0.007479411133317626, 0.022991660807747394, 0.055734837806085125, 0.028919884498463944, 0.016972447956504766, 0.059175452988711186, 0.029285638993314933, 0.07364588178461418, 0.012229509247845272, 0.06726806503138505, 0.05974714789772406, 0.027492092558532022, 0.050014578737318516, 0.0652297267515678, 0.01890277777420124, 0.03735941347258631, 0.02982009664265206, 0.014920566409273306, 0.07899695949163288, 0.26148445322178304, 1.613983700517565, 6.413590824231505, 24.74431212991476, 41.12500324845314, 56.63438022136688, 62.74630665779114, 72.51653999090195, 79.66464802622795, 76.142009049654, 71.90721228718758, 58.09298135340214, 51.34429648518562, 32.0291843265295, 37.94659540057182, 30.701370276510715, 29.796652123332024, 31.600924506783485, 39.41552817821503, 52.44623355567455, 39.96109910309315, 53.73395025730133, 50.6550020724535, 51.02985575795174, 55.7387188822031, 64.74246114492416, 57.93874762952328, 47.1680773794651, 54.0479502081871, 50.44820956885815, 36.73602595925331, 27.14142870157957, 23.560193069279194, 19.250331334769726, 14.950345270335674, 15.929081551730633, 16.192656308412552, 14.33903407305479, 16.555679328739643, 24.25380975008011, 29.82537668198347, 32.46383540332317, 37.4947464466095, 44.93422284722328, 55.166131407022476, 54.43073406815529, 52.622369304299355, 51.85156546533108, 60.91968007385731, 59.22918498516083, 52.52606347203255, 47.473508790135384, 33.72186429798603, 24.420010931789875, 25.403215773403645, 33.07157479226589, 40.68778730928898, 41.278674602508545, 48.472440987825394, 51.0175634175539, 71.91894605755806, 73.77700075507164, 78.94463986158371, 82.26240903139114, 82.29219183325768, 87.54213452339172, 80.7618847489357, 69.83562424778938, 33.73378045856953, 12.697303667664528, 4.6252690348774195, 1.370335549581796, 0.09754222061019391, 0.0741668842965737, 0.06357513077091426, 0.03307984858111013, 0.056371752652921714, 0.06797381036449224, 0.09642352946684696, 0.034590364011819474, 0.01714822563371854, 0.04459763542399742, 0.016611623177595902, 0.05585187078395393, 0.024043814701144584, 0.05075247390777804, 0.05058396556705702, 0.07998051296453923, 0.012912872334709391, 0.026364824043412227, 0.03649152000434697, 0.03184944565873593, 0.04916384001262486, 0.07674554319237359, 0.06319947788142599, 0.006880650098537444, 0.04324859277403448, 0.022487302812805865, 0.07285283762030303, 0.021320963933249004, 0.03885355712554883, 0.1487739957519807, 0.029462609672918916, 0.04142598198086489, 0.02860328801034484, 0.08292151062050834, 0.06789909835788421, 0.02707284591451753, 0.019253600257798098, 0.03534603732987307, 0.04554405924864113, 0.05614062560198363, 0.047164553543552756, 0.03658996589365415, 0.05132264741405379, 0.018120559689123183, 0.022635752757196315, 0.020877749630017206, 0.0959035733831115, 0.046099890751065686, 0.04588838608469814, 0.03768522372411098, 0.011276842105871765, 0.013006020217289915, 0.027748129796236753, 0.01697805302683264, 0.0432228476711316, 0.296629776712507, 0.13923575053922832, 0.11921215351321734, 0.10658314524334855, 0.14047754171770066, 0.1430694479495287, 0.15119842893909663, 0.13803366426145658, 0.1082858101290185, 0.1732856046874076, 0.1172612773370929, 0.14099707477726042, 0.1433337712660432, 0.0909381452947855, 0.08410052352701314, 0.1871720189228654, 0.15933165501337498, 0.0830484698235523, 0.11579669342609122, 0.11667060942272656, 0.15623030893038958, 0.1544561900664121, 0.14458108402322978, 0.08703976971446536, 0.07986183612956665, 0.2507610426982865, 0.24611831526272, 0.1191541769367177, 0.12518926989287138, 0.12729809735901654, 0.08637125793029554, 0.087382011115551, 0.16452262178063393, 0.12067383562680334, 0.18087498494423926, 0.1458536001155153, 0.0936662133608479, 0.12244943136465736, 0.14441040490055457, 0.14367753406986594, 0.167147894972004, 0.12540942057967186, 0.09033033376908861, 0.13106169149978086, 0.07330882057431154, 0.1622158190002665, 0.15146618097787723, 0.14304746553534642, 0.17131189262727275, 0.5938725080341101, 3.4247317677363753, 11.706591378897429, 34.57223206758499, 52.79710292816162, 70.4696886241436, 75.85822507739067, 84.63712200522423, 93.07317852973938, 85.42754039168358, 84.92396861314774, 62.88539059460163, 55.03561981022358, 30.981854125857353, 44.699908420443535, 43.39134603738785, 39.1712810844183, 44.479174464941025, 65.56892439723015, 72.22543761134148, 58.47513444721699, 93.26496943831444, 75.0119648873806, 86.18682324886322, 85.79476028680801, 121.87075406312943, 102.34430864453316, 66.73515021800995, 84.69298660755157, 80.18139749765396, 55.48292800784111, 36.33729815483093, 26.034584194421768, 24.660750813782215, 17.07876306027174, 21.269599981606007, 19.48121454566717, 20.15839710831642, 21.392027512192726, 35.1979710906744, 48.751623407006264, 50.002102106809616, 56.635238975286484, 68.90899077057838, 92.39191308617592, 92.74308264255524, 79.99050334095955, 100.02764135599136, 97.83073604106903, 82.09328010678291, 88.11597213149071, 63.381434977054596, 50.73344126343727, 31.332531608641148, 25.190166905522346, 34.34161864221096, 38.18500980734825, 36.48119643330574, 50.5090557038784, 56.51429906487465, 82.62053221464157, 82.53672391176224, 90.80199480056763, 92.3400230705738, 94.02079448103905, 100.87645500898361, 95.98485589027405, 84.46033269166946, 46.52251482009888, 20.565140582621098, 8.025776389986277, 2.9599860683083534, 0.6268885207828134, 0.14471852977294475, 0.166585436090827, 0.07681108225369826, 0.10051544973975979, 0.09111981562455185, 0.2043289740686305, 0.12802072655176744, 0.13673909154022112, 0.13971344131277874, 0.17674457689281553, 0.18906730081653222, 0.11092471657320857, 0.17322256666375324, 0.18917188426712528, 0.2059304396971129, 0.1766599275288172, 0.101324190327432, 0.16909379133721814, 0.09346979655674659, 0.1019246100622695, 0.23526629054686055, 0.15338700759457424, 0.08121205508359708, 0.14772207563510165, 0.12325798641541041, 0.20761845458764583, 0.14852095308015123, 0.12111613337765448, 0.23872300662333146, 0.13427296449663118, 0.14382280205609277, 0.09770269520231523, 0.196597695176024, 0.15239704196574166, 0.14613341947551817, 0.1755603912170045, 0.2098815597128123, 0.24495587451383471, 0.21774802822619677, 0.16023624397348613, 0.13392915716394782, 0.16952361358562484, 0.09379527284181677, 0.09890444751363248, 0.09897227981127799, 0.16997808997984976, 0.1209853075852152, 0.14205380401108414, 0.20028422470204532, 0.12590283004101366, 0.1199255652318243, 0.10341835295548663, 0.11287197106867097, 0.1808206448913552], [0.02338357600820018, 0.05603732977760956, 0.03887496808602009, 0.017819520471675787, 0.013527746323234169, 0.0662768971233163, 0.01667676890065195, 0.06409694222384132, 0.017642410639382433, 0.013300353202794213, 0.02407686068181647, 0.0815808579500299, 0.032412015862064436, 0.05834919029439334, 0.06358013284625486, 0.00393491429349524, 0.01303270599237294, 0.042428430533618666, 0.04623250511940569, 0.029684615728911012, 0.017407775085303, 0.09609695480321534, 0.06358372484100983, 0.04899165804090444, 0.06130888265033718, 0.01491210221502115, 0.019615712662925944, 0.03516873453918379, 0.03496342680591624, 0.02494014541298384, 0.020050436796736903, 0.04713982889370527, 0.028511580821941607, 0.019973529888375197, 0.05370916427636985, 0.10429126705275849, 0.0397540234553162, 0.021177727576286998, 0.04354489894467406, 0.040607411647215486, 0.029856677101633977, 0.02434995989460731, 0.03148404182866216, 0.03006822258612374, 0.057930641269194894, 0.046973502467153594, 0.07960140908835456, 0.04099795572983567, 1.3225470576435328, 8.250180948525667, 32.57238797843456, 43.78328740596771, 55.68848937749863, 70.2866904437542, 66.07335492968559, 61.80889315903187, 58.93086679279804, 43.52484427392483, 44.57235686480999, 36.63892976939678, 26.99868556112051, 18.16138196736574, 29.005122296512127, 53.809201419353485, 61.923343017697334, 39.48800168931484, 52.849407121539116, 47.42398604750633, 40.329599529504776, 56.97168432176113, 45.085971504449844, 55.18096201121807, 51.24222256243229, 29.85167507082224, 24.487487711012363, 27.31162916868925, 22.124675698578358, 14.859012421220541, 12.007784117013216, 4.269966725260019, 1.0664770170114934, 0.6128717260435224, 0.2841879677725956, 0.33241005206946284, 0.08207324324757792, 0.25774732406716794, 0.2960010292008519, 0.8625854796264321, 0.5408208828885108, 1.7571209510788321, 3.7039923202246428, 5.937226535752416, 11.065678820014, 23.55079047381878, 28.496766574680805, 47.5614208728075, 48.80079656839371, 41.364804580807686, 56.53225690126419, 74.82955947518349, 78.07184189558029, 75.15342369675636, 40.413772612810135, 47.07388423383236, 35.74773319065571, 22.784020118415356, 21.606892682611942, 14.894739054143429, 11.71515516936779, 21.640708968043327, 32.19133682549, 49.460551366209984, 55.15154778957367, 63.42949479818344, 68.86590868234634, 68.801129758358, 77.17970296740532, 81.25900447368622, 61.04897193610668, 53.491242080926895, 34.13459055125713, 7.080197604373097, 3.4327536122873425, 0.05649926846672315, 0.0877104040409904, 0.06756086455425248, 0.0985256330750417, 0.03602033786592074, 0.04821223599719815, 0.14647382777184248, 0.04442412871867418, 0.058019613643409684, 0.05920184376009274, 0.1298775800387375, 0.052708040457218885, 0.004516002472882974, 0.04221399809466675, 0.07539348371210508, 0.07044952595606446, 0.060435797859099694, 0.03252459966461174, 0.0252843497946742, 0.012742977105517639, 0.008814339525997639, 0.07629972024005838, 0.021900924512010533, 0.02748830203927355, 0.028047558553225826, 0.024484930581820663, 0.008432665035797982, 0.004003085659860517, 0.030618768141721375, 0.018452373915351927, 0.026289633351552766, 0.03270482280640863, 0.010839119695447152, 0.028342909208731726, 0.044023535956512205, 0.015706605627201498, 0.025845747404673602, 0.03441307977482211, 0.06024074289598502, 0.01400776094669709, 0.054149703137227334, 0.04057216705405153, 0.0158379583444912, 0.06759409050573595, 0.029747967309958767, 0.02797476128762355, 0.03506341265165247, 0.04718344862340018, 0.025420123856747523, 0.050047225813614205, 0.040978225733852014, 0.012006595916318474, 0.035088356235064566, 0.057832158272503875, 0.08413022427703254, 0.052187030523782596, 0.017258391890209168, 0.018366809854342137, 0.04187923012068495, 0.041809037793427706, 0.020418595850060228, 0.07365464654867537, 0.08137534983688965, 0.032133554632309824, 0.04474354907870293, 0.06075151119148359, 0.024518249301763717, 0.041627549289842136, 0.03276671421190258, 0.04580637876642868, 0.020254182309145108, 0.02545954117522342, 0.006069029514037538, 0.043875017363461666, 0.02381085454544518, 0.040727721207076684, 0.022191213720361702, 0.019318410159030464, 0.03390732468687929, 0.04215536842821166, 0.06812737556174397, 0.036944764433428645, 0.016972021221590694, 0.07526699948357418, 0.009229521056113299, 0.05261536476609763, 0.03262333128077444, 0.012191986261314014, 0.06775887697585858, 0.04395615265821107, 0.06342754728393629, 0.06567201708094217, 0.026599502270983066, 0.04162730067037046, 0.05586299557762686, 0.06570099052623846, 0.04274002123565879, 0.03873922556522302, 0.04227769291901495, 0.12725569104077294, 0.0870520225726068, 1.6924460465088487, 9.62747784331441, 35.48124589025974, 48.74323345720768, 67.78824090957642, 83.10303792357445, 77.09560588002205, 75.68663388490677, 69.54878523945808, 56.816546246409416, 59.070319309830666, 51.527986228466034, 38.31675633788109, 30.727512873709202, 31.440865695476532, 48.442574590444565, 57.88089193403721, 38.52156154811382, 53.13217654824257, 50.726506635546684, 47.04610392451286, 50.39608396589756, 50.04404425621033, 53.520139530301094, 48.250088319182396, 35.48121929168701, 29.442798011004925, 28.371947072446346, 22.280091159045696, 17.802899703383446, 13.114500381052494, 6.0675889905542135, 1.8129906593821943, 0.7122784887906164, 0.43775313533842564, 0.34320073085837066, 0.07352451837505214, 0.19836917199427262, 0.3208435024134815, 0.8335663180332631, 0.7921533496119082, 1.851558352354914, 3.817243818193674, 5.599487358704209, 9.154065996408463, 19.045119546353817, 24.837063252925873, 35.916455537080765, 38.94217237830162, 43.25695104897022, 51.33130878210068, 65.33110275864601, 59.79791946709156, 59.60162200033665, 34.03367556631565, 34.5596319437027, 35.705403462052345, 26.284059807658195, 25.610545948147774, 25.28652973473072, 21.16110060364008, 35.27935512363911, 46.017742305994034, 60.41418939828873, 67.3947112262249, 72.88984715938568, 78.69625478982925, 78.0293145775795, 86.03762045502663, 90.36100566387177, 70.44255807995796, 60.469085052609444, 39.9083237349987, 9.685751516371965, 3.3069217018783092, 0.04843267612159252, 0.12092280390788801, 0.03373309438757133, 0.0909118510026019, 0.014938380736566614, 0.04183553246548399, 0.04513574443990365, 0.04860862078203354, 0.09552969422657043, 0.07142617003410123, 0.04081743201822974, 0.039451802367693745, 0.03721066110301763, 0.07076374386087991, 0.02883693465264514, 0.0882594745780807, 0.030085193648119457, 0.0174701210562489, 0.06142134028777946, 0.019195473396393936, 0.048435581629746594, 0.05154095015313942, 0.011386094593035523, 0.047010019843582995, 0.08518861592165194, 0.0756508308404591, 0.023843863418733235, 0.02861136443243595, 0.06568029202753678, 0.03947258250263985, 0.03710883102030493, 0.09066582904779352, 0.0239261137903668, 0.08617113780928776, 0.022724342925357632, 0.029723875341005623, 0.06961875842534937, 0.042112913870369084, 0.06665806417004205, 0.003905877765646437, 0.03257929965911899, 0.07996385917067528, 0.012933260059071472, 0.028088460167055018, 0.041808002497418784, 0.027842601484735496, 0.024078970236587338, 0.032892537929001264, 0.017627964734856505, 0.04379469100967981, 0.0046683890468557365, 0.03398344306333456, 0.041662571238703094, 0.13867560715880245, 0.16808850778033957, 0.12731892202282324, 0.09630742788431235, 0.08521630545146763, 0.12077958424924873, 0.14120693929726258, 0.10325139941414818, 0.15301225270377472, 0.17449345003115013, 0.18671303027076647, 0.10999315796652809, 0.09517505153780803, 0.22888576495461166, 0.09927740640705451, 0.17719737603329122, 0.1083564774307888, 0.12218950898386538, 0.09226573616615497, 0.13878998695872724, 0.10985242450260557, 0.1454351030406542, 0.19062343606492504, 0.12670528463786468, 0.14201473735738546, 0.10195087466854602, 0.1561830341233872, 0.15966660110279918, 0.23444531194400042, 0.129494498251006, 0.1697579096071422, 0.21859781700186431, 0.17505218333099037, 0.11458681459771469, 0.13400487106991932, 0.26096512796357274, 0.10526311685680412, 0.14914548519300297, 0.17201982729602605, 0.11686441386700608, 0.09711432052426971, 0.19765777891734615, 0.2812591858673841, 0.07075897185131907, 0.23559501743875444, 0.15200940339127555, 0.2025694606709294, 0.2543759549735114, 3.602211456745863, 16.02967355400324, 48.25946241617203, 65.60619279742241, 80.00305786728859, 93.25357005000114, 89.72602173686028, 87.8620545566082, 81.15228340029716, 63.14229480922222, 62.33025178313255, 53.15746419131756, 43.94365780055523, 32.02224209904671, 45.88215798139572, 74.41042676568031, 87.64236554503441, 59.95155282318592, 77.23588675260544, 67.30283215641975, 59.55448932945728, 80.50998106598854, 67.3322881758213, 77.07031443715096, 69.53869298100471, 43.37635204195976, 36.96655198931694, 37.41085834801197, 31.358869895339012, 21.966915763914585, 17.052251882851124, 7.199806636199355, 2.064469358883798, 1.39879637863487, 0.9204958565533161, 0.7195432833395898, 0.30473423714283854, 0.5388277710881084, 0.6445030693430454, 1.4509141445159912, 1.0498716705478728, 2.255369215272367, 5.572114577516913, 8.665079735219479, 15.287735816091299, 30.30748151242733, 35.94542138278484, 60.60811199247837, 61.192573830485344, 56.64027750492096, 77.78143867850304, 97.42453783750534, 97.33050048351288, 99.77863311767578, 58.50286155939102, 67.82579809427261, 52.68700383603573, 36.545154601335526, 34.42960672080517, 28.28826416283846, 24.1360217705369, 38.518012538552284, 49.0334352850914, 69.32200580835342, 74.01813581585884, 83.33145886659622, 92.26775854825974, 87.44627326726913, 97.03078776597977, 104.50484231114388, 86.33376136422157, 75.59014946222305, 52.3108734190464, 16.477661915123463, 6.489237640053034, 0.2323055814485997, 0.13013186951866373, 0.09523242697468959, 0.19061332801356912, 0.15414347872138023, 0.18503512343158945, 0.21130666136741638, 0.16337995184585452, 0.19298300554510206, 0.14996256009908393, 0.15632147435098886, 0.12101690823328681, 0.1167432805232238, 0.1900708774337545, 0.17266194830881432, 0.18595921603264287, 0.14145273860776797, 0.10779415213619359, 0.13503178081009537, 0.10870123471249826, 0.1639383882866241, 0.1402646047063172, 0.09933050707331859, 0.16104650596389547, 0.12312549821217544, 0.18420342821627855, 0.120680329418974, 0.11273124502622522, 0.140537180704996, 0.06933978511369787, 0.13847283757058904, 0.16523953643627465, 0.09630332380766049, 0.23787283193087205, 0.08628428564406931, 0.11799078623880632, 0.21287465613568202, 0.11062485180445947, 0.19148946303175762, 0.07275057709193788, 0.13140925409970805, 0.08159536693710834, 0.12213358815643005, 0.1908151328098029, 0.12574755790410563, 0.16011404193704948, 0.12811690889066085, 0.13609551591798663, 0.14393793884664774, 0.1612787536578253, 0.12538430630229414, 0.1241780565760564, 0.1823680376401171], [0.01484052763771615, 0.03762530272069853, 0.050500611250754446, 0.07723002461716533, 0.002495575927241589, 0.05483644948981237, 0.06681323982775211, 0.022798613354098052, 0.03227891167625785, 0.05790599825559184, 0.010537043326621642, 0.054811075460747816, 0.053060345380799845, 0.03030640375072835, 0.028936352755408734, 0.03864903235808015, 0.050258656265214086, 0.01248830263648415, 0.055182498108479194, 0.01656568238104228, 0.06156478630146012, 0.0346668905694969, 0.03152886012685485, 0.04178695518930908, 0.01154363028035732, 0.02881398373574484, 0.04270997909770813, 0.034701990443863906, 0.0511686295067193, 0.033227205713046715, 0.04264416915248148, 0.01447400965844281, 0.08973307558335364, 0.08021650108275935, 0.0032716193436499452, 0.07911738779512234, 0.03674032872368116, 0.056730072683421895, 0.03953844810894225, 0.05990406389173586, 0.03513449555612169, 0.04167316168604884, 0.03813325456576422, 0.03681962720293086, 0.10987177229253575, 0.24962125229649246, 2.3265885561704636, 13.330817073583603, 38.45348060131073, 50.97744517028332, 66.61723494529724, 69.20661360025406, 69.70152944326401, 55.15103481709957, 54.60672162473202, 42.85942018032074, 38.367305025458336, 37.226469442248344, 19.97629377990961, 21.992784775793552, 33.50526072084904, 51.44515447318554, 76.67402610182762, 62.22372829914093, 49.07297596335411, 60.33558301627636, 50.54862678050995, 39.854465425014496, 39.93631303310394, 33.51363927125931, 23.85505724698305, 15.563050042837858, 7.942723771557212, 4.3606203608214855, 3.5208725463598967, 2.3148072883486748, 1.3135250355117023, 0.6645740673411638, 0.3659691981738433, 0.10426086868392304, 0.08485384794767015, 0.07568588247522712, 0.08768888917984441, 0.02164425459341146, 0.023933592783578206, 0.02595816236862447, 0.050364404887659475, 0.02586344206065405, 0.12273514337721281, 0.08700672187842429, 0.04238024659571238, 0.12331447127508, 0.3655717632500455, 0.5100585648324341, 0.9016707167029381, 2.9844375187531114, 3.7238759407773614, 6.191776776686311, 10.347881186753511, 16.88627488911152, 39.71180967986584, 48.522906079888344, 66.5558834373951, 81.88891187310219, 68.68191495537758, 91.07281386852264, 86.12174034118652, 46.779958605766296, 29.6984026953578, 19.849682673811913, 14.772170931100845, 20.239669047296047, 23.102346137166023, 42.69304230809212, 59.491446912288666, 55.66296614706516, 59.011483266949654, 67.94733077287674, 79.50533017516136, 80.17436787486076, 79.1455426812172, 62.79527083039284, 32.24311284720898, 10.254335906356573, 1.773150865919888, 0.1871538659906946, 0.13685250654816628, 0.08565123367588967, 0.050629607649170794, 0.04927108406263869, 0.04007970754173584, 0.020444710171432234, 0.05207308116951026, 0.01990551576454891, 0.008219352312153205, 0.028391545856720768, 0.03802959879976697, 0.06437447576900013, 0.06517428089864552, 0.06900440857862122, 0.03786542460147757, 0.03620397859776858, 0.0326619155384833, 0.06146911233372521, 0.1325216592522338, 0.012162884795543505, 0.024291920235555153, 0.013864361317246221, 0.05475734025822021, 0.04635383142158389, 0.02194037522713188, 0.06351497970172204, 0.03280060438555665, 0.05873039073776454, 0.022420641253120266, 0.052737384976353496, 0.01580458952957997, 0.0071066762757254764, 0.020787812463822775, 0.047020576894283295, 0.02043950586084975, 0.033706918839016, 0.02544323248002911, 0.0219548452514573, 0.02238870849396335, 0.05292288478813134, 0.031168937057373114, 0.06264049225137569, 0.06142128833744209, 0.11149594021844678, 0.02581822671345435, 0.0494628995511448, 0.06129805100499652, 0.04753416535095312, 0.03127715703158174, 0.03217443954781629, 0.051945246232207865, 0.0333157587738242, 0.013375665421335725, 0.022153918944241013, 0.018081988418998662, 0.027635139667836484, 0.049503057161928155, 0.05388930207118392, 0.019678620810736902, 0.041666070464998484, 0.06734276219503954, 0.03751394346181769, 0.06942009291378781, 0.022864994753035717, 0.041831840280792676, 0.020814802519453224, 0.026909634652838577, 0.003794221183852642, 0.03602769997087307, 0.06584763890714385, 0.04402400350954849, 0.06066067231586203, 0.04065389606694225, 0.1172778791806195, 0.006133758242867771, 0.05263297221972607, 0.05331831220246386, 0.005413932049123105, 0.05476606049342081, 0.10427255008835346, 0.024556690696044825, 0.03322941731312312, 0.02386612042755587, 0.04338955259299837, 0.07205130328657106, 0.0530013965908438, 0.03679859473777469, 0.11226689806790091, 0.0849793228553608, 0.048016201399150304, 0.06539469133713283, 0.019935563468607143, 0.08778387666097842, 0.022329210514726583, 0.04602460358000826, 0.09904207137878984, 2.3337107989937067, 13.763982430100441, 40.868000239133835, 59.82182778418064, 78.50881084799767, 79.51014071702957, 81.59760430455208, 67.94359177350998, 67.52982437610626, 55.74880354106426, 55.42482532560825, 48.11685986816883, 34.381961077451706, 30.273767821490765, 38.91654655337334, 41.953560188412666, 59.94213692843914, 61.30423083901405, 51.906153336167336, 52.46603809297085, 46.25150576233864, 43.462413623929024, 45.45667961239815, 38.71271789073944, 29.9540301784873, 20.976012535393238, 11.933566499501467, 6.021401518955827, 4.875263320282102, 2.752452604472637, 2.090861080214381, 1.0430987714789808, 0.5268739687744528, 0.10538992763031274, 0.09874660012428649, 0.1742292899871245, 0.060855834890389815, 0.0771205429919064, 0.11891435933648609, 0.08729005901841447, 0.028149733734608162, 0.033388370502507314, 0.15559644059976563, 0.1024065756064374, 0.0060381886396498885, 0.09821857689530589, 0.4247025871882215, 0.699641079409048, 1.0723436647094786, 3.0787776689976454, 3.4804897382855415, 5.056676510721445, 11.40699740499258, 19.415086694061756, 32.500564232468605, 45.92826850712299, 55.104878693819046, 66.42305016517639, 59.44008506834507, 65.83013758063316, 71.09359234571457, 45.557898581027985, 29.248647429049015, 25.298086814582348, 27.035691775381565, 33.30446049571037, 35.36114953458309, 54.969655349850655, 70.37140309810638, 64.86229911446571, 68.78650814294815, 79.04446050524712, 87.64437183737755, 89.30746659636497, 90.40687680244446, 70.28727561235428, 37.37159885466099, 11.586859803646803, 2.022989597171545, 0.20411223726114258, 0.10349944743211381, 0.07765741262119263, 0.06459408468799666, 0.04784805300005246, 0.04001219065685291, 0.05383060561143793, 0.02397930536972126, 0.06776424270356074, 0.02927203728177119, 0.06809798651374876, 0.06916449725395069, 0.018843266807380132, 0.09095117740798742, 0.06255910833715461, 0.057472083062748425, 0.03582393219403457, 0.04731949171400629, 0.021287053350533824, 0.10540098563069478, 0.049773106147767976, 0.05027560320741031, 0.02555210368882399, 0.04623103937774431, 0.047824304274399765, 0.030868845933582634, 0.03655152264400385, 0.038711925662937574, 0.030192626945790835, 0.027261227114649955, 0.03699025066453032, 0.02523390416172333, 0.07837404526071623, 0.0685427853022702, 0.0360168943007011, 0.03358609348651953, 0.012520398668129928, 0.02572241359303007, 0.031277613452402875, 0.052099297536187805, 0.015673151465307456, 0.04021844833914656, 0.047402730997418985, 0.009638463907322148, 0.04114132381801028, 0.0237850445046206, 0.02882661508920137, 0.02291024720761925, 0.06944484353880398, 0.01752014552039327, 0.04902758912066929, 0.1635665277717635, 0.1766665920149535, 0.16816981747979298, 0.12667350587435067, 0.10215604881523177, 0.12269768718397245, 0.24897153169149533, 0.10651622578734532, 0.1442309535923414, 0.18976027378812432, 0.12345725306659006, 0.15275897254468873, 0.1201448476058431, 0.1327598886564374, 0.15606371161993593, 0.09411036648089066, 0.17711697175400332, 0.09391513711307198, 0.21622325613861904, 0.12440084930858575, 0.1841838503605686, 0.11045553081203252, 0.12900634319521487, 0.21879053791053593, 0.09482863184530288, 0.1302446165936999, 0.1501407497562468, 0.15737707552034408, 0.15939019562210888, 0.17744923126883805, 0.17415166134014726, 0.0797659283853136, 0.18135993392206728, 0.13928575644968078, 0.14573527208995074, 0.15997594309737906, 0.1418890175409615, 0.2487346826819703, 0.1905818164232187, 0.12789119209628552, 0.09159167311736383, 0.10477652031113394, 0.1318237732630223, 0.13676741189556196, 0.2802312222775072, 0.5451858986634761, 4.845663858577609, 21.39743462204933, 53.51129360496998, 74.81829687952995, 88.55288788676262, 90.85852056741714, 92.99342840909958, 76.56311005353928, 79.05510753393173, 63.729587495326996, 57.679012566804886, 52.588600516319275, 30.649960935115814, 36.41332067549229, 50.59114649891853, 67.21315696835518, 96.72804281115532, 82.60836526751518, 65.98225861787796, 81.19572266936302, 71.12813249230385, 60.418844148516655, 60.62773413956165, 48.95224504172802, 38.15133221447468, 25.07669359445572, 13.251389935612679, 7.513030953705311, 5.986899845302105, 4.061859967187047, 2.4824908655136824, 1.8977467739023268, 1.0544868791475892, 0.44428109598811716, 0.4319400410167873, 0.35007165279239416, 0.23070787108736113, 0.2565666858572513, 0.373457646346651, 0.4011385078774765, 0.2570714650209993, 0.09690343184047379, 0.41183273715432733, 0.4295948543585837, 0.20816905394895002, 0.27846428740303963, 0.8365533140022308, 1.0133533738553524, 2.159064095467329, 4.507219344377518, 5.281992070376873, 8.252924401313066, 14.474592749029398, 25.69341380149126, 54.25358757376671, 66.0078464448452, 89.13578420877457, 106.3780277967453, 95.48500791192055, 113.8523331284523, 110.34072875976562, 67.41408258676529, 48.54402154684067, 34.75134685635567, 27.24953670054674, 36.187020018696785, 38.42486813664436, 62.43341624736786, 78.18357110023499, 75.96759080886841, 81.63347437977791, 87.18095630407333, 97.86778405308723, 99.07070070505142, 103.44140097498894, 86.60024866461754, 48.6735375970602, 19.422150515019894, 3.6535424273461103, 0.36614484968595207, 0.16560280288103968, 0.15620227059116587, 0.190406862529926, 0.13978646864416078, 0.13867937726899981, 0.2575260156299919, 0.09476777573581785, 0.17155105713754892, 0.10931497599813156, 0.1482682369532995, 0.1363197632599622, 0.12283777497941628, 0.3051045985193923, 0.1544418220873922, 0.14015433640452102, 0.16568696242757142, 0.21474592213053256, 0.14707511581946164, 0.23860595509177074, 0.10131803050171584, 0.20575952308718115, 0.19591339048929513, 0.1614821466500871, 0.1164855103706941, 0.15364260325441137, 0.11401662995922379, 0.19255353952758014, 0.18841747631086037, 0.11845865839859471, 0.17914573632879183, 0.07419205052428879, 0.0790545872587245, 0.18575135531136766, 0.13783628266537562, 0.1906025520293042, 0.10185714141698554, 0.13226074981503189, 0.08634903060737997, 0.11326327585265972, 0.09486901210038923, 0.13015457923756912, 0.11900263038114645, 0.10923607085715048, 0.1646038721082732, 0.23306797491386533, 0.1410639868117869, 0.14472601062152535, 0.14984651788836345, 0.31720519764348865, 0.163845055794809], [0.07037802002741955, 0.058217652040184475, 0.05283914826577529, 0.04268388147465885, 0.07520091123296879, 0.055564065914950334, 0.03378269953827839, 0.05683447430783417, 0.03779656814003829, 0.02596810900286073, 0.02705920338485157, 0.07849471847293898, 0.057127132822643034, 0.008749028675083537, 0.0121457337627362, 0.05964486139419023, 0.05644223070703447, 0.004796775028808042, 0.007328910542128142, 0.006545890937559307, 0.04646641893486958, 0.04726485480205156, 0.04341681538789999, 0.011438805631769355, 0.06476220340118743, 0.02614257493405603, 0.04264749397407286, 0.044858418696094304, 0.010036750445578946, 0.04558526699838694, 0.03246029998990707, 0.044533632608363405, 0.0340296899958048, 0.026063808945764322, 0.07057619572151452, 0.009088682763831457, 0.02732443026616238, 0.01924894513649633, 0.02138019659469137, 0.05935815490374807, 0.019999764808744658, 0.08429620560491458, 0.06849489451269619, 0.04430779707035981, 0.1724873061175458, 11.737491320818663, 38.11611570417881, 61.146550700068474, 66.63765504956245, 74.91715237498283, 68.4038458764553, 65.62709927558899, 43.334428891539574, 35.67851610481739, 26.273256987333298, 19.451616033911705, 14.13692956790328, 15.769306775182486, 22.701266258955002, 40.93716412782669, 53.079256787896156, 64.88542467355728, 62.23599024116993, 46.921086832880974, 38.80339242517948, 30.095456689596176, 27.051187343895435, 16.38749085366726, 8.6596735753119, 5.226164516061544, 3.3924047648906708, 1.7843330721370876, 0.4521602106979117, 0.0735150559921749, 0.09403413307154551, 0.007348500457737828, 0.019890531802957412, 0.005332050895958673, 0.06102825063862838, 0.026235877739964053, 0.08895379083696753, 0.05068085665698163, 0.2224060587468557, 0.1480671891476959, 0.02581144162832061, 0.089122332574334, 0.10633005804265849, 0.08608653297415003, 0.07036072056507692, 0.042813015170395374, 0.11041186284273863, 0.06499346403870732, 0.06803698939620517, 0.0942181634309236, 0.05853848248079885, 0.03172931421431713, 0.25835935841314495, 0.03482530570181552, 0.11297953053144738, 0.7930317556019872, 2.0295333210378885, 6.615530038252473, 14.964481461793184, 24.396229907870293, 31.168226525187492, 52.77919448912144, 58.62695910036564, 73.77975940704346, 78.96647348999977, 54.53745894134045, 50.24747014045715, 25.326098911464214, 26.661548651754856, 12.584195137023926, 29.730339981615543, 33.71241420507431, 41.31093867123127, 60.67856401205063, 67.21908465027809, 63.550373911857605, 66.00980713963509, 66.82383745908737, 77.20879420638084, 54.06394734978676, 31.233624815940857, 12.01522221788764, 1.252568825148046, 0.10782737808767706, 0.08595473496825434, 0.0642241834430024, 0.062099507413222454, 0.07874709321185946, 0.04398190889332909, 0.047670883795944974, 0.05318868126778398, 0.03893446235451847, 0.05301236924424302, 0.02035208457527915, 0.03617719077738002, 0.017722172960930038, 0.08465124905342236, 0.043334221772965975, 0.04447600855201017, 0.019140432013955433, 0.0589251599740237, 0.027012808022846002, 0.025396039309271146, 0.0584441889077425, 0.034255113641847856, 0.02705185612285277, 0.054060274342191406, 0.054937170061748475, 0.02958252589451149, 0.011973837517871289, 0.0684822334733326, 0.036423453930183314, 0.046499155068886466, 0.05604556019534357, 0.03867087005346548, 0.02341184255783446, 0.039157392384367995, 0.011947317798330914, 0.04387017113913316, 0.06543699375470169, 0.03866483639285434, 0.02544296716223471, 0.0267981733486522, 0.0080332903235103, 0.0017857261696008209, 0.031327441247412935, 0.05384753399994224, 0.042611444150679745, 0.014927453539712587, 0.021745221929450054, 0.031050117358972784, 0.008721848444110947, 0.026175800885539502, 0.04806802186067216, 0.0323235852556536, 0.03704536255099811, 0.01433985718904296, 0.06400486396159977, 0.05171889119083062, 0.0609878555405885, 0.05599987729510758, 0.034075688308803365, 0.04700997902546078, 0.0487774074281333, 0.061163911523181014, 0.061118228622945026, 0.0991019033244811, 0.045625090642715804, 0.021742450007877778, 0.03652427840279415, 0.0035112996465613833, 0.02059574835584499, 0.00901555153177469, 0.04850443066970911, 0.027630966942524537, 0.0753022960270755, 0.025887496922223363, 0.03831902526144404, 0.020858093848801218, 0.025780603536986746, 0.019098213088000193, 0.06574571976670995, 0.054898704547667876, 0.020064359487150796, 0.023585293602081947, 0.05218324928137008, 0.023571610254293773, 0.08695728000020608, 0.08140568883391097, 0.0673033318889793, 0.02520793455914827, 0.07253647490870208, 0.018504277868487407, 0.08397494471864775, 0.020279380078136455, 0.053389101958600804, 0.5903116834815592, 14.191395845264196, 43.731074407696724, 67.5933189690113, 78.87203335762024, 84.74486902356148, 81.77578434348106, 74.85205426812172, 54.91702437400818, 47.17362128198147, 39.495403692126274, 33.38421441614628, 28.240631818771362, 30.669522285461426, 25.02028752118349, 41.74013324081898, 49.59221430122852, 57.43362173438072, 57.74706311523914, 48.00982341170311, 41.04563690721989, 34.226929396390915, 30.836344733834267, 21.133949160575867, 10.92033376917243, 8.065015934407711, 4.708926295861602, 2.562451637350023, 0.6362022366374731, 0.23936906101880595, 0.06251167025766335, 0.16812708461657166, 0.06524291471578181, 0.04589323973050341, 0.011719507219822844, 0.04457199422176927, 0.02359098958550021, 0.06088150206778664, 0.22662135364953429, 0.10540943127125502, 0.12986330111743882, 0.23773400578647852, 0.0890838447958231, 0.12786453415174037, 0.03295366121164989, 0.07572326445369981, 0.021889475028729066, 0.031524318183073774, 0.03527865032083355, 0.06150177796371281, 0.0411441068717977, 0.05090563834528439, 0.053655926312785596, 0.08547711098799482, 0.03442464985710103, 0.8254928200040013, 2.2890468081459403, 6.475377883762121, 14.442449323832989, 23.46561424434185, 31.47881805896759, 53.91936130821705, 52.56970413029194, 60.622403025627136, 60.949622467160225, 45.1175782084465, 34.476921781897545, 27.284686714410782, 38.914281874895096, 32.550770938396454, 48.63643638789654, 49.28403943777084, 51.15080326795578, 70.9246838092804, 79.11314561963081, 70.78254103660583, 75.24439841508865, 78.08388724923134, 87.44843915104866, 62.16930001974106, 35.702838599681854, 13.511683568358421, 1.1732619744725525, 0.1356827630661428, 0.022989723802311346, 0.015806751034688205, 0.04169474334048573, 0.0579936273425119, 0.028029336972394958, 0.021441676108224783, 0.04317116450692993, 0.002130236107404926, 0.0723979901522398, 0.06517191344755702, 0.05330702042556368, 0.06373434371198528, 0.05048784259997774, 0.010452658352733124, 0.03991221594333183, 0.034978945113834925, 0.11853279895149171, 0.0036780379650735995, 0.016688446594343986, 0.03544086895999499, 0.016686570816091262, 0.05011287619709037, 0.034626124397618696, 0.04594429577991832, 0.058941231181961484, 0.010362028206145624, 0.048075543527374975, 0.050556498681544326, 0.04964691135683097, 0.04573725142108742, 0.10934394202195108, 0.12273755535716191, 0.03359827955137007, 0.021526601922232658, 0.011063623078371165, 0.052673014797619544, 0.04225015552947298, 0.012764138518832624, 0.03799087353399955, 0.05891430235351436, 0.016790658883110154, 0.023452345267287455, 0.10861671893508174, 0.06043232460797299, 0.051919827674282715, 0.053995458874851465, 0.028900961588078644, 0.028896915027871728, 0.1450389000819996, 0.19131378183374181, 0.1851474994327873, 0.174627244414296, 0.11253925142227672, 0.13327156979357824, 0.1596827057073824, 0.15280238818377256, 0.15906470449408516, 0.04914813245704863, 0.13384196965489537, 0.20100069406908005, 0.19998309086076915, 0.12819717958336696, 0.11485494513181038, 0.16254332876997069, 0.12499188829679042, 0.08477466821204871, 0.08806967773125507, 0.15932971058646217, 0.16237781499512494, 0.1306373908300884, 0.14716827019583434, 0.2801818842999637, 0.16915846208576113, 0.11320822333800606, 0.13022328726947308, 0.09678013884695247, 0.18917949870228767, 0.11551774980034679, 0.10960194224026054, 0.17523791320854798, 0.12953169469255954, 0.10813817469170317, 0.08505044286721386, 0.1773373005562462, 0.21310663665644825, 0.13633050955832005, 0.11594377967412584, 0.09741036323248409, 0.22074695792980492, 0.15843522967770696, 0.10144683023099788, 0.1409995832364075, 1.5058885258622468, 21.598611027002335, 57.23928116261959, 80.9508866071701, 86.49203807115555, 95.71654468774796, 88.48400518298149, 87.6408152282238, 63.48880961537361, 52.98748791217804, 42.8458359092474, 31.69292327016592, 24.47400413453579, 27.634039968252182, 35.31820423901081, 58.35582844913006, 70.71303516626358, 84.98497053980827, 81.70783638954163, 63.820509016513824, 57.02809229493141, 44.6928483992815, 38.95171746611595, 24.538716562092304, 13.648685216903687, 9.07498273998499, 5.667326543480158, 3.6901332763954997, 1.5045089623890817, 0.42526198842097074, 0.19805604504654184, 0.33706946298480034, 0.2998562785796821, 0.18493616546038538, 0.21777342451969162, 0.1622478204080835, 0.2925078588305041, 0.31220953445881605, 0.39510852831881493, 0.6414150819182396, 0.37863662000745535, 0.4881125158863142, 0.6216999585740268, 0.38213142310269177, 0.15479008230613545, 0.1531086428440176, 0.38470815983600914, 0.255908104008995, 0.19173229375155643, 0.2866702142637223, 0.33229098189622164, 0.25532174797262996, 0.4360059415921569, 0.5419426539447159, 0.3361182671505958, 1.7395761050283909, 3.581113088876009, 9.435168262571096, 20.036300159990788, 32.3790467530489, 43.29191297292709, 68.29118952155113, 73.56435656547546, 97.34553247690201, 98.74204114079475, 74.17868480086327, 66.53158754110336, 36.7729751765728, 40.88062696158886, 24.00070533156395, 46.63206674158573, 53.29229235649109, 61.84226296842098, 83.56174930930138, 86.57209977507591, 84.36419785022736, 84.88212525844574, 87.74871423840523, 100.83384409546852, 77.41579189896584, 48.19454289972782, 19.54787626862526, 2.0336705865338445, 0.28470295888837427, 0.19291771139251068, 0.15780949528561905, 0.18008820450631902, 0.10957472026348114, 0.15410530264489353, 0.13854251039447263, 0.1855271970271133, 0.14395264821359888, 0.18967700481880456, 0.11957590977544896, 0.1553755477652885, 0.18974231381434947, 0.18360914604272693, 0.11589453075430356, 0.16950566845480353, 0.12191720757982694, 0.3420140367234126, 0.09483942267252132, 0.11126901372335851, 0.16765665204729885, 0.11837874393677339, 0.15458039590157568, 0.17321492254268378, 0.1220016714069061, 0.12848985294112936, 0.06887072551762685, 0.14953054109355435, 0.16490074602188542, 0.11544042543391697, 0.11709306956618093, 0.22768428723793477, 0.16546271508559585, 0.08209463194361888, 0.17884757107822224, 0.10347516436013393, 0.14335035084513947, 0.11539390761754476, 0.05690814730769489, 0.1164348736347165, 0.1820208312710747, 0.14522725716233253, 0.15228500735247508, 0.09739381333929487, 0.07046213504509069, 0.15809473232366145, 0.1631579309469089, 0.10803454861161299, 0.1460325319203548], [0.10846679026144557, 0.05207717411394697, 0.03095907624810934, 0.06996232084929943, 0.03618748436565511, 0.036238306638551876, 0.03326845799165312, 0.057842199530568905, 0.06798664209782146, 0.04941379535011947, 0.033592145700822584, 0.01391842770317453, 0.038578992171096615, 0.030162950315570924, 0.016991805023280904, 0.03764697343285661, 0.07452843638020568, 0.04217148416501004, 0.041131991310976446, 0.05665944619977381, 0.10095785139128566, 0.016775591429905035, 0.044305975097813644, 0.009116283235925948, 0.023203172895591706, 0.05105168187583331, 0.012794746544386726, 0.017924565909197554, 0.0472435551637318, 0.062179173255572096, 0.11027093642042018, 0.05052365122537594, 0.047523226094199345, 0.032747210570960306, 0.024517034034943208, 0.019818383916572202, 0.02517101456760429, 0.062043827783782035, 0.07405519849271514, 0.057842989917844534, 0.016285104175040033, 0.060563410152099095, 0.023889470248832367, 5.92060717754066, 25.350248515605927, 52.07410052418709, 63.43894109129906, 70.09401798248291, 61.75295256078243, 45.06446845829487, 26.23081896454096, 30.998354740440845, 27.170261554419994, 23.78782745450735, 27.12831560522318, 18.697609193623066, 31.98601484298706, 46.018874645233154, 71.1145444214344, 59.29109886288643, 61.23940631747246, 42.20023915171623, 25.70331037044525, 15.692912824451923, 8.15559832379222, 5.603186935186386, 1.7146368557587266, 0.5474679730832577, 0.4131385311484337, 0.22831239650258794, 0.15717452857643366, 0.9145446633920074, 0.8405407250393182, 0.22728324547642842, 0.08600342727731913, 0.08304683709866367, 0.05104102463519666, 0.03093202682066476, 0.03820797399384901, 0.04412434558616951, 0.056360427479376085, 0.020227372224326245, 0.04625872890756, 0.07510309616918676, 0.16872130741830915, 0.11031890142476186, 0.11601300720940344, 0.19608825532486662, 0.1689964215620421, 0.04203586409857962, 0.07023353871772997, 0.035927955323131755, 0.029319321365619544, 0.07692886851145886, 0.03539895988069475, 0.13838055892847478, 0.054464058339362964, 0.24020607001148164, 0.18701686552958563, 0.03572569039533846, 0.022366236262314487, 0.18804325576638803, 0.2929575409507379, 0.9398389561101794, 0.9053512348327786, 2.878567837178707, 17.03687220811844, 33.98850739002228, 42.626428082585335, 62.7867478877306, 90.6634010374546, 75.17702043056488, 40.69308042526245, 24.415808357298374, 22.236537896096706, 18.682016730308533, 26.871878765523434, 34.63229164481163, 38.672348856925964, 49.475868344306946, 58.505445420742035, 72.77806475758553, 72.61705979704857, 78.34605038166046, 78.78086864948273, 68.17673966288567, 30.944200046360493, 4.267452685162425, 0.1872747766901739, 0.07351846987148747, 0.014612859922635835, 0.01732149856252363, 0.06997650329140015, 0.0649344632984139, 0.05242192397417966, 0.06847343902336434, 0.028665550489677116, 0.07913266119430773, 0.016205466163228266, 0.0197704022139078, 0.022396964886866044, 0.021240040150587447, 0.045329830900300294, 0.028127426630817354, 0.037880026357015595, 0.029491720415535383, 0.025703236497065518, 0.03203563566785306, 0.043793525837827474, 0.07490665710065514, 0.041663098163553514, 0.03860915305267554, 0.03202293752110563, 0.09190575743559748, 0.018528373548178934, 0.03612566717492882, 0.05631141975754872, 0.03570620159734972, 0.035619785921880975, 0.06914790283190086, 0.023900941996544134, 0.04551943849946838, 0.02101743666571565, 0.04583869558700826, 0.024223740983870812, 0.019950872119807173, 0.032098313749884255, 0.0863021714030765, 0.04527103796135634, 0.010989450984197902, 0.0019152929780830164, 0.06155809584015515, 0.07624715392012149, 0.09410884507815354, 0.02103564896970056, 0.06616709637455642, 0.04863138987275306, 0.05543531813600566, 0.027173367961950134, 0.053073177114129066, 0.011006762506440282, 0.009500762116658734, 0.04718618714832701, 0.07226893067127094, 0.048804551479406655, 0.023529408026661258, 0.010061721859528916, 0.02384638115472626, 0.02329989514691988, 0.010830768678715685, 0.06401769569492899, 0.1216931754606776, 0.06355492951115593, 0.028348222986096516, 0.08943358930991963, 0.05156735205673613, 0.02062459934677463, 0.021766224708699156, 0.06984851250308566, 0.02002169898332795, 0.054953775616013445, 0.040977123644552194, 0.023313417077588383, 0.04302930668927729, 0.052254024194553494, 0.02641575763846049, 0.0388536313403165, 0.04006527648016345, 0.09418759436812252, 0.04409109737025574, 0.0380038759612944, 0.054654704945278354, 0.09157881169812754, 0.07255237913341261, 0.04518355359323323, 0.05239059421001002, 0.053503470626310445, 0.03324790050101001, 0.020427084164111875, 7.978725414723158, 29.213161133229733, 61.468078047037125, 73.55410471558571, 81.6409219801426, 70.19833758473396, 57.02531084418297, 37.36842222511768, 47.01528757810593, 36.764361038804054, 36.20706394314766, 35.25421567261219, 24.431296326220036, 32.52913869917393, 32.99857310950756, 50.00332564115524, 49.09880317747593, 56.89804047346115, 44.06999722123146, 28.782190158963203, 17.937608174979687, 10.949078276753426, 6.900589317083359, 2.594057391397655, 0.8897787204477936, 0.5218464229255915, 0.43123411014676094, 0.1540965898311697, 1.0405010171234608, 0.7842988148331642, 0.11734453146345913, 0.3024914371781051, 0.012361511344352039, 0.06550585763761774, 0.02105090010445565, 0.012059507334925001, 0.057179817886208184, 0.08206438942579553, 0.24931299383752048, 0.14904514682712033, 0.13490481418557465, 0.28143706382252276, 0.637353693600744, 0.5429190234281123, 0.702466880902648, 0.517739555798471, 0.3901222755666822, 0.25958108191844076, 0.08883991569746286, 0.12244978017406538, 0.125216135638766, 0.07448231190210208, 0.13947994681075215, 0.17556474020238966, 0.13691644999198616, 0.1739595935214311, 0.061954350749147125, 0.03984201619459782, 0.08336689570569433, 0.33118049148470163, 0.5651700356975198, 1.267880816012621, 3.2573946844786406, 12.49462254345417, 27.807234674692154, 44.131219536066055, 58.58183652162552, 75.06558761000633, 61.2716855853796, 43.27386014163494, 21.088070422410965, 31.518085151910782, 31.068172194063663, 38.614356368780136, 52.456979379057884, 53.41643549501896, 61.078705340623856, 66.84434115886688, 81.02240636944771, 81.10851734876633, 88.43675091862679, 90.69398939609528, 78.13570126891136, 37.25201927125454, 5.481542162597179, 0.036907686735503376, 0.08314887498272583, 0.03336285917612258, 0.021004037189413793, 0.05624405872367788, 0.04564511007629335, 0.0372364729992114, 0.05610545522358734, 0.05170641939912457, 0.05290401939419098, 0.097272190178046, 0.031695386933279224, 0.013129065519024152, 0.0506430405221181, 0.04314603909733705, 0.018677777152333874, 0.10235937501420267, 0.033523764213896357, 0.04401425911055412, 0.02276225553941913, 0.01822496131353546, 0.08415562057052739, 0.05945483448158484, 0.015495049938181182, 0.04328482071286999, 0.06185895879752934, 0.030706692232342903, 0.07459696629666723, 0.018786227192322258, 0.03303949430119246, 0.03676029620692134, 0.05091057733807247, 0.021694917304557748, 0.008427527518506395, 0.05430993282061536, 0.016948890333878808, 0.03833731920167338, 0.009592507340130396, 0.007889718144724611, 0.03268760126957204, 0.048403313048765995, 0.025031314544321503, 0.02714178030146286, 0.02524830739275785, 0.06518714973935857, 0.02242647453385871, 0.055970436296775006, 0.120528901607031, 0.21846800053026527, 0.09411912382347509, 0.14136902434984222, 0.1776235766010359, 0.14538261835696176, 0.09582357728504576, 0.17774334439309314, 0.15176161512499675, 0.1273749690153636, 0.2162100755958818, 0.18955606443341821, 0.1168452441925183, 0.10988781010382809, 0.12165613487013616, 0.10659625157131813, 0.1721839013043791, 0.23474760353565216, 0.153445266187191, 0.28785423666704446, 0.2594236872391775, 0.2249854226829484, 0.1339487498626113, 0.1510962500469759, 0.12990521761821583, 0.10643974004779011, 0.14352659607538953, 0.13637220341479406, 0.14770730689633638, 0.1791519852122292, 0.12463628081604838, 0.1911434144130908, 0.09375511523103341, 0.2175157656893134, 0.1207694761978928, 0.1014535763533786, 0.15760856622364372, 0.17062035942217335, 0.1407820894382894, 0.18730976153165102, 0.19895980280125514, 0.1303237146930769, 0.09950434032361954, 0.6757765193469822, 11.96676341816783, 42.37237371504307, 74.34302598237991, 81.78467586636543, 90.19266709685326, 79.87851575016975, 64.99016225337982, 41.36287808418274, 49.12642389535904, 41.29006639122963, 37.44936928153038, 42.2758474946022, 33.17232258617878, 45.0036945194006, 61.93465881049633, 91.63852751255035, 76.23439729213715, 80.28917491436005, 58.288477063179016, 36.62020057439804, 23.83349720388651, 13.07107251137495, 9.215799383819103, 3.084928351454437, 1.354970361571759, 1.0365020879544318, 1.1061331140808761, 0.46824759745504707, 1.5393348061479628, 1.348953740671277, 0.4467155778547749, 0.35147184797097, 0.17201909999130294, 0.28134052525274456, 0.14034650812391192, 0.23273141094250605, 0.1088371813239064, 0.13020658894674852, 0.26373360597062856, 0.16057445551268756, 0.22908645652933046, 0.6013754429295659, 0.6619927589781582, 0.44988315319642425, 0.4140049440320581, 0.6178762950003147, 0.6437549251131713, 0.2646146243205294, 0.16741477127652615, 0.2248261429485865, 0.2925849531311542, 0.2823887940030545, 0.309580669272691, 0.6881493085529655, 0.6912175251636654, 0.38472843531053513, 0.22873389185406268, 0.1661273231729865, 0.4888646973995492, 0.9313814411871135, 1.6985896043479443, 1.771674882620573, 4.8259528912603855, 23.493468649685383, 42.67918825149536, 56.82078301906586, 84.10954311490059, 116.59783020615578, 95.46065121889114, 51.755985394120216, 33.7104307115078, 34.79377157986164, 30.285583287477493, 45.10618641972542, 51.46320350468159, 55.918662026524544, 69.76407408714294, 79.83109429478645, 93.25278729200363, 92.25161701440811, 98.38378876447678, 102.37704008817673, 91.84942379593849, 50.317359790205956, 8.286684639751911, 0.46943770546931773, 0.2581635501701385, 0.1440486969659105, 0.1262852587387897, 0.24919775314629078, 0.15690588596044108, 0.1356463087722659, 0.14900495210895315, 0.1289837373769842, 0.1736009432352148, 0.14802840451011434, 0.13100994896376505, 0.10304268522304483, 0.12860555376391858, 0.1599074577097781, 0.10918760119238868, 0.11867866065585986, 0.1656144397566095, 0.15155506058363244, 0.10648894443875179, 0.08721024845726788, 0.1620889562764205, 0.15134423127165064, 0.1308966675424017, 0.1643007344682701, 0.19692306756041944, 0.1562853911309503, 0.14967588329454884, 0.1761060330318287, 0.08997686367365532, 0.09648563238442875, 0.21996759896865115, 0.1561811490682885, 0.2232371157151647, 0.12443101019016467, 0.18135988939320669, 0.12473192880861461, 0.05677733264747076, 0.12380454107187688, 0.18017313588643447, 0.10444415689562447, 0.13159363326849416, 0.1670527516398579, 0.14117323094978929, 0.13304027204867452, 0.1597739156568423, 0.17195672990055755, 0.18921274691820145], [0.05104022682644427, 0.04370306174678262, 0.036125615224591456, 0.03267785315983929, 0.03454871468420606, 0.023639720857318025, 0.03678389279230032, 0.0337955795112066, 0.041252300870837644, 0.04119664721656591, 0.027783209261542652, 0.038122096375445835, 0.04665598942665383, 0.0849101621133741, 0.009397942194482312, 0.02711676621402148, 0.027615320614131633, 0.05481907952344045, 0.11339289936586283, 0.019975557806901634, 0.012617349129868671, 0.025475899965385906, 0.05161353219591547, 0.04740231539472006, 0.028069255240552593, 0.04095969801710453, 0.02725661837757798, 0.008073606568359537, 0.07971246406668797, 0.029847110818082, 0.032366444283979945, 0.08020727618713863, 0.0740304404462222, 0.03436266939388588, 0.047728322315379046, 0.051198508372181095, 0.09276714597945102, 0.09887910317047499, 0.0842595731955953, 0.05432460879092105, 0.27837398287374526, 5.335541171953082, 24.015233851969242, 45.78510358929634, 71.82383716106415, 67.07996651530266, 69.01181325316429, 57.38185331225395, 73.10054585337639, 75.65680548548698, 72.23655581474304, 37.44685381650925, 22.85146839916706, 22.66998253762722, 34.67147894203663, 72.0657017827034, 79.65529292821884, 77.11127623915672, 68.4894248843193, 49.496843218803406, 23.92088681459427, 8.96584214642644, 3.749669431708753, 1.7660083179362118, 0.4788137023570016, 0.3409929305780679, 0.05336352012818679, 0.07838001212803647, 0.04239227309881244, 0.09676381901954301, 0.03450365889875684, 0.6967849982902408, 1.0747783840633929, 0.04655258228012826, 0.2528006723150611, 0.5875057715456933, 0.1318565761903301, 0.1023992506088689, 0.11247577553149313, 0.018997574152308516, 0.09261774423066527, 0.1579939783550799, 0.3112380631500855, 0.05218170932494104, 0.16429034440079704, 0.017005245317704976, 0.17936726741027087, 0.759337538620457, 0.09211174052325077, 0.08174627524567768, 0.015001324136392213, 0.24601059994893149, 0.24604338803328574, 0.15060672943945974, 0.05759490479249507, 0.08915972197428346, 0.043400243230280466, 0.12140932623879053, 0.05975471780402586, 0.0819758883153554, 0.1493452861905098, 0.07115803207852878, 0.031187353451969102, 0.052254172624088824, 0.022422450238082092, 0.2695583371678367, 0.17039266851497814, 0.4013909271452576, 2.5330618768930435, 11.65462726727128, 25.920649208128452, 46.72404080629349, 74.76763039827347, 80.57423561811447, 49.127579033374786, 20.970468632876873, 15.815079119056463, 23.59888069331646, 28.526207394897938, 25.99972676485777, 33.69761399924755, 44.110723435878754, 58.78261394798756, 70.01521021127701, 71.14147737622261, 81.38829633593559, 79.11616265773773, 52.94411703944206, 6.896023862063885, 0.45383580203633755, 0.06127182721684221, 0.011241658739891136, 0.09477240673732013, 0.006152445985208033, 0.04169062813161872, 0.031032534025143832, 0.01456840898754308, 0.04677013916079886, 0.017535448605485726, 0.02174239620217122, 0.04876926606812049, 0.030879955884302035, 0.05039425777795259, 0.014709987572132377, 0.046045966300880536, 0.021209190927038435, 0.057827189593808725, 0.07467517381883226, 0.039168903094832785, 0.038452251901617274, 0.06161190525745042, 0.09626246115658432, 0.05311230313964188, 0.0958146269840654, 0.08632784971268848, 0.045492075514630415, 0.033381475950591266, 0.05083289303001948, 0.031701275875093415, 0.03182133681548294, 0.03981236739491578, 0.03733257370186038, 0.020506184118858073, 0.03731403485289775, 0.01788455858331872, 0.030186548756319098, 0.07429798468365334, 0.07303462669369765, 0.04415042836626526, 0.05227513458521571, 0.008286344127554912, 0.018586589467304293, 0.06044390953320544, 0.038688388449372724, 0.04025459093099926, 0.024598119234724436, 0.007773408296998241, 0.028162186972622294, 0.05610218606307171, 0.09570561291184276, 0.08399136102525517, 0.007177082434282056, 0.03897362548741512, 0.1209556290996261, 0.01828093038056977, 0.03881879121763632, 0.05445051414426416, 0.03999351822130848, 0.0630179930885788, 0.07794810444465838, 0.04443383601028472, 0.01156822969278437, 0.03896486814483069, 0.026287199107173365, 0.04336895428423304, 0.03660362883238122, 0.03683986185933463, 0.04919015285850037, 0.021540001398534514, 0.02763553857221268, 0.044353728590067476, 0.014233733782020863, 0.03990582234109752, 0.032260454463539645, 0.047194996441248804, 0.051041544138570316, 0.02516887161618797, 0.05035197020333726, 0.045971669896971434, 0.004074855514772935, 0.024360639399674255, 0.01033001752148266, 0.027807607366412412, 0.13449117075651884, 0.04109797126147896, 0.06559759451192804, 0.19302774220705032, 6.646017227321863, 25.917691066861153, 52.54896104335785, 80.46187564730644, 75.40674850344658, 78.43833222985268, 67.18466609716415, 76.48173362016678, 73.90158846974373, 59.53870877623558, 40.316874012351036, 29.450496397912502, 31.097808703780174, 44.5529855042696, 57.093866765499115, 64.02250617742538, 64.54984948039055, 61.528525203466415, 45.73836989700794, 25.59895657002926, 10.763565581291914, 4.3717509135603905, 2.1071828668937087, 0.6678314425516874, 0.26290118345059454, 0.10544616758124903, 0.07101493858499452, 0.055050124938134104, 0.0891148071968928, 0.07891599118011072, 0.9570493013598025, 1.809905106201768, 0.19402692531002685, 0.09829940419876948, 1.3780795340426266, 0.3367769974283874, 0.19552325829863548, 0.08264430362032726, 0.23668397072469816, 0.32693991903215647, 1.0513442102819681, 1.104630057234317, 0.6818722828757018, 0.7688743143808097, 1.058957576751709, 0.5998924537561834, 1.7109254049137235, 0.8194729336537421, 0.3275830642087385, 0.2057351658004336, 0.12749193148920313, 0.24417357664788142, 0.10839399299584329, 0.09589774752384983, 0.09213968238327652, 0.5231249949429184, 0.2464663379942067, 0.02878187100577634, 0.06363936365232803, 0.07964430522406474, 0.06697431555949152, 0.14093740610405803, 0.022299641495919786, 0.058858800839516334, 0.1511516291066073, 0.33800302539020777, 0.5806455959100276, 3.026121756993234, 12.73642921820283, 31.377893574535847, 47.47750237584114, 52.02673986554146, 51.0043553262949, 43.249594643712044, 21.850936487317085, 24.32999186217785, 29.578217044472694, 45.75934857130051, 37.61410564184189, 50.55975638329983, 61.43012188374996, 69.13720652461052, 78.96834298968315, 81.23320385813713, 93.6455038189888, 91.5611332654953, 63.38627591729164, 11.435674466192722, 0.9350890922360122, 0.06850351084722206, 0.08275987827801146, 0.06317932857200503, 0.05540976228076033, 0.01747224359860411, 0.09067843071534298, 0.02743332373938756, 0.04057129503053147, 0.047244160014088266, 0.04618433231371455, 0.02735927966568852, 0.026325536600779742, 0.048057446256279945, 0.0350188763695769, 0.06214267443283461, 0.0007834684879526321, 0.038071062590461224, 0.06434073773561977, 0.027895329221792053, 0.06421347425202839, 0.028225855821801815, 0.023020062799332663, 0.030705744138685986, 0.04754514171509072, 0.06002592825097963, 0.06357412887155078, 0.08621168875833973, 0.0417324629961513, 0.07765528265736066, 0.04855611754464917, 0.07570941597805358, 0.05091633640404325, 0.048447404042235576, 0.07993366860318929, 0.00417203789766063, 0.038313154873321764, 0.03011443797731772, 0.016971162185654975, 0.06531588267534971, 0.12061988149071112, 0.14201037352904677, 0.0354614709794987, 0.02537075062718941, 0.029885982658015564, 0.03537373057042714, 0.006877110054119839, 0.09455307241296396, 0.1981788408011198, 0.11740909088985063, 0.23142983234720305, 0.15862830681726336, 0.10815800487762317, 0.09013402828713879, 0.1787763397442177, 0.25493645458482206, 0.07992176455445588, 0.12467772234231234, 0.09896553368889727, 0.114250517799519, 0.14956260187318549, 0.17746990750310943, 0.09945710262400098, 0.17798541812226176, 0.09941917145624757, 0.19538334861863405, 0.17565568297868595, 0.1140349981142208, 0.11171923761139624, 0.14638665510574356, 0.18839046213543043, 0.16883357951883227, 0.09070752290426753, 0.13280763843795285, 0.11283681553322822, 0.1607128363684751, 0.18162835389375687, 0.12258703296538442, 0.14372938050655648, 0.13322604645509273, 0.13722154690185562, 0.17101268836995587, 0.10815272820764221, 0.12416999685228802, 0.17694350215606391, 0.20701148168882355, 0.16319490474415943, 0.39430555421859026, 10.805879160761833, 38.39249387383461, 66.2392920255661, 93.24299901723862, 85.79281479120255, 88.09644117951393, 75.51337838172913, 89.41151261329651, 88.50906103849411, 84.57558810710907, 50.95618911087513, 34.80638310313225, 33.39447386562824, 46.49034194648266, 88.05376186966896, 93.9455509185791, 97.80338510870934, 87.7776762843132, 65.16663998365402, 34.51463095843792, 14.80946023017168, 6.208904832601547, 3.1749858940020204, 1.1269834265112877, 0.9492603130638599, 0.32115072186570615, 0.48761447542347014, 0.10992894734954461, 0.28812595177441835, 0.17712975153699517, 2.1122123720124364, 2.6031412789598107, 0.29385464906226844, 0.8770675712730736, 3.3481302531436086, 1.2064877478405833, 0.383573712897487, 0.4049998725531623, 0.4768697504187003, 0.5988377134781331, 0.6846302223857492, 0.6003225431777537, 0.5314051662571728, 0.47431426879484206, 0.6474514736328274, 0.6828661076724529, 3.171415035612881, 0.5333211540710181, 0.7556861126795411, 0.3897929994855076, 1.1048388085328043, 1.1081954534165561, 0.5429214576724917, 0.5386602238286287, 0.27851810795255005, 0.7550877041649073, 0.6555408833082765, 0.29561368748545647, 0.207356906903442, 0.3426537086488679, 0.2630350668914616, 0.21637432771967724, 0.17164223740110174, 0.2597786416299641, 0.4416321334429085, 0.4373426386155188, 0.9633498976472765, 4.339085966348648, 16.458385549485683, 36.595714688301086, 63.200857266783714, 102.92372435331345, 112.51899987459183, 67.755296677351, 36.155884489417076, 30.397578477859497, 37.07854337990284, 45.8697060495615, 40.76982490718365, 50.79204171895981, 63.18555548787117, 79.85560297966003, 87.74144142866135, 91.67026340961456, 100.5082243680954, 102.10494428873062, 77.46262818574905, 19.62733380496502, 1.932104411534965, 0.19222457514842972, 0.22335455316351727, 0.1476242605713196, 0.26559461548458785, 0.12405351677443832, 0.08889598495443352, 0.15143330383580178, 0.12411763091222383, 0.08427781518548727, 0.10705651671742089, 0.16401110391598195, 0.14779807155719027, 0.20268084219424054, 0.15065300976857543, 0.2239435660885647, 0.12746264634188265, 0.2333539689425379, 0.3124116361141205, 0.10014500672696158, 0.12411530798999593, 0.14715667784912512, 0.2532762405462563, 0.14489024790236726, 0.2703384234337136, 0.20207795110763982, 0.13373014284297824, 0.21153314999537542, 0.22417692700400949, 0.19244484457885846, 0.20129914133576676, 0.12099118539481424, 0.18580323143396527, 0.13437688001431525, 0.17212357954122126, 0.1692212774651125, 0.19268216856289655, 0.1573865898535587, 0.1300081386580132, 0.22821648133685812, 0.13528283452615142, 0.2543691865867004, 0.1711507872096263, 0.09629095962736756, 0.12592702405527234, 0.0927453713666182, 0.11631463828962296], [0.03753510951355565, 0.0841406143445056, 0.06402961458661593, 0.013406597208813764, 0.037099721157574095, 0.11437134686275385, 0.012538791870611021, 0.043202204833505675, 0.04760863244882785, 0.03745633795915637, 0.06876827945234254, 0.04056771416799165, 0.07263107647304423, 0.04406720763654448, 0.033652853380772285, 0.014698326576763066, 0.054265734215732664, 0.028342888799670618, 0.03628973747254349, 0.007834371554054087, 0.05897625313082244, 0.02523771509004291, 0.03782118146773428, 0.035014646127820015, 0.052392056240933016, 0.03150837314024102, 0.06060186082322616, 0.005644508519253577, 0.05569793822360225, 0.008114065676636528, 0.016068085351435002, 0.05561143720115069, 0.0722097369725816, 0.06642503722105175, 0.0317569851904409, 0.035284075420349836, 0.014903648225299548, 0.09671481500845402, 0.12613164901267737, 2.1424231259152293, 17.404529079794884, 47.989179119467735, 70.1555746793747, 72.02703505754471, 64.67414081096649, 67.13646948337555, 55.28144381940365, 65.58486074209213, 71.30324229598045, 63.31281065940857, 92.50175759196281, 50.904587879776955, 23.38173184543848, 42.54652976989746, 53.47862295806408, 71.84722110629082, 67.40175604820251, 33.175955191254616, 17.461075745522976, 4.826091583818197, 1.4395639160647988, 0.323048037244007, 0.10322935020667501, 0.06263719711569138, 0.013913668681198033, 0.015993575580068864, 0.1591751360683702, 0.08448673717794009, 0.04680730962718371, 0.1250397419789806, 0.0845668742840644, 1.5681041311472654, 0.7881101884413511, 0.7225849607493728, 3.4793476620689034, 5.036235982552171, 2.655932321213186, 0.018005447018367704, 0.12332021549809724, 0.14739588688826188, 0.21919629973126575, 1.0190008208155632, 1.7877290211617947, 0.5302198673598468, 1.143670231103897, 1.9320856500416994, 1.1064157239161432, 1.5376504277810454, 0.8407793997321278, 0.4080609348602593, 0.4378629138227552, 0.3386937570758164, 0.2615983580471948, 0.11095960493548773, 0.4771132639143616, 0.07157032479881309, 0.03741468863154296, 0.0981575129844714, 0.10213045214186423, 0.09124726464506239, 0.04039527615532279, 0.038668892229907215, 0.05405958043411374, 0.03701849309436511, 0.07753665777272545, 0.07963547366671264, 0.10818573893629946, 0.14917717489879578, 0.2513270342024043, 0.3618072340032086, 2.840244281105697, 13.809115458279848, 38.795215263962746, 46.238795444369316, 54.52203556895256, 68.26734960079193, 56.631819158792496, 51.11732706427574, 26.743614748120308, 32.383701503276825, 36.32263094186783, 29.285057075321674, 36.51401147246361, 43.93318556249142, 53.793534860014915, 65.6006146967411, 70.26227295398712, 72.08805218338966, 60.064577758312225, 34.63019035756588, 9.269378408789635, 1.0448137857019901, 0.19260707806097344, 0.048961103821056895, 0.03437184604990762, 0.031102262510103174, 0.02840916258719517, 0.07611836161231622, 0.05420714907813817, 0.07574134317110293, 0.032879869468160905, 0.057196345514967106, 0.04114521638257429, 0.07236649340484291, 0.07868081942433491, 0.013967620034236461, 0.01600338120624656, 0.07042213328531943, 0.04506075412791688, 0.045756866384181194, 0.05299761534843128, 0.046485462444252335, 0.038218056070036255, 0.06400499754818156, 0.027488730629556812, 0.0092370677703002, 0.0944744492881, 0.10194192436756566, 0.06142929240013473, 0.03181555548508186, 0.07475350750610232, 0.03873217887303326, 0.03822133265202865, 0.03369983875018079, 0.06060139698092826, 0.02886947968363529, 0.07134642626624554, 0.02811576378007885, 0.02449512954626698, 0.027137989782204386, 0.03324918441649061, 0.03381613329111133, 0.020170128518657293, 0.02671286532859085, 0.03956158456276171, 0.014002424904902, 0.036637203593272716, 0.03457812970736995, 0.010104575321747689, 0.03350092090840917, 0.037887885700911283, 0.07782798042171635, 0.03893064771546051, 0.052439230857999064, 0.011358390220266301, 0.04090657879714854, 0.07472618905012496, 0.0292937469566823, 0.03062968884478323, 0.04682521022914443, 0.03604673605877906, 0.005412096161308, 0.07165524875745177, 0.029573761130450293, 0.004799377647941583, 0.01456601648897049, 0.03271971028880216, 0.024024181184358895, 0.048957304024952464, 0.008867247233865783, 0.03461557105765678, 0.039531972870463505, 0.0271656514814822, 0.011542046722752275, 0.02849450957000954, 0.03674160150694661, 0.07346337282797322, 0.024198682367568836, 0.025317104482383, 0.05168634801520966, 0.024385139549849555, 0.036482603100012057, 0.04294632344681304, 0.06600041742785834, 0.17651195812504739, 2.72625467274338, 20.46351883560419, 54.370499700307846, 80.08674457669258, 81.96278750896454, 73.8533690571785, 73.96137446165085, 65.54079830646515, 69.47417244315147, 83.69376942515373, 87.03028678894043, 117.73222133517265, 59.41452383995056, 25.637216717004776, 35.27728423476219, 36.64663955569267, 61.87649913132191, 54.401601031422615, 36.94512113928795, 21.548850797116756, 7.699254211038351, 1.5613789670169353, 0.43465161113999784, 0.16710375202819705, 0.056504997846786864, 0.08845317512168549, 0.02004803409363376, 0.07411923841573298, 0.0991145198349841, 0.13113261113176122, 0.5382974026724696, 0.2516544994432479, 1.660135667771101, 1.1103081400506198, 1.0042776796035469, 4.258790574967861, 4.906626837328076, 3.863814356736839, 0.12360117034404539, 0.2836700080661103, 0.1880591525696218, 1.5671293647028506, 3.069059452973306, 3.7399533530697227, 2.097951262257993, 3.1512281438335776, 3.1412738654762506, 2.0128553034737706, 2.0391351683065295, 1.6364768310450017, 0.2353275177301839, 0.2892625064123422, 0.24521305836969987, 0.14506710169371217, 0.06496977468486875, 0.8852460980415344, 0.2964474161854014, 0.2710345876403153, 0.458501506363973, 0.2187042112927884, 0.16615380300208926, 0.35040051327086985, 0.12513317837147042, 0.1398202808923088, 0.0737034872872755, 0.07742216665064916, 0.01463991955461097, 0.04465764919586945, 0.08913404366467148, 0.2753414190374315, 0.572724505327642, 2.5703782495111227, 11.978592183440924, 36.684671714901924, 49.212257489562035, 50.786919593811035, 48.20592328906059, 52.043903544545174, 60.80799266695976, 37.27693073451519, 33.65999221801758, 37.23733305931091, 37.67494797706604, 53.11241380870342, 55.95339976251125, 63.34631726145744, 74.09680679440498, 79.16264936327934, 82.04249203205109, 73.65419894456863, 41.646088287234306, 12.189078088849783, 1.278899156022817, 0.1200007893203292, 0.05863425292773172, 0.049893508476088755, 0.07302612168132327, 0.05367443918657955, 0.0808293221052736, 0.04607355935149826, 0.08601657813414931, 0.06662935789790936, 0.007266116963364766, 0.05837338059791364, 0.032831945281941444, 0.06906996248289943, 0.026542761370365042, 0.09835535471211188, 0.09649180705309846, 0.02989140590216266, 0.006217019790710765, 0.027029051780118607, 0.003407626718399115, 0.036826243449468166, 0.0833098468137905, 0.03092617313086521, 0.03269911198003683, 0.02637897494423669, 0.0907632359303534, 0.05732600613555405, 0.02852730693120975, 0.060477673541754484, 0.06790274972445332, 0.016208149027079344, 0.03428266216360498, 0.030474479790427722, 0.07314876158488914, 0.03372779545316007, 0.0425870423350716, 0.0593533680512337, 0.021120096098456997, 0.042628817827790044, 0.05310936794558074, 0.037228079308988526, 0.031948095638654195, 0.07026485734968446, 0.04182704971753992, 0.1030910064582713, 0.13467253680573776, 0.12435130352969281, 0.09594466609996744, 0.09778992724022828, 0.20686820265837014, 0.15020617749541998, 0.14110309799434617, 0.09006633699755184, 0.1429840415949002, 0.21615497855236754, 0.20147381321294233, 0.11115488625364378, 0.14754915522644296, 0.12944855930982158, 0.09304600054747425, 0.18998472893144935, 0.12363133122562431, 0.09477553117903881, 0.09949112267349847, 0.08455046539893374, 0.14033837418537587, 0.07840840669814497, 0.1374324652715586, 0.0961254681169521, 0.09519880026346073, 0.1669831233448349, 0.13023152510868385, 0.127836198953446, 0.1740946198697202, 0.16462714585941285, 0.11069405707530677, 0.14299564878456295, 0.2683770458679646, 0.11350900094839744, 0.10514858120586723, 0.06660103012109175, 0.15643616585293785, 0.30236331280320883, 4.528121072798967, 28.214360028505325, 66.0629054903984, 90.48393666744232, 90.14782190322876, 84.36914518475533, 86.54098704457283, 75.1447069644928, 80.50888672471046, 85.07078513503075, 78.61672505736351, 101.6484671831131, 60.87409771978855, 35.5769969522953, 57.15754374861717, 67.64173597097397, 93.06499376893044, 83.3527909219265, 47.95710124075413, 27.03708630055189, 8.905402589589357, 2.5190729275345802, 0.8183270576409996, 0.42192683613393456, 0.22695174295222387, 0.2621300029568374, 0.39400296576786786, 0.2874430571682751, 0.17726403573760763, 0.2077857792028226, 0.7635838107671589, 0.3431170166004449, 3.0574617628008127, 1.1216143146157265, 1.277175354771316, 7.305068587884307, 8.71289636939764, 6.3848344422876835, 0.360313409473747, 0.5559183633886278, 0.6100866536144167, 2.0822590542957187, 2.351823952049017, 5.062610367313027, 1.952329776249826, 4.074068237096071, 5.3209851030260324, 5.604901118203998, 3.6018687626346946, 3.5186781641095877, 1.4638560125604272, 1.102973346132785, 1.2057035649195313, 1.6906184633262455, 0.518451186362654, 1.9652151223272085, 0.504540370311588, 0.4624687012983486, 0.25423954823054373, 0.20157590304734185, 0.26871561363805085, 0.1648178035975434, 0.1680119032971561, 0.43834430049173534, 0.32597536453977227, 0.20481652056332678, 0.15961741155479103, 0.26313053676858544, 0.4789593117311597, 0.6270120735280216, 0.86293880129233, 4.510445846244693, 19.324662946164608, 52.882883325219154, 62.708711475133896, 76.5965786576271, 90.91272845864296, 73.66194292902946, 67.73244470357895, 38.39418098330498, 46.40298843383789, 51.05112701654434, 40.428204238414764, 53.28314624726772, 62.63889402151108, 76.26528203487396, 85.75205817818642, 89.75078880786896, 92.77364060282707, 87.98964411020279, 54.7337906062603, 17.455499544739723, 2.494371165521443, 0.30214334023185074, 0.1314160818583332, 0.2058895622030832, 0.29045193165075034, 0.043286839354550466, 0.144684836268425, 0.3031193237984553, 0.226664487272501, 0.30933519650716335, 0.12767666688887402, 0.16324684023857117, 0.1343374719726853, 0.14711004128912464, 0.11437916909926571, 0.23405382904456928, 0.21070562565000728, 0.11665981117403135, 0.14862092037219554, 0.15430005703819916, 0.10473967267898843, 0.13541192369302735, 0.2780215220991522, 0.11464997136499733, 0.11907982116099447, 0.31126255402341485, 0.15894612413831055, 0.15841251995880157, 0.15109938191017136, 0.12852045911131427, 0.21676972915884107, 0.16848601691890508, 0.12563071417389438, 0.1603633293416351, 0.1929353893501684, 0.17274195182835683, 0.13208883872721344, 0.11849690868984908, 0.127001075015869, 0.10885781302931719, 0.06786521931644529, 0.15684462909121066, 0.21261218818835914, 0.1730446144938469, 0.11251626710873097], [0.05591332803305704, 0.057871555181918666, 0.04752904082124587, 0.07117770641343668, 0.0550590010243468, 0.12213526541017927, 0.01081514461475308, 0.048004460622905754, 0.0749428516428452, 0.05462628811073955, 0.00659014520351775, 0.0057413212198298424, 0.03603437187848613, 0.03968662902479991, 0.029046454073977657, 0.040433129397570156, 0.00943597633522586, 0.0983223291405011, 0.03452898839896079, 0.03170071926433593, 0.0908227042236831, 0.03481086721876636, 0.06938763137441128, 0.055081246900954284, 0.03342204545333516, 0.05574700531724375, 0.04981642901839223, 0.061788903767592274, 0.07974140782607719, 0.07803715474437922, 0.02324407822015928, 0.03429330085054971, 0.050908046614495106, 0.014090160675550578, 0.06219341878022533, 0.09588313463609666, 0.1483291227486916, 1.3512465613894165, 13.713433742523193, 46.95105202496052, 65.56745767593384, 72.04570725560188, 69.65479955077171, 68.89164090156555, 61.12250559031963, 53.41053441166878, 47.36428365111351, 44.12913724780083, 22.08711091428995, 16.211727485060692, 11.659788340330124, 18.359643928706646, 38.96866075694561, 68.57435032725334, 63.70740428566933, 30.307196527719498, 14.73953828215599, 4.133475674316287, 1.0856194398365915, 0.3513753687730059, 0.07415148473228328, 0.040641977175255306, 0.07068366612656973, 0.0026653345548766083, 0.05620265430479776, 0.05023491496103816, 0.06647634188993834, 0.07922363365651108, 0.18994475685758516, 0.18894110602559522, 0.192670873075258, 0.7953674427699298, 4.2953503131866455, 4.609418660402298, 5.424682963639498, 0.22233306110138074, 0.7164991123136133, 0.17895421769935638, 0.25504771736450493, 0.048630143064656295, 1.648940637242049, 3.956927410326898, 4.428390199318528, 1.9882739474996924, 4.389331620186567, 4.373359177261591, 0.6523496482986957, 2.104269373230636, 2.4675574293360114, 0.31826542981434613, 0.056772924290271476, 0.0779217210947536, 0.08317294283187948, 0.05140428736922331, 0.21980756224365905, 0.03565089304174762, 0.7054016890469939, 1.4384340704418719, 0.19112662703264505, 0.13413645385298878, 0.08777590599493124, 0.08658561244374141, 0.1055450810235925, 0.06326369591988623, 0.0277262754025287, 0.11197075888048857, 0.052809506887570024, 0.06251454979064874, 0.0807217403780669, 0.08129160589305684, 0.09030980596435256, 0.8680858626030385, 2.4819919047877192, 15.092131812125444, 36.36007413268089, 70.0161449611187, 79.85512420535088, 47.4405911564827, 42.91135199368, 53.46896007657051, 106.15503296256065, 28.63393161445856, 13.69376789778471, 21.206572763621807, 43.25957290828228, 44.384529143571854, 57.87997618317604, 63.55346694588661, 66.38337269425392, 71.65299072861671, 64.27108883857727, 37.0135098695755, 6.0115994699299335, 0.10579750029137358, 0.027321018242218997, 0.10442462356877513, 0.07681047369260341, 0.06530225684400648, 0.007618724775966257, 0.0803274818463251, 0.059717120602726936, 0.044316799321677536, 0.02968791828607209, 0.12375727368635125, 0.02925517939729616, 0.02697328309295699, 0.07620868098456413, 0.05173927056603134, 0.07424292474752292, 0.033364766495651565, 0.018622507559484802, 0.048600535083096474, 0.06168254287331365, 0.03788453119341284, 0.04038258543005213, 0.0728489487664774, 0.046082446569926105, 0.08035883016418666, 0.045924550940981135, 0.03471891141089145, 0.08037485313252546, 0.04390440270071849, 0.044210338237462565, 0.01371154290609411, 0.07269973997608759, 0.011926388306164881, 0.040347452159039676, 0.019218928973714355, 0.040108113244059496, 0.04668873669288587, 0.024899830095819198, 0.00920257089092047, 0.022629633749602363, 0.02035743360465858, 0.02058187390503008, 0.01322280804743059, 0.03499635960906744, 0.04655914286558982, 0.0465847989107715, 0.028440167661756277, 0.02099915571307065, 0.11887846165336668, 0.09507241251412779, 0.042999372162739746, 0.008889672153600259, 0.11673069369862787, 0.02655296033481136, 0.03205818582500797, 0.045857290097046643, 0.04859015985857695, 0.018797333432303276, 0.009606366020307178, 0.04434654831129592, 0.060357375114108436, 0.029149278634577058, 0.025575451654731296, 0.02932787832833128, 0.030196515799616463, 0.01717272578389384, 0.025978363628382795, 0.0170705951313721, 0.03373185500095133, 0.04543413975625299, 0.04612927237758413, 0.055755610519554466, 0.08603091642726213, 0.029771662229904905, 0.013753287785220891, 0.048271860141539946, 0.0425282159994822, 0.04103034676518291, 0.08544199998141266, 0.18109258264303207, 1.6001459117978811, 16.085450761020184, 53.024323135614395, 75.53682312369347, 80.71216821670532, 76.26304775476456, 77.22115874290466, 72.04441532492638, 62.20797434449196, 56.32315792143345, 53.235230818390846, 35.73173984885216, 23.76008704304695, 19.65208377689123, 25.324343405663967, 37.619436755776405, 51.95215746760368, 52.782443314790726, 31.96430280804634, 14.4617741368711, 4.906837251037359, 0.9060156054329127, 0.3042274690233171, 0.07229602648294531, 0.058371573468321, 0.020312357410148252, 0.14352361264172941, 0.1452053341199644, 0.09830122246057726, 0.1924756437074393, 0.5985223304014653, 0.3878061514114961, 0.8305427490267903, 0.6573036918416619, 1.8233117368072271, 3.832105058245361, 5.325747197493911, 5.840652817860246, 0.5344210762996227, 1.1146878800354898, 0.5701487779151648, 0.22877033130498603, 0.058619510164135136, 1.5428599482402205, 6.112744817510247, 5.721112657338381, 6.443571215495467, 6.071368362754583, 5.257106255739927, 2.4099330464378, 3.639512392692268, 1.3168769306503236, 0.31733427196741104, 0.11075303555116989, 0.12840429815696552, 0.0632039456104394, 0.06632763775996864, 0.1278918600291945, 0.1974001943017356, 0.973437346983701, 2.446172176860273, 0.6236801866907626, 0.24977647990453988, 0.46793999208603054, 0.45801884320098907, 0.15298259648261592, 0.02377584187343018, 0.07325209080590867, 0.1205563684925437, 0.015870256611378863, 0.04290590608434286, 0.06307532399659976, 0.08984034560853615, 0.11082518714829348, 0.8986491663381457, 2.6056303828954697, 13.316621985286474, 31.607623547315598, 64.85279202461243, 72.84255489706993, 42.12418243288994, 32.46626727283001, 52.12721787393093, 92.13932543992996, 31.599980257451534, 21.079486683011055, 29.852007552981377, 54.55358527600765, 54.44024495780468, 68.83593589067459, 74.3735459446907, 75.04473432898521, 84.48234871029854, 75.90422540903091, 45.13210102915764, 9.672254640609026, 0.13878571218810976, 0.016215782015933655, 0.014243314908526372, 0.020220167825755198, 0.034702791963354684, 0.04623169617843814, 0.11804336740169674, 0.03280600350990426, 0.0604200160887558, 0.02863598147087032, 0.018916917542810552, 0.046649840733152814, 0.01954630330146756, 0.04190605504845735, 0.03416906904021744, 0.0736795381817501, 0.04486562866077293, 0.039738824270898476, 0.0402542272786377, 0.014703124561492587, 0.03579275457013864, 0.012828929866373073, 0.04639872022380587, 0.06704618514049798, 0.05606348677247297, 0.045047068924759515, 0.002074335225188406, 0.06475979142123833, 0.03997126863396261, 0.014935382459952962, 0.012050633104081498, 0.09193495352519676, 0.09814439181354828, 0.03092698949330952, 0.06847642245702446, 0.05229610396781936, 0.0339639802405145, 0.025098990990954917, 0.01955649484443711, 0.05862016696482897, 0.05409708486695308, 0.047897773183649406, 0.031816631599213, 0.16728649847209454, 0.09001003767480142, 0.1204457736457698, 0.13537446007831022, 0.1586378359934315, 0.2233284740941599, 0.15453034546226263, 0.1295219428720884, 0.14068480872083455, 0.33284055709373206, 0.12821464973967522, 0.14477760472800583, 0.08533254062058404, 0.16453066666144878, 0.12801306758774444, 0.09923824327415787, 0.10682653257390484, 0.2569619833957404, 0.14504979480989277, 0.10879804787691683, 0.19692244415637106, 0.12693692377069965, 0.1075160842447076, 0.11231487049371935, 0.18294548790436238, 0.15890493494225666, 0.08723949649720453, 0.16593282110989094, 0.1950315260910429, 0.2039891594904475, 0.16728574148146436, 0.28143768722657114, 0.20668125565862283, 0.1382273796480149, 0.13785459887003526, 0.2895686571719125, 0.30966180085670203, 2.7733410336077213, 23.470360189676285, 66.17648139595985, 89.03166979551315, 89.81158554553986, 86.73614457249641, 86.97138234972954, 81.76232546567917, 71.35544389486313, 64.88849490880966, 59.62274506688118, 34.05210837721825, 25.311101116240025, 20.88347990065813, 30.81758514046669, 52.733615934848785, 91.4942416548729, 85.54490849375725, 42.5860096514225, 22.221887782216072, 7.012019287794828, 1.9253735477104783, 0.7549111917614937, 0.32357463554944843, 0.25939521845430136, 0.09722409158712253, 0.5165308644063771, 0.2957033092388883, 0.36893579992465675, 0.37406929477583617, 0.6529170647263527, 0.2998367155669257, 0.6896045117173344, 0.35350619349628687, 1.5252142888493836, 7.6209009904414415, 6.430570688098669, 8.748182225972414, 0.4221287596737966, 1.8010982475243509, 0.6205619196407497, 0.5979863810352981, 0.31968162569683045, 6.346631292253733, 11.730527244508266, 10.808336678892374, 11.130806375294924, 15.111949648708105, 13.121629748493433, 5.536350421607494, 6.753247948363423, 5.69536903873086, 2.226154482923448, 1.0972610651515424, 0.33798963704612106, 0.2720295108156279, 0.25101162143982947, 0.8073501591570675, 0.6681275891605765, 3.567991442978382, 6.201804438605905, 0.5844934831839055, 0.3062809619586915, 0.4204526636749506, 0.4264132969547063, 0.3328187082661316, 0.15658170101232827, 0.17482174647739157, 0.29674914374481887, 0.22702898568240926, 0.26236279984004796, 0.21769728016806766, 0.31321060261689126, 0.21103030041558668, 1.5817562048323452, 4.142960915341973, 21.24347448348999, 48.85205201804638, 83.99416610598564, 94.49256956577301, 59.227638468146324, 56.67668715119362, 70.3009244799614, 108.81667613983154, 40.63852675259113, 27.27896422147751, 36.56882733106613, 61.06325916945934, 64.42634850740433, 79.2720302939415, 84.81570482254028, 84.87087026238441, 94.99177917838097, 90.64372569322586, 55.538370832800865, 12.477087434381247, 0.3845651925075799, 0.16264935198705643, 0.16717482008971274, 0.23576709179906175, 0.21016762795625255, 0.10955382880638354, 0.16251879336778075, 0.09409645121195354, 0.13947871484560892, 0.10959433522657491, 0.200377601722721, 0.15120668162126094, 0.12556129368022084, 0.14393635065061972, 0.1408317539608106, 0.15372435824247077, 0.09559893660480157, 0.2058404468698427, 0.09972284344257787, 0.11996348155662417, 0.1443769340403378, 0.09734089820994996, 0.15040347003377974, 0.20359962101792917, 0.16874005406862125, 0.09699810019810684, 0.13964983925689012, 0.23250521917361766, 0.1660489969071932, 0.11386610014596954, 0.1672626013169065, 0.16050093836383894, 0.14843838172964752, 0.15140710602281615, 0.1405603505554609, 0.1599181891651824, 0.1814446278149262, 0.1391149140545167, 0.12174246890936047, 0.14414030767511576, 0.12849153019487858, 0.20794608310097829, 0.15129762439755723], [0.0649285558029078, 0.04562474183330778, 0.05631983200146351, 0.05770852018031292, 0.037496083677979186, 0.023889229050837457, 0.03093479317612946, 0.10408328758785501, 0.03498501959256828, 0.00940799922318547, 0.03226830638595857, 0.03810384325333871, 0.012751811445923522, 0.007714326848144992, 0.01451913223718293, 0.012009779729851289, 0.08211317821405828, 0.0077592105481016915, 0.07265037231263705, 0.03593215958971996, 0.04572827514493838, 0.04099404832231812, 0.023089791284292005, 0.01037361962517025, 0.026661172887543216, 0.04496744761127047, 0.02284046491695335, 0.046289331367006525, 0.042845847783610225, 0.058564012360875495, 0.12942625035066158, 0.014853323191346135, 0.05563599486777093, 0.056410129109281115, 0.15081405581440777, 0.050891819555545226, 7.79146196320653, 31.96570113301277, 62.07414172589779, 73.28101336956024, 68.8885934650898, 66.18862554430962, 57.96643294394016, 47.0810354501009, 28.426829427480698, 37.88985684514046, 26.720770373940468, 27.8375456482172, 24.861412346363068, 41.98738977313042, 62.834534123539925, 51.64295665919781, 56.46976165473461, 33.59208986163139, 9.714335482567549, 0.9408437053207308, 0.1244471370591782, 0.07957351175718941, 0.011330741508572828, 0.04908575123408809, 0.10262458148645237, 0.00877644732099725, 0.030833352720947005, 0.03088429930357961, 0.026543933963694144, 0.05995500490826089, 0.1962613093201071, 0.05459718107886147, 0.30582522391341627, 1.1352922744117677, 0.6073790020309389, 0.009371745309181279, 3.6039847740903497, 4.061182653531432, 0.15718935668701306, 0.09774553196621127, 0.7824245654046535, 0.03132185658614617, 0.19498543872032315, 0.14577214198652655, 1.5940148220397532, 5.857532462105155, 3.2788184098899364, 4.935877192765474, 3.3525285171344876, 3.930178270675242, 2.4290013732388616, 2.436145464889705, 0.7900901790708303, 0.11440132220741361, 0.06555821615620516, 0.1431412878446281, 0.06698751836665906, 0.04226379249303136, 0.11185652751009911, 0.46698838064912707, 0.5309304292313755, 1.303574675694108, 0.5409402202349156, 0.22186558227986097, 2.2543463576585054, 0.8642811386380345, 0.0792491486936342, 0.0329136000800645, 0.05810929476865567, 0.03145451919408515, 0.0024491965677952976, 0.19691911933477968, 0.01736010508466279, 0.14444501866819337, 0.048616921703796834, 0.05494194949278608, 0.059290853241691366, 0.2913529583020136, 2.9496693843975663, 12.132824957370758, 35.670141354203224, 77.2017189860344, 64.415093511343, 40.910113379359245, 62.912277951836586, 50.87744973599911, 38.13372775912285, 36.388880386948586, 24.945292845368385, 16.97834774851799, 36.30359776318073, 47.88065694272518, 61.06491968035698, 72.11962848901749, 74.46502983570099, 73.2901556789875, 67.33135342597961, 25.314349941909313, 3.1546641094610095, 0.15227795694954693, 0.07048106723232195, 0.07746984963887371, 0.07090936065651476, 0.09962526586605236, 0.04182461547316052, 0.02932028059149161, 0.04468392122362275, 0.026162460781051777, 0.024967933277366683, 0.02393304544966668, 0.05440774417365901, 0.04453967740118969, 0.040087537199724466, 0.0324486519821221, 0.0475714397180127, 0.11151640122989193, 0.042849933306570165, 0.025352443699375726, 0.0432564669608837, 0.02869975422072457, 0.058154799553449266, 0.0111304980055138, 0.06833036779426038, 0.05362811432860326, 0.006511755391329643, 0.02275252598337829, 0.03558964730473235, 0.018212276154372375, 0.01116875757361413, 0.01711836532194866, 0.059083003652631305, 0.035670541401486844, 0.032332991977455094, 0.03824427614745218, 0.07354366578510962, 0.039170394811662845, 0.022446256480179727, 0.03841016841761302, 0.013541640255425591, 0.007439783230438479, 0.04578799947921652, 0.05825697102409322, 0.04423535232490394, 0.0211518989817705, 0.05095329906907864, 0.025069872826861683, 0.08264121628599241, 0.026807144058693666, 0.06803010226576589, 0.0040634459219290875, 0.03036399997654371, 0.02323859003809048, 0.042945915265590884, 0.037342306968639605, 0.02568912455899408, 0.0253285910730483, 0.06094036922149826, 0.015173155443335418, 0.023392440962197725, 0.07770559284836054, 0.04146113009483088, 0.024610568762000185, 0.0699832865211647, 0.04662092665967066, 0.03905941775883548, 0.04593802092131227, 0.06660771687165834, 0.0518149028357584, 0.014674773592560086, 0.03138952190056443, 0.1025451642635744, 0.0915640132734552, 0.0408089863776695, 0.024609119718661532, 0.11434533458668739, 0.06097864548792131, 8.611834142357111, 35.88343910872936, 71.39068320393562, 83.46351698040962, 79.15691927075386, 75.32340377569199, 67.61696889996529, 59.40740302205086, 45.195006653666496, 49.22930337488651, 37.13346183300018, 35.5728779733181, 20.562739111483097, 30.421859174966812, 40.51644690334797, 43.0740250647068, 51.06860227882862, 36.836769953370094, 12.451722845435143, 1.5752539224922657, 0.2223691443214193, 0.05080264309071936, 0.03310217238322366, 0.02607387061289046, 0.03672373801236972, 0.03800032478466164, 0.13023287581745535, 0.05222685416811146, 0.06919155595824122, 0.1490633442881517, 0.33312628394924104, 0.9606622543651611, 2.134293462149799, 2.078727618791163, 3.417281792499125, 0.05364944736356847, 4.154091943055391, 6.539065791293979, 0.6305467151105404, 0.6819245300721377, 1.033899940084666, 0.18353028543060645, 0.1794129391782917, 0.1388941251207143, 1.6590372892096639, 3.7272727210074663, 5.257763145491481, 4.886810425668955, 4.483045991510153, 3.6733177537098527, 3.5467707691714168, 4.724009111523628, 0.9061370801646262, 0.10959737803204916, 0.2027220610762015, 0.18725365516729653, 0.11355983806424774, 0.22636525332927704, 0.700761959888041, 0.2810409350786358, 1.4871600433252752, 1.8519163643941283, 2.807342321611941, 0.817213183036074, 2.4795384239405394, 1.4744151709601283, 0.7916247623506933, 0.1819593962864019, 0.029554956963693257, 0.1528223222703673, 0.08104640030069277, 0.1284273641067557, 0.06325801849015988, 0.07247642031870782, 0.06479605275671929, 0.044235367167857476, 0.01746788348100381, 0.39116422121878713, 3.1248107738792896, 15.130601897835732, 34.75344434380531, 57.39337049424648, 44.78207901120186, 47.23917156457901, 71.4511227607727, 36.63536936044693, 30.02744033932686, 37.6092305034399, 37.61628292500973, 28.246891982853413, 46.08584605157375, 56.77041672170162, 70.92952474951744, 79.46664825081825, 85.24787843227386, 85.85067808628082, 83.5982121527195, 34.91408072412014, 4.0805834624916315, 0.1264259550953284, 0.07718921391642652, 0.07471758013707586, 0.05717162828659639, 0.05479837360326201, 0.04350129405793268, 0.03445964212005492, 0.04014361387817189, 0.0049065929397329455, 0.06911140400916338, 0.010685486777219921, 0.04265276322257705, 0.061969809685251676, 0.012197798205306754, 0.08561644921428524, 0.0366360569751123, 0.14271893160184845, 0.008644492536404869, 0.009706607906991849, 0.0834174953342881, 0.025427588007005397, 0.044773075424018316, 0.029437072371365502, 0.0257274527757545, 0.12317741144215688, 0.013122509571985574, 0.07745442781015299, 0.06227693636901677, 0.003146594131067104, 0.03755155921680853, 0.06553301282110624, 0.05219090082391631, 0.05140968278283253, 0.04484855926421005, 0.07858387267333455, 0.037760117556899786, 0.00789652178355027, 0.023782719727023505, 0.08179710494005121, 0.03957168519264087, 0.02820978275849484, 0.11815119403763674, 0.23764333018334582, 0.16005751996999606, 0.16366786061553285, 0.1997542570461519, 0.09383768658153713, 0.1794600358698517, 0.2349169467925094, 0.1360224885866046, 0.10220691561698914, 0.20168060524156317, 0.15214819984976202, 0.2617494890000671, 0.1652802506578155, 0.17778845212887973, 0.10824483615579084, 0.12606436590431258, 0.15965799218975008, 0.17009978735586628, 0.2648213569773361, 0.11802338136476465, 0.1679400634020567, 0.11399686656659469, 0.10550861930823885, 0.12030242040054873, 0.09149520876235329, 0.11819717750768177, 0.09896409392240457, 0.09061894015758298, 0.16015977307688445, 0.20694045815616846, 0.18057294568279758, 0.14237803348805755, 0.14713410171680152, 0.25426320789847523, 0.3847349068382755, 11.952137053012848, 49.28328327834606, 84.04082000255585, 92.86496490240097, 85.62647491693497, 85.38395673036575, 77.06989645957947, 65.93594670295715, 45.02973832190037, 52.678708881139755, 40.99175199866295, 43.07974375784397, 37.65967659652233, 58.812822327017784, 90.06522193551064, 71.04621648788452, 75.80635786056519, 47.45682768523693, 14.221174847334623, 2.1928093722090125, 0.39311096363235265, 0.2740028518019244, 0.13592155650258064, 0.13787040661554784, 0.1451743271900341, 0.147637277841568, 0.30683127930387855, 0.2089645472005941, 0.24611193279270083, 0.24492213648045436, 0.5060684226918966, 0.36918409285135567, 1.5025229752063751, 2.6883004093542695, 1.8056049244478345, 0.06791983396396972, 9.211342222988605, 9.54550864174962, 0.4277544468641281, 0.3912569006206468, 3.18210837431252, 0.8607979724183679, 0.607804044848308, 0.2725897135678679, 8.476207070052624, 16.929685659706593, 11.029153279960155, 14.749480448663235, 12.11045365780592, 11.4425577968359, 6.426054630428553, 8.734785094857216, 3.050657990388572, 0.4313925141468644, 0.4738235310651362, 0.5628281738609076, 0.2846288925502449, 0.33052087062969804, 1.0378814139403403, 1.728421684820205, 3.541607796214521, 5.2236096281558275, 1.5244606230407953, 0.41766186186578125, 3.315980415791273, 2.4216627795249224, 0.7069661363493651, 0.15739770722575486, 0.16105425398563966, 0.24171059631044045, 0.19484631571685895, 0.37426866532769054, 0.2898242528317496, 0.29735999065451324, 0.24473851430229843, 0.16080551577033475, 0.1827405215590261, 0.5468731862492859, 5.300641944631934, 18.132562413811684, 49.79777567088604, 100.2218109369278, 85.24344027042389, 57.593859136104584, 74.95490714907646, 62.56151497364044, 53.029570654034615, 51.02229796350002, 38.466563299298286, 30.335503108799458, 54.302540346980095, 66.33580684661865, 83.7560784816742, 91.55016705393791, 95.73331698775291, 95.28408229351044, 93.35690930485725, 43.08083809912205, 6.1535427533090115, 0.3478315839311108, 0.2231044345535338, 0.13885893247788772, 0.14548046310665086, 0.19897547696018592, 0.11210648284759372, 0.15561808162601665, 0.18672673031687737, 0.14049708988750353, 0.12436264354619198, 0.14425237197428942, 0.20221219077939168, 0.12580489623360336, 0.0784447867772542, 0.1663726771948859, 0.1390802112291567, 0.22249618516070768, 0.14937204803572968, 0.09244949935236946, 0.12378827319480479, 0.12906887655844912, 0.19003313180292025, 0.17513807950308546, 0.2247825640370138, 0.20758424157975242, 0.09386632606037892, 0.1615358781418763, 0.19637626799521968, 0.12173450566479005, 0.15046431130031124, 0.10970137518597767, 0.24586792947957292, 0.13963858829811215, 0.12674546451307833, 0.19833521131658927, 0.16881558985915035, 0.1688022757298313, 0.10727396598667838, 0.09353215180453844, 0.21375234966399148, 0.11206605064217001], [0.02263250029500341, 0.07193649304099381, 0.0038309686260618037, 0.059620723041007295, 0.05835773983562831, 0.04358790269179735, 0.03752498290850781, 0.03236356846173294, 0.01827497464546468, 0.015178538797044894, 0.034448443111614324, 0.1136496156686917, 0.05359827628126368, 0.043017595598939806, 0.02669584602699615, 0.02317940005013952, 0.05152022196853068, 0.03930515769752674, 0.04312624972953927, 0.09847025401541032, 0.03196395162376575, 0.03649654805485625, 0.082434728537919, 0.0354187566699693, 0.012100328240194358, 0.08382273765164427, 0.05090043960080948, 0.04586554648994934, 0.08304110771859996, 0.04937851364957169, 0.08964489359641448, 0.032831923017511144, 0.02947479017166188, 0.02662090766534675, 0.4346167598851025, 15.94162467867136, 41.14536255598068, 66.31582751870155, 73.88049960136414, 69.19905200600624, 72.6478761434555, 74.21950981020927, 57.29518376290798, 32.4591426551342, 15.941049009561539, 16.321687884628773, 23.729185201227665, 20.40630340576172, 47.178086042404175, 42.9489965736866, 41.21840603649616, 40.09741298854351, 21.63568563759327, 2.1990125393494964, 0.13018425030168146, 0.05202602158533409, 0.24770250369329005, 0.1368738804012537, 0.04902743698039558, 0.12980903527932242, 0.0928422661672812, 0.005259658564682468, 0.09725761439767666, 0.0714309568866156, 0.237234866945073, 0.0968186414684169, 0.7058013207279146, 2.4931188952177763, 0.9322746901307255, 2.521098218858242, 3.0530815478414297, 1.3407017709687352, 0.048817483402672224, 0.17081595986383036, 0.271742923068814, 1.1744329053908587, 0.8339799020905048, 0.688871507300064, 0.04332478536525741, 0.2722970995819196, 1.208270920906216, 3.323542959988117, 2.98575462307781, 4.29497935809195, 3.597939061000943, 1.6586780897341669, 1.3136924640275538, 2.9167581629008055, 1.291042948141694, 0.09820668026804924, 0.06872173937154002, 0.12319706351263449, 0.048349800490541384, 0.04175754758762196, 0.44475414091721177, 0.21424319129437208, 0.3040109993889928, 0.35436153353657573, 1.7178897187113762, 0.4669908742653206, 1.3213489344343543, 1.089162512216717, 0.17426333972252905, 0.3248049085959792, 0.20349396887468174, 0.18859153962694108, 0.029678019891434815, 0.12654694000957534, 0.030012804563739337, 0.04631094270735048, 0.059890564225497656, 0.06813782500103116, 0.13191023346735165, 0.03950073216401506, 0.07170105411205441, 0.021457402217492927, 2.808306044898927, 12.460774909704924, 43.49042572081089, 35.66353730857372, 34.728783667087555, 45.58665543794632, 40.36830045282841, 31.331781148910522, 20.562076047062874, 15.85557259619236, 21.564270369708538, 39.35013748705387, 42.568040415644646, 57.08641916513443, 59.13713112473488, 69.55321580171585, 79.11771297454834, 82.11427018046379, 36.606954485177994, 4.191779745742679, 0.19760697148740292, 0.1261044864077121, 0.01425222346369992, 0.04452027766092215, 0.023717215917713474, 0.05686416021490004, 0.06160459510283545, 0.05999130335112568, 0.05268356813758146, 0.007887947194831213, 0.06072451185900718, 0.053916976758046076, 0.0722167725325562, 0.02924882290244568, 0.04383181694720406, 0.052202478327672, 0.10736442636698484, 0.05580406534136273, 0.07723133079707623, 0.05699840359739028, 0.10052431840449572, 0.05884160898858681, 0.07418572000460699, 0.04095823969691992, 0.03167648443195503, 0.0117112619591353, 0.03599426992877852, 0.03994911181507632, 0.05310930857376661, 0.10707820969400927, 0.04334335018938873, 0.05575528026383836, 0.03063064064917853, 0.05212936936004553, 0.020225286789354868, 0.03464983972662594, 0.012707740861515049, 0.05094010368338786, 0.01244851609953912, 0.04055424047692213, 0.02311834727152018, 0.059092710944241844, 0.05484238667122554, 0.05422163209004793, 0.03926399447664153, 0.056601384276291355, 0.08110504481010139, 0.04730484542960767, 0.0644226856820751, 0.028544958913698792, 0.035055683183600195, 0.056889070401666686, 0.10725703759817407, 0.04779203940415755, 0.008375170855288161, 0.023024665970297065, 0.009019352255563717, 0.033072720252675936, 0.0562248890491901, 0.020031873827974778, 0.062197856823331676, 0.07404223317280412, 0.06129679306468461, 0.06548707387992181, 0.037156410107854754, 0.041416289532207884, 0.05786759211332537, 0.04427724656125065, 0.05434728511318099, 0.03369895930518396, 0.023949344868015032, 0.035119292660965584, 0.05676537664839998, 0.0017040831994563632, 0.790519081056118, 18.846979178488255, 47.673818841576576, 76.93814232945442, 82.76369333267212, 78.94461706280708, 81.98487192392349, 81.92633986473083, 65.86998224258423, 40.757954344153404, 24.375460222363472, 32.96511970460415, 34.6348375082016, 33.664346784353256, 54.163228422403336, 47.317390367388725, 50.663437619805336, 42.435450330376625, 22.700950875878334, 2.6676221564412117, 0.17187875986564904, 0.176670198852662, 0.07501195301301777, 0.1428044418571517, 0.06840186630142853, 0.2144201341434382, 0.09111375227803364, 0.08786405829596333, 0.25387928006239235, 0.3687480662483722, 0.7244051224552095, 0.8047261030878872, 2.0131937228143215, 4.952170718461275, 3.4329450270161033, 6.380572021007538, 6.376096336171031, 5.374884735792875, 0.6438038474880159, 1.0101081104949117, 0.957993728807196, 5.637210784479976, 2.2020970238372684, 0.08048779316595756, 0.24392313149292022, 0.28505001682788134, 0.28389096027240157, 0.8206138224340975, 3.448328976519406, 4.669199427589774, 3.065266781486571, 1.7407861026003957, 1.6243279329501092, 2.008480313234031, 0.8333865401800722, 0.054503904248122126, 0.6447543308604509, 0.06984664229094051, 0.1738521602237597, 0.22533291106810793, 1.3168629189021885, 0.7827999733854085, 1.936109634116292, 1.565395351499319, 4.663859764114022, 4.2175480630248785, 3.6094961408525705, 2.2750039491802454, 0.7158422225620598, 2.1811596723273396, 0.6859390146564692, 0.19714504393050447, 0.17222005873918533, 0.19404969440074638, 0.08765225677052513, 0.10341374421841465, 0.04422224228619598, 0.08848146579111926, 0.059647540547302924, 0.01624003540200647, 0.07087828693329357, 0.07488257440854795, 3.148773475550115, 14.743590764701366, 39.88627351820469, 43.41555833816528, 47.176045551896095, 50.40270321071148, 46.289404928684235, 43.93581122159958, 24.66976772993803, 28.71189583092928, 39.901928678154945, 49.30532589554787, 53.96275877952576, 67.89006024599075, 67.48996451497078, 75.93846157193184, 85.07910668849945, 96.30951046943665, 52.3540049046278, 7.130607599392533, 0.1274951672530733, 0.09212501012370922, 0.03449920972343534, 0.039486401292379014, 0.036699135816888884, 0.04555629726382904, 0.027772069624916185, 0.025395523516635876, 0.060968021643930115, 0.012317309956415556, 0.007698432364122709, 0.04705618885054719, 0.08313652564538643, 0.02154225567210233, 0.06885388618684374, 0.022269662440521643, 0.016760950711613987, 0.05600307966233231, 0.07402390212519094, 0.0697266889619641, 0.07859830744564533, 0.038114374328870326, 0.07808041453245096, 0.01455848740079091, 0.016251933884632308, 0.006634447245232877, 0.04123477134271525, 0.05389099045714829, 0.050556899441289715, 0.056827112202881835, 0.06324929083348252, 0.06989339017309248, 0.04244954092428088, 0.03178386949002743, 0.030753638638998382, 0.0337996947200736, 0.07325902246520855, 0.03790926326473709, 0.058580514014465734, 0.05097447254229337, 0.08226579346228391, 0.28950554493349046, 0.10953504504868761, 0.1198089738318231, 0.11115549481473863, 0.18497085344279185, 0.16734051198000088, 0.15825460577616468, 0.16259508614894003, 0.2123359459801577, 0.23605860740644857, 0.17382185091264546, 0.2093515475280583, 0.13681585929589346, 0.08701677055796608, 0.11973582033533603, 0.09575455012964085, 0.151415150903631, 0.16639044421026483, 0.21325735200662166, 0.1834898383822292, 0.16683467896655202, 0.17258822335861623, 0.28902439575176686, 0.08600744229624979, 0.1053813038743101, 0.21937915007583797, 0.15721617790404707, 0.1650392307783477, 0.09659605653723702, 0.21193601744016632, 0.12287403631489724, 0.20565583021380007, 0.19966448686318472, 1.2943980493582785, 27.09001176059246, 62.749365493655205, 89.15805861353874, 91.83762162923813, 87.92014583945274, 89.52055156230927, 92.72738948464394, 75.49326226115227, 48.58374081552029, 26.210980229079723, 25.822646766901016, 36.57117560505867, 34.3486862629652, 65.4994185268879, 63.74066390097141, 59.53573353588581, 56.266077384352684, 30.769240334630013, 4.518881868571043, 0.5028692912310362, 0.4536957142408937, 0.4744759382447228, 0.5078408494591713, 0.18765729444567114, 0.3792889084434137, 0.3516109858173877, 0.25052708806470037, 0.46111030387692153, 0.2830696402816102, 0.5453375936485827, 0.3716316068312153, 2.032925826497376, 7.252654675394297, 2.835568394511938, 6.873915698379278, 14.141719210892916, 5.2800318505615, 0.18668441305635497, 0.4249837720999494, 0.26196515711490065, 2.9118884867057204, 3.9534370601177216, 1.8772219377569854, 0.45260312443133444, 0.8109549782238901, 4.622689448297024, 12.48258763924241, 10.3197655454278, 14.672684669494629, 11.141802035272121, 8.191654589027166, 6.942482544109225, 8.457790408283472, 3.799929334782064, 0.399582966347225, 1.03811118286103, 0.22020821808837354, 0.2299452549777925, 0.25785481673665345, 1.2706335308030248, 0.5880246218293905, 2.25085387006402, 2.209852645173669, 6.735941302031279, 4.62110873311758, 2.767035746946931, 1.6656447784043849, 0.2981926209758967, 1.469892819877714, 0.5985759431496263, 0.3269012086093426, 0.3746475465595722, 0.13893834227928892, 0.15661708661355078, 0.20654832216678187, 0.14383893634658307, 0.23657759127672762, 0.31105024041607976, 0.1754379368503578, 0.19990301312645897, 0.24839354708092287, 4.258069563657045, 17.68944539129734, 58.49369265139103, 52.6768583804369, 53.181934878230095, 60.821945518255234, 56.91361963748932, 47.763266041874886, 33.818656504154205, 28.556191585958004, 36.34868994355202, 53.31777758896351, 61.75617478787899, 76.07549741864204, 79.4295546412468, 88.39250609278679, 97.4708117544651, 106.29189401865005, 62.23689839243889, 9.809772111475468, 0.38675918884109706, 0.19339446705998853, 0.14872615691274405, 0.18458064703736454, 0.14855866902507842, 0.282584156957455, 0.14008822588948533, 0.2214093692600727, 0.14441540697589517, 0.09198297790135257, 0.15588920301524922, 0.178591916046571, 0.20496497978456318, 0.1330012796097435, 0.15413343004183844, 0.124717234284617, 0.1499215341755189, 0.1464857318205759, 0.13090999651467428, 0.17256113496841863, 0.19468277605483308, 0.11888742679730058, 0.13524923007935286, 0.14164599386276677, 0.19544117676559836, 0.16176082310266793, 0.12366192255285569, 0.15878089237958193, 0.22778903396101668, 0.16266973136225715, 0.1843418536009267, 0.221601941739209, 0.13607912929728627, 0.10476236755494028, 0.14740074053406715, 0.09079866606043652, 0.2005749981617555, 0.11013302311766893, 0.19561798602808267, 0.10183928534388542], [0.050797592775779776, 0.03719742860994302, 0.06316938379313797, 0.01670358640694758, 0.02931057144451188, 0.0692310679005459, 0.049043337494367734, 0.045770443975925446, 0.031652101170038804, 0.05626760706945788, 0.08215905778342858, 0.013831109390594065, 0.02491834296961315, 0.03571612782252487, 0.007549804304289864, 0.04298217289033346, 0.09856785385636613, 0.029848908670828678, 0.009737195523484843, 0.07681227711145766, 0.07855997551814653, 0.10566804005065933, 0.04475171270314604, 0.03195785859134048, 0.08043058100156486, 0.07929767773021013, 0.0700043338292744, 0.01501475237091654, 0.0712587266752962, 0.048802829696796834, 0.12275009765289724, 0.023560587505926378, 0.14049195422558114, 0.11009271707735024, 21.928870305418968, 51.405773386359215, 62.445032224059105, 71.25865548849106, 59.846792444586754, 58.369116336107254, 46.71586364507675, 33.70804823935032, 28.428191654384136, 26.011386439204216, 24.327664487063885, 12.607597131282091, 22.98272855579853, 21.528476290404797, 18.535981066524982, 47.31406554579735, 34.864109605550766, 10.989843439310789, 0.4328077897662297, 0.0187635323163704, 0.09175816652714275, 0.12048734133713879, 0.12071782271959819, 0.057642910614958964, 0.1111866204882972, 0.0725775453611277, 0.09367117832880467, 0.05248164830845781, 0.13783128059003502, 0.32888618647120893, 0.6070684280712157, 0.9101254411507398, 1.2444842839613557, 7.084493273869157, 5.436454256996512, 2.613997533917427, 5.8155247662216425, 2.6857310347259045, 1.5782415121793747, 0.748140251962468, 1.9684054073877633, 3.9314756635576487, 0.4547905898652971, 0.26392540661618114, 0.6816797400824726, 0.33945995033718646, 0.25167118292301893, 0.6777843553572893, 3.9677409175783396, 3.9007122768089175, 2.1005852334201336, 1.6956117516383529, 4.936937335878611, 7.771536782383919, 6.995876803994179, 4.335857564583421, 2.7792789274826646, 0.8840149641036987, 0.3150827740319073, 0.7794622681103647, 0.8850310533307493, 0.4588104475988075, 0.44250863953493536, 0.8889651484787464, 5.405323477461934, 3.1590740103274584, 2.95855307020247, 1.8771899957209826, 2.550532389432192, 1.62565513048321, 0.3168027161154896, 0.41185639682225883, 0.08691413153428584, 0.12498112715547904, 0.10604687675368041, 0.061819843904231675, 0.07804378954460844, 0.05533822666620836, 0.05576555158768315, 0.09450301455217414, 0.13927394145866856, 0.14492373360553756, 0.018661370122572407, 0.16644589748466387, 2.35951307695359, 24.1909896209836, 37.33018487691879, 37.4288921803236, 22.454963475465775, 23.947046510875225, 29.192661233246326, 15.401744898408651, 15.61629943549633, 19.89521373063326, 27.332100570201874, 31.18545100092888, 56.03433921933174, 61.01256988942623, 62.36816614866257, 73.12064677476883, 77.7701760828495, 49.395913034677505, 10.878804847598076, 0.3218937007477507, 0.05155932572961319, 0.012830662781198043, 0.04687696760811377, 0.07847047250834294, 0.033525393228046596, 0.05380874194088392, 0.04685348234488629, 0.0352272937016096, 0.05293237314617727, 0.03976428364694584, 0.09006509761093184, 0.10711814466048963, 0.019933498442696873, 0.037935282962280326, 0.025483048702881206, 0.02207306937634712, 0.03890475047228392, 0.07057957249344327, 0.027839901922561694, 0.02745847697951831, 0.06775312533136457, 0.0529554724926129, 0.01798127341317013, 0.05497094891325105, 0.040561001442256384, 0.03977288884925656, 0.0329674911336042, 0.07069610452163033, 0.08290881247376092, 0.02052004372671945, 0.0304535697796382, 0.07325833968934603, 0.034981791250174865, 0.03580697411962319, 0.05799892998766154, 0.11321666155708954, 0.013226530845713569, 0.05568191896600183, 0.05007190593460109, 0.06007764481182676, 0.04056218145706225, 0.08032669516978785, 0.034938342214445584, 0.030680978670716286, 0.0436240341514349, 0.02310159328771988, 0.06492379121482372, 0.008618124957138207, 0.12918206892209128, 0.024550157941121142, 0.012064074326190166, 0.04587396244460251, 0.009947757662303047, 0.0727327803906519, 0.11085866542998701, 0.035612820865935646, 0.06716829069773667, 0.08240136157837696, 0.02351958755753003, 0.024030758468143176, 0.04839177265239414, 0.005302733279677341, 0.11050299115595408, 0.03939917296520434, 0.039611590473214164, 0.006691098624287406, 0.03561403798812535, 0.017649516703386325, 0.04236444256093819, 0.059589842276182026, 0.056803252155077644, 0.23068936192430556, 26.424580067396164, 64.06289801001549, 72.9413191974163, 81.97954460978508, 69.50641751289368, 64.70074698328972, 56.66820600628853, 51.782051995396614, 49.82845522463322, 36.86891242861748, 22.90472824126482, 16.062771677970886, 27.563185170292854, 21.99621219187975, 29.012066423892975, 48.46798002719879, 38.553118854761124, 12.890831083059311, 0.5154417478479445, 0.1031902019167319, 0.06352840515319258, 0.05402054717706051, 0.16679273277986795, 0.12620071327546611, 0.2598359057446942, 0.07217447753646411, 0.2556069998536259, 0.5802907899487764, 1.0187976504676044, 1.500869826413691, 2.0911933248862624, 2.9219522466883063, 4.127262532711029, 9.488793835043907, 9.204375296831131, 7.07195489667356, 9.474461004137993, 4.549498725682497, 6.648807702586055, 2.922899345867336, 8.804896082729101, 7.324266582727432, 2.7093797782436013, 1.3811666308902204, 0.8184965641703457, 0.07380983704933897, 0.610211156308651, 0.06738124997355044, 2.0872830972075462, 2.2220647148787975, 0.7387409219518304, 1.133218298200518, 2.9453779896721244, 6.2670559622347355, 5.4922775365412235, 2.6735453261062503, 2.333062933757901, 1.1202847422100604, 0.36344928026665, 1.095587492454797, 2.7393846306949854, 1.695524831302464, 2.404721863567829, 2.9625409562140703, 5.516294147819281, 4.204272525385022, 4.837678112089634, 6.817391831427813, 4.753546351566911, 3.587962221354246, 1.5662536304444075, 2.6486685359850526, 0.5208707659039646, 1.1102382000535727, 0.5706175183877349, 0.3667147894157097, 0.3636330954032019, 0.1533317769644782, 0.11249407689319924, 0.01884206081740558, 0.15757338842377067, 0.15426553232828155, 0.03737696155440062, 0.10325368522899225, 2.412598840892315, 20.83852831274271, 40.30480585992336, 38.129901364445686, 24.802388213574886, 22.636483535170555, 25.718116275966167, 15.103961527347565, 19.903632178902626, 29.23377502709627, 38.024871200323105, 42.88026586174965, 65.2546052634716, 72.42717638611794, 71.30201116204262, 80.98891496658325, 90.44186532497406, 63.72057817876339, 14.475835282355547, 0.23897219012724236, 0.06052261058357544, 0.01851075496233534, 0.016637156768410932, 0.0209114357130602, 0.03943136733141728, 0.011386961978132604, 0.037978398031555116, 0.02810154608596349, 0.05545783860725351, 0.06967747714952566, 0.0416437800595304, 0.03873164823744446, 0.05906894366489723, 0.023622874105058145, 0.06207326507137623, 0.017305791006947402, 0.07596825482323766, 0.027895151106349658, 0.04707223408331629, 0.011111906278529204, 0.11280720384093001, 0.05540304584428668, 0.026135327861993574, 0.034761388233164325, 0.03581556818971876, 0.09323547084932216, 0.010096894093294395, 0.0297585614680429, 0.022037973212718498, 0.004772090269398177, 0.02816885145875858, 0.03423080088396091, 0.03720325075846631, 0.012520800355559913, 0.041384343785466626, 0.012793848545697983, 0.053983213438186795, 0.0285133526995196, 0.15649087697966024, 0.11422360010328703, 0.07989284305949695, 0.12909600947750732, 0.12080399348633364, 0.11122172407340258, 0.21058769838418812, 0.16173357143998146, 0.12504993908805773, 0.20326175086665899, 0.24990000296384096, 0.16799112316221, 0.08696120596141554, 0.14097212377237156, 0.1131125605024863, 0.16984730871627107, 0.25105145992711186, 0.11830339368316345, 0.13739688671194017, 0.11022005477570929, 0.18249911576276645, 0.15456484048627317, 0.1015487864788156, 0.14224187907529995, 0.20253704366041347, 0.19544013775885105, 0.11754813225707039, 0.2154372475342825, 0.1627634497708641, 0.13012947980314493, 0.3395135037135333, 0.1722819241695106, 0.2531935356091708, 0.6803169194608927, 36.73594996333122, 77.45423823595047, 85.88531702756882, 91.46170020103455, 79.56222832202911, 76.13070845603943, 64.79879692196846, 50.792091116309166, 44.90149900317192, 40.852831453084946, 36.530532985925674, 19.211710207164288, 33.603428453207016, 31.157089322805405, 27.623248547315598, 63.02614264190197, 50.892591923475266, 16.171394549310207, 0.8773160423152149, 0.17736505687935278, 0.3270814020652324, 0.18418221763568, 0.3143607237143442, 0.21150831773411483, 0.21609579969663173, 0.16064187220763415, 0.22975703148404136, 0.5184936372097582, 1.0476829879917204, 0.7808199827559292, 1.3047794485464692, 2.5645396253094077, 6.550373509526253, 21.85822829604149, 16.059938929975033, 10.663752537220716, 15.52532471716404, 7.039902191609144, 4.520426485687494, 3.223520927131176, 9.82079342007637, 11.761186849325895, 2.1703737135976553, 0.5569224595092237, 1.7877887492068112, 1.095925911795348, 1.4964677626267076, 4.6511622704565525, 11.123760603368282, 9.887144509702921, 8.046795912086964, 6.2927639577537775, 9.285850524902344, 11.866532396525145, 6.19721096009016, 3.0504124285653234, 4.6929714269936085, 2.7830488001927733, 1.991453308146447, 3.1626997282728553, 2.5167510146275163, 0.9865243791136891, 1.8034124420955777, 3.666675710119307, 13.991204537451267, 14.570732340216637, 6.862414190545678, 6.147936629131436, 7.348856013268232, 5.956670567393303, 2.603619103319943, 4.327938789501786, 1.0284792934544384, 0.8678964665159583, 0.35580061725340784, 0.4031508561456576, 0.29409816255792975, 0.27984298998489976, 0.15451055980520323, 0.3416262794053182, 0.4047638102201745, 0.38233696832321584, 0.24953483662102371, 0.4322918487014249, 4.0973852109164, 32.49180570244789, 51.96629650890827, 52.5875935703516, 34.834353402256966, 40.44132873415947, 47.45951794087887, 24.9765632674098, 25.04830341786146, 31.814400851726532, 45.248481184244156, 48.47546562552452, 74.98731940984726, 81.8028236925602, 82.87339344620705, 91.97841167449951, 102.5584651529789, 75.1640023291111, 17.61117909103632, 0.32409378269221634, 0.1327496173325926, 0.21994435490341857, 0.1100883012986742, 0.16965556744253263, 0.09039430689881556, 0.1642172280116938, 0.1297046893159859, 0.13426686404272914, 0.19580058404244483, 0.15833110635867342, 0.15955575392581522, 0.11047231819247827, 0.17844697460532188, 0.14876348694087937, 0.2451946827932261, 0.14107761264313012, 0.1494466487201862, 0.09150672689429484, 0.22931797691853717, 0.140345424588304, 0.21637460973579437, 0.1329516150872223, 0.2346281919744797, 0.15009632479632273, 0.18103022739524022, 0.18957991705974564, 0.10360822401707992, 0.1494135637767613, 0.22821514547104016, 0.10614409067784436, 0.15087277453858405, 0.17398421798134223, 0.09748713840963319, 0.103931065677898, 0.22756968479370698, 0.22548537788679823, 0.17868383845780045, 0.14970396616263315], [0.07081363844918087, 0.1841896539554, 0.11417051427997649, 0.050240466225659475, 0.12352435805951245, 0.0047353316949738655, 0.014748928988410626, 0.018340734495723154, 0.044215032321517356, 0.05781803891295567, 0.10588895514956675, 0.09720859554363415, 0.022126461335574277, 0.080514696019236, 0.08771712047746405, 0.027847865167132113, 0.017767336357792374, 0.0511581615137402, 0.030861019986332394, 0.017526943593111355, 0.09252431525965221, 0.09534353390336037, 0.013980367348267464, 0.040610855212435126, 0.06912833981914446, 0.06863241447717883, 0.07395143882604316, 0.14865900739096105, 0.36252539546694607, 0.3175209666369483, 0.08486695427563973, 0.09430538062588312, 0.2407716162269935, 16.98552556335926, 52.74299383163452, 64.85973805189133, 66.18005320429802, 54.818085283041, 48.117806017398834, 40.410607382655144, 28.909319937229156, 17.96432264149189, 16.7329778149724, 16.358922086656094, 35.90110436081886, 67.65388011932373, 45.570179522037506, 60.66050358116627, 69.80291560292244, 33.80932800471783, 6.900285808369517, 0.14551835716702044, 0.08561760696466081, 0.19114488386549056, 0.08436659089056775, 0.10877021733904257, 0.2114722048281692, 0.3894666029373184, 0.14439165825024247, 0.40448734536767006, 0.39301582030020654, 0.838990705087781, 1.032657406758517, 2.1094646444544196, 3.9398627635091543, 3.1976108299568295, 3.086954830214381, 4.2120217345654964, 6.807444915175438, 8.31713430583477, 6.342359846457839, 8.407140076160431, 11.076585184782743, 6.2046500109136105, 12.814087551087141, 13.873711992055178, 0.9715853619854897, 1.0887004807591438, 0.6354084354825318, 2.743517621420324, 0.5292501475196332, 0.21222180366748944, 2.436896162107587, 3.566862903535366, 9.115385971963406, 22.489995695650578, 45.87868116796017, 59.17074032127857, 63.788985908031464, 65.73489189147949, 43.642219975590706, 24.021376222372055, 2.459613005630672, 1.5345520502887666, 2.5091687589883804, 2.9187668301165104, 1.6963126952759922, 0.7580881181638688, 2.9014737205579877, 3.2984222704544663, 6.804907126352191, 5.367040056735277, 3.637835020199418, 4.486077753826976, 0.8755052019841969, 0.6606801075395197, 0.4894097603391856, 0.3603055723942816, 0.7950271829031408, 0.6223751942161471, 0.08569050813093781, 0.26799635379575193, 0.08333296471391805, 0.03994141945440788, 0.09302329825004563, 0.13406771613517776, 0.40631495823618025, 0.06531473976792768, 0.12286153854802251, 0.19518068293109536, 9.714194890111685, 38.203784599900246, 58.779080137610435, 60.733288675546646, 42.37349845468998, 48.659105971455574, 38.723611906170845, 25.201319307088852, 15.947007089853287, 23.79737064242363, 30.052974969148636, 33.41918773949146, 59.233376160264015, 73.79971593618393, 80.39360851049423, 71.58127337694168, 62.57253058254719, 13.233492895960808, 0.308338135946542, 0.12037160340696573, 0.16454536118544638, 0.1755669666454196, 0.03765610556001775, 0.02402939848252572, 0.051764789313892834, 0.17692662571789697, 0.11668348568491638, 0.18367188720731065, 0.24645857512950897, 0.4630859603639692, 0.35143610613886267, 0.22793323325458914, 0.06385769607732072, 0.008822480886010453, 0.0565302197355777, 0.023731535657134373, 0.07619714800966904, 0.035181250859750435, 0.051160970542696305, 0.07550096896011382, 0.10680913663236424, 0.02639808339154115, 0.007425780759149347, 0.024206818161474075, 0.04188425817119423, 0.14675054495455697, 0.025056358317669947, 0.048982139996951446, 0.20440786436665803, 0.1281250428291969, 0.017282084954786114, 0.032931957102846354, 0.057067631132667884, 0.051734402077272534, 0.06181853772432078, 0.01038621479892754, 0.05415762556367554, 0.13069873675704002, 0.06358897924656048, 0.025390647606400307, 0.09910669759847224, 0.032616822645650245, 0.033594613341847435, 0.0404098816215992, 0.04880798020167276, 0.06660729384748265, 0.015638725089957006, 0.06582862508366816, 0.038426707178587094, 0.011893718965438893, 0.0510701205348596, 0.05148604977875948, 0.06540092537761666, 0.04447000828804448, 0.0323899147042539, 0.07195522484835237, 0.027018079126719385, 0.006980632233535289, 0.04950619273586199, 0.06173426314489916, 0.04538810804660898, 0.04525079217273742, 0.04597076818754431, 0.09383992044604383, 0.2624384989030659, 0.1598025328712538, 0.04627457004971802, 0.17274863115744665, 0.33275663503445685, 20.779739767313004, 62.841138169169426, 72.07416012883186, 79.20827731490135, 63.43011416494846, 61.08491040766239, 51.66287139058113, 43.33750672638416, 26.44589502364397, 21.27079501748085, 25.805918164551258, 33.53820115327835, 39.20174024999142, 27.78826229274273, 37.199080511927605, 46.30642041563988, 38.07280942797661, 9.24662807956338, 0.3214916941942647, 0.09099368762690574, 0.19550278986571357, 0.09624574799090624, 0.1429700298467651, 0.8121333899907768, 0.7752952573355287, 0.7789793971460313, 1.4839166798628867, 0.5405597062781453, 1.6138864494860172, 1.4564565033651888, 5.1622951682657, 7.457061856985092, 5.87393713183701, 5.1439207792282104, 8.91780037432909, 11.562953386455774, 7.569411378353834, 9.202944673597813, 7.092195460572839, 6.442011874169111, 5.041726212948561, 6.8742443807423115, 9.294978585094213, 3.944511814042926, 2.3225657595321536, 1.0398463835008442, 3.7095072492957115, 0.8051932405214757, 1.0415865713730454, 2.7901876671239734, 4.37176326289773, 10.487713683396578, 23.310090489685535, 44.89122435450554, 60.25511093437672, 66.0447196662426, 64.81451287865639, 38.23208548128605, 19.558078721165657, 3.0312700057402253, 1.0012079193256795, 1.9177097151987255, 3.5138186998665333, 1.4761629584245384, 2.097647753544152, 2.553376299329102, 3.7990682059898973, 4.944916432723403, 5.4722977336496115, 4.540421487763524, 3.7998200906440616, 2.4100202042609453, 2.751925145275891, 1.7187928827479482, 2.585789510048926, 2.6835019793361425, 1.4290082012303174, 0.9093591885175556, 0.8012768381740898, 0.16209375055041164, 0.03414250386413187, 0.22155923856189474, 0.01975363524252316, 0.21481004368979484, 0.12054570383043028, 0.08721569582121447, 0.2624868572456762, 7.341338116675615, 34.339015781879425, 42.711923494935036, 44.96234133839607, 38.487329185009, 22.285999841988087, 22.391453683376312, 28.00702605396509, 25.743042938411236, 35.5107931047678, 47.45892897248268, 45.10130748152733, 68.62715229392052, 81.1198179423809, 91.18443667888641, 86.44583255052567, 76.69895276427269, 18.745636716485023, 0.3717754944227636, 0.07387855250271969, 0.06328510688035749, 0.1298063190188259, 0.024129768389684614, 0.10004595227655955, 0.033292470179731026, 0.12554205721244216, 0.08434857896645553, 0.1464574263081886, 0.1195521536283195, 0.408208622247912, 0.2135832587373443, 0.10853406594833359, 0.031091939235921018, 0.014259380550356582, 0.02390560825006105, 0.03856789706333075, 0.08416268581640907, 0.05917438058531843, 0.06926715112058446, 0.03582342753361445, 0.09204473200952634, 0.0953087123343721, 0.07696811328059994, 0.05850375739100855, 0.03382607064850163, 0.02602226351882564, 0.020000254626211245, 0.03986540497862734, 0.032124901190400124, 0.09691973682492971, 0.038167745879036374, 0.050682571018114686, 0.08176177128916606, 0.031223722398863174, 0.02008349576499313, 0.04465822807105724, 0.18593298853375018, 0.2255832077935338, 0.21403801714768633, 0.1536460913484916, 0.19573048077290878, 0.13234136189566925, 0.1474336176761426, 0.13210390432504937, 0.1587359033874236, 0.11661748649203219, 0.22224018874112517, 0.15169203135883436, 0.10484231912414543, 0.1393000056850724, 0.2203067604568787, 0.10830515049747191, 0.22153263998916373, 0.2711505407933146, 0.15549987234408036, 0.1310490453033708, 0.16194132826058194, 0.21478408336406574, 0.15588681329973042, 0.18854362657293677, 0.1818673254456371, 0.1910897422931157, 0.24563026410760358, 0.1844227476976812, 0.48911174351815134, 0.4007239144993946, 0.1542446928215213, 0.23558290558867157, 0.493435911484994, 31.255901120603085, 79.84413519501686, 83.59047576785088, 87.99080684781075, 72.7117583155632, 67.72213965654373, 59.959315806627274, 47.78675638139248, 31.881949827075005, 26.34886723011732, 28.600335717201233, 51.250338926911354, 84.934311658144, 60.657953917980194, 74.70371782779694, 89.07142326235771, 51.3927248865366, 10.784393213689327, 0.413834071950987, 0.30252584314439446, 0.4038020462030545, 0.1985374910873361, 0.26661771058570594, 0.5997944308910519, 0.5866587138734758, 0.5392401083372533, 1.329683312214911, 0.9935157664585859, 2.5702338572591543, 2.6454360969364643, 6.964970687404275, 12.624337133020163, 13.00664221867919, 13.833266012370586, 15.168252177536488, 19.05006118118763, 17.436453066766262, 18.902393504977226, 15.999641865491867, 24.664079435169697, 16.445483341813087, 24.772139936685562, 26.335999220609665, 9.337381459772587, 4.108404144644737, 1.5661498485133052, 4.658273113891482, 1.6932111117057502, 1.9028595183044672, 8.357093911617994, 8.104466367512941, 13.638054337352514, 21.794281527400017, 38.23900490999222, 51.9769511371851, 58.751903995871544, 58.79133827984333, 37.37012833356857, 23.940985836088657, 5.631800349801779, 4.8207262717187405, 10.040361788123846, 6.684845443814993, 9.036961980164051, 6.450334852561355, 9.978457409888506, 11.824685242027044, 18.066088780760765, 18.09714451432228, 12.733257338404655, 13.458359129726887, 6.721700141206384, 6.426471183076501, 2.62820259667933, 3.360278676263988, 3.256992381066084, 1.2210412044078112, 0.4096915520494804, 0.5120123724918813, 0.19192897772882134, 0.20007124316180125, 0.15944330370984972, 0.28174906270578504, 0.4296244215220213, 0.17343167419312522, 0.13683695113286376, 0.6109518196899444, 14.037740640342236, 52.28731848299503, 76.81287825107574, 79.94023963809013, 60.89579075574875, 65.81604033708572, 55.26204966008663, 41.41332797706127, 27.594571486115456, 36.5692301094532, 45.10023973882198, 49.34958212077618, 79.39621523022652, 94.25919368863106, 99.8442479968071, 98.62244635820389, 84.80300590395927, 20.928184501826763, 0.5345211771782488, 0.2973595750518143, 0.1952784979948774, 0.19563299225410447, 0.1555751558043994, 0.22697569947922602, 0.08810750499833375, 0.3170510980999097, 0.1994691090658307, 0.27122318220790476, 0.4301867913454771, 0.4873572470387444, 0.25397314690053463, 0.33234186354093254, 0.1841546394280158, 0.1408822348457761, 0.1245403804932721, 0.14947844232665375, 0.21565089700743556, 0.23712804220849648, 0.1895959919784218, 0.14500091696390882, 0.16929066827287897, 0.1999084753333591, 0.240686432516668, 0.0926114508183673, 0.14200933452229947, 0.2025035728001967, 0.12224502163007855, 0.18712771270656958, 0.2927084465045482, 0.18001084303250536, 0.1429076597560197, 0.18170711060520262, 0.17178575391881168, 0.09636021684855223, 0.19546448020264506, 0.13741192262386903], [0.09254708435037173, 0.10541795112658292, 0.05650943217915483, 0.06133831251645461, 0.05312691231665667, 0.04279173408576753, 0.04561090077913832, 0.046821161813568324, 0.05099029513075948, 0.09373486202093773, 0.11935968504985794, 0.07290655426913872, 0.012932100453326711, 0.06726480700308457, 0.007822854349797126, 0.09119423077208921, 0.03345104487380013, 0.029529488310799934, 0.09839569785981439, 0.0545066539052641, 0.11637838877504691, 0.014371194374689367, 0.0490893358073663, 0.10546485485974699, 0.04768715538375545, 0.3169492754386738, 0.12783676298568025, 0.30070850159972906, 0.37695375562179834, 0.17216729203937575, 0.24486224516294897, 0.6570618704427034, 16.653763465583324, 53.86170320212841, 56.3793721050024, 68.00741314888, 53.606611490249634, 64.59039330482483, 27.44025606662035, 24.571467004716396, 18.621727265417576, 16.84516679495573, 37.94143907725811, 27.77561467140913, 27.39903587847948, 82.02700406312943, 82.31194317340851, 53.701249212026596, 37.82480053603649, 5.246901903301477, 0.45929355605039746, 0.05919802169955801, 0.04223123447445687, 0.04983583989087492, 0.312526787747629, 0.17769430327462032, 0.241439534293022, 0.6549660454038531, 0.7989278517197818, 1.9587586750276387, 1.4695646124891937, 2.281905566342175, 1.4864047151058912, 5.617129812017083, 5.195721024647355, 4.880175981670618, 2.57551581133157, 8.113702721893787, 12.120460420846939, 8.190556447952986, 12.431069053709507, 8.31325851380825, 6.8063928466290236, 3.6516311299055815, 5.24580423720181, 3.718698243610561, 5.030524414032698, 10.13086723163724, 3.8471933361142874, 5.235368572175503, 16.943192034959793, 21.284238696098328, 28.102279342710972, 38.59132960438728, 61.54878191649914, 91.18700534105301, 83.59914690256119, 71.79723858833313, 69.87970188260078, 77.4159286916256, 80.24426132440567, 84.71846804022789, 37.68919341266155, 7.832064684480429, 6.8843271397054195, 5.702891210094094, 2.035182905383408, 2.824291787110269, 1.9391526770778, 1.0500303120352328, 3.7816421035677195, 7.381089208647609, 3.828987325541675, 3.2091610226780176, 1.590113618876785, 1.0349537897855043, 0.6053534138482064, 2.6016638707369566, 2.0481577841565013, 0.32720094721298665, 0.3733158070826903, 0.5941047705709934, 0.21808721940033138, 0.1504128210945055, 0.16372505051549524, 0.06826181561336853, 0.08745701998122968, 0.14356192230479792, 0.022470938456535805, 0.09566184104187414, 0.06014302431140095, 0.7778514514211565, 14.158720448613167, 36.07635475695133, 45.322193428874016, 48.18317010998726, 35.34361347556114, 17.625441625714302, 24.431547112762928, 18.042043671011925, 13.770105801522732, 23.144546672701836, 39.234676882624626, 56.47115238010883, 63.2736499607563, 64.90151301026344, 64.05066266655922, 62.21987530589104, 13.847050722688437, 0.2976723754545674, 0.322611327865161, 0.16797340067569166, 0.10117285899468698, 0.13469926896505058, 0.0974432923248969, 0.09139107060036622, 0.2170587659929879, 0.2349916662205942, 0.13089501997455955, 0.45293186616618186, 0.46500485739670694, 0.4045324382605031, 0.08370374169317074, 0.04945718501403462, 0.02435080965369707, 0.07468312222044915, 0.025785030447877944, 0.013681787422683556, 0.13458144559990615, 0.10089981544297189, 0.19599150895373896, 0.08145790634443983, 0.07541362560004927, 0.009108348749577999, 0.0851840665563941, 0.021090579029987566, 0.208162730850745, 0.1658301820862107, 0.10387038768385537, 0.04300316082662903, 0.05970127946056891, 0.00854368568980135, 0.018368941673543304, 0.012629158554773312, 0.055254222970688716, 0.014814611840847647, 0.05589525302639231, 0.030795653474342544, 0.057249294040957466, 0.04402003301947843, 0.029933433725091163, 0.0618778909847606, 0.11327716143568978, 0.046476100251311436, 0.04097426266525872, 0.024498103703081142, 0.05924646909988951, 0.01414458050930989, 0.034960985140060075, 0.06971494818571955, 0.07086091325618327, 0.07894179565482773, 0.08232005187892355, 0.04051240561238956, 0.06945137443835847, 0.09524223816697486, 0.06344123990857042, 0.0597065709735034, 0.11518854051246308, 0.010386188823758857, 0.024632248751004227, 0.22849713190225884, 0.10302574199158698, 0.2384670844185166, 0.2908153465250507, 0.22605211153859273, 0.25103798252530396, 0.6726775481365621, 20.11958409100771, 65.10173946619034, 68.67358580231667, 77.47297123074532, 64.00864452123642, 73.68338137865067, 41.73596106469631, 38.244602009654045, 30.825222730636597, 29.24929339438677, 33.91044057905674, 30.593425668776035, 33.709906339645386, 70.26708349585533, 69.0718500316143, 51.52264751493931, 38.45801755785942, 6.952172974124551, 0.22167191142216325, 0.06998872646363452, 0.014825899907009443, 0.10212988810962997, 0.5100897944066674, 0.37579689582344145, 0.9957246948033571, 1.5244410303421319, 2.1977619314566255, 2.677654568105936, 4.0744586661458015, 2.882018289528787, 4.570983722805977, 5.752533646300435, 6.847607810050249, 3.791474550962448, 4.3365078046917915, 5.280499700456858, 5.375242391601205, 3.4984117140993476, 4.111833935603499, 5.1997435837984085, 3.751917011104524, 0.5549925786908716, 3.7970951618626714, 3.016565744765103, 4.083933932706714, 7.9563189670443535, 4.032118013128638, 10.313702020794153, 22.09385745227337, 25.685426630079746, 30.424975007772446, 45.775030329823494, 71.92269265651703, 100.88491335511208, 96.83914884924889, 86.06554135680199, 85.21100521087646, 93.95780146121979, 93.86172741651535, 92.5749796628952, 41.17989510297775, 7.213792260736227, 4.639821778982878, 2.4861013842746615, 1.3956918264739215, 1.992774331010878, 1.123347021639347, 1.5202086511999369, 2.0018522813916206, 1.0779680754058063, 0.8235104545019567, 2.6706660306081176, 1.1640604119747877, 0.6564534280914813, 1.5897851740010083, 5.443196520209312, 2.439439413137734, 2.7888672379776835, 3.1245041778311133, 2.5658424803987145, 1.09981179703027, 0.0644339737482369, 0.3159694030182436, 0.053836635561310686, 0.1145640603499487, 0.13015791890211403, 0.027057834122388158, 0.035187013636459596, 0.023863604546932038, 0.8558629278559238, 14.748733788728714, 33.98911915719509, 44.125481843948364, 47.20351427793503, 34.23787280917168, 20.729164481163025, 26.97836995124817, 27.904562652111053, 25.615968257188797, 35.57377852499485, 54.92110155522823, 69.1348734498024, 72.37124338746071, 73.17977920174599, 75.98042652010918, 77.78401494026184, 22.19068955630064, 0.29064144648145884, 0.5027768493164331, 0.2214870127500035, 0.042096872348338366, 0.11087248421972618, 0.06361542938975617, 0.08636583283077925, 0.131470971100498, 0.11591336646233685, 0.15189057070529088, 0.28777265979442745, 0.39547909749671817, 0.5009063403122127, 0.07002028258284554, 0.03164130663208198, 0.06613859790377319, 0.08410969647229649, 0.004161530014243908, 0.07123157891328447, 0.022290563174465206, 0.09362233016872779, 0.14833305613137782, 0.1739249352249317, 0.1417503843549639, 0.07564997737063095, 0.058808490648516454, 0.1478733995463699, 0.06936303660040721, 0.08078647791990079, 0.01655228104937123, 0.040452889079460874, 0.04171776476141531, 0.036728446939378045, 0.07145411931560375, 0.030888241963111795, 0.07587924905237742, 0.011317067437630612, 0.17821750254370272, 0.21695442002965137, 0.18772288545733318, 0.16315641696564853, 0.19605132605647668, 0.17513810918899253, 0.24685075564775616, 0.14633510552812368, 0.11424599069869146, 0.25238106201868504, 0.35003442666493356, 0.14361777633894235, 0.09986503893742338, 0.23310309334192425, 0.17490985424956307, 0.21970860427245498, 0.14639909350080416, 0.16340974165359512, 0.17660876386798918, 0.13303335523232818, 0.2565030986443162, 0.16935473046032712, 0.3180027095368132, 0.13651984627358615, 0.24929791339673102, 0.4865454859100282, 0.45176805986557156, 0.6276836281176656, 0.5607672594487667, 0.5172213586047292, 0.4841710883192718, 1.4601053763180971, 30.163997411727905, 78.32703620195389, 75.4455292224884, 87.64054164290428, 72.46677786111832, 82.46689885854721, 41.50329954922199, 39.6627277135849, 31.52683798223734, 27.45990101248026, 55.00484146177769, 43.415619134902954, 41.17690846323967, 95.91642156243324, 96.28284350037575, 72.24024921655655, 54.156255796551704, 9.027722775936127, 0.9505102084949613, 0.24168034637114033, 0.13754921994404867, 0.29428369947709143, 0.8348510053474456, 0.3336575726279989, 0.7709455001167953, 1.4907979918643832, 2.77664661873132, 2.896203165873885, 3.8435609685257077, 5.939923441037536, 7.632564939558506, 16.84322889894247, 15.865269675850868, 18.02528467029333, 12.56947947666049, 15.741783902049065, 23.39321482926607, 19.905723966658115, 23.824886865913868, 18.55093516409397, 19.418899789452553, 9.67463806271553, 13.545578699558973, 10.613704472780228, 9.609919935464859, 19.930738024413586, 4.833964761346579, 13.294441625475883, 25.96604347229004, 27.9750469699502, 36.01744271814823, 49.6381576359272, 73.62315461039543, 94.11312192678452, 90.69395139813423, 83.68046253919601, 82.85708472132683, 90.49842908978462, 87.47173190116882, 88.83166372776031, 46.833216547966, 11.84652267023921, 14.210751056671143, 12.643254417926073, 8.478996120393276, 11.228584628552198, 9.796156492084265, 10.586950108408928, 12.540008258074522, 18.047676868736744, 13.332873713225126, 9.49352553114295, 5.122027304023504, 3.9658080087974668, 3.708400083705783, 9.080463945865631, 10.246648918837309, 5.440761325880885, 4.4998847879469395, 3.043613168410957, 0.9821905335411429, 0.21479309303686023, 0.3884022147394717, 0.17811268160585314, 0.17642934224568307, 0.18084807466948405, 0.16498034878168255, 0.16494527488248423, 0.19934476964408532, 1.5841764374636114, 21.122146993875504, 47.94443652033806, 63.35851840674877, 71.29025459289551, 53.57804462313652, 32.81934812664986, 39.28560175001621, 31.06213241815567, 25.32483547925949, 38.84515218436718, 57.08720192313194, 75.21604433655739, 86.33012115955353, 86.0487462580204, 87.64649212360382, 87.89322808384895, 23.443410135805607, 1.0500421863980591, 0.5344758764840662, 0.3656094940379262, 0.127568714087829, 0.2239930970245041, 0.14587354904506356, 0.18428608862450346, 0.45485114911571145, 0.35804516868665814, 0.47154988744296134, 0.7797252258751541, 0.6796459585893899, 0.7363817235454917, 0.36191953578963876, 0.22764910943806171, 0.21085044834762812, 0.1385101824416779, 0.12407490547047928, 0.18430875381454825, 0.18204069114290178, 0.18745088833384216, 0.39860846707597375, 0.3522399708162993, 0.15407019905978814, 0.15188218443654478, 0.20706105715362355, 0.15808680618647486, 0.34096695540938526, 0.21279088250594214, 0.25750962900929153, 0.26537170400843024, 0.19345640670508146, 0.28234646189957857, 0.10661035237717442, 0.1271583657944575, 0.18280440563103184, 0.11453310537035577], [0.05995996245474089, 0.09036335191922262, 0.02346067216421943, 0.02167934519093251, 0.09096446927287616, 0.06519766597193666, 0.01225376170623349, 0.06999762481427751, 0.07021924495347776, 0.0724697632540483, 0.06553577361046337, 0.027212683235120494, 0.1050926158495713, 0.03367154065927025, 0.10095858611748554, 0.04781653769896366, 0.049072867550421506, 0.02328752540051937, 0.010394789387646597, 0.0551220538909547, 0.0878030463354662, 0.05706672200176399, 0.05573530535912141, 0.046360699998331256, 0.13361496152356267, 0.24006086139706895, 0.06562292401213199, 0.2587179047986865, 0.09370405547088012, 0.14174698531860486, 0.550666629569605, 23.636291585862637, 62.0890749245882, 63.49653460085392, 66.56198590993881, 60.57267129421234, 48.35384555160999, 24.57934968173504, 23.594286739826202, 20.626431293785572, 22.43365801870823, 28.524636179208755, 28.907482735812664, 52.15760864317417, 50.38374602794647, 38.7927757948637, 32.35655575990677, 25.319023691117764, 6.833928069099784, 0.09345415950519964, 0.032807903407956474, 0.03949930352973752, 0.06276095766224898, 0.28109796170610934, 0.5169262806884944, 0.3974185965489596, 1.6968769649975002, 2.1871488634496927, 3.0279128858819604, 3.803661447018385, 3.3400701731443405, 2.2534892661496997, 3.6131448950618505, 4.900715304538608, 6.776734963059425, 3.7148167518898845, 2.5008419808000326, 5.120956711471081, 5.9011094737797976, 3.7666554702445865, 4.542908454313874, 6.2778345588594675, 5.275578014552593, 6.778076766058803, 14.234333541244268, 17.825897969305515, 19.510579369962215, 20.111716613173485, 17.416023463010788, 16.647700890898705, 25.125887654721737, 38.96415799856186, 44.51883293688297, 40.16273908317089, 63.78439575433731, 65.8166255056858, 47.10964411497116, 51.49145118892193, 50.641862377524376, 56.955451592803, 49.454524889588356, 51.24254174530506, 54.72808711230755, 31.04756209999323, 10.94363221898675, 12.186080049723387, 4.993513450026512, 6.489276112988591, 7.167841801419854, 6.801361441612244, 6.437102537602186, 2.1632664324715734, 2.255708109587431, 1.3580585271120071, 0.7859029225073755, 0.32576361496467143, 1.7423898540437222, 2.6200783951207995, 2.3765857983380556, 2.3405675310641527, 2.7490546368062496, 2.0317813754081726, 0.6426530436147004, 0.3961427853209898, 1.4941966719925404, 0.2098422555718571, 0.16581606643740088, 0.050042843431583606, 0.051256403312436305, 0.06586329080164433, 0.07075507557601668, 0.007785207981214626, 0.04729307125671767, 3.2953392108902335, 24.353096522390842, 41.13244704902172, 45.037341713905334, 35.791309252381325, 36.397137343883514, 32.02715523540974, 26.600130647420883, 19.71527438610792, 27.444734126329422, 34.6108303964138, 33.13063122332096, 52.910599038004875, 64.45065960288048, 71.70315563678741, 68.18319171667099, 25.978508703410625, 0.6895145040471107, 0.1918897923314944, 0.0757535663433373, 0.09124460033490323, 0.1685959883616306, 0.017045167296600994, 0.13103852164931595, 0.15232781443046406, 0.1992672894266434, 0.269319157814607, 0.42532643652521074, 0.2389622453483753, 0.13808886520564556, 0.12994259217521176, 0.04760892188642174, 0.048920719855232164, 0.015338312987296376, 0.08812180618406273, 0.047178071763482876, 0.07662389776669443, 0.03637089132098481, 0.08804367287666537, 0.11520555053721182, 0.020170644311292563, 0.03731768993020523, 0.02427142211672617, 0.03127909774775617, 0.05903238175960723, 0.02769485472526867, 0.06508618054795079, 0.035353859566384926, 0.006901207589180558, 0.04290059601771645, 0.02932182982476661, 0.0727499536878895, 0.03433046760619618, 0.021255872015899513, 0.0697181691066362, 0.03093922379775904, 0.02557630697992863, 0.033469813788542524, 0.04175657166342717, 0.058286196799599566, 0.06879612483317032, 0.08084303699433804, 0.03711019286129158, 0.05390715814428404, 0.04411618567246478, 0.11487617797683924, 0.07410220612655394, 0.02190776154748164, 0.04182113851129543, 0.04272779435268603, 0.02663196009962121, 0.058464356770855375, 0.03385193820577115, 0.08859407927957363, 0.08315406259498559, 0.06982374703511596, 0.04035834317619447, 0.04486175464990083, 0.2138679614290595, 0.26852096314541996, 0.1944867748534307, 0.07419371293508448, 0.24389663682086393, 0.7054452679585665, 25.954017117619514, 70.02559885382652, 76.59688264131546, 72.43848457932472, 69.30698901414871, 57.954368591308594, 42.54073888063431, 29.547697082161903, 29.24618326127529, 27.447686567902565, 19.056988209486008, 33.912606462836266, 37.72098250687122, 42.31524758040905, 46.35761506855488, 40.73301628232002, 28.5948621109128, 9.12852281704545, 0.03448775096330792, 0.07593135524075478, 0.15787896030815318, 0.15028071880806237, 0.9574172284919769, 1.1962243798188865, 1.800607955083251, 2.885131509974599, 3.629544102586806, 7.6155689265578985, 8.192893322557211, 6.441613845527172, 3.2595876418054104, 4.475964121520519, 4.393266784027219, 4.056854210793972, 2.671238137409091, 1.6500165732577443, 1.6214233450591564, 2.652529841288924, 3.3170837815850973, 4.371201368048787, 5.074085276573896, 6.57264506444335, 8.594946898519993, 12.13953634724021, 15.318344123661518, 17.31731615960598, 20.605597011744976, 18.53159610182047, 18.085272051393986, 28.207527995109558, 43.967300131917, 53.25116716325283, 50.422568544745445, 73.18566888570786, 78.10878351330757, 57.06165969371796, 56.49358257651329, 58.24034124612808, 63.996781557798386, 59.02525372803211, 65.10275021195412, 64.42979872226715, 34.26709324121475, 13.787309378385544, 12.44316190481186, 6.593320230022073, 7.846379466354847, 8.311730995774269, 7.493193168193102, 7.080173380672932, 4.641799572855234, 2.1330803772434592, 0.5077041161712259, 0.7484350330196321, 1.3367964117787778, 1.0651219147257507, 3.9619215298444033, 3.381071873009205, 3.297264757566154, 3.673409898765385, 3.9410333381965756, 2.03724168241024, 2.317225858569145, 1.637939871288836, 0.800556717440486, 0.19753820408368483, 0.28428417979739606, 0.04459857795154676, 0.06147181004052982, 0.08903521185857244, 0.03835508250631392, 0.010290605769114336, 3.295873557217419, 21.608045920729637, 41.501346454024315, 44.696503803133965, 27.203619964420795, 26.491868756711483, 24.78376541286707, 20.013446286320686, 15.567344762384892, 33.165612146258354, 47.992830723524094, 43.74771751463413, 61.26793138682842, 73.15125793218613, 81.53883665800095, 84.92328464984894, 39.292874559760094, 0.8027352474164218, 0.3631435747956857, 0.03638083981059026, 0.20326912781456485, 0.029636891922564246, 0.0316170012956718, 0.024588246815255843, 0.08925908812670968, 0.13768288074061275, 0.21875065489439294, 0.2535858645569533, 0.11286926965112798, 0.12848462822148576, 0.09022900092531927, 0.08232533597038127, 0.07001421181485057, 0.029178695513110142, 0.057660963357193395, 0.03374705418536905, 0.02179216462536715, 0.054806437037768774, 0.08356080405064858, 0.03800415797741152, 0.02151927321392577, 0.03838980017462745, 0.014257823895604815, 0.10400294268038124, 0.03121546600596048, 0.023225160875881556, 0.11046878556953743, 0.03903834818629548, 0.032826735405251384, 0.07834303090930916, 0.046214567410061136, 0.019913926153094508, 0.09706226628622971, 0.1300306702614762, 0.22076715918956324, 0.1342771205236204, 0.16954115795670077, 0.2801392553374171, 0.15991738764569163, 0.12119845239794813, 0.21056883299024776, 0.21840724832145497, 0.14840246178209782, 0.19133606110699475, 0.15664266102248803, 0.16304509481415153, 0.16114678495796397, 0.16745113651268184, 0.15693278139224276, 0.10375185185694136, 0.13426785852061585, 0.15107324346899986, 0.13127516285749152, 0.215128751588054, 0.2121066371910274, 0.28701780654955655, 0.20919824950397015, 0.535053979838267, 0.49725746735930443, 0.5370298738125712, 0.5535103019792587, 0.20622593321604654, 0.43524684326257557, 1.2381832720711827, 35.46983890235424, 85.946706533432, 84.79799017310143, 86.6554445028305, 79.4184136390686, 65.59189036488533, 39.79029826819897, 36.31398640573025, 32.896711975336075, 34.80142056941986, 41.38029254972935, 42.75249771773815, 71.37526363134384, 70.06960809230804, 57.06746578216553, 49.145198687911034, 39.88573394715786, 12.359368801116943, 0.26127962046302855, 0.24245651409728453, 0.3936993679963052, 0.3624842211138457, 0.758999950485304, 1.4506024424917996, 1.6760577633976936, 4.101267177611589, 6.6570185869932175, 8.251437731087208, 10.405100416392088, 10.279229320585728, 5.913127278909087, 11.230850256979465, 13.191093821078539, 17.737108133733273, 12.687142062932253, 9.899945072829723, 16.049563586711884, 15.68841291591525, 13.869812451303005, 11.7318856716156, 12.477033287286758, 10.061236917972565, 12.188367526978254, 19.850286841392517, 22.104257494211197, 29.126776568591595, 28.186720311641693, 21.024161651730537, 20.428152233362198, 32.58520469069481, 54.718583822250366, 61.43933638930321, 61.30437143146992, 76.4398142695427, 83.28511655330658, 63.36103767156601, 61.1225625872612, 63.992913365364075, 68.97928699851036, 62.59250231087208, 62.98153303563595, 67.84640058875084, 39.772348031401634, 16.872654519975185, 17.563805133104324, 7.765072854235768, 9.317824859172106, 10.860766265541315, 12.608914710581303, 11.706070806831121, 7.588922856375575, 8.122955225408077, 5.951267257332802, 4.521823385730386, 4.315522005781531, 7.846723822876811, 9.478506837040186, 7.500309711322188, 9.595929086208344, 10.413569211959839, 6.56934779137373, 5.409544100984931, 2.9563859989866614, 3.351919362321496, 0.6123756151646376, 0.2333907943102531, 0.27674137672875077, 0.13915770628955215, 0.25199829193297774, 0.17042259190930054, 0.13727610959904268, 0.21853519458090886, 5.83827082067728, 34.51074376702309, 58.66496466100216, 59.39681299030781, 51.70890212059021, 51.198399513959885, 47.49458245933056, 41.7222286015749, 32.824595645070076, 41.92219287157059, 51.14553675055504, 51.88778132200241, 73.21778476238251, 82.69427865743637, 93.67074206471443, 96.72943353652954, 42.37210012972355, 1.210949420928955, 0.6714902899693698, 0.2467164714471437, 0.5872931017074734, 0.2981964504579082, 0.16747700778068975, 0.24984609335660934, 0.39257415337488055, 0.3726915718289092, 0.5017835588660091, 0.9413196297828108, 0.5268791934940964, 0.3979263443034142, 0.25705430656671524, 0.19439166120719165, 0.184873350081034, 0.10841826122486964, 0.1663878615363501, 0.1615291988127865, 0.17110429907916114, 0.26665754907298833, 0.3434198722243309, 0.34714278182946146, 0.23269238881766796, 0.08491684886394069, 0.14109174313489348, 0.27488526538945735, 0.27294074941892177, 0.15982582146534696, 0.2572968404274434, 0.11541386396856979, 0.1554619485978037, 0.14057158667128533, 0.12790909269824624, 0.16985229594865814, 0.1860557694453746], [0.057459217932773754, 0.027185272010683548, 0.0402628361916868, 0.03582421049941331, 0.034511585035943426, 0.037031966785434633, 0.025595944207452703, 0.0452565067098476, 0.02814696366840508, 0.0258802962343907, 0.04681418191466946, 0.032919106815825216, 0.06461693541496061, 0.011835487275675405, 0.027728149325412232, 0.022612649700022303, 0.050779506636899896, 0.022822052233095746, 0.10099838007590733, 0.030424898759520147, 0.028285231346671935, 0.06194448389578611, 0.06479595627752133, 0.031815941401873715, 0.010758851785794832, 0.1876980680390261, 0.07670301813050173, 0.27212144806981087, 0.06070916053431574, 0.16196886193938553, 10.502009466290474, 53.57090100646019, 64.02733951807022, 61.25254601240158, 49.38117362558842, 32.023484632372856, 30.120094567537308, 23.29532068222761, 50.46531245112419, 42.60669954121113, 25.757132582366467, 59.458852261304855, 48.4529822319746, 54.76773038506508, 46.259519532322884, 31.52985692024231, 12.221755385398865, 3.9057952165603638, 0.16655334562528878, 0.0327995987754548, 0.15761232149088755, 0.19283462053863332, 0.05908079576329328, 0.9781705273780972, 1.6265598381869495, 1.5511528844945133, 2.081794054247439, 2.3277707677334547, 4.5532225258648396, 8.95106378942728, 7.17859759926796, 1.7083988967351615, 3.2443685084581375, 3.636395134963095, 3.939322242513299, 1.9697009003721178, 3.270641486160457, 6.759511912241578, 16.618423461914062, 24.212433770298958, 33.78009997308254, 31.957474574446678, 34.980569556355476, 31.753511019051075, 38.41302417218685, 37.717159911990166, 38.32675360143185, 45.60637637972832, 40.86705029010773, 43.40029835700989, 44.76698622107506, 47.13207431137562, 49.301499500870705, 46.44816800951958, 43.56401637196541, 45.093913078308105, 43.86110723018646, 50.287200808525085, 48.872586116194725, 57.48772323131561, 47.08635896444321, 40.808077454566956, 35.918119847774506, 43.11920464038849, 34.021801203489304, 34.24937479197979, 31.27581015229225, 33.626983389258385, 30.909285619854927, 27.831372879445553, 26.09180722385645, 30.510426722466946, 17.075491435825825, 5.471260389313102, 1.0208266228437424, 0.012264220422366634, 0.3121203579939902, 3.201749282889068, 1.2090261303819716, 1.3551238970831037, 2.555857803672552, 2.462276662699878, 1.6939283232204616, 1.0977790248580277, 0.7283605914562941, 0.517706663813442, 0.45337840158026665, 0.6526723341085017, 0.09442315946216695, 0.05289855718729086, 0.13716809742618352, 0.10921994398813695, 0.02166067461075727, 0.020498656886047684, 0.9364389104302973, 11.834013741463423, 37.08373390138149, 59.011312276124954, 51.8870859593153, 48.18412005901337, 46.91401161253452, 75.37348508834839, 109.3570451438427, 61.14746265113354, 34.245400205254555, 48.658137023448944, 50.618596225976944, 61.119727939367294, 65.12201517820358, 77.61389046907425, 23.06534182280302, 0.47290362417697906, 0.10274210057104938, 0.06548573801410384, 0.08884239447070286, 0.17210517427884042, 0.11861528124427423, 0.11275845958152786, 0.10635589962475933, 0.13898386561777443, 0.29689101269468665, 0.1800649010692723, 0.06473580520832911, 0.030315855001390446, 0.05202262997045182, 0.12577583373058587, 0.11256199082708918, 0.04404745537613053, 0.026953352717100643, 0.022894975663803052, 0.01627380868740147, 0.08279082583612762, 0.12004183750832453, 0.07273443537997082, 0.048243042547255754, 0.05115055450005457, 0.043730250326916575, 0.04808333978871815, 0.1376106549287215, 0.029643027628480922, 0.06586414427147247, 0.011220417545700911, 0.016527532279724255, 0.019618055994214956, 0.022806131310062483, 0.03206999339454342, 0.059816946886712685, 0.07940696639707312, 0.02956416330562206, 0.03685284944367595, 0.04824178460694384, 0.05660273498506285, 0.07455917613697238, 0.04269777447916567, 0.027278782617941033, 0.035202160870539956, 0.036505082753137685, 0.020070374594070017, 0.07790998773998581, 0.030783513793721795, 0.02712028584937798, 0.06509975442895666, 0.0780591594229918, 0.03500451952277217, 0.06638829348958097, 0.038204274387680925, 0.018384202085144352, 0.015206353564281017, 0.08007630938664079, 0.03512750452500768, 0.019489961305225734, 0.12560749979456887, 0.08579689500038512, 0.2667355933226645, 0.0926076213363558, 0.04306443253881298, 13.301512096077204, 64.97828409075737, 73.67643535137177, 70.66514253616333, 59.97772961854935, 46.335393860936165, 40.400344133377075, 24.161968678236008, 50.50035037100315, 44.87041287124157, 22.655864395201206, 44.04532894492149, 40.64138799905777, 54.33767706155777, 50.096823424100876, 33.385464549064636, 12.025304976850748, 3.8837751606479287, 0.17941078695002943, 0.065096978796646, 0.1449170839623548, 0.3891651128651574, 0.3507166088093072, 2.5473643094301224, 2.8853742219507694, 2.8537014964967966, 2.8986894199624658, 3.7514831218868494, 5.609690761193633, 7.122151628136635, 3.901273221708834, 2.581266090273857, 2.825731197372079, 3.334358367137611, 3.1176673946902156, 1.5685643814504147, 2.231604577973485, 8.151582889258862, 15.999128893017769, 25.112550370395184, 31.959059089422226, 33.864858224987984, 37.549026533961296, 35.79309895634651, 38.675297498703, 38.41505706310272, 38.60733814537525, 46.064331606030464, 42.78282769024372, 46.58108487725258, 47.74237856268883, 51.86171472072601, 55.262893214821815, 50.57960271835327, 52.916773706674576, 51.56035289168358, 49.54776428639889, 57.882191464304924, 56.29857324063778, 66.7327943444252, 55.11709503829479, 49.81097236275673, 45.16711615025997, 49.882666915655136, 39.62931610643864, 35.65412521362305, 34.04806539416313, 35.80622725188732, 33.52997079491615, 31.06237180531025, 28.31860553473234, 32.296252995729446, 19.45913963019848, 5.600905632600188, 1.7640286241658032, 0.1093210987164639, 0.10649623975041322, 1.1783091723918915, 1.3912632828578353, 0.24794117838609964, 1.3782557495869696, 3.762857336550951, 1.863833237439394, 1.9153090752661228, 1.3540810905396938, 0.7295002334285527, 1.0429872712120414, 0.8738415443804115, 0.846744307782501, 0.3329216886777431, 0.05119014807860367, 0.06760198695701547, 0.11170475831022486, 0.08283276460133493, 0.7187475229147822, 12.100911419838667, 35.68524554371834, 50.66993147134781, 40.173169523477554, 31.050396747887135, 28.5258749127388, 58.41053031384945, 89.1441361606121, 57.282595038414, 42.079519629478455, 57.766548469662666, 59.85271252691746, 69.17250663042068, 75.36631867289543, 90.77082127332687, 37.12327837944031, 0.5192968191113323, 0.10138663463294506, 0.1275924182846211, 0.10425378117361106, 0.10766243576654233, 0.08035384293179959, 0.055098461016314104, 0.08278597961179912, 0.07691712773521431, 0.22070113773224875, 0.1052590276231058, 0.04644340122467838, 0.02434274250845192, 0.045063043653499335, 0.08987917477497831, 0.07229941809782758, 0.09383533397340216, 0.030835864890832454, 0.01824292128731031, 0.019614374941738788, 0.031265104553312995, 0.03628918086178601, 0.049287782385363244, 0.10682481079129502, 0.016889049111341592, 0.054594171670032665, 0.0028660117504841764, 0.04353449032350909, 0.016544638783670962, 0.07275019117514603, 0.07309437700314447, 0.050214209040859714, 0.033565420962986536, 0.014243989335227525, 0.012242671236890601, 0.18347337754676118, 0.15397748997202143, 0.15824062371393666, 0.1198211005248595, 0.07912860906799324, 0.1750919921323657, 0.1361201552208513, 0.11669782397802919, 0.11979845759924501, 0.12909204640891403, 0.18892376945586875, 0.1327659742673859, 0.1680278149433434, 0.2282075458788313, 0.17149373365100473, 0.19176255853381008, 0.26037393312435597, 0.22097798850154504, 0.22455926664406434, 0.19911029550712556, 0.15952948189806193, 0.1176360173849389, 0.24951847968623042, 0.11976754714851268, 0.20059957809280604, 0.4365463141584769, 0.28856681718025357, 0.5811674147844315, 0.33874223416205496, 0.35442604101262987, 20.49686584621668, 77.08967059850693, 80.75061455368996, 81.60866171121597, 69.37821999192238, 52.095766961574554, 46.83289736509323, 36.019118428230286, 63.10682751238346, 51.77824079990387, 39.12278428673744, 81.79856032133102, 66.57014027237892, 74.2357425391674, 63.39829467236996, 46.65663622319698, 19.092675894498825, 6.391556281596422, 0.6488418427761644, 0.20812373841181397, 0.46494248730596155, 0.72410250431858, 0.6740677985362709, 3.328781691379845, 3.6994489515200257, 5.097773680463433, 5.49332675524056, 7.2021539602428675, 10.773576144129038, 19.78075437247753, 15.732448752969503, 7.2049482353031635, 10.826355312019587, 9.446740541607141, 10.481224581599236, 5.869645262137055, 8.290369492024183, 11.59856317564845, 23.22775460779667, 30.126616917550564, 37.28923827409744, 35.22694833576679, 39.839433431625366, 35.25401808321476, 42.2206212580204, 41.66107468307018, 40.336226373910904, 53.037683218717575, 46.816736832261086, 51.20335444808006, 52.121518179774284, 56.299306601285934, 66.3682647049427, 57.550761848688126, 59.31449420750141, 59.17920246720314, 58.443626537919044, 63.79843220114708, 62.2134992480278, 73.7017647922039, 63.51818963885307, 57.093935161828995, 52.26952023804188, 57.66243025660515, 44.60554048418999, 39.459860399365425, 37.896354496479034, 41.13583266735077, 38.13143648207188, 32.82474383711815, 30.836367532610893, 34.363000094890594, 21.051613278687, 8.304020259529352, 3.501797094941139, 1.7574352654628456, 3.58175715431571, 11.873122192919254, 7.9154706839472055, 6.408560844138265, 9.513262622058392, 8.297169227153063, 5.649061873555183, 4.695220906287432, 2.9458854999393225, 1.9290730054490268, 1.4349000225774944, 1.3319465657696128, 0.8158801670651883, 0.20959721325198188, 0.198370240686927, 0.20727176772197708, 0.217518511635717, 0.18056620698189363, 1.5922936331480742, 17.838196009397507, 52.78568834066391, 76.52186706662178, 69.66497540473938, 67.41504773497581, 62.73297317326069, 89.74289283156395, 114.02592301368713, 69.45646539330482, 47.33149901032448, 64.99330848455429, 68.53530362248421, 81.47712796926498, 83.18575948476791, 100.10145619511604, 41.043809205293655, 1.3630240294151008, 0.44985512970015407, 0.42255522741470486, 0.2810060541378334, 0.3451312053948641, 0.30874697025865316, 0.20525619853287935, 0.34753234998788685, 0.378939772490412, 0.3734714206075296, 0.3184368659276515, 0.14416657970286906, 0.1402342805522494, 0.2563541941344738, 0.26218501094263047, 0.3238477458944544, 0.20774338772753254, 0.11726238313713111, 0.16393249563407153, 0.18214914860436693, 0.1304623924079351, 0.2928038570098579, 0.13241888664197177, 0.2859947708202526, 0.10015396444941871, 0.1200911977502983, 0.12102568784030154, 0.17014208977343515, 0.19824400136712939, 0.1887174672447145, 0.10218310751952231, 0.10804125762660988, 0.11689376580761746, 0.12080812724889256, 0.13016174838412553], [0.02318862494576024, 0.07476950821001083, 0.03434962243773043, 0.008310459288622951, 0.008054881254793145, 0.044729307264788076, 0.004074238140674424, 0.03899951159837656, 0.11614764021942392, 0.05153264180989936, 0.06683412386337295, 0.10045273083960637, 0.02250227378681302, 0.08091881769360043, 0.007758191022730898, 0.023937023361213505, 0.0719353649765253, 0.02735609214141732, 0.060568928020074964, 0.0472758460091427, 0.03220345752197318, 0.016303559532389045, 0.026726431788119953, 0.07168318319600075, 0.03126544594124425, 0.06497927417512983, 0.1984653394902125, 0.052739129023393616, 0.12321625545155257, 6.278496198356152, 43.43901447951794, 67.19884693622589, 76.77532866597176, 61.523327082395554, 37.51639388501644, 44.21207919716835, 49.2127438634634, 30.374319925904274, 23.66718202829361, 35.412268191576004, 55.55412098765373, 39.15252909064293, 50.046058148145676, 29.598625749349594, 15.930652767419815, 2.9404821898788214, 0.38090536545496434, 0.005902143693674589, 0.046989855691208504, 0.04567532661894802, 0.1292032201308757, 0.21326064714230597, 0.3785312647232786, 1.742692650295794, 1.30989421159029, 2.8674636455252767, 3.5350099252536893, 2.2973016276955605, 10.551496110856533, 9.237600713968277, 5.093162627890706, 5.173545889556408, 5.095414482057095, 6.063473811373115, 9.360943045467138, 16.234581358730793, 29.35758948326111, 47.867008075118065, 59.45582002401352, 61.23757861554623, 62.38651156425476, 64.63941067457199, 61.67112395167351, 67.59984701871872, 62.3349217325449, 60.303516536951065, 63.12161631882191, 63.17000292241573, 59.46658864617348, 60.98082259297371, 65.07712438702583, 68.78115803003311, 62.028285786509514, 62.17331260442734, 30.11191550642252, 38.25303375720978, 47.648082822561264, 43.36481586098671, 45.9116367995739, 55.00457547605038, 47.50635802745819, 32.828539833426476, 34.25225503742695, 42.977943420410156, 55.57517185807228, 56.63518577814102, 55.294389724731445, 55.14080956578255, 50.436760783195496, 52.506065145134926, 56.29245176911354, 48.43280531466007, 52.565448358654976, 39.21179451048374, 27.28282291442156, 16.833759807050228, 7.284945342689753, 1.922067606355995, 2.380410530604422, 0.9654533816501498, 1.9603752507828176, 3.541360809467733, 1.3896108465269208, 2.054994567297399, 1.8803926301188767, 1.359567758627236, 0.5327959510032088, 0.22575232840608805, 0.47379348892718554, 0.26939200703054667, 0.114795847912319, 0.09847895198618062, 0.021170296822674572, 0.06689138797810301, 0.1360561969340779, 0.0559013423480792, 5.317676905542612, 20.697960555553436, 45.46509616076946, 57.3722892254591, 57.80875280499458, 81.18271216750145, 98.13363298773766, 99.87607508897781, 40.75522989034653, 23.60640998929739, 47.96334810554981, 46.219465881586075, 66.5656641125679, 71.51244387030602, 78.27889278531075, 17.25922677665949, 0.3545979817863554, 0.202626294340007, 0.024200394873332698, 0.0807875614555087, 0.16408701078034937, 0.09602688121958636, 0.02074004412861541, 0.039721276189084165, 0.02572108329331968, 0.028085723497497384, 0.06299793283687904, 0.05798694059194531, 0.007971908216859447, 0.02075615615467541, 0.08119209873257205, 0.09246359273674898, 0.04327782597101759, 0.0724276463733986, 0.06287620577495545, 0.04006466049759183, 0.09457023086724803, 0.03489202477794606, 0.12321260408498347, 0.05274120703688823, 0.03144793263345491, 0.011648264753603144, 0.12184081831946969, 0.02951205155113712, 0.025464183308940846, 0.040808763733366504, 0.025994544303102884, 0.0282991818676237, 0.04820574220502749, 0.0902252308151219, 0.02499986789189279, 0.013111020198266488, 0.00539372893399559, 0.038485900877276435, 0.014684235975437332, 0.020063231422682293, 0.053370900786831044, 0.014918346460035536, 0.12668494979152456, 0.012519456140580587, 0.09647716447943822, 0.037206286142463796, 0.057581965447752737, 0.04066208566655405, 0.04950888302118983, 0.05243164981948212, 0.07227702008094639, 0.03738233099284116, 0.02956852527859155, 0.05557959164434578, 0.09063161603990011, 0.08077376493019983, 0.0460412388201803, 0.06946669978788123, 0.05314115413057152, 0.09777006736840121, 0.15621123573509976, 0.01508804873083136, 0.09096292560570873, 7.750796545296907, 51.06577143073082, 77.67939895391464, 84.3619255721569, 68.23676124215126, 48.46617892384529, 48.62157538533211, 50.85021659731865, 37.41384878754616, 35.22179201245308, 33.54426182806492, 45.40324307978153, 44.62961979210377, 50.41613169014454, 35.31084023416042, 17.306007966399193, 2.5947696156799793, 0.25828585610724986, 0.04398859935463406, 0.02276836155942874, 0.11393592882086523, 0.5259797698818147, 1.0562812141142786, 2.083649542182684, 1.9662684970535338, 2.5665573170408607, 4.1679213009774685, 3.4998727357015014, 2.5095271272584796, 3.959887926466763, 4.356497107073665, 5.336406100541353, 4.596981452777982, 4.479470383375883, 5.5054880026727915, 8.639383614063263, 16.74436390399933, 30.95145955681801, 47.8774157166481, 61.04582190513611, 62.79160402715206, 64.57941189408302, 67.60516673326492, 65.77266946434975, 66.39035671949387, 64.65083286166191, 61.47510387003422, 62.83771835267544, 64.89425539970398, 61.633699759840965, 59.76173400878906, 65.70169687271118, 71.9335600733757, 65.92688798904419, 60.36478064954281, 38.3701054751873, 45.985242649912834, 52.4803177267313, 49.0553031116724, 51.30760185420513, 59.72869098186493, 53.182622641325, 39.719413071870804, 39.52013276517391, 46.20570681989193, 58.70488531887531, 59.123201072216034, 60.45656852424145, 62.76915483176708, 54.81663756072521, 54.72789332270622, 57.75837890803814, 52.77863971889019, 56.72775261104107, 42.264820486307144, 31.545616574585438, 17.804022543132305, 7.63794070109725, 2.105513568967581, 0.47185663192067295, 1.2119114818051457, 0.38898747239727527, 2.256820499897003, 1.537520403508097, 1.7472971719689667, 1.3813891564495862, 2.3236261401325464, 1.5902464929968119, 1.226916757877916, 0.8671954635065049, 0.672745528863743, 0.4553447663784027, 0.23118858982343227, 0.22473233548225835, 0.04154397603997495, 0.31024192285258323, 0.016211286456382368, 4.130464335903525, 21.84878010302782, 43.20685833692551, 52.33406737446785, 56.125667318701744, 87.88096994161606, 99.28226575255394, 101.13183170557022, 52.04885467886925, 40.19225589931011, 62.57009491324425, 56.63320228457451, 73.20149883627892, 78.8554510474205, 91.85639262199402, 28.107690252363682, 0.3050731017719954, 0.19750679639400914, 0.02111069865350146, 0.030977967617218383, 0.1354463741881773, 0.08538894384400919, 0.11855906355776824, 0.014694298570248066, 0.03291149980213959, 0.03154758822347503, 0.06968742192839272, 0.014073829715925967, 0.007554806843472761, 0.046742312333662994, 0.05084398442704696, 0.042222106058034115, 0.04459461859369185, 0.024077012822090182, 0.015906295302556828, 0.09197390143526718, 0.018193228934251238, 0.03216468401660677, 0.07647718259249814, 0.0329569340829039, 0.018406833878543694, 0.03960362351790536, 0.005932011890763533, 0.019088288718194235, 0.013597745692095486, 0.0657390478590969, 0.04839858185732737, 0.05522802515770309, 0.10516430731513537, 0.018142798144253902, 0.14576561108697206, 0.12729878013487905, 0.13237921142717823, 0.09062344499398023, 0.08293342951219529, 0.21255526546156034, 0.14279583294410259, 0.16954669437836856, 0.2337616158183664, 0.11515552978380583, 0.1880785819957964, 0.2227767021395266, 0.19316174439154565, 0.15375753224361688, 0.23898486600955948, 0.15608251764206216, 0.21291694371029735, 0.13891616690671071, 0.11040996294468641, 0.1360268227290362, 0.14618370740208775, 0.2046284603420645, 0.22819442470790818, 0.22524612431880087, 0.11298804296529852, 0.15513256861595437, 0.3928964235819876, 0.2719422342488542, 0.24838701618136838, 11.997326128184795, 66.86770990490913, 87.5972543656826, 96.60049885511398, 80.28635546565056, 54.42064180970192, 58.301947340369225, 61.984082758426666, 43.096846640110016, 32.236379608511925, 49.207842126488686, 72.09105402231216, 53.79732705652714, 68.95913287997246, 43.22645768523216, 24.986497834324837, 5.888863205909729, 1.1524313734844327, 0.1600911095738411, 0.2505002816906199, 0.1852569662150927, 0.6152106786612421, 0.6517616892233491, 2.4840682558715343, 3.8698023604229093, 3.829804756678641, 7.482687206938863, 8.127402886748314, 7.448565512895584, 21.9504227489233, 17.839001566171646, 11.929879747331142, 10.657765958458185, 9.096993058919907, 10.01364542171359, 12.819416765123606, 20.265232175588608, 35.07155567407608, 53.8545785844326, 64.68310832977295, 65.44467866420746, 66.66373685002327, 68.30357685685158, 66.50583252310753, 67.91911348700523, 64.6827283501625, 63.89613255858421, 63.98961514234543, 65.09312152862549, 65.2275887131691, 64.10316824913025, 67.23654091358185, 72.64285281300545, 71.74934595823288, 63.88981729745865, 44.157973900437355, 50.53585946559906, 59.64549444615841, 55.403732657432556, 56.66675068438053, 68.06046590209007, 60.91560289263725, 46.93772993981838, 43.55169363319874, 53.352538123726845, 69.22982275485992, 64.63597565889359, 65.64890250563622, 65.12377068400383, 55.1716373115778, 55.624200627207756, 60.44738061726093, 55.258998423814774, 59.79426026344299, 44.76678483188152, 33.21258142590523, 20.297811627388, 9.49195621535182, 5.298546832054853, 9.073137938976288, 6.06813901104033, 8.795255050063133, 11.635068766772747, 4.876729566603899, 6.281318971887231, 5.440551387146115, 6.798005746677518, 4.494650568813086, 2.666894495487213, 2.030917634256184, 0.5603546253405511, 0.29076321807224303, 0.23858320084400475, 0.2324669243535027, 0.1504116485011764, 0.5170335655566305, 0.21007919363910332, 7.722405418753624, 32.390278950333595, 62.01131969690323, 76.58967822790146, 72.23638102412224, 88.29105153679848, 98.81270974874496, 99.16539162397385, 52.79773369431496, 39.145039692521095, 64.76888492703438, 67.14999675750732, 86.36181905865669, 86.66464000940323, 101.19447514414787, 31.831199750304222, 1.1321847536601126, 0.22890975116752088, 0.16426178655819967, 0.17665404971921816, 0.3014138981234282, 0.27425503358244896, 0.22815443779109046, 0.16535071015823632, 0.09835654956987128, 0.10794423666084185, 0.1932332428987138, 0.07142763206502423, 0.12335733772488311, 0.09876416675979272, 0.14378499705344439, 0.20053000916959718, 0.13828949740855023, 0.23566703544929624, 0.1466873733443208, 0.15553926554275677, 0.18280588992638513, 0.1637547364225611, 0.2637252048589289, 0.20890805491944775, 0.09302496066084132, 0.11555733595741913, 0.2050608504214324, 0.15460457507288083, 0.14949422038625926, 0.1831020662211813, 0.11840016231872141, 0.1475988791207783, 0.22956716042244807, 0.18650571873877198], [0.12685295718256384, 0.017493431914772373, 0.09132461869739927, 0.06293275000643916, 0.03773565636947751, 0.04300462285755202, 0.03591920540202409, 0.04062087420606986, 0.06572297294042073, 0.15764957730425522, 0.07298563010408543, 0.03811226662946865, 0.010470712950336747, 0.052458649151958525, 0.08049889569520019, 0.039764035027474165, 0.049618791381362826, 0.057529128243913874, 0.045426169090205804, 0.045675549263251014, 0.07612355664605275, 0.07760116524877958, 0.041736188577488065, 0.08563611612771638, 0.05846532898431178, 0.021393768620328046, 0.06665065753622912, 0.113470943615539, 1.382596897892654, 33.37621584534645, 68.76544207334518, 66.75676345825195, 67.68107905983925, 64.17225614190102, 31.935158371925354, 70.07311910390854, 113.02357479929924, 29.141063801944256, 23.239556774497032, 40.74875123798847, 39.936708211898804, 47.98081196844578, 28.71789000928402, 16.145111359655857, 2.485906882211566, 0.20059668371686712, 0.06534449246828444, 0.04102428341866471, 0.07427244738209993, 0.037290334366844036, 0.2284749862155877, 0.666302558965981, 0.8836787415202707, 2.7661810303106904, 2.539738593623042, 1.7102637654170394, 2.8763425815850496, 3.7341560516506433, 6.443921271711588, 10.629303585737944, 12.89748452603817, 18.244897685945034, 20.07007274776697, 28.259904384613037, 43.76841880381107, 60.97720518708229, 66.44116759300232, 70.5553588271141, 65.33883914351463, 65.09960398077965, 65.84694027900696, 65.9066654741764, 69.20077711343765, 71.1655604839325, 70.9144775569439, 66.53441458940506, 66.05793535709381, 65.98449289798737, 65.99424317479134, 64.92536813020706, 66.88864678144455, 70.5084465444088, 67.42941096425056, 60.169357135891914, 36.31611429154873, 31.341687217354774, 53.40860791504383, 45.95823369920254, 47.14157000184059, 51.6804226487875, 37.275057435035706, 36.31025120615959, 49.438831731677055, 51.55233912169933, 61.311674639582634, 60.210801512002945, 69.28041324019432, 65.45909509062767, 66.58239081501961, 62.44134642183781, 64.92507174611092, 69.21906173229218, 68.27033624053001, 70.47347322106361, 71.7421567440033, 72.56115719676018, 69.39251482486725, 51.51648424565792, 29.538549073040485, 7.8459348902106285, 1.0609206464141607, 2.885568724013865, 1.8655249779112637, 2.2018811479210854, 0.33600626222323626, 0.7503117166925222, 1.5123867709189653, 0.6572323862928897, 1.3501640944741666, 1.068334998562932, 0.5552956124302, 0.16203141014557332, 0.032349987159250304, 0.048633286060066894, 0.02630186023452552, 0.11186486924998462, 0.13143197866156697, 1.256491995882243, 11.690896321088076, 33.03117536008358, 34.339623749256134, 39.54621456563473, 49.33581545948982, 31.570697128772736, 15.439647864550352, 11.075473744422197, 12.16314448043704, 34.651400819420815, 62.443052530288696, 62.21084699034691, 73.73344749212265, 70.00118136405945, 14.126709066331387, 0.8585561520885676, 0.2499869529856369, 0.0874213820497971, 0.03319457347970456, 0.09609374872525223, 0.03044066012080293, 0.06783576347515918, 0.0471368565922603, 0.08855017382302321, 0.1007009792374447, 0.06690949638141319, 0.032531052638660185, 0.051476312801241875, 0.03295021393569186, 0.0882865852327086, 0.034136566682718694, 0.05157004234206397, 0.02671646845556097, 0.055119059325079434, 0.0168602983103483, 0.010569163478066912, 0.024473568300891202, 0.07439553999574855, 0.03239408557419665, 0.009194502817990724, 0.054447259826702066, 0.06058175233192742, 0.0733921340724919, 0.06849000375950709, 0.036216754670022056, 0.03194235512637533, 0.04025673944852315, 0.04452521665371023, 0.08006941483472474, 0.01359342917567119, 0.053562972316285595, 0.044167635060148314, 0.0413054275122704, 0.08046330971410498, 0.0492503670102451, 0.028604529252334032, 0.05947898025624454, 0.06775699934223667, 0.11308366869343445, 0.00996325370579143, 0.04456825008674059, 0.0064273050156771205, 0.05288360291160643, 0.030941463228373323, 0.015005241748440312, 0.032401607240899466, 0.04931599884002935, 0.06206339079653844, 0.05290732566209044, 0.06598519597901031, 0.004377586365080788, 0.072808093536878, 0.05119648601976223, 0.08686634464538656, 0.09743967064423487, 0.10331417768611573, 2.055228492245078, 39.989840760827065, 80.82961231470108, 76.53129056096077, 78.03370714187622, 71.73929169774055, 39.01262819766998, 81.60026416182518, 110.63571453094482, 30.3136732801795, 25.911620892584324, 37.96142220497131, 41.48753419518471, 48.70508350431919, 36.293368712067604, 16.497954726219177, 1.5879681590013206, 0.07415101717924699, 0.09871664704405703, 0.06857321335701272, 0.13153973850421607, 0.6569406331982464, 1.3397306855767965, 2.2226118855178356, 2.2260704124346375, 4.041445087641478, 3.0684723844751716, 2.633897541090846, 2.7662950241938233, 4.129432216286659, 8.745446372777224, 11.534131933003664, 13.895639665424824, 17.606799826025963, 19.77731365710497, 27.967593669891357, 45.73495768010616, 60.960246697068214, 70.12914329767227, 72.94708728790283, 69.20162826776505, 66.3184341788292, 70.67373767495155, 71.10623806715012, 71.66226983070374, 73.80925342440605, 71.98635444045067, 67.55517661571503, 66.71622723340988, 65.75635313987732, 67.24809229373932, 67.88997665047646, 67.51272529363632, 71.87966376543045, 68.48594427108765, 61.58925734460354, 40.34701779484749, 41.00368715822697, 60.14621637761593, 53.61893802881241, 52.829401195049286, 58.745516538619995, 44.23420920968056, 42.597230449318886, 52.85309672355652, 57.5978185236454, 65.58872133493423, 63.884907960891724, 72.82384470105171, 66.0769647359848, 65.81749945878983, 64.5655882358551, 65.1245990395546, 69.98397588729858, 70.408283919096, 71.62446945905685, 75.28817966580391, 75.06816387176514, 71.11541077494621, 54.82471972703934, 31.233537420630455, 8.45102772116661, 1.6100107762031257, 1.0979551216587424, 0.479715263354592, 1.2518719187937677, 0.9863150340970606, 2.1218669414520264, 1.7200642707757652, 0.9537033434025943, 1.352789041120559, 1.354298391379416, 1.1951624555513263, 0.8172091457527131, 0.20384357980219647, 0.198639759037178, 0.08834704800392501, 0.017273785888392013, 0.09610565277398564, 0.7767751591745764, 14.208532925695181, 37.2994901239872, 42.01220244169235, 52.679487839341164, 60.90424530208111, 37.8017433732748, 22.13355392217636, 19.939080476760864, 23.064059391617775, 45.1016266644001, 69.0467257797718, 69.23496767878532, 78.39711204171181, 83.31906393170357, 23.3844505995512, 0.9888170810882002, 0.16337022971129045, 0.02739468382060295, 0.059123376486240886, 0.022552569134859368, 0.010238311260764021, 0.036985697588534094, 0.09539174381643534, 0.046656805789098144, 0.127194641972892, 0.03533515002345666, 0.05515719829418231, 0.049897237768163905, 0.04255830266629346, 0.027014932420570403, 0.018927229684777558, 0.04163532328675501, 0.02796982415020466, 0.015203600196400657, 0.049604950327193365, 0.039991944868233986, 0.0509702608542284, 0.02983549806231167, 0.020190097857266665, 0.06210608655237593, 0.04327656431996729, 0.031480653924518265, 0.024590501088823657, 0.04098788107512519, 0.041846334424917586, 0.08584581737522967, 0.07189688461949117, 0.00636809786556114, 0.23367815389065072, 0.20055292668985203, 0.19759457762120292, 0.15740861679660156, 0.12867723038652912, 0.18464185937773436, 0.1696767780231312, 0.09991117083700374, 0.20213974232319742, 0.25258031382691115, 0.18474601238267496, 0.1399504832806997, 0.06582185669685714, 0.141480925376527, 0.14464624458923936, 0.0891246777609922, 0.11171560108778067, 0.14685229340102524, 0.16135657526319847, 0.16843642661115155, 0.18603927892399952, 0.2992954524233937, 0.12321470436290838, 0.21880204119952396, 0.11538969964021817, 0.17595067183719948, 0.2621745615033433, 0.3443691384745762, 3.226594962179661, 52.288701608777046, 89.4847422838211, 86.02315083146095, 87.52204120159149, 80.94445735216141, 45.423799976706505, 79.34378564357758, 115.41522726416588, 38.069883584976196, 34.95764918625355, 57.69767336547375, 54.058764427900314, 66.13149181008339, 43.408365324139595, 22.650424987077713, 4.3782024923712015, 0.39309558633249253, 0.26388111524283886, 0.19885912304744124, 0.31672743265517056, 0.6137588596902788, 1.3564030034467578, 2.719539483077824, 4.593977713957429, 7.928217574954033, 7.761561367660761, 7.769425045698881, 11.495783440768719, 10.058539062738419, 13.279605321586132, 13.272678293287754, 19.10662304610014, 22.411488108336926, 24.435470402240753, 33.05677838623524, 48.69990058243275, 65.69738030433655, 72.2535865008831, 73.88337224721909, 71.21609017252922, 68.42722222208977, 70.92504099011421, 71.15616738796234, 73.40563148260117, 75.74281007051468, 72.38223999738693, 64.18011412024498, 65.79265639185905, 67.01394125819206, 66.75086617469788, 68.95920127630234, 70.7283179461956, 72.80896469950676, 73.38531777262688, 68.27970653772354, 46.81968167424202, 46.99701815843582, 64.9089378118515, 58.95439513027668, 60.12676902115345, 65.65475419163704, 48.56496222317219, 46.348309367895126, 55.67743957042694, 57.547425627708435, 68.44188943505287, 68.65833342075348, 72.08071857690811, 66.57239735126495, 66.17470309138298, 61.80742643773556, 64.2427271604538, 70.46530365943909, 70.8386792242527, 75.01293003559113, 77.49707713723183, 76.86396270990372, 77.01520219445229, 58.08697007596493, 33.72164011001587, 9.19968444854021, 3.3623208291828632, 6.594858672469854, 4.421587139368057, 6.320740906521678, 3.8069164473563433, 6.0794163309037685, 6.547430092468858, 3.4970217011868954, 4.812690652906895, 3.409105818718672, 1.376324265729636, 0.45911517343483865, 0.1286720353527926, 0.2014773161499761, 0.22876846109284088, 0.3138627129374072, 0.40653300122357905, 2.057898323982954, 19.94861226528883, 48.98242302238941, 51.719727739691734, 57.59093329310417, 60.73104679584503, 41.93836100399494, 25.790850073099136, 19.06468279659748, 23.790409415960312, 50.63877314329147, 79.68772038817406, 82.49041959643364, 88.76023516058922, 91.56720533967018, 26.268959417939186, 1.31131925387308, 0.2922905283048749, 0.1772331475513056, 0.1808037981390953, 0.1966706186067313, 0.17563652072567493, 0.17075597948860377, 0.14722237276146188, 0.11142554751131684, 0.19893850316293538, 0.13664653088198975, 0.17236448067706078, 0.16537766496185213, 0.13830702693667263, 0.17173102794913575, 0.1218130619963631, 0.09953315791790374, 0.09596358344424516, 0.09958207287127152, 0.10710984002798796, 0.15415516012581065, 0.1466699774027802, 0.23047776077874005, 0.16894429310923442, 0.1394423792953603, 0.17319665086688474, 0.20883018878521398, 0.1650992111535743, 0.11785880269599147, 0.13553943950682878, 0.16808824060717598, 0.26134961983188987, 0.1495433208765462], [0.05031696680816822, 0.03052253941859817, 0.10519339208258316, 0.06870337863801979, 0.0970419537043199, 0.04175693902652711, 0.07376272551482543, 0.0023792433512426214, 0.05025415142881684, 0.03184862187481485, 0.06321504071820527, 0.04820764581381809, 0.07884531645686366, 0.011715724122041138, 0.11814498226158321, 0.04084090614924207, 0.05663784599164501, 0.04547106160316616, 0.025602816494938452, 0.08856443790136836, 0.09050142849446274, 0.10514401699765585, 0.053804938434041105, 0.013670777661900502, 0.06160944132716395, 0.03245568383135833, 0.048994496755767614, 0.6766454852186143, 29.410915821790695, 69.97182413935661, 71.74415543675423, 68.68503838777542, 56.80551543831825, 39.80667918920517, 25.17712600529194, 23.986836075782776, 26.304236724972725, 38.62842321395874, 47.402353808283806, 41.05530358850956, 47.23683089017868, 31.285134851932526, 9.85753744840622, 0.024085714503598865, 0.03963726507208776, 0.04719556418422144, 0.20502617728197947, 0.027397183002904058, 0.1561221483279951, 0.37718293082434684, 1.5035938052460551, 3.1779321609064937, 2.322204066440463, 0.5500755237881094, 1.4561155904084444, 3.1358073838055134, 7.820631572976708, 13.91721110790968, 21.533514820039272, 25.766261592507362, 32.943103685975075, 46.641570031642914, 49.07954581081867, 60.42099863290787, 69.14815753698349, 71.75686195492744, 68.23563650250435, 63.38636711239815, 61.92598767578602, 64.9495880305767, 65.75022786855698, 63.61688174307346, 61.37519583106041, 65.10321378707886, 72.23785534501076, 70.49792870879173, 67.37844809889793, 67.27590680122375, 68.32319140434265, 67.00460135936737, 66.48817107081413, 70.04604935646057, 67.08702653646469, 59.35055047273636, 59.153428450226784, 28.15835103392601, 34.30515579879284, 52.01439052820206, 48.16964663565159, 43.90026032924652, 31.981971859931946, 54.42650489509106, 66.96909606456757, 70.88835015892982, 72.89804711937904, 69.37230750918388, 64.61610272526741, 63.922297954559326, 63.354688212275505, 68.27789023518562, 71.8394847214222, 72.20934927463531, 71.25866308808327, 64.48973670601845, 64.6605983376503, 67.83115580677986, 66.89801707863808, 71.88297718763351, 78.58006462454796, 76.1707279086113, 57.49291755259037, 30.53225465118885, 8.482963107526302, 1.3914266740903258, 1.445579705759883, 1.9371660961769521, 1.4553054026328027, 0.6850126362405717, 0.3232962707988918, 1.4595025149174035, 1.730703106150031, 1.4149893284775317, 0.35667727177497, 0.10182011566939764, 0.043787800168502145, 0.021043415545136668, 0.06203298129548784, 0.02427557443297701, 0.45601011661347, 11.497009824961424, 29.67809848487377, 37.17732287943363, 35.75679950416088, 35.391715094447136, 35.29833510518074, 29.853012599051, 20.068936608731747, 19.049149230122566, 39.31572273373604, 65.47123923897743, 66.84124052524567, 73.81078094244003, 64.51844036579132, 9.639388304203749, 0.18370712437899783, 0.010605753213894786, 0.021053566269984003, 0.04125791150727309, 0.05103002600662876, 0.007862745715101482, 0.041611815759097226, 0.05203071566938888, 0.035993357087136246, 0.0428549502248643, 0.08572458013077267, 0.05760293854109477, 0.03376476925041061, 0.12462538608815521, 0.044805459037888795, 0.07758419233141467, 0.04617350066837389, 0.03493051997793373, 0.09788615410798229, 0.01506391408838681, 0.05654907399730291, 0.020596375470631756, 0.019285071030026302, 0.06993405244429596, 0.04744114456116222, 0.039734668243909255, 0.06746643368387595, 0.056544843755546026, 0.03983570793934632, 0.06432500420487486, 0.030012620882189367, 0.09114400963881053, 0.01945736617926741, 0.015712418498878833, 0.04236613094690256, 0.04223528660077136, 0.10741035788669251, 0.06246141201700084, 0.029887693308410235, 0.11996948553132825, 0.0626563816331327, 0.05675539476214908, 0.0639752671122551, 0.08115827906294726, 0.03552370377292391, 0.027137015713378787, 0.12248676881426945, 0.033704024463077076, 0.07946135097881779, 0.06770562045858242, 0.028342898076516576, 0.054682713598595, 0.03563083279004786, 0.046845274191582575, 0.04879060281382408, 0.05642949174216483, 0.010918570314970566, 0.11066978884628043, 0.03647053577878978, 1.3243045820854604, 38.30432340502739, 81.23005762696266, 79.89890545606613, 74.2704650759697, 67.8633400797844, 53.05714577436447, 37.99402445554733, 33.48602995276451, 45.15452742576599, 44.36997212469578, 34.5133276283741, 37.863493859767914, 46.561333537101746, 34.23148915171623, 10.34174831584096, 0.3708644933067262, 0.04775116562086623, 0.08830924300127663, 0.3069478558609262, 0.6489834445528686, 0.6374926830176264, 1.5863939747214317, 3.432995849289, 2.9805455775931478, 3.2823868934065104, 2.1380980079993606, 2.1312066027894616, 2.003414472565055, 7.532436512410641, 14.70963578671217, 22.663401290774345, 27.6121037453413, 35.06105683743954, 44.642558097839355, 49.55450512468815, 62.22086705267429, 71.77177235484123, 74.80070382356644, 70.12392237782478, 66.48125544190407, 68.23451176285744, 68.963882625103, 70.28881072998047, 67.72092372179031, 63.71807411313057, 66.48029789328575, 72.73817449808121, 69.73163142800331, 68.21568757295609, 67.94458732008934, 68.43451023101807, 67.69203007221222, 69.1497154533863, 71.33223474025726, 70.25062277913094, 62.69079923629761, 63.30349735915661, 32.55762577056885, 40.89826941490173, 56.10347270965576, 53.73624913394451, 49.27884891629219, 38.119216337800026, 57.922488301992416, 67.79375061392784, 74.32358622550964, 75.35873427987099, 69.85868141055107, 66.52087971568108, 64.71030727028847, 64.12589862942696, 68.44190463423729, 73.28367322683334, 75.3384205698967, 73.54810863733292, 67.60614708065987, 67.98249408602715, 69.44860741496086, 69.21563431620598, 75.59227734804153, 81.57285243272781, 78.93405362963676, 58.127073124051094, 32.02934771776199, 8.860811982303858, 1.933152205310762, 1.541143034119159, 0.25210002553649247, 0.5667791899759322, 0.415642685838975, 1.2376883486285806, 0.9332224423997104, 1.7434362228959799, 1.7206664197146893, 0.9216542600188404, 0.3886828653048724, 0.19196987006580457, 0.15566081448923796, 0.09435165353352204, 0.020174397723167203, 0.39698292617686093, 11.869565583765507, 32.84199871122837, 41.57132349908352, 38.83536770939827, 27.991378493607044, 21.566694639623165, 26.842268854379654, 28.603816330432892, 30.711739920079708, 50.315900668501854, 75.86670622229576, 74.44736078381538, 79.81572031974792, 79.17210325598717, 14.61810914799571, 0.18676398613024503, 0.09947808313881978, 0.07665739089134149, 0.011987795460299822, 0.06916019279742613, 0.029735630960203707, 0.06527392906718887, 0.021585725116892718, 0.06190953245095443, 0.02188700182159664, 0.0280866715911543, 0.05368571240978781, 0.034776913962559775, 0.04423901853442658, 0.06420789330150001, 0.004888900139121688, 0.09309401008067653, 0.02325700828805566, 0.054526372769032605, 0.03743059656699188, 0.02855972579709487, 0.037056194196338765, 0.05042978438723367, 0.046039023509365506, 0.006245463064260548, 0.06270246900385246, 0.02106526808347553, 0.025914692923834082, 0.031622804890503176, 0.03752884949790314, 0.02282811557961395, 0.09310710898716934, 0.13513879850506783, 0.09930053172865883, 0.17869753850391135, 0.1813372242031619, 0.28030368557665497, 0.16182441031560302, 0.18704450310906395, 0.18087385687977076, 0.1964175610919483, 0.15016010496765375, 0.15391547611216083, 0.18520522367907688, 0.1555481119430624, 0.11259664912358858, 0.1865033883950673, 0.14889021607814357, 0.17084477003663778, 0.1798357703955844, 0.11146571996505372, 0.16604641423327848, 0.15922739810775965, 0.22855487099150196, 0.19244750146754086, 0.14603575284127146, 0.16627903300104663, 0.2004472745466046, 0.19166367477737367, 1.939083687029779, 50.54930314421654, 92.14415118098259, 90.32505959272385, 89.23619762063026, 77.86250352859497, 56.81750759482384, 41.35056674480438, 32.761412635445595, 36.78299903869629, 48.31174001097679, 65.77424257993698, 56.79779805243015, 62.70243041217327, 45.08472137153149, 15.233185943216085, 0.6460156256798655, 0.2622144890483469, 0.20899432216538116, 0.5558594665490091, 0.4777095647295937, 0.8551659027580172, 1.3969582272693515, 4.486881885677576, 7.184578478336334, 6.77659722045064, 4.106145640835166, 5.751571347936988, 9.000252149999142, 10.796526912599802, 18.704365231096745, 25.014882311224937, 33.53915870189667, 39.14422273635864, 48.112360909581184, 50.646809712052345, 63.40784355998039, 75.20008519291878, 77.01421424746513, 72.3737208545208, 69.5408284664154, 68.78478303551674, 68.51555988192558, 71.16440534591675, 68.59879061579704, 65.8726117014885, 68.5758626461029, 76.0836973786354, 70.82240089774132, 66.38151079416275, 69.23540085554123, 69.95790928602219, 69.37227711081505, 71.90934777259827, 74.03465732932091, 70.36213919520378, 64.74401906132698, 63.24553146958351, 38.14947031438351, 46.63536876440048, 62.20887869596481, 59.04732674360275, 55.419406816363335, 42.4393755197525, 60.45002527534962, 71.48122474551201, 75.77202290296555, 74.72656980156898, 71.80923834443092, 67.06583127379417, 66.0065545141697, 65.37540838122368, 68.69171842932701, 74.76372420787811, 76.77894607186317, 77.12036535143852, 71.63790553808212, 71.1295536160469, 71.970684081316, 73.2960757613182, 76.16462543606758, 85.9370094537735, 81.93607494235039, 63.17781150341034, 35.72648473083973, 9.639484249055386, 2.8033888712525368, 4.444842841476202, 5.899157803505659, 4.3757877219468355, 3.8492409512400627, 3.6371398949995637, 4.898769808933139, 4.073082664981484, 2.7052700612694025, 0.8384875883348286, 0.2994123555254191, 0.15437915513757616, 0.18904843542259187, 0.35781816055532545, 0.09805055466131307, 1.1562362755648792, 18.809110410511494, 46.168863996863365, 55.78963615000248, 55.8068872243166, 54.18299876153469, 51.91819109022617, 41.903710663318634, 32.9089967161417, 32.607076317071915, 56.91490016877651, 86.55740976333618, 84.99464482069016, 88.57763975858688, 89.05956789851189, 17.98174850642681, 0.31959630839992315, 0.28883740422315896, 0.2329364960314706, 0.14623328286688775, 0.15817463194252923, 0.1472389226546511, 0.13597383338492364, 0.06262175302254036, 0.20855725655565038, 0.08325613758643158, 0.1532977569149807, 0.1706027111504227, 0.2544150809990242, 0.1479988225037232, 0.11654348694719374, 0.1131611860182602, 0.2135202058707364, 0.15021698316559196, 0.18553685978986323, 0.12666191352764145, 0.20235644944477826, 0.11602866652538069, 0.13678166113095358, 0.2473686114535667, 0.13251622673124075, 0.13756161381024867, 0.15957504976540804, 0.10628662013914436, 0.0969574750342872, 0.1486281637335196, 0.12463941267924383, 0.1699081202968955], [0.017102260717365425, 0.06807165511418134, 0.028915503971802536, 0.017465786913817283, 0.03118281892966479, 0.023890010161267128, 0.0381668553018244, 0.06031014854670502, 0.029579284564533737, 0.047699482456664555, 0.03408122844120953, 0.1253264187835157, 0.03698426895425655, 0.0061098049627617, 0.03752935415832326, 0.09141916831140406, 0.05418630957137793, 0.06923138702404685, 0.059837281733052805, 0.048075302329380065, 0.025110084243351594, 0.03391542522876989, 0.049554525103303604, 0.031280630282708444, 0.02791330960462801, 0.0554060960712377, 0.025241438816010486, 11.89908904954791, 64.77285951375961, 68.5623961687088, 68.92535269260406, 61.46675571799278, 32.88761146366596, 19.43187039345503, 15.457175374031067, 30.433226265013218, 12.78504190966487, 29.491386003792286, 49.333254396915436, 43.06174412369728, 40.54574713110924, 15.012872815132141, 0.769100283505395, 0.05734004014811944, 0.23826928721973673, 0.3226648218696937, 0.038136074726935476, 0.05919115683354903, 0.3998356231022626, 1.404968909919262, 2.2242861706763506, 1.5426317229866982, 1.548869563266635, 1.7163893929682672, 3.938082796521485, 8.248324748128653, 19.14458490908146, 29.427969306707382, 38.905329555273056, 49.175342470407486, 60.62283620238304, 60.3991574048996, 63.270849511027336, 72.23798453807831, 73.97525891661644, 68.12731191515923, 59.71578687429428, 58.5280542075634, 65.45041635632515, 70.0134015083313, 72.73666977882385, 66.40408918261528, 63.328473418951035, 59.356189370155334, 63.93811270594597, 67.5506092607975, 68.99393141269684, 67.29008764028549, 66.59024119377136, 66.58717855811119, 66.32158800959587, 61.64566911756992, 66.85302749276161, 66.7315100133419, 64.98691722750664, 53.210687935352325, 34.46970596909523, 40.9495210647583, 44.074340388178825, 30.749690383672714, 53.73304970562458, 67.08913162350655, 65.16043111681938, 60.637537613511086, 61.8722053617239, 67.39868581295013, 61.28050871193409, 60.2779895067215, 65.86552888154984, 68.91967579722404, 67.30391129851341, 65.63865825533867, 59.641075283288956, 60.2123898267746, 59.141732677817345, 58.7420891225338, 58.228725269436836, 62.096571922302246, 62.437786012887955, 62.083656415343285, 67.50123471021652, 72.98645317554474, 72.25727990269661, 48.687790632247925, 26.441901437938213, 13.440107759088278, 3.7241169903427362, 0.3701140929479152, 1.2002081098034978, 1.1333771771751344, 1.2242305395193398, 2.127488264814019, 1.5817090636119246, 0.47430218663066626, 0.3175619331886992, 0.11334683425957337, 0.009441217753192177, 0.027748213287850376, 0.044868849581689574, 0.22591843589907512, 4.424437461420894, 19.98334050178528, 40.45729547739029, 53.391622826457024, 57.30530261993408, 43.98624211549759, 29.65647004544735, 13.902339655905962, 26.08360916376114, 46.141817048192024, 58.20650406181812, 62.98685275018215, 72.97291070222855, 37.0827953517437, 1.6133629088290036, 0.16313202999299392, 0.04225268625305034, 0.021943091487628408, 0.03382260852959007, 0.08138319433783181, 0.03010471584275365, 0.06759132971637882, 0.07078310649376363, 0.024197891980293207, 0.047383142009493895, 0.0863492680946365, 0.021870527998544276, 0.021853592188563198, 0.040837948690750636, 0.03634074157162104, 0.021785971403005533, 0.007306282923309482, 0.04636057012248784, 0.017725024663377553, 0.08623994974186644, 0.036426496735657565, 0.029479985205398407, 0.0924254537676461, 0.031001951974758413, 0.01694877715635812, 0.01672946509643225, 0.021369572750700172, 0.06265521646128036, 0.11300605488941073, 0.025966049543058034, 0.038815473817521706, 0.033278317423537374, 0.062412051775027066, 0.028873468727397267, 0.02155692422093125, 0.07378606605925597, 0.05131844685820397, 0.008674177515786141, 0.05487213195010554, 0.056614869099576026, 0.03657161629234906, 0.004103945384485996, 0.031761616191943176, 0.042215371067868546, 0.04844678063818719, 0.05179135077924002, 0.019061163220612798, 0.07322902485611849, 0.034306373781873845, 0.025139144890999887, 0.09761161883943714, 0.03197403741069138, 0.03114660212304443, 0.03468052753305528, 0.04499296635913197, 0.042980080033885315, 0.05826933149364777, 0.03623149743361864, 16.37533340603113, 77.06535190343857, 75.41169583797455, 78.66526365280151, 71.32749259471893, 46.85035362839699, 26.73827413469553, 23.00527084618807, 33.76431182026863, 16.68302569538355, 23.880861662328243, 45.45366257429123, 42.51905344426632, 41.840881034731865, 13.934234194457531, 0.363985140575096, 0.07689484104048461, 0.052779613179154694, 0.2686853043269366, 0.46858307789079845, 1.3891452527604997, 2.534172129817307, 3.7506868271157146, 3.4581984719261527, 2.341344114392996, 3.2708169892430305, 1.942687793634832, 2.9524907330051064, 10.911654084920883, 20.163718722760677, 33.18519249558449, 43.400879725813866, 54.066200628876686, 64.4810351729393, 60.417404025793076, 63.39643657207489, 72.53066763281822, 76.99326977133751, 70.26421085000038, 63.12390759587288, 61.095074862241745, 67.71390169858932, 71.59885123372078, 75.30777901411057, 70.15397876501083, 64.72494408488274, 62.832569628953934, 66.02493032813072, 70.24254441261292, 71.64736703038216, 66.85586214065552, 67.58597016334534, 68.06318655610085, 68.42757180333138, 66.36358335614204, 68.5629965364933, 67.48177215456963, 66.95636674761772, 55.097674280405045, 40.744989439845085, 47.73876875638962, 50.41792519390583, 37.02685475349426, 57.99512140452862, 71.13432615995407, 68.19495588541031, 64.28132548928261, 65.95135107636452, 68.90927195549011, 63.96658077836037, 61.81779608130455, 67.52583459019661, 70.00515595078468, 70.7665666937828, 67.33532801270485, 61.96735605597496, 63.70433785021305, 61.51943989098072, 63.33249360322952, 61.612329706549644, 65.65753564238548, 65.67578226327896, 64.72627401351929, 72.66234576702118, 76.408351957798, 74.61692288517952, 51.02326311171055, 28.44116795808077, 14.226528760045767, 4.309229543432593, 0.23169235966634005, 0.3163299086736515, 0.719493767246604, 0.4735346871893853, 2.419665986672044, 2.490942324511707, 1.5336818969808519, 0.6988640211056918, 0.3766685927985236, 0.07472243378288113, 0.09825437067775056, 0.03436675491684582, 0.16210822243010625, 4.574705148115754, 18.73331967741251, 39.683406203985214, 48.772248700261116, 48.54640781879425, 33.610982447862625, 22.894048914313316, 19.436071068048477, 39.62246887385845, 57.39577576518059, 64.39007565379143, 69.95651096105576, 81.81953519582748, 50.42728029191494, 2.170553016476333, 0.1689566276036203, 0.08656690290081315, 0.03307691709778737, 0.024930725703598, 0.015643665938114282, 0.02477186713804258, 0.03330304578412324, 0.04245719246682711, 0.018622750612848904, 0.006419351047952659, 0.044834458458353765, 0.0450085403281264, 0.03727096431248356, 0.03929756552679464, 0.026811919778992888, 0.048174130424740724, 0.01902179228636669, 0.01367459137327387, 0.04423859922098927, 0.03982844602433033, 0.0055141558459581574, 0.04597023013047874, 0.05199266204726882, 0.044531576859299093, 0.0037844862936253776, 0.03465507928922307, 0.044440014389692806, 0.04539188557828311, 0.036780304508283734, 0.02321596195542952, 0.04431900721101556, 0.09540618601022288, 0.1291595966904424, 0.23403825878631324, 0.07104260585037991, 0.17335772659862414, 0.10690281793358736, 0.12988945440156385, 0.22384512762073427, 0.127920922532212, 0.10253950909827836, 0.12852572835981846, 0.16171454277355224, 0.11608420143602416, 0.21174302935833111, 0.22632830921793357, 0.1395881370990537, 0.15154585795244202, 0.17445816833060235, 0.17623455816647038, 0.17750517436070368, 0.11184871269506402, 0.13596900942502543, 0.13965981372166425, 0.15349504945334047, 0.18819109158357605, 0.2206840386497788, 0.18259813310578465, 24.490191265940666, 92.31850102543831, 84.41207528114319, 89.64870348572731, 79.13701593875885, 51.01221710443497, 30.88167630136013, 24.959545880556107, 44.18334133923054, 20.26278890669346, 40.57018741965294, 67.64994353055954, 59.84131693840027, 56.26301094889641, 21.676140166819096, 1.2828381196595728, 0.18093928461894393, 0.3600591793656349, 0.5534787161741406, 0.45869283203501254, 1.2460832856595516, 1.8725860677659512, 4.785419991239905, 7.747545819729567, 7.34318339265883, 6.957110334187746, 6.605992550030351, 7.205284042283893, 13.305922709405422, 26.36075109243393, 38.50403308868408, 49.76973317563534, 56.87042735517025, 68.08536976575851, 65.45727118849754, 63.74711595475674, 74.9831472337246, 79.66847062110901, 73.22998970746994, 65.42109712958336, 62.69084483385086, 70.07871240377426, 74.3382154405117, 77.05559402704239, 72.52999126911163, 68.8701568543911, 64.69757795333862, 68.4854806959629, 71.19800314307213, 73.05803373456001, 69.4332106411457, 69.1744065284729, 70.62784373760223, 71.86647087335587, 67.60398119688034, 71.80197313427925, 68.76311659812927, 70.36273956298828, 56.869093626737595, 46.03419542312622, 52.11798436939716, 54.76210668683052, 40.670684427022934, 61.43559359014034, 73.01516443490982, 71.03826731443405, 65.56231275200844, 68.27722907066345, 71.78412169218063, 67.4122054874897, 62.18346945941448, 67.6185192167759, 72.56120279431343, 72.5645238161087, 72.64878809452057, 65.20484313368797, 66.00446462631226, 64.62191641330719, 65.73669299483299, 65.36154672503471, 67.74726390838623, 67.27931141853333, 67.16192811727524, 72.55163490772247, 78.03741574287415, 76.46464973688126, 50.054710283875465, 28.84566005319357, 14.702893048524857, 4.757224554196, 1.9822087604552507, 3.966378215700388, 5.462274821475148, 7.533749816939235, 5.803873166441917, 5.415364438667893, 3.1889081094413996, 0.739960775244981, 0.23716526833595708, 0.0724449087283574, 0.21967032429529354, 0.1504826423479244, 0.5959645926486701, 7.944088373333216, 31.446827575564384, 57.51908674836159, 70.47398999333382, 77.43870466947556, 63.15157391130924, 42.548615857958794, 24.416796304285526, 40.2177145332098, 61.99419781565666, 76.29256457090378, 79.33275863528252, 88.87812003493309, 59.30449694395065, 3.6628811387345195, 0.27638306783046573, 0.18814420269336551, 0.099385567009449, 0.1271772015024908, 0.24845912324963138, 0.24199215229600668, 0.15453496162081137, 0.1419090703711845, 0.10736234093201347, 0.0793344214616809, 0.10924565940513276, 0.13149957347195596, 0.09285367297707126, 0.18872536369599402, 0.12224745587445796, 0.1634221206768416, 0.12162571423687041, 0.08255565408035181, 0.14824248442891985, 0.25013033591676503, 0.0913733926427085, 0.13039415935054421, 0.2699418197153136, 0.13570594775956124, 0.0992533311364241, 0.09994165084208362, 0.14867162390146405, 0.11704025091603398, 0.24507436581188813, 0.0991217112459708, 0.13428795587969944], [0.04962670638633426, 0.045232082629809156, 0.035577761809690855, 0.052364741495694034, 0.06045366506441496, 0.041463297166046686, 0.03452519602433313, 0.045461539848474786, 0.01785040680260863, 0.038636185781797394, 0.004646653860618244, 0.02483784221112728, 0.029095036916260142, 0.04142159959883429, 0.023441927369276527, 0.03298342875496019, 0.01780895599949872, 0.0717821263242513, 0.014149687413009815, 0.030378651827049907, 0.0308207825946738, 0.03224435728043318, 0.010721481867221883, 0.0159342983897659, 0.04589774085616227, 0.05373577027057763, 2.570870560593903, 43.69558811187744, 69.83611062169075, 65.59331148862839, 63.71988661587238, 48.639822006225586, 27.537726536393166, 22.372015826404095, 29.819737784564495, 31.460086964070797, 48.93372483551502, 68.25184643268585, 46.10870182514191, 37.36812584102154, 11.434671320021152, 0.4202884412370622, 0.07672193547477946, 0.016617020446574315, 0.03953679683036171, 0.1451376947807148, 0.5195140605792403, 1.3909122766926885, 2.3886969359591603, 3.145017377100885, 3.8211625954136252, 1.2864212086424232, 2.673145397566259, 6.164179807528853, 13.346729669719934, 25.219336040318012, 40.636873841285706, 54.57945428788662, 60.55682994425297, 67.45300009846687, 62.94760085642338, 64.52455803751945, 62.20624163746834, 65.79013332724571, 67.71716952323914, 63.70889760553837, 54.834143221378326, 57.91178807616234, 66.3319082558155, 69.38850224018097, 63.45506742596626, 66.6568212211132, 62.10943043231964, 56.730157881975174, 60.696852430701256, 63.13602514564991, 65.21076321601868, 64.14850741624832, 64.1332246363163, 65.23913249373436, 62.74628385901451, 68.06240379810333, 66.61098808050156, 62.9246386885643, 58.99789519608021, 66.24774277210236, 46.051298305392265, 32.20314659178257, 24.472945891320705, 41.702572256326675, 69.26266819238663, 64.68756929039955, 60.804196670651436, 59.32545281946659, 60.85806258022785, 66.55277520418167, 71.73254325985909, 62.64171727001667, 62.705348655581474, 66.48448526859283, 62.40317367017269, 56.63757584989071, 53.99164102971554, 48.75949278473854, 48.978034257888794, 50.07739506661892, 51.31567262113094, 53.2728336006403, 57.30109244585037, 60.79470857977867, 62.47962936758995, 61.70012779533863, 64.45465698838234, 68.90221193432808, 59.17184606194496, 59.909967854619026, 36.487811878323555, 27.918395809829235, 11.722832657396793, 0.22403156996006146, 1.0434817196801305, 1.4451560284942389, 1.8709514429792762, 1.310498141683638, 1.3584917038679123, 0.08296725660329685, 0.027417885212344117, 0.04193635693809483, 0.008649214450997533, 0.038473978274851106, 0.11755195431760512, 1.1200039135292172, 7.191929183900356, 30.855858586728573, 37.23219193518162, 61.65358029305935, 64.3771943449974, 33.875638246536255, 21.432730928063393, 30.86748406291008, 53.33720214664936, 58.23862373828888, 72.46432319283485, 55.09630635380745, 6.994430981576443, 0.39840844343416393, 0.08862947230227292, 0.08704378473339602, 0.035277050992590375, 0.03410493263800163, 0.04648764064768329, 0.04003098925750237, 0.059482575961737894, 0.04616649850504473, 0.042993954484700225, 0.05656510438711848, 0.07210953961475752, 0.04658030149585102, 0.020119213477300946, 0.03666711585537996, 0.01917811641760636, 0.007532623585575493, 0.024747656425461173, 0.1316880641388707, 0.03873561872751452, 0.03512177514494397, 0.03759580977202859, 0.04220603856083471, 0.07175811784691177, 0.01779030768375378, 0.0145995662023779, 0.05766425107140094, 0.020299414354667533, 0.04010783122794237, 0.06614998987060972, 0.030345056657097302, 0.022857875701447483, 0.046026362470001914, 0.03094462848821422, 0.058891551816486754, 0.06404383413610049, 0.04133428963541519, 0.027027270625694655, 0.022493488613690715, 0.03517475335684139, 0.059567889547906816, 0.025070112169487402, 0.06897732018842362, 0.03036062691535335, 0.06745009901351295, 0.054641487295157276, 0.037217633580439724, 0.060838379577035084, 0.10482703830348328, 0.02849669890565565, 0.04698351403931156, 0.052589278275263496, 0.09339448341052048, 0.06627656315686181, 0.03247943255701102, 0.06556840584380552, 0.05395875225076452, 3.389350203797221, 52.63014368712902, 82.55181670188904, 74.84067007899284, 70.42294353246689, 59.43107955157757, 33.176965937018394, 29.152938164770603, 24.66790582984686, 25.211601555347443, 39.565300941467285, 56.9415595382452, 48.94493043422699, 37.58233554661274, 12.156848218291998, 0.6802601006347686, 0.00232795514875761, 0.050374846905469894, 0.16827557352371514, 0.8485447580460459, 1.3682660856284201, 3.4975166246294975, 4.35941725037992, 4.408258879557252, 4.329039780423045, 2.1581697184592485, 3.1906994758173823, 7.430348815396428, 15.642368886619806, 27.721125595271587, 45.80086134374142, 59.0905000269413, 63.36461327970028, 69.91079941391945, 64.54965949058533, 65.94982355833054, 64.4165450334549, 66.72000423073769, 70.38489997386932, 66.22538477182388, 57.10873156785965, 60.335149839520454, 68.82379174232483, 70.56989684700966, 66.06113478541374, 70.19131556153297, 64.44285482168198, 59.42752294242382, 62.963351011276245, 64.79350000619888, 67.83316969871521, 66.92306533455849, 65.98275259137154, 68.39803978800774, 65.76820850372314, 69.07349154353142, 66.6035708785057, 65.07166787981987, 61.739904060959816, 66.43932849168777, 49.37482416629791, 36.825701147317886, 29.347073547542095, 44.27494302392006, 71.3942702114582, 65.55806457996368, 62.81344525516033, 62.212173119187355, 63.966117203235626, 68.83938610553741, 72.2966305911541, 64.9434931576252, 64.1356261074543, 68.83858814835548, 65.31296253204346, 59.755175560712814, 56.27702459692955, 51.896239668130875, 52.20031835138798, 54.1143174469471, 54.18546102941036, 58.341727405786514, 61.95939928293228, 65.34809544682503, 66.32897481322289, 65.00254958868027, 68.0346728861332, 70.92480540275574, 63.720110803842545, 62.88106642663479, 40.22548511624336, 32.26590022444725, 13.588845077902079, 1.0452118143439293, 0.3153146506519988, 0.891418510582298, 1.118489457294345, 2.20917081926018, 0.9938117349520326, 0.7212029630318284, 0.39283387537579983, 0.1056183829496149, 0.04772438893269282, 0.04490264327614568, 0.11710518883774057, 0.9769682481419295, 7.5629018526524305, 30.478335544466972, 37.93515041470528, 55.175315514206886, 57.26031303405762, 30.20595096051693, 33.27391393482685, 40.67923776805401, 62.76223920285702, 65.41539743542671, 77.04957515001297, 72.78419762849808, 13.056289404630661, 0.386539691244252, 0.1003960010712035, 0.11773761740187183, 0.05897763723623939, 0.09942985838279128, 0.029038290449534543, 0.01406446288456209, 0.053888170295977034, 0.01770864546415396, 0.015056688353070058, 0.008720258392713731, 0.08708114444743842, 0.0704024886363186, 0.05947276848019101, 0.01543145437608473, 0.03432952878938522, 0.011882396574947052, 0.06047311304428149, 0.06522427196614444, 0.06974587347940542, 0.049086968356277794, 0.06869603879749775, 0.048641011817380786, 0.06875220453366637, 0.005008200841984944, 0.04456809052499011, 0.06689514324534684, 0.05415405954408925, 0.049660288568702526, 0.028179686814837623, 0.013989261060487479, 0.10719376950873993, 0.15476403292268515, 0.11447712517110631, 0.17833645397331566, 0.1877986587351188, 0.0769037839199882, 0.08676491532241926, 0.18386152078164741, 0.14748034329386428, 0.19226502219680697, 0.09290796850109473, 0.11070567910792306, 0.06747039675246924, 0.2225262124557048, 0.11746853691875003, 0.0860527875192929, 0.18935160274850205, 0.1946695361402817, 0.11593445829930715, 0.13273683754960075, 0.0976577284745872, 0.15643735328922048, 0.1392149258754216, 0.19271348719485104, 0.12289741396671161, 0.16345067851943895, 5.788784651085734, 70.16927674412727, 91.87890261411667, 84.96711149811745, 81.2998066842556, 66.23755171895027, 41.55624970793724, 34.22265462577343, 43.1890144944191, 46.32717490196228, 64.22339379787445, 89.26142826676369, 63.57745885848999, 52.74819195270538, 17.81725723296404, 0.9826031082775444, 0.22658050584141165, 0.1746829945477657, 0.17601369501790032, 0.5855565948877484, 1.539702673908323, 8.214177880436182, 7.017101040109992, 8.435988128185272, 11.488098353147507, 7.134819198399782, 7.100709853693843, 11.408271286636591, 20.79745251685381, 33.30903545022011, 48.25647957623005, 63.42781528830528, 66.24667882919312, 71.5528205037117, 62.591795548796654, 65.80366060137749, 64.64780822396278, 68.61038759350777, 73.68826031684875, 68.40639933943748, 59.33362238109112, 62.60563060641289, 72.29982241988182, 71.56693294644356, 69.56047341227531, 71.78479045629501, 67.44852393865585, 62.00758829712868, 66.74216464161873, 68.69260758161545, 70.15376597642899, 67.20418184995651, 66.873599588871, 69.88309130072594, 67.3702709376812, 71.32748499512672, 68.37436705827713, 64.47432473301888, 62.16787129640579, 68.05383905768394, 53.57439301908016, 42.932133078575134, 34.24600437283516, 48.99922952055931, 72.93704062700272, 69.75094199180603, 66.46810054779053, 65.44686734676361, 67.77198538184166, 70.73094740509987, 72.04111710190773, 65.26525989174843, 67.1153350174427, 73.05741056799889, 68.92918288707733, 60.7774119079113, 58.24437662959099, 53.63142415881157, 54.506338611245155, 54.75780911743641, 56.78045958280563, 60.81278420984745, 64.83159676194191, 66.19725868105888, 68.37090164422989, 65.50976917147636, 69.85107421875, 72.6078262925148, 65.23072734475136, 65.83912029862404, 47.90290854871273, 33.26625734567642, 13.57807645574212, 2.007124973461032, 5.730923255905509, 6.69240846298635, 7.2812695149332285, 3.7682347605004907, 3.3661985211074352, 0.5074215063359588, 0.2080377531819977, 0.21420670731458813, 0.26710494537837803, 0.2404619922162965, 0.2329471384291537, 2.020509992726147, 12.776976842433214, 44.94270779192448, 51.71386085450649, 78.85358914732933, 79.44468542933464, 49.54962618649006, 33.77879664301872, 44.604810923337936, 71.18063047528267, 76.60359308123589, 86.63002386689186, 81.61110118031502, 17.110244370996952, 0.7765208696946502, 0.26593998132739216, 0.2884071070002392, 0.13690025632968172, 0.21025911992182955, 0.16286383266560733, 0.1668598674586974, 0.15517369844019413, 0.11878972305567004, 0.15041000093333423, 0.16427890048362315, 0.17875322926556692, 0.13476929801981896, 0.16114504833240062, 0.1359660259913653, 0.10334870239603333, 0.08660134597448632, 0.10703221880248748, 0.2579004142899066, 0.19645002263132483, 0.2008315734565258, 0.19148518826114014, 0.17593654134543613, 0.15700853982707486, 0.12125607274356298, 0.15383630379801616, 0.13016103592235595, 0.12319959423621185, 0.11821847714600153, 0.08436495816567913, 0.20215988421114162], [0.026382461182947736, 0.04063632572069764, 0.017232887985301204, 0.04297288862289861, 0.051662714322446845, 0.009252815216314048, 0.03482038155198097, 0.03515133859764319, 0.04324511952290777, 0.060560404454008676, 0.006118159226389253, 0.020524272113107145, 0.03791850671404973, 0.04805752418178599, 0.04549922239675652, 0.03286820290668402, 0.008816901790851261, 0.053483054143725894, 0.00991342591078137, 0.022215318676899187, 0.024859550030669197, 0.002335826552553044, 0.04715965907962527, 0.04549042052531149, 0.06253130006371066, 0.39379005844239146, 30.378152020275593, 79.96171608567238, 73.16671550273895, 71.48468255996704, 50.7095405459404, 34.98766377568245, 22.193412110209465, 24.429282434284687, 39.06954914331436, 50.39657413959503, 41.968770772218704, 34.94086928665638, 33.4839628636837, 13.605611678212881, 0.8961587562225759, 0.02676799205801217, 0.02335204029805027, 0.1664237369550392, 0.013296919842105126, 0.6091945921070874, 0.6539359444286674, 3.1190747441723943, 4.6609619446098804, 1.6745402198284864, 1.6590970172546804, 0.9153857838828117, 12.5211888179183, 22.40446988493204, 32.402233108878136, 53.62606264650822, 63.733558282256126, 66.70684933662415, 69.06247973442078, 70.79124256968498, 66.80866107344627, 64.27255555987358, 63.97124692797661, 67.23423823714256, 65.87023302912712, 61.3197074085474, 51.83562912046909, 53.46607223153114, 66.9075545668602, 64.08606916666031, 63.6541273444891, 66.75753101706505, 61.1635509878397, 57.535745054483414, 55.576007813215256, 54.6424625068903, 61.014519184827805, 63.13903458416462, 63.65135349333286, 63.61299455165863, 62.99426235258579, 62.629766911268234, 66.08659341931343, 63.196544498205185, 61.85538746416569, 61.29418797791004, 57.67615891993046, 26.870028264820576, 22.99556616693735, 62.83487990498543, 62.929179444909096, 61.85167886316776, 55.62506318092346, 51.54724359512329, 53.64372789859772, 62.96454034745693, 67.05526784062386, 69.75150436162949, 66.92250296473503, 61.6074887663126, 57.46087767183781, 49.355335012078285, 47.157943323254585, 48.91318693757057, 52.599114552140236, 56.221342384815216, 57.25518710911274, 56.78213149309158, 51.77626110613346, 47.67809361219406, 55.428222343325615, 62.233816757798195, 68.91199260950089, 67.21166744828224, 61.356151252985, 56.31465017795563, 54.09183785319328, 70.13343706727028, 63.42440687119961, 42.429009675979614, 10.494225583970547, 0.31388248375151306, 2.4609923316165805, 1.6589572560042143, 1.2861738656647503, 1.539376366417855, 0.6808929448015988, 0.14781848061829805, 0.07332933353609405, 0.02597084010631079, 0.026716188294813037, 0.06009085504047107, 0.24118068802636117, 4.855933282524347, 24.92273535579443, 46.580636501312256, 32.95337833464146, 36.31123535335064, 25.040407441556454, 15.544040612876415, 40.38906633853912, 50.18056333065033, 55.24964712560177, 70.50482153892517, 35.838799104094505, 1.3161157839931548, 0.18287142156623304, 0.0658878410467878, 0.04930657727527432, 0.04595830752805341, 0.02140389522537589, 0.021742424032709096, 0.031088907562661916, 0.07171768564148806, 0.028382879427226726, 0.04319762949307915, 0.09444021401577629, 0.10203848520177417, 0.045165671544964425, 0.0056673536801099544, 0.07186440081568435, 0.004925424937027856, 0.026780669795698486, 0.05198269500397146, 0.03428684787650127, 0.009001019352581352, 0.043610694046947174, 0.030085670478001703, 0.020420505024958402, 0.04245104377332609, 0.04064133892825339, 0.05742156507039908, 0.10266884317388758, 0.023683991821599193, 0.053665002778870985, 0.046085715730441734, 0.04152019762841519, 0.09658784096245654, 0.017512417907710187, 0.05064913726528175, 0.06512403750093654, 0.017440553892811295, 0.02451556829328183, 0.05482487198605668, 0.02156068690965185, 0.06522181545733474, 0.03169406219967641, 0.03723562324012164, 0.04392994371301029, 0.07130048732506111, 0.04600120737450197, 0.01952850474481238, 0.03338307527883444, 0.0221048778257682, 0.03181719934218563, 0.021335799465305172, 0.020495593671512324, 0.04230801707308274, 0.015756268294353504, 0.061045609472785145, 0.08027335701626725, 0.6220653920900077, 38.719196543097496, 92.95195743441582, 81.08132600784302, 80.31746059656143, 62.300522178411484, 46.29286274313927, 36.354921609163284, 26.738559119403362, 37.222251668572426, 44.35953788459301, 40.354389399290085, 43.60047161579132, 34.91259880363941, 15.14101903885603, 0.6814484274946153, 0.04863190195464995, 0.023424060163961258, 0.39138077991083264, 0.9366331156343222, 1.7165540903806686, 1.942524639889598, 5.291891964152455, 7.321610525250435, 3.522292720153928, 1.3040498876944184, 2.3485756013542414, 10.212234165519476, 22.811994217336178, 36.41176275908947, 55.17096854746342, 64.68739449977875, 70.26329129934311, 71.29120454192162, 71.28171265125275, 68.6997663974762, 64.25237864255905, 64.50223043560982, 69.43007960915565, 68.30253571271896, 62.26786673069, 55.05584232509136, 55.823606327176094, 69.51616778969765, 66.36650919914246, 65.55478155612946, 69.70673516392708, 65.2456833422184, 60.72782836854458, 57.334006279706955, 59.79582957923412, 64.40058588981628, 65.98199263215065, 64.13979828357697, 66.48076146841049, 63.93647879362106, 63.806411772966385, 67.64773964881897, 62.59591832756996, 63.273934945464134, 63.028152734041214, 58.263428807258606, 31.48202508687973, 27.292216010391712, 63.883220851421356, 65.00767171382904, 65.24369984865189, 59.097210466861725, 53.36326114833355, 57.62292757630348, 64.32637587189674, 69.25970435142517, 70.52292376756668, 69.267957508564, 64.25878509879112, 59.07768331468105, 53.15178729593754, 48.223976120352745, 51.708168759942055, 55.90358063578606, 59.66858960688114, 59.35512162744999, 59.00449924170971, 54.650031700730324, 51.524239629507065, 59.04438950121403, 66.50223791599274, 70.3546991944313, 70.39201319217682, 61.871867179870605, 59.13485884666443, 60.6813682615757, 72.70272240042686, 65.82886084914207, 46.22387744486332, 11.812910623848438, 0.99053138284944, 0.4799512366298586, 1.5001137857325375, 1.4674424263648689, 2.121088458225131, 2.0783246029168367, 0.3966204612515867, 0.11566186003619805, 0.10931889453786425, 0.03272755478974432, 0.042492693100939505, 0.15625364205334336, 4.534463882446289, 23.823047764599323, 49.562074318528175, 35.85638456046581, 36.79396905004978, 28.703454583883286, 19.727471731603146, 48.505225628614426, 56.558912470936775, 62.507854253053665, 80.06336823105812, 53.459289595484734, 1.9802025868557394, 0.1735157595248893, 0.029385699053818826, 0.02800035239488352, 0.040672501709195785, 0.042266174787073396, 0.026755156613944564, 0.04797216606675647, 0.021706112602259964, 0.024187455528590363, 0.027141485297761392, 0.07982348935911432, 0.02655541498825187, 0.02894525481679011, 0.03069375659833895, 0.04097917197213974, 0.039329793289653026, 0.028223835324752145, 0.03785840388445649, 0.020439604195416905, 0.051553488738136366, 0.023682375795033295, 0.04611472257238347, 0.010942826484097168, 0.03682613583805505, 0.03570985296391882, 0.015702197270002216, 0.027760044977185316, 0.037504918946069665, 0.0345200232550269, 0.010747979322331958, 0.11113069966086186, 0.3390190255595371, 0.08313318598084152, 0.1507062662858516, 0.12692760239588097, 0.13988173071993515, 0.10165026775212027, 0.1075605240475852, 0.10523193181143142, 0.12003800802631304, 0.130218300037086, 0.07852457507397048, 0.15984677971573547, 0.19201635819626972, 0.09163036127574742, 0.09046136736287735, 0.15596975572407246, 0.17446642101276666, 0.11543382774107158, 0.12744544335873798, 0.10777069284813479, 0.09278572193579748, 0.1750576900667511, 0.11218635278055444, 0.1662878051865846, 1.0760725708678365, 49.24033038318157, 102.05585092306137, 91.13810196518898, 92.06853523850441, 69.56304207444191, 50.70229813456535, 35.31522139906883, 36.529966816306114, 53.525953218340874, 69.47414964437485, 58.448927253484726, 51.084933802485466, 46.617790907621384, 20.459764637053013, 1.3706248090602458, 0.29742607148364186, 0.20935194828780368, 0.38178555259946734, 0.6507179327309132, 2.9927405482158065, 4.164966959506273, 9.894626308232546, 11.725026089698076, 9.96872803196311, 6.461736615747213, 6.712269997224212, 17.996296025812626, 27.655932493507862, 37.76784919202328, 58.732756823301315, 68.03903505206108, 72.34955415129662, 71.91029772162437, 74.23875957727432, 69.47347328066826, 64.15472388267517, 62.44633175432682, 69.80002775788307, 71.12343594431877, 65.34906819462776, 57.999244183301926, 59.83252801001072, 72.07539886236191, 69.80738416314125, 68.19225803017616, 69.70671996474266, 67.38693684339523, 63.52991200983524, 61.0333813726902, 61.2846314907074, 67.65065029263496, 68.58495935797691, 68.00280019640923, 68.33473518490791, 66.69050261378288, 65.43212413787842, 68.24008986353874, 63.31454336643219, 64.18883845210075, 66.26471266150475, 59.71384897828102, 35.67435532808304, 31.437103897333145, 66.68435454368591, 68.3931228518486, 67.62490287423134, 61.68897919356823, 56.07519842684269, 60.43490208685398, 68.4353081882, 72.3678919672966, 73.38676169514656, 71.90006107091904, 66.13042786717415, 61.2102884799242, 54.406403973698616, 50.542911887168884, 54.33020666241646, 57.54435919225216, 60.82015961408615, 62.125537768006325, 63.208464458584785, 57.534434124827385, 53.0535663664341, 61.249179393053055, 69.78914514183998, 73.22151616215706, 72.76779770851135, 60.532028675079346, 60.52832007408142, 61.945142447948456, 70.51021724939346, 69.92088407278061, 48.095330223441124, 12.407924495637417, 2.638498144224286, 6.865047449246049, 5.832106126472354, 4.370653247460723, 4.596638046205044, 1.8385090213268995, 0.4296421440085396, 0.1766355405561626, 0.17246429953956977, 0.19669024099130183, 0.2297666051890701, 0.5276227660942823, 7.75531355291605, 37.24900223314762, 62.491192147135735, 43.21419194340706, 54.757641926407814, 34.75963421165943, 26.250137127935886, 54.80520397424698, 66.71734437346458, 71.37283936142921, 88.31442788243294, 61.469537168741226, 2.951546721160412, 0.31358749489299953, 0.13006377004785463, 0.12319377579842694, 0.09953133223461919, 0.19023694039788097, 0.12965869100298733, 0.24242178158601746, 0.09896168936393224, 0.12996282312087715, 0.15455347078386694, 0.18847888160962611, 0.1932544237934053, 0.08778537579928525, 0.1403609206317924, 0.12150072914664634, 0.18434265512041748, 0.24110221333103254, 0.14274673245381564, 0.10656439117155969, 0.11453133905888535, 0.12079562206054106, 0.14142524945782498, 0.1342078039306216, 0.21156550763407722, 0.08259421607363038, 0.12086591086699627, 0.17349432629998773, 0.09051639019162394, 0.19795586995314807, 0.1608116162242368], [0.07731019883067347, 0.0370940325956326, 0.01848811203672085, 0.09251284907804802, 0.05425342569651548, 0.010672244079614757, 0.07946643469040282, 0.039671633930993266, 0.03333469096105546, 0.10408322821604088, 0.09590960704372264, 0.04918028600513935, 0.013813497298542643, 0.09383843615069054, 0.0704666473029647, 0.05633242995827459, 0.03779790400585625, 0.012959517243871232, 0.027961471278104, 0.01171300600617542, 0.028684889002761338, 0.04604441892297473, 0.1276795464218594, 0.05685549935151357, 0.11013947238097899, 12.493118774145842, 68.7969271838665, 73.04125383496284, 64.33908998966217, 49.920113906264305, 44.17615972459316, 23.64372968673706, 14.483917448669672, 28.690117299556732, 38.87965813279152, 33.783960565924644, 42.92656637728214, 30.38627028465271, 9.052088968455791, 0.6148806901182979, 0.04270144439942669, 0.0671050300297793, 0.03492630828986876, 0.026066150421684142, 0.6700099725276232, 1.5244691725820303, 2.6938685355708003, 2.467547692358494, 3.7134566623717546, 2.62256464920938, 5.032931584864855, 13.755409140139818, 36.708811819553375, 46.109815165400505, 63.98113399744034, 67.55196198821068, 68.56086105108261, 65.72556719183922, 70.23195058107376, 65.3202885389328, 64.62313994765282, 61.7308035492897, 66.82476460933685, 64.4119244813919, 63.493563160300255, 56.300343945622444, 50.16271188855171, 50.18094331026077, 63.78843113780022, 63.710482120513916, 66.83560162782669, 62.35367372632027, 65.16097068786621, 57.66577027738094, 61.33579954504967, 58.97813245654106, 63.71147006750107, 61.268170773983, 65.13919025659561, 59.342426508665085, 64.47506189346313, 59.77849870920181, 65.92114269733429, 59.393860548734665, 62.23595604300499, 52.49139033257961, 65.42007878422737, 29.526235833764076, 33.85614909231663, 71.19132310152054, 58.69524523615837, 61.89577929675579, 49.022206887602806, 49.42101448774338, 45.71427918970585, 53.10937017202377, 58.13804693520069, 58.457245007157326, 56.35008707642555, 57.72847071290016, 51.80746503174305, 49.59472216665745, 45.73505647480488, 51.07179030776024, 56.19060583412647, 63.519204184412956, 59.66365747153759, 62.86597743630409, 57.644890397787094, 51.3962396979332, 50.516115725040436, 58.042968437075615, 60.375290885567665, 67.42899298667908, 64.16471734642982, 60.7664342969656, 63.65606904029846, 61.6363862156868, 68.34405228495598, 72.29501187801361, 67.06102073192596, 34.648923352360725, 2.4502690695226192, 0.8232014835812151, 1.0838842391967773, 1.512634470127523, 2.7212748024612665, 0.6751458125654608, 0.020176130637992173, 0.08907021896447986, 0.03785434062592685, 0.05768490504124202, 0.07989029007148929, 0.05167220639123116, 2.1133482735604048, 26.150327883660793, 49.21243607997894, 46.19649991393089, 55.091792196035385, 30.20166479051113, 32.336109057068825, 49.293120950460434, 56.96806311607361, 67.77058705687523, 59.903861582279205, 9.31793600320816, 0.3798761253710836, 0.1082697648962494, 0.05685585187165998, 0.046936747603467666, 0.07966107034008019, 0.10803202530951239, 0.028220419590070378, 0.0675401660555508, 0.03975178588007111, 0.06570407043909654, 0.013303863561304752, 0.06150402667117305, 0.052628827324952, 0.06165883125504479, 0.06563152550370432, 0.06114794050517958, 0.0554184231441468, 0.027588725752139, 0.028558950252772775, 0.10195925351581536, 0.0385324520902941, 0.03330976964207366, 0.006220942968866439, 0.025639209561632015, 0.03864235673972871, 0.02878306586353574, 0.0273862845642725, 0.032690439984435216, 0.02798198980599409, 0.02819188215653412, 0.12173933704616502, 0.04313880686822813, 0.015603502761223353, 0.0830929541552905, 0.04620915715349838, 0.040352328069275245, 0.11949889711104333, 0.00864559648107388, 0.07690220314543694, 0.01679999510088237, 0.007559408622910269, 0.05074815831903834, 0.03860533470287919, 0.04429983011505101, 0.11313862472889014, 0.05947451252723113, 0.0405871139082592, 0.019729339182958938, 0.020705257811641786, 0.04987260217603762, 0.05849243221746292, 0.06921294465428218, 0.0578176789713325, 0.01996887476707343, 0.09078173025045544, 15.413007494062185, 81.31037011742592, 79.68399658799171, 73.0812656879425, 57.891763150691986, 53.651133701205254, 36.83654956519604, 20.852065086364746, 31.62908859550953, 39.14554126560688, 40.09910389780998, 42.81066119670868, 32.564115822315216, 10.780205838382244, 0.41635298053734004, 0.1026471501972992, 0.08804217373835854, 0.18019467301201075, 0.6955761881545186, 2.591359536163509, 3.120461432263255, 3.7006976595148444, 2.648245096206665, 2.4802983831614256, 2.4215879710391164, 5.644532041624188, 15.24481426924467, 35.78884318470955, 48.46316948533058, 63.30570504069328, 69.14186507463455, 73.21130990982056, 68.39407280087471, 70.20684912800789, 69.70882505178452, 65.06013929843903, 63.1956971436739, 64.862200319767, 68.1443578004837, 66.30663961172104, 58.30805741250515, 51.93171836435795, 52.34476000070572, 65.76411992311478, 67.28042095899582, 66.61100327968597, 63.61404329538345, 67.20598295331001, 61.15615278482437, 63.783027827739716, 62.546201795339584, 67.08621338009834, 64.19878631830215, 65.2169568836689, 61.49995073676109, 66.96464270353317, 62.269781827926636, 67.3630665242672, 61.78905822336674, 63.155468702316284, 54.79743339121342, 67.09453493356705, 32.52939708530903, 36.18303783237934, 72.56620332598686, 61.798550114035606, 64.73355442285538, 50.651791244745255, 51.73773497343063, 48.68567034602165, 56.72174513339996, 61.01516515016556, 60.0125927478075, 58.817127496004105, 60.50175569951534, 53.74021992087364, 51.96259170770645, 48.47506284713745, 53.09851795434952, 58.88417109847069, 64.81209620833397, 63.766665905714035, 66.88370704650879, 59.48039710521698, 53.97764638066292, 53.0774100869894, 61.34835407137871, 63.71247321367264, 69.9916210770607, 66.22180536389351, 62.31812283396721, 65.68999350070953, 65.23232325911522, 70.91656744480133, 77.2118416428566, 72.91518419981003, 38.44394691288471, 3.5555846337229013, 0.876948768272996, 0.6241392495576292, 1.7721817991696298, 3.0624102847650647, 0.9468183503486216, 0.6698287697508931, 0.35633089661132544, 0.1476435860968195, 0.04532541883236263, 0.07782280023093335, 0.04674810479627922, 2.148364344611764, 24.192479141056538, 35.93868434429169, 47.239065170288086, 33.00054520368576, 39.899747595191, 46.48048147559166, 54.01019163429737, 65.998415350914, 70.7802003622055, 73.88472497463226, 17.65218459069729, 0.784110784297809, 0.18683389644138515, 0.0782426109071821, 0.055823602378950454, 0.06876245359308086, 0.028204615555296186, 0.011625207152974326, 0.08567447774112225, 0.04084751126356423, 0.059209695682511665, 0.03826814361673314, 0.03775706732994877, 0.04820925627427641, 0.08574111518100835, 0.03548111933923792, 0.08003825947525911, 0.0614346321526682, 0.07359848081250675, 0.05587818362982944, 0.10155435258639045, 0.019385509585845284, 0.009683271073299693, 0.042743164231069386, 0.02445191057631746, 0.05103625633637421, 0.06700526311760768, 0.02561930701631354, 0.03193700795236509, 0.019271708661108278, 0.0238328276827815, 0.33899655332788825, 0.19413345318753272, 0.08894247308489867, 0.2525608101859689, 0.1781943326932378, 0.1185494675883092, 0.28477239422500134, 0.11085378209827468, 0.16088173433672637, 0.2566780970664695, 0.11030178007786162, 0.17208743694936857, 0.17219666624441743, 0.34388463478535414, 0.1461200014455244, 0.13173486397136003, 0.14273313630837947, 0.08382386571611278, 0.14257164497394115, 0.06695140546071343, 0.08529152953997254, 0.19165141449775547, 0.30650034081190825, 0.17007695889333263, 0.2479979972122237, 20.323961824178696, 95.40369987487793, 90.40182307362556, 85.82632899284363, 68.36632668972015, 62.221801802515984, 34.59085486829281, 21.72200370579958, 43.37082713842392, 52.385771200060844, 47.70677827298641, 57.99978755414486, 44.080420061945915, 13.766082767397165, 1.11336471978575, 0.19540078908903524, 0.15465879638213664, 0.34862449450884014, 0.5122151866089553, 2.904717084020376, 6.965277045965195, 8.03026869893074, 9.753630124032497, 10.844844169914722, 7.821482727304101, 9.935278426855803, 17.833497561514378, 39.97977890074253, 48.11010383069515, 67.40098848938942, 71.2557752430439, 74.7764003276825, 69.36163008213043, 76.15701824426651, 70.40625482797623, 65.87720945477486, 62.478869408369064, 66.47351905703545, 69.24230888485909, 68.79525527358055, 60.29714807868004, 54.39546436071396, 54.91011634469032, 69.13957759737968, 70.49835428595543, 67.5506092607975, 64.73315164446831, 68.83260726928711, 62.37683728337288, 67.16897293925285, 65.45452013611794, 68.59796226024628, 66.28310367465019, 68.28413709998131, 63.437086790800095, 69.09496039152145, 63.7445130944252, 70.66252067685127, 64.77332308888435, 64.81094107031822, 58.716885074973106, 66.77072390913963, 37.403007969260216, 39.72539775073528, 73.38960394263268, 66.61750853061676, 66.02519631385803, 54.43711772561073, 53.77909563481808, 51.35234445333481, 58.336943462491035, 65.34151419997215, 62.734797075390816, 61.59881763160229, 64.00281563401222, 57.88092993199825, 54.19773817062378, 50.29913976788521, 55.381762236356735, 62.88634434342384, 66.55355796217918, 65.0872166454792, 69.3065558373928, 63.39491285383701, 57.17496961355209, 55.70806972682476, 64.27456945180893, 64.94662418961525, 71.6524587571621, 66.15274026989937, 63.09975989162922, 64.67871576547623, 66.27207666635513, 70.98504737019539, 79.10183742642403, 75.94825744628906, 40.94553127884865, 3.8558181608095765, 5.437302086502314, 6.070599379017949, 5.102531975135207, 6.041804999113083, 1.6847544279880822, 0.4103528946870938, 0.3921089752111584, 0.3247725509572774, 0.19312750169774517, 0.14130273571936414, 0.2574366907356307, 3.9494871720671654, 39.7454796731472, 69.48286637663841, 62.21185013651848, 71.40814706683159, 48.46038043498993, 45.93143753707409, 62.335434705019, 78.56092885136604, 81.01938173174858, 83.80841687321663, 20.203308798372746, 0.9225888911169022, 0.2991075406316668, 0.15551487857010216, 0.08107769666821696, 0.23969008441781625, 0.23050009942380711, 0.0807118475495372, 0.3034670348279178, 0.10470052438904531, 0.20214618416503072, 0.1381892035715282, 0.15716897731181234, 0.1687984017189592, 0.16349217941751704, 0.14180386351654306, 0.17222676775418222, 0.21121521393069997, 0.19268752686912194, 0.24343270546523854, 0.18378205160843208, 0.09606459716451354, 0.10115608645719476, 0.1958091781125404, 0.14072893682168797, 0.1551975213806145, 0.15689518419094384, 0.09145891774096526, 0.05540437799936626, 0.11172839571372606, 0.16767529479693621], [0.04314793899538927, 0.07211588497739285, 0.05788858004962094, 0.027885291674465407, 0.016531090877833776, 0.01014026705888682, 0.13134008593624458, 0.05494937839102931, 0.031224408885464072, 0.05460342625156045, 0.09395971792400815, 0.02193215779698221, 0.08697973738890141, 0.084858174668625, 0.04416033232701011, 0.06034208316123113, 0.05772881420853082, 0.04141186633205507, 0.06796096378820948, 0.044828053723904304, 0.02677679578482639, 0.04025779700896237, 0.09463010734179989, 0.04808154008060228, 1.0400906391441822, 29.340169318020344, 76.54519781470299, 70.8505953848362, 60.380960181355476, 36.86814866960049, 34.76755678653717, 16.823217272758484, 37.56785832345486, 30.069490782916546, 33.46900686621666, 41.250814497470856, 28.313093930482864, 4.807183323428035, 0.25300503009930253, 0.0603784521081252, 0.0915613786492031, 0.12439517930033617, 0.23761017102515325, 0.8202628756407648, 3.0227515753358603, 1.0833978652954102, 1.1351660499349236, 1.9406799576245248, 5.83747761324048, 10.77395137399435, 24.071480333805084, 46.22928835451603, 58.41056831181049, 60.83526000380516, 65.15935197472572, 63.143943920731544, 66.9416843354702, 62.26553365588188, 64.3261706829071, 66.74057632684708, 69.82978016138077, 61.71557396650314, 64.63460773229599, 63.47142934799194, 63.762265741825104, 55.60999318957329, 47.66640163958073, 48.11521455645561, 58.55888955295086, 62.66675792634487, 65.84725186228752, 62.53790684044361, 64.12969842553139, 61.61120116710663, 64.32178571820259, 60.21255321800709, 63.412441313266754, 58.78994755446911, 61.22457571327686, 59.84032519161701, 63.19252051413059, 60.144111290574074, 65.06064847111702, 60.90853527188301, 61.70561470091343, 52.31737107038498, 65.59679210186005, 29.36770834028721, 35.73818430304527, 71.99222892522812, 55.937767401337624, 59.78768281638622, 49.391847252845764, 52.95336574316025, 45.03532022237778, 44.23157215118408, 45.515546053647995, 50.935613214969635, 48.22627119719982, 48.13671760261059, 44.75256219506264, 45.31839743256569, 48.343479707837105, 55.78060403466225, 60.324328020215034, 65.77868834137917, 66.37578830122948, 65.07450252771378, 55.930376797914505, 46.43260784447193, 47.462242394685745, 55.0869170576334, 61.5506362169981, 65.24993911385536, 60.94059035181999, 60.063240230083466, 59.254419431090355, 68.03053870797157, 70.42119562625885, 65.0022380053997, 65.08932933211327, 71.28374934196472, 51.46860681474209, 11.33270189166069, 0.4209228587569669, 1.233905057888478, 4.066230207681656, 1.0450297803618014, 0.4309211316285655, 0.16318049223627895, 0.1112792850472033, 0.05612470653431956, 0.061720292214886285, 0.02054623040748993, 0.05797382313176058, 2.882612245157361, 36.843837574124336, 45.809296891093254, 50.22957310080528, 13.161246422678232, 13.233832027763128, 39.596470668911934, 44.892592281103134, 59.62914392352104, 66.40956088900566, 56.73238456249237, 4.031762732192874, 0.0877700281853322, 0.043080195755464956, 0.05065255114459433, 0.039959776477189735, 0.018369518693361897, 0.021337228099582717, 0.04960946629580576, 0.05862932877789717, 0.04319439372920897, 0.05036071641370654, 0.0413834420760395, 0.04259051558619831, 0.0411869547679089, 0.04199527233140543, 0.11250414783717133, 0.03273874637670815, 0.012427219244273147, 0.06532973115099594, 0.013944860220362898, 0.048816396156325936, 0.020779472579306457, 0.038944436819292605, 0.010953696164506255, 0.01927826553583145, 0.027516306981851812, 0.039409596429322846, 0.046133914511301555, 0.025942224747268483, 0.046143117142491974, 0.10370842137490399, 0.05769039322331082, 0.037392205267678946, 0.0238017984884209, 0.06433023634599522, 0.04239665548084304, 0.007426219090120867, 0.017036747631209437, 0.05096365945064463, 0.003273794764027116, 0.01580770840519108, 0.04907562833977863, 0.044201903729117475, 0.03272545822255779, 0.05790397961391136, 0.051773661689367145, 0.07401058057439514, 0.03832014219369739, 0.08254830681835301, 0.05104689502331894, 0.029096678917994723, 0.00901283619896276, 0.09559021636960097, 0.0895719182153698, 1.5604250994510949, 42.60626256465912, 85.62063843011856, 79.8930461704731, 69.64545965194702, 47.95137494802475, 46.12971089780331, 22.304322458803654, 28.40577855706215, 22.277896776795387, 34.127165749669075, 40.03911271691322, 28.73061552643776, 4.8754471354186535, 0.16113244666485116, 0.0314757334854221, 0.06862543828901835, 0.2949278836604208, 1.0384953184984624, 2.1946062007918954, 4.591529220342636, 3.412130456417799, 2.842503022402525, 2.1091504488140345, 2.383681917563081, 9.159817937761545, 27.00198568403721, 49.44128639996052, 61.97361811995506, 61.70784518122673, 67.84086808562279, 67.78926685452461, 68.3831749856472, 64.8845887184143, 66.87310561537743, 69.99269261956215, 70.9413193166256, 61.0753159224987, 64.93891820311546, 66.10239297151566, 67.08811327815056, 57.98534452915192, 49.94714945554733, 51.30485460162163, 60.653504356741905, 64.88367676734924, 67.27248698472977, 61.78588539361954, 65.11934772133827, 64.56940323114395, 66.5985931456089, 63.885508328676224, 64.82072934508324, 60.6719371676445, 64.64271649718285, 61.77575133740902, 64.5257967710495, 61.69331096112728, 66.87169969081879, 62.50892199575901, 65.97934797406197, 54.43741790950298, 65.04241704940796, 30.78651800751686, 37.54247948527336, 74.22526270151138, 60.070030465722084, 63.09444397687912, 53.11480388045311, 53.608370795845985, 46.69322445988655, 46.85583293437958, 48.41933123767376, 52.17135630548, 51.65629394352436, 50.53774796426296, 47.43495225906372, 47.79432937502861, 49.532044529914856, 58.07587467133999, 62.19902582466602, 69.25737887620926, 68.94620597362518, 67.8823770582676, 57.70307667553425, 49.291810020804405, 50.83956956863403, 56.82084761559963, 64.35002580285072, 67.9337503015995, 63.26174899935722, 62.192759960889816, 61.897933781147, 69.67381373047829, 72.98377811908722, 66.18631526827812, 67.6576267182827, 72.77124792337418, 57.800720036029816, 14.07758055254817, 0.9143467771355063, 1.6863166191615164, 3.339461493305862, 1.88970711780712, 1.7975188395939767, 0.7185138354543597, 0.27220139221753925, 0.0668113399296999, 0.08746832289034501, 0.07956844288855791, 0.0519037416233914, 2.6440016739070415, 36.5203533321619, 42.26158306002617, 45.0211925804615, 18.57765343040228, 20.25585237890482, 51.0116471350193, 52.48501427471638, 63.138130232691765, 74.44612205028534, 75.62248572707176, 10.276045091450214, 0.20848234416916966, 0.0954636801907327, 0.11147723809699528, 0.024009150838537607, 0.017113519097620156, 0.024234036427515093, 0.036564079782692716, 0.08766942264628597, 0.022356189438141882, 0.017016661404340994, 0.06708600878482684, 0.04036792059196159, 0.032922594909905456, 0.020020680385641754, 0.02640998372953618, 0.02347382116568042, 0.04932865245791618, 0.0323674498940818, 0.037430073352879845, 0.0864561002526898, 0.060711090118275024, 0.02593917823105585, 0.007359139144682558, 0.061587288219016045, 0.029244446086522657, 0.0335455981985433, 0.05645770077535417, 0.02745260288065765, 0.031739296100568026, 0.22361571493092924, 0.1762804525787942, 0.14161007391521707, 0.15053904557134956, 0.12037376305670477, 0.11006432250724174, 0.17420650605345145, 0.16206670668907464, 0.23259872978087515, 0.13253231649287045, 0.16262064571492374, 0.16423909168224782, 0.1565057793050073, 0.22403283161111176, 0.16395694197854027, 0.12760641518980265, 0.1472468487918377, 0.122931278165197, 0.23403190600220114, 0.09949927145498805, 0.13968418585136533, 0.16215169744100422, 0.18811671354342252, 0.15305188338970765, 2.6522978162392974, 56.214977726340294, 96.44862860441208, 88.43751847743988, 80.61132922768593, 54.43849705159664, 49.6689435839653, 24.79086723178625, 50.30094847083092, 42.754507809877396, 46.16968095302582, 55.84912955760956, 39.95724990963936, 7.291006492450833, 0.6225226144306362, 0.2042635908583179, 0.26357469731010497, 0.3767756401794031, 0.7109619781840593, 3.9136938052251935, 8.323197830468416, 6.7433613538742065, 7.362964181229472, 7.214062996208668, 13.6167754791677, 15.178325437009335, 29.87441685050726, 50.31120412051678, 62.82738670706749, 65.75426325201988, 70.021031498909, 69.01663899421692, 71.6644737124443, 68.08380424976349, 69.78124916553497, 73.09067398309708, 72.42118030786514, 60.623018592596054, 65.10107830166817, 68.63269239664078, 68.4528936445713, 61.424182802438736, 51.14889197051525, 53.36378552019596, 64.29379642009735, 67.70122557878494, 68.74949052929878, 63.59152190387249, 68.04177090525627, 66.0898308455944, 69.63258594274521, 64.75411131978035, 66.98348209261894, 62.47370168566704, 66.47230312228203, 62.27862775325775, 66.83111786842346, 64.82200607657433, 69.6783658862114, 66.3250382244587, 67.88857832551003, 58.321740478277206, 65.15597775578499, 35.32221682369709, 40.91514050960541, 76.52970224618912, 63.7611486017704, 64.7486700117588, 57.21074089407921, 58.489349484443665, 50.087973698973656, 48.171272948384285, 51.5725502371788, 55.53478002548218, 54.27323251962662, 53.8701843470335, 50.09150370955467, 50.19239969551563, 52.15352386236191, 60.65268740057945, 65.54558604955673, 71.33367866277695, 72.32651218771935, 70.10385945439339, 61.34274177253246, 51.766241043806076, 53.40804174542427, 59.82244335114956, 67.49803528189659, 70.26095062494278, 62.8571505099535, 63.62926907837391, 63.01500163972378, 71.50845408439636, 76.15150853991508, 71.1532111465931, 69.61220383644104, 75.62806382775307, 60.10888338088989, 15.53516048938036, 3.4432365372776985, 9.027607832103968, 11.275927238166332, 3.6228982592001557, 1.3234860822558403, 0.6540109904017299, 0.2846890361979604, 0.1643625256838277, 0.33504562627058476, 0.23448682768503204, 0.13722328352741897, 5.468727350234985, 53.16417083144188, 62.63637475669384, 71.36035323143005, 19.897645600140095, 21.918741948902607, 55.85370071232319, 60.30230060219765, 76.30868330597878, 81.01816579699516, 82.6281926035881, 9.50030341744423, 0.4014280345290899, 0.18025788915110752, 0.2201147223240696, 0.14465114276390523, 0.11166978831170127, 0.08875679515767843, 0.184499055321794, 0.22571735840756446, 0.3051177196903154, 0.13089533167658374, 0.12238895375048742, 0.10429259549709968, 0.081301706522936, 0.17724882171023637, 0.2099225707934238, 0.13440398324746639, 0.1923032131162472, 0.15085263265063986, 0.21007294475566596, 0.21259399072732776, 0.1629379583755508, 0.15891925839241594, 0.11921620563953184, 0.09957278860383667, 0.09566406006342731, 0.14677905826829374, 0.09425046169781126, 0.07077339920215309, 0.1471688342280686], [0.038756235589971766, 0.021344543820305262, 0.07669486192753538, 0.027976616656815168, 0.1300957566127181, 0.02809477398841409, 0.018150820760638453, 0.06200218958838377, 0.049730462342267856, 0.04386820815852843, 0.03675137188110966, 0.017611826733627822, 0.007619594016432529, 0.05427032810985111, 0.0610546933603473, 0.04093435738468543, 0.019379806180950254, 0.039649106038268656, 0.06380904087563977, 0.06687223314656876, 0.07043560326565057, 0.06393251940608025, 0.04995914772734977, 0.03471711912425235, 12.070302162319422, 63.243547976017, 67.6934663951397, 65.94731569290161, 51.396916061639786, 24.772358424961567, 35.41051268577576, 46.72048419713974, 37.71600477397442, 55.02035602927208, 48.96030440926552, 32.96683721244335, 4.533211849629879, 0.31665680988226086, 0.07566146581666544, 0.03261826241214294, 0.09406888042576611, 0.23731475172098726, 0.6643626443110406, 1.573198945261538, 3.775015496648848, 2.688668752089143, 2.1880050050094724, 1.6846183477900922, 11.464203335344791, 38.966582268476486, 59.93031196296215, 67.6671414077282, 64.83500897884369, 66.84946328401566, 67.21949502825737, 63.826778680086136, 61.719229370355606, 58.92263263463974, 61.7386045306921, 64.98836874961853, 66.1327001452446, 60.500942543148994, 61.925007328391075, 61.019998490810394, 58.643222227692604, 52.30493053793907, 45.692092180252075, 46.733247712254524, 55.47651395201683, 60.99427007138729, 64.45602491497993, 59.827386885881424, 59.966425225138664, 58.850227519869804, 62.030808851122856, 59.46167550981045, 60.42151540517807, 60.76047241687775, 64.60436895489693, 60.45857481658459, 64.07761082053185, 59.052422270178795, 61.159971579909325, 59.38792526721954, 62.701172679662704, 57.90415808558464, 68.71608272194862, 28.22403620928526, 37.43042349815369, 68.37154760956764, 57.888255938887596, 63.42640936374664, 55.92158406972885, 61.57751217484474, 54.92986008524895, 52.967675775289536, 46.63997791707516, 46.112756207585335, 43.73692989349365, 45.68321965634823, 45.41967339813709, 46.854039430618286, 52.19266936182976, 58.83002020418644, 62.51578062772751, 63.25912334024906, 57.050989866256714, 64.4966447353363, 54.17876198887825, 48.0679526925087, 45.563944056630135, 51.38143569231033, 60.649989545345306, 61.709752678871155, 64.96934697031975, 62.207423374056816, 61.621779799461365, 65.61067655682564, 67.63504073023796, 65.4363115131855, 67.10648149251938, 66.10553920269012, 70.94211727380753, 60.7489400357008, 21.54325369745493, 1.307513639330864, 3.709172154776752, 0.7124434236902744, 2.5749653158709407, 0.7010196335613728, 0.10858053923584521, 0.13539926265366375, 0.020663469331339, 0.08710804730071686, 0.096466366230743, 0.033931173602468334, 3.841315289027989, 37.59251520037651, 30.648264326155186, 35.605681613087654, 27.760185599327087, 22.902091182768345, 39.95355650782585, 54.517787396907806, 61.814190074801445, 67.47482612729073, 41.903497874736786, 2.27961381431669, 0.4472925531445071, 0.030873003815941047, 0.06270550438784994, 0.09704515978228301, 0.0289308274659561, 0.030153747684380505, 0.018937046443170402, 0.10653135075699538, 0.07130003461497836, 0.021941434642940294, 0.01561070530442521, 0.00971962332187104, 0.03227785782655701, 0.07771747463266365, 0.04775123241415713, 0.048765855899546295, 0.05130787496455014, 0.04976952157448977, 0.029279779737407807, 0.005105333129904466, 0.03743950233911164, 0.054842048994032666, 0.08272364662843756, 0.03872905443131458, 0.04639015955035575, 0.03475269397313241, 0.08772545479587279, 0.055382325081154704, 0.048004954151110724, 0.007423242150252918, 0.050299990180064924, 0.02703650294279214, 0.05273482085613068, 0.09044054269907065, 0.023248204561241437, 0.05882574929273687, 0.059459832846187055, 0.028195054837851785, 0.0831412457046099, 0.08715772666619159, 0.09310787339927629, 0.07441174850100651, 0.028650688982452266, 0.015237044153764145, 0.03310076230263803, 0.03923801559722051, 0.03800595768552739, 0.049263536420767196, 0.018140128267987166, 0.05645990124321543, 0.10345745671656914, 0.047131479732342996, 17.53491908311844, 79.26166445016861, 76.06630191206932, 73.48709911108017, 63.17716933786869, 41.67193070054054, 45.413251742720604, 36.05587765574455, 36.18596367537975, 44.184865057468414, 41.2559974193573, 28.29377956688404, 3.9987980760633945, 0.32935166149400175, 0.08537801943020895, 0.04879205742327031, 0.251347161247395, 0.5884398682974279, 1.4379098173230886, 2.7648663008585572, 4.216548716649413, 3.86081513017416, 2.0374053111299872, 2.047742181457579, 12.05477524548769, 40.68751372396946, 63.257272839546204, 70.90887665748596, 67.58886560797691, 68.24088022112846, 69.77757096290588, 66.60838142037392, 65.23771896958351, 62.40221232175827, 63.01635056734085, 68.71566474437714, 69.29448768496513, 60.87785191833973, 62.528787329792976, 62.77413256466389, 63.18474993109703, 56.3623908162117, 47.457561045885086, 47.601615116000175, 57.67802841961384, 63.67364689707756, 67.71424368023872, 61.19641162455082, 60.68230301141739, 60.9428284317255, 63.94062057137489, 63.49240802228451, 63.35112780332565, 62.75104120373726, 66.81178450584412, 62.32975780963898, 66.1989913880825, 61.66591823101044, 64.25484851002693, 60.283586606383324, 65.37325009703636, 60.312031880021095, 67.66181409358978, 30.452854111790657, 38.78550298511982, 71.25557005405426, 59.5147168636322, 64.8437637090683, 59.20331597328186, 64.8240427672863, 55.98483547568321, 54.52420525252819, 48.63055430352688, 47.917910143733025, 45.930293798446655, 48.77055399119854, 47.97687537968159, 48.1227495521307, 53.71666498482227, 61.92085035145283, 66.49931207299232, 64.92678925395012, 61.4918115735054, 67.17148840427399, 56.748491898179054, 50.069879069924355, 47.9058001935482, 54.589329957962036, 63.69404800236225, 66.03972673416138, 66.98352009057999, 63.59040856361389, 63.28403100371361, 69.03841942548752, 70.26562437415123, 66.67797088623047, 70.69028198719025, 67.0350681245327, 72.8501544892788, 66.26937121152878, 25.120936520397663, 2.0870159240439534, 3.2205145759508014, 0.4280545120127499, 2.5625547068193555, 3.1910602189600468, 1.156104113906622, 0.45364952296949923, 0.13290272239828482, 0.08131640846841037, 0.16986287897452712, 0.030457948450930417, 4.559819921851158, 39.96939405798912, 33.16195674240589, 21.258065700531006, 28.27084019780159, 37.98153832554817, 47.14156240224838, 63.32248114049435, 64.74673971533775, 73.56165871024132, 59.83318917453289, 5.116187492385507, 0.5627623305190355, 0.04042220127303153, 0.08424298619502224, 0.026203675952274352, 0.14114654331933707, 0.044370000177877955, 0.025210179555870127, 0.08479245749185793, 0.03990881690697279, 0.035407127215876244, 0.02337269797862973, 0.017829053358582314, 0.015521311761403922, 0.021837947715539485, 0.026539870705164503, 0.03300384523754474, 0.024148041920852847, 0.055587855458725244, 0.06314648853731342, 0.013623398954223376, 0.05386307086155284, 0.030367150393431075, 0.14154702104860917, 0.031001896313682664, 0.07088455065968446, 0.03898448310792446, 0.07957943409564905, 0.08846279335557483, 0.12754912138916552, 0.11109196697361767, 0.18952899088617414, 0.12922410416649655, 0.19229607365559787, 0.17066978645743802, 0.1065207232022658, 0.21651106100762263, 0.1718540018191561, 0.10769783621071838, 0.19563843961805105, 0.16664102295180783, 0.18504468229366466, 0.15849292423808947, 0.14067447802517563, 0.11264036904321983, 0.1014631352154538, 0.14766776526812464, 0.17891264258651063, 0.20315983914770186, 0.09946358157321811, 0.15105290862265974, 0.26711866026744246, 0.19655120704555884, 26.7995610460639, 94.01849940419197, 86.24179109930992, 86.34478077292442, 70.17522722482681, 38.62548977136612, 48.28090086579323, 59.37223210930824, 54.99892517924309, 71.58859178423882, 63.64616297185421, 45.69664053618908, 7.2446157317608595, 0.6227073795162141, 0.3025399142643437, 0.10054232290713117, 0.5643944616895169, 0.6064394430723041, 2.6776650175452232, 4.3640482518821955, 11.158243753015995, 9.999452233314514, 6.3364236149936914, 4.334311047568917, 13.704511821269989, 43.6761711537838, 65.99709302186966, 73.21590006351471, 68.54683980345726, 70.49251019954681, 74.55138400197029, 69.57673653960228, 66.36082470417023, 64.48244869709015, 66.63293570280075, 72.56553456187248, 69.06443282961845, 61.23591050505638, 63.70722949504852, 65.44586420059204, 63.29837903380394, 58.132134452462196, 50.51245652139187, 51.8609319627285, 60.00995188951492, 66.88459619879723, 68.54955285787582, 61.18073366582394, 62.78349906206131, 62.23255142569542, 66.46187648177147, 65.89588165283203, 63.88872295618057, 66.16848662495613, 69.29508045315742, 64.9421252310276, 68.21796745061874, 65.22929862141609, 66.24073594808578, 63.98093640804291, 66.53064519166946, 63.94216328859329, 68.66382792592049, 35.078642293810844, 43.83748009800911, 71.92087635397911, 61.63091450929642, 67.47220426797867, 63.38817961513996, 67.81149566173553, 60.25112874805927, 58.59813764691353, 52.22041167318821, 51.114370822906494, 49.084196761250496, 50.50471633672714, 50.88089235126972, 50.225252732634544, 59.03449863195419, 65.6858441233635, 66.30824312567711, 68.43425944447517, 62.75274731218815, 70.29907777905464, 58.95487390458584, 52.45877668261528, 52.76178002357483, 56.42385631799698, 67.24830508232117, 68.79097670316696, 68.01219329237938, 63.496625795960426, 64.54820036888123, 71.04416459798813, 74.46865484118462, 69.13082286715508, 72.84272208809853, 70.11671036481857, 76.4161491394043, 68.58753561973572, 27.593104764819145, 6.239272803068161, 12.610635068267584, 4.710517935454845, 6.613791631534696, 3.1856184359639883, 1.005144389346242, 0.49742816132493317, 0.2056625095428899, 0.27041073830332607, 0.42132916976697743, 0.14058926462894306, 7.887279521673918, 54.474317729473114, 45.69469504058361, 54.24014009535313, 40.713895708322525, 36.59741319715977, 53.940263986587524, 74.59413170814514, 74.8510891199112, 83.72758001089096, 67.38629847764969, 4.941565012559295, 0.7390701386611909, 0.19917398662073538, 0.17752157582435757, 0.17810359771829098, 0.33915578853338957, 0.13076811272185296, 0.1053058571415022, 0.22793790878495201, 0.2210390820982866, 0.1196687895571813, 0.10651503092958592, 0.15810546377906576, 0.0781014321546536, 0.18024027056526393, 0.14504109683912247, 0.1307817385531962, 0.1261767715914175, 0.17040464677847922, 0.1920179760782048, 0.13059388613328338, 0.1385648935684003, 0.196676347986795, 0.29091331001836807, 0.20720454398542643, 0.21036972961155698, 0.12088214163668454, 0.1501010448555462, 0.15912814327748492], [0.017214985527971294, 0.08180955075658858, 0.01949349021742819, 0.10611834557494149, 0.03407019641599618, 0.023202456723083742, 0.03150007592921611, 0.01818610431655543, 0.07834112358978018, 0.02126549767126562, 0.02324680746824015, 0.040092632043524645, 0.04822807342861779, 0.035454936369205825, 0.03007444363902323, 0.09515390775050037, 0.010620369812386343, 0.09610551176592708, 0.0324752765300218, 0.03428338204685133, 0.0636801595101133, 0.03005298629432218, 0.06948876383830793, 1.6852212091907859, 45.579679012298584, 69.1083736717701, 64.64613631367683, 55.07570765912533, 45.82060508430004, 13.3035459369421, 30.52257277071476, 57.807134091854095, 37.19320982694626, 38.87211933732033, 37.148908004164696, 4.113983195275068, 0.09836731813265942, 0.039908215767354704, 0.024864229271770455, 0.09450770492549054, 0.08342677218024619, 0.8816411008592695, 1.824884614907205, 1.336323218420148, 2.1108950302004814, 2.2921265428885818, 4.567963359877467, 23.410564698278904, 53.73060643672943, 68.012033700943, 67.18769073486328, 66.28425881266594, 66.16132020950317, 64.78286057710648, 62.458460703492165, 61.253784745931625, 54.168639332056046, 57.81748853623867, 61.86197251081467, 64.04269069433212, 62.25935898721218, 60.97428694367409, 65.44046089053154, 60.609890297055244, 56.26062087714672, 49.00615654885769, 45.73425091803074, 48.365054950118065, 55.32493628561497, 60.20718030631542, 62.81310707330704, 60.873022377491, 60.72133831679821, 59.917882829904556, 61.60108610987663, 63.14978800714016, 61.27303071320057, 60.74337713420391, 61.18165701627731, 58.361022770404816, 59.8215351998806, 57.13635228574276, 59.07330974936485, 54.44924287497997, 63.745349049568176, 57.29017183184624, 68.59748348593712, 34.51832436025143, 37.68310993909836, 67.67030283808708, 55.92344217002392, 65.16432210803032, 62.346176728606224, 62.49599128961563, 59.486917555332184, 57.36923798918724, 55.72349689900875, 53.049196600914, 49.50168035924435, 47.78043732047081, 44.09181945025921, 48.41700576245785, 53.57740245759487, 63.01543861627579, 64.84621837735176, 60.597757548093796, 60.71123085916042, 61.03236682713032, 45.192073211073875, 46.45721152424812, 47.39519499242306, 54.42053161561489, 60.53101412951946, 65.8586360514164, 58.37633214890957, 61.60243883728981, 59.88520458340645, 68.65217015147209, 66.38904199004173, 64.27826285362244, 56.731050834059715, 64.05954658985138, 66.7038094997406, 68.26574608683586, 62.049621641635895, 25.508975498378277, 2.712952299043536, 1.4687229576520622, 1.667073976714164, 1.6433930536732078, 1.1757123679853976, 0.916024565231055, 0.09368976912810467, 0.012625187137018656, 0.03422745750867762, 0.03944887459510937, 0.2522529673296958, 14.636143930256367, 45.70435032248497, 47.285559475421906, 25.678368508815765, 12.323484476655722, 24.479795023798943, 39.67559762299061, 50.76423101127148, 60.17533801496029, 66.7196698486805, 31.770243421196938, 2.665064656175673, 0.457952109281905, 0.13396648719208315, 0.09176532825222239, 0.02415925762761617, 0.04342904969234951, 0.11077270988607779, 0.048050317927845754, 0.04255066596670076, 0.015621353268215898, 0.00513809848598612, 0.018549808628449682, 0.0876584165962413, 0.036006196241942234, 0.01618199203221593, 0.0641821556200739, 0.09181033950881101, 0.06489003091701306, 0.0541132377111353, 0.02423156693112105, 0.02747758542682277, 0.029011706719757058, 0.053828843010705896, 0.026464416550879832, 0.07174968704930507, 0.02497199096978875, 0.02039070222963346, 0.09071685912203975, 0.0423489687818801, 0.025450837638345547, 0.08370357099920511, 0.006805967313994188, 0.026784662550198846, 0.050349565644864924, 0.013633898488478735, 0.030742203998670448, 0.011836637604574207, 0.013165052259864751, 0.01842142821260495, 0.016976110455289017, 0.07924213539808989, 0.03432630415773019, 0.03325079487694893, 0.09322201571194455, 0.01873808778327657, 0.08913897152524441, 0.040194536341005005, 0.056513217132305726, 0.060441490131779574, 0.06480140364146791, 0.031206719795591198, 2.355011743493378, 57.3396185785532, 79.69696149230003, 73.0479870736599, 64.98864993453026, 52.74960547685623, 22.353573516011238, 40.78408934175968, 52.048045322299004, 41.363406255841255, 47.747375294566154, 34.07389260828495, 4.066000794991851, 0.04774581844685599, 0.053144668199820444, 0.17754578468156978, 0.18386771029327065, 0.9162757080048323, 2.631522906012833, 3.7111314246430993, 2.414729814045131, 1.9747784966602921, 1.4288033684715629, 5.2348988223820925, 25.979382656514645, 56.75335183739662, 70.13682648539543, 69.5168137550354, 68.2933022081852, 68.6273954808712, 66.57778546214104, 64.50523987412453, 63.094550371170044, 56.54597416520119, 59.74845752120018, 65.3726877272129, 65.80820515751839, 63.67567978799343, 62.776454240083694, 66.48383930325508, 61.995212361216545, 59.06855620443821, 50.37755995988846, 47.352967858314514, 50.920288637280464, 58.57927545905113, 63.421161845326424, 64.50894087553024, 61.726175397634506, 61.40189319849014, 60.320889204740524, 63.39097626507282, 63.99488165974617, 63.37301082909107, 61.419319063425064, 63.60121138393879, 62.69797705113888, 62.04916946589947, 58.21892559528351, 61.46204017102718, 57.19544671475887, 64.66033235192299, 61.5569818764925, 68.12649115920067, 36.14761233329773, 39.581799656152725, 67.01658591628075, 59.92461986839771, 69.38572078943253, 64.78989779949188, 64.04680207371712, 62.73366093635559, 61.42624609172344, 56.719628646969795, 55.048402324318886, 50.97070813179016, 50.78811652958393, 47.118505239486694, 49.89117085933685, 56.143978536129, 65.6196440756321, 65.28621196746826, 63.20544742047787, 63.80408629775047, 63.742525801062584, 48.10995563864708, 49.1468857973814, 49.2694254219532, 56.70960858464241, 63.568270951509476, 69.60660293698311, 57.52536401152611, 61.36460579931736, 63.71165245771408, 69.34336826205254, 68.31056848168373, 67.42884859442711, 58.96649368107319, 66.65546849370003, 69.45942163467407, 71.41963765025139, 66.12483456730843, 28.203350119292736, 2.655139113776386, 0.9808386967051774, 1.6264783800579607, 2.759828008711338, 2.1438879473134875, 1.489392661023885, 0.29299420304596424, 0.280424477532506, 0.06631431620917283, 0.13346794206881896, 0.2851298719178885, 14.192013312131166, 46.72914773225784, 41.92319221794605, 28.68272289633751, 20.70924025028944, 36.28602750599384, 48.01945969462395, 58.08546915650368, 66.49215325713158, 77.42263913154602, 51.79232284426689, 4.637340987101197, 0.34707049664575607, 0.027626797927950975, 0.05027713574236259, 0.0721117363718804, 0.01716415397822857, 0.06099281679780688, 0.04473583816434257, 0.1311833443469368, 0.04556866144412197, 0.038553284175577573, 0.042587209318298846, 0.057633099422673695, 0.05982203801977448, 0.04140927623666357, 0.008323915353685152, 0.07779499937896617, 0.05672344901540782, 0.028846714303654153, 0.02911544968810631, 0.017650950903771445, 0.07842491948395036, 0.00828288757475093, 0.03276016104791779, 0.0302212070528185, 0.014700926876685116, 0.04303479116060771, 0.08917118073441088, 0.16417492559412494, 0.2630449226126075, 0.19231562182540074, 0.1993598203989677, 0.15224997798213735, 0.09930597909260541, 0.12677087564952672, 0.1305945243802853, 0.09308419888839126, 0.12701035186182708, 0.1262905725161545, 0.14083656307775527, 0.17056673183105886, 0.10685693836421706, 0.19166930025676265, 0.24985452415421605, 0.14019148831721395, 0.27648402960039675, 0.10156241231015883, 0.17719595110975206, 0.22599814255954698, 0.14776026655454189, 0.22199161379830912, 2.997290091589093, 68.7460707128048, 88.51612105965614, 85.36130994558334, 73.55947762727737, 60.45456983149052, 22.12074100971222, 40.593328177928925, 68.14425140619278, 50.86239114403725, 54.456910863518715, 49.58461470901966, 6.777330106124282, 0.2867519692517817, 0.2267608922556974, 0.3046430420363322, 0.38422448735218495, 0.5697327596135437, 2.6840757485479116, 5.760888922959566, 6.628579488024116, 9.099147543311119, 9.023525901138783, 9.00772824883461, 30.843057073652744, 57.42263652384281, 73.56522291898727, 72.44929879903793, 72.08761140704155, 70.08899465203285, 69.03381407260895, 67.79878914356232, 66.94398701190948, 60.95487758517265, 62.95568682253361, 67.31884449720383, 67.35298946499825, 64.44687500596046, 62.92099088430405, 67.01547637581825, 64.85236644744873, 61.198972687125206, 53.91089156270027, 50.05789451301098, 54.374341294169426, 61.24773547053337, 65.84086060523987, 67.57344603538513, 62.01860770583153, 62.65806019306183, 63.80980119109154, 65.70867329835892, 67.91786715388298, 65.01336380839348, 63.62342119216919, 65.71169793605804, 64.10677805542946, 65.38704335689545, 63.07388328015804, 63.86160001158714, 60.23689091205597, 68.4943038225174, 65.56326270103455, 67.78787612915039, 39.45361353456974, 43.35300989449024, 69.13034409284592, 62.45396934449673, 69.0032409131527, 69.35272336006165, 66.71653881669044, 64.66869190335274, 63.47646027803421, 60.99931240081787, 59.01466749608517, 55.70937305688858, 53.58300715684891, 48.249685540795326, 53.13560776412487, 59.082110077142715, 68.91061708331108, 67.32338145375252, 65.15603095293045, 68.45384359359741, 67.28475272655487, 50.786250829696655, 50.74415288865566, 51.913775727152824, 60.29065042734146, 66.71768635511398, 72.02088698744774, 58.857808113098145, 60.662680864334106, 64.52689111232758, 72.07539886236191, 72.12655931711197, 70.09008899331093, 59.6257621049881, 69.35827106237411, 73.13057944178581, 74.40815448760986, 67.7120853960514, 29.799249283969402, 7.326565934345126, 8.714716471731663, 9.445026833564043, 6.549615450203419, 2.694851257838309, 3.100816961377859, 0.7096952805295587, 0.1776811821036972, 0.15837615472264588, 0.3509399952599779, 0.5965773691423237, 22.52923049032688, 68.60720336437225, 65.33179432153702, 39.44796323776245, 22.285783253610134, 38.24642971158028, 53.5581336915493, 70.98466739058495, 73.8672611117363, 87.0335242152214, 56.558114513754845, 4.708771454170346, 0.5723375792149454, 0.17527236370369792, 0.11805930131231435, 0.1401372966938652, 0.13666216051205993, 0.14677000406663865, 0.13002182386117056, 0.19042225467273965, 0.1553123167832382, 0.12271643383428454, 0.13490252837073058, 0.17522203124826774, 0.1782180814188905, 0.11690226339851506, 0.1506491654436104, 0.18777127348585054, 0.13926050858572125, 0.12570019403938204, 0.17879894556244835, 0.07319205848034471, 0.18151318741729483, 0.15642936778021976, 0.2030190240475349, 0.134473210782744, 0.335568068549037, 0.15756233042338863, 0.1395121857058257], [0.033841837575891986, 0.046286540891742334, 0.0287755052340799, 0.06015735889377538, 0.030429208782152273, 0.027760436460084748, 0.0309460274365847, 0.035325606004334986, 0.012045870371366618, 0.010677150603441987, 0.021476288020494394, 0.030882056162226945, 0.04571297577058431, 0.06899342479300685, 0.028821421910834033, 0.04134190778131597, 0.04700563004007563, 0.06060888154024724, 0.025257626912207343, 0.05952675601292867, 0.01683594844507752, 0.11150581820402294, 0.06678478588582948, 16.71429231762886, 72.7450293302536, 71.32356360554695, 72.05367162823677, 56.71569585800171, 39.79299612343311, 32.05172471702099, 24.56021010875702, 29.97639387845993, 36.423534527421, 36.31181672215462, 7.714464319869876, 0.10075605401652865, 0.12917593878228217, 0.04548839446215425, 0.0755202944856137, 0.2958079520612955, 0.7342404196970165, 1.7872165236622095, 1.091486206278205, 1.6558651719242334, 0.9474348078947514, 7.464701822027564, 30.54513406008482, 56.260316893458366, 70.88357001543045, 64.43400889635086, 63.80783289670944, 61.68585196137428, 64.6052885055542, 61.12815208733082, 58.57076771557331, 50.423434898257256, 54.32707563042641, 59.15771082043648, 63.41288208961487, 63.938743472099304, 59.1875734180212, 60.68151645362377, 63.65162707865238, 57.50753536820412, 54.963917657732964, 42.539192363619804, 48.32930266857147, 48.70914168655872, 57.68275536596775, 57.70349845290184, 63.566435649991035, 58.48523050546646, 61.35043255984783, 62.50525139272213, 61.687877252697945, 58.97080644965172, 59.92324814200401, 56.91393882036209, 56.9713119417429, 53.142223209142685, 56.40567049384117, 52.04903706908226, 56.953688487410545, 50.23411385715008, 60.032876059412956, 53.98983612656593, 70.50367400050163, 32.238674685359, 37.94984042644501, 66.63976773619652, 56.31032221019268, 62.23777614533901, 53.861972987651825, 60.62106929719448, 58.5222215205431, 66.01689755916595, 58.94749090075493, 58.195564448833466, 52.55969546735287, 52.40080699324608, 50.54940193891525, 56.88511736690998, 56.84626445174217, 62.60151542723179, 59.760457277297974, 52.96766437590122, 59.98804226517677, 53.709076792001724, 45.977080687880516, 47.510598599910736, 50.08374832570553, 56.889133751392365, 60.23839943110943, 62.44199238717556, 57.89107158780098, 60.013580694794655, 66.82468101382256, 62.55369499325752, 64.69139948487282, 61.88547044992447, 57.20834322273731, 55.25256156921387, 62.76063568890095, 67.33440086245537, 69.55613404512405, 67.97195345163345, 35.08978709578514, 1.4296275679953396, 0.10002864539274015, 4.146282412111759, 1.9687312399037182, 1.4328909991309047, 0.7943827018607408, 0.0519080572121311, 0.08609557975432836, 0.01950565772858681, 0.11767120260628872, 0.9021405852399766, 24.12668377161026, 38.077008202672005, 39.44494619965553, 28.48374467343092, 16.265399605035782, 33.319450691342354, 53.00067700445652, 56.12684145569801, 62.469882890582085, 63.561169132590294, 28.66728812456131, 1.6371961799450219, 0.42096709075849503, 0.09506756628979929, 0.04790540617250372, 0.050398992680129595, 0.07695495500229299, 0.05895742113352753, 0.01399366292389459, 0.0169928458853974, 0.046022507012821734, 0.0502482958836481, 0.008482660741719883, 0.05150720098754391, 0.012591381382662803, 0.01818246593757067, 0.12045328418025747, 0.06594779915758409, 0.022694057734042872, 0.01864878329797648, 0.053110863373149186, 0.028660565112659242, 0.11352501649525948, 0.018720469197432976, 0.04370519542135298, 0.012433086849341635, 0.03713921825692523, 0.045994290558155626, 0.05111603721161373, 0.03942160066799261, 0.02999187785462709, 0.02160858883144101, 0.037344500015024096, 0.04636605459381826, 0.035917535569751635, 0.037722279157605954, 0.04829924168006983, 0.01340172686468577, 0.06759864729247056, 0.0070902729567023925, 0.007034594718788867, 0.054481294719153084, 0.0404030427307589, 0.03787323941651266, 0.02352795341721503, 0.019983135134680197, 0.03753607059479691, 0.0459282765223179, 0.0235426776271197, 0.07081809875671752, 0.035492210736265406, 21.70517060905695, 85.95168426632881, 77.75057673454285, 80.46183004975319, 63.329408168792725, 52.324320897459984, 29.715608172118664, 25.96624296158552, 25.10156325995922, 30.232201851904392, 36.897825077176094, 6.792267579585314, 0.14872035331791267, 0.08622155190096237, 0.13760229834588245, 0.14448785543208942, 0.8760767744388431, 3.020421350374818, 4.693955574184656, 3.4605785692110658, 1.9483025860972703, 0.8846274437382817, 6.68738940730691, 30.728058144450188, 59.55573186278343, 73.22776302695274, 68.55344384908676, 66.45670875906944, 63.369678407907486, 67.39038705825806, 65.36931350827217, 60.2784226834774, 51.98683820664883, 55.82135684788227, 63.533643409609795, 66.36858388781548, 66.12063959240913, 59.37712624669075, 61.92824475467205, 66.33527487516403, 59.74918708205223, 56.76168479025364, 45.356596782803535, 49.87904950976372, 51.39613710343838, 60.374914705753326, 60.35830579698086, 65.59419304132462, 58.55877175927162, 62.56338067352772, 63.41456159949303, 63.19613792002201, 62.27110035717487, 62.445169016718864, 58.57335917651653, 59.0864722430706, 55.96506893634796, 60.13790242373943, 54.21120844781399, 58.67018178105354, 52.90961869060993, 61.209726110100746, 57.58703090250492, 71.43424406647682, 35.4180970788002, 39.12641689181328, 67.0703150331974, 58.56734409928322, 64.6947281062603, 56.33621782064438, 62.51352734863758, 59.70685355365276, 66.83177903294563, 62.59994611144066, 61.423829421401024, 55.678590908646584, 55.34278392791748, 53.391239047050476, 57.46465466916561, 59.382404163479805, 64.12674218416214, 62.238156124949455, 55.66027969121933, 62.09632493555546, 56.520279943943024, 47.21156984567642, 50.61690151691437, 53.12839575111866, 59.70093347132206, 62.904260382056236, 65.45859351754189, 58.61845135688782, 59.64283838868141, 68.54485630989075, 66.35080844163895, 67.63903051614761, 64.32460516691208, 59.81070198118687, 57.89124257862568, 64.67971131205559, 70.58148622512817, 70.71406111121178, 71.46455883979797, 40.500134378671646, 2.5831087538972497, 0.43070676969364285, 2.9327944898977876, 3.6411432176828384, 2.1675191167742014, 1.9499747338704765, 0.7559477642644197, 0.5697102576959878, 0.17134957888629287, 0.06932095682714134, 0.9106892952695489, 27.053955495357513, 36.67280875146389, 32.94141657650471, 21.666520982980728, 21.62017486989498, 46.35992154479027, 60.350147634744644, 66.29987597465515, 65.63632518053055, 71.9764293730259, 44.798608124256134, 3.223478654399514, 0.27900344284716994, 0.1443878881400451, 0.06704050771077164, 0.04207186197163537, 0.06064758825232275, 0.024580777098890394, 0.05120375906699337, 0.012585456261149375, 0.03563710764865391, 0.023539477115264162, 0.10109002047101967, 0.023467564860766288, 0.008133441297104582, 0.07928404447739013, 0.1231840907712467, 0.05712699923606124, 0.005592506231550942, 0.044919883366674185, 0.08096545425360091, 0.05264685409201775, 0.06647688365774229, 0.06961770457564853, 0.05883959405764472, 0.01166337951872265, 0.014021408114786027, 0.03059750746615464, 0.12095493890228681, 0.13631888752570376, 0.16010526975151151, 0.11880549369379878, 0.13325657841050997, 0.18906191282439977, 0.17858048697235063, 0.1293397753033787, 0.08689217880601063, 0.10101015053805895, 0.19608334230724722, 0.15814736543688923, 0.10709296358982101, 0.14953978825360537, 0.08500999581883661, 0.12582144612679258, 0.1401516646728851, 0.11692277636029758, 0.20170491799945012, 0.2261649922002107, 0.148086158442311, 0.2887198480311781, 0.17648359324084595, 27.9387741163373, 96.24260365962982, 88.44256460666656, 90.61240017414093, 72.37727746367455, 55.40935255587101, 44.08879101276398, 32.60153241455555, 41.434519439935684, 48.75209458172321, 51.873216703534126, 11.436987295746803, 0.2883296267827973, 0.33505485858768225, 0.2765225322218612, 0.3188920399406925, 0.6828853441402316, 2.9034569766372442, 5.205368706956506, 5.903284857049584, 8.151644635945559, 5.71863804012537, 10.85379458963871, 35.0583665817976, 59.797125309705734, 76.58397853374481, 70.5960014462471, 68.25906604528427, 66.59917071461678, 69.99507889151573, 66.90282002091408, 63.61283876001835, 54.3927551060915, 58.34884822368622, 66.43430516123772, 66.89097225666046, 67.68165662884712, 58.79790432751179, 62.778848111629486, 69.57307353615761, 62.26537026464939, 60.92367745935917, 46.66158735752106, 52.94274151325226, 53.98168936371803, 64.05789747834206, 62.82026968896389, 67.27621838450432, 59.58606943488121, 63.28191451728344, 66.33417293429375, 64.52224016189575, 64.72476169466972, 64.68247756361961, 60.87497167289257, 60.981042981147766, 58.95742356777191, 64.07635688781738, 58.03836688399315, 62.386420369148254, 54.86196152865887, 65.27592971920967, 59.605942368507385, 74.07305806875229, 42.06340469419956, 43.06349962949753, 67.3367415368557, 59.393054991960526, 66.29128843545914, 59.023635014891624, 64.20964613556862, 61.22155487537384, 70.52631318569183, 64.49873462319374, 63.24974164366722, 59.17254902422428, 56.74639441072941, 56.51017628610134, 61.249342784285545, 62.07169845700264, 66.94789320230484, 62.5591666996479, 58.94363030791283, 65.8997194468975, 58.09930041432381, 51.61888115108013, 52.70230561494827, 54.66357797384262, 62.25144401192665, 67.42605954408646, 66.78342282772064, 60.60686185956001, 60.205519795417786, 68.00188064575195, 68.04336681962013, 71.08027786016464, 67.462028414011, 63.00809361040592, 59.59784120321274, 68.4378844499588, 74.01473879814148, 73.29251915216446, 73.56954708695412, 42.6972296833992, 2.284034164622426, 5.824782494455576, 13.07940736413002, 6.383320223540068, 4.621377093717456, 2.091409913264215, 0.4919616796541959, 0.5190456169657409, 0.18076865002512932, 0.26786089700181037, 1.6481954022310674, 37.48669847846031, 54.28689658641815, 53.249533250927925, 41.83845676481724, 28.103174194693565, 49.01415511965752, 67.47191548347473, 74.65733751654625, 76.92434147000313, 80.42049586772919, 49.089512676000595, 3.007800802588463, 0.5031177029013634, 0.3353011922445148, 0.1590992440469563, 0.07175992868724279, 0.20974268903955817, 0.16933433624217287, 0.15482628426980227, 0.1662216056138277, 0.09943422963260673, 0.10149766734684817, 0.21428537496831268, 0.1429658886627294, 0.12718039273750037, 0.21900997613556683, 0.22727613570168614, 0.16601233481196687, 0.12590125668793917, 0.13963487755972892, 0.13267476431792602, 0.15111223590793088, 0.2503477851860225, 0.1612458171439357, 0.20074453437700868, 0.12722178973490372, 0.10160140474908985, 0.20839858538238332], [0.04145538587181363, 0.03369977195688989, 0.02239977206045296, 0.07256203447468579, 0.039244572471943684, 0.026451323210494593, 0.02464532539306674, 0.023755692564009223, 0.03958448724006303, 0.012246669557498535, 0.024454686208628118, 0.029830050698365085, 0.05196038604481146, 0.009131154019996757, 0.029250169900478795, 0.060906007784069516, 0.0925732524774503, 0.03376440188731067, 0.017312275522272103, 0.007447149973813794, 0.09484311114647426, 0.030795217462582514, 0.39715920109301805, 31.06478277593851, 67.80706509947777, 62.27385140955448, 59.05815616250038, 57.87334553897381, 31.001561768352985, 27.95749571174383, 44.27151940762997, 55.88392049074173, 76.46598726511002, 22.584948800504208, 0.5780068156309426, 0.04234998923493549, 0.049285192289971747, 0.08691481431014836, 0.09267338304198347, 0.12182325910544023, 2.712219413369894, 3.713694862090051, 3.241906715556979, 0.9275207889731973, 9.213915634900331, 33.946040868759155, 57.3886663466692, 72.92950183153152, 63.97225767374039, 61.63929305970669, 60.73576234281063, 60.802532359957695, 57.78076350688934, 55.61172969639301, 47.99997813999653, 52.83893868327141, 58.95748816430569, 61.838303580880165, 61.36224612593651, 62.76929922401905, 58.53280395269394, 60.89031144976616, 64.12051051855087, 56.933389976620674, 50.52764430642128, 43.79692107439041, 46.73028767108917, 52.05432638525963, 57.75248162448406, 59.59665186703205, 62.30823576450348, 59.74781155586243, 62.68726922571659, 59.222656935453415, 55.88780388236046, 55.023935437202454, 54.87738870084286, 52.68788158893585, 55.40048003196716, 55.741739720106125, 52.25407786667347, 51.002071648836136, 49.67531964182854, 50.418358370661736, 57.93114423751831, 57.97052912414074, 57.694891914725304, 25.740231089293957, 35.29834270477295, 61.83057479560375, 55.667951479554176, 56.8100979924202, 54.46169100701809, 55.86404375731945, 51.21260315179825, 60.20651154220104, 57.151353880763054, 61.14144757390022, 59.47071522474289, 56.68307080864906, 54.49909619987011, 60.0328304618597, 60.0949115306139, 62.75484099984169, 54.47988823056221, 56.79091662168503, 60.70107780396938, 52.15826980769634, 44.21643756330013, 47.09239684045315, 56.21891811490059, 61.49096041917801, 60.214882493019104, 60.090689957141876, 55.376446321606636, 61.18158861994743, 60.28545990586281, 61.607845947146416, 63.34458075463772, 56.44448161125183, 55.299610644578934, 53.712754994630814, 54.569039046764374, 62.52610467374325, 67.37309038639069, 65.58297604322433, 68.6262859404087, 40.470712557435036, 1.6196095361374319, 1.5562376054003835, 3.4384088963270187, 0.21535120293265209, 0.5010537605267018, 0.8333232498262078, 0.09942025499185547, 0.07403522729873657, 0.11446852367953397, 0.12277971676667221, 4.829376507550478, 39.39618721604347, 47.66966946423054, 47.98020400106907, 21.731089018285275, 16.628800705075264, 34.72871907055378, 46.93683698773384, 50.84264360368252, 59.90367919206619, 65.41991159319878, 24.218256957829, 1.3201928464695811, 0.3509829507675022, 0.05430739467556123, 0.03832262838841416, 0.041794072385528125, 0.11928843887289986, 0.08215918394853361, 0.031038365450513083, 0.15849679824896157, 0.0646357265941333, 0.04048283844895195, 0.05238985577307176, 0.031293128049583174, 0.05297338422678877, 0.035738844962907024, 0.0264928630713257, 0.03365416327142157, 0.01711299773887731, 0.058749920353875495, 0.05516489065485075, 0.05248112138360739, 0.05728108393668663, 0.026104272692464292, 0.05066618068667594, 0.032146200828719884, 0.019095981078862678, 0.037402795715024695, 0.012272610401851125, 0.034375319301034324, 0.062391234532697126, 0.009491187483945396, 0.04794980144652072, 0.05458435676700901, 0.002588875254332379, 0.021893107841606252, 0.03738523279025685, 0.04517771289101802, 0.019086702377535403, 0.040743629142525606, 0.009833730382524664, 0.009142468061327236, 0.04887747491011396, 0.03213010364561342, 0.0180712903602398, 0.021555506718868855, 0.05543315477552824, 0.042241913979523815, 0.04186077661870513, 0.6465912947896868, 43.73225994408131, 78.80505055189133, 69.5087505877018, 67.1535761654377, 65.84905296564102, 40.85552930831909, 29.576528035104275, 39.63522858917713, 59.3249474465847, 60.943345203995705, 22.284675613045692, 0.7135480956640095, 0.054713078570785, 0.11214557918719947, 0.07988485755049624, 0.42551428894512355, 1.776901502162218, 5.415693121030927, 3.8061301270499825, 2.1590431965887547, 0.43813284777570516, 9.951042830944061, 38.158225044608116, 60.43973922729492, 75.20597487688065, 67.50009477138519, 65.67848771810532, 60.96926361322403, 62.85369649529457, 59.512429386377335, 57.47163489460945, 50.752516239881516, 55.59298150241375, 61.74376465380192, 63.914629966020584, 63.20681914687157, 63.65590184926987, 59.14063073694706, 62.57867485284805, 66.23307555913925, 59.03548277914524, 52.71195709705353, 44.588449001312256, 48.734824508428574, 54.05213378369808, 61.33135758340359, 63.18410776555538, 62.06282593309879, 59.97214011847973, 63.908611088991165, 60.38986310362816, 57.948152124881744, 58.42075936496258, 55.785893350839615, 55.23033656179905, 57.66124852001667, 59.226395934820175, 56.596918031573296, 54.27693352103233, 54.26415480673313, 51.582482904195786, 58.89309301972389, 60.558558851480484, 62.56247252225876, 31.326130852103233, 35.84174394607544, 63.7857560813427, 55.86138769984245, 57.73309126496315, 56.231898218393326, 56.87703900039196, 52.670733109116554, 60.51220893859863, 58.654344230890274, 62.60226018726826, 61.3945671916008, 60.177667289972305, 57.56062611937523, 61.898792535066605, 62.854042276740074, 62.77854032814503, 55.351569056510925, 58.96327145397663, 62.50346548855305, 54.10876214504242, 45.80686502158642, 49.00386527180672, 58.55728603899479, 64.09890487790108, 62.584815323352814, 59.446092545986176, 55.73661379516125, 64.03111651539803, 63.844478130340576, 65.39116993546486, 65.10169386863708, 58.878980576992035, 57.150472328066826, 55.47893822193146, 56.54217816889286, 64.3275386095047, 71.03907287120819, 69.03648152947426, 70.92639371752739, 46.519615575671196, 2.434654519893229, 0.6331857922486961, 3.168883896432817, 1.8322196463122964, 2.675398914143443, 2.0821099122986197, 0.9631233348045498, 0.23909415467642248, 0.11925056707696058, 0.07613084453623742, 5.3303098026663065, 42.91449822485447, 40.92189274728298, 37.917355969548225, 25.138438381254673, 28.073017112910748, 48.392204493284225, 56.73851363360882, 61.616805866360664, 64.70684945583344, 75.79481407999992, 36.86132803559303, 1.655910057015717, 0.37832325557246804, 0.05175367565243505, 0.03702717622218188, 0.13069281441858038, 0.10857967092306353, 0.028290795598877594, 0.08754247086471878, 0.11768125128583051, 0.03642563213361427, 0.0834724291053135, 0.003313233419248718, 0.0405338425480295, 0.016110558462969493, 0.03473205113550648, 0.04832653416087851, 0.00594514790464018, 0.0652295486361254, 0.04513460153248161, 0.035414737940300256, 0.06674799020402133, 0.06749395251972601, 0.012462022259569494, 0.029346990486374125, 0.03600995893066283, 0.0924641864548903, 0.14513272239128128, 0.0985316073638387, 0.12599877489265054, 0.18974915641592816, 0.10260754919727333, 0.15235183032928035, 0.1521406151005067, 0.11203930363990366, 0.12321232949034311, 0.09178174455882981, 0.15533587255049497, 0.12285105942282826, 0.19507921650074422, 0.15709025028627366, 0.0668893322290387, 0.1168485838570632, 0.17994177876971662, 0.16985490830847993, 0.09083833385375328, 0.1039809751091525, 0.2046929975040257, 0.07804999389918521, 1.1045180819928646, 53.307483941316605, 90.44185012578964, 79.51717793941498, 76.56678065657616, 72.82498463988304, 43.53456415235996, 41.992207914590836, 58.18857662379742, 68.56754869222641, 94.93159040808678, 32.73339293897152, 1.0002232971601188, 0.17967687657801434, 0.33655082050245255, 0.21115232433658093, 0.5173515016213059, 1.431832518428564, 9.210883397608995, 10.800425503402948, 9.420860130339861, 5.048970049247146, 12.24102795124054, 38.74978870153427, 60.44386960566044, 76.92590698599815, 69.55202266573906, 66.99161365628242, 64.20976012945175, 66.06071680784225, 63.62811394035816, 60.77141582965851, 52.82001189887524, 57.68711753189564, 65.46506837010384, 66.05323120951653, 65.47509223222733, 62.51556783914566, 59.076038002967834, 64.9171681702137, 68.83323043584824, 62.25621275603771, 55.457336381077766, 48.55745002627373, 51.19016535580158, 56.68574206531048, 64.80478540062904, 65.89610204100609, 62.9339861869812, 60.27583122253418, 66.26444667577744, 62.69310191273689, 60.147584304213524, 61.018292382359505, 59.91472139954567, 58.00614081323147, 61.59740790724754, 63.80672335624695, 58.32905888557434, 58.125032633543015, 56.348897740244865, 53.917488008737564, 63.11185464262962, 64.75648239254951, 64.62730452418327, 34.05667953193188, 39.372632279992104, 64.7299674153328, 56.981848776340485, 57.613481283187866, 56.903249993920326, 57.68217399716377, 52.34647370874882, 61.49799004197121, 59.87918570637703, 64.92450937628746, 63.13261292874813, 61.941901221871376, 60.143161341547966, 64.53251481056213, 65.41844487190247, 64.45426940917969, 55.23692540824413, 62.5880641490221, 67.20510140061378, 57.03193008899689, 48.59365448355675, 51.349752992391586, 62.01969064772129, 67.29907035827637, 64.26838338375092, 61.914219707250595, 55.077729150652885, 66.1343340575695, 67.3909342288971, 67.84844487905502, 69.23418492078781, 62.48431071639061, 60.31879931688309, 57.491086050868034, 59.27620366215706, 67.39617794752121, 74.5845790207386, 72.37349286675453, 72.86878108978271, 48.785711377859116, 1.8532196944579482, 7.245501084253192, 11.612613871693611, 5.217627799138427, 3.7110440293326974, 2.5636101001873612, 0.8254495379514992, 0.13753105216892436, 0.4211487981956452, 0.273881881730631, 7.774855904281139, 59.27304223179817, 63.84216025471687, 65.54150506854057, 36.46116390824318, 27.107335031032562, 50.89243993163109, 60.90275578200817, 70.52257418632507, 72.4027968943119, 84.74767327308655, 40.320388823747635, 2.2628538636490703, 0.5224743986036628, 0.17014636454405263, 0.10928424366284162, 0.33173336181789637, 0.22677751636365429, 0.19916750025004148, 0.11130527505883947, 0.22712463367497548, 0.15252249460900202, 0.12749353452818468, 0.13441302260616794, 0.13506964518455788, 0.19447009137365967, 0.194601392140612, 0.17949926579603925, 0.07822689964086749, 0.18259146861964837, 0.12490091583458707, 0.12457365839509293, 0.10803894212585874, 0.25037064333446324, 0.16978289029793814, 0.1789128949167207, 0.15457675937796012, 0.15205924602923915], [0.11325692306854762, 0.01462307280235109, 0.01994715210457798, 0.028740739326167386, 0.02926211105659604, 0.046110596231301315, 0.008362699063582113, 0.021208098114584573, 0.01245905737960129, 0.04466609112569131, 0.017652555798122194, 0.028059803989890497, 0.06566913754795678, 0.05325672136677895, 0.030655651025881525, 0.03891440210281871, 0.011540458526724251, 0.08322663721628487, 0.09016335796331987, 0.04849650453252252, 0.037920213653706014, 0.07073118584230542, 7.08906632848084, 65.8654148876667, 66.68672561645508, 59.34611991047859, 45.974911004304886, 29.232414700090885, 18.77645306289196, 30.74973788112402, 36.189394891262054, 31.761539988219738, 34.646529480814934, 1.8361763027496636, 0.07686763390665874, 0.038499957154272124, 0.10522609853069298, 0.10774578637210652, 0.07693921405007131, 3.0021676048636436, 4.718364039435983, 4.039455419406295, 1.3767117261886597, 10.364344753324986, 40.23293651640415, 55.249145552515984, 69.60654973983765, 65.90690106153488, 64.81984779238701, 58.65909017622471, 59.086251854896545, 54.200948998332024, 53.23417827486992, 48.68145637214184, 51.8841677159071, 57.48187534511089, 62.578899040818214, 61.5440321713686, 65.88423907756805, 57.87704274058342, 64.49120342731476, 63.61137963831425, 59.34374503791332, 57.1231821924448, 48.18879000842571, 42.8592149913311, 44.9777153134346, 54.04229611158371, 60.59007056057453, 60.75040675699711, 59.25584815442562, 57.55912519991398, 62.54756972193718, 58.6087466776371, 51.8755117803812, 48.789089396595955, 48.12105484306812, 49.36464451253414, 57.32095018029213, 53.473884612321854, 54.11866821348667, 48.36857736110687, 49.342909678816795, 44.830302223563194, 57.9852419346571, 52.86099269986153, 67.8215043246746, 38.702678829431534, 35.98029971122742, 59.433101043105125, 52.0481251180172, 59.521750286221504, 52.57259577512741, 58.55667807161808, 51.60747416317463, 54.249039217829704, 53.63794840872288, 54.51604329049587, 56.225997135043144, 62.51746393740177, 59.77665960788727, 60.328067019581795, 58.39357942342758, 58.47075328230858, 55.850018709897995, 62.84501016139984, 56.110156551003456, 49.0841169655323, 43.54215234518051, 49.30658362805843, 57.46941961348057, 64.26408961415291, 60.43291479349136, 55.00353053212166, 57.04666569828987, 63.07632274925709, 63.33780571818352, 60.33962219953537, 56.614556685090065, 53.23079265654087, 55.173024237155914, 56.376997232437134, 55.51769994199276, 53.65167707204819, 59.90722060203552, 66.73268795013428, 64.07162234187126, 69.29579481482506, 45.81221133470535, 5.647318717092276, 2.9935021698474884, 0.8780134236440063, 2.3535561840981245, 1.535969611722976, 0.5495352996513247, 0.31110711861401796, 0.06688244509859942, 0.03228952809877228, 0.04652779454772826, 11.883903164416552, 42.14508891105652, 34.38151270151138, 22.885037697851658, 23.19837838411331, 21.20927631855011, 40.80214977264404, 50.55273815989494, 52.25493282079697, 56.97321563959122, 60.45767426490784, 12.17699283733964, 0.4068609414389357, 0.20653848128858954, 0.05281748126435559, 0.08407131259446032, 0.1495710326707922, 0.017882150314108003, 0.08275846077594906, 0.06482651791884564, 0.06738137613865547, 0.046113271673675627, 0.04817924382223282, 0.035576084555941634, 0.021408476131909993, 0.03156950384436641, 0.04978817916708067, 0.06086149747716263, 0.03272387744800653, 0.012234747882757802, 0.08485846410621889, 0.08744355000089854, 0.06903467336087488, 0.03282007462985348, 0.07111663508112542, 0.01106013405660633, 0.047218901017913595, 0.055401754507329315, 0.09508957838988863, 0.018633778927323874, 0.0555975145107368, 0.017440841475035995, 0.023532320956292097, 0.06545740281580947, 0.029721424398303498, 0.05405779185821302, 0.044241541836527176, 0.058019235148094594, 0.06618314902880229, 0.03189935508999042, 0.021978057775413617, 0.03496287390589714, 0.02889317460358143, 0.050357989020994864, 0.09186672788928263, 0.050196698066429235, 0.0452136142848758, 0.04006486458820291, 0.0884170547942631, 10.919389519840479, 79.9986121058464, 74.12590563297272, 67.97399014234543, 55.73838450014591, 43.25889274477959, 29.172235429286957, 36.39217481017113, 39.41982574760914, 37.189098447561264, 39.38902460038662, 2.760030347853899, 0.10903717527980916, 0.05571874433371704, 0.1618576585315168, 0.3523542021866888, 1.869361822027713, 5.171475000679493, 1.6957265767268836, 3.507410818710923, 1.0896346368826926, 11.813650634139776, 42.40447819232941, 58.26909430325031, 70.65538465976715, 68.15210938453674, 66.33297979831696, 60.64381867647171, 61.920341178774834, 55.636059790849686, 55.35801351070404, 50.82323044538498, 53.04841384291649, 61.19215205311775, 64.86277788877487, 64.44942086935043, 63.32622013986111, 59.81200531125069, 64.42732125520706, 64.8553378880024, 63.3062370121479, 59.46101434528828, 50.528472661972046, 44.886505007743835, 47.212079018354416, 56.797174885869026, 64.71091523766518, 61.73610806465149, 59.416294544935226, 59.21080157160759, 63.71943823993206, 60.342130064964294, 54.30258974432945, 50.86897999048233, 50.818039923906326, 52.654637172818184, 60.32183915376663, 56.06007143855095, 56.054219752550125, 50.28302103281021, 51.177314445376396, 48.01006279885769, 60.776610150933266, 56.19067803025246, 67.87009611725807, 40.93440927565098, 38.264573737978935, 62.63475224375725, 52.70233981311321, 59.458225294947624, 54.78697255253792, 59.40760441124439, 52.46778979897499, 54.04351204633713, 54.50725436210632, 56.89875863492489, 58.4205237776041, 63.22182834148407, 61.68285012245178, 63.545339182019234, 59.18606869876385, 57.015917748212814, 58.335887119174004, 64.78023111820221, 58.17868955433369, 53.11610721051693, 45.84754943847656, 51.46546818315983, 62.42640942335129, 65.86273223161697, 60.49047410488129, 55.52771620452404, 57.722273245453835, 66.07077106833458, 65.37306770682335, 64.15968641638756, 60.39033427834511, 56.6356797516346, 58.13876509666443, 59.01365675032139, 58.382073640823364, 57.29253530502319, 61.930425837635994, 71.52919337153435, 66.8858653306961, 71.73605427145958, 52.707830518484116, 7.529086992144585, 1.4653059910051525, 1.061776194255799, 3.163797394372523, 3.480398068204522, 2.2541900910437107, 0.5791960924398154, 0.10616248109727167, 0.11051032357499935, 0.08355922327609733, 15.368585977703333, 42.399116680026054, 33.08048531413078, 19.365256167948246, 21.555202156305313, 33.160193637013435, 49.806218817830086, 59.83689397573471, 59.82324130833149, 60.88222548365593, 72.85029888153076, 20.883835181593895, 0.7250298920553178, 0.20232057402608916, 0.06304761962383054, 0.05405800337030087, 0.10434332129079849, 0.09429868645383976, 0.02714604022912681, 0.02867019076802535, 0.036858571402262896, 0.01830577377404552, 0.06928675866220146, 0.07256708107888699, 0.009975628090614919, 0.03739940410014242, 0.046835414759698324, 0.037411137454910204, 0.02383116341661662, 0.018301743912161328, 0.03827923872449901, 0.09216475955327041, 0.05964091316855047, 0.02542374553740956, 0.02628322305099573, 0.05380030001106206, 0.04955561977112666, 0.1719797810073942, 0.166803122847341, 0.09055855160113424, 0.10143966108444147, 0.13235342921689153, 0.12597327469848096, 0.2220976518583484, 0.09331035354989581, 0.10429674410261214, 0.13856793637387455, 0.17782459472073242, 0.11535936064319685, 0.20020414696773514, 0.16688116709701717, 0.19310548959765583, 0.16176503850147128, 0.1414007882704027, 0.2775064419256523, 0.2136068738764152, 0.15677247749408707, 0.14614645158872008, 0.21531829610466957, 14.040564838796854, 94.58395466208458, 84.03780296444893, 78.24218675494194, 63.417346850037575, 44.94665578007698, 29.70987617969513, 41.743758246302605, 44.32432897388935, 45.779738277196884, 47.056439369916916, 3.6344838375225663, 0.22180638858117163, 0.29339757515117526, 0.2354067048872821, 0.5237941746599972, 1.4629025012254715, 7.352976892143488, 13.536832518875599, 12.42367560043931, 6.326584042981267, 12.665060497820377, 44.95101794600487, 59.12667788565159, 72.05342844128609, 69.07897084951401, 68.35363537073135, 62.7303247153759, 64.94575023651123, 57.50989884138107, 58.39741721749306, 54.34651158750057, 56.32168360054493, 63.688040524721146, 67.62474328279495, 66.18069916963577, 66.20187163352966, 61.65574237704277, 64.07248869538307, 66.53135195374489, 65.61537310481071, 64.75579082965851, 53.72868753969669, 47.52324052155018, 49.67030771076679, 60.18091231584549, 67.58341670036316, 62.43719704449177, 59.04000073671341, 61.44559845328331, 66.25965893268585, 63.831186443567276, 55.883779898285866, 54.57078695297241, 52.47084103524685, 54.7794109582901, 62.616828605532646, 58.666153997182846, 58.482456654310226, 54.375207647681236, 52.84635588526726, 49.99496228992939, 63.37233446538448, 61.16676941514015, 71.03459671139717, 43.52351434528828, 42.088874727487564, 63.98319348692894, 53.52032192051411, 60.95974512398243, 55.49918353557587, 61.78466945886612, 55.168453082442284, 55.569935739040375, 53.26673872768879, 57.13593810796738, 59.23541285097599, 65.63564121723175, 65.54202944040298, 64.78745073080063, 60.96386030316353, 57.428017035126686, 58.38923625648022, 68.47039550542831, 60.969825983047485, 55.281364023685455, 48.76513168215752, 54.069647043943405, 65.08945092558861, 69.59593310952187, 63.123827800154686, 55.47832265496254, 57.398792803287506, 68.12560200691223, 67.6036012172699, 66.62170350551605, 64.40618678927422, 59.59366902709007, 61.95712320506573, 61.90286211669445, 60.82552492618561, 59.636306539177895, 63.25546033680439, 74.07824099063873, 70.00976890325546, 73.79762604832649, 53.26072745025158, 8.839158844202757, 10.662976428866386, 10.532361287623644, 8.61339870840311, 5.007481975480914, 2.5193393882364035, 1.0604085051454604, 0.2122343608061783, 0.1999059075023979, 0.1804858323885128, 20.669429786503315, 60.602131113409996, 47.26705066859722, 33.61270375549793, 36.758615747094154, 34.52750466763973, 56.16467982530594, 65.58735340833664, 70.0849136710167, 69.01991441845894, 83.73444244265556, 21.959907039999962, 0.8629013376776129, 0.2539367222925648, 0.1400097957230173, 0.18078880675602704, 0.260055759572424, 0.19563821697374806, 0.2850719843991101, 0.14469807618297637, 0.12466210755519569, 0.11499440210172907, 0.21533333201659843, 0.17455276247346774, 0.07756983919534832, 0.1754959431127645, 0.1061572712205816, 0.11916856718016788, 0.12003368130535819, 0.09816919438890181, 0.13643917482113466, 0.11942835597437806, 0.20484065520577133, 0.07418510402203538, 0.18372480233665556, 0.12986908986931667, 0.1184153243957553], [0.022791763331042603, 0.030846058289171197, 0.023120558871596586, 0.003381923361303052, 0.017339716432616115, 0.022750427560822573, 0.03487658810627181, 0.018556675349827856, 0.05510606802999973, 0.011798097875725944, 0.05694764811778441, 0.06626880771364085, 0.06855203988379799, 0.06966935805394314, 0.051554613091866486, 0.04081697930814698, 0.04363351508800406, 0.06322723420453258, 0.02555583112552995, 0.04355200500867795, 0.09585476233041845, 0.2856952103320509, 28.300744593143463, 76.20223581790924, 63.08880127966404, 60.538203343749046, 38.61637406051159, 23.329737335443497, 20.80112311989069, 33.686195611953735, 38.11363823711872, 52.314658015966415, 14.069152604788542, 0.10325990442652255, 0.27596609957981855, 0.06895491475006565, 0.1999590007471852, 0.4265705728903413, 0.7457208505365998, 3.5961206210777164, 2.7474340237677097, 0.8042782021220773, 7.255033822730184, 38.068751245737076, 62.30184830725193, 66.78554311394691, 66.0480634868145, 70.03113895654678, 65.31380608677864, 59.994448721408844, 58.06081987917423, 53.533150032162666, 47.19912551343441, 48.092791959643364, 55.633350536227226, 63.91719102859497, 63.02348658442497, 63.65391455590725, 56.78149312734604, 56.13794066011906, 63.18233706057072, 55.34388966858387, 59.51333373785019, 56.94092497229576, 52.34576314687729, 40.682057216763496, 46.82334467768669, 54.54960688948631, 61.033214181661606, 59.086730629205704, 55.36498613655567, 57.91919007897377, 61.127779707312584, 55.13827510178089, 48.48490431904793, 43.87648120522499, 45.31252674758434, 50.925467759370804, 57.48927354812622, 54.704657569527626, 53.7957501411438, 46.912898272275925, 48.28601159155369, 45.26012375950813, 54.04299147427082, 54.5653760433197, 62.79006130993366, 36.74411192536354, 31.68705638498068, 60.98150655627251, 52.27021940052509, 56.65440894663334, 54.87655654549599, 54.355235919356346, 53.37365359067917, 52.38758370280266, 51.80602490901947, 55.79829968512058, 52.65691705048084, 58.222360610961914, 55.423977971076965, 60.14338932931423, 55.41283696889877, 56.9539050757885, 60.24569883942604, 60.19283227622509, 52.4173741042614, 46.32549159228802, 44.06517527997494, 50.902505591511726, 58.32188107073307, 61.655677780508995, 61.4880383759737, 54.35664564371109, 56.488346457481384, 60.29687449336052, 59.57543760538101, 59.459958001971245, 54.02228258550167, 55.064771845936775, 52.8403028100729, 59.13477525115013, 58.61330263316631, 56.509321331977844, 56.87500610947609, 57.53446452319622, 63.30205723643303, 64.94970202445984, 65.90722024440765, 49.68953087925911, 9.322832990437746, 0.42863312002737075, 2.725963513366878, 2.4856078857555985, 1.9051720504648983, 0.24089378857752308, 0.16698702704161406, 0.2360238748951815, 0.1484526606509462, 2.494446448981762, 26.10571827739477, 34.42652128636837, 44.12996560335159, 28.762923292815685, 21.923603788018227, 33.606335297226906, 41.7579048871994, 46.389768943190575, 52.71835595369339, 59.339348673820496, 55.7388860732317, 3.448694469407201, 0.4061379411723465, 0.014819009065831779, 0.07070268737152219, 0.02368446865148144, 0.11532100645126775, 0.02445783477014629, 0.008608604130131425, 0.019640719328890555, 0.05118999593832996, 0.012566316272568656, 0.01580961386935087, 0.028526069399958942, 0.05928935781412292, 0.08152259935741313, 0.026478589716134593, 0.05189044233702589, 0.02670418962225085, 0.03786768073041458, 0.06253063955227844, 0.01388781040077447, 0.03481024752545636, 0.019156364069203846, 0.006649559227298596, 0.024734102953516413, 0.08932545097195543, 0.04627529364370275, 0.05478320781548973, 0.03930614475393668, 0.00866331340148463, 0.02162286404200131, 0.031164361716946587, 0.027369257841201033, 0.017054418167390395, 0.037113562211743556, 0.01852667217463022, 0.01739877840009285, 0.038793944113422185, 0.008711354475963162, 0.056062826261040755, 0.051946671155747026, 0.044910773503943346, 0.03396863721718546, 0.012903010119771352, 0.05255325813777745, 0.13751359685556963, 0.3782179596601054, 38.889336213469505, 90.11122986674309, 70.16582652926445, 67.95822858810425, 45.37455081939697, 31.989164873957634, 27.576526254415512, 31.08465950936079, 39.23266299068928, 49.96626242995262, 15.316739659756422, 0.11077092131017707, 0.06965073014725931, 0.110134069545893, 0.273410024237819, 1.5290880622342229, 3.459735014475882, 6.278157066553831, 2.785279992967844, 0.36011792777571827, 10.922460705041885, 42.266895174980164, 64.3566070497036, 68.17477136850357, 67.80302971601486, 70.64285293221474, 67.11072966456413, 62.70368054509163, 59.876541048288345, 55.362862050533295, 50.37581205368042, 49.01117227971554, 57.667932361364365, 66.77419692277908, 65.03189161419868, 64.90530520677567, 58.54868710041046, 59.08453434705734, 61.69791631400585, 57.98499874770641, 63.007231056690216, 59.78662267327309, 54.82582166790962, 43.14746752381325, 48.86008478701115, 57.2409188747406, 63.912950456142426, 60.03590829670429, 54.94698576629162, 58.247496262192726, 64.32681664824486, 58.74058060348034, 49.98342990875244, 46.238005086779594, 46.84184208512306, 52.52630665898323, 58.855809420347214, 56.55291639268398, 56.062434911727905, 48.89836013317108, 49.26402971148491, 46.622989028692245, 56.810413375496864, 56.51470184326172, 65.95924705266953, 41.25678397715092, 34.56085167825222, 62.72172577679157, 51.980131566524506, 57.30986997485161, 55.34570597112179, 55.28078265488148, 55.434963181614876, 55.29694318771362, 52.842966467142105, 55.19793950021267, 52.21974290907383, 59.165682792663574, 58.277921229600906, 59.3441554158926, 54.95306923985481, 57.379102259874344, 61.25717036426067, 61.85596123337746, 55.50653614103794, 48.54108430445194, 45.202431455254555, 52.45471850037575, 61.33006565272808, 64.36395585536957, 61.24331630766392, 54.17835921049118, 58.33079159259796, 62.91991554200649, 62.008032873272896, 61.730632558465004, 57.67617031931877, 58.255255445837975, 56.195667162537575, 61.39909654855728, 62.41250216960907, 59.36502009630203, 57.88393177092075, 60.4805376380682, 65.67456632852554, 66.4175632596016, 67.86194175481796, 57.011141404509544, 10.22062411531806, 0.17173234897200018, 2.550763702020049, 2.680614134296775, 4.232839392498136, 1.4454910042695701, 0.4218737280461937, 0.3829583537299186, 0.11189666285645217, 2.2605514246970415, 31.31881434470415, 36.98093041777611, 45.13468109071255, 26.754613257944584, 26.486853025853634, 50.17636455595493, 53.096458464860916, 54.49703671038151, 60.45822523534298, 62.84693665802479, 70.29515638947487, 7.2994866874068975, 0.6684719456825405, 0.0894517199776601, 0.07295264163985848, 0.03729079449840356, 0.09594528208253905, 0.02938336128863739, 0.02077335728245089, 0.025985914980992675, 0.02868179239158053, 0.019906165143765975, 0.03466271598881576, 0.01645839751290623, 0.036625381180783734, 0.008583734761486994, 0.0613224676635582, 0.04125475366890896, 0.021194696782913525, 0.022785831715737004, 0.029379559637163766, 0.047511589218629524, 0.026178086700383574, 0.058801147097256035, 0.03179520208504982, 0.017774243897292763, 0.18087275850120932, 0.14793918351642787, 0.23818217392545193, 0.09191821809508838, 0.1514198412769474, 0.09880906669422984, 0.19848090974846855, 0.14661118446383625, 0.14265437959693372, 0.0883510556013789, 0.19153664878103882, 0.10760568373370916, 0.15809517761226743, 0.14740706363227218, 0.08918347069993615, 0.18241664831293747, 0.18466076930053532, 0.19964530976722017, 0.1699426895356737, 0.1519366877619177, 0.3131403954466805, 0.5822164553683251, 48.76668959856033, 103.14858868718147, 77.63066276907921, 78.57458531856537, 55.09076625108719, 37.22023397684097, 29.35747928917408, 44.97282117605209, 50.899632945656776, 69.46233227849007, 21.29123032093048, 0.190012737584766, 0.6062982568982989, 0.3910978732164949, 0.4363676346838474, 1.2421964504756033, 3.1473775254562497, 12.861078679561615, 10.39514685049653, 7.388706849887967, 12.072318904101849, 42.91668690741062, 66.6948875784874, 66.74065232276917, 69.3217322230339, 72.51642599701881, 68.61985668540001, 65.34076184034348, 63.588018491864204, 59.206348210573196, 52.1102099865675, 52.17177428305149, 61.65810205042362, 69.04678657650948, 67.32519015669823, 66.29302874207497, 60.67642852663994, 61.21726110577583, 60.49944922327995, 60.695564299821854, 65.02089500427246, 62.913417890667915, 57.99670211970806, 46.39900624752045, 52.229394391179085, 60.00517554581165, 65.97784325480461, 60.41900373995304, 55.64934007823467, 59.38979096710682, 65.92453211545944, 61.14963233470917, 52.414387464523315, 48.89622464776039, 49.71452973783016, 54.42566134035587, 62.35191062092781, 59.647489339113235, 60.04785865545273, 53.346089869737625, 51.53948441147804, 51.39282368123531, 59.947654232382774, 60.996656343340874, 67.073575258255, 45.553183034062386, 38.373152911663055, 65.87648749351501, 54.41759817302227, 58.39468516409397, 57.80665151774883, 57.66602486371994, 57.811180874705315, 57.349604442715645, 55.18468961119652, 56.077991276979446, 54.44690980017185, 60.18517188727856, 58.957161381840706, 61.36860318481922, 56.03934735059738, 58.68782423436642, 64.85282242298126, 65.26628583669662, 58.381594866514206, 51.252930387854576, 50.43871387839317, 56.565463319420815, 63.19190114736557, 66.39059230685234, 61.86012580990791, 55.51109969615936, 59.82130341231823, 66.36806711554527, 64.90680992603302, 65.82047089934349, 59.65536631643772, 61.1433132737875, 59.60195258259773, 64.68979597091675, 63.89366269111633, 62.39478752017021, 61.07464715838432, 63.38225573301315, 69.91310209035873, 69.49499532580376, 70.06670504808426, 58.486632630228996, 11.659396011382341, 3.456663591787219, 10.83606569096446, 9.507892560213804, 4.477335372939706, 1.5027330326847732, 0.44594160688575357, 0.6543994008097798, 0.28304221050348133, 3.645615577697754, 41.87506780028343, 50.787280574440956, 62.77245305478573, 44.534408301115036, 36.81579127907753, 46.37537531554699, 56.70224077999592, 64.4050544500351, 70.69931030273438, 71.42649248242378, 81.40628457069397, 9.06539585441351, 0.9792713401839137, 0.21066180925117806, 0.13840843399520963, 0.16102179244626313, 0.19128951360471547, 0.13310694659594446, 0.08340786225744523, 0.0853475765325129, 0.13856483419658616, 0.1312277841498144, 0.2166396306711249, 0.2019449879298918, 0.1377516778302379, 0.1002743408025708, 0.1513598015299067, 0.13483089627698064, 0.13386481296038255, 0.11333026210195385, 0.15873340977123007, 0.16566839389270172, 0.2130574916373007, 0.14520221709972247, 0.11585115964408033, 0.14526006008964032], [0.037607212871080264, 0.019497792818583548, 0.03427561547141522, 0.0613428062206367, 0.06894351536175236, 0.0382629300293047, 0.01990889068110846, 0.01768786161846947, 0.003180805051670177, 0.025856352694972884, 0.058362062845844775, 0.03079817492107395, 0.008665644672873896, 0.0547155128151644, 0.023749222891638055, 0.039110214056563564, 0.07928028178866953, 0.07281916638021357, 0.05205898778513074, 0.046410171562456526, 0.01969703720533289, 0.6854373821988702, 55.165443643927574, 72.58665382862091, 62.19192400574684, 54.23327386379242, 42.0113018900156, 27.90840044617653, 30.363541804254055, 36.95839002728462, 38.57327677309513, 36.4469450712204, 0.9152895421721041, 0.08755980001296848, 0.16620162699837238, 0.06119640274846461, 0.45003606530372053, 0.2805439929943532, 4.330652793869376, 4.541630772873759, 0.6683038640767336, 5.816374020650983, 38.20761479437351, 67.01880499720573, 69.17249143123627, 66.6737987101078, 68.89040976762772, 64.82377678155899, 64.7996024787426, 61.6213808208704, 55.043306797742844, 49.435829892754555, 48.96307826042175, 47.41854853928089, 59.8674975335598, 63.29298332333565, 61.57469652593136, 62.7238916605711, 55.53795665502548, 62.55095534026623, 54.62167762219906, 56.21427856385708, 60.38756802678108, 58.573070392012596, 56.55678078532219, 44.34963181614876, 43.45152720808983, 53.045837581157684, 60.38506776094437, 57.16105856001377, 53.15147951245308, 57.844280898571014, 60.11568881571293, 54.177865236997604, 46.517890468239784, 42.688778936862946, 45.93992628157139, 50.35452179610729, 56.174984872341156, 53.41815300285816, 52.473915070295334, 48.53685513138771, 45.46549133956432, 41.46061263978481, 52.77411416172981, 51.3982155919075, 65.9224346280098, 41.2418507784605, 31.131999269127846, 56.090089827775955, 48.45981806516647, 56.531052365899086, 53.79655949771404, 57.627791315317154, 54.1788037866354, 57.07865998148918, 48.964100405573845, 53.01061727106571, 52.07717835903168, 57.02875725924969, 55.597548857331276, 52.611950263381004, 47.60253086686134, 59.29064668715, 58.07582527399063, 57.572112902998924, 45.3034832328558, 43.523058369755745, 43.17544162273407, 50.81601843237877, 58.02942976355553, 59.728542789816856, 58.25482986867428, 51.04742981493473, 57.300081700086594, 61.264272183179855, 58.816226944327354, 53.30684557557106, 51.95254124701023, 52.17536509037018, 55.859476402401924, 57.75401294231415, 57.09972605109215, 59.7363817691803, 60.17962038516998, 57.39629253745079, 57.29283168911934, 60.36905162036419, 65.38739293813705, 67.78491988778114, 47.5052484869957, 7.863237736746669, 0.9341297030914575, 2.984543200582266, 4.553851867094636, 0.2707659895531833, 0.47486918745562434, 0.1539239811245352, 0.05049476683780085, 0.08371914867893793, 6.691247150301933, 32.40167833864689, 23.501421622931957, 26.494794599711895, 16.71363115310669, 7.332397671416402, 19.384435638785362, 38.06338593363762, 51.627871468663216, 49.923415929079056, 63.60506057739258, 26.984170340001583, 0.7052230392582715, 0.055159213225124404, 0.013278667647682596, 0.0647883937926963, 0.03944580952520482, 0.034208232173114084, 0.046412234732997604, 0.10993530013365671, 0.0323587073944509, 0.06781239324482158, 0.011008714354829863, 0.03513967945764307, 0.06385174405295402, 0.02003526173211867, 0.01970485202036798, 0.04404467603308149, 0.016464898726553656, 0.07773343822918832, 0.01767060297424905, 0.010159360663237749, 0.01240703653820674, 0.016415974496339913, 0.03371391358086839, 0.03582521610951517, 0.014788803655392257, 0.0552827103092568, 0.05250983878795523, 0.07678285095607862, 0.04528474542894401, 0.01934357082063798, 0.01621455932763638, 0.03097577457083389, 0.033643865972408094, 0.017593024422239978, 0.08389314520172775, 0.04596278638928197, 0.042805408156709746, 0.008916190017771441, 0.0246852603595471, 0.04855613980907947, 0.03784233638725709, 0.07077884656609967, 0.02047345169557957, 0.00782787961725262, 0.023669640540902037, 2.155853030271828, 70.32987892627716, 80.4257395863533, 70.30724734067917, 63.114814683794975, 50.828466564416885, 33.87148506939411, 26.330065838992596, 33.11989679932594, 39.10897582769394, 38.76421272754669, 1.7396833305247128, 0.1346765147172846, 0.17269725969526917, 0.5596134276129305, 1.1878118687309325, 3.5475570894777775, 5.04563620314002, 3.751866426318884, 0.5693758162669837, 7.297105640172958, 41.64998307824135, 67.65695035457611, 71.80764243006706, 67.8650651872158, 69.75409582257271, 66.55731976032257, 68.41668158769608, 64.46948379278183, 57.482825294137, 51.527910232543945, 50.640939027071, 49.57652494311333, 60.20369589328766, 65.65267190337181, 64.56195563077927, 63.03404621779919, 59.06745806336403, 62.185213565826416, 54.861266165971756, 57.60992467403412, 62.36440435051918, 60.962750762701035, 58.98231603205204, 46.37278385460377, 45.912259966135025, 55.733224377036095, 63.12331482768059, 58.24093781411648, 54.826897010207176, 57.96311192214489, 63.231609016656876, 56.77946783602238, 48.08700107038021, 44.58319008350372, 48.16893607378006, 51.66969582438469, 58.25566202402115, 55.43001964688301, 55.33332243561745, 50.08097067475319, 47.49896362423897, 44.4517969340086, 55.22076867520809, 54.463727697730064, 66.96426272392273, 43.22800040245056, 34.59045968949795, 58.18957597017288, 52.024224400520325, 56.49425134062767, 54.31527726352215, 58.16175006330013, 56.349463909864426, 58.001189678907394, 52.87171192467213, 55.26515409350395, 54.37940262258053, 58.15330311655998, 57.296574488282204, 53.455915376544, 48.99600729346275, 61.54745578765869, 59.780292212963104, 61.54134191572666, 48.24867479503155, 46.03725045919418, 46.244521737098694, 54.01311747729778, 61.351215317845345, 60.712116211652756, 58.1254506111145, 51.17435820400715, 59.519573003053665, 64.63823273777962, 60.93197241425514, 54.34528425335884, 53.21976184844971, 54.90397967398167, 59.372843876481056, 61.71370446681976, 60.254749953746796, 63.66110756993294, 62.450545728206635, 62.296638786792755, 61.875887364149094, 63.650703728199005, 68.1926304101944, 69.26912024617195, 53.97889271378517, 9.680123068392277, 0.5240186001174152, 0.8651662536431104, 4.110430385917425, 4.088027738034725, 0.933707213262096, 0.24288939399411902, 0.12367660965537652, 0.09986119461245835, 7.693358827382326, 34.65482443571091, 31.793883852660656, 34.75345954298973, 17.72943824529648, 10.210078731179237, 31.115553751587868, 47.43978179991245, 60.00922612845898, 56.68576866388321, 70.29616713523865, 40.99854223430157, 1.083440613001585, 0.029735109601460863, 0.03285567174316384, 0.04870123339060228, 0.025372787822561804, 0.06652757234405726, 0.07065844794851728, 0.07398984496830963, 0.021265766699798405, 0.018278913594258483, 0.026312087029509712, 0.031015646454761736, 0.05792316784209106, 0.024016661373025272, 0.044332774050417356, 0.030181253532646224, 0.04456263573956676, 0.05378009132982697, 0.04966167267411947, 0.035813449358101934, 0.09081063690246083, 0.03882273202179931, 0.03080977468925994, 0.04187384955002926, 0.13115704263327643, 0.12723808729788288, 0.2223704950301908, 0.16132353484863415, 0.1403160355403088, 0.08637869425001554, 0.08062941720709205, 0.16094978927867487, 0.13141539908247069, 0.07284126753802411, 0.09806064786971547, 0.10551565486821346, 0.18525104387663305, 0.1703446070314385, 0.08989925729110837, 0.20030406973091885, 0.17918368976097554, 0.2767633442999795, 0.27175209601409733, 0.18006283789873123, 0.2604488603537902, 3.3844641409814358, 85.38316637277603, 89.77958366274834, 81.59610718488693, 71.20891615748405, 57.797288820147514, 40.41833616793156, 42.88461282849312, 48.68953853845596, 52.04012654721737, 51.72538183629513, 1.7887791898101568, 0.3054975805571303, 0.38683847989887, 0.6608142878394574, 1.2407182110473514, 3.567970306612551, 12.301409561187029, 12.933362200856209, 5.005190698429942, 8.384498041123152, 43.485087007284164, 70.06327003240585, 74.39540237188339, 70.14970019459724, 75.36976888775826, 69.69088241457939, 70.1915967464447, 67.54925653338432, 58.99666406214237, 55.0712238997221, 52.49283045530319, 52.14178629219532, 63.660856783390045, 68.88744592666626, 67.20378667116165, 67.51894935965538, 60.87580382823944, 63.60346086323261, 55.39281204342842, 57.99007527530193, 64.18028891086578, 65.44540822505951, 61.544028371572495, 48.4783648699522, 48.56964737176895, 57.78217703104019, 65.44956520199776, 59.850052669644356, 55.36717861890793, 61.06928564608097, 63.894126266241074, 58.20927791297436, 50.58166600763798, 48.07014897465706, 50.489171370863914, 55.39931729435921, 62.265982031822205, 58.80765840411186, 57.291224375367165, 53.71611401438713, 49.87141951918602, 46.52312658727169, 56.80203102529049, 56.65582627058029, 69.09675389528275, 47.13227190077305, 39.53614890575409, 60.6899444013834, 54.59697514772415, 58.49876157939434, 56.95393927395344, 61.80745303630829, 58.40523339807987, 59.84119154512882, 54.68583717942238, 57.88924388587475, 57.69543148577213, 58.83157432079315, 58.93594712018967, 53.57163056731224, 50.77644355595112, 62.16029830276966, 63.74277278780937, 64.30828884243965, 49.93994504213333, 47.843734323978424, 48.438938185572624, 57.14297913014889, 63.220658004283905, 63.98551136255264, 57.53065712749958, 50.128114745020866, 61.13841533660889, 68.68994772434235, 65.20110413432121, 57.51074619591236, 56.97009980678558, 57.83089801669121, 62.749631479382515, 63.582341596484184, 63.302490413188934, 66.14112049341202, 65.8564093708992, 64.50668379664421, 63.56087654829025, 64.71688091754913, 72.49306485056877, 70.99352851510048, 57.59184904396534, 9.961239583790302, 5.241938419640064, 10.039779469370842, 11.702882777899504, 4.4910987094044685, 1.0822464083321393, 0.449103809078224, 0.12782377540133893, 0.1663208010722883, 11.38352321460843, 47.944485917687416, 37.9554945230484, 41.63919545710087, 27.464633658528328, 14.96609067544341, 32.2777783870697, 51.81252636015415, 68.62581476569176, 66.32571458816528, 80.7387363910675, 50.13558514416218, 1.7051004362292588, 0.24687575118150562, 0.13734134437981993, 0.1830250016064383, 0.11821138221421279, 0.14688172697788104, 0.14213416376151145, 0.22226632718229666, 0.1099007976881694, 0.133181101991795, 0.16939761175308377, 0.1111196936108172, 0.15344412327976897, 0.08460921380901709, 0.12818873394280672, 0.12410604598699138, 0.13136062858393416, 0.1736156377592124, 0.20985362527426332, 0.09029523018398322, 0.10612811965984292, 0.1863982854411006, 0.11297677716356702, 0.05783327520475723], [0.05630635088891722, 0.019369815017853398, 0.14210312714567408, 0.1029307025601156, 0.009078405873879092, 0.06129465939011425, 0.06257398839807138, 0.14904538431437686, 0.038322992040775716, 0.05662313662469387, 0.01257845038708183, 0.03257577074691653, 0.019165106568834744, 0.05088863574201241, 0.046642348752357066, 0.06281645546550862, 0.009630766908230726, 0.01880619653093163, 0.07595318922540173, 0.11278697289526463, 0.08596076120738871, 16.27791043370962, 78.33838999271393, 64.9357795715332, 70.50249606370926, 53.34784917533398, 35.994712337851524, 20.221694111824036, 43.08803491294384, 34.7837895154953, 54.29905213415623, 16.406328342854977, 0.03992478421423584, 0.2627171011408791, 0.08925531059503555, 0.10885317460633814, 0.3619452437851578, 2.682279869914055, 5.142846861854196, 1.8680337932892144, 4.554232321679592, 39.64679516851902, 71.1286872625351, 66.72124296426773, 66.85105919837952, 67.36485242843628, 65.72051346302032, 64.99787583947182, 63.49712356925011, 57.154177129268646, 49.272712245583534, 48.27302768826485, 48.08174975216389, 46.91411420702934, 49.98795926570892, 59.03148539364338, 58.89394037425518, 56.20012432336807, 61.17437280714512, 57.98813737928867, 58.53066086769104, 53.3737675845623, 56.84026837348938, 57.002086490392685, 57.545958906412125, 48.98306518793106, 42.9098928719759, 44.4492244720459, 57.044302225112915, 59.75725404918194, 59.82707530260086, 57.7172727137804, 58.0624195933342, 49.68397177755833, 42.94406823813915, 42.21896454691887, 46.00132718682289, 52.32679456472397, 54.59995798766613, 53.38257171213627, 51.20507575571537, 45.862953811883926, 46.7020969837904, 44.21785868704319, 52.44280993938446, 51.7888118326664, 62.3714529722929, 38.60203742980957, 34.75050330162048, 50.80233156681061, 49.51403349637985, 55.53080543875694, 48.8916002959013, 54.17188435792923, 53.56247305870056, 52.917347475886345, 55.533396899700165, 58.1502328813076, 57.28017456829548, 59.0272182226181, 57.95401141047478, 56.444451212882996, 51.70542150735855, 61.706040278077126, 55.680657997727394, 52.70268939435482, 43.391456231474876, 44.583946242928505, 42.72526077926159, 46.986876502633095, 56.89897522330284, 59.38955917954445, 59.58986163139343, 51.139453276991844, 57.24055789411068, 59.10993218421936, 54.99947614967823, 53.189188688993454, 45.92909686267376, 50.94348259270191, 52.742602452635765, 59.2869570851326, 57.372824996709824, 64.80803042650223, 64.49331611394882, 62.02812999486923, 59.8496612906456, 62.36267164349556, 56.68441213667393, 67.44715601205826, 65.65976232290268, 44.687517285346985, 5.742911612614989, 1.1763362470082939, 4.064144594594836, 2.839776431210339, 0.8019796223379672, 1.6960758017376065, 0.3087323944782838, 0.04125244930037297, 0.3005159291205928, 15.092212557792664, 40.640647038817406, 19.671371541917324, 32.919617146253586, 44.94242660701275, 22.549952678382397, 24.898452758789062, 38.86520750820637, 52.53722347319126, 55.48068232834339, 53.82968232035637, 6.593213360756636, 0.11318834862322547, 0.025999227254942525, 0.044932551827514544, 0.04440658063685987, 0.09883024758892134, 0.02333757955057081, 0.06432932350435294, 0.08789109473582357, 0.0447421612625476, 0.09226521666278131, 0.08214718342060223, 0.04134549235459417, 0.01812795890145935, 0.018531748464738484, 0.03546369000105187, 0.06465286278398708, 0.05297881674778182, 0.0072484093197999755, 0.028172473139420617, 0.027336085695424117, 0.03439752807025798, 0.04608024981280323, 0.07632050779648125, 0.032410809872089885, 0.014312381954368902, 0.04239975394739304, 0.02313565415533958, 0.03218301877495833, 0.0653497246094048, 0.05137840496900026, 0.09778701802133583, 0.05234332311374601, 0.003359632260071521, 0.014582395688194083, 0.031199854929582216, 0.030949153733672574, 0.02506993962015258, 0.046376971586141735, 0.13165581040084362, 0.0273503200878622, 0.05938330999924801, 0.06523994612507522, 0.1042013855476398, 0.07367274753050879, 23.09051927179098, 93.06345865130424, 72.13483527302742, 78.34272935986519, 60.683868527412415, 46.92087024450302, 24.610380716621876, 39.88808982074261, 31.009980216622353, 47.33939118683338, 16.124869845807552, 0.08299162873299792, 0.047662760989624076, 0.22724818642018363, 0.6881991808768362, 1.919294586405158, 5.568134291097522, 3.6825522081926465, 0.5095208343118429, 5.168988984078169, 41.58196672797203, 73.90809372067451, 70.61430126428604, 69.21759501099586, 69.38863143324852, 68.27863499522209, 68.09321254491806, 67.19658225774765, 58.72100405395031, 51.239216923713684, 49.30148810148239, 50.305515825748444, 48.4612999856472, 54.09591503441334, 61.95826694369316, 60.62956564128399, 58.84422764182091, 63.64647835493088, 59.82569597661495, 59.391820058226585, 54.398333206772804, 59.33165788650513, 59.78185772895813, 60.14228358864784, 50.48020765185356, 44.198593720793724, 48.72923880815506, 59.52540569007397, 61.4738043397665, 61.52524217963219, 59.30600546300411, 61.63399234414101, 52.03802905976772, 45.4836505651474, 44.07736122608185, 47.36544258892536, 55.56278072297573, 55.743145644664764, 55.958571285009384, 54.08531740307808, 48.693794310092926, 47.886748015880585, 46.600889414548874, 53.85169453918934, 55.44170781970024, 64.1484922170639, 42.23755694925785, 37.74726949632168, 54.06778134405613, 51.9793564081192, 57.32226490974426, 51.28943882882595, 56.241295114159584, 55.43600432574749, 55.58528311550617, 56.92435786128044, 60.438557490706444, 59.82781246304512, 60.20246855914593, 60.23960016667843, 58.1528053432703, 52.31302410364151, 63.53379160165787, 59.46525491774082, 55.25315433740616, 44.40364211797714, 47.35473096370697, 44.62154142558575, 48.758330047130585, 59.44832682609558, 62.77226686477661, 60.151726081967354, 52.174050360918045, 57.57012940943241, 62.87741482257843, 58.228862062096596, 54.9538329988718, 49.172469824552536, 52.935757488012314, 55.36600448191166, 62.044545114040375, 61.851568669080734, 67.72701859474182, 66.85263231396675, 64.35276165604591, 62.0870990306139, 64.47918087244034, 61.36111758649349, 67.97570005059242, 66.57485201954842, 49.526436030864716, 8.602438196539879, 0.3520839416887611, 3.0417503183707595, 5.02528022043407, 2.0607688324525952, 3.908332292921841, 0.3026724321534857, 0.13331203168490902, 0.36464654258452356, 18.284046985208988, 36.61800429224968, 22.401428148150444, 25.7353388518095, 32.49157391488552, 22.000030986964703, 35.27507655322552, 46.595265716314316, 59.34875696897507, 60.972466841340065, 66.06990471482277, 11.288175880908966, 0.19104347680695355, 0.05517811201571021, 0.051252477351226844, 0.07743837515590712, 0.03391985585039947, 0.010807625731104054, 0.04181014359346591, 0.04142109122767579, 0.020253777838661335, 0.04523015675658826, 0.049841053478303365, 0.014004264503455488, 0.01612152555026114, 0.0034580575083964504, 0.042273551734979264, 0.0800673887715675, 0.03796567390963901, 0.04177578586677555, 0.025331166325486265, 0.10528939630603418, 0.019180853087163996, 0.04667947468988132, 0.09774412188562565, 0.1406269657309167, 0.08497282164171338, 0.2497394912643358, 0.2543600433273241, 0.09033555106725544, 0.11228680989006534, 0.14407342532649636, 0.22698107262840495, 0.138305616856087, 0.10333044556318782, 0.1303064968669787, 0.17850803851615638, 0.07461984670953825, 0.1445169624639675, 0.2538450522115454, 0.3748049709247425, 0.1703301796806045, 0.22507026500534266, 0.1016270682157483, 0.2120481411111541, 0.215681518020574, 29.258492700755596, 106.00193917751312, 79.86927464604378, 88.97884503006935, 66.39802470803261, 51.728360876441, 28.032564483582973, 57.6523531973362, 45.078793689608574, 72.5467711687088, 25.507645569741726, 0.26377816451713443, 0.4699663521023467, 0.6762427662033588, 1.0185156343504786, 2.3032616078853607, 10.869383253157139, 14.02868952602148, 8.668252564966679, 7.039196854457259, 44.65182580053806, 76.65005698800087, 72.00754970312119, 71.1888076364994, 71.50482147932053, 71.64359763264656, 71.93181976675987, 69.49472174048424, 61.27220995724201, 53.6554616689682, 51.8544989079237, 53.24493549764156, 51.73340700566769, 55.866851806640625, 63.49841549992561, 64.62168842554092, 59.509119763970375, 65.22966340184212, 61.56160242855549, 60.01907519996166, 55.86260363459587, 61.12358093261719, 64.03205126523972, 63.70692931115627, 54.76916290819645, 47.990653440356255, 52.11478494107723, 63.8250307738781, 66.26009970903397, 64.30878281593323, 61.081912368535995, 63.755182921886444, 54.40399490296841, 46.61753632128239, 47.88514070212841, 50.07821202278137, 58.35010975599289, 57.736568078398705, 58.5410001128912, 58.099520802497864, 52.127590253949165, 52.472569942474365, 49.25374746322632, 56.34176552295685, 57.66854792833328, 66.50086238980293, 43.99346172809601, 41.95636823773384, 55.84903076291084, 55.930984765291214, 60.74453607201576, 52.874299585819244, 55.9241109341383, 56.62906810641289, 57.094398736953735, 59.907478988170624, 62.09872640669346, 61.05633594095707, 64.2751394212246, 63.090693578124046, 60.72185128927231, 53.09411779046059, 64.88210365176201, 62.49683864414692, 59.66848321259022, 49.341435357928276, 49.48076628148556, 47.54465617239475, 51.58095918595791, 64.14227575063705, 66.16323530673981, 61.12680695950985, 54.31639060378075, 58.7000747770071, 66.04136824607849, 62.534513622522354, 59.14746657013893, 50.90363033115864, 55.93364082276821, 58.112546503543854, 65.64507231116295, 63.636047914624214, 69.79753509163857, 68.22188884019852, 68.66854727268219, 66.56058758497238, 68.56036707758904, 63.48387748003006, 72.13080748915672, 70.59930726885796, 52.40260049700737, 8.820861876010895, 3.82223651278764, 10.722295995801687, 10.286964755505323, 3.6180371325463057, 2.6471141818910837, 0.7890600187238306, 0.24249770329333842, 0.639503903221339, 26.094734966754913, 53.18470872938633, 32.2262417525053, 48.133696764707565, 59.04780551791191, 32.73212380707264, 36.55987121164799, 53.97716000676155, 70.97915008664131, 68.62522959709167, 74.86022382974625, 13.829298075288534, 0.3451152640627697, 0.17318330705165863, 0.32098278868943453, 0.1188780831580516, 0.23404066334478557, 0.14214890281436965, 0.15795638115378097, 0.22120410605566576, 0.15842472086660564, 0.18130106676835567, 0.17461167415603995, 0.14533105393638834, 0.18733836390310898, 0.12192709298687987, 0.17502904316643253, 0.14617490553064272, 0.1771908748196438, 0.09346845326945186, 0.09773217330803163, 0.17942883598152548, 0.08717818025615998, 0.17233583377674222, 0.24723640526644886], [0.024208276481658686, 0.030225368645915296, 0.02017743496253388, 0.04869185635470785, 0.050192694179713726, 0.06769652172806673, 0.11747919415938668, 0.021271317964419723, 0.07950409126351587, 0.023101956940081436, 0.0768914123182185, 0.0954054958128836, 0.02513990744773764, 0.05528159708774183, 0.023483745535486378, 0.018400857734377496, 0.060897332077729516, 0.024658607981109526, 0.005165406273590634, 0.025190562737407163, 0.263614832656458, 47.88560047745705, 73.77420410513878, 68.02159398794174, 61.63815692067146, 54.605638682842255, 28.832168877124786, 33.49703796207905, 33.70990253984928, 35.398110151290894, 46.084071546792984, 0.9337874839548022, 0.09953637883882038, 0.054835128466947936, 0.24813330557662994, 0.5585237767081708, 1.5609849756583571, 4.4837043061852455, 2.9677901370450854, 1.48073541931808, 33.3382672816515, 70.1762455701828, 65.86460933089256, 63.241393491625786, 59.6955643594265, 55.89601144194603, 54.41226325929165, 53.18592846393585, 49.42873187363148, 47.86646090447903, 47.77162939310074, 52.65010021626949, 48.07377018034458, 45.292881801724434, 48.20914551615715, 49.94923174381256, 52.4956689029932, 56.15764260292053, 57.758116722106934, 57.896007522940636, 60.40440492331982, 55.31379908323288, 55.23763217031956, 56.31331644952297, 55.82692734897137, 51.07118234038353, 44.60086293518543, 42.73921363055706, 45.239194482564926, 53.723390623927116, 55.91736249625683, 56.7607918381691, 54.87721391022205, 45.55724881589413, 42.28436663746834, 39.31009903550148, 44.05649274587631, 48.95979143679142, 51.34756051003933, 50.81051252782345, 49.810368195176125, 45.35108707845211, 46.424267292022705, 44.63832512497902, 52.49202109873295, 51.391185969114304, 61.633904948830605, 41.48560009896755, 38.30132156610489, 61.35887570679188, 53.56411837041378, 57.863891646265984, 53.46304379403591, 53.37769277393818, 53.65692839026451, 56.16027966141701, 53.11011493206024, 56.40681803226471, 53.728106170892715, 54.55581195652485, 57.19695903360844, 56.19424223899841, 54.9372772872448, 58.07087793946266, 55.685529336333275, 52.734558284282684, 44.24148961901665, 43.51340688765049, 42.96380817890167, 44.11339469254017, 53.35435442626476, 59.11893010139465, 57.29300647974014, 52.01473630964756, 55.69538600742817, 60.83099663257599, 57.97634281218052, 55.030702874064445, 46.0707076638937, 47.61044964194298, 51.714085042476654, 60.7894154638052, 60.72333320975304, 60.34206546843052, 65.62000885605812, 69.05969068408012, 62.09080383181572, 65.02747625112534, 61.73160910606384, 57.71173641085625, 64.72557485103607, 63.944747149944305, 32.19601057469845, 3.205188810825348, 2.004366321489215, 5.053312266245484, 0.8462639304343611, 4.1946865897625685, 0.6036869063973427, 0.051697027520276606, 0.09746412441018037, 2.0263623911887407, 27.464502565562725, 43.004500195384026, 60.466968566179276, 92.9161861538887, 56.49640582501888, 19.485506415367126, 28.17878633737564, 48.34159500896931, 50.77581658959389, 60.737001076340675, 22.448843903839588, 0.6759720901027322, 0.030986968013166916, 0.0354756793967681, 0.014204976487235399, 0.033705182213452645, 0.02059139937045984, 0.022252613453019876, 0.026948042650474235, 0.025360208419442642, 0.0559192466607783, 0.018553222507762257, 0.07107894140062854, 0.0482996684149839, 0.06637548402068205, 0.0215650136306067, 0.03615323796111625, 0.06574381244718097, 0.05712350000976585, 0.03146205941447988, 0.041477869235677645, 0.054739569532102905, 0.03767808426346164, 0.048069725089590065, 0.026323380661779083, 0.02582102461019531, 0.027520073381310795, 0.059078866179334, 0.006445533554142457, 0.02904404951550532, 0.06868601980386302, 0.01804475858079968, 0.03676186584925745, 0.032051859016064554, 0.04913124859740492, 0.004124546476305113, 0.10106119545525871, 0.04184041579719633, 0.06037634811946191, 0.04089844114787411, 0.14172751136356965, 0.0301285406385432, 0.020718807572848164, 0.0306259335775394, 0.970563335577026, 60.655742436647415, 82.80974686145782, 75.69704532623291, 68.64388659596443, 60.63879534602165, 38.47684554755688, 28.836835026741028, 27.3898346722126, 35.68093657493591, 42.88688510656357, 1.9293062179349363, 0.16041263763327152, 0.08129007706884295, 0.5619544582441449, 1.3794129062443972, 4.404887510463595, 3.422230314463377, 0.27955408673733473, 2.106348811648786, 34.51366201043129, 72.36431255936623, 68.43884959816933, 64.15103048086166, 62.63987436890602, 58.67462374269962, 55.96346162259579, 57.12698958814144, 52.234136536717415, 50.77234737575054, 49.29005831480026, 54.1999002546072, 49.24806296825409, 47.86133497953415, 50.03999747335911, 50.639905482530594, 53.55512425303459, 59.1892871260643, 59.55486550927162, 59.46705982089043, 61.51432156562805, 54.346633180975914, 56.1417518556118, 58.38108949363232, 58.959536254405975, 52.53556676208973, 47.43955001235008, 43.98946814239025, 47.70277328789234, 56.744650304317474, 58.630815893411636, 59.29320015013218, 58.26691322028637, 48.25229600071907, 44.3233410269022, 43.036502078175545, 46.33740395307541, 52.57521763443947, 53.249601647257805, 53.65453451871872, 53.288739547133446, 48.23789097368717, 48.090588077902794, 47.168157175183296, 54.12954702973366, 54.69523027539253, 62.92485147714615, 44.3195716291666, 41.58096358180046, 63.073028326034546, 55.289157405495644, 60.52645817399025, 56.01952001452446, 55.25399409234524, 55.245801731944084, 58.03341194987297, 54.5628871768713, 58.11990670859814, 55.74422478675842, 56.93155847489834, 58.159572780132294, 58.33345904946327, 56.162935718894005, 60.018364638090134, 59.89165283739567, 54.512289091944695, 45.987001955509186, 45.98498806357384, 43.68393413722515, 46.082760617136955, 56.485097631812096, 61.30132399499416, 59.78948391973972, 53.774908259510994, 55.32573044300079, 63.553349152207375, 59.63822543621063, 55.59086501598358, 48.60848508775234, 49.97920073568821, 54.73300404846668, 62.780417427420616, 62.2537162899971, 63.51378947496414, 66.94454938173294, 69.95803087949753, 64.98077675700188, 67.30515003204346, 64.37357693910599, 63.89173999428749, 67.68277376890182, 65.35437270998955, 36.62086933851242, 4.55056456848979, 0.9269506414420903, 4.096995731815696, 5.3990433644503355, 7.906750626862049, 1.336483284831047, 0.06996504453127272, 0.24184778972994536, 2.2999351238831878, 32.12587013840675, 37.59897105395794, 58.226065412163734, 85.10725557804108, 54.25364837050438, 26.397519819438457, 34.552606120705605, 56.01910583674908, 57.23559156060219, 69.68353360891342, 33.20125423371792, 0.5533593194559216, 0.04204360469884705, 0.07241805782541633, 0.014087692106841132, 0.007018938649707707, 0.03758306338568218, 0.03613468797993846, 0.03496218370855786, 0.02085852058371529, 0.06831528735347092, 0.03206046421837527, 0.0546667574235471, 0.039504064407083206, 0.04177624599833507, 0.030804561101831496, 0.039758906787028536, 0.056466335663571954, 0.04673856819863431, 0.03726811075466685, 0.009719510144350352, 0.012361925091681769, 0.040732300258241594, 0.044220539057278074, 0.11470943965832703, 0.11295830510789528, 0.09585828011040576, 0.1702691602986306, 0.216157665126957, 0.1594987272983417, 0.27532936655916274, 0.13422938558505848, 0.21063025313196704, 0.15206515352474526, 0.12790515931556, 0.2413740917108953, 0.23582843772601336, 0.17240943998331204, 0.14483369624940678, 0.15614798991009593, 0.39438229228835553, 0.18642970797372982, 0.12466228567063808, 0.14062934060348198, 1.294021988287568, 75.6016780436039, 90.89536339044571, 84.59703415632248, 77.59058251976967, 68.0651168525219, 39.403323233127594, 47.76404120028019, 45.64616024494171, 49.85728047788143, 63.62143389880657, 2.304115374572575, 0.24669031816301867, 0.10879584369831719, 1.130763511173427, 1.5786947566084564, 6.1310251615941525, 14.32289158925414, 9.47866452857852, 3.631030535325408, 37.572376281023026, 74.57695662975311, 71.09334155917168, 66.73728570342064, 64.07153874635696, 62.055857107043266, 58.830343186855316, 59.978018403053284, 54.11991834640503, 51.97112984955311, 51.678910329937935, 56.29698872566223, 50.44404499232769, 51.430263072252274, 53.17651256918907, 55.10067231953144, 56.188215762376785, 60.87419271469116, 62.001687213778496, 62.380067110061646, 65.14290645718575, 55.88465765118599, 57.49145083129406, 59.30179908871651, 61.63483589887619, 55.56447543203831, 48.496786281466484, 46.98114261031151, 49.40756320953369, 57.894533202052116, 61.19773395359516, 61.01847097277641, 61.28380313515663, 50.75539268553257, 47.42020145058632, 45.53891479969025, 48.75307872891426, 54.75966341793537, 55.92300899326801, 56.91330425441265, 55.148732140660286, 51.315125450491905, 51.49712048470974, 49.81923691928387, 57.00648285448551, 57.68542282283306, 66.52152568101883, 46.63029603660107, 45.64114451408386, 65.8290508389473, 59.06212314963341, 61.986928805708885, 57.024972662329674, 58.05637411773205, 56.407410800457, 57.50702999532223, 57.8112568706274, 59.915154576301575, 58.63170504570007, 59.454805478453636, 60.9397391974926, 59.67247299849987, 55.81600673496723, 61.94522604346275, 61.66296198964119, 58.13275381922722, 48.337202444672585, 48.50654035806656, 46.23708553612232, 48.35704877972603, 59.37790900468826, 65.57656958699226, 62.42353677749634, 54.19206127524376, 56.31057679653168, 66.00191876292229, 62.56051182746887, 60.84857068955898, 51.75782069563866, 52.059057131409645, 56.774980276823044, 66.33311659097672, 65.99180370569229, 67.07536116242409, 69.40200671553612, 71.62643775343895, 67.058474868536, 68.51769536733627, 67.57900133728981, 64.95197430253029, 69.8221805691719, 70.02955064177513, 37.14870281517506, 5.5197215639054775, 5.742789069190621, 13.346131201833487, 7.4631676543504, 9.670765120536089, 0.871757356217131, 0.23250351223396137, 0.5096248537302017, 3.507743775844574, 42.45944224298, 53.258090391755104, 67.29296788573265, 98.10440495610237, 67.69761577248573, 30.863733664155006, 42.85572297871113, 64.30702731013298, 67.06694841384888, 78.43344569206238, 41.61406360566616, 1.1550271091982722, 0.2108093778952025, 0.3189998888410628, 0.11445685711805709, 0.11121704112156294, 0.06518303824122995, 0.1625668103224598, 0.11805703034042381, 0.09368045517476276, 0.18439577805111185, 0.14263784454669803, 0.17456411733292043, 0.17933648312464356, 0.07089485166943632, 0.12741779093630612, 0.1946285695885308, 0.23719841265119612, 0.16984448855509982, 0.13992603693623096, 0.10773880276246928, 0.12044494244037196, 0.1521330897230655, 0.17480583483120427], [0.02830382585671032, 0.03479446946585085, 0.049830232965177856, 0.004181040612820652, 0.04000656146672554, 0.048381152519141324, 0.05110686055559199, 0.03316452763101552, 0.05824845859024208, 0.06956296376301907, 0.021567728035734035, 0.01996093193156412, 0.028108769038226455, 0.03757186437724158, 0.04686394662712701, 0.06863141999929212, 0.021575704267888796, 0.01901436709886184, 0.03519814956234768, 0.04630856783478521, 3.5619357554242015, 63.80056008696556, 66.50662288069725, 62.140037789940834, 41.5797970443964, 41.65165118873119, 21.12488094717264, 45.771051943302155, 70.09874492883682, 49.000304862856865, 20.524931140244007, 0.031784786042408086, 0.39242934552021325, 0.15182187751634046, 0.17724488832755014, 1.1527327448129654, 1.9305003038607538, 1.7735612438991666, 0.9327792911790311, 26.3826360180974, 77.19328343868256, 64.23215612769127, 66.39169424772263, 55.79658977687359, 54.354882538318634, 50.8596096932888, 52.261954843997955, 51.417898535728455, 50.12829713523388, 48.580670580267906, 48.18160079419613, 49.11230765283108, 47.75953084230423, 49.26995359361172, 48.70908088982105, 45.281151831150055, 48.0575792491436, 50.232894122600555, 59.418943002820015, 59.09509778022766, 60.45830883085728, 53.758409544825554, 53.421147242188454, 56.490337550640106, 56.32146321237087, 48.01931910216808, 44.85998623073101, 42.84971550107002, 42.89908245205879, 41.83592230081558, 48.01248326897621, 47.7282889187336, 50.46605721116066, 41.46942816674709, 41.756612956523895, 37.789173647761345, 45.01519650220871, 47.02994339168072, 50.288667529821396, 47.950607389211655, 47.38547891378403, 43.10280092060566, 43.93006972968578, 44.362535923719406, 51.15753650665283, 53.51236514747143, 59.93030436336994, 43.05396594107151, 43.186430633068085, 57.50886909663677, 50.778465047478676, 57.92123816907406, 55.66209599375725, 51.754165291786194, 45.016769617795944, 51.873250901699066, 58.15805286169052, 59.035615772008896, 51.79051414132118, 49.02736321091652, 54.828337132930756, 57.76122495532036, 52.809136882424355, 54.74593475461006, 58.93410041928291, 52.04594403505325, 46.64671875536442, 42.99226105213165, 42.56829500198364, 42.39761956036091, 47.98942610621452, 55.54239861667156, 59.552475437521935, 57.376522198319435, 52.865552455186844, 60.02233922481537, 58.69212940335274, 55.772609263658524, 48.402555137872696, 42.955011650919914, 49.305341094732285, 59.4401078671217, 60.7805847376585, 58.25551003217697, 58.52936513721943, 62.40522176027298, 59.66490760445595, 62.442623153328896, 63.914819955825806, 61.58337526023388, 55.07579505443573, 58.26698921620846, 60.324783995747566, 17.737119533121586, 1.3921873457729816, 3.275177967734635, 1.1222880659624934, 1.8751723039895296, 0.24674335203599185, 0.023910502713988535, 0.12039815002935939, 0.05280830831907224, 9.065656140446663, 38.65252152085304, 67.1983453631401, 98.90030264854431, 71.98794275522232, 24.14510328322649, 25.98900943994522, 45.39193108677864, 48.78857262432575, 56.65956147015095, 45.31136400997639, 1.8005855125375092, 0.08406754990573972, 0.021505461845663376, 0.08373873395612463, 0.02344165463000536, 0.1284473724081181, 0.06021421853802167, 0.027835966684506275, 0.03654705862572882, 0.059928662376478314, 0.03217836550902575, 0.033136800993815996, 0.09588314205757342, 0.032310167225659825, 0.023488608458137605, 0.01866913113190094, 0.0738183272187598, 0.06413678813260049, 0.09563386207446456, 0.024711417354410514, 0.031823652316234075, 0.005717088242818136, 0.043230217197560705, 0.008230149633163819, 0.008926588434405858, 0.06066531073884107, 0.0244634546834277, 0.07015711234998889, 0.02677481981663732, 0.01660923531744629, 0.08881657515303232, 0.04164473371929489, 0.019055971897614654, 0.08032208643271588, 0.039274020891753025, 0.04120464014704339, 0.05689232471922878, 0.05361972434911877, 0.11788105228333734, 0.05416983018221799, 0.01132874698669184, 0.04348287024185993, 0.015996288129827008, 6.070974608883262, 76.82924777269363, 74.66986924409866, 70.89676290750504, 51.09295517206192, 53.395080640912056, 29.250047653913498, 52.21043340861797, 50.72539709508419, 41.907647252082825, 22.43992768228054, 0.05351399799110368, 0.1078234966553282, 0.04374889307655394, 0.7738605968188494, 2.2032621363177896, 4.5860066916793585, 2.053495072759688, 1.3536626379936934, 28.190900087356567, 80.59776395559311, 67.14839324355125, 69.33949247002602, 58.38895887136459, 57.67119638621807, 53.30860488116741, 54.63273882865906, 52.888989597558975, 52.244897559285164, 50.30517004430294, 48.9927888661623, 50.25783598423004, 50.16495756804943, 50.951374769210815, 51.4593581110239, 47.441438511013985, 50.368554443120956, 52.776378840208054, 62.23573185503483, 62.106740176677704, 61.55642710626125, 53.95617373287678, 54.06908467411995, 59.743753373622894, 59.39632661640644, 50.68965621292591, 47.3933444917202, 43.60518716275692, 44.82142969965935, 44.59250718355179, 50.52081987261772, 49.61852788925171, 53.082300424575806, 45.08014261722565, 43.976909816265106, 41.25935263931751, 46.39381192624569, 49.10098806023598, 53.42895582318306, 50.891923159360886, 49.64147865772247, 45.334884747862816, 46.57087482511997, 47.186027616262436, 54.094661101698875, 55.65181754529476, 60.28668724000454, 44.85081732273102, 46.849038898944855, 60.72592467069626, 54.77608613669872, 59.70331594347954, 57.962207570672035, 53.91306884586811, 47.70789921283722, 53.7096581608057, 59.34277608990669, 59.79890361428261, 53.86890761554241, 50.506604835391045, 57.32596971094608, 60.29298350214958, 54.8484418541193, 57.08729691803455, 60.652862191200256, 54.2146510630846, 49.464814737439156, 45.82392230629921, 45.9966154396534, 44.414878115057945, 49.828607216477394, 55.741397738456726, 61.47263400256634, 57.953753024339676, 54.65751729905605, 62.41323173046112, 62.03681632876396, 58.642013892531395, 50.92531196773052, 46.77897445857525, 50.25478474795818, 61.99773162603378, 63.63813780248165, 61.209194138646126, 61.09142325818539, 62.53801703453064, 62.75083601474762, 62.72296071052551, 66.01774111390114, 64.51480016112328, 59.624473974108696, 61.49547457695007, 62.4174153059721, 21.534136086702347, 1.993188508786261, 1.0105176572687924, 4.473766414448619, 7.474026521667838, 1.541444999165833, 0.2985748864011839, 0.033354495171806775, 0.15841225278563797, 10.336486548185349, 44.233426451683044, 71.46864742040634, 98.21739569306374, 75.90065360069275, 28.312048986554146, 32.52068415284157, 51.870127469301224, 54.2475762963295, 61.0813993960619, 57.772096171975136, 4.194232989102602, 0.09282882587285712, 0.030759794753976166, 0.04788919024576899, 0.06707279855618253, 0.1140412618406117, 0.08009027660591528, 0.05702303918951657, 0.04636464822397102, 0.0672885928361211, 0.049084478450822644, 0.05304390309902374, 0.03652143968793098, 0.03409903998544905, 0.029173107141104992, 0.02478046306350734, 0.056851899935281835, 0.036281340071582235, 0.05039035779191181, 0.028609991459234152, 0.02989502201671712, 0.025321260509372223, 0.0725047777814325, 0.09466948569752276, 0.10519199684495106, 0.1526276717777364, 0.0735817379609216, 0.12428315953002311, 0.13344570732442662, 0.08851249498547986, 0.19023058761376888, 0.2892837318358943, 0.2035951236030087, 0.15483694151043892, 0.1887748797889799, 0.08782177814282477, 0.08838278241455555, 0.15246140101226047, 0.20296085451263934, 0.11196796098374762, 0.1254016428720206, 0.14772510359762236, 0.14313469757325947, 9.826376270502806, 91.59318074584007, 82.44848504662514, 81.61428540945053, 56.57245494425297, 57.82843574881554, 30.743010342121124, 61.77406802773476, 84.68901202082634, 65.76603502035141, 29.206013716757298, 0.11011403155862354, 0.5932425137143582, 0.3166263521416113, 0.8494049962610006, 2.560793738812208, 10.336181614547968, 9.99020827934146, 4.040222028270364, 30.28156690299511, 83.06937173008919, 70.53294003009796, 72.12686330080032, 60.45484721660614, 59.44439023733139, 55.54639220237732, 56.82177096605301, 56.01857766509056, 56.455873399972916, 53.34496133029461, 51.27242714166641, 51.19593724608421, 52.4574239552021, 53.209487199783325, 52.58417375385761, 49.0267438441515, 52.555458694696426, 54.393891245126724, 64.43026229739189, 65.17495393753052, 63.76135379076004, 53.97483453154564, 53.93874406814575, 62.51081809401512, 63.26803766191006, 53.721091747283936, 49.78628508746624, 46.51529520750046, 47.949843630194664, 47.06708259880543, 52.151069194078445, 53.71635340154171, 54.979508221149445, 47.311044707894325, 46.55275359749794, 42.15903036296368, 49.154667779803276, 53.28017480671406, 57.9474263638258, 54.5745487511158, 53.22697386145592, 48.397493809461594, 48.612740859389305, 49.029529094696045, 56.01144924759865, 58.638111501932144, 63.15454535186291, 48.768175318837166, 49.74421374499798, 64.94046851992607, 57.153576761484146, 61.91678836941719, 61.01540453732014, 55.17512932419777, 48.731970861554146, 55.142891854047775, 61.86381921172142, 63.11356075108051, 57.64623172581196, 54.18418049812317, 60.505281910300255, 64.6991890668869, 55.332608073949814, 57.238152623176575, 63.19735385477543, 56.83141864836216, 52.226479947566986, 47.405405044555664, 49.241808503866196, 47.34576344490051, 51.973998695611954, 60.908375680446625, 66.29204079508781, 59.28272791206837, 53.422450572252274, 64.51720923185349, 66.35542139410973, 61.436383947730064, 52.719381898641586, 48.161830455064774, 52.757368460297585, 64.87983137369156, 66.46059975028038, 62.12698929011822, 64.5150737464428, 64.80479300022125, 65.32083570957184, 65.96515193581581, 69.02171552181244, 66.9930499792099, 61.796817407011986, 63.42965438961983, 67.32925593852997, 21.950817927718163, 3.5931615298613906, 10.408849865198135, 7.1231357753276825, 7.49984186142683, 1.3639784906990826, 0.26868595741689205, 0.24239176913397387, 0.18302672338904813, 14.618890006095171, 55.99415637552738, 72.88106963038445, 99.71876353025436, 78.32396596670151, 35.14855854213238, 38.819465562701225, 58.474112302064896, 64.80319708585739, 67.38381341099739, 68.88994619250298, 6.488920357078314, 0.2069300680886954, 0.18733149161562324, 0.20313496235758066, 0.134834443742875, 0.26639877702109516, 0.15603617794113234, 0.14571971667464823, 0.10439885620144196, 0.16558994888328016, 0.2027882161200978, 0.14380779583007097, 0.15361238300101832, 0.1066681434167549, 0.1296993755386211, 0.15480621659662575, 0.1615283082355745, 0.17363496328471228, 0.36581281281542033, 0.11933978807064705, 0.1659351514535956, 0.07769924748572521, 0.16652604943374172], [0.04477652641071472, 0.033375163984601386, 0.04135422372200992, 0.02480018934875261, 0.050878564798040316, 0.019421449942456093, 0.013697379945369903, 0.04775507673912216, 0.04789009195519611, 0.007496607158827828, 0.025828596371866297, 0.05783600630820729, 0.03477812366327271, 0.03290853863290977, 0.03351938183186576, 0.08641579421237111, 0.009399307746207342, 0.020678438449976966, 0.08794979861704633, 0.10159014636883512, 28.371257409453392, 81.14653050899506, 61.720513701438904, 49.41942237317562, 33.375182300806046, 22.376121506094933, 21.322500742971897, 30.62296338379383, 54.45555433630943, 50.337339118123055, 3.062229319475591, 0.060065659126848914, 0.0961428195296321, 0.06088706817536149, 0.22411664976971224, 2.1863221703097224, 4.701050268486142, 0.2868938975734636, 17.483046166598797, 70.12263044714928, 63.720866963267326, 62.37861558794975, 58.84075842797756, 56.68904788792133, 58.10877710580826, 62.160963267087936, 64.43149343132973, 64.48421940207481, 61.32234826683998, 54.568320885300636, 47.57458336651325, 46.282854080200195, 50.5845994502306, 53.72733101248741, 56.90921567380428, 50.396551340818405, 46.97859674692154, 49.681919887661934, 53.59378717839718, 56.45826727151871, 58.329131081700325, 58.13075132668018, 53.02063353359699, 57.2555822879076, 55.354802682995796, 49.68350060284138, 47.20359027385712, 44.901107624173164, 47.856855019927025, 43.71491387486458, 41.09769031405449, 43.22650708258152, 43.13508398830891, 40.372955203056335, 40.95048241317272, 38.85815888643265, 43.32516498863697, 46.41061082482338, 47.30835445225239, 44.143876656889915, 46.149329245090485, 41.85975082218647, 45.71107976138592, 43.53642985224724, 49.6240945905447, 51.672754660248756, 64.4035193324089, 37.95170232653618, 41.25371754169464, 60.1887246966362, 52.652030512690544, 52.78352625668049, 56.42401970922947, 59.6032939106226, 52.0113430917263, 50.34030295908451, 52.77992025017738, 57.12002836167812, 51.28565803170204, 47.21013352274895, 49.93300661444664, 56.91824398934841, 55.01235365867615, 53.26505921781063, 56.57774046063423, 55.15246354043484, 43.886508867144585, 43.90737734735012, 41.60813972353935, 43.40484291315079, 43.10494780540466, 51.994597390294075, 51.99679747223854, 56.82246632874012, 54.21191141009331, 54.19540509581566, 62.08339422941208, 57.54589430987835, 51.106619238853455, 44.13214668631554, 45.66325172781944, 54.5172668248415, 60.6783664226532, 58.404344245791435, 59.66716468334198, 53.12209188938141, 60.35181574523449, 59.51338313519955, 61.25891447067261, 61.80478937923908, 64.46567639708519, 51.798938289284706, 53.96272838115692, 47.282918617129326, 6.707134572789073, 1.4142799540422857, 4.908189503476024, 6.857377560809255, 3.030658238567412, 0.5360037507489324, 0.08561582581023686, 0.0023028835448712925, 0.9365797997452319, 18.426497541368008, 33.11569042503834, 52.68893413245678, 39.44333888590336, 23.828817754983902, 24.156719259917736, 34.83303867280483, 47.110985442996025, 48.77327084541321, 55.79689376056194, 14.921805001795292, 0.35736910183914006, 0.025739943121152464, 0.011923757392651169, 0.025583923270460218, 0.03725986920471769, 0.0556922830583062, 0.05678221226844471, 0.04289302240067627, 0.06174466805532575, 0.047522354070679285, 0.05157167135621421, 0.09846134082181379, 0.027250896418991033, 0.006656273808403057, 0.04776280249643605, 0.04214038446662016, 0.09784627851331607, 0.0536835676030023, 0.03211706040019635, 0.08993005641968921, 0.060062319462304004, 0.022319794516079128, 0.03950833917770069, 0.03751357609871775, 0.026584727966110222, 0.024459239284624346, 0.01394639368299977, 0.03495817982184235, 0.0023888247096692794, 0.06670602175290696, 0.012099626910639927, 0.13602630322566256, 0.0469162680383306, 0.03220257807697635, 0.05007342362659983, 0.038192292413441464, 0.06736256269505247, 0.0030218525580494315, 0.01565501337609021, 0.030788417534495238, 0.07933948290883563, 0.06793092907173559, 36.14412032067776, 93.65592285990715, 68.94315853714943, 57.59101688861847, 38.29977884888649, 35.968216359615326, 31.093349643051624, 32.148972898721695, 60.65280519425869, 49.49374258518219, 4.715062491595745, 0.17442152107832953, 0.04670584690757096, 0.7908262114506215, 1.7279691528528929, 4.186738366261125, 1.6909705381840467, 1.3473915494978428, 20.49629967659712, 71.51693522930145, 65.77366501092911, 65.41751772165298, 60.575049966573715, 57.89336286485195, 60.63348703086376, 65.8124989271164, 67.20058724284172, 65.0919359922409, 63.8188599050045, 57.43416890501976, 50.12299261987209, 47.55902700126171, 54.00770656764507, 55.98069749772549, 59.17563445866108, 51.798885092139244, 50.13312287628651, 51.852086037397385, 56.73658713698387, 59.320140704512596, 58.560994639992714, 60.97346618771553, 53.4818147867918, 59.3522147834301, 58.23628306388855, 52.803923562169075, 48.177318423986435, 47.037273198366165, 49.77814972400665, 46.3636339455843, 43.86196218430996, 45.32167285680771, 44.584151431918144, 42.61224344372749, 43.013547509908676, 41.27630352973938, 46.255848929286, 48.625397980213165, 49.02779258787632, 46.09502635896206, 48.08257810771465, 44.41523149609566, 46.64394110441208, 45.92200264334679, 50.691924691200256, 51.95367358624935, 63.15420337021351, 41.3620725274086, 44.10362161695957, 63.24512869119644, 53.6856434494257, 55.64495891332626, 58.0368659645319, 61.30340628325939, 54.81025390326977, 52.43419200181961, 53.57589393854141, 60.40491409599781, 53.96654337644577, 48.961835727095604, 52.03332491219044, 60.95387443900108, 56.24112032353878, 53.151278123259544, 58.876373916864395, 57.77775786817074, 46.883598044514656, 45.853545516729355, 43.607892617583275, 44.54719461500645, 45.86467131972313, 54.70341123640537, 54.61938634514809, 59.341833740472794, 55.565022602677345, 55.47281675040722, 64.06399995088577, 59.9036829918623, 54.10349942743778, 47.46028929948807, 47.71995596587658, 56.275717467069626, 62.480241134762764, 61.62842944264412, 62.95863166451454, 56.10173620283604, 61.96557015180588, 62.31724128127098, 63.2718488574028, 63.065660521388054, 66.65885031223297, 57.16049239039421, 58.63846108317375, 51.45882613956928, 9.472506009042263, 0.600707569392398, 1.445479248650372, 3.214548658579588, 7.709460938349366, 1.3147319457493722, 0.12828338745748624, 0.041738381623872556, 0.8117002726066858, 24.39032882452011, 41.877556666731834, 61.27073563635349, 53.0262154340744, 32.30025038123131, 35.17948128283024, 42.057302221655846, 53.31443376839161, 53.717018365859985, 64.48627889156342, 20.617059096693993, 0.41103587835095823, 0.05245445601758547, 0.04281133791664615, 0.01885899848275585, 0.034733387001324445, 0.0264968688134104, 0.043071783511550166, 0.012865559492638567, 0.051980349817313254, 0.04907809598080348, 0.03620006376877427, 0.03086687924223952, 0.06789625593228266, 0.016226752813963685, 0.0063017517186381156, 0.04353949610958807, 0.0754747266182676, 0.030351735986187123, 0.026467624484212138, 0.06634054370806552, 0.026181246394116897, 0.005995414958306355, 0.16207084787311032, 0.09853129566181451, 0.16376674437196925, 0.18164393899496645, 0.08686408851644956, 0.15047698718262836, 0.07414743260596879, 0.19191284343833104, 0.10502525110496208, 0.20655109779909253, 0.1672564711770974, 0.18710855045355856, 0.1106225882540457, 0.11762100373744033, 0.12844317185226828, 0.2459096084930934, 0.12301479946472682, 0.14563518605427817, 0.14461045822827145, 0.24272787297377363, 46.726054698228836, 103.58936503529549, 78.45521852374077, 68.01542311906815, 47.741451412439346, 35.461388155817986, 33.11672016978264, 41.33396163582802, 64.79506552219391, 67.88588806986809, 6.049476787447929, 0.30522031418513507, 0.35115875070914626, 0.9428913204465061, 1.6777810896746814, 7.320495285093784, 13.706533312797546, 4.455918297171593, 23.103100396692753, 74.98310923576355, 66.60393565893173, 68.22476148605347, 64.11048665642738, 61.83117896318436, 62.97401703894138, 68.43064963817596, 68.75221118330956, 67.81699016690254, 67.49480545520782, 59.37935292720795, 52.23809972405434, 50.08100487291813, 54.96195696294308, 58.00499327480793, 62.91804604232311, 55.63155323266983, 53.29587176442146, 55.807441994547844, 59.21302445232868, 61.719632148742676, 63.03238570690155, 62.09339149296284, 54.28272821009159, 62.840518802404404, 60.00072978436947, 54.65350851416588, 51.50004252791405, 51.0651520639658, 52.652699276804924, 47.77273513376713, 45.9216682612896, 47.1318007260561, 48.13446432352066, 45.24541474878788, 46.05096772313118, 44.42574553191662, 48.343582302331924, 51.447723135352135, 53.244954496622086, 49.273912981152534, 51.57696180045605, 47.35464356839657, 51.12800449132919, 49.39047932624817, 53.02893228828907, 56.33747175335884, 67.41275265812874, 44.14600074291229, 48.982039242982864, 66.36489048600197, 56.56400799751282, 57.36004248261452, 60.87225861847401, 63.786645233631134, 55.35487487912178, 53.94318222999573, 55.21988332271576, 62.35045149922371, 56.183234229683876, 51.02575957775116, 54.65980477631092, 61.67132914066315, 57.37109608948231, 54.116604924201965, 60.20916000008583, 58.812522143125534, 48.833577409386635, 48.418616876006126, 46.42159603536129, 47.113086730241776, 47.73244209587574, 58.7286302447319, 57.071117386221886, 62.39543728530407, 56.73901900649071, 56.66651129722595, 68.08505058288574, 61.8098659068346, 56.8596663326025, 49.286809489130974, 50.899948328733444, 59.33743737637997, 65.7299217581749, 65.79631939530373, 65.00088527798653, 57.51545414328575, 64.10639807581902, 63.95094081759453, 65.29563546180725, 65.70578545331955, 69.2736192047596, 59.90733839571476, 61.21175520122051, 55.1664087921381, 11.361091118305922, 3.9240983594208956, 17.966309934854507, 14.581230226904154, 8.400741219520569, 0.7298844878096133, 0.26615743059664965, 0.15126023499760777, 1.1985772848129272, 31.651893071830273, 48.31694953143597, 61.34157903492451, 52.70040951669216, 33.135240375995636, 35.52223429083824, 46.28668427467346, 62.78301268815994, 61.32368579506874, 74.30019468069077, 25.35628829151392, 0.7757600792683661, 0.23658720951061696, 0.10788331375806592, 0.14974258752772585, 0.13138442183844745, 0.1012191319023259, 0.16762306244345382, 0.12090001255273819, 0.13681618584087119, 0.22274214774370193, 0.07947765596327372, 0.18202621926320717, 0.12410581592121162, 0.18579113442683592, 0.14709729119203985, 0.12349200784228742, 0.2235990166082047, 0.12437758297892287, 0.19654892123071477, 0.194664029404521, 0.08901023858925328, 0.1482478724210523], [0.07616188857355155, 0.03434131038375199, 0.053715769390692, 0.003986791807619738, 0.01236983916896861, 0.02124586044374155, 0.11982337891822681, 0.051619105724967085, 0.08379259161301889, 0.04229908903653268, 0.037216223499854095, 0.04683069470047485, 0.017487739642092492, 0.019115184149995912, 0.03308855026261881, 0.02904674536694074, 0.022653564301435836, 0.020760247243742924, 0.024681685063114855, 1.492544710636139, 57.56359376013279, 69.2157407104969, 54.76263105869293, 51.1087167263031, 38.43518078327179, 23.666106685996056, 28.82357183843851, 41.59512922167778, 31.391768530011177, 20.713534019887447, 0.19149827974615619, 0.14100028085522354, 0.09562879320583306, 0.13366517523536459, 1.0766503773629665, 3.2305842731148005, 1.7819131957367063, 3.9499410102143884, 61.80071219801903, 70.81729397177696, 67.20109641551971, 63.08974742889404, 61.470437720417976, 64.25383016467094, 66.93566545844078, 63.450652062892914, 63.529174849390984, 62.688910737633705, 62.868637293577194, 62.31292091310024, 50.75005017220974, 47.915071696043015, 53.147675916552544, 58.09788689017296, 58.661685436964035, 54.22574646770954, 49.0902878344059, 45.92067651450634, 50.14447286725044, 52.95076668262482, 55.831787288188934, 58.966695070266724, 55.54583743214607, 57.21635699272156, 57.05532543361187, 51.600429341197014, 50.92940054833889, 50.825704112648964, 52.800040170550346, 47.82172590494156, 44.50440131127834, 40.29825881123543, 41.92001938819885, 39.54150281846523, 43.18193547427654, 38.022161945700645, 42.03020587563515, 42.76016190648079, 45.31903579831123, 43.54400284588337, 44.809190556406975, 41.98229804635048, 45.8685927093029, 42.48563043773174, 52.269611433148384, 51.55405282974243, 58.897451385855675, 36.958279833197594, 42.47791685163975, 58.255453035235405, 50.65298818051815, 46.974280178546906, 50.93441627919674, 56.9245820492506, 53.726202473044395, 54.56882245838642, 51.92977286875248, 56.93745955824852, 52.1038643270731, 46.15107335150242, 47.67185054719448, 57.047209069132805, 53.97948168218136, 51.56046308577061, 57.27704353630543, 57.629679813981056, 44.59656536579132, 43.53221967816353, 41.55154936015606, 42.059608697891235, 44.092252627015114, 50.37556126713753, 52.17849612236023, 58.455744087696075, 57.36734949052334, 51.6470642387867, 57.05330394208431, 58.118911162018776, 54.841328635811806, 46.59188009798527, 42.86071591079235, 46.7988245934248, 58.43287691473961, 58.57448771595955, 57.7604915946722, 57.84055709838867, 58.445556834340096, 62.30966068804264, 61.718043833971024, 63.7469981610775, 59.84564870595932, 62.83264182507992, 53.25926072895527, 49.416192546486855, 33.77974659204483, 4.313200330361724, 1.2165867746807635, 10.174225755035877, 4.17760650627315, 1.3850371981970966, 0.1606049429392442, 0.17145805119071156, 0.0209415131030255, 7.755362950265408, 22.68769148737192, 23.90641149133444, 31.178157292306423, 21.609486043453217, 16.013539619743824, 27.448133043944836, 45.63576020300388, 50.22814057767391, 56.803486347198486, 29.702747762203217, 1.1947074299678206, 0.08519862007233314, 0.020762638814630918, 0.03594464993511792, 0.053351990864030086, 0.0139824620600848, 0.04053548640513327, 0.0409656129340874, 0.056704516828176565, 0.04740880547615234, 0.014917101507307962, 0.023746677325107157, 0.06447353021940216, 0.009810190385906026, 0.055271793316933326, 0.03812445269431919, 0.0680160459887702, 0.04101597507542465, 0.03973811551986728, 0.03881844982970506, 0.0415502731630113, 0.037295659276423976, 0.09620642158552073, 0.006165933127704193, 0.01692115627520252, 0.04441756071173586, 0.06401808903319761, 0.06313482197583653, 0.06458685616962612, 0.05067032187071163, 0.08272140534245409, 0.02656781998666702, 0.06569543926161714, 0.0855198290082626, 0.04851844612858258, 0.020029257757414598, 0.0138107402199239, 0.03982434565841686, 0.054974385056993924, 0.033989498988376, 0.022589158870687243, 2.1175384987145662, 67.83480361104012, 78.22253420948982, 63.58139164745808, 58.92101772129536, 47.68896862864494, 29.432848244905472, 30.90981189161539, 37.77926757931709, 38.938608169555664, 24.641848728060722, 0.14412789896596223, 0.12507373234257102, 0.281075726961717, 0.9474384295754135, 2.411372931674123, 3.5320764826610684, 0.8619176060892642, 4.981912672519684, 62.87340223789215, 71.00318759679794, 70.17911821603775, 64.99433442950249, 64.67444479465485, 66.121726334095, 68.99270787835121, 66.93056613206863, 66.10180020332336, 64.42687287926674, 65.68423300981522, 63.3813551813364, 51.77704006433487, 48.841621577739716, 54.964476227760315, 60.19141115248203, 62.16920122504234, 57.038651928305626, 50.853651612997055, 47.42916136980057, 53.155419901013374, 55.22504344582558, 60.06240427494049, 61.821212098002434, 56.082604229450226, 58.456173464655876, 61.09268859028816, 54.526652321219444, 53.64250436425209, 52.92313076555729, 54.777332469820976, 50.51755204796791, 45.78175976872444, 41.9680792093277, 45.65083399415016, 42.297810316085815, 44.55400384962559, 40.83932317793369, 43.722920045256615, 45.28063885867596, 48.63204762339592, 46.527838334441185, 45.60880444943905, 44.37828607857227, 48.100098967552185, 44.96679849922657, 54.02807727456093, 53.98818701505661, 62.77155250310898, 39.59380321204662, 45.27512915432453, 61.97125464677811, 52.58689060807228, 49.918271005153656, 53.18902529776096, 59.18485276401043, 56.89647875726223, 56.324476450681686, 53.094794154167175, 58.31749610602856, 53.537538796663284, 47.86430262029171, 49.67555522918701, 57.791809514164925, 55.64419895410538, 52.48505227267742, 58.42750780284405, 60.31588867306709, 47.463716715574265, 44.547802582383156, 43.006882667541504, 45.730910897254944, 47.014960795640945, 53.95535297691822, 53.67815785109997, 60.51152877509594, 58.15637715160847, 51.27505660057068, 58.79033513367176, 59.019827619194984, 55.478550642728806, 49.43648725748062, 44.102371484041214, 49.143287390470505, 60.11031970381737, 62.22437426447868, 60.520279705524445, 59.61921125650406, 59.57038387656212, 64.90007668733597, 63.4121373295784, 65.47680974006653, 61.520712822675705, 62.73640438914299, 54.93931017816067, 53.276606798172, 37.238416001200676, 6.651092329993844, 0.4156956751830876, 0.9446762746665627, 6.782885883003473, 4.574878988787532, 0.9336150682065636, 0.3114916995400563, 0.08194724883651361, 9.93123259395361, 27.63878781348467, 26.842263154685497, 31.88122406601906, 25.77180739492178, 23.12817145138979, 30.69820884615183, 53.097169026732445, 53.30503687262535, 64.6441376209259, 39.48349133133888, 2.06986578181386, 0.08467632622341625, 0.02407567881164141, 0.037673579427064396, 0.0064247200225509005, 0.03992807192844339, 0.03295098205853719, 0.06258876455831341, 0.02211472427006811, 0.033814303897088394, 0.0327262968494324, 0.02839202825271059, 0.12353769445326179, 0.013086480157653568, 0.03246442633098923, 0.0585601383500034, 0.01820101406337926, 0.03860977645672392, 0.027414718097134028, 0.03512019808113109, 0.06568000258994289, 0.02101102079905104, 0.16603648429736495, 0.07922563745523803, 0.14282970456406474, 0.1442021582624875, 0.11156623644637875, 0.16825526836328208, 0.21039408689830452, 0.2818131842650473, 0.16965142625849694, 0.11319847151753493, 0.1392708541243337, 0.22974432591581717, 0.15603004780132324, 0.09565390006173402, 0.0864481963799335, 0.17097023752285168, 0.18636634340509772, 0.1844405147130601, 0.11927115425351076, 2.9879000829532743, 78.93413722515106, 85.78465282917023, 71.5958721935749, 66.47446900606155, 53.26634734869003, 31.85774702578783, 39.69104379415512, 55.595713555812836, 48.194812685251236, 31.658662408590317, 0.4697285976726562, 0.32432574837002903, 0.3665150032611564, 1.4934196136891842, 4.355118731036782, 9.920226484537125, 6.573555115610361, 5.747677981853485, 67.6827509701252, 72.15955674648285, 71.7029732465744, 68.33667308092117, 66.7433349788189, 68.74202013015747, 70.18324479460716, 67.9701979458332, 66.72243610024452, 64.83624011278152, 66.93606063723564, 68.50643277168274, 55.722926929593086, 52.48890906572342, 59.06322129070759, 63.64202879369259, 64.66878309845924, 60.24344176054001, 55.30340664088726, 49.43768039345741, 55.35699896514416, 57.15557545423508, 61.77125237882137, 64.9240306019783, 56.24966226518154, 59.95835445821285, 63.50721962749958, 56.81119993329048, 57.0724169164896, 55.41874185204506, 58.29430215060711, 52.53026224672794, 47.97578863799572, 43.16677428781986, 47.06076353788376, 44.97637018561363, 49.751790538430214, 43.68610002100468, 45.95680117607117, 48.11741843819618, 51.10240526497364, 48.28491725027561, 49.74335499107838, 47.26964972913265, 50.50224646925926, 47.29467138648033, 56.29354231059551, 59.0269560366869, 65.00323355197906, 43.14515724778175, 49.45255659520626, 65.52175372838974, 55.91505602002144, 51.25559404492378, 56.00220814347267, 61.20564512908459, 58.05456921458244, 59.67376872897148, 56.03813521564007, 63.40904429554939, 55.52158713340759, 50.65186724066734, 52.9498091340065, 62.401205375790596, 57.45305769145489, 52.77834713459015, 61.70702062547207, 63.658694699406624, 50.31135231256485, 48.05548936128616, 44.8337372392416, 46.68591745197773, 48.98832410573959, 55.906263291835785, 55.9595288336277, 63.265043422579765, 61.269690692424774, 52.405408546328545, 60.667191222310066, 62.92385593056679, 58.85018192231655, 51.65828503668308, 47.376405000686646, 52.13642477989197, 63.407246991992, 65.94117522239685, 63.395832404494286, 62.38308794796467, 61.755133643746376, 67.48022183775902, 66.87708780169487, 68.84637773036957, 64.67053100466728, 64.77316349744797, 58.29742178320885, 54.95053477585316, 41.46612994372845, 7.875508703291416, 3.4232310857623816, 20.47152880579233, 16.496852785348892, 5.334270615130663, 0.49822148750536144, 0.3012404136825353, 0.1644383286475204, 12.33181457966566, 37.753774747252464, 39.47695568203926, 41.64020240306854, 29.71983354538679, 25.26558715850115, 38.374387845396996, 61.39672167599201, 63.23670454323292, 73.17153364419937, 49.12948653101921, 2.7775048976764083, 0.447016682010144, 0.09774894584552385, 0.15108611230971292, 0.1556048120255582, 0.09005680039990693, 0.1758210631669499, 0.17674632836133242, 0.143831915629562, 0.10300361114786938, 0.08457613628706895, 0.1674445313983597, 0.3063523268792778, 0.1457029886660166, 0.1382085884688422, 0.13418925023870543, 0.12038471715641208, 0.1053692885034252, 0.14057957218028605, 0.1057867391500622, 0.1459600092493929, 0.09232212454662658], [0.04445450111234095, 0.09798182436497882, 0.012512022603914374, 0.059540804868447594, 0.011124831708002603, 0.04704271144873928, 0.025876346153381746, 0.05491800780873746, 0.04597215971443802, 0.01243876706212177, 0.006333311548587517, 0.0626428597024642, 0.05081572715425864, 0.03967432421632111, 0.09742549562361091, 0.07945513178128749, 0.0222508378647035, 0.12403666260070167, 0.056322696691495366, 9.707422703504562, 80.32829001545906, 67.25361719727516, 63.285923302173615, 47.790191397070885, 27.72812481969595, 26.159719079732895, 42.17631183564663, 36.329367980360985, 44.28490608930588, 8.104634508490562, 0.05052429318311624, 0.17860861436929554, 0.023343268112512305, 0.9504273254424334, 1.9243794260546565, 2.607645937241614, 0.4506037785904482, 35.573653131723404, 73.4731462597847, 66.14319518208504, 64.53996241092682, 64.02062147855759, 66.073187738657, 66.00331708788872, 65.69627076387405, 63.1557422876358, 63.426660150289536, 60.9723262488842, 63.87505888938904, 59.83721695840359, 55.42814254760742, 48.17455597221851, 54.99236673116684, 59.029209315776825, 58.9881981164217, 54.433390125632286, 50.92190735042095, 45.82045689225197, 46.50040000677109, 50.52270457148552, 53.67061145603657, 56.849414482712746, 59.30337980389595, 55.64927168190479, 58.90714466571808, 55.50818905234337, 55.32283119857311, 54.79567028582096, 54.2445782572031, 51.475807428359985, 48.70835892856121, 40.32701566815376, 40.51027603447437, 39.98351030051708, 40.97854770720005, 39.3338667601347, 43.199919909238815, 41.40483923256397, 43.84684279561043, 42.54165083169937, 43.78000058233738, 40.41754201054573, 46.59773178398609, 43.14267598092556, 50.63135214149952, 51.75181321799755, 63.53642866015434, 35.73581703007221, 39.25338327884674, 56.4318472892046, 51.67726121842861, 49.097967222332954, 43.25440138578415, 52.918308824300766, 55.49326725304127, 59.09275710582733, 54.96236354112625, 56.01325415074825, 50.77765189111233, 42.70266339182854, 44.96947355568409, 53.94735060632229, 54.58774924278259, 51.40160880982876, 55.19288957118988, 55.457917749881744, 43.33450108766556, 39.90131691098213, 42.14840993285179, 43.64000469446182, 48.68873678147793, 51.88593842089176, 53.497621938586235, 55.43603852391243, 59.232441410422325, 50.90356193482876, 54.76442836225033, 58.51012296974659, 55.56967735290527, 51.74187295138836, 45.2143058180809, 44.26546633243561, 53.46039153635502, 62.43676766753197, 60.42476423084736, 60.458453223109245, 58.447004556655884, 58.37838023900986, 59.679122641682625, 61.6997592151165, 61.34626418352127, 56.16635553538799, 61.70474074780941, 60.71730673313141, 59.79316972196102, 39.12658788263798, 2.9605422634631395, 0.28695074608549476, 8.47596388310194, 5.382856233045459, 0.6880591821391135, 0.06337092141620815, 0.08829012527712621, 0.3856192796956748, 17.82616015523672, 30.46607170253992, 37.07201912999153, 26.33792381733656, 23.40537417680025, 28.582919351756573, 37.19806596636772, 45.82320414483547, 58.73588785529137, 47.79077276587486, 6.692585153505206, 0.017141451680799946, 0.09400703725987114, 0.05405860079918057, 0.043281822436256334, 0.009316814321209677, 0.024563648330513388, 0.020267123509256635, 0.05768487164459657, 0.023868983262218535, 0.0055371670623571845, 0.03994656624854542, 0.03310422813228797, 0.016575491717958357, 0.04338608676334843, 0.01879681021819124, 0.0466025473724585, 0.1028947826125659, 0.04362601197499316, 0.059247151875752024, 0.03155865735607222, 0.11358279269188643, 0.027495640024426393, 0.06375544297043234, 0.02947345987195149, 0.06929131544893607, 0.007836605418560794, 0.09382462478242815, 0.07905724414740689, 0.05334073619451374, 0.0292598846135661, 0.06909643489052542, 0.05591086781350896, 0.030003909923834726, 0.05027122824685648, 0.04764018485730048, 0.07248868059832603, 0.06783729229937308, 0.06816428256570362, 0.11590476497076452, 0.19359918107511476, 13.415712118148804, 91.97238519787788, 74.3819510936737, 71.3353581726551, 55.86195766925812, 36.46918527781963, 31.02117821574211, 29.680279567837715, 32.90834695100784, 46.76439844071865, 9.789964724332094, 0.13158187764929608, 0.26703770679887384, 0.678340787999332, 1.979153724387288, 5.547933150082827, 1.0984788998030126, 1.2387331738136709, 36.03433661162853, 77.0820102095604, 68.70357379317284, 66.9464036822319, 65.46129897236824, 68.149244338274, 67.2261218726635, 68.18350329995155, 64.65799167752266, 62.78685048222542, 61.486009284853935, 65.71648567914963, 62.44461044669151, 57.9031777381897, 50.85622787475586, 56.03159576654434, 60.032446682453156, 62.525983080267906, 56.177967712283134, 52.97904096543789, 47.24212400615215, 49.28791522979736, 52.915306985378265, 56.23696714639664, 58.73803474009037, 59.9732306599617, 56.15128554403782, 61.679817885160446, 57.648785188794136, 57.96173259615898, 56.366160213947296, 56.80250599980354, 54.26658667623997, 49.949740916490555, 43.394712656736374, 44.615750536322594, 41.6256757825613, 43.81404675543308, 42.24427878856659, 47.1017899364233, 45.56148178875446, 46.26268096268177, 44.30318310856819, 46.64258077740669, 43.8589983433485, 48.22149485349655, 45.25611877441406, 52.7811361849308, 53.74385252594948, 66.198391020298, 37.61562176048756, 41.71073421835899, 59.148583710193634, 53.92432764172554, 51.85625821352005, 45.00131584703922, 54.22168828547001, 58.009568229317665, 60.161278769373894, 57.907900884747505, 58.12428407371044, 52.97725886106491, 44.74845461547375, 47.265295162796974, 55.37346728146076, 57.47420355677605, 50.849046260118484, 57.116205766797066, 57.59267359972, 46.07983477413654, 43.54287050664425, 43.77506084740162, 45.85111744701862, 52.15623311698437, 53.23367290198803, 54.831517562270164, 56.878733709454536, 60.61582177877426, 51.083106100559235, 57.11582198739052, 61.07230648398399, 58.03141325712204, 53.157050013542175, 49.12873797118664, 45.972885712981224, 53.559482619166374, 62.94394165277481, 63.21917608380318, 62.5783746689558, 59.869028851389885, 60.37459932267666, 62.228440046310425, 64.66176867485046, 62.4538591504097, 57.76851676404476, 60.79325705766678, 63.533438220620155, 62.07950323820114, 44.58527997136116, 5.310195107012987, 0.216246900963597, 1.0809015179984272, 4.570791833102703, 2.8406905196607113, 0.16078535903943703, 0.17812247795518488, 0.4124591691652313, 21.960725896060467, 35.83851031959057, 34.931149408221245, 20.620875991880894, 22.73069567978382, 38.78678731620312, 46.018901243805885, 52.34408363699913, 62.23929226398468, 59.21426318585873, 10.157316662371159, 0.0712772952101659, 0.046500713579007424, 0.06726068808347918, 0.05415474603069015, 0.07025702027021907, 0.03313251138024498, 0.09835250486503355, 0.11290872964309528, 0.053730367435491644, 0.01125028249589377, 0.02327084934222512, 0.008233771313825855, 0.08344340370967984, 0.03375234198756516, 0.05579876640695147, 0.016810537308629137, 0.060240802267799154, 0.0747640905319713, 0.025047439557965845, 0.07006476691458374, 0.0701566670613829, 0.14173056901199743, 0.17295444355113432, 0.12543210061267018, 0.2539805683773011, 0.10037492407718673, 0.29614426370244473, 0.20240890444256365, 0.12352284407825209, 0.1359428561409004, 0.1773145017796196, 0.10047691743238829, 0.09956188645446673, 0.2348911200533621, 0.20421521767275408, 0.21372033341322094, 0.16040782851632684, 0.16642140661133453, 0.2763373515335843, 0.2208676905138418, 19.471152685582638, 103.00261572003365, 82.39831253886223, 79.48218941688538, 63.25303226709366, 40.413069650530815, 38.67896810173988, 58.177135437726974, 48.64625126123428, 63.71469609439373, 13.56779420748353, 0.15019725688034669, 0.5129324574954808, 0.7945444900542498, 3.126140940003097, 6.506338622421026, 9.807668924331665, 2.5563520146533847, 39.67035010457039, 75.06260097026825, 73.39568361639977, 69.21700224280357, 69.44741427898407, 70.99058747291565, 70.458714812994, 70.9208232164383, 67.62698516249657, 64.7758461534977, 64.13840755820274, 67.29295268654823, 63.533138036727905, 59.631727784872055, 53.40667001903057, 59.91201214492321, 62.32436589896679, 63.4041615575552, 58.95537167787552, 54.25296060740948, 50.49312695860863, 50.71455627679825, 54.721756651997566, 57.38746181130409, 61.014443188905716, 61.444127932190895, 56.35709770023823, 62.46671766042709, 59.97369043529034, 61.852856799960136, 58.2398396730423, 58.1985092908144, 56.56686544418335, 53.811773881316185, 43.761731162667274, 46.07691653072834, 44.08399187028408, 46.345649510622025, 45.639620795845985, 49.25413504242897, 47.90149122476578, 48.49511817097664, 49.79544639587402, 48.94801586866379, 46.1239618062973, 50.143078342080116, 49.32429447770119, 55.33458396792412, 57.22864933311939, 67.994714230299, 40.990737453103065, 45.772887244820595, 61.055302396416664, 57.84877605736256, 55.144632160663605, 47.105677127838135, 57.79372841119766, 61.38716518878937, 64.29861456155777, 59.273258820176125, 60.403109192848206, 56.05914808809757, 47.71545320749283, 49.671983420848846, 58.085142374038696, 59.06684249639511, 52.49878093600273, 58.891903683543205, 60.53081274032593, 47.225526496768, 45.79412430524826, 46.91315285861492, 48.83342921733856, 53.91130194067955, 57.043804451823235, 56.69669307768345, 61.57921068370342, 62.83448852598667, 52.38836646080017, 58.324715718626976, 62.351880222558975, 60.35372704267502, 56.010700687766075, 51.68624773621559, 48.47878284752369, 57.75622062385082, 67.67677009105682, 66.38495340943336, 66.04279696941376, 61.3497181981802, 64.12072330713272, 65.46712026000023, 67.99314111471176, 65.65742924809456, 59.49848413467407, 61.9889160990715, 65.79825729131699, 63.19014184176922, 46.57706469297409, 5.46313832513988, 0.8958908705972135, 16.714552603662014, 15.734014268964529, 2.1275018015876412, 0.15926947788102552, 0.26038239360786974, 0.4326621210202575, 27.79752429574728, 46.505620926618576, 53.156347051262856, 38.390259593725204, 33.94112013280392, 41.62397727370262, 49.5991413295269, 62.49451696872711, 69.55413535237312, 69.74249124526978, 13.9415393024683, 0.1956717175198719, 0.16289596766000614, 0.20825281273573637, 0.18848998413886875, 0.16083897178759798, 0.07922315126052126, 0.29624130693264306, 0.23690731264650822, 0.1760293246479705, 0.0837772959494032, 0.09740415887790732, 0.11673618559143506, 0.11949222520343028, 0.1474363636225462, 0.15615150769008324, 0.10834026150405407, 0.16497678647283465, 0.10708442889153957, 0.17227364180143923, 0.11944060141104273, 0.20002923760330305], [0.045037647360004485, 0.0466554216836812, 0.08080852712737396, 0.1185395079664886, 0.010191055007453542, 0.013641499936056789, 0.08077464808593504, 0.07542885447037406, 0.022499776459881105, 0.034519674445618875, 0.06841452734079212, 0.03330390667542815, 0.04682721773860976, 0.12750146066537127, 0.012695285768131725, 0.0747418483661022, 0.03534043782565277, 0.12614037666935474, 0.14989731047535315, 20.613143406808376, 76.55651360750198, 56.19991533458233, 46.2669937312603, 40.18160127103329, 24.566508270800114, 25.201701186597347, 39.91056561470032, 43.228140994906425, 25.852231979370117, 0.14373377402080223, 0.08445543338893913, 0.129031412943732, 0.4361227556364611, 0.7018352241721004, 2.359127872623503, 1.5042781247757375, 10.562999043613672, 62.59755223989487, 62.65039600431919, 65.87120577692986, 68.61722722649574, 66.29881203174591, 66.21998906135559, 62.932462468743324, 62.017988339066505, 62.191232442855835, 62.290551513433456, 61.19209125638008, 63.18114772439003, 61.09611600637436, 56.43492512404919, 53.855627328157425, 57.52697132527828, 59.02208089828491, 60.52386671304703, 56.504263803362846, 50.456242337822914, 47.09463112056255, 47.41960488259792, 50.58877542614937, 55.20176209509373, 56.330491527915, 58.55725184082985, 51.74804002046585, 57.831794768571854, 54.71279673278332, 56.772734597325325, 55.412958562374115, 58.148367181420326, 54.524209052324295, 49.489433616399765, 42.006905525922775, 43.139875531196594, 40.2499558031559, 41.345235630869865, 39.099092558026314, 41.27778925001621, 42.15414382517338, 43.01270395517349, 40.50674222409725, 42.751247584819794, 40.30330494046211, 47.36883960664272, 44.78255018591881, 54.63959366083145, 49.45574842393398, 62.82089665532112, 33.88949990272522, 35.28185158967972, 57.46923342347145, 50.33062867820263, 57.49746970832348, 45.31716629862785, 43.599111288785934, 46.87521189451218, 54.44776855409145, 53.985188975930214, 55.66561460494995, 47.98231288790703, 42.24678285419941, 44.807929024100304, 55.133468359708786, 56.27931967377663, 52.321847230196, 53.5231451690197, 55.227855294942856, 44.53611060976982, 41.410827711224556, 39.64073449373245, 44.15873385965824, 52.04031653702259, 54.62491124868393, 55.01809515058994, 55.102074444293976, 54.76095914840698, 50.927287861704826, 51.37589938938618, 55.43123938143253, 56.51992656290531, 53.97429496049881, 42.73588880896568, 43.89948137104511, 48.93389202654362, 54.34466488659382, 55.66469505429268, 57.157460153102875, 55.02020783722401, 53.55016931891441, 55.2711995691061, 59.75742504000664, 59.26445849239826, 57.50814713537693, 59.93024356663227, 65.50337791442871, 62.4483722448349, 66.80742233991623, 42.069966942071915, 2.0081649301573634, 0.8029353898018599, 5.308375954627991, 3.4800615487620234, 0.3626661957241595, 0.03891515909344889, 0.09175631115795113, 4.552965089678764, 22.1827669814229, 32.01406493782997, 36.69536054134369, 28.22889994829893, 15.354921910911798, 24.513172432780266, 48.85336294770241, 49.563951417803764, 55.55358901619911, 22.952668368816376, 0.1836525319959037, 0.026287820655852556, 0.0541342404903844, 0.057939457983593456, 0.033284069068031386, 0.04323041015595663, 0.02007517443416873, 0.07827115390682593, 0.05156616462045349, 0.037654413463314995, 0.05080508104583714, 0.03622745272878092, 0.06981855200137943, 0.04350822571723256, 0.0246428336322424, 0.05452212026284542, 0.03546624298905954, 0.025890975739457645, 0.04928766735247336, 0.06459404758061282, 0.08780808551819064, 0.09765858936589211, 0.04068937814736273, 0.01582882621733006, 0.06244240561500192, 0.021013532968936488, 0.02949788951809751, 0.04632112126273569, 0.01494928845204413, 0.031112088545341976, 0.044960163431824185, 0.037335846573114395, 0.033521433870191686, 0.059109672729391605, 0.023371902025246527, 0.010543373846303439, 0.05658065238094423, 0.015170582973951241, 0.08111739414744079, 0.1444104197435081, 28.791100680828094, 88.44410732388496, 65.12377828359604, 53.94484654068947, 48.82254280149937, 30.469846799969673, 24.640539698302746, 34.38001938164234, 39.714705124497414, 29.76126652210951, 0.37626768462359905, 0.06999136108788662, 0.1847819471731782, 0.8914623863529414, 4.252972137182951, 4.233568478375673, 0.42032765632029623, 11.091388240456581, 67.83498600125313, 65.51066592335701, 67.88668602705002, 70.22964790463448, 67.23704248666763, 67.57408440113068, 66.35554298758507, 65.35286039113998, 64.50440391898155, 64.14202496409416, 63.98300349712372, 62.66803465783596, 64.15539264678955, 59.59693685173988, 56.39938183128834, 59.98176880180836, 61.48216009140015, 61.219259798526764, 57.904207482934, 53.58795069158077, 49.81376901268959, 50.78553646802902, 53.34911450743675, 56.82346947491169, 57.79923811554909, 59.49048176407814, 51.16416335105896, 58.940275087952614, 57.61821582913399, 59.16949778795242, 57.92528495192528, 58.02078902721405, 56.26610018312931, 51.351569294929504, 43.165345564484596, 46.09229810535908, 44.353762194514275, 44.08465303480625, 41.05518959462643, 42.900568172335625, 44.14310909807682, 45.230154767632484, 42.02934332191944, 44.165193513035774, 42.58913688361645, 48.40789005160332, 46.05940327048302, 56.59162111580372, 52.00793847441673, 64.87099304795265, 37.12462730705738, 37.427368462085724, 58.721900805830956, 52.46243588626385, 59.20004054903984, 47.350748777389526, 44.99155797064304, 48.22171904146671, 55.86186267435551, 56.1926045268774, 57.93753929436207, 50.852982848882675, 44.57032397389412, 45.769885405898094, 57.239626944065094, 57.96934738755226, 52.79234558343887, 55.94865761697292, 58.45470294356346, 46.56726501882076, 42.348472997546196, 42.735470831394196, 45.359632819890976, 54.5549152046442, 57.487278655171394, 58.241785168647766, 55.703658163547516, 56.86886943876743, 50.59101730585098, 51.52723766863346, 56.55208803713322, 57.636504247784615, 54.53131467103958, 44.82614144682884, 46.50280527770519, 51.36926494538784, 57.20176577568054, 57.64382645487785, 59.30344820022583, 56.610707491636276, 56.89333252608776, 57.903227135539055, 63.37742239236832, 61.61804839968681, 58.16701278090477, 60.467698127031326, 66.39340415596962, 64.77907598018646, 68.37561339139938, 47.72388495504856, 3.2082096487283707, 0.33547304396051913, 1.226078427862376, 8.083376549184322, 0.8841253363061696, 0.16567044222028926, 0.04110352252610028, 4.470697604119778, 30.783681459724903, 30.00411719083786, 28.346657529473305, 30.620377622544765, 20.53555727005005, 30.825133435428143, 54.55124840140343, 54.00282762944698, 63.66991549730301, 31.386910490691662, 0.1862684392835945, 0.04158877949521411, 0.06997378703090362, 0.019226856966270134, 0.03414683058508672, 0.019598891885834746, 0.04204884797218256, 0.05810159127577208, 0.017811557227105368, 0.03037746253539808, 0.02215553497080691, 0.037985556045896374, 0.0829976772365626, 0.028918086645717267, 0.0014239000711313565, 0.024105244119709823, 0.03643897594884038, 0.020488034897425678, 0.022103922310634516, 0.04618371262040455, 0.0703735597198829, 0.21775599889224395, 0.2172250219155103, 0.13726374541874975, 0.1715627682278864, 0.10320900793885812, 0.08157201154972427, 0.12938264175318182, 0.1667027993244119, 0.10481992110726424, 0.13827297720126808, 0.13750476529821754, 0.09601763405953534, 0.19349658658029512, 0.25482044206000865, 0.10605207178741693, 0.17289122741203755, 0.14188704342814162, 0.16066904965555295, 0.3276223089778796, 38.93114537000656, 96.6254635155201, 73.90164166688919, 63.653637170791626, 56.150871366262436, 34.956866428256035, 35.84753483533859, 54.52384427189827, 60.119313821196556, 39.65722180902958, 0.8338212606031448, 0.22118863969808444, 0.6135911343153566, 1.9334197347052395, 4.960962496697903, 10.441517662256956, 5.819280864670873, 12.899948693811893, 66.76660493016243, 69.7925041615963, 70.06449356675148, 72.18289509415627, 70.09721741080284, 70.96015110611916, 67.5975139439106, 67.46371552348137, 65.57887226343155, 67.27668195962906, 64.68793407082558, 65.80182150006294, 67.18764513731003, 61.401619613170624, 59.79981556534767, 63.68229143321514, 63.729868680238724, 64.28771674633026, 61.32024697959423, 55.6832342594862, 51.85403913259506, 52.367061004042625, 54.879007413983345, 58.85211981832981, 60.27351714670658, 60.17264015972614, 52.018042132258415, 61.10480234026909, 58.52664828300476, 60.11410430073738, 59.317146465182304, 60.38659527897835, 59.44466382265091, 54.41589206457138, 45.918913409113884, 47.429176568984985, 46.03221952915192, 46.882173120975494, 42.75900296866894, 44.439797177910805, 48.00495967268944, 48.46821181476116, 45.473888888955116, 47.00921170413494, 44.060174748301506, 52.520230785012245, 49.49115872383118, 58.7877094745636, 55.7992572337389, 68.02581176161766, 40.621739253401756, 40.710981264710426, 62.43888035416603, 54.32360641658306, 61.61351144313812, 50.211953446269035, 48.303030878305435, 50.78023575246334, 58.99294026196003, 60.427503883838654, 61.01583011448383, 54.805553555488586, 45.40353946387768, 49.047304540872574, 62.81073600053787, 61.013877019286156, 52.58052594959736, 57.05717973411083, 60.28650484979153, 49.61398333311081, 44.91039052605629, 44.47411693632603, 47.17485621571541, 57.244224697351456, 59.54267576336861, 58.57032313942909, 57.35609449446201, 58.87208014726639, 51.97161242365837, 53.50838676095009, 60.33702313899994, 60.286219865083694, 57.378323301672935, 46.75441637635231, 48.91910322010517, 54.24450986087322, 58.7107940018177, 62.165754809975624, 62.885926365852356, 60.70106640458107, 58.78121182322502, 61.14706367254257, 65.906832665205, 62.48967602849007, 57.57460176944733, 63.26647974550724, 70.98609611392021, 69.2753367125988, 70.95642730593681, 51.67538031935692, 3.0628641229122877, 2.6837997883558273, 12.60975731536746, 11.889162082225084, 1.1593889188952744, 0.1754853897728026, 0.34280899562872946, 7.140424372628331, 37.79168151319027, 44.53364834189415, 51.1130902916193, 40.50843693315983, 25.871514044702053, 35.112730264663696, 63.21402736008167, 63.35808522999287, 70.25657325983047, 38.16463150084019, 0.6000294245313853, 0.17072227114113048, 0.21014162310166284, 0.13256038451800123, 0.10118727892404422, 0.07551000831881538, 0.08445185623713769, 0.1570786430966109, 0.2441381019889377, 0.13216176215792075, 0.151097422640305, 0.2766183583298698, 0.1282442020601593, 0.21538606903050095, 0.1511924175429158, 0.17513932631118223, 0.15097091614734381, 0.11790953591116704, 0.11652794637484476, 0.11692221232806332, 0.17155518347863108], [0.03397494547243696, 0.07130039084586315, 0.016585106241109315, 0.1278597695636563, 0.035040020156884566, 0.013441501341731055, 0.05861843776074238, 0.06095572425692808, 0.07791145719238557, 0.08418141020229086, 0.0331633810128551, 0.02846887207851978, 0.006936483723620768, 0.013419362148852088, 0.036156711212242953, 0.036592953038052656, 0.14585699915187433, 0.07335929403780028, 1.0852868389338255, 39.76531460881233, 71.035645455122, 57.92679727077484, 52.415527403354645, 30.42358238250017, 23.195826821029186, 36.29044286906719, 40.904470682144165, 36.69120356440544, 8.614519648253918, 0.018858521652873605, 0.011415352837502724, 0.1387062281719409, 1.1232516705058515, 2.271744436584413, 4.994689486920834, 0.4430680407676846, 39.89964880049229, 67.73920074105263, 65.19989579916, 67.65597760677338, 61.89403519034386, 62.99722619354725, 62.6824738830328, 61.15195780992508, 62.41639696061611, 60.25682084262371, 60.58999456465244, 59.559550657868385, 62.50081703066826, 59.14575286209583, 59.841313138604164, 54.851591885089874, 60.73886297643185, 58.626776710152626, 59.88682709634304, 57.14361749589443, 53.922298550605774, 49.13415648043156, 51.38856790959835, 53.923499286174774, 56.75951890647411, 56.15777559578419, 55.84947533905506, 55.14144413173199, 54.97825048863888, 54.10438098013401, 54.439674988389015, 50.50475053489208, 56.195195987820625, 55.76259680092335, 49.390201941132545, 40.68167343735695, 43.098054975271225, 38.34475323557854, 40.97405634820461, 38.98791432380676, 41.428226977586746, 39.895959198474884, 41.48528091609478, 40.11921241879463, 43.065718710422516, 41.593255922198296, 48.57495188713074, 45.379114374518394, 55.1010674983263, 50.464054718613625, 60.33539682626724, 32.598287388682365, 33.43647301197052, 55.69883622229099, 50.951648354530334, 56.6300218552351, 52.107721120119095, 47.898994758725166, 42.56452560424805, 47.84364312887192, 46.93698137998581, 51.62303812801838, 47.01731286942959, 43.07391107082367, 44.615613743662834, 53.68275560438633, 56.09796680510044, 51.5462214499712, 53.249567449092865, 55.49606770277023, 41.872138157486916, 41.65125980973244, 39.420844092965126, 45.90510495007038, 51.42936632037163, 54.62081506848335, 54.296734258532524, 52.40515775978565, 53.827398642897606, 54.50296439230442, 54.04600091278553, 56.951492205262184, 57.370237335562706, 55.29676079750061, 42.58094072341919, 42.172329649329185, 45.20284563302994, 49.53711345791817, 51.978193670511246, 49.3406829982996, 51.17136016488075, 51.166466027498245, 54.65100824832916, 60.24325177073479, 58.93935173749924, 58.13383296132088, 63.434917107224464, 54.002288058400154, 58.88245739042759, 54.09187205135822, 66.23949721455574, 28.715032562613487, 1.2747740023769438, 0.6876977859064937, 4.365400979295373, 0.5236247868742794, 0.17715033871354535, 0.08060431777266786, 1.3279985776171088, 15.989733897149563, 36.88707925379276, 33.589543998241425, 53.98153357207775, 44.18275997042656, 20.21234091371298, 40.37863589823246, 42.4131341278553, 56.63247272372246, 36.65409475564957, 2.096275077201426, 0.174825546273496, 0.05808749789139256, 0.09505919486400671, 0.09104726326768287, 0.05239249410806224, 0.043487022558110766, 0.06419763682060875, 0.024866676503734197, 0.02439926076476695, 0.017990700544032734, 0.02181679279601667, 0.05528056179173291, 0.0533830608765129, 0.014700656920467736, 0.09852538074483164, 0.08051716737099923, 0.010384137713117525, 0.008745111990720034, 0.01199669937705039, 0.03790270639001392, 0.08651520489365794, 0.05682726434315555, 0.050551136664580554, 0.022751598298782483, 0.019918469952244777, 0.07406728807836771, 0.0516314736159984, 0.03933472115022596, 0.016427934206149075, 0.1188319809443783, 0.053517070482484996, 0.017935766773007344, 0.03573256268282421, 0.048525496531510726, 0.019294073281344026, 0.04976529504347127, 0.06818184920120984, 0.03761890540772583, 1.1364590493030846, 50.925828740000725, 79.79090765118599, 65.01812875270844, 57.84732073545456, 40.046241134405136, 30.87714124470949, 32.12336227297783, 34.274221658706665, 42.20785014331341, 11.447120402008295, 0.11811391595983878, 0.09375000925501809, 0.9200679638888687, 1.0711593157611787, 4.487845133990049, 2.4591914657503366, 0.566077830735594, 41.40958517789841, 70.72629645466805, 67.05421909689903, 70.382741689682, 64.86669167876244, 65.74868515133858, 62.91474401950836, 64.39550936222076, 65.22842466831207, 62.32616700232029, 62.13130205869675, 62.556689232587814, 63.39731812477112, 60.09815275669098, 62.81531475484371, 57.360692247748375, 62.990432158112526, 61.15462526679039, 60.02310298383236, 59.530987590551376, 56.327527686953545, 52.03070305287838, 52.970153242349625, 55.88664494454861, 59.761281833052635, 58.966353088617325, 58.260924741625786, 56.69286288321018, 55.668156668543816, 56.30530647933483, 54.40618738532066, 51.65428385138512, 58.0227193236351, 58.10888729989529, 51.414452120661736, 44.171675965189934, 44.16197508573532, 40.339418202638626, 43.926049545407295, 41.90542817115784, 44.64521035552025, 41.62216477096081, 44.19529929757118, 42.55437254905701, 44.78176362812519, 45.34089222550392, 50.68701155483723, 49.48120705783367, 56.856007128953934, 53.8054396212101, 62.82582879066467, 35.57299196720123, 36.863877698779106, 58.05355466902256, 53.858860954642296, 58.4075740724802, 54.9883009493351, 48.94977517426014, 43.028381913900375, 50.216129422187805, 50.04508160054684, 52.65337184071541, 47.42677889764309, 44.80848379433155, 46.17094628512859, 54.785657823085785, 58.5925405472517, 53.51196236908436, 57.585491985082626, 57.38229028880596, 43.82079519331455, 42.999062687158585, 41.24020926654339, 49.93249364197254, 55.48543207347393, 57.59491167962551, 55.12660592794418, 53.993149548769, 55.900141820311546, 55.90016081929207, 54.320976957678795, 58.17574471235275, 58.73121030628681, 55.62419302761555, 46.55021533370018, 44.72888566553593, 46.62143111228943, 51.31018191576004, 55.468002408742905, 53.358773589134216, 53.831597417593, 53.69562551379204, 57.015875950455666, 62.48548485338688, 60.77669754624367, 58.597123101353645, 65.22745952010155, 56.81808516383171, 62.55267284810543, 56.25260330736637, 67.42750346660614, 32.95587480068207, 2.5791291799396276, 0.6806174002122134, 4.518108135089278, 2.6882626488804817, 0.8839021576568484, 0.10313704187865369, 0.7599019270855933, 18.19188293069601, 40.49575321376324, 29.741410687565804, 45.90526834130287, 42.7514261752367, 24.82403375208378, 43.074978813529015, 48.09974558651447, 61.23677305877209, 47.29427620768547, 3.1283977814018726, 0.1693009099108167, 0.01621576531761093, 0.025862690636131447, 0.08154016599291936, 0.047033634982653894, 0.04312434612074867, 0.04088755013071932, 0.013951502442068886, 0.06850207850220613, 0.0024734780163271353, 0.03221207014576066, 0.06024175963830203, 0.09768374075065367, 0.08818134127068333, 0.04684169703978114, 0.13829482602886856, 0.04350385075667873, 0.06013460464600939, 0.024973549479909707, 0.08579048284445889, 0.17829682328738272, 0.146115088427905, 0.09938663570210338, 0.21229554346064106, 0.17622200102778152, 0.10467790372786112, 0.16811525478260592, 0.1583095989190042, 0.12283905147342011, 0.13036962394835427, 0.1670610043220222, 0.09717863504192792, 0.08553962208679877, 0.1203503186115995, 0.19793225481407717, 0.06362921849358827, 0.26372891559731215, 0.16326662589563057, 1.7626346927136183, 67.00758039951324, 89.0261372923851, 74.84044969081879, 67.71277695894241, 45.152403339743614, 34.67842496931553, 49.83766213059425, 55.0785993039608, 54.81172442436218, 14.191149808466434, 0.34578251419588923, 0.2872152772033587, 1.1683836299926043, 2.9406341817229986, 8.340378608554602, 13.429420832544565, 1.8488281988538802, 44.05955918133259, 72.7337059378624, 69.85262453556061, 72.17056855559349, 67.95331165194511, 69.02341783046722, 66.27463772892952, 65.70975244045258, 67.54516795277596, 65.76073050498962, 65.51328018307686, 64.72618281841278, 65.22181302309036, 61.54378138482571, 66.51072666049004, 59.87362280488014, 66.01192742586136, 60.29026284813881, 62.677024975419044, 61.418274119496346, 58.01025599241257, 53.53213548660278, 57.792607471346855, 59.61720496416092, 62.048284113407135, 60.06416738033295, 59.927013739943504, 57.68364831805229, 56.94853596389294, 59.020420387387276, 54.39125418663025, 50.775926783680916, 59.032005965709686, 60.73697067797184, 53.711983636021614, 45.54524905979633, 46.73840023577213, 42.7048596739769, 46.16528458893299, 44.50341336429119, 46.31180852651596, 46.04056008160114, 48.160622119903564, 45.63993617892265, 47.30996936559677, 47.217866107821465, 53.752717450261116, 50.68298377096653, 58.86580288410187, 56.910872384905815, 64.0044267475605, 38.18739227950573, 41.6165828704834, 63.10702130198479, 56.69382803142071, 61.21853403747082, 57.50701479613781, 52.244528979063034, 46.210486963391304, 52.15716026723385, 52.430019825696945, 56.34265087544918, 51.38377256691456, 48.90127457678318, 48.413574546575546, 56.993134170770645, 60.88023439049721, 54.723162576556206, 59.50964413583279, 60.9981344640255, 47.53120109438896, 46.72770380973816, 42.92107567191124, 51.83239549398422, 56.64042949676514, 59.919528141617775, 56.9065748155117, 54.48945991694927, 57.807468473911285, 57.89983011782169, 58.33714485168457, 60.65843649208546, 62.968659326434135, 59.69674229621887, 48.664946258068085, 47.21437029540539, 50.71422189474106, 53.778742253780365, 58.44160884618759, 55.07104530930519, 57.372843995690346, 56.882077530026436, 60.862257555127144, 65.912144780159, 62.84732423722744, 60.71982599794865, 67.77145341038704, 59.755912721157074, 64.52531799674034, 57.08806827664375, 70.59770375490189, 36.587849110364914, 2.7321255952119827, 3.222698508761823, 17.58112460374832, 4.60209502838552, 0.8796268526930362, 0.17081211553886533, 1.683020533528179, 23.900157026946545, 55.62625631690025, 46.88564993441105, 63.13719168305397, 51.63224123418331, 30.20920928567648, 53.96017871797085, 57.790745571255684, 67.97836750745773, 54.3699449300766, 4.219931960105896, 0.32024755782913417, 0.2006195715512149, 0.20087693352252245, 0.1482960526482202, 0.18990913376910612, 0.16856040980201215, 0.20277264586184174, 0.1302469617803581, 0.16175902710529044, 0.10942666180199012, 0.10453893657540902, 0.12722134444629773, 0.2592800074489787, 0.15142865799134597, 0.2117998481844552, 0.16581186588155106, 0.1545524614630267, 0.10791595341288485, 0.07894996670074761, 0.13805203983793035], [0.03735656362550799, 0.04133814509259537, 0.08392609655857086, 0.031879562011454254, 0.11017192649887875, 0.08554518077289686, 0.030073970519879367, 0.021945202897768468, 0.06387137385900132, 0.03894227345881518, 0.041983962000813335, 0.03008737927302718, 0.036027852111146785, 0.06218555943632964, 0.044982576291658916, 0.055178872717078775, 0.09960602197679691, 0.07503049928345717, 8.256722297519445, 59.080635756254196, 64.1051821410656, 53.50679084658623, 36.93834990262985, 25.747672989964485, 21.404029168188572, 35.39544649422169, 46.677227318286896, 30.108662880957127, 1.1194357252679765, 0.038397822791012004, 0.011246040194237139, 0.1273814108571969, 0.3298550454201177, 3.4785112319514155, 1.278267321176827, 6.699515031650662, 60.3730034083128, 63.206165581941605, 63.672605752944946, 61.92544050514698, 65.95499888062477, 61.66757494211197, 63.77258598804474, 60.45539438724518, 57.84322455525398, 50.20581677556038, 54.0699016302824, 59.78318005800247, 58.70353639125824, 59.989425390958786, 57.190525978803635, 60.487780049443245, 59.73996117711067, 58.950754925608635, 58.91717992722988, 58.04044537246227, 55.8424761146307, 51.98477491736412, 51.48621886968613, 55.379026383161545, 58.97248215973377, 56.94432958960533, 56.091925129294395, 57.742571756243706, 57.71330572664738, 54.277765676379204, 56.17365874350071, 51.495342180132866, 54.299907088279724, 56.41776144504547, 50.81349536776543, 43.7355125695467, 42.19414047896862, 41.6953906416893, 42.97920495271683, 40.127644166350365, 39.207527339458466, 39.53865297138691, 40.569898635149, 38.61135832965374, 43.244468718767166, 42.84305065870285, 51.36026322841644, 49.033978655934334, 52.37040102481842, 52.29246340692043, 59.53343465924263, 34.62913781404495, 30.05704455077648, 51.50498606264591, 45.98097927868366, 54.67983730137348, 51.464126855134964, 54.22798454761505, 44.194486141204834, 42.60446526110172, 44.05235476791859, 44.72318597137928, 44.664072543382645, 41.97128243744373, 45.22977098822594, 56.220115050673485, 54.54555630683899, 54.313225373625755, 55.301396548748016, 51.12920522689819, 43.64342451095581, 41.621047630906105, 39.16449084877968, 47.725963443517685, 53.27159106731415, 54.4937688857317, 53.745444640517235, 55.620796009898186, 54.58694368600845, 56.24134451150894, 55.29801093041897, 58.28605659306049, 56.49207025766373, 54.30192098021507, 42.088840529322624, 43.83856683969498, 42.64196924865246, 47.0458797365427, 47.59157605469227, 47.327380031347275, 48.320574536919594, 50.51491878926754, 54.843737706542015, 59.48302276432514, 57.62117587029934, 60.989831909537315, 59.318939968943596, 55.61940908432007, 57.44287043809891, 58.19587603211403, 62.54095807671547, 61.63307659327984, 18.33118725568056, 1.5710875648073852, 0.9008873056154698, 1.4239340485073626, 0.8903672138694674, 0.33648542244918644, 0.1287836246774532, 6.560455318540335, 26.58884145319462, 33.38910095393658, 37.519733905792236, 19.75229199975729, 21.020249761641026, 28.499320037662983, 42.49983787536621, 50.849141255021095, 48.480906933546066, 11.384599506855011, 0.24678940972080454, 0.06092066520068329, 0.08877603162545711, 0.030570111084671225, 0.03402928552532103, 0.061976028882781975, 0.07935649293358438, 0.034481297989259474, 0.048818771028891206, 0.09272594194044359, 0.02198807862441754, 0.06624779751291499, 0.06375136115821078, 0.07523813736042939, 0.060722211201209575, 0.03259369361330755, 0.045460838518920355, 0.021906264264544006, 0.09394420703756623, 0.036567018687492236, 0.03535617877787445, 0.0061476874270738335, 0.05153504265763331, 0.03462437292910181, 0.016186114662559703, 0.06326587783405557, 0.020185713619866874, 0.11534174205735326, 0.04631364041415509, 0.07574998919153586, 0.08906121671316214, 0.03105696552665904, 0.03332912856421899, 0.04789403647009749, 0.028853441872342955, 0.04825076088309288, 0.08258211164502427, 0.03340358081914019, 12.820553854107857, 72.04071432352066, 70.08307456970215, 61.5868254750967, 43.79197753965855, 32.42610722780228, 26.096461974084377, 35.71268007159233, 47.060478553175926, 37.23403863608837, 1.29077791236341, 0.10315893523511477, 0.22216030396521091, 1.1059018014930189, 2.5786549178883433, 4.367349799722433, 1.703211225103587, 6.938267145305872, 63.70908759534359, 66.71625003218651, 67.04756945371628, 64.1710402071476, 67.14864403009415, 64.0366642177105, 64.26019102334976, 62.49170131981373, 60.45255973935127, 53.054284527897835, 57.72753596305847, 63.47711764276028, 61.553915441036224, 62.974780797958374, 60.66254407167435, 61.19769975543022, 62.106971964240074, 59.34957392513752, 59.69831161201, 60.267946645617485, 58.24265532195568, 53.367003947496414, 54.68708351254463, 59.60799425840378, 61.53886824846268, 58.63969601690769, 57.24624238908291, 59.106189385056496, 58.989121466875076, 56.95635974407196, 56.95618115365505, 53.18176008760929, 56.90337918698788, 57.90654435753822, 52.39217385649681, 45.562040358781815, 45.75477361679077, 43.432410433888435, 44.236401692032814, 41.87393546104431, 42.36100472509861, 41.6149527579546, 43.29652972519398, 40.64747907221317, 46.259401738643646, 45.440230295062065, 53.141649439930916, 53.189849853515625, 54.960676431655884, 54.132032096385956, 63.812164664268494, 37.10692025721073, 33.90838108956814, 57.2542979568243, 49.11539688706398, 56.183165833353996, 52.830145955085754, 57.553486302495, 47.33243376016617, 44.631075114011765, 45.23741237819195, 47.812040224671364, 47.978220507502556, 43.781129121780396, 45.76358534395695, 58.28079007565975, 56.43141031265259, 55.52632927894592, 58.68581794202328, 53.73737767338753, 45.75615294277668, 43.448437973856926, 42.167921885848045, 49.89339753985405, 55.762087628245354, 57.19566710293293, 53.990352898836136, 56.716566011309624, 57.6949755102396, 56.73044666647911, 57.23538637161255, 60.08454188704491, 58.12600538134575, 56.965315863490105, 45.057378038764, 45.38514465093613, 44.823048412799835, 49.02250327169895, 50.477319806814194, 49.7231400758028, 51.18758149445057, 52.99678221344948, 58.27010124921799, 60.72492152452469, 60.90934082865715, 61.79633103311062, 61.258158311247826, 58.2539901137352, 59.85175497829914, 61.44775673747063, 64.55155938863754, 63.117687329649925, 23.155341893434525, 2.5990458112210035, 2.551962537690997, 5.864817146211863, 1.3935211929492652, 0.6270647363271564, 0.16246141050942242, 4.79778072796762, 32.42803372442722, 32.828805819153786, 40.61898820102215, 28.187417574226856, 27.638345137238503, 35.21155536174774, 47.4509683996439, 57.097031995654106, 58.17506454885006, 16.93146586418152, 0.3034277306869626, 0.0026967102394337417, 0.04392670052766334, 0.11262739630183205, 0.018903872442024294, 0.07221623076475225, 0.032649632994434796, 0.0253134531158139, 0.06888200616231188, 0.09518639155430719, 0.07455682352883741, 0.04033593402709812, 0.02714091941015795, 0.045823529799235985, 0.027553798427106813, 0.01329885313680279, 0.02251183264888823, 0.09375105568324216, 0.060825766777270474, 0.016692253811925184, 0.13749203004408628, 0.0895459578896407, 0.2969904901692644, 0.09694722597487271, 0.225744862400461, 0.1897050134721212, 0.13608214241685346, 0.13739396265009418, 0.14824104466242716, 0.16625920281512663, 0.1859581473399885, 0.1640577701618895, 0.13879930833354592, 0.16634174447972327, 0.1343291302327998, 0.14095975959207863, 0.37081842077896, 0.10864561074413359, 16.114154420793056, 81.91005393862724, 79.34272170066833, 71.96321368217468, 52.329921796917915, 38.12704011797905, 30.396024361252785, 50.47101594507694, 60.28284564614296, 46.618778854608536, 2.494582054205239, 0.16924685187404975, 0.26927278842777014, 2.121722074225545, 3.7543080328032374, 10.47944437712431, 5.437096422538161, 8.321885000914335, 65.28121143579483, 67.85412937402725, 70.14077827334404, 69.03944537043571, 69.5881587266922, 66.98281332850456, 67.64401584863663, 64.88436833024025, 62.91941396892071, 54.973660334944725, 60.28830215334892, 65.90043380856514, 62.27715723216534, 65.38202002644539, 62.23701998591423, 63.88407200574875, 64.69501689076424, 61.956006065011024, 62.204516530036926, 60.93157723546028, 59.98183719813824, 57.19344802200794, 57.575707510113716, 61.63368836045265, 64.489356726408, 58.39121975004673, 59.32835966348648, 62.44135782122612, 62.635136023163795, 57.548728957772255, 60.06676264107227, 53.842901811003685, 56.59303463995457, 60.19739583134651, 55.495881512761116, 47.28793054819107, 48.54926526546478, 47.09597244858742, 47.645776346325874, 44.42552134394646, 44.21762689948082, 44.90234635770321, 44.65822085738182, 43.333376348018646, 48.508474454283714, 48.29396456480026, 56.01169243454933, 55.56487061083317, 56.61047950387001, 58.64113613963127, 63.57972353696823, 41.04269206523895, 38.21655951440334, 60.14022409915924, 52.914775013923645, 60.633027255535126, 58.08537036180496, 58.78651633858681, 49.0950071811676, 47.474504336714745, 48.16250301897526, 50.33769629895687, 50.75758896768093, 47.00576148927212, 49.030403047800064, 59.99299339950085, 59.50402423739433, 58.28402750194073, 60.390657261013985, 57.11142562329769, 47.75806412100792, 46.37018099427223, 44.309334978461266, 54.208248406648636, 58.16123329102993, 58.463092893362045, 56.19948595762253, 59.067876040935516, 58.85367393493652, 60.85896693170071, 59.42845769226551, 61.603574976325035, 60.88598348200321, 59.500946402549744, 47.39906698465347, 47.90942519903183, 47.340295538306236, 52.49486334621906, 53.09240408241749, 54.569571018218994, 54.73615787923336, 56.46972365677357, 61.084192246198654, 64.39626172184944, 62.37083740532398, 65.36571890115738, 65.41694015264511, 60.69927290081978, 63.492860198020935, 64.00368958711624, 65.88939160108566, 64.76321563124657, 26.43319420516491, 3.296951511874795, 9.56070402637124, 11.80774575099349, 1.5102205309085548, 0.7583202025853097, 0.17889699811348692, 8.69815981015563, 42.30325162410736, 47.85770997405052, 52.07375854253769, 27.719864062964916, 32.0007998496294, 39.588282108306885, 57.22272165119648, 64.94863048195839, 69.39583584666252, 18.375893756747246, 0.4480922024231404, 0.22370878024958074, 0.2534568792907521, 0.21496256988029927, 0.1575848471838981, 0.2526487992145121, 0.19653165887575597, 0.11698733578668907, 0.13147129764547572, 0.3475150727899745, 0.15260742598911747, 0.1409827364841476, 0.1785928214667365, 0.17804949515266344, 0.13580794853623956, 0.15246333059621975, 0.10110906398040242, 0.22285765560809523, 0.1848564884858206, 0.12668263429077342], [0.0506033801502781, 0.13870416500139982, 0.073781457322184, 0.07818870129995048, 0.059669771580956876, 0.029900823756179307, 0.03913172520697117, 0.07129720703233033, 0.082971382944379, 0.025940760860976297, 0.028399022994562984, 0.047163666677079163, 0.0896266070776619, 0.0597189871041337, 0.03361741211847402, 0.0610962573409779, 0.09890148634440266, 0.18000483163632452, 31.65111791342497, 71.13208428025246, 61.425691321492195, 63.80008891224861, 42.60657414793968, 25.16583491116762, 30.559957064688206, 39.7109205275774, 33.16254951059818, 20.189492739737034, 0.04837274027522653, 0.07230663177324459, 0.4381674318574369, 1.3854310708120465, 1.0647422913461924, 2.5489286379888654, 0.8765563205815852, 17.324615567922592, 71.49801224470139, 64.99037504196167, 65.73613822460175, 59.67495806515217, 56.159660294651985, 48.68540436029434, 51.026800721883774, 49.84535671770573, 47.94502928853035, 44.451048374176025, 51.75009950995445, 59.66197416186333, 59.379455521702766, 59.781014174222946, 59.24707442522049, 56.09968811273575, 60.058995857834816, 54.54407058656216, 55.79074189066887, 57.7855284512043, 56.56286045908928, 52.80625283718109, 52.768699452281, 55.984881073236465, 58.33486117422581, 57.61888839304447, 58.41412112116814, 54.325977489352226, 55.84614671766758, 54.753294959664345, 59.03600335121155, 53.35599973797798, 54.73475955426693, 56.52063712477684, 50.456344932317734, 42.82056726515293, 40.56541867554188, 40.076346918940544, 41.550584211945534, 39.78592470288277, 41.14024043083191, 39.0076694637537, 39.84774738550186, 40.4679349064827, 43.77156123518944, 47.54166193306446, 52.475374191999435, 48.158520832657814, 55.75203336775303, 50.65419651567936, 61.779649928212166, 31.973239928483963, 33.23180839419365, 53.09816837310791, 46.82046063244343, 51.44093669950962, 51.402292773127556, 53.87839190661907, 54.855486676096916, 45.59585854411125, 41.08844541013241, 42.94935755431652, 41.768274530768394, 41.288063898682594, 43.14413130283356, 53.69846776127815, 55.767285749316216, 56.86216279864311, 54.948448687791824, 49.082730039954185, 40.90831607580185, 41.097146943211555, 40.00314004719257, 45.32489888370037, 54.29730422794819, 55.42079754173756, 52.45201304554939, 56.32119342684746, 53.93923044204712, 52.059117928147316, 51.40518821775913, 54.262133315205574, 54.234778583049774, 52.25328370928764, 41.03239081799984, 41.47668957710266, 41.31514884531498, 46.046065986156464, 47.14965216815472, 47.83833481371403, 48.94155241549015, 52.11725860834122, 56.296091973781586, 57.493761107325554, 58.6076333373785, 60.40856570005417, 58.50211299955845, 51.130595952272415, 46.93589843809605, 56.72046460211277, 57.085685804486275, 62.4873885512352, 47.76308365166187, 11.33256509900093, 3.177775894291699, 2.5801192643120885, 1.02022708626464, 0.18819334771251306, 0.04146444007346872, 0.8489613106939942, 23.942880034446716, 34.08573657274246, 26.94537442177534, 23.159569166600704, 16.921367906033993, 29.89366091787815, 41.63951463997364, 48.77718083560467, 51.03528946638107, 30.629879012703896, 1.1539796716533601, 0.10773124769912101, 0.04451241831702646, 0.03437499646679498, 0.0489795610337751, 0.01336468256340595, 0.007921168507891707, 0.03583708305086475, 0.03416322833800223, 0.04315572041377891, 0.017778655965230428, 0.07185302369180135, 0.01552595760585973, 0.02651450409757672, 0.024840107616910245, 0.08278258057544008, 0.0802542467135936, 0.021619175568048377, 0.021076576558698434, 0.02910200197220547, 0.05949776772467885, 0.061672839292441495, 0.05474959223647602, 0.10494966336409561, 0.03790361181017943, 0.02571622779214522, 0.05755557467637118, 0.10172929163672961, 0.09291046953876503, 0.06458343486883678, 0.07244948035804555, 0.03391710248251911, 0.03835189127130434, 0.026569445290078875, 0.05687622382538393, 0.013419487386272522, 0.11196176405064762, 0.11350880056852475, 38.513023406267166, 79.11478713154793, 67.13257849216461, 68.65552917122841, 50.54234191775322, 34.93087202310562, 25.815624743700027, 36.23640976846218, 42.987598702311516, 23.509735576808453, 0.21575929509708658, 0.06952158160856925, 0.5916669045109302, 1.9071056717075408, 3.7932559428736567, 3.2935896422713995, 0.7964273483958095, 19.12696335464716, 73.90847370028496, 66.29792287945747, 67.42228254675865, 62.372912093997, 57.366266548633575, 53.248967081308365, 54.16749179363251, 51.15041568875313, 49.94471378624439, 45.53794205188751, 54.57613326609135, 61.77358165383339, 61.79204486310482, 61.18568480014801, 62.22856543958187, 57.45355926454067, 60.50073355436325, 57.483874037861824, 57.82844714820385, 60.50816975533962, 59.33415815234184, 55.62909856438637, 54.74603354930878, 57.82971628010273, 59.25674110651016, 59.86017532646656, 60.086023807525635, 56.94945551455021, 57.94534407556057, 56.499795243144035, 59.738232269883156, 54.67032641172409, 54.55100521445274, 57.6660742610693, 53.18289242684841, 43.34495432674885, 42.55563408136368, 42.00841024518013, 43.45840863883495, 42.55941107869148, 43.677033707499504, 41.19789473712444, 42.104681879282, 42.69884839653969, 46.70701012015343, 50.781774669885635, 53.41011643409729, 51.04910172522068, 57.4835966527462, 52.69965335726738, 63.89982596039772, 35.10605402290821, 37.19275765120983, 55.33652566373348, 51.951754689216614, 54.25249703228474, 54.21398989856243, 57.55893141031265, 55.02644330263138, 46.55833549797535, 42.527367398142815, 45.00973239541054, 43.49775172770023, 43.631842732429504, 44.632180854678154, 56.32839784026146, 56.37108854949474, 57.99897439777851, 56.754263788461685, 53.15806455910206, 44.42956052720547, 42.832464426755905, 41.803373247385025, 48.15301112830639, 55.552973449230194, 57.49686174094677, 53.13059203326702, 57.438880652189255, 56.73863522708416, 54.086548537015915, 53.99485185742378, 57.8726501762867, 58.55360023677349, 52.8909844905138, 43.09575229883194, 43.72971028089523, 44.25133869051933, 47.40918964147568, 48.38747374713421, 50.39259195327759, 51.11526757478714, 54.022483974695206, 58.88154163956642, 59.69623692333698, 61.16771176457405, 63.089758828282356, 60.48689849674702, 52.748423740267754, 50.7785714417696, 59.23182584345341, 61.291265934705734, 64.19426456093788, 52.29738414287567, 12.928303722292185, 1.8141152802854776, 3.5391531279310584, 4.56530730240047, 1.0887881135568023, 0.017934011593752075, 0.7729387900326401, 25.221695713698864, 41.62633314728737, 27.22934078425169, 23.83769027888775, 19.729056246578693, 34.82090212404728, 47.46420308947563, 53.243556171655655, 60.52463047206402, 39.33151088654995, 1.494196553248912, 0.1595643479959108, 0.08944560468080454, 0.04194299915980082, 0.015456273649760988, 0.023910309755592607, 0.04842403010115959, 0.01103701059037121, 0.05881358920305502, 0.04791921383002773, 0.0027197747976970277, 0.08175181166734546, 0.012266089706827188, 0.046505763893947005, 0.036804899282287806, 0.03661728434963152, 0.07197697719675489, 0.035172782954759896, 0.059160843811696395, 0.06481379750766791, 0.17695497575914487, 0.14228103478671983, 0.21287953946739435, 0.17442315380321816, 0.08888716824003495, 0.12513277761172503, 0.21826868935022503, 0.20505504682660103, 0.29038311971817166, 0.15174611908150837, 0.1301060279365629, 0.1251391600817442, 0.09606395149603486, 0.20039011433254927, 0.09748532756930217, 0.18000281299464405, 0.34687029488850385, 0.34724436700344086, 45.611426308751106, 87.75136649608612, 75.73489129543304, 77.15358316898346, 57.6460949331522, 37.743108719587326, 42.43709184229374, 56.693714037537575, 50.64938597381115, 29.39806681126356, 0.3108055691700429, 0.18896852096077055, 1.1642866185866296, 4.092165715992451, 3.934851544909179, 9.582189973443747, 3.6545854713767767, 20.237007290124893, 75.80541551113129, 68.10261324048042, 70.20064026117325, 65.26346638798714, 60.998681634664536, 53.73447462916374, 55.6575096398592, 52.53392904996872, 53.34453955292702, 46.93554885685444, 56.30489990115166, 64.36591655015945, 64.08982336521149, 62.745960876345634, 63.80365312099457, 61.89443796873093, 60.33509284257889, 58.2234625518322, 58.53679373860359, 62.57675215601921, 61.25646360218525, 57.844847068190575, 57.37129367887974, 61.07623167335987, 62.066093757748604, 63.166488111019135, 63.884505182504654, 58.875534161925316, 60.92397004365921, 59.92421329021454, 63.61766830086708, 56.05846792459488, 56.34356662631035, 60.7404512912035, 56.05655662715435, 46.34268566966057, 44.2750608175993, 44.2840663343668, 45.90596370398998, 46.6032262891531, 46.71582944691181, 42.715103924274445, 43.90836529433727, 44.64923053979874, 49.34019282460213, 53.532918244600296, 56.62114933133125, 53.623239398002625, 60.10814622044563, 55.13045892119408, 66.16859301924706, 38.736132234334946, 41.16359017789364, 57.65836447477341, 54.05190959572792, 58.195830434560776, 58.524106219410896, 61.02800466120243, 58.92194487154484, 48.94774608314037, 43.89741808176041, 47.399796545505524, 46.64864905178547, 46.153110042214394, 48.131793066859245, 59.25052843987942, 59.824609234929085, 59.91407163441181, 59.73671615123749, 56.47825799882412, 46.0338344424963, 45.49619369208813, 44.295838102698326, 50.659140050411224, 59.01802271604538, 60.026872381567955, 56.65850132703781, 60.80350510776043, 59.12456899881363, 55.9561812132597, 55.973219498991966, 60.14705993235111, 61.156525164842606, 56.44954293966293, 45.78184716403484, 46.024407148361206, 46.411404982209206, 51.0774140059948, 53.4046371281147, 53.10413405299187, 53.92810083925724, 57.565201073884964, 63.29495161771774, 60.47417677938938, 65.685243755579, 64.6900087594986, 63.51577676832676, 55.58020658791065, 51.827235370874405, 59.75887656211853, 65.16819790005684, 67.10594192147255, 55.09471423923969, 15.203371793031693, 6.505693132057786, 8.703483324497938, 6.507869465276599, 1.0648078378289938, 0.17676229937933385, 1.2330539035610855, 31.915771812200546, 51.835758313536644, 38.03461007773876, 34.27990235388279, 24.92541991174221, 43.305067867040634, 56.80305317044258, 63.2350630313158, 67.52769649028778, 45.08608169853687, 1.7160960962064564, 0.33279769064392895, 0.2059436944546178, 0.11741106500267051, 0.08689711408806033, 0.16358551190933213, 0.08584802155382931, 0.18179308099206537, 0.18253913236549124, 0.13678397663170472, 0.05463192472234368, 0.14549779967637733, 0.07712380844168365, 0.12727007386274636, 0.13574358948972076, 0.11459287052275613, 0.13262345222756267, 0.10246838166494854, 0.13088712352328002, 0.1652607024880126], [0.027708090929081663, 0.03020244370418368, 0.014169307942211162, 0.013910043289797613, 0.046960180916357785, 0.03535892472427804, 0.03483963657345157, 0.0683620129711926, 0.042130565852858126, 0.03840723693429027, 0.07113008279702626, 0.0316348610795103, 0.002676490425983502, 0.018843981124518905, 0.04316313817980699, 0.0042501707412156975, 0.04962728897226043, 3.0402679229155183, 48.99617448449135, 60.28307743370533, 59.295958802103996, 40.45765645802021, 29.80891026556492, 13.379904739558697, 41.13971225917339, 39.329740181565285, 38.42665784060955, 8.338549956679344, 0.2401540009304881, 0.040358977712458, 0.18785665015457198, 0.20613901288015768, 2.7269744966179132, 2.1356737380847335, 0.3861693595536053, 39.02205169200897, 70.01851603388786, 64.43526282906532, 64.54266786575317, 58.73587265610695, 59.29728113114834, 54.4773081690073, 50.85576809942722, 48.478839844465256, 45.652285516262054, 44.554019048810005, 48.01922410726547, 57.944397926330566, 59.76500563323498, 58.172119706869125, 63.56491193175316, 61.00052833557129, 51.478987857699394, 55.681345760822296, 54.24002230167389, 57.95825958251953, 56.47499777376652, 56.303113996982574, 57.69913628697395, 57.18853108584881, 58.484865725040436, 56.96892946958542, 55.87244130671024, 51.767312586307526, 51.02143160998821, 51.745197772979736, 54.780547097325325, 53.411047384142876, 54.081240221858025, 55.25288835167885, 49.650347381830215, 41.64039999246597, 40.41937731206417, 40.201185420155525, 40.71146763861179, 40.49516424536705, 41.04304164648056, 37.63750098645687, 40.21089389920235, 40.002437084913254, 48.60357575118542, 49.59265507757664, 53.69432978332043, 52.24380701780319, 56.914379596710205, 52.84486636519432, 61.25755034387112, 30.930860862135887, 32.10806429386139, 54.308749213814735, 49.31608311831951, 53.23074325919151, 45.459533259272575, 51.52064122259617, 52.70139366388321, 52.40639269351959, 40.03364861011505, 42.176232039928436, 41.77249610424042, 41.84835523366928, 39.86834228038788, 50.8373086899519, 54.328584149479866, 56.53634928166866, 53.27397733926773, 46.355836763978004, 40.8539941906929, 40.37220664322376, 41.85213603079319, 43.53243246674538, 52.84085378050804, 54.56174723803997, 53.317500203847885, 54.862166717648506, 54.090355932712555, 50.820114612579346, 51.004207134246826, 51.09540984034538, 52.30044297873974, 46.89131163060665, 40.40732815861702, 43.46402853727341, 43.4294617921114, 42.59916074573994, 43.72190549969673, 43.69871914386749, 48.06751191616058, 50.47027878463268, 57.05958880484104, 57.58674591779709, 60.4765934497118, 58.12400668859482, 57.48264670372009, 47.48564533889294, 50.02634100615978, 55.368599742650986, 62.90484935045242, 60.76552614569664, 60.80281734466553, 36.974805146455765, 5.211206618696451, 4.510959293693304, 2.3527152417227626, 0.5132218357175589, 0.10384807872469537, 0.27023654140066355, 6.561788097023964, 34.56201821565628, 40.55543661117554, 38.763262778520584, 18.31251885741949, 16.661798134446144, 26.493483670055866, 43.978862911462784, 51.56801328063011, 44.13394398987293, 3.9895536471158266, 0.2274674762156792, 0.013900931571697583, 0.06568744633113965, 0.01837132396758534, 0.11028121516574174, 0.07145431227399968, 0.014282837055361597, 0.09919020405504853, 0.06144161947304383, 0.06807774814660661, 0.0111453929093841, 0.013774078124697553, 0.05522342384210788, 0.022104230301920325, 0.04012053679616656, 0.05571259192947764, 0.028756266910932027, 0.043072551634395495, 0.025160290533676744, 0.057453187982901, 0.03629642422311008, 0.04019690379209351, 0.02896129633882083, 0.047917213742039166, 0.07426537471474148, 0.04636888959794305, 0.026554067990218755, 0.01346515266050119, 0.03182996799296234, 0.03427001225645654, 0.037490769900614396, 0.0822922213410493, 0.02015860482060816, 0.07027165542240255, 0.04425327148055658, 0.06367996655171737, 4.729902120307088, 59.16445165872574, 69.00220736861229, 65.34184098243713, 48.58455017209053, 38.34170579910278, 20.550028793513775, 44.32000480592251, 36.77782751619816, 45.38166023790836, 10.117864329367876, 0.3825822629733011, 0.02778279551421292, 0.7260846917051822, 3.00075716804713, 5.32382782548666, 1.6723903664387763, 0.7454737450461835, 42.2854495793581, 71.63468331098557, 65.73497548699379, 65.5208569765091, 59.8858505487442, 61.01212151348591, 55.121290013194084, 53.08870688080788, 50.33072367310524, 47.8572653979063, 45.92039912939072, 49.91710066795349, 60.12799255549908, 62.84115716814995, 60.45784145593643, 62.793055549263954, 64.7525230050087, 54.065444469451904, 58.647485598921776, 56.27151109278202, 59.8882482200861, 58.3812490850687, 57.76647247374058, 59.02358181774616, 60.330707877874374, 58.79956103861332, 57.65157423913479, 58.47453407943249, 54.430361688137054, 53.8500302284956, 54.53768312931061, 56.342947259545326, 54.8050519824028, 55.75271733105183, 55.80323942005634, 52.06128381192684, 44.743796065449715, 42.80640162527561, 42.25528299808502, 44.16069075465202, 42.494103983044624, 44.64134596288204, 39.91437681019306, 42.47471362352371, 42.678447291255, 51.3835521787405, 51.00994482636452, 55.1825313270092, 54.612679705023766, 59.59543213248253, 54.26985830068588, 61.83204151690006, 32.975158765912056, 34.95635725557804, 57.78775133192539, 50.60553252696991, 54.813947305083275, 49.011350870132446, 52.47419245541096, 54.92805138230324, 55.31075544655323, 42.56164535880089, 44.83417421579361, 43.57475459575653, 43.359830528497696, 42.429515048861504, 52.51397632062435, 57.18220442533493, 57.79480755329132, 56.955352798104286, 49.67565022408962, 43.537987768650055, 43.045386001467705, 41.28335975110531, 45.47544300556183, 55.576376393437386, 56.93503148853779, 53.933215364813805, 57.5215870141983, 56.718788892030716, 53.65512728691101, 53.42702552676201, 54.631792679429054, 54.904561042785645, 49.093559458851814, 41.6301329433918, 45.37691809237003, 44.8128991574049, 44.09579783678055, 46.22632831335068, 46.50136515498161, 50.68052910268307, 52.72425703704357, 58.88468787074089, 59.741610288619995, 63.295646980404854, 60.34818693995476, 59.05524551868439, 49.55165907740593, 51.43730789422989, 57.97225423157215, 65.90253129601479, 62.36831434071064, 62.3357804864645, 41.56037628650665, 6.073141917586327, 2.0160065218806267, 0.7348302786704153, 1.8940182239748538, 0.5171418003737926, 0.327064540470019, 6.684402767568827, 38.65472540259361, 39.47080001235008, 35.1909376680851, 21.003638952970505, 28.686705082654953, 32.91166417300701, 49.93970565497875, 57.399647757411, 54.103218242526054, 7.247688341885805, 0.262367787072435, 0.04612496792105958, 0.08259804555564187, 0.04463809360458981, 0.02687715084903175, 0.013299461697897641, 0.07206787544419058, 0.08735876705031842, 0.1364308627671562, 0.04533820603683125, 0.030063673220865894, 0.023627048685739283, 0.024779479717835784, 0.027586495598370675, 0.0795019390352536, 0.02072035309538478, 0.02687562573555624, 0.029842375915904995, 0.027351197677489836, 0.2336040578666143, 0.20849567314144224, 0.12231692831846885, 0.23635188932530582, 0.17499539419077337, 0.1876635433291085, 0.16355051222490147, 0.18736729281954467, 0.07812106938217767, 0.12244960948009975, 0.15425389545271173, 0.09511588010354899, 0.16377124178688973, 0.09278577388613485, 0.1452014155802317, 0.09560243212035857, 0.1451690134126693, 5.875347331166267, 67.62165784835815, 77.82708942890167, 76.30548387765884, 57.14363269507885, 42.86671578884125, 20.6247840821743, 55.687011256814, 51.78897522389889, 55.21566554903984, 11.470540445297956, 0.3967884834855795, 0.07859779536374845, 2.27736480999738, 4.366233134642243, 10.803995411843061, 8.425456993281841, 0.9410842799115926, 45.6073909252882, 72.26695418357849, 67.71311894059181, 67.11870923638344, 64.2518162727356, 62.7752611041069, 57.972926795482635, 55.73483169078827, 54.11745987832546, 51.206314489245415, 48.617023229599, 53.68825390934944, 62.112846449017525, 64.05920460820198, 62.42404595017433, 62.64376536011696, 68.0964195728302, 56.50940112769604, 57.473405599594116, 56.60385645925999, 62.663151919841766, 59.933420196175575, 58.99395860731602, 61.24771647155285, 60.534464344382286, 60.56666761636734, 59.25109460949898, 60.88835455477238, 55.65355405211449, 56.410785019397736, 57.85175509750843, 59.709205627441406, 57.34941825270653, 55.16216441988945, 58.35095711052418, 54.31294038891792, 46.74097649753094, 46.08848311007023, 43.31424817442894, 47.0748645812273, 45.02846919000149, 46.655659675598145, 42.187156453728676, 43.520227521657944, 44.8009791970253, 54.74711649119854, 53.1327199190855, 56.35723829269409, 56.25600792467594, 62.093106508255005, 58.49647790193558, 64.75931704044342, 35.94740487635136, 38.82451169192791, 62.10248440504074, 52.925330847501755, 58.871836960315704, 50.19544333219528, 55.58771878480911, 58.72640736401081, 56.96255341172218, 45.386824160814285, 47.71038807928562, 45.57996019721031, 45.38188822567463, 44.08491902053356, 55.26271462440491, 59.37086038291454, 62.44775667786598, 58.57826091349125, 52.20660701394081, 46.41425862908363, 46.568450555205345, 45.4012405872345, 47.12950564920902, 58.38868148624897, 60.05690596997738, 54.95667524635792, 59.566994458436966, 58.39392140507698, 56.259929314255714, 55.57498946785927, 56.66836939752102, 56.45527683198452, 51.76666662096977, 43.89550678431988, 48.211224004626274, 47.83382065594196, 46.31400480866432, 48.04715260863304, 48.690792471170425, 55.75357988476753, 57.214202508330345, 63.466474413871765, 62.28383727371693, 66.59050717949867, 62.705743834376335, 61.410659328103065, 53.28696884214878, 55.18619433045387, 60.21227963268757, 67.82363221049309, 65.58376640081406, 63.48939098417759, 45.06604537367821, 8.112485837191343, 8.167135454714298, 9.257318805903196, 3.3006487134844065, 0.41772559750825167, 0.2913339593214914, 8.162591848522425, 49.01563324034214, 54.20245371758938, 53.197137862443924, 28.475964590907097, 28.78444153815508, 39.817497208714485, 60.126301646232605, 63.8470695912838, 62.65301026403904, 8.243450559675694, 0.39015190210193396, 0.19635179196484387, 0.2208345610415563, 0.13756934698903933, 0.16729215363739058, 0.18211134360171854, 0.11536712350789458, 0.15817553736269474, 0.19438029150478542, 0.10953851829981431, 0.19318626495078206, 0.057646847708383575, 0.08850414582411759, 0.10598593158647418, 0.21432926558190957, 0.10530467712669633, 0.1330858696019277, 0.1617902418365702, 0.08648609786177985], [0.035648406847030856, 0.03590410269680433, 0.0554939589346759, 0.035052239618380554, 0.06473343033576384, 0.03085512733377982, 0.034829183423426, 0.04568446987832431, 0.04437327304913197, 0.025695002368593123, 0.017347002467431594, 0.04744233199744485, 0.056267484615091234, 0.06245068056159653, 0.05934022461588029, 0.036745085890288465, 0.11796500402851962, 9.940779581665993, 64.82930168509483, 63.785041719675064, 57.47614525258541, 49.205098673701286, 26.895952373743057, 24.878978803753853, 26.631347872316837, 39.26049269735813, 31.43557257950306, 0.8305916120298207, 0.03591691958718002, 0.026316202238376718, 0.14605153090087697, 1.3754105335101485, 3.6406848672777414, 0.6383846257813275, 9.572925120592117, 63.38984772562981, 59.284175634384155, 69.02189031243324, 67.86238253116608, 65.36272466182709, 61.10202468931675, 63.29399786889553, 61.06146186590195, 56.20096407830715, 48.342503160238266, 43.889081329107285, 45.44580079615116, 52.875260934233665, 59.88005205988884, 58.38423952460289, 56.093657836318016, 66.02214127779007, 61.95751838386059, 53.97545389831066, 56.56417898833752, 52.8427878767252, 56.96819230914116, 57.889103293418884, 58.2007397711277, 53.75644885003567, 56.386910900473595, 57.24553182721138, 55.01106172800064, 50.251809507608414, 45.5848353356123, 47.7577905356884, 54.96618613600731, 54.32916931807995, 56.71530067920685, 55.85153862833977, 50.51896557211876, 41.732309460639954, 40.2674500644207, 38.97294692695141, 40.99683612585068, 41.88414551317692, 39.10113304853439, 38.91838185489178, 41.746562495827675, 44.712839126586914, 52.986583560705185, 50.796582475304604, 55.521913915872574, 53.102416545152664, 58.22217062115669, 51.499654948711395, 60.604969561100006, 29.964492917060852, 32.20543406903744, 55.40065482258797, 47.097461968660355, 53.370701149106026, 50.302764773368835, 48.96958351135254, 52.02270448207855, 54.05407927930355, 47.73454338312149, 38.51783014833927, 41.376971527934074, 41.23450197279453, 39.68345560133457, 44.94725614786148, 50.02883367240429, 49.826103150844574, 48.807484209537506, 42.10524804890156, 39.24919210374355, 39.712425246834755, 41.276060342788696, 41.22579284012318, 50.9565082937479, 55.469408333301544, 53.73376026749611, 54.179134368896484, 54.432968348264694, 50.26547737419605, 44.813529923558235, 48.449896797537804, 45.658752769231796, 44.35745559632778, 40.91694161295891, 41.17861457169056, 42.4714457988739, 41.1207664757967, 42.43192411959171, 43.55396211147308, 47.50787414610386, 52.512391805648804, 54.938466623425484, 59.23591062426567, 58.835795894265175, 58.944872841238976, 49.94127117097378, 44.6625792235136, 48.49222272634506, 54.36924196779728, 57.944610714912415, 59.91664409637451, 61.398902758955956, 57.43966341018677, 25.00752780586481, 1.3564009848050773, 3.0169072514399886, 1.5359642682597041, 0.05759166902862489, 0.02566479324741522, 0.386765482253395, 29.09073930233717, 34.94629919528961, 30.810025446116924, 17.992298640310764, 10.664430800825357, 37.46925741434097, 45.15055663883686, 50.48824802041054, 51.16607844829559, 20.411332435905933, 0.7099232682958245, 0.12909930461319163, 0.0758600867993664, 0.027705406209861394, 0.07009204084170051, 0.03242357481212821, 0.053758817666675895, 0.012937770461576292, 0.018951241872855462, 0.04907176917186007, 0.10014154831878841, 0.06690175578114577, 0.04106687156308908, 0.07039836229523644, 0.04002678128017578, 0.03430270015087444, 0.025884776950988453, 0.02127832569385646, 0.05641654126520734, 0.002418805156594317, 0.012984266013518209, 0.07715944637311623, 0.0021611310194202815, 0.029746393956884276, 0.040472719265380874, 0.07062246862915345, 0.007716408108535688, 0.03543572216585744, 0.06349997347570024, 0.049730299069778994, 0.056119184955605306, 0.02849019212590065, 0.05919612551224418, 0.07363891301793046, 0.025016211839101743, 0.1965390655095689, 13.819867931306362, 77.79155373573303, 67.41225108504295, 64.71421346068382, 53.35890278220177, 33.36312174797058, 22.0344153419137, 25.41254997253418, 41.97090245783329, 37.55076304078102, 0.9431815892457962, 0.055656400218140334, 0.11673540633637458, 1.4059890364296734, 2.6526697212830186, 2.5943248020485044, 0.2128284945501946, 12.078806106001139, 62.98878684639931, 59.94846738874912, 70.85196331143379, 69.02729362249374, 67.65018671751022, 63.735743165016174, 66.5426753461361, 64.3070501089096, 58.22840228676796, 50.14798387885094, 45.62657989561558, 46.47124037146568, 55.53776666522026, 60.710178315639496, 59.6153848618269, 56.32425606250763, 64.19801115989685, 65.28399288654327, 56.07991397380829, 57.403249964118004, 54.27246116101742, 58.11342045664787, 58.74753423035145, 58.64731080830097, 56.10193759202957, 57.129068076610565, 59.85315330326557, 58.12727451324463, 52.16247238218784, 46.78151272237301, 49.545568004250526, 56.37109234929085, 54.87069346010685, 57.374918684363365, 57.25196488201618, 51.30866579711437, 44.028461650013924, 42.85173699259758, 41.862756460905075, 42.86428011953831, 44.15060229599476, 42.7526231110096, 42.34188415110111, 43.79941374063492, 45.934864953160286, 55.25149002671242, 52.534301429986954, 57.78423652052879, 54.40644957125187, 60.02342216670513, 52.57007651031017, 63.11042211949825, 32.03216716647148, 34.46073845028877, 57.8761687874794, 50.30339553952217, 55.162134021520615, 52.1578898280859, 52.436194494366646, 53.00290368497372, 57.61724688112736, 48.479003235697746, 40.98805099725723, 42.396871000528336, 42.559403479099274, 40.89835301041603, 46.65490351617336, 52.751417979598045, 52.897983714938164, 52.14367859065533, 44.29938331246376, 41.31140224635601, 42.556986808776855, 44.02597278356552, 44.62327033281326, 53.079203590750694, 58.66266578435898, 56.01007752120495, 57.36383467912674, 57.20238134264946, 52.42343097925186, 47.47718699276447, 50.496580973267555, 48.197582736611366, 45.73911465704441, 43.333152160048485, 43.56155030429363, 45.34630313515663, 44.044447392225266, 44.54111114144325, 45.99793016910553, 49.030197858810425, 55.0062245875597, 58.262133076786995, 61.994038224220276, 60.4302017390728, 62.69503980875015, 53.90530966222286, 47.16159872710705, 51.91295877099037, 56.8591495603323, 61.781717017292976, 63.41054141521454, 63.25064979493618, 61.76631264388561, 30.607061237096786, 2.2953064972534776, 2.274829871021211, 3.5641702730208635, 0.7125104544684291, 0.18495982512831688, 0.29737634758930653, 31.33983101695776, 40.4208592325449, 26.475922912359238, 23.540447428822517, 19.705022536218166, 43.43465991318226, 52.743932381272316, 56.39147825539112, 59.41882520914078, 29.266253784298897, 0.7920697540976107, 0.029928522562840953, 0.03771706185943913, 0.0293947124373517, 0.03889416373567656, 0.015668099294998683, 0.05334435416443739, 0.031920268811518326, 0.055717189534334466, 0.06257221466512419, 0.05628773040371016, 0.08836607667035423, 0.05622174976451788, 0.038713038884452544, 0.09741306465002708, 0.03908124432200566, 0.025291782403655816, 0.046744687206228264, 0.086174403259065, 0.24259250523755327, 0.053756257257191464, 0.20160833490081131, 0.09915385366184637, 0.1825589031795971, 0.14940483612008393, 0.11359305659425445, 0.11141244860482402, 0.14148717425996438, 0.263277719495818, 0.15556494385236874, 0.18589332816191018, 0.17077662603696808, 0.16454467840958387, 0.16218825563555583, 0.22744432120816782, 0.3948826185660437, 19.20268189162016, 88.42906013131142, 77.85399198532104, 73.64476025104523, 64.07528534531593, 40.804209262132645, 35.83368077874184, 40.2535580098629, 54.45699825882912, 45.242914482951164, 1.4784177811816335, 0.306958572473377, 0.20286502840463072, 2.015428952872753, 5.102264564484358, 12.860789895057678, 4.613748053088784, 13.055832479149103, 64.75874707102776, 58.81965056061745, 72.46630668640137, 68.08362185955048, 71.11703708767891, 67.50954106450081, 69.01578024029732, 66.89706712961197, 60.65500907599926, 52.41469144821167, 48.608203902840614, 50.05339175462723, 57.408919259905815, 63.56461934745312, 64.31661799550056, 57.98866555094719, 63.12774159014225, 66.79724648594856, 59.756965264678, 58.810249865055084, 57.23306089639664, 58.65483820438385, 61.04021340608597, 60.65303698182106, 56.705026030540466, 58.35699498653412, 62.453239783644676, 60.64159199595451, 53.619500398635864, 50.44485814869404, 53.03705245256424, 59.00875501334667, 57.49813087284565, 58.98310258984566, 61.075034737586975, 54.20416362583637, 45.805181711912155, 44.69040893018246, 44.816660955548286, 45.821285247802734, 46.62781476974487, 43.94403778016567, 44.215761199593544, 45.64747117459774, 48.59341509640217, 55.94721369445324, 55.567397475242615, 61.053383499383926, 58.492290526628494, 61.139597073197365, 55.88954798877239, 63.25185053050518, 34.18877184391022, 38.40232774615288, 61.26321583986282, 52.04314738512039, 55.74105195701122, 54.23148036003113, 53.77067148685455, 56.759401112794876, 59.631925374269485, 51.777629032731056, 43.16571794450283, 44.730667769908905, 45.13488627970219, 44.76669363677502, 48.68782863020897, 55.279787108302116, 54.17407684028149, 56.4472820609808, 45.89134208858013, 43.12816075980663, 45.15544697642326, 45.146426260471344, 45.09178139269352, 54.66632902622223, 62.56744645535946, 57.324419394135475, 58.37173439562321, 60.5042065680027, 55.396064668893814, 50.81650100648403, 53.97861912846565, 50.2544579654932, 47.79327683150768, 44.529339373111725, 46.02394737303257, 49.56360183656216, 45.81352226436138, 47.99905098974705, 49.14462111890316, 52.294678688049316, 58.87066662311554, 61.364978179335594, 66.229427754879, 61.978987231850624, 65.25724992156029, 55.93726962804794, 49.142618626356125, 53.79527896642685, 59.28599193692207, 63.77674296498299, 66.05382397770882, 64.96972694993019, 62.88904219865799, 31.18300773203373, 3.169132308103144, 7.923955153673887, 7.825031261891127, 0.9064160089474171, 0.24306182458531111, 0.6072631676215678, 38.98263640701771, 49.08422335982323, 44.044979363679886, 27.720396034419537, 17.48386312276125, 48.70685800909996, 59.68996345996857, 63.2243400067091, 69.35602158308029, 34.093423560261726, 0.9628217853605747, 0.2825403702445328, 0.16705304849892855, 0.10702870844397694, 0.10443839040817693, 0.09464794857194647, 0.1840557111427188, 0.18713629193371162, 0.14789438748266548, 0.1734467694768682, 0.1939766076975502, 0.23279596294742078, 0.12154727664892562, 0.1276101853, 0.19658243661979213, 0.10434529540361837, 0.06668888556305319, 0.1134510911651887, 0.16646646981826052], [0.03967890326748602, 0.0917055037280079, 0.027651954878820106, 0.039012911074678414, 0.014378873747773468, 0.025460680371907074, 0.021503419084183406, 0.08538248715922236, 0.060132311409688555, 0.020006555459985975, 0.02526525619032327, 0.02289155250764452, 0.08403764135437086, 0.07319405485759489, 0.05809943533677142, 0.059145800478290766, 0.6113084068056196, 33.6134447157383, 63.44666227698326, 56.42636798322201, 49.402429684996605, 35.52200250327587, 18.808958418667316, 27.186743170022964, 53.480017483234406, 39.24041077494621, 18.14639937132597, 0.6151717307511717, 0.0727164902491495, 0.13467047363519669, 0.45825161039829254, 2.9990244610235095, 2.7708659414201975, 1.035585505887866, 52.37974472343922, 72.21922114491463, 63.54408524930477, 57.52623416483402, 62.724138647317886, 64.55286651849747, 66.53267428278923, 63.60237032175064, 59.37961131334305, 59.89876985549927, 58.33679907023907, 46.63436561822891, 43.33912543952465, 44.45701025426388, 55.29627062380314, 59.076972752809525, 58.52944113314152, 54.48145754635334, 62.319980934262276, 57.036953419446945, 59.322884157299995, 56.55314818024635, 56.913718432188034, 52.847647815942764, 54.95634846389294, 52.52898171544075, 57.47863031923771, 53.38364325463772, 53.67984876036644, 45.366449654102325, 41.40747629106045, 46.65497191250324, 55.559087321162224, 53.915876895189285, 55.02745404839516, 52.277826592326164, 49.0789720416069, 40.054273903369904, 42.92164944112301, 39.67856526374817, 41.095338240265846, 37.91296720504761, 40.265413373708725, 38.68752524256706, 41.571019515395164, 48.232860043644905, 56.4454809576273, 50.89033864438534, 58.34010869264603, 51.82561285793781, 56.73092924058437, 49.01312917470932, 58.4414454549551, 28.445484526455402, 31.578215025365353, 52.923282757401466, 48.816539123654366, 52.17964366078377, 48.577547147870064, 46.6671996563673, 46.98946036398411, 54.038758501410484, 53.68150547146797, 44.38523970544338, 38.78194637596607, 42.045006081461906, 39.220055267214775, 41.928956508636475, 44.02150422334671, 46.6394155472517, 42.67200663685799, 41.92004978656769, 40.04306450486183, 41.14593252539635, 40.66794857382774, 41.7380927503109, 49.261609241366386, 56.60346508026123, 54.15470167994499, 56.44972912967205, 54.66283321380615, 51.61821238696575, 43.75643044710159, 43.821954131126404, 42.48381033539772, 42.4258254468441, 40.369318798184395, 41.0278956592083, 42.195850387215614, 42.98258297145367, 42.36033596098423, 42.22940258681774, 43.885239735245705, 48.541471883654594, 52.020443603396416, 56.209224835038185, 56.003462076187134, 51.72308295965195, 42.74118572473526, 46.55215322971344, 51.37576259672642, 56.4486537873745, 55.54193504154682, 60.27050390839577, 62.29912005364895, 62.04830311238766, 49.34924773871899, 12.231727000325918, 0.4056618979666382, 1.2671568361110985, 0.24369622726226225, 0.057275892613688484, 0.2456825558329001, 8.877621330320835, 39.24707941710949, 39.66300889849663, 33.12541410326958, 17.206776291131973, 23.886815942823887, 33.8325409591198, 48.42096135020256, 50.44764719903469, 34.80242371559143, 1.4334552688524127, 0.1181752173579298, 0.05869289001566358, 0.06616081780521199, 0.06789051913074218, 0.04426383966347203, 0.10798895105835982, 0.07637515955138952, 0.08587776683270931, 0.032670587534084916, 0.10635488288244233, 0.07609770764247514, 0.009300070541939931, 0.03579850250389427, 0.01939004781888798, 0.01438945027985028, 0.028776505278074183, 0.034160712457378395, 0.06910139985848218, 0.07166219525970519, 0.07475498437997885, 0.015259156443789834, 0.06848398494184949, 0.06141106896393467, 0.04810313286725432, 0.06214264845766593, 0.08853507111780345, 0.01350994312815601, 0.0665420590667054, 0.056005243022809736, 0.022736282226105686, 0.02858205887605436, 0.027411901646701153, 0.039335222099907696, 0.028900334473291878, 0.7424920925404876, 45.169373229146004, 71.76561668515205, 64.7705340385437, 57.51041181385517, 45.91518200933933, 33.460582718253136, 34.06029313802719, 42.44517780840397, 44.57587167620659, 21.034688986837864, 0.393581188400276, 0.1127521661692299, 0.17881741019664332, 2.7368401922285557, 4.172223620116711, 0.6857835198752582, 1.9419844751246274, 54.24230597913265, 72.07207784056664, 62.35108606517315, 58.344189673662186, 65.65014883875847, 65.47982677817345, 66.89566880464554, 64.20982852578163, 62.344394624233246, 63.30544665455818, 59.427234157919884, 47.95317605137825, 46.074545457959175, 47.89462499320507, 60.186414420604706, 60.26081442832947, 59.56122636795044, 56.35712809860706, 61.872167363762856, 58.81215736269951, 59.15491037070751, 56.645376831293106, 57.42525078356266, 55.28415307402611, 56.83809868991375, 54.14821922779083, 58.44469428062439, 56.64513744413853, 55.82342013716698, 48.043888583779335, 43.872909396886826, 50.131830945611, 56.46875090897083, 55.75837902724743, 55.36199189722538, 55.80528371036053, 51.09314516186714, 42.57481165230274, 44.73777338862419, 42.667872458696365, 44.1128209233284, 41.48890972137451, 42.01417453587055, 41.38193026185036, 44.00133490562439, 51.038998067379, 58.29728499054909, 53.46696138381958, 59.62415099143982, 55.46783521771431, 60.03653146326542, 50.735751539468765, 60.143427327275276, 30.38011461496353, 34.93322789669037, 55.16350194811821, 50.083873718976974, 52.42062672972679, 50.52482485771179, 49.62391220033169, 50.48460401594639, 54.69075031578541, 54.60454814136028, 46.285418942570686, 41.65948636829853, 44.048399180173874, 40.72027936577797, 44.699042066931725, 45.79788610339165, 49.33604724705219, 45.85693873465061, 43.62889789044857, 41.31358712911606, 42.742424458265305, 42.172466441988945, 42.192704156041145, 52.01518848538399, 57.33597457408905, 54.55377146601677, 56.484968438744545, 58.547421768307686, 54.1795751452446, 46.223334074020386, 45.20382598042488, 44.489156529307365, 44.955304116010666, 42.80319079756737, 43.330416306853294, 43.12694102525711, 44.52528119087219, 43.84752295911312, 44.9801129847765, 46.73707030713558, 51.63689598441124, 55.59859000146389, 58.629820346832275, 58.21158818900585, 53.546259328722954, 44.287303760647774, 48.88984479010105, 53.490504920482635, 58.25058549642563, 59.351302832365036, 62.37117938697338, 63.082322627305984, 64.83789682388306, 50.26228554546833, 15.361591503024101, 1.0272065992467105, 4.709477741271257, 1.8881931365467608, 0.1648401125567034, 0.2580936101730913, 8.73710772022605, 47.03671082854271, 37.469447404146194, 27.130612581968307, 20.144275166094303, 33.41823399066925, 39.611529260873795, 53.11859227716923, 57.17414125800133, 45.00038489699364, 2.964977575466037, 0.14431440067710355, 0.025758674928511027, 0.007239106034830911, 0.09016050811624154, 0.021154700589249842, 0.050116182464989834, 0.017861622509371955, 0.019569087235140614, 0.024829353897075634, 0.05588413194345776, 0.0343680870719254, 0.03902135671523865, 0.023742081575619522, 0.09464802278671414, 0.0346358613751363, 0.07526269502704963, 0.044093479664297774, 0.03248608591093216, 0.10393391552497633, 0.20292342058382928, 0.06631836091401055, 0.20024079422000796, 0.20823442231630906, 0.10531318956054747, 0.26487698836717755, 0.16255833499599248, 0.20727439492475241, 0.16255321417702362, 0.23409527057083324, 0.12111778094549663, 0.15487548866076395, 0.17446728190407157, 0.11754973529605195, 0.1549777269246988, 0.8423232450149953, 54.28669519722462, 82.4481126666069, 72.72235214710236, 65.62930315732956, 51.87348268926144, 29.022278375923634, 38.15672792494297, 70.20648434758186, 56.28938153386116, 25.306368470191956, 1.2677957955747843, 0.18805958301527426, 0.3483245777897537, 2.8802081616595387, 12.109825741499662, 8.372634127736092, 2.074299193918705, 56.88663728535175, 72.49672785401344, 63.68949964642525, 60.09729020297527, 66.29479944705963, 65.2195255458355, 65.93296766281128, 67.0070332288742, 64.80866879224777, 65.95226302742958, 63.133612275123596, 50.668658539652824, 48.65652970969677, 48.96098457276821, 60.95962733030319, 63.193234875798225, 63.783757388591766, 60.13049282133579, 61.77810341119766, 60.602697283029556, 61.686402931809425, 57.87098206579685, 58.38803932070732, 55.791870430111885, 56.9119743257761, 55.763083174824715, 57.68864504992962, 59.65156652033329, 58.52370344102383, 48.83376359939575, 46.01563721895218, 50.15428774058819, 61.07274726033211, 58.967329636216164, 56.783187836408615, 57.72649481892586, 53.5801687091589, 44.52999673783779, 47.22955048084259, 45.93630127608776, 46.10419526696205, 44.575962871313095, 44.18181762099266, 43.969371020793915, 46.21644124388695, 53.298660814762115, 62.09906838834286, 55.7352876663208, 62.20167428255081, 57.66447834670544, 59.5714820176363, 52.091119810938835, 61.954824328422546, 32.640442326664925, 38.62688049674034, 57.5634341686964, 52.608306258916855, 55.3562618046999, 50.9147447347641, 50.18438212573528, 50.77287934720516, 58.10961306095123, 57.21283458173275, 48.835051730275154, 44.11475121974945, 45.768608674407005, 43.13206695020199, 46.33973702788353, 48.829762414097786, 50.4392496496439, 47.978657484054565, 45.75948156416416, 43.22553813457489, 44.86837238073349, 45.04429154098034, 45.92169106006622, 54.721840247511864, 59.93593946099281, 56.68551027774811, 60.40546506643295, 60.7208177447319, 54.98832754790783, 48.37848722934723, 48.49506497383118, 46.6699431091547, 46.84356339275837, 44.50377054512501, 45.01347899436951, 46.13438844680786, 47.02393591403961, 47.567948922514915, 46.19956634938717, 49.28264111280441, 53.618463054299355, 59.25918057560921, 60.918220952153206, 61.820440739393234, 57.40509286522865, 47.199851274490356, 50.98799340426922, 56.996983364224434, 60.57785801589489, 60.67390166223049, 65.82374632358551, 66.48117184638977, 67.9281722009182, 53.00751283764839, 17.087542489171028, 1.3945124647580087, 6.800830420106649, 1.5167464432306588, 0.17487871373305097, 0.28438751643989235, 10.79825296998024, 57.8492434322834, 54.42393243312836, 43.597370982170105, 24.542064182460308, 35.43766602873802, 47.036304250359535, 63.36596980690956, 63.18854212760925, 53.01362670958042, 4.029302839189768, 0.23662845807848498, 0.14306244207546115, 0.09536042518448085, 0.09783893125131726, 0.12150608003139496, 0.2711539843585342, 0.1166600857686717, 0.1552530933986418, 0.1124632332357578, 0.2334308554418385, 0.18547033367212862, 0.05381493145250715, 0.07708165445365012, 0.17659271863522008, 0.08702593608177267, 0.12869893078459427, 0.1530201343121007, 0.19360448000952601], [0.04845313342229929, 0.007597978501507896, 0.024120558337017428, 0.030997040812508203, 0.055135642614914104, 0.03530025795043912, 0.07152910591685213, 0.01736020527459914, 0.07540853446698748, 0.032361234407289885, 0.052220883590052836, 0.0145250703462807, 0.01441976422938751, 0.0776465104718227, 0.0500212432234548, 0.006940809516891022, 2.6181511860340834, 47.22948208451271, 63.273437172174454, 60.85594229400158, 47.9500488191843, 21.5102581679821, 15.239333063364029, 29.530537202954292, 35.28367169201374, 41.52871638536453, 14.190633036196232, 0.14222359255654737, 0.040550021367380396, 0.1135144779982511, 1.381206528749317, 1.2519038608297706, 0.7637790846638381, 33.53420376777649, 74.61395904421806, 62.50123880803585, 68.9318959414959, 63.636674880981445, 58.81810024380684, 54.792071878910065, 59.2446843534708, 62.724488228559494, 66.10135942697525, 58.104821518063545, 59.086913019418716, 48.0142767727375, 43.43049913644791, 41.973436921834946, 51.923628598451614, 59.286181926727295, 57.54039220511913, 56.69688306748867, 52.74854153394699, 54.52775426208973, 59.770697727799416, 56.52605943381786, 56.130565255880356, 57.276268377900124, 56.50920733809471, 57.53611363470554, 52.765405029058456, 54.9958511441946, 53.49342316389084, 42.86500968039036, 41.54157489538193, 45.90157113969326, 52.71944649517536, 54.56101767718792, 55.99915690720081, 52.94770784676075, 48.052274733781815, 40.20098403096199, 40.426026955246925, 39.7199260443449, 41.233859807252884, 35.574766471982, 39.87781897187233, 37.83982113003731, 45.168157294392586, 52.808870896697044, 54.119245782494545, 51.03068791329861, 57.656380981206894, 50.66944129765034, 57.89894476532936, 48.925863057374954, 59.79800686240196, 29.198661111295223, 30.093399100005627, 52.2293221950531, 48.6265417188406, 50.93864165246487, 50.11150203645229, 51.266906037926674, 45.67216604948044, 50.883168429136276, 52.871092557907104, 49.471965953707695, 38.94232057034969, 41.41555465757847, 42.27329783141613, 39.97954711318016, 42.40129016339779, 41.25621780753136, 39.292232394218445, 40.127849355340004, 38.24608772993088, 39.82289671897888, 41.05279192328453, 39.990665316581726, 47.42045983672142, 55.54554104804993, 53.89626994729042, 55.04488751292229, 55.46106018126011, 51.714043244719505, 44.09058831632137, 40.13780862092972, 41.10264524817467, 42.2051826864481, 41.34030729532242, 41.249416172504425, 41.12817607820034, 41.73379138112068, 44.2881815135479, 44.171805158257484, 43.543562069535255, 44.40325453877449, 47.056173384189606, 47.49169461429119, 45.38609080016613, 43.64844024181366, 44.201131984591484, 47.592662796378136, 51.79888129234314, 55.530953630805016, 52.86921165883541, 58.080768808722496, 58.34729790687561, 60.84353215992451, 61.676413267850876, 28.16052071750164, 2.9802038334310055, 3.0069190124049783, 0.8206389960832894, 0.1360950557864271, 0.097212922264589, 0.5989375174976885, 33.76583553850651, 34.18010450899601, 44.78849686682224, 30.012277252972126, 16.47643268108368, 29.915771931409836, 38.255458027124405, 52.658710554242134, 46.26491904258728, 11.641406826674938, 0.38581289118155837, 0.06115567739470862, 0.05394283318310045, 0.034832894161809236, 0.042073713630088605, 0.0552709806652274, 0.040222285242634825, 0.017262918991036713, 0.04371856150100939, 0.04811469181731809, 0.02009212508710334, 0.009097409492824227, 0.056599870295030996, 0.05364190714317374, 0.03888355102390051, 0.10303137489245273, 0.05252618087979499, 0.00725033380149398, 0.04244489136908669, 0.11144512536702678, 0.016662937123328447, 0.04213042113406118, 0.05678132540197112, 0.08088153961580247, 0.015090686138137244, 0.0647091398423072, 0.05299806434777565, 0.06494535802630708, 0.02105485760694137, 0.021968691871734336, 0.03412673693674151, 0.052146898888167925, 0.10279825888574123, 0.019613536314864177, 3.4077264927327633, 59.65621367096901, 69.68109413981438, 69.08622086048126, 54.56472247838974, 31.162954308092594, 18.86350829154253, 26.81333340704441, 36.642585173249245, 48.21689710021019, 14.25907876342535, 0.28957702859770507, 0.0651367059617769, 1.0265902010723948, 3.5533610405400395, 2.0933314226567745, 1.2813358940184116, 33.438741490244865, 76.91655948758125, 65.67242324352264, 69.7560565173626, 65.08111417293549, 59.51525643467903, 56.981609389185905, 58.694006502628326, 61.56070187687874, 65.92222183942795, 60.12987345457077, 61.5300565212965, 50.61901040375233, 45.96644505858421, 44.146019741892815, 54.86330285668373, 59.698433205485344, 60.55636636912823, 59.29538883268833, 54.52762886881828, 54.68384988605976, 60.96656955778599, 58.88822928071022, 59.41640853881836, 58.07241305708885, 59.04123567044735, 57.67970032989979, 55.946541130542755, 57.466106191277504, 55.210155844688416, 44.546480253338814, 43.23418267071247, 48.88615518808365, 57.394521832466125, 53.99170182645321, 56.748252511024475, 56.20971500873566, 49.277051612734795, 41.72957740724087, 43.12947928905487, 41.04502134025097, 44.120105132460594, 39.09753084182739, 43.182212859392166, 39.7812357544899, 48.661841824650764, 53.411723747849464, 56.53104856610298, 53.0835847556591, 57.683967500925064, 52.61020615696907, 60.33560201525688, 50.579956099390984, 59.43580649793148, 31.042403876781464, 32.67074190080166, 53.781117126345634, 49.95525822043419, 52.471676990389824, 51.38127230107784, 51.06341175734997, 47.562101036310196, 53.21421414613724, 55.27153395116329, 52.97250531613827, 41.05217255651951, 43.67485262453556, 40.81423692405224, 42.119504883885384, 43.77980679273605, 44.13718141615391, 42.13888384401798, 42.371195778250694, 40.62487028539181, 42.4125337600708, 41.51558429002762, 42.35185481607914, 49.38096083700657, 57.58885480463505, 55.24458199739456, 55.402094945311546, 58.210569843649864, 55.17109774053097, 46.112646013498306, 41.09511025249958, 42.20668740570545, 43.2700527459383, 42.35250078141689, 41.966335102915764, 43.27697217464447, 44.22363057732582, 45.55928170681, 44.99771364033222, 45.618756115436554, 46.427398324012756, 47.685746401548386, 50.67552477121353, 48.97247515618801, 46.50997929275036, 46.24713979661465, 48.61162751913071, 55.08175693452358, 57.28106752038002, 56.522031649947166, 61.21827945113182, 59.79508861899376, 61.18189260363579, 63.80682215094566, 30.305460020899773, 2.912213606759906, 1.6031525004655123, 4.252340421080589, 0.42829024780075997, 0.049756452353904024, 0.5689289839938283, 36.47626429796219, 38.334752172231674, 35.626656487584114, 26.79180186241865, 22.620095014572144, 37.98243887722492, 47.65336453914642, 57.459289357066154, 59.90729279816151, 18.917243108153343, 0.6678299582563341, 0.12523258163128048, 0.037890527746640146, 0.043360764684621245, 0.08759351578191854, 0.08280134949018247, 0.0565773832204286, 0.029396005629678257, 0.030669044936075807, 0.0259481526518357, 0.028953772816748824, 0.022497397876577452, 0.059511070721782744, 0.027739912366087083, 0.04669274057960138, 0.001785674567145179, 0.03373237821506336, 0.01594506324181566, 0.1781493437010795, 0.1855818190961145, 0.08773341061896645, 0.08650264775496908, 0.16122205357532948, 0.14508102438412607, 0.19981682009529322, 0.20191215531667694, 0.197980850643944, 0.14887451223330572, 0.11604968414758332, 0.16233870381256565, 0.11457001979579218, 0.1399593593669124, 0.17022225656546652, 0.15955999901052564, 4.455501269549131, 72.95455768704414, 77.15922206640244, 79.59133476018906, 62.44098164141178, 35.04056453704834, 21.78209748119116, 39.417378678917885, 48.48156809806824, 58.06064888834953, 20.058164186775684, 0.3583338047610596, 0.2543694240739569, 1.4565519732423127, 3.345550666563213, 7.978102248162031, 2.632544101215899, 36.26963898539543, 79.64032933115959, 66.801737844944, 72.35432669520378, 66.38050764799118, 62.30695903301239, 58.18085543811321, 60.46909265220165, 61.07741340994835, 64.5913964509964, 61.96826420724392, 62.443557903170586, 51.869314312934875, 47.82236807048321, 46.737689673900604, 57.64370486140251, 63.03690746426582, 62.574278488755226, 61.03583984076977, 57.71236337721348, 57.21764512360096, 63.37311342358589, 60.52447088062763, 60.94273343682289, 61.21919900178909, 61.070216596126556, 61.05727069079876, 57.72052153944969, 61.66531406342983, 59.69845600426197, 46.70823745429516, 46.29886642098427, 50.459141582250595, 59.93991784751415, 56.097431033849716, 55.86731158196926, 60.08126646280289, 52.009663581848145, 43.79287049174309, 45.26032514870167, 43.54354307055473, 46.03181295096874, 41.49435482919216, 44.378715455532074, 42.68350102007389, 50.51756724715233, 57.02720694243908, 59.42249581217766, 54.65178720653057, 58.8991878926754, 54.73144993185997, 61.34418569505215, 52.883552089333534, 61.14232152700424, 33.23314592242241, 36.531494334340096, 57.73664407432079, 52.24808178842068, 53.358351811766624, 53.26184459030628, 53.17852646112442, 48.87373365461826, 55.731852650642395, 58.88208881020546, 55.532769933342934, 42.95563481748104, 45.85355691611767, 45.373764261603355, 44.492173567414284, 46.74491308629513, 46.48363910615444, 44.714530035853386, 43.30560363829136, 41.66394352912903, 44.88001115620136, 43.4837456792593, 44.076612666249275, 52.93937489390373, 58.51705759763718, 57.059490010142326, 59.645593240857124, 61.87003567814827, 56.93712517619133, 46.95749267935753, 42.57955759763718, 44.77631852030754, 45.66541761159897, 45.86406335234642, 44.73849155008793, 43.984365016222, 46.45180821418762, 49.166561141610146, 48.08311387896538, 47.615043595433235, 48.73089551925659, 51.9197566062212, 53.304079324007034, 52.25005388259888, 47.48333886265755, 49.575913175940514, 52.421933859586716, 56.85591593384743, 61.11237533390522, 58.77048499882221, 64.4331881403923, 62.180574014782906, 63.4822853654623, 67.08705693483353, 34.04131695628166, 5.34614022821188, 9.463073965162039, 5.959263928234577, 0.42046002577990294, 0.16845309524796903, 0.9252939303405583, 42.89578042924404, 49.93853911757469, 63.827394247055054, 39.27852652966976, 26.674599051475525, 43.65073911845684, 54.27413687109947, 65.22888824343681, 68.48532110452652, 23.41540563851595, 0.6855882459785789, 0.1761684031225741, 0.1795953293913044, 0.26248474954627454, 0.12611616781214252, 0.15402255317894742, 0.13364669575821608, 0.07376321533229202, 0.1736712097772397, 0.2431926503777504, 0.09046649560332298, 0.10560391106992029, 0.1376056973822415, 0.07671854385989718, 0.12340209665126167, 0.14374217513250187, 0.20854542672168463, 0.09598993710824288], [0.011889202069141902, 0.010537858761381358, 0.05662118477630429, 0.0660019091446884, 0.10436692900839262, 0.02075667380267987, 0.026181222274317406, 0.02045234687102493, 0.045741949215880595, 0.007963447733345674, 0.035456888217595406, 0.04668973488151096, 0.04371466151496861, 0.08410284644924104, 0.029806294551235624, 0.0752241701411549, 11.633009277284145, 59.5340122282505, 59.361695274710655, 48.564373254776, 37.2879159450531, 22.24836476147175, 26.85112237930298, 52.40311726927757, 42.77934327721596, 47.40542024374008, 4.179071327671409, 0.1080876641208306, 0.12051497891661711, 0.23242245486471802, 6.4324606116861105, 2.2592803929001093, 9.737210255116224, 67.70775362849236, 66.90366357564926, 63.881351351737976, 61.79464392364025, 63.272874802351, 66.96185365319252, 61.516871228814125, 55.084272399544716, 50.148960426449776, 61.0721430927515, 62.51130446791649, 56.901087909936905, 53.270481526851654, 45.59742026031017, 40.52450627088547, 45.70913426578045, 57.25693121552467, 58.38094890117645, 56.15028239786625, 51.54015317559242, 49.47056382894516, 50.65805710852146, 53.233562707901, 52.339181900024414, 52.77781516313553, 56.515119820833206, 53.3201714605093, 54.64252710342407, 54.868280589580536, 47.4680332839489, 41.90992332994938, 41.38039894402027, 47.24940441548824, 55.03235578536987, 56.46473832428455, 55.285600796341896, 52.324742674827576, 46.708704829216, 40.06924130022526, 40.63531972467899, 38.98223742842674, 38.92581805586815, 37.12251842021942, 39.789412915706635, 38.6556563526392, 48.986010029911995, 51.490831822156906, 52.47874841094017, 51.12777270376682, 56.34951710700989, 51.208655163645744, 56.628980711102486, 50.39412707090378, 57.66357019543648, 29.631461687386036, 28.141700327396393, 53.54465201497078, 46.52036793529987, 55.38373813033104, 48.80917131900787, 52.66406446695328, 49.35883082449436, 47.430745884776115, 51.125485226511955, 52.62753702700138, 43.59211966395378, 40.23853361606598, 40.87643578648567, 41.0043141245842, 39.95846584439278, 39.04225900769234, 39.45467747747898, 40.98648548126221, 40.92222712934017, 39.52845051884651, 39.958868622779846, 41.43630534410477, 44.31827589869499, 55.23285202682018, 53.87819051742554, 54.18116346001625, 53.58347073197365, 52.94053003191948, 42.947894632816315, 41.672987043857574, 42.88695350289345, 40.47684542834759, 40.44451296329498, 40.49257658421993, 41.025140807032585, 40.43282099068165, 43.439500853419304, 43.972570449113846, 42.982556372880936, 41.60036914050579, 43.81915368139744, 41.96778662502766, 43.38342346251011, 43.41818019747734, 46.39568902552128, 48.579948619008064, 52.97405183315277, 52.51880966126919, 52.98679634928703, 54.82650563120842, 58.37849423289299, 58.943801298737526, 62.065785974264145, 51.098533272743225, 7.906042439863086, 2.0560611225664616, 5.667750220745802, 0.09991063649067655, 0.10137168035726063, 0.38884162553586066, 14.688188787549734, 43.058138117194176, 32.41690792143345, 36.439284682273865, 14.909891691058874, 27.46638346463442, 39.58464950323105, 48.875432163476944, 49.890650287270546, 33.71500186622143, 1.2325608800165355, 0.14574551372788846, 0.106571627111407, 0.016401035063609015, 0.021445108541229274, 0.023129987857828382, 0.0798189993656706, 0.0017221852249349467, 0.04354482844064478, 0.04999563912861049, 0.035630458005471155, 0.00966464780503884, 0.04541916692687664, 0.05808578724099789, 0.00838704057969153, 0.020454890582186636, 0.06580868357559666, 0.04017828330688644, 0.008035456467041513, 0.009417967194167431, 0.09300261459429748, 0.05581657795119099, 0.06646372537943535, 0.05623612516501453, 0.10360119587858208, 0.03483030406641774, 0.0612306417315267, 0.0351545446756063, 0.025018603409989737, 0.060664739285130054, 0.055662793820374645, 0.14729293616255745, 0.022213787997316103, 0.06520036738947965, 15.726458374410868, 71.05296492576599, 64.27352830767632, 55.34851022064686, 44.389263689517975, 28.41929253190756, 26.719446144998074, 37.77168318629265, 40.63331723213196, 52.386166378855705, 4.060375671833754, 0.15282376203686, 0.1764136235578917, 1.0675148363225162, 2.9870375292375684, 1.2328007421456277, 11.297912858426571, 70.06839215755463, 69.14946466684341, 66.16315171122551, 64.20146897435188, 66.28007903695107, 67.2815228998661, 61.4311820268631, 56.60845421254635, 54.03351478278637, 61.747826635837555, 64.28434252738953, 60.58803766965866, 53.74338895082474, 48.169240057468414, 44.17694628238678, 49.432588666677475, 60.261977165937424, 61.62151001393795, 57.295939922332764, 53.725172728300095, 50.286041870713234, 53.83400648832321, 55.332627072930336, 54.64415341615677, 56.17798671126366, 57.931748405098915, 57.36741028726101, 56.95048525929451, 56.591051146388054, 49.289632737636566, 43.3467972278595, 42.01767034828663, 48.49384903907776, 56.23947501182556, 57.8965774923563, 56.529980823397636, 54.52479422092438, 48.01013879477978, 42.46164612472057, 42.70041771233082, 41.32889270782471, 42.254169657826424, 39.71788175404072, 43.9512649923563, 41.31737932562828, 50.54779462516308, 53.41963492333889, 55.11350803077221, 53.17182742059231, 59.08016458153725, 53.58569361269474, 58.244160041213036, 54.421983137726784, 58.78935478627682, 30.808714516460896, 30.308790542185307, 55.489885434508324, 49.61322717368603, 57.722907811403275, 51.08594074845314, 53.94636645913124, 52.53558576107025, 50.43831489980221, 53.24061892926693, 56.22174896299839, 45.272138714790344, 41.80922873318195, 41.997079253196716, 42.372730895876884, 40.88967427611351, 41.402456760406494, 41.603108793497086, 43.50768819451332, 42.033101320266724, 41.03298358619213, 42.69837722182274, 43.302666395902634, 46.02694921195507, 55.82131125032902, 55.61016798019409, 56.16184897720814, 55.437501445412636, 55.82546062767506, 45.04052594304085, 42.327935099601746, 44.17007625102997, 42.936274856328964, 41.96441240608692, 43.211368694901466, 42.73881085216999, 42.46524453163147, 44.24412287771702, 45.663073137402534, 44.55994293093681, 44.708150178194046, 45.3756033629179, 44.35992546379566, 45.65401442348957, 45.61089053750038, 48.14854636788368, 51.005020290613174, 54.35599967837334, 55.021682158112526, 54.9076084792614, 56.91258229315281, 59.245140329003334, 60.42914539575577, 63.29368628561497, 55.75803704559803, 8.312539402395487, 1.4546165708452463, 7.7429181430488825, 1.5084460261277854, 0.5046991899143904, 0.46443470986559987, 15.74067436158657, 50.112018808722496, 29.297765493392944, 36.070294082164764, 23.493763133883476, 37.61475920677185, 48.151806592941284, 53.995942398905754, 56.44992291927338, 45.470723658800125, 2.1463920129463077, 0.2123691645101644, 0.025141991027339827, 0.036571126474882476, 0.030757139720662963, 0.036886216403217986, 0.035446457332000136, 0.034627489949343726, 0.14177011064020917, 0.030274606433522422, 0.047433967993129045, 0.024972029932541773, 0.00932176908463589, 0.031733006399008445, 0.038624964508926496, 0.012392253884172533, 0.052755697470274754, 0.0043068207287433324, 0.11655805530608632, 0.13062811398413032, 0.16205818683374673, 0.2225632159388624, 0.16597092297160998, 0.08628358802525327, 0.19709346466697752, 0.08749849861487746, 0.12997800746234134, 0.155627031926997, 0.15983374760253355, 0.10554062071605586, 0.09535390912787989, 0.31504908052738756, 0.18580735777504742, 0.1619703313917853, 20.460488498210907, 83.35367247462273, 73.42972218990326, 64.04180154204369, 51.341518834233284, 32.892441004514694, 38.8016939163208, 70.40999382734299, 57.03152351081371, 59.933872371912, 5.38856590166688, 0.3552623523864895, 0.4671558685367927, 1.4085259940475225, 16.221122480928898, 6.653006952255964, 11.0190505720675, 74.24830466508865, 69.62049499154091, 69.48741093277931, 66.69782102108002, 69.17316779494286, 68.95531788468361, 64.20927375555038, 56.314357593655586, 55.32607242465019, 60.15506990253925, 64.3217933177948, 62.62680687010288, 55.760503113269806, 51.8534729629755, 45.69882541894913, 49.96571525931358, 63.117960914969444, 64.26617190241814, 60.325289368629456, 55.82692734897137, 55.471612215042114, 56.85122698545456, 57.16549292206764, 56.23405650258064, 57.17777766287327, 60.210235342383385, 61.88374534249306, 58.62088322639465, 59.84061777591705, 52.10204802453518, 46.212485656142235, 45.34380666911602, 50.343958362936974, 60.12408636510372, 60.571679547429085, 58.71686227619648, 57.27922081947327, 50.47839514911175, 44.77787643671036, 45.213074684143066, 44.296404272317886, 45.01095972955227, 41.1275415122509, 46.05752997100353, 43.011659011244774, 53.38735945522785, 56.18066556751728, 56.1234862357378, 54.848719239234924, 60.032746866345406, 55.70094130933285, 60.33766150474548, 56.740295737981796, 59.59436438977718, 33.51031444966793, 34.82578486204147, 56.896353363990784, 51.370701268315315, 58.560284078121185, 53.139677345752716, 55.84680788218975, 52.41152621805668, 51.05262033641338, 55.645072907209396, 56.68835632503033, 47.762768268585205, 42.702849581837654, 46.08178406953812, 45.24288788437843, 43.63700285553932, 43.25139954686165, 44.12543244659901, 46.07407048344612, 44.5709053426981, 42.69468382000923, 43.758782520890236, 46.32903680205345, 48.300785198807716, 58.332699090242386, 57.648663595318794, 56.224796399474144, 59.70173142850399, 57.53097251057625, 48.38795252144337, 46.29643835127354, 46.71825371682644, 45.335458517074585, 44.14835661649704, 45.36607727408409, 44.99749705195427, 45.268031135201454, 47.84963920712471, 48.86328421533108, 46.29509322345257, 46.57885439693928, 50.04220515489578, 47.492298781871796, 46.86755530536175, 47.43663176894188, 51.623573899269104, 53.87180306017399, 58.44042710959911, 57.65580341219902, 57.2186254709959, 60.43996341526508, 63.01420368254185, 62.5141429156065, 65.45160949230194, 58.25660817325115, 11.31555911153555, 7.459211591631174, 15.13185203075409, 1.0456312168389559, 0.4494562995387241, 0.6658989493735135, 19.578265137970448, 59.326201379299164, 48.1484741717577, 47.174442037940025, 22.99396075308323, 40.52131824195385, 55.985344648361206, 61.87287412583828, 65.82286477088928, 52.5133303552866, 2.428693352267146, 0.2764035214204341, 0.172413477266673, 0.0951268564676866, 0.09146043172222562, 0.21907169313635677, 0.14094769227085635, 0.22829914174508303, 0.28470566030591726, 0.14272123225964606, 0.08110060676699504, 0.09426596516277641, 0.09613942791474983, 0.1145816789357923, 0.09686386794783175, 0.08201839853427373, 0.26635528716724366, 0.08664813096402213], [0.1077789900591597, 0.04987885105947498, 0.08384096479858272, 0.0073460128714941675, 0.039962129085324705, 0.014454919764830265, 0.05029262065363582, 0.04780785457114689, 0.07249771995702758, 0.0417485972866416, 0.10921011053142138, 0.041527433568262495, 0.029573341817012988, 0.0561880822351668, 0.13162487768568099, 0.06205996578501072, 22.836020328104496, 64.5223617553711, 56.66162855923176, 51.20966590940952, 30.896043330430984, 18.596386425197124, 27.61882558465004, 43.39625917375088, 42.197541296482086, 33.48769426345825, 0.23600693908520043, 0.055531478210468777, 0.02039340921328403, 1.1661772546358407, 2.133994703181088, 0.9258782083634287, 39.295610412955284, 76.22882679104805, 60.848563089966774, 62.04145208001137, 58.76019895076752, 62.48898446559906, 60.99162541329861, 66.10797867178917, 59.75433960556984, 55.80799676477909, 51.54206447303295, 58.89574147760868, 58.05603213608265, 56.737457290291786, 46.364454701542854, 44.00797314941883, 40.95408841967583, 51.06483668088913, 59.05630946159363, 56.7936372756958, 47.93462924659252, 42.166120782494545, 45.36432556807995, 46.67313493788242, 46.48074746131897, 47.16951750218868, 50.03061957657337, 53.725868090987206, 53.31477954983711, 48.80382500588894, 43.08007434010506, 39.288132414221764, 40.65474808216095, 45.95881126821041, 53.17894443869591, 50.70580154657364, 53.11344355344772, 51.484322771430016, 43.47514294087887, 39.334721714258194, 40.45690409839153, 40.30577480792999, 40.979949831962585, 40.02480648458004, 40.2735411375761, 40.87368093430996, 51.37508623301983, 51.61496356129646, 53.39964419603348, 52.30080395936966, 54.31745834648609, 53.14114026725292, 55.827113538980484, 50.068746730685234, 61.00180126726627, 30.814799889922142, 28.763694651424885, 56.67723432183266, 48.446716368198395, 54.82470452785492, 48.8455505669117, 53.19640450179577, 52.35291816294193, 51.945169642567635, 50.52469566464424, 52.560276836156845, 45.76702035963535, 40.939303413033485, 38.572980388998985, 39.21362981200218, 38.2155791670084, 39.108861833810806, 38.305349349975586, 40.99424846470356, 38.82583022117615, 41.389465257525444, 38.51226344704628, 43.3615480363369, 44.52393986284733, 54.264063611626625, 53.72928410768509, 56.17838568985462, 52.146832421422005, 53.07350389659405, 41.62753388285637, 42.03735709190369, 40.84635280072689, 41.35748617351055, 42.532014548778534, 41.342233791947365, 40.59079371392727, 40.31362138688564, 42.195842787623405, 43.83133202791214, 42.8549250215292, 42.77896709740162, 41.6220735758543, 44.19260524213314, 44.24984537065029, 45.37319429218769, 43.0596998333931, 45.270029827952385, 48.3496505767107, 49.269463419914246, 48.382427617907524, 50.28177089989185, 53.7486706674099, 58.77074718475342, 56.87848672270775, 61.441194489598274, 19.432444162666798, 0.393558211508207, 3.8465803815051913, 1.7501389444805682, 0.29440431331750005, 0.06324652262264863, 2.187819527462125, 38.877914026379585, 36.14720955491066, 31.489556282758713, 17.797323502600193, 27.410733550786972, 34.67405140399933, 47.07605391740799, 50.25800317525864, 42.52806656062603, 7.146346354857087, 0.2614039450418204, 0.10579767840681598, 0.07998415690963157, 0.12211775072501041, 0.10945272602839395, 0.08799684335826896, 0.040317554739885963, 0.02783709845971316, 0.06976739576202817, 0.06627869312069379, 0.03179702034685761, 0.07397174398647621, 0.015445986555278068, 0.05351646563212853, 0.09430814883671701, 0.08270176069345325, 0.008155512769008055, 0.06428836437407881, 0.03310089959995821, 0.033088579948525876, 0.03922615978808608, 0.05160814420378301, 0.0808593568217475, 0.05319227697327733, 0.08238992508267984, 0.025362342094013002, 0.02692628844670253, 0.030819582170806825, 0.1255569001659751, 0.008356760026799748, 0.07447319832863286, 0.12304826290346682, 0.016239606811723206, 29.702890254557133, 77.69190028309822, 62.769610807299614, 58.068180084228516, 38.01991626620293, 25.37408083677292, 19.3264127522707, 37.697651758790016, 47.49722711741924, 36.88415341079235, 0.045578981007565744, 0.03869732761813793, 0.40476844122167677, 6.833815025165677, 3.6191623471677303, 0.6743412651121616, 41.79600544273853, 76.55788913369179, 63.630371019244194, 64.98393058776855, 61.15839846432209, 65.81271931529045, 63.207624703645706, 66.8659619987011, 59.75025862455368, 56.32790766656399, 52.778841108083725, 59.70398850739002, 61.06472589075565, 58.54750156402588, 48.320969715714455, 45.84407642483711, 43.45830224454403, 52.95390911400318, 61.550906002521515, 56.77702836692333, 51.208955347537994, 44.4473397731781, 46.26931920647621, 47.57934831082821, 49.06648591160774, 49.8551981896162, 51.927831172943115, 56.690206825733185, 56.9156601279974, 50.94172328710556, 44.81807827949524, 41.395803317427635, 42.36591026186943, 48.97285133600235, 56.946252286434174, 55.104947090148926, 56.038750782608986, 53.178051486611366, 44.2807225137949, 42.334238961339, 42.26004794239998, 43.148580864071846, 42.43598610162735, 42.184394001960754, 42.51429229974747, 42.459761425852776, 53.16584274172783, 54.60788816213608, 55.73042392730713, 53.63990530371666, 56.12260088324547, 55.453338995575905, 59.62450437247753, 51.67449116706848, 60.69454215466976, 32.062303349375725, 30.006687752902508, 57.388689145445824, 50.56661121547222, 57.538214921951294, 50.16849137842655, 55.93841716647148, 52.86934085190296, 54.25806753337383, 52.682026103138924, 54.66456212103367, 47.578143775463104, 43.9618094265461, 41.29376359283924, 40.6469888985157, 40.80910339951515, 40.19691064953804, 40.8387266099453, 42.71441236138344, 41.30267411470413, 41.707827374339104, 41.24504640698433, 45.4971132427454, 46.28572292625904, 56.8829020857811, 56.09194032847881, 58.6746883392334, 52.65512354671955, 54.564255103468895, 43.86256255209446, 44.016800075769424, 43.41004863381386, 43.520983681082726, 42.274202182888985, 44.24432046711445, 42.08468355238438, 42.565038576722145, 44.40988138318062, 44.33302290737629, 45.24365924298763, 45.19677735865116, 44.863926619291306, 46.5086455643177, 46.25637710094452, 47.54882074892521, 44.122506603598595, 47.93250136077404, 49.87279884517193, 50.50037316977978, 50.80599457025528, 53.68894927203655, 56.35941557586193, 59.86971281468868, 59.190062284469604, 63.05469810962677, 23.450557552278042, 0.24946920108050108, 5.494399722665548, 2.832896187901497, 0.3782019589561969, 0.07139722627471201, 1.9511866313405335, 46.908988282084465, 37.26464219391346, 25.643619373440742, 18.122451156377792, 31.44374404102564, 40.85958369076252, 52.37980552017689, 57.61760786175728, 50.60459777712822, 12.537632435560226, 0.32848958275280893, 0.05499650847923476, 0.08044331625569612, 0.05927885271375999, 0.022200045277713798, 0.05209177215874661, 0.06464630962000228, 0.02374092939135153, 0.05524812251678668, 0.02924509361037053, 0.015309378504753113, 0.04049684648634866, 0.021922441228525713, 0.02088531768094981, 0.05534783747862093, 0.05379149813961703, 0.014417291949939681, 0.1950114732608199, 0.1071725292422343, 0.12223069817991927, 0.13499923021299765, 0.1417380795464851, 0.1782252950943075, 0.1310145205934532, 0.20154814672423527, 0.26990221871528774, 0.12021213813568465, 0.19699714874150231, 0.2644615637836978, 0.13667569728568196, 0.2856994851026684, 0.2616785099962726, 0.2170728222699836, 36.89412407577038, 85.39004400372505, 71.40034228563309, 68.67640525102615, 45.3858096152544, 28.91802717000246, 37.5758720934391, 58.83407078683376, 56.629459485411644, 42.1843484044075, 0.5990389245562255, 0.17568391427630559, 0.36259735410567373, 4.467766536399722, 9.297540597617626, 1.9304049527272582, 44.66268181800842, 78.29970806837082, 66.07283815741539, 67.02084168791771, 65.00367432832718, 67.38946750760078, 65.8468946814537, 68.98757815361023, 60.134816989302635, 56.04611478745937, 57.53397814929485, 62.425121292471886, 61.99890956282616, 62.41258196532726, 49.91364285349846, 49.14316579699516, 43.62531468272209, 54.28838990628719, 62.63290174305439, 61.10036417841911, 53.75715561211109, 44.82891529798508, 48.236564844846725, 50.92152737081051, 51.817184910178185, 51.98301941156387, 55.55654525756836, 58.95782634615898, 59.008663818240166, 52.65612669289112, 47.35531993210316, 43.93669277429581, 44.71562817692757, 50.580187886953354, 58.36351163685322, 57.47222766280174, 57.86429822444916, 55.735652446746826, 47.78644859790802, 43.55492725968361, 44.42485257983208, 45.56993633508682, 45.92232942581177, 45.70273160934448, 45.98107047379017, 45.94888620078564, 56.08004316687584, 55.97000867128372, 56.675619408488274, 56.663847640156746, 58.914713859558105, 58.19287419319153, 60.3658863902092, 55.41558042168617, 62.51197703182697, 36.546062752604485, 35.687145441770554, 61.60127229988575, 52.06477962434292, 60.61357229948044, 53.57672989368439, 57.06574447453022, 55.269048884510994, 56.395228654146194, 55.068613439798355, 56.526454612612724, 48.798246905207634, 46.08259342610836, 43.864755034446716, 42.709753811359406, 43.49057771265507, 41.96014903485775, 44.83659088611603, 46.02578267455101, 44.0016882866621, 44.23984430730343, 42.67384573817253, 47.522191777825356, 48.53585198521614, 59.74988244473934, 57.236522510647774, 60.246679186820984, 56.89463585615158, 57.60889492928982, 45.36949709057808, 46.27405755221844, 45.23894749581814, 46.785506308078766, 46.96750894188881, 47.80550457537174, 44.21714812517166, 45.90272627770901, 45.66780008375645, 48.64041477441788, 47.229520082473755, 46.949197724461555, 47.00167290866375, 48.761632069945335, 48.983635157346725, 49.473732858896255, 47.79694363474846, 50.28047516942024, 52.69681490957737, 53.786262050271034, 54.8362635076046, 57.347324565052986, 59.86228421330452, 63.900669515132904, 62.49146193265915, 65.91567859053612, 26.814368851482868, 1.6062646522186697, 14.675701707601547, 6.407747687771916, 0.9466467658057809, 0.2047771422076039, 3.142118132673204, 52.5261090695858, 53.426333963871, 41.433748081326485, 24.60040245205164, 39.37025360763073, 45.45311160385609, 62.54202201962471, 63.30029033124447, 61.4180613309145, 14.632736463099718, 0.4015606711618602, 0.2065725755528547, 0.2510538644855842, 0.16570866282563657, 0.16584791941568255, 0.23075719422195107, 0.19720541022252291, 0.1613829066627659, 0.1200109493220225, 0.2593525004340336, 0.17385210085194558, 0.12388270406518131, 0.08772995221079327, 0.16138311446411535, 0.1876379837631248, 0.26767025410663337, 0.1260739247663878], [0.022094923770055175, 0.05887668288778514, 0.035874008608516306, 0.03385387892194558, 0.05001406665542163, 0.04721588789834641, 0.0840387397329323, 0.046568445686716586, 0.025793489076022524, 0.018556847899162676, 0.10728512046625838, 0.011746018590201857, 0.04783001139003318, 0.012464514948078431, 0.01514773410235648, 0.7249793666414917, 42.03107602894306, 66.62681043148041, 53.862444162368774, 41.16669841110706, 28.729960061609745, 20.71994237601757, 47.99009867012501, 39.238062500953674, 49.289503544569016, 16.62940487265587, 0.09832768744672649, 0.2078583018737845, 0.4480472282739356, 6.081738481298089, 0.5164603900630027, 2.3862745659425855, 60.739410147070885, 67.35484376549721, 62.12951235473156, 58.44048410654068, 52.9348911345005, 59.89281177520752, 61.64952591061592, 62.69674971699715, 60.56745417416096, 57.400738298892975, 46.5768177062273, 55.28930179774761, 58.88954401016235, 55.66513203084469, 52.245429530739784, 45.25147162377834, 42.78553694486618, 42.22472883760929, 49.94045801460743, 45.48552766442299, 41.97807267308235, 39.50775682926178, 39.99885007739067, 41.66869707405567, 42.46923431754112, 41.46221995353699, 44.165881276130676, 45.730910897254944, 45.47204598784447, 41.90231613814831, 38.44791769981384, 40.402076840400696, 38.912085592746735, 42.48325556516647, 53.70453603565693, 54.56571042537689, 54.8896848410368, 44.689610973000526, 41.3485262542963, 38.96750181913376, 40.71681395173073, 39.761913791298866, 40.35046800971031, 39.269995987415314, 39.61254760622978, 41.32557548582554, 51.57185107469559, 49.07071128487587, 55.26765055954456, 49.98718410730362, 54.248473048210144, 51.43975496292114, 55.98290137946606, 49.03601914644241, 61.160161569714546, 32.185572534799576, 30.23635122925043, 54.991960152983665, 48.916405364871025, 53.71621660888195, 48.43287371098995, 52.1594325453043, 48.568819016218185, 53.51360388100147, 48.04293863475323, 52.04287379980087, 48.13228324055672, 44.74792264401913, 38.09452906250954, 40.241607651114464, 38.25928062200546, 40.19990108907223, 39.39019113779068, 40.70786543190479, 38.68259310722351, 39.143743962049484, 38.355719447135925, 44.49091203510761, 44.936643317341805, 52.50236414372921, 54.642743691802025, 53.44868816435337, 52.41278015077114, 51.686886101961136, 39.63037244975567, 41.71912036836147, 39.85375106334686, 41.19106650352478, 41.847390085458755, 41.60306699573994, 40.17704911530018, 41.8089285492897, 40.74180141091347, 43.548817187547684, 42.22356230020523, 41.474599689245224, 41.54576987028122, 44.89347003400326, 44.086568132042885, 42.288189232349396, 42.50040024518967, 44.52094942331314, 43.620222955942154, 47.79187850654125, 47.587620466947556, 51.50308236479759, 48.698604851961136, 57.3367915302515, 56.18849314749241, 65.7561631500721, 40.185089483857155, 2.399329715408385, 4.211267000064254, 3.096335339359939, 0.3886049101129174, 0.12562618707306683, 0.14039563830010593, 22.890889383852482, 41.71417683362961, 44.73785698413849, 42.3615100979805, 50.290818214416504, 40.17753168940544, 43.848024532198906, 48.66372272372246, 45.268992483615875, 27.160640470683575, 1.068937147501856, 0.09273772724554874, 0.08933255332522094, 0.0861905375495553, 0.06469253057730384, 0.05108156074129511, 0.019023647655558307, 0.06007318450429011, 0.019922648243664298, 0.006083482840040233, 0.07107014695066027, 0.03164378540532198, 0.07281771919224411, 0.015864386223256588, 0.03977252148615662, 0.01934244646690786, 0.04313868441386148, 0.005850938287039753, 0.10636119855917059, 0.05329997373337392, 0.014426872148760594, 0.039540236684842966, 0.06561231130035594, 0.03133505568257533, 0.12348765885690227, 0.038425642196671106, 0.010352348745072959, 0.03650413651484996, 0.04898155741102528, 0.06652419557212852, 0.0008094740962860669, 0.09466149276704527, 1.5013009845279157, 55.77775798738003, 74.75322917103767, 62.15959534049034, 49.30815674364567, 38.26698660850525, 25.596310012042522, 41.25166945159435, 36.995069459080696, 55.712720677256584, 17.097461856901646, 0.20666069816797972, 0.2229887040448375, 1.4811560092493892, 8.539301734417677, 1.248933607712388, 3.4951329650357366, 63.35488960146904, 70.07165998220444, 65.95719516277313, 61.33596673607826, 56.27271942794323, 61.82153508067131, 63.72930631041527, 63.86985316872597, 61.47507347166538, 58.556313291192055, 47.673020884394646, 57.592521607875824, 62.83969804644585, 59.82525520026684, 53.465764448046684, 47.85856492817402, 44.3660469353199, 45.657122656702995, 50.57278208434582, 48.91952499747276, 44.68000128865242, 42.190344482660294, 41.41850709915161, 44.307226091623306, 43.329371362924576, 43.62319439649582, 47.673731446266174, 47.70297087728977, 47.738354578614235, 44.57443155348301, 40.4057702422142, 42.98685774207115, 40.64535118639469, 44.246573746204376, 55.54603882133961, 55.46815060079098, 56.8799040466547, 46.71208664774895, 44.18722093105316, 41.599875167012215, 43.8336157053709, 41.4214101433754, 42.337426990270615, 41.29763938486576, 42.260712906718254, 44.48291726410389, 52.33917810022831, 52.58741118013859, 58.01766939461231, 52.47137300670147, 55.13740874826908, 53.58962640166283, 56.6940788179636, 52.20606744289398, 62.881586998701096, 34.137360602617264, 32.57179141044617, 57.00590908527374, 49.802540615200996, 55.77992007136345, 49.934648126363754, 53.01239177584648, 50.9017950296402, 55.30648447573185, 51.04143753647804, 53.23284454643726, 50.05773492157459, 46.9240278750658, 40.9077575057745, 43.238001465797424, 39.49201047420502, 41.599574983119965, 41.55972272157669, 42.03080244362354, 39.75032441318035, 41.318754851818085, 40.67259952425957, 45.52285686135292, 46.03405103087425, 54.90863062441349, 55.5353993922472, 54.56216901540756, 55.536877512931824, 53.88847276568413, 41.3829106092453, 42.952575981616974, 42.83763214945793, 41.2481964379549, 42.65044279396534, 44.513433426618576, 43.31851914525032, 44.12162505090237, 43.17403569817543, 45.397448390722275, 43.63949932157993, 44.15224000811577, 43.336351588368416, 46.91308066248894, 45.45897848904133, 43.81529688835144, 44.2691483348608, 46.96662358939648, 45.92459790408611, 50.24688497185707, 49.63547118008137, 52.90117934346199, 53.71141366660595, 60.40299519896507, 59.340640604496, 66.8078251183033, 45.58369919657707, 2.7041023364290595, 1.6166681377217174, 4.874790720641613, 1.0838500410318375, 0.055129308384493925, 0.2788445638725534, 24.884484708309174, 50.730485022068024, 33.56631964445114, 35.86393855512142, 55.4429579526186, 45.435890927910805, 48.89999404549599, 52.637059316039085, 54.25884649157524, 37.54418559372425, 1.6065819351933897, 0.09259284517611377, 0.03184511893778108, 0.056970201985677704, 0.03698524116771296, 0.050065909381373785, 0.02106004707457032, 0.15017479949165136, 0.08401807834161445, 0.03859720076434314, 0.13961978227598593, 0.060954974687774666, 0.05527395667741075, 0.05332467982952949, 0.014865425764583051, 0.01459963485103799, 0.04776571542606689, 0.10042975394753739, 0.1977287876070477, 0.13237860286608338, 0.13359728356590495, 0.11744663614081219, 0.14988206676207483, 0.22333024040563032, 0.2695267810486257, 0.13239957595942542, 0.14617964043281972, 0.15609829570166767, 0.22595342074055225, 0.13547491718782112, 0.11327709464239888, 0.22329065424855798, 2.065393659286201, 65.42275384068489, 83.84772196412086, 70.63028320670128, 56.22856579720974, 42.11697801947594, 30.604730062186718, 60.842312425374985, 53.58564041554928, 65.33948510885239, 21.105110608041286, 0.4601506772451103, 0.4373578674858436, 0.9876418753992766, 11.188022755086422, 4.51377066783607, 3.4608894400298595, 66.5201273560524, 70.38145735859871, 68.70367258787155, 63.809413611888885, 57.577189430594444, 63.92212316393852, 66.98803424835205, 66.83587521314621, 64.03884530067444, 58.470004722476006, 49.99003775417805, 59.8289979994297, 63.435217291116714, 62.28455163538456, 57.730078026652336, 50.67482940852642, 48.330290615558624, 47.82336741685867, 52.26564444601536, 49.52456273138523, 46.52494668960571, 43.65825891494751, 44.16971527040005, 46.41549356281757, 45.89747495949268, 46.097424030303955, 49.05635565519333, 49.25246313214302, 50.26163958013058, 45.78025124967098, 41.60059712827206, 44.7466991096735, 41.15212619304657, 46.3633793592453, 59.18981909751892, 58.164949491620064, 59.918422400951385, 49.13512922823429, 46.65380157530308, 43.17733012139797, 44.888921678066254, 42.846956849098206, 45.44768929481506, 44.814240485429764, 43.57403263449669, 45.1185167580843, 56.59656465053558, 55.50061985850334, 61.45885594189167, 53.02514009177685, 57.84985139966011, 56.78947649896145, 59.73448947072029, 54.83192414045334, 65.18078282475471, 38.53107623755932, 36.51210397481918, 58.87341007590294, 53.765089586377144, 58.068814650177956, 53.52099068462849, 55.61994105577469, 53.522172421216965, 57.39759586751461, 52.33237646520138, 57.06021197140217, 53.135011196136475, 49.26078848540783, 42.5934686511755, 46.06126517057419, 42.30591908097267, 43.904979676008224, 44.273069724440575, 43.50491814315319, 41.61432199180126, 42.641862854361534, 41.95866331458092, 47.38873153924942, 48.44225160777569, 56.41539417207241, 59.10512924194336, 57.933644503355026, 58.98687198758125, 56.6683541983366, 42.56891056895256, 44.63356778025627, 45.52578270435333, 44.71855401992798, 46.083756163716316, 46.45660735666752, 44.559087976813316, 45.989711210131645, 44.2443660646677, 48.413521349430084, 46.31858356297016, 46.21009938418865, 44.82297241687775, 49.590158611536026, 49.446514919400215, 48.400248661637306, 46.09160274267197, 50.847176760435104, 48.97670812904835, 52.52822935581207, 51.30024164915085, 56.54331810772419, 53.9447895437479, 64.21676695346832, 62.52453535795212, 69.5746086537838, 46.64914682507515, 4.802873879671097, 12.246895786374807, 6.497649438679218, 0.8412746200338006, 0.30045593390241265, 0.28550878283567727, 28.565024212002754, 60.95853678882122, 61.227706745266914, 55.903656631708145, 58.941890001297, 50.36631256341934, 57.71747410297394, 60.656582191586494, 62.993870973587036, 41.87726408243179, 2.3615856282413006, 0.3606322658015415, 0.18955670268042013, 0.18424313311697915, 0.1808208823786117, 0.17957039322936907, 0.11831927564344369, 0.2236330069717951, 0.21568562951870263, 0.1243479638651479, 0.1768251444445923, 0.128698589396663, 0.16597041831118986, 0.10284839838277549, 0.1711987447924912, 0.09905627608532086, 0.1743833746877499], [0.07069339568261057, 0.04470222629606724, 0.050469912312109955, 0.024421938942396082, 0.042121211081393994, 0.01672841124673141, 0.02396714156930102, 0.03518205980071798, 0.023831380494812038, 0.06003739814332221, 0.007917856673884671, 0.09877542514004745, 0.05477524086018093, 0.046126225861371495, 0.07316819843254052, 5.523774521425366, 56.17868587374687, 59.00777466595173, 57.78823770582676, 39.617266952991486, 26.829980313777924, 27.99727387726307, 31.661525554955006, 37.07189753651619, 48.72408628463745, 5.005695596337318, 0.13669619540451095, 0.04230329330312088, 0.11756054838770069, 15.639466792345047, 0.7651232031639665, 17.81655427068472, 74.67798560857773, 63.48909080028534, 67.2424153983593, 55.24726465344429, 52.39000417292118, 54.027279317379, 59.61661979556084, 58.71308147907257, 61.129048839211464, 61.65298752486706, 59.210197404026985, 59.17480990290642, 58.33932213485241, 56.682060062885284, 53.95078182220459, 46.209449619054794, 43.21848191320896, 40.914049968123436, 40.73163315653801, 41.06360614299774, 42.24698044359684, 42.33129411935806, 41.05478301644325, 40.81424072384834, 42.3428151011467, 40.201253816485405, 41.30715787410736, 39.507350251078606, 40.98230570554733, 39.67218920588493, 41.27705588936806, 38.76560725271702, 40.79003982245922, 38.16903546452522, 42.8654732555151, 42.885938957333565, 44.56600360572338, 40.87343394756317, 41.88598461449146, 40.83387427031994, 41.341736018657684, 39.596067890524864, 40.09519390761852, 38.10776375234127, 40.85737980902195, 40.909418016672134, 49.43965628743172, 48.64677183330059, 52.90036998689175, 50.60935512185097, 54.32476915419102, 47.57654786109924, 54.58735026419163, 49.58056412637234, 60.2214827388525, 29.544887132942677, 26.85978591442108, 58.588710352778435, 48.527716621756554, 54.331832975149155, 47.72619903087616, 49.122920483350754, 45.63659995794296, 51.96723885834217, 47.79105395078659, 51.37936860322952, 48.58314424753189, 45.20074054598808, 37.87746571004391, 40.7899334281683, 39.571407213807106, 39.113980159163475, 38.829310834407806, 40.15574745833874, 40.41523553431034, 41.896183267235756, 39.665657356381416, 42.664236053824425, 45.14891892671585, 51.59606717526913, 52.68690124154091, 53.77360872924328, 52.0161422342062, 46.826924085617065, 40.57939812541008, 39.93448153138161, 40.72064034640789, 43.00820879638195, 41.98239304125309, 41.91168263554573, 41.77390582859516, 42.402718886733055, 41.73221826553345, 43.13375785946846, 43.301005885005, 43.638359382748604, 40.57777181267738, 40.550470277667046, 40.77840104699135, 41.709491685032845, 43.42923000454903, 43.930020332336426, 45.45070633292198, 48.557070046663284, 50.56374616920948, 49.282017946243286, 51.88600301742554, 56.537071242928505, 57.34379455447197, 58.92281882464886, 58.8790375739336, 9.755519572645426, 1.2636586488224566, 2.3175305547192693, 1.30916049471125, 0.14324330346425995, 0.24484407738782465, 4.629188049584627, 36.29528760910034, 36.75735801458359, 32.64832690358162, 20.728220231831074, 27.13362392038107, 35.34782364964485, 41.917424127459526, 50.88539510965347, 47.75780953466892, 5.38460461422801, 0.3389905270887539, 0.04882255969278049, 0.11876670163474046, 0.04473471752135083, 0.02302036707988009, 0.07379522416158579, 0.05134234772413038, 0.03846115025226027, 0.08580190449720249, 0.05540085650864057, 0.028268059904803522, 0.0275781687014387, 0.024129402881953865, 0.04070074784976896, 0.053860606931266375, 0.023818084919184912, 0.017320027254754677, 0.04309184747398831, 0.07250523791299202, 0.028453661761886906, 0.09622693454730324, 0.017477540677646175, 0.0036734009336214513, 0.026426787808304653, 0.040521986738895066, 0.057548190306988545, 0.03461370084551163, 0.08899077205569483, 0.102833985874895, 0.02989973650983302, 0.04777800539159216, 9.220621325075626, 70.8479355275631, 65.10034874081612, 64.49403047561646, 45.60643717646599, 31.213660687208176, 27.668173536658287, 31.649168618023396, 39.199517369270325, 54.461618810892105, 5.216161077842116, 0.37758639198727906, 0.07081772026140243, 5.194886969402432, 13.829171732068062, 1.259109580423683, 20.210589207708836, 77.2435775399208, 64.36000406742096, 68.32917988300323, 57.83817082643509, 54.58146058022976, 55.92863269150257, 62.909146919846535, 61.145444959402084, 64.40353453159332, 63.26274074614048, 59.53700266778469, 58.853305354714394, 59.41578537225723, 59.35674414038658, 55.86246304214001, 48.336457684636116, 44.99476119875908, 42.55935028195381, 43.45334351062775, 43.62225964665413, 44.58579674363136, 42.975754737854004, 42.75921955704689, 43.040336072444916, 43.876724392175674, 42.28981554508209, 42.654820159077644, 40.82681804895401, 42.343609258532524, 41.47580422461033, 42.724949195981026, 39.99611422419548, 43.184526935219765, 40.08605159819126, 45.426228046417236, 47.19591848552227, 47.05134764313698, 41.71163097023964, 43.43502089381218, 42.67282359302044, 44.3658759444952, 40.501103326678276, 43.50076116621494, 38.87319467961788, 44.315148666501045, 43.62700179219246, 52.11522191762924, 50.42755387723446, 53.36260758340359, 52.812936678528786, 56.80328495800495, 51.80510155856609, 56.445933133363724, 51.81688092648983, 62.03675173223019, 32.12862119078636, 29.86834667623043, 57.82052457332611, 49.68779817223549, 57.159553840756416, 50.27737453579903, 50.640874430537224, 49.357934072613716, 52.90057137608528, 51.43075704574585, 54.23779182136059, 49.746809005737305, 47.772491946816444, 39.489453211426735, 43.6737734824419, 41.02623134851456, 41.51176169514656, 40.322687700390816, 41.96154735982418, 41.21503181755543, 43.44418980181217, 41.37526161968708, 44.99610252678394, 48.301906138658524, 54.08805325627327, 54.65225078165531, 55.08573152124882, 55.402376130223274, 47.85216607153416, 42.62671306729317, 41.99550613760948, 42.74190008640289, 44.02066446840763, 44.597367122769356, 43.646977320313454, 42.41144321858883, 44.557302072644234, 43.633412048220634, 45.61789736151695, 46.157305017113686, 45.99571108818054, 43.27157266438007, 42.722144946455956, 44.04285527765751, 43.984832391142845, 45.351364463567734, 46.30545146763325, 47.836522310972214, 51.42853036522865, 54.05700132250786, 52.33790136873722, 53.614389672875404, 60.01350089907646, 60.08709914982319, 61.107663586735725, 60.95035582780838, 14.343767669051886, 0.8196415496058762, 7.220329809933901, 2.6823487412184477, 0.7610752328764647, 0.2044321919674985, 4.436498489230871, 45.607900097966194, 38.92394855618477, 30.366028770804405, 24.085718169808388, 32.326085194945335, 40.45173637568951, 48.385102674365044, 54.83818240463734, 59.49671722948551, 10.027008354663849, 0.23566520976601169, 0.04062081112351734, 0.0680733694753144, 0.054163533059181646, 0.07147839496610686, 0.06790528786950745, 0.02939127072750125, 0.03333414177177474, 0.0672449693956878, 0.05347509832063224, 0.020380434616527054, 0.023588343829032965, 0.02532245165639324, 0.05833978357259184, 0.00964524899245589, 0.06123518367530778, 0.1330785668687895, 0.19738008209969848, 0.23746053921058774, 0.1174687001912389, 0.16123744571814314, 0.15661165409255773, 0.04296607199648861, 0.10559183632722124, 0.10216150360065512, 0.1136979962757323, 0.11667988626868464, 0.2085650194203481, 0.2078614931087941, 0.19008661096449941, 0.2356084799976088, 12.55812093615532, 83.00191015005112, 72.57997378706932, 73.40639904141426, 52.23741956055164, 37.80581675469875, 39.392820596694946, 46.25192753970623, 49.95420567691326, 62.52759799361229, 6.608274802565575, 0.4974498617229983, 0.11238360821153037, 4.70163781195879, 31.290450766682625, 3.791575958020985, 22.760242894291878, 81.20515376329422, 68.96880716085434, 71.71179637312889, 60.02221763134003, 56.53300166130066, 58.24333928525448, 65.40547236800194, 64.79396358132362, 66.38844922184944, 65.73091730475426, 61.2779438495636, 60.767836421728134, 62.41023749113083, 60.54846279323101, 59.601697996258736, 50.80500662326813, 48.70889849960804, 44.498374834656715, 45.157365873456, 44.43898782134056, 45.38018971681595, 46.39720894396305, 45.032257586717606, 45.27425520122051, 45.22986218333244, 44.131356328725815, 44.60341639816761, 43.404291942715645, 43.892444148659706, 44.57070015370846, 45.64164608716965, 42.062944918870926, 44.48373802006245, 41.8648387491703, 46.86758570373058, 49.37100537121296, 50.18260382115841, 45.0425436347723, 45.44073946774006, 45.25620996952057, 46.380387246608734, 43.2102819532156, 45.67737936973572, 41.36451579630375, 46.066030114889145, 44.94966521859169, 55.16689896583557, 52.973557859659195, 55.46351484954357, 53.58273737132549, 58.97127762436867, 52.375823333859444, 58.0159442871809, 53.62206906080246, 62.97536216676235, 34.81171801686287, 32.87031479179859, 59.41076964139938, 53.575878739356995, 60.289214104413986, 52.694181650877, 52.553691789507866, 51.254446506500244, 56.328565031290054, 52.44089104235172, 56.980416253209114, 53.67756508290768, 49.83239561319351, 40.78205265104771, 45.58400318026543, 43.10837522149086, 43.67578737437725, 43.0222300440073, 43.426338359713554, 45.125409588217735, 46.769281178712845, 43.94741199910641, 47.391410395503044, 50.64422205090523, 54.82154689729214, 58.034479692578316, 58.51771116256714, 57.856174260377884, 50.399819165468216, 45.083022862672806, 42.783895432949066, 45.290636122226715, 46.47190533578396, 47.18880146741867, 47.46530883014202, 45.661891400814056, 47.29596711695194, 46.49185426533222, 48.00945483148098, 48.49920675158501, 46.97774939239025, 45.15204235911369, 44.11878660321236, 46.789192110300064, 44.93528299033642, 48.51252123713493, 49.273776188492775, 51.83324284851551, 53.17364752292633, 58.30700106918812, 54.34226341545582, 56.306108236312866, 61.28851108253002, 62.976445108652115, 62.7244084328413, 65.4247373342514, 14.563773013651371, 5.263733575120568, 25.017906948924065, 2.304936842992902, 0.6255306873936206, 0.2957343606976792, 5.345684252679348, 50.980135425925255, 54.048911556601524, 44.71161179244518, 27.281922362744808, 36.79133199155331, 47.433591932058334, 58.76072712242603, 63.453216925263405, 69.73124384880066, 12.25462932139635, 0.537374111590907, 0.19535878353053704, 0.23160950629971921, 0.10833482156158425, 0.13605382206151262, 0.14660937362350523, 0.2317203683196567, 0.11759645349229686, 0.1978712502750568, 0.09863307379418984, 0.09736437234096229, 0.17687457147985697, 0.09139724526903592, 0.15445181139511988, 0.128925048338715, 0.12877503060735762], [0.022848066364531405, 0.02253267401101766, 0.06770173160475679, 0.04293311321816873, 0.027731626287277322, 0.034493209459469654, 0.03892540073138662, 0.09859241152298637, 0.032696577545721084, 0.032981395270326175, 0.041533526600687765, 0.08407152781728655, 0.03902749056578614, 0.07570563102490269, 0.08579897301387973, 14.277816507965326, 62.008211463689804, 62.10079729557037, 50.10875478386879, 32.774293944239616, 20.320606604218483, 33.54186415672302, 45.41345313191414, 41.8278781324625, 44.33614633977413, 0.66626604530029, 0.040366569883190095, 0.16843954363139346, 3.6201809300109744, 6.849613627418876, 2.274289824999869, 44.52894039452076, 70.09629786014557, 62.918631210923195, 61.864020600914955, 55.4803441464901, 47.1830789744854, 46.83803468942642, 54.73165512084961, 57.477459982037544, 59.25528198480606, 58.44428010284901, 59.521013125777245, 56.28801740705967, 55.53786166012287, 53.923484086990356, 57.3548823595047, 48.06107126176357, 42.726681903004646, 40.45427463948727, 43.74753512442112, 43.55906143784523, 42.25221276283264, 40.882621854543686, 41.14273689687252, 39.923503920435905, 42.589779049158096, 41.989464461803436, 41.22079610824585, 41.31762631237507, 40.013612285256386, 40.42745567858219, 41.32345139980316, 40.10207913815975, 41.926273852586746, 39.10159282386303, 40.4327791929245, 39.23502266407013, 41.95360578596592, 39.487256929278374, 41.439766958355904, 40.94581626355648, 42.09939256310463, 37.689109817147255, 41.62791006267071, 38.428797125816345, 40.3039775043726, 39.385916367173195, 46.25341705977917, 45.571319460868835, 51.55558034777641, 47.12866969406605, 51.183872893452644, 47.37102068960667, 54.65490683913231, 49.49641764163971, 60.52022270858288, 29.985256902873516, 31.16893518716097, 55.38755312561989, 49.88171696662903, 54.67441499233246, 45.35722754895687, 46.45786888897419, 43.559099435806274, 47.0490525662899, 49.37235049903393, 47.61796183884144, 47.29440540075302, 47.180992886424065, 41.94719932973385, 38.999347910284996, 39.714499935507774, 40.06022058427334, 40.3848447650671, 39.700600281357765, 39.3075417727232, 38.04926589131355, 39.47069741785526, 41.97224758565426, 45.09045526385307, 49.461839497089386, 53.45370389521122, 54.41738158464432, 48.44722934067249, 41.54646523296833, 40.37638261914253, 40.95070280134678, 42.22437925636768, 40.72629064321518, 40.19646607339382, 42.330180779099464, 41.36689066886902, 40.11805348098278, 45.10298319160938, 46.33608542382717, 51.07473514974117, 46.39798790216446, 46.18589848279953, 40.01675471663475, 42.585120499134064, 43.31108674407005, 44.174275025725365, 41.91932402551174, 48.83416637778282, 48.33055280148983, 51.86728522181511, 55.130629912018776, 56.917449831962585, 58.09741571545601, 61.19951605796814, 58.41382093727589, 63.551308661699295, 36.57647252082825, 1.9172802194952965, 3.3709309296682477, 3.9819072699174285, 0.12347005511401221, 0.06237559748115018, 0.1063783273275476, 19.739752672612667, 43.14293436706066, 36.08354017138481, 15.870845876634121, 12.979110796004534, 27.43799138814211, 40.285077318549156, 48.384418711066246, 56.41906097531319, 23.593243695795536, 0.30745471303816885, 0.051744881202466786, 0.1228715872275643, 0.013749018580710981, 0.04349983202700969, 0.017553054203744978, 0.05939016744378023, 0.061753892950946465, 0.06147992542537395, 0.08057585640926845, 0.07424296185490675, 0.051160937146050856, 0.12384423112962395, 0.15967118757544085, 0.019598097787820734, 0.023728726628178265, 0.01743993976560887, 0.013132446929375874, 0.021504454380192328, 0.024955153494374827, 0.023423089805874042, 0.049411353684263304, 0.002935556785814697, 0.0007313982473533542, 0.047545074921799824, 0.046994078511488624, 0.05367040190321859, 0.010966195786750177, 0.0999683681584429, 0.08257790366769768, 0.10243899261695333, 22.482937574386597, 74.4937714934349, 68.43252673745155, 59.13827486336231, 37.248132079839706, 28.409376963973045, 32.891996428370476, 42.58888229727745, 45.77250726521015, 47.750118747353554, 0.47424225078430027, 0.11914631017134525, 0.41106856253463775, 8.447574656456709, 8.086768817156553, 3.0692470679059625, 49.869888201355934, 68.84096682071686, 66.97848916053772, 63.12833055853844, 58.414702489972115, 49.803486764431, 49.40142273902893, 56.17480628192425, 60.11972039937973, 61.88597582280636, 60.952829495072365, 61.66881367564201, 58.424418568611145, 56.881613954901695, 56.39627739787102, 60.444200187921524, 51.82891488075256, 45.812120139598846, 42.892387211322784, 44.73578229546547, 46.233958303928375, 43.416177704930305, 41.807454228401184, 42.95267477631569, 42.564909383654594, 43.910177797079086, 42.42190785706043, 43.77190321683884, 42.416842728853226, 41.048414558172226, 42.2494351118803, 42.20379576086998, 42.46676824986935, 42.459161058068275, 41.29082255065441, 42.54044249653816, 41.12301215529442, 43.61505903303623, 41.07775278389454, 42.90906451642513, 42.43651047348976, 44.872742146253586, 39.747102186083794, 42.914752811193466, 40.44330842792988, 43.37889030575752, 41.843795478343964, 48.90560254454613, 48.66551622748375, 52.53857620060444, 50.046255737543106, 53.67546759545803, 48.27726446092129, 55.55485434830189, 50.77078565955162, 62.76314355432987, 31.132882721722126, 31.496314220130444, 55.765142664313316, 51.63432352244854, 57.51769982278347, 48.29764276742935, 48.396517261862755, 45.3930976241827, 49.07894924283028, 50.061416923999786, 48.96391801536083, 48.83830055594444, 49.35455225408077, 42.303882390260696, 40.61195857822895, 40.95368564128876, 42.06992134451866, 41.56829126179218, 41.3157644122839, 41.668032109737396, 41.251046285033226, 42.492029294371605, 44.15705054998398, 46.73416346311569, 51.547384187579155, 55.3689569234848, 55.59005945920944, 51.23235069215298, 43.25261548161507, 42.47636653482914, 42.75229632854462, 43.43346677720547, 43.03179793059826, 42.91854500770569, 43.63616690039635, 42.718740329146385, 43.641053438186646, 47.303566709160805, 48.9562576264143, 50.94847932457924, 48.12315233051777, 47.398656606674194, 42.947028279304504, 44.77975353598595, 44.85919587314129, 47.285069301724434, 44.793258011341095, 50.19928112626076, 51.519387289881706, 54.388712123036385, 57.33205698430538, 57.58811004459858, 61.37186340987682, 61.19538567960262, 60.260134264826775, 64.56976801156998, 40.46291157603264, 2.5446973275393248, 2.993241408839822, 4.4362230040133, 0.15237724146572873, 0.10959654682665132, 0.23818230751203373, 23.29723957926035, 46.19379065930843, 32.094673812389374, 19.389052391052246, 22.453137673437595, 34.03866849839687, 47.69057214260101, 53.30887846648693, 63.51196937263012, 35.34766025841236, 0.7017774553969502, 0.11019109617336653, 0.011520437237777514, 0.05201859268709086, 0.10499643351067789, 0.02494428845238872, 0.05865436884050723, 0.03471918229479343, 0.041518000871292315, 0.02640899852849543, 0.027442340833658818, 0.08951219759183004, 0.07889985688962042, 0.04906216578092426, 0.07297679854673333, 0.05865947110578418, 0.08963717526057735, 0.20445410016691312, 0.14200969075318426, 0.20246879576006904, 0.11966038844548166, 0.15115535468794405, 0.1725737366359681, 0.12056856940034777, 0.16557952912990004, 0.15723820484708995, 0.15715943329269066, 0.14824292971752584, 0.1776007332955487, 0.3031311387894675, 0.1877055934164673, 31.637628637254238, 83.28500255942345, 76.08406975865364, 66.4235669374466, 46.145521849393845, 30.77577978372574, 46.05752617120743, 59.58736516535282, 56.445993930101395, 54.99051243066788, 0.7218609214760363, 0.22663545445539057, 0.9479695104528219, 7.5773201789706945, 15.288540422916412, 4.469001470133662, 51.86372101306915, 71.54317662119865, 68.09555321931839, 65.52807658910751, 61.71795643866062, 51.32335960865021, 52.66033686697483, 58.032112419605255, 63.670983240008354, 64.03128370642662, 64.43158462643623, 64.80715647339821, 60.924642607569695, 60.822948664426804, 60.00278167426586, 61.93645231425762, 53.34386318922043, 47.491766810417175, 44.915436655282974, 48.46710227429867, 47.88460873067379, 46.07038088142872, 43.986211717128754, 45.111156553030014, 44.575936272740364, 47.30023808777332, 44.46225397288799, 46.52702137827873, 44.74791884422302, 43.37675102055073, 44.28874768316746, 44.71416525542736, 44.58142317831516, 44.93065483868122, 44.10324543714523, 44.194455742836, 42.78168395161629, 46.02875791490078, 44.87546660006046, 45.50339810550213, 44.20221112668514, 47.58344069123268, 41.75400249660015, 43.97697441279888, 42.4813062697649, 44.5082239061594, 43.80803927779198, 51.21532000601292, 51.23575530946255, 55.31421326100826, 52.6314128190279, 55.537094101309776, 52.30790197849274, 59.74065274000168, 54.95911091566086, 64.04922634363174, 35.16314975917339, 36.14277519285679, 57.37591043114662, 55.565064400434494, 58.728915229439735, 49.721126183867455, 50.26223614811897, 48.72624836862087, 50.167473033070564, 54.48988549411297, 50.657433941960335, 51.1638517677784, 52.01560266315937, 45.71692384779453, 43.108002841472626, 43.74814309179783, 45.43207213282585, 44.83336865901947, 43.88678625226021, 44.62103985249996, 41.921178326010704, 43.960418701171875, 47.09466151893139, 48.83872993290424, 54.695910438895226, 57.70625330507755, 58.456739634275436, 54.19160149991512, 45.90789020061493, 43.890650644898415, 45.1270966976881, 45.778134763240814, 44.589125365018845, 44.39086340367794, 46.52495048940182, 45.48134408891201, 44.075069949030876, 48.54225464165211, 51.629748567938805, 55.36410838365555, 51.32105313241482, 50.54653689265251, 45.838521122932434, 47.23189115524292, 48.02052363753319, 51.131504103541374, 47.15395353734493, 54.1267503798008, 53.3359482139349, 57.851131930947304, 60.376164838671684, 62.0578557997942, 64.84804227948189, 64.84034389257431, 62.79788888990879, 66.12136155366898, 41.06457129120827, 4.260750794783235, 14.113840106874704, 12.00744403526187, 0.37456386198755354, 0.21419855853309855, 0.16938178916461766, 27.805015593767166, 59.99306559562683, 50.9089994430542, 24.077105931937695, 22.720286138355732, 38.800721168518066, 57.4319726228714, 61.51925750076771, 71.58126577734947, 41.475861221551895, 1.4582601003348827, 0.16861233045347035, 0.2364615342230536, 0.08726769068744034, 0.22238729725359008, 0.19102045538602397, 0.11591194896027446, 0.18673093087272719, 0.1824091823073104, 0.1529682581895031, 0.16610308462986723, 0.14669672440504655, 0.2745046326890588, 0.19129356573102996, 0.1812973857158795, 0.18564755853731185], [0.01481113209592877, 0.12454425450414419, 0.0711931505065877, 0.08791204556473531, 0.07075486035319045, 0.056334745459025726, 0.020408582422533073, 0.0023952403444127413, 0.03711110199219547, 0.029113254786352627, 0.0323550337634515, 0.03943865522160195, 0.018465261309756897, 0.05892479261092376, 1.0502821672707796, 36.967885717749596, 58.20453576743603, 59.450534507632256, 48.14403221011162, 36.906777396798134, 27.253401093184948, 42.77986004948616, 38.938000202178955, 46.49255722761154, 27.074715681374073, 0.13871658855350688, 0.11513092016684823, 0.27547957724891603, 10.509025789797306, 8.308978993445635, 5.573856309056282, 44.73387099802494, 71.06908366084099, 61.872638538479805, 60.90954601764679, 56.16715349256992, 50.67944996058941, 44.199254885315895, 46.096550077199936, 50.399792566895485, 55.74863635003567, 57.78534986078739, 59.14331719279289, 55.35093829035759, 56.033708453178406, 54.55822862684727, 57.9051498323679, 49.59104776382446, 44.20115478336811, 41.528032422065735, 42.307970970869064, 40.12601785361767, 42.6815365254879, 40.285711884498596, 41.677326411008835, 39.445831552147865, 41.31576061248779, 40.365135222673416, 40.474082976579666, 40.623247772455215, 41.57969444990158, 39.540784657001495, 41.46147519350052, 38.97998794913292, 42.136638164520264, 39.868365079164505, 40.74554421007633, 40.91599926352501, 42.43308685719967, 40.489088371396065, 39.830496311187744, 40.42022846639156, 40.87176963686943, 39.929025024175644, 41.00078411400318, 39.13660794496536, 40.673652067780495, 39.89076107740402, 45.68454958498478, 42.83341817557812, 47.21623979508877, 45.8709903806448, 49.45631079375744, 43.42245876789093, 51.916272193193436, 47.048129215836525, 60.851120352745056, 28.457645773887634, 26.723728515207767, 53.687056973576546, 48.25259618461132, 54.99606393277645, 49.883943647146225, 50.18761955201626, 43.52397792041302, 43.57389584183693, 44.17776703834534, 46.00471280515194, 45.79592540860176, 45.99416457116604, 41.602215841412544, 38.4089469909668, 39.575260207057, 39.86849807202816, 38.1211694329977, 40.1013457775116, 38.39124754071236, 41.62074364721775, 41.301879957318306, 40.95862157642841, 40.68940222263336, 43.81798714399338, 46.9939137250185, 46.48396968841553, 41.754975244402885, 40.97405254840851, 40.583433508872986, 41.66027672588825, 40.91811574995518, 41.49179756641388, 41.02068364620209, 40.915326699614525, 40.740855261683464, 43.841359689831734, 47.13165633380413, 51.17223031818867, 49.917902424931526, 50.397049114108086, 49.382450357079506, 44.856114238500595, 42.707359939813614, 43.42834085226059, 45.193308144807816, 45.35331755876541, 48.86355400085449, 51.1754335463047, 52.49663405120373, 55.27530334889889, 54.80361945927143, 55.980781093239784, 60.65801851451397, 55.405336171388626, 56.76228515803814, 55.41524983942509, 14.160405658185482, 2.503326334990561, 4.834547080099583, 0.6018334371037781, 0.05542598933971021, 0.16017310204915702, 9.251099489629269, 40.423823073506355, 36.08586944639683, 28.624688610434532, 11.707872860133648, 27.650291696190834, 43.22282887995243, 49.18936751782894, 52.00734190642834, 38.63149344921112, 2.5327500561252236, 0.05217031735810451, 0.013178060253267176, 0.030414820394071285, 0.017951661720871925, 0.03742973196494859, 0.06521836447063833, 0.02515059066354297, 0.0465790435555391, 0.05716666331863962, 0.0360490292950999, 0.05662445393681992, 0.05357364811061416, 0.03739615349331871, 0.045507649483624846, 0.13388882885919884, 0.031670725365984254, 0.07453122685546987, 0.017304115608567372, 0.031840339506743476, 0.07606909042806365, 0.05195336532779038, 0.05679847272404004, 0.07220897998195142, 0.044779799281968735, 0.0650512550782878, 0.03093137187534012, 0.04535717162070796, 0.042708966066129506, 0.05709398479666561, 1.835902954917401, 48.202701061964035, 66.25037223100662, 65.429198294878, 52.788522988557816, 42.912959307432175, 27.917295768857002, 42.32948541641235, 41.59178540110588, 55.78428603708744, 30.928100310266018, 0.11223531226278283, 0.043573653456405737, 0.9669050818774849, 14.697685427963734, 8.081597294658422, 5.504862936213613, 47.993218302726746, 72.15200275182724, 64.4072887301445, 62.70165905356407, 57.62690596282482, 52.74996645748615, 47.00970187783241, 48.6829686909914, 52.58397616446018, 57.731955125927925, 60.08613020181656, 61.51107273995876, 58.015340119600296, 59.056822434067726, 57.44358479976654, 60.42973056435585, 51.098852455616, 47.08191700279713, 43.77236299216747, 42.596234902739525, 41.27459742128849, 43.22790540754795, 41.532181799411774, 43.268297240138054, 42.24836736917496, 43.8758048415184, 41.45547151565552, 41.802643686532974, 41.54348999261856, 45.30020400881767, 42.40030601620674, 42.28050984442234, 41.98285661637783, 42.439299523830414, 41.9716852158308, 41.3332586735487, 40.239130184054375, 42.754207625985146, 42.221259623765945, 43.00794281065464, 41.13952986896038, 42.30750359594822, 41.36125557124615, 42.49758459627628, 41.841257214546204, 42.0069245249033, 41.79097071290016, 49.15475517511368, 46.35080963373184, 50.72564408183098, 47.711231634020805, 50.765051767230034, 46.423100754618645, 54.520268663764, 48.31848464906216, 62.78770923614502, 30.082085207104683, 27.915821447968483, 52.78944633901119, 49.256281927227974, 57.03876972198486, 50.75817033648491, 52.533024698495865, 46.16523519158363, 45.57460628449917, 45.946028754115105, 47.77379147708416, 46.4663652330637, 47.95883394777775, 42.3769486695528, 40.886497646570206, 41.78853124380112, 41.761894673109055, 41.083418279886246, 41.506730765104294, 40.5969113856554, 42.46366001665592, 42.303494811058044, 42.4204221367836, 43.77359792590141, 48.082931488752365, 48.70934307575226, 48.49185414612293, 43.87645460665226, 42.67627000808716, 43.242796808481216, 43.632538095116615, 43.23394328355789, 42.55207747220993, 42.130482494831085, 42.901666313409805, 43.04533660411835, 45.901130363345146, 49.48209621012211, 52.01358117163181, 52.08567090332508, 53.42088125646114, 50.577702820301056, 45.92479929327965, 45.122141763567924, 44.69717636704445, 46.80724494159222, 48.31013649702072, 52.84947171807289, 53.92915718257427, 54.80704307556152, 56.660579815506935, 56.95142760872841, 58.05760145187378, 62.34241493046284, 58.048979714512825, 57.672632709145546, 58.82858008146286, 17.374296002089977, 3.1258797040209174, 4.677032707259059, 1.25598412938416, 0.21670094691216946, 0.1797041727695614, 9.125524777919054, 48.22232320904732, 35.350365713238716, 29.770406931638718, 17.483618035912514, 35.10789692401886, 50.84432691335678, 55.489467456936836, 57.14385688304901, 50.26628293097019, 5.227061742916703, 0.11048505344660953, 0.018318622205697466, 0.04689986657467671, 0.008039774838835001, 0.03434723272221163, 0.03706875504576601, 0.04893619363429025, 0.04436312417965382, 0.12984565284568816, 0.03189936622220557, 0.08477988551021554, 0.021803235613333527, 0.033451638591941446, 0.03760563580726739, 0.019759433271246962, 0.12538492970634252, 0.23099736805306748, 0.1567743328632787, 0.22736488172085956, 0.25087239453569055, 0.13034332223469391, 0.10268580866977572, 0.239208861021325, 0.19126782804960385, 0.1491071013151668, 0.0857506888860371, 0.10427237197291106, 0.10818115246365778, 0.1952419991721399, 2.520040450617671, 58.635394647717476, 73.90049412846565, 74.56930384039879, 61.01524114608765, 51.35810114443302, 36.351843774318695, 53.18392597138882, 49.88462761044502, 63.44285488128662, 34.549330696463585, 0.3176470723701641, 0.20917821151670069, 1.0476839379407465, 25.734073519706726, 19.004676416516304, 7.770558809861541, 50.895369574427605, 73.36135625839233, 66.77325457334518, 63.3501398563385, 59.3044513463974, 54.99419443309307, 49.306766018271446, 49.603020921349525, 53.92224155366421, 60.161605551838875, 62.12708808481693, 64.33075323700905, 61.226342618465424, 60.30934542417526, 59.024201184511185, 63.05959224700928, 54.9005788564682, 51.69574722647667, 45.58406017720699, 44.84573319554329, 43.47223989665508, 45.92614822089672, 44.326715245842934, 45.01341059803963, 44.20034922659397, 47.048763781785965, 44.12347175180912, 44.50355775654316, 44.41986344754696, 46.50544993579388, 43.89457203447819, 44.29540112614632, 44.46421466767788, 45.93064717948437, 44.89511154592037, 42.163685113191605, 45.69042406976223, 48.151764795184135, 45.140817761421204, 44.808787778019905, 43.63558553159237, 44.29069697856903, 44.28530506789684, 45.21857298910618, 44.24191139638424, 46.04868024587631, 44.60354559123516, 51.462584137916565, 48.25028210878372, 52.21118576824665, 52.04520307481289, 53.43731917440891, 47.68686354160309, 55.67062273621559, 51.536193788051605, 65.07093831896782, 34.46521081030369, 30.859116911888123, 52.62733183801174, 53.01339492201805, 59.04863767325878, 53.1795372068882, 56.45870804786682, 50.172549560666084, 47.80737027525902, 48.922124058008194, 51.09098307788372, 48.93749803304672, 52.16671295464039, 45.620317831635475, 42.18121737241745, 43.97773817181587, 44.89407800137997, 42.091568782925606, 44.69648860394955, 41.317641511559486, 45.28391048312187, 44.521048218011856, 45.96647545695305, 46.85649789869785, 50.40719456970692, 51.327877566218376, 51.00536227226257, 46.436612829566, 44.717984050512314, 45.06352610886097, 46.66885256767273, 45.318256840109825, 46.992367208004, 44.47466790676117, 45.20796395838261, 45.27161054313183, 48.46560135483742, 51.257980316877365, 55.10048992931843, 54.24411468207836, 55.19022211432457, 54.07240189611912, 48.24590474367142, 47.38113194704056, 47.46465906500816, 48.50326493382454, 51.7610315233469, 55.66414028406143, 56.85318008065224, 57.73032881319523, 59.818734750151634, 59.88659530878067, 60.32099939882755, 65.62918916344643, 60.869959741830826, 59.1003642976284, 61.002565026283264, 17.4987830221653, 7.635488882660866, 11.619292013347149, 2.766218315809965, 0.3194025781704113, 0.25944817811250687, 11.120521277189255, 55.561747178435326, 50.42799845337868, 37.89754383265972, 18.987980112433434, 39.44743126630783, 55.711253955960274, 63.62357698380947, 63.43759596347809, 60.1842675358057, 7.091597942635417, 0.26064627163577825, 0.21046571899205446, 0.18575850961497054, 0.11982275551417843, 0.09166959862341173, 0.2077469351934269, 0.25438842305447906, 0.11180263274582103, 0.3096539340913296, 0.10105262364959344, 0.15096299001015723, 0.13496236031642184, 0.2121252057258971, 0.14206885476596653, 0.30131629086099565], [0.022700117369822692, 0.03925371202058159, 0.04697248943557497, 0.0372277304995805, 0.029240744624985382, 0.037761356943519786, 0.05005312959838193, 0.02048258753347909, 0.048019875030149706, 0.03770495000935625, 0.011650265769276302, 0.03822683938778937, 0.051163920579710975, 0.11718101406586356, 5.266119847074151, 41.93008504807949, 55.11475816369057, 55.33637747168541, 39.0869066119194, 25.733351558446884, 38.03265318274498, 37.413993179798126, 36.23900882899761, 56.91090278327465, 17.016140520572662, 0.40507972764316946, 0.3447446651989594, 0.2971469348995015, 14.155861102044582, 6.704743076115847, 2.9827710706740618, 54.85884189605713, 64.96838182210922, 63.40259604156017, 60.1380468159914, 59.53763723373413, 53.028928488492966, 45.52638687193394, 45.90869575738907, 43.88919912278652, 46.759967878460884, 51.58870317041874, 54.671367555856705, 58.79063531756401, 61.45898513495922, 58.44584561884403, 55.31026527285576, 45.99263705313206, 43.21119390428066, 41.037129163742065, 41.93735405802727, 41.31313495337963, 42.23586603999138, 38.756601735949516, 40.50889290869236, 39.939763247966766, 40.583346113562584, 40.18350876867771, 41.55555434525013, 41.204696372151375, 41.91250339150429, 40.8929231017828, 41.032755598425865, 41.044785752892494, 41.14809460937977, 40.12493871152401, 42.09890998899937, 40.40400333702564, 42.66962796449661, 40.03732681274414, 40.842522606253624, 40.03270626068115, 40.67937456071377, 39.04022991657257, 40.32817840576172, 38.6055788397789, 40.80767847597599, 38.15094083547592, 42.512996569275856, 41.085090190172195, 45.76236180961132, 43.93875986337662, 47.26501017808914, 44.793394804000854, 53.443813025951385, 47.96307072043419, 58.84349428117275, 27.548685148358345, 26.566424556076527, 48.287029936909676, 46.84500731527805, 56.5778848528862, 49.637663662433624, 50.638697147369385, 45.73122248053551, 42.360161170363426, 40.539492666721344, 42.91869319975376, 42.63571098446846, 43.18354278802872, 42.492724657058716, 40.70585533976555, 38.966548070311546, 38.53041507303715, 40.92995211482048, 40.11367991566658, 39.74163047969341, 43.1491394340992, 41.71078361570835, 41.04780279099941, 40.673473477363586, 41.136353239417076, 39.30088832974434, 41.54667042195797, 39.15155254304409, 39.488955438137054, 38.48390556871891, 41.07043817639351, 41.366955265402794, 40.270026326179504, 41.115249171853065, 40.092914029955864, 43.57110679149628, 50.43903686106205, 49.80420492589474, 53.1996039301157, 55.25486424565315, 51.9546577334404, 50.34694120287895, 48.03856886923313, 42.244917154312134, 41.659455969929695, 42.81541854143143, 49.46900211274624, 49.227289482951164, 53.03621269762516, 54.046278297901154, 57.71997056901455, 56.245824471116066, 57.13434599339962, 53.935043066740036, 61.4869250357151, 59.6011546254158, 65.44525623321533, 44.98196728527546, 8.027740884572268, 1.709353239275515, 0.2907490578945726, 0.07118952882592566, 0.06682541104964912, 1.2431716918945312, 32.40913733839989, 35.76430030167103, 41.628096252679825, 33.79372224211693, 18.121740594506264, 33.351007997989655, 42.06688150763512, 47.40088328719139, 52.464613169431686, 13.198888152837753, 0.16240992030361667, 0.04975728355930187, 0.023424368155247066, 0.045391744570224546, 0.04956648110237438, 0.012296681034058565, 0.09118201502133161, 0.03976890351623297, 0.11987100253463723, 0.04283945047063753, 0.06328380070044659, 0.011652663833956467, 0.04633241675037425, 0.08605879891547374, 0.03027211281732889, 0.02204626114689745, 0.02335395689442521, 0.04896821359579917, 0.01075119467714103, 0.016609214908385184, 0.08647001552162692, 0.03598085560952313, 0.07526483241235837, 0.04286837938707322, 0.0124432310803968, 0.07856559357605875, 0.055291976022999734, 0.06124640494817868, 0.19425466074608266, 8.152154758572578, 55.011871084570885, 62.13914103806019, 64.54943150281906, 45.3756033629179, 38.33762861788273, 45.13420231640339, 37.741805389523506, 37.29099377989769, 65.62418103218079, 17.03601725399494, 0.48448718385770917, 0.2535508351866156, 1.5650498075410724, 12.163313571363688, 4.977639801800251, 4.682982712984085, 55.394563749432564, 66.39649718999863, 65.43831780552864, 65.09959638118744, 62.04776354134083, 53.97412396967411, 46.8766900151968, 46.91461198031902, 45.51587663590908, 50.85173271596432, 54.110757037997246, 56.761981174349785, 59.24104794859886, 62.149924859404564, 58.99444118142128, 57.32296787202358, 47.96311631798744, 45.92984162271023, 42.25893460214138, 43.54988493025303, 43.12209628522396, 43.97336080670357, 41.326935812830925, 41.89623646438122, 42.45443031191826, 43.607660830020905, 42.550785541534424, 42.97003224492073, 44.36743386089802, 44.94206182658672, 42.41414487361908, 43.934116512537, 41.91351033747196, 43.50891552865505, 41.53112545609474, 42.901168540120125, 41.38314999639988, 44.49703350663185, 41.330545619130135, 43.384476006031036, 41.447032168507576, 42.140293568372726, 40.468318685889244, 42.29147985577583, 42.30244226753712, 42.111840695142746, 42.066820710897446, 44.14521038532257, 44.20280769467354, 48.47943641245365, 45.58375619351864, 48.77030320465565, 47.36549198627472, 54.83807981014252, 50.700257644057274, 60.35984851419926, 29.592365585267544, 27.000353671610355, 51.00810572504997, 48.543212190270424, 57.8802003711462, 51.56801328063011, 52.45965823531151, 48.37754487991333, 45.08819438517094, 42.54236899316311, 45.48901967704296, 45.18086761236191, 44.938744604587555, 44.068294912576675, 40.906967148184776, 40.68304896354675, 40.92506557703018, 42.57497884333134, 42.38215059041977, 42.56866358220577, 44.74604554474354, 43.83718751370907, 42.676988169550896, 41.7367248237133, 43.00008483231068, 42.042802199721336, 44.03191566467285, 40.64703829586506, 42.018935680389404, 40.473258420825005, 43.208347856998444, 42.40260869264603, 41.93890817463398, 42.06015966832638, 41.41792573034763, 46.4041967689991, 53.20768229663372, 53.93119007349014, 55.58938689529896, 55.97405545413494, 54.54531691968441, 53.36396411061287, 50.99791847169399, 45.32506227493286, 44.00220885872841, 46.48061826825142, 51.16593025624752, 50.89717447757721, 56.05210326611996, 57.49078966677189, 59.36558626592159, 57.206116542220116, 59.514762461185455, 56.168878600001335, 62.23497189581394, 60.60317225754261, 65.56387066841125, 49.816140085458755, 8.038930334150791, 0.5522695498075336, 3.139576781541109, 0.3891705453861505, 0.12333437567576766, 0.7723979721777141, 34.43850204348564, 41.47575102746487, 34.9265668541193, 28.86726949363947, 26.777045354247093, 42.71013379096985, 49.30349059402943, 51.950736343860626, 62.25475363433361, 21.234524063766003, 0.20227414526743814, 0.020145147827861365, 0.09489749572821893, 0.008162661506503355, 0.022769756797060836, 0.0864211970474571, 0.08249272737884894, 0.007996988169907127, 0.023580118977406528, 0.005783849064755486, 0.04209636026644148, 0.056765465706121176, 0.05478524501086213, 0.033040173366316594, 0.020813928640563972, 0.14868133119307458, 0.11858138735988177, 0.12793969886843115, 0.1964010705705732, 0.10775998365716077, 0.17759173846570775, 0.11779056963860057, 0.16352284495951608, 0.0878406732226722, 0.09215704863891006, 0.11105675206636079, 0.12440251171938144, 0.1759729511104524, 0.2604209556011483, 9.324758537113667, 69.8567359149456, 69.31042402982712, 74.35464575886726, 52.158847376704216, 38.395499512553215, 46.24348059296608, 48.4330864995718, 49.494920521974564, 71.7849500477314, 20.101951137185097, 0.6882713770028204, 0.46311612124554813, 2.2450104961171746, 29.38761167228222, 15.11578744277358, 4.8056472558528185, 59.96504209935665, 67.68253058195114, 67.73676127195358, 66.67084246873856, 65.09491503238678, 56.055154502391815, 49.72825460135937, 48.44666317105293, 48.274980783462524, 53.90386573970318, 57.277719900012016, 58.96593891084194, 62.96483673155308, 66.07333973050117, 64.18770611286163, 60.667191222310066, 50.56014396250248, 47.16707043349743, 45.7579692453146, 45.06879262626171, 46.155861094594, 44.615100771188736, 42.03979656100273, 45.02571813762188, 44.306196346879005, 45.37712328135967, 44.478000327944756, 44.72845248878002, 46.25703066587448, 46.504154205322266, 45.061352625489235, 45.306842252612114, 45.564107447862625, 45.13666458427906, 43.623954355716705, 44.626325368881226, 44.139107912778854, 46.71612963080406, 45.13007953763008, 44.38501551747322, 43.8330989331007, 44.659999161958694, 42.95639477670193, 43.872187435626984, 44.96799163520336, 45.166690573096275, 43.073143512010574, 47.28087432682514, 47.12277241051197, 51.739064902067184, 48.65150257945061, 51.599787175655365, 50.62151066958904, 57.38805077970028, 52.67202503979206, 60.120263770222664, 33.277253955602646, 29.685126207768917, 50.37448972463608, 50.626598596572876, 60.42043626308441, 55.62866538763046, 53.36678355932236, 49.97630149126053, 46.50230750441551, 46.40670083463192, 46.83197021484375, 48.360339403152466, 47.288568913936615, 47.630007192492485, 45.171972289681435, 43.05015854537487, 42.64673039317131, 45.264584720134735, 44.82745997607708, 44.47711497545242, 46.39718994498253, 46.75465576350689, 45.09230576455593, 43.51077362895012, 45.37936896085739, 44.27834764122963, 46.37707382440567, 42.75165416300297, 43.246250823140144, 41.498276218771935, 45.75997553765774, 46.79134279489517, 44.0697730332613, 43.25903333723545, 45.3346149623394, 48.585294932127, 57.03754998743534, 54.43604618310928, 58.001326471567154, 57.53708258271217, 58.298611119389534, 55.7972851395607, 51.54993765056133, 47.70301267504692, 46.35297931730747, 47.84647397696972, 54.062108248472214, 53.64641435444355, 59.17317979037762, 60.23541659116745, 61.77927754819393, 59.14708659052849, 61.52603253722191, 58.13106290996075, 64.02630597352982, 63.910685777664185, 68.40117841959, 52.81574472784996, 13.73792627826333, 11.162905152887106, 3.7372901709750295, 0.38868019357323647, 0.1488076150417328, 1.3970027561299503, 40.26810362935066, 51.512809842824936, 55.66433787345886, 44.623049944639206, 29.09957192838192, 45.14705702662468, 56.286478489637375, 60.09135112166405, 70.73815181851387, 25.8665382117033, 0.6492595234885812, 0.2938321471447125, 0.23660451639443636, 0.10476361436303705, 0.08708006091183051, 0.12633989565074444, 0.25086568552069366, 0.14683865272672847, 0.1433666335651651, 0.17692140099825338, 0.11162316659465432, 0.14776080090086907, 0.1321694062789902, 0.12576152512338012, 0.18522935832152143], [0.031432169416802935, 0.05530520480533596, 0.02859651591279544, 0.030730229445907753, 0.031136538600549102, 0.052840758726233616, 0.006671124183412758, 0.03762303545954637, 0.08020667504752055, 0.0594725272821961, 0.025927218521246687, 0.03608812934544403, 0.05665300435794052, 0.15879607672104612, 16.599707566201687, 49.40394580364227, 57.17037186026573, 49.48361232876778, 32.06414245069027, 18.054852783679962, 19.084983207285404, 40.75278282165527, 44.28543046116829, 53.47471296787262, 5.529461391270161, 0.21198084315983579, 0.33460912469308823, 1.2841885909438133, 12.201119642704725, 2.62556245084852, 10.474503692239523, 55.56336209177971, 63.08691278100014, 63.48060205578804, 61.356060057878494, 57.88743898272514, 54.98194009065628, 47.24989838898182, 45.3334978222847, 43.57587933540344, 43.57585273683071, 42.258037850260735, 46.003405675292015, 46.638913974165916, 48.240885213017464, 47.704224810004234, 44.85422194004059, 42.590292021632195, 41.55695267021656, 41.09063409268856, 40.070772618055344, 40.77276214957237, 41.49438142776489, 39.75241430103779, 41.547730565071106, 41.52720786631107, 43.04201178252697, 42.5496532022953, 42.79073506593704, 39.94867376983166, 41.87819503247738, 38.20060797035694, 42.215730920434, 38.30788001418114, 40.64395286142826, 39.097508043050766, 42.65816777944565, 41.02297492325306, 40.7938814163208, 41.13413415849209, 40.81014834344387, 37.89347805082798, 40.27838207781315, 40.95205172896385, 41.10862232744694, 37.58088402450085, 40.787968933582306, 40.26480920612812, 42.887303084135056, 44.00454953312874, 46.40887811779976, 43.530680760741234, 47.38527752459049, 42.69990473985672, 53.78797575831413, 46.53303265571594, 60.332208797335625, 27.238226607441902, 32.52041816711426, 56.602541729807854, 50.75039215385914, 52.86352716386318, 48.93750563263893, 51.004359126091, 47.35190011560917, 44.61555674672127, 40.10708346962929, 40.13948813080788, 41.84062644839287, 43.623954355716705, 40.85779398679733, 39.487154334783554, 38.29292021691799, 38.642421662807465, 39.90325480699539, 40.956797674298286, 38.8768120855093, 41.503189355134964, 40.17975077033043, 40.167880207300186, 40.73254130780697, 40.96246317028999, 40.33770069479942, 40.46165384352207, 38.91969658434391, 40.13541854918003, 39.44137819111347, 41.45675204694271, 39.87358599901199, 42.14042656123638, 40.351182371377945, 42.67755813896656, 49.755461141467094, 53.92870880663395, 55.70293240249157, 54.65170741081238, 54.27395448088646, 53.136135935783386, 52.861729860305786, 47.09480591118336, 46.219971254467964, 43.09857934713364, 42.880957424640656, 47.94251002371311, 52.31523558497429, 52.92901284992695, 55.089751705527306, 53.688557893037796, 59.18775200843811, 53.817188590765, 56.48113064467907, 61.36715926229954, 58.28673675656319, 56.52768574655056, 63.03126096725464, 18.186040744185448, 0.18920902133686468, 2.0990356290712953, 0.3117941989330575, 0.11958028844674118, 0.11476270359707996, 16.65988113731146, 42.46478855609894, 41.08694449067116, 42.318150624632835, 14.274024311453104, 16.48751098662615, 30.638400055468082, 40.44144652783871, 54.26534794270992, 26.89630575478077, 0.3582947381073609, 0.061520866001956165, 0.0464049097354291, 0.027681755818775855, 0.015829358708288055, 0.023266596836037934, 0.03992537793237716, 0.021625244480674155, 0.03363775438629091, 0.030646090308437124, 0.012279716465855017, 0.036608675436582416, 0.02814770024997415, 0.03899692892446183, 0.015474938663828652, 0.055182898868224584, 0.022526501197717153, 0.041835053780232556, 0.06660611383267678, 0.018836144045053516, 0.012868054964201292, 0.021352512630983256, 0.03487841007881798, 0.019565359798434656, 0.044539796144817956, 0.035310135936015286, 0.07779683990520425, 0.0873137112648692, 0.14046587515622377, 20.94786934554577, 63.06734003126621, 61.32691562175751, 57.33324632048607, 35.682129710912704, 26.480729654431343, 21.60228542983532, 33.77282336354256, 47.454828992486, 60.78009456396103, 5.665528764948249, 0.2722687495406717, 0.32030689995735884, 2.8588585322722793, 11.187628526240587, 3.8106312230229378, 11.748336888849735, 58.360129818320274, 64.5920804142952, 64.65337112545967, 63.808547258377075, 61.639642640948296, 56.389551758766174, 50.365696996450424, 47.40647278726101, 46.526998579502106, 45.72085663676262, 44.26831237971783, 47.98907272517681, 50.23204296827316, 52.44434505701065, 50.57487577199936, 46.84668682515621, 44.68445084989071, 43.80583539605141, 42.53787763416767, 42.566615492105484, 41.83651506900787, 43.72683763504028, 41.72135844826698, 43.46181705594063, 43.25447358191013, 46.203635931015015, 45.433877035975456, 43.79482738673687, 41.72696694731712, 42.894720286130905, 41.41662999987602, 43.55247259140015, 40.65837308764458, 43.8051438331604, 40.683478340506554, 43.543303683400154, 43.24382655322552, 42.317550256848335, 41.337457448244095, 41.83160953223705, 40.19068658351898, 42.588962092995644, 41.80795960128307, 41.75563260912895, 39.287927225232124, 42.1060536056757, 40.80574817955494, 44.74303610622883, 44.92877393960953, 48.53916920721531, 44.47541266679764, 48.47809508442879, 46.27496190369129, 54.00569647550583, 49.314464405179024, 60.29833361506462, 28.80978237837553, 32.03671932220459, 58.25631558895111, 50.90173803269863, 55.56163318455219, 50.856866240501404, 53.13917197287083, 48.545735254883766, 45.526994839310646, 42.69344508647919, 43.84274661540985, 44.461064636707306, 44.77099500596523, 42.27996647357941, 40.76846458017826, 40.39484962821007, 41.72002851963043, 42.17780515551567, 44.095581248402596, 41.764691323041916, 42.58515849709511, 42.417424097657204, 42.246908247470856, 42.82102704048157, 43.061215952038765, 41.447100564837456, 42.02688105404377, 42.016997784376144, 41.44143506884575, 40.355719327926636, 43.813301995396614, 41.1931411921978, 44.353959783911705, 42.15316727757454, 45.79511225223541, 52.09744647145271, 57.1172659099102, 56.1673054844141, 56.121647134423256, 57.608514949679375, 54.51657526195049, 54.51368361711502, 50.52950240671635, 49.02949869632721, 45.697708278894424, 44.28802952170372, 49.177880734205246, 53.49397413432598, 55.34827843308449, 58.172290697693825, 57.71891042590141, 60.718933045864105, 53.835355415940285, 58.86632725596428, 65.4574915766716, 60.121893882751465, 58.24915677309036, 63.81412535905838, 22.840684577822685, 2.0741182286292315, 4.968860847875476, 0.482843920472078, 0.369689465733245, 0.13492158672306687, 16.89905170351267, 47.804478630423546, 43.070837035775185, 38.309464529156685, 16.540708132088184, 22.480568401515484, 37.47214525938034, 44.73609007894993, 60.70557676255703, 37.68192060291767, 1.0894397785887122, 0.0271176920432481, 0.02893811535614077, 0.05426914809504524, 0.04994839029677678, 0.1071034575579688, 0.04219210473820567, 0.0171620444234577, 0.03019365482032299, 0.016027335877879523, 0.029751097317785025, 0.019015910766029265, 0.04892736949841492, 0.02858206815290032, 0.0314998124667909, 0.13397089554928243, 0.1148566669144202, 0.17783746356144547, 0.11635046917945147, 0.10948274590191431, 0.1642263712710701, 0.31515241716988385, 0.13404787110630423, 0.1484824504586868, 0.10524562443606555, 0.1765589212300256, 0.1381168738589622, 0.2310413625673391, 0.1974476026953198, 26.490569226443768, 75.65365925431252, 68.56980577111244, 65.8357460796833, 41.9853150844574, 29.199546463787556, 26.316310577094555, 55.27483597397804, 57.6478124409914, 66.06074720621109, 6.948459148406982, 0.38110123306978494, 0.7767919613979757, 2.6396093470975757, 25.32429590821266, 8.961521778255701, 13.84701082482934, 61.263945400714874, 66.19432523846626, 67.948067933321, 66.03410303592682, 63.02557647228241, 57.13713124394417, 52.51386992633343, 48.64894911646843, 48.619747683405876, 48.89027796685696, 46.11913986504078, 50.07392965257168, 52.43271008133888, 54.430585876107216, 51.730405166745186, 49.45341154932976, 47.38597668707371, 46.37302324175835, 43.64599697291851, 44.18681435286999, 44.5539316534996, 44.33010846376419, 42.88976155221462, 45.2020438760519, 46.38107120990753, 48.70962806046009, 47.272267788648605, 46.878734305500984, 43.64394508302212, 43.270056545734406, 43.13153877854347, 45.69352090358734, 41.827479153871536, 45.2606937289238, 43.680799305438995, 45.73802791535854, 45.95596522092819, 45.73042832314968, 43.66044759750366, 45.36544270813465, 40.96820466220379, 44.26338404417038, 46.21093153953552, 43.84851090610027, 40.973015204072, 44.7731114923954, 44.29983548820019, 47.09472231566906, 49.83460709452629, 51.601793467998505, 47.61086381971836, 50.690704956650734, 47.3217449337244, 56.83930702507496, 50.663753002882004, 63.79096940159798, 32.34981492161751, 34.91235941648483, 60.048523619771004, 54.32850815355778, 56.21512211859226, 53.05351696908474, 54.69036653637886, 51.029099598526955, 47.71789267659187, 45.32001994550228, 45.224565267562866, 48.19484308362007, 48.05322468280792, 45.52362821996212, 43.484710827469826, 42.14531309902668, 42.752604112029076, 43.94708141684532, 45.61344400048256, 44.236986860632896, 46.119497045874596, 44.77910757064819, 44.26832377910614, 44.3587551265955, 45.039803981781006, 44.09102909266949, 44.36272591352463, 44.22151409089565, 44.34295177459717, 43.855852112174034, 44.973938316106796, 43.52615900337696, 46.130565851926804, 44.65195119380951, 48.20750020444393, 53.83504383265972, 58.86492893099785, 58.38963523507118, 58.98697458207607, 61.200583800673485, 57.35167533159256, 56.493476182222366, 51.398492977023125, 51.16206206381321, 49.832448810338974, 47.662867829203606, 52.438337579369545, 56.00458301603794, 57.56989382207394, 61.035383865237236, 59.257926642894745, 65.80411657691002, 56.18430197238922, 60.72202987968922, 66.63933455944061, 63.179836794734, 61.03678598999977, 68.69147524237633, 26.56372480094433, 6.3319731038063765, 10.116687342524529, 1.0010567586869001, 0.4202920926036313, 0.15689879102865234, 21.073323413729668, 57.257618978619576, 57.473147213459015, 55.57440809905529, 23.68166495114565, 25.39796255528927, 45.30364662408829, 52.64124669134617, 67.26875558495522, 48.34576718509197, 2.5076193921267986, 0.15964276331942528, 0.2086994075216353, 0.11352089015417732, 0.09090151288546622, 0.15478877612622455, 0.14947943680454046, 0.07357397509622388, 0.1046318089356646, 0.0765097257681191, 0.07166998038883321, 0.11614647504757158, 0.15878449921729043, 0.1391334825893864, 0.18909805541625246], [0.053632021736120805, 0.014022193863638677, 0.0053334971562435385, 0.010784236947074533, 0.06263809511438012, 0.040193593813455664, 0.13195971987443045, 0.0468178035953315, 0.03288464147772174, 0.0336621005408233, 0.06830478596384637, 0.03118657048617024, 0.0551569570961874, 0.08198404451832175, 26.261950694024563, 58.6397036164999, 55.85142843425274, 50.336525961756706, 31.73115111887455, 15.920975636690855, 45.86165048182011, 48.40348228812218, 44.32361841201782, 44.80203554034233, 0.32438384369015694, 0.008948030008468777, 0.11169905119459145, 3.2038320461288095, 5.443400759249926, 1.8589854100719094, 15.913015063852072, 55.84819860756397, 62.5262338668108, 63.37967947125435, 58.66480886936188, 58.791300281882286, 49.57279734313488, 46.40862733125687, 44.86150994896889, 43.886098489165306, 41.067983508110046, 41.52591973543167, 41.724652871489525, 41.783728301525116, 42.199118211865425, 42.39600844681263, 42.148113548755646, 42.74668402969837, 41.051800176501274, 41.68374806642532, 40.559217408299446, 41.007099375128746, 41.96532815694809, 40.647437274456024, 42.75959573686123, 43.670938834548, 45.75835682451725, 46.053312197327614, 43.21988023817539, 42.98848785459995, 42.284328639507294, 39.662834107875824, 41.17021702229977, 40.25641165673733, 40.638990327715874, 41.03965222835541, 38.43342527747154, 39.53637309372425, 42.21989929676056, 40.1909601688385, 40.42430944740772, 40.62900446355343, 42.30918310582638, 39.215605705976486, 41.93833440542221, 40.00829637050629, 45.35166844725609, 43.7795066088438, 44.21883523464203, 45.44022649526596, 47.65891224145889, 45.47858543694019, 47.64072261750698, 44.751232266426086, 50.96171401441097, 49.43087495863438, 58.6589951813221, 26.505487225949764, 35.688965544104576, 60.8773997426033, 48.89241725206375, 54.71675992012024, 48.07457193732262, 50.93499004840851, 46.48295134305954, 44.780893474817276, 38.64623665809631, 40.18656000494957, 40.51479019224644, 40.303513929247856, 39.57446224987507, 39.58236962556839, 38.37645873427391, 38.34930919110775, 40.382302701473236, 41.22391954064369, 39.16146621108055, 40.17921879887581, 41.389362663030624, 38.67737598717213, 39.382633343338966, 40.20426705479622, 41.20838217437267, 40.705114379525185, 41.555326357483864, 38.76069791615009, 40.07490299642086, 39.99752774834633, 41.6923888027668, 41.46655932068825, 40.52042528986931, 46.96153186261654, 55.10183125734329, 55.58461055159569, 52.8590852022171, 51.13087333738804, 54.775478169322014, 57.24714294075966, 50.289309695363045, 47.47491851449013, 44.985394701361656, 40.6241787225008, 44.4926143437624, 46.38305850327015, 52.855030819773674, 55.19166603684425, 54.83122877776623, 58.55996109545231, 57.48461499810219, 53.25432859361172, 60.204851031303406, 60.127578377723694, 59.315535351634026, 55.515853241086006, 64.82638344168663, 34.67552952468395, 0.5158989108167589, 3.3589078998193145, 1.130793197080493, 0.13044357154285535, 0.13016688404604793, 5.8533507864922285, 42.09451362490654, 34.0467544645071, 38.999948278069496, 34.065080881118774, 16.501718424260616, 22.279076613485813, 39.080880135297775, 56.21475733816624, 41.21613375842571, 4.3069306667894125, 0.08337210558238439, 0.03718844862305559, 0.12108661816455424, 0.04550847697828431, 0.02677121854503639, 0.07940917057567276, 0.032575763325439766, 0.0481439918075921, 0.07311630004551262, 0.034377330521238036, 0.12333623104495928, 0.025149985813186504, 0.028362219891278073, 0.06581531837582588, 0.0620022934890585, 0.07148992051952519, 0.04486845253268257, 0.011636351428023772, 0.04427987747476436, 0.040090932525345124, 0.025968238878704142, 0.03260292221966665, 0.0669636508973781, 0.05633512024360243, 0.02576721519290004, 0.032614470037515275, 0.10412494433694519, 0.37753037468064576, 37.19404958188534, 68.62500920891762, 62.37562134861946, 58.009431436657906, 42.25495241582394, 19.25971683114767, 36.20808228850365, 46.36473588645458, 49.99933585524559, 48.73712718486786, 0.39715275925118476, 0.012646866198338103, 0.2677708596456796, 3.563000885769725, 6.406298065558076, 3.9679145207628608, 17.45404042303562, 57.48501777648926, 63.19289289414883, 66.28878816962242, 61.518679931759834, 59.83229622244835, 52.143059223890305, 46.85229152441025, 46.28828018903732, 44.55441802740097, 43.23959358036518, 43.58931541442871, 44.09396253526211, 44.81541082262993, 44.46616776287556, 45.15334948897362, 42.67213582992554, 44.902498349547386, 42.64669619500637, 43.177702501416206, 42.20425933599472, 44.51749540865421, 42.04657919704914, 42.857820466160774, 43.71451869606972, 45.41745811700821, 47.68178701400757, 47.378540486097336, 46.12833917140961, 43.214488327503204, 42.75869518518448, 42.40939512848854, 42.047517746686935, 41.27096861600876, 42.32174903154373, 43.59121911227703, 39.83638979494572, 39.928949028253555, 43.15379798412323, 42.37257890403271, 42.78156615793705, 41.134954914450645, 43.44471037387848, 41.706911623477936, 44.61122117936611, 42.24318064749241, 46.19433782994747, 45.48613183200359, 46.654964312911034, 46.29576198756695, 49.62936490774155, 47.69097492098808, 49.633392691612244, 46.82293429970741, 52.34886758029461, 50.9968127310276, 59.72939774394035, 26.75643526017666, 39.42188523709774, 63.207161128520966, 51.055648773908615, 56.82576835155487, 50.3478417545557, 53.663388043642044, 50.60087397694588, 47.916675209999084, 41.08073562383652, 43.355593755841255, 43.71284678578377, 42.431369349360466, 40.6419313699007, 40.92917315661907, 37.88373537361622, 40.84751173853874, 40.875710025429726, 44.026884734630585, 41.76452413201332, 42.58704699575901, 43.11802290380001, 41.71846680343151, 41.70145131647587, 41.66184604167938, 41.59796766936779, 42.57169581949711, 42.73021951317787, 42.13081307709217, 41.57181367278099, 42.485607638955116, 43.222859278321266, 43.60052101314068, 42.443999871611595, 49.96422953903675, 56.47454559803009, 57.659572809934616, 53.81026156246662, 53.70803564786911, 57.06992045044899, 57.95881435275078, 52.48801231384277, 49.20858308672905, 47.202636525034904, 43.357934430241585, 46.580936685204506, 49.76104684174061, 52.18354605138302, 56.67485944926739, 56.23040869832039, 59.85236294567585, 59.15870636701584, 55.35108648240566, 61.91332295536995, 61.01921573281288, 61.977702900767326, 57.69509330391884, 67.5410869717598, 38.86444374918938, 0.12557212903629988, 5.144800907000899, 2.5861174799501896, 0.2833738614572212, 0.1099877996603027, 5.74788554571569, 47.18482308089733, 37.252076268196106, 42.58431114256382, 36.54541298747063, 21.396862752735615, 25.56358616799116, 43.53720501065254, 60.79919993877411, 55.93951150774956, 9.186410810798407, 0.2619497204432264, 0.07280874662683345, 0.17074818693799898, 0.04546819691313431, 0.05511836912774015, 0.03151108568999916, 0.009912264449667418, 0.041074118635151535, 0.04840717592742294, 0.014762620685360162, 0.06424613617127761, 0.007379976332231308, 0.03938376597943716, 0.023387067813018803, 0.16505535022588447, 0.17952098103705794, 0.11392801752663217, 0.15162295225309208, 0.1816077667172067, 0.19762019655900076, 0.2090673494967632, 0.198329912382178, 0.11785177455749363, 0.1452322889235802, 0.17022507672663778, 0.10663286171620712, 0.1716658376972191, 0.4801834694808349, 49.892732575535774, 76.6589181125164, 70.3813585639, 65.69606557488441, 43.623388186097145, 23.321392983198166, 59.34653788805008, 63.140539303421974, 56.46053954958916, 54.15349334478378, 0.4936394083779305, 0.12030708108795807, 0.5454867950174958, 9.313440844416618, 13.151387851685286, 6.003375286236405, 19.585482850670815, 57.96673692762852, 64.7796231508255, 67.51407042145729, 64.21864405274391, 62.11623206734657, 53.59923228621483, 48.27102139592171, 49.37394641339779, 48.86934868991375, 45.81286869943142, 46.430681347846985, 47.08911381661892, 47.55090683698654, 46.83939501643181, 47.41328962147236, 45.48096410930157, 46.90751776099205, 46.40311762690544, 44.890190809965134, 42.9072368144989, 45.74775919318199, 44.34446029365063, 44.34147745370865, 47.159315049648285, 48.124505057930946, 50.107808634638786, 50.75733818113804, 47.32558652758598, 46.078945621848106, 46.32381588220596, 43.265382796525955, 43.44624549150467, 43.26566778123379, 44.369987323880196, 44.723147973418236, 41.23959369957447, 40.85228428244591, 46.1271346360445, 45.21202974021435, 43.70341569185257, 44.329082518815994, 46.30906127393246, 43.54521118104458, 46.72821678221226, 44.06115509569645, 48.35708297789097, 48.57738375663757, 48.40784825384617, 49.80531066656113, 52.848069593310356, 50.389932096004486, 53.12975227832794, 49.35926780104637, 55.0525289028883, 54.981875494122505, 62.65172593295574, 30.931563824415207, 41.39487996697426, 65.94663172960281, 54.29035820066929, 58.695917800068855, 53.898169845342636, 55.97709909081459, 52.0466697961092, 49.48058769106865, 43.11317436397076, 45.96299484372139, 45.155294984579086, 44.79947827756405, 43.39755490422249, 43.64082545042038, 41.828113719820976, 42.65122555196285, 43.73332008719444, 44.90245275199413, 43.648162856698036, 44.80363145470619, 45.6005284935236, 43.031486347317696, 43.23870062828064, 43.867506086826324, 44.47787493467331, 44.63553987443447, 45.99259905517101, 42.538781985640526, 44.23097178339958, 44.22825872898102, 44.31740194559097, 45.737891122698784, 44.658327251672745, 51.3696601241827, 58.793511763215065, 60.29989533126354, 56.736435145139694, 54.30716849863529, 59.954892843961716, 61.44604682922363, 56.31525434553623, 51.55598692595959, 51.268638744950294, 45.874527990818024, 50.8464851975441, 51.52228653430939, 56.37963809072971, 59.28118519484997, 61.465999558568, 63.943675607442856, 59.50880818068981, 58.3646135777235, 64.77384746074677, 66.03885278105736, 64.82654303312302, 59.833519756793976, 70.46069830656052, 40.97662881016731, 0.7354640134144574, 9.21391848474741, 3.4433524310588837, 0.2650813164655119, 0.16470141999889165, 7.329220091924071, 53.74692276120186, 48.27185735106468, 52.39810533821583, 46.27834752202034, 27.617537453770638, 31.602731309831142, 54.15088288486004, 67.26724326610565, 65.78905418515205, 11.555002313107252, 0.4581412678817287, 0.3229240095242858, 0.41820128448307514, 0.13509585784049705, 0.09053095112903975, 0.20370408572489396, 0.1048211456509307, 0.09895513619994745, 0.10018834815127775, 0.1304056032677181, 0.2467069571139291, 0.16775471944129094, 0.1013341499492526, 0.19198855734430254], [0.0720632889715489, 0.05180927735636942, 0.014518360403599218, 0.027014223669539206, 0.05078522488474846, 0.022016992697899695, 0.06400301601388492, 0.09402529409271665, 0.10107384165166877, 0.08854395462549292, 0.042910076954285614, 0.08746651947149076, 0.09671192805399187, 1.7714473698288202, 41.8388557434082, 58.70966166257858, 49.661613777279854, 32.5077648460865, 14.609228074550629, 21.74413751810789, 39.50807601213455, 31.602339930832386, 54.55544717609882, 25.753642469644547, 0.14785459352424368, 0.09999547139159404, 0.7325670251157135, 2.314395485445857, 4.653671085834503, 4.0352043975144625, 19.358059354126453, 57.29165755212307, 62.83966384828091, 62.40926094353199, 57.10460878908634, 56.95905759930611, 53.446229696273804, 54.10984888672829, 53.46034213900566, 51.13121151924133, 45.48505648970604, 42.624284997582436, 41.378274857997894, 42.6360909640789, 40.66158391535282, 42.98318333923817, 41.70448735356331, 42.99834832549095, 40.55265516042709, 41.142774894833565, 41.32792375981808, 41.138222739100456, 41.94371111690998, 42.076373398303986, 44.345402643084526, 45.62174655497074, 47.983433827757835, 48.54188226163387, 46.91385582089424, 46.66295528411865, 43.43603163957596, 41.2216130644083, 41.473125368356705, 39.69540975987911, 41.648641750216484, 39.79771926999092, 41.15201599895954, 39.967133179306984, 40.792889669537544, 40.8076860755682, 40.768795162439346, 39.29524943232536, 40.80091863870621, 39.79036286473274, 45.18790863454342, 47.58287452161312, 49.0442419052124, 44.357337802648544, 48.00639219582081, 44.52955596148968, 49.21862594783306, 46.28968231379986, 48.08346726000309, 44.69187185168266, 50.53461693227291, 46.90882109105587, 59.14225324988365, 28.919617384672165, 39.03804883360863, 58.5698177665472, 47.39881619811058, 48.89373958110809, 47.51145355403423, 46.78345061838627, 42.68424578011036, 40.77799826860428, 38.3141078799963, 40.38744382560253, 40.567500963807106, 40.79672746360302, 38.73613603413105, 38.734657913446426, 37.05273896455765, 40.43039292097092, 38.7444119900465, 39.53816659748554, 40.23501880466938, 41.69416330754757, 38.57808731496334, 40.42607635259628, 40.152263045310974, 40.38782760500908, 38.72309133410454, 40.29194734990597, 41.360826194286346, 40.896092131733894, 38.08444440364838, 41.309038773179054, 41.30118079483509, 40.511427372694016, 43.4309247136116, 51.50117106735706, 52.651517540216446, 53.712686598300934, 52.409573122859, 55.043591782450676, 52.60702572762966, 52.77884490787983, 52.46440038084984, 46.64131164550781, 42.62036740779877, 42.369660660624504, 42.66728349030018, 46.70755349099636, 52.203069403767586, 50.42869761586189, 47.921238765120506, 44.36202295124531, 47.805189192295074, 60.99712751805782, 60.556457564234734, 58.329397067427635, 52.89068430662155, 57.584865018725395, 59.13317933678627, 57.25452974438667, 1.2183047574944794, 3.1127278972417116, 0.5180139129515737, 0.4266792529961094, 0.08040501401410438, 0.7036614418029785, 35.76686516404152, 41.87099441885948, 32.42582984268665, 53.303178772330284, 22.993915155529976, 26.02855771780014, 40.28607666492462, 44.914365112781525, 52.66740068793297, 17.917727641761303, 0.7015490520279855, 0.0557928737543989, 0.08098114325548522, 0.06367530586430803, 0.07714392064372078, 0.040133324000635184, 0.020956127846147865, 0.021070598559163045, 0.008104401058517396, 0.016001288349798415, 0.008238534046540735, 0.05154059763299301, 0.014552439824910834, 0.048221605611615814, 0.05260051439108793, 0.024045662648859434, 0.05223196385486517, 0.022046923513698857, 0.06169719286845066, 0.028094339832023252, 0.050357725558569655, 0.027753100330301095, 0.07223344116937369, 0.07043315417831764, 0.019571690318116453, 0.006869052649562946, 0.13382383156567812, 3.1221404671669006, 57.69584946334362, 65.43093100190163, 57.07107558846474, 40.980128422379494, 21.136502623558044, 16.24571666121483, 41.15811847150326, 34.84542600810528, 61.845884174108505, 30.225789695978165, 0.09091319428989664, 0.0912318576592952, 1.327618716750294, 4.688747953623533, 6.689759055152535, 4.21814083121717, 22.025312930345535, 59.51589860022068, 63.43070313334465, 65.70910647511482, 58.34074705839157, 59.28200975060463, 55.144829750061035, 55.71995168924332, 54.605733677744865, 52.87661746144295, 46.70101024210453, 44.48213830590248, 44.81484465301037, 44.04119856655598, 42.87715382874012, 44.49099563062191, 42.7130938321352, 44.60596986114979, 41.38957545161247, 44.058347046375275, 42.75332987308502, 43.49209763109684, 44.62740831077099, 43.11983160674572, 46.172371208667755, 48.40717948973179, 49.60332490503788, 51.32109493017197, 50.63598029315472, 47.63650484383106, 45.4269690066576, 42.0836766064167, 42.50687509775162, 41.762521639466286, 42.76474826037884, 43.58666695654392, 43.39437447488308, 41.3520372658968, 41.85228802263737, 42.65210710465908, 42.007308304309845, 40.76965011656284, 42.18604311347008, 41.57848611474037, 47.02737092971802, 50.04654832184315, 49.22683350741863, 46.49455972015858, 49.53151635825634, 46.87069393694401, 51.08251333236694, 48.020614832639694, 51.05802744626999, 46.50779440999031, 53.476286083459854, 49.119276478886604, 60.95470279455185, 31.39598060399294, 42.13117025792599, 61.642823070287704, 49.542873948812485, 51.52124918997288, 49.147360771894455, 49.13341552019119, 45.543801337480545, 44.0666837990284, 40.639111921191216, 42.26068250834942, 42.61973664164543, 43.96068088710308, 40.19298925995827, 40.92112518846989, 37.63043716549873, 40.55642455816269, 41.09379172325134, 42.82033167779446, 42.17133030295372, 43.417652025818825, 42.01934605836868, 41.258866265416145, 41.494400426745415, 42.99133390188217, 40.14809086918831, 42.80144289135933, 42.961828485131264, 40.801602602005005, 40.59141308069229, 43.06499294936657, 43.58165502548218, 41.84199437499046, 44.00622524321079, 54.346530586481094, 54.86103817820549, 54.49055805802345, 53.88537973165512, 56.20784170925617, 55.39276644587517, 55.62780283391476, 53.856733068823814, 48.66937302052975, 43.61255496740341, 43.33340674638748, 45.11921972036362, 49.50729265809059, 53.06097976863384, 53.57951134443283, 49.83196623623371, 45.83021096885204, 50.0883536785841, 60.767897218465805, 61.52004025876522, 59.02726002037525, 54.307924658060074, 58.53547140955925, 61.141861751675606, 60.16819819808006, 1.5368238533847034, 5.538135850802064, 3.927437667734921, 0.4837445018347353, 0.020513861636572983, 0.5385818530339748, 39.906370639801025, 45.15817143023014, 36.06438919901848, 52.422002255916595, 25.65667737275362, 30.70272110402584, 46.30751855671406, 47.40297317504883, 62.43368223309517, 27.066251635551453, 0.9785175556316972, 0.07802769236150198, 0.031235656133503653, 0.050721530060400255, 0.056507728950236924, 0.02306530783243943, 0.029173177645134274, 0.036916455210302956, 0.02765505891147768, 0.017884593835333362, 0.0481062350445427, 0.02319629133126, 0.021008677467762027, 0.033618068919167854, 0.13506678049452603, 0.07872431669966318, 0.1748483450501226, 0.17114897636929527, 0.12480179459089413, 0.15987759368726984, 0.24896005808841437, 0.18713985424255952, 0.21348115405999124, 0.15821381733985618, 0.1133938344719354, 0.15351605223258957, 0.23532885359600186, 3.935100669041276, 67.07435041666031, 72.43354484438896, 63.96769031882286, 46.04523383080959, 24.4337110966444, 30.85776038467884, 53.5799141228199, 43.586024791002274, 68.91660556197166, 32.884879410266876, 0.21914117300184444, 0.2515281562227756, 3.046451616100967, 12.487252838909626, 14.512375071644783, 8.188496958464384, 23.194367699325085, 60.67363187670708, 66.76665052771568, 67.22284644842148, 62.11930990219116, 61.49307690560818, 58.42810057103634, 58.906540498137474, 59.964582324028015, 56.05410575866699, 50.68341314792633, 47.591735646128654, 45.88532321155071, 46.94267347455025, 45.74731461703777, 47.22720220685005, 45.316087156534195, 46.77918344736099, 44.49137561023235, 44.41346079111099, 45.64108371734619, 45.17444595694542, 45.995293110609055, 47.28647522628307, 49.447886645793915, 50.0288412719965, 52.632043585181236, 54.00424875319004, 51.983604580163956, 50.32710626721382, 48.28695014119148, 45.42383037507534, 44.8014921694994, 43.26151840388775, 46.05465732514858, 45.40687568485737, 45.76792851090431, 42.088764533400536, 44.76974867284298, 45.11176452040672, 44.912693202495575, 42.610966712236404, 45.23600645363331, 44.40025269985199, 49.833402559161186, 51.75870984792709, 52.04301059246063, 48.72449666261673, 52.807457372546196, 49.03313510119915, 53.970544561743736, 50.11858105659485, 52.737560123205185, 49.24794137477875, 54.92318384349346, 50.0570547580719, 61.950853541493416, 33.44390921294689, 43.66195231676102, 64.67739343643188, 52.36560568213463, 53.133647069334984, 52.8805198520422, 52.67518267035484, 49.70592699944973, 46.878563314676285, 42.578725442290306, 45.52183471620083, 48.08284029364586, 45.13182744383812, 44.033564776182175, 42.59648568928242, 40.06098434329033, 44.01478238403797, 43.77606779336929, 42.86432571709156, 44.66708578169346, 46.241470500826836, 42.33403377234936, 43.32283951342106, 44.22268822789192, 45.098784416913986, 42.90033258497715, 46.09499976038933, 46.701941192150116, 43.94283324480057, 41.73607885837555, 45.56940816342831, 46.49721957743168, 44.4485405087471, 46.86731591820717, 57.19549611210823, 56.882453709840775, 56.615818217396736, 56.07154682278633, 58.40347409248352, 57.79846675693989, 57.5584564357996, 58.38747315108776, 50.91291703283787, 46.80985540151596, 47.55097523331642, 47.51396141946316, 52.73704715073109, 57.018490210175514, 56.336704194545746, 49.348525777459145, 54.08872961997986, 54.590948671102524, 61.06443330645561, 65.76179444789886, 62.763249948620796, 57.912540435791016, 62.699493169784546, 62.34796263277531, 64.21533823013306, 1.2880249600857496, 10.474141761660576, 4.1066875867545605, 1.2441992992535233, 0.1283026090823114, 1.173164842184633, 43.74474607408047, 53.84058013558388, 43.60333286225796, 62.276135087013245, 34.569028839468956, 37.34771713614464, 57.361000031232834, 57.15249761939049, 73.1663279235363, 33.237713277339935, 1.6608051443472505, 0.2767234167549759, 0.1639885426266119, 0.11812274751719087, 0.15994628687622026, 0.08682752290042117, 0.06564333307323977, 0.1444303389871493, 0.15432818443514407, 0.16335338295903057, 0.10126291861524805, 0.1808609880390577, 0.1711810371489264, 0.08286043186672032], [0.06518672671518289, 0.024492138691130094, 0.030401122203329578, 0.059960656362818554, 0.0499754972406663, 0.02363917537877569, 0.017459040791436564, 0.061269949583220296, 0.037838770367670804, 0.060019675656803884, 0.06917459788382985, 0.03464244422502816, 0.25113235402386636, 6.009012283757329, 54.35835175216198, 52.46364042162895, 56.90066613256931, 28.690147697925568, 29.027227610349655, 30.205126404762268, 35.554882138967514, 40.21424151957035, 58.55248689651489, 13.721061833202839, 0.185426339157857, 0.06023879846907221, 2.6024155179038644, 2.0539386989548802, 2.0022424729540944, 6.241583079099655, 22.974099218845367, 60.84198944270611, 58.34287114441395, 62.7869226783514, 56.22363366186619, 59.96865190565586, 56.27053454518318, 58.64755019545555, 55.806594640016556, 56.29809446632862, 51.889818012714386, 49.198297038674355, 42.42957204580307, 41.46209456026554, 39.28932175040245, 41.092404797673225, 41.203830018639565, 41.82085610926151, 39.31261450052261, 41.244776621460915, 40.02291038632393, 41.36842958629131, 40.07211394608021, 42.14628204703331, 39.96049113571644, 43.867198303341866, 47.42205195128918, 52.01728977262974, 50.206740126013756, 50.72453074157238, 48.82553704082966, 44.02637556195259, 40.630269795656204, 39.19910319149494, 39.40662145614624, 39.149413257837296, 41.12783029675484, 39.35638815164566, 40.85595868527889, 40.785430669784546, 39.82090562582016, 38.9273227751255, 40.78878588974476, 43.91452096402645, 50.57900235056877, 50.99828325212002, 51.46727688610554, 48.13778914511204, 48.04153650999069, 46.49744376540184, 47.226073667407036, 45.951610654592514, 48.483186811208725, 47.5345791131258, 52.558449134230614, 47.68099285662174, 58.45963507890701, 29.65589627623558, 39.81525532901287, 57.43221201002598, 46.96092389523983, 47.03909710049629, 39.72562573850155, 44.55042824149132, 38.07885490357876, 41.31310075521469, 38.820065930485725, 39.948859959840775, 39.24088574945927, 40.66492013633251, 37.26112738251686, 38.6259039491415, 37.52579838037491, 39.70405429601669, 39.38072204589844, 39.58857849240303, 39.82109181582928, 40.4789999127388, 39.57831524312496, 39.41561937332153, 39.04655657708645, 42.590728998184204, 40.365279614925385, 40.544337406754494, 39.18597489595413, 38.82565163075924, 39.24070715904236, 44.43624056875706, 40.26560716331005, 40.888564735651016, 48.07499371469021, 53.73120300471783, 55.62508977949619, 51.62878341972828, 55.67975364625454, 55.02736285328865, 51.10919550061226, 47.13356763124466, 43.70023526251316, 43.45780827105045, 41.52229852974415, 41.78555600345135, 41.49815082550049, 45.92761114239693, 54.07696545124054, 57.36460983753204, 52.42414154112339, 49.231355264782906, 51.92700281739235, 59.97123196721077, 57.651760429143906, 54.49235916137695, 49.66092221438885, 61.892207488417625, 58.8385621458292, 65.025135576725, 10.664875376969576, 3.234707764349878, 3.3523504016920924, 1.1549356766045094, 0.17919888894539326, 0.02476975572790252, 26.124928146600723, 41.77514836192131, 44.49112482368946, 98.79180327057838, 28.97640533745289, 21.72615498304367, 32.97147296369076, 41.96464419364929, 51.894997134804726, 36.10787786543369, 0.8936879981774837, 0.08161617675796151, 0.031018661429698113, 0.027408471069065854, 0.05455797341710422, 0.06084526299673598, 0.09968471931642853, 0.03771927717025392, 0.03248524357331917, 0.016939387132879347, 0.0781880333670415, 0.0791227980516851, 0.14475747768301517, 0.07012500704149716, 0.09136877648415975, 0.015887806548562367, 0.046295127540361136, 0.010099771770910593, 0.0894569224328734, 0.05035839720221702, 0.09273735617171042, 0.06131649708549958, 0.028771837169188075, 0.05731167155317962, 0.11311356982332654, 0.03952645500248764, 0.21647269197274, 8.826767709106207, 64.52740028500557, 59.62203450500965, 61.819566786289215, 33.32320109009743, 24.38667342066765, 28.669794090092182, 37.98203989863396, 43.2797422260046, 64.4931261241436, 14.818808678537607, 0.32586223154794425, 0.19711903907591477, 13.143496625125408, 12.617943976074457, 6.252924520522356, 7.3252122569829226, 25.588355138897896, 61.853970140218735, 60.299716740846634, 65.43212413787842, 60.840382128953934, 62.82963238656521, 57.55043126642704, 60.48374466598034, 59.21093836426735, 57.937664687633514, 52.681573927402496, 48.8738514482975, 43.4955820441246, 44.30528439581394, 41.92509591579437, 43.51385146379471, 43.423731699585915, 44.19059135019779, 42.59237051010132, 41.65095962584019, 41.7740274220705, 43.2624189555645, 41.09587021172047, 43.027549758553505, 41.406625136733055, 46.09237030148506, 47.964799627661705, 52.9911433160305, 53.33701975643635, 51.66179224848747, 50.70083521306515, 45.230850130319595, 41.23195230960846, 40.67846640944481, 41.314510479569435, 42.31273211538792, 42.112072482705116, 41.16172447800636, 42.6965457201004, 42.435621321201324, 41.43934518098831, 39.312641099095345, 42.348438799381256, 47.096417024731636, 52.25164979696274, 51.668259501457214, 52.2375563532114, 48.84221434593201, 49.49204407632351, 47.85848133265972, 50.13300508260727, 47.489460334181786, 50.342054665088654, 49.23732854425907, 54.9326491355896, 50.969283208251, 59.41821724176407, 31.723051853477955, 39.91069860756397, 58.979017809033394, 48.049307093024254, 49.72950853407383, 43.64046826958656, 46.78728461265564, 39.93019916117191, 43.5998522490263, 40.50638124346733, 44.57968287169933, 42.564138025045395, 43.488499224185944, 38.817124888300896, 41.9864322245121, 38.31863343715668, 40.35912774503231, 39.90225926041603, 42.50682570040226, 42.11044616997242, 42.91351407766342, 42.1549341827631, 41.16830192506313, 40.145404413342476, 43.05743135511875, 43.46169166266918, 42.392239049077034, 42.04561784863472, 40.54638169705868, 41.665132865309715, 44.762567058205605, 42.02069118618965, 43.10478061437607, 49.50501658022404, 56.04014910757542, 57.31168247759342, 52.23615422844887, 55.320277735590935, 56.83200381696224, 52.953878715634346, 47.82991446554661, 45.80631025135517, 44.47979383170605, 43.83060626685619, 42.877894788980484, 42.75581493973732, 48.05661790072918, 56.01868025958538, 60.96313074231148, 56.417396664619446, 54.20288689434528, 55.70610523223877, 61.5343426913023, 58.83433297276497, 57.112603560090065, 51.44238822162151, 63.148575872182846, 59.97891515493393, 67.67384424805641, 12.820234671235085, 3.583013699389994, 3.6678296606987715, 2.485063564963639, 0.15410135441925377, 0.051424280827632174, 26.57074112445116, 49.42859508097172, 42.871112152934074, 82.2583432495594, 33.72100554406643, 28.342274464666843, 40.73649309575558, 48.071475103497505, 57.32541874051094, 48.141843527555466, 2.251814268529415, 0.09139357163803652, 0.022513712137879338, 0.048186409258050844, 0.04573313250148203, 0.07212152529973537, 0.049605892854742706, 0.04594210644427221, 0.0346699667716166, 0.017501860857009888, 0.09517229816992767, 0.04057641956023872, 0.0784125627251342, 0.009976767287298571, 0.13851490250090137, 0.10887399184866808, 0.19817977590719238, 0.13716584129724652, 0.11926839346415363, 0.12094074161723256, 0.11321603073156439, 0.13984052668092772, 0.21674350165994838, 0.13130147941410542, 0.19014111428987235, 0.10446508546010591, 0.2993583568604663, 12.044857777655125, 75.79722315073013, 65.47202959656715, 76.53876096010208, 39.36416253447533, 42.330249175429344, 38.450870141386986, 50.47350861132145, 53.99344973266125, 70.45059084892273, 17.588813491165638, 0.40731647168286145, 0.23382717714412138, 6.262576002627611, 8.629726432263851, 10.015713460743427, 12.269541621208191, 28.090380281209946, 61.548975706100464, 60.37743017077446, 67.42287531495094, 62.42535687983036, 64.73457276821136, 60.01557178795338, 62.86020174622536, 60.08926883339882, 60.56208126246929, 55.5353119969368, 52.590709403157234, 45.50737649202347, 45.90536333620548, 42.74531610310078, 45.456729009747505, 45.2997100353241, 45.89381955564022, 43.99483345448971, 44.75332595407963, 43.164084032177925, 45.94687610864639, 43.04519221186638, 45.56426703929901, 44.10038039088249, 47.85003438591957, 52.56279610097408, 55.50445765256882, 54.98536750674248, 55.07134549319744, 52.2255489975214, 48.00147145986557, 43.73803183436394, 42.50540837645531, 42.810657396912575, 43.90184484422207, 44.37859386205673, 42.81808219850063, 45.007946491241455, 44.9953805655241, 41.82940185070038, 42.40396521985531, 46.12393140792847, 48.350030556321144, 54.469670578837395, 54.95688423514366, 55.59788703918457, 51.82321518659592, 53.537626191973686, 51.395156756043434, 51.903375685214996, 51.80942192673683, 52.082296684384346, 53.35384905338287, 58.38000275194645, 53.88609029352665, 61.92499212920666, 34.63593564927578, 43.83125603199005, 60.515092983841896, 50.775926783680916, 50.4107815772295, 45.28981536626816, 49.75851617753506, 42.126374915242195, 46.56363621354103, 44.448570907115936, 45.83327740430832, 44.09156486392021, 47.51616910099983, 43.10289591550827, 43.92568476498127, 39.87269304692745, 43.08842249214649, 41.564913243055344, 44.9826854467392, 45.767202749848366, 46.16367347538471, 44.823151007294655, 44.18811768293381, 41.866822242736816, 46.536729857325554, 45.94640873372555, 45.02180054783821, 45.018768310546875, 41.9011951982975, 43.75551089644432, 47.93063186109066, 45.202028676867485, 45.03359131515026, 52.21784681081772, 58.084781393408775, 61.778661981225014, 52.74498112499714, 58.13206985592842, 59.41391207277775, 54.987749978899956, 50.848343297839165, 47.60174810886383, 46.88076339662075, 45.86213305592537, 45.83683021366596, 45.60660056769848, 51.18578419089317, 59.67836268246174, 63.805682212114334, 58.25729213654995, 54.642238318920135, 58.956826999783516, 65.83533570170403, 62.954090908169746, 60.94833813607693, 52.64206364750862, 66.84247925877571, 62.81400382518768, 70.68052411079407, 14.483599215745926, 8.408527001738548, 12.062357738614082, 2.638381775468588, 0.5657895805779845, 0.17264459689613432, 31.239294111728668, 54.745843559503555, 57.791133150458336, 100.75952768325806, 39.3410711735487, 33.36054168641567, 46.280726194381714, 56.50153174996376, 67.35810399055481, 59.38541740179062, 2.9671695828437805, 0.21867201692657545, 0.11158817433170043, 0.11363345169229433, 0.08327371906489134, 0.13764745061052963, 0.2759156929096207, 0.08887737189070322, 0.1317946513881907, 0.16650831210426986, 0.17307259346125647, 0.1862682611681521, 0.18409333802992478, 0.106452645995887], [0.029088329756632447, 0.04636187630239874, 0.11972955660894513, 0.04476186899410095, 0.06522777490317822, 0.030206031988200266, 0.09918040028424002, 0.045846150460420176, 0.12452540395315737, 0.06641259882599115, 0.1094644222757779, 0.07198551189503632, 0.2858937199926004, 14.565807804465294, 53.07447284460068, 54.67074818909168, 46.93839110434055, 28.954083435237408, 31.156832836568356, 23.459669463336468, 41.781060844659805, 41.713299080729485, 54.963001906871796, 5.002096714451909, 0.14545827289111912, 0.19221684196963906, 5.319820465520024, 4.557190937921405, 5.338605232536793, 6.250378182157874, 31.100082881748676, 58.15133482217789, 56.10527001321316, 60.595990642905235, 58.94485764205456, 59.16872262954712, 58.236587047576904, 59.8354272544384, 60.26576556265354, 60.47670364379883, 56.599095314741135, 57.35048219561577, 52.74408057332039, 48.05458880960941, 42.134590074419975, 41.00554145872593, 39.78688605129719, 41.4611142128706, 40.39868362247944, 42.632412761449814, 40.502182468771935, 42.268396094441414, 42.78786242008209, 40.99538080394268, 42.056504264473915, 41.93943254649639, 45.04689820110798, 49.988073259592056, 51.08407124876976, 52.04519547522068, 51.273905262351036, 49.69185255467892, 44.30239275097847, 40.010507851839066, 39.16448324918747, 41.47446669638157, 38.99950370192528, 40.3221595287323, 40.941077917814255, 40.25614947080612, 40.395370200276375, 39.06425602734089, 40.53076073527336, 52.54956141114235, 55.55445156991482, 51.89719341695309, 49.049603417515755, 47.806614115834236, 47.95782320201397, 47.5385233014822, 46.085196286439896, 44.3697365373373, 47.34674759209156, 46.34718082845211, 51.909858137369156, 47.92589731514454, 58.316063582897186, 33.00411321222782, 36.96613781154156, 56.79647572338581, 47.12599463760853, 47.86347046494484, 40.629832819104195, 44.323097839951515, 39.54412467777729, 42.16580919921398, 37.70881175994873, 39.4160221517086, 37.81106427311897, 40.149280205368996, 36.67878583073616, 37.37403832376003, 35.9841451048851, 39.34978790581226, 37.36254774034023, 42.82195799052715, 40.94615824520588, 41.90280631184578, 39.401719719171524, 42.13973119854927, 38.457215800881386, 42.80046634376049, 38.76077391207218, 40.50855852663517, 37.52531960606575, 40.43705776333809, 39.540047496557236, 41.584345400333405, 39.000556245446205, 46.3709257543087, 50.79225830733776, 53.61297994852066, 53.20960879325867, 52.92276218533516, 53.63902375102043, 50.988118797540665, 47.156400606036186, 41.95085473358631, 41.27945356070995, 42.12917536497116, 41.8248724937439, 42.49898672103882, 42.79988497495651, 44.03120130300522, 50.95520876348019, 57.65668496489525, 57.07972012460232, 57.61781685054302, 60.70014305412769, 58.35907347500324, 53.09359721839428, 48.726438358426094, 46.3507754355669, 57.93865643441677, 54.61930654942989, 67.6904645562172, 31.327382884919643, 2.8024997189641, 4.5109982416033745, 0.6790378724690527, 0.29624234593939036, 0.45726312906481326, 12.165075726807117, 50.90829648077488, 49.492511451244354, 57.494893446564674, 22.074799574911594, 18.470786064863205, 36.35301411151886, 43.669855892658234, 48.75570438802242, 49.494570940732956, 2.7679080376401544, 0.09783032975974493, 0.07743274225504138, 0.02475732846505707, 0.08889948789146729, 0.04725249433249701, 0.0151140229718294, 0.04767149606777821, 0.07943628865177743, 0.06840486457804218, 0.07880660603404976, 0.06381413200870156, 0.08268383040558547, 0.1064376620342955, 0.0482271420332836, 0.016000360665202606, 0.06067295485991053, 0.03548719010723289, 0.10557412126217969, 0.04247485187079292, 0.08123553663608618, 0.03631100742495619, 0.10259217189741321, 0.06784269513445906, 0.07563249979284592, 0.07197708851890638, 0.39424336224328727, 21.20510794222355, 67.29204833507538, 58.89299422502518, 55.52209250628948, 31.57937776297331, 35.60024790465832, 26.096545569598675, 37.74576477706432, 48.37021127343178, 60.47842875123024, 5.1048436760902405, 0.06893840196426027, 0.16683694993844256, 8.22146873921156, 10.18035102635622, 4.605173338204622, 8.203223068267107, 32.06191956996918, 61.06644719839096, 54.70303125679493, 59.39129948616028, 60.35616651177406, 61.45749181509018, 58.68848159909248, 60.489322766661644, 60.42669452726841, 62.11439676582813, 59.60603356361389, 60.388118997216225, 54.04114857316017, 50.52454747259617, 42.7275026589632, 45.37216454744339, 42.03350409865379, 43.36272977292538, 42.37885616719723, 43.11033591628075, 42.02626168727875, 44.43427227437496, 43.14283937215805, 43.12942609190941, 43.50553371012211, 44.50601242482662, 45.089178532361984, 51.61931432783604, 54.03026595711708, 55.15711069107056, 54.38574828207493, 50.18940545618534, 44.660360142588615, 42.72259332239628, 40.301557034254074, 42.7286121994257, 41.25732734799385, 43.41866657137871, 41.39589071273804, 42.69683450460434, 42.05995447933674, 41.31597340106964, 43.12592267990112, 55.10894447565079, 56.119177266955376, 52.73331955075264, 53.554596081376076, 50.09613946080208, 50.83476662635803, 49.51696313917637, 48.730013966560364, 48.3794903755188, 49.08375218510628, 47.48153775930405, 53.11846308410168, 50.54517276585102, 58.661624640226364, 35.061569809913635, 39.4913113117218, 60.00224210321903, 51.09347574412823, 49.91967312991619, 42.508186027407646, 45.935902297496796, 40.84887586534023, 44.616670086979866, 39.49960246682167, 42.264554500579834, 41.116218119859695, 41.77476838231087, 37.37439550459385, 39.5353889465332, 39.36475150287151, 41.55868157744408, 39.714602530002594, 42.51626439392567, 42.49637246131897, 44.821471497416496, 41.28071129322052, 43.57606552541256, 40.466373190283775, 42.7346196770668, 40.86210675537586, 42.84410320222378, 38.53566259145737, 42.434644773602486, 42.32276737689972, 44.10834476351738, 41.92346200346947, 47.42106780409813, 54.24470365047455, 55.62571294605732, 54.91643540561199, 53.34413677453995, 55.48189826309681, 54.41606305539608, 49.15361523628235, 43.96326094865799, 43.263574093580246, 44.170235842466354, 42.11672343313694, 43.511396795511246, 44.26831617951393, 46.50354243814945, 52.988848239183426, 59.03006047010422, 58.48923169076443, 59.7408427298069, 61.56200520694256, 60.046851709485054, 57.425718158483505, 49.52867791056633, 47.87923961877823, 60.88069036602974, 57.51641929149628, 69.30964887142181, 34.556816294789314, 0.8735319797415286, 5.042365528643131, 1.7897734302096069, 0.9524977393448353, 0.3980505501385778, 11.895143911242485, 55.42654663324356, 51.269307509064674, 59.66121420264244, 23.74859645962715, 22.90322732180357, 41.34615138173103, 51.89635366201401, 54.73534852266312, 58.97217057645321, 5.044609783217311, 0.21580504107987508, 0.029940701206214726, 0.012755603820551187, 0.035330136815900914, 0.06906784736202098, 0.057604994290159084, 0.04567861804389395, 0.056203507774625905, 0.04689054891059641, 0.07542830528109334, 0.05932872503763065, 0.056983757312991656, 0.05509721791895572, 0.11215264443308115, 0.1143002268509008, 0.1687556688557379, 0.17566285212524235, 0.18890399864176288, 0.15877753787208349, 0.19711371045559645, 0.14519604243105277, 0.2379738530726172, 0.15026424312964082, 0.16211441194172949, 0.14586133329430595, 0.42809788312297314, 26.808809749782085, 79.36688840389252, 67.32848078012466, 63.988771587610245, 39.594232589006424, 43.33955481648445, 31.223754845559597, 57.74802826344967, 53.541243597865105, 68.35808113217354, 7.497453689575195, 0.1821641399874352, 0.8159682748373598, 9.16568387299776, 7.705578971654177, 12.312170583754778, 8.795817419886589, 36.792772114276886, 61.052585542201996, 57.059626802802086, 61.42141655087471, 63.28758001327515, 61.74021564424038, 60.976274237036705, 62.734960466623306, 64.04428660869598, 63.91325443983078, 62.620734795928, 61.19095131754875, 57.29664668440819, 52.090048268437386, 45.04959225654602, 47.342704609036446, 43.717604130506516, 45.6256565451622, 44.717615470290184, 45.547445341944695, 44.53710615634918, 46.75928011536598, 47.15134687721729, 44.72252860665321, 47.150028347969055, 46.864800453186035, 47.848529666662216, 55.17774738371372, 56.41673929989338, 56.44208773970604, 57.07064241170883, 52.817241847515106, 47.45293289422989, 44.002961218357086, 42.03736089169979, 45.431654155254364, 43.79542015492916, 44.65116463601589, 45.006650760769844, 44.79510851204395, 45.205212906003, 41.708952113986015, 43.8812917470932, 58.66287097334862, 59.61394853889942, 56.34792499244213, 55.62718726694584, 51.779969707131386, 52.94929996132851, 53.51906418800354, 51.35992884635925, 50.73354385793209, 52.099334970116615, 50.87119907140732, 54.917715936899185, 53.24444532394409, 61.81615836918354, 37.073573246598244, 41.53905563056469, 61.958612725138664, 53.69632847607136, 53.38454380631447, 45.55213809013367, 50.17626576125622, 45.077414363622665, 47.63446815311909, 41.978084072470665, 44.82414275407791, 44.14612993597984, 45.2767288684845, 40.09885311126709, 41.99339725077152, 41.54713399708271, 43.79654109477997, 41.09992079436779, 45.99964387714863, 45.39765737950802, 45.28713271021843, 42.791422829031944, 45.940051674842834, 43.68384674191475, 46.09936572611332, 43.54983173310757, 44.973938316106796, 40.53901009261608, 44.76918250322342, 44.506692588329315, 45.33253267407417, 44.13849234580994, 49.888822585344315, 57.065645679831505, 57.94660560786724, 55.89045614004135, 55.10763354599476, 58.39466996490955, 57.243460938334465, 52.229789569973946, 46.93796172738075, 45.2895075827837, 46.40431076288223, 44.711235612630844, 45.62899276614189, 46.105270609259605, 48.77307325601578, 54.32946190237999, 61.10398918390274, 61.89892552793026, 62.355858609080315, 61.51929169893265, 64.99205455183983, 59.65108394622803, 52.54098907113075, 51.62217937409878, 64.40149784088135, 59.31577853858471, 75.31101644039154, 37.34025813639164, 5.391186336055398, 14.067211858928204, 1.8157035950571299, 0.7741231983527541, 0.4067576047964394, 15.15599213540554, 64.7661642730236, 61.685433983802795, 66.18976548314095, 30.362812243402004, 28.96916102617979, 48.975188210606575, 61.300184056162834, 61.59244917333126, 70.2877239882946, 9.267583955079317, 0.346713523613289, 0.21291965997079387, 0.11865032545756549, 0.17859077313914895, 0.2098115158150904, 0.09734803024912253, 0.11511414762935601, 0.16144689463544637, 0.09218090868671425, 0.13774949591606855, 0.13590827205916867, 0.17587589303730056, 0.2116092646610923], [0.03406896816159133, 0.03286612860392779, 0.020619547176465858, 0.043487159855430946, 0.022941096431168262, 0.07275977230165154, 0.03906241603544913, 0.038058312493376434, 0.04003686706710141, 0.09043281694175676, 0.029223203964647837, 0.06675213138805702, 0.049716884750523604, 27.95501634478569, 63.28721143305302, 54.215836599469185, 39.08779576420784, 29.408962726593018, 18.347750566899776, 32.539736330509186, 46.60234473645687, 48.820046335458755, 49.495916068553925, 1.28540120087564, 0.04576724903017748, 0.43363531411159784, 18.45314171165228, 13.91483623534441, 6.07719250023365, 11.46820642054081, 39.58939544856548, 62.142944633960724, 59.261673241853714, 59.93613705039024, 59.076193794608116, 62.09505960345268, 58.93270209431648, 55.51701217889786, 54.63811933994293, 54.793933779001236, 58.559581115841866, 57.18880087137222, 58.01469415426254, 53.80610078573227, 52.65975169837475, 43.594893515110016, 41.62577457726002, 40.908357873559, 39.87874232232571, 40.80080844461918, 42.01448231935501, 41.89720921218395, 44.73628766834736, 43.12718041241169, 41.98979124426842, 43.997934088110924, 43.58868084847927, 47.308669835329056, 52.14678302407265, 51.914041712880135, 54.34072069823742, 52.39086672663689, 48.36995668709278, 43.21024775505066, 40.0750207901001, 39.019422233104706, 39.76461924612522, 39.25858899950981, 39.78347383439541, 39.61276039481163, 40.018293634057045, 39.33366537094116, 47.27839685976505, 54.703696221113205, 50.37199705839157, 50.904922261834145, 51.01609669625759, 48.522366508841515, 50.51097460091114, 46.174685284495354, 47.5775396078825, 46.48499943315983, 48.640703558921814, 45.64127370715141, 51.79358437657356, 49.60483342409134, 56.993229165673256, 34.418138936161995, 36.463398188352585, 54.4061341881752, 50.13684667646885, 47.77246914803982, 40.30139744281769, 42.25936397910118, 40.529605597257614, 41.42962910234928, 38.19649279117584, 40.56824952363968, 38.17646786570549, 37.821836695075035, 35.81408143043518, 38.01312983036041, 37.39566296339035, 38.5246279835701, 37.56088949739933, 39.82884339988232, 39.73627656698227, 41.23694144189358, 40.3767853975296, 39.79402966797352, 39.58725616335869, 41.48787997663021, 40.76486997306347, 38.74580271542072, 40.746019184589386, 41.4973908662796, 40.92309728264809, 40.528097078204155, 45.624896585941315, 50.33905662596226, 50.68934842944145, 55.73295459151268, 51.16887889802456, 52.7125346660614, 54.244384467601776, 51.739030703902245, 44.05044727027416, 38.35871748626232, 39.61735054850578, 41.48870833218098, 40.48218034207821, 40.7257928699255, 44.23403061926365, 42.2725834697485, 45.34613214433193, 51.32399797439575, 54.45926293730736, 53.90286639332771, 52.271936908364296, 49.89120125770569, 44.94460389018059, 41.764037758111954, 46.52484029531479, 52.94695928692818, 63.195233568549156, 56.20039790868759, 59.326364770531654, 1.5179564408026636, 3.3758217422291636, 3.5905988048762083, 0.0929722013825085, 0.038433731606346555, 2.0853957859799266, 45.75698509812355, 40.68212941288948, 32.16414548456669, 28.638540767133236, 15.801901426166296, 25.54765362292528, 41.210977435112, 49.82476182281971, 47.93793126940727, 5.820143418386579, 0.14731166796991602, 0.05948404912487604, 0.06466403952799737, 0.08177813564543612, 0.05029433130403049, 0.03778081605560146, 0.07045537407975644, 0.04460258554900065, 0.02593247849290492, 0.06390627706423402, 0.07817855614121072, 0.024557657343393657, 0.03205029679520521, 0.029168682085582986, 0.04932715331960935, 0.014207628737494815, 0.01409004749802989, 0.019456375412119087, 0.10292190068867058, 0.02870372285542544, 0.06948943177121691, 0.05302351630234625, 0.041388451572856866, 0.022708620526827872, 0.058796430748770945, 0.07898523355834186, 37.345999628305435, 70.12690901756287, 60.74472986161709, 43.872214034199715, 32.94417902827263, 28.84284820407629, 31.549397371709347, 44.02204379439354, 55.527856796979904, 54.64619390666485, 1.321424930356443, 0.0991391739808023, 0.4190217732684687, 11.424236129969358, 6.189866429194808, 6.26707686111331, 12.811479941010475, 40.16095697879791, 61.909853741526604, 61.4096599817276, 61.00577965378761, 59.86190803349018, 62.53900498151779, 59.932854026556015, 55.07591284811497, 56.74425512552261, 57.17323310673237, 60.28500393033028, 58.71843919157982, 59.80168126523495, 55.69628655910492, 54.683758690953255, 46.846774220466614, 43.45432385802269, 41.96812100708485, 41.50903724133968, 42.06598475575447, 43.9520363509655, 43.3928469568491, 47.91276901960373, 44.4407357275486, 43.36954280734062, 45.29051072895527, 45.68730063736439, 49.9627286195755, 53.80216799676418, 54.59319055080414, 56.31013602018356, 54.17278490960598, 50.76546214520931, 44.78389151394367, 40.848503485322, 40.54968371987343, 41.60228043794632, 41.04646906256676, 41.051568388938904, 41.75122484564781, 42.04939864575863, 41.193832755088806, 50.04454582929611, 55.7773058116436, 52.94330768287182, 52.03763768076897, 53.15249405801296, 51.723637729883194, 52.002041190862656, 47.812564596533775, 48.96671086549759, 48.27823340892792, 50.82614868879318, 48.72344791889191, 53.09824436903, 51.32055155932903, 59.495056718587875, 37.18898065388203, 38.77937011420727, 56.88499577343464, 50.86584135890007, 51.3429019600153, 42.274392172694206, 44.16891731321812, 42.68872573971748, 44.32481534779072, 41.48386359214783, 41.34622357785702, 40.641418397426605, 39.089471474289894, 38.346037566661835, 41.00762374699116, 40.14793507754803, 41.92184329032898, 40.629737824201584, 42.43891954421997, 42.52597667276859, 41.89763478934765, 40.71657456457615, 41.339703127741814, 40.08245699107647, 43.49799871444702, 41.485372111201286, 41.71326108276844, 41.464499831199646, 44.04914774000645, 41.71490639448166, 43.73539857566357, 47.494031488895416, 52.416625544428825, 53.374345153570175, 59.08970966935158, 53.082771599292755, 52.59974531829357, 56.623072028160095, 53.26872602105141, 46.270865723490715, 40.6764031201601, 41.821870654821396, 42.85858042538166, 42.01159067451954, 42.795085832476616, 45.8366934210062, 45.17136812210083, 47.47584946453571, 53.11148665845394, 55.76836869120598, 56.746314615011215, 55.400138050317764, 51.60655461251736, 46.791456788778305, 46.38837821781635, 48.686882480978966, 54.5670023560524, 63.61715532839298, 59.45003293454647, 60.555617809295654, 2.459842418320477, 3.1342981522902846, 3.3303809305652976, 0.6316492496989667, 0.008093241940514417, 2.502565188333392, 49.15241450071335, 45.6645854562521, 38.853602930903435, 27.12580393999815, 20.37701077759266, 32.337507382035255, 47.59130246937275, 56.93189285695553, 58.95359717309475, 9.837760459631681, 0.24641594616696239, 0.05912955115491059, 0.03257834971009288, 0.06568317156052217, 0.02592070432001492, 0.03993202386482153, 0.02245602499897359, 0.02610391275084112, 0.0682962586870417, 0.02078560271911556, 0.016914105872274376, 0.01966491519851843, 0.05501164087036159, 0.1778214777004905, 0.20629974722396582, 0.09838242083787918, 0.17823906935518607, 0.13523155212169513, 0.21647132642101496, 0.17488693672930822, 0.10494689515326172, 0.09375785375596024, 0.32490195182617754, 0.09709415637189522, 0.12826125661376864, 0.30550900963135064, 46.04752890765667, 77.93951779603958, 67.37742975354195, 49.67462047934532, 40.43649919331074, 26.912373192608356, 45.08091017603874, 62.605284824967384, 60.807384699583054, 60.54500877857208, 1.5973696857690811, 0.30093022563960403, 2.084214761853218, 32.22732849419117, 22.346665486693382, 12.413622289896011, 16.051509082317352, 45.47340631484985, 64.62513104081154, 63.50628487765789, 61.944017708301544, 62.7225199341774, 63.500843569636345, 61.71945735812187, 55.42723439633846, 58.57935905456543, 57.55272634327412, 62.90949650108814, 62.73174583911896, 61.94281317293644, 57.2831954061985, 58.394962549209595, 48.688725382089615, 45.335063338279724, 43.313583210110664, 44.319127053022385, 44.398413598537445, 46.30895487964153, 43.63528914749622, 50.48681549727917, 47.37459249794483, 47.34170526266098, 48.506289571523666, 48.140718787908554, 51.41687259078026, 56.402946040034294, 55.79872906208038, 57.61843241751194, 56.162035167217255, 53.48932698369026, 48.03949601948261, 43.790073841810226, 41.21194638311863, 43.56228746473789, 43.002835884690285, 42.292141020298004, 43.375694677233696, 43.99270936846733, 44.71216656267643, 52.3528877645731, 58.51017616689205, 52.77020797133446, 53.04395668208599, 55.71038760244846, 52.51917824149132, 55.01547709107399, 49.90477792918682, 50.93991458415985, 50.75603485107422, 54.17861379683018, 50.74024669826031, 55.8178686350584, 54.16142351925373, 62.033054530620575, 39.43322382867336, 41.86111494898796, 57.28110931813717, 53.363967910408974, 53.6056387424469, 44.53299097716808, 47.633943781256676, 44.938820600509644, 46.948392167687416, 44.223144203424454, 45.25464065372944, 43.502159491181374, 43.127837777137756, 40.57258889079094, 43.58406409621239, 40.93692474067211, 44.55702468752861, 42.060646042227745, 44.67417240142822, 44.06809352338314, 43.069594502449036, 42.38293714821339, 42.51468367874622, 43.8529908657074, 46.253295466303825, 44.29134674370289, 44.02664914727211, 44.04820159077644, 47.00796917080879, 44.31456349790096, 45.49480676651001, 49.69078481197357, 54.611478969454765, 54.63040575385094, 60.42616255581379, 53.04261155426502, 54.9901020526886, 58.57222683727741, 54.774330630898476, 48.49150836467743, 42.36967585980892, 43.09694163501263, 45.75609214603901, 43.97950127720833, 44.4763246178627, 49.51881363987923, 47.18950442969799, 50.11138804256916, 55.787496864795685, 58.4802907705307, 58.950025364756584, 58.25046770274639, 55.33274866640568, 49.9966873973608, 48.196621388196945, 51.67927511036396, 57.279236018657684, 67.17031806707382, 62.14823015034199, 67.047159075737, 2.1414385037496686, 9.360379725694656, 10.943223740905523, 0.6254873459693044, 0.3031609731260687, 3.128146519884467, 56.50371663272381, 50.51356606185436, 47.48651169240475, 40.16185753047466, 26.753123737871647, 37.414430156350136, 56.9078553467989, 64.29027780890465, 67.99399986863136, 15.08157217875123, 0.39480219944380224, 0.1875845342874527, 0.19301330001326278, 0.23012136662146077, 0.18317013600608334, 0.10545643148361705, 0.19615160505054519, 0.178024054330308, 0.15391535736853257, 0.1436204629135318, 0.17723219760227948, 0.12090843592886813, 0.20652867009630427], [0.027119090991618577, 0.05037248687585816, 0.036009316972922534, 0.11710881793987937, 0.030702628973813262, 0.10999968886608258, 0.04634196819097269, 0.041599904288887046, 0.057618512510089204, 0.07507961461669765, 0.06259718793444335, 0.018971489516843576, 0.34833119774702936, 34.69636760652065, 59.508287608623505, 51.63247302174568, 46.28811299800873, 33.65009754896164, 17.30842463672161, 37.7508869022131, 35.03317013382912, 55.714582577347755, 33.745654821395874, 0.012565182641992578, 0.0768841318495106, 0.18194774456787854, 4.203825099393725, 7.489594761282206, 7.477990183979273, 26.279547549784184, 53.37009698152542, 64.89637568593025, 58.186087757349014, 57.84780710935593, 57.845386639237404, 58.602575808763504, 57.686859145760536, 58.44556823372841, 57.2796805948019, 57.31895908713341, 56.969921216368675, 55.2411013841629, 53.37610825896263, 55.14845475554466, 53.723029643297195, 46.16660311818123, 41.54922388494015, 40.20581737160683, 40.46403631567955, 40.74090465903282, 44.76228587329388, 49.218363761901855, 47.82144472002983, 49.556226432323456, 49.67637598514557, 49.56576392054558, 49.25903297960758, 49.61009994149208, 51.30053423345089, 53.245494067668915, 52.57032349705696, 52.19208799302578, 54.018642380833626, 48.58695924282074, 40.80672852694988, 38.43670070171356, 40.13951472938061, 40.33586919307709, 39.07786689698696, 39.82733488082886, 39.311166778206825, 40.351474955677986, 51.71121619641781, 54.17146638035774, 51.590641066432, 53.19758243858814, 52.09123380482197, 51.162719428539276, 52.67344616353512, 51.21389888226986, 50.8781298995018, 48.118862360715866, 50.932345390319824, 49.13702912628651, 52.43700385093689, 48.67256484925747, 56.40426076948643, 35.838301330804825, 37.449673265218735, 55.29307119548321, 48.89196127653122, 46.5816168487072, 42.22904160618782, 43.55306535959244, 39.75274108350277, 41.09305456280708, 38.955065086483955, 41.667712926864624, 38.780259266495705, 37.95098036527634, 36.112597212195396, 38.38165685534477, 36.32304511964321, 38.91473405063152, 37.43771530687809, 39.50601652264595, 40.345513075590134, 39.83459249138832, 39.38874341547489, 40.303460732102394, 40.28967507183552, 39.21582609415054, 40.89734226465225, 43.81198346614838, 45.556029081344604, 46.82680629193783, 45.998697727918625, 47.12165907025337, 49.403064250946045, 50.90530604124069, 53.934716284275055, 52.05322064459324, 46.368398889899254, 52.806659415364265, 53.94766978919506, 50.473573207855225, 44.4226410984993, 40.3643486648798, 41.84362828731537, 40.17160780727863, 43.43339078128338, 41.32658243179321, 41.18450425565243, 40.99014848470688, 40.64431384205818, 41.82564005255699, 42.32416570186615, 41.990551203489304, 40.73612451553345, 40.58321312069893, 46.823382675647736, 44.20799061655998, 46.97780258953571, 47.145122811198235, 60.16303047537804, 54.319871217012405, 67.23245993256569, 11.549344416707754, 1.652305000461638, 0.8675858331844211, 0.8006862073671073, 0.07998841683729552, 0.043482614200911485, 32.22163259983063, 50.14346592128277, 35.854199677705765, 32.07513906061649, 15.248400326818228, 20.341864563524723, 35.35911664366722, 42.22475163638592, 53.84913727641106, 16.69770810753107, 0.18446084955940023, 0.05382586699852254, 0.01713567035039887, 0.04267778844223358, 0.04331911164626945, 0.026855969954340253, 0.08814355853246525, 0.03555367911758367, 0.05765231733676046, 0.006204598093972891, 0.01779706679371884, 0.03643037816800643, 0.024764633053564467, 0.03974712890340015, 0.07097281428286806, 0.03764128116017673, 0.05692186961823609, 0.055280606320593506, 0.07581742072943598, 0.044574439598363824, 0.035323160627740435, 0.03726471171830781, 0.031119146369746886, 0.02999283893586835, 0.010888248943956569, 1.5013053780421615, 42.643219381570816, 68.26360300183296, 58.51833052933216, 50.59276141226292, 43.26613515615463, 21.91573441028595, 34.6964929997921, 39.42681737244129, 61.77148036658764, 36.43623344600201, 0.019723160803550854, 0.010362165503465803, 0.7695585745386779, 5.857777548953891, 6.59582999534905, 4.7369578666985035, 24.959116503596306, 54.75144065916538, 67.04877778887749, 59.64336276054382, 58.46506118774414, 59.74522389471531, 60.77426567673683, 60.15657462179661, 60.70588834583759, 57.99161039292812, 58.717432245612144, 56.47839479148388, 56.170276924967766, 55.859829783439636, 56.85216173529625, 56.57287672162056, 49.20418292284012, 44.40147623419762, 42.19904221594334, 42.64930285513401, 44.24074865877628, 46.82047203183174, 52.45085410773754, 50.71072228252888, 52.208609506487846, 52.13659197092056, 52.27064497768879, 51.926603838801384, 51.30539417266846, 53.24441112577915, 55.30191332101822, 51.84235475957394, 53.571033999323845, 55.122661739587784, 49.75796900689602, 43.67457523941994, 41.118969172239304, 41.32906749844551, 41.758490055799484, 42.07677997648716, 41.19312599301338, 42.02051639556885, 42.11245246231556, 53.427253514528275, 54.61344726383686, 54.002922624349594, 52.29561343789101, 53.39768350124359, 52.81186133623123, 54.836020320653915, 52.30305723845959, 53.74954842031002, 51.90040424466133, 53.24510648846626, 50.76324686408043, 54.895471930503845, 50.5835735052824, 58.259602412581444, 37.774175852537155, 38.51535648107529, 55.574016720056534, 51.027556881308556, 49.27575968205929, 42.62917533516884, 46.71524427831173, 42.19355911016464, 43.52260619401932, 41.070392578840256, 42.881823778152466, 41.21847063302994, 39.335006698966026, 39.919225350022316, 39.96531307697296, 37.42098480463028, 40.84021992981434, 39.13454085588455, 41.96324586868286, 42.717068418860435, 42.26567544043064, 41.840539053082466, 41.979395002126694, 42.134590074419975, 42.32481926679611, 42.997861951589584, 45.13658478856087, 46.86925761401653, 49.870446771383286, 48.74644808471203, 47.79156692326069, 51.55923955142498, 53.78045216202736, 56.065402552485466, 54.074054807424545, 45.32247081398964, 54.57095414400101, 55.30466437339783, 53.37597906589508, 44.64484177529812, 41.498310416936874, 43.678295239806175, 43.28578770160675, 44.44183386862278, 42.777849957346916, 42.03998655080795, 43.522047623991966, 42.15963453054428, 43.17164942622185, 44.09067951142788, 43.72734680771828, 43.61181780695915, 43.14346253871918, 49.051746502518654, 47.432812973856926, 50.202108174562454, 50.89779384434223, 61.901596784591675, 56.50017902255058, 71.65759608149529, 14.42968675866723, 2.2003826033324003, 5.212757885456085, 1.91678149625659, 0.3417183947749436, 0.14993553108070046, 34.484768360853195, 55.204288959503174, 42.36912488937378, 34.346467182040215, 20.814369209110737, 24.431632608175278, 42.113087028265, 46.346344873309135, 63.95291671156883, 25.005173832178116, 0.3136629267828539, 0.03401813104574103, 0.06699292120174505, 0.10914602607954293, 0.059976597694912925, 0.02790935952361906, 0.008879819215508178, 0.02098100092553068, 0.04967863074853085, 0.03113888749794569, 0.07582693506265059, 0.015527106079389341, 0.017520885812700726, 0.2051027669222094, 0.07726175885181874, 0.14636618667282164, 0.18140881176805124, 0.09471357669099234, 0.2441886274027638, 0.1729462799266912, 0.15960258344421163, 0.1553245325339958, 0.18711355252889916, 0.17555706639541313, 0.11154488485772163, 2.1437865402549505, 52.84593030810356, 77.14716151356697, 66.6357171535492, 58.64878132939339, 44.4274440407753, 23.52110266685486, 50.52952140569687, 49.513539522886276, 68.32025796175003, 40.932383984327316, 0.11816287544206716, 0.10990507988026366, 0.640623418148607, 14.377580154687166, 18.551906011998653, 13.776289019733667, 32.15374544262886, 55.358488485217094, 70.65029293298721, 62.20480151474476, 61.903207898139954, 63.208095878362656, 63.48229296505451, 61.70219488441944, 62.57256478071213, 60.331908613443375, 60.334378480911255, 58.35667200386524, 58.322192654013634, 57.235838547348976, 59.24256406724453, 58.612489476799965, 50.942886024713516, 45.4337440431118, 44.24836724996567, 44.027614295482635, 47.10895635187626, 50.06392098963261, 55.44443607330322, 51.971760615706444, 54.652357175946236, 55.906563475728035, 52.55120292305946, 52.7431458234787, 53.275911435484886, 56.12161673605442, 57.835225984454155, 54.56409931182861, 55.61400577425957, 58.37446644902229, 52.20619283616543, 45.882762148976326, 43.203229531645775, 44.21362191438675, 43.18651422858238, 43.15477833151817, 43.85780520737171, 44.552012756466866, 43.91784578561783, 55.86723938584328, 57.57917292416096, 54.08814065158367, 54.76971387863159, 55.50921879708767, 55.47964498400688, 57.42471881210804, 57.462059408426285, 56.61254659295082, 54.36876319348812, 55.18489859998226, 54.949246644973755, 56.20056129992008, 52.906430661678314, 61.24223716557026, 41.03859208524227, 42.17605724930763, 59.11033496260643, 53.159820064902306, 51.30324348807335, 47.23288670182228, 50.20596496760845, 43.94351340830326, 45.81682808697224, 43.577304258942604, 46.33097469806671, 43.65235023200512, 42.227168306708336, 40.2845149487257, 43.770846873521805, 39.370227009058, 42.956288382411, 41.540750339627266, 44.36806842684746, 43.86845983564854, 45.01437194645405, 43.916067481040955, 43.8571098446846, 44.639556258916855, 43.65022614598274, 46.17603421211243, 48.400248661637306, 50.35875476896763, 52.786995470523834, 51.054645627737045, 50.738460794091225, 52.98376031219959, 55.85808947682381, 57.973363772034645, 56.2924175709486, 44.78851966559887, 56.84746898710728, 58.34539420902729, 56.50356084108353, 47.855046316981316, 44.61750224232674, 46.25928774476051, 44.47569765150547, 47.18074209988117, 45.24940833449364, 44.42531615495682, 45.5864654481411, 43.68928425014019, 45.352386608719826, 46.397117748856544, 46.75421878695488, 45.29676139354706, 44.98845353722572, 53.2469417899847, 49.35138322412968, 53.20999637246132, 52.34161376953125, 67.4610860645771, 58.78975376486778, 75.12643754482269, 14.030306339263916, 5.478019751608372, 9.503370802849531, 2.550071901641786, 0.42909731855615973, 0.16471701994305477, 38.63661177456379, 60.07988713681698, 52.11890771985054, 42.61290080845356, 25.328010208904743, 29.992225728929043, 51.63419812917709, 54.51359622180462, 70.83991035819054, 30.62809120863676, 0.537303815362975, 0.3122922987677157, 0.17757965630153194, 0.14901712333085015, 0.21407313557574525, 0.14792128291446716, 0.21710684231948107, 0.1571655782754533, 0.12317358196014538, 0.15889165049884468, 0.13093313667923212, 0.087882500665728, 0.09258373902412131], [0.049060907840612344, 0.018276251139468513, 0.09237171485438012, 0.06291093828622252, 0.011176783900737064, 0.08326865019625984, 0.0628074977430515, 0.013031255093665095, 0.06371024617692456, 0.07015696392045356, 0.04136091418331489, 0.04738909032312222, 2.084722272120416, 41.99969731271267, 60.03431238234043, 50.62188684940338, 38.56500841677189, 24.32637445628643, 38.661090061068535, 40.71149803698063, 38.38901326060295, 62.904302179813385, 21.52696207165718, 0.12360828011878766, 0.021494068023457658, 0.4694055556319654, 6.020362749695778, 2.7819639584049582, 13.580159693956375, 39.81369361281395, 62.339584082365036, 58.04248206317425, 56.81733280420303, 54.82608005404472, 54.387074410915375, 55.59665970504284, 55.86705319583416, 56.6814710944891, 57.0159937441349, 57.010567635297775, 57.16565631330013, 55.223010554909706, 56.85298629105091, 56.590538173913956, 53.39356832206249, 45.74030019342899, 41.64757400751114, 39.313138872385025, 40.32034322619438, 45.91250695288181, 52.01598264276981, 52.56297469139099, 52.78312727808952, 52.81175494194031, 54.29438218474388, 53.47081437706947, 52.09330849349499, 53.401202112436295, 53.3408385515213, 51.65103502571583, 54.39413823187351, 55.809003710746765, 55.517927929759026, 49.249833673238754, 45.037197321653366, 39.378894343972206, 39.932087659835815, 39.78108376264572, 40.93394190073013, 39.48783449828625, 38.822209015488625, 42.40065939724445, 50.82605369389057, 51.129987984895706, 48.89658182859421, 48.76155227422714, 54.64633449912071, 51.777439042925835, 52.68812097609043, 49.304911717772484, 52.827410101890564, 50.72291202843189, 53.474880158901215, 51.69709235429764, 52.696708515286446, 48.68153616786003, 56.47776022553444, 32.68447056412697, 37.612764313817024, 55.288405045866966, 47.04665869474411, 47.2125805914402, 40.8896628767252, 41.90171957015991, 40.79410560429096, 42.068956196308136, 40.13106778264046, 40.44658005237579, 38.8406228274107, 38.16096469759941, 37.13894493877888, 37.48512916266918, 34.947659522295, 37.584132850170135, 37.247315123677254, 38.614800944924355, 40.12774296104908, 41.19916386902332, 39.56843577325344, 40.1231300085783, 39.865853413939476, 39.89620238542557, 44.65213358402252, 46.68322719633579, 50.03460556268692, 51.51055656373501, 49.1615454107523, 50.91355159878731, 51.382834017276764, 53.85379962623119, 51.174456998705864, 47.867137268185616, 49.90507811307907, 52.65437878668308, 53.811241909861565, 48.492063134908676, 41.41132548451424, 40.42905539274216, 39.51757550239563, 41.71092040836811, 40.0740784406662, 42.258664816617966, 42.23621182143688, 41.07725501060486, 41.25195063650608, 42.627362832427025, 44.99000005424023, 46.926892921328545, 48.4236516058445, 52.71792657673359, 54.25397515296936, 56.75060838460922, 56.4753245562315, 54.859567657113075, 57.98690244555473, 55.985986813902855, 64.71804365515709, 35.526053085923195, 0.4699587821960449, 1.87560512451455, 0.5200809426605701, 0.4098215763224289, 0.0682080841215793, 13.796186652034521, 52.825035229325294, 36.55034512281418, 32.09162637591362, 19.07155852764845, 17.777207382023335, 30.761578045785427, 41.91778890788555, 56.91155254840851, 26.64800427854061, 0.6194935832172632, 0.06900523978401907, 0.07563504535937682, 0.03867581646773033, 0.013828306855430128, 0.04257450746081304, 0.035009228449780494, 0.015618032157362904, 0.12320147186983377, 0.009025945309986128, 0.05370766142732464, 0.07801486804964952, 0.011694546010403428, 0.025937454593076836, 0.050093290919903666, 0.0841950805624947, 0.07126631142455153, 0.044276782718952745, 0.03355749853653833, 0.039351104060187936, 0.06844951960374601, 0.05557897195103578, 0.01547424661112018, 0.01863552854047157, 0.016017962552723475, 3.3602874632924795, 52.67769053578377, 64.04731124639511, 56.772141829133034, 42.590865790843964, 26.12400859594345, 30.12385256588459, 41.90426163375378, 41.684804409742355, 69.00200217962265, 23.298567607998848, 0.10911651828791946, 0.11537916114320979, 1.177006436046213, 7.66093754209578, 2.63161338865757, 12.179687842726707, 41.11101619899273, 64.84623357653618, 60.214437916874886, 59.43595848977566, 56.56158372759819, 57.7864746004343, 56.74350656569004, 57.61799544095993, 58.06676276028156, 57.94198885560036, 58.308517187833786, 59.72435541450977, 58.925870060920715, 56.82789623737335, 57.43410810828209, 55.809064507484436, 48.3419293910265, 42.58458852767944, 41.36552654206753, 42.93511971831322, 47.94179566204548, 53.93377013504505, 53.95281471312046, 54.24248456954956, 55.564893409609795, 56.74537606537342, 55.86330659687519, 55.57111367583275, 56.31367743015289, 54.84301574528217, 53.2702611386776, 54.1238359361887, 57.07958713173866, 56.20710074901581, 51.10285364091396, 45.92360235750675, 40.037972778081894, 40.85615247488022, 40.25804936885834, 42.12233953177929, 40.01371867954731, 40.48716947436333, 45.48078931868076, 53.280927166342735, 52.07232981920242, 50.5359810590744, 50.66222168505192, 55.84206573665142, 52.8740905970335, 55.37446662783623, 51.67453296482563, 55.518323108553886, 52.998469322919846, 56.54995635151863, 52.98684574663639, 54.4324591755867, 51.26697063446045, 58.7193663418293, 33.27484868466854, 39.18877154588699, 57.13386341929436, 48.654124438762665, 49.82107222080231, 43.92735667526722, 44.335196390748024, 42.53456801176071, 44.27458204329014, 42.592925280332565, 42.81361743807793, 40.974143743515015, 40.87461568415165, 38.992436081171036, 40.43434090912342, 37.716722935438156, 39.5942135900259, 38.263536393642426, 41.08529917895794, 43.196275904774666, 43.423895090818405, 41.69123366475105, 41.803038865327835, 42.212102115154266, 41.29687562584877, 47.11432546377182, 49.51266176998615, 51.484056785702705, 52.61333338916302, 51.92096494138241, 55.06158761680126, 54.51891213655472, 54.964468628168106, 52.206447422504425, 47.935810983181, 51.91562622785568, 54.62996877729893, 53.4358486533165, 51.14533916115761, 43.006179705262184, 41.92354939877987, 42.093936055898666, 42.602109387516975, 42.62450538575649, 43.42190019786358, 43.333041965961456, 43.42023208737373, 43.376800417900085, 44.87927779555321, 46.56910791993141, 48.90256270766258, 50.15345178544521, 55.863207802176476, 56.48618057370186, 60.31440295279026, 58.52101318538189, 55.998138561844826, 60.362272784113884, 58.530201092362404, 67.42657631635666, 36.98661871254444, 0.7675391610246152, 2.6339730620384216, 1.3519439427182078, 0.5017769092228264, 0.09967679317924194, 14.588569533079863, 59.960543140769005, 39.56789240241051, 33.45808245241642, 21.700460761785507, 22.626199387013912, 39.419609159231186, 49.13420967757702, 62.994839921593666, 33.35415042936802, 0.5877224786672741, 0.0683991945697926, 0.06993967792368494, 0.034304952569073066, 0.0380992642021738, 0.03807670662354212, 0.0849239957460668, 0.04236423104885034, 0.016222138510784134, 0.03489208786049858, 0.023231962659338024, 0.019189708764315583, 0.012219738873682218, 0.10015018691774458, 0.12620955967577174, 0.11566162997041829, 0.1258360070642084, 0.1027388648071792, 0.16571393207414076, 0.12640462577110156, 0.14461108163231984, 0.1753191783791408, 0.1334590808255598, 0.18976797728100792, 0.10381563202827238, 5.42331931181252, 63.37565168738365, 74.07659187912941, 66.3737440109253, 51.6577834635973, 35.07639281451702, 50.66238507628441, 57.05426909029484, 51.05832763016224, 75.96863955259323, 26.07724640518427, 0.20361165865324438, 0.30079889518674463, 1.6061131353490055, 15.627296045422554, 8.24415447190404, 18.372479639947414, 43.28847795724869, 67.11216598749161, 63.44890035688877, 60.79122796654701, 59.47652131319046, 59.208586290478706, 60.789909437298775, 59.645217061042786, 61.183252930641174, 60.46759933233261, 60.22571571171284, 61.36406622827053, 60.34755617380142, 59.15806420147419, 60.26025205850601, 58.132818415760994, 50.58121383190155, 44.578371942043304, 43.165128976106644, 45.710657984018326, 52.12964214384556, 55.979204177856445, 57.5331611931324, 55.91793246567249, 57.339280396699905, 60.7307618111372, 58.90261150896549, 57.208122834563255, 60.03547891974449, 57.42630712687969, 55.51256641745567, 54.993426874279976, 58.480302169919014, 60.0666144490242, 53.68362955749035, 47.85082474350929, 43.18087913095951, 43.75104993581772, 42.231952250003815, 43.13267111778259, 41.4120664447546, 43.259044736623764, 48.047730177640915, 56.1720210313797, 54.05400708317757, 50.63406519591808, 51.09556183218956, 58.04989546537399, 56.24520130455494, 56.459961980581284, 54.51393820345402, 57.13231310248375, 55.044423937797546, 58.40728908777237, 56.49283021688461, 56.04582600295544, 53.99898983538151, 59.023559018969536, 34.86994989216328, 41.45628847181797, 59.035178795456886, 51.743799448013306, 51.930164247751236, 46.87413655221462, 46.730143278837204, 46.033598855137825, 46.65941387414932, 46.09366983175278, 46.28143295645714, 43.61105024814606, 43.33342954516411, 42.01885588467121, 42.867399752140045, 39.68800015747547, 41.45816557109356, 40.30874624848366, 43.45444545149803, 44.95186910033226, 45.07345497608185, 43.525896817445755, 43.78908969461918, 44.594475477933884, 42.97860078513622, 49.18277867138386, 52.04916626214981, 53.87698598206043, 55.99769778549671, 53.147865906357765, 57.19007380306721, 55.789700746536255, 57.994141057133675, 53.98974493145943, 48.13746616244316, 54.571828097105026, 56.467105597257614, 56.35678231716156, 53.78616325557232, 44.573819786310196, 44.120173528790474, 43.50056737661362, 44.383894577622414, 44.448380917310715, 46.93427212536335, 45.76175384223461, 45.80807715654373, 44.865332543849945, 48.00360694527626, 49.84922491014004, 52.907221019268036, 53.17710533738136, 58.10825273394585, 59.537401646375656, 62.994847521185875, 60.48089861869812, 59.71120432019234, 62.633445113897324, 62.336213663220406, 68.30926895141602, 41.7598769813776, 2.9780341498553753, 10.185364857316017, 3.3319321973249316, 0.8605360239744186, 0.17734490014845505, 17.777551263570786, 64.62279796600342, 49.70485545694828, 43.85522894561291, 27.996333427727222, 29.348667562007904, 45.60246258974075, 56.946142092347145, 72.63476684689522, 43.63338924944401, 1.22760713333264, 0.24263654428068548, 0.26541789527982473, 0.16336637054337189, 0.10670008545275778, 0.12175153053249232, 0.16884263372048736, 0.16329150268575177, 0.18194517673691735, 0.1316813551238738, 0.14406598900677636, 0.16805623919935897, 0.07736889529041946], [0.036598482038243674, 0.019856253857142292, 0.026037831921712495, 0.015565781250188593, 0.052636545660789125, 0.05455119760881644, 0.033827443621703424, 0.06989603964029811, 0.02589045252534561, 0.028487548224802595, 0.047264654422178864, 0.05323639023117721, 3.8887277198955417, 48.3714310079813, 52.28004567325115, 57.09690660238266, 38.697191923856735, 28.19578282535076, 31.47786621004343, 35.19198641180992, 42.38654315471649, 60.87282098829746, 15.662535354495049, 0.4401058325311169, 0.17848552175564691, 1.5184903121553361, 2.2516138292849064, 5.553981950506568, 21.018678545951843, 53.596982806921005, 60.00852696597576, 58.274148032069206, 58.15463304519653, 54.48093317449093, 50.12383237481117, 50.90614199638367, 49.20541785657406, 48.53106424212456, 50.73656469583511, 52.10272058844566, 53.65317419171333, 55.822834968566895, 54.948551282286644, 52.858325242996216, 46.513277515769005, 41.31964020431042, 41.53910122811794, 40.93462586402893, 41.538485661149025, 49.46476154029369, 51.74832500517368, 53.308943063020706, 54.042531698942184, 52.93313182890415, 54.17553976178169, 51.88579022884369, 53.039355129003525, 51.437843665480614, 48.84679690003395, 50.09862072765827, 51.359974443912506, 48.64508852362633, 49.8908706754446, 49.81044799089432, 45.24833299219608, 39.195041209459305, 40.62819130718708, 39.16890621185303, 40.48473380506039, 39.44901578128338, 39.17647160589695, 42.01521947979927, 50.78991763293743, 49.6188622713089, 47.527800276875496, 47.431912422180176, 50.42674832046032, 52.136268988251686, 53.36593620479107, 52.57646016776562, 52.61626683175564, 50.17051286995411, 54.0921950340271, 50.86458742618561, 53.755065724253654, 46.35633073747158, 50.1710220426321, 32.8120107203722, 37.978718876838684, 53.9813207834959, 46.974777951836586, 47.68007330596447, 41.44511327147484, 46.458191871643066, 46.03785462677479, 45.739411041140556, 44.35017138719559, 46.2023364007473, 41.81794546544552, 38.0979260802269, 37.50955045223236, 37.77683950960636, 36.42775610089302, 37.94799752533436, 37.78054051101208, 39.80685777962208, 40.20049385726452, 39.70639117062092, 41.74125798046589, 41.39733083546162, 40.09158790111542, 41.273297891020775, 48.96403580904007, 55.13010933995247, 49.295917600393295, 53.445560932159424, 52.60242037475109, 52.63135962188244, 52.26140767335892, 52.38902002573013, 53.43477711081505, 54.46685492992401, 53.3355226367712, 53.526116609573364, 51.966634690761566, 42.28186637163162, 40.22242248058319, 42.510842084884644, 42.20437332987785, 43.994590267539024, 41.48557350039482, 42.37785682082176, 41.25654079020023, 44.826829209923744, 46.92569598555565, 51.608671098947525, 53.890501856803894, 54.47860009968281, 57.168198376894, 58.456181064248085, 59.068955183029175, 56.903599575161934, 56.03216573596001, 57.56616622209549, 58.49931254982948, 59.016491398215294, 61.92230947315693, 44.893150851130486, 0.29097090067807585, 5.376642616465688, 1.399664394557476, 0.1873368350788951, 0.056468988841515966, 6.295633278787136, 56.15030899643898, 41.35745197534561, 39.508087411522865, 22.419657669961452, 14.240306820720434, 29.58764623850584, 44.61622171103954, 54.54012259840965, 32.19521261751652, 1.2119045946747065, 0.0581032240006607, 0.07505757283070125, 0.019940699130529538, 0.062014783834456466, 0.04634672535758, 0.10000382055295631, 0.039829355155234225, 0.02593072331364965, 0.09525855057290755, 0.04012791003333405, 0.12442838298738934, 0.020990919729229063, 0.01499419395258883, 0.031689880197518505, 0.05917659589613322, 0.02931788345449604, 0.05794681637780741, 0.03760781401069835, 0.01611847161257174, 0.08328690702910535, 0.07697396140429191, 0.01767138222930953, 0.015612991119269282, 0.09266545690479688, 6.9430838618427515, 60.582474768161774, 59.03691150248051, 64.02452006936073, 43.85055519640446, 34.98400457203388, 34.90329310297966, 42.241033762693405, 46.784415766596794, 65.994813144207, 15.550199132412672, 0.256286688381806, 0.26073654647916555, 2.540598060004413, 3.9845027681440115, 5.60557178221643, 24.713100604712963, 54.95036758482456, 62.415739595890045, 57.91461892426014, 60.76625570654869, 55.79975500702858, 53.137754648923874, 53.884148597717285, 51.53769850730896, 50.38935832679272, 53.22737284004688, 54.699220061302185, 56.81276544928551, 58.28259497880936, 57.48108498752117, 55.296137630939484, 49.770082756876945, 43.1317325681448, 42.95001111924648, 42.96006537973881, 44.40990038216114, 50.37976764142513, 53.18782076239586, 55.59023045003414, 56.319912895560265, 53.90838369727135, 56.28728784620762, 54.17848840355873, 54.25594724714756, 50.32445400953293, 48.6671881377697, 50.20061485469341, 52.186012119054794, 51.06966622173786, 52.32573442161083, 53.723405823111534, 47.4268738925457, 40.982092916965485, 42.52691902220249, 41.728350073099136, 41.92797616124153, 41.15053027868271, 40.06297543644905, 43.485558182001114, 53.85468117892742, 50.91626465320587, 48.11598591506481, 49.50409322977066, 51.65296912193298, 53.764371424913406, 55.73021873831749, 53.47350463271141, 54.88230563700199, 53.691274747252464, 56.239323019981384, 53.59409876167774, 56.78007960319519, 47.59492367506027, 49.39986862242222, 32.29829728603363, 39.9396226555109, 56.54686711728573, 50.41648127138615, 49.08635504543781, 45.83721399307251, 49.26846407353878, 47.232966497540474, 48.75278614461422, 47.00271785259247, 48.075092509388924, 42.96909749507904, 41.12575940787792, 39.881056398153305, 41.2082339823246, 39.395666643977165, 40.35286568105221, 39.555277079343796, 41.935104578733444, 41.78572319447994, 41.17194212973118, 42.44968816637993, 42.195876985788345, 40.78454151749611, 44.2389627546072, 50.58884762227535, 54.95606727898121, 50.531884878873825, 54.487069845199585, 54.58038903772831, 54.86617550253868, 54.600854739546776, 53.54558676481247, 55.369173511862755, 55.22142983973026, 53.95650051534176, 53.373205214738846, 52.961364313960075, 44.628175869584084, 41.29756718873978, 43.725089728832245, 44.465704187750816, 47.720689326524734, 43.375675678253174, 43.01581218838692, 43.85811299085617, 47.24610239267349, 48.696279376745224, 53.69597889482975, 56.47019103169441, 57.584925815463066, 59.41237315535545, 60.6161143630743, 61.306392922997475, 59.057232812047005, 59.13450926542282, 59.34908375144005, 59.40573491156101, 60.89396685361862, 64.34395372867584, 49.1622369736433, 1.0942798876203597, 1.7011389113031328, 4.582187896594405, 0.538622047752142, 0.07590141700347885, 6.846846900880337, 63.18430915474892, 45.88339291512966, 36.91357523202896, 19.224810004234314, 17.716845721006393, 34.54203508794308, 50.354696586728096, 60.14599218964577, 42.67028532922268, 2.2229652665555477, 0.0023988497332538827, 0.05123924114741385, 0.02147654777218122, 0.039024217694532126, 0.022097445216786582, 0.03826500804279931, 0.025314156300737523, 0.052959472668590024, 0.09439892091904767, 0.03250314788601827, 0.06981428465223871, 0.04060024621139746, 0.0849187264975626, 0.10663028646376915, 0.18008902086876333, 0.05599768424872309, 0.16066314216004685, 0.1388301223050803, 0.1452752889599651, 0.1648194808512926, 0.11166497177327983, 0.10104795554070733, 0.14264024910517037, 0.17147520964499563, 10.346537008881569, 71.90315410494804, 66.0392327606678, 74.35264706611633, 50.36126643419266, 42.46903672814369, 42.03075684607029, 48.5795534402132, 53.85763742029667, 71.29146292805672, 18.619696274399757, 0.39158682979177684, 0.405465763178654, 6.833199933171272, 9.271870125085115, 10.824227426201105, 25.09529549628496, 57.41295464336872, 63.754514157772064, 60.891850367188454, 63.867603689432144, 59.50181655585766, 56.10944218933582, 56.128463968634605, 54.134346172213554, 53.227331042289734, 57.5443097949028, 57.10927113890648, 58.92287202179432, 60.491785034537315, 60.667996779084206, 56.97696603834629, 51.33886277675629, 44.981602504849434, 45.217018872499466, 46.06286868453026, 44.381082728505135, 53.02949845790863, 55.16743093729019, 55.9616719186306, 56.45101726055145, 56.54329150915146, 58.39027740061283, 55.49999289214611, 55.665025636553764, 52.39543408155441, 50.13553574681282, 51.220130547881126, 52.52521991729736, 53.21528188884258, 52.65814058482647, 54.92883414030075, 49.25823502242565, 43.432136848568916, 44.56201381981373, 42.51287117600441, 44.4992183893919, 43.62520068883896, 42.42961764335632, 46.639392748475075, 54.31610181927681, 53.76554936170578, 50.3042770922184, 48.99727642536163, 52.728539407253265, 55.452772825956345, 55.88993176817894, 56.034445613622665, 55.783662870526314, 55.681714341044426, 57.79140293598175, 54.34390872716904, 58.44945542514324, 49.77959744632244, 49.85096141695976, 35.26962764561176, 43.87035213410854, 58.14886495471001, 52.79154382646084, 49.944003224372864, 47.18602001667023, 52.75423362851143, 49.721597358584404, 50.937475115060806, 49.241652712225914, 51.08973674476147, 47.333064526319504, 44.48643587529659, 43.40190187096596, 43.065084144473076, 42.19767428934574, 42.38962098956108, 43.2015386223793, 44.58407163619995, 43.74281957745552, 43.77277337014675, 45.36469414830208, 45.60057409107685, 46.32797285914421, 45.7489675283432, 54.45571392774582, 57.97651380300522, 52.23670519888401, 56.83097407221794, 56.88824459910393, 56.458711847662926, 56.65295362472534, 56.66883297264576, 57.934396862983704, 58.05006645619869, 58.139696046710014, 56.74221843481064, 56.21037237346172, 46.304866299033165, 43.62605944275856, 46.277116388082504, 46.760587245225906, 49.269702807068825, 45.50576537847519, 46.7151302844286, 44.91628400981426, 49.145149290561676, 52.35736772418022, 56.99835129082203, 59.466930627822876, 60.81320978701115, 62.02241510152817, 63.844896107912064, 64.50811251997948, 60.709209367632866, 61.297980174422264, 62.54615619778633, 61.56825587153435, 63.741249069571495, 65.07071033120155, 51.550830602645874, 0.9680306527297944, 10.99901519715786, 6.14027576521039, 0.5724698002450168, 0.1246581444866024, 8.287156764417887, 67.77498722076416, 55.34019246697426, 53.95288310945034, 30.818221606314182, 25.592246130108833, 42.80394695699215, 58.83893832564354, 67.29067280888557, 52.07375854253769, 2.955631264485419, 0.09224546069162898, 0.15304851403925568, 0.15621717291651294, 0.211023680458311, 0.18133909441530704, 0.2380940067814663, 0.07020564880804159, 0.11383395773009397, 0.2598255156772211, 0.14143421460175887, 0.2142268788884394, 0.10981600731611252], [0.10111972122103907, 0.05681308190105483, 0.06968143279664218, 0.036261131390347145, 0.0687550098518841, 0.044757456926163286, 0.03606806909374427, 0.024472941186104435, 0.07844293140806258, 0.06183336583490018, 0.023610135140188504, 0.021854106125829276, 16.23738370835781, 58.88360492885113, 52.212785482406616, 41.68106161057949, 24.50789451599121, 17.686103470623493, 25.35943452268839, 35.85824266076088, 45.98962001502514, 60.17018549144268, 5.391563465818763, 0.20814399904338643, 0.012668344879784854, 0.575982058653608, 4.856300912797451, 7.382938284426928, 33.751700296998024, 58.68502378463745, 63.52410212159157, 56.32944278419018, 55.70392794907093, 51.69492267072201, 52.15904876589775, 50.14809787273407, 48.70887190103531, 43.33206161856651, 42.6811907440424, 42.82588317990303, 44.24168340861797, 45.2671267837286, 44.085299000144005, 40.86537837982178, 39.06360246241093, 40.40944084525108, 41.02323330938816, 40.12889429926872, 42.61673100292683, 47.328341379761696, 53.12164731323719, 52.97093600034714, 52.89606101810932, 53.01545821130276, 49.9815908074379, 47.90625996887684, 49.719378277659416, 50.27076669037342, 52.18552954494953, 50.32851219177246, 50.513706654310226, 50.6375952064991, 52.12412104010582, 51.808703765273094, 43.29216755926609, 38.485702872276306, 39.30105172097683, 39.78892274200916, 39.749838039278984, 38.50622557103634, 39.360301941633224, 41.050018072128296, 48.89659322798252, 51.01200811564922, 53.37163209915161, 49.1901920735836, 52.01380155980587, 49.352325573563576, 50.010400861501694, 48.122342973947525, 51.42365902662277, 49.5306234061718, 52.265788838267326, 50.74863284826279, 51.87110781669617, 46.49151228368282, 51.47576943039894, 35.09493201971054, 37.80724547803402, 53.74286077916622, 47.31624662876129, 49.780406802892685, 45.87520435452461, 48.46827261149883, 47.34723396599293, 50.39547219872475, 48.617175221443176, 49.26901124417782, 46.561135947704315, 40.76946772634983, 38.619113713502884, 39.25917036831379, 37.89579592645168, 37.49193839728832, 37.06143669784069, 38.393998593091965, 38.63390251994133, 39.88401263952255, 38.83985906839371, 40.115621611475945, 39.75192412734032, 44.7087087482214, 49.60014067590237, 48.80333103239536, 50.13873517513275, 50.00933311879635, 50.12740418314934, 49.72120217978954, 49.90279443562031, 52.86318898200989, 53.140182718634605, 51.45812317728996, 52.799774184823036, 48.599585965275764, 43.821475356817245, 40.6282939016819, 43.02593104541302, 46.628692522645, 45.91631814837456, 46.34047418832779, 45.32755874097347, 42.371495962142944, 42.96695061028004, 48.436434119939804, 54.19281363487244, 56.774167120456696, 56.33897267282009, 57.975943833589554, 56.0222102701664, 55.599365159869194, 55.33329963684082, 55.798189491033554, 58.47086347639561, 60.537781566381454, 60.677325278520584, 60.246473997831345, 65.10861709713936, 55.06135202944279, 4.4401581678539515, 0.3260194481117651, 1.1612261203117669, 0.21386759035522118, 0.2040872714133002, 1.785409008152783, 47.4293627589941, 48.13927486538887, 45.498910546302795, 41.52521677315235, 26.85817290097475, 33.676874712109566, 42.246547266840935, 51.952415853738785, 44.00549188256264, 5.091683082282543, 0.12378734551020898, 0.017235205341421533, 0.10486583778401837, 0.041625779267633334, 0.16488602181198075, 0.021529958285100292, 0.03928616613848135, 0.046757875170442276, 0.060763741785194725, 0.1224116634693928, 0.05639854789478704, 0.05181467276997864, 0.057036646467167884, 0.03636724366515409, 0.05593882822722662, 0.020049646409461275, 0.06020913853717502, 0.02840787867171457, 0.030495391656586435, 0.02254958941193763, 0.03906944046320859, 0.08026841431274079, 0.0524012217647396, 0.04472326247196179, 21.667527928948402, 66.73478543758392, 58.36780920624733, 48.635250851511955, 31.00287839770317, 24.058619923889637, 31.057582162320614, 41.07217848300934, 50.375105291604996, 63.23383569717407, 6.660446003079414, 0.500975449103862, 0.24029545427765697, 3.4978400822728872, 1.3186204433441162, 8.020096644759178, 33.83056506514549, 61.05842962861061, 63.37173029780388, 58.80498334765434, 58.606117218732834, 54.726867377758026, 52.93647184967995, 51.96293368935585, 50.080092921853065, 47.44254045188427, 44.722289219498634, 44.98922869563103, 45.73583543300629, 47.13778540492058, 46.823219284415245, 42.26662918925285, 42.26408712565899, 42.60494023561478, 40.49115926027298, 41.323086619377136, 44.935032203793526, 49.55848731100559, 54.42967772483826, 55.306290686130524, 54.03046354651451, 54.35861773788929, 52.117178812623024, 48.93708385527134, 48.35072211921215, 51.65809124708176, 52.429487854242325, 51.403406113386154, 51.894997134804726, 51.12847946584225, 54.16924349963665, 53.35736006498337, 45.39932169020176, 39.32087905704975, 42.51214921474457, 41.05777345597744, 42.612623423337936, 40.32633550465107, 40.62927424907684, 43.42094264924526, 50.52829407155514, 52.19144582748413, 53.900081142783165, 51.27862460911274, 52.17633783817291, 51.492803916335106, 50.88038697838783, 49.12526495754719, 53.132138550281525, 49.95495043694973, 53.31435777246952, 50.281953290104866, 52.90503613650799, 48.225974813103676, 53.23152221739292, 35.99958747625351, 40.88007219135761, 55.50889581441879, 49.10918802022934, 52.278187572956085, 50.27540244162083, 50.56310020387173, 49.91658389568329, 53.032272309064865, 51.429826095700264, 51.968587785959244, 48.556796461343765, 43.20826806128025, 40.32828100025654, 42.35330633819103, 39.24664244055748, 38.63801769912243, 38.792118430137634, 41.27756126224995, 39.941640347242355, 41.27229854464531, 41.01157173514366, 41.360560208559036, 40.882971435785294, 46.4900341629982, 51.80238850414753, 52.947464659810066, 52.48387433588505, 52.7037039399147, 52.69770406186581, 50.11511564254761, 49.20158006250858, 55.78295610845089, 54.84024189412594, 54.218941032886505, 52.85319931805134, 52.15159736573696, 45.55931210517883, 43.1704068928957, 45.07007695734501, 48.660899475216866, 49.09547835588455, 48.98169346153736, 45.479273200035095, 44.8838147521019, 44.82504330575466, 49.6767483651638, 57.122832611203194, 58.73708099126816, 58.63607481122017, 60.390383675694466, 57.219149842858315, 56.32085524499416, 55.09607456624508, 56.81814216077328, 60.522422790527344, 63.09443257749081, 62.35170543193817, 61.61337465047836, 65.09130522608757, 56.70815326273441, 5.24208091199398, 1.6047110105864704, 3.262156778946519, 0.6859819404780865, 0.09279896185034886, 1.8544548656791449, 52.35223799943924, 53.31214629113674, 46.04360371828079, 32.85394906997681, 30.96400648355484, 37.9757284373045, 50.038143172860146, 56.45814187824726, 55.65771862864494, 7.550620911642909, 0.28637394891120493, 0.023880928129074164, 0.059154049449716695, 0.06739906893926673, 0.032143343560164794, 0.03864423437335063, 0.04134597475058399, 0.05238059377006721, 0.0889957815525122, 0.08651872267364524, 0.042390718299429864, 0.11378670518752187, 0.22434104554122314, 0.15370550769148394, 0.1748215832049027, 0.054291453343466856, 0.14771630172617733, 0.19189250859199092, 0.16781312646344304, 0.09395352841238491, 0.22195057303179055, 0.16478547564474866, 0.19293153018224984, 0.10439903431688435, 27.202658616006374, 76.05739519000053, 64.10365462303162, 58.33793520927429, 35.59940055012703, 26.841565892100334, 33.651131093502045, 49.024323374032974, 56.745885238051414, 70.90185463428497, 7.5239392183721066, 0.4493674199329689, 0.11792161807534285, 3.9059852063655853, 11.319231614470482, 9.699602723121643, 37.08069026470184, 60.81425853073597, 66.94381222128868, 60.54222732782364, 62.38795168697834, 54.75744813680649, 55.864879712462425, 54.30285573005676, 53.15502852201462, 48.39596249163151, 46.92384548485279, 46.24657362699509, 47.99211636185646, 48.988540694117546, 48.00257720053196, 43.76087620854378, 42.331381514668465, 44.76554989814758, 43.989437744021416, 43.486743718385696, 46.404622346162796, 51.85440771281719, 58.47165383398533, 57.24390171468258, 56.49346858263016, 56.30573205649853, 52.36055575311184, 49.14221964776516, 49.80648100376129, 54.022749960422516, 54.50721636414528, 53.76253232359886, 54.00930628180504, 53.38806241750717, 55.70838890969753, 56.42064929008484, 48.23537550866604, 42.102337405085564, 43.79789002239704, 43.74884605407715, 44.3580711632967, 40.347450971603394, 42.07879766821861, 45.82866445183754, 53.07429425418377, 54.7674036026001, 56.15160092711449, 53.39370511472225, 53.20927441120148, 53.603035882115364, 52.903850600123405, 50.20099863409996, 55.28829105198383, 51.03423312306404, 54.181459844112396, 52.22009629011154, 53.96343134343624, 50.68537384271622, 53.61851625144482, 37.21206061542034, 42.49923750758171, 57.61820062994957, 52.07193084061146, 54.046468287706375, 51.136341243982315, 52.69530639052391, 51.96269430220127, 53.83232697844505, 51.68224275112152, 54.97893825173378, 50.83454243838787, 46.766142547130585, 44.45032641291618, 44.301556795835495, 41.91695295274258, 41.2238435447216, 41.1175936460495, 43.06824557483196, 43.63658107817173, 43.022781014442444, 44.70927111804485, 44.21614117920399, 43.52671377360821, 49.15255129337311, 55.813084691762924, 55.0818595290184, 54.23337645828724, 54.231708347797394, 54.248568043112755, 51.84295512735844, 51.49467721581459, 57.91081912815571, 56.93733796477318, 57.57195331156254, 56.63762904703617, 53.944132179021835, 49.3375975638628, 45.21066561341286, 47.71038427948952, 52.378543987870216, 51.53384551405907, 51.10549069941044, 48.93262289464474, 46.75326883792877, 47.67956033349037, 52.03898660838604, 59.87755559384823, 60.52536003291607, 60.79184353351593, 62.453650161623955, 59.590910375118256, 59.32380370795727, 57.981586530804634, 58.92144709825516, 62.49946430325508, 65.59990033507347, 64.32658106088638, 66.53768241405487, 68.62131580710411, 60.18980763852596, 6.645093876868486, 2.6331589557230473, 6.243347134441137, 0.815929148811847, 0.2537260117242113, 2.4852967774495482, 57.80186377465725, 61.82609483599663, 61.3821342587471, 53.37336100637913, 39.11229684948921, 45.18331088125706, 59.68781277537346, 64.91200804710388, 64.59137365221977, 10.248239133507013, 0.46524682722520083, 0.2740449761040509, 0.27441952319350094, 0.2119190667872317, 0.3126017446629703, 0.18516145180910826, 0.08676801749970764, 0.14057173510082066, 0.2202994131948799, 0.261604324914515, 0.18112024990841746, 0.1787678644177504], [0.07582743230159394, 0.03124647293589078, 0.07096967499819584, 0.06857218177174218, 0.06658816870185547, 0.06698422323097475, 0.009201469729305245, 0.07125477844965644, 0.049753962448448874, 0.05675072665326297, 0.0477814712212421, 0.35184630600269884, 26.868529245257378, 59.85149659216404, 48.20139393210411, 34.143432676792145, 17.20316268503666, 27.20352116972208, 42.4659588932991, 33.62994343042374, 49.78324145078659, 45.78362926840782, 1.4933347119949758, 0.08803535340121016, 0.858974129660055, 2.5115070585161448, 2.662913496606052, 14.916309546679258, 41.579930037260056, 62.795981392264366, 57.083584517240524, 58.904389813542366, 55.56176617741585, 55.97062423825264, 54.03359077870846, 51.59591518342495, 47.23923236131668, 46.08087591826916, 43.01223658025265, 41.74630410969257, 42.09999293088913, 40.50913609564304, 41.648497357964516, 41.48201309144497, 41.90615393221378, 43.019368797540665, 41.18299953639507, 40.857315212488174, 43.810900524258614, 46.325917169451714, 48.79677638411522, 52.512847781181335, 54.89479556679726, 53.98420862853527, 52.284035459160805, 49.15316306054592, 50.73079660534859, 53.24965104460716, 51.62499502301216, 50.92155396938324, 54.28471550345421, 52.599258944392204, 51.90943256020546, 46.865803599357605, 40.71096986532211, 41.14789322018623, 39.90303061902523, 39.42775212228298, 39.3736582249403, 39.64135006070137, 39.18760500848293, 39.06844720244408, 43.56805935502052, 48.634992465376854, 49.147121384739876, 51.396144703030586, 52.57606878876686, 49.41268913447857, 53.27216863632202, 52.188086807727814, 53.37343320250511, 51.51774197816849, 53.40160109102726, 53.482350558042526, 55.71588970720768, 52.16197460889816, 55.08376702666283, 38.639378026127815, 37.604568153619766, 54.818355068564415, 49.24857974052429, 50.441468730568886, 50.309615805745125, 50.508200749754906, 51.252379417419434, 51.55689887702465, 52.37602852284908, 50.293649062514305, 47.35426738858223, 41.45870514214039, 37.84043289721012, 38.64568568766117, 36.62610925734043, 38.8124131411314, 37.20034584403038, 39.12265509366989, 40.02757653594017, 39.9381635338068, 41.37988217175007, 39.75597470998764, 38.93530234694481, 42.84649707376957, 50.40223963558674, 51.933637261390686, 49.92733731865883, 53.144734874367714, 49.983965680003166, 47.756722792983055, 54.73203510046005, 52.07607261836529, 49.978870153427124, 50.53886130452156, 48.36824677884579, 43.13811242580414, 39.50269550085068, 42.200919315218925, 46.535384729504585, 51.21209017932415, 51.38430453836918, 49.103780910372734, 45.78235633671284, 43.371267914772034, 47.14763067662716, 51.95466913282871, 54.23442140221596, 57.71891802549362, 55.24779662489891, 51.4645030349493, 52.476514130830765, 53.244730308651924, 56.81847274303436, 57.16816797852516, 56.41897737979889, 54.14270952343941, 55.31205877661705, 55.85563860833645, 62.15391464531422, 56.730226278305054, 9.520870763808489, 0.08541273709852248, 5.195095958188176, 0.2518130518728867, 0.11964917459408753, 0.4699349740985781, 34.33001406490803, 54.646680280566216, 41.843480095267296, 34.435572400689125, 17.488301284611225, 30.671084001660347, 45.91427005827427, 47.46750511229038, 54.29231509566307, 10.741217080503702, 0.22957658569794148, 0.09437929111300036, 0.058786241061170585, 0.04212640240439214, 0.05573023277975153, 0.0959597465407569, 0.07423301707603969, 0.021055033867014572, 0.017648045395617373, 0.03392360740690492, 0.042172946195933037, 0.025115225471381564, 0.06853614308056422, 0.0928470455983188, 0.039205416760523804, 0.013576855162682477, 0.06700215351884253, 0.0239524284916115, 0.019600702726165764, 0.07878943273681216, 0.027569313024287112, 0.053681574936490506, 0.053430703046615236, 0.4149253258947283, 33.15452814102173, 66.37977048754692, 55.96229888498783, 41.91425509750843, 21.69307015836239, 25.984569378197193, 43.57569694519043, 36.95668771862984, 56.576714515686035, 51.46256513893604, 1.611584248021245, 0.2701040235115215, 1.6774416016414762, 2.8484658524394035, 2.307531153783202, 17.066949494183064, 41.90202735364437, 62.11857654154301, 59.55262742936611, 60.53695321083069, 58.04054796695709, 57.07796461880207, 54.29129675030708, 53.3733344078064, 50.539936646819115, 47.29570113122463, 46.472091525793076, 44.575389102101326, 43.519756346940994, 41.158680841326714, 42.418575435876846, 42.11370259523392, 43.66735942661762, 44.47079211473465, 43.494761288166046, 42.28598155081272, 45.3664268553257, 48.0538934469223, 49.75193113088608, 53.53620506823063, 55.41391611099243, 53.93513046205044, 51.63314178586006, 49.32099245488644, 51.06149286031723, 54.66156788170338, 52.2931207716465, 54.39156576991081, 55.026363506913185, 54.57285404205322, 53.565820679068565, 50.062625259160995, 42.654519975185394, 42.77604125440121, 41.88966661691666, 40.99875122308731, 41.275877952575684, 41.36559493839741, 41.32143370807171, 41.01225569844246, 46.08448572456837, 49.47175316512585, 51.036216616630554, 52.534491419792175, 54.530512914061546, 52.104445695877075, 53.884285390377045, 53.67952197790146, 55.04658222198486, 54.22951206564903, 55.4063431173563, 55.68016782402992, 56.46140590310097, 54.8195444047451, 56.99377253651619, 40.3729248046875, 38.91120404005051, 57.12616503238678, 49.97091718018055, 54.75872866809368, 51.008751690387726, 52.44757868349552, 53.201511427760124, 52.598377391695976, 53.305014073848724, 52.49890632927418, 48.341104835271835, 42.844992354512215, 41.320213973522186, 41.026014760136604, 40.250407978892326, 39.59761060774326, 38.94660674035549, 42.271732315421104, 42.26202003657818, 41.29918210208416, 43.28140273690224, 41.82473190128803, 40.75576566159725, 45.12302331626415, 52.667431086301804, 55.13278439640999, 53.60742464661598, 53.73140439391136, 50.59151507914066, 48.405435383319855, 55.312252566218376, 53.406879007816315, 51.80482417345047, 52.09831282496452, 50.046692714095116, 44.49603036046028, 42.268293499946594, 44.264125004410744, 48.46312388777733, 53.81670601665974, 52.93861113488674, 51.36277489364147, 49.146015644073486, 45.01222126185894, 49.071117863059044, 55.18451102077961, 57.9608890414238, 58.3451434224844, 54.97007332742214, 52.06675171852112, 52.27121874690056, 53.7831462174654, 57.83432923257351, 58.03409591317177, 56.111091300845146, 57.85800576210022, 58.404180854558945, 60.367341712117195, 59.01299558579922, 62.58207947015762, 9.469890799373388, 0.8732925332151353, 5.3906448651105165, 1.4325392805039883, 0.1670539687620476, 0.37733747565653175, 39.375831708312035, 60.17109364271164, 45.85079446434975, 36.6652699559927, 23.514614515006542, 37.87030689418316, 53.6700414866209, 51.7482566088438, 63.771218061447144, 14.92016538977623, 0.4116833279840648, 0.04921571984596085, 0.035904807737097144, 0.049700820964062586, 0.038928543726797216, 0.057232584586017765, 0.02981427820486715, 0.008351491705980152, 0.017669079716142733, 0.034929276880575344, 0.019090307359874714, 0.032857812839210965, 0.18869315448682755, 0.15623551880707964, 0.14664363116025925, 0.13632182643050328, 0.1305955633870326, 0.11966349804424681, 0.11000662052538246, 0.21523504197830334, 0.1656119609833695, 0.19634984753793105, 0.17546667280839756, 0.6721419550012797, 40.8476485311985, 74.6875610947609, 64.4810351729393, 47.3795398324728, 26.192701309919357, 37.218349277973175, 51.13724559545517, 46.555656641721725, 63.82449880242348, 55.682398304343224, 1.9960376434028149, 0.417368802591227, 2.249914607964456, 7.755077490583062, 5.080163525417447, 18.728984110057354, 44.04874496161938, 64.06728297472, 61.79087072610855, 63.39117385447025, 60.16089119017124, 59.22681011259556, 57.044868394732475, 55.92580944299698, 53.21878530085087, 49.246421456336975, 49.14273262023926, 46.991155073046684, 46.06537654995918, 42.79645375907421, 45.44764369726181, 45.25535121560097, 45.63308134675026, 47.644465416669846, 46.030091643333435, 44.084022268652916, 47.605859488248825, 50.79696245491505, 53.71335156261921, 56.46842412650585, 59.49868932366371, 54.3343560397625, 52.38785728812218, 50.96080966293812, 54.32227648794651, 57.03075595200062, 55.327193364501, 56.47222772240639, 58.62913638353348, 56.17169424891472, 55.71458637714386, 51.99051260948181, 43.34090754389763, 45.58459214866161, 43.75399857759476, 42.176832407712936, 43.53106454014778, 42.10885785520077, 43.33866946399212, 43.345482498407364, 47.3380346596241, 51.25731535255909, 53.19138877093792, 54.679164737463, 55.935343131423, 54.12076950073242, 55.45636363327503, 57.00431317090988, 56.830153316259384, 55.5342860519886, 58.79047192633152, 58.89722719788551, 60.38085758686066, 57.72141449153423, 57.40720175206661, 41.86882093548775, 41.65422365069389, 59.3406368046999, 53.459753170609474, 56.068848967552185, 54.23600971698761, 54.64354544878006, 54.39658150076866, 54.04418081045151, 55.413688123226166, 53.12451235949993, 51.52631051838398, 45.44646576046944, 43.78108352422714, 42.7152369171381, 40.70942334830761, 42.943521067500114, 42.17202566564083, 44.24813166260719, 46.372833251953125, 43.376568630337715, 44.661834463477135, 43.58533702790737, 43.455433398485184, 47.2943028062582, 55.9844820946455, 56.25718966126442, 55.48744596540928, 58.64791877567768, 52.41103604435921, 51.106721833348274, 58.3023539185524, 55.17387539148331, 55.62529116868973, 54.368105828762054, 54.37536723911762, 47.17780865728855, 44.18325774371624, 46.958210840821266, 51.31224140524864, 55.655670538544655, 55.25668814778328, 53.91667865216732, 50.96986077725887, 46.756597459316254, 52.7262519299984, 58.59369948506355, 60.077371671795845, 59.70130205154419, 57.951359152793884, 52.59189113974571, 52.441217824816704, 54.10229109227657, 59.48608919978142, 59.6478009223938, 59.136811941862106, 57.254351153969765, 60.08632019162178, 61.88049651682377, 61.65292672812939, 62.37835340201855, 12.15843653306365, 2.571944477967918, 13.716127797961235, 2.6836912566795945, 0.4351594776380807, 0.5797049682587385, 44.52741667628288, 64.77678090333939, 57.502800822257996, 47.02903524041176, 27.373187765479088, 44.37536023557186, 64.92724522948265, 60.77356271445751, 72.23407834768295, 20.180352330207825, 0.5573344405274838, 0.19054938456974924, 0.19489881524350494, 0.12284530777833425, 0.1469230349175632, 0.13638453790917993, 0.15029679372673854, 0.12374233425362036, 0.06680086080450565, 0.1678693961002864, 0.10745198494987562, 0.11449174548033625], [0.015453176110895583, 0.03098964716627961, 0.05440410765004344, 0.05551353679038584, 0.040134244263754226, 0.06023522873874754, 0.04115939140319824, 0.1407264728914015, 0.011134575179312378, 0.14022705203387886, 0.028952867396583315, 1.3952448754571378, 38.28076086938381, 56.23435668647289, 51.886626183986664, 39.76967677474022, 23.844651505351067, 37.19631806015968, 50.39403587579727, 36.70181259512901, 60.14125384390354, 35.20850412547588, 0.6096151226665825, 0.09009933288325556, 2.739006313495338, 4.298765854910016, 2.3019689647480845, 29.523292891681194, 46.291867196559906, 47.76348643004894, 56.09322465956211, 59.38748449087143, 58.17157253623009, 59.10534203052521, 53.47495995461941, 49.50751684606075, 47.99136020243168, 45.01491151750088, 44.717634469270706, 43.12208108603954, 41.86653345823288, 39.6760194003582, 40.89459501206875, 40.86029805243015, 39.66350667178631, 39.47301909327507, 39.537338241934776, 41.0014832764864, 41.319526210427284, 43.1394499540329, 45.51302678883076, 49.764671847224236, 54.59045849740505, 53.14303256571293, 49.2133404314518, 46.81930549442768, 52.46511474251747, 52.02187992632389, 51.0059018433094, 48.21905918419361, 49.06126119196415, 49.74176287651062, 47.0373909920454, 40.22597908973694, 40.999518781900406, 40.28934828937054, 39.93080712854862, 38.282049000263214, 39.395605847239494, 40.113007351756096, 39.31091599166393, 38.570571318268776, 42.40749903023243, 45.31237095594406, 50.90313635766506, 53.4632071852684, 52.53935135900974, 50.76178774237633, 52.938649132847786, 50.146919935941696, 54.447331577539444, 52.93594367802143, 53.217231184244156, 52.6689738035202, 53.170581087470055, 49.73391629755497, 55.84826320409775, 42.768707647919655, 34.17530156672001, 53.14406231045723, 48.90323147177696, 50.949068292975426, 52.27886773645878, 53.57715167105198, 49.50556755065918, 52.502592131495476, 49.88550916314125, 48.407141491770744, 43.48240815103054, 39.94439519941807, 39.373791217803955, 37.83459261059761, 37.31422573328018, 39.651446118950844, 38.14169593155384, 40.550778061151505, 39.228243827819824, 39.21400599181652, 38.75098563730717, 38.85562442243099, 39.23163324594498, 37.573789805173874, 43.646798729896545, 52.35535003244877, 51.39016382396221, 49.81633387506008, 52.150871604681015, 53.20966579020023, 51.91266618669033, 50.13894036412239, 48.38227182626724, 44.783180952072144, 40.9552663564682, 41.77152335643768, 39.23030711710453, 45.0747013092041, 51.26097835600376, 54.47481170296669, 53.90584163367748, 52.072922587394714, 47.96466663479805, 46.87058374285698, 47.56082810461521, 53.174844458699226, 55.64444214105606, 53.35599973797798, 49.8877814412117, 53.24067212641239, 54.069620445370674, 57.77171239256859, 58.58887754380703, 60.491690039634705, 56.6547167301178, 60.57513356208801, 49.40602049231529, 63.53065297007561, 47.77177758514881, 51.38001836836338, 12.622667122632265, 1.0266035003587604, 0.7448217831552029, 1.1230721301399171, 0.43645413941703737, 0.14899030211381614, 21.52923244982958, 58.12503643333912, 44.49445344507694, 29.28058471530676, 13.507235907018185, 21.284753568470478, 34.11238834261894, 47.900347486138344, 54.95093375444412, 19.52822182327509, 0.5419969791546464, 0.01911156803544145, 0.05276735289953649, 0.030430748738581315, 0.024275572577607818, 0.015033056515676435, 0.031014863488962874, 0.03145467875583563, 0.05372015919419937, 0.05723504851630423, 0.03210020251572132, 0.0319850991218118, 0.057739560506888665, 0.05102645998704247, 0.06578304979484528, 0.04292939505830873, 0.03712084639118984, 0.06262122609768994, 0.04865434821113013, 0.050668154799495824, 0.04544285999145359, 0.12485083570936695, 0.04565266142890323, 2.0386777678504586, 48.766708597540855, 64.24001410603523, 58.07113252580166, 47.19689503312111, 29.138413444161415, 36.57099701464176, 42.30307303369045, 39.874315559864044, 64.62668135762215, 39.31833319365978, 0.23212020780192688, 0.12063572634360753, 2.2078145295381546, 2.3192573245614767, 3.6169423162937164, 28.534943126142025, 50.00970549881458, 51.4640698581934, 57.96078264713287, 59.78077858686447, 60.29817782342434, 58.48958507180214, 55.86935967206955, 50.701013803482056, 49.52442593872547, 47.709593921899796, 47.3285997658968, 44.045629128813744, 45.30652306973934, 41.49096921086311, 44.099730625748634, 41.786042377352715, 41.064597889781, 41.65910638868809, 42.234361320734024, 41.90808802843094, 42.746798023581505, 44.92667265236378, 47.63824135065079, 51.76866911351681, 56.756038293242455, 53.189652264118195, 50.38268968462944, 47.31229864060879, 54.69450071454048, 54.495250806212425, 54.06711257994175, 50.67057363688946, 51.26236908137798, 50.40941745042801, 49.098799377679825, 41.59097604453564, 42.88505360484123, 42.49541111290455, 40.94496510922909, 40.316349640488625, 42.13067248463631, 41.662457808852196, 41.30445621907711, 40.95210112631321, 46.75546891987324, 48.195386454463005, 52.545286640524864, 52.99541808664799, 53.932212218642235, 52.067599073052406, 54.32991027832031, 52.938922718167305, 56.36254280805588, 54.15097787976265, 56.018022894859314, 53.947707787156105, 55.28690792620182, 50.241907238960266, 57.98026420176029, 43.713032975792885, 37.83498778939247, 54.864617586135864, 52.976654693484306, 52.90644586086273, 53.521735444664955, 53.222486302256584, 51.01925052702427, 54.5219823718071, 52.24932052195072, 51.57235264778137, 45.407259464263916, 43.02132569253445, 41.393496841192245, 41.46619454026222, 40.22788658738136, 42.97095559537411, 39.9338735640049, 41.44077010452747, 42.5872103869915, 41.49280831217766, 41.66860967874527, 41.107410192489624, 42.71388798952103, 39.89563621580601, 46.761924773454666, 54.73898112773895, 52.49354101717472, 52.80376777052879, 52.97820881009102, 54.119314178824425, 53.32047164440155, 52.722862511873245, 51.81047827005386, 45.82593999803066, 43.44366542994976, 43.38231012225151, 41.14817440509796, 46.01683795452118, 53.1878549605608, 54.67808939516544, 55.17677463591099, 53.533833995461464, 50.33123664557934, 48.101565688848495, 49.336966797709465, 54.975522235035896, 55.32220423221588, 57.044799998402596, 51.763942167162895, 55.08795440196991, 56.391843035817146, 60.39026968181133, 59.78804759681225, 62.65696965157986, 58.52169334888458, 60.703429877758026, 52.19963438808918, 62.24271588027477, 46.663608849048615, 52.79111444950104, 15.277966540306807, 1.7100392212159932, 6.532784728333354, 3.824760289862752, 0.6179680244531482, 0.22245429834583774, 22.588659301400185, 64.42104399204254, 48.01415137946606, 33.61187919974327, 18.038724549114704, 25.96656024456024, 39.867198541760445, 55.11865675449371, 62.131317257881165, 25.011169910430908, 0.6447315320838243, 0.04767939622979611, 0.05412968370364979, 0.04978570039384067, 0.04013794386992231, 0.09858800316578709, 0.02388707682257518, 0.02291676697495859, 0.04699729943240527, 0.054700116961612366, 0.02585811715107411, 0.05651998922985513, 0.17114594840677455, 0.1619007030967623, 0.18281625030795112, 0.3844863170525059, 0.151960926305037, 0.1472450082655996, 0.1300032256403938, 0.19426349230343476, 0.10333493555663154, 0.35591523454058915, 0.08037955092731863, 2.6291836565360427, 59.05777618288994, 71.83162674307823, 65.67245364189148, 53.010457679629326, 34.0440072119236, 45.00169962644577, 59.9541936814785, 50.619128197431564, 71.91115647554398, 44.05284494161606, 0.6092464237008244, 0.29796769085805863, 5.669161370024085, 9.223565217107534, 4.733232166618109, 31.05417374521494, 49.36112590134144, 57.07373544573784, 60.97468592226505, 62.99794055521488, 61.96270890533924, 61.72100007534027, 57.09137789905071, 53.51642332971096, 52.08181791007519, 50.02835489809513, 49.89585600793362, 46.45538382232189, 47.877761498093605, 43.930388912558556, 45.70106349885464, 43.50521832704544, 43.60297188162804, 42.87246108055115, 44.11613814532757, 44.8998498916626, 45.769038051366806, 47.13774360716343, 49.85968954861164, 54.50451850891113, 60.090792551636696, 54.951108545064926, 53.12057577073574, 47.33295053243637, 56.00332908332348, 57.43251979351044, 56.817781180143356, 54.07801419496536, 53.47694344818592, 53.61089006066322, 51.833451837301254, 43.92729587852955, 43.979216292500496, 44.07027080655098, 43.544496819376945, 41.494339630007744, 42.89587922394276, 44.17102240025997, 43.72052617371082, 43.305170461535454, 48.04404437541962, 50.504891127347946, 53.546878695487976, 56.44792802631855, 55.093532502651215, 54.44573946297169, 55.99787637591362, 54.334937408566475, 56.9571653008461, 56.975959092378616, 59.55271102488041, 58.091898411512375, 58.214514032006264, 53.261023834347725, 58.53924460709095, 46.061390563845634, 40.98135195672512, 55.922925397753716, 54.19781416654587, 54.371502846479416, 57.31400415301323, 56.031443774700165, 51.98282182216644, 56.7542789876461, 54.496219754219055, 53.07022087275982, 48.599680960178375, 45.48199765384197, 43.06916132569313, 42.30821415781975, 41.847937256097794, 44.023738503456116, 43.283656015992165, 44.53156605362892, 44.29588370025158, 43.12294363975525, 42.40583851933479, 42.750973999500275, 45.27071759104729, 41.93782523274422, 49.410739839076996, 57.04211354255676, 56.95786826312542, 54.26242969930172, 56.939435452222824, 56.63764424622059, 55.91276474297047, 53.76509718596935, 53.73567536473274, 47.76241108775139, 44.974219501018524, 47.35387600958347, 42.42357216775417, 48.103100806474686, 55.59189856052399, 58.05296950042248, 57.38555431365967, 57.09784135222435, 52.32052870094776, 49.454103112220764, 52.37138897180557, 57.037397995591164, 57.26592153310776, 58.084807991981506, 52.15860418975353, 56.95040166378021, 58.62764686346054, 63.00057001411915, 64.80390384793282, 66.19840621948242, 61.87416225671768, 62.34546236693859, 52.942319735884666, 63.75620886683464, 51.485333517193794, 56.63084641098976, 15.328515227884054, 3.9858773443847895, 5.848910724744201, 2.8705120319500566, 1.169196073897183, 0.2545800158986822, 27.84532953053713, 70.32575234770775, 58.34329292178154, 41.46171078085899, 22.045790031552315, 32.31016784906387, 50.16521975398064, 62.407463639974594, 71.2104132771492, 31.751875206828117, 0.8174333337228745, 0.11986153273028322, 0.20685848052380607, 0.09476276623900048, 0.1713320196722634, 0.20594093366526067, 0.15879748680163175, 0.1281249537714757, 0.12858291825978085, 0.08829592145048082, 0.13614371098810807, 0.08856092012138106], [0.09747485586558469, 0.08512341824825853, 0.07255238655488938, 0.07213806034997106, 0.03843990998575464, 0.015010792085377034, 0.021735893133154605, 0.024020622586249374, 0.09800581057788804, 0.06822626673965715, 0.03867969418934081, 2.532473145984113, 44.12631019949913, 53.56822595000267, 40.80115042626858, 27.079457826912403, 14.643586780875921, 41.874874010682106, 57.16354742646217, 34.33535657823086, 61.2760591506958, 28.464859686791897, 0.10501308730454184, 0.09396239707712084, 1.2665475625544786, 1.437256489880383, 10.917965546250343, 41.03116348385811, 41.43432945013046, 52.983813509345055, 58.80311764776707, 57.96229116618633, 58.18383827805519, 57.40985780954361, 52.86331817507744, 45.69077745079994, 43.29762406647205, 42.71544970571995, 41.43382027745247, 40.0366048514843, 39.558791890740395, 38.6427978426218, 39.831628650426865, 38.06479185819626, 39.117950946092606, 39.29049588739872, 41.17321506142616, 39.81006860733032, 39.36386235058308, 40.06423316895962, 41.39526754617691, 45.43792001903057, 52.07204483449459, 54.40271057188511, 55.14761880040169, 49.88612473011017, 52.00031228363514, 51.66059531271458, 49.63479481637478, 47.34079331159592, 43.408741503953934, 41.56091205775738, 36.995685026049614, 38.47987778484821, 39.62138973176479, 38.67450714111328, 38.71938653290272, 39.309168085455894, 41.35453373193741, 40.17370909452438, 40.00785939395428, 37.56658159196377, 41.98896288871765, 46.4917516708374, 49.333835765719414, 52.35788069665432, 50.0694876909256, 48.383320569992065, 53.23610097169876, 53.19804601371288, 53.34068275988102, 48.65448921918869, 50.99644415080547, 49.18791599571705, 51.29749819636345, 50.30266597867012, 55.04329539835453, 45.13966262340546, 28.05107519030571, 52.109864205121994, 47.73940712213516, 50.84661819040775, 51.67443796992302, 50.096299052238464, 51.032728403806686, 51.895475909113884, 47.91294381022453, 43.94574388861656, 38.42895671725273, 40.78198425471783, 38.181703984737396, 38.703864365816116, 37.34921805560589, 39.160303473472595, 37.3212743550539, 39.41998153924942, 40.132781490683556, 40.20728789269924, 39.75282467901707, 40.72230465710163, 41.49522118270397, 40.273799523711205, 38.878343403339386, 41.0661406069994, 44.87282574176788, 49.71074514091015, 49.82882380485535, 53.10389846563339, 52.15038143098354, 52.89695397019386, 47.65812188386917, 47.012532725930214, 41.65358908474445, 40.715138241648674, 39.658760726451874, 47.66871951520443, 52.81981810927391, 54.52710449695587, 54.24999676644802, 51.15546941757202, 51.573693975806236, 50.256004482507706, 50.66102094948292, 53.62427294254303, 56.70378729701042, 54.91631381213665, 54.85868610441685, 57.05968379974365, 56.48136243224144, 54.59834307432175, 52.13931642472744, 54.28750455379486, 53.206587955355644, 59.93791155517101, 52.7448633313179, 50.05257859826088, 52.063970267772675, 59.73401829600334, 14.734870232641697, 0.13311073154909536, 4.366116290912032, 1.6098781395703554, 0.09430464589968324, 0.16944853792665526, 10.792728066444397, 57.46761091053486, 45.183660462498665, 38.94917160272598, 21.582385897636414, 18.880660571157932, 34.55949515104294, 46.96339376270771, 55.11364862322807, 23.117826506495476, 0.34515967417974025, 0.03951401660742704, 0.023907712238724343, 0.03516709810355678, 0.04678504519688431, 0.11711335988366045, 0.0671396660618484, 0.07775961377774365, 0.05504245113115758, 0.010060653166874545, 0.026958911403198726, 0.021596278456854634, 0.09148697092314251, 0.019469995677354746, 0.06776960100978613, 0.016541213772143237, 0.04668933412176557, 0.029430122158373706, 0.023119959587347694, 0.035709274088731036, 0.06914160199812613, 0.08026874085771851, 0.06619301959290169, 3.6285362066701055, 56.80906444787979, 59.0188966691494, 52.003447115421295, 31.868939325213432, 20.580180175602436, 44.96958374977112, 50.45140139758587, 39.54174980521202, 66.6302302479744, 33.974090963602066, 0.17040271719451994, 0.11356132235960104, 1.4255000394769013, 1.2467957474291325, 10.927757620811462, 42.07765772938728, 44.900165274739265, 55.016537234187126, 59.779281467199326, 60.53889110684395, 59.339143484830856, 58.72857324779034, 55.26996083557606, 48.85880045592785, 46.437669172883034, 45.41584700345993, 42.37009383738041, 42.404588386416435, 40.557982474565506, 41.519311890006065, 40.70331707596779, 39.57446224987507, 40.48098720610142, 41.81222677230835, 41.912423595786095, 41.499640345573425, 41.00768834352493, 41.66564203798771, 44.09710116684437, 47.06411115825176, 51.41640141606331, 54.97349314391613, 55.33206470310688, 50.18237203359604, 53.65301840007305, 53.01491104066372, 51.9920439273119, 50.560774728655815, 47.74851143360138, 43.534146174788475, 39.67945821583271, 38.99267926812172, 40.10547615587711, 40.890973806381226, 40.94002537429333, 41.55215732753277, 41.640890166163445, 40.78652881085873, 42.03454904258251, 40.357056856155396, 44.70510274171829, 46.66538715362549, 49.49535369873047, 53.178290873765945, 51.62735469639301, 50.6098110973835, 54.53991740942001, 54.618466794490814, 57.08567060530186, 51.51440195739269, 53.93092408776283, 52.67126128077507, 52.742207273840904, 53.117114156484604, 55.820399299263954, 45.402414724230766, 28.76087710261345, 51.76263123750687, 50.74483685195446, 50.52418269217014, 51.009051874279976, 50.0363040715456, 53.61295334994793, 53.645046427845955, 51.865301728248596, 47.14918099343777, 43.83159041404724, 43.51669371128082, 41.293208822607994, 39.345596730709076, 39.54290114343166, 41.184990629553795, 40.6116583943367, 41.308601796627045, 42.09466181695461, 41.557727828621864, 41.30380265414715, 43.37771236896515, 43.94633665680885, 41.765899658203125, 40.03063917160034, 44.15882885456085, 47.2723513841629, 52.54356533288956, 52.146490439772606, 53.377947360277176, 52.466832250356674, 54.96234454214573, 50.14316953718662, 47.60218508541584, 43.50287765264511, 42.860126942396164, 42.17881590127945, 48.894590735435486, 53.51553417742252, 57.3525682836771, 54.60209347307682, 54.06886048614979, 51.26271866261959, 52.23051533102989, 53.64740610122681, 55.20599126815796, 58.00658158957958, 55.1766112446785, 56.79917357861996, 59.40437078475952, 57.82610647380352, 56.45897403359413, 53.903253972530365, 55.748058781027794, 57.03337401151657, 61.31167843937874, 53.30538645386696, 54.000684544444084, 50.8678362518549, 59.19872961938381, 16.540651135146618, 1.7841693246737123, 6.829593926668167, 5.291753271594644, 0.5887069227173924, 0.056288739724550396, 11.836298368871212, 62.91127100586891, 50.531326308846474, 39.11930747330189, 24.23966120928526, 24.338300116360188, 41.19990862905979, 54.37896944582462, 62.245136350393295, 29.37016110867262, 0.6451534281950444, 0.030315131407405715, 0.003752462389456923, 0.05936824811215047, 0.052417946062632836, 0.07346475322265178, 0.022358592141245026, 0.04200604460493196, 0.04352579977421556, 0.03522597638948355, 0.034745183438644744, 0.044612240890273824, 0.1882758893771097, 0.14229914319003, 0.16986559523502365, 0.20412210782524198, 0.1817434758413583, 0.13429368525976315, 0.07544426887761801, 0.06647669812082313, 0.20288073224946856, 0.14998840168118477, 0.27442863676697016, 6.56970402225852, 65.37133499979973, 66.38993874192238, 58.65471661090851, 38.48819553852081, 22.018366903066635, 51.189439594745636, 67.28456273674965, 45.67235603928566, 70.67151859402657, 37.45908536016941, 0.3478591324528679, 0.3205542132491246, 4.5833625085651875, 4.012786075472832, 12.142788022756577, 41.15053407847881, 49.62952449917793, 55.57107947766781, 60.988707169890404, 62.1850273758173, 63.09197410941124, 60.61403587460518, 58.619503900408745, 48.67794916033745, 48.117129653692245, 47.88821093738079, 45.21420702338219, 43.956181928515434, 43.72741520404816, 42.05892093479633, 43.208777233958244, 40.45812003314495, 41.476066410541534, 43.71277838945389, 44.8598912358284, 43.81765276193619, 43.2935506850481, 42.47735068202019, 47.62760192155838, 49.32165741920471, 56.832649782299995, 59.9444206058979, 57.00757339596748, 52.47274473309517, 56.71791113913059, 55.997101217508316, 54.7854982316494, 52.232362031936646, 48.6589577794075, 46.871985867619514, 40.454521626234055, 41.62631794810295, 43.22411701083183, 42.954479679465294, 42.010446935892105, 43.41507576406002, 45.15791304409504, 43.02330158650875, 44.74550597369671, 41.870903223752975, 47.11543880403042, 49.608302637934685, 52.10207462310791, 54.468899220228195, 53.58676515519619, 51.508075296878815, 55.947783663868904, 55.70160627365112, 58.0315500497818, 54.075753316283226, 55.21919935941696, 55.622863098978996, 55.48421233892441, 55.720354467630386, 58.00832189619541, 49.419030994176865, 31.32307581603527, 52.70606741309166, 51.06100268661976, 53.832106590270996, 54.32205989956856, 52.333429008722305, 56.77702076733112, 55.43711766600609, 51.63496948778629, 48.00384633243084, 45.093080922961235, 44.29712623357773, 43.375462889671326, 42.91991673409939, 42.297285944223404, 43.45590837299824, 43.37445214390755, 44.13551330566406, 44.729364439845085, 44.574796333909035, 42.775611877441406, 45.250958651304245, 45.143887996673584, 43.128453344106674, 43.158836513757706, 46.96056291460991, 47.186293601989746, 54.84298534691334, 53.8947918266058, 56.88003323972225, 54.33592915534973, 55.330130606889725, 51.59520082175732, 50.47114513814449, 45.999195501208305, 44.63520169258118, 43.76699388027191, 52.13083527982235, 56.70491963624954, 57.953665629029274, 56.52662180364132, 56.31515175104141, 55.43843999505043, 55.81189915537834, 56.034445613622665, 57.267274260520935, 60.78263662755489, 56.72870256006718, 60.0534063577652, 62.268717885017395, 60.50267145037651, 58.575840443372726, 56.575984954833984, 58.19815970957279, 58.699322417378426, 64.0876878798008, 55.0009922683239, 54.43386510014534, 53.159793466329575, 59.87726680934429, 18.046175949275494, 2.173311193473637, 13.908930402249098, 5.111860949546099, 0.5046833970118314, 0.3245198348304257, 15.153093840926886, 68.08464780449867, 60.18140248954296, 52.68335223197937, 32.428060322999954, 30.26559256017208, 47.590234726667404, 62.086768448352814, 73.21890950202942, 38.24422962963581, 1.4972984930500388, 0.1835409426712431, 0.12279612565180287, 0.2009593416005373, 0.11103704804554582, 0.23608669027453288, 0.18488998903194442, 0.18180393119109794, 0.11935716916923411, 0.18858532042941079, 0.12940777087351307, 0.13950546184787527], [0.013567613568739034, 0.06123450461018365, 0.11491859913803637, 0.060753114230465144, 0.05096992688777391, 0.01581762535352027, 0.0489670781098539, 0.07532202973379754, 0.08484127596602775, 0.04953908843162935, 0.07366344099864364, 5.766943423077464, 53.34316402673721, 55.226491168141365, 44.1704448312521, 35.706904381513596, 26.64789218455553, 47.81465448439121, 56.167043298482895, 38.9743946492672, 65.92049673199654, 20.091674588620663, 0.11772854093578644, 0.0556093332124874, 1.6365661262534559, 1.5390738076530397, 20.17328280955553, 38.02211634814739, 53.31377640366554, 56.096880063414574, 54.68327611684799, 57.60294444859028, 55.71690425276756, 55.410393700003624, 48.22491466999054, 41.27598434686661, 41.23981028795242, 40.576221495866776, 44.2900700122118, 44.29578870534897, 41.631158888339996, 40.8683118224144, 38.49370524287224, 39.588874876499176, 39.14860010147095, 40.13571873307228, 39.60134960711002, 38.21426823735237, 39.173705354332924, 39.920331090688705, 39.17273260653019, 41.71944335103035, 46.73035606741905, 51.35037235915661, 53.85437339544296, 53.76585714519024, 49.49343480169773, 53.24731037020683, 51.93121299147606, 49.88108240067959, 44.047688618302345, 37.71107263863087, 38.727719485759735, 37.13972769677639, 38.86142671108246, 39.42794971168041, 41.00369855761528, 39.37675125896931, 40.12648142874241, 39.56920713186264, 38.7758819013834, 38.349537178874016, 39.739943370223045, 44.39201854169369, 46.5118183940649, 49.14951905608177, 53.854882568120956, 46.84381037950516, 50.00625528395176, 50.90092487633228, 51.13854892551899, 51.458579152822495, 53.299439772963524, 50.4973067343235, 52.79903322458267, 48.48585046827793, 54.29896093904972, 43.926091343164444, 27.437470816075802, 56.49150788784027, 52.085306122899055, 52.63702131807804, 51.470130532979965, 49.52600285410881, 49.35829125344753, 50.47241427004337, 51.866646856069565, 45.3105204552412, 41.78075686097145, 40.87857127189636, 38.30065280199051, 39.298448860645294, 37.074937373399734, 39.00982014834881, 37.67816260457039, 38.49557854235172, 39.88596573472023, 40.77728770673275, 40.32050281763077, 40.08528783917427, 38.39113734662533, 40.98378002643585, 39.68986205756664, 39.308096542954445, 42.42018274962902, 50.412115305662155, 51.21945798397064, 52.831612676382065, 49.5978569984436, 52.15726666152477, 50.986815467476845, 45.72303391993046, 39.547525495290756, 41.075932681560516, 41.72734692692757, 46.99154645204544, 51.44773453474045, 55.17831735312939, 52.131561040878296, 53.69950130581856, 53.21793794631958, 52.409242540597916, 50.825635716319084, 55.82523263990879, 54.08569358289242, 55.41901923716068, 54.47443172335625, 54.521036222577095, 52.0734241604805, 47.90276415646076, 45.777895376086235, 54.335913956165314, 57.81162545084953, 59.79012608528137, 56.22443921864033, 48.96565832197666, 54.89581011235714, 62.96656183898449, 16.879180669784546, 1.3894992275163531, 5.974801294505596, 7.206804910674691, 0.43448836833704263, 0.1200258664903231, 3.144665895961225, 50.000840574502945, 47.880626544356346, 40.350186824798584, 29.698516689240932, 14.659864157438278, 29.554097838699818, 42.69561477005482, 54.07760001718998, 31.52884617447853, 1.7920178035274148, 0.08542153154849075, 0.09106097073527053, 0.031939167602104135, 0.13327243068488315, 0.057182344899047166, 0.041865370512823574, 0.03813036390056368, 0.05096864668303169, 0.0759916621609591, 0.018288895480509382, 0.028311635105637833, 0.02510262009309372, 0.04912126671115402, 0.07381612304016016, 0.07427071817801334, 0.034544506706879474, 0.026814879092853516, 0.04151639041083399, 0.01892641703307163, 0.06932131305802613, 0.11110571154858917, 0.1146507506200578, 8.56278257444501, 62.108997255563736, 59.45476368069649, 49.91729065775871, 39.31509956717491, 33.197709023952484, 50.73636710643768, 54.402311593294144, 41.922303065657616, 70.93461647629738, 23.806870132684708, 0.08585979201598093, 0.01888038717879681, 1.3269951939582825, 1.4885303447954357, 21.510425359010696, 40.605050548911095, 54.68644514679909, 57.69777975976467, 56.57946556806564, 59.57925260066986, 56.664497405290604, 56.8622387945652, 50.805116817355156, 43.85840177536011, 43.33202742040157, 41.76409475505352, 45.83561807870865, 43.621347695589066, 43.358242213726044, 42.45713956654072, 41.358964294195175, 41.95779696106911, 40.19495755434036, 42.34954833984375, 41.13828353583813, 39.540750458836555, 42.14703820645809, 40.982795879244804, 42.15308368206024, 43.965297639369965, 48.25798809528351, 54.245858788490295, 55.43619051575661, 54.3879559636116, 51.12283676862717, 54.25121270120144, 54.688071459531784, 50.33871844410896, 44.567576721310616, 41.22930385172367, 39.43457655608654, 40.23196756839752, 40.65216422080994, 41.091470047831535, 40.28049096465111, 42.186863869428635, 42.15681508183479, 41.01334623992443, 42.09760665893555, 40.21379314363003, 43.03258068859577, 45.93914732336998, 49.44869600236416, 51.92236706614494, 53.528373688459396, 49.631773978471756, 53.69366101920605, 52.14003838598728, 56.410560831427574, 54.232171922922134, 55.063700303435326, 51.678936928510666, 55.99067576229572, 49.85344648361206, 58.00708696246147, 45.821038261055946, 30.142747052013874, 56.343023255467415, 52.79833406209946, 53.77094127237797, 51.20382942259312, 51.52447521686554, 51.157118529081345, 52.94988892972469, 52.60313093662262, 46.87328539788723, 43.47221329808235, 42.295545637607574, 40.039158314466476, 42.34339267015457, 39.67099606990814, 42.05882973968983, 40.48550136387348, 40.55379129946232, 40.31938187777996, 43.77930521965027, 42.64056332409382, 41.698704063892365, 41.00618362426758, 42.44396947324276, 42.7899295091629, 39.42020572721958, 44.142368137836456, 51.24759167432785, 53.26664373278618, 53.120682165026665, 50.70857159793377, 53.95450562238693, 53.209297209978104, 49.66466121375561, 41.618535965681076, 42.67663858830929, 43.949023112654686, 48.90219412744045, 53.22332225739956, 55.40059022605419, 54.200667813420296, 54.651627615094185, 55.061272233724594, 55.20287163555622, 52.581654489040375, 58.089591935276985, 55.504970625042915, 55.67362077534199, 57.065147906541824, 55.27667127549648, 54.748989790678024, 51.427751407027245, 46.858181208372116, 55.73972202837467, 58.737232983112335, 61.708783730864525, 56.92933939397335, 50.31371958553791, 56.93860709667206, 63.86491343379021, 18.67037795484066, 2.8701270651072264, 10.18444150686264, 9.719241969287395, 0.5785781505983323, 0.34693334775511175, 3.7328332476317883, 55.18302530050278, 54.38921369612217, 44.98756818473339, 33.1182324886322, 22.41499911993742, 36.618703454732895, 50.46869046986103, 61.11903637647629, 41.868338361382484, 2.9366522328928113, 0.07592411187943071, 0.085750310390722, 0.03550252287823241, 0.07615231486852281, 0.039811476817703806, 0.0433129258453846, 0.01763590200425824, 0.06592399106011726, 0.0641263832221739, 0.03508828944177367, 0.0518845311307814, 0.15799252374563366, 0.17821898683905602, 0.26916841277852654, 0.2395303890807554, 0.21977167198201641, 0.16308950493112206, 0.15906808868749067, 0.19108701118966565, 0.21700016601243988, 0.190267828584183, 0.25606024428270757, 11.579274460673332, 71.88216403126717, 67.8291343152523, 58.911077454686165, 46.65834613144398, 37.66192987561226, 53.85719284415245, 65.16341775655746, 50.77425107359886, 77.11836665868759, 26.554339304566383, 0.21725924976635724, 0.17805635259719566, 4.796277433633804, 3.9381250692531466, 22.328386567533016, 45.10401293635368, 57.89436601102352, 58.27143877744675, 59.5721697807312, 62.105600237846375, 59.2313926666975, 59.27549310028553, 53.171945214271545, 46.23083487153053, 45.07593244314194, 45.35303257405758, 47.0752065628767, 45.228372663259506, 45.19102066755295, 43.62321339547634, 43.16373445093632, 44.013995826244354, 42.11465634405613, 44.662100449204445, 42.73322895169258, 41.3005044311285, 42.19053067266941, 43.325168788433075, 43.64709131419659, 45.18333747982979, 51.78976558148861, 57.07583673298359, 58.70349079370499, 57.587695866823196, 50.25519132614136, 57.89574533700943, 57.4612994492054, 54.24137502908707, 48.543614968657494, 42.92974300682545, 42.21242129802704, 40.581898391246796, 41.93505898118019, 43.77104826271534, 43.505583107471466, 42.651803120970726, 44.495946764945984, 44.54019919037819, 42.1663373708725, 42.366985604166985, 44.630227759480476, 47.77598775923252, 52.091883569955826, 53.91887493431568, 54.084739834070206, 50.10244332253933, 55.320878103375435, 54.16822515428066, 55.4266682267189, 55.34159459173679, 57.75666519999504, 53.24029974639416, 56.997078359127045, 53.836119174957275, 59.32401269674301, 48.00686337053776, 33.442548885941505, 58.992396891117096, 55.52016980946064, 53.20315293967724, 53.82075659930706, 51.937342062592506, 52.63635255396366, 54.26044620573521, 55.56119620800018, 49.326684549450874, 47.58565217256546, 44.595573619008064, 42.96163849532604, 43.87656860053539, 41.55614711344242, 43.19318287074566, 41.835728511214256, 42.41108983755112, 42.47829683125019, 44.71545718610287, 45.25361850857735, 44.950740560889244, 42.29290097951889, 43.65942545235157, 44.42109078168869, 42.203997150063515, 48.59054245054722, 55.80478593707085, 54.97663177549839, 56.17415651679039, 52.346652299165726, 54.6990604698658, 56.30031734704971, 51.76684521138668, 41.97993077337742, 45.26646941900253, 45.16409911215305, 52.392990812659264, 55.682451501488686, 57.85144351422787, 56.54114082455635, 56.53175912797451, 57.13088057935238, 57.24379912018776, 54.06101010739803, 59.33054454624653, 57.70619250833988, 58.84975254535675, 59.04758132994175, 58.09428088366985, 56.46861031651497, 53.28471556305885, 49.07203361392021, 58.05242232978344, 62.322055622935295, 63.784038573503494, 59.64464329183102, 52.26072371006012, 59.552897214889526, 61.824384927749634, 20.44345211237669, 4.0606654062867165, 13.575984667986631, 17.939715161919594, 1.7675427231006324, 0.36717821611091495, 4.979037651792169, 62.53988653421402, 60.14933981001377, 55.22487245500088, 40.66805496811867, 26.787929870188236, 44.37442548573017, 61.379394605755806, 68.55422660708427, 52.18839459121227, 4.856803910806775, 0.19857928884448484, 0.2562379144364968, 0.11845224624266848, 0.2990653569577262, 0.18307981663383543, 0.13917934731580317, 0.17029666429152712, 0.1299337309319526, 0.34213096951134503, 0.10455230265506543, 0.10908779717283323], [0.017123591896961443, 0.06112333830969874, 0.0013777795356872957, 0.06933202224900015, 0.03416083491174504, 0.044086848574806936, 0.02113005943101598, 0.017801488138502464, 0.01829398846894037, 0.043667041609296575, 0.029869460595364217, 9.14022333920002, 55.62720626592636, 48.02343048155308, 44.448852092027664, 26.037728525698185, 29.536677673459053, 54.02013190090656, 50.532648637890816, 42.307670786976814, 62.014112547039986, 19.313459247350693, 0.10909829856245779, 0.0346290670131566, 0.21311074815457687, 2.5234450679272413, 24.1083250567317, 49.57532800734043, 57.08547681570053, 54.10379201173782, 58.02979074418545, 55.20533010363579, 54.55884039402008, 45.971935763955116, 42.49264866113663, 39.178234711289406, 43.86178359389305, 48.933531045913696, 49.76285554468632, 47.84666396677494, 43.21650981903076, 39.62647385895252, 38.02256092429161, 40.20981475710869, 39.84413757920265, 39.89235699176788, 42.687851786613464, 40.45648992061615, 43.40390056371689, 40.78466311097145, 39.94311086833477, 41.19526527822018, 42.32974760234356, 46.36928044259548, 51.12287096679211, 52.55118392407894, 51.860943362116814, 50.13454779982567, 52.24631868302822, 50.70168636739254, 48.21670711040497, 39.75890815258026, 37.02067248523235, 38.09821106493473, 40.580268278717995, 38.9902587980032, 39.436449855566025, 38.681791350245476, 41.525999531149864, 38.626481518149376, 39.96142968535423, 37.634031772613525, 38.16159166395664, 42.14193508028984, 46.406902223825455, 48.42771738767624, 49.9713921546936, 48.97171139717102, 52.15006224811077, 51.16761736571789, 50.33435247838497, 51.30736626684666, 51.004385724663734, 49.747048392891884, 50.98760202527046, 48.81076343357563, 51.85824550688267, 45.495110750198364, 33.00384722650051, 53.363489136099815, 48.63794110715389, 50.51513157784939, 54.277062714099884, 53.2365645468235, 50.910238176584244, 52.68932931125164, 50.756836608052254, 45.44218719005585, 41.11477039754391, 42.36282862722874, 42.745323702692986, 40.89440122246742, 41.74810141324997, 40.88451035320759, 36.88633069396019, 40.348936691880226, 41.76189087331295, 41.23033359646797, 41.05501860380173, 40.15332318842411, 38.35169546306133, 38.23516711592674, 41.07769198715687, 38.37238535284996, 42.6968003064394, 48.55544373393059, 52.63105943799019, 49.826087951660156, 50.571425557136536, 52.649211063981056, 48.714073821902275, 45.86080692708492, 41.05760246515274, 41.492394134402275, 39.78298746049404, 44.22743797302246, 47.9727678000927, 54.28349956870079, 53.19751784205437, 55.64479172229767, 52.74496212601662, 57.169311717152596, 53.024855107069016, 54.095808640122414, 50.686023607850075, 56.423373743891716, 55.29913567006588, 53.883506432175636, 44.624421671032906, 45.58141551911831, 49.903075620532036, 58.46289150416851, 52.84419000148773, 60.250847563147545, 54.693972542881966, 51.501060873270035, 43.21117490530014, 62.487247958779335, 25.782435424625874, 2.2220300417393446, 5.199383553117514, 6.7233198042958975, 0.7362539554014802, 0.044302130772848614, 1.2849411880597472, 43.37257884442806, 54.5091200619936, 38.64461414515972, 35.17306722700596, 17.602487057447433, 27.627052143216133, 42.292194217443466, 52.41335391998291, 38.87555815279484, 5.216184826567769, 0.25999508157838136, 0.05042967306508217, 0.02198802296334179, 0.011022749295079848, 0.08255457054474391, 0.04241489375999663, 0.02971995680127293, 0.06329197916784324, 0.08551096776500344, 0.04339279206760693, 0.005282978700051899, 0.05416043830337003, 0.014697686474391958, 0.02203166310209781, 0.04668877008953132, 0.048205185594270006, 0.02750092597125331, 0.06198203285748605, 0.03762198532058392, 0.07389398917439394, 0.10457055948791094, 0.032910223308135755, 13.076108191162348, 63.63078139722347, 56.20097927749157, 50.493769124150276, 32.01422452926636, 32.86058351397514, 49.747880548238754, 51.67122334241867, 45.50259254872799, 68.8055071234703, 18.55320744216442, 0.13053212460363284, 0.2158650808269158, 1.1471236520446837, 3.1375061301514506, 26.922851130366325, 52.01513148844242, 58.70865471661091, 58.00984561443329, 59.81637887656689, 57.6176268607378, 56.90049894154072, 48.69919002056122, 44.174335822463036, 41.794713512063026, 46.3692956417799, 50.63681624829769, 51.040419191122055, 49.99027334153652, 45.500985234975815, 42.76537902653217, 39.87406097352505, 41.133427396416664, 41.35645642876625, 42.29684516787529, 43.87195564806461, 43.63743223249912, 44.18708793818951, 43.15301522612572, 42.00903721153736, 41.45521692931652, 43.9848817884922, 49.54699672758579, 52.54995658993721, 55.63955940306187, 54.5105791836977, 53.417898416519165, 53.97160850465298, 51.76526829600334, 50.51680728793144, 41.8481120467186, 38.4837231785059, 39.68334920704365, 41.08520798385143, 40.44213809072971, 42.326175794005394, 40.2437811344862, 43.44185292720795, 39.91847299039364, 42.279347106814384, 39.125702530145645, 40.123897567391396, 43.89397546648979, 47.807427272200584, 49.257843643426895, 53.16274210810661, 51.6492073237896, 52.13549762964249, 52.103442549705505, 54.31098349392414, 52.61013776063919, 52.806024849414825, 50.34133270382881, 53.40192027390003, 51.31735973060131, 54.13509853184223, 46.01292036473751, 33.8117902725935, 57.62212581932545, 51.34972259402275, 53.02096791565418, 55.66303074359894, 54.412498846650124, 51.965673342347145, 55.01365318894386, 52.44168899953365, 47.72581525146961, 42.96239845454693, 43.786942809820175, 43.405226692557335, 43.006179705262184, 43.18591006100178, 43.192339316010475, 39.05512131750584, 41.52018204331398, 42.089896872639656, 42.847454622387886, 43.59900489449501, 41.61388501524925, 40.265610963106155, 40.758520513772964, 41.092199608683586, 41.26590348780155, 44.21858064830303, 50.86092062294483, 54.78159584105015, 50.111426040530205, 51.64646007120609, 54.71485622227192, 51.73177309334278, 48.52768622338772, 44.36073862016201, 43.30072470009327, 42.78124317526817, 46.14275939762592, 49.582749009132385, 56.29890002310276, 54.284206330776215, 55.52743881940842, 56.05019196867943, 59.403952807188034, 54.44436393678188, 55.494927763938904, 51.795765459537506, 58.96052040159702, 57.61921137571335, 56.379991471767426, 47.4556877464056, 46.942791268229485, 52.58121371269226, 59.160435274243355, 55.44800408184528, 61.240793243050575, 57.68804468214512, 55.73164366185665, 48.84321369230747, 61.25358335673809, 28.317767679691315, 1.4410243439488113, 8.333646319806576, 7.309571821242571, 1.5514102019369602, 0.16120991203933954, 1.3244901783764362, 46.61488026380539, 60.494330897927284, 43.01360450685024, 35.75506679713726, 23.607177548110485, 33.83823685348034, 48.58457297086716, 59.843843802809715, 46.40564829111099, 7.880230899900198, 0.21305044123437256, 0.013255850317364093, 0.07575472409371287, 0.023613534176547546, 0.06154322320071515, 0.007914548550616018, 0.04345597109931987, 0.04331331547291484, 0.05001927653211169, 0.03810989175690338, 0.02220030131866224, 0.14850041043246165, 0.25451583496760577, 0.1470162338227965, 0.16298710339469835, 0.11770784985856153, 0.1027501306089107, 0.10107911832164973, 0.15969055762980133, 0.1430875711957924, 0.19348226313013583, 0.1443833313533105, 17.476654909551144, 73.42123344540596, 62.418722435832024, 59.90673802793026, 37.46856205165386, 37.957265228033066, 59.67382572591305, 62.19056747853756, 52.690834030508995, 74.09046873450279, 22.685945481061935, 0.13664126163348556, 0.4184192977845669, 1.3636234472505748, 3.733758023008704, 27.823134921491146, 52.26452350616455, 63.50032679736614, 60.09589567780495, 61.79075673222542, 59.295168444514275, 58.937402442097664, 50.31403496861458, 46.889214143157005, 44.330575838685036, 47.69462652504444, 52.30857074260712, 55.3405686467886, 51.55605912208557, 48.04361119866371, 43.86078044772148, 43.04499842226505, 43.080347925424576, 43.0900602042675, 44.424035623669624, 46.89482644200325, 46.11139588057995, 46.96113668382168, 44.14164997637272, 44.580568224191666, 45.902749076485634, 45.79216741025448, 50.03258787095547, 55.37807643413544, 59.095599353313446, 56.379527896642685, 54.58404824137688, 55.83272963762283, 53.68237942457199, 52.99295961856842, 44.060353338718414, 39.66335088014603, 42.45753854513168, 42.172527238726616, 41.262080892920494, 44.06193785369396, 41.99884615838528, 46.859533935785294, 41.53095066547394, 43.8085712492466, 41.41924045979977, 43.04319731891155, 45.6598699092865, 48.48823294043541, 53.19692127406597, 55.170691162347794, 50.4689222574234, 53.48107762634754, 53.606945872306824, 55.27383662760258, 55.81013984978199, 55.825665816664696, 52.52820275723934, 54.10543352365494, 54.02688793838024, 56.548083052039146, 48.024277836084366, 38.50352771580219, 59.268885254859924, 53.873163387179375, 54.13996987044811, 58.65578435361385, 56.42563462257385, 53.35163377225399, 57.72393375635147, 54.977699518203735, 49.51233118772507, 46.8078301101923, 46.879171282052994, 48.802286088466644, 45.517046973109245, 45.81274330615997, 44.5444967597723, 40.31021296977997, 44.875261411070824, 45.202458053827286, 44.8097263276577, 45.69359689950943, 44.56274718046188, 42.22247555851936, 43.1302734464407, 44.385790675878525, 41.114622205495834, 46.78659304976463, 52.012365236878395, 57.13409140706062, 51.8667646497488, 53.07126581668854, 57.73694425821304, 52.82919600605965, 51.54349699616432, 47.30803906917572, 47.32704184949398, 45.330286994576454, 48.48550468683243, 51.64612948894501, 58.964920565485954, 57.91101671755314, 57.21083588898182, 58.69293875992298, 61.837505623698235, 56.042265594005585, 55.848973765969276, 53.35208974778652, 60.7708078622818, 61.45667105913162, 58.279361352324486, 47.61328428983688, 50.00977389514446, 54.94140386581421, 61.28648579120636, 57.919665053486824, 62.68658526241779, 59.71513710916042, 57.45792143046856, 50.89169517159462, 65.46471118927002, 29.43878922611475, 5.398309528827667, 14.94505025446415, 10.126560162752867, 1.9060769956558943, 0.2923590433783829, 1.950111526530236, 53.55955481529236, 66.657505184412, 51.8467853218317, 45.39726220071316, 28.8652366027236, 42.06329070031643, 57.37457290291786, 68.27773824334145, 59.09120298922062, 11.033441349864006, 0.34468072175513953, 0.1685655751498416, 0.11536220306879841, 0.0884625558683183, 0.2158494363538921, 0.1324664434650913, 0.13280529325129464, 0.11706300516379997, 0.1929875326459296, 0.15908826026134193, 0.1039396745909471], [0.030813993798801675, 0.00579499380364723, 0.02767894864518894, 0.07736295810900629, 0.0378085167176323, 0.06335274621960707, 0.0008763216567331256, 0.04830067031434737, 0.06336463542538695, 0.043337984461686574, 0.0758847409451846, 15.3230444714427, 57.244695872068405, 46.36769212782383, 41.869333907961845, 20.88161990046501, 28.372581638395786, 73.76218914985657, 45.98297797143459, 42.255799770355225, 60.17077066004276, 15.165332034230232, 0.10003541377955116, 0.24387811281485483, 0.5297098041046411, 3.874029158614576, 30.54576102644205, 54.14771005511284, 57.49270096421242, 55.09831644594669, 53.54205295443535, 52.54842907190323, 42.783173471689224, 41.65676571428776, 40.0991190969944, 47.744605243206024, 53.40409755706787, 53.66904214024544, 55.929176062345505, 53.50049078464508, 47.43597820401192, 44.72851328551769, 40.13460159301758, 41.294846534729004, 41.736033260822296, 44.28768754005432, 46.97006620466709, 44.789321422576904, 44.78933282196522, 46.28306686878204, 43.257467821240425, 43.10996733605862, 40.05053870379925, 37.866564095020294, 43.10531258583069, 49.20496188104153, 51.49629592895508, 50.33279836177826, 50.59937685728073, 50.54383143782616, 50.03238648176193, 41.105962470173836, 37.85562448203564, 38.67862991988659, 40.27745492756367, 40.496034398674965, 38.10348518192768, 38.68037402629852, 40.532546639442444, 39.681871086359024, 38.99662345647812, 38.78168039023876, 37.142193764448166, 40.50587207078934, 44.81878504157066, 49.9912840873003, 49.00704190135002, 49.12434920668602, 50.86024805903435, 51.44053392112255, 55.22621378302574, 53.38094919919968, 53.95490080118179, 51.3743756711483, 51.696043610572815, 48.84732887148857, 52.69291631877422, 50.13204373419285, 34.913484156131744, 51.3393035531044, 48.45025397837162, 49.712747633457184, 49.55524608492851, 53.782583847641945, 50.13387143611908, 51.346663758158684, 48.080803602933884, 45.51152586936951, 41.62074364721775, 43.33584241569042, 45.342009365558624, 45.6193982809782, 43.97941768169403, 42.079382836818695, 39.7954735904932, 38.06056268513203, 39.65327002108097, 42.20598444342613, 40.98264388740063, 40.42364828288555, 39.825043603777885, 39.44350987672806, 38.724615052342415, 39.221529588103294, 39.263239949941635, 49.06056962907314, 52.43112936615944, 50.12904949486256, 51.40450045466423, 50.38777381181717, 52.65648007392883, 45.82754351198673, 39.59705203771591, 39.367738142609596, 40.37955164909363, 42.641650065779686, 43.35299849510193, 50.87776891887188, 49.9143648147583, 51.66491948068142, 53.313065841794014, 52.217637822031975, 48.6949722468853, 49.677633717656136, 55.66656835377216, 55.575612634420395, 53.106577321887016, 47.25921168923378, 44.33287471532822, 53.6738982796669, 57.20983274281025, 55.91883301734924, 58.9042454212904, 54.87868443131447, 56.76081843674183, 51.13316461443901, 41.14412762224674, 53.758599534630775, 43.22124816477299, 3.6345771700143814, 15.517848618328571, 16.807782500982285, 1.2569388281553984, 0.22522047569509596, 0.25544518197420985, 35.69971516728401, 58.39183911681175, 44.499575570225716, 46.90371036529541, 22.182974070310593, 23.18273462355137, 39.57881301641464, 46.46410435438156, 52.503192499279976, 11.136736907064915, 0.36313745949883014, 0.06255421016248874, 0.025779382704058662, 0.020703584268630948, 0.07381035655271262, 0.05955486114544328, 0.04197233996819705, 0.11342717916704714, 0.133444519888144, 0.02191370429500239, 0.028619487238756847, 0.05025962476793211, 0.026671583364077378, 0.027210237858525943, 0.02776565004751319, 0.06293806378380395, 0.08952091040555388, 0.022037796952645294, 0.01746003341395408, 0.015269322011590702, 0.02894364806707017, 0.025443273298151325, 20.46551562845707, 65.08261889219284, 54.67311166226864, 47.763969004154205, 27.91878528892994, 28.361045457422733, 67.48118698596954, 53.20957079529762, 46.88041001558304, 66.22546076774597, 15.24086818099022, 0.28673834342043847, 0.2956536744022742, 0.8798455190844834, 3.692123657092452, 32.89331495761871, 56.1283765733242, 59.975464940071106, 57.64771744608879, 56.270941123366356, 54.706808254122734, 46.670984253287315, 43.25140714645386, 42.510439306497574, 48.05635951459408, 54.329853281378746, 54.157182946801186, 57.18513786792755, 54.78805169463158, 49.485215842723846, 45.4863940179348, 40.94217985868454, 43.32508899271488, 43.77512164413929, 45.871879532933235, 48.234490156173706, 46.83600939810276, 47.68808327615261, 46.79163537919521, 45.18404424190521, 43.95936615765095, 42.084835544228554, 40.40570184588432, 45.52759140729904, 51.1404450237751, 53.88503775000572, 52.22123242914677, 50.746900141239166, 52.852123975753784, 52.67785772681236, 43.37544769048691, 39.21996407210827, 39.555793851614, 41.58507116138935, 41.080990210175514, 39.63999353349209, 40.55456645786762, 42.30998106300831, 40.57965651154518, 41.94096386432648, 40.4558477550745, 40.51442161202431, 43.46006155014038, 46.1808979511261, 49.70309995114803, 51.53734512627125, 50.82293026149273, 51.89091615378857, 53.90757814049721, 56.441149190068245, 55.56835502386093, 55.46591632068157, 54.243286326527596, 54.45389002561569, 52.09926277399063, 55.05950912833214, 51.0970551520586, 37.15117648243904, 54.432033598423004, 51.45760640501976, 52.21919573843479, 50.77691853046417, 53.466064631938934, 52.09474101662636, 53.482331559062004, 50.38117736577988, 44.9913489818573, 44.89984609186649, 44.816907942295074, 46.23018130660057, 47.76402600109577, 46.06702946126461, 45.02386003732681, 40.46726234257221, 39.45643678307533, 40.86080342531204, 42.1623969823122, 43.08848708868027, 41.723007559776306, 40.59026554226875, 41.667876318097115, 41.10522910952568, 40.516933277249336, 41.92694641649723, 52.98694834113121, 54.099008068442345, 51.41526147723198, 52.68304064869881, 54.62237298488617, 54.83716405928135, 48.74275468289852, 40.97205765545368, 42.621324956417084, 41.51118032634258, 45.03187760710716, 45.15674650669098, 53.15575048327446, 52.71778978407383, 53.148329481482506, 53.53604547679424, 52.26220943033695, 49.742256850004196, 51.00176006555557, 56.26281715929508, 57.69769996404648, 55.031542629003525, 48.65205354988575, 45.485292077064514, 56.71007215976715, 60.29150918126106, 56.35550178587437, 60.81449791789055, 56.34713463485241, 59.40780960023403, 53.74469608068466, 48.5590573400259, 51.85734115540981, 46.218770518898964, 4.078475525602698, 7.155309123918414, 14.364779591560364, 1.6878855787217617, 0.04669606911193114, 0.09094827561057173, 37.75402933359146, 65.46439960598946, 48.563708290457726, 42.369318678975105, 23.984085023403168, 30.26902187615633, 47.93271414935589, 50.72006598114967, 62.77922809123993, 14.626601692289114, 0.3074520413065329, 0.03577567033062223, 0.07178630461567082, 0.055831120334914885, 0.032619301418890245, 0.034249762757099234, 0.05002217090805061, 0.08236239140387625, 0.08456113748252392, 0.034475768989068456, 0.048915810548351146, 0.10492889807210304, 0.13887466600863263, 0.19070851587457582, 0.17381422163452953, 0.12798832438420504, 0.20738978404551744, 0.15962820238200948, 0.10022811242379248, 0.14667063049273565, 0.12131440555094741, 0.151576716452837, 24.7503063082695, 74.53944504261017, 59.67032231390476, 56.40496753156185, 29.971735328435898, 38.8899289816618, 80.10970294475555, 58.96691545844078, 52.389536798000336, 71.43129542469978, 17.94621091336012, 0.2844346279744059, 1.1813098238781095, 3.5142594762146473, 5.881055099889636, 33.952215537428856, 58.777613416314125, 61.40342451632023, 60.224822759628296, 58.491211384534836, 55.841400772333145, 46.598309352993965, 45.72076924145222, 44.84977997839451, 52.89892226457596, 57.00187370181084, 57.07087799906731, 59.67853367328644, 57.82869793474674, 52.562549114227295, 49.568085595965385, 42.33877591788769, 46.54421925544739, 46.7574068158865, 47.592609599232674, 51.7918136715889, 48.485048711299896, 48.6673629283905, 49.539640322327614, 47.3127356171608, 45.988749861717224, 43.41343805193901, 41.476271599531174, 47.26489618420601, 54.62708093225956, 54.78596940636635, 54.41631384193897, 53.00798401236534, 54.615027979016304, 56.329499781131744, 46.05714239180088, 41.09086588025093, 41.48575209081173, 43.59257943928242, 42.85990655422211, 41.52660369873047, 40.96064306795597, 44.82998684048653, 43.010013699531555, 44.07765381038189, 42.2999420017004, 42.30835095047951, 46.25102698802948, 50.39159260690212, 51.79288521409035, 55.300161615014076, 53.82974311709404, 53.997443318367004, 53.8115268945694, 57.24222220480442, 56.65451534092426, 58.669224232435226, 55.85415668785572, 57.23880618810654, 52.623494043946266, 56.92795626819134, 53.182672038674355, 41.82540066540241, 56.64998218417168, 53.05073171854019, 55.22885464131832, 53.67079384624958, 57.95479416847229, 51.996706277132034, 55.16458489000797, 52.30568669736385, 49.91957813501358, 47.33259715139866, 48.65313269197941, 49.73449386656284, 51.483600810170174, 50.67882679402828, 49.30936507880688, 42.777986750006676, 42.691651582717896, 41.988544911146164, 46.00889638066292, 43.99063087999821, 43.28258827328682, 43.10529738664627, 43.28400939702988, 42.902335077524185, 42.883225902915, 42.73002192378044, 53.396494165062904, 55.21929815411568, 52.03675612807274, 55.50184339284897, 56.12272247672081, 56.64057768881321, 51.24965496361256, 42.70970061421394, 45.292342230677605, 43.93736153841019, 46.82138778269291, 47.85006858408451, 55.527222231030464, 54.50464390218258, 54.78188842535019, 55.98774611949921, 53.66788700222969, 50.74176661670208, 50.02026133239269, 58.64790357649326, 60.22606909275055, 58.93318086862564, 52.9385731369257, 49.28529717028141, 59.81610909104347, 62.15523697435856, 60.178575441241264, 63.23239557445049, 57.142025381326675, 64.07373502850533, 58.33634689450264, 52.82809406518936, 56.863253340125084, 48.044694140553474, 4.705584850162268, 23.16745564341545, 31.793254986405373, 1.7813198338262737, 0.3426300489809364, 0.25558476510923356, 42.28089742362499, 70.35901576280594, 58.72809447348118, 56.58219762146473, 31.864159181714058, 36.640715673565865, 56.5950371325016, 60.912148877978325, 70.7622729241848, 19.28362514823675, 0.5554687406402081, 0.11535715646459721, 0.12851026200223714, 0.2089121367316693, 0.1660955889383331, 0.15209553705062717, 0.16696047299774364, 0.2377643744694069, 0.20104482216993347, 0.1727591993403621, 0.18548646796261892], [0.016828033440106083, 0.015356051244452829, 0.05745144764659926, 0.025321236389572732, 0.04409740933624562, 0.055253625541809015, 0.0378259571880335, 0.042633467382984236, 0.025951432944566477, 0.08930493058869615, 0.06802590170991607, 18.50609377026558, 56.03506878018379, 47.10381522774696, 36.514539644122124, 21.92223396152258, 24.761082530021667, 46.26881763339043, 44.10368241369724, 45.6259111315012, 58.89579847455025, 9.26969664171338, 0.5223362997639924, 0.2954621706157923, 0.8315348520409316, 4.747966350987554, 37.153718546032906, 60.99062226712704, 56.46150849759579, 53.83100464940071, 51.09734393656254, 43.79711486399174, 40.933265537023544, 43.07509660720825, 49.03335928916931, 54.291581735014915, 54.146668910980225, 58.4675158560276, 54.119751155376434, 52.57829166948795, 48.98950204253197, 42.92842447757721, 41.44073970615864, 41.525896936655045, 42.27450616657734, 46.510868445038795, 48.28440807759762, 47.303825095295906, 49.449319168925285, 48.30588452517986, 48.260283172130585, 48.95153068006039, 47.70905055105686, 42.37063720822334, 41.128780245780945, 44.52748507261276, 50.73355905711651, 51.824670508503914, 49.71654362976551, 49.67761091887951, 49.820426255464554, 40.857068225741386, 37.55818024277687, 36.92411966621876, 39.7766076028347, 40.70893697440624, 38.046017065644264, 39.884829595685005, 40.70021264255047, 39.26565282046795, 39.60195377469063, 38.00784811377525, 37.91576385498047, 38.656819090247154, 43.15956227481365, 44.70782719552517, 49.59538333117962, 49.64200682938099, 50.363964289426804, 51.34905003011227, 47.84178122878075, 47.62803889811039, 49.62437577545643, 53.335895016789436, 56.41187556087971, 53.0967852473259, 54.10251908004284, 47.74721570312977, 35.56804463267326, 52.10580602288246, 46.59441456198692, 45.76220601797104, 44.42988730967045, 49.326106980443, 49.66837361454964, 48.19102428853512, 46.398447677493095, 43.78489471971989, 41.104556545615196, 44.99736785888672, 47.641566172242165, 46.23587720096111, 45.5570512264967, 44.555728957057, 41.39505475759506, 38.063906505703926, 39.534336403012276, 40.16409941017628, 42.657445818185806, 37.89114497601986, 38.4866414219141, 38.40076602995396, 38.88932481408119, 40.6739142537117, 38.93193952739239, 49.16247256100178, 52.505506575107574, 51.12640477716923, 52.14876651763916, 50.486169531941414, 51.54540829360485, 49.25850100815296, 40.45177437365055, 41.01146914064884, 40.03164991736412, 40.60314305126667, 41.81099943816662, 45.067766681313515, 51.930464431643486, 52.881382405757904, 48.875287771224976, 44.157415330410004, 55.6888085603714, 56.92270115017891, 54.64959852397442, 51.35656222701073, 49.73884463310242, 40.25815576314926, 47.39384226500988, 53.92270512878895, 58.11547614634037, 57.54991829395294, 56.30352057516575, 46.23914122581482, 52.79078386723995, 53.794579803943634, 39.81344282627106, 38.71050640940666, 46.50499016046524, 10.989601202309132, 3.2394130993634462, 31.38972993940115, 3.793398910202086, 1.090841309633106, 0.20499499223660678, 22.324755862355232, 61.67324423789978, 45.33839575946331, 41.54070854187012, 27.746607027947903, 17.7125633507967, 37.94654980301857, 44.534921273589134, 53.98532956838608, 16.074066571891308, 0.4530957620590925, 0.00691374478265061, 0.020142511348240077, 0.048733093790360726, 0.018780987629725132, 0.05025330166972708, 0.05605207625194453, 0.09085578916710801, 0.030927534971851856, 0.06595677914447151, 0.03861047407553997, 0.0434658565063728, 0.043018419382860884, 0.0528166166623123, 0.043533176722121425, 0.043351413623895496, 0.05380968075769488, 0.03449095704127103, 0.01253055681445403, 0.06336718841339462, 0.02288765066623455, 0.07607654901221395, 24.095884524285793, 66.15022480487823, 53.16546656191349, 43.79801921546459, 26.417371854186058, 31.557747423648834, 51.96702226996422, 51.04597449302673, 47.92202152311802, 64.45518895983696, 10.00944759696722, 0.4682542470982298, 0.6384049903135747, 2.2246079659089446, 6.387183191254735, 39.2676705121994, 63.58924962580204, 58.78858342766762, 57.581126019358635, 53.15515771508217, 46.97449676692486, 42.559927850961685, 45.0113283097744, 49.89594340324402, 56.873391196131706, 55.581494718790054, 59.50420282781124, 55.836632028222084, 53.73488500714302, 52.44872622191906, 45.7500808686018, 43.56208607554436, 43.14167283475399, 44.09869708120823, 48.00184763967991, 51.375519409775734, 50.67529298365116, 50.36656714975834, 51.38348378241062, 51.49903938174248, 52.92346894741058, 48.835044130682945, 44.712538942694664, 42.43179872632027, 47.53653220832348, 53.00714425742626, 52.61964865028858, 50.88502272963524, 52.116012275218964, 51.0670405626297, 44.074116200208664, 37.9222197085619, 40.24294897913933, 40.106825083494186, 40.36017648875713, 41.28881245851517, 40.98970390856266, 41.75880543887615, 42.08434157073498, 40.58788686990738, 39.50136937201023, 40.01710809767246, 40.81243962049484, 45.43079540133476, 45.6355170160532, 51.261179745197296, 51.28336675465107, 51.911659240722656, 53.75273644924164, 51.82118609547615, 48.527211248874664, 51.6411517560482, 55.43782062828541, 57.693846970796585, 53.47964510321617, 55.23789055645466, 49.21556331217289, 39.252520725131035, 54.78594660758972, 50.33399149775505, 47.27523922920227, 46.35117061436176, 52.74242766201496, 50.881477519869804, 50.68523325026035, 48.18331070244312, 45.18735006451607, 43.67536559700966, 47.256772220134735, 49.33143049478531, 48.428477346897125, 47.64198414981365, 46.42780490219593, 42.61844091117382, 40.63046358525753, 40.87913744151592, 42.682209089398384, 45.20865172147751, 41.75432927906513, 40.96729651093483, 40.13038381934166, 41.711900755763054, 41.98588505387306, 40.76471798121929, 50.378380715847015, 54.83418881893158, 53.79527896642685, 52.97010004520416, 52.23419353365898, 54.39278930425644, 52.84911833703518, 42.12562255561352, 42.8049311041832, 42.85562418401241, 41.99964791536331, 43.077414482831955, 47.39462122321129, 54.12016533315182, 53.974598944187164, 50.4826433211565, 45.82834906876087, 56.59132473170757, 56.66988551616669, 57.5889877974987, 52.93185509741306, 51.61068499088287, 41.83596029877663, 50.14937840402126, 55.67826792597771, 60.72360299527645, 57.504677921533585, 57.964977622032166, 49.525774866342545, 58.294564336538315, 59.13854464888573, 47.36222416162491, 41.02963596582413, 48.384460508823395, 11.656935643404722, 2.1672357944771647, 30.034785345196724, 9.555530603975058, 1.3918371708132327, 0.13677288894541562, 23.78865770995617, 68.11186954379082, 51.03602662682533, 42.43608869612217, 32.05497354269028, 26.05318609625101, 45.967759788036346, 52.17443414032459, 61.05110362172127, 21.753215231001377, 0.3080277401022613, 0.02742188167758286, 0.03201084051397629, 0.020619977622118313, 0.0419982001039898, 0.029735321113548707, 0.02135272228770191, 0.04851882091315929, 0.02158942286769161, 0.06810423539718613, 0.07418228386086412, 0.10892456921283156, 0.2375699020922184, 0.14096911065280437, 0.15629996691131964, 0.1976665511028841, 0.19465973979094997, 0.08278692213934846, 0.10488494066521525, 0.17875308083603159, 0.24760228407103568, 0.33385032322257757, 31.00715696811676, 72.17101693153381, 60.93454107642174, 52.43407420814037, 31.049074418842793, 35.53071163594723, 55.281664207577705, 57.83317409455776, 56.112375631928444, 69.34426501393318, 12.005551736801863, 0.8620217442512512, 1.0660413466393948, 3.501889002509415, 6.382212108001113, 40.97435653209686, 65.06733611226082, 63.25739823281765, 59.537812024354935, 55.11343963444233, 48.514633923769, 46.17272838950157, 47.15359255671501, 54.65339072048664, 58.594790026545525, 58.185874968767166, 62.488482892513275, 57.451039999723434, 56.09574772417545, 55.70591524243355, 49.492272064089775, 46.78672604262829, 47.37668238580227, 46.37250266969204, 51.793629974126816, 53.471604734659195, 52.88143940269947, 54.148511812090874, 52.60730691254139, 52.615354880690575, 54.95132893323898, 51.33809521794319, 48.018274158239365, 44.68987695872784, 49.22931097447872, 53.929863944649696, 56.032773703336716, 50.74136383831501, 51.99224911630154, 55.031972005963326, 45.27075558900833, 39.467201605439186, 41.77988290786743, 42.504393830895424, 42.69841901957989, 42.10644118487835, 43.887014240026474, 44.41158749163151, 44.84407268464565, 43.08207683265209, 40.852694660425186, 41.598161458969116, 43.97443614900112, 49.12598691880703, 48.49512577056885, 53.300530314445496, 52.21591651439667, 55.12349009513855, 58.09095226228237, 52.981765419244766, 51.23735502362251, 52.57929101586342, 56.904184743762016, 59.165006428956985, 54.61878977715969, 58.64111714065075, 51.45528852939606, 41.85084030032158, 56.27437233924866, 50.45659191906452, 52.04611122608185, 47.61959955096245, 55.36737620830536, 53.36470507085323, 53.54615293443203, 50.55550821125507, 47.45818421244621, 45.85629276931286, 48.8767658919096, 52.56041742861271, 50.3966311365366, 49.20102909207344, 49.58535186946392, 45.54983161389828, 43.18348579108715, 43.49558964371681, 44.57951948046684, 47.50196546316147, 41.90485440194607, 43.236124366521835, 41.6837252676487, 42.74354539811611, 44.88691918551922, 42.84868575632572, 55.330670177936554, 56.660674810409546, 54.77444842457771, 53.71983401477337, 53.87882508337498, 55.76421171426773, 55.81765204668045, 43.90447810292244, 44.829196482896805, 43.604643791913986, 43.11828128993511, 45.48077791929245, 49.20042872428894, 55.76256260275841, 55.555496513843536, 52.679670229554176, 47.00004659593105, 59.09836560487747, 61.062882989645004, 60.54898716509342, 54.97487246990204, 54.89765301346779, 45.38890264928341, 52.272278890013695, 57.62743413448334, 63.3220973610878, 60.421424210071564, 62.061385810375214, 54.528685212135315, 62.636317759752274, 64.65488344430923, 56.089360266923904, 45.406495705246925, 53.381051793694496, 14.413663018494844, 5.236061085015535, 43.6609073728323, 10.055451728403568, 2.32279303483665, 0.45799319457728416, 29.24349680542946, 74.65023949742317, 60.49894005060196, 53.88151913881302, 40.64282052218914, 30.47106083482504, 53.31659585237503, 61.383202001452446, 72.68927112221718, 27.474862709641457, 0.790581718320027, 0.19131773005938157, 0.16598394024185836, 0.13239714171504602, 0.2567572990665212, 0.15240902022924274, 0.2512775477953255, 0.12613109982339665, 0.170873491151724, 0.16848929721163586, 0.23919082683278248], [0.06583446578588337, 0.05327567210770212, 0.03184267356118653, 0.052972660632804036, 0.030411126354010776, 0.005332376049409504, 0.011297592554910807, 0.07018177391728386, 0.062336642149602994, 0.009426735668967012, 0.2186991201597266, 17.67403531819582, 59.103453531861305, 51.85346536338329, 35.0601676851511, 20.499692894518375, 26.77464008331299, 30.924433507025242, 46.419798731803894, 47.93658994138241, 58.76640021800995, 6.905763214454055, 0.3245399025036022, 0.06987716682488099, 0.5187708442099392, 2.411485738120973, 40.361977592110634, 64.25041794776917, 56.53231389820576, 54.76343281567097, 45.234022960066795, 44.68252435326576, 44.7045973688364, 52.5243953615427, 54.53430891036987, 52.704467698931694, 56.866350173950195, 52.86457970738411, 51.512885838747025, 52.98756390810013, 49.10362131893635, 45.14058217406273, 40.714735463261604, 39.91780422627926, 42.651544734835625, 47.88945347070694, 49.462276473641396, 50.81635281443596, 49.0258014947176, 51.972995549440384, 51.47963762283325, 52.46418759226799, 51.6518709808588, 50.78797213733196, 45.55804677307606, 41.804839968681335, 45.85971258580685, 51.40174180269241, 52.02202811837196, 49.80289779603481, 48.86978566646576, 38.65240752696991, 37.09988683462143, 36.64101205766201, 39.11836512386799, 39.59562711417675, 39.223904460668564, 38.834429159760475, 38.31861063838005, 41.34505324065685, 40.228410959243774, 38.11016142368317, 38.69245357811451, 38.35473909974098, 38.091310635209084, 43.928390219807625, 48.81259873509407, 50.696150064468384, 51.27596855163574, 50.13314947485924, 47.21534684300423, 50.239205583930016, 50.8167327940464, 49.189686700701714, 52.265804037451744, 57.00836755335331, 54.459175541996956, 47.653923109173775, 38.75736549496651, 51.76376737654209, 52.25279353559017, 43.60159255564213, 39.6829654276371, 43.14670756459236, 43.06705243885517, 42.0889887213707, 41.81219257414341, 43.939580619335175, 42.42615982890129, 45.73528066277504, 46.22237652540207, 47.13721923530102, 48.39032359421253, 44.814472272992134, 39.36074651777744, 40.1941291987896, 39.66888338327408, 41.80631048977375, 40.906081795692444, 41.117882430553436, 39.09395903348923, 39.68033216893673, 40.07156677544117, 40.10631211102009, 39.44365806877613, 41.69683836400509, 51.14389903843403, 53.361619636416435, 50.34867770969868, 51.81480623781681, 50.08442848920822, 52.932303473353386, 45.482753813266754, 39.03179056942463, 39.83491167426109, 39.34100277721882, 40.469143241643906, 42.58838452398777, 48.97667773067951, 53.02210785448551, 51.09948702156544, 55.820520892739296, 55.292622819542885, 52.724371030926704, 54.128798469901085, 46.98472201824188, 42.44370348751545, 43.17371651530266, 52.289206981658936, 57.820767760276794, 59.88091081380844, 49.23910304903984, 46.90452352166176, 52.85523980855942, 53.10727268457413, 53.58699694275856, 55.41553482413292, 34.226902797818184, 41.15979418158531, 18.72010588645935, 0.42907276831101626, 6.370039461180568, 5.6795500125736, 0.3817768843146041, 0.08761648525251076, 11.916146334260702, 62.44470164179802, 52.503397688269615, 44.41795215010643, 29.059546776115894, 24.49811764061451, 49.888685792684555, 50.64003087580204, 44.82495591044426, 21.589710004627705, 1.045144486706704, 0.04503936543187592, 0.04634375676687341, 0.0005753858761181618, 0.0650376663543284, 0.07010867979261093, 0.07697603941778652, 0.06781882024370134, 0.028602399288502056, 0.11921053563128226, 0.05167630304640625, 0.047712655577925034, 0.07894591457443312, 0.0596873604808934, 0.05623684133752249, 0.02264916336571332, 0.06595112397917546, 0.02956126150820637, 0.0856908420973923, 0.04591887722199317, 0.05391797123593278, 0.2678446291247383, 27.842848263680935, 66.49584665894508, 57.43144825100899, 41.09174743294716, 21.689063273370266, 26.821371875703335, 34.48318764567375, 50.77517822384834, 53.07221956551075, 62.95404531061649, 7.359271729364991, 0.46550548053346574, 0.7172782486304641, 3.8330490700900555, 4.563018400222063, 40.80350250005722, 65.1243482530117, 60.40381595492363, 56.89778208732605, 47.355737909674644, 45.27220331132412, 46.392934173345566, 53.98124098777771, 57.07322247326374, 55.2778872102499, 59.36898708343506, 54.58481200039387, 53.55788670480251, 55.98895825445652, 51.68677970767021, 46.41216114163399, 42.460867166519165, 41.571817472577095, 44.06923346221447, 49.28556315600872, 52.32469707727432, 52.82514162361622, 51.240786239504814, 53.26217517256737, 52.48725235462189, 53.449934497475624, 53.376480638980865, 50.44608548283577, 47.521599009633064, 43.07268373668194, 48.16029533743858, 54.44690220057964, 52.89374694228172, 49.80908386409283, 49.7421732544899, 41.71227313578129, 39.07505504786968, 39.201782047748566, 42.32785150408745, 40.82901053130627, 40.67766085267067, 41.95721559226513, 41.46301411092281, 44.036961793899536, 40.69999225437641, 39.90391597151756, 40.9437757730484, 39.15624149143696, 41.393770426511765, 44.81588199734688, 50.65574303269386, 53.88276167213917, 52.67612501978874, 52.11769558489323, 48.0754990875721, 51.18584878742695, 52.79882423579693, 52.01817512512207, 54.26945932209492, 57.651160061359406, 56.09686866402626, 49.41224455833435, 40.37975303828716, 53.971752896904945, 52.69145339727402, 46.78418777883053, 41.0834676772356, 44.71685171127319, 45.310718044638634, 46.2308918684721, 44.10349242389202, 46.51339530944824, 45.00799968838692, 47.127442359924316, 50.52461586892605, 49.16561879217625, 50.7706830650568, 46.75255827605724, 41.91218040883541, 42.54258558154106, 41.90661370754242, 43.12415197491646, 42.97031342983246, 43.88966269791126, 41.18220537900925, 41.14029362797737, 40.66708981990814, 42.579667791724205, 42.8997740149498, 45.35112127661705, 52.604688853025436, 54.5716343075037, 51.84654973447323, 53.3021642267704, 53.30095209181309, 54.32215869426727, 47.65741512179375, 42.338935509324074, 41.909311562776566, 41.68598994612694, 41.51297003030777, 43.066695258021355, 52.1804416179657, 53.99653896689415, 52.87303805351257, 57.48292028903961, 56.61553703248501, 54.70827117562294, 54.53161485493183, 49.182888865470886, 44.43165421485901, 44.536612182855606, 53.96041810512543, 60.11255398392677, 60.26074603199959, 51.64310485124588, 51.5445951372385, 57.5347875058651, 55.976692512631416, 58.835803493857384, 62.83191226422787, 39.438858926296234, 39.38890300691128, 22.237394750118256, 0.4280855634715408, 4.347940441220999, 8.817163724452257, 0.8953737420961261, 0.1398608466843143, 12.632766030728817, 68.94981577992439, 54.44654121994972, 46.28624349832535, 35.36460354924202, 31.234650760889053, 57.4112219363451, 59.47419583797455, 55.016579031944275, 26.632115431129932, 1.2032186170108616, 0.04960619342455175, 0.07861945865442976, 0.08201278047636151, 0.07305298742721789, 0.06451093446230516, 0.06277630527620204, 0.03982713613368105, 0.041455100144958124, 0.07348923667450435, 0.024011316054384224, 0.1927175690070726, 0.18240842531668022, 0.14908232842572033, 0.15582738211378455, 0.12421238090610132, 0.17335713288048282, 0.09455170686123893, 0.13393990346230567, 0.1734060700982809, 0.2030022515100427, 0.5356830242089927, 37.45670288801193, 76.26821547746658, 65.15915438532829, 46.81241646409035, 28.673542588949203, 38.45141351222992, 42.5238411873579, 60.68402051925659, 57.93087065219879, 69.37805280089378, 7.9800524935126305, 0.40701824706047773, 0.30834517150651664, 2.7697590133175254, 4.130679024383426, 42.834907695651054, 69.4404074549675, 62.14057736098766, 58.90768803656101, 48.66846866905689, 47.97346316277981, 47.04680308699608, 56.963917538523674, 59.4588066637516, 58.27284090220928, 61.25858008861542, 55.760947689414024, 55.28025068342686, 57.478565722703934, 54.39834080636501, 49.14683640003204, 44.40717592835426, 43.14522564411163, 46.59737840294838, 52.21784681081772, 56.64514884352684, 55.52478276193142, 52.72966034710407, 57.07134157419205, 54.449493661522865, 55.06215758621693, 55.665557608008385, 53.612485975027084, 50.0405902415514, 45.036201775074005, 48.34044747054577, 57.686102986335754, 55.41803888976574, 51.64282746613026, 52.003420516848564, 42.524350360035896, 42.28294551372528, 38.6084096878767, 44.52994354069233, 43.877127170562744, 42.975576147437096, 43.991007059812546, 41.493458077311516, 45.711155757308006, 44.29755941033363, 41.00152127444744, 42.96584486961365, 41.050884425640106, 43.09371180832386, 48.04951228201389, 52.902589067816734, 55.27667887508869, 53.14994439482689, 53.68870608508587, 48.11814799904823, 54.97191242873669, 55.08188992738724, 54.96536538004875, 56.34063318371773, 56.98558397591114, 58.815592378377914, 51.101276725530624, 43.95164877176285, 55.59844180941582, 56.219419687986374, 46.269566193223, 43.42343531548977, 47.7029936760664, 48.48692961037159, 47.53753915429115, 46.000240445137024, 48.6184823513031, 47.91700579226017, 50.63011720776558, 51.806929260492325, 52.12543956935406, 54.31380674242973, 49.9923138320446, 44.17799882590771, 44.42473478615284, 44.443596974015236, 45.54491847753525, 44.855787456035614, 45.43346665799618, 43.06135654449463, 42.640662118792534, 42.556530833244324, 43.992918357253075, 44.381211921572685, 46.20315335690975, 54.57091994583607, 58.270089849829674, 52.524140775203705, 55.57150885462761, 54.83853958547115, 56.016841158270836, 50.18222004175186, 44.00659762322903, 45.90035900473595, 43.846968188881874, 44.210642874240875, 46.36073850095272, 53.68253901600838, 56.71494349837303, 53.60050521790981, 59.68394078314304, 59.67262879014015, 54.779346361756325, 57.034681141376495, 52.26942904293537, 47.85603806376457, 47.0244412869215, 57.252413257956505, 61.491059213876724, 63.467682749032974, 56.77158705890179, 56.37753680348396, 59.7552477568388, 57.96107143163681, 61.92624606192112, 65.73585703969002, 45.65002083778381, 47.05566421151161, 24.71912518143654, 1.0772714065387845, 11.259444672614336, 10.887655522674322, 1.1824422818608582, 0.3457034903112799, 14.764583688229322, 73.91532853245735, 64.57679763436317, 57.294989973306656, 40.95711685717106, 37.701459154486656, 66.42909184098244, 65.5030207335949, 66.9947674870491, 33.42887721955776, 1.8503196188248694, 0.19896639307262376, 0.1719647747813724, 0.15481487003853545, 0.3149550058878958, 0.19947575870901346, 0.13472490274580196, 0.269000509288162, 0.1695879577891901, 0.2596606401493773, 0.21619437175104395], [0.01537569960419205, 0.08137510492815636, 0.07073325643432327, 0.019366278684174176, 0.0963338409201242, 0.07675967368413694, 0.03651598861324601, 0.014011517141625518, 0.1143423882604111, 0.08743545316974632, 0.0841007535927929, 17.269944101572037, 56.238046288490295, 48.28912742435932, 40.32123997807503, 23.700215555727482, 34.8450992256403, 33.059502840042114, 44.04258169233799, 49.84590768814087, 53.73934216797352, 4.459774615243077, 0.015422994820255553, 2.6290437765419483, 1.0692847101017833, 15.420004818588495, 43.68209883570671, 62.11040697991848, 54.98656444251537, 53.45908060669899, 51.3614297658205, 54.5272146910429, 52.106280997395515, 53.94467934966087, 52.73339934647083, 57.80326209962368, 50.89792683720589, 49.26163204014301, 51.81357130408287, 55.31791806221008, 49.21632707118988, 44.82127010822296, 40.83879880607128, 39.034830406308174, 41.57049514353275, 44.405454620718956, 49.07669976353645, 48.190651908516884, 49.391015097498894, 52.74071395397186, 54.649286940693855, 52.454938888549805, 51.06350675225258, 53.12814496457577, 49.38975736498833, 48.504591062664986, 46.77392452955246, 48.66616599261761, 48.28684754669666, 48.880896270275116, 45.752185955643654, 41.286247596144676, 38.1763880699873, 37.87419408559799, 39.81312744319439, 38.14707264304161, 40.36416247487068, 40.134426802396774, 38.23383718729019, 42.5329264998436, 38.793892934918404, 38.634909465909004, 38.74788120388985, 38.62978354096413, 36.76772005856037, 41.13477632403374, 47.16448277235031, 50.34525029361248, 49.46685902774334, 50.6836449354887, 52.82470844686031, 53.435024097561836, 53.44234250485897, 55.19895024597645, 46.64664275944233, 49.074419885873795, 56.92150421440601, 50.95758743584156, 40.799022540450096, 50.3233976662159, 50.33956199884415, 49.137903079390526, 43.81988704204559, 40.124744921922684, 39.50540095567703, 39.657947570085526, 41.98235884308815, 43.83895821869373, 44.42973531782627, 46.457796692848206, 50.89470461010933, 51.578546315431595, 47.07456439733505, 41.78752809762955, 37.5526325404644, 39.833437353372574, 40.85144832730293, 39.23479087650776, 40.226267874240875, 40.97526468336582, 39.10746730864048, 40.922766700387, 37.31862589716911, 39.681221321225166, 38.90577033162117, 38.28996017575264, 43.68910185992718, 50.80900780856609, 51.99593871831894, 51.94440968334675, 50.44760540127754, 52.3812722414732, 48.09261716902256, 40.83635553717613, 39.05703641474247, 40.94396576285362, 42.112517058849335, 39.577289298176765, 45.35393312573433, 54.59900803864002, 55.513425171375275, 54.98844914138317, 53.12854774296284, 51.353062614798546, 44.43836085498333, 41.0217209905386, 41.6154695302248, 49.69002105295658, 54.65111844241619, 56.82981513440609, 49.39677178859711, 47.82391458749771, 55.6267274916172, 53.706299141049385, 59.21723082661629, 56.877635568380356, 60.600261613726616, 41.49251952767372, 36.676114574074745, 26.358254626393318, 0.49046375846955925, 5.490026157349348, 9.41089991480112, 0.49924292019568384, 0.048311850769096054, 7.863469999283552, 59.336783811450005, 54.11736488342285, 43.50454196333885, 27.48824369162321, 23.43460600823164, 38.75629775226116, 44.95762579143047, 50.558544248342514, 29.433955885469913, 2.8312902990728617, 0.05687718861736357, 0.052845634636469185, 0.023287384392460808, 0.05066940160759259, 0.054067536257207394, 0.1026258357160259, 0.027597807784331962, 0.04677974997321144, 0.06615502905333415, 0.04618815808498766, 0.04149573273025453, 0.09755655148182996, 0.049517940933583304, 0.09216767619363964, 0.06416633303160779, 0.017271138276555575, 0.013583012205344858, 0.028096961468691006, 0.08413652511080727, 0.10020393325248733, 0.20737869635922834, 25.537297278642654, 67.8037440776825, 54.92451757192612, 48.36106516420841, 26.420814469456673, 37.32030160725117, 41.96798801422119, 49.195595383644104, 55.19194722175598, 58.23286324739456, 4.798671305179596, 0.21718132426030934, 5.434500211849809, 4.908735249191523, 15.538908988237381, 48.217132687568665, 62.71581709384918, 58.41716095805168, 53.06191451847553, 53.56821455061436, 55.81724926829338, 53.712044432759285, 56.953190714120865, 56.6879915446043, 58.799025267362595, 55.28342731297016, 49.82772186398506, 54.20861318707466, 56.55416652560234, 51.90762385725975, 47.172108963131905, 43.14546123147011, 40.90268857777119, 44.0553680062294, 45.90528354048729, 52.66755647957325, 51.53358332812786, 50.340348556637764, 52.84469157457352, 54.7180138528347, 53.612356781959534, 53.22044961154461, 54.64356064796448, 51.237932592630386, 49.95393209159374, 49.83366094529629, 51.16451293230057, 51.54475472867489, 51.45398139953613, 46.16976074874401, 41.979353204369545, 39.595794305205345, 39.599172323942184, 38.792859390378, 39.800056144595146, 41.48466914892197, 41.03565104305744, 40.88685862720013, 43.29310990869999, 39.549797773361206, 38.88107165694237, 39.18734282255173, 39.70986418426037, 40.586469545960426, 42.547605112195015, 48.52031461894512, 51.84222936630249, 50.54332226514816, 52.65081077814102, 53.987780436873436, 53.841537684202194, 56.39726534485817, 55.07038414478302, 51.09715774655342, 53.172758370637894, 56.1282017827034, 52.49780438840389, 42.72317849099636, 52.059596702456474, 53.47576931118965, 50.31908489763737, 46.58257819712162, 41.11496798694134, 40.30334293842316, 43.2410679012537, 45.206634029746056, 46.575901955366135, 46.98716528713703, 49.64657038450241, 53.750118389725685, 54.573002234101295, 47.01433762907982, 42.19571739435196, 39.77195285260677, 41.993442848324776, 40.90524964034557, 41.34984478354454, 43.38574133813381, 42.31951855123043, 41.16797134280205, 41.16691879928112, 39.25075002014637, 41.54967226088047, 40.81548325717449, 40.24207502603531, 46.54805324971676, 53.312450274825096, 54.28741715848446, 54.17467720806599, 52.765351831912994, 54.14680950343609, 50.474979132413864, 42.911614179611206, 40.61185598373413, 42.33993485569954, 43.10605354607105, 42.34936594963074, 47.25132331252098, 56.1628483235836, 57.76242569088936, 56.97487995028496, 53.560177981853485, 52.44091384112835, 47.32615649700165, 42.97666668891907, 42.25444704294205, 51.586803272366524, 57.65261918306351, 57.37299598753452, 52.69713029265404, 52.27659925818443, 57.50466652214527, 55.826231986284256, 60.49063749611378, 58.318104073405266, 61.80292367935181, 49.236610382795334, 36.802066415548325, 29.419579356908798, 0.6157656863797456, 4.553744997829199, 7.094901390373707, 1.752375599462539, 0.015063919654494384, 8.230925481766462, 65.49724504351616, 60.768797770142555, 47.06728018820286, 27.039877250790596, 28.85890234261751, 45.9817810356617, 54.15353134274483, 60.487145483493805, 37.390898019075394, 4.317271336913109, 0.1012153692136053, 0.03679288020066451, 0.047952042732504196, 0.012814359652111307, 0.055322422631434165, 0.08133582305163145, 0.0352092112734681, 0.0505526098277187, 0.07893472298746929, 0.0750615433207713, 0.1541262460523285, 0.27414825337473303, 0.14199505560100079, 0.13426404388155788, 0.13269281334942207, 0.24660477822180837, 0.09518679973552935, 0.11546171765075997, 0.23758934636134654, 0.23570020945044234, 0.4582325223600492, 37.2490706294775, 76.72007963061333, 64.34089869260788, 53.93769532442093, 32.87319503724575, 45.299786031246185, 45.86639642715454, 57.2723051905632, 59.37678426504135, 66.65614485740662, 5.094994604587555, 0.25919718376826495, 4.90821230225265, 7.372847450897098, 20.501775182783604, 49.82105702161789, 63.260111287236214, 60.66600188612938, 55.88274635374546, 56.24669462442398, 60.14044068753719, 56.806093007326126, 58.786189556121826, 57.65740692615509, 61.76131211221218, 56.79062783718109, 51.55056081712246, 55.87174594402313, 58.326756209135056, 53.85458618402481, 48.807826191186905, 45.52277326583862, 42.38949939608574, 45.226039588451385, 47.70340405404568, 53.73775765299797, 52.5187336653471, 52.85740569233894, 56.23932681977749, 57.268919572234154, 55.293325781822205, 55.54007314145565, 56.476779878139496, 52.805166095495224, 54.19555328786373, 52.31423243880272, 53.78560468554497, 53.31518992781639, 53.741432055830956, 49.19056825339794, 44.702712669968605, 41.743750646710396, 42.64270260930061, 43.34368519484997, 40.7612069696188, 43.520588502287865, 44.83345225453377, 42.822584956884384, 45.90232349932194, 42.09917217493057, 41.869238913059235, 42.00530581176281, 44.782968163490295, 41.34408049285412, 44.32870253920555, 50.49660377204418, 53.20117324590683, 53.52026492357254, 54.078641161322594, 55.368033573031425, 56.31096437573433, 57.169851288199425, 57.72873289883137, 52.578550055623055, 57.5338489562273, 56.783564016222954, 52.3609509319067, 45.218637585639954, 53.74038711190224, 54.51961129903793, 53.252747878432274, 47.373061180114746, 43.50484974682331, 41.602284237742424, 45.65193213522434, 46.651647090911865, 48.59983675181866, 49.843665808439255, 49.696077927947044, 57.06262864172459, 55.044499933719635, 50.93367151916027, 45.20004138350487, 41.31467767059803, 44.12263199687004, 42.674096524715424, 44.62018109858036, 44.414517134428024, 43.68469789624214, 43.91515552997589, 45.24291828274727, 40.61712250113487, 43.87324757874012, 42.96637304127216, 41.26710042357445, 47.973991334438324, 56.49819552898407, 56.7589071393013, 55.26849791407585, 53.623839765787125, 57.29544594883919, 53.15238766372204, 45.31553238630295, 42.8035631775856, 44.70560051500797, 46.10426366329193, 46.11148327589035, 48.61547291278839, 60.393427312374115, 59.669911935925484, 59.09562975168228, 56.793648675084114, 54.6046507358551, 48.064228892326355, 44.99017484486103, 44.987598583102226, 54.9322235584259, 58.90403263270855, 60.33977039158344, 54.52859781682491, 56.03718526661396, 59.52713459730148, 59.86567363142967, 62.94409364461899, 63.307962119579315, 62.81900815665722, 52.479523569345474, 40.73746584355831, 34.97639738023281, 1.3103330880403519, 15.41098315268755, 18.354987278580666, 2.6660694647580385, 0.1336339901899919, 9.793590679764748, 70.64317211508751, 67.47161909937859, 56.51046507060528, 36.486044973134995, 36.28755882382393, 54.886356219649315, 64.14631113409996, 68.76791954040527, 45.852815955877304, 5.166248381137848, 0.27023470087442547, 0.11557562989764847, 0.08954836244811304, 0.15149375918554142, 0.21617477905238047, 0.18267496023327112, 0.18337989662541077, 0.1707260264083743, 0.12902004324132577, 0.1986781132291071], [0.022821133825345896, 0.022185872112459037, 0.017955784351215698, 0.008808871752989944, 0.0511916249524802, 0.010077154820464784, 0.006065843381293234, 0.015624123334418982, 0.014280792438512435, 0.017825199756771326, 0.08818586837151088, 25.295449756085873, 57.695108503103256, 51.60539947450161, 31.877371072769165, 18.572531305253506, 20.74244286864996, 23.67824323475361, 41.305216178298, 54.21422928571701, 49.818788543343544, 3.897481500171125, 0.11850621522171423, 34.46195438504219, 20.475383698940277, 1.112525558564812, 26.538501754403114, 59.25758846104145, 58.84178437292576, 55.23114211857319, 54.08040426671505, 58.62781785428524, 58.78971956670284, 55.43528996407986, 55.136641189455986, 52.46577970683575, 42.925882413983345, 49.61596682667732, 52.16300815343857, 52.87337243556976, 48.46927955746651, 41.31134144961834, 39.17004995048046, 39.49952647089958, 41.911112666130066, 45.90456537902355, 49.250031262636185, 51.63921006023884, 52.36132711172104, 51.8297204375267, 51.90387725830078, 50.1930570602417, 51.300435438752174, 53.661621138453484, 52.60375030338764, 52.02579751610756, 49.195929765701294, 47.915930449962616, 47.14978136122227, 48.208351358771324, 42.10417650640011, 37.986120879650116, 38.41273918747902, 38.16191844642162, 38.95633041858673, 40.66144712269306, 40.49292616546154, 40.112387984991074, 39.0183886885643, 39.12978731095791, 38.67704540491104, 39.99282360076904, 37.812454998493195, 38.29264663159847, 36.691883727908134, 39.65664803981781, 45.586412250995636, 52.39875890314579, 51.32311262190342, 52.83502869307995, 52.63958998024464, 51.972429379820824, 50.49071408808231, 51.93545736372471, 55.78446842730045, 44.50171485543251, 47.93046087026596, 52.740656957030296, 40.20463943481445, 51.993738636374474, 51.99930913746357, 50.28147451579571, 50.35143256187439, 45.66946819424629, 39.26851786673069, 40.45894078910351, 44.89217430353165, 46.85771003365517, 48.205197528004646, 47.00061276555061, 48.01653765141964, 50.390547662973404, 45.000263303518295, 39.634966403245926, 40.09833633899689, 38.673188611865044, 40.34729517996311, 39.19144280254841, 40.35358764231205, 40.991003438830376, 39.40568670630455, 39.13995936512947, 38.644925728440285, 37.57287785410881, 39.1076534986496, 39.314271211624146, 41.60052113234997, 46.28999389708042, 51.70384079217911, 51.14754304289818, 51.02091483771801, 50.979029685258865, 50.05985900759697, 45.96026659011841, 40.19998848438263, 38.893614783883095, 40.68041950464249, 38.63954521715641, 41.89345881342888, 47.92960211634636, 50.76581932604313, 48.78786966204643, 48.10788094997406, 40.38462057709694, 41.455520913004875, 41.05543278157711, 46.40183709561825, 52.32437789440155, 58.259697407484055, 51.17443040013313, 48.38689997792244, 58.50753150880337, 52.20666401088238, 55.83769977092743, 56.219514682888985, 61.707085222005844, 59.45214182138443, 50.84175065159798, 44.49094243347645, 39.442453533411026, 1.8876717332750559, 4.602153925225139, 26.73938747495413, 0.7152915489859879, 0.22566772357095033, 4.535503601655364, 51.74845799803734, 54.64905895292759, 49.47659030556679, 43.20403888821602, 24.009404964745045, 35.26725277304649, 49.13165241479874, 51.52436502277851, 40.81805571913719, 5.340671371668577, 0.1734035467961803, 0.05975774947728496, 0.03730406038812362, 0.08704896492417902, 0.05307480983901769, 0.03625637051300146, 0.013092292101646308, 0.057583627858548425, 0.10130384063813835, 0.06743726728018373, 0.028646981954807416, 0.05077718371467199, 0.014068498312553857, 0.010461715337442001, 0.03782359715842176, 0.08072828612057492, 0.049213742022402585, 0.020396223808347713, 0.018158646707888693, 0.08084490720648319, 0.2212016421253793, 34.75327715277672, 67.59020313620567, 56.6359381377697, 39.86684136092663, 22.260305620729923, 22.25767996162176, 29.452162608504295, 48.030965477228165, 56.49729497730732, 55.63605599105358, 3.1001676712185144, 0.1259419263806194, 25.53825292736292, 14.000122658908367, 2.7942781476303935, 29.885894134640694, 62.95932322740555, 60.51533617079258, 56.006068736314774, 55.54005414247513, 60.602009519934654, 59.17549766600132, 57.70088419318199, 56.940826177597046, 54.62335713207722, 43.916960433125496, 50.138951763510704, 53.786820620298386, 55.195192247629166, 51.25650979578495, 42.62032940983772, 40.63709802925587, 42.34130658209324, 43.70512939989567, 48.74301306903362, 51.35395936667919, 52.96129211783409, 53.21490190923214, 53.48930038511753, 53.419897109270096, 50.8066975325346, 52.15595953166485, 53.446583077311516, 54.474344328045845, 53.22058640420437, 50.90795449912548, 50.72344779968262, 50.76744183897972, 50.686023607850075, 44.1058748960495, 39.48834367096424, 41.36033982038498, 39.55976843833923, 40.60410439968109, 42.214275598526, 41.392904072999954, 42.17195726931095, 42.19008229672909, 41.12730972468853, 41.529643535614014, 41.93945534527302, 40.268647000193596, 40.450680032372475, 38.27136017382145, 41.08808822929859, 46.66919834911823, 52.00725071132183, 52.75374345481396, 53.9426426589489, 54.01649169623852, 53.84465351700783, 53.26692871749401, 53.632396906614304, 59.08853933215141, 47.33465664088726, 50.67878119647503, 53.83299954235554, 43.10170657932758, 53.19065921008587, 55.23541308939457, 53.39096546173096, 53.18372458219528, 47.613782063126564, 41.37641295790672, 43.83149541914463, 46.9545554369688, 47.82925330102444, 48.356505408883095, 49.551431089639664, 49.00344729423523, 53.22743743658066, 47.25123971700668, 42.086655646562576, 41.11815221607685, 39.72192093729973, 42.683231234550476, 40.34862130880356, 42.062291353940964, 42.28720508515835, 40.02676717936993, 41.5141137689352, 40.02038352191448, 40.18295019865036, 42.670513316988945, 41.2072916328907, 43.139438554644585, 51.65106542408466, 53.523365557193756, 52.7307964861393, 53.579154163599014, 52.39473111927509, 52.00640715658665, 46.22790902853012, 41.698540672659874, 41.27770185470581, 41.59487463533878, 40.99460184574127, 44.14796903729439, 48.53557080030441, 53.049139603972435, 51.38151928782463, 49.81728382408619, 41.40912540256977, 42.56185434758663, 43.25517274439335, 47.50341318547726, 54.99701768159866, 58.75245116651058, 53.693949803709984, 53.256650269031525, 58.42890992760658, 55.25690093636513, 58.463761657476425, 58.29655542969704, 62.26968303322792, 60.98326586186886, 54.10861775279045, 46.78960248827934, 40.79815238714218, 2.7665453357622027, 1.8670217413455248, 31.31787959486246, 3.9421929884701967, 0.28067395789548755, 5.307829733937979, 56.135064214468, 61.611816734075546, 51.50310896337032, 42.98251077532768, 30.78805312514305, 43.52168284356594, 56.604164242744446, 58.70940327644348, 48.721859604120255, 6.773138456046581, 0.18342332710744813, 0.017447233221901115, 0.10463635087944567, 0.0471901502169203, 0.038793599014752544, 0.05943523807218298, 0.03213676442101132, 0.06637973652686924, 0.06860425739432685, 0.0374596516485326, 0.15764991869218647, 0.16879256843822077, 0.12171972208307125, 0.07604408005136065, 0.10879575464059599, 0.27581787784583867, 0.15200665744487196, 0.1679872046224773, 0.14807315601501614, 0.15139358409214765, 0.49987380509264767, 46.3161326944828, 74.27548840641975, 64.12458389997482, 43.63685466349125, 27.72418063133955, 27.255093902349472, 35.48929385840893, 53.154675140976906, 63.66485416889191, 59.55395735800266, 4.1100276075303555, 0.27804773475509137, 48.75738389790058, 29.281496666371822, 1.6125206602737308, 35.389587208628654, 63.664534986019135, 64.18985679745674, 58.005289658904076, 58.27925115823746, 62.15539276599884, 63.89924839138985, 58.78663033246994, 58.53666454553604, 55.326330810785294, 44.005070105195045, 50.576733872294426, 54.818860441446304, 56.989463567733765, 53.055956438183784, 45.22407129406929, 42.20930926501751, 44.77272391319275, 46.086970791220665, 51.37994237244129, 54.64402422308922, 55.18525958061218, 56.2719214707613, 55.18926076591015, 54.83212932944298, 53.2393041998148, 53.61263036727905, 55.28915360569954, 55.615993067622185, 57.14935138821602, 53.6219322681427, 53.43943566083908, 50.73318287730217, 53.21977324783802, 47.08227798342705, 41.332251727581024, 42.89294958114624, 41.25163145363331, 43.29009287059307, 44.461338222026825, 44.835910722613335, 43.307742923498154, 43.030627593398094, 43.052126839756966, 42.32711814343929, 45.07388435304165, 41.55828259885311, 42.520542964339256, 39.79277953505516, 42.80453972518444, 48.66412930190563, 55.68392962217331, 54.32255007326603, 56.729249730706215, 59.20436851680279, 55.50652094185352, 55.989596620202065, 55.73049232363701, 61.622243374586105, 47.089698985219, 52.777647972106934, 51.54089033603668, 45.239107087254524, 56.31746582686901, 58.02658751606941, 56.06460079550743, 54.41918648779392, 50.50504311919212, 44.35287304222584, 43.33411730825901, 49.69227813184261, 51.63536086678505, 53.27199384570122, 50.79635828733444, 52.1381650865078, 55.01944787800312, 48.643302619457245, 44.08960796892643, 43.766534104943275, 41.52427442371845, 44.99974653124809, 41.93613812327385, 44.52960155904293, 46.116092428565025, 42.02000342309475, 43.98117318749428, 41.84763327240944, 40.92132657766342, 44.2570573836565, 43.254370987415314, 46.237431317567825, 52.93616406619549, 56.80470608174801, 53.960691690444946, 55.23716479539871, 55.245433151721954, 52.90385439991951, 49.819354712963104, 44.19206187129021, 44.6309345215559, 43.48890200257301, 43.54092501103878, 46.10644094645977, 50.683846324682236, 55.01524530351162, 54.10110555589199, 52.54519164562225, 43.70993994176388, 45.43566673994064, 46.27612084150314, 50.93742951750755, 59.86289978027344, 62.13149584829807, 59.40629728138447, 55.537477880716324, 59.79527100920677, 58.12081106007099, 60.50607606768608, 60.955306962132454, 66.57444924116135, 63.06966930627823, 59.81971129775047, 47.39449962973595, 45.723425298929214, 2.89416101295501, 8.4996822103858, 37.492481768131256, 1.789996549487114, 0.34119630872737616, 5.689342087134719, 64.13666725158691, 68.99794399738312, 64.01417702436447, 55.739003866910934, 37.04588033258915, 49.43013019859791, 66.9061030447483, 67.67080441117287, 57.164045199751854, 7.658509947359562, 0.3357240976765752, 0.179637735709548, 0.20973516366211697, 0.10502269069547765, 0.2013605021056719, 0.18805668863933533, 0.052792916176258586, 0.18918962159659714, 0.16412788827437907, 0.09896821284200996], [0.05560287281696219, 0.007828978923498653, 0.059556664564297535, 0.04819521484023426, 0.05985297815641388, 0.054600576404482126, 0.06257928733248264, 0.016437493068224285, 0.05141490379173774, 0.03526877975673415, 0.27213139284867793, 27.661945670843124, 61.02458484470844, 50.35612151026726, 38.30794841051102, 27.00723510235548, 40.66368140280247, 31.219943650066853, 41.2036058306694, 53.4849838167429, 45.39756238460541, 1.8586040055379272, 0.18573585926787928, 7.512507531791925, 25.098342932760715, 2.059334171935916, 9.765252750366926, 61.21677093207836, 56.52354396879673, 61.44151367247105, 54.518634751439095, 58.13472591340542, 53.39145943522453, 51.3790912181139, 51.24916858971119, 53.577345460653305, 54.22522969543934, 54.594243094325066, 54.020690470933914, 52.07132667303085, 46.17655098438263, 42.69555777311325, 40.284587144851685, 39.438224360346794, 40.4304613173008, 46.236796751618385, 49.11965645849705, 51.36831119656563, 51.127552315592766, 51.65496401488781, 50.00638447701931, 47.579249516129494, 48.91744650900364, 47.44400717318058, 49.925361424684525, 53.32640692591667, 49.96197625994682, 50.07753185927868, 47.496182173490524, 45.57502046227455, 38.88308934867382, 36.40665963292122, 37.81466647982597, 39.491425305604935, 36.99088208377361, 38.79171945154667, 39.77351076900959, 39.327194318175316, 39.0587767213583, 38.28565500676632, 39.117460772395134, 38.594589829444885, 38.313667103648186, 38.027204275131226, 37.62319475412369, 37.82106913626194, 39.201489463448524, 46.98657251894474, 49.23713095486164, 50.888928920030594, 48.371142223477364, 47.93185539543629, 45.53574196994305, 48.03367853164673, 51.43454164266586, 53.01025629043579, 46.34294405579567, 53.31256806850433, 42.76659116148949, 44.88394774496555, 49.99363236129284, 52.60262556374073, 51.27525418996811, 53.27510587871075, 45.835435688495636, 41.01973369717598, 43.42711351811886, 45.42772896587849, 47.57792338728905, 48.50218579173088, 49.53092359006405, 47.2604314237833, 44.27150800824165, 39.64340195059776, 39.73137103021145, 38.93030561506748, 38.50097045302391, 40.35421080887318, 39.568481370806694, 39.14655201137066, 39.29976738989353, 38.95574904978275, 40.09400077164173, 39.31112878024578, 37.76698663830757, 39.56929452717304, 38.98431211709976, 41.21874421834946, 50.330959260463715, 51.45908832550049, 49.63597275316715, 52.15741865336895, 49.7076141089201, 49.393511563539505, 43.86057145893574, 41.9130277633667, 39.67941641807556, 41.124706864356995, 38.704035356640816, 39.50068160891533, 38.40259753167629, 39.65092554688454, 39.59650106728077, 40.23643992841244, 40.14613017439842, 41.55069820582867, 49.169262796640396, 54.36889998614788, 53.59532989561558, 45.49855336546898, 54.72276359796524, 55.305150747299194, 56.01625978946686, 56.24815374612808, 56.60135239362717, 57.90765769779682, 61.957275196909904, 62.26517267525196, 51.9536317884922, 65.1765650510788, 9.263771809637547, 0.6610050494782627, 29.91189043968916, 20.57356473058462, 0.178531980200205, 2.5638274010270834, 45.22101245820522, 57.56227523088455, 51.85082830488682, 36.78631626069546, 7.8967600129544735, 32.017777338624, 56.04815527796745, 51.417400762438774, 46.37592628598213, 8.28728785738349, 0.07736551851849072, 0.022860784920339938, 0.048176163909374736, 0.007166665000113426, 0.1375778520014137, 0.04763244425703306, 0.014316763408714905, 0.07727470190729946, 0.07185880502220243, 0.002192041006310319, 0.06367224821588024, 0.02372539438511012, 0.04243488350766711, 0.013270825929794228, 0.023454547590517905, 0.06229943086509593, 0.05844527986482717, 0.05092402876471169, 0.05956089109531604, 0.040449482621625066, 0.5940128036309034, 40.481712967157364, 66.0142832994461, 56.87162809073925, 41.96302928030491, 29.427484832704067, 31.819293089210987, 32.204221934080124, 46.3107255846262, 56.32750488817692, 50.50641864538193, 1.7366691422648728, 0.27077136270236224, 10.608116872608662, 35.80999664962292, 1.5175525937229395, 11.6977777518332, 63.57225313782692, 58.42397019267082, 62.21883796155453, 56.32972776889801, 60.031888112425804, 55.946404337882996, 53.39015990495682, 52.74389438331127, 53.12988147139549, 52.02156074345112, 56.1125086247921, 56.83123625814915, 55.443022549152374, 48.78427505493164, 44.555630162358284, 42.629198133945465, 42.31029264628887, 42.9540541023016, 48.30298528075218, 50.04277512431145, 53.9038011431694, 53.35946135222912, 51.20139755308628, 52.165698409080505, 50.183337181806564, 48.46345826983452, 48.55868496000767, 50.95695286989212, 54.19839173555374, 51.809330731630325, 53.61660115420818, 49.46514531970024, 47.47214466333389, 40.71828067302704, 38.84646691381931, 38.57678398489952, 40.457299277186394, 38.37127201259136, 41.27706728875637, 40.568838492035866, 40.26905357837677, 41.19021154940128, 40.53940527141094, 41.218159049749374, 42.330678552389145, 39.57096263766289, 40.67587494850159, 39.002193957567215, 39.033956453204155, 42.306367456912994, 50.006088092923164, 50.96099965274334, 53.571668565273285, 50.54032802581787, 49.094631001353264, 49.30765897035599, 50.727562978863716, 54.578781723976135, 54.585203379392624, 48.133225589990616, 55.214005038142204, 43.81158448755741, 45.85258796811104, 51.23599089682102, 54.4251673668623, 53.66897754371166, 53.42036448419094, 47.400149926543236, 42.86196984350681, 46.5789569914341, 47.626097202301025, 48.530042096972466, 51.71362906694412, 52.05637447535992, 51.02514021098614, 46.83770410716534, 42.27050498127937, 41.81423306465149, 40.942673832178116, 41.1833681166172, 41.268152967095375, 41.70410357415676, 42.63029247522354, 41.19803912937641, 41.79233483970165, 42.43917033076286, 41.45009100437164, 39.2253939807415, 42.23714657127857, 42.15406782925129, 43.37888650596142, 53.773502334952354, 53.67070645093918, 52.18718625605106, 54.504073932766914, 53.07978875935078, 50.120978727936745, 45.65390422940254, 44.005301892757416, 40.78860729932785, 43.62779974937439, 40.49365192651749, 41.48132152855396, 40.36125183105469, 41.498534604907036, 42.51116506755352, 42.57560960948467, 42.37534135580063, 44.23420920968056, 50.551856607198715, 56.8188489228487, 56.544024869799614, 50.62400333583355, 55.40996812283993, 56.664626598358154, 58.123702704906464, 58.983151987195015, 58.451062738895416, 60.00285007059574, 63.526663184165955, 64.73453477025032, 54.7297628223896, 66.57074064016342, 10.485392957925797, 0.8206182159483433, 33.75156730413437, 23.67155559360981, 0.1522422448033467, 2.329130619764328, 49.63466562330723, 62.867531552910805, 57.902353182435036, 42.61083371937275, 14.326596390455961, 37.44096793234348, 63.68859529495239, 60.09144611656666, 56.850588619709015, 10.61493655666709, 0.09124597330810502, 0.054291854103212245, 0.07526650224463083, 0.0496779108652845, 0.07007932785199955, 0.008973419808171457, 0.08588802331360057, 0.032730786842876114, 0.039709617049084045, 0.017812835576478392, 0.1812368561513722, 0.11321785641484894, 0.1261517166858539, 0.16886114288354293, 0.1225645533122588, 0.11061023149522953, 0.17285202717175707, 0.1667239356902428, 0.17700404656352475, 0.12765688123181462, 1.203938559629023, 54.71402406692505, 74.64466899633408, 65.9619677066803, 51.98239624500275, 38.55767481029034, 53.26841823756695, 43.714799880981445, 53.558745458722115, 61.83647967875004, 55.22158183157444, 2.0313377492129803, 0.2989955950761214, 11.287667658179998, 36.23724952340126, 2.6348170917481184, 13.945941366255283, 65.27741923928261, 59.561290964484215, 66.0343386232853, 58.30086439847946, 62.894285917282104, 57.665188908576965, 54.56353314220905, 53.361748829483986, 55.70808492600918, 53.98642770946026, 57.36124321818352, 59.62262727320194, 57.489870116114616, 52.27243848145008, 47.55102463066578, 44.393508061766624, 44.10302884876728, 45.06588578224182, 51.09377972781658, 53.32022465765476, 56.81479834020138, 53.73226694762707, 52.46046379208565, 52.421436086297035, 50.5110277980566, 50.43943203985691, 47.238369807600975, 52.34382525086403, 57.63350620865822, 54.012973085045815, 56.15610368549824, 52.23312199115753, 49.90490712225437, 43.45727249979973, 40.03764979541302, 40.124661326408386, 41.788143664598465, 40.67059703171253, 43.246775195002556, 43.83115343749523, 42.461794316768646, 42.95143224298954, 42.77754597365856, 43.97400677204132, 42.017529755830765, 41.43035486340523, 42.56864458322525, 41.4952477812767, 42.438288778066635, 43.64033527672291, 50.15305660665035, 52.93226547539234, 55.685897916555405, 52.4191752076149, 52.319434359669685, 52.25316971540451, 52.17729538679123, 56.87371797859669, 56.481871604919434, 51.47274859249592, 58.10322940349579, 45.59009425342083, 48.63633759319782, 53.77048909664154, 56.80079989135265, 55.70327818393707, 56.44098199903965, 50.52883364260197, 45.55493474006653, 48.31092305481434, 48.2377427816391, 51.904128044843674, 53.71956042945385, 55.47850124537945, 51.91020391881466, 48.67988705635071, 44.242044389247894, 43.4189173579216, 43.05669419467449, 42.29879066348076, 45.3027118742466, 43.049485981464386, 43.772552981972694, 43.027458563447, 42.80609004199505, 45.05846858024597, 43.32310929894447, 41.180050894618034, 45.138933062553406, 44.26740422844887, 46.21875911951065, 55.15733487904072, 56.89577579498291, 52.48690277338028, 56.683868765830994, 55.504077672958374, 52.570198103785515, 48.57202224433422, 46.76439844071865, 43.189972043037415, 46.32532060146332, 43.31830635666847, 44.9970106780529, 41.34791448712349, 44.14012245833874, 43.214883506298065, 44.8805583268404, 45.21302528679371, 45.637492910027504, 52.82110244035721, 58.46578694880009, 60.699896067380905, 53.611885607242584, 56.25218152999878, 60.03412999212742, 59.8825903236866, 62.477319091558456, 62.03392468392849, 63.90659719705582, 64.95496094226837, 69.17958945035934, 54.97962221503258, 70.00938132405281, 13.417574018239975, 1.5562116005457938, 44.08826284110546, 24.5926508679986, 0.15612082730513066, 2.7472297847270966, 57.74827525019646, 67.70906075835228, 70.61011388897896, 46.58997260034084, 15.698686614632607, 45.57805649936199, 72.83975824713707, 68.24788704514503, 68.26419577002525, 14.340596739202738, 0.3787943412316963, 0.1638356305193156, 0.1432034798199311, 0.13384113844949752, 0.18602937867399305, 0.15205397678073496, 0.20989934157114476, 0.1381143950857222, 0.1438700917060487, 0.22177769715199247], [0.059213436106801964, 0.11027217580704018, 0.05991597907268442, 0.05964566291368101, 0.0899142560956534, 0.03732330056664068, 0.030448972174781375, 0.04006488685263321, 0.05704432769562118, 0.05859025470272172, 0.3560761618427932, 37.75372534990311, 60.54249331355095, 46.291247829794884, 33.38486038148403, 22.847932688891888, 25.443662703037262, 24.75740622729063, 48.47666636109352, 49.823865070939064, 44.29697044193745, 0.8337517955806106, 0.10875409789150581, 2.3677531722933054, 48.28959859907627, 7.1906087547540665, 12.683116178959608, 65.52020341157913, 51.52624972164631, 57.706074714660645, 51.69481247663498, 52.50977374613285, 50.28902851045132, 55.640064775943756, 54.97641898691654, 56.966611593961716, 53.405670672655106, 55.9765899181366, 53.25803719460964, 51.63115069270134, 45.69561839103699, 41.210004687309265, 39.24745559692383, 41.99179373681545, 41.56966298818588, 45.19958160817623, 48.07330660521984, 50.46461708843708, 48.37894320487976, 52.02809639275074, 46.95071384310722, 47.46883124113083, 47.19777278602123, 53.040358275175095, 52.57913142442703, 50.8584925532341, 49.06274691224098, 49.65905651450157, 45.29744155704975, 41.67384959757328, 36.86643876135349, 38.54228563606739, 39.83326256275177, 37.12591923773289, 37.83006705343723, 38.71316246688366, 37.393136098980904, 39.64744493365288, 39.51982498168945, 41.898387148976326, 37.60683283209801, 40.6889234483242, 37.369949743151665, 38.77174012362957, 38.844016045331955, 37.68403708934784, 39.06281590461731, 39.1868906468153, 39.30279202759266, 40.96882022917271, 36.79773084819317, 41.5259463340044, 43.37482452392578, 50.10801762342453, 49.882974699139595, 53.05406793951988, 49.989152401685715, 49.66629512608051, 40.08410610258579, 42.614603117108345, 50.56018576025963, 52.589159086346626, 53.35411123931408, 50.023760944604874, 45.737256556749344, 41.930328235030174, 43.77386011183262, 44.230451211333275, 45.81848479807377, 48.041908890008926, 49.45925563573837, 46.21218927204609, 40.66675923764706, 39.35011848807335, 41.04189410805702, 39.8860227316618, 38.298676908016205, 38.89666602015495, 40.59306599199772, 41.13837853074074, 41.75015330314636, 41.2009421736002, 37.96564377844334, 41.27053923904896, 39.94454339146614, 39.44497659802437, 38.77126894891262, 40.1347079873085, 43.70259113609791, 51.18388429284096, 50.838524624705315, 54.27009008824825, 51.01762041449547, 50.05620360374451, 48.465821743011475, 46.89429447054863, 41.39797680079937, 40.50668142735958, 39.6078472584486, 39.847116619348526, 37.803434282541275, 41.54999144375324, 40.780867114663124, 42.65309505164623, 39.05213847756386, 46.3656060397625, 49.173070192337036, 55.13659179210663, 49.2248310148716, 50.31658083200455, 54.11981575191021, 58.33084478974342, 54.20760244131088, 55.1157271116972, 56.01942881941795, 57.09015816450119, 54.70761381089687, 66.05328440666199, 53.78041036427021, 39.25029784440994, 23.77061627805233, 0.2569465170381591, 10.376946777105331, 24.623113833367825, 0.31121784704737365, 1.652820585295558, 40.7811065018177, 57.50440813601017, 49.66466881334782, 40.34099891781807, 23.117894902825356, 31.221017092466354, 45.96739500761032, 46.22651070356369, 49.151707738637924, 9.71784744411707, 0.021963528379274067, 0.04347646921814885, 0.08417913180892356, 0.058702638125396334, 0.04463897676032502, 0.08963834043242969, 0.10536004876485094, 0.06569247067091055, 0.027200085278309416, 0.04860627930611372, 0.010238801078230608, 0.020387757758726366, 0.01913599953695666, 0.028486943374446128, 0.014599997575714951, 0.03369524856680073, 0.010490484692127211, 0.029541861767938826, 0.033120355001301505, 0.016087657641037367, 1.3532570097595453, 49.702860563993454, 66.32275834679604, 53.24768275022507, 40.19079677760601, 26.00976772606373, 25.63310533761978, 25.127242282032967, 52.080297991633415, 56.901790872216225, 47.36557178199291, 0.8288540365174413, 0.21247811178909615, 0.6697027827613056, 47.183018177747726, 6.746853841468692, 14.224463570863008, 67.02233120799065, 53.48151460289955, 59.28771324455738, 55.35340815782547, 54.26529474556446, 50.590994507074356, 55.355384051799774, 55.54837189614773, 58.3484910428524, 55.46148955821991, 58.3282495290041, 54.83841419219971, 54.49064925312996, 48.836157470941544, 42.76213780045509, 41.73824854195118, 44.089448377490044, 41.81821145117283, 45.81843540072441, 51.257003769278526, 52.93898731470108, 49.08047676086426, 52.17302821576595, 49.12195533514023, 51.41731336712837, 48.95208925008774, 54.21607218682766, 53.76700468361378, 52.75689348578453, 50.53545668721199, 52.44688332080841, 46.6193488240242, 43.04893121123314, 39.119166880846024, 39.942214116454124, 41.12677775323391, 40.71759670972824, 39.81005720794201, 40.55675134062767, 41.54421955347061, 42.045709043741226, 40.46292297542095, 42.65446297824383, 39.443696066737175, 42.30256386101246, 38.020136654376984, 39.79785606265068, 38.57700817286968, 39.80500727891922, 39.571456611156464, 42.171197310090065, 42.42677539587021, 44.55644331872463, 39.052993431687355, 43.151795491576195, 46.25340946018696, 52.891459465026855, 51.64223849773407, 54.79439355432987, 51.43661253154278, 51.08243353664875, 41.26643165946007, 44.269801899790764, 51.38558886945248, 54.716550931334496, 55.708005130290985, 52.443919479846954, 48.29082973301411, 43.784275352954865, 45.18584534525871, 46.013927310705185, 47.640357837080956, 49.703563526272774, 50.80383628606796, 48.58039699494839, 42.70861007273197, 41.262305080890656, 41.1593572050333, 40.72039715945721, 40.5093564838171, 40.615659579634666, 41.98203586041927, 41.75142243504524, 41.15768529474735, 43.19736644625664, 39.57940198481083, 42.75438241660595, 42.165015041828156, 41.7718805372715, 40.90868465602398, 41.35411195456982, 46.32866442203522, 52.60277755558491, 53.486275747418404, 55.48941045999527, 54.5586010068655, 52.09826722741127, 52.16882944107056, 47.18567803502083, 43.65222103893757, 42.251631394028664, 41.275064796209335, 42.28962555527687, 39.06146317720413, 44.317420944571495, 42.830028757452965, 44.55328568816185, 42.125998735427856, 47.01632872223854, 52.03737169504166, 58.23453135788441, 52.944728806614876, 52.08271846175194, 55.36605387926102, 60.03061518073082, 57.21686616539955, 58.97752448916435, 56.908573508262634, 59.511133655905724, 56.10653914511204, 67.71740511059761, 57.030239179730415, 43.75456854701042, 26.824696697294712, 0.20495580683927983, 7.151535926386714, 21.11582413315773, 0.29176621581427753, 1.7929355730302632, 46.376545652747154, 61.534802466630936, 55.326991975307465, 40.271200463175774, 23.702333942055702, 37.4746835231781, 54.24677453935146, 53.54017585515976, 58.76797713339329, 14.970068112015724, 0.04821145303139929, 0.011091448977822438, 0.04476372807403095, 0.07419135290547274, 0.04215611428662669, 0.034565702444524504, 0.057009335432667285, 0.03906201527570374, 0.02553920330683468, 0.024764122827036772, 0.17004277557134628, 0.19546433177310973, 0.1941233451361768, 0.14984150097006932, 0.14083503425354138, 0.07743995593045838, 0.07798223581630737, 0.12741008744342253, 0.17576025158632547, 0.11959533178014681, 2.319967648945749, 58.83473955094814, 72.35184162855148, 62.86076791584492, 43.52287597954273, 32.63940118253231, 34.08176578581333, 35.17226926982403, 59.36819672584534, 62.691646590828896, 51.692699790000916, 0.8625072275754064, 0.3727156767854467, 2.7436171285808086, 61.94659397006035, 8.916788678616285, 16.389081068336964, 72.65011042356491, 56.492207050323486, 61.218146458268166, 58.14643308520317, 54.920246601104736, 51.14230692386627, 55.79283557832241, 56.72008082270622, 61.61760002374649, 57.77321331202984, 59.71538029611111, 60.35323306918144, 55.68831458687782, 50.90135045349598, 45.053498446941376, 42.912959307432175, 46.269930973649025, 44.162039682269096, 50.19146494567394, 52.65814058482647, 54.69474010169506, 51.81793726980686, 53.93477328121662, 53.06140534579754, 53.38990531861782, 50.958567783236504, 55.860513746738434, 57.10694566369057, 54.47784774005413, 51.28513365983963, 55.232365652918816, 48.99134874343872, 44.96038444340229, 41.810079887509346, 42.51143105328083, 42.270299792289734, 41.253953129053116, 41.436286345124245, 42.214157804846764, 40.69540590047836, 43.64584118127823, 42.3150309920311, 46.87380596995354, 40.791791528463364, 44.37653437256813, 39.793459698557854, 42.45553985238075, 41.787338107824326, 41.400674656033516, 41.96898736059666, 45.04818633198738, 43.74376192688942, 47.10308946669102, 39.87810775637627, 47.03043356537819, 48.07190828025341, 55.21380364894867, 53.394058495759964, 55.9816512465477, 52.82885022461414, 54.66554246842861, 44.65729370713234, 45.5278117954731, 53.162871301174164, 57.007892578840256, 58.574920892715454, 53.71759593486786, 49.79818984866142, 46.598301753401756, 48.706922605633736, 48.40822443366051, 50.97640782594681, 53.237176313996315, 55.422674641013145, 49.89364452660084, 43.8500764220953, 42.186385095119476, 43.638290986418724, 42.73417890071869, 41.81391768157482, 42.32674576342106, 44.75847847759724, 44.96618673205376, 44.449042081832886, 45.58019958436489, 41.13725759088993, 45.21153576672077, 45.57410851120949, 43.84819932281971, 43.61141122877598, 42.92788490653038, 47.94221743941307, 55.52946791052818, 57.0589504390955, 59.11981165409088, 56.71544507145882, 54.20013964176178, 54.89815078675747, 50.49855686724186, 45.483783558011055, 44.855255484580994, 43.057647943496704, 43.84273521602154, 41.877917647361755, 45.83332680165768, 45.41294775903225, 46.6237223893404, 44.17733006179333, 50.105182975530624, 54.58528697490692, 61.1920228600502, 57.72419594228268, 54.741796776652336, 59.00370888411999, 62.146649435162544, 60.117178335785866, 59.21424798667431, 59.264606684446335, 60.208365842700005, 59.871525317430496, 71.49267733097076, 59.5524488389492, 43.06478016078472, 31.65559407323599, 0.20992610341636464, 17.12273810058832, 31.777263544499874, 0.4166341060772538, 2.108238022774458, 48.497447445988655, 69.3278194963932, 63.223454654216766, 53.540814220905304, 33.575815334916115, 44.58414003252983, 62.87030540406704, 63.14495466649532, 68.91794309020042, 21.502305194735527, 0.24341066367924213, 0.20707327290438116, 0.21443999401526526, 0.21690414694603533, 0.14247253857320175, 0.21354708645958453, 0.23375190852675587, 0.18365413503488526, 0.21577957057161257, 0.09568536712322384], [0.014282613483374007, 0.09864453997579403, 0.033497644326416776, 0.06677429933915846, 0.05776939484348986, 0.05230273134657182, 0.04300139822589699, 0.04005897564638872, 0.08719378020032309, 0.028592985145223793, 1.453704263549298, 51.20772421360016, 55.750213265419006, 48.71828779578209, 45.32541565597057, 20.6679155677557, 20.10712455958128, 43.563131019473076, 43.46714437007904, 54.22003537416458, 36.32587596774101, 0.486593606765382, 0.191423159558326, 3.3835626393556595, 21.310229301452637, 0.42220811010338366, 22.483328953385353, 26.643412224948406, 34.79243025183678, 54.25475791096687, 55.257182121276855, 57.6160841435194, 57.886017858982086, 59.126632288098335, 55.93035779893398, 53.10849241912365, 52.549884393811226, 54.72917765378952, 48.57581444084644, 46.538530960679054, 41.36996850371361, 41.21254675090313, 40.184952691197395, 40.19711583852768, 40.99400907754898, 42.36375957727432, 48.15850183367729, 53.002611100673676, 50.49472287297249, 48.12142342329025, 46.18939429521561, 49.401263147592545, 50.417089238762856, 50.96161141991615, 50.5549306422472, 52.37805001437664, 48.70669461786747, 44.52852241694927, 41.32276363670826, 37.67779782414436, 38.78774866461754, 38.20933610200882, 38.31777088344097, 37.69631043076515, 36.67714051902294, 39.31501217186451, 39.29726332426071, 38.27907755970955, 35.938862934708595, 39.51681174337864, 40.48026904463768, 37.03796535730362, 38.086655884981155, 37.668442726135254, 38.0819783359766, 38.15304212272167, 39.01946783065796, 39.1091164201498, 37.65689134597778, 37.831989750266075, 40.406799986958504, 40.539827048778534, 45.893196389079094, 49.853210896253586, 49.30488511919975, 52.9950837045908, 51.69909104704857, 53.234638050198555, 41.463511884212494, 46.141285076737404, 54.7670654207468, 52.0374970883131, 49.0870276093483, 50.51781423389912, 45.594703406095505, 38.64806056022644, 41.69601000845432, 41.77079379558563, 42.226309552788734, 41.13807454705238, 42.931069135665894, 41.46796904504299, 39.500977993011475, 41.3035024702549, 41.37070946395397, 36.51247255504131, 38.48597265779972, 38.18791665136814, 38.832088485360146, 40.501403510570526, 40.77969677746296, 41.26410998404026, 38.42942029237747, 38.9388969540596, 38.32587204873562, 38.421250730752945, 38.55758361518383, 39.09638710319996, 39.12271589040756, 43.07480402290821, 49.34324786067009, 51.036843582987785, 50.84646239876747, 50.31588926911354, 49.81297865509987, 46.477209851145744, 44.599912986159325, 40.747485905885696, 41.668005511164665, 39.40537892282009, 39.755868315696716, 39.821414798498154, 37.57791258394718, 41.23710483312607, 42.10584081709385, 45.54038532078266, 51.877932250499725, 51.07829175889492, 50.587358102202415, 52.35376551747322, 57.046274319291115, 56.128600761294365, 56.87341399490833, 54.481883123517036, 56.34801618754864, 57.101618349552155, 60.25363281369209, 59.20647360384464, 62.08677604794502, 53.57275530695915, 42.666173949837685, 0.3719672653824091, 4.308653399348259, 7.857992118224502, 0.5343129008542746, 0.47175653104204684, 35.17047196626663, 58.72347392141819, 49.85437363386154, 41.104393154382706, 24.71719678491354, 19.92489393800497, 41.57998703420162, 49.95819926261902, 48.93643409013748, 17.326129786670208, 0.06456160088418983, 0.025259947979066055, 0.05939450900768861, 0.02560005941631971, 0.06224185133760329, 0.06046762486221269, 0.15595645643770695, 0.03458614861301612, 0.02454883506288752, 0.05389455647673458, 0.03329330138512887, 0.04246389777108561, 0.03606612837756984, 0.06953503674594685, 0.053745848636026494, 0.09677164867753163, 0.07869524677516893, 0.07454670805600472, 0.025605903829273302, 0.01329406628428842, 2.9050970636308193, 60.10401204228401, 60.788134932518005, 53.991964012384415, 54.32276286184788, 30.388006791472435, 21.259950399398804, 45.16849547624588, 50.41032940149307, 59.17355976998806, 39.98972296714783, 0.4570071178022772, 0.19721323245903477, 5.8552012871950865, 17.08904530853033, 0.3385222319047898, 25.37501558661461, 27.27327972650528, 37.42919996380806, 55.580252185463905, 56.109161004424095, 59.548394456505775, 59.51436348259449, 60.15691660344601, 58.38479429483414, 55.482871010899544, 54.39042963087559, 55.32533906400204, 51.59712351858616, 47.430453300476074, 43.645005226135254, 41.644328981637955, 41.08319029211998, 42.51944102346897, 42.68238388001919, 43.36203061044216, 50.9421868622303, 54.45548973977566, 52.23878748714924, 50.693277418613434, 47.98699423670769, 52.48910665512085, 52.13595740497112, 52.80781835317612, 52.59395822882652, 55.782481133937836, 51.16203926503658, 47.0870391279459, 43.36970239877701, 38.91696073114872, 40.25738060474396, 39.29876044392586, 39.741676077246666, 39.67623598873615, 38.112217113375664, 41.61121375858784, 41.540560349822044, 40.07221654057503, 39.15489636361599, 41.75853945314884, 42.49410778284073, 39.20150846242905, 40.27098387479782, 40.95902815461159, 40.74116304516792, 40.50273343920708, 41.09782710671425, 41.968136206269264, 39.70339693129063, 41.43263094127178, 43.129585683345795, 43.12913350760937, 47.57087476551533, 52.12092541158199, 51.08102761209011, 54.533153772354126, 54.08252455294132, 53.62646542489529, 41.96512296795845, 47.203305289149284, 56.29073806107044, 53.63532654941082, 51.47877886891365, 51.93443141877651, 47.861547768116, 41.435180604457855, 43.570696413517, 42.84574091434479, 44.08980555832386, 43.248215317726135, 45.378248021006584, 41.49014085531235, 43.01364630460739, 45.04635103046894, 42.50099681317806, 38.931586146354675, 39.56140995025635, 41.38890288770199, 40.612220764160156, 42.58592985570431, 42.252892926335335, 42.47108481824398, 40.669700279831886, 41.64864555001259, 41.86938710510731, 39.658582136034966, 40.12656882405281, 40.92068061232567, 40.84484428167343, 46.22559495270252, 52.404036819934845, 53.97157810628414, 53.434689715504646, 54.24193739891052, 52.671899646520615, 49.002379551529884, 47.79246747493744, 43.737488463521004, 42.309411093592644, 41.017636209726334, 41.59023508429527, 40.60414619743824, 40.63730701804161, 41.20436578989029, 44.00512710213661, 47.3254307359457, 54.77672830224037, 55.206314250826836, 55.366327464580536, 55.528654754161835, 57.41195909678936, 57.0489227771759, 58.43308590352535, 56.6728113591671, 60.09181849658489, 58.36131155490875, 62.294837683439255, 61.43230676651001, 63.268018662929535, 58.35409574210644, 45.320426523685455, 0.47459441469982266, 0.4662066913442686, 5.694433338940144, 0.38287653937004507, 0.4217223002342507, 39.22674670815468, 64.25630003213882, 54.431752413511276, 46.83287836611271, 28.17138433456421, 26.7459649220109, 50.35197593271732, 59.32129964232445, 58.44838388264179, 25.694916620850563, 0.19247594056650996, 0.013587750818260247, 0.03716793937201146, 0.04391398011648562, 0.021240001187834423, 0.024886905594030395, 0.08051048062043265, 0.03543731407262385, 0.023933099255373236, 0.032204233066295274, 0.1340455110766925, 0.13214500446338207, 0.0982513946655672, 0.19239325047237799, 0.1470130871166475, 0.21270408091368154, 0.19418811978539452, 0.1317690176074393, 0.16890234692255035, 0.09242896412615664, 4.312415672466159, 70.68976521492004, 67.62394532561302, 61.34892784059048, 58.49236272275448, 28.64826824516058, 28.367729298770428, 57.110433876514435, 54.413331001996994, 65.95985502004623, 43.483149111270905, 0.5883669597096741, 0.42921730899252, 10.146885272115469, 29.384828321635723, 1.210896698758006, 29.580299332737923, 28.100907616317272, 38.378503024578094, 59.267118349671364, 57.20393545925617, 60.734428614377975, 60.177443102002144, 62.84526474773884, 62.17324800789356, 56.478451788425446, 56.42397031188011, 58.145973309874535, 51.98118790984154, 50.63881114125252, 45.644404739141464, 44.60076794028282, 43.51455442607403, 44.6678077429533, 44.55229394137859, 46.095459535717964, 54.977391734719276, 56.188025772571564, 53.71858008205891, 52.99458973109722, 49.760837852954865, 53.52675497531891, 54.669722244143486, 55.731928646564484, 56.19334168732166, 58.84008586406708, 51.56246557831764, 49.815608114004135, 46.91094517707825, 40.60844376683235, 43.336454182863235, 41.97364591062069, 41.76806554198265, 41.83011241257191, 38.18602055311203, 44.98050816357136, 43.659531846642494, 41.69510565698147, 40.24272479116917, 43.82895715534687, 45.16604460775852, 39.98640574514866, 42.544405683875084, 42.62205071747303, 42.74693861603737, 43.918339759111404, 42.83103570342064, 43.969902992248535, 41.20575651526451, 40.7014399766922, 45.46672247350216, 44.267848804593086, 48.65306809544563, 54.95126813650131, 54.34114247560501, 57.75899827480316, 54.58805702626705, 58.54570046067238, 46.08746096491814, 50.38933552801609, 58.258618265390396, 55.84987431764603, 52.000582069158554, 54.141865968704224, 52.33379378914833, 42.16782309114933, 45.07423013448715, 44.882507622241974, 46.268110871315, 44.82239104807377, 47.10561253130436, 44.15829308331013, 44.890183210372925, 47.8018643707037, 44.44801613688469, 41.24420665204525, 42.26222142577171, 42.2063834220171, 42.08585008978844, 44.989912658929825, 44.15288597345352, 44.52090382575989, 41.665167063474655, 43.973144218325615, 42.26360075175762, 40.964085683226585, 42.713097631931305, 44.34802830219269, 43.96905183792114, 47.041160389781, 53.89740228652954, 55.4865188151598, 55.70078931748867, 56.189389899373055, 55.56482121348381, 50.58544300496578, 49.28826101124287, 46.199589148163795, 44.92265626788139, 43.77471886575222, 43.5056097060442, 42.89499767124653, 41.38022795319557, 44.05418246984482, 46.32930278778076, 50.7374120503664, 56.82295270264149, 57.13956691324711, 57.950690388679504, 56.44965313374996, 61.17390163242817, 61.10987886786461, 59.98641215264797, 58.47432889044285, 63.74560363590717, 60.083785727620125, 68.4604400396347, 61.314034312963486, 68.52584972977638, 51.53625838458538, 44.66450572013855, 1.5602433029562235, 10.455614905804396, 16.29914939403534, 1.2055823276750743, 0.5851532821543515, 42.061656787991524, 72.5995959341526, 61.77043542265892, 57.49092645943165, 33.608041405677795, 32.522466257214546, 57.903595715761185, 65.60623839497566, 67.78546705842018, 32.69529618322849, 0.6336087570525706, 0.08695756943779998, 0.22531052789418027, 0.08675298158777878, 0.21347566216718405, 0.20008607127238065, 0.2154800100834109, 0.0984871007676702, 0.16066697164205834, 0.15532527468167245], [0.07302917190827429, 0.05965324766293634, 0.05643522112222854, 0.03541265250532888, 0.03476910656900145, 0.020874766196357086, 0.08211641397792846, 0.18783450446790084, 0.10999424892361276, 0.015758440931676887, 3.8059337250888348, 53.56807015836239, 53.10191497206688, 50.104548409581184, 30.573738925158978, 17.126820981502533, 44.78193461894989, 46.23648136854172, 39.26816448569298, 56.64919562637806, 36.78885832428932, 0.3458454186329618, 0.03215591925254557, 3.357181129977107, 1.2331099505536258, 3.146339706145227, 26.746836975216866, 20.78870538622141, 36.63093499839306, 59.664356634020805, 56.58166565001011, 55.002987161278725, 52.4337550252676, 54.124261513352394, 50.888491943478584, 49.23026092350483, 46.26723311841488, 44.90269213914871, 40.30825987458229, 40.14697752892971, 40.699467882514, 39.62461195886135, 41.43828123807907, 40.71437828242779, 38.394606560468674, 41.089136973023415, 45.66377229988575, 49.604958817362785, 53.23034048080444, 50.65778352320194, 49.07486826181412, 49.64475028216839, 49.516556560993195, 50.722193866968155, 45.69912560284138, 42.16362051665783, 40.4113407433033, 37.45122738182545, 37.893618643283844, 36.97330042719841, 36.0522298514843, 37.50763535499573, 38.01625706255436, 36.54913678765297, 38.14202271401882, 39.87087294459343, 37.43746072053909, 38.62789124250412, 38.45841273665428, 40.65407931804657, 37.86824360489845, 38.72695192694664, 37.729380056262016, 38.583604618906975, 40.405720844864845, 39.63107541203499, 36.8865966796875, 38.705285489559174, 37.415380105376244, 38.6514537781477, 40.39355009794235, 40.65288618206978, 44.07646827399731, 48.16183425486088, 47.20586255192757, 50.27147725224495, 47.15443231165409, 53.88719983398914, 41.57927267253399, 46.73404186964035, 52.81747363507748, 50.36973997950554, 50.651517659425735, 44.284860491752625, 42.208017334342, 39.85312029719353, 41.061577051877975, 41.388196125626564, 42.40499496459961, 43.50639246404171, 41.951063722372055, 45.283484905958176, 47.57309004664421, 47.46614098548889, 46.69230490922928, 39.29909862577915, 37.2098795324564, 38.53107623755932, 37.918769493699074, 39.07948940992355, 42.255731374025345, 42.01240003108978, 37.26969212293625, 38.701599687337875, 39.27414916455746, 38.169027864933014, 39.706052988767624, 39.07717153429985, 39.51185680925846, 38.740745186805725, 43.87414813041687, 47.75888867676258, 48.27326327562332, 48.98352116346359, 48.672621846199036, 47.62038230895996, 45.71281626820564, 43.536049872636795, 41.548365131020546, 37.94650800526142, 37.94428512454033, 40.216183215379715, 40.73775462806225, 40.280000790953636, 42.814225405454636, 45.16008272767067, 48.90685647726059, 49.72885496914387, 53.01580399274826, 54.3833202123642, 54.90309052169323, 54.68729630112648, 54.92077097296715, 57.153044790029526, 56.46868251264095, 53.5745944082737, 57.66005918383598, 61.799165681004524, 65.22726193070412, 66.64058089256287, 58.293226808309555, 4.0967463701963425, 0.863350247964263, 2.6382523449137807, 0.27433916344307363, 0.16084762522950768, 26.42278466373682, 63.22394102811813, 46.90766215324402, 46.85068801045418, 32.36777275800705, 26.691397950053215, 39.141061305999756, 53.563753589987755, 54.11880500614643, 25.95993150025606, 0.6575320952106267, 0.03267325184424408, 0.0403825037938077, 0.100177757703932, 0.029102909247740172, 0.008723359642317519, 0.014366477098519681, 0.04379031604912598, 0.0874711578944698, 0.00701602757544606, 0.04069855851412285, 0.06232536892639473, 0.036836871004197747, 0.024525201370124705, 0.016798408760223538, 0.0704694600426592, 0.04858517262618989, 0.07233864060253836, 0.13589074253104627, 0.07992671467945911, 5.696039702743292, 65.57414531707764, 60.075965747237206, 54.234307408332825, 35.40456220507622, 18.16038642078638, 40.93380130827427, 52.99488231539726, 42.96289622783661, 62.421458289027214, 38.11732403934002, 0.3376684058457613, 0.3776907082647085, 1.7277992307208478, 0.3334321081638336, 3.6323431273922324, 31.833893805742264, 19.93543267250061, 41.356099247932434, 62.371783554553986, 59.328397661447525, 56.51008889079094, 54.52535659074783, 55.95621921122074, 53.77665996551514, 51.493575274944305, 48.46062362194061, 46.74582123756409, 43.12767058610916, 42.81682446599007, 41.15824766457081, 40.694524347782135, 42.19749949872494, 43.33122946321964, 39.80300098657608, 42.08311043679714, 45.65908335149288, 52.22102724015713, 52.94254012405872, 51.423704624176025, 52.252367958426476, 53.078895807266235, 53.14982660114765, 51.10812395811081, 47.90550380945206, 45.39351560175419, 44.25149068236351, 39.78680245578289, 38.790473118424416, 38.83162871003151, 40.80456264317036, 39.994138330221176, 38.19348715245724, 38.59887219965458, 38.53435546159744, 40.81203304231167, 39.38679412007332, 40.07501699030399, 39.9678323417902, 42.1534788608551, 41.08097121119499, 40.33642776310444, 40.57423800230026, 40.015128403902054, 42.23680078983307, 41.72860465943813, 38.55148874223232, 39.56075258553028, 40.33282555639744, 40.98775081336498, 42.4794215708971, 41.640323996543884, 47.08248317241669, 51.72391131520271, 49.45048950612545, 53.74453268945217, 48.79001274704933, 55.802521258592606, 42.632971331477165, 48.01757499575615, 54.80040103197098, 51.6529805213213, 52.02061839401722, 45.701002702116966, 42.378913164138794, 42.256270945072174, 44.294884353876114, 43.46348516643047, 44.0872672945261, 44.50504347681999, 43.958583399653435, 47.90195859968662, 50.12029476463795, 49.12880256772041, 48.30029882490635, 41.40385128557682, 39.74561646580696, 40.79177252948284, 39.90760937333107, 42.28024385869503, 43.32622893154621, 43.349909260869026, 40.81851929426193, 39.886896684765816, 40.48553556203842, 40.434337109327316, 42.76269257068634, 40.862794518470764, 39.782862067222595, 41.88157685101032, 45.400758013129234, 50.17083205282688, 48.717881217598915, 51.166944801807404, 52.37305708229542, 49.439705684781075, 47.60671824216843, 45.7498224824667, 42.64266841113567, 39.55523908138275, 40.51577053964138, 43.39764229953289, 43.22055280208588, 41.93907156586647, 43.880455791950226, 48.22241820394993, 50.31873531639576, 52.580480352044106, 55.326194018125534, 55.9295142441988, 57.01686769723892, 55.35526625812054, 56.89084365963936, 59.86092388629913, 57.5163508951664, 56.24792195856571, 59.46053557097912, 64.59356993436813, 65.86033076047897, 66.9109895825386, 63.0565220117569, 3.9721662551164627, 0.5596640717703849, 3.28585515730083, 0.19742306729312986, 0.2453635065467097, 29.916558489203453, 68.96080479025841, 52.89497047662735, 40.695200711488724, 29.13007479161024, 31.970352083444595, 45.69517761468887, 59.44684490561485, 60.91979406774044, 33.592450842261314, 0.7771295495331287, 0.04551013196760323, 0.04649042370147072, 0.024204764267778955, 0.025444944985792972, 0.05592197034275159, 0.09263099898817018, 0.020306947153585497, 0.05086020777525846, 0.05555008385272231, 0.15975717280525714, 0.1334189306362532, 0.12693742843111977, 0.1449958555167541, 0.12828901293687522, 0.13337695476366207, 0.1901190576609224, 0.3052968147676438, 0.2547925669932738, 0.18320578878046945, 7.592184981331229, 75.0369219481945, 68.82433891296387, 62.07891806960106, 41.39345124363899, 24.58130657672882, 54.28413413465023, 57.62846387922764, 48.69936481118202, 66.12581491470337, 42.72959254682064, 0.4497615894069895, 0.32073550508357584, 6.103862319141626, 6.819931995123625, 6.193054933100939, 33.50750260055065, 22.85871271044016, 45.774429962038994, 64.3940806388855, 64.10855636000633, 59.65821236371994, 57.39290311932564, 56.499236673116684, 54.95315283536911, 53.720096200704575, 50.304128900170326, 48.5591409355402, 44.266287088394165, 44.45993609726429, 42.71322302520275, 43.70143599808216, 44.44797433912754, 46.25137276947498, 41.722638979554176, 43.30711595714092, 49.17973883450031, 54.32323403656483, 57.62336075305939, 53.75381179153919, 53.09809237718582, 55.26325039565563, 54.482852071523666, 53.96784670650959, 49.982335567474365, 47.00311303138733, 44.47030954062939, 40.41592329740524, 42.234946489334106, 40.03712922334671, 41.56740590929985, 42.83685319125652, 41.75894983112812, 39.38078664243221, 43.382473513484, 44.01907995343208, 42.2421433031559, 42.624360993504524, 41.0123772919178, 45.25292694568634, 40.603671222925186, 42.47105062007904, 43.05844970047474, 42.257608473300934, 45.48426233232021, 43.45118522644043, 40.57667747139931, 43.13156917691231, 42.298342287540436, 41.070434376597404, 44.447902143001556, 44.85764555633068, 48.55825178325176, 53.00038442015648, 50.19531413912773, 55.883890092372894, 51.507706716656685, 59.391219690442085, 48.262513652443886, 50.558441653847694, 57.08273336291313, 54.105387926101685, 55.051077380776405, 48.193182572722435, 42.26051151752472, 43.30996960401535, 47.882948219776154, 45.522526279091835, 46.169137582182884, 46.59326322376728, 45.36416597664356, 50.17800606787205, 52.016704604029655, 50.24337776005268, 50.94086453318596, 44.2572245746851, 41.38880029320717, 42.06780485808849, 42.08129793405533, 43.70936997234821, 44.74927917122841, 45.98601780831814, 41.027276292443275, 42.69035965204239, 41.88153885304928, 42.15889357030392, 43.63081678748131, 41.558130607008934, 42.171995267271996, 43.16846899688244, 48.86936768889427, 51.5114077180624, 52.20975324511528, 53.326718509197235, 53.47969450056553, 53.26882101595402, 51.4358601719141, 49.3671789765358, 46.1845837533474, 41.159782782197, 41.5920589864254, 44.58469100296497, 44.814191088080406, 43.693369030952454, 44.887815937399864, 50.14244757592678, 53.07077184319496, 54.39098820090294, 57.67509877681732, 59.06224474310875, 59.26321215927601, 56.744137331843376, 59.6582617610693, 61.14533856511116, 60.63701704144478, 58.048953115940094, 60.71557402610779, 66.2843120098114, 70.37628203630447, 67.7787110209465, 63.32602255046368, 5.2201195154339075, 3.912232546135783, 8.26007466763258, 0.40990912006236613, 0.4248863132670522, 32.3860801756382, 78.85980561375618, 62.07605682313442, 58.51537048816681, 47.0512792468071, 40.97278341650963, 53.99514444172382, 67.24892064929008, 71.71404585242271, 42.58425794541836, 1.5210288134403527, 0.14749015448614955, 0.12216310336953029, 0.18909538368461654, 0.13111496286001056, 0.09424994219443761, 0.1639793993672356, 0.0863886835577432, 0.14042260794667527, 0.1176693917659577], [0.07229313210700639, 0.02090507921820972, 0.028596844313142356, 0.028341337711026426, 0.0776535682962276, 0.02315680350875482, 0.02560763303335989, 0.058466768750804476, 0.02194427706854185, 0.03297704999567941, 6.901189209893346, 55.16923204064369, 47.19250246882439, 43.02925206720829, 29.89203840494156, 43.77073287963867, 64.8332990705967, 50.74258737266064, 38.875451758503914, 56.98353208601475, 34.44087691605091, 0.2681169379502535, 0.005607365883406601, 2.3269991716369987, 1.7341567645780742, 2.894342690706253, 46.250198632478714, 49.45908464491367, 57.59659118950367, 55.301601737737656, 55.23823633790016, 51.40299953520298, 52.92811989784241, 47.28037655353546, 44.616685286164284, 40.354096814990044, 40.596398413181305, 39.40308764576912, 40.55900081992149, 41.919232830405235, 42.44046226143837, 43.08194763958454, 41.03666938841343, 38.10795374214649, 40.9464356303215, 39.91791442036629, 45.05538694560528, 45.4276529699564, 49.521435499191284, 48.67578707635403, 51.407848075032234, 51.65956936776638, 50.45223355293274, 47.80894719064236, 39.31630790233612, 36.89111843705177, 38.702963814139366, 37.604336366057396, 37.22949028015137, 38.31798367202282, 38.57135787606239, 36.82511977851391, 36.2432873994112, 38.37380647659302, 38.84505718946457, 39.84663784503937, 37.840866073966026, 38.018688932061195, 38.817406073212624, 40.523389130830765, 38.62213835120201, 36.72035180032253, 38.728954419493675, 41.313583329319954, 43.61924260854721, 41.82428352534771, 42.84563452005386, 41.276409924030304, 39.05507951974869, 38.57298418879509, 38.607744723558426, 40.196203887462616, 42.55186848342419, 43.50428357720375, 45.36220148205757, 48.84484380483627, 48.40219795703888, 52.95856386423111, 41.340037509799004, 46.08560286462307, 53.6521140486002, 48.69629077613354, 43.74022051692009, 39.65665943920612, 43.270056545734406, 42.71421857178211, 48.153239116072655, 46.01071648299694, 50.767719224095345, 48.6001293361187, 51.84224456548691, 54.19474393129349, 53.322481736540794, 49.897835701704025, 51.311850026249886, 43.50266486406326, 37.75991141796112, 40.20041026175022, 39.62222948670387, 39.41793344914913, 41.036038622260094, 41.84714689850807, 40.158764496445656, 37.37802430987358, 37.77731068432331, 38.451983481645584, 39.36677299439907, 38.70432414114475, 42.36575447022915, 37.05086566507816, 39.800405725836754, 43.14165763556957, 45.49323745071888, 44.48034480214119, 45.950797498226166, 44.5679946988821, 46.383696869015694, 40.87258279323578, 40.49256518483162, 38.47713813185692, 37.8784004598856, 38.21920797228813, 42.382283583283424, 41.082491129636765, 43.61842945218086, 43.93414691090584, 49.231260269880295, 51.01133555173874, 52.22013808786869, 53.05657580494881, 55.3967410326004, 51.83787100017071, 55.36836035549641, 54.51611928641796, 54.723006784915924, 52.98190601170063, 57.610392048954964, 59.211705923080444, 63.68331737816334, 55.8808084577322, 75.63703894615173, 16.265240013599396, 0.33099329215474427, 3.4029556112363935, 0.12684267101576552, 0.0471039460535394, 22.0555954053998, 63.485382199287415, 57.06954047083855, 70.39384469389915, 76.17177665233612, 36.22403763234615, 33.79857078194618, 51.488061770796776, 53.2011466473341, 34.945847019553185, 0.8053950453177094, 0.09703344869194552, 0.03505440297885798, 0.07215799443656579, 0.03355759872647468, 0.06743174570146948, 0.04239130088535603, 0.06297110419836827, 0.051459109818097204, 0.029977192607475445, 0.016294403285428416, 0.05718320207961369, 0.020988338910683524, 0.027023951370210852, 0.05225567918387242, 0.02508275465515908, 0.0069611712660844205, 0.01449440665965085, 0.0675535098707769, 0.11472110621980391, 9.219177402555943, 65.53825244307518, 52.38176241517067, 51.10104873776436, 36.69964671134949, 37.8050871938467, 66.81549310684204, 56.209935396909714, 42.63112083077431, 62.126533314585686, 37.27598838508129, 0.21417339972686023, 0.05849527464306448, 2.2567675402387977, 0.6066757428925484, 3.4757701540365815, 48.2905637472868, 53.134110644459724, 59.05192069709301, 56.25852718949318, 56.161624789237976, 53.43871749937534, 53.66226710379124, 50.039541497826576, 47.80938796699047, 42.6175631582737, 42.60723151266575, 40.95645189285278, 42.645054683089256, 42.15894676744938, 45.94757527112961, 43.901928439736366, 41.16667561233044, 39.40903052687645, 43.63393262028694, 42.52551689743996, 45.69884441792965, 48.066140189766884, 52.219773307442665, 51.664239317178726, 50.487199276685715, 52.181269973516464, 50.86339429020882, 48.885646015405655, 42.64385014772415, 38.25412429869175, 38.88652056455612, 39.64550703763962, 38.4534578025341, 39.93007376790047, 38.826438188552856, 39.327236115932465, 37.663985565304756, 39.05159890651703, 39.966551810503006, 41.23354822397232, 40.3509733825922, 38.75415086746216, 39.598203375935555, 41.381208300590515, 40.68822428584099, 39.76887121796608, 40.17222337424755, 42.774213552474976, 43.709423169493675, 43.69207330048084, 45.69515481591225, 42.288136035203934, 41.340200901031494, 40.455011799931526, 40.8013404160738, 41.697837710380554, 43.7746998667717, 46.04439787566662, 48.246562108397484, 51.468226835131645, 49.93466332554817, 55.234064161777496, 44.08996894955635, 47.994529232382774, 53.9301261305809, 51.007182374596596, 46.06621250510216, 42.78488717973232, 43.565247505903244, 44.93091702461243, 49.038413017988205, 47.63778917491436, 52.74564228951931, 48.738487511873245, 53.502622470259666, 54.5626325905323, 56.66686087846756, 51.92853033542633, 52.725039795041084, 46.05723358690739, 40.211904644966125, 41.600680723786354, 41.15400709211826, 41.736333444714546, 43.231724202632904, 42.825981974601746, 42.5701455026865, 39.49361398816109, 39.39077630639076, 38.88471566140652, 40.422546342015266, 40.793018862605095, 42.223429307341576, 39.41433884203434, 41.626234352588654, 43.32962214946747, 48.49081680178642, 47.08818666636944, 49.02064137160778, 46.54513880610466, 47.53076411783695, 44.583140686154366, 42.17554047703743, 40.050724893808365, 40.83879500627518, 41.02506101131439, 44.681441411376, 41.88033051788807, 46.390232518315315, 45.63783869147301, 49.81895573437214, 51.4696441590786, 54.473968148231506, 54.312051236629486, 57.76816338300705, 53.62588785588741, 57.51351624727249, 54.893009662628174, 57.82704882323742, 53.51262353360653, 59.492852836847305, 59.8182787746191, 66.2306360900402, 59.00956057012081, 80.02123609185219, 18.41995809227228, 0.3287153737619519, 3.6152062844485044, 0.707859800895676, 0.07363837125012651, 23.044498041272163, 69.93335500359535, 61.45302325487137, 69.69930276274681, 75.09208738803864, 42.28822723031044, 41.241877377033234, 60.66347122192383, 61.202050521969795, 44.16846513748169, 1.3879782403819263, 0.08678810743731447, 0.008697304692759644, 0.04863754969846923, 0.027820025352411903, 0.0385542749427259, 0.07372986321570352, 0.025301842215412762, 0.017945015788427554, 0.02584686804766534, 0.11070989450672641, 0.12820834148442373, 0.1357866488979198, 0.14141174237011, 0.15048310247948393, 0.17521224974188954, 0.1166688950615935, 0.12104154011467472, 0.17770671198377386, 0.24465622496791184, 11.640505325049162, 76.28045082092285, 59.272384867072105, 60.394764840602875, 41.55033342540264, 55.93103416264057, 74.24907982349396, 60.35841219127178, 47.90393449366093, 67.97815471887589, 40.60942031443119, 0.27815950219519436, 0.18797151977196336, 8.05834824219346, 7.140410598367453, 4.014155901968479, 51.37853644788265, 52.72031284868717, 62.61433593928814, 58.384174928069115, 58.881887421011925, 55.43110638856888, 57.58900299668312, 52.01813332736492, 50.194656774401665, 43.91932770609856, 44.70181591808796, 43.19539815187454, 45.28881601989269, 45.49411900341511, 47.62137785553932, 47.54457637667656, 43.82331445813179, 41.49194195866585, 45.88124983012676, 44.91311118006706, 48.51444773375988, 49.57585997879505, 53.636987060308456, 52.36261144280434, 54.754788279533386, 55.31444124877453, 53.97662043571472, 51.05320170521736, 43.97115312516689, 39.814521968364716, 40.95601111650467, 41.681365594267845, 39.68872211873531, 41.82102710008621, 40.79732023179531, 40.35609930753708, 39.17929105460644, 41.59802086651325, 42.09822602570057, 43.56564648449421, 42.0971354842186, 41.71481139957905, 41.64475075900555, 44.302886724472046, 42.97263130545616, 41.60780534148216, 42.133887112140656, 46.2079980969429, 47.545849308371544, 45.545439049601555, 47.530870512127876, 44.52313810586929, 44.619816318154335, 41.84867441654205, 43.65589164197445, 43.56871671974659, 47.41630285978317, 47.095626667141914, 50.038177371025085, 53.59119951725006, 53.449755907058716, 58.37822064757347, 48.4843685477972, 50.66796697676182, 55.794032514095306, 52.07562804222107, 47.83037804067135, 43.570255637168884, 45.6990572065115, 47.38027699291706, 53.4843834489584, 49.59209270775318, 56.60565756261349, 51.446093022823334, 55.664296075701714, 58.098373264074326, 58.601728454232216, 55.21027363836765, 56.902984008193016, 47.387226819992065, 42.0684090256691, 45.35955682396889, 43.371758088469505, 44.052909538149834, 43.83877582848072, 45.23554667830467, 43.36293116211891, 40.91574087738991, 40.17745189368725, 41.23277686536312, 41.69756032526493, 42.045682445168495, 44.82066594064236, 42.425567060709, 44.36531737446785, 46.90572425723076, 50.60748182237148, 50.15855871140957, 51.582311913371086, 49.800739511847496, 49.84692223370075, 47.260355427861214, 45.43856978416443, 43.457732275128365, 42.03190438449383, 43.268426433205605, 46.393876522779465, 44.91026133298874, 48.64130012691021, 48.73207725584507, 51.76683381199837, 54.433492720127106, 55.98803110420704, 58.04388418793678, 60.28631865978241, 56.07240177690983, 59.281242191791534, 58.396300077438354, 59.93844732642174, 58.13029535114765, 63.44488017261028, 64.84120264649391, 68.46785724163055, 61.34259358048439, 81.04202091693878, 22.182728983461857, 0.4233637230936438, 12.045559789985418, 1.254086724948138, 0.11889219880686142, 26.485865078866482, 75.39420917630196, 68.22299838066101, 84.37291458249092, 82.47626915574074, 46.53763800859451, 52.64514908194542, 69.02551531791687, 68.68316888809204, 55.26047274470329, 2.7333391550928354, 0.18979824206326157, 0.16466878034407273, 0.1652217100490816, 0.09802138083614409, 0.17071979236789048, 0.17442382173612714, 0.10504131118068472, 0.19190846476703882, 0.13930638815509155], [0.04725944083475042, 0.007536011025877087, 0.08688166257343255, 0.018015779569395818, 0.03494964512356091, 0.05318727489793673, 0.03127582116576377, 0.07363645650912076, 0.07227899419376627, 0.08152179783792235, 8.107356112450361, 59.08556029200554, 51.62754088640213, 34.581761956214905, 22.7597888186574, 39.835257455706596, 67.35476016998291, 46.15959629416466, 39.4652409106493, 60.32182775437832, 29.662865102291107, 0.16829964879434556, 0.13039337267400697, 0.4697946785017848, 0.48264333279803395, 6.532281255349517, 61.295244321227074, 60.13774283230305, 57.46735252439976, 53.39198000729084, 54.719697162508965, 45.61662822961807, 41.97105444967747, 41.102326065301895, 38.750202879309654, 38.47817547619343, 40.50322741270065, 41.89825415611267, 47.66064114868641, 47.864599004387856, 51.525371968746185, 48.711964935064316, 49.33017276227474, 47.67781242728233, 46.05565667152405, 44.09897446632385, 44.41101372241974, 44.733464419841766, 50.84933504462242, 49.92332473397255, 49.130554273724556, 50.67303970456123, 48.9563450217247, 43.98862078785896, 37.51648128032684, 38.02498519420624, 39.16816905140877, 39.464211165905, 37.84477986395359, 38.50559860467911, 39.186499267816544, 37.669062092900276, 37.26094499230385, 37.30311892926693, 38.75495262444019, 39.15249489247799, 39.86248679459095, 39.95078265666962, 37.9767619818449, 40.07477380335331, 39.57983896136284, 37.63155050575733, 38.82893465459347, 42.52342700958252, 46.052198857069016, 47.91696019470692, 45.407859832048416, 44.046693071722984, 44.110047072172165, 42.23790653049946, 39.0747244656086, 37.36181437969208, 38.393261432647705, 42.45864428579807, 44.93494860827923, 51.068967059254646, 48.246615305542946, 54.52536419034004, 46.77090749144554, 48.02637152373791, 52.50786244869232, 45.149496495723724, 41.024943217635155, 41.10214747488499, 44.49457123875618, 47.73444838821888, 50.42645953595638, 51.67403519153595, 54.811382442712784, 50.09723760187626, 51.55975632369518, 53.16165916621685, 50.19300766289234, 47.713933289051056, 52.66839623451233, 43.890118673443794, 37.572315484285355, 37.640575021505356, 38.50874103605747, 38.80508713424206, 38.284347876906395, 39.46106493473053, 40.49313895404339, 41.58700905740261, 39.42183583974838, 39.08385917544365, 37.25460693240166, 39.148288518190384, 39.40693683922291, 38.57807211577892, 38.75724770128727, 38.06342013180256, 40.70184275507927, 40.434671491384506, 43.06881934404373, 42.420650124549866, 42.477768659591675, 41.61071978509426, 40.1341912150383, 38.3575813472271, 39.80789512395859, 39.104332476854324, 40.15868090093136, 39.86644618213177, 40.95755763351917, 44.29217129945755, 48.198585882782936, 48.39298725128174, 48.539104610681534, 50.94045415520668, 51.56976878643036, 53.07504281401634, 52.35483705997467, 52.53428243100643, 55.022426918148994, 50.370663329958916, 53.928275629878044, 54.9071791023016, 65.78273892402649, 58.56090724468231, 71.65327951312065, 37.182737588882446, 0.2656356117222458, 1.4883540105074644, 0.3551086090737954, 0.15925082028843462, 17.508248314261436, 60.15691660344601, 53.38281489908695, 48.277640640735626, 31.81433815509081, 42.70246960222721, 43.70154619216919, 39.687050208449364, 59.76710692048073, 37.24875524640083, 0.940925816539675, 0.14984147128416225, 0.09475157465203665, 0.025656701982370578, 0.051236973886261694, 0.05518205653061159, 0.04458860348677263, 0.028294396870478522, 0.07920965901575983, 0.04346764508227352, 0.054294344008667395, 0.018010601233982015, 0.10657210208592005, 0.052573155116988346, 0.04652859606721904, 0.09127988945692778, 0.0159832986901165, 0.046648612478747964, 0.22917472757399082, 0.13156501605408266, 11.664759423583746, 69.91946294903755, 58.57767954468727, 45.205212906003, 31.861710213124752, 45.24550974369049, 74.88960385322571, 53.63357104361057, 43.03985349833965, 64.84964579343796, 33.200581669807434, 0.1185087682097219, 0.11881143087521195, 1.5172754460945725, 0.26353750086855143, 7.772440183907747, 59.698733389377594, 60.654370710253716, 59.405848905444145, 55.17748899757862, 57.668095752596855, 47.62202002108097, 44.735246524214745, 43.38501937687397, 41.02428585290909, 40.253922790288925, 43.58512803912163, 43.92599634826183, 48.9625158905983, 50.3485257178545, 51.93417303264141, 51.596811935305595, 51.64208270609379, 49.435734897851944, 47.576908841729164, 45.318663418293, 46.37523852288723, 48.68109919130802, 52.62247569859028, 50.30632518231869, 51.780167296528816, 52.16791749000549, 50.45092262327671, 46.674499064683914, 39.42848168313503, 40.61078444123268, 40.840318724513054, 40.511906147003174, 39.08325120806694, 40.080918073654175, 41.373217329382896, 40.33165901899338, 38.14947411417961, 38.665490224957466, 39.32576559484005, 39.269980788230896, 41.55472978949547, 41.05686530470848, 40.25697402656078, 40.51859758794308, 40.684774070978165, 40.9039881080389, 39.76003669202328, 43.19336146116257, 47.04626351594925, 48.897900357842445, 46.57337509095669, 47.06950306892395, 47.08192840218544, 43.60123537480831, 41.089034378528595, 39.54628296196461, 40.38490556180477, 43.95682029426098, 45.990740954875946, 53.07687431573868, 49.676493778824806, 56.53608709573746, 49.656126871705055, 50.98880656063557, 55.60745112597942, 49.31620091199875, 43.12036357820034, 42.79461845755577, 46.77748113870621, 50.86047224700451, 51.18896082043648, 51.975191831588745, 57.44408257305622, 52.86295339465141, 53.746603578329086, 55.537211894989014, 52.69302651286125, 50.58819405734539, 55.02744644880295, 45.37042424082756, 39.623019844293594, 39.90055315196514, 40.20130321383476, 40.42795345187187, 40.70642150938511, 40.63474215567112, 41.86985068023205, 41.70257605612278, 41.624991819262505, 40.046514719724655, 40.229835882782936, 41.922447457909584, 42.417055517435074, 41.216521337628365, 40.52954860031605, 40.27004532516003, 43.5713841766119, 43.665413931012154, 45.14299124479294, 43.64152081310749, 45.735105872154236, 43.97833473980427, 42.45327517390251, 41.21511921286583, 41.14893056452274, 40.837180092930794, 43.42872843146324, 41.67891092598438, 42.299489825963974, 46.928633227944374, 52.069920748472214, 50.723755583167076, 51.45766340196133, 53.71783912181854, 55.54055191576481, 55.990386977791786, 54.83868397772312, 53.939553424715996, 57.494380474090576, 51.41618862748146, 57.151885852217674, 56.4861273765564, 67.67044723033905, 60.75555928051472, 75.84921196103096, 39.2638973146677, 0.2309866514406167, 4.672949351370335, 0.3173713496653363, 0.07859428500523791, 18.042207062244415, 66.55533626675606, 59.769523590803146, 59.696780294179916, 40.98512515425682, 46.591652110219, 51.2037268280983, 48.6885429918766, 67.64298990368843, 48.58312904834747, 2.1545672742649913, 0.15379653952550143, 0.0247224642225774, 0.03932479863578919, 0.042375285338493995, 0.07923442448372953, 0.05184071102121379, 0.10118761289049871, 0.01707775500108255, 0.08839565867674537, 0.09071815788047388, 0.08618120875325985, 0.22920466581126675, 0.19742027681786567, 0.12133885931689292, 0.14854900626232848, 0.13311197835719213, 0.14297577406978235, 0.3019882313674316, 0.1463326415978372, 15.13327980414033, 80.83497762680054, 65.52125215530396, 50.52104026079178, 31.579400561749935, 51.86576150357723, 71.0890705883503, 54.260753989219666, 51.41415573656559, 71.48496374487877, 37.18754053115845, 0.2787716849707067, 0.1890260967775248, 3.658950012177229, 3.0618733260780573, 9.148134514689445, 63.736069947481155, 64.20629471540451, 61.83313965797424, 57.62766972184181, 59.9276939034462, 49.85900558531284, 46.948958337306976, 45.807761773467064, 41.703548803925514, 42.829249799251556, 44.74512219429016, 47.03444615006447, 52.60290674865246, 52.4470467120409, 55.539905950427055, 54.770359843969345, 53.79483439028263, 51.55268870294094, 50.051571652293205, 49.14263382554054, 48.488658517599106, 50.57824619114399, 54.52332749962807, 53.26214857399464, 52.57222339510918, 54.51270706951618, 53.84077772498131, 49.220465049147606, 40.92571534216404, 41.13783895969391, 43.29198136925697, 42.94254831969738, 41.64578050374985, 41.72191321849823, 42.99550227820873, 41.50631658732891, 41.617042645812035, 40.347177386283875, 42.22658313810825, 43.10676030814648, 44.230417013168335, 43.402019664645195, 41.14225812256336, 42.73227900266647, 41.97256676852703, 43.80071707069874, 41.52484819293022, 45.83605505526066, 49.973820224404335, 52.007459700107574, 48.54466751217842, 49.075210243463516, 49.97431419789791, 47.01971814036369, 42.823082730174065, 40.88055096566677, 43.12073975801468, 47.708666771650314, 49.57793466746807, 54.64767962694168, 52.29858107864857, 59.49089594185352, 53.02661821246147, 54.55399565398693, 57.567397356033325, 51.38360157608986, 46.26770809292793, 45.09995475411415, 49.335956051945686, 53.72793897986412, 54.11214396357536, 53.910697773098946, 59.35386389493942, 54.38403457403183, 56.07921481132507, 58.814289048314095, 54.03614044189453, 50.42917639017105, 57.43869066238403, 48.52971911430359, 40.95113217830658, 42.33337260782719, 41.3611263781786, 42.261305674910545, 42.828356847167015, 41.77654668688774, 44.57265704870224, 46.676292568445206, 44.25475470721722, 42.2596375644207, 41.048387959599495, 42.44823284447193, 42.77270883321762, 43.31821136176586, 41.870481446385384, 42.41929739713669, 45.730903297662735, 45.40538616478443, 47.244818061590195, 46.16791024804115, 48.07633504271507, 46.764968410134315, 44.55859400331974, 44.569727405905724, 43.375067710876465, 43.81979204714298, 45.432744696736336, 43.34726840257645, 43.67710970342159, 49.57031987607479, 53.83530601859093, 52.26211063563824, 54.07210931181908, 56.639369353652, 57.46353752911091, 59.31639410555363, 56.4782389998436, 57.41351321339607, 60.817222371697426, 53.89621675014496, 60.14078266918659, 59.441718980669975, 72.23228484392166, 63.549146577715874, 74.78802770376205, 42.04252481460571, 0.30496278894133866, 10.491001456975937, 1.0397580382414162, 0.2560374158201739, 20.33006999641657, 72.69635394215584, 64.93687391281128, 63.62313620746136, 44.294188991189, 53.10266353189945, 56.02843813598156, 57.38349102437496, 75.02106159925461, 59.25204075872898, 4.307506335899234, 0.28987789526581764, 0.2619430411141366, 0.06306310082436539, 0.13503866794053465, 0.12694400385953486, 0.12747198255965486, 0.18380597844952717, 0.1895004478865303, 0.1608661492355168], [0.00899864726306987, 0.009464079612371279, 0.07500676540075801, 0.08565232463297434, 0.07661143710720353, 0.05529061789275147, 0.03230686466849875, 0.03167793904140126, 0.29457637283485383, 0.04041802298161201, 14.245222806930542, 54.86031621694565, 49.51200820505619, 38.70691940188408, 18.238620422780514, 41.659824550151825, 55.25631196796894, 39.419221580028534, 46.06269769370556, 59.94027502834797, 30.512852892279625, 0.04224252996209543, 0.017268807932850905, 0.9378806955646724, 0.2536311652511358, 15.409915409982204, 63.97237166762352, 56.323910281062126, 55.74650086462498, 51.86730042099953, 48.66205461323261, 42.97321267426014, 43.08903805911541, 44.41790655255318, 47.6649197191, 47.429655343294144, 49.69306468963623, 50.092784240841866, 49.899636805057526, 51.78239397704601, 53.91354762017727, 54.66503329575062, 51.66606701910496, 51.13531529903412, 48.6021014302969, 47.97497548162937, 49.21671085059643, 48.34162160754204, 47.91160628199577, 48.77035640180111, 48.72981257736683, 49.20795612037182, 44.853868559002876, 40.69593407213688, 35.95786191523075, 37.12055392563343, 38.295435681939125, 38.447910100221634, 38.245966136455536, 39.39711436629295, 38.142626881599426, 36.483001336455345, 36.11282140016556, 38.311197236180305, 39.57112602889538, 38.150541856884956, 39.37752261757851, 38.842952102422714, 38.93762782216072, 38.49351145327091, 39.41487081348896, 38.97016167640686, 37.89402902126312, 42.60804086923599, 46.169540360569954, 49.88628052175045, 54.874025881290436, 47.79429517686367, 44.060782715678215, 41.54925808310509, 38.80947209894657, 39.59691524505615, 38.8439666479826, 40.98077058792114, 48.49517896771431, 52.8914974629879, 50.27765952050686, 56.231879219412804, 42.96655163168907, 48.237028419971466, 54.51039299368858, 46.97022959589958, 41.506928354501724, 41.80629149079323, 45.1375575363636, 46.56801737844944, 50.97239524126053, 50.95989391207695, 54.31878447532654, 56.616965755820274, 57.85260625183582, 47.32906714081764, 47.4301341176033, 50.976464822888374, 48.37046205997467, 39.597739800810814, 37.9557529091835, 39.54732410609722, 37.30632595717907, 39.20942723751068, 38.91781948506832, 39.300173968076706, 37.93603956699371, 38.78552958369255, 40.04530258476734, 38.92494410276413, 39.93685260415077, 38.2917270809412, 39.26859766244888, 37.83102460205555, 38.897027000784874, 39.01912584900856, 36.91362462937832, 39.344000816345215, 39.46033917367458, 40.68984679877758, 41.65520779788494, 41.0210370272398, 39.870302975177765, 40.70191115140915, 40.578098595142365, 38.918104469776154, 40.45157678425312, 40.51241531968117, 40.91294422745705, 41.52540676295757, 45.22666275501251, 45.03258056938648, 48.771545737981796, 48.06313835084438, 49.412445947527885, 49.19324330985546, 50.82330644130707, 50.11715233325958, 50.85220389068127, 48.145514130592346, 49.79946658015251, 48.813898265361786, 58.361303955316544, 57.25826494395733, 66.65571928024292, 57.383168041706085, 1.8590292264707386, 4.628466563299298, 0.357887803693302, 0.0930503272684291, 12.22336269915104, 63.77353593707085, 55.8676041662693, 44.245304614305496, 32.21525654196739, 56.03326007723808, 47.46644116938114, 42.07186684012413, 55.61313182115555, 38.012746050953865, 1.6799209685996175, 0.11368182487785816, 0.021099265868542716, 0.07960781382280402, 0.0725627172505483, 0.012349323424132308, 0.033935444662347436, 0.11940609154407866, 0.037128019248484634, 0.08309362208819948, 0.04510220678639598, 0.026317601186747197, 0.05427884425444063, 0.07384920056210831, 0.016293802145810332, 0.12507972889579833, 0.01349021034911857, 0.015454017520823982, 0.30475145496893674, 0.010324304839741671, 17.428864873945713, 65.25703713297844, 54.64336305856705, 45.4984013736248, 20.506511628627777, 49.251858964562416, 64.64001104235649, 45.25020249187946, 50.091442912817, 64.67185333371162, 33.222244307398796, 0.10194726783083752, 0.1080515437934082, 0.7245353248436004, 0.2588922798167914, 16.711360774934292, 66.3481105864048, 57.250201776623726, 57.25623965263367, 51.911142468452454, 50.60071438550949, 45.44009730219841, 45.657088458538055, 44.83006663620472, 47.58227415382862, 48.766435012221336, 51.15262717008591, 50.694075375795364, 53.935092464089394, 53.249943628907204, 56.01909823715687, 56.82750105857849, 53.87307979166508, 52.55108132958412, 51.49879239499569, 51.272480338811874, 50.681308060884476, 49.127354845404625, 52.414148077368736, 51.082908511161804, 51.46353408694267, 51.760579347610474, 47.00726620852947, 42.256358340382576, 38.959617242217064, 38.701633885502815, 39.23352554440498, 38.63695755600929, 39.51567180454731, 40.07033944129944, 39.62136313319206, 37.720530331134796, 39.013118371367455, 38.3773098886013, 40.75336039066315, 38.79736974835396, 40.502756237983704, 39.81306664645672, 40.18260061740875, 40.644762217998505, 41.1494929343462, 39.801640659570694, 40.493435338139534, 44.58933815360069, 47.798072174191475, 51.71321488916874, 54.4379498809576, 49.522241055965424, 45.82218959927559, 43.244415521621704, 41.76783375442028, 43.31899791955948, 40.66883012652397, 43.691260144114494, 50.452522337436676, 54.44966085255146, 52.04704977571964, 57.12925426661968, 46.272058859467506, 50.49530044198036, 56.39527045190334, 50.56331679224968, 43.03636148571968, 44.969397559762, 48.55120316147804, 49.130751863121986, 52.543717324733734, 53.99079367518425, 55.919847562909126, 55.26421934366226, 58.042368069291115, 48.312119990587234, 48.06080147624016, 54.052616357803345, 51.09472967684269, 41.737351790070534, 39.01216082274914, 42.31316529214382, 38.79633240401745, 39.8231665045023, 40.112851560115814, 41.4766401797533, 40.54616890847683, 41.246216744184494, 40.62721475958824, 39.347363635897636, 41.48645505309105, 41.354959309101105, 39.94947172701359, 40.932098999619484, 41.17421440780163, 40.12840412557125, 40.831837579607964, 40.00494875013828, 42.10748992860317, 42.085352316498756, 42.93924629688263, 43.07890400290489, 42.063389495015144, 41.54947467148304, 42.05652706325054, 40.57724364101887, 42.072600200772285, 42.15805381536484, 42.76770070195198, 45.67215844988823, 47.931638807058334, 48.06123085319996, 51.60540707409382, 49.33724798262119, 53.57686668634415, 50.86026705801487, 53.821797743439674, 51.566850543022156, 52.735390439629555, 50.597115978598595, 50.46946182847023, 51.52539476752281, 62.0569134503603, 57.90058247745037, 68.0329629778862, 60.86426004767418, 2.4303047033026814, 2.548923888243735, 0.44173413421958685, 0.09927008883096278, 13.84127028286457, 68.71264770627022, 61.371118649840355, 51.990995183587074, 39.070331901311874, 62.242092713713646, 54.8459529876709, 48.77187632024288, 63.77950921654701, 49.014162719249725, 3.062020093202591, 0.24544440064346418, 0.023854834216763265, 0.0025897686145981424, 0.01916860208439175, 0.03511623130179942, 0.023638926759304013, 0.05924036864598747, 0.044978524165344425, 0.051892950796172954, 0.18163433560403064, 0.09152148079010658, 0.13569503818871453, 0.21458690956933424, 0.1770783355459571, 0.1909731508931145, 0.09740995505126193, 0.12223892859765328, 0.4436184174846858, 0.08967878005933017, 22.67621610313654, 73.79543736577034, 62.13159464299679, 54.197624176740646, 25.655951611697674, 52.10493966937065, 58.323917761445045, 50.67728407680988, 58.488988503813744, 69.64700996875763, 37.900017499923706, 0.12729400070384145, 0.15329529298469424, 3.640696741640568, 1.842767761554569, 18.02595343440771, 68.3902882039547, 60.56247644126415, 58.25285777449608, 57.05199681222439, 52.61342838406563, 48.489122092723846, 47.67612911760807, 48.96867536008358, 51.652197763323784, 51.27762906253338, 54.79922689497471, 53.36246319115162, 54.918050318956375, 56.651566699147224, 58.06544803082943, 59.58856210112572, 55.128741413354874, 55.7225089520216, 52.07703776657581, 56.03446461260319, 53.904352113604546, 52.25720129907131, 52.98769690096378, 53.17887224256992, 54.04987670481205, 54.1019719094038, 50.38168653845787, 44.32283565402031, 39.835804626345634, 41.85114428400993, 40.99634975194931, 42.1844357997179, 42.34010584652424, 42.589862644672394, 41.36997610330582, 38.58957789838314, 40.40560305118561, 40.07672309875488, 42.71836414933205, 40.619181990623474, 42.93609246611595, 41.812127977609634, 41.758816838264465, 42.015918642282486, 42.75837980210781, 41.2409046292305, 42.66581676900387, 45.79862706363201, 49.72845979034901, 54.31444890797138, 58.14305506646633, 50.778962820768356, 48.05820241570473, 44.43900682032108, 44.9159724265337, 46.54742628335953, 44.253090396523476, 46.20889484882355, 52.97314368188381, 56.146266013383865, 53.82126957178116, 59.8948522657156, 48.133404180407524, 53.166070729494095, 58.05449701845646, 52.91103981435299, 44.559798538684845, 46.88718505203724, 51.98243424296379, 51.235899701714516, 54.496751725673676, 53.497021570801735, 58.07896010577679, 56.056355237960815, 58.6511941999197, 49.290316700935364, 51.129927188158035, 56.05280242860317, 51.75059728324413, 44.93168458342552, 42.04622581601143, 43.304725885391235, 40.65206162631512, 41.91644378006458, 41.01099036633968, 42.49472714960575, 42.112387865781784, 43.35365206003189, 43.98349106311798, 40.75639642775059, 42.6417488604784, 43.03786240518093, 41.49361006915569, 42.77810834348202, 42.91454002261162, 42.58277602493763, 42.14357279241085, 43.456523939967155, 43.579527139663696, 44.713105112314224, 46.82087101042271, 45.10638400912285, 44.34883385896683, 45.90125195682049, 45.04586845636368, 43.417378440499306, 43.770672082901, 45.34459702670574, 45.94464182853699, 48.08530256152153, 51.05820223689079, 49.632245153188705, 54.104445576667786, 52.74686582386494, 55.402410328388214, 53.99175502359867, 55.54138787090778, 54.96492460370064, 55.4117426276207, 53.99322934448719, 52.4744014441967, 52.402809485793114, 63.470452800393105, 61.26007340848446, 70.00537633895874, 63.63977171480656, 3.059061001986265, 6.282146377488971, 1.925239961128682, 0.22353097650920972, 15.29908960685134, 76.50296688079834, 68.97686272859573, 57.04260751605034, 44.197446182370186, 67.81399592757225, 58.88700194656849, 61.348445266485214, 71.80875197052956, 61.674380376935005, 5.795221505686641, 0.23934517870657146, 0.1346535823540762, 0.2218536485452205, 0.18808621127391234, 0.10358656814787537, 0.14983660279540345, 0.24554138450184837, 0.16840424708789214, 0.21791958308313042], [0.0841636951372493, 0.043715273786801845, 0.023575263476232067, 0.06552479724632576, 0.09655740548623726, 0.04363966378150508, 0.014071336099732434, 0.053283123270375654, 0.2054903461248614, 0.09029122258652933, 16.590322069823742, 57.13402681052685, 49.95405748486519, 43.02466191351414, 25.522421076893806, 35.4601988196373, 38.56531620025635, 37.00351640582085, 46.30162127315998, 58.96031141281128, 28.804648853838444, 0.046138159596011974, 0.17021541396388784, 0.4838849458610639, 0.4735162225551903, 29.157553017139435, 65.69346651434898, 54.39905896782875, 56.59415937960148, 52.21624329686165, 51.1029714345932, 49.641832038760185, 50.894761607050896, 50.76670467853546, 53.52414071559906, 49.91630271077156, 50.35765662789345, 53.60505357384682, 52.30662144720554, 52.69008927047253, 50.094197764992714, 51.141691356897354, 52.8313010931015, 50.50861492753029, 51.041851714253426, 49.49125751852989, 50.94928868114948, 49.7112201154232, 49.43543091416359, 46.83702394366264, 47.98458516597748, 44.450508803129196, 40.69168969988823, 37.58198596537113, 38.186624720692635, 38.37667152285576, 38.84348787367344, 39.246448650956154, 38.22241500020027, 39.07392270863056, 36.917025446891785, 34.79470632970333, 35.724011063575745, 37.60818935930729, 37.390958815813065, 37.70589731633663, 38.037383928895, 37.84544862806797, 38.50710712373257, 37.7568069845438, 38.04975226521492, 37.965814769268036, 36.74918085336685, 44.43214438855648, 51.84722989797592, 47.18030132353306, 50.833638086915016, 54.06962424516678, 46.0054499655962, 44.63459372520447, 37.94716916978359, 38.3280835300684, 36.28586031496525, 40.55161401629448, 49.70129884779453, 52.2753719240427, 51.13840073347092, 53.204144686460495, 42.87897393107414, 47.28497050702572, 52.2835148870945, 48.51474031805992, 41.22708097100258, 41.1628682166338, 43.223459646105766, 45.72454243898392, 49.36514608561993, 51.00468210875988, 48.78656253218651, 45.313488095998764, 43.42978857457638, 49.07599300146103, 53.828033208847046, 49.582441225647926, 48.49979192018509, 39.7122922539711, 39.52179707586765, 38.50757449865341, 36.5729159116745, 37.75411292910576, 39.841918498277664, 37.9858472943306, 37.83026844263077, 38.480136170983315, 40.05928963422775, 37.862578108906746, 40.043725669384, 39.18219789862633, 39.8663055896759, 39.56177473068237, 39.09405402839184, 39.537038058042526, 40.05618520081043, 37.98220328986645, 38.775775507092476, 39.965860247612, 39.65162090957165, 39.644526690244675, 37.31536187231541, 39.5599964261055, 40.417804196476936, 38.58904592692852, 42.354533672332764, 39.300610944628716, 39.915699139237404, 42.45087370276451, 42.32037350535393, 44.52077843248844, 44.37320955097675, 45.13152725994587, 44.43549580872059, 45.652619898319244, 45.707150772213936, 44.653284922242165, 46.295742988586426, 45.49722723662853, 47.027059346437454, 49.956584349274635, 59.130937457084656, 61.25448390841484, 62.90606528520584, 60.78273922204971, 5.660301670432091, 1.2496094964444637, 0.19477073539746925, 0.13597432320239022, 11.159704774618149, 61.31211541593075, 58.963104262948036, 50.5599045753479, 25.869370959699154, 29.774529710412025, 33.28314743936062, 45.79410530626774, 55.68463258445263, 45.06127282977104, 3.1866626674309373, 0.17052002105629072, 0.012411688876454718, 0.039196833822643384, 0.05874043199582957, 0.02765262652246747, 0.10162417383980937, 0.02914022814366035, 0.03525112406350672, 0.019983812344435137, 0.07158774300478399, 0.025690881593618542, 0.024980087800940964, 0.033741951920092106, 0.043246410859865136, 0.01627163048397051, 0.019163946963089984, 0.028622787940548733, 0.15558017272269353, 0.024092803869280033, 20.125530771911144, 64.97079849243164, 56.52156047523022, 49.707792699337006, 27.897006757557392, 44.20086219906807, 44.9026807397604, 40.450284853577614, 51.3374188542366, 62.56538316607475, 30.945902355015278, 0.11186478019226342, 0.1594974656472914, 0.8632289513479918, 0.6389954430051148, 30.880393870174885, 67.13818699121475, 55.90236470103264, 58.457750380039215, 53.80790188908577, 51.56583219766617, 51.64459057152271, 52.640832513570786, 52.137811705470085, 53.8919647783041, 52.786258310079575, 53.7235502153635, 54.468196257948875, 55.67713938653469, 54.57392178475857, 51.511187329888344, 52.604369670152664, 54.505430459976196, 52.59964272379875, 53.16771984100342, 51.35014057159424, 53.52762512862682, 50.29567055404186, 51.65536679327488, 49.30388577282429, 52.326954156160355, 46.591424122452736, 43.551553040742874, 39.006096348166466, 40.32692447304726, 40.026037618517876, 40.669031515717506, 40.03136493265629, 40.00459536910057, 40.95232531428337, 37.58702449500561, 36.734623834490776, 38.101995661854744, 39.33769315481186, 38.496190309524536, 38.61517332494259, 40.610298067331314, 39.63232174515724, 40.19099436700344, 39.20945003628731, 40.69675862789154, 40.65865807235241, 40.42655512690544, 46.603078097105026, 51.58497177064419, 49.191856384277344, 52.47222416102886, 55.17633005976677, 49.02664124965668, 46.20976500213146, 39.84724581241608, 41.156735345721245, 39.67223480343819, 42.23106689751148, 52.9315435141325, 53.76589134335518, 53.78101833164692, 52.4446452409029, 44.431050047278404, 48.86078394949436, 53.82228411734104, 47.85916529595852, 42.82436326146126, 44.299155324697495, 43.83881002664566, 47.300196290016174, 52.00500503182411, 52.80377916991711, 51.15157462656498, 47.33046546578407, 46.68058253824711, 51.90764285624027, 53.504267781972885, 52.354438081383705, 50.22268407046795, 40.60853876173496, 39.91392843425274, 41.391129568219185, 38.45857992768288, 39.60842102766037, 41.193144991993904, 40.87751492857933, 39.852542728185654, 40.65903425216675, 41.30047023296356, 40.06600387394428, 40.4982078820467, 40.45039884746075, 41.956037655472755, 40.89385025203228, 41.2710066139698, 40.18809512257576, 40.73241971433163, 41.19719937443733, 41.497797444462776, 43.031615540385246, 42.90129013359547, 43.022268041968346, 40.18301099538803, 42.44475983083248, 41.121260449290276, 39.8015570640564, 43.59918728470802, 41.64665825664997, 41.65960036218166, 43.718744069337845, 43.2449284940958, 46.85401663184166, 45.7398746162653, 47.05558441579342, 47.424700409173965, 47.683789506554604, 48.838080167770386, 46.18575409054756, 47.96364448964596, 47.90530242025852, 49.4605665653944, 51.8701958656311, 60.641147419810295, 63.337277546525, 64.92524653673172, 66.33635401725769, 6.931608477607369, 1.2356166285462677, 0.36407731531653553, 0.15062756894621998, 12.09228778257966, 67.1905329823494, 62.52624146640301, 56.82724267244339, 33.34336280822754, 40.03711402416229, 39.62704382836819, 53.33224721252918, 60.85613988339901, 54.94926944375038, 4.740218091756105, 0.08436894349870272, 0.04840332047024276, 0.054618877766188234, 0.02374829706241144, 0.047645706436014734, 0.04296783088648226, 0.011349160686222604, 0.02341626946872566, 0.045863995401305147, 0.2471028928994201, 0.15174390748143196, 0.11260692044743337, 0.19965264218626544, 0.2902272983919829, 0.1239612752397079, 0.07074829234625213, 0.09948309263563715, 0.33985857269726694, 0.22888892650371417, 25.693239010870457, 75.23759678006172, 63.818700313568115, 55.637807697057724, 35.259493589401245, 43.12441796064377, 42.82788947224617, 48.59159119427204, 57.00882352888584, 68.50968539714813, 34.59878124296665, 0.1830704655731097, 0.45196374936494976, 3.572735725902021, 1.3590023014694452, 34.24416147172451, 68.9271005988121, 59.87021058797836, 61.03484809398651, 57.55933038890362, 56.52903847396374, 53.976084664464, 53.12605507671833, 56.4084367454052, 57.022495195269585, 54.78637978434563, 55.349064990878105, 57.39340849220753, 56.688398122787476, 56.64064608514309, 51.35204426944256, 54.855931252241135, 55.47182880342007, 53.71221162378788, 53.18064674735069, 52.20135569572449, 54.90627855062485, 52.20896668732166, 51.51896931231022, 52.75739125907421, 54.306218549609184, 49.238008707761765, 44.7618792951107, 40.26315249502659, 41.8427961319685, 41.56645596027374, 42.04493008553982, 42.828725427389145, 40.983217656612396, 43.31850774586201, 40.570571199059486, 38.85682515799999, 40.154003351926804, 41.025270000100136, 40.22077336907387, 41.532877162098885, 42.8942035138607, 42.96413876116276, 44.480983167886734, 41.05669051408768, 41.962691098451614, 42.86151386797428, 41.204525381326675, 48.333421647548676, 56.09660267829895, 52.07052491605282, 54.808897376060486, 56.931436881423, 51.71650551259518, 48.59222196042538, 40.82102335989475, 43.12592267990112, 41.11197754740715, 45.326608791947365, 54.25796493887901, 56.45711213350296, 53.458313047885895, 55.68652108311653, 48.554668575525284, 51.02460823953152, 55.88416367769241, 51.762080267071724, 44.04750622808933, 46.98798604309559, 46.656252443790436, 49.73635196685791, 54.15826588869095, 55.07384195923805, 54.017217457294464, 50.29722847044468, 45.59929355978966, 50.44770799577236, 54.39000025391579, 55.00573441386223, 52.00142942368984, 43.38957913219929, 42.98108585178852, 43.85440818965435, 39.46809455752373, 41.58745363354683, 44.46010708808899, 43.64131562411785, 41.91031850874424, 41.64937511086464, 44.29219029843807, 42.6490368694067, 43.179777190089226, 42.890988886356354, 43.446507677435875, 43.199524730443954, 44.22192066907883, 42.52203248441219, 42.36675761640072, 42.63770967721939, 43.210981115698814, 45.10212063789368, 45.11707283556461, 45.482883006334305, 41.960916593670845, 44.56026591360569, 43.962546586990356, 42.54223220050335, 46.371168941259384, 43.96992199122906, 44.549903869628906, 48.231864497065544, 46.13473802804947, 48.959248065948486, 48.98935765028, 51.37415528297424, 49.142679423093796, 52.210794389247894, 49.2005655169487, 49.079017639160156, 50.21049052476883, 51.07521012425423, 52.05422379076481, 55.7923986017704, 63.298401832580566, 66.31882175803185, 66.9254820048809, 70.29628872871399, 11.107712164521217, 3.257383522577584, 1.8060137587599456, 0.24875348870409653, 14.138592928647995, 74.09918546676636, 71.20402202010155, 63.67270454764366, 34.781521037220955, 45.02251870930195, 45.795788615942, 61.21006429195404, 69.85817223787308, 68.78909200429916, 6.975369779393077, 0.3526862687431276, 0.12860399525379762, 0.16643417155137286, 0.11872863688040525, 0.10913172489381395, 0.30760821886360645, 0.19955948780989274, 0.12398393300827593, 0.09911271641612984], [0.051118063274770975, 0.038933441901463084, 0.05539759848034009, 0.05651250095979776, 0.08904241069103591, 0.04780256676895078, 0.034163914824603125, 0.029773122405458707, 0.06477649716543965, 0.11644475162029266, 13.45930527895689, 60.81661820411682, 52.55752198398113, 41.41926325857639, 19.218430146574974, 23.25697124004364, 37.70472317934036, 37.15377554297447, 47.35663466155529, 61.14781603217125, 22.902488261461258, 0.24403636838542297, 0.10739406774519011, 0.432338307145983, 2.3129859985783696, 38.30219931900501, 61.29868693649769, 57.343095391988754, 56.813544407486916, 53.11534345149994, 55.48997662961483, 53.336742371320724, 54.9335914850235, 52.18646429479122, 54.76343661546707, 53.103583082556725, 52.077459543943405, 52.185206562280655, 51.49000346660614, 50.761578753590584, 46.48276895284653, 46.45047828555107, 47.61422663927078, 48.3479330688715, 47.853347808122635, 48.20013999938965, 50.046263337135315, 52.576843947172165, 50.77458545565605, 48.16572144627571, 47.87832386791706, 42.07863807678223, 35.17986126244068, 37.14294232428074, 36.92853502929211, 38.86209547519684, 38.19751113653183, 37.96150200068951, 38.2717477530241, 37.13684745132923, 36.55392073094845, 35.2262681722641, 37.13621288537979, 37.82847873866558, 39.85065422952175, 37.58578196167946, 37.33080804347992, 38.62569496035576, 37.87294775247574, 37.749393582344055, 37.37471088767052, 37.5820467621088, 36.96904845535755, 43.10142159461975, 49.50611852109432, 50.93529023230076, 45.153357088565826, 52.86466330289841, 49.351159036159515, 45.61240665614605, 40.816087424755096, 38.40332329273224, 38.28232638537884, 39.367548152804375, 48.10339339077473, 52.314323633909225, 51.64661966264248, 53.847936540842056, 48.068731650710106, 47.341872453689575, 49.368470907211304, 46.067006662487984, 44.608394131064415, 41.87406465411186, 39.886406511068344, 40.97134709358215, 46.3652640581131, 49.47245232760906, 53.023483380675316, 54.48444418609142, 46.14413112401962, 39.72684167325497, 50.18142968416214, 51.95912629365921, 48.867870569229126, 42.796001583337784, 37.830093652009964, 40.17849303781986, 37.70834058523178, 39.90337260067463, 40.09067215025425, 41.291992887854576, 38.35493288934231, 39.20006833970547, 38.204692751169205, 37.895317152142525, 36.999321430921555, 38.64631645381451, 38.69694493710995, 39.784267991781235, 39.162499755620956, 39.58028353750706, 39.079421013593674, 39.98621575534344, 38.35609182715416, 39.42981921136379, 38.56859162449837, 38.66370432078838, 38.49053621292114, 37.97048091888428, 38.566102758049965, 39.32322733104229, 39.06113639473915, 40.14007709920406, 38.25557202100754, 41.170334815979004, 40.15086092054844, 39.373266845941544, 39.548065066337585, 40.04699729382992, 42.32090167701244, 42.29415111243725, 43.2454414665699, 43.95703688263893, 44.38794136047363, 45.60701474547386, 53.757691383361816, 58.42708982527256, 61.48746460676193, 60.98958492279053, 68.17062199115753, 58.42807397246361, 3.9228874118998647, 0.34837323299143463, 0.12491538771428168, 0.01779509268089896, 11.382008995860815, 63.79944294691086, 58.079397082328796, 55.846614092588425, 36.15178070962429, 29.999540336430073, 28.036964647471905, 45.576361790299416, 52.692695930600166, 42.84025780856609, 3.175676269456744, 0.1957297237822786, 0.05868009167897981, 0.12916642444906756, 0.02355233667913126, 0.10829847858985886, 0.04514221225690562, 0.030183114467945416, 0.062264587031677365, 0.034061457627103664, 0.0572252076381119, 0.023353908654826228, 0.026474682308617048, 0.0712217899854295, 0.0880063947988674, 0.08731190042453818, 0.06602663750527427, 0.06316151702776551, 0.0940568650548812, 0.09121350434725173, 17.277832478284836, 70.31708121299744, 57.232167944312096, 46.87087632715702, 23.791974931955338, 24.82551757246256, 33.41727264225483, 41.65753707289696, 52.28315390646458, 66.3874688744545, 25.026887767016888, 0.43900148710235953, 0.2483477268833667, 0.05092065199278295, 2.616703938692808, 40.38557052612305, 62.34672769904137, 60.847252160310745, 59.11440074443817, 54.77911077439785, 56.89269036054611, 56.28609471023083, 56.06870457530022, 55.69579638540745, 57.13296666741371, 55.11228829622269, 54.456413090229034, 54.21060808002949, 51.217204704880714, 50.213556960225105, 47.7715115994215, 46.804980263113976, 46.647315323352814, 49.32074546813965, 49.30287502706051, 50.10990992188454, 51.184800043702126, 52.53762625157833, 51.77508696913719, 49.858355820178986, 48.76600943505764, 43.23290593922138, 37.0879402756691, 38.365435525774956, 38.82111847400665, 39.658650532364845, 38.47390830516815, 39.63524378836155, 40.62758333981037, 38.337883204221725, 38.627294674515724, 37.37924784421921, 38.42923030257225, 39.82607714831829, 40.42725808918476, 39.27387177944183, 39.47410583496094, 40.17362929880619, 39.109074622392654, 39.35397908091545, 39.202663600444794, 40.32477378845215, 37.78313957154751, 44.61612291634083, 51.11869119107723, 52.553338408470154, 47.61461801826954, 53.56929749250412, 51.10321842133999, 46.29597097635269, 42.50864960253239, 40.27916483581066, 40.10046802461147, 40.899698138237, 50.842487812042236, 53.79612632095814, 52.646216824650764, 55.52938051521778, 49.45530764758587, 49.73979838192463, 52.26560264825821, 48.695603013038635, 44.61364544928074, 43.614135682582855, 41.252254620194435, 42.50045724213123, 48.993864208459854, 51.788184866309166, 55.84771603345871, 54.700386598706245, 46.98605194687843, 43.69312584400177, 55.60462407767773, 53.91710042953491, 51.477171555161476, 42.682680264115334, 38.86881731450558, 42.708028703927994, 38.28576900064945, 41.05724908411503, 41.89109534025192, 42.48433470726013, 39.24695022404194, 40.36877162754536, 38.80019299685955, 39.16401967406273, 39.964982494711876, 40.976940393447876, 39.34358663856983, 41.97127103805542, 41.03771433234215, 41.99861437082291, 40.305801406502724, 40.347306579351425, 40.764102414250374, 41.288956850767136, 40.95805920660496, 40.06509192287922, 40.48442222177982, 40.625915229320526, 41.241235211491585, 41.371663212776184, 40.40326237678528, 42.17122010886669, 39.88652050495148, 43.69269646704197, 41.90560296177864, 41.66301257908344, 42.445945367217064, 41.848959401249886, 44.177121073007584, 44.96374346315861, 47.33764708042145, 45.418651252985, 47.17840522527695, 48.57784353196621, 56.00645251572132, 61.99036002159119, 63.40164229273796, 63.24573665857315, 69.20106589794159, 65.81112340092659, 8.155265841633081, 0.41774331999477, 0.3434369119349867, 0.06871450343169272, 12.60217197239399, 67.84420430660248, 62.26075351238251, 58.535672798752785, 35.06896421313286, 34.2702242732048, 32.6750622689724, 54.030972719192505, 59.24146592617035, 51.66390113532543, 4.943399839103222, 0.03450000011071097, 0.06244212359888479, 0.07105928190867417, 0.02126863138983026, 0.03995238097559195, 0.02592659140645992, 0.056676619497011416, 0.05907902945182286, 0.01803358183678938, 0.20963590883184224, 0.191978627408389, 0.17446462501538917, 0.13067430525552481, 0.17122776276664808, 0.2435150690143928, 0.14903236704412848, 0.11438301342423074, 0.2627509430749342, 0.25040558364707977, 21.416080221533775, 80.1924017071724, 64.18654337525368, 55.915523394942284, 29.74708568304777, 32.6205237954855, 45.70436932146549, 50.07013365626335, 58.65444302558899, 73.22513356804848, 28.81081972271204, 0.5401399475522339, 0.35943509254138917, 1.7370333289727569, 4.008475681766868, 42.027356028556824, 61.18810907006264, 63.002625703811646, 62.09686070680618, 57.72843271493912, 59.64189223945141, 60.33602759242058, 58.13989743590355, 57.79373601078987, 59.631195813417435, 56.38466142117977, 54.44289341568947, 54.293527230620384, 52.58225865662098, 49.88971173763275, 48.271971344947815, 47.28985704481602, 47.89769522845745, 50.114264488220215, 50.025691241025925, 53.35278511047363, 52.61955365538597, 54.38514791429043, 55.59955894947052, 52.0482163131237, 52.00937859714031, 46.16995073854923, 37.41942308843136, 39.761621206998825, 41.2139792740345, 41.70496612787247, 41.01677365601063, 41.52766764163971, 41.51080034673214, 40.038858130574226, 41.1455487459898, 38.55857916176319, 40.705319568514824, 41.06293357908726, 43.94336901605129, 40.00687524676323, 41.954445540905, 42.39164248108864, 41.74626611173153, 41.22602082788944, 41.79488070309162, 41.824709102511406, 40.756556019186974, 45.76130546629429, 53.64992156624794, 53.269204795360565, 49.916135519742966, 55.310614854097366, 54.19645003974438, 49.25736106932163, 45.23479051887989, 43.42011049389839, 42.32397571206093, 43.60056281089783, 52.16734752058983, 55.194291695952415, 56.0140673071146, 56.718659698963165, 51.07877433300018, 52.903645411133766, 53.69908332824707, 50.008850544691086, 46.77826389670372, 45.99235586822033, 41.771937534213066, 45.799497216939926, 51.24016687273979, 53.017677292227745, 57.39728048443794, 58.02054964005947, 49.89191561937332, 45.94133220613003, 55.8993324637413, 54.05993476510048, 53.199900314211845, 45.09395107626915, 41.723410338163376, 45.69360829889774, 41.04713402688503, 45.86228884756565, 43.075305595993996, 45.187391862273216, 41.54247544705868, 41.853975132107735, 41.14825040102005, 41.13407716155052, 41.933432668447495, 42.949319556355476, 42.39165008068085, 43.61551120877266, 42.32142984867096, 44.65877562761307, 41.897733584046364, 42.660265266895294, 43.07460643351078, 43.474360182881355, 43.201557621359825, 43.26591856777668, 44.17693108320236, 42.51752972602844, 43.607128858566284, 44.9763397872448, 42.57980838418007, 44.26661767065525, 42.14472033083439, 48.092176392674446, 44.59321394562721, 43.932771384716034, 45.43851658701897, 44.25443172454834, 47.48496897518635, 47.791692316532135, 48.27980652451515, 49.65299963951111, 49.00680631399155, 52.61584885418415, 59.02932330965996, 64.75632280111313, 65.62664330005646, 67.91724398732185, 71.1363172531128, 69.08957228064537, 13.576452992856503, 0.9363978845067322, 1.1449241638183594, 0.25154115865007043, 13.180874269455671, 74.9773259460926, 68.18463563919067, 70.2225498855114, 46.60624332726002, 43.49674478173256, 41.05051204562187, 63.15758138895035, 67.20677331089973, 63.68909306824207, 8.011593651026487, 0.2473900595214218, 0.22513156640343368, 0.20967919088434428, 0.10652610377292149, 0.2510721510043368, 0.09814073302550241, 0.1260049792472273, 0.19510090205585584, 0.12461455073207617], [0.06451439287047833, 0.06979193858569488, 0.042817089561140165, 0.03593743625970092, 0.03683075941808056, 0.003308653208478063, 0.02741876094660256, 0.06173785513965413, 0.12454305222490802, 0.05295120514347218, 13.636540118604898, 62.12519958615303, 49.81915332376957, 45.64544588327408, 20.529447197914124, 22.590777687728405, 30.355611629784107, 35.30460096895695, 47.16425098478794, 56.741230487823486, 23.225043453276157, 0.32467892160639167, 0.04453151377674658, 0.5504812113940716, 3.439853531308472, 47.875086441636086, 56.653272807598114, 57.36622095108032, 56.911738738417625, 54.95781138539314, 55.01233845949173, 55.57355314493179, 54.11799184978008, 55.794005915522575, 54.238612577319145, 53.663407042622566, 51.704832538962364, 49.379756301641464, 48.544310331344604, 46.48710072040558, 49.49737139046192, 49.06635291874409, 49.837012365460396, 49.072782173752785, 47.025041654706, 49.651023745536804, 52.00265295803547, 48.67528170347214, 47.62276478111744, 47.72654861211777, 42.41268955171108, 37.41479113698006, 35.43271489441395, 36.72473296523094, 38.278978765010834, 40.1051189750433, 37.39344768226147, 37.935868576169014, 38.216019943356514, 37.47300401329994, 37.460658475756645, 36.375964879989624, 37.027732506394386, 37.64273330569267, 37.705171555280685, 36.35744087398052, 36.47923953831196, 37.82388478517532, 37.34508387744427, 36.06579512357712, 36.08420893549919, 37.99987994134426, 37.13872455060482, 42.24010281264782, 48.02884519100189, 48.86344000697136, 45.86562126874924, 50.13859078288078, 49.9641877412796, 45.98768591880798, 42.28839822113514, 39.00831922888756, 38.33908773958683, 37.02312335371971, 42.55109332501888, 48.54616843163967, 49.686817824840546, 52.46043339371681, 48.07253524661064, 48.18203777074814, 52.03175559639931, 49.35378469526768, 50.83779886364937, 46.663479655981064, 40.944653525948524, 39.57149460911751, 41.11940994858742, 44.49395567178726, 49.63754586875439, 52.16170482337475, 54.19750638306141, 52.496751844882965, 38.959917426109314, 45.57044930756092, 50.248518884181976, 44.29743021726608, 39.140160754323006, 37.17722408473492, 37.4233178794384, 37.31114789843559, 39.46357659995556, 39.945010766386986, 40.11466786265373, 38.80070976912975, 37.83771224319935, 37.553939670324326, 38.34811605513096, 37.31215864419937, 39.405793100595474, 38.335857912898064, 40.47390058636665, 37.96257734298706, 40.348533913493156, 40.118999630212784, 38.84269751608372, 37.86833480000496, 40.674818605184555, 40.059745609760284, 39.56069938838482, 39.71047215163708, 39.215620905160904, 38.80258306860924, 39.17121648788452, 39.002433344721794, 39.36068572103977, 40.87411791086197, 42.346500903367996, 42.404930368065834, 42.67635740339756, 41.609386056661606, 41.76654942333698, 42.60095804929733, 42.69922077655792, 43.248678892850876, 46.13031506538391, 52.57559381425381, 59.30850952863693, 58.71144376695156, 63.57131078839302, 64.80604693293571, 65.65850079059601, 56.40666224062443, 6.830913880839944, 0.37983575253747404, 0.18663829599972814, 0.0330541368748527, 10.838256273418665, 62.108738869428635, 57.963621094822884, 59.472588524222374, 52.40980111062527, 37.39283211529255, 28.70010696351528, 48.52277308702469, 56.94510854780674, 46.4053975045681, 2.5293072033673525, 0.29815180285368115, 0.029382633983914275, 0.029690217088500503, 0.06169289212266449, 0.06673809737549163, 0.037802393999299966, 0.041878877600538544, 0.03179935069056228, 0.013826401391270338, 0.04760350420838222, 0.009458655440539587, 0.019144252219120972, 0.08470572269288823, 0.07441707712132484, 0.03417718813579995, 0.06052396129234694, 0.10306632262654603, 0.19020428590010852, 0.021580776847258676, 17.484757974743843, 68.85168984532356, 56.50515295565128, 52.48755633831024, 28.215214982628822, 25.41302114725113, 34.84812006354332, 44.10815477371216, 51.210790649056435, 63.27250622212887, 24.18134953826666, 0.3076894098194316, 0.19474468601401895, 0.5589506006799638, 3.7669623037800193, 50.52876144647598, 55.42609065771103, 57.574035599827766, 58.07964786887169, 58.06050069630146, 56.57480701804161, 56.669292747974396, 56.34951330721378, 56.5669946372509, 55.926071628928185, 53.39161902666092, 52.59828619658947, 49.95417907834053, 48.161917850375175, 47.61789724230766, 50.76849818229675, 49.95268955826759, 50.12135490775108, 49.97782900929451, 48.991797119379044, 49.85300570726395, 52.93576508760452, 52.16538302600384, 50.50345100462437, 49.90946687757969, 44.3901414424181, 39.65963467955589, 37.2920311242342, 38.093499317765236, 39.19562637805939, 41.872875317931175, 40.086328983306885, 40.7170457392931, 40.01604415476322, 37.958397567272186, 38.10524828732014, 38.97741548717022, 38.1797356903553, 39.77038733661175, 40.14266096055508, 37.99496300518513, 38.17131534218788, 39.97010841965675, 38.54370296001434, 39.52848471701145, 38.76781113445759, 39.66603733599186, 38.1635257601738, 43.64688232541084, 50.05483187735081, 52.39072233438492, 48.81577916443348, 52.11263805627823, 54.00454133749008, 48.08066301047802, 43.25819358229637, 40.74270196259022, 40.817991122603416, 39.139404594898224, 45.40565975010395, 49.297547712922096, 52.630687057971954, 54.606805220246315, 51.61826938390732, 50.883305221796036, 53.7956665456295, 51.0057308524847, 52.75663509964943, 47.59369634091854, 43.2247743755579, 41.92216247320175, 43.82098898291588, 47.356399074196815, 53.13118100166321, 53.0686591565609, 57.796559259295464, 52.13219940662384, 42.62835457921028, 50.17730310559273, 52.59325906634331, 47.00866833329201, 40.54908715188503, 39.21623267233372, 38.84750045835972, 38.77276986837387, 41.15421988070011, 41.42281986773014, 42.10220441222191, 40.14268755912781, 37.90053807199001, 40.950227826833725, 40.15190966427326, 39.30466152727604, 40.01917518675327, 41.390871182084084, 41.23303905129433, 41.51123732328415, 41.35810934007168, 41.43608495593071, 40.08904583752155, 40.21463669836521, 42.67792671918869, 40.87970361113548, 41.1233389377594, 41.077270209789276, 42.009272798895836, 40.322018936276436, 41.19652681052685, 41.55003324151039, 41.49286150932312, 43.62364277243614, 43.75055976212025, 42.97798901796341, 45.447620898485184, 44.17156957089901, 43.82337525486946, 44.16697561740875, 43.00666607916355, 45.79319715499878, 47.25664682686329, 55.47713711857796, 63.1878961622715, 61.66404873132706, 64.24782648682594, 67.48746424913406, 64.35357481241226, 60.202320367097855, 12.383019682019949, 1.0208926443010569, 0.26947753212880343, 0.059601304747047834, 11.048275753855705, 66.10750749707222, 63.866866528987885, 63.387377858161926, 50.61690911650658, 44.02777388691902, 35.687730610370636, 54.6849974244833, 63.5458255559206, 54.53020893037319, 4.890838209539652, 0.20134672784479335, 0.0466986666287994, 0.06499954222817905, 0.11676984198857099, 0.0836867761972826, 0.1240072661312297, 0.06688473091344349, 0.033294960085186176, 0.055851937577244826, 0.10599474087939598, 0.16577599046286196, 0.09481317290919833, 0.19584975874749944, 0.21886542061110958, 0.07229926966829225, 0.0845087344350759, 0.1435841273632832, 0.2531654230551794, 0.153133163403254, 21.67014978826046, 78.49566355347633, 60.8837454020977, 60.60586251318455, 30.355917513370514, 32.83183425664902, 42.052628472447395, 48.68286609649658, 59.127540439367294, 67.41114154458046, 27.205962538719177, 0.40374032920226455, 1.0145062557421625, 1.2913564313203096, 5.247954921796918, 51.73023417592049, 56.85229852795601, 60.287720784544945, 59.4022960960865, 58.42116594314575, 58.967519626021385, 58.49012464284897, 57.45191775262356, 56.94847136735916, 55.53610235452652, 55.41808448731899, 55.201803892850876, 52.17757277190685, 50.36750569939613, 48.49806681275368, 53.77184182405472, 51.95613205432892, 51.939914524555206, 52.072949185967445, 49.42943103611469, 51.93409703671932, 55.10470770299435, 53.703760877251625, 51.972824558615685, 52.86670379340649, 46.415941938757896, 42.3134882748127, 38.899105489254, 39.28065441548824, 42.19115383923054, 44.43964518606663, 41.146745681762695, 41.92068435251713, 43.44467617571354, 40.04104681313038, 40.417682603001595, 40.58137781918049, 40.56967444717884, 41.53736852109432, 42.66330890357494, 40.032261684536934, 39.601949974894524, 41.70119673013687, 41.16414874792099, 40.33697493374348, 40.39432905614376, 41.44638620316982, 41.57951585948467, 44.80892837047577, 51.4776199311018, 54.18666936457157, 51.442707404494286, 54.76546190679073, 53.4262465685606, 49.307415783405304, 48.828595876693726, 43.86597476899624, 42.84382961690426, 40.476252660155296, 48.54402914643288, 50.94217166304588, 54.81970779597759, 56.6356835514307, 54.071360751986504, 53.905826434493065, 54.71898280084133, 53.800849467515945, 55.091286823153496, 49.43855434656143, 45.3238957375288, 44.03013356029987, 46.37846454977989, 48.99753861129284, 54.96384546160698, 56.54465563595295, 59.76407468318939, 54.64982271194458, 46.15399919450283, 49.367091581225395, 53.077797666192055, 50.41271947324276, 42.1586237847805, 42.05998107790947, 39.57934118807316, 40.734194219112396, 43.39901402592659, 44.3001888692379, 44.92312744259834, 40.567850545048714, 40.07595933973789, 42.155899330973625, 41.09893664717674, 41.06712855398655, 44.19077754020691, 43.592165261507034, 43.768069222569466, 42.05022320151329, 43.33262398838997, 42.96771056950092, 42.906537652015686, 42.78166115283966, 44.93155539035797, 43.66457037627697, 45.05924753844738, 44.124239310622215, 43.73907297849655, 43.24429392814636, 44.5378091186285, 43.96053649485111, 44.269786700606346, 46.98823682963848, 46.33249081671238, 45.4818494617939, 47.80857481062412, 46.45679734647274, 45.643401592969894, 47.25329540669918, 45.84991291165352, 47.07582972943783, 49.84849154949188, 57.53348037600517, 63.516209945082664, 64.58322688937187, 65.1303519308567, 72.0812277495861, 64.43400889635086, 64.19430255889893, 19.716458022594452, 1.401415744330734, 1.8462658300995827, 0.1422022929182276, 12.583892103284597, 75.23977786302567, 66.93861410021782, 77.52530962228775, 62.030653059482574, 48.82011093199253, 40.00706143677235, 62.08563230931759, 70.49029871821404, 67.188481092453, 7.694135410711169, 0.43488233000971377, 0.13902083941502497, 0.14592158084269613, 0.24471752636600286, 0.12630811688723043, 0.2199734322493896, 0.1304229101515375, 0.12592346174642444, 0.1880265277577564], [0.05862710233486723, 0.03684789189719595, 0.033249343978241086, 0.03599017327360343, 0.08411135888309218, 0.10158682154724374, 0.03201380910468288, 0.08313984304550104, 0.11609345601755194, 0.01718855208309833, 12.82299617305398, 53.72707262635231, 47.43674576282501, 38.50212179124355, 21.280661188066006, 19.32350780814886, 21.278442107141018, 33.58940340578556, 46.626503840088844, 58.512459844350815, 21.067213341593742, 0.22877517010783777, 0.15361490630311891, 0.3335495159262791, 4.537564516067505, 46.65650323033333, 51.611448749899864, 53.11435550451279, 52.52335421741009, 52.39811673760414, 54.1550512611866, 54.514048397541046, 54.07621689140797, 52.13672116398811, 48.970180079340935, 50.92238612473011, 51.912943571805954, 51.49796783924103, 51.93720147013664, 52.35699534416199, 52.982380986213684, 51.7496245354414, 51.83279447257519, 51.8942029774189, 51.1268075555563, 54.3275848031044, 49.82115961611271, 50.05847208201885, 42.81312346458435, 38.59311170876026, 37.45972752571106, 38.0867812782526, 37.61654511094093, 36.05459712445736, 37.14305251836777, 37.585873156785965, 38.43634732067585, 37.999693751335144, 35.60236819088459, 37.090391144156456, 35.96346281468868, 37.01868139207363, 36.60272531211376, 37.63599246740341, 38.52122716605663, 36.86937980353832, 38.3790197968483, 37.705916315317154, 36.65382117033005, 37.90791727602482, 35.92581443488598, 38.10580685734749, 36.4502888917923, 39.34371963143349, 46.639461144804955, 50.97882069647312, 46.250491216778755, 47.147151902318, 48.99113215506077, 47.451747357845306, 41.192898005247116, 38.85497845709324, 37.17788904905319, 38.71007703244686, 37.947617545723915, 44.72483888268471, 48.817017897963524, 53.738061636686325, 48.91314134001732, 46.736310347914696, 51.55898496508598, 49.10946540534496, 50.95506437122822, 50.497891902923584, 45.6156212836504, 38.82037751376629, 39.31881196796894, 43.042137175798416, 45.41607119143009, 50.6555188447237, 48.97039666771889, 53.578880578279495, 49.90310601890087, 40.36634735763073, 47.010150253772736, 46.435465291142464, 38.11707325279713, 37.87145063281059, 39.4070166349411, 36.509782299399376, 38.479459807276726, 38.60348895192146, 40.24445369839668, 37.29958891868591, 37.67069600522518, 37.20630772411823, 39.28215153515339, 36.09899014234543, 38.89237605035305, 40.365313813090324, 41.882735788822174, 41.05568736791611, 40.31989865005016, 37.97146126627922, 38.564757630228996, 38.944182470440865, 38.60979661345482, 37.76390120387077, 38.84286850690842, 39.672018215060234, 40.2186568826437, 39.53196533024311, 40.963629707694054, 40.728232339024544, 41.558696776628494, 42.30152651667595, 40.45734107494354, 40.316212847828865, 41.10392577946186, 39.69293989241123, 41.11022964119911, 39.48816888034344, 42.25924998521805, 40.28188928961754, 48.5217547416687, 57.26785942912102, 59.90988425910473, 62.783236876130104, 63.94309803843498, 61.89787298440933, 61.36655129492283, 66.34817898273468, 14.56444177776575, 0.428888775059022, 0.22700445028021932, 0.0807614898076281, 6.942574214190245, 58.23498733341694, 60.00660426914692, 56.38154178857803, 42.00344771146774, 19.08667031675577, 26.08202274888754, 43.08014273643494, 55.29264181852341, 47.42025084793568, 3.0245833145454526, 0.17114179237978533, 0.04558157852443401, 0.04276522828149609, 0.014629921897721943, 0.006992632761466666, 0.01876530790468678, 0.07170227123424411, 0.07067496815579943, 0.06909918083692901, 0.026198833438684233, 0.024608661442471202, 0.02570084121543914, 0.08879292290657759, 0.06716011223034002, 0.06190108309965581, 0.05817789147840813, 0.03454605408478528, 0.13091725471895188, 0.0185135083302157, 16.53665754944086, 63.94917771220207, 52.75819681584835, 46.069073751568794, 20.26196625083685, 22.993839159607887, 23.395969681441784, 36.708143055438995, 51.42243169248104, 64.10905793309212, 24.054905623197556, 0.269707182305865, 0.23284026916371658, 0.16448413400212303, 5.173086114227772, 48.29242564737797, 51.277849450707436, 53.55483166873455, 52.999575063586235, 53.20138603448868, 54.60669122636318, 54.84140843153, 52.9306847602129, 53.142162412405014, 50.41869655251503, 53.59974145889282, 53.47536273300648, 53.61981578171253, 52.537139877676964, 54.84460026025772, 54.093160182237625, 56.3919760286808, 53.708286434412, 53.62266182899475, 53.46647121012211, 54.56213481724262, 51.970791667699814, 51.24283812940121, 45.21161936223507, 42.1930955350399, 39.384012669324875, 39.58625681698322, 38.722935542464256, 39.22441363334656, 38.678025752305984, 40.14341711997986, 39.78441618382931, 39.10853125154972, 38.3072492480278, 38.543490171432495, 37.12362416088581, 36.02441154420376, 38.477195128798485, 39.96864929795265, 38.2134360820055, 39.49985705316067, 39.40556511282921, 39.62811157107353, 38.43388505280018, 39.584311321377754, 37.26098299026489, 40.489947125315666, 39.14764255285263, 41.235748305916786, 49.73684974014759, 53.219081684947014, 48.91442567110062, 51.63482889533043, 52.288340628147125, 48.46506178379059, 42.825791984796524, 41.087738648056984, 40.119463205337524, 41.37756809592247, 41.92775957286358, 46.4336109906435, 49.12289388477802, 56.75843596458435, 50.50722800195217, 50.57769522070885, 51.64117455482483, 51.571600288152695, 52.46880814433098, 53.16300429403782, 48.406643718481064, 39.541480019688606, 41.514166966080666, 44.5306047052145, 46.79216355085373, 51.29416957497597, 51.4462374150753, 56.041828617453575, 49.93624024093151, 43.65671619772911, 51.86491034924984, 49.2909474670887, 39.18882094323635, 39.48892883956432, 39.63311590254307, 38.296541422605515, 39.724789783358574, 41.233388632535934, 40.723338201642036, 40.306318178772926, 40.49341633915901, 39.67377372086048, 41.40282914042473, 37.897745221853256, 40.89195415377617, 41.987165585160255, 42.6265724748373, 42.5148356705904, 42.31405444443226, 41.90181836485863, 41.39732703566551, 41.12283356487751, 42.163289934396744, 40.424928814172745, 43.17288056015968, 41.91130265593529, 42.17935547232628, 42.333877980709076, 43.17132644355297, 42.08472155034542, 44.87545520067215, 43.164623603224754, 42.321049869060516, 42.1962683647871, 43.49293738603592, 41.958317533135414, 43.01023408770561, 42.248055785894394, 44.902874529361725, 43.84794093668461, 50.59175066649914, 59.83437091112137, 62.559219896793365, 65.82294076681137, 66.22564315795898, 63.60040582716465, 63.81132110953331, 67.2027987241745, 20.5400163307786, 0.778212194563821, 0.7786481617949903, 0.16777843848103657, 7.833387013524771, 62.79205620288849, 66.19678750634193, 60.61246655881405, 45.34362427890301, 26.146524287760258, 29.362833201885223, 49.08252105116844, 62.46341183781624, 57.21867486834526, 5.71162361651659, 0.08460654949885793, 0.06808528094552457, 0.05338653783837799, 0.041282803140347824, 0.007086384566719062, 0.10368189701694064, 0.022732515826646704, 0.07304434882826172, 0.07219661580165848, 0.19371780595974997, 0.10307942153303884, 0.11929419793887064, 0.07962529140058905, 0.34663666679989547, 0.16216798016102985, 0.1277873953222297, 0.19552829005988315, 0.19666898588184267, 0.06969784168177284, 20.65696455538273, 74.40704494714737, 61.008340716362, 52.87587270140648, 30.04467811435461, 31.55088499188423, 32.331659495830536, 45.78087441623211, 55.391546711325645, 71.11576795578003, 26.763538978993893, 0.5111660272814333, 0.771485308650881, 0.9363999625202268, 5.849898671731353, 49.717379584908485, 52.24063418805599, 54.25124689936638, 53.757672384381294, 54.86134596168995, 54.26412060856819, 55.862143859267235, 53.716957569122314, 54.97832648456097, 51.77892096340656, 54.147972241044044, 56.118713691830635, 56.97038099169731, 56.14102989435196, 57.37584963440895, 57.145376801490784, 57.301350831985474, 56.16377927362919, 56.31594590842724, 55.60424029827118, 57.93916940689087, 55.2204304933548, 55.13257920742035, 46.98423184454441, 42.80474491417408, 41.558749973773956, 40.85063137114048, 41.64398320019245, 39.785502925515175, 41.26412898302078, 42.24024340510368, 42.43783660233021, 42.32181362807751, 39.60625134408474, 40.26908777654171, 38.857281133532524, 38.66902783513069, 40.30692994594574, 42.9700930416584, 41.61485016345978, 40.96407808363438, 41.15046948194504, 42.11918570101261, 40.206056758761406, 40.89829221367836, 39.36506688594818, 40.717429518699646, 40.815939232707024, 43.22111517190933, 52.19096705317497, 54.27627235651016, 50.24543344974518, 51.878806203603745, 53.98661009967327, 51.28506526350975, 45.220172703266144, 42.18380883336067, 41.57802253961563, 42.645335868000984, 43.32697369158268, 47.131093963980675, 52.08599388599396, 58.71934354305267, 53.230367079377174, 52.523308619856834, 54.63743917644024, 53.1337458640337, 53.856296092271805, 55.92777393758297, 50.90396851301193, 42.71962948143482, 43.374391347169876, 46.84180408716202, 49.52105171978474, 54.94570903480053, 54.37032870948315, 58.73381696641445, 51.589375734329224, 44.85664241015911, 51.11657090485096, 50.60962110757828, 42.02194131910801, 41.38431653380394, 43.515682965517044, 40.14021769165993, 41.660132333636284, 44.562234207987785, 44.648782163858414, 42.652608677744865, 41.68199636042118, 40.95781221985817, 44.58279110491276, 39.35727350413799, 42.583072409033775, 43.52643258869648, 45.28251975774765, 44.30685751140118, 44.00532469153404, 43.82351204752922, 43.34073655307293, 45.03895282745361, 44.161283522844315, 42.27233648300171, 45.42406976222992, 44.544397965073586, 43.87757174670696, 43.878491297364235, 44.55949455499649, 45.31392887234688, 46.48365430533886, 45.62621131539345, 44.23050060868263, 42.920813485980034, 45.4814238846302, 45.13511046767235, 45.53537718951702, 43.56337420642376, 47.23000645637512, 44.89885054528713, 51.3160640001297, 63.268816620111465, 62.761790826916695, 68.52953553199768, 67.42149978876114, 67.79185831546783, 64.43753510713577, 71.78680434823036, 25.530710332095623, 1.039432561956346, 1.4051489252597094, 0.2421466080704704, 8.443607669323683, 70.43769434094429, 70.30436709523201, 70.25588169693947, 53.394016698002815, 29.418378621339798, 39.386892914772034, 59.94352765381336, 70.35319447517395, 69.19547259807587, 9.295546654611826, 0.3094771842006594, 0.18869167019147426, 0.12357543266261928, 0.13040129881119356, 0.1740546923247166, 0.18091409612679854, 0.11699334718286991, 0.2208096397225745, 0.20683786366134882], [0.011151757753395941, 0.0375526724383235, 0.12800905999029055, 0.059886797826038674, 0.07465969261829741, 0.0323198893602239, 0.023331197080551647, 0.049744266289053485, 0.16363116883439943, 0.013609714678750606, 14.233955461531878, 55.018714517354965, 44.439394399523735, 40.52455946803093, 28.202647157013416, 45.642288252711296, 62.12965674698353, 46.06097258627415, 39.806641191244125, 56.753500029444695, 25.10018203407526, 0.20845007558818907, 0.07648116792552173, 0.0915020216780249, 3.656546166166663, 47.39561676979065, 55.71562372148037, 48.47735412418842, 50.719313621520996, 50.63603349030018, 53.62391956150532, 52.7029287815094, 51.71951875090599, 52.45911106467247, 53.016373962163925, 53.96267518401146, 54.103955402970314, 52.92615160346031, 51.45288705825806, 49.30352859199047, 49.180563390254974, 49.34633709490299, 46.348924934864044, 46.24894089996815, 44.802844896912575, 46.537733003497124, 43.10101501643658, 39.15459617972374, 37.604986131191254, 35.95176324248314, 37.76702843606472, 36.56487174332142, 35.36128632724285, 36.842910423874855, 37.360355257987976, 38.79787512123585, 37.00281344354153, 34.55786883831024, 35.46793520450592, 35.082407891750336, 34.40599858760834, 36.07283994555473, 35.13303257524967, 36.79214894771576, 37.34989441931248, 37.50597484409809, 37.889913842082024, 36.45810507237911, 33.45882721245289, 37.60661244392395, 36.298574432730675, 38.371446803212166, 38.01880672574043, 38.39881293475628, 44.691290482878685, 52.37439841032028, 50.599312260746956, 46.16013966500759, 49.179784432053566, 49.981161430478096, 41.440428122878075, 38.92930626869202, 36.51714250445366, 38.862855434417725, 38.782368153333664, 45.61387337744236, 51.863105446100235, 51.2701016664505, 50.52558861672878, 41.44947163760662, 44.4680068641901, 48.1328684091568, 51.61106497049332, 51.44453510642052, 48.04200768470764, 39.90155629813671, 41.148375794291496, 41.22803092002869, 42.653456032276154, 46.785008534789085, 49.2511598020792, 49.5121905952692, 52.89339356124401, 46.27378396689892, 49.07269857823849, 45.70224903523922, 39.75798100233078, 39.439546689391136, 36.58201262354851, 36.98427803814411, 40.170057490468025, 39.61763933300972, 38.959906026721, 38.92485670745373, 38.35727356374264, 37.37515926361084, 36.93355455994606, 37.579956874251366, 37.70589731633663, 38.90595652163029, 39.8734188079834, 38.74182432889938, 39.31587092578411, 38.58395420014858, 39.770744517445564, 39.41815383732319, 38.66742432117462, 38.435784950852394, 38.872073739767075, 38.647368997335434, 39.85816642642021, 40.78381195664406, 39.5242365449667, 41.09590820968151, 39.80664499104023, 39.072801768779755, 40.21489888429642, 41.64944730699062, 38.46932575106621, 41.07108794152737, 40.78174106776714, 43.474626168608665, 43.66413339972496, 42.505750358104706, 43.264550641179085, 53.71537685394287, 56.79780185222626, 60.08383892476559, 62.15962573885918, 64.91773813962936, 60.56979864835739, 71.90049424767494, 15.174160860478878, 1.680011332500726, 0.45322062098421156, 0.11786639486672357, 5.200082240626216, 55.149716287851334, 59.678978249430656, 59.14228744804859, 47.71092005074024, 20.33317632973194, 31.646560057997704, 43.08474808931351, 57.947475761175156, 42.167458310723305, 5.095506152138114, 0.14518934825900942, 0.039724560192553326, 0.05485223497089464, 0.03057323923712829, 0.005507093383130268, 0.12619167391676456, 0.10377429440268315, 0.010700287057261448, 0.05741704910178669, 0.08333295729244128, 0.032018087586038746, 0.012471943846321665, 0.06363383465213701, 0.05417113636212889, 0.04686161999416072, 0.016043750329117756, 0.04738040348456707, 0.13799710606690496, 0.0525576293875929, 16.153299920260906, 62.66430325806141, 51.40922740101814, 44.77917596697807, 34.816980734467506, 44.878187254071236, 46.05633683502674, 44.35527451336384, 45.83168528974056, 63.26513461768627, 27.595926113426685, 0.20218955527525395, 0.2015530300559476, 0.0958754459861666, 4.737547310069203, 50.527572110295296, 55.01604326069355, 49.18645687401295, 52.91928917169571, 53.011692613363266, 53.92649732530117, 53.66778060793877, 54.72111068665981, 52.393173202872276, 54.43939760327339, 55.90751342475414, 55.48425413668156, 54.7505135089159, 54.4271394610405, 52.926170602440834, 50.67227214574814, 50.96193440258503, 48.1338145583868, 49.22906018793583, 48.50316233932972, 50.14177121222019, 46.72339864075184, 40.218360498547554, 38.96370202302933, 38.03098127245903, 38.56936298310757, 38.82797330617905, 38.30684266984463, 39.8677609115839, 39.58724096417427, 40.3914488106966, 39.12121117115021, 37.82722860574722, 37.565532848238945, 36.407180204987526, 35.80343060195446, 39.04579281806946, 36.76461182534695, 39.09532316029072, 38.655413165688515, 39.33828592300415, 38.193905130028725, 38.075936660170555, 36.47114597260952, 39.803339168429375, 38.3912855386734, 40.41218049824238, 39.70327153801918, 39.76544380187988, 46.96087069809437, 53.01889322698116, 50.80224797129631, 48.90428401529789, 50.99581338465214, 50.432049036026, 42.894024923443794, 40.78057833015919, 37.90199339389801, 42.384240478277206, 40.56382276117802, 46.63467340171337, 53.25947351753712, 54.820817336440086, 52.342449724674225, 43.47384721040726, 46.4633671939373, 51.27591535449028, 54.57127332687378, 51.76192827522755, 49.545773193240166, 41.155321821570396, 43.53611446917057, 43.17127704620361, 44.37818728387356, 47.34024994075298, 50.51130898296833, 51.200398206710815, 55.25715932250023, 48.04210647940636, 52.21300207078457, 47.748465836048126, 41.912947967648506, 41.58450499176979, 38.75235736370087, 38.93114157021046, 40.71984238922596, 39.89193521440029, 40.843879133462906, 40.82917392253876, 39.29752171039581, 39.22090642154217, 38.834223970770836, 39.060102850198746, 39.104469269514084, 41.822410225868225, 40.688376277685165, 40.94373777508736, 41.090706288814545, 41.27913437783718, 39.93346318602562, 39.870508164167404, 40.22617667913437, 41.54374077916145, 40.390327870845795, 40.62958583235741, 41.267313212156296, 43.3621522039175, 40.814122930169106, 42.98322133719921, 41.76714979112148, 43.280004411935806, 41.82887367904186, 44.46566238999367, 41.972065195441246, 42.91865900158882, 42.592951878905296, 45.569681748747826, 45.23134410381317, 45.94411365687847, 45.351383462548256, 54.999685138463974, 58.98576244711876, 62.87525273859501, 64.30984675884247, 67.4435006082058, 63.19054462015629, 72.11585149168968, 18.431710861623287, 1.2763915280811489, 0.5611434986349195, 0.18814868526533246, 5.624803500249982, 60.37374056875706, 63.78045916557312, 63.51849362254143, 48.22062470018864, 25.201714485883713, 36.54285952448845, 50.41835457086563, 63.915154337882996, 52.12660990655422, 6.467428710311651, 0.19605243927799165, 0.06907188464538194, 0.016314372624037787, 0.024241925457317848, 0.027945952970185317, 0.08814329878077842, 0.0189492195204366, 0.03926828037947416, 0.009447110405744752, 0.13156212167814374, 0.1578993842122145, 0.19535968895070255, 0.15911331516690552, 0.22347049147356302, 0.07444341594236903, 0.13231796940090135, 0.10700944971176796, 0.3345551557140425, 0.10756015297374688, 20.031666308641434, 72.89632201194763, 58.84260892868042, 52.785110771656036, 40.333422124385834, 60.327193066477776, 70.7254832983017, 56.45332373678684, 52.38990157842636, 66.76067724823952, 30.70567924529314, 0.23680737504037097, 0.45674407097976655, 0.42297281906940043, 5.7973878644406796, 52.42041774094105, 56.209517419338226, 50.612972527742386, 54.681425616145134, 53.006828874349594, 57.13162533938885, 55.9336294233799, 55.77866233885288, 55.62301509082317, 56.13827884197235, 59.4774978607893, 59.41134341061115, 56.819194704294205, 56.3144563883543, 54.02498044073582, 52.19043888151646, 52.35664576292038, 49.96471971273422, 51.56652756035328, 49.49364759027958, 51.5792378783226, 48.311356231570244, 44.02940779924393, 41.37938439846039, 40.26939556002617, 41.933159083127975, 40.53098112344742, 38.569868355989456, 40.950220227241516, 40.870375111699104, 44.07042279839516, 41.410561725497246, 38.67222346365452, 38.324659913778305, 37.59000353515148, 37.98103295266628, 40.91296702623367, 37.86080740392208, 41.3725371658802, 42.11585707962513, 42.206425219774246, 40.86010426282883, 39.12107437849045, 37.444254755973816, 42.02933572232723, 39.19462703168392, 41.96969412267208, 40.705182775855064, 42.50802643597126, 49.71124291419983, 55.42256444692612, 53.20004850625992, 49.14500489830971, 53.586324378848076, 53.72117534279823, 45.70447191596031, 42.944885194301605, 39.923982694745064, 44.09521646797657, 42.4927132576704, 49.36360716819763, 56.79770305752754, 56.73070125281811, 56.70194059610367, 46.98867380619049, 48.13927486538887, 53.06193731725216, 55.68168394267559, 55.429799258708954, 52.9173968732357, 43.50615307688713, 45.7767516374588, 45.609021037817, 45.6111641228199, 51.49926736950874, 52.34956294298172, 53.063366040587425, 59.08580727875233, 49.38620835542679, 54.19267684221268, 49.79739189147949, 43.09599168598652, 43.72851334512234, 38.99860315024853, 39.354188069701195, 44.822987616062164, 44.49025847017765, 41.6631455719471, 43.493267968297005, 41.99823819100857, 40.31226105988026, 41.096854358911514, 40.393097922205925, 41.51733219623566, 43.55068288743496, 42.68111854791641, 43.950531631708145, 44.24425967037678, 42.68346682190895, 43.38652029633522, 43.36668536067009, 42.38413408398628, 42.854244858026505, 43.80281075835228, 42.98960119485855, 44.192282259464264, 46.09446778893471, 43.10742527246475, 45.926315411925316, 44.20064181089401, 45.02792961895466, 44.09737475216389, 46.777332946658134, 44.45740923285484, 44.944087117910385, 45.224014297127724, 49.357367902994156, 48.37334230542183, 47.06819213926792, 47.5366348028183, 57.74441845715046, 61.55375584959984, 63.819574266672134, 66.92433446645737, 70.32263651490211, 64.91757094860077, 75.96352502703667, 22.90185559540987, 2.380479876883328, 1.3354434468783438, 0.2700977004133165, 5.765726063400507, 67.18666478991508, 67.74284854531288, 76.56573191285133, 60.22435538470745, 31.6469419375062, 44.43346291780472, 60.804299265146255, 73.98609593510628, 63.36842827498913, 11.37689447030425, 0.2607691119192168, 0.1278098378679715, 0.12125114488299005, 0.2192434112657793, 0.16780951962573454, 0.17730528430547565, 0.23715127143077552, 0.10938991064904258, 0.18323868076549843], [0.0233763345022453, 0.029463140308507718, 0.08279751258669421, 0.03881882090354338, 0.09222807217156515, 0.024140100940712728, 0.06281850379309617, 0.052615887980209664, 0.13983098266180605, 0.021276197585393675, 13.320594672113657, 57.67909996211529, 51.48736260831356, 44.440123960375786, 17.320367395877838, 54.91904206573963, 84.49590638279915, 49.60210897028446, 35.542415007948875, 48.26691761612892, 31.0524258390069, 0.20214242889778689, 0.06089870505093131, 0.04240033282258082, 4.729385348036885, 42.280547842383385, 53.8465990126133, 54.0240228921175, 55.099783167243004, 53.946301862597466, 55.10947644710541, 55.65255090594292, 56.648720651865005, 54.79983106255531, 52.22285874187946, 48.986952379345894, 47.549048736691475, 45.25095485150814, 42.7126644551754, 41.686742305755615, 39.849704280495644, 37.755541652441025, 36.9817815721035, 36.675916984677315, 37.1333934366703, 38.07648003101349, 35.55755339562893, 37.11275674402714, 36.103857681155205, 35.627610236406326, 37.14691311120987, 36.97474054992199, 37.33065225183964, 37.80118100345135, 36.790739223361015, 38.37758727371693, 36.718501299619675, 35.56583695113659, 36.109834760427475, 35.10975122451782, 37.04265050590038, 35.51664099097252, 36.3365837931633, 35.94603694975376, 37.14581497013569, 35.57390011847019, 38.049695268273354, 36.22289389371872, 37.245506420731544, 38.04114572703838, 37.13619388639927, 37.627085745334625, 39.88978073000908, 35.62205113470554, 42.87138573825359, 51.091716438531876, 49.746311232447624, 46.03931374847889, 49.398717284202576, 52.37265810370445, 40.96415027976036, 41.50662437081337, 35.75276032090187, 38.194136917591095, 37.527500689029694, 48.84679690003395, 51.06010973453522, 53.36875565350056, 47.96508081257343, 46.000643223524094, 52.225750386714935, 51.77420921623707, 51.95188768208027, 50.621358677744865, 45.686122700572014, 38.321658074855804, 39.84304703772068, 40.21092049777508, 44.37167063355446, 43.49879287183285, 46.58887065947056, 51.91302336752415, 50.965430215001106, 50.65748333930969, 45.706713795661926, 46.16892859339714, 39.066095128655434, 37.64537416398525, 39.287456050515175, 36.54448963701725, 37.90341071784496, 39.41101782023907, 38.721613213419914, 37.39267252385616, 37.435386031866074, 37.804034650325775, 37.4269200861454, 38.686267510056496, 36.87442593276501, 36.665034368634224, 38.754644840955734, 40.05199782550335, 39.23086188733578, 37.33220636844635, 37.62463867664337, 39.08286742866039, 40.43206103146076, 36.920532658696175, 40.194034203886986, 39.864626079797745, 40.356566682457924, 38.89714479446411, 40.34207426011562, 39.963147193193436, 39.64606560766697, 39.91410702466965, 42.669939547777176, 41.70469634234905, 40.05721874535084, 41.60061612725258, 41.78409308195114, 42.9545708745718, 41.35149009525776, 44.27260994911194, 45.22460326552391, 47.87390470504761, 49.45248439908028, 54.99365486204624, 56.17321036756039, 61.08969435095787, 60.821569338440895, 66.22615233063698, 13.163399007171392, 0.9840711951255798, 0.8619501418434083, 0.11111907762824558, 6.074037244543433, 55.505912974476814, 62.20005176961422, 55.86677961051464, 42.221594005823135, 19.63579025119543, 22.715916372835636, 44.46827284991741, 52.82533921301365, 50.11539302766323, 6.376485815271735, 0.04476472255191766, 0.036702638753922656, 0.038790307589806616, 0.04284041155187879, 0.07877635609474964, 0.08429160428931937, 0.03631943080108613, 0.05756584228947759, 0.09482189314439893, 0.03338359478220809, 0.055224670650204644, 0.06698209326714277, 0.03814388583123218, 0.05860891971678939, 0.026478261315787677, 0.06546295408043079, 0.03607403596106451, 0.2108277683146298, 0.061428728367900476, 15.263884495943785, 65.14729902148247, 57.53117389976978, 51.00539647042751, 23.553408533334732, 55.66338412463665, 81.87885001301765, 54.04198832809925, 41.60293020308018, 54.947711527347565, 33.29912178218365, 0.1515403512166813, 0.11160466485307552, 0.07491729949833825, 5.758806634694338, 44.262608885765076, 56.2338475137949, 56.521146297454834, 56.43531650304794, 55.692878141999245, 57.59333856403828, 57.8154556453228, 58.040430173277855, 57.256357446312904, 54.8350665718317, 51.40325412154198, 50.18130049109459, 48.61112214624882, 46.31290666759014, 44.63004916906357, 42.34714686870575, 39.716103449463844, 38.78336749970913, 39.67723913490772, 39.10652115941048, 40.93428388237953, 39.47279870510101, 38.20752739906311, 36.98470361530781, 37.504048347473145, 39.25333388149738, 38.65106999874115, 38.33122216165066, 40.26035204529762, 38.667340725660324, 39.70394030213356, 37.89754003286362, 37.9235952347517, 38.209134712815285, 35.90341463685036, 37.68709972500801, 38.658593595027924, 38.7555567920208, 37.508627101778984, 39.7609106451273, 36.92666932940483, 38.46318908035755, 38.048547729849815, 37.57434457540512, 38.337617218494415, 39.74020175635815, 39.76527281105518, 39.710529148578644, 37.48656928539276, 44.71681371331215, 52.71890692412853, 51.09110467135906, 49.577775076031685, 50.38288727402687, 54.34555783867836, 43.24623562395573, 42.11125932633877, 39.04851347208023, 41.81275114417076, 39.156591072678566, 50.025493651628494, 54.02164801955223, 55.49819178879261, 52.22956918179989, 47.89684787392616, 53.51952776312828, 53.79652909934521, 53.98085340857506, 52.29163885116577, 47.631686702370644, 42.41558879613876, 42.298015505075455, 42.846322283148766, 45.64612224698067, 46.16781525313854, 48.834135979413986, 53.779718801379204, 52.03779347240925, 53.94128993153572, 49.90354299545288, 48.623467683792114, 39.82468642294407, 38.73899348080158, 40.26178076863289, 38.45514491200447, 40.32203033566475, 40.27288377285004, 39.548699632287025, 38.78167659044266, 38.657541051506996, 39.582673609256744, 39.65282544493675, 40.02269759774208, 38.856372982263565, 39.43402178585529, 42.066296339035034, 40.630767568945885, 40.22706963121891, 39.16153460741043, 40.83652652800083, 41.124167293310165, 42.05491214990616, 40.2302348613739, 40.376306623220444, 40.5718669295311, 41.428903341293335, 40.76434180140495, 41.22064031660557, 41.26553110778332, 42.5227240473032, 42.83354736864567, 44.43767309188843, 43.592321053147316, 42.12487019598484, 44.63840492069721, 45.081385150551796, 45.9576029330492, 42.67153926193714, 45.92396333813667, 46.749267652630806, 50.1034464687109, 51.58570133149624, 56.74666419625282, 58.12331512570381, 64.07637968659401, 63.35491620004177, 69.9797049164772, 14.146330263465643, 1.03130396688357, 1.5096071013249457, 0.015334951058321167, 5.351089937612414, 59.10240098834038, 65.15691250562668, 61.7635577917099, 49.20384094119072, 23.343251310288906, 28.570923395454884, 51.96231432259083, 58.320744931697845, 59.59897734224796, 8.566326834261417, 0.11438144749263301, 0.047807297960389405, 0.12156953365774825, 0.03390146172023378, 0.01775604087015381, 0.03233868796087336, 0.05163686160813086, 0.027041933608416002, 0.07525055349105969, 0.07345221834839322, 0.08617990999482572, 0.20176230085780844, 0.1276085080462508, 0.2048031915910542, 0.09409369042259641, 0.15652912727091461, 0.13448036508634686, 0.337471766397357, 0.14705378649523482, 17.68631435930729, 75.03901943564415, 64.97628539800644, 58.011069148778915, 27.641880847513676, 64.24857884645462, 85.89126750826836, 61.06349855661392, 49.6692855656147, 60.277134552598, 37.74646393954754, 0.21556547580985352, 0.21865502174478024, 0.15629594447091222, 6.289576403796673, 48.57705317437649, 58.76570485532284, 59.07228000462055, 58.23371060192585, 58.014918342232704, 60.02697877585888, 60.12988865375519, 60.672951713204384, 57.88264364004135, 57.42915317416191, 55.04842512309551, 52.450968101620674, 50.10846599936485, 47.709164544939995, 46.42599619925022, 43.015819787979126, 41.868760138750076, 41.46117500960827, 40.792711079120636, 40.766959860920906, 41.999290734529495, 42.146107256412506, 40.82909792661667, 39.77455571293831, 40.749875977635384, 42.30044737458229, 40.584607645869255, 40.00799238681793, 42.225872576236725, 40.58629855513573, 43.48080463707447, 41.69851787388325, 40.92600032687187, 39.98223356902599, 37.0037329941988, 39.6529546380043, 41.105932071805, 40.08818708360195, 39.44624952971935, 41.61809898912907, 38.21432903409004, 40.434325709939, 39.622514471411705, 40.38309685885906, 41.2351593375206, 40.5680975317955, 41.784241273999214, 42.914384230971336, 38.85464407503605, 47.24749691784382, 53.826676681637764, 54.94965702295303, 49.24614027142525, 50.652630999684334, 56.39262579381466, 45.1584792137146, 44.79848273098469, 40.03501653671265, 44.01156775653362, 40.89680649340153, 54.84050028026104, 56.105353608727455, 57.477950155735016, 54.74274292588234, 50.52953660488129, 56.1300902813673, 55.56794844567776, 56.874660328030586, 53.93330276012421, 49.217258021235466, 43.424229472875595, 43.642098382115364, 44.30926278233528, 49.285935536026955, 47.29353904724121, 49.39886547625065, 57.14915759861469, 52.57729232311249, 52.73123346269131, 51.949512809515, 50.25755099952221, 42.738256081938744, 41.86138853430748, 41.89508132636547, 41.39005422592163, 41.69824808835983, 43.55243839323521, 42.473490089178085, 40.54066300392151, 39.66277711093426, 41.330906599760056, 40.62800511717796, 42.994620725512505, 40.457265079021454, 41.108808517456055, 44.192643240094185, 41.710855811834335, 42.74514511227608, 41.68710708618164, 43.942058086395264, 44.32271406054497, 47.085731998085976, 42.80469551682472, 43.59324440360069, 43.97148750722408, 44.087955057621, 42.43467517197132, 45.354769080877304, 44.343137964606285, 43.80922481417656, 44.680210277438164, 47.22165450453758, 48.24671030044556, 44.614382609725, 48.14251609146595, 46.8641696870327, 46.88429720699787, 43.341264724731445, 48.75261515378952, 49.69189055263996, 52.952985763549805, 54.4788508862257, 60.1936150342226, 60.846290811896324, 69.11990985274315, 66.27620324492455, 71.4204204082489, 16.499284654855728, 1.2935223150998354, 3.5118881659582257, 0.11710204213159159, 6.053102742880583, 65.58115974068642, 72.98021391034126, 69.89050850272179, 56.64612919092178, 31.122780963778496, 33.898706808686256, 62.38619618117809, 66.84069335460663, 72.54837468266487, 13.140022661536932, 0.3908562893047929, 0.06680146194412373, 0.20258991426089779, 0.08814541390165687, 0.11465140371001326, 0.13271950097987428, 0.12780164455762133, 0.12480792473070323, 0.17158139613457024], [0.016255741102213506, 0.012501689125201665, 0.07870110232033767, 0.04595132762915455, 0.015380211862066062, 0.020942897208442446, 0.03289251937530935, 0.052620032874983735, 0.06503105381852947, 0.031454051641048864, 4.871333856135607, 55.81455521285534, 52.829879969358444, 44.48894374072552, 26.931134685873985, 27.986398860812187, 54.117969051003456, 36.78911291062832, 36.13726168870926, 47.241979613900185, 37.688216865062714, 0.8799319644458592, 0.18064762058202177, 0.12865239812526852, 4.44871530868113, 45.413141548633575, 57.81568743288517, 56.204380095005035, 53.190450221300125, 55.436942875385284, 51.59510962665081, 51.150411888957024, 47.5651940703392, 45.6392028182745, 42.020265609025955, 40.76432280242443, 38.65277610719204, 37.24862225353718, 37.41359420120716, 35.54773472249508, 38.30985210835934, 38.70675601065159, 39.736546352505684, 37.27772109210491, 36.633230075240135, 36.77883446216583, 37.38167591392994, 37.370557710528374, 36.511127427220345, 37.77691550552845, 37.4084834754467, 37.910710126161575, 35.57749852538109, 38.01219888031483, 36.99592441320419, 36.438581719994545, 35.676274225115776, 37.29617290198803, 35.67313939332962, 35.063978880643845, 36.69911853969097, 38.24771784245968, 36.47938773036003, 38.49449560046196, 36.278405115008354, 37.370113134384155, 35.72315230965614, 38.07423435151577, 37.00307942926884, 38.00922363996506, 36.7680848389864, 38.063921704888344, 38.02200995385647, 37.27833665907383, 39.45005312561989, 50.709673538804054, 50.0460771471262, 43.54965694248676, 49.59898553788662, 50.91845713555813, 42.40941792726517, 39.88080941140652, 37.8516460955143, 37.03113712370396, 36.27899408340454, 47.99434304237366, 52.02892854809761, 53.17551702260971, 45.643401592969894, 47.52087704837322, 53.03973510861397, 47.74913839995861, 51.247656270861626, 44.62594918906689, 42.285863757133484, 39.7242122143507, 42.35954560339451, 41.94541722536087, 42.720404639840126, 44.44157928228378, 48.310174494981766, 46.914657577872276, 53.75186629593372, 44.93871420621872, 44.77367386221886, 47.03613705933094, 36.194661408662796, 40.3321947902441, 36.81283123791218, 37.89970211684704, 38.83345641195774, 38.520714193582535, 37.596797570586205, 38.537220507860184, 37.38213188946247, 38.38961362838745, 37.86986991763115, 37.35382720828056, 34.76696401834488, 38.18550758063793, 38.16399693489075, 39.264467284083366, 37.83582754433155, 37.932121977210045, 37.173568680882454, 39.568112790584564, 36.7446780949831, 39.39289279282093, 37.65715353190899, 40.29048442840576, 40.16073279082775, 40.691644102334976, 38.41391712427139, 40.216654390096664, 40.51471799612045, 41.64435178041458, 40.500271171331406, 41.14877097308636, 39.60382327437401, 41.80358223617077, 41.02504201233387, 42.259238585829735, 42.03467443585396, 44.14536237716675, 43.97412836551666, 44.801446571946144, 43.27644780278206, 47.24889524281025, 55.75434364378452, 62.503104507923126, 55.81330507993698, 74.90167960524559, 15.302632916718721, 0.8328971383161843, 0.21787060133647174, 0.08718739773030393, 3.6461625108495355, 50.77864743769169, 64.78638678789139, 55.1013258844614, 40.51468759775162, 23.338894844055176, 26.161398589611053, 38.69129464030266, 51.76116071641445, 48.58797378838062, 7.183683626353741, 0.23018750682240352, 0.03728893912921194, 0.04206005440209992, 0.03943948642699979, 0.02149123673007125, 0.017613082818570547, 0.08165434541297145, 0.10026058138464577, 0.07659435286768712, 0.07292317837709561, 0.03995244776888285, 0.056589105442981236, 0.007505657649744535, 0.04934852717269678, 0.009975519551517209, 0.05500896542798728, 0.02897341561038047, 0.11543954227818176, 0.025459556018176954, 6.8130638636648655, 64.4739143550396, 57.67560034990311, 50.03923371434212, 27.7083582803607, 39.39263440668583, 65.50501182675362, 46.26530662178993, 44.35881592333317, 52.26231962442398, 40.49000032246113, 0.8528139477130026, 0.13289196125697345, 0.03685997406137176, 5.150006152689457, 47.33304552733898, 60.69408617913723, 60.036801248788834, 55.408824384212494, 57.273551523685455, 54.973284155130386, 54.796377047896385, 51.52810022234917, 48.674764931201935, 45.67718178033829, 43.56668762862682, 41.00597843527794, 39.76951718330383, 39.38657373189926, 37.73196391761303, 38.87405343353748, 39.35806766152382, 41.10002338886261, 39.12478677928448, 37.24405489861965, 38.57748694717884, 37.7712994068861, 39.634537026286125, 37.503706365823746, 39.1091126203537, 38.54064792394638, 40.49782030284405, 37.0554406195879, 40.291757360100746, 38.464332818984985, 38.31773668527603, 37.73017801344395, 38.784496039152145, 38.91270495951176, 37.54993848502636, 38.33599090576172, 37.98181191086769, 35.240996181964874, 39.4573525339365, 37.70957171916962, 39.10000450909138, 37.607406601309776, 38.60319636762142, 38.769536241889, 39.25758205354214, 39.26496125757694, 39.545002430677414, 38.22241500020027, 39.64891545474529, 42.80808873474598, 51.48101694881916, 51.936319917440414, 48.210547640919685, 51.79071933031082, 52.0701639354229, 44.55964274704456, 40.39108023047447, 40.299140363931656, 38.14496375620365, 38.08485858142376, 50.650050938129425, 51.96245491504669, 54.36010725796223, 47.05369211733341, 49.59602929651737, 55.96797198057175, 51.74719266593456, 52.686563059687614, 46.306238025426865, 44.26163233816624, 40.54165855050087, 45.31349949538708, 44.022381976246834, 45.991846695542336, 46.18060536682606, 49.832346215844154, 48.36804918944836, 53.864853233098984, 49.655157923698425, 45.85851565003395, 49.22203816473484, 39.297137930989265, 41.782725155353546, 38.75511981546879, 39.066011533141136, 39.909114092588425, 39.8294285684824, 38.67389917373657, 40.19465357065201, 38.94197478890419, 39.145769253373146, 39.85024385154247, 38.65455821156502, 36.04269236326218, 40.068260952830315, 39.59076337516308, 40.840903893113136, 39.723581448197365, 39.61209923028946, 38.69211159646511, 41.369820311665535, 38.9238915592432, 42.04333037137985, 39.667629450559616, 42.92585201561451, 42.30087675154209, 42.113649398088455, 40.34859091043472, 42.0231344550848, 42.11331121623516, 43.5222490131855, 43.894929215312004, 41.72898843884468, 42.16156482696533, 42.573732510209084, 42.80228264629841, 44.7582770884037, 44.674791768193245, 46.95021227002144, 46.26293554902077, 46.61369472742081, 46.522822603583336, 50.193919613957405, 57.478181943297386, 65.98798111081123, 59.01405952870846, 75.92807292938232, 15.20004317164421, 0.9278200229164213, 0.9972111275419593, 0.09556166594848037, 3.1873148074373603, 57.55582697689533, 67.43935123085976, 62.11476914584637, 47.43708394467831, 24.65944178402424, 33.60912434756756, 47.063985764980316, 59.29837167263031, 59.255996346473694, 9.726009406149387, 0.27082648943178356, 0.039015541988192126, 0.08031182253034785, 0.015814337639312726, 0.027916194703720976, 0.00610449118539691, 0.05765621732280124, 0.02212070598034188, 0.0526853084738832, 0.14397452672710642, 0.21006310387747362, 0.15076091804075986, 0.15020362450741231, 0.20021755015477538, 0.04826607881113887, 0.19955206633312628, 0.14690286334371194, 0.21352666255552322, 0.09915849950630218, 8.043403644114733, 73.26937839388847, 64.33212116360664, 58.15410867333412, 36.877982541918755, 38.713827431201935, 63.19435961544514, 49.94045041501522, 52.01779514551163, 58.9424903690815, 45.656624883413315, 1.0406815074384212, 0.4164925043005496, 0.1276625512400642, 5.776591105386615, 51.01340264081955, 60.96496224403381, 62.358267679810524, 57.734656780958176, 60.79339385032654, 57.60615527629852, 56.7775147408247, 53.78106392920017, 49.88021984696388, 47.85107173025608, 45.94515100121498, 41.74380384385586, 40.45043304562569, 41.98208525776863, 38.8858176022768, 40.945512279868126, 43.7396277487278, 43.18477012217045, 40.40637440979481, 39.62915651500225, 40.976537615060806, 41.025843769311905, 40.38674846291542, 39.436674043536186, 41.16674780845642, 40.11756330728531, 42.53405503928661, 39.023537412285805, 43.41482877731323, 42.00686372816563, 40.97914047539234, 39.22672390937805, 41.56759209930897, 41.88734494149685, 39.01890926063061, 40.891076400876045, 40.53646042943001, 38.31872843205929, 41.26867733895779, 39.05634865164757, 41.89305983483791, 39.064354822039604, 39.993074387311935, 41.106125861406326, 41.81694991886616, 40.09853012859821, 42.76319034397602, 40.73643609881401, 41.44969962537289, 44.59520883858204, 53.507338017225266, 54.84051547944546, 47.85352639853954, 51.41655720770359, 55.603894516825676, 47.78135687112808, 43.64054046571255, 41.854868084192276, 40.87793670594692, 40.54464519023895, 52.38165222108364, 55.09323991835117, 56.779654026031494, 49.56385262310505, 53.62444393336773, 57.55629815161228, 52.539636343717575, 54.52303111553192, 49.630615040659904, 46.710635125637054, 45.23913748562336, 46.72614209353924, 46.47352784872055, 47.125029489398, 48.66730213165283, 51.638666689395905, 51.1042557656765, 55.80863133072853, 50.32356485724449, 49.81295965611935, 51.08183316886425, 41.57129310071468, 44.6438842266798, 41.1716153472662, 41.69721834361553, 42.31070302426815, 41.92801795899868, 41.27371586859226, 40.91249965131283, 40.4380989074707, 41.88737913966179, 41.41195245087147, 41.83592990040779, 38.75653333961964, 41.41251482069492, 41.415851041674614, 43.93770731985569, 43.80673974752426, 41.33602112531662, 41.27945736050606, 45.080192014575005, 40.672914907336235, 43.575829938054085, 41.5988340228796, 44.888150319457054, 44.698373302817345, 43.39274436235428, 42.35048308968544, 45.114158391952515, 45.54960362613201, 47.48787581920624, 46.20471507310867, 44.30849142372608, 44.73441816866398, 46.6263784468174, 45.61222046613693, 47.313582971692085, 48.53694632649422, 50.53631164133549, 48.42035338282585, 49.468751326203346, 49.70262497663498, 51.08485400676727, 61.52430362999439, 69.95182201266289, 59.11349639296532, 79.08184289932251, 17.950460985302925, 1.4367441111244261, 2.4829285545274615, 0.10807678423589095, 3.6173940170556307, 62.40722045302391, 73.31070497632027, 69.02714923024178, 55.532393753528595, 33.0195289850235, 39.95107524096966, 54.07918073236942, 66.55611142516136, 72.02057540416718, 14.118459708988667, 0.31557327427435666, 0.17662645666860044, 0.13774628983810544, 0.14067259297007695, 0.11786979390308261, 0.11340455108438618, 0.11753618367947638, 0.26463095156941563, 0.19645664258860052], [0.049038610013667494, 0.03421900444664061, 0.08191987843019888, 0.07752507284749299, 0.0453365584689891, 0.02198436231992673, 0.014730011644132901, 0.0394442435936071, 0.10584191782982089, 0.018272865090693813, 2.7261596778407693, 51.50794230401516, 56.93470470607281, 42.603876292705536, 39.47277210652828, 28.199111446738243, 41.65570177137852, 31.422799564898014, 42.78748244047165, 49.086203053593636, 41.72245278954506, 1.2128164269961417, 0.16148101858561859, 0.05926997291680891, 3.5131309367716312, 46.16411045193672, 59.62144173681736, 56.929677575826645, 51.86195030808449, 50.508637726306915, 46.047293320298195, 42.39158548414707, 41.99438899755478, 39.5530503988266, 39.70944620668888, 39.4497187435627, 39.21875573694706, 38.269125893712044, 38.48305821418762, 38.496403098106384, 37.79630966484547, 38.2379599660635, 36.02944627404213, 37.9400597512722, 36.27210505306721, 38.56704890727997, 37.406693771481514, 36.82251311838627, 34.549357295036316, 35.08600629866123, 36.582404002547264, 37.005693688988686, 35.784199833869934, 37.066612020134926, 36.11864648759365, 36.74473889172077, 35.01616984605789, 35.13032712042332, 35.38181662559509, 36.125835701823235, 37.63987585902214, 36.95037245750427, 34.71763886511326, 37.57540851831436, 38.06553281843662, 36.31718963384628, 35.4557416588068, 37.95664966106415, 36.603713259100914, 36.51725269854069, 38.08562994003296, 37.31706038117409, 37.89149835705757, 36.520946100354195, 37.42637291550636, 48.03095027804375, 48.414653688669205, 40.16439959406853, 47.594137117266655, 45.62822140753269, 41.758072078228, 39.80251841247082, 38.149477913975716, 36.753839403390884, 36.532429084181786, 46.53171792626381, 51.72493726015091, 53.59667122364044, 49.21172171831131, 47.38750420510769, 51.41049273312092, 48.8023316860199, 43.537885174155235, 39.97748002409935, 41.39357663691044, 38.30312266945839, 40.9532904624939, 43.335519433021545, 44.45995509624481, 48.19809190928936, 47.690351754426956, 51.00723557174206, 51.84079684317112, 42.01631762087345, 48.60565423965454, 42.28216655552387, 36.497991532087326, 37.479102686047554, 37.162781059741974, 36.547863855957985, 37.33077384531498, 39.373901411890984, 35.88644474744797, 36.86579279601574, 37.230903804302216, 39.917929619550705, 35.47930419445038, 37.07674987614155, 36.025110706686974, 36.48051626980305, 36.91928252577782, 38.97556118667126, 38.30542914569378, 37.753029987215996, 38.345197811722755, 38.73122289776802, 36.621868684887886, 38.3578397333622, 38.11947472393513, 39.282447919249535, 39.81017880141735, 40.762232914566994, 40.33012770116329, 42.02906973659992, 41.00115269422531, 43.36702734231949, 41.52059622108936, 43.68399113416672, 42.06826463341713, 42.084432765841484, 41.92455634474754, 44.1023600846529, 42.603351920843124, 47.55079284310341, 44.5178297907114, 46.33982062339783, 46.03375464677811, 50.12537509202957, 53.87023754417896, 61.421522945165634, 57.19825856387615, 72.60908022522926, 13.254728056490421, 0.9326734906062484, 0.6591958715580404, 0.028922745477757417, 3.1612365692853928, 50.37587285041809, 61.61451078951359, 58.72139923274517, 42.226909920573235, 24.40397009253502, 19.45763871073723, 37.93529860675335, 50.81265941262245, 42.757585644721985, 5.780946146696806, 0.22664749209070578, 0.0467663690506015, 0.10712789648096077, 0.016601565221208148, 0.09489331743679941, 0.07081209478201345, 0.08365400295588188, 0.03995605460659135, 0.06099816397181712, 0.051581567895482294, 0.032265630943584256, 0.06918253886396997, 0.03819833349552937, 0.068453683052212, 0.06654246724792756, 0.024675486274645664, 0.017789413395803422, 0.154213908535894, 0.08360806401469745, 3.008859995752573, 59.126339703798294, 60.326953679323196, 50.69295823574066, 39.605757370591164, 27.56155125796795, 51.949585005640984, 37.9660427570343, 50.8525762706995, 54.123987928032875, 45.73322117328644, 1.2504170718602836, 0.19077955425018445, 0.10298078268533573, 4.002619246020913, 48.18732708692551, 60.098338946700096, 58.35289500653744, 54.31100629270077, 53.46321098506451, 48.95895928144455, 44.26827818155289, 43.96676816046238, 42.46631607413292, 41.249587163329124, 40.489559546113014, 40.83227835595608, 40.39244435727596, 40.21165005862713, 39.235189855098724, 40.39005048573017, 40.34560427069664, 39.450349509716034, 40.40703937411308, 37.72736616432667, 39.86326575279236, 39.73884142935276, 39.034317433834076, 36.16181597113609, 37.21518024802208, 37.483803033828735, 38.92352677881718, 36.54242254793644, 38.581134751439095, 38.86775717139244, 37.347800731658936, 36.827122271060944, 37.09731437265873, 37.13704124093056, 38.080978989601135, 37.71150581538677, 37.843145951628685, 37.937122508883476, 39.33632142841816, 38.736611008644104, 38.66590440273285, 37.61324688792229, 38.87207753956318, 38.796013221144676, 38.94940339028835, 39.850262850522995, 39.78402100503445, 39.46684442460537, 39.4413135945797, 39.660896211862564, 49.400833770632744, 50.15614964067936, 43.77525083720684, 49.38989415764809, 48.43254692852497, 44.591690227389336, 41.74943134188652, 40.692252069711685, 39.36811052262783, 38.677828162908554, 48.337734416127205, 54.15276758372784, 53.668388575315475, 51.4279679954052, 49.71765697002411, 54.379828199744225, 50.103450268507004, 46.943581625819206, 41.955144703388214, 42.30607487261295, 41.437186896800995, 41.285157054662704, 44.465050622820854, 45.63136383891106, 49.2364127933979, 49.81156513094902, 51.68146759271622, 56.432136073708534, 44.31345775723457, 51.29314363002777, 44.23080459237099, 38.32872189581394, 40.91840073466301, 39.42201443016529, 38.66465426981449, 40.29910996556282, 40.68307936191559, 37.657305523753166, 38.99779759347439, 39.06208634376526, 41.16889849305153, 37.62399271130562, 38.729554787278175, 39.40649226307869, 38.98414492607117, 39.730854257941246, 41.35906308889389, 40.614766627550125, 40.092013478279114, 39.9639717489481, 41.678922325372696, 38.83388578891754, 39.90599445998669, 39.59162972867489, 40.70759564638138, 40.25986947119236, 43.98251071572304, 42.46118634939194, 43.982294127345085, 44.590728878974915, 45.05224451422691, 43.491124883294106, 46.38097621500492, 44.190097376704216, 43.94811496138573, 44.197624772787094, 45.920133143663406, 45.06118543446064, 50.287208408117294, 47.1741646528244, 48.801678121089935, 49.57561679184437, 53.22811000049114, 57.31701359152794, 63.75180870294571, 60.54918855428696, 75.52665486931801, 14.848668426275253, 0.9753995260689408, 1.0077058081515133, 0.022799856451456435, 2.871767389588058, 54.30225536227226, 67.7233935892582, 65.31639754772186, 47.887211591005325, 24.06293459236622, 23.029640838503838, 42.5959537178278, 57.20902718603611, 54.76803816854954, 8.043440692126751, 0.15796705323737115, 0.004504515418375377, 0.10738619355834089, 0.024757424944255035, 0.0688081030966714, 0.06252450941246934, 0.11382586089894176, 0.08695832642843015, 0.01977348769287346, 0.2253875182941556, 0.11907256295671687, 0.2284143675933592, 0.15980196883901954, 0.09167844502371736, 0.1138615062518511, 0.1364421285688877, 0.2402322381385602, 0.1901498419465497, 0.1116290147183463, 3.8676148653030396, 66.29217758774757, 68.53788748383522, 57.054421082139015, 48.326680809259415, 37.43768110871315, 55.69753669202328, 43.747223541140556, 57.25576087832451, 57.7573149651289, 50.41473336517811, 1.2468545255251229, 0.5091244680806994, 0.24876435374608263, 4.744650553911924, 51.60387955605984, 61.31620779633522, 61.279699355363846, 56.737723276019096, 56.00020945072174, 51.287512332201004, 46.0418102145195, 46.427063941955566, 44.04944032430649, 43.21381576359272, 42.306120470166206, 43.60704906284809, 43.44655327498913, 42.38030768930912, 41.92999005317688, 42.80205845832825, 42.28500880300999, 41.635961830616, 42.01714597642422, 39.89971339702606, 41.98978744447231, 42.14703440666199, 40.84656558930874, 38.24555955827236, 37.7257664501667, 40.877887308597565, 41.398915350437164, 38.20774778723717, 39.845323115587234, 40.495038852095604, 41.553688645362854, 39.55411434173584, 38.32256242632866, 39.161948785185814, 40.004872754216194, 39.22615014016628, 41.647938787937164, 39.66111660003662, 41.84079363942146, 41.35506570339203, 39.74140249192715, 37.9105581343174, 41.401909589767456, 40.580397471785545, 40.41173592209816, 43.38045962154865, 41.32021777331829, 42.1225219219923, 41.44344516098499, 41.33294329047203, 52.8313846886158, 51.81441865861416, 46.219895258545876, 49.971988722682, 49.18897993862629, 46.03976592421532, 44.28303278982639, 42.31465481221676, 42.04284779727459, 41.1528405547142, 49.30580087006092, 57.44845613837242, 56.483003944158554, 53.30219462513924, 52.25442364811897, 58.27372245490551, 52.54112966358662, 46.807586923241615, 43.566216453909874, 45.558403953909874, 43.32926496863365, 43.12021538615227, 48.09243477880955, 49.44583095610142, 52.58906029164791, 52.77589626610279, 52.8944157063961, 54.999574944376945, 48.073781579732895, 54.29001621901989, 45.50744108855724, 40.46108387410641, 42.41931639611721, 42.113846987485886, 40.75753256678581, 42.665110006928444, 43.73446382582188, 38.14046859741211, 41.23269706964493, 40.38265988230705, 44.14039224386215, 38.93165074288845, 40.174191668629646, 41.57463692128658, 40.60174472630024, 41.61774940788746, 43.77688094973564, 44.42201793193817, 42.83912926912308, 42.603910490870476, 44.74701829254627, 40.754336938261986, 43.24085891246796, 41.23633347451687, 44.323097839951515, 42.88027726113796, 46.60085141658783, 44.63391736149788, 47.115427404642105, 46.427432522177696, 45.68671926856041, 46.1929889023304, 48.336054906249046, 45.84050841629505, 46.1886191368103, 47.08037808537483, 49.63793344795704, 47.58651092648506, 53.56378398835659, 49.307047203183174, 51.50728113949299, 51.43958397209644, 56.06333166360855, 59.73748371005058, 67.255539894104, 63.57100300490856, 77.80341669917107, 16.599337086081505, 1.3298047869466245, 3.456631056033075, 0.14162899868097156, 3.148943753913045, 61.75088167190552, 73.13944056630135, 71.60205826163292, 56.28148935735226, 36.75779119133949, 31.913127154111862, 53.60407702624798, 67.09717959165573, 68.1397296488285, 11.958509311079979, 0.3092934878077358, 0.1245453825686127, 0.3139416180783883, 0.15276970400009304, 0.1748283812776208, 0.16457537363748997, 0.15519594802754, 0.17138279741629958, 0.17798071290599182], [0.03211670045857318, 0.08575497107813135, 0.09255006036255509, 0.03642686038801912, 0.04448709252756089, 0.020909819686494302, 0.03255002935475204, 0.0170281906684977, 0.07067642276524566, 0.0476346261712024, 0.6383577303495258, 34.26426239311695, 61.36572293937206, 42.79119864106178, 42.43848256766796, 34.85226944088936, 41.33464179933071, 39.62779998779297, 46.66692987084389, 54.34285618364811, 43.26967656612396, 2.1766671258956194, 0.3057279728818685, 0.19713170011527836, 0.9115488803945482, 46.74729935824871, 58.90199974179268, 56.05352818965912, 51.206204295158386, 47.932410165667534, 41.378506645560265, 41.09522424638271, 37.18133166432381, 37.43662856519222, 37.36935697495937, 38.928474113345146, 36.77372373640537, 37.682505771517754, 35.708602890372276, 36.97203889489174, 36.589916199445724, 39.68796215951443, 40.911279916763306, 40.77745109796524, 37.555448189377785, 36.43529109656811, 37.11697071790695, 37.17414245009422, 37.966730520129204, 40.182756409049034, 39.765933975577354, 41.683079302310944, 39.809821620583534, 37.21233420073986, 36.72868475317955, 35.88986836373806, 33.9144379645586, 35.23419074714184, 34.43566359579563, 36.26243457198143, 34.68992315232754, 36.69220291078091, 36.41789563000202, 37.70197972655296, 37.51908794045448, 37.18455009162426, 37.388059571385384, 36.94268546998501, 36.238153874874115, 36.469401866197586, 37.5895931571722, 39.31233711540699, 38.83474834263325, 38.271295577287674, 36.73468843102455, 44.536524787545204, 49.71313901245594, 46.34336583316326, 48.39064657688141, 44.755279049277306, 39.611932039260864, 40.07345527410507, 35.367248207330704, 37.207888439297676, 37.44125671684742, 45.261438488960266, 51.00253902375698, 51.340416893363, 49.930076971650124, 48.213196098804474, 53.340276181697845, 48.09742771089077, 41.808647364377975, 39.568766355514526, 40.99201798439026, 40.49661956727505, 44.761761501431465, 48.412073627114296, 46.85099199414253, 52.02153034508228, 52.15782903134823, 48.9372244477272, 41.80797480046749, 46.26764349639416, 49.2109427601099, 39.146514013409615, 38.47037069499493, 36.92433625459671, 36.112509816884995, 37.899914905428886, 37.691040113568306, 36.63785442709923, 37.587442472577095, 37.72292800247669, 37.60517232120037, 36.48724190890789, 36.03184774518013, 37.634073570370674, 35.65843418240547, 37.623810321092606, 35.428835302591324, 37.819693610072136, 36.58919803798199, 37.43263117969036, 36.39891944825649, 37.50742256641388, 37.28876329958439, 38.31366330385208, 37.3335362970829, 37.86717966198921, 38.45489792525768, 39.781060963869095, 39.848400950431824, 39.34264808893204, 39.28096599876881, 40.609085932374, 39.6949727833271, 41.98965065181255, 39.47704687714577, 42.488993257284164, 41.75909422338009, 43.55443328619003, 44.03652861714363, 46.34836256504059, 44.769015312194824, 47.19867333769798, 49.98143121600151, 52.77290962636471, 54.72251661121845, 62.33502432703972, 58.10020476579666, 71.84794306755066, 11.376081313937902, 0.6388914829585701, 0.6001925782766193, 0.04847654447075911, 2.459617992863059, 49.91073600947857, 63.253020867705345, 59.749335274100304, 47.874288484454155, 24.921709410846233, 28.567923456430435, 48.24744366109371, 50.90096667408943, 46.195413172245026, 4.915027711540461, 0.11258204365731217, 0.05377757544920314, 0.02997911662532715, 0.05742672670749016, 0.029411047107714694, 0.012590025107783731, 0.09919988908222876, 0.03695539940963499, 0.05648682636092417, 0.016851598484208807, 0.030233858815336134, 0.06067609414458275, 0.017712920234771445, 0.07358302929787897, 0.05878479016246274, 0.10332916906918399, 0.03586826809623744, 0.0617804655485088, 0.007539134539911174, 0.8588182192761451, 39.20833669602871, 67.22131133079529, 48.61663565039635, 43.62350977957249, 42.56647489964962, 53.16876858472824, 44.67368222773075, 52.0531864464283, 56.874033361673355, 47.14566998183727, 2.099196407943964, 0.21139704011147842, 0.050516207484179176, 1.039925585500896, 48.83365720510483, 61.581441164016724, 58.032507598400116, 53.937957510352135, 49.83614221215248, 43.99246618151665, 42.562895491719246, 39.17194984853268, 39.59477595984936, 38.132257238030434, 39.960555732250214, 38.73301260173321, 39.219386503100395, 38.285582810640335, 38.76016974449158, 39.05295543372631, 40.672287940979004, 42.94560715556145, 42.7577718347311, 38.51929686963558, 39.709791988134384, 38.25821667909622, 37.72309899330139, 37.99210175871849, 42.375063970685005, 40.77911540865898, 43.72821316123009, 39.99276660382748, 39.343940019607544, 39.42750133574009, 39.3327572196722, 37.510181218385696, 38.52598451077938, 34.83913354575634, 36.89081825315952, 36.30898967385292, 37.86877557635307, 37.57556051015854, 37.84811228513718, 38.20808216929436, 38.626918494701385, 38.43833081424236, 38.73045153915882, 37.60692022740841, 38.37908059358597, 39.15127515792847, 39.80995461344719, 39.57743749022484, 38.722008392214775, 38.49788121879101, 45.434579998254776, 50.76308347284794, 48.11918154358864, 49.75077599287033, 46.0471261292696, 42.69123360514641, 41.781961396336555, 37.54076197743416, 40.66262125968933, 40.13025462627411, 46.246117651462555, 51.71740226447582, 53.61896462738514, 52.72281691431999, 51.18244417011738, 55.37004366517067, 51.958924904465675, 43.837681487202644, 41.85629680752754, 43.51683430373669, 41.858280301094055, 48.33520755171776, 48.92190746963024, 49.72971752285957, 51.98613904416561, 51.87471762299538, 52.76910603046417, 45.169228836894035, 47.203400284051895, 50.47217108309269, 40.8514217287302, 40.013277903199196, 38.940238282084465, 38.81713628768921, 38.07619124650955, 38.92655901610851, 38.62405724823475, 39.43724401295185, 40.1462821662426, 38.868539929389954, 38.56680952012539, 38.49412702023983, 38.95488269627094, 37.14245595037937, 38.823280557990074, 37.4649940431118, 40.052560195326805, 38.3852818608284, 39.73360911011696, 38.975166007876396, 39.68804195523262, 40.59848830103874, 39.31135676801205, 39.06991012394428, 39.534970968961716, 40.10291129350662, 41.53636917471886, 42.09462761878967, 41.03135347366333, 41.14008083939552, 42.821916192770004, 42.85160019993782, 43.84430453181267, 41.76068253815174, 45.46464018523693, 45.386094599962234, 46.16796724498272, 45.858724638819695, 48.8896320015192, 48.37124481797218, 50.38833998143673, 50.92317648231983, 55.744718760252, 56.440909802913666, 64.75601881742477, 60.03707103431225, 74.32302385568619, 12.90343975648284, 1.1790576134808362, 1.2256558192893863, 0.09539322069031186, 2.508596177212894, 54.725830033421516, 65.5861222743988, 65.07093071937561, 48.55449378490448, 27.302880138158798, 31.476779468357563, 56.67902022600174, 57.351105362176895, 55.728953406214714, 7.8513462748378515, 0.1076014460704755, 0.08337637293152511, 0.01594817469595, 0.009078378971025813, 0.026336589035054203, 0.024507341586286202, 0.13176263513742015, 0.04105272993911058, 0.03785913118917961, 0.19308971153805032, 0.16955083556240425, 0.20526845881249756, 0.10366813759901561, 0.20328359969425946, 0.14679461368359625, 0.1615541201317683, 0.12471689289668575, 0.18890117848059162, 0.10027903859736398, 1.077212628442794, 45.26289761066437, 75.2928078174591, 54.49311912059784, 55.83190128207207, 44.67791520059109, 53.01505923271179, 51.03612922132015, 58.23402978479862, 62.72351548075676, 51.523407474160194, 2.3881625896319747, 0.35421209468040615, 0.3651909821201116, 1.653068878222257, 52.03765667974949, 63.14222261309624, 61.18853084743023, 56.30072392523289, 52.640308141708374, 45.89691258966923, 46.04397229850292, 40.82028619945049, 41.34865924715996, 40.932965353131294, 43.48726809024811, 41.384244337677956, 40.8574254065752, 40.444866344332695, 40.82825817167759, 40.5639823526144, 42.379198148846626, 44.45055440068245, 45.63119284808636, 40.37329338490963, 40.83602495491505, 41.31330594420433, 39.74854990839958, 41.48882232606411, 44.54619526863098, 43.63422520458698, 45.50503961741924, 43.89951556921005, 42.363049015402794, 40.716331377625465, 40.06928689777851, 39.24878932535648, 40.06446875631809, 37.09204785525799, 39.8302037268877, 38.25496785342693, 38.77550572156906, 39.844209775328636, 41.13890290260315, 41.3096809387207, 41.04527972638607, 41.16262502968311, 39.656678438186646, 39.93465632200241, 41.016032695770264, 41.852747797966, 42.694353237748146, 42.66803205013275, 40.92856138944626, 39.602877125144005, 48.78363288938999, 54.23245310783386, 50.47562509775162, 52.28976555168629, 46.97189770638943, 42.84521274268627, 43.141532242298126, 38.88480685651302, 43.68173785507679, 42.096816301345825, 50.846002623438835, 55.57098068296909, 55.49333944916725, 56.1755358427763, 53.50566990673542, 58.51547688245773, 55.31324051320553, 45.41569121181965, 42.47757866978645, 45.5636590719223, 44.4337023049593, 50.41338823735714, 51.52528077363968, 51.216433346271515, 55.816284120082855, 55.07663480937481, 52.24607169628143, 46.78487554192543, 50.27626119554043, 52.154249623417854, 43.847500160336494, 41.51883311569691, 39.28170695900917, 39.833969324827194, 41.67101874947548, 40.60324564576149, 39.95965898036957, 42.027990594506264, 43.61943639814854, 40.339501798152924, 41.20347663760185, 39.172702208161354, 41.60560145974159, 38.97240735590458, 41.441963240504265, 40.693323612213135, 43.543303683400154, 41.210297271609306, 41.67528972029686, 40.04298850893974, 41.43292352557182, 43.54204975068569, 43.590022176504135, 41.13511450588703, 41.77106738090515, 43.256498873233795, 43.62141229212284, 44.49386827647686, 43.08176524937153, 41.714439019560814, 43.86403687298298, 43.83177660405636, 45.09145841002464, 43.250650987029076, 48.21738347411156, 48.20328623056412, 48.93722824752331, 48.676300048828125, 52.06812724471092, 50.73058381676674, 54.23785641789436, 54.00809034705162, 58.99198651313782, 59.537409245967865, 67.76453018188477, 63.56895871460438, 77.2348304092884, 14.70791257917881, 0.9891986043658108, 3.7846527295187116, 0.07740711589576676, 2.7514458959922194, 59.6945346146822, 71.82391315698624, 74.11764487624168, 61.90688610076904, 37.724987491965294, 42.7488499134779, 64.55130860209465, 66.62803396582603, 69.27594467997551, 12.56813244894147, 0.24444174428936094, 0.17069970985176042, 0.13523435743991286, 0.17819032509578392, 0.15138889371883124, 0.11110548148280941, 0.2756879723165184, 0.11373626883141696, 0.16925409523537382], [0.04160442025749944, 0.09586751984898001, 0.019409918822930194, 0.05239796744717751, 0.02148568175471155, 0.005132390442668111, 0.03010033346072305, 0.002234515741292853, 0.06896157923620194, 0.1283068541670218, 0.2585423126583919, 22.60780457407236, 59.216011092066765, 48.0134180188179, 33.79810340702534, 8.658462390303612, 27.466715946793556, 37.13091216981411, 49.35159981250763, 52.5558652728796, 49.1199566423893, 3.5444771172478795, 0.37949626450426877, 0.06427852349588647, 0.7921386254020035, 43.66664506494999, 60.56932367384434, 56.67654275894165, 50.485287979245186, 47.741903588175774, 43.323394283652306, 41.342036202549934, 40.816566199064255, 42.319195568561554, 43.615849390625954, 45.51381714642048, 46.42796449363232, 48.74362863600254, 45.581936091184616, 40.439748018980026, 38.127309903502464, 41.59845024347305, 37.7973660081625, 37.55756847560406, 36.60416163504124, 38.89779835939407, 41.02997034788132, 44.296172484755516, 47.41043597459793, 47.21254259347916, 47.565950229763985, 48.31958658993244, 45.39392597973347, 42.75928795337677, 37.93692111968994, 36.16359427571297, 33.81780914962292, 35.44361270964146, 36.30450211465359, 35.35698115825653, 37.79547370970249, 37.39790864288807, 34.71874080598354, 36.02182388305664, 36.72938011586666, 36.55667558312416, 36.95471942424774, 36.75298824906349, 36.988370418548584, 38.360529989004135, 37.50368356704712, 37.12159126996994, 35.52957929670811, 36.891342625021935, 37.07017622888088, 41.1410877853632, 46.653543189167976, 46.997158750891685, 45.75562097132206, 43.043782487511635, 40.60858055949211, 38.01695242524147, 36.18173070251942, 37.60405518114567, 38.49211312830448, 43.38154636323452, 51.17343485355377, 49.83503647148609, 51.02867782115936, 47.93352350592613, 50.548710376024246, 49.24748919904232, 40.51349826157093, 41.573816165328026, 42.71525591611862, 44.37178082764149, 47.30200119316578, 49.505993127822876, 50.069141909480095, 51.7434498667717, 48.64744819700718, 45.50820864737034, 47.901574820280075, 49.568495973944664, 40.4887729883194, 38.27254571020603, 36.41327507793903, 37.36527219414711, 35.85301794111729, 35.96225447952747, 38.07586446404457, 37.77595415711403, 36.55689597129822, 37.15327776968479, 36.30035273730755, 37.11723290383816, 37.054460272192955, 37.566159814596176, 36.58186063170433, 37.74343930184841, 36.73579417169094, 36.51581257581711, 35.91797165572643, 37.54598669707775, 34.683189913630486, 36.98479861021042, 36.59445695579052, 37.133309841156006, 36.956170946359634, 38.1117307394743, 38.0987848341465, 40.06015978753567, 41.26155272126198, 41.947830095887184, 41.623981073498726, 39.76480543613434, 40.98198652267456, 41.71833001077175, 39.841876700520515, 42.00062446296215, 41.24903619289398, 45.955437049269676, 46.28686286509037, 46.23908802866936, 46.6999576985836, 48.05879898369312, 48.74040260910988, 52.42079772055149, 56.99837788939476, 61.88001774251461, 60.926614701747894, 72.04577565193176, 8.600060474127531, 0.8448057586792856, 0.4321295558474958, 0.030793337973591406, 2.6948457956314087, 47.09144689142704, 66.34792819619179, 54.43489484488964, 46.69912174344063, 19.90606974810362, 20.576931349933147, 38.63939702510834, 52.74179309606552, 46.97426117956638, 4.017237536609173, 0.17400906508555636, 0.05792156851384789, 0.07555936113931239, 0.032883609892451204, 0.04421075384016149, 0.06432786889490671, 0.010542419258854352, 0.02693590482522268, 0.019748640588659327, 0.04127228690776974, 0.035888948041247204, 0.050622586932149716, 0.0602545357105555, 0.030351843597600237, 0.036749022983713076, 0.05438952815893572, 0.020030025880259927, 0.022943738476897124, 0.2041972873848863, 0.2570622327039018, 27.300966940820217, 69.92606699466705, 52.182592302560806, 41.823303177952766, 14.500408563762903, 32.236637994647026, 43.55393171310425, 54.52634833753109, 57.561728060245514, 55.32209023833275, 3.4036851720884442, 0.3163945348933339, 0.13213721191277727, 0.9366138791665435, 47.2288703173399, 61.26246728003025, 58.63480567932129, 54.324081391096115, 49.6187786757946, 45.6103889644146, 44.028856828808784, 41.20107136666775, 43.886945843696594, 45.152593329548836, 46.84869311749935, 47.09787234663963, 49.389928355813026, 46.926292553544044, 41.26364640891552, 38.90114597976208, 43.98221053183079, 40.97134329378605, 40.7407146692276, 37.66387157142162, 42.359431609511375, 43.46970543265343, 45.92187725007534, 47.06605665385723, 49.45247679948807, 48.33342544734478, 51.02871961891651, 47.89287328720093, 45.30457757413387, 39.777956530451775, 37.58844181895256, 37.170981019735336, 38.03664296865463, 38.651579171419144, 37.633826583623886, 38.88114005327225, 39.236090406775475, 36.75742261111736, 37.73335084319115, 38.243572264909744, 37.93424606323242, 39.41107861697674, 39.281041994690895, 38.43439042568207, 38.51959705352783, 37.93769247829914, 39.36008155345917, 37.869402542710304, 39.10898722708225, 37.83979073166847, 42.308331951498985, 47.28071093559265, 48.169069066643715, 47.447681576013565, 44.57520671188831, 42.425358071923256, 40.739380940794945, 38.448605462908745, 40.13162635266781, 40.30848406255245, 45.14589808881283, 52.063601687550545, 52.20148108899593, 53.08142647147179, 50.80647334456444, 54.54980067908764, 51.43280893564224, 43.79381284117699, 43.531710505485535, 46.01043909788132, 47.861836552619934, 50.03345422446728, 51.52558475732803, 51.51473633944988, 52.92175143957138, 52.52682723104954, 49.14080612361431, 48.05605933070183, 50.10887637734413, 43.44740442931652, 39.036760702729225, 38.615591302514076, 39.13951098918915, 38.4808961302042, 37.56961762905121, 39.69426982104778, 38.06848146021366, 39.20430891215801, 38.55840817093849, 38.89729678630829, 38.64537790417671, 37.53348536789417, 39.988571628928185, 39.05225247144699, 39.771740064024925, 38.10721658170223, 38.352178037166595, 38.42603847384453, 39.95976537466049, 37.93306052684784, 39.54244516789913, 39.57722470164299, 38.71357284486294, 38.70763376355171, 40.21519906818867, 39.094684794545174, 41.139294281601906, 41.34906582534313, 42.39214785397053, 43.195451349020004, 40.647900849580765, 42.48699836432934, 41.9716814160347, 42.239840626716614, 43.79271849989891, 44.563879519701004, 48.88263277709484, 49.35868263244629, 50.162191316485405, 49.279460683465004, 50.44502533972263, 51.47774152457714, 56.286873668432236, 60.91894671320915, 63.81281062960625, 63.360296711325645, 73.40021297335625, 10.26770168915391, 1.7051620641723275, 1.545712526421994, 0.07177530598710291, 2.1944710705429316, 53.168745785951614, 70.92823281884193, 61.13229766488075, 57.67361305654049, 31.322650238871574, 25.406789481639862, 47.42229513823986, 59.770682528615, 56.72655947506428, 6.811865977942944, 0.04490042796533089, 0.10102099331561476, 0.025515176275803242, 0.028736297572322655, 0.01640457510802662, 0.03399726556381211, 0.11069398286053911, 0.04817863155039959, 0.02071783907013014, 0.0874326255870983, 0.20406741154147312, 0.09473446072661318, 0.17600366118131205, 0.13408555736532435, 0.08023028276511468, 0.10292045350070111, 0.09474332196987234, 0.1558925278368406, 0.3317347273696214, 0.2830884017748758, 32.949209958314896, 78.32024976611137, 59.41942557692528, 47.421295791864395, 16.39916952699423, 38.793892934918404, 47.459403946995735, 62.4041236191988, 62.53477580845356, 60.67656151950359, 4.039988340809941, 0.5417036823928356, 0.21006865514209494, 1.1998883332125843, 50.084439888596535, 63.98919716477394, 62.21395902335644, 55.930916368961334, 52.51086808741093, 47.340276539325714, 44.54324282705784, 44.961623176932335, 46.65023356676102, 46.52170546352863, 49.37469497323036, 51.740163043141365, 52.70369254052639, 50.60751602053642, 43.74488666653633, 41.838171780109406, 45.9547720849514, 41.43918178975582, 41.71879358589649, 39.43706922233105, 43.834383264184, 45.23996964097023, 48.08902256190777, 50.11085607111454, 51.025094613432884, 51.49800203740597, 54.058859422802925, 49.56827558577061, 46.41851060092449, 41.94483585655689, 41.178052201867104, 38.84320668876171, 39.778214916586876, 41.65342949330807, 40.316239446401596, 42.633073925971985, 41.68304890394211, 37.0381211489439, 39.574758633971214, 38.91913801431656, 40.56304380297661, 40.56770995259285, 40.413130447268486, 41.62752628326416, 41.940378695726395, 39.9530853331089, 42.137599512934685, 39.60679471492767, 40.44812276959419, 40.02093829214573, 43.767579048871994, 50.42128041386604, 50.65808370709419, 49.76752549409866, 48.04404437541962, 44.649203941226006, 41.47170424461365, 40.401757657527924, 42.66694150865078, 41.68859280645847, 46.97184830904007, 56.63831301033497, 53.55199322104454, 54.31190304458141, 54.85668361186981, 55.731457471847534, 53.02099831402302, 44.93412785232067, 45.99409617483616, 48.558057993650436, 49.041559249162674, 51.55371084809303, 52.199467197060585, 53.02952125668526, 56.241416707634926, 54.05209958553314, 51.80762842297554, 51.40991896390915, 52.603529915213585, 44.89114075899124, 42.41598017513752, 40.39826564490795, 40.821513533592224, 40.90242259204388, 40.21482668817043, 42.21543833613396, 39.60571937263012, 40.58017708361149, 41.72767370939255, 39.53756242990494, 41.64535112679005, 41.00004695355892, 42.468576952815056, 40.617031306028366, 41.66680097579956, 40.24276278913021, 40.15704318881035, 40.70485219359398, 43.321532383561134, 38.88421408832073, 41.84705190360546, 41.60258822143078, 40.38491316139698, 41.62737049162388, 42.78079479932785, 42.41487443447113, 43.30829009413719, 44.05011288821697, 45.632032603025436, 45.84627650678158, 43.79700846970081, 44.97234620153904, 45.130459517240524, 44.437585696578026, 47.764345183968544, 47.56128028035164, 52.053406834602356, 53.55971060693264, 52.42639862000942, 52.1278790384531, 52.45436131954193, 53.96025851368904, 59.451245069503784, 62.343672662973404, 69.0917381644249, 66.04833707213402, 78.20126295089722, 10.604319926351309, 1.7052517156116664, 3.408320448361337, 0.14935609186068177, 2.5726559897884727, 58.1202182918787, 75.46569094061852, 69.16433706879616, 61.43649034202099, 30.483698956668377, 31.874996200203896, 55.854931846261024, 66.71391695737839, 68.04417997598648, 11.012399978935719, 0.28168966120574623, 0.14779079850995913, 0.11434367959736846, 0.10050446595414542, 0.19158370094373822, 0.0990327203180641, 0.17132440523710102, 0.11089932770119049, 0.12493925518356264], [0.054972321886452846, 0.09406105818925425, 0.03496208351862151, 0.007217027605292969, 0.03811406633758452, 0.07262867933604866, 0.03039650975551922, 0.04942347666656133, 0.03865830920403823, 0.15976967057213187, 0.048285181692335755, 11.58945506438613, 56.38111241161823, 49.95090365409851, 41.98756456375122, 33.80183480679989, 48.352793008089066, 35.763620138168335, 46.487989872694016, 54.29309405386448, 51.62224777042866, 5.8899428229779005, 0.20319954404840246, 0.22833676863228902, 0.19764584518270567, 30.61333280056715, 64.86199513077736, 57.385835498571396, 50.877259746193886, 47.68485724925995, 46.87410995364189, 45.78356087207794, 49.102530777454376, 50.961923003196716, 51.15045368671417, 50.97412794828415, 52.22495622932911, 51.97161242365837, 52.00351171195507, 45.607626512646675, 38.2739782333374, 36.46655961871147, 36.29395008087158, 39.207405745983124, 46.32768027484417, 51.51387378573418, 48.93399842083454, 48.337631821632385, 48.46970893442631, 47.424039244651794, 50.11640377342701, 48.91148842871189, 47.8582039475441, 46.14195764064789, 44.653748497366905, 38.68755184113979, 36.861347034573555, 34.28371734917164, 34.973973110318184, 34.28331837058067, 34.808275401592255, 38.10199186205864, 36.37565329670906, 36.56160771846771, 36.249439269304276, 34.46635454893112, 35.87197132408619, 38.02830621600151, 37.61894278228283, 37.12765954434872, 37.381869703531265, 37.43191681802273, 36.499576047062874, 37.45687007904053, 35.890404134988785, 38.192370012402534, 42.503478080034256, 43.36868405342102, 43.76868478953838, 42.836845591664314, 41.327794566750526, 39.572649747133255, 39.017613530159, 38.89289282262325, 38.33027981221676, 42.57856585085392, 49.347051456570625, 51.85409612953663, 49.708005487918854, 45.91458164155483, 51.372973546385765, 48.12034048140049, 41.04987747967243, 42.44435325264931, 44.46802966296673, 46.482373774051666, 47.63677842915058, 48.23424696922302, 49.41650412976742, 51.567682698369026, 49.679168835282326, 50.10277010500431, 47.23297029733658, 42.626120299100876, 38.28840605914593, 36.77367053925991, 37.62345314025879, 38.17409299314022, 38.0547109991312, 39.05536450445652, 37.69357457756996, 37.287190183997154, 37.58280672132969, 35.27207851409912, 36.557253152132034, 37.418176755309105, 36.73547498881817, 37.110875844955444, 35.26103250682354, 36.80155724287033, 36.44764043390751, 36.15352861583233, 37.1796939522028, 38.18013086915016, 38.925042897462845, 40.527204126119614, 39.826685115695, 41.00862309336662, 38.33033300936222, 38.41142825782299, 38.33546653389931, 39.26732853055, 38.06391030550003, 40.461391657590866, 41.510788947343826, 40.758642107248306, 41.60426393151283, 42.19603277742863, 40.666801035404205, 42.44354389607906, 41.41996622085571, 43.96731153130531, 46.165022403001785, 48.565285205841064, 48.986902981996536, 49.239217042922974, 47.192285880446434, 52.22780607640743, 57.679449543356895, 63.02292801439762, 61.89867854118347, 63.26785147190094, 6.489195367321372, 1.4367082505486906, 0.6141126563306898, 0.1093966122425627, 1.3579446519725025, 46.817781776189804, 61.284775882959366, 56.18456795811653, 39.30326700210571, 25.856738537549973, 18.858382366597652, 32.412386164069176, 50.72785176336765, 40.90898483991623, 1.0785607248544693, 0.024541868151573, 0.020437518760445528, 0.050757346107275225, 0.06593388388864696, 0.052186718821758404, 0.04758221941301599, 0.04080235528817866, 0.059699939884012565, 0.014570582552551059, 0.054542978323297575, 0.05275381983665284, 0.023299442436837126, 0.019165360754413996, 0.041799271130003035, 0.04837255102756899, 0.10375119876698591, 0.03378624329343438, 0.025200078925990965, 0.08250011174823157, 0.03313388806418516, 14.3430732563138, 65.40047943592072, 56.53813138604164, 48.17950710654259, 25.246856063604355, 42.96370178461075, 42.204829305410385, 52.19972178339958, 56.85413382947445, 56.30643881857395, 5.9270549565553665, 0.29872287064790726, 0.0819971805321984, 0.545305295381695, 34.681388810276985, 64.83567014336586, 57.881625294685364, 51.73312582075596, 50.74344992637634, 48.46492499113083, 47.273381128907204, 49.93415415287018, 53.25380802154541, 54.2877971380949, 53.82367864251137, 53.54611873626709, 54.83398362994194, 54.452142119407654, 49.11589466035366, 38.922128453850746, 38.29934947192669, 37.987234219908714, 40.906913951039314, 47.66241945326328, 52.657373026013374, 51.088646203279495, 52.0483873039484, 50.08988879621029, 47.77126081287861, 49.27572928369045, 50.79111076891422, 51.206443682312965, 47.45732545852661, 46.99136406183243, 40.790754184126854, 37.84085847437382, 35.36835014820099, 37.252410650253296, 37.49764949083328, 36.56475014984608, 37.426467910408974, 37.86747224628925, 37.68155962228775, 37.37900845706463, 36.01768210530281, 37.83847600221634, 39.23239320516586, 40.59610202908516, 41.94309175014496, 40.122294053435326, 38.91477204859257, 37.99024745821953, 38.174792155623436, 39.66905057430267, 39.747523963451385, 44.27305832505226, 46.03448800742626, 46.62901170551777, 45.662328377366066, 43.82493317127228, 40.89770324528217, 38.68602052330971, 41.688087433576584, 40.50654463469982, 43.95153097808361, 50.9908090531826, 53.243898153305054, 50.64756587147713, 47.964472845196724, 52.6296117156744, 50.33847525715828, 43.49745534360409, 45.97239553928375, 47.41127572953701, 49.73852165043354, 50.11848986148834, 49.24727641046047, 52.14109852910042, 51.53148204088211, 50.16010522842407, 52.80267342925072, 50.49360953271389, 43.88378441333771, 40.85943929851055, 39.163073524832726, 38.6215265840292, 41.498766392469406, 41.114527210593224, 40.02375014126301, 38.69423568248749, 38.75226616859436, 40.61728589236736, 38.623855859041214, 37.74809405207634, 38.64065855741501, 37.64817461371422, 39.17007274925709, 36.82059042155743, 38.17601948976517, 37.887360379099846, 38.87995071709156, 38.949224799871445, 40.943616181612015, 41.64881274104118, 43.730569034814835, 41.44599102437496, 43.14079508185387, 41.66024252772331, 40.53411975502968, 39.74594704806805, 40.92460200190544, 40.45841261744499, 43.534343764185905, 43.47290486097336, 42.26623021066189, 42.92113646864891, 43.48610535264015, 43.35360266268253, 44.95933569967747, 43.530106991529465, 47.65620678663254, 48.00482288002968, 50.50823114812374, 50.33934161067009, 52.65689045190811, 48.5921573638916, 54.949212446808815, 58.786729127168655, 65.44673815369606, 62.92758733034134, 64.94520306587219, 6.756542371585965, 1.1241497285664082, 0.932639945531264, 0.1350098874536343, 1.5351337753236294, 50.21521747112274, 66.98181018233299, 61.46228715777397, 41.62052325904369, 26.192100942134857, 22.622044309973717, 39.86207261681557, 57.712952345609665, 51.78569220006466, 2.2985631600022316, 0.03700307497638278, 0.058190040435874835, 0.03534057141223457, 0.0234466919573606, 0.09013697461341508, 0.045146357151679695, 0.0221535460150335, 0.08076977217569947, 0.025534538908686955, 0.1534935354720801, 0.24936173809692264, 0.1165624636632856, 0.09769837590283714, 0.18272613873705268, 0.2252224349649623, 0.14116867416305467, 0.1416718354448676, 0.16500381549121812, 0.25504151300992817, 0.15216627856716514, 16.55280288308859, 74.47543367743492, 63.873067796230316, 57.25036136806011, 43.29045385122299, 60.33258117735386, 46.46128490567207, 58.29050995409489, 61.64549432694912, 60.99248796701431, 7.3569215554744005, 0.389141482883133, 0.4002829303499311, 0.8189794351346791, 36.27243183553219, 66.44427582621574, 61.28586262464523, 53.68218943476677, 51.64381921291351, 51.49175517261028, 48.59194457530975, 52.623938620090485, 56.21606446802616, 57.22485713660717, 56.434700936079025, 56.66791722178459, 57.22945109009743, 56.53780460357666, 51.03949584066868, 42.53625892102718, 40.3455700725317, 39.695960730314255, 43.301948234438896, 48.960817381739616, 53.861080035567284, 54.170885011553764, 52.553972974419594, 51.51681862771511, 49.15582671761513, 51.029870957136154, 53.7249219417572, 55.331126153469086, 50.34364677965641, 49.457678720355034, 43.37417095899582, 41.78001590073109, 38.424860537052155, 38.55146214365959, 39.57659773528576, 38.952956199645996, 41.128746047616005, 39.79879081249237, 39.65633265674114, 40.306770354509354, 37.26585052907467, 40.17186999320984, 41.21649473905563, 42.47749887406826, 41.661032885313034, 41.46733067929745, 41.775383949279785, 39.606289342045784, 40.56872449815273, 39.55770134925842, 40.50390377640724, 47.0176662504673, 47.52869702875614, 48.998803943395615, 49.05156411230564, 44.710293263196945, 44.95110534131527, 41.69122986495495, 43.50702702999115, 44.12554644048214, 47.55989335477352, 52.18962572515011, 55.969222113490105, 55.466923266649246, 49.46392558515072, 53.89291852712631, 53.16722586750984, 46.485998779535294, 47.807925045490265, 48.87957774102688, 50.33874124288559, 52.11478114128113, 52.87744581699371, 54.48201611638069, 54.9525410681963, 54.346093609929085, 55.76329976320267, 51.351774483919144, 46.82527497410774, 42.38208219408989, 41.95583626627922, 41.18389628827572, 42.81969331204891, 42.048555091023445, 43.0909189581871, 41.450615376234055, 40.78197285532951, 43.41873496770859, 39.8131388425827, 39.31772522628307, 41.29906810820103, 40.68496786057949, 40.62586963176727, 39.11312520503998, 40.2572438120842, 39.92883503437042, 41.09541043639183, 42.25323870778084, 43.83925840258598, 42.77223765850067, 45.38412630558014, 43.31509172916412, 46.22875638306141, 44.12238880991936, 44.027124121785164, 42.82589837908745, 42.128039225935936, 41.62611275911331, 45.587681382894516, 45.76319016516209, 43.551819026470184, 46.88048601150513, 46.62648104131222, 45.01712679862976, 47.717372104525566, 45.89317359030247, 48.963028863072395, 50.02122648060322, 53.52788731455803, 54.473348781466484, 54.73193630576134, 53.973029628396034, 57.00490973889828, 61.5153931081295, 68.92831653356552, 66.30064353346825, 66.54514521360397, 9.328730273991823, 2.6511419657617807, 3.633692767471075, 0.20585304853739217, 1.6816849051974714, 54.59252938628197, 72.16572001576424, 69.01901006698608, 53.25763441622257, 38.41487467288971, 29.440233148634434, 51.19336478412151, 64.25582885742188, 64.46856424212456, 5.928592449054122, 0.1995822272147052, 0.19261595414718613, 0.09492471770499833, 0.11400752380723134, 0.12417896941769868, 0.09659456482040696, 0.10073856159579009, 0.1778910614666529, 0.12421178718796], [0.01706075981928734, 0.01770456921803998, 0.02321841846423922, 0.08148158827680163, 0.041049687133636326, 0.04542151953501161, 0.06626149755902588, 0.029445569962263107, 0.13959303527371958, 0.11330178589560091, 0.028611648303922266, 5.357934795320034, 55.8118611574173, 52.72644951939583, 47.6006955653429, 28.91112294048071, 33.6158461868763, 38.784667029976845, 46.31068758666515, 54.68293033540249, 54.88928586244583, 11.469271313399076, 0.3097986232023686, 0.2732984645990655, 0.19476677232887596, 17.010965198278427, 60.985834524035454, 57.74518221616745, 55.77563390135765, 51.26570910215378, 51.533552929759026, 52.28816203773022, 50.36546140909195, 51.46479941904545, 52.769827991724014, 52.200770527124405, 53.58002811670303, 53.324472829699516, 51.928507536649704, 45.50202637910843, 36.60728506743908, 38.682836294174194, 40.777584090828896, 46.45463906228542, 49.911666959524155, 43.96546483039856, 44.806044325232506, 48.08903016149998, 48.83716441690922, 48.762300834059715, 48.61355401575565, 50.23991994559765, 47.732548490166664, 45.6759050488472, 44.75174903869629, 42.184481397271156, 38.17934811115265, 35.127975046634674, 35.859010219573975, 35.64383536577225, 35.67422993481159, 35.67581444978714, 34.65625315904617, 37.19656124711037, 38.064480274915695, 36.24505430459976, 35.435241758823395, 37.40165524184704, 36.958701610565186, 37.978411093354225, 38.85738752782345, 38.45759578049183, 35.78085221350193, 37.75676518678665, 37.01487019658089, 36.8433777987957, 38.772199898958206, 40.01211516559124, 40.871397256851196, 39.96961824595928, 39.54056806862354, 38.63321475684643, 36.319841891527176, 36.705141216516495, 38.613163232803345, 39.91936594247818, 50.60905873775482, 51.79033175110817, 51.110985204577446, 47.828892320394516, 53.68297979235649, 47.45463900268078, 41.26532971858978, 44.999731332063675, 45.19119165837765, 45.07646441459656, 49.36369076371193, 47.86705747246742, 48.307146057486534, 48.90646889805794, 46.07157401740551, 45.698369443416595, 40.976340025663376, 38.256358578801155, 36.64659395813942, 36.26452825963497, 37.65237718820572, 37.24331013858318, 37.146445736289024, 37.394405230879784, 37.99092002213001, 39.265470430254936, 37.69983284175396, 37.80796743929386, 37.48107098042965, 36.81772917509079, 35.306983441114426, 36.590421572327614, 37.87923261523247, 36.17653638124466, 36.67510382831097, 37.29661367833614, 36.70999355614185, 41.37715011835098, 44.90880221128464, 48.97364929318428, 49.10262957215309, 47.828162759542465, 46.624402552843094, 44.334227442741394, 43.54700468480587, 39.568249583244324, 39.758155792951584, 38.61928850412369, 40.04836522042751, 40.39095103740692, 39.981325417757034, 40.1620589196682, 39.782949462533, 37.666858211159706, 41.45426698029041, 41.830625385046005, 44.18461427092552, 48.364291191101074, 50.536402836441994, 50.296016335487366, 50.39840944111347, 51.382450237870216, 55.24844639003277, 58.45260165631771, 64.68277394771576, 50.337031334638596, 3.547658734023571, 0.9021835110615939, 1.5114136668853462, 0.08948212576797232, 1.3193047628737986, 47.69483931362629, 63.391930013895035, 54.54690143465996, 50.70464640855789, 38.72467204928398, 24.62581928819418, 34.36455801129341, 50.48976793885231, 43.2612182199955, 1.6545483050867915, 0.08847382909152657, 0.005329746527422685, 0.04051495488965884, 0.08867804586770944, 0.08326210445375182, 0.08379745268030092, 0.10518719514948316, 0.028766825817001518, 0.010466360254213214, 0.023968076675373595, 0.036166043719276786, 0.04636031037080102, 0.07420655951136723, 0.03020773707248736, 0.05365140663343482, 0.03821166617854033, 0.06257175453356467, 0.06644896406214684, 0.0871673077926971, 0.016635292122373357, 6.1456990242004395, 64.17313769459724, 59.48005512356758, 53.45031447708607, 32.738602459430695, 41.471890434622765, 41.65844142436981, 49.483388140797615, 59.75172534584999, 59.6405129134655, 12.291066516190767, 0.39334851026069373, 0.3455415536882356, 0.6180249620229006, 18.058175705373287, 60.93960240483284, 59.25597734749317, 56.247237995266914, 53.38583953678608, 53.75433996319771, 53.04991856217384, 53.10442663729191, 54.46043707430363, 55.30809558928013, 54.6369756013155, 53.94939869642258, 55.14414198696613, 53.05319018661976, 46.579880341887474, 38.89432914555073, 39.63178597390652, 42.12958574295044, 49.62244167923927, 52.16711953282356, 46.20077468454838, 46.18251286447048, 48.127290308475494, 49.98546659946442, 49.598784148693085, 50.55547021329403, 52.37107738852501, 49.385535791516304, 48.98649260401726, 47.17916898429394, 44.26903434097767, 40.581108033657074, 37.36261993646622, 37.879274412989616, 37.27214299142361, 36.56040318310261, 37.45272450149059, 37.1309045702219, 38.32180626690388, 39.987602680921555, 35.94734787940979, 37.34121188521385, 39.03794623911381, 39.06908176839352, 38.61293904483318, 39.3685968965292, 40.26837341487408, 38.533979281783104, 38.181008622050285, 39.366742596030235, 38.73004496097565, 39.20883446931839, 42.39228464663029, 43.43042314052582, 42.365853264927864, 40.595197677612305, 40.943418592214584, 38.35953064262867, 39.07461427152157, 40.468618869781494, 42.41359770298004, 51.55988931655884, 52.856087163090706, 53.59271563589573, 50.52102506160736, 55.48074692487717, 50.01766987144947, 42.6387470215559, 46.69780321419239, 46.413540467619896, 48.10816213488579, 50.15252843499184, 49.430042803287506, 48.84431563317776, 50.585488602519035, 49.71902869641781, 47.97355815768242, 43.31683963537216, 40.418446362018585, 39.325906187295914, 38.09015549719334, 37.98243887722492, 39.36800792813301, 39.85355347394943, 38.03405150771141, 40.13929434120655, 41.4215849339962, 38.92160788178444, 37.84711293876171, 39.57060545682907, 38.507954478263855, 37.147106900811195, 38.222555592656136, 38.83515112102032, 36.973091438412666, 39.76341471076012, 39.64929923415184, 39.25094000995159, 42.02915333211422, 46.962668001651764, 50.81368915736675, 49.873251020908356, 49.558601304888725, 48.714271411299706, 47.71737590432167, 44.29287426173687, 41.53994478285313, 41.951322108507156, 40.425802767276764, 41.560437083244324, 42.23334297537804, 42.44925118982792, 41.98711238801479, 41.51312202215195, 41.50833807885647, 43.74273978173733, 45.13017073273659, 46.93819351494312, 51.059053391218185, 52.43407420814037, 52.75610312819481, 53.429218009114265, 55.600934475660324, 57.855361104011536, 60.01165419816971, 65.3090563416481, 55.94415865838528, 3.410249319858849, 0.6716881762258708, 1.0241356515325606, 0.04435495313373394, 1.1906966264359653, 50.54939053952694, 66.32637575268745, 62.796950340270996, 56.29686713218689, 32.84407339990139, 28.58578819781542, 41.17475777864456, 58.312700763344765, 53.014831244945526, 3.5000788746401668, 0.022371177110471763, 0.03502834617393091, 0.03581667027901858, 0.07632392909727059, 0.030091548287600745, 0.032311785107594915, 0.02801692269713385, 0.04409218090586364, 0.01329664895820315, 0.06172817011247389, 0.12368089184747078, 0.15328321082051843, 0.16739348648115993, 0.1941462032846175, 0.16289253893774003, 0.12468655389966443, 0.15510846365941688, 0.1635480037657544, 0.19095879775704816, 0.12145565109676681, 7.76877480559051, 73.49336877465248, 65.64821854233742, 61.86607629060745, 37.955798506736755, 44.787178337574005, 50.3506726026535, 58.65732327103615, 65.00169083476067, 65.50981476902962, 14.529396258294582, 0.5033610679674894, 0.8451830665580928, 0.5075555085204542, 20.773266814649105, 61.57541088759899, 61.485469713807106, 59.35762569308281, 55.48172727227211, 57.16856695711613, 56.01762771606445, 52.9617290943861, 55.31763307750225, 55.99341541528702, 54.35925230383873, 55.50605736672878, 56.664197221398354, 56.16112321615219, 48.21581795811653, 40.42702630162239, 41.68566316366196, 44.50997181236744, 50.81530027091503, 53.716649785637856, 46.18961848318577, 46.44509017467499, 49.46331761777401, 50.77277675271034, 52.03626595437527, 51.917016953229904, 55.777412205934525, 51.74234412610531, 51.75654776394367, 49.67606820166111, 46.18070796132088, 43.54109600186348, 37.70615950226784, 39.600107073783875, 39.200246930122375, 38.09702552855015, 40.594468116760254, 38.3833933621645, 40.14974758028984, 41.09676316380501, 38.3683043718338, 38.664228692650795, 40.84967382252216, 41.31873585283756, 40.48886798322201, 41.313233748078346, 42.91599914431572, 40.589976757764816, 41.05605974793434, 40.08310295641422, 39.558655098080635, 41.80476777255535, 44.289063066244125, 45.84817260503769, 45.28193838894367, 43.828155398368835, 43.737978637218475, 41.02823004126549, 41.80142015218735, 42.721483781933784, 45.18404424190521, 54.14181277155876, 55.194557681679726, 55.118219777941704, 53.537299409508705, 58.208590149879456, 52.68734201788902, 45.369698479771614, 50.07225774228573, 48.338961750268936, 51.48892432451248, 53.29252414405346, 51.50885805487633, 51.17527015507221, 54.280269742012024, 49.81278106570244, 51.71235613524914, 44.784742668271065, 42.72519998252392, 39.8625285923481, 40.672014355659485, 40.54038181900978, 40.714838057756424, 41.45761460065842, 40.59067212045193, 42.32782110571861, 43.784602135419846, 40.817063972353935, 40.60901753604412, 41.02830983698368, 41.06882706284523, 38.75673092901707, 40.02505347132683, 41.82253181934357, 39.58163246512413, 42.42193825542927, 43.45368929207325, 40.82719802856445, 45.70470370352268, 50.452419742941856, 52.97784022986889, 52.17497371137142, 51.599779576063156, 51.039423644542694, 50.262882113456726, 47.428815588355064, 44.41873110830784, 43.47372941672802, 43.90827789902687, 43.44568692147732, 44.37944121658802, 44.77493539452553, 43.86777587234974, 42.459871619939804, 43.213545978069305, 48.23120713233948, 48.037466928362846, 49.52543668448925, 54.19822454452515, 55.41530303657055, 55.70746935904026, 56.31355583667755, 59.03873160481453, 60.39704851806164, 63.131982162594795, 67.71162182092667, 57.52690672874451, 4.840990584343672, 3.1618583109229803, 5.909687038511038, 0.39281532168388367, 1.3817304256372154, 57.428256422281265, 72.21295148134232, 69.19070765376091, 65.43415322899818, 52.773206010460854, 37.35286965966225, 51.81808926165104, 66.37823536992073, 66.34866535663605, 7.294177422299981, 0.16659685032209381, 0.1192274565983098, 0.11711957165971398, 0.12815935973776504, 0.1497117438702844, 0.12548511964268982, 0.34637958684470505, 0.08375276054721326, 0.11427003628341481], [0.059758076022262685, 0.058465755719225854, 0.045178169311839156, 0.046039847293286584, 0.0018455866415933997, 0.043172930818400346, 0.02910248436819529, 0.03978548680606764, 0.03798643920163158, 0.035541222168831155, 0.02561571131082019, 2.172707263380289, 45.91132901608944, 52.64291100203991, 47.2402773052454, 31.30391724407673, 41.120238304138184, 34.10405158996582, 45.52387900650501, 51.74265570938587, 54.78425569832325, 17.915584556758404, 0.2878953219624236, 0.24675498891156167, 0.581199653679505, 5.548602864146233, 47.19424657523632, 62.721231803298, 53.29421505331993, 52.909398302435875, 50.136611089110374, 56.581559255719185, 50.77465385198593, 53.21318060159683, 41.31445728242397, 45.674529522657394, 54.87795867025852, 52.110259383916855, 48.48077014088631, 38.075704872608185, 35.659414529800415, 38.77800978720188, 45.47711871564388, 50.620233938097954, 44.48909193277359, 46.65571667253971, 50.81992842257023, 47.77808524668217, 48.5834938287735, 47.43811748921871, 49.82888840138912, 46.37276105582714, 45.163156762719154, 45.56590095162392, 47.21415750682354, 40.11816367506981, 40.66296324133873, 36.635209769010544, 34.690572917461395, 36.61635138094425, 34.23219971358776, 36.36056050658226, 35.454947501420975, 35.99522151052952, 37.00830414891243, 37.15920925140381, 36.247740760445595, 37.08153001964092, 38.47087226808071, 37.60381959378719, 38.49096938967705, 39.23467308282852, 38.479657396674156, 36.55488967895508, 38.608755469322205, 39.97913293540478, 39.80718456208706, 37.26615071296692, 38.17496694624424, 39.07219760119915, 37.77830243110657, 36.43850952386856, 38.55659946799278, 38.35668459534645, 37.62563802301884, 39.557283371686935, 46.86320073902607, 50.67889139056206, 51.31033010780811, 49.0719386190176, 53.04187819361687, 45.330606177449226, 41.49622052907944, 42.04943284392357, 44.87965017557144, 45.562230348587036, 44.74782384932041, 47.14876301586628, 44.788645058870316, 45.34685030579567, 42.79754810035229, 40.539287477731705, 37.32893854379654, 37.281479090452194, 37.72285580635071, 36.57884359359741, 38.391198143363, 36.04466065764427, 39.360704720020294, 38.04757118225098, 37.171596586704254, 37.87146583199501, 37.105062156915665, 36.160075664520264, 36.27645581960678, 37.687506303191185, 37.77562737464905, 36.239464804530144, 36.69229030609131, 35.32196223735809, 35.96015699207783, 36.14282839000225, 39.132416769862175, 43.837734684348106, 47.0120045542717, 48.92224185168743, 51.47121347486973, 49.941449761390686, 48.53243596851826, 50.732004940509796, 50.78855350613594, 48.88800568878651, 45.80703221261501, 41.19721457362175, 39.73308473825455, 38.96196931600571, 39.808442294597626, 38.75433325767517, 41.885593235492706, 43.37906889617443, 41.1321734637022, 39.331146106123924, 40.96271775662899, 43.82115237414837, 50.70591174066067, 50.475340113043785, 51.89824216067791, 53.08810271322727, 58.178446367383, 57.008929923176765, 63.4755103290081, 50.09767837822437, 1.064282397273928, 0.28185124159790576, 0.24650892242789268, 0.030215301412681583, 1.3391059753485024, 42.641726061701775, 66.48290455341339, 58.694443479180336, 41.83517374098301, 29.497446678578854, 34.55865919589996, 47.785570845007896, 54.431767612695694, 40.59790313243866, 2.395492158830166, 0.07152207035687752, 0.0369755153224105, 0.0372364284703508, 0.1338136789854616, 0.0868908577831462, 0.06590073215193115, 0.0716245015792083, 0.047905198371154256, 0.09189350457745604, 0.03383810086234007, 0.015830150950932875, 0.07190609467215836, 0.058030964792123996, 0.025867568401736207, 0.05475878744618967, 0.04570081568090245, 0.01625172979402123, 0.04111191621632315, 0.02507427747332258, 0.019208757839805912, 2.896944838576019, 51.94785229861736, 58.6247818171978, 54.54279385507107, 29.809225648641586, 43.59412595629692, 45.46692006289959, 49.99918006360531, 55.13857148587704, 58.380272537469864, 19.456779956817627, 0.2960757486289367, 0.09962732903659344, 0.9799817239399999, 7.3829644080251455, 48.37043546140194, 64.6804940700531, 55.910104885697365, 55.64329840242863, 52.26448550820351, 57.825832888484, 52.620731592178345, 55.73594883084297, 42.93278284370899, 47.38153852522373, 54.978182092309, 55.367399007081985, 49.676835760474205, 41.190865114331245, 37.7327124774456, 41.174032017588615, 48.059684336185455, 51.46668791770935, 45.768506079912186, 44.88126128911972, 50.417355224490166, 50.10476879775524, 50.76105818152428, 49.936570823192596, 51.861760318279266, 49.322079196572304, 47.861733958125114, 47.543406039476395, 50.34001037478447, 43.14342454075813, 42.14448094367981, 37.42456801235676, 36.4418875426054, 37.539181262254715, 36.63247391581535, 37.18626379966736, 36.63281969726086, 38.196382597088814, 38.55761781334877, 38.02823022007942, 37.952770069241524, 38.59758406877518, 40.09232886135578, 39.10677954554558, 39.95049387216568, 41.06850787997246, 39.23511005938053, 37.79230087995529, 40.2105937153101, 40.5003547668457, 40.28815135359764, 38.569549173116684, 39.437642991542816, 40.86763545870781, 40.477502793073654, 39.220062866806984, 39.37930092215538, 39.578068256378174, 38.86124812066555, 42.760895267128944, 49.00405526161194, 53.579917922616005, 53.511118814349174, 51.52803562581539, 54.12641599774361, 47.86281310021877, 43.84640581905842, 44.962728917598724, 48.43146778643131, 47.94154107570648, 47.70210072398186, 49.494149163365364, 46.044386476278305, 46.78389899432659, 44.31398592889309, 43.412833884358406, 37.82982386648655, 39.95018228888512, 38.98594222962856, 38.14178712666035, 39.762092381715775, 37.73767501115799, 41.23906932771206, 38.8602601736784, 38.551534339785576, 39.57269914448261, 39.606855511665344, 38.53310912847519, 39.05425876379013, 39.77604903280735, 38.25107306241989, 38.25581140816212, 38.25947821140289, 37.673450857400894, 36.88604570925236, 39.18758600950241, 41.12580120563507, 45.06204418838024, 49.188907742500305, 50.207013711333275, 54.141919165849686, 52.556906417012215, 52.30990067124367, 53.63632209599018, 51.63410313427448, 50.542775094509125, 46.86122104525566, 43.473862409591675, 41.672816053032875, 40.72438694536686, 42.40511655807495, 41.38400495052338, 44.11432184278965, 46.57608434557915, 43.53376239538193, 41.90191715955734, 43.76607432961464, 46.494206339120865, 52.89522126317024, 53.293147310614586, 54.394928589463234, 53.970859944820404, 58.768566101789474, 60.26866860687733, 66.0837359726429, 51.98238484561443, 1.3440124620683491, 1.0268943035043776, 1.2393296230584383, 0.11830435847514309, 1.2385734636336565, 48.28220419585705, 70.10538697242737, 64.14357528090477, 48.190104737877846, 36.05319879949093, 41.4705491065979, 55.407505854964256, 61.976775750517845, 49.73998077213764, 3.484556470066309, 0.12742947234073654, 0.015221005414787214, 0.013549725026678061, 0.0064867821220104815, 0.05345348698028829, 0.04611786927853245, 0.05981255337246694, 0.03694371058372781, 0.04275268227502238, 0.11531938114785589, 0.18817044503521174, 0.19167446560459211, 0.12225452112033963, 0.1821007754188031, 0.11305131105473265, 0.14520987606374547, 0.12383036781102419, 0.1049055352632422, 0.1377407237305306, 0.09134078267379664, 3.1862615514546633, 59.63710069656372, 65.80371379852295, 61.282142624258995, 40.905147045850754, 51.94112665951252, 45.65766602754593, 57.3689454048872, 59.90028977394104, 64.41460713744164, 22.222163267433643, 0.31316105683799833, 0.5879837146494538, 1.673883330076933, 8.114432282745838, 51.009352058172226, 66.93934366106987, 58.760419338941574, 55.95731355249882, 56.56377241015434, 62.16152183711529, 55.46700306236744, 55.17019338905811, 42.271656319499016, 48.66153784096241, 57.49530762434006, 57.34050013124943, 53.19602832198143, 42.75860778987408, 40.07161617279053, 42.49896392226219, 50.10766424238682, 52.98169702291489, 46.9653582572937, 46.07358790934086, 52.112197279930115, 52.515120059251785, 53.68997901678085, 51.85507647693157, 54.86649848520756, 51.50764212012291, 48.89593966305256, 50.7449584454298, 52.75831840932369, 45.03297574818134, 45.07611483335495, 40.30194841325283, 39.938106536865234, 40.805778577923775, 37.931992784142494, 39.65945988893509, 39.32181380689144, 38.92641082406044, 41.794120743870735, 41.450204998254776, 40.42754307389259, 41.24582156538963, 42.35564321279526, 40.683539137244225, 41.13830253481865, 41.96141056716442, 41.858477890491486, 39.66090381145477, 44.35766078531742, 43.6550784856081, 44.60908569395542, 39.316038116812706, 40.91978766024113, 43.35073001682758, 40.76442539691925, 40.745616406202316, 43.12835834920406, 43.38879257440567, 39.63865600526333, 44.65394988656044, 50.342571437358856, 56.001919358968735, 57.831676974892616, 53.484071865677834, 55.01148730516434, 50.4561473429203, 46.26456946134567, 46.755818501114845, 50.25843635201454, 50.27984440326691, 49.81241628527641, 51.71977333724499, 48.06725732982159, 48.80681924521923, 47.35875494778156, 45.98116546869278, 40.137721225619316, 41.67961768805981, 41.941887214779854, 39.82138440012932, 42.16012850403786, 39.22276832163334, 43.34413357079029, 40.75088292360306, 40.293205082416534, 40.68581901490688, 40.27589701116085, 39.76703591644764, 41.73913389444351, 41.457192823290825, 40.64819723367691, 40.239164382219315, 40.51383264362812, 39.66977633535862, 39.115549474954605, 42.990349754691124, 44.34940002858639, 48.97888541221619, 52.03839763998985, 53.57773303985596, 56.253978833556175, 55.661518424749374, 53.07600416243076, 55.0442985445261, 55.17123453319073, 52.72058643400669, 48.46922256052494, 46.15647666156292, 43.22733163833618, 42.74757318198681, 45.075579062104225, 41.831028163433075, 46.27227924764156, 47.977483347058296, 47.24422909319401, 43.71099628508091, 46.051264107227325, 47.385368719697, 57.0222482085228, 56.86888463795185, 57.17997394502163, 56.654310151934624, 61.26866474747658, 63.29969376325607, 68.3781972527504, 54.92366261780262, 1.426599605474621, 1.242347729858011, 1.9185546948574483, 0.3542814706452191, 1.3980959099717438, 50.96258036792278, 76.0925281047821, 69.42581623792648, 54.56196382641792, 42.13895224034786, 47.71556720137596, 61.594117283821106, 71.32572948932648, 63.01849365234375, 6.480546556413174, 0.23900134168798104, 0.07768812269205227, 0.12780390068655834, 0.2622256212634966, 0.19312943128170446, 0.1675794686889276, 0.13976329879369587, 0.10307094620657153, 0.1864332999684848], [0.030367870276677422, 0.0552677486120956, 0.08483518293360248, 0.03387078504601959, 0.0304606739882729, 0.04636303034203593, 0.012867652349086711, 0.016596429559285752, 0.07496122721931897, 0.0075450350777828135, 0.1845995124313049, 0.25135814503300935, 35.33853694796562, 60.77572479844093, 44.04911734163761, 35.6876128166914, 36.800265312194824, 27.447576373815536, 44.02702912688255, 52.08008900284767, 55.85082046687603, 25.00807497650385, 0.10561461283941753, 0.03372169870999642, 0.6855026911944151, 1.4462570194154978, 25.78702747821808, 55.95726415514946, 54.990432634949684, 55.88905781507492, 51.078158766031265, 53.35806682705879, 50.44436417520046, 53.08622561395168, 48.38006414473057, 52.39539988338947, 51.43537379801273, 47.13951051235199, 38.180066272616386, 37.19580888748169, 39.16281133890152, 48.217733055353165, 51.017137840390205, 49.824894815683365, 46.587187349796295, 46.21507331728935, 47.94440992176533, 46.523928344249725, 46.823914647102356, 46.47438280284405, 48.719655722379684, 46.77557364106178, 42.692688927054405, 42.587058395147324, 42.28830322623253, 39.86213721334934, 37.544428780674934, 36.279708445072174, 36.142402812838554, 36.717456355690956, 36.2236462533474, 36.250947788357735, 38.43766205012798, 37.09522068500519, 36.29346750676632, 36.292221173644066, 37.24514923989773, 38.204350769519806, 38.52185793220997, 37.95250788331032, 37.44374558329582, 37.57093235850334, 38.24072241783142, 38.33993509411812, 36.68054513633251, 38.97006668150425, 37.81713254749775, 37.303825691342354, 37.548023387789726, 38.8061510771513, 38.903365060687065, 38.045880272984505, 37.82575808465481, 36.5012289583683, 37.35769160091877, 42.29310616850853, 48.32035414874554, 53.18017177283764, 50.81996262073517, 49.382157772779465, 53.9461612701416, 47.56372354924679, 40.664030984044075, 41.88364014029503, 43.93234960734844, 42.931635305285454, 45.07647201418877, 43.91402319073677, 42.40287467837334, 41.42676405608654, 39.49891850352287, 39.762289971113205, 40.03974348306656, 38.65833140909672, 35.818166211247444, 37.00554929673672, 38.86521130800247, 37.18426130712032, 36.90514728426933, 38.62572155892849, 37.73672506213188, 36.54788285493851, 38.04175369441509, 37.3505973815918, 37.349233254790306, 35.89139208197594, 37.39154778420925, 35.974440425634384, 38.10577265918255, 37.120496928691864, 37.20093101263046, 34.81525182723999, 38.02669510245323, 39.79133941233158, 45.54052211344242, 47.84281097352505, 49.959156811237335, 51.875435784459114, 45.509276390075684, 46.79982773959637, 47.98406079411507, 47.31183886528015, 49.089185893535614, 48.45744699239731, 44.58850219845772, 40.14814406633377, 40.85809797048569, 45.707526952028275, 52.022921070456505, 50.40352776646614, 52.98098646104336, 46.54763527214527, 44.30855982005596, 41.30399264395237, 48.62952075898647, 50.60151234269142, 55.51168866455555, 57.25544549524784, 57.12511628866196, 56.49691879749298, 65.24856358766556, 35.40706627070904, 0.2352682498167269, 0.20900846750009805, 0.6559167662635446, 0.03345707482367288, 0.8983828837517649, 46.06429360806942, 62.0605194568634, 59.55090992152691, 52.87043139338493, 21.180882342159748, 20.940250754356384, 37.96359568834305, 52.821459621191025, 37.88209766149521, 1.5235198172740638, 0.05644678007229231, 0.05926582060055807, 0.04627556452760473, 0.0478935243882006, 0.030979201437730808, 0.023483847580791917, 0.03698103319038637, 0.007902854158601258, 0.06742069512256421, 0.021489075224963017, 0.06527387711685151, 0.02781724229862448, 0.042754786263685673, 0.0457220299722394, 0.03973061240685638, 0.0671188413980417, 0.03589752726838924, 0.03115782339591533, 0.10250975639792159, 0.17017588717862964, 0.38503918738570064, 42.68448896706104, 64.53835129737854, 48.31149682402611, 40.54411321878433, 42.49750480055809, 32.56592832505703, 50.36810606718063, 56.84523470699787, 61.72400191426277, 27.192864641547203, 0.09344017744297162, 0.10591311947791837, 1.145672129932791, 0.8569183805957437, 26.169235669076443, 58.28939661383629, 56.150278598070145, 57.55340650677681, 53.518186435103416, 54.17438082396984, 51.29278264939785, 52.64697678387165, 47.748610228300095, 53.58735032379627, 53.36109906435013, 49.04778711497784, 40.73248811066151, 38.04773457348347, 40.03402478992939, 50.53330220282078, 51.860772371292114, 52.31013625860214, 47.538937479257584, 48.607261553406715, 48.963963612914085, 48.019611686468124, 49.029958471655846, 49.345850721001625, 50.84982141852379, 49.45091128349304, 45.573386549949646, 45.47515042126179, 45.24785041809082, 42.51902684569359, 40.169783905148506, 37.61724427342415, 38.29715318977833, 38.75855103135109, 38.14632408320904, 38.383545354008675, 39.053054228425026, 38.45454454421997, 37.283470183610916, 37.95449137687683, 38.31575319170952, 40.16826018691063, 39.87827494740486, 39.734695851802826, 39.99179385602474, 39.39633160829544, 38.03107246756554, 39.44745786488056, 39.53107237815857, 40.766496285796165, 39.47014644742012, 38.75241816043854, 38.432532325387, 40.60440078377724, 39.98852603137493, 40.47684922814369, 39.41200576722622, 39.24989506602287, 38.92138749361038, 44.08386267721653, 50.966912135481834, 53.99359032511711, 52.65768080949783, 52.22329571843147, 55.28795287013054, 50.447255820035934, 41.88020132482052, 45.030087903141975, 45.230420753359795, 44.02512922883034, 45.54071590304375, 45.60768350958824, 43.946047872304916, 43.157833367586136, 41.970400884747505, 41.202287301421165, 40.31997084617615, 41.98127590119839, 37.211737632751465, 38.477221727371216, 40.992614552378654, 39.45839747786522, 38.90396922826767, 38.83008599281311, 39.8547238111496, 38.77292186021805, 39.3935539573431, 38.21827322244644, 38.20402018725872, 38.079975843429565, 38.581605926156044, 37.109359726309776, 39.2820755392313, 39.13446485996246, 38.066957741975784, 36.45499303936958, 40.43351635336876, 42.79303394258022, 48.151601403951645, 49.45278078317642, 52.829572185873985, 53.726400062441826, 48.352397829294205, 50.34085012972355, 49.84077796339989, 49.76260095834732, 51.626138761639595, 48.837221413850784, 45.531368404626846, 41.64417318999767, 42.69224055111408, 46.493932753801346, 54.017536640167236, 54.61079120635986, 53.75634245574474, 48.22627119719982, 45.19966520369053, 43.690127804875374, 50.297327265143394, 53.38892877101898, 58.01994167268276, 58.6593409627676, 59.76389229297638, 59.151448756456375, 69.74043175578117, 38.03814768791199, 0.4139578324975446, 0.8046916080638766, 0.3461116418475285, 0.07942375377751887, 0.8034725266043097, 50.36553740501404, 65.81904977560043, 66.35635614395142, 54.015511348843575, 23.25900413095951, 24.518760032951832, 45.33424258232117, 60.20855963230133, 47.261077389121056, 2.854550275951624, 0.017530745244584978, 0.09123098192503676, 0.05543906598177273, 0.02166942082112655, 0.011304772833682364, 0.08193230940378271, 0.011826360714621842, 0.05669531790772453, 0.021000415508751757, 0.10913033707765862, 0.1990703828050755, 0.11593089599045925, 0.25057615886908025, 0.1539758127182722, 0.1088276224618312, 0.1646041392814368, 0.19013137731235474, 0.13474615785526112, 0.12131253533880226, 0.3067627939162776, 0.6759941170457751, 46.47201932966709, 74.6800146996975, 55.088892951607704, 47.62697495520115, 46.98365047574043, 38.038162887096405, 55.701720267534256, 59.68693882226944, 66.82534217834473, 30.87426669895649, 0.2836256573209539, 0.5249594652559608, 3.3040937036275864, 2.233359608799219, 30.18439471721649, 57.3671481013298, 56.717553958296776, 60.247081965208054, 54.97434809803963, 56.048250272870064, 52.339318692684174, 53.306951969861984, 50.99301293492317, 57.14488662779331, 57.33785927295685, 52.221582010388374, 42.079021856188774, 42.084630355238914, 43.04412066936493, 54.23121057450771, 55.02694487571716, 52.61043034493923, 49.14304040372372, 50.79810619354248, 51.52873858809471, 50.8253089338541, 51.57204866409302, 51.174278408288956, 56.25785082578659, 52.8698044270277, 48.544773906469345, 46.41507938504219, 47.75093950331211, 44.9720574170351, 42.47648812830448, 40.36238417029381, 40.13809360563755, 40.26542857289314, 38.53928379714489, 39.428424686193466, 42.4930514395237, 40.96746750175953, 40.58504842221737, 40.00964529812336, 39.31273989379406, 41.662294417619705, 41.49342767894268, 40.629388242959976, 40.70620112121105, 40.969128012657166, 41.319397017359734, 41.96453399956226, 41.20902054011822, 42.29790911078453, 42.35513024032116, 41.42306685447693, 40.151613280177116, 43.97629424929619, 44.06955644488335, 42.38107904791832, 42.11907550692558, 41.37674354016781, 41.607619151473045, 47.0258130133152, 52.86532446742058, 56.82713247835636, 54.267373234033585, 54.71984155476093, 59.59176152944565, 52.052213698625565, 45.976985692977905, 46.35237514972687, 49.00732308626175, 47.132328897714615, 49.38852623105049, 49.64310497045517, 46.59503772854805, 47.06109032034874, 42.523362413048744, 43.129053711891174, 43.672850131988525, 44.125877022743225, 37.695387080311775, 39.93589885532856, 43.72662104666233, 40.975986644625664, 40.82480035722256, 41.21511921286583, 42.37391263246536, 40.118562653660774, 42.697191685438156, 40.65780311822891, 40.853105038404465, 39.68863472342491, 40.626599192619324, 38.83974127471447, 40.39327651262283, 41.478091701865196, 40.56148588657379, 38.12267415225506, 42.43350863456726, 43.674256056547165, 50.979390665888786, 52.836225628852844, 54.28268641233444, 56.018725857138634, 50.15723258256912, 51.725936606526375, 52.95523904263973, 51.84499941766262, 54.235010370612144, 51.760769337415695, 48.87911796569824, 43.476640060544014, 45.47781027853489, 48.7969321757555, 57.197377011179924, 57.02177703380585, 57.569996416568756, 50.45769385993481, 48.57625521719456, 45.35478428006172, 52.214928567409515, 54.44877170026302, 61.52947135269642, 62.272088304162025, 61.540760546922684, 62.772612646222115, 70.76291128993034, 40.92847399413586, 0.8256411307957023, 1.8346490222029388, 3.7836968433111906, 0.23551528109237552, 0.9815763321239501, 55.81931255757809, 72.15626612305641, 73.60343366861343, 65.41189402341843, 32.827031314373016, 32.14664362370968, 51.48761719465256, 68.63706976175308, 57.458423003554344, 4.924015654250979, 0.2528990217251703, 0.14347886113682762, 0.1411130724591203, 0.09896149640553631, 0.1789251106674783, 0.15053386538056657, 0.10860041395062581, 0.18166013265727088, 0.3751734324032441], [0.09215344180120155, 0.022588036372326314, 0.04140811477554962, 0.039119706125347875, 0.11643869569525123, 0.07977922025020234, 0.0506689563189866, 0.06097929486713838, 0.04750011932628695, 0.06252807914279401, 0.15078129741596058, 0.029918175168859307, 18.467525839805603, 56.313593834638596, 42.009709775447845, 35.58129072189331, 43.13795283436775, 34.79042015969753, 41.78220838308334, 51.30125239491463, 55.4863478243351, 31.864601857960224, 0.17352099908748642, 0.08279138986836188, 0.5563894787337631, 0.15858187805861235, 6.953566549345851, 41.24425604939461, 48.41318316757679, 49.95714671909809, 49.160454869270325, 54.636800810694695, 52.94491499662399, 54.94866147637367, 53.05321678519249, 51.19426913559437, 43.22600170969963, 38.13204064965248, 35.72352088987827, 38.480341359972954, 44.28090110421181, 53.23780708014965, 48.30724485218525, 50.168073400855064, 48.73314119875431, 46.29353150725365, 44.93273712694645, 46.37445196509361, 43.44540573656559, 44.89831857383251, 43.94891671836376, 42.55978345870972, 39.768833220005035, 41.277576461434364, 39.40485455095768, 39.294812455773354, 37.34941564500332, 36.23681254684925, 36.265671998262405, 36.30817651748657, 35.8949638903141, 36.293988078832626, 36.636813282966614, 36.024460941553116, 36.584197506308556, 35.907579213380814, 36.906974986195564, 39.02629226446152, 39.092781096696854, 37.33415946364403, 39.58243042230606, 39.9271859228611, 37.5874462723732, 37.77763366699219, 39.06413823366165, 37.2532694041729, 37.819169238209724, 37.08824425935745, 36.672512367367744, 37.04659469425678, 37.02091187238693, 37.810277715325356, 36.46834172308445, 37.40546263754368, 35.047335773706436, 45.49605309963226, 47.24594660103321, 53.859503120183945, 49.58213344216347, 48.858618065714836, 51.99034541845322, 46.381785571575165, 41.206326484680176, 41.090067923069, 39.373817816376686, 41.28587141633034, 42.550751343369484, 41.63921445608139, 40.72340279817581, 40.557648092508316, 38.54470610618591, 36.76625333726406, 37.999317571520805, 36.9592297822237, 37.522621750831604, 38.188520818948746, 39.72643129527569, 38.02751585841179, 37.784860879182816, 37.135255336761475, 37.50525288283825, 37.09078632295132, 36.25941373407841, 37.052488178014755, 36.343586817383766, 36.332396417856216, 36.076331958174706, 36.71163886785507, 36.08263202011585, 36.42226539552212, 36.24704159796238, 35.5429507791996, 36.61492645740509, 38.43195855617523, 42.179412469267845, 47.1739936619997, 48.31250376999378, 49.55760195851326, 45.728289037942886, 47.86983512341976, 45.95286078751087, 45.8516950160265, 47.339341789484024, 46.06848858296871, 46.30523107945919, 41.52567654848099, 42.563735246658325, 46.031394973397255, 52.70236261188984, 54.038629308342934, 55.16875706613064, 54.00266423821449, 53.210798129439354, 49.252371937036514, 49.837612733244896, 46.972178891301155, 54.568826258182526, 56.0037774592638, 60.81197865307331, 55.020052045583725, 66.22929096221924, 27.397384867072105, 0.11704675955115817, 0.7728439138736576, 0.5947192094754428, 0.17779729852918535, 1.0225669294595718, 44.38686601817608, 63.66350144147873, 56.963849142193794, 41.72967620193958, 34.89331863820553, 32.946918681263924, 44.41523149609566, 51.90914757549763, 30.97722787410021, 0.3074073343304917, 0.05171926968614571, 0.05181556334719062, 0.022087066281528678, 0.020273825102776755, 0.09261944374884479, 0.049472751561552286, 0.020370408201415557, 0.04190841507806908, 0.05577315860136878, 0.03381742462806869, 0.02310317591764033, 0.007079514598444803, 0.021814215688209515, 0.10687521746149287, 0.012971686610399047, 0.07307034626137465, 0.1276832868461497, 0.036835401551797986, 0.05877071904251352, 0.21731382730649784, 0.09392498541274108, 23.016936220228672, 64.11445364356041, 46.76287092268467, 40.49699194729328, 43.13136398792267, 33.25986988842487, 52.04047992825508, 55.5589809268713, 61.605949848890305, 34.24888461828232, 0.15156794426729903, 0.025899042884702794, 1.4095203531906009, 0.9403405291959643, 10.537830144166946, 43.42228777706623, 49.96824972331524, 50.912305265665054, 50.315060913562775, 55.455147698521614, 55.82457147538662, 55.87864637374878, 54.69131648540497, 53.83945919573307, 46.3053222745657, 39.74356837570667, 37.21915863454342, 39.931924268603325, 45.932676270604134, 52.394484132528305, 51.297160014510155, 50.50464794039726, 49.568290784955025, 49.311960339546204, 47.84247659146786, 49.2325484007597, 47.26158656179905, 48.05169716477394, 46.187566593289375, 44.829701855778694, 40.62072090804577, 41.723615527153015, 41.584877371788025, 39.76514361798763, 38.45378078520298, 38.96722823381424, 38.7237448990345, 38.45415696501732, 38.10878969728947, 37.09431253373623, 38.27206693589687, 37.20743626356125, 36.94398880004883, 36.25945173203945, 38.12749229371548, 39.341831132769585, 38.6376491189003, 39.135821387171745, 40.53277462720871, 39.73493903875351, 39.43766199052334, 39.220116063952446, 39.53442759811878, 39.370454996824265, 39.643496945500374, 39.17623981833458, 37.932387962937355, 39.906610026955605, 39.19996574521065, 38.71202252805233, 39.035624563694, 39.51608218252659, 38.43065902590752, 47.77661852538586, 48.89956846833229, 55.15984274446964, 50.60210511088371, 49.99534226953983, 53.87459971010685, 48.428811728954315, 42.21358023583889, 42.820210084319115, 41.527568846940994, 43.133890852332115, 44.170004054903984, 43.14026691019535, 41.49611033499241, 42.31083981692791, 41.33303448557854, 39.28532436490059, 39.93718698620796, 38.64919289946556, 39.30550888180733, 39.313515052199364, 38.63418750464916, 39.057477191090584, 38.59853021800518, 39.97257448732853, 39.956235364079475, 37.14936017990112, 38.36232729256153, 39.85708728432655, 37.578360959887505, 38.16151566803455, 36.66212372481823, 38.97116482257843, 38.13877008855343, 38.740486800670624, 38.302716091275215, 39.57754388451576, 40.488822385668755, 39.635137394070625, 43.22667047381401, 50.36885462701321, 50.64990274608135, 51.83874115347862, 48.45519371330738, 49.126283302903175, 49.49262924492359, 50.094619542360306, 49.4247192889452, 48.44655677676201, 46.89216658473015, 44.313621148467064, 44.97796230018139, 48.33409421145916, 53.88109356164932, 55.73980562388897, 57.518140599131584, 55.70259042084217, 55.90547293424606, 51.920679956674576, 50.74446827173233, 50.38949131965637, 57.3709174990654, 57.10832118988037, 64.37799230217934, 58.23458455502987, 67.75596544146538, 29.005908854305744, 0.24242106912424788, 1.6478584078140557, 1.1547330999746919, 0.12079323234502226, 0.9321837325114757, 47.03715920448303, 69.73426848649979, 61.39193393290043, 47.12633661925793, 31.865827292203903, 33.14637377858162, 48.7165816873312, 59.54636536538601, 38.768476098775864, 1.0151952062733471, 0.05583830061368644, 0.028894996576127596, 0.10819751681992784, 0.060546047607203946, 0.0676492320781108, 0.07237522848299704, 0.025858820335997734, 0.024179427346098237, 0.03793090058024973, 0.22094004991231486, 0.14156879566144198, 0.1338928661425598, 0.15110356762306765, 0.20141392189543694, 0.1351245047408156, 0.15941691293846816, 0.302575656096451, 0.12755914038280025, 0.12867769051808864, 0.29515518865082413, 0.17547554889461026, 26.187888868153095, 72.9967050254345, 53.63884896039963, 47.7759725600481, 52.487738728523254, 44.382146671414375, 57.025497034192085, 59.69657130539417, 67.69018337130547, 38.87369625270367, 0.37841762707103044, 0.20077306253369898, 4.181721210479736, 1.5285132243297994, 9.751305598765612, 47.051009461283684, 49.744639322161674, 51.75110265612602, 48.97929199039936, 57.69627884030342, 57.42800183594227, 60.81712357699871, 56.354943215847015, 56.522183641791344, 47.63196788728237, 42.48524285852909, 39.33383256196976, 43.28774459660053, 48.090348690748215, 54.76231947541237, 51.36824280023575, 53.30606661736965, 53.57945054769516, 53.2245571911335, 49.49212767183781, 51.50928743183613, 48.23303863406181, 50.42946137487888, 47.73752622306347, 49.292152002453804, 43.11274118721485, 45.03980778157711, 44.68081824481487, 43.9630975574255, 41.20143234729767, 41.221160888671875, 40.81879287958145, 41.267442405223846, 39.273385405540466, 40.16402341425419, 40.57261548936367, 39.51313354074955, 39.07752871513367, 38.90549294650555, 40.19776180386543, 42.19293214380741, 42.472084164619446, 40.63839755952358, 42.08862014114857, 43.64792726933956, 41.91141664981842, 41.37345291674137, 43.00528295338154, 41.66565343737602, 42.87453196942806, 42.497664391994476, 40.34207426011562, 42.29726314544678, 40.51075100898743, 41.24575316905975, 41.467543467879295, 42.48997740447521, 40.062371268868446, 51.01056419312954, 49.84171271324158, 57.310629934072495, 51.62509001791477, 51.21468164026737, 56.45403049886227, 49.94498357176781, 46.27444513142109, 46.66348725557327, 43.14432889223099, 44.49480302631855, 47.176474928855896, 44.4897036999464, 44.18250538408756, 45.039940774440765, 42.47653752565384, 41.08605533838272, 42.53142938017845, 39.9989602714777, 41.01191371679306, 41.72018051147461, 42.23300479352474, 41.10466293990612, 39.96066212654114, 40.596390813589096, 41.49358347058296, 41.6274730861187, 40.04528358578682, 41.65321670472622, 40.3343340754509, 40.397950261831284, 38.64565148949623, 42.690348252654076, 39.76206198334694, 40.40922425687313, 39.46545749902725, 40.05081228911877, 41.53567761182785, 40.644788816571236, 45.50260774791241, 52.46540352702141, 52.889829352498055, 53.29083703458309, 50.339645594358444, 49.38965857028961, 49.86613780260086, 50.7510457187891, 52.777932956814766, 49.45916824042797, 49.797376692295074, 46.69501796364784, 47.239536345005035, 51.1278411000967, 56.59025318920612, 57.461314648389816, 60.23426905274391, 57.68975459039211, 57.329872101545334, 54.15586441755295, 54.86991070210934, 52.8608863055706, 58.99452097713947, 59.99373055994511, 66.4340315759182, 60.78284181654453, 69.40050959587097, 31.585058458149433, 0.36507036827970296, 2.66592507250607, 2.8174763778224587, 0.32318714540451765, 1.012076404877007, 51.702225878834724, 73.94153192639351, 67.17202797532082, 57.130542397499084, 47.478904500603676, 45.86548067629337, 59.764694049954414, 67.89057701826096, 49.06137138605118, 1.8156138248741627, 0.1508702215505764, 0.08834665466565639, 0.2669452648842707, 0.16950722696492448, 0.18111299170413986, 0.15275330253643915, 0.21064364147605374, 0.08238047754275613, 0.13116309855831787], [0.11764379509259015, 0.05383264651754871, 0.06295072482316755, 0.018885893914557528, 0.02895046283811098, 0.02963105678645661, 0.09666859405115247, 0.03246548760216683, 0.06519771792227402, 0.030150135280564427, 0.2638489654054865, 0.01582511733431602, 8.86030850932002, 52.352739572525024, 43.61709952354431, 34.85357657074928, 38.57423812150955, 27.651237845420837, 34.70124654471874, 54.37370292842388, 53.113736137747765, 41.0653692483902, 0.2684022788889706, 0.044389266331563704, 0.39502683270256966, 0.6211987417191267, 2.9296969436109066, 23.544251024723053, 48.63509885966778, 52.55979426205158, 54.73213769495487, 53.320080265402794, 51.289982199668884, 50.90876005589962, 45.08604370057583, 38.29360418021679, 37.28730417788029, 37.44021937251091, 40.75330339372158, 49.5028430968523, 51.8985765427351, 53.631944730877876, 51.898633539676666, 49.44217175245285, 46.11889287829399, 44.96903657913208, 43.69474455714226, 43.5839919000864, 40.08199721574783, 38.497603833675385, 36.68992303311825, 36.57953895628452, 37.77641773223877, 37.819932997226715, 36.09234809875488, 36.5184610337019, 38.46725106239319, 37.39290051162243, 34.941534250974655, 37.438045889139175, 35.82863084971905, 37.64089420437813, 35.41079767048359, 36.54664792120457, 35.00929981470108, 36.63942374289036, 37.2636504471302, 36.79187536239624, 37.12778873741627, 38.9344397932291, 38.179636895656586, 38.91017809510231, 37.82665103673935, 38.83369579911232, 39.06414583325386, 37.75741495192051, 38.26589226722717, 38.12692232429981, 36.850088238716125, 37.743792682886124, 38.21458362042904, 36.04589179158211, 36.384145841002464, 37.92881615459919, 37.21206061542034, 43.71715195477009, 48.22992280125618, 50.52495025098324, 50.620518922805786, 47.856144458055496, 52.25670352578163, 50.78115150332451, 42.15203873813152, 40.39748668670654, 38.52655827999115, 38.96068878471851, 40.89974753558636, 40.715499222278595, 41.806143298745155, 39.549410194158554, 38.166474401950836, 37.30366989970207, 38.66922162473202, 36.09665706753731, 36.21624045073986, 39.13239777088165, 39.73276175558567, 39.202279821038246, 38.78287352621555, 39.33965764939785, 36.65780335664749, 36.39527544379234, 35.90391241014004, 36.211665496230125, 36.59759558737278, 36.616305783391, 36.1261510848999, 36.69490456581116, 38.64436715841293, 36.30209684371948, 36.12324044108391, 36.80810049176216, 36.4585230499506, 36.90156787633896, 41.23560771346092, 48.0350274592638, 49.42394033074379, 48.750304877758026, 49.08639304339886, 50.99679373204708, 50.059091448783875, 50.79421900212765, 48.9451964199543, 45.172709450125694, 46.02705180644989, 42.39571586251259, 41.43808364868164, 46.479318737983704, 50.39432846009731, 54.94557224214077, 57.09846071898937, 54.89118956029415, 54.18321534991264, 55.07710978388786, 57.28814274072647, 50.1362919062376, 56.77874207496643, 57.214080914855, 60.62576204538345, 57.022221609950066, 66.68392136693001, 15.45462666079402, 0.1145680679474026, 0.16003424621885642, 1.0537453251890838, 0.01545486542454455, 0.93969497946091, 42.64613762497902, 63.93391773104668, 55.112398490309715, 51.06160685420036, 33.0940467864275, 29.38442174345255, 44.60339739918709, 55.1516579836607, 23.004129007458687, 0.5325172597076744, 0.04973549039277714, 0.05324690275301691, 0.06360120984027162, 0.08358213337487541, 0.006558729164680699, 0.037519401957979426, 0.018771417635434773, 0.07451276964275166, 0.0542818165558856, 0.05857518168340903, 0.04826696196687408, 0.0465208146488294, 0.015360301895270823, 0.06252873223274946, 0.08510710584232584, 0.06556059102877043, 0.06265176547458395, 0.0842333234322723, 0.01971329766092822, 0.26040142227429897, 0.04652966475987341, 12.14791014790535, 60.31539849936962, 50.1009614020586, 39.67836767435074, 43.72330762445927, 32.1175903826952, 42.26386293768883, 57.56048172712326, 58.01333762705326, 43.450375869870186, 0.3067019971786067, 0.18592832784634084, 1.1180859664455056, 1.3953998358920217, 3.781240750104189, 24.473863542079926, 49.49437715113163, 51.91695995628834, 56.953996270895004, 54.25408914685249, 54.31584723293781, 51.401794999837875, 48.206918835639954, 41.1722195148468, 40.47019578516483, 37.52653934061527, 42.52888731658459, 50.8274482190609, 53.564946725964546, 54.00922268629074, 53.06564971804619, 50.50300642848015, 49.03397485613823, 47.800405248999596, 47.040480226278305, 45.545412451028824, 41.69370733201504, 42.4753025919199, 38.91192600131035, 39.176965579390526, 39.76163260638714, 39.07043069601059, 37.4718526750803, 39.094278216362, 40.453510880470276, 39.06560115516186, 37.00667403638363, 38.02017085254192, 37.37407252192497, 39.83535245060921, 37.30381429195404, 37.76670925319195, 36.783937588334084, 38.04031357169151, 40.60439318418503, 39.92983818054199, 39.691758155822754, 40.22700123488903, 40.84213122725487, 40.487408861517906, 40.0641305744648, 42.703271359205246, 40.90933822095394, 39.61602441966534, 40.49998998641968, 38.99211309850216, 38.19644719362259, 39.31391403079033, 38.360024616122246, 38.92225004732609, 38.41792970895767, 38.663799315690994, 39.95913840830326, 47.37792111933231, 50.750680938363075, 53.44169653952122, 51.33436381816864, 51.08111120760441, 56.081198304891586, 50.46332895755768, 44.279381185770035, 41.57651022076607, 40.93244858086109, 42.62723743915558, 42.1906940639019, 42.531748563051224, 42.79555320739746, 41.07338681817055, 40.83766266703606, 38.79958502948284, 39.667336866259575, 36.85671128332615, 38.006768971681595, 40.54069720208645, 40.81148587167263, 41.26897372305393, 40.081913620233536, 42.420213147997856, 39.28470499813557, 38.07264603674412, 39.28038462996483, 36.37393578886986, 37.010975405573845, 38.53726990520954, 39.09626550972462, 38.19124147295952, 40.00124394893646, 39.87031817436218, 38.87116938829422, 39.096710085868835, 38.43659810721874, 39.485482424497604, 43.0265162140131, 52.233209386467934, 51.14346586167812, 51.22185945510864, 51.100471168756485, 51.920714154839516, 52.22684472799301, 52.72097401320934, 50.16945652663708, 47.47862331569195, 49.064054042100906, 44.96501259505749, 43.942726850509644, 47.54373662173748, 52.65172652900219, 55.07179766893387, 59.3330942094326, 56.7810295522213, 57.45426222681999, 57.245433032512665, 58.18687431514263, 53.923791870474815, 59.42393973469734, 58.24889838695526, 63.06677006185055, 58.55648048222065, 68.4022119641304, 18.165098167955875, 0.30186752846930176, 1.6824253904633224, 1.1337495571933687, 0.12523411045549437, 1.0118423611856997, 46.122335493564606, 70.53756818175316, 59.94752883911133, 54.69215244054794, 36.16943456232548, 35.62047801911831, 52.36841753125191, 62.43384562432766, 30.2527891471982, 0.3691964421886951, 0.020276880895835347, 0.02217444489360787, 0.03130753684672527, 0.03308802333776839, 0.028153245948487893, 0.03680178226204589, 0.06702090016915463, 0.06637834871071391, 0.01899731440062169, 0.21118916454724967, 0.10840563729288988, 0.09086947437026538, 0.07805698493029922, 0.16421020729467273, 0.1101464856765233, 0.24906235572416335, 0.19717765389941633, 0.22604402212891728, 0.15216516534565017, 0.3868995141237974, 0.13927536638220772, 14.453502930700779, 68.87260392308235, 55.47740310430527, 46.50136895477772, 48.405803963541985, 40.08744992315769, 48.52618530392647, 64.98972147703171, 63.40890370309353, 49.48274217545986, 0.6395367358345538, 0.2361249554087408, 2.1621578419581056, 4.807932358235121, 3.8528115721419454, 27.067163586616516, 53.140285313129425, 57.0791881531477, 56.50897555053234, 57.05106966197491, 56.24324440956116, 55.493514239788055, 49.10839386284351, 43.2069381326437, 42.96363338828087, 41.56758449971676, 44.803034886717796, 54.87918600440025, 54.355235919356346, 56.203840523958206, 55.67485190927982, 53.112071827054024, 50.131922140717506, 50.38774721324444, 49.83603581786156, 47.786855176091194, 44.07056339085102, 43.76962333917618, 41.492135748267174, 41.58529534935951, 42.44878761470318, 41.96778662502766, 40.31964786350727, 40.24789251387119, 43.423553109169006, 42.19472944736481, 39.46792736649513, 41.74382284283638, 39.96928006410599, 42.79393449425697, 38.608352690935135, 40.913027822971344, 38.17977748811245, 40.545572340488434, 41.87800884246826, 41.42085537314415, 42.23278060555458, 43.09276185929775, 43.00332225859165, 42.65843376517296, 43.133229687809944, 44.170562624931335, 44.20900136232376, 42.1667705476284, 42.22848683595657, 41.644002199172974, 42.009770572185516, 42.170467749238014, 41.60948105156422, 40.30648536980152, 42.415410205721855, 42.175700068473816, 43.202123790979385, 48.56629215180874, 53.18782836198807, 53.624595925211906, 54.02064107358456, 52.451192289590836, 57.975259870290756, 55.734295919537544, 47.24994778633118, 46.34008280932903, 43.60429421067238, 45.399044305086136, 44.686924517154694, 46.5395151078701, 45.21744064986706, 43.890487253665924, 43.115154057741165, 40.62602922320366, 42.56425581872463, 38.919263407588005, 38.878651186823845, 43.5968504101038, 43.62404555082321, 43.66232089698315, 42.73267038166523, 43.82416941225529, 41.411006301641464, 38.435743153095245, 40.480599626898766, 37.681958600878716, 39.96497869491577, 40.270687490701675, 40.45958675444126, 40.5704116076231, 41.466718912124634, 41.18990756571293, 39.87909570336342, 41.67552910745144, 40.60996748507023, 40.83132840692997, 44.485656917095184, 55.72946637868881, 52.83860810101032, 54.79569308459759, 51.84833563864231, 54.651319831609726, 52.233904749155045, 55.02760224044323, 52.270409390330315, 48.764196932315826, 52.384889647364616, 48.038477674126625, 45.56996293365955, 50.55883303284645, 55.68110257387161, 59.08469773828983, 62.15264551341534, 60.104126036167145, 58.62002447247505, 60.81922486424446, 62.36455254256725, 54.2502361536026, 62.40511916577816, 61.664390712976456, 66.37064337730408, 61.23586870729923, 71.42826318740845, 20.410483181476593, 0.3947978059295565, 3.248719274997711, 2.940277950838208, 0.5986055103130639, 0.9184322110377252, 51.905518770217896, 74.32939991354942, 67.18226462602615, 63.6750528216362, 43.432889208197594, 41.671505123376846, 61.581802144646645, 73.600834608078, 42.33004778623581, 0.9171244280878454, 0.13635639566928148, 0.16620085516478866, 0.20810956339119002, 0.11103060620371252, 0.10438713768962771, 0.1447092232410796, 0.13243015244370326, 0.15634675190085545, 0.17138919472927228], [0.07569665103801526, 0.008118598343571648, 0.0378252707014326, 0.044326851711957715, 0.053830412653042004, 0.08195972433895804, 0.07105361932190135, 0.01856247523392085, 0.0383073920966126, 0.06310207099886611, 0.20636458124499768, 0.061798418100806884, 6.023844787850976, 47.62053430080414, 49.71068814396858, 28.943208418786526, 28.173430524766445, 37.360294461250305, 35.968094766139984, 55.07538467645645, 51.02446764707565, 48.8472680747509, 1.8982010870240629, 0.05618601535388734, 1.0155724547803402, 0.16496366530191153, 2.204370489344001, 13.810748420655727, 54.132176488637924, 56.604342833161354, 52.277621403336525, 51.08176477253437, 47.00878992676735, 40.55929720401764, 37.955771908164024, 37.46525622904301, 40.339262410998344, 45.978581607341766, 51.698289290070534, 51.570631340146065, 48.078557923436165, 48.6791954934597, 50.65327316522598, 47.40738473832607, 43.239692375063896, 41.8289078772068, 41.59403868019581, 39.0127307921648, 37.418571934103966, 37.30289854109287, 35.64944386482239, 35.71766920387745, 36.03647589683533, 35.17307862639427, 35.70044472813606, 35.41273556649685, 36.614424884319305, 37.253542989492416, 36.956676319241524, 36.08339957892895, 37.72562585771084, 35.19238539040089, 35.66247716546059, 36.45696893334389, 36.48678593337536, 35.85785128176212, 38.386752381920815, 37.21848987042904, 37.16274306178093, 37.760884165763855, 37.28830732405186, 38.046188056468964, 37.6077713817358, 38.35943944752216, 37.47387796640396, 37.23292149603367, 37.98774339258671, 37.492059990763664, 36.67336732149124, 35.25453485548496, 37.37181544303894, 37.627651914954185, 37.32895754277706, 37.02792249619961, 36.02133750915527, 41.86820536851883, 46.25635050237179, 52.1255649626255, 52.158159613609314, 51.78490184247494, 52.71340101957321, 47.0915836840868, 40.48230953514576, 38.49373184144497, 38.28670375049114, 40.79436399042606, 40.447438806295395, 42.093248292803764, 40.695630088448524, 37.761526331305504, 37.66017436981201, 38.79255920648575, 36.973843798041344, 36.79126739501953, 38.7125962972641, 36.89638875424862, 38.4770355373621, 37.64372505247593, 39.53592091798782, 39.55938085913658, 37.03036576509476, 36.97769299149513, 36.76493480801582, 36.533998399972916, 36.84273563325405, 36.88474237918854, 36.98373846709728, 37.178998589515686, 36.537984386086464, 37.28172227740288, 37.51041300594807, 37.61815622448921, 39.91480618715286, 38.586108684539795, 44.42441180348396, 47.72301100194454, 48.56489762663841, 48.522890880703926, 48.187076300382614, 48.87838460505009, 48.97934138774872, 46.16400025784969, 47.12279140949249, 46.08910247683525, 44.955174922943115, 43.90528745949268, 43.26948657631874, 44.72173444926739, 46.57822363078594, 50.55054187774658, 54.288811683654785, 54.236408695578575, 56.96671038866043, 55.77518552541733, 58.143906220793724, 54.08078044652939, 57.77649633586407, 54.89528574049473, 62.824954837560654, 56.06333926320076, 53.57018664479256, 14.235236942768097, 0.3623142989818007, 1.3686452340334654, 0.3113492962438613, 0.2215943273040466, 1.4870307315140963, 45.25501303374767, 66.46864771842957, 51.63267441093922, 46.93679139018059, 32.18664787709713, 30.543682537972927, 43.40650722384453, 55.989562422037125, 30.243010371923447, 0.2987171709537506, 0.15698725503170863, 0.07312216301215813, 0.02637564826727612, 0.034661246536416, 0.054567869956372306, 0.008919089959817939, 0.048714065123931505, 0.05776417383458465, 0.03833571987343021, 0.04680451544118114, 0.023925388341012876, 0.05082127099740319, 0.05823327424877789, 0.017528275748190936, 0.05530717891815584, 0.01989660999242915, 0.03775415811105631, 0.03627419690019451, 0.019772578561969567, 0.1451248853118159, 0.08761863748077303, 7.293824041262269, 52.98047348856926, 56.09200492501259, 33.95505018532276, 31.65412165224552, 39.2608080804348, 40.22205010056496, 60.93486785888672, 54.658778831362724, 53.21513369679451, 1.8219169741496444, 0.12825652171159163, 0.16861175157828256, 5.429916707798839, 3.310228236950934, 14.090462811291218, 53.69671605527401, 59.159861505031586, 55.43745584785938, 52.069278582930565, 50.0443634390831, 42.353986501693726, 40.01617714762688, 38.81591655313969, 42.84564591944218, 48.535582199692726, 54.286778792738914, 54.389570876955986, 50.99471904337406, 52.05459237098694, 52.65604689717293, 49.24211248755455, 48.17603029310703, 44.9837189912796, 43.68101209402084, 41.92773677408695, 40.17238296568394, 37.83404164016247, 38.29993464052677, 36.817432790994644, 37.377290949225426, 38.18903759121895, 38.26267383992672, 38.24156977236271, 37.365534380078316, 39.06224973499775, 38.309061750769615, 39.09948393702507, 39.653042033314705, 37.05305814743042, 37.04974852502346, 38.509094417095184, 36.66249990463257, 37.244005501270294, 40.257232412695885, 38.8132680952549, 39.60800684988499, 38.49637649953365, 39.58801992237568, 39.94645468890667, 40.47371819615364, 39.86762031912804, 39.200820699334145, 39.34569172561169, 39.88469660282135, 39.878115355968475, 38.40823642909527, 36.92416526377201, 40.04010446369648, 39.50610011816025, 38.78965236246586, 38.99664245545864, 38.032786175608635, 43.99025849997997, 49.91705507040024, 55.95570243895054, 54.787888303399086, 52.76114545762539, 55.8637435734272, 50.48625312745571, 42.2748139500618, 41.22408673167229, 40.65687216818333, 43.24195325374603, 41.60910487174988, 43.68742235004902, 42.953202947974205, 39.853796660900116, 38.86551149189472, 40.42641073465347, 38.98316077888012, 38.06530483067036, 38.96701164543629, 38.88726532459259, 39.31381143629551, 40.418077781796455, 41.251088082790375, 39.657191410660744, 38.463405668735504, 39.84881512820721, 39.33934226632118, 39.432000294327736, 40.4775445908308, 38.855008855462074, 38.866054862737656, 38.557158038020134, 40.20014047622681, 39.522845819592476, 39.815661907196045, 38.9593930542469, 40.67723907530308, 40.49267917871475, 46.650305762887, 51.67333982884884, 51.89462095499039, 51.934347823262215, 50.10073721408844, 52.505445778369904, 48.90717186033726, 48.873083889484406, 49.297847896814346, 48.225921615958214, 47.61883199214935, 46.5821336209774, 45.49300566315651, 47.22191669046879, 49.6950101852417, 54.63948726654053, 55.208989307284355, 56.38342648744583, 59.59064058959484, 57.6051939278841, 60.279042050242424, 57.0184750109911, 59.27935369312763, 58.753302320837975, 64.23232331871986, 58.00399012863636, 58.93874377012253, 16.25208131968975, 0.49473751976620406, 2.438448378816247, 0.892821466550231, 0.21822729235282168, 1.3977425289340317, 49.23108547925949, 70.5134166777134, 58.291357308626175, 58.964373394846916, 39.000522047281265, 36.96970961987972, 47.93502442538738, 67.6133818924427, 38.5734211653471, 0.47913496324326843, 0.10310590878361836, 0.08821342431474477, 0.09354825640912168, 0.03181650914484635, 0.0476240913849324, 0.07699388806940988, 0.015410578689625254, 0.03204267493856605, 0.012519213087216485, 0.2173461701022461, 0.11299906385829672, 0.1617577506112866, 0.16252385481493548, 0.18023406621068716, 0.1415220255148597, 0.18650467973202467, 0.11632597088464536, 0.09188268406433053, 0.173003425297793, 0.29730866372119635, 0.23432512854924425, 8.258254565298557, 63.4345181286335, 62.67075911164284, 41.40477083623409, 37.339490577578545, 47.85155810415745, 47.181559056043625, 65.84045022726059, 59.08750958740711, 58.548166528344154, 2.5099011696875095, 0.4379123408580199, 2.3518035281449556, 6.036219298839569, 4.036595597863197, 16.10291462391615, 54.98243406414986, 59.80197384953499, 57.767395824193954, 56.47658608853817, 51.25129647552967, 43.68681438267231, 42.43183672428131, 41.0055148601532, 44.854639917612076, 50.40356196463108, 56.52423553168774, 55.999954864382744, 51.03465870022774, 53.67101803421974, 55.45168228447437, 52.47441664338112, 50.01745708286762, 45.96809796988964, 45.799934193491936, 44.117190688848495, 41.90872639417648, 41.2418507784605, 40.75251303613186, 38.73977243900299, 40.0177426636219, 38.892748430371284, 40.86105041205883, 40.09265564382076, 40.75336039066315, 42.50046864151955, 40.248641073703766, 41.19396194815636, 41.078983917832375, 39.37724523246288, 38.527797013521194, 40.50287023186684, 40.0830839574337, 39.3494763225317, 42.99780495464802, 40.933755710721016, 42.15020723640919, 39.89342853426933, 41.22091770172119, 41.849198788404465, 42.82561719417572, 41.50557562708855, 40.72838433086872, 40.625425055623055, 43.07439364492893, 41.71040743589401, 40.19832417368889, 39.01464208960533, 41.434812024235725, 42.202268242836, 40.89905597269535, 44.51406039297581, 39.15140815079212, 45.69304592907429, 51.09056130051613, 57.03800216317177, 57.10340805351734, 55.73757514357567, 57.97130428254604, 51.47154025733471, 44.49949957430363, 44.01320546865463, 41.84830583631992, 47.60042957961559, 44.06855709850788, 47.52610556781292, 45.05963891744614, 42.33256325125694, 40.105571150779724, 44.00290422141552, 40.998496636748314, 41.33113078773022, 42.40216791629791, 41.75299555063248, 41.87917537987232, 40.69252945482731, 44.28244762122631, 43.078486025333405, 40.832730531692505, 40.59387154877186, 40.21024413406849, 41.084831804037094, 41.19342237710953, 40.608721151947975, 41.75511583685875, 41.11676529049873, 42.06988714635372, 41.56565420329571, 41.35294921696186, 41.56372010707855, 43.50195810198784, 42.79965318739414, 49.760393276810646, 54.54152092337608, 53.18266823887825, 54.07583311200142, 52.2080547362566, 54.57004599273205, 50.34100592136383, 48.33407141268253, 50.025185868144035, 49.87624146044254, 49.99382995069027, 48.55102837085724, 47.51844897866249, 49.2996072024107, 51.940366700291634, 56.28339305520058, 57.567104771733284, 58.301141783595085, 62.51866087317467, 60.01765787601471, 63.24272722005844, 57.994768023490906, 60.881758108735085, 61.13648124039173, 68.9868713915348, 58.86601947247982, 59.83815550804138, 19.275979958474636, 1.060982036869973, 4.3759729620069265, 3.5675300052389503, 0.7227397430688143, 1.5895514865405858, 52.53091961145401, 78.01758840680122, 61.7471806704998, 63.12038138508797, 43.06841276586056, 44.332084357738495, 57.41103574633598, 73.99501025676727, 48.69588039815426, 0.9493073355406523, 0.2950263815000653, 0.1371603345614858, 0.1064275688258931, 0.10588521472527646, 0.15369896194897592, 0.13296807592269033, 0.12622704467503354, 0.11346683211741038, 0.16554393572732806], [0.06017994986905251, 0.0533539352909429, 0.010032958070951281, 0.033735502656782046, 0.03379964648047462, 0.14130813855445012, 0.01022736736558727, 0.07009701323113404, 0.1144602858403232, 0.03982414898928255, 0.11968551014433615, 0.03364280470123049, 2.2070897184312344, 38.67714039981365, 54.96169477701187, 36.08306139707565, 28.182479739189148, 38.57945904135704, 33.38709846138954, 55.91376028954983, 48.95483270287514, 53.71116667985916, 5.8987203519791365, 0.1057868950010743, 0.6655358313582838, 1.461472709197551, 1.5864028804935515, 9.280220177024603, 57.35706724226475, 54.206086322665215, 54.464518055319786, 44.85555946826935, 40.24330236017704, 36.9797220826149, 41.17658548057079, 45.86638502776623, 50.66154532134533, 51.35769456624985, 48.82190063595772, 47.11867243051529, 50.59579744935036, 51.023681089282036, 47.4421376734972, 45.613869577646255, 43.038500770926476, 40.33697493374348, 38.35245542228222, 38.31896401941776, 35.22127903997898, 33.870158940553665, 34.6722237020731, 33.947112411260605, 35.18383964896202, 35.337374210357666, 36.63793422281742, 34.33348707854748, 35.73989801108837, 36.54991954565048, 36.212273463606834, 35.251647010445595, 35.700034350156784, 36.87038294970989, 35.74097715318203, 36.78372859954834, 35.425122901797295, 35.325119867920876, 36.72771580517292, 34.83908034861088, 38.20161871612072, 36.13099582493305, 38.0318134278059, 39.15577031672001, 37.62053109705448, 36.908080726861954, 37.46893063187599, 38.12461204826832, 40.58491162955761, 39.30424354970455, 36.26545540988445, 37.48561553657055, 38.23990926146507, 35.307732000947, 35.78766144812107, 34.9611259996891, 35.93142293393612, 38.55640187859535, 46.04038529098034, 51.71319209039211, 51.971650421619415, 50.36290034651756, 52.024695575237274, 49.468990713357925, 40.11694774031639, 39.20211263000965, 40.44594168663025, 41.037642136216164, 42.568344399333, 41.51675462722778, 40.868634805083275, 36.76925517618656, 37.35189691185951, 39.71817433834076, 38.56174819171429, 37.843043357133865, 36.34133733808994, 38.23691122233868, 38.70075613260269, 38.50749850273132, 39.60457183420658, 38.64937908947468, 38.13401274383068, 36.378495544195175, 37.173637077212334, 35.149413496255875, 37.12659940123558, 36.52576424181461, 35.87235510349274, 37.62076288461685, 35.059407725930214, 36.234988644719124, 35.99652864038944, 35.563690066337585, 37.80368506908417, 38.373916670680046, 44.84267435967922, 50.53261823952198, 47.857823967933655, 48.17586690187454, 50.55437207221985, 49.183607026934624, 48.54940965771675, 50.18999442458153, 46.65043495595455, 44.95826795697212, 45.604153499007225, 39.63671810925007, 41.67216628789902, 45.74855335056782, 49.48079288005829, 48.12070146203041, 52.352439388632774, 51.05897359549999, 54.71939317882061, 55.79238720238209, 57.688797041773796, 54.52943377196789, 60.556879341602325, 57.82296784222126, 61.73066295683384, 49.792661145329475, 53.95072102546692, 18.931695632636547, 0.19811310135992244, 1.5233880118466914, 0.7989371137227863, 0.09267886751331389, 2.011302374303341, 47.247280329465866, 63.3491975069046, 53.08439411222935, 42.32473187148571, 30.083620324730873, 26.407646276056767, 46.3711841404438, 58.87155957520008, 19.894429072737694, 0.14698737912112847, 0.04761305193824228, 0.034556637110654265, 0.02601486430648947, 0.03864079822960775, 0.04174169531324878, 0.05897222326893825, 0.07900900454842485, 0.05381641945859883, 0.023948463567649014, 0.054246560830506496, 0.08103555010166019, 0.04924012908304576, 0.006689891242785961, 0.004928858297716943, 0.04205862947856076, 0.043326889353920706, 0.045939779811305925, 0.04872366109339055, 0.05791560164652765, 0.06982042963500135, 0.020656610031437594, 3.0373318679630756, 44.77289870381355, 58.83732721209526, 39.36292000114918, 30.094330050051212, 41.06209762394428, 39.033363685011864, 61.9217699021101, 54.27573658525944, 59.61981162428856, 6.242450857535005, 0.18217795877717435, 0.6846436997875571, 4.979372508823872, 1.4864264451898634, 9.423437342047691, 58.46517898142338, 56.64949581027031, 55.76696276664734, 48.163057789206505, 41.22695177793503, 37.676125913858414, 41.83312565088272, 46.607303470373154, 51.89873233437538, 53.97701181471348, 52.40872576832771, 49.755639731884, 51.68680250644684, 51.81540660560131, 48.33707705140114, 47.011290192604065, 45.12438364326954, 41.6483149677515, 40.12468032538891, 40.17082504928112, 37.266086116433144, 36.41361325979233, 37.098442912101746, 35.46127036213875, 36.4901677519083, 36.37269325554371, 37.46512323617935, 35.96081055700779, 39.54409047961235, 37.729285061359406, 37.94282220304012, 38.1169668585062, 38.43823201954365, 37.48586252331734, 37.771329805254936, 38.18409405648708, 37.21083328127861, 37.54006661474705, 37.67735704779625, 38.21485720574856, 40.81611782312393, 39.01434190571308, 39.371682330965996, 42.567637637257576, 38.92976604402065, 40.06337061524391, 38.71697746217251, 39.8034493625164, 40.870435908436775, 40.085223242640495, 38.849385157227516, 39.227841049432755, 39.34374243021011, 39.075845405459404, 38.80942650139332, 38.02359066903591, 37.72435672581196, 40.51394663751125, 48.66713494062424, 54.15496006608009, 52.11486093699932, 52.20527708530426, 53.873455971479416, 49.06147018074989, 42.14882791042328, 39.90320920944214, 41.894192174077034, 43.599650859832764, 44.1029604524374, 43.49830649793148, 44.84113164246082, 40.048418417572975, 40.11380150914192, 40.719435811042786, 39.51670914888382, 38.95528927445412, 38.94804306328297, 40.12516289949417, 39.75274108350277, 39.42290358245373, 40.83927758038044, 41.030088141560555, 40.74632316827774, 37.220218777656555, 38.58084976673126, 36.76362007856369, 39.50568974018097, 38.76124128699303, 38.10152068734169, 37.439512610435486, 36.72419719398022, 38.22760932147503, 38.49690467119217, 38.343362510204315, 40.5718707293272, 40.693426206707954, 46.550948694348335, 52.54922702908516, 51.21853843331337, 51.88238941133022, 52.7955412119627, 50.55020749568939, 51.89381919801235, 51.39803320169449, 48.59218396246433, 45.93666985630989, 47.639867663383484, 43.21228064596653, 43.995171636343, 48.48781496286392, 52.1253901720047, 50.56878849864006, 55.42218826711178, 54.635763466358185, 56.9713119417429, 56.84492312371731, 60.06531871855259, 57.89293348789215, 61.511486917734146, 61.33692428469658, 63.42041328549385, 52.86350056529045, 55.95124527812004, 21.482363864779472, 0.37169151299167424, 3.372599990107119, 0.9951317484956235, 0.22380419075489044, 1.8614556337706745, 51.56333193182945, 67.59842589497566, 58.30641970038414, 48.7273883074522, 34.14018005132675, 33.923899456858635, 53.88447917997837, 68.17124515771866, 27.6768446713686, 0.14897752233082429, 0.02450996693369234, 0.06328893636236899, 0.04919777471513953, 0.04072451141837519, 0.03951987215259578, 0.03584938785934355, 0.04026351525681093, 0.04710769389930647, 0.019395150084164925, 0.2069689566269517, 0.21389030007412657, 0.13083428260870278, 0.14981888030888513, 0.14100345724727958, 0.2249055972788483, 0.10495709226233885, 0.1668033900205046, 0.24745277100009844, 0.1794901819084771, 0.17715474707074463, 0.1964744392898865, 3.1876159412786365, 51.83189392089844, 67.17294752597809, 47.82904051244259, 37.3132111877203, 49.06982593238354, 44.55645091831684, 70.50324842333794, 56.84190608561039, 65.00814288854599, 7.1300362050533295, 0.32518809428438544, 2.4030072055757046, 4.006769098341465, 3.7245929148048162, 10.468531362712383, 61.03159926831722, 58.59972596168518, 59.917692840099335, 48.66651177406311, 44.184120297431946, 39.929025024175644, 46.25909395515919, 49.36532847583294, 55.278491377830505, 55.1456581056118, 52.83201165497303, 50.75356878340244, 54.45412561297417, 55.24029582738876, 50.77868543565273, 49.6009424328804, 49.363994747400284, 44.181479439139366, 43.707424476742744, 42.15411722660065, 39.37714263796806, 39.00194317102432, 39.75931853055954, 37.44137451052666, 39.55642081797123, 39.63549457490444, 41.518684923648834, 37.4743415415287, 40.87472587823868, 41.66403852403164, 39.92508463561535, 39.76971097290516, 40.38960210978985, 39.56547953188419, 39.23798270523548, 40.608857944607735, 40.050417110323906, 38.83171230554581, 39.3198037147522, 40.35363703966141, 42.90342181921005, 39.43017639219761, 41.93970613181591, 45.262920409440994, 40.228281766176224, 43.14206041395664, 41.19610883295536, 42.1733707934618, 44.69237342476845, 44.44885589182377, 40.97846031188965, 41.211368814110756, 42.18919314444065, 40.513897240161896, 40.97991183400154, 40.198647156357765, 40.56863330304623, 42.60019809007645, 51.85528166592121, 56.355551183223724, 54.41579706966877, 53.39256517589092, 56.96413792669773, 51.472129225730896, 45.09496562182903, 43.07048365473747, 44.77929376065731, 45.50267994403839, 48.140240013599396, 45.80701321363449, 47.4606578797102, 42.531079798936844, 40.79840697348118, 43.387751430273056, 42.258201241493225, 40.25925390422344, 40.611327812075615, 42.76010110974312, 41.688721999526024, 42.13869005441666, 43.675886169075966, 42.28861100971699, 43.599985241889954, 39.340322613716125, 41.29485033452511, 38.68562534451485, 42.234893292188644, 40.426969304680824, 40.413601621985435, 40.880262181162834, 38.52143615484238, 40.66056936979294, 41.09284557402134, 40.64019486308098, 41.60672999918461, 42.1350384503603, 48.39179031550884, 56.0283013433218, 52.59240411221981, 53.14816989004612, 55.582961440086365, 52.81705945730209, 53.44849817454815, 54.72074210643768, 49.48016591370106, 48.66072468459606, 49.32778649032116, 44.529107585549355, 47.13596910238266, 50.75685940682888, 53.90684477984905, 52.82196879386902, 57.86641091108322, 54.89799119532108, 59.86303277313709, 59.10834766924381, 61.59113064408302, 58.98266561329365, 65.33638447523117, 63.95541697740555, 65.00241279602051, 52.07480348646641, 57.03275464475155, 23.070646338164806, 1.4800875540822744, 6.844820659607649, 3.4832776011899114, 0.4793139098910615, 1.9777682237327099, 54.285509660840034, 73.25351804494858, 66.0113650560379, 55.990128591656685, 41.735337898135185, 37.83679649233818, 64.36343148350716, 75.44877424836159, 36.91416420042515, 0.3049050795380026, 0.14800217701122165, 0.1894925514352508, 0.1649628340965137, 0.26414229185320437, 0.12302659219130874, 0.12916682520881295, 0.16897829831577837, 0.16019113623769954, 0.11434419910074212], [0.03055748158658389, 0.02459561263094656, 0.0537096615153132, 0.07797852507792413, 0.038465083634946495, 0.04761752708873246, 0.0714337473618798, 0.06761643657227978, 0.04505773358687293, 0.012546173456939869, 0.01749680312059354, 0.09949172381311655, 0.6403067882638425, 35.968850925564766, 55.992598459124565, 46.63390204310417, 28.5657062754035, 29.87986195832491, 35.599696934223175, 51.98759816586971, 50.47864593565464, 53.08599762618542, 12.407573964446783, 0.1664700172841549, 0.38852113648317754, 11.741739492863417, 5.394855039194226, 6.2683431431651115, 57.70177334547043, 53.01855884492397, 51.896642446517944, 39.449680745601654, 39.847314208745956, 44.65266935527325, 54.044591188430786, 52.55986265838146, 51.47260420024395, 50.58187119662762, 51.838117986917496, 50.29084861278534, 48.508740440011024, 46.19797043502331, 45.4542401432991, 41.498808190226555, 39.48423609137535, 35.980478301644325, 35.98132945597172, 35.774441957473755, 35.91718129813671, 34.345163851976395, 33.47636327147484, 33.790872395038605, 34.920886158943176, 35.48595003783703, 36.37805096805096, 35.6998747587204, 37.179967537522316, 34.80993591248989, 38.03767271339893, 36.45844325423241, 37.11266174912453, 36.04431867599487, 35.21199993789196, 34.37860205769539, 36.184310764074326, 36.57594054937363, 37.16386400163174, 37.669970244169235, 36.06634609401226, 39.48227919638157, 39.65739279985428, 38.502072393894196, 38.553369641304016, 39.301811680197716, 40.55906541645527, 38.72785247862339, 40.74961759150028, 37.77027726173401, 38.42590548098087, 35.59750445187092, 38.93087938427925, 35.91392867267132, 36.70649774372578, 36.50324285030365, 38.9808315038681, 37.11162820458412, 45.42850412428379, 51.37599818408489, 51.71112880110741, 50.80440625548363, 52.621221765875816, 47.60874733328819, 39.80527326464653, 37.609393894672394, 40.00494875013828, 41.399378925561905, 41.881322264671326, 40.728251338005066, 39.53703425824642, 37.724938094615936, 39.85586754977703, 38.14945891499519, 37.575678303837776, 37.32767701148987, 37.47580446302891, 38.43907557427883, 37.4345538765192, 38.995582312345505, 37.29437179863453, 38.719435930252075, 38.21149438619614, 36.25742644071579, 36.62757597863674, 37.76043199002743, 37.54059478640556, 35.993469804525375, 37.55802825093269, 36.80914543569088, 35.42817793786526, 35.38898304104805, 35.343529880046844, 34.756396785378456, 37.109025344252586, 37.40441009402275, 45.78970894217491, 49.62630607187748, 47.888153940439224, 48.45327101647854, 46.475161761045456, 48.93381983041763, 50.38148134946823, 47.66520470380783, 49.5157016068697, 45.867300778627396, 45.155199989676476, 42.15224392712116, 40.665839686989784, 44.21723172068596, 50.52164062857628, 51.936517506837845, 51.144119426608086, 47.28514529764652, 54.297095239162445, 51.465293392539024, 54.345364049077034, 51.82952284812927, 54.51397240161896, 55.01666642725468, 53.71184304356575, 52.99391716718674, 59.09668989479542, 20.21578922867775, 1.218824617099017, 2.1769380988553166, 1.0579464747570455, 0.20251572917914018, 1.973758963868022, 50.33353932201862, 64.5455253124237, 49.853347688913345, 47.04383544623852, 39.22518119215965, 28.51872179657221, 41.92594327032566, 57.63560749590397, 17.776899598538876, 0.1209527940955013, 0.07709803365287371, 0.03595145171857439, 0.021514631080208346, 0.05815438766148873, 0.03418378582864534, 0.05217478879785631, 0.06757333263522014, 0.05556201758736279, 0.1110724633326754, 0.028125832868681755, 0.0698517556884326, 0.041528787987772375, 0.038306282585836016, 0.09297908851294778, 0.03846910607535392, 0.043299463286530226, 0.06768046907382086, 0.04839487111894414, 0.017227544522029348, 0.06075534809497185, 0.06291326120845042, 0.8141887828242034, 41.63792632520199, 63.32404285669327, 51.844376251101494, 34.204392805695534, 39.10656675696373, 38.781786784529686, 59.330567345023155, 53.94695922732353, 59.51878264546394, 12.716522086411715, 0.19245196919655427, 1.1759173194877803, 7.89934434928, 2.076708027161658, 6.81387796998024, 60.508652329444885, 55.71390241384506, 55.745410323143005, 41.559167951345444, 42.63064965605736, 46.34021580219269, 57.215445041656494, 53.837954476475716, 52.86452271044254, 51.86225049197674, 52.90347822010517, 53.62742677330971, 51.48053057491779, 49.15860436856747, 47.79048778116703, 43.94317902624607, 41.476222202181816, 37.82671943306923, 39.87939588725567, 36.698126792907715, 37.83412143588066, 35.18419682979584, 35.411531031131744, 35.732989981770515, 37.68218278884888, 38.36992688477039, 37.17231094837189, 37.201018407940865, 38.40653792023659, 37.867217659950256, 40.10489858686924, 38.93395721912384, 39.1023413836956, 37.835325971245766, 37.43486925959587, 37.22832754254341, 37.11629435420036, 37.36733168363571, 38.3164219558239, 39.73126083612442, 38.05145837366581, 41.89363360404968, 41.210304871201515, 40.12183427810669, 39.79200437664986, 41.197218373417854, 42.92004972696304, 40.3490848839283, 42.232681810855865, 40.366069972515106, 39.80786852538586, 37.90766268968582, 40.10818541049957, 38.799125254154205, 38.21284331381321, 38.69595319032669, 40.135619938373566, 38.83945249021053, 49.005673974752426, 54.32130753993988, 53.33786331117153, 53.27670179307461, 55.29791973531246, 48.75269494950771, 40.837601870298386, 40.083087757229805, 41.23883754014969, 43.89939397573471, 43.25594410300255, 43.648531436920166, 41.649200320243835, 40.54212972521782, 40.01491941511631, 39.57938298583031, 39.17255021631718, 38.79070870578289, 39.91935074329376, 40.428743809461594, 38.3992613106966, 39.96581085026264, 39.50055621564388, 39.52529288828373, 39.178044721484184, 37.899690717458725, 37.93741509318352, 37.71268755197525, 40.32580353319645, 37.58395805954933, 37.76920571923256, 37.0902543514967, 36.87557727098465, 38.5808801651001, 37.900864854454994, 36.908407509326935, 39.252152144908905, 39.51513983309269, 47.44430735707283, 51.605661660432816, 51.404975429177284, 50.42353369295597, 48.89269083738327, 51.255244463682175, 50.31287603080273, 49.09885637462139, 49.981727600097656, 48.49445700645447, 47.21812829375267, 44.42278549075127, 42.17803694307804, 47.07961432635784, 52.30341821908951, 55.313289910554886, 52.8206692636013, 49.48738552629948, 55.5555535107851, 53.31394739449024, 54.95747700333595, 51.44437551498413, 55.532530546188354, 54.921196550130844, 55.858363062143326, 56.144404113292694, 61.54638044536114, 22.057385109364986, 1.9315136619843543, 1.8419409496709704, 0.9282936318777502, 0.2167857447057031, 1.8287408142350614, 53.38960513472557, 68.94593238830566, 56.097404435276985, 50.82037679851055, 37.87863224744797, 31.386517211794853, 47.75262661278248, 64.8170055449009, 22.729257456958294, 0.1157333362789359, 0.055411383873433806, 0.03878487506881356, 0.039897855385788716, 0.11896624288056046, 0.019298294246254954, 0.04475491507037077, 0.05222886167757679, 0.0718004276859574, 0.04692777503805701, 0.17626078566536307, 0.11878270976012573, 0.17585267865797505, 0.16250867047347128, 0.22366046643583104, 0.10513505185372196, 0.1253782949061133, 0.19276649138191715, 0.14482391474302858, 0.11199060390936211, 0.12334377126535401, 0.19929409580072388, 1.0647036996670067, 45.48876889050007, 71.53591141104698, 59.27800856530666, 39.67765711247921, 40.555854588747025, 46.97217509150505, 64.84988898038864, 60.439416244626045, 64.10050079226494, 15.50362978130579, 0.3568595432443544, 1.1597716296091676, 22.744616232812405, 8.736780937761068, 8.453235402703285, 61.02571718394756, 58.08818221092224, 57.388518154621124, 42.97178395092487, 44.7412995994091, 48.94806146621704, 57.8456412255764, 55.030368492007256, 54.689264595508575, 53.824301809072495, 55.05065940320492, 54.53154265880585, 51.92233286798, 51.338235810399055, 51.82597763836384, 46.49034194648266, 43.56088913977146, 38.91152322292328, 41.793657168745995, 39.634244441986084, 39.50885497033596, 37.304057478904724, 37.731830924749374, 38.736474215984344, 39.348332583904266, 39.903334602713585, 40.03946229815483, 39.787782803177834, 40.89132338762283, 38.65982472896576, 42.28606514632702, 39.646156802773476, 41.181722804903984, 39.82140339910984, 39.33312579989433, 38.545101284980774, 38.967764005064964, 40.28430216014385, 41.08090661466122, 41.60864509642124, 39.71768416464329, 44.41289842128754, 43.2335215061903, 41.434280052781105, 41.53043009340763, 43.036870658397675, 44.321228340268135, 43.13150458037853, 45.67528188228607, 42.05188751220703, 41.99340105056763, 39.081146121025085, 43.901575058698654, 41.63092330098152, 41.192236840724945, 40.90413250029087, 43.31121973693371, 40.54630950093269, 50.73993131518364, 56.38978734612465, 55.254077687859535, 54.10410739481449, 57.351139560341835, 51.340739876031876, 43.367426320910454, 41.58089138567448, 44.97216761112213, 47.32487216591835, 46.41095660626888, 44.1275679320097, 43.93254339694977, 43.42842444777489, 42.709324434399605, 41.440291330218315, 41.5663305670023, 41.938304007053375, 42.37401522696018, 42.31696508824825, 39.68117572367191, 43.294082656502724, 40.92341646552086, 42.080891355872154, 42.190568670630455, 39.536308497190475, 40.29906436800957, 40.62136307358742, 42.22660593688488, 38.6848995834589, 40.06555549800396, 39.84634906053543, 38.80230948328972, 40.7987679541111, 40.014452040195465, 38.857315331697464, 41.845896765589714, 39.93792414665222, 51.05009727180004, 54.28171366453171, 53.56218047440052, 53.802855759859085, 51.12414389848709, 52.89729215204716, 53.521477058529854, 51.548094749450684, 53.52783031761646, 49.51440587639809, 49.5927918702364, 47.65518844127655, 45.26893548667431, 49.359450191259384, 55.906734466552734, 57.518262192606926, 55.379128977656364, 53.26321251690388, 57.820038199424744, 54.665983244776726, 56.99295178055763, 53.32921117544174, 57.039389088749886, 57.743677496910095, 55.98165884613991, 55.354304909706116, 63.58949661254883, 23.609142042696476, 2.871431107632816, 6.169430175796151, 3.44233859796077, 0.8819880103692412, 2.1404113713651896, 58.75784307718277, 73.73499780893326, 62.251345217227936, 61.963826045393944, 49.904291555285454, 40.467315539717674, 57.2729017585516, 74.85017716884613, 30.97300250083208, 0.4441398801282048, 0.20426964678335935, 0.14165800181217492, 0.11993936175713316, 0.20797847042558715, 0.05811693146824837, 0.13005106447963044, 0.18092053796863183, 0.27329424920026213, 0.22275654540862888], [0.048403060718555935, 0.0972514545719605, 0.09235298304702155, 0.027829415375890676, 0.029260695409902837, 0.12768204003805295, 0.04819020163267851, 0.0408975579921389, 0.06780250041629188, 0.035830355482175946, 0.021660806341969874, 0.10397923848358914, 0.2407279927865602, 21.94518283009529, 51.960319429636, 45.70303179323673, 22.499185502529144, 25.253680497407913, 36.74397513270378, 49.75815139710903, 50.863599479198456, 55.59721827507019, 19.032692313194275, 0.0654117384692654, 0.7693568884860724, 5.320655470713973, 3.036096696741879, 3.24260825291276, 55.92435032129288, 53.541494384408, 50.722330659627914, 41.72415129840374, 49.26265798509121, 50.455805361270905, 52.84689545631409, 47.421098202466965, 53.49580943584442, 51.52145057916641, 51.08651451766491, 45.37022665143013, 49.02561530470848, 44.51574370265007, 43.0284883081913, 37.652700170874596, 37.522845938801765, 34.84850004315376, 35.722202360630035, 35.145366713404655, 36.484836637973785, 34.395165368914604, 35.607904493808746, 34.985497891902924, 36.92448444664478, 36.621249318122864, 37.67339006066322, 35.33161371946335, 35.96921190619469, 35.333935394883156, 36.91596910357475, 36.79997652769089, 36.7442487180233, 36.03942833840847, 37.57776819169521, 36.74303278326988, 35.37451721727848, 36.569043919444084, 38.10725077986717, 36.67659714818001, 37.550808638334274, 37.41642124950886, 39.366613402962685, 39.17778253555298, 37.74650193750858, 38.97762067615986, 40.74756570160389, 37.810543701052666, 39.020459577441216, 36.7758022248745, 36.88560493290424, 37.91794873774052, 36.79855540394783, 35.158126428723335, 36.12655386328697, 35.579751804471016, 37.94452451169491, 37.78753213584423, 45.613166615366936, 51.64446137845516, 52.1433974057436, 52.215072959661484, 53.11254680156708, 48.067496716976166, 40.350650399923325, 38.505347818136215, 40.876652374863625, 42.55002178251743, 41.96342445909977, 40.600669384002686, 39.46840614080429, 37.926445081830025, 39.209678024053574, 38.59756126999855, 39.27327141165733, 36.97489634156227, 37.41318002343178, 37.31843210756779, 38.640776351094246, 36.44633710384369, 38.55546332895756, 37.3927903175354, 38.09925600886345, 36.83141604065895, 36.25986970961094, 35.585265308618546, 36.07037767767906, 37.592750787734985, 35.73079749941826, 36.89395688474178, 36.66026942431927, 37.28595145046711, 35.35944722592831, 35.563465878367424, 36.08640521764755, 36.45403929054737, 41.51727519929409, 48.418556079268456, 47.04029403626919, 50.20531140267849, 48.069734796881676, 47.32642248272896, 49.752812683582306, 50.48574775457382, 46.96313537657261, 45.36636605858803, 44.01767022907734, 42.13048629462719, 37.1652889251709, 43.723649606108665, 52.05194391310215, 55.08473217487335, 45.7480251789093, 49.09553535282612, 55.863986760377884, 53.43785874545574, 54.32130753993988, 51.895373314619064, 51.5800966322422, 52.79779069125652, 54.92225669324398, 56.76243335008621, 55.14666125178337, 30.1618505269289, 2.0414727553725243, 0.733636727090925, 0.778570503462106, 0.1453784029581584, 2.1633535902947187, 46.53026640415192, 66.14506468176842, 53.889498710632324, 42.48707056045532, 23.174530863761902, 30.462938770651817, 46.177440136671066, 59.71781976521015, 14.451058711856604, 0.09504048532107845, 0.03385783827980049, 0.03356576606165618, 0.09855614276602864, 0.08920837717596442, 0.043305003418936394, 0.040436008930555545, 0.07236906123580411, 0.05759462648711633, 0.019046503948629834, 0.03256253454310354, 0.05034568421251606, 0.08448819920886308, 0.05379667090892326, 0.04898057035461534, 0.06779062605346553, 0.019292243887321092, 0.022465992042270955, 0.05559970755712129, 0.04252109880326316, 0.0852883086190559, 0.1213618139445316, 0.2568002842599526, 28.64149320870638, 58.034411296248436, 51.590508073568344, 27.296426184475422, 26.289240829646587, 39.1840635985136, 57.756042033433914, 55.44198140501976, 62.00394809246063, 20.354316495358944, 0.06451403663959354, 1.3962545525282621, 4.62887124158442, 4.32546179741621, 4.016754012554884, 59.577489495277405, 55.74886053800583, 53.26553799211979, 44.39033903181553, 51.531991213560104, 52.668495029211044, 55.25845505297184, 50.06175510585308, 55.65659008920193, 52.5594674795866, 53.601553961634636, 47.35593929886818, 51.33834980428219, 45.71916192770004, 44.152338802814484, 40.35995990037918, 39.27037596702576, 36.70404687523842, 37.803992852568626, 36.50483496487141, 37.89865717291832, 36.06510356068611, 35.97916357219219, 37.307883873581886, 38.6358480155468, 37.80141659080982, 40.6524758040905, 36.608489602804184, 38.22477087378502, 38.57060931622982, 38.65568295121193, 37.87953659892082, 39.08572867512703, 38.007996305823326, 38.158525228500366, 39.19071704149246, 37.604910135269165, 37.702238112688065, 39.46044936776161, 38.03799569606781, 38.80346842110157, 38.13075251877308, 40.29906436800957, 39.77912686765194, 40.03298744559288, 40.62513247132301, 41.62328191101551, 39.97414380311966, 40.48481360077858, 38.34989815950394, 38.97787146270275, 40.16802839934826, 38.547168374061584, 37.711619809269905, 38.37680071592331, 38.15473683178425, 39.38172519207001, 40.859424099326134, 47.74557799100876, 54.431452229619026, 54.25278201699257, 53.24832111597061, 55.13599142432213, 50.63298225402832, 42.35310114920139, 39.36126708984375, 43.625892251729965, 43.952967301011086, 45.97485400736332, 43.27588923275471, 41.250727102160454, 41.18750989437103, 41.5376079082489, 40.7513464987278, 41.68369106948376, 39.3866079300642, 39.97681125998497, 39.270056784152985, 39.825438782572746, 38.87184955179691, 40.82701563835144, 39.6799635887146, 39.868596866726875, 38.43131259083748, 39.801306277513504, 38.37534539401531, 37.22165510058403, 39.93274122476578, 39.219394102692604, 39.02743600308895, 37.03804515302181, 39.90024156868458, 37.78400592505932, 37.64830380678177, 39.147680550813675, 38.86860452592373, 44.02984477579594, 49.76850964128971, 50.594912096858025, 50.79833798110485, 49.386470541357994, 50.07593974471092, 51.450500786304474, 50.7001094520092, 49.88898977637291, 47.03997105360031, 46.87330059707165, 43.85887295007706, 39.89166922867298, 46.67727291584015, 54.94427651166916, 56.93730376660824, 47.5788277387619, 49.873095229268074, 57.675117775797844, 54.15684476494789, 55.78666850924492, 52.6617655903101, 53.00118997693062, 53.13685789704323, 56.28385283052921, 56.01988859474659, 57.54922293126583, 32.599134743213654, 2.8106509940698743, 1.7834968795068562, 0.46756832452956587, 0.11661285549052991, 2.4475042428821325, 51.65244475007057, 70.3036679327488, 57.894772589206696, 48.268730118870735, 32.08143152296543, 36.15697883069515, 54.590865075588226, 67.77703151106834, 18.628160320222378, 0.09982405754271895, 0.019029490213142708, 0.03852846675727051, 0.017234565239050426, 0.09235532081220299, 0.07326404680497944, 0.028216322934895288, 0.07581237412523478, 0.09457826832658611, 0.057045470603043213, 0.08752107474720106, 0.17989460786338896, 0.2523345442023128, 0.14355804829392582, 0.15962849924108014, 0.16072371625341475, 0.10973575146635994, 0.13189378747483715, 0.19305122375953943, 0.09319378441432491, 0.19956079398980364, 0.23056153440847993, 0.38399608398322016, 31.156718842685223, 66.69176414608955, 57.14411526918411, 31.527725234627724, 34.32741120457649, 47.1940565854311, 63.118314296007156, 59.96566526591778, 66.53537973761559, 23.916792534291744, 0.1484770030947402, 2.443633913062513, 14.133939128369093, 4.337548473849893, 4.445241345092654, 64.13309544324875, 56.659044697880745, 54.31721515953541, 47.061455100774765, 53.95112380385399, 54.40253958106041, 56.27026475965977, 51.591066643595695, 59.137153923511505, 55.79058229923248, 56.30950145423412, 48.86610746383667, 54.30304951965809, 48.78421425819397, 46.85360625386238, 42.52973847091198, 40.127951949834824, 37.945052683353424, 40.3363061696291, 39.163837283849716, 40.08982099592686, 39.206060618162155, 37.787098959088326, 39.30227905511856, 42.238153517246246, 40.36896541714668, 42.10655897855759, 38.582825660705566, 38.90462279319763, 39.93870310485363, 41.627685874700546, 40.797821804881096, 40.863687470555305, 39.93361137807369, 40.0246848911047, 41.12557701766491, 40.328508988022804, 39.813689813017845, 42.40434519946575, 40.144469663500786, 40.675384774804115, 39.75396081805229, 43.483776077628136, 43.37443694472313, 42.11659424006939, 42.265979424118996, 43.28125834465027, 42.64355756342411, 41.96810580790043, 40.878058299422264, 42.88805924355984, 44.29411679506302, 39.6313413977623, 40.55376470088959, 40.94999983906746, 40.52550181746483, 42.269752621650696, 45.19984759390354, 50.35035341978073, 54.276181161403656, 55.43104939162731, 54.47052173316479, 57.00745180249214, 52.80323199927807, 43.95984873175621, 41.770968586206436, 46.84109352529049, 47.93708011507988, 48.58257807791233, 45.90642727911472, 43.584584668278694, 42.32091687619686, 43.95770564675331, 44.07564751803875, 42.22114183008671, 41.75238758325577, 41.35226145386696, 41.18673853576183, 42.50157818198204, 39.422781988978386, 45.05841538310051, 41.12351752817631, 41.82576544582844, 41.39262668788433, 41.68438643217087, 39.466342851519585, 39.56402041018009, 41.53065428137779, 40.513243675231934, 41.538451462984085, 40.07343627512455, 41.489289700984955, 40.110947862267494, 39.99302498996258, 41.97330392897129, 41.22691757977009, 46.189238503575325, 51.47623300552368, 52.37893916666508, 55.512729808688164, 50.66806577146053, 51.14196114242077, 53.18459093570709, 53.97585287690163, 50.87585002183914, 49.4756593555212, 49.634927809238434, 47.838589400053024, 41.35860711336136, 48.73262442648411, 58.20440277457237, 60.57013303041458, 50.68429470062256, 52.183302864432335, 61.072960048913956, 57.22192369401455, 56.92354090511799, 54.49378028512001, 53.33899945020676, 55.1761020720005, 57.44014598429203, 57.204942405223846, 59.06819522380829, 35.29242642223835, 3.5620948718860745, 6.396469417959452, 3.662642939016223, 0.3005241818027571, 2.3318227753043175, 56.135717779397964, 76.5607237815857, 65.35232082009315, 55.0336629152298, 35.55892512202263, 42.58483171463013, 62.770716547966, 75.52881315350533, 24.64771181344986, 0.21362330502597615, 0.12602176662767306, 0.1543458623928018, 0.11419016635045409, 0.12284416487091221, 0.21391867980128154, 0.20830945344641805, 0.18816189549397677, 0.12361864050035365, 0.14074483362492174], [0.034993598819710314, 0.1103805071034003, 0.03660662339825649, 0.056583528203191236, 0.022264077779254876, 0.08910677715903148, 0.10923599664238282, 0.04971421672962606, 0.02007558818149846, 0.021311746459105052, 0.05945432982116472, 0.1938664581393823, 0.09083820768864825, 10.175397042185068, 50.18584504723549, 47.377750128507614, 35.52210509777069, 37.6461037248373, 32.761739417910576, 43.26851762831211, 50.55789828300476, 57.34547406435013, 27.919818833470345, 0.8858614868950099, 2.2200000006705523, 3.506668908521533, 9.61877441033721, 2.1772209461778402, 47.890984788537025, 53.53560470044613, 53.89208257198334, 46.363219767808914, 51.632321029901505, 51.427322030067444, 53.580047115683556, 51.38005256652832, 51.30084581673145, 47.37371854484081, 47.98298165202141, 43.95168676972389, 43.708932995796204, 36.76389366388321, 36.617004945874214, 36.07995316386223, 37.07110337913036, 35.70797972381115, 36.13681711256504, 35.92170685529709, 36.890666261315346, 35.245738327503204, 35.19110105931759, 34.58719566464424, 36.06891095638275, 36.32825084030628, 36.23887203633785, 35.215381756424904, 37.34560824930668, 36.35871380567551, 37.42433622479439, 37.20500059425831, 35.18591433763504, 36.61323554813862, 37.79630206525326, 37.87294015288353, 36.50695525109768, 36.29948638379574, 35.570601895451546, 38.074435740709305, 37.31768734753132, 38.45101073384285, 38.10908608138561, 39.40385140478611, 38.1497211009264, 39.05043236911297, 39.88872058689594, 37.23729506134987, 38.194900676608086, 37.03555628657341, 39.731789007782936, 37.4279498308897, 38.91286835074425, 35.73654279112816, 37.13701844215393, 34.708374962210655, 36.311573535203934, 35.72664052248001, 45.394438952207565, 50.03486014902592, 53.2379362732172, 52.36337900161743, 54.20311488211155, 50.02484768629074, 39.50964912772179, 39.74973164498806, 40.346945598721504, 42.133020758628845, 41.29185609519482, 38.76855589449406, 37.73927092552185, 37.15145006775856, 39.4921662658453, 39.67930242419243, 38.62748086452484, 36.62817254662514, 38.33446338772774, 37.953431233763695, 39.7721466422081, 37.94901207089424, 39.18633967638016, 37.7963400632143, 38.13081331551075, 37.58970335125923, 37.92541913688183, 35.65307267010212, 38.8675481826067, 36.31966330111027, 36.61713793873787, 35.7289469987154, 37.572212889790535, 37.45262950658798, 36.53171092271805, 36.53089016675949, 37.23259091377258, 36.80033750832081, 41.79490730166435, 48.145479932427406, 49.70036409795284, 48.208617344498634, 44.40520003437996, 48.82364094257355, 50.680312514305115, 48.892550244927406, 44.99981872737408, 46.295355409383774, 43.423568308353424, 41.73735938966274, 36.89162760972977, 43.6933234333992, 51.73660263419151, 58.9665050804615, 44.8990785330534, 45.183550268411636, 55.28751589357853, 52.46735282242298, 54.73630987107754, 52.226118966937065, 50.75896069407463, 52.74382598698139, 57.93048307299614, 56.820524632930756, 57.02835828065872, 34.089692160487175, 3.8616888457909226, 0.29559213551692665, 0.4785280051873997, 0.028432514263840858, 2.303679585456848, 47.76158273220062, 62.71532692015171, 52.7585805952549, 35.78128919005394, 24.258000925183296, 36.542916521430016, 44.58294689655304, 53.787462785840034, 11.060106419026852, 0.25521609582938254, 0.07536609104136005, 0.04529122066742275, 0.12876138993306085, 0.0625841632427182, 0.06781601492548361, 0.1269090041751042, 0.03094250409048982, 0.01743373170029372, 0.08255405846284702, 0.04976841948518995, 0.02312514348886907, 0.007366727604676271, 0.02904680288338568, 0.022222647385206074, 0.063362854270963, 0.01838762895204127, 0.0540673136129044, 0.03292269881058019, 0.12000217713648453, 0.026682932657422498, 0.16052054590545595, 0.17499448877060786, 14.21071020886302, 58.854832872748375, 52.59289048612118, 35.88245116174221, 37.61022225022316, 41.275562569499016, 51.14000424742699, 55.06421707570553, 60.13059921562672, 31.66234441101551, 0.5744668305851519, 1.3922518235631287, 1.8381911446340382, 8.264367487281561, 3.1505394307896495, 54.411127120256424, 56.05310641229153, 56.749650835990906, 47.27675914764404, 55.81871598958969, 53.80573220551014, 54.262425899505615, 53.33625979721546, 54.271207228302956, 50.08774571120739, 49.78403940796852, 46.66369244456291, 45.86754396557808, 40.817500948905945, 38.81008006632328, 37.29479357600212, 38.39014180004597, 37.92764201760292, 38.49877417087555, 36.72284446656704, 38.09063047170639, 36.56061977148056, 37.39908657968044, 36.00667789578438, 38.232176676392555, 38.21573495864868, 39.48156103491783, 37.094206139445305, 38.77726882696152, 39.374528378248215, 39.98291373252869, 38.70704099535942, 38.854530081152916, 38.91397029161453, 39.70626957714558, 38.80541771650314, 37.44357079267502, 37.81977340579033, 38.89343999326229, 39.50419642031193, 39.24896791577339, 39.72640849649906, 39.457553923130035, 39.34548273682594, 39.840805158019066, 39.040575698018074, 41.748868972063065, 39.35130022466183, 40.433702543377876, 39.54984337091446, 39.94517035782337, 39.64962601661682, 41.254329308867455, 39.21435937285423, 39.04567502439022, 38.16830590367317, 38.65066722035408, 38.87078180909157, 46.563332229852676, 52.23642401397228, 54.33310590684414, 53.17821487784386, 55.396323055028915, 49.54896882176399, 41.60196125507355, 40.70973873138428, 43.22101637721062, 45.29853589832783, 43.513110503554344, 41.65453143417835, 39.92397889494896, 40.5972533673048, 40.714727863669395, 40.2155714482069, 39.370284005999565, 38.50032068789005, 40.5781289935112, 39.71003137528896, 40.87644338607788, 40.49231439828873, 39.838377088308334, 39.9737524241209, 39.35485303401947, 38.245707750320435, 37.4605368822813, 36.769874542951584, 39.92820426821709, 38.64687882363796, 38.78124721348286, 37.892144322395325, 38.19876506924629, 39.72133196890354, 38.2524523884058, 38.12696412205696, 39.273898378014565, 37.89440140128136, 42.64324977993965, 49.25609193742275, 51.573325395584106, 49.57055926322937, 46.84664502739906, 49.21183951199055, 53.59585426747799, 51.58131256699562, 47.69468732178211, 48.57815891504288, 45.5735157430172, 44.263456240296364, 38.79127487540245, 46.59933529794216, 54.277416095137596, 60.619176998734474, 49.275421500205994, 46.605289578437805, 57.58925758302212, 54.565284848213196, 55.879550725221634, 52.70668298006058, 53.172150403261185, 53.37677702307701, 58.87004345655441, 59.204178526997566, 59.434145987033844, 36.07519581913948, 3.9282536739483476, 1.3344184518791735, 0.9089166310150176, 0.14134266326436773, 2.1934494003653526, 53.2315868139267, 69.22824963927269, 58.965220749378204, 43.61518442630768, 23.013978078961372, 38.80765579640865, 52.50653252005577, 63.07516761124134, 14.828642550855875, 0.26053269335534424, 0.026296635514881928, 0.023944754684634972, 0.035748040172620676, 0.05087243094749283, 0.024932879787229467, 0.04750595260702539, 0.0176501864916645, 0.041130625759251416, 0.12049641038174741, 0.14296747685875744, 0.21685092011466622, 0.08665760818985291, 0.1131400496524293, 0.21229175850749016, 0.25294640043284744, 0.24487011192832142, 0.24519695376511663, 0.29771945730317384, 0.18321228999411687, 0.17633440671488643, 0.2773667697329074, 0.27006148360669613, 16.66753202676773, 67.86726146936417, 60.059501230716705, 46.847496181726456, 47.35190771520138, 45.80543629825115, 54.95774298906326, 59.946909472346306, 66.8323566019535, 36.70803666114807, 1.071982802823186, 3.7039030250161886, 9.045839253813028, 12.400773279368877, 3.3508338080719113, 56.626244857907295, 57.95955151319504, 60.01434825360775, 51.11725486814976, 58.355475068092346, 53.97038497030735, 56.00152038037777, 55.544157922267914, 56.54757387936115, 53.4223859757185, 52.800518944859505, 49.47386585175991, 47.81805910170078, 41.78876683115959, 41.34561561048031, 40.865385979413986, 41.290089190006256, 39.57693591713905, 40.9007278829813, 40.303950905799866, 40.597743541002274, 38.471320644021034, 39.80305418372154, 38.41701775789261, 40.24342015385628, 39.8051592707634, 41.95516750216484, 38.339323326945305, 41.41531527042389, 40.40209203958511, 42.458921670913696, 41.38727277517319, 38.833125829696655, 38.855172246694565, 41.48903511464596, 40.82266107201576, 39.87232446670532, 38.818941190838814, 40.04643492400646, 42.39645682275295, 40.593654960393906, 42.63828344643116, 41.50798849761486, 42.34578654170036, 42.31382645666599, 41.81838244199753, 44.0280968695879, 41.351949870586395, 42.36641563475132, 41.84611715376377, 44.73415978252888, 42.676532194018364, 42.78866037726402, 41.625516191124916, 41.52194894850254, 39.600468054413795, 41.064483895897865, 40.18471710383892, 48.569556176662445, 54.74292151629925, 56.41277231276035, 54.97135005891323, 58.153477907180786, 53.914539366960526, 43.12557689845562, 43.130125254392624, 45.91881841421127, 46.864063292741776, 45.57073049247265, 43.12266245484352, 42.18344025313854, 43.00255469977856, 43.69077757000923, 43.398607447743416, 41.01107016205788, 40.321426168084145, 42.979581132531166, 41.1191363632679, 42.867399752140045, 42.573021948337555, 42.221225425601006, 42.073869332671165, 41.66609801352024, 41.43726669251919, 40.1788692176342, 38.120451271533966, 42.2378571331501, 40.95650129020214, 41.930149644613266, 39.83676217496395, 41.54022216796875, 43.50319683551788, 41.37981377542019, 40.90911403298378, 42.34826780855656, 40.666937828063965, 44.86676126718521, 52.39556707441807, 54.548330157995224, 51.60265602171421, 47.245110645890236, 51.95630304515362, 54.60772097110748, 54.4939398765564, 50.28284624218941, 50.92235952615738, 47.29894995689392, 46.07680253684521, 40.16743183135986, 49.41200137138367, 56.45306535065174, 66.05014577507973, 48.10275882482529, 47.709688916802406, 58.763113394379616, 55.36843255162239, 57.4091662466526, 55.6533108651638, 52.65794299542904, 54.272742345929146, 59.92096446454525, 60.46879626810551, 60.80451965332031, 38.9485028386116, 5.815649684518576, 2.4261961737647653, 2.461467068642378, 0.4308610473526642, 2.7286276454105973, 58.04375879466534, 73.65419134497643, 64.7204527258873, 50.08374832570553, 34.46568198502064, 51.381291300058365, 60.564855113625526, 73.22264850139618, 19.937178678810596, 0.40757390786893666, 0.2453360173967667, 0.18762746010906994, 0.1773575463448651, 0.13158210029359907, 0.21141773118870333, 0.18712464021518826, 0.21156337024876848, 0.1409779125242494, 0.16294756176648661], [0.04830119723919779, 0.05631997300952207, 0.048521273711230606, 0.039123479946283624, 0.006753793404641328, 0.05954391075647436, 0.021038912564108614, 0.11118260546936654, 0.018667941840249114, 0.05700845598767046, 0.08516750924172811, 0.06233316147699952, 0.060960644696024247, 6.117367744445801, 46.134639233350754, 52.280030474066734, 36.83757930994034, 22.647761330008507, 28.065088838338852, 41.029012799263, 52.86442771553993, 55.14602288603783, 33.47379460930824, 0.38744825811591, 0.7377468596678227, 2.8366449242457747, 12.634931914508343, 1.418864883016795, 36.52464710175991, 58.0478435754776, 54.35001119971275, 52.092198953032494, 56.56688064336777, 52.49586649239063, 49.879801869392395, 49.05329301953316, 48.34222577512264, 43.26422765851021, 40.588947013020515, 38.40188317000866, 36.06739863753319, 36.82526037096977, 36.46537408232689, 36.40658363699913, 37.50331498682499, 36.27454072237015, 36.19442202150822, 35.75412064790726, 35.76868146657944, 35.163107961416245, 36.246764212846756, 35.11596389114857, 36.23189941048622, 36.13324150443077, 36.94879174232483, 36.01971499621868, 36.49656280875206, 35.70732615888119, 38.44151124358177, 37.10342064499855, 36.53736501932144, 37.124623507261276, 37.016044333577156, 37.270159497857094, 36.6988829523325, 33.57072740793228, 37.76354782283306, 37.870732471346855, 36.97895832359791, 37.904706448316574, 38.86650323867798, 37.64039643108845, 37.33616955578327, 38.37372288107872, 38.90494577586651, 37.11448185145855, 37.88755036890507, 37.044341415166855, 36.83879904448986, 36.48636415600777, 36.007559448480606, 38.20506513118744, 34.39306028187275, 34.831986129283905, 36.93377494812012, 36.767370477318764, 44.61445480585098, 52.60470785200596, 52.98072807490826, 49.689302891492844, 52.17295601963997, 48.83205369114876, 40.02060391008854, 38.21038104593754, 39.287516847252846, 41.82382754981518, 40.06788857281208, 41.82893827557564, 37.08974897861481, 36.13526299595833, 38.036054000258446, 39.25053343176842, 38.48216526210308, 37.36993834376335, 38.12956318259239, 40.56247763335705, 38.49668808281422, 37.2664774954319, 37.76111215353012, 38.03132325410843, 37.448696717619896, 36.388348415493965, 36.10332190990448, 37.106031104922295, 36.988431215286255, 38.617297410964966, 37.785408049821854, 36.67909361422062, 36.525380462408066, 37.33740068972111, 36.52005694806576, 35.304992347955704, 35.43391942977905, 34.43068966269493, 41.37096405029297, 47.34118469059467, 49.361456483602524, 47.26925075054169, 49.54375170171261, 48.8633032143116, 45.234520733356476, 49.58329617977142, 48.69416669011116, 46.58162444829941, 41.22524946928024, 40.80260194838047, 36.90896987915039, 41.58990070223808, 48.929594457149506, 53.83542001247406, 56.50571912527084, 45.9086349606514, 54.80043902993202, 54.971730038523674, 56.42346873879433, 53.84266622364521, 55.16321696341038, 56.34344503283501, 56.140957698225975, 56.74877688288689, 57.034388557076454, 29.52056083828211, 2.3573569301515818, 0.5415056773927063, 0.2829171437770128, 0.055332486153929494, 2.930602007545531, 51.41152247786522, 61.77691027522087, 52.64668419957161, 38.13902847468853, 29.389049895107746, 37.86773443222046, 45.33798158168793, 50.49329034984112, 11.191779803484678, 0.18968694959767163, 0.08179875992937014, 0.10625552415149286, 0.027835673536174, 0.060585696846828796, 0.11037485193810426, 0.014749775036762003, 0.057190308143617585, 0.08685101187438704, 0.049227145209442824, 0.09252264542737976, 0.06470392996561714, 0.0805615255376324, 0.01715860271360725, 0.062369875522563234, 0.13435514993034303, 0.02974348473799182, 0.12331084959441796, 0.022226940709515475, 0.0622869553626515, 0.028322043726802804, 0.0952106672048103, 0.08067631351877935, 7.651077546179295, 53.67435045540333, 56.73122942447662, 43.03655527532101, 28.848563097417355, 34.95197609066963, 47.6903023570776, 56.36111408472061, 60.011866986751556, 36.53879754245281, 0.23318303748965263, 1.0946342186070979, 3.7917961087077856, 12.430422138422728, 1.8587303487583995, 41.25176064670086, 60.71364752948284, 56.03994391858578, 54.14207875728607, 57.15798832476139, 53.74793730676174, 51.97371371090412, 51.08709588646889, 50.76317846775055, 46.58577762544155, 43.667268231511116, 40.7226238399744, 38.48246544599533, 38.11877176165581, 38.6035231500864, 37.90783368051052, 39.14432913064957, 37.75162026286125, 38.4954759478569, 36.06813199818134, 37.52534240484238, 37.70766422152519, 36.90397694706917, 37.31438532471657, 36.118255108594894, 37.908745631575584, 39.133693501353264, 36.818937510252, 38.74004602432251, 39.277766570448875, 38.60074169933796, 38.79832349717617, 38.631204664707184, 39.220887422561646, 38.3051023632288, 38.01423937082291, 38.78181338310242, 35.83377957344055, 39.17399413883686, 39.59895573556423, 38.54800432920456, 40.49101106822491, 39.369888827204704, 39.69220653176308, 39.59294445812702, 39.86066669225693, 40.67536577582359, 39.86594840884209, 39.57038126885891, 39.709632396698, 39.86437529325485, 37.38164931535721, 39.64040391147137, 38.37945677340031, 38.202747255563736, 37.02897123992443, 39.086393639445305, 39.71357278525829, 47.47872591018677, 52.60766789317131, 55.52085377275944, 51.43364489078522, 52.46084377169609, 50.098426938056946, 42.111445516347885, 41.96747504174709, 42.64186665415764, 43.04910980165005, 43.25488016009331, 42.85476543009281, 40.65668597817421, 39.68352399766445, 38.97665552794933, 39.824314042925835, 40.875280648469925, 38.826882764697075, 37.89790481328964, 41.10606126487255, 39.63071063160896, 38.90575133264065, 37.521310821175575, 40.01347929239273, 38.50974798202515, 39.01396952569485, 38.51879149675369, 39.068599194288254, 39.10978138446808, 40.94534508883953, 40.98751902580261, 39.44902718067169, 37.90206179022789, 39.81816977262497, 37.859241887927055, 37.137717604637146, 36.85916215181351, 35.95501206815243, 42.255921363830566, 50.079697743058205, 51.410086154937744, 49.4662244617939, 50.128654316067696, 49.96788874268532, 47.8883021324873, 51.59925140440464, 50.839991346001625, 49.45877306163311, 44.52437303960323, 44.72830429673195, 39.918393194675446, 42.12734766304493, 51.3235229998827, 55.79978160560131, 59.133851900696754, 50.020709708333015, 55.96462815999985, 57.70549334585667, 59.01507027447224, 55.783013105392456, 54.99478720128536, 57.30326592922211, 58.378368839621544, 58.63308437168598, 57.39348828792572, 33.31177890300751, 2.7749500097706914, 0.8449891582131386, 0.39801121631171554, 0.15592855168506503, 2.8935038857162, 54.92094196379185, 67.01733827590942, 59.328937232494354, 43.8672249019146, 31.514093466103077, 41.02221496403217, 51.38137109577656, 58.983991742134094, 15.038345698267221, 0.2108226326527074, 0.0044586043077288195, 0.04205492987239268, 0.047472953010583296, 0.08323384347022511, 0.08544260112103075, 0.026001479673141148, 0.10249791172100231, 0.010768518259283155, 0.016343550159945153, 0.15911865863017738, 0.17725863290252164, 0.17487587872892618, 0.17872666037874296, 0.1645456877304241, 0.37427587900310755, 0.1052019045164343, 0.20278478739783168, 0.13357209507375956, 0.188041444926057, 0.17004964785883203, 0.17597154102986678, 0.1677313566324301, 8.038850538432598, 60.832022577524185, 65.15312790870667, 49.342214316129684, 31.706469543278217, 38.43104660511017, 53.92200976610184, 60.015852972865105, 66.60286411643028, 40.54047681391239, 1.0645189345814288, 2.5413907924667, 8.64214226603508, 14.809939954429865, 1.9845550158061087, 45.14727741479874, 64.19133871793747, 57.50898689031601, 56.39058530330658, 59.956203773617744, 56.28335885703564, 53.84930446743965, 54.030843526124954, 53.0734620988369, 47.002337872982025, 44.486994445323944, 43.10411185026169, 39.60607275366783, 40.759250074625015, 41.099229231476784, 41.432383954524994, 41.22136987745762, 40.42827643454075, 40.32647989690304, 38.05099479854107, 39.90428075194359, 39.45948041975498, 38.4653739631176, 39.566733464598656, 38.091671615839005, 40.569302067160606, 41.2140666693449, 38.66556242108345, 40.41900873184204, 40.80032207071781, 41.710331439971924, 40.97208425402641, 41.255735233426094, 41.431905180215836, 41.18515022099018, 39.955961778759956, 40.906545370817184, 37.28647582232952, 40.64034305512905, 42.93742999434471, 40.317086800932884, 42.9651153087616, 40.90111546218395, 41.33623771369457, 41.36233851313591, 40.97606644034386, 42.657761201262474, 40.99511481821537, 43.197510838508606, 42.36418515443802, 43.77827167510986, 39.46148291230202, 40.555744394659996, 42.621678337454796, 40.02056211233139, 39.61715295910835, 42.620048224925995, 40.35055160522461, 50.06623886525631, 54.595219641923904, 56.40350081026554, 52.32267178595066, 55.40910176932812, 51.265028938651085, 46.0844287276268, 43.46382714807987, 43.19627210497856, 46.36817470192909, 45.887082517147064, 46.64430968463421, 42.358675450086594, 41.61312885582447, 41.34658455848694, 41.51048116385937, 42.697138488292694, 41.7582468688488, 41.58189073204994, 43.65692138671875, 41.61252848803997, 40.85166871547699, 40.69404177367687, 41.38118550181389, 40.225306525826454, 40.35159274935722, 39.66188035905361, 41.157765090465546, 41.060368716716766, 43.58748771250248, 42.300546169281006, 41.22714936733246, 40.82365661859512, 41.736941412091255, 40.884559750556946, 40.110666677355766, 38.81768345832825, 38.18895019590855, 45.11059798300266, 52.9651603102684, 53.05374875664711, 51.32408916950226, 51.56673274934292, 49.449653550982475, 49.19415146112442, 53.458320647478104, 53.79928395152092, 51.40766568481922, 46.320335268974304, 46.8784911185503, 41.911713033914566, 45.76476328074932, 53.68202604353428, 56.55329257249832, 60.592810213565826, 48.140118420124054, 59.76822026073933, 59.38312612473965, 60.02690277993679, 56.520067155361176, 57.693778574466705, 58.7883098423481, 59.89703334867954, 60.57123877108097, 59.715292900800705, 35.186176523566246, 4.05888662673533, 1.3872099691070616, 2.4082354875281453, 0.34323763044085354, 3.0470417719334364, 59.16923940181732, 72.05355003476143, 64.50198724865913, 53.58470566570759, 40.673997849226, 48.4892550855875, 61.402588561177254, 69.64833989739418, 19.250071048736572, 0.32084543199744076, 0.16647116019157693, 0.2593321952736005, 0.13651962362928316, 0.10444266517879441, 0.19553355930838734, 0.07611825771164149, 0.18384823633823544, 0.18640460853930563, 0.13242170680314302], [0.0613472999248188, 0.04727200910565443, 0.08562053844798356, 0.08292394486488774, 0.030844998873362783, 0.024115207452268805, 0.013148259313311428, 0.018217901633761358, 0.041606557642808184, 0.0262766346349963, 0.01551869847389753, 0.07541997838416137, 0.06831274178694002, 2.5878508994355798, 39.82547678053379, 53.76532897353172, 34.08604435622692, 23.399676382541656, 34.094966277480125, 38.75878281891346, 48.67770217359066, 52.80821733176708, 42.24245868623257, 2.7758631482720375, 1.071413664612919, 1.2097566411830485, 5.688648149371147, 0.30971476051490754, 23.712688386440277, 57.1839789301157, 55.56507959961891, 54.43570800125599, 52.766845151782036, 51.79899908602238, 48.18923458456993, 46.78503133356571, 42.03321531414986, 37.04417422413826, 36.77359074354172, 36.586967557668686, 37.07856997847557, 36.601843759417534, 36.087385565042496, 35.27981489896774, 37.50239163637161, 40.4374947398901, 39.912457913160324, 38.60856547951698, 40.26613153517246, 39.84896332025528, 39.34326745569706, 39.43241447210312, 39.59904693067074, 37.79026038944721, 37.70585551857948, 36.84406936168671, 38.22370693087578, 37.35825017094612, 37.71932199597359, 37.68024869263172, 37.81459428369999, 37.5465452671051, 38.28209839761257, 35.73821470141411, 36.71898767352104, 36.88192293047905, 37.14998334646225, 37.668127343058586, 37.19860553741455, 37.22652643918991, 39.045815616846085, 37.52116642892361, 37.421486377716064, 37.14613415300846, 36.138321831822395, 37.29801580309868, 36.62049315869808, 36.184952929615974, 38.55182692408562, 36.47931553423405, 38.13877008855343, 36.959309577941895, 37.16609828174114, 35.18109239637852, 35.6033219397068, 37.423253282904625, 46.78514152765274, 51.587764620780945, 53.141828030347824, 52.112968638539314, 51.97100065648556, 46.930339336395264, 40.79869195818901, 40.342803820967674, 40.350179225206375, 42.29452349245548, 42.85173699259758, 41.075537502765656, 37.88859151303768, 36.1150860786438, 39.15480136871338, 36.86741530895233, 38.2353875041008, 38.31415727734566, 39.3306103348732, 38.49294528365135, 40.485220178961754, 39.70666475594044, 37.71747149527073, 38.34903560578823, 39.401704519987106, 36.32079944014549, 37.5345379114151, 39.05423976480961, 37.7682101726532, 36.82928815484047, 37.37764433026314, 37.390624433755875, 36.859325543046, 37.692351043224335, 38.26208487153053, 36.140293926000595, 35.77873952686787, 36.09211631119251, 36.361989229917526, 43.11712995171547, 51.147033870220184, 49.68924209475517, 41.00418493151665, 43.685507252812386, 45.82934461534023, 47.28917308151722, 51.31833627820015, 47.41346821188927, 44.91226762533188, 42.11049936711788, 40.796833857893944, 35.15369586646557, 42.12420903146267, 44.93135020136833, 53.59122611582279, 52.85778567194939, 53.29185537993908, 56.08321599662304, 53.216072246432304, 56.02651163935661, 57.165770307183266, 54.6730774641037, 56.64426349103451, 57.90702313184738, 52.12250612676144, 24.284730590879917, 1.140596552286297, 0.5347716668620706, 0.2026897034374997, 0.1771299444953911, 2.8121189028024673, 54.60307002067566, 63.42049688100815, 48.31894062459469, 36.97499893605709, 28.075306490063667, 33.226093500852585, 46.65563307702541, 45.60427889227867, 4.00072599761188, 0.058317882794654, 0.04953833886247594, 0.01384086399411899, 0.09087071375688538, 0.03081250764807919, 0.04634269549569581, 0.04864367612753995, 0.05569630549871363, 0.08051973520196043, 0.045028374224784784, 0.053529349315795116, 0.07079406059347093, 0.13178678462281823, 0.03936862987757195, 0.051098348121740855, 0.04579422980896197, 0.021249287310638465, 0.11125003700726666, 0.03518623438139912, 0.03238292738387827, 0.015504265556955943, 0.08329412812599912, 0.02654740535945166, 3.241534810513258, 47.05052688717842, 59.51765790581703, 40.667238011956215, 24.676231183111668, 36.24598145484924, 43.346417248249054, 52.034670040011406, 56.931220293045044, 46.9169070571661, 2.319333557970822, 1.1019040597602725, 2.091904361732304, 10.21355839446187, 0.8922156959306449, 27.137530110776424, 61.294963136315346, 57.55918599665165, 56.62202708423138, 54.03178207576275, 52.94265791773796, 50.999643579125404, 49.89808268845081, 45.083923414349556, 40.55963158607483, 39.08501051366329, 38.74350383877754, 39.5317867398262, 37.498227059841156, 39.059236496686935, 37.89212912321091, 39.49047155678272, 39.663092494010925, 40.51775023341179, 39.9965626001358, 41.41933165490627, 39.49968986213207, 40.361704006791115, 41.03388033807278, 40.50062455236912, 39.08039376139641, 38.03496725857258, 39.085698276758194, 39.99636121094227, 38.73246543109417, 39.810258597135544, 39.00648772716522, 38.66427809000015, 38.29166628420353, 38.74429039657116, 39.183284640312195, 38.372389152646065, 38.49911995232105, 39.93655622005463, 40.334425270557404, 40.03719002008438, 38.52974630892277, 39.97891254723072, 40.70762224495411, 39.62412938475609, 38.40106621384621, 38.61327342689037, 38.49177874624729, 38.6772657930851, 38.703503385186195, 40.57149454951286, 39.29207660257816, 39.90212246775627, 40.14172621071339, 38.27326387166977, 39.04604360461235, 37.02725753188133, 39.619102254509926, 47.508763298392296, 53.92346888780594, 56.07979618012905, 53.308908864855766, 53.27209264039993, 48.792235627770424, 42.463276237249374, 43.140297308564186, 42.92955681681633, 43.3450873196125, 43.55302736163139, 43.212181851267815, 39.633001908659935, 38.962774872779846, 40.58549299836159, 38.69470685720444, 40.18898047506809, 39.500875398516655, 39.5753476023674, 40.339099019765854, 42.17959485948086, 40.76250270009041, 40.36219038069248, 40.55518202483654, 42.19113104045391, 38.41234780848026, 37.537646144628525, 39.61357355117798, 39.76998455822468, 38.43890458345413, 39.64270658791065, 38.15436825156212, 38.7194587290287, 39.82861541211605, 39.72877956926823, 38.497201055288315, 37.23429322242737, 37.327939197421074, 37.81578741967678, 46.77386753261089, 53.773794919252396, 50.01775346696377, 41.56282715499401, 44.21261116862297, 46.620629355311394, 50.69936469197273, 53.82347345352173, 48.65520358085632, 45.9831527620554, 44.56520564854145, 42.94450521469116, 38.25370252132416, 45.07876329123974, 49.5240193605423, 53.964833468198776, 55.899910032749176, 54.14757326245308, 58.22529025375843, 56.26241818070412, 57.88089193403721, 59.41250994801521, 57.777146100997925, 57.63398118317127, 59.29288476705551, 54.25611063838005, 26.669357232749462, 1.403321223333478, 0.6929595535621047, 1.318757354747504, 0.04167828992649447, 2.649482642300427, 57.3875568062067, 68.75153481960297, 55.06532281637192, 43.083193972706795, 29.88629311323166, 38.24472740292549, 54.65765029191971, 54.20094519853592, 7.203108659014106, 0.07422967741149478, 0.055467787096858956, 0.033255091911996715, 0.06373887823428959, 0.02027494574576849, 0.06894007921800949, 0.03560751451004762, 0.025660689170763362, 0.025263530696975067, 0.030029465779080056, 0.18718249804805964, 0.1733855571364984, 0.2713978540850803, 0.21814902545884252, 0.09442807990126312, 0.14980182575527579, 0.12087713956134394, 0.17193100706208497, 0.08106530280201696, 0.07833714567823336, 0.1327940126066096, 0.10215659058303572, 0.1386777000152506, 4.1354539431631565, 52.61651001870632, 68.1803722679615, 48.30020383000374, 32.49634265899658, 44.08298872411251, 50.79776041209698, 57.80995354056358, 63.30637760460377, 52.78554014861584, 3.6784973507747054, 2.3613984882831573, 3.6174479266628623, 8.733666054904461, 2.2753397561609745, 28.216750100255013, 64.35046657919884, 58.22100788354874, 59.65921550989151, 54.03970085084438, 58.05186375975609, 51.99568033218384, 52.221650406718254, 47.20206655561924, 41.32711060345173, 41.48823715746403, 40.75551487505436, 41.966452896595, 39.79389287531376, 40.95495477318764, 38.916193172335625, 40.754549726843834, 44.103469625115395, 44.200189635157585, 42.411431819200516, 43.90519626438618, 44.59134824573994, 42.93998345732689, 43.78581807017326, 44.67764541506767, 41.78983837366104, 40.05450189113617, 41.68534778058529, 43.025988042354584, 42.43200771510601, 41.45269386470318, 41.92062735557556, 41.24486781656742, 41.278401017189026, 40.54105818271637, 40.90686835348606, 40.22153712809086, 41.467019096016884, 42.40511275827885, 41.63254961371422, 42.14494451880455, 40.22074297070503, 41.615963503718376, 41.250761300325394, 41.56632676720619, 39.93504390120506, 39.28391844034195, 40.041506588459015, 40.027348548173904, 40.980223417282104, 44.96393345296383, 42.658353969454765, 43.132063150405884, 42.39150948822498, 41.56892202794552, 41.02030746638775, 39.35056686401367, 41.5852877497673, 50.47997586429119, 55.89326038956642, 56.712511628866196, 56.13873861730099, 55.92504568397999, 50.75888089835644, 44.38624665141106, 45.420824736356735, 45.28765328228474, 45.9012595564127, 46.7084426432848, 45.139575228095055, 43.27382594347, 40.26160217821598, 44.41188007593155, 39.8678483068943, 41.815490797162056, 40.905002653598785, 41.5081100910902, 40.91672882437706, 44.75690536201, 43.15979406237602, 41.19776174426079, 43.07575777173042, 43.48507560789585, 40.83913318812847, 40.25731980800629, 42.53520257771015, 41.262578666210175, 41.92897170782089, 40.61343289911747, 40.04635892808437, 39.60139900445938, 41.22516207396984, 42.39643022418022, 40.24153545498848, 39.194277450442314, 39.42017152905464, 40.081491842865944, 48.63720394670963, 57.110065296292305, 52.22349710762501, 43.04897300899029, 44.55541357398033, 46.59446395933628, 49.257748648524284, 55.740436390042305, 52.58385457098484, 48.191905841231346, 47.43410870432854, 45.14567390084267, 40.40629081428051, 47.18302957713604, 51.81280754506588, 55.76601281762123, 56.1842829734087, 55.099938958883286, 61.15337893366814, 57.40991860628128, 59.14592765271664, 60.430342331528664, 57.61091262102127, 61.01430259644985, 62.324286103248596, 57.32210911810398, 29.931909665465355, 2.435204777866602, 2.0426915399730206, 2.26052553858608, 0.4514790081884712, 3.4738640813156962, 62.27311424911022, 73.49188685417175, 62.924308106303215, 49.61753614246845, 36.575689762830734, 47.24232919514179, 60.629254058003426, 64.8821796476841, 9.606659710407257, 0.17984485428314656, 0.2107481358689256, 0.1487351962714456, 0.23812243103748187, 0.12727848981739953, 0.13593151612440124, 0.2707642677705735, 0.14214764116331935, 0.2661660098237917, 0.19838514301227406], [0.0628816605603788, 0.06887513387482613, 0.04752466586069204, 0.023804570409993175, 0.023601474276802037, 0.04509979480644688, 0.050407668386469595, 0.040927321824710816, 0.08018446998903528, 0.020429830110515468, 0.032696440248400904, 0.04187014252238441, 0.04015323211206123, 1.0611171671189368, 28.101475685834885, 48.96876275539398, 38.53008069097996, 18.95885657519102, 24.66813001781702, 36.14618360996246, 48.29829253256321, 52.356949746608734, 50.408478900790215, 6.277754288166761, 0.510198682313785, 0.35711314994841814, 6.0782963410019875, 0.11827856884337962, 9.069447387009859, 51.30168177187443, 56.60897098481655, 58.7597543746233, 54.831148982048035, 50.77999256551266, 46.62858232855797, 43.78966726362705, 40.37643201649189, 40.59738256037235, 41.97995737195015, 41.511457711458206, 39.412799924612045, 40.07067762315273, 40.05875006318092, 42.731895223259926, 43.857911601662636, 46.73016607761383, 44.245878383517265, 45.76838828623295, 46.94222889840603, 46.07916980981827, 45.048490315675735, 45.334557965397835, 44.49856862425804, 44.37931962311268, 43.48456263542175, 42.02308125793934, 38.44724893569946, 35.63577979803085, 36.64289675652981, 37.49116703867912, 37.76082716882229, 37.63168349862099, 36.321984976530075, 35.47950938344002, 36.21145650744438, 36.77613280713558, 38.009136244654655, 38.95796053111553, 39.11588005721569, 37.764015197753906, 38.91065686941147, 37.89848618209362, 37.41430476307869, 37.30634495615959, 37.16878093779087, 37.887394577264786, 36.340687572956085, 37.22251005470753, 35.73931284248829, 39.152217507362366, 37.710308879613876, 37.70886115729809, 36.2967125326395, 35.20924508571625, 36.57639652490616, 36.20041809976101, 48.23367320001125, 52.81205892562866, 51.70267045497894, 52.24577911198139, 51.89074136316776, 47.698506116867065, 41.67337842285633, 39.89149063825607, 41.55119977891445, 41.885969415307045, 42.14600466191769, 39.62502993643284, 37.98007920384407, 37.68398769199848, 38.55782300233841, 39.82692450284958, 38.39665085077286, 36.098686158657074, 35.63445746898651, 37.793520614504814, 39.62168991565704, 39.58305358886719, 36.92047566175461, 37.79772698879242, 37.527698278427124, 37.35711023211479, 36.21720179915428, 36.36982060968876, 37.19344161450863, 36.5362174808979, 36.71012654900551, 35.343693271279335, 36.177474930882454, 38.10874029994011, 37.0655632764101, 38.631155267357826, 35.805243104696274, 36.414339020848274, 36.687681153416634, 38.01489673554897, 49.52124930918217, 50.87760552763939, 46.77063390612602, 49.110016375780106, 46.477878615260124, 46.36297658085823, 48.9752110093832, 51.09601780772209, 46.64673775434494, 46.00456461310387, 42.18015342950821, 38.800462782382965, 39.667944833636284, 43.917306214571, 42.52438835799694, 44.45672906935215, 45.67843571305275, 49.5081552118063, 50.4250194132328, 50.6115286052227, 52.4265506118536, 53.43948505818844, 53.42249996960163, 57.23803862929344, 52.212268710136414, 16.266740933060646, 0.4773666331311688, 0.4197215591557324, 0.7690421584993601, 0.07717819302342832, 4.149688454344869, 54.426641687750816, 59.3306927382946, 48.20252247154713, 27.021562233567238, 29.69209123402834, 37.232773303985596, 48.05475980043411, 41.53688594698906, 2.617108142003417, 0.0673482392448932, 0.15988826577086002, 0.04536474894848652, 0.08453073911368847, 0.05201691914408002, 0.0458135442022467, 0.024634313776914496, 0.05516952536709141, 0.054099040426081046, 0.060419307337724604, 0.03409231983823702, 0.03710009223141242, 0.03438245505094528, 0.019915286138711963, 0.06155479328299407, 0.03240112855564803, 0.05452528552268632, 0.04368381414678879, 0.016222824997385032, 0.08806521742371842, 0.04521846421994269, 0.028182256501168013, 0.05977149776299484, 1.1576891038566828, 34.63225744664669, 56.75952270627022, 44.12246100604534, 24.68586176633835, 31.56312793493271, 42.08606667816639, 51.70894771814346, 55.75513020157814, 54.26860436797142, 6.659162621945143, 0.5773957609198987, 1.2161697470583022, 6.858127070590854, 1.3459462020546198, 9.995917472988367, 56.72258488833904, 57.54510395228863, 58.91703553497791, 54.698327109217644, 53.7721686065197, 48.94514702260494, 47.41205848753452, 41.76224805414677, 42.53923036158085, 42.076236605644226, 42.884403839707375, 41.13556668162346, 40.25420777499676, 40.35005383193493, 43.7361965328455, 46.210289373993874, 46.853773444890976, 46.58449709415436, 47.11634315550327, 48.2783892005682, 47.983072847127914, 47.970081344246864, 48.084827587008476, 45.710323601961136, 46.42675615847111, 44.93001267313957, 43.83207678794861, 39.42463628947735, 37.130581587553024, 38.549839630723, 39.191138818860054, 38.48733678460121, 38.753041326999664, 37.67019063234329, 38.15657593309879, 37.89068900048733, 38.60498607158661, 38.700733333826065, 39.554308131337166, 39.6068175137043, 40.013646483421326, 41.35079473257065, 40.13028882443905, 39.38584417104721, 40.23849181830883, 39.73738990724087, 38.71576152741909, 39.04532924294472, 39.51588839292526, 38.447944298386574, 41.164323538541794, 38.71744103729725, 41.177539229393005, 38.41279238462448, 37.06253483891487, 38.13833311200142, 40.31638763844967, 49.26759012043476, 53.06095317006111, 53.79362225532532, 52.874763160943985, 52.96769097447395, 49.23312596976757, 44.021397829055786, 42.71097354590893, 45.235197097063065, 44.904580637812614, 44.39221993088722, 44.25987683236599, 38.64094354212284, 40.48067182302475, 38.25746811926365, 40.71912422776222, 40.813058987259865, 36.83145023882389, 39.05028037726879, 40.03491774201393, 40.97008936107159, 40.70082440972328, 40.12255243957043, 39.43147212266922, 38.77686604857445, 39.4359976798296, 38.843913450837135, 39.78071138262749, 39.51484724879265, 39.10103805363178, 38.36400680243969, 37.892436906695366, 37.27315753698349, 39.18042339384556, 39.16131801903248, 39.25451181828976, 37.70571872591972, 38.306386694312096, 38.22892785072327, 40.11156722903252, 50.78773275017738, 52.784012630581856, 47.92760342359543, 48.99804398417473, 46.0819398611784, 46.2376669049263, 52.010754123330116, 53.38625371456146, 49.05301183462143, 46.35663852095604, 44.29357722401619, 41.06132246553898, 41.88450649380684, 45.54280199110508, 45.52572190761566, 46.5038388222456, 49.31514836847782, 52.17060014605522, 53.653569370508194, 52.87873774766922, 55.03637596964836, 56.86683274805546, 55.358325093984604, 59.40597049891949, 55.11971689760685, 17.85285372287035, 0.4150872922036797, 1.6996511723846197, 1.1051863711327314, 0.1710175717016682, 4.164879564195871, 59.20744635164738, 63.78445655107498, 55.78723847866058, 38.114174008369446, 37.87752650678158, 43.84879969060421, 53.6612905561924, 49.14129629731178, 4.181025847792625, 0.11236947029829025, 0.06505656143417582, 0.05578889213211369, 0.09058523181010969, 0.08703653395059519, 0.08121333899907768, 0.07294006223673932, 0.07707377284532413, 0.040259752568090335, 0.02250975649076281, 0.11547683519893326, 0.17069473746232688, 0.17644191422732547, 0.14154948497889563, 0.19062622654018924, 0.13025994936469942, 0.17953436938114464, 0.1834603157476522, 0.11489784126752056, 0.06812707870267332, 0.08997723474749364, 0.12454523413907737, 0.12105100991902873, 1.2926050205715, 40.05560003221035, 63.0357751250267, 53.25518734753132, 29.910205230116844, 37.46948920190334, 49.796495139598846, 60.543656051158905, 59.6223346889019, 63.677587285637856, 7.734569991007447, 0.6327653804328293, 3.684456618502736, 10.519266240298748, 1.1684777936898172, 11.057404763996601, 59.782332703471184, 58.94657514989376, 60.857602804899216, 55.82205221056938, 55.202917233109474, 51.46387226879597, 50.350193828344345, 43.990885466337204, 46.00418463349342, 46.50868356227875, 46.56235568225384, 44.186996743083, 43.85722763836384, 42.624019011855125, 46.35995954275131, 49.37032900750637, 48.97851683199406, 48.50016809999943, 49.20608662068844, 51.72937162220478, 50.29290810227394, 50.485356375575066, 50.424590036273, 48.843567073345184, 47.963667288422585, 47.592936381697655, 46.982373744249344, 41.71765744686127, 39.102360382676125, 40.8520182967186, 42.042338624596596, 41.70604147017002, 40.93658655881882, 40.02420611679554, 39.40246067941189, 40.24816609919071, 40.327745229005814, 42.130809277296066, 43.14773730933666, 41.938201412558556, 41.57172627747059, 43.7597780674696, 41.81163400411606, 41.054460033774376, 42.10204862058163, 40.912849232554436, 41.33784882724285, 40.8527934551239, 41.82080291211605, 39.629563093185425, 43.68930324912071, 41.503987312316895, 42.70410731434822, 42.32632398605347, 39.84154611825943, 40.887930169701576, 42.565768137574196, 52.87937991321087, 54.75618660449982, 55.45297421514988, 55.36716341972351, 54.789054840803146, 52.09397725760937, 46.89117483794689, 45.35126946866512, 47.50929906964302, 46.856490299105644, 46.8836360424757, 45.43564774096012, 41.70940048992634, 42.9292718321085, 41.49112120270729, 44.91542525589466, 43.30925904214382, 38.46883177757263, 40.70158436894417, 42.879996076226234, 41.96671508252621, 43.34759898483753, 42.34314188361168, 42.2456581145525, 40.94413675367832, 40.86477041244507, 40.655447244644165, 41.64326883852482, 42.35430188477039, 41.29084154963493, 40.705954134464264, 39.85036924481392, 40.43497547507286, 43.3932763338089, 42.46112175285816, 43.12842294573784, 39.200056940317154, 40.28389938175678, 42.01154127717018, 41.734729930758476, 53.43006916344166, 56.92985236644745, 49.87647704780102, 51.37390449643135, 47.23625332117081, 45.64411215484142, 51.467763260006905, 55.59734746813774, 52.8261561691761, 50.81089250743389, 46.918616965413094, 41.77299007773399, 43.99363271892071, 47.99894459545612, 47.64841340482235, 48.643336817622185, 50.82934431731701, 53.55702795088291, 54.53920304775238, 54.8459529876709, 57.56868928670883, 58.44901844859123, 59.46310043334961, 60.53785376250744, 57.493392527103424, 19.943362846970558, 1.0276236268691719, 2.762639857828617, 2.8784101456403732, 0.16412119410233572, 4.556293711066246, 62.90645286440849, 68.4135353565216, 60.67098341882229, 42.006202563643456, 40.83813764154911, 49.781915321946144, 63.07408086955547, 58.61845135688782, 6.348861772567034, 0.28106014186050743, 0.36859162151813507, 0.13850201881723478, 0.2939207595773041, 0.21217066969256848, 0.11983815507846884, 0.20621578063583001, 0.10925489172223024, 0.10663932582247071, 0.2651918667834252], [0.034385716789984144, 0.05213803393417038, 0.05551645714149345, 0.07838274323148653, 0.06594015503651462, 0.059562839232967235, 0.015523925048910314, 0.04124060091271531, 0.04225171032885555, 0.07005114850471728, 0.0986417791864369, 0.02940200032753637, 0.12042548332829028, 0.32017981458920985, 18.666992336511612, 54.32511493563652, 43.723288625478745, 26.033945828676224, 28.439708836376667, 33.87374974787235, 49.398512095212936, 49.950812458992004, 52.36209087073803, 14.747466556727886, 0.33845781348645687, 0.7867391151376069, 5.335161192342639, 0.305492504267022, 1.4023507316596806, 29.985999763011932, 51.57032735645771, 57.163771614432335, 49.781839326024055, 50.935047045350075, 47.12342597544193, 44.16704781353474, 42.041369676589966, 45.011077523231506, 45.54759353399277, 47.84742392599583, 46.997569128870964, 46.661876142024994, 46.242036670446396, 49.44795124232769, 48.44600200653076, 48.504461869597435, 47.192988842725754, 48.26866552233696, 46.403566002845764, 47.08072766661644, 44.46579918265343, 47.416519448161125, 45.452013462781906, 45.602713376283646, 46.145787835121155, 47.25385017693043, 44.31397072970867, 42.47504040598869, 38.49166855216026, 38.006958961486816, 37.76791758835316, 37.27163001894951, 37.65063688158989, 37.32420779764652, 35.618931502103806, 37.39667750895023, 36.10027827322483, 36.80550143122673, 38.55579011142254, 38.474991247057915, 37.98028439283371, 38.40683810412884, 39.75247509777546, 37.00353920459747, 39.50931094586849, 37.903524711728096, 37.34259881079197, 36.683102399110794, 37.6219180226326, 37.9927933216095, 37.104951962828636, 35.86625263094902, 35.94985194504261, 36.095942705869675, 35.75542777776718, 36.11372195184231, 46.179119646549225, 51.894472762942314, 51.2869955599308, 51.005749851465225, 51.58213332295418, 49.78155814111233, 41.02345749735832, 39.33553107082844, 42.36358478665352, 44.073105454444885, 42.10988000035286, 39.78270627558231, 36.243701577186584, 37.17365987598896, 37.259922847151756, 36.87415614724159, 39.20110948383808, 37.41726100444794, 37.46266096830368, 38.285643607378006, 39.473725855350494, 39.258429408073425, 37.86227412521839, 38.876386508345604, 37.18850947916508, 36.526322811841965, 36.792213544249535, 37.310935109853745, 38.05129878222942, 38.872708305716515, 37.853264808654785, 37.96266853809357, 35.409121960401535, 36.80369272828102, 37.33969196677208, 36.21027857065201, 36.62452474236488, 37.218710258603096, 37.91152708232403, 36.20484486222267, 41.40616916120052, 46.27799034118652, 50.18554486334324, 49.964301735162735, 49.761096239089966, 47.51189813017845, 48.936084508895874, 46.72205351293087, 50.00686325132847, 47.70036041736603, 47.31260642409325, 44.14786644279957, 43.020561933517456, 41.15265056490898, 41.34382210671902, 39.45185802876949, 41.39829978346825, 43.163483664393425, 45.43182134628296, 45.646779611706734, 48.33838418126106, 50.36685973405838, 53.79011884331703, 56.03590853512287, 48.60273219645023, 9.00097506120801, 0.07415377796860412, 0.7347847404889762, 0.4341663949890062, 0.10585311683826149, 4.41189955919981, 62.59488098323345, 59.52269643545151, 51.07242487370968, 36.60722427070141, 23.4347864985466, 41.05403445661068, 47.501422092318535, 38.37372288107872, 2.03568400349468, 0.030938266427256167, 0.02421514320303686, 0.05460610911541153, 0.015036227341624908, 0.0176042401290033, 0.08684375367010944, 0.022156776212796103, 0.0739534426247701, 0.04382434723083861, 0.038501541639561765, 0.005443927339001675, 0.049186256583197974, 0.05150923447217792, 0.017124170772149228, 0.05448727271868847, 0.09591583366272971, 0.004921305553580169, 0.05651079773087986, 0.0529379874933511, 0.09164214658085257, 0.06372452509822324, 0.01819864846765995, 0.06915160614880733, 0.3189908940112218, 23.86791955679655, 58.984960690140724, 50.74908122420311, 27.73606449365616, 28.13815701752901, 41.93499818444252, 53.29717889428139, 55.41040509939194, 57.368546426296234, 15.55224247276783, 0.43859493860509247, 0.40769838087726384, 9.563933853060007, 2.3948476184159517, 2.2670858865603805, 33.95112119615078, 54.383525401353836, 56.4447133988142, 50.72010017931461, 53.08997221291065, 48.17872054874897, 47.35094256699085, 44.47157867252827, 46.59555830061436, 47.27539502084255, 48.8314913213253, 47.71785467863083, 47.94641621410847, 48.59985955059528, 51.71088941395283, 50.62121048569679, 51.19777634739876, 49.176387414336205, 49.22358848154545, 47.63385258615017, 49.95802067220211, 46.14604242146015, 47.70356744527817, 48.23142372071743, 48.761255890131, 48.85540343821049, 49.31438460946083, 46.66353665292263, 42.857041507959366, 39.89457607269287, 39.3566807359457, 37.76741601526737, 40.17515681684017, 38.480394557118416, 37.91874669492245, 36.066650077700615, 39.64249759912491, 37.908335253596306, 38.8654050976038, 40.873882323503494, 40.61377488076687, 40.210111141204834, 40.573785826563835, 39.95506502687931, 39.15094457566738, 41.029453575611115, 38.84237453341484, 39.539747312664986, 40.03918871283531, 38.94018888473511, 39.32304114103317, 38.475720807909966, 38.67217406630516, 38.02296370267868, 37.44658783078194, 38.317679688334465, 39.05831694602966, 48.001433461904526, 55.259188413619995, 51.78270936012268, 52.16102845966816, 54.02123384177685, 51.01508215069771, 43.003162667155266, 41.53442367911339, 45.43275989592075, 45.20948767662048, 43.58406789600849, 40.46145625412464, 39.21198830008507, 38.205559104681015, 39.03829202055931, 37.716798931360245, 39.55165967345238, 39.083091616630554, 39.632032960653305, 40.677364468574524, 40.98466157913208, 39.77279640734196, 39.35421086847782, 40.579154938459396, 38.311334028840065, 38.19278039038181, 38.89457233250141, 39.77235563099384, 39.757772013545036, 39.76756028831005, 39.099624529480934, 39.81590509414673, 37.911044508218765, 38.54124069213867, 38.613592609763145, 38.134282529354095, 39.2885085940361, 40.0282870978117, 39.582331627607346, 38.81276272237301, 43.38052801787853, 50.159447863698006, 53.42456705868244, 53.680684715509415, 51.60646341741085, 48.49632650613785, 48.86382378637791, 50.49840867519379, 52.24317245185375, 50.73019243776798, 49.44944076240063, 45.235170498490334, 45.24559713900089, 43.55240419507027, 43.311166539788246, 43.618087470531464, 42.05450177192688, 45.27854137122631, 48.24039123952389, 47.60451816022396, 51.99718125164509, 52.36420355737209, 54.92444537580013, 58.46335127949715, 50.33301115036011, 12.111711390316486, 0.09031434048665687, 3.341601015999913, 2.7525718230754137, 0.3475843893829733, 4.850683389231563, 64.58729267120361, 65.42744278907776, 56.42048589885235, 36.583992317318916, 25.29375694692135, 44.52376887202263, 54.229170083999634, 45.3595682233572, 3.093726304359734, 0.06499882976640947, 0.05967000535747502, 0.054713553545298055, 0.07799143844749779, 0.07631802902324125, 0.10872757353354245, 0.009078063558263239, 0.027123484505864326, 0.02417540119495243, 0.06174174770421814, 0.27544965385459363, 0.22634652152191848, 0.1518039620714262, 0.1295018900418654, 0.17992456094361842, 0.1701986711123027, 0.12501740333391353, 0.09914430222124793, 0.1731817188556306, 0.10264680880936794, 0.19555144506739452, 0.11186970063135959, 0.1631315698614344, 0.4410066216951236, 26.884116008877754, 69.34783682227135, 57.87566341459751, 37.62774311006069, 38.512396439909935, 46.67590118944645, 60.23197017610073, 59.563194662332535, 63.82848098874092, 18.284856341779232, 0.43846310349181294, 3.592492053285241, 12.180193215608597, 2.005256423726678, 2.4259591614827514, 34.80224132537842, 55.843673050403595, 58.387203365564346, 53.941559717059135, 55.73089890182018, 51.21649794280529, 47.84620799124241, 46.26170441508293, 48.857717514038086, 50.675304383039474, 51.89718581736088, 50.85487514734268, 50.40227383375168, 51.63971543312073, 55.40961094200611, 51.36092819273472, 54.57802556455135, 50.88169030845165, 53.656829595565796, 49.412111565470695, 51.10647864639759, 49.803327172994614, 51.25602342188358, 51.3928958773613, 50.97530208528042, 51.77010923624039, 52.97751344740391, 49.14150148630142, 46.6224380582571, 41.52935475111008, 41.184287667274475, 41.181019842624664, 42.54682615399361, 42.039712965488434, 40.93334153294563, 38.95470030605793, 42.362836226820946, 39.568602964282036, 40.888914316892624, 42.58678860962391, 42.21981190145016, 41.497668251395226, 42.91620813310146, 42.54274517297745, 40.887079015374184, 43.66983309388161, 40.64634673297405, 40.64548037946224, 41.94293215870857, 41.04098975658417, 43.67649033665657, 39.87542890012264, 41.09648957848549, 40.33237338066101, 40.46525225043297, 39.298148676753044, 40.61481222510338, 50.35325646400452, 56.904397532343864, 53.53364020586014, 52.600965052843094, 57.893777042627335, 53.53389859199524, 46.74661539494991, 43.50036978721619, 49.0105377137661, 47.848613262176514, 47.136428877711296, 43.51512059569359, 41.5655630081892, 41.588110998272896, 42.00772628188133, 38.867236599326134, 41.80061459541321, 40.583980679512024, 41.70299023389816, 41.78415387868881, 43.88622388243675, 41.535210236907005, 40.96091665327549, 42.905971482396126, 42.16177761554718, 39.90705080330372, 40.050451308488846, 39.77654680609703, 42.70506106317043, 43.70608314871788, 40.79879455268383, 42.391262501478195, 39.46084454655647, 42.09393225610256, 42.01539047062397, 40.22064037621021, 41.15948639810085, 40.770698860287666, 42.83850610256195, 40.82633927464485, 45.88640995323658, 50.58868423104286, 54.669095277786255, 56.933374777436256, 53.37880991399288, 50.59742756187916, 50.751915872097015, 50.02967722713947, 54.61777903139591, 53.241059705615044, 52.72893078625202, 48.6875094473362, 47.863105684518814, 45.46543434262276, 46.9927091896534, 45.16455888748169, 44.80481319129467, 48.58382821083069, 51.8358913064003, 49.06927116215229, 54.34360474348068, 53.13292510807514, 59.54997897148132, 60.823241248726845, 52.926463186740875, 13.476646598428488, 0.1373649892047979, 2.4869874492287636, 2.0512847788631916, 0.5356037034653127, 5.4876940324902534, 71.67468756437302, 69.13203120231628, 62.20045454800129, 47.123342379927635, 36.641745418310165, 53.85504595935345, 60.03889113664627, 54.36446562409401, 4.992250017821789, 0.13987938553327695, 0.14019516936969012, 0.12974730343557894, 0.17744316050084308, 0.15501777321333066, 0.21660498721757904, 0.13889244786696509, 0.16803211939986795, 0.1467058528214693, 0.23211343941511586], [0.03363165022165049, 0.048334207967855036, 0.02523235492844833, 0.010808917068061419, 0.11740945454221219, 0.13166844175430015, 0.06682527004159056, 0.039409191958839074, 0.10365352471126243, 0.014444279222516343, 0.03729864642082248, 0.0605929773155367, 0.08850914047798142, 0.11355564492987469, 10.064792577177286, 49.106319174170494, 46.786053478717804, 28.283717706799507, 21.38549566268921, 34.1854128241539, 42.040476724505424, 51.09538324177265, 49.72792021930218, 30.280457362532616, 0.05799140461022034, 0.7086772914044559, 2.377422940917313, 1.2314781756140292, 0.1997866592137143, 13.019220493733883, 45.289564579725266, 57.01540857553482, 53.101515993475914, 49.540909454226494, 44.23929713666439, 43.541453182697296, 43.784636333584785, 44.64256949722767, 47.05148823559284, 50.71697294712067, 48.08041602373123, 51.27322889864445, 49.40359242260456, 49.884304627776146, 49.36755135655403, 49.503386467695236, 47.892185524106026, 48.480443358421326, 46.06943093240261, 44.16543669998646, 44.5347198843956, 45.69624535739422, 45.19387051463127, 45.13642519712448, 47.165333926677704, 47.17512980103493, 48.49427841603756, 47.28014096617699, 44.353496208786964, 38.94483983516693, 36.34868234395981, 36.904258131980896, 35.281729996204376, 36.70536160469055, 36.325826570391655, 37.025965601205826, 38.31307053565979, 36.29404127597809, 37.28883549571037, 40.0499003380537, 38.938832357525826, 36.96726255118847, 37.762822061777115, 37.81015992164612, 37.82442435622215, 39.94349844753742, 36.93322017788887, 38.361293748021126, 37.04312928020954, 36.96451909840107, 37.55936577916145, 34.95026618242264, 35.91045945882797, 35.611392706632614, 36.22627951204777, 36.31281226873398, 44.77675549685955, 51.84808865189552, 51.49663411080837, 52.44741529226303, 49.429176449775696, 49.159151539206505, 42.898922860622406, 43.082962185144424, 42.851132825016975, 43.00589092075825, 40.68293496966362, 37.53313958644867, 37.31050953269005, 35.908874943852425, 36.748394295573235, 37.33021907508373, 37.25984685122967, 39.23108607530594, 37.38126553595066, 36.615960001945496, 39.001156613230705, 37.53840610384941, 36.31488315761089, 37.4785441160202, 36.203313544392586, 36.84148170053959, 36.52799092233181, 36.646031588315964, 36.86125583946705, 39.40953969955444, 37.936632335186005, 34.39972132444382, 36.03513836860657, 35.73868587613106, 35.779260098934174, 36.787893176078796, 36.705399602651596, 36.30929745733738, 36.281175166368484, 36.01012051105499, 37.059099823236465, 41.70762598514557, 44.50789712369442, 47.23226733505726, 48.030494302511215, 51.73660263419151, 50.511715561151505, 49.63827162981033, 49.53305907547474, 51.483851596713066, 50.83106182515621, 50.04374027252197, 50.12972965836525, 47.90649555623531, 43.04430305957794, 41.35956846177578, 43.54715287685394, 43.529609218239784, 41.41950264573097, 43.08307237923145, 44.89771820604801, 50.05035951733589, 51.83059819042683, 57.43496686220169, 42.44107022881508, 5.345187429338694, 0.009083357854251517, 4.541066503152251, 3.0196794401854277, 0.23905434587504715, 5.516843693330884, 45.769311636686325, 52.81459338963032, 40.744347274303436, 33.88186231255531, 34.75306436419487, 39.401772916316986, 49.4246356934309, 26.951115913689137, 0.9328602149616927, 0.0699173763860017, 0.02595879319414962, 0.002142562484550581, 0.033627375451033004, 0.03884946789185051, 0.03869750944431871, 0.08845583943184465, 0.05314580368576571, 0.0170372207503533, 0.021040625069872476, 0.08841406393912621, 0.040993387810885906, 0.04536445951089263, 0.04130126406380441, 0.06585831099073403, 0.04453915789781604, 0.08543102361727506, 0.028249728857190348, 0.08448641063296236, 0.01108938580728136, 0.04157360999670345, 0.05723183501686435, 0.1286743805394508, 0.10131360730156302, 12.13286105543375, 56.232506185770035, 52.78025083243847, 33.189296275377274, 29.95968997478485, 42.148121148347855, 48.160914704203606, 54.95153032243252, 56.260685473680496, 31.682542227208614, 0.07917448863736354, 0.8256189257372171, 6.468906356021762, 3.8499377388507128, 0.4184746620012447, 17.122346721589565, 46.22382424771786, 57.018680199980736, 54.63567227125168, 51.345413625240326, 46.71405874192715, 45.552719458937645, 44.844528660178185, 47.114416658878326, 49.362588822841644, 52.97322727739811, 51.588896960020065, 51.61009222269058, 50.73015443980694, 50.99512942135334, 50.95761023461819, 51.35050155222416, 49.22072723507881, 50.27666017413139, 48.36987689137459, 45.29882848262787, 46.37073956429958, 47.995224595069885, 46.944326385855675, 47.82567009329796, 49.50143717229366, 49.775767251849174, 51.50082528591156, 48.74821498990059, 44.57958407700062, 40.08017711341381, 38.87659549713135, 39.410254061222076, 36.6097055375576, 37.73565351963043, 37.58785665035248, 37.70225711166859, 40.5662926286459, 37.46111065149307, 38.284716457128525, 40.09986385703087, 40.374695509672165, 39.4280257076025, 39.476195722818375, 38.87666769325733, 39.39292699098587, 42.10009552538395, 39.27200987935066, 40.155831053853035, 39.4677297770977, 39.408392161130905, 39.025904685258865, 37.910888716578484, 39.01379853487015, 36.90068632364273, 38.81636492908001, 38.89098532497883, 46.70367389917374, 53.47402140498161, 52.90627107024193, 52.78723485767841, 50.82897573709488, 52.31451362371445, 43.540123254060745, 44.05598737299442, 44.827266186475754, 45.08394621312618, 41.06604561209679, 40.811824053525925, 39.17283520102501, 38.5468377918005, 39.00696650147438, 39.98050086200237, 40.56719698011875, 39.309529066085815, 39.39324617385864, 39.1108301281929, 40.241634249687195, 38.97916339337826, 38.486637622117996, 39.106775745749474, 39.267381727695465, 37.78560183942318, 39.059981256723404, 38.77751961350441, 39.60035026073456, 41.66024252772331, 39.41535338759422, 38.084227815270424, 36.73545219004154, 37.518137991428375, 37.206866294145584, 37.4110521376133, 37.761792317032814, 39.768369644880295, 38.361396342515945, 38.766659796237946, 37.891707345843315, 44.1553520411253, 47.655982598662376, 50.325753539800644, 49.5169061422348, 53.98943714797497, 51.303308084607124, 51.57596245408058, 50.52322134375572, 53.01027528941631, 52.33182929456234, 52.48780332505703, 52.270299196243286, 48.69407929480076, 45.330081805586815, 44.16073635220528, 45.21904036402702, 44.79367218911648, 43.76607432961464, 45.23944526910782, 48.2027542591095, 51.595311015844345, 54.58364926278591, 59.53384503722191, 45.259979367256165, 6.14502883516252, 0.20311286119977012, 4.224220979958773, 2.4536677496507764, 0.21269232529448345, 5.825743367895484, 53.97990345954895, 60.11451467871666, 50.17610237002373, 42.1230348944664, 40.18008895218372, 45.619006901979446, 54.650556072592735, 35.4561672359705, 1.725046040955931, 0.03854189591947943, 0.0065943643130594864, 0.05088000456453301, 0.035155364748789, 0.03832771209999919, 0.011790774733526632, 0.055268520445679314, 0.08086457411991432, 0.007032259272818919, 0.047266227775253356, 0.16101966990390792, 0.12872564810095355, 0.23817043314920738, 0.21800040296511725, 0.26802235865034163, 0.19199121423298493, 0.23913092067232355, 0.18556691677076742, 0.22881860058987513, 0.14939682092517614, 0.1978531270287931, 0.1297472440637648, 0.17993941874010488, 0.3999008727259934, 14.21602327376604, 64.46310013532639, 58.66384372115135, 39.29393470287323, 33.65678519010544, 45.663012340664864, 53.53341601788998, 60.97673401236534, 60.078845992684364, 37.802035957574844, 0.19808102573733777, 2.5841038255020976, 6.505306027829647, 3.748676022514701, 0.33171555027365685, 16.947472505271435, 47.82176770269871, 57.803471088409424, 58.449862003326416, 53.35951454937458, 49.734151884913445, 45.90573571622372, 47.976761385798454, 49.900503158569336, 52.74311542510986, 54.289510846138, 53.0239013582468, 53.44636648893356, 55.226266980171204, 52.75769144296646, 54.36865299940109, 54.28001515567303, 52.040362134575844, 52.982065603137016, 51.697441935539246, 48.73643562197685, 48.58032859861851, 50.274304300546646, 50.19994609057903, 50.460608303546906, 51.40549220144749, 51.052339151501656, 54.60925228893757, 51.32362559437752, 46.56531572341919, 43.50716382265091, 39.96261902153492, 41.785688996315, 38.45451794564724, 40.17523281276226, 40.435921624302864, 41.31254978477955, 43.039564713835716, 38.93187493085861, 40.05422070622444, 43.01127143204212, 42.50837601721287, 39.804764091968536, 41.84080883860588, 41.448935866355896, 39.444665014743805, 44.52981434762478, 41.28657437860966, 41.93869538605213, 40.70350706577301, 40.91729499399662, 41.39685966074467, 40.20041026175022, 39.75514255464077, 39.29592199623585, 40.9124768525362, 40.91634504497051, 48.08772683143616, 56.91886715590954, 54.401867017149925, 56.3493575155735, 54.124398306012154, 52.44399167597294, 47.01094441115856, 46.98551617562771, 45.579834803938866, 48.489266484975815, 42.86378614604473, 43.75573888421059, 42.58762076497078, 40.17148241400719, 40.32334126532078, 41.24444603919983, 42.40762062370777, 41.873107105493546, 41.27458222210407, 41.53047949075699, 42.92020171880722, 40.9731025993824, 38.71994890272617, 40.07796183228493, 40.024012327194214, 39.66038703918457, 41.1096216738224, 41.344635263085365, 41.968489587306976, 45.286467745900154, 41.34017430245876, 38.59708249568939, 39.79741908609867, 38.13828371465206, 38.74213971197605, 40.48761785030365, 39.23283018171787, 41.269258707761765, 40.124642327427864, 40.36482743918896, 41.05511359870434, 48.32365237176418, 48.917313516139984, 51.34823687374592, 51.42235189676285, 56.433371007442474, 54.7671490162611, 52.78549835085869, 52.1647484600544, 55.29325358569622, 55.253853499889374, 54.44731257855892, 55.5743321031332, 53.12022618949413, 47.287892550230026, 44.99377705156803, 49.39592823386192, 47.75897607207298, 45.65740764141083, 47.01861999928951, 50.762847885489464, 54.722900390625, 58.10704439878464, 60.9304790943861, 48.6292889714241, 7.762848073616624, 0.32833230681717396, 10.789507739245892, 7.9270420130342245, 0.5964797618798912, 5.727823572233319, 56.20208501815796, 66.996219009161, 62.41780288517475, 45.52624627947807, 47.157403752207756, 52.69601695239544, 63.40092793107033, 42.80179247260094, 2.666063765063882, 0.22462321008788422, 0.11808420778834261, 0.09778181556612253, 0.11762530819396488, 0.11716721011907794, 0.11777968975366093, 0.19322601438034326, 0.199274992919527, 0.1722130083362572, 0.15811122284503654], [0.036309237402747385, 0.02211526603787206, 0.053214867948554456, 0.09315661023720168, 0.04342802923929412, 0.01910114642669214, 0.024058748567767907, 0.04777457295858767, 0.052552968700183555, 0.029202637197158765, 0.08358320206752978, 0.017771891289157793, 0.13559646613430232, 0.04580635279126, 4.376932410523295, 45.814400017261505, 50.08860066533089, 28.943130522966385, 17.74752337485552, 31.79480340331793, 42.472065165638924, 56.337904930114746, 50.84487408399582, 41.04261226952076, 1.3596224994398654, 0.3101565461838618, 6.9417444337159395, 4.771670904010534, 0.056126821655198, 4.1136459633708, 28.088132701814175, 54.5146943628788, 50.039188116788864, 49.237176552414894, 44.848488047719, 44.89227309823036, 44.260344207286835, 44.911329075694084, 47.80497260391712, 51.111824959516525, 50.13644389808178, 51.12464167177677, 49.57801826298237, 49.455421641469, 48.69439847767353, 47.34685778617859, 45.95607541501522, 44.058920815587044, 43.592621237039566, 44.55965794622898, 41.5649626404047, 43.577904626727104, 45.61095893383026, 46.45209699869156, 49.27362039685249, 49.370872378349304, 48.891752287745476, 48.8037072122097, 49.514842852950096, 44.447909742593765, 36.17746353149414, 36.96215182542801, 35.72562597692013, 35.14642305672169, 36.469907239079475, 37.31486789882183, 37.41976886987686, 36.665136963129044, 36.671809405088425, 39.33232024312019, 38.75264994800091, 37.35810957849026, 35.787475258111954, 38.44674736261368, 38.744715973734856, 39.38922978937626, 37.53716737031937, 37.78027452528477, 37.786471992731094, 37.87087306380272, 38.243230283260345, 36.404239162802696, 35.85410848259926, 35.26460811495781, 36.542076766490936, 35.82870304584503, 43.88956770300865, 51.88750393688679, 50.290373638272285, 49.67970460653305, 52.90761239826679, 47.946199625730515, 41.28005772829056, 42.89406292140484, 43.176782950758934, 43.23758728802204, 41.82256981730461, 37.67033502459526, 36.022291257977486, 36.95452943444252, 36.70305892825127, 36.483328118920326, 39.1215493530035, 38.36500994861126, 38.91623876988888, 39.02335502207279, 37.67822340130806, 38.51048894226551, 39.85419563949108, 35.91164119541645, 35.3895378112793, 36.170411109924316, 36.89275994896889, 38.04379418492317, 37.62143164873123, 36.45039148628712, 36.2931939214468, 37.20356427133083, 38.66245798766613, 37.979722023010254, 36.74276299774647, 36.846710219979286, 37.038124948740005, 37.43053749203682, 36.497999131679535, 37.22149930894375, 36.92340910434723, 34.180879667401314, 39.957135915756226, 45.720081478357315, 46.78196869790554, 47.08228558301926, 48.32389175891876, 49.15964551270008, 47.95255288481712, 50.55641636252403, 52.83666640520096, 51.035506054759026, 51.69923163950443, 49.83953543007374, 50.38863256573677, 48.409732952713966, 50.88146232068539, 49.48085367679596, 45.95856808125973, 44.648413583636284, 42.6699623465538, 49.742291048169136, 52.35780470073223, 57.27044329047203, 32.08238147199154, 3.112313007004559, 0.07720409397734329, 3.628554968163371, 3.8834194047376513, 0.15269272844307125, 9.67390850186348, 52.76185221970081, 45.76801970601082, 52.272886857390404, 27.065928652882576, 20.773428305983543, 34.89224709570408, 52.33292743563652, 18.375728465616703, 0.6195593671873212, 0.11345644947141409, 0.07030875538475811, 0.02099776789691532, 0.05441716573841404, 0.04574558202875778, 0.030442467250395566, 0.05395126026996877, 0.07776629310683347, 0.043551240596571006, 0.06560437032021582, 0.07881194207584485, 0.03476321762718726, 0.03469623137789313, 0.037310761981643736, 0.03990142511611339, 0.023906188980618026, 0.03685200339532457, 0.061654511955566704, 0.05935769477218855, 0.06793029082473367, 0.06045892689144239, 0.02987520296301227, 0.08265589596703649, 0.05395309708546847, 6.033776504918933, 52.62314446270466, 55.72293072938919, 35.19401550292969, 21.04163121432066, 36.72301545739174, 47.17486761510372, 58.186441138386726, 54.881321489810944, 44.60174448788166, 1.5295598306693137, 0.498313691932708, 1.0570639721117914, 4.942183429375291, 0.734110870398581, 5.360440760850906, 31.83837566524744, 54.69441331923008, 52.159652933478355, 51.06886826455593, 47.92118936777115, 46.6428429633379, 45.87396942079067, 48.16989742219448, 48.56494702398777, 52.17571847140789, 53.45434986054897, 52.73583881556988, 51.33812561631203, 51.774824783205986, 51.55790962278843, 48.238012567162514, 47.876534163951874, 46.28407761454582, 46.169232577085495, 46.195926144719124, 44.31774012744427, 44.90160159766674, 46.65470212697983, 47.97158606350422, 50.68133845925331, 50.44725961983204, 51.25619441270828, 51.1823795735836, 51.905731558799744, 46.772522404789925, 38.47659856081009, 38.9001352339983, 37.3219583183527, 38.25037769973278, 36.86827026307583, 38.21125879883766, 38.03783230483532, 38.28426048159599, 38.2647979259491, 40.58445945382118, 40.51631771028042, 40.52349932491779, 38.29243764281273, 39.396696388721466, 39.688980504870415, 38.89877110719681, 39.20579843223095, 40.13732224702835, 39.94878016412258, 39.554908499121666, 40.40333837270737, 38.04895430803299, 37.57545031607151, 37.578026577830315, 38.688969165086746, 39.549934566020966, 44.15707714855671, 54.12809170782566, 53.35674449801445, 51.51589907705784, 55.62935695052147, 49.78823438286781, 44.20185014605522, 44.84204359352589, 45.758919194340706, 44.05973017215729, 44.42695006728172, 39.1120270639658, 39.0503715723753, 40.09073294699192, 38.166447803378105, 38.707911148667336, 40.91712400317192, 40.193072855472565, 39.14668120443821, 41.083315685391426, 38.94442945718765, 40.39863422513008, 40.46491786837578, 37.879950776696205, 37.34264060854912, 37.36447423696518, 38.06873984634876, 38.845722153782845, 39.050721153616905, 39.855844751000404, 39.49034996330738, 37.84061908721924, 38.26095633208752, 39.739008620381355, 38.77437338232994, 38.596588522195816, 38.5734211653471, 39.387717470526695, 39.225329384207726, 38.79330016672611, 38.50649535655975, 36.84266343712807, 42.290925085544586, 50.876469388604164, 49.44151058793068, 48.802688866853714, 51.06398552656174, 49.93038475513458, 50.34297041594982, 52.94715687632561, 54.11926098167896, 53.03503476083279, 53.65174926817417, 54.38402317464352, 53.16425442695618, 50.783788561820984, 52.88975715637207, 50.27838908135891, 49.14652481675148, 45.909394919872284, 45.39931409060955, 52.821349427103996, 55.73310658335686, 56.63337707519531, 34.347375333309174, 3.209207570180297, 0.06338346371194348, 5.14302640222013, 3.491184264421463, 0.13244582660263404, 9.167688265442848, 56.499263271689415, 54.02327053248882, 58.827839121222496, 29.822524935007095, 25.926913172006607, 41.46058604121208, 60.18575705587864, 23.930323608219624, 0.7144556532148272, 0.18510207999497652, 0.07157917119911872, 0.024454120321024675, 0.055057769059203565, 0.07912637520348653, 0.06135207193437964, 0.03844679711619392, 0.08321083689224906, 0.05040270341851283, 0.0172927997118677, 0.24086370191071182, 0.15180127549683675, 0.15588567039230838, 0.21006077353376895, 0.20011698914458975, 0.08819518974632956, 0.12599421810591593, 0.14962252287659794, 0.15639318065950647, 0.11491873272461817, 0.21182240947382525, 0.15412542968988419, 0.33198664197698236, 0.19242222391767427, 7.182770725339651, 61.74888677895069, 62.17398516833782, 43.09129513800144, 27.425529956817627, 42.424921095371246, 56.12933412194252, 64.5026408135891, 59.93900589644909, 50.36328412592411, 2.0032057212665677, 0.6634473090525717, 16.092379689216614, 11.443403251469135, 0.42473429173696786, 5.126176681369543, 32.571232840418816, 58.92444133758545, 54.75768752396107, 54.32691603899002, 49.259720742702484, 49.4645107537508, 47.32290767133236, 50.19289366900921, 52.02123016119003, 54.23973731696606, 55.2711995691061, 54.96451422572136, 54.110396057367325, 54.59757171571255, 52.42078632116318, 51.46489821374416, 49.508071616292, 47.68539302051067, 48.15591797232628, 49.201925843954086, 45.85660055279732, 47.42131859064102, 50.0146072357893, 50.48827841877937, 53.63149635493755, 52.48453550040722, 52.99735978245735, 53.76907177269459, 54.24754209816456, 49.579678773880005, 40.84425151348114, 40.28805635869503, 39.831833839416504, 40.97012735903263, 39.76087644696236, 39.67869445681572, 40.22196650505066, 40.25494873523712, 40.236565321683884, 42.93049916625023, 42.1049402654171, 42.105168253183365, 39.23476427793503, 41.85680978000164, 43.31233307719231, 41.45985268056393, 41.05213075876236, 41.52128018438816, 42.64774113893509, 43.48496161401272, 44.13919150829315, 40.35545714199543, 40.92682488262653, 39.235721826553345, 42.34151177108288, 41.227669939398766, 47.55479782819748, 55.51089450716972, 54.222816824913025, 52.20185726881027, 58.75741750001907, 53.85858356952667, 46.1682104319334, 48.00333335995674, 48.69504824280739, 46.90163567662239, 46.19089901447296, 41.11784063279629, 40.16626909375191, 40.89037723839283, 40.831529796123505, 40.26686109602451, 43.41534934937954, 41.70827575027943, 42.41068705916405, 43.68593282997608, 41.97988137602806, 41.50509685277939, 43.3850421756506, 39.03163477778435, 38.668096885085106, 38.33519294857979, 39.301158115267754, 40.49631558358669, 41.68109580874443, 40.80666773021221, 41.399318128824234, 40.970807522535324, 41.119520142674446, 42.0324819535017, 40.31793415546417, 41.205836310982704, 41.17020942270756, 41.4920749515295, 40.82762360572815, 41.353329196572304, 40.85443116724491, 38.19218382239342, 43.34789156913757, 52.87622608244419, 51.85089290142059, 50.59902727603912, 53.34216468036175, 53.04545000195503, 52.82935939729214, 53.66900414228439, 57.867664843797684, 54.63100612163544, 56.92891761660576, 55.527978390455246, 55.074066147208214, 52.7260847389698, 55.91556519269943, 53.604229018092155, 52.16271176934242, 48.63488607108593, 46.173032373189926, 56.37331523001194, 58.05467560887337, 58.24962794780731, 36.1674814671278, 4.447397729381919, 0.24086151999654248, 12.564979568123817, 8.385333996266127, 0.23039771273033693, 11.047630738466978, 64.08682152628899, 58.61089736223221, 66.69577673077583, 35.737302750349045, 31.69592320919037, 49.894138500094414, 66.83813989162445, 32.179124280810356, 1.3916855351999402, 0.29544661520048976, 0.19896698679076508, 0.1045038181473501, 0.13324627740075812, 0.19725292251678184, 0.14142481901217252, 0.1600089983548969, 0.1133642673084978, 0.18838329298887402, 0.15872074873186648], [0.055048725989763625, 0.018038151611108333, 0.06671535797067918, 0.04215098233544268, 0.02853773967217421, 0.03885087055095937, 0.08407653731410392, 0.03227175366191659, 0.018140148677048273, 0.06538144400110468, 0.011552921969268937, 0.051674132264452055, 0.15528439718764275, 0.07535759345046245, 1.1709867278113961, 38.29718738794327, 52.3388285189867, 32.46784798800945, 24.86812848597765, 35.99650964140892, 42.80393935739994, 54.590367302298546, 49.31306608021259, 47.65996478497982, 4.193679168820381, 0.27352835226338357, 0.8358680445235223, 5.814747232943773, 1.2864498258568347, 1.3368222978897393, 10.133092012256384, 45.069438591599464, 56.31151534616947, 48.88114705681801, 44.68681052327156, 40.496300384402275, 42.154972180724144, 44.110423251986504, 46.49071432650089, 48.22209522128105, 50.209209993481636, 51.58058300614357, 48.55952471494675, 46.93352356553078, 46.58262379467487, 43.97615745663643, 43.730629831552505, 41.74824200570583, 43.58646556735039, 41.41353316605091, 44.66851830482483, 47.6498307287693, 48.23788337409496, 47.7549596875906, 48.49756523966789, 50.47512352466583, 50.23209236562252, 49.8904412984848, 49.26915183663368, 48.645970076322556, 44.06490929424763, 38.0705713480711, 36.17053650319576, 36.2296537309885, 34.99158136546612, 35.68688705563545, 35.56193456053734, 36.1757156252861, 37.56131127476692, 38.40222895145416, 38.23079735040665, 37.65022270381451, 38.95236723124981, 38.19433070719242, 38.58781099319458, 38.31653214991093, 37.972331419587135, 37.169951274991035, 36.77321836352348, 36.994898468256, 36.82323507964611, 36.70232176780701, 35.1025316119194, 36.8319746106863, 36.934363916516304, 35.22921681404114, 43.75068135559559, 51.16950586438179, 53.159485682845116, 52.79095105826855, 52.01900728046894, 50.03242447972298, 43.76445561647415, 43.38376924395561, 43.387930020689964, 44.23814579844475, 42.02485576272011, 37.13343143463135, 37.07485757768154, 37.70300567150116, 37.12526187300682, 36.21645323932171, 37.40377552807331, 36.837526112794876, 38.0110627412796, 37.46673434972763, 39.74279321730137, 38.15994635224342, 38.02056223154068, 38.94597217440605, 36.24027036130428, 37.71133482456207, 38.21023665368557, 37.30458565056324, 37.5776731967926, 36.49663880467415, 38.02368946373463, 35.99587507545948, 36.72078877687454, 38.404847010970116, 38.58995407819748, 36.361396461725235, 37.4204870313406, 36.584144309163094, 36.15560710430145, 35.80068714916706, 37.34516367316246, 37.36986994743347, 36.131839379668236, 37.74492122232914, 44.67682085931301, 45.6504350155592, 45.36833435297012, 47.55350969731808, 47.20608294010162, 49.363181591033936, 49.885573759675026, 53.00258830189705, 48.58912892639637, 53.26925799250603, 47.63543710112572, 51.097469329833984, 52.93059356510639, 51.54290422797203, 50.69818675518036, 48.0144439637661, 44.880235344171524, 48.10455992817879, 52.6356989890337, 55.49023121595383, 20.27021750807762, 0.6276567920576781, 0.1057520363247022, 1.3828436471521854, 1.1266977293416858, 0.19509722100337967, 14.370918162167072, 66.08199566602707, 50.690089389681816, 42.83372975885868, 42.18798100948334, 32.71547690033913, 37.65241898596287, 46.410736218094826, 13.422281015664339, 0.17717980197630823, 0.024448574622510932, 0.07331667249673046, 0.07019835349638015, 0.07350355270318687, 0.03343077682075091, 0.07741790672298521, 0.05952133462415077, 0.05645550030749291, 0.04400360929139424, 0.017904166124935728, 0.03210439193935599, 0.0686669020797126, 0.031688822637079284, 0.04879688880464528, 0.03903769138560165, 0.040391231450485066, 0.02362723978876602, 0.043789625851786695, 0.012783644015144091, 0.009848317295109155, 0.0710271840216592, 0.04893761484709103, 0.04920796440273989, 0.129784514720086, 1.8285497557371855, 47.475499883294106, 54.991599172353745, 38.43319728970528, 26.852961480617523, 39.855749756097794, 50.35792261362076, 59.01700437068939, 53.265355601906776, 52.05880634486675, 4.33624466881156, 0.11649043080979027, 1.1320693348534405, 6.731372997164726, 2.7997833397239447, 1.6930515202693641, 14.016599524766207, 47.006650641560555, 56.86280116438866, 50.61464063823223, 46.00447341799736, 42.50589855015278, 44.243769496679306, 46.44239991903305, 48.69412109255791, 49.70064528286457, 52.031934186816216, 53.591374307870865, 51.31119266152382, 49.4959806650877, 48.69834266602993, 46.681179106235504, 46.074393466115, 42.97272630035877, 44.570646956562996, 43.452914133667946, 46.02032236754894, 48.60319957137108, 49.38423626124859, 49.23206962645054, 51.56051628291607, 52.08472475409508, 51.797847747802734, 50.87716095149517, 50.1648435741663, 51.057689264416695, 44.92379620671272, 38.583665415644646, 38.45008738338947, 37.19691842794418, 37.84837067127228, 37.499640583992004, 38.390757367014885, 37.71718271076679, 39.775273874402046, 40.982849076390266, 40.70673689246178, 38.01370359957218, 39.80339236557484, 38.93445499241352, 40.23022726178169, 40.12935787439346, 40.124007761478424, 37.52129942178726, 39.581431075930595, 39.37568351626396, 39.26575921475887, 37.68812566995621, 37.32917033135891, 38.71798440814018, 38.74436639249325, 37.00062856078148, 45.267430767416954, 54.12379413843155, 55.15095502138138, 52.433724626898766, 54.35770958662033, 52.73925483226776, 45.899260863661766, 46.083326786756516, 46.588524878025055, 45.845303758978844, 43.086856976151466, 38.62415984272957, 39.22103561460972, 38.80258686840534, 39.38035346567631, 38.81382666528225, 38.737066984176636, 39.32013809680939, 39.375497326254845, 39.08293202519417, 40.86196616292, 39.00180637836456, 40.550683066248894, 41.34107485413551, 38.43952775001526, 39.18085657060146, 38.38401272892952, 38.84650111198425, 39.331902265548706, 38.7052208930254, 39.85683649778366, 38.15269634127617, 38.89657102525234, 40.1807577162981, 41.082646921277046, 38.16310778260231, 39.11663621664047, 37.97579683363438, 36.47721044719219, 37.56402052938938, 37.62128725647926, 39.250556230545044, 38.59215036034584, 40.48162177205086, 46.36254720389843, 47.576464265584946, 49.58159767091274, 49.57145981490612, 49.31683547794819, 51.06147386133671, 52.30518512427807, 55.76054871082306, 49.46351520717144, 53.051506876945496, 50.63131794333458, 52.36915849149227, 54.575540497899055, 54.20002944767475, 53.41163255274296, 51.91486246883869, 48.84466141462326, 50.25659345090389, 55.626206919550896, 56.11555226147175, 23.02289430052042, 1.0939759039320052, 1.1360809695906937, 3.423769944347441, 1.8596065579913557, 0.11947088103624992, 14.728102795779705, 71.12501665949821, 54.93994854390621, 49.575966373085976, 37.93480843305588, 30.90066198259592, 43.75723600387573, 53.896881714463234, 17.38442435860634, 0.34698319039307535, 0.09681519048172049, 0.05214355180214625, 0.09441908507142216, 0.032164413132704794, 0.04587651914334856, 0.0584707466623513, 0.07091290812240914, 0.09521553569356911, 0.04295183389331214, 0.01085666870494606, 0.18695066595682874, 0.13324553525308147, 0.1716990562272258, 0.11351734268828295, 0.16031413979362696, 0.08505062840413302, 0.21386411710409448, 0.15255419915774837, 0.1820613822201267, 0.1345277883228846, 0.12582030321937054, 0.1424137011053972, 0.20670487079769373, 0.19859214284224436, 2.373874168843031, 54.3707200884819, 63.05460311472416, 46.753641217947006, 33.596524223685265, 47.90379770100117, 54.1169773042202, 65.4090365767479, 58.60031113028526, 57.127825543284416, 6.194857461377978, 0.693975524045527, 6.886925725266337, 13.125138860195875, 4.844269333407283, 2.3791029257699847, 14.193448685109615, 48.19527626037598, 58.60767513513565, 54.24563080072403, 48.24951454997063, 44.86176073551178, 47.76553452014923, 49.35623176395893, 50.382248908281326, 51.320433765649796, 55.397402197122574, 56.58575803041458, 52.91162118315697, 50.89979253709316, 51.041920110583305, 47.34530366957188, 48.604183718562126, 45.26186026632786, 45.73573283851147, 44.840044900774956, 48.11353884637356, 52.023187056183815, 51.703985184431076, 51.38461232185364, 52.82029688358307, 54.39345046877861, 54.04815919697285, 53.15887771546841, 52.99143210053444, 54.08668152987957, 47.5415251404047, 42.1296389400959, 39.806804582476616, 39.12001423537731, 40.35896435379982, 38.92275162041187, 39.99598503112793, 39.89422649145126, 41.98805473744869, 41.42010681331158, 42.43173412978649, 39.87632945179939, 41.96518376469612, 42.184659987688065, 41.80492356419563, 41.79443992674351, 41.84290252625942, 41.03154346346855, 40.76518915593624, 41.97341412305832, 41.76926247775555, 40.36334931850433, 38.99262607097626, 41.72913283109665, 40.93136943876743, 39.56623949110508, 48.15565958619118, 56.345990896224976, 56.503868624567986, 55.13362415134907, 57.70404562354088, 55.48496849834919, 47.966232150793076, 48.36998708546162, 48.387523144483566, 47.79016859829426, 46.45961679518223, 40.64883179962635, 41.47514306008816, 42.04156346619129, 40.78301779925823, 40.74247017502785, 40.501650497317314, 40.84583602845669, 40.98051980137825, 40.91953307390213, 43.82637709379196, 41.35433994233608, 42.74186588823795, 43.107942044734955, 39.6934262663126, 41.21332950890064, 41.13426335155964, 41.62893980741501, 40.83124101161957, 40.54357744753361, 41.509994789958, 39.19482462108135, 42.20923326909542, 42.69380606710911, 42.30789117515087, 38.25831167399883, 40.76980210840702, 39.36307579278946, 40.030255392193794, 39.415835961699486, 41.14662788808346, 41.47653378546238, 40.518749579787254, 41.51234686374664, 49.651103541255, 49.936707615852356, 51.39493256807327, 52.90306404232979, 51.3717158138752, 54.52872321009636, 52.92728774249554, 57.98783339560032, 49.668328016996384, 54.81443367898464, 50.75537368655205, 53.470274806022644, 56.52388595044613, 56.31678566336632, 55.9789913892746, 53.59540969133377, 50.6441954523325, 53.10355648398399, 57.028179690241814, 60.09689502418041, 24.7029285505414, 1.6336014540866017, 1.5846254071220756, 8.628497198224068, 2.658204361796379, 0.4339747130870819, 16.516455933451653, 77.19024360179901, 58.63699436187744, 56.02192148566246, 54.53531205654144, 43.44448998570442, 51.908262223005295, 62.37832300364971, 22.38326132297516, 0.5855187156703323, 0.1539877019240521, 0.20161658758297563, 0.25339646846987307, 0.11283141269814223, 0.1456703044823371, 0.2400490315631032, 0.22393837105482817, 0.14897244604071602, 0.10674962381017394, 0.11821918218629435], [0.04678053664974868, 0.0054693041511200136, 0.005416901103671989, 0.08375207777135074, 0.030761720627197064, 0.09547903522616252, 0.05050419582403265, 0.03871509834425524, 0.0029074196481815306, 0.022453611163655296, 0.08018904161872342, 0.02003458637773292, 0.06839834109996445, 0.034933525676024146, 0.46525472367648035, 26.38836421072483, 52.31458581984043, 40.91733679175377, 28.955134078860283, 27.706118300557137, 39.99753154814243, 54.15012672543526, 49.83483128249645, 53.564190566539764, 10.685895849019289, 0.2513071446446702, 0.5742270278278738, 2.999421302229166, 3.3827986428514123, 0.5559845629613847, 3.8875721069052815, 30.7999274879694, 52.1770104020834, 44.592966958880424, 46.93535506725311, 40.165683925151825, 41.6026908159256, 42.01364256441593, 44.002531841397285, 45.83977125585079, 49.43911671638489, 45.959328040480614, 46.50105357170105, 42.96135351061821, 42.14398697018623, 40.04816763103008, 41.899466291069984, 40.52169822156429, 44.80374164879322, 47.27453626692295, 47.51808039844036, 46.90923526883125, 48.99159952998161, 48.690902665257454, 48.317470103502274, 48.96669566631317, 48.68089400231838, 50.61279013752937, 51.872023567557335, 49.88861359655857, 48.68428722023964, 38.919297605752945, 34.57252845168114, 37.044744193553925, 36.730216071009636, 36.81965947151184, 38.65182235836983, 35.85375890135765, 36.228677183389664, 39.13867883384228, 38.831685706973076, 36.72279506921768, 36.13332509994507, 39.54765468835831, 38.733506575226784, 39.714328944683075, 37.27810487151146, 35.042589828372, 38.23472633957863, 37.11730130016804, 37.66878090798855, 35.90278007090092, 37.6317822933197, 36.61634378135204, 36.51845723390579, 37.01338067650795, 43.225507736206055, 50.65205343067646, 51.364131420850754, 51.023491099476814, 52.417370304465294, 49.55228604376316, 45.553354024887085, 45.60520984232426, 45.28326451778412, 46.13917998969555, 42.45758034288883, 35.91362088918686, 35.13706795871258, 36.909539848566055, 38.9075942337513, 37.815183252096176, 40.087522119283676, 41.447738930583, 37.275665402412415, 38.923731967806816, 38.755108416080475, 36.41279250383377, 38.949061408638954, 37.711380422115326, 36.142702996730804, 36.58673956990242, 36.75994947552681, 37.35406659543514, 37.7791877835989, 36.83621898293495, 36.79145738482475, 37.76194430887699, 38.237880170345306, 38.3859658241272, 36.300975903868675, 36.591477915644646, 37.744187861680984, 38.10385376214981, 35.03107264637947, 37.0797935128212, 35.797183737158775, 35.46759322285652, 38.29814873635769, 35.4021455347538, 37.70332485437393, 40.860693231225014, 43.67554038763046, 42.968998700380325, 44.41540628671646, 47.12066352367401, 47.20128759741783, 50.172754749655724, 52.32413470745087, 52.593506053090096, 52.54150964319706, 53.82205992937088, 52.099171578884125, 54.81854505836964, 53.019246608018875, 51.13328620791435, 51.49174377322197, 48.849502354860306, 54.23186793923378, 47.8339384496212, 9.833507537841797, 0.2501548267900944, 0.11310386995319277, 0.9722144657280296, 1.9841268262825906, 0.11208314972463995, 19.86394140869379, 64.11610275506973, 45.01909889280796, 36.538284569978714, 23.80615197122097, 25.409954711794853, 39.16780807077885, 42.011655271053314, 7.8573917504400015, 0.20403958100359887, 0.0647076110180933, 0.019059153855778277, 0.033538095085532404, 0.02337588735827012, 0.07616343224071898, 0.03311507090984378, 0.018169676877732854, 0.05930462008109316, 0.01796806503989501, 0.015142879528866615, 0.006613368859689217, 0.020422518100531306, 0.029648254203493707, 0.06336430888040923, 0.06203874778293539, 0.06325070091406815, 0.008678526501171291, 0.06459859694587067, 0.03842489262751769, 0.06862816197099164, 0.09855990545474924, 0.019906925845134538, 0.0665197278431151, 0.055370435875374824, 0.5421365622896701, 32.84946531057358, 57.93212078511715, 46.01066708564758, 30.692976526916027, 35.15800483524799, 46.739232391119, 58.53077866137028, 54.406848549842834, 57.13708944618702, 11.69433893635869, 0.43345316138584167, 0.5628250865265727, 3.659348040819168, 6.9727578945457935, 1.1896072723902762, 3.8048018608242273, 35.57538963854313, 54.661712273955345, 48.77294026315212, 46.995821222662926, 42.82999835908413, 43.17061968147755, 44.613102078437805, 46.79551117122173, 49.74058493971825, 50.58424986898899, 48.543402180075645, 49.343920424580574, 44.559331163764, 43.030114620923996, 41.93860039114952, 43.29231195151806, 42.65090636909008, 45.853587314486504, 49.042117819190025, 48.39747481048107, 50.20569138228893, 51.152942553162575, 49.8310124874115, 48.70632603764534, 50.69562569260597, 49.02871213853359, 51.41780734062195, 52.082167491316795, 51.703153029084206, 50.45241594314575, 40.10679468512535, 37.88403555750847, 38.63354913890362, 37.863923236727715, 39.70811627805233, 39.11766596138477, 37.53917746245861, 37.310429736971855, 41.33205033838749, 41.434485241770744, 39.32655595242977, 39.17017534375191, 40.10595493018627, 40.14906741678715, 40.14950059354305, 39.95041787624359, 37.81798370182514, 39.24373559653759, 38.65661770105362, 40.17739489674568, 39.007175490260124, 39.30859811604023, 37.76053078472614, 37.60823495686054, 39.28842879831791, 44.43804167211056, 51.156012788414955, 53.737761452794075, 53.40215586125851, 53.6453428119421, 50.57279348373413, 47.38150432705879, 46.932174637913704, 47.871757820248604, 47.66619265079498, 45.04521869122982, 38.50587218999863, 38.324735909700394, 38.631736636161804, 39.678956642746925, 39.20080170035362, 41.432307958602905, 41.750533282756805, 38.51526528596878, 40.32106898725033, 40.082855969667435, 37.396156936883926, 39.946880266070366, 39.55683119595051, 37.46904842555523, 38.298232331871986, 39.770668521523476, 39.921205043792725, 39.35794606804848, 38.80760259926319, 37.31232963502407, 38.86407896876335, 39.949923902750015, 39.628388956189156, 38.01626466214657, 38.327129781246185, 39.77444551885128, 38.8224446028471, 36.81188128888607, 39.22023005783558, 38.23116593062878, 39.05734799802303, 39.55274261534214, 38.029655143618584, 41.38914607465267, 42.841587737202644, 45.22929981350899, 44.97078448534012, 47.6978525519371, 49.62108515202999, 48.81968915462494, 53.20906922221184, 54.240026101469994, 53.36452268064022, 54.00654762983322, 52.91031025350094, 54.01099719107151, 54.00864131748676, 54.823139011859894, 53.46275880932808, 53.28886494040489, 51.842962726950645, 56.07664994895458, 49.270508363842964, 11.688743736594915, 0.30264936620369554, 2.315004877746105, 4.53618424013257, 1.393448521848768, 0.21176272595766932, 21.333841234445572, 69.59173053503036, 50.10582134127617, 41.50517284870148, 30.563800558447838, 30.768024399876595, 43.98849159479141, 49.91962753236294, 11.1232191324234, 0.2739749173633754, 0.08735150142456405, 0.02265290379000362, 0.04746220300148707, 0.06038238920154981, 0.04879412430454977, 0.053660368066630326, 0.04518568726780359, 0.06290953562711366, 0.021332867981982417, 0.0325137643085327, 0.12028623415972106, 0.08919360101572238, 0.07642838638275862, 0.2015089464839548, 0.1418249701964669, 0.08564834672142752, 0.1131423503102269, 0.13229791657067835, 0.13637031835969537, 0.17721204087138176, 0.2491581521462649, 0.13553914264775813, 0.2331459746346809, 0.13824070862028748, 0.8419214165769517, 38.27176295220852, 66.28811940550804, 53.92997793853283, 38.544022142887115, 40.27609460055828, 52.26068951189518, 64.0006497502327, 57.69276782870293, 64.13702443242073, 14.556145872920752, 0.5639938800595701, 1.1190813942812383, 10.617228783667088, 8.906853161752224, 1.217437454033643, 5.800152216106653, 38.09940420091152, 59.76244457066059, 50.495277643203735, 51.57241724431515, 45.12509040534496, 46.10332511365414, 45.30984789133072, 49.04000513255596, 51.29525251686573, 54.98027577996254, 49.998971074819565, 51.80995009839535, 45.866803005337715, 44.734235778450966, 42.59450979530811, 45.889005213975906, 45.299949422478676, 48.13140548765659, 51.367802023887634, 50.81014774739742, 51.171914935112, 54.52341869473457, 53.04708391427994, 49.43788558244705, 52.0864612609148, 49.92533102631569, 52.94639311730862, 54.85857971012592, 54.21071447432041, 51.708529740571976, 43.211615681648254, 39.165193811059, 41.04055278003216, 39.98243875801563, 42.25204937160015, 42.02213130891323, 40.438950061798096, 39.6245701611042, 42.79597878456116, 44.155177250504494, 41.06660418212414, 40.75467512011528, 43.168921172618866, 42.187232449650764, 42.821452617645264, 41.75426468253136, 39.639852941036224, 41.85253880918026, 40.997512489557266, 42.605848386883736, 40.26995413005352, 41.96709506213665, 40.62540605664253, 41.354685723781586, 42.29742273688316, 47.08311013877392, 52.668419033288956, 55.0358971953392, 53.68262641131878, 55.56940756738186, 52.16271936893463, 49.63940776884556, 50.20297072827816, 50.597245171666145, 50.071072205901146, 47.61564016342163, 39.557309970259666, 40.593867748975754, 41.02620095014572, 43.76438342034817, 41.91353693604469, 42.848001793026924, 42.559095695614815, 41.39809839427471, 42.76555001735687, 42.94253692030907, 38.93817879259586, 41.955805867910385, 41.04399539530277, 40.07746405899525, 40.481139197945595, 39.9860143661499, 41.58541314303875, 41.42342023551464, 41.46021746098995, 39.99954164028168, 41.21627435088158, 41.31232939660549, 41.71023264527321, 40.81313498318195, 40.357767418026924, 41.33102059364319, 41.979053020477295, 37.482560500502586, 41.546811014413834, 39.65639345347881, 39.63161498308182, 42.547346726059914, 40.118623450398445, 41.00157827138901, 43.61628636717796, 47.48530715703964, 48.123779296875, 49.2130858451128, 51.86772979795933, 51.79355397820473, 55.88430047035217, 56.77722215652466, 56.559486240148544, 56.39410391449928, 54.927971586585045, 54.25783954560757, 57.146740928292274, 57.25028537213802, 55.510826110839844, 55.49924053251743, 55.18579915165901, 58.030603900551796, 52.185267359018326, 13.025624100118876, 1.0285117104649544, 1.789474196266383, 9.095599483698606, 5.803476087749004, 0.37285481463186443, 22.838104516267776, 77.34291180968285, 53.818222135305405, 49.47911337018013, 35.991436913609505, 37.00908690690994, 52.13452488183975, 60.45888639986515, 13.612524457275867, 0.4985617473721504, 0.2043582295300439, 0.09414449785253964, 0.1386176751111634, 0.16244128346443176, 0.15004505723481998, 0.14262789976783097, 0.11903371894732118, 0.12361515982775018, 0.15181588096311316, 0.12068523501511663], [0.07051816719467752, 0.08902822824893519, 0.03934043568733614, 0.0860121104051359, 0.07940353767480701, 0.024429032018815633, 0.016833727568155155, 0.014785802595724817, 0.05283185666485224, 0.07288690962013789, 0.051262128981761634, 0.011397042198950658, 0.06527227407786995, 0.06952748168259859, 0.075628366030287, 18.48850641399622, 50.24297118186951, 40.80290213227272, 38.737579956650734, 33.78506250679493, 37.10090517997742, 53.11285458505154, 48.06691154837608, 54.37007412314415, 14.830999374389648, 0.0637940272281412, 0.248291754105594, 3.5814063856378198, 3.6009722482413054, 0.3889469214482233, 0.12690983538050205, 13.441030159592628, 57.50098071992397, 49.77613963186741, 48.64564709365368, 40.813727751374245, 39.302514642477036, 41.75973258912563, 43.22826638817787, 44.21405129134655, 43.461361080408096, 42.96918109059334, 41.664574295282364, 37.34851889312267, 39.596394672989845, 38.82069669663906, 41.957914754748344, 43.63688126206398, 48.91504883766174, 48.25694315135479, 49.89261098206043, 49.50478859245777, 48.307377845048904, 49.728528186678886, 49.77804332971573, 47.95058459043503, 47.269368544220924, 47.148888409137726, 50.04894599318504, 49.56238970160484, 50.444880947470665, 42.59952552616596, 36.61099746823311, 38.23036417365074, 36.30326718091965, 36.882663890719414, 36.10507741570473, 34.99958373606205, 37.3000904917717, 39.114451333880424, 39.13223057985306, 37.203556671738625, 38.611757308244705, 39.14642281830311, 38.329994827508926, 38.96035820245743, 39.01676617562771, 36.484897434711456, 36.41538396477699, 37.30859823524952, 39.439949467778206, 38.07848632335663, 37.290184423327446, 36.72549292445183, 37.3334527015686, 35.410862267017365, 42.5336978584528, 51.98787935078144, 51.90616853535175, 50.47163911163807, 51.218371242284775, 49.303608387708664, 46.8103189766407, 46.306409016251564, 45.16314536333084, 43.91201689839363, 40.80963917076588, 37.05303534865379, 35.43952792882919, 36.45966298878193, 37.693988755345345, 37.104461789131165, 39.5627398788929, 38.45816195011139, 37.51175433397293, 36.73276573419571, 37.984114587306976, 36.17782451212406, 37.375565841794014, 38.802769258618355, 37.45082840323448, 37.871975004673004, 37.83822901546955, 38.89886610209942, 36.35562837123871, 38.35711397230625, 38.85342054069042, 40.06480693817139, 38.653038293123245, 37.11155220866203, 39.234992265701294, 37.359830886125565, 37.01366186141968, 36.48645535111427, 37.47211866080761, 35.046040043234825, 35.8943635225296, 36.03443540632725, 37.20519058406353, 36.65374897420406, 34.704670161008835, 36.760983020067215, 40.39097763597965, 40.03629706799984, 40.09102173149586, 41.98736697435379, 45.585675090551376, 47.702948078513145, 47.801742777228355, 50.03139853477478, 52.64816612005234, 52.977304458618164, 54.87531781196594, 54.3944726139307, 53.39457906782627, 53.48605155944824, 52.68096216022968, 50.697214007377625, 56.53524734079838, 40.29594473540783, 3.5992894135415554, 0.1406844673329033, 2.0167747931554914, 2.7697003539651632, 1.0724459029734135, 0.0915887342125643, 24.78395540267229, 64.41142290830612, 52.048638090491295, 37.5925911962986, 21.706318147480488, 31.98311559855938, 44.95869733393192, 38.78537379205227, 3.178820600733161, 0.14534071669913828, 0.053354436240624636, 0.013780492135992972, 0.08132905466482043, 0.0785262077988591, 0.03394465100427624, 0.08570653109927662, 0.02041107047261903, 0.07234764285385609, 0.03611610831285361, 0.027982535284536425, 0.049800175984273665, 0.10086206981213763, 0.10837337613338605, 0.04089057809324004, 0.0661640461476054, 0.0704470842902083, 0.03841386431304272, 0.02573127298092004, 0.049590111084398814, 0.05396481559728272, 0.023096205295587424, 0.03747225331608206, 0.036576392012648284, 0.050465886160964146, 0.08848989658872597, 25.09236965328455, 58.251987621188164, 45.735550448298454, 39.47095960378647, 34.4938650727272, 46.13934338092804, 59.87525291740894, 51.695511639118195, 60.4861955344677, 15.462537836283445, 0.13769171229796484, 0.8010438038036227, 3.6667346069589257, 9.361826498061419, 2.4402941297739744, 0.4366847692290321, 17.537624537944794, 61.05812564492226, 51.66075870394707, 51.939219161868095, 42.332179471850395, 41.41085051000118, 43.09393599629402, 45.01540929079056, 45.22815987467766, 45.33675044775009, 45.773985385894775, 45.365712493658066, 41.55503377318382, 40.983498841524124, 40.13557054102421, 44.00505110621452, 46.27743557095528, 50.06295584142208, 50.40866129100323, 51.62531800568104, 51.8535565584898, 49.7593217343092, 51.230401396751404, 51.63357496261597, 48.833243027329445, 49.221981167793274, 48.10432814061642, 50.58857023715973, 51.050811633467674, 53.13552036881447, 43.92329469323158, 39.85247053205967, 40.18113389611244, 39.39240641891956, 39.09416422247887, 38.2958422601223, 36.7679138481617, 37.84333594143391, 41.18444725871086, 41.77193373441696, 38.09789948165417, 39.70488265156746, 40.15842631459236, 40.25112994015217, 42.00739569962025, 41.07224687933922, 38.09531942009926, 38.04372198879719, 39.904132559895515, 41.098089292645454, 39.96273301541805, 40.302028208971024, 39.518282264471054, 39.7358737885952, 38.43366086483002, 44.752679988741875, 54.90945138037205, 53.83036248385906, 51.4549845457077, 54.698653891682625, 50.46066530048847, 47.79907152056694, 48.54175686836243, 47.71278195083141, 47.01404884457588, 43.48840042948723, 38.83978687226772, 38.20800617337227, 38.801389932632446, 40.211482867598534, 37.830728217959404, 40.79589530825615, 40.52854545414448, 39.24028158187866, 38.78057084977627, 38.95515248179436, 38.59715849161148, 40.26695989072323, 40.813898742198944, 38.61828155815601, 38.82911704480648, 40.18262721598148, 39.903627187013626, 39.068386405706406, 39.752573892474174, 41.2243527173996, 41.58318646252155, 41.29522651433945, 39.031178802251816, 39.40192490816116, 37.62420170009136, 38.76558065414429, 37.97554224729538, 38.65907996892929, 37.42509998381138, 37.10885815322399, 38.45403917133808, 39.49507310986519, 38.54961924254894, 37.97720655798912, 40.20421385765076, 42.700630500912666, 42.21173353493214, 42.78860718011856, 44.75416570901871, 48.02914917469025, 51.2601538002491, 50.027697533369064, 51.87648452818394, 55.152102559804916, 54.90922339260578, 57.2818198800087, 57.15416572988033, 55.48738896846771, 56.30085691809654, 55.45311480760574, 53.41987431049347, 58.05223993957043, 43.74261438846588, 4.122072011232376, 0.4127183271339163, 3.5494990227743983, 3.864745069295168, 1.3104498130269349, 0.12520132237114012, 25.51100078970194, 70.72501212358475, 54.58043463528156, 45.818370804190636, 25.79012431204319, 34.79645423591137, 51.49094961583614, 45.94596415758133, 5.579187422990799, 0.24327450926648453, 0.011708023412211332, 0.013123575481586158, 0.0727115994959604, 0.06665359644102864, 0.07288953682291321, 0.024562006328778807, 0.016320786635333207, 0.04846186850045342, 0.054446580761577934, 0.0320147553429706, 0.13845260662492365, 0.29701026098337024, 0.15183865005383268, 0.12172268325230107, 0.12570037215482444, 0.12743155035423115, 0.2267707182909362, 0.10296011387254111, 0.1713589151040651, 0.16055282932939008, 0.10803152064909227, 0.10923182577244006, 0.12634274549782276, 0.2055194234708324, 0.19020597799681127, 29.68596026301384, 65.11013701558113, 55.02640150487423, 49.366817995905876, 43.656795993447304, 49.68356899917126, 64.23682987689972, 56.85802102088928, 63.79054382443428, 18.885972686111927, 0.1844661930226721, 1.4310527290217578, 10.139658059924841, 9.464257601648569, 1.8998310808092356, 0.5000282311812043, 18.526703864336014, 66.9536004960537, 55.31901240348816, 54.26093637943268, 44.80463080108166, 43.382355719804764, 44.22556087374687, 45.368455946445465, 46.795305982232094, 46.771184876561165, 47.36211396753788, 46.18220508098602, 41.52627311646938, 43.161416575312614, 42.79182940721512, 46.88796021044254, 47.14937478303909, 53.079169392585754, 52.46820777654648, 54.10316124558449, 52.91803903877735, 52.44719870388508, 52.14531250298023, 54.31013613939285, 50.49234800040722, 49.7005008906126, 49.4750589877367, 51.01165093481541, 55.38657657802105, 55.3255632519722, 46.24021656811237, 41.688756197690964, 42.579743787646294, 41.2631980329752, 41.12635977566242, 39.01049271225929, 38.43966834247112, 40.07011145353317, 43.73219534754753, 44.06899407505989, 40.08493825793266, 42.3418727517128, 43.32267992198467, 41.84165999293327, 43.863029927015305, 43.40440213680267, 38.4405042976141, 39.54960398375988, 42.98919081687927, 43.61279055476189, 42.64728896319866, 43.05176965892315, 41.57668121159077, 43.533143028616905, 40.88284604251385, 47.63726480305195, 54.93654012680054, 54.86684046685696, 54.1463877260685, 56.04370951652527, 53.03699165582657, 51.72097027301788, 50.85066877305508, 50.180954709649086, 47.458427399396896, 45.0977698713541, 41.6107501834631, 40.622708201408386, 41.80487796664238, 43.2113990932703, 41.15310654044151, 44.39383864402771, 43.02790313959122, 40.231181010603905, 40.44500693678856, 41.28553703427315, 40.27250379323959, 41.79517328739166, 43.242280036211014, 40.30699074268341, 41.40477083623409, 41.043919399380684, 41.955000311136246, 40.09555868804455, 42.07188963890076, 43.0566181987524, 43.016454353928566, 42.64883928000927, 41.014926955103874, 42.3505362868309, 41.220963299274445, 41.31711333990097, 40.98178893327713, 41.23846895992756, 38.353644758462906, 39.40308004617691, 39.747618958353996, 41.47847928106785, 41.581807136535645, 39.46130432188511, 40.17772927880287, 44.45892155170441, 44.33242253959179, 46.15391559898853, 46.49319939315319, 51.321144327521324, 54.02654215693474, 52.66445964574814, 55.0671961158514, 57.88287542760372, 57.869500145316124, 58.07041056454182, 57.83327668905258, 56.8022134155035, 57.76182532310486, 57.4698755890131, 54.50254261493683, 60.37743777036667, 44.55617353320122, 6.174768414348364, 0.5389931809622794, 6.944051384925842, 8.072749469429255, 3.754584467969835, 0.25377205456607044, 28.451809287071228, 73.8514843583107, 62.07188844680786, 50.57315066456795, 32.35080286860466, 44.62899662554264, 57.067807763814926, 58.95614303648472, 7.7020779345184565, 0.2969430817756802, 0.16840015043271706, 0.08227737838751636, 0.1469516966608353, 0.11973302986007184, 0.24317794101079926, 0.1799467214732431, 0.17541588022140786, 0.1967488112859428, 0.14470153459114954, 0.10671748139429837], [0.015591207229590509, 0.06019029540766496, 0.033477298347861506, 0.030420581315411255, 0.02665759759111097, 0.05481311265612021, 0.022379142210411374, 0.018255955255881418, 0.028205749185872264, 0.027716013355529867, 0.029974828867125325, 0.0472218658978818, 0.03733653677045368, 0.09070803498616442, 0.04438735530129634, 7.755056591704488, 47.14700371026993, 40.1245891302824, 39.36599023640156, 29.182530976831913, 32.42454171180725, 50.81439211964607, 53.23568679392338, 53.93866807222366, 22.396000139415264, 0.009193736550514586, 0.2639068232383579, 1.7806125967763364, 10.12998852878809, 3.050624504685402, 0.1583769265562296, 8.004750218242407, 58.01872953772545, 52.19183720648289, 47.44995765388012, 42.95956000685692, 39.817292019724846, 40.43290078639984, 39.8516383767128, 40.13297148048878, 41.443205773830414, 38.52875076234341, 39.684375151991844, 36.75736181437969, 41.2909821420908, 43.695736303925514, 48.121871799230576, 48.281919211149216, 48.390574380755424, 48.622567132115364, 52.713944390416145, 47.27478325366974, 51.02310352027416, 50.18332198262215, 48.914862647652626, 49.99881908297539, 50.9547071903944, 51.52277670800686, 49.96414214372635, 49.05140072107315, 50.250772163271904, 42.30760999023914, 35.88009148836136, 36.084642112255096, 36.47243030369282, 37.692719623446465, 36.456383764743805, 36.74708716571331, 38.04144211113453, 38.662522584199905, 38.44122625887394, 38.10669220983982, 36.69132135808468, 36.99557103216648, 38.977035507559776, 39.68094773590565, 38.491421565413475, 36.78488753736019, 38.18840302526951, 38.025300577282906, 38.03340174257755, 36.67849704623222, 38.19249540567398, 37.01077401638031, 38.077369183301926, 37.03131951391697, 41.87450163066387, 51.71259932219982, 53.260621055960655, 51.04060158133507, 52.784309014678, 49.89194601774216, 45.473535507917404, 47.46070347726345, 46.611532643437386, 43.92580635845661, 40.91400057077408, 35.428922697901726, 36.18307963013649, 38.73003736138344, 37.752832397818565, 37.16456696391106, 39.203488156199455, 37.97105088829994, 37.60188549757004, 38.80453996360302, 36.98820322751999, 38.537220507860184, 38.78742568194866, 37.63772137463093, 35.89456491172314, 37.46608078479767, 38.01476374268532, 37.49791547656059, 38.714591190218925, 38.98968122899532, 35.55696062743664, 37.75264620780945, 37.27569580078125, 43.19512076675892, 45.150929018855095, 45.216616094112396, 45.76633259654045, 40.31826093792915, 36.50933772325516, 36.730850636959076, 36.9998762011528, 37.22245305776596, 37.05167882144451, 36.73190318048, 34.674742966890335, 35.64373277127743, 36.299133002758026, 35.679591447114944, 36.64163142442703, 37.99993693828583, 39.65692542493343, 41.12163282930851, 45.40293149650097, 46.70463524758816, 49.50796902179718, 49.42140206694603, 49.37101297080517, 49.697947427630424, 53.72515372931957, 51.82027414441109, 56.27865090966225, 55.20674742758274, 50.6146976351738, 25.868489407002926, 1.4146570838056505, 0.1379151432774961, 3.1484595173969865, 1.0277276462875307, 0.5542129080276936, 0.13346522580832243, 29.6657320484519, 57.500999718904495, 48.99409979581833, 35.90506374835968, 29.952230975031853, 29.489206820726395, 43.928998187184334, 36.1746858805418, 0.843122152145952, 0.02537999036576366, 0.05120735848322511, 0.09592556321877055, 0.05424776682048105, 0.019905372901121154, 0.018805354193318635, 0.006070914105293923, 0.10954203607980162, 0.040027931609074585, 0.08072028576862067, 0.056234837538795546, 0.09462523885304108, 0.09313882095739245, 0.028019844903610647, 0.045741062349407, 0.022854977614770178, 0.03144211419567, 0.04681140257162042, 0.043687079596566036, 0.051250009710201994, 0.06158157739264425, 0.04076254277606495, 0.06385660512023605, 0.08927324088290334, 0.08016840249183588, 0.02214375708717853, 11.99724918231368, 55.45122630894184, 48.36584910750389, 46.417579650878906, 34.30330149829388, 36.84911549091339, 54.682318568229675, 55.30188672244549, 59.43128854036331, 21.81477762758732, 0.012456970089260722, 0.3906103712506592, 2.8139834152534604, 9.091282915323973, 4.750837571918964, 0.47558898164425045, 8.902493845671415, 60.49536444246769, 53.079256787896156, 51.75632357597351, 45.09746588766575, 43.00955772399902, 40.841785445809364, 42.93959587812424, 42.77278482913971, 43.40853251516819, 39.64631639420986, 42.85847023129463, 38.37400786578655, 42.893477752804756, 45.07032014429569, 48.964993357658386, 49.826293140649796, 50.161146372556686, 50.9101127833128, 55.12810304760933, 49.350250884890556, 50.68918123841286, 52.50630833208561, 52.17371217906475, 52.60650895535946, 52.781386971473694, 51.89615227282047, 51.438531428575516, 49.71223086118698, 51.39637269079685, 44.87109683454037, 37.77909658849239, 38.69188740849495, 38.76501448452473, 40.164148807525635, 37.88954146206379, 37.07805700600147, 39.79445144534111, 40.931498631834984, 39.68017257750034, 40.61815224587917, 38.169818222522736, 39.161606803536415, 41.060349717736244, 42.37456999719143, 39.751194566488266, 39.13230657577515, 39.29672375321388, 39.97789040207863, 39.76812645792961, 38.93826238811016, 38.08678887784481, 39.729060754179955, 39.78054419159889, 38.59661512076855, 43.98388244211674, 54.1830899566412, 54.15331095457077, 53.05806152522564, 51.886284202337265, 50.83844482898712, 48.272537514567375, 50.10938934981823, 49.849479496479034, 46.194607615470886, 42.84868575632572, 37.809221372008324, 38.95943105220795, 40.08654937148094, 39.45616699755192, 38.63743633031845, 40.60131534934044, 38.655979335308075, 38.59384506940842, 39.180582985281944, 38.946257159113884, 38.282504975795746, 39.51088026165962, 40.27174763381481, 37.33762487769127, 38.407161086797714, 38.788406029343605, 39.295241832733154, 40.4323536157608, 42.70901285111904, 38.648603931069374, 39.55020435154438, 38.4533704072237, 44.622559770941734, 46.704794839024544, 45.82029350101948, 47.06012897193432, 40.64196936786175, 38.1966295838356, 38.5349178314209, 38.555581122636795, 39.509048759937286, 40.20297132432461, 38.001863434910774, 37.759254053235054, 38.490357622504234, 37.81251199543476, 38.838639333844185, 39.728050008416176, 40.470009595155716, 42.55165949463844, 45.02191074192524, 48.31077106297016, 49.28373545408249, 51.33558355271816, 52.05048859119415, 52.67498128116131, 53.05412493646145, 53.57242092490196, 55.014280155301094, 57.61500120162964, 56.456002593040466, 51.877366080880165, 29.303389191627502, 2.21271769143641, 0.5610694026108831, 4.393289582803845, 5.136538250371814, 1.1684526200406253, 0.16788714827271178, 31.637182161211967, 63.185327500104904, 54.38292883336544, 38.59589695930481, 29.142724312841892, 36.56976968050003, 50.21241322159767, 44.83405642211437, 1.621047758962959, 0.04432581641594879, 0.059262347349431366, 0.05756877006206196, 0.08670680515933782, 0.024577231488365214, 0.08101551211439073, 0.018517278440413065, 0.05861363977601286, 0.021361644758144394, 0.05736751816584729, 0.04994445320335217, 0.17166833131341264, 0.18790052592521533, 0.11601501100813039, 0.13470425619743764, 0.12300846894504502, 0.17734390567056835, 0.224635960184969, 0.15965744300046936, 0.14466467953752726, 0.17681349272606894, 0.11155419138958678, 0.16012566396966577, 0.18597448943182826, 0.2042806157260202, 0.15079513104865327, 14.675544016063213, 65.28678193688393, 54.27898921072483, 51.86518773436546, 40.86439423263073, 43.88621248304844, 60.61630055308342, 61.39618970453739, 64.04011443257332, 26.856204606592655, 0.15906477870885283, 1.5887955646030605, 5.781967816874385, 21.7195338383317, 6.867961417883635, 0.411870438256301, 10.716204922646284, 61.535402834415436, 56.08022555708885, 52.205641865730286, 47.63868972659111, 43.84228304028511, 43.28266426920891, 44.88324858248234, 45.21752804517746, 46.63620851933956, 41.86617247760296, 44.308073446154594, 41.00854329764843, 43.61399509012699, 47.997797057032585, 51.286999359726906, 52.552464455366135, 52.47309051454067, 52.46126934885979, 55.673609375953674, 50.49680896103382, 52.67718516290188, 57.39351108670235, 54.78447988629341, 55.78604154288769, 55.800161585211754, 57.48347885906696, 53.980146646499634, 51.90182916820049, 53.11203382909298, 47.984075993299484, 39.50212933123112, 41.12644337117672, 41.80605210363865, 42.65330024063587, 39.498595520853996, 39.12246510386467, 41.37962378561497, 43.001293167471886, 43.01911801099777, 41.52555115520954, 40.531604290008545, 41.01639747619629, 42.96655923128128, 42.96077214181423, 42.3928090184927, 41.23732142150402, 42.30603687465191, 41.85355715453625, 42.47558377683163, 40.661561116576195, 40.82878254354, 42.61093631386757, 41.659995540976524, 40.69741979241371, 45.28783567249775, 57.51272588968277, 56.59120313823223, 54.30680751800537, 54.56110507249832, 52.32894144952297, 50.156248435378075, 53.1047610193491, 53.27827870845795, 48.5413920879364, 46.363751739263535, 39.217251017689705, 40.92656269669533, 43.675430193543434, 42.010652124881744, 39.780399799346924, 43.53769898414612, 40.52318774163723, 39.07124765217304, 42.20092311501503, 40.27571462094784, 40.8268066495657, 41.74421042203903, 42.597872614860535, 39.983160719275475, 39.81661565601826, 41.919609010219574, 41.39049880206585, 42.20751956105232, 43.23958978056908, 37.68569000065327, 41.30794443190098, 39.4576945155859, 48.135627061128616, 48.680742010474205, 48.80763240158558, 50.88363580405712, 43.66017021238804, 40.13784281909466, 40.837343484163284, 41.69347174465656, 41.79576225578785, 42.14852012693882, 39.97032880783081, 38.25822427868843, 39.94707405567169, 39.438490346074104, 40.437183156609535, 41.72550402581692, 41.71548776328564, 43.643736094236374, 46.16619274020195, 50.880945548415184, 52.208753898739815, 54.920820370316505, 53.27344536781311, 55.163205564022064, 55.35385273396969, 57.09251023828983, 56.10268995165825, 61.10184609889984, 57.26323887705803, 53.672366961836815, 31.261095441877842, 2.5666591990739107, 1.196991226170212, 8.56403460726142, 7.6367204915732145, 2.7035622904077172, 0.19612441275967285, 36.11095570027828, 68.77884775400162, 59.0165825933218, 48.694668263196945, 38.47020350396633, 42.98097565770149, 58.82141746580601, 53.42025808990002, 2.2098462330177426, 0.24396533000981435, 0.10700630300561897, 0.19898898404790089, 0.13851629773853347, 0.13953925925306976, 0.13410886080237105, 0.0936488842125982, 0.2618988387985155, 0.1469394809100777, 0.19264706497779116, 0.16931337799178436], [0.07402640316286124, 0.03133741571218707, 0.05150342345586978, 0.009236575169779826, 0.014452989253186388, 0.021776562825834844, 0.04978101002052426, 0.01921674149343744, 0.04027383110951632, 0.035537481744540855, 0.06289215452852659, 0.04627314141544048, 0.019097908807452768, 0.11758806722355075, 0.029105252579029184, 3.5051511274650693, 39.09823380410671, 45.34457802772522, 42.52467334270477, 31.459881775081158, 36.29398047924042, 46.51092544198036, 46.01411730051041, 55.14967069029808, 29.925436712801456, 0.44478121446445584, 0.17097702075261623, 1.2037508259527385, 6.7305023688822985, 4.404832888394594, 0.424856033641845, 6.752598658204079, 57.508549913764, 51.666219010949135, 52.42109790444374, 44.60921108722687, 42.413479909300804, 38.2416457682848, 39.487952291965485, 37.70246610045433, 37.68795847892761, 39.0902466326952, 40.21543085575104, 41.24515660107136, 47.31739416718483, 48.16632181406021, 49.77464631199837, 50.844501703977585, 51.463245302438736, 49.67621259391308, 46.16483621299267, 47.95224130153656, 52.64669179916382, 46.26834265887737, 47.08791308104992, 46.187695786356926, 48.72145302593708, 47.550789043307304, 49.474565014243126, 50.605760514736176, 49.40795078873634, 39.52927507460117, 33.460411727428436, 36.64921961724758, 36.971829906105995, 36.7173233628273, 36.07478924095631, 36.796818897128105, 38.73700238764286, 39.80881467461586, 40.17480343580246, 37.042061537504196, 37.56958723068237, 38.28354611992836, 39.134879037737846, 40.08170463144779, 39.37835857272148, 37.95003801584244, 37.5744965672493, 37.30624616146088, 36.75056777894497, 37.61603593826294, 37.297404035925865, 35.636809542775154, 40.26366926729679, 37.03339420258999, 41.760796532034874, 50.72659023106098, 51.47866487503052, 52.04114109277725, 52.526747435331345, 50.037208423018456, 47.60253846645355, 48.96859556436539, 47.59587362408638, 47.172211557626724, 41.92062735557556, 36.682186648249626, 38.000259920954704, 37.1629748493433, 35.705532655119896, 36.30479849874973, 38.83865833282471, 38.878711983561516, 38.22427310049534, 37.71130442619324, 37.21393011510372, 36.88413821160793, 39.47762444615364, 37.30053886771202, 35.566596910357475, 37.29819059371948, 36.57902218401432, 37.4866034835577, 36.87114670872688, 36.75431817770004, 36.68894648551941, 36.96826569736004, 44.13474574685097, 50.75964845716953, 50.26239573955536, 52.04943984746933, 47.59951762855053, 48.116597682237625, 44.228137135505676, 40.06868652999401, 37.89075739681721, 38.249412551522255, 36.05175107717514, 35.855324417352676, 36.369851008057594, 35.157301872968674, 36.4913646876812, 34.949981197714806, 34.58672069013119, 36.534583568573, 36.71631261706352, 36.940812170505524, 38.319883570075035, 39.88064222037792, 43.480869233608246, 46.10051706433296, 45.886045172810555, 47.343741953372955, 49.22676511108875, 51.492306143045425, 53.75631585717201, 54.59914483129978, 44.729037657380104, 11.492571663111448, 0.5310598597861826, 0.15715569286840037, 1.6357494075782597, 3.50640173535794, 0.7445880956947803, 0.7724301517009735, 33.207922875881195, 58.53534981608391, 44.19850252568722, 33.45259174704552, 27.07858957350254, 34.313538148999214, 53.15837614238262, 23.73657390475273, 0.2372489677509293, 0.08644769171951339, 0.020496250472206157, 0.026108211641258094, 0.11103584576630965, 0.0371118701150408, 0.03545967127138283, 0.023273931110452395, 0.04762211727211252, 0.022898191018612124, 0.023992738242668565, 0.03548375396349002, 0.11243430431932211, 0.04574640581267886, 0.03126962423266377, 0.046720303944312036, 0.045314234666875564, 0.051296271485625766, 0.03836611453152727, 0.011376070033293217, 0.02901881092839176, 0.0652136147255078, 0.07721384579781443, 0.08710368347237818, 0.022289665175776463, 0.04642545980459545, 0.06324221074464731, 5.5374447628855705, 48.39309744536877, 51.39900594949722, 48.410606905817986, 34.53424170613289, 43.35995972156525, 54.920656979084015, 53.1328909099102, 59.45821009576321, 31.815820075571537, 0.4335358366370201, 0.2603676693979651, 2.3240790283307433, 6.535038007423282, 3.8791560335084796, 0.6349120871163905, 7.905386025086045, 58.36629308760166, 53.50072257220745, 53.99731792509556, 46.532177701592445, 43.66575591266155, 39.875482097268105, 41.70037977397442, 37.83528797328472, 40.00029779970646, 39.86334554851055, 42.3123749345541, 42.808692902326584, 48.111247569322586, 49.629209116101265, 50.84083870053291, 53.06635648012161, 52.861505672335625, 50.23360848426819, 48.74191112816334, 49.94423881173134, 53.78257244825363, 49.199395179748535, 50.12896969914436, 49.826429933309555, 50.7955489307642, 48.094353675842285, 51.657464280724525, 51.6081353276968, 52.34460420906544, 42.78308987617493, 37.838608995079994, 37.37513646483421, 38.91700632870197, 38.14713343977928, 37.15724095702171, 37.11114943027496, 39.807712733745575, 40.92676408588886, 40.5005219578743, 39.31747443974018, 39.20450650155544, 40.5151891708374, 39.13753129541874, 39.431544318795204, 39.4294848293066, 40.11710733175278, 39.97953951358795, 39.4416593760252, 38.714256808161736, 40.17696551978588, 40.84103308618069, 38.73925946652889, 41.63088530302048, 38.852668181061745, 44.7478162497282, 52.809292674064636, 53.987077474594116, 52.666522935032845, 53.45691852271557, 52.86202244460583, 49.183968007564545, 51.14547215402126, 49.291107058525085, 48.32353077828884, 42.83270001411438, 39.445006996393204, 40.05954422056675, 37.623312547802925, 38.47981698811054, 38.35802972316742, 41.14955373108387, 40.29517337679863, 39.77887228131294, 39.41588535904884, 37.957272827625275, 38.6788123100996, 40.99414587020874, 38.77523593604565, 36.33582383394241, 38.49486418068409, 39.489411413669586, 39.676091596484184, 40.873642936348915, 39.86614979803562, 38.20561610162258, 38.96344743669033, 46.75484575331211, 53.23885202407837, 52.90714122354984, 54.208426997065544, 50.236427932977676, 50.56481771171093, 45.140441581606865, 42.674826085567474, 39.289994314312935, 39.326156973838806, 38.2047725468874, 36.24676801264286, 37.59045951068401, 37.01226733624935, 37.3068655282259, 37.712193578481674, 36.118650287389755, 39.08248744904995, 38.71657468378544, 38.87671709060669, 41.045275926589966, 43.342207074165344, 45.18192395567894, 48.94004389643669, 49.00474302470684, 49.96014855802059, 51.75189681351185, 54.073386043310165, 56.14158846437931, 55.46686626970768, 46.47146075963974, 14.810391180217266, 0.6794218893628567, 2.714904681779444, 4.411299666389823, 4.647508766502142, 1.04469207348302, 0.49534355755895376, 35.90752221643925, 62.85485923290253, 49.57021728157997, 42.17862211167812, 32.618601098656654, 37.800227254629135, 57.05530263483524, 31.039607226848602, 0.2747391810407862, 0.054443986955448054, 0.015330916558013996, 0.01945209693076322, 0.042678519457695074, 0.01032997299262206, 0.012602404131030198, 0.05880503224034328, 0.040998445547302254, 0.04324662237195298, 0.08260765636805445, 0.0404860371054383, 0.21106944128405303, 0.15023348852992058, 0.10061398468678817, 0.10464737177244388, 0.2518864057492465, 0.12992767500691116, 0.1540440903045237, 0.11378628216334619, 0.15417349117342383, 0.15269529627403244, 0.14444271801039577, 0.12625579547602683, 0.14639303757576272, 0.23356703954050317, 0.1305237680207938, 7.44742794893682, 54.65008869767189, 59.39652040600777, 52.74550549685955, 41.59302793443203, 47.37752974033356, 60.08632019162178, 56.02969206869602, 66.30887389183044, 37.110294476151466, 0.7931670045945793, 1.1712188716046512, 7.146346354857087, 12.50534176826477, 8.950839601457119, 1.5082978340797126, 9.854517560452223, 60.459498167037964, 56.29214018583298, 56.563723012804985, 49.41997334361076, 46.59020818769932, 42.52595767378807, 44.025383815169334, 40.109773725271225, 42.42204084992409, 42.38305874168873, 45.60287296772003, 44.12621520459652, 51.175194159150124, 54.04928773641586, 54.66563366353512, 55.96672564744949, 55.27438759803772, 49.45458188652992, 49.809760227799416, 52.99051634967327, 57.38400399684906, 51.914866268634796, 52.433390244841576, 51.41946405172348, 53.657498359680176, 51.99228711426258, 55.71334384381771, 54.84873063862324, 53.661811128258705, 44.20922175049782, 38.982951790094376, 38.8075266033411, 39.45433549582958, 40.38608729839325, 39.10720892250538, 40.57652547955513, 41.78734190762043, 44.182721972465515, 43.226632475852966, 39.190169870853424, 40.96971318125725, 41.31058529019356, 43.12261305749416, 42.801773473620415, 43.14354993402958, 41.91858306527138, 42.44107022881508, 40.332487374544144, 40.0179136544466, 42.23492369055748, 42.23770134150982, 40.98564952611923, 44.74390245974064, 40.30891723930836, 46.58266179263592, 55.574548691511154, 54.66117650270462, 54.13735181093216, 55.50034247338772, 53.57912376523018, 50.397280901670456, 53.650852516293526, 51.570939123630524, 52.09119960665703, 46.314787566661835, 41.05612054467201, 43.71955722570419, 40.5835323035717, 39.89556781947613, 40.55928960442543, 41.782390773296356, 42.75970213115215, 41.179321333765984, 40.7633500546217, 39.951569214463234, 39.63822282850742, 42.73812688887119, 39.82654832303524, 38.262730836868286, 40.35981550812721, 40.561436489224434, 41.34379930794239, 42.368193939328194, 41.436191350221634, 40.3139291703701, 41.371123641729355, 49.321129247546196, 55.03679394721985, 55.662624165415764, 56.15420758724213, 51.84946417808533, 52.82608777284622, 48.556914255023, 43.366020396351814, 42.14019097387791, 42.728361412882805, 40.60513034462929, 37.9304538667202, 39.87450174987316, 39.08153370022774, 39.730854257941246, 39.439957067370415, 38.389488235116005, 42.02857196331024, 41.12367331981659, 41.032918989658356, 42.763365134596825, 45.04504010081291, 47.0143224298954, 50.88331662118435, 51.73269264400005, 52.67658859491348, 54.3216685205698, 56.87301501631737, 59.51401770114899, 56.21028497815132, 48.29374797642231, 16.881287656724453, 1.1688297498039901, 2.3239704966545105, 8.619102202355862, 11.79194999858737, 1.908675106242299, 0.6392583413980901, 39.105423018336296, 68.55421900749207, 53.342350870370865, 47.63127252459526, 37.28220485150814, 47.528415843844414, 65.59299230575562, 34.94709715247154, 0.7617815199773759, 0.23664569074753672, 0.1093607813527342, 0.09057884191861376, 0.23400030535412952, 0.16203390376176685, 0.15612582938047126, 0.1226374990073964, 0.12744544335873798, 0.1425531061249785, 0.19245722360210493, 0.1368046973948367], [0.034623185492819175, 0.03241358921513893, 0.01383923961839173, 0.024028153529798146, 0.0794248966849409, 0.0112587745206838, 0.007181276496339706, 0.029051411620457657, 0.07836585195036605, 0.07475109552615322, 0.033646931042312644, 0.06261653572437353, 0.0542619195766747, 0.04889854077191558, 0.07152388119720854, 1.2399701261892915, 35.60609959065914, 47.1344605833292, 50.612653344869614, 24.87797375768423, 27.90276724845171, 40.6767413020134, 45.65641589462757, 55.92639461159706, 43.794033229351044, 5.013623395934701, 0.45397393056191504, 1.6452031815424562, 3.2475845608860254, 1.8938883184455335, 0.6511547311674803, 16.281539238989353, 55.282135382294655, 51.97871044278145, 50.550416484475136, 45.74754260480404, 39.95351850986481, 38.421585112810135, 38.927907943725586, 37.070016637444496, 39.94839258491993, 40.65736994147301, 44.72406752407551, 44.392033740878105, 47.72059813141823, 52.053209245204926, 53.629121482372284, 50.984801575541496, 50.29193535447121, 44.49777826666832, 48.950732722878456, 50.212124437093735, 48.06788809597492, 45.573831126093864, 43.53595867753029, 45.160147324204445, 44.21960659325123, 46.20878465473652, 48.557499423623085, 48.63152325153351, 43.20306234061718, 37.74818144738674, 35.75793944299221, 36.325055211782455, 37.06552907824516, 36.926236152648926, 36.701899990439415, 36.953564286231995, 38.45702961087227, 38.566197752952576, 37.39968314766884, 36.428170278668404, 36.48821845650673, 36.221320778131485, 37.702333107590675, 39.59722302854061, 39.01973381638527, 39.50502097606659, 38.85101526975632, 36.64129324257374, 38.54996882379055, 38.70178207755089, 39.048688262701035, 39.469850063323975, 37.69040934741497, 38.896255642175674, 43.464712500572205, 51.83831177651882, 52.93020598590374, 51.699611619114876, 54.38424736261368, 49.68302182853222, 48.97213317453861, 50.713515132665634, 48.80743481218815, 47.796426862478256, 40.25801137089729, 37.316182628273964, 35.599130764603615, 37.56857268512249, 35.84166795015335, 37.62466147542, 38.53733450174332, 37.2855980694294, 38.5407505184412, 37.62881085276604, 38.43661330640316, 37.74833723902702, 36.79483540356159, 39.12448279559612, 36.122921258211136, 36.1233202368021, 36.3768046349287, 37.14947037398815, 35.770607963204384, 36.71283580362797, 36.6360305249691, 39.7514795511961, 49.558472111821175, 47.76241108775139, 49.89809028804302, 47.434716671705246, 52.56498858332634, 48.790331929922104, 47.555702179670334, 46.094319596886635, 43.470157608389854, 41.70171730220318, 43.504021391272545, 40.47250226140022, 38.39889273047447, 37.24688574671745, 36.732161566615105, 36.163404285907745, 34.6802032738924, 34.63011056184769, 36.33493088185787, 35.526577457785606, 36.69961631298065, 36.82936415076256, 36.523655354976654, 39.26204301416874, 40.35443499684334, 42.51227080821991, 45.937942788004875, 50.383335649967194, 50.12737758457661, 54.46874722838402, 39.86274138092995, 5.431402428075671, 0.11369804080459289, 2.111531258560717, 2.7849323116242886, 4.089168151840568, 0.39048824342899024, 0.9699676581658423, 40.92897176742554, 54.11021746695042, 45.52351422607899, 27.23472509533167, 22.61179246008396, 35.82203060388565, 46.930004954338074, 15.520040150731802, 0.3708274749806151, 0.055464974357164465, 0.07603423917316832, 0.11569908616365865, 0.027734093928302173, 0.023957159683050122, 0.05664662559865974, 0.07984514522831887, 0.049540802792762406, 0.08495087633491494, 0.024423330469289795, 0.04718190124549437, 0.08941024876548909, 0.037500395555980504, 0.0628320628311485, 0.09013905262690969, 0.020367814395285677, 0.017231271958735306, 0.12819360243156552, 0.05022915589506738, 0.022681285372527782, 0.06553944724146277, 0.029925474191259127, 0.027624847934930585, 0.04595201040501706, 0.021330456002033316, 0.03886770246026572, 2.156698959879577, 44.51802738010883, 53.88590790331364, 54.61464419960976, 30.89296169579029, 34.227890744805336, 45.27625389397144, 52.0404951274395, 59.29259978234768, 47.99543358385563, 4.157242449000478, 0.04027012408187147, 1.223789881914854, 5.406189830973744, 5.702588651329279, 0.5811195017304271, 18.857854194939137, 56.37608528137207, 54.14079822599888, 52.543067559599876, 48.83385479450226, 42.37395063042641, 41.10684782266617, 39.16111662983894, 38.939238935709, 40.3740381449461, 43.72010439634323, 45.19247218966484, 48.31827186048031, 50.8287363499403, 52.44863502681255, 52.962994426488876, 53.321900367736816, 50.24493187665939, 46.93438611924648, 50.64978115260601, 52.288485020399094, 49.971813932061195, 47.92040280997753, 46.02198667824268, 48.79798851907253, 46.59375719726086, 49.593700021505356, 49.375101551413536, 51.10860273241997, 46.516108363866806, 39.3396158516407, 38.62721107900143, 37.65856705605984, 39.15398821234703, 39.20957162976265, 37.19859033823013, 38.40111941099167, 40.121290907263756, 41.13875851035118, 40.24188503623009, 38.009003251791, 38.39775279164314, 39.30851832032204, 38.68120618164539, 41.282181814312935, 41.19027994573116, 41.68241433799267, 41.0555125772953, 38.844358026981354, 39.287722036242485, 39.442031756043434, 40.66083535552025, 41.37834705412388, 39.734661653637886, 41.84190697968006, 45.4580969363451, 52.11749039590359, 54.12667438387871, 52.51663997769356, 55.58288924396038, 51.53805188834667, 50.72865352034569, 53.3309742808342, 50.729071497917175, 49.060949608683586, 43.44224810600281, 38.6493106931448, 37.44003318250179, 39.82987694442272, 37.2211991250515, 39.23481747508049, 40.34331299364567, 40.455714762210846, 38.17627787590027, 38.9497035741806, 38.24870578944683, 39.950566068291664, 39.22149159014225, 40.11640056967735, 36.978414952754974, 38.58360081911087, 36.88218891620636, 39.407894387841225, 36.671501621603966, 38.580089807510376, 37.78521426022053, 42.04307198524475, 50.157749354839325, 50.28046377003193, 52.0630469173193, 50.41555792093277, 54.23962712287903, 49.40917432308197, 48.760663121938705, 45.971806570887566, 44.60680961608887, 43.4470434486866, 44.10528592765331, 41.25861547887325, 39.797662273049355, 39.258095026016235, 37.49297194182873, 37.68350891768932, 36.854769587516785, 38.31585578620434, 38.8299074023962, 36.9238992780447, 38.91021989285946, 38.83551970124245, 39.65126372873783, 41.24368228018284, 41.73919469118118, 43.96675296127796, 48.009211644530296, 52.45233602821827, 52.417738884687424, 55.63965819776058, 41.957014203071594, 6.934530045837164, 0.35966403025668114, 5.461533386260271, 6.385769667103887, 4.608693849295378, 1.3637176109477878, 1.1792998504824936, 43.451918587088585, 61.512531861662865, 50.63997007906437, 31.84537298977375, 26.19007185101509, 39.43475514650345, 57.46436968445778, 19.6621323376894, 0.3911045228596777, 0.02423430731141707, 0.06354196419124492, 0.03848627195111476, 0.01457956996091525, 0.01203814368636813, 0.019016127844224684, 0.06333535769954324, 0.029728907102253288, 0.016546889346500393, 0.039954796666279435, 0.040428583743050694, 0.22065132478019223, 0.11135748514789157, 0.15682327008107677, 0.16539314616238698, 0.1648425468010828, 0.07455754341208376, 0.20378367364173755, 0.18490410468075424, 0.2795588958542794, 0.24552686809329316, 0.08433677881839685, 0.1549328863620758, 0.17560569191118702, 0.14989833463914692, 0.10800954565638676, 2.695436426438391, 52.783412262797356, 60.55263876914978, 62.09844522178173, 34.83835078775883, 39.28785502910614, 53.66701304912567, 58.01099315285683, 65.31149581074715, 53.10326009988785, 6.2381138652563095, 0.5397705361247063, 6.6963697504252195, 16.53176911175251, 9.230136014521122, 1.6484181652776897, 22.498712427914143, 58.26318562030792, 56.56773939728737, 54.61838319897652, 50.3350630402565, 44.63927887380123, 42.21996769309044, 41.2387615442276, 40.64112201333046, 44.215179830789566, 46.10384188592434, 47.98826336860657, 50.68576902151108, 53.43440093100071, 54.75945062935352, 54.50194604694843, 53.63008663058281, 49.56293307244778, 45.93552231788635, 54.91556145250797, 54.74410705268383, 53.57225753366947, 49.84488174319267, 48.36514234542847, 51.15576580166817, 47.88175128400326, 51.55519276857376, 54.08494882285595, 53.3485521376133, 48.29616464674473, 41.24499320983887, 40.014957413077354, 40.01900799572468, 40.677698850631714, 40.649572759866714, 39.2341411113739, 39.39113348722458, 43.10943156480789, 41.98859430849552, 41.6574002802372, 40.82245208323002, 39.18807618319988, 39.7832078486681, 40.15225924551487, 42.2652992606163, 42.31876619160175, 43.438265919685364, 43.01209598779678, 40.98781540989876, 41.35798394680023, 41.88818469643593, 43.51939536631107, 45.05800500512123, 42.50114880502224, 44.38528910279274, 49.1264770925045, 54.94797371327877, 57.2256550937891, 54.63608264923096, 56.256756484508514, 53.938181698322296, 51.78138703107834, 54.714259654283524, 53.179567605257034, 51.334033235907555, 44.80750724673271, 40.82359582185745, 38.79915565252304, 42.6424328237772, 40.2534706145525, 41.91650077700615, 42.11756318807602, 40.992853939533234, 40.55659934878349, 41.11401803791523, 41.27869360148907, 41.874874010682106, 40.49772530794144, 42.54812568426132, 38.79960782825947, 40.33766269683838, 39.42671097815037, 40.60293026268482, 38.759789764881134, 40.45457862317562, 38.735300078988075, 42.6237378269434, 53.483688086271286, 51.28665737807751, 54.41571727395058, 50.05771592259407, 55.84958553314209, 52.920759692788124, 50.81761434674263, 50.01398406922817, 48.0205350369215, 47.49516762793064, 47.13620848953724, 44.12109687924385, 42.31118559837341, 40.824386179447174, 39.02809716761112, 40.13267129659653, 38.91973838210106, 39.6828818321228, 40.86632452905178, 38.76103229820728, 41.87423564493656, 40.82331843674183, 42.13591240346432, 43.84967364370823, 44.21283915638924, 45.58740399777889, 50.33096686005592, 54.56210821866989, 54.41970705986023, 56.4185594022274, 44.03039954602718, 9.324114471673965, 0.5155759875196964, 5.314528299495578, 9.406264163553715, 12.565507739782333, 2.460561292245984, 1.0735569871030748, 48.95926706492901, 65.01809075474739, 55.9245403110981, 37.700524404644966, 34.585459157824516, 47.58308731019497, 64.23169255256653, 23.900592103600502, 0.5301895877346396, 0.10752837421023287, 0.19453952671028674, 0.14246266800910234, 0.17038140271324664, 0.13472024205839261, 0.13917836768087, 0.11724565512849949, 0.15104575431905687, 0.18361500900937244, 0.08069488947512582, 0.1765724431606941], [0.024624821708130185, 0.0499388240132248, 0.02700986911804648, 0.03959603505791165, 0.08477572206174955, 0.034233650731039234, 0.0260797484224895, 0.06973666342673823, 0.034910893882624805, 0.08467772888252512, 0.04439733347680885, 0.11409914935939014, 0.059021676279371604, 0.12749230256304145, 0.08027239964576438, 0.8788396418094635, 23.57319977134466, 48.72133143246174, 49.14891108870506, 27.06980064511299, 39.829261377453804, 43.338228687644005, 53.13258692622185, 51.47734634578228, 49.15932632982731, 11.703648436814547, 0.01509480784079642, 0.9022183029446751, 3.372211935929954, 3.3194714784622192, 0.2624946349533275, 21.890501864254475, 52.270299196243286, 56.08827352523804, 49.17255721986294, 46.796860098838806, 42.45908886194229, 38.44754531979561, 38.34933578968048, 39.43431057035923, 43.44017341732979, 48.55164393782616, 47.46759630739689, 50.44358901679516, 51.22678779065609, 50.0048303604126, 45.19471786916256, 46.48318313062191, 44.95311163365841, 47.199729681015015, 50.7314957678318, 47.17302851378918, 45.05911074578762, 41.86336062848568, 37.763498425483704, 38.82187083363533, 37.37895905971527, 40.09613245725632, 39.55612823367119, 39.939368069171906, 38.3729363232851, 36.42472006380558, 35.83143509924412, 37.245293632149696, 38.87004844844341, 37.37036012113094, 38.69796708226204, 37.19810776412487, 37.74041086435318, 39.804581701755524, 35.90421639382839, 37.18971021473408, 38.26983265578747, 36.902533024549484, 37.792038694024086, 38.64076115190983, 38.13483729958534, 38.206330463290215, 40.532178059220314, 38.960817977786064, 38.208792731165886, 35.83063714206219, 36.560718566179276, 39.93219405412674, 40.141243636608124, 41.39290027320385, 43.1380782276392, 52.332889437675476, 51.98760196566582, 55.89758075773716, 53.2760102301836, 50.26567116379738, 50.118999034166336, 50.368406251072884, 49.11311320960522, 49.04262699186802, 41.31266377866268, 36.008562594652176, 37.89131976664066, 36.12766720354557, 37.25562907755375, 37.132477685809135, 38.615530505776405, 39.16146241128445, 38.60680237412453, 37.072262316942215, 35.9631360322237, 37.38991767168045, 37.06858791410923, 38.47406029701233, 36.15870773792267, 35.92752054333687, 36.61294676363468, 37.40866966545582, 36.843206807971, 37.38372020423412, 37.91530787944794, 41.22473269701004, 52.192650362849236, 44.141611978411674, 47.89506956934929, 44.17962893843651, 48.462983295321465, 49.7564072906971, 48.18384647369385, 47.82628186047077, 46.41797482967377, 46.608701795339584, 44.54208008944988, 44.980283975601196, 45.333615615963936, 44.41159889101982, 42.988746240735054, 41.254500299692154, 38.06783549487591, 38.62022325396538, 35.89400254189968, 34.810779467225075, 35.80036796629429, 37.38397479057312, 37.68866144120693, 38.087890818715096, 38.139830231666565, 39.320160895586014, 44.220640137791634, 50.28166450560093, 52.02558472752571, 54.46343891322613, 39.56989109516144, 4.324745060876012, 0.12371074844850227, 5.677177514880896, 3.346499428153038, 2.644767570309341, 0.8319927868433297, 1.9537808233872056, 44.683915078639984, 54.96116280555725, 38.87625351548195, 36.03776402771473, 36.160136461257935, 46.68464832007885, 41.36171534657478, 7.615788364782929, 0.041043556993827224, 0.028967020152776968, 0.12319651432335377, 0.13797013642033562, 0.06868711818242446, 0.06705816340399906, 0.026555108852335252, 0.012576654389704345, 0.029200399621913675, 0.07292068476090208, 0.04529028927208856, 0.03867282190185506, 0.01600644627615111, 0.04112213930056896, 0.014788258176849922, 0.01768329369951971, 0.015867649817664642, 0.035532913825591095, 0.06479543677414767, 0.06716852818499319, 0.01179600038085482, 0.052923578696209006, 0.0363565084990114, 0.07762558932881802, 0.06782673895941116, 0.0672250724164769, 0.09243942840839736, 0.9867834183387458, 33.619539588689804, 54.96604934334755, 56.688698306679726, 27.97641109675169, 45.35024352371693, 53.95751126110554, 56.39076009392738, 56.175763830542564, 53.2449658960104, 11.814378295093775, 0.15869487746385857, 1.1590846977196634, 4.141525542363524, 3.816987806931138, 1.038510042708367, 24.38053485006094, 52.777074202895164, 56.57949976623058, 51.92984126508236, 49.29211400449276, 43.19915995001793, 40.21313577890396, 39.657225608825684, 39.532406106591225, 44.221799075603485, 49.370101019740105, 48.74492056667805, 52.12146878242493, 53.82511496543884, 51.89049057662487, 46.42298296093941, 45.79418510198593, 46.33580423891544, 49.4963226467371, 52.47089043259621, 50.425790771842, 47.9912082105875, 45.113447830080986, 39.81866754591465, 40.577859207987785, 40.198673754930496, 44.176581501960754, 43.86712230741978, 43.36087927222252, 40.01657612621784, 39.39011514186859, 37.245267033576965, 39.17606122791767, 40.91157250106335, 40.83535999059677, 38.87083500623703, 37.07137316465378, 39.38152760267258, 41.23393580317497, 37.797696590423584, 39.646285995841026, 39.30721499025822, 38.590242862701416, 41.284944266080856, 39.72229331731796, 38.746353685855865, 40.62867008149624, 40.560630932450294, 40.725747272372246, 40.041001215577126, 38.649170100688934, 38.918397054076195, 40.63560850918293, 43.06119695305824, 43.09687323868275, 43.3426820486784, 54.981601908802986, 53.69167372584343, 55.99993206560612, 55.09963117539883, 52.816907465457916, 52.118774726986885, 53.80188301205635, 50.212732404470444, 50.32316207885742, 43.139377757906914, 38.44508305191994, 39.754709377884865, 37.964560836553574, 38.94734010100365, 38.10031995177269, 39.64554123580456, 39.8856807500124, 40.70288389921188, 39.64594781398773, 38.58151093125343, 40.854339972138405, 38.38650159537792, 39.47331927716732, 37.45520956814289, 37.087165117263794, 37.72759035229683, 39.11990784108639, 38.582669869065285, 39.640240520238876, 39.08018097281456, 42.29237660765648, 52.367961555719376, 47.30658754706383, 50.5220890045166, 46.15358121693134, 51.24647833406925, 52.21069559454918, 50.219868421554565, 50.825704112648964, 48.41922104358673, 48.98973383009434, 45.79065129160881, 45.71547232568264, 46.110955104231834, 46.31867095828056, 43.77867825329304, 42.526303455233574, 39.67410430312157, 39.01870787143707, 38.16479109227657, 37.92118236422539, 37.62583941221237, 38.589973077178, 38.123658299446106, 40.0347201526165, 40.75945906341076, 40.20143620669842, 45.12341469526291, 52.48834289610386, 54.06970024108887, 56.44315928220749, 40.12528449296951, 5.720385946333408, 0.36082679755054414, 8.857209775596857, 8.21192555129528, 3.705307524651289, 0.3139844548422843, 1.4437493914738297, 50.380599796772, 58.981016501784325, 48.629307970404625, 39.300645142793655, 36.36726714670658, 50.3581316024065, 47.3885453492403, 10.218534227460623, 0.07084809636580758, 0.030696678804815747, 0.08847330216667615, 0.017607546396902762, 0.036637181328842416, 0.09794725512620062, 0.03258241296862252, 0.026866655025514774, 0.0710892201459501, 0.050597168374224566, 0.02261105222714832, 0.01443735684006242, 0.08868059143424034, 0.13109442021232098, 0.06829284480772913, 0.11910227112821303, 0.17557388346176594, 0.06459909418481402, 0.15016497345641255, 0.14918284490704536, 0.14412300079129636, 0.08768804313149303, 0.1836131833260879, 0.17024878092342988, 0.18379907647613436, 0.13296068413183093, 0.21032744203694165, 1.6464168601669371, 39.680050984025, 63.286557868123055, 61.53093047440052, 36.95155419409275, 54.186080396175385, 55.116205886006355, 64.07709404826164, 60.699827671051025, 59.20322857797146, 14.806674979627132, 0.1528724914533086, 3.6061069602146745, 14.753893911838531, 8.252715412527323, 1.0450547165237367, 26.904836297035217, 53.38726446032524, 59.6853619068861, 53.43138009309769, 51.19336098432541, 45.5543115735054, 41.40393488109112, 42.18998730182648, 42.072702795267105, 46.370731964707375, 52.60518282651901, 51.385132893919945, 54.781189262866974, 54.89478796720505, 52.78761863708496, 47.489604726433754, 48.30401122570038, 49.24337401986122, 51.77837759256363, 53.105357587337494, 52.626868262887, 51.16135150194168, 47.495813593268394, 41.075613498687744, 43.390289694070816, 41.28153204917908, 46.345881298184395, 44.657289907336235, 44.191013127565384, 42.148326337337494, 40.54629810154438, 40.54988890886307, 40.859819278120995, 42.22952038049698, 41.95043295621872, 42.2778195887804, 40.145180225372314, 40.25958068668842, 44.38437335193157, 37.9656969755888, 41.24796085059643, 40.667709186673164, 40.97203865647316, 42.15712286531925, 41.56628876924515, 41.24145559966564, 41.69083088636398, 43.10050584375858, 43.535818085074425, 42.04487308859825, 40.40955103933811, 39.90156389772892, 42.45734095573425, 45.60690835118294, 47.26988911628723, 45.433987230062485, 57.267840430140495, 56.07625097036362, 57.122551426291466, 54.869564920663834, 52.37750664353371, 53.58804188668728, 54.19992685317993, 51.8172837048769, 52.76671975851059, 43.438482508063316, 41.24375067651272, 44.06550966203213, 42.405196353793144, 42.120656222105026, 39.949118345975876, 41.112247332930565, 41.49369366466999, 43.05646240711212, 41.12185321748257, 39.159307926893234, 41.4485976845026, 40.4885184019804, 41.944615468382835, 38.85706454515457, 40.09475693106651, 39.32003930211067, 41.634149327874184, 41.543698981404305, 41.79230064153671, 42.03202597796917, 43.87814171612263, 54.90260034799576, 50.407905131578445, 52.0335528999567, 48.87166276574135, 51.435666382312775, 54.92259107530117, 52.02139355242252, 53.742545396089554, 50.51519237458706, 53.67539159953594, 49.21353802084923, 48.40262733399868, 48.50033529102802, 49.40958470106125, 46.63580194115639, 45.260948315262794, 42.36695900559425, 43.508797734975815, 39.75827358663082, 39.64133866131306, 40.61595976352692, 40.26396565139294, 41.370420679450035, 41.94693714380264, 43.99677515029907, 42.2858751565218, 47.86974772810936, 54.78105627000332, 57.81349875032902, 58.60324837267399, 43.93107287585735, 7.137883258983493, 0.34111698798369616, 11.180935185402632, 13.713000565767288, 11.057559605687857, 1.797611340880394, 2.3505168221890926, 53.72325003147125, 65.20805016160011, 51.93914316594601, 49.72122497856617, 46.36284738779068, 58.06376472115517, 56.62577748298645, 13.457720763981342, 0.24600577598903328, 0.24815879092784598, 0.22713837824994698, 0.21325450215954334, 0.22089678270276636, 0.24628293846035376, 0.15592629555612803, 0.14155209733871743, 0.17628199624596164, 0.24332129425602034, 0.13020485232118517, 0.09534132972476073], [0.02748526294453768, 0.06725829094648361, 0.03049033577553928, 0.010938552641164279, 0.014004982531332644, 0.0780939735705033, 0.0588527003856143, 0.07860000696382485, 0.041304288315586746, 0.008564107738493476, 0.0304836249051732, 0.02651571194292046, 0.02060049810097553, 0.048646507420926355, 0.09643465426051989, 0.3515263512963429, 18.717886805534363, 51.40832684934139, 35.04982464015484, 33.72147671878338, 25.639948770403862, 29.99604642391205, 49.58643861114979, 50.22868014872074, 55.88253736495972, 24.6555070951581, 0.18830841028830037, 0.42921769490931183, 1.94593186955899, 2.9234410542994738, 1.3688634848222136, 20.241470150649548, 55.05958512425423, 54.48194392025471, 51.37776888906956, 50.07098101079464, 42.458499893546104, 38.615967482328415, 40.30016630887985, 44.966160133481026, 51.01208411157131, 47.72538207471371, 51.650981828570366, 48.750278279185295, 43.51287491619587, 46.13544479012489, 48.717778623104095, 48.68907876312733, 48.15245255827904, 48.12216818332672, 48.26153710484505, 46.15218669176102, 44.25204165279865, 40.98481357097626, 37.52348430454731, 37.12401553988457, 36.05817273259163, 35.922459214925766, 35.851000249385834, 36.49147488176823, 36.866586953401566, 36.822235733270645, 36.715001687407494, 38.65499898791313, 38.74454118311405, 37.19844214618206, 36.51873081922531, 36.05783835053444, 37.06630043685436, 37.57719062268734, 37.370884492993355, 38.093799501657486, 37.01284870505333, 39.82698529958725, 39.1629633307457, 39.05512511730194, 37.641688361763954, 38.922265246510506, 39.18090216815472, 41.09268978238106, 38.39554511010647, 38.28369051218033, 39.517305716872215, 40.423120111227036, 41.77656568586826, 43.23673993349075, 45.96180930733681, 52.51151405274868, 49.122920483350754, 55.273312255740166, 48.88837046921253, 50.401920452713966, 53.60575653612614, 51.1630842089653, 51.68817423284054, 47.62160584330559, 42.98770509660244, 37.42487579584122, 37.13470056653023, 35.312534943223, 36.542350351810455, 37.9902208596468, 38.89702320098877, 38.46736125648022, 37.426726296544075, 37.55759507417679, 37.49227657914162, 37.12849549949169, 38.42083275318146, 36.57524138689041, 36.06388382613659, 36.59130312502384, 37.388591542840004, 37.95637607574463, 36.875683665275574, 37.41963967680931, 36.57896898686886, 38.81884999573231, 47.5170012563467, 48.91463465988636, 48.137032985687256, 45.201367512345314, 44.703442230820656, 48.689994513988495, 48.53975057601929, 49.95582818984985, 47.798398956656456, 48.428545743227005, 46.43616825342178, 48.158752620220184, 47.868850976228714, 49.801020696759224, 46.27087712287903, 47.045419961214066, 46.481085643172264, 46.86277516186237, 41.10391438007355, 38.668697252869606, 36.907567754387856, 35.402217730879784, 37.59614020586014, 38.69528442621231, 39.84090015292168, 39.677516520023346, 47.08253636956215, 52.1313102543354, 49.43791598081589, 53.544484823942184, 38.746129497885704, 5.016220081597567, 0.5926365056075156, 6.665793266147375, 4.574526557698846, 1.7711397050879896, 0.3192268079146743, 3.5906864376738667, 50.75694680213928, 52.25014887750149, 37.073960825800896, 18.98335576057434, 25.716784447431564, 38.9394099265337, 38.081119582057, 3.5395858297124505, 0.06399514924851246, 0.056361403403570876, 0.049541697080712765, 0.04262515532900579, 0.05549972542212345, 0.0427644304727437, 0.022651211693300866, 0.09914863636367954, 0.05987586599076167, 0.03951148588384967, 0.07141506008338183, 0.012908174539916217, 0.014021281949680997, 0.005806926610603114, 0.03519223835610319, 0.013537115009967238, 0.03756798294489272, 0.08805818186374381, 0.025168402207782492, 0.029873603634769097, 0.06731730652973056, 0.004805661783393589, 0.01850253753218567, 0.04193920307443477, 0.03574933893105481, 0.0862303760368377, 0.15152969397604465, 0.5427923239767551, 24.245129115879536, 59.44835722446442, 44.19719159603119, 38.04316721856594, 36.310194209218025, 38.426600843667984, 56.06111638247967, 53.389669731259346, 58.62078823149204, 25.381365045905113, 0.0790182665514294, 0.41238067962694913, 5.917691309005022, 4.042912758886814, 0.816063447855413, 22.494819536805153, 55.43689347803593, 55.71783900260925, 52.68450357019901, 52.30594128370285, 43.75651404261589, 40.44637106359005, 41.48766718804836, 45.043208599090576, 51.07881233096123, 50.535494685173035, 50.96564680337906, 51.16378337144852, 47.41700582206249, 46.55102849006653, 46.87908008694649, 50.358819365501404, 50.085279643535614, 52.30426177382469, 50.68128526210785, 48.702112063765526, 47.10226111114025, 41.215955168008804, 40.11028289794922, 40.172261372208595, 38.47379811108112, 37.65157163143158, 38.81163418292999, 40.10317727923393, 39.069963321089745, 39.10158522427082, 39.049357026815414, 40.54654888808727, 39.188722148537636, 38.43445882201195, 39.41183477640152, 36.721879318356514, 38.56619015336037, 39.44083862006664, 38.773244842886925, 39.346143901348114, 38.654505014419556, 39.20303218066692, 40.16052380204201, 41.01656086742878, 38.94602157175541, 40.90300776064396, 41.30387105047703, 41.92447654902935, 39.716798812150955, 38.80189150571823, 42.263475358486176, 41.95185028016567, 43.03453378379345, 44.53851208090782, 47.19566009938717, 53.12187910079956, 51.74346126616001, 56.300431340932846, 51.44743055105209, 51.72414690256119, 53.10259513556957, 54.451302364468575, 53.088782876729965, 49.45014752447605, 43.88276606798172, 40.999492183327675, 37.81278558075428, 38.193965926766396, 39.46332961320877, 38.84607173502445, 40.39757788181305, 39.9923562258482, 38.90508636832237, 39.382785335183144, 39.18966829776764, 38.61328482627869, 39.81376960873604, 38.61769638955593, 36.835801005363464, 38.636315390467644, 37.50568225979805, 40.570878982543945, 36.776417791843414, 38.06706793606281, 37.91190706193447, 41.38397455215454, 49.663080498576164, 49.90231566131115, 50.09334281086922, 47.52084665000439, 46.52481749653816, 50.2813833206892, 50.21431311964989, 51.42927512526512, 51.087848246097565, 51.85067631304264, 48.266568034887314, 50.15674240887165, 50.21234102547169, 50.80510161817074, 48.779810294508934, 47.91088432073593, 47.81034171581268, 47.356912046670914, 43.36044229567051, 41.797190979123116, 37.97585763037205, 38.73113930225372, 40.04597894847393, 41.906875893473625, 41.57721698284149, 41.24580256640911, 47.73529574275017, 54.29749421775341, 53.221646547317505, 56.8348802626133, 39.52160708606243, 5.141476560384035, 0.8620751195121557, 10.133638232946396, 8.492383752018213, 4.984230548143387, 0.35370773111935705, 3.514147619716823, 55.29301419854164, 56.01881705224514, 44.13260266184807, 25.5234869197011, 32.239791825413704, 45.553893595933914, 46.92717410624027, 5.275058867409825, 0.038802827621111646, 0.04014235222712159, 0.08174752205377445, 0.016826384016894735, 0.048461426922585815, 0.05344503391825128, 0.07714559789747, 0.06869278819067404, 0.03211942042980809, 0.04420346594997682, 0.06250214108149521, 0.044809763494413346, 0.10847433790331706, 0.1691509218653664, 0.2003717832849361, 0.09520542764221318, 0.11970680236117914, 0.18010537780355662, 0.16033947671530768, 0.16167719790246338, 0.08820270770229399, 0.09667133999755606, 0.11612977672484703, 0.15989194682333618, 0.1578205087571405, 0.16129361145431176, 0.2751019428251311, 0.655078673735261, 30.87403491139412, 67.47147470712662, 49.360016360878944, 43.49646359682083, 36.779951602220535, 40.02325616776943, 60.98858177661896, 59.238916262984276, 66.17155686020851, 30.232728123664856, 0.287092822836712, 2.288655429147184, 8.942097220569849, 9.32315407320857, 2.3155328119173646, 25.325715132057667, 57.154245525598526, 56.469567865133286, 54.779741540551186, 55.884080082178116, 45.97357727587223, 42.216190695762634, 43.59096832573414, 48.76644641160965, 54.28991362452507, 52.1025799959898, 52.680149003863335, 51.94692514836788, 48.820209726691246, 47.0003467798233, 48.841158002614975, 52.24298246204853, 52.16887503862381, 52.90582649409771, 53.048444241285324, 50.176322758197784, 49.568590968847275, 43.52827548980713, 41.54979385435581, 42.61759735643864, 40.87160624563694, 39.31832559406757, 39.4293974339962, 42.64679878950119, 41.056337133049965, 41.85668058693409, 40.748838633298874, 42.05950990319252, 41.70334741473198, 40.633169040083885, 40.35718224942684, 38.74030441045761, 40.865503773093224, 40.62324017286301, 41.69013552367687, 41.63726516067982, 40.872734785079956, 42.47090622782707, 42.78405502438545, 44.76504072546959, 41.5898323059082, 42.8005613386631, 43.27906586229801, 43.995312228798866, 41.25202663242817, 41.467714458703995, 45.269919633865356, 45.06294094026089, 46.83382831513882, 47.56525866687298, 48.96049439907074, 54.869447126984596, 54.71487522125244, 55.18156997859478, 51.70541010797024, 55.12425385415554, 57.092624232172966, 55.08896514773369, 56.87987744808197, 51.51547349989414, 46.30725257098675, 44.205292761325836, 40.77873542904854, 39.456087201833725, 42.56193794310093, 41.674677953124046, 43.4917176514864, 41.65747247636318, 40.23601055145264, 40.488924980163574, 41.363037675619125, 40.19407220184803, 42.24976569414139, 39.98958617448807, 39.65271145105362, 40.56341618299484, 39.63952615857124, 43.18183667957783, 40.36980137228966, 41.201223358511925, 38.7152561545372, 41.60520248115063, 49.79995295405388, 54.86191973090172, 51.94358892738819, 48.86367939412594, 47.90198139846325, 51.25426411628723, 50.79217471182346, 54.179339557886124, 53.32021705806255, 55.142394080758095, 50.52327074110508, 52.76496425271034, 52.60871663689613, 54.47210244834423, 51.30351707339287, 48.98933865129948, 48.68799962103367, 50.566683411598206, 44.78430949151516, 44.6199569106102, 42.14956887066364, 39.4961104542017, 42.532614916563034, 42.93307542800903, 44.25950065255165, 42.461243346333504, 50.75298361480236, 56.31401941180229, 55.36080256104469, 58.21641393005848, 41.54435634613037, 7.160610789433122, 2.7571764634922147, 17.898297384381294, 15.776525437831879, 7.810001168400049, 1.1705277836881578, 4.197804322466254, 61.156737953424454, 62.59611211717129, 48.18050645291805, 28.117127045989037, 38.93895395100117, 50.67079022526741, 55.510157346725464, 6.591961327940226, 0.24011990666622296, 0.16844206693349406, 0.15433147957082838, 0.11789587297243997, 0.1527938386425376, 0.1122859341558069, 0.1663512142840773, 0.1837729083490558, 0.2308271045330912, 0.1504138601012528, 0.2856702741701156, 0.21126526437001303], [0.010627146548358724, 0.03209500006050803, 0.021867292234674096, 0.03599470037443098, 0.049087005463661626, 0.06337046128464863, 0.021312791031959932, 0.03098672124906443, 0.037553221627604216, 0.04293968864658382, 0.07377777626970783, 0.014315251282823738, 0.028098455040890258, 0.027642761524475645, 0.12274787863134407, 0.1518933760235086, 14.752967711538076, 43.164992183446884, 39.89027090370655, 42.26936884224415, 53.38715806603432, 40.53987264633179, 39.216711446642876, 54.657939076423645, 47.01276071369648, 38.020927011966705, 0.7246262824628502, 0.2545483410358429, 2.7493294095620513, 2.273000031709671, 0.5125361506361514, 22.50019434839487, 54.962599128484726, 54.70863975584507, 52.879900485277176, 49.34066399931908, 41.42206370830536, 40.01814164221287, 44.030992314219475, 48.422207683324814, 49.71109852194786, 54.01271849870682, 49.22379747033119, 42.19179980456829, 47.82684803009033, 49.75914694368839, 49.06585514545441, 48.77751521766186, 49.14954945445061, 47.92367443442345, 48.635079860687256, 47.025756016373634, 46.17000013589859, 43.30984801054001, 37.93619155883789, 35.43570913374424, 35.50220936536789, 36.521812453866005, 37.86677308380604, 36.84130311012268, 38.575894832611084, 36.922060176730156, 36.832962557673454, 36.520638316869736, 36.98929376900196, 37.978737875819206, 37.47163228690624, 35.60301415622234, 37.58505240082741, 36.62378378212452, 38.638675063848495, 37.209130972623825, 35.977373868227005, 37.23194494843483, 39.44837361574173, 38.38471569120884, 36.92987635731697, 40.09549789130688, 37.35739901661873, 39.19508680701256, 37.66201727092266, 38.28484944999218, 40.191435143351555, 42.220229879021645, 44.82176788151264, 44.952541664242744, 47.18541204929352, 52.94825501739979, 49.82888080179691, 55.01483112573624, 43.40636283159256, 48.0465142428875, 53.036987856030464, 50.52229419350624, 50.867870450019836, 47.629106640815735, 41.705076321959496, 40.000696778297424, 35.86900748312473, 35.647384375333786, 36.42076827585697, 38.44961240887642, 40.09613625705242, 38.59413765370846, 37.26532235741615, 37.82224327325821, 36.52843549847603, 37.84626178443432, 38.441925421357155, 36.99083648622036, 37.55025386810303, 37.07586832344532, 35.323679745197296, 35.63791148364544, 34.899789690971375, 34.963573068380356, 36.55037932097912, 37.682000398635864, 45.93626327812672, 45.11273346841335, 48.62778425216675, 47.67310447990894, 49.48412150144577, 47.37234681844711, 45.28250075876713, 45.87615430355072, 47.29869917035103, 50.00021740794182, 47.22866132855415, 49.20244261622429, 47.76942551136017, 50.355133563280106, 51.45271986722946, 50.51726706326008, 51.21996335685253, 49.75864537060261, 49.702450186014175, 48.30898515880108, 42.39487610757351, 40.304893255233765, 36.827517449855804, 39.11042734980583, 39.320324286818504, 42.42452971637249, 46.139681562781334, 52.53564655780792, 50.54247871041298, 56.777537539601326, 31.9560344517231, 2.7997025940567255, 0.3994603338651359, 10.527829080820084, 6.768801938742399, 2.9738757479935884, 0.16306817560689524, 4.83360568061471, 53.43983083963394, 45.89058592915535, 40.00089056789875, 24.24436915665865, 31.12955790013075, 48.050405234098434, 23.10585144907236, 0.5617117462679744, 0.08355259589734487, 0.06727373503963463, 0.006523237807414262, 0.05382151801313739, 0.05375189342885278, 0.0366296596621396, 0.06682954481220804, 0.020771761664946098, 0.05018397394451313, 0.0448994297767058, 0.034505376970628276, 0.03297500908956863, 0.09239760838681832, 0.03863816731609404, 0.043121255075675435, 0.04215985842165537, 0.06704188068397343, 0.09282640647143126, 0.06349411050905474, 0.060689274687319994, 0.03628632359323092, 0.06581116234883666, 0.04098190678632818, 0.015701436568633653, 0.04279512941138819, 0.028406780293153133, 0.00300873092328402, 0.35252982401289046, 19.515407010912895, 52.43631228804588, 42.607527896761894, 42.65579670667648, 44.21326853334904, 40.55236257612705, 48.49459379911423, 56.25613331794739, 53.28736402094364, 39.905143305659294, 0.6140509096439928, 0.48048941243905574, 5.501952767372131, 4.272393370047212, 0.6466422358062118, 24.37864065170288, 56.67365871369839, 56.13251835107803, 54.536041617393494, 50.08547343313694, 43.08933824300766, 41.402012184262276, 45.105008482933044, 50.81160306930542, 51.17465078830719, 53.657608553767204, 51.670087203383446, 45.97307190299034, 46.13389067351818, 51.75446167588234, 49.92726892232895, 49.449790343642235, 51.5787249058485, 49.54654835164547, 49.08053755760193, 49.35177080333233, 47.151202484965324, 44.02213118970394, 39.22554977238178, 36.91612109541893, 37.18819409608841, 39.816186279058456, 39.47877578437328, 39.27599586546421, 38.14812898635864, 39.2093550413847, 38.49531635642052, 38.726613745093346, 38.81806343793869, 38.957208171486855, 37.84692294895649, 38.15556898713112, 38.14261928200722, 39.4904525578022, 40.58538660407066, 39.501251578330994, 37.5911320745945, 38.709575459361076, 41.65363848209381, 40.08328914642334, 39.468067958950996, 39.87738199532032, 39.707048535346985, 40.79982049763203, 39.706706553697586, 39.146848395466805, 40.796750262379646, 44.39945474267006, 44.99607212841511, 47.42984153330326, 48.535787388682365, 51.70524671673775, 52.66024187207222, 55.180167853832245, 44.39193494617939, 48.59809264540672, 54.486674666404724, 52.835351675748825, 53.68069991469383, 51.3812343031168, 44.7183146327734, 41.04263886809349, 36.410071849823, 38.8951651006937, 38.641186729073524, 39.66571055352688, 40.475059524178505, 39.391285479068756, 39.71507750451565, 38.373787477612495, 37.97824390232563, 39.52112831175327, 39.28594373166561, 37.55197897553444, 38.244465216994286, 40.027853921055794, 37.41446815431118, 37.868467792868614, 36.25773802399635, 36.77403151988983, 38.2190103828907, 40.082126408815384, 46.84157229959965, 49.55811873078346, 49.06084321439266, 49.965966045856476, 50.9098581969738, 47.54412420094013, 45.89437432587147, 48.75681392848492, 50.52374191582203, 51.08719848096371, 49.16113123297691, 51.93468600511551, 49.943953827023506, 53.68562065064907, 52.9055605083704, 52.559642270207405, 52.69917078316212, 51.933249682188034, 50.670022666454315, 49.821721985936165, 45.08574351668358, 41.11908316612244, 38.384043127298355, 41.3992041349411, 40.90379811823368, 44.16769377887249, 48.51954326033592, 55.15897639095783, 53.63787621259689, 57.809501364827156, 34.40249517560005, 3.4665644355118275, 1.3516135979443789, 9.385701566934586, 8.874829430133104, 6.035381443798542, 0.1993318265886046, 5.450126398354769, 59.30108852684498, 50.69184489548206, 48.00470508635044, 24.69599012285471, 32.829972356557846, 50.42198717594147, 29.977828301489353, 1.013933198992163, 0.04092159986612387, 0.15072394424350932, 0.0924625685729552, 0.04128868837142363, 0.04970731846697163, 0.020419013308128342, 0.1665981565020047, 0.03610325431509409, 0.018198216166638304, 0.03188748443790246, 0.0706437460030429, 0.04595525359036401, 0.22029334242688492, 0.2070567081682384, 0.0950536435993854, 0.1533957352512516, 0.1890723325777799, 0.20169004536001012, 0.13129857019521296, 0.2894486964214593, 0.14375125902006403, 0.17803949100198224, 0.2481343297404237, 0.11894152194145136, 0.09076247893972322, 0.12830677995225415, 0.1707076805178076, 0.47379467636346817, 23.49029392004013, 59.24389399588108, 53.37855912744999, 53.81321780383587, 61.49019666016102, 52.58901849389076, 50.75938627123833, 62.98961520195007, 56.57905898988247, 46.89445786178112, 0.8024493127595633, 0.9790755913127214, 9.816885329782963, 6.610237397253513, 1.550140951294452, 25.807487480342388, 57.64017105102539, 59.29998658597469, 58.072861433029175, 53.67562718689442, 44.21487204730511, 43.32825042307377, 47.325947508215904, 53.42489764094353, 54.51852835714817, 56.438447535037994, 51.74097999930382, 48.11995670199394, 48.27297069132328, 52.03197218477726, 53.178385868668556, 53.36249738931656, 52.170474752783775, 51.018072590231895, 52.6441041380167, 52.92466588318348, 51.27602554857731, 49.14232224225998, 41.63804031908512, 39.47073541581631, 38.283937498927116, 41.06346555054188, 42.399116680026054, 42.709221839904785, 40.743746906518936, 41.57807573676109, 39.71868731081486, 41.19257502257824, 39.838582277297974, 41.363869830965996, 40.357398837804794, 38.89409355819225, 41.660398319363594, 40.550109297037125, 41.986325830221176, 41.55171275138855, 39.636216536164284, 41.28688596189022, 43.87530706822872, 43.42257276177406, 41.010519191622734, 42.70973481237888, 41.58144995570183, 42.26604402065277, 41.77408441901207, 41.56592018902302, 45.58296963572502, 46.46797254681587, 48.147262036800385, 50.58739610016346, 50.41906513273716, 56.01675756275654, 53.4004345536232, 54.254237338900566, 45.295610055327415, 48.84035624563694, 57.43261858820915, 54.47068892419338, 54.10521313548088, 52.30005919933319, 47.160842567682266, 43.69105115532875, 40.68542763590813, 40.64906358718872, 40.63512973487377, 43.10371667146683, 43.11640039086342, 42.27112054824829, 41.690720692276955, 39.9933859705925, 40.0499003380537, 41.544257551431656, 42.13550202548504, 40.59002995491028, 41.48166351020336, 42.224698439240456, 37.352987453341484, 39.644663482904434, 38.59560437500477, 37.84270137548447, 40.53419575095177, 42.01306499540806, 49.58256281912327, 48.79016473889351, 53.020276352763176, 52.735287845134735, 52.705155462026596, 50.66603668034077, 46.291145235300064, 48.28372411429882, 52.51980520784855, 53.73934596776962, 51.8149658292532, 54.03407335281372, 50.94993084669113, 55.15374407172203, 55.18855020403862, 55.20523510873318, 54.37159784138203, 53.536022678017616, 51.750418692827225, 54.12576623260975, 46.37327402830124, 43.659953624010086, 40.506248250603676, 43.86587217450142, 43.37784916162491, 46.789458096027374, 51.0977429151535, 58.34310673177242, 54.857302978634834, 59.310854002833366, 36.30225643515587, 5.327791012823582, 2.8264949563890696, 17.412736639380455, 13.180539887398481, 11.461082752794027, 0.5843513470608741, 5.878092208877206, 64.7024492919445, 53.586426973342896, 54.13967728614807, 34.41534988582134, 41.261206939816475, 60.77789828181267, 36.577749252319336, 1.595539846457541, 0.17290335410507396, 0.24798300582915545, 0.1546210507513024, 0.12612749298568815, 0.1356951124034822, 0.21437933086417615, 0.23879943299107254, 0.18684483569813892, 0.18817167700035498, 0.13087711937259883, 0.1471515273442492, 0.12161536127678119], [0.02218644913227763, 0.01446378471882781, 0.10154051895369776, 0.027130974631290883, 0.034388677959213965, 0.035783006460405886, 0.0994453247403726, 0.05340681331290398, 0.015868800146563444, 0.1039276592200622, 0.02079197220155038, 0.04600414256856311, 0.07024448539596051, 0.04990105611796025, 0.10489291133126244, 0.038519123118021525, 6.886346731334925, 42.31680549681187, 42.87054978311062, 48.24021264910698, 56.62541650235653, 51.37316733598709, 36.57210275530815, 50.94384357333183, 50.640429854393005, 44.77957494556904, 3.222172474488616, 0.4567702242638916, 5.569759178906679, 4.0004457626491785, 0.5470173410139978, 19.516761638224125, 52.27026879787445, 54.32183191180229, 50.54614931344986, 48.98702457547188, 40.611764788627625, 41.24080963432789, 47.29535534977913, 50.80788306891918, 50.884486958384514, 54.65106904506683, 41.14124357700348, 46.61374792456627, 48.03085908293724, 48.805759102106094, 50.31102553009987, 48.59812684357166, 48.47935661673546, 49.95146222412586, 47.843384742736816, 47.923989817500114, 46.42424449324608, 45.96732661128044, 38.77055838704109, 35.5515269190073, 35.84266349673271, 35.49487575888634, 35.7898311316967, 36.56513772904873, 35.960711762309074, 36.71598203480244, 36.07378229498863, 38.077532574534416, 38.64561349153519, 37.60940909385681, 37.363201305270195, 36.57503239810467, 39.4364308565855, 39.426862969994545, 37.92234130203724, 36.81627005338669, 36.620941534638405, 38.344399854540825, 37.392132952809334, 38.179773688316345, 37.15026073157787, 39.025973081588745, 37.45565414428711, 38.31328332424164, 35.758775398135185, 36.67057827115059, 38.67900229990482, 43.919095918536186, 48.464879393577576, 48.44401091337204, 49.95031088590622, 52.53978453576565, 52.533727660775185, 52.08372920751572, 44.46796886622906, 45.66033348441124, 52.6655425876379, 51.73640124499798, 51.46101102232933, 48.32817032933235, 43.38274709880352, 38.79974082112312, 37.72486209869385, 36.70944258570671, 36.05278842151165, 38.47856305539608, 38.606954365968704, 38.748196586966515, 37.0762825012207, 36.856946870684624, 38.26588846743107, 36.82276010513306, 37.06980764865875, 36.59979186952114, 37.27153122425079, 35.491984114050865, 38.054600805044174, 37.325556725263596, 34.726553186774254, 35.94900079071522, 36.5885254740715, 37.25813314318657, 42.00616456568241, 42.34997771680355, 45.93033939599991, 46.892831549048424, 47.62923203408718, 50.461850836873055, 45.23672081530094, 47.75930665433407, 48.76709997653961, 49.696875885128975, 46.459278613328934, 48.404534831643105, 46.63439221680164, 47.67704866826534, 46.2998353689909, 48.69070127606392, 48.40591035783291, 52.242017313838005, 50.338437259197235, 49.62719142436981, 47.495881989598274, 48.80594529211521, 42.87127174437046, 44.15822468698025, 39.33800093829632, 44.24080565571785, 47.22300723195076, 53.20160262286663, 49.96640682220459, 54.13005240261555, 27.934974320232868, 1.2984056468121707, 0.18846590886823833, 7.666000770404935, 6.679859636351466, 4.683276247233152, 0.08584284136304632, 7.6740435138344765, 52.864302322268486, 47.606486454606056, 32.25607395172119, 23.835159614682198, 34.73811216652393, 47.86250911653042, 16.935014873743057, 0.14524177357088774, 0.07337069342611358, 0.0245916644053068, 0.031060954570421018, 0.04192290551145561, 0.03590593580156565, 0.033433288990636356, 0.030731416882190388, 0.04586367627780419, 0.007173747408160125, 0.0995915055682417, 0.06364684450090863, 0.01958002834726358, 0.03179623367032036, 0.05706553827621974, 0.014122655611572554, 0.0032673188297849265, 0.09691831932286732, 0.037383722519734874, 0.03339871975185815, 0.03256165138736833, 0.03271075627708342, 0.1215430983575061, 0.010455783722136403, 0.011150380141771166, 0.12367154078674503, 0.03026395475899335, 0.10618427055305801, 0.07614223650307395, 10.450810063630342, 49.29706133902073, 48.87690648436546, 54.246500954031944, 59.59817178547382, 50.7644248008728, 41.057340279221535, 57.34904207289219, 53.390019312500954, 47.43096247315407, 2.5566146755591035, 0.235224804491736, 7.138305036351085, 4.705717843025923, 0.9088725771289319, 21.507900394499302, 54.349866807460785, 56.294632852077484, 53.77904623746872, 49.51155982911587, 42.47789025306702, 42.871378138661385, 49.44372206926346, 52.738460674881935, 52.74078615009785, 54.06147748231888, 42.2598959505558, 45.42326420545578, 50.32769523561001, 49.95851084589958, 52.49496594071388, 49.009462371468544, 50.676505118608475, 50.41533373296261, 51.462823525071144, 49.61319677531719, 47.16877654194832, 47.04676128923893, 40.64524859189987, 37.610260248184204, 38.34452144801617, 36.64179101586342, 38.654273226857185, 37.97602102160454, 39.13708671927452, 39.368680492043495, 37.964458242058754, 40.08112706243992, 39.24832575023174, 40.66749259829521, 38.92026275396347, 37.75610402226448, 40.86010426282883, 41.30322888493538, 40.001931712031364, 37.99847401678562, 39.160337671637535, 40.223756209015846, 39.991900250315666, 38.81885379552841, 39.71634663641453, 40.356585681438446, 40.538424924016, 39.28581453859806, 38.655078783631325, 38.06633077561855, 41.2007749825716, 46.14773713052273, 50.08373312652111, 50.108880177140236, 52.78458259999752, 51.53517924249172, 56.19477801024914, 51.82210184633732, 43.94948288798332, 47.73963510990143, 52.413331121206284, 53.84407974779606, 52.18886196613312, 51.20405741035938, 44.81141343712807, 40.743849501013756, 39.419172182679176, 39.00721728801727, 37.82983906567097, 39.66733306646347, 41.27989433705807, 41.44795931875706, 37.84194141626358, 38.94425466656685, 38.85619439184666, 38.61760139465332, 38.79749894142151, 38.395757898688316, 38.55617769062519, 39.0886165201664, 37.87759490311146, 39.82969455420971, 35.935055539011955, 36.577749252319336, 38.51458892226219, 40.04757486283779, 42.632431760430336, 46.2895455211401, 47.655758410692215, 49.54927280545235, 48.90643090009689, 51.50739133358002, 46.12923972308636, 48.15225876867771, 49.306747019290924, 51.3816674798727, 48.54515768587589, 50.73209993541241, 48.18350449204445, 47.549744099378586, 47.84438028931618, 51.43833763897419, 50.71911983191967, 54.525907561182976, 52.70734794437885, 51.033636555075645, 50.03431297838688, 49.315915927290916, 44.406697154045105, 46.006673499941826, 40.95650888979435, 46.18977427482605, 48.24542596936226, 57.08401769399643, 52.70663358271122, 55.38140885531902, 30.290789008140564, 1.8755237851291895, 1.6836890601553023, 8.680998031049967, 8.833478149026632, 5.912791471928358, 0.07322551449760795, 8.538822010159492, 58.51863071322441, 52.14403197169304, 38.936233296990395, 27.608018964529037, 39.419643357396126, 53.53407718241215, 21.955921053886414, 0.2751903177704662, 0.13891846756450832, 0.0709003435622435, 0.04934110940666869, 0.07543566738604568, 0.08556168613722548, 0.03503414976876229, 0.0298387226939667, 0.034948030952364206, 0.02638370613567531, 0.022445254580816254, 0.08509185470757075, 0.02952859031211119, 0.12620391935342923, 0.16734589997213334, 0.12234593144967221, 0.15365367609774694, 0.154300442954991, 0.25311059318482876, 0.123640207311837, 0.11732798899174668, 0.1503458496881649, 0.22685974632622674, 0.13086784252664074, 0.07545718224719167, 0.1574507262557745, 0.19731202715774998, 0.19946228130720556, 0.15489248384255916, 12.294247895479202, 59.57408867776394, 56.075221225619316, 61.34182222187519, 63.532974645495415, 56.800362914800644, 48.98982882499695, 60.62824331223965, 57.25797235965729, 54.12436790764332, 4.0769171342253685, 0.5828230571933091, 14.846003819257021, 8.017415888607502, 1.1476987274363637, 23.221965618431568, 57.0766194909811, 58.02843801677227, 56.040525287389755, 53.03378842771053, 44.8009829968214, 45.25528281927109, 51.38190306723118, 56.13078944385052, 54.52469922602177, 55.670892521739006, 43.85348863899708, 44.756753370165825, 50.72818994522095, 53.67495842278004, 54.787458926439285, 51.52706667780876, 52.96368978917599, 53.46203684806824, 52.61376656591892, 52.32329115271568, 49.02372680604458, 49.475138783454895, 43.52474927902222, 40.1064109057188, 39.59830217063427, 39.111415296792984, 40.13063460588455, 41.05236254632473, 41.53549902141094, 41.50693595409393, 39.99252341687679, 42.009409591555595, 39.61866147816181, 42.715806886553764, 41.628765016794205, 38.653783053159714, 42.57545381784439, 42.534484416246414, 42.74339720606804, 40.87083488702774, 40.37832051515579, 42.64310158789158, 41.59959018230438, 42.470617443323135, 41.04586109519005, 41.84929758310318, 42.29580782353878, 42.00039267539978, 40.17779767513275, 39.82262693345547, 42.90557250380516, 47.59585462510586, 52.605597004294395, 52.99140930175781, 53.67666833102703, 55.459943041205406, 57.23135098814964, 53.33778731524944, 43.78909349441528, 47.570092007517815, 55.6795484572649, 56.17354094982147, 55.275196954607964, 51.19602084159851, 47.227540388703346, 43.354066237807274, 42.54772290587425, 41.62055365741253, 40.83858601748943, 43.47097836434841, 44.206098318099976, 42.532333731651306, 40.71852385997772, 40.06399378180504, 42.18173414468765, 40.16773201525211, 40.051059275865555, 40.767267644405365, 40.7043582201004, 40.94807334244251, 41.50123246014118, 40.83653412759304, 38.16439971327782, 38.07532489299774, 41.16980284452438, 42.090976014733315, 47.425764352083206, 46.754541769623756, 49.94805380702019, 50.70358246564865, 52.39153549075127, 54.53511066734791, 47.89881996810436, 50.193832218647, 52.12109260261059, 53.593475595116615, 49.46316182613373, 52.17741698026657, 49.231860637664795, 48.68533216416836, 48.763433173298836, 51.218766421079636, 52.43472017347813, 56.88152655959129, 53.691096156835556, 54.555002599954605, 52.49620087444782, 53.33822809159756, 47.1830827742815, 50.12535609304905, 43.21125850081444, 47.57223889231682, 51.01630948483944, 58.18699590861797, 54.8541035503149, 55.16217961907387, 33.04846063256264, 2.690762202255428, 2.382321353070438, 18.193568140268326, 18.092921040952206, 13.258320763707161, 0.257826674496755, 9.442326128482819, 64.02438327670097, 57.047304064035416, 43.59793335199356, 35.265409871935844, 46.969044059515, 60.01522220671177, 28.0827958881855, 0.6127203872893006, 0.24519438593415543, 0.125464012962766, 0.10746834188466892, 0.1325188687769696, 0.17502583708846942, 0.16715935373213142, 0.22198959515662864, 0.12998802645597607, 0.16103779315017164, 0.115162928996142, 0.18552817666204646, 0.1797892525792122], [0.054734003424528055, 0.02732999637373723, 0.035947856013081037, 0.041914534085663036, 0.05923358541622292, 0.07165680726757273, 0.09628089610487223, 0.026388515252619982, 0.058151827252004296, 0.033953553065657616, 0.029677734164579306, 0.041954561820602976, 0.024365272256545722, 0.05929121689405292, 0.028782971239706967, 0.0950807542540133, 1.8792231241241097, 34.42121297121048, 39.49260324239731, 33.14614579081535, 51.74241632223129, 74.29001122713089, 43.635650128126144, 45.81835940480232, 47.25569687783718, 48.21280471980572, 8.566508274525404, 0.12224938545841724, 4.355874415487051, 2.5644652917981148, 0.211429976625368, 14.609819892793894, 54.0882508456707, 53.297562673687935, 54.28022414445877, 47.041544169187546, 41.92670702934265, 43.34159530699253, 51.2310815602541, 49.22958455979824, 53.49669858813286, 43.98008644580841, 44.24019768834114, 49.61838349699974, 48.38341936469078, 51.04280926287174, 49.026158675551414, 46.01216420531273, 49.47975933551788, 48.768790885806084, 48.38363215327263, 49.21691603958607, 48.32151688635349, 46.26738131046295, 40.47040097415447, 37.35939770936966, 35.27482196688652, 35.05925193428993, 38.115640729665756, 36.37567989528179, 37.68899202346802, 36.96063190698624, 38.2842680811882, 37.15658359229565, 37.809985131025314, 37.11822085082531, 38.5896310955286, 37.599575221538544, 38.1663566082716, 36.9776625931263, 37.54249468445778, 35.6574310362339, 37.646818086504936, 37.35385000705719, 38.13367456197739, 37.18046151101589, 36.869759783148766, 37.33050785958767, 38.07678781449795, 37.29831598699093, 36.96632020175457, 38.29606644809246, 40.44722601771355, 47.32889614999294, 52.89547584950924, 51.11500918865204, 51.14657789468765, 52.04518027603626, 55.281971991062164, 49.196583330631256, 45.59265151619911, 46.190070658922195, 50.344509333372116, 50.916876420378685, 51.35566547513008, 45.42647883296013, 42.68182530999184, 36.96860767900944, 37.55550518631935, 37.0091363042593, 36.74736835062504, 38.49975071847439, 38.06537702679634, 37.912355437874794, 36.13491341471672, 37.08232417702675, 36.785670295357704, 36.58255219459534, 36.65578946471214, 35.93338742852211, 36.25255510210991, 35.675552263855934, 35.836234241724014, 36.30935825407505, 36.6971692442894, 34.59770210087299, 36.88654348254204, 36.18857033550739, 38.62972654402256, 41.386938393116, 46.85351125895977, 48.45672883093357, 46.75236828625202, 48.19122187793255, 46.166052147746086, 47.21776731312275, 46.40979766845703, 48.37234675884247, 48.502257987856865, 48.39502774178982, 49.73332352936268, 52.055979296565056, 46.1965911090374, 43.926186338067055, 46.98678910732269, 46.66278049349785, 50.9486199170351, 54.205375760793686, 50.571227967739105, 50.49712434411049, 48.27428542077541, 47.3098211735487, 42.7022036164999, 45.063351318240166, 45.87152615189552, 53.04303713142872, 48.966775462031364, 51.28785811364651, 25.681111961603165, 1.6784430854022503, 1.0476033110171556, 5.932824946939945, 6.9003489799797535, 4.074275800958276, 0.08368663518922403, 12.575459405779839, 53.88783819973469, 37.67593212425709, 34.76733259856701, 21.79984252899885, 30.990111082792282, 45.546012818813324, 10.065599083900452, 0.14753800816833973, 0.08464073282084428, 0.04108097607968375, 0.052342996568768285, 0.020005846708954778, 0.025625550333643332, 0.03800350859819446, 0.04280665496480651, 0.11024165869457647, 0.030894461160642095, 0.032291936367983, 0.021195878653088585, 0.09887076143058948, 0.07772367156576365, 0.08651300813653506, 0.047045720857568085, 0.051979192066937685, 0.04513197432970628, 0.049657865456538275, 0.05076413675851654, 0.025581668996892404, 0.03683605835249182, 0.04322206470533274, 0.017953108908841386, 0.04699841265392024, 0.06004267110256478, 0.07194577730842866, 0.05658457834215369, 0.030988034850452095, 3.3352159336209297, 44.10565830767155, 44.553813859820366, 41.02420225739479, 55.724899023771286, 67.6559168100357, 44.98595327138901, 51.75467826426029, 52.480614110827446, 53.38270850479603, 7.808523997664452, 0.11011550843250006, 3.4420141903683543, 4.124017506837845, 0.8027643989771605, 16.441675946116447, 57.1681147813797, 54.097438752651215, 56.07228398323059, 47.88928247988224, 44.32465195655823, 44.29753661155701, 53.05658720433712, 52.03155040740967, 55.440184101462364, 46.66455499827862, 46.492105051875114, 51.0931109637022, 52.30893552303314, 51.35341219604015, 51.522541120648384, 47.30773128569126, 50.45325189828873, 48.77337723970413, 49.33171167969704, 51.61990709602833, 49.980492666363716, 48.953536972403526, 42.56716266274452, 37.954829558730125, 39.32423807680607, 37.27240517735481, 39.2895345389843, 38.53826925158501, 39.6708744764328, 39.67982679605484, 40.158943086862564, 39.67116326093674, 40.42324550449848, 38.808446153998375, 40.0571845471859, 38.66959400475025, 39.74646382033825, 40.08569821715355, 40.134692788124084, 36.9386500865221, 40.32978191971779, 38.69406849145889, 40.08718013763428, 38.91876183450222, 38.590284660458565, 37.7941057831049, 40.24136446416378, 39.47374485433102, 39.05555069446564, 39.826346933841705, 42.1669415384531, 48.69374871253967, 54.68908600509167, 51.08445882797241, 54.33404065668583, 52.67601102590561, 57.781314477324486, 51.41769714653492, 44.864534586668015, 49.93937887251377, 51.132226064801216, 53.38787242770195, 52.6381878554821, 48.35161507129669, 45.5233508348465, 39.108937829732895, 38.16696457564831, 39.01395432651043, 38.802195489406586, 39.6941102296114, 39.4902777671814, 38.676319643855095, 37.55170539021492, 39.26153004169464, 38.459419682621956, 38.0775211751461, 38.668868243694305, 38.48249204456806, 38.27591612935066, 37.649356350302696, 38.929545655846596, 39.69513237476349, 38.49948093295097, 36.9014310836792, 38.939235135912895, 37.491193637251854, 41.049083322286606, 44.71938997507095, 47.71528221666813, 50.3402915596962, 50.21068051457405, 50.27839668095112, 48.587016239762306, 48.450884744524956, 48.08864638209343, 50.54389223456383, 50.44245667755604, 50.10215073823929, 50.32191574573517, 53.55345234274864, 46.016499772667885, 46.11365295946598, 48.27943414449692, 48.177413418889046, 53.16631391644478, 54.94863487780094, 53.28405439853668, 51.99381843209267, 51.36762723326683, 49.020576775074005, 44.10596989095211, 45.77575609087944, 47.84772790968418, 55.32663479447365, 51.214864030480385, 51.40582278370857, 28.403595574200153, 1.7827362078242004, 3.955208477564156, 12.13208494707942, 9.112335685640574, 4.948750426992774, 0.2006094783428125, 13.54224817827344, 60.19610770046711, 45.77388659119606, 40.48683509230614, 22.816217690706253, 35.34327909350395, 52.43716724216938, 14.576049204915762, 0.07698001732933335, 0.04596166945702862, 0.060565829553524964, 0.0956127405515872, 0.03885072954290081, 0.05466874637932051, 0.030948329949751496, 0.020035886991536245, 0.16315732238581404, 0.06657757083303295, 0.015936265081109013, 0.02875490321457619, 0.04898388775472995, 0.18855910777347162, 0.2336531286709942, 0.19872123200912029, 0.10690687005990185, 0.14005392382387072, 0.20075119886314496, 0.34626084321644157, 0.1649050653213635, 0.17438330047298223, 0.09071179025340825, 0.04967649707396049, 0.16617397457594052, 0.1482321388903074, 0.17160045448690653, 0.16542076889891177, 0.19873361103236675, 4.33186492882669, 51.25214383006096, 53.76168876886368, 45.29916666448116, 60.81097550690174, 77.1772862970829, 52.64969363808632, 58.37985835969448, 55.35751573741436, 59.151456356048584, 9.808662571012974, 0.20652415783843026, 10.816571786999702, 8.805313110351562, 0.9215236420277506, 18.77122074365616, 57.986431270837784, 56.77347935736179, 58.377297297120094, 53.445880115032196, 45.91922499239445, 48.005822226405144, 55.7936829328537, 54.211428835988045, 55.28421767055988, 45.65365344285965, 46.62683442234993, 52.027268037199974, 53.53385679423809, 53.31107094883919, 53.23772728443146, 49.265131652355194, 53.25386501848698, 50.53875111043453, 53.286604061722755, 54.82755817472935, 52.644544914364815, 50.589535385370255, 45.27695305645466, 41.254089921712875, 39.76687632501125, 38.94214577972889, 41.535989195108414, 40.35443499684334, 41.85035012662411, 41.66772052645683, 42.22805365920067, 41.43704630434513, 41.135999858379364, 41.363774836063385, 41.98300860822201, 40.63261806964874, 40.89707627892494, 41.91162183880806, 42.40599051117897, 37.89158195257187, 41.75972118973732, 41.010845974087715, 41.68849781155586, 40.611533001065254, 40.5169864743948, 39.23266299068928, 41.78802587091923, 40.08474826812744, 40.075773149728775, 41.639742627739906, 44.3902288377285, 52.207682356238365, 56.848274543881416, 54.406643360853195, 55.28172880411148, 56.76843702793121, 56.968180909752846, 53.8072407245636, 43.882925659418106, 49.75105717778206, 53.097735196352005, 54.25073392689228, 55.634368881583214, 49.312895089387894, 48.01849074661732, 41.317219734191895, 41.38037234544754, 41.75402529537678, 41.37675113976002, 43.19977171719074, 41.148466989398, 41.55009403824806, 40.13471558690071, 39.49692741036415, 39.92612577974796, 39.58652660250664, 40.573561638593674, 39.525125697255135, 40.45453682541847, 39.00737687945366, 39.24376219511032, 40.69395437836647, 40.82600489258766, 37.816030606627464, 40.263714864850044, 39.3969813734293, 41.685875952243805, 47.70474538207054, 50.7831159979105, 53.47196951508522, 52.09325909614563, 51.467592269182205, 49.290172308683395, 49.04918164014816, 49.91231292486191, 52.28889159858227, 52.15263091027737, 52.315121591091156, 52.36033916473389, 55.420136377215385, 47.935936376452446, 46.18272565305233, 49.520819932222366, 49.377845004200935, 54.575977474451065, 56.58899165689945, 54.29741062223911, 55.939587503671646, 54.14087802171707, 52.70514406263828, 46.8948720395565, 48.4188524633646, 49.28338587284088, 57.227365002036095, 53.56577888131142, 51.3787492364645, 30.097331888973713, 2.7964304946362972, 4.685232192277908, 16.132469438016415, 19.33920666575432, 11.63321066647768, 0.23467436840292066, 15.267261564731598, 64.92995828390121, 47.808833196759224, 47.126644402742386, 30.451831966638565, 43.042745143175125, 60.21709397435188, 18.337204232811928, 0.21075502299936488, 0.18580762494821101, 0.10376129939686507, 0.189038579701446, 0.1607027876889333, 0.13555356999859214, 0.15579014114337042, 0.14845769241219386, 0.20682621194282547, 0.2040913829114288, 0.12022875482216477, 0.1985340178362094, 0.20307006896473467], [0.03326028694573324, 0.038155296351760626, 0.057073301140917465, 0.10259944494464435, 0.012536288049886934, 0.024883987098291982, 0.03392429389350582, 0.03224250191124156, 0.017714354435156565, 0.020763405082107056, 0.06574632090632804, 0.022231875991565175, 0.013721649102080846, 0.012595471544045722, 0.02154159144993173, 0.06210565610672347, 0.25990151159930974, 21.724494472146034, 47.51915954053402, 40.15800453722477, 45.20078994333744, 63.031979128718376, 53.921964168548584, 43.65657560527325, 47.62407951056957, 53.903451561927795, 18.515340574085712, 0.07962703544762917, 2.8974205255508423, 2.701865443959832, 0.5128130014054477, 13.033588472753763, 51.00111410021782, 52.86145627498627, 51.86730422079563, 47.97047272324562, 46.99614800512791, 48.21301370859146, 50.232198759913445, 50.99917620420456, 49.49777036905289, 43.81018616259098, 48.8993214815855, 50.65019153058529, 50.854415372014046, 47.35378101468086, 45.34169398248196, 47.640965804457664, 49.10279296338558, 47.71466284990311, 51.221004500985146, 46.031771153211594, 50.06325222551823, 47.1155072003603, 45.96141032874584, 39.16867822408676, 36.71784393489361, 36.49470470845699, 37.33813785016537, 37.15785652399063, 37.00414717197418, 37.372480407357216, 37.33940318226814, 36.78972467780113, 36.51384808123112, 37.396567314863205, 37.742740139365196, 37.83204674720764, 40.71795009076595, 38.04705820977688, 36.23767510056496, 37.09882289171219, 38.04482012987137, 38.98404613137245, 38.50590638816357, 37.06702619791031, 39.615731835365295, 37.14328050613403, 37.58191756904125, 36.80171303451061, 37.58866600692272, 38.77261407673359, 42.03567758202553, 49.65808376669884, 53.12649205327034, 50.64840942621231, 52.36753597855568, 51.19871869683266, 58.43234494328499, 43.22972550988197, 48.29410895705223, 48.961957320570946, 51.672161892056465, 50.79039640724659, 51.66513606905937, 43.67971256375313, 42.74020537734032, 39.165045619010925, 38.88880804181099, 37.053327932953835, 37.22751058638096, 36.01958580315113, 35.21648369729519, 37.00504012405872, 36.28983870148659, 36.563401222229004, 37.05255277454853, 37.47139289975166, 36.12622708082199, 36.48743949830532, 35.7119695097208, 36.16948775947094, 36.86930760741234, 37.76647366583347, 36.344126388430595, 35.520839765667915, 37.321285754442215, 37.18893505632877, 37.80004866421223, 40.62065251171589, 46.87967665493488, 47.32384242117405, 46.10095404088497, 47.877050936222076, 46.636459305882454, 47.81763732433319, 46.91744662821293, 46.6129157692194, 44.67682085931301, 46.58592961728573, 47.77017407119274, 48.695637211203575, 49.7533218562603, 47.97237642109394, 48.84334668517113, 48.11752863228321, 45.554854944348335, 44.691290482878685, 50.659732818603516, 52.48573623597622, 48.97147201001644, 49.82276313006878, 48.94808806478977, 48.3748622238636, 46.659862250089645, 52.41191379725933, 49.368805289268494, 48.329253271222115, 18.632307797670364, 0.5476856301538646, 3.1971299182623625, 7.602487178519368, 4.652964798733592, 4.343079077079892, 0.22938943089684471, 14.21523291617632, 47.27348752319813, 33.54353986680508, 23.41868106275797, 25.92970412224531, 38.228566870093346, 36.464967504143715, 4.511875044554472, 0.13965472258860245, 0.1216321338142734, 0.05755911843152717, 0.01662740123720141, 0.007616031243742327, 0.062489903066307306, 0.004875508548138896, 0.035620461276266724, 0.044178021416882984, 0.03600464144255966, 0.09527018744847737, 0.09500981977907941, 0.026715589010564145, 0.05497549456777051, 0.034527155294199474, 0.02645188167662127, 0.024274568822875153, 0.017924076091730967, 0.05897138464206364, 0.0451506059471285, 0.03503036110487301, 0.04702347127022222, 0.05796473924419843, 0.023164581216406077, 0.017287953487539198, 0.07760101681924425, 0.02910513198003173, 0.04535288200713694, 0.0448276566748973, 0.5330048804171383, 28.366802148520947, 51.901521384716034, 42.50055603682995, 51.17519795894623, 72.06127882003784, 55.841898545622826, 50.17090044915676, 52.12911777198315, 59.90791976451874, 18.777942582964897, 0.03876029513776302, 2.2859879722818732, 4.886455619707704, 0.9017208858858794, 15.146359652280807, 51.597454100847244, 55.031174048781395, 54.5771212130785, 49.595672115683556, 47.76922792196274, 48.993195444345474, 51.53878904879093, 53.023449182510376, 50.366768538951874, 45.78298710286617, 48.151703998446465, 52.19795107841492, 52.77824454009533, 49.04996059834957, 49.199490174651146, 50.323576256632805, 50.7905749976635, 50.51646150648594, 50.817352160811424, 49.32722792029381, 51.49847321212292, 49.05755639076233, 46.32531300187111, 39.73251476883888, 39.344859570264816, 39.75649148225784, 39.250909611582756, 39.02947649359703, 40.28039216995239, 39.1730859875679, 38.30327466130257, 39.159342125058174, 38.88462446630001, 39.89670015871525, 40.206478536129, 38.62798623740673, 41.0310684889555, 39.535810723900795, 37.21594400703907, 36.92622475326061, 38.64014558494091, 41.12064868211746, 40.905276238918304, 39.12898935377598, 40.9497756510973, 38.732693418860435, 40.26970714330673, 39.06725786626339, 39.498173743486404, 41.02718889713287, 44.2923840880394, 50.21623581647873, 54.42068360745907, 50.87344095110893, 56.8320532143116, 50.62762834131718, 54.21028509736061, 47.368490025401115, 47.28559747338295, 51.51811435818672, 51.92645184695721, 53.35739426314831, 51.34192921221256, 47.60930970311165, 43.62362377345562, 41.235147938132286, 40.36956958472729, 38.87669809162617, 38.59867841005325, 39.03358407318592, 37.400332912802696, 39.30238164961338, 37.02531963586807, 38.52424040436745, 36.987796649336815, 38.83086495101452, 38.720739260315895, 38.209495693445206, 36.70571878552437, 40.01903459429741, 38.791742250323296, 38.723843693733215, 37.421307787299156, 36.812375262379646, 38.923120200634, 39.575214609503746, 37.546503469347954, 43.7539491802454, 47.341469675302505, 49.1926733404398, 48.47084887325764, 51.26194350421429, 49.40929591655731, 49.469891265034676, 48.62721808254719, 48.53295274078846, 46.59680463373661, 48.938520178198814, 49.38344970345497, 50.566854402422905, 50.516396909952164, 49.176645800471306, 47.48952493071556, 47.24949561059475, 46.96593962609768, 47.66982905566692, 52.705128863453865, 55.855368822813034, 51.29504732787609, 52.80735097825527, 48.00237201154232, 50.08411690592766, 49.41821403801441, 54.08376708626747, 50.22449277341366, 49.996090829372406, 19.854571111500263, 1.1892851209267974, 3.066988564096391, 11.374091170728207, 5.96808610484004, 3.006236949004233, 0.29582487302832305, 15.185764487832785, 54.05277594923973, 38.73313419520855, 32.110591158270836, 27.065294086933136, 43.717474937438965, 42.743283212184906, 6.727077327668667, 0.24397379049332812, 0.09849610301898792, 0.012102956370654283, 0.06284421921009198, 0.07434099214151502, 0.07421000307658687, 0.01866951148258522, 0.07484217931050807, 0.07353314213105477, 0.05574402188358363, 0.05078852744190954, 0.02882796023186529, 0.015328293993661646, 0.12481159094022587, 0.07728125507128425, 0.0907125324010849, 0.15716304013039917, 0.09440797512070276, 0.17386884370353073, 0.13478550652507693, 0.13309373636730015, 0.07710129168117419, 0.16400846187025309, 0.06308788113528863, 0.09165432522422634, 0.10629417520249262, 0.0727140337403398, 0.17918561934493482, 0.15846024005440995, 0.5670904170256108, 31.940459087491035, 62.13673576712608, 50.04901818931103, 55.53612895309925, 69.07174363732338, 60.038587152957916, 52.62083038687706, 55.873634442687035, 62.80318200588226, 23.435842841863632, 0.16194524680031464, 8.134069629013538, 7.807021653279662, 1.1996178352274, 18.34774486720562, 54.48535233736038, 55.703863352537155, 56.092696487903595, 52.11207188665867, 51.417822539806366, 51.607272773981094, 54.88040193915367, 54.80508618056774, 50.85326783359051, 47.41442196071148, 50.25460235774517, 54.178534001111984, 54.733460023999214, 52.08378240466118, 50.88058076798916, 52.10830628871918, 52.74175129830837, 52.52109333872795, 54.356949627399445, 51.16523489356041, 55.25595098733902, 53.017540499567986, 49.32355351746082, 43.646361753344536, 40.20941577851772, 41.47269979119301, 40.6257214397192, 41.10384598374367, 41.91308856010437, 42.586150243878365, 39.74399395287037, 40.674552619457245, 39.63772885501385, 41.20704084634781, 42.6287117600441, 40.849453434348106, 43.8180935382843, 42.29306057095528, 39.15580831468105, 39.661633372306824, 41.418776884675026, 42.644366919994354, 42.17844732105732, 40.25687523186207, 43.202184587717056, 41.1835353076458, 42.03612595796585, 41.01215310394764, 41.69646978378296, 42.41620436310768, 46.40024498105049, 52.72513099014759, 55.861535891890526, 52.862235233187675, 56.94064758718014, 52.56930895149708, 52.206242233514786, 50.41306905448437, 49.06238593161106, 48.44356633722782, 56.08586825430393, 54.80276830494404, 56.943379640579224, 48.49147416651249, 47.245445027947426, 43.31719681620598, 43.278469294309616, 40.68731993436813, 41.165421679615974, 41.85907065868378, 40.22518493235111, 40.96052527427673, 39.73769009113312, 40.331039652228355, 39.73348751664162, 41.05958595871925, 41.12236998975277, 39.139670580625534, 39.732472971081734, 40.84468089044094, 42.03657813370228, 41.1242812871933, 41.00788593292236, 39.04593341052532, 42.23004475235939, 39.75740723311901, 40.828296169638634, 44.67714004218578, 51.051005423069, 51.96599632501602, 50.49583621323109, 52.11341701447964, 51.67531192302704, 51.811310425400734, 51.083664670586586, 51.13829053938389, 48.23553130030632, 50.760226026177406, 50.78741356730461, 52.40741863846779, 52.670322731137276, 49.55795153975487, 48.996470868587494, 49.018965661525726, 46.48441046476364, 49.09623071551323, 53.16668249666691, 58.788332641124725, 54.759940803050995, 56.03849999606609, 51.15367591381073, 54.23178054392338, 51.33179895579815, 56.079910174012184, 52.11415797472, 50.304478481411934, 22.486416287720203, 1.7986439354717731, 7.0971195213496685, 19.62666694074869, 12.515993546694517, 8.17810831591487, 0.2691087737912312, 17.658484652638435, 60.24906165897846, 43.53643745183945, 35.871925726532936, 35.26798613369465, 51.70971907675266, 47.67395183444023, 9.039243757724762, 0.34846377500798553, 0.28860778373200446, 0.14238137315260246, 0.17769574304111302, 0.20982894144253805, 0.1879902367363684, 0.09740440378664061, 0.15498758264584467, 0.19837972533423454, 0.19739835377549753, 0.20566599763697013, 0.24020783632295206, 0.08670020004501566], [0.021078777026559692, 0.016717076796339825, 0.07931579355499707, 0.10720921360189095, 0.01081145521311555, 0.045648204832104966, 0.008682252082508057, 0.05015164970245678, 0.12537746370071545, 0.03920978801033925, 0.028505849586508702, 0.018126402246707585, 0.022768617600377183, 0.09536737168673426, 0.0379467305901926, 0.1082550258433912, 0.14909841818735003, 6.692484458908439, 45.6594405323267, 46.546461135149, 33.77353012561798, 36.16425544023514, 39.919267147779465, 41.35294921696186, 39.95341971516609, 50.538325533270836, 26.558577977120876, 0.22764636349165812, 0.9950195951387286, 2.3506127670407295, 0.3870147548150271, 8.326703142374754, 47.00114853680134, 53.12887452542782, 53.680779710412025, 49.41894359886646, 50.59158347547054, 48.45331281423569, 51.93022884428501, 50.867406874895096, 46.09207011759281, 45.218356400728226, 52.41627596318722, 46.64029709994793, 48.23354780673981, 46.23585060238838, 43.148390874266624, 46.25020623207092, 48.167062774300575, 49.42917264997959, 48.63172464072704, 47.96960636973381, 50.261088609695435, 47.98070177435875, 48.02366986870766, 40.97416654229164, 38.0751197040081, 36.594863533973694, 39.62570630013943, 38.567998856306076, 38.009702414274216, 38.026045337319374, 40.23141659796238, 37.267184257507324, 38.070723339915276, 36.58441789448261, 36.59595787525177, 38.60325716435909, 39.47854019701481, 39.46124732494354, 37.41474933922291, 36.28657467663288, 36.40476353466511, 39.369056671857834, 39.389963150024414, 37.090923115611076, 39.53762322664261, 37.96980455517769, 38.35009194910526, 37.05086946487427, 37.70191513001919, 39.59149673581123, 39.89628978073597, 49.78640668094158, 50.86331449449062, 51.09046250581741, 48.54412414133549, 59.61198404431343, 68.21488201618195, 36.48529641330242, 45.76192483305931, 50.86225815117359, 49.81839716434479, 49.77714657783508, 47.71426387131214, 43.76635171473026, 41.03026673197746, 39.997216165065765, 37.256662622094154, 38.09200219810009, 38.15887860953808, 36.98387145996094, 35.922527611255646, 37.009432688355446, 36.42046429216862, 36.24921888113022, 37.11198918521404, 36.122765466570854, 36.73829823732376, 36.81780897080898, 36.20055869221687, 34.74840581417084, 37.91466951370239, 37.32031300663948, 36.131170615553856, 35.901628732681274, 36.54413245618343, 36.23670235276222, 35.09685471653938, 39.60165739059448, 46.93545766174793, 45.315057411789894, 48.66713114082813, 49.07664656639099, 47.527070716023445, 46.20781570672989, 46.155864894390106, 42.27766379714012, 42.527640983462334, 45.6935703009367, 45.14089375734329, 47.35411159694195, 46.85600012540817, 48.348119258880615, 50.50182469189167, 47.94542446732521, 47.123574167490005, 44.35468174517155, 41.624296456575394, 50.161085575819016, 52.161556631326675, 51.678610146045685, 51.23466096818447, 49.13930140435696, 48.65762025117874, 50.0339026004076, 51.137180998921394, 47.13607929646969, 18.38605061173439, 2.046567094512284, 2.5645980471745133, 10.278429463505745, 5.874962601810694, 2.708207303658128, 0.375241442816332, 18.762722499668598, 51.344923451542854, 35.04290521144867, 25.67270491272211, 28.6499135568738, 45.67943885922432, 28.947916366159916, 2.0208075642585754, 0.1381935377139598, 0.028623429898289032, 0.012803485333279241, 0.07481894266675226, 0.030297501689346973, 0.010690061189961853, 0.03174364879669156, 0.04308203628170304, 0.00927605093238526, 0.016196044598473236, 0.04228944853821304, 0.035754007039940916, 0.03353573876665905, 0.03018647083081305, 0.04159944044658914, 0.08268849851447158, 0.021490483450179454, 0.02138479791028658, 0.04260242705640849, 0.02846580700861523, 0.07136463114875369, 0.031099761472432874, 0.0221404879266629, 0.0203557693384937, 0.02729277952312259, 0.05236362456344068, 0.05150806187884882, 0.09874439594568685, 0.003843114800474723, 0.1480810227803886, 12.182577587664127, 56.550560519099236, 50.532416850328445, 37.57138453423977, 44.954574555158615, 49.765853583812714, 46.250301226973534, 48.08728985488415, 57.39820383489132, 29.54609166830778, 0.12390145813697018, 1.0646622581407428, 5.633354466408491, 0.5373656214214861, 10.443864986300468, 49.58350136876106, 54.90741468966007, 54.509716629981995, 51.83198131620884, 51.82845510542393, 48.49335506558418, 53.247253373265266, 51.56836286187172, 46.88132956624031, 45.798741057515144, 53.66853676736355, 50.57444639503956, 49.77988623082638, 47.97365315258503, 46.67154662311077, 49.581042900681496, 49.89615999162197, 51.80644668638706, 51.22226223349571, 49.592506885528564, 52.5940266251564, 49.213887602090836, 50.318731516599655, 42.297407537698746, 39.568200185894966, 39.69945274293423, 40.88110193610191, 40.832688733935356, 39.93528328835964, 40.177843272686005, 41.59885682165623, 40.79035520553589, 39.338126331567764, 38.99661585688591, 37.28974364697933, 39.40523833036423, 40.935667008161545, 39.828094840049744, 39.09577913582325, 38.46285469830036, 39.90380197763443, 39.53103817999363, 40.84317997097969, 38.655044585466385, 41.56471945345402, 39.38364788889885, 39.31695766746998, 39.31642189621925, 39.77160707116127, 40.06111353635788, 41.657829657197, 52.052411288022995, 53.561386317014694, 51.044519171118736, 51.962861493229866, 54.181433245539665, 60.347069799900055, 41.20982229709625, 45.48257902264595, 53.39034229516983, 50.858427956700325, 52.130276709795, 49.682007282972336, 47.91352517902851, 42.67822690308094, 41.36534035205841, 39.41528119146824, 39.110807329416275, 40.42307451367378, 38.36943671107292, 36.127944588661194, 38.66617798805237, 38.454308956861496, 36.92593216896057, 37.59734854102135, 37.27909281849861, 39.05732519924641, 38.35941664874554, 38.089904710650444, 36.199684739112854, 38.40814523398876, 38.557287231087685, 38.25713753700256, 37.99987614154816, 36.782151684165, 37.94550105929375, 36.21590606868267, 41.676220670342445, 48.0967703461647, 47.65931881964207, 50.549686923623085, 50.79137675464153, 49.95814606547356, 48.17019000649452, 47.61229634284973, 45.77209308743477, 45.446541756391525, 48.928427919745445, 47.76903793215752, 49.45545203983784, 48.64338621497154, 50.64301751554012, 51.582285314798355, 47.850501760840416, 47.43610739707947, 45.337438210844994, 41.842245161533356, 52.821562215685844, 53.69470976293087, 55.11842496693134, 50.63692644238472, 52.18722805380821, 51.105179116129875, 53.61129283905029, 51.255483850836754, 48.857595920562744, 19.648304879665375, 3.307343004271388, 7.38254833035171, 14.128850251436234, 5.595131367444992, 2.017741366289556, 0.44082749693188816, 19.034630209207535, 55.312731340527534, 40.4962357878685, 31.37577898800373, 30.26411823928356, 51.750916466116905, 33.87117348611355, 2.681299285031855, 0.14534071669913828, 0.15078595810336992, 0.0223022501450032, 0.17862532753497362, 0.011882174858328653, 0.05532025184947997, 0.035873589295079, 0.04822874878300354, 0.02647314791829558, 0.01889261035103118, 0.008758324074733537, 0.020247386091796216, 0.0401512913958868, 0.18289649131475016, 0.10139473888557404, 0.2118006200180389, 0.17514253238914534, 0.06178541938425042, 0.2048661999288015, 0.06831842663814314, 0.1554000683245249, 0.16526239458471537, 0.18075063067954034, 0.11482868794701062, 0.14492058689938858, 0.1750284939771518, 0.288039268925786, 0.15152118896367028, 0.25445304927416146, 0.2284628149936907, 15.055497977882624, 65.10883748531342, 57.9483687132597, 46.11468270421028, 47.5736828148365, 52.04081051051617, 52.94368386268616, 51.18112564086914, 60.025876834988594, 33.9795208722353, 0.4186288802884519, 3.9053565775975585, 7.980924546718597, 1.0003750515170395, 10.518615525215864, 52.162552177906036, 56.70287534594536, 59.29965600371361, 54.38977226614952, 56.06083519756794, 51.15957699716091, 54.83079560101032, 53.302133828401566, 49.400997161865234, 48.183124512434006, 55.36326102912426, 50.607755407691, 51.81211218237877, 49.897577315568924, 47.43485726416111, 50.29559835791588, 52.35759951174259, 51.75321914255619, 54.806237518787384, 50.47005079686642, 55.29280140995979, 51.42823398113251, 52.84121096134186, 44.7930908203125, 42.58828192949295, 42.60546840727329, 42.886847108602524, 42.197841480374336, 41.86948210000992, 43.069294318556786, 43.62704358994961, 40.54706946015358, 41.860913559794426, 40.74851185083389, 38.78915458917618, 41.13687761127949, 42.418024465441704, 44.06528167426586, 40.86502879858017, 39.80265140533447, 39.74169887602329, 43.259242326021194, 42.705783024430275, 40.92685528099537, 43.20267476141453, 41.54132030904293, 41.84338130056858, 40.76877996325493, 41.40616536140442, 42.105563431978226, 44.86859276890755, 53.113853931427, 54.92601849138737, 52.95519344508648, 50.9973257035017, 56.60562716424465, 64.77409824728966, 42.372662499547005, 47.771925777196884, 52.860209941864014, 54.868143796920776, 54.499331787228584, 53.97556409239769, 48.88164483010769, 45.954107120633125, 43.54360766708851, 43.75994525849819, 41.189459189772606, 43.69444437325001, 42.91183456778526, 39.84500773251057, 40.78932166099548, 39.708044081926346, 39.61378633975983, 39.882222935557365, 38.83518151938915, 41.39710284769535, 40.663689002394676, 39.35560919344425, 37.67000824213028, 41.1057572811842, 42.695257589221, 40.37580505013466, 40.55092245340347, 40.16546733677387, 39.14745256304741, 39.39818970859051, 43.39026689529419, 50.91507151722908, 49.36621382832527, 54.013410061597824, 54.036322832107544, 50.83697430789471, 49.75835658609867, 49.32460606098175, 47.54788979887962, 47.66973786056042, 51.16962365806103, 49.706101790070534, 52.51046910881996, 50.22359222173691, 50.465726628899574, 53.0493675917387, 48.546369820833206, 48.47046509385109, 45.29238022863865, 41.49092361330986, 52.99104452133179, 55.95804311335087, 58.80504794418812, 54.67005282640457, 54.73625287413597, 53.33935283124447, 55.74127234518528, 52.23454311490059, 51.5752062946558, 22.23420862108469, 4.053708929568529, 10.48046462237835, 24.747891537845135, 15.65482271835208, 7.419515121728182, 0.5147891922388226, 22.33392857015133, 63.752644658088684, 45.07532447576523, 38.0521347373724, 39.22244153916836, 59.206226617097855, 41.28530144691467, 4.03682928532362, 0.2906389825511724, 0.2580286574084312, 0.07929173312732019, 0.2220332037541084, 0.12374992642435245, 0.10493617111933418, 0.10100718194735236, 0.16410501528298482, 0.17086121602915227, 0.12791068089427426, 0.12071200428181328, 0.10995403194101527, 0.12669927324168384], [0.060792752337874845, 0.028043864513165317, 0.09507500260951929, 0.02503805881133303, 0.04605094982252922, 0.047552707910654135, 0.05100218804727774, 0.0500102891237475, 0.07087977122864686, 0.0669969362206757, 0.019309563758724835, 0.05717940228350926, 0.054299783951137215, 0.025480686817900278, 0.04693617986049503, 0.03984367860539351, 0.06766379301552661, 0.172748334298376, 27.667117193341255, 47.80933476984501, 41.31091587245464, 35.26234723627567, 33.20514142513275, 41.13307021558285, 45.90312905609608, 52.321106269955635, 34.96341347694397, 1.2803500844165683, 0.770830437541008, 3.5249931877478957, 6.799841523170471, 21.14771392196417, 36.56156972050667, 49.998705089092255, 53.43802593648434, 50.88385619223118, 49.4903227686882, 52.08307944238186, 48.49094599485397, 45.10189265012741, 44.03499349951744, 46.11376695334911, 51.25418812036514, 49.16751489043236, 48.40369127690792, 45.55537551641464, 44.599210023880005, 46.15521892905235, 47.10263729095459, 48.27311888337135, 48.688561990857124, 49.32840585708618, 48.38382214307785, 49.003485292196274, 47.446275651454926, 46.62988945841789, 43.130049258470535, 37.135145142674446, 38.16539905965328, 38.08064840734005, 38.7971493601799, 38.41282278299332, 36.216715425252914, 36.97772338986397, 38.01339201629162, 38.008235692977905, 37.88307040929794, 37.65943340957165, 37.569632828235626, 37.37610161304474, 38.89060914516449, 36.81961387395859, 38.881428837776184, 36.02031536400318, 36.68385095894337, 37.05665275454521, 37.99586735665798, 38.54307219386101, 41.029677763581276, 40.067386999726295, 38.53882022202015, 37.92049840092659, 38.718106001615524, 48.88870485126972, 53.239053413271904, 50.96721611917019, 52.040913105010986, 49.66795563697815, 42.37062580883503, 42.0793030411005, 40.729820653796196, 51.621335819363594, 50.513524264097214, 48.36584150791168, 45.543466955423355, 45.210775807499886, 42.88731448352337, 42.396278232336044, 40.063306018710136, 38.75789366662502, 35.88221937417984, 37.216350585222244, 36.21310941874981, 36.32810264825821, 35.19195221364498, 36.63822300732136, 36.48689992725849, 37.014114037156105, 35.916729122400284, 36.58007472753525, 35.43186753988266, 36.08883708715439, 35.72422005236149, 38.08914855122566, 38.47665935754776, 38.34270894527435, 35.267305970191956, 36.922641545534134, 34.08095642924309, 39.475766345858574, 45.867498368024826, 47.06833653151989, 48.08662109076977, 47.52581298351288, 49.51458066701889, 47.49819986522198, 43.64087864756584, 41.54682241380215, 39.573379307985306, 42.08274945616722, 43.96316975355148, 45.228688046336174, 46.465153098106384, 46.299797371029854, 47.389267310500145, 48.16420532763004, 48.895388692617416, 46.67787328362465, 46.44231252372265, 44.929834082722664, 48.49693827331066, 50.224420577287674, 50.84515526890755, 50.12198947370052, 51.76186367869377, 54.26255129277706, 50.33324673771858, 40.34564606845379, 24.745911844074726, 4.1786998976022005, 3.9586235443130136, 8.82919767871499, 3.8280423637479544, 0.8113449916709214, 0.13329356705071405, 17.796991020441055, 53.33171144127846, 35.78427202999592, 24.35879621654749, 24.489214718341827, 43.91481354832649, 19.1597118973732, 0.6492023484315723, 0.04364592379715759, 0.013337711989152012, 0.04988241707906127, 0.034658875374589115, 0.033816604554886, 0.008008561962924432, 0.043845513282576576, 0.048730715207057074, 0.029559497052105144, 0.06663705396931618, 0.02550662302382989, 0.012014904259558534, 0.03852779511362314, 0.019250292134529445, 0.05626164020213764, 0.06434858965803869, 0.057483066848362796, 0.04380853206384927, 0.006196752201503841, 0.05921369214775041, 0.020294664609536994, 0.028117190558987204, 0.020860453878412955, 0.04338789760367945, 0.020809316192753613, 0.04780990660947282, 0.024263989507744554, 0.018909883838205133, 0.04683356310124509, 0.025799322356760968, 1.0506850644014776, 39.200547114014626, 53.50478835403919, 43.38834799826145, 38.8339351862669, 40.83983235061169, 48.00223521888256, 47.84657657146454, 54.14256513118744, 37.28921167552471, 0.9389932046178728, 0.6668607133906335, 2.6562823774293065, 5.480400323867798, 17.707165740430355, 40.864227041602135, 51.984676122665405, 54.955497309565544, 53.77389371395111, 52.82636135816574, 54.14752386510372, 51.81169040501118, 46.87683820724487, 42.97950133681297, 47.20764845609665, 54.20833960175514, 49.79831524193287, 50.97019135951996, 47.310512736439705, 46.49164907634258, 48.21205236017704, 48.03274758160114, 48.70275042951107, 50.770481675863266, 50.7203433662653, 50.04121720790863, 49.8866681009531, 50.585017427802086, 47.93736509978771, 44.51702043414116, 39.199509769678116, 39.98954437673092, 40.53179427981377, 41.27724967896938, 40.02856068313122, 39.901567697525024, 40.79253248870373, 39.16048966348171, 40.003998801112175, 38.75902600586414, 40.38172513246536, 39.432266280055046, 39.3246940523386, 40.660162791609764, 37.57930710911751, 41.49578355252743, 38.0008564889431, 40.38903973996639, 38.31649795174599, 40.2595578879118, 39.614933878183365, 43.7547205388546, 42.15855538845062, 40.707774236798286, 39.494168758392334, 40.1128363609314, 49.60490562021732, 56.89918041229248, 51.2484922260046, 53.14850427210331, 49.68731939792633, 44.767867773771286, 44.63960185647011, 40.5242782831192, 54.11804884672165, 50.56327499449253, 51.60237863659859, 47.734486386179924, 48.32532808184624, 43.46876688301563, 43.506662249565125, 40.281836092472076, 41.31548322737217, 38.08087259531021, 39.53124336898327, 37.28228084743023, 38.82597081363201, 38.17495174705982, 36.96220502257347, 38.461220785975456, 38.66819567978382, 37.660219967365265, 38.29334959387779, 39.37032960355282, 38.038128688931465, 37.5637811422348, 39.68538589775562, 39.583642557263374, 38.26312981545925, 36.96510806679726, 39.82139199972153, 35.521918907761574, 41.16479091346264, 47.47827373445034, 49.03929837048054, 51.85476489365101, 49.070312306284904, 51.8092205375433, 50.05008213222027, 46.52731396257877, 43.70054304599762, 42.413008734583855, 45.48779994249344, 44.38295602798462, 48.01321282982826, 48.54213684797287, 48.94950918853283, 49.74314220249653, 50.54199233651161, 49.10305134952068, 49.166226759552956, 45.736021623015404, 45.63683554530144, 50.28132252395153, 53.46678279340267, 53.15562129020691, 52.758698388934135, 51.6661886125803, 55.973534882068634, 50.68542703986168, 43.13389465212822, 25.203278101980686, 5.309682134538889, 6.7259991355240345, 9.946590419858694, 8.179139960557222, 2.118066670373082, 0.1945381166297011, 18.135596551001072, 58.93343165516853, 40.60887694358826, 30.82424808293581, 31.204427182674408, 50.93372471630573, 25.916819013655186, 1.2391161220148206, 0.07307038336875848, 0.02242573980765883, 0.023519847309216857, 0.02035365792835364, 0.06524060663650744, 0.024533771320420783, 0.024650483319419436, 0.023476466922147665, 0.029588884244731162, 0.0370462048886111, 0.05428937904071063, 0.035670211145770736, 0.01809754754503956, 0.13156468950910494, 0.11576613178476691, 0.15141025272896513, 0.09963414195226505, 0.18547196639701724, 0.12653337355004624, 0.21122557431226596, 0.15264595829648897, 0.11530029310961254, 0.22489795315777883, 0.1613177015678957, 0.11801014145021327, 0.10718037374317646, 0.10321041059796698, 0.1662568427855149, 0.15128203929634765, 0.11185472409124486, 1.4325237250886858, 42.126348316669464, 62.58803375065327, 51.177698224782944, 46.061690747737885, 46.202237606048584, 51.85266740620136, 54.75786991417408, 60.61780907213688, 43.004260808229446, 1.5851712715812027, 1.8639568495564163, 11.105403788387775, 9.84508741647005, 28.77365581691265, 46.51336491107941, 52.22654074430466, 58.14622029662132, 55.46805180609226, 54.55860860645771, 54.94785211980343, 53.730420246720314, 47.3629043251276, 44.52696070075035, 49.34667527675629, 55.05975991487503, 53.466098830103874, 51.7160951346159, 48.379144594073296, 48.520162627100945, 50.48773504793644, 49.21691223978996, 50.78710578382015, 53.91670145094395, 52.93490253388882, 53.32533538341522, 50.93908242881298, 52.23668619990349, 50.824856758117676, 47.31817312538624, 42.014983892440796, 41.392964869737625, 43.450280874967575, 42.61960744857788, 42.04863488674164, 40.556420758366585, 40.94684220850468, 40.78619822859764, 41.79714158177376, 40.147984474897385, 40.96019849181175, 41.18067406117916, 41.3080470263958, 41.9858318567276, 39.90518510341644, 41.952572241425514, 40.584280863404274, 41.41311898827553, 40.949600860476494, 42.9182144254446, 43.47922012209892, 45.99690042436123, 44.912199229002, 42.87411019206047, 42.304250970482826, 41.51863172650337, 52.444880828261375, 57.87405990064144, 54.487609416246414, 51.529574543237686, 53.83981257677078, 50.475271716713905, 43.58531042933464, 46.316459476947784, 53.83353911340237, 53.79618711769581, 53.87825511395931, 51.61565512418747, 51.003253385424614, 45.572398602962494, 45.88311932981014, 44.66889068484306, 42.6312880218029, 42.612596824765205, 42.23198264837265, 40.80102123320103, 41.306500509381294, 39.35714051127434, 39.93785575032234, 41.126937344670296, 41.267613396048546, 39.726891070604324, 40.17513021826744, 39.16180059313774, 39.42866027355194, 38.96687485277653, 41.31539203226566, 42.23269701004028, 40.35772182047367, 38.446625769138336, 41.864093989133835, 37.54991188645363, 43.704320043325424, 50.21066911518574, 50.81067591905594, 54.308783411979675, 51.11592493951321, 53.688770681619644, 52.4698568880558, 47.59927064180374, 46.73409126698971, 43.80316033959389, 45.957545936107635, 46.44411362707615, 49.50000084936619, 50.98843418061733, 49.906890615820885, 50.17995536327362, 51.6770788282156, 52.657604813575745, 49.64942403137684, 47.76445917785168, 45.96193090081215, 49.112949818372726, 53.24561566114426, 54.83911335468292, 53.95737446844578, 54.76927310228348, 58.35315719246864, 50.207674875855446, 45.20479112863541, 31.127274222671986, 6.183914048597217, 11.069522313773632, 15.375006683170795, 12.263478096574545, 4.050082974135876, 0.41824391344562173, 20.435491539537907, 63.74686896800995, 49.30803135037422, 36.08526527881622, 34.00350138545036, 57.798782140016556, 32.35368691384792, 1.6186823858879507, 0.23664652195293456, 0.18404177360935137, 0.10901756031671539, 0.12302109287702478, 0.18855009810067713, 0.14047464734176174, 0.1366173051064834, 0.19089329580310732, 0.11410691222408786, 0.16316964203724638, 0.15596255689160898, 0.10131131406524219, 0.14286044432083145], [0.07079355593305081, 0.07348955579800531, 0.03291494336735923, 0.023432858324667905, 0.009171299570880365, 0.04593735298840329, 0.09933597670169547, 0.04122323836782016, 0.0052811636851402, 0.017428766732336953, 0.035688490243046544, 0.009132914765359601, 0.10151619877433404, 0.0449187515914673, 0.029745636966254096, 0.0926027305831667, 0.07152195903472602, 0.1668065070407465, 7.176996935158968, 42.03303672373295, 47.05172002315521, 32.40843057632446, 27.048407793045044, 39.58331577479839, 52.34031043946743, 49.91452060639858, 44.942175820469856, 4.4169798865914345, 0.3890795283950865, 2.466462138108909, 7.908154651522636, 39.298338666558266, 27.227045707404613, 40.86213335394859, 54.27157200872898, 53.21973904967308, 51.91108167171478, 50.8014652132988, 48.82811330258846, 47.097093388438225, 46.021207720041275, 47.501475289464, 49.913475662469864, 47.70295187830925, 45.7623428106308, 45.0297649204731, 46.620579957962036, 46.369702219963074, 48.50724332034588, 48.64512272179127, 49.655895084142685, 47.08238437771797, 48.750441670417786, 49.80876848101616, 48.65816742181778, 46.93977043032646, 46.13229475915432, 43.75980086624622, 37.2021659463644, 36.239027827978134, 36.620873138308525, 37.30444885790348, 37.72719897329807, 37.62686915695667, 39.62355561554432, 37.12067931890488, 37.42021344602108, 39.25436742603779, 39.19669412076473, 37.9791596531868, 37.52140961587429, 37.06042595207691, 38.54954704642296, 38.496137112379074, 38.0004271119833, 36.261366829276085, 40.17300233244896, 40.956178307533264, 43.355532959103584, 40.42222335934639, 42.23009034991264, 38.88648256659508, 40.40981322526932, 41.9132025539875, 49.496911615133286, 48.97693991661072, 57.609886676073074, 33.1769697368145, 31.06486827135086, 47.1711590141058, 40.937160328030586, 50.34588485956192, 50.55296994745731, 49.78734143078327, 46.87095992267132, 47.66879931092262, 45.84927074611187, 43.13981473445892, 41.6300455480814, 40.224903747439384, 38.660694882273674, 37.26285628974438, 34.08657632768154, 35.69112382829189, 35.49877814948559, 36.84902049601078, 35.72849862277508, 35.983643531799316, 36.2407111376524, 36.124737560749054, 37.97851748764515, 38.24684388935566, 37.10814759135246, 36.72844156622887, 37.06490211188793, 38.334505185484886, 35.51872707903385, 35.808845311403275, 35.684899762272835, 40.93892723321915, 46.6941212117672, 48.52740503847599, 47.53148227930069, 48.1290952116251, 49.172177240252495, 46.01525343954563, 42.471423000097275, 40.66243126988411, 39.76393148303032, 38.91978017985821, 40.41161432862282, 40.74063487350941, 44.3605600297451, 46.132720336318016, 45.94777286052704, 48.15024487674236, 48.65233853459358, 46.527743339538574, 47.13104456663132, 51.9203569740057, 48.334090411663055, 47.345980033278465, 46.415383368730545, 53.553900718688965, 48.74826438724995, 54.940997287631035, 47.114431858062744, 29.96810272336006, 6.202535899356008, 1.9884384074248374, 9.99706881120801, 8.272565547376871, 5.272233719006181, 0.9491945884656161, 0.17031272436724976, 20.886907316744328, 47.62326255440712, 30.702021941542625, 18.601825833320618, 23.977872356772423, 43.80099065601826, 9.911762438714504, 0.04118062053748872, 0.022864054080855567, 0.02214806154370308, 0.020682134345406666, 0.10941791930235922, 0.008431040660070721, 0.01527483987956657, 0.018481608967704233, 0.01692477238975698, 0.06761009863112122, 0.03505858869175427, 0.017704417077766266, 0.04998099655495025, 0.03907662816345692, 0.03462547872914001, 0.03585419697628822, 0.02924548138253158, 0.003996353916591033, 0.06422676611691713, 0.07477448059944436, 0.015135425583139295, 0.052769928151974455, 0.0787765861605294, 0.043628654020722024, 0.034519741238909774, 0.028707754572678823, 0.03270249617344234, 0.02690437282581115, 0.07880102508352138, 0.034112535940948874, 0.006716645202686777, 0.07635413450771011, 12.7590418048203, 50.82157373428345, 48.994232788681984, 37.42099620401859, 37.19951368868351, 46.39871746301651, 56.20577462017536, 55.55541291832924, 48.311006650328636, 4.284274857491255, 0.2542899549007416, 2.266213595867157, 9.52747955918312, 45.55792897939682, 32.783519849181175, 44.277538284659386, 56.87671981751919, 53.451196029782295, 53.50064277648926, 52.09830902516842, 48.295750468969345, 47.93730430305004, 46.44474819302559, 49.8848631978035, 51.369698122143745, 50.329150557518005, 48.48126411437988, 47.892554104328156, 48.67343880236149, 48.24022024869919, 50.17483703792095, 49.374542981386185, 51.321341916918755, 50.83178758621216, 51.12531803548336, 49.84832435846329, 51.88392072916031, 48.53514142334461, 49.36041533946991, 46.67947679758072, 40.10705687105656, 38.266956210136414, 39.141464084386826, 39.51359711587429, 38.07501330971718, 39.80963543057442, 39.49213966727257, 38.47115345299244, 40.435781031847, 41.532732769846916, 40.44521972537041, 38.14565911889076, 39.235011264681816, 37.361255809664726, 39.71468612551689, 39.73247677087784, 38.536620140075684, 37.30834364891052, 41.838677152991295, 42.18668907880783, 46.637584045529366, 41.95027716457844, 44.71495181322098, 39.6271426230669, 42.193973287940025, 42.93446995317936, 49.61980082094669, 50.69017678499222, 59.93728078901768, 35.899690836668015, 30.415264628827572, 48.37825924158096, 42.9973603785038, 52.35420249402523, 51.281090676784515, 50.96467025578022, 48.56500402092934, 49.91208113729954, 46.35401286184788, 45.12527659535408, 43.68726655840874, 42.29716435074806, 40.52441127598286, 39.52728018164635, 35.85094325244427, 37.57145673036575, 37.38623566925526, 37.93629415333271, 37.69924387335777, 36.95850782096386, 35.72707749903202, 37.96814784407616, 39.19483982026577, 39.19162519276142, 38.767096772789955, 37.1537147462368, 40.092674642801285, 39.53544594347477, 36.4244768768549, 37.16376140713692, 37.34886847436428, 41.97373330593109, 49.28230293095112, 49.66984413564205, 48.818750604987144, 50.87312936782837, 50.892557725310326, 49.018578082323074, 45.04163168370724, 42.93513871729374, 40.99335551261902, 40.810786709189415, 42.851159423589706, 42.986561357975006, 45.864640921354294, 49.9951408803463, 49.32465545833111, 50.7380086183548, 50.37926606833935, 48.68218593299389, 49.18246328830719, 52.58366458117962, 49.115100502967834, 47.68109545111656, 47.76809178292751, 54.621476233005524, 51.31165623664856, 57.29733444750309, 48.66476766765118, 34.243564903736115, 8.399777971208096, 3.613385232165456, 11.52470463886857, 11.081831753253937, 8.996285162866116, 1.4541434962302446, 0.21019842708483338, 21.760562136769295, 53.37688721716404, 40.078938379883766, 24.07375641167164, 24.853675961494446, 50.25592468678951, 13.637614510953426, 0.06448427651776001, 0.07862601923989132, 0.0749788161192555, 0.027871268794115167, 0.06864149094326422, 0.07374936685664579, 0.019060020313190762, 0.0027488883233672823, 0.021139623859198764, 0.037621925948769785, 0.022590767475776374, 0.014452918749157107, 0.0682381188380532, 0.03981145084253512, 0.1751340867485851, 0.19577867584303021, 0.12320461115450598, 0.12310686288401484, 0.08180309407180175, 0.13410412590019405, 0.157603059487883, 0.14926507486961782, 0.13817016006214544, 0.10613813865347765, 0.14016628498211503, 0.12556225847220048, 0.1988666335819289, 0.13630794826894999, 0.18927899101981893, 0.22078540117945522, 0.18198917125118896, 0.24024869897402823, 14.473378714174032, 58.63940343260765, 57.96135261654854, 42.20359817147255, 37.8643412142992, 51.84058025479317, 61.6800344735384, 59.085754081606865, 55.86084432899952, 5.8872720412909985, 0.7453096413519233, 9.014628678560257, 14.051483552902937, 44.47928845882416, 36.126591861248016, 45.17673723399639, 56.689899042248726, 55.617186203598976, 56.206659972667694, 53.905716240406036, 48.75286974012852, 46.03946954011917, 46.948392167687416, 51.111688166856766, 52.15311348438263, 52.3803298920393, 50.23451283574104, 50.871993228793144, 50.957515239715576, 50.965601205825806, 52.631580010056496, 52.179624661803246, 53.59269663691521, 51.682991310954094, 51.490410044789314, 52.415854185819626, 54.539001658558846, 50.46278938651085, 51.07543431222439, 49.18128155171871, 42.482913583517075, 40.99524401128292, 40.713853910565376, 41.35474272072315, 41.8247926980257, 41.57315880060196, 43.18303741514683, 41.156769543886185, 42.133130952715874, 43.88619348406792, 42.70295597612858, 40.36011569201946, 41.09007932245731, 39.249347895383835, 42.89594382047653, 41.55987851321697, 40.88117033243179, 40.828512758016586, 44.53595481812954, 45.74365921318531, 48.953681364655495, 45.195443630218506, 48.139271065592766, 41.240102872252464, 44.506365805864334, 46.52249202132225, 50.492739379405975, 52.915709763765335, 60.04782445728779, 41.273837462067604, 35.607950091362, 46.15513153374195, 45.4646135866642, 54.656764939427376, 52.85100683569908, 52.297851517796516, 50.19901134073734, 51.41384035348892, 48.774201795458794, 47.48460799455643, 46.4833465218544, 44.83561433851719, 43.34017798304558, 40.49635358154774, 37.23439201712608, 39.021204337477684, 39.762213975191116, 40.35635769367218, 38.92881229519844, 39.99181665480137, 37.97659479081631, 39.91409182548523, 41.76846072077751, 42.3714579641819, 41.11241452395916, 38.598602414131165, 41.033785343170166, 42.686487659811974, 38.393664211034775, 39.42397512495518, 40.03363721072674, 44.33510139584541, 51.943866312503815, 52.030106484889984, 50.26901498436928, 53.59605185687542, 52.14505411684513, 50.31522050499916, 47.309707179665565, 44.617019668221474, 42.104533687233925, 43.183421194553375, 44.98626105487347, 45.199619606137276, 49.13227178156376, 50.88348761200905, 50.074286833405495, 54.249400198459625, 51.30449362099171, 51.12580440938473, 49.91981752216816, 54.71219636499882, 51.85818091034889, 48.3908935636282, 47.91539087891579, 54.204004034399986, 52.28571116924286, 57.57335163652897, 49.986982718110085, 39.963420778512955, 9.414330180734396, 4.966854555532336, 17.744272649288177, 17.897858507931232, 14.459684249013662, 3.3522765431553125, 0.2936687262263149, 24.505101665854454, 58.14687006175518, 43.07735748589039, 28.836504444479942, 33.51784564554691, 58.98668199777603, 18.218806385993958, 0.24188437761040404, 0.2265075230388902, 0.11339445045450702, 0.14464934676652774, 0.21149540436454117, 0.11689415172440931, 0.11917017764062621, 0.14628146309405565, 0.11264213535469025, 0.09312100941315293, 0.12140387145336717, 0.1478668538038619, 0.16456973331514746, 0.09968869722797535], [0.021618917671730742, 0.051352099544601515, 0.03541442994901445, 0.018597996277094353, 0.05911117186769843, 0.019927713401557412, 0.04540907371847425, 0.046853111271047965, 0.06761181299225427, 0.008534772496204823, 0.04955932679877151, 0.07428211014484987, 0.03777705707761925, 0.03460261315922253, 0.05653303618601058, 0.03923860189388506, 0.15181573253357783, 0.02931859406089643, 0.9070686239283532, 30.104804188013077, 51.68569676578045, 29.377698004245758, 24.933570474386215, 40.23213475942612, 46.47949352860451, 46.8748889118433, 51.066934168338776, 10.087819341570139, 0.5490785522852093, 1.533541779499501, 3.9483916433528066, 3.606707565486431, 6.450156737118959, 33.7312687933445, 52.904792949557304, 50.01721389591694, 50.13471499085426, 48.04488033056259, 44.14521038532257, 51.19711138308048, 43.57510797679424, 47.620899081230164, 49.052168279886246, 47.03240565955639, 45.31922198832035, 43.09307724237442, 42.968364134430885, 46.05145789682865, 48.10441553592682, 48.30014303326607, 48.43117520213127, 50.79099677503109, 48.90966072678566, 48.4892512857914, 49.87761698663235, 47.75310918688774, 48.03017891943455, 47.54439778625965, 43.26717630028725, 36.921740993857384, 36.598131358623505, 39.13098804652691, 37.64614172279835, 38.674947917461395, 36.58830888569355, 38.327893540263176, 37.0010769367218, 38.882048204541206, 37.894177213311195, 38.566444739699364, 37.22479373216629, 37.563389763236046, 38.47075067460537, 37.23590433597565, 38.02527017891407, 38.96210990846157, 41.47002853453159, 44.62917901575565, 44.46352690458298, 43.632735684514046, 43.326027542352676, 41.27375766634941, 40.09796015918255, 40.32611131668091, 46.23538322746754, 50.919114500284195, 51.042151898145676, 48.46495918929577, 50.107755437493324, 42.95164883136749, 44.51483555138111, 51.51257045567036, 54.51308324933052, 54.65897262096405, 50.907616317272186, 49.6737427264452, 47.13169813156128, 48.71730364859104, 45.18149837851524, 44.831924736499786, 42.32771471142769, 38.49054001271725, 35.68420059978962, 36.58621899783611, 36.19659550487995, 35.244871973991394, 36.17055170238018, 36.728954538702965, 36.45943120121956, 38.12378749251366, 37.63711720705032, 36.09171733260155, 35.27362883090973, 36.440211832523346, 36.03664308786392, 37.612129747867584, 34.67313565313816, 36.943350434303284, 35.96549190580845, 40.9055308252573, 45.040753930807114, 47.16616228222847, 48.110217824578285, 46.6967810690403, 46.28650948405266, 43.50349701941013, 40.36887042224407, 38.53675313293934, 38.839437291026115, 37.664996311068535, 37.09994003176689, 39.72163215279579, 40.05888305604458, 43.29519219696522, 43.573899641633034, 45.566455721855164, 45.97636252641678, 46.52217283844948, 45.63094966113567, 46.83425389230251, 45.870686396956444, 49.72093999385834, 50.60935892164707, 47.734220400452614, 53.12985487282276, 49.19840723276138, 32.82135061919689, 10.107250548899174, 0.3582241153344512, 3.408396919257939, 8.945800121873617, 6.162841804325581, 7.437646798789501, 1.3239558320492506, 0.6522315577603877, 27.5672547519207, 45.793261751532555, 26.86062376946211, 23.25794778764248, 32.411622405052185, 38.05554695427418, 3.703488609753549, 0.03637787864136044, 0.041204369263141416, 0.026040678058052436, 0.03884239893523045, 0.012709493257716531, 0.011521800006448757, 0.04016160724859219, 0.07541513215983286, 0.010969284976454219, 0.005513815385711496, 0.03431150944379624, 0.05080372662632726, 0.013629225741169648, 0.04317540588090196, 0.03119147237157449, 0.07137763357604854, 0.021043458218628075, 0.06936834295629524, 0.038312123288051225, 0.028461185283958912, 0.05019399664888624, 0.05286999192321673, 0.02387749384070048, 0.07330219319555908, 0.02606075500807492, 0.044359016392263584, 0.03794664895394817, 0.026794952427735552, 0.13302424165885895, 0.03653545514680445, 0.16672712692525238, 0.05176980994292535, 2.0000908384099603, 39.706721752882004, 57.59753733873367, 32.743671387434006, 28.899039588868618, 45.68184033036232, 50.70427402853966, 50.95791421830654, 53.75975847244263, 11.19377564638853, 0.39542014128528535, 3.78715964499861, 8.177706487476826, 5.64362246543169, 10.509249977767467, 37.14451164007187, 54.84334632754326, 53.278464898467064, 51.76493011415005, 48.756984919309616, 45.31577177345753, 49.21352282166481, 45.03318473696709, 49.896893352270126, 51.305933743715286, 49.081400111317635, 47.194789946079254, 45.98045110702515, 46.37628346681595, 47.135228142142296, 49.14803333580494, 50.741873010993004, 51.56179681420326, 49.974196404218674, 49.445815756917, 50.1208571344614, 50.99203258752823, 50.854647159576416, 50.84130607545376, 49.84126053750515, 44.74778585135937, 39.48996998369694, 39.493287205696106, 39.85379286110401, 39.910546615719795, 40.736037120223045, 39.001388400793076, 40.663772597908974, 37.8608226031065, 40.07538177073002, 39.86491106450558, 40.49414210021496, 38.678550124168396, 39.502015337347984, 39.05938468873501, 38.5377486795187, 38.11468318104744, 40.08350193500519, 41.56472325325012, 47.09814593195915, 46.07562839984894, 44.59660716354847, 44.1461793333292, 42.868395298719406, 42.752372324466705, 43.11697036027908, 47.35648266971111, 52.10150085389614, 54.5461642742157, 49.085431694984436, 49.94316726922989, 42.52834774553776, 43.723888993263245, 50.85620507597923, 56.65212906897068, 55.47259256243706, 51.26352421939373, 52.026530876755714, 49.22255873680115, 49.58337977528572, 46.53873234987259, 46.18410497903824, 44.560759887099266, 40.59247702360153, 37.350946962833405, 38.20852294564247, 36.615728214383125, 37.08525002002716, 38.210198655724525, 37.7314243465662, 38.93659047782421, 39.506746083498, 39.26649637520313, 37.589209377765656, 36.45711712539196, 38.27248111367226, 39.01893585920334, 38.94767068326473, 37.02666476368904, 37.584227845072746, 37.45836719870567, 43.61536301672459, 48.105741664767265, 48.96971270442009, 50.27279578149319, 48.05015444755554, 48.490440621972084, 46.94257088005543, 42.052655071020126, 41.93436361849308, 40.87395451962948, 39.63269032537937, 40.35694286227226, 40.85799917578697, 42.36020676791668, 45.15607014298439, 46.23991258442402, 47.768676951527596, 48.82858447730541, 48.66899684071541, 48.526276499032974, 50.19909493625164, 49.903485998511314, 52.144628539681435, 49.845193326473236, 49.04200002551079, 53.19309487938881, 50.15946686267853, 38.01576688885689, 13.526348881423473, 0.7411910186056048, 4.654434369876981, 10.621109325438738, 5.022387150675058, 5.864025363698602, 1.084637667518109, 0.4681975767016411, 29.447616152465343, 51.16610124707222, 34.05897840857506, 20.911775082349777, 34.45656247437, 47.25552588701248, 6.457399623468518, 0.04274617735063657, 0.034045037609757856, 0.045891684931120835, 0.05272103546303697, 0.020942364717484452, 0.058195892270305194, 0.07560755620943382, 0.07690822196309455, 0.026194983547611628, 0.0771841302048415, 0.06039181818778161, 0.08663310247357003, 0.04343185129982885, 0.05628513288684189, 0.10365838577854447, 0.1677994115743786, 0.12113765566027723, 0.2808310557156801, 0.10708759786211886, 0.07154452774557285, 0.11221613516681828, 0.15217079082503915, 0.21360075857955962, 0.1163840587832965, 0.13584774249466136, 0.20210162561852485, 0.09972415704396553, 0.10316246043657884, 0.264689699979499, 0.12734749470837414, 0.2980986947659403, 0.12997836369322613, 2.3432264383882284, 46.341602727770805, 63.05521108210087, 40.7098413258791, 35.63954159617424, 52.49872013926506, 56.921728402376175, 55.66744990646839, 60.11217400431633, 13.207205906510353, 0.49753360566683114, 6.009972207248211, 9.280969686806202, 5.2684244234114885, 10.445337407290936, 40.832627937197685, 52.80022256076336, 52.582254856824875, 51.666116416454315, 50.760199427604675, 45.62648490071297, 51.078854128718376, 46.96028932929039, 52.94444762170315, 52.85897880792618, 51.15358091890812, 49.59111995995045, 48.82032752037048, 48.399731889367104, 48.775223940610886, 51.458400562405586, 52.15005464851856, 53.44849817454815, 52.868983671069145, 50.96186600625515, 51.11073821783066, 51.861862912774086, 52.48860128223896, 52.612885013222694, 52.17154249548912, 47.44148410856724, 42.181357964873314, 40.918970704078674, 43.67462083697319, 41.70935869216919, 43.926083743572235, 40.587085112929344, 42.428907081484795, 39.17071491479874, 42.23729096353054, 41.516104862093925, 42.27556250989437, 40.6258088350296, 41.95061154663563, 42.22342170774937, 40.06118193268776, 41.16461992263794, 41.762856021523476, 44.95011739432812, 49.32148642838001, 48.61896872520447, 46.41845740377903, 46.488202661275864, 44.682406559586525, 43.909026458859444, 46.273901760578156, 50.93085587024689, 55.40950454771519, 55.04929527640343, 52.3549472540617, 52.44478203356266, 42.924518287181854, 45.0812179595232, 54.69565585255623, 57.62111887335777, 57.819969803094864, 54.20888677239418, 54.0578106790781, 52.05966129899025, 53.383365869522095, 48.18489521741867, 49.94625270366669, 46.986371129751205, 43.22635509073734, 40.25383159518242, 40.748067274689674, 38.93584191799164, 37.77056984603405, 39.60235275328159, 40.02284578979015, 39.90115351974964, 41.795226484537125, 41.2890138477087, 39.20951463282108, 37.660949528217316, 40.20256094634533, 39.980614855885506, 41.47026412189007, 38.0634581297636, 40.390867441892624, 38.60226161777973, 45.35301357507706, 49.091579765081406, 51.265705302357674, 52.81285688281059, 48.88359032571316, 50.89857280254364, 48.777667209506035, 43.46399433910847, 43.18116791546345, 43.58042769134045, 42.73301236331463, 41.99489437043667, 43.61598998308182, 44.15350154042244, 47.21812069416046, 47.723998948931694, 50.40700078010559, 51.51066675782204, 50.060223788022995, 50.589235201478004, 51.738662123680115, 50.83403706550598, 53.50743681192398, 49.48664076626301, 48.7930753827095, 52.97737665474415, 49.78589370846748, 39.96834151446819, 15.730957332998514, 0.43529166898224503, 7.212840411812067, 16.941204741597176, 16.052238643169403, 17.814631573855877, 2.581666731275618, 0.9809241921175271, 32.378830164670944, 59.147546365857124, 38.3731035143137, 32.477849051356316, 42.2556059807539, 55.87742663919926, 9.596158973872662, 0.1528186263749376, 0.14111181080807, 0.10749442095402628, 0.17079519457183778, 0.11355466529494151, 0.09197502207825892, 0.25242864852771163, 0.15832405595574528, 0.15147866390179843, 0.17521769710583612, 0.12457316857762635, 0.23390054586343467, 0.10610077151795849, 0.10398154656286351], [0.09945051977410913, 0.028604891049326397, 0.04032216718769632, 0.021951670714770444, 0.07552249124273658, 0.01637773162656231, 0.02087316501274472, 0.01827754433179507, 0.01625531993340701, 0.03684214025270194, 0.08461850549792871, 0.061840397684136406, 0.03830639019724913, 0.03683957984321751, 0.025113377523666713, 0.04493937216466293, 0.06152751564513892, 0.05266338543151505, 0.037424818947329186, 9.560815170407295, 48.49236711859703, 42.17692740261555, 31.549754552543163, 30.875053256750107, 43.3722672611475, 50.122316256165504, 49.26394231617451, 14.251342378556728, 0.05590048887825105, 0.5775475152768195, 0.9008764405734837, 0.19000084837898612, 0.7787844794802368, 26.180023290216923, 53.29387307167053, 51.74245432019234, 48.29710699617863, 49.62198570370674, 43.060133010149, 53.9557633548975, 46.98885999619961, 47.554630637168884, 48.95129509270191, 44.87236596643925, 43.80429647862911, 43.68197724223137, 46.8455620855093, 46.4192021638155, 45.330845564603806, 48.000711500644684, 49.83970262110233, 48.43436323106289, 48.69645036756992, 47.712800949811935, 47.750738114118576, 49.72377844154835, 47.38532692193985, 49.031672179698944, 47.116122767329216, 40.36123663187027, 38.27539175748825, 37.65872664749622, 39.86246399581432, 38.22057589888573, 40.412134900689125, 39.187426418066025, 37.66406536102295, 37.6827147603035, 38.3553546667099, 39.73204739391804, 37.7424019575119, 37.14461803436279, 38.60551804304123, 36.82353526353836, 38.0820619314909, 37.738545164465904, 45.519361048936844, 47.75810591876507, 49.16546680033207, 47.34642840921879, 48.69822487235069, 43.38583633303642, 42.472958117723465, 39.74314659833908, 42.030160278081894, 45.6517231464386, 49.97688665986061, 49.83141526579857, 51.35398216545582, 46.35558597743511, 42.714495956897736, 44.12422031164169, 41.27461642026901, 53.73664811253548, 52.13869705796242, 52.10452929139137, 49.854787811636925, 49.604229256510735, 49.369337260723114, 48.129486590623856, 43.12906131148338, 37.754831090569496, 34.44339618086815, 37.16141313314438, 36.89449265599251, 36.458082273602486, 35.46818219125271, 35.87338484823704, 35.716867446899414, 36.401982083916664, 35.76437629759312, 38.207823783159256, 35.75966455042362, 36.74815110862255, 36.398543268442154, 37.976712584495544, 36.25226251780987, 34.844745844602585, 35.201155319809914, 40.052655190229416, 42.66084663569927, 42.03429825603962, 42.36298821866512, 41.58342964947224, 43.64549919962883, 43.3753564953804, 42.207033187150955, 37.15790972113609, 37.77388706803322, 36.499310061335564, 36.38532377779484, 36.994244903326035, 37.084395065903664, 36.96220122277737, 37.92304806411266, 37.9938268661499, 39.94222551584244, 39.66702148318291, 39.47241872549057, 41.447081565856934, 43.58044669032097, 45.90613089501858, 50.176744535565376, 47.432417795062065, 45.78212834894657, 42.267829924821854, 16.13795254379511, 2.6011167000979185, 1.4755253051407635, 6.391405239701271, 8.489312566816807, 7.986085619777441, 5.131050394847989, 0.6168610963504761, 0.5994654516689479, 29.17350646108389, 37.28624403476715, 34.5002069324255, 30.366157963871956, 36.54514700174332, 31.26077625900507, 1.1705395393073559, 0.06396564145688899, 0.013815883303323062, 0.007555712727480568, 0.022111458820290864, 0.007121249736883328, 0.037882412361796014, 0.06741430523106828, 0.020473735567065887, 0.0307359291400644, 0.03308025676233228, 0.06961072838748805, 0.09667218604590744, 0.06416127158445306, 0.04183864948572591, 0.08854316794895567, 0.08437422016868368, 0.06788240745663643, 0.041646036188467406, 0.06459439639002085, 0.050575798231875524, 0.02145344842574559, 0.03682151225802954, 0.05094366228149738, 0.031549577179248445, 0.08094718999927863, 0.026668573955248576, 0.08213007691665553, 0.05474888348544482, 0.00982241726887878, 0.02579919990239432, 0.0440783138765255, 0.027205274745938368, 0.061934361001476645, 16.470801383256912, 56.15203410387039, 43.84669080376625, 32.13221959769726, 40.90826667845249, 50.84083490073681, 54.7822418063879, 54.54990707337856, 15.084330830723047, 0.2021493308711797, 1.049787956289947, 3.7298895930871367, 1.6397061827592552, 1.2615552241913974, 29.441008307039738, 54.3986751884222, 49.79483462870121, 49.24245446920395, 48.95444132387638, 43.89622114598751, 56.69734284281731, 48.537964671850204, 50.272837579250336, 49.896676763892174, 47.48366564512253, 46.355297192931175, 45.1433864235878, 46.706956923007965, 47.23887898027897, 47.34517827630043, 50.50508871674538, 52.19086445868015, 50.90577341616154, 52.55382478237152, 49.919650331139565, 49.86492566764355, 50.399929359555244, 49.86328415572643, 51.4157060533762, 47.887675166130066, 41.23416759073734, 38.397000432014465, 41.086154133081436, 40.221423134207726, 39.99857269227505, 40.81767573952675, 41.15264676511288, 39.6661551296711, 41.08387805521488, 39.977046847343445, 40.01262053847313, 39.68027897179127, 38.8208182901144, 40.4828567057848, 37.363843470811844, 39.87366959452629, 37.8814022988081, 46.193406879901886, 50.15644982457161, 50.57965211570263, 47.996030151844025, 49.21242468059063, 45.55988967418671, 43.10762286186218, 42.682475075125694, 43.139962926506996, 47.76475176215172, 52.04082190990448, 52.26935684680939, 54.209217354655266, 45.4978010058403, 44.29283246397972, 45.237872153520584, 42.84395880997181, 55.83618365228176, 53.75151291489601, 53.995600417256355, 49.950778260827065, 51.089041382074356, 50.04853941500187, 48.785589784383774, 45.414718464016914, 38.39692443609238, 37.32139594852924, 38.80236268043518, 39.21395659446716, 38.614766746759415, 36.832749769091606, 37.55620434880257, 37.91285701096058, 38.582875058054924, 37.416873425245285, 39.469815865159035, 37.36442483961582, 38.69863584637642, 38.25885124504566, 38.681095987558365, 38.60779792070389, 36.67421467602253, 37.81280837953091, 41.02585896849632, 44.43785548210144, 44.87975277006626, 45.10242462158203, 44.405652210116386, 46.43577687442303, 45.54969102144241, 43.50540451705456, 38.875786140561104, 39.71200346946716, 38.49248930811882, 38.19312237203121, 38.10055173933506, 37.78297618031502, 39.09827180206776, 39.59370441734791, 41.92531630396843, 41.6560323536396, 42.71156631410122, 42.96019837260246, 44.00545008480549, 46.05732858181, 50.00702664256096, 50.193817019462585, 47.093312591314316, 48.356873989105225, 46.43073834478855, 18.939376920461655, 3.634949787519872, 1.8532945029437542, 9.04450362548232, 4.335949709638953, 4.497278602793813, 0.5352711619343609, 0.30152121267747134, 0.6645927100908011, 31.80520724505186, 45.382655784487724, 36.53463676571846, 28.651568368077278, 39.306097850203514, 39.32610757648945, 1.7160482425242662, 0.1074405039253179, 0.05269880442938302, 0.05619860959996004, 0.018341563845751807, 0.039754739627824165, 0.014589519378205296, 0.07473873134586029, 0.05944997712504119, 0.046959342289483175, 0.025664995482657105, 0.03311633256089408, 0.09151235979516059, 0.06239091540919617, 0.046535360743291676, 0.20738262974191457, 0.14407876878976822, 0.22682537004584447, 0.07183063309639692, 0.20541608682833612, 0.10841619805432856, 0.16193371382541955, 0.15165688324486837, 0.1034715872083325, 0.1313856092747301, 0.22501438128529117, 0.19823484326479957, 0.1870447999681346, 0.154119492508471, 0.049930426612263545, 0.14771460962947458, 0.08357393264304847, 0.19866223126882687, 0.2014299077563919, 18.70910357683897, 65.43976172804832, 53.8262815028429, 41.96172595024109, 41.316911950707436, 54.08723250031471, 59.56950232386589, 60.13703607022762, 18.159461170434952, 0.3593043558066711, 2.923257714137435, 2.7970292000100017, 1.0169395501725376, 1.8170154746621847, 33.956133127212524, 54.84148822724819, 52.181338369846344, 50.76615750789642, 49.35247376561165, 45.12630634009838, 57.44350120425224, 49.59994688630104, 52.51235380768776, 52.51107707619667, 49.87661384046078, 49.198718816041946, 48.28931741416454, 49.92764890193939, 50.75875170528889, 49.29196201264858, 52.57806368172169, 54.69766594469547, 51.42676346004009, 51.608712896704674, 51.235846504569054, 51.99403502047062, 55.06123423576355, 51.90687149763107, 53.7550201267004, 51.252440214157104, 43.88813138008118, 41.27595014870167, 41.75843685865402, 43.72849054634571, 41.05037145316601, 44.0521077811718, 41.692350804805756, 40.58974117040634, 41.501019671559334, 41.98705539107323, 42.70124986767769, 40.552955344319344, 40.766435489058495, 42.52047456800938, 39.18452337384224, 42.04505927860737, 40.09429715573788, 49.578177854418755, 53.26792426407337, 52.66115382313728, 49.76224757730961, 52.35521703958511, 46.9951144605875, 45.18237613141537, 45.08206531405449, 45.28878562152386, 49.276451244950294, 53.37832733988762, 54.058988615870476, 54.83090199530125, 45.993716195225716, 45.240934789180756, 46.09297826886177, 43.385247364640236, 57.830989211797714, 56.13178879022598, 56.66062541306019, 53.44525694847107, 53.789366483688354, 54.88097570836544, 52.19584979116917, 48.337441831827164, 40.1947333663702, 38.555778712034225, 40.39953477680683, 40.78815892338753, 39.30985204875469, 38.117251843214035, 39.260409101843834, 39.23836648464203, 41.30479820072651, 40.109465941786766, 40.52284196019173, 38.71272549033165, 40.615401193499565, 39.409737288951874, 40.97097471356392, 40.19141994416714, 37.93902240693569, 38.95447611808777, 42.800306752324104, 46.37839235365391, 45.32696217298508, 46.76285572350025, 46.431745290756226, 48.9070350676775, 47.69825533032417, 46.27420574426651, 41.12466886639595, 40.80207757651806, 39.62622307240963, 40.41926331818104, 39.59427438676357, 40.58762468397617, 40.51635570824146, 41.84336990118027, 43.10632713139057, 44.22780655324459, 45.346485525369644, 44.542555063962936, 45.90226270258427, 48.126442953944206, 52.34681189060211, 52.73807689547539, 46.88545614480972, 49.36540447175503, 48.69539022445679, 23.617813177406788, 4.105886779725552, 4.428834775462747, 15.248142890632153, 16.41988031566143, 17.991190999746323, 9.334768150001764, 1.6711377399042249, 0.8924736070912331, 35.142972841858864, 48.77533793449402, 45.94337649643421, 40.327027067542076, 46.82460620999336, 48.173408433794975, 2.4317730870097876, 0.4965201287996024, 0.16105463990243152, 0.10671715484932065, 0.1476924045709893, 0.13075855385977775, 0.17373216978739947, 0.1725745084695518, 0.11393994383979589, 0.09599952565622516, 0.10319671797333285, 0.1717936058412306, 0.17161415453301743, 0.14493642433080822, 0.20399444358190522], [0.11563982567167841, 0.04460711636056658, 0.014054416988074081, 0.05731337849283591, 0.06937956422916614, 0.07116082255379297, 0.08926300666644238, 0.09536988014588133, 0.04380289545224514, 0.050971897289855406, 0.02602892058348516, 0.036449885519687086, 0.06333065990475006, 0.02232142538559856, 0.07656057772692293, 0.08149245331878774, 0.07938341805129312, 0.04108476474357303, 0.017141922944574617, 2.3319291695952415, 36.09749302268028, 43.67196477949619, 25.76232500374317, 26.810584254562855, 40.589752569794655, 43.14445808529854, 53.94833855330944, 22.877145521342754, 0.23023948684567586, 1.2422301736660302, 1.4011016674339771, 0.6153009238187224, 0.7342585281003267, 9.047987088561058, 43.203761503100395, 52.072785794734955, 50.11608459055424, 49.86532084643841, 46.70147381722927, 50.365450009703636, 48.676858618855476, 49.37510535120964, 46.09770521521568, 45.54451949894428, 42.21162714064121, 42.675031274557114, 46.1020065844059, 48.17354142665863, 48.608906865119934, 50.018000453710556, 49.37294326722622, 48.91767829656601, 49.49823394417763, 48.32425653934479, 50.24975761771202, 47.49645195901394, 49.87784877419472, 49.257672652602196, 48.1926354020834, 46.421789824962616, 38.87767843902111, 38.1095914542675, 37.51843437552452, 40.5774412304163, 38.79895806312561, 39.50600512325764, 38.887542709708214, 40.0298298150301, 38.97044286131859, 39.74145568907261, 37.05794468522072, 36.606312319636345, 36.41948774456978, 37.28576526045799, 36.372879445552826, 39.30689960718155, 48.90760123729706, 50.91141991317272, 48.83287064731121, 50.951313972473145, 48.2119307667017, 49.86005812883377, 45.94126760959625, 42.069187983870506, 41.14535495638847, 43.49047511816025, 47.70105578005314, 50.69765858352184, 50.95393963158131, 49.84688423573971, 44.19664442539215, 39.59022380411625, 41.552643701434135, 47.558928206562996, 46.78121253848076, 51.143560856580734, 50.89617133140564, 49.858192428946495, 49.653691202402115, 46.370534375309944, 42.51146525144577, 38.533937484025955, 35.09504981338978, 36.11619181931019, 34.81957599520683, 36.528294906020164, 35.79246439039707, 37.14348189532757, 36.18432216346264, 36.04925461113453, 36.40625685453415, 36.38315409421921, 35.07210284471512, 40.96878603100777, 37.01963134109974, 36.03043042123318, 36.12685404717922, 35.45869030058384, 37.4732282012701, 42.99987584352493, 44.43710312247276, 44.63631883263588, 42.81113997101784, 44.2049165815115, 42.28240214288235, 43.97469453513622, 39.518943428993225, 40.82747161388397, 35.7077631354332, 36.01343013346195, 34.33024205267429, 35.42665421962738, 34.276391342282295, 36.961486861109734, 33.18187527358532, 35.431289970874786, 34.011769741773605, 38.59814643859863, 37.60148651897907, 40.78005775809288, 40.148018673062325, 48.04415836930275, 44.78950001299381, 52.194888442754745, 45.720742642879486, 29.80317447334528, 4.37251609750092, 5.180209781974554, 4.809538247063756, 1.8819164671003819, 4.387590363621712, 2.026802455075085, 1.023124074563384, 0.22398002038244158, 1.237831434700638, 31.17901224642992, 31.194982789456844, 30.243952721357346, 30.21736364811659, 40.37857510149479, 23.17628636956215, 0.10273086445522495, 0.07582243764773011, 0.04374841068056412, 0.040448506697430275, 0.017144294106401503, 0.07329909843974747, 0.042734796516015194, 0.03596345595724415, 0.04458904506464023, 0.00452970530204766, 0.03694045255542733, 0.05494376404385548, 0.0830829722690396, 0.05549820401938632, 0.056783778200042434, 0.09363244564156048, 0.042605065391398966, 0.014128951806924306, 0.0501503843406681, 0.08127349748974666, 0.10529763414524496, 0.048997699122992344, 0.06920650281244889, 0.03504567161144223, 0.035989019233966246, 0.029700143313675653, 0.04689624489401467, 0.03851601722999476, 0.03163260123983491, 0.05413627397501841, 0.1306884505902417, 0.020766811539942864, 0.055734815541654825, 0.03493336611427367, 4.547364190220833, 45.060984045267105, 49.10172522068024, 30.415213331580162, 33.07660572230816, 48.152904734015465, 48.248716592788696, 56.87962286174297, 21.565522402524948, 0.2384941282798536, 1.6176254488527775, 4.257386550307274, 1.7179147736169398, 0.6764712883159518, 12.506003882735968, 45.967638194561005, 51.84078924357891, 49.24960948526859, 51.93883918225765, 47.70606391131878, 50.901673436164856, 49.40266527235508, 52.649853229522705, 48.198164105415344, 48.479953184723854, 44.25744116306305, 44.85859550535679, 46.630638018250465, 49.47263091802597, 49.46103394031525, 52.40623690187931, 51.4352598041296, 50.580385476350784, 51.79426833987236, 49.14426013827324, 51.25674918293953, 50.87430730462074, 51.22925005853176, 50.69832354784012, 50.1267696171999, 46.78305923938751, 40.2094803750515, 39.21453416347504, 39.98973436653614, 41.478460282087326, 40.86146458983421, 41.903832256793976, 40.75777195394039, 41.387861743569374, 40.12135550379753, 41.8566007912159, 38.56197617948055, 38.43977473676205, 39.10243637859821, 39.81565050780773, 38.777660205960274, 41.105156913399696, 51.221946850419044, 53.2109235227108, 49.24596548080444, 51.51386998593807, 50.75764216482639, 50.95801301300526, 47.84679315984249, 43.698874935507774, 42.02348783612251, 45.09794466197491, 50.29611133038998, 52.43240609765053, 53.273319974541664, 50.23895859718323, 44.559635147452354, 39.628217965364456, 41.00378215312958, 48.095922991633415, 49.689287692308426, 52.43518374860287, 51.61296866834164, 51.19149908423424, 51.83468297123909, 47.571053355932236, 44.58669729530811, 39.60307091474533, 36.39372132718563, 38.133089393377304, 37.11345590651035, 38.29224765300751, 37.61916697025299, 39.72785621881485, 37.91901648044586, 37.1506293118, 38.04173469543457, 37.77547538280487, 37.2756540030241, 43.057142570614815, 39.39239501953125, 38.209290504455566, 38.0861809104681, 37.377024963498116, 37.90974497795105, 44.15395371615887, 45.09112402796745, 45.55629886686802, 45.40170796215534, 45.39440855383873, 43.892991319298744, 45.57896465063095, 42.20723457634449, 41.61387741565704, 38.92883889377117, 38.16200964152813, 37.4398659914732, 37.080572471022606, 35.36384359002113, 37.68041588366032, 34.69105929136276, 37.0871689170599, 36.5841519087553, 40.41549392044544, 38.60886186361313, 43.41473378241062, 43.42205598950386, 50.205573588609695, 46.668480187654495, 52.0295213162899, 43.71955342590809, 33.36952820420265, 5.9958497900515795, 6.863101478666067, 5.555500918999314, 1.8269905331544578, 2.9686847515404224, 0.4805531183956191, 0.45773495687171817, 0.14527536317473277, 1.0442750458605587, 36.2777591496706, 37.92846277356148, 36.845608279109, 33.59867110848427, 45.91902360320091, 29.569899290800095, 0.36235841223970056, 0.12631691875867546, 0.03335506291477941, 0.028168714161438402, 0.029728628796874546, 0.04129855522478465, 0.03259780511143617, 0.023159128286351915, 0.022071900493756402, 0.006384455728039029, 0.045945598249090835, 0.021024629932071548, 0.007536553257523337, 0.05449411160952877, 0.05253339826595038, 0.19402891426580027, 0.1558462029788643, 0.09278673125663772, 0.1350675820140168, 0.2245035461965017, 0.16438683844171464, 0.14902216993505135, 0.2751222479855642, 0.10360511441831477, 0.11116054141893983, 0.1580296756583266, 0.14576446817955002, 0.14565572870196775, 0.13782758469460532, 0.14272568514570594, 0.17119127878686413, 0.12042322719935328, 0.11084768906584941, 0.13683812372619286, 5.769393341615796, 50.31172849237919, 56.10018968582153, 36.46535128355026, 36.50528334081173, 52.84515514969826, 52.70808890461922, 63.859973698854446, 27.28603184223175, 0.3090439777588472, 6.61749548278749, 9.569081626832485, 1.8519648117944598, 1.407270161435008, 14.078834485262632, 47.50320799648762, 51.43133461475372, 50.041255205869675, 50.67553997039795, 48.723900094628334, 52.06276573240757, 49.95596878230572, 53.81191827356815, 51.27217635512352, 51.78783528506756, 47.66914129257202, 46.98961615562439, 48.68251271545887, 52.102568596601486, 52.23855949938297, 53.46758455038071, 53.44295807182789, 53.24457071721554, 54.36301790177822, 50.70386365056038, 54.654602855443954, 52.210118025541306, 54.952351078391075, 53.68014894425869, 53.83312873542309, 51.18955738842487, 42.933728992938995, 41.9446686655283, 40.728730112314224, 44.69184525310993, 42.388294860720634, 44.07370202243328, 42.67043352127075, 42.64264561235905, 41.913753524422646, 43.390855863690376, 40.69710060954094, 39.82498660683632, 41.11040063202381, 41.26490794122219, 40.850224792957306, 41.84356369078159, 52.559049502015114, 55.27897395193577, 51.506600975990295, 53.853191658854485, 52.160450890660286, 55.26033595204353, 49.95327852666378, 46.976503059268, 45.45386776328087, 46.391672641038895, 52.08542011678219, 54.061063304543495, 54.244650453329086, 51.23341083526611, 44.63283821940422, 40.80969996750355, 43.119364231824875, 49.12698246538639, 49.00225415825844, 53.82818520069122, 54.83044981956482, 52.98699393868446, 54.904355853796005, 50.02971902489662, 47.78535805642605, 41.497265473008156, 38.08527275919914, 40.57889275252819, 39.54695172607899, 40.61887800693512, 39.494693130254745, 40.915189906954765, 39.80783052742481, 39.15396921336651, 40.25120593607426, 39.293725714087486, 38.02060402929783, 46.122248098254204, 41.05911858379841, 40.71738392114639, 40.11236138641834, 39.498276337981224, 39.62436497211456, 46.82767644524574, 48.09257157146931, 47.90618397295475, 47.623661532998085, 48.1906633079052, 46.18670403957367, 48.582555279135704, 44.397205263376236, 44.64605771005154, 39.40585769712925, 40.36211058497429, 38.10493290424347, 39.148657098412514, 36.55632600188255, 40.60695804655552, 35.84980711340904, 38.1944826990366, 38.36856655776501, 42.94669009745121, 42.7049470692873, 46.43227346241474, 45.88876962661743, 50.84537945687771, 48.83666284382343, 51.916203796863556, 46.54916658997536, 35.49287706613541, 7.510005841031671, 10.552986580878496, 9.68479871749878, 7.5413627084344625, 14.256727639585733, 4.612213410437107, 4.0479926113039255, 1.2183038075454533, 1.9021318573504686, 39.305866062641144, 43.57937894761562, 43.8532530516386, 41.21940538287163, 53.13564956188202, 35.124665424227715, 0.8990989672020078, 0.26149427925702184, 0.25853949249722064, 0.10971350187901407, 0.11034614566597156, 0.18164631386753172, 0.15026759763713926, 0.11727764169336297, 0.14331348094856367, 0.21057356789242476, 0.18597673071781173, 0.153182738868054, 0.22378780413419008, 0.15835314814466983, 0.13607135158963501], [0.0040318457376997685, 0.10720156948082149, 0.0285998667095555, 0.00792470020314795, 0.01680893426964758, 0.06166787803522311, 0.02419853950414108, 0.021928489732090384, 0.020452764329093043, 0.024802660700515844, 0.020187793488730676, 0.18265909311594442, 0.01580262469360605, 0.02402653935860144, 0.0648278537846636, 0.042050335978274234, 0.068928368127672, 0.04546522461168934, 0.1123775151791051, 0.37161364685744047, 22.2500803694129, 47.40371413528919, 31.110819205641747, 25.46445708721876, 36.53207190334797, 33.313800394535065, 55.1507992297411, 22.2128214687109, 0.05069025224656798, 0.4834355309139937, 4.229230536147952, 2.75470825843513, 0.18185246764915064, 1.5997827937826514, 27.703040465712547, 53.49477209150791, 53.158748522400856, 48.88759911060333, 47.30275735259056, 47.90424607694149, 46.861798614263535, 50.25469355285168, 45.31848482787609, 44.21048328280449, 40.682760179042816, 41.969371140003204, 42.787170857191086, 47.40516185760498, 48.55918273329735, 51.145122572779655, 52.57534682750702, 52.97681048512459, 49.915937930345535, 48.153007328510284, 46.982039362192154, 46.5195319801569, 48.525839522480965, 50.073241889476776, 49.11450773477554, 49.75747883319855, 47.73414820432663, 41.97497583925724, 36.480858251452446, 37.69665241241455, 36.77358694374561, 39.68329221010208, 37.60606907308102, 39.34120036661625, 37.60037697851658, 39.21474315226078, 36.7979322373867, 38.218713998794556, 35.958963856101036, 38.157297894358635, 35.10144867002964, 42.02576391398907, 53.834044486284256, 51.53016731142998, 52.70211182534695, 51.118599995970726, 52.543785721063614, 48.79010774195194, 49.46258045732975, 48.744867369532585, 43.52608680725098, 44.21151302754879, 46.15644246339798, 50.446123480796814, 52.4877805262804, 48.815604373812675, 45.72290852665901, 50.980796590447426, 51.433496698737144, 51.812898740172386, 51.84961996972561, 52.02981390058994, 50.29256232082844, 50.9665397554636, 47.63940028846264, 46.425331234931946, 38.78305211663246, 35.655314549803734, 35.078110322356224, 35.28681792318821, 36.328999400138855, 36.33682698011398, 36.50447018444538, 34.47023034095764, 35.48104830086231, 36.76811143755913, 35.90417839586735, 38.141201958060265, 36.71602003276348, 35.784336626529694, 37.813921719789505, 34.722867384552956, 35.63003070652485, 34.828015342354774, 38.118984550237656, 48.37894320487976, 48.17473076283932, 47.7991247177124, 46.27232104539871, 47.398846596479416, 45.128384828567505, 44.58242252469063, 44.861464351415634, 42.59768262505531, 39.71834912896156, 38.4891264885664, 37.08455465734005, 35.92929884791374, 33.590752333402634, 35.87302386760712, 35.60644157230854, 36.903099194169044, 39.88980732858181, 41.24902859330177, 44.08455803990364, 45.629862919449806, 43.834964632987976, 47.59831689298153, 50.32929114997387, 47.75304079055786, 42.00493723154068, 13.831084929406643, 0.7772060798015445, 2.9838998476043344, 2.2951008332893252, 4.017313057556748, 0.3360256471205503, 0.6452948518563062, 0.26640328927896917, 0.24961023882497102, 2.341188797727227, 31.108679920434952, 33.04267734289169, 21.581728532910347, 25.62662098556757, 40.376272425055504, 10.339301247149706, 0.008946448306232924, 0.06633801298448816, 0.031727314126328565, 0.04187248399830423, 0.031312097344198264, 0.09136167413089424, 0.008490544205415063, 0.06404971194569953, 0.021072366726002656, 0.06734953058185056, 0.07517553720390424, 0.028101158313802443, 0.08217467999202199, 0.03578093586838804, 0.02698148939089151, 0.0081833228978212, 0.052058305009268224, 0.024445331437163986, 0.06880400644149631, 0.0440932533092564, 0.0327677940367721, 0.00789609226558241, 0.012766473500960274, 0.03758282218768727, 0.0043361109783290885, 0.044741586098098196, 0.025674029275251087, 0.08962035819422454, 0.06534680054755881, 0.025111420109169558, 0.022689881297992542, 0.13912111840909347, 0.02632594663737109, 0.05826847060234286, 0.8068780938629061, 29.207938313484192, 53.7256895005703, 32.588502913713455, 28.570583313703537, 44.25120569765568, 39.362935200333595, 59.61456410586834, 26.308380402624607, 0.19791990547673777, 1.379984300583601, 8.968068826943636, 3.2676852447912097, 0.31509473745245486, 2.501483908854425, 33.91588568687439, 54.280159547924995, 52.576380372047424, 48.752592355012894, 48.44433009624481, 48.77361662685871, 50.90446248650551, 52.071079686284065, 47.26179555058479, 47.67148196697235, 43.994445875287056, 45.116977840662, 46.887489035725594, 49.156047105789185, 49.799401983618736, 51.83701604604721, 54.133411422371864, 52.671626061201096, 50.81783093512058, 48.93556393682957, 48.06061528623104, 48.653258085250854, 49.97930333018303, 52.69589155912399, 51.00458711385727, 50.67675970494747, 49.0327475219965, 44.21790808439255, 36.82944394648075, 39.8617572337389, 39.378008991479874, 41.75397589802742, 39.69596453011036, 39.33398835361004, 39.144405126571655, 41.15801587700844, 38.23050856590271, 39.845847487449646, 38.388184905052185, 39.76561099290848, 36.03463679552078, 44.562971368432045, 55.35832889378071, 52.11782477796078, 53.565957471728325, 53.15839134156704, 53.93883526325226, 50.44881373643875, 50.23749567568302, 49.416029155254364, 46.35378107428551, 45.56808963418007, 47.89188154041767, 51.90190136432648, 54.50178265571594, 50.503492802381516, 45.792653784155846, 51.87751807272434, 53.00733044743538, 51.8454933911562, 51.728733256459236, 54.36274811625481, 52.98804268240929, 52.704760283231735, 49.31812360882759, 48.20595748722553, 41.01678505539894, 36.31541892886162, 36.38132259249687, 36.92308612167835, 37.771439999341965, 38.18606235086918, 39.098408594727516, 37.58408345282078, 36.836633160710335, 37.06147849559784, 37.931126430630684, 39.417051896452904, 37.48182713985443, 38.02774004638195, 38.81714388728142, 37.010280042886734, 37.41818815469742, 36.637816429138184, 39.63183157145977, 50.49606800079346, 49.07498985528946, 48.04468274116516, 49.38882261514664, 49.08413216471672, 47.312914207577705, 46.38355627655983, 45.772055089473724, 43.40863510966301, 41.2087507545948, 40.33139683306217, 39.416675716638565, 36.08547426760197, 36.29806526005268, 37.1545697003603, 37.72596403956413, 38.79718355834484, 40.89557155966759, 43.85982669889927, 45.20224906504154, 47.25859612226486, 45.68554513156414, 49.94246430695057, 51.9682078063488, 47.842362597584724, 46.57555617392063, 15.937737487256527, 1.6974958567880094, 4.893926968798041, 1.7332344828173518, 1.026354969944805, 0.685523827560246, 0.6159477797336876, 0.03820262681983877, 0.1922871678834781, 2.3062256863340735, 33.97467993199825, 37.042240127921104, 27.86489088088274, 30.427091494202614, 48.78605715930462, 14.45931851863861, 0.052959290842409246, 0.007533252555731451, 0.018927341006929055, 0.035327543009771034, 0.08055706523009576, 0.03037720834981883, 0.03074322816246422, 0.02553384500060929, 0.015962067700456828, 0.08148737702867948, 0.01941601742146304, 0.060848316934425384, 0.10475708346348256, 0.036670700428658165, 0.02254958755656844, 0.1365875598276034, 0.2545296389143914, 0.061878265769337304, 0.16845919570187107, 0.1442283412325196, 0.33463563420809805, 0.17452649044571444, 0.10254661887302063, 0.21994331589667127, 0.08250216749729589, 0.14880543312756345, 0.2032923125079833, 0.2150122937746346, 0.08360010077012703, 0.24382579140365124, 0.19472761661745608, 0.2377721224911511, 0.1262349559692666, 0.20483765692915767, 0.968045376939699, 33.80634896457195, 64.15882766246796, 41.37160241603851, 33.99468205869198, 47.75373235344887, 43.23917560279369, 63.53342302143574, 26.97554860264063, 0.15780168789206073, 1.8871172005310655, 9.152604974806309, 9.858595691621304, 0.6273829692509025, 3.8794984901323915, 36.25068560242653, 54.23281408846378, 53.24341557919979, 48.9910713583231, 47.803156301379204, 51.47352375090122, 52.3726125061512, 54.162498861551285, 49.15078818798065, 48.7482263892889, 45.192236602306366, 47.38893672823906, 47.81862907111645, 52.31223374605179, 52.153117284178734, 54.033879563212395, 53.7982390075922, 54.83207233250141, 51.35089673101902, 51.39059320092201, 51.91131725907326, 50.68185903131962, 51.89575709402561, 54.20432321727276, 54.003986567258835, 52.916937097907066, 52.418126463890076, 46.53617508709431, 38.825279250741005, 42.24195331335068, 40.504678934812546, 45.76599061489105, 40.51339566707611, 40.82135394215584, 39.9532563239336, 43.21640722453594, 40.08958540856838, 41.582236513495445, 40.44013559818268, 41.67745940387249, 37.74896800518036, 45.299991220235825, 58.3257682621479, 54.15372133255005, 56.02678902447224, 54.3645416200161, 56.14424832165241, 52.04052932560444, 51.22463710606098, 52.29231521487236, 48.217535465955734, 47.470525950193405, 50.1452062278986, 52.905549108982086, 56.46957166492939, 51.20262488722801, 45.83808794617653, 54.12523806095123, 54.52702470123768, 54.32327203452587, 53.1755094230175, 56.352465748786926, 54.04568172991276, 54.91260141134262, 49.41529959440231, 50.5033066123724, 42.72368386387825, 39.528959691524506, 38.90178054571152, 39.35017928481102, 40.76703205704689, 38.362236097455025, 41.21045306324959, 38.02459381520748, 37.33363889157772, 39.93180647492409, 39.95467744767666, 42.173796370625496, 39.346702471375465, 38.825381845235825, 41.39922693371773, 37.297430634498596, 38.50591018795967, 38.34895201027393, 42.806276232004166, 52.376708686351776, 51.37284815311432, 51.044655963778496, 51.59305393695831, 51.6377167403698, 48.38996261358261, 48.68735745549202, 49.17721576988697, 47.38463915884495, 45.037163123488426, 42.04303778707981, 40.93291595578194, 38.30837778747082, 36.36321656405926, 39.5638570189476, 39.874950125813484, 40.35358004271984, 43.62287901341915, 45.13176664710045, 47.88957126438618, 50.77670194208622, 48.395377323031425, 52.84186452627182, 53.176497370004654, 49.31711286306381, 46.75855055451393, 19.58318207412958, 2.0123487431555986, 7.256420748308301, 5.1828135922551155, 10.167613159865141, 4.029399733990431, 1.546756757888943, 0.6544042692985386, 0.44627898721955717, 3.1251009833067656, 38.66356372833252, 43.959860131144524, 32.82016508281231, 35.63096545636654, 55.465327352285385, 17.869873009622097, 0.1622772985137999, 0.1155334610666614, 0.05622024320473429, 0.10499667841941118, 0.2550440956838429, 0.1392642193241045, 0.1573638801346533, 0.10491176188224927, 0.10405340872239321, 0.18455073848599568, 0.11791404074756429, 0.15570857911370695, 0.26394488057121634, 0.19477009715046734, 0.12451660208171234], [0.02978550699481275, 0.024014980408537667, 0.11983573567704298, 0.02927414869191125, 0.0398812386993086, 0.07664759454200976, 0.09996101347496733, 0.06767747821868397, 0.029929546726634726, 0.06855984727735631, 0.044508889404824004, 0.09223479602951556, 0.0547496182116447, 0.06854906387161463, 0.0391775528260041, 0.0520388125005411, 0.026161243658862077, 0.08481671087793075, 0.018233998816867825, 0.03488731585093774, 8.715184796601534, 47.20867060124874, 39.996083825826645, 26.774377897381783, 38.96648347377777, 39.54912140965462, 43.62541727721691, 32.19667173922062, 0.34457999747246504, 0.4273166984785348, 8.747541010379791, 1.4743746793828905, 0.36785731092095375, 0.10653409670339897, 9.23819538205862, 40.5026688426733, 55.50782427191734, 51.64384961128235, 48.895164504647255, 48.211824372410774, 49.43574249744415, 52.432531490921974, 47.66137830913067, 44.066391214728355, 42.22204238176346, 43.18424575030804, 44.67156954109669, 48.8061048835516, 49.41739708185196, 50.38965851068497, 50.010324865579605, 48.947233110666275, 50.32152056694031, 49.19914059340954, 45.35694636404514, 46.781261935830116, 46.094087809324265, 49.318298399448395, 50.297585651278496, 50.62707357108593, 49.95189160108566, 47.93499402701855, 41.64654806256294, 36.887903809547424, 37.42354966700077, 39.736409559845924, 38.08613911271095, 40.60559771955013, 37.82622925937176, 40.66248446702957, 36.27928666770458, 38.02206315100193, 35.4979307949543, 36.17731913924217, 36.423283740878105, 41.44086889922619, 50.50734579563141, 49.30555008351803, 51.293713599443436, 49.540525674819946, 47.74043686687946, 54.350508973002434, 50.66957429051399, 50.45792184770107, 46.0632448643446, 46.514048874378204, 46.65290102362633, 48.10786575078964, 52.580180168151855, 50.558912828564644, 46.97016879916191, 49.689185097813606, 50.641167014837265, 51.84293232858181, 51.10455974936485, 49.23037491738796, 49.49762597680092, 47.3601570725441, 47.4217289686203, 42.99639143049717, 35.50958476960659, 35.70110209286213, 35.93965709209442, 36.643485724925995, 36.296241357922554, 36.930822506546974, 37.00008139014244, 35.792217403650284, 37.21979700028896, 35.15330068767071, 35.70014454424381, 35.443217530846596, 34.79559548199177, 35.97611613571644, 34.71941716969013, 35.846577286720276, 35.98600320518017, 34.22770455479622, 36.34323723614216, 47.04964153468609, 48.0381128937006, 48.853856921195984, 48.17843936383724, 46.86389610171318, 47.86413922905922, 47.90493004024029, 47.49873943626881, 45.264455527067184, 44.68098163604736, 44.34495806694031, 40.74559360742569, 38.29375617206097, 36.77418731153011, 35.42667701840401, 35.58455854654312, 39.081993475556374, 43.342465460300446, 44.17960613965988, 45.24701066315174, 45.02232871949673, 51.19413994252682, 47.894001826643944, 49.06085081398487, 47.28079453110695, 27.30482753366232, 2.270625871606171, 0.09293933908338659, 0.7502714032307267, 0.21892817661864683, 1.4312266884371638, 0.3764837980270386, 0.09871995702269487, 0.19984675833256915, 0.17584096756763756, 4.133683713153005, 34.2631870508194, 27.79588658362627, 22.611150294542313, 30.264222733676434, 33.71538944542408, 2.026645001024008, 0.07272117320098914, 0.03648009464086499, 0.057879588930518366, 0.01596881753357593, 0.027154595336469356, 0.07401254726573825, 0.024617326016596053, 0.01654301904636668, 0.015516858875344042, 0.04857847103266977, 0.07047942708595656, 0.006801085373808746, 0.0704347349528689, 0.05539518650039099, 0.03141862151096575, 0.04402018887049053, 0.015277023649105104, 0.0058216549950884655, 0.07295433373656124, 0.018789101159200072, 0.11904321843758225, 0.056860987533582374, 0.025686731132736895, 0.06803415439208038, 0.046336290761246346, 0.04352228941570502, 0.06900228603626601, 0.021428206127893645, 0.07146483592805453, 0.04706243773398455, 0.04170904452621471, 0.042218996459268965, 0.03219263700884767, 0.03744934692804236, 0.08326741080963984, 13.76660618931055, 55.074769109487534, 41.56448766589165, 29.217211715877056, 43.46680998802185, 42.015428468585014, 50.072280541062355, 32.90694862604141, 0.22533635463332757, 0.2709185454295948, 3.2544783409684896, 3.391111884266138, 0.293139218701981, 0.9508263634052128, 13.025502506643534, 44.67238649725914, 55.687269642949104, 51.15823186933994, 47.78800651431084, 50.04128560423851, 52.02848017215729, 53.84278781712055, 49.2213200032711, 46.35859541594982, 43.008410185575485, 45.7822385430336, 46.956272944808006, 50.923932641744614, 51.31133705377579, 51.88587762415409, 52.15140737593174, 50.9199770539999, 49.20313037931919, 50.037979781627655, 48.1126344949007, 49.41130980849266, 47.46365211904049, 52.483391761779785, 51.84235855937004, 52.35432028770447, 53.17371591925621, 49.87746499478817, 42.60974317789078, 38.50214459002018, 39.74737197160721, 39.97045420110226, 39.86151024699211, 41.344962045550346, 40.927090868353844, 42.9608291387558, 37.99839802086353, 39.9760664999485, 37.55898579955101, 39.149679243564606, 37.15523846447468, 43.63308146595955, 53.62233504652977, 50.917252600193024, 52.6068015396595, 50.61252415180206, 50.410287603735924, 54.48578171432018, 52.15273730456829, 51.370332688093185, 49.04678396880627, 46.38801723718643, 48.36630128324032, 49.265853613615036, 54.29172992706299, 49.57896441221237, 48.96228790283203, 52.43912793695927, 51.40980117022991, 53.6775004863739, 50.49807049334049, 52.12882898747921, 50.43000854551792, 49.18465577065945, 50.36984257400036, 45.92687778174877, 37.199251502752304, 38.401468992233276, 36.91169813275337, 38.24775584042072, 37.82786697149277, 37.79103174805641, 39.125204756855965, 37.59677097201347, 39.65670503675938, 37.50329978764057, 36.82403303682804, 37.452751100063324, 36.68956205248833, 37.05502264201641, 36.213295608758926, 37.412260472774506, 38.41983340680599, 36.22683808207512, 38.42518351972103, 47.832414731383324, 49.856136739254, 48.645248115062714, 49.99165266752243, 48.94421987235546, 49.085097312927246, 50.665041133761406, 49.54993017017841, 46.67858764529228, 46.69538274407387, 45.47732010483742, 42.77710139751434, 40.218584686517715, 38.80080096423626, 38.1076193600893, 37.82071955502033, 40.95263309776783, 45.16061469912529, 47.32391841709614, 48.540571331977844, 48.253861516714096, 51.219571977853775, 49.30090293288231, 50.07042624056339, 47.6390241086483, 31.272435933351517, 3.1704458501189947, 0.8354431798215955, 2.192755937576294, 0.3186967660440132, 1.0792601248249412, 0.19192140782251954, 0.155235831043683, 0.05655800945532974, 0.1765177765628323, 3.9257911685854197, 37.2400689125061, 32.01390154659748, 23.812167048454285, 33.77435468137264, 43.05889807641506, 4.30848098360002, 0.04122073733014986, 0.07299577526282519, 0.02723902576690307, 0.02321138290426461, 0.03202389118087012, 0.061278302455320954, 0.05990745921735652, 0.09161720299744047, 0.0689806672744453, 0.09086631282116286, 0.047265827015507966, 0.009146989596047206, 0.05084629250632133, 0.028177070744277444, 0.05289605614962056, 0.12569961516419426, 0.2185408942750655, 0.19227524899179116, 0.2046356740174815, 0.11698982198140584, 0.22747737646568567, 0.31272146792616695, 0.14309386460809037, 0.19042287807678804, 0.19956895761424676, 0.10965574794681743, 0.22725608287146315, 0.18376355728833005, 0.15824164787773043, 0.13963260658783838, 0.15997048089047894, 0.21289102791342884, 0.22851127723697573, 0.11778697022236884, 0.23103597457520664, 15.449432339519262, 61.05791285634041, 51.50446929037571, 38.96202631294727, 51.02887161076069, 49.212455078959465, 53.19572053849697, 39.057838171720505, 0.6652938912156969, 1.5823655971325934, 21.61545742303133, 5.477583725005388, 1.8548160837963223, 0.8885314967483282, 13.526630066335201, 45.9054659307003, 54.77876119315624, 52.53298670053482, 50.26873379945755, 51.28111347556114, 54.229702055454254, 56.13634094595909, 52.24447958171368, 48.72562900185585, 46.49390235543251, 47.14641094207764, 49.275413900613785, 53.24054293334484, 52.015142887830734, 53.08800771832466, 53.07842083275318, 51.087677255272865, 51.80323585867882, 51.273320093750954, 48.736093640327454, 51.00743316113949, 50.01881740987301, 54.28355656564236, 53.13644751906395, 55.33822037279606, 55.802194476127625, 53.579754531383514, 45.02515956759453, 39.64716374874115, 41.35568507015705, 43.12352880835533, 41.182649955153465, 43.97680342197418, 41.47411331534386, 44.178538396954536, 39.18442077934742, 41.285955011844635, 37.88199506700039, 40.574557185173035, 39.44528058171272, 45.105403661727905, 54.94862347841263, 52.503500282764435, 54.45502996444702, 52.84135915338993, 52.05693304538727, 56.55871868133545, 54.495877772569656, 54.387735575437546, 50.10588973760605, 49.523665979504585, 52.345561757683754, 50.71983799338341, 55.797786712646484, 52.07039572298527, 48.93592871725559, 54.2338552325964, 54.165295511484146, 55.39148971438408, 53.60792241990566, 52.49599948525429, 51.59502603113651, 51.724899262189865, 49.52506810426712, 48.077528178691864, 39.18994568288326, 40.04953935742378, 37.78728134930134, 41.055926755070686, 39.901465103030205, 39.636037945747375, 40.48304669559002, 38.56968216598034, 41.07765018939972, 37.68257796764374, 38.85561682283878, 38.64246726036072, 38.064385280013084, 38.821445256471634, 37.030551955103874, 38.69529202580452, 41.03946603834629, 37.97216422855854, 39.618980661034584, 48.765602856874466, 53.92906978726387, 50.29598593711853, 51.46176718175411, 49.87343341112137, 51.12698994576931, 53.84784534573555, 52.15863838791847, 49.694330021739006, 50.07147118449211, 48.03933642804623, 46.12386301159859, 41.31964400410652, 41.24132640659809, 39.84839715063572, 39.267415925860405, 43.707029297947884, 46.762266755104065, 48.710437417030334, 51.14638030529022, 49.11036975681782, 55.40886998176575, 49.43884313106537, 52.558441534638405, 47.409280836582184, 34.07918192446232, 4.249878628179431, 0.3732958878390491, 1.7141440697014332, 3.0810060119256377, 4.157385416328907, 1.2723841681145132, 0.4115682060364634, 0.3853109321789816, 0.24494713201420382, 4.742934945970774, 43.45663793385029, 38.50429527461529, 33.55008311569691, 40.352717489004135, 51.634353920817375, 6.514094481244683, 0.19472846266580746, 0.16169554379303008, 0.15709684055764228, 0.09407512188772671, 0.11996196015388705, 0.2692967152688652, 0.14951599499909207, 0.10643087880453095, 0.15748954057926312, 0.26158021995797753, 0.1656400883803144, 0.12709434813586995, 0.15141939598834142, 0.139233123336453, 0.17916976707056165], [0.03273164031270426, 0.006638652439505677, 0.029075642742100172, 0.0498484823765466, 0.03846983709081542, 0.020410096403793432, 0.02696996754821157, 0.0581912204506807, 0.04982873011613265, 0.04453840461792424, 0.02981808727781754, 0.053867263995925896, 0.039979491630219854, 0.05471449236210901, 0.06325019625364803, 0.012473781589505961, 0.023464807782147545, 0.04468828505196143, 0.08976184122730047, 0.044412495553842746, 0.8171977463643998, 30.161280557513237, 43.62871930003166, 25.238367319107056, 36.05202466249466, 31.65996953845024, 35.625353157520294, 41.73678182065487, 0.3750031243544072, 0.08793929722742178, 2.501562279649079, 2.537274663336575, 0.3375810995930806, 0.18273991299793124, 3.3804596308618784, 24.753180854022503, 49.773331582546234, 53.19703906774521, 53.61540801823139, 52.43018701672554, 49.90678422152996, 48.00833769142628, 44.51135493814945, 42.544698268175125, 40.627655535936356, 41.64613388478756, 46.29870682954788, 49.17344257235527, 51.980370953679085, 49.3035551905632, 49.916374906897545, 50.33370651304722, 50.04730448126793, 49.73650395870209, 52.80722178518772, 52.14981526136398, 49.889859929680824, 50.040844827890396, 47.255579084157944, 47.79581889510155, 48.55598330497742, 50.432421416044235, 48.9776124805212, 39.1049974411726, 38.25678415596485, 37.53768414258957, 37.18678057193756, 39.65634785592556, 37.972563207149506, 38.4416214376688, 38.08393143117428, 38.603241965174675, 35.47222137451172, 37.18625620007515, 35.18105439841747, 39.26653437316418, 48.268053755164146, 51.20226010680199, 49.84230928122997, 47.55990855395794, 43.35098460316658, 40.991740599274635, 47.668415531516075, 53.29195037484169, 49.698718786239624, 47.8788748383522, 48.116270899772644, 47.81154245138168, 51.742701306939125, 49.800807908177376, 48.33588011562824, 51.18328772485256, 49.23659138381481, 49.217204824090004, 48.901339173316956, 48.17756921052933, 47.97123268246651, 47.19613507390022, 40.45252673327923, 37.7952229231596, 35.452538430690765, 35.851600617170334, 36.85586392879486, 35.22100165486336, 36.441385969519615, 37.8017433732748, 36.01908802986145, 37.0104206353426, 38.31428647041321, 35.54729014635086, 37.94564165174961, 36.099142134189606, 34.14015345275402, 36.50884374976158, 34.79169309139252, 36.05366237461567, 35.13759233057499, 35.84249250590801, 35.534036457538605, 40.1947295665741, 46.87751457095146, 47.09113530814648, 47.9916337877512, 47.5696512311697, 47.39373207092285, 45.60573421418667, 47.5257483869791, 47.4646932631731, 46.978148370981216, 45.61065874993801, 45.36099694669247, 43.07633154094219, 37.71765388548374, 35.236641615629196, 35.9412682056427, 36.0662966966629, 39.47283670306206, 42.66154959797859, 46.204734072089195, 48.617756590247154, 47.59307697415352, 47.225712686777115, 47.10520215332508, 40.64207196235657, 10.040312390774488, 0.12200725977891125, 1.868502355646342, 1.712863182183355, 0.5106721131596714, 0.3068523859838024, 0.04351602568931412, 0.10318007902242243, 0.2332713530631736, 0.9388704830780625, 12.178555503487587, 30.602294392883778, 35.06092004477978, 32.01779633760452, 29.632079154253006, 22.962623834609985, 0.37735424819402397, 0.04868200434430037, 0.070127300277818, 0.042018779859063216, 0.06313315214356408, 0.08224965917179361, 0.040669447771506384, 0.014446870245592436, 0.0341060235950863, 0.06993329545366578, 0.03489352762699127, 0.026980943912349176, 0.048383746325271204, 0.06476178037701175, 0.013505744427675381, 0.036109124703216366, 0.023684375883021858, 0.059021264387411065, 0.010793686342367437, 0.04730652268335689, 0.06521216011606157, 0.01660740777879255, 0.06350586612825282, 0.030789013108005747, 0.005106041880935663, 0.010595989333523903, 0.01960688481631223, 0.03926865516405087, 0.022915807749086525, 0.07370101593551226, 0.07505075991502963, 0.04142892830714118, 0.046234798355726525, 0.03412107063923031, 0.05188211172935553, 0.04089824818947818, 2.3499998124316335, 36.488419845700264, 48.6430936306715, 26.825876533985138, 45.25174140930176, 42.484980672597885, 40.21472029387951, 43.01510542631149, 0.4641426005400717, 0.010971778592647752, 1.8723757728002965, 1.0313429147936404, 0.45717718836385757, 0.080078209284693, 4.034734172746539, 28.637706711888313, 51.01305305957794, 52.7976007014513, 52.821022644639015, 54.31997761130333, 52.030288875103, 50.44206149876118, 45.434621796011925, 44.98432315886021, 43.0622760951519, 44.324496164917946, 48.27018924057484, 49.447320476174355, 52.74848833680153, 50.59976063668728, 50.446613654494286, 51.08779884874821, 51.380861923098564, 50.6522586196661, 53.124044984579086, 52.39422954618931, 48.98405313491821, 50.74751950800419, 48.05008985102177, 50.17417587339878, 49.69805762171745, 53.17767530679703, 50.072888508439064, 40.39061285555363, 39.60654012858868, 38.76834310591221, 39.56574931740761, 39.9344777315855, 39.85817402601242, 40.230109468102455, 39.972563087940216, 39.58934985101223, 36.707884669303894, 38.972308561205864, 38.154182061553, 40.47905310988426, 49.83448930084705, 51.1914686858654, 51.937125474214554, 49.27522391080856, 44.50112208724022, 44.00298401713371, 48.72469425201416, 53.94662484526634, 51.69790931046009, 49.90543909370899, 49.93569687008858, 50.073713064193726, 52.192623764276505, 50.613614693284035, 49.95054267346859, 54.89611029624939, 51.05813004076481, 51.424973756074905, 50.86189717054367, 50.723360404372215, 50.13242371380329, 49.01003614068031, 42.672683000564575, 39.10948500037193, 37.48889856040478, 36.294656842947006, 38.03853526711464, 37.223262414336205, 38.49851958453655, 38.5075668990612, 36.971803307533264, 37.543691620230675, 38.331047371029854, 38.10389555990696, 38.5774527490139, 37.966954708099365, 37.12767854332924, 38.329143673181534, 36.555839627981186, 36.96695476770401, 37.02442668378353, 36.85044161975384, 36.727290228009224, 42.4206805229187, 48.03087808191776, 48.940382078289986, 48.89351159334183, 48.9798391610384, 47.81814269721508, 48.4308560192585, 48.95172446966171, 49.45101007819176, 47.21997879445553, 46.7845905572176, 47.09938086569309, 45.02642869949341, 40.04041224718094, 37.586104944348335, 38.342762142419815, 37.96594016253948, 42.07684837281704, 45.107033774256706, 47.53263741731644, 49.71255764365196, 48.53365570306778, 48.2355123013258, 45.92556685209274, 41.65600575506687, 12.907289899885654, 0.6211782584432513, 4.420719835907221, 3.0028598802164197, 0.21236062981188297, 0.15891826391452923, 0.1826673754840158, 0.14012810890562832, 0.07198437640909106, 1.438299771398306, 13.080022931098938, 37.257768362760544, 39.12371523678303, 33.4578924626112, 34.4379510730505, 31.202882565557957, 1.1293914285488427, 0.05970002894173376, 0.03635063811088912, 0.04317972146964166, 0.04714408882136922, 0.05530569462280255, 0.05441309876914602, 0.012586014727276051, 0.08428142944467254, 0.04943582600390073, 0.07432203768985346, 0.0640914577525109, 0.028379333816701546, 0.006783361031921231, 0.027515503606991842, 0.04391966125695035, 0.07637971633812413, 0.10446986489114352, 0.1180224611016456, 0.14622071088524535, 0.19752350955968723, 0.08627399947727099, 0.14752246759599075, 0.12643508351175115, 0.1389008341357112, 0.07596846262458712, 0.12695414159679785, 0.13914382812799886, 0.11427897174144164, 0.1199822653143201, 0.22909231949597597, 0.10472709327586927, 0.15466568351257592, 0.10815954112331383, 0.14043504634173587, 0.17086598061723635, 2.9979761922731996, 42.99145549535751, 55.64059294760227, 34.037391766905785, 48.53266015648842, 43.130246847867966, 44.0102606266737, 48.38389813899994, 0.5488234315998852, 0.15219498483929783, 9.431958384811878, 10.518214646726847, 1.4185274136252701, 1.85048301005736, 6.361695108935237, 29.686562530696392, 52.18037322163582, 52.80761696398258, 55.62186375260353, 55.552775859832764, 54.283640161156654, 51.75640717148781, 48.1546526402235, 46.2698245793581, 45.553961992263794, 45.898067727684975, 50.73466099798679, 53.531117141246796, 56.51998735964298, 51.884844079613686, 54.03945006430149, 52.692300751805305, 53.21118950843811, 51.6104494035244, 53.33599001169205, 53.45512501895428, 50.57415761053562, 52.8376467525959, 49.62687984108925, 51.59855604171753, 51.79303340613842, 54.68986876308918, 52.446081563830376, 42.73215360939503, 41.54483512043953, 40.267556458711624, 40.35931393504143, 43.44528794288635, 40.34724198281765, 41.32264204323292, 43.16596493124962, 42.817561626434326, 39.1830338537693, 40.862220749258995, 39.50893096625805, 42.64538146555424, 51.910002529621124, 54.37466807663441, 54.05005529522896, 51.038447096943855, 45.143990591168404, 43.17261837422848, 49.81818437576294, 55.603335946798325, 54.104977548122406, 51.194550320506096, 52.57582560181618, 51.18442006409168, 54.27966557443142, 50.96565820276737, 51.90353907644749, 56.084086149930954, 52.0006238669157, 53.43119390308857, 52.50521399080753, 53.576452508568764, 51.61373622715473, 50.170072093605995, 43.67941617965698, 40.83663672208786, 38.91724951565266, 38.531433418393135, 41.32522210478783, 37.219557613134384, 39.762255772948265, 41.601315289735794, 40.188193917274475, 40.1131821423769, 41.502820774912834, 40.1191022247076, 41.689554154872894, 38.83337281644344, 38.41952562332153, 39.68117192387581, 38.23173210024834, 38.853534534573555, 39.49142150580883, 38.71280908584595, 38.544124737381935, 45.22585719823837, 50.917579382658005, 50.76953552663326, 51.102580055594444, 50.68132326006889, 49.72247891128063, 48.46606492996216, 50.958894565701485, 51.95061095058918, 49.64753173291683, 49.96012955904007, 51.21692731976509, 47.21597000956535, 42.27041758596897, 39.243910387158394, 40.42885400354862, 39.4266539812088, 43.11485007405281, 47.6099556684494, 50.368938222527504, 51.34577080607414, 49.94802340865135, 48.104901909828186, 45.25515742599964, 44.36517298221588, 14.76302957162261, 0.526771730510518, 4.216389125213027, 7.0984328258782625, 1.2822914239950478, 1.0345549299381673, 0.4513062065234408, 0.47695058514364064, 0.4967378155561164, 2.773986286483705, 17.587798945605755, 40.44170491397381, 48.081491366028786, 39.11196626722813, 42.422261238098145, 38.35537366569042, 1.600986854173243, 0.195811924058944, 0.12106145935831591, 0.1322742272168398, 0.19101103011053056, 0.17153153865365312, 0.13806498289341107, 0.1430493060615845, 0.15153859974816442, 0.12104432316846214, 0.14667054143501446, 0.1688831252977252, 0.18042110226815566, 0.13860066508641466, 0.0655594035924878, 0.1408028695732355], [0.11117787056718953, 0.029174541341490112, 0.10781219374621287, 0.07624894249602221, 0.033097611885750666, 0.038241500515141524, 0.028319321900198702, 0.05089168967970181, 0.04593151970766485, 0.06245616503292695, 0.05467159251566045, 0.03187425565556623, 0.012686250120168552, 0.020991071869502775, 0.04710385328507982, 0.09449223856790923, 0.02985687562613748, 0.007895164580986602, 0.05605152706266381, 0.04103508166735992, 0.3090416919440031, 15.69744598120451, 44.35267545282841, 31.52953963726759, 25.54486647248268, 36.22846819460392, 31.55662078410387, 39.415045604109764, 1.6244989237748086, 0.11702315183356404, 0.03610391853726469, 0.9592486114706844, 0.3234514390351251, 0.48703435342758894, 0.8042987447697669, 7.376376986503601, 36.26094505190849, 53.87998782098293, 50.868117436766624, 54.571828097105026, 51.491842567920685, 47.71354950964451, 44.136569648981094, 41.039032861590385, 39.525049701333046, 44.06040273606777, 47.346436008811, 48.84374186396599, 49.59200531244278, 52.05947890877724, 50.92050142586231, 51.01765461266041, 49.674666076898575, 51.319335624575615, 50.5709657818079, 50.6219058483839, 51.12339533865452, 51.97032429277897, 50.29462940990925, 49.467421397566795, 50.29958434402943, 52.21627749502659, 50.64652092754841, 42.45173625648022, 36.24135710299015, 38.98310378193855, 37.61822082102299, 39.02853034436703, 38.80455896258354, 39.22473281621933, 37.93306052684784, 37.734456583857536, 35.67674160003662, 36.801287457346916, 36.91834777593613, 36.67773708701134, 42.53079481422901, 51.9371634721756, 48.34543280303478, 56.22436702251434, 46.37557290494442, 18.746803253889084, 46.54505901038647, 51.78261436522007, 52.704802080988884, 50.675433576107025, 50.709373354911804, 49.93772596120834, 51.22840270400047, 48.15752148628235, 51.33100099861622, 48.81118901073933, 47.86021023988724, 46.096413284540176, 42.408901154994965, 42.5679986178875, 38.75906020402908, 37.03744098544121, 35.53818963468075, 36.3456767052412, 35.5378058552742, 35.37534557282925, 36.13476142287254, 36.763316094875336, 37.53874808549881, 36.23916082084179, 35.27701444923878, 36.294466853141785, 37.056261375546455, 35.800063982605934, 37.15801611542702, 35.18798142671585, 36.09821118414402, 35.09311191737652, 35.78629732131958, 35.37106700241566, 35.82427628338337, 34.93319749832153, 36.14902585744858, 33.192434906959534, 38.049980252981186, 46.1642624437809, 46.74021653831005, 47.76776880025864, 45.9342797845602, 45.04941746592522, 48.981929048895836, 46.606585308909416, 48.2822497934103, 46.068936958909035, 46.572995111346245, 44.37448628246784, 40.72689101099968, 38.413369953632355, 36.06633089482784, 35.3969170153141, 37.59197562932968, 40.583133324980736, 45.10285399854183, 46.09230190515518, 47.78501607477665, 47.88553588092327, 46.912195309996605, 27.74803575128317, 2.3979197535663843, 0.0968160068441648, 7.91958823800087, 1.2429724400863051, 0.08192832407075912, 0.1046698959544301, 0.033595166241866536, 0.1429697626736015, 0.5499995278660208, 1.9789866521023214, 16.975359208881855, 26.966223903000355, 33.73340807855129, 44.35957208275795, 31.80727243423462, 12.168171610683203, 0.014328975448734127, 0.02049875522061484, 0.09174658902338706, 0.017818195738072973, 0.06542279646964744, 0.02290704669576371, 0.025524900265736505, 0.015704742836533114, 0.061350598771241494, 0.06140815974504221, 0.03321857453556731, 0.08370587907847948, 0.07330755892326124, 0.055715786875225604, 0.0713246590748895, 0.04132222973566968, 0.06150709916255437, 0.019403770129429176, 0.1026705204276368, 0.016797627649793867, 0.0317365130467806, 0.10693160584196448, 0.025614815167500637, 0.02674815259524621, 0.01729718394926749, 0.053021683197584935, 0.05025047037634067, 0.032645246901665814, 0.04359883452707436, 0.019413156442169566, 0.08074446493992582, 0.06610904558328912, 0.03072546300245449, 0.05924726319790352, 0.06161249526485335, 0.039436002043657936, 0.3438975184690207, 22.417320795357227, 49.82051745057106, 34.08699810504913, 30.71878094226122, 38.712489902973175, 36.608387008309364, 43.16454000771046, 1.5941681200638413, 0.23047461407259107, 0.3214009740622714, 0.5900391074828804, 0.39912752516102046, 0.3986271098256111, 1.4413920929655433, 10.974488463252783, 42.29193963110447, 54.93705689907074, 52.78077520430088, 56.51432566344738, 53.21986064314842, 50.341085717082024, 46.35323770344257, 43.237549290061, 42.124763801693916, 44.736542254686356, 49.80851009488106, 53.06559272110462, 52.4165153503418, 52.643841952085495, 52.937911972403526, 53.49772073328495, 52.72704228758812, 52.477148696780205, 50.47402158379555, 52.10876226425171, 54.11451883614063, 52.575867399573326, 50.58049947023392, 49.074180498719215, 50.74164122343063, 53.57832960784435, 51.42525874078274, 41.935697346925735, 39.64620240032673, 41.45366281270981, 38.692362383008, 39.37306925654411, 39.547730684280396, 41.00024834275246, 40.76987810432911, 38.33731323480606, 36.74850448966026, 39.02652405202389, 38.74122016131878, 37.99733407795429, 45.966825038194656, 53.71096149086952, 50.07585994899273, 58.14796440303326, 47.46484525501728, 22.025035545229912, 47.14836023747921, 54.48277227580547, 53.58803428709507, 50.53571127355099, 51.97758570313454, 51.27607874572277, 53.457002118229866, 49.723219871520996, 52.22209498286247, 50.222809463739395, 50.65833069384098, 47.92403541505337, 46.024722531437874, 45.065084025263786, 41.942814365029335, 40.14067366719246, 37.04357385635376, 37.654482275247574, 37.62056149542332, 35.52460916340351, 37.89939433336258, 38.25637377798557, 38.272564709186554, 37.09101811051369, 36.30319118499756, 37.57613807916641, 38.65730166435242, 37.45626211166382, 39.00711089372635, 38.01905371248722, 36.7932964861393, 37.27096505463123, 37.750259935855865, 35.837666764855385, 36.881147772073746, 36.97508633136749, 36.97882533073425, 35.05027301609516, 40.26418223977089, 46.924799233675, 48.652513325214386, 47.60820776224136, 47.24596939980984, 46.935803443193436, 50.719059035182, 48.374565839767456, 51.60120829939842, 47.71967098116875, 48.48790995776653, 45.13465829193592, 42.78149016201496, 40.303882509469986, 37.97439470887184, 37.288922891020775, 39.83586922287941, 42.437430024147034, 47.43292696774006, 48.656799495220184, 49.81975369155407, 49.76333051919937, 46.65795095264912, 29.55767534673214, 3.0447770934551954, 1.084554665721953, 8.082625139504671, 5.465081445872784, 0.3385885205352679, 0.34328129841014743, 0.10568826357484795, 0.24500470783095807, 0.7087152299936861, 3.5569138498976827, 19.58949163556099, 33.67900639772415, 39.44996193051338, 45.10952644050121, 37.13526673614979, 17.664450332522392, 0.05230758870311547, 0.04348554568423424, 0.006990090441831853, 0.018165261099056806, 0.03998119485913776, 0.03629526647273451, 0.07653770473552868, 0.03501304679957684, 0.02941341826954158, 0.03488898939394858, 0.01895043478725711, 0.05729666903789621, 0.033514925235067494, 0.04364379383332562, 0.06264527910389006, 0.09112207917496562, 0.2799677004804835, 0.10355398786487058, 0.2835520659573376, 0.15840827487409115, 0.10675840341718867, 0.1463357437751256, 0.1303227647440508, 0.14179764431901276, 0.14675557671580464, 0.15486671647522599, 0.13955929724033922, 0.10525341698667035, 0.1284921684418805, 0.08992630115244538, 0.1702307170489803, 0.20248754241038114, 0.10286880744388327, 0.13485004368703812, 0.1604141664574854, 0.0885567937802989, 0.4604288638802245, 25.542520098388195, 57.99969255924225, 41.60970523953438, 35.05183853209019, 45.61228506267071, 40.40290519595146, 46.58820189535618, 2.776161669753492, 0.28086023696232587, 0.38936697703320533, 6.106279939413071, 0.9048239537514746, 3.2939164247363806, 2.96083009801805, 11.957404520362616, 43.11875246465206, 56.67159162461758, 53.66076998412609, 58.817986249923706, 57.00367480516434, 52.96221166849136, 49.138537645339966, 45.02549774944782, 43.93285118043423, 47.99847722053528, 51.70069456100464, 54.992636516690254, 54.195454493165016, 56.41876459121704, 54.65776428580284, 54.093399569392204, 54.1668838262558, 55.759746953845024, 54.76590268313885, 54.5910132676363, 55.41428089141846, 56.106432750821114, 52.072717398405075, 50.565551072359085, 52.35998198390007, 56.25783562660217, 54.30732049047947, 44.99574914574623, 41.1767602711916, 43.2322333753109, 39.742515832185745, 41.70126512646675, 41.37421287596226, 41.918659061193466, 42.398603707551956, 39.85826902091503, 39.23935063183308, 40.380672588944435, 40.272598788142204, 40.09281903505325, 47.87574000656605, 56.19567856192589, 52.26217903196812, 59.178366512060165, 50.07724307477474, 20.299572832882404, 48.29399116337299, 54.69570145010948, 55.62441721558571, 51.65880560874939, 54.55703929066658, 52.38913021981716, 55.3581503033638, 52.13512144982815, 54.15628619492054, 51.77119977772236, 53.851493149995804, 50.32893016934395, 46.589554622769356, 47.04051062464714, 43.64855423569679, 41.75008490681648, 39.820506647229195, 41.18634335696697, 38.91903541982174, 39.07825827598572, 39.66688089072704, 41.34512543678284, 40.07376305758953, 39.04451608657837, 38.59950676560402, 39.76029507815838, 41.68230414390564, 38.46499778330326, 39.68996085226536, 39.27791476249695, 39.14842531085014, 37.37266659736633, 39.64531324803829, 38.362502083182335, 38.247748240828514, 39.19241555035114, 39.45026971399784, 36.17677576839924, 40.973543375730515, 48.911302238702774, 51.18607297539711, 49.64011073112488, 49.159649312496185, 47.57241748273373, 51.47108808159828, 49.4991534948349, 52.82734550535679, 50.061466321349144, 51.25641480088234, 48.91369231045246, 44.0460205078125, 41.942772567272186, 38.68603192269802, 38.26166309416294, 41.644800156354904, 44.06818091869354, 51.265036538243294, 50.27097947895527, 52.93903291225433, 49.96773675084114, 46.913335248827934, 29.76276744157076, 3.665403015911579, 0.509448756929487, 16.52003724128008, 5.788439344614744, 0.2804122172528878, 0.5822935199830681, 0.2603222499601543, 0.4144652537070215, 1.8900418560951948, 6.778042567893863, 24.871468506753445, 38.24937455356121, 43.71879726648331, 49.01781812310219, 47.87193261086941, 21.038625575602055, 0.16257917450275272, 0.1978527707979083, 0.2409861859632656, 0.12248771876329556, 0.2013333246577531, 0.10712595947552472, 0.08625767964986153, 0.12267235026229173, 0.16338912479113787, 0.09210244883433916, 0.2570522582391277, 0.22021204757038504, 0.182749264058657, 0.11644374972092919, 0.15113485656911507, 0.16744968190323561], [0.0517320865765214, 0.040984033039421774, 0.0805094267707318, 0.07743677953840233, 0.04092639785085339, 0.03818366123596206, 0.04322168621001765, 0.05427955671621021, 0.03301254320831504, 0.02853511989087565, 0.05683414405211806, 0.07033147994661704, 0.011615008188528009, 0.06432689668145031, 0.07441559282597154, 0.030851270021230448, 0.021089280271553434, 0.009370848238177132, 0.00967894064160646, 0.05341246105672326, 0.08357826678548008, 5.011632777750492, 36.15947529673576, 42.46058978140354, 30.75461871922016, 35.757103487849236, 33.6952543258667, 36.38365186750889, 4.814163548871875, 0.8243404724635184, 0.567714711651206, 0.030090514846961014, 0.29826452024281025, 0.07753176701953635, 0.03584029655030463, 0.3572890389477834, 12.749002743512392, 43.69646206498146, 55.04374377429485, 52.97632411122322, 52.04391874372959, 48.1552492082119, 47.693061009049416, 42.28196136653423, 42.13606059551239, 44.25643801689148, 44.69721056520939, 45.9318783134222, 47.70518995821476, 50.289670675992966, 49.703050553798676, 47.44202367961407, 46.68228104710579, 46.55187964439392, 48.64780157804489, 48.13632622361183, 47.26164735853672, 48.26401837170124, 48.470119312405586, 51.84351369738579, 47.78983421623707, 50.05889005959034, 50.36889262497425, 45.35494767129421, 37.48409181833267, 38.07844452559948, 36.58651918172836, 38.9154864102602, 37.231675162911415, 39.277439787983894, 39.193240106105804, 37.06357218325138, 37.8230070322752, 37.24862985312939, 37.56688937544823, 36.02681681513786, 39.05932009220123, 45.3912129253149, 49.76015008985996, 49.55190606415272, 58.77863176167011, 39.949289336800575, 47.253625988960266, 44.7728531062603, 50.023445561528206, 48.302533105015755, 50.04126280546188, 48.07669222354889, 49.26167003810406, 44.867631420493126, 50.310877338051796, 47.80436083674431, 48.709529265761375, 43.19336146116257, 41.72620318830013, 38.078440725803375, 37.073155269026756, 37.363794073462486, 36.92111782729626, 36.75026759505272, 36.13234855234623, 34.526056945323944, 36.822646111249924, 36.63133017718792, 38.08622270822525, 34.325929284095764, 35.286650732159615, 35.215837731957436, 37.302111983299255, 34.643409848213196, 35.64997583627701, 33.57350505888462, 34.72938023507595, 35.953431352972984, 35.08316785097122, 34.738533943891525, 35.63756950199604, 36.82174935936928, 35.647323578596115, 33.10046464204788, 34.61296208202839, 37.0450671762228, 43.757752776145935, 45.476305559277534, 45.32043032348156, 47.201306596398354, 47.40234240889549, 46.573337092995644, 47.835538163781166, 46.71481490135193, 48.42953749001026, 45.7476831972599, 44.16796736419201, 41.01956270635128, 37.21000112593174, 35.65064840018749, 37.63465493917465, 37.22949028015137, 41.47410951554775, 42.903980389237404, 46.9227397441864, 47.32083298265934, 46.54163159430027, 13.089194688946009, 0.13123158394591883, 1.5674290736205876, 4.194183591753244, 3.3572402643039823, 0.2071246740524657, 0.2059636582271196, 0.012690663115790812, 0.09018396740430035, 0.32692887587472796, 1.393990230280906, 22.26878296583891, 27.38352321088314, 30.084026902914047, 44.82975125312805, 24.277121499180794, 3.185827899724245, 0.09338545147329569, 0.1282524547423236, 0.05543647217564285, 0.005662812664013472, 0.10448260756675154, 0.048952450379147194, 0.05730553399189375, 0.02449822615744779, 0.05409743738709949, 0.006940280736671411, 0.04577947962388862, 0.023563383547298145, 0.0875998314586468, 0.0420564290106995, 0.03061698142118985, 0.056005758815445006, 0.028011198883177713, 0.05469920040923171, 0.024178590574592818, 0.03302438046375755, 0.04394784431497101, 0.09271747403545305, 0.0027345087482899544, 0.015289534403564176, 0.020175384779577143, 0.10540674469666556, 0.021684152452507988, 0.006351253432512749, 0.018619828406372108, 0.06725878818542697, 0.05444179019832518, 0.040798125046421774, 0.023219605900521856, 0.06321535242022946, 0.05219833714363631, 0.034306833913433366, 0.05426175630418584, 8.079295568168163, 45.09309232234955, 43.799995109438896, 29.180321395397186, 45.106045827269554, 38.70663821697235, 41.5774791687727, 5.5748295318335295, 2.540245153941214, 1.044338217470795, 0.26092285523191094, 0.4091308149509132, 0.29283223673701286, 0.5850196362007409, 2.0473745511844754, 17.689734175801277, 46.96804851293564, 56.759606301784515, 53.93353454768658, 54.259579852223396, 50.82243248820305, 49.12876836955547, 44.03518728911877, 43.85552912950516, 46.574803814291954, 46.52464650571346, 49.56085838377476, 51.11140698194504, 50.913240015506744, 51.726065799593925, 49.85717408359051, 49.533990025520325, 49.139472395181656, 49.50922295451164, 50.0005441904068, 50.02761773765087, 50.184933096170425, 51.58931493759155, 52.97044202685356, 49.30044315755367, 51.844026669859886, 53.22244830429554, 45.928929671645164, 40.50109192728996, 39.8365493863821, 39.104803651571274, 39.78800319135189, 39.44927416741848, 39.687266796827316, 41.708849519491196, 39.06843200325966, 38.60707975924015, 37.92232230305672, 39.7411897033453, 38.02060402929783, 40.93798868358135, 47.24643677473068, 52.435499131679535, 50.08465267717838, 58.99469196796417, 42.938334345817566, 47.49690793454647, 45.780939012765884, 49.969002082943916, 49.868474677205086, 52.71112114191055, 51.68207176029682, 51.08553037047386, 46.0228606313467, 51.479117050766945, 52.672302424907684, 50.89335948228836, 44.007718563079834, 44.8209585249424, 39.41080503165722, 39.52219985425472, 40.11420428752899, 38.12503382563591, 37.43159383535385, 37.50217504799366, 36.29051886498928, 38.87606352567673, 36.86582699418068, 39.159874096512794, 35.94437263906002, 37.06873990595341, 37.11629055440426, 38.547761142253876, 37.18456149101257, 38.135449066758156, 36.09542973339558, 36.616191789507866, 37.96934098005295, 36.84563107788563, 36.11666299402714, 36.678086668252945, 37.78935983777046, 37.58406065404415, 35.160672292113304, 36.04584239423275, 38.58879134058952, 46.25093199312687, 46.95374608039856, 47.73656487464905, 48.98356296122074, 48.12268115580082, 48.246930688619614, 47.15939864516258, 48.62197816371918, 49.263117760419846, 47.57422998547554, 47.74804785847664, 42.994510531425476, 37.722080647945404, 37.11410567164421, 39.098989963531494, 39.0187306702137, 44.59406889975071, 43.928329423069954, 49.496790021657944, 48.96557852625847, 48.21650952100754, 15.356958601623774, 0.9386147686745971, 4.0043415036052465, 9.204488340765238, 6.290308814495802, 0.7103477767668664, 0.1842916547320783, 0.08508703074767254, 0.12317985310801305, 0.34622842620592564, 2.1355521446093917, 26.364459693431854, 34.17239472270012, 33.38460959494114, 46.73120342195034, 33.28322723507881, 5.654197772964835, 0.08000297777471133, 0.07367115933448076, 0.04305600916268304, 0.04824741750780959, 0.07590791821712628, 0.055555690778419375, 0.030837521735520568, 0.02631123355968157, 0.01875362650025636, 0.042544576645013876, 0.036995590417063795, 0.030621903715655208, 0.06428468332160264, 0.056930174250737764, 0.005688086503141676, 0.002780169616016792, 0.20287765975808725, 0.20476307108765468, 0.11046920859371312, 0.16137224942212924, 0.10678718390408903, 0.11126872428576462, 0.1531870581675321, 0.1467183357453905, 0.16116863378556445, 0.19606637681135908, 0.19073557457886636, 0.13537928403820843, 0.06997824733844027, 0.17738254187861457, 0.18843815254513174, 0.1525751277222298, 0.11960204821662046, 0.1356476149521768, 0.14564134587999433, 0.11180396119016223, 0.19106965977698565, 9.109881017357111, 51.89100354909897, 53.3969197422266, 39.74075272679329, 45.84203593432903, 43.237290903925896, 43.51490020751953, 7.247899230569601, 4.612502194941044, 2.835969985462725, 1.0114833991974592, 1.4267880516126752, 1.142070754431188, 0.8481340238358825, 2.9433111380785704, 19.18147522956133, 49.4336374104023, 57.94152148067951, 55.504446253180504, 56.2542562186718, 53.02874989807606, 52.86809451878071, 45.933998599648476, 46.053399592638016, 48.08335326611996, 47.45958253741264, 49.59547072649002, 52.57025130093098, 53.49190704524517, 52.93278604745865, 52.22936399281025, 50.064924135804176, 49.967482164502144, 52.06058844923973, 52.94014245271683, 50.63143573701382, 53.14888805150986, 52.10726894438267, 53.98703567683697, 50.412217900156975, 53.92756126821041, 55.95553904771805, 48.36316265165806, 42.04376734793186, 40.276542976498604, 40.24559363722801, 41.697256341576576, 40.17714411020279, 40.078277215361595, 42.73591160774231, 40.45094981789589, 40.88336281478405, 40.23988634347916, 41.428603157401085, 38.53335611522198, 41.56662695109844, 47.216536179184914, 56.02457374334335, 51.59510962665081, 63.04903261363506, 38.88884983956814, 47.25792355835438, 47.663631588220596, 51.363318264484406, 51.442536413669586, 52.89852328598499, 51.33243732154369, 51.61085218191147, 46.84537589550018, 52.10084728896618, 52.26092129945755, 52.90343262255192, 46.042577773332596, 45.173712596297264, 41.70796036720276, 40.98717704415321, 43.35376225411892, 39.94805820286274, 39.98108223080635, 39.198943600058556, 37.8814022988081, 41.673614010214806, 40.33646956086159, 41.47220201790333, 38.72681513428688, 37.76165932416916, 38.90148036181927, 40.389024540781975, 37.79484674334526, 39.41137880086899, 37.026280984282494, 38.13478410243988, 39.2804454267025, 39.0243049710989, 38.226298391819, 38.27415682375431, 40.56407734751701, 38.82120966911316, 36.181384921073914, 38.83297763764858, 39.602584540843964, 48.80586549639702, 50.84956683218479, 49.142842814326286, 50.1727357506752, 49.19964976608753, 48.559710904955864, 49.19105842709541, 47.823017835617065, 50.54693967103958, 49.684682339429855, 47.99033805727959, 45.0616680085659, 41.05591915547848, 39.54420067369938, 40.107596442103386, 41.923184618353844, 45.726126953959465, 47.10061199963093, 52.1568600833416, 50.06574869155884, 49.53223451972008, 17.025807201862335, 0.5440648994408548, 3.006246448494494, 11.188384685665369, 7.982894740998745, 1.4034438855014741, 0.346077146823518, 0.18196297343820333, 0.35997433704324067, 1.6179642244242132, 4.792372193187475, 33.54816421866417, 40.86303010582924, 39.8904874920845, 51.12143084406853, 40.9995149821043, 7.152453577145934, 0.24485636735334992, 0.23733125708531588, 0.1881743042031303, 0.11691631967551075, 0.18561656645033509, 0.17183359275804833, 0.14733615884324536, 0.08221313066314906, 0.12018987370538525, 0.06537647161167115, 0.12128028902225196, 0.14116837730398402, 0.16136608959641308, 0.14948954485589638, 0.06806193297961727, 0.18561840697657317], [0.026629989697539713, 0.032670127402525395, 0.07616208895342425, 0.07994888263056055, 0.039799828809918836, 0.030543165557901375, 0.0534778739529429, 0.07915557871456258, 0.06268930330406874, 0.037767565008834936, 0.06545195545186289, 0.07156860301620327, 0.01931225589942187, 0.03554528913809918, 0.0764997216174379, 0.06269093602895737, 0.028282867606321815, 0.03597215392801445, 0.020924848176946398, 0.01893916527478723, 0.04364468069979921, 0.5886083655059338, 18.369266912341118, 50.33143423497677, 28.642988428473473, 29.940768890082836, 35.120709836483, 37.813328951597214, 9.327797424048185, 0.1690141440485604, 0.4392287030350417, 0.19983950012829155, 0.13452415179926902, 0.0433927326957928, 0.37623036943841726, 1.7528707603923976, 1.2859532400034368, 21.381006203591824, 53.3820815384388, 54.04799200594425, 53.746516183018684, 48.94914820790291, 46.4944913238287, 42.58895069360733, 42.34776623547077, 44.07849736511707, 44.76399578154087, 44.348959252238274, 42.93048016726971, 39.29884023964405, 41.137200593948364, 38.72141942381859, 40.733240470290184, 39.41482901573181, 41.81507281959057, 43.40463012456894, 47.46772550046444, 45.85790388286114, 49.17606063187122, 49.74438853561878, 51.37104704976082, 50.0591978430748, 50.47521471977234, 46.350828632712364, 37.71758168935776, 37.10152454674244, 39.79779526591301, 36.841470301151276, 38.923678770661354, 38.25342893600464, 39.643284156918526, 37.03487992286682, 37.058438658714294, 36.31913132965565, 37.07685247063637, 37.27855704724789, 37.91940785944462, 40.1208121329546, 48.085914328694344, 48.217957243323326, 53.70547458529472, 51.567048132419586, 50.45338489115238, 50.69692522287369, 48.61185550689697, 48.619257509708405, 48.774562776088715, 48.44760552048683, 45.84325186908245, 45.34330889582634, 48.04303742945194, 50.216102823615074, 50.16164414584637, 44.527701660990715, 40.48479840159416, 38.82576182484627, 38.528636768460274, 36.903672963380814, 37.04160936176777, 37.2586727142334, 35.97429983317852, 35.33202409744263, 37.46297635138035, 37.5604335218668, 36.6169935464859, 37.03274063766003, 35.872704684734344, 37.72811472415924, 34.86236929893494, 35.295466259121895, 35.755104795098305, 37.53473550081253, 34.98052395880222, 34.95738700032234, 35.7811713963747, 34.38054375350475, 35.56552156805992, 35.369178503751755, 35.84732964634895, 36.6966562718153, 36.080344542860985, 35.05987510085106, 36.69802039861679, 38.26328940689564, 43.02743196487427, 44.512342885136604, 46.12397700548172, 48.197400346398354, 46.600083857774734, 45.28095044195652, 45.124208852648735, 46.79244473576546, 45.47671213746071, 43.59757997095585, 41.77730284631252, 38.23707841336727, 37.4519569426775, 38.57896126806736, 39.060178846120834, 44.615169167518616, 46.53193071484566, 48.75613376498222, 37.112144976854324, 3.7373132072389126, 0.3590195195283741, 6.461144797503948, 7.394161932170391, 7.13454513810575, 1.0349569958634675, 0.1306895786547102, 0.08285835385322571, 0.10806916237925179, 0.4580267396522686, 5.742240948602557, 31.416011229157448, 26.543046310544014, 31.0916131362319, 46.79812163114548, 17.604565545916557, 0.1759185962146148, 0.029846435463696253, 0.022172400276758708, 0.03613748587667942, 0.0229688416220597, 0.0727647595340386, 0.01715185288048815, 0.0550211329391459, 0.04275953600881621, 0.031814998874324374, 0.011381882904970553, 0.11450787234934978, 0.04274894927220885, 0.016418683335359674, 0.036987808998674154, 0.022544116072822362, 0.028757582367688883, 0.021198893628024962, 0.03255578842072282, 0.055518716981168836, 0.035357919114176184, 0.031729781767353415, 0.02818804710841505, 0.015429381001013098, 0.020974820690753404, 0.05245674183242954, 0.026992851671820972, 0.04167372200754471, 0.02155733796826098, 0.024069121936918236, 0.00639893873994879, 0.03367375968082342, 0.08151430956786498, 0.05041500822699163, 0.010070742664538557, 0.06313798352493905, 0.06024956332112197, 0.054303776705637574, 1.2404037779197097, 26.3715311139822, 56.50619029998779, 32.146031856536865, 33.528857454657555, 42.39057093858719, 41.10045276582241, 9.366429951041937, 1.2708222144283354, 1.2742411997169256, 0.2525962848449126, 0.21149642852833495, 0.2915418497286737, 0.12911471159895882, 2.0314842788502574, 3.071235786192119, 26.10616285353899, 56.310599595308304, 56.02080814540386, 53.84499169886112, 50.779810175299644, 48.84860560297966, 44.54562149941921, 44.441427290439606, 44.565483033657074, 47.20127999782562, 44.99994032084942, 46.217356994748116, 40.9972009062767, 43.021941259503365, 41.78160421550274, 42.96445794403553, 41.701679304242134, 44.032390639185905, 46.381492987275124, 48.86238746345043, 47.81385652720928, 49.705167040228844, 51.18321932852268, 51.800017431378365, 51.775098368525505, 52.3053827136755, 47.43859626352787, 39.009535163640976, 38.86638164520264, 41.30618892610073, 39.76748809218407, 39.83244940638542, 39.10879343748093, 41.59347631037235, 37.65988178551197, 38.8142104446888, 38.362931460142136, 40.09082794189453, 39.607934653759, 39.46640744805336, 43.03572691977024, 50.23885980248451, 49.016264006495476, 55.03117024898529, 55.778605341911316, 49.93458732962608, 51.81028068065643, 49.06166397035122, 49.108849838376045, 48.54331478476524, 47.96283893287182, 48.56063425540924, 46.80247999727726, 51.09398111701012, 53.82289968430996, 51.02780766785145, 47.491706013679504, 42.97178015112877, 40.25444336235523, 40.71227319538593, 39.034161642193794, 38.91432747244835, 39.8943442851305, 39.144070744514465, 38.148372173309326, 38.73477190732956, 39.55358996987343, 36.255648136138916, 37.725143283605576, 38.71335245668888, 39.14629362523556, 36.771143674850464, 37.635813876986504, 37.38306663930416, 39.068625792860985, 36.80122286081314, 37.31667660176754, 37.129434049129486, 36.10304452478886, 38.618729934096336, 37.95984908938408, 38.42476934194565, 37.670167833566666, 36.95882320404053, 36.05352558195591, 39.13975417613983, 41.14039622247219, 44.67103756964207, 46.2933225184679, 48.643063232302666, 47.9949776083231, 48.00850868225098, 44.97820168733597, 48.46807882189751, 48.311546221375465, 46.858120411634445, 45.284993425011635, 42.26239241659641, 42.251331210136414, 39.15377162396908, 39.76492702960968, 41.87762126326561, 46.241649091243744, 48.277872428298, 48.802156895399094, 40.73284529149532, 5.27841598726809, 1.1658561718650162, 7.3547713458538055, 8.535652980208397, 7.089544627815485, 0.30971476051490754, 0.11993840438663028, 0.043514333592611365, 0.5264745152089745, 1.2895259982906282, 7.067510560154915, 37.61485420167446, 31.945186033844948, 32.93821334838867, 49.3656400591135, 22.928706854581833, 0.43855320021975785, 0.019479667716950644, 0.030698651062266435, 0.053280577703844756, 0.026844334934139624, 0.05115434687468223, 0.07239823506097309, 0.06116321761510335, 0.05983041686704382, 0.029887531891290564, 0.07096442801412195, 0.026988606587110553, 0.08150977504556067, 0.03000004704517778, 0.05636298417812213, 0.03460866537352558, 0.010968417591357138, 0.08315694954944775, 0.1797668990911916, 0.11811202348326333, 0.25616957747843117, 0.15041792707052082, 0.23925392422825098, 0.17261857719859108, 0.23023444024147466, 0.16178964811842889, 0.11318000688333996, 0.16149120085174218, 0.23914134042570367, 0.07106829158146866, 0.15079345379490405, 0.1429816518793814, 0.15029495320050046, 0.11705237760907039, 0.10575214022537693, 0.2340704679954797, 0.1484362146584317, 0.20341942756203935, 1.412781528197229, 29.258635193109512, 65.08011102676392, 37.1074104309082, 39.667561054229736, 45.345182195305824, 49.2032253742218, 10.905998088419437, 2.415940286591649, 3.95017612259835, 0.38514130690600723, 0.5597086006309837, 0.8993406104855239, 1.909416897688061, 2.495444845408201, 4.322306541725993, 26.322637237608433, 58.8907865434885, 58.51164668798447, 56.82842820882797, 52.54630498588085, 51.66690297424793, 46.68353118002415, 48.015599101781845, 46.32992595434189, 48.30755263566971, 47.438334077596664, 48.34863603115082, 43.03383082151413, 44.24465864896774, 42.79355451464653, 45.76684556901455, 42.03521400690079, 46.382727921009064, 47.164665162563324, 51.292820647358894, 49.66382905840874, 51.700717359781265, 52.404097616672516, 54.52291712164879, 53.681421875953674, 54.26385082304478, 50.1301134377718, 41.62762887775898, 40.27759552001953, 43.400055170059204, 40.49759991466999, 42.293812930583954, 40.183615162968636, 43.16772423684597, 40.523518323898315, 40.15105850994587, 39.87446755170822, 42.913928255438805, 42.116248458623886, 41.05584695935249, 44.73485514521599, 51.722155809402466, 52.462348490953445, 56.86893403530121, 55.791828632354736, 51.39667667448521, 54.11558657884598, 51.38722278177738, 50.89763045310974, 49.72526416182518, 49.5446864515543, 48.05961214005947, 49.13441866636276, 52.04721316695213, 55.54842509329319, 53.78584027290344, 49.7107907384634, 47.019881531596184, 43.27806271612644, 42.99891449511051, 40.42945057153702, 40.746934935450554, 42.190405279397964, 40.81886127591133, 39.96209464967251, 41.16974204778671, 41.85775212943554, 40.06112113595009, 40.57784400880337, 40.93899942934513, 41.8952789157629, 37.82959207892418, 39.91909235715866, 38.545762449502945, 41.639309450984, 38.91936980187893, 38.75424966216087, 39.37205471098423, 37.70214691758156, 39.01928164064884, 38.35053272545338, 40.57220511138439, 41.03204503655434, 39.164737835526466, 39.14274841547012, 41.795804053545, 41.55111238360405, 46.0582709312439, 48.714115619659424, 50.67727267742157, 51.59993536770344, 49.74552847445011, 45.76658718287945, 48.47787469625473, 50.39694271981716, 49.156905859708786, 48.99019740521908, 45.400123447179794, 42.530764415860176, 40.52254557609558, 42.34314188361168, 43.17856885492802, 49.39279340207577, 51.16197466850281, 51.069438233971596, 41.11897677183151, 5.396345984190702, 0.7978506095241755, 12.07361463457346, 14.310566000640392, 17.173851057887077, 4.101807698607445, 0.4243621788918972, 0.3182483901036903, 0.7773580122739077, 3.444381938315928, 12.156687676906586, 43.29733148217201, 38.5138213634491, 41.09010212123394, 55.34274213016033, 28.109303265810013, 0.8362518833018839, 0.2508489426691085, 0.11632974841631949, 0.1269169748411514, 0.10626776958815753, 0.17817433923482895, 0.17227396834641695, 0.13256232894491404, 0.1872449868824333, 0.11100244912086055, 0.15156712790485471, 0.18911539198597893, 0.199515211279504, 0.12305123891565017, 0.13930545304901898, 0.15645966224838048, 0.10585439333226532], [0.07611137800267898, 0.0237652811119915, 0.035328210942680016, 0.053298626735340804, 0.026516162797634024, 0.040114503135555424, 0.010895052582782228, 0.056292513545486145, 0.10832611616933718, 0.07124312673113309, 0.0206706848621252, 0.023278382141143084, 0.0696451566182077, 0.028179376968182623, 0.06783626071410254, 0.00327816044773499, 0.059532633822527714, 0.03742051820154302, 0.08498725641402416, 0.019357410019438248, 0.0272719066197169, 0.05462060325953644, 4.1604832001030445, 34.68013107776642, 35.21997191011906, 32.282927110791206, 35.303586423397064, 42.41345711052418, 14.753561429679394, 0.47330649162176996, 1.6594850714318454, 0.06963312640436925, 0.07924139325041324, 0.13894355215597898, 0.41124278912320733, 2.2807577904313803, 0.09779124084161595, 3.9134534681215882, 39.25844840705395, 55.45939587056637, 51.73664443194866, 52.57268697023392, 49.54402908682823, 46.2687074393034, 43.64414647221565, 42.879730090498924, 41.32349319756031, 41.7019908875227, 40.61638914048672, 40.386683866381645, 44.492226764559746, 44.6155871450901, 44.64201092720032, 40.80483242869377, 39.60656672716141, 38.99639166891575, 42.42546446621418, 43.51154498755932, 47.18958042562008, 50.33718332648277, 51.57926827669144, 48.175122141838074, 52.68667705357075, 46.023438200354576, 37.72018454968929, 38.897087797522545, 39.040328711271286, 37.91894428431988, 39.06313508749008, 36.52854949235916, 36.00580394268036, 37.046347707509995, 37.833293080329895, 37.21113346517086, 36.62238925695419, 35.553468614816666, 37.655417025089264, 36.3822915405035, 43.08207303285599, 49.491139724850655, 48.421934098005295, 48.788378834724426, 48.89808654785156, 48.9556610584259, 50.75681000947952, 50.9014530479908, 50.530889332294464, 51.69770032167435, 47.01499879360199, 45.323204174637794, 50.50110273063183, 51.4373192936182, 50.01776486635208, 45.63390210270882, 42.176608219742775, 37.74052485823631, 41.01112335920334, 42.893382757902145, 43.110206723213196, 42.678196504712105, 42.069366574287415, 36.28807559609413, 38.066281378269196, 35.898885279893875, 37.5668665766716, 34.926597252488136, 37.33256734907627, 35.86677700281143, 36.72372221946716, 36.22119538486004, 35.943931862711906, 37.42219313979149, 37.609317898750305, 35.24224631488323, 35.8686351031065, 35.57608500123024, 35.10891906917095, 35.362688452005386, 36.190656423568726, 35.27421399950981, 36.13739088177681, 34.8652533441782, 34.55419823527336, 33.54573994874954, 35.69048926234245, 39.302024468779564, 43.25415059924126, 45.26623763144016, 46.86478905379772, 46.384179443120956, 46.74562364816666, 46.23049668967724, 48.08521516621113, 47.48556934297085, 43.60977351665497, 43.32109160721302, 40.716107189655304, 39.91172835230827, 43.296210542321205, 47.16032959520817, 46.61245979368687, 48.51859711110592, 23.440928868949413, 0.3247735009063035, 2.1103352727368474, 6.487897261977196, 8.836840968579054, 4.522008625790477, 0.30351275112479925, 0.024613849054730963, 0.013838930699421326, 0.8469125081319362, 0.31386526592541486, 12.880935464054346, 31.927486583590508, 27.65696033835411, 39.850889816880226, 35.10460630059242, 5.408609826117754, 0.10067294831969775, 0.04262858034053352, 0.02616960209707031, 0.02931669972895179, 0.033322627350571565, 0.07259684862219729, 0.060376975234248675, 0.016664551294525154, 0.041196955207851715, 0.040240081943920814, 0.05270570640277583, 0.03786945075262338, 0.047455816820729524, 0.019911465933546424, 0.08007178970729001, 0.11890924593899399, 0.030058724951231852, 0.04721570607216563, 0.031458356097573414, 0.008482219163852278, 0.039061054194462486, 0.024872860449249856, 0.03767769092519302, 0.051434299821266904, 0.036172377949696966, 0.08806956640910357, 0.046573124927817844, 0.04559849578072317, 0.13443979929434136, 0.021457892034959514, 0.06665439053904265, 0.03139947039016988, 0.01361168137009372, 0.09040807373821735, 0.06691259113722481, 0.03592246343032457, 0.09447130258195102, 0.015071386587806046, 0.05479741252202075, 7.937022652477026, 44.90660212934017, 36.922272965312004, 33.60545374453068, 40.042414739727974, 49.059619680047035, 17.89528414607048, 1.0847140196710825, 3.2364255096763372, 0.06223270065675024, 0.1216956542339176, 0.3049780474975705, 0.7127304864116013, 4.000213025137782, 0.2639433369040489, 5.84487771615386, 42.77884170413017, 54.085552990436554, 54.26597110927105, 52.26655639708042, 52.4197793751955, 46.83197781443596, 45.08912153542042, 44.63028475642204, 43.14654417335987, 41.87677390873432, 40.28711020946503, 41.361236572265625, 44.40658316016197, 46.54388107359409, 45.36185950040817, 42.36803814768791, 41.70368939638138, 40.64571216702461, 45.53745187819004, 45.96229948103428, 50.56526228785515, 50.37744976580143, 52.38885663449764, 51.371301636099815, 54.19063255190849, 47.90817506611347, 38.53752829134464, 41.52581714093685, 39.52974244952202, 39.05258685350418, 40.5062710493803, 38.47938001155853, 38.604184314608574, 38.30316826701164, 37.45340086519718, 39.0731817483902, 39.48688454926014, 38.30207772552967, 38.47270376980305, 37.211703434586525, 44.5414075255394, 51.12390071153641, 49.71877031028271, 50.218359902501106, 51.05430744588375, 51.69565603137016, 52.05863535404205, 52.72489920258522, 52.93541170656681, 51.39133796095848, 47.401289865374565, 45.94176918268204, 51.55181474983692, 52.59819120168686, 50.64826883375645, 47.31146268546581, 43.101991564035416, 39.72099378705025, 40.80138221383095, 44.00733098387718, 45.65630570054054, 43.8884087651968, 41.162077859044075, 38.33690665662289, 39.19082723557949, 37.01593413949013, 38.87657269835472, 37.17253893613815, 37.74761527776718, 37.31450691819191, 37.8040536493063, 37.01453201472759, 37.418245151638985, 38.19582022726536, 37.58876860141754, 37.00657904148102, 37.109059542417526, 36.77148945629597, 37.2505297511816, 36.00718706846237, 37.287687957286835, 36.964180916547775, 37.282679826021194, 36.13831423223019, 36.04711152613163, 36.0462261736393, 36.824576407670975, 40.712155401706696, 46.093145459890366, 47.67583653330803, 47.821885496377945, 49.33922007679939, 46.66446380317211, 47.36686371266842, 49.01034392416477, 48.80106255412102, 45.9125791490078, 45.05288287997246, 41.9836887717247, 42.373426258563995, 44.16764818131924, 47.57955349981785, 46.88216172158718, 50.23504860699177, 24.04471267014742, 0.9639023523777723, 4.185856813564897, 8.805947676301003, 10.961222425103188, 3.3847277518361807, 0.5539447849150747, 0.21154627116629854, 0.06402276456356049, 0.9832903370261192, 0.8135580166708678, 15.789998564869165, 37.01212674379349, 29.342582188546658, 41.0712893307209, 43.07973995804787, 8.984672036021948, 0.11594205789151601, 0.03927677797037177, 0.04685202773544006, 0.03510764094244223, 0.048949021656881087, 0.04722849698737264, 0.07395707914838567, 0.03277368668932468, 0.05348581493308302, 0.042368550348328426, 0.054189007278182544, 0.024928421335062012, 0.04143344056501519, 0.03413967257074546, 0.07673194704693742, 0.055783218413125724, 0.028987440346099902, 0.14206287305569276, 0.15432435495313257, 0.1806128435418941, 0.10127301924512722, 0.1267283654306084, 0.10975749639328569, 0.09717591135995463, 0.17501439317129552, 0.2896929520647973, 0.1527676111436449, 0.12016533088171855, 0.17851295153377578, 0.20208167668897659, 0.1152138551697135, 0.15639856865163893, 0.07289585249964148, 0.24160298489732668, 0.3032240259926766, 0.2106739062583074, 0.19929292320739478, 0.0784571138501633, 0.16759273828938603, 7.848010053858161, 51.673130840063095, 45.63882663846016, 43.48482862114906, 44.07262668013573, 53.70804704725742, 20.03163021057844, 1.6796047543175519, 5.588086070492864, 0.19010273041203618, 0.36123871919699013, 0.6826420384459198, 1.7145898332819343, 6.5008065942674875, 0.30078452720772475, 6.123683005571365, 44.36414323747158, 55.76270319521427, 55.29819332063198, 55.62150277197361, 54.94181424379349, 48.28305535018444, 47.97897666692734, 45.99560089409351, 45.001874417066574, 45.49071438610554, 44.288204312324524, 44.18487265706062, 47.30176940560341, 49.970354810357094, 49.353841692209244, 43.902570605278015, 42.97318987548351, 42.290058732032776, 47.80846081674099, 47.79481954872608, 52.48585022985935, 52.35472306609154, 55.03970459103584, 52.01388135552406, 57.715559005737305, 50.6049245595932, 41.801879927515984, 43.054235726594925, 42.26007454097271, 40.524821653962135, 42.337092608213425, 39.569218531250954, 40.6252084672451, 40.8091451972723, 40.34167908132076, 40.57149074971676, 41.37834705412388, 39.76354770362377, 40.66260226070881, 38.96782860159874, 45.85704892873764, 53.49884167313576, 52.50962935388088, 50.88010959327221, 52.462443485856056, 52.537022083997726, 54.491040632128716, 53.67780826985836, 55.119070932269096, 53.95698308944702, 46.42075628042221, 48.08238051831722, 54.5868106931448, 54.20837759971619, 52.21831798553467, 49.89631198346615, 46.29015728831291, 41.072577461600304, 43.49722735583782, 46.0576743632555, 48.43423783779144, 47.02269718050957, 44.02044788002968, 40.72076193988323, 40.555710196495056, 39.98873122036457, 42.714693546295166, 37.72091791033745, 40.96258096396923, 39.58388194441795, 38.92939366400242, 38.91519382596016, 38.605385050177574, 41.66995860636234, 39.669909328222275, 38.717935010790825, 39.54394988715649, 38.02478760480881, 38.25460687279701, 40.46852387487888, 39.31789621710777, 38.916466757655144, 39.42929103970528, 38.68043102324009, 38.25976699590683, 37.04125978052616, 39.42957982420921, 42.97445520758629, 47.10980370640755, 50.22733502089977, 49.711505100131035, 50.503036826848984, 47.32238329946995, 47.87031389772892, 50.539001896977425, 52.64373175799847, 48.22288937866688, 47.32140675187111, 43.461505472660065, 44.645438343286514, 45.770854353904724, 49.69983592629433, 48.98592263460159, 51.322732642292976, 25.587443187832832, 0.8316241472493857, 4.774017753079534, 14.696060065180063, 19.87810704857111, 13.096556793898344, 1.7095084371976554, 0.6500758265610784, 0.23969116795342416, 2.6565006282180548, 2.1316936891525984, 20.12619573622942, 42.994176149368286, 36.20343893766403, 49.1108713299036, 47.48594172298908, 10.391689036041498, 0.3111372498096898, 0.23511441744631156, 0.17527570336824283, 0.11502240333356895, 0.10345160859287716, 0.20515038311714306, 0.20442445878870785, 0.11121293704491109, 0.13303334038937464, 0.13534676312701777, 0.2313158384640701, 0.07410988735500723, 0.12433818978024647, 0.12231812317622826, 0.20577120449161157, 0.24644581018947065, 0.12361448447336443], [0.02837771036865888, 0.022415932326111943, 0.02276678820635425, 0.052207810658728704, 0.057380505750188604, 0.03812067516264506, 0.023210381004901137, 0.09250959104974754, 0.0168890027271118, 0.04108651621208992, 0.10756372270407155, 0.026729899473139085, 0.04118936303711962, 0.07799313054420054, 0.03628102094808128, 0.02179457289457787, 0.03227658504329156, 0.06123555103840772, 0.060963019568589516, 0.018108397744072136, 0.09892518311971799, 0.05524609274289105, 0.4315214400412515, 18.199683912098408, 41.814024075865746, 27.652391083538532, 32.085550501942635, 34.99411202967167, 14.000066611915827, 0.6446720415260643, 0.13114335743011907, 0.20209684618748724, 0.02029598934313981, 0.1145954457751941, 0.29899206245318055, 3.190574082545936, 0.3709080128464848, 0.292141386307776, 15.238315667957067, 53.37990045547485, 55.29213264584541, 53.28231789171696, 50.33103905618191, 46.253956630825996, 45.43280549347401, 44.14233013987541, 44.157905504107475, 46.8051702529192, 49.28053602576256, 49.42775912582874, 51.65617994964123, 51.269136518239975, 51.808661967515945, 50.01837283372879, 42.79303394258022, 38.95402394235134, 41.96083299815655, 44.975876212120056, 49.563123062253, 50.438140109181404, 49.64296817779541, 51.18422247469425, 50.252873450517654, 42.442764937877655, 36.72311805188656, 38.82481187582016, 37.522416561841965, 39.09612491726875, 38.80029559135437, 37.14895740151405, 37.81321495771408, 36.527789533138275, 37.26198613643646, 37.46742971241474, 37.243724316358566, 37.210339307785034, 36.0428823530674, 35.73265939950943, 38.15663293004036, 40.999663174152374, 45.0295103341341, 46.7361431568861, 48.66766691207886, 48.466080129146576, 48.11687506735325, 48.586647659540176, 49.646171405911446, 50.00245928764343, 51.55672788619995, 45.13646699488163, 50.33330373466015, 50.8169873803854, 47.872392386198044, 46.81715860962868, 42.79455006122589, 44.99206334352493, 45.278674364089966, 46.18315503001213, 46.80682696402073, 47.94841110706329, 48.47702354192734, 40.97960785031319, 35.09659633040428, 37.75954283773899, 35.46469397842884, 37.193000838160515, 35.975770354270935, 36.06592811644077, 34.880479127168655, 35.353040769696236, 34.51300464570522, 36.36354334652424, 37.69219145178795, 36.20564661920071, 35.81470839679241, 34.10665065050125, 37.81073369085789, 42.65514314174652, 42.97390043735504, 40.687483325600624, 38.156165555119514, 39.15246069431305, 39.52604904770851, 39.49640303850174, 37.758741080760956, 38.662959560751915, 40.444429367780685, 44.189599603414536, 47.354958951473236, 47.037565782666206, 44.40470986068249, 45.69395028054714, 44.605426490306854, 49.961136505007744, 46.35236755013466, 46.4812034368515, 44.31851148605347, 45.19206941127777, 44.2204387485981, 46.701538413763046, 47.47843712568283, 41.030893698334694, 9.463882371783257, 0.3192315873457119, 4.139420930296183, 5.72274086996913, 7.9147126246243715, 2.1028337627649307, 0.11748200689908117, 0.03985864401329309, 0.06989730871282518, 0.286988714360632, 0.35622349299956113, 21.791792660951614, 38.67714419960976, 30.64326949417591, 36.154030188918114, 16.295872069895267, 0.9469888068269938, 0.07387056699371897, 0.014103596331551671, 0.03135738690616563, 0.0981499653425999, 0.025155700350296684, 0.13862153427908197, 0.02370276444707997, 0.01558137377287494, 0.050620371621334925, 0.07409885904053226, 0.06208972219610587, 0.05298445335938595, 0.02712589834118262, 0.023416846488544252, 0.018219573321403004, 0.03802720537350979, 0.04046379865030758, 0.06761847747839056, 0.008888454103725962, 0.042924285371555015, 0.04406389023642987, 0.06363336709910072, 0.06271131540415809, 0.02495246135367779, 0.07199326733825728, 0.013980292205815203, 0.08578049353673123, 0.020588510560628492, 0.0292602167246514, 0.05598639247182291, 0.0140152612766542, 0.032111141772475094, 0.05211186580709182, 0.05288594067678787, 0.028815395671699662, 0.010832325333467452, 0.04684030180214904, 0.027722863378585316, 0.0293240228711511, 1.0574352834373713, 26.329150088131428, 47.227821573615074, 29.04692765325308, 37.54554592072964, 41.488594338297844, 17.65876203775406, 0.7405832887161523, 0.6356591626536101, 0.23847276926971972, 0.12465906474972144, 0.08663506916491315, 0.41248024615924805, 2.464486719109118, 1.1532189999707043, 0.5057048890739679, 18.053241670131683, 55.195792615413666, 55.88978357613087, 53.35363246500492, 51.43480762839317, 48.08478578925133, 46.21469333767891, 44.838878363370895, 43.93297277390957, 48.86070795357227, 49.903812780976295, 51.80080018937588, 53.42823006212711, 53.27495388686657, 52.7754782885313, 51.08014225959778, 43.0488096177578, 40.236196741461754, 44.716004356741905, 47.55011647939682, 51.33995331823826, 51.523863449692726, 51.31728373467922, 52.299804612994194, 52.88598395884037, 45.759819746017456, 38.778055384755135, 40.72119131684303, 38.30254890024662, 40.74408508837223, 39.5247533172369, 39.356494545936584, 39.311672151088715, 38.464503809809685, 38.60228821635246, 39.7926389425993, 39.02424417436123, 38.68398763239384, 38.52034941315651, 38.47854785621166, 40.49500845372677, 44.35459055006504, 48.23194049298763, 49.775220081210136, 49.89704914391041, 50.696716234087944, 49.48145404458046, 51.05050764977932, 50.45110501348972, 52.931300327181816, 52.047532349824905, 45.867179185152054, 51.575571075081825, 52.04702317714691, 49.109047427773476, 48.85513365268707, 45.96274025738239, 47.453651055693626, 46.85148976743221, 48.25491786003113, 48.25819708406925, 49.2892337590456, 49.91990111768246, 42.467212826013565, 37.48859837651253, 38.47236938774586, 36.55145466327667, 40.016997903585434, 36.80317975580692, 37.7982247620821, 36.8163650482893, 38.6634611338377, 36.51819124817848, 38.86380158364773, 38.83458115160465, 37.514425590634346, 38.24856899678707, 36.72904573380947, 39.77425932884216, 44.85482610762119, 43.86192798614502, 41.851007491350174, 39.84236307442188, 40.60292266309261, 40.59683158993721, 40.53088612854481, 38.74061219394207, 40.41753061115742, 43.50671924650669, 46.60060442984104, 49.14612203836441, 48.009717017412186, 46.31480276584625, 46.51562958955765, 44.8321907222271, 52.19474785029888, 48.580146208405495, 49.17620122432709, 44.58346366882324, 47.72453851997852, 44.221738278865814, 49.30628344416618, 47.55838103592396, 44.760800153017044, 10.670186541974545, 0.5960381543263793, 8.071087058633566, 6.706985905766487, 9.433113522827625, 2.962106354534626, 0.5425563803873956, 0.05908711886149831, 0.04530147343757562, 0.5563463747967035, 0.6764380994718522, 25.857280008494854, 40.61308331787586, 32.52074874937534, 41.35003097355366, 24.55850590020418, 1.834006025455892, 0.06176187103847042, 0.06238737536477856, 0.014990816252975492, 0.03944648487959057, 0.10538122965954244, 0.07434919287334196, 0.01536092437163461, 0.08285413103294559, 0.017075120376830455, 0.041337373259011656, 0.021096703603689093, 0.01708184980088845, 0.02106930722220568, 0.024703101589693688, 0.016456145094707608, 0.036806929056183435, 0.04831851154449396, 0.1650668089860119, 0.12596539309015498, 0.16655205428833142, 0.14553855842677876, 0.10499725729459897, 0.21344596141716465, 0.08704806692549028, 0.22644562792265788, 0.11302333208732307, 0.12656384613364935, 0.15730973304016516, 0.11948710438446142, 0.2179185886052437, 0.21162017423193902, 0.16299847309710458, 0.12051870449795388, 0.17375041177729145, 0.16766526096034795, 0.19945086707593873, 0.11139438473037444, 0.11301540595013648, 0.09699914662633091, 1.3697652239352465, 29.334315732121468, 55.22853545844555, 37.42661990225315, 43.08518126606941, 45.21350406110287, 23.493728935718536, 1.369296780321747, 1.105821649543941, 0.8992371847853065, 0.3614152316004038, 0.2745034749386832, 0.46826876350678504, 7.137332763522863, 1.9558729673735797, 0.5785592703614384, 18.78545667976141, 57.993628084659576, 59.298402070999146, 56.52902327477932, 54.53852668404579, 49.75734204053879, 49.20895926654339, 47.640821412205696, 47.87521943449974, 51.41250662505627, 53.689602836966515, 53.05736996233463, 55.53851902484894, 55.05130156874657, 55.53045205771923, 53.76385845243931, 46.79823562502861, 41.428200379014015, 45.5742035061121, 48.90733525156975, 52.45638281106949, 53.05930785834789, 53.128999918699265, 53.29834543168545, 54.05385509133339, 46.80922843515873, 40.193133652210236, 42.47416265308857, 40.247577130794525, 43.01333852112293, 43.43834571540356, 42.41807386279106, 41.662267819046974, 40.12655362486839, 40.40801212191582, 41.82587943971157, 41.47930383682251, 40.62484368681908, 39.88718166947365, 38.68358865380287, 42.30140872299671, 44.658129662275314, 49.32478465139866, 52.32404351234436, 52.0154582709074, 52.93046437203884, 52.91411764919758, 52.939283698797226, 52.828732430934906, 56.47329546511173, 53.60425941646099, 47.88769416511059, 54.150039330124855, 55.072113052010536, 52.27473355829716, 51.2267953902483, 47.242940962314606, 49.953711703419685, 50.65580762922764, 49.24226447939873, 48.970780447125435, 51.017403826117516, 52.44388148188591, 44.40715692937374, 39.74274381995201, 41.36983931064606, 38.45747798681259, 41.65759786963463, 38.100452944636345, 38.740008026361465, 37.29584991931915, 39.84504193067551, 38.04515831172466, 39.14523348212242, 41.272868514060974, 39.42936323583126, 39.2750459164381, 37.10353843867779, 41.661420464515686, 47.537463158369064, 47.510435208678246, 43.900290727615356, 42.74424076080322, 43.79055641591549, 43.009018152952194, 42.52268224954605, 41.86945170164108, 42.45286099612713, 46.60286910831928, 49.339934438467026, 51.894867941737175, 48.68920035660267, 47.66536809504032, 46.75744481384754, 46.85796841979027, 53.54154758155346, 51.46706409752369, 51.28726154565811, 47.22760498523712, 49.87524591386318, 47.10294887423515, 50.59529967606068, 48.85157324373722, 42.6935438811779, 11.183540895581245, 1.2645238148979843, 9.764941167086363, 13.930650036782026, 14.083148203790188, 10.650637540966272, 1.0318011464551091, 0.23338874598266557, 0.3182538819964975, 0.8085314801428467, 1.4020186057314277, 31.510343067348003, 49.11392256617546, 40.44278405606747, 46.78160771727562, 28.547203168272972, 2.0064364979043603, 0.18450995004968718, 0.19552579644368961, 0.1093343757383991, 0.22862202051328495, 0.14282450953032821, 0.1594594825292006, 0.1355835676076822, 0.14347681280924007, 0.20443609566427767, 0.08701300786924548, 0.15537155501078814, 0.10468105785548687, 0.10569621197646484, 0.11479384411359206, 0.07945019649923779, 0.14483277598628774, 0.07759582178550772], [0.04447128107130993, 0.05838214165123645, 0.02618794056616025, 0.02682875725440681, 0.018896766378020402, 0.04794216474692803, 0.057077293895417824, 0.04219057962473016, 0.09900632212520577, 0.03646308461611625, 0.048289003752870485, 0.04077222038176842, 0.05325728910975158, 0.045571099399239756, 0.008625734753877623, 0.01843725080107106, 0.05585723651165608, 0.02325130488316063, 0.007597706689921324, 0.030971776250225957, 0.039468407921958715, 0.0518783564621117, 0.19054322474403307, 4.59773856215179, 35.055550932884216, 42.21019461750984, 30.448092967271805, 36.92877821624279, 21.835708804428577, 4.369194125756621, 0.6669406872242689, 0.26553476869594306, 0.193832972436212, 0.24955288565251976, 0.012620332563528791, 1.6677042678929865, 1.3328762096352875, 0.03709223659825511, 3.6801495496183634, 33.19589652121067, 53.50348882377148, 52.84011282026768, 50.49573741853237, 50.199706703424454, 47.4085246771574, 48.87371085584164, 48.8860297948122, 51.08412444591522, 48.08296948671341, 52.29186683893204, 52.14877411723137, 51.57767616212368, 49.992496222257614, 49.87548530101776, 43.774878457188606, 40.564138144254684, 43.38233672082424, 48.524931371212006, 51.12891264259815, 50.34825213253498, 51.86890013515949, 50.97792014479637, 49.362178444862366, 41.762350648641586, 36.72157533466816, 37.043399065732956, 38.07244844734669, 38.42837534844875, 38.38632680475712, 37.758414298295975, 37.168321162462234, 36.480428874492645, 36.92918859422207, 36.31448797881603, 36.67232617735863, 36.68318219482899, 36.473482847213745, 36.48153081536293, 35.44839285314083, 37.82783277332783, 39.81213189661503, 42.13397830724716, 44.85622063279152, 45.1180037856102, 45.29511608183384, 45.90699724853039, 49.25886578857899, 48.05480919778347, 50.90336814522743, 45.31718149781227, 49.104271084070206, 50.26076942682266, 50.512855499982834, 48.33971790969372, 47.14278593659401, 46.45523943006992, 48.755628392100334, 49.87435296177864, 51.290445774793625, 49.195485189557076, 49.66566815972328, 44.439667984843254, 36.745016276836395, 35.297301560640335, 36.922462955117226, 35.5383226275444, 36.29731670022011, 36.804794669151306, 35.63875883817673, 36.182475462555885, 34.851555079221725, 34.89743761718273, 35.49111396074295, 36.3680575042963, 35.00390410423279, 37.95468516647816, 45.141915902495384, 48.21754306554794, 48.513877764344215, 46.920015290379524, 43.25515374541283, 42.498599141836166, 44.82798434793949, 44.64413121342659, 44.18410889804363, 45.4117888212204, 42.63018228113651, 44.332924112677574, 44.748743399977684, 47.02019311487675, 44.59034129977226, 46.28764562308788, 43.46365235745907, 44.57038477063179, 46.03249691426754, 46.676839739084244, 46.70470744371414, 46.76552318036556, 46.71222344040871, 47.92528174817562, 44.88923326134682, 27.46394209563732, 2.058348124846816, 0.45368220715317875, 8.14562575891614, 4.7375306859612465, 7.609948078170419, 1.4684023498557508, 0.4755383374867961, 0.23040111176669598, 0.08160728582879528, 0.18790122354403138, 2.828062609769404, 28.528282083570957, 30.96027698367834, 30.241517052054405, 41.476127207279205, 8.245129119604826, 0.11109014871180989, 0.07933747911010869, 0.019199629423383158, 0.04758772243803833, 0.025318573934782762, 0.027708426750905346, 0.039452377532143146, 0.06212848827999551, 0.05541192564123776, 0.05319749427144416, 0.06912149721756577, 0.029625481402035803, 0.020112153797526844, 0.03425572220294271, 0.03322324264445342, 0.03192669581039809, 0.03125967945379671, 0.03937507914088201, 0.03850918947136961, 0.048420044768135995, 0.028016317846777383, 0.0402691444469383, 0.03942293653381057, 0.027947845446760766, 0.021480525683728047, 0.025730291490617674, 0.021518234207178466, 0.036333268144517206, 0.04910609721264336, 0.025762094373931177, 0.07470658150850795, 0.02299563686392503, 0.033230144617846236, 0.04983127939340193, 0.01015644123981474, 0.05290991575748194, 0.03880643445882015, 0.06116565928095952, 0.007293728103832109, 0.06297149753663689, 0.27034902130253613, 9.060979541391134, 43.36190141737461, 43.16429302096367, 34.07751381397247, 41.866598054766655, 24.749346859753132, 5.325920088216662, 1.2097509414888918, 0.045799142826581374, 0.3333677491173148, 0.11240751278819516, 0.051200263551436365, 0.8340284682344645, 2.633312135003507, 0.16615745436865836, 5.156666245311499, 37.37336955964565, 55.286079570651054, 53.81841592490673, 51.376849338412285, 52.966072261333466, 49.16278034448624, 50.6598886102438, 50.367102921009064, 52.5036446750164, 51.14081360399723, 53.35973873734474, 51.88664898276329, 53.561815693974495, 51.443520560860634, 51.73845313489437, 44.5072777569294, 42.47352808713913, 45.58309502899647, 51.07241727411747, 53.20790648460388, 52.19959259033203, 51.68638072907925, 53.689800426363945, 51.844231858849525, 43.658167719841, 39.52169448137283, 39.57717150449753, 39.853367283940315, 40.265052393078804, 39.81117434799671, 39.81076776981354, 38.915429413318634, 37.68714152276516, 38.61279085278511, 38.65339547395706, 38.303058072924614, 37.719508185982704, 36.990996077656746, 37.839973121881485, 37.020569890737534, 40.91863252222538, 43.41302007436752, 44.702385887503624, 47.397816851735115, 47.5907438993454, 46.81275464594364, 48.25351573526859, 50.71647137403488, 50.27690716087818, 52.46017500758171, 46.51255175471306, 49.66646611690521, 52.82364450395107, 52.831620275974274, 49.227065294981, 47.40982800722122, 48.63677836954594, 49.92159962654114, 52.160895466804504, 51.980800330638885, 50.542208924889565, 50.60648247599602, 46.25522956252098, 38.61487694084644, 36.44200913608074, 38.80501873791218, 38.80673244595528, 37.643060088157654, 37.216916754841805, 36.62474513053894, 36.928310841321945, 36.849161088466644, 36.27622403204441, 36.790446639060974, 37.538744285702705, 36.473809629678726, 39.221753776073456, 47.25317381322384, 49.341537952423096, 51.61732703447342, 48.22670057415962, 44.20008324086666, 44.2346765846014, 47.12222523987293, 45.57093188166618, 46.655864864587784, 47.006008476018906, 44.8976194113493, 45.48943005502224, 46.13153100013733, 48.86782877147198, 45.07810592651367, 46.166318133473396, 44.66672480106354, 46.061322167515755, 49.046901762485504, 47.85781256854534, 48.501684218645096, 48.14704164862633, 49.48921322822571, 47.44089134037495, 47.20252253115177, 28.432496823370457, 3.8177974009886384, 1.170674313325435, 11.99519919231534, 8.109913375228643, 11.490164492279291, 2.355291028507054, 0.8608857833314687, 0.2073361267684959, 0.017370222412864678, 0.11059469092288055, 3.542862441390753, 35.16318015754223, 39.81243208050728, 34.48889493942261, 44.90335710346699, 11.677799373865128, 0.23721175646642223, 0.1133965358894784, 0.04848502721870318, 0.014183675921231043, 0.027317168351146393, 0.033146667847177014, 0.07826187706086785, 0.029771216941298917, 0.03312818465929013, 0.07380968861980364, 0.020320372605056036, 0.08803845557849854, 0.06987064334680326, 0.03267360807512887, 0.04807450452062767, 0.012555048615467967, 0.05694115061487537, 0.09888422398944385, 0.1643592305481434, 0.13138252194039524, 0.17794039944419637, 0.15314729389501736, 0.16995711688650772, 0.08951379320933484, 0.13358551310375333, 0.23749537562252954, 0.0940740383521188, 0.13171552360290661, 0.2091644669417292, 0.14310507103800774, 0.19943326333304867, 0.09229517716448754, 0.10446939733810723, 0.13855748693458736, 0.1444125868147239, 0.22248080786084756, 0.16024161712266505, 0.14275642490247265, 0.17173441214254126, 0.17075020557967946, 0.44310511846560985, 9.604041650891304, 49.57584857940674, 52.451902851462364, 41.56044088304043, 47.43944361805916, 32.1083302795887, 9.93409764021635, 2.4185269977897406, 0.8274158730637282, 0.8974948595277965, 0.5395578069146723, 0.2444793118047528, 4.082591654732823, 5.732551468536258, 0.18376478925347328, 5.014592343941331, 37.03747518360615, 55.89655861258507, 56.32133021950722, 53.38314928114414, 54.59070548415184, 50.53848512470722, 53.688892275094986, 52.7975133061409, 55.09498402476311, 51.90686009824276, 56.474405005574226, 55.15841402113438, 55.053391456604004, 53.78937028348446, 53.56289103627205, 46.753485426306725, 45.17283484339714, 46.39033891260624, 51.9210409373045, 56.790468245744705, 53.79282429814339, 54.05274175107479, 54.45876896381378, 55.27078539133072, 43.974686935544014, 40.09595386683941, 40.306086391210556, 41.663365960121155, 43.13560836017132, 41.875276789069176, 42.471259608864784, 40.243898928165436, 39.72516596317291, 39.686974212527275, 40.20360589027405, 41.01583130657673, 39.37936931848526, 39.73762549459934, 40.1424215734005, 39.394541904330254, 42.76410989463329, 44.178287610411644, 46.27918727695942, 48.81968155503273, 49.16701711714268, 47.727308571338654, 50.49126885831356, 53.446309491992, 51.819415390491486, 54.74072523415089, 48.64866033196449, 52.0626175403595, 54.95301604270935, 56.192425936460495, 51.231020763516426, 50.15925407409668, 50.05275338888168, 51.73888251185417, 54.61757764220238, 54.02622677385807, 52.48844929039478, 51.78670674562454, 48.053844049572945, 41.09630338847637, 39.80408392846584, 39.68177989125252, 40.23713909089565, 39.55074392259121, 40.03093175590038, 38.92248563468456, 39.14483830332756, 37.68185980618, 38.43302249908447, 37.94612802565098, 40.34488990902901, 37.545629516243935, 42.24999748170376, 49.56232510507107, 51.913733929395676, 52.38488204777241, 50.56387156248093, 46.79722487926483, 47.19984367489815, 48.79886247217655, 47.520056292414665, 48.63430470228195, 50.151198506355286, 47.07673408091068, 47.587859854102135, 46.919338926672935, 50.285468101501465, 46.98869660496712, 46.59288324415684, 45.385950207710266, 46.468291729688644, 51.298736929893494, 49.63800184428692, 49.03585955500603, 49.999031871557236, 51.74647830426693, 47.83231593668461, 48.08405622839928, 29.124707579612732, 2.966529792174697, 1.781302853487432, 16.4334037899971, 13.900990728288889, 18.09809446334839, 4.340477641671896, 1.9181267428211868, 0.3444388706702739, 0.2720308763673529, 0.355149456881918, 6.026014471426606, 40.142239183187485, 42.70567283034325, 38.513167798519135, 52.863967940211296, 14.972048755735159, 0.30580349382944405, 0.198855857597664, 0.09712226150440983, 0.12165873980848119, 0.12382169952616096, 0.13804058107780293, 0.22255555697483942, 0.16423530672909692, 0.2796648448565975, 0.12844152428442612, 0.10521889227675274, 0.21161904616747051, 0.1110213367792312, 0.09415185995749198, 0.10501972952624783, 0.08553289822884835, 0.1379929351969622, 0.16768589266575873], [0.03386979798960965, 0.07699099369347095, 0.015360385386884445, 0.14708935021189973, 0.04747468963614665, 0.0309847360040294, 0.04034420526295435, 0.04835053150600288, 0.05847996784723364, 0.03197234902472701, 0.014829367592028575, 0.09042376274010167, 0.025646282228990458, 0.03429747172049247, 0.0436015916056931, 0.07153144368203357, 0.004611078084053588, 0.033087318297475576, 0.003917266485586879, 0.06162129342556, 0.027429987785581034, 0.016004848803277127, 0.11244276480283588, 0.6274205516092479, 17.399790734052658, 39.62154172360897, 27.23326787352562, 29.15427189320326, 33.06001201272011, 8.59615333378315, 0.1418833326897584, 0.14378026215126738, 0.3567434713477269, 0.14389962918357924, 0.017068018023564946, 0.33779240387957543, 0.905423549702391, 0.872188633074984, 0.2591398899676278, 11.25770341604948, 40.543824434280396, 52.07220822572708, 54.96582515537739, 50.78792653977871, 50.06232127547264, 49.973478242754936, 51.35380357503891, 51.17464318871498, 53.587061539292336, 54.19560268521309, 52.194820046424866, 52.06679351627827, 53.040650859475136, 47.097952142357826, 38.04378278553486, 41.54839172959328, 48.22786331176758, 50.09354420006275, 50.61964876949787, 48.475872203707695, 50.94557628035545, 50.43451890349388, 46.18460655212402, 40.0383185595274, 36.389720141887665, 38.94770108163357, 40.49205221235752, 39.004158452153206, 37.50550366938114, 38.697492107748985, 37.94901207089424, 37.086283564567566, 37.003223821520805, 36.71396054327488, 37.97245301306248, 37.976868376135826, 37.49799907207489, 35.543494150042534, 37.057154327631, 36.96123607456684, 39.458564668893814, 39.24438916146755, 39.64790090918541, 41.58160574734211, 42.16259837150574, 41.822813004255295, 46.28821939229965, 48.12740810215473, 52.63275034725666, 44.41239684820175, 48.04035097360611, 50.46143285930157, 50.28027758002281, 48.666105195879936, 47.17242054641247, 52.384106889367104, 50.37909507751465, 49.72333386540413, 51.17205172777176, 51.08986593782902, 49.974952563643456, 44.770413637161255, 33.754702135920525, 34.407214522361755, 35.75806483626366, 35.93945190310478, 36.400397568941116, 36.755511313676834, 37.5841024518013, 36.62601426243782, 36.988355219364166, 35.17804495990276, 34.820864126086235, 36.14052951335907, 34.98083554208279, 38.287281319499016, 46.12512454390526, 47.42529697716236, 48.66659536957741, 48.237697184085846, 43.819073885679245, 41.52564994990826, 46.429909989237785, 46.094517186284065, 46.64442367851734, 46.55663698911667, 45.29847510159016, 45.63029609620571, 45.385665223002434, 43.504826948046684, 46.486393958330154, 46.46392576396465, 47.14784726500511, 44.21269476413727, 48.88369292020798, 43.791418969631195, 48.99129554629326, 47.44086094200611, 49.55972224473953, 47.535361871123314, 34.99861478805542, 11.57473560422659, 0.735850939527154, 0.8236668992321938, 9.83211301267147, 5.3659856133162975, 8.03770300000906, 0.3896068985341117, 0.20161485095741227, 0.09712199433124624, 0.08603525799117051, 0.12624368362594396, 10.274038799107075, 34.46125902235508, 26.01029209792614, 35.142038092017174, 27.870881259441376, 0.6338527158368379, 0.030391503969440237, 0.04961682097928133, 0.0588947950018337, 0.088378477958031, 0.04722087141999509, 0.016789360124676023, 0.05008853375329636, 0.017398611416865606, 0.03375039013917558, 0.04274526079825591, 0.019375013762328308, 0.042167342980974354, 0.015414892422995763, 0.03649064055935014, 0.02973261412989814, 0.07948518134071492, 0.12615345331141725, 0.05222642743319739, 0.024233006697613746, 0.03778203317779116, 0.019265200025984086, 0.17763046373147517, 0.06161743796837982, 0.034391627996228635, 0.027467874424473848, 0.04089030720933806, 0.03806589724263176, 0.026183068366663065, 0.01634287109482102, 0.020622929514502175, 0.017575680431036744, 0.03922325427993201, 0.008613588579464704, 0.10194019516347907, 0.021992236506775953, 0.01541886569611961, 0.014945845814509084, 0.08857977067236789, 0.014386855546035804, 0.03981985566497315, 0.07336824433878064, 1.2982524675317109, 25.08154023438692, 46.10018648207188, 31.56861674040556, 37.11843743920326, 37.38929830491543, 10.28109597042203, 0.17112374334828928, 0.4835413018008694, 0.5052018316928297, 0.0984150604926981, 0.13073069363599643, 0.1416514560696669, 1.6678068623878062, 2.1326901856809855, 0.3665347443893552, 14.51591458171606, 45.025509148836136, 53.34764398634434, 55.17921030521393, 51.68688990175724, 52.1657782047987, 51.50364473462105, 53.90035092830658, 53.99710513651371, 54.03674080967903, 56.18695802986622, 53.16018484532833, 55.530387461185455, 56.13800525665283, 49.13756489753723, 41.148425191640854, 42.94764764606953, 50.50700381398201, 51.01740762591362, 52.003276124596596, 49.82624374330044, 52.99401976168156, 53.05761694908142, 48.925160095095634, 40.57647988200188, 37.099959030747414, 40.58589577674866, 41.98868170380592, 39.99068811535835, 39.07795429229736, 40.4408423602581, 38.875102177262306, 38.658080622553825, 39.65455815196037, 37.766956239938736, 37.6778320223093, 40.10440841317177, 38.845988139510155, 37.76390120387077, 38.97223636507988, 39.63204815983772, 41.65923938155174, 41.76006317138672, 40.85809417068958, 43.67165319621563, 43.04218277335167, 44.82097752392292, 48.70978385210037, 50.21730735898018, 54.463549107313156, 46.877020597457886, 49.715038910508156, 52.64429792761803, 52.19672754406929, 51.67887233197689, 48.766305819153786, 53.35652410984039, 53.20880323648453, 49.44777265191078, 52.65743002295494, 51.02919839322567, 51.10079415142536, 46.88345365226269, 36.48540660738945, 35.951580852270126, 38.810213059186935, 37.18939483165741, 38.04499872028828, 38.433444276452065, 37.80798263847828, 38.23523931205273, 37.127811536192894, 37.127838134765625, 36.959343776106834, 36.45864464342594, 37.3480287194252, 40.316281244158745, 47.70275428891182, 48.93613390624523, 50.539207085967064, 48.97816725075245, 44.85031574964523, 43.234015479683876, 49.59667906165123, 48.43893438577652, 48.85509565472603, 49.26039330661297, 47.08942539989948, 47.11324632167816, 48.04464854300022, 45.719952285289764, 48.133533373475075, 45.702347829937935, 49.15793940424919, 45.76030991971493, 50.73162116110325, 46.53063878417015, 51.27388246357441, 47.604195177555084, 50.60060799121857, 47.30778828263283, 38.69575560092926, 13.95553870126605, 1.0072528012096882, 3.694556476548314, 10.834288336336613, 9.563611820340157, 8.39533505961299, 3.8856719713658094, 0.750430163461715, 0.32443410193081945, 0.07582153964904137, 0.03171736192598473, 11.18086963891983, 38.02885338664055, 28.50185640156269, 38.057910427451134, 35.61881750822067, 2.4258731910958886, 0.11611252921284176, 0.06885160037199967, 0.02384176685154671, 0.07748824005830102, 0.0315933416277403, 0.04550161582301371, 0.029079767227813136, 0.059558950379141606, 0.04361215607787017, 0.056407628071610816, 0.02079844372929074, 0.02932297829829622, 0.07984988013049588, 0.01652265080338111, 0.03559140248398762, 0.04019176441943273, 0.07360903415246867, 0.07775070058414713, 0.09363485020003282, 0.1371740346075967, 0.11428582176449709, 0.317429355927743, 0.09890513771097176, 0.1313551070052199, 0.14775483403354883, 0.11590076479478739, 0.14109664130955935, 0.09857438475592062, 0.09445642252103426, 0.13991238141898066, 0.14819543226622045, 0.14953391044400632, 0.2017167181475088, 0.23336285987170413, 0.14157798344967887, 0.16598163958406076, 0.0627493801584933, 0.16399534069932997, 0.12431176932295784, 0.12666578753851354, 0.24895652546547353, 1.4630527119152248, 26.956507824361324, 51.63597263395786, 38.995719105005264, 40.2104265242815, 46.892120987176895, 16.730012074112892, 0.315550445811823, 0.6555061507970095, 1.5034515503793955, 0.19051451847190037, 0.2861551637761295, 0.5714951525442302, 4.092759909108281, 4.283210439607501, 0.5357502331025898, 14.616259597241879, 43.57017584145069, 54.71903219819069, 58.20470295846462, 56.041304245591164, 53.55456568300724, 54.07797619700432, 57.83770725131035, 54.499601572752, 56.043261140584946, 58.33967551589012, 54.745406582951546, 55.699318796396255, 59.596663266420364, 50.11576160788536, 41.46246314048767, 45.014250352978706, 53.90083730220795, 53.58027510344982, 53.66198591887951, 51.18317753076553, 55.27419000864029, 55.09217977523804, 51.50120906531811, 43.76665949821472, 39.223760068416595, 42.58899629116058, 44.14469741284847, 42.982563972473145, 39.796830117702484, 42.7316140383482, 41.93213693797588, 40.336526557803154, 41.266275867819786, 40.66310003399849, 39.50646869838238, 42.53663130104542, 41.58411741256714, 40.02436950802803, 40.25628626346588, 42.006210163235664, 43.99710193276405, 44.28547605872154, 43.50296504795551, 46.152809858322144, 44.348788261413574, 45.75250133872032, 51.00902147591114, 53.25907073915005, 55.83912089467049, 49.531022384762764, 51.7179836332798, 52.744335159659386, 55.61819314956665, 53.63327465951443, 51.624132469296455, 54.91929665207863, 55.12051485478878, 52.66084223985672, 53.13989393413067, 54.4695907831192, 53.44593331217766, 48.005248457193375, 38.02202135324478, 37.61474400758743, 39.52646702528, 39.72993850708008, 40.39559818804264, 40.649572759866714, 39.20981861650944, 39.39588703215122, 39.54671233892441, 38.61428417265415, 37.92980410158634, 39.11428414285183, 38.83070915937424, 42.43212930858135, 49.74035695195198, 50.90762011706829, 52.900848761200905, 52.68432877957821, 47.179662957787514, 45.48156067728996, 50.38936972618103, 49.44926217198372, 51.03596203029156, 50.97683720290661, 48.48467253148556, 48.936403691768646, 49.09328207373619, 46.72200791537762, 49.639035388827324, 48.988145515322685, 50.62805771827698, 47.81912684440613, 51.669787019491196, 48.88819567859173, 51.99184253811836, 49.296278581023216, 51.66252560913563, 49.48455847799778, 35.77123872935772, 13.909343630075455, 1.2873507337644696, 3.5237599164247513, 17.32717853039503, 11.773737575858831, 17.583013102412224, 4.7559938952326775, 0.4490176902618259, 0.43863453960511833, 0.32600234902929515, 0.20665783347794786, 16.395563520491123, 44.364158436656, 36.79944075644016, 44.668548703193665, 40.7988553494215, 2.677325173281133, 0.32062545942608267, 0.13659014250151813, 0.1505285664461553, 0.18321782641578466, 0.13370807137107477, 0.07750838194624521, 0.15241016313666478, 0.13794405735097826, 0.07593393791466951, 0.25285072275437415, 0.10544439384830184, 0.1729014393640682, 0.10555197557550855, 0.09285105319577269, 0.16980384854832664, 0.26148914359509945, 0.244494273501914, 0.17590387200471014], [0.046688157817698084, 0.08419297286309302, 0.04513444197073113, 0.03610364394262433, 0.055950261012185365, 0.08364064429770224, 0.07364082033745944, 0.06763700890587643, 0.1227825740352273, 0.07396450062515214, 0.018099465996783692, 0.05967749733827077, 0.04746939812321216, 0.04121304125874303, 0.037861264863749966, 0.054974455561023206, 0.05230059025052469, 0.030558117978216615, 0.015756728425913025, 0.05532523166039027, 0.04466981299628969, 0.11201057510334067, 0.029082461223879363, 0.04169226456724573, 5.386720150709152, 32.7488961070776, 36.82743385434151, 24.390471316874027, 33.488594815135, 18.510239347815514, 0.5742571293376386, 0.037799199053552, 0.04559053253615275, 0.08037821506150067, 0.05728636431740597, 0.08454518872895278, 1.5270383097231388, 1.3987640803679824, 0.33853324537631124, 0.9668928512837738, 15.806186646223068, 41.38177827000618, 52.31145478785038, 53.333501145243645, 51.01873375475407, 53.97310942411423, 51.481313332915306, 51.8714801967144, 51.848537027835846, 49.83773432672024, 49.87667843699455, 46.96180544793606, 46.368022710084915, 39.56392161548138, 40.30928201973438, 44.58627171814442, 50.12297362089157, 51.696309596300125, 50.04010006785393, 49.123555049300194, 49.70688454806805, 50.27789890766144, 48.67162249982357, 41.49376966059208, 35.118422359228134, 39.32472825050354, 40.62110848724842, 39.976986050605774, 38.771436139941216, 37.24162682890892, 36.826806887984276, 39.460092186927795, 38.137934133410454, 36.348397359251976, 36.70181259512901, 37.59376533329487, 38.38264100253582, 37.19171650707722, 36.79307609796524, 37.88216605782509, 36.52278520166874, 37.85006918013096, 39.147551357746124, 38.90831999480724, 41.0261819511652, 43.136360719799995, 47.90744170546532, 48.344338461756706, 52.373680248856544, 43.8620837777853, 44.30405706167221, 50.4483387619257, 52.01542027294636, 49.586229622364044, 55.81144317984581, 48.17804038524628, 48.16800892353058, 49.62760180234909, 50.14648675918579, 48.994996547698975, 46.7447192966938, 42.67089329659939, 35.3720473498106, 34.94463108479977, 36.365101262927055, 35.09944997727871, 35.33097915351391, 35.942696928977966, 38.67410436272621, 36.35163098573685, 37.84420229494572, 36.14736154675484, 35.37360526621342, 37.613030299544334, 36.41639471054077, 37.524859830737114, 46.850745007395744, 46.889058351516724, 49.22387346625328, 47.51233130693436, 43.117418736219406, 40.12414075434208, 45.54811030626297, 47.32454538345337, 48.50363731384277, 47.81954102218151, 47.82037317752838, 45.02085439860821, 46.466756612062454, 46.95908859372139, 46.77120387554169, 45.026656687259674, 47.59725674986839, 43.15635144710541, 47.43614159524441, 45.27053900063038, 46.4197151362896, 46.94690264761448, 49.032059758901596, 36.53322324156761, 23.08020282536745, 2.1696992497891188, 0.08995471056550741, 2.6406048936769366, 9.482502322643995, 9.287569932639599, 6.6843571700155735, 2.986505082808435, 0.6101516063790768, 0.5468363163527101, 0.1202912065491546, 0.24120773188769817, 21.769782342016697, 33.67198817431927, 27.830472327768803, 39.57567818462849, 11.707254443317652, 0.02886810114432592, 0.06612824494368397, 0.04700526267697569, 0.057460379393887706, 0.016158022517629433, 0.1412680625799112, 0.020474579760048073, 0.04194762273982633, 0.08578333596233279, 0.011481943893159041, 0.035169613984180614, 0.0448882752971258, 0.016533794150745962, 0.02158147075533634, 0.07543588260887191, 0.09491788994637318, 0.03216853576304857, 0.033809531887527555, 0.03361309652973432, 0.055841710782260634, 0.09487664879998192, 0.07849493369576521, 0.07527718174969777, 0.011906886520591797, 0.03249142195272725, 0.09799328312510625, 0.041927024431061, 0.040653016621945426, 0.03451751108514145, 0.04111298119823914, 0.04071984702022746, 0.03322195872897282, 0.09350184249342419, 0.05843865990755148, 0.022195677738636732, 0.017455010929552373, 0.025547840050421655, 0.03573429930838756, 0.061251095321495086, 0.0742807297501713, 0.04118892888072878, 0.0704979436704889, 0.0786094025534112, 8.223067503422499, 40.26516258716583, 37.813116163015366, 27.994243539869785, 44.11062844097614, 20.89353036135435, 1.2274848273955286, 0.039312167282332666, 0.12144759137299843, 0.137053836369887, 0.08978457321063615, 0.5294719012454152, 4.282899806275964, 4.400078868493438, 1.0308905015699565, 0.8872642647475004, 20.633198730647564, 43.39717872440815, 54.63781915605068, 55.273148864507675, 53.020910918712616, 55.40733866393566, 52.94742286205292, 52.52809636294842, 54.29511934518814, 53.004309609532356, 53.24441872537136, 49.57797646522522, 49.57149401307106, 42.95323334634304, 41.79444372653961, 46.00746005773544, 51.5449371188879, 52.69103541970253, 52.920193523168564, 50.95169395208359, 50.16383282840252, 50.25894172489643, 50.28209388256073, 43.92715908586979, 37.241520434617996, 39.70130704343319, 41.960411220788956, 41.26048117876053, 40.10594733059406, 40.256856232881546, 39.41145859658718, 41.70231766998768, 38.98546725511551, 38.04258964955807, 38.512001261115074, 39.11209926009178, 39.736462756991386, 38.5061951726675, 38.12401548027992, 37.61551536619663, 39.15070898830891, 40.657746121287346, 41.73620045185089, 41.34361311793327, 41.589516922831535, 43.901472464203835, 49.124675989151, 50.959168151021004, 52.777495980262756, 47.49809347093105, 47.40662097930908, 51.77099458873272, 52.265796437859535, 50.912331864237785, 55.3959658741951, 52.410245686769485, 48.533910289406776, 50.952187925577164, 52.146068662405014, 50.098461136221886, 48.94037067890167, 45.914258658885956, 37.553004920482635, 36.79661750793457, 39.09581333398819, 37.515934109687805, 37.924643978476524, 37.621674835681915, 40.13357184827328, 38.099810779094696, 38.7091688811779, 37.10902914404869, 36.09344623982906, 38.73802073299885, 38.29559147357941, 39.05762918293476, 48.373372703790665, 48.83540131151676, 50.054185912013054, 51.08514279127121, 44.799345284700394, 42.67763413488865, 47.718675434589386, 49.42324496805668, 49.962656423449516, 49.09876137971878, 48.61087515950203, 47.21436269581318, 46.76269233226776, 45.702081844210625, 45.98214581608772, 47.123828753829, 48.14457178115845, 45.58206148445606, 49.436422660946846, 47.5408373773098, 48.18636193871498, 49.95437666773796, 49.62453156709671, 38.7127672880888, 24.658488035202026, 4.7752156388014555, 2.0232710195705295, 5.8774443436414, 11.796166822314262, 9.407318606972694, 8.70526922866702, 7.424309989437461, 1.5608674194663763, 0.8599541801959276, 0.13342117192223668, 0.3075839951634407, 24.104384668171406, 41.389526054263115, 31.30838580429554, 42.18248650431633, 17.31025993824005, 0.03526217464241199, 0.05219844104431104, 0.07617664989084005, 0.05630087012832519, 0.017416434093320277, 0.06040332518750802, 0.011316471864120103, 0.0296509556210367, 0.056891731001087464, 0.021881018255953677, 0.04198133850877639, 0.03374607455043588, 0.034116851529688574, 0.027886746283911634, 0.1294345030328259, 0.05787787456938531, 0.009747072581376415, 0.01190563971249503, 0.05047587546869181, 0.1284338950063102, 0.1767129762447439, 0.1859941118163988, 0.20327269012341276, 0.09822613938013092, 0.2531184005783871, 0.20233704970451072, 0.15179986541625112, 0.19232807506341487, 0.24955579487141222, 0.13728087418712676, 0.210723303607665, 0.11974647757597268, 0.29481293982826173, 0.10365892754634842, 0.12983753375010565, 0.11446223768871278, 0.32543493260163814, 0.2456100331619382, 0.11858315367135219, 0.13672543602297083, 0.22846559062600136, 0.10847562924027443, 0.36055543867405504, 8.73917005956173, 45.909394919872284, 48.336567878723145, 33.735269978642464, 47.60693483054638, 29.330426640808582, 2.1487958589568734, 0.09712095532449894, 0.3424038126831874, 0.506380065344274, 0.24219989427365363, 0.5326984624844044, 6.129178460687399, 3.879380696453154, 0.9311153960879892, 1.314259939827025, 19.592438377439976, 45.08985489606857, 54.811735823750496, 55.702320635318756, 54.19940248131752, 56.46165668964386, 53.81379917263985, 53.65464471280575, 55.76977461576462, 55.10504588484764, 55.520139411091805, 51.03826090693474, 51.18521802127361, 43.005168959498405, 44.3758238106966, 47.62764371931553, 55.219476744532585, 54.60645943880081, 53.95324029028416, 51.74508757889271, 52.31555096805096, 53.53990226984024, 52.41172380745411, 45.091811791062355, 38.57723616063595, 41.32651403546333, 44.752869978547096, 44.29931491613388, 42.381151244044304, 41.91561542451382, 40.31737558543682, 43.99026229977608, 41.79010055959225, 39.113740772008896, 39.643189162015915, 40.62282979488373, 42.396981194615364, 40.280737951397896, 41.53346233069897, 40.86506299674511, 41.6739521920681, 42.282588332891464, 43.32873299717903, 42.193433716893196, 44.89231489598751, 46.685605868697166, 51.94678835570812, 52.47360348701477, 55.82144424319267, 49.71743658185005, 48.696579560637474, 52.255119010806084, 54.26749862730503, 54.04117897152901, 57.445834279060364, 54.276188760995865, 51.25862628221512, 51.69713415205479, 53.61590199172497, 50.85164912045002, 48.723763301968575, 46.67127303779125, 39.024035185575485, 38.15433405339718, 41.669609025120735, 38.768734484910965, 38.77075217664242, 39.102728962898254, 42.26459629833698, 39.46311302483082, 41.28195382654667, 39.833703339099884, 37.14567057788372, 41.63385674357414, 40.564343333244324, 40.96026688814163, 51.58432960510254, 50.08917823433876, 49.60414186120033, 52.89302498102188, 47.43985399603844, 45.22819027304649, 49.31267090141773, 51.16323620080948, 51.750992462038994, 51.02661073207855, 49.82065424323082, 47.945599257946014, 46.48929700255394, 47.480283826589584, 47.86424942314625, 47.419931665062904, 48.833117634058, 47.67746664583683, 51.649788692593575, 49.35106784105301, 49.64907445013523, 48.9954449236393, 50.94785615801811, 38.137626349925995, 25.078661888837814, 2.918974393978715, 2.4883380392566323, 8.911050036549568, 20.525480210781097, 18.446982242166996, 15.149621777236462, 11.501398589462042, 1.1972941411659122, 1.9692553742788732, 0.3319761628517881, 0.5291307508014143, 30.767114348709583, 44.05051186680794, 36.372826248407364, 50.16523875296116, 20.382630676031113, 0.21370507485698909, 0.19153494184138253, 0.21477859147125855, 0.1550857984693721, 0.14147481007967144, 0.17835192033089697, 0.05863797108759172, 0.1555021433159709, 0.254933723481372, 0.1345798425609246, 0.07458662817953154, 0.1124332653125748, 0.21811309066833928, 0.10271826278767549, 0.19611860916484147, 0.27381102147046477, 0.2551674109417945, 0.15394176298286766, 0.3181216906523332], [0.1451183098834008, 0.027912919977097772, 0.047626967207179405, 0.01200103073642822, 0.05165745991689619, 0.0311140311168856, 0.050087401978089474, 0.03070795017265482, 0.08911782773793675, 0.05826972112117801, 0.04795538239704911, 0.019559055253921542, 0.06187894112372305, 0.06143244281702209, 0.03586383747460786, 0.030251943098846823, 0.040667221328476444, 0.010144031602976611, 0.04942729872709606, 0.07277304190210998, 0.03756156707822811, 0.024714439750823658, 0.04008754091046285, 0.05314429712598212, 0.8107725880108774, 12.605059817433357, 35.775984674692154, 26.642950549721718, 25.473464503884315, 32.71762378513813, 4.92328941822052, 0.0935658230446279, 0.11445542477304116, 0.041549742527422495, 0.09595716386684217, 0.28568318753968924, 1.7687885812483728, 2.610816629603505, 1.1295753624290228, 0.040229320802609436, 2.479098835028708, 19.14612952619791, 40.59886448085308, 48.87187175452709, 51.64995588362217, 50.81357516348362, 53.193657249212265, 51.93074941635132, 49.80887107551098, 47.89881996810436, 46.247413381934166, 42.94430382549763, 42.436814457178116, 44.99672569334507, 46.24607965350151, 47.37368814647198, 49.5841359347105, 52.9961134493351, 50.94474032521248, 49.73787948489189, 51.916640773415565, 49.99866709113121, 49.20046292245388, 46.31805159151554, 39.4967108219862, 40.66668324172497, 40.63896372914314, 39.54467184841633, 39.00848262012005, 37.32480816543102, 38.58816057443619, 40.59790313243866, 39.52830232679844, 37.90152981877327, 37.53487229347229, 36.5952967107296, 36.73232115805149, 36.79787524044514, 36.75499454140663, 36.051257103681564, 38.0426200479269, 37.90564499795437, 36.744381710886955, 39.08645823597908, 41.82687118649483, 44.48876895010471, 48.32861490547657, 48.45917969942093, 55.30526094138622, 42.51232400536537, 42.307997569441795, 52.76504784822464, 49.07913163304329, 55.74123054742813, 51.29122473299503, 46.532648876309395, 51.76079973578453, 48.51182207465172, 50.55351331830025, 49.183804616332054, 45.52968129515648, 39.21316243708134, 34.47815291583538, 34.04461517930031, 34.58191774785519, 35.77597327530384, 36.356791108846664, 36.09003022313118, 36.20913103222847, 39.152156710624695, 39.66849200427532, 37.155519649386406, 36.01582780480385, 35.321456864476204, 34.121146872639656, 37.994712218642235, 46.813092827796936, 46.52745075523853, 49.73090685904026, 48.07125471532345, 45.2615562826395, 39.88530457019806, 41.24815084040165, 44.69521947205067, 46.408935114741325, 46.40147611498833, 48.15884381532669, 49.163817688822746, 46.49589724838734, 45.414908453822136, 46.71930246055126, 45.76623760163784, 43.70549418032169, 43.27554725110531, 42.53158517181873, 42.99818493425846, 46.43031656742096, 48.45290243625641, 40.77162601053715, 26.68027974665165, 9.876097552478313, 1.4609502372331917, 1.5516317775472999, 5.528995441272855, 7.5637126341462135, 8.45492821186781, 5.167891792953014, 5.468820445239544, 2.921148589812219, 0.9948638034984469, 0.1255887679872103, 2.1991495694965124, 31.53703473508358, 21.082262434065342, 30.106536895036697, 33.98185394704342, 2.1662131743505597, 0.02970339763123775, 0.06849926576251164, 0.015385454207716975, 0.03316233087389264, 0.02487749145075213, 0.023059105333231855, 0.015258225976140238, 0.04717110670753755, 0.011098856539319968, 0.04346392692241352, 0.07942016920424066, 0.0637259500217624, 0.024670504608366173, 0.03294193527835887, 0.03938056361221243, 0.05971454163955059, 0.04448435400263406, 0.08604403759818524, 0.03650686761830002, 0.07926421429147013, 0.040503006312064826, 0.07659585942747071, 0.03120238565315958, 0.030219821092032362, 0.12365415968815796, 0.08549055870389566, 0.08928143419325352, 0.009112375828408403, 0.0073454660014249384, 0.09855618729488924, 0.06345485089696012, 0.03527534776367247, 0.0439252273645252, 0.08151011643349193, 0.10055104314233176, 0.01221051583343069, 0.04914062192256097, 0.033780291269067675, 0.0283420297637349, 0.02984336668305332, 0.010357792398281163, 0.06937075493624434, 0.08626150171039626, 2.007454368285835, 19.484752155840397, 42.08514332771301, 28.901207372546196, 32.661212012171745, 37.772906720638275, 5.31718815676868, 0.033980003208853304, 0.06291630401392467, 0.15130841522477567, 0.12928135343827307, 1.3206022744998336, 7.224047435447574, 7.107966039329767, 2.2725564055144787, 0.24583597260061651, 4.118912955746055, 24.07109085470438, 45.34774325788021, 49.94636669754982, 50.94027556478977, 50.38000702857971, 52.418468445539474, 53.25950771570206, 51.90994933247566, 50.63997767865658, 48.429438695311546, 44.43426467478275, 44.57019478082657, 45.50764627754688, 47.52755329012871, 48.52494277060032, 52.131329253315926, 54.007349386811256, 51.505210250616074, 49.84561510384083, 52.53757685422897, 52.474944815039635, 51.260681971907616, 48.14891494810581, 39.682927429676056, 41.52115099132061, 41.68331488966942, 41.311132460832596, 40.404143929481506, 39.10250477492809, 40.901161059737206, 43.169270753860474, 40.29073141515255, 39.955471605062485, 37.50844091176987, 38.245441764593124, 39.72750663757324, 38.88894483447075, 38.96366022527218, 38.065715208649635, 39.92629677057266, 41.28732293844223, 40.024981275200844, 39.52538788318634, 43.306131809949875, 46.57399445772171, 48.424362167716026, 49.72348965704441, 55.111763924360275, 46.07828065752983, 43.90972562134266, 53.55511285364628, 52.247755005955696, 54.46217738091946, 53.92908118665218, 47.641102597117424, 53.76884378492832, 51.10351860523224, 51.368858367204666, 50.993590503931046, 47.05342233181, 39.80869308114052, 37.10958391427994, 34.66971963644028, 36.35036565363407, 38.09538781642914, 38.23852613568306, 38.09405788779259, 38.502782955765724, 40.96045307815075, 41.55616991221905, 38.71084079146385, 36.98235534131527, 36.76497280597687, 35.70956043899059, 38.423830792307854, 49.06954474747181, 48.760457932949066, 49.948129802942276, 48.16585823893547, 46.57679870724678, 41.25644579529762, 43.10083642601967, 46.85306288301945, 49.46496292948723, 47.14279353618622, 48.748784959316254, 48.9760659635067, 46.48478664457798, 45.30996188521385, 47.455588951706886, 47.01033644378185, 45.3566537797451, 45.23447893559933, 44.35861073434353, 45.299219861626625, 50.295123383402824, 48.4563260525465, 42.10392951965332, 29.421036578714848, 12.768075820058584, 1.9771537254564464, 2.725848569534719, 6.304280664771795, 7.975666578859091, 6.769370958209038, 8.517074827104807, 7.156566856428981, 0.8651267120148987, 0.9406528249382973, 0.21662766725057736, 2.0593555457890034, 38.27441520988941, 25.781622268259525, 31.682099550962448, 41.63559705018997, 4.578897273167968, 0.12331753634498455, 0.02365922264289111, 0.05340927353245206, 0.006940539096831344, 0.03913717628165614, 0.04458759416593239, 0.09959388786228374, 0.031028489320306107, 0.016181823193619493, 0.023678722573095, 0.04964797633874696, 0.04619441067916341, 0.02087161577946972, 0.05252607697912026, 0.032474029721925035, 0.05591258959611878, 0.034795274696080014, 0.039348669815808535, 0.034224930495838635, 0.2644169161794707, 0.10691598363337107, 0.14516255672788247, 0.12684899411397055, 0.1997110788943246, 0.19582875596825033, 0.21881069464143366, 0.1898805907694623, 0.14478082564892247, 0.12722747458610684, 0.16360403591534123, 0.14343948278110474, 0.16284594690660015, 0.11838747159345075, 0.25136613054201007, 0.1922923035454005, 0.1677264436148107, 0.13363712205318734, 0.07755427635856904, 0.22368093486875296, 0.14894042978994548, 0.11500094784423709, 0.158059153764043, 0.13740755879553035, 1.5702069620601833, 22.537234760820866, 48.96983049809933, 35.3202523291111, 36.878541111946106, 45.93036599457264, 9.567828644067049, 0.1428030466195196, 0.3257600823417306, 0.3151352587155998, 0.2416538368561305, 0.7949690578971058, 7.606339221820235, 11.41224967315793, 1.9100547884590924, 0.20498515135841444, 3.689752584323287, 23.516398519277573, 46.207245737314224, 50.393044129014015, 51.87407545745373, 50.73327787220478, 53.12167011201382, 53.69644246995449, 53.04551459848881, 51.433960273861885, 50.571372359991074, 46.268224865198135, 46.92005328834057, 48.877354860305786, 49.9536395072937, 50.3201450407505, 53.60882297158241, 55.213970839977264, 52.65444338321686, 53.100110068917274, 54.46139082312584, 55.54503947496414, 52.106493785977364, 49.71219666302204, 42.06490181386471, 43.73756445944309, 44.345417842268944, 43.55108946561813, 42.301480919122696, 41.27544477581978, 42.4775330722332, 45.08866935968399, 42.73099847137928, 42.272530272603035, 40.46874426305294, 39.86027151346207, 40.312500447034836, 41.022275760769844, 40.63151612877846, 38.8926762342453, 41.435712575912476, 42.34874278306961, 41.44429251551628, 42.96253904700279, 45.547977313399315, 48.21199916303158, 51.1651436984539, 50.652220621705055, 56.382092759013176, 46.598419547080994, 45.84708206355572, 53.781941682100296, 54.63588505983353, 56.03690408170223, 57.32580631971359, 50.25384619832039, 55.45044735074043, 52.8355872631073, 53.247234374284744, 53.64489063620567, 48.93466338515282, 41.39778681099415, 39.202158227562904, 36.783352419734, 37.74543039500713, 40.98584711551666, 40.73509097099304, 39.862319603562355, 40.292749106884, 43.85583311319351, 42.79113404452801, 40.50140731036663, 39.192297756671906, 38.92584465444088, 37.50140368938446, 42.03387647867203, 50.84334656596184, 50.48670910298824, 52.61558286845684, 51.127388924360275, 48.35404314100742, 42.830765917897224, 45.58640465140343, 48.66366572678089, 50.9217743575573, 49.38796766102314, 51.24190717935562, 50.28576448559761, 47.696807608008385, 45.80005198717117, 48.857219740748405, 49.34560373425484, 47.401118874549866, 47.48699426651001, 46.23811528086662, 47.47712999582291, 50.42319931089878, 49.85539957880974, 42.81911954283714, 27.089242301881313, 12.102273646742105, 2.569473423063755, 2.574842059984803, 12.906283903867006, 14.595786295831203, 18.69626596570015, 15.097973998636007, 14.223373029381037, 7.314390912652016, 4.32872487232089, 0.291646997211501, 3.4827719908207655, 42.775311693549156, 29.066091924905777, 38.631121069192886, 46.013395339250565, 4.794550901278853, 0.2645612193737179, 0.12494296592194587, 0.14025761367520317, 0.0909267904353328, 0.18280887336004525, 0.19318066915730014, 0.15301725477911532, 0.18036174529697746, 0.1026097682188265, 0.16120084299473092, 0.19718983996426687, 0.14727003348525614, 0.1363100708113052, 0.08258205227321014, 0.17747761099599302, 0.11803081768448465, 0.10031276920926757, 0.12610637146281078, 0.1284681525430642], [0.03462047294306103, 0.0059056299323856365, 0.007918676747067366, 0.04981173864507582, 0.06776170455850661, 0.07821578969014809, 0.05305870152369607, 0.05426379349955823, 0.02197558085754281, 0.051237949810456485, 0.016512748698005453, 0.0328198482748121, 0.037174819080973975, 0.04761205374961719, 0.023374019001494162, 0.07403852243442088, 0.04065484972670674, 0.07182868124800734, 0.05150805816811044, 0.07262749189976603, 0.05885760227101855, 0.025404900552530307, 0.02540387082262896, 0.022396996428142302, 0.0021305197469700943, 2.724349549971521, 30.04784904420376, 34.0709325671196, 26.897046715021133, 40.15307240188122, 12.896251492202282, 0.24692488135769963, 0.07042952507617883, 0.10021349953603931, 0.32069863518700004, 0.9758479020092636, 3.148151971399784, 5.659422967582941, 2.8887935634702444, 0.975473978323862, 0.46468609012663364, 5.0548383593559265, 21.31515383720398, 38.6119244992733, 48.0481481552124, 50.20539119839668, 52.15670049190521, 49.92127284407616, 51.14055521786213, 46.43351599574089, 45.04135049879551, 45.1316374540329, 45.50182119011879, 47.032565250992775, 48.55244569480419, 50.92696487903595, 52.20379896461964, 51.3288389146328, 50.89043743908405, 50.61868742108345, 51.47293858230114, 50.800572261214256, 51.20162174105644, 44.98348720371723, 37.743785083293915, 38.25098566710949, 39.80167865753174, 37.18039691448212, 38.49374704062939, 39.624623358249664, 40.9054434299469, 40.133081674575806, 42.21978150308132, 38.73928606510162, 39.19796325266361, 36.693787425756454, 37.88170248270035, 34.28481549024582, 37.60103054344654, 36.744526103138924, 38.74076798558235, 38.33779200911522, 38.61645765602589, 41.618870347738266, 44.0255282074213, 47.55133621394634, 49.59158353507519, 49.49407696723938, 54.669102877378464, 42.81501956284046, 44.76380959153175, 51.342385187745094, 52.702187821269035, 52.23686099052429, 46.5526320040226, 49.29439768195152, 49.34270828962326, 51.08818642795086, 48.3798361569643, 47.98184931278229, 43.766910284757614, 38.40490780770779, 33.92926096916199, 35.16859486699104, 35.20562008023262, 36.054927706718445, 35.89423052966595, 36.85856558382511, 38.55533413589001, 43.768335208296776, 45.665535405278206, 44.08300392329693, 39.70468506217003, 34.73889112472534, 36.359861344099045, 35.20592786371708, 43.83831985294819, 47.65879064798355, 48.128012269735336, 45.986872762441635, 47.17234455049038, 43.09089235961437, 36.56104534864426, 39.12439540028572, 43.03536593914032, 46.33246421813965, 47.89200693368912, 46.80349834263325, 48.33912134170532, 46.437756568193436, 45.973151698708534, 44.50360335409641, 42.25750207901001, 40.803479701280594, 42.72817902266979, 45.56390605866909, 45.2760449051857, 45.055778324604034, 30.326366499066353, 13.565098252147436, 1.694953318219632, 0.8619196841027588, 3.7271178793162107, 3.1308377254754305, 7.638646988198161, 4.999490054324269, 7.021395284682512, 6.042491812258959, 0.6611040816642344, 0.1494013925548643, 0.1375561219174415, 10.344713106751442, 34.40865844488144, 22.061046212911606, 41.52237072587013, 13.842762652784586, 0.21758288552518934, 0.09708061959827319, 0.06464507765485905, 0.00921581451621023, 0.0070858047638466815, 0.01069300102244597, 0.007076836373016704, 0.036474075823207386, 0.004224965550747584, 0.07931371554150246, 0.03915923662134446, 0.04592187178786844, 0.03434401180129498, 0.05549726149183698, 0.025654575729276985, 0.026519546991039533, 0.05911476015171502, 0.01259092403415707, 0.03512008304824121, 0.0448852213594364, 0.023821587856218684, 0.035095666389679536, 0.011543804685061332, 0.010496931172383483, 0.022768933013139758, 0.0875775670283474, 0.10684907902032137, 0.0757670882740058, 0.044594637147383764, 0.04881244050920941, 0.026242675812682137, 0.037006837665103376, 0.04151054970861878, 0.053644827494281344, 0.023106259541236795, 0.043963919233647175, 0.03990162549598608, 0.05003452766686678, 0.025299747503595427, 0.10963023290969431, 0.05289504682878032, 0.07383135933196172, 0.02865183003450511, 0.08369362622033805, 0.025012241349031683, 4.697628077119589, 34.94599901139736, 35.990038588643074, 27.02290166169405, 48.39348502457142, 14.449792429804802, 0.0907953263958916, 0.1831534376833588, 0.3204170346725732, 0.45048396626953036, 2.8963138349354267, 6.263506477698684, 7.699705436825752, 4.453589022159576, 2.5277051143348217, 1.7310815420933068, 7.6667963527143, 27.023883908987045, 42.915634363889694, 49.716961607337, 50.232901722192764, 51.85504987835884, 52.37857438623905, 51.64966709911823, 48.29610385000706, 46.85934774577618, 45.93832276761532, 45.37632152438164, 47.270208299160004, 50.51117978990078, 52.25685931742191, 51.02083884179592, 52.93987266719341, 51.80624529719353, 51.57566227018833, 52.46249668300152, 52.95198641717434, 52.0680246502161, 47.186259403824806, 39.49800655245781, 40.06022818386555, 40.029750019311905, 39.60077963769436, 41.18085265159607, 40.37130609154701, 42.289458364248276, 42.79187500476837, 42.93938688933849, 40.40428452193737, 40.75782895088196, 37.78016433119774, 40.149846374988556, 36.679055616259575, 39.54330772161484, 39.13960978388786, 40.35188913345337, 39.88989472389221, 41.25207982957363, 42.232818603515625, 47.39518739283085, 48.339345529675484, 50.321079790592194, 50.50559028983116, 54.66292820870876, 46.12656466662884, 43.99237118661404, 51.69076569378376, 52.88420185446739, 53.653029799461365, 47.61067382991314, 48.954684510827065, 51.507706716656685, 52.01755955815315, 50.018642619252205, 49.790635854005814, 44.19229745864868, 38.69874984025955, 37.219910994172096, 36.41917996108532, 35.528986528515816, 38.16346496343613, 38.31588238477707, 37.47152969241142, 40.97212605178356, 44.92052838206291, 46.49122729897499, 46.53049059212208, 41.08904957771301, 36.04289375245571, 38.63062709569931, 36.47825539112091, 45.62407962977886, 49.36536647379398, 48.736557215452194, 48.54775674641132, 47.59444110095501, 44.53295297920704, 38.61701242625713, 41.3265710324049, 45.28885021805763, 48.55314865708351, 48.78378868103027, 49.235763028264046, 48.60367454588413, 47.57001221179962, 46.02211207151413, 47.42409244179726, 42.83926606178284, 41.35016396641731, 42.62510575354099, 47.13661506772041, 46.275881454348564, 48.24041783809662, 31.5754696726799, 16.882078014314175, 3.0306157283484936, 3.4229945484548807, 5.419106762856245, 7.152432203292847, 9.257822278887033, 5.7582129165530205, 10.370810106396675, 5.731713613495231, 0.617691648658365, 0.30488625867292285, 0.2657702373107895, 11.564277615398169, 42.66753047704697, 20.587253496050835, 43.21540027856827, 19.535677023231983, 0.5548456334508955, 0.10219363117357716, 0.004794006354131852, 0.020493096344580408, 0.010797503764479188, 0.044385711444192566, 0.03526950706145726, 0.02767451987892855, 0.029004541283939034, 0.05683950235834345, 0.048084126465255395, 0.015325837484851945, 0.05726201074139681, 0.05469103307405021, 0.04535943517112173, 0.06492257409263402, 0.028259820210223552, 0.06498734874185175, 0.0969539572542999, 0.027678494079736993, 0.23548798490082845, 0.07392618354060687, 0.08879508255631663, 0.182121911784634, 0.20211632014252245, 0.1610160482232459, 0.16546511964406818, 0.15262833971064538, 0.09247335940017365, 0.11582331426325254, 0.12639951979508623, 0.11422634604969062, 0.11426239216234535, 0.15843422035686672, 0.15939064091071486, 0.15785326715558767, 0.16577279922785237, 0.20426506031071767, 0.10673623546608724, 0.1934859887114726, 0.16841791744809598, 0.13868080219253898, 0.09550659859087318, 0.1623646789812483, 0.13513574085664004, 4.894335446879268, 41.311003267765045, 45.45621983706951, 36.22766263782978, 53.74650098383427, 20.325901620090008, 0.4036600288236514, 0.33160039864014834, 0.4517202061833814, 0.8757730876095593, 3.8934112060815096, 9.182566367089748, 14.952250868082047, 9.81929250061512, 2.4907262111082673, 1.0144462902098894, 6.861658506095409, 25.42934127151966, 41.086066737771034, 48.779175728559494, 49.60490942001343, 51.884878277778625, 53.02823692560196, 54.75878186523914, 51.18354231119156, 48.591458201408386, 49.2528735101223, 47.97873727977276, 50.28038017451763, 52.34066382050514, 55.43833740055561, 53.41780722141266, 53.97326521575451, 54.05205778777599, 53.27351376414299, 52.294781282544136, 56.22137278318405, 54.06692638993263, 49.34956692159176, 40.8402731269598, 42.882036566734314, 43.2497314363718, 41.61291226744652, 42.57838346064091, 42.704677283763885, 45.94757907092571, 44.56817328929901, 45.646308436989784, 42.454924285411835, 42.73899704217911, 39.51295115053654, 43.082851991057396, 36.873567178845406, 41.33477099239826, 42.04751014709473, 42.081183940172195, 42.289424166083336, 42.35778629779816, 45.33353582024574, 48.75900261104107, 52.5189920514822, 53.34104374051094, 53.60869757831097, 55.44524922966957, 48.49607191979885, 46.67417988181114, 53.578109219670296, 53.29478122293949, 56.782914251089096, 50.45758366584778, 50.697050616145134, 52.185506746172905, 54.947399944067, 52.85643294453621, 51.0264777392149, 46.52098350226879, 40.54550014436245, 39.2218791693449, 37.81215861439705, 37.73522034287453, 40.157666355371475, 39.55993942916393, 40.352459102869034, 42.63639874756336, 46.95180058479309, 48.38008314371109, 49.614982679486275, 43.568712919950485, 37.89283588528633, 40.181179493665695, 37.880026772618294, 47.717071920633316, 51.677196621894836, 51.38364717364311, 50.45547857880592, 50.5729378759861, 47.660903334617615, 39.65894311666489, 43.90306457877159, 46.341207548975945, 50.127651169896126, 52.380500882864, 50.611144825816154, 49.86261919140816, 49.7933679074049, 47.25761577486992, 49.111885875463486, 44.45856437087059, 43.73256392776966, 45.05224071443081, 51.004685908555984, 47.85712480545044, 49.22419264912605, 31.56106274574995, 15.499181170016527, 2.5808502500876784, 4.136760598048568, 7.641658801585436, 9.722414799034595, 16.484189964830875, 13.76305527985096, 16.76793973892927, 15.136717669665813, 5.131715834140778, 1.3866771664470434, 0.34312063828110695, 14.826166033744812, 49.38806265592575, 27.02812258154154, 51.774471402168274, 21.889491118490696, 0.7601560384500772, 0.32217467785812914, 0.1063123058702331, 0.06870118930237368, 0.05510013084858656, 0.09386724632349797, 0.1983453638968058, 0.07565140971564688, 0.12770728790201247, 0.16497301636263728, 0.13447751523926854, 0.14459635742241517, 0.10619897249853238, 0.14098144514719024, 0.1827575612696819, 0.4032472462859005, 0.15047780354507267, 0.09622484911233187, 0.18435071484418586, 0.1312290903297253], [0.013277364250825485, 0.03857996067381464, 0.06143065795185976, 0.027472611182020046, 0.02270928474899847, 0.037827730920980684, 0.060756914026569575, 0.09019261342473328, 0.03951191632950213, 0.0511313588503981, 0.018836372255464084, 0.018365225369052496, 0.024289306020364165, 0.054019753079046495, 0.038420339551521465, 0.03868047344440129, 0.01964550989214331, 0.1227714640845079, 0.05229039685218595, 0.07003073944360949, 0.024545259766455274, 0.03501116545521654, 0.044806857986259274, 0.13771568366792053, 0.030695326240675058, 0.10333179627195932, 10.78606702387333, 34.82375577092171, 23.200223185122013, 34.851992055773735, 23.585723899304867, 0.222916136845015, 0.07353516077273525, 0.16472683113534003, 0.28764376358594745, 1.9467478757724166, 7.51317392103374, 8.597051985561848, 2.312379931099713, 7.92984863743186, 2.8335958253592253, 0.8359300286974758, 8.479358050972223, 24.73913110792637, 41.71677969396114, 51.986477226018906, 51.95720739662647, 53.17470006644726, 50.38858696818352, 46.33060231804848, 44.90075424313545, 44.982924833893776, 45.1198922842741, 49.52150769531727, 50.75422614812851, 53.09034079313278, 51.51350140571594, 52.26700097322464, 53.442954272031784, 53.115810826420784, 52.17908889055252, 50.42900159955025, 47.71077185869217, 42.2424852848053, 37.28989563882351, 38.88957940042019, 39.90936107933521, 38.44271957874298, 38.37744288146496, 40.52172861993313, 44.063757956027985, 43.27057331800461, 41.239563301205635, 39.72260110080242, 39.403676614165306, 37.166812643408775, 36.66910395026207, 37.016659900546074, 37.35921151936054, 35.99359139800072, 37.609051913022995, 37.81077168881893, 38.075739070773125, 42.17918448150158, 45.16230560839176, 46.36728934943676, 49.19317491352558, 48.44866566359997, 53.81531909108162, 42.592400908470154, 45.72990395128727, 48.29856991767883, 49.182828068733215, 46.922648549079895, 47.688182070851326, 50.19158273935318, 49.861657842993736, 50.460152328014374, 49.841617718338966, 44.91004854440689, 41.43944017589092, 37.04576253890991, 34.07209150493145, 35.37617772817612, 34.507783725857735, 35.503740683197975, 36.51247635483742, 36.284974962472916, 41.18931859731674, 46.60070322453976, 51.947073340415955, 48.11181753873825, 44.92026999592781, 35.5527276545763, 34.780757278203964, 34.48661506175995, 38.06824207305908, 44.15785610675812, 46.06504216790199, 45.727688670158386, 46.160512045025826, 46.667279452085495, 43.84912267327309, 37.45164155960083, 37.45713606476784, 40.21352715790272, 43.73372286558151, 46.52525447309017, 45.82768030464649, 47.424366027116776, 45.86040794849396, 43.152430057525635, 38.83835434913635, 40.81099949777126, 43.829937502741814, 46.09563432633877, 48.15879821777344, 42.03637674450874, 20.44703722000122, 5.499048298224807, 0.9245482203550637, 1.7157729947939515, 5.306377736851573, 7.105715610086918, 4.74603415466845, 2.5675673503428698, 6.247444739565253, 4.786198474466801, 0.23846052383305505, 0.053048148183734156, 0.3151206235634163, 23.120328672230244, 27.23035342991352, 26.162054054439068, 35.99841333925724, 5.426251804456115, 0.0356739144626772, 0.027947865855821874, 0.07793302400386892, 0.10850607213797048, 0.06417900149244815, 0.06550519712618552, 0.03201340834493749, 0.08217234964831732, 0.04596849721565377, 0.03035063018614892, 0.058511234528850764, 0.02811125337757403, 0.10768024731078185, 0.03660142465378158, 0.007038652875053231, 0.027287129923934117, 0.019248295757279266, 0.05398971465183422, 0.047677655893494375, 0.02083328385197092, 0.03114988241577521, 0.026713331026257947, 0.054004973208066076, 0.027558611254789867, 0.02662638285983121, 0.02506802116840845, 0.0484959553432418, 0.06200455332873389, 0.04718492549727671, 0.024520538827346172, 0.036381555983098224, 0.01378198663587682, 0.038910676521481946, 0.049338163080392405, 0.016247503263002727, 0.028728093129757326, 0.032135024084709585, 0.02741622280154843, 0.011339013672113651, 0.029645762442669366, 0.04115584022656549, 0.010737386091932422, 0.03913736924005207, 0.12003094278043136, 0.012607873759407084, 0.3215850266860798, 16.14375863224268, 42.071467861533165, 24.230756387114525, 40.34174747765064, 25.804098062217236, 0.27222730801440775, 0.315743790124543, 0.8123415475711226, 1.4963376196101308, 3.516437471844256, 9.030817709863186, 9.260317794978619, 6.256220368668437, 5.188897540792823, 3.2060513645410538, 3.0601054709404707, 12.302678693085909, 27.468997724354267, 44.29933771491051, 52.508603408932686, 53.56605626642704, 55.00789649784565, 51.150047108531, 49.33997243642807, 46.012699976563454, 45.77441096305847, 47.045651748776436, 51.1322108656168, 51.98396176099777, 53.43563586473465, 53.35805542767048, 54.152182415127754, 54.52336169779301, 53.26030567288399, 53.89489062130451, 52.53032684326172, 50.60815058648586, 44.380174577236176, 40.142368376255035, 40.45029245316982, 39.769897162914276, 39.57909420132637, 39.875721484422684, 42.02664166688919, 45.205494090914726, 45.067493095993996, 42.96752817928791, 41.559091955423355, 41.271530985832214, 39.923880100250244, 39.24551010131836, 38.80876153707504, 39.45239380002022, 36.782900243997574, 40.30497685074806, 39.032482132315636, 40.59314578771591, 44.660838916897774, 46.15128614008427, 48.373433500528336, 50.94331920146942, 51.73610106110573, 55.15863820910454, 45.86206465959549, 46.534381583333015, 48.943064734339714, 50.03718562424183, 48.33634369075298, 49.09464620053768, 51.08352407813072, 50.31446434557438, 52.717444002628326, 50.05703575909138, 47.43376672267914, 44.43914361298084, 37.94489309191704, 35.45647121965885, 37.13085137307644, 36.745023876428604, 36.784093379974365, 38.06728832423687, 38.196538388729095, 42.325465232133865, 49.390764310956, 51.03443831205368, 49.29796189069748, 45.80079294741154, 37.183543145656586, 36.638599187135696, 36.797753646969795, 39.99027393758297, 46.66021563112736, 47.566979974508286, 48.25155884027481, 47.31829471886158, 48.261107727885246, 44.1232817620039, 40.01092582941055, 39.57441285252571, 43.87847229838371, 46.745331063866615, 47.03794576227665, 47.597602531313896, 48.720522075891495, 47.16590389609337, 45.97121000289917, 41.42050959169865, 42.537341862916946, 45.85716672241688, 47.492762356996536, 48.48013937473297, 42.94627971947193, 21.434875912964344, 9.004468973726034, 2.195936841890216, 4.854637552052736, 6.230184165760875, 7.609013803303242, 6.618113424628973, 6.059192391112447, 8.269354719668627, 1.3142840447835624, 0.1846050488529727, 0.13249229989014566, 0.23182318545877934, 25.83886429667473, 32.61668600142002, 26.9092820584774, 41.85597002506256, 8.010328318923712, 0.09414088359335437, 0.030480094137601554, 0.07441725523676723, 0.03562351150321774, 0.0550111287884647, 0.04966105298080947, 0.051582577216322534, 0.06061359046725556, 0.07461079250788316, 0.03005568029038841, 0.07216560887172818, 0.02715066195378313, 0.026755306898849085, 0.04465258774871472, 0.03547589833033271, 0.010150953057745937, 0.0365938733011717, 0.0645986340532545, 0.05358284332032781, 0.06629509458434768, 0.11815460791694932, 0.0866876206418965, 0.10887513475609012, 0.11001339633367024, 0.15048492816276848, 0.10228837374597788, 0.18163369735702872, 0.21319363120710477, 0.21169130166526884, 0.10613470250973478, 0.14354688639286906, 0.11713998814229853, 0.09087143364013173, 0.2410522074205801, 0.11966605103225447, 0.09338555537397042, 0.15880032180575654, 0.2025658093043603, 0.12861748749855906, 0.20300281554227695, 0.15039517282275483, 0.14517575211357325, 0.11676955997245386, 0.24077091860817745, 0.10456403600983322, 0.251514381961897, 16.934959776699543, 50.09514011442661, 31.26518402248621, 44.87330071628094, 34.47512447834015, 0.3798941447166726, 0.5384092591702938, 1.1531858704984188, 0.9820895420853049, 8.580378480255604, 17.226172350347042, 17.817886099219322, 9.213984981179237, 14.024318810552359, 4.738558055832982, 1.6837354889139533, 11.296546831727028, 28.366030789911747, 44.231857135891914, 53.17487485706806, 54.302008375525475, 58.076463639736176, 54.54660505056381, 50.67804403603077, 49.476271122694016, 47.97795072197914, 49.05369579792023, 53.98279510438442, 55.25839805603027, 55.35940423607826, 54.32417258620262, 54.654139280319214, 57.44371019303799, 56.00044123828411, 56.622213274240494, 54.3823778629303, 53.10126520693302, 45.93374401330948, 41.226408407092094, 43.38379964232445, 42.953803315758705, 42.52986766397953, 41.10977366566658, 43.96695055067539, 48.63729514181614, 47.997838854789734, 45.655192360281944, 44.05077405273914, 43.42765308916569, 41.820172145962715, 40.62930464744568, 41.44985921680927, 41.96149416267872, 38.13469670712948, 42.23389774560928, 42.41864003241062, 42.91868560016155, 47.29366064071655, 48.94560679793358, 50.45919097959995, 53.818214535713196, 55.40233813226223, 56.95710830390453, 48.388963267207146, 48.41462329030037, 50.43131187558174, 51.61467857658863, 51.14175595343113, 49.943627044558525, 52.89926044642925, 52.82385729253292, 55.134042128920555, 53.29579196870327, 48.46920736134052, 47.13569551706314, 39.450246915221214, 38.59853781759739, 38.5645904392004, 37.968087047338486, 38.84863659739494, 40.38912333548069, 40.674784407019615, 45.9572609513998, 52.05506734549999, 54.30064804852009, 52.70788371562958, 49.87407177686691, 39.12027262151241, 38.215009197592735, 38.17099615931511, 40.77986016869545, 48.39263767004013, 49.765845984220505, 48.48547428846359, 48.7254998087883, 51.15152142941952, 47.00731560587883, 41.62384048104286, 39.875071719288826, 44.52911898493767, 48.93679887056351, 50.90444728732109, 49.750582203269005, 50.82334823906422, 49.13164101541042, 48.238373547792435, 44.454392194747925, 45.427812561392784, 48.189443573355675, 49.406613260507584, 50.56315720081329, 44.196477234363556, 21.533036045730114, 7.620212277397513, 2.651244322769344, 5.244406862184405, 12.724474109709263, 14.512490015476942, 12.673553042113781, 11.426753494888544, 14.164776373654604, 13.481772523373365, 1.2779817427508533, 0.39858071075286716, 0.5847071623429656, 31.504787765443325, 37.76662565767765, 33.23923699557781, 48.00682157278061, 10.23539012297988, 0.18030406557954848, 0.1885898326872848, 0.1884681946830824, 0.18354974454268813, 0.13043879211181775, 0.14883237308822572, 0.17055665346561, 0.11512165816384368, 0.1657262071967125, 0.1739663173793815, 0.1571568357758224, 0.11642967860097997, 0.19124597922200337, 0.11428493860876188, 0.0768180213344749, 0.17001577623886988, 0.09422498376807198, 0.18949256627820432, 0.19530491845216602, 0.08979227670351975], [0.07129553720005788, 0.04740189608128276, 0.03172925113176461, 0.019578592291509267, 0.044484632308012806, 0.04209467559121549, 0.0347568574215984, 0.08014565566554666, 0.043646821795846336, 0.04684219427872449, 0.021111381429363973, 0.021812720260641072, 0.083871622919105, 0.04523637595411856, 0.0592177220096346, 0.07503973902203143, 0.053189954051049426, 0.03483947701170109, 0.006068930251785787, 0.015938780961732846, 0.08772107612458058, 0.011396480022085598, 0.03866411650960799, 0.05314061236276757, 0.023871437915659044, 0.03148392679577228, 0.4751284938538447, 26.732874624431133, 27.8541811555624, 29.406707547605038, 35.76843447983265, 1.7249485524371266, 0.1445888914167881, 0.7502186810597777, 1.999591402709484, 4.529019249603152, 5.10456676594913, 6.563241994008422, 2.1946707973256707, 14.793135356158018, 1.8683489388786256, 1.7665084660984576, 2.20766918733716, 12.154130414128304, 29.173998534679413, 53.3612472563982, 53.4458839148283, 52.902691662311554, 50.05426950752735, 47.57705323398113, 46.240064576268196, 46.88959412276745, 45.41160263121128, 48.47800388932228, 49.30642403662205, 51.289218440651894, 52.52385579049587, 50.777674689888954, 51.6378041356802, 47.722817212343216, 46.9987128674984, 44.376701563596725, 40.63802517950535, 39.28963713347912, 38.84412623941898, 38.27051281929016, 36.04928880929947, 38.5312320291996, 39.254226833581924, 44.02221478521824, 45.28066165745258, 45.90730883181095, 45.60617499053478, 42.49855354428291, 39.303578585386276, 36.8634445220232, 36.387352868914604, 38.55520874261856, 36.93151406943798, 36.327034905552864, 39.03011865913868, 38.08953233063221, 40.515698343515396, 42.717068418860435, 45.264018550515175, 45.28372809290886, 49.716942608356476, 49.57608416676521, 53.10129180550575, 43.62350977957249, 42.17862591147423, 51.702431067824364, 49.549485594034195, 48.819848746061325, 48.495938926935196, 50.356410294771194, 48.787922859191895, 50.09362779557705, 45.41613578796387, 44.82965245842934, 41.98213845491409, 36.590645760297775, 36.176608577370644, 36.57988093793392, 34.25717197358608, 35.16586281359196, 35.35222761332989, 35.25191679596901, 43.150089383125305, 47.45292529463768, 50.56576386094093, 49.202404618263245, 47.66732878983021, 40.90519644320011, 35.00297695398331, 35.606977343559265, 35.10085590183735, 41.9999822974205, 44.94853287935257, 46.76455803215504, 48.76335717737675, 45.62268130481243, 45.99722720682621, 43.37724879384041, 41.73186108469963, 38.33469897508621, 36.47107757627964, 40.041396394371986, 43.62925507128239, 43.1820684671402, 43.57556015253067, 40.20743228495121, 38.85797269642353, 41.45797558128834, 46.28747843205929, 45.77568009495735, 45.93912452459335, 33.26317951083183, 12.083464656025171, 3.293562331236899, 0.5713241023477167, 4.89734536036849, 4.038476021960378, 4.802848706021905, 8.279641717672348, 3.56914515607059, 8.80046647042036, 0.9295822377316654, 0.20124411850702018, 0.09158267828752287, 4.550235886126757, 38.04665543138981, 21.750956252217293, 33.83677773177624, 22.712319865822792, 0.7178822380956262, 0.020913302214466967, 0.03103236147580901, 0.02696050887607271, 0.03478386046481319, 0.04860912173171528, 0.019029347349714953, 0.044611862394958735, 0.0034916044387500733, 0.10276050583343022, 0.07301649602595717, 0.0028174430553917773, 0.028352625777188223, 0.07750545788439922, 0.06067522212106269, 0.028857915167463943, 0.06922265194589272, 0.10862158742384054, 0.0429211906157434, 0.031954752703313716, 0.05726001807488501, 0.08263435141998343, 0.061093633848940954, 0.005648686810673098, 0.03323876837384887, 0.05916354522923939, 0.052922832837793976, 0.017415799557056744, 0.04141481265833136, 0.002740054910645995, 0.01913399017212214, 0.13673069042852148, 0.02837572141288547, 0.07993129373062402, 0.018217393262602855, 0.08478914009174332, 0.018335363201913424, 0.05374273532652296, 0.10018419212428853, 0.006388465180862113, 0.022704633338435087, 0.038237184926401824, 0.07229617491248064, 0.025140838843071833, 0.12423713153111748, 0.056778983926051296, 0.034893416304839775, 1.9326819805428386, 32.997607961297035, 30.233681872487068, 33.052959591150284, 40.87379112839699, 1.342279992531985, 0.14873543375870213, 1.2795710074715316, 1.7337243002839386, 1.3556555123068392, 7.036133268848062, 9.833997711539268, 6.0361437778919935, 24.49244074523449, 4.634448867291212, 1.7012848472222686, 3.714720094576478, 14.21941364184022, 32.39082992076874, 52.3362522572279, 54.3738055229187, 52.86734215915203, 51.41791373491287, 49.722934886813164, 47.87254437804222, 47.98161372542381, 48.23849134147167, 51.33227773010731, 52.03554779291153, 53.32086302340031, 54.62556101381779, 53.00005003809929, 53.88848036527634, 49.97427240014076, 49.65417377650738, 46.941180154681206, 43.252349495887756, 40.35437040030956, 40.78257702291012, 40.732925087213516, 38.81596975028515, 40.31622804701328, 40.36656394600868, 45.37298150360584, 47.111756801605225, 48.073352202773094, 46.02001078426838, 42.83267341554165, 41.20811238884926, 39.397338554263115, 38.43062862753868, 39.395305663347244, 38.486413434147835, 38.30122657120228, 39.30195227265358, 40.79410560429096, 42.60155461728573, 44.511263743042946, 47.26762443780899, 47.134232595562935, 49.938850700855255, 50.996204763650894, 54.699923023581505, 46.3077237457037, 44.61268030107021, 52.43758901953697, 50.55567920207977, 48.652992099523544, 49.009086191654205, 51.60602264106274, 49.623900800943375, 52.41176180541515, 48.34531120955944, 46.504290997982025, 43.36491085588932, 38.22130165994167, 36.324120461940765, 36.1996391415596, 36.796081736683846, 38.10509629547596, 36.59798316657543, 36.480634063482285, 43.75342100858688, 48.91285255551338, 52.22209878265858, 51.23771220445633, 48.77881474792957, 41.351486295461655, 36.3041715323925, 37.69309960305691, 36.09753482043743, 43.96665796637535, 48.17599609494209, 48.481324911117554, 49.257345870137215, 48.09629537165165, 48.593076914548874, 45.510469526052475, 42.23422832787037, 38.13460171222687, 39.49618645012379, 44.499370381236076, 44.54118713736534, 45.324575901031494, 44.51901912689209, 42.61995702981949, 39.133849292993546, 41.95619344711304, 46.78677164018154, 48.00646439194679, 47.137397825717926, 35.25905281305313, 13.769209049642086, 3.768317406065762, 2.8532006358727813, 3.3045209432020783, 4.2996687814593315, 8.650593012571335, 7.302612019702792, 6.592574045062065, 7.43039583787322, 1.0250698076561093, 0.3165047289803624, 0.1234471524367109, 3.952262685634196, 44.23048920929432, 21.181076131761074, 33.397965878248215, 29.932143352925777, 1.5755760739557445, 0.10281786642735824, 0.029879134490329307, 0.04674947776948102, 0.013491720619640546, 0.006696714362988132, 0.057937506135203876, 0.06716778603731655, 0.04456611270143185, 0.06469854197348468, 0.11675165937049314, 0.0590366157121025, 0.03843379839963745, 0.03387579454283696, 0.020511444090516306, 0.060525805529323407, 0.037940800830256194, 0.029432012779579964, 0.0353665020520566, 0.09473705082200468, 0.04485783239942975, 0.18373091763351113, 0.2587560215033591, 0.12356200721114874, 0.13556323276134208, 0.1646537592750974, 0.19098772667348385, 0.10114954071468674, 0.13415668479865417, 0.07653946362552233, 0.1800883380929008, 0.24237915262347087, 0.238970898790285, 0.2251826410065405, 0.12666555005125701, 0.15896387631073594, 0.14755194570170715, 0.15568555769277737, 0.2180938987294212, 0.09380037139635533, 0.12462572747608647, 0.12297127250349149, 0.14684169553220272, 0.19533044833224267, 0.25278063432779163, 0.14857469941489398, 0.07344138299231417, 1.8047756189480424, 36.995179653167725, 39.415106400847435, 37.71500542759895, 45.33366501331329, 2.697628433816135, 0.390545359114185, 2.9673512605950236, 5.02359121106565, 8.234922867268324, 14.756961297243834, 13.809752874076366, 8.77807142212987, 21.715055778622627, 4.329991154372692, 3.638305007480085, 2.972343717701733, 15.034422408789396, 32.12720386683941, 52.31448322534561, 55.78411504626274, 56.15981608629227, 54.240717664361, 52.894176319241524, 51.81094564497471, 51.22119449079037, 51.140380427241325, 53.422545567154884, 52.55455434322357, 54.72051791846752, 56.42740912735462, 54.796806424856186, 56.169710755348206, 51.03976562619209, 50.34001797437668, 48.030999675393105, 44.64077599346638, 42.57306754589081, 42.894427701830864, 42.22304932773113, 40.610024482011795, 42.32211381196976, 41.3294892758131, 47.58026786148548, 49.714385345578194, 49.82680991292, 48.51833492517471, 45.1556521654129, 44.13217708468437, 41.560019105672836, 38.97478602826595, 43.01484704017639, 40.556910932064056, 40.60152813792229, 41.7436670511961, 42.80222184956074, 45.41199401021004, 47.858853712677956, 49.719393476843834, 49.11714479327202, 51.93257711827755, 52.92044810950756, 56.16883300244808, 50.5703654140234, 44.6502298861742, 53.51043105125427, 52.18983471393585, 52.08809517323971, 49.97487656772137, 52.93998286128044, 51.63691498339176, 52.79180981218815, 48.99725362658501, 47.85853073000908, 45.79757831990719, 39.27237465977669, 37.62807369232178, 39.65944468975067, 38.54004755616188, 38.16884547472, 38.4890428930521, 38.27481798827648, 46.02616645395756, 49.44523438811302, 53.77385571599007, 53.42319913208485, 52.094592824578285, 43.86197738349438, 38.7420979142189, 39.895058646798134, 38.448195084929466, 45.4648681730032, 48.60705256462097, 50.46691596508026, 51.89247027039528, 47.80391626060009, 50.412176102399826, 47.53287300467491, 47.1100202947855, 41.80191792547703, 40.999818965792656, 46.28166474401951, 46.91981390118599, 46.50792360305786, 47.90337212383747, 43.54115679860115, 41.995544135570526, 45.10967843234539, 49.48625698685646, 50.31332440674305, 49.35270555317402, 35.878107994794846, 14.381548091769218, 4.374301051720977, 3.462044815532863, 11.33672397583723, 9.730850346386433, 14.605018850415945, 18.34488932043314, 12.63506680727005, 18.88668704777956, 4.260276770219207, 0.885357242077589, 0.28024656989146024, 6.665494507178664, 51.05771966278553, 28.598228730261326, 45.39616025984287, 32.84610629081726, 2.053883126936853, 0.12591468956088647, 0.12415522069204599, 0.13715344743104652, 0.14624509785789996, 0.12372747645713389, 0.11366457736585289, 0.16876871581189334, 0.10748642060207203, 0.2220063825370744, 0.3272817225661129, 0.11706723540555686, 0.11066029677749611, 0.1553659889032133, 0.16080284403869882, 0.12722048355499282, 0.15261015709256753, 0.14466018212260678, 0.08981316816061735, 0.2650053799152374, 0.16589878621743992], [0.04100200785615016, 0.07510794239351526, 0.051831385935656726, 0.026882139936788008, 0.03539152356097475, 0.023273888436960988, 0.028213358054927085, 0.08635173944639973, 0.03043834090931341, 0.03578223091608379, 0.015501006600970868, 0.029273204308992717, 0.018189690745202824, 0.1316099159885198, 0.04507384561293293, 0.04207227386359591, 0.032144193319254555, 0.08016410545678809, 0.02268358974106377, 0.07520166822359897, 0.06561016649357043, 0.038397833923227154, 0.0737067824229598, 0.05651248611684423, 0.0522165531583596, 0.08979185367934406, 0.056749947398202494, 10.890786554664373, 38.8986799120903, 21.324014961719513, 42.64688238501549, 9.648772850632668, 0.10503236830118112, 1.8474714341573417, 3.3177860314026475, 2.253101449459791, 4.794945605099201, 5.4995218478143215, 14.501567501574755, 12.165639996528625, 2.867449871264398, 3.8020427338778973, 0.9595608478412032, 4.1076570097357035, 13.555409722030163, 41.29922389984131, 54.231761544942856, 54.293880611658096, 51.559433341026306, 49.10292595624924, 44.116563722491264, 41.58786401152611, 44.578998908400536, 47.11654834449291, 46.77731014788151, 47.68431767821312, 47.06514470279217, 47.031235322356224, 44.26713824272156, 41.23162552714348, 37.53815531730652, 37.80166357755661, 37.49811686575413, 38.49491737782955, 38.06391790509224, 38.45728799700737, 40.21322697401047, 39.17172186076641, 38.71109917759895, 47.347754538059235, 50.16320966184139, 48.88552822172642, 46.61680296063423, 43.53743299841881, 39.51877623796463, 38.02166797220707, 38.3865699917078, 36.47800840437412, 37.11580038070679, 36.04352451860905, 37.60517232120037, 37.65685714781284, 41.01530313491821, 41.79062493145466, 43.95942695438862, 44.089740961790085, 49.88215394318104, 49.87334981560707, 52.61104591190815, 47.73264728486538, 46.616848558187485, 51.02878801524639, 47.04377464950085, 49.713708981871605, 51.78793787956238, 48.011818304657936, 48.50200340151787, 48.91984038054943, 46.99450649321079, 45.14541171491146, 41.34721912443638, 38.314077481627464, 38.20985667407513, 34.68304552137852, 33.661455139517784, 34.49246674776077, 35.36968007683754, 35.67596644163132, 43.22508215904236, 45.43508157134056, 50.115575417876244, 50.51704667508602, 48.56038346886635, 46.95874281227589, 37.52177819609642, 35.01152649521828, 35.07451951503754, 34.831788539886475, 41.868228167295456, 46.7297101020813, 44.575389102101326, 45.745593309402466, 46.27960905432701, 44.960456639528275, 45.887819677591324, 42.62315645813942, 40.04881739616394, 36.83314874768257, 36.915019154548645, 36.867263317108154, 37.960745841264725, 36.22460760176182, 38.80494274199009, 42.14503951370716, 43.76151457428932, 46.1700951308012, 45.74681304395199, 26.57357197254896, 6.260603908449411, 1.9881591224111617, 3.089328990317881, 2.1955143520608544, 2.8115881187841296, 5.021768733859062, 3.5974061395972967, 3.7987758591771126, 4.4988645426929, 0.15031850896775723, 0.053173979322309606, 0.14925507071893662, 18.715686723589897, 30.988467670977116, 26.03961132466793, 37.97742314636707, 6.448105797171593, 0.06199382558406796, 0.06105411077442113, 0.07888656502473168, 0.014379989752342226, 0.03841773832391482, 0.01771479415765498, 0.07126172495190986, 0.09475958984694444, 0.0017080165821425908, 0.07396761764539406, 0.03806734071986284, 0.1159103013924323, 0.046774399088462815, 0.07903123929281719, 0.03073810919886455, 0.040042529653874226, 0.033416969163226895, 0.017638950375840068, 0.04098385863471776, 0.12070920638507232, 0.047669989507994615, 0.06920858824742027, 0.020902902870147955, 0.024303638747369405, 0.03377751192601863, 0.0037252698666634387, 0.0677324268326629, 0.03330323874251917, 0.07771528529701754, 0.07244698674185202, 0.036763780590263195, 0.0380025697813835, 0.08099228289211169, 0.038717974166502245, 0.02702406269236235, 0.0341133263282245, 0.06604660869925283, 0.018621579874888994, 0.029165745036152657, 0.006983188468439039, 0.024780767344054766, 0.09170254255877808, 0.06241873852559365, 0.0598543028900167, 0.019287382820039056, 0.09249651440768503, 0.11488109099445865, 0.09725578129291534, 15.133207608014345, 42.0999663323164, 25.347088985145092, 50.9204938262701, 9.793357942253351, 0.0638846805668436, 0.5682601011358202, 0.43953687243629247, 1.679550250992179, 5.3109294176101685, 5.105796474963427, 12.416121605783701, 17.75919444859028, 4.84919766895473, 3.6697202967479825, 2.3913962161168456, 4.600413143634796, 16.218867301940918, 44.0617136657238, 54.41013537347317, 55.42517490684986, 52.725476771593094, 51.49109400808811, 44.86233450472355, 45.369493290781975, 47.21653997898102, 48.62661011517048, 49.520527347922325, 50.101177990436554, 47.984847351908684, 48.1888622045517, 46.173100769519806, 44.63783875107765, 40.35173714160919, 39.02883052825928, 39.78391461074352, 39.27937388420105, 39.14842151105404, 40.970792323350906, 42.35926441848278, 40.546267703175545, 41.51103973388672, 46.9064462184906, 51.12971059978008, 50.60744382441044, 47.35009901225567, 45.12421265244484, 41.02493941783905, 39.92485664784908, 40.61459183692932, 38.726055175065994, 37.83798962831497, 38.28519143164158, 38.735326677560806, 38.78645673394203, 42.677751928567886, 43.813499584794044, 45.37045083940029, 46.382214948534966, 50.23065984249115, 50.806461945176125, 53.14742133021355, 50.34080073237419, 47.41059936583042, 53.11188563704491, 49.20657679438591, 50.721285715699196, 52.76490345597267, 50.692327469587326, 50.807001516222954, 51.481947898864746, 48.92520569264889, 46.35259933769703, 44.224930107593536, 39.520839527249336, 38.60309757292271, 36.093735024333, 36.63433201611042, 35.92970162630081, 36.22581973671913, 37.21148684620857, 44.0727748721838, 47.71690472960472, 53.7079406529665, 50.93266077339649, 50.79467497766018, 49.022317081689835, 38.351380079984665, 35.661147236824036, 36.49687059223652, 35.07777214050293, 44.78916943073273, 47.376568391919136, 46.33206523954868, 47.03418776392937, 47.0481064170599, 45.72811044752598, 48.34649674594402, 44.30334649980068, 41.527192667126656, 37.42645651102066, 39.18167732656002, 38.86641204357147, 39.32033568620682, 37.24897563457489, 40.844726487994194, 43.32552216947079, 45.9070048481226, 46.386691108345985, 46.84684261679649, 26.02287132292986, 8.161509856581688, 2.907096706330776, 3.5596796264871955, 3.874392989091575, 7.586549408733845, 5.689847934991121, 7.3235108982771635, 8.03229684010148, 5.658967467024922, 0.5324884643778205, 0.07929327679448761, 0.14399116567801684, 21.515902765095234, 37.57390759885311, 25.861896760761738, 43.06283086538315, 10.86671294644475, 0.03528952278429642, 0.09375786117743701, 0.0519589165924117, 0.041777318401727825, 0.05682508242898621, 0.08899860171368346, 0.06813537591369823, 0.06978493271162733, 0.014934990049368935, 0.09991450308007188, 0.032029550056904554, 0.04931639959977474, 0.034971553322975524, 0.07396617787890136, 0.006066708911021124, 0.012720317481580423, 0.013873868228984065, 0.03477233862213325, 0.059790622908622026, 0.10634783247951418, 0.018869010054913815, 0.2002431097207591, 0.10153114562854171, 0.16296696150675416, 0.09962217853171751, 0.14388673065695912, 0.10668620729120448, 0.12348610034678131, 0.23044544766889885, 0.15472239843802527, 0.12364017762592994, 0.1849949880852364, 0.12663676956435665, 0.10170973604544997, 0.2215226655243896, 0.17204698990099132, 0.12790367502020672, 0.1001404425187502, 0.26646809361409396, 0.10263183226925321, 0.17150335188489407, 0.35690736724063754, 0.1256897149141878, 0.1727310719434172, 0.11716871667886153, 0.20323675533290952, 0.23874687409261242, 0.26209049101453274, 16.265808083117008, 51.16758316755295, 29.770541824400425, 53.13365466892719, 15.02300402149558, 0.2477653487585485, 4.391916431486607, 7.015763511881232, 5.575957121327519, 13.793395701795816, 17.01722726225853, 23.73298119753599, 17.92859695851803, 7.820936031639576, 7.446941575035453, 2.4803952779620886, 4.973366456106305, 15.698143243789673, 44.79756698012352, 56.5613367408514, 58.5120190680027, 56.41473300755024, 53.39285396039486, 46.51179179549217, 45.53223855793476, 48.58665145933628, 51.36961832642555, 50.81602223217487, 51.2971980124712, 50.99610976874828, 49.27099093794823, 47.751251086592674, 46.54543898999691, 41.636379808187485, 41.37770488858223, 42.174506932497025, 41.582080721855164, 41.2948427349329, 42.61234603822231, 44.99890297651291, 42.925221249461174, 43.07613395154476, 49.20482888817787, 54.86779801547527, 53.03986430168152, 48.23833554983139, 47.37128667533398, 44.06652420759201, 41.534883454442024, 42.97726705670357, 39.95744749903679, 40.882663652300835, 40.96269115805626, 40.2118856459856, 41.71527497470379, 44.058647230267525, 46.15575470030308, 47.70163714885712, 49.41618114709854, 54.23081919550896, 52.807328179478645, 55.10313078761101, 53.26516181230545, 49.882476925849915, 53.977642580866814, 49.63941916823387, 52.3741552233696, 54.751296266913414, 51.532789170742035, 52.57161922752857, 53.10539938509464, 52.027697414159775, 48.447651118040085, 46.30615442991257, 41.392425298690796, 41.04186750948429, 38.111609145998955, 38.447438925504684, 37.17823103070259, 37.64825440943241, 39.35517601668835, 46.641494035720825, 49.033860862255096, 54.979078844189644, 51.86085596680641, 54.2429443448782, 51.6907998919487, 40.888032764196396, 38.379703760147095, 39.82255473732948, 37.42527857422829, 45.31898260116577, 49.57792706787586, 47.605422511696815, 48.63098368048668, 48.569092601537704, 49.369869232177734, 50.89291110634804, 46.279483661055565, 45.52041359245777, 41.2046317756176, 40.935024842619896, 39.89668495953083, 41.08604393899441, 39.120994582772255, 42.793094739317894, 47.40820549428463, 47.26968012750149, 49.30086113512516, 47.61182516813278, 27.14022796601057, 7.6976801455020905, 4.210412045940757, 7.536686109378934, 7.102337591350079, 9.689557012170553, 13.594277836382389, 11.30388043820858, 11.01641921326518, 13.958990816026926, 1.8432681472040713, 0.17751039908034727, 0.28907726635225117, 26.394295692443848, 41.010382398962975, 34.46348190307617, 46.281455755233765, 12.636363487690687, 0.20856635528616607, 0.27631223725620657, 0.16059387009590864, 0.17328273999737576, 0.134656194713898, 0.12234216133947484, 0.3144153457833454, 0.3626780700869858, 0.1403273903997615, 0.19613239826867357, 0.17801651410991326, 0.22790804476244375, 0.08859628345817327, 0.15178420610027388, 0.19609575101640075, 0.0815050549863372, 0.1808520228951238, 0.14630813588155434, 0.14507631916785613, 0.2697343745967373, 0.15503166621783748], [0.05562416874454357, 0.07403268915368244, 0.03406156894925516, 0.0894356524804607, 0.0486119715787936, 0.022587489038414788, 0.08412646158831194, 0.055390841225744225, 0.027651904783851933, 0.025784551762626506, 0.04941063751175534, 0.05835545031004585, 0.04177963019174058, 0.04299088199331891, 0.07972158506163396, 0.05794791104563046, 0.07624371777637862, 0.04621314619726036, 0.03032177919521928, 0.012442537172319135, 0.054213717085076496, 0.046681493331561796, 0.03525828578858636, 0.048391883974545635, 0.07637561968294904, 0.028855185919383075, 0.05562774218560662, 1.999722020700574, 34.35773737728596, 31.08585264533758, 37.16596908867359, 30.516702085733414, 1.074572007637471, 0.20545221457723528, 0.19955064140958712, 0.22691310674417764, 3.3526038005948067, 2.7943683927878737, 6.129563665017486, 12.703468836843967, 4.85944714397192, 1.6203177231363952, 2.140339412726462, 0.9160434454679489, 5.693258726969361, 28.059537336230278, 54.68647554516792, 53.73711548745632, 51.07833735644817, 51.86838336288929, 48.09941120445728, 43.904474303126335, 41.88069149851799, 41.641353741288185, 40.644583627581596, 41.114656403660774, 39.793022722005844, 38.631128668785095, 38.425958678126335, 38.42200689017773, 39.645385444164276, 41.36967211961746, 40.691891089081764, 40.74159622192383, 36.77356414496899, 38.36185231804848, 39.55498829483986, 38.18333029747009, 39.397878125309944, 47.00124733150005, 50.90473227202892, 52.200094163417816, 51.209392324090004, 43.80963899195194, 38.68739604949951, 38.08294728398323, 36.6500935703516, 37.63738699257374, 36.62439934909344, 36.61888964474201, 37.58647732436657, 39.4889060407877, 42.47531779110432, 41.28563202917576, 44.06971603631973, 43.21427173912525, 48.86634685099125, 50.13486698269844, 52.729808539152145, 47.714233472943306, 46.943684220314026, 51.30111180245876, 49.29221659898758, 49.864530488848686, 47.32719764113426, 47.831635773181915, 46.081928461790085, 49.70403090119362, 45.03400929272175, 44.091412872076035, 41.76249884068966, 38.320122957229614, 36.64836846292019, 34.722867384552956, 34.36351306736469, 35.398436933755875, 36.575811356306076, 35.30621588230133, 40.979322865605354, 49.75901775062084, 47.91929326951504, 51.28093108534813, 48.41507166624069, 48.89368638396263, 43.20849224925041, 36.986569315195084, 33.41837838292122, 31.95401296019554, 37.44157209992409, 44.129479229450226, 45.16453988850117, 46.30287900567055, 45.25531321763992, 49.262927770614624, 45.15469841659069, 46.18976667523384, 45.638488456606865, 42.232013046741486, 36.9025482237339, 35.853565111756325, 35.12956716120243, 38.22738513350487, 39.81978088617325, 44.17960613965988, 43.83479744195938, 47.259671464562416, 41.97857424616814, 20.618955194950104, 3.6069642892107368, 1.816508558113128, 1.983004817739129, 1.5566649637185037, 3.8652713410556316, 5.04046325571835, 7.012739349156618, 6.107890103012323, 4.418307915329933, 0.20499922247836366, 0.040818701090756804, 2.7423401596024632, 40.26880279183388, 39.570316672325134, 34.65302713215351, 25.1008602976799, 2.0469458866864443, 0.08115792283206247, 0.08701012091478333, 0.0691256755089853, 0.012866480683442205, 0.09583293576724827, 0.05901735697989352, 0.03699512657476589, 0.06463432393502444, 0.0235461527336156, 0.020432997225725558, 0.025806758676480968, 0.01342540786936297, 0.04845328185183462, 0.07858784316340461, 0.06000958244840149, 0.047664608937338926, 0.05837984099343885, 0.0063345671696879435, 0.031063730202731676, 0.01199378923047334, 0.011477453899715329, 0.02522583701647818, 0.0496712500898866, 0.04000816079496872, 0.032837203398230486, 0.025886042312777136, 0.011083803929068381, 0.0974037210107781, 0.033267886537942104, 0.05221969244303182, 0.07447494979714975, 0.04528285666310694, 0.08795788060524501, 0.032061855745268986, 0.007847053002478788, 0.03244843304855749, 0.028458743618102744, 0.021850951998203527, 0.06335054204100743, 0.019432725021033548, 0.015957449686538894, 0.055758720118319616, 0.016364246803277638, 0.05380363967560697, 0.030300943399197422, 0.03718091953487601, 0.0897343223914504, 0.0696262541168835, 3.542272048071027, 43.217748552560806, 30.824954845011234, 39.245909079909325, 33.160003647208214, 0.6430621747858822, 0.23839831701479852, 0.2128530596382916, 0.41835078271105886, 2.3741019191220403, 6.284537399187684, 12.833907287567854, 9.892544019967318, 7.285008989274502, 4.360868772491813, 2.4092212971299887, 1.500752626452595, 6.581728952005506, 31.922577247023582, 54.94755573570728, 55.837429985404015, 51.89462095499039, 52.34542116522789, 49.88808922469616, 44.750502705574036, 42.27099135518074, 43.904200717806816, 43.3001509308815, 43.67773286998272, 42.433907613158226, 42.313750460743904, 40.64704589545727, 39.930449947714806, 40.28325341641903, 41.53279736638069, 42.849305123090744, 42.99002677202225, 38.67351159453392, 39.81684364378452, 40.33069767057896, 39.4336000084877, 41.0931571573019, 49.76143442094326, 53.94772678613663, 52.79843285679817, 52.853385508060455, 46.73213057219982, 40.02034172415733, 39.468520134687424, 38.79550404846668, 39.030810222029686, 38.42176370322704, 38.739012479782104, 39.30756077170372, 41.33887097239494, 44.20819200575352, 44.56872805953026, 47.22452335059643, 46.1473685503006, 50.809129402041435, 52.46354542672634, 53.08162406086922, 50.39653234183788, 48.418951258063316, 51.86259247362614, 51.19744576513767, 50.57613730430603, 49.244639351964, 49.76760908961296, 49.07884284853935, 50.08693255484104, 46.24585546553135, 46.98995813727379, 43.9823929220438, 40.017830058932304, 39.07387711107731, 35.84946893155575, 35.37816882133484, 36.968425288796425, 38.42313922941685, 36.72773100435734, 42.70712435245514, 50.26839181780815, 50.552852153778076, 52.09166698157787, 49.30536009371281, 51.066265404224396, 45.01850612461567, 38.566239550709724, 36.028534322977066, 33.832058385014534, 39.614128321409225, 46.432319059967995, 47.73766301572323, 47.45682008564472, 46.031052991747856, 49.46049436926842, 46.5371972322464, 47.39232614636421, 47.61556036770344, 43.62749956548214, 38.672941625118256, 36.14315137267113, 37.734703570604324, 38.90535995364189, 40.95905855298042, 45.16023851931095, 45.2127631008625, 48.84687289595604, 42.046582996845245, 21.11868917942047, 3.81610625423491, 3.247145446948707, 4.158712970092893, 2.8792529879137874, 7.204874139279127, 8.630481641739607, 6.421438828110695, 7.055540252476931, 1.8411077256314456, 0.19760720897465944, 0.0896516397187952, 2.198999240063131, 40.649804547429085, 35.01379117369652, 37.19010919332504, 31.27691589295864, 3.140233908779919, 0.08976512152003124, 0.06464402380515821, 0.11339269898599014, 0.06382901206961833, 0.02860952947230544, 0.014629055440309457, 0.07583853483083658, 0.05964939220575616, 0.0513073294860078, 0.09238116239430383, 0.05610993779555429, 0.02766721157968277, 0.032795969673315994, 0.05122413102071732, 0.030617922093369998, 0.06279980167164467, 0.07724989191046916, 0.04313521487347316, 0.030584443811676465, 0.035950045348727144, 0.020312030865170527, 0.13206745003117248, 0.15833554440177977, 0.09105661432840861, 0.17118678137194365, 0.11904551167390309, 0.16642394475638866, 0.24363807257032022, 0.19190761871868744, 0.12074914135155268, 0.2562934864545241, 0.14840201649349183, 0.2516922599170357, 0.1638299011392519, 0.16051247133873403, 0.22043973847758025, 0.17412951565347612, 0.16723782842746004, 0.17170582461403683, 0.17139528034022078, 0.16823667014250532, 0.11312059054034762, 0.08131699476507492, 0.15031338814878836, 0.2612582466099411, 0.18528736458392814, 0.25076760328374803, 0.18286343605723232, 4.742571115493774, 49.44374866783619, 42.00395308434963, 43.62844951450825, 41.1832807213068, 1.6487122932448983, 0.9435478539671749, 0.7263810758013278, 0.6674443383235484, 10.457622148096561, 9.471731800585985, 16.82886376976967, 22.285595163702965, 14.209920801222324, 3.343239203095436, 4.10565166734159, 1.23086201492697, 7.169030187651515, 33.54991972446442, 58.54320019483566, 58.721327036619186, 55.35827949643135, 57.07835599780083, 52.489608228206635, 48.23254086077213, 43.43231163918972, 45.753147304058075, 44.11871820688248, 45.22549241781235, 44.259006679058075, 42.541901618242264, 43.39698113501072, 41.73752658069134, 42.73695655167103, 44.7469536960125, 44.145145788788795, 45.10302498936653, 40.44555030763149, 42.586674615740776, 42.91829042136669, 42.12611272931099, 42.54746451973915, 50.30581220984459, 54.020793065428734, 55.52118815481663, 56.5230043977499, 48.157407492399216, 42.28119760751724, 41.48524671792984, 40.62181144952774, 41.56505383551121, 39.5358145236969, 41.16853751242161, 41.24791905283928, 43.36569741368294, 46.19528017938137, 45.25085985660553, 49.20184604823589, 48.11011143028736, 52.69603595137596, 54.60083194077015, 54.56259459257126, 52.629205137491226, 49.937779158353806, 51.9244721531868, 52.94262371957302, 53.05516608059406, 50.45420564711094, 50.91679282486439, 50.6014097481966, 53.349768072366714, 47.76432618498802, 48.1344111263752, 46.41677409410477, 42.22809165716171, 40.07208734750748, 37.678861767053604, 38.321057707071304, 38.715457543730736, 40.250415578484535, 38.28551821410656, 44.166162461042404, 52.12920896708965, 52.53029264509678, 55.502629950642586, 48.59499201178551, 55.227118134498596, 47.54701964557171, 40.995118618011475, 37.935355603694916, 36.139195784926414, 41.657312884926796, 47.401365861296654, 49.24383759498596, 50.32726965844631, 46.478513181209564, 51.08501359820366, 48.804113790392876, 50.587228909134865, 49.405841901898384, 45.62782242894173, 39.77194145321846, 38.724314868450165, 38.04516591131687, 41.78273655474186, 41.60464011132717, 49.204874485731125, 47.06078253686428, 50.97309060394764, 41.88331335783005, 22.56684087216854, 4.217555662617087, 4.636872662231326, 5.508910194039345, 5.308959223330021, 9.00835046544671, 11.870227698236704, 16.306963674724102, 12.953079342842102, 8.67679925635457, 0.8652792975772172, 0.2759944199351594, 3.8419987773522735, 52.350733280181885, 45.5238676071167, 43.507733792066574, 37.72991202771664, 4.58498977124691, 0.1774960311013274, 0.1862404157873243, 0.2465701347682625, 0.09362333206809126, 0.3465370705816895, 0.11131746854516678, 0.15889971022261307, 0.12762382597429678, 0.13194278406444937, 0.10199965603533201, 0.13572962227044627, 0.11413572239689529, 0.13964868150651455, 0.14004703669343144, 0.15951241250149906, 0.15807810821570456, 0.14582337986212224, 0.12878126464784145, 0.20640845701564103, 0.06301713961875066, 0.11707279409165494], [0.01836087081755977, 0.06490349347586744, 0.009954093748092419, 0.017279856656386983, 0.040024098416324705, 0.057589490825193934, 0.05159858163096942, 0.04609600560797844, 0.06437359261326492, 0.03880165873852093, 0.053986875936971046, 0.02645355893037049, 0.008418274792347802, 0.026529957467573695, 0.07715518644545227, 0.048865993885556236, 0.005859945176780457, 0.02225738175184233, 0.011277396861260058, 0.08167027190211229, 0.04578313841193449, 0.07073752378346398, 0.02819858375005424, 0.0747197397868149, 0.03806707354669925, 0.056875322115956806, 0.03504394611809403, 0.10595480591291562, 21.241422593593597, 38.13447631895542, 26.59794196486473, 45.38593880832195, 11.502811163663864, 0.0635426989174448, 0.12930392957059667, 1.1104354332201183, 1.851964930538088, 4.3232018686831, 6.650467738509178, 5.416182819753885, 7.132034422829747, 5.822536814957857, 1.446564446669072, 0.4991109960246831, 1.546591348014772, 14.478309899568558, 48.811796978116035, 55.535995960235596, 50.602648481726646, 53.2849245518446, 50.405803844332695, 46.4343823492527, 44.6123269200325, 42.98408009111881, 41.26854054629803, 38.70022036135197, 40.47298863530159, 42.5553984940052, 45.7645732909441, 46.54351629316807, 47.565342262387276, 48.438862189650536, 51.119644939899445, 51.36879377067089, 46.78503133356571, 37.6148846000433, 38.607349544763565, 36.615272238850594, 42.741079330444336, 50.91015838086605, 53.72492574155331, 52.862201035022736, 51.06922924518585, 47.27390930056572, 39.76936899125576, 36.81575708091259, 36.74677178263664, 37.865826934576035, 35.981755033135414, 37.263901233673096, 38.02619352936745, 39.07465226948261, 42.91588515043259, 42.178082540631294, 43.41212332248688, 45.88420607149601, 48.01092155277729, 48.705003708601, 54.01599012315273, 45.523871406912804, 46.408600732684135, 50.57184733450413, 48.67511451244354, 49.783237650990486, 46.61353513598442, 48.44343714416027, 46.238461062312126, 47.18296118080616, 45.864393934607506, 44.833938628435135, 42.089896872639656, 38.894256949424744, 35.1739601790905, 35.82598239183426, 35.2429036796093, 35.85630476474762, 35.047951340675354, 36.08359336853027, 38.149116933345795, 45.985903814435005, 48.77931632101536, 45.9030606597662, 46.96541525423527, 49.579678773880005, 48.72988857328892, 44.290271401405334, 38.096406161785126, 32.50757485628128, 31.77478037774563, 36.12010180950165, 43.6968382447958, 47.284495532512665, 46.45296335220337, 46.65543548762798, 48.898132145404816, 45.3287822753191, 46.536593064665794, 43.47768500447273, 45.405028983950615, 41.960411220788956, 36.81106433272362, 37.497094720602036, 41.11833840608597, 43.905082270503044, 44.93855841457844, 45.578444078564644, 35.2631413936615, 11.866898126900196, 1.1871998640708625, 1.786597513128072, 3.7091638427227736, 3.0676981760188937, 9.881188329309225, 4.443667279556394, 4.898874778300524, 7.850779155269265, 1.5093708015047014, 0.09682771793450229, 0.06064795932616107, 10.562607664614916, 49.46618266403675, 34.95077155530453, 33.511621579527855, 12.872362174093723, 0.14077258994802833, 0.06476904600276612, 0.06842398972366937, 0.06283080860157497, 0.08538420152035542, 0.041538198420312256, 0.01037169839037233, 0.0563704947126098, 0.033916174797923304, 0.052024774777237326, 0.07439602239173837, 0.04205328972602729, 0.12007702272967435, 0.05642759926558938, 0.05985245865304023, 0.032027164052124135, 0.019397239229874685, 0.021307104325387627, 0.013409698458417552, 0.047298841454903595, 0.06654167314991355, 0.037279896059772, 0.010580848593235714, 0.05546905616938602, 0.03317490656627342, 0.006961286762816599, 0.01879574338090606, 0.013568665563070681, 0.03179025567078497, 0.043833865274791606, 0.02548981337895384, 0.020463807486521546, 0.0487000348221045, 0.0447272886231076, 0.015496345913561527, 0.06929198338184506, 0.012451225866243476, 0.010194008755206596, 0.02021187432546867, 0.03555503724783193, 0.066875943884952, 0.09324675149400719, 0.03755966718017589, 0.028366464975988492, 0.021044424865976907, 0.0053520448182098335, 0.05566159525187686, 0.09989922968088649, 0.019806936288659927, 0.34243717964272946, 28.59633643180132, 41.47675797343254, 30.102049335837364, 51.66186824440956, 9.399119596928358, 0.11272940449998714, 0.16511245106812567, 0.5546495877206326, 0.9311890765093267, 6.453447360545397, 9.73271794617176, 6.74065874889493, 6.035142056643963, 6.220191176980734, 3.0532518262043595, 2.0548019651323557, 1.8256895779632032, 16.069092638790607, 50.71863725781441, 58.18649813532829, 54.53286498785019, 54.618785977363586, 50.82147873938084, 47.60962128639221, 46.174746081233025, 43.92011046409607, 42.09938496351242, 40.11693634092808, 41.219154596328735, 42.752767503261566, 45.39358779788017, 47.699406668543816, 47.60941989719868, 50.251665115356445, 52.60360971093178, 52.317606657743454, 47.24500425159931, 39.45680916309357, 41.5046750754118, 39.16504941880703, 45.48670560121536, 53.338380083441734, 54.99786503612995, 55.729622170329094, 53.79081040620804, 49.01304557919502, 40.2580189704895, 39.69197474420071, 39.51567180454731, 39.924833849072456, 38.163214176893234, 39.31475758552551, 40.1516854763031, 40.74818126857281, 44.5114803314209, 43.19736264646053, 44.325301721692085, 47.27379530668259, 49.87846054136753, 51.15483485162258, 55.606166794896126, 49.15960371494293, 48.413753136992455, 52.74492792785168, 49.751087576150894, 51.91841907799244, 48.83607767522335, 49.95965078473091, 49.86663557589054, 49.55966904759407, 48.5636854916811, 46.6670286655426, 45.01087613403797, 40.50122492015362, 38.31058166921139, 37.23932035267353, 37.07942113280296, 36.66583612561226, 37.47800834476948, 37.26059541106224, 39.99807111918926, 48.55710044503212, 51.06611721217632, 48.46182055771351, 48.31696093082428, 50.26581555604935, 49.75477337837219, 44.09917965531349, 38.92219305038452, 34.52806703746319, 34.56226520240307, 38.963014259934425, 46.51991195976734, 48.104411736130714, 48.53539980947971, 48.0586051940918, 48.68633911013603, 46.77120007574558, 48.06489385664463, 45.46108737587929, 46.118433102965355, 43.37490051984787, 38.45093473792076, 39.168397039175034, 43.04931499063969, 44.68972496688366, 47.08037808537483, 45.391763895750046, 37.45322227478027, 14.347235932946205, 2.05037544015795, 2.364174476824701, 6.166192274540663, 3.4198837028816342, 7.60659808292985, 10.598619282245636, 6.759615456685424, 3.510547550395131, 0.9358519606757909, 0.0898932978452649, 0.056026505553745665, 13.11819663271308, 57.353385239839554, 40.41688844561577, 37.885464280843735, 16.957367174327374, 0.26559408113826066, 0.07088508500601165, 0.08021098692552187, 0.06233394073206, 0.04205700788588729, 0.0397949900070671, 0.04197886344627477, 0.035367054952075705, 0.06389165675500408, 0.017362769394821953, 0.014304176584118977, 0.02889204097300535, 0.07914363755844533, 0.004789750601048581, 0.03686352152726613, 0.02148264080460649, 0.004205465156701393, 0.08856788888806477, 0.01771687217114959, 0.06862884474685416, 0.01837356339819962, 0.03619390023231972, 0.1501851005014032, 0.24063768825726584, 0.11298666999209672, 0.08868594974046573, 0.1096631471591536, 0.1221046963473782, 0.18899172049714252, 0.1630420668516308, 0.12668337643845007, 0.15055090509122238, 0.25975409138482064, 0.15036435885122046, 0.07201252607046627, 0.17104565456975251, 0.19100010569673032, 0.1212577722617425, 0.110606498492416, 0.10401834966614842, 0.11741607449948788, 0.21706439147237688, 0.10806815305841155, 0.13741437171120197, 0.15052328235469759, 0.20184744003927335, 0.19605781242717057, 0.15519771433901042, 0.14552003442076966, 0.4684591986006126, 31.46207045763731, 51.0102716088295, 34.43128243088722, 57.566531002521515, 14.56532808020711, 0.21705035003833473, 0.6574045051820576, 2.623581332154572, 5.149877909570932, 12.960981018841267, 16.196138821542263, 11.89815429970622, 15.989874489605427, 13.322389125823975, 4.046786651015282, 1.5984095237217844, 2.3320842487737536, 17.2137888148427, 50.994285866618156, 60.54008424282074, 55.98299257457256, 56.871700286865234, 54.02215339243412, 50.1439218968153, 48.451766297221184, 46.86805687844753, 44.67812038958073, 42.313503473997116, 45.192912966012955, 46.00851260125637, 48.87360446155071, 51.63253001868725, 51.25245541334152, 52.00667314231396, 56.7541915923357, 56.79541938006878, 52.088433355093, 41.22086450457573, 41.60443872213364, 41.789173409342766, 48.271705359220505, 56.35599575936794, 57.77598336338997, 56.72275967895985, 55.87522275745869, 51.55524596571922, 42.77280002832413, 40.91494292020798, 40.318751111626625, 41.68430283665657, 39.20949563384056, 41.760849729180336, 41.4538262039423, 43.11283238232136, 47.092043459415436, 46.31747022271156, 46.851166784763336, 50.90182162821293, 52.258010655641556, 53.033077865839005, 58.313095942139626, 48.57922665774822, 49.55176927149296, 53.80701653659344, 52.43663527071476, 54.53017093241215, 50.750414952635765, 52.06840842962265, 50.86658991873264, 51.27574436366558, 50.14132663607597, 49.64671477675438, 47.640992403030396, 42.57671155035496, 39.03179056942463, 39.35423746705055, 38.730348944664, 38.857642114162445, 38.788645416498184, 40.93990758061409, 41.85363695025444, 50.21902106702328, 52.51466028392315, 49.32599678635597, 48.4430305659771, 52.568328604102135, 52.74980306625366, 48.46017524600029, 40.905500426888466, 36.02926008403301, 36.18773438036442, 39.727217853069305, 48.03224980831146, 52.0534448325634, 49.97110716998577, 48.741987124085426, 52.13292136788368, 48.628244027495384, 49.655458107590675, 48.55380982160568, 49.0714218467474, 47.248857244849205, 41.35434374213219, 41.75727792084217, 45.02063401043415, 47.950273007154465, 49.43085215985775, 47.23697908222675, 38.25771510601044, 13.137873876839876, 2.0764517784118652, 4.110825089737773, 10.067469533532858, 7.199317887425423, 18.389434330165386, 11.10406531020999, 11.288981437683105, 16.899786964058876, 6.210952922701836, 0.2574809524230659, 0.20321756339399144, 15.920137781649828, 62.3783154040575, 38.019418492913246, 45.024445205926895, 22.618867680430412, 0.3475393558619544, 0.12906516582006589, 0.12411831368808635, 0.13964661833597347, 0.17341929516987875, 0.10500760283321142, 0.08886841416824609, 0.1392636849777773, 0.1218034586054273, 0.10980131279211491, 0.25662074389401823, 0.12037877255352214, 0.1930322396219708, 0.18295866844709963, 0.11767982636229135, 0.20803209801670164, 0.13004683423787355, 0.24526903114747256, 0.09392976484377868, 0.17228605051059276, 0.16486638458445668, 0.08065411588177085], [0.06499197232187726, 0.033030959602911025, 0.06795603592763655, 0.07690900863963179, 0.045668009042856283, 0.018449011986376718, 0.01852571665949654, 0.019605573070293758, 0.029634778657054994, 0.03416834915697109, 0.033039371846825816, 0.05503432090335991, 0.08210508138290606, 0.010761270259536104, 0.034054273637593724, 0.035793162751360796, 0.019861430337186903, 0.091083042207174, 0.06744711557985283, 0.01973360838746885, 0.0604288699105382, 0.015727272584626917, 0.11105559431598522, 0.008508844639436575, 0.057496514564263634, 0.04182768796454184, 0.020503992927842773, 0.01942595848959172, 3.157792529091239, 32.979171350598335, 23.384678587317467, 33.83335791528225, 30.671074502170086, 0.8725078159477562, 0.0673021592956502, 0.042616483333404176, 0.31240338343195617, 4.536396553739905, 7.466384656727314, 3.5725056007504463, 5.710467053577304, 4.999830136075616, 2.7423966815695167, 1.8196258158423007, 0.43479241139721125, 3.7061641411855817, 32.82106563448906, 57.76304505765438, 54.10791479051113, 51.22112229466438, 51.22822031378746, 48.118311390280724, 44.916603192687035, 41.91323675215244, 41.945052444934845, 46.19906857609749, 50.14629676938057, 52.20741257071495, 53.19173455238342, 50.80070145428181, 52.68777899444103, 53.349855467677116, 52.54624418914318, 50.02033352851868, 51.64528973400593, 42.5192928314209, 38.17651346325874, 39.5701152831316, 41.86640806496143, 50.63620068132877, 52.252831533551216, 53.8408575206995, 53.8479745388031, 49.65215988457203, 41.574279740452766, 38.735866248607635, 37.81413070857525, 38.56441184878349, 36.575663164258, 35.99845893681049, 38.394940942525864, 40.46666197478771, 44.97249439358711, 45.94222895801067, 45.03630816936493, 45.66438406705856, 48.02889458835125, 50.164759978652, 54.210991859436035, 47.42930956184864, 45.33116094768047, 51.34549722075462, 50.164163410663605, 49.12576653063297, 45.83636283874512, 47.871108055114746, 47.65143424272537, 46.665280759334564, 45.036399364471436, 44.1974575817585, 43.14687095582485, 37.95880414545536, 36.1613941937685, 35.22406429052353, 36.765820160508156, 35.09121581912041, 36.28685966134071, 34.787840098142624, 38.01564909517765, 46.066679880023, 49.82203356921673, 48.46400164067745, 46.69536754488945, 48.41817989945412, 46.07013389468193, 48.02528478205204, 45.37678509950638, 43.30991640686989, 37.393257692456245, 33.0592330545187, 34.95006859302521, 41.024316251277924, 45.93278266489506, 47.18704216182232, 46.829830929636955, 49.04536284506321, 46.55566804111004, 47.815429642796516, 46.421067863702774, 45.352557599544525, 42.46416538953781, 41.1825929582119, 44.36312489211559, 43.806887939572334, 45.53651712834835, 42.08399198949337, 24.956319853663445, 5.156698068603873, 0.5286336899735034, 1.7444835416972637, 4.201864879578352, 1.30082635441795, 4.571554642170668, 12.396707497537136, 3.759524440392852, 2.3998006526380777, 0.35619870526716113, 0.10017515276558697, 1.5054628299549222, 26.812753938138485, 30.27891654521227, 21.274013444781303, 28.479162119328976, 3.706465750001371, 0.011589456044021063, 0.035091454701614566, 0.039478059552493505, 0.04955764212354552, 0.06399234393029474, 0.03676478620036505, 0.02516329252102878, 0.010826360321516404, 0.03692298610985745, 0.071533781447215, 0.04294298378226813, 0.020653604333347175, 0.022525725653395057, 0.03410635756154079, 0.03960898182413075, 0.02581403728981968, 0.05754132173024118, 0.04423565660545137, 0.08110879265586846, 0.1022241631289944, 0.08524458127794787, 0.09032447822391987, 0.07454702717950568, 0.04016688762931153, 0.0502389559551375, 0.07370192135567777, 0.027780691525549628, 0.0313653390185209, 0.011347662475600373, 0.04908489034278318, 0.03143383553833701, 0.028155151412647683, 0.1016688288655132, 0.014399155716091627, 0.05464522029797081, 0.029522773729695473, 0.017943114035006147, 0.052579144248738885, 0.017934449460881297, 0.05103680552565493, 0.04757080889248755, 0.015446042216353817, 0.02771844945527846, 0.02390212943282677, 0.045698455651290715, 0.0168679554190021, 0.09753951177117415, 0.060447824362199754, 0.034088427273673005, 0.06357590260449797, 6.39374733902514, 42.38716632127762, 27.196269258856773, 42.57474705576897, 33.74402470886707, 0.5617304483894259, 0.046687723661307245, 0.2096701366826892, 0.2074555234867148, 3.8388233352452517, 7.959003522992134, 5.57893093675375, 5.754786925390363, 6.008619479835033, 4.612584840506315, 2.9764118744060397, 1.1266249394975603, 5.104783354327083, 35.7453279197216, 57.27677375078201, 55.473713502287865, 53.39406609535217, 51.785148829221725, 49.086313247680664, 46.63498878479004, 42.96484552323818, 42.41802826523781, 44.579777866601944, 50.382685884833336, 51.64636127650738, 53.138305619359016, 52.53958694636822, 53.07734549045563, 54.80542056262493, 55.86551807820797, 52.34539456665516, 54.495224207639694, 43.96890364587307, 39.921771213412285, 40.264854803681374, 43.6874033510685, 51.25324197113514, 55.282674953341484, 56.40272565186024, 54.312393218278885, 50.7555028796196, 43.88488255441189, 39.564297795295715, 39.20057751238346, 40.81124268472195, 40.004496574401855, 37.09558546543121, 40.565509870648384, 42.93494872748852, 45.87149195373058, 46.32190838456154, 46.795556768774986, 47.50995643436909, 51.11290030181408, 50.10432422161102, 55.42947247624397, 49.143785163760185, 47.87185661494732, 51.91835828125477, 50.52418269217014, 50.321243181824684, 47.39528238773346, 48.76263901591301, 49.032204151153564, 48.840215653181076, 47.43717133998871, 45.49001902341843, 44.56436589360237, 39.98133301734924, 38.0274398624897, 37.37885266542435, 38.74384582042694, 37.45516397058964, 37.950190007686615, 35.44222578406334, 39.90404136478901, 47.26401083171368, 50.34832812845707, 49.82750527560711, 47.62251779437065, 49.85385686159134, 49.77374196052551, 49.366954788565636, 47.90679574012756, 42.68573150038719, 37.89603531360626, 35.40683828294277, 38.13517168164253, 43.80179241299629, 48.63988280296326, 49.05702821910381, 48.533788695931435, 48.206371665000916, 48.21915417909622, 48.54146048426628, 47.5318356603384, 45.772955641150475, 42.37587712705135, 40.52799068391323, 45.80239646136761, 45.41870824992657, 47.56519787013531, 43.37436094880104, 28.35023693740368, 5.982103552669287, 1.7858794704079628, 3.4547406574711204, 4.5038071274757385, 4.242214439436793, 5.743825938552618, 11.674481201916933, 4.433853356167674, 1.9355116412043571, 0.22057047521229833, 0.1222879919805564, 0.9556446829810739, 31.067146249115467, 38.392797857522964, 25.736077912151814, 33.57888177037239, 5.408321991562843, 0.00927100061744568, 0.09374092536745593, 0.02961332687846152, 0.045769089556415565, 0.01068981164280558, 0.05543922925426159, 0.07790489660692401, 0.004486203852138715, 0.03928590638679452, 0.03608967672334984, 0.04446293933142442, 0.05243811392574571, 0.05726959920139052, 0.0408604209223995, 0.005682585333488532, 0.049410574429202825, 0.02587489339930471, 0.04457608716620598, 0.06927558933966793, 0.035116483632009476, 0.02013039578741882, 0.041607489038142376, 0.23280814901227131, 0.1306949369609356, 0.2366088653798215, 0.15167383389780298, 0.0859179838153068, 0.18427786562824622, 0.16298601985909045, 0.18927850120235234, 0.14079337008297443, 0.17052238108590245, 0.16576662455918267, 0.09217684913892299, 0.11961784854065627, 0.08409122441662475, 0.12574107153341174, 0.1397827875916846, 0.08969392729341052, 0.19358945894055068, 0.20309286774136126, 0.13580254570115358, 0.16981340741040185, 0.12618322827620432, 0.3162177256308496, 0.16308175690937787, 0.15937610965920612, 0.11197877407539636, 0.15613108378602192, 0.11723012939910404, 7.599104885011911, 49.79007348418236, 32.112468257546425, 43.850228413939476, 37.23367005586624, 1.026450558565557, 0.260022867587395, 0.6978345732204616, 1.0654561780393124, 13.285298366099596, 17.639736458659172, 11.943509615957737, 14.86733302474022, 11.297552827745676, 8.097040615975857, 4.605776555836201, 0.8207552460953593, 5.495055662468076, 36.353523284196854, 61.963757649064064, 59.060234650969505, 56.32099203765392, 54.53214302659035, 52.78599992394447, 49.04868766665459, 45.35400912165642, 45.09755328297615, 49.278449937701225, 52.939830869436264, 55.301635935902596, 55.32292999327183, 53.85404281318188, 55.7008159160614, 57.98505574464798, 55.78541837632656, 54.15502466261387, 56.44169256091118, 47.25127391517162, 41.399884298443794, 42.43094377219677, 45.60658156871796, 53.624576926231384, 55.60419850051403, 58.192794397473335, 56.32707931101322, 54.08349350094795, 45.573728531599045, 43.244046941399574, 40.98437659442425, 43.649808168411255, 42.38657735288143, 39.43019159138203, 42.79577739536762, 45.48138968646526, 48.09438407421112, 49.50557515025139, 49.048060700297356, 49.50704947113991, 53.59276123344898, 53.095588311553, 57.41752579808235, 50.865742564201355, 49.406829848885536, 54.35987547039986, 52.78536155819893, 51.94576621055603, 50.76065920293331, 51.47015333175659, 52.512615993618965, 51.18861883878708, 48.39645266532898, 47.03038416802883, 46.045724004507065, 42.19599097967148, 39.08979445695877, 39.05827134847641, 41.60786233842373, 40.033694207668304, 39.192905724048615, 38.22511285543442, 42.5571957975626, 49.67197582125664, 54.69276800751686, 51.744312420487404, 49.130200892686844, 49.77138228714466, 50.80006308853626, 52.52870813012123, 49.7452586889267, 47.29235351085663, 40.637440010905266, 37.572513073682785, 38.39939050376415, 45.018107146024704, 48.71278949081898, 51.538295075297356, 49.11217845976353, 50.114933252334595, 48.805211931467056, 48.83059076964855, 50.79973630607128, 47.976050823926926, 44.80574794113636, 43.31352241337299, 48.290537148714066, 47.76384361088276, 49.88224893808365, 45.61386197805405, 27.02681165188551, 5.677076345309615, 1.3708858075551689, 5.088343536481261, 8.66690743714571, 6.124686151742935, 11.32189717143774, 19.380379356443882, 13.463875483721495, 7.266641249880195, 1.2156579620204866, 0.2809571020770818, 2.3093871166929603, 36.047886684536934, 39.74797993898392, 32.47737407684326, 40.66991686820984, 6.775327138602734, 0.13097304938128218, 0.17127781320596114, 0.16835750662721694, 0.11221072491025552, 0.14268842933233827, 0.12552393396617845, 0.14201396552380174, 0.10170052599278279, 0.09798387269256637, 0.16272021224722266, 0.206310419307556, 0.20212265808368102, 0.24141407862771302, 0.2232587122125551, 0.1592504937434569, 0.10424486055853777, 0.07263914361828938, 0.1515290854149498, 0.2231340017169714, 0.21003552566980943, 0.20328214508481324, 0.1611396751832217], [0.02324928624148015, 0.033927685508388095, 0.014060116682230728, 0.06159926648251712, 0.024257165459857788, 0.021551250501943287, 0.04280704459233675, 0.041084735057665966, 0.029753347880614456, 0.05412059610534925, 0.027775913949881215, 0.04451078930287622, 0.019482001771393698, 0.0425634717248613, 0.016223851016547997, 0.031643896727473475, 0.023756184236845, 0.09555523152812384, 0.06820605805842206, 0.013911808673583437, 0.03369575693795923, 0.03412979087443091, 0.07333874396863393, 0.12010368809569627, 0.04434452966961544, 0.02744844870903762, 0.007322788751480402, 0.02537870645028306, 0.11631547691649757, 19.593002647161484, 34.75382052361965, 27.239480540156364, 43.418081402778625, 8.788505662232637, 0.06827303688623942, 0.05025495294830762, 0.22844552295282483, 2.265695398673415, 5.317439893260598, 4.633224857971072, 1.814997426699847, 4.3062790017575026, 4.084439305588603, 2.7284198440611362, 0.8067534130532295, 0.1306982320966199, 11.112780142575502, 48.64980407059193, 58.172932863235474, 53.471939116716385, 51.213389709591866, 51.18328772485256, 46.13067984580994, 44.83783341944218, 50.86907118558884, 52.07738354802132, 54.13719981908798, 52.94250212609768, 53.0621425062418, 53.319540694355965, 55.12296572327614, 53.11323456466198, 54.39577594399452, 52.62401081621647, 48.50970558822155, 43.106346130371094, 37.36596375703812, 39.794386848807335, 44.52569916844368, 51.80294707417488, 52.4787750095129, 54.50690858066082, 52.11389198899269, 51.46962136030197, 43.47771920263767, 38.31673353910446, 38.43285530805588, 38.14458757638931, 37.723786756396294, 38.85450728237629, 38.010678961873055, 41.16699859499931, 45.610164776444435, 44.81443427503109, 46.08182966709137, 46.170003935694695, 48.98350976407528, 49.893488734960556, 55.02118058502674, 47.839189767837524, 45.192776173353195, 51.673267632722855, 51.05406045913696, 48.80384400486946, 46.089235469698906, 46.58757112920284, 45.2795597165823, 46.75799958407879, 46.21096953749657, 44.28975462913513, 42.3566235601902, 39.613364562392235, 35.17258085310459, 35.80811195075512, 35.904964953660965, 36.699122339487076, 35.57843707501888, 35.70469669997692, 38.637200742959976, 45.955684036016464, 46.209586411714554, 50.14242097735405, 49.24280025064945, 47.40746833384037, 49.694903790950775, 48.399473503232, 47.1203975379467, 46.35001167654991, 44.84220698475838, 41.90355487167835, 36.42270237207413, 34.587001875042915, 38.81936676800251, 43.12045477330685, 45.385330840945244, 47.980697974562645, 47.50455692410469, 47.904215678572655, 49.73018869757652, 45.17207108438015, 44.24661174416542, 41.74828000366688, 44.229011088609695, 41.890635564923286, 45.44793248176575, 36.96722075343132, 14.62983151897788, 1.1047577066347003, 1.0156979667954147, 2.138817594386637, 3.9577396167442203, 4.184381067752838, 3.1037480290979147, 14.74275765940547, 2.654273947700858, 0.9169773641042411, 0.16892554645892233, 0.059768403007183224, 6.340710259974003, 37.22100533545017, 26.518343836069107, 33.55651997029781, 19.031039401888847, 0.16276919399388134, 0.0694686739007011, 0.03103959927102551, 0.08637331367935985, 0.032099827731144615, 0.018686347102629952, 0.09922866956912912, 0.0679205464257393, 0.040846635529305786, 0.04908419643470552, 0.05774716380983591, 0.009008604101836681, 0.04918940700008534, 0.05328439234290272, 0.07298379699932411, 0.055153580324258655, 0.007390986093014362, 0.05722600544686429, 0.05485455418238416, 0.03314739515190013, 0.03412038415262941, 0.07624656020198017, 0.012003495594399283, 0.03495809076412115, 0.03680281384731643, 0.0348960880364757, 0.09837147415964864, 0.014062088939681416, 0.012032740851282142, 0.017656650597928092, 0.10693496034946293, 0.017058390512829646, 0.08313038808410056, 0.022296262868621852, 0.045108589256415144, 0.038530897290911525, 0.09844627522397786, 0.02765536690276349, 0.043668084326782264, 0.052531142137013376, 0.04523186740698293, 0.10558534995652735, 0.07615489754243754, 0.02167147285945248, 0.06379952654242516, 0.041542120670783333, 0.038780678223702125, 0.01348890231383848, 0.030953482309996616, 0.06020376167725772, 0.052281969765317626, 0.34416659153066576, 28.040857538580894, 36.70158840715885, 29.674695767462254, 49.60601896047592, 7.526681246235967, 0.10818461829330772, 0.10065717026009224, 0.24538100638892502, 0.8308416861109436, 4.923685071989894, 3.8541849609464407, 5.0054490845650434, 4.133789632469416, 5.228799199685454, 4.218980111181736, 2.479648618027568, 0.26271840732079, 14.230442550033331, 51.87338009476662, 59.189093336462975, 55.46720065176487, 52.88112781941891, 52.33698941767216, 48.105441480875015, 45.22559881210327, 51.37619577348232, 53.44475917518139, 54.48017701506615, 53.304645493626595, 55.55773839354515, 54.04012642800808, 55.93053638935089, 54.1747760027647, 56.50706425309181, 54.97704215347767, 50.77978737652302, 46.39232620596886, 40.8746574819088, 39.80431951582432, 45.71818917989731, 53.8841599971056, 53.26730489730835, 56.37222468852997, 53.09753380715847, 54.18106086552143, 45.10101869702339, 40.078509002923965, 39.401670321822166, 39.99742895364761, 39.64292697608471, 40.85468575358391, 40.2326325327158, 42.028986141085625, 47.0100324600935, 48.23053456842899, 49.08513531088829, 47.6311357319355, 51.20039060711861, 51.83495655655861, 55.1354556530714, 50.27806609869003, 46.861327439546585, 53.451291024684906, 53.31933170557022, 51.08739987015724, 48.016868233680725, 48.04104633629322, 46.81362099945545, 47.56361335515976, 48.590455055236816, 45.6577268242836, 44.58208814263344, 40.10841719806194, 37.33290173113346, 36.17821969091892, 37.948962673544884, 38.50326173007488, 38.67078714072704, 36.80132545530796, 40.3146131336689, 47.2131771594286, 48.11283588409424, 52.14812435209751, 49.06869739294052, 48.78804065287113, 50.00479996204376, 50.38986749947071, 48.749548718333244, 47.37895846366882, 46.854647397994995, 44.27788786590099, 37.59565383195877, 36.25361144542694, 41.464043855667114, 46.33622221648693, 46.61687135696411, 49.74321059882641, 49.75628949701786, 48.725435212254524, 50.47949329018593, 45.99357560276985, 45.902699679136276, 43.955900743603706, 46.82511918246746, 43.57031263411045, 46.61532863974571, 38.77419479191303, 17.05414418131113, 2.0926937693729997, 2.201709682121873, 3.2651301193982363, 4.343414884060621, 4.517737179994583, 6.706797815859318, 8.037675451487303, 1.9391983933746815, 0.4216937127057463, 0.1420176020474173, 0.04847067408263683, 6.683310326188803, 45.07142588496208, 26.436636820435524, 34.27184298634529, 23.920565731823444, 0.41009341017343104, 0.029796930502925534, 0.048905858348007314, 0.03480420644336846, 0.02364389358262997, 0.04509874837822281, 0.043932979097007774, 0.08527365862391889, 0.062205074209487066, 0.15500681911362335, 0.020695958701253403, 0.03353852924192324, 0.08858941117068753, 0.052115465223323554, 0.021578925188805442, 0.04922090003674384, 0.03118063701549545, 0.015920501864457037, 0.009309171127824811, 0.013813509358442388, 0.023475492853322066, 0.07017212599748746, 0.07346304628299549, 0.0920463350485079, 0.172096194291953, 0.09376439949846826, 0.1675782070378773, 0.10482793630217202, 0.09125001801294275, 0.07105328535544686, 0.16925326402997598, 0.13856425532139838, 0.12017146102152765, 0.13233423727797344, 0.13977060152683407, 0.10217386035947129, 0.25099912367295474, 0.09656475274823606, 0.111947737459559, 0.10004144001868553, 0.2092490717768669, 0.19134150847094133, 0.16237287229159847, 0.16034274216508493, 0.190213963505812, 0.1342549451510422, 0.19353872572537512, 0.08402204883168451, 0.18641053087776527, 0.11165525706019253, 0.1233058178331703, 0.7661838212516159, 34.799349680542946, 48.17104496061802, 38.18495661020279, 53.85072939097881, 11.678579282015562, 0.18257248448207974, 0.6347966683097184, 0.5980361939873546, 5.189233347773552, 11.307724881917238, 11.042154282331467, 7.502325028181076, 12.4131197668612, 8.569368571043015, 7.137222094461322, 3.49809633102268, 0.7438043283764273, 13.483315240591764, 51.89815856516361, 61.7932265996933, 58.27765144407749, 55.755570977926254, 53.95709328353405, 50.80341450870037, 48.26540909707546, 55.29584124684334, 55.328629687428474, 59.26711454987526, 57.80325450003147, 58.070513159036636, 55.2405846118927, 57.83136539161205, 56.09207712113857, 58.031983226537704, 56.58715255558491, 52.62188673019409, 47.797737792134285, 42.688949927687645, 43.04189018905163, 49.54152122139931, 56.35306231677532, 55.5916553735733, 58.07966686785221, 54.867748618125916, 57.101508155465126, 47.16239668428898, 41.64189711213112, 41.448145508766174, 42.74674482643604, 42.34064921736717, 43.20852264761925, 41.570213958621025, 43.539918065071106, 49.86114867031574, 50.542604103684425, 50.41220270097256, 50.22317424416542, 54.155115857720375, 54.892040714621544, 56.435343101620674, 50.6402550637722, 49.10119704902172, 53.822500705718994, 55.65434440970421, 54.159128442406654, 50.68891905248165, 50.03027759492397, 49.14806753396988, 49.683010429143906, 51.72610379755497, 47.807161286473274, 46.696769669651985, 44.15839567780495, 39.7851799428463, 38.655937537550926, 39.98399667441845, 41.03961803019047, 39.26851786673069, 37.98009440302849, 41.51963107287884, 49.686525240540504, 50.09258285164833, 53.451693803071976, 49.380622655153275, 47.9757734388113, 52.69345968961716, 51.025789976119995, 49.84316423535347, 48.910952657461166, 47.70807020366192, 47.732111513614655, 39.69153016805649, 38.53936739265919, 42.58684180676937, 47.17719689011574, 48.76472130417824, 52.33958087861538, 50.59019275009632, 49.63377267122269, 51.30754865705967, 47.64689728617668, 49.29610379040241, 45.946921706199646, 50.01259334385395, 45.36093235015869, 48.86484593153, 39.17529746890068, 16.104292050004005, 1.6306206327863038, 2.490971297957003, 4.6918880101293325, 10.159840676933527, 8.402734212577343, 11.268528085201979, 27.78312686830759, 8.133726697415113, 3.1339955935254693, 0.6143949099350721, 0.10017475200584158, 9.328147005289793, 49.9965164065361, 33.16104859113693, 43.86725530028343, 29.125043861567974, 0.80786865320988, 0.2042022004025057, 0.11716315799276344, 0.13964926038170233, 0.15797327243490145, 0.08866168893291615, 0.13398125593084842, 0.15298890473786741, 0.10448588785948232, 0.3067594097228721, 0.15137733105802909, 0.08180459321010858, 0.1164683593378868, 0.1410350578953512, 0.1633951361873187, 0.1785614137770608, 0.071773428353481, 0.08842860261211172, 0.10876796121010557, 0.10002457100199535, 0.208700847288128, 0.23983014252735302, 0.1448393365717493], [0.038910227522137575, 0.022018588315404486, 0.019888654169335496, 0.041848742694128305, 0.011424090698710643, 0.0317768376407912, 0.03281423392763827, 0.03123485090327449, 0.06947228073840961, 0.0035847782964992803, 0.033498078482807614, 0.029691744057345204, 0.0847749799140729, 0.0726110755931586, 0.05750924981839489, 0.02496418728696881, 0.06743997611920349, 0.014204848466761177, 0.07135119085432962, 0.07068374776281416, 0.02948667752207257, 0.03266547413659282, 0.05752467164711561, 0.03107772339717485, 0.033917610853677616, 0.02210547711001709, 0.02487861394911306, 0.08414013194851577, 0.13614641240565106, 6.791948871687055, 40.95362864434719, 28.097117319703102, 38.0116631090641, 28.398106768727303, 1.0083198314532638, 0.07143650072976016, 0.17598767532035708, 0.7283918804023415, 3.5835953056812286, 1.930438675917685, 3.8540348690003157, 2.718076561577618, 4.058856228366494, 3.3266257820650935, 2.3844979237765074, 0.5858561850618571, 0.8713396161329001, 24.27195567637682, 58.989170864224434, 54.10674825310707, 54.87278714776039, 51.586624681949615, 48.417750522494316, 49.11386936903, 50.66378340125084, 53.335944414138794, 55.632320791482925, 55.28197579085827, 52.382890954613686, 54.28617462515831, 52.75325708091259, 55.029228553175926, 52.62795880436897, 51.00005015730858, 48.154344856739044, 41.076985225081444, 39.6246537566185, 39.74133029580116, 47.450596019625664, 51.06671757996082, 53.4361108392477, 53.68361055850983, 53.38815361261368, 50.30838467180729, 45.45223765075207, 42.129874527454376, 40.24125427007675, 39.44072462618351, 38.19807730615139, 38.42100754380226, 38.60155485570431, 41.6348484903574, 45.09794466197491, 46.88496597111225, 48.44927363097668, 47.321661338210106, 48.73844191431999, 49.14125829935074, 55.14355681836605, 49.067705646157265, 44.29877154529095, 50.48350587487221, 46.91378362476826, 51.96131497621536, 51.047760397195816, 48.27970013022423, 47.76830457150936, 45.73252961039543, 47.830058857798576, 45.356475189328194, 42.29329615831375, 40.41647046804428, 35.384837463498116, 35.890438333153725, 36.71591363847256, 36.60529017448425, 34.4981474429369, 37.08164781332016, 43.537482395768166, 48.55289787054062, 48.56620855629444, 49.05964247882366, 48.70384097099304, 48.83512772619724, 49.785490930080414, 50.135642141103745, 48.26857432723045, 48.95397014915943, 47.046388909220695, 46.22679188847542, 44.84795227646828, 40.117327719926834, 40.015850365161896, 39.50272969901562, 41.3786244392395, 43.90951283276081, 47.23309949040413, 45.783074498176575, 46.8074881285429, 46.79379366338253, 48.386588394641876, 46.27168647944927, 46.55938044190407, 45.71752041578293, 44.975652024149895, 25.440062396228313, 5.014748610556126, 0.409453411702998, 2.2760947281494737, 2.1274666534736753, 2.731811637058854, 2.785374987870455, 4.366141464561224, 4.366849176585674, 1.4821849227882922, 0.2579586877254769, 0.1033683618879877, 0.21861077490029857, 18.942207768559456, 38.72536741197109, 23.945015519857407, 30.641318298876286, 4.702253853902221, 0.06973817740799859, 0.0761115264322143, 0.03345617682498414, 0.01591729207575554, 0.04647445268346928, 0.00936823495067074, 0.05451391582028009, 0.016079646156867966, 0.012491010547819315, 0.06405858803191222, 0.08083860637270845, 0.02858369902241975, 0.007302082831301959, 0.04459523828700185, 0.01598164741153596, 0.10698897385736927, 0.05244646679784637, 0.1183126334217377, 0.03316113230539486, 0.09934562462149188, 0.0587814801838249, 0.08436771153355949, 0.03688847995363176, 0.028464300448831636, 0.08289065954159014, 0.052550456530298106, 0.018586717487778515, 0.04212734493194148, 0.07756557926768437, 0.053099178257980384, 0.025222584554285277, 0.055831142599345185, 0.07296815994777717, 0.029861424991395324, 0.03452680277405307, 0.020389306992001366, 0.007299163871721248, 0.06427845670259558, 0.02230531521490775, 0.059009605247410946, 0.03300925178336911, 0.07848831373848952, 0.0506245387805393, 0.0599422548111761, 0.02391069010627689, 0.05120995228935499, 0.03323303157230839, 0.09096429115743376, 0.0977185029478278, 0.030409831306315027, 0.01535310955659952, 0.08520517323631793, 11.057789493352175, 46.18548050522804, 30.38339003920555, 48.89905169606209, 29.815229326486588, 0.5527959403116256, 0.08287911914521828, 0.07410494465148076, 0.33443038584664464, 1.588424015790224, 5.136471278965473, 6.862740973010659, 6.520868567749858, 5.37525569088757, 6.15995823405683, 3.371716062538326, 2.03095895703882, 1.2326343823224306, 28.95889587700367, 57.896178513765335, 55.361824706196785, 54.847879484295845, 53.002037331461906, 51.280953884124756, 50.55044308304787, 52.45186485350132, 56.06810040771961, 55.91122582554817, 54.88837011158466, 53.03411900997162, 56.20566822588444, 55.16963481903076, 57.70104378461838, 53.39776709675789, 52.58931867778301, 49.551320895552635, 43.721677511930466, 41.63808211684227, 42.08849094808102, 49.30168569087982, 54.44958105683327, 55.71483336389065, 55.286809131503105, 53.656605407595634, 51.91789470613003, 48.319005221128464, 43.19817580282688, 40.13147056102753, 40.03697723150253, 40.10988771915436, 41.10406257212162, 40.56522108614445, 43.62059913575649, 47.02780790627003, 48.49281929433346, 50.69664403796196, 49.11290802061558, 50.29041163623333, 50.3825680911541, 55.40201894938946, 50.63629187643528, 45.353518947958946, 51.28758452832699, 49.489707201719284, 53.28531593084335, 51.89885392785072, 49.576935321092606, 48.09626877307892, 47.11951978504658, 50.038348361849785, 47.03714780509472, 44.492124170064926, 42.148713916540146, 36.569910272955894, 37.38129213452339, 39.21002380549908, 39.17060472071171, 36.52930565178394, 38.40276472270489, 45.188429206609726, 50.60514494776726, 51.39232970774174, 51.554296016693115, 49.00940917432308, 51.73322841525078, 51.12448588013649, 50.77043607831001, 49.079754799604416, 49.511685222387314, 48.86498272418976, 48.93772982060909, 45.62674708664417, 41.1675001680851, 39.95125003159046, 40.41884534060955, 43.39092046022415, 46.0021897405386, 47.24940441548824, 47.11607336997986, 47.98094496130943, 48.56866702437401, 48.07686321437359, 47.58090242743492, 47.43740312755108, 46.911929324269295, 46.184435561299324, 27.978814467787743, 6.335599534213543, 1.4350068918429315, 4.906885698437691, 3.7624493334442377, 4.075345918536186, 4.743456467986107, 7.390527902171016, 3.262780657969415, 1.1193623417057097, 0.38656376651488245, 0.09191984339850023, 0.10233284323476255, 19.752390794456005, 44.79481212794781, 26.82932674884796, 35.504048466682434, 7.857681484892964, 0.04756005517265294, 0.047056678668013774, 0.06136478121334221, 0.036000299878651276, 0.011418208250688622, 0.01719239640806336, 0.047441842179978266, 0.0397225304186577, 0.023054388984746765, 0.017416339469491504, 0.018501325976103544, 0.006279606031966978, 0.03706026487634517, 0.008602374728070572, 0.02782175455649849, 0.11722352428478189, 0.026743311937025283, 0.07390738493995741, 0.058284601182094775, 0.06045531263225712, 0.04135631286771968, 0.04206506760965567, 0.07564842628198676, 0.10494557413039729, 0.10080990425194614, 0.12080901782610454, 0.06655165503616445, 0.11455634201411158, 0.1743521896423772, 0.15037716832011938, 0.1746164684300311, 0.1528533737291582, 0.16175268916413188, 0.23381356615573168, 0.17576534271938726, 0.21548088581766933, 0.18933816987555474, 0.18650779675226659, 0.13969267602078617, 0.17839998181443661, 0.1275228790473193, 0.16770716261817142, 0.12814674322726205, 0.1308876133407466, 0.10730177426012233, 0.13957927585579455, 0.22965655953157693, 0.12833649554522708, 0.3309941530460492, 0.12166103304480202, 0.2473636539070867, 0.20143707690294832, 12.951855808496475, 55.922826603055, 37.61841081082821, 48.95483270287514, 35.19784189760685, 1.7090860661119223, 0.38017791230231524, 0.4434234998188913, 2.0501823630183935, 9.058578070253134, 10.731277763843536, 15.326244849711657, 11.386683695018291, 13.599958531558514, 10.837545711547136, 6.097419764846563, 2.4603853141888976, 2.1181906387209892, 27.273429818451405, 63.5499407351017, 58.74951012432575, 59.79188919067383, 55.32789632678032, 53.5175708681345, 52.794705256819725, 55.55296964943409, 58.182702139019966, 59.1701627522707, 58.28167162835598, 54.99867059290409, 57.07959473133087, 56.32453724741936, 59.02254067361355, 56.09324745833874, 54.27463084459305, 53.481362611055374, 44.42763403058052, 45.657825618982315, 43.68705376982689, 52.45546706020832, 56.881724148988724, 57.77367688715458, 57.07678288221359, 54.39193055033684, 53.80611978471279, 50.42178578674793, 45.502417758107185, 43.212071657180786, 42.647771537303925, 42.586879804730415, 43.098818734288216, 41.186601743102074, 45.58953948318958, 48.6848533898592, 51.36490277945995, 54.273110926151276, 53.04390348494053, 53.9158920943737, 52.2608795017004, 57.768288776278496, 52.62809559702873, 48.17570351064205, 51.22495248913765, 52.71737180650234, 54.92835156619549, 53.04092064499855, 51.57796114683151, 50.950850397348404, 50.30202381312847, 52.70612061023712, 51.176353096961975, 46.02547489106655, 44.00523729622364, 39.226666912436485, 39.569552913308144, 41.6826157271862, 40.58209978044033, 38.135517463088036, 40.162013322114944, 47.02264778316021, 51.43518380820751, 51.38270102441311, 52.37233892083168, 49.77212704718113, 50.675099194049835, 52.08239547908306, 52.943828254938126, 51.14997111260891, 51.69358894228935, 51.418282315135, 50.65730854868889, 47.83490739762783, 42.309103310108185, 43.24974663555622, 43.82219731807709, 45.40166616439819, 47.039959654212, 49.29404430091381, 48.98425072431564, 49.14595104753971, 48.70761036872864, 50.9769131988287, 49.906788021326065, 50.29962234199047, 48.70436914265156, 47.198228761553764, 27.275103628635406, 5.898938365280628, 1.3934644334949553, 6.109588611871004, 6.628991765901446, 8.182934056967497, 7.9813216254115105, 13.822289351373911, 12.010095342993736, 4.955844171345234, 1.2673285393975675, 0.33778759476263076, 0.5364141287282109, 25.63553150743246, 50.036152079701424, 32.32345953583717, 43.659968823194504, 9.407000374048948, 0.22215297154616565, 0.24612036359030753, 0.14906445750966668, 0.10337556072045118, 0.10588348552118987, 0.2317372299148701, 0.23463159101083875, 0.1289390749298036, 0.1276839993079193, 0.1735561472014524, 0.17120907548815012, 0.1614682239596732, 0.08670903160236776, 0.16325727483490482, 0.0875874153280165, 0.18657424865523353, 0.10833482898306102, 0.21290486154612154, 0.23603233537869528, 0.24110086262226105, 0.12645850569242612, 0.11965788740781136, 0.10906352894380689], [0.08467646723147482, 0.01300620297115529, 0.03955201456847135, 0.023575456434627995, 0.04644917884434108, 0.018491216069378424, 0.032015812903409824, 0.025367765338160098, 0.03681124835566152, 0.0520083139417693, 0.022083518815634307, 0.08266198157798499, 0.03913454907888081, 0.08874710270902142, 0.01569961830682587, 0.048952198048937134, 0.02110798053763574, 0.05463873392727692, 0.0068878429010510445, 0.056496437173336744, 0.05338742470485158, 0.019400896162551362, 0.06152678462967742, 0.05142833666468505, 0.04130243665713351, 0.046515482317772694, 0.023903318724478595, 0.07369662242126651, 0.002331630867047352, 0.8790708356536925, 29.253691658377647, 35.941006019711494, 25.54740473628044, 39.64459128677845, 8.707019984722137, 0.06343016706523485, 0.07385171644273214, 0.22544228879269212, 1.0878500388935208, 2.5897111371159554, 4.06205328181386, 2.669690907932818, 2.590008471161127, 4.748455099761486, 1.6874709259718657, 1.82076848577708, 0.40860204957425594, 4.71252185292542, 45.64470112323761, 56.6560048609972, 54.06762175261974, 51.886447593569756, 50.849304646253586, 51.74951434135437, 54.882742613554, 55.2204342931509, 53.31892512738705, 50.51349766552448, 53.96365933120251, 56.26662455499172, 54.71146680414677, 51.19126729667187, 47.998773604631424, 46.21945068240166, 42.417948469519615, 40.5555772036314, 40.04910238087177, 42.842412292957306, 52.336541041731834, 52.3745010048151, 54.75484527647495, 54.184769466519356, 53.48985135555267, 52.039009407162666, 46.738495230674744, 39.51880283653736, 39.95662674307823, 37.65466846525669, 38.752665147185326, 37.60540410876274, 37.71357670426369, 42.12532997131348, 45.796092599630356, 47.73313365876675, 49.00780566036701, 46.31842017173767, 50.26542417705059, 50.04912078380585, 57.20459662377834, 48.100022971630096, 50.93142583966255, 48.47756311297417, 48.62032525241375, 55.2409303933382, 47.25928768515587, 46.234497874975204, 46.7703565210104, 47.07449220120907, 47.69135110080242, 46.52862869203091, 42.50851660966873, 37.06510730087757, 34.64187853038311, 35.98460108041763, 35.96144512295723, 37.07700826227665, 34.91322956979275, 41.68309070169926, 47.752717807888985, 49.44130539894104, 49.75373603403568, 46.99203662574291, 49.81329023838043, 49.167796075344086, 48.23238506913185, 47.270424887537956, 48.556332886219025, 47.56773993372917, 50.1562674343586, 47.953806817531586, 45.41259817779064, 45.19458867609501, 45.212455317378044, 42.805607467889786, 41.01459637284279, 40.98775841295719, 46.601611375808716, 47.873878106474876, 46.87050774693489, 44.797563180327415, 46.48510202765465, 46.150529980659485, 48.062120005488396, 46.62033297121525, 32.51682735979557, 10.030172634869814, 0.9232896566390991, 1.573614904191345, 3.4250751743093133, 2.2412092750892043, 2.6347543951123953, 2.9871026007458568, 6.430722204968333, 2.543560001067817, 0.4597815329907462, 0.14750740199815482, 0.08239304210292175, 2.373523637652397, 30.22002350538969, 29.90412175655365, 26.48748379200697, 21.02557137608528, 1.1083746375516057, 0.06157925075967796, 0.08643529785331339, 0.0806671628379263, 0.028258506608835887, 0.04490890700253658, 0.06814451175159775, 0.04129187589569483, 0.06628823713981546, 0.02866080445528496, 0.0575982852751622, 0.01551993786051753, 0.04117467593459878, 0.018649950325198006, 0.02613745968119474, 0.05611817934550345, 0.10770433000288904, 0.10665472538676113, 0.06582118876394816, 0.016533209709450603, 0.04039592924527824, 0.02632423598697642, 0.016973572310234886, 0.045518162005464546, 0.017156274225271773, 0.026280705315002706, 0.0528028498229105, 0.04731776993139647, 0.04506907360337209, 0.058875384129351005, 0.03489185779471882, 0.09467544514336623, 0.04429344764503185, 0.06534499712870456, 0.03370592065039091, 0.043770404226961546, 0.06042479923053179, 0.033951842415262945, 0.04552760954538826, 0.04871392040513456, 0.05378366848162841, 0.06094952732382808, 0.00564621638659446, 0.012102497166779358, 0.02758759026619373, 0.02975237566715805, 0.03553861351974774, 0.02892480308219092, 0.005845791492902208, 0.0696783306193538, 0.023335623991442844, 0.024894109992601443, 0.07417351909680292, 1.4306410448625684, 36.303255781531334, 37.09569185972214, 30.151454284787178, 47.91686899960041, 8.095825631171465, 0.05103348070406355, 0.10641441054758616, 0.1263445711811073, 0.6617764674592763, 2.506465441547334, 4.7295905370265245, 5.750581501051784, 5.235872995108366, 6.19787497445941, 4.212581729516387, 3.396503319963813, 0.9080964687746018, 6.822972781956196, 47.808198630809784, 59.54454526305199, 55.5387432128191, 55.39480313658714, 52.683511823415756, 53.57590913772583, 55.17392098903656, 56.30396515130997, 53.60365144908428, 52.94238053262234, 53.7641966342926, 57.36925318837166, 56.20124526321888, 54.48251388967037, 50.11558301746845, 47.71571919322014, 44.878529235720634, 42.74210907518864, 41.68625593185425, 43.91614727675915, 52.76114925742149, 55.48479750752449, 55.82555182278156, 54.89093877375126, 56.18646785616875, 54.014937579631805, 49.47662450373173, 41.9182562828064, 41.170068830251694, 39.44907657802105, 40.03568150103092, 39.72925454378128, 39.62995447218418, 44.105776101350784, 48.870690017938614, 50.07533937692642, 51.268931329250336, 49.028757736086845, 52.37961173057556, 52.188542783260345, 57.73420840501785, 49.47627492249012, 48.85823428630829, 48.802039101719856, 50.496907755732536, 55.415033251047134, 48.90135057270527, 48.3677414059639, 47.67829120159149, 48.321965262293816, 50.28581388294697, 47.57330283522606, 43.99803288280964, 39.496733620762825, 37.9352568089962, 38.33455838263035, 37.988005578517914, 37.129939422011375, 35.77851913869381, 43.4068264067173, 48.53337071835995, 49.91845719516277, 51.09973020851612, 48.38076330721378, 50.88335081934929, 51.99895955622196, 50.477304607629776, 48.33325445652008, 48.59404966235161, 50.0004567950964, 51.24675191938877, 49.342472702264786, 48.03392551839352, 46.23480945825577, 46.87320940196514, 44.25571225583553, 42.89030112326145, 43.058248311281204, 48.66893984377384, 50.521302446722984, 49.37686465680599, 45.63222259283066, 49.94171194732189, 47.611312195658684, 48.34636755287647, 48.07160809636116, 34.84727270901203, 13.273550346493721, 2.34909332357347, 1.8625105521641672, 3.8523221109062433, 4.0094788279384375, 4.425330888479948, 4.861233048141003, 7.601209972053766, 0.5071795068215579, 0.514454988297075, 0.13152646890375763, 0.2014165639411658, 2.0210842369124293, 36.60388804972172, 36.38162277638912, 27.824945524334908, 26.972130686044693, 1.521782479248941, 0.1316569236223586, 0.013253146116767311, 0.04517656998359598, 0.043458561194711365, 0.08842132956488058, 0.043262923645670526, 0.02483132244378794, 0.05123196810018271, 0.02926112214481691, 0.04302995977923274, 0.026187085240962915, 0.07231069874251261, 0.02019850639044307, 0.03239614132326096, 0.02863867917767493, 0.040214700493379496, 0.0686521184979938, 0.02091470672894502, 0.02313776371011045, 0.0045110231258149724, 0.027229747065575793, 0.04015591126517393, 0.13377381081227213, 0.21664918953320011, 0.1307996836840175, 0.17989131272770464, 0.12659737636568025, 0.1181141757115256, 0.11571871596970595, 0.1264118542894721, 0.16306974895996973, 0.10847862751688808, 0.13571436371421441, 0.12526902108220384, 0.19465683057205752, 0.14637277694419026, 0.1809180443524383, 0.17229647026397288, 0.14129504706943408, 0.17143606877652928, 0.1846775715239346, 0.10985696644638665, 0.10559814458247274, 0.22768462862586603, 0.10740003461251035, 0.22636225505266339, 0.1799434411805123, 0.10640675900503993, 0.11967333892243914, 0.2130006579682231, 0.1331663184100762, 0.146357785561122, 2.1094249840825796, 42.397068589925766, 46.98805443942547, 33.55123445391655, 50.2767513692379, 11.747758369892836, 0.25740471901372075, 0.4590460052713752, 0.4506367299472913, 3.1291038310155272, 10.498570650815964, 12.052607461810112, 8.431291580200195, 8.640423808246851, 10.505721867084503, 6.7628904059529305, 5.061415806412697, 1.1300569865852594, 6.107141068205237, 48.3546245098114, 61.27244554460049, 58.37120622396469, 57.33978196978569, 55.31430445611477, 56.25429421663284, 58.91349792480469, 57.90494084358215, 56.309999227523804, 52.51748353242874, 56.21559329330921, 59.00981895625591, 59.318271204829216, 56.676219776272774, 51.77402302622795, 49.80169326066971, 47.189800813794136, 44.79435235261917, 44.32366020977497, 48.54668140411377, 57.00945049524307, 57.99917958676815, 55.37102401256561, 54.251167103648186, 57.81029172241688, 55.881773605942726, 51.037956923246384, 43.40833492577076, 44.380174577236176, 41.66689597070217, 42.773810774087906, 40.913920775055885, 42.23749615252018, 47.22538970410824, 51.01022981107235, 52.55665563046932, 54.18228439986706, 50.138453990221024, 54.1383321583271, 54.41482812166214, 59.0760912001133, 52.48453930020332, 52.39329479634762, 50.15630163252354, 50.997910872101784, 56.92819945514202, 52.68219709396362, 50.891383588314056, 49.37482796609402, 49.902707040309906, 53.41969572007656, 50.23558057844639, 45.394780933856964, 40.22906452417374, 39.24875132739544, 39.31282348930836, 40.79109236598015, 39.84572969377041, 37.94308818876743, 46.0336634516716, 50.92170976102352, 51.92683942615986, 52.337244004011154, 48.06667976081371, 52.48540185391903, 53.3525875210762, 52.72880919277668, 49.868448078632355, 51.40125162899494, 50.78427493572235, 54.23852138221264, 51.335465759038925, 49.151460751891136, 49.33926947414875, 48.65710347890854, 46.62650004029274, 44.55193296074867, 43.996151983737946, 51.23672805726528, 52.60157682001591, 50.52806608378887, 46.477931812405586, 50.174590051174164, 50.08471727371216, 51.46582156419754, 47.804725617170334, 33.55018191039562, 11.209020428359509, 1.6288768826052547, 3.960433672182262, 7.722148457542062, 6.828924687579274, 8.12112657353282, 9.74793802946806, 13.427743222564459, 8.395410105586052, 2.807534448802471, 0.8984225441236049, 0.5065533716697246, 3.223836310207844, 40.25372140109539, 39.533546045422554, 35.957728922367096, 34.30590055882931, 1.6356330388225615, 0.22526467801071703, 0.1806636806577444, 0.24514904071111232, 0.11439493231591769, 0.21638063597492874, 0.25294013670645654, 0.10196962874033488, 0.13150246784789488, 0.22251228976529092, 0.2467232695198618, 0.09616023031412624, 0.19835668907035142, 0.16528399108210579, 0.15690349624492228, 0.173556637018919, 0.25513529079034925, 0.1918743853457272, 0.11070674037910067, 0.092732888442697, 0.1610502167022787, 0.16860965872183442, 0.13781876798020676, 0.20093056111363694], [0.020184897257422563, 0.038166413723956794, 0.04262422022293322, 0.016900060727493837, 0.010075471072923392, 0.04782005547895096, 0.09208979521645233, 0.07675962173379958, 0.07955359251354821, 0.003705636813720048, 0.06454733680584468, 0.018352979932387825, 0.017502693917776924, 0.037745333975180984, 0.01955310879566241, 0.04223920142976567, 0.05829759618791286, 0.02397030682914192, 0.032809157637530006, 0.059807399156852625, 0.07648677856195718, 0.04570312376017682, 0.014667102568637347, 0.01389829880281468, 0.047807594819460064, 0.01477463883929886, 0.03410331475606654, 0.0929203697887715, 0.08046895745792426, 0.1111143798334524, 10.928425434976816, 37.678253799676895, 27.67322726547718, 33.18806894123554, 30.448275357484818, 1.8573599285446107, 0.025369153154315427, 0.07356794143561274, 0.47414642467629164, 1.4122991915792227, 3.3671477576717734, 5.7172677386552095, 3.236489868722856, 4.217936592176557, 3.958923490718007, 1.9741702917963266, 0.8173893392086029, 0.17079517972888425, 13.303783424198627, 55.70500709116459, 55.64402416348457, 55.2332928031683, 51.66028752923012, 51.844995617866516, 52.34901577234268, 55.997701585292816, 52.386930137872696, 54.70261327922344, 54.59399230778217, 53.55224400758743, 51.390767991542816, 48.630919083952904, 45.957941114902496, 44.13248486816883, 41.851900443434715, 41.709020510315895, 39.4775028526783, 45.85783928632736, 52.220518067479134, 54.126218408346176, 53.79939414560795, 48.48588466644287, 52.01808772981167, 52.5501199811697, 47.72371016442776, 40.84056191146374, 39.3957844376564, 39.26820628345013, 37.96212136745453, 39.23817649483681, 38.995111137628555, 44.525900557637215, 46.34081616997719, 49.903573393821716, 46.84678182005882, 48.93262289464474, 50.29723607003689, 51.0883080214262, 52.56016284227371, 50.80233156681061, 50.96305914223194, 47.37029492855072, 53.35265971720219, 48.64616386592388, 48.0629825592041, 46.837077140808105, 48.25021751224995, 48.837977573275566, 48.28959859907627, 45.32748654484749, 40.462641790509224, 37.386209070682526, 36.74289979040623, 36.46534748375416, 36.83657616376877, 34.84068006277084, 38.64025577902794, 44.38364379107952, 48.23380619287491, 50.255377516150475, 50.03057397902012, 49.72962252795696, 47.420699223876, 46.93441651761532, 45.052734687924385, 45.38745492696762, 46.22555695474148, 46.81928649544716, 46.6235513985157, 46.74166426062584, 47.615248784422874, 47.174708023667336, 47.4279910326004, 42.53608413040638, 42.50881679356098, 42.13645577430725, 43.50959189236164, 48.38220722973347, 44.559361562132835, 48.99377301335335, 48.615415915846825, 47.98389360308647, 48.62157918512821, 37.549307718873024, 15.74133837595582, 1.962515723425895, 1.4986361400224268, 0.72683906997554, 3.177679949440062, 2.758487155660987, 3.4634723514318466, 2.9372801491990685, 6.18246965110302, 0.09045683284057304, 0.3148203802993521, 0.22048340644687414, 0.0408424498164095, 10.415650550276041, 34.86299626529217, 27.76713352650404, 30.135208256542683, 7.470756322145462, 0.14652889512944967, 0.07519720791606233, 0.05388122008298524, 0.03476892103208229, 0.015963576115609612, 0.025431990798097104, 0.030669017105537932, 0.006555033269250998, 0.062087009646347724, 0.02546130748669384, 0.0833568989764899, 0.06479852410848252, 0.04433864443853963, 0.07721072135609575, 0.03337170557642821, 0.09833386953687295, 0.049089495369116776, 0.029347817981033586, 0.0024520767965441337, 0.036638888268498704, 0.029237236121844035, 0.02644899101142073, 0.023327948329097126, 0.033493169175926596, 0.03072871175390901, 0.03749087751202751, 0.08108885856927373, 0.01312795044213999, 0.05456337996292859, 0.02835161460097879, 0.04958709054335486, 0.045985373653820716, 0.06338310748105869, 0.019975112518295646, 0.026111759107152466, 0.04946937107888516, 0.011732548609870719, 0.04709388995252084, 0.058701090747490525, 0.00250123920977785, 0.07847383443731815, 0.03434616774029564, 0.04440164164407179, 0.039146260169218294, 0.09915018003084697, 0.02922439140093047, 0.062265344022307545, 0.027289894424029626, 0.019985855105915107, 0.056740848667686805, 0.009861958897090517, 0.054493068892043084, 0.04325861176766921, 0.24791048315819353, 15.700609311461449, 43.44868876039982, 27.766441963613033, 41.754648461937904, 31.39854546636343, 1.5419737645424902, 0.021025628120696638, 0.07551223476184532, 0.3221620316617191, 0.3101054864237085, 2.4624968133866787, 4.5517235063016415, 5.785113573074341, 5.308307083323598, 5.208650780841708, 3.912412323988974, 2.1430816780775785, 0.11489919197629206, 17.15298067778349, 57.2809649258852, 57.187242954969406, 55.84905356168747, 53.71229141950607, 53.79833020269871, 55.71104496717453, 57.946316823363304, 53.510047271847725, 52.422078251838684, 55.08765421807766, 55.05067080259323, 53.28850395977497, 51.164056956768036, 48.84828262031078, 46.0900866240263, 44.1973739862442, 41.91935822367668, 40.22168532013893, 46.40038177371025, 55.051008984446526, 55.37518098950386, 54.9226138740778, 52.298630475997925, 52.65109956264496, 53.07756967842579, 49.534829780459404, 43.268821612000465, 40.973045602440834, 40.49972780048847, 40.121298506855965, 41.048980727791786, 40.25991126894951, 45.8187659829855, 48.74226450920105, 51.04129694402218, 51.464864015579224, 51.62117622792721, 51.9833005964756, 54.802217334508896, 53.56835514307022, 52.603222131729126, 49.30365398526192, 47.113565504550934, 54.68965597450733, 51.30099020898342, 51.627837270498276, 48.46766084432602, 50.539936646819115, 51.37319013476372, 49.32789288461208, 45.794838666915894, 43.958917781710625, 38.10156248509884, 38.32272581756115, 37.57353141903877, 38.96931812167168, 36.548756808042526, 40.486044734716415, 46.67126163840294, 51.401958391070366, 51.699079647660255, 50.49804389476776, 50.69524571299553, 50.12964606285095, 49.43023279309273, 46.36534385383129, 47.10323765873909, 49.919847920536995, 47.448110952973366, 49.0687657892704, 47.68594019114971, 49.689595475792885, 48.57640340924263, 47.61514239013195, 42.77381457388401, 43.30395832657814, 42.49796077609062, 44.778267815709114, 51.799512058496475, 45.88673673570156, 49.774954095482826, 46.50799959897995, 47.692468240857124, 49.54174540936947, 38.488419726490974, 19.615639932453632, 2.3107229825109243, 1.726434153970331, 2.946667307987809, 4.155869297683239, 4.704629676416516, 5.691664712503552, 5.075582871213555, 5.520291533321142, 0.4612929018912837, 0.1347830129088834, 0.2565504773519933, 0.03401896596187726, 10.699524767696857, 40.78501269221306, 28.924230337142944, 33.63160774111748, 11.225514393299818, 0.21514447027584538, 0.11692487663822249, 0.046810549101792276, 0.04381839891721029, 0.03240083540731575, 0.025100321290665306, 0.03579666568839457, 0.02957017841254128, 0.011314026487525553, 0.027042061628890224, 0.038605809677392244, 0.09178901018458419, 0.012270497136341874, 0.019928991750930436, 0.002022372596002242, 0.040064378481474705, 0.043803774897241965, 0.031224408885464072, 0.04039933570311405, 0.02629908089147648, 0.09632787405280396, 0.03550664921931457, 0.0076374435957404785, 0.04700690282334108, 0.09679546419647522, 0.17056582641089335, 0.2403152102488093, 0.12122039028326981, 0.15902606828603894, 0.09663919758168049, 0.12843122327467427, 0.15761496353661641, 0.24535268603358418, 0.2239113420364447, 0.17588896967936307, 0.15890527633018792, 0.06040063119144179, 0.09526376044959761, 0.15098195930477232, 0.0954374972207006, 0.20182306790957227, 0.08728505694307387, 0.21092231792863458, 0.14145594468573108, 0.24632304412079975, 0.1874436449725181, 0.14066551288124174, 0.10360771193518303, 0.14949462114600465, 0.19128841522615403, 0.14035685366252437, 0.1730067649623379, 0.18197903351392597, 0.2285833249334246, 17.97685816884041, 52.741462513804436, 37.61975593864918, 43.04161660373211, 39.16263274848461, 3.2626495650038123, 0.18197137454990298, 0.20740199979627505, 0.9144518652465194, 4.680602140724659, 10.883151814341545, 14.404696449637413, 9.817583542317152, 12.61091910302639, 9.526067934930325, 5.5743013601750135, 2.4123328551650047, 0.2913710073335096, 16.06090407818556, 60.35648949444294, 58.87119099497795, 59.99103270471096, 55.83354279398918, 56.569426506757736, 56.68116331100464, 59.960140362381935, 54.47193145751953, 54.92219589650631, 57.11883142590523, 57.05887824296951, 55.01704640686512, 52.53609873354435, 51.12489625811577, 47.57096216082573, 46.76103562116623, 45.936783850193024, 41.80416360497475, 49.259215369820595, 55.23630604147911, 57.68718592822552, 54.65527921915054, 52.99822613596916, 55.058889761567116, 56.237084940075874, 51.65996074676514, 44.430776461958885, 42.16133303940296, 42.18941733241081, 40.86690589785576, 43.5933393985033, 42.4580667167902, 47.82207928597927, 51.50624379515648, 53.93547244369984, 53.24688859283924, 52.97855459153652, 53.995934799313545, 54.83482338488102, 54.06858690083027, 55.086115300655365, 51.790369749069214, 47.157909125089645, 56.360756903886795, 54.08537060022354, 53.34312982857227, 49.19018067419529, 51.93006545305252, 53.6140400916338, 51.75068847835064, 48.88231359422207, 44.37072068452835, 40.664638951420784, 40.56351117789745, 39.13753129541874, 40.25668524205685, 38.64250145852566, 42.83459231257439, 48.4888257086277, 51.7617154866457, 55.11174872517586, 52.1367971599102, 52.7419450879097, 50.78427493572235, 51.283157765865326, 48.45124952495098, 50.233270302414894, 50.74445687234402, 48.741557747125626, 50.900001525878906, 48.922716826200485, 49.66743886470795, 50.305379033088684, 50.48977933824062, 45.786574110388756, 46.0992631316185, 46.139632165431976, 46.87270402908325, 53.93239080905914, 46.71632342040539, 51.083638072013855, 47.32144095003605, 47.49372750520706, 49.02258686721325, 37.7922210842371, 18.24840109795332, 3.03433311637491, 2.904601665213704, 4.137488733977079, 8.724577892571688, 8.655755035579205, 8.60870311036706, 11.288418117910624, 17.20108799636364, 1.8009923282079399, 0.6580931588541716, 0.690370051888749, 0.08299078268464655, 14.118486307561398, 46.6324695199728, 32.90713481605053, 42.93048396706581, 13.702311739325523, 0.2707051928155124, 0.224373655510135, 0.2075149695156142, 0.1843519022804685, 0.1927146449452266, 0.10686785535654053, 0.09997893634135835, 0.0980443503067363, 0.14728935901075602, 0.13974210305605084, 0.12965735513716936, 0.22218568541575223, 0.1073597434151452, 0.18158946535550058, 0.15361348137957975, 0.3380010661203414, 0.11293988500256091, 0.0892176762863528, 0.10600675625028089, 0.122694332676474, 0.1352379791205749, 0.08977646895800717, 0.12072790850652382, 0.14570594241376966], [0.05914463159570005, 0.025550558166287374, 0.011393633885745658, 0.0425795837509213, 0.06896670747664757, 0.045447665397659875, 0.07718819717410952, 0.034944553990499116, 0.04826650183531456, 0.11808894269051962, 0.009951727224688511, 0.03483821164991241, 0.036374097398947924, 0.08893954160157591, 0.036426381702767685, 0.05369778715248685, 0.07501938191126101, 0.05367648380342871, 0.05526577078853734, 0.05173355602892116, 0.025064056244445965, 0.04716124356491491, 0.09377254827995785, 0.09553086681989953, 0.032434313689009286, 0.07514295692089945, 0.02067118024569936, 0.0032792636966405553, 0.06130347239377443, 0.04295518097933382, 1.834216439165175, 28.096176870167255, 31.334868483245373, 24.177222959697247, 38.252114206552505, 18.859611600637436, 1.4148129941895604, 0.06873224076116458, 0.19771523599047214, 0.08864375864504836, 1.3061758736148477, 3.09550104662776, 3.5972189996391535, 2.856015572324395, 3.428643657825887, 3.3643791312351823, 1.2923192046582699, 0.196161208441481, 1.2417990155518055, 30.965744890272617, 53.144924864172935, 57.79660865664482, 51.551955342292786, 51.95096053183079, 55.975723564624786, 55.54392993450165, 54.60140570998192, 55.54833009839058, 53.88115435838699, 53.949353098869324, 51.411184296011925, 47.11330711841583, 45.0396291911602, 43.726966828107834, 40.66895171999931, 42.12390884757042, 40.444626957178116, 47.94526107609272, 53.725267723202705, 55.205174311995506, 47.25272923707962, 51.27951756119728, 54.055789187550545, 52.058620154857635, 45.97803823649883, 41.57523348927498, 38.61261986196041, 37.716301158070564, 37.90301933884621, 38.174689561128616, 36.90955884754658, 45.67091591656208, 48.87517377734184, 52.958088889718056, 49.658357352018356, 50.29427982866764, 51.527214869856834, 53.486002162098885, 50.721517503261566, 54.87378269433975, 39.39127787947655, 43.85247029364109, 53.033978417515755, 48.13787654042244, 51.66045092046261, 46.455353423953056, 47.377305552363396, 47.88284942507744, 47.411511316895485, 43.692426681518555, 38.52889895439148, 36.52307778596878, 38.241053000092506, 35.58406077325344, 36.9293861836195, 36.37344181537628, 37.845752611756325, 44.59297075867653, 47.70567253232002, 49.489407017827034, 49.17105250060558, 48.42869013547897, 47.45314568281174, 44.20995511114597, 40.68815968930721, 38.144108802080154, 40.73256030678749, 43.93431790173054, 44.97304916381836, 45.23672081530094, 45.24126157164574, 47.75914326310158, 48.017141819000244, 41.23877674341202, 41.80012062191963, 39.987697675824165, 46.509538516402245, 46.66760243475437, 48.87688748538494, 43.281341940164566, 51.076475456357, 42.159372344613075, 36.492348834872246, 20.416215173900127, 2.7254536282271147, 0.1218019965745043, 1.371695757843554, 1.454223885666579, 2.034704606048763, 3.619122924283147, 4.169955141842365, 3.214067746885121, 3.4985900670289993, 0.23185558762634173, 0.07177261199103668, 0.08776095914072357, 1.4965551579371095, 23.956204019486904, 35.794653072953224, 28.17325383424759, 24.798341430723667, 2.20668385270983, 0.049429981590947136, 0.03815352261881344, 0.051984747042297386, 0.08711255213711411, 0.09761787514435127, 0.05449404852697626, 0.05936641129665077, 0.013153513718862087, 0.08748187450692058, 0.04898185798083432, 0.08106964436592534, 0.04257362801581621, 0.03384181531146169, 0.01810086308978498, 0.01979025651962729, 0.06859746674308553, 0.027444691586424597, 0.038913396492716856, 0.06735877032042481, 0.010554768596193753, 0.053380359458969906, 0.021369554197008256, 0.0492391680018045, 0.03377531516889576, 0.06271605030633509, 0.04286947034415789, 0.04038046288769692, 0.07112528852303512, 0.048742697181296535, 0.02575615348177962, 0.0171481458528433, 0.05356341018341482, 0.056091365549946204, 0.06710904504870996, 0.021983840961183887, 0.010660862317308784, 0.028688675811281428, 0.0846681700204499, 0.03592618159018457, 0.022145074399304576, 0.018761239080049563, 0.039596454371348955, 0.013119200521032326, 0.05418444678070955, 0.04012064069684129, 0.020387780023156665, 0.04826386721106246, 0.03744899069715757, 0.05916037625866011, 0.06914166136994027, 0.013452439670800231, 0.03292642439191695, 0.040701983525650576, 0.12259854367584921, 2.907270547002554, 35.965385511517525, 34.558446407318115, 27.92986549437046, 46.623194217681885, 17.58083201944828, 1.1884718458168209, 0.048846701756701805, 0.24268174107419327, 0.20313310698838905, 0.7941320340614766, 3.1898143608123064, 6.082625258713961, 5.4295015800744295, 5.391936795786023, 3.546450873836875, 2.4467366840690374, 0.5729805759619921, 2.2045728284865618, 36.143535152077675, 55.44523403048515, 58.874401822686195, 54.72981981933117, 54.234976172447205, 57.28785775601864, 57.22056716680527, 54.96074102818966, 56.35169059038162, 55.86095072329044, 54.30552318692207, 52.41029888391495, 48.4444060921669, 46.3015528768301, 45.3050297498703, 41.9974934309721, 42.819936498999596, 41.582612693309784, 50.10369345545769, 55.595325976610184, 57.27456986904144, 49.865241050720215, 52.586404234170914, 55.88991276919842, 54.191928282380104, 47.90497563779354, 43.93915884196758, 40.03719761967659, 40.92776723206043, 39.891106858849525, 40.32480038702488, 39.808339700102806, 46.97867274284363, 49.95229437947273, 54.720802903175354, 50.72452314198017, 54.14785824716091, 50.9246052056551, 56.39928303658962, 50.11646457016468, 55.77948309481144, 42.789047956466675, 45.579466223716736, 57.82049797475338, 51.51597507297993, 53.27662579715252, 49.147087186574936, 51.43248975276947, 50.5387207120657, 49.85076382756233, 45.56802123785019, 41.15322433412075, 37.76454716920853, 39.27935868501663, 36.91250368952751, 38.586032688617706, 37.50030554831028, 39.85683269798756, 47.36903339624405, 49.533914029598236, 53.51580776274204, 51.06424391269684, 50.20081244409084, 48.58513154089451, 45.64025156199932, 43.307161554694176, 40.40363475680351, 43.29944036900997, 46.185689494013786, 48.785376995801926, 46.856661289930344, 46.69410981237888, 49.48700554668903, 49.15341004729271, 44.79474753141403, 43.91508713364601, 41.73970006406307, 47.1053883433342, 46.69965751469135, 49.84514392912388, 45.60841307044029, 52.24547512829304, 43.68585683405399, 38.53911280632019, 22.035669274628162, 4.90138596855104, 0.5650276027154177, 4.263247260823846, 2.7431231550872326, 3.417837512679398, 7.4909864366054535, 6.052101496607065, 3.528387355618179, 0.7855293550528586, 0.03023947687324835, 0.10653545483364724, 0.0853610761987511, 1.0524568380787969, 26.592774242162704, 40.20444184541702, 31.21058665215969, 30.072673112154007, 3.72215558309108, 0.14933946775272489, 0.06659349732217379, 0.039590947635588236, 0.03632255153206643, 0.03154088662995491, 0.013188626580813434, 0.019358430472493637, 0.051767230979749, 0.03983475427958183, 0.01194543738165521, 0.024550042908231262, 0.04513758496614173, 0.024505488072463777, 0.009081676889763912, 0.03938507958082482, 0.11030541660147719, 0.03802736122452188, 0.04721992889244575, 0.09879767472739331, 0.05781012761872262, 0.05875459588423837, 0.03550239671312738, 0.039791175368009135, 0.03859009470033925, 0.1706219179322943, 0.1412458426784724, 0.1462751696817577, 0.21997745468979701, 0.20098451524972916, 0.08332624085596763, 0.15814288286492229, 0.18119995656888932, 0.12181192651041783, 0.24736976920394227, 0.1335250132251531, 0.12073852863977663, 0.09731136815389618, 0.22965305659454316, 0.10737898730440065, 0.11195570070412941, 0.19198587076971307, 0.17775821703253314, 0.17350064939819276, 0.19003149907803163, 0.10240874267765321, 0.08380569794098847, 0.17556882201461121, 0.1229237973166164, 0.14286396210081875, 0.2013794268714264, 0.07243347223266028, 0.10214902809821069, 0.22840669378638268, 0.25514683860819787, 2.963626985438168, 40.06658524274826, 42.74905130267143, 32.058993726968765, 48.381656259298325, 25.822251588106155, 1.95108498679474, 0.25858912733383477, 0.4986088292207569, 1.1366679193452, 6.500294096767902, 10.142987631261349, 12.274863235652447, 9.85631961375475, 8.243090528994799, 7.627896415069699, 4.183904193341732, 0.4466992209199816, 2.2230707108974457, 34.62911121547222, 57.43944302201271, 60.515127182006836, 58.19621801376343, 56.076334565877914, 58.92766356468201, 58.92535708844662, 56.456979140639305, 58.21622394025326, 58.905297964811325, 58.006402999162674, 55.65338306128979, 51.28976561129093, 48.21001946926117, 46.38624273240566, 42.35627397894859, 43.98924395442009, 44.431506022810936, 52.23950944840908, 57.585404589772224, 58.17530773580074, 48.77370782196522, 53.94998386502266, 58.10897469520569, 57.20159098505974, 49.950136095285416, 46.380843222141266, 43.2141425460577, 41.483251824975014, 41.12605199217796, 42.27324843406677, 41.228904873132706, 48.46196874976158, 53.51879820227623, 56.66944473981857, 54.47215564548969, 55.63340753316879, 53.99761810898781, 58.29106852412224, 50.550690069794655, 56.14992521703243, 45.833520591259, 47.61714108288288, 58.393332436680794, 51.97097785770893, 54.22473952174187, 51.81088864803314, 51.493016704916954, 51.05835422873497, 51.8320307135582, 48.068712651729584, 42.612794414162636, 39.76141221821308, 41.42772540450096, 38.38701456785202, 39.575058817863464, 40.02586282789707, 41.853564754128456, 48.29401396214962, 51.36274069547653, 52.75490619242191, 51.073245629668236, 51.70905411243439, 50.56790694594383, 46.59575589001179, 44.66375716030598, 41.95870891213417, 43.475465923547745, 48.09585839509964, 49.37904193997383, 48.898930102586746, 47.683420926332474, 51.72482326626778, 51.144666597247124, 45.47301113605499, 45.017096400260925, 43.40993843972683, 50.5063084512949, 51.68389566242695, 51.039210855960846, 46.921645402908325, 53.96661937236786, 49.021804109215736, 41.31990239024162, 21.86558660119772, 3.3038882771506906, 0.4837127972859889, 5.284656677395105, 4.999203644692898, 5.377525594085455, 9.646420776844025, 11.751447971910238, 8.91195248812437, 8.778173066675663, 0.9629828017205, 0.5477978428825736, 0.36099324643146247, 2.4100883631035686, 30.8083763346076, 43.90242621302605, 36.67988397181034, 37.658350467681885, 4.585534567013383, 0.22832876828033477, 0.20509331196080893, 0.1731010919320397, 0.15132426749914885, 0.18446594069246203, 0.09486234761425294, 0.1829003801685758, 0.11051410110667348, 0.15618301928043365, 0.14890234277117997, 0.23030417243717238, 0.17222638183739036, 0.08143144135829061, 0.07763859175611287, 0.12124870321713388, 0.32793439691886306, 0.13289945694850758, 0.19382703525479883, 0.14980513573391363, 0.15368627122370526, 0.13575567165389657, 0.11032446011085995, 0.15452823776286095, 0.1339372168877162], [0.06924899818841368, 0.031012889376142994, 0.03385941905435175, 0.024007451320358086, 0.06102273277065251, 0.023725238534098025, 0.057731066626729444, 0.06243775234906934, 0.08703525003511459, 0.05543971165025141, 0.010959034061670536, 0.05447140931210015, 0.030533834906236734, 0.02412450656265719, 0.024944459146354347, 0.04276569954527076, 0.08775345602771267, 0.014824039899394847, 0.09733474580571055, 0.06063552093110047, 0.047033946684678085, 0.030347275678650476, 0.012684375269600423, 0.0748125156678725, 0.07217387639684603, 0.06014541031618137, 0.00701765195117332, 0.05790453993540723, 0.05093536135973409, 0.0423516479349928, 0.09287113571190275, 11.487979609519243, 34.13348861038685, 26.193653158843517, 30.698214545845985, 33.42055946588516, 13.068225514143705, 2.5641415966674685, 0.2240717943641357, 0.14542690973030403, 0.3017627965891734, 1.300620452966541, 3.9552956353873014, 3.17052208352834, 3.80210068076849, 2.910531722009182, 1.7394741042517126, 0.980811920017004, 0.1680860438500531, 6.036754120141268, 36.30770914256573, 52.05981329083443, 56.67259857058525, 54.873562306165695, 55.336476266384125, 53.32273632287979, 54.056723937392235, 52.51633979380131, 56.23652637004852, 51.6420941054821, 51.25041872262955, 47.921519950032234, 48.84599894285202, 44.583877846598625, 44.52939257025719, 39.928588047623634, 44.487450420856476, 49.19580057263374, 53.36902543902397, 53.340454772114754, 51.27925917506218, 53.16887117922306, 56.20202422142029, 52.40938313305378, 51.823564767837524, 42.9588608443737, 39.99790772795677, 39.1861192882061, 39.85001966357231, 38.60897205770016, 38.677683770656586, 47.253375202417374, 49.8908706754446, 51.625914573669434, 53.72651405632496, 51.09114646911621, 53.94340641796589, 51.65587596595287, 50.34619644284248, 44.45776641368866, 44.19730558991432, 52.14243225753307, 49.10522863268852, 51.313848719000816, 49.29439768195152, 47.30008989572525, 46.1834704130888, 44.59685035049915, 42.78137996792793, 40.3824432939291, 36.136049553751945, 36.74555204808712, 37.989738285541534, 37.090964913368225, 38.01515892148018, 37.3623501509428, 38.108060136437416, 40.07489539682865, 45.93816317617893, 47.18317396938801, 47.27030709385872, 43.98069441318512, 42.20480650663376, 38.96064318716526, 37.82361499965191, 37.38435477018356, 35.958568677306175, 35.79048089683056, 37.74801425635815, 40.30461587011814, 43.463899344205856, 42.37003304064274, 42.142033874988556, 40.42401686310768, 40.266306325793266, 39.665269777178764, 46.39997139573097, 45.83721399307251, 50.27360513806343, 44.84498843550682, 39.67974320054054, 39.18286666274071, 21.06275998055935, 2.719015823677182, 0.6359101866837591, 0.4695299395825714, 2.7597560500726104, 1.8158927536569536, 2.9421690618619323, 4.7331685200333595, 3.8834153674542904, 2.9819885501638055, 0.5971427075564861, 0.1935024792328477, 0.0670504079607781, 0.4139777220552787, 9.696511588990688, 34.162203669548035, 26.796599105000496, 28.441677130758762, 13.72371694073081, 0.13316094526089728, 0.0352625271625584, 0.044981578103033826, 0.047364803540403955, 0.012291942421143176, 0.05705543022486381, 0.08746938416152261, 0.058242851664545015, 0.05162898371054325, 0.011744222592824372, 0.04386551787320059, 0.09588732777046971, 0.021604080284305383, 0.06560342037118971, 0.03966059819504153, 0.013127885504218284, 0.05967812074231915, 0.024116721433529165, 0.05211096409766469, 0.08627026647445746, 0.12225622805999592, 0.013825789119437104, 0.007937189620861318, 0.023969488611328416, 0.08177460302249528, 0.049890191075974144, 0.04106182495888788, 0.030292672163341194, 0.03178399936587084, 0.009916105063894065, 0.02104766248521628, 0.03399739172891714, 0.033269701089011505, 0.006148958354970091, 0.029058515829092357, 0.023586601637362037, 0.02690547120437259, 0.016207867010962218, 0.013008495279791532, 0.07433302147546783, 0.0643596550798975, 0.08910229458706453, 0.03844904953439254, 0.054373998718801886, 0.011185216553712962, 0.0260962593529257, 0.05034925023210235, 0.012362171855784254, 0.02685742456378648, 0.04424566817760933, 0.07643758901394904, 0.027768635336542502, 0.03870636697683949, 0.0033444671680626925, 0.03659672314825002, 0.15538056468358263, 16.40460703521967, 39.37287926673889, 26.250976882874966, 35.769999995827675, 38.96332584321499, 13.807075917720795, 1.9897125265561044, 0.13111003499943763, 0.07775052246870473, 0.2939998428337276, 0.31856911664362997, 5.191237265244126, 5.387824941426516, 3.2431611232459545, 4.880265276879072, 3.1005939608439803, 2.4669734481722116, 0.12818916438845918, 9.364047478884459, 40.60557872056961, 54.74615894258022, 57.63059936463833, 58.13555806875229, 56.31131395697594, 54.97684456408024, 55.243829637765884, 53.613386526703835, 56.99495427310467, 54.33880180120468, 53.65179106593132, 49.480139315128326, 50.202769339084625, 47.510742992162704, 46.6242391616106, 42.388492450118065, 44.14346247911453, 52.45739355683327, 54.63072493672371, 55.24310767650604, 50.75440853834152, 54.67447578907013, 57.54257328808308, 54.84221398830414, 52.290673702955246, 44.50631260871887, 41.4283599704504, 40.39100423455238, 40.19772760570049, 40.770147889852524, 39.199707359075546, 48.50909002125263, 52.00746729969978, 54.227585569024086, 53.91995407640934, 53.569935858249664, 55.14175571501255, 53.53358320891857, 50.3865996748209, 45.17002299427986, 44.71168018877506, 52.65590250492096, 51.6352316737175, 53.37694801390171, 50.570327416062355, 49.61039252579212, 47.52645894885063, 47.73119576275349, 44.2564532160759, 42.513406947255135, 38.322353437542915, 37.94851429760456, 37.57337562739849, 37.95184671878815, 38.77541072666645, 39.367247968912125, 39.54805366694927, 41.546640023589134, 47.015629559755325, 48.999738693237305, 49.492503851652145, 46.80051930248737, 44.68567058444023, 40.217684134840965, 39.00651812553406, 38.982359021902084, 37.3935616761446, 36.05561167001724, 40.06838634610176, 43.66880714893341, 45.603921711444855, 45.89020594954491, 44.76849094033241, 42.90203109383583, 41.110951602458954, 42.85525940358639, 47.81549423933029, 48.063062354922295, 50.052643194794655, 45.70357896387577, 41.36752903461456, 43.64707611501217, 23.924148939549923, 4.571331879124045, 1.1154125723987818, 1.9440238969400525, 3.7237880704924464, 5.109255714341998, 5.3264145366847515, 6.153421634808183, 6.214106278494, 3.1866013957187533, 0.45403558819089085, 0.1270913943881169, 0.026591149398882408, 0.22061075898818672, 9.24195908010006, 39.977320432662964, 30.298684984445572, 31.48848094046116, 19.41777504980564, 0.4011164215626195, 0.07630536056240089, 0.032013586460379884, 0.047435173983103596, 0.033216259034816176, 0.08433408482233062, 0.054573298766626976, 0.07120852780644782, 0.0766856518748682, 0.028633849651669152, 0.0448933886946179, 0.016789807268651202, 0.04458314499061089, 0.062200840256991796, 0.017480225396866444, 0.059676907330867834, 0.017305703804595396, 0.05432486112113111, 0.04461860109586269, 0.029614735103677958, 0.06769059196813032, 0.04016892853542231, 0.031020323840493802, 0.040543753930251114, 0.030980390729382634, 0.2045244409237057, 0.11841617044410668, 0.12613187165698037, 0.15468307945411652, 0.18233928683912382, 0.12219800657476299, 0.11589126530452631, 0.09896024959743954, 0.1491906968294643, 0.14276029891334474, 0.12759293778799474, 0.09916667055222206, 0.14764312596525997, 0.1598115128581412, 0.2738909359322861, 0.1739235845161602, 0.189363076351583, 0.12530743464594707, 0.12624810682609677, 0.11120023889816366, 0.1687227768707089, 0.10020279776654206, 0.14045683579752222, 0.23375869175652042, 0.12189693210530095, 0.2273413259536028, 0.13806863425998017, 0.1518820211640559, 0.1280871339258738, 0.19688802334712818, 0.2570813801139593, 17.777423970401287, 48.61616067588329, 35.15441782772541, 40.59224143624306, 42.523225620388985, 18.90513315796852, 3.8615273544564843, 0.644231146434322, 0.22298993600998074, 1.0450754966586828, 7.317568967118859, 9.388944692909718, 9.293137583881617, 11.075772978365421, 9.235963951796293, 5.8083241526037455, 2.9591104527935386, 0.3381837235065177, 7.368576005101204, 41.41373075544834, 57.077694833278656, 60.150483548641205, 60.48565596342087, 58.31911861896515, 56.378634944558144, 55.47443926334381, 54.17286470532417, 59.685658290982246, 56.071448028087616, 54.32382680475712, 51.74244672060013, 53.10273952782154, 49.66419383883476, 48.30586552619934, 43.79092499613762, 47.1624156832695, 54.763816595077515, 58.096203580498695, 55.11793099343777, 52.26170405745506, 54.23898495733738, 61.56842686235905, 57.01778344810009, 56.4382803440094, 47.87384390830994, 43.274259120225906, 42.05230928957462, 43.99732232093811, 42.36754797399044, 41.84430085122585, 50.88017039000988, 54.20863978564739, 56.68951526284218, 56.214533150196075, 53.924931809306145, 57.85316862165928, 55.12819044291973, 52.71679423749447, 46.2275480479002, 48.73890928924084, 55.334906950592995, 53.109396770596504, 54.82328720390797, 52.262365221977234, 51.16066373884678, 50.489129573106766, 48.6835690587759, 46.081552281975746, 43.23846124112606, 39.19224835932255, 40.060782954096794, 41.90564475953579, 40.19420899450779, 41.8253930658102, 40.92623591423035, 42.7244970202446, 43.440496399998665, 49.397577345371246, 52.158015221357346, 51.15525282919407, 48.28377351164818, 46.75239868462086, 42.8424920886755, 40.36615736782551, 40.661131739616394, 39.308723509311676, 38.11235770583153, 42.14266084134579, 42.78044141829014, 46.73006348311901, 46.74141347408295, 46.67416848242283, 45.15535958111286, 42.79202699661255, 44.12205822765827, 50.13257950544357, 50.22981248795986, 52.39990644156933, 44.94528405368328, 42.97442480921745, 42.85191938281059, 24.113920256495476, 3.6419851100072265, 1.9276446383446455, 2.3430547351017594, 5.771204894408584, 4.788500675931573, 10.462182853370905, 12.572301775217056, 9.974598716944456, 11.674929577857256, 2.049670577980578, 0.42854225146584213, 0.3003740304848179, 0.629062419757247, 12.256491221487522, 44.59465026855469, 34.837765619158745, 39.01620760560036, 22.608993910253048, 0.5806595482863486, 0.1812413684092462, 0.16347099852282554, 0.13207703857915476, 0.14568627550033852, 0.11529998882906511, 0.24202673637773842, 0.25892600300721824, 0.274109928868711, 0.13361518416786566, 0.16234893060754985, 0.14254783687647432, 0.10701171326218173, 0.25587942742276937, 0.09515852390904911, 0.15835886268178, 0.16944556933594868, 0.14521220640745014, 0.16872576030436903, 0.15643846651073545, 0.12645466136746109, 0.19627585541456938, 0.08382515705307014, 0.07128164419555105, 0.15011431445600465], [0.019036672347283456, 0.03807875866186805, 0.052489611553028226, 0.03134435479296371, 0.015795091894688085, 0.03544245344528463, 0.02771546602161834, 0.05408460936450865, 0.042393382609589025, 0.05167205054021906, 0.0409906233107904, 0.028593771821761038, 0.03440602566115558, 0.029623152913700324, 0.08526050034561194, 0.04526541619270574, 0.0400291672849562, 0.03976422427513171, 0.036643882922362536, 0.056729371353867464, 0.07586830979562365, 0.10048948199255392, 0.04780206210853066, 0.01958438104338711, 0.047316972122644074, 0.04374825854029041, 0.05022210178140085, 0.04610251424310263, 0.10300437555997632, 0.01407769352226751, 0.05427380878245458, 1.1022168304771185, 20.657640919089317, 37.20240153372288, 29.28649339824915, 36.133906468749046, 32.96994924545288, 14.867294076830149, 3.2553791301324964, 0.1338805168052204, 0.32792406622320414, 0.14870979997795075, 5.265504755079746, 5.59555409476161, 2.3583745630457997, 2.2684234147891402, 1.807652183342725, 1.936550410464406, 0.3542532690335065, 0.635079515632242, 11.619234066456556, 34.77301329374313, 50.899074375629425, 56.68199926614761, 55.35636439919472, 55.810607224702835, 52.98037089407444, 52.74979546666145, 55.99725320935249, 54.174111038446426, 53.195834532380104, 52.23908767104149, 50.41505254805088, 47.645175978541374, 44.210319891572, 39.34972330927849, 43.86007368564606, 49.65130873024464, 53.779308423399925, 52.76841066777706, 52.6317548006773, 51.10612906515598, 55.88083505630493, 54.75961782038212, 52.75460220873356, 47.66162149608135, 42.00045347213745, 37.5118987262249, 38.23780417442322, 38.309095948934555, 39.70282316207886, 45.25873303413391, 53.782542049884796, 52.38634496927261, 54.17427442967892, 53.498324900865555, 52.98336513340473, 46.09004482626915, 52.45188385248184, 44.00021776556969, 42.92045630514622, 54.225894659757614, 49.5512904971838, 51.960965394973755, 49.03925657272339, 45.63725732266903, 42.1566516906023, 41.41545966267586, 38.29564467072487, 36.36433370411396, 36.085257679224014, 36.79288990795612, 37.514262199401855, 38.931730538606644, 39.01314876973629, 39.7250671684742, 38.045177310705185, 37.84138284623623, 39.01587322354317, 41.63834050297737, 39.67112526297569, 37.97107368707657, 37.5920744240284, 38.782067969441414, 42.17659682035446, 42.25934877991676, 44.99611012637615, 41.77252270281315, 39.568439573049545, 33.81271742284298, 35.519680827856064, 37.63501591980457, 37.486478090286255, 37.59989820420742, 40.78392595052719, 45.22809907793999, 45.960144996643066, 48.74140955507755, 49.47534777224064, 51.59580118954182, 44.51248347759247, 20.74812736362219, 2.692256234586239, 0.2106753460248001, 0.6213646859396249, 1.6517534363083541, 4.619558891281486, 4.877136619761586, 2.7461344934999943, 11.26774437725544, 5.25937900878489, 1.9052050611935556, 0.24596480943728238, 0.06659450664301403, 0.1752755104098469, 4.8831763956695795, 28.02247792482376, 33.03190492093563, 28.923903554677963, 26.977655589580536, 5.006635095924139, 0.11637110830633901, 0.08304752729600295, 0.03280821882071905, 0.07470339027349837, 0.052848514169454575, 0.07840963124181144, 0.048657684164936654, 0.013243360899650725, 0.05641123490931932, 0.10489350504940376, 0.06709548601065762, 0.025620355299906805, 0.043805611712741666, 0.046527304730261676, 0.02841955079929903, 0.08415340897045098, 0.054794930038042367, 0.039248646862688474, 0.07080093288095668, 0.07142873044358566, 0.01402735642841435, 0.03818803248577751, 0.058290145025239326, 0.08614198624854907, 0.030743523166165687, 0.03437876657699235, 0.030123785327305086, 0.019974630122305825, 0.04430622371728532, 0.043985745796817355, 0.01869309322501067, 0.021400696568889543, 0.05837856078869663, 0.03276206836744677, 0.025796218324103393, 0.030021146303624846, 0.033739632708602585, 0.04186602731351741, 0.021574234815489035, 0.04714407026767731, 0.03045356792426901, 0.05454802492749877, 0.07327652230742387, 0.011757737102016108, 0.04133728420129046, 0.020508898523985408, 0.019890407493221574, 0.04756926522532012, 0.03289444153779186, 0.008038392588787246, 0.04308681200200226, 0.043549266483751126, 0.006582693577001919, 0.03866834675136488, 0.014392333523574052, 0.05937484580499586, 2.3886249773204327, 28.591250404715538, 40.37985563278198, 29.398387894034386, 40.662435069680214, 37.01015084981918, 15.062129572033882, 3.0073346151039004, 0.12466889078496024, 0.35653736209496856, 0.09187481729895808, 1.7926399013958871, 4.9228533916175365, 3.5913145914673805, 4.4084493443369865, 3.649971568956971, 3.890343583188951, 1.1169666890054941, 1.1585727939382195, 15.222727004438639, 40.77966257929802, 54.15688656270504, 59.32101085782051, 56.91419340670109, 58.417043164372444, 53.38915675878525, 54.444280341267586, 56.44713766872883, 56.68294161558151, 53.58736552298069, 52.75708727538586, 52.33358480036259, 49.82104182243347, 46.06614030897617, 40.15161707997322, 46.446477100253105, 52.24774360656738, 56.56609408557415, 55.732289627194405, 52.46012181043625, 50.95295548439026, 57.66946367919445, 55.57049050927162, 53.38188774883747, 48.36211010813713, 43.34539130330086, 40.051659643650055, 40.591561272740364, 40.37741616368294, 40.10836400091648, 47.942631617188454, 54.90771487355232, 54.2040990293026, 54.717117100954056, 54.573568403720856, 54.08975936472416, 48.54285500943661, 52.054539173841476, 44.07335244119167, 45.355662032961845, 56.81265905499458, 52.482886388897896, 53.37999165058136, 50.847777128219604, 47.296149507164955, 45.222395583987236, 44.066657200455666, 41.54348999261856, 37.93041966855526, 39.23760272562504, 39.14331078529358, 39.6334008872509, 40.01983255147934, 40.940811932086945, 41.006096228957176, 39.24425236880779, 39.248755127191544, 42.10985340178013, 44.614515602588654, 43.02756875753403, 40.706322714686394, 39.290518686175346, 40.43058671057224, 43.40350918471813, 44.805622547864914, 45.66050827503204, 42.06886500120163, 39.94758702814579, 35.1460886746645, 37.415296509861946, 38.83134372532368, 38.75097803771496, 39.4375441968441, 42.062686532735825, 45.418320670723915, 49.58836130797863, 48.1052552908659, 49.77270841598511, 49.936122447252274, 45.60200281441212, 24.34432089328766, 5.3947244212031364, 0.723966364748776, 2.2795328311622143, 3.0753241293132305, 4.963461812585592, 7.208771305158734, 7.632391098886728, 13.469673972576857, 5.242242878302932, 0.7173461106140167, 0.16044784511905164, 0.068074208102189, 0.24521114362869412, 3.7962010223418474, 29.714631624519825, 38.583194240927696, 30.76602190732956, 33.11725974082947, 7.184230322018266, 0.12462305574445054, 0.039457105012843385, 0.07553998366347514, 0.045508532639360055, 0.054867697617737576, 0.08703894593054429, 0.012341882465989329, 0.022231143120734487, 0.00516233517373621, 0.0482059166097315, 0.03425144743232522, 0.07199347513960674, 0.004585286596920923, 0.016630312311463058, 0.026546344088274054, 0.04352767369709909, 0.03186883797752671, 0.02119099532137625, 0.047067224586498924, 0.12257657610462047, 0.03700323082739487, 0.015269585474015912, 0.01554407250296208, 0.051935731898993254, 0.015868751906964462, 0.11698914662702009, 0.08972799929324538, 0.1297736496780999, 0.11027996835764498, 0.09237935155397281, 0.13428016332909465, 0.1551173991174437, 0.172214730118867, 0.1415515036205761, 0.18596712732687593, 0.11123821459477767, 0.1416335703106597, 0.11136800880194642, 0.15657426469260827, 0.14043644157936797, 0.15155572851654142, 0.18679374625207856, 0.19223900249926373, 0.08203854042221792, 0.1788512521306984, 0.16593757085502148, 0.27397221594583243, 0.12644348462345079, 0.13468209566781297, 0.12083089633961208, 0.17039244587067515, 0.16945042298175395, 0.07354967718129046, 0.20753091084770858, 0.10196870847721584, 0.22225065302336589, 2.2741435328498483, 31.872560530900955, 51.29124753177166, 38.609439432621, 44.540788158774376, 42.53755085170269, 19.557820335030556, 4.431632850319147, 0.24720949499169365, 0.6402589345816523, 1.287473514676094, 14.563720766454935, 16.4063910394907, 7.81795984134078, 9.233664125204086, 7.1891106851398945, 7.662914860993624, 1.6042572911828756, 1.29638712387532, 13.585980031639338, 37.74896040558815, 53.97604666650295, 59.52949047088623, 60.018117651343346, 58.67659203708172, 53.84525008499622, 55.81046663224697, 58.668202087283134, 59.5724243670702, 58.41632500290871, 55.21207094192505, 54.13548991084099, 51.24707870185375, 48.13713937997818, 42.5285529345274, 47.98313744366169, 53.69152553379536, 59.32334013283253, 56.042573377490044, 54.844877645373344, 52.82948479056358, 58.74540254473686, 58.70466113090515, 54.6559289842844, 50.90371772646904, 46.49968944489956, 43.16910736262798, 42.427968531847, 41.439014598727226, 42.628126591444016, 50.61689391732216, 57.69555687904358, 57.16042399406433, 56.50840938091278, 56.788727939128876, 53.210729733109474, 48.883278742432594, 52.515754625201225, 48.45946468412876, 47.61969454586506, 56.79810203611851, 56.26628257334232, 54.30583097040653, 53.082798197865486, 48.564240261912346, 47.022807374596596, 45.94717249274254, 43.955368772149086, 39.418940395116806, 41.39929912984371, 41.66673257946968, 42.47518099844456, 41.793220192193985, 44.055406004190445, 43.08681517839432, 41.98431193828583, 40.8736315369606, 42.96943187713623, 45.676862597465515, 44.25094351172447, 42.0358257740736, 41.0194943100214, 42.04653359949589, 46.56760700047016, 47.04760864377022, 50.16212671995163, 46.095159351825714, 43.34686182439327, 37.435686215758324, 38.23791816830635, 40.256134271621704, 39.98300492763519, 41.30844980478287, 43.659326657652855, 49.07012611627579, 51.258253902196884, 52.27048918604851, 51.80894695222378, 51.7622322589159, 47.20178157091141, 21.63419421762228, 3.5534083005040884, 0.57524204836227, 2.31435083784163, 5.141675574705005, 11.056844294071198, 12.26741848513484, 7.9698737896978855, 20.14998435974121, 13.497410584241152, 4.06946905888617, 0.6844167213421315, 0.2597424545092508, 0.3863508888753131, 7.174427323043346, 34.50172305107117, 43.63864816725254, 37.740148678421974, 40.33620737493038, 9.012848474085331, 0.22253140748944134, 0.30171141028404236, 0.19264979608124122, 0.15403144410811365, 0.1463527389569208, 0.18801641970640048, 0.15651187975890934, 0.10340907610952854, 0.13342040008865297, 0.16822384583065286, 0.20105824019992724, 0.31122986983973533, 0.09874907147604972, 0.14934409875422716, 0.19289561023470014, 0.1444206910673529, 0.1792769183521159, 0.15727115620393306, 0.24690079124411568, 0.1947568720788695, 0.08672160358401015, 0.2004444840713404, 0.17880379920825362, 0.1948455735691823, 0.12202737198094837], [0.033982838212978095, 0.10700252547394484, 0.05923647608142346, 0.028727414064633194, 0.08434834147919901, 0.04109941473871004, 0.05379543152230326, 0.011039152614102932, 0.03516815195325762, 0.014022006471350323, 0.062468313990393654, 0.08062861568760127, 0.07837293203920126, 0.018872880355047528, 0.03584835256333463, 0.026983923635270912, 0.08791939282673411, 0.02589106294180965, 0.07913953348179348, 0.0258390198359848, 0.005037120017732377, 0.028606861451407894, 0.023592115794599522, 0.04963614650478121, 0.06939409548067488, 0.02682880178326741, 0.026393478365207557, 0.022104760937509127, 0.07896230119513348, 0.02578456660558004, 0.04571294608467724, 0.051160361981601454, 3.2027044566348195, 29.990246035158634, 33.289325907826424, 24.787595607340336, 33.6982561647892, 35.274081006646156, 19.36472799628973, 2.7602127380669117, 0.22416987660108134, 0.11491155615658499, 0.6048206111881882, 1.9204043643549085, 1.6614116868004203, 4.4965276680886745, 1.7252750974148512, 2.5314690498635173, 0.558891169494018, 0.03953000246838201, 1.385669270530343, 13.339600302278996, 28.589701987802982, 45.988981649279594, 53.00845518708229, 56.25583313405514, 51.736063063144684, 53.47720183432102, 53.14269058406353, 52.66312971711159, 51.98830492794514, 51.676611453294754, 51.39596611261368, 48.10347318649292, 44.28771033883095, 41.86804957687855, 43.563643991947174, 47.385114133358, 51.59289054572582, 55.51735796034336, 52.49165631830692, 52.797973081469536, 51.571927070617676, 54.98977147042751, 54.05173860490322, 52.28272832930088, 48.5928413271904, 39.8265141248703, 38.88652816414833, 38.54432612657547, 37.623141556978226, 44.26273047924042, 52.85828344523907, 53.453673496842384, 56.462089866399765, 53.335165455937386, 56.03745885193348, 47.791126146912575, 52.01335318386555, 45.99143251776695, 45.83090253174305, 60.061575919389725, 50.130375623703, 51.48083455860615, 48.279012367129326, 44.661458283662796, 38.85699614882469, 38.89097012579441, 38.03472027182579, 37.73973070085049, 36.583502143621445, 38.63513745367527, 37.12547846138477, 39.40650746226311, 43.04779127240181, 43.753603398799896, 41.90008945763111, 36.99899464845657, 36.15541711449623, 35.85358791053295, 39.387580677866936, 38.70789214968681, 41.23937711119652, 43.5068142414093, 48.20255666971207, 48.453054428100586, 46.97219409048557, 49.753720834851265, 47.018072828650475, 41.97574719786644, 36.88909314572811, 37.11570158600807, 40.02989061176777, 41.76594525575638, 43.767503052949905, 47.15929985046387, 46.1889573186636, 48.65734666585922, 46.5989401191473, 42.09845781326294, 18.695393912494183, 1.5389722818508744, 0.19354595424374565, 1.3056569639593363, 2.1231173118576407, 1.3272089324891567, 1.7653108178637922, 7.1083118207752705, 6.025810232385993, 9.33241132646799, 6.093485550954938, 0.3442333551356569, 0.06485811856691726, 0.18965456227306277, 3.167809029109776, 18.411305956542492, 29.100356586277485, 31.432489044964314, 29.22574605792761, 18.378451019525528, 0.7091827236581594, 0.08858935922035016, 0.039551791924168356, 0.04745763508253731, 0.04902944448986091, 0.08552952887839638, 0.08727353881113231, 0.026933298031508457, 0.01815367617382435, 0.030252839242166374, 0.06509555387310684, 0.0028580756406881846, 0.02910610790422652, 0.0035710719885173603, 0.060286455482128076, 0.04581323992169928, 0.003526923710523988, 0.038245140749495476, 0.015871533105382696, 0.04351580675574951, 0.06351148418616503, 0.028112576255807653, 0.009382760636071907, 0.022036383161321282, 0.04358620317361783, 0.09858856719802134, 0.0412266819330398, 0.12246371028595604, 0.047074994872673415, 0.002181187792302808, 0.06678505305899307, 0.019421960168983787, 0.028938785144418944, 0.09332366767921485, 0.02404496874078177, 0.021303840730979573, 0.04131945039262064, 0.028683989148703404, 0.03271714987931773, 0.060607831401284784, 0.013071209541521966, 0.04549899975245353, 0.04191710191662423, 0.10014463565312326, 0.022120535286376253, 0.028700655930151697, 0.03203962471161503, 0.05906148137000855, 0.03879536903696135, 0.04719451775599737, 0.046432569579337724, 0.023830068748793565, 0.050053400482283905, 0.039103434537537396, 0.009999238591262838, 0.0060961554754612735, 0.10131264993106015, 0.059077459809486754, 6.31275468505919, 38.05935434997082, 36.31773680448532, 29.367197267711163, 41.08520798385143, 41.059278175234795, 17.406757660210133, 2.165405717678368, 0.10147247143322602, 0.038971588292042725, 0.484730014577508, 1.5579667501151562, 4.158759517595172, 4.554803241044283, 6.054407497867942, 4.046021467074752, 1.7973606730811298, 0.45110609382390976, 2.9228798719123006, 16.502144001424313, 33.27486388385296, 50.06248466670513, 55.86547628045082, 56.55383214354515, 51.928192153573036, 53.69429938495159, 55.76952762901783, 55.983387753367424, 54.80022244155407, 55.04794254899025, 52.445154413580894, 50.0388765335083, 45.52658066153526, 41.917424127459526, 46.256563290953636, 50.25312803685665, 52.86235302686691, 56.62703141570091, 54.034008756279945, 54.27988976240158, 53.486860916018486, 57.132617086172104, 55.59586174786091, 55.35105988383293, 50.39839804172516, 41.48372299969196, 40.39808325469494, 40.463310554623604, 39.39032033085823, 46.30598343908787, 53.74795250594616, 54.66774635016918, 57.139316126704216, 54.91471789777279, 55.64216986298561, 47.888207137584686, 52.44863882660866, 47.45143957436085, 47.31729157269001, 57.93126963078976, 50.88302403688431, 54.6520683914423, 49.24834795296192, 46.35650932788849, 41.341728419065475, 40.2458406239748, 39.15489636361599, 37.694281339645386, 38.27058121562004, 40.39254315197468, 38.83938409388065, 41.13039515912533, 44.928925931453705, 44.75833408534527, 41.66813090443611, 38.9128303527832, 38.525045961141586, 38.39631646871567, 40.69009758532047, 40.19793659448624, 42.85869061946869, 43.94616946578026, 49.75294187664986, 50.88854134082794, 49.446549117565155, 52.085074335336685, 47.83917836844921, 41.451523527503014, 36.9822109490633, 39.00281712412834, 40.5759859085083, 42.33643524348736, 44.69587683677673, 47.640931606292725, 47.16193690896034, 50.49462407827377, 47.884407341480255, 43.77675175666809, 24.01727434247732, 3.491969872266054, 0.8417335047852248, 3.046787898056209, 4.437151104211807, 3.3882791362702847, 4.484380194917321, 6.2682020757347345, 7.783340374007821, 14.420398157089949, 4.3240197747945786, 0.19263637805124745, 0.03821476464509033, 0.2660444163484499, 2.8435560408979654, 21.326792612671852, 36.257464438676834, 33.38181674480438, 34.22072432935238, 23.636589869856834, 1.5060732909478247, 0.07764209469314665, 0.13207524258177727, 0.017800998321035877, 0.06834416431956924, 0.03954626292397734, 0.12782678852090612, 0.0020207496118018753, 0.02486105659045279, 0.06299667860730551, 0.032607916873530485, 0.05981032321869861, 0.019787996679951902, 0.036727541519212537, 0.010958857801597333, 0.06273179125855677, 0.010579097124718828, 0.07789178285747766, 0.014265273202909157, 0.0693560678337235, 0.022036991722416133, 0.01394039805745706, 0.041607155071687885, 0.010108037440659245, 0.06368030793964863, 0.08225719197071157, 0.12126068890211172, 0.32885148364584893, 0.21963493869407102, 0.14236384362448007, 0.1803425682010129, 0.07263417865033261, 0.18669214623514563, 0.1579704522737302, 0.2538160787662491, 0.14017933193827048, 0.14185085630742833, 0.17228655517101288, 0.15491191326873377, 0.1765757382963784, 0.07391796054434963, 0.11913689973880537, 0.10216538503300399, 0.3157295408891514, 0.18661134119611233, 0.1243530327337794, 0.08328006442752667, 0.12337059248238802, 0.1088583176897373, 0.13198879722040147, 0.15102763107279316, 0.12123282125685364, 0.14114971971139312, 0.10735653733718209, 0.21086670138174668, 0.10052278215880506, 0.25248689227737486, 0.16733746917452663, 6.057842988520861, 42.27071397006512, 44.86367203295231, 33.08012053370476, 42.28927217423916, 46.93134628236294, 24.193075709044933, 3.898959383368492, 0.41284648119471967, 0.2639519755030051, 2.794432514347136, 8.22333063930273, 7.121155131608248, 9.03206879273057, 6.938568754121661, 7.520128972828388, 2.5624077022075653, 0.4967075359309092, 2.367511885240674, 16.449503526091576, 30.8854665979743, 49.70145843923092, 55.034381076693535, 58.29136870801449, 51.46949976682663, 53.88902373611927, 56.34433798491955, 55.21989472210407, 56.66798561811447, 57.114093080163, 53.886386677622795, 52.87622228264809, 47.181532457470894, 45.003607124090195, 48.409508764743805, 51.769155487418175, 55.22298015654087, 59.28456701338291, 54.99317988753319, 54.30539779365063, 54.07122775912285, 58.80755580961704, 58.06165963411331, 57.045563757419586, 52.39190027117729, 44.25632022321224, 42.06341229379177, 42.17041075229645, 40.34595765173435, 49.64985340833664, 54.7592606395483, 57.303615510463715, 59.00099202990532, 58.30530636012554, 56.78752340376377, 49.07668836414814, 50.72782136499882, 50.20655773580074, 51.381796672940254, 59.69323128461838, 56.19842581450939, 55.664881244301796, 52.80748397111893, 46.99473828077316, 44.64614510536194, 42.4588418751955, 42.35514923930168, 39.416709914803505, 38.70117411017418, 42.475830763578415, 40.690424367785454, 42.15008184313774, 47.782515808939934, 46.98624573647976, 44.806960076093674, 40.02992480993271, 40.29046542942524, 39.934823513031006, 43.16441461443901, 41.612638682127, 45.100437328219414, 46.19733966886997, 53.23873043060303, 53.11184383928776, 50.099498480558395, 54.40559461712837, 50.844440907239914, 44.92598108947277, 40.21122068166733, 40.98670966923237, 43.39065447449684, 45.76314076781273, 47.891087383031845, 50.030699372291565, 48.09040568768978, 52.30008579790592, 46.35234095156193, 44.42248910665512, 21.7913081869483, 2.5878575490787625, 0.6933590664993972, 3.190480275079608, 5.986859472468495, 5.478637218475342, 8.001718930900097, 15.062021277844906, 11.874345727264881, 15.765804313123226, 9.402496665716171, 1.2322484655305743, 0.39796832017600536, 0.32560123305302113, 4.466933431103826, 23.50089155137539, 37.6529623568058, 41.06580622494221, 39.45356413722038, 29.238203689455986, 1.8111563078127801, 0.26244995766319335, 0.3409427317092195, 0.09498100960627198, 0.08747463856707327, 0.22486528381705284, 0.16747700778068975, 0.09417479974217713, 0.12151562405051664, 0.1222618980682455, 0.19206931785447523, 0.14037062792340294, 0.13215995131758973, 0.1277800925890915, 0.1542251298087649, 0.24097247107420117, 0.17511729936813936, 0.16136760357767344, 0.06735192029736936, 0.15747879428090528, 0.20152006385615095, 0.14784507919102907, 0.1426157879177481, 0.24973726482130587, 0.13268923619762063, 0.2722336311126128], [0.051697335511562414, 0.03424010370508768, 0.012720647737296531, 0.025081507847062312, 0.04154079593718052, 0.08756129915127531, 0.016964310307230335, 0.03606462923926301, 0.05514365780982189, 0.004829529716516845, 0.033370020901202224, 0.05166800212464295, 0.04558227985398844, 0.03790403112361673, 0.02226183463790221, 0.08811601743218489, 0.03433294637943618, 0.09449232762563042, 0.026577222997730132, 0.030320831101562362, 0.02742614902672358, 0.031778184638824314, 0.023030298871162813, 0.026405660719319712, 0.05943983938777819, 0.08371211311896332, 0.037919170936220326, 0.047648519175709225, 0.06573592341737822, 0.01665350628172746, 0.033126518537756056, 0.041809850445133634, 0.004230657823427464, 7.821618095040321, 32.45669938623905, 30.480396933853626, 23.85301675647497, 32.078809663653374, 38.70850011706352, 17.65907172113657, 3.054387727752328, 0.07216030993731692, 0.16854755580425262, 0.8026868000160903, 2.613543695770204, 3.3721729880198836, 5.846114074811339, 2.885876982472837, 1.5995555184781551, 0.6942003651056439, 0.5074307683389634, 2.0659239683300257, 9.318161141127348, 23.346526734530926, 39.064347222447395, 49.33903008699417, 51.960836201906204, 50.37850230932236, 53.82963292300701, 55.902524292469025, 57.19674624502659, 53.72248627245426, 52.543941512703896, 49.7594091296196, 45.476966723799706, 41.57929927110672, 44.87645074725151, 47.87760190665722, 49.79484602808952, 54.38498832285404, 54.779707342386246, 53.756137266755104, 53.693136647343636, 50.24134486913681, 54.37726713716984, 54.13589648902416, 54.72932584583759, 45.70654280483723, 38.8997096568346, 39.38460923731327, 39.863125160336494, 39.245711490511894, 47.5768518447876, 52.139088436961174, 53.27697157859802, 51.967079266905785, 56.96837089955807, 54.272784143686295, 56.0702320933342, 48.42509172856808, 46.247523576021194, 57.197179421782494, 52.84360483288765, 51.25513046979904, 49.92480285465717, 46.255997121334076, 42.633263915777206, 40.26166297495365, 38.547707945108414, 39.042410999536514, 36.30758374929428, 36.50136575102806, 39.747694954276085, 44.86878655850887, 45.87328925728798, 46.50098517537117, 42.723448276519775, 39.51954759657383, 36.54195137321949, 39.03076082468033, 41.554942578077316, 43.93089048564434, 46.09391301870346, 46.3424538820982, 47.230660021305084, 47.842533588409424, 51.06631860136986, 49.075320437550545, 50.054942071437836, 46.76717609167099, 40.0600153952837, 40.36888562142849, 42.78763823211193, 44.55657631158829, 45.70807032287121, 46.38761065900326, 47.82276324927807, 49.146957993507385, 47.69736237823963, 23.065355122089386, 2.807805184274912, 0.0584107699978631, 2.0385096268728375, 3.123425985686481, 4.692087974399328, 1.8548261770047247, 3.3082219446077943, 3.6051938217133284, 11.908765230327845, 9.107524193823338, 1.3659619842655957, 0.18483536696294323, 0.08249398160842247, 2.4532374227419496, 15.141022838652134, 29.971079863607883, 38.54297339916229, 27.642954289913177, 28.309069946408272, 6.783374156802893, 0.05140889981703367, 0.07332249093451537, 0.03308242012280971, 0.029183779224695172, 0.02309757641342003, 0.05834211020555813, 0.035746552166529, 0.05077303510915954, 0.08005411174963228, 0.010615600585879292, 0.015684124118706677, 0.0045222017251944635, 0.021853551370440982, 0.00566547790185723, 0.0165128488879418, 0.015784612769493833, 0.01582034532475518, 0.0265527080046013, 0.006995912126512849, 0.010588348923192825, 0.006739391101291403, 0.09226423702784814, 0.05825295971590094, 0.03994959050032776, 0.03778749538469128, 0.02577091294369893, 0.017444477998651564, 0.02677275479072705, 0.02883553384890547, 0.05489552815561183, 0.08503722521709278, 0.054113063306431286, 0.05091715276648756, 0.08743672224227339, 0.01571382857946446, 0.017491840008005966, 0.08702952807652764, 0.026773979334393516, 0.07909324573120102, 0.023293739031942096, 0.035997268205392174, 0.03976898886321578, 0.04162035787885543, 0.02516014767024899, 0.01722737568343291, 0.04993589252990205, 0.00672466967444052, 0.012505220820457907, 0.040858843858586624, 0.03017622362676775, 0.11163400195073336, 0.02617191017634468, 0.0765557166596409, 0.028089224579161964, 0.02633844625961501, 0.01872640452347696, 0.12775379087543115, 0.026525437788222916, 0.07766947994241491, 14.440420232713223, 37.87372291088104, 29.746086336672306, 26.490447632968426, 41.498397812247276, 44.151233062148094, 15.928912460803986, 2.430288316681981, 0.22046831116313115, 0.09245977809769101, 0.18547196639701724, 1.0975602990947664, 2.4393106950446963, 10.647696498781443, 8.162717241793871, 4.138599224388599, 1.9935872498899698, 1.523253119084984, 3.482965067960322, 13.054331559687853, 26.29676252603531, 42.54314415156841, 51.138149946928024, 51.40132002532482, 51.14710606634617, 54.409208223223686, 57.45194435119629, 56.6265070438385, 55.42820334434509, 54.59043189883232, 51.62041626870632, 46.825233176350594, 43.49938943982124, 45.72113782167435, 49.18769180774689, 53.03346164524555, 57.97389954328537, 56.94665506482124, 54.43213239312172, 54.54035058617592, 51.62465304136276, 57.40464448928833, 56.14205963909626, 56.2339311093092, 47.36843302845955, 41.313902512192726, 41.00361876189709, 41.61983169615269, 40.87074749171734, 49.752675890922546, 54.0161307156086, 54.69234623014927, 52.261449471116066, 57.08818607032299, 56.03339686989784, 55.65221272408962, 48.23426976799965, 48.00905965268612, 58.656472116708755, 54.43695813417435, 53.07002328336239, 51.03049032390118, 46.878863498568535, 43.2449284940958, 41.091340854763985, 41.692160815000534, 39.34412620961666, 38.24779383838177, 38.430168852210045, 41.8894462287426, 46.361110880970955, 47.10436999797821, 47.967071905732155, 45.777697786688805, 41.572250649333, 39.938098937273026, 39.271557703614235, 42.81224951148033, 44.58759784698486, 46.990991681814194, 47.79662445187569, 50.059726014733315, 49.558532908558846, 50.64448423683643, 49.95900861918926, 51.88333936035633, 47.293140068650246, 41.268494948744774, 41.52720406651497, 43.73025745153427, 46.7207045853138, 49.17714737355709, 48.13684679567814, 47.329447120428085, 48.77321384847164, 47.68306374549866, 26.147730723023415, 4.562249416485429, 0.6174937624018639, 2.567407046444714, 5.342707587406039, 4.910035254433751, 2.8256229031831026, 4.232220975682139, 5.969017529860139, 7.370677292346954, 3.1698742182925344, 0.2478798176161945, 0.0856635978561826, 0.11886107313330285, 1.7016245727427304, 16.407800763845444, 32.22790606319904, 35.90050399303436, 29.878847412765026, 32.166812941432, 10.867880433797836, 0.015687595514464192, 0.06738863434293307, 0.030102337259449996, 0.053649350884370506, 0.011733786141121527, 0.030715186112502124, 0.06205495257745497, 0.0316796571132727, 0.04643929343728814, 0.02679213783267187, 0.03855849405226763, 0.037174737444729544, 0.015670041866542306, 0.059463183642947115, 0.039214244607137516, 0.08672368901898153, 0.07304018537979573, 0.03433926576690283, 0.024796213292574976, 0.04990519359125756, 0.024352173350052908, 0.03649535690783523, 0.03770535819057841, 0.04356118537543807, 0.06248355028219521, 0.027659513652906753, 0.16452006879262626, 0.15420945564983413, 0.0828749556967523, 0.21918537531746551, 0.13685407990124077, 0.2289621764793992, 0.1360156905138865, 0.1400125416694209, 0.12128857139032334, 0.10561721777776256, 0.1921488909283653, 0.14218106749467552, 0.17708621715428308, 0.09227642309269868, 0.08053325713262893, 0.16499737364938483, 0.10856539942324162, 0.24604263104265556, 0.14000308670802042, 0.16055882588261738, 0.08449858185485937, 0.12558036687551066, 0.1416528958361596, 0.12182861741166562, 0.12013352243229747, 0.11236034930334426, 0.23452393506886438, 0.12090728559996933, 0.15924682753393427, 0.17513202357804403, 0.19736442278372124, 0.13710513361729681, 0.2175218958291225, 14.86284926533699, 46.300861313939095, 42.022366896271706, 33.003045469522476, 43.65526847541332, 48.86895731091499, 22.82234486192465, 3.9677601540461183, 0.3903851145878434, 0.3849431237904355, 2.2376407915726304, 8.525034449994564, 8.787805549800396, 15.575515273958445, 7.758278343826532, 4.805081086233258, 1.7335987882688642, 1.7633441858924925, 2.8632235480472445, 11.709712911397219, 25.97478110343218, 42.406818866729736, 51.67198710143566, 53.50731901824474, 50.31648963689804, 56.31632588803768, 59.997340366244316, 60.98451979458332, 58.33061680197716, 58.16087231040001, 53.88145834207535, 48.9930434525013, 46.52792572975159, 48.00658978521824, 51.45598389208317, 54.311690255999565, 60.04272133111954, 57.96812005341053, 56.9696020334959, 54.98431496322155, 51.50516465306282, 57.205823957920074, 58.965855315327644, 60.04047565162182, 50.91084234416485, 44.530471712350845, 43.44432279467583, 43.930768892169, 43.38227592408657, 51.17342345416546, 57.13739722967148, 56.945978701114655, 55.23601345717907, 60.40415793657303, 59.31672468781471, 57.981578931212425, 49.294477477669716, 51.1022874712944, 57.38908812403679, 57.84431889653206, 54.996839091181755, 54.20541375875473, 49.82641853392124, 46.99766032397747, 44.09032993018627, 43.43583784997463, 42.32819728553295, 40.0319766998291, 40.788569301366806, 44.12656478583813, 48.86706881225109, 49.869683012366295, 51.14194594323635, 47.71733030676842, 43.381584361195564, 41.99370123445988, 42.121606171131134, 44.619018360972404, 45.48529967665672, 50.020287930965424, 49.54152122139931, 51.6113917529583, 50.6128965318203, 52.82577998936176, 52.15878278017044, 53.83047267794609, 50.67241653800011, 42.06837482750416, 43.59922528266907, 45.219872519373894, 49.20476049184799, 50.76289348304272, 50.618151649832726, 50.4998791962862, 50.67014425992966, 48.97747568786144, 25.25354940444231, 3.6330660386011004, 0.5709993978962302, 4.624108672142029, 7.825736599043012, 9.148139264434576, 6.520991111174226, 9.725665524601936, 12.092255484312773, 22.742317356169224, 17.321112155914307, 3.748480095528066, 0.4530447319848463, 0.170112730411347, 3.130353488959372, 20.446381755173206, 38.92421834170818, 46.37972608208656, 36.10750928521156, 37.9317419975996, 12.092993594706059, 0.10560949202044867, 0.3023017739178613, 0.07803578177117743, 0.229527247720398, 0.19546024996088818, 0.09179659493383951, 0.24464500369504094, 0.2111706108553335, 0.17219026893144473, 0.05818556157464627, 0.09084676465135999, 0.12487955682445318, 0.10181363672018051, 0.18231813563033938, 0.25427065906114876, 0.2213992760516703, 0.16273063200060278, 0.10193034686380997, 0.06356787998811342, 0.19649250316433609, 0.10599670757073909, 0.1755086486809887, 0.11309508292470127, 0.13107280887197703, 0.13301802246132866, 0.09883455204544589], [0.05677711371390615, 0.06545227457536384, 0.0024887718245736323, 0.0490061187883839, 0.04168108040175866, 0.01868434701464139, 0.03203383967047557, 0.028358093550195917, 0.011321085239615059, 0.05955448265012819, 0.08987816545413807, 0.08844018753734417, 0.09394076347234659, 0.03474174358416349, 0.08809156366623938, 0.04053620628837962, 0.10134899290278554, 0.03300202697573695, 0.05462064036692027, 0.01428145109457546, 0.012213194986543385, 0.05344026561942883, 0.06679185113171116, 0.04828875513339881, 0.05158367188414559, 0.02390052453847602, 0.022072015526646283, 0.02371741815295536, 0.016122575689223595, 0.09633355890400708, 0.1042781384603586, 0.008005669442354701, 0.04112495946174022, 0.4374647367512807, 18.786102645099163, 37.601026743650436, 30.483011193573475, 18.839649371802807, 30.06303682923317, 37.00975947082043, 17.05252356827259, 3.4074065973982215, 0.15332220325944945, 0.18325609154999256, 0.8439237310085446, 1.7449795338325202, 8.976006601005793, 6.458944715559483, 3.604639288969338, 2.8148794546723366, 1.326262664515525, 0.7430943008512259, 1.0533020552247763, 4.452704144641757, 12.116487734019756, 28.42551089823246, 39.68821294605732, 47.58193217217922, 52.87385120987892, 52.826965525746346, 55.58818615972996, 54.80426162481308, 52.92627699673176, 48.815414384007454, 46.915539130568504, 43.55280317366123, 45.21094299852848, 45.2089899033308, 48.3879791200161, 51.800215020775795, 55.33138453960419, 54.507280960679054, 55.80175369977951, 51.36961452662945, 55.23496091365814, 53.73837701976299, 53.44740003347397, 51.5186083316803, 41.635376662015915, 38.38316157460213, 39.59117755293846, 39.46014158427715, 42.104260101914406, 46.6877755522728, 49.84829016029835, 50.1211991161108, 57.07468159496784, 51.005620658397675, 56.96475729346275, 52.50695049762726, 45.43257750570774, 55.822302997112274, 52.79857724905014, 52.79028229415417, 49.99615542590618, 50.67514859139919, 46.89870223402977, 43.744898065924644, 37.049357146024704, 35.78291170299053, 37.68839165568352, 36.38644851744175, 42.97646529972553, 45.45195646584034, 48.839121311903, 48.95507209002972, 47.08341792225838, 43.24001535773277, 38.5930585116148, 39.473349675536156, 46.471886336803436, 50.19587650895119, 49.770914912223816, 49.68991465866566, 51.90436363220215, 47.892082929611206, 49.47267271578312, 50.514649003744125, 47.66827493906021, 46.19091421365738, 42.52528890967369, 43.563670590519905, 46.286061108112335, 47.563677951693535, 48.65530617535114, 46.51890881359577, 47.62611620128155, 48.03266778588295, 25.23655291646719, 3.5711495485156775, 0.09190087410388514, 1.0632560960948467, 0.6745580316055566, 3.107454967685044, 3.015801510773599, 1.790162909310311, 2.7761291339993477, 3.7512375600636005, 3.992059612646699, 2.71399961784482, 0.2592897741124034, 0.08163498278008774, 1.6365853627212346, 13.753513991832733, 29.727535732090473, 37.40964241325855, 26.878389716148376, 29.081771783530712, 18.52534543722868, 0.8823676337487996, 0.06419102428480983, 0.05051041502156295, 0.02503065588825848, 0.023044646441121586, 0.018090369121637195, 0.07224538232549094, 0.05684108684363309, 0.07726880925474688, 0.03715487757290248, 0.06349494171445258, 0.06032197838067077, 0.03802300110692158, 0.102051932917675, 0.043536219527595676, 0.015430198291142005, 0.0636318234319333, 0.02323819113371428, 0.09765174676431343, 0.005520326340047177, 0.03081437600485515, 0.030836495716357604, 0.03915810855687596, 0.0018588155398902018, 0.01977989057195373, 0.037948916215100326, 0.02323862714547431, 0.009016884614538867, 0.0648413534509018, 0.03553770809958223, 0.017870632182166446, 0.01758375314238947, 0.045019401659374125, 0.013034112362220185, 0.041538083387422375, 0.05401856564276386, 0.0403993023064686, 0.05470419877383392, 0.05035257505369373, 0.053532915335381404, 0.037398836357169785, 0.08154234048561193, 0.029432649171212688, 0.11851846807985567, 0.05750237010943238, 0.020134898768446874, 0.06486257145297714, 0.07218787330202758, 0.051875647623091936, 0.03393312174011953, 0.03158666972012725, 0.02779945672955364, 0.035784739375230856, 0.030168757621140685, 0.04301885353925172, 0.035026557598030195, 0.0035009661678486736, 0.09129708501859568, 0.018267601408297196, 0.032024926476879045, 1.0491776140406728, 25.22475454956293, 42.268730476498604, 30.28379548341036, 25.371335484087467, 39.99687038362026, 43.14833387732506, 17.263347655534744, 2.477709297090769, 0.09097355316043831, 0.06683735220576636, 0.5978098092600703, 1.3816051511093974, 13.114055804908276, 15.512177422642708, 7.80464630573988, 2.9515578830614686, 2.487119254656136, 2.128350343555212, 1.817460882011801, 8.097564987838268, 16.447563730180264, 33.70960995554924, 43.65345597267151, 51.52787983417511, 53.71172145009041, 55.98802350461483, 59.70532223582268, 57.84765511751175, 54.45651188492775, 51.39793440699577, 47.760127410292625, 47.227677181363106, 45.47407507896423, 47.16294005513191, 50.762008130550385, 54.09864328801632, 56.378087773919106, 55.16647718846798, 55.2922086417675, 52.03570358455181, 54.34492327272892, 55.762448608875275, 54.68544960021973, 51.90170377492905, 42.62831658124924, 39.98951017856598, 41.602774411439896, 41.14250510931015, 43.55992779135704, 49.57254655659199, 53.66041660308838, 51.95419795811176, 57.62244500219822, 53.496060222387314, 57.52479784190655, 53.12832735478878, 47.042915895581245, 57.6967766135931, 54.06224124133587, 53.442346304655075, 51.61680266261101, 51.15078046917915, 48.479987382888794, 45.667119920253754, 40.84854148328304, 38.52721944451332, 40.646787509322166, 37.139302119612694, 43.36167722940445, 47.548037990927696, 50.99298253655434, 50.10047882795334, 47.96923018991947, 44.41283002495766, 39.16275434195995, 40.748728439211845, 45.99060416221619, 50.7723967730999, 52.504374235868454, 52.096925899386406, 51.608112528920174, 49.90963026881218, 52.30891652405262, 50.263687670230865, 49.585861042141914, 49.21147093176842, 43.85674886405468, 44.468926414847374, 47.615336179733276, 48.28540362417698, 51.13615125417709, 46.847195997834206, 49.26028311252594, 49.18471276760101, 29.306966699659824, 6.020219307392836, 0.8325691684149206, 2.122057406231761, 1.8541517131961882, 4.763391623273492, 4.736480042338371, 4.526419714093208, 4.540454261004925, 6.9912030547857285, 3.1908089574426413, 0.8159660780802369, 0.10792376080644317, 0.10516556154470891, 1.3630635710433125, 14.614972416311502, 31.925848871469498, 38.45007598400116, 33.807773888111115, 32.466898038983345, 24.964158833026886, 1.8043196434155107, 0.03348997051944025, 0.0687426159856841, 0.06756067901733331, 0.032604762745904736, 0.0456060137366876, 0.008793472188699525, 0.03753234872419853, 0.06574212035047822, 0.034979149204446, 0.030856776756991167, 0.048655895589035936, 0.03689505909278523, 0.029468183201970533, 0.012123727228754433, 0.0253574068119633, 0.05453831392514985, 0.03755849087610841, 0.06570413723238744, 0.042450980690773576, 0.01970869448996382, 0.042245320437359624, 0.10152757589821704, 0.18408708914648741, 0.05354271539545152, 0.029049712102278136, 0.02430712313071126, 0.10267818681313656, 0.17700676282402128, 0.07794339180691168, 0.09120225338847376, 0.11059734781156294, 0.21353479649405926, 0.17507440323242918, 0.1179744589899201, 0.18229701410746202, 0.1553566675283946, 0.2149875060422346, 0.2352966443868354, 0.16434447665233165, 0.1590165836387314, 0.3454843786312267, 0.2149673641542904, 0.2250964628183283, 0.11120771974674426, 0.06315597318462096, 0.12251519307028502, 0.193072434340138, 0.14087827177718282, 0.17216395237483084, 0.1591063686646521, 0.10645358110195957, 0.1481399789918214, 0.07040167227387428, 0.11257592093897983, 0.1918898813892156, 0.14926706382539123, 0.22759364132070914, 0.14476675452897325, 0.103041408729041, 0.9824720746837556, 25.45926846563816, 50.79532094299793, 41.27274692058563, 27.822669446468353, 39.9193849414587, 47.95196011662483, 22.274000085890293, 4.5152464136481285, 0.4778948047896847, 0.8573271555360407, 2.8051690757274628, 6.303420960903168, 16.460357643663883, 12.651214990764856, 7.463473062962294, 7.75981773622334, 4.252578383311629, 2.1001283079385757, 1.9015494198538363, 6.482543349266052, 14.458629805594683, 31.9706142693758, 42.884301245212555, 50.06826035678387, 54.3754318356514, 56.35953716933727, 61.65890000760555, 59.916355311870575, 55.76987721025944, 52.963841781020164, 48.840892016887665, 48.17509554326534, 49.97660927474499, 47.76000201702118, 51.080130860209465, 56.249046698212624, 58.742248713970184, 57.45377965271473, 56.93274401128292, 52.09146939218044, 54.399138763546944, 57.45515137910843, 55.68501636385918, 56.85204774141312, 44.63949926197529, 43.04944418370724, 43.64038087427616, 43.1436563283205, 45.78431323170662, 51.130390763282776, 54.404732063412666, 54.374580681324005, 61.04817397892475, 53.104544430971146, 58.76033954322338, 54.95702102780342, 49.184530377388, 56.311655938625336, 57.00628526508808, 54.79940548539162, 54.519508704543114, 55.26885509490967, 51.70630306005478, 47.031227722764015, 42.28668071329594, 39.08512070775032, 41.93727046251297, 38.583236038684845, 45.75285091996193, 49.47864979505539, 53.32730367779732, 53.155556693673134, 50.91846473515034, 46.770421117544174, 41.69657617807388, 42.69187197089195, 50.040928423404694, 54.472999200224876, 53.42259116470814, 53.12330782413483, 54.2495521903038, 50.614952221512794, 51.07545331120491, 52.93208308517933, 51.36902555823326, 50.43595902621746, 46.28477297723293, 46.984836012125015, 50.10397844016552, 52.058696150779724, 53.79281669855118, 49.94127117097378, 50.24032652378082, 49.824450239539146, 26.931898444890976, 4.7116369754076, 0.675275243120268, 2.631672522984445, 2.6198228588327765, 7.627967186272144, 8.395150769501925, 6.36752494610846, 8.975467029958963, 8.754063360393047, 10.389719791710377, 6.066214889287949, 0.7228074269369245, 0.30512264755088836, 2.2364483680576086, 18.941067829728127, 36.625983864068985, 46.23163282871246, 35.56528218090534, 40.83996154367924, 27.165868990123272, 2.0972112519666553, 0.21131170797161758, 0.22575115581275895, 0.17626795481191948, 0.15021061553852633, 0.14882061746902764, 0.18661675887415186, 0.1938066558795981, 0.21496967965504155, 0.09346031933091581, 0.17394236085237935, 0.14544353383826092, 0.15250217460561544, 0.1426618010737002, 0.14076454506721348, 0.12148902547778562, 0.08821495313895866, 0.15584222506731749, 0.2684532495914027, 0.12911631463794038, 0.13792542944429442, 0.1105728346738033, 0.1514894695719704, 0.26057980488985777, 0.16409222065703943, 0.12110009556636214, 0.09932923800079152], [0.03824025370704476, 0.049719456292223185, 0.0380372280778829, 0.05871265340829268, 0.04314516707381699, 0.018620769078552257, 0.04061974243086297, 0.014501822570309741, 0.04721460398286581, 0.02525563795643393, 0.0352272937016096, 0.035621288770926185, 0.0027978918706139666, 0.002684265582502121, 0.040380845093750395, 0.053255363236530684, 0.018708795214479323, 0.010588275636109756, 0.014391469849215355, 0.06629620780586265, 0.05243569452431984, 0.008372881329705706, 0.028574835923791397, 0.04441972778295167, 0.05377686669817194, 0.018465036810084712, 0.04204925244266633, 0.046933682533563115, 0.03120686080364976, 0.023957332232384942, 0.08334418598678894, 0.02434074613120174, 0.034050785543513484, 0.051206070857006125, 2.427851934917271, 19.91834118962288, 36.626591831445694, 23.858942538499832, 21.41594722867012, 32.378032207489014, 38.904299810528755, 21.98786973953247, 3.1924414448440075, 0.08188118285033852, 0.038595022560912184, 0.46980483108200133, 17.585604563355446, 26.31288506090641, 8.686337694525719, 2.474848525598645, 2.812209860421717, 1.157742419745773, 0.4991553467698395, 0.5866453552152961, 1.3907120749354362, 6.301645981147885, 16.023907363414764, 32.20395974814892, 47.77063764631748, 56.27691440284252, 55.301765128970146, 54.88685019314289, 52.943125292658806, 53.37078474462032, 48.37144620716572, 46.12863175570965, 43.876519203186035, 45.116293877363205, 50.485724955797195, 52.99956366419792, 56.66339546442032, 54.92154233157635, 56.25235632061958, 51.88129886984825, 56.26498684287071, 55.91525360941887, 54.25224244594574, 50.707401260733604, 41.09370432794094, 37.89152875542641, 39.039162173867226, 38.330978974699974, 41.455254927277565, 41.487712785601616, 46.020246371626854, 49.870917946100235, 51.39232210814953, 53.52079689502716, 54.8686795681715, 53.572603315114975, 43.08330416679382, 52.37533316016197, 52.950903475284576, 52.77699440717697, 51.367555037140846, 52.064031064510345, 53.024486526846886, 50.88407278060913, 42.055869698524475, 39.27033416926861, 38.46431761980057, 38.94393928349018, 45.338494554162025, 49.90696281194687, 51.09240420162678, 50.024748891592026, 48.224283903837204, 45.28217777609825, 41.116218119859695, 42.30271205306053, 47.853955775499344, 51.41866609454155, 51.38113170862198, 49.93529789149761, 49.332593232393265, 49.8595679551363, 49.344083815813065, 50.620028749108315, 47.14819684624672, 47.00128152966499, 44.68107283115387, 46.11213684082031, 49.99965123832226, 48.150925040245056, 48.98520067334175, 47.53096930682659, 48.45891371369362, 29.344354793429375, 6.798888249322772, 0.2085668599465862, 1.2155915843322873, 2.6802263176068664, 1.1134529463015497, 3.5262176720425487, 2.616331558674574, 3.382928785867989, 3.4806419676169753, 5.341562423855066, 2.2631915705278516, 0.28199465421494097, 0.09402924231835641, 1.7660869262181222, 13.249084409326315, 27.52749938517809, 40.802176371216774, 28.88429258018732, 19.501475058496, 29.04848176985979, 5.122739765793085, 0.08951456504291855, 0.1038432696077507, 0.027573984843911603, 0.06871103760204278, 0.052609405320254155, 0.03565018057997804, 0.056128469223040156, 0.06335191501420923, 0.051513186408556066, 0.028800471081922296, 0.023618018603883684, 0.041307717037852854, 0.010962934047711315, 0.006027356066624634, 0.043204535177210346, 0.016407296934630722, 0.02812582730257418, 0.07418668479658663, 0.05522678948182147, 0.023393769406538922, 0.09506472386419773, 0.00947189628277556, 0.04490421291848179, 0.036272664365242235, 0.03134648475679569, 0.03684855983010493, 0.025399113656021655, 0.019589891489886213, 0.025508727012493182, 0.020985080882383045, 0.07276173899299465, 0.03889505431288853, 0.06910162250278518, 0.05912945467571262, 0.06315712351351976, 0.040714087954256684, 0.017729856044752523, 0.06071908675949089, 0.04658010111597832, 0.021071290611871518, 0.05707607306248974, 0.02634156513522612, 0.049294335549348034, 0.04729202853923198, 0.01334602311544586, 0.03125346396700479, 0.039566167324665, 0.014191087193466956, 0.05487134898430668, 0.043530352850211784, 0.05249128138530068, 0.04879639527644031, 0.043332050991011783, 0.06799361086450517, 0.05655552326061297, 0.04648566282412503, 0.037176392434048466, 0.05520893711945973, 0.03447438488365151, 0.07240217586513609, 0.06193588240421377, 4.508434804156423, 27.06765566021204, 40.47417417168617, 21.976073272526264, 26.52194794267416, 44.3918551504612, 43.48419405519962, 21.695321537554264, 2.334859287366271, 0.06448931570048444, 0.06296852152445354, 0.18171883653849363, 3.969879965297878, 8.92982292920351, 7.03218100592494, 2.32676453422755, 4.109403965994716, 1.6550536779686809, 1.3011430436745286, 1.0191266890615225, 1.939697116613388, 8.721995931118727, 20.75702838599682, 35.63240557909012, 50.62385514378548, 56.156248077750206, 57.259925454854965, 56.988623812794685, 54.82824593782425, 54.506809785962105, 50.21707557141781, 47.04179875552654, 46.258945763111115, 46.628468334674835, 51.04070797562599, 54.186509773135185, 58.39905492961407, 55.298675894737244, 57.330301478505135, 52.52290964126587, 56.15609988570213, 57.50032715499401, 55.16702055931091, 52.34827481210232, 42.82805286347866, 41.02433905005455, 40.29879078269005, 40.00468276441097, 42.740547358989716, 44.18540842831135, 47.735782116651535, 52.449064403772354, 53.723474219441414, 55.565296187996864, 56.82802923023701, 54.38335441052914, 45.26202365756035, 53.647485896945, 54.56511005759239, 54.34511326253414, 54.17759545147419, 52.9970595985651, 53.86330671608448, 52.38051988184452, 43.29993054270744, 41.62039786577225, 39.856669306755066, 40.17981916666031, 47.6421133428812, 50.20921379327774, 52.95587360858917, 49.981906190514565, 49.24953728914261, 46.20751552283764, 41.88785031437874, 43.9126780629158, 48.7751479446888, 52.80761696398258, 54.32081736624241, 51.441936045885086, 50.963465720415115, 50.197803005576134, 50.34343779087067, 51.85678258538246, 48.69942180812359, 48.82260359823704, 46.80542103946209, 47.092309445142746, 50.723865777254105, 50.63906952738762, 50.790324211120605, 49.36586044728756, 48.650187849998474, 33.14784809947014, 9.038189314305782, 0.7676021545194089, 2.2990801697596908, 4.933339403942227, 2.6048388378694654, 2.804052885621786, 3.903896980918944, 4.431156450882554, 4.065872551873326, 4.205305119976401, 0.7089719537179917, 0.18584099190775305, 0.10719157275161706, 1.1181135149672627, 13.972882870584726, 33.66183511912823, 45.098484233021736, 32.115272507071495, 22.81696245074272, 33.186552822589874, 8.041619639843702, 0.0955567677738145, 0.053733755339635536, 0.07995943597052246, 0.015414072349813068, 0.021696017538488377, 0.08470040149404667, 0.021481247422343586, 0.042602827816153876, 0.038205777236726135, 0.054016506182961166, 0.027953721400990617, 0.06720384699292481, 0.032186733224079944, 0.023848392374929972, 0.057175045876647346, 0.011772447396651842, 0.012590888782142429, 0.019604389344749507, 0.10092694836203009, 0.050874282605946064, 0.03298870171420276, 0.030456753593171015, 0.05299599375575781, 0.028348807427391876, 0.06992628215812147, 0.06577477484825067, 0.0564293655770598, 0.14313321327790618, 0.15402224147692323, 0.13101924065267667, 0.19438705989159644, 0.0824522803304717, 0.17283712484641, 0.13154432497685775, 0.18966536794323474, 0.1477685192367062, 0.10604326249449514, 0.12742920516757295, 0.1336179894860834, 0.08449293411104009, 0.17573611694388092, 0.13630451954668388, 0.17234683240531012, 0.1702801589271985, 0.13152643921785057, 0.11899804390850477, 0.15315311233280227, 0.2020798806915991, 0.20270564476959407, 0.09066849335795268, 0.13960817508632317, 0.15225440118229017, 0.161845131078735, 0.18862919620005414, 0.18121269182302058, 0.17905957298353314, 0.1364507374819368, 0.2931661141337827, 0.11167686840053648, 0.16385786526370794, 0.0878716133593116, 3.9946843218058348, 29.60976105183363, 50.26398405432701, 30.894574709236622, 32.20252342522144, 41.90453141927719, 48.42015579342842, 27.661413699388504, 3.9491333160549402, 0.2692648029187694, 0.4111690790159628, 2.715782434679568, 26.34428657591343, 38.830116391181946, 18.22206851094961, 6.227847766131163, 7.466497700661421, 4.707916975021362, 1.4352219365537167, 1.5408950974233449, 1.9398549268953502, 8.30956606194377, 19.001239500939846, 35.815525352954865, 50.0888704508543, 59.133707508444786, 58.52216452360153, 59.87218268215656, 56.87016896903515, 58.81930097937584, 53.52291338145733, 48.84352147579193, 48.341705203056335, 50.05974501371384, 53.325251787900925, 58.56249935925007, 60.56038275361061, 57.064349949359894, 58.48956607282162, 52.680346593260765, 57.06919088959694, 60.461500659585, 57.50904008746147, 54.45577472448349, 44.66235123574734, 41.69711954891682, 42.271424531936646, 43.12670163810253, 45.35668037831783, 47.09633722901344, 49.05043177306652, 55.66612757742405, 55.534194856882095, 58.07604566216469, 58.37381288409233, 56.961398273706436, 47.43694335222244, 54.546985030174255, 56.59284844994545, 57.49588139355183, 57.83268392086029, 56.43235266208649, 56.35806664824486, 54.39588613808155, 45.30428498983383, 42.75897637009621, 40.59109389781952, 43.03986109793186, 50.234839618206024, 55.006467774510384, 54.10715863108635, 52.44635134935379, 52.37866558134556, 47.146657928824425, 45.607884898781776, 47.141478806734085, 51.95523150265217, 54.56226021051407, 55.451264306902885, 51.99147775769234, 52.24464297294617, 51.227912530303, 51.30642011761665, 51.93096600472927, 50.44338382780552, 50.567230582237244, 49.260218515992165, 49.654625952243805, 52.89042592048645, 51.020542457699776, 53.181668892502785, 49.020550176501274, 50.7814896851778, 31.591026037931442, 8.916198760271072, 0.652991101378575, 3.510665581561625, 5.7382867857813835, 5.496263047680259, 9.008213672786951, 8.537690620869398, 10.126299876719713, 8.876638133078814, 12.400034219026566, 6.2354901060462, 0.911594299832359, 0.33294086577370763, 2.601219769567251, 16.92676741629839, 36.49459071457386, 49.59115035831928, 35.78919656574726, 29.26088087260723, 39.790381863713264, 8.300387654453516, 0.1705741829937324, 0.22215160599444062, 0.15981253702193499, 0.19680408644489944, 0.11826181114884093, 0.17741341522196308, 0.17383550642989576, 0.13984414836158976, 0.23737661715131253, 0.13056182535365224, 0.12069299045833759, 0.13350236287806183, 0.18344242998864502, 0.13710005732718855, 0.14244257065001875, 0.12678456085268408, 0.09218421866535209, 0.17580820916919038, 0.13743455812800676, 0.08867296957760118, 0.23276687075849622, 0.09902805963065475, 0.11174534636666067, 0.22552178765181452, 0.2275400434155017, 0.16821713681565598, 0.11757801854400896], [0.016875694163900334, 0.02995538274262799, 0.017408708336006384, 0.037580220960080624, 0.03144338697893545, 0.053569581141346134, 0.06215021094249096, 0.04546044518065173, 0.041101578099187464, 0.10678161037503742, 0.034434858098393306, 0.02399563632934587, 0.05938115034950897, 0.013983121643832419, 0.030577285797335207, 0.03543548096786253, 0.14345171337481588, 0.0802578758157324, 0.07810664203134365, 0.060329143816488795, 0.07379412578302436, 0.030781586065131705, 0.021296300510584842, 0.038607186361332424, 0.035979159802081995, 0.03573444402718451, 0.08044990652706474, 0.01077395727406838, 0.04813959829334635, 0.025773421402845997, 0.03709796968905721, 0.04136819836276118, 0.06450816625147127, 0.05655990193190519, 0.0858237459033262, 4.097867785021663, 24.555205777287483, 35.41216939687729, 20.66143311560154, 23.38032592087984, 29.30859111249447, 38.61985847353935, 22.18803159892559, 4.074664805084467, 0.48524500569328666, 0.16735778917791322, 3.65714677143842, 7.514523798599839, 7.177987731993198, 0.4107751470291987, 2.5596884731203318, 3.3687044866383076, 1.0351922269910574, 0.5077395611442626, 0.11567269539227709, 0.4249082808382809, 4.226365489885211, 15.698991548269987, 30.592591613531113, 51.219666972756386, 53.95479440689087, 56.31870076060295, 55.08133515715599, 54.91359695792198, 53.224253207445145, 49.93026316165924, 49.041791036725044, 48.217254281044006, 48.420330584049225, 51.23439498245716, 55.87265029549599, 58.27188715338707, 54.72114488482475, 53.59698660671711, 54.80124078691006, 54.94715295732021, 55.36890372633934, 49.70164082944393, 41.62506781518459, 40.778731629252434, 39.64258499443531, 38.94085764884949, 40.81118568778038, 40.03053277730942, 42.2884514182806, 46.120010018348694, 51.23450517654419, 51.56753450632095, 54.5747197419405, 54.75024372339249, 40.601706728339195, 48.315729796886444, 53.07538479566574, 54.8559008538723, 51.93950034677982, 54.98937629163265, 53.3266045153141, 53.848183527588844, 45.97098581492901, 39.31203693151474, 39.48759891092777, 39.05352920293808, 46.714263930916786, 51.11872158944607, 52.71005339920521, 52.01475150883198, 50.000540390610695, 46.709495186805725, 41.68646112084389, 42.56812781095505, 50.10616332292557, 52.64741376042366, 51.68343588709831, 50.283366814255714, 52.35792249441147, 51.55887097120285, 50.09167470037937, 48.5230428725481, 48.14677186310291, 46.14600442349911, 46.91269688308239, 48.96020941436291, 49.54481944441795, 51.392542496323586, 51.68160438537598, 47.519816905260086, 32.404402792453766, 8.677971493452787, 0.4044760944088921, 0.5945846729446203, 1.611593747511506, 2.224793918430805, 1.9829587452113628, 1.885785253252834, 3.315608510747552, 3.2379456656053662, 3.3716293796896935, 4.776518493890762, 1.1386711243540049, 0.12166461019660346, 1.0177831049077213, 12.200954351574183, 33.32567475736141, 24.649372324347496, 43.69328923523426, 41.57997943460941, 23.79395842552185, 14.179816916584969, 0.5679190694354475, 0.02885403373511508, 0.05731027260480914, 0.014575566074199742, 0.04352199255663436, 0.015810422810318414, 0.047076200862647966, 0.1063456802512519, 0.06268365556024946, 0.0377968983957544, 0.03774108517973218, 0.04692783440987114, 0.04294105419830885, 0.024457346808048896, 0.027501161603140645, 0.05448654912470374, 0.059997518837917596, 0.02919284270319622, 0.04853876613196917, 0.022694621766277123, 0.021687588596250862, 0.0500028528040275, 0.038227789336815476, 0.04884364410827402, 0.09516958933090791, 0.037242525213514455, 0.0232173163749394, 0.042175699563813396, 0.030525470901920926, 0.02849695123586571, 0.048670549294911325, 0.05790461043943651, 0.031899759560474195, 0.07826939501683228, 0.04083166269992944, 0.025198308903782163, 0.018551714092609473, 0.09168431541183963, 0.05090921920782421, 0.06532098865136504, 0.04852903657592833, 0.011716577591869282, 0.012699481685558567, 0.017817954540078063, 0.05636866160784848, 0.05844373990839813, 0.0549795244296547, 0.04674161100410856, 0.0047400132552866125, 0.051209432785981335, 0.03389337602129672, 0.04484609904466197, 0.11393428125302307, 0.042693414361565374, 0.05559544020798057, 0.014028201549081132, 0.034192535749753006, 0.027385740941099357, 0.024493398486811202, 0.0758153798233252, 0.046032169775571674, 0.08002329777809791, 0.08406991735682823, 6.5737788286060095, 32.33993925154209, 36.15151472389698, 22.40283977240324, 23.71890675276518, 40.01775786280632, 45.89387655258179, 21.309729628264904, 3.3575178869068623, 0.46872613427694887, 0.18685620540054515, 1.0231656348332763, 2.5083985878154635, 6.450211834162474, 3.893143320456147, 4.523031245917082, 2.8549670660868287, 3.5178835317492485, 2.0613335771486163, 0.8356442127842456, 1.4060585014522076, 5.356164565309882, 18.799050450325012, 35.07618002593517, 55.21618992090225, 55.093961879611015, 58.547060787677765, 57.454478815197945, 55.56550897657871, 53.91267366707325, 50.682508796453476, 50.349559262394905, 48.886348977684975, 49.98306892812252, 54.39941994845867, 57.97290399670601, 58.555378541350365, 55.12877181172371, 52.41384409368038, 54.77236993610859, 57.088824436068535, 58.00118587911129, 51.17876976728439, 43.08783732354641, 42.150146439671516, 42.81251169741154, 41.7470146715641, 43.1529126316309, 41.260503977537155, 44.327034428715706, 49.72240291535854, 54.8944041877985, 53.49153086543083, 57.58652172982693, 56.08296141028404, 41.97195500135422, 47.7924332767725, 54.16768938302994, 56.17265559732914, 54.19620305299759, 53.98159816861153, 55.11997528374195, 55.94637393951416, 47.317534759640694, 39.77571465075016, 40.487116277217865, 40.53399436175823, 47.16908052563667, 51.02904640138149, 52.61902928352356, 54.56980660557747, 52.11581468582153, 49.567177444696426, 43.18820893764496, 46.10124282538891, 51.40845604240894, 53.00907455384731, 53.555394038558006, 52.070950493216515, 51.26388140022755, 51.89971648156643, 51.26650705933571, 50.57788901031017, 48.850718289613724, 47.3711346834898, 48.76092150807381, 50.730846002697945, 51.08868420124054, 50.761973932385445, 51.474203914403915, 48.187144696712494, 36.647053733468056, 11.918656099587679, 1.6731377388350666, 1.860218325164169, 2.05872121732682, 6.136706806719303, 3.3046620106324553, 2.221117140725255, 4.219206674024463, 5.139105012640357, 3.6120857018977404, 0.6354963651392609, 0.4246460652211681, 0.05009072679968085, 1.303209182806313, 11.670008841902018, 38.33222530782223, 31.221805550158024, 47.85934388637543, 40.74442707002163, 28.434117436408997, 18.556264378130436, 0.8431450102943927, 0.01829799421102507, 0.059945256798528135, 0.05300338554661721, 0.053892604628345, 0.027483843587106094, 0.04309013682359364, 0.036795073247049004, 0.030963087556301616, 0.08546048688003793, 0.047291256705648266, 0.017620231556065846, 0.0069511722176685, 0.050654339720495045, 0.05574979579250794, 0.02859287753381068, 0.12126477071433328, 0.019864688365487382, 0.0436562804679852, 0.050465092062950134, 0.02196787179855164, 0.03663336668978445, 0.06431169749703258, 0.027814772802230436, 0.08420498823397793, 0.042448798776604235, 0.016405179958383087, 0.030487574986182153, 0.18348773068282753, 0.15487876895349473, 0.1514804153703153, 0.25375614291988313, 0.1006513369793538, 0.3064928896492347, 0.21673225070117041, 0.1799355002003722, 0.12158783501945436, 0.21592929144389927, 0.11948315615882166, 0.17703662684652954, 0.18272584187798202, 0.10964493485516869, 0.13510063727153465, 0.17804697185056284, 0.21501609357073903, 0.15208597818855196, 0.12891896272776648, 0.1331362169003114, 0.11711494065821171, 0.12574770633364096, 0.1966403389815241, 0.13323870749445632, 0.3245286812307313, 0.12085894210031256, 0.22055493463994935, 0.14842068892903626, 0.10967302514472976, 0.10983390049659647, 0.11259618899202906, 0.15903142659226432, 0.12652944016736, 0.23033397708786651, 0.17301535903243348, 5.675146523863077, 35.51564544439316, 49.808601289987564, 31.3438967987895, 32.64662079513073, 36.384541019797325, 46.03517957031727, 27.81729843467474, 5.641676494851708, 0.7845916366204619, 0.6546387285925448, 6.562861539423466, 16.810482256114483, 19.25867948681116, 3.529784018173814, 6.514154328033328, 7.145058698952198, 4.035506481304765, 2.461782689206302, 0.6591009360272437, 1.287861568853259, 5.445601316168904, 18.215504363179207, 35.60920022428036, 54.63953286409378, 55.37184476852417, 61.39856077730656, 59.55212585628033, 58.25489826500416, 57.43156224489212, 53.98990452289581, 54.38618905842304, 51.97420388460159, 52.32209041714668, 55.54964862763882, 60.54542675614357, 63.26510801911354, 55.481791868805885, 52.97149457037449, 55.00320754945278, 57.993574887514114, 61.06624960899353, 53.081141486763954, 45.483981147408485, 44.261081367731094, 44.54161651432514, 43.64565119147301, 46.29562519490719, 44.524958208203316, 44.99584414064884, 51.688387021422386, 57.06239305436611, 56.10553599894047, 58.160431534051895, 58.36085557937622, 43.65080751478672, 48.1053426861763, 54.24487084150314, 56.99304677546024, 57.046042531728745, 57.79616788029671, 58.38920585811138, 58.63401152193546, 49.619185253977776, 42.58559927344322, 42.42783933877945, 41.188566237688065, 50.331232845783234, 54.46558579802513, 55.502166375517845, 54.676934257149696, 54.70367342233658, 53.22111077606678, 45.6228256970644, 47.428515404462814, 54.29393380880356, 56.069852113723755, 53.86033907532692, 53.52806210517883, 53.43003876507282, 52.466155886650085, 53.38501118123531, 52.11102694272995, 50.36562480032444, 48.50401729345322, 51.56533442437649, 53.54772225022316, 53.39283116161823, 54.304744228720665, 53.40806074440479, 50.00538133084774, 35.45826472342014, 10.237802993506193, 1.1025345884263515, 1.7015010793693364, 3.100943067111075, 5.947318794205785, 6.273517990484834, 5.002129012718797, 8.358062859624624, 8.186879195272923, 10.694914665073156, 9.792338646948338, 1.8930663750506938, 0.3522001323290169, 1.7823090869933367, 17.273781895637512, 41.12639397382736, 31.783559806644917, 51.70295163989067, 46.55698277056217, 36.36001713573933, 19.133688993752003, 0.9319731406867504, 0.09853525130893104, 0.08387833935557865, 0.1293226020061411, 0.10325747018214315, 0.11966201374889351, 0.2688329026568681, 0.17127466649981216, 0.15769600606290624, 0.21972482762066647, 0.12045830852002837, 0.12114575991290621, 0.1864947794820182, 0.1327333494555205, 0.24448456621030346, 0.15632494760211557, 0.19137561757816002, 0.14052057143999264, 0.1329779761726968, 0.12848891783505678, 0.08637741775601171, 0.11019623183528893, 0.16862548131030053, 0.1595204573823139, 0.1944947158335708, 0.17887764290207997, 0.07962899471749552, 0.11453374361735769], [0.0089854500220099, 0.020982934220228344, 0.055856987892184407, 0.06226398589205928, 0.060762502398574725, 0.066646212071646, 0.0493940913293045, 0.08261970142484643, 0.023817836299713235, 0.019078141704085283, 0.061850921338191256, 0.07410066988086328, 0.0027635993137664627, 0.036057916513527744, 0.02995800066855736, 0.046316312145791017, 0.05949879559921101, 0.003877982289850479, 0.04464373392693233, 0.051476850858307444, 0.04616805701516569, 0.039908111866679974, 0.060579603814403526, 0.01434648549548001, 0.030174223538779188, 0.02661364389496157, 0.047885653912089765, 0.040964948711916804, 0.0196279172814684, 0.022872861518408172, 0.023797295507392846, 0.04564256079902407, 0.017998411458393093, 0.0453252926672576, 0.06057934035197832, 0.17920699319802225, 4.545026840642095, 25.74504353106022, 35.07596343755722, 24.24154780805111, 19.032870903611183, 33.59742857515812, 43.16626511514187, 22.395874746143818, 6.291954126209021, 0.6288392411079258, 0.13526181690394878, 1.1958015337586403, 4.109517959877849, 4.004015671089292, 3.1005220022052526, 0.3771928162313998, 2.2109512612223625, 1.6750903590582311, 0.17995034315390512, 0.5890364362858236, 0.7472272915765643, 4.5992181077599525, 14.846759978681803, 37.133051455020905, 52.89370134472847, 58.81100222468376, 55.08892334997654, 55.53856462240219, 54.944428503513336, 54.42175135016441, 54.523034915328026, 53.53346161544323, 53.147094547748566, 54.71058525145054, 57.14149720966816, 59.008694216609, 54.942129626870155, 53.41140076518059, 57.3531648516655, 57.21488267183304, 53.11039611697197, 51.257037967443466, 41.941613629460335, 42.2461748868227, 42.281114012002945, 41.181741803884506, 41.71357646584511, 42.62250669300556, 41.77834779024124, 44.549740478396416, 47.63630345463753, 52.90312483906746, 52.24697984755039, 57.81989000737667, 41.90075822174549, 45.425430089235306, 50.25957629084587, 54.18062008917332, 54.5874110609293, 55.027708634734154, 56.041486635804176, 54.06110130250454, 45.9493687748909, 38.909657523036, 39.614436104893684, 40.26506759226322, 47.8133587539196, 50.99645175039768, 51.41679659485817, 53.15742239356041, 50.4279300570488, 47.32391081750393, 44.02218818664551, 44.757380336523056, 48.02587375044823, 51.51607386767864, 54.00279723107815, 49.57517981529236, 51.858465895056725, 50.94907209277153, 50.52264757454395, 47.84044370055199, 46.79303750395775, 48.93206812441349, 49.19608175754547, 49.74849991500378, 52.19378650188446, 51.31524704396725, 47.582483142614365, 33.805828392505646, 10.287586972117424, 0.798871151637286, 0.7083661830984056, 1.4906588243320584, 1.5930031263269484, 4.811585862189531, 2.5502514420077205, 0.9660441312007606, 3.0966454977169633, 3.0282266065478325, 2.419398813508451, 0.5241910158656538, 0.3490510809933767, 0.8145855052862316, 11.246509216725826, 27.727801837027073, 30.489142164587975, 17.610774412751198, 30.223525017499924, 36.88944652676582, 15.42988808825612, 3.2297167321667075, 0.03934294043574482, 0.07095650187693536, 0.05369587612221949, 0.04550345263851341, 0.02022329226747388, 0.0641499315679539, 0.05334604997187853, 0.08794251814833842, 0.016963159978331532, 0.04347194953879807, 0.02482834086549701, 0.03532351314788684, 0.04151070927036926, 0.03164726236718707, 0.040613460150780156, 0.04587950257700868, 0.017661773272266146, 0.020238099968992174, 0.01537735737656476, 0.0038172140784809017, 0.05933326327067334, 0.02072292278171517, 0.0489962036954239, 0.03093079856625991, 0.04604460445989389, 0.037937268207315356, 0.013905522682762239, 0.059815028434968553, 0.025907698181981687, 0.06220516326720826, 0.025158123462460935, 0.03192163807398174, 0.08173987793270499, 0.0721366799552925, 0.017303649910900276, 0.03805879117862787, 0.02104253424477065, 0.07529698224971071, 0.03194326054654084, 0.047119189766817726, 0.06733395290211774, 0.04045251429488417, 0.06925842346390709, 0.06217553673195653, 0.03758524158911314, 0.015659117452742066, 0.022423173832066823, 0.11072747598518617, 0.039460685875383206, 0.04169856540102046, 0.045704021758865565, 0.018351337930653244, 0.04968388515408151, 0.03453914097917732, 0.039969186909729615, 0.03077445217058994, 0.01838160642364528, 0.014835412384854862, 0.057528393517713994, 0.0707330486329738, 0.0065905487463169266, 0.06168406798678916, 0.022762880798836704, 0.492858134675771, 8.248555585741997, 34.27727669477463, 36.021766886115074, 23.51217694580555, 19.537960700690746, 38.86706180870533, 45.920440927147865, 21.73502940684557, 4.921234203502536, 0.7353280519600958, 0.16271417116513476, 0.45323777943849564, 1.9455763511359692, 6.342481914907694, 4.615035708993673, 5.229150680825114, 4.917746465653181, 1.7374030966311693, 1.511805283371359, 1.364523523952812, 1.4858427015133202, 5.708866389468312, 18.24959423393011, 40.44000640511513, 54.376347586512566, 58.57637241482735, 58.08862678706646, 57.47679881751537, 56.64357952773571, 55.87762422859669, 55.57855747640133, 54.50365975499153, 55.25994077324867, 55.914083272218704, 58.318480253219604, 58.855706825852394, 55.4287239164114, 53.579446747899055, 58.21405045688152, 57.73850977420807, 55.162734389305115, 51.89287684857845, 43.961919620633125, 44.14714828133583, 43.73369626700878, 43.45297873020172, 44.2561986297369, 42.969804257154465, 42.957568913698196, 46.674730852246284, 51.415326073765755, 54.73774999380112, 53.63664507865906, 57.018114030361176, 44.38272804021835, 46.78932510316372, 51.39922633767128, 54.76790137588978, 54.05984356999397, 56.77752234041691, 56.02474473416805, 55.38286417722702, 47.93929539620876, 41.24093122780323, 42.491497322916985, 43.00558313727379, 49.9419779330492, 53.373581394553185, 54.06062252819538, 54.461516216397285, 53.34429256618023, 48.834683150053024, 44.90689091384411, 46.68807953596115, 50.15157848596573, 53.8557755202055, 54.07502755522728, 50.96557080745697, 52.82554440200329, 51.71188496053219, 52.393583580851555, 51.36410482227802, 49.43720921874046, 49.4632226228714, 52.007528096437454, 52.075582444667816, 51.96802541613579, 52.476479932665825, 49.70148503780365, 38.27578693628311, 14.407307859510183, 2.005561594851315, 0.9773323754779994, 2.977603585459292, 3.557701357640326, 5.376206589862704, 4.59317073225975, 3.0658448254689574, 4.839435992762446, 5.219792732968926, 0.6883553287480026, 0.13237597566330805, 0.17862458538729697, 0.826445440761745, 9.891330935060978, 33.30059990286827, 39.88716647028923, 19.852940998971462, 35.21331086754799, 45.26526868343353, 19.31160494685173, 4.4985453598201275, 0.07729249860858545, 0.08625221744296141, 0.02574842957983492, 0.032214196398854256, 0.026499557243369054, 0.00890715158675448, 0.06496848334791139, 0.048356917686760426, 0.01708747342490824, 0.0018160666741096065, 0.010700914172048215, 0.012380748739815317, 0.040615293255541474, 0.019541624060366303, 0.030685730271216016, 0.058092117760679685, 0.04528502373432275, 0.07096764151356183, 0.051807663185172714, 0.009713843846839154, 0.056273165755555965, 0.03921738018107135, 0.023628579365322366, 0.023448315405403264, 0.0462147084181197, 0.025197574177582283, 0.05040075528086163, 0.03962738708651159, 0.15417889400850981, 0.13076627219561487, 0.09403239644598216, 0.11104172357590869, 0.21927801019046456, 0.22685015777824447, 0.10245085955830291, 0.13679092313395813, 0.11769040196668357, 0.22954893327550963, 0.1537378950160928, 0.1377923326799646, 0.09387085316120647, 0.13751877704635262, 0.2317783300532028, 0.09902167716063559, 0.14872655767248943, 0.1086351835692767, 0.11017713637556881, 0.20628402853617445, 0.07919372510514222, 0.18187587498687208, 0.17623072868445888, 0.11849014030303806, 0.11211130680749193, 0.08276563734398223, 0.2435175032587722, 0.13666622748132795, 0.11790889766416512, 0.10686906505725347, 0.20291411405196413, 0.16214675473747775, 0.10151098147616722, 0.17617141624214128, 0.12127836685976945, 0.33536065311636776, 7.284739203751087, 36.667770221829414, 47.43684835731983, 33.24457950890064, 26.367754116654396, 40.560991913080215, 53.86747509241104, 28.37027706205845, 8.239096943289042, 1.3953919988125563, 0.33711277472320944, 2.5328832864761353, 9.087157286703587, 11.203930601477623, 8.702312037348747, 4.792243950068951, 4.657823788002133, 4.937873035669327, 2.3680868418887258, 1.6967024118639529, 1.3356816465966403, 5.768448617309332, 18.511630073189735, 42.232355028390884, 54.805637151002884, 60.345036908984184, 59.47677589952946, 60.183849558234215, 61.144381016492844, 58.900426626205444, 60.26177577674389, 59.322686567902565, 58.224222511053085, 58.901695758104324, 60.50934389233589, 60.311062932014465, 56.28714345395565, 53.02070952951908, 58.41762073338032, 61.25416472554207, 56.941639333963394, 54.527416080236435, 46.06444180011749, 45.89546486735344, 45.176243260502815, 45.307735204696655, 44.8080126196146, 45.50465203821659, 45.48303119838238, 48.51521149277687, 53.042793944478035, 58.76124769449234, 55.21798722445965, 60.83457604050636, 47.981495931744576, 44.43456865847111, 53.2749804854393, 54.68418426811695, 57.00629286468029, 58.09615798294544, 58.65924596786499, 58.44431810081005, 50.28174430131912, 42.393998354673386, 43.14538523554802, 44.03114050626755, 52.487799525260925, 55.663053542375565, 54.1910695284605, 55.71833297610283, 54.557867646217346, 51.212633550167084, 48.642006888985634, 49.66793283820152, 50.68679116666317, 55.43485678732395, 55.548128709197044, 50.354745984077454, 53.3397214114666, 52.6397305727005, 55.07965564727783, 53.2308192551136, 51.00053273141384, 52.99257583916187, 53.43427933752537, 54.4570704549551, 54.93035785853863, 53.57064642012119, 50.611376613378525, 37.10252769291401, 13.039483856409788, 1.346649401821196, 1.4177187695167959, 4.156576059758663, 5.951712308451533, 10.361778941005468, 6.597130000591278, 5.4589808732271194, 6.7928641475737095, 8.76305177807808, 7.991263791918755, 1.2014834163710475, 0.6124954274855554, 1.3732111640274525, 14.931930508464575, 34.9681556224823, 40.99737949669361, 24.342660382390022, 40.10125458240509, 47.138879746198654, 24.397559836506844, 4.205929236486554, 0.2598766051232815, 0.24059008690528572, 0.09140952781308442, 0.11933497895370238, 0.13625638384837657, 0.18395005899947137, 0.3016360674519092, 0.16331036807969213, 0.07895788541645743, 0.14935077808331698, 0.1003883421071805, 0.0948329882521648, 0.15863762819208205, 0.10910564582445659, 0.22869503300171345, 0.18626572302309796, 0.1614737752242945, 0.10900912209763192, 0.11812222059234045, 0.14529549021972343, 0.15575187600916252, 0.13985287601826712, 0.17891090596094728, 0.09411573963006958, 0.15358238539192826, 0.0614403207146097, 0.12500732496846467, 0.15607098466716707], [0.03902938675309997, 0.037306984449969605, 0.009878025466605322, 0.04279917411622591, 0.04616775273461826, 0.012005321277683834, 0.05477465456351638, 0.05215197517827619, 0.03605238380259834, 0.043029963489971124, 0.013626068830490112, 0.020713165395136457, 0.06271392776397988, 0.06432571666664444, 0.03810665228229482, 0.04481616822886281, 0.05373958119889721, 0.009217154092766577, 0.023867630698077846, 0.08023927759495564, 0.017413790192222223, 0.08192233493900858, 0.10872418191866018, 0.0158794555318309, 0.04742410113976803, 0.03460781190369744, 0.044692719384329394, 0.07835003678337671, 0.0449378062330652, 0.04780948729603551, 0.05915704030485358, 0.0007511118349157186, 0.04272159370884765, 0.032086298378999345, 0.06495493173133582, 0.07843456740374677, 0.18700344749959186, 5.035861702635884, 28.852488286793232, 36.11898086965084, 26.048616841435432, 16.843411289155483, 22.249991074204445, 42.03140281140804, 28.73046163469553, 10.377415101975203, 1.2550807278603315, 0.21979583631036803, 1.468206422869116, 5.7467204332351685, 3.2660045474767685, 3.976763295941055, 3.3643891056999564, 1.8554029148072004, 1.851300559937954, 0.8712111948989332, 0.7836570055224001, 1.0034287814050913, 4.426196292042732, 18.169840313494205, 35.29294319450855, 54.79655563831329, 55.42478732764721, 55.65823920071125, 55.924692302942276, 57.34977923333645, 55.663087740540504, 56.03359445929527, 57.49314174056053, 57.33535520732403, 58.91553841531277, 58.47761571407318, 53.85958291590214, 53.014230877161026, 58.25728453695774, 57.09593765437603, 54.17540296912193, 51.969575732946396, 51.457705199718475, 47.67248131334782, 43.33269238471985, 43.18759337067604, 42.46210590004921, 41.756381168961525, 44.724356308579445, 47.10034981369972, 52.504298239946365, 51.77925534546375, 54.57512252032757, 52.63053126633167, 44.009553864598274, 46.64521023631096, 55.25328353047371, 53.66757161915302, 55.06917200982571, 54.782177209854126, 54.46729190647602, 51.33308708667755, 41.34128004312515, 41.22224003076553, 40.40717236697674, 41.27177037298679, 46.91886395215988, 48.80073957145214, 54.357147216796875, 53.328493013978004, 52.09130220115185, 49.5231644064188, 44.260651990771294, 43.557283133268356, 49.581875056028366, 50.61412386596203, 56.181604117155075, 50.605821311473846, 53.26066665351391, 51.62659853696823, 47.477916553616524, 49.26449328660965, 49.77856010198593, 48.844923600554466, 50.28744779527187, 50.97291961312294, 52.09691070020199, 47.27256037294865, 33.33578981459141, 11.328376773744822, 1.4955821726471186, 0.28961443284060806, 0.5598396935965866, 1.8633132590912282, 1.449350647162646, 5.468788621947169, 2.487038034014404, 2.100843619555235, 3.655451824888587, 5.203317292034626, 0.7890375168062747, 0.15639920689864084, 1.0139117063954473, 12.319830022752285, 29.420364014804363, 27.003562599420547, 23.246126621961594, 18.96782599389553, 22.517435923218727, 16.883732825517654, 4.576527625322342, 0.18033277185168117, 0.03815440206381027, 0.027603386879491154, 0.024355958303203806, 0.07099630325683393, 0.03469826857326552, 0.050148131922469474, 0.008444845534540946, 0.041671258077258244, 0.010946774709736928, 0.04713300855655689, 0.06647237882134505, 0.041340987518196926, 0.054258965828921646, 0.017500400681456085, 0.05794448974484112, 0.035866791222360916, 0.021798886627948377, 0.062002456761547364, 0.07727240867097862, 0.043547303503146395, 0.018267196937813424, 0.07858373908675276, 0.018445041496306658, 0.0045330032207857585, 0.054111193094286136, 0.03581638084142469, 0.07460511507815681, 0.03524595500493888, 0.03279919059423264, 0.0373710800340632, 0.041461323053226806, 0.02230413334473269, 0.006642970347456867, 0.012224137954035541, 0.009718499895825516, 0.07553581279353239, 0.052868047496303916, 0.030489677119476255, 0.026984962642018218, 0.07074666704284027, 0.05453007608593907, 0.02068072797555942, 0.029487193314707838, 0.033971717130043544, 0.06180690455948934, 0.007118211105989758, 0.10365393289248459, 0.06554893188877031, 0.037823715902050026, 0.07816202109097503, 0.07289312881766818, 0.03144823691400234, 0.061742909165332094, 0.040650983137311414, 0.02209730606409721, 0.05638714850647375, 0.09868548426311463, 0.01959389166586334, 0.02450128195050638, 0.015588342539558653, 0.05226413966738619, 0.023556737614853773, 0.02950726655399194, 0.01490340888267383, 0.28958148148376495, 9.09325310960412, 35.47024928033352, 39.69715006649494, 23.68854448199272, 20.809427574276924, 34.25601303577423, 48.136877194046974, 28.58919281512499, 8.05902460590005, 1.0631932807154953, 0.23202880489407107, 0.5692068440839648, 3.818379957228899, 3.2024398958310485, 10.298622529953718, 12.518219277262688, 4.514327337965369, 3.3825545059517026, 2.558621442876756, 1.7898931237868965, 2.928929622285068, 6.26408452168107, 20.11838525533676, 40.60869075357914, 56.01974040269852, 58.303885236382484, 57.91910648345947, 57.76136554777622, 58.209661692380905, 58.18261094391346, 58.79228822886944, 59.38706271350384, 59.39681299030781, 61.36066921055317, 59.590822979807854, 53.99166762828827, 53.09417478740215, 58.12675014138222, 58.923092409968376, 55.135269463062286, 53.219974637031555, 52.088813334703445, 47.82729260623455, 45.22060588002205, 44.61651809513569, 42.958416268229485, 43.09296704828739, 45.16172043979168, 48.075548484921455, 54.746546521782875, 53.60708646476269, 56.04846306145191, 55.26684120297432, 47.73471437394619, 48.703544586896896, 53.616080582141876, 54.342149421572685, 55.94473622739315, 55.441316440701485, 56.85696467757225, 53.37926208972931, 43.57353486120701, 41.18444725871086, 41.66070230305195, 42.57184401154518, 48.949634581804276, 51.593114733695984, 56.086274832487106, 54.7642307728529, 53.39620538055897, 50.30314855277538, 45.969815477728844, 44.976757764816284, 50.85414178669453, 51.98713459074497, 56.915150955319405, 51.44377514719963, 53.057628348469734, 52.76470586657524, 50.465392246842384, 50.0471942871809, 51.50873266160488, 49.66570995748043, 51.601219698786736, 51.487434804439545, 53.6053803563118, 46.78486414253712, 37.07356184720993, 15.008761435747147, 2.297420846298337, 0.7428343710489571, 1.6968764900229871, 1.9865515711717308, 4.7393284644931555, 2.5793422060087323, 4.532089484855533, 4.137698197737336, 2.3992413701489568, 2.466778471134603, 0.2747175993863493, 0.1894350053044036, 1.0795401223003864, 11.505027394741774, 34.24186259508133, 34.25440572202206, 24.580540917813778, 21.15014959126711, 27.753805741667747, 25.15054453164339, 7.420181035995483, 0.23039379419060424, 0.024043013181653805, 0.028537938196677715, 0.058882935481960885, 0.02162434277124703, 0.036503925002762116, 0.010184514831053093, 0.03051994561246829, 0.059310382857802324, 0.004571056379063521, 0.010797351624205476, 0.03783573498367332, 0.02664932264451636, 0.0688389541755896, 0.0318244872323703, 0.02194795812101802, 0.026065350757562555, 0.04287305120669771, 0.014138430888124276, 0.01768723264831351, 0.055898069476825185, 0.06500018789665774, 0.06901188942720182, 0.03376672109880019, 0.1306539258803241, 0.054614324690192007, 0.09124876378336921, 0.05459689535200596, 0.011848770791402785, 0.10872614861000329, 0.16804170794785023, 0.08330470373039134, 0.13018978672334924, 0.09332093657576479, 0.10350548109272495, 0.15775923704495654, 0.15669079672079533, 0.143449516617693, 0.12472421047277749, 0.11235580735956319, 0.14948809024645016, 0.13812068849802017, 0.20908296428387985, 0.1214250894554425, 0.1773286471143365, 0.09616675379220396, 0.1385007126373239, 0.17071548791136593, 0.17243057634914294, 0.18571966560557485, 0.2342417705222033, 0.1592583753517829, 0.15521657973295078, 0.14832526358077303, 0.08857218592311256, 0.09036164497956634, 0.09778548919712193, 0.15665406041080132, 0.15174224507063627, 0.14206245745299384, 0.21148900705156848, 0.12372830766253173, 0.11293401461443864, 0.13600068428786471, 0.12719648249913007, 0.34614198084454983, 7.984522003680468, 39.26965020596981, 50.643910467624664, 34.48533833026886, 26.083400174975395, 32.76834346354008, 52.0827716588974, 36.09001122415066, 12.888115178793669, 1.7653692397288978, 0.3445901203667745, 3.3055860735476017, 10.26220053434372, 8.80314152687788, 9.015640374273062, 8.787764701992273, 3.9355407329276204, 5.448434539139271, 2.9975900379940867, 1.912171037402004, 1.9102719705551863, 5.624389322474599, 20.913177207112312, 38.62537957727909, 58.490155041217804, 59.011673256754875, 60.02892807126045, 60.23293912410736, 62.701001688838005, 60.43194964528084, 59.77262802422047, 61.293025240302086, 61.894084587693214, 63.64705212414265, 61.76944747567177, 54.75353054702282, 52.84341104328632, 60.0584676861763, 61.633194386959076, 57.13856756687164, 54.34380613267422, 56.1316291987896, 51.876773312687874, 48.19904185831547, 47.13678605854511, 46.64796508848667, 44.88233283162117, 46.91906914114952, 51.48611627519131, 59.042937979102135, 56.38453222811222, 58.63904245197773, 55.03088526427746, 51.35908529162407, 46.7780777066946, 54.15001653134823, 57.082186192274094, 57.22666583955288, 57.54457578063011, 59.55721378326416, 55.90186692774296, 44.98481713235378, 44.99912716448307, 43.11330355703831, 45.25528281927109, 50.844072327017784, 53.2838986068964, 57.692543640732765, 56.73971816897392, 56.290320083498955, 52.0008784532547, 48.35816591978073, 48.59047785401344, 53.8514019548893, 53.1173687428236, 59.78010222315788, 51.72447368502617, 53.60712066292763, 53.86389948427677, 51.58972151577473, 52.55486212670803, 54.39125798642635, 52.03447625041008, 53.60158056020737, 53.070243671536446, 55.45160248875618, 48.833980187773705, 37.41946488618851, 13.400442637503147, 1.924175899475813, 0.8253985969349742, 1.47319994866848, 5.68046766333282, 5.6145597249269485, 10.497237872332335, 8.20370089262724, 6.359430430456996, 11.500369794666767, 10.780316032469273, 1.5535961533896625, 0.49797984422184527, 2.0762819750234485, 15.856881625950336, 36.86427667737007, 35.2941819280386, 33.4701582044363, 29.327498897910118, 34.74772185087204, 27.60959967970848, 7.618840076029301, 0.26376249035820365, 0.13770636229310185, 0.13683111785212532, 0.24696938053239137, 0.22671827813610435, 0.09719804220367223, 0.1804400418768637, 0.19810646655969322, 0.15594012918882072, 0.06588274249224924, 0.16253782203420997, 0.15619973244611174, 0.10491302353329957, 0.1222606141527649, 0.11386210739146918, 0.12362043649773113, 0.1406290289014578, 0.11985329489107244, 0.10389945760834962, 0.12554331886349246, 0.25621377979405224, 0.08908505449653603, 0.14400586020201445, 0.1731365517480299, 0.2077195351012051, 0.14287429279647768, 0.1667224068660289, 0.23790667386492714, 0.1113093642925378], [0.04891111275355797, 0.08954972799983807, 0.03847265354124829, 0.05498316837474704, 0.04553320904960856, 0.017149930718005635, 0.06584755727089942, 0.04679887140810024, 0.04426099723787047, 0.059375406126491725, 0.028292860624787863, 0.019611641982919537, 0.040666200875421055, 0.037414914986584336, 0.039886170270619914, 0.010554232394497376, 0.05632308260828722, 0.022569616266991943, 0.014958733208914055, 0.023718536940577906, 0.043346775200916454, 0.03460082087258343, 0.04345262030255981, 0.07770761891151778, 0.09288350731367245, 0.009417341934749857, 0.008232947529904777, 0.042507977632340044, 0.06224212222150527, 0.05845538049470633, 0.06534847780130804, 0.031215176568366587, 0.0346762527624378, 0.02606221332825953, 0.031271498155547306, 0.03806102875387296, 0.07819226360879838, 0.17287852184381336, 5.147734824568033, 24.546929821372032, 31.328938901424408, 28.128668926656246, 12.999725639820099, 22.12447050958872, 32.885426580905914, 31.12421538680792, 11.17247398942709, 0.9908490814268589, 0.023636243895452935, 2.3490237398073077, 3.0077844159677625, 16.521268375217915, 22.191377319395542, 2.8402718296274543, 2.007408058270812, 2.347346367314458, 1.5233709127642214, 0.6486219295766205, 1.0751730878837407, 5.280275037512183, 19.152896963059902, 40.101927146315575, 56.530262008309364, 58.4592816978693, 58.17108616232872, 56.4438546448946, 57.424817606806755, 56.721258759498596, 59.691574573516846, 59.51229639351368, 59.024391174316406, 54.65367950499058, 54.49487082660198, 55.57736814022064, 54.518927335739136, 55.67822612822056, 55.95346435904503, 53.06055039167404, 54.442513436079025, 53.72776418924332, 48.797733932733536, 40.52674435079098, 43.7203323841095, 41.50086767971516, 46.50321565568447, 51.71658530831337, 55.1015804708004, 57.81556583940983, 57.82951109111309, 53.97246725857258, 45.59383325278759, 51.76092132925987, 57.136880457401276, 56.495797857642174, 57.6436972618103, 55.92355236411095, 53.02765175700188, 48.190138936042786, 41.93231552839279, 41.76455833017826, 39.610826298594475, 41.83138154447079, 47.62748792767525, 49.86447349190712, 51.64639547467232, 53.654162138700485, 52.21891835331917, 51.24366648495197, 49.94195893406868, 44.62202399969101, 46.03158116340637, 53.43360297381878, 51.5950982272625, 53.85523594915867, 52.54532463848591, 53.27502988278866, 51.71094261109829, 52.04665459692478, 50.76790161430836, 52.89559364318848, 51.07728101313114, 50.533891171216965, 43.92239414155483, 27.638757415115833, 10.485195368528366, 1.1175681254826486, 0.1330115509335883, 0.6541374523658305, 1.2220467254519463, 1.3074474991299212, 4.281928958371282, 1.6451584151946008, 4.215708486735821, 2.4905010731890798, 1.5134261338971555, 1.1562089645303786, 0.30361766112037003, 1.1212209169752896, 13.160494063049555, 27.267220951616764, 26.25509586185217, 20.656569376587868, 23.713311553001404, 23.1850752979517, 13.453206606209278, 4.212845815345645, 0.05991961188556161, 0.07617794864927419, 0.004893011173408013, 0.028000148304272443, 0.00650572729682608, 0.09947365993866697, 0.06782692449633032, 0.03305067104520276, 0.04995609378966037, 0.04659235397411976, 0.05280254925310146, 0.06363874024827965, 0.0525649543851614, 0.021982243488309905, 0.02295852391398512, 0.04977018208592199, 0.029431478433252778, 0.04371439434180502, 0.015033650233817752, 0.027712785013136454, 0.0384153523191344, 0.019416874602029566, 0.08220176096074283, 0.022347725243889727, 0.011713313997461228, 0.04828551194805186, 0.0021676621508959215, 0.015036518634587992, 0.03928892321710009, 0.046218433999456465, 0.020022778808197472, 0.050734636388369836, 0.06731408560881391, 0.05451983444800135, 0.014722233936481643, 0.07295725037693046, 0.037243041006149724, 0.06538268338772468, 0.019560123946575914, 0.035309609011164866, 0.04507943398493808, 0.07364956283709034, 0.11820414627436548, 0.03720264961884823, 0.031390479271067306, 0.08971695613581687, 0.07330902095418423, 0.019871989243256394, 0.008786558155406965, 0.015031732709758217, 0.03757570870220661, 0.0759965529141482, 0.04610003175912425, 0.14184046623995528, 0.04462989658350125, 0.03474531331448816, 0.03543258659192361, 0.028769011441909242, 0.021270588804327417, 0.02227900051366305, 0.04989802073396277, 0.012654014008148806, 0.03643451564130373, 0.021472057778737508, 0.048399090228485875, 0.1093744146055542, 0.07862713246140629, 0.29341446643229574, 9.159707743674517, 31.760491244494915, 35.0877770036459, 25.950038731098175, 17.947898022830486, 34.52541097998619, 47.8054665774107, 31.91508784890175, 10.046545956283808, 0.7123446883633733, 0.08713275339687243, 0.23812971892766654, 1.868075947277248, 12.960525043308735, 15.359596610069275, 9.333321377635002, 8.387239594012499, 1.5409617125988007, 2.2830690164119005, 1.7555967578664422, 2.345703667961061, 6.794685199856758, 22.107897698879242, 44.55063723027706, 58.6059196293354, 58.31752650439739, 59.26780991256237, 59.70190241932869, 58.82015973329544, 59.43615987896919, 61.513166427612305, 61.79527088999748, 60.599737241864204, 55.10314978659153, 54.26839917898178, 54.65231157839298, 56.38942636549473, 56.99427030980587, 58.24902758002281, 55.076091438531876, 57.23412483930588, 55.234235152602196, 48.96619789302349, 42.9814126342535, 44.27757628262043, 44.07730042934418, 48.81617434322834, 53.93449209630489, 57.90650635957718, 59.44327689707279, 59.7140883654356, 55.75129620730877, 46.81317642331123, 53.38948734104633, 55.349897146224976, 56.58328056335449, 57.799192517995834, 57.457807436585426, 54.51003961265087, 49.1771549731493, 44.59640957415104, 42.86556825041771, 39.781722128391266, 43.81795674562454, 49.85246993601322, 53.833949491381645, 54.80202354490757, 54.290156811475754, 53.87002855539322, 53.39304395020008, 51.185263618826866, 47.564783692359924, 49.33141149580479, 55.002413392066956, 52.876796051859856, 52.68211729824543, 53.423438519239426, 54.23647329211235, 52.55354359745979, 53.389403745532036, 53.53794537484646, 53.33613060414791, 52.59746924042702, 51.45758740603924, 45.808688923716545, 31.803529635071754, 15.249647609889507, 2.433538567274809, 0.43627611303236336, 1.829443657770753, 3.0040026688948274, 2.115590628236532, 4.777094163000584, 3.653350775130093, 3.402227950282395, 4.297724235802889, 1.4453461370430887, 0.6700282590463758, 0.28138288704212755, 0.5052387015894055, 11.145377643406391, 30.863948352634907, 33.30841988325119, 23.745132945477962, 25.445458106696606, 26.314125694334507, 20.22730451077223, 6.794707523658872, 0.32558259030338377, 0.024230574308603536, 0.034884785127360374, 0.05772827244072687, 0.04497887668549083, 0.13643728976603597, 0.03289613363449462, 0.0325733439240139, 0.01334483660684782, 0.0431170804949943, 0.07916585003840737, 0.06678510500933044, 0.05246979621006176, 0.05484892870299518, 0.025432668007852044, 0.05179759224120062, 0.016790328627394047, 0.06470619351603091, 0.05782346401247196, 0.023473001092497725, 0.01768426034686854, 0.016853856468515005, 0.03345855169754941, 0.05402731185313314, 0.008858146647980902, 0.03920998096873518, 0.05190451345697511, 0.01337268105999101, 0.03068941688979976, 0.036773432220797986, 0.2616849518381059, 0.19084107829257846, 0.1701979586505331, 0.21539795823628083, 0.10815865796757862, 0.16408564522862434, 0.11861811624839902, 0.15044183906866238, 0.12051508281729184, 0.11629356871708296, 0.10054710233816877, 0.1626188645604998, 0.222113014315255, 0.12258141490747221, 0.14162472391035408, 0.1285988447489217, 0.17407112347427756, 0.1275495666777715, 0.1080493099289015, 0.08768868879997171, 0.13979871408082545, 0.0880895450245589, 0.10961747539113276, 0.20206894143484533, 0.26036873809061944, 0.10901730798650533, 0.0870233385649044, 0.09586259198840708, 0.12536413472844288, 0.18803182669216767, 0.13245204580016434, 0.14218157215509564, 0.09574912503012456, 0.12168141984147951, 0.1024723521550186, 0.15709682571468875, 0.21809156838571653, 0.3105800156481564, 7.781895026564598, 35.605244636535645, 44.9096305668354, 39.124133214354515, 21.15496963262558, 31.50754451751709, 45.3888950496912, 38.53489123284817, 14.036132376641035, 1.5511497971601784, 0.16472401097416878, 4.09969643689692, 5.44304215349257, 25.49646656960249, 34.036593809723854, 8.222202099859715, 6.496809683740139, 5.691572092473507, 3.040980384685099, 1.9121848116628826, 2.039404478855431, 6.561946738511324, 22.688018269836903, 44.347785115242004, 61.76224686205387, 60.63786059617996, 62.35658057034016, 61.94901444017887, 62.58652903139591, 62.71015539765358, 62.76809848845005, 64.3699823319912, 60.7062379270792, 56.24875031411648, 54.87594477832317, 54.76412057876587, 56.718967482447624, 58.166150227189064, 62.2000365704298, 56.784464567899704, 59.52798955142498, 57.973295375704765, 52.6629701256752, 46.599912866950035, 45.86785554885864, 44.97708834707737, 51.2929954379797, 56.36373594403267, 59.6018385887146, 61.92495033144951, 61.7930556088686, 56.390076130628586, 51.52680829167366, 51.09999619424343, 54.734128788113594, 58.053516671061516, 61.69657498598099, 60.67783445119858, 56.139996349811554, 51.31001852452755, 46.19777284562588, 46.66946433484554, 41.96546494960785, 45.43309047818184, 52.39930987358093, 54.99341167509556, 56.52217224240303, 54.94970262050629, 55.32499708235264, 54.84760969877243, 54.57563169300556, 49.89630438387394, 50.04331849515438, 57.918756902217865, 53.91197070479393, 52.80082292854786, 53.910139203071594, 54.3917291611433, 53.99902783334255, 56.093562841415405, 55.51676519215107, 55.307586416602135, 53.55707734823227, 52.61032395064831, 45.30737042427063, 29.919632524251938, 12.328023333102465, 1.9124099495820701, 0.5897445639129728, 2.1665843669325113, 4.949138481169939, 5.6597416754812, 9.065192565321922, 6.846682084724307, 11.549352966248989, 8.414635173976421, 6.905933730304241, 3.348679323680699, 0.6170508486684412, 1.8733062478713691, 16.547475568950176, 33.70011426508427, 34.31163065135479, 31.052344143390656, 32.756241112947464, 34.514429569244385, 21.101415306329727, 6.3945110980421305, 0.37146233778912574, 0.2638166374526918, 0.08570552177843638, 0.09132671897532418, 0.11185401905095205, 0.27882678201422095, 0.15298506041290238, 0.23756105569191277, 0.1406906865304336, 0.11804986861534417, 0.2451052688411437, 0.17057177843526006, 0.13030168775003403, 0.1425027588265948, 0.07723671136773191, 0.10579637222690508, 0.1532518328167498, 0.09439236033358611, 0.08812647429294884, 0.144746582955122, 0.2221956747234799, 0.10823177435668185, 0.1313414514879696, 0.16545140475500375, 0.08083617212832905, 0.12451838323613629, 0.10007749355281703, 0.1400175437447615, 0.10026208794442937, 0.10802379489177838], [0.025039993961399887, 0.019197219298803248, 0.006677658329863334, 0.028452958576963283, 0.057567768162698485, 0.029598378168884665, 0.01624798751436174, 0.00871206972078653, 0.07118479392374866, 0.01467965970732621, 0.04727508901851252, 0.020295827926020138, 0.032099679301609285, 0.00945012074225815, 0.05437948690087069, 0.035115782302455045, 0.06014959602907766, 0.05222152183705475, 0.10373786237323657, 0.017210187543241773, 0.026788059731188696, 0.07947781923576258, 0.06018305204634089, 0.031949219992384315, 0.04294982638384681, 0.07857133779907599, 0.14393155637662858, 0.05554620613111183, 0.033242275021621026, 0.01965438226761762, 0.021254988860164303, 0.05345420686353464, 0.02119199536537053, 0.13035691838013008, 0.06663212610874325, 0.03511274691845756, 0.02860499866073951, 0.07430230398313142, 0.04233626321365591, 4.8305359203368425, 22.745207101106644, 34.83862057328224, 23.465070873498917, 16.091258749365807, 24.010364413261414, 28.950059451162815, 32.22914859652519, 12.75357199832797, 1.8855097680352628, 0.04765201469126623, 1.3656081282533705, 12.482460346072912, 16.302945390343666, 14.017397481948137, 7.259717546403408, 1.065886386204511, 2.9047686187550426, 3.182633458636701, 0.863010878674686, 0.444138603634201, 5.416796486824751, 20.591404773294926, 43.20648215711117, 55.791904628276825, 61.36255010962486, 57.73463398218155, 58.344402462244034, 59.183211252093315, 59.33556407690048, 55.3532637655735, 54.853332191705704, 54.65218238532543, 58.021966964006424, 56.16101682186127, 55.02698287367821, 55.61807155609131, 59.79995995759964, 58.467911034822464, 56.70209638774395, 55.25179781019688, 53.8739575445652, 47.02263258397579, 43.53676803410053, 43.31691563129425, 46.15141913294792, 55.956333205103874, 56.65816694498062, 58.3135861158371, 56.65659382939339, 42.05898553133011, 40.2502977848053, 53.67433525621891, 56.98232375085354, 55.031413435935974, 55.843802243471146, 56.352602541446686, 55.35426311194897, 49.72143016755581, 50.17107903957367, 45.64397536218166, 43.82823519408703, 40.66230967640877, 44.975883811712265, 47.84598380327225, 50.12230105698109, 54.3048582226038, 50.98861277103424, 50.25547631084919, 47.43620619177818, 49.75160054862499, 53.47862295806408, 51.72762751579285, 54.56800930202007, 53.12719501554966, 54.470004960894585, 50.153204798698425, 51.14851959049702, 50.94035916030407, 51.907969638705254, 51.18505083024502, 49.409907683730125, 38.76175045967102, 21.33956752717495, 7.373129585757852, 1.421061521396041, 0.5207926325965673, 0.2340866468148306, 1.0396496253088117, 1.4156253193505108, 0.6020269298460335, 4.675684254616499, 0.9793681162409484, 1.7930302117019892, 4.245355445891619, 0.7971443817950785, 0.4361819790210575, 1.2643107888288796, 13.474262226372957, 28.576908074319363, 27.90715791285038, 26.02138750255108, 22.477099187672138, 23.36634647101164, 11.679679322987795, 2.1526866126805544, 0.005872763458683039, 0.031110878844629042, 0.047327896536444314, 0.012224196398165077, 0.051901697006542236, 0.043670184604707174, 0.0651948235463351, 0.030568285401386674, 0.04014978483610321, 0.05905711754166987, 0.022989918616076466, 0.017195407672261354, 0.074495121371001, 0.03895750975061674, 0.05689743069524411, 0.05734297534218058, 0.022007825318723917, 0.02453243545460282, 0.05145172544871457, 0.09535546763800085, 0.0048267962938552955, 0.06633082157350145, 0.020324252182035707, 0.07053144421661273, 0.02925628148659598, 0.04016557773866225, 0.009637962029955816, 0.04506947807385586, 0.029988792375661433, 0.04066978915943764, 0.04335895013355184, 0.029206596555013675, 0.06178637304401491, 0.06241891664103605, 0.03318485876661725, 0.009346445494884392, 0.015860638377489522, 0.057386209155083634, 0.011595145533647155, 0.045756602921755984, 0.022305997990770265, 0.02986764047818724, 0.025449182649026625, 0.019990992623206694, 0.03584875332308002, 0.05033537949202582, 0.022108601551735774, 0.020721037726616487, 0.08160854005836882, 0.006184330504765967, 0.08014961873413995, 0.04191307205474004, 0.0768056719971355, 0.03025623085704865, 0.06837584660388529, 0.027363133267499506, 0.039614046982023865, 0.13770407647825778, 0.023363335785688832, 0.022325681602524128, 0.048248597522615455, 0.057846147756208666, 0.02526124859286938, 0.04052868091093842, 0.012759360015479615, 0.019665584986796603, 0.02245309908175841, 0.04559570901619736, 0.08239140195655636, 0.11097506387159228, 8.212798554450274, 30.387571714818478, 38.072661235928535, 22.607114911079407, 16.72795258462429, 30.361125133931637, 40.884970128536224, 33.8671875, 10.491945706307888, 1.303315933328122, 0.05067983620392624, 0.7555980049073696, 3.585589723661542, 3.6087475810199976, 10.72222189977765, 12.086361050605774, 4.512112531810999, 3.3829028997570276, 2.425323883071542, 2.920566746033728, 1.3907856959849596, 8.7057451531291, 24.23127505928278, 46.51941038668156, 59.444367438554764, 61.89219228923321, 58.879512548446655, 60.06933130323887, 61.102955639362335, 59.29057069122791, 57.382499277591705, 54.368235021829605, 55.93363702297211, 57.60832875967026, 56.182975843548775, 55.228429064154625, 57.69037015736103, 60.64680531620979, 59.82542239129543, 59.21247348189354, 58.16141568124294, 55.97449243068695, 49.29406329989433, 46.203928515315056, 44.8742962628603, 49.04678016901016, 57.994209453463554, 57.963640093803406, 61.397394239902496, 56.017851904034615, 46.37110814452171, 44.61433321237564, 53.35289530456066, 58.159701973199844, 55.71554012596607, 58.25402811169624, 57.17981435358524, 57.804174050688744, 50.18322318792343, 50.92925235629082, 46.214913725852966, 44.60638403892517, 43.051165491342545, 46.79005466401577, 50.71620158851147, 52.225716188549995, 55.87459199130535, 53.34425076842308, 52.29327276349068, 50.26871100068092, 52.24240489304066, 52.50298731029034, 54.55993093550205, 56.20677396655083, 54.92381080985069, 53.61705332994461, 51.168343126773834, 53.480093479156494, 54.21471565961838, 53.24733316898346, 53.14845107495785, 50.10678268969059, 42.007916271686554, 25.30190370976925, 9.821033757179976, 2.955518220551312, 1.2248774548061192, 1.1947717890143394, 3.1676947977393866, 4.141609612852335, 3.5350092127919197, 4.141422472894192, 2.7894550189375877, 2.1328818378970027, 0.9068003227002919, 0.337649347493425, 0.25229737744666636, 0.9056906041223556, 12.195345852524042, 33.73471520841122, 32.122089341282845, 26.600499227643013, 23.926540911197662, 27.536465004086494, 17.01645590364933, 4.354047663509846, 0.17691449902486056, 0.03239447520172689, 0.07000917263212614, 0.022310506537905894, 0.09363177028717473, 0.018813757160387468, 0.029624063899973407, 0.019763307282119058, 0.048410934905405156, 0.06246918230317533, 0.05784139801107813, 0.033289219572907314, 0.02316188722033985, 0.0553422676603077, 0.034270134710823186, 0.01938316439918708, 0.051193836552556604, 0.04786938603501767, 0.05236755052465014, 0.07531569921411574, 0.0625769495673012, 0.009399536884302506, 0.014936519801267423, 0.0513129289902281, 0.02605135756311938, 0.05139335182320792, 0.015487745349673787, 0.027890026576642413, 0.018961450114147738, 0.04804199474165216, 0.03737052342330571, 0.09101768126129173, 0.13881937600672245, 0.1580996750271879, 0.1152672378520947, 0.17548001662362367, 0.10075120037072338, 0.09031187655637041, 0.14153057505609468, 0.1754133717622608, 0.13903301063692197, 0.13911714049754664, 0.15132603381061926, 0.1825256401207298, 0.11786835413658991, 0.1682634319877252, 0.12933417950989679, 0.21469863248057663, 0.18766148015856743, 0.1526581888902001, 0.15070107125211507, 0.1480051307589747, 0.15416056296089664, 0.1308814832009375, 0.14084312366321683, 0.11692317712004296, 0.13875231554266065, 0.3059853200102225, 0.15852005715714768, 0.13589393376605585, 0.1745392256998457, 0.13824444904457778, 0.19884245441062376, 0.11868329165736213, 0.279283351264894, 0.18532156274886802, 0.15593491931213066, 0.16412098630098626, 0.18054193875286728, 0.31527748389635235, 7.336291037499905, 33.36484685540199, 47.30941839516163, 33.58115404844284, 21.910342499613762, 32.22770467400551, 42.80627243220806, 39.3491305410862, 15.489889718592167, 2.309725536033511, 0.7257848046720028, 2.660550973378122, 18.512635119259357, 26.408767215907574, 24.65024057775736, 14.06425941735506, 5.1339273154735565, 7.274802736938, 7.12674985639751, 2.826140862889588, 1.0649306187406182, 7.24181623198092, 23.65304298698902, 45.02278849482536, 62.05780640244484, 64.83988791704178, 60.81198625266552, 60.313301011919975, 61.401817202568054, 60.8260340988636, 56.283305659890175, 55.872939079999924, 55.621308982372284, 58.819004595279694, 56.292995139956474, 55.44056788086891, 57.232399731874466, 62.58715219795704, 63.71871627867222, 62.115076929330826, 61.35633744299412, 58.55822838842869, 52.607439905405045, 48.085899129509926, 47.388666942715645, 51.22847110033035, 59.233642145991325, 61.63426972925663, 63.511091619729996, 59.001322612166405, 44.00113731622696, 47.90657535195351, 54.70867395401001, 57.02539063990116, 55.6082908809185, 58.96777041256428, 61.704600155353546, 61.28085449337959, 52.89832569658756, 54.45165194571018, 48.38031493127346, 47.537824138998985, 44.71708729863167, 48.786558732390404, 53.49582463502884, 54.69488449394703, 58.29138770699501, 54.943140372633934, 53.67364749312401, 52.33457654714584, 55.454136952757835, 55.98296597599983, 54.760670363903046, 56.34154513478279, 53.6299916356802, 56.87368378043175, 51.97270296514034, 54.08529840409756, 54.522700533270836, 54.568792060017586, 53.64610277116299, 51.65517300367355, 40.82266867160797, 24.37164332717657, 8.497760463505983, 2.886563795618713, 0.903868245659396, 0.6771985930390656, 3.6192967649549246, 5.690859155729413, 3.9798800786957145, 13.497868459671736, 8.75873425975442, 5.85585200227797, 9.156939592212439, 2.1908529521897435, 0.6601825123652816, 1.838497978169471, 16.892430558800697, 35.18525317311287, 37.125497460365295, 33.5016243159771, 31.70037467032671, 34.257456958293915, 18.084094114601612, 3.661514399573207, 0.2563622687011957, 0.14102380693657324, 0.1247545939986594, 0.10322995876776986, 0.22473606106359512, 0.11579542435356416, 0.13164411415345967, 0.08233162196120247, 0.15445963363163173, 0.1933931905659847, 0.15305598004488274, 0.1109593451838009, 0.14519570104312152, 0.1787785958731547, 0.15608198329573497, 0.1295942280557938, 0.1773356826743111, 0.11582688399357721, 0.16445237008156255, 0.20448249473702163, 0.12116335623431951, 0.3057703940430656, 0.08359405968803912, 0.11333381698932499, 0.09933544235536829, 0.22831031848909333, 0.07199411338660866, 0.15790218953043222, 0.10391222996986471, 0.1279386004898697, 0.09208685631165281], [0.08474314177874476, 0.058843297374551184, 0.007256647622853052, 0.035158722967025824, 0.06211235398950521, 0.025140725665551145, 0.0017890576009449433, 0.018356839100306388, 0.06519544695038348, 0.046385784589801915, 0.03371513812453486, 0.04550262885459233, 0.026993775645678397, 0.049039114674087614, 0.08600638102507219, 0.03980498302553315, 0.03163982975820545, 0.04406517415191047, 0.014376940453075804, 0.06383595115039498, 0.028090753403375857, 0.07420701964292675, 0.028062143610441126, 0.04912993870675564, 0.02239033750811359, 0.07827011490007862, 0.05072881052910816, 0.02521979778975947, 0.02959567489597248, 0.05928203281655442, 0.052702051325468346, 0.03993265469034668, 0.015669329404772725, 0.06174325055326335, 0.06346030568238348, 0.026427917728142347, 0.04783185191627126, 0.036965121544199064, 0.04409541666973382, 0.056627329759066924, 4.7439328674227, 18.492509499192238, 35.50259694457054, 25.659753307700157, 20.546865463256836, 21.14316936582327, 35.996737629175186, 33.79886336624622, 15.08633902296424, 1.9973692344501615, 0.3137421584688127, 2.777825742959976, 1.1490370868705213, 9.317594021558762, 19.52902738004923, 2.772042928263545, 2.633516611531377, 1.1930709052830935, 1.5300691220909357, 0.20636285946238786, 0.931194182485342, 6.330859288573265, 20.704135224223137, 37.33927018940449, 51.28933243453503, 56.90685600042343, 56.92539140582085, 58.70152249932289, 59.05376739799976, 58.62782925367355, 56.09016202390194, 58.15586797893047, 58.349444791674614, 56.28462038934231, 55.53916119039059, 55.42397417128086, 59.04648318886757, 60.78749656677246, 58.07327181100845, 58.19240301847458, 54.72258120775223, 51.759534403681755, 43.831867799162865, 44.71271373331547, 43.62911067903042, 52.3479176312685, 58.31392429769039, 56.951252818107605, 60.793743431568146, 54.57489833235741, 37.492025792598724, 50.64432844519615, 57.71493963897228, 56.13419786095619, 58.76836471259594, 57.0944557338953, 56.6346538066864, 54.663916155695915, 51.57201066613197, 52.64720857143402, 48.11857357621193, 42.75326527655125, 44.83936473727226, 49.89872105419636, 51.04487635195255, 54.394860193133354, 55.46494357287884, 53.3562733232975, 50.74225299060345, 51.15933001041412, 53.34594927728176, 54.309657365083694, 53.10830622911453, 52.881674990057945, 55.22469766438007, 53.39560501277447, 53.28411899507046, 52.33820155262947, 51.82837910950184, 43.44206191599369, 30.21554544568062, 15.535021796822548, 3.8121967390179634, 0.20554657123284414, 0.5130748311057687, 1.4151984360069036, 1.7725362488999963, 2.1469959430396557, 2.4259646236896515, 2.73148437961936, 1.6955794533714652, 2.622841321863234, 2.0320589980110526, 0.7261409761849791, 0.3650770179228857, 1.2492565903812647, 15.172127019613981, 27.968518920242786, 24.14020534604788, 23.376309536397457, 26.15446776151657, 24.102173186838627, 10.26174170896411, 1.0460579814389348, 0.02066335244307993, 0.06405721505871043, 0.05785316476249136, 0.07950585015350953, 0.03894249981385656, 0.014575147688447032, 0.008209680272557307, 0.03800350117671769, 0.03074415584706003, 0.03385042793524917, 0.011986991157755256, 0.038545643765246496, 0.00508955878103734, 0.032480868612765335, 0.01641385937546147, 0.07752918434562162, 0.005136853997100843, 0.01788277742889477, 0.05062749994976912, 0.0293190875891014, 0.0434999396384228, 0.028896866788272746, 0.049803200236056, 0.02083881656290032, 0.02219865746155847, 0.013394288689596578, 0.03883858800691087, 0.05515067852684297, 0.02495722223102348, 0.012319131001277128, 0.08791111045866273, 0.030415161782002542, 0.018538199583417736, 0.04956707853125408, 0.030139899208734278, 0.02207264264143305, 0.08608623611507937, 0.022054973960621282, 0.03135762439342216, 0.05855076502484735, 0.012091377011529403, 0.004185066300124163, 0.001985259182220034, 0.02125325408997014, 0.013162461236788658, 0.06799683178542182, 0.06431721907574683, 0.018741516505542677, 0.05066609905043151, 0.08712434486369602, 0.05004496226320043, 0.03373588486283552, 0.08668300448334776, 0.07338772571529262, 0.03240862424718216, 0.05226274071901571, 0.031007417892396916, 0.16681275592418388, 0.04097343517059926, 0.019199030139134265, 0.07235642246087082, 0.03141337452689186, 0.037781654682476074, 0.055466696139774285, 0.04590841293975245, 0.049854527169372886, 0.016118683124659583, 0.052484045445453376, 0.07319519034354016, 0.07373162952717394, 0.056263079968630336, 0.07365889163338579, 7.89642040617764, 26.619572304189205, 38.74006122350693, 24.70506403595209, 20.33761639147997, 27.12544295936823, 47.93931819498539, 37.969302982091904, 13.817460760474205, 2.2925656568259, 0.17659933859249577, 0.19501546601532027, 0.6222954578697681, 2.9746910417452455, 10.153067540377378, 7.585125910118222, 5.6781369633972645, 4.833224276080728, 3.81880862172693, 0.997175385709852, 1.29757966613397, 9.587015714496374, 25.54970931261778, 42.06908918917179, 54.49238196015358, 58.970821648836136, 59.64413791894913, 57.684602066874504, 59.49109733104706, 58.33295367658138, 56.09929293394089, 57.72832632064819, 57.88616985082626, 55.64928688108921, 56.234504878520966, 56.17628440260887, 60.02833530306816, 60.295369774103165, 60.60102537274361, 59.63401906192303, 57.074871584773064, 53.95198255777359, 45.62982112169266, 46.12506754696369, 45.96361041069031, 55.856029987335205, 58.159770369529724, 59.33029755949974, 61.38542488217354, 51.785714998841286, 38.68446260690689, 52.51785211265087, 56.681493893265724, 55.436171516776085, 57.85223767161369, 58.933990225195885, 57.22768798470497, 58.14742863178253, 54.551434591412544, 54.440583139657974, 49.47720967233181, 43.99690814316273, 46.598772928118706, 51.50844767689705, 53.2643486559391, 55.24300128221512, 56.93172946572304, 55.02898536622524, 51.78082466125488, 51.97503224015236, 55.576915964484215, 55.692501962184906, 55.39698801934719, 52.59957812726498, 55.31605236232281, 53.86178679764271, 54.85126510262489, 53.573298677802086, 53.92847701907158, 44.33788664638996, 35.107155963778496, 19.74637571722269, 6.949828499928117, 1.3372793421149254, 1.2672942224889994, 3.539040796458721, 2.92051806114614, 3.8419565046206117, 4.486769316717982, 4.123523533344269, 4.437949061393738, 2.5863670790567994, 0.2859267307212576, 0.5209625547286123, 0.2744044130668044, 1.30520882550627, 13.0719730630517, 33.38575713336468, 29.182388484477997, 25.53989253938198, 27.93206747621298, 27.979371137917042, 16.0297267511487, 2.9701286740601063, 0.060746505405404605, 0.052971202312619425, 0.04884070891421288, 0.08360752966837026, 0.052639299028669484, 0.005723314397982904, 0.021166122241993435, 0.02198045862314757, 0.01679875756963156, 0.02970047171402257, 0.04342293439549394, 0.04098907964362297, 0.04608288443705533, 0.01911344937980175, 0.01298324092203984, 0.015786991352797486, 0.05552812370297033, 0.01322745574725559, 0.035264460457256064, 0.03532593254931271, 0.12429687441908754, 0.03842174221063033, 0.0432291336619528, 0.03759707513381727, 0.014700998308398994, 0.06790532497689128, 0.07145153664168902, 0.05736728438932914, 0.006685424905299442, 0.011333692473272095, 0.006550575744768139, 0.025144853862002492, 0.21004239795729518, 0.19180588511517271, 0.1420692406827584, 0.10456618081661873, 0.24293705471791327, 0.08724639847059734, 0.08217212700401433, 0.08803335702395998, 0.1126157445833087, 0.2177475532516837, 0.10686918380088173, 0.1229139044880867, 0.07568193424958736, 0.0949359018704854, 0.13278901053126901, 0.08531852145097218, 0.0878456307691522, 0.20694685546914116, 0.19130664237309247, 0.13998163864016533, 0.20798663405003026, 0.26880633377004415, 0.11567544133868068, 0.11573217110708356, 0.08433721668552607, 0.303970092209056, 0.148170214088168, 0.066410951258149, 0.21879528765566647, 0.18392478144960478, 0.18909382517449558, 0.20557725161779672, 0.1601961679989472, 0.15663555124774575, 0.1359737294842489, 0.1856769178994, 0.14618118409998715, 0.12740069185383618, 0.11981635820120573, 0.12232602704898454, 7.9208815935999155, 30.343100801110268, 49.20657679438591, 36.55664138495922, 28.087344244122505, 32.101236060261726, 48.64315822720528, 42.73019291460514, 18.758508525788784, 3.2207119278609753, 0.6018121226225048, 5.488174231722951, 6.901894072070718, 16.623416393995285, 32.453040182590485, 12.165492754429579, 4.360605636611581, 3.9439703430980444, 5.311438115313649, 0.9224948461633176, 1.6883739712648094, 8.329260405153036, 24.10618767142296, 40.634574964642525, 53.516066148877144, 58.98395374417305, 58.339892104268074, 58.74793320894241, 59.24795977771282, 57.8317491710186, 57.18661978840828, 56.760746240615845, 59.003328904509544, 56.18194229900837, 55.87307967245579, 55.50722010433674, 59.69861179590225, 63.59029836952686, 62.0464526116848, 61.8925266712904, 59.27508272230625, 56.139414981007576, 47.619192972779274, 48.70098352432251, 48.16997341811657, 57.086757346987724, 62.86874368786812, 60.65574623644352, 62.354357689619064, 56.16172358393669, 42.366685420274734, 53.07330630719662, 57.233703061938286, 56.28273569047451, 59.656415060162544, 61.705500707030296, 59.31385584175587, 58.720092102885246, 55.35128407180309, 57.297706827521324, 52.886477932333946, 47.77470722794533, 50.12809194624424, 53.90223942697048, 55.460060834884644, 59.48256678879261, 58.77981349825859, 58.70816074311733, 53.83589118719101, 55.961763113737106, 58.30378644168377, 57.43393711745739, 54.83083739876747, 52.339474484324455, 56.228896379470825, 56.41422003507614, 56.20859406888485, 55.02387844026089, 54.18899103999138, 45.33076196908951, 32.58653461933136, 17.72921595722437, 4.847631203010678, 0.9185656788758934, 1.8223309144377708, 3.264979077503085, 3.950197258964181, 6.4430368691682816, 6.186093706637621, 7.866432415321469, 7.562520448118448, 6.136716781184077, 6.332191592082381, 2.0682845916599035, 0.6187302991747856, 1.7596669332124293, 18.56735598295927, 35.960582569241524, 33.23564238846302, 32.330903336405754, 35.71821257472038, 34.249207600951195, 15.866413414478302, 1.971986477728933, 0.06910211232025176, 0.12294675936573185, 0.09869773712125607, 0.32110827101860195, 0.16349666198948398, 0.10066302580526099, 0.12285312259336933, 0.0968544278293848, 0.09053394198417664, 0.09165447365376167, 0.12676587357418612, 0.173536806832999, 0.2378367487108335, 0.07453158308635466, 0.13173023296985775, 0.1579200752894394, 0.11018514414899983, 0.07596816576551646, 0.1816568968934007, 0.16026267927372828, 0.2974416862707585, 0.16349488083506003, 0.14392885495908558, 0.10142925617401488, 0.0889906236261595, 0.1686584623530507, 0.18361006630584598, 0.1702313998248428, 0.07655888563022017, 0.07187759620137513, 0.20913676999043673, 0.08107895831926726], [0.029237393828225322, 0.08131610418786295, 0.042607358627719805, 0.055814848747104406, 0.022751384931325447, 0.02542847487347899, 0.03216761178919114, 0.01747864647768438, 0.0900540841394104, 0.04132665664656088, 0.022060803530621342, 0.037290401160134934, 0.03662254617665894, 0.08732807924388908, 0.022074086118664127, 0.06290446675848216, 0.05522919775103219, 0.04002898174803704, 0.034762534851324745, 0.022958919107622933, 0.007421870568578015, 0.034957497045979835, 0.06558692984981462, 0.1026855266536586, 0.006629593599427608, 0.06364965724060312, 0.014219281383702764, 0.033144018379971385, 0.026175997554673813, 0.016182274048333056, 0.017368760381941684, 0.022522716244566254, 0.051964675658382475, 0.050232799840159714, 0.032171931088669226, 0.06544360629050061, 0.08159114411682822, 0.023510835781053174, 0.04895896272500977, 0.024644954319228418, 0.032662898884154856, 3.584317029453814, 20.993814580142498, 32.11558409035206, 26.01455546915531, 13.389086946845055, 15.522562265396118, 26.31621178239584, 30.01534938812256, 15.496690403670073, 3.622610424645245, 0.2865184599068016, 0.09864374587778002, 1.8750808713957667, 9.89894287660718, 7.396511156111956, 5.5898206774145365, 4.371961327269673, 4.585590614005923, 1.2690510344691575, 0.17740685463650152, 0.38382901169825345, 4.613483967259526, 15.474370401352644, 32.356886342167854, 46.16337329149246, 52.72397205233574, 54.60596166551113, 60.14778949320316, 58.21101441979408, 59.225856363773346, 56.469233483076096, 56.23643897473812, 58.125933185219765, 58.06827127933502, 58.94624076783657, 57.74610936641693, 58.02116900682449, 61.57314620912075, 59.67960141599178, 57.39277012646198, 55.900886580348015, 47.73732863366604, 47.95876935124397, 45.49451798200607, 50.1708472520113, 53.15925769507885, 58.279995918273926, 57.786071822047234, 62.31572516262531, 38.19048911333084, 51.56994357705116, 59.14852291345596, 54.3928425014019, 58.430524840950966, 56.018323078751564, 57.666990011930466, 57.41032138466835, 56.13074004650116, 54.445078298449516, 51.143021285533905, 46.65447413921356, 44.29996468126774, 50.54321587085724, 53.07327210903168, 56.350508853793144, 56.197244077920914, 54.629881381988525, 52.255734577775, 53.77321355044842, 54.514466375112534, 55.670326352119446, 55.186213329434395, 54.448232129216194, 55.578477680683136, 52.68633507192135, 50.87189823389053, 44.70409579575062, 37.4815421551466, 24.448498003184795, 12.05823116004467, 2.6176301389932632, 0.12063237925758585, 0.28574039228260517, 0.6459500198252499, 3.7625020556151867, 3.081620391458273, 3.775800629518926, 5.252503277733922, 3.1584439566358924, 2.5738735869526863, 2.0558732701465487, 0.3975326498039067, 0.1694646870600991, 1.5134622319601476, 15.389479156583548, 31.68306089937687, 29.282767698168755, 22.041076384484768, 25.9286230802536, 22.930922135710716, 8.453125208616257, 0.9819979313760996, 0.06860654320917092, 0.025957661418942735, 0.027257356814516243, 0.04845664749154821, 0.020588647857948672, 0.061046778355375864, 0.06817803456215188, 0.06286291391006671, 0.014447580851992825, 0.06987489585299045, 0.0022165555355968536, 0.012911951143905753, 0.04233173240208998, 0.028067973180441186, 0.02355616987188114, 0.020235324336681515, 0.02548611933889333, 0.052583470969693735, 0.04141539895499591, 0.017768022844393272, 0.05842949067300651, 0.04315351994591765, 0.07248218680615537, 0.09788259179913439, 0.025497275673842523, 0.06164786231238395, 0.020225656007824, 0.0673838474904187, 0.049093543784692883, 0.03793717914959416, 0.044789128078264184, 0.03248748485930264, 0.0263692787848413, 0.037944485593470745, 0.04953643525368534, 0.03925565273675602, 0.1375881233252585, 0.07844799285521731, 0.0054854073641763534, 0.04282949084881693, 0.03267094005423132, 0.021526195596379694, 0.03600511270633433, 0.06339116720482707, 0.0360087269655196, 0.0105532091583882, 0.025083791806537192, 0.028114357410231605, 0.051289098628330976, 0.08141515863826498, 0.056745186520856805, 0.11916372837731615, 0.007918641495052725, 0.04439136289875023, 0.08117235018289648, 0.05013414614950307, 0.04764098266605288, 0.045865702340961434, 0.05281430858303793, 0.07306787490961142, 0.027262926632829476, 0.042318455380154774, 0.038653284864267334, 0.05919821094721556, 0.034860780360759236, 0.029670379481103737, 0.09092063060961664, 0.0666040506621357, 0.02104569022776559, 0.013218254043749766, 0.02156645896320697, 0.05780852457974106, 0.0897470279596746, 0.06303301415755413, 6.503092171624303, 28.397078923881054, 36.79521918296814, 29.274056665599346, 18.34916789084673, 25.700285732746124, 39.70442667603493, 35.263943150639534, 15.546152349561453, 3.0648754024878144, 0.47984371427446604, 0.20049863116582856, 0.6527762941550463, 4.284917498007417, 5.05341581068933, 7.793035553768277, 5.590678006410599, 6.148547446355224, 2.7054151659831405, 0.5658354749903083, 0.6964823801536113, 7.162525411695242, 19.228119626641273, 35.200744941830635, 48.11576172709465, 53.68503928184509, 57.7630602568388, 60.31877651810646, 58.65212135016918, 58.74137096107006, 55.974427834153175, 56.355216801166534, 56.60302050411701, 58.008006513118744, 58.32952246069908, 58.69283616542816, 59.011414870619774, 60.14175541698933, 60.920466631650925, 60.29345467686653, 56.69678807258606, 48.64924170076847, 49.06319908797741, 46.94054178893566, 52.6495036482811, 56.0782078653574, 61.095477640628815, 59.18750122189522, 63.004802986979485, 41.450812965631485, 51.35134130716324, 59.572447165846825, 56.10437326133251, 58.22058230638504, 57.70074740052223, 57.70510956645012, 60.02344876527786, 59.315029978752136, 56.02456234395504, 52.27224849164486, 48.61073076725006, 46.694102212786674, 52.25913539528847, 54.77371886372566, 57.171147018671036, 57.578010186553, 56.594790145754814, 53.81729498505592, 55.50940498709679, 55.3982837498188, 55.17414137721062, 54.499924555420876, 53.30900385975838, 55.65276749432087, 54.28735636174679, 50.75939007103443, 45.618680119514465, 41.287087351083755, 28.136361613869667, 15.206178892403841, 3.9458244061097503, 1.1161208781413734, 0.918081501731649, 2.111499197781086, 4.492660900577903, 5.550774447619915, 4.653836851939559, 4.294422687962651, 2.0909584499895573, 2.520585721358657, 1.4891845034435391, 0.25698018085677177, 0.13199770299252123, 0.9240754425991327, 11.746160555630922, 36.00557215511799, 32.61290520429611, 24.04718443751335, 27.95171432197094, 28.640058785676956, 15.623192265629768, 2.231336929835379, 0.038655993703287095, 0.02841147066646954, 0.040874555124901235, 0.03393430546566378, 0.07094465720001608, 0.03588391999073792, 0.06431746398448013, 0.026621638680808246, 0.045583367100334726, 0.039427025767508894, 0.006271133952395758, 0.005786070869362447, 0.10935753074591048, 0.053902976142126136, 0.07498561419197358, 0.02127103965904098, 0.0325892778346315, 0.026499739069549832, 0.05564918654272333, 0.06267180346185341, 0.07367316313320771, 0.08727060732780956, 0.03018848019564757, 0.07204001522040926, 0.026562281709630042, 0.04037700819026213, 0.027712156042980496, 0.09940011310391128, 0.017032404211931862, 0.01723753197438782, 0.029919724402134307, 0.03786757311900146, 0.06979028359637596, 0.19152703054714948, 0.16244784404989332, 0.09486988783464767, 0.21134693030035123, 0.1133806242432911, 0.09521330925053917, 0.14462889317655936, 0.11290156049653888, 0.19756422378122807, 0.14676976657938212, 0.16719617909984663, 0.20987657248042524, 0.17013741424307227, 0.16162371874088421, 0.09259881946491078, 0.15471800492377952, 0.24491168704116717, 0.1887506412458606, 0.14158497448079288, 0.14208458829671144, 0.14609827136155218, 0.1734766928711906, 0.15605867985868827, 0.2268166423891671, 0.14867716032313183, 0.17320594255579636, 0.11420707989600487, 0.1630458518047817, 0.0665499184106011, 0.1542820970644243, 0.12147905843448825, 0.1290274498751387, 0.10761678626295179, 0.1703925646143034, 0.15705513185821474, 0.1709657846367918, 0.12187430402263999, 0.14123586821369827, 0.16091088589746505, 0.16581142059294507, 0.152040024404414, 6.440181797370315, 29.49629344046116, 47.41240046918392, 37.85047195851803, 23.65719236433506, 23.912445567548275, 34.75585341453552, 39.654216170310974, 20.524155981838703, 4.731372641399503, 0.5582112434785813, 0.9618774766568094, 5.851600030437112, 14.372835159301758, 17.405404932796955, 14.163504391908646, 11.408214289695024, 10.347070880234241, 2.894562128931284, 0.6858301267493516, 1.1284420732408762, 5.51364379003644, 18.221846222877502, 35.747421607375145, 48.0177915841341, 54.668460711836815, 56.24509871006012, 60.69950848817825, 57.65922702848911, 58.52483958005905, 56.384209245443344, 56.91988930106163, 56.43250845372677, 59.08977806568146, 60.56798234581947, 59.398963674902916, 58.7260577827692, 63.58438588678837, 64.15742933750153, 64.3638114631176, 59.98895041644573, 51.17222651839256, 52.612850815057755, 49.06146638095379, 56.28002643585205, 57.51690946519375, 63.21392856538296, 62.195032238960266, 62.849858701229095, 45.86529068648815, 52.69347108900547, 59.230108335614204, 56.067484840750694, 58.369177132844925, 59.02350202202797, 59.72731165587902, 61.06505647301674, 60.774235278367996, 59.14309300482273, 54.92145113646984, 51.01963050663471, 47.95316845178604, 54.70671705901623, 58.599361181259155, 60.45501820743084, 60.11691614985466, 59.39905487000942, 56.34205050766468, 58.23422737419605, 58.36271747946739, 56.87485791742802, 54.837760627269745, 55.33474735915661, 55.992590859532356, 53.457078114151955, 52.372616305947304, 46.258166804909706, 40.17480343580246, 27.40090347826481, 14.303894508630037, 3.453075159341097, 0.7922454946674407, 0.9590382571332157, 2.5050248438492417, 7.366283778101206, 7.871629111468792, 8.94021537154913, 12.141630984842777, 9.68094477429986, 9.71043974161148, 6.657854542136192, 1.2177058146335185, 0.49565205350518227, 2.2250974271446466, 19.003753066062927, 40.44180370867252, 38.05583953857422, 30.040162056684494, 35.90984769165516, 34.17987272143364, 16.366358287632465, 1.8079420365393162, 0.13825544767314568, 0.12369366420898587, 0.14470349386101589, 0.11183835231349804, 0.11502934241434559, 0.16355972969904542, 0.19440390664385632, 0.19521452486515045, 0.18096269195666537, 0.20554792194161564, 0.11470871235360391, 0.09040707926033065, 0.1683121020323597, 0.15534822188783437, 0.12516834132838994, 0.1508677427773364, 0.14003039774252102, 0.11762606518459506, 0.1726463483646512, 0.13614614523248747, 0.2858995978021994, 0.15410153253469616, 0.26048415689729154, 0.2155390108237043, 0.09191953911795281, 0.14630746794864535, 0.09891920140944421, 0.17678060074103996, 0.11235411526286043, 0.11778766784118488, 0.130732074030675, 0.18795762676745653, 0.13807368086418137], [0.04713193986390252, 0.03855277209368069, 0.042868858072324656, 0.03961727532441728, 0.05572012101765722, 0.0478745365398936, 0.03320052921480965, 0.03136833358439617, 0.09103153715841472, 0.039998060165089555, 0.09207916024024598, 0.014630315235990565, 0.02938764348073164, 0.029759448334516492, 0.045383733086055145, 0.056668849210836925, 0.045746791729470715, 0.05844869003340136, 0.034285478614037856, 0.017487491022620816, 0.0417558554909192, 0.03336034329549875, 0.04083452367922291, 0.04662219202145934, 0.019153952089254744, 0.03223650906875264, 0.036895890298183076, 0.029177482101658825, 0.06796293790102936, 0.05932345207838807, 0.01770889779436402, 0.021117737924214453, 0.06846893418696709, 0.044008514887536876, 0.05929207407461945, 0.03291007116786204, 0.04795349363121204, 0.037841308512724936, 0.03090779013291467, 0.0514970224321587, 0.04614555880834814, 0.14216328563634306, 2.2283346159383655, 14.547966811805964, 30.25295063853264, 28.48873570561409, 18.427291698753834, 14.143766351044178, 24.568514563143253, 27.45823100209236, 17.734184190630913, 6.746795894578099, 0.610528914257884, 0.5414502834901214, 1.2951285601593554, 3.2113565923646092, 8.350189682096243, 6.739150229841471, 3.764135967940092, 2.40421649068594, 1.219828831963241, 0.13977965572848916, 0.14801293815253302, 2.99041744787246, 10.155394915491343, 25.877988897264004, 33.59081692993641, 43.01267735660076, 50.12480512261391, 55.50789646804333, 57.45091840624809, 57.349099069833755, 52.23494969308376, 58.14050920307636, 56.513953283429146, 56.07304774224758, 59.85780045390129, 58.57226483523846, 59.03710149228573, 61.36716306209564, 59.88887518644333, 59.35097225010395, 52.27265886962414, 52.65654467046261, 50.137640833854675, 49.641592651605606, 54.3487648665905, 57.605190128088, 58.13248783349991, 62.244870364665985, 36.87635622918606, 46.820244044065475, 61.795145496726036, 54.83868397772312, 58.43951515853405, 55.178400948643684, 58.49494278430939, 57.92088098824024, 57.15144507586956, 54.370370507240295, 54.51803058385849, 51.66506767272949, 50.66974148154259, 54.70134794712067, 56.329568177461624, 56.39074869453907, 56.8562351167202, 56.51634715497494, 56.840127781033516, 55.319369584321976, 56.782511472702026, 57.110563069581985, 53.96092727780342, 52.06976115703583, 49.062553122639656, 41.863998994231224, 37.52243556082249, 28.142224699258804, 15.920588057488203, 7.827712018042803, 1.8737711291760206, 0.20114802522584796, 1.1528143216855824, 0.9647312422748655, 1.3204908929765224, 2.6724839955568314, 3.809090880677104, 3.583257836289704, 3.2393335411325097, 1.414601393043995, 1.3087051128968596, 0.9267866564914584, 0.3322246338939294, 2.835596655495465, 14.717167932540178, 29.862029515206814, 29.05420806258917, 20.817103162407875, 25.19648216664791, 28.332412093877792, 10.319055933505297, 1.012152994517237, 0.0828423531493172, 0.01726930702716345, 0.014469947327597765, 0.010944894293061225, 0.062143138275132515, 0.046352985373232514, 0.019779692047450226, 0.0849138357443735, 0.05558810407819692, 0.018831885972758755, 0.01980598819500301, 0.035809456603601575, 0.02832077650964493, 0.04174647845502477, 0.052410016214707866, 0.05156289174919948, 0.03271767309342977, 0.02972997765027685, 0.02332108902919572, 0.013847329028067179, 0.02990832315845182, 0.08606093630078249, 0.04832848229852971, 0.02399856224656105, 0.07831239505321719, 0.04775001900270581, 0.039906783422338776, 0.00165369728620135, 0.03305784390249755, 0.015676765724492725, 0.12711003713775426, 0.07002875048783608, 0.04899092331470456, 0.08013781858608127, 0.0463708043389488, 0.0323143121204339, 0.06771150568965822, 0.020463636792555917, 0.03439867839915678, 0.05875369788554963, 0.04736498165584635, 0.045474542275769636, 0.05014637303247582, 0.05431812984170392, 0.03616456684540026, 0.02973019472847227, 0.06392926879925653, 0.021942644343653228, 0.054247269581537694, 0.022386875389202032, 0.07702818271354772, 0.09912929599522613, 0.00992992756437161, 0.017296716396231204, 0.0038110718787720543, 0.04225384400342591, 0.029518278170144185, 0.013348997272260021, 0.027791525026259478, 0.03541313861205708, 0.0515454698324902, 0.020511740949586965, 0.08750085122301243, 0.007839734498702455, 0.02689057630050229, 0.027719453210011125, 0.035337331937626004, 0.02581112064945046, 0.030677223403472453, 0.03742145330761559, 0.006628613036809838, 0.04452025539649185, 0.0371311028720811, 0.05902701974264346, 0.06478971481556073, 0.15247562056174502, 5.756930485367775, 23.61124712973833, 34.368232414126396, 27.682405672967434, 14.954415801912546, 16.885560527443886, 34.83471058309078, 35.77131852507591, 22.25898139178753, 5.555641036480665, 0.4840122687164694, 0.3828767471713945, 0.3385246067773551, 1.0792924230918288, 3.4337866818532348, 3.936410411261022, 6.166201299056411, 4.924912406131625, 1.7193041928112507, 0.6204236426856369, 0.6061888940166682, 5.1866471115499735, 15.34116854891181, 28.80758799612522, 36.09474956989288, 43.89755867421627, 53.30479748547077, 56.38831302523613, 57.013972252607346, 56.90745256841183, 52.23261281847954, 59.34204652905464, 57.67449080944061, 57.760476395487785, 59.800051152706146, 58.01686763763428, 60.61297573149204, 63.36156204342842, 61.99523136019707, 60.16250990331173, 54.54426437616348, 52.355749011039734, 51.366738080978394, 51.55007064342499, 54.93698090314865, 60.437915325164795, 60.858510956168175, 61.844649240374565, 40.97211465239525, 47.396213337779045, 61.13778077065945, 55.144468769431114, 58.48624125123024, 56.15626707673073, 57.50547207891941, 58.72553341090679, 58.22271019220352, 56.870860531926155, 57.569369450211525, 53.40779095888138, 52.17357158660889, 56.58026732504368, 56.95627614855766, 57.928514778614044, 56.938056126236916, 58.2783468067646, 58.01168851554394, 55.898374915122986, 56.78531192243099, 57.066238448023796, 55.54823890328407, 53.6949909478426, 49.44186396896839, 44.01399202644825, 39.76761728525162, 30.400948897004128, 20.40878277271986, 9.574294947087765, 3.0843752436339855, 0.8296364382840693, 1.0084017645567656, 2.5551581662148237, 3.27312964014709, 6.37185481376946, 6.6024302411824465, 5.360232247039676, 4.314396791160107, 0.4741440201178193, 0.8286674902774394, 0.3031244594603777, 0.22246678126975894, 2.9064041934907436, 16.264673843979836, 37.07651808857918, 35.573972314596176, 24.68465343117714, 26.49953104555607, 32.370634004473686, 14.934725258499384, 1.8982681771740317, 0.14456805191002786, 0.06981047001318075, 0.05687903656507842, 0.01820132205466507, 0.0348323486832669, 0.014104162219155114, 0.03004135869559832, 0.05388997742556967, 0.028505482223408762, 0.0710503538721241, 0.01609226266737096, 0.09630092667066492, 0.01372941011140938, 0.02630757291626651, 0.08458072275971062, 0.030217739367799368, 0.04186316262348555, 0.01406777379088453, 0.013613931932923151, 0.028764135531673674, 0.0662213473697193, 0.027853145547851454, 0.0565760547760874, 0.02110989527864149, 0.03169785086356569, 0.008065268539212411, 0.0718094150943216, 0.05917167916777544, 0.04340694853453897, 0.015491768717765808, 0.05532626324566081, 0.04892499833658803, 0.02930723177996697, 0.03853141679428518, 0.12991112511372194, 0.18740386585704982, 0.2194595691980794, 0.09678043570602313, 0.11289317422779277, 0.1605447250767611, 0.10851926010218449, 0.14551385975209996, 0.16316515946527943, 0.1083067461149767, 0.20199523132760078, 0.08845586169627495, 0.13146347540896386, 0.07073318964103237, 0.28053669026121497, 0.09531778137898073, 0.1608877012040466, 0.14056501124287024, 0.1350841615931131, 0.13807645649649203, 0.12260647723451257, 0.20905332290567458, 0.1201621990185231, 0.1621465914649889, 0.11058954041800462, 0.1158643327653408, 0.21926215791609138, 0.10989478629198857, 0.1834233122644946, 0.14515313145238906, 0.10833006439497694, 0.16623725008685142, 0.1992760764551349, 0.1438372442498803, 0.16825244820211083, 0.1426673968671821, 0.16013943823054433, 0.14651856443379074, 0.08000368281500414, 0.1332415870274417, 0.12470200541429222, 0.2808754955185577, 4.759797966107726, 23.9453537017107, 42.05910712480545, 38.169989213347435, 27.110688351094723, 20.947419069707394, 33.34579847753048, 37.41462014615536, 24.08554717898369, 8.543616402894258, 0.7417570101097226, 1.039075618609786, 4.500690819695592, 10.563926193863153, 14.609364867210388, 15.31720893457532, 8.909228034317493, 6.111089056357741, 3.7806154461577535, 0.3522226639324799, 0.7037940784357488, 3.7397852120921016, 12.993011400103569, 27.39586114883423, 35.417644903063774, 44.449608251452446, 50.87354354560375, 54.639760851860046, 57.06687681376934, 57.87188641726971, 52.848137989640236, 60.29270991683006, 57.23029464483261, 58.10911908745766, 60.4491551220417, 60.35648949444294, 57.817450538277626, 64.4602882862091, 64.82490912079811, 63.06644327938557, 56.12874895334244, 54.42434661090374, 54.92236688733101, 53.107021898031235, 58.36342044174671, 62.167521715164185, 63.36918443441391, 63.61953020095825, 44.370500296354294, 49.79683332145214, 62.03644394874573, 55.246626287698746, 58.59759047627449, 56.09073959290981, 57.816447392106056, 60.33162362873554, 59.920668080449104, 58.76380115747452, 59.16331171989441, 54.883320182561874, 55.458639711141586, 59.05959628522396, 60.35558894276619, 60.606288090348244, 59.583930149674416, 60.53633764386177, 60.0176502764225, 56.65184028446674, 58.24191816151142, 58.36809419095516, 54.83672708272934, 51.750091910362244, 49.699653536081314, 44.912161231040955, 40.4938343167305, 29.5384331792593, 17.82311461865902, 8.977590166032314, 2.6719080889597535, 1.0663624294102192, 2.7761383960023522, 3.106553703546524, 4.063596474006772, 9.427775759249926, 9.31588126346469, 11.16414388641715, 8.442404083907604, 5.619146078824997, 6.22402279637754, 2.0853592129424214, 0.5251708882860839, 3.5613714857026935, 18.560178168118, 36.366396993398666, 40.56555546820164, 29.64250009506941, 34.233248457312584, 38.53565499186516, 17.074442692101, 1.7168035707436502, 0.1679977134335786, 0.11559140795725398, 0.0729371455963701, 0.10977259167702869, 0.1837826007977128, 0.06773258268367499, 0.1400967754307203, 0.1639315308420919, 0.15065026382217184, 0.12316855762037449, 0.0972151116002351, 0.23690179106779397, 0.11896022406290285, 0.1303576902137138, 0.13442755385767668, 0.12227098195580766, 0.1393718455801718, 0.10367337716161273, 0.12845247838413343, 0.14519598305923864, 0.13259921368444338, 0.18411054101306945, 0.2373356802854687, 0.14823202014667913, 0.15777381282532588, 0.10565370175754651, 0.10397742764325812, 0.12182533711893484, 0.17370484390994534, 0.05859518256329466, 0.16505877894815058, 0.13111525971908122, 0.1743854972301051, 0.1084481252473779], [0.027990570888505317, 0.06289589495281689, 0.0324878262472339, 0.08650644012959674, 0.04144605707551818, 0.06614302852540277, 0.016323937052220572, 0.039218775418703444, 0.0049692125776346074, 0.008540932321920991, 0.020429217838682234, 0.01526684602140449, 0.03319185721920803, 0.09372924396302551, 0.01963312715815846, 0.047787375006009825, 0.07156178267905489, 0.08011243713553995, 0.05058814385847654, 0.029949516065244097, 0.09634231624659151, 0.028621966011996847, 0.05464573980134446, 0.02766774963674834, 0.0334720105456654, 0.05414780323917512, 0.06723520273226313, 0.05270430745440535, 0.016824916419864167, 0.025570254765625577, 0.01957115968252765, 0.03027987011591904, 0.024538708457839675, 0.04303922178223729, 0.05643957381835207, 0.09017831966048107, 0.04974915704224259, 0.05952952051302418, 0.04303165929741226, 0.03793753538047895, 0.06742611280060373, 0.046056523351580836, 0.06614037905819714, 1.5871072676964104, 10.754166785627604, 32.45636120438576, 33.440671786665916, 26.012725867331028, 19.090036936104298, 23.435175977647305, 23.498664870858192, 24.534050412476063, 8.46936458721757, 0.99766033468768, 0.3660467377630994, 0.9232617518864572, 1.761727372650057, 1.2524924729950726, 5.803518835455179, 4.46205829270184, 0.9997959388419986, 1.43180544488132, 0.2823314111446962, 0.10526113532250747, 0.7907475437968969, 5.256847394630313, 14.932674318552017, 22.90092844516039, 28.253258541226387, 36.79940275847912, 50.776827335357666, 55.369363501667976, 58.78175139427185, 48.31588178873062, 62.066952511668205, 48.65918956696987, 53.40332619845867, 59.50748585164547, 59.02772359549999, 65.0009536743164, 59.326930940151215, 60.217918530106544, 57.18618281185627, 57.71635316312313, 54.0513776242733, 57.268619388341904, 55.44226258993149, 62.16091386973858, 57.65375532209873, 65.97529739141464, 33.77505004405975, 43.182596638798714, 60.03963589668274, 57.51280948519707, 57.64397844672203, 58.582664877176285, 56.441783756017685, 58.260677754879, 57.37673878669739, 55.50997495651245, 56.33885107934475, 55.71546033024788, 55.74630707502365, 56.19926556944847, 57.767961993813515, 58.65772984921932, 56.28933593630791, 57.99569897353649, 57.410925552248955, 58.426261469721794, 57.6522696018219, 51.28205202519894, 44.303468093276024, 36.88535034656525, 29.253421872854233, 21.58192042261362, 13.765004575252533, 8.289606682956219, 3.3749860245734453, 0.37498923134990036, 0.37050143466331065, 0.4006065661087632, 0.07076495356159285, 3.042747052386403, 2.713747168891132, 4.82136701233685, 6.014746651053429, 4.233643524348736, 2.126185647211969, 0.34903065708931535, 0.5226999521255493, 0.6556793383788317, 2.2144121630117297, 17.930616550147533, 34.18801948428154, 27.019586339592934, 22.122350223362446, 22.10040260106325, 21.17656197398901, 10.723263993859291, 0.9155145019758493, 0.03463247347099241, 0.03452609773376025, 0.0489230353559833, 0.029881813643442, 0.02499840771633899, 0.05985520459944382, 0.03691360165248625, 0.06493889392004348, 0.0772522296756506, 0.013997010937600862, 0.05486715213919524, 0.026376488749519922, 0.04161246142757591, 0.014077629512030398, 0.05131042424181942, 0.050850782499765046, 0.05727740659494884, 0.029383392829913646, 0.040709074746700935, 0.04590071315760724, 0.08502307246089913, 0.03209243222954683, 0.04210556660837028, 0.037296750233508646, 0.03268984997703228, 0.024395262444159016, 0.04788623278727755, 0.06023407098837197, 0.039700458946754225, 0.03757525970286224, 0.08636251543066464, 0.03638073590991553, 0.03063513806409901, 0.017192578234244138, 0.08410290582105517, 0.04138514901569579, 0.014060090707062045, 0.043276293436065316, 0.012570809049066156, 0.02683800812519621, 0.017186676304845605, 0.04680339108745102, 0.023561860289191827, 0.010387772381363902, 0.048200710443779826, 0.06155820345156826, 0.02874905323551502, 0.02565121751104016, 0.03020594478584826, 0.012261310275789583, 0.04931037707137875, 0.07662678472115658, 0.03998280531959608, 0.04643909676815383, 0.005634816534438869, 0.0725180102745071, 0.03993466591055039, 0.05165669179405086, 0.03224705498723779, 0.038545447096112184, 0.022287509236775804, 0.04437381481693592, 0.023942569059727248, 0.040985973755596206, 0.006195560590640525, 0.040932323900051415, 0.07626974489539862, 0.044003705770592205, 0.04245207535859663, 0.07628139661392197, 0.07559879886684939, 0.10522537864744663, 0.05059200673713349, 0.030104524739726912, 0.10327396812499501, 0.023557817439723294, 0.049981137563008815, 0.12243305216543376, 3.1106446590274572, 18.094868436455727, 39.546237364411354, 33.82921613752842, 20.58615155518055, 20.350091122090816, 28.238291144371033, 30.890410132706165, 29.196812510490417, 7.439405154436827, 0.9839373116847128, 0.45031662681140006, 0.6862479855772108, 1.3637716392986476, 1.8228867533616722, 5.230930410325527, 5.317511139437556, 3.170315707102418, 3.4341999096795917, 0.3114493377506733, 0.14574358414392918, 2.2216258384287357, 7.630019076168537, 17.59378742426634, 26.099986284971237, 30.876088701188564, 41.15730531513691, 52.34849140048027, 56.98619954288006, 58.73370677232742, 52.115358710289, 62.037823274731636, 51.6219399869442, 55.793747529387474, 61.38025335967541, 57.15674199163914, 66.91645368933678, 60.19508175551891, 63.379462882876396, 58.81687670946121, 58.98487329483032, 56.001619175076485, 58.339542523026466, 57.81958222389221, 63.034627586603165, 57.04983092844486, 66.25654309988022, 36.96973241865635, 44.60473492741585, 59.98146481812, 56.94384701550007, 59.070627093315125, 58.696278780698776, 57.72028215229511, 58.364640176296234, 57.73131676018238, 56.59489654004574, 59.93847772479057, 57.47119031846523, 56.487582698464394, 57.511623948812485, 58.49484398961067, 60.14718532562256, 58.367300033569336, 59.50172916054726, 57.21065349876881, 58.13950605690479, 56.662251725792885, 52.10530824959278, 45.96649445593357, 39.99837510287762, 32.91068382561207, 24.259473346173763, 17.60544329881668, 12.503979541361332, 4.785841293632984, 1.5800094860605896, 1.0702039045281708, 1.7223683721385896, 4.047292498871684, 2.3294747387990355, 5.643540769815445, 4.611155167222023, 3.413360402919352, 5.332640027627349, 1.864483596291393, 0.1364673170610331, 0.33112907549366355, 0.527308986056596, 2.7323189098387957, 14.998254049569368, 32.42688238620758, 27.48236920684576, 26.02300051599741, 23.938348777592182, 28.483670577406883, 18.19706965237856, 2.3338936641812325, 0.057431710229138844, 0.03332506530568935, 0.01183061693154741, 0.02232415648904862, 0.03053355289011961, 0.011088114879385103, 0.025978283847507555, 0.014305652530310908, 0.02814266106724972, 0.040630844960105605, 0.052268310537328944, 0.01187414853120572, 0.09941851836629212, 0.04214645152387675, 0.08356751306564547, 0.03708403215568978, 0.024543380277464166, 0.06001638794259634, 0.026736001782410312, 0.03404606177355163, 0.07294887152966112, 0.025455210743530188, 0.017469579288444947, 0.04884336951363366, 0.011547672202141257, 0.01821866233512992, 0.042520130300545134, 0.027526544909051154, 0.032415203386335634, 0.04392533126519993, 0.014596022447221912, 0.015553020948573248, 0.014781058416701853, 0.04560940164083149, 0.06778563882107846, 0.12366084643872455, 0.1498017812264152, 0.14214188209734857, 0.17366595537168905, 0.12481208075769246, 0.133535789209418, 0.18902151030488312, 0.1337366588995792, 0.1168452441925183, 0.0626105020637624, 0.13566887006163597, 0.05942340081674047, 0.16829488420626149, 0.29312013066373765, 0.07973556712386198, 0.2533650310942903, 0.12591007340233773, 0.21145158796571195, 0.08215647510951385, 0.1515132182976231, 0.21198342583375052, 0.10138991492567584, 0.1964670474990271, 0.12764908868120983, 0.14243834040826187, 0.11185605995706283, 0.1169539094553329, 0.1443283530534245, 0.09332920410088263, 0.14308069890830666, 0.11929924454307184, 0.12182663587736897, 0.14622608403442428, 0.2521237445762381, 0.14291196421254426, 0.17114265327109024, 0.19807253556791693, 0.12508637853898108, 0.1464906448381953, 0.17756405635736883, 0.12953162047779188, 0.09564864565618336, 0.14983971981564537, 2.498146975412965, 18.03112305700779, 46.20795249938965, 45.83224005997181, 34.35299523174763, 28.06764990091324, 32.65034839510918, 31.16773445159197, 32.559708058834076, 10.886004511266947, 1.3393477373756468, 0.6584758101962507, 2.12256895378232, 5.026341313496232, 6.265044445171952, 11.631750594824553, 8.893226142972708, 3.449271800927818, 2.45753712952137, 1.423474510665983, 0.3244048316264525, 1.6995427594520152, 6.053575342521071, 16.022820621728897, 25.284491144120693, 29.31026492267847, 38.72188299894333, 52.312229946255684, 58.106793612241745, 60.33272936940193, 53.100976422429085, 63.93337056040764, 55.245288759469986, 57.39607594907284, 59.828253239393234, 56.483836099505424, 65.55629387497902, 62.28840842843056, 64.72759634256363, 63.88593390583992, 62.49734401702881, 58.25626999139786, 61.38943746685982, 60.489923134446144, 66.33808672428131, 61.215539798140526, 66.40162691473961, 41.252383813261986, 47.39388786256313, 58.83414678275585, 58.884220495820045, 59.064650014042854, 59.25947695970535, 57.13842697441578, 60.038267970085144, 59.27283704280853, 58.69790509343147, 60.99671334028244, 59.759549126029015, 59.20182265341282, 58.4924691170454, 61.38267382979393, 62.816758677363396, 59.780713990330696, 62.625590935349464, 59.135276824235916, 60.79821199178696, 58.85612100362778, 52.10656978189945, 45.0735005736351, 39.97213751077652, 30.66043507307768, 22.954307980835438, 15.341316740959883, 10.504177249968052, 4.8528853710740805, 1.2034746282733977, 0.7813552196603268, 1.5908894897438586, 3.1936623668298125, 6.625262266024947, 6.526491791009903, 8.21965528652072, 11.970352325588465, 10.43452413752675, 8.25461246073246, 3.978911843150854, 1.6444281418807805, 1.1482331925071776, 3.4352306043729186, 22.02358592301607, 41.65077343583107, 33.79254810512066, 32.00998775660992, 31.35535318404436, 32.47590355575085, 18.26863121241331, 1.937764089088887, 0.07854652038076892, 0.1887608235119842, 0.13423014257568866, 0.12368411276838742, 0.18513656017603353, 0.14573843363905326, 0.15630719542969018, 0.1683368452358991, 0.14993679273175076, 0.1179343755939044, 0.15964498976245522, 0.13419165479717776, 0.21647993533406407, 0.17302822787314653, 0.11592353388550691, 0.14165185682941228, 0.1901561947306618, 0.1333786765462719, 0.07362254124018364, 0.11217741732252762, 0.1941221725428477, 0.09948865132173523, 0.10761259312857874, 0.08530292150680907, 0.1155646461120341, 0.13544071902288124, 0.1320122490869835, 0.11261167761404067, 0.13747889403020963, 0.12634872720809653, 0.18069683981593698, 0.11252313197473995, 0.15618410281604156, 0.21204518736340106, 0.2618756837910041], [0.04709142231149599, 0.02784717125905445, 0.033916864995262586, 0.05534988209547009, 0.04152003435592633, 0.07880278397351503, 0.05772732991317753, 0.035852285946020856, 0.06378981925081462, 0.0699671077018138, 0.07108088582754135, 0.04405964144098107, 0.01172993439467973, 0.061680861908826046, 0.011651524637272814, 0.06895451399032027, 0.06211516301846132, 0.03875540067383554, 0.01162300854048226, 0.0675487972330302, 0.03891092514095362, 0.08212928281864151, 0.07269890134921297, 0.07027544037555344, 0.026280265592504293, 0.07200568346888758, 0.039347578858723864, 0.05914843510254286, 0.0842283658857923, 0.008223590903071454, 0.03339480121212546, 0.0660982695990242, 0.023210850413306616, 0.1237097242847085, 0.025629454030422494, 0.04592755292833317, 0.033113620011135936, 0.06432467765989713, 0.04585140857670922, 0.03171093121636659, 0.03859769058180973, 0.013372257108130725, 0.07926500096800737, 0.05153936566784978, 0.5008946440648288, 8.257234320044518, 23.354014232754707, 29.554413221776485, 32.17683680355549, 19.174468405544758, 19.25136297941208, 19.447493255138397, 28.577656634151936, 13.711216561496258, 2.8545866115018725, 0.3132443851791322, 0.7899923343211412, 1.429255425464362, 5.555109540000558, 4.679927201941609, 2.4819871550425887, 5.0993800442665815, 0.7427231676410884, 0.3623271529795602, 0.8067760337144136, 0.3089856152655557, 1.9055587984621525, 5.703963227570057, 14.010652843862772, 17.673579342663288, 28.321221694350243, 35.118654146790504, 47.96468183398247, 49.44475561380386, 53.75240206718445, 54.08659793436527, 54.81496945023537, 55.148295164108276, 55.76630540192127, 60.855801701545715, 63.43021295964718, 63.03269349038601, 59.74391296505928, 61.76206447184086, 60.51818981766701, 60.792500898242, 62.27083817124367, 60.87675377726555, 64.36503499746323, 47.85672202706337, 43.6020827293396, 48.12401108443737, 53.69728982448578, 59.46318782866001, 57.72806033492088, 58.40155519545078, 59.06129479408264, 57.129444256424904, 59.264074712991714, 61.47446550428867, 60.68130746483803, 59.426481798291206, 58.57055492699146, 60.37410154938698, 60.24088829755783, 61.538188084959984, 59.64195303618908, 56.86389170587063, 55.98320536315441, 49.45604860782623, 39.82509300112724, 30.968317352235317, 18.13787452876568, 13.011447060853243, 7.399528194218874, 3.8973577693104744, 1.9755186256952584, 0.8922746521420777, 0.21331246389308944, 0.527210725704208, 0.3858966944972053, 0.4747806047089398, 5.2803215850144625, 0.8296927227638662, 7.3918212577700615, 5.890338476747274, 2.3247390054166317, 5.0731870997697115, 1.2736846483312547, 0.3992657724302262, 0.5236021068412811, 4.988750405609608, 28.575690239667892, 49.077790305018425, 54.355304315686226, 47.006779834628105, 34.85502429306507, 28.812373839318752, 12.929704897105694, 1.9251613528467715, 0.09236194819095545, 0.08487412342219613, 0.04498438342125155, 0.0565357747109374, 0.11162900729686953, 0.010144495445274515, 0.06475070011219941, 0.0751992488221731, 0.04011986886325758, 0.05555007643124554, 0.050821541881305166, 0.026738623419078067, 0.014328217530419352, 0.029787729727104306, 0.030790677374170627, 0.08619359519798309, 0.03900389026966877, 0.025178113210131414, 0.007975528042152291, 0.038299822190310806, 0.07429065226460807, 0.03844814782496542, 0.02956288866698742, 0.041630336054367945, 0.006287993228397681, 0.03728955882252194, 0.016270726919174194, 0.032474578911205754, 0.017191726619785186, 0.054146192778716795, 0.06407494496670552, 0.07371774394414388, 0.06314055877737701, 0.014294408065325115, 0.04615249788912479, 0.04312976008804981, 0.10164412276935764, 0.025899350875988603, 0.05544458013901021, 0.0211459896308952, 0.03998079409939237, 0.0474684815708315, 0.055500330272479914, 0.033001915653585456, 0.06995889954851009, 0.03140738539514132, 0.03286595790996216, 0.039535806063213386, 0.05234760530584026, 0.036768600839423016, 0.0064690382987464545, 0.005838008682985674, 0.03514693024044391, 0.023126399573811796, 0.021429239568533376, 0.05114883642818313, 0.04927277615934145, 0.0613998625340173, 0.03351021630805917, 0.017122573299275246, 0.015373919377452694, 0.09787839124328457, 0.02359712714678608, 0.05610841639281716, 0.00810137031294289, 0.05396653737989254, 0.05603874356893357, 0.04946544882841408, 0.017234795304830186, 0.10702018116717227, 0.06641323707299307, 0.09747930875164457, 0.03894699351803865, 0.04467087797820568, 0.0365325236634817, 0.04540783804259263, 0.0692842502030544, 0.013874676242267014, 0.05670429418387357, 0.10394387514679693, 1.8052573618479073, 17.26941592991352, 36.720378398895264, 34.50696296989918, 29.310603104531765, 20.460435301065445, 21.97458755224943, 31.42427198588848, 33.43281760811806, 11.517219990491867, 1.5338373323902488, 0.2110743839875795, 0.4298626509262249, 0.6274554622359574, 2.3389234067872167, 3.8911840505898, 3.177180038765073, 9.855982381850481, 1.086412409786135, 2.400005366653204, 0.8133459999226034, 1.0359215503558517, 4.233694821596146, 7.467988645657897, 16.669792905449867, 20.255426801741123, 31.985938847064972, 37.110739052295685, 52.60739430785179, 52.87140794098377, 57.936832532286644, 57.52927400171757, 57.31572166085243, 58.586403876543045, 57.682561576366425, 63.70696730911732, 64.06229764223099, 64.02802348136902, 62.503351494669914, 65.45077353715897, 60.59003256261349, 62.37631671130657, 61.82518668472767, 61.45035199820995, 65.73259681463242, 50.56720018386841, 39.498097747564316, 48.436494916677475, 55.5052176117897, 58.98575484752655, 57.66912169754505, 58.31368871033192, 59.722983688116074, 57.509746849536896, 60.785733461380005, 61.098616272211075, 61.01017601788044, 60.996280163526535, 59.24410678446293, 59.64052431285381, 61.33900657296181, 60.611296221613884, 59.65655565261841, 58.89894850552082, 59.48027551174164, 53.32727327942848, 44.265755116939545, 35.30422858893871, 24.243162721395493, 17.557896450161934, 10.457621198147535, 5.656140418723226, 3.9000777108594775, 2.290206220932305, 0.9966963739134371, 1.3263158616609871, 3.0027323495596647, 4.134374801069498, 4.02114087715745, 6.2213691137731075, 6.796226967126131, 3.246672134846449, 3.9104706281796098, 2.066821907646954, 0.2344649937003851, 0.2071154714212753, 0.44191373395733535, 5.517748994752765, 20.193961299955845, 50.816588401794434, 55.24536855518818, 45.47483503818512, 34.85137268900871, 32.18017302453518, 17.13803417980671, 3.7143318029120564, 0.016770105103205424, 0.09312839378253557, 0.0396919873310253, 0.08502879441948608, 0.0779088596755173, 0.046221257871366106, 0.048344831811846234, 0.03242030936235096, 0.07791061114403419, 0.05234072188613936, 0.07038035037112422, 0.0745757482945919, 0.019058417274209205, 0.03351080260472372, 0.021866674396733288, 0.038034571189200506, 0.03570585649868008, 0.03996438150352333, 0.052179950434947386, 0.006742721488990355, 0.03170641153701581, 0.03996475257736165, 0.06215285298821982, 0.0307006066213944, 0.06313384234090336, 0.06052080345398281, 0.02319455841643503, 0.034288424940314144, 0.015146721998462453, 0.06097480858443305, 0.03987346470239572, 0.03390637844859157, 0.04622445652785245, 0.026002104932558723, 0.04475100395211484, 0.02999272575834766, 0.0877612856857013, 0.09810303934500553, 0.15946687432006001, 0.19234998326282948, 0.1533248898340389, 0.17935116280568764, 0.1692656727391295, 0.14784920553211123, 0.1448416817584075, 0.18494986550649628, 0.1981419263756834, 0.15286986425053328, 0.08584234412410296, 0.11646196944639087, 0.1231493211525958, 0.18834238580893725, 0.31881108647212386, 0.19745365862036124, 0.1575005688937381, 0.11355476177413948, 0.12353962403722107, 0.1715081906877458, 0.15122259326744825, 0.21050542389275506, 0.10124499574885704, 0.19008965376997367, 0.09906437291647308, 0.18305278761545196, 0.14469712623395026, 0.10536580783082172, 0.12722040934022516, 0.38609947892837226, 0.10089490984682925, 0.2448184139211662, 0.16561454365728423, 0.24794662575004622, 0.11676007532514632, 0.1746727232239209, 0.19415775110246614, 0.14848161925328895, 0.2229728369275108, 0.14943851478165016, 0.17184473981615156, 0.13220887369243428, 1.501905508339405, 18.039486408233643, 43.35307829082012, 43.19898895919323, 44.12923224270344, 27.712306268513203, 27.07044281065464, 29.302652031183243, 36.661861538887024, 16.902570314705372, 3.978859595954418, 0.5343165225349367, 1.249930104240775, 5.7666384894400835, 12.070297412574291, 14.307907093316317, 8.60384602099657, 8.854162339121103, 0.9907001175452024, 2.375581464730203, 2.219373984262347, 1.3361815572716296, 2.4201867962256074, 6.618732316419482, 15.558246150612831, 20.02825789153576, 29.93853460997343, 36.25507436692715, 49.995600655674934, 52.26384334266186, 56.69932633638382, 61.70522332191467, 62.68596209585667, 62.40087479352951, 58.7426894903183, 61.31462708115578, 64.44015696644783, 65.92836230993271, 65.42222946882248, 67.30754390358925, 64.3050742149353, 64.39278110861778, 66.5216700732708, 64.0308429300785, 66.8282300233841, 52.78277009725571, 44.85212825238705, 54.53194923698902, 55.449558198451996, 59.72202993929386, 56.772905588150024, 57.54948891699314, 60.01348190009594, 58.692547380924225, 61.05252854526043, 64.7703592479229, 64.59144204854965, 63.798660188913345, 61.02959677577019, 62.944177240133286, 63.71712416410446, 62.49284125864506, 61.21445685625076, 58.61539252102375, 58.47029350697994, 51.19824752211571, 42.72945575416088, 34.073098450899124, 21.44560843706131, 14.321461915969849, 8.48102331161499, 5.2435618825256824, 2.750400952063501, 1.5526020317338407, 0.5331515881698579, 1.3756746193394065, 1.9012758345343173, 2.9718922544270754, 11.9031529314816, 4.9815307930111885, 14.65064300224185, 15.760231912136078, 13.969143871217966, 12.25234754383564, 4.31194307282567, 0.6173924147151411, 0.694248634390533, 6.409998591989279, 32.94280730187893, 56.81376099586487, 57.59914845228195, 54.718283638358116, 46.1115288734436, 39.99790392816067, 19.403742402791977, 3.3087826520204544, 0.12730792339425534, 0.16422647517174482, 0.20762167550856248, 0.19917826139135286, 0.24576346477260813, 0.1632881778641604, 0.13664325058925897, 0.09876372147118673, 0.15120343101443723, 0.19508171011693776, 0.1710474060382694, 0.14932533726096153, 0.11559002014109865, 0.15604595944751054, 0.16984913439955562, 0.19567260809708387, 0.10532535336096771, 0.09714379120850936, 0.11229780851863325, 0.1398934714961797, 0.18794131436152384, 0.11447715485701337, 0.15688537299865857, 0.14604317431803793, 0.1900089971604757, 0.12329164281254634, 0.0971853440569248, 0.17036387318512425, 0.0888381568074692, 0.1063025466282852, 0.17334767791908234, 0.30115191999357194, 0.1266825303900987, 0.19477606401778758, 0.17231362871825695, 0.1148627970542293], [0.04938081059663091, 0.06483480770839378, 0.01944786297826795, 0.022592593159060925, 0.051419334413367324, 0.018621971357788425, 0.04599607171257958, 0.03649062571639661, 0.027229151492065284, 0.022753587254555896, 0.03447202114330139, 0.026551886076049414, 0.047084624238777906, 0.02949139572592685, 0.020865147962467745, 0.05926565732806921, 0.10782136669149622, 0.03263293096097186, 0.02062069564999547, 0.025514172521070577, 0.024507159760105424, 0.026729738056019414, 0.11469615521491505, 0.05434619415609632, 0.02316397636604961, 0.02948877779999748, 0.08564463598304428, 0.007010486515355296, 0.04131738351134118, 0.07265707390615717, 0.08807793783489615, 0.0919434436946176, 0.029831047031620983, 0.0945985215366818, 0.006433596108763595, 0.058532478506094776, 0.04323208369896747, 0.03996253726654686, 0.005849601029694895, 0.02299070529261371, 0.03579349671781529, 0.042966491309925914, 0.0876940025773365, 0.03764214205148164, 0.08446759718935937, 0.7250195019878447, 4.570305934175849, 26.23343702405691, 35.0320415943861, 27.115683183073997, 16.354839205741882, 17.01106209307909, 16.077338196337223, 27.074873372912407, 18.93271777778864, 5.993337649852037, 1.101370663382113, 0.43480918393470347, 1.0580025217495859, 3.8676158152520657, 2.21597530413419, 19.405646100640297, 2.839133315719664, 0.920380437746644, 0.5717965238727629, 1.26748290611431, 0.7824699254706502, 0.41853082773741335, 1.4368962217122316, 5.44192548841238, 11.746609881520271, 15.769917592406273, 17.85497210919857, 21.310217902064323, 30.332121290266514, 37.01138198375702, 41.801838129758835, 40.74829526245594, 49.597252830863, 50.578337386250496, 57.88477912545204, 65.71237429976463, 66.33071511983871, 63.713286370038986, 62.573643922805786, 64.61954534053802, 64.85659182071686, 63.34373340010643, 56.84342980384827, 37.21896484494209, 47.49098785221577, 42.80740097165108, 51.57041475176811, 58.65425303578377, 60.42530000209808, 60.2766215801239, 63.90016794204712, 59.58759315311909, 60.73949754238129, 56.1263132840395, 62.02511675655842, 60.6581325083971, 58.6311274766922, 57.01090581715107, 57.96318031847477, 58.01241047680378, 50.82651726901531, 32.31594353914261, 21.038901060819626, 16.794175431132317, 10.319854840636253, 5.2198464050889015, 2.8675838140770793, 1.4176101190969348, 0.9422577638179064, 0.17935620940988883, 0.5592574342153966, 1.587528451345861, 0.9627325495239347, 1.5763083659112453, 4.386115092784166, 5.000359257683158, 3.183318371884525, 5.29685877263546, 3.753948714584112, 1.1877500033006072, 2.71492890547961, 1.8300662306137383, 0.19521259528119117, 1.8986510066315532, 9.03270335868001, 36.57887399196625, 35.296230018138885, 15.707287453114986, 15.197325367480516, 24.911900237202644, 31.139482967555523, 16.954720616340637, 3.33532327786088, 0.010545478762651328, 0.10255563596729189, 0.004269606197340181, 0.029948627343401313, 0.029744662897428498, 0.05356682406272739, 0.04996779374778271, 0.07918199175037444, 0.0439543974789558, 0.03327933787659276, 0.04253279505064711, 0.02007324856094783, 0.05078135829535313, 0.07891763132647611, 0.053478694026125595, 0.0434274577855831, 0.046736679432797246, 0.03410473596886732, 0.016399758569605183, 0.06775779344025068, 0.08294695144286379, 0.04326429290813394, 0.06698323617456481, 0.008649920418974943, 0.0709699050639756, 0.037198148493189365, 0.061064281908329576, 0.021933781245024875, 0.032511578683624975, 0.03705779352458194, 0.0814725860254839, 0.043530490147531964, 0.027755890805565286, 0.0150592905083613, 0.047586768778273836, 0.08123559600790031, 0.013140253395249601, 0.06939900849829428, 0.057592028970248066, 0.03716690407600254, 0.08605345545220189, 0.010311538044334156, 0.07266312240972184, 0.034686898870859295, 0.009967635160137434, 0.012039946177537786, 0.031883499104878865, 0.026777567618410103, 0.056422638008370996, 0.04113864466489758, 0.03786477151152212, 0.027150220375915524, 0.03969987636082806, 0.03800574988417793, 0.03525645639456343, 0.029155002448533196, 0.025084181434067432, 0.03691549783980008, 0.04115024072234519, 0.11408763122744858, 0.016962740664894227, 0.044871376594528556, 0.0163576157137868, 0.11728957542800345, 0.0453357606602367, 0.024459905362164136, 0.04568265903799329, 0.10544472781475633, 0.09130568651016802, 0.010049653610622045, 0.04265284485882148, 0.01904411237774184, 0.0478520272008609, 0.07409509635181166, 0.042272965438314714, 0.015167783221841091, 0.03851481495075859, 0.038249946155701764, 0.06206188423675485, 0.034779645066009834, 0.05920283823797945, 0.15599096630467102, 1.4218676718883216, 12.915790043771267, 32.781977131962776, 40.09182728827, 27.668986693024635, 14.950347170233727, 20.498570054769516, 29.63894158601761, 39.96603883802891, 20.736074410378933, 5.683593470603228, 0.6624740269035101, 0.19842639158014208, 0.8098478720057756, 1.5583874587900937, 1.909663884434849, 12.09439191967249, 6.001266399398446, 1.6623916779644787, 2.7392048528417945, 1.0836779815144837, 1.2933177198283374, 0.5652910354547203, 3.0669277673587203, 6.978110857307911, 14.027880169451237, 19.153474532067776, 21.66933663189411, 26.607249565422535, 34.40700553357601, 43.02860610187054, 48.447848707437515, 48.77244628965855, 54.16815675795078, 54.43117864429951, 60.667464807629585, 67.03368499875069, 68.14939633011818, 65.52800819277763, 64.2896318435669, 65.8205696940422, 66.15188151597977, 62.587387785315514, 60.05773052573204, 41.886569783091545, 45.070863515138626, 46.239635199308395, 55.359662622213364, 60.49487806856632, 60.05714535713196, 60.36653235554695, 63.85207772254944, 60.87041571736336, 61.079735085368156, 59.690776616334915, 62.777483984827995, 62.97879338264465, 61.056959107518196, 60.29088221490383, 59.36351537704468, 59.4792989641428, 52.92482927441597, 38.80686543881893, 27.906719036400318, 22.69676350057125, 13.59963459894061, 9.08315135166049, 4.660694058984518, 2.33168242033571, 1.770640981849283, 0.7284354593139142, 1.9051278778351843, 3.182404045946896, 6.078363787382841, 3.335229945369065, 6.359015302732587, 6.280387071892619, 5.449408236891031, 5.292515605688095, 6.210463223978877, 2.624905086122453, 0.8495217212475836, 0.7639853423461318, 0.18650089477887377, 1.4706952893175185, 8.398770075291395, 29.677889496088028, 48.79905246198177, 30.89449681341648, 25.04630282521248, 33.59314240515232, 37.59326756000519, 24.991443268954754, 5.91850446537137, 0.03714587161084637, 0.17894795397296548, 0.06892012286698446, 0.029032659404037986, 0.06544445976032875, 0.04627906375390012, 0.03797174838837236, 0.08883269460056908, 0.08098051242996007, 0.028759098204318434, 0.014938347339921165, 0.02177066089643631, 0.060539253245224245, 0.02271700679557398, 0.06526129771373235, 0.01584164310770575, 0.025372672789671924, 0.02144775615306571, 0.03727579569385853, 0.05541381069633644, 0.03268633590778336, 0.03846587773296051, 0.03337850735988468, 0.0072541999270470114, 0.006120403759268811, 0.024479869134665933, 0.02623056210723007, 0.02873694509617053, 0.05580616190854926, 0.03980985522503033, 0.00860278012623894, 0.0914288756030146, 0.031353835729532875, 0.0378408743563341, 0.019545813484000973, 0.030910055538697634, 0.018397352941974532, 0.154684875451494, 0.16308778314851224, 0.13071714201942086, 0.22254006093135104, 0.15052359405672178, 0.2619390038307756, 0.10536597110331059, 0.11510472977533937, 0.1358276599785313, 0.08901399385649711, 0.08374913144507445, 0.09747626594617032, 0.10310351164662279, 0.0862589932512492, 0.12114704382838681, 0.209575854241848, 0.2524826175067574, 0.11904496248462237, 0.14745807886356488, 0.09546315326588228, 0.11440216825576499, 0.20279306976590306, 0.3405610896879807, 0.17429323343094438, 0.14570445811841637, 0.16853544395416975, 0.14687858027173206, 0.11129364560474642, 0.18337398912990466, 0.119440497510368, 0.19575905345845968, 0.2216518289060332, 0.11751180412829854, 0.1516791179892607, 0.0923758783028461, 0.13183284230763093, 0.1427906527533196, 0.10805987811181694, 0.11630074528511614, 0.10877242893911898, 0.09902037840220146, 0.13850368122803047, 0.11301709804683924, 0.10100882951519452, 0.254589396645315, 1.219643116928637, 14.101114589720964, 38.87860178947449, 50.65978601574898, 39.465510696172714, 25.05498345941305, 24.666384011507034, 23.872272223234177, 37.24321894347668, 21.907813735306263, 8.392550759017467, 1.2569059361703694, 1.0646275850012898, 2.663190644234419, 9.152207896113396, 8.189287316054106, 27.120902203023434, 7.104048449546099, 1.2199670495465398, 2.0624215062707663, 2.7776108169928193, 2.8962119529023767, 0.8825832128059119, 2.3733516968786716, 6.693559801205993, 13.018892761319876, 17.346023619174957, 20.651059672236443, 23.352579809725285, 32.036476135253906, 39.002889320254326, 45.87631769478321, 48.68585653603077, 60.11676035821438, 61.67209289968014, 62.65778660774231, 68.25086608529091, 71.29947289824486, 69.30353119969368, 67.32287228107452, 68.14117357134819, 68.32259863615036, 62.76177182793617, 58.12066286802292, 44.725659638643265, 46.016902551054955, 45.864367336034775, 57.14568458497524, 60.22440478205681, 60.40402114391327, 61.66428431868553, 63.08801092207432, 60.865825563669205, 62.07652419805527, 58.53279635310173, 63.94131973385811, 62.69855462014675, 61.47929884493351, 60.76895356178284, 58.977509289979935, 60.291322991251945, 53.03241290152073, 33.34057375788689, 23.32798942923546, 19.186977334320545, 11.529610175639391, 6.6365989577025175, 3.4740552585572004, 2.519551939330995, 1.1339567648246884, 0.36331052833702415, 1.7126825731247663, 3.9660264970734715, 3.3757464587688446, 4.78555915877223, 7.410572301596403, 11.03730859234929, 8.086454384028912, 11.725162882357836, 14.952689744532108, 5.772030400112271, 5.460440944880247, 3.429187503643334, 0.6773676839657128, 2.2845787229016423, 11.667134296149015, 41.988734900951385, 42.48236261308193, 22.35370460897684, 24.856738597154617, 34.538467079401016, 41.25127047300339, 26.465028896927834, 4.576886231079698, 0.09751388541189954, 0.273437513387762, 0.10952262891805731, 0.119298190693371, 0.21112407819600776, 0.14201211015461013, 0.1719956926535815, 0.18502727150917053, 0.10754967384855263, 0.12412169788149185, 0.07423795235808939, 0.16740623657824472, 0.20899534632917494, 0.11492340825498104, 0.14293909713160247, 0.09722873743157834, 0.236169217096176, 0.16382512170821428, 0.25244844902772456, 0.23829520301660523, 0.14443853229749948, 0.1119114167522639, 0.09726908057928085, 0.09458479180466384, 0.2700040413765237, 0.07057831826386973, 0.15049748530145735, 0.11397448339266703, 0.16514571412699297, 0.20082951028598472, 0.11138134519569576, 0.20247106673195958, 0.08961746381828561, 0.16343592462362722, 0.07882134508690797, 0.2247602996067144, 0.15229340846417472], [0.033177734148921445, 0.04998281481675804, 0.046950195319368504, 0.019624295600806363, 0.0377435602422338, 0.044314491242403165, 0.09666547703091055, 0.04165043341345154, 0.03465923531621229, 0.05229650472756475, 0.03699764245538972, 0.02232498583907727, 0.04914751276373863, 0.01214729598359554, 0.06808465754147619, 0.023811973333067726, 0.0233091200425406, 0.0880361623421777, 0.016492888826178387, 0.08031387827941217, 0.04710476983746048, 0.052899893053108826, 0.02837552845448954, 0.038605041554546915, 0.07123888164642267, 0.02110543311573565, 0.035253513779025525, 0.016414037490903866, 0.03138811553071719, 0.05152009580342565, 0.05511987939826213, 0.010362360317230923, 0.10882696195039898, 0.04097281547728926, 0.042755257527460344, 0.02394849139818689, 0.022498167854791973, 0.0187511384501704, 0.060285501822363585, 0.035873674642061815, 0.038312501783366315, 0.03149723350361455, 0.056100545916706324, 0.07310170942218974, 0.03369998717971612, 0.21736337308539078, 0.16708019626094028, 7.405471075326204, 25.75825922191143, 37.510523200035095, 30.179114900529385, 22.812404595315456, 14.839630611240864, 14.076575506478548, 26.044176779687405, 21.08386404812336, 9.411339741200209, 2.4777893302962184, 0.533393231453374, 0.5620633461512625, 0.848696690518409, 13.637692406773567, 5.631029941141605, 1.3377528917044401, 1.9985930062830448, 0.12265754441614263, 0.9665579348802567, 0.546849318780005, 0.10572727827820927, 0.20444605528609827, 0.9032065467908978, 2.8913237527012825, 3.7935834378004074, 4.367433870211244, 6.32400113157928, 9.680999871343374, 15.347692798823118, 22.60293323546648, 29.38609555363655, 40.46853147447109, 53.53522852063179, 55.643408596515656, 56.89552880823612, 69.50811222195625, 63.932587802410126, 64.19907510280609, 61.93764545023441, 63.22624750435352, 50.220468789339066, 38.99220809340477, 36.994039714336395, 36.268339455127716, 41.82366415858269, 62.8568085283041, 65.615274310112, 61.83768801391125, 63.37143391370773, 62.417909279465675, 61.077143624424934, 62.98778370022774, 59.281447380781174, 57.92414501309395, 59.623736813664436, 51.54135391116142, 36.042194589972496, 21.653386987745762, 9.625023175030947, 3.482216033153236, 0.8043633413035423, 0.38733723282348365, 0.12152887138654478, 0.9504632453899831, 0.5939609720371664, 0.3360021358821541, 1.1116207321174443, 0.6838775065261871, 2.9048460396006703, 3.7377535086125135, 12.124265916645527, 2.4345281766727567, 8.004446234554052, 7.315065851435065, 2.5965156219899654, 7.046895241364837, 4.224816597998142, 0.1541272405302152, 0.18730342359049246, 0.39872014545835555, 3.754006423987448, 13.600812535732985, 40.095581486821175, 27.76158582419157, 7.193615343421698, 17.899410724639893, 26.0986240580678, 29.615783728659153, 19.500553607940674, 2.7381430473178625, 0.038057303172536194, 0.07443134862114675, 0.010674105014913948, 0.02433860132441623, 0.0981808609503787, 0.031512247151113115, 0.05120564041135367, 0.04153119996772148, 0.08968677298980765, 0.037057422450743616, 0.03121870176983066, 0.0843967220862396, 0.05659891292452812, 0.014496605272142915, 0.08249170321505517, 0.04384287865832448, 0.10342679859604686, 0.020304572281020228, 0.015405496833409416, 0.0007509868294164335, 0.010632600406097481, 0.018407076931907795, 0.011315375340927858, 0.04366216198832262, 0.06780127587262541, 0.07002892860327847, 0.047216652310453355, 0.020445363261387683, 0.08453265385469422, 0.028524432964331936, 0.02472727333952207, 0.06305335642537102, 0.04298639942135196, 0.01605920184374554, 0.030828795934212394, 0.07253343952470459, 0.01630202885280596, 0.02595301000837935, 0.017399140197085217, 0.09228876500856131, 0.02538119450036902, 0.005201463982302812, 0.09611909306840971, 0.03657749039120972, 0.08375079385587014, 0.032506057104910724, 0.010815548157552257, 0.025920630105247255, 0.03579778262064792, 0.09737609827425331, 0.05573912741965614, 0.059921548890997656, 0.05227775436651427, 0.04658450205170084, 0.05723328220483381, 0.04266898657078855, 0.03700138287968002, 0.06671436349279247, 0.02134215596015565, 0.012765736919391202, 0.005325306165104848, 0.021881140710320324, 0.05090784623462241, 0.04495971072174143, 0.03065927085117437, 0.07024444086709991, 0.08584278941270895, 0.054042544434196316, 0.05590781016508117, 0.014520293698296882, 0.018740778068604413, 0.02892994431022089, 0.06650702227489091, 0.09677954512881115, 0.06876925166579895, 0.06893046098412015, 0.028686942896456458, 0.09138725596130826, 0.013236637041700305, 0.048312470462406054, 0.0437175633123843, 0.12185105995740741, 0.03688152602990158, 0.18115499726263806, 0.7551617408171296, 15.04822801798582, 33.94572168588638, 41.250609308481216, 31.246736012399197, 18.205273412168026, 13.651216831058264, 23.591588884592056, 40.13537675142288, 26.947468109428883, 11.586577668786049, 2.063566669821739, 0.08131694281473756, 0.3112728847190738, 0.6555968115571886, 7.584284255281091, 6.336915688589215, 1.6365281282924116, 3.1841132417321205, 2.299151890911162, 2.2172325616702437, 0.8952812408097088, 0.4459626541938633, 0.5145926121622324, 1.7193469405174255, 3.985354397445917, 5.569942519068718, 6.324734017252922, 8.955587446689606, 12.795788682997227, 20.338556841015816, 27.24390920251608, 37.05559641122818, 47.587681263685226, 56.094258204102516, 59.422579407691956, 63.141337260603905, 69.66034725308418, 63.060139417648315, 65.26452273130417, 62.431079372763634, 61.60343438386917, 52.91261672973633, 43.93952362239361, 41.32101573050022, 39.96219724416733, 48.93219351768494, 62.452715411782265, 64.03345718979836, 60.899757742881775, 63.123630210757256, 61.60548247396946, 61.39159195125103, 61.56606338918209, 61.71159937977791, 61.31476007401943, 60.24740494787693, 55.043865367770195, 42.137504518032074, 28.087532334029675, 14.59191620349884, 6.10176008194685, 2.0974325900897384, 1.2004711269401014, 1.0505647771060467, 2.028823234140873, 2.0786490105092525, 1.669973221141845, 2.31551808770746, 2.0117543125525117, 3.8186252815648913, 6.273262454196811, 10.932665057480335, 2.726076557300985, 7.571505540981889, 4.056276166811585, 4.57536868751049, 2.191085214726627, 0.8639139833394438, 0.4557316331192851, 0.1838494386174716, 0.2144976588897407, 4.2418458592146635, 14.649643655866385, 35.26353657245636, 40.818667486310005, 13.873026128858328, 12.215768806636333, 19.516879431903362, 30.932069197297096, 25.134813375771046, 5.303204907104373, 0.02004113768634852, 0.16913471336010844, 0.06765881320461631, 0.07275977230165154, 0.011210313205083366, 0.021908269918640144, 0.018887001569964923, 0.027535682602319866, 0.07137966706068255, 0.011358206538716331, 0.02466313322656788, 0.049149293918162584, 0.05395329375460278, 0.06596480918233283, 0.08157965567079373, 0.05515065626241267, 0.12364143927698024, 0.06714064569678158, 0.05084245189209469, 0.027648474206216633, 0.04086099979758728, 0.03726542418007739, 0.019443408236838877, 0.05912874221394304, 0.06634337129071355, 0.028264434513403103, 0.09012403897941113, 0.0363675961853005, 0.08614870268502273, 0.051548724150052294, 0.011408253267291002, 0.08641635824460536, 0.03824539679044392, 0.03339676790346857, 0.09545844804961234, 0.027274136773485225, 0.017487580080342013, 0.03311407272121869, 0.0940892894868739, 0.14868455211399123, 0.1754007997806184, 0.10120103092049249, 0.19692996953381225, 0.1258259583846666, 0.15984185185516253, 0.13630861620185897, 0.11907637017429806, 0.15927566739264876, 0.16525086160982028, 0.13918008946347982, 0.21167513768887147, 0.10915408580331132, 0.1289358243229799, 0.131510408828035, 0.1654552639229223, 0.12128131318604574, 0.0885410157206934, 0.2069872579886578, 0.12577997491462156, 0.09025831575854681, 0.26293517381418496, 0.08343114343006164, 0.210988754988648, 0.10451698384713382, 0.1354579220060259, 0.12661441607633606, 0.23750269319862127, 0.11794870646554045, 0.1386401621857658, 0.1554609986487776, 0.28977099631447345, 0.18956554908072576, 0.22531624243129045, 0.14695726276841015, 0.17623779393034056, 0.16875437751878053, 0.13448143377900124, 0.1829630322754383, 0.1536648825276643, 0.24182623776141554, 0.2447232705890201, 0.24617890419904143, 0.1204742795380298, 0.43703072878997773, 0.6488089507911354, 13.12307272106409, 37.058070078492165, 52.11553730070591, 41.08942575752735, 30.832847021520138, 20.545636229217052, 20.82771599292755, 36.520980298519135, 26.636836677789688, 12.980151940137148, 2.8057499695569277, 1.028656221460551, 1.1293560429476202, 2.3851650254800916, 22.93319821357727, 12.776049692183733, 4.664821112528443, 4.934189608320594, 2.505422872491181, 4.360328251495957, 1.5058481530286372, 0.4289632569998503, 0.3158864309079945, 1.6538732475601137, 4.187849331647158, 4.078768584877253, 5.296128736808896, 6.825443599373102, 11.511740684509277, 18.503293320536613, 24.885713942348957, 35.22719532251358, 49.475302174687386, 62.60042868554592, 67.45752945542336, 61.755304634571075, 70.05736514925957, 67.94105350971222, 64.94914725422859, 64.10525813698769, 60.61261475086212, 54.46845464408398, 48.24233293533325, 43.06044839322567, 42.07087129354477, 51.335097178816795, 64.00445714592934, 65.76766893267632, 61.60218045115471, 64.06486630439758, 62.14670643210411, 61.88806191086769, 64.5192763209343, 60.90122066438198, 59.60811585187912, 58.52586552500725, 53.30566383898258, 38.1461226940155, 23.33416599780321, 10.681486185640097, 4.502913225442171, 1.376875948626548, 0.6525687302928418, 0.584020052338019, 1.7880042688921094, 2.095274068415165, 0.8352511120028794, 2.66419711522758, 1.5046899276785553, 4.589945180341601, 9.477496091276407, 19.905929155647755, 8.790135774761438, 16.50416549295187, 14.0242257155478, 8.85110255330801, 13.420011587440968, 10.273669268935919, 1.9792616623453796, 0.41831815789919347, 0.5912087322212756, 5.2968108002096415, 16.690080016851425, 46.15596368908882, 36.30959004163742, 13.12932813540101, 27.445116005837917, 35.64763896167278, 42.13807448744774, 28.261215314269066, 4.723245827481151, 0.14780902565689757, 0.2345456651528366, 0.12832714448450133, 0.19524790666764602, 0.1727284150547348, 0.10956685349810869, 0.13960770011181012, 0.14256401569582522, 0.2866543619893491, 0.17211641039466485, 0.15960828313836828, 0.20707624149508774, 0.1527976235956885, 0.11956682588788681, 0.14854165900032967, 0.12980805564438924, 0.2392089946079068, 0.20482483261730522, 0.1231668729451485, 0.13924875296652317, 0.14248025690903887, 0.10570889528025873, 0.16824204329168424, 0.11830734933027998, 0.2632582455407828, 0.15750019781989977, 0.12981981126358733, 0.1285253424430266, 0.16695303667802364, 0.10514929366763681, 0.13250450079794973, 0.19981968478532508, 0.14691571734147146, 0.08974135052994825, 0.0934617145685479, 0.1246852774056606, 0.08619815940619446, 0.09405838645761833], [0.028167641758045647, 0.0636069466418121, 0.033594075284781866, 0.07897220886661671, 0.02573760721134022, 0.030371786961040925, 0.01859010910266079, 0.00914720110813505, 0.029980691833770834, 0.045137933775549755, 0.062337020644918084, 0.029093400480633136, 0.050750507216434926, 0.0342256689327769, 0.05717743559216615, 0.038595727601205, 0.05648343845678028, 0.03805223801464308, 0.037105138835613616, 0.006993060424065334, 0.048827584032551385, 0.0314676774723921, 0.056357132343691774, 0.029006812255829573, 0.011362266086507589, 0.04882365436060354, 0.03613610919273924, 0.014246029313653708, 0.05532469731406309, 0.021009310148656368, 0.02641739592945669, 0.034980151103809476, 0.0448940306523582, 0.08286093652714044, 0.025183326797559857, 0.02086899970890954, 0.06349047398543917, 0.056452520584571175, 0.03841181969619356, 0.07299168602912687, 0.05601062730420381, 0.047654189183958806, 0.0347897011670284, 0.006099919091866468, 0.0035310417024447815, 0.06495386303868145, 0.0739400765451137, 0.17875603458378464, 4.484150782227516, 22.27791767567396, 31.921973079442978, 34.597120732069016, 27.583576776087284, 17.83182755112648, 25.458892285823822, 27.405959106981754, 21.384640708565712, 14.593019094318151, 6.064057080075145, 1.560095704626292, 1.7830477911047637, 0.8486731199081987, 4.7167491260915995, 2.183330305851996, 5.007491474971175, 2.21599240321666, 1.8539390433579683, 0.8708840562030673, 0.7889424625318497, 0.027851668673974928, 0.2723922429140657, 0.20777509227627888, 0.7675204589031637, 0.5235731927677989, 0.5591158324386925, 0.5227486370131373, 1.388647360727191, 3.0775085370987654, 7.099320078268647, 17.9570422321558, 38.27819220721722, 53.649195805191994, 55.97483441233635, 45.63912682235241, 60.35527355968952, 63.31141233444214, 59.323381930589676, 60.177530497312546, 42.510724291205406, 37.88797214627266, 28.813686668872833, 35.22897742688656, 39.954734444618225, 60.40549926459789, 61.75709433853626, 59.9679983407259, 59.47686709463596, 57.92370043694973, 56.68663501739502, 47.700504809617996, 41.396730467677116, 32.548320069909096, 23.700295351445675, 13.109404854476452, 3.9755706349387765, 0.39644080214202404, 0.1037218765122816, 0.11799711675848812, 0.11971151499892585, 0.24308573658345267, 1.171219227835536, 1.3530353154055774, 1.6014551790431142, 2.075622472912073, 2.6738716335967183, 3.195741567760706, 3.981010280549526, 4.754608394578099, 10.167296826839447, 1.4863999653607607, 3.7796586100012064, 1.4719652524217963, 4.401080114766955, 1.1648340267129242, 0.4563272511586547, 0.9025888424366713, 1.8285597302019596, 10.184159372001886, 19.69388533383608, 49.42778192460537, 33.38089719414711, 8.683856427669525, 25.28899770230055, 29.382480047643185, 30.456370823085308, 15.18387408927083, 2.4239514442160726, 0.01876435610029148, 0.094646946672583, 0.08106229710392654, 0.06526249257149175, 0.029733105802733917, 0.03838113188976422, 0.03826424363069236, 0.026310847642889712, 0.03185528265021276, 0.025315158200100996, 0.017060824757209048, 0.041305631602881476, 0.057740306365303695, 0.057124012091662735, 0.13275077508296818, 0.06259703950490803, 0.06550567210069858, 0.04084669490111992, 0.05475589678098913, 0.023982053171494044, 0.022913802094990388, 0.026081557407451328, 0.05875943097635172, 0.07197478786110878, 0.10348566574975848, 0.01427304534445284, 0.06145427680166904, 0.05230603761447128, 0.014164250205794815, 0.042628187002264895, 0.016938168155320454, 0.05822350016387645, 0.042714483934105374, 0.048601280941511504, 0.035417743638390675, 0.06502656382508576, 0.016832445508043747, 0.05453294077597093, 0.06061176478397101, 0.06848121673101559, 0.030478396474791225, 0.05100926813611295, 0.010994637668773066, 0.08032923331484199, 0.04941852283081971, 0.028081125892640557, 0.046506992148351856, 0.019478957110550255, 0.04495695364312269, 0.05734316830057651, 0.021855863160453737, 0.022391150159819517, 0.02481711402651854, 0.020261618628865108, 0.018755685960059054, 0.043545867447392084, 0.03849312197417021, 0.056520467915106565, 0.031236828726832755, 0.0188500017975457, 0.018923116331279743, 0.08827809506328776, 0.07771940421662293, 0.01764485044986941, 0.03528717759763822, 0.011510042531881481, 0.019873449418810196, 0.049078110823757015, 0.05098292931506876, 0.009250972834706772, 0.02739594732702244, 0.0077125391999288695, 0.016219385142903775, 0.050843208882724866, 0.06015013779688161, 0.050824169084080495, 0.024572880647610873, 0.05651494633639231, 0.055452350425184704, 0.038282147943391465, 0.034814566824934445, 0.003301356505289732, 0.04568648109852802, 0.025961136525438633, 0.06524626922328025, 0.07205510308267549, 0.42428526270668954, 10.100586656481028, 30.24027831852436, 37.866598293185234, 34.29230108857155, 18.7473751232028, 12.851052917540073, 28.321628272533417, 31.113047786056995, 29.668319709599018, 20.157988630235195, 4.789365129545331, 0.7133123895619065, 0.7766099867876619, 1.1797712626866996, 0.6779892474878579, 2.6027995347976685, 3.1762388767674565, 2.809181185439229, 3.244082098826766, 2.0432878704741597, 2.0182327274233103, 1.0382023779675364, 0.9632633929140866, 0.6175861449446529, 0.7934842875692993, 1.1886639730073512, 1.3461954449303448, 1.1077874503098428, 2.6099820993840694, 5.369725087657571, 9.74080391228199, 23.78737147897482, 45.335785299539566, 59.33121711015701, 57.1781500428915, 51.63135588169098, 63.228983357548714, 64.44595545530319, 60.621783658862114, 61.81347191333771, 47.406829968094826, 42.72168517112732, 33.98911535739899, 38.66418309509754, 48.230697959661484, 60.86517959833145, 62.824878841638565, 62.15529017150402, 65.13718396425247, 61.29268325865269, 59.77395415306091, 49.866502583026886, 44.91401553153992, 37.134122997522354, 30.041467286646366, 18.191029876470566, 6.561063285917044, 1.5444412571378052, 0.2588528272463009, 0.40902994223870337, 0.7343145157210529, 0.9766649769153446, 1.9034734228625894, 4.386932048946619, 2.985296272672713, 7.221721485257149, 2.771640862338245, 6.699426211416721, 6.469270186498761, 5.085167856886983, 8.630851171910763, 5.384259782731533, 6.076616831123829, 1.3245366071350873, 1.345902148168534, 0.37502360763028264, 0.282699991366826, 0.41820633108727634, 1.1022892640903592, 10.818799417465925, 22.742362953722477, 41.251019686460495, 47.44750298559666, 12.07659462466836, 13.669109120965004, 27.145370990037918, 37.14212156832218, 22.724051736295223, 4.0484319627285, 0.09796884420211427, 0.15619977697497234, 0.09540942177409306, 0.13225870148744434, 0.0502840377157554, 0.11561843697563745, 0.0645801991049666, 0.08641896318295039, 0.04047707196150441, 0.04731107204861473, 0.0710257442551665, 0.008758198837313103, 0.06772060442017391, 0.054039156530052423, 0.17706233484204859, 0.04090389222255908, 0.07997623077244498, 0.06766049045836553, 0.0304086865435238, 0.01707575676846318, 0.03097530145169003, 0.03806463188084308, 0.053402824269142, 0.06740545140928589, 0.046202310841181315, 0.07143633745727129, 0.04146322295127902, 0.09525484725600109, 0.045440952671924606, 0.05190403106098529, 0.005750547043135157, 0.08094424367300235, 0.05764622430433519, 0.0495619836874539, 0.05025018464948516, 0.06148280495835934, 0.041809312388068065, 0.05028163686802145, 0.020760603474627715, 0.18937989341793582, 0.11005387306795456, 0.1705293424311094, 0.15543123852694407, 0.18728666589595377, 0.09745404604473151, 0.1414420219953172, 0.10405720109702088, 0.0877129496075213, 0.10391791482106782, 0.1745964155998081, 0.08128232904709876, 0.09431689875782467, 0.17862298234831542, 0.15314865944674239, 0.06748091298504733, 0.13743712595896795, 0.11527477065101266, 0.1551446210942231, 0.059070105126011185, 0.11631369576207362, 0.12500457902206108, 0.16940295521635562, 0.14265506237279624, 0.10528537386562675, 0.11899482298758812, 0.1272609454463236, 0.12863957381341606, 0.20876289083389565, 0.11454061590484343, 0.09325038059614599, 0.1393150119110942, 0.15037430363008752, 0.12587433157023042, 0.13831257820129395, 0.09649943633121438, 0.14709651935845613, 0.14412542019272223, 0.14446205837884918, 0.10255362474708818, 0.20832751732086763, 0.17680163320619613, 0.12490425549913198, 0.1224951476615388, 0.08339957988937385, 0.26672006759326905, 0.17605461704079062, 0.3914951893966645, 8.323263376951218, 33.54849100112915, 47.497006729245186, 46.875519677996635, 37.60223887860775, 25.124985203146935, 34.48274306952953, 35.35746373236179, 30.116944536566734, 20.760951675474644, 8.049548864364624, 2.0533492555841804, 2.2594520961865783, 1.9011511537246406, 9.634003043174744, 9.798044990748167, 10.017163082957268, 6.383901592344046, 5.003527337685227, 2.642810675315559, 2.2979217069223523, 1.1169149167835712, 0.8963560487609357, 0.631113953422755, 1.2865179846994579, 1.0271150479093194, 1.2309135496616364, 0.7705419498961419, 1.7019805661402643, 3.436617529951036, 7.988454792648554, 21.374616846442223, 42.43932232260704, 59.88476000726223, 67.53110870718956, 53.95637132227421, 59.38974916934967, 65.00879645347595, 61.308323219418526, 63.12499813735485, 52.23966144025326, 45.78659690916538, 37.151719853281975, 41.309692338109016, 53.15993785858154, 62.93313503265381, 63.57290670275688, 65.6354208290577, 65.87245211005211, 62.41643875837326, 60.28951808810234, 48.00803750753403, 42.508535608649254, 34.072300493717194, 25.153660364449024, 14.220729321241379, 4.794328138232231, 0.9919602249283344, 0.16774303803686053, 0.31435730983503163, 0.3280447097495198, 0.942554147914052, 2.328935880213976, 4.477621782571077, 4.02443815022707, 5.188931738957763, 5.189202474430203, 7.371170790866017, 9.680903926491737, 11.323897764086723, 19.0632426738739, 6.591485403478146, 9.695409648120403, 7.728242380544543, 11.364067308604717, 3.4874248411506414, 1.316128014586866, 1.4939710590988398, 2.045591971836984, 12.893094811588526, 24.328154660761356, 55.40856219828129, 43.5756703466177, 15.074902586638927, 33.78158949315548, 41.60623602569103, 42.60162301361561, 22.76497934013605, 3.48317239433527, 0.116206715174485, 0.23688353423494846, 0.2511039742967114, 0.1806078414665535, 0.20989824319258332, 0.15648584521841258, 0.17292650911258534, 0.165281156077981, 0.1223585256957449, 0.13221706700278446, 0.11033328424673527, 0.12642930960282683, 0.08558732733945362, 0.16330998216290027, 0.29408789123408496, 0.16023085598135367, 0.23428209882695228, 0.12942755653057247, 0.15549582021776587, 0.15918846504064277, 0.1313469879096374, 0.12323423768975772, 0.14186658983817324, 0.2113979306886904, 0.2585095987888053, 0.16783021070295945, 0.15949439315591007, 0.16574903565924615, 0.1330960963969119, 0.1183686952572316, 0.1853689266135916, 0.2315816906047985, 0.1285638747503981, 0.20735013851663098, 0.11184930641320534, 0.13927174470154569, 0.11099036695668474, 0.13905957952374592, 0.10567086021183059], [0.007017326333880192, 0.0022128093132778304, 0.017887193207570817, 0.044689405694953166, 0.02276295686897356, 0.02815052412188379, 0.0484874132234836, 0.004035339397887583, 0.03126968731521629, 0.01742070515319938, 0.044455195020418614, 0.021444121484819334, 0.06475698610302061, 0.06420326229999773, 0.01906844183395151, 0.05001617064408492, 0.030988997787062544, 0.03234979049011599, 0.032426944162580185, 0.061093325857655145, 0.04302722867578268, 0.08401933257118799, 0.03846577754302416, 0.02950941321614664, 0.03775890414544847, 0.07012627611402422, 0.03769437440496404, 0.09294704999774694, 0.03752552467631176, 0.01974420069018379, 0.016027629026211798, 0.048268806203850545, 0.059584999762591906, 0.031649770826334134, 0.025108499758061953, 0.06678933525108732, 0.01948921173607232, 0.03349195576447528, 0.022135803119454067, 0.032840027270140126, 0.058185713714919984, 0.05242704850388691, 0.11009566340362653, 0.0655082993034739, 0.014622377966588829, 0.11551527102710679, 0.12216074333991855, 0.060271133843343705, 0.12203686404973269, 2.8042832482606173, 18.72095324099064, 35.93177631497383, 40.336252972483635, 29.57736399024725, 24.863234348595142, 22.478512711822987, 18.78782395273447, 25.70258840918541, 22.95908622443676, 14.022682998329401, 3.388389330357313, 1.065754818264395, 0.650125639513135, 1.466756563168019, 0.88723523193039, 1.4899395941756666, 3.051860863342881, 1.404898138716817, 1.9866473972797394, 1.0916118370369077, 0.43418717512395233, 0.2454841649159789, 0.578512663487345, 0.6285235018003732, 0.2306613977998495, 0.2725732378894463, 0.2281032592873089, 0.06223053358553443, 0.12659734667977318, 0.42641300009563565, 5.722810216248035, 18.903601840138435, 48.71602691709995, 43.701147213578224, 37.87278816103935, 47.86896876990795, 46.46609544754028, 35.32838389277458, 33.12775857746601, 36.667994409799576, 29.83937133103609, 33.75996485352516, 43.63218851387501, 58.20671685039997, 49.91662569344044, 29.43146701902151, 19.20620810240507, 17.953533120453358, 15.187833476811647, 11.690006218850613, 6.356302723288536, 4.493184322491288, 1.2072568503208458, 0.0966511238948442, 0.025177905408781953, 0.014877057074045297, 0.44660122774075717, 0.6046861934009939, 2.2182197961956263, 1.4702337328344584, 1.6900184517726302, 3.9459823351353407, 2.842175764963031, 12.704489082098007, 1.0796437854878604, 7.298844996839762, 4.222001424059272, 2.400690042413771, 3.9910878147929907, 2.9036424541845918, 5.565736144781113, 1.6347226314246655, 1.1926950816996396, 0.7237187249120325, 0.7547362823970616, 5.0943035166710615, 16.584800966084003, 23.110468201339245, 38.03981959819794, 34.41054694354534, 11.01699773222208, 23.671112917363644, 24.982354156672955, 25.567465759813786, 10.423774514347315, 0.5633198912255466, 0.02976517214847263, 0.03970384685089812, 0.026750317811092827, 0.014698618797410745, 0.04823956929612905, 0.019068529036303516, 0.043745605362346396, 0.07443229857017286, 0.023599761771038175, 0.07800765437423252, 0.036501294089248404, 0.05591799985268153, 0.02728877563640708, 0.03811208109254949, 0.035234488823334686, 0.04506460216362029, 0.01951194371940801, 0.022126003059383947, 0.027368408082111273, 0.006418486445909366, 0.024803143096505664, 0.017983509133046027, 0.056093009407049976, 0.025574544379196595, 0.05490980707691051, 0.01568209434481105, 0.03220426275220234, 0.06182631914271042, 0.022187579052115325, 0.042997787677450106, 0.05335277754056733, 0.03349236023495905, 0.047960236042854376, 0.032495637351530604, 0.038395781884901226, 0.026593797010718845, 0.06692179376841523, 0.023348559625446796, 0.008679983893671306, 0.01103962666093139, 0.04285509123292286, 0.03518952209560666, 0.03560437893611379, 0.053170947649050504, 0.02637897865497507, 0.033998697908828035, 0.014511573463096283, 0.041354242275701836, 0.05351840263756458, 0.036190820319461636, 0.1288461877265945, 0.02859743432054529, 0.04970942245563492, 0.037733904900960624, 0.016372360332752578, 0.03671384518384002, 0.11502008041134104, 0.00515135324349103, 0.027347086179361213, 0.0961217722215224, 0.005982990942356992, 0.05081548966700211, 0.04266026633558795, 0.049766367446864024, 0.022239746467676014, 0.06481077696662396, 0.046455498231807724, 0.052949594683013856, 0.015610414011462126, 0.045554297175840475, 0.05907124803343322, 0.04377914301585406, 0.08210628366214223, 0.03174125908117276, 0.024737203275435604, 0.050048431803588755, 0.02366282762523042, 0.03308867271698546, 0.020111845806241035, 0.017613674681342673, 0.06268559998716228, 0.047689945859019645, 0.006547311686517787, 0.02549089134845417, 0.06070237359381281, 0.00504264345181582, 0.09335124588687904, 0.06795747569412924, 0.2642213157378137, 6.952269868925214, 27.397639453411102, 43.01943339407444, 42.042106837034225, 25.006066784262657, 21.78269024938345, 26.210005581378937, 23.071170710027218, 37.37463869154453, 29.946939758956432, 11.406127251684666, 3.605453632771969, 0.32038256933446974, 0.22665559634333476, 0.6155538477469236, 0.7963357376866043, 0.8542591764125973, 1.6872041090391576, 2.7413168270140886, 2.886777059175074, 2.0217995485290885, 1.445982602890581, 1.0323442798107862, 1.5599973849020898, 1.9982678862288594, 1.0915112611837685, 1.0275103454478085, 2.2012404073029757, 1.0543518676422536, 0.7397086825221777, 2.333211600780487, 8.927487954497337, 27.205181680619717, 55.5674734711647, 47.131067365407944, 44.263775423169136, 55.38785330951214, 51.68143719434738, 45.053342655301094, 41.28331795334816, 43.47768120467663, 31.719546541571617, 40.50239145755768, 48.647068217396736, 60.360695868730545, 56.79120920598507, 38.80549371242523, 27.999568954110146, 26.367393136024475, 21.866990625858307, 17.12434731423855, 11.17006016895175, 6.353583969175816, 2.29127942584455, 0.394647060893476, 0.18882654811022803, 0.03173530334606767, 0.9175672230776399, 2.0120376348495483, 4.6837887447327375, 3.8773506553843617, 4.644423807039857, 7.716409815475345, 4.658455504104495, 10.165269635617733, 7.59975322522223, 10.236618407070637, 6.0140493884682655, 6.02007064037025, 3.3277654834091663, 3.9010490337386727, 2.489975276403129, 0.8986502350308001, 0.22576800256501883, 0.3547020902624354, 0.4123133816756308, 5.083687836304307, 16.043546609580517, 29.36350006610155, 35.58620385825634, 45.63976898789406, 16.091653928160667, 16.801909916102886, 28.709036484360695, 30.517551340162754, 13.98909755051136, 0.9458542114589363, 0.049890547306858934, 0.057128487242152914, 0.009466332030569902, 0.09751876874361187, 0.046574939478887245, 0.03078403700783383, 0.0256700866157189, 0.04626020207069814, 0.0583096486661816, 0.05716023260902148, 0.06021913155564107, 0.039786436755093746, 0.04143697689869441, 0.02170123112591682, 0.05796166675281711, 0.045980438371771015, 0.06254560867091641, 0.03311369051516522, 0.07176104190875776, 0.019811023666989058, 0.03671776001283433, 0.1012289579375647, 0.011406456342228921, 0.032690380612621084, 0.05233603893429972, 0.13336934032849967, 0.020097431442991365, 0.08666621710290201, 0.050174674834124744, 0.01747468711982947, 0.03795935452217236, 0.01653683510085102, 0.05274593080685008, 0.0382931391504826, 0.08770012529566884, 0.09520775798591785, 0.010096955320477718, 0.0601374582038261, 0.03258075055782683, 0.06056420796085149, 0.1610252953832969, 0.10919024323811755, 0.13306335284141824, 0.18309636652702466, 0.10004469804698601, 0.09971491730539128, 0.2379459037911147, 0.10886377247516066, 0.1736373530002311, 0.1302482234314084, 0.15137851849431172, 0.1425448534428142, 0.15258370694937184, 0.10334687671274878, 0.06607391231227666, 0.11544936831342056, 0.29369948082603514, 0.09771684053703211, 0.11366690770955756, 0.16855925205163658, 0.12232046836288646, 0.14519432064844295, 0.18003629869781435, 0.11342250363668427, 0.0809719406242948, 0.291804273147136, 0.08646194837638177, 0.14141407271381468, 0.09744626833708026, 0.10837449677637778, 0.1781590361497365, 0.18628973892191425, 0.22021277487510815, 0.07323533311136998, 0.15830826305318624, 0.18860305775888264, 0.11073266359744594, 0.10676624049665406, 0.13517871120711789, 0.1592562676523812, 0.08460681667202152, 0.18613510503200814, 0.18531525449361652, 0.12365145827061497, 0.14699508261401206, 0.3285389207303524, 0.33700011670589447, 0.25592449062969536, 0.14790048793656752, 5.102893905714154, 27.62233279645443, 49.22529079020023, 54.652151986956596, 41.54744938015938, 35.081207156181335, 33.805862590670586, 26.26535341143608, 35.458146929740906, 30.923038981854916, 17.091819159686565, 4.941309476271272, 1.2845496903173625, 1.4666669117286801, 4.319614861160517, 4.477264601737261, 8.831286616623402, 8.538080099970102, 4.571508094668388, 5.2980447839945555, 3.55652769561857, 1.564038349315524, 0.9039351576939225, 1.4233227563090622, 1.747272473294288, 0.9725629189051688, 0.8135933429002762, 1.52088881470263, 0.6263639708049595, 0.5303867615293711, 1.2782109179534018, 6.844044551253319, 21.709563173353672, 50.73702447116375, 54.376552775502205, 46.43891550600529, 52.09771625697613, 53.72559830546379, 46.20664916932583, 46.109780967235565, 49.47269931435585, 38.02091181278229, 45.24056240916252, 53.656761199235916, 65.3201973438263, 58.00603061914444, 35.42090132832527, 23.681856840848923, 22.428811378777027, 18.019651472568512, 14.97230714187026, 8.667030930519104, 5.259624095633626, 1.8379244464449584, 0.3731702867662534, 0.1313047151779756, 0.22353504347847775, 0.7059763488359749, 1.2538709677755833, 5.150797935202718, 5.152371050789952, 4.922787370160222, 10.0701854377985, 9.00309344753623, 22.499590180814266, 9.665512852370739, 17.384715043008327, 10.42791249230504, 9.308236073702574, 11.485120262950659, 6.003296440467238, 11.743511147797108, 3.5595575580373406, 2.5117868185043335, 1.2813355377875268, 1.118448965717107, 7.473143069073558, 19.629174806177616, 30.963590405881405, 44.2999342828989, 44.00149829685688, 18.469963409006596, 33.08493487536907, 36.51236996054649, 36.28432139754295, 15.819782316684723, 0.985352557618171, 0.18551925604697317, 0.2153419706155546, 0.09198803192703053, 0.13638262316817418, 0.12215497685247101, 0.09701977833174169, 0.09441153742955066, 0.2557401411468163, 0.15916124306386337, 0.14999796054325998, 0.11746084826881997, 0.09554107135045342, 0.1603956424514763, 0.10976476944051683, 0.16152400377904996, 0.05419229499239009, 0.09552373478072695, 0.0909368168504443, 0.0785286643076688, 0.1048978540347889, 0.1266647336888127, 0.22591174172703177, 0.09235146164428443, 0.09529717193800025, 0.18861747026676312, 0.18993577687069774, 0.09098259994061664, 0.1755304232938215, 0.08569707613787614, 0.1081556077406276, 0.10607516742311418, 0.17841972294263542, 0.15442061150679365, 0.21173493994865566, 0.17636277159908786, 0.18031081912340596, 0.25051441218238324, 0.12882426468422636, 0.10190535133006051, 0.155498803651426], [0.09164756425889209, 0.08421255071880296, 0.06458284857217222, 0.03586391168937553, 0.12192235808470286, 0.04364108128356747, 0.021089347064844333, 0.046720611935597844, 0.01676910134847276, 0.0428642010956537, 0.020931868893967476, 0.10751882276963443, 0.043963885837001726, 0.0654280954040587, 0.03780069077038206, 0.03358564819791354, 0.07751541750621982, 0.034397617127979174, 0.024846519772836473, 0.06643903412623331, 0.05068576967460103, 0.0374278914387105, 0.012317221826378955, 0.038524217961821705, 0.003291387374702026, 0.045374059191090055, 0.05509205257112626, 0.018079353794746567, 0.0672585358552169, 0.09315242452430539, 0.06891359196742997, 0.05177582133910619, 0.03116319654509425, 0.009748966913321055, 0.024885436141630635, 0.016730006864236202, 0.01604814940947108, 0.06731631947332062, 0.041215327073587105, 0.03879613344906829, 0.09396221896167845, 0.01988906235055765, 0.004741895991173806, 0.015731230087112635, 0.06825144781032577, 0.0967306004895363, 0.024405557887803297, 0.07872147427406162, 0.07286123873200268, 0.029609931552840862, 0.9006131859496236, 9.727234840393066, 29.423189163208008, 38.493332862854004, 39.26840007305145, 28.558988235890865, 20.422021262347698, 18.201885893940926, 20.49144733697176, 24.97512884438038, 22.60609846562147, 9.602994807064533, 3.7827692180871964, 0.5702523817308247, 0.6686751754023135, 0.5088541482109576, 0.511004535946995, 2.4372673546895385, 2.465855833142996, 1.003395295701921, 1.9368895422667265, 2.036292920820415, 1.0189282684586942, 2.064637024886906, 0.7963062892667949, 1.2666042032651603, 2.1416724286973476, 0.6910248636268079, 0.331988274701871, 0.34024282707832754, 0.11725839780410752, 1.1356780724599957, 5.852043656632304, 10.640528183430433, 12.767489701509476, 13.462217822670937, 9.678245019167662, 2.586214137263596, 5.706406021490693, 17.549276612699032, 21.82722005993128, 14.372515976428986, 24.792797528207302, 18.81269171833992, 8.215108830481768, 2.772372323088348, 1.7655377369374037, 0.9023334842640907, 0.28598645876627415, 0.07923778641270474, 0.025621537170081865, 0.019187072284694295, 0.08697224169736728, 0.08622558176284656, 0.5975811090320349, 0.183477578102611, 0.7066930853761733, 1.9661754020489752, 3.4872305765748024, 4.12370877340436, 4.270367128774524, 7.501586442813277, 5.118358600884676, 8.787772301584482, 5.283001866191626, 6.54950050637126, 4.895273046568036, 2.511587804183364, 2.671301309019327, 7.1031212992966175, 3.870428614318371, 1.2277616187930107, 0.5503406783100218, 5.01190303824842, 14.833494890481234, 27.861689552664757, 26.05859700590372, 29.166547134518623, 33.82774941623211, 14.310189820826054, 27.414508648216724, 32.85638853907585, 26.754297874867916, 7.27500032633543, 0.1303436339367181, 0.08644475281471387, 0.037095991865498945, 0.0360961927799508, 0.02852385408914415, 0.055486214623670094, 0.07964610122144222, 0.022360681286954787, 0.013978460956423078, 0.009554028838465456, 0.03599675983423367, 0.053172005209489726, 0.04043866952997632, 0.10060879707452841, 0.032783679707790725, 0.03740763080713805, 0.03343878830492031, 0.0363967662997311, 0.02075204836728517, 0.06938990234630182, 0.031663485715398565, 0.028327552317932714, 0.008243812571890885, 0.009090973217098508, 0.11326563588227145, 0.02229537600214826, 0.04809628284419887, 0.13487095740856603, 0.043419635549071245, 0.07656241083168425, 0.054180747174541466, 0.04493935361097101, 0.022288965701591223, 0.01649939931667177, 0.019084555715380702, 0.025014903803821653, 0.0267016997167957, 0.04442979501618538, 0.02726290993450675, 0.04732506153231952, 0.010166361898882315, 0.07895346963778138, 0.06393030780600384, 0.04732559958938509, 0.02481060910213273, 0.043618534837150946, 0.041952932806452736, 0.03016590406332398, 0.10746205589384772, 0.047351355824503116, 0.04820176800421905, 0.05606704165984411, 0.04654971387935802, 0.019005672838829923, 0.010022617170761805, 0.036121770899626426, 0.03529659174091648, 0.03217818739358336, 0.04851105433772318, 0.03882339253323153, 0.029939239175291732, 0.05085224453068804, 0.06696080105029978, 0.015824117290321738, 0.07634219335159287, 0.016516798968950752, 0.06748307263478637, 0.02818897850374924, 0.04877263541857246, 0.05681884467776399, 0.058750254320329987, 0.02850841556210071, 0.07733532052952796, 0.0127738374612818, 0.08480641728965566, 0.050267550905118696, 0.02175276771595236, 0.027995316922897473, 0.0059625795620377176, 0.03597787217586301, 0.06892919191159308, 0.051234632410341874, 0.07513537959312089, 0.035773354829871096, 0.015292994667106541, 0.056520638609072194, 0.08681835737661459, 0.04865937626163941, 0.014490802604996134, 0.04661780592869036, 0.0752016385376919, 0.04144943013670854, 3.1415346264839172, 18.45469392836094, 36.26057267189026, 42.74125412106514, 38.18241834640503, 28.6210161074996, 18.606822565197945, 21.527237556874752, 33.00504796206951, 39.91360925137997, 24.47780203074217, 10.211574900895357, 2.3031799122691154, 0.4050111828837544, 0.7734761049505323, 0.6837509258184582, 0.390074867173098, 1.07651132857427, 3.2583189848810434, 2.2128485469147563, 1.9244582718238235, 4.393000323325396, 2.7091878885403275, 3.288089674897492, 3.4219002071768045, 2.375241620466113, 5.016794800758362, 2.3993971617892385, 1.7671522940509021, 1.1132739996537566, 0.583378718001768, 3.383704419247806, 12.908004261553288, 17.158587276935577, 16.78728260099888, 18.980492614209652, 15.56965883821249, 5.931671233847737, 10.649506151676178, 25.662443563342094, 27.4945380538702, 22.98796657472849, 34.03082571923733, 28.384165316820145, 13.568147588521242, 4.149068612605333, 2.4305013427510858, 1.3360201846808195, 1.0173646523617208, 0.3181890182895586, 0.2549654577160254, 0.08834806474624202, 0.023788677317497786, 0.6282143527641892, 1.8579676584340632, 0.8730779041070491, 3.626620634458959, 3.862462341785431, 6.77867665886879, 4.716182481497526, 5.5152530036866665, 11.310995556414127, 6.940919402986765, 7.284567262977362, 7.602365110069513, 2.3674083407968283, 4.172652522101998, 2.1069722156971693, 1.672532621305436, 0.6348499248269945, 0.6072866194881499, 0.015059887009556405, 0.3113907971419394, 2.5367246428504586, 13.25716657564044, 30.49076657742262, 34.764258563518524, 27.475360482931137, 37.21472427248955, 20.305120535194874, 21.1920328438282, 35.88929079473019, 31.052068658173084, 11.405153553932905, 0.5501058034133166, 0.05830926646012813, 0.026451646044733934, 0.06849377386970446, 0.012544030505523551, 0.007729924009254319, 0.06146938321762718, 0.02984643360832706, 0.04120820987736806, 0.03929026279365644, 0.048985776520567015, 0.022501874882436823, 0.0285319880276802, 0.06380282909958623, 0.006010486586092156, 0.02339103459235048, 0.03117146778095048, 0.03724736401636619, 0.014987862505222438, 0.0650063477223739, 0.04466372738534119, 0.06959503196412697, 0.0023459139629267156, 0.01329262744548032, 0.04608725939760916, 0.09261111685191281, 0.031167456472758204, 0.03806244254519697, 0.006108831821620697, 0.009545912525936728, 0.06186478094605263, 0.041553427290637046, 0.050961993329110555, 0.02611251980852103, 0.019346446642884985, 0.07563785809907131, 0.04086599074071273, 0.03206520283129066, 0.0641645815630909, 0.01233829696502653, 0.05525244923774153, 0.03146549184748437, 0.19006412388989702, 0.19607114139944315, 0.13073260837700218, 0.1530911133158952, 0.17533210659166798, 0.18185715802246705, 0.2499334589811042, 0.12384569316054694, 0.0562241357692983, 0.1273329634568654, 0.1406040185247548, 0.18972708494402468, 0.18569542706245556, 0.1522070076316595, 0.1130075688706711, 0.1426234914106317, 0.11189976503374055, 0.10193179405177943, 0.09599251236068085, 0.28814699908252805, 0.09907678904710338, 0.14090622105868533, 0.13108909159200266, 0.1283793174661696, 0.11833126132842153, 0.2452844232902862, 0.16812487301649526, 0.16391162644140422, 0.1792644799570553, 0.11443198032793589, 0.13927775609772652, 0.10117599827935919, 0.22205282613867894, 0.09943282697349787, 0.1634635918890126, 0.12963933579158038, 0.16642667585983872, 0.21660414116922766, 0.11826698391814716, 0.09937794515280984, 0.1437423235620372, 0.1130880622076802, 0.08953694079536945, 0.20503888285020366, 0.1637546473648399, 0.15262626169715077, 0.12431196228135377, 0.17662834172369912, 0.18009823834290728, 0.14135912409983575, 2.114896452985704, 17.03172918409109, 42.556865215301514, 53.75194229185581, 51.56967379152775, 38.871731758117676, 31.825441159307957, 25.115134231746197, 28.05554375052452, 34.97322075068951, 28.907636627554893, 12.63509625568986, 4.639428025111556, 1.0889969835989177, 1.3551342277787626, 1.9263042602688074, 4.711723895743489, 7.1165084559470415, 7.760093696415424, 5.8892284613102674, 6.662217183038592, 5.623448872938752, 3.3940816624090075, 5.81802835687995, 3.2305600494146347, 3.1050268979743123, 5.232549123466015, 2.81941213645041, 1.3341483101248741, 1.068183125462383, 0.6491663097403944, 3.175587924197316, 10.96749683842063, 12.25398050621152, 14.68199796974659, 16.488930210471153, 12.689516935497522, 4.234771113842726, 9.693271312862635, 24.75835807621479, 28.114664778113365, 21.81004498153925, 35.47817945480347, 24.70384430140257, 10.168908890336752, 3.0029703117907047, 1.8975604651495814, 1.018393209669739, 0.7562319771386683, 0.2137791263521649, 0.25665316090453416, 0.18111205659806728, 0.1394148010876961, 0.3725823573768139, 1.5256542339920998, 0.8585636923089623, 2.240008539520204, 4.894997086375952, 9.718861039727926, 8.698996715247631, 14.04704064130783, 20.44408667832613, 11.614416874945164, 17.777971141040325, 13.195514883846045, 14.916943162679672, 10.051735527813435, 9.170002341270447, 7.8208386618644, 12.222026120871305, 5.867487452924252, 2.012963122688234, 0.8020119206048548, 6.8489600624889135, 18.51326398551464, 35.24879716336727, 36.49111770093441, 36.51936538517475, 45.26920147240162, 22.60100483894348, 36.267214715480804, 42.76140823960304, 36.68908707797527, 10.911602787673473, 0.4434888088144362, 0.22994765953626484, 0.12069705742760561, 0.1523242669645697, 0.08798378898063675, 0.0956397844129242, 0.19614140794146806, 0.10601029629469849, 0.1566129454295151, 0.11000944810803048, 0.18381607165792957, 0.09307564192567952, 0.1604467912693508, 0.17906684603076428, 0.09613968766643666, 0.12449979985831305, 0.15102158999070525, 0.19837530213408172, 0.1087207903037779, 0.1937416140572168, 0.11200004402780905, 0.18133823352400213, 0.06583988346392289, 0.08389496346353553, 0.20286400424083695, 0.18801748839905486, 0.09909842265187763, 0.20395381841808558, 0.3036538482410833, 0.1770348456921056, 0.17941483907634392, 0.12344488146482036, 0.14956760394852608, 0.07975219123181887, 0.1312354431138374, 0.14802769204834476, 0.11847439192933962, 0.14930798584828153, 0.21112226735567674, 0.10332824138458818, 0.11906022104085423, 0.16994105681078508], [0.04319613777624909, 0.02392936254182132, 0.029342559864744544, 0.07840506703360006, 0.06328498813672923, 0.026431682272232138, 0.05636151101498399, 0.03607973565522116, 0.020096550142625347, 0.016123505229188595, 0.04080994003743399, 0.04047004011226818, 0.03008588570082793, 0.057735129885259084, 0.011677432084979955, 0.047106176207307726, 0.015535793845629087, 0.02062187937553972, 0.05226933099038433, 0.02861766526621068, 0.01394672764945426, 0.026762754350784235, 0.03774634329602122, 0.07858796932850964, 0.016229747379838955, 0.004864238571826718, 0.08627946910564788, 0.0458396158501273, 0.031122693835641257, 0.007748703592369566, 0.04917867925541941, 0.0037339845357564627, 0.04497252019064035, 0.03280116099631414, 0.06605558126466349, 0.07530999951995909, 0.02205882570706308, 0.016290557105094194, 0.048042113485280424, 0.013117168891767506, 0.010815983241627691, 0.027525789773790166, 0.04400054422148969, 0.025556100154062733, 0.01832014360843459, 0.019103927625110373, 0.06711748326779343, 0.08299953260575421, 0.03788171103224158, 0.05606550912489183, 0.1023582395282574, 0.29819318500813097, 6.942241732031107, 20.800661444664, 37.97429211437702, 37.10484556853771, 29.343644231557846, 22.448773607611656, 16.179178431630135, 12.922844365239143, 26.499527245759964, 29.80401612818241, 21.64623387157917, 11.175519526004791, 4.415757777169347, 0.7143937284126878, 0.12289420046727173, 1.5053920587524772, 2.32572790235281, 1.557749449275434, 2.208715081214905, 2.2356917336583138, 3.461955045349896, 2.359939366579056, 4.115671729668975, 1.7911718739196658, 4.865529192611575, 2.169843167066574, 2.370669753290713, 1.7412205855362117, 0.5740505747962743, 1.2701438320800662, 0.9438169270288199, 0.5890531791374087, 0.2898565214127302, 0.04135570059588645, 0.3032784996321425, 0.08078681930783205, 0.16899452166398987, 1.4220924535766244, 2.50950931571424, 1.2330442853271961, 1.9263476016931236, 0.44466264895163476, 0.16341226495569572, 0.052105275535723194, 0.105023187934421, 0.07680829919991083, 0.04842402267968282, 0.17920313403010368, 0.341749238432385, 0.535969315096736, 0.18408949370495975, 0.2630633278749883, 2.150876009836793, 0.1827416941523552, 6.212224904447794, 7.469625407829881, 5.7364619337022305, 3.352850074879825, 3.3982379268854856, 6.490140566602349, 3.3216668106615543, 4.901603981852531, 7.728682206943631, 2.608613222837448, 5.36229363642633, 3.2611678820103407, 1.0412904247641563, 0.9695317503064871, 0.7234110007993877, 2.683984790928662, 10.389981027692556, 24.241029135882854, 30.925712138414383, 28.53172279894352, 29.327411502599716, 32.36345238983631, 22.0187658816576, 23.435255773365498, 33.30806650221348, 15.832352992147207, 1.7050725314766169, 0.08730667570489459, 0.11339122953359038, 0.012846915815316606, 0.10988824054948054, 0.04581476503517479, 0.05512756062671542, 0.05471212120028213, 0.026458347638254054, 0.0603693348239176, 0.027528726823220495, 0.03179420389642473, 0.10236803587758914, 0.047415744556928985, 0.06810399048845284, 0.0180303238084889, 0.023116128249967005, 0.012339222794253146, 0.02526080330426339, 0.023004525937722065, 0.034219906156067736, 0.053455524175660685, 0.06534121217555366, 0.08240897601353936, 0.014148486989142839, 0.03793225871049799, 0.008450646346318536, 0.04395133983052801, 0.07641667529242113, 0.042547155608190224, 0.05670844278938603, 0.036720253629027866, 0.03817960539890919, 0.02151768872863613, 0.07006065541645512, 0.005823614728797111, 0.03778755104576703, 0.04544812923995778, 0.03288145766418893, 0.05377848458010703, 0.10284162999596447, 0.016799395816633478, 0.04094189760508016, 0.022410286437661853, 0.016814687769510783, 0.01683832331764279, 0.010021644029620802, 0.03182451691827737, 0.048830073938006535, 0.09206923772580922, 0.07305192615604028, 0.018600393414089922, 0.025437799959036056, 0.009831171828409424, 0.02167367889342131, 0.04204348966595717, 0.014800618646404473, 0.03525602965964936, 0.006780402645745198, 0.07539284546510316, 0.043942860793322325, 0.032961405522655696, 0.040792458748910576, 0.028091705207771156, 0.09997834262321703, 0.020501426952250767, 0.03333648324769456, 0.02315304082003422, 0.07091204723110422, 0.02422301553451689, 0.03343382333696354, 0.04088513815077022, 0.03609956584114116, 0.05968912308162544, 0.015171162776823621, 0.013633084909088211, 0.02157900311431149, 0.03499748025205918, 0.015618885627191048, 0.04967800734448247, 0.02765113295026822, 0.009630148142605321, 0.05642165466269944, 0.005951245575488429, 0.004915738054478425, 0.0763919617747888, 0.050990072486456484, 0.031197042189887725, 0.06202735581609886, 0.03072771356528392, 0.12869940575910732, 0.06761277778423391, 0.032936261559370905, 0.029384650770225562, 0.11263742271694355, 0.9548049280419946, 12.47942240908742, 30.63911821693182, 44.775961339473724, 39.78753961622715, 30.148862823843956, 18.216019235551357, 11.796483155339956, 20.178262442350388, 37.33870401978493, 37.45197594165802, 23.709044381976128, 8.722524102777243, 3.3666267106309533, 0.36459871858824044, 0.1630674779880792, 0.6308416742831469, 0.16989462805213407, 0.8238922746386379, 0.6407881749328226, 2.3975974833592772, 2.7339057996869087, 3.0397663498297334, 3.313925676047802, 4.213614324107766, 6.280574211850762, 4.307611305266619, 4.717400316148996, 3.95351923070848, 1.4362468128092587, 2.232089526951313, 0.6562656944151968, 2.419050894677639, 0.6583613413386047, 0.22381446207873523, 0.32239696593023837, 0.16675365128321573, 0.17513607570435852, 2.456282959319651, 4.845888996496797, 2.4654960399493575, 4.129582783207297, 1.368315601721406, 0.2745437587145716, 0.4138781555229798, 0.4850924795027822, 0.7777938013896346, 0.47356701514218, 2.0002212189137936, 1.829245830886066, 3.6774868424981833, 1.6120000882074237, 2.180778980255127, 5.948541853576899, 4.480775138363242, 8.307891301810741, 8.96030679345131, 6.754786390811205, 5.904696956276894, 5.69869433529675, 4.652711637318134, 7.817890970036387, 3.8723843218758702, 3.152130120433867, 1.7627939279191196, 0.35393361118622124, 0.6468453467823565, 0.3154045989504084, 0.5690590676385909, 0.7354871684219688, 3.3732464304193854, 10.284430291503668, 26.431062519550323, 41.58346384763718, 37.08466865122318, 28.50000400096178, 30.320776998996735, 25.81126257777214, 24.580046944320202, 36.968615278601646, 25.23612353950739, 6.043523456901312, 0.22420042339945212, 0.07629523766809143, 0.04305213886254933, 0.00682475246321701, 0.05709829296392854, 0.0695533974794671, 0.025810725455812644, 0.030576896169804968, 0.03025171117769787, 0.0501279863237869, 0.06404556334018707, 0.015413632627314655, 0.031682614571764134, 0.05148568241565954, 0.025287284988735337, 0.014171436978358543, 0.03301601274870336, 0.03029598214197904, 0.0956522673368454, 0.03367112505657133, 0.018236716932733543, 0.09596117888577282, 0.0027730071951737045, 0.009524746474198764, 0.035053467872785404, 0.039575132468598895, 0.03855761460727081, 0.07875275579863228, 0.02530001467675902, 0.004300264781704755, 0.019039596409129445, 0.017641345657466445, 0.001805193167001562, 0.020630111648642924, 0.019342097657499835, 0.04602301909471862, 0.023263212642632425, 0.06368487956933677, 0.07713005732512102, 0.07773245117277838, 0.0549580355436774, 0.035510538073140197, 0.013412390599114588, 0.14190788293490186, 0.07469187956303358, 0.17534976970637217, 0.2302102165413089, 0.1250984607031569, 0.26819863356649876, 0.1393422784167342, 0.11386532831238583, 0.10768159801955335, 0.0889969764102716, 0.13035818003118038, 0.1573759622988291, 0.12247315040440299, 0.10728327251854353, 0.11004708983819, 0.15037436300190166, 0.14056248794076964, 0.17481521557783708, 0.1374418757040985, 0.1440208961139433, 0.23110463807825, 0.12530056235846132, 0.2333983642165549, 0.1991259102942422, 0.10811927219037898, 0.21092166483867913, 0.24356209149118513, 0.10610886834911071, 0.12063917733030394, 0.21383137354860082, 0.09736983454786241, 0.16974679223494604, 0.08801108517218381, 0.13172281149309129, 0.09693972286186181, 0.1702506362926215, 0.13232368393801153, 0.09407668781932443, 0.1052563707344234, 0.06931251860805787, 0.07425943011185154, 0.20407796488143504, 0.10880406669457443, 0.07172355602961034, 0.24436476873233914, 0.1628699479624629, 0.23991946742171422, 0.20111431687837467, 0.1656221432494931, 0.14770622336072847, 0.2162367186974734, 0.611687139607966, 10.837214179337025, 30.10310757905245, 53.23045827448368, 48.38234022259712, 41.887873113155365, 32.083133831620216, 24.12836328148842, 20.66568698734045, 34.33773525059223, 38.11072759330273, 28.15635234117508, 13.914804887026548, 6.503266012296081, 1.2029711552895606, 0.6541997927706689, 3.8491502311080694, 6.054946593940258, 4.558639610186219, 7.013735845685005, 8.423970323055983, 7.651911601424217, 8.921159394085407, 8.09716695919633, 5.587761187925935, 11.33407361805439, 7.657446479424834, 6.4297993294894695, 5.245913006365299, 2.8172738011926413, 4.380974443629384, 2.3988730274140835, 2.9855508590117097, 0.5913651769515127, 0.14585892873583362, 0.7018017978407443, 0.16072254366008565, 0.43515422323253006, 2.063357918523252, 3.8713745260611176, 2.9316854244098067, 3.5171876940876245, 1.0909310798160732, 0.37624708260409534, 0.45664925419259816, 0.3748630662448704, 0.4424927575746551, 0.3231831674929708, 1.3700060360133648, 1.46223658695817, 1.9578135944902897, 1.2903605285100639, 1.626524452585727, 8.564707171171904, 5.560968825593591, 14.886507745832205, 19.013288654386997, 15.671574119478464, 10.524426363408566, 11.184998117387295, 15.221306830644608, 10.590277779847383, 13.316438645124435, 14.713097400963306, 7.548195216804743, 10.6580575928092, 7.16082357801497, 3.0149254202842712, 1.9409910659305751, 1.4136508502997458, 3.6818031733855605, 14.45397125557065, 29.916510991752148, 40.53369037806988, 36.97422757744789, 39.10194620490074, 44.73659165203571, 33.40184926986694, 35.62483638525009, 44.74039524793625, 27.265875823795795, 5.1635918486863375, 0.2657210477627814, 0.18278322473634034, 0.1051483437186107, 0.1587716452195309, 0.11243832675972953, 0.16470101923914626, 0.09361090109450743, 0.11170647267135791, 0.1739045706926845, 0.12677759950747713, 0.12870982551248744, 0.1566411618841812, 0.16757575795054436, 0.11460921261459589, 0.11117836038465612, 0.06323693407466635, 0.15031742543214932, 0.09272663213778287, 0.20010612410260364, 0.06251466111280024, 0.12700349441729486, 0.1876779113081284, 0.13151094317436218, 0.08483409939799458, 0.16186331369681284, 0.09065024394658394, 0.13264813605928794, 0.21927155350567773, 0.13851114723365754, 0.11095648049376905, 0.23599545063916594, 0.12946690520038828, 0.09147082178969868, 0.11449567886302248, 0.07821554478141479, 0.1733929934562184, 0.09021245845360681, 0.12229258587467484, 0.15028919413452968, 0.19837482715956867, 0.10172910609981045, 0.12296748012886383, 0.10591959100565873], [0.030588679619540926, 0.03090232792601455, 0.03189364797435701, 0.019217760091123637, 0.06102485160226934, 0.06539233130752109, 0.016598570655332878, 0.0338866744277766, 0.07434740429744124, 0.04000031258328818, 0.005198736589591135, 0.05315169633831829, 0.04972596492734738, 0.019995287802885287, 0.006858739579911344, 0.03303525663795881, 0.09626942250179127, 0.03179582919983659, 0.03506520122755319, 0.019452365959296003, 0.018828704014595132, 0.09516650941804983, 0.05266439475235529, 0.017906802604557015, 0.006654257949776365, 0.06179744588735048, 0.03400154775590636, 0.036865592119283974, 0.15469020407181233, 0.05913423781748861, 0.02770230217720382, 0.00907832887605764, 0.045834431948605925, 0.018728245049715042, 0.0184149770939257, 0.017900182647281326, 0.037437762002809905, 0.022318026349239517, 0.06528657526359893, 0.029887615382904187, 0.004487255846470362, 0.05187749928154517, 0.08671560703078285, 0.08188770632841624, 0.042720532437670045, 0.05268744585919194, 0.013836625403200742, 0.016223034654103685, 0.05087070545414463, 0.0243187562955427, 0.05898242037801538, 0.04522552575508598, 0.049493706101202406, 1.8896108167245984, 14.643027260899544, 35.15731707215309, 37.672801092267036, 36.57982014119625, 27.355486415326595, 23.193786330521107, 13.975926507264376, 22.275157123804092, 30.695548988878727, 30.797873698174953, 22.554284445941448, 13.713894467800856, 4.458904936909676, 1.5289086406119168, 0.693792540114373, 0.9964960534125566, 0.04910654992272612, 2.6145530166104436, 0.877132227178663, 2.031516102142632, 3.3947278652340174, 3.436931250616908, 5.174549035727978, 3.4024162776768208, 3.7477519595995545, 3.1119256652891636, 1.2709160218946636, 0.4487298260210082, 1.4199480623938143, 8.5479187220335, 4.530565766617656, 0.21184443641686812, 0.047565688073518686, 0.37769468617625535, 0.17546756338560954, 0.07734427825198509, 0.060551624846993946, 0.2634549740469083, 0.025187722167174798, 0.0395793589996174, 0.12552880245493725, 0.16807961685117334, 0.37416491308249533, 0.7964373228605837, 0.3706316667376086, 4.114453895017505, 1.3774792850017548, 3.683477221056819, 2.3066353518515825, 3.5320608085021377, 4.679086022078991, 2.812211997807026, 5.0151699129492044, 3.426035810261965, 4.266115156933665, 3.8934211805462837, 2.844646107405424, 3.4144768305122852, 8.938727751374245, 2.901761792600155, 1.955336721148342, 0.9037758631166071, 0.4335333133349195, 0.12675573583692312, 1.0772246215492487, 3.443297571502626, 9.838618263602257, 21.74921404570341, 26.142542101442814, 28.33734042942524, 24.137270003557205, 18.263165205717087, 27.902590557932854, 28.460398726165295, 26.151557117700577, 28.216685503721237, 14.791783578693867, 0.4249676823383197, 0.09637198731070384, 0.034635304764378816, 0.041483275781502016, 0.06643875211011618, 0.027734184841392562, 0.07451207202393562, 0.007179339954745956, 0.06253293278859928, 0.045542671432485804, 0.057473311317153275, 0.017109992040786892, 0.03984425376984291, 0.04570511642668862, 0.01826240822992986, 0.02750058087258367, 0.03110076708253473, 0.04666871725930832, 0.057354122400283813, 0.0843922320927959, 0.052764488209504634, 0.03855578150250949, 0.018708292409428395, 0.040541597991250455, 0.034362650840193965, 0.047736125998198986, 0.026099595306732226, 0.020127714778936934, 0.016182262916117907, 0.08052855933783576, 0.08028510521398857, 0.027660458035825286, 0.03341542178532109, 0.07941225791000761, 0.0434336769831134, 0.02718637595535256, 0.05553639493882656, 0.05332983775588218, 0.0453055515390588, 0.05914222703722771, 0.01085699617760838, 0.03267874373705126, 0.07635646485141478, 0.009032422403834062, 0.0701840003603138, 0.050253962181159295, 0.014054090443096356, 0.03181990447046701, 0.020114680810365826, 0.026595635681587737, 0.038984820785117336, 0.028871123540739063, 0.020328899881860707, 0.10307085714885034, 0.07021508150501177, 0.04995063158276025, 0.02285497019329341, 0.05934943095780909, 0.028058160132786725, 0.008595521921961335, 0.040718655873206444, 0.0404716728371568, 0.09379643059219234, 0.042014178543468006, 0.03805093183473218, 0.06283422248088755, 0.0469050467654597, 0.05497088211996015, 0.05087316567369271, 0.06108900655817706, 0.04317080456530675, 0.0449293086421676, 0.05158152707736008, 0.04949748734361492, 0.05129047902300954, 0.049736521978047676, 0.0520555887487717, 0.015432410818903008, 0.046764517392148264, 0.04981208374374546, 0.023489224440709222, 0.007312772540899459, 0.02906321176851634, 0.044988762092543766, 0.03335733759740833, 0.044910680735483766, 0.05406320582551416, 0.04072670446475968, 0.03405348696105648, 0.04597276827553287, 0.06481673641246744, 0.03711365498020314, 0.06634487785049714, 0.06195113353896886, 0.014821685435890686, 0.08799092101980932, 0.049790765551733784, 0.16133362805703655, 5.048134094104171, 22.71212797611952, 41.12460047006607, 41.265914887189865, 35.26445612311363, 25.25565069168806, 16.031683646142483, 14.821713622659445, 30.795569121837616, 40.58352470397949, 38.84213514626026, 24.76854532957077, 15.140016842633486, 4.428882272914052, 0.8412883942946792, 0.3784101759083569, 0.05078918795334175, 0.2823720214655623, 0.7991154072806239, 0.8907525369431823, 1.389614527579397, 2.5994148664176464, 2.9248151555657387, 2.8337582666426897, 3.0612356727942824, 3.8601969508454204, 3.4059693245217204, 3.494809032417834, 2.0642784191295505, 1.8413028214126825, 12.041319217532873, 4.120068568736315, 0.6513276812620461, 0.6141562946140766, 0.8880470821168274, 0.38900602608919144, 0.2523424703394994, 0.47805445559788495, 0.20156609185505658, 0.1914086876786314, 0.0719777267659083, 0.2523077081423253, 0.64200927503407, 0.853505035629496, 2.6148968981578946, 2.5514322286471725, 3.040708936750889, 4.648604057729244, 7.951235789805651, 5.262370398268104, 7.214230662211776, 6.786543186753988, 6.846468821167946, 6.996210236102343, 3.9704304607585073, 4.126506373286247, 1.4505950803868473, 2.8195653157308698, 1.0306762880645692, 0.9673410491086543, 1.112387697212398, 0.6855685345362872, 0.32083204365335405, 0.20908670470817015, 0.5738067941274494, 0.9059731545858085, 2.908632061444223, 11.584508679807186, 25.455987341701984, 30.65572712570429, 39.770831912755966, 29.593849405646324, 18.802278377115726, 27.214597575366497, 33.8307436555624, 29.10344772040844, 33.21906767785549, 22.00502011924982, 2.3160780826583505, 0.057783499360084534, 0.08520696923369542, 0.05811739159980789, 0.0672129679878708, 0.013346063933568075, 0.06126484731794335, 0.020018960458401125, 0.04732810062705539, 0.02772058498521801, 0.09390162260388024, 0.04886488808551803, 0.08609396187239327, 0.0332805030484451, 0.06337738552247174, 0.015321452319767559, 0.050560398667585105, 0.05870470871741418, 0.04251021149684675, 0.04049218579893932, 0.07623025521752425, 0.09298330391175114, 0.03914036751666572, 0.06785321878851391, 0.06802561227232218, 0.036797244029003195, 0.024352971158805303, 0.0212842925611767, 0.010151095921173692, 0.0701826496515423, 0.018499066136428155, 0.025676138830021955, 0.008391599221795332, 0.07605192455230281, 0.026288115659554023, 0.02184431163186673, 0.057127229301841, 0.016798327123979107, 0.03887842649419326, 0.026944864403048996, 0.030027159555174876, 0.04360757702670526, 0.02687245862034615, 0.04679097495682072, 0.026101164949068334, 0.19376294338144362, 0.09821503685088828, 0.13945867685833946, 0.09592531831003726, 0.1624656407511793, 0.09752322162967175, 0.15359188488218933, 0.11161250935401767, 0.17829101969255134, 0.11866886430652812, 0.09587805092451163, 0.14287518337368965, 0.14568893238902092, 0.10424287160276435, 0.16724896064260975, 0.14303743169875816, 0.1821828866377473, 0.21532306069275364, 0.21861758781597018, 0.13326313899597153, 0.09022868922329508, 0.20796278142370284, 0.24709183489903808, 0.09928080544341356, 0.14535039430484176, 0.16584337747190148, 0.16002194141037762, 0.09743636066559702, 0.3573913365835324, 0.17128422536188737, 0.13830879324814305, 0.1381360212690197, 0.23953675670782104, 0.1308486209018156, 0.1142777620407287, 0.11357194249285385, 0.1517866106587462, 0.12364466019789688, 0.19425421545747668, 0.15125460951821879, 0.07862707308959216, 0.10792572749778628, 0.10097174439579248, 0.1790710465866141, 0.08995082171168178, 0.28192141908220947, 0.15176410874119028, 0.21978007309371606, 0.16103233094327152, 0.09288432367611676, 0.15798207430634648, 0.13002289255382493, 0.14906637225067243, 3.8061192026361823, 20.96765488386154, 49.42619360983372, 51.540301367640495, 49.87393878400326, 39.32895362377167, 32.75043502449989, 21.079754568636417, 31.198645792901516, 40.74680954217911, 39.11567486822605, 27.80580025166273, 18.02678558975458, 6.426102602854371, 2.228321316652, 1.3238516938872635, 2.020600475370884, 2.3224790766835213, 5.983915580436587, 5.042038271203637, 6.091405637562275, 12.95528132468462, 10.164354834705591, 13.815164733678102, 8.987174201756716, 12.779984381049871, 10.557323098182678, 4.760094350203872, 4.306026315316558, 3.163952948525548, 20.23541707545519, 6.263612871989608, 0.27543329691980034, 0.25866375770419836, 0.6822167581412941, 0.4363461124012247, 0.19305122375953943, 0.552225555293262, 0.22392039623809978, 0.16060893569374457, 0.18210016685770825, 0.2309409054578282, 0.49945748993195593, 1.4684719336219132, 2.5781155843287706, 2.1853617718443274, 7.894906662404537, 4.915762497112155, 8.35363894701004, 6.89199797809124, 11.052544824779034, 9.641672931611538, 11.92582156509161, 13.601254262030125, 9.152940306812525, 14.089719951152802, 12.986347507685423, 11.411995086818933, 10.351540390402079, 15.498761292546988, 7.511925213038921, 6.278941249474883, 3.0005937768146396, 1.5930727100931108, 0.5825479875784367, 1.7609118414111435, 4.2612875159829855, 12.742392998188734, 28.20222157984972, 32.79967658221722, 37.80087701976299, 30.78675739467144, 27.63433825224638, 39.1579058021307, 39.904345348477364, 38.816129341721535, 41.36576592922211, 21.93902336061001, 2.0381536334753036, 0.23018758103717119, 0.2120324521092698, 0.18562486366136, 0.1700473768869415, 0.041807798406807706, 0.22999414766673, 0.1964451392996125, 0.119148224912351, 0.1308807113673538, 0.2351001533679664, 0.15932304610032588, 0.18119799729902297, 0.10853799933101982, 0.12949960422702134, 0.1777114172000438, 0.18376116757281125, 0.1887555097346194, 0.12425601918948814, 0.16526897001313046, 0.1427404538844712, 0.10959048348013312, 0.0955046244780533, 0.12187676053144969, 0.20195770834106952, 0.12054643855663016, 0.10494100992218591, 0.09934435554896481, 0.11314920775475912, 0.12873967469204217, 0.17464974633185193, 0.16308251390000805, 0.09160742891253904, 0.17230133875273168, 0.15280117106158286, 0.07053553345031105, 0.1565393540658988, 0.14921024499926716, 0.26641652919352055, 0.13052373833488673, 0.10719689395045862, 0.11706126111675985, 0.23795903980499133, 0.1135033235186711, 0.18879954877775162], [0.050750574009725824, 0.009204478210449452, 0.016339028625225183, 0.0038719173198842327, 0.012169199544587173, 0.020058136578882113, 0.03276561212260276, 0.02818691162246978, 0.02865803624445107, 0.047848060421529226, 0.020635577566281427, 0.026028200700238813, 0.03240785612433683, 0.025771998334676027, 0.08848018929711543, 0.06644146094913594, 0.03399240078579169, 0.03846422645437997, 0.05738584921346046, 0.12083634370355867, 0.019611189272836782, 0.01835887444030959, 0.056827512962627225, 0.04429449407325592, 0.023588058102177456, 0.04754714551381767, 0.03338516071380582, 0.054565550744882785, 0.03326754515001085, 0.06444276819820516, 0.017504211609775666, 0.029822245160175953, 0.08982053026556969, 0.10103830019943416, 0.015352629015978891, 0.03278172043792438, 0.03973565901105758, 0.07075107540003955, 0.04871453267696779, 0.021713960813940503, 0.0585781985137146, 0.03616112328018062, 0.029947310031275265, 0.04425153856573161, 0.04839479319343809, 0.02580982560175471, 0.014573811822629068, 0.04314204634283669, 0.0234965550043853, 0.052885031545883976, 0.031207899810397066, 0.04489236824156251, 0.01002376471660682, 0.1005139209155459, 0.8133943285793066, 8.841702807694674, 29.18918251991272, 41.269498094916344, 38.221499249339104, 32.10294596850872, 23.125011920928955, 19.903795570135117, 17.704994156956673, 16.072879135608673, 23.49540464580059, 22.846114486455917, 25.806465335190296, 18.6980252712965, 10.554781034588814, 4.4725376553833485, 0.816540737869218, 0.43023675272706896, 1.0312107531353831, 0.7003063405863941, 0.9454865218140185, 2.388582704588771, 2.9941913578659296, 3.451088578440249, 1.5618377923965454, 1.6441413760185242, 0.9369655977934599, 1.8025952484458685, 1.124388522002846, 2.619870356284082, 1.8039005971513689, 0.62732502236031, 1.1434482992626727, 0.9049986256286502, 0.39205423439852893, 0.7576186652295291, 0.28505191672593355, 0.15257014048984274, 0.1827175446669571, 0.3193074942100793, 0.48057152365799993, 1.3238629745319486, 1.1508328467607498, 4.621081184595823, 3.1113889440894127, 1.412638679612428, 6.103275725618005, 13.257051631808281, 3.4089915873482823, 4.642020436003804, 5.097919022664428, 4.87789467908442, 7.006951309740543, 4.699383582919836, 2.821740936487913, 1.5229455730877817, 2.1687906235456467, 0.7971552468370646, 1.9875712227076292, 1.2369405012577772, 0.9886721544899046, 1.608750787563622, 3.716650865972042, 7.19156582839787, 17.2570912912488, 27.059368304908276, 23.30582331866026, 24.86529763787985, 23.36934830993414, 26.00211303681135, 24.465777575969696, 27.782298512756824, 27.097216174006462, 27.986583150923252, 25.26365876197815, 11.62841722369194, 0.8538202405907214, 0.04461455268028658, 0.05480288586113602, 0.06885651338961907, 0.053279635176295415, 0.03189447917975485, 0.0067428444071993, 0.02336252870009048, 0.10728903900599107, 0.024360741444979794, 0.0828202223055996, 0.05092473751574289, 0.0893017319322098, 0.0516180184786208, 0.01950702142494265, 0.03834922696114518, 0.14399685052921996, 0.0671683500695508, 0.07159264860092662, 0.04926565154164564, 0.0355240154749481, 0.06606116963666864, 0.029712616960750893, 0.02229165969765745, 0.025145868748950306, 0.0819388625677675, 0.023984396502783056, 0.05713213118724525, 0.02818176111759385, 0.04945385648170486, 0.08086984336841851, 0.08409005182329565, 0.015157063826336525, 0.03175753437972162, 0.03979003617132548, 0.06534701577038504, 0.04997462150640786, 0.09926219980116002, 0.05642185504257213, 0.0007504463951590878, 0.008499029736412922, 0.06679133904981427, 0.03730630167410709, 0.019667954293254297, 0.04936717734381091, 0.03836058924207464, 0.032640612189425156, 0.06853448066976853, 0.01457480722820037, 0.033912593935383484, 0.010373781969974516, 0.05497878599271644, 0.06164666745462455, 0.019134823232889175, 0.04292090488888789, 0.0497094929596642, 0.02439023068291135, 0.06477249698946252, 0.04248094861395657, 0.005052076612628298, 0.022867091320222244, 0.027172223199158907, 0.037847917337785475, 0.02984909606311703, 0.0417614104662789, 0.019091819485765882, 0.018782996994559653, 0.045200177701190114, 0.028534819321066607, 0.05205522509641014, 0.15068532287841663, 0.008000683137652231, 0.019827805481327232, 0.009980411232390907, 0.05409438344941009, 0.10132745577720925, 0.013264192984934198, 0.051880419632652774, 0.07162875408539549, 0.07353292690822855, 0.025326646646135487, 0.04355541146651376, 0.0720300259126816, 0.03911399900971446, 0.031748313194839284, 0.06922844069777057, 0.0480406366114039, 0.05375163738790434, 0.021449335072247777, 0.1115609375119675, 0.02249591729196254, 0.00977204492301098, 0.03249311776016839, 0.06897970248246565, 0.03132888472464401, 0.07186551403719932, 0.008595495946792653, 0.059871661724173464, 0.026969776445184834, 0.1462501147761941, 2.569661275483668, 15.604489669203758, 37.08393149077892, 47.31459751725197, 40.51229752600193, 31.995993107557297, 17.230635210871696, 16.650892719626427, 23.7474375218153, 25.607650503516197, 32.664890214800835, 36.04766629636288, 32.69528478384018, 20.237334072589874, 8.369884975254536, 3.434576326981187, 0.5468297854531556, 0.1403582192142494, 0.35437272512353957, 0.2842706727096811, 0.26300330297090113, 0.9915042493958026, 0.904866048367694, 1.2319755926728249, 2.3930982872843742, 1.9836994679644704, 0.6909785536117852, 4.822724489495158, 3.744568917900324, 7.880980409681797, 3.2947025075554848, 1.8307865294627845, 2.897421712987125, 3.5880538914352655, 1.9388211448676884, 2.168666892684996, 0.9053999197203666, 1.3032122701406479, 0.38351998140569776, 1.0891944542527199, 1.6435625008307397, 3.0257351277396083, 3.1280845357105136, 6.328705754131079, 5.17824006266892, 5.230746120214462, 5.438067270442843, 7.46387061662972, 6.048445617780089, 5.041485400870442, 2.7812096988782287, 2.1487635606899858, 3.000126164406538, 0.8951317425817251, 1.1242924584075809, 0.14660716202342883, 1.0792914731428027, 0.2007206075359136, 0.6991175981238484, 0.22239304147660732, 0.2525468578096479, 0.44994273281190544, 3.08094569016248, 7.966184662654996, 15.421777423471212, 28.227057047188282, 32.339547872543335, 33.10669630765915, 29.46184068918228, 27.001978084445, 19.482673667371273, 24.732359871268272, 33.50245647132397, 34.297024235129356, 32.51886025071144, 18.733365274965763, 2.045240728184581, 0.15325152111472562, 0.040984470906550996, 0.013168614568712655, 0.034737966052489355, 0.019379670738999266, 0.056551144589320756, 0.014956464092392707, 0.05523021820408758, 0.04104293358977884, 0.06994650568231009, 0.05014383859816007, 0.0345683593332069, 0.0831920160271693, 0.03474584023933858, 0.03928201011149213, 0.06840346191893332, 0.024481911896145903, 0.056394625644315965, 0.002754054830802488, 0.12771166657330468, 0.03963698305597063, 0.025214331872120965, 0.003114146970801812, 0.014046908308955608, 0.06994230512646027, 0.05438571723061614, 0.033571937019587494, 0.024087100464385003, 0.027844436444866005, 0.04340810999565292, 0.012353329166217009, 0.07836917677195743, 0.06788061888073571, 0.05115754553116858, 0.019382444515940733, 0.09716542481328361, 0.04213657353830058, 0.03301299591839779, 0.08267330675153062, 0.0627976049145218, 0.04155533832090441, 0.016355097977793775, 0.054545802195207216, 0.03644239724962972, 0.005389762618506211, 0.14344731986057013, 0.21136578085133806, 0.18452719756169245, 0.09831196133745834, 0.12331232646829449, 0.09665106452303007, 0.15170064027188346, 0.1245093512989115, 0.1638915142393671, 0.11897245465661399, 0.09710616432130337, 0.10325175564503297, 0.1342922158073634, 0.14816631039138883, 0.11220318468986079, 0.16612797626294196, 0.25386467459611595, 0.09225294154020958, 0.1684840428060852, 0.26755617116577923, 0.07127374032279477, 0.10026527175796218, 0.12814386369427666, 0.16153595235664397, 0.19471753825200722, 0.0859042837691959, 0.10511772270547226, 0.11968042643275112, 0.12707447342108935, 0.16548348037758842, 0.0693275174126029, 0.12103894259780645, 0.25268641125876456, 0.20379819005029276, 0.11978829759755172, 0.1393761351937428, 0.13924247439717874, 0.14836048590950668, 0.13782886118860915, 0.11871493683429435, 0.16513287497218698, 0.1273773142020218, 0.19783899653702974, 0.21881759661482647, 0.10002718336181715, 0.19620594510342926, 0.11493106721900403, 0.26823924388736486, 0.14196084259310737, 0.2444293355802074, 0.10328265867428854, 0.1459157030330971, 0.21857954532606527, 0.2982345374766737, 1.954516083933413, 13.332274295389652, 41.957819759845734, 56.21444575488567, 54.76144552230835, 44.62099425494671, 33.08851808309555, 29.207527935504913, 28.92832461744547, 24.250445030629635, 32.79262416064739, 32.56215512752533, 34.619467332959175, 24.676381275057793, 13.441529832780361, 6.322320196777582, 1.0665233270265162, 0.911626301240176, 2.497484148479998, 3.232713108882308, 5.170145547017455, 7.543110139667988, 9.52942980453372, 9.186806939542294, 8.038628250360489, 6.457333602011204, 1.5523512451909482, 6.222941279411316, 7.454723082482815, 10.437358785420656, 5.2341322135180235, 2.2626213636249304, 3.7176200514659286, 3.6158168641850352, 1.5377755835652351, 2.59003150742501, 1.8012501206248999, 1.1005464638583362, 0.8003319951239973, 1.0791670298203826, 2.3713145311921835, 4.482598090544343, 5.007170392200351, 11.2687399238348, 8.67939356714487, 7.250226130709052, 15.458703842014074, 23.037578612565994, 12.646640036255121, 13.17102424800396, 15.786180719733238, 14.345151744782925, 11.965546533465385, 10.11900806799531, 8.548537138849497, 7.01327464543283, 6.7487898375838995, 2.1568965492770076, 4.061360293999314, 2.126387511380017, 1.2262251949869096, 1.9781889324076474, 4.640720905736089, 9.37659440562129, 21.59421656280756, 36.45643696188927, 29.50372204184532, 33.48064564168453, 34.50709216296673, 36.71043053269386, 34.1270137578249, 39.504245817661285, 38.825218454003334, 42.901407927274704, 38.88143643736839, 17.703377343714237, 1.3292539352551103, 0.20864570571575314, 0.1683399177272804, 0.3137812844943255, 0.11489799711853266, 0.153430393547751, 0.151008632092271, 0.12421358318533748, 0.08570271646021865, 0.15149392245803028, 0.17996580951148644, 0.13778500026091933, 0.14924758987035602, 0.18756911245873198, 0.14801025157794356, 0.09645046942750923, 0.19300982676213607, 0.11196689229109325, 0.2120786433806643, 0.13656072376761585, 0.16815528622828424, 0.2408706780988723, 0.1507544910418801, 0.17676387273240834, 0.10423513100249693, 0.1989995819167234, 0.16489682748215273, 0.12358272797428071, 0.0945740009774454, 0.1140236432547681, 0.16311567305820063, 0.16091440367745236, 0.2792681223945692, 0.20594673726009205, 0.15130914252949879, 0.12815386784495786, 0.18961828609462827, 0.17398121970472857, 0.14222167781554163, 0.17088014079490677, 0.1594343237229623, 0.1409597892779857, 0.1718460163101554, 0.13735492568230256, 0.14731500763446093, 0.11865834065247327], [0.03479112980130594, 0.025796773079491686, 0.10631475495756604, 0.007743394453427754, 0.021950423906673677, 0.029065902053844184, 0.02437844352243701, 0.02994767182826763, 0.04886892536887899, 0.05093840787594672, 0.06094402058806736, 0.02432101984595647, 0.00406470015150262, 0.06619817009777762, 0.0677767107845284, 0.036175773275317624, 0.071774667740101, 0.030430242222792003, 0.06635189114604145, 0.0340793990471866, 0.021447748731588945, 0.02966608986753272, 0.0207562470677658, 0.04093417926924303, 0.052747147929039784, 0.03616529043938499, 0.051761531285592355, 0.05369298916775733, 0.06367869005771354, 0.06721504600136541, 0.016933487058850005, 0.012622500562429195, 0.0344789899099851, 0.03131631274300162, 0.028475603357946966, 0.0019527658696461003, 0.020122256282775197, 0.039763381937518716, 0.036746340119862, 0.025851795908238273, 0.05520514845557045, 0.028358381132420618, 0.10522056953050196, 0.05855000432347879, 0.06249584024772048, 0.02096235260978574, 0.011631060842773877, 0.017855818914540578, 0.0441304126434261, 0.036607168876798823, 0.057937391102313995, 0.06540963819134049, 0.01675549221545225, 0.019235308172937948, 0.031210449087666348, 0.2584621013374999, 3.1265612924471498, 17.544745355844498, 37.019619941711426, 39.00208376348019, 42.41174720227718, 33.61263155937195, 21.325874961912632, 21.18523120880127, 19.43554289638996, 24.458377473056316, 18.82197082042694, 25.9162737429142, 33.82041200995445, 31.116615794599056, 21.5494454652071, 11.582346595823765, 5.272740991786122, 1.9007278326898813, 0.4851487936684862, 0.20557861716952175, 0.5495433148462325, 0.6699092779308558, 2.342443442903459, 1.7773096240125597, 1.6126432036980987, 1.4501538290642202, 1.1485925107263029, 0.9912970417644829, 1.6264788550324738, 2.336722374893725, 4.209014195948839, 4.697712147608399, 1.698768907226622, 1.464131735265255, 0.6770281959325075, 1.503657333087176, 0.31619566900189966, 0.738861981080845, 0.8302455337252468, 2.215865347534418, 2.8431005403399467, 4.810223635286093, 4.36072058044374, 4.806074257940054, 3.9962503127753735, 3.8899959018453956, 5.513119418174028, 5.771101824939251, 1.6697308653965592, 1.2460173829458654, 2.214163038879633, 0.5782030988484621, 0.4797289188718423, 0.4145999683532864, 0.5442486552055925, 0.5659397318959236, 2.1855541365221143, 4.87890874966979, 11.221484709531069, 16.37422576546669, 20.549743808805943, 18.318499736487865, 60.28980307281017, 37.837871834635735, 14.713198095560074, 23.875424154102802, 22.574166879057884, 27.96793755143881, 28.559140227735043, 31.95896789431572, 29.160805642604828, 21.47529624402523, 7.382300868630409, 0.5896125209983438, 0.07495995072531514, 0.017836573169915937, 0.033335937769152224, 0.04833364764635917, 0.04855323059018701, 0.0973343376244884, 0.05602350727713201, 0.03946427044866141, 0.03204315733455587, 0.02702498295548139, 0.057441031603957526, 0.028813922508561518, 0.02991365920024691, 0.07092317944625393, 0.07487904920708388, 0.04063157226482872, 0.01457456603020546, 0.054023504635551944, 0.07057978029479273, 0.036384275954333134, 0.03829014087386895, 0.08281482689199038, 0.009533108623145381, 0.04695514544437174, 0.054925681615713984, 0.021799124115204904, 0.03611562220612541, 0.03461271749984007, 0.0308827964545344, 0.07151010693632998, 0.0289974667612114, 0.056972925667651, 0.09331753753940575, 0.016448784845124464, 0.013918064978497569, 0.06363059888826683, 0.02470758045092225, 0.05185667090700008, 0.039384177871397696, 0.06595653423573822, 0.023307210867642425, 0.05436922670924105, 0.021063130698166788, 0.06365616587572731, 0.02547072719607968, 0.011490855231386377, 0.035329791717231274, 0.04294808233680669, 0.05908707433263771, 0.018540273886173964, 0.061634956364287063, 0.03505646614939906, 0.07593358910526149, 0.04990192814148031, 0.08766622398979962, 0.01814981886127498, 0.04509444763243664, 0.03339927636261564, 0.0297049134678673, 0.038168009341461584, 0.055633772135479376, 0.08713201867067255, 0.03602024509746116, 0.036914744559908286, 0.04845265102630947, 0.05332827182428446, 0.05051734668086283, 0.04995016031898558, 0.04192185166175477, 0.028064527759852353, 0.06913723074831069, 0.03759187267860398, 0.02389518664131174, 0.10114919190527871, 0.033944439492188394, 0.09562427352648228, 0.01582290202350123, 0.013949886415502988, 0.03682679634948727, 0.02018879724346334, 0.017524924951430876, 0.06032948520442005, 0.03771824929572176, 0.037312940185074694, 0.013359278800635366, 0.04158552146691363, 0.06305590199190192, 0.028833624674007297, 0.04071540155564435, 0.0070645097639499, 0.025866219548333902, 0.08985940396087244, 0.023823721530789044, 0.03191142612195108, 0.026329432876082137, 0.06628980307141319, 0.05306040475261398, 0.01152849881691509, 0.01561537526868051, 0.07676162553252652, 0.046369650299311616, 0.9762225381564349, 6.695488672703505, 26.465648263692856, 43.41168634593487, 43.959654942154884, 42.843544632196426, 29.124181307852268, 18.99487864226103, 16.75959348678589, 18.204150572419167, 24.012040123343468, 28.725886680185795, 37.952401489019394, 44.54637385904789, 35.066912323236465, 19.584152922034264, 9.772889390587807, 4.775701062753797, 1.2711837887763977, 0.34640879777725786, 0.15492861159145832, 0.19912645948352292, 0.7255317026283592, 0.4670383420307189, 0.9223770524840802, 0.5408259888645262, 1.411034215707332, 1.67511505773291, 1.0169479809701443, 1.754723279736936, 3.464375277981162, 1.7128013167530298, 3.1698720809072256, 1.9346474250778556, 2.338922219350934, 0.48751481983345, 0.8289923728443682, 1.7101066675968468, 1.6744438000023365, 1.465595606714487, 2.003883272409439, 2.4682228686288, 3.942584367468953, 4.119129544124007, 2.688851379789412, 2.369656157679856, 1.0598078998737037, 0.4672497947467491, 2.332615270279348, 1.0680241277441382, 1.3226696010679007, 0.761565703433007, 0.9452641743700951, 0.2547973464243114, 0.315553592517972, 0.19599060353357345, 0.3202999831410125, 1.5569203812628984, 4.535875031724572, 10.402152724564075, 19.0177059173584, 32.348139211535454, 25.760484002530575, 57.342753410339355, 45.471160635352135, 19.859185963869095, 24.87371228635311, 22.63611875474453, 26.338854767382145, 30.72220455855131, 37.48416781425476, 34.83314506709576, 30.346708707511425, 11.911054607480764, 1.0833449056372046, 0.06594173581106588, 0.07150007309974171, 0.03334682136483025, 0.008035993596422486, 0.013966397345939185, 0.029409922753984574, 0.0511139851732878, 0.0768281813361682, 0.04493919404922053, 0.03818848890659865, 0.02863733774574939, 0.013958297731733182, 0.03256842719565611, 0.05376984969188925, 0.07275577212567441, 0.020946350050508045, 0.024964641852420755, 0.015417531685670838, 0.057424893602728844, 0.07982386785442941, 0.042760630676639266, 0.020325020304881036, 0.04259699824615382, 0.03325455756566953, 0.031055674189701676, 0.01578378341946518, 0.02124979753716616, 0.05212208518059924, 0.03181639782269485, 0.03646768964244984, 0.008427778921031859, 0.1158743814448826, 0.0810067547718063, 0.021039485873188823, 0.05073087741038762, 0.06951312854653224, 0.07122181967133656, 0.03045478504645871, 0.015616633208992425, 0.06607541145058349, 0.0537221221748041, 0.06243374475161545, 0.028761727262462955, 0.013748715227848152, 0.021644228618242778, 0.0508090515359072, 0.10603385206195526, 0.08049574156757444, 0.1330324646551162, 0.10844011747394688, 0.15655658673495054, 0.12374869445920922, 0.1458620754419826, 0.19620633102022111, 0.12576925830217078, 0.13456924469210207, 0.10964699802570976, 0.15510985889704898, 0.10760598059277982, 0.1641099579865113, 0.1571668844553642, 0.20549727778416127, 0.13194444647524506, 0.07248910362250172, 0.17154549102997407, 0.09663470758823678, 0.16885848599486053, 0.10188848231337033, 0.10081540356623009, 0.15575825847918168, 0.16332844679709524, 0.1600699732080102, 0.18331409781239927, 0.24596957402536646, 0.16980258689727634, 0.1874459901591763, 0.10732927083154209, 0.09956818728824146, 0.17328180489130318, 0.09907199477311224, 0.1424027024768293, 0.1495764948776923, 0.15904034720733762, 0.18399846187094226, 0.09606058956705965, 0.14132792421150953, 0.22827067296020687, 0.10778786614537239, 0.12418733342201449, 0.1695487872348167, 0.18253027112223208, 0.14305381831945851, 0.06725193074089475, 0.07233160504256375, 0.11094767120084725, 0.13585350156063214, 0.09009666115161963, 0.11620739795034751, 0.11753475875593722, 0.15208018943667412, 0.12223984886077233, 1.0030422708950937, 5.4174367524683475, 25.181695260107517, 52.13574081659317, 54.99571815133095, 56.423012763261795, 44.53904025256634, 32.02083237469196, 31.06942992657423, 28.168789073824883, 32.54053048789501, 26.51232685893774, 36.43378637731075, 45.333212837576866, 40.00861555337906, 26.365985311567783, 15.058560613542795, 7.08608633838594, 2.887233509682119, 0.816474063321948, 0.9165650268550962, 1.8056897073984146, 2.6403343956917524, 6.233908915892243, 6.849464485421777, 5.840971525758505, 4.475980270653963, 4.236340429633856, 6.2867621798068285, 6.1505551636219025, 7.743632979691029, 11.812348254024982, 10.617915596812963, 5.959537038579583, 4.53410005196929, 2.4794952012598515, 5.541548542678356, 2.8361521381884813, 4.911558972671628, 4.85247784294188, 8.873077724128962, 8.668645843863487, 11.06648437678814, 14.508984703570604, 16.130077466368675, 11.17447268217802, 14.014733824878931, 13.201813995838165, 15.31558072194457, 8.361552022397518, 7.5356335658580065, 7.094879066571593, 4.039485342800617, 2.1716708689928055, 0.6484111596364528, 1.0001166653819382, 0.713459987891838, 2.9813485220074654, 5.841892501339316, 16.009834818542004, 20.267493054270744, 29.719546660780907, 21.88593450933695, 70.10457381606102, 47.318435311317444, 19.907310381531715, 35.43967992067337, 31.09660416841507, 39.125660732388496, 39.60677571594715, 46.34882993996143, 40.79826258122921, 30.457284674048424, 10.447112862020731, 0.7098365854471922, 0.1496291725197807, 0.156113316770643, 0.15482209855690598, 0.19545357063179836, 0.12919597676955163, 0.15624507766915485, 0.3531707724323496, 0.17513992002932355, 0.11540869119926356, 0.1431012712419033, 0.20610885199857876, 0.17450599232688546, 0.17239881242858246, 0.12613069906365126, 0.13221166416769847, 0.12922613765113056, 0.0695246912073344, 0.1290421889279969, 0.13039016659604385, 0.12481564306654036, 0.1492858401616104, 0.17222235939698294, 0.08673611999256536, 0.1269489317201078, 0.22944112890399992, 0.09445155403227545, 0.1623531905352138, 0.17937131953658536, 0.0859377026790753, 0.22090669779572636, 0.13856042583938688, 0.19557385792722926, 0.14940471737645566, 0.12789656524546444, 0.12584681273438036, 0.2453507564496249, 0.1999792762217112, 0.15762268187245354, 0.14639913802966475, 0.12007419514702633, 0.09794300262001343, 0.22030168416677043, 0.10891429788898677, 0.08798333627055399, 0.12240531810675748, 0.11009174486389384], [0.05216230216319673, 0.042562421585898846, 0.029632700643560383, 0.029957113802083768, 0.08421201637247577, 0.04428326166816987, 0.08705085740075447, 0.03307597457023803, 0.036041403727722354, 0.054719164181733504, 0.048287923928000964, 0.06995840230956674, 0.04353066084149759, 0.021199147813604213, 0.08616719700512476, 0.07728586380835623, 0.034169158097938634, 0.014888602108840132, 0.030450270933215506, 0.02117840664141113, 0.015227233889163472, 0.041194212972186506, 0.0049631218644208275, 0.02877098184399074, 0.045994943648111075, 0.039555235489387996, 0.02287999726831913, 0.013206617168179946, 0.0470233636588091, 0.06113539820944425, 0.0457801920856582, 0.021905542525928468, 0.026436823500262108, 0.0703153308131732, 0.04538581481028814, 0.0326996500371024, 0.05958892943453975, 0.06903373083332554, 0.08467919833492488, 0.05068762875453103, 0.05796614561404567, 0.055745131394360214, 0.0554674011800671, 0.0591811601043446, 0.035770942849921994, 0.04328529568738304, 0.04415326708112843, 0.024044996571319643, 0.016540317628823686, 0.027327658608555794, 0.03418514024815522, 0.05624168385111261, 0.07083409203914925, 0.031760925994603895, 0.029338014210225083, 0.05610861677268986, 0.08094955745036714, 0.2616238285554573, 8.383539542555809, 24.602536037564278, 33.5691124945879, 43.63660767674446, 41.18301473557949, 32.19336211681366, 32.79066726565361, 28.854437582194805, 24.901441298425198, 20.2686120942235, 18.731600269675255, 25.77524621039629, 34.92312043905258, 36.44859418272972, 32.782189920544624, 26.17440529167652, 15.175015814602375, 7.213596096262336, 3.029544185847044, 1.1506595998071134, 0.22609350853599608, 0.32805990893393755, 0.42050307034514844, 0.679007355356589, 0.3570287529146299, 0.4566140763927251, 0.7107437867671251, 2.466651890426874, 0.21893966506468132, 2.9989641392603517, 1.9288735161535442, 1.2142332759685814, 0.29049052332993597, 0.863865832798183, 0.6946261797565967, 0.932265012525022, 1.5255776443518698, 1.7318661999888718, 2.076550810597837, 2.788629988208413, 1.648715736810118, 2.0496777025982738, 1.6176241426728666, 0.4459898464847356, 0.5788659257814288, 0.19268090691184625, 0.0940744168474339, 0.5460139573551714, 0.24703653005417436, 0.39884583558887243, 1.2629948719404638, 4.017962822690606, 7.554477229714394, 12.906759828329086, 18.848265409469604, 25.353761427104473, 27.193670198321342, 27.731248252093792, 19.23045840114355, 23.000682592391968, 65.02473279833794, 36.881919130682945, 23.82247019559145, 21.261857897043228, 30.592584013938904, 37.916497215628624, 32.71330341696739, 22.583729065954685, 10.361308716237545, 2.0315353386104107, 0.00564931717235595, 0.03992227946582716, 0.029443625535350293, 0.025927411479642615, 0.019291867247375194, 0.0437089321349049, 0.03280704993812833, 0.025123205414274707, 0.028577060511452146, 0.05477722610521596, 0.03278398398833815, 0.03992938181909267, 0.08358343955478631, 0.06193833891302347, 0.10213666391791776, 0.03175189776811749, 0.06843751907581463, 0.05611894746834878, 0.04760989781061653, 0.02639382717461558, 0.022757064216420986, 0.023759594405419193, 0.03657117842521984, 0.05412781720224302, 0.15978521114448085, 0.035503491380950436, 0.027996660210192204, 0.035692482997546904, 0.03466175861831289, 0.09318155382061377, 0.07062680277158506, 0.03887176571879536, 0.052426391703193076, 0.06133177419542335, 0.029520345051423647, 0.11406912948586978, 0.02270292454340961, 0.04875945487583522, 0.05836492753587663, 0.012444476033124374, 0.1083899186050985, 0.031223002515616827, 0.020719449530588463, 0.02963390106742736, 0.06090704679081682, 0.04610356438206509, 0.06626187605434097, 0.035907965575461276, 0.03163831206620671, 0.07054924091789871, 0.003350331758156244, 0.043154076556675136, 0.055937017386895604, 0.061671139774261974, 0.12215977112646215, 0.030181472466210835, 0.0069308494312281255, 0.02517843047826318, 0.027029523043893278, 0.0451169421285158, 0.04930537128529977, 0.0109473341035482, 0.059408973465906456, 0.005903495330130681, 0.02379660159931518, 0.015504411203437485, 0.021775175009679515, 0.006363931634041364, 0.06126266911451239, 0.01379209654260194, 0.017622881023271475, 0.028633202127821278, 0.04761968302773312, 0.023377577599603683, 0.03059035872865934, 0.07996995220310055, 0.011970073901466094, 0.04203709235298447, 0.02598301874968456, 0.054629286387353204, 0.014982059838075656, 0.016513646696694195, 0.029293602237885352, 0.013080491953587625, 0.057483319178572856, 0.03624272612796631, 0.06146240331872832, 0.03995972823759075, 0.05584902464761399, 0.07964763746713288, 0.02699816359381657, 0.059520136055652983, 0.014784533523197751, 0.05684973657480441, 0.033419447936466895, 0.024379744136240333, 0.03919792106898967, 0.01881120046164142, 0.0661764622782357, 0.014126999958534725, 0.06611398828681558, 0.018152141783502884, 0.057574985548853874, 0.020756668236572295, 0.1645591206033714, 1.7520914459601045, 15.13439029455185, 32.118487134575844, 43.405500277876854, 46.891288831830025, 39.64013032615185, 30.83248984068632, 27.37581342458725, 22.605777382850647, 18.982723094522953, 21.335524544119835, 28.38647749274969, 37.2763379663229, 45.245874524116516, 44.17329467833042, 34.030042961239815, 26.88754342496395, 12.761156391352415, 6.093568196520209, 1.6485029482282698, 0.5005740956403315, 0.3342665493255481, 0.4207621095702052, 0.42285998293664306, 0.4693413450149819, 0.1942309713922441, 0.21832890721270815, 0.5353584978729486, 0.832686546491459, 0.8982782112434506, 0.9485953487455845, 0.7630828313995153, 1.1353745637461543, 0.842966657364741, 0.6018288061022758, 1.1491671111434698, 0.6442547170445323, 1.7838281742297113, 0.5976847722195089, 1.2463622144423425, 0.6631156580988318, 0.46590618090704083, 0.5234175792429596, 0.5170642607845366, 0.4370121454121545, 0.4938009293982759, 0.6267286918591708, 0.04514184489380568, 0.20993475685827434, 0.14995409961557016, 0.12006984616164118, 1.0313285468146205, 2.7539038890972733, 6.874149385839701, 13.176737241446972, 22.023557424545288, 31.275639161467552, 37.97586902976036, 39.34886075556278, 28.87834209948778, 22.995995543897152, 72.1307846903801, 38.760914504528046, 14.596168175339699, 20.883381105959415, 28.754109665751457, 40.487758442759514, 40.03441236913204, 32.23757654428482, 17.987182214856148, 4.231987288221717, 0.14773473667446524, 0.011452144808572484, 0.02313972669071518, 0.03970732752350159, 0.07690817743423395, 0.08191218978026882, 0.028342269106360618, 0.05144440787262283, 0.028023156737617683, 0.01822010766773019, 0.0048792049074108945, 0.0485096999182133, 0.028990566643187776, 0.05984960138448514, 0.0422355649061501, 0.0309794686108944, 0.05665750548359938, 0.05255469790427014, 0.024433221442450304, 0.029728996159974486, 0.02410667460935656, 0.03263147264078725, 0.024267498010885902, 0.057630872979643755, 0.1515230443328619, 0.042595354389050044, 0.06672232673736289, 0.053892760479357094, 0.03568016334611457, 0.02392996924754698, 0.014707522714161314, 0.07636754511622712, 0.005602354995062342, 0.0180114231625339, 0.03492122828902211, 0.08587537711719051, 0.02954583596874727, 0.010584478623059113, 0.041429188058828004, 0.011666360169328982, 0.0736225041327998, 0.04141384415561333, 0.0237804413336562, 0.024498838429281022, 0.05573142392677255, 0.01626870085601695, 0.038650854330626316, 0.051245671857031994, 0.1363374263746664, 0.160865570360329, 0.11037974269129336, 0.06787877093302086, 0.23781731928465888, 0.11079155301558785, 0.25270659767556936, 0.07734050814178772, 0.17193200153997168, 0.1255638466682285, 0.1428706562728621, 0.17663598584476858, 0.1337038114434108, 0.0956499221501872, 0.20733427139930427, 0.2509134798310697, 0.12680878455284983, 0.05687086551915854, 0.07159296030295081, 0.09930142972734757, 0.21536764892516658, 0.1882164878770709, 0.14278550224844366, 0.0889311553328298, 0.17569026706041768, 0.1378466875758022, 0.11764171707909554, 0.17073830153094605, 0.13998585403896868, 0.16910777339944616, 0.16897111432626843, 0.15701064752647653, 0.11547725080163218, 0.18870946689276025, 0.11262022715527564, 0.09184586611809209, 0.1521501294337213, 0.10668369883205742, 0.2135584264760837, 0.15380115568405017, 0.1641755786840804, 0.17988883395446464, 0.13114622212015092, 0.15074518451001495, 0.10780973723740317, 0.13184560724766925, 0.09437450426048599, 0.0452144343580585, 0.12237207731232047, 0.11109320636023767, 0.17270441399887204, 0.16530444467207417, 0.18938422756036744, 0.16448331763967872, 0.14802643039729446, 0.20425468508619815, 0.24716839485336095, 1.0285586141981184, 13.031733222305775, 34.425145760178566, 49.045761823654175, 60.64189597964287, 54.45676647126675, 45.83038575947285, 45.125417187809944, 39.77810472249985, 33.80969658493996, 27.726707495748997, 27.063802666962147, 34.08219136297703, 44.216285571455956, 49.04700055718422, 42.79599018394947, 34.99806381762028, 20.369639173150063, 10.31525518745184, 4.101481391116977, 1.9747325428761542, 0.5957341112662107, 1.1557754315435886, 1.459194018971175, 3.3057468524202704, 3.509214771911502, 3.323459126986563, 3.29338445328176, 8.347538374364376, 3.5961842676624656, 7.488904148340225, 7.597445324063301, 7.992209941148758, 3.0817643087357283, 3.1114582903683186, 4.496839251369238, 4.6031043492257595, 6.4586792048066854, 7.108786320313811, 8.29836331307888, 8.366373963654041, 7.556112566962838, 6.944697350263596, 5.838661724701524, 3.0675552086904645, 2.256482793018222, 1.4668306591920555, 0.696726042078808, 1.1289929249323905, 0.8457451988942921, 0.718176900409162, 1.9051612447947264, 5.785416606813669, 9.989372324198484, 17.711163125932217, 26.358372420072556, 34.23351064324379, 36.61880984902382, 38.44386711716652, 24.46255724877119, 29.544379860162735, 73.51530879735947, 44.82506990432739, 28.302306309342384, 32.84309305250645, 41.66957102715969, 49.860996678471565, 45.56145139038563, 35.93858174979687, 16.045955680310726, 3.355614901520312, 0.2571707940660417, 0.10683553482522257, 0.09438695749850012, 0.15107653860468417, 0.11337530304444954, 0.2776002197060734, 0.11419591057347134, 0.15149926592130214, 0.19513670325977728, 0.12624642957234755, 0.09207963521475904, 0.07884456688771024, 0.13571425981353968, 0.12915227911435068, 0.1714453604654409, 0.14146128814900294, 0.13015915086725727, 0.22001938603352755, 0.11969795596087351, 0.0856340084283147, 0.13723410404054448, 0.10366541391704232, 0.07429399935062975, 0.16900804359465837, 0.28459650522563607, 0.16954837163211778, 0.1832905420451425, 0.14439452294027433, 0.10542276766500436, 0.1629057788522914, 0.10613760430715047, 0.21630496659781784, 0.09767651223228313, 0.12812673492589965, 0.11019487370504066, 0.16658062697388232, 0.14062067231861874, 0.1417331665288657, 0.25990471767727286, 0.12574221444083378, 0.20971668418496847, 0.14745482825674117, 0.10415801443741657, 0.09087745245778933, 0.12913705024402589, 0.16520054399734363, 0.10241928117466159, 0.16255938884569332], [0.021210450722719543, 0.06965391396079212, 0.04927850553940516, 0.03074134681810392, 0.01052671263096272, 0.07351418025791645, 0.06888780975714326, 0.03983399357821327, 0.05624869714665692, 0.06967128021642566, 0.047496523620793596, 0.08759222444496118, 0.0632140610832721, 0.029803424295096193, 0.028699726390186697, 0.016198198682104703, 0.02866906455892604, 0.07112459090421908, 0.12213584428536706, 0.012781436125806067, 0.08263764655566774, 0.013967669201520039, 0.0730907850083895, 0.05477472135680728, 0.1557088759727776, 0.06128458473540377, 0.007165742881625192, 0.04461223717953544, 0.029803012403135654, 0.02768333288258873, 0.08959863553172909, 0.04321751905081328, 0.03678397442854475, 0.055197979309014045, 0.04623913991963491, 0.0046811451738904, 0.04859804888837971, 0.02886960399337113, 0.02024470508331433, 0.025692063463793602, 0.03815168951405212, 0.05815606491523795, 0.07177610008511692, 0.05412927923316602, 0.11704125281539746, 0.05557848584430758, 0.010770714088721434, 0.0445661683625076, 0.0065517594703123905, 0.039538180935778655, 0.025112744842772372, 0.05339024115528446, 0.08753620713832788, 0.03122771144262515, 0.04260600049747154, 0.028314479386608582, 0.13885961525375023, 0.08895510443835519, 0.1367837836733088, 2.562009673565626, 8.745360877364874, 19.72461998462677, 34.63566966354847, 41.55466519296169, 44.33341808617115, 42.837917134165764, 36.68969884514809, 31.71710517257452, 26.037777923047543, 23.23298502713442, 20.5829369276762, 29.89609468728304, 35.255815386772156, 32.34375424683094, 40.69090314209461, 34.01591531932354, 30.873535238206387, 21.07848733663559, 15.011511538177729, 8.67357037961483, 4.588841814547777, 1.91686627920717, 0.5584113264922053, 0.16050834499765188, 0.12095227459212765, 0.21333440177841112, 1.0752798384055495, 0.28127043682616204, 0.053301576772355475, 0.7045426382683218, 0.6636257213540375, 0.17466368386521935, 1.202032605651766, 0.4995167430024594, 0.5379748356062919, 0.21752244501840323, 0.009715252072055591, 0.19422151643084362, 0.2935607882682234, 0.2901431982172653, 0.07713217986747622, 0.20068373763933778, 0.38319426763337106, 1.2262853980064392, 2.7138953609392047, 4.5924406964331865, 9.420455452054739, 17.016877681016922, 20.493957102298737, 29.327373504638672, 33.237576484680176, 34.44593444466591, 33.749291226267815, 31.820189841091633, 20.832539834082127, 23.069848380982876, 23.497490733861923, 34.851091504096985, 35.692506954073906, 29.421872533857822, 32.98419468104839, 34.95421417057514, 37.616271525621414, 28.687554337084293, 13.3334731310606, 3.456546035595238, 0.33290666760876775, 0.03995169448899105, 0.15896688943030313, 0.008305318060592981, 0.021325500310922507, 0.06006518786307424, 0.045052371569909155, 0.03744453038962092, 0.03977120417403057, 0.02037202979408903, 0.042303560476284474, 0.040287583105964586, 0.04656402248656377, 0.13371531473239884, 0.07885793296736665, 0.009529735561955022, 0.022550283320015296, 0.025372355521540157, 0.03644008174887858, 0.02563826332334429, 0.02119318651239155, 0.018224059604108334, 0.04390448804770131, 0.03731894044904038, 0.09637510433094576, 0.015809678807272576, 0.01784123756806366, 0.00703096886354615, 0.011892430411535315, 0.049111091866507195, 0.05031102591601666, 0.08530015329597518, 0.12408446433255449, 0.06505846133222803, 0.045648100931430236, 0.028835943885496818, 0.042038576648337767, 0.03928958743927069, 0.027213043176743668, 0.07735551436780952, 0.03513313000439666, 0.06406559390597977, 0.05907003833272029, 0.04669055124395527, 0.07704051720793359, 0.08918050210922956, 0.03726228118466679, 0.0295738483328023, 0.044102741667302325, 0.03821676844381727, 0.018484649917809293, 0.005183074490560102, 0.07986189550138079, 0.02265101131342817, 0.061492519671446644, 0.05821425671456382, 0.07345509045990184, 0.09085647194297053, 0.017681028293736745, 0.03203123473213054, 0.08355791709618643, 0.02468779664923204, 0.048523956575081684, 0.054927919190959074, 0.03782284758926835, 0.05929043021751568, 0.017098529569921084, 0.08416731681791134, 0.08270515230833553, 0.0675130554009229, 0.024447292562399525, 0.02405323255516123, 0.01196137036458822, 0.08772721368586645, 0.08735131588764489, 0.06339265892165713, 0.01108913997086347, 0.05500223043782171, 0.013803793717670487, 0.021470733045134693, 0.10446110754855908, 0.10219743096968159, 0.043684036791091785, 0.07761840533930808, 0.03342099160363432, 0.047225016314769164, 0.02658999164850684, 0.06614604906644672, 0.003920128392564948, 0.036335839686216787, 0.0617767251242185, 0.05197462785872631, 0.08803285978501663, 0.011133243951917393, 0.06161347861052491, 0.06175821225042455, 0.02477607697073836, 0.09813183467485942, 0.083060618781019, 0.06458609175751917, 0.06621869790251367, 0.037198044592514634, 0.06285557406954467, 0.07860076395445503, 0.03108643435552949, 0.07165015020291321, 0.1324044296052307, 0.058885826147161424, 0.40619143517687917, 5.96081661991775, 15.745079275220633, 31.94362811744213, 45.808962509036064, 48.60331356525421, 45.705057084560394, 42.006878927350044, 30.833760872483253, 23.921570777893066, 18.449828289449215, 20.38616258651018, 26.03219412267208, 35.825480818748474, 47.761533334851265, 43.61472085118294, 49.698737785220146, 43.2175699621439, 35.7721658796072, 26.39206901192665, 13.158153388649225, 5.246226014569402, 1.5863201161846519, 0.9673203283455223, 0.3246293164556846, 0.04233028521412052, 0.06170796885271557, 0.032731406536186114, 0.2893026714446023, 0.31220908917021006, 0.2716500061796978, 0.48281067225616425, 0.1634707165067084, 0.1825905335135758, 0.07121168935555033, 0.22712451493134722, 0.3569111373508349, 0.18214586831163615, 0.1761285201064311, 0.161014519399032, 0.2928455063374713, 0.11814565761596896, 0.06762757620890625, 0.31219466181937605, 0.08986168977571651, 1.0246312874369323, 2.40584185346961, 5.706371823325753, 10.1407372020185, 18.003059662878513, 23.854701966047287, 34.62247297167778, 38.472889959812164, 42.21747502684593, 41.07512332499027, 36.998352482914925, 26.47433079779148, 25.353997014462948, 15.493206940591335, 24.07375641167164, 44.822584837675095, 29.42988060414791, 29.7216859459877, 35.27188092470169, 43.879418447613716, 37.829649075865746, 22.83820331096649, 8.07054653763771, 0.6591905280947685, 0.029134919932403136, 0.024428670221823268, 0.06088348360208329, 0.018613087850098964, 0.05208122995099984, 0.06951532530365512, 0.03274699534813408, 0.06140080506156664, 0.01979357020900352, 0.03536061311024241, 0.025701663143991027, 0.033940940265893005, 0.08337376799318008, 0.02933587496954715, 0.016092420373752248, 0.10049266580608673, 0.034732136482489295, 0.01935659922310151, 0.017535025581310038, 0.009980176528188167, 0.07236767341964878, 0.05574910930590704, 0.03583618876291439, 0.01674781655310653, 0.02443655554088764, 0.06642862179432996, 0.036228918470442295, 0.02492410574632231, 0.03111624642770039, 0.05965217525954358, 0.06696799988276325, 0.08954203192843124, 0.060068598031648435, 0.03978995082434267, 0.03635590364865493, 0.014023244002601132, 0.011358794690750074, 0.037187569178058766, 0.06582439484191127, 0.020222182756697293, 0.0415322352637304, 0.026336468436056748, 0.024649240222061053, 0.03735487523954362, 0.00613670642451325, 0.07409812431433238, 0.02732259530603187, 0.054264038408291526, 0.060388003548723646, 0.10042914538644254, 0.18284645571839064, 0.17913438146933913, 0.10063687252113596, 0.15414628403959796, 0.15384811878902838, 0.1728632187587209, 0.18868687591748312, 0.12501933291787282, 0.176208924385719, 0.12773220922099426, 0.1313950345502235, 0.155383889505174, 0.1290840608999133, 0.17119890806498006, 0.30205799324903637, 0.10261882984195836, 0.20876902097370476, 0.31638895394280553, 0.1274077274138108, 0.328291755868122, 0.15314629941713065, 0.1576512842439115, 0.17357058939523995, 0.3471333417110145, 0.18723590299487114, 0.1690143666928634, 0.11135895460029133, 0.15267479815520346, 0.12166135958977975, 0.2606715343426913, 0.16530537977814674, 0.1271102300961502, 0.16288051614537835, 0.13356244715396315, 0.12194789538625628, 0.15126097714528441, 0.14061599678825587, 0.12769294960889965, 0.11870151138282381, 0.22684117779135704, 0.1909725571749732, 0.20061476243427023, 0.1391192333539948, 0.24163970636436716, 0.16263767058262601, 0.1748046770808287, 0.17693958361633122, 0.18727249087532982, 0.1469649514183402, 0.18708794843405485, 0.1053379253426101, 0.3193202888360247, 0.17404091806383803, 0.17178501177113503, 0.11902582991751842, 0.42542671551927924, 0.23534751118859276, 0.33643629227299243, 4.526023110374808, 15.960329174995422, 33.046511337161064, 49.790027886629105, 59.663798063993454, 57.68538862466812, 56.71266742050648, 47.57898353040218, 43.236534744501114, 36.99870586395264, 32.91360206902027, 30.40250301361084, 40.29499098658562, 48.82140286266804, 40.852899849414825, 53.091362938284874, 45.92259541153908, 40.49628518521786, 28.35341166704893, 20.269098468124866, 12.111545149236917, 6.239787675440311, 2.937113670632243, 0.9934640536084771, 0.5363714403938502, 0.5198031419422477, 0.6192952813580632, 2.172346282750368, 1.1335883033461869, 1.0787296970374882, 2.340573468245566, 2.064079879783094, 1.0028236638754606, 2.356909979134798, 1.4975903648883104, 1.584922622423619, 1.139575238339603, 1.3572884746827185, 1.0127103771083057, 1.3570458814501762, 0.6978134368546307, 0.26454272505361587, 0.8214665798004717, 0.5974655121099204, 2.077123154886067, 3.2134775910526514, 6.287462767213583, 13.406844343990088, 23.10197375714779, 26.61962930113077, 37.67777502536774, 42.308092564344406, 47.46329493820667, 43.203202933073044, 38.76089930534363, 30.203631184995174, 32.994777113199234, 33.352543115615845, 40.22307604551315, 49.61907885968685, 39.47377525269985, 43.59317600727081, 46.323416903615, 48.89469712972641, 40.52056208252907, 20.12047704309225, 6.276539778336883, 0.5186603532638401, 0.08533741653081961, 0.31690243107732385, 0.13920976052759215, 0.15501605143072084, 0.15651661466108635, 0.13870360096916556, 0.09084157703910023, 0.15530615695752203, 0.156678477069363, 0.16055447689723223, 0.11678749768179841, 0.1754433842143044, 0.21038279141066596, 0.15523689973633736, 0.11645054037217051, 0.22779890452511609, 0.14257087314035743, 0.1066249875293579, 0.14239649812225252, 0.10060176893603057, 0.30232293996959925, 0.2128724445356056, 0.16201051126699895, 0.1780792701174505, 0.09666759957326576, 0.1345101252081804, 0.2008344084606506, 0.14427980175241828, 0.1444646410527639, 0.1232548471307382, 0.16596109693637118, 0.23840435809688643, 0.18868846411351115, 0.11211288016056642, 0.22116077947430313, 0.1966691788402386, 0.13880117854569107, 0.09566501001245342, 0.2091337865567766, 0.10151088499696925, 0.13702484808163717, 0.11178981585544534, 0.16357430547941476, 0.13091134722344577, 0.2290874658501707, 0.1202487334376201, 0.13615231990115717, 0.10558017718722112, 0.14556616632035002], [0.03241686208639294, 0.034927039305330254, 0.03257505457440857, 0.046581559436162934, 0.008419881542067742, 0.040949812610051595, 0.07826378438039683, 0.04419652315846179, 0.10887975833611563, 0.04400015459395945, 0.06834396393969655, 0.03268099986598827, 0.05106211647216696, 0.03574758746253792, 0.02213661020505242, 0.004004204447483062, 0.006945806953808642, 0.044034838865627535, 0.034881319297710434, 0.07500443505705334, 0.030329623696161434, 0.05398060478910338, 0.09957638059859164, 0.08547501071006991, 0.0708660637610592, 0.057303515350213274, 0.09564950654748827, 0.016231012741627637, 0.05854480928974226, 0.03747554845176637, 0.06754900503437966, 0.04024170724733267, 0.03506521235976834, 0.035016597976209596, 0.03754721394216176, 0.06363612046698108, 0.07411125290673226, 0.025130641733994707, 0.0358475399116287, 0.12906369636766613, 0.07418989087454975, 0.01000096222924185, 0.09297966738813557, 0.046976682569948025, 0.021388300847320352, 0.03090134086960461, 0.024580873578088358, 0.016463772517454345, 0.032710006707930006, 0.06641796455369331, 0.07295281975530088, 0.04485027362534311, 0.05808121932204813, 0.039149243602878414, 0.07706726421019994, 0.08134050600347109, 0.04329204552050214, 0.011720879265340045, 0.031176566335489042, 0.17985024227527902, 0.18655173189472407, 2.280969391576946, 5.912639955058694, 17.560419514775276, 28.858417868614197, 38.66727612912655, 38.989510238170624, 41.66132926940918, 44.507368952035904, 37.19724901020527, 34.17413502931595, 31.17066789418459, 22.641269378364086, 25.387558713555336, 24.60583046078682, 27.335524186491966, 27.839814126491547, 29.740162454545498, 22.406593970954418, 35.31992934644222, 39.50303368270397, 24.08909808844328, 18.793899826705456, 14.147549998015165, 9.967975672334433, 8.50606681779027, 4.756133537739515, 3.7116413097828627, 2.7883768267929554, 1.8732947297394276, 1.9987145997583866, 1.4767699758522213, 2.292975322343409, 1.9646085798740387, 1.9794023735448718, 1.5316771483048797, 3.186487639322877, 3.6674451688304543, 6.098035331815481, 8.35395148023963, 11.010405085980892, 12.810194659978151, 17.39855770021677, 22.156554087996483, 23.7734642252326, 28.624168038368225, 29.162399657070637, 22.969792149960995, 26.138407923281193, 25.51434651017189, 25.93073956668377, 22.779346369206905, 29.614206813275814, 25.31540058553219, 25.71569200605154, 23.860105276107788, 28.832588754594326, 32.46192030608654, 36.18868052959442, 41.58840738236904, 36.15070536732674, 29.989011101424694, 17.871275134384632, 4.155685007572174, 0.6584654795005918, 0.03076886565395398, 0.06660583181655966, 0.07954637141665444, 0.0380681904789526, 0.007623731489729835, 0.03577727336960379, 0.0684845563955605, 0.020481949286477175, 0.010003105180658167, 0.014731438423041254, 0.08788625593297184, 0.006844495910627302, 0.062438271852442995, 0.06282152433414012, 0.014196092051861342, 0.020551271445583552, 0.03601824129873421, 0.029471294656104874, 0.07156841005780734, 0.09568993133143522, 0.018955512932734564, 0.05001727273338474, 0.024853980212355964, 0.07784223707858473, 0.01725821006402839, 0.03284070633526426, 0.03918230999261141, 0.049799133266787976, 0.026200512547802646, 0.06276935135247186, 0.021554712620854843, 0.03283013815234881, 0.1262438320554793, 0.05540004014619626, 0.019236853695474565, 0.08922485285438597, 0.05653565596730914, 0.059404312778497115, 0.01862173572590109, 0.07205416797660291, 0.08868020551744848, 0.04067412330186926, 0.029723452316829935, 0.03692866725032218, 0.04677441393141635, 0.05320166143064853, 0.051780363282887265, 0.039193197299027815, 0.0033227860194529057, 0.04623720291419886, 0.004483133216126589, 0.06103294843342155, 0.03873601948725991, 0.01990027063584421, 0.1215815638715867, 0.038706270497641526, 0.05284992796077859, 0.08534742068150081, 0.03988248179666698, 0.005739204707424506, 0.03658175402961206, 0.0819301200681366, 0.053498398046940565, 0.08518536531482823, 0.043034716945840046, 0.04004518654255662, 0.05468818322697189, 0.018936695778393187, 0.059046085516456515, 0.05344476674508769, 0.04413095441123005, 0.04604570283845533, 0.03913296830432955, 0.029264983168104663, 0.06347711532725953, 0.054833829708513804, 0.07713738232268952, 0.04296192339097615, 0.06508868158562109, 0.07482288347091526, 0.06275245264987461, 0.03150950862618629, 0.028348072701191995, 0.06094629527069628, 0.049707786020007916, 0.10602962924167514, 0.07332736684475094, 0.04044536370201968, 0.04717634255939629, 0.04263334492861759, 0.022802771236456465, 0.016187688015634194, 0.03051555951969931, 0.0400267107761465, 0.06631512515014037, 0.06594175065401942, 0.031005043019831646, 0.026636073453119025, 0.03304569123429246, 0.05118890869198367, 0.01851357883424498, 0.052026299890712835, 0.030744872019567993, 0.08087162452284247, 0.034369181739748456, 0.07394919011858292, 0.04218338450300507, 0.01781902879884001, 0.05743356559833046, 0.046289145830087364, 0.24520997103536502, 0.488067808910273, 4.027668451890349, 11.533489767462015, 28.5660919547081, 40.541388764977455, 45.60339733958244, 45.63334733247757, 44.99476119875908, 42.45928645133972, 31.75752740353346, 28.586658351123333, 34.41363997757435, 26.49876158684492, 25.27405120432377, 30.961449220776558, 30.7345424965024, 38.52726884186268, 37.902958542108536, 39.66942295432091, 48.72951239347458, 36.710825711488724, 25.82109645009041, 23.077446073293686, 15.011462140828371, 10.455660503357649, 7.86187550984323, 6.008521635085344, 4.50866611674428, 4.075370142236352, 1.8762235413305461, 2.3772434005513787, 1.7881272872909904, 1.4143493003211915, 1.6955937026068568, 1.6184719721786678, 1.458780791144818, 2.7660936350002885, 2.9945765621960163, 4.528792686760426, 8.915375154465437, 12.86952467635274, 16.935786232352257, 24.03447601944208, 31.653354093432426, 35.19686535000801, 34.802203327417374, 39.11720618605614, 34.64775301516056, 36.322155967354774, 36.892699152231216, 34.740471839904785, 30.46879805624485, 31.866986230015755, 25.355813317000866, 22.735158540308475, 20.205484181642532, 24.122213311493397, 31.90822921693325, 37.91497729718685, 41.004241928458214, 41.45381100475788, 37.469044625759125, 25.994777530431747, 8.806685786694288, 1.7316469992510974, 0.06504206729005091, 0.06936740785022266, 0.041628592007327825, 0.045365602418314666, 0.030115246918285266, 0.027922733024752233, 0.036334151300252415, 0.054331837309291586, 0.006592903209821088, 0.02435270213027252, 0.08097837504465133, 0.10617618856485933, 0.006801492627346306, 0.057396458214498125, 0.030550672381650656, 0.039707219912088476, 0.03985909672337584, 0.03331204432470258, 0.019014296594832558, 0.07077616741298698, 0.023213292079162784, 0.020625055767595768, 0.019239801877120044, 0.012370198182907188, 0.04940171318594366, 0.07052907676552422, 0.07346424856223166, 0.06883432317408733, 0.02940166636108188, 0.03509287962515373, 0.03790630951698404, 0.036911059796693735, 0.20443530898774043, 0.13267287926282734, 0.021293111130944453, 0.029510634049074724, 0.03369053221831564, 0.056466691894456744, 0.029761576442979276, 0.07185833004768938, 0.029139144608052447, 0.04581457207677886, 0.09812521471758373, 0.03938728375942446, 0.09854354109847918, 0.05100186892377678, 0.056556031631771475, 0.03165618298226036, 0.03756311445613392, 0.0658668827963993, 0.03916021996701602, 0.12162365106632933, 0.09703830975922756, 0.10144336440134794, 0.14485092891845852, 0.0668633051100187, 0.20006722072139382, 0.18618181580677629, 0.12676551734330133, 0.12615967250894755, 0.091741601791, 0.18236129893921316, 0.2131965255830437, 0.20830382796702906, 0.10970113769872114, 0.11675879140966572, 0.18376674852333963, 0.12659148371312767, 0.12964775174623355, 0.13280438783112913, 0.18666346964892, 0.10954012133879587, 0.1464878098340705, 0.1377624092856422, 0.2196668362012133, 0.17093258094973862, 0.20961671689292416, 0.20918972964864224, 0.28494807542301714, 0.14176531636621803, 0.30052379588596523, 0.09747727526701055, 0.11122961310320534, 0.1528467092430219, 0.13923414750024676, 0.1649054660811089, 0.21827156888321042, 0.15223973634419963, 0.15307557274354622, 0.09736973064718768, 0.21029876545071602, 0.1476147907669656, 0.08401069397223182, 0.21085010695969686, 0.16225896746618673, 0.1172079837124329, 0.10968044662149623, 0.10849427941138856, 0.09326710118330084, 0.15589263173751533, 0.14377938641700894, 0.184013438411057, 0.08092757503618486, 0.15407336060889065, 0.166505892702844, 0.11406766003347002, 0.29296715918462723, 0.17643542785663158, 0.16048808436607942, 0.1548588348669, 0.3578282834496349, 0.4042075853794813, 3.1749994307756424, 9.78787673637271, 27.677743323147297, 42.611662074923515, 53.106919303536415, 56.73959657549858, 59.45392392575741, 56.223314478993416, 47.11775287985802, 45.037463307380676, 44.13150072097778, 35.645617470145226, 34.09875087440014, 34.91294078528881, 33.61129403114319, 40.132310315966606, 37.4211709946394, 32.285370379686356, 49.264694675803185, 47.81323716044426, 33.30150805413723, 26.536128781735897, 20.144601948559284, 15.19509393721819, 12.870530672371387, 7.849547546356916, 5.809620833024383, 3.837213646620512, 2.945684823207557, 3.1840320210903883, 2.888330463320017, 3.1815840024501085, 2.7697352645918727, 2.894149851053953, 2.5948999961838126, 4.748704461380839, 5.53095281124115, 8.432135134935379, 11.315254177898169, 15.529240407049656, 20.06288543343544, 23.9488685131073, 31.07495293021202, 34.07161273062229, 37.66398936510086, 39.647589325904846, 32.19171680510044, 34.78025570511818, 34.91897486150265, 35.679918229579926, 31.207854598760605, 39.67983819544315, 34.122818782925606, 35.706782788038254, 34.77470800280571, 40.97238063812256, 44.81855325400829, 47.398717403411865, 52.474485039711, 51.77233211696148, 40.590516328811646, 23.41772921383381, 6.804981222376227, 1.1471605813130736, 0.2711751207243651, 0.1894272572826594, 0.15709376806626096, 0.11584356005187146, 0.09126385164563544, 0.10123183747055009, 0.13294370379298925, 0.17396250274032354, 0.2826065698172897, 0.08539895541616715, 0.24067825404927135, 0.18045625038212165, 0.15327112865634263, 0.0913918053265661, 0.1526288888999261, 0.1610840141074732, 0.1374164200387895, 0.1769790065009147, 0.2761173789622262, 0.19544108770787716, 0.12637856154469773, 0.11148072619107552, 0.09769092474016361, 0.21007604693295434, 0.08605220122262836, 0.21571742312517017, 0.2527881448622793, 0.23401970509439707, 0.09341609475086443, 0.10250398991047405, 0.10649443633155897, 0.14015979861142114, 0.30453602434135973, 0.3141932358266786, 0.09440330701181665, 0.24158811225788668, 0.12289752528886311, 0.19426871702307835, 0.12922089808853343, 0.19899478764273226, 0.11506429756991565, 0.20031092717545107, 0.19332038587890565, 0.10350434560677968, 0.23367001995211467, 0.1419913151767105, 0.14691755786770955, 0.13841254549333826, 0.2358616710989736, 0.19017400627490133, 0.13861961953807622], [0.025987933622673154, 0.06803273689001799, 0.024079152062768117, 0.0195735827946919, 0.03623369048000313, 0.015593131247442216, 0.033678216277621686, 0.04183000717603136, 0.02044340955762891, 0.08365890855202451, 0.03306433398392983, 0.027512627784744836, 0.00987039711617399, 0.025800569164857734, 0.01482447962189326, 0.07070139603456482, 0.10545570417889394, 0.06996471056481823, 0.06255511558265425, 0.021258642082102597, 0.06495430832728744, 0.025742696489032824, 0.06965168751776218, 0.05027573679399211, 0.03345572782563977, 0.03835268165857997, 0.041629957559052855, 0.02027953407377936, 0.06836413551354781, 0.023532170671387576, 0.03141541172226425, 0.03201700033969246, 0.013156447985238628, 0.027312795245961752, 0.0951627318863757, 0.017212131970154587, 0.008710317324585048, 0.03160113417834509, 0.08038160667638294, 0.03322994423797354, 0.015905890832073055, 0.023875913066149224, 0.0463967646646779, 0.05618112088995986, 0.03654573760286439, 0.06378374106134288, 0.041813620555331, 0.0375444828387117, 0.01838607044192031, 0.03878069306665566, 0.08166521045495756, 0.09152839760645293, 0.03889043815433979, 0.044388431415427476, 0.023985003208508715, 0.04208917627693154, 0.060258279845584184, 0.0388045865111053, 0.033729509814293124, 0.06981722355703823, 0.10789484673296101, 0.06655713950749487, 0.19208249839721248, 0.3023239196045324, 2.965869577601552, 10.082541424781084, 16.44784491509199, 26.141831539571285, 33.33886384963989, 43.03679846227169, 47.55216456949711, 47.34816111624241, 43.47331903874874, 41.0046599060297, 28.285205326974392, 22.15072900056839, 26.199979819357395, 45.12950196862221, 30.238273926079273, 39.416770711541176, 57.18107968568802, 27.853770777583122, 25.446573346853256, 29.104732051491737, 29.189982376992702, 25.434641987085342, 21.765921749174595, 19.687252789735794, 18.835188411176205, 20.553279519081116, 18.61414287239313, 21.387327164411545, 17.915506660938263, 17.780241519212723, 21.696478575468063, 23.791192173957825, 23.648954406380653, 30.819238051772118, 36.64243318140507, 30.020218826830387, 22.301962785422802, 21.162818111479282, 20.246276892721653, 19.955195412039757, 21.361214965581894, 27.353778406977654, 29.52082872390747, 31.194631308317184, 29.036396518349648, 30.53698729723692, 29.441048204898834, 30.376155227422714, 36.36606641113758, 34.875881373882294, 33.960677683353424, 39.292505979537964, 35.030251890420914, 37.64053702354431, 34.34711694717407, 26.97854284197092, 16.7797989025712, 4.199859062209725, 0.38495202956255525, 0.07072858832543716, 0.08262775372713804, 0.03144208822050132, 0.047568129739374854, 0.04935771496093366, 0.05662190465955064, 0.022095695603638887, 0.03014210524270311, 0.02952438790089218, 0.03412956451938953, 0.04163675934250932, 0.029617993131978437, 0.089673859620234, 0.08286046897410415, 0.08400368067668751, 0.07780514453770593, 0.016349806464859284, 0.07252104565850459, 0.05872317706234753, 0.0805158018192742, 0.035913910178351216, 0.05374456843128428, 0.03946187331166584, 0.12864597112638876, 0.07557134682429023, 0.035385107694310136, 0.021368680318119004, 0.055244719769689254, 0.060164936221553944, 0.0546915006270865, 0.029266239253047388, 0.046113178905216046, 0.03298680552688893, 0.029414763412205502, 0.04872582445386797, 0.025159611468552612, 0.050037540786433965, 0.08454765265923925, 0.05243013583822176, 0.045752610167255625, 0.11023790342733264, 0.016726396315789316, 0.01933370396727696, 0.007860524838179117, 0.04449556043255143, 0.018234857852803543, 0.041636477326392196, 0.07767086033709347, 0.019127429586660583, 0.04774794841068797, 0.06438499200157821, 0.08885783114237711, 0.07617138064233586, 0.02539059194532456, 0.03069468613830395, 0.03793040705204476, 0.028458300184865948, 0.04255434701917693, 0.03346899371535983, 0.032487492280779406, 0.044413345312932506, 0.056098790737451054, 0.08593138700234704, 0.030210089680622332, 0.024049176718108356, 0.026012433772848453, 0.041248894413001835, 0.02665106669155648, 0.04946571971231606, 0.10925034977844916, 0.07792034070007503, 0.02083982588374056, 0.026924896919808816, 0.028122161093051545, 0.041587840678403154, 0.01882774849946145, 0.05627918086247519, 0.01132162700741901, 0.05741000240959693, 0.03667056684207637, 0.10574668543995358, 0.06741112883901224, 0.02602567183203064, 0.020940373906341847, 0.027171161927981302, 0.0670739563065581, 0.05254332449112553, 0.008449920896964613, 0.007824740332580404, 0.0432154336158419, 0.0316188381111715, 0.05583898710028734, 0.05121955939102918, 0.1216803585703019, 0.029900122426624876, 0.055734745037625544, 0.10643631874700077, 0.03397383225092199, 0.06144184211734682, 0.02015104048041394, 0.025118815610767342, 0.05294031783705577, 0.03233335562981665, 0.06734495153068565, 0.07408392702927813, 0.037825701147085056, 0.05980504283797927, 0.04534058090939652, 0.029603498987853527, 0.05766106354712974, 0.017975198934436776, 0.06748169966158457, 0.029573751853604335, 0.08052313423831947, 0.04992509799194522, 0.5728659883607179, 1.621230742894113, 7.282884428277612, 18.211343586444855, 26.80154073983431, 37.96025186777115, 43.4190009534359, 52.24371962249279, 51.737788170576096, 48.21447283029556, 40.14669254422188, 37.432205602526665, 25.447821579873562, 23.372352048754692, 24.468475431203842, 34.00102011859417, 21.2744827196002, 38.828759863972664, 62.55540490150452, 36.38533517718315, 38.20866733789444, 40.20548298954964, 41.01302705705166, 39.60812844336033, 30.434717684984207, 26.531846411526203, 25.472598150372505, 28.26253194361925, 28.33076488226652, 29.254255928099155, 30.25744579732418, 30.317826457321644, 30.204773023724556, 31.259269639849663, 38.13362516462803, 37.88793794810772, 36.91731043159962, 36.26216858625412, 37.93537460267544, 35.97756765782833, 34.13770638406277, 31.311074160039425, 27.189752608537674, 33.45229156315327, 29.903652481734753, 24.267774000763893, 23.006108701229095, 23.2337848842144, 24.408459551632404, 26.72515533864498, 33.556573167443275, 33.195163160562515, 34.71697010099888, 40.54037041962147, 40.46171084046364, 43.229083344340324, 43.72150272130966, 38.560433462262154, 24.240575060248375, 7.967817150056362, 1.4037774363532662, 0.10061691617011093, 0.10935125959804282, 0.08657996469992213, 0.06972467774176039, 0.0723275454947725, 0.018893968481279444, 0.05743308691307902, 0.05686642005457543, 0.0591638532205252, 0.050821415716200136, 0.047690992287243716, 0.06480886964709498, 0.05543622355617117, 0.021957157041470055, 0.047200469780364074, 0.07521453706431203, 0.053216222368064336, 0.06511751402285881, 0.03680394191178493, 0.02972147449327167, 0.07213705102913082, 0.027150394780619536, 0.028784002824977506, 0.04366552391729783, 0.07136411164538004, 0.09210297575918958, 0.03528694011038169, 0.027694587552105077, 0.10684783963370137, 0.005201941739869653, 0.0867969093087595, 0.06467792511102743, 0.05177152059332002, 0.028152752420282923, 0.03858964941173326, 0.09565225991536863, 0.035292829052195884, 0.02913416665251134, 0.03112754933681572, 0.04802072107850108, 0.06775513655156828, 0.05480610307131428, 0.07177352483267896, 0.04251168094924651, 0.12516878661699593, 0.005396556516643614, 0.0690175371710211, 0.06556219406775199, 0.03441165856202133, 0.06997742355451919, 0.08199987452826463, 0.06657374877249822, 0.06279856228502467, 0.05440584056486841, 0.18573995592305437, 0.07636773065314628, 0.09502636225079186, 0.1791307597886771, 0.19107645784970373, 0.1320606519584544, 0.06811072918935679, 0.17820488603319973, 0.1883661196916364, 0.20426198781933635, 0.10431934249936603, 0.13634596107294783, 0.10444539628224447, 0.11920318836928345, 0.133421988284681, 0.24266005551908165, 0.19414053327636793, 0.13220930413808674, 0.13501585432095453, 0.16022566094761714, 0.15216084604617208, 0.21941803861409426, 0.11463204849860631, 0.1374083900009282, 0.1832780591212213, 0.12252775763045065, 0.1585220906417817, 0.18938872497528791, 0.10108704445883632, 0.1856713369488716, 0.10704792264732532, 0.21520758251426741, 0.22019172756699845, 0.25364933302626014, 0.09590286834281869, 0.13319748861249536, 0.09768918069312349, 0.13106894970405847, 0.16065436997450888, 0.21707840322051197, 0.17828165378887206, 0.15853049175348133, 0.2616082731401548, 0.241198870644439, 0.1263988221762702, 0.22173505334649235, 0.171215561858844, 0.07530036644311622, 0.10909104777965695, 0.20535150513751432, 0.21773526328615844, 0.09466875839279965, 0.10674451041268185, 0.14395012491149828, 0.1299137671594508, 0.20769876980921254, 0.18549892120063305, 0.2350905945058912, 0.20387786702485755, 0.2806146157672629, 0.13077866606181487, 0.36920395272318274, 0.9202076657675207, 5.26185030117631, 16.31599958986044, 26.629731059074402, 39.442803114652634, 48.936643078923225, 62.581593096256256, 64.01347026228905, 64.09516587853432, 57.22362980246544, 54.37799669802189, 40.31180128455162, 35.0683980435133, 36.434037163853645, 57.06656523048878, 35.71274846792221, 52.227122113108635, 66.84780657291412, 38.711178973317146, 35.35853147506714, 39.22846041619778, 40.593088790774345, 37.78522565960884, 32.531855553388596, 29.862020015716553, 28.10995113104582, 30.82538042217493, 27.809218168258667, 32.73511424660683, 29.716001451015472, 29.551211893558502, 32.407283037900925, 35.85615657269955, 35.586705431342125, 41.61047279834747, 49.31069500744343, 40.403661355376244, 31.636296808719635, 29.648802056908607, 29.304627925157547, 27.012239433825016, 27.941907048225403, 36.58161364495754, 37.150055542588234, 41.68342128396034, 38.97201597690582, 39.128301590681076, 41.80984050035477, 40.231317803263664, 50.45687310397625, 47.95355223119259, 48.84995073080063, 54.58467900753021, 50.8993935585022, 53.09637486934662, 49.71415355801582, 39.8340605199337, 23.725187815725803, 6.358169373124838, 0.7753932802006602, 0.2039477921789512, 0.14385228016180918, 0.20084672811208293, 0.26039883960038424, 0.12753692048136145, 0.20693462487543002, 0.14838148868875578, 0.12635522842174396, 0.14446277084061876, 0.11932328270631842, 0.1725830728537403, 0.1682283729314804, 0.13441523420624435, 0.17092682188376784, 0.17424414778361097, 0.25393574265763164, 0.12091896700439975, 0.21904407039983198, 0.15254315600031987, 0.13124663470080122, 0.10737936579971574, 0.14936444844352081, 0.11181642927112989, 0.17845607333583757, 0.1245899114292115, 0.1821147426380776, 0.1274889035266824, 0.16110233031213284, 0.1525023824069649, 0.11142533228849061, 0.14866593905026093, 0.18243457860080525, 0.10698751182644628, 0.1428111657151021, 0.1625784917268902, 0.2715849643573165, 0.08127949404297397, 0.11183666763827205, 0.1217510926653631, 0.19193981308490038, 0.283124529523775, 0.16346308722859249, 0.14207471773261204, 0.11194746286491863, 0.2202155950362794, 0.06501095645944588, 0.10080644584377296, 0.16741198080126196, 0.13985756639158353, 0.22367210331140086, 0.16432567063020542, 0.36676386022008955, 0.17661202931776643], [0.08850655780406669, 0.058905971745844, 0.045390583109110594, 0.12016723820124753, 0.03448079703957774, 0.029634355632879306, 0.014102900568104815, 0.059890586489927955, 0.039917511167004704, 0.04589654599840287, 0.042512408253969625, 0.03338527945743408, 0.05580300035944674, 0.0444086549396161, 0.060913280831300654, 0.033776929340092465, 0.07877907235524617, 0.018656091597222257, 0.030089308856986463, 0.053413006535265595, 0.03126366107608192, 0.010249581700918498, 0.037407259733299725, 0.07221756663057022, 0.014209291148290504, 0.06356229903758503, 0.04122107129660435, 0.06553320577950217, 0.05570058026933111, 0.09405441596754827, 0.025273386418120936, 0.034550095078884624, 0.09151302772806957, 0.04562859729048796, 0.020309310893935617, 0.020823891973122954, 0.019549347962311003, 0.054456633151858114, 0.05931360006798059, 0.032076887946459465, 0.012772295649483567, 0.025303601105406415, 0.03567963642126415, 0.03756003454327583, 0.07856203868868761, 0.04338002712756861, 0.0580246565368725, 0.03777173958951607, 0.027549191545404028, 0.0024912735580073786, 0.04667026092647575, 0.005612489485429251, 0.025209788072970696, 0.029084951129334513, 0.019550785873434506, 0.08603883514297195, 0.019266482086095493, 0.008026529358176049, 0.03334703287691809, 0.035882684314856306, 0.048921306151896715, 0.015603569554514252, 0.032131996122188866, 0.04567873678752221, 0.05903458222746849, 0.28723377152346075, 0.6652656896039844, 2.1751272585242987, 6.120377657935023, 13.121958430856466, 20.836309231817722, 33.05147007107735, 33.72301563620567, 47.442973628640175, 48.37301932275295, 46.68884329497814, 37.13375821709633, 36.10894560813904, 46.903185993433, 60.49917183816433, 80.13020664453506, 32.23027713596821, 30.219387039542198, 25.39341989904642, 22.806055136024952, 24.71412844955921, 27.22278233617544, 32.84111335873604, 37.38853074610233, 17.981638312339783, 18.093331418931484, 21.42718892544508, 21.839417405426502, 19.95824284851551, 28.699322305619717, 27.17768445611, 24.6125029027462, 23.639794997870922, 83.25284108519554, 56.2770701944828, 24.876845218241215, 23.655225969851017, 29.118057936429977, 31.249618157744408, 27.490922547876835, 37.90907621383667, 45.38513705134392, 44.007171392440796, 45.25886222720146, 47.55761727690697, 49.81033019721508, 47.36216716468334, 40.249256640672684, 35.52873954176903, 31.70965377241373, 25.174213461577892, 19.46878731250763, 12.201847303658724, 3.977741743437946, 1.4377660187892616, 0.2520555560477078, 0.01311344516579993, 0.040543490467825904, 0.051913942443206906, 0.023939982675074134, 0.02938001049187733, 0.006808993421145715, 0.06394074982381426, 0.004176259790256154, 0.061669521892326884, 0.029976836376590654, 0.04719733049569186, 0.01725812842778396, 0.0706898927455768, 0.05303008802002296, 0.013924309223511955, 0.02052450774499448, 0.04730426655441988, 0.08803594711935148, 0.021007753493904602, 0.03737909522897098, 0.015968362968123984, 0.07307580846827477, 0.025868804077617824, 0.0762590579688549, 0.022017373048583977, 0.018058963287330698, 0.04544539813650772, 0.03679475041280966, 0.038568375748582184, 0.08098638281808235, 0.07075701258145273, 0.015043543990032049, 0.0331061688484624, 0.06241021867026575, 0.06804708260460757, 0.01192990979689057, 0.05675146880093962, 0.06400157624739222, 0.020815707939618733, 0.06078134923882317, 0.04704808830865659, 0.015150363160501001, 0.017335450938844588, 0.03968695556977764, 0.07441198598826304, 0.024963101895991713, 0.12694056029431522, 0.023124733452277724, 0.04381042454042472, 0.11670370178762823, 0.04596106089593377, 0.013154812477296218, 0.04939875943819061, 0.05575421157118399, 0.04213886677462142, 0.015624707775714342, 0.04769862898683641, 0.010926537270279368, 0.045448730379575863, 0.044696277982438914, 0.05899357856833376, 0.028485446091508493, 0.08938334591221064, 0.03266882493335288, 0.07232062867842615, 0.07568820539745502, 0.0215581970041967, 0.06097524274082389, 0.0354514000355266, 0.03233916293538641, 0.02309077277459437, 0.03913157677743584, 0.032029275462264195, 0.11785478025558405, 0.07084662691340782, 0.030256763348006643, 0.02860829194105463, 0.07741883440758102, 0.031587987032253295, 0.04062451444042381, 0.06305714137852192, 0.00495106382004451, 0.03347349484101869, 0.024395091750193387, 0.06835537817096338, 0.024047215592872817, 0.0552536515169777, 0.08799349627224728, 0.021648703768732958, 0.03813333991274703, 0.028501706547103822, 0.042828897130675614, 0.039499656049883924, 0.07493709999835119, 0.009365865644213045, 0.03157071354507934, 0.006697519129374996, 0.024340844465768896, 0.06814269348978996, 0.036008686147397384, 0.041522245956002735, 0.04077080659044441, 0.053363705665105954, 0.03655923355836421, 0.027502593948156573, 0.0539625854435144, 0.03619160699599888, 0.0480808944121236, 0.041817609599092975, 0.006005447867210023, 0.06010137127304915, 0.03199843551556114, 0.041136522122542374, 0.03479460305243265, 0.044952304087928496, 0.048243261480820365, 0.05532073795620818, 0.12261063326150179, 0.08845494885463268, 0.07562401704490185, 0.9044258063659072, 2.2839695680886507, 6.183362603187561, 13.411320503801107, 22.380753457546234, 32.02525533735752, 46.32005028426647, 47.98126794397831, 52.081437930464745, 49.285259172320366, 44.817105531692505, 36.45712472498417, 37.23871998488903, 37.30710871517658, 52.53628112375736, 80.44954910874367, 30.217394046485424, 25.042932406067848, 24.10611167550087, 25.956798568367958, 25.24555653333664, 28.701757974922657, 31.01655576378107, 33.97979445755482, 24.211675710976124, 24.152773171663284, 29.762077778577805, 27.259649857878685, 26.11788522452116, 32.28058643639088, 37.084653452038765, 28.37333019822836, 30.31206786632538, 83.03857818245888, 44.27755728363991, 17.55871720612049, 16.893773786723614, 16.182026378810406, 19.452303797006607, 17.558420822024345, 30.541845336556435, 36.31132274866104, 39.912758097052574, 42.50224694609642, 45.94407565891743, 49.8238118737936, 51.36300288140774, 46.61035090684891, 44.62478265166283, 41.18182919919491, 35.01580506563187, 29.415931552648544, 21.168229021131992, 10.412042643874884, 4.554921984672546, 0.9146824653726071, 0.08262485192972235, 0.004430289982337854, 0.06819734524469823, 0.021312371718522627, 0.068710458726855, 0.021188067548791878, 0.024085013174044434, 0.053651358393835835, 0.04599581196089275, 0.029780007680528797, 0.0603265091922367, 0.04333608456363436, 0.011470234658190748, 0.09224207649822347, 0.05023802827054169, 0.05736359962611459, 0.08704535808647051, 0.034816952829714864, 0.03628359620051924, 0.04332231772423256, 0.02193179228925146, 0.06256618100451306, 0.03001211807713844, 0.031140308710746467, 0.015119708750717109, 0.005794835633423645, 0.042662281266530044, 0.006426861118598026, 0.02671679871127708, 0.09088202408747748, 0.06013289399561472, 0.044039302883902565, 0.005857174182892777, 0.11909611872397363, 0.032754220155766234, 0.041504965047352016, 0.01615846780623542, 0.014372515397553798, 0.03523310100717936, 0.05655600194586441, 0.03735975857125595, 0.021594361860479694, 0.023060927305778023, 0.01820105859223986, 0.07460930821252987, 0.07112160747055896, 0.10395795368822291, 0.03640026552602649, 0.08090896939393133, 0.01650751284614671, 0.03778929509280715, 0.03240390789869707, 0.04325023292039987, 0.020908884580421727, 0.021598504899884574, 0.13704665238037705, 0.17733115557348356, 0.1089985910221003, 0.2552000357536599, 0.1841001064167358, 0.149371973820962, 0.13890599948354065, 0.24944539298303425, 0.15898465644568205, 0.15454713284270838, 0.1485072827199474, 0.14762256847461686, 0.1903553871670738, 0.10752282294561155, 0.16559572279220447, 0.20851655717706308, 0.1802166851121001, 0.14833590597845614, 0.22630711348028854, 0.16868569917278364, 0.1076053200813476, 0.14565044461051002, 0.12771116191288456, 0.11508279931149445, 0.14747955661732703, 0.1524910720763728, 0.0975274592929054, 0.18467607238562778, 0.1609953274601139, 0.1516582487965934, 0.0660812298883684, 0.13767881377134472, 0.1889543459401466, 0.14598423294955865, 0.15389791689813137, 0.09902457895805128, 0.17936330434167758, 0.22065760334953666, 0.19713591551408172, 0.1624878606526181, 0.13959413365228102, 0.08671790026710369, 0.17147856415249407, 0.13347135594813153, 0.20409072982147336, 0.13452210347168148, 0.1589823854737915, 0.1814353361260146, 0.11557895471923985, 0.11244623805396259, 0.10710537229897454, 0.08842160415952094, 0.11476432147901505, 0.11021392463590018, 0.09787091039470397, 0.1640637667151168, 0.1713611712330021, 0.07443019087077118, 0.28537252452224493, 0.12220832242746837, 0.15900380385573953, 0.14731226168805733, 0.17440378374885768, 0.1809442273224704, 0.10309937788406387, 0.5272791220340878, 1.291069546714425, 4.305424997583032, 11.311920806765556, 20.873862616717815, 30.323049277067184, 47.54825837910175, 51.500331312417984, 63.99185702204704, 62.2290214151144, 62.516198605298996, 50.715643018484116, 51.466296538710594, 58.788024857640266, 67.3205316066742, 91.58687308430672, 36.7306986451149, 42.766374573111534, 32.755066975951195, 32.27137193083763, 34.061771258711815, 38.29278342425823, 45.10321877896786, 51.807434633374214, 27.341275177896023, 29.120182022452354, 30.586540438234806, 32.78564393520355, 28.331190459430218, 39.717269986867905, 37.284412533044815, 31.71142067760229, 29.875984266400337, 97.50753298401833, 61.677047833800316, 30.340021066367626, 33.16242791712284, 36.15287885069847, 41.196549609303474, 36.94813817739487, 50.34167468547821, 57.73114196956158, 56.18285045027733, 58.5362883657217, 60.66406399011612, 65.40563195943832, 63.15134212374687, 55.79338654875755, 51.527575850486755, 45.73871947824955, 35.3435792773962, 28.49812690168619, 20.250418670475483, 8.945747874677181, 3.230966627597809, 0.5226298933848739, 0.06546391145093367, 0.15383544290671125, 0.17704032274195924, 0.10334409365896136, 0.20887550432235003, 0.11037431759177707, 0.13351793313631788, 0.13418904243735597, 0.10839192982530221, 0.13849974784534425, 0.1316480475361459, 0.12066361625329591, 0.2656449330970645, 0.25669394934084266, 0.1338789434521459, 0.1338911146740429, 0.1476196147268638, 0.21609532472211868, 0.17931196256540716, 0.1603323669405654, 0.16590119077591226, 0.16778252029325813, 0.06158790049084928, 0.2784636046271771, 0.05616805538011249, 0.09509700728813186, 0.10662317668902688, 0.10550509410677478, 0.10077380618895404, 0.18717428989475593, 0.1352352777030319, 0.14907533739460632, 0.15929526009131223, 0.2679689833894372, 0.09059623786015436, 0.10078882725792937, 0.20521683502011, 0.15019918646430597, 0.11980213123024441, 0.16294162458507344, 0.12649791373405606, 0.09414843123522587, 0.1815426506800577, 0.06445192630053498, 0.13214683014666662, 0.15649538923753425, 0.23815008345991373, 0.1226598970242776, 0.2096115070162341, 0.23523517971625552, 0.12202447760500945, 0.08609939439338632, 0.14410645089810714, 0.13339072902454063, 0.08139405195834115], [0.03881308781274129, 0.022321536707750056, 0.07447348034474999, 0.005893134484722395, 0.0322032756957924, 0.04519510141108185, 0.040137008763849735, 0.03866614257276524, 0.02635879223817028, 0.029524807214329485, 0.019394218688830733, 0.02883642999222502, 0.019182571159035433, 0.127405337698292, 0.043492058030096814, 0.03696941857924685, 0.03895708672644105, 0.007956002136779716, 0.05269129389489535, 0.019729348459804896, 0.03027235587069299, 0.057683776976773515, 0.04680324265791569, 0.04622002590622287, 0.017092048765334766, 0.05026288279623259, 0.04440710756171029, 0.04062654421431944, 0.06293972619459964, 0.08734287766856141, 0.05849118540936615, 0.06322382774669677, 0.005164358917681966, 0.049522223125677556, 0.04331234697019681, 0.011652259363472695, 0.048125716421054676, 0.029872946834075265, 0.022894580470165238, 0.026300960380467586, 0.04523701420112047, 0.061341351611190476, 0.025036426086444408, 0.005475298848978127, 0.08437663214863278, 0.012793073929060483, 0.06872334983199835, 0.016383486981794704, 0.043272137409076095, 0.06246304474188946, 0.06950802257051691, 0.06958797413972206, 0.05715293729736004, 0.047612773632863536, 0.05291007531923242, 0.056755146142677404, 0.008039897293201648, 0.04058174818055704, 0.043001435333280824, 0.04809686171938665, 0.038392694550566375, 0.036698389958473854, 0.07193508296040818, 0.06404766361811198, 0.05791546434920747, 0.02788024507026421, 0.05365082404750865, 0.09775753249414265, 0.06290117162279785, 0.314078945084475, 0.6693472049664706, 1.9597518467344344, 3.7655549542978406, 13.172686658799648, 21.929998844861984, 31.39099147170782, 48.871875554323196, 55.1097272336483, 53.7256895005703, 50.49359813332558, 54.76836875081062, 42.97599412500858, 39.174761697649956, 34.857273772358894, 36.061866134405136, 35.9660504758358, 36.58600240945816, 40.57559832930565, 38.80796357989311, 37.189691215753555, 42.409528121352196, 37.38114394247532, 38.04089494049549, 38.65235432982445, 34.584539607167244, 31.061345860362053, 44.778321012854576, 25.391907580196857, 65.3280021250248, 78.88981640338898, 44.442567229270935, 44.939618557691574, 46.579101383686066, 46.75229988992214, 49.49111692607403, 51.26968368887901, 48.85813929140568, 42.37132877111435, 36.88450299203396, 33.28846715390682, 23.280151896178722, 16.298239342868328, 10.896489098668098, 6.5832882933318615, 3.650578111410141, 2.2969658207148314, 1.0249464330263436, 0.28556218778248876, 0.032616833777865395, 0.013498189364327118, 0.03989392571384087, 0.03830215624475386, 0.06925879453774542, 0.08525400655344129, 0.11233481942326762, 0.036485768359852955, 0.07083174685249105, 0.001831609797591227, 0.08769009888055734, 0.03830558496701997, 0.11149293452035636, 0.04986906213162001, 0.015943139223963954, 0.030777144311286975, 0.009921399359882344, 0.026717023210949264, 0.061760524040437303, 0.019631312607089058, 0.04795835840923246, 0.03576221890398301, 0.022621926545980386, 0.03919455914001446, 0.0608650226786267, 0.08402190782362595, 0.018398527390672825, 0.07025601094937883, 0.06354806464514695, 0.011512213313835673, 0.011977426729572471, 0.03426110648433678, 0.011405012864997843, 0.022335561443469487, 0.00616793228800816, 0.008294376020785421, 0.04839355380681809, 0.029408601731120143, 0.028832427960878704, 0.05099465895909816, 0.005212166679484653, 0.02330786024685949, 0.07215259902295657, 0.03288290114142001, 0.017983598190767225, 0.02587905870313989, 0.1826104972860776, 0.03299015632364899, 0.03483067514025606, 0.03094774921919452, 0.05507769572432153, 0.07320945442188531, 0.025989458736148663, 0.05679563029843848, 0.009542225907352986, 0.026810147901414894, 0.05742727589677088, 0.05336195419658907, 0.04621448948455509, 0.01878870967630064, 0.05444948255899362, 0.03343728916661348, 0.0489311581623042, 0.02159464387659682, 0.0028121350760557107, 0.012735410909954226, 0.04913318931357935, 0.03326630576339085, 0.015027529370854609, 0.06396950804628432, 0.024622111013741232, 0.07684173295274377, 0.01610209612408653, 0.022215624812815804, 0.03109524550382048, 0.039832705951994285, 0.034375285904388875, 0.0073913093910960015, 0.02777614958176855, 0.03949665777327027, 0.06778254406526685, 0.042309597847633995, 0.07026396677247249, 0.04610315249010455, 0.06684279956971295, 0.04745761652884539, 0.06659069942543283, 0.1016280181647744, 0.029735476964560803, 0.013732960360357538, 0.03336884830787312, 0.014698149389005266, 0.04487180704018101, 0.06384412219631486, 0.054369419667636976, 0.06394093536073342, 0.04410390683915466, 0.075562455895124, 0.03970952056988608, 0.052653347884188406, 0.03444115893216804, 0.03007977040397236, 0.03347648569615558, 0.04710858076578006, 0.03980903515184764, 0.03780519560677931, 0.021132720030436758, 0.04491192754358053, 0.06631584503338672, 0.0627428047300782, 0.037769687551190145, 0.05434482118289452, 0.028553434240166098, 0.0951279177388642, 0.0663305469788611, 0.0203554372274084, 0.047312968235928565, 0.014833082968834788, 0.009615786657377612, 0.019865170761477202, 0.15261777152772993, 0.11575084354262799, 0.021382920276664663, 0.019805307274509687, 0.04699890618212521, 0.08216636051656678, 0.25905142596457154, 1.0711190616711974, 2.7569164149463177, 5.751653993502259, 9.690559208393097, 24.006598815321922, 34.47486609220505, 44.325807094573975, 55.43857678771019, 53.921116814017296, 53.85163374245167, 58.482430055737495, 64.27687212824821, 42.78164975345135, 35.54396532475948, 31.839648596942425, 29.67271227389574, 30.495943799614906, 30.3320224955678, 38.17699983716011, 40.62004454433918, 26.378650031983852, 30.809092596173286, 24.29452456533909, 24.538108594715595, 24.209164045751095, 26.51995874941349, 23.45841933041811, 26.31835676729679, 21.242268048226833, 73.91267627477646, 80.38402542471886, 34.9696147441864, 30.113465823233128, 39.724557995796204, 44.07880134880543, 49.139343202114105, 54.40054088830948, 54.42037582397461, 47.751053497195244, 47.248762249946594, 43.82676087319851, 34.74514938890934, 27.83614542335272, 18.9057145267725, 12.308776415884495, 8.388609420508146, 5.755063835531473, 2.57816759403795, 0.6773290922865272, 0.05449372198199853, 0.02751472064119298, 0.07383560441667214, 0.031134037562878802, 0.07916936039691791, 0.04597523591655772, 0.07827795940102078, 0.027316641426295973, 0.06460014803451486, 0.008688696707395138, 0.047578460435033776, 0.02952089980681194, 0.040323180219274946, 0.016356218620785512, 0.03803744701144751, 0.03379390596819576, 0.024909171879698988, 0.14265277655795217, 0.010860970378416823, 0.02241218819108326, 0.06250617836485617, 0.08754932088777423, 0.029402913169178646, 0.024399967660428956, 0.06596521736355498, 0.01859053212683648, 0.03150702243146952, 0.029982435880810954, 0.08642391330795363, 0.00909070511625032, 0.011904532984772231, 0.08564066549297422, 0.041999673267127946, 0.04070302253239788, 0.009820760424190667, 0.08046882387134247, 0.04109821245947387, 0.08088582922937348, 0.043130528210895136, 0.007525091250499827, 0.04618388331437018, 0.021348826012399513, 0.05028579289501067, 0.05517485027667135, 0.03890158892318141, 0.09511476688203402, 0.08135935655445792, 0.018964761948154774, 0.0357706311478978, 0.03619392249675002, 0.021811772166984156, 0.09288885077694431, 0.01116413213821943, 0.016229001521423925, 0.019826773896056693, 0.012778521340806037, 0.08460461249342188, 0.03548272608895786, 0.1574899858678691, 0.054054144202382304, 0.21649289323249832, 0.0925841843127273, 0.15944714803481475, 0.15153089625528082, 0.11629792512394488, 0.1677931033191271, 0.10932166274869815, 0.15722392592579126, 0.19042681145947427, 0.28347583254799247, 0.05818758021632675, 0.23750808119075373, 0.11823239983641542, 0.13492019148543477, 0.12293415769818239, 0.17291763302637264, 0.08940203319070861, 0.11144891032017767, 0.09141828515566885, 0.19678688346175477, 0.19576322432840243, 0.08101212049950846, 0.13626659580040723, 0.1524505508132279, 0.2000490974751301, 0.1286518934648484, 0.14099342341069132, 0.20188028749544173, 0.16454160591820255, 0.11825234134448692, 0.12428742687916383, 0.1525547928758897, 0.11102508462499827, 0.1508402536273934, 0.15177256922470406, 0.24716711835935712, 0.17939592915354297, 0.13515634287614375, 0.07790287054376677, 0.22346087323967367, 0.10571400125627406, 0.11542390522663482, 0.13520490902010351, 0.16135396290337667, 0.264108331175521, 0.13535483769373968, 0.16001713229343295, 0.13678363524377346, 0.14801025157794356, 0.20793506962945685, 0.1411019402439706, 0.11694869957864285, 0.12260245479410514, 0.18109587777871639, 0.17589337803656235, 0.14354169135913253, 0.14044711366295815, 0.10976100675179623, 0.11315211697365157, 0.20174165430944413, 0.26201404980383813, 0.21152710891328752, 0.16999774205032736, 0.11637652598437853, 0.2174231011304073, 0.12331926554907113, 0.1651379364193417, 0.5330913257785141, 1.5921634901314974, 3.756004166789353, 8.201525509357452, 20.431982427835464, 34.198434725403786, 46.7208793759346, 65.39227947592735, 70.27488827705383, 67.45454281568527, 66.46757617592812, 71.23423799872398, 54.218006283044815, 54.90370988845825, 47.57024399936199, 50.58754429221153, 49.26007032394409, 49.657532796263695, 55.23114591836929, 56.49962805211544, 45.85803307592869, 57.531793266534805, 47.662309259176254, 48.34577098488808, 47.759793028235435, 46.016157791018486, 42.938634529709816, 57.089519798755646, 34.324891939759254, 79.29454788565636, 86.97518214583397, 53.782146871089935, 57.71183140575886, 58.79699997603893, 61.52358926832676, 64.21934321522713, 67.37185925245285, 63.49927045404911, 57.25926049053669, 51.74909256398678, 45.677626356482506, 33.03480036556721, 24.9985146895051, 15.831874217838049, 9.433379508554935, 5.57880031876266, 3.657004041597247, 1.5507288509979844, 0.4850061528850347, 0.1242466458643321, 0.12924497335916385, 0.12937147985212505, 0.14934540493413806, 0.1755765700363554, 0.2031243496458046, 0.13796747953165323, 0.1506141063873656, 0.1535091205732897, 0.16029606107622385, 0.16469825844978914, 0.12035872714477591, 0.23319408064708114, 0.18533740018028766, 0.1154949955525808, 0.10612964106258005, 0.0819971360033378, 0.3460964129772037, 0.1389790713437833, 0.09070923726540059, 0.17278334882576019, 0.13244051282526925, 0.1489861312438734, 0.2048638992710039, 0.2616824582219124, 0.19235176441725343, 0.16987917653750628, 0.11389151128241792, 0.18183596228482202, 0.08596711399150081, 0.12656169390538707, 0.13676263246452436, 0.12085983267752454, 0.18139882246032357, 0.10936523423879407, 0.12586000812007114, 0.13202587491832674, 0.13446491357171908, 0.08900594897568226, 0.08912491524824873, 0.17687960324110463, 0.08359265702893026, 0.20973446604330093, 0.1828207922517322, 0.143360503425356, 0.17017756443237886, 0.47132566978689283, 0.11325181709253229, 0.14500844234135002, 0.10173177040996961, 0.1471798328566365, 0.1439409371232614, 0.06215464156412054, 0.150311651523225, 0.16743176645832136, 0.11818232713267207, 0.13399727147771046, 0.16212138812988997], [0.037984053196851164, 0.0869974672968965, 0.056571112072560936, 0.03160367603413761, 0.012228678970132023, 0.014771227743040072, 0.03343438365845941, 0.08756144758081064, 0.03412891514017247, 0.060874139962834306, 0.06895899656228721, 0.06431142290239222, 0.006967791687202407, 0.020885267585981637, 0.07104904769221321, 0.0546430309623247, 0.03484129527350888, 0.05860286750248633, 0.020405747418408282, 0.05197418257012032, 0.01987616382393753, 0.04451910135685466, 0.010251774747302989, 0.06556952648679726, 0.05434988263004925, 0.028969458107894752, 0.007911430602689506, 0.02504477339243749, 0.029719331541855354, 0.06746935774572194, 0.08391756928176619, 0.022522185608977452, 0.015452649186045164, 0.024328439467353746, 0.016094721031549852, 0.10708830290241167, 0.04201260147965513, 0.016258564974123146, 0.04228048710501753, 0.03371457409230061, 0.034062685881508514, 0.0767896935576573, 0.04244871342962142, 0.010897848624153994, 0.03017892133357236, 0.07768744733766653, 0.05885484890313819, 0.07158958353102207, 0.08057820159592666, 0.03362208393809851, 0.061231216895976104, 0.028318982367636636, 0.051020853061345406, 0.016605728669674136, 0.028841276216553524, 0.009028447275341023, 0.037696574872825295, 0.11719509260728955, 0.0159129412350012, 0.048662986810086295, 0.04826853531994857, 0.03442902481765486, 0.014332222344819456, 0.02662413415237097, 0.014617520610045176, 0.026857892116822768, 0.03875696660543326, 0.07722734546405263, 0.026795349476742558, 0.051681876575457864, 0.05729983800847549, 0.03222499093681108, 0.026595997478580102, 0.1565361479879357, 0.43457864318042994, 1.4433849672786891, 8.148454707115889, 17.60938558727503, 34.598465859889984, 42.21295706927776, 48.52531515061855, 54.3976454436779, 56.68684780597687, 52.02108196914196, 52.93723180890083, 51.56647056341171, 51.146323308348656, 48.88637937605381, 50.55614277720451, 54.20242711901665, 60.31918689608574, 53.41931574046612, 49.223181903362274, 52.344345822930336, 52.86890007555485, 56.43263004720211, 55.573203563690186, 53.646923527121544, 50.83760127425194, 54.567633122205734, 54.74761426448822, 51.255407854914665, 43.18343639373779, 44.95071776211262, 35.826202780008316, 23.237742371857166, 15.357520021498203, 9.340154360979795, 5.094217546284199, 1.3790757930837572, 0.5286367773078382, 0.08509167659212835, 0.032284678163705394, 0.01676319385296665, 0.09276211421820335, 0.05498965845617931, 0.1152162003563717, 0.10388219525339082, 0.049306914952467196, 0.021609130599244963, 0.021750086707470473, 0.009940230429492658, 0.04847310461627785, 0.03752358767087571, 0.033125965637736954, 0.027517798698681872, 0.08894969418179244, 0.051483990318956785, 0.02347006960917497, 0.036882965796394274, 0.03997631152742542, 0.03345979850564618, 0.035109629898215644, 0.06443078993470408, 0.013230149743321817, 0.0684894694131799, 0.03192547497747, 0.014004569711687509, 0.028354720489005558, 0.07317557538044639, 0.05189543328015134, 0.10629419004544616, 0.06996553434873931, 0.04336696532845963, 0.057203125033993274, 0.03625383607868571, 0.08439555691438727, 0.019914748081646394, 0.04641903280571569, 0.0356487074168399, 0.08670880895806476, 0.03848935928544961, 0.0348776753526181, 0.022528671979671344, 0.06094915996072814, 0.02780765189527301, 0.0130628362603602, 0.035621645001810975, 0.06497059846878983, 0.02783381631161319, 0.05900768308492843, 0.018479462305549532, 0.028617119787668344, 0.010201504446740728, 0.07825698630767874, 0.05356515423045494, 0.04749203362734988, 0.023895169942989014, 0.035579127361415885, 0.02168467195588164, 0.050522920209914446, 0.0166501554849674, 0.03858403877529781, 0.04427827814652119, 0.07070871361065656, 0.06478360694018193, 0.011929127758776303, 0.07371253406745382, 0.00391184834370506, 0.05004298443964217, 0.02006212562264409, 0.0273673393894569, 0.06500245144707151, 0.1313130569178611, 0.06777885559131391, 0.02714751895837253, 0.02673237082490232, 0.045608447981067, 0.03372110870259348, 0.002679617650755972, 0.04262458758603316, 0.0224286453158129, 0.015846988426346797, 0.038718549330951646, 0.036168967781122774, 0.06848117962363176, 0.024353731860173866, 0.02847904135705903, 0.029180354213167448, 0.05121403781231493, 0.05352709689759649, 0.03329890460008755, 0.028634046320803463, 0.03599728675908409, 0.07884286736953072, 0.03128850818029605, 0.1139271714782808, 0.02386551001109183, 0.03945792508602608, 0.011657850518531632, 0.026984010837622918, 0.05125320465594996, 0.050783807382686064, 0.03489153124974109, 0.013526723087124992, 0.010448697139509022, 0.028950340383744333, 0.03512681803840678, 0.0727227317111101, 0.036546453775372356, 0.08775243928539567, 0.03452227196248714, 0.06539035719470121, 0.05366597499232739, 0.03978139015089255, 0.008571713824494509, 0.0566109579813201, 0.05677239736542106, 0.06457596144173294, 0.07057782844640315, 0.0398668966954574, 0.05589768356003333, 0.0223797340731835, 0.012539968174678506, 0.05454091886349488, 0.07378562819212675, 0.03260821373260114, 0.0346055631962372, 0.03335936737130396, 0.02089586359943496, 0.023983233186299913, 0.024746634117036592, 0.02957174805487739, 0.044889989658258855, 0.026644235222192947, 0.015851671378186438, 0.07977022542036138, 0.01609076909517171, 0.08794722336460836, 0.4291040275711566, 1.4755560597404838, 4.426879305392504, 15.481975693255663, 30.707850828766823, 47.55714610219002, 51.227384358644485, 56.04200340807438, 61.25389114022255, 56.510917246341705, 54.75121647119522, 53.24173606932163, 54.522974118590355, 55.86019456386566, 53.790069445967674, 52.100680097937584, 55.07982663810253, 59.2942450940609, 53.701454401016235, 52.929396629333496, 53.68231862783432, 53.75348120927811, 52.75470860302448, 55.87501756846905, 48.92703339457512, 55.51681078970432, 63.201959207654, 58.65365266799927, 57.55990035831928, 53.99534583091736, 53.99103686213493, 47.28852331638336, 36.285419538617134, 26.537840589880943, 18.247855827212334, 11.051109451800585, 5.112953865900636, 2.5716689927503467, 0.7072641828563064, 0.18649394827662036, 0.05051519074186217, 0.03686896889121272, 0.08140080550219864, 0.03733061072125565, 0.029167097600293346, 0.03294065136287827, 0.08228356047766283, 0.03680439833260607, 0.08519738810718991, 0.07831808732589707, 0.02620331786602037, 0.03956468674005009, 0.03846158811938949, 0.05002785204851534, 0.03251783498853911, 0.029144489926693495, 0.023856543011788744, 0.10896584004512988, 0.013015844397159526, 0.0403491739416495, 0.010679087608878035, 0.0367333488247823, 0.03538204633514397, 0.0321760091901524, 0.01379851890305872, 0.03407359174161684, 0.03594474641431589, 0.09074230736587197, 0.07626555176102556, 0.02700907687540166, 0.046369375704671256, 0.018202008541265968, 0.03897894668625668, 0.025908440329658333, 0.03937170607969165, 0.02413017842627596, 0.050445113447494805, 0.04899218867649324, 0.04327264949097298, 0.01734501351165818, 0.037250915192998946, 0.04486276026000269, 0.009059516360139241, 0.03763784872717224, 0.020464848348638043, 0.0526611404347932, 0.03465993664576672, 0.029079459236527327, 0.01782851901225513, 0.02351486007682979, 0.017882098363770638, 0.03539126380928792, 0.04264524526661262, 0.11513080142321996, 0.02520545578590827, 0.028086497186450288, 0.01737171598506393, 0.06814428910729475, 0.060485740686999634, 0.03236508615373168, 0.02506127319065854, 0.04718612406577449, 0.03750888572540134, 0.12838834198191762, 0.20183967717457563, 0.10402134794276208, 0.12551118386909366, 0.18025708763161674, 0.12143539046519436, 0.18675102823181078, 0.25333620607852936, 0.13388492516241968, 0.22371256520273164, 0.1827144721755758, 0.11246838374063373, 0.17546900315210223, 0.12947060109581798, 0.17939474171726033, 0.14124517474556342, 0.11795139304012991, 0.09556620789226145, 0.11719413523678668, 0.14775740186451003, 0.19375884672626853, 0.18055238819215447, 0.07373764834483154, 0.13687408820260316, 0.11989960490609519, 0.1401145276031457, 0.18407191964797676, 0.1277646707603708, 0.22235001175431535, 0.14085953996982425, 0.2226469450397417, 0.07023312311503105, 0.14774438459426165, 0.07481663458747789, 0.10254679698846303, 0.17857915110653266, 0.2079706927179359, 0.09921033110003918, 0.07864272498409264, 0.12661962595302612, 0.08366926151211374, 0.12568802281748503, 0.1529783068690449, 0.1732261586585082, 0.18484943808289245, 0.13572165160439909, 0.16597527195699513, 0.13335624884348363, 0.12739938567392528, 0.13943699130322784, 0.0955059529223945, 0.17899188911542296, 0.13525766087695956, 0.2151181537192315, 0.15155651519307867, 0.09509500348940492, 0.13786506315227598, 0.17269846197450534, 0.12420342318364419, 0.1796380028827116, 0.09666204088716768, 0.1324763585580513, 0.07715108236880042, 0.24354353779926896, 0.0627878234081436, 0.07852292008465156, 0.13434461143333465, 0.23454804002540186, 0.09277271950850263, 0.12027588119963184, 0.24192472075810656, 0.16877123911399394, 0.1443595380987972, 0.2546053973492235, 0.8676112443208694, 3.234857856296003, 11.943535264581442, 25.576528273522854, 48.21146719157696, 58.31114664673805, 65.23501351475716, 72.86031514406204, 73.08729216456413, 69.62918132543564, 71.66689038276672, 69.92037490010262, 68.78614336252213, 67.26963713765144, 68.62522959709167, 70.98160475492477, 78.12069207429886, 69.65771019458771, 68.95819053053856, 71.51892632246017, 71.6172194480896, 72.89136707782745, 75.1276458799839, 67.84820929169655, 66.41112640500069, 70.59294641017914, 69.7857329249382, 70.02486929297447, 60.39745509624481, 58.17285306751728, 47.970639914274216, 34.79186408221722, 21.605760343372822, 13.38389452546835, 7.1423655934631824, 2.9611483309417963, 1.2279283348470926, 0.3209996205987409, 0.14022262883372605, 0.18208744644653052, 0.22252797876717523, 0.10795061913086101, 0.19011377356946468, 0.17835200938861817, 0.1268693883321248, 0.13280872197356075, 0.17437240574508905, 0.16307679936289787, 0.10834255474037491, 0.1868406351422891, 0.09367651437059976, 0.1694789808243513, 0.21829001867445186, 0.10107432404765859, 0.1678244664799422, 0.08062972148763947, 0.18146947491914034, 0.11078753799665719, 0.1156375918071717, 0.10465052590006962, 0.067765823478112, 0.12844573968322948, 0.10368147399276495, 0.09747858886839822, 0.24530550028430298, 0.1876348370569758, 0.16546421422390267, 0.2593171445187181, 0.1669968233909458, 0.12533542845631018, 0.2252868830692023, 0.08472582747344859, 0.24326806742465124, 0.09102349227759987, 0.15219768625684083, 0.09328310188720934, 0.1516286371042952, 0.13611022528493777, 0.16930169658735394, 0.11419430753448978, 0.17816442414186895, 0.11692034211591817, 0.21779597096610814, 0.22717351152095944, 0.22689752164296806, 0.10426961118355393, 0.12068877505953424, 0.09641189259127714, 0.15370712557341903, 0.10613090271363035, 0.31791656103450805, 0.12110281924833544, 0.23139590135542676, 0.15442815172718838, 0.1304841521778144, 0.16154368553543463, 0.2462122414726764, 0.10684348322683945, 0.2667120227124542, 0.14137101330561563, 0.12041165711707436, 0.16547573235584423], [0.013924358390795533, 0.052702760076499544, 0.024492678603564855, 0.03941967479477171, 0.026438964596309233, 0.022060315568523947, 0.0586234138609143, 0.08855317209963687, 0.016280634590657428, 0.025754964190127794, 0.053115668779355474, 0.008339524574694224, 0.06893160389154218, 0.017863902758108452, 0.041006501560332254, 0.0255086565084639, 0.07147435026126914, 0.02316482426977018, 0.02724366418988211, 0.03786543202295434, 0.046352265489986166, 0.09035187831614166, 0.03277360134234186, 0.05807704103062861, 0.03071311737585347, 0.09425101088709198, 0.05579121505434159, 0.0382511113275541, 0.0682439372758381, 0.013147952249710215, 0.03858534124447033, 0.0276069621759234, 0.02300218075106386, 0.015370819055533502, 0.030611355941800866, 0.048937358806142583, 0.05240791964752134, 0.06036425482307095, 0.08978307407232933, 0.037554093651124276, 0.04889997682766989, 0.07237362544401549, 0.06118970115494449, 0.04877016777754761, 0.054915963191888295, 0.059189416497247294, 0.023122104394133203, 0.049880758379003964, 0.051176177148590796, 0.05197084661631379, 0.029132084928278346, 0.02726772832829738, 0.030787840514676645, 0.06861384594230913, 0.015079234799486585, 0.03592405162635259, 0.023968822533788625, 0.037223210820229724, 0.042321201326558366, 0.034470017344574444, 0.017121077871706802, 0.017617140510992613, 0.02300282085343497, 0.01985158018214861, 0.024748010800976772, 0.029996870653121732, 0.03943962001358159, 0.03357406698341947, 0.043300769466441125, 0.024476553589920513, 0.020737541235575918, 0.03535339572408702, 0.028426666140148882, 0.019732940454559866, 0.0790876499377191, 0.10439749064971693, 0.06905275207827799, 0.13902699924074113, 0.45828812406398356, 2.0520269265398383, 4.575068978592753, 7.304608812555671, 16.785238310694695, 21.546783708035946, 21.349731981754303, 21.90744325518608, 30.04375286400318, 34.102178290486336, 37.08310313522816, 34.854496121406555, 33.64699311554432, 32.14128591120243, 24.7270667552948, 23.189302571117878, 24.043103456497192, 29.739313200116158, 33.198943957686424, 34.37336213886738, 34.30884540081024, 36.796476915478706, 29.068844877183437, 17.084322161972523, 8.83528495207429, 5.654196348041296, 1.5747606614604592, 0.5497086059767753, 0.08910418706363998, 0.07474921047105454, 0.06023586698574945, 0.06832780738477595, 0.07687595338211395, 0.01522197577287443, 0.005117145337862894, 0.04614330639014952, 0.09149986944976263, 0.011722874714905629, 0.020871675151283853, 0.01590839929122012, 0.02264451566588832, 0.020952387421857566, 0.06543743904330768, 0.06621106862439774, 0.12846065685153008, 0.01541061950774747, 0.038668168635922484, 0.046005938565940596, 0.08064414883847348, 0.09483563771937042, 0.033888288598973304, 0.055599963598069735, 0.034526639501564205, 0.07332511071581393, 0.026547366396698635, 0.03975061328674201, 0.056996908169821836, 0.03821470156253781, 0.039895447116578, 0.017536791892780457, 0.05933398315391969, 0.020309296050982084, 0.11884954015840776, 0.007866155883675674, 0.028227729744685348, 0.05699934612493962, 0.040944717766251415, 0.04674381889344659, 0.06885687704198062, 0.04894638332189061, 0.019613582699093968, 0.020016427879454568, 0.01821872912842082, 0.013831415526510682, 0.035186872628401034, 0.04391180191305466, 0.04243601899361238, 0.016792668247944675, 0.021119211087352596, 0.05592833796981722, 0.023748612475174014, 0.015217083164316136, 0.022288301479420625, 0.03820891281065997, 0.029628813645103946, 0.020367296747281216, 0.023467264290957246, 0.0612196208385285, 0.015482058643101482, 0.05206609013839625, 0.03243146384193096, 0.029847839978174306, 0.049245543050346896, 0.05053617125668097, 0.04519861548033077, 0.02878158527892083, 0.07703320705331862, 0.06522430165205151, 0.007806218181940494, 0.030814930760243442, 0.02436899783788249, 0.03376302891410887, 0.02020993360929424, 0.03981671266956255, 0.02031486772466451, 0.029076837599859573, 0.050421071573509835, 0.055036929552443326, 0.002274040671181865, 0.04299359083233867, 0.05730642456910573, 0.03000570406584302, 0.03193477037712, 0.03051267998671392, 0.06774358873371966, 0.013953773413959425, 0.03892556400387548, 0.03161929453199264, 0.030639401702501345, 0.07279924713657238, 0.06768809093046002, 0.044548160149133764, 0.040662356550456025, 0.06776384936529212, 0.031438344085472636, 0.033253177170990966, 0.028626244493352715, 0.0555877330043586, 0.03807919281825889, 0.053970292647136375, 0.024714721766940784, 0.05607209568552207, 0.01337769612291595, 0.007592269066662993, 0.019613237600424327, 0.022715570739819668, 0.023497304573538713, 0.06663735824986361, 0.019770290891756304, 0.06461312819737941, 0.060504012362798676, 0.045873554263380356, 0.018660600144357886, 0.09069802341400646, 0.04909379611490294, 0.017685458915366326, 0.06933861994184554, 0.04915668941976037, 0.037925208307569847, 0.019881217849615496, 0.037605528195854276, 0.07150934252422303, 0.06992326903855428, 0.03507961373543367, 0.015599856960761826, 0.03966093958297279, 0.07569422421511263, 0.03361082555784378, 0.01866288781457115, 0.032909176879911683, 0.08722128419321962, 0.005757235185228637, 0.053288540948415175, 0.004238340907249949, 0.03381788104888983, 0.01880024265119573, 0.04717805320979096, 0.08231118321418762, 0.015173293668340193, 0.013994206547067733, 0.031052564590936527, 0.0649979614536278, 0.10498874486074783, 0.003932437375624431, 0.011766795942094177, 0.18583116587251425, 1.965750299859792, 6.277679242193699, 11.221641451120377, 18.120397366583347, 29.503015279769897, 33.15703220665455, 35.2215526252985, 35.89319318532944, 43.003041073679924, 44.677459225058556, 49.292471185326576, 49.40157473087311, 48.89359138906002, 45.31416445970535, 38.94115403294563, 37.6296354085207, 39.85351547598839, 44.22926187515259, 45.23438774049282, 48.09439927339554, 45.416622161865234, 47.12285600602627, 41.171793937683105, 26.841328404843807, 16.737028397619724, 11.81194357573986, 4.9158997647464275, 1.7476709769107401, 0.48207974585238844, 0.05016511226131115, 0.11702594230882823, 0.03127822572423611, 0.029698523576371372, 0.018463136912032496, 0.034916816221084446, 0.033145395063911565, 0.0480560398864327, 0.03898010814737063, 0.04379968566354364, 0.024961461749626324, 0.029701293642574456, 0.03595710688387044, 0.018602061390993185, 0.07404548377962783, 0.07359240262303501, 0.03790561560890637, 0.010968303486151854, 0.03964172166888602, 0.06868300668429583, 0.043600630524451844, 0.03775204670091625, 0.003564117137102585, 0.06862794674816541, 0.05438022162707057, 0.042335728867328726, 0.04511310893576592, 0.004613838873410714, 0.07676909153815359, 0.03681537098600529, 0.02706050028791651, 0.04143919963098597, 0.026775354162964504, 0.015863820335653145, 0.046613783488282934, 0.026773762256198097, 0.09009913250338286, 0.057495549772283994, 0.0511207350064069, 0.041404689764021896, 0.030551080562872812, 0.025021805777214468, 0.01769559850799851, 0.04526331220404245, 0.041819676480372436, 0.06728171312715858, 0.03446644761424977, 0.031124597444431856, 0.027005182455468457, 0.07808772468706593, 0.04481314397708047, 0.03973899867560249, 0.041683180679683574, 0.030682997312396765, 0.0635175104252994, 0.05972429346002173, 0.012687738126260228, 0.02617369689687621, 0.03771531039092224, 0.03787211506278254, 0.030842588748782873, 0.04152512177824974, 0.04118510682019405, 0.0685104499279987, 0.09035727372975089, 0.05250386078841984, 0.04692254289693665, 0.036770701117347926, 0.07647152742720209, 0.15405735990498215, 0.152639887528494, 0.09993629253585823, 0.09552976844133809, 0.18139647727366537, 0.10484102778718807, 0.12922875001095235, 0.19460563722532243, 0.20920541865052655, 0.14460743026575074, 0.12266754114534706, 0.15811929741175845, 0.15254288882715628, 0.10433877192554064, 0.10228415092569776, 0.10632045465172268, 0.19009533862117678, 0.13729200640227646, 0.17757119581801817, 0.14449734007939696, 0.11089338309830055, 0.2055062577710487, 0.10577568114968017, 0.14095941820414737, 0.10000722701079212, 0.19382599624805152, 0.11064284888561815, 0.09149010278633796, 0.14113806799286976, 0.14958458428736776, 0.17444957426050678, 0.12474562885472551, 0.25851155805867165, 0.11949726438615471, 0.10156750344322063, 0.1093270507408306, 0.17468044155975804, 0.11419955451856367, 0.19197499088477343, 0.24855668598320335, 0.09925370963173918, 0.13274960248963907, 0.13315337535459548, 0.21575234859483317, 0.15350753237726167, 0.1869391478248872, 0.12634538754355162, 0.18705931637668982, 0.14722902240464464, 0.16983764595352113, 0.15851753385504708, 0.1614085552864708, 0.11918490927200764, 0.17167898855404928, 0.1505842275219038, 0.18256081792060286, 0.16917320113861933, 0.133496351481881, 0.192033383063972, 0.12389353942126036, 0.04840707202674821, 0.10563622417976148, 0.1433905158773996, 0.1493728198693134, 0.164024195400998, 0.10385595291154459, 0.12660404085181653, 0.0738729047589004, 0.16063203132944182, 0.18847730825655162, 0.18233662995044142, 0.12897834938485175, 0.1581930965767242, 0.13758818269707263, 0.23080577520886436, 0.22833282040664926, 0.14907092903740704, 0.23718665703199804, 1.1884514219127595, 4.121618885546923, 8.226428423076868, 13.477814085781574, 23.549071066081524, 28.925678059458733, 31.54196687042713, 33.54688748717308, 42.021637335419655, 45.33038578927517, 49.781238958239555, 50.48433803021908, 47.29074999690056, 45.6976892799139, 38.55417139828205, 38.21644552052021, 39.47260111570358, 42.257764264941216, 44.944318905472755, 48.53540740907192, 48.269664868712425, 48.70184227824211, 38.658646792173386, 25.423212200403214, 14.677815344184637, 7.925829878076911, 2.442876328714192, 0.8079663198441267, 0.4168903548270464, 0.20190329407341778, 0.21715842158300802, 0.23918062972370535, 0.1976983150234446, 0.13340629928279668, 0.09534405340673402, 0.13017923338338733, 0.2480297611327842, 0.15804408816620708, 0.1157717795285862, 0.08045490118092857, 0.13646086037624627, 0.1291624316945672, 0.09491512173553929, 0.19726366881513968, 0.2320290869101882, 0.12049675176967867, 0.1804466766770929, 0.09611164932721294, 0.1900132719310932, 0.1675293143489398, 0.18032635969575495, 0.15588633832521737, 0.19551899837097153, 0.21892513381317258, 0.1326523069292307, 0.17999375879298896, 0.19598701153881848, 0.23817322362447158, 0.1230133225908503, 0.07205701782368124, 0.11589400382945314, 0.10563430201727897, 0.214337800280191, 0.12540801049908623, 0.1468397956341505, 0.1979829731862992, 0.12450810449081473, 0.12117159407353029, 0.14923736307537183, 0.17257538420381024, 0.16266418009763584, 0.15179639216512442, 0.17618888639844954, 0.12132800911786035, 0.15460797410923988, 0.1251749464427121, 0.12075323800672777, 0.14210787689080462, 0.18822570535121486, 0.13257494545541704, 0.08871429236023687, 0.09165370924165472, 0.14979722443968058, 0.15894305164692923, 0.14306747383670881, 0.114196207432542, 0.12342499932856299, 0.13765693525783718, 0.05630957552057225, 0.13095072557916865, 0.13915228861151263, 0.11323592028929852, 0.13084342586807907, 0.10154582530958578, 0.17697185219731182, 0.1498934513074346, 0.15066810505231842, 0.23789934144588187], [0.024532841780455783, 0.026917518116533756, 0.04554325401841197, 0.0146116502219229, 0.05950674029008951, 0.05643404110742267, 0.06310138080152683, 0.006353904755087569, 0.06650057301158085, 0.03486655798042193, 0.08231035200878978, 0.014122682514425833, 0.060708303353749216, 0.034692635672399774, 0.020443231442186516, 0.021867292234674096, 0.012763124559569405, 0.0908441300271079, 0.034597251142258756, 0.037717863378929906, 0.031166525077424012, 0.04271406462066807, 0.0475285250286106, 0.05637280279188417, 0.027163243212271482, 0.0793581701873336, 0.04115378818823956, 0.010016674423241057, 0.08349784766323864, 0.09748433309141546, 0.027718237943190616, 0.01957778149517253, 0.00560000053155818, 0.03274100621638354, 0.0432861009176122, 0.03417876148887444, 0.03503125910356175, 0.05047470287536271, 0.029812645479978528, 0.009863871782727074, 0.0459084018075373, 0.017138475668616593, 0.10440528320032172, 0.05303547230141703, 0.04197105605271645, 0.010567754325165879, 0.054528116816072725, 0.04508977952355053, 0.03162791457725689, 0.023363009240711108, 0.02650979888130678, 0.07176712751970626, 0.05452563433209434, 0.04184656449069735, 0.041668515841593035, 0.023757327144267038, 0.02322149095562054, 0.027195148140890524, 0.009916167218761984, 0.02511941118427785, 0.026028844513348304, 0.019121657533105463, 0.05297995223372709, 0.06448420230299234, 0.03426418268645648, 0.04494368033192586, 0.04761747142765671, 0.02452097112836782, 0.06008434640534688, 0.033095786202466115, 0.06381675179000013, 0.023088058369467035, 0.05823779392812867, 0.04026888098451309, 0.013263162327348255, 0.013739393853029469, 0.01909869177325163, 0.0608397043106379, 0.020515286560112145, 0.04271933015843388, 0.01877806913398672, 0.0348813712480478, 0.10954286728519946, 0.12705207540420815, 0.2990693645551801, 0.6168346758931875, 1.1193520110100508, 1.6860043234191835, 1.8547174078412354, 1.7740724352188408, 1.6545035387389362, 1.1138579808175564, 0.8949343312997371, 0.6955210911110044, 0.9105291101150215, 0.8682082872837782, 1.2764446064829826, 0.9207665326539427, 0.8757434017024934, 0.8898986515123397, 0.24459562118863687, 0.08465899707516655, 0.055970503090065904, 0.09846868066233583, 0.16951681551290676, 0.048936716848402284, 0.03843116377538536, 0.012900400543003343, 0.04112630274903495, 0.028436998691176996, 0.08109314818284474, 0.07113334082532674, 0.009679696704552043, 0.061099626691429876, 0.03626259713200852, 0.026719995512394235, 0.046152664872352034, 0.022456826518464368, 0.061661191284656525, 0.010161007303395309, 0.006475310374298715, 0.05756921163992956, 0.08485296479193494, 0.03366119883139618, 0.011630760272964835, 0.04549610166577622, 0.027872853279404808, 0.07049790656310506, 0.010506811941013439, 0.034972896610270254, 0.0959448961657472, 0.0314781009365106, 0.026822706895472948, 0.05514310862054117, 0.03847955180390272, 0.06887803567224182, 0.037912536135991104, 0.02117014282703167, 0.04898068538750522, 0.011904374350706348, 0.04161963799560908, 0.03873209723678883, 0.025639309751568362, 0.08830867896904238, 0.03401815702090971, 0.0670367079146672, 0.05007889325497672, 0.026160143424931448, 0.027424366016930435, 0.06746554310666397, 0.05195174002437852, 0.07568485088995658, 0.03536847616487648, 0.04420608944201376, 0.086960174376145, 0.047208882024278864, 0.04120828409213573, 0.05291626112011727, 0.020273962400096934, 0.01796719487174414, 0.014026001081219874, 0.04287265044695232, 0.01277318251595716, 0.006843085830041673, 0.030931444234738592, 0.013857510366506176, 0.0279564469383331, 0.07845507294405252, 0.08529000813723542, 0.031859653900028206, 0.10036860840045847, 0.10058298517833464, 0.004552363534457982, 0.06654944343608804, 0.022339815805025864, 0.07109837082680315, 0.09247934853192419, 0.021100770572957117, 0.05083925694634672, 0.01794080966647016, 0.10871071935980581, 0.028342324767436367, 0.022303758560155984, 0.08331113815074787, 0.04881976179603953, 0.05162502064194996, 0.060503563363454305, 0.05148623531567864, 0.014843383050902048, 0.03944000221963506, 0.045075059024384245, 0.03150916352751665, 0.021570759708993137, 0.02566949846368516, 0.0390798193984665, 0.05011525849113241, 0.02264242652017856, 0.025877411135297734, 0.053399065291159786, 0.04603684901667293, 0.04099161407793872, 0.029045775008853525, 0.07885065249865875, 0.07102752540959045, 0.05943237709288951, 0.033868951941258274, 0.0448307996703079, 0.06776013120543212, 0.037320480405469425, 0.06585362803889439, 0.04783723990840372, 0.044079297222197056, 0.010036224448413122, 0.04384616266179364, 0.040900571111706086, 0.039098098495742306, 0.04849591823585797, 0.07349012725171633, 0.015352534392150119, 0.02520031270250911, 0.0033152093874377897, 0.04970816080458462, 0.02289511110575404, 0.02679512312170118, 0.04279639477317687, 0.04457639515749179, 0.06562000737176277, 0.033227161184186116, 0.02739623305387795, 0.06599618718610145, 0.043993653380312026, 0.0050666997049120255, 0.05815237273054663, 0.02450865889841225, 0.0363471685705008, 0.024794189084786922, 0.033745039254426956, 0.041958773508667946, 0.02038531980360858, 0.05324626821675338, 0.04164160927757621, 0.018530948800616898, 0.04950370283040684, 0.03775545315875206, 0.028025026949762832, 0.06843854323960841, 0.08071383650531061, 0.04856371342611965, 0.01678903543506749, 0.07048381317872554, 0.053781768583576195, 0.025675968136056326, 0.030418145215662662, 0.023978027020348236, 0.07510294031817466, 0.1294423104263842, 0.02792321171000367, 0.03664862895675469, 0.39524733962025493, 0.9034609550144523, 1.613054412882775, 2.3809406021609902, 4.067962439730763, 4.941591611132026, 4.9895151145756245, 5.245496928691864, 4.811257654801011, 3.3420446421951056, 3.050188715569675, 2.679781741462648, 2.438085498288274, 3.1347339414060116, 3.312453730031848, 3.178670983761549, 3.1422573002055287, 3.2010764814913273, 1.1557502578943968, 0.5577029613777995, 0.23622930137207732, 0.029256231391627807, 0.05963596675428562, 0.016085626011772547, 0.05621812066237908, 0.024037217008299194, 0.08994970849016681, 0.026946743892040104, 0.03633868582255673, 0.01742901535180863, 0.03456858939898666, 0.040511622646590695, 0.045294337687664665, 0.024857525822881144, 0.037413274840218946, 0.053583845219691284, 0.03869757252687123, 0.008374639292014763, 0.03991682096966542, 0.0520355804474093, 0.0739957598852925, 0.02523305440263357, 0.03517684621328954, 0.062231205229181796, 0.06926285408553667, 0.07291891844943166, 0.04458521187189035, 0.027086126647191122, 0.05179581850825343, 0.039091831058613025, 0.007685558421144378, 0.008805391080386471, 0.00884191773366183, 0.03402737078431528, 0.07998955974471755, 0.00891594232598436, 0.05762993787357118, 0.053489299316424876, 0.02935501866886625, 0.0634085334604606, 0.06920770509168506, 0.03515957643685397, 0.11209685719222762, 0.04526364617049694, 0.006011332170601236, 0.07755038750474341, 0.03075324715609895, 0.04524773823504802, 0.021861555433133617, 0.09185115020954981, 0.05772890326625202, 0.025902785164362285, 0.07485018708393909, 0.016641279398754705, 0.020023404067615047, 0.026686587734729983, 0.020246378626325168, 0.040072044866974466, 0.012311280934227398, 0.009852291495917598, 0.015812879319128115, 0.015412270786328008, 0.04519566173257772, 0.022354391585395206, 0.016555483416595962, 0.04315337151638232, 0.0288564420043258, 0.06903789428179152, 0.009603286107449094, 0.0983691809233278, 0.0046585806376242545, 0.020334694199846126, 0.05710755125619471, 0.03238107201468665, 0.14467503991909325, 0.07260929443873465, 0.10680287290597335, 0.06562916547409259, 0.27094235352706164, 0.1245969915180467, 0.09386895326315425, 0.1109941593313124, 0.11819807550637051, 0.06965861917706206, 0.18439744046190754, 0.135555766755715, 0.14035968866664916, 0.1125350953952875, 0.16957617248408496, 0.14787069812882692, 0.09662079974077642, 0.17373552429489791, 0.12126902322052047, 0.11140450020320714, 0.06868006777949631, 0.09511363881756552, 0.13779543485725299, 0.2171745855594054, 0.20351534272776917, 0.187392006337177, 0.21349608607124537, 0.16737365629523993, 0.18384467402938753, 0.18087167496560141, 0.07872183050494641, 0.09420372865861282, 0.1307400150108151, 0.12492405599914491, 0.1531621813774109, 0.12749344547046348, 0.15388380124932155, 0.12677699094638228, 0.10695123564801179, 0.12978589511476457, 0.15760406880872324, 0.18424682901240885, 0.20849874563282356, 0.13059893273748457, 0.15511907637119293, 0.07518671394791454, 0.12489319749874994, 0.1540936212404631, 0.19651041860925034, 0.11753329672501422, 0.14521806937409565, 0.16480778460390866, 0.10425145825138316, 0.10325758150429465, 0.10803133511217311, 0.11260162151302211, 0.12893998034996912, 0.09785959264263511, 0.1018043450312689, 0.16005953861167654, 0.1045201528177131, 0.11523660941747949, 0.1726318764849566, 0.16398104693507776, 0.19725559424841776, 0.09700633803731762, 0.07825090069673024, 0.12573002837598324, 0.18488143949070945, 0.15054714982397854, 0.20402791444212198, 0.18468572030542418, 0.1786553845158778, 0.3180244693066925, 0.14459656522376463, 0.10465525338076986, 0.15165131713729352, 0.11573974843486212, 0.21313322038622573, 0.21140529279364273, 0.23635749996174127, 0.1932035421486944, 0.2787098492262885, 0.3688715002499521, 1.01050756406039, 1.3792948750779033, 2.3584840446710587, 2.8300636773929, 2.7415597764775157, 3.2794249523431063, 2.9486591136083007, 1.7321739834733307, 1.7008152161724865, 1.5224261884577572, 1.2287549092434347, 1.8457388458773494, 1.9834529561921954, 1.8458199477754533, 1.9079804560169578, 1.8241020943969488, 0.6587298028171062, 0.37671430909540504, 0.21466394449817017, 0.17799137014662847, 0.17114499845774844, 0.09539709470118396, 0.1548774924594909, 0.07052572967950255, 0.1819123441237025, 0.12208009415189736, 0.20691336976597086, 0.18641024886164814, 0.16740123450290412, 0.2331354361376725, 0.13648211548570544, 0.21112859045388177, 0.09153408245765604, 0.21542031172430143, 0.12827301223296672, 0.15814936923561618, 0.09460523797315545, 0.13910041248891503, 0.20774009259184822, 0.08554932195693254, 0.13709558959817514, 0.1614634890574962, 0.18558397132437676, 0.1908506519976072, 0.1419726575841196, 0.11349866283126175, 0.19150449894368649, 0.13460461545037106, 0.10915257182205096, 0.1357581652700901, 0.11103038355940953, 0.12182168575236574, 0.14039029483683407, 0.14712473581312224, 0.1136483762820717, 0.10702181389206089, 0.14037807908607647, 0.1762599396170117, 0.23064383858582005, 0.15865334687987342, 0.2485783418524079, 0.1284691915498115, 0.130657265544869, 0.13438318826956674, 0.16261176962871104, 0.12573624757351354, 0.0896898825885728, 0.1449507923098281, 0.16281229793094099, 0.10554566732025705, 0.16311963612679392, 0.22277581156231463, 0.096634922811063, 0.19709555752342567, 0.14325629104860127, 0.0996036767901387, 0.10166832420509309, 0.12031780512188561, 0.10773046102258377, 0.10841645780601539, 0.13851402676664293, 0.0787398053216748, 0.11946296974201687, 0.16812951886095107, 0.18557338829850778, 0.18624004471348599, 0.2555518731242046, 0.2059743006248027, 0.12579823174746707, 0.1703049466595985, 0.179513797047548, 0.14776412572246045], [0.0541633438115241, 0.006590877610506141, 0.04011253644421231, 0.04798896457941737, 0.02675001167517621, 0.02729016345256241, 0.02411863060842734, 0.03464169836661313, 0.004012747031083563, 0.12833882588893175, 0.08161861842381768, 0.010405360353615833, 0.035151976844645105, 0.028388727550918702, 0.03795608536165673, 0.08612140649347566, 0.021809282261529006, 0.029688866379729006, 0.0037332073679863242, 0.015428166661877185, 0.014883943276799982, 0.014393370674952166, 0.018775289790937677, 0.03583289733796846, 0.021266651710902806, 0.021874507765460294, 0.022023054189048707, 0.020467707472562324, 0.012898989534733118, 0.01661592392338207, 0.06578789601917379, 0.08175057228072546, 0.02629149799759034, 0.09314032751717605, 0.08417594057391398, 0.0495242046599742, 0.07970116857904941, 0.03312258886580821, 0.04832732454815414, 0.02609052069601603, 0.018123955014743842, 0.08985766733530909, 0.028229642630321905, 0.021998687625455204, 0.04778427282872144, 0.01584168949193554, 0.03625187309808098, 0.01020687759591965, 0.08836969835101627, 0.0677209606510587, 0.025755069946171716, 0.0012824432451452594, 0.01828321248467546, 0.01901351733977208, 0.026344658035668544, 0.0798018483328633, 0.05656394663674291, 0.06803047333960421, 0.00933724564674776, 0.048483988211955875, 0.02438089817587752, 0.0619255183119094, 0.02239777568320278, 0.06218535534571856, 0.03196333193045575, 0.031180629594018683, 0.014711063686263515, 0.011707938992913114, 0.006727359959768364, 0.023101658225641586, 0.030987977334007155, 0.023720496210444253, 0.015244109399645822, 0.09471456374740228, 0.016341878472303506, 0.022769135248381644, 0.02598441769805504, 0.01735562807880342, 0.08269678088254295, 0.04178171562671196, 0.002350879162804631, 0.021712756679335143, 0.013213358652137686, 0.0780699799361173, 0.02001499738980783, 0.020084896568732802, 0.04470696861972101, 0.021281439003359992, 0.04625285480869934, 0.016627553377475124, 0.02771704865153879, 0.06816622699261643, 0.004508523479671567, 0.10526751779252663, 0.09513875309494324, 0.016985326074063778, 0.04167462742771022, 0.03510000053211115, 0.04229348211083561, 0.02553155176428845, 0.01825307943363441, 0.0417652399482904, 0.04749605977849569, 0.08130272326525301, 0.04805177253729198, 0.04335515775892418, 0.008748870041017653, 0.014737228102603694, 0.08391198833123781, 0.06746248545823619, 0.018841838173102587, 0.025846919998002704, 0.05083763535367325, 0.0477883323765127, 0.025145898434857372, 0.04760827621794306, 0.053553595280391164, 0.012059293967467966, 0.06017335217620712, 0.025325991700810846, 0.06173765104904305, 0.07736977844615467, 0.07315170048968866, 0.06412331815226935, 0.005292530140650342, 0.07106838063918985, 0.054226719512371346, 0.014792261135880835, 0.06218079484824557, 0.04087220993824303, 0.10259003451210447, 0.038925111293792725, 0.018812688467733096, 0.0070645941832481185, 0.030444953445112333, 0.008082189506239956, 0.00874776424097945, 0.03844776190817356, 0.09344651538413018, 0.0821989779069554, 0.02184522818424739, 0.06853985381894745, 0.027816822985187173, 0.026562135135463905, 0.02738740706263343, 0.02537564138037851, 0.04328667237132322, 0.03178459679475054, 0.0692681159125641, 0.010038912878371775, 0.09338962234323844, 0.030988470862212125, 0.04799296846613288, 0.034825535767595284, 0.03583661178709008, 0.05281758516503032, 0.05753575562266633, 0.06472474720794708, 0.019330920913489535, 0.06898778447066434, 0.0519123505364405, 0.04548489523585886, 0.08542370604118332, 0.09147953460342251, 0.017142976794275455, 0.06301165514742024, 0.02212803654401796, 0.05198235732677858, 0.011015304626198485, 0.025177745847031474, 0.0931408024916891, 0.008083152442850405, 0.035567913510021754, 0.0382709637779044, 0.008494354206050048, 0.007243448062581592, 0.028699852555291727, 0.014976806360209594, 0.05316317736287601, 0.050424752625986, 0.04351264149590861, 0.07009413369814865, 0.030680266208946705, 0.05365666846046224, 0.03580246186174918, 0.029326841176953167, 0.023797423527867068, 0.0649779754166957, 0.033951026052818634, 0.022085756390879396, 0.03620761141064577, 0.06844706309493631, 0.017543547292007133, 0.02030323084909469, 0.020132154677412473, 0.03568187770724762, 0.03790687354921829, 0.05804617881949525, 0.009832647774601355, 0.016691923556209076, 0.014892516010149848, 0.016963631242106203, 0.015548653409496183, 0.02417472584056668, 0.0383426923508523, 0.005689537865691818, 0.010222102755506057, 0.04022816305223387, 0.04593157165800221, 0.0601026663207449, 0.04696513104136102, 0.013091459968563868, 0.0688354809244629, 0.034576363395899534, 0.04428383312188089, 0.046541613337467425, 0.06233348060050048, 0.08958297621575184, 0.015068140619405312, 0.0170018537028227, 0.03883468802087009, 0.015464163607248338, 0.01992085039091762, 0.02528688793972833, 0.043950768376816995, 0.012277542900847038, 0.03153804049361497, 0.011761389396269806, 0.016974904465314467, 0.05239797857939266, 0.02244676299596904, 0.05204141001740936, 0.003512250755193236, 0.07272202667081729, 0.07657826310605742, 0.019672943381010555, 0.06069082948670257, 0.025507040481898002, 0.03409129938518163, 0.0275400575628737, 0.0664565636543557, 0.013475338637363166, 0.04380098442197777, 0.09364906974951737, 0.05861010344233364, 0.02093390608933987, 0.1146645842527505, 0.01977805746719241, 0.046932788245612755, 0.017627860834181774, 0.0612407572043594, 0.014056790005270159, 0.01087493852537591, 0.04475982437725179, 0.07328064864850603, 0.048278561735060066, 0.0614024526294088, 0.02160675016057212, 0.02333665372134419, 0.042374584008939564, 0.058632924483390525, 0.01665829313424183, 0.044409716210793704, 0.06916996688232757, 0.05051679378084373, 0.0229957760166144, 0.07509106595534831, 0.030298900637717452, 0.0770935213949997, 0.07228600748931058, 0.05226282235526014, 0.05389742487750482, 0.08119086676742882, 0.036790887534152716, 0.07558351062471047, 0.022640431998297572, 0.047630718763684854, 0.0038452992657767027, 0.012254424073034897, 0.017061186554201413, 0.03597591661673505, 0.04247390934324358, 0.009261192208214197, 0.04175123562163208, 0.045040389595669694, 0.0586060179193737, 0.051438099617371336, 0.044021331777912565, 0.03635123182903044, 0.02245538304123329, 0.04907002512481995, 0.021952455535938498, 0.02698642096220283, 0.039759559876983985, 0.006254603540583048, 0.004223958085276536, 0.036610875904443674, 0.043739397297031246, 0.05302222867612727, 0.020394392558955587, 0.024450164673908148, 0.012148652258474613, 0.02468383729137713, 0.010662070162652526, 0.0306048640049994, 0.07234047370729968, 0.06128913038992323, 0.03882464676280506, 0.005344357095964369, 0.02386625772487605, 0.048501027922611684, 0.015127561600820627, 0.04170037624135148, 0.052881116716889665, 0.04135006027354393, 0.008346416343556484, 0.01724245426885318, 0.06470605250797234, 0.0437009206507355, 0.007871421421441482, 0.028764673588739242, 0.05846943306096364, 0.02278983189171413, 0.0563233757566195, 0.03337935711897444, 0.059039027692051604, 0.041045427205972373, 0.00023414044591163474, 0.08699778642039746, 0.0651651005318854, 0.024204215078498237, 0.061665781468036585, 0.05542060134757776, 0.05247662396868691, 0.03392707323655486, 0.08380600222153589, 0.014919224977347767, 0.004293868860258954, 0.05476802718476392, 0.04149265652813483, 0.02598946615762543, 0.06858241598820314, 0.015545445476163877, 0.031598566347383894, 0.013716773191845277, 0.023561264715681318, 0.03622950105636846, 0.020330812767497264, 0.035373159116716124, 0.024672133622516412, 0.08682159314048477, 0.01994778107473394, 0.09396584064234048, 0.12419402017258108, 0.17230683064553887, 0.13753639563219622, 0.14079958928050473, 0.10709670401411131, 0.1621539832558483, 0.07722194262896664, 0.08918120714952238, 0.24951735162176192, 0.2092940459260717, 0.12099220213713124, 0.10908446492976509, 0.1510745199630037, 0.09943123877746984, 0.19060880091274157, 0.14192569447914138, 0.09707834862638265, 0.09931807609973475, 0.10772680965601467, 0.09153662060271017, 0.09346081656985916, 0.09535446573863737, 0.09301983242039569, 0.16384907823521644, 0.09995643442380242, 0.16593538894085214, 0.11973236192716286, 0.09768197443918325, 0.061461238146875985, 0.10019239285611548, 0.23560941510368139, 0.14703077991725877, 0.2624510560417548, 0.11966815131017938, 0.1282205869210884, 0.1612709611072205, 0.12019056390272453, 0.10995651071425527, 0.10832203435711563, 0.1510753808543086, 0.13363443547859788, 0.10657231730874628, 0.06863093018182553, 0.11802991226431914, 0.1019555056700483, 0.1482142976601608, 0.17450648214435205, 0.1119485983508639, 0.1293405471369624, 0.13984830438857898, 0.1085186589625664, 0.061970533279236406, 0.144049825030379, 0.0952850526664406, 0.28160962800029665, 0.1352405914803967, 0.14485165622318164, 0.1846533626667224, 0.12675656704232097, 0.18603141215862706, 0.16746786452131346, 0.16024495678720996, 0.2002403637743555, 0.13291674898937345, 0.13596460106782615, 0.134376093337778, 0.19358411547727883, 0.13201126945205033, 0.09658218579716049, 0.16622607334284112, 0.08497399423504248, 0.13020345708355308, 0.1715606456855312, 0.13042288046563044, 0.08839697227813303, 0.06410698348190635, 0.14240521093597636, 0.21702634898247197, 0.18121033179340884, 0.15778481145389378, 0.1671308997902088, 0.17586841218871996, 0.16654890758218244, 0.09163816124782898, 0.12977958685951307, 0.1182433613575995, 0.18416014616377652, 0.1259805032168515, 0.1077567701577209, 0.14904023380950093, 0.16431723983259872, 0.3438170696608722, 0.1715087695629336, 0.3079952043481171, 0.08882975569576956, 0.09088687031180598, 0.1201049645897001, 0.18865606194594875, 0.13369192223763093, 0.13975641166325659, 0.14968990988563746, 0.1510161574697122, 0.19670603389386088, 0.12207978987134993, 0.15854583936743438, 0.18441109597915784, 0.11437916167778894, 0.1705557480454445, 0.1480833234381862, 0.1186087132373359, 0.1387948406045325, 0.09591532158083282, 0.09882796919555403, 0.18548937718151137, 0.11041387406294234, 0.20610523031791672, 0.09037788317073137, 0.1360818455577828, 0.21299874322721735, 0.14717806654516608, 0.1694785206927918, 0.23438595497282222, 0.12288453028304502, 0.07208513037767261, 0.2035839023301378, 0.11306635438813828, 0.07466122886398807, 0.1798838615650311, 0.17751511913957074, 0.1205179475073237, 0.1200887635059189, 0.1186325732851401, 0.11873429946717806, 0.13550669595133513, 0.0983059276768472, 0.0846399535657838, 0.17203627328854054, 0.22836624673800543, 0.10421951621538028, 0.09951452258974314, 0.10865839052712545, 0.15516519342781976, 0.08420867670793086, 0.11510843309224583, 0.15133027889532968, 0.14384993497515097, 0.15516918618232012, 0.15154234017245471, 0.17948089021956548, 0.1449050908559002, 0.112320792832179, 0.172271741903387, 0.15191618964308873, 0.12663323694141582, 0.16920818598009646, 0.09885064180707559, 0.131601678149309, 0.09761740016983822, 0.16498745855642483, 0.16387809620937333, 0.12608946533873677, 0.20369510573800653, 0.2625426073791459, 0.13088516425341368, 0.1266004191711545, 0.06764204808860086, 0.1360417398973368, 0.11056258561438881, 0.09917660048813559, 0.1595613348763436, 0.08038687592488714, 0.08717285905731842, 0.08474956877762452, 0.167747980740387, 0.09669402745203115], [0.06414144139853306, 0.02593973113107495, 0.06671930619631894, 0.05912482738494873, 0.031557737092953175, 0.01883585089672124, 0.06630976684391499, 0.02306252106791362, 0.009671122115832986, 0.02988953569001751, 0.024080185503407847, 0.010975049608532572, 0.06061560539819766, 0.00476368173622177, 0.06792841319111176, 0.028242841726751067, 0.09486962066148408, 0.04128547487198375, 0.027242601063335314, 0.07378293419606052, 0.03200498496880755, 0.022334878667606972, 0.014525587066600565, 0.07863987513701431, 0.01764364817063324, 0.010994352869602153, 0.04721497134596575, 0.018852183711715043, 0.02419396972982213, 0.052630912759923376, 0.030110909065115266, 0.03557961346814409, 0.03745236375834793, 0.06373535303282551, 0.04119179728149902, 0.03317467650049366, 0.04212758612993639, 0.05278399556118529, 0.02837096053553978, 0.0651365946396254, 0.04682272774516605, 0.054065725416876376, 0.022288166037469637, 0.03298539173556492, 0.007453378448190051, 0.07415049767587334, 0.054618866633973084, 0.040152604997274466, 0.04909650124318432, 0.07060364034259692, 0.04181072617939208, 0.04889566494966857, 0.024198897590395063, 0.09018719574669376, 0.010576032982498873, 0.02924902884842595, 0.08023187838261947, 0.06449104490457103, 0.024414369036094286, 0.047155258143902756, 0.1229223575501237, 0.10842508156201802, 0.02808876073686406, 0.062263703875942156, 0.06575829174835235, 0.09049268599483185, 0.022685738258587662, 0.04700675810454413, 0.050775684576365165, 0.07939760049339384, 0.04868357769737486, 0.10642336827004328, 0.029438243109325413, 0.011327094780426705, 0.0021463938219312695, 0.015068815973791061, 0.043685550772352144, 0.02049835260550026, 0.0356094886228675, 0.029823237782693468, 0.01801712285669055, 0.032153822685359046, 0.010616773179208394, 0.044798824237659574, 0.022560886754945386, 0.06503192955278791, 0.028313989569141995, 0.013922691341576865, 0.08338324521901086, 0.046368021285161376, 0.002020319861912867, 0.011173206748935627, 0.01951738366187783, 0.05821167775138747, 0.05913702458201442, 0.02235934356576763, 0.02297084913152503, 0.010781877845147392, 0.03838036376691889, 0.020059518828929868, 0.07943750577396713, 0.058423664813744836, 0.03042590251425281, 0.06278398650465533, 0.05956469460215885, 0.053231770361890085, 0.009183213824144332, 0.03316527348943055, 0.06335017838864587, 0.00893750357136014, 0.029977046033309307, 0.02770168433926301, 0.03450394462561235, 0.019383797080081422, 0.05522334962734021, 0.027184398131794296, 0.022316749855235685, 0.034297872480237857, 0.10646226422977634, 0.06081039318814874, 0.05071752246294636, 0.044320424713077955, 0.057475114736007527, 0.027521930605871603, 0.003519740184856346, 0.07240216102218255, 0.014042393268027809, 0.028955288653378375, 0.058789625254576094, 0.06075128854718059, 0.08085244742687792, 0.03853050024190452, 0.01448369004720007, 0.09666065307101235, 0.027422944804129656, 0.06392512019374408, 0.035050209844484925, 0.03988635209680069, 0.04538367000350263, 0.04871324134001043, 0.07097775698639452, 0.046101530897431076, 0.09194207814289257, 0.05714101098419633, 0.0612300665670773, 0.015608068824803922, 0.04389893678307999, 0.011081785287387902, 0.04779480390425306, 0.06241647497517988, 0.04411639347381424, 0.06708120708935894, 0.07307939304155298, 0.03997245235950686, 0.07578941207611933, 0.025957065845432226, 0.01242161231857608, 0.01859613534179516, 0.04175517642579507, 0.026378340407973155, 0.027321461675455794, 0.03319552713946905, 0.016253368085017428, 0.036572443787008524, 0.03418347783735953, 0.049955192080233246, 0.02292330715135904, 0.015155158362176735, 0.055146028971648775, 0.08632095516077243, 0.01768833473761333, 0.052047666322323494, 0.014460900547419442, 0.021116350108059123, 0.020784322514373343, 0.04511053739406634, 0.0274274719049572, 0.029309730962268077, 0.058895065885735676, 0.027444817751529627, 0.0522334184643114, 0.017870266674435697, 0.01775776079739444, 0.01998347095650388, 0.026336123337387107, 0.015239355016092304, 0.015798158819961827, 0.11051428664359264, 0.017523351598356385, 0.03013552795891883, 0.04451417720702011, 0.031872081162873656, 0.05638308524794411, 0.027550000486371573, 0.06391139046172611, 0.08175561888492666, 0.062408400408457965, 0.07531876428402029, 0.02505700584151782, 0.015055648418638157, 0.026767279596242588, 0.03294080350315198, 0.0348589954955969, 0.03146152135741431, 0.014539881758537376, 0.05753542165621184, 0.02656897031556582, 0.002988841829392186, 0.027175755822099745, 0.03113061626208946, 0.008224296871048864, 0.042764278332469985, 0.03453902965702582, 0.04333070399297867, 0.039970585858100094, 0.04690018940891605, 0.015928804641589522, 0.048724759471951984, 0.03349349572090432, 0.09603958678781055, 0.025431122485315427, 0.07187800438259728, 0.04351017014414538, 0.02786853026918834, 0.03959805369959213, 0.06514760811114684, 0.029807706487190444, 0.03423642636334989, 0.026828061490959954, 0.05799323400424328, 0.023837961489334702, 0.030044464583625086, 0.03880969619785901, 0.018164481843996327, 0.05942797986790538, 0.015058002882142318, 0.07292751251952723, 0.04554865685349796, 0.051215596322435886, 0.04469557665288448, 0.03664586445665918, 0.06330778691335581, 0.023816997672838625, 0.0353053082653787, 0.02978344196890248, 0.02062983334326418, 0.04258729095454328, 0.07108182835509069, 0.06694949071970768, 0.026970017643179744, 0.050545685589895584, 0.037265145874698646, 0.017748762256815098, 0.030455766536761075, 0.05233100717305206, 0.045657221926376224, 0.013856824807589874, 0.059251857092021964, 0.05883170131710358, 0.006919766383362003, 0.12655091792112216, 0.028522392058221158, 0.051686618899111636, 0.04156399176281411, 0.059102132508996874, 0.12224056132254191, 0.027967939095105976, 0.0814234113204293, 0.01168265402156976, 0.031085421323950868, 0.025697434757603332, 0.013780836306978017, 0.02749565857811831, 0.030173197519616224, 0.03958071341912728, 0.033739758873707615, 0.05487593916768674, 0.07903618941782042, 0.09484928581514396, 0.0857059819099959, 0.02175511104724137, 0.0403452108730562, 0.03633614025602583, 0.019772198211285286, 0.117171180609148, 0.0077881431752757635, 0.06195859212311916, 0.03201315972546581, 0.039176380232675, 0.005130643148731906, 0.08300954417791218, 0.07663493350264616, 0.027541042763914447, 0.056670801059226505, 0.04338920749432873, 0.055223846866283566, 0.015868629452597816, 0.04944013417116366, 0.07882967940531671, 0.0229229620526894, 0.007165881570472266, 0.020804052510356996, 0.05948501391685568, 0.029004172065469902, 0.07901548349764198, 0.04234131352859549, 0.015480492711503757, 0.0064559662951069186, 0.011184739723830717, 0.05272361071547493, 0.034952595160575584, 0.013795361064694589, 0.01566327533510048, 0.10639092899509706, 0.01483304493376636, 0.005276690390019212, 0.033773266841308214, 0.05722485882870387, 0.07175750186434016, 0.012839464652643073, 0.04279865090211388, 0.03974562234361656, 0.09503508990746923, 0.034356431642663665, 0.01852283898188034, 0.07862749611376785, 0.02540438847063342, 0.08432535716565326, 0.0539134738210123, 0.038819373803562485, 0.04392931659822352, 0.01958362034201855, 0.060233480980969034, 0.004098567596884095, 0.10622817600960843, 0.030793818514212035, 0.018176493504142854, 0.04583813526551239, 0.050831583139370196, 0.014603781601181254, 0.06360294646583498, 0.05879280906810891, 0.03817961653112434, 0.014896478151058545, 0.10351290999096818, 0.023700588099018205, 0.029816942515026312, 0.01956687934580259, 0.017439553848817013, 0.04979941157216672, 0.011758075706893578, 0.019909938964701723, 0.15503628237638623, 0.19642091559944674, 0.20014697191072628, 0.09153346647508442, 0.10479149685124867, 0.12317026456003077, 0.1975615817354992, 0.1114617865823675, 0.0871525464754086, 0.30199033906683326, 0.1534501346759498, 0.12653929588850588, 0.1525925236637704, 0.13920999801484868, 0.19978529366198927, 0.07881123703555204, 0.20619005779735744, 0.17017962760291994, 0.12176860735053197, 0.14181506994646043, 0.14283957512816414, 0.09953611908713356, 0.09782261884538457, 0.1127641370112542, 0.10135657765204087, 0.07872274334658869, 0.14012730738613755, 0.11757729866076261, 0.12305745811318047, 0.11985172895947471, 0.1541220158105716, 0.1303006784291938, 0.19164063851349056, 0.09878754441160709, 0.09753175632795319, 0.12599540554219857, 0.12939524342073128, 0.13820103340549394, 0.09156809508567676, 0.15555157035123557, 0.13850574439857155, 0.1349291269434616, 0.12241506250575185, 0.13051924091996625, 0.11101661672000773, 0.16603630618192255, 0.25825557648204267, 0.17735882283886895, 0.1319076953222975, 0.22475085948826745, 0.1476461984566413, 0.21018975879997015, 0.09623507590731606, 0.2016201795777306, 0.10246773599646986, 0.13500902656232938, 0.1840453507611528, 0.12143212501541711, 0.13409814418992028, 0.14273408625740558, 0.14801569894189015, 0.20669465884566307, 0.07606415514601395, 0.14989410439739004, 0.11583417930523865, 0.16091674886411056, 0.11784915477619506, 0.08184151505702175, 0.1231743537937291, 0.19364324980415404, 0.17441120522562414, 0.26196551334578544, 0.3187003580387682, 0.10596590102068149, 0.15257849707268178, 0.11304621250019409, 0.16109637828776613, 0.16391115146689117, 0.18405899143544957, 0.19387643260415643, 0.08052264442085288, 0.21263912814902142, 0.23419825098244473, 0.12459841644158587, 0.1955855096457526, 0.1650166546460241, 0.16703571192920208, 0.14029541867785156, 0.1695373878465034, 0.27941037726122886, 0.10426402281154878, 0.15862808417296037, 0.07737806081422605, 0.12943187583005056, 0.15175297652604058, 0.08159322213032283, 0.11485048482427374, 0.1627062598709017, 0.16979181091301143, 0.1502391733811237, 0.14615229971241206, 0.15042574930703267, 0.14386286318767816, 0.15599730424582958, 0.14451985683990642, 0.13263292203191668, 0.1312085922108963, 0.1169766637030989, 0.1856168039375916, 0.1386741377064027, 0.16861678333953023, 0.09020611309097148, 0.24671019287779927, 0.11436103843152523, 0.19802279683062807, 0.20686388335889205, 0.0773091301380191, 0.14850437350105494, 0.1687229995150119, 0.12729311012662947, 0.12950678821653128, 0.14222719939425588, 0.11845422035548836, 0.14613877778174356, 0.151256732060574, 0.14632707549026236, 0.16543553763767704, 0.15140465693548322, 0.14222172234440222, 0.12696761899860576, 0.11680855241138488, 0.1328221696894616, 0.09350343811092898, 0.2272718312451616, 0.09423532930668443, 0.08703065614099614, 0.08295194609672762, 0.2363393025007099, 0.11146553442813456, 0.16170980787137523, 0.15005283494247124, 0.17750461032846943, 0.2541833824943751, 0.14430871582590044, 0.1377452359884046, 0.13335927680600435, 0.10458016287884675, 0.12104240100597963, 0.10446749001857825, 0.17070343543309718, 0.14998408238170668, 0.24273948016343638, 0.17703416291624308, 0.16686155955540016, 0.19305367284687236, 0.11375764268450439, 0.2309659158345312, 0.1166466528957244, 0.19996020302642137, 0.08099185244645923, 0.10779752890812233, 0.09989886602852494, 0.0955183690530248, 0.12081022752681747, 0.17128182080341503, 0.218686681764666, 0.13711829931708053, 0.128869624750223, 0.1573828494292684, 0.1474105814122595, 0.10873396342503838, 0.09475789032876492, 0.13817091705277562, 0.13841588515788317, 0.12541397736640647, 0.12398037812090479], [0.015915234471322037, 0.051490439582266845, 0.034450005332473665, 0.05478494815179147, 0.09833220712607726, 0.06299628526903689, 0.03589293708500918, 0.020129737131355796, 0.038605189984082244, 0.03252386493841186, 0.05823737461469136, 0.02843344565917505, 0.019334421995154116, 0.009642897312005516, 0.015006430112407543, 0.04946930057485588, 0.03727949530002661, 0.03967918528360315, 0.05466275353683159, 0.003482601723590051, 0.033057068358175457, 0.05782013919088058, 0.07696720043895766, 0.023100543148757424, 0.05157420950126834, 0.02917137051554164, 0.02165526064345613, 0.014257431485020788, 0.024057370028458536, 0.054773938391008414, 0.12225895916344598, 0.05806806104374118, 0.10011828198912553, 0.05735505008487962, 0.047731925442349166, 0.04446955557796173, 0.057366449473192915, 0.011613871774898143, 0.0544150951463962, 0.054735023877583444, 0.004117267862966401, 0.019626787361630704, 0.038750472813262604, 0.018689291573537048, 0.04211811632558238, 0.026874621980823576, 0.02899030874687014, 0.07867968393838964, 0.020238046163285617, 0.02513037085009273, 0.036104749742662534, 0.022536789219884668, 0.039731169017613865, 0.03993906684627291, 0.005660837623508996, 0.0429854828689713, 0.04089350586582441, 0.015113201970962109, 0.022445544018410146, 0.06332066317554563, 0.02086455609969562, 0.03679085413750727, 0.012824579953303328, 0.013545606107072672, 0.008384353077417472, 0.01921622570080217, 0.057147078041452914, 0.0620654576778179, 0.007465824728569714, 0.0369965181016596, 0.037346886019804515, 0.055888762944960035, 0.04780961346114054, 0.05226673718425445, 0.07363960321526974, 0.025291196106991265, 0.02324966659216443, 0.03204304230166599, 0.02500710754247848, 0.09201662687701173, 0.03097330692980904, 0.021777622241643257, 0.06021573623002041, 0.030686132886330597, 0.09855893324129283, 0.12915153696667403, 0.0515013157564681, 0.027932527518714778, 0.09852197428699583, 0.11715184024069458, 0.05114283245347906, 0.01417306413713959, 0.02378467714152066, 0.005329328141669976, 0.010610387926135445, 0.060167403862578794, 0.008242127896664897, 0.0209393441764405, 0.05585575592704117, 0.011153470259159803, 0.023294978418562096, 0.09822372740018182, 0.040913952034316026, 0.053778774017700925, 0.06436351424781606, 0.08130359899951145, 0.06342091248370707, 0.044684262611554004, 0.03566426283214241, 0.014499112803605385, 0.06387770437868312, 0.0596175132523058, 0.020714551355922595, 0.10948498718789779, 0.06345400484860875, 0.06909199684741907, 0.05386715638451278, 0.07027780782664195, 0.024272962073155213, 0.05100890819448978, 0.023575194827571977, 0.03362251809448935, 0.03251709284086246, 0.030963881654315628, 0.04077448393218219, 0.030834824028715957, 0.06984892068430781, 0.05884142345166765, 0.08514738961821422, 0.005493652624863898, 0.06417989206966013, 0.035672400481416844, 0.02899612347391667, 0.017436421985621564, 0.027849872676597442, 0.05211199197219685, 0.034697188748396, 0.04518052563071251, 0.037911560211796314, 0.017953671085706446, 0.06883223031763919, 0.03974471321271267, 0.06816540320869535, 0.07787738519255072, 0.06447578634833917, 0.0380094086722238, 0.05780751154816244, 0.05746118833485525, 0.012462479608075228, 0.07716663036262617, 0.01892251519166166, 0.03620063522248529, 0.07722327849478461, 0.04477244830923155, 0.04398083648993634, 0.041238322519348, 0.10638279505656101, 0.07170409691752866, 0.01440829990315251, 0.04041477608552668, 0.049965300131589174, 0.0459518693969585, 0.010700500424718484, 0.03276756026025396, 0.02370994658122072, 0.0663417014584411, 0.056415097787976265, 0.02559696094976971, 0.028494212710938882, 0.073200979095418, 0.08129763955366798, 0.04876307284575887, 0.04794465836312156, 0.030142320465529338, 0.013697148951905547, 0.026258177422278095, 0.08131383321597241, 0.06245611308258958, 0.04084262051037513, 0.05287628162477631, 0.02683962415176211, 0.05319318239344284, 0.01783669005817501, 0.03290366643341258, 0.02700078894122271, 0.04649472815799527, 0.12044264920405112, 0.012225112950545736, 0.037813548478879966, 0.00601263695898524, 0.07731106714345515, 0.04957107870723121, 0.027268045596429147, 0.017418278330296744, 0.026435201907588635, 0.05082553092506714, 0.057225033233407885, 0.11856324184918776, 0.09111738880164921, 0.07505092318751849, 0.017583324552106205, 0.039381880924338475, 0.02929314025095664, 0.014209793025656836, 0.04314898542361334, 0.03374169216840528, 0.014708118287671823, 0.05963239702396095, 0.0643149481038563, 0.031886400902294554, 0.004662918954636552, 0.012504177175287623, 0.03052538555493811, 0.013210052384238224, 0.006580067765753483, 0.019112287918687798, 0.036034312506671995, 0.029506064274755772, 0.027617504383670166, 0.045194118065410294, 0.024281591395265423, 0.051017995792790316, 0.019812921709672082, 0.05670087659382261, 0.07466800467227586, 0.050845962250605226, 0.02923802094301209, 0.022737946492270567, 0.05300847296894062, 0.031017720757517964, 0.06589234588318504, 0.06233931388123892, 0.0532602280145511, 0.00859469999340945, 0.01053930131092784, 0.03348296835611109, 0.049520100583322346, 0.058859754499280825, 0.039942918592714705, 0.037885867059230804, 0.060099308102508076, 0.05460512205900159, 0.046956748483353294, 0.05188063114474062, 0.04240705296979286, 0.0437374825560255, 0.011641449982562335, 0.07286806649062783, 0.017060446261893958, 0.02331474366656039, 0.04051095100294333, 0.01708161973510869, 0.037876274800510146, 0.052268128711148165, 0.01897682926937705, 0.031848291619098745, 0.05148977164935786, 0.06125995656475425, 0.04711147885245737, 0.03134126745862886, 0.039900230258353986, 0.05893524576094933, 0.025801674964895938, 0.01746694466419285, 0.025187694336636923, 0.09022422149428166, 0.02809216719469987, 0.017034313386830036, 0.021994440685375594, 0.03834033603197895, 0.0645765032095369, 0.035909227226511575, 0.052525943392538466, 0.050337220018263906, 0.061297008287510835, 0.0007060741393161152, 0.014628958961111493, 0.06180272626806982, 0.014760856229258934, 0.018869696541514713, 0.05813049792777747, 0.054547201143577695, 0.08396439137868583, 0.033252635403187014, 0.0525272198865423, 0.034935017392854206, 0.03311828440928366, 0.04174215173406992, 0.09596140153007582, 0.06975822281674482, 0.023424332903232425, 0.03203169486369006, 0.038401852652896196, 0.04082092382304836, 0.02145659142115619, 0.05683758019586094, 0.031009620215627365, 0.03309280647954438, 0.05550438982027117, 0.05494521865330171, 0.054064519426901825, 0.02347262816329021, 0.031742747087264434, 0.023687398279435, 0.03365993718034588, 0.030265407513070386, 0.07838344827177934, 0.028036289040755946, 0.045877650918555446, 0.04433304122358095, 0.0156420239363797, 0.025573863458703272, 0.030433296160481405, 0.02730704360146774, 0.08570244928705506, 0.009402768009749707, 0.03557340540282894, 0.051378275093156844, 0.08614565245807171, 0.02319833594810916, 0.06014964797941502, 0.045270833870745264, 0.04875604099652264, 0.04290989141736645, 0.04095841039088555, 0.09548094996716827, 0.047258687554858625, 0.01000235190076637, 0.018926574739452917, 0.04880280372162815, 0.0703971748589538, 0.04811590893950779, 0.062123308089212514, 0.017038803380273748, 0.04328161463490687, 0.01816602180042537, 0.050754188268911093, 0.04160432748903986, 0.003422340028009785, 0.008750850647629704, 0.0394546447932953, 0.0472293690108927, 0.10475352857611142, 0.03220941325707827, 0.02572540815890534, 0.005883879439352313, 0.04971175279933959, 0.022962156726862304, 0.04364492189779412, 0.022354048342094757, 0.029118729980837088, 0.019110000248474535, 0.1282959000673145, 0.16163715161383152, 0.1118882246373687, 0.1341343461535871, 0.18099577690009028, 0.09546776942443103, 0.07556140204542316, 0.08660153151140548, 0.17344794207019731, 0.17482079652836546, 0.18672456324566156, 0.1206593489041552, 0.17952455818885937, 0.10383313929196447, 0.13582782325102016, 0.12267026482732035, 0.11353125053574331, 0.13353575952351093, 0.1066770640318282, 0.11052070622099563, 0.18787135952152312, 0.18619021691847593, 0.21184660348808393, 0.08206002559745684, 0.22532606846652925, 0.10928043644526042, 0.13239038817118853, 0.08755082744755782, 0.20103250251850113, 0.19678140641190112, 0.21414478251244873, 0.11932801018701866, 0.18434164579957724, 0.20981154550099745, 0.14537359384121373, 0.14551357773598284, 0.2338684257119894, 0.16471375449327752, 0.10438215045724064, 0.18757420359179378, 0.1439788014977239, 0.1236463597160764, 0.10338765772758052, 0.14042584371054545, 0.1695796160493046, 0.09347456856630743, 0.08147271219058894, 0.13101269491016865, 0.1875514938728884, 0.12575293105328456, 0.12476400443119928, 0.14016928325872868, 0.13405401608906686, 0.105857295129681, 0.15879545331699774, 0.10958853163174354, 0.13089907210087404, 0.14277742768172175, 0.12279597722226754, 0.10066615766845644, 0.11000728845829144, 0.17446155252400786, 0.115715695428662, 0.09922889221343212, 0.13731103506870568, 0.24353212356800213, 0.14151044801110402, 0.13540232030209154, 0.17428570805350319, 0.07374719978542998, 0.13273066288093105, 0.15273240365786478, 0.13194603467127308, 0.12050288933096454, 0.09745914459927008, 0.13198866363381967, 0.08246328638051637, 0.121406609978294, 0.14827729115495458, 0.10214327645371668, 0.07881158584496006, 0.10730464637163095, 0.11934592563193291, 0.0555304985755356, 0.1993297040462494, 0.21923073538346216, 0.14906111784512177, 0.11138133035274222, 0.21280864952132106, 0.20272185327485204, 0.12207913678139448, 0.11355782684404403, 0.13076092873234302, 0.12159049932961352, 0.17093835485866293, 0.12560040486278012, 0.10464263687026687, 0.08159599034115672, 0.10365935799200088, 0.10783147474285215, 0.145034343295265, 0.37220142781734467, 0.1575180093641393, 0.11565141059691086, 0.23962970328284428, 0.1598546316381544, 0.184117324242834, 0.10522690005018376, 0.1602976641152054, 0.12296103828703053, 0.10811309752170928, 0.11858369543915614, 0.1374683852191083, 0.19571645418182015, 0.1713286354788579, 0.11486949122627266, 0.2319276798516512, 0.13601546786958352, 0.07428172422805801, 0.09069069099496119, 0.07489152470952831, 0.09614192153094336, 0.1393383153481409, 0.12945189897436649, 0.10893346756347455, 0.08461156641715206, 0.09794481346034445, 0.15149700979236513, 0.14781897043576464, 0.17443848657421768, 0.18165896006394178, 0.1660986614297144, 0.17296605074079707, 0.1227689630468376, 0.1323149711242877, 0.07088359328918159, 0.08764954793150537, 0.1752795625361614, 0.19735864887479693, 0.05612963068415411, 0.17245637340238318, 0.1365107178571634, 0.11740966234356165, 0.10958269835100509, 0.11505548085551709, 0.1490248565096408, 0.18207701185019687, 0.23629199800780043, 0.17404102196451277, 0.16404286783654243, 0.11284267849987373, 0.12321313100983389, 0.14567483158316463, 0.1369638880714774, 0.1479635259602219, 0.17835156410001218, 0.10064787857118063, 0.1821477830526419, 0.13581712148152292, 0.10201288110692985, 0.1044842551345937, 0.11045170133002102, 0.15719323069788516, 0.15534595091594383, 0.11538313163327985, 0.16954917315160856, 0.20819771569222212, 0.14722669206093997, 0.16636258398648351, 0.12402505541103892, 0.10757410535006784, 0.17308952927123755, 0.21891794982366264, 0.16953949554590508, 0.1030773732054513, 0.12338621469098143], [0.019114683200314175, 0.044345513015287, 0.044620823828154244, 0.030821645341347903, 0.013117928665451473, 0.05691967286111321, 0.03669001853268128, 0.0073742483436944894, 0.0133857187393005, 0.02329326034669066, 0.024401357331953477, 0.026095058929058723, 0.018414069818391, 0.07375338187557645, 0.05560318451898638, 0.014172338687785668, 0.080975970486179, 0.012190876750537427, 0.07133291917853057, 0.06723860919009894, 0.03124708149698563, 0.021067132729513105, 0.031358392516267486, 0.0316360559372697, 0.06311476172413677, 0.003983965616498608, 0.012495345617935527, 0.07364165154285729, 0.06301739194896072, 0.023705807252554223, 0.006109498826845083, 0.02439258143567713, 0.04427846739417873, 0.02906783720391104, 0.02634116623084992, 0.037512618728214875, 0.07881967525463551, 0.0629934280004818, 0.012752359707519645, 0.012050097830069717, 0.09180455075693317, 0.08723504361114465, 0.0021039728926552925, 0.04053317090438213, 0.07783066699630581, 0.024246710454463027, 0.04536768785328604, 0.021999596756359097, 0.04799208531039767, 0.04312999386456795, 0.06501850410131738, 0.0555924679065356, 0.07668499136343598, 0.042072771102539264, 0.04356908182671759, 0.022409282682929188, 0.10432395865791477, 0.08412011622567661, 0.07180826476542279, 0.046581722708651796, 0.04618025050149299, 0.06593689700821415, 0.031936173036228865, 0.021535650557780173, 0.034207853677798994, 0.016405536189267877, 0.06553863830049522, 0.053898660553386435, 0.02392287802649662, 0.04535613632469904, 0.06385968503309414, 0.039770654984749854, 0.007454310307366541, 0.011560209859453607, 0.0491517021873733, 0.040565317030996084, 0.02682608366740169, 0.006985595809965162, 0.026509097551752347, 0.03797440898779314, 0.038999463358777575, 0.02491597922926303, 0.06494197383290157, 0.033444718064856716, 0.04558600172458682, 0.011373392735549714, 0.011954728142882232, 0.05674796586390585, 0.02968130760564236, 0.03517058248689864, 0.031050143334141467, 0.05991091762552969, 0.03517829711199738, 0.07908598010544665, 0.03786826702707913, 0.017908741465362255, 0.020529780704237055, 0.04920239829516504, 0.03509342510369606, 0.03205703920684755, 0.01567790863191476, 0.05962871597148478, 0.0658904311421793, 0.038669226196361706, 0.031053494130901527, 0.030044588893360924, 0.04226051220030058, 0.041652852814877406, 0.06517542380606756, 0.014344309147418244, 0.028965710262127686, 0.016018591522879433, 0.05530117494345177, 0.04338193073635921, 0.0639206673076842, 0.015603369174641557, 0.03629322185588535, 0.06326610047835857, 0.017736342415446416, 0.06450824046623893, 0.023728554078843445, 0.02968746000988176, 0.034761822389555164, 0.03429867771046702, 0.02228129746072227, 0.05460980872157961, 0.06436145107727498, 0.014978061517467722, 0.08293302133097313, 0.04268734730430879, 0.03886114187480416, 0.037478086596820503, 0.02680332570889732, 0.09859975878498517, 0.03563345628208481, 0.009159768451354466, 0.04099424128071405, 0.06906559123308398, 0.06032383374986239, 0.03428331154282205, 0.024490635842084885, 0.057091294511337765, 0.04397929282276891, 0.035489594665705226, 0.04899623709206935, 0.016508939625055064, 0.0045925730955787, 0.030045323619560804, 0.019984636128356215, 0.027460239580250345, 0.049726695942808874, 0.04307079274440184, 0.0405813808174571, 0.06815297223511152, 0.04695477065979503, 0.01664058734604623, 0.06974128700676374, 0.051665801656781696, 0.01010493804642465, 0.010453263203089591, 0.05637560439936351, 0.046929756572353654, 0.009051561464730185, 0.0255108254350489, 0.02309097872057464, 0.05341979718650691, 0.02058403169939993, 0.05214637567405589, 0.01675852017797297, 0.041607808161643334, 0.06448362342780456, 0.00814641125543858, 0.06778215814847499, 0.0031233679237629985, 0.021253742052067537, 0.017721701697155368, 0.008864985538821202, 0.0027210730922888615, 0.04576081089908257, 0.0323407362884609, 0.02212691404565703, 0.04173573586740531, 0.04219071692205034, 0.0665693033079151, 0.045477547973860055, 0.020856416595051996, 0.018231635076517705, 0.024827331544656772, 0.020639395916077774, 0.041859117918647826, 0.03521678860124666, 0.02651571194292046, 0.025007055592141114, 0.008470252960250946, 0.03160544976708479, 0.07565850464743562, 0.02018380258959951, 0.009775817816262133, 0.047524706678814255, 0.02030638868745882, 0.010471751029399456, 0.010435552776471013, 0.028930443404533435, 0.028328285188763402, 0.025237997106160037, 0.024205680820159614, 0.019673921160574537, 0.01136484876042232, 0.05194398087041918, 0.052159808547003195, 0.10909435033681802, 0.020388535158417653, 0.05851713089214172, 0.03928895290300716, 0.020401296387717593, 0.07561774589703418, 0.124097540974617, 0.031863038093433715, 0.03334978253406007, 0.02557663723564474, 0.039868072999524884, 0.005021512188250199, 0.02007767732720822, 0.08581920395954512, 0.020201508377795108, 0.023713302944088355, 0.007808403806848219, 0.04206491546938196, 0.022773556593165267, 0.04197826601739507, 0.041108821460511535, 0.04705543185991701, 0.029222352350188885, 0.036441621705307625, 0.022358382484526373, 0.011707217254297575, 0.06265179516049102, 0.030820292777207214, 0.037900810202700086, 0.0273998955526622, 0.023699819976172876, 0.03879547664837446, 0.047596750664524734, 0.0486509454640327, 0.010603981336316792, 0.012310994279687293, 0.023769040089973714, 0.046791464774287306, 0.07294290466234088, 0.037028066799393855, 0.05997906162519939, 0.03893683351634536, 0.045279465048224665, 0.012888674609712325, 0.04161269520409405, 0.03487468449748121, 0.04766231570101809, 0.03814746298303362, 0.05984848816297017, 0.05339064562576823, 0.038820865520392545, 0.026215474244963843, 0.01360308544462896, 0.019500301277730614, 0.07609449414303526, 0.03896573274687398, 0.022128287018858828, 0.037291135886334814, 0.040813331652316265, 0.009733918941492448, 0.01989143536775373, 0.02562164663686417, 0.09357279923278838, 0.007666703695576871, 0.04420707278768532, 0.05154086851689499, 0.056017922615865245, 0.03292721477919258, 0.04964108549756929, 0.0575354736065492, 0.03145145783491898, 0.03359094342158642, 0.048656756480340846, 0.04714813352620695, 0.09554501215461642, 0.037366051983553916, 0.011635243772616377, 0.015156435783865163, 0.034673336122068577, 0.028971248539164662, 0.0483709999389248, 0.05679404210241046, 0.11164524548803456, 0.019521819849614985, 0.06814783657318912, 0.08912840334232897, 0.07204223424196243, 0.03419630214921199, 0.02448905877827201, 0.055043586617102847, 0.009042963683896232, 0.03613018314354122, 0.054515196025022306, 0.040170494467020035, 0.03408903212402947, 0.007498122995457379, 0.05346299018128775, 0.043008767752326094, 0.026751896730274893, 0.11938075462239794, 0.07505029978347011, 0.018840986558643635, 0.043613610687316395, 0.03670713987958152, 0.03348797785292845, 0.0188655386591563, 0.022766854999645147, 0.02313019009307027, 0.05713145212212112, 0.009890635483316146, 0.05312157627486158, 0.05284218364977278, 0.027971735180472024, 0.04083430103491992, 0.045225150970509276, 0.019736109425139148, 0.03675300831673667, 0.05513511940080207, 0.059330639778636396, 0.03740412044862751, 0.030197506566764787, 0.01947643751918804, 0.03578201198251918, 0.066057503427146, 0.09290980902733281, 0.033460177000961266, 0.026425732103234623, 0.0408572779269889, 0.03026898095413344, 0.04325059286202304, 0.058141303597949445, 0.06277360385865904, 0.06710495581501164, 0.004043052631459432, 0.041078330323216505, 0.03334555971377995, 0.05063674339908175, 0.0026783369821714587, 0.12051422192598693, 0.030157571600284427, 0.058279231743654236, 0.03514671501761768, 0.09645239158999175, 0.09169665732770227, 0.17369994573527947, 0.11325820698402822, 0.1200257996970322, 0.12931057921377942, 0.15314696735003963, 0.14966184186050668, 0.10977400917909108, 0.06056181824533269, 0.16189016459975392, 0.10604300274280831, 0.1103992092248518, 0.20745332672959194, 0.07849577974411659, 0.12012606384814717, 0.2924657939001918, 0.09584230167092755, 0.1253823025035672, 0.24144429888110608, 0.09654048451920971, 0.07340323660173453, 0.163279895496089, 0.15971687418641523, 0.14217121177352965, 0.05577250922215171, 0.08299934706883505, 0.19079637131653726, 0.18852085748221725, 0.07643983029993251, 0.2035399226588197, 0.11269086477113888, 0.07049326814012602, 0.06205094498000108, 0.15210506622679532, 0.16506936197401956, 0.19997001421870664, 0.16031430306611583, 0.08731023059226573, 0.1553483257885091, 0.27579041838180274, 0.19291297649033368, 0.1429722414468415, 0.17228420998435467, 0.16382308822358027, 0.19358603021828458, 0.2032573425094597, 0.1498660512152128, 0.1105157783604227, 0.12450960362912156, 0.16081584646599367, 0.12868012476246804, 0.17318075406365097, 0.1624936197185889, 0.1175377050822135, 0.09350382402772084, 0.12107076589018106, 0.13181644084397703, 0.12676453770836815, 0.10295709333149716, 0.11401504176319577, 0.12346287854597904, 0.07875050709117204, 0.11673795932438225, 0.07006775034824386, 0.10332897611078806, 0.16173095908015966, 0.1494926618761383, 0.09395266009960324, 0.11562984378542751, 0.16867410682607442, 0.11642280631349422, 0.21837432665051892, 0.17772174789570272, 0.11903397127753124, 0.1811972403083928, 0.06970311093027703, 0.13561387691879645, 0.1296177096082829, 0.11266402128967457, 0.18233239970868453, 0.10834938992047682, 0.1444836994051002, 0.13108256069244817, 0.1748739936738275, 0.15127049147849903, 0.1250026494381018, 0.106732524727704, 0.12206950370455161, 0.2386258594924584, 0.11650124390143901, 0.17783341143513098, 0.1451854594051838, 0.11296194163151085, 0.11930714841582812, 0.07306204162887298, 0.15335833100834861, 0.12505491147749126, 0.1619117017253302, 0.11532644639373757, 0.20181766507448629, 0.1721158908912912, 0.14768097549676895, 0.20520282327197492, 0.164613920787815, 0.13678880059160292, 0.19925767119275406, 0.10995752745657228, 0.19266962626716122, 0.1488645822973922, 0.1120603657909669, 0.08427751090493985, 0.1217998072388582, 0.14706338988617063, 0.18935639702249318, 0.22957167268032208, 0.19308236427605152, 0.06395089498255402, 0.12585744028910995, 0.39011164801195264, 0.10225321078905836, 0.09148664437816478, 0.1399228605441749, 0.15580845734803006, 0.08746623003389686, 0.2329852106049657, 0.1952113039442338, 0.10242116622976027, 0.14339959976496175, 0.084767476801062, 0.1784143943223171, 0.13485773233696818, 0.12947950686793774, 0.20936416403856128, 0.21500721748452634, 0.086656747298548, 0.16037759341998026, 0.12889628269476816, 0.09991798375267535, 0.10384419729234651, 0.12945828144438565, 0.0987761227588635, 0.14957805338781327, 0.21004441659897566, 0.09374248387757689, 0.07142446309444495, 0.10348210344091058, 0.12954012549016625, 0.17212745355209336, 0.08578968132496811, 0.16794907307485119, 0.1645479883882217, 0.20850830449489877, 0.13368984422413632, 0.20102616457734257, 0.13748037832556292, 0.0926906825043261, 0.1730182534083724, 0.11647145409369841, 0.06722388498019427, 0.0970481506374199, 0.1542948471615091, 0.0813474302412942, 0.1870617803069763, 0.14052906160941347, 0.18013126391451806, 0.13944913283921778, 0.1127829281904269, 0.10845181372133084, 0.13368179934332147, 0.12402731153997593, 0.13514403806766495, 0.20691240497399122, 0.1747880975017324, 0.12069335411069915, 0.10053141333628446], [0.0684363761683926, 0.029076446116960142, 0.04399396508233622, 0.057296494633192196, 0.02668740038643591, 0.057428107102168724, 0.0321170937968418, 0.017926977889146656, 0.02698041142139118, 0.022671798869851045, 0.07057493407046422, 0.03944028794649057, 0.051968701809528284, 0.047318315409938805, 0.05512614683539141, 0.02817057138599921, 0.010575423493719427, 0.02217220731836278, 0.04492500789638143, 0.025078732214751653, 0.009542385469103465, 0.04817266468307935, 0.048489543187315576, 0.020737446611747146, 0.056788899019011296, 0.030559010410797782, 0.02920041817560559, 0.031498625030508265, 0.036225786607246846, 0.062416445289272815, 0.03985746399848722, 0.0352395094523672, 0.0066311395858065225, 0.07390430502709933, 0.07430398865835741, 0.06094716729421634, 0.07945772929815575, 0.08123659790726379, 0.014694055516883964, 0.017549825861351565, 0.0565718950383598, 0.03243195365939755, 0.0863642743206583, 0.0737749486870598, 0.09487241855822504, 0.07039486677967943, 0.039285965758608654, 0.0556779855833156, 0.0034280974705325207, 0.055190004932228476, 0.023709265660727397, 0.019286898568680044, 0.051323341322131455, 0.016761177066655364, 0.07981088769156486, 0.051023168562096544, 0.027689390662999358, 0.05893962814297993, 0.020004453326691873, 0.042220695977448486, 0.06069627313991077, 0.00897343001270201, 0.05720236062188633, 0.02530029112676857, 0.060669882368529215, 0.028891380461573135, 0.050376223589410074, 0.06456195711507462, 0.009356744649267057, 0.046289791498566046, 0.026853999552258756, 0.05908240251301322, 0.02770624112599762, 0.04507513323915191, 0.025891929399222136, 0.04599621272063814, 0.028868815461464692, 0.052981677727075294, 0.019149578984070104, 0.052917129432898946, 0.03323016317153815, 0.043830755676026456, 0.044829007383668795, 0.008836617871565977, 0.0701828945602756, 0.03987638876424171, 0.042342359956819564, 0.036321378938737325, 0.03212575837096665, 0.11782752859289758, 0.019090568966930732, 0.028875407588202506, 0.028896775875182357, 0.0367028280015802, 0.04220463219098747, 0.030778936597926077, 0.008014944432943594, 0.07013514477876015, 0.08127534543746151, 0.028030483590555377, 0.07782769098412246, 0.06154541624709964, 0.03743165041669272, 0.028208736330270767, 0.1036709948675707, 0.04168151084741112, 0.01655848911468638, 0.08826440243865363, 0.033723739616107196, 0.05235223630734254, 0.07865137100452557, 0.06406359010725282, 0.039027958118822426, 0.04705030361947138, 0.06711516034556553, 0.05877511626749765, 0.035393152575124986, 0.02167079564969754, 0.03494016418699175, 0.07940271389088593, 0.04518494512012694, 0.012411057123244973, 0.030349247936101165, 0.02595135501906043, 0.005369320624595275, 0.031232227411237545, 0.030673059955006465, 0.06957946912734769, 0.008024799226404866, 0.014422359890886582, 0.030376115537364967, 0.020456855418160558, 0.04262346694304142, 0.027122762767248787, 0.0494709778286051, 0.03167179034790024, 0.005194643645154429, 0.04450205793546047, 0.04360690167231951, 0.04550487756205257, 0.04044671812152956, 0.07387898294837214, 0.0649951041850727, 0.06051688491425011, 0.033465119704487734, 0.017072311347874347, 0.07619261348736472, 0.009843589814408915, 0.040579388150945306, 0.05630387953715399, 0.03907958191120997, 0.05840150799485855, 0.047779148299014196, 0.030805488786427304, 0.06919986801221967, 0.008033244866965106, 0.06548441699123941, 0.02089821435220074, 0.024377886911679525, 0.014395614743989427, 0.03729017851583194, 0.011232702872803202, 0.05380598857300356, 0.040916486468631774, 0.057796501787379384, 0.07315714785363525, 0.030505432914651465, 0.07576270218123682, 0.036055508244317025, 0.02378862536716042, 0.023049663359415717, 0.013547906764870277, 0.03526965178025421, 0.02864974274416454, 0.0610311450145673, 0.029189328633947298, 0.05302865196426865, 0.09497704653767869, 0.020501755352597684, 0.09602236896171235, 0.02638046851643594, 0.0570019621954998, 0.031127545626077335, 0.02000232521822909, 0.015525141243415419, 0.014516395567625295, 0.03047378959308844, 0.02316475562111009, 0.025458915915805846, 0.03737517668923829, 0.06010173121467233, 0.037874668050790206, 0.018448722548782825, 0.012731752121908357, 0.041993498598458245, 0.07321200740989298, 0.02478032391081797, 0.05949687343672849, 0.03200360828486737, 0.02792656065139454, 0.11015180687536485, 0.03342682488437276, 0.04603164656145964, 0.050426774978404865, 0.02418775053229183, 0.04083681320480537, 0.025174947950290516, 0.03550528737832792, 0.028318303302512504, 0.04165655613178387, 0.017963330137718003, 0.09317945354268886, 0.004336275178502547, 0.031832443055463955, 0.03621766380092595, 0.03008223804499721, 0.03666792850708589, 0.06110323352913838, 0.06876225321320817, 0.026543338390183635, 0.06689932895824313, 0.07782189481076784, 0.052489518784568645, 0.05835804782691412, 0.010663728862709831, 0.059096774202771485, 0.0031026891383589827, 0.008735772062209435, 0.01637396893784171, 0.0681525788968429, 0.02509566616936354, 0.0295933909364976, 0.05090653263323475, 0.020285977770981845, 0.05089868442155421, 0.025710016016091686, 0.050852630447479896, 0.07985346470377408, 0.03232171504350845, 0.04452749875781592, 0.018666477953956928, 0.03425008930207696, 0.04421059427841101, 0.015314711763494415, 0.044733700779033825, 0.06795320834498852, 0.0198417114734184, 0.03912213294825051, 0.029702488500333857, 0.07681601753574796, 0.04165919446677435, 0.03398729852051474, 0.025198038019880187, 0.04112104463274591, 0.024292654961755034, 0.012618682212632848, 0.025186735110764857, 0.01748031074384926, 0.059679605037672445, 0.011935125239688205, 0.02321079846296925, 0.01424369154847227, 0.028045309845765587, 0.018003003497142345, 0.05242635830654763, 0.031558987611788325, 0.05004063554224558, 0.004091276923645637, 0.03986587624240201, 0.011211250166525133, 0.03984311086242087, 0.0221147706542979, 0.021036021898908075, 0.0400627197814174, 0.027648989998851903, 0.05442953734018374, 0.02662252740265103, 0.028468853524827864, 0.0467155541991815, 0.08884303271770477, 0.06835274354671128, 0.030380653770407662, 0.04302621935494244, 0.036344099789857864, 0.055350193797494285, 0.06951471674256027, 0.032234553509624675, 0.05053637163655367, 0.03996614039351698, 0.024932753622124437, 0.019993486239400227, 0.03615605441154912, 0.03785052598686889, 0.02592127948446432, 0.05504045846464578, 0.07094395958120003, 0.05226897475949954, 0.038985451610642485, 0.02147444563888712, 0.06096491575590335, 0.02475923021847848, 0.05312224049703218, 0.024386904005950782, 0.046350840566447005, 0.029564445321739186, 0.042248845638823695, 0.027842688687087502, 0.03504572727251798, 0.022910044972377364, 0.05311704917403404, 0.0669377351005096, 0.017080896141123958, 0.031212040994432755, 0.021466744001372717, 0.04511790320975706, 0.030564934604626615, 0.0959447848435957, 0.0993289782491047, 0.059198689632466994, 0.03402422778890468, 0.027549165570235346, 0.029724517298745923, 0.07690934260608628, 0.02322615349839907, 0.06441116012865677, 0.004681680447902181, 0.031592002051183954, 0.048683150962460786, 0.0884253965341486, 0.039709732081973925, 0.04220325921778567, 0.04070499664521776, 0.07634156994754449, 0.039668635654379614, 0.02853928519471083, 0.007126500895537902, 0.09895028997561894, 0.05704010858607944, 0.09270602269680239, 0.03887913153448608, 0.043594756425591186, 0.06902798661030829, 0.019771565530390944, 0.007155333332775626, 0.010564316326053813, 0.09749681601533666, 0.042296502651879564, 0.025330279459012672, 0.03434362959524151, 0.020744478460983373, 0.04030389551189728, 0.027892976613657083, 0.07750760269118473, 0.14781929698074237, 0.1708307137596421, 0.16002597869373858, 0.08726581305381842, 0.10566452969214879, 0.11315061783534475, 0.18777225312078372, 0.12051426645484753, 0.12070311335264705, 0.1525764784310013, 0.10052756158984266, 0.1364920157357119, 0.178271486365702, 0.1850033743539825, 0.12969416566193104, 0.15931924630422145, 0.09476030230871402, 0.10666972419130616, 0.20327309088315815, 0.14383608649950475, 0.12571174185723066, 0.10470647641341202, 0.15425898658577353, 0.1195235586783383, 0.1504206730169244, 0.13313673640368506, 0.19097047916147858, 0.07783676002873108, 0.12444757492630742, 0.22684635798214003, 0.11151771483127959, 0.10545326993451454, 0.14233394991606474, 0.10712199640693143, 0.1681285837548785, 0.1976323380949907, 0.11628408406977542, 0.11182235160958953, 0.13467618817230687, 0.14999126637121662, 0.1540566622861661, 0.23622085573151708, 0.12185120096546598, 0.2071909626829438, 0.22565236111404374, 0.14118197344942018, 0.1207496014831122, 0.1191194518469274, 0.17259994929190725, 0.1012786224600859, 0.10078294202685356, 0.11072595458244905, 0.15832297242013738, 0.17454642453230917, 0.10372661883593537, 0.1693563483422622, 0.11548009322723374, 0.10008449200540781, 0.14560394163709134, 0.17046274209860712, 0.17187641467899084, 0.15305430279113352, 0.11964489240199327, 0.13157270470401272, 0.1194913791550789, 0.18945180752780288, 0.19564289250411093, 0.1019653762341477, 0.1546718878671527, 0.13652517489390448, 0.20872146415058523, 0.22670196573017165, 0.15929724904708564, 0.12477323674829677, 0.16770744463428855, 0.16773290029959753, 0.2490268216934055, 0.10637538100127131, 0.08341371780261397, 0.1165737072005868, 0.09349716696306132, 0.11444506439147517, 0.13677104841917753, 0.19646919972728938, 0.08122469385853037, 0.11049189604818821, 0.12529763829661533, 0.2625847316812724, 0.17224327311851084, 0.16504611790878698, 0.1173633523285389, 0.15143937460379675, 0.11377912785974331, 0.22849402972497046, 0.15779307897901163, 0.15112997323740274, 0.18189561611507088, 0.10570390804787166, 0.13103491481160745, 0.29209792613983154, 0.19497053639497608, 0.14971392578445375, 0.20049500948516652, 0.14147212350508198, 0.14972094650147483, 0.1350355806061998, 0.12094989229808562, 0.11580620775930583, 0.08240456023486331, 0.2594033523928374, 0.17087660817196593, 0.18257714516948909, 0.1461032882798463, 0.10233720706310123, 0.18051651277346537, 0.09347593411803246, 0.08606860268628225, 0.09370177707751282, 0.18727827962720767, 0.12863816373283044, 0.163543090748135, 0.13621719845104963, 0.1534751895815134, 0.09569404282956384, 0.14589836646337062, 0.12367071700282395, 0.14582220726879314, 0.13915613293647766, 0.10376487654866651, 0.14495726383756846, 0.18982270325068384, 0.12006707795080729, 0.12254759523784742, 0.12954705714946613, 0.07087883612257428, 0.1479441559058614, 0.11283007683232427, 0.2193032728973776, 0.12165066524175927, 0.18970119883306324, 0.18199136800831184, 0.17299297585850582, 0.15687879757024348, 0.15411961125209928, 0.09169130644295365, 0.13981404685182497, 0.141417145205196, 0.14475838310318068, 0.13650921871885657, 0.13326738408068195, 0.10616406929329969, 0.1880621211603284, 0.2068263603723608, 0.21065054344944656, 0.10840703995199874, 0.16831204266054556, 0.12037084641633555, 0.053805097995791584, 0.10211201719357632, 0.24715855397516862, 0.12419741920894012, 0.250647256616503, 0.16168985894182697, 0.12435310694854707, 0.19297703867778182, 0.14684059715364128, 0.17301795654930174, 0.13055142044322565, 0.19819319393718615, 0.09348819439765066, 0.09372372980578803, 0.1264591290964745, 0.24806495377561077, 0.12266823134268634, 0.1286482866271399], [0.08509442253853194, 0.04194930741505232, 0.025830245795077644, 0.043543711508391425, 0.02686997984710615, 0.030299603822641075, 0.028450233039620798, 0.04912745993351564, 0.05220835984800942, 0.04732061606773641, 0.035771402981481515, 0.042042832865263335, 0.05438452608359512, 0.045888104068581015, 0.046817020629532635, 0.01707426690700231, 0.04787910445884336, 0.019543013731890824, 0.025386016604898032, 0.08115671313134953, 0.02663996972842142, 0.018280271724506747, 0.042282468639314175, 0.07023124548140913, 0.07114975713193417, 0.0312573565315688, 0.03261750171077438, 0.03901903379301075, 0.026933229382848367, 0.029737152362940833, 0.014648534033767646, 0.03072624411288416, 0.04597138045937754, 0.04742612720292527, 0.09640579955885187, 0.013784668572043302, 0.020055316417710856, 0.025250689686799888, 0.07450649107340723, 0.015938356082187966, 0.04444417412742041, 0.005702399284928106, 0.008146631116687786, 0.02851398166967556, 0.00434471989137819, 0.031842933312873356, 0.05157453975698445, 0.04457642113266047, 0.029012263330514543, 0.057234436244471, 0.07736895466223359, 0.06762203978723846, 0.006069218761695083, 0.07352341257501394, 0.033620640460867435, 0.02844633490894921, 0.0301120742369676, 0.010468142336321762, 0.003160886735713575, 0.032484898474649526, 0.06500431423773989, 0.09877013362711295, 0.026726235118985642, 0.030498332416755147, 0.016710477248125244, 0.02503991603589384, 0.03705716269905679, 0.01846097169618588, 0.0016816677884889941, 0.026557014316495042, 0.027814624372695107, 0.09917240735376254, 0.10911058110650629, 0.030117688584141433, 0.055403394653694704, 0.02127868378011044, 0.0427346184005728, 0.04471176660445053, 0.057352010990143754, 0.019076848511758726, 0.053956807823851705, 0.029255780536914244, 0.041097507419181056, 0.03113312843197491, 0.02207796755101299, 0.02072946481348481, 0.03212026276742108, 0.014679429641546449, 0.03137724306725431, 0.0685369668644853, 0.043282512633595616, 0.056033607907011174, 0.056510623326175846, 0.010064075395348482, 0.05420954250439536, 0.044960059531149454, 0.018978406333189923, 0.037214457188383676, 0.017228308934136294, 0.024481934160576202, 0.05327407649019733, 0.09189290343783796, 0.01436853563063778, 0.025124823296209797, 0.042420890313223936, 0.029041561465419363, 0.06735744187608361, 0.020735921498271637, 0.03815632422629278, 0.012817317110602744, 0.035369247998460196, 0.05235753895249218, 0.021419636177597567, 0.006659238224528963, 0.024780659732641652, 0.030051168032514397, 0.05807021327200346, 0.04909323950414546, 0.026520732571952976, 0.08521969706634991, 0.03332616368425079, 0.004305717247916618, 0.06333135010208935, 0.03761236337595619, 0.0252443350473186, 0.013493453534465516, 0.029724994128628168, 0.018639192894625012, 0.06101030179706868, 0.03923536613001488, 0.025622650391596835, 0.06114586620242335, 0.02788847548799822, 0.02909301456384128, 0.028716664055536967, 0.032949779779301025, 0.01422171006197459, 0.0365714307554299, 0.02999224336235784, 0.02873478730180068, 0.027893748447240796, 0.008582373848184943, 0.04539414912869688, 0.042491119747865014, 0.07726540279691108, 0.06507363825221546, 0.026233168900944293, 0.09430037855054252, 0.025445785468036775, 0.025244652315450367, 0.03186000270943623, 0.02189571092458209, 0.022340032883221284, 0.03491211842629127, 0.07278543576830998, 0.019647051703941543, 0.039101757283788174, 0.05795191122160759, 0.03358883201144636, 0.07726341384113766, 0.016598913898633327, 0.01119367796491133, 0.007829131063772365, 0.06928300339495763, 0.017797072359826416, 0.041300306693301536, 0.039199279199237935, 0.0585216728359228, 0.030888997098372784, 0.01968844313523732, 0.016976544611679856, 0.013044733423157595, 0.07583632323076017, 0.026369891056674533, 0.018756201752694324, 0.05754362980951555, 0.04054343109601177, 0.07763975692796521, 0.04997625423129648, 0.027920539978367742, 0.051618853394757025, 0.06475396556197666, 0.009856927135842852, 0.07916054368251935, 0.017498001689091325, 0.02274327696795808, 0.07189954150817357, 0.04847137170145288, 0.040423340469715185, 0.014810127413511509, 0.04807084202184342, 0.026685465236369055, 0.05642671982059255, 0.024946329358499497, 0.08096416291664355, 0.08998895325930789, 0.04206063698802609, 0.040455564521835186, 0.11377549133612774, 0.0708212454628665, 0.01992900844925316, 0.03651214428828098, 0.016825215134304017, 0.024897245566535275, 0.04196300375042483, 0.035886918267351575, 0.03187291607900988, 0.05533650859433692, 0.020184784079901874, 0.09209565818309784, 0.02927842717326712, 0.06249922444112599, 0.02638800688146148, 0.02192227795603685, 0.030306520638987422, 0.01254871624041698, 0.027657919890771154, 0.028187392163090408, 0.040272710466524586, 0.04766961843415629, 0.07058998482534662, 0.04171845124801621, 0.026069174673466478, 0.04251412632584106, 0.03150521530187689, 0.07417720757075585, 0.04177093222097028, 0.07367792029981501, 0.01242550766619388, 0.0381072979507735, 0.036964227256248705, 0.027889842895092443, 0.024505189358023927, 0.11952436761930585, 0.008582337668485707, 0.024201450578402728, 0.03752581782464404, 0.08568155782995746, 0.03217627636331599, 0.03793270770984236, 0.023694838309893385, 0.028938991090399213, 0.02063243828160921, 0.024196752783609554, 0.01938379336934304, 0.030850357179588173, 0.018658655717445072, 0.08592722355388105, 0.03509260503051337, 0.03282222314737737, 0.011942756373173324, 0.06984300576732494, 0.037782218714710325, 0.007739141947240569, 0.03088072029640898, 0.021701785881305113, 0.08739904340473004, 0.034113318906747736, 0.06377994868671522, 0.03635816348833032, 0.045499775296775624, 0.027860223781317472, 0.009716420026961714, 0.04063982123625465, 0.057836473861243576, 0.047537122809444554, 0.03998597429017536, 0.049825594542198814, 0.08143122613546439, 0.030769800760026556, 0.04949438887706492, 0.02100269019138068, 0.04615866513631772, 0.05441111352411099, 0.01536496351036476, 0.0176513590849936, 0.038588643801631406, 0.13696863781660795, 0.04605017056746874, 0.025479271171207074, 0.033910794227267615, 0.03202294865332078, 0.02744467117736349, 0.036563196626957506, 0.06683835410512984, 0.015910846523183864, 0.031387332564918324, 0.03972561033151578, 0.02528982313378947, 0.10482170968316495, 0.02396922885964159, 0.1135491140303202, 0.026944591663777828, 0.03663528885226697, 0.04425962426466867, 0.017486505821580067, 0.026217040176561568, 0.050286746554775164, 0.030382646436919458, 0.022580282784474548, 0.032774670034996234, 0.029524245037464425, 0.04197472597297747, 0.03207906614989042, 0.01530685613033711, 0.06918425322510302, 0.03302699282357935, 0.07976677443366498, 0.04588732852425892, 0.04584107417031191, 0.03661077200376894, 0.04891912052698899, 0.02962912720249733, 0.05994324186758604, 0.03079341218835907, 0.03615537534642499, 0.03778089398110751, 0.055658318669884466, 0.04014055251900572, 0.043677071735146455, 0.058130286415689625, 0.055712309913360514, 0.035403731890255585, 0.05798652127850801, 0.02545966734032845, 0.03751312709937338, 0.07692008148296736, 0.0343804809381254, 0.041784494969761, 0.05436640654806979, 0.020096700427529868, 0.01972727601241786, 0.018405139926471747, 0.06023055320838466, 0.054779931233497337, 0.05503160835360177, 0.135414699325338, 0.04472302498470526, 0.035619878690340556, 0.046634797399747185, 0.007633326995346579, 0.052248732681619, 0.048992225783877075, 0.038730505330022424, 0.029071822536934633, 0.03154839345370419, 0.08110474795103073, 0.03018784565938404, 0.06611151693505235, 0.014356766096170759, 0.026186727154708933, 0.02305066525877919, 0.17125121463323012, 0.176347290398553, 0.12377512233797461, 0.1930834774975665, 0.15296810975996777, 0.2786311222007498, 0.12590646656462923, 0.17417374765500426, 0.19727101607713848, 0.15479493595194072, 0.1853518869029358, 0.15516931976890191, 0.11082180295488797, 0.09088309278013185, 0.14554937893990427, 0.1347265057847835, 0.08564221658161841, 0.12183715953142382, 0.11319620796712115, 0.232318791677244, 0.2522243501152843, 0.26213858218397945, 0.25959821068681777, 0.13294711767230183, 0.1921770183253102, 0.18716416700044647, 0.12956139544257894, 0.1173791526525747, 0.10565483724349178, 0.18254162598168477, 0.0923487008549273, 0.1021250121993944, 0.1363529372611083, 0.20375263702590019, 0.1092117655207403, 0.10615545295877382, 0.17218586057424545, 0.16244196624029428, 0.21075037715490907, 0.3086051606805995, 0.1270166749600321, 0.16077951091574505, 0.1185381349932868, 0.07575528812594712, 0.14215319242794067, 0.12851993960794061, 0.21786942874314263, 0.1271940630977042, 0.17096489405957982, 0.1722685358254239, 0.10821543968631886, 0.19373546907445416, 0.049935807182919234, 0.26368299149908125, 0.18059411173453555, 0.10929456693702377, 0.1747921050991863, 0.1198807469336316, 0.139034821477253, 0.180540231813211, 0.10345738250180148, 0.17699094023555517, 0.07441512527293526, 0.14956652041291818, 0.11099683106294833, 0.14281863172072917, 0.08160315948771313, 0.09750115015776828, 0.06680902442894876, 0.2093588502611965, 0.17161203199066222, 0.16796465817606077, 0.22599996824283153, 0.12333650563959964, 0.14014176442287862, 0.11478138345410116, 0.05100713446154259, 0.21389087894931436, 0.18951701262267306, 0.08729244873393327, 0.21745462756371126, 0.06411591151845641, 0.16463242995087057, 0.06977938886848278, 0.19153121626004577, 0.07539718702901155, 0.13935725495684892, 0.11205480710486881, 0.11551864037755877, 0.16613796557066962, 0.12794879759894684, 0.13524777546990663, 0.15096024406375363, 0.07862838669097982, 0.11186200455995277, 0.17991154367337003, 0.19093208044068888, 0.12310551217524335, 0.11175201085279696, 0.16159648192115128, 0.16525676910532638, 0.2335317133110948, 0.07672956475289539, 0.0836532014363911, 0.1587965220096521, 0.09078690301976167, 0.12424079031916335, 0.12445132277207449, 0.1366232571308501, 0.06521741452161223, 0.23494615772506222, 0.11680776573484764, 0.17274021520279348, 0.2284648039494641, 0.22170781652675942, 0.2122284533106722, 0.08982414452475496, 0.17680828284937888, 0.15484240371733904, 0.18619230977492407, 0.09240036917617545, 0.11256126352236606, 0.13803931942675263, 0.11816436715889722, 0.11823156863101758, 0.1896672381553799, 0.13278608646942303, 0.0925384605943691, 0.15211906313197687, 0.119622909987811, 0.08548229860025458, 0.2042388921836391, 0.11592530019697733, 0.203457128664013, 0.12969544215593487, 0.23592577781528234, 0.11171179387019947, 0.12446065156836994, 0.20367532008094713, 0.14675674930913374, 0.11259018501732498, 0.13650740787852556, 0.09484567897743545, 0.07143264898331836, 0.171707026893273, 0.12558061920572072, 0.15162091876845807, 0.22431035031331703, 0.0936652411473915, 0.15106076054507867, 0.10902933820034377, 0.10670605232007802, 0.17156355490442365, 0.14380466396687552, 0.1396999935968779, 0.0906257530732546, 0.12288635596632957, 0.14334245439385995, 0.1515396239119582, 0.11727237986633554, 0.22180129744810984, 0.11589580724830739, 0.09233003584085964, 0.1677418506005779, 0.16904862422961742, 0.2006193043780513, 0.16139256942551583, 0.0801812342251651, 0.1186897186562419, 0.10205674945609644, 0.1242090635059867, 0.08136582808219828, 0.16247125138761476, 0.11567829860723577, 0.08943423497839831, 0.06822774361353368], [0.05182326684007421, 0.045613754336955026, 0.04648041584005114, 0.032481740636285394, 0.05072754145658109, 0.03689108489197679, 0.03553507718606852, 0.03711782585014589, 0.08196526076062582, 0.05573725349677261, 0.09484861046075821, 0.05754161116783507, 0.008074523120740196, 0.0731566951435525, 0.06487628634204157, 0.020102596790820826, 0.10915141407167539, 0.05539218822377734, 0.018270792643306777, 0.057175216570612974, 0.08317839761730283, 0.027004833646060433, 0.06398855897714384, 0.02328045644389931, 0.04087958317541052, 0.031586654877173714, 0.031091005985217635, 0.0702188145078253, 0.018688137533899862, 0.05152133890078403, 0.010022272072092164, 0.03032517637620913, 0.05597538642177824, 0.07280039004399441, 0.035647683253046125, 0.03592119806853589, 0.007126480022634496, 0.0028334224225545768, 0.04437090930878185, 0.05846318046678789, 0.012470852889236994, 0.05647234705975279, 0.07991166392457671, 0.019763934396905825, 0.05694083149137441, 0.027575294734560885, 0.02256467912957305, 0.06433873393689282, 0.021499595168279484, 0.03937422938179225, 0.01538476493806229, 0.036916740937158465, 0.025399191581527703, 0.06196886344696395, 0.08958027479820885, 0.05382149574870709, 0.07950965737109073, 0.04685513362346683, 0.0057397186446905835, 0.051945246232207865, 0.03689302189741284, 0.05608542836853303, 0.07523367705289274, 0.06133647570095491, 0.05675183987477794, 0.03726600305526517, 0.051779572895611636, 0.05827883469464723, 0.0269441333875875, 0.020184509485261515, 0.030272200019680895, 0.03944341980968602, 0.06214973225723952, 0.050560754898469895, 0.02339631497306982, 0.10225843550870195, 0.050926967669511214, 0.012844198627135484, 0.03156752973154653, 0.042291018180549145, 0.02194832733948715, 0.07535069147706963, 0.031680388128734194, 0.01810945901524974, 0.009143549741565948, 0.023359853257716168, 0.02629603994137142, 0.05616029251541477, 0.01364637306323857, 0.03993737846030854, 0.09971266117645428, 0.03870501626806799, 0.03834646617178805, 0.03561306577466894, 0.022305628772301134, 0.008728840402909555, 0.05559704695770051, 0.01165015351944021, 0.06197446295118425, 0.030829395218461286, 0.1078419316036161, 0.03689983481308445, 0.030452606843027752, 0.04505573720962275, 0.029823970653524157, 0.017445546691305935, 0.030163193368935026, 0.07461807297659107, 0.01908760594233172, 0.022885110665811226, 0.019726789905689657, 0.04464990859560203, 0.013777226686215727, 0.07123828792828135, 0.06908071620273404, 0.03157135550281964, 0.02627121881232597, 0.051625692285597324, 0.050164451749878936, 0.03525007392454427, 0.018711264710873365, 0.03285740836872719, 0.019329121205373667, 0.056392261903965846, 0.024757437931839377, 0.028299449040787295, 0.0442221272533061, 0.006578601560249808, 0.05293447713484056, 0.08399727594223805, 0.030386188336706255, 0.03898830145772081, 0.08880461173248477, 0.053033182775834575, 0.004221560948280967, 0.06327390787191689, 0.03250312933232635, 0.03839039018203039, 0.030225492955651134, 0.06291206635069102, 0.07124677809770219, 0.0757821167644579, 0.06315983977401629, 0.03928694539354183, 0.02770660848909756, 0.02004316931561334, 0.026499959858483635, 0.03671675811347086, 0.038079923833720386, 0.02481462597643258, 0.11596021824516356, 0.03648926387540996, 0.010660327970981598, 0.025644189372542314, 0.04134931070439052, 0.01961493897397304, 0.02161039039492607, 0.060981194765190594, 0.06778309325454757, 0.045923036959720775, 0.020918016707582865, 0.05314220798027236, 0.02755403776973253, 0.12203259670059197, 0.030119399234536104, 0.07634991910890676, 0.055148737810668536, 0.03338778420584276, 0.024242895815405063, 0.019745608915400226, 0.042925662055495195, 0.050634086510399356, 0.03091555856371997, 0.019892337077180855, 0.054252561094472185, 0.011275406050117454, 0.029243811550259124, 0.05620551157335285, 0.09939886629581451, 0.06170070693769958, 0.05364259734051302, 0.023626833462913055, 0.0224296193846385, 0.011392550350137753, 0.037787725450471044, 0.04351782539742999, 0.05549068606342189, 0.029200674216554035, 0.018172682575823274, 0.044561841641552746, 0.041819605976343155, 0.057886932481778786, 0.016264299920294434, 0.05871116911293939, 0.008281668597192038, 0.0632449121621903, 0.03286246981588192, 0.023407233820762485, 0.014730378079548245, 0.015454835738637485, 0.030942116318328772, 0.08003619630471803, 0.08510675703291781, 0.018875806272262707, 0.03825456973572727, 0.016884965443750843, 0.038863542722538114, 0.03460329964582343, 0.04039679013658315, 0.04885784139332827, 0.052732438562088646, 0.09372120650368743, 0.04114263370865956, 0.028156945554655977, 0.04687348322477192, 0.05215835764829535, 0.028273086099943612, 0.04393968811200466, 0.03172233802615665, 0.0242941670876462, 0.04211531842884142, 0.03890915511874482, 0.02816460266330978, 0.060868640648550354, 0.03496366800391115, 0.052474968979367986, 0.03316816786536947, 0.024306609193445183, 0.059516466135391966, 0.05412290047388524, 0.02481060910213273, 0.03456506419752259, 0.023588158292113803, 0.04003123045549728, 0.022914525688975118, 0.045545588072855026, 0.0422499737032922, 0.10168420616537333, 0.02353231167944614, 0.0434827218123246, 0.03064449098019395, 0.05651213359669782, 0.051612574825412594, 0.02504267311451258, 0.01794768566469429, 0.028667890110227745, 0.03790304406720679, 0.04702777943748515, 0.07454031074303202, 0.03589306696085259, 0.03392549617274199, 0.024286882908199914, 0.053818375017726794, 0.02858131301763933, 0.04087427310878411, 0.023398374432872515, 0.04646339839382563, 0.05514025877346285, 0.04278400090697687, 0.041040963187697344, 0.04790137259988114, 0.07720663954387419, 0.03559889075404499, 0.019250659497629385, 0.025656483048805967, 0.030931279106880538, 0.11659969721222296, 0.008263908075605286, 0.033742686646291986, 0.03755459089006763, 0.0571239527198486, 0.021235078893369064, 0.05345707897504326, 0.06906817390699871, 0.07521268911659718, 0.043027555220760405, 0.10046794486697763, 0.040695738352951594, 0.06699152596411295, 0.01319742937994306, 0.02862511457351502, 0.0014960762518967385, 0.019180624876753427, 0.026096930996573064, 0.004945146120007848, 0.0436666148743825, 0.01322840291322791, 0.06147553933260497, 0.06405981257557869, 0.03899568953784183, 0.03245399544539396, 0.056943302843137644, 0.03385573800187558, 0.011009792324330192, 0.00968252150414628, 0.07163046102505177, 0.011925115522899432, 0.030375605310837273, 0.02633060732478043, 0.019591822929214686, 0.02676602907740744, 0.01779802973032929, 0.07357738155405968, 0.014085511120356387, 0.0449582783767255, 0.010585752334009157, 0.053608807356795296, 0.04718011638033204, 0.015089859571162378, 0.04306392787839286, 0.025956282879633363, 0.031077433959580958, 0.07893007714301348, 0.02953822895506164, 0.007599562522955239, 0.005487112448463449, 0.008658219485369045, 0.028002044491586275, 0.0494170199817745, 0.06224283468327485, 0.008452769816358341, 0.04961574115441181, 0.02633062773384154, 0.01803199920686893, 0.03239325807953719, 0.047278781203203835, 0.032822512584971264, 0.04735802402137779, 0.020443311223061755, 0.0592746002075728, 0.03802993647695985, 0.049550784679013304, 0.04015132108179387, 0.04559454013360664, 0.010854140764422482, 0.013790877565043047, 0.011004020270775072, 0.03300619042420294, 0.030064038728596643, 0.09265675151254982, 0.02122152171068592, 0.07572206217446364, 0.09302830774686299, 0.01708198709820863, 0.0274303495825734, 0.036524694005493075, 0.02937258901511086, 0.02282179062603973, 0.05886561004444957, 0.028882645383419003, 0.03294252899650019, 0.014849371254967991, 0.08675663295434788, 0.22170397220179439, 0.18547561776358634, 0.1634934262256138, 0.20512271585175768, 0.16534125519683585, 0.09723526833113283, 0.09519902290776372, 0.14692505355924368, 0.22134110651677474, 0.15362532605649903, 0.08828118981909938, 0.14550434541888535, 0.1512102736160159, 0.14738671394297853, 0.20267601823434234, 0.16481958475196734, 0.17200832400703803, 0.11703265132382512, 0.13508806528989226, 0.1921981546911411, 0.14264735887991264, 0.09376389483804815, 0.0683260484947823, 0.06777300746762194, 0.1904675256810151, 0.10972468604450114, 0.10656321857823059, 0.1574114221148193, 0.12571628380101174, 0.05576750343607273, 0.11421640869230032, 0.15534455567831174, 0.1228977701975964, 0.1424137011053972, 0.20135392667725682, 0.1872992527205497, 0.09726607488119043, 0.1295649429084733, 0.15302411222364753, 0.1115383168507833, 0.07033179164864123, 0.25321870925836265, 0.20783579995622858, 0.15720552066341043, 0.14987504604505375, 0.10449941721162759, 0.21893570199608803, 0.09832788782659918, 0.09434726001927629, 0.08654557357658632, 0.11316781339701265, 0.18903607124229893, 0.27493362373206764, 0.11647873456240632, 0.11742639777367003, 0.15730250452179462, 0.21587596071185544, 0.07785114285070449, 0.11906894127605483, 0.2891858574002981, 0.2549960045143962, 0.25481115037109703, 0.13239675579825416, 0.16592529573244974, 0.1698048727121204, 0.10160878911847249, 0.08857735127094202, 0.11405786368413828, 0.1170668717531953, 0.19152124179527164, 0.13624124403577298, 0.14854657201794907, 0.2011418654001318, 0.12428318179445341, 0.22699034947436303, 0.24778272985713556, 0.12000916816759855, 0.08477434166707098, 0.14324676187243313, 0.19566980277886614, 0.20155823993263766, 0.13605416344944388, 0.20486323133809492, 0.10708105211961083, 0.1744553926982917, 0.2513316652039066, 0.21751745778601617, 0.08800836891168728, 0.2027181870653294, 0.22735838050721213, 0.1693851436721161, 0.12492303183535114, 0.12648678151890635, 0.09627645064028911, 0.1556299114599824, 0.21473804052220657, 0.19509423756971955, 0.14193842973327264, 0.16436555364634842, 0.3362185461446643, 0.15995093272067606, 0.06464584948844276, 0.1919066093978472, 0.15093379392055795, 0.09521763597149402, 0.09923474775860086, 0.18015094567090273, 0.12726961373118684, 0.1347150470246561, 0.07016623334493488, 0.13021594000747427, 0.13286506582517177, 0.1750636420911178, 0.10626251518260688, 0.1279853261075914, 0.14620891073718667, 0.09381389332702383, 0.19694316491950303, 0.17637185548665002, 0.14806042076088488, 0.08565482567064464, 0.09299019104219042, 0.1390519947744906, 0.11149073776323348, 0.13725855038501322, 0.1659424541867338, 0.08125334075884894, 0.16973655059700832, 0.15346834697993472, 0.2067679533502087, 0.22483760170871392, 0.2015638505690731, 0.14437074452871457, 0.0885744123661425, 0.131991513480898, 0.2039577963296324, 0.1604302562191151, 0.13773057115031406, 0.17917018267326057, 0.1510052033700049, 0.13163508963771164, 0.21979306067805737, 0.15685245132772252, 0.08479881027597003, 0.126247305306606, 0.12050344594172202, 0.094660579925403, 0.15847092698095366, 0.16853128792718053, 0.2696507493965328, 0.10358009662013501, 0.11079682968556881, 0.09468618402024731, 0.14869742095470428, 0.14614612504374236, 0.08380885949009098, 0.08447032087133266, 0.16074599552666768, 0.0778692883613985, 0.07498603721614927, 0.08394856879021972, 0.15993092441931367, 0.2699147758539766, 0.10359766325564124, 0.16160363622475415, 0.19778053014306352, 0.0891269784187898, 0.12189846092951484, 0.10853718296857551, 0.11249916802626103, 0.21052828204119578, 0.14346354320878163, 0.11204095862922259, 0.14651283505372703, 0.10268180107232183], [0.002250618258585746, 0.06149280539830215, 0.0076278620053926716, 0.024809263959468808, 0.04437609692104161, 0.06154323804366868, 0.05943314892647322, 0.053913084193482064, 0.045622760299011134, 0.02869247746275505, 0.027061307373514865, 0.033785512277972884, 0.050332262471783906, 0.05982663933536969, 0.02972617785417242, 0.010158631503145443, 0.03759814382647164, 0.037555125236394815, 0.0617543939006282, 0.05208004622545559, 0.11390533007215708, 0.03129541757516563, 0.07839773461455479, 0.03720201137184631, 0.011662720862659626, 0.04453121320693754, 0.08076587590039708, 0.06303321453742683, 0.056689321354497224, 0.03680603847897146, 0.06157951051136479, 0.0481421772565227, 0.0022146632909425534, 0.03981819696491584, 0.07857720818719827, 0.045356032424024306, 0.10748011234682053, 0.04408491156937089, 0.058612589637050405, 0.014207524836820085, 0.03691064048325643, 0.03707205018145032, 0.02544155708164908, 0.028424009251466487, 0.062108457714202814, 0.03759576524316799, 0.0398451629007468, 0.05918190967349801, 0.052493993935058825, 0.0506349622446578, 0.08513089909683913, 0.02065038526779972, 0.030588412446377333, 0.02562157613283489, 0.025300350498582702, 0.023965876207512338, 0.03723768641066272, 0.02114166105457116, 0.055251595767913386, 0.009210195530613419, 0.04300067463191226, 0.027434334915596992, 0.02776631612505298, 0.007227452460938366, 0.030371996617759578, 0.07648303813766688, 0.05519150035979692, 0.05187248236325104, 0.030302737541205715, 0.02297313309099991, 0.021692720547434874, 0.014594094718631823, 0.018238689190184232, 0.018611347513797227, 0.09037053590873256, 0.0323184273293009, 0.005490896473929752, 0.01628561625693692, 0.025821811286732554, 0.06774837558623403, 0.07921914366306737, 0.02101400608808035, 0.06593110083485954, 0.01560841021273518, 0.04289473676180933, 0.06471612345194444, 0.05124831019202247, 0.01649197412916692, 0.009581216490914812, 0.01672782309469767, 0.046153663060977124, 0.06489155231975019, 0.07519593142205849, 0.056520204452681355, 0.01440461513993796, 0.06381976490956731, 0.048310474085155874, 0.06316087135928683, 0.03490121256618295, 0.08478698044200428, 0.03775247714656871, 0.08356093763723038, 0.04697778836998623, 0.056011117121670395, 0.024621749216748867, 0.03451662792940624, 0.027630618133116513, 0.05403963150456548, 0.07365091354586184, 0.023230125843838323, 0.005775445170002058, 0.08384702072362415, 0.06462622710387222, 0.015931019952404313, 0.035940991147072054, 0.028765306269633584, 0.025188041290675756, 0.015611783273925539, 0.05189784526010044, 0.04693127797509078, 0.015059012202982558, 0.040768279577605426, 0.05799951628432609, 0.07844907639082521, 0.023829395249777008, 0.03652344719739631, 0.032112522167153656, 0.02341078685276443, 0.08113907970255241, 0.019685565457621124, 0.018745381239568815, 0.04585586517350748, 0.05344048826373182, 0.036703878140542656, 0.12143605839810334, 0.018873006520152558, 0.055037400816217996, 0.06661149440333247, 0.02541276546253357, 0.03057849364267895, 0.039102595910662785, 0.046063258341746405, 0.02324810622667428, 0.014702230273542227, 0.025482245328021236, 0.056204197971965186, 0.04919494713249151, 0.045970326609676704, 0.01165026391390711, 0.03559276432497427, 0.012565077813633252, 0.05498936901858542, 0.07084221855620854, 0.01593130196852144, 0.032633762166369706, 0.04050082810863387, 0.026537471712799743, 0.0072820184050215175, 0.05367157449654769, 0.023112079834390897, 0.024809648020891473, 0.01884355253423564, 0.041097722642007284, 0.033740196740836836, 0.007575791996714543, 0.03640257360530086, 0.059027335155406035, 0.03134283339022659, 0.013465790907503106, 0.05001838595489971, 0.05417482112534344, 0.009418673162144842, 0.016535623544768896, 0.057194174733012915, 0.07877896845457144, 0.021205804878263734, 0.015303082309401361, 0.05779507686384022, 0.01405280838298495, 0.05564682651311159, 0.07636271373485215, 0.0469695616629906, 0.017208515855600126, 0.019013515484402888, 0.03194651486410294, 0.028426322896848433, 0.041416875828872435, 0.03690871461003553, 0.10222627824987285, 0.012921843972435454, 0.04025822003313806, 0.03903436285327189, 0.06997629549005069, 0.04564740331261419, 0.03364909440279007, 0.05276391304505523, 0.04318327264627442, 0.031234142152243294, 0.050591680192155764, 0.020624590069928672, 0.02835621406120481, 0.07627971193869598, 0.03179853803885635, 0.051902943814639, 0.07344929428654723, 0.021146485014469363, 0.06725676212226972, 0.051163597745471634, 0.026793991346494295, 0.04651917450246401, 0.023345192130364012, 0.027942401793552563, 0.023093015915947035, 0.034560666972538456, 0.0029913987600593828, 0.06269984180107713, 0.06329383453703485, 0.07415408224915154, 0.04551428428385407, 0.05384573058108799, 0.060055539943277836, 0.01373959516058676, 0.030800714921497274, 0.040488074300810695, 0.04183096454653423, 0.07419617686537094, 0.084927357675042, 0.044812160631408915, 0.044533528707688674, 0.04606404130754527, 0.007020809325695154, 0.032021575680118985, 0.004928788721372257, 0.016302655967592727, 0.05959959780739155, 0.03571271394321229, 0.03557841118890792, 0.04905421366856899, 0.026906222628895193, 0.013543593959184363, 0.03214377400581725, 0.022010198335919995, 0.049349284163326956, 0.04945347798638977, 0.057207221689168364, 0.025825382872426417, 0.027788426559709478, 0.01620602091861656, 0.042064258668688126, 0.0699485391669441, 0.07549025234766304, 0.07475128106307238, 0.013438160749501549, 0.025929122130037285, 0.021719165124522988, 0.011510088916111272, 0.10823558899573982, 0.06525651828269474, 0.028792138618882746, 0.015749544436403085, 0.046661076848977245, 0.019537538537406363, 0.07572139424155466, 0.02216480625065742, 0.023200645882752724, 0.04440674762008712, 0.016447371053800453, 0.02433607616694644, 0.03774655851884745, 0.002957924652946531, 0.017401270160917193, 0.02449600156978704, 0.011771598565246677, 0.02584041878435528, 0.05450845732411835, 0.03335517423693091, 0.05977652210276574, 0.014208474785846192, 0.03760457824682817, 0.021146453473193105, 0.028928036990691908, 0.0290077139652567, 0.022581327357329428, 0.034314177464693785, 0.02983302856591763, 0.014628239077865146, 0.02919863887655083, 0.04664010375563521, 0.04465178993996233, 0.02405814371741144, 0.02945059986814158, 0.010373013847129187, 0.0340873437380651, 0.04821574635570869, 0.08277652465039864, 0.0414962707873201, 0.06618691171752289, 0.0473297593271127, 0.052331304032122716, 0.0880080349452328, 0.014888422138028545, 0.07846890657674521, 0.017717725640977733, 0.028793442943424452, 0.025678728925413452, 0.012827661721530603, 0.06913499688380398, 0.07699911278905347, 0.08810757179162465, 0.04507070261752233, 0.04091347334906459, 0.06998861514148302, 0.027085727742814925, 0.015576087826048024, 0.03894486726494506, 0.05781371219200082, 0.03636141409515403, 0.01740155403240351, 0.031589385980623774, 0.04835036823351402, 0.02589285337307956, 0.018379923603788484, 0.05327331578882877, 0.025414173687750008, 0.06951223796932027, 0.046406360634136945, 0.02631575880513992, 0.03712209691002499, 0.045188255098764785, 0.12013918501907028, 0.03901913769368548, 0.031093475481611677, 0.04333973221946508, 0.03207135152479168, 0.015335750722442754, 0.037155653117224574, 0.04145602411881555, 0.058245983527740464, 0.011453463976067724, 0.031418053767993115, 0.03403928967600223, 0.029173825168982148, 0.05223322550591547, 0.03653530671726912, 0.029149022593628615, 0.036658454991993494, 0.07386483761365525, 0.048932252830127254, 0.04086739711055998, 0.06152385685709305, 0.03550901667040307, 0.01099614608392585, 0.08759292206377722, 0.14881019771564752, 0.07956355213536881, 0.19487929675960913, 0.23514591419370845, 0.16112921090098098, 0.1358864677604288, 0.06372402785927989, 0.12247177000972442, 0.11157434069900773, 0.12466755491914228, 0.11737495951820165, 0.15018858859548345, 0.07876425166614354, 0.11841294952319004, 0.1183674558706116, 0.22220115177333355, 0.12146797074819915, 0.1550808854517527, 0.13513007084839046, 0.22837386117316782, 0.15835013502510265, 0.12290479091461748, 0.11515455014887266, 0.09630749467760324, 0.1602116640424356, 0.2077234091120772, 0.1606094848830253, 0.18743277993053198, 0.1502024519140832, 0.13491722289472818, 0.18275005073519424, 0.1211858210444916, 0.1213818890391849, 0.1720019563799724, 0.16558024159166962, 0.3057767468271777, 0.1563013027771376, 0.09319969190983102, 0.12111220741644502, 0.15396583825349808, 0.12502534431405365, 0.13223032176028937, 0.1775394764263183, 0.10287299315677956, 0.10415099372039549, 0.1340156767400913, 0.1660738291684538, 0.15111241402337328, 0.14260535332141444, 0.19976633921032771, 0.1301688136300072, 0.12426555578713305, 0.13536536134779453, 0.0819313371903263, 0.18718123639700934, 0.059027769311796874, 0.16141587286256254, 0.12435974174877629, 0.13814133504638448, 0.14748619141755626, 0.10022188580478542, 0.19675123068736866, 0.1641001319512725, 0.15187149751000106, 0.12981985579244792, 0.11179858061950654, 0.18898668873589486, 0.10630667296936736, 0.09903933285386302, 0.09852108370978385, 0.16863343713339418, 0.09315512594184838, 0.13361321005504578, 0.15838546125451103, 0.2562979987123981, 0.11659781215712428, 0.06740224533132277, 0.10006521100876853, 0.19127562060020864, 0.22454022313468158, 0.1333277058438398, 0.1695080878562294, 0.1017246903211344, 0.09473555910517462, 0.1649824861669913, 0.3410485025960952, 0.10871635226067156, 0.11690661980537698, 0.1942036158288829, 0.09667407852248289, 0.10601128335110843, 0.14388079347554594, 0.11165922755026259, 0.16593817941611633, 0.10936330465483479, 0.07746357106952928, 0.20232481911079958, 0.18153068725951016, 0.0996474560815841, 0.12758202821714804, 0.16212193731917068, 0.13970839470857754, 0.13318343233549967, 0.16864817618625239, 0.1897329924395308, 0.11456326625193469, 0.17803353897761554, 0.19037745863897726, 0.13057315052719787, 0.09627881809137762, 0.20418027736013755, 0.17783304036129266, 0.11446157717728056, 0.17367447522701696, 0.14810561755439267, 0.08842627226840705, 0.22937393485335633, 0.18424406822305173, 0.16816154995467514, 0.12658042571274564, 0.19546842842828482, 0.11389059844077565, 0.20087288139620796, 0.10630662844050676, 0.1833776998682879, 0.20904809818603098, 0.10174584152991883, 0.17352990485960618, 0.12621640227735043, 0.19079046382103115, 0.14144347660476342, 0.22771306772483513, 0.13945348182460293, 0.3561261232243851, 0.1643238152610138, 0.13877440185751766, 0.15842590830288827, 0.08203503748518415, 0.2003904854063876, 0.13312342227436602, 0.1423169844201766, 0.11741948837880045, 0.16667033778503537, 0.11285734333796427, 0.17619290883885697, 0.13488004129612818, 0.1166258059674874, 0.15026709297671914, 0.12958232400706038, 0.07490590011002496, 0.12126665576943196, 0.15363074373453856, 0.382965745520778, 0.09238365601049736, 0.11692876549204811, 0.1189921957848128, 0.06529033053084277, 0.06525407661683857, 0.1366312277968973, 0.09436621447093785, 0.10322289352188818, 0.1455223053926602, 0.14386176480911672, 0.14524656784487888, 0.15439705573953688, 0.20666823838837445, 0.12611089856363833, 0.0983223514049314, 0.16881808347534388, 0.1297734270337969, 0.12417898426065221, 0.31001862545963377, 0.1834050109027885, 0.10888457487453707, 0.149498836544808], [0.04066129527927842, 0.06728951309924014, 0.059261979986331426, 0.10329095588531345, 0.05721125526179094, 0.03646757089882158, 0.03651731334684882, 0.024946340490714647, 0.04171973516349681, 0.01959274690307211, 0.03190564479155, 0.014896120064804563, 0.014101916294748662, 0.05206044239457697, 0.02592047425423516, 0.013015820277360035, 0.04936231627652887, 0.060444280607043765, 0.023398784469463862, 0.03645518816483673, 0.06172441484523006, 0.039460960470023565, 0.02820814446749864, 0.062265047163236886, 0.040514665452064946, 0.07277225522557274, 0.035670819706865586, 0.029204006459622178, 0.009723589173518121, 0.04763308992551174, 0.01835753115301486, 0.09024430401041172, 0.022430018289014697, 0.048129030110430904, 0.03615155699662864, 0.057150395441567525, 0.05495508921740111, 0.05453688158013392, 0.031869635786279105, 0.02673184575542109, 0.044118820296716876, 0.10988757261657156, 0.040039360683294944, 0.020173275224806275, 0.03063710104470374, 0.02916255751188146, 0.03767259979213122, 0.0193743513955269, 0.06580059416592121, 0.023620406464033294, 0.032440818613395095, 0.028108963851991575, 0.06708471744786948, 0.0338052942242939, 0.08983213745523244, 0.018621234776219353, 0.020383777991810348, 0.019014684366993606, 0.013427524845610606, 0.0625383282022085, 0.03882003060425632, 0.04436692768649664, 0.07567493579699658, 0.037846128761884756, 0.03908219798177015, 0.02636054556205636, 0.033013285355991684, 0.058655014508985914, 0.0684946718683932, 0.05609159932646435, 0.04691928486863617, 0.059006172814406455, 0.04521830094745383, 0.026983801180904265, 0.01907051799207693, 0.040093010538839735, 0.032790841432870366, 0.022458422135969158, 0.058079987356904894, 0.06685222484520636, 0.041244315361836925, 0.06944315144210123, 0.04903992732579354, 0.04634760851331521, 0.08340270433109254, 0.04485909405048005, 0.02898626589740161, 0.02856711387721589, 0.03723122601513751, 0.05304057827743236, 0.053060564314364456, 0.029980959006934427, 0.041316222050227225, 0.05755121455877088, 0.022019864809408318, 0.03864502104988787, 0.04016266109829303, 0.022738575462426525, 0.032003637970774435, 0.037729173709522, 0.0639563200820703, 0.028109674458391964, 0.04707359963504132, 0.022173765828483738, 0.06493642256828025, 0.04018096245999914, 0.04545586241874844, 0.04065622269990854, 0.03701117180753499, 0.050250529748154804, 0.024416196574748028, 0.020970338118786458, 0.009163532995444257, 0.07102545481757261, 0.011585621923586586, 0.07526101777330041, 0.029736823962593917, 0.05059369883383624, 0.015784673996677157, 0.03686942160129547, 0.057920006292988546, 0.02348675494431518, 0.04012992125353776, 0.03882900688040536, 0.04246501099260058, 0.08372919735847972, 0.10655112899257801, 0.04916818157653324, 0.049104813297162764, 0.05208708920690697, 0.05290476154186763, 0.05402215763751883, 0.047541163803543895, 0.03858261014102027, 0.040203178650699556, 0.02544965947890887, 0.05123579758219421, 0.03776755758735817, 0.03660308706457727, 0.042950060160364956, 0.021739609437645413, 0.01723661171126878, 0.04834623818169348, 0.04101502141566016, 0.024467573603033088, 0.026169251432293095, 0.03919754257367458, 0.028901017249154393, 0.02810502304782858, 0.04206803991110064, 0.08303969763801433, 0.026655501023924444, 0.016574063083680812, 0.008982144681795035, 0.043605862665572204, 0.0042044043493660865, 0.03044366581889335, 0.04949243331793696, 0.0063868551842460874, 0.005908030316277291, 0.016911868297029287, 0.03319546776765492, 0.05510648734343704, 0.03538421340635978, 0.09126389617449604, 0.04131974354095291, 0.02204714430263266, 0.07330922133405693, 0.037281736586010084, 0.0478390804346418, 0.006502954911411507, 0.059666936576832086, 0.03059272432437865, 0.0065045700102928095, 0.04268990771379322, 0.013564862056227867, 0.015252572666213382, 0.029548127349698916, 0.029748874585493468, 0.06595876810024492, 0.014544279911206104, 0.039206567089422606, 0.038864129019202664, 0.04197384281724226, 0.039752683878759854, 0.04432297027960885, 0.05803019295854028, 0.0448535947361961, 0.01119631166147883, 0.011933208643313264, 0.005578831696766429, 0.05645423494570423, 0.06691918140859343, 0.026771465309138875, 0.021836183259438258, 0.04343563625297975, 0.08343302848516032, 0.02124052625731565, 0.00418274523326545, 0.05605469603324309, 0.055147290622699074, 0.05471108219353482, 0.060184881440363824, 0.054511511261807755, 0.028976276589673944, 0.05614399866317399, 0.013207646898081293, 0.009701254239189439, 0.015055243020469788, 0.018982451038027648, 0.05101286013086792, 0.04920618695905432, 0.05438870437501464, 0.12967074348125607, 0.037515349831664935, 0.01896213103464106, 0.007515748075093143, 0.14770478359423578, 0.0663660216378048, 0.027008772594854236, 0.03343047254020348, 0.04335574776632711, 0.02060817747405963, 0.024070437393675093, 0.04542803188087419, 0.0306298725263332, 0.023494072520406917, 0.01252756039320957, 0.05274658389680553, 0.04711683344794437, 0.06920183470356278, 0.02506523254851345, 0.009120453178184107, 0.05486975707754027, 0.039778826030669734, 0.030265099521784578, 0.023219169888761826, 0.09276629250962287, 0.1205461194331292, 0.07779313658829778, 0.06075590841646772, 0.045068183026160114, 0.021895623722230084, 0.04199966584565118, 0.08519989656633697, 0.04650958966522012, 0.015618021025147755, 0.0717696656647604, 0.02075706343021011, 0.04261213805875741, 0.030820912470517214, 0.02989840621012263, 0.008211621916416334, 0.07328161344048567, 0.11994777771178633, 0.03723395711858757, 0.060717557935277, 0.07167320130974986, 0.004055526278534671, 0.027785168531409, 0.07601872086524963, 0.033242490244447254, 0.013048775344941532, 0.107224783860147, 0.030413406602747273, 0.030737012675672304, 0.059714248491218314, 0.030032790600671433, 0.03875874404911883, 0.039202296029543504, 0.05021511446102522, 0.01635217577131698, 0.037678121370845474, 0.007935634821478743, 0.022677235101582482, 0.032764677016530186, 0.04037319726194255, 0.034676030118134804, 0.10175644682021812, 0.03587402345146984, 0.03358984875376336, 0.04452360619325191, 0.042654032295104116, 0.06305199829512276, 0.04160861710261088, 0.04240141264745034, 0.03247283115342725, 0.020854967551713344, 0.037974427541485056, 0.024878354197426233, 0.03056496429053368, 0.022185217167134397, 0.025545760181557853, 0.028815584919357207, 0.041924849938368425, 0.00916292350666481, 0.013705375658901175, 0.06321777182165533, 0.07476060243789107, 0.046575926535297185, 0.04528243363893125, 0.04419535427587107, 0.062000208054087125, 0.04381497761642095, 0.06008519987517502, 0.04459278177819215, 0.064200679626083, 0.024230227354564704, 0.012776203984685708, 0.05933462882239837, 0.012570709786814405, 0.049108531457022764, 0.10534646004089154, 0.005270337605907116, 0.024361533687624615, 0.010534375305724097, 0.01901047824503621, 0.05134821811225265, 0.036122917517786846, 0.027012728241970763, 0.0013824401071360626, 0.012221811321069254, 0.03067400804866338, 0.028341632714727893, 0.010237630340270698, 0.029862998344469815, 0.10632984281983227, 0.06629793700994924, 0.04045772417157423, 0.050332307000644505, 0.030407773701881524, 0.044532623287523165, 0.045056215894874185, 0.035051827726420015, 0.012969635499757715, 0.01382702293994953, 0.08767352672293782, 0.07711003418080509, 0.01032304597174516, 0.017466603276261594, 0.030906031242921017, 0.055963192935450934, 0.021716200244554784, 0.06037506049324293, 0.009073164455912774, 0.05166753828234505, 0.01061038699845085, 0.02717221577768214, 0.06096608463849407, 0.04199491238978226, 0.04739759904623497, 0.0649368975427933, 0.09542184532620013, 0.14768945082323626, 0.11415611661504954, 0.13800936634652317, 0.11249509363551624, 0.07549075700808316, 0.07394616957753897, 0.13863094471162185, 0.1089330148533918, 0.06868887707241811, 0.1168699873960577, 0.1681458461098373, 0.1514432783005759, 0.15665518847526982, 0.08539112575817853, 0.17901689949212596, 0.14654679573141038, 0.14126969530479982, 0.08889706106856465, 0.19543954404070973, 0.1663257140899077, 0.16115782811539248, 0.06723287981003523, 0.17662881669821218, 0.11973254746408202, 0.11887219050549902, 0.12998866470297799, 0.09373042397783138, 0.16167786583537236, 0.12367020492092706, 0.18688722717342898, 0.1738483307417482, 0.14859328279271722, 0.11115299377706833, 0.12493265006924048, 0.12498991418397054, 0.11051134773879312, 0.2785765891894698, 0.061749395536025986, 0.12009919810225256, 0.15330044348957017, 0.21183508535614237, 0.21958491794066504, 0.16407844639616087, 0.10436845041112974, 0.1945855695521459, 0.06686005450319499, 0.12583539850311354, 0.12018297173199244, 0.11609790890361182, 0.06838813656941056, 0.07183444031397812, 0.17184807948069647, 0.11254526281845756, 0.096879527263809, 0.11250779178226367, 0.11100672389147803, 0.19811742065940052, 0.12065595728927292, 0.18714775069383904, 0.1250774579239078, 0.15030086069600657, 0.19440914620645344, 0.1339399183052592, 0.16392872552387416, 0.11366117832949385, 0.20440691441763192, 0.170118133246433, 0.1926409496809356, 0.09903119891532697, 0.08017068088520318, 0.09016072333906777, 0.1651007548207417, 0.11005928332451731, 0.11954824993154034, 0.11704723452567123, 0.10500920587219298, 0.16070213459897786, 0.22358291200362146, 0.18782797356834635, 0.18709771509747952, 0.2765618957346305, 0.16214717034017667, 0.1737927141948603, 0.13354392314795405, 0.1838594427681528, 0.10631549710524268, 0.18518658092943951, 0.09444278184673749, 0.11357090348610654, 0.13779501925455406, 0.1289232968701981, 0.12212869740324095, 0.251277310308069, 0.16011626838007942, 0.11429450489231385, 0.15220199071336538, 0.09953725457307883, 0.11133632651763037, 0.20139205822488293, 0.13951044908026233, 0.1109903966425918, 0.27456118434201926, 0.13441333430819213, 0.12131675815908238, 0.1117056563089136, 0.17091420537326485, 0.1369363840785809, 0.1735550636658445, 0.11581819344428368, 0.05140715576999355, 0.10990567359840497, 0.1437091495608911, 0.09970540297217667, 0.35590618033893406, 0.18284356134245172, 0.25931269163265824, 0.17327258741715923, 0.12438490055501461, 0.0706538392114453, 0.1016799388162326, 0.11988271362497471, 0.1557845898787491, 0.1901812051073648, 0.21086402965011075, 0.1472752878908068, 0.1541650455328636, 0.1325246278429404, 0.12151418428402394, 0.17870295618195087, 0.16981291759293526, 0.0708930853579659, 0.13731042650761083, 0.15602433326421306, 0.18762312596663833, 0.12771502108080313, 0.16462468192912638, 0.06634636214585043, 0.16793938062619418, 0.15960927761625499, 0.1806579067488201, 0.0973418852663599, 0.10651388802216388, 0.06970758608076721, 0.09236652724212036, 0.1243655601865612, 0.15629615227226168, 0.11364480655174702, 0.11064900128985755, 0.08461049030302092, 0.26809452509041876, 0.12976866244571283, 0.08614686958026141, 0.1111108175246045, 0.11796478880569339, 0.11272968651610427, 0.11455889500211924, 0.10850353399291635, 0.08475121634546667, 0.13172337552532554, 0.12639718945138156, 0.11384881552658044, 0.15090685395989567, 0.1410726847825572, 0.22639021917711943, 0.12260866657015868, 0.154377284925431, 0.23305424518184736, 0.08236736379330978, 0.12390001094900072, 0.1116278866538778, 0.17897630401421338, 0.1298258375027217, 0.1397809767513536, 0.09950627732905559, 0.11168095021275803], [0.01650629572395701, 0.02347783989534946, 0.01298888031669776, 0.0686904949543532, 0.030764362672925927, 0.050565712444949895, 0.032008881244109944, 0.06887652169098146, 0.043434957187855616, 0.049551760603208095, 0.016345880503649823, 0.11599867633776739, 0.06425997722544707, 0.013712132913497044, 0.01961321904673241, 0.05674058891599998, 0.055652923256275244, 0.02606292393465992, 0.01822856629587477, 0.023261296046257485, 0.07113377869245596, 0.012792788202204974, 0.02013984147197334, 0.039714344529784285, 0.008458591037197039, 0.030090674408711493, 0.039522139413747936, 0.04823519062483683, 0.07008784028585069, 0.05480783598613925, 0.031148557682172395, 0.006941598048797459, 0.025722808786667883, 0.08409439338720404, 0.029739974379481282, 0.020518021374300588, 0.009469867436564527, 0.0674655134207569, 0.004321016158428392, 0.041771833930397406, 0.017068810266209766, 0.05355536901333835, 0.04665504318836611, 0.027442613572929986, 0.036872479249723256, 0.038991177279967815, 0.0074421877889108146, 0.03808618013863452, 0.035875006797141396, 0.05692296428605914, 0.07853520262870006, 0.036901385901728645, 0.029706869026995264, 0.039625880526728, 0.11615239738603123, 0.036797403590753675, 0.02752919252088759, 0.05480178748257458, 0.036413460911717266, 0.012061868292221334, 0.05790100360172801, 0.037238439690554515, 0.0454021346376976, 0.10254733133479021, 0.015759090310893953, 0.04629379167454317, 0.09458468048251234, 0.02390850077063078, 0.06471161119407043, 0.04371940754936077, 0.025698353165353183, 0.06726124469423667, 0.05153671620064415, 0.024446982715744525, 0.02275226252095308, 0.07506572161219083, 0.05058764661953319, 0.046171957001206465, 0.02398419241217198, 0.04129426561121363, 0.011296599004708696, 0.02301410335348919, 0.02090327765472466, 0.05357993039069697, 0.017981932069233153, 0.03765685141843278, 0.04630733958038036, 0.015200158486550208, 0.016989593423204497, 0.03031699605344329, 0.04325822585087735, 0.09782350942259654, 0.04683538507379126, 0.03865994563966524, 0.05405798481660895, 0.03879129835695494, 0.03648130805231631, 0.029349523065320682, 0.024774566700216383, 0.03193495220330078, 0.02473944827215746, 0.02560980195994489, 0.07607994062709622, 0.07042682365863584, 0.034447927318979055, 0.0482605164143024, 0.06127935259428341, 0.003341904671287921, 0.04010750097222626, 0.06736020266544074, 0.029197930125519633, 0.04988005333871115, 0.056047218895400874, 0.030243788751249667, 0.05947147714323364, 0.021543235307035502, 0.0363793926226208, 0.1126936032960657, 0.03179995183018036, 0.036048483816557564, 0.057047433583647944, 0.029162357132008765, 0.05026565842854325, 0.08648974922834896, 0.008530186951247742, 0.054887802398297936, 0.07626213788171299, 0.09962486510630697, 0.014650249322585296, 0.006057850450815749, 0.05928796257649083, 0.13189338671509176, 0.030233632460294757, 0.029264743825478945, 0.0502635878365254, 0.030597409131587483, 0.04577493768010754, 0.04889416210062336, 0.04851057936321013, 0.04904672910925001, 0.03613393098930828, 0.02390575853496557, 0.04372876603156328, 0.03315734735224396, 0.02477590442140354, 0.027087610942544416, 0.058503846448729746, 0.04786746758327354, 0.01868534705863567, 0.061861374488216825, 0.03639762719103601, 0.01641287046368234, 0.05298133262840565, 0.039139365617302246, 0.026871326845139265, 0.04435818518686574, 0.01677774180279812, 0.06445433828048408, 0.04410047440615017, 0.09510612828307785, 0.04105656313186046, 0.04520952876191586, 0.06330769785563461, 0.033849537358037196, 0.044597783853532746, 0.02227698187198257, 0.02906913225160679, 0.041205608649761416, 0.0068554583594959695, 0.04615257210389245, 0.02888288287067553, 0.025018955930136144, 0.09434022445930168, 0.021191015730437357, 0.03816913740593009, 0.07547025146777742, 0.04742085795442108, 0.007403217614410096, 0.04616050195181742, 0.04898528670310043, 0.041842293430818245, 0.054335084205376916, 0.07242212479468435, 0.07355850131716579, 0.014362582678586477, 0.017445969715481624, 0.012003118026768789, 0.02971773035824299, 0.07304284226847813, 0.08946704532718286, 0.04658442041545641, 0.04302022651245352, 0.06432418784243055, 0.02160898773581721, 0.0197066405962687, 0.05633484193822369, 0.009855933585640742, 0.06467952072853222, 0.03300822019809857, 0.03860574659483973, 0.051747601173701696, 0.06146263338450808, 0.060489343813969754, 0.04497675414313562, 0.03262420701503288, 0.03472847769444343, 0.035200542988604866, 0.034438116126693785, 0.010491215707588708, 0.05058250353613403, 0.027397800840844866, 0.020065057105966844, 0.03361441755259875, 0.05224114051088691, 0.03605992402299307, 0.024241118371719494, 0.023367206085822545, 0.06766033460735343, 0.0802888604812324, 0.037349921403802, 0.031670680837123655, 0.026470630182302557, 0.04044912268000189, 0.01325607667240547, 0.02689383618417196, 0.060019538359483704, 0.04210876897559501, 0.018146887377952226, 0.019327623922436032, 0.018990156386280432, 0.07709499084739946, 0.07723944247118197, 0.06197340910148341, 0.04774792614625767, 0.039919841510709375, 0.04969007095496636, 0.04044617264298722, 0.026831232316908427, 0.07248799040098675, 0.015650727473257575, 0.07089033199008554, 0.04285884650016669, 0.04734302892757114, 0.031155622928054072, 0.06904406895046122, 0.06849019671790302, 0.002287292413711839, 0.06686645923764445, 0.035473812895361334, 0.03681150068587158, 0.05167323055502493, 0.08224087214330211, 0.05409167461039033, 0.011353634909028187, 0.02500840444554342, 0.03715291459229775, 0.02185483528592158, 0.033639576358837076, 0.02669257501111133, 0.010402703464933438, 0.0065601735695963725, 0.057337438920512795, 0.06327735143713653, 0.04313598670705687, 0.053762031166115776, 0.0797545512614306, 0.05365935132431332, 0.06563295042724349, 0.08124023443087935, 0.03212910545698833, 0.032504843693459406, 0.026980990296578966, 0.011292599756416166, 0.041492741875117645, 0.038603011780651286, 0.025620425803936087, 0.07876491217757575, 0.027193597052246332, 0.05413459301053081, 0.12715481832856312, 0.028787915798602626, 0.03535439020197373, 0.0223294498573523, 0.020007646417070646, 0.04773480868607294, 0.034890262177214026, 0.01915331755299121, 0.027021682253689505, 0.04960014492098708, 0.005101810247651883, 0.04757559574500192, 0.05365697645174805, 0.02954400100861676, 0.022411896898120176, 0.03220769147446845, 0.11586778375203721, 0.016845113968884107, 0.04678682264056988, 0.058479667277424596, 0.019910374976461753, 0.023855431645642966, 0.027893108344869688, 0.007785893540130928, 0.0562575101503171, 0.031483258862863295, 0.023412098598782904, 0.02829143199051032, 0.05717443360481411, 0.014826056685706135, 0.015024967106000986, 0.02333485030248994, 0.04863236208620947, 0.02674656625458738, 0.01731784905132372, 0.029619655542774126, 0.021503305906662717, 0.006608653438888723, 0.026995777589036152, 0.017319771213806234, 0.03547656626324169, 0.06250438236747868, 0.03688224962388631, 0.018071160484396387, 0.009559326845192118, 0.014717500889673829, 0.014254787583922734, 0.03014161171449814, 0.029254177497932687, 0.018482171144569293, 0.02822002068569418, 0.008775829483056441, 0.07131015008781105, 0.06021333538228646, 0.030698719710926525, 0.01728535225993255, 0.06756099814083427, 0.01957252337888349, 0.05454797668789979, 0.004915125782645191, 0.042617744984454475, 0.045705238881055266, 0.04177008246188052, 0.015004110900918022, 0.0338152315816842, 0.038323392800521106, 0.03216884746507276, 0.07727015996351838, 0.010459372933837585, 0.02302031327417353, 0.04300370259443298, 0.02847439365723403, 0.05653698441165034, 0.15730988146970049, 0.07202166932984255, 0.15391169115900993, 0.19524241477483884, 0.11693741893395782, 0.130866150429938, 0.13244872097857296, 0.1291890599532053, 0.12587412376888096, 0.17023974156472832, 0.145703612070065, 0.1329398000962101, 0.2864168747328222, 0.18591859086882323, 0.08693160911207087, 0.11713241081451997, 0.22218126221559942, 0.09106425102800131, 0.12092180200852454, 0.16517623123945668, 0.1608878347906284, 0.13977434195112437, 0.07092328334692866, 0.10741126330685802, 0.1505388377700001, 0.17336217948468402, 0.11253510281676427, 0.08041224995395169, 0.16954354767221957, 0.10382102002040483, 0.08918318126234226, 0.10981225947034545, 0.13789137970888987, 0.15746818156912923, 0.10211025830358267, 0.06896361272083595, 0.11460237743449397, 0.1519557015853934, 0.13946102204499766, 0.11930944907362573, 0.09319319069618359, 0.12683318636845797, 0.1871642709011212, 0.14134637400275096, 0.11640782235190272, 0.12507147621363401, 0.2389664459042251, 0.14549567713402212, 0.18304900266230106, 0.1482520581339486, 0.1557155404589139, 0.19151183136273175, 0.12299135501962155, 0.13435250788461417, 0.1661849583615549, 0.1946855368441902, 0.11980754148680717, 0.19637174089439213, 0.09028587912325747, 0.08641191278002225, 0.14762181148398668, 0.05725417366193142, 0.12500555865699425, 0.21667675289791077, 0.1134039054159075, 0.10155067895539105, 0.14142373547656462, 0.17482260736869648, 0.23526734439656138, 0.14633906859671697, 0.10311598714906722, 0.1588498378987424, 0.13024656102061272, 0.15074620867380872, 0.15306956134736538, 0.17414556088624522, 0.14669388940092176, 0.10765962302684784, 0.1176781120011583, 0.08074363373452798, 0.10161232916289009, 0.15647587075363845, 0.09165740513708442, 0.11602829545154236, 0.08538428315659985, 0.1995053407154046, 0.1399071715422906, 0.14584240852855146, 0.1318647398147732, 0.17838273430243134, 0.21487849939148873, 0.21905423782300204, 0.13732279068790376, 0.14054084691451862, 0.2931628189980984, 0.0927329997648485, 0.16107069997815415, 0.09874129376839846, 0.1768957226886414, 0.15759225381771103, 0.16219218901824206, 0.17888334259623662, 0.1364154409384355, 0.20976571046048775, 0.13433266285574064, 0.10556135632214136, 0.13508083677152172, 0.07172887722845189, 0.1276355519075878, 0.13064597005723044, 0.114209840685362, 0.13709995342651382, 0.16374217928387225, 0.09078653936740011, 0.1947947809821926, 0.17191720311529934, 0.09682040777988732, 0.2417102103936486, 0.1161757082445547, 0.14908318931702524, 0.12675353907980025, 0.10731346308602951, 0.16749378031818196, 0.17910042079165578, 0.18879595678299665, 0.11047989552025683, 0.16716824466129765, 0.22056713554775342, 0.12138116173446178, 0.0799097194976639, 0.15236774197546765, 0.2544533758191392, 0.11207747971639037, 0.21177289338083938, 0.10608137919916771, 0.15948648186167702, 0.11957078153500333, 0.22828732675407082, 0.12288198471651413, 0.15264956513419747, 0.0834534820751287, 0.11833428929094225, 0.08666494060889818, 0.16837807896081358, 0.2091215262771584, 0.17893138923682272, 0.09407978257513605, 0.15124605997698382, 0.0707843087729998, 0.1540175362606533, 0.13006929162656888, 0.1455964904744178, 0.12220320902997628, 0.08709578702109866, 0.1804762883693911, 0.26202527107670903, 0.08733465467230417, 0.1362958809477277, 0.16127484996104613, 0.22102170099969953, 0.0661442827549763, 0.1361040654592216, 0.14342805370688438, 0.09841903840424493, 0.22829127497971058, 0.1649050207925029, 0.1010110485367477, 0.2069960450171493, 0.10441402569995262, 0.23472818895243108, 0.1482708938419819, 0.1151280925842002, 0.1205114611366298, 0.12083972047548741, 0.07854040508391336, 0.21462931588757783], [0.03494092117762193, 0.014437531244766433, 0.02929876387497643, 0.025395829652552493, 0.009523787248326698, 0.004750565667563933, 0.06976257922360674, 0.05297947354847565, 0.041554239942342974, 0.06260880254558288, 0.038018448030925356, 0.04468244063900784, 0.02585159552836558, 0.04391695612866897, 0.0497460771293845, 0.0311434665491106, 0.05748548996052705, 0.03882532211719081, 0.045184202972450294, 0.08706302862265147, 0.027424629479355644, 0.06352161450195126, 0.048668898016330786, 0.05341643154679332, 0.034276019941898994, 0.0337166780809639, 0.012590530695888447, 0.0538547810720047, 0.05172298784600571, 0.030957270973885898, 0.06074500997783616, 0.02983034199132817, 0.0513495354243787, 0.03257636817579623, 0.08950611198088154, 0.09227259361068718, 0.0476762124162633, 0.03268083659349941, 0.02699265314731747, 0.022419277556764428, 0.040723991915001534, 0.03877203220326919, 0.05100909744214732, 0.04502825177041814, 0.03380505302629899, 0.029794913716614246, 0.044926644332008436, 0.06910811629495583, 0.011952933073189342, 0.039616251160623506, 0.024261291800939944, 0.032639224373269826, 0.02350500250031473, 0.03841261008346919, 0.06691134432912804, 0.049718009104253724, 0.03264081999077462, 0.10026426985859871, 0.07869493507314473, 0.05874469192349352, 0.021839519213244785, 0.03540591380442493, 0.06713061928167008, 0.056786991699482314, 0.07850877474993467, 0.08763228557654656, 0.03397229971596971, 0.031108223811315838, 0.0351137562392978, 0.07700636357185431, 0.04287666917662136, 0.008849050700519001, 0.035444917375571094, 0.006325044951154268, 0.01621113802684704, 0.06279179389821365, 0.02200452276156284, 0.07906779748736881, 0.012639954020414734, 0.025209164668922313, 0.03022598277311772, 0.03460227919276804, 0.026499327177589294, 0.07093194421031512, 0.03524286767060403, 0.01334406199021032, 0.03489181326585822, 0.0618630183453206, 0.02061093269730918, 0.0336652880650945, 0.054347455807146616, 0.0367958933202317, 0.06561975504155271, 0.026742508562165312, 0.045956604299135506, 0.03678738830785733, 0.038651941576972604, 0.026582616555970162, 0.020130173143115826, 0.08197961389669217, 0.032313128394889645, 0.03704423819726799, 0.13890392147004604, 0.026892108835454565, 0.022382014321919996, 0.04000543340225704, 0.04613509452610742, 0.025124422536464408, 0.015903156017884612, 0.03749393887119368, 0.0437120973947458, 0.04008168165455572, 0.06066141075280029, 0.053542463065241463, 0.0573702158726519, 0.06300580702372827, 0.036250526100047864, 0.019355328295205254, 0.031020338683447335, 0.09796056925551966, 0.07183406181866303, 0.007186703451225185, 0.03183221670042258, 0.004475363393794396, 0.01467732008677558, 0.09352844106615521, 0.0470693545503309, 0.021503111092897598, 0.08002928690984845, 0.021431087516248226, 0.02578487830760423, 0.052510588357108645, 0.019924963744415436, 0.01046772209519986, 0.09792956974706613, 0.04405568579386454, 0.039387309734593146, 0.015394688380183652, 0.014393846577149816, 0.024936824302130844, 0.047513815661659464, 0.05593794136075303, 0.07248076188261621, 0.03388643694052007, 0.07398988949717022, 0.011422552597650792, 0.05297600400808733, 0.038445435275207274, 0.027190867804165464, 0.034740237024379894, 0.05407627504609991, 0.03729941825440619, 0.03724937894730829, 0.015134574896364938, 0.010501393335289322, 0.056671109050512314, 0.02075101678201463, 0.04540931862720754, 0.044506733465823345, 0.03733351994014811, 0.04271211648301687, 0.01840667988290079, 0.03029813065950293, 0.030748009448871017, 0.05738504769396968, 0.03160660380672198, 0.022094055457273498, 0.02165188387152739, 0.03726584720425308, 0.06429743341868743, 0.027876808926521335, 0.00845683121951879, 0.04013574340206105, 0.030813294324616436, 0.024519015569239855, 0.05269383575068787, 0.004300863602111349, 0.06931013631401584, 0.06792721091187559, 0.019936860371672083, 0.006364650589603116, 0.05555434378038626, 0.011989056183665525, 0.09334573915111832, 0.01736638179863803, 0.03353463667735923, 0.02841735589754535, 0.04458390198124107, 0.008632268436485901, 0.030672278844576795, 0.04935495788231492, 0.017734002794895787, 0.03488704496703576, 0.061967330912011676, 0.0818781326233875, 0.08631072836578824, 0.026156391868426, 0.00591144326790527, 0.02483431700966321, 0.02116388095600996, 0.13176192267565057, 0.02221747832663823, 0.02360087128181476, 0.06507118174340576, 0.03916696608939674, 0.05442534791654907, 0.054369935460272245, 0.03192469201167114, 0.08696005563251674, 0.04713795497082174, 0.019722401957551483, 0.026096439323737286, 0.044701098231598735, 0.00636114626104245, 0.05183964975003619, 0.023099967984308023, 0.01996201361180283, 0.065559047361603, 0.014970121465012198, 0.02245847037556814, 0.048185630002990365, 0.036354359981487505, 0.06194996465637814, 0.03422196190513205, 0.07491618627682328, 0.038844402733957395, 0.03143980611639563, 0.0020532839744191733, 0.03567928390111774, 0.02442384255118668, 0.03597153423470445, 0.04340613588283304, 0.030045746643736493, 0.026355517511547077, 0.07055981652229093, 0.028040741926815826, 0.009755711180332582, 0.020134060141572263, 0.018507055356167257, 0.046422253726632334, 0.04409891218529083, 0.028322045582171995, 0.04002685920568183, 0.0249852809793083, 0.013093425732222386, 0.03864213409542572, 0.044655964520643465, 0.014222753707144875, 0.04719265867606737, 0.04339752696978394, 0.022555285395355895, 0.034221271707792766, 0.06843970098998398, 0.02140536467777565, 0.08646283153211698, 0.03493844240438193, 0.04351966592366807, 0.06692246170132421, 0.026515051431488246, 0.041321420794702135, 0.02515885076718405, 0.03795699820329901, 0.018918186615337618, 0.014757228054804727, 0.035587825332186185, 0.024020511264097877, 0.06516922687296756, 0.01932556817337172, 0.09544951259158552, 0.03141965309623629, 0.03270921632065438, 0.03975443163653836, 0.022804518994234968, 0.04905520072497893, 0.049960205287788995, 0.024959250149549916, 0.02144170579413185, 0.059871594930882566, 0.06182554359838832, 0.027269490929029416, 0.06667192748864181, 0.08102183521259576, 0.0754446251085028, 0.038236427935771644, 0.04721877114207018, 0.020665057527367026, 0.02318281949555967, 0.019273417456133757, 0.0495298041641945, 0.03949787489545997, 0.056124784459825605, 0.08141341459122486, 0.04239199850417208, 0.02718136089242762, 0.06266211101319641, 0.006971849379624473, 0.05691768019460142, 0.02900466188293649, 0.038531253521796316, 0.02435878588585183, 0.0637369709147606, 0.09646529011661187, 0.07000164725468494, 0.020350997328932863, 0.07107052544597536, 0.040263826958835125, 0.019920479317079298, 0.03181414540449623, 0.03755315483431332, 0.03160814005241264, 0.1725060527678579, 0.05853136899531819, 0.04245524432917591, 0.058535565840429626, 0.04063609565491788, 0.022485497538582422, 0.04735917435027659, 0.01420782911736751, 0.08329544172738679, 0.01691334146016743, 0.0867163714428898, 0.05061617848696187, 0.028248908784007654, 0.04616487320163287, 0.015578110178466886, 0.01642223451199243, 0.10111105293617584, 0.021082823586766608, 0.012444652293197578, 0.04428594453202095, 0.044297737258602865, 0.04605079026077874, 0.008470426437270362, 0.06158283904369455, 0.06458882286096923, 0.0401499852159759, 0.03715779050253332, 0.06637761398451403, 0.02616908630443504, 0.05780091756605543, 0.03899152608937584, 0.04728693740617018, 0.0030597081195082865, 0.04412005597259849, 0.037556193929049186, 0.0382993583480129, 0.02570157408626983, 0.07795562240062281, 0.01433930799976224, 0.0644996835035272, 0.03187058573530521, 0.021744938057963736, 0.09773494151886553, 0.15098004456376657, 0.11577700424822979, 0.17037807789165527, 0.08538257621694356, 0.08393597454414703, 0.11987454257905483, 0.145174965437036, 0.08349283816642128, 0.149583337479271, 0.16237221920164302, 0.09916960945702158, 0.13707810459891334, 0.11937582676182501, 0.11836254285299219, 0.13986909936647862, 0.10561110990238376, 0.1572122742072679, 0.1222233880253043, 0.16349804238416255, 0.12965607864316553, 0.1253336769877933, 0.08285836127470247, 0.22821946477051824, 0.24818118894472718, 0.09294447474530898, 0.06801590498071164, 0.1051299532991834, 0.162606337107718, 0.12893450330011547, 0.18074806284857914, 0.09437938017072156, 0.1286124112084508, 0.12417459816788323, 0.21053102798759937, 0.2008234988898039, 0.1316073926864192, 0.06990714959101751, 0.14432962954742834, 0.11477791762445122, 0.22926409699721262, 0.14248353720176965, 0.1557131952722557, 0.14453195384703577, 0.11349867025273852, 0.13085374172078446, 0.11124383265268989, 0.13106624828651547, 0.13435664906864986, 0.09791442251298577, 0.24646010395372286, 0.07729592733085155, 0.11379392628441565, 0.08825850978610106, 0.14805647253524512, 0.12959311483427882, 0.14021538547240198, 0.21452425746247172, 0.1954703580122441, 0.10685538727557287, 0.10423389161587693, 0.11779834734625183, 0.14701094973133877, 0.12104312831070274, 0.21011165517847985, 0.30627333268057555, 0.10155991127248853, 0.17726295220199972, 0.07839417230570689, 0.16251469671260566, 0.1935827944544144, 0.07891893008491024, 0.1324352584197186, 0.1406174068688415, 0.10189080523559824, 0.06617809500312433, 0.18831427325494587, 0.14458326593739912, 0.17673127760645002, 0.0907532095152419, 0.12253546854481101, 0.16858740913448855, 0.11086321479524486, 0.10736624462879263, 0.11260899846092798, 0.17516375781269744, 0.09633644585846923, 0.1576765172649175, 0.12524936901172623, 0.0928125654172618, 0.07434117767843418, 0.09848325644270517, 0.16069995268480852, 0.3604232770157978, 0.17460747360019013, 0.07204552195616998, 0.1434523070929572, 0.1239067422284279, 0.1122599960945081, 0.15539545216597617, 0.1340154540957883, 0.19743866723729298, 0.35463295178487897, 0.0791476303129457, 0.1382162474328652, 0.20763228822033852, 0.18739591003395617, 0.1304875809000805, 0.13920769735705107, 0.09765578404767439, 0.23899403895484284, 0.1102567242924124, 0.1500893189222552, 0.12321304195211269, 0.1666122127790004, 0.2138282119994983, 0.10247786631225608, 0.1049389764375519, 0.18556684255599976, 0.09074552828678861, 0.21107990556629375, 0.08089284994639456, 0.0635537866037339, 0.09408361947862431, 0.11189270720933564, 0.29249607352539897, 0.14650982193415985, 0.0814157523564063, 0.22644570213742554, 0.1351826891186647, 0.11938315175939351, 0.12776121235219762, 0.11950452259043232, 0.07213883218355477, 0.25346121343318373, 0.19599502673372626, 0.13285550696309656, 0.1270726477378048, 0.11289637288427912, 0.09791281205252744, 0.19949477253248915, 0.13318341749254614, 0.18416801292914897, 0.12703116168268025, 0.1892655878327787, 0.19763821590458974, 0.1380295676062815, 0.09199751657433808, 0.14365635317517444, 0.08296056985273026, 0.18430590396746993, 0.14731944567756727, 0.1290690992027521, 0.08118662910419516, 0.25933771685231477, 0.19944360887166113, 0.07456542502040975, 0.16550737753277645, 0.1387348008574918, 0.11111040934338234, 0.10698522601160221, 0.15310883580241352, 0.10475760296685621, 0.2611000504111871, 0.1145032858767081, 0.13271776435431093, 0.106965529412264, 0.07226683781482279, 0.12514855567133054, 0.11962288030190393, 0.09240978703019209, 0.18130407988792285, 0.13688804057892412, 0.21423248952487484, 0.13688232604181394, 0.1524652898660861], [0.04175148053036537, 0.008494305966451066, 0.05206920344789978, 0.028402629832271487, 0.015930370573187247, 0.045609000881086104, 0.04907570997602306, 0.03509270150971133, 0.02474385291861836, 0.04786055818840396, 0.039140649532782845, 0.062230307230493054, 0.05722512229112908, 0.03197318765160162, 0.02067928264295915, 0.010340622811781941, 0.02859557524061529, 0.03547907843312714, 0.020528175809886307, 0.06162603574921377, 0.010218217612418812, 0.1202243019361049, 0.10149342226213776, 0.005399113679231959, 0.018844211190298665, 0.02149813499272568, 0.012900457131763687, 0.049671739907353185, 0.06683010884444229, 0.04330887371907011, 0.08572254664613865, 0.0320308896334609, 0.01617737958440557, 0.007554721496489947, 0.03112555481493473, 0.04392547227325849, 0.06972423987463117, 0.054764895321568474, 0.05453992067486979, 0.022651603176200297, 0.015693118948547635, 0.04235441614582669, 0.0462932536174776, 0.0649248153786175, 0.06191196298459545, 0.062977405032143, 0.01593247270648135, 0.042318284686189145, 0.015779966925038025, 0.056456030943081714, 0.016007236663426738, 0.05201782456424553, 0.04156162431172561, 0.053209839898045175, 0.07564113097032532, 0.019787261953752022, 0.02558560052420944, 0.013159276495571248, 0.0519321139290696, 0.0637704343535006, 0.03822724014753476, 0.04933315358357504, 0.02901711512095062, 0.07642014854354784, 0.004078951242263429, 0.026432838167238515, 0.06132036738563329, 0.03726437775185332, 0.03349754784721881, 0.06430055043892935, 0.04903680288407486, 0.01938437038916163, 0.04429089465702418, 0.06355821722536348, 0.04139204727835022, 0.08386458735913038, 0.0708485564973671, 0.0436207798338728, 0.01429637011824525, 0.031573285086778924, 0.024755042650213, 0.0325558143958915, 0.008377597678190796, 0.01822908023314085, 0.036169587474432774, 0.017192370432894677, 0.02596502352389507, 0.06791303589125164, 0.0492130740894936, 0.05974190091365017, 0.018379439352429472, 0.01900483050121693, 0.040572467623860575, 0.026582059945212677, 0.03522386869008187, 0.044760714954463765, 0.0641224201535806, 0.012569357222673716, 0.06299771019257605, 0.03407325035368558, 0.02504678090190282, 0.012698877762886696, 0.013824750112689799, 0.0700169280753471, 0.052298126320238225, 0.06909980424097739, 0.015142904576350702, 0.014897758355800761, 0.05699323824956082, 0.009765907361725112, 0.02625226250529522, 0.031274767316062935, 0.02150653424905613, 0.08087605514447205, 0.09291091482737102, 0.05178128354600631, 0.030747580858587753, 0.007098899495758815, 0.11788680392783135, 0.018382016460236628, 0.049408039994887076, 0.016191361646633595, 0.09908481166348793, 0.03687196716782637, 0.044680971186608076, 0.05635591151076369, 0.026595611561788246, 0.024647525860928, 0.06670013652183115, 0.07153335100156255, 0.029283996991580352, 0.01820516452426091, 0.04435829650901724, 0.005951505327175255, 0.01215664704432129, 0.0542277473869035, 0.053142282195040025, 0.0773141990066506, 0.032006150140659884, 0.02577784274762962, 0.04800131020601839, 0.026870786932704505, 0.056878190516727045, 0.06675922631984577, 0.013132209442119347, 0.01771340634149965, 0.04277445317711681, 0.01435149406461278, 0.04865847455221228, 0.0104820548222051, 0.023500774113927037, 0.03764314024010673, 0.0755924683471676, 0.03185337904142216, 0.0253717265513842, 0.059916235113632865, 0.018162242413382046, 0.026168479598709382, 0.066894534684252, 0.05962102732155472, 0.027387555492168758, 0.04137285905017052, 0.018742570355243515, 0.038793795683886856, 0.031123400731303263, 0.03517734716297127, 0.04179801318969112, 0.05317386057868134, 0.03600458207074553, 0.1331983198178932, 0.07305050865397789, 0.046795791495242156, 0.049464877374703065, 0.01443546900190995, 0.07811427873093635, 0.023479561677959282, 0.032131491461768746, 0.028904935788887087, 0.04169638348685112, 0.03811169517575763, 0.046122919593472034, 0.027858058565470856, 0.03412491125345696, 0.028689449500234332, 0.04668148591008503, 0.059350640658522025, 0.006380036702466896, 0.03370225444086827, 0.03976982749009039, 0.006625634241572698, 0.07229577415273525, 0.0027150071946380194, 0.011492217072373023, 0.0655443751020357, 0.029615944804390892, 0.013323804141691653, 0.025622733883210458, 0.022329898856696673, 0.06333353201625869, 0.04549493649392389, 0.022739083833585028, 0.08333181438501924, 0.06044364236004185, 0.06131328729679808, 0.06347869610181078, 0.12271432613488287, 0.026573545655992348, 0.055210454811458476, 0.06339346044114791, 0.022011847759131342, 0.032278139842674136, 0.025428801418456715, 0.02637304332893109, 0.040454840927850455, 0.049943451303988695, 0.01814192240999546, 0.027003115574188996, 0.043006463383790106, 0.0258821553143207, 0.019449349128990434, 0.011353267545928247, 0.05250586829788517, 0.037244569830363616, 0.052765545769943856, 0.038996420553303324, 0.01803536113584414, 0.008829922771838028, 0.02098940203723032, 0.008875935000105528, 0.01956958632945316, 0.044013988226652145, 0.018488982204871718, 0.031141555518843234, 0.046863004099577665, 0.01966671861737268, 0.021724311918660533, 0.05140372704772744, 0.05035560672695283, 0.035104731723549776, 0.03611233820265625, 0.021936156117590144, 0.08433144277660176, 0.005173532326807617, 0.023388104964396916, 0.013152009014447685, 0.05734765829402022, 0.0675896301981993, 0.018573247507447377, 0.03369177160493564, 0.06115723961556796, 0.023884891197667457, 0.046261949828476645, 0.07170936616603285, 0.08230247782194056, 0.04404162580613047, 0.06369164795614779, 0.0028931926772202132, 0.03348677928443067, 0.013147691570338793, 0.034147721162298694, 0.029854801323381253, 0.0629634378128685, 0.05279243006953038, 0.042566080373944715, 0.06290237390203401, 0.08171989189577289, 0.016710030104150064, 0.016540215583518147, 0.020085772302991245, 0.014936819443391869, 0.03126577619696036, 0.014767491957172751, 0.05019133604946546, 0.026365889025328215, 0.028993665109737776, 0.05359268048778176, 0.020649969665100798, 0.04548152588540688, 0.028987061850784812, 0.07206248003058136, 0.02841959532815963, 0.05902841869101394, 0.019354786527401302, 0.014812757399340626, 0.05662489180394914, 0.06639418614213355, 0.07289413071703166, 0.013745096330239903, 0.04316501952416729, 0.08304195376695134, 0.033110039148596115, 0.03437287392443977, 0.05636822745145764, 0.022720064444001764, 0.02393139231571695, 0.020003186109534, 0.08204685247619636, 0.036149850056972355, 0.07774469660944305, 0.026012459748017136, 0.05058399896370247, 0.06538381887366995, 0.042772208180394955, 0.045873806593590416, 0.02213390136603266, 0.06119443605712149, 0.04355033888714388, 0.048398656072095037, 0.018752578216663096, 0.02692601570743136, 0.026528571506787557, 0.04799725065822713, 0.0372992178745335, 0.037274715868989006, 0.0191646520033828, 0.017323888278042432, 0.0074087939265155, 0.04887518167379312, 0.013529202788049588, 0.022939497102925088, 0.022165214431879576, 0.052260900192777626, 0.034481056791264564, 0.016943275986704975, 0.037945116418995894, 0.02385590847552521, 0.027129681438964326, 0.024158159249054734, 0.022172233293531463, 0.08736233678064309, 0.043356322930776514, 0.03101693593634991, 0.043108196987304837, 0.016746078072173987, 0.022485686786239967, 0.06824969634180889, 0.014273049982875818, 0.06531838371302001, 0.012012871702609118, 0.03602725839300547, 0.011443550738476915, 0.08952947478974238, 0.03481738327536732, 0.030064407947065774, 0.05097489927720744, 0.04427233354363125, 0.042354341931059025, 0.01627323352295207, 0.005477500244523981, 0.029166307213017717, 0.05332011933205649, 0.009606361381884199, 0.12338546512182802, 0.1436229862156324, 0.11693960084812716, 0.1406508925720118, 0.12000474496744573, 0.10821794072398916, 0.14022530056536198, 0.1696602875017561, 0.14493603841401637, 0.18469199887476861, 0.19128647079924121, 0.10065803857287392, 0.20233728719176725, 0.12555673689348623, 0.1326281574438326, 0.09701299510197714, 0.10268866593833081, 0.20525839529000223, 0.12441934362868778, 0.17788359546102583, 0.10616331230266951, 0.2283935874584131, 0.2619835326913744, 0.1145034639921505, 0.15755421132780612, 0.1685946821817197, 0.13377634895732626, 0.12967650254722685, 0.1336530188564211, 0.11969219689490274, 0.23764024284901097, 0.10612501006107777, 0.15418882394442335, 0.11744613890186884, 0.10428791254526004, 0.14303527947049588, 0.12572858860949054, 0.14363156544277444, 0.1324974949238822, 0.17672547401161864, 0.22398555680410936, 0.16851147258421406, 0.16054971230914816, 0.17606490320758894, 0.14797384181292728, 0.14428054390009493, 0.1499728165799752, 0.15413993125548586, 0.1323820315883495, 0.14709444134496152, 0.08017929721972905, 0.17719667841447517, 0.164418320346158, 0.09098175389226526, 0.2063516975613311, 0.10074025369249284, 0.1308835909003392, 0.10669442286598496, 0.13751536316704005, 0.13839295279467478, 0.09659875053330325, 0.12662452412769198, 0.12867209472460672, 0.18829761946108192, 0.0769607289112173, 0.10230954721919261, 0.1391927059739828, 0.13963278470328078, 0.08884915543603711, 0.16024991433368996, 0.11952464963542297, 0.08069111194345169, 0.1286705065285787, 0.14585048309527338, 0.09347892497316934, 0.16676852392265573, 0.22786350105889142, 0.23463518300559372, 0.19467795209493488, 0.13337671727640554, 0.07913566689239815, 0.1862733523012139, 0.07638561641215347, 0.11227755530853756, 0.15364827326266095, 0.14683908317238092, 0.11962921082158573, 0.14072090678382665, 0.12443060943041928, 0.1643218263052404, 0.05443645415653009, 0.12235166825121269, 0.10208103994955309, 0.1069272865424864, 0.10064603804494254, 0.13730287144426256, 0.11565454246010631, 0.1356029970338568, 0.15451778832357377, 0.29151014517992735, 0.13360255281440914, 0.08436518823145889, 0.1272330406936817, 0.30907781969290227, 0.14687519607832655, 0.12767944252118468, 0.13447990495478734, 0.09656061156420037, 0.14051778096472844, 0.1335180370369926, 0.12210943867103197, 0.1033425128844101, 0.11184741393662989, 0.2160340826958418, 0.2540606015827507, 0.2938006800832227, 0.0959110542316921, 0.12048623553710058, 0.1665898592909798, 0.11400847375625744, 0.14901641086908057, 0.13928421278251335, 0.24533134186640382, 0.10909532255027443, 0.12339962529949844, 0.15761978749651462, 0.1320012949872762, 0.19613591604866087, 0.1538447049097158, 0.152793794113677, 0.1208860008046031, 0.15022738807601854, 0.14123238011961803, 0.12896224478026852, 0.13816722115734592, 0.13055100484052673, 0.20479379600146785, 0.08354151563253254, 0.12097502141841687, 0.1398880686610937, 0.15668214327888563, 0.07244830034323968, 0.13965126418042928, 0.16950409510172904, 0.09396516528795473, 0.1519379048841074, 0.1655705491430126, 0.0748809045762755, 0.12140326289227232, 0.05753824923885986, 0.06719623255776241, 0.13853513344656676, 0.15605710650561377, 0.1291283522732556, 0.26651093037799, 0.1888200468965806, 0.10384051623987034, 0.15463546325918287, 0.11755398780223913, 0.0976022232498508, 0.2064557615085505, 0.14468410896370187, 0.20402160618687049, 0.11273413940216415, 0.162918662535958, 0.19574691192246974, 0.08436886186245829, 0.24298888631165028, 0.11747638141969219, 0.2623694494832307, 0.12048753429553472, 0.1043415475578513, 0.12254991816007532, 0.0743141931889113, 0.18323433178011328, 0.08395682147238404], [0.09779433559742756, 0.025273560822824948, 0.0255979591383948, 0.027515039764693938, 0.021400516598077957, 0.055768197344150394, 0.04523846509982832, 0.025767519473447464, 0.04107048953301273, 0.042750518914544955, 0.014231947989173932, 0.06934403761988506, 0.04275291976227891, 0.04377677927550394, 0.036397727380972356, 0.035266104314359836, 0.04292748402804136, 0.04665844593546353, 0.044567292716237716, 0.039497533507528715, 0.03456277467194013, 0.04173544642981142, 0.02137317216693191, 0.030553101059922483, 0.05061205956735648, 0.01461810412365594, 0.04053578326420393, 0.04277882071619388, 0.02496345256076893, 0.01877250302641187, 0.02904473785747541, 0.026425323922012467, 0.035090296951239, 0.02823958740918897, 0.01723124041745905, 0.0578113039227901, 0.04055271536344662, 0.016127898743434343, 0.05481828542542644, 0.0523826532298699, 0.09431157755898312, 0.00939689112783526, 0.011832082673208788, 0.052378879408934154, 0.05346329075109679, 0.05450861317513045, 0.03588132247386966, 0.04077239107573405, 0.07975551605341025, 0.017457617723266594, 0.018170148141507525, 0.03895552450558171, 0.037600340583594516, 0.07389203732600436, 0.03951010919990949, 0.019471730447548907, 0.04291376913897693, 0.013218967433203943, 0.012780227352777729, 0.025042359557119198, 0.03459724743152037, 0.016158310099854134, 0.043322228666511364, 0.038471955922432244, 0.09618971584131941, 0.012889214522147086, 0.007501918153138831, 0.038239411369431764, 0.0196753460841137, 0.13901157741202042, 0.02034245520917466, 0.04032017081044614, 0.05003667247365229, 0.07124665935407393, 0.04791610794200096, 0.04379365571367089, 0.02186510660976637, 0.04746289319882635, 0.16240640252362937, 0.015864519809838384, 0.015804515314812306, 0.1368870461010374, 0.00995670703559881, 0.05289831227855757, 0.027000542177120224, 0.05122141104948241, 0.02315867557626916, 0.07895086469943635, 0.03032504093425814, 0.04676885153457988, 0.01852552370110061, 0.016168052643479314, 0.018781957987812348, 0.049302473198622465, 0.044342767068883404, 0.029861102157155983, 0.03317263559438288, 0.1264273503329605, 0.03358827540068887, 0.018139660714950878, 0.09050585911609232, 0.018232460715807974, 0.01209878086228855, 0.027868170327565167, 0.024236962344730273, 0.030471433274215087, 0.02796355856844457, 0.012948189287271816, 0.03776529774768278, 0.05965649455902167, 0.03788224537856877, 0.023089666974556167, 0.05371536492020823, 0.0050927416668855585, 0.021777128713438287, 0.02318984392331913, 0.021404978760983795, 0.02458883867802797, 0.01788675905117998, 0.050462535364204086, 0.011207720326638082, 0.030286920518847182, 0.025920663501892705, 0.049332233320456, 0.07423565170029178, 0.01513604620413389, 0.01697991210676264, 0.09978705405956134, 0.026360048323113006, 0.016067502765508834, 0.09217945407726802, 0.02296324397320859, 0.016499621960974764, 0.04934826742100995, 0.051316227836650796, 0.010717442728491733, 0.0855287718877662, 0.003869229121846729, 0.040329180483240634, 0.04139739816309884, 0.038734739282517694, 0.010829183265741449, 0.03759336810617242, 0.030034913143026643, 0.03955025938921608, 0.02292230896273395, 0.07573074530228041, 0.022902391574461944, 0.032356221199734136, 0.011882605303981109, 0.06489240578957833, 0.024508091155439615, 0.06559190966072492, 0.05099595771753229, 0.025389575203007553, 0.026506596514082048, 0.022635710083704907, 0.03996875646407716, 0.07365558165474795, 0.029507867693610024, 0.011224952995689819, 0.031813243695069104, 0.024368686135858297, 0.03819374331214931, 0.033005218210746534, 0.04841548055992462, 0.034474332933314145, 0.037037165529909544, 0.00331464721057273, 0.023372562536678743, 0.050784174745786004, 0.0702212487522047, 0.0660858757328242, 0.034710135514615104, 0.026737337648228277, 0.03874545589496847, 0.029230983527668286, 0.014883926578477258, 0.03069927632168401, 0.017704175879771356, 0.032335596915800124, 0.037086718730279244, 0.07437232561642304, 0.07674466003663838, 0.06108571513323113, 0.017017641039274167, 0.0063017809407028835, 0.05525626016606111, 0.026336843220633455, 0.01451041014661314, 0.07170849043177441, 0.019504861775203608, 0.0671470578527078, 0.06959417107282206, 0.09383840646478347, 0.047190565819619223, 0.024642848475195933, 0.07217553138616495, 0.01991242515941849, 0.030141593160806224, 0.036667991589638405, 0.02598406146717025, 0.01159831821496482, 0.07675446380744688, 0.028312219546933193, 0.11240818072110415, 0.03602499855333008, 0.10277433946612291, 0.04867101684794761, 0.016926750213315245, 0.016726361063774675, 0.03296628514362965, 0.014643185004388215, 0.014946309656806989, 0.033137925347546116, 0.011644355490716407, 0.09720148576889187, 0.04685514846642036, 0.04933189935400151, 0.08465885606710799, 0.03864153666654602, 0.06194900728587527, 0.10542046700720675, 0.005611877677438315, 0.11152655381010845, 0.04012196171970572, 0.024299495707964525, 0.030466091666312423, 0.019297112376079895, 0.08050376418395899, 0.02491687537258258, 0.028442850525607355, 0.01316601983489818, 0.024023160731303506, 0.029818885086569935, 0.03661193717562128, 0.01679188342677662, 0.03706733383296523, 0.08692975374287926, 0.05014059541281313, 0.0035699295449376223, 0.09601353740436025, 0.03537083248374984, 0.0290402478640317, 0.031272667038138025, 0.05951929371803999, 0.0054831461329740705, 0.03575431874196511, 0.08790548497927375, 0.05904665325942915, 0.06978817589697428, 0.033186261425726116, 0.06144949365989305, 0.047860669510555454, 0.02970353678392712, 0.023060669409460388, 0.0793606712250039, 0.040618050334160216, 0.050571208048495464, 0.03472891927231103, 0.03741480737517122, 0.007362283531620051, 0.030957705130276736, 0.00897240770427743, 0.03340911724080797, 0.042214565837639384, 0.01649414305575192, 0.03535056071996223, 0.054513737704837695, 0.11654886009637266, 0.010684317894629203, 0.008926933533075498, 0.01993177294934867, 0.05195618548896164, 0.04014854916022159, 0.033743914900696836, 0.027540914743440226, 0.044003831935697235, 0.031169582725851797, 0.08924251596909016, 0.023136351774155628, 0.020076141081517562, 0.057501587143633515, 0.04890240736131091, 0.02513618743250845, 0.022376943597919308, 0.008661231677251635, 0.030077436349529307, 0.07643859091331251, 0.0389459879079368, 0.03260651050368324, 0.00797321532445494, 0.027564201482164208, 0.035374146173126064, 0.01632331550354138, 0.0610299056279473, 0.014071056866669096, 0.05752321703766938, 0.040592917503090575, 0.03474153207207564, 0.06768069913960062, 0.023823730807635002, 0.019779805224970914, 0.029679441104235593, 0.0704109416983556, 0.07002738493611105, 0.058238892306690104, 0.011876412081619492, 0.004486933939915616, 0.04391852948174346, 0.0287321712312405, 0.05010169574234169, 0.07303357284399681, 0.03124525581370108, 0.0040590398839412956, 0.03502110281260684, 0.004401561909617158, 0.035430712669040076, 0.03233806084608659, 0.07372708016191609, 0.020002289966214448, 0.03195760626113042, 0.05279588476696517, 0.04620880092261359, 0.035039790091104805, 0.06865817442303523, 0.011134810811199713, 0.039422572881449014, 0.05611880274955183, 0.046782169374637306, 0.03865281731123105, 0.023748660714772996, 0.02341841613088036, 0.046728864617762156, 0.04840971036173869, 0.06007522169966251, 0.06332242206553929, 0.004126235326111782, 0.019829642296826933, 0.026529232018219773, 0.04093764138815459, 0.0394317606696859, 0.028388206192175858, 0.016620601309114136, 0.019347366906004027, 0.05669499878422357, 0.049163628500537015, 0.06202383432537317, 0.027636013546725735, 0.019367942950339057, 0.03686454198032152, 0.016498718396178447, 0.18699691660003737, 0.08320622815517709, 0.18001914024353027, 0.07174948666943237, 0.09425366777577437, 0.0941062401398085, 0.09738613953231834, 0.10429506684886292, 0.13363148173084483, 0.17474537948146462, 0.09327354302513413, 0.22053366468753666, 0.1162626211589668, 0.17765176336979493, 0.13184231211198494, 0.1877978423726745, 0.17503161099739373, 0.14934878912754357, 0.1990843945532106, 0.11451561294961721, 0.10126803201274015, 0.15998787683201954, 0.11397108435630798, 0.10869939418626018, 0.16862494696397334, 0.08535343949915841, 0.06371830590069294, 0.14447897934587672, 0.10061649314593524, 0.16267931991023943, 0.1591719003045, 0.2361055408255197, 0.15284829743904993, 0.052930462115909904, 0.11054611735744402, 0.11734045707271434, 0.11067755913245492, 0.08964164298959076, 0.12977051781490445, 0.24726012430619448, 0.28022777871228755, 0.13837377569871023, 0.10619477936415933, 0.15060934179928154, 0.18164276640163735, 0.13433641812298447, 0.22982191003393382, 0.12318707420490682, 0.2705730905290693, 0.13294538104673848, 0.12209236927446909, 0.1016439966042526, 0.12705679546343163, 0.18248682579724118, 0.17523239162983373, 0.08865955896908417, 0.19516922417096794, 0.09946600839612074, 0.1410455073346384, 0.20545386214507744, 0.12718863057671115, 0.2353594300802797, 0.12409104718244635, 0.16251266322797164, 0.17781226022634655, 0.14157842873828486, 0.1048125812667422, 0.09569785004714504, 0.1417246021446772, 0.21128496096935123, 0.1484276502742432, 0.13874107942683622, 0.19413269619690254, 0.19898503582226112, 0.20351994404336438, 0.12745044543407857, 0.09092098684050143, 0.11992002138867974, 0.336534790112637, 0.14021982351550832, 0.14816734939813614, 0.17696744384011254, 0.096722125163069, 0.19070058973738924, 0.10320433240849525, 0.13527860428439453, 0.03734492674993817, 0.18669616867555305, 0.09592515503754839, 0.13520324660930783, 0.1537472163909115, 0.14066353876842186, 0.12918417662149295, 0.15245175309246406, 0.11245875066379085, 0.13062949437880889, 0.07516663143178448, 0.19466487545287237, 0.13247445865999907, 0.10930898686638102, 0.15389911917736754, 0.1242139987880364, 0.10751762791187502, 0.18629281141329557, 0.1454008900327608, 0.13304058375069872, 0.10350422686315142, 0.142837704916019, 0.1482323615346104, 0.10341130997403525, 0.05274407914839685, 0.10396029887488112, 0.12931096513057128, 0.08859554131049663, 0.11321870246320032, 0.10265169214108028, 0.17266695038415492, 0.10627628202200867, 0.2859197248471901, 0.11897064381628297, 0.1496062401565723, 0.14932603487977758, 0.1084072922822088, 0.09349928950541653, 0.15839634113945067, 0.11888098495546728, 0.14805029786657542, 0.1462395317503251, 0.11613132039201446, 0.15163160569500178, 0.199408846674487, 0.10997922785463743, 0.08785570913460106, 0.09582359954947606, 0.13450541999191046, 0.14213866117643192, 0.1466145389713347, 0.11270278366282582, 0.08654485369333997, 0.13452533923555166, 0.10864813404623419, 0.06442301222705282, 0.1044630519754719, 0.2665301371598616, 0.1275838539004326, 0.09019865450682119, 0.15255045873345807, 0.08246154975495301, 0.10545638695475645, 0.1431698160013184, 0.1689064287347719, 0.10886858159210533, 0.10619448992656544, 0.1138586712477263, 0.10787425213493407, 0.06917170350789092, 0.07338572933804244, 0.11662369084660895, 0.12741396145429462, 0.14864409022266045, 0.1320951321395114, 0.17551151337102056, 0.09299071796704084, 0.1274196759914048, 0.07505968795157969, 0.19226321135647595, 0.1949105114908889, 0.2315281075425446, 0.08997629964142106, 0.14515160262817517, 0.08564197167288512, 0.20754477416630834, 0.1862198137678206, 0.15251962991897017, 0.1254537416389212, 0.17119046242441982], [0.047931923108990304, 0.024750502561801113, 0.050317538261879236, 0.014190903511916986, 0.022993174789007753, 0.04074744749232195, 0.043769714029622264, 0.03908448379661422, 0.07148448799853213, 0.016520131212018896, 0.006106792307036812, 0.037332978172344156, 0.03187178801454138, 0.013742676928814035, 0.018492238377803005, 0.016531844157725573, 0.037736624872195534, 0.05189444993447978, 0.06301545494352467, 0.04433201334904879, 0.03170361364027485, 0.055502170798718, 0.0224730424451991, 0.03535662035574205, 0.03827172076853458, 0.035037953275605105, 0.03613691071223002, 0.06243406387511641, 0.04675226453400683, 0.005135745414008852, 0.01749865106830839, 0.00893317870577448, 0.020728308918478433, 0.07653249485883862, 0.03145450435113162, 0.015058978806337109, 0.034945103179779835, 0.06503731754492037, 0.04339276238169987, 0.030720687282155268, 0.007659461261937395, 0.05110685313411523, 0.04539819012279622, 0.030575940654671285, 0.015666692925151438, 0.07761095417663455, 0.011120510553155327, 0.06325283829937689, 0.06830494181485847, 0.11318656746880151, 0.005102474469822482, 0.06361664651194587, 0.04390945301565807, 0.021822251292178407, 0.0696857224102132, 0.0326872561709024, 0.026399029629828874, 0.14430917595745996, 0.02852179834007984, 0.014252409000619082, 0.027765137965616304, 0.041541905447957106, 0.16187232336960733, 0.024709051758691203, 0.045357524140854366, 0.010904031641985057, 0.01812405520468019, 0.054796752010588534, 0.03431599943723995, 0.103073410136858, 0.05402696304372512, 0.012839240152970888, 0.014597839781345101, 0.004469390960366582, 0.10879824083531275, 0.09283943858463317, 0.005486557693075156, 0.04198870803520549, 0.06274403669522144, 0.019247616692155134, 0.040948391397250816, 0.062077725378912874, 0.06634826204390265, 0.1027720610727556, 0.017643386563577224, 0.02260359178762883, 0.0762627761287149, 0.041401899288757704, 0.05428960168501362, 0.009299683697463479, 0.018380441251792945, 0.07062338889227249, 0.04212570107483771, 0.013196460877225036, 0.016994604775391053, 0.07574480900075287, 0.024186238406400662, 0.029326531330298167, 0.053008395043434575, 0.040391209186054766, 0.05036549955548253, 0.03408738455618732, 0.04003635127446614, 0.050155019052908756, 0.08032558936974965, 0.02561011180659989, 0.0226865267904941, 0.08385490975342691, 0.03444333342486061, 0.03144054455333389, 0.020575393100443762, 0.012838616748922504, 0.035182549618184566, 0.023876820341683924, 0.05211761003010906, 0.01215488722664304, 0.06367636713548563, 0.05103906165459193, 0.015910078400338534, 0.034787931144819595, 0.06154609902296215, 0.034739665570668876, 0.05497796220879536, 0.020212594208715018, 0.02143166453606682, 0.07687314064241946, 0.06629850846366026, 0.01256594798178412, 0.025376899320690427, 0.04983555416401941, 0.03155332131427713, 0.03858419833704829, 0.05523787716811057, 0.05413966558990069, 0.027133603689435404, 0.011434439948061481, 0.037311678534024395, 0.01166092486528214, 0.042628313167369924, 0.04146028033574112, 0.03211340161215048, 0.02335585122636985, 0.006648676999247982, 0.07368266262346879, 0.040732782654231414, 0.015213740716717439, 0.026035397677333094, 0.02930818729510065, 0.01867823171778582, 0.09277585879317485, 0.04715139897598419, 0.0197214019135572, 0.046380173953366466, 0.04777338923304342, 0.038125380378915, 0.04434121226950083, 0.05934935303230304, 0.05810772141558118, 0.03841843223199248, 0.03173762626829557, 0.07238247926579788, 0.03927969832147937, 0.009695702046883525, 0.08888494179700501, 0.055487858480773866, 0.03566520907043014, 0.1672727835830301, 0.01699524302239297, 0.03629719234595541, 0.0719247003144119, 0.025046179762284737, 0.029414409036689904, 0.013620701247418765, 0.05539078556466848, 0.06812954263295978, 0.053978771684342064, 0.0026296145233573043, 0.11410097504267469, 0.0384842050698353, 0.022044082943466492, 0.048212184046860784, 0.02782920200843364, 0.06225554025149904, 0.08381124178413302, 0.021985540479363408, 0.03547849213646259, 0.007825720895198174, 0.04155587637796998, 0.011438918809290044, 0.020212536692270078, 0.006138963944977149, 0.05029054264014121, 0.023703649458184373, 0.02160454783734167, 0.05347300917492248, 0.08244823562563397, 0.08096694597043097, 0.08205260412069038, 0.03591096385207493, 0.009940930831362493, 0.04497296547924634, 0.01828850399760995, 0.030915771931177005, 0.030685876845382154, 0.02699212807783624, 0.02189379247283796, 0.04626611327694263, 0.06968638292164542, 0.016143071952683385, 0.05467852417496033, 0.061580412220791914, 0.04170618725765962, 0.03344183482113294, 0.050546984348329715, 0.09914000518620014, 0.015615620177413803, 0.11516972706886008, 0.058814861986320466, 0.04130575405724812, 0.07137218621210195, 0.023499946619267575, 0.07002262776950374, 0.02323474756849464, 0.058840944766416214, 0.022244817191676702, 0.07298254276975058, 0.053348881265264936, 0.020049488703079987, 0.03171520227624569, 0.04709725559223443, 0.1182953265379183, 0.022214164637262, 0.04052744152431842, 0.08425550622632727, 0.06490179395768791, 0.04836212014197372, 0.0494479378539836, 0.017159524832095485, 0.041865370512823574, 0.06336931095574982, 0.026178606203757226, 0.09698024412500672, 0.012886073382105678, 0.02586402464658022, 0.04291947996534873, 0.06714002971420996, 0.1126959707471542, 0.012554695167636964, 0.03976132247771602, 0.07160501278121956, 0.08324580689077266, 0.045654687492060475, 0.020415013132151216, 0.0320197574183112, 0.0478533779096324, 0.021668608169420622, 0.034411090819048695, 0.019223975577915553, 0.01399976245011203, 0.012616026251635049, 0.010267651141475653, 0.018966624738823157, 0.02700272965739714, 0.014737473939021584, 0.02260167519125389, 0.048128284252015874, 0.1197331708681304, 0.06677433644654229, 0.014768432629352901, 0.019516366919560824, 0.024428527358395513, 0.09831835865043104, 0.02912152045610128, 0.09922932265908457, 0.009826652149058646, 0.03941887698601931, 0.038302783359540626, 0.028454739731387235, 0.042608931980794296, 0.021403737518994603, 0.021590395081148017, 0.026141055386688095, 0.0577742113819113, 0.0618771154404385, 0.0369190787023399, 0.01698397536529228, 0.018064516407321207, 0.019126308943668846, 0.04622002219548449, 0.04365776105260011, 0.052943086047889665, 0.029519094532588497, 0.03549941327946726, 0.048738934492575936, 0.042150418303208426, 0.07269173962413333, 0.017160200186481234, 0.016946255709626712, 0.05460557105834596, 0.04298307831049897, 0.008583910093875602, 0.11731880862498656, 0.03064843920583371, 0.015669316417188384, 0.014013391064509051, 0.03333841283165384, 0.017467892757849768, 0.026006030893768184, 0.01350230550087872, 0.07662305913981982, 0.02128973250364652, 0.0539545071660541, 0.02414749273157213, 0.039671140402788296, 0.02713991008931771, 0.03558418138709385, 0.009481877241341863, 0.058570038600009866, 0.012981200015929062, 0.05307007493684068, 0.09404902797541581, 0.04274131257261615, 0.013754069823335158, 0.05679518872057088, 0.06284446411882527, 0.018602597592689563, 0.03393036837223917, 0.04854108905419707, 0.03570028296962846, 0.016232326343015302, 0.050021439892589115, 0.06928353774128482, 0.0908849852567073, 0.027781366879935376, 0.012383658886392368, 0.03218398727767635, 0.04143283571465872, 0.026515329736866988, 0.07990142970811576, 0.015878099256951828, 0.04133765527512878, 0.049232113888137974, 0.024443733964290004, 0.07527650639531203, 0.06466561288107187, 0.02238973080238793, 0.034315910379518755, 0.03607898979680613, 0.08156400377629325, 0.07238393387524411, 0.07330951819312759, 0.04079677433765028, 0.16214684379519895, 0.21027041540946811, 0.11620985445915721, 0.07840716731152497, 0.1504112032125704, 0.13003350526560098, 0.20136502920649946, 0.21522310824366286, 0.15460876078577712, 0.12298619709326886, 0.0624330471327994, 0.09893554350128397, 0.1976137250312604, 0.1463940617395565, 0.09973035397706553, 0.1168249909824226, 0.133151356712915, 0.16375363804399967, 0.13601094076875597, 0.17668875254457816, 0.15699881769251078, 0.13688116829143837, 0.17587866866961122, 0.1235141238430515, 0.20197736041154712, 0.12395698562613688, 0.14334379025967792, 0.09632413362851366, 0.10820697920280509, 0.1039794685493689, 0.0794599112123251, 0.07532675721449777, 0.08785967220319435, 0.11018710341886617, 0.1428783152368851, 0.2251186827197671, 0.09621305638574995, 0.15151666186284274, 0.2786520804511383, 0.12395986515912227, 0.28391010768245906, 0.18509967543650419, 0.11020270336302929, 0.13941552839241922, 0.1287944897194393, 0.1783263310790062, 0.10806760386913083, 0.10005829419242218, 0.15055792580824345, 0.18224322324385867, 0.15058468765346333, 0.15357922384282574, 0.13192737707868218, 0.08115489486954175, 0.2997272339416668, 0.11975628134678118, 0.2100353327114135, 0.2210524259135127, 0.14742220344487578, 0.11267188805504702, 0.0836420469568111, 0.1406609857804142, 0.17039997124811634, 0.2028846656321548, 0.1169008384749759, 0.22044414683477953, 0.11015873853466474, 0.0960735919943545, 0.15587654197588563, 0.2533560065785423, 0.1876598474336788, 0.08241225630627014, 0.16698643332347274, 0.2694609673926607, 0.16834143170854077, 0.14502987556625158, 0.07865946041420102, 0.1237331167794764, 0.19599401741288602, 0.12811045220587403, 0.14572951302397996, 0.12052553225657903, 0.1765562643413432, 0.25842312374152243, 0.1827921305084601, 0.07743568858131766, 0.16384502610890195, 0.1352118406794034, 0.2137713783304207, 0.1881447815685533, 0.295641859411262, 0.14355341729242355, 0.11583152241655625, 0.0895052139821928, 0.0776373672124464, 0.18232376110972837, 0.06172172084916383, 0.11743226074031554, 0.10736159136286005, 0.10220389507594518, 0.14380602951860055, 0.11388939616153948, 0.1542223393335007, 0.11131421793834306, 0.1478561817202717, 0.14975556026911363, 0.18157668557250872, 0.21298220817698166, 0.12330454133916646, 0.181821534933988, 0.15007374866399914, 0.10446361600770615, 0.13411959225777537, 0.10743462611571886, 0.16415640158811584, 0.08946860383730382, 0.18060732196317986, 0.13180251815356314, 0.13964850339107215, 0.2317716952529736, 0.08288533092127182, 0.13869092508684844, 0.24369024555198848, 0.1522533770184964, 0.07490448260796256, 0.15959854616085067, 0.16866637364728376, 0.1620472624199465, 0.0882979400921613, 0.21651241171639413, 0.11791947326855734, 0.18451420997735113, 0.14783430320676416, 0.1733203075127676, 0.1436122102313675, 0.17413220222806558, 0.08932984448620118, 0.12318055814830586, 0.12476118427002802, 0.10403293286799453, 0.1040400649071671, 0.11213930061785504, 0.21638920035911724, 0.1057100752950646, 0.15884560765698552, 0.11363509926013649, 0.13279635779326782, 0.09188418320263736, 0.1751610415522009, 0.18090901983669028, 0.19155548448907211, 0.1103471549868118, 0.22403247538022697, 0.1193863207299728, 0.12596239481354132, 0.1359799932106398, 0.2141659040353261, 0.12718493468128145, 0.08099499915260822, 0.08661544678034261, 0.12363519039354287, 0.1557845453498885, 0.11256172365392558, 0.10176590920309536, 0.14659122069133446, 0.1247435063123703, 0.23367646179394796, 0.15328548179240897, 0.13244935922557488, 0.16909080790355802, 0.1378256847965531, 0.09487344272201881, 0.15943580801831558, 0.16007270431146026, 0.1841362935374491, 0.12200444703921676], [0.012675079869950423, 0.05185145360883325, 0.012734348711092025, 0.0581366874394007, 0.02282523604662856, 0.040694257768336684, 0.05059463393990882, 0.07996017811819911, 0.024300699842569884, 0.06115753647463862, 0.02149986790755065, 0.07757923478493467, 0.056484789165551774, 0.061572849735966884, 0.009444751303817611, 0.03810785827226937, 0.03940760376281105, 0.027177325464435853, 0.041487980997771956, 0.06923368026036769, 0.03450775555393193, 0.07006846281001344, 0.1001964375609532, 0.05173953773919493, 0.04398277720611077, 0.037062172195874155, 0.028580867729033343, 0.02311782220203895, 0.0046289893543871585, 0.06180265947477892, 0.06061128980945796, 0.03876152710290626, 0.05426882897154428, 0.038845549352117814, 0.05737899919040501, 0.014522468190989457, 0.048823591278051026, 0.0626961533271242, 0.01088146293113823, 0.05589048843830824, 0.013663164154422702, 0.030916931536921766, 0.022350684557750355, 0.05426057628937997, 0.016620762726233806, 0.05217166806687601, 0.015264301382558187, 0.014101410706643946, 0.018943289760500193, 0.10662048269296065, 0.008029087912291288, 0.03804081636189949, 0.03235102616599761, 0.08128846660838462, 0.03164283174555749, 0.06145170525996946, 0.0789118128886912, 0.038884144742041826, 0.056004229991231114, 0.015681645345466677, 0.03208646536222659, 0.06285816416493617, 0.01977585328859277, 0.05314721005561296, 0.027481721044750884, 0.02478072467056336, 0.023570025769004133, 0.05619023817416746, 0.01413109754139441, 0.01652020542678656, 0.0941360522119794, 0.048576426415820606, 0.05008655964047648, 0.01838494608819019, 0.057480528703308664, 0.027098531645606272, 0.0649841723497957, 0.018106885618180968, 0.013035452866461128, 0.034949737892020494, 0.023838022716518026, 0.018642642025952227, 0.00976290444668848, 0.06265462274313904, 0.0501323687058175, 0.01826340456318576, 0.046206830520532094, 0.04452413311810233, 0.04191914282273501, 0.02698771972063696, 0.029079780215397477, 0.01634945580008207, 0.01829275093768956, 0.10890664634644054, 0.03674041035992559, 0.007745633420199738, 0.009904399539664155, 0.021766948302683886, 0.03995842947915662, 0.07171407880377956, 0.03955874213716015, 0.029823586592101492, 0.10783860678202473, 0.05637461734295357, 0.02015185498748906, 0.02799535774101969, 0.026836464458028786, 0.020198235506541096, 0.022833112088846974, 0.004693394785135752, 0.021647072899213526, 0.020927326950186398, 0.011050673529098276, 0.08582684065913782, 0.02455134723277297, 0.03913410007953644, 0.041757992876227945, 0.011824535031337291, 0.09048374311532825, 0.030425768927671015, 0.08483416619128548, 0.04153930422035046, 0.052994591096648946, 0.07225985420518555, 0.09519649960566312, 0.026207477603747975, 0.025443822487432044, 0.01105252518755151, 0.0439624089631252, 0.025809717990341596, 0.03533865667122882, 0.042091488066944294, 0.09726358868647367, 0.07107172772521153, 0.021021826469223015, 0.03501237144519109, 0.060653128384728916, 0.040226196360890754, 0.024691243925190065, 0.03537616481480654, 0.030199016837286763, 0.03543673890817445, 0.08349668991286308, 0.017201626869791653, 0.0566282648651395, 0.05908226150495466, 0.02203153693699278, 0.04761476258863695, 0.03729024530912284, 0.032640211429679766, 0.007140131365304114, 0.042727293403004296, 0.12734647054458037, 0.0626241130521521, 0.06896920851431787, 0.026173993755946867, 0.04360500919574406, 0.053398052259581164, 0.06086298919399269, 0.07023799902526662, 0.025950889321393333, 0.026911759050562978, 0.04282990645151585, 0.01796641376131447, 0.0308260499878088, 0.06491027670563199, 0.02079676833091071, 0.029526688558689784, 0.01749739869410405, 0.019001177279278636, 0.07047679246170446, 0.07282856196979992, 0.013366075017984258, 0.09786023088963702, 0.022763504202885088, 0.026460919179953635, 0.08425345789873973, 0.05487377580720931, 0.044362241023918614, 0.04179609473794699, 0.0057424636634095805, 0.03507470813929103, 0.06841477224952541, 0.03562790130672511, 0.027003354916814715, 0.044499193245428614, 0.05289809705573134, 0.037683000991819426, 0.0412204404710792, 0.007852550461393548, 0.005202096199354855, 0.027355962265573908, 0.06122071179561317, 0.035121315013384447, 0.05885278573259711, 0.028176588348287623, 0.020180872961645946, 0.09017931413836777, 0.091032450000057, 0.0654640153516084, 0.025527174948365428, 0.009122458832280245, 0.022555433824891225, 0.009828709753492149, 0.03850397217320278, 0.035502318787621334, 0.0510513516201172, 0.045901084231445566, 0.03941397510061506, 0.029664969224540982, 0.049752941995393485, 0.028564698186528403, 0.0904731304035522, 0.0872601727314759, 0.07487077426048927, 0.026218186794721987, 0.031215265626087785, 0.0601064958027564, 0.048969712734106, 0.01712947527266806, 0.02274649974424392, 0.006583476542800781, 0.07911692024208605, 0.04232255203532986, 0.02006182876357343, 0.043264426494715735, 0.03532738715875894, 0.007441527277478599, 0.03328768703795504, 0.05345672274415847, 0.007565227988379775, 0.036585928610293195, 0.03561075769539457, 0.029549411265179515, 0.0268315922585316, 0.012358872081676964, 0.03358062014740426, 0.038327062720782124, 0.03573811765818391, 0.02864823803975014, 0.032080928940558806, 0.027762716708821245, 0.040087411034619436, 0.024433145372313447, 0.026660903859010432, 0.008987346209323732, 0.03625006596848834, 0.023958805395523086, 0.043556116506806575, 0.016988534007396083, 0.027400492981541902, 0.058822469000006095, 0.043049793675891124, 0.03169071511365473, 0.05878027790458873, 0.01949276847881265, 0.023055628371366765, 0.027822698939417023, 0.029657182240043767, 0.04617476603016257, 0.01580020343681099, 0.03205604101822246, 0.042160029115621, 0.029497496179828886, 0.03968586832343135, 0.04369430069345981, 0.02776639405055903, 0.016879421600606292, 0.028471321165852714, 0.06755909824278206, 0.021851606943528168, 0.02115251681971131, 0.06695064847008325, 0.08012110542040318, 0.06941227809875272, 0.019342771156516392, 0.029680109037144575, 0.0276998939079931, 0.05571021705691237, 0.024774271696514916, 0.030134962071315385, 0.039220946200657636, 0.010885113370022736, 0.04177051661827136, 0.019924826447095256, 0.1114418228098657, 0.036987478742958046, 0.0837287149624899, 0.04916014411719516, 0.047650471024098806, 0.05034590314608067, 0.026332379202358425, 0.054163084059837274, 0.030128750295261852, 0.039128689822973683, 0.05863004123966675, 0.032556471196585335, 0.01582569249876542, 0.05240262813458685, 0.06384378822986037, 0.05124005750985816, 0.011836876947199926, 0.045926684615551494, 0.022023508754500654, 0.03784230299061164, 0.07101895360392518, 0.026487716277188156, 0.10268678088323213, 0.07628617604495957, 0.033451360286562704, 0.013041087622696068, 0.03431822216953151, 0.0652657357568387, 0.04879915235505905, 0.059221195260761306, 0.029848493068129756, 0.05685896147042513, 0.01586338061315473, 0.09087503305636346, 0.03618113900301978, 0.01848820294981124, 0.11527002832735889, 0.016219951030507218, 0.027739413271774538, 0.01562514193210518, 0.06999156146775931, 0.06437224190449342, 0.02830234898283379, 0.06785911144106649, 0.010675395424186718, 0.052017794878338464, 0.0193690617379616, 0.04690074230893515, 0.05664324511599261, 0.04587074894516263, 0.06137322314316407, 0.05780762658105232, 0.030269105263869278, 0.015261893113347469, 0.0236719727399759, 0.03233211253245827, 0.013996977540955413, 0.03381337992323097, 0.045265327134984545, 0.06470826410804875, 0.03285678496467881, 0.038067952991696075, 0.025312664583907463, 0.0786129871266894, 0.06250078295124695, 0.02304794528754428, 0.021126493411429692, 0.12096128426492214, 0.09400026887306012, 0.19131790817482397, 0.11270281334873289, 0.06683396059088409, 0.1283445255830884, 0.18674219667445868, 0.1653614712995477, 0.1043276916607283, 0.21766109304735437, 0.08953560492955148, 0.174059605342336, 0.1472903831745498, 0.10441680133226328, 0.16867036640178412, 0.13204156392021105, 0.13720695627853274, 0.10903782094828784, 0.21300310705555603, 0.18758916528895497, 0.11411232248065062, 0.18859499803511426, 0.23045706970151514, 0.23926383932121098, 0.13730089733144268, 0.1460127017344348, 0.0816451947321184, 0.09814482225920074, 0.15030480892164633, 0.11338865428115241, 0.11070023174397647, 0.12912134639918804, 0.15028236637590453, 0.16151638934388757, 0.14558736205799505, 0.12197344010928646, 0.13228034251369536, 0.2474458541837521, 0.176680336589925, 0.21759254828793928, 0.08211029125959612, 0.0896177532558795, 0.14036754058906808, 0.10860048816539347, 0.11799345797044225, 0.12195107919978909, 0.18389021221082658, 0.10755343653727323, 0.13246308895759284, 0.15764608921017498, 0.13539038656745106, 0.11565549240913242, 0.0734057673253119, 0.21087701723445207, 0.1910786546068266, 0.23219123133458197, 0.20197972044115886, 0.12991789350053295, 0.13761013542534783, 0.16659325832733884, 0.12309308120165952, 0.18481975217582658, 0.08407413275563158, 0.09438821172807366, 0.12843215838074684, 0.19779276073677465, 0.1067063862865325, 0.13940090808318928, 0.11265570923569612, 0.07361437019426376, 0.09535782766761258, 0.17744048876920715, 0.14086935116210952, 0.10037523577921093, 0.19154050794895738, 0.08106504305033013, 0.13510740565834567, 0.1369585149222985, 0.16247327002929524, 0.20594546076608822, 0.09235805191565305, 0.12227511571836658, 0.07851976595702581, 0.15323661878937855, 0.16197937075048685, 0.151789223018568, 0.08709047324373387, 0.12112933618482202, 0.11378908006008714, 0.17477043438702822, 0.11119948190753348, 0.05400384143285919, 0.1729075249750167, 0.177572917600628, 0.17196713481098413, 0.14515047456370667, 0.1219646679237485, 0.15899132093181834, 0.21462342323502526, 0.14396305312402546, 0.14628088421886787, 0.10533189910347573, 0.143548667547293, 0.16448405978735536, 0.1198572208522819, 0.1271066232584417, 0.09036502175149508, 0.08268167817732319, 0.07713479964877479, 0.2370637425337918, 0.11721455171937123, 0.1636459821020253, 0.10707381617976353, 0.1783597277244553, 0.09655321977334097, 0.08984585234429687, 0.15370372653706, 0.11468765020254068, 0.18216406577266753, 0.18132523109670728, 0.15492222912143916, 0.0972671881027054, 0.19752961001358926, 0.19544640148524195, 0.290204351185821, 0.09892268208204769, 0.1373110053827986, 0.202056176494807, 0.11692926273099147, 0.14792543894145638, 0.09596530522685498, 0.22462592634838074, 0.16977006598608568, 0.17042968684108928, 0.08349937648745254, 0.16919834510190412, 0.11261391890002415, 0.1381619370658882, 0.1304973624064587, 0.14448028552578762, 0.11161265036207624, 0.10491270440979861, 0.3155535034602508, 0.07588533466332592, 0.15716216439614072, 0.18934516090666875, 0.09344009580672719, 0.152895201172214, 0.11486435556435026, 0.2173435577424243, 0.15601784689351916, 0.21808175719343126, 0.20973529724869877, 0.11205589064047672, 0.1722586652613245, 0.0732310583407525, 0.14421547239180654, 0.1560879501630552, 0.13146761659299955, 0.08367764778085984, 0.1257999090012163, 0.15335576317738742, 0.09169312470476143, 0.09405483157024719, 0.08077899707132019, 0.1363771758042276, 0.13344049744773656, 0.07008902030065656, 0.1510367149603553, 0.10566626631771214, 0.1588603763957508, 0.20030194718856364, 0.16989602328976616, 0.23251860751770437, 0.13262144842883572, 0.16410989861469716], [0.026300797107978724, 0.026065740385092795, 0.025221514006261714, 0.044639830230153166, 0.09666770347394049, 0.025547378063492943, 0.015630899142706767, 0.08995309268357232, 0.03481567262497265, 0.0448529082495952, 0.010145679170818767, 0.06269866178627126, 0.04479595212615095, 0.05200739738938864, 0.0692282106319908, 0.04001386419986375, 0.030028421206225175, 0.04323005392507184, 0.07909084117272869, 0.006106747778176214, 0.051137329428456724, 0.0721400864131283, 0.02101471669448074, 0.04671093061915599, 0.042229727914673276, 0.028544270571728703, 0.018142781445931178, 0.014476283413387137, 0.06580809727893211, 0.025700922851683572, 0.02349464954022551, 0.028537574544316158, 0.0729100349417422, 0.007980548671184806, 0.030918638476578053, 0.03065763070480898, 0.0370969752111705, 0.017755037115421146, 0.037078020759508945, 0.03977669606683776, 0.0629426799423527, 0.028702509443974122, 0.02515831456548767, 0.08985189342638478, 0.03579652839107439, 0.035782327395281754, 0.016480674930789974, 0.016324827629432548, 0.0748707223101519, 0.12681923399213701, 0.03466630798357073, 0.09473569269175641, 0.030388388804567512, 0.02916143501352053, 0.03563957157894038, 0.03273536218330264, 0.00802776410637307, 0.015549406689387979, 0.028037179617967922, 0.03519353711453732, 0.03678187415061984, 0.05586579347436782, 0.0656560534844175, 0.04849566590564791, 0.031055015533638652, 0.026074688830703963, 0.040689463494345546, 0.03807661014434416, 0.0519636960234493, 0.06364948654663749, 0.011327749725751346, 0.09716468266560696, 0.015462354622286512, 0.03620208612119313, 0.04197771311737597, 0.036699414122267626, 0.02266460931423353, 0.03050930507015437, 0.05288537293381523, 0.08513364504324272, 0.03681120382680092, 0.0224351520955679, 0.055598301187274046, 0.12925886636367068, 0.016458915160910692, 0.06602448527701199, 0.07498079765355214, 0.024050954161793925, 0.04116983342100866, 0.028066379418305587, 0.012111913165426813, 0.08547944875317626, 0.01804336890927516, 0.07315958951949142, 0.03359024580277037, 0.030266034627857152, 0.057113362272502854, 0.03518611934850924, 0.06351551404804923, 0.03436602761212271, 0.025003337432281114, 0.049533180936123244, 0.012177391927252756, 0.05606716040347237, 0.018267623672727495, 0.08142266175127588, 0.01862760054791579, 0.014444971275224816, 0.007135021214708104, 0.004181971080470248, 0.020325131627032533, 0.03721793786098715, 0.04213608743157238, 0.026949645689455792, 0.10648513722117059, 0.0328795392124448, 0.010500115913600894, 0.05408470213296823, 0.06721135010593571, 0.04259786655893549, 0.14508241962175816, 0.0301759249123279, 0.03466509086138103, 0.04654833348467946, 0.08744022517930716, 0.019378807992325164, 0.08757653544307686, 0.01379136831019423, 0.005387360379245365, 0.05584477956290357, 0.03223708052246366, 0.04279398279322777, 0.031539387491648085, 0.05033539804571774, 0.06703036997350864, 0.0609005233127391, 0.07108993260771967, 0.1061873504659161, 0.012369892046990572, 0.03951559367123991, 0.02008804884098936, 0.02258636839542305, 0.04029743511637207, 0.014708359485666733, 0.03276010538684204, 0.04020504144136794, 0.02208456524385838, 0.04920887353364378, 0.04131318666622974, 0.04305155998736154, 0.02365967164223548, 0.03736493134056218, 0.07063589408062398, 0.06825086151366122, 0.03137867170153186, 0.008966371260612505, 0.0391721982305171, 0.0032713813925511204, 0.0627023502602242, 0.01634204360016156, 0.05934745313425083, 0.014712134234287078, 0.04190077837847639, 0.09526211288175546, 0.06997690405114554, 0.046979116814327426, 0.1136382385448087, 0.025078585640585516, 0.026480023916519713, 0.028887194748676848, 0.008512892127328087, 0.04619701190677006, 0.024692058432265185, 0.005799736591143301, 0.06417475640773773, 0.025830349695752375, 0.05512963864021003, 0.027576764186960645, 0.019332377378304955, 0.07875122697441839, 0.04534144180070143, 0.01473441165217082, 0.01803458002541447, 0.03508747679006774, 0.03079131005506497, 0.009224092245858628, 0.06429770801332779, 0.04122694539546501, 0.005718409265682567, 0.04040213731059339, 0.04151987479417585, 0.030004093605384696, 0.040327551469090395, 0.009476710965827806, 0.05202805135922972, 0.020289914864406455, 0.01213859615745605, 0.05611143322312273, 0.028283587489568163, 0.036281581269577146, 0.021123315164004453, 0.013322260474524228, 0.011452044618636137, 0.021991008252371103, 0.06725011990056373, 0.03581532328098547, 0.04459602125280071, 0.07213348129880615, 0.03152853358187713, 0.013771095618722029, 0.04617410922946874, 0.028629528496821877, 0.006752350855094846, 0.0291567279418814, 0.004545429092104314, 0.028160348301753402, 0.0831537286285311, 0.04942977750033606, 0.022524185696966015, 0.0460430088423891, 0.03609499050071463, 0.020619196511688642, 0.030270732422650326, 0.02262399713799823, 0.007110720052878605, 0.1134386082412675, 0.022402694266929757, 0.09103044620133005, 0.026836024735530373, 0.025962019681173842, 0.04242779228661675, 0.03942775307223201, 0.09138643217738718, 0.02084820287564071, 0.04120313729799818, 0.026200468018942047, 0.025758212941582315, 0.0699756720860023, 0.007610007787661743, 0.12576824898133054, 0.025689154244901147, 0.003693222306537791, 0.06474753114162013, 0.03591587686969433, 0.05687900316843297, 0.042972447045031004, 0.04559326735034119, 0.07829774505808018, 0.02501232855138369, 0.044430258858483285, 0.028972424843232147, 0.046815803507342935, 0.035384154034545645, 0.0411454798449995, 0.021263152484607417, 0.05705526324163657, 0.06176760041853413, 0.04808456062164623, 0.05976074775389861, 0.03194053686456755, 0.029494742811948527, 0.07471006960258819, 0.013890514601371251, 0.043739764660131186, 0.04491745283303317, 0.02818879296683008, 0.02991585966810817, 0.046181975994841196, 0.03773411641304847, 0.040623408640385605, 0.022009348576830234, 0.03617509049945511, 0.03084260730247479, 0.018528228829381987, 0.04776030145876575, 0.019134077374474145, 0.005691131627827417, 0.04595127567881718, 0.019279740554338787, 0.037087672390043736, 0.040901476531871594, 0.054821907106088474, 0.03936767621780746, 0.04580470151267946, 0.06782820841181092, 0.016565548794460483, 0.019825892595690675, 0.011847601908812067, 0.0328696018550545, 0.012553506803669734, 0.05572421767283231, 0.021076955054013524, 0.05370256658352446, 0.09074700516066514, 0.02892169348342577, 0.0388509076583432, 0.0421940231899498, 0.017211775739269797, 0.05806448760267813, 0.0932697877578903, 0.030002060120750684, 0.025755231363291387, 0.04726726307126228, 0.07265720749273896, 0.01326129768131068, 0.0161115752052865, 0.04517266257607844, 0.0708944583311677, 0.027251289757259656, 0.020863808385911398, 0.006610501850445871, 0.07417265078402124, 0.061572185513796285, 0.04290865945222322, 0.062223687273217365, 0.030199740431271493, 0.019083949009655043, 0.04755795860546641, 0.029278857618919574, 0.04749556625029072, 0.03906395228113979, 0.05691083017154597, 0.012765689607476816, 0.08262027287855744, 0.040280525281559676, 0.028754964441759512, 0.048050191762740724, 0.004854428307226044, 0.05276187584968284, 0.05903311277506873, 0.04963248400599696, 0.013470806898112642, 0.06203761229699012, 0.019128386957163457, 0.018122956826118752, 0.021954498297418468, 0.015715095796622336, 0.04588648989738431, 0.053480827700695954, 0.060088428217568435, 0.017571581920492463, 0.03258106597058941, 0.04628544622391928, 0.012860047190770274, 0.021317290302249603, 0.029490265806089155, 0.04247509306878783, 0.017024290682456922, 0.07595017610583454, 0.00733499939997273, 0.04895726691756863, 0.026346073682361748, 0.18226017389679328, 0.13617692951811478, 0.11696653338731267, 0.1624225961859338, 0.22815516509581357, 0.08521328491042368, 0.08231127969338559, 0.19172067171894014, 0.11947809471166693, 0.05309918567945715, 0.09548703557811677, 0.22640570037765428, 0.16079297347459942, 0.2023427197127603, 0.13682274642633274, 0.16886822297237813, 0.11659819065243937, 0.11055554263293743, 0.14082773152040318, 0.12428010188159533, 0.09043941463460214, 0.18673731334274635, 0.1299892138922587, 0.14817772462265566, 0.13194547063903883, 0.09693272440927103, 0.06995416464633308, 0.07027107654721476, 0.13778005755739287, 0.10718137564253993, 0.0895289627078455, 0.1371765133808367, 0.1909209630684927, 0.09253063093638048, 0.10838401110959239, 0.158773708390072, 0.15473148232558742, 0.13984857156174257, 0.18085356656229123, 0.21053335833130404, 0.11122521216748282, 0.13466707459883764, 0.09687753088655882, 0.1646781017188914, 0.10541783980443142, 0.11762279231334105, 0.09804553774301894, 0.150958611338865, 0.18911503575509414, 0.2671877987449989, 0.15771657839650288, 0.11884379593539052, 0.14040764624951407, 0.10788990402943455, 0.1518512368784286, 0.22448558622272685, 0.11297488468699157, 0.1507148751989007, 0.09955865811207332, 0.1602197831380181, 0.0656598161731381, 0.13836228725267574, 0.16380315413698554, 0.15318432706408203, 0.11729425837984309, 0.16239599761320278, 0.20100854599149898, 0.20181800646241754, 0.1907293702242896, 0.12296267101191916, 0.22269389330176637, 0.2229351209825836, 0.1978126057656482, 0.13824532477883622, 0.17558563908096403, 0.14148784219287336, 0.0844365383090917, 0.10360439453506842, 0.15563578926958144, 0.10856384091312066, 0.11067375933635049, 0.11574968579225242, 0.18040121271042153, 0.18589024082757533, 0.09325279257609509, 0.20462761429371312, 0.12487865140428767, 0.16339820867870003, 0.1342741074040532, 0.16859978815773502, 0.08440991747193038, 0.1806661149021238, 0.1866696888464503, 0.13464412739267573, 0.11997751556918956, 0.14879618596751243, 0.122323978721397, 0.12415679404512048, 0.1352254071389325, 0.15976897295331582, 0.22670110483886674, 0.13893488387111574, 0.14204043050995097, 0.0796856131637469, 0.10986177556333132, 0.14324837975436822, 0.18105688533978537, 0.1401363912736997, 0.09128420875640586, 0.14689017261844128, 0.13726775301620364, 0.11680401788908057, 0.17828736832598224, 0.12308611985645257, 0.18658316927030683, 0.09076739195734262, 0.08679356222273782, 0.17826311493990943, 0.14449058653553948, 0.22429696196923032, 0.2875892008887604, 0.10849007143406197, 0.1070427498780191, 0.1596003124723211, 0.14670398260932416, 0.10925883994787, 0.30433638661634177, 0.08550981743610464, 0.1006527990102768, 0.19708405423443764, 0.12401396772474982, 0.20396894338773564, 0.13286604546010494, 0.09972363754059188, 0.1848633459303528, 0.2915964717976749, 0.13582516636233777, 0.1924700479139574, 0.10347121613449417, 0.2539103612070903, 0.08154380251653492, 0.10376071310020052, 0.1684161659795791, 0.10556591310887598, 0.11193094265763648, 0.12576204462675378, 0.12777617404935881, 0.19263660069555044, 0.10280245944159105, 0.09524813081952743, 0.17593980679521337, 0.12889326957520097, 0.2111737130326219, 0.16793424496427178, 0.1521932185278274, 0.07719675413682126, 0.25627466558944434, 0.16847446910105646, 0.17363076272886246, 0.08343044581124559, 0.13957620336441323, 0.1256643483066, 0.11571373615879565, 0.11850401846459135, 0.18252215202664956, 0.12493345158873126, 0.262349292752333, 0.05907435392145999, 0.09718512141262181, 0.07345630016061477, 0.19013378187082708, 0.16111206728965044, 0.19164519530022517, 0.11442169416113757, 0.16335750930011272, 0.12780274293618277], [0.04554286439088173, 0.02989635231642751, 0.028715561966237146, 0.03250226844102144, 0.024504415669071022, 0.04011255128716584, 0.011355204551364295, 0.012163169594714418, 0.012847449233959196, 0.02462759177433327, 0.025901957669702824, 0.08374834476853721, 0.02802694169076858, 0.054024376659072004, 0.05307258339598775, 0.013922554971941281, 0.026590203160594683, 0.049538286912138574, 0.11375264803064056, 0.05101264490804169, 0.04083329542481806, 0.07887171464972198, 0.03379217676410917, 0.016876176559890155, 0.012803545632777968, 0.05501272069523111, 0.049455225744168274, 0.027593631348281633, 0.059117602577316575, 0.056303771925740875, 0.06788021812099032, 0.011557232919585658, 0.030384351521206554, 0.02529843204683857, 0.08046284216106869, 0.13601328595541418, 0.06291340963798575, 0.047827528906054795, 0.023654573087696917, 0.03137662337394431, 0.08991300186607987, 0.020743426466651727, 0.03537294018315151, 0.033487142936792225, 0.07634483539732173, 0.032942573525360785, 0.06822053735959344, 0.03079238060308853, 0.02144270398275694, 0.019934637639380526, 0.019823187467409298, 0.028140764879935887, 0.0685059821989853, 0.036738888957188465, 0.027110409719171003, 0.03081232396652922, 0.0454839564190479, 0.03391244921658654, 0.07353715714998543, 0.06256897890125401, 0.03534610783390235, 0.029046749077679124, 0.009567073939251713, 0.04639175516786054, 0.029223061101220082, 0.016598591064393986, 0.01999974625505274, 0.06802401665481739, 0.016289696213789284, 0.013883389055990847, 0.024742249879636802, 0.042736162067740224, 0.03289775151642971, 0.04881559463683516, 0.07929293540655635, 0.014675307011202676, 0.03846459381747991, 0.01742362364893779, 0.06400283789844252, 0.0548264379176544, 0.062171106110326946, 0.015294923323381227, 0.052770388283533975, 0.018826043415174354, 0.025444306738791056, 0.036632372211897746, 0.00898328758921707, 0.057473070119158365, 0.03052691066841362, 0.04954686985001899, 0.03971161713707261, 0.0324779111542739, 0.013140608698449796, 0.05180604159249924, 0.06267544740694575, 0.013215484905231278, 0.058756139551405795, 0.05219248530920595, 0.044084941255277954, 0.04471126194403041, 0.029894576728111133, 0.08244157856097445, 0.060924747012904845, 0.015800383407622576, 0.019959909623139538, 0.06312253943178803, 0.018291656269866508, 0.04594654448737856, 0.02318619255675003, 0.07278095319634303, 0.03393599014088977, 0.038720452939742245, 0.04599443527695257, 0.0989876125822775, 0.02575930760940537, 0.05043861594458576, 0.024673912921571173, 0.04929987197101582, 0.021942983876215294, 0.045727273245574906, 0.022448850286309607, 0.03867357889248524, 0.0590745505905943, 0.056000708500505425, 0.015054731866257498, 0.08734306320548058, 0.12097973405616358, 0.10267728139297105, 0.04886622766207438, 0.047914115275489166, 0.008405605403822847, 0.05904845296754502, 0.05196612655709032, 0.01635612585232593, 0.0149366134974116, 0.02660780319274636, 0.03975325162173249, 0.0404184905346483, 0.04317965838708915, 0.03369276979356073, 0.019799327419605106, 0.031812097076908685, 0.006352464988594875, 0.049644555037957616, 0.037198159625404514, 0.05791154209873639, 0.055267132629523985, 0.08120725338812917, 0.06309176256763749, 0.044184596845298074, 0.02769034617813304, 0.016897617206268478, 0.013091391319903778, 0.04947452158376109, 0.03803179926762823, 0.020194608259771485, 0.022875087961438112, 0.04715336937806569, 0.0318716507172212, 0.02371856662648497, 0.025480395524937194, 0.0035737087000597967, 0.01809873869206058, 0.1057556876912713, 0.03842156038444955, 0.03357178487931378, 0.03600796997488942, 0.07631141648744233, 0.0251308643782977, 0.030938262716517784, 0.040294351492775604, 0.03769781797018368, 0.05386815457313787, 0.08591219506342895, 0.06380100341630168, 0.037960668123560026, 0.017812278965720907, 0.0580965854896931, 0.009651079490140546, 0.038446355538326316, 0.013805345733999275, 0.019598164581111632, 0.010446388132550055, 0.011416644174460089, 0.02191381747252308, 0.054501985796377994, 0.029178320728533436, 0.09974604297894984, 0.0253806675755186, 0.07819923979695886, 0.03554107745003421, 0.045746572795906104, 0.03564413949789014, 0.04496159206610173, 0.012466492771636695, 0.053873653887421824, 0.031082797831913922, 0.015039008540043142, 0.0046175537863746285, 0.049584533844608814, 0.012708830890915124, 0.04555365892883856, 0.02237860044260742, 0.04215448527247645, 0.014016355944477255, 0.034405513579258695, 0.0460261435364373, 0.017845202492026147, 0.02014610705373343, 0.0018637751736605424, 0.06281892681727186, 0.04936291370540857, 0.07039554213406518, 0.054960180350462906, 0.044739853183273226, 0.02466237809130689, 0.0984422602050472, 0.04990139008441474, 0.0413041435967898, 0.015748813420941588, 0.0621231559489388, 0.02186831639846787, 0.02096686486765975, 0.02573598932940513, 0.07899941600044258, 0.08041483262786642, 0.027708141024049837, 0.018503717546991538, 0.016901136841624975, 0.030366918472282123, 0.020186691399430856, 0.04839704561163671, 0.05195627825742122, 0.02109699860739056, 0.05741703054809477, 0.055745201898389496, 0.03496997996990103, 0.07108139790943824, 0.09063268473255448, 0.043606541730696335, 0.03341282426845282, 0.006616002092414419, 0.08259533671662211, 0.024042632830969524, 0.011707920439221198, 0.013627657954202732, 0.027475639144540764, 0.02810799349390436, 0.026192695877398364, 0.03332128035253845, 0.04837666252569761, 0.02152519184164703, 0.06750443164492026, 0.014570553794328589, 0.05227532012213487, 0.03906845340679865, 0.05289868335239589, 0.04975592913979199, 0.056993498001247644, 0.03466112779278774, 0.01988378196983831, 0.047215390659403056, 0.024912786138884258, 0.006830562551840558, 0.06421636862796731, 0.006268446913963999, 0.01219028303239611, 0.032316078431904316, 0.011395459569030209, 0.03519650941598229, 0.047458113767788745, 0.05157752319064457, 0.021006955685152207, 0.0425015246582916, 0.008016254323592875, 0.0427754291013116, 0.031493815913563594, 0.05362048505048733, 0.018728580871538725, 0.051644353588926606, 0.076467430772027, 0.040874176629586145, 0.026513954908296, 0.022302884681266733, 0.01791776598111028, 0.016789900037110783, 0.020415207945916336, 0.02409440690826159, 0.0265879859944107, 0.0194691644719569, 0.04481024217966478, 0.0695678248303011, 0.043357150425435975, 0.06612962533836253, 0.03785113825870212, 0.04111653979634866, 0.03450399286521133, 0.027865639603987802, 0.02448816449032165, 0.06901939996168949, 0.02588655068393564, 0.08696866454556584, 0.11788826595875435, 0.1237926963949576, 0.016334223219018895, 0.006589995846297825, 0.011890248497365974, 0.031926937008393, 0.020323138960520737, 0.02556120241933968, 0.02334795477509033, 0.03415627812501043, 0.03777776211791206, 0.036590956660802476, 0.02603357941552531, 0.07948253929498605, 0.047230126001522876, 0.02565323800808983, 0.03513997631671373, 0.025728057626110967, 0.026750312244985253, 0.023797558969818056, 0.02786115146591328, 0.02758800401352346, 0.05972757004201412, 0.06500865580164827, 0.010405759257992031, 0.03764300294278655, 0.0653004385821987, 0.01664988274569623, 0.016989511786960065, 0.040475220303051174, 0.03832749316643458, 0.060079017785028554, 0.04146724539168645, 0.053943371240166016, 0.02717818078963319, 0.022132669400889426, 0.050885552118415944, 0.05029637963161804, 0.06420283185434528, 0.013145918765076203, 0.02034617522440385, 0.031260262039722875, 0.043062373079010285, 0.04720482989796437, 0.06550189456902444, 0.02965928622870706, 0.03794140196987428, 0.002330879210603598, 0.04140000310144387, 0.027748300490202382, 0.08434291637968272, 0.18157601763959974, 0.12538138224044815, 0.18436129787005484, 0.09636558257625438, 0.11261316190939397, 0.09017905438668095, 0.11746959818992764, 0.11467022457509302, 0.08782508812146261, 0.1362740618060343, 0.265105243306607, 0.1177573214226868, 0.14004623517394066, 0.08212917891796678, 0.1217720509157516, 0.090216933604097, 0.10259627597406507, 0.1828558067791164, 0.1802173678879626, 0.1584371889475733, 0.13390819891355932, 0.1661574692116119, 0.0884145760210231, 0.18474871380021796, 0.1835933531401679, 0.24689100973773748, 0.10209032421698794, 0.09827063113334589, 0.11166992189828306, 0.0925508321961388, 0.08938316779676825, 0.1009957083442714, 0.08151571222697385, 0.1718468326725997, 0.2519397810101509, 0.17705393373034894, 0.15064674604218453, 0.23223016440169886, 0.11811962307547219, 0.18067427852656692, 0.11449259152868763, 0.16073190956376493, 0.15741290641017258, 0.16819684649817646, 0.09353045970783569, 0.16459744510939345, 0.17404808721039444, 0.1356926336302422, 0.15591287752613425, 0.16598646354395896, 0.057242510811192915, 0.15322363120503724, 0.08114839365589432, 0.1336620285292156, 0.20714696816867217, 0.17118646966991946, 0.11876800781465136, 0.2223171791411005, 0.15273197321221232, 0.13584177562734112, 0.158027375000529, 0.15407938684802502, 0.1693489120225422, 0.10696650904719718, 0.05932738175033592, 0.33480974205303937, 0.2051490027224645, 0.10169944987865165, 0.09079145980649628, 0.13157050794688985, 0.096386251389049, 0.24501647829310969, 0.15805372124304995, 0.17893977550556883, 0.0833642907673493, 0.11901463090907782, 0.11931503002415411, 0.15779943176312372, 0.1106955339491833, 0.16200734971789643, 0.12419501465046778, 0.10239392941002734, 0.1675248020910658, 0.153195132734254, 0.11889692628756166, 0.074089841946261, 0.12916290666908026, 0.13401683449046686, 0.10149327383260243, 0.0778894970426336, 0.2420370522304438, 0.10220980999292806, 0.17431672982638702, 0.15698817529482767, 0.15132112079299986, 0.1748243736801669, 0.11842563282698393, 0.15602103812852874, 0.12458525074180216, 0.09641063094022684, 0.160509072302375, 0.18810206354828551, 0.10299823799869046, 0.1672086917096749, 0.1266677022795193, 0.10236167567200027, 0.1672046395833604, 0.11056134622776881, 0.18448862072546035, 0.1300053036538884, 0.2168237723526545, 0.10737688702647574, 0.12126316025387496, 0.1394836575491354, 0.17466985853388906, 0.16177772922674194, 0.22553391434485093, 0.10449503854033537, 0.1795611609122716, 0.08947977315983735, 0.10333032681955956, 0.11006219996488653, 0.13861412764526904, 0.16867758007720113, 0.09513464159681462, 0.2224953391123563, 0.21166124468436465, 0.14385201298864558, 0.12141574581619352, 0.16737834666855633, 0.22410624485928565, 0.27875016268808395, 0.1555759276379831, 0.10970698582241312, 0.12929818534757942, 0.04758304319693707, 0.16132182790897787, 0.08641926746349782, 0.13805618102196604, 0.10407061170553789, 0.17280203610425815, 0.14143087493721396, 0.1539615634828806, 0.19700559438206255, 0.10061894965474494, 0.11189815457328223, 0.11485015827929601, 0.2533217193558812, 0.15356270363554358, 0.11695949040586129, 0.098234399483772, 0.17756049404852092, 0.10753567694337107, 0.10851603918126784, 0.11790250035119243, 0.18230970483273268, 0.21956004115054384, 0.17414995440049097, 0.08353853962034918, 0.12574944295920432, 0.08418955898378044, 0.18433124088915065, 0.1707931314012967, 0.20273987262044102, 0.06695065589156002, 0.15735546418000013, 0.17181446019094437, 0.18154668796341866, 0.061101222308934666, 0.1386547231231816, 0.11532618664205074, 0.1632626776699908, 0.30100075935479254, 0.09321898774942383, 0.18976628518430516], [0.008477553838019958, 0.029047771386103705, 0.016753284326114226, 0.036314870303613134, 0.017185800570587162, 0.03529936366248876, 0.04827922224649228, 0.017108093998103868, 0.019899300277756993, 0.07897836127085611, 0.0027136940570926527, 0.11336499461322092, 0.016368005781259853, 0.046006279953871854, 0.07423138435115106, 0.013093270808894886, 0.025758721312740818, 0.04705543185991701, 0.02995058661326766, 0.09800700543564744, 0.045877739976276644, 0.06495597815955989, 0.024309720647579525, 0.08080810410319827, 0.03084185031184461, 0.03678089451568667, 0.024861576093826443, 0.0697405893879477, 0.0634522236941848, 0.04690169225796126, 0.05454112666484434, 0.04828608340176288, 0.011220860978937708, 0.0166829547015368, 0.030576560347981285, 0.03345995435665827, 0.013040626563451951, 0.12397895319736563, 0.027949773175350856, 0.024289673383464105, 0.017032372670655604, 0.02401957244728692, 0.07689726044191048, 0.07604834740050137, 0.034017990037682466, 0.014600274025724502, 0.08825370809063315, 0.10144576895982027, 0.011446429343777709, 0.02318729650141904, 0.0087336550859618, 0.03599195813876577, 0.018428204020892736, 0.007966061020852067, 0.040028584699030034, 0.008269287718576379, 0.020218939571350347, 0.06204871853697114, 0.024422582755505573, 0.028586997868842445, 0.0057393211318412796, 0.011744113126042066, 0.03604486584663391, 0.03712844969413709, 0.0333212692203233, 0.04676794240367599, 0.05088490273919888, 0.04915536839689594, 0.02364600499277003, 0.09692427876871079, 0.04342629632446915, 0.03254154660680797, 0.07738437649095431, 0.04433449954376556, 0.03472419921308756, 0.014031598730070982, 0.052391540448297746, 0.05606307116977405, 0.06353459466481581, 0.023773800967319403, 0.0297798518295167, 0.04843501388677396, 0.01026050982545712, 0.02919242895586649, 0.07474667232600041, 0.024150255376298446, 0.044311589444987476, 0.06473420216934755, 0.08717882592463866, 0.04514907341217622, 0.017094354989239946, 0.09604277060134336, 0.04838843669858761, 0.08032853569602594, 0.06665359644102864, 0.02587885090179043, 0.013361678720684722, 0.04119697005080525, 0.0021569977207036573, 0.0260289558354998, 0.06125759282440413, 0.08390554648940451, 0.018939467699965462, 0.07696610206039622, 0.058425475654075854, 0.0338140812527854, 0.03122997128230054, 0.02965140090964269, 0.03352387182530947, 0.02766863464785274, 0.036882783970213495, 0.031223766927723773, 0.05151909019332379, 0.07786753689288162, 0.03529018329572864, 0.006174531836222741, 0.041975341955549084, 0.03267750435043126, 0.09014875249704346, 0.027373228331271093, 0.05961602524621412, 0.020639535068767145, 0.07973961925017647, 0.043660202718456276, 0.02196626319346251, 0.022114672319730744, 0.05919861912843771, 0.08021368834306486, 0.041073257743846625, 0.03456128295511007, 0.014319385973067256, 0.02980397348437691, 0.023725017745164223, 0.07800378036336042, 0.04007741801615339, 0.019574816615204327, 0.03432019999308977, 0.01176897971163271, 0.029824267512594815, 0.027262303228781093, 0.006658624097326538, 0.033862721611512825, 0.028010399219056126, 0.04725021222839132, 0.04420227851369418, 0.060562237558769993, 0.09543653242872097, 0.008593408656452084, 0.07465350310667418, 0.05399780777224805, 0.029406213870970532, 0.06405967156752013, 0.04505312113906257, 0.08868482167599723, 0.021123010883457027, 0.03897561073245015, 0.015068990378495073, 0.13501120847649872, 0.050475901443860494, 0.018891350555350073, 0.06049678755516652, 0.025335756508866325, 0.07326065519009717, 0.05958822810498532, 0.10139109494048171, 0.06988229506532662, 0.010253543841827195, 0.02054974447673885, 0.015352962054748787, 0.03555231356585864, 0.05283346712531056, 0.015198512774077244, 0.05862371814146172, 0.08449808461591601, 0.036506656106212176, 0.026335457259847317, 0.03603295066568535, 0.037547655520029366, 0.02514746807719348, 0.022766046058677603, 0.06759452837286517, 0.023690802881901618, 0.01401166278810706, 0.023134262628445867, 0.05320193602528889, 0.0699052719573956, 0.0579037940769922, 0.03178998849762138, 0.061437860495061614, 0.06262611685087904, 0.017194290740008, 0.056047471225610934, 0.038337267251336016, 0.027993559888273012, 0.059044248700956814, 0.09768566291313618, 0.022840351739432663, 0.0644683203427121, 0.08853501174598932, 0.01777522909833351, 0.006764287836631411, 0.017070572866941802, 0.06058713661332149, 0.08615374186774716, 0.10347900868509896, 0.026091021645697765, 0.08315896819112822, 0.015379138530988712, 0.036108950298512354, 0.039725179885863326, 0.057666366192279384, 0.05462689296109602, 0.009184218506561592, 0.06955295961233787, 0.008122916715365136, 0.01659011388255749, 0.05203760651056655, 0.029368737268669065, 0.09462093439651653, 0.04323784647567663, 0.04662691950215958, 0.02483408694388345, 0.04677802076912485, 0.011114725512015866, 0.09989394558942877, 0.026278707082383335, 0.016640887915855274, 0.029848789927200414, 0.02340575880225515, 0.03583250771043822, 0.024312646564794704, 0.03217921526811551, 0.03174127763486467, 0.029829961640643887, 0.02542449139582459, 0.03795764016103931, 0.009155127245321637, 0.05894061891012825, 0.05598421426839195, 0.015355939922301332, 0.01740469702781411, 0.018953574071929324, 0.02696845171158202, 0.04081900537130423, 0.02416309082036605, 0.061361697589745745, 0.0241845259006368, 0.08136150136124343, 0.02346336801565485, 0.03659616282675415, 0.052375012819538824, 0.02169533105188748, 0.012777078791259555, 0.021209432125033345, 0.07776443031616509, 0.026370065461378545, 0.025862254624371417, 0.05419664768851362, 0.03730055374035146, 0.009770510532689514, 0.053193152707535774, 0.04603398061590269, 0.053704340316471644, 0.06384574007824995, 0.0755797405145131, 0.03245844833145384, 0.0520511618378805, 0.08116088400129229, 0.0884044605481904, 0.06268895449466072, 0.06761120443115942, 0.03165902540786192, 0.048578352289041504, 0.011067677060054848, 0.042122784434468485, 0.07605353501276113, 0.015535116635874147, 0.03320619180158246, 0.031360526190837845, 0.030530957228620537, 0.054474225762533024, 0.0422671915293904, 0.03147198563965503, 0.043188812778680585, 0.04405907369800843, 0.013734589374507777, 0.07962289426359348, 0.014430607934627915, 0.059080354185425676, 0.03474386241578031, 0.05306912869855296, 0.08352855031262152, 0.058911534142680466, 0.053262042565620504, 0.028483692767622415, 0.04759019007906318, 0.03884073281369638, 0.021329626652004663, 0.027364103625586722, 0.018423426445224322, 0.03763474654988386, 0.05838848701387178, 0.0798129582835827, 0.04396104712213855, 0.060743291905964725, 0.09851579219684936, 0.025359833634865936, 0.08168269545421936, 0.06442552068619989, 0.01977104602701729, 0.05506357265403494, 0.012548571521620033, 0.032531052638660185, 0.04787180543644354, 0.03493244956189301, 0.017956231495190877, 0.03023328179551754, 0.015984051970008295, 0.021470278479682747, 0.039202273765113205, 0.016357198255718686, 0.09268596244510263, 0.05159890075447038, 0.05598517906037159, 0.05647188321745489, 0.02159374773327727, 0.008745921859372174, 0.043961199262412265, 0.0539521174505353, 0.03796663870161865, 0.04566989780869335, 0.07840168284019455, 0.027454341361590195, 0.00374930710222543, 0.07361516429227777, 0.02086448745103553, 0.03737048631592188, 0.024122987015289254, 0.04917695747280959, 0.01665725783823291, 0.04901762949884869, 0.06159302873129491, 0.039966708136489615, 0.030711137696926016, 0.062088879858492874, 0.02163140059565194, 0.03569115826394409, 0.003189820290572243, 0.05014648435462732, 0.036334448159323074, 0.033549962026881985, 0.02268078813358443, 0.12444092528312467, 0.15623517741914839, 0.11387141392333433, 0.08112101582810283, 0.11540404535480775, 0.1364007464144379, 0.23382112121907994, 0.1216853161167819, 0.12003370356978849, 0.16699388448614627, 0.07214114026282914, 0.16893483814783394, 0.15982478245859966, 0.08806220430415124, 0.1343865873059258, 0.11510498952702619, 0.09194234531605616, 0.14087009330978617, 0.09345515398308635, 0.1835299440426752, 0.07741541310679168, 0.11656539514660835, 0.18249052169267088, 0.11639911695965566, 0.15146925346925855, 0.11799876432633027, 0.12368357100058347, 0.15454153704922646, 0.20112746773520485, 0.11464471695944667, 0.14539161318680272, 0.10564023919869214, 0.09169934390229173, 0.21272627112921327, 0.12519019015599042, 0.1483238089713268, 0.09162630172795616, 0.14162408566335216, 0.1501616634777747, 0.09479276384809054, 0.10462367499712855, 0.07253855292219669, 0.2433389870566316, 0.19047059817239642, 0.11215098944376223, 0.08525786572135985, 0.1924743375275284, 0.20022100856294855, 0.1414345411467366, 0.09520807710941881, 0.11550862138392404, 0.11529602576047182, 0.1405041996622458, 0.09790133844944648, 0.13794751575915143, 0.15448989841388538, 0.17921699734870344, 0.15039149177027866, 0.14742434083018452, 0.09200683052768, 0.14641616289736703, 0.13524182344553992, 0.13308581023011357, 0.19053286436246708, 0.1483065020875074, 0.18559640971943736, 0.1335120404837653, 0.06642776090302505, 0.14067061885725707, 0.2033150222268887, 0.11643692196230404, 0.18722171313129365, 0.11776131417718716, 0.13313307019416243, 0.21980679041007534, 0.11836034609586932, 0.08533406202332117, 0.1182756076741498, 0.17984923295443878, 0.13611007685540244, 0.1415896648541093, 0.11895827221451327, 0.07319503449252807, 0.12634843034902588, 0.1366237469483167, 0.13353446818655357, 0.11822719738120213, 0.22426245210226625, 0.2729813597397879, 0.10653521734639071, 0.08041361550567672, 0.16856281436048448, 0.1304924939176999, 0.1842499608756043, 0.1942577480804175, 0.12618220411241055, 0.09689941682154313, 0.07566211890662089, 0.08666112596984021, 0.1309252847568132, 0.12736152129946277, 0.13253371173050255, 0.10110498216818087, 0.22788009548094124, 0.16157240665052086, 0.1437970792176202, 0.09022495622048154, 0.16704763082088903, 0.1348901493474841, 0.20484737906372175, 0.18247048370540142, 0.05414845632913057, 0.23149622487835586, 0.1929150099749677, 0.11234397010412067, 0.14351277728565037, 0.20946785691194236, 0.14629823563154787, 0.15677912713726982, 0.17871212912723422, 0.16290076193399727, 0.18317623645998538, 0.1931049849372357, 0.15017944533610716, 0.06600582768442109, 0.15394574089441448, 0.14240170799894258, 0.07828269430319779, 0.12128543210565113, 0.17446419456973672, 0.077451503748307, 0.18659822002518922, 0.12744571053190157, 0.21906704729190096, 0.2289190873852931, 0.16437459300504997, 0.11020947917131707, 0.16916110413149, 0.10776701921713538, 0.12649463344132528, 0.14802377350861207, 0.14192483358783647, 0.09790683776373044, 0.12680479179834947, 0.09356557813589461, 0.14859690447337925, 0.1508774352259934, 0.1527488199644722, 0.22742748929886147, 0.1636867260094732, 0.07319581374758855, 0.16071362304501235, 0.12212587724206969, 0.3093969135079533, 0.1265029306523502, 0.11585797255975194, 0.15128353843465447, 0.1579246172332205, 0.1531392044853419, 0.1119943665980827, 0.1436640863539651, 0.08878753491444513, 0.21343350817915052, 0.16156225407030433, 0.13263007218483835, 0.15190465666819364, 0.12223904734128155, 0.11966680060140789, 0.1672257314203307, 0.15839064144529402, 0.13213796890340745, 0.10919581676716916, 0.18925099720945582, 0.16927158023463562, 0.2437023722450249, 0.07188637580838986], [0.010019489945989335, 0.01553015816170955, 0.015982350596459582, 0.035809779437840916, 0.07081388335791416, 0.050633325809030794, 0.02907457219407661, 0.05631541622278746, 0.03720094267919194, 0.15154824766796082, 0.029226829356048256, 0.05768197726865765, 0.06991083064349368, 0.023496965040976647, 0.009210022053594003, 0.07215453602839261, 0.06845418771263212, 0.07328530933591537, 0.009344059490103973, 0.0242396118119359, 0.06606573384488001, 0.04871830649790354, 0.06918834245880134, 0.0458712202089373, 0.02501677216059761, 0.032147648016689345, 0.03702864567458164, 0.009403664153069258, 0.04545275281998329, 0.050937194464495406, 0.02376480242674006, 0.02450359930662671, 0.06015578925143927, 0.11384662619093433, 0.04625190114893485, 0.09115698238019831, 0.0659012071264442, 0.01713208206638228, 0.06531563776661642, 0.017247096402570605, 0.033233977810596116, 0.01330630522716092, 0.03451712887908798, 0.02720729524298804, 0.022508005022245925, 0.041996103536803275, 0.05929543600359466, 0.03454546778812073, 0.032994831854011863, 0.04420867211592849, 0.048958153784042224, 0.016495718264195602, 0.017796012944018003, 0.041394555737497285, 0.022503023355966434, 0.00609414889368054, 0.031035599095048383, 0.04024955916975159, 0.00695937434102234, 0.06715987474308349, 0.024869884437066503, 0.01414671603924944, 0.047769804659765214, 0.08697235301951878, 0.032451698498334736, 0.017897839315992314, 0.049803664078353904, 0.046423641542787664, 0.00743492958463321, 0.06233616717508994, 0.04078295183717273, 0.02936265907919733, 0.07392629486275837, 0.00725341232282517, 0.021065615037514362, 0.08699882542714477, 0.030130967461445834, 0.010760221048258245, 0.07755971630103886, 0.052139325271127746, 0.04728418032755144, 0.05064485136244912, 0.02500864564353833, 0.009299705034209182, 0.03881979682773817, 0.06150520668597892, 0.04791762192326132, 0.008141689340845915, 0.06808237914810888, 0.0043036248553107725, 0.028834700788138434, 0.02238983470306266, 0.0854072006768547, 0.05919495291891508, 0.040955323056550696, 0.021810360231029335, 0.06184857244079467, 0.056130844095605426, 0.02228480781923281, 0.03707500763994176, 0.0475998565525515, 0.01106937843360356, 0.038902780070202425, 0.05641375078994315, 0.04612789940438233, 0.03964089788496494, 0.0408863812481286, 0.01991246968827909, 0.01099941524444148, 0.020961937007086817, 0.06958802609005943, 0.04082967745489441, 0.006438535565393977, 0.04574273589241784, 0.034889100716100074, 0.026189884993073065, 0.04265818090061657, 0.06541492228279822, 0.0354496745421784, 0.027783602599811275, 0.019482643729133997, 0.0403596641990589, 0.05275987205095589, 0.03347578436660115, 0.06958459736779332, 0.03390022975509055, 0.040424772814731114, 0.007211205456769676, 0.07400381960906088, 0.05189446477743331, 0.05120548827107996, 0.04450995438673999, 0.013203216276451712, 0.0258898792162654, 0.09710029393318109, 0.07025471961242147, 0.022609729348914698, 0.0168276530894218, 0.04583594964060467, 0.019871289769071154, 0.06763300130842254, 0.06486574784503318, 0.08292352926218882, 0.030334941184264608, 0.03919314905942883, 0.04594166486640461, 0.014077314099267824, 0.06519143935292959, 0.0405330892681377, 0.05341634991054889, 0.034979965566890314, 0.06606731461943127, 0.029503394398489036, 0.05952081141003873, 0.04454584835912101, 0.033744315660442226, 0.030238185536290985, 0.022690100231557153, 0.035742518593906425, 0.0525234126689611, 0.017945949039130937, 0.017259774140256923, 0.009782914603420068, 0.055052433017408475, 0.006877480664115865, 0.07488861549063586, 0.024801970503176562, 0.07509692892199382, 0.03768616254092194, 0.062403569027082995, 0.0903730740537867, 0.051162417730665766, 0.027205801670788787, 0.073093152459478, 0.020070268838026095, 0.022981495239946526, 0.038524640985997394, 0.021361657745728735, 0.03458586288616061, 0.03668835612188559, 0.0814792282471899, 0.020638997011701576, 0.0342032486514654, 0.09400475886650383, 0.062097993431962095, 0.03432447847444564, 0.02081576174532529, 0.05327115984982811, 0.06836966451373883, 0.035895111577701755, 0.02874846693885047, 0.03846314662951045, 0.027395444521971513, 0.0541628131759353, 0.055431017390219495, 0.04181323463853914, 0.06226197467185557, 0.00765427457736223, 0.02278419713547919, 0.03844889739411883, 0.05899212395888753, 0.1293005156912841, 0.05752460485382471, 0.005721356055801152, 0.04629303468391299, 0.08146987718646415, 0.02865920883778017, 0.04610821764799766, 0.01674546208960237, 0.04517520443187095, 0.048064118163893, 0.013901409329264425, 0.015243471152643906, 0.04669299290981144, 0.0536290568561526, 0.10507126426091418, 0.011678716000460554, 0.027982180909020826, 0.01071542037607287, 0.02361395348998485, 0.05294648508424871, 0.0028800766085623764, 0.02846424849849427, 0.0026766854716697708, 0.04919607890769839, 0.08415338670602068, 0.0047524414458166575, 0.03256672396673821, 0.010806184109242167, 0.050738228383124806, 0.020479869417613372, 0.0345045086578466, 0.036639545069192536, 0.029512192559195682, 0.0030386779735636082, 0.08443535087280907, 0.03931866478524171, 0.031747007014928386, 0.029989521535753738, 0.03480678169580642, 0.034667079817154445, 0.060933916247449815, 0.1008832803927362, 0.016690133124939166, 0.03566054467228241, 0.010861300634132931, 0.015720350202172995, 0.020537361742754, 0.036016615995322354, 0.017290083451371174, 0.07663151962333359, 0.0950013667170424, 0.039411236575688235, 0.04229946753184777, 0.02180944738938706, 0.018745600173133425, 0.03179903156706132, 0.02008240295253927, 0.10243712982628495, 0.06776152644306421, 0.059599835294648074, 0.026413499654154293, 0.021192987987888046, 0.02503083956980845, 0.0810610874032136, 0.0514672103599878, 0.020182834086881485, 0.0275375342607731, 0.11888533394085243, 0.034804685128619894, 0.01274725280381972, 0.018026585239567794, 0.02082651360979071, 0.03147477611491922, 0.012439796792023117, 0.023266556017915718, 0.011289708163531031, 0.03709311604325194, 0.03684885668917559, 0.02856474086001981, 0.014768985529372003, 0.05113418272230774, 0.046438744248007424, 0.057675468633533455, 0.010139317109860713, 0.025713869617902674, 0.07604163096402772, 0.045280875128810294, 0.045813566466677, 0.07011489156866446, 0.05109585450554732, 0.007889328517194372, 0.04455136993783526, 0.04791214858414605, 0.06323759458609857, 0.10109791692229919, 0.012384527199174045, 0.07319062613532878, 0.013186010510253254, 0.06841669441200793, 0.024597191550128628, 0.03143259986245539, 0.025362549895362463, 0.024722070884308778, 0.08643563181976788, 0.044142917831777595, 0.09350108550279401, 0.010300762060069246, 0.058517424040474, 0.02092789283778984, 0.08378036844078451, 0.030351494788192213, 0.09145467265625484, 0.06329252835712396, 0.05134623286721762, 0.04829736404644791, 0.02041080701019382, 0.023117978053051047, 0.05914565204875544, 0.049035570918931626, 0.052777742967009544, 0.04588539894029964, 0.01655985281104222, 0.02976608127937652, 0.00492053279231186, 0.023964644242369104, 0.01593938210135093, 0.03446716749749612, 0.04308488983951975, 0.04772100845002569, 0.05099862944916822, 0.03496107419778127, 0.02040558600128861, 0.026707039469329175, 0.0665560930792708, 0.04724821956187952, 0.0430482945375843, 0.015597880992572755, 0.06733756716130301, 0.02664809439011151, 0.013974996054457733, 0.021690989487979095, 0.020150313175690826, 0.07607265273691155, 0.0390965065889759, 0.014123573091637809, 0.0652868498582393, 0.02478802554833237, 0.08589468037826009, 0.020189372407912742, 0.02208748373959679, 0.027196756745979656, 0.2132673264713958, 0.10425176253193058, 0.11055697497795336, 0.14913868712028489, 0.19434077956248075, 0.12291924052988179, 0.10411360432044603, 0.23078107653418556, 0.12579854344949126, 0.3987606073496863, 0.1673780646524392, 0.13951319502666593, 0.21634977747453377, 0.11612167247221805, 0.12689037626842037, 0.12479193886974826, 0.17688451625872403, 0.15285064262570813, 0.15193319966783747, 0.21488161641173065, 0.1516791179892607, 0.12338328320765868, 0.16573615197557956, 0.17367551423376426, 0.13634884060593322, 0.14931724785128608, 0.26068765379022807, 0.14089023519773036, 0.09900895674945787, 0.1770775785553269, 0.07235534634673968, 0.1242029778950382, 0.12738570047076792, 0.18312529544346035, 0.09976273388019763, 0.1420525275170803, 0.16864657314727083, 0.1288637617835775, 0.1668055125628598, 0.17428202700102702, 0.13942657154984772, 0.08678127967868932, 0.12845975143136457, 0.0951574181090109, 0.1351995803997852, 0.11482604590128176, 0.19277998362667859, 0.1163616830308456, 0.13462575181620196, 0.17010409181239083, 0.17035161290550604, 0.09232895230525173, 0.15987453603884205, 0.12636503961402923, 0.12944291898747906, 0.0878925493452698, 0.1283535797847435, 0.18839185737306252, 0.14504465914797038, 0.2747114247176796, 0.17666868487140164, 0.1524708411307074, 0.14818223688052967, 0.1898549569887109, 0.19940439378842711, 0.11146211312734522, 0.17514379404019564, 0.0833931528904941, 0.09869575558695942, 0.15704518707934767, 0.0798277641297318, 0.08885398681741208, 0.14606635901145637, 0.10777071511256509, 0.20397443528054282, 0.40070654824376106, 0.21161171374842525, 0.10299107627361082, 0.1484072263701819, 0.13180784677388147, 0.1564467785647139, 0.13315468153450638, 0.1371772852144204, 0.13033900293521583, 0.1718279079068452, 0.15075824630912393, 0.18487038149032742, 0.13789060787530616, 0.18355210457229987, 0.15495859435759485, 0.09994897583965212, 0.09382607939187437, 0.32678486953955144, 0.13239239196991548, 0.13018441357417032, 0.11087939361459576, 0.12304112344281748, 0.19459695409750566, 0.2498088969150558, 0.11016486125299707, 0.12289259742829017, 0.07378485635854304, 0.1423469968722202, 0.12835779518354684, 0.09776637147297151, 0.15719521965365857, 0.20186624606139958, 0.12901633250294253, 0.13860988256055862, 0.10837509791599587, 0.14394632511539385, 0.1747180536040105, 0.08903797264792956, 0.1613779045874253, 0.1470485914614983, 0.16930944460909814, 0.1536447851685807, 0.0913358102843631, 0.15342843427788466, 0.2131748993997462, 0.149371973820962, 0.3496249986346811, 0.13603477855212986, 0.12573891930514947, 0.21680082514649257, 0.16441397136077285, 0.10148811590624973, 0.16024810349335894, 0.1433209321112372, 0.1846964962896891, 0.14361436245962977, 0.14170975919114426, 0.11120282157207839, 0.10057787178084254, 0.17450441897381097, 0.14572206186130643, 0.16859065974131227, 0.15385131002403796, 0.13874376600142568, 0.11673054526909254, 0.1845076642348431, 0.10585227078991011, 0.1693864053231664, 0.09948272156179883, 0.10722054619691335, 0.08808360784314573, 0.13308683439390734, 0.10771628600195982, 0.13478178094374016, 0.09874306007986888, 0.14584844961063936, 0.1441871075076051, 0.11336565512465313, 0.26379143411759287, 0.21728192979935557, 0.15415688190842047, 0.11952180720982142, 0.11119676564703695, 0.13151086895959452, 0.15161343791987747, 0.07579643279314041, 0.17149879509815946, 0.2539308147970587, 0.12248069804627448, 0.05229185146163218, 0.16023872274672613, 0.08309621218359098, 0.18611171253724024, 0.1886792911682278, 0.2102645524428226, 0.28971480089239776, 0.157265501038637, 0.1196144123969134, 0.17012006283039227, 0.11317373573547229, 0.0995977470302023], [0.06701422826154158, 0.04060538187331986, 0.009718009150674334, 0.04992898684577085, 0.027097477795905434, 0.023741189143038355, 0.05081606483145151, 0.013153005347703584, 0.006014745586071513, 0.04285179609723855, 0.02960478661407251, 0.0515058539895108, 0.03339355069329031, 0.014873029067530297, 0.008762540401221486, 0.037320009141694754, 0.02123070207744604, 0.034970339911524206, 0.03363339426869061, 0.07063322234898806, 0.05771335898316465, 0.028088029721402563, 0.03837186988675967, 0.03576848263037391, 0.020190708273730706, 0.07081021714839153, 0.058352400083094835, 0.03812318362179212, 0.02695892624615226, 0.04585134178341832, 0.04635265140677802, 0.03672643571917433, 0.05110055601107888, 0.022820384256192483, 0.01060235974364332, 0.08182358476915397, 0.025300511915702373, 0.04148764332057908, 0.04487968122703023, 0.059931348951067775, 0.03557863012247253, 0.024351243810087908, 0.010099021274072584, 0.01336371313300333, 0.03968721903220285, 0.041661780851427466, 0.041851421847241, 0.06104169835452922, 0.06371453579049557, 0.031001475144876167, 0.05023128214816097, 0.050275777612114325, 0.01959070414159214, 0.016286785139527638, 0.002591000115899078, 0.020808000735996757, 0.04011587610875722, 0.02998853819008218, 0.0358097163552884, 0.028642686775128823, 0.051487044256646186, 0.025429046327190008, 0.03523474857502151, 0.0742115467437543, 0.01776074608642375, 0.05527607921976596, 0.04827320342883468, 0.052656435218523256, 0.046015415791771375, 0.06324223300907761, 0.02713837198825786, 0.08824986376566812, 0.054557060575461946, 0.02205374385084724, 0.04841633031901438, 0.021582658191618975, 0.013758494878857164, 0.01475438562920317, 0.054001574171707034, 0.09117078632698394, 0.05115490348543972, 0.048010497994255275, 0.050737838755594566, 0.045258477111929096, 0.047206726085278206, 0.04724368132883683, 0.04457516690308694, 0.09055221365997568, 0.017431813248549588, 0.021951006492599845, 0.044910554570378736, 0.049101395707111806, 0.08716721131349914, 0.04052580508869141, 0.03368492529261857, 0.05032334927818738, 0.04986715110135265, 0.010044820373877883, 0.04029163523227908, 0.010789436619234039, 0.042559323119348846, 0.01317438569458318, 0.05818228128191549, 0.027526142293936573, 0.006164896440168377, 0.04793403080839198, 0.04279298831534106, 0.03955608524847776, 0.01502249389886856, 0.010929811996902572, 0.09610249864635989, 0.01367809059956926, 0.05412555365182925, 0.06972860370296985, 0.03798170801019296, 0.038674376701237634, 0.03145173985103611, 0.025140419529634528, 0.06427177737350576, 0.017278793529840186, 0.03648059930128511, 0.02303001871041488, 0.03989979981270153, 0.024184798639907967, 0.009952857144526206, 0.022873208472447004, 0.03713541475008242, 0.008512208423780976, 0.034611860319273546, 0.08083333712420426, 0.0413784400006989, 0.0371788415213814, 0.050276282272534445, 0.043759272011811845, 0.01008142495265929, 0.09170972654828802, 0.022679545036226045, 0.00822978412543307, 0.026072733271576, 0.059674784788512625, 0.04307826988224406, 0.014015033066243632, 0.042856920626945794, 0.032000736173358746, 0.028702843410428613, 0.0426360203709919, 0.011789678210334387, 0.10620332148391753, 0.06342000706354156, 0.011219138268643292, 0.016801319834485184, 0.047222789871739224, 0.023301028777495958, 0.05735338025260717, 0.08030319135286845, 0.06954183481866494, 0.03635308348748367, 0.027435316405899357, 0.01767140820447821, 0.04693247283285018, 0.0488760277221445, 0.016485426531289704, 0.03030846877663862, 0.07713962360867299, 0.011148098965350073, 0.12711052695522085, 0.05405140567745548, 0.03285488135588821, 0.05090739723527804, 0.038431275097536854, 0.026276794196746778, 0.028075212831026874, 0.04345388566434849, 0.013735245247517014, 0.06301134344539605, 0.06446147031965666, 0.024170105971279554, 0.018954722545458935, 0.017998634102696087, 0.040047394431894645, 0.02799212197714951, 0.01784316344128456, 0.034065706422552466, 0.06545620795805007, 0.039070601924322546, 0.056392239639535546, 0.05641830757667776, 0.05621013144263998, 0.045310241912375204, 0.029679179497179575, 0.04997402778826654, 0.032237663108389825, 0.019453507011348847, 0.06250208170968108, 0.04887811315711588, 0.05042637050792109, 0.03848439060675446, 0.015664290222048294, 0.013165467862563673, 0.008491136995871784, 0.03215171869669575, 0.08481665892759338, 0.061289011646294966, 0.023881525557953864, 0.019696042727446184, 0.03738635714398697, 0.03437756800849456, 0.03464159817667678, 0.016076928041002247, 0.016670978293404914, 0.04929521499434486, 0.058897002891171724, 0.017120682678068988, 0.04023019653686788, 0.04376077857159544, 0.02196050227212254, 0.03824098101176787, 0.020581834942277055, 0.05170573291252367, 0.04253216422512196, 0.05368468082451727, 0.016005635479814373, 0.07766537586576305, 0.04413984905113466, 0.029434081516228616, 0.0853330378595274, 0.021601777771138586, 0.015491331778321182, 0.05226094101089984, 0.04108748471480794, 0.04143204903812148, 0.09360078562167473, 0.04388411238323897, 0.01977620766410837, 0.03855618226225488, 0.016481524689879734, 0.07974443578859791, 0.06021009219693951, 0.02511729977413779, 0.035409123593126424, 0.016932709659158718, 0.006325948979792884, 0.03971795507823117, 0.02223377588961739, 0.03550041146809235, 0.027270452010270674, 0.046568352918257006, 0.0795182737056166, 0.024937045091064647, 0.014537858478433918, 0.08250260536442511, 0.049949878302868456, 0.051720264164032415, 0.08093884083791636, 0.039730423159198835, 0.033006264638970606, 0.02283596564666368, 0.04687956141424365, 0.06831298669567332, 0.015186695927695837, 0.036895842058584094, 0.022044956822355743, 0.037838403004570864, 0.07511632866226137, 0.03213106843759306, 0.08702080041985027, 0.03628416765423026, 0.033189059322467074, 0.02391291840467602, 0.021021345928602386, 0.02917602934758179, 0.0721870717825368, 0.03622411306423601, 0.009725466807140037, 0.030075896393100265, 0.010175555253226776, 0.006474428146248101, 0.013947252718935488, 0.05357644229661673, 0.02880727843148634, 0.055752385887899436, 0.042672300260164775, 0.043324087746441364, 0.008227768266806379, 0.05084431097202469, 0.07600616372656077, 0.02607174807053525, 0.030414857501455117, 0.051276519225211814, 0.0031388498200612958, 0.06483901568572037, 0.05807505578559358, 0.012007867771899328, 0.02441641736368183, 0.01845135717303492, 0.02909071019530529, 0.02561729765147902, 0.029358560568653047, 0.03006363425811287, 0.05051472318882588, 0.008283966471935855, 0.07690805126912892, 0.050710490613710135, 0.04906172049231827, 0.04281244742742274, 0.049759907051338814, 0.09337402239907533, 0.01754661792801926, 0.07378397320280783, 0.013939948130428093, 0.031169835056061856, 0.05275249139231164, 0.04900792220723815, 0.032968084851745516, 0.027741784433601424, 0.10176495925406925, 0.05868377644219436, 0.04106658212549519, 0.052032426319783553, 0.013991461528348736, 0.04320118809118867, 0.016656504558341112, 0.015993621964298654, 0.006564825907844352, 0.12660969601711258, 0.06089818554755766, 0.04057656056829728, 0.005553576875172439, 0.07036477269139141, 0.033756123229977675, 0.042474766523810104, 0.03094567120569991, 0.035670530269271694, 0.03320130846987013, 0.048715007651480846, 0.018687942720134743, 0.022660473696305417, 0.08296971311210655, 0.03249148874601815, 0.03400353300094139, 0.05630003521218896, 0.007223435122796218, 0.10089157018228434, 0.07463514237315394, 0.057360664432053454, 0.024727816962695215, 0.08329522650456056, 0.033033772342605516, 0.027305696603434626, 0.0519458585040411, 0.060351649444783106, 0.035175191223970614, 0.23104237188817933, 0.08055957368924282, 0.15094393165782094, 0.15520279062911868, 0.15544781810604036, 0.12051491954480298, 0.12476485047955066, 0.12476624571718276, 0.1439119191491045, 0.15537878352915868, 0.09670490733697079, 0.14483751088846475, 0.07390869854134507, 0.11334092676406726, 0.13330527814105153, 0.11100253075710498, 0.13498935964889824, 0.09294454153859988, 0.13323413586476818, 0.21100517129525542, 0.12958673236425966, 0.07193124605691992, 0.18654860003152862, 0.1593149418476969, 0.07662063231691718, 0.18245662038680166, 0.17242092842934653, 0.10496665854589082, 0.08948072310886346, 0.2004671492613852, 0.1339238730724901, 0.13650984212290496, 0.08221628479077481, 0.155161690490786, 0.1114589961071033, 0.1428213479812257, 0.16471178038045764, 0.08197686052881181, 0.14586988283554092, 0.11450861449702643, 0.10530447674682364, 0.14890072488924488, 0.13730493461480364, 0.09354857553262264, 0.11409907514462247, 0.05683667477569543, 0.1782266903319396, 0.14753475756151602, 0.1830367126967758, 0.17140834213932976, 0.13321665086550638, 0.08533015090506524, 0.09842336512519978, 0.11832329808385111, 0.10818720838869922, 0.18499022349715233, 0.22709203854901716, 0.06530383019708097, 0.2301956556038931, 0.07454428123310208, 0.13576683355495334, 0.19148750376189128, 0.1274151192046702, 0.1452157538733445, 0.09134091626037844, 0.17729807063005865, 0.10670499847037718, 0.1710420032031834, 0.26878181321080774, 0.11251225951127708, 0.13591201248345897, 0.1698671982740052, 0.173717311990913, 0.15377433446701616, 0.17650328984018415, 0.12377473642118275, 0.12046386720612645, 0.12989977025426924, 0.12079272026312537, 0.14321161375846714, 0.1145557408744935, 0.1329177137813531, 0.14546599122695625, 0.08877546759322286, 0.19909807975636795, 0.15886439883615822, 0.11934927271795459, 0.1783108795643784, 0.1129528577439487, 0.20195166725898162, 0.13534426951082423, 0.12370092241326347, 0.14790296670980752, 0.11334493436152115, 0.10316597079508938, 0.1954630998079665, 0.15132535103475675, 0.20980148197850212, 0.13229594245785847, 0.10305286748916842, 0.0882222929794807, 0.15042744140373543, 0.12652374047320336, 0.18407313677016646, 0.182521216920577, 0.16811115812743083, 0.07284509702003561, 0.1392065841355361, 0.060369479542714544, 0.21861396613530815, 0.12846488709328696, 0.09543677733745426, 0.14369025448104367, 0.16691076394636184, 0.13980251387692988, 0.13182482711272314, 0.11783665700932033, 0.19550691620679572, 0.1808510284172371, 0.12883416493423283, 0.06405348947737366, 0.12056186038535088, 0.0996546697570011, 0.13612327224109322, 0.0671594962477684, 0.212263067078311, 0.15579391125356779, 0.12373766614473425, 0.14506845240248367, 0.17886523419292644, 0.14387697883648798, 0.10678695383830927, 0.14486621716059744, 0.11015418916940689, 0.09786783790332265, 0.21875675534829497, 0.13195687002735212, 0.14381116518052295, 0.08481278491672128, 0.2478766263811849, 0.15838933526538312, 0.11243827480939217, 0.0832554696535226, 0.12809617328457534, 0.12251790190930478, 0.12157456541899592, 0.0993434723932296, 0.18732697935774922, 0.2241677837446332, 0.08395118115004152, 0.09606332809198648, 0.12148780835559592, 0.14288042293628678, 0.11177054970175959, 0.15862443280639127, 0.12783612473867834, 0.12933541147504002, 0.15784504415933043, 0.16322629759088159, 0.18992920144228265, 0.165434394730255, 0.177364032715559, 0.08336118859006092, 0.12970356125151739, 0.1034269915544428, 0.1294846276869066, 0.21186370257055387, 0.265045307460241, 0.13763431459665298, 0.15276768535841256, 0.13085535960271955, 0.1017098844749853, 0.13672991859493777, 0.07301888574147597, 0.21576138795353472, 0.25039106723852456], [0.023456260096281767, 0.023064567540131975, 0.013482027243298944, 0.06665818291367032, 0.022620215895585716, 0.05144112386915367, 0.0007521731640736107, 0.029113377240719274, 0.03586903621908277, 0.012219889158586739, 0.021350482857087627, 0.044133644696557894, 0.02100187753967475, 0.02572899087681435, 0.07996226355317049, 0.053118448122404516, 0.022522272811329458, 0.08029302392969839, 0.031232030742103234, 0.05620159674435854, 0.059678079924196936, 0.09293213282944635, 0.030658975847472902, 0.03742604349099565, 0.04984770312148612, 0.035154373981640674, 0.08509414794389158, 0.02214562915469287, 0.03921766961866524, 0.03202867061190773, 0.04823357274290174, 0.006208842250998714, 0.036800628222408704, 0.02730618456553202, 0.024583138983871322, 0.018574240129964892, 0.01889079579996178, 0.06266541357035749, 0.038050809380365536, 0.039790911905583926, 0.05851411035109777, 0.06643428438110277, 0.08289074117783457, 0.027902767396881245, 0.02022261505771894, 0.06040813430445269, 0.061842794821131974, 0.0270519377590972, 0.02693292324693175, 0.01937327342602657, 0.05232927425822709, 0.043490488387760706, 0.048134024764294736, 0.007142496497181128, 0.05009572516428307, 0.01646061096835183, 0.019982584090030286, 0.1292888491298072, 0.013602973194792867, 0.05393085863033775, 0.02065731507173041, 0.0466275577491615, 0.08929506744607352, 0.046966021618572995, 0.04765275683894288, 0.05967862169200089, 0.05691171332728118, 0.052169883201713674, 0.04613460099790245, 0.05002163285098504, 0.014571667943528155, 0.02946508102468215, 0.04729331245471258, 0.022035856236470863, 0.015359825065388577, 0.0443731988343643, 0.08038629704969935, 0.028727319440804422, 0.025336810358567163, 0.0756629575334955, 0.07213820135802962, 0.0361829721077811, 0.02503268566215411, 0.039573663016199134, 0.05782112624729052, 0.04108723238459788, 0.021535012310778257, 0.02219420457549859, 0.04454924739548005, 0.024688076809979975, 0.07799571321811527, 0.08727197287953459, 0.06278696251683868, 0.03403862545383163, 0.0541331124259159, 0.0793692133447621, 0.037054327694932, 0.07697392429690808, 0.04906113419565372, 0.018089797667926177, 0.050325661068200134, 0.015068823395267827, 0.03881433833157644, 0.05034093446738552, 0.024038734700297937, 0.060290047476883046, 0.028612475798581727, 0.05415826009993907, 0.014334523002617061, 0.03306732112832833, 0.016523036720172968, 0.025524920674797613, 0.04587958050251473, 0.01744667846651282, 0.07580369841889478, 0.043596006944426335, 0.034080174591508694, 0.049514293277752586, 0.0749145238660276, 0.06913403209182434, 0.04351310162746813, 0.03850567540212069, 0.014663079200545326, 0.0404679324128665, 0.06864630006020889, 0.052864648459944874, 0.0558939060283592, 0.04530893944320269, 0.035103228874504566, 0.09361099757370539, 0.010410161121399142, 0.017600477440282702, 0.03523362051055301, 0.036950868598069064, 0.033467565081082284, 0.03323875724163372, 0.03649090031103697, 0.04649695460102521, 0.044501720258267596, 0.023189519233710598, 0.04823838185984641, 0.03221950646548066, 0.09696027293102816, 0.012304780648264568, 0.016490211528434884, 0.04691670590545982, 0.013952035860711476, 0.05895985537790693, 0.03107220367382979, 0.08287328586447984, 0.11244965193327516, 0.057446159844403155, 0.026802839602169115, 0.021391013397078495, 0.04272379788744729, 0.03353497806529049, 0.034655019917408936, 0.029967429654789157, 0.03172339187585749, 0.03648772391898092, 0.016064279989222996, 0.006351276624627644, 0.02728331342950696, 0.03225733744329773, 0.050270935098524205, 0.07722600959823467, 0.039752836019033566, 0.026803145738085732, 0.0707022866117768, 0.04180629926850088, 0.0268046355995466, 0.022409781777241733, 0.056338118520216085, 0.013965782291052165, 0.04055351317219902, 0.058344755962025374, 0.04176379647105932, 0.014943301175662782, 0.022164672664075624, 0.06024202681146562, 0.058259813449694775, 0.00962235373663134, 0.042297500840504654, 0.008973517215054017, 0.03639948627096601, 0.022816233795310836, 0.029347808704187628, 0.07866651081712916, 0.06995895149884745, 0.054270795662887394, 0.05941371950029861, 0.055146188533399254, 0.01676436088018818, 0.014448092006205115, 0.00420328370637435, 0.05786279412859585, 0.03838993747194763, 0.04752157852635719, 0.010340093103877734, 0.04162975346844178, 0.014685965179523919, 0.02696107290830696, 0.02077410499623511, 0.10678052683942951, 0.03175874036969617, 0.02576326882262947, 0.007276786263901158, 0.026093164597114082, 0.03210482609574683, 0.03574619593564421, 0.07329990738071501, 0.044313986581983045, 0.08013853104785085, 0.05573415503022261, 0.02338988797419006, 0.04016039012640249, 0.038997960509732366, 0.05598343501333147, 0.054704454814782366, 0.020034567824041005, 0.015314334195863921, 0.023296883882721886, 0.024840280166245066, 0.027961077939835377, 0.043773524957941845, 0.07551145550678484, 0.04627492256986443, 0.03806367079960182, 0.026353764187661, 0.010005233289120952, 0.04567959396808874, 0.032687271013855934, 0.037426815324579366, 0.04166840823017992, 0.093486435507657, 0.0922546187939588, 0.02223665356723359, 0.013160857270122506, 0.04217796311422717, 0.025095248711295426, 0.02212543346104212, 0.1179397339001298, 0.021905735484324396, 0.05852905349456705, 0.06073838259908371, 0.09357651739264838, 0.023788400867488235, 0.04108049368369393, 0.022111130419943947, 0.020568845502566546, 0.0217731860539061, 0.020443285247893073, 0.01765686767612351, 0.0408214470371604, 0.037945598814985715, 0.044794705318054184, 0.05512033952982165, 0.03195627410605084, 0.04067069086886477, 0.0481007468624739, 0.04427484942425508, 0.023903456021798775, 0.11326334264595062, 0.0434504309669137, 0.021184288161748555, 0.06412327362340875, 0.03469268020126037, 0.020199938735459, 0.04558273998554796, 0.03284632810391486, 0.004251185628163512, 0.028194023252581246, 0.03059613078221446, 0.04389129637274891, 0.07589623681269586, 0.001338460551778553, 0.04300796252209693, 0.041877319090417586, 0.049294669515802525, 0.04791871288034599, 0.03691118967253715, 0.04899418505374342, 0.0038932774896238698, 0.0019323187734698877, 0.09324066588305868, 0.03843837374006398, 0.07063381606712937, 0.04784197109984234, 0.04080318278283812, 0.06437228643335402, 0.02252050649985904, 0.03025688765774248, 0.032248520728899166, 0.0337285413115751, 0.028895072646264452, 0.04454066445759963, 0.03833212787867524, 0.016511145659023896, 0.011261794134043157, 0.03926544537534937, 0.03939066795282997, 0.029217982955742627, 0.018296326234121807, 0.012889399131381651, 0.045301083810045384, 0.054823447062517516, 0.014511976078210864, 0.047681637515779585, 0.012424957549228566, 0.02569926971773384, 0.022418221851694398, 0.02571865090430947, 0.03821276826784015, 0.013456770102493465, 0.035322344265296124, 0.047752764949109405, 0.05933723005000502, 0.027393680065870285, 0.031385840848088264, 0.07910101601737551, 0.03170086769387126, 0.09703608331619762, 0.006254230611375533, 0.0661555930855684, 0.027489981148391962, 0.004402069353091065, 0.05052820430137217, 0.04187412414466962, 0.04011780198197812, 0.03088436980760889, 0.012766147883667145, 0.03182567466865294, 0.04179450283118058, 0.0639219066943042, 0.04870829863648396, 0.0646332923497539, 0.03875071030051913, 0.052397644612938166, 0.02546022766182432, 0.012887976063211681, 0.044054542886442505, 0.134071204229258, 0.00857612682011677, 0.045790077492711134, 0.026697690263972618, 0.0632774701807648, 0.016999085491988808, 0.04917045254842378, 0.012313537063164404, 0.03273474248999264, 0.019356823722773697, 0.02158935236366233, 0.16176159493625164, 0.1301381629309617, 0.1504617286263965, 0.23493512941058725, 0.15206343174213544, 0.07800301595125347, 0.06336125865345821, 0.09198708197800443, 0.13215275248512626, 0.10139281672309153, 0.2129633427830413, 0.18131671124137938, 0.2372761006699875, 0.18227080145152286, 0.11983793243416585, 0.0809457576542627, 0.1329459747648798, 0.15230865217745304, 0.1917795537156053, 0.1711858611088246, 0.1447553254547529, 0.22380049485946074, 0.07333551562624052, 0.10033555314294063, 0.12879229296231642, 0.13369892811169848, 0.16636500338790938, 0.19999723619548604, 0.1225717001943849, 0.0925844737503212, 0.08062237422564067, 0.10196355797233991, 0.15919453580863774, 0.09607754021999426, 0.19123284320812672, 0.11774309445172548, 0.1812510163290426, 0.2093117980984971, 0.09358295181300491, 0.1624846991035156, 0.1026705426920671, 0.11287181521765888, 0.24342623393749818, 0.2221086950157769, 0.07661678799195215, 0.11895134797669016, 0.11813736040494405, 0.18191452603787184, 0.11426902696257457, 0.2651216002414003, 0.12919946486363187, 0.10928320465609431, 0.17530500335851684, 0.08924930662033148, 0.1367193800979294, 0.07591188870719634, 0.15274568810127676, 0.29976710211485624, 0.18859115371014923, 0.14943475951440632, 0.14192895992891863, 0.09738990222103894, 0.10460066099767573, 0.11403355092625134, 0.10838383299415, 0.13020255166338757, 0.13111438398482278, 0.19888523180270568, 0.08075171572272666, 0.12908615375636145, 0.08498511902871542, 0.07452058445778675, 0.09814452540013008, 0.1923801441444084, 0.1185206722584553, 0.11341214325511828, 0.1692758995341137, 0.09830994269577786, 0.11226521339267492, 0.13581902137957513, 0.1304218711447902, 0.08661302737891674, 0.12462418380891904, 0.09554796590236947, 0.14827868639258668, 0.1458299849764444, 0.22382258117431775, 0.14653575257398188, 0.1871026132721454, 0.16333034669514745, 0.21408551459899172, 0.1536746195051819, 0.21368140034610406, 0.09871391594060697, 0.1242736897256691, 0.10066819857456721, 0.0866295030573383, 0.1738393062260002, 0.12962796608917415, 0.14027122466359288, 0.10474536495166831, 0.10496296265046112, 0.11594182782573625, 0.1415324304252863, 0.08889689779607579, 0.15108332183444872, 0.06004355425829999, 0.10022951508290134, 0.0958317557524424, 0.12962642242200673, 0.1497789824497886, 0.17892914795083925, 0.09229229763150215, 0.08954630669904873, 0.1359029731247574, 0.0993137493787799, 0.049691158201312646, 0.17587733280379325, 0.27492180874105543, 0.15702142351074144, 0.13535054808016866, 0.08959383383626118, 0.11255854726186953, 0.2248876669909805, 0.12500250100856647, 0.11612461879849434, 0.07300646961084567, 0.07459591986844316, 0.09881021702312864, 0.12570380087709054, 0.09643694007536396, 0.11847382789710537, 0.16923987568588927, 0.1273270114324987, 0.09326689338195138, 0.1626588960061781, 0.16201290098251775, 0.1331625334569253, 0.1215975423110649, 0.12643719121115282, 0.14789257664233446, 0.09950982479494996, 0.23159200645750389, 0.09363200035295449, 0.1432342195766978, 0.13296397926751524, 0.10132541487109847, 0.15099361102329567, 0.15846169466385618, 0.14751982555026188, 0.15786861476954073, 0.19294484431156889, 0.19419660995481536, 0.14979229657910764, 0.11833313154056668, 0.11233518307562917, 0.0823441642569378, 0.14695739635499194, 0.13052100723143667, 0.13137539732269943, 0.16208797664148733, 0.12081410153768957, 0.08126391636324115, 0.08461301360512152, 0.13825146976159886, 0.21808209858136252, 0.06876453160657547, 0.09408350815647282, 0.18178681726567447, 0.14153565134620294, 0.12709940958302468, 0.09482714754994959, 0.095861768204486, 0.12759397679474205, 0.12088993418728933, 0.10314929473679513], [0.01659399345953716, 0.07204676876426674, 0.024725690709601622, 0.020516088079602923, 0.0475588677363703, 0.01771613744494971, 0.0385937794635538, 0.1013108910410665, 0.03575115719286259, 0.047605300205759704, 0.02312506185262464, 0.03910501531208865, 0.012929174536111532, 0.0057248650227847975, 0.020312633860157803, 0.023068311675160658, 0.0059501467330846936, 0.05323287616192829, 0.025979395213653333, 0.00661952311929781, 0.03945094518712722, 0.0515286267909687, 0.07645741177839227, 0.044147014486952685, 0.016529057393199764, 0.05613579422060866, 0.056972877428052016, 0.0690819630108308, 0.05102304981846828, 0.03877553142956458, 0.036148733124719, 0.027669341543514747, 0.017514438404759858, 0.05544384170207195, 0.031779001001268625, 0.033582174946786836, 0.05006378312828019, 0.028271303090150468, 0.03453629484283738, 0.06178417999763042, 0.08983166248071939, 0.02186325680668233, 0.05154142141691409, 0.027688078916980885, 0.027027766009268817, 0.0624926935415715, 0.04343658991274424, 0.01757207173795905, 0.038779680035077035, 0.026597492906148545, 0.028863323568657506, 0.040404508472420275, 0.03232971910620108, 0.017378963057126384, 0.06944508844753727, 0.02916536839620676, 0.011547271442395868, 0.020489407870627474, 0.07885676037403755, 0.045271568596945144, 0.04082635263330303, 0.014737440542376135, 0.02219115434854757, 0.048446635919390246, 0.03851222856610548, 0.042890250479104, 0.07499726591049694, 0.055798276589484885, 0.02239188674138859, 0.060650326777249575, 0.06966022963752039, 0.030436899287451524, 0.07242564999614842, 0.07498375882278197, 0.04296001236070879, 0.08838641151669435, 0.033271671491093, 0.04557575266517233, 0.03785430351854302, 0.014803584454057273, 0.04602098932082299, 0.04551577600068413, 0.04148865264141932, 0.03554946000804193, 0.048234300047624856, 0.028925430196977686, 0.030996550995041616, 0.05808512301882729, 0.03604533711040858, 0.03482347630779259, 0.04279522217984777, 0.00967772537478595, 0.08829987709759735, 0.03308380051748827, 0.0179226084947004, 0.05862356971192639, 0.04404944433190394, 0.0247922019843827, 0.05131004945724271, 0.06994113253313117, 0.035798587850877084, 0.03101685430010548, 0.03563790174666792, 0.026159646185988095, 0.0016423527472397836, 0.022591259148612153, 0.0675378653977532, 0.028640977980103344, 0.06775941874366254, 0.029861228322261013, 0.07619189360411838, 0.030472323851427063, 0.01528711871287669, 0.021871283133805264, 0.012978987488168059, 0.05112296887091361, 0.029033050886937417, 0.07351840307819657, 0.11122547191916965, 0.016716397731215693, 0.0386836572579341, 0.017034849588526413, 0.0898138880438637, 0.017799964880396146, 0.0703628282644786, 0.13369778520427644, 0.05432899859442841, 0.028969435843464453, 0.027811468389700167, 0.040127713364199735, 0.050192568014608696, 0.028981581090192776, 0.05414388098870404, 0.08453859103610739, 0.025218649316229858, 0.03275780843978282, 0.03705776012793649, 0.04317719445680268, 0.018762357867672108, 0.041868687912938185, 0.048147587513085455, 0.005358834077924257, 0.12160769489128143, 0.017583254048076924, 0.030796757419011556, 0.017557729734107852, 0.028770094977517147, 0.04983763959899079, 0.0760657804494258, 0.008106411351036513, 0.08257175126345828, 0.06936892183148302, 0.02955563788418658, 0.027081692314823158, 0.029696347228309605, 0.10872505023144186, 0.01536074069008464, 0.03787421534070745, 0.042916125457850285, 0.023222876916406676, 0.027896093633899, 0.041394474101252854, 0.0465765202534385, 0.03383352552191354, 0.024904301535570994, 0.04590792683302425, 0.03361598348419648, 0.0860792599269189, 0.009139163648796966, 0.0739736290415749, 0.025894100181176327, 0.036293043740442954, 0.028803651184716728, 0.04427746549481526, 0.04233368796121795, 0.022090118363848887, 0.03928013247787021, 0.0466770664206706, 0.022292103130894247, 0.055648436973569915, 0.05206859117606655, 0.00999719304672908, 0.039881810153019615, 0.018249548666062765, 0.04576615436235443, 0.0651440532237757, 0.03158668456308078, 0.025727541833475698, 0.00811997224445804, 0.03339612223498989, 0.04241618138621561, 0.02505221898900345, 0.023144990373111796, 0.024781823049124796, 0.00942792681598803, 0.011389214396331226, 0.0747319110087119, 0.036637522716773674, 0.013820043968735263, 0.05682506387529429, 0.046856027911417186, 0.016421189939137548, 0.024636150592414197, 0.0287287406536052, 0.020123595859331544, 0.03567135405319277, 0.03467451242613606, 0.017003375105559826, 0.016360305999114644, 0.047728700810694136, 0.029845361204934306, 0.041118380322586745, 0.011433225608925568, 0.059186388534726575, 0.04458323775907047, 0.02839538276020903, 0.05197084661631379, 0.004996828820367227, 0.013510065582522657, 0.044937052953173406, 0.03155868704197928, 0.06908268289407715, 0.015763875308039133, 0.027016520616598427, 0.024032808651099913, 0.048249480678350665, 0.06170819891849533, 0.04631911375327036, 0.0829665144556202, 0.029994647920830175, 0.026828222908079624, 0.023975284784683026, 0.026513544871704653, 0.022736410246579908, 0.043710282843676396, 0.042074322191183455, 0.023393737865262665, 0.006145710531200166, 0.04644646629458293, 0.03984602750279009, 0.014791310259170132, 0.04115076764719561, 0.02802152401272906, 0.09147082921117544, 0.049633352318778634, 0.007853949409764027, 0.0766085872601252, 0.04058824939420447, 0.027506740698299836, 0.02722539251408307, 0.04685750478529371, 0.020919667986163404, 0.006818267947892309, 0.04522318056842778, 0.06090020418923814, 0.010492376241018064, 0.014262760105339112, 0.10872483500861563, 0.016116558726935182, 0.041147654337692074, 0.05133249571372289, 0.03244799518142827, 0.028348321320663672, 0.06344300622004084, 0.006591515857508057, 0.052738290396519005, 0.006485030653493595, 0.013716707326238975, 0.040569632619735785, 0.027612624762696214, 0.010281180493620923, 0.025660820901975967, 0.040229721562354825, 0.010467688698554412, 0.04029173913295381, 0.039127843774622306, 0.049025195694412105, 0.023391396389342844, 0.041444175731157884, 0.023681908241997007, 0.02254496212117374, 0.023839844689064194, 0.040416304909740575, 0.0315320810477715, 0.017735631809046026, 0.03488907474093139, 0.02581998003734043, 0.03528583431034349, 0.07748470001388341, 0.01889084218419157, 0.04246202384820208, 0.05622884098556824, 0.03164330672007054, 0.05003554811992217, 0.06646129855653271, 0.046287275617942214, 0.02310047078935895, 0.032605760934529826, 0.03841021294647362, 0.0444984436762752, 0.03607585793361068, 0.11737803943105973, 0.05706295560230501, 0.06035935664840508, 0.020308724597271066, 0.054675329229212366, 0.071417279104935, 0.021743906472693197, 0.04859138440224342, 0.04438285788637586, 0.01381686201057164, 0.07390135127934627, 0.027416369375714567, 0.03929873069864698, 0.08988932735519484, 0.049284709893981926, 0.018735974517767318, 0.047982600663090125, 0.0515181587979896, 0.07876907562604174, 0.026708655495895073, 0.054179244325496256, 0.018576640977698844, 0.03452151497185696, 0.0652852987695951, 0.01879070419818163, 0.038306212081806734, 0.05031447690271307, 0.021511968625418376, 0.033804804406827316, 0.020499623533396516, 0.02877806193282595, 0.05946507983026095, 0.039518476914963685, 0.025076314668694977, 0.0382968350459123, 0.004685466792579973, 0.027545812918106094, 0.02848935535439523, 0.04154524140176363, 0.05557520184083842, 0.039774443648639135, 0.03733921592356637, 0.02510693382646423, 0.02036909088928951, 0.06165662707644515, 0.020014991823700257, 0.05027555496781133, 0.013612060793093406, 0.049359139884472825, 0.0053568089424516074, 0.021837925451109186, 0.12418130718288012, 0.15624674007995054, 0.12762341037159786, 0.08859409412252717, 0.11441406488302164, 0.08995677373604849, 0.1846873085014522, 0.14016689354320988, 0.09808043352677487, 0.14853052678517997, 0.09980697330320254, 0.15485632640775293, 0.11188006843440235, 0.10598331922665238, 0.1113411653204821, 0.121424978133291, 0.112492844928056, 0.11319394441670738, 0.11591206028242595, 0.07989276142325252, 0.167395549651701, 0.11452727208961733, 0.20629400300094858, 0.08976184864877723, 0.17200710688484833, 0.08832938488922082, 0.10099498846102506, 0.14027604862349108, 0.10581317445030436, 0.15577627782477066, 0.12796564435120672, 0.09443448463571258, 0.1575915265129879, 0.11935654576518573, 0.143546856706962, 0.17426247883122414, 0.2029266266617924, 0.1278858634759672, 0.17645790008828044, 0.15810319280717522, 0.20745436573633924, 0.07347649399889633, 0.20680399204138666, 0.20306925260229036, 0.10401213789009489, 0.14714254735736176, 0.20884727302473038, 0.06973232928430662, 0.1170556059514638, 0.1715793478069827, 0.11271977142314427, 0.12322910944931209, 0.15797800733707845, 0.157335351977963, 0.11250159484916367, 0.08989718669909053, 0.1034591042844113, 0.12514496367657557, 0.15515082544879988, 0.18775807810015976, 0.16041458206018433, 0.06689451984129846, 0.20380872854730114, 0.11901975914952345, 0.2058857327210717, 0.2294928120682016, 0.1585934407194145, 0.13606951106339693, 0.0961145140172448, 0.14259016897995025, 0.14194473798852414, 0.16878591879503801, 0.2286389414803125, 0.14919936511432752, 0.13239923457149416, 0.17254627717193216, 0.10644063062500209, 0.0955826613062527, 0.1423872064333409, 0.09669079910963774, 0.1286851119948551, 0.22143639827845618, 0.13051674730377272, 0.21511678816750646, 0.19131572626065463, 0.2075079339556396, 0.16872390493517742, 0.19814921426586807, 0.09056045892066322, 0.10399680511909537, 0.13712111947825179, 0.11010168222128414, 0.18278672767337412, 0.10538839880609885, 0.07025509068625979, 0.18560723023256287, 0.14077161031309515, 0.13797442603390664, 0.114089397538919, 0.2155454971943982, 0.12394493314786814, 0.07804871740518138, 0.15678104187827557, 0.06613364035729319, 0.05822480634378735, 0.06741961900843307, 0.13684732635738328, 0.12896289787022397, 0.11078632829594426, 0.12620078749023378, 0.14667995186755434, 0.10306451178621501, 0.34352950227912515, 0.11929778251214884, 0.11474593848106451, 0.28464608069043607, 0.09255567099899054, 0.19624326028861105, 0.2800338703673333, 0.11086023136158474, 0.12253299719304778, 0.07561471793451346, 0.12389850438921712, 0.1635508387698792, 0.12813932175049558, 0.24624525220133364, 0.1220373464457225, 0.16312441555783153, 0.14680393505841494, 0.1348932960536331, 0.1280899837729521, 0.11451512313215062, 0.11876945500262082, 0.19501892442349344, 0.06736449227901176, 0.19779253809247166, 0.0941025219799485, 0.18033672007732093, 0.21429877815535292, 0.15471058344701305, 0.13247772410977632, 0.18719103274634108, 0.25485366059001535, 0.15741051669465378, 0.0986294521135278, 0.10565966862486675, 0.09927628576406278, 0.10534459725022316, 0.16939422755967826, 0.08659385028295219, 0.10363824389060028, 0.14574063039617613, 0.16821479162899777, 0.0922817294485867, 0.11527684866450727, 0.1895488507580012, 0.13240797707112506, 0.08518967719282955, 0.1099974253156688, 0.15658355638151988, 0.12444145220797509, 0.10155905038118362, 0.16552196815609932, 0.11149041121825576, 0.12882957846159115, 0.13657696195878088, 0.21343956410419196, 0.13213917118264362, 0.0977779935055878, 0.15265109395841137, 0.10426489854580723, 0.2535101358080283, 0.0829380530922208, 0.17389265180099756, 0.06053386896383017, 0.10150212765438482], [0.014107618771959096, 0.04603509012667928, 0.07973557454533875, 0.011176226362294983, 0.006546644217451103, 0.025641343236202374, 0.03892485525284428, 0.024401925074926112, 0.013366165003390051, 0.04742197859741282, 0.08206254147808068, 0.03666400625661481, 0.0702054261637386, 0.055359626494464464, 0.08186749764718115, 0.0643146141374018, 0.05507811874849722, 0.040665284323040396, 0.04176612681476399, 0.0368045467621414, 0.014154944601614261, 0.005092603441880783, 0.040650823575560935, 0.055919610313139856, 0.00896076619028463, 0.05645489916787483, 0.11231983546167612, 0.04038533879793249, 0.044378675884217955, 0.07689942009164952, 0.05459145912027452, 0.06028701951436233, 0.04700077639427036, 0.04188996157608926, 0.01612725121958647, 0.02498545538401231, 0.018702596426010132, 0.021545695526583586, 0.01483139365518582, 0.06175730311952066, 0.10157272816286422, 0.02314737081178464, 0.011768538133765105, 0.0789417585474439, 0.009840178718150128, 0.03884394631313626, 0.03889847190293949, 0.11900349869392812, 0.0406389900308568, 0.0357259687007172, 0.052823188379989006, 0.06149592612928245, 0.08536462366464548, 0.03309187508421019, 0.06610467433347367, 0.049718365335138515, 0.015018720077932812, 0.03882762277498841, 0.036362471655593254, 0.01998786818148801, 0.029029705656284932, 0.032157403547898866, 0.03912094922270626, 0.04933632255415432, 0.03152047756884713, 0.019636993747553788, 0.020112697420699988, 0.03790774928347673, 0.05233641371887643, 0.028470792385633104, 0.04482597942114808, 0.06629829324083403, 0.04115233357879333, 0.033353819817421027, 0.035389144977671094, 0.03839214536128566, 0.008545611563022248, 0.009257937890652101, 0.028802050001104362, 0.02073202522296924, 0.03310595733637456, 0.0699847485520877, 0.05446929790196009, 0.05839200479385909, 0.0807761398027651, 0.02546739866374992, 0.026454260259924922, 0.03918300018995069, 0.08695742100826465, 0.027451988753455225, 0.0248120099058724, 0.010537782691244502, 0.08210990534280427, 0.033849285027827136, 0.04881790642684791, 0.03312451844976749, 0.023137735879572574, 0.05159657041076571, 0.050351677055004984, 0.0516612188948784, 0.019345877044543158, 0.05150636607140768, 0.026280614401912317, 0.04514595268119592, 0.02338620321097551, 0.08292593382066116, 0.060230853778193705, 0.05798399055493064, 0.12269521583220921, 0.03133455102215521, 0.04200877570838202, 0.007067885144351749, 0.039560786754009314, 0.14224743033992127, 0.013778400207229424, 0.0797681622498203, 0.013882000312150922, 0.010910308355960296, 0.03949442019802518, 0.04487928046728484, 0.009227590544469422, 0.02843912494427059, 0.043593216469162144, 0.03920522751286626, 0.044147289081593044, 0.06609535295865498, 0.043721882611862384, 0.031202036843751557, 0.028068320134480018, 0.015794049177202396, 0.034262156623299234, 0.027452070389699657, 0.07450044999131933, 0.03719388485478703, 0.044487604609457776, 0.014496818639599951, 0.018923240641015582, 0.08478379662847146, 0.036613814809243195, 0.011379646257410059, 0.04071976167324465, 0.04143121783272363, 0.07772455472149886, 0.07022736404906027, 0.08645256762974896, 0.023622323060408235, 0.046007934943190776, 0.033562493190402165, 0.042695985903264955, 0.01601901454705512, 0.04930474045977462, 0.009174904553219676, 0.0647015031427145, 0.05095341410196852, 0.01990301472687861, 0.05325664715201128, 0.10305907926522195, 0.086442110768985, 0.04213467735098675, 0.05964623065665364, 0.09876229654764757, 0.026248811518598814, 0.0067370027772994945, 0.027304872819513548, 0.09603484446415678, 0.07769670191919431, 0.015028800298750866, 0.04920944869809318, 0.0789354502921924, 0.03252022470405791, 0.08919332642108202, 0.08930246665840968, 0.05703876158804633, 0.05903304227103945, 0.03369432088220492, 0.038363865824067034, 0.06140397774288431, 0.05431763631349895, 0.0495330807461869, 0.032285160559695214, 0.0405863606283674, 0.0765120264259167, 0.019885064029949717, 0.05273871713143308, 0.09629011357901618, 0.02573974274127977, 0.08560368427424692, 0.031178577555692755, 0.03975448358687572, 0.027956107405771036, 0.028954119770787656, 0.026750789074867498, 0.03606085912906565, 0.0742537749465555, 0.043773053694167174, 0.037924117350485176, 0.023341731866821647, 0.04674455733038485, 0.02818656652380014, 0.017400368451490067, 0.06748847546987236, 0.07689337900956161, 0.006464960661105579, 0.02660786256456049, 0.0030809432837486384, 0.06353443881380372, 0.09036165982251987, 0.0749318975431379, 0.010858247624128126, 0.057630564988357946, 0.010981291998177767, 0.060443683178164065, 0.017844250687630847, 0.008281099926534807, 0.01950739064341178, 0.01946730353665771, 0.07041054093861021, 0.07591754387249239, 0.038161066549946554, 0.04596887571096886, 0.019856162944051903, 0.01226002728799358, 0.019226218719268218, 0.10986816545482725, 0.06792652813601308, 0.03891702559485566, 0.03576274211809505, 0.028454750863602385, 0.0391137021506438, 0.005786493893538136, 0.044148231609142385, 0.030183192393451463, 0.07098436952219345, 0.01888345410407055, 0.025241782059310935, 0.06331998782115988, 0.026977131128660403, 0.04269168515747879, 0.10657619131961837, 0.013518511223082896, 0.05336423258995637, 0.02726057773543289, 0.015157985944824759, 0.024989867451949976, 0.034097195748472586, 0.045399856244330294, 0.055967074367799796, 0.047994571505114436, 0.029278111760504544, 0.024240175844170153, 0.03687049771542661, 0.01234541230587638, 0.03424443413678091, 0.06127119268057868, 0.05039051735366229, 0.06591679964913055, 0.03226326349249575, 0.02705174294533208, 0.020500209830061067, 0.05903461562411394, 0.062150941957952455, 0.015930066292639822, 0.03853722409985494, 0.019726773207366932, 0.06194273984874599, 0.0471045657468494, 0.028437803921406157, 0.10135684482520446, 0.029455446092470083, 0.030824404275335837, 0.05100023619888816, 0.03680658766825218, 0.016105764188978355, 0.05118126828165259, 0.03409619013837073, 0.02613515160192037, 0.028886215113743674, 0.029402684958768077, 0.04773013686644845, 0.05450473916425835, 0.03202334941306617, 0.011630301996774506, 0.06779207324143499, 0.07532709860242903, 0.07016123869107105, 0.0296872522085323, 0.017385378923790995, 0.04611850752553437, 0.03250225359806791, 0.04063084124936722, 0.04381743783596903, 0.04908925046038348, 0.048971074575092643, 0.008663100034027593, 0.03203735745046288, 0.017563587134645786, 0.0618151461094385, 0.0624069754849188, 0.033458418110967614, 0.024879652955860365, 0.05543007857340854, 0.06571858684765175, 0.03965044190408662, 0.04516884422628209, 0.02464952409354737, 0.031053824386617634, 0.028190112134325318, 0.06196922709932551, 0.05990725141600706, 0.04322723747463897, 0.05425341827503871, 0.009767321153049124, 0.0555931989219971, 0.02161421060009161, 0.022867171101097483, 0.014117931841610698, 0.00395069652768143, 0.0164167296316009, 0.067009352351306, 0.061853504012105986, 0.032005085158743896, 0.026708087752922438, 0.015504272050748114, 0.027152606380695943, 0.019178062611899804, 0.012925988867209526, 0.039083281517378055, 0.10182631260249764, 0.06688265289994888, 0.040859200089471415, 0.02095756946800975, 0.01934807009092765, 0.014526599170494592, 0.09252861971617676, 0.04583230198477395, 0.06920346000697464, 0.008427784487139434, 0.03252579452237114, 0.022424153466999996, 0.042298487896914594, 0.04105446285393555, 0.015614803814969491, 0.04395406722323969, 0.03724797999893781, 0.026067553080793004, 0.056742833912721835, 0.0679182902968023, 0.10462806108989753, 0.09939368610503152, 0.0162033343440271, 0.03010309796081856, 0.017449272272642702, 0.16291809850372374, 0.26033836940769106, 0.15239046653732657, 0.08589679549913853, 0.10514303736272268, 0.20865383965428919, 0.11509745672810823, 0.1279629726195708, 0.11514018216985278, 0.1428053027484566, 0.2134231774834916, 0.1384949981002137, 0.1448546099709347, 0.15556512196781114, 0.15500811045058072, 0.17978612071601674, 0.19264862348791212, 0.15171947597991675, 0.13857464538887143, 0.2549248473951593, 0.06557748973136768, 0.13424608390778303, 0.122025063901674, 0.16661335568642244, 0.1196636761596892, 0.3321650542784482, 0.19692915317136794, 0.10704862768761814, 0.1006515818880871, 0.1269527166732587, 0.15417479735333472, 0.1066374259244185, 0.09089116734685376, 0.14307893259683624, 0.18791617039823905, 0.15682082099374384, 0.17936677759280428, 0.11864423984661698, 0.14711937750689685, 0.1744039767072536, 0.232093223312404, 0.22550764231709763, 0.13536166545236483, 0.12273372587515041, 0.13534269615774974, 0.10700709710363299, 0.1943570325965993, 0.1835865105385892, 0.1293877328862436, 0.14124806912150234, 0.1638490188634023, 0.23271420795936137, 0.16912888007937, 0.10243848795653321, 0.14020379312569275, 0.13188458484364673, 0.10770963635877706, 0.20024903205921873, 0.07604302620165981, 0.10091859920066781, 0.1425691958866082, 0.1818628577166237, 0.23556355037726462, 0.13208015559939668, 0.15135402762098238, 0.07366191217442974, 0.11320920297293924, 0.1987042516702786, 0.12294640313484706, 0.12761735444655642, 0.28315611532889307, 0.1485481156851165, 0.10028251926996745, 0.10701062230509706, 0.12695526966126636, 0.19483346171909943, 0.09811564843403175, 0.1971456376486458, 0.11272161194938235, 0.17253703001188114, 0.06902264314703643, 0.14557878283085302, 0.15904517116723582, 0.13288240239489824, 0.2746449876576662, 0.13213243248173967, 0.12409290255163796, 0.09188387892208993, 0.19169750186847523, 0.18291804328327999, 0.07760765904095024, 0.17520698049338534, 0.17312518204562366, 0.10843484822544269, 0.22020958364009857, 0.10867095508729108, 0.08971030649263412, 0.1285648246994242, 0.19951231690356508, 0.14390770375030115, 0.13296590885147452, 0.1597005024086684, 0.13661911594681442, 0.14266233542002738, 0.0881022283283528, 0.1318193500628695, 0.1352142749237828, 0.13051932997768745, 0.20350720878923312, 0.16300675546517596, 0.10707839523092844, 0.15470308775547892, 0.154340325971134, 0.15780697198351845, 0.2023001352790743, 0.18181138235377148, 0.17914848227519542, 0.11302807441097684, 0.10182070938753895, 0.13495067891199142, 0.11129890743177384, 0.1281190908048302, 0.1936890700017102, 0.18307260295841843, 0.22019987634848803, 0.20886946324026212, 0.09715207357658073, 0.152791092696134, 0.07733590682619251, 0.10925881026196294, 0.11538140242919326, 0.14877018111292273, 0.07708616671152413, 0.1256435681716539, 0.08365045548998751, 0.07422538779792376, 0.15794388338690624, 0.12224001955473796, 0.13799268286675215, 0.10319567896658555, 0.10864814146771096, 0.09679287410108373, 0.13646707957377657, 0.21866211667656898, 0.1460327100357972, 0.1596586749656126, 0.1787805848289281, 0.1495121803600341, 0.16908838850213215, 0.06139545046607964, 0.11262347034062259, 0.17785629926947877, 0.17641221347730607, 0.10216646114713512, 0.12909134879009798, 0.10201817261986434, 0.20400631794473156, 0.2015008867601864, 0.14512132300296798, 0.1388376031536609, 0.18781080027110875, 0.1316405666875653, 0.09659341449150816, 0.15455298096640036, 0.1826744110439904, 0.24408407363807783, 0.11382030221284367, 0.1551541205844842, 0.22018087736796588, 0.16504642961081117, 0.15868196409428492, 0.2744490606710315, 0.20639106107410043, 0.16888603451661766, 0.13627977634314448, 0.10292860970366746], [0.01485015514845145, 0.02314108296559425, 0.010292851693520788, 0.015779510504216887, 0.07709800396696664, 0.046375813835766166, 0.02703010934055783, 0.029600823545479216, 0.012534400211734464, 0.015243175221257843, 0.038277223793556914, 0.02533070248318836, 0.04337745929660741, 0.027113519317936152, 0.019763086493185256, 0.023718275333521888, 0.09051545508555137, 0.04280806504539214, 0.041392537095816806, 0.022335034518619068, 0.03638230555225164, 0.026078251139551867, 0.020243447143002413, 0.034867207359638996, 0.03908499958924949, 0.009428956545889378, 0.029670733856619336, 0.007202370188679197, 0.05587700361502357, 0.031816238260944374, 0.05656668516166974, 0.10352955636335537, 0.014655085342383245, 0.08007668046047911, 0.00842569163069129, 0.04747050392325036, 0.005469558800541563, 0.062183878471842036, 0.049288769441773184, 0.05239290228928439, 0.021952809911454096, 0.013932070232840488, 0.008991851045720978, 0.0504464641562663, 0.020386642681842204, 0.034747881145449355, 0.03593499459384475, 0.06743043210008182, 0.032299035010510124, 0.034683021149248816, 0.0693586356646847, 0.023420577635988593, 0.045269100955920294, 0.047278013080358505, 0.05644446086080279, 0.024341128337255213, 0.03797454628511332, 0.020735286962008104, 0.03160218802804593, 0.042530368227744475, 0.04941490486089606, 0.03087405024416512, 0.024972683022497222, 0.020108674980292562, 0.11503393630846404, 0.02238330380350817, 0.059887844254262745, 0.03555692972440738, 0.03214716933143791, 0.06592085919692181, 0.038663292725686915, 0.08049747077166103, 0.02650670227012597, 0.07435488514602184, 0.03622139680373948, 0.046841003131703474, 0.011638193809631048, 0.05166659946553409, 0.05642471231112722, 0.012463744042179314, 0.07588042906718329, 0.03139334396109916, 0.01861916418420151, 0.05284453996864613, 0.038690948858857155, 0.046944113419158384, 0.04817348104552366, 0.009098493956116727, 0.028426727367332205, 0.016431913973065093, 0.07404874180792831, 0.02547037467593327, 0.016303138363582548, 0.041469067364232615, 0.08462967482046224, 0.009099417929974152, 0.05763181179645471, 0.020646039993152954, 0.025931487725756597, 0.07012816859059967, 0.07980699883773923, 0.0965546743827872, 0.046325882140081376, 0.03345322307723109, 0.06370813105604611, 0.057036820871871896, 0.07771420176140964, 0.0583512794401031, 0.027378482736821752, 0.05098734509374481, 0.05373991887609009, 0.06415767958969809, 0.06550290388986468, 0.011789296004280914, 0.023282593829208054, 0.04370119895611424, 0.031990305287763476, 0.02346349232539069, 0.023388724657706916, 0.10153137569432147, 0.04429893953783903, 0.0342738714243751, 0.01832950580137549, 0.05083326039311942, 0.04209306513075717, 0.0667172578687314, 0.04671656723076012, 0.024488260969519615, 0.05858634729520418, 0.01822832509787986, 0.0736125667754095, 0.01826798546971986, 0.05086897253931966, 0.11447124736150727, 0.01173094371551997, 0.03805360356636811, 0.031275951041607186, 0.08967503963503987, 0.07815155680873431, 0.012239728621352697, 0.05814873249619268, 0.038932031820877455, 0.05527738539967686, 0.043479664163896814, 0.04540145928331185, 0.03184906345268246, 0.02149854688468622, 0.03909681829100009, 0.05941302559222095, 0.008956500696513103, 0.009983634008676745, 0.028301436141191516, 0.045675148503505625, 0.03699182401760481, 0.024789064555079676, 0.009454879764234647, 0.07552506649517454, 0.03747547794773709, 0.03381383263331372, 0.03968996497860644, 0.09686895908089355, 0.039331756270257756, 0.010986089055222692, 0.045102292133378796, 0.028487982381193433, 0.059302326844772324, 0.04869566357228905, 0.020786929308087565, 0.04146450686675962, 0.017679664597380906, 0.07275437688804232, 0.03613314802350942, 0.02015785896219313, 0.04480198578676209, 0.014028877831151476, 0.03529188281390816, 0.05047658421972301, 0.0354070047615096, 0.06184159625263419, 0.037372419610619545, 0.012604899602592923, 0.019787746205111034, 0.0096975889573514, 0.027276767686998937, 0.058800586775760166, 0.037798512566951104, 0.026967010089720134, 0.05768843766418286, 0.033057639811886474, 0.06650479583186097, 0.020602407275873702, 0.05479450701386668, 0.0578641337051522, 0.051402213066467084, 0.01973736179934349, 0.030452439859800506, 0.12009248908725567, 0.03195219971530605, 0.028284105137572624, 0.05276457726722583, 0.04727573097625282, 0.04623663888196461, 0.026334490612498485, 0.02449686060572276, 0.0323842484067427, 0.03385222764336504, 0.08260021262685768, 0.06036400249286089, 0.07857527860323898, 0.07944166180095635, 0.02161593052733224, 0.027937310660490766, 0.02995204307808308, 0.042757038681884296, 0.08949854207457975, 0.01946480064361822, 0.02894883196859155, 0.005652426307278802, 0.0113262106970069, 0.03381058944796678, 0.037387258853414096, 0.031988386836019345, 0.04642011634132359, 0.03381736154551618, 0.06150763721961994, 0.02947390701592667, 0.05403987270256039, 0.07552824288723059, 0.07767598115606233, 0.08631981225335039, 0.03540454083122313, 0.024642469979880843, 0.046560489863622934, 0.03779938087973278, 0.044498885254142806, 0.0710466134478338, 0.02073622206808068, 0.015283971079043113, 0.042434156202943996, 0.04499861410295125, 0.01833197344240034, 0.040673960029380396, 0.031244342972058803, 0.011378109084034804, 0.0333199853048427, 0.0487997609161539, 0.025375448421982583, 0.02956432286737254, 0.045842098334105685, 0.05997129876050167, 0.010412344890937675, 0.05042878619860858, 0.04751871012558695, 0.054141027430887334, 0.10046765542938374, 0.021632986936310772, 0.041198814287781715, 0.027711554903362412, 0.02090027937811101, 0.07940237250295468, 0.029244902507343795, 0.018398696229269262, 0.08758683645282872, 0.04331378673668951, 0.0661739835049957, 0.010816422036441509, 0.06930863717570901, 0.018865110068873037, 0.03550496454408858, 0.05125163872435223, 0.04665850901801605, 0.02418076135654701, 0.06733356698532589, 0.015111020984477364, 0.019075917116424534, 0.01951197897142265, 0.039530102658318356, 0.02503665800759336, 0.02631636365549639, 0.044628445684793405, 0.02165767076803604, 0.0471729546552524, 0.04023785179015249, 0.02610528201330453, 0.015964472258929163, 0.004326942671468714, 0.046233581233536825, 0.06332503442536108, 0.03916328503692057, 0.04869525168032851, 0.045833285330445506, 0.044323972178972326, 0.042958631966030225, 0.04317850063671358, 0.02739157236646861, 0.026635707945388276, 0.038305581256281585, 0.0654354204016272, 0.018489883914298844, 0.08238056660047732, 0.049415476314607076, 0.08887143470929004, 0.06994087278144434, 0.02679495984921232, 0.047218407489708625, 0.04301092369132675, 0.03331173262267839, 0.054104317096062005, 0.02155731384846149, 0.030144430020300206, 0.046436759002972394, 0.026703208131948486, 0.032196303218370304, 0.09360233671031892, 0.007242328811116749, 0.016581664531258866, 0.009165084084088448, 0.03224696221877821, 0.035485954431351274, 0.026737350635812618, 0.10794939458719455, 0.017813813356042374, 0.03544263156072702, 0.029168758155719843, 0.019142033197567798, 0.02597722257632995, 0.030455423293460626, 0.04693613162089605, 0.07853137314668857, 0.06017006075126119, 0.02309686580701964, 0.06494288667454384, 0.024589842432760634, 0.04380522950668819, 0.06810438382672146, 0.03919296352250967, 0.02655413292814046, 0.04351420371676795, 0.018085111005348153, 0.05356945126550272, 0.047657643881393597, 0.07957322231959552, 0.0623277660633903, 0.04353543285105843, 0.06380683669704013, 0.030705042809131555, 0.07512319352827035, 0.033690506243146956, 0.03707713018229697, 0.032274351178784855, 0.0404382761917077, 0.04574709601001814, 0.14334533392684534, 0.10399961785878986, 0.14412944263312966, 0.135863134637475, 0.20296891423640773, 0.11031342437490821, 0.11930552311241627, 0.1174152729799971, 0.13573978969361633, 0.1287874096306041, 0.11697342793922871, 0.17313956486759707, 0.14691769145429134, 0.13184047158574685, 0.0574940654769307, 0.10811517553520389, 0.20313563029048964, 0.1622601252165623, 0.09970166996936314, 0.10069069307064638, 0.28786486422177404, 0.22919224225915968, 0.11540508436155505, 0.09112870655371808, 0.12981789652258158, 0.12264200384379365, 0.12291738516069017, 0.23561475856695324, 0.17436087277019396, 0.15284311724826694, 0.21422088233521208, 0.1837035026983358, 0.14546127116773278, 0.16713584249373525, 0.20505253836745396, 0.2050459777819924, 0.1287692566984333, 0.13325457461178303, 0.14753526222193614, 0.08823363299597986, 0.0974198553012684, 0.09393955377163365, 0.08141465397784486, 0.18468273687176406, 0.1372866629390046, 0.11789410666096956, 0.18618013855302706, 0.14494035771349445, 0.09942665972630493, 0.09134673469816335, 0.1729038736084476, 0.12088057570508681, 0.11382570504792966, 0.18646448501385748, 0.18183795124059543, 0.23463776567950845, 0.13136343390215188, 0.14394216908840463, 0.13007125089643523, 0.1496760465670377, 0.13373578316532075, 0.10516905706026591, 0.12122912536142394, 0.11949186155106872, 0.25450767134316266, 0.23806685901945457, 0.12783291866071522, 0.0762740641948767, 0.08406708235270344, 0.1484243551385589, 0.1484267003252171, 0.19654835719848052, 0.13147135701728985, 0.15722325799288228, 0.16702045337297022, 0.13192754035117105, 0.1047146919881925, 0.1070385864295531, 0.17212424747413024, 0.164708782103844, 0.1257801233441569, 0.21441257908008993, 0.07688455487368628, 0.22398393892217427, 0.20791065297089517, 0.06645318688242696, 0.20227270550094545, 0.16677288775099441, 0.22786721179727465, 0.06304223905317485, 0.133909638680052, 0.10662154396413825, 0.12810024025384337, 0.0934545899508521, 0.18026918463874608, 0.08030211523873731, 0.11843085012515076, 0.14155570417642593, 0.14226864092051983, 0.21921627834672108, 0.1297683359007351, 0.1577200516476296, 0.135618626663927, 0.12321480084210634, 0.07428766140947118, 0.08450638924841769, 0.10418095422210172, 0.12012622712063603, 0.08712565846508369, 0.11837662881589495, 0.1787286196486093, 0.16706030670320615, 0.1483130775159225, 0.13165232230676338, 0.24881717981770635, 0.1538981543853879, 0.16326404322171584, 0.11869667257997207, 0.15352621965575963, 0.22049603780033067, 0.1327125693205744, 0.1633597951149568, 0.10684112319722772, 0.22223865991691127, 0.11460495268693194, 0.160546253900975, 0.18906065117334947, 0.09358601688290946, 0.1404598043882288, 0.12534244917333126, 0.15901238308288157, 0.17745233344612643, 0.14243651472497731, 0.2269682928454131, 0.19813497987342998, 0.10852318606339395, 0.12157804609159939, 0.17486758151790127, 0.23774844798026606, 0.12584233016241342, 0.12809293752070516, 0.13100123615004122, 0.1659723775810562, 0.15464140044059604, 0.15799881715793163, 0.13464075804222375, 0.13197439955547452, 0.11505435279104859, 0.1108554370875936, 0.15974057838320732, 0.07476660641259514, 0.09642594886827283, 0.1402996340766549, 0.10816345966304652, 0.09677613867097534, 0.1512181997532025, 0.15264704183209687, 0.1052625454030931, 0.12527800106909126, 0.12923109519761056, 0.3192154678981751, 0.1258924845024012, 0.2119392977328971, 0.12026375450659543, 0.15046915010316297, 0.17534442624310032, 0.23187442333437502, 0.20218897640006617, 0.17350762558635324, 0.11182893445948139, 0.13713717955397442, 0.21159440686460584, 0.2349544846219942, 0.1831853945623152, 0.10635776983690448, 0.14247010432882234], [0.05539254445466213, 0.01579325136845, 0.01456327889172826, 0.049042810569517314, 0.049683525212458335, 0.03807964923908003, 0.06442823694669642, 0.02744203284237301, 0.050224825463374145, 0.04224137963319663, 0.02683402464754181, 0.013458868525049184, 0.055420011340174824, 0.024707847624085844, 0.014223422567738453, 0.05935710476478562, 0.07846460954169743, 0.020388902521517593, 0.03700639237649739, 0.10031108453404158, 0.02919560720329173, 0.043957503366982564, 0.025679869977466296, 0.02295824931934476, 0.015647491709387396, 0.04501870404055808, 0.014557543945556972, 0.03246952859626617, 0.03190003044437617, 0.027093626049463637, 0.10625147202517837, 0.05186471949855331, 0.031138828126131557, 0.023655957193113863, 0.07212467942736112, 0.12201250676298514, 0.08154920535162091, 0.018146488473576028, 0.07683610747335479, 0.01514685558504425, 0.04650371185562108, 0.04404554063512478, 0.023655432123632636, 0.042577717249514535, 0.05155288759851828, 0.01577362527314108, 0.0475188103155233, 0.01027542884912691, 0.05784464119642507, 0.09807643335079774, 0.02950260772195179, 0.016706141250324436, 0.022642252115474548, 0.06334973310003988, 0.05149963850271888, 0.021593961100734305, 0.04987306230759714, 0.09657109811087139, 0.05150598015461583, 0.07823473672033288, 0.05692630023986567, 0.020314945650170557, 0.0654342255438678, 0.005218563064772752, 0.04049091301567387, 0.027967636669927742, 0.015080029825185193, 0.03427098075917456, 0.0219743878551526, 0.02982710622745799, 0.044594407081604004, 0.006591564560949337, 0.055033255921443924, 0.02053045049251523, 0.03933169318770524, 0.05153412239451427, 0.041535292912158184, 0.01807945027394453, 0.05632845946820453, 0.013392056680459064, 0.009745256174937822, 0.013890219597669784, 0.04417988791828975, 0.020108491298742592, 0.03028141934919404, 0.05700519795936998, 0.05312731307640206, 0.09298294025938958, 0.027343210313119926, 0.038580235268455, 0.027734919567592442, 0.07051692780805752, 0.03471417279797606, 0.06043067704013083, 0.04226296870911028, 0.033472099603386596, 0.019606741952884477, 0.03840686957119033, 0.051838005892932415, 0.022145202419778798, 0.05646604622597806, 0.06348270369926468, 0.03992726298747584, 0.0528445028612623, 0.042836956854444, 0.03866857681714464, 0.049787288589868695, 0.056989104487001896, 0.013935395054431865, 0.02456780435750261, 0.025555176180205308, 0.05759842628322076, 0.02520645397453336, 0.014077871637709904, 0.03004999914992368, 0.041512390234856866, 0.03815053547441494, 0.0897990599332843, 0.01970247714780271, 0.018074763611366507, 0.011984412194578908, 0.024073404129012488, 0.023567020070913713, 0.02539516171964351, 0.03151841439830605, 0.027479975142341573, 0.019394602750253398, 0.08707226836122572, 0.04501298208197113, 0.06310060154646635, 0.04725183382106479, 0.04842938840738498, 0.038537045984412543, 0.006517924030049471, 0.06218503251147922, 0.054700321052223444, 0.022908057871973142, 0.043998989422107115, 0.036849869720754214, 0.024617852941446472, 0.06099009311583359, 0.022536978467542212, 0.034290914845769294, 0.11231415061047301, 0.03720122840604745, 0.08831408180412836, 0.029305641728569753, 0.025253381827496924, 0.049931239263969474, 0.011598204109759536, 0.07666864927159622, 0.02429688520351192, 0.0050410932908562245, 0.09380383722600527, 0.079205903748516, 0.04071620678587351, 0.014411136762646493, 0.08309570752317086, 0.03620849827711936, 0.01003956689601182, 0.031066416777321137, 0.12017513465252705, 0.028794103454856668, 0.06637851940467954, 0.02354729007493006, 0.049750693287933245, 0.031678588420618325, 0.06567277407157235, 0.04660364204028156, 0.03517098695738241, 0.027060238680860493, 0.07984927156940103, 0.10704120621085167, 0.03611630498198792, 0.044284630930633284, 0.05406823016528506, 0.0289094257823308, 0.030356142488017213, 0.05858766831806861, 0.029393777331279125, 0.01497978608313133, 0.06055228164768778, 0.04185689889709465, 0.09654164969106205, 0.011714198080881033, 0.03308319937787019, 0.0396181992982747, 0.08635599195258692, 0.10128642243216746, 0.009972741136152763, 0.04670868562243413, 0.01258432634131168, 0.013200439716456458, 0.02330003429960925, 0.05050201390986331, 0.04961790080415085, 0.0319533834408503, 0.06312082507065497, 0.0251021376971039, 0.014233582569431746, 0.04314302968850825, 0.029204487000242807, 0.04046123081934638, 0.02988658565300284, 0.02959077672130661, 0.04538011140539311, 0.025235822613467462, 0.0630018810625188, 0.026370911509729922, 0.07045964142889716, 0.04818996414542198, 0.056287715560756624, 0.009573958286637207, 0.06307948744506575, 0.03219731253921054, 0.022140389592095744, 0.021991793073539156, 0.038605742884101346, 0.05767534988990519, 0.02727324619627325, 0.03425099843298085, 0.08815826789941639, 0.02373736151639605, 0.03668008488602936, 0.057246722499257885, 0.01532544043584494, 0.05365212280594278, 0.004756114612973761, 0.058258169592591, 0.012280088467377936, 0.026346331578679383, 0.021119678640388884, 0.047632236455683596, 0.08290615558507852, 0.005411302990978584, 0.04696546500781551, 0.09194894300890155, 0.051873992633773014, 0.0687984329124447, 0.044464412494562566, 0.056493052979931235, 0.065751374932006, 0.06739316886523739, 0.058993103593820706, 0.017576634090801235, 0.016648463388264645, 0.04248426601407118, 0.02518621189665282, 0.04891207383479923, 0.04818329594854731, 0.030021762286196463, 0.038611219933955, 0.04039900544739794, 0.02623119107738603, 0.02706744122406235, 0.09882341240881942, 0.026661549527489115, 0.019615298915596213, 0.042428760789334774, 0.01416295886883745, 0.023326016889768653, 0.06133200797194149, 0.018341009090363514, 0.06294037186307833, 0.05035703907196876, 0.035804465660476126, 0.02739205661782762, 0.07701999682467431, 0.03157011611619964, 0.07125075600924902, 0.01835057537391549, 0.03508933215925936, 0.02517465480195824, 0.02735132940870244, 0.03575794784410391, 0.04463981538719963, 0.02546181029174477, 0.022957995133765507, 0.0387003221840132, 0.020933061896357685, 0.04132354704779573, 0.05946289049461484, 0.04765477548062336, 0.03309409410576336, 0.015368880194728263, 0.03586895087209996, 0.020225309053785168, 0.08498648458044045, 0.024147949152393267, 0.057901460022549145, 0.036523476883303374, 0.02523349226976279, 0.030396574693440925, 0.03021069638634799, 0.06060151201381814, 0.020857364688708913, 0.01678533953963779, 0.01885401496110717, 0.02643658601300558, 0.016540273099963088, 0.06282566551817581, 0.04402345060952939, 0.010151744372706162, 0.08069759831414558, 0.04171760519966483, 0.056110806108335964, 0.030440353984886315, 0.04962690676620696, 0.053227651442284696, 0.027752447240345646, 0.04962195293046534, 0.050385140493744984, 0.10374696110375226, 0.019944456253142562, 0.07481928405468352, 0.06658884405624121, 0.040501432958990335, 0.014487869266304187, 0.04846452167839743, 0.05901103017095011, 0.02440630745695671, 0.03335249137307983, 0.07125681935576722, 0.07145710274926387, 0.04014589598227758, 0.003421793157940556, 0.035111811812384985, 0.015259343836078187, 0.026350187035859562, 0.06834250190877356, 0.0874324920005165, 0.006688117973681074, 0.1167371949122753, 0.030016034761501942, 0.08598851010901853, 0.042753962479764596, 0.033756319899111986, 0.02563915761129465, 0.03357324319949839, 0.04345080575149041, 0.06327917712042108, 0.03149752665194683, 0.06206596975971479, 0.019900005318049807, 0.06392351715476252, 0.012741344380629016, 0.10426943306811154, 0.03891945612849668, 0.06101402366766706, 0.04107363252842333, 0.015802630259713624, 0.02839008011505939, 0.14108938310528174, 0.14882377901813015, 0.2631700783967972, 0.09585711493855342, 0.12134817327023484, 0.11264848813880235, 0.13924194005085155, 0.10966394867864437, 0.1652070600539446, 0.09956608701031655, 0.22409971395973116, 0.16100013657705858, 0.17974856804357842, 0.07677482833969407, 0.09425860305782408, 0.1331162976566702, 0.10965031542582437, 0.043484139314386994, 0.12132196803577244, 0.21207718877121806, 0.19301600143080577, 0.15687597740907222, 0.10504768622922711, 0.09649227460613474, 0.11522040833369829, 0.0887315027648583, 0.13812054006848484, 0.09830402777879499, 0.13025145919527858, 0.1269040466286242, 0.18513872724724934, 0.13582096580648795, 0.14776314608752728, 0.1434735770453699, 0.13224225549492985, 0.19792052888078615, 0.18332419102080166, 0.12854664208134636, 0.11517414284753613, 0.169239979586564, 0.10664582703611813, 0.12003417854430154, 0.0784693518653512, 0.08512778207659721, 0.11414004911785014, 0.15421004936797544, 0.2159073535585776, 0.12476909556426108, 0.22610232525039464, 0.27132930932566524, 0.12460888072382659, 0.10914025959209539, 0.11922552701435052, 0.20801620121346787, 0.08872469727066346, 0.10284465053700842, 0.10409019698272459, 0.16122046537930146, 0.10929747615591623, 0.14330660866107792, 0.14715868164785206, 0.06903448782395571, 0.18667023803573102, 0.11937181916437112, 0.10574844432994723, 0.14118218125076964, 0.1633786308229901, 0.13777441723505035, 0.15559152758214623, 0.09682338379207067, 0.12149879956268705, 0.12158053970779292, 0.1825466428999789, 0.11662210265058093, 0.17276117345318198, 0.14414590346859768, 0.18279901763889939, 0.1812762493500486, 0.1140102771751117, 0.1460573641816154, 0.19142114091664553, 0.1103461159800645, 0.1471299011609517, 0.06618079642066732, 0.1279647389310412, 0.13366093015065417, 0.20639046735595912, 0.1271688746055588, 0.12711918039713055, 0.13609852903755382, 0.14795522874919698, 0.20306202408391982, 0.1040727342478931, 0.1474154499010183, 0.12612344085937366, 0.1062230700335931, 0.1798745698761195, 0.14816775015788153, 0.13903370825573802, 0.14008607366122305, 0.20642093993956223, 0.13258355436846614, 0.16208062937948853, 0.10847885016119108, 0.13786571624223143, 0.11053499998524785, 0.19685731327626854, 0.13921057689003646, 0.14759010693524033, 0.12182742255390622, 0.12826048478018492, 0.17564815760124475, 0.12124216489610262, 0.15923753584502265, 0.07702398957917467, 0.09551905925036408, 0.09299273660872132, 0.15891213377472013, 0.07885343555244617, 0.12522336415713653, 0.1546502171549946, 0.14863533288007602, 0.07544509266153909, 0.09750501674716361, 0.12858998350566253, 0.1648656275938265, 0.10397032528999262, 0.20652847713790834, 0.1305003309971653, 0.1856492506340146, 0.08852443614159711, 0.18668634264031425, 0.08502830460201949, 0.07632548018591478, 0.17046726919943467, 0.24584351282101125, 0.12776884163031355, 0.08389038441237062, 0.2001871369429864, 0.1957158010918647, 0.21693457500077784, 0.23692025570198894, 0.1341904525179416, 0.19925243163015693, 0.14281894342275336, 0.2190457921824418, 0.12288860467378981, 0.1473870553309098, 0.15642319311155006, 0.1052676142717246, 0.13726568984566256, 0.08925078349420801, 0.13856293429853395, 0.2672075992450118, 0.1764924990129657, 0.08104759515845217, 0.1343498658388853, 0.21507772151380777, 0.12176882999483496, 0.09689441474620253, 0.07199767569545656, 0.1596280836383812, 0.1109982114576269, 0.18080584646668285, 0.13697727641556412, 0.11860100232297555, 0.1702767302049324, 0.1542479731142521, 0.2277696639066562, 0.0866837021021638, 0.1803079099045135, 0.12620583409443498, 0.2133043299545534, 0.11780281507526524, 0.2267741470132023, 0.14106147835263982], [0.039861141340225004, 0.02031656538747484, 0.03437391293118708, 0.058589660984580405, 0.053936725307721645, 0.08019789544050582, 0.08450022200122476, 0.020824548773816787, 0.012863133597420529, 0.07046882179565728, 0.07203184417448938, 0.021714179747505113, 0.08517562833731063, 0.08734281087527052, 0.029615095045301132, 0.05775303790869657, 0.03400721776415594, 0.050585702192620374, 0.0037775096416226006, 0.06199898722115904, 0.022540839490829967, 0.049742099217837676, 0.05934984656050801, 0.02358946261665551, 0.03815886979282368, 0.02055652399576502, 0.08010019912035204, 0.044888843040098436, 0.06051343763829209, 0.01998149869905319, 0.06856623716885224, 0.02435487291222671, 0.01289178513616207, 0.03511918133881409, 0.05505725697730668, 0.027447797474451363, 0.027040881614084356, 0.03653041225334164, 0.04479639741475694, 0.03309771949716378, 0.03296097136626486, 0.02702389199839672, 0.01933207495312672, 0.0116095877274347, 0.03565053681086283, 0.05614874098682776, 0.046569039404857904, 0.015281090618373128, 0.056025978628895245, 0.03169903458910994, 0.021271768819133285, 0.04780722003488336, 0.010246728143101791, 0.06502112388261594, 0.02030214174737921, 0.024736824780120514, 0.015420540166815044, 0.05851262234500609, 0.0748224530252628, 0.07916426926385611, 0.038123473059386015, 0.03455223988567013, 0.007908664247224806, 0.0710061144491192, 0.02250775640277425, 0.05127670105139259, 0.04441647346538957, 0.12821617856388912, 0.03799744154093787, 0.04044493325636722, 0.04370282797026448, 0.030365532511495985, 0.06377504309057258, 0.05274884373648092, 0.030757141576032154, 0.04923723099636845, 0.037832621674169786, 0.047773203696124256, 0.026457314197614323, 0.021258489941828884, 0.012740955680783372, 0.03200609076884575, 0.055962884944165125, 0.03257224183471408, 0.029581705821328796, 0.026090995670529082, 0.00687592586473329, 0.04871161603659857, 0.023239317342813592, 0.046160264464560896, 0.05933021675446071, 0.07701029695454054, 0.0241990664289915, 0.04285507638996933, 0.023121531085052993, 0.009564964384480845, 0.038918053469387814, 0.04238854380673729, 0.04587657851516269, 0.01653704104683129, 0.08853033621562645, 0.0052359038090799, 0.06568746117409319, 0.06897410668898374, 0.06276686515775509, 0.008898149335436756, 0.0629758316790685, 0.09035659095388837, 0.009940737872966565, 0.04945462460455019, 0.06543352792505175, 0.02022898454015376, 0.0376225419313414, 0.023040655541990418, 0.03711720615683589, 0.06300820416072384, 0.028784147543774452, 0.05763636116171256, 0.07005853287409991, 0.0655814008496236, 0.03801284481596667, 0.04406528176332358, 0.05360642877349164, 0.05486403140821494, 0.0065880170950549655, 0.021600276777462568, 0.03999145876150578, 0.023554676299681887, 0.07418052497087047, 0.034898581652669236, 0.01417409572241013, 0.05169338357518427, 0.06919916297192685, 0.054781500875833444, 0.009288097844546428, 0.08177504831110127, 0.056570651941001415, 0.03778091253479943, 0.031096837410586886, 0.036919906196999364, 0.04651975708839018, 0.08422879633144476, 0.04460011419723742, 0.014403728273464367, 0.014512035450024996, 0.0318678212352097, 0.010458062115503708, 0.0593956185184652, 0.00900495922905975, 0.027105134904559236, 0.04366915673017502, 0.024122974027704913, 0.061264197938726284, 0.03288067469839007, 0.04462425997189712, 0.03877606206515338, 0.0755701593880076, 0.03371465572854504, 0.017056531432899646, 0.06708724817144684, 0.034761788992909715, 0.03195990691892803, 0.0316492476122221, 0.05733172067266423, 0.00916521210456267, 0.04513089079409838, 0.018579279312689323, 0.06982129052630626, 0.022956946850172244, 0.04168780425970908, 0.02179757117119152, 0.0268728463925072, 0.05910654457693454, 0.016564257457503118, 0.02300734424352413, 0.03986108938988764, 0.019378403521841392, 0.04517689652857371, 0.038664246385451406, 0.026748193413368426, 0.027466174906294327, 0.04774557724886108, 0.18848507112124935, 0.011333271304465597, 0.02440252992528258, 0.012979406801605364, 0.03946616292523686, 0.04139127544476651, 0.05492716591106728, 0.04184741424978711, 0.038543242917512543, 0.047445901727769524, 0.010925899950962048, 0.037949157413095236, 0.08339866704773158, 0.13272407260956243, 0.03184900037012994, 0.05236572484136559, 0.014900120240781689, 0.07612959030666389, 0.040028139410424046, 0.07619653944857419, 0.014105540758464485, 0.010720684058469487, 0.01729926938423887, 0.047287813140428625, 0.04360938044555951, 0.02367348857660545, 0.005884807587790419, 0.05449605974717997, 0.06341764703392982, 0.026516979160078336, 0.019365736916370224, 0.03959057285101153, 0.03776146826567128, 0.04818297311430797, 0.011491869190649595, 0.024845916777849197, 0.020643880343413912, 0.052983169443905354, 0.03789187845541164, 0.015082596728461795, 0.03364782161952462, 0.027068936651630793, 0.047579677557223476, 0.07531491995905526, 0.020175807803752832, 0.024800254286674317, 0.06270285492064431, 0.051844685222022235, 0.12452999042579904, 0.04120248791878112, 0.06260624213609844, 0.05459476538817398, 0.05721424240618944, 0.07820188184268773, 0.08520018600393087, 0.07325811704504304, 0.012521396856755018, 0.048727364410297014, 0.0403316221490968, 0.01786519595043501, 0.023481031130359042, 0.10926293660304509, 0.003598490866352222, 0.008623392350273207, 0.027948420611210167, 0.01912540537887253, 0.05976860338705592, 0.015162167946982663, 0.06753077788744122, 0.01919739370350726, 0.02805805066600442, 0.012049230444972636, 0.03139691740216222, 0.0496853471850045, 0.05881976387172472, 0.010090559862874215, 0.05229927664913703, 0.05360304086934775, 0.031124243068916257, 0.016546030310564674, 0.08204395810025744, 0.04391154587210622, 0.006791562691432773, 0.01267162795556942, 0.06320916290860623, 0.0479948015708942, 0.034681425531744026, 0.01803158360417001, 0.025234714958060067, 0.04148599946347531, 0.04125458297494333, 0.029204195707279723, 0.013173682509659557, 0.04184771481959615, 0.03649395795946475, 0.032759856767370366, 0.029933472687844187, 0.009275136235373793, 0.015420912168337964, 0.007578173826914281, 0.05099875561427325, 0.03620712159317918, 0.023125592488213442, 0.035736792924581096, 0.02668750057637226, 0.03212250776414294, 0.05998236047162209, 0.03637320682173595, 0.021140887365618255, 0.04193231594399549, 0.03558152078767307, 0.04906154237687588, 0.04038441111333668, 0.009167711286863778, 0.056752633972791955, 0.029317013286345173, 0.03080428094108356, 0.02676059099030681, 0.027327181778673548, 0.040250056408694945, 0.02972326492454158, 0.07367911515757442, 0.02837156724126544, 0.025750630047696177, 0.00636532687167346, 0.014569898849003948, 0.04503825221036095, 0.03383719544217456, 0.038116496871225536, 0.05020598604460247, 0.023622150511073414, 0.015708511091361288, 0.0370189383829711, 0.02068362977297511, 0.05486812806339003, 0.04327603368437849, 0.04428368469234556, 0.0270107726828428, 0.036306265101302415, 0.026935732275887858, 0.0351279869209975, 0.01930458951392211, 0.043456609346321784, 0.05170668286154978, 0.038594002107856795, 0.067777994700009, 0.025678237252577674, 0.045204689959064126, 0.0457212544279173, 0.024115778905979823, 0.045779806168866344, 0.022858437878312543, 0.025758847477845848, 0.04098575853276998, 0.03500383303617127, 0.035650919016916305, 0.06795705266995355, 0.029394003686320502, 0.05422947659099009, 0.04259584049577825, 0.017599551611056086, 0.022975884603511076, 0.03819973244389985, 0.020003946810902562, 0.020214796531945467, 0.05657920519297477, 0.03524257081153337, 0.05133969083544798, 0.025044984904525336, 0.051264837820781395, 0.15180253714788705, 0.13905888190492988, 0.16587180172791705, 0.1688618998741731, 0.11964277728111483, 0.1893569907406345, 0.38843860966153443, 0.0898436778516043, 0.1676861004671082, 0.15584388747811317, 0.19921526487451047, 0.1153537054779008, 0.23527273238869384, 0.15337808697950095, 0.13271690346300602, 0.09814258839469403, 0.1354463296593167, 0.17113401467213407, 0.1935198306455277, 0.2936136885546148, 0.0923732882074546, 0.09594303337507881, 0.12643257505260408, 0.2173935784958303, 0.1178331021219492, 0.22640347393462434, 0.18907426216173917, 0.09383347860421054, 0.24675083288457245, 0.14554522291291505, 0.17559821106260642, 0.07369279293925501, 0.1378261746140197, 0.12562302552396432, 0.14291849511209875, 0.0935261181439273, 0.08533200627425686, 0.12491776258684695, 0.1638999895658344, 0.17668645188678056, 0.1571964070899412, 0.14395123813301325, 0.1671688532223925, 0.12404486333252862, 0.08715967851458117, 0.09669122955529019, 0.08653379569295794, 0.13638401840580627, 0.2322757471119985, 0.11149446334457025, 0.07555865609901957, 0.12039076565997675, 0.1339134681620635, 0.20112730446271598, 0.18287011538632214, 0.1383766849176027, 0.11853312549646944, 0.12564671487780288, 0.18541823490522802, 0.21385454339906573, 0.15008140762802213, 0.1838562812190503, 0.11579083045944571, 0.14324348157970235, 0.24077890411717817, 0.15369211934739724, 0.10675185025320388, 0.16847495891852304, 0.07936508700367995, 0.1748526346636936, 0.1969411165919155, 0.07556155789643526, 0.13271173811517656, 0.15498413908062503, 0.12511265056673437, 0.11116218898678198, 0.14348221564432606, 0.12698811711743474, 0.12089928524801508, 0.16513388429302722, 0.0971334901987575, 0.10664175264537334, 0.14525857579428703, 0.18341071059694514, 0.1643301235162653, 0.06643095213803463, 0.13718329661060125, 0.12565229582833126, 0.07173249890911393, 0.11559514838154428, 0.10326759307645261, 0.18729705596342683, 0.12915704370243475, 0.1445472420891747, 0.11162147449795157, 0.10288701232639141, 0.09329723980044946, 0.16595333407167345, 0.1719204685650766, 0.16135268640937284, 0.1113155389612075, 0.19640384620288387, 0.11303934021270834, 0.24673015665030107, 0.16136463498696685, 0.07759877553326078, 0.14775467076105997, 0.1579366548685357, 0.13882427418138832, 0.11028520049876533, 0.13453040068270639, 0.07603604259202257, 0.10863824863918126, 0.13475829939125106, 0.20905553450575098, 0.10755397088360041, 0.08560984409996308, 0.15148304257309064, 0.14887503173667938, 0.10267379329889081, 0.0845160816970747, 0.11306184955174103, 0.22908474958967417, 0.14048281096620485, 0.08911937882658094, 0.18297642061952502, 0.16978401836240664, 0.2609339577611536, 0.13640095421578735, 0.1839462443604134, 0.08541053291992284, 0.18260386248584837, 0.1908915740204975, 0.12660445645451546, 0.12730327754979953, 0.11742344402591698, 0.2362476769485511, 0.12851783190853894, 0.14106003858614713, 0.15782387810759246, 0.12863565527368337, 0.12753399641951546, 0.18110310629708692, 0.12297016670345329, 0.11547993737622164, 0.1642914130934514, 0.17574123776284978, 0.18613768770592287, 0.0805193418636918, 0.11386333193513565, 0.15250962576828897, 0.17371858848491684, 0.17630301386816427, 0.07589559114421718, 0.12975058372830972, 0.14521435863571241, 0.16176745790289715, 0.13453175139147788, 0.10333117286791094, 0.1360900982399471, 0.0873174071602989, 0.12532330176327378, 0.1513392143533565, 0.18532086513005197, 0.11545087487320416, 0.08392030038521625, 0.12545938196126372, 0.1349701380240731, 0.08810645857010968, 0.11517440259922296, 0.08610896809841506, 0.10855562533834018, 0.09856780932750553, 0.14235532376915216, 0.17343916988465935, 0.10811388419824652], [0.02719344491197262, 0.020832100126426667, 0.024827060660754796, 0.017908696936501656, 0.03708372787514236, 0.02599675219244091, 0.052181820647092536, 0.028188650103402324, 0.06761668890248984, 0.06402395942131989, 0.02811445574479876, 0.04681933241954539, 0.0769572556600906, 0.07268175773788244, 0.019138674979330972, 0.026175285092904232, 0.06206853016919922, 0.05006156410672702, 0.046996891251183115, 0.016072220969363116, 0.015355899104179116, 0.07230784147395752, 0.024148351767507847, 0.029719984631810803, 0.04339885912486352, 0.05541021870158147, 0.022688677163387183, 0.05060175113612786, 0.03952261067752261, 0.028088866492907982, 0.051315355813130736, 0.020395615247252863, 0.038723002217011526, 0.02015602029132424, 0.028722282113449182, 0.011636019316938473, 0.019310632451379206, 0.02011995191423921, 0.024308447864314076, 0.046326123338076286, 0.02028204624366481, 0.03785166518355254, 0.00895074255822692, 0.03887292717990931, 0.04274698629160412, 0.0049094580936071, 0.07722351598204114, 0.01491234805143904, 0.03633786203863565, 0.1033287460450083, 0.031204077749862336, 0.06590761928237043, 0.06172160581627395, 0.020568372383422684, 0.05633674925775267, 0.06007359639625065, 0.025196060196321923, 0.02221985505457269, 0.004903454582745326, 0.08761989913182333, 0.054197731224121526, 0.06339623607345857, 0.024766625720076263, 0.040246167554869317, 0.018711320371949114, 0.05424063107057009, 0.03583372483262792, 0.07844570704037324, 0.04435776216269005, 0.06057388185581658, 0.043044550402555615, 0.06841423048172146, 0.01839261247368995, 0.016258713403658476, 0.044733734175679274, 0.06563280941918492, 0.039926713798195124, 0.07632670472958125, 0.06927955982973799, 0.03632694875705056, 0.011250637799093965, 0.060103931682533585, 0.03854093483823817, 0.08985400854726322, 0.03384118448593654, 0.039295272290473804, 0.07210694951936603, 0.03125609116978012, 0.08423371677054092, 0.04101579324924387, 0.025644959350756835, 0.014193448150763288, 0.013999568564031506, 0.05494035758601967, 0.042106305045308545, 0.04819167479581665, 0.060974125808570534, 0.004146700512137613, 0.042014475402538665, 0.051595535114756785, 0.05060154704551678, 0.04963733765180223, 0.02476542900694767, 0.021319073312042747, 0.03357741406944115, 0.06709403882268816, 0.017158502523670904, 0.04387188178952783, 0.047822274500504136, 0.054394597027567215, 0.03407310934562702, 0.005230184633546742, 0.07003160775639117, 0.03785353539569769, 0.027242892356298398, 0.09382849137182347, 0.0642353601870127, 0.009770525375643047, 0.05136211111675948, 0.03054381308174925, 0.004303471787352464, 0.04602866312779952, 0.05096590815810487, 0.04452349487110041, 0.021866499992029276, 0.032223443558905274, 0.060553539587999694, 0.039714036538498476, 0.014869925962557318, 0.04131554298510309, 0.059552200546022505, 0.012376553750073072, 0.044544293559738435, 0.037297792950994335, 0.005812631870867335, 0.031224902413669042, 0.04458592433365993, 0.07575244570034556, 0.06934375560376793, 0.056964647010318004, 0.0584876119683031, 0.10455554584041238, 0.07242920488351956, 0.04842361820919905, 0.025374461365572643, 0.018069631660182495, 0.0602383568912046, 0.03247882399591617, 0.016842256700329017, 0.061683121748501435, 0.04201835683488753, 0.009559351892676204, 0.0410976966668386, 0.032256906997645274, 0.0548084890760947, 0.03579545969842002, 0.00914075184482499, 0.035662889858940616, 0.03679593042761553, 0.05641935029416345, 0.08386958943447098, 0.05444416878162883, 0.04173935383732896, 0.0273680258760578, 0.01661650836467743, 0.026844127132790163, 0.025666889814601745, 0.020753181997861248, 0.04355521479737945, 0.021910724572080653, 0.003953641462430824, 0.03194894168700557, 0.0291557316086255, 0.05042772121669259, 0.07941679985378869, 0.03047645019250922, 0.05933642853051424, 0.03806715518294368, 0.02427084509690758, 0.059172673645662144, 0.09703180854558013, 0.08355950529221445, 0.10200680291745812, 0.012784907521563582, 0.045216349099064246, 0.044704322863253765, 0.02874062800401589, 0.05992924496240448, 0.0326675373071339, 0.026059565716423094, 0.07715751678915694, 0.045236843507154845, 0.03737213759450242, 0.019821910973405465, 0.03981517642387189, 0.010610301651468035, 0.023899518928374164, 0.059410350149846636, 0.033174119889736176, 0.051581924126367085, 0.029389680676104035, 0.1102160026493948, 0.013044459756201832, 0.04135154085815884, 0.03347486039274372, 0.03263805920141749, 0.026346383529016748, 0.04805339041922707, 0.04070694849360734, 0.02790346130495891, 0.029224960999272298, 0.01503041075920919, 0.023155614217102993, 0.043782786960946396, 0.02045409091806505, 0.049481048772577196, 0.10909183445619419, 0.10859320769668557, 0.09524344044621103, 0.007143361099224421, 0.0048860702372621745, 0.02087466600642074, 0.030521177577611525, 0.03892618740792386, 0.010937829974864144, 0.07893815913121216, 0.017815154787967913, 0.107185123488307, 0.008968441852630349, 0.05267186075798236, 0.036289121489971876, 0.05406215197581332, 0.04495063054491766, 0.023414608913299162, 0.0032781444451757125, 0.046033924954826944, 0.02053955107840011, 0.0035409730298852082, 0.03954435189370997, 0.06662046696874313, 0.018327809993934352, 0.03637396381236613, 0.033903873700182885, 0.01780708393198438, 0.020814173549297266, 0.009295765157730784, 0.05153200727363583, 0.01854191217717016, 0.04152740759309381, 0.05559023033129051, 0.004809320107597159, 0.04962112543580588, 0.030153562147461344, 0.03258550772443414, 0.048704150030971505, 0.03231746995879803, 0.02257816024211934, 0.06289584300247952, 0.03365841577760875, 0.03735526857781224, 0.0412459146900801, 0.023841590591473505, 0.03862425946863368, 0.04027213901281357, 0.012481697522161994, 0.07682012161239982, 0.03947218916437123, 0.04514440159255173, 0.04319532141380478, 0.048922842397587374, 0.01592700122273527, 0.021416992276499514, 0.07146672098315321, 0.012277695968805347, 0.03304846315586474, 0.03377036133315414, 0.06328273942926899, 0.030530712319887243, 0.04494254484598059, 0.02475732846505707, 0.023978589197213296, 0.0690214334463235, 0.11821466250694357, 0.06737087474903092, 0.028076014350517653, 0.030067176157899667, 0.011998025966022396, 0.050397545492160134, 0.044318851360003464, 0.005030158208683133, 0.05201445521379355, 0.055653854651609436, 0.03861278215481434, 0.007064980100039975, 0.07054294750560075, 0.021370507856772747, 0.013476696767611429, 0.045782273809891194, 0.10262752039125189, 0.021586893999483436, 0.02665475145477103, 0.07006952408119105, 0.0978129635041114, 0.002947867624243372, 0.03511368573526852, 0.024241969986178447, 0.0449590984499082, 0.03579501440981403, 0.014254917459766148, 0.066621646983549, 0.015373475016531302, 0.04898304170637857, 0.042912559438264, 0.02050307266472373, 0.03380852998816408, 0.022500626218970865, 0.037171490548644215, 0.06678942430880852, 0.05472447053762153, 0.05927686746872496, 0.027462065263534896, 0.04279283246432897, 0.028830257178924512, 0.024132649778039195, 0.03214923992345575, 0.04330341893364675, 0.03197037491190713, 0.034357704425929114, 0.0649271383008454, 0.04417906413436867, 0.0457399342849385, 0.017202532289957162, 0.005632288130072993, 0.027212273198529147, 0.028347948391456157, 0.03139158136036713, 0.020160924032097682, 0.01169841631053714, 0.0426099487231113, 0.038077407953096554, 0.023473965884477366, 0.017448864091420546, 0.04860078370256815, 0.03592716122511774, 0.015323444986279355, 0.02846378651156556, 0.015554028414044296, 0.09534765282296576, 0.010092091470141895, 0.022465806505351793, 0.032800582121126354, 0.03379711946763564, 0.14684795925859362, 0.19014953024452552, 0.15862567961448804, 0.14399012667126954, 0.2794096647994593, 0.1992978510679677, 0.23191947169834748, 0.15234193007927388, 0.15378049429273233, 0.14499345095828176, 0.13870910770492628, 0.12738341465592384, 0.14725493820151314, 0.13793684367556125, 0.20084086514543742, 0.13013157265959308, 0.17049161164322868, 0.1411818398628384, 0.1786880093277432, 0.05893835907045286, 0.14734588097780943, 0.1202786568319425, 0.08956684192526154, 0.12581164977746084, 0.1937260734848678, 0.1735639397520572, 0.10347553543397225, 0.16399379703216255, 0.12990435672691092, 0.16897359309950843, 0.20813972427276894, 0.13791659788694233, 0.08542113821022213, 0.10569000762188807, 0.14252483029849827, 0.09377844093251042, 0.05960832546406891, 0.09687546029454097, 0.1653936953516677, 0.12451292102923617, 0.2581594238290563, 0.27573048253543675, 0.12098509978386573, 0.13860128849046305, 0.18449862487614155, 0.0850055503542535, 0.15874421544140205, 0.09660435374826193, 0.1391660628723912, 0.23314085381571203, 0.1319823702215217, 0.20544684142805636, 0.10553586354944855, 0.1128770993091166, 0.1535562617937103, 0.10540822157054208, 0.11076782655436546, 0.14415047509828582, 0.0807329171220772, 0.1600070539279841, 0.05533575160370674, 0.14826249273028225, 0.17887149791931733, 0.18106778006767854, 0.13418438174994662, 0.09932351604220457, 0.0921181304147467, 0.11230321135371923, 0.16412404394941404, 0.15506694791838527, 0.16583790042204782, 0.09960337250959128, 0.11459980960353278, 0.14435413526371121, 0.1424133448745124, 0.1528356215567328, 0.15135301830014214, 0.13372545246966183, 0.25035725499037653, 0.09579294142895378, 0.10484544356586412, 0.11216614409931935, 0.14491353649646044, 0.17866115842480212, 0.09921377466525882, 0.14964591537136585, 0.15804583963472396, 0.1431562940706499, 0.21216140768956393, 0.11860358499689028, 0.10070911317598075, 0.1945119781885296, 0.12283755233511329, 0.15484385832678527, 0.13453859399305657, 0.14922651287633926, 0.20166929491097108, 0.07835270851501264, 0.09737975706229918, 0.10939035593764856, 0.1791377508197911, 0.12310920064919628, 0.10212340173893608, 0.13911375630414113, 0.11970809369813651, 0.27118275000248104, 0.18830841028830037, 0.2513775002444163, 0.13438905123621225, 0.14460121106822044, 0.15815405960893258, 0.2030640427256003, 0.16647055163048208, 0.10128908674232662, 0.12956341408425942, 0.1969608131912537, 0.08916678722016513, 0.09843368839938194, 0.1788791420403868, 0.21175855508772656, 0.12768506800057366, 0.15341650054324418, 0.20384561328683048, 0.1145208821981214, 0.0793145467469003, 0.16667830845108256, 0.14703103224746883, 0.13269086892250925, 0.10272468236507848, 0.11667565602692775, 0.11762633235775866, 0.09759835666045547, 0.20490946713835, 0.14724606211530045, 0.07524502449086867, 0.1306490573915653, 0.10954208060866222, 0.11173909006174654, 0.08624364563729614, 0.15470743674086407, 0.10241336625767872, 0.23992645845282823, 0.12086042639566585, 0.14957361534470692, 0.2138211319106631, 0.17312746786046773, 0.10207777449977584, 0.10609143530018628, 0.0802852536435239, 0.153676682675723, 0.1319627626799047, 0.13685957179404795, 0.21386612090282142, 0.16893492720555514, 0.09860235630185343, 0.11582608247408643, 0.18207539396826178, 0.08938934988691472, 0.13170963095035404, 0.15972594323102385, 0.14863074640743434, 0.11610389803536236, 0.18175223318394274, 0.11322986436425708, 0.06971371622057632, 0.10824531113030389, 0.1529386019683443, 0.12266029778402299, 0.10455464042024687, 0.11474648767034523, 0.1509954663924873, 0.16959586908342317, 0.1221121326670982, 0.10682523381547071, 0.11859595571877435, 0.05495629520737566], [0.0070595781926385825, 0.03845465646008961, 0.02894062938139541, 0.11242146516451612, 0.03185546818713192, 0.05625958816381171, 0.03641485243861098, 0.02640156035340624, 0.025221688410965726, 0.052975621802033857, 0.050343851107754745, 0.03616834066633601, 0.020070155660505407, 0.03347593650687486, 0.03440264888922684, 0.03235349751776084, 0.035639523339341395, 0.013535307880374603, 0.016410206153523177, 0.012614778515853686, 0.04084707339643501, 0.0834413108532317, 0.03977598360506818, 0.023738753043289762, 0.02739172450674232, 0.046578197507187724, 0.036611736795748584, 0.021560386339842808, 0.010871597005461808, 0.031863346084719524, 0.052061243914067745, 0.011107704794994788, 0.04396517717395909, 0.020145665475865826, 0.02560679626185447, 0.020915665954817086, 0.03630652485298924, 0.13589525478892028, 0.027026259449485224, 0.05779612700280268, 0.0279056543513434, 0.04299977663322352, 0.010593047645670595, 0.031124285742407665, 0.06710103727527894, 0.014685463302157586, 0.06653144635492936, 0.02236983011243865, 0.05892730849154759, 0.04915796220302582, 0.058926154451910406, 0.035495869524311274, 0.021980028177495115, 0.018313171131012496, 0.036595914207282476, 0.01914133557875175, 0.033265763995586894, 0.03475098332273774, 0.07043351040920243, 0.05762608983786777, 0.019608140901254956, 0.015328050012612948, 0.030850002804072574, 0.02692832193133654, 0.005628160861306242, 0.01576081023813458, 0.01147647983088973, 0.03837263058812823, 0.06615427948418073, 0.04430643151863478, 0.03331056374008767, 0.022864775819471106, 0.002794253259708057, 0.04030791424156632, 0.03268817272328306, 0.017763848263712134, 0.04755871930683497, 0.06662695333943702, 0.02711419281695271, 0.03318138551549055, 0.013311303591763135, 0.025018163687491324, 0.005051150319559383, 0.03996408835519105, 0.07343167570070364, 0.03516870485327672, 0.05590704946371261, 0.05372149134927895, 0.021090128175274003, 0.022691825724905357, 0.009471171761106234, 0.04473653207242023, 0.0629103445680812, 0.04432055829965975, 0.08427860928350128, 0.038685623949277215, 0.05613416520645842, 0.02126215615135152, 0.028750752753694542, 0.06795507855713367, 0.03684149087348487, 0.03397834821953438, 0.04021389155241195, 0.034577892220113426, 0.010388565551693318, 0.01593106262589572, 0.08849942576489411, 0.029467075546563137, 0.04132988498895429, 0.010928286883427063, 0.10269381644320674, 0.01305802714341553, 0.08671683157444932, 0.0484230096481042, 0.08645989262731746, 0.044124145206296816, 0.022093526677053887, 0.06952796407858841, 0.04289466254704166, 0.0665681084501557, 0.07527699621277861, 0.06700351907056756, 0.043633737732307054, 0.02683888014871627, 0.016048822908487637, 0.042504033117438667, 0.12224676567711867, 0.012681746211455902, 0.09606821884517558, 0.06265981777687557, 0.021752567336079665, 0.0076869569056725595, 0.061947430222062394, 0.020209276808600407, 0.0735336245270446, 0.06145883729914203, 0.04005789953225758, 0.06635142359300517, 0.016843687189975753, 0.08853560546413064, 0.021617281236103736, 0.005576263401962933, 0.020588378829415888, 0.05114343359309714, 0.06293228245340288, 0.03839694334601518, 0.06612203316763043, 0.013215869894338539, 0.04563371810945682, 0.035302009418956004, 0.02232057933724718, 0.07943711985717528, 0.01373710525513161, 0.04558211287076119, 0.044719529469148256, 0.027995582240691874, 0.047565435743308626, 0.07151516096200794, 0.0411912480922183, 0.07339269068324938, 0.07749841490294784, 0.06946055480511859, 0.01638479130633641, 0.03860891185468063, 0.034460781316738576, 0.03814911797235254, 0.03446311537118163, 0.018472018564352766, 0.056549719665781595, 0.02745476995187346, 0.014511785902868723, 0.050734751421259716, 0.06082518048060592, 0.020214143441990018, 0.061145621293690056, 0.07828067566151731, 0.02551685909566004, 0.013445452350424603, 0.030540087500412483, 0.07025949904345907, 0.03614117806137074, 0.05136060826771427, 0.025168930988002103, 0.0650881027104333, 0.026465164264664054, 0.01893983320769621, 0.046430803267867304, 0.07058811461320147, 0.014075121052883333, 0.02727073588175699, 0.008973699041234795, 0.017453415312047582, 0.0682924514694605, 0.011983500280621229, 0.03847234554996248, 0.04994711751351133, 0.06194591253006365, 0.05611673586827237, 0.018769463931676, 0.04626438778359443, 0.009508298626315081, 0.030838586717436556, 0.04744890000438318, 0.030433537358476315, 0.01845189523010049, 0.050923089947900735, 0.034736162633635104, 0.02289569740241859, 0.07651426771190017, 0.018717099846981, 0.06386194858350791, 0.0006117928001003747, 0.032031216178438626, 0.11020933816325851, 0.029713251497014426, 0.06778740513254888, 0.043950467807007954, 0.03213569572835695, 0.03129617456579581, 0.04737949064292479, 0.07713754559517838, 0.025363058266520966, 0.035662210793816485, 0.011495142989588203, 0.023469878506148234, 0.04269026765541639, 0.00833647342005861, 0.050109013318433426, 0.05927509002503939, 0.03712771867867559, 0.029273198742885143, 0.037705124414060265, 0.052709888404933736, 0.07915173438959755, 0.0620035328756785, 0.042642966873245314, 0.021817575761815533, 0.026476815983187407, 0.01115318545998889, 0.05228254492976703, 0.025293270409747493, 0.01294223262448213, 0.06610798431211151, 0.056775425327941775, 0.029815181769663468, 0.020546946579997893, 0.014334190891531762, 0.02531014870328363, 0.017667463689576834, 0.007548558423877694, 0.023041330896376166, 0.03720972599694505, 0.041547182117938064, 0.0576743294368498, 0.045839652957511134, 0.046823262091493234, 0.053866551534156315, 0.04609172712662257, 0.013857363792340038, 0.046603653172496706, 0.07358356364420615, 0.026813500553544145, 0.019290444179205224, 0.021589712305285502, 0.021563390182564035, 0.023323862806137186, 0.010421398164908169, 0.03089066693064524, 0.05228081572568044, 0.07610511427628808, 0.09844499130849726, 0.04367738714790903, 0.02004393929382786, 0.022276365889410954, 0.031227210492943414, 0.02618746930238558, 0.004397519060148625, 0.03452648736129049, 0.05246042288490571, 0.0973738644097466, 0.030061979268793948, 0.04327969247242436, 0.046521415788447484, 0.030608483830292244, 0.020278923657315318, 0.023980722871783655, 0.04287191201001406, 0.02384759642154677, 0.05025155762268696, 0.036477771718637086, 0.03736843427759595, 0.04097830365935806, 0.04606368878739886, 0.02561019344284432, 0.05333645400241949, 0.009151105732598808, 0.023276562023966108, 0.03670275007607415, 0.0023763902572682127, 0.051851720781996846, 0.04570745048113167, 0.037079835310578346, 0.04423462502018083, 0.028081730742997024, 0.025450700341025367, 0.04097609948075842, 0.021405555780802388, 0.05721072833694052, 0.044780233438359573, 0.04465986079594586, 0.09948435428668745, 0.024771379175945185, 0.059067878682981245, 0.058334714703960344, 0.03385063573659863, 0.03972174374212045, 0.03065681619773386, 0.020891894964734092, 0.05660483526298776, 0.02940787628176622, 0.03425132126722019, 0.03754957768251188, 0.06376255274517462, 0.04995987503207289, 0.044262540905037895, 0.012550792398542399, 0.06851116238976829, 0.034872127798735164, 0.018634124025993515, 0.1049970940221101, 0.008568515168008162, 0.06633281795075163, 0.023060561798047274, 0.06766612335923128, 0.02962947230116697, 0.015065713796502678, 0.05019786323828157, 0.07020972319878638, 0.013713696062040981, 0.04406958250910975, 0.044871936916024424, 0.021667140572390053, 0.03557150921551511, 0.10566913842922077, 0.054578081908402964, 0.007734317059657769, 0.044131225295132026, 0.06947202840819955, 0.015845743473619223, 0.023377614706987515, 0.09095897738006897, 0.07414288324071094, 0.07647515652934089, 0.11846841764054261, 0.05872767447726801, 0.23302832938497886, 0.1177608169382438, 0.15875459066592157, 0.10766918931039982, 0.0775571855774615, 0.09292842209106311, 0.17741981253493577, 0.17247808864340186, 0.18107364303432405, 0.08673790114698932, 0.13114234810927883, 0.09058038558578119, 0.14755774929653853, 0.3386667132144794, 0.05005422426620498, 0.09917944291373715, 0.10764585618744604, 0.19868627685355023, 0.1364694396033883, 0.13454515457851812, 0.23097427241737023, 0.13876840530429035, 0.09701505085104145, 0.25051067175809294, 0.14991979754995555, 0.09358960887766443, 0.0963697831321042, 0.12733346811728552, 0.09972122556064278, 0.15218291751807556, 0.1147054617467802, 0.10328461794415489, 0.16685210459399968, 0.08068667390034534, 0.27261200768407434, 0.11948428422329016, 0.1753971038851887, 0.140729857084807, 0.09885847888654098, 0.10142306666239165, 0.15427238977281377, 0.14599815563997254, 0.11838569786050357, 0.1460015695192851, 0.13637606258271262, 0.2064083531149663, 0.16785974818049, 0.1741582664544694, 0.23712127382168546, 0.14470062917098403, 0.10927431372692809, 0.16260975098703057, 0.1630300737451762, 0.14807045459747314, 0.14231422363081947, 0.18089827353833243, 0.1333084248472005, 0.15981188393197954, 0.09480433393036947, 0.08645035602967255, 0.1330610373406671, 0.07496950958739035, 0.11132950618048199, 0.14292391279013827, 0.15114333189558238, 0.18046453275019303, 0.1848427884397097, 0.14524857164360583, 0.08907329887733795, 0.09803521446883678, 0.11324334918754175, 0.17191148857818916, 0.0818250393786002, 0.1433290957356803, 0.26716241729445755, 0.16270042659016326, 0.08644971778267063, 0.12164017127361149, 0.10783183839521371, 0.07370798470219597, 0.16411087824963033, 0.1326889541815035, 0.13659100339282304, 0.14724052569363266, 0.17343306943075731, 0.08864203686243854, 0.11464379669632763, 0.06952567084226757, 0.09537675243336707, 0.1557314075762406, 0.14607600693125278, 0.11881580954650417, 0.1387794633046724, 0.25736182287801057, 0.17905706452438608, 0.06841570735559799, 0.18355290609179065, 0.11820166750112548, 0.10628466829075478, 0.2029092307202518, 0.135194756439887, 0.09260212202207185, 0.09472125049796887, 0.2280624708510004, 0.13271942676510662, 0.07916652539279312, 0.07642135824426077, 0.20551774621708319, 0.06378036428941414, 0.16058753215475008, 0.0781022707815282, 0.12318465480348095, 0.16071727441158146, 0.14934577600797638, 0.22374104883056134, 0.1285848775296472, 0.16473003721330315, 0.161561882996466, 0.1686803557095118, 0.07108081903425045, 0.07883994330768473, 0.1502359821461141, 0.11418567635701038, 0.13934771093772724, 0.11496136168716475, 0.1183584684622474, 0.10383909873780794, 0.1287336039240472, 0.06474082212662324, 0.2310865296749398, 0.227878640871495, 0.22712254081852734, 0.13732161809457466, 0.12162550643552095, 0.2912944176932797, 0.09871050948277116, 0.2395100987632759, 0.11150637481478043, 0.12078514293534681, 0.10863243020139635, 0.1281741284765303, 0.11945721809752285, 0.14205990446498618, 0.2704562764847651, 0.12927056261105463, 0.13918164797360078, 0.12636864645173773, 0.15667292580474168, 0.16001361451344565, 0.10758757533039898, 0.19379012082936242, 0.12893189094029367, 0.11082368800998665, 0.10785020655021071, 0.15663820813642815, 0.09039962067618035, 0.16538566531380638, 0.1569754400406964, 0.12255812631337903, 0.10153881201404147, 0.14204227103618905, 0.09919194810208865, 0.08549208010663278, 0.14399748877622187, 0.2085030500893481, 0.13793391961371526, 0.07752718796837144, 0.08374669720069505, 0.1538018384599127, 0.20939157897373661, 0.08821358016575687, 0.14942610607249662, 0.09668653176049702], [0.029021844457020052, 0.055103659760789014, 0.025607137649785727, 0.07151327590690926, 0.0999371163197793, 0.11162586801219732, 0.04959764759405516, 0.010531445677770535, 0.008961343210103223, 0.03151024706312455, 0.02880085328797577, 0.07294749113498256, 0.02782730953185819, 0.06517372428788804, 0.06282181377173401, 0.04865926493948791, 0.03467844580882229, 0.022584616926906165, 0.042957207042491063, 0.03592538007069379, 0.05596305192739237, 0.014807802635914413, 0.0665681529790163, 0.04778894093760755, 0.05073311127489433, 0.017285081376030575, 0.04483333781536203, 0.035960546738351695, 0.010828625727299368, 0.0023558981683891034, 0.011398319620639086, 0.04312448341806885, 0.016475283227919135, 0.03792534931562841, 0.06222001735295635, 0.08231688290834427, 0.011809517673100345, 0.013060864002909511, 0.055512987601105124, 0.11063012847444043, 0.04107262320758309, 0.025216257745341863, 0.013478027995006414, 0.016044909934862517, 0.032543780471314676, 0.035215207826695405, 0.055085896456148475, 0.12420708939316683, 0.04374960182758514, 0.020739674910146277, 0.015932639689708594, 0.02362379993428476, 0.024835103686200455, 0.06452893896494061, 0.0591295697086025, 0.025134755087492522, 0.05048179780715145, 0.0448901789059164, 0.02334811619221, 0.013800581145915203, 0.03002389225002844, 0.05515906850632746, 0.03490185823466163, 0.01673639675573213, 0.037236662246868946, 0.05840664365678094, 0.03868350882839877, 0.030143582116579637, 0.008987528963189106, 0.038958678633207455, 0.03657813977042679, 0.10224014156847261, 0.08727571330382489, 0.07860022960812785, 0.027932742741541006, 0.01784963682439411, 0.03832819820672739, 0.040882600005716085, 0.05632640371914022, 0.011102093230874743, 0.004330056444814545, 0.01619236540136626, 0.08429702196735889, 0.032116203219629824, 0.07347115053562447, 0.03129747332422994, 0.0369589171896223, 0.010927874991466524, 0.020961031586921308, 0.057177832641173154, 0.061279256115085445, 0.059992984315613285, 0.05161484579730313, 0.023614897872903384, 0.01968507935089292, 0.012091428034182172, 0.027382579391996842, 0.06509116778033786, 0.05744377755036112, 0.019796444175881334, 0.04725677652459126, 0.012681026328209555, 0.12822026037611067, 0.055157884780783206, 0.0795900468074251, 0.05880654993234202, 0.049669346481096, 0.011766744919441408, 0.05178943232749589, 0.030747664350201376, 0.011067467403336195, 0.04799713562533725, 0.03359876565809827, 0.06131288282631431, 0.03920937240764033, 0.02885508758481592, 0.06003821450576652, 0.04038310864416417, 0.06897314931848086, 0.0449533208302455, 0.062418167071882635, 0.04964416541042738, 0.041472659358987585, 0.03835637755400967, 0.02083184037473984, 0.03926102217519656, 0.01320745950579294, 0.040539805704611354, 0.02557985073508462, 0.034362272344878875, 0.04404021943628322, 0.051438697046251036, 0.0546882463095244, 0.030435405715252273, 0.024234876909758896, 0.04817285021999851, 0.0436289916979149, 0.019292820907139685, 0.1216817760723643, 0.027994322445010766, 0.03732013901753817, 0.023540846377727576, 0.015280770567187574, 0.0208423844378558, 0.061681192164542153, 0.04838601358642336, 0.017643214014242403, 0.05585701386735309, 0.06348149399855174, 0.03805754808126949, 0.01336397195700556, 0.04982452213880606, 0.03862349134578835, 0.05730835044232663, 0.03902472977642901, 0.04782159172464162, 0.07017934709438123, 0.024921033254940994, 0.04554613355139736, 0.060217083228053525, 0.016739003549446352, 0.019653675371955615, 0.013771486173936864, 0.031673285775468685, 0.011222399079997558, 0.01694302922260249, 0.09714368730783463, 0.03359923321113456, 0.020930204627802595, 0.041270776637247764, 0.06867105810670182, 0.04498236106883269, 0.052280945601523854, 0.06365580964484252, 0.08186363847926259, 0.04849488293984905, 0.03837141346593853, 0.01338788117209333, 0.018836359267879743, 0.07801229279721156, 0.09140529014985077, 0.07315955983358435, 0.06286918505793437, 0.020347832069091965, 0.04525583135546185, 0.07646734913578257, 0.03548992863215972, 0.02768792306596879, 0.03439317908487283, 0.02519481895433273, 0.05292281057336368, 0.013085886439512251, 0.052274451809353195, 0.0408504167717183, 0.01051489207384293, 0.04324865214584861, 0.05694572966604028, 0.03331672356580384, 0.12826671882066876, 0.09464623421081342, 0.025808326463447884, 0.0928782974369824, 0.027446856802271213, 0.01946932217833819, 0.07782736443914473, 0.0163733733643312, 0.03328338629216887, 0.04822384689759929, 0.08216122485464439, 0.053705167811131105, 0.04946046901750378, 0.09784441572264768, 0.015513909766013967, 0.03384220122825354, 0.0524837522971211, 0.06187617662362754, 0.05957940767984837, 0.03515356875141151, 0.09985759519622661, 0.07124046242097393, 0.029923116017016582, 0.07123748640879057, 0.041495532350381836, 0.03313189539767336, 0.04586673021549359, 0.038328832742990926, 0.052328398523968644, 0.011230992222408531, 0.04458505973161664, 0.04104757943423465, 0.0272229953770875, 0.0442783412290737, 0.035036680492339656, 0.0390562933171168, 0.01782714232831495, 0.008018934404390166, 0.05336849993909709, 0.10308710276149213, 0.00822090711153578, 0.014561813150066882, 0.02482332394720288, 0.037296449663699605, 0.008904952974262415, 0.023053069817251526, 0.0166423647897318, 0.1011359816766344, 0.013049379267613403, 0.08647372626001015, 0.04406820211443119, 0.08428619403275661, 0.041101878668996505, 0.032866510809981264, 0.013600572347058915, 0.044461414217948914, 0.011040771423722617, 0.01948006476595765, 0.042116082840948366, 0.04289370517653879, 0.06065575929824263, 0.0562822978827171, 0.06765402635210194, 0.05228630390774924, 0.017771102757251356, 0.03256839008827228, 0.035782316263066605, 0.024713840466574766, 0.03691136778797954, 0.013413416618277552, 0.07080707786371931, 0.0888471219514031, 0.02893896511523053, 0.03593039698898792, 0.009198187581205275, 0.009331567289336817, 0.013794640253763646, 0.018595463698147796, 0.07646901154657826, 0.03235490388760809, 0.05679017922375351, 0.06602729059522972, 0.011770229302783264, 0.020297178634791635, 0.039849367167335004, 0.04463480589038227, 0.0686768394371029, 0.01643216444790596, 0.07384317432297394, 0.023381065693683922, 0.03547101870935876, 0.025197748582286295, 0.01985985327337403, 0.032018291676649824, 0.033027274839696474, 0.047065469407243654, 0.020607336991815828, 0.13774056045804173, 0.049563338106963784, 0.05139325534400996, 0.04111696653126273, 0.03149267671687994, 0.04836750442336779, 0.010338946485717315, 0.01646477627218701, 0.03396830696146935, 0.02055634031421505, 0.06015204511641059, 0.0880511017749086, 0.04846369047299959, 0.029676747108169366, 0.0320019421633333, 0.05675494947354309, 0.015910814981907606, 0.06891922486829571, 0.048205768180196173, 0.04789200669620186, 0.06314544210908934, 0.08226419784477912, 0.007056928725432954, 0.03079181471548509, 0.023397257500619162, 0.04541518159385305, 0.023216230983962305, 0.05570344867010135, 0.061770795364282094, 0.03714374906849116, 0.061276179912965745, 0.05050638887041714, 0.012732724335364765, 0.012598422508744989, 0.030570168601116166, 0.039427074007107876, 0.02052777690551011, 0.010314068767911522, 0.01986635077628307, 0.059435950533952564, 0.07056576112518087, 0.005381849468903965, 0.04265244409907609, 0.07762263558106497, 0.028890174471598584, 0.013585083725047298, 0.08034211699850857, 0.01121657136536669, 0.021278450003592297, 0.02153348905267194, 0.04850676101341378, 0.057903089036699384, 0.044147841981612146, 0.07856041338527575, 0.0817977506085299, 0.05050742045568768, 0.04632518823200371, 0.09227896123775281, 0.14876154251396656, 0.09758930988027714, 0.15022335079265758, 0.23683125735260546, 0.26356712740380317, 0.20474794611800462, 0.10315379957319237, 0.18166011781431735, 0.1763699110597372, 0.08081170351943001, 0.14811300934525207, 0.1324103371007368, 0.15090563683770597, 0.21030090283602476, 0.13799718028167263, 0.22914567991392687, 0.09682582545792684, 0.1300402291235514, 0.14169439673423767, 0.1383803808130324, 0.11914616174180992, 0.21973456459818408, 0.16885750635992736, 0.08405068088904954, 0.16867793630808592, 0.12472768372390419, 0.056818503289832734, 0.12154651965829544, 0.10867690711165778, 0.10618191794492304, 0.1710809807991609, 0.164772339630872, 0.0878130727505777, 0.0829775353486184, 0.20148628129391, 0.09410572805791162, 0.10707320019719191, 0.157342788297683, 0.14283538941526785, 0.11903225691639818, 0.13476285617798567, 0.1487727341009304, 0.22311406763037667, 0.12157544857473113, 0.20410122378962114, 0.14341622387291864, 0.18024059711024165, 0.19733821012778208, 0.18013751279795542, 0.14648092270363122, 0.06621400752919726, 0.11014592906576581, 0.1922957767965272, 0.10349242671509273, 0.06871080011478625, 0.11886954103829339, 0.1268534766859375, 0.16105685150250793, 0.17445436853449792, 0.11660366028081626, 0.17473696352681145, 0.0864556104352232, 0.07183467780123465, 0.13757755514234304, 0.23194601089926437, 0.19490726088406518, 0.1412720701773651, 0.10218341180006973, 0.172864836640656, 0.1404032824211754, 0.3128166409442201, 0.238123158342205, 0.220578208391089, 0.16643645736621693, 0.11319725439534523, 0.11168194469064474, 0.13381406490225345, 0.20558888849336654, 0.10221244461718015, 0.15652624773792922, 0.1980318658752367, 0.16910401813220233, 0.1516330157755874, 0.22186400892678648, 0.12107293296139687, 0.09873582414002158, 0.12855899141868576, 0.1241411198861897, 0.09013410250190645, 0.16269379178993404, 0.14695050922455266, 0.19286901166196913, 0.08046303511946462, 0.18138858082238585, 0.16030490747652948, 0.13734934473177418, 0.17566405440447852, 0.12445498156012036, 0.10856874650926329, 0.17080347693990916, 0.19263795140432194, 0.28587576001882553, 0.15804781374754384, 0.10117218364030123, 0.08200885451515205, 0.1813626056537032, 0.13608235021820292, 0.09904054997605272, 0.14371556171681732, 0.10584325369563885, 0.08734110393561423, 0.11308973203995265, 0.13662784360349178, 0.12813020817702636, 0.11623982238234021, 0.18366412434261292, 0.1511958017363213, 0.13265922374557704, 0.2850512636359781, 0.1992287125904113, 0.13967861974379048, 0.10291231956216507, 0.12388660034048371, 0.10364651883719489, 0.13426114950561896, 0.10580635411315598, 0.16201509773964062, 0.07853522489313036, 0.19878947990946472, 0.17754470114596188, 0.12121903215302154, 0.17502784088719636, 0.08721974052605219, 0.12477633892558515, 0.17129612941062078, 0.1644286361988634, 0.07251896022353321, 0.19161840376909822, 0.15184936666628346, 0.16502220591064543, 0.07866602099966258, 0.05895552123547532, 0.11142450108309276, 0.11538173639564775, 0.12348104632110335, 0.15595635253703222, 0.19169088191119954, 0.17710585438180715, 0.08277293265564367, 0.1447503679082729, 0.13052048772806302, 0.16790871508419514, 0.07078705471940339, 0.2092887766775675, 0.1326679514022544, 0.13592183851869777, 0.13765611889539286, 0.1628418650943786, 0.1997820133692585, 0.21416251984192058, 0.10597525208140723, 0.14090780925471336, 0.15248186944518238, 0.10841176743269898, 0.1579958337242715, 0.1530226576142013, 0.14654011640232056, 0.14672032470116392, 0.19176862930180505, 0.20459500432480127, 0.09945788187906146, 0.12046631629345939, 0.21733716042945161, 0.39379362075123936, 0.146903560962528], [0.03843154227070045, 0.038767653531976976, 0.06769277388229966, 0.018758268633973785, 0.056777996869641356, 0.030664694095321465, 0.019064063162659295, 0.04847804731980432, 0.0351602777664084, 0.017181802249979228, 0.03839400815195404, 0.04039314248075243, 0.021793652631458826, 0.05042969532951247, 0.028822126951126847, 0.04664171050535515, 0.010490355743968394, 0.05817346456751693, 0.06883479072712362, 0.005994971061227261, 0.04726932995254174, 0.017925849824678153, 0.04199794406304136, 0.06750832792022265, 0.034752931460388936, 0.009431514172320021, 0.04732428598799743, 0.020043699951202143, 0.04204180499073118, 0.06805506069213152, 0.027688770969689358, 0.03792917508690152, 0.017371504472976085, 0.10509204439586028, 0.042135913026868366, 0.052279008596087806, 0.058844273298745975, 0.0973948449245654, 0.045256317462190054, 0.0377950170513941, 0.05120638998050708, 0.027100863844680134, 0.04091236012754962, 0.01819501008867519, 0.0908825287478976, 0.05754286910814699, 0.022851374487800058, 0.029124015927664004, 0.02988364674820332, 0.03308044600998983, 0.03061838222492952, 0.008252266561612487, 0.039141016895882785, 0.026013552560471, 0.07580576901091263, 0.06409903508028947, 0.05706389812985435, 0.07444661459885538, 0.02500866790796863, 0.07173186808358878, 0.03127753923763521, 0.009487843180977507, 0.10041611327324063, 0.037768288602819666, 0.05254971809335984, 0.06270021287491545, 0.0077923697062942665, 0.03959610556194093, 0.03622317795816343, 0.04826381154998671, 0.03593968125642277, 0.010667921997082885, 0.046514094501617365, 0.03428630610869732, 0.08481602810206823, 0.012119178791181184, 0.04557468026177958, 0.05183962006412912, 0.04424947910592891, 0.01164809498732211, 0.06388819092535414, 0.0366464804392308, 0.05141016146808397, 0.04867569979978725, 0.02133540798240574, 0.018214604642707855, 0.03374129140865989, 0.0587850647571031, 0.0576941373583395, 0.021147052757441998, 0.046638708518003114, 0.06287440977757797, 0.04799713191459887, 0.032779386383481324, 0.011950854132010136, 0.026984292853740044, 0.07096678804373369, 0.051764778181677684, 0.0019069521658821031, 0.0483064405125333, 0.014362750589498319, 0.030264312845247332, 0.05268745699140709, 0.03270365021307953, 0.02949946472654119, 0.03408230084460229, 0.043621666700346395, 0.029783939207845833, 0.07011668014456518, 0.04528228149865754, 0.024775624260655604, 0.06925394831341691, 0.09680229195510037, 0.024255811040347908, 0.08077784674242139, 0.02343320898944512, 0.05663525218551513, 0.05363843389204703, 0.032120667237904854, 0.05606388753221836, 0.07449337732396089, 0.05100798422063235, 0.04654962111089844, 0.01901963449199684, 0.04600996842782479, 0.06462332530645654, 0.04055824436363764, 0.053087853084434755, 0.018823121208697557, 0.011900628360308474, 0.018629303776833694, 0.028687757403531577, 0.05065161603852175, 0.012520172313088551, 0.02787206474749837, 0.032556163205299526, 0.08611551384092309, 0.009881141559162643, 0.036401319375727326, 0.04361056417110376, 0.09909146872814745, 0.034511881895014085, 0.01756560948706465, 0.04912099953799043, 0.07065293379127979, 0.02045076424110448, 0.02687307645828696, 0.041600820841267705, 0.03259893688664306, 0.07548673456767574, 0.04835861349420156, 0.012657285951718222, 0.04490187515330035, 0.04140674551308621, 0.010874815143324668, 0.03207266141544096, 0.012553213655337458, 0.06588524352991953, 0.01773211402905872, 0.010935070113191614, 0.038019216153770685, 0.029125533619662747, 0.014657981573691359, 0.06207324280694593, 0.01612400432350114, 0.04969257199263666, 0.026857830889639445, 0.03413447011553217, 0.030598412886320148, 0.05763423861935735, 0.016687745264789555, 0.014477872537099756, 0.010691778334148694, 0.05699373548850417, 0.10613772305077873, 0.09202828601701185, 0.029029147190158255, 0.010982772582792677, 0.04959943616995588, 0.019791865124716423, 0.03431807373999618, 0.024246556458820123, 0.02790347429254325, 0.005706835936507559, 0.027841655246447772, 0.010670433239283739, 0.031473837298108265, 0.017332970310235396, 0.022064384393161163, 0.02695170885999687, 0.028840975646744482, 0.014270149113144726, 0.010899120479734847, 0.08071152842603624, 0.03745198897377122, 0.04831022917642258, 0.015904031752143055, 0.010083087363454979, 0.04747425547975581, 0.03645917349786032, 0.05769384792074561, 0.09503054054221138, 0.02692323636438232, 0.023072861040418502, 0.04698541022662539, 0.06571382968104444, 0.04611231430317275, 0.0603691344440449, 0.08525130513589829, 0.05318435825756751, 0.026732736332633067, 0.022755982536182273, 0.07611004213686101, 0.0398129165841965, 0.012663541328947758, 0.030973998982517514, 0.019273987054475583, 0.03449954740062822, 0.028946084166818764, 0.01667777822149219, 0.0488262964063324, 0.033203475541085936, 0.014099553482083138, 0.04537750646704808, 0.029569632933998946, 0.021949592701275833, 0.05458324354549404, 0.06289861863479018, 0.02416188297502231, 0.038772369880462065, 0.07031324537820183, 0.05526110267965123, 0.07227077861898579, 0.08783632423728704, 0.02854330392437987, 0.02421229706669692, 0.042300751447328366, 0.042334730678703636, 0.05671318882377818, 0.035052814782829955, 0.013762799335381715, 0.01303385910432553, 0.03539679280947894, 0.01868122813903028, 0.02940690035757143, 0.04425654435181059, 0.046803914301563054, 0.05005299601180013, 0.020790220733033493, 0.03194703065673821, 0.046076973230810836, 0.010529939117986942, 0.05635279077978339, 0.03536708092724439, 0.04715395567473024, 0.03713089878147002, 0.03411766047065612, 0.056343821925111115, 0.006430967514461372, 0.03434587088122498, 0.03896046349836979, 0.00856591486808611, 0.05915848749282304, 0.0484123412752524, 0.048275255467160605, 0.057233226543758065, 0.015741330716991797, 0.0920589515590109, 0.06188442188431509, 0.057126765459543094, 0.02363367977523012, 0.03799427257035859, 0.021110006600792985, 0.05711042707844172, 0.02360185462748632, 0.047489740391029045, 0.016576671732764225, 0.02933132189355092, 0.05619217889034189, 0.08294505896628834, 0.04503061922150664, 0.0314823719963897, 0.05440937318780925, 0.04835153711610474, 0.058969759338651784, 0.029241445954539813, 0.02590277959825471, 0.0657167611643672, 0.02408848642517114, 0.06645722416578792, 0.05402787217462901, 0.04603927955031395, 0.04375730532046873, 0.04593837715219706, 0.04490693660045508, 0.05999133674777113, 0.04894757817965001, 0.026310025714337826, 0.05412337544839829, 0.0279316592059331, 0.04877445739111863, 0.03401824978936929, 0.03043171724129934, 0.02465207151544746, 0.019034379110962618, 0.06295503670116886, 0.03695338076795451, 0.08626087088487111, 0.012701471569016576, 0.03455269630649127, 0.04708396001660731, 0.024189802570617758, 0.062428542296402156, 0.017906273824337404, 0.017959491378860548, 0.06308512776740827, 0.047992927648010664, 0.053616573932231404, 0.007466270944860298, 0.05660372946294956, 0.016919497575145215, 0.0433742086897837, 0.07071316649671644, 0.011349387968948577, 0.02225802185421344, 0.035938627406721935, 0.0226808827574132, 0.036568966825143434, 0.024377814552281052, 0.04346703281044029, 0.018650924394023605, 0.03185255525750108, 0.07879453871282749, 0.07970362508785911, 0.04009865086118225, 0.0564824810862774, 0.044001802161801606, 0.02664073785126675, 0.03751958749489859, 0.013390877593337791, 0.05501817176991608, 0.052341597620397806, 0.027425549742474686, 0.04722401070466731, 0.11494428486912511, 0.03341427516716067, 0.0951824284857139, 0.09023077465826645, 0.02614061380882049, 0.01862665987573564, 0.025368772803631146, 0.06542839226312935, 0.09575629417668097, 0.06849806348327547, 0.21782611700473353, 0.1212366581603419, 0.13738443347392604, 0.13194429804570973, 0.09779190877452493, 0.21274831291520968, 0.09778508843737654, 0.07456333958543837, 0.1571198322926648, 0.14150108210742474, 0.10760124569060281, 0.16525757062481716, 0.1738714857492596, 0.12616678228368983, 0.08707385655725375, 0.18959646695293486, 0.1463378663174808, 0.09394582491950132, 0.19880773674231023, 0.1084742859529797, 0.15044684114400297, 0.10383608561824076, 0.3039809869369492, 0.16314069827785715, 0.17682106263237074, 0.06649859889876097, 0.10937226237729192, 0.10586582240648568, 0.0825178564991802, 0.13350542052648962, 0.22213305230252445, 0.1674342600745149, 0.09094529217691161, 0.15250913595082238, 0.14805319224251434, 0.17017711914377287, 0.10367806753492914, 0.15849633811740205, 0.1709105836926028, 0.10359301741118543, 0.1962803231435828, 0.08157287986250594, 0.2249970892444253, 0.12350314747891389, 0.1245069170545321, 0.08884154842235148, 0.12800134165445343, 0.13414963439572603, 0.10836355009814724, 0.14554032473824918, 0.122948406933574, 0.12723776075290516, 0.18557162198703736, 0.14420186140341684, 0.12158980913227424, 0.20573834219248965, 0.14998247934272513, 0.1785619926522486, 0.15465354197658598, 0.14674353908048943, 0.18261689459905028, 0.13639072742080316, 0.11659286203212105, 0.19451511005172506, 0.1588983298279345, 0.1378114355611615, 0.1786661011283286, 0.15326024877140298, 0.09912634224747308, 0.17318954109214246, 0.10077949104015715, 0.0924010667949915, 0.1688591093989089, 0.13702879630727693, 0.10437063232529908, 0.10779956239275634, 0.12645292474189773, 0.1222831902850885, 0.0972140725934878, 0.14536694419803098, 0.12141480328864418, 0.17609763192012906, 0.08866631251294166, 0.12870752485468984, 0.13003960571950302, 0.12385312948026694, 0.19624271109933034, 0.08969248752691783, 0.10668286762665957, 0.24801292922347784, 0.2294460716075264, 0.23818732443032786, 0.0757190193689894, 0.16624410753138363, 0.18339485832257196, 0.15208254946628585, 0.09673289372585714, 0.10251150044496171, 0.13552274118410423, 0.21319024701369926, 0.1374290365492925, 0.15542396547971293, 0.1689904843806289, 0.19313493801746517, 0.20747622940689325, 0.17867398273665458, 0.1369758218061179, 0.10838521338882856, 0.1353359574568458, 0.16687189025105909, 0.21109608438564464, 0.1843613275559619, 0.24501257459633052, 0.10534262313740328, 0.11616932577453554, 0.1584856363479048, 0.17839796317275614, 0.13950635242508724, 0.15500249981414527, 0.1603918574983254, 0.13804132322547957, 0.07925178331788629, 0.15031157730845734, 0.13232507917564362, 0.08057452054345049, 0.17822275694925338, 0.12171851238235831, 0.1323839314864017, 0.06929202791070566, 0.22696670464938506, 0.15301474631996825, 0.058453833116800524, 0.21179961069719866, 0.14818796626059338, 0.14292069186922163, 0.1270327647216618, 0.14139697363134474, 0.1585250295465812, 0.17138346534920856, 0.13312272465554997, 0.07753349622362293, 0.15307070425478742, 0.1521901460364461, 0.1609621534589678, 0.18368242570431903, 0.12380984742776491, 0.08760636977967806, 0.13319598947418854, 0.10451717680552974, 0.15498666238272563, 0.1133380843384657, 0.1250681365490891, 0.09656008463934995, 0.11464925148175098, 0.16091619967482984, 0.20174361357931048, 0.13459137553581968, 0.13566403125878423, 0.11944616009714082, 0.07662231699214317, 0.15297205798560753, 0.17617024364881217, 0.17948972177691758, 0.15017033176263794, 0.15721766219940037, 0.20908247446641326, 0.2644091681577265, 0.11246102905715816, 0.17209456156706437, 0.11304403800750151, 0.14100096363108605, 0.13634015747811645, 0.21214745531324297, 0.17360199708491564], [0.025992238079197705, 0.009926388447638601, 0.05242174956947565, 0.05566730978898704, 0.05621785719995387, 0.07020698467385955, 0.09187318457406946, 0.02405328821623698, 0.03568253079720307, 0.0275626541042584, 0.024134896630130243, 0.06385405213222839, 0.0018122886785931769, 0.050478851480875164, 0.03984843577200081, 0.013544413104682462, 0.031795216928003356, 0.025781347540032584, 0.0045276630044099875, 0.01591317315615015, 0.008980639977380633, 0.07328179155592807, 0.05198608290811535, 0.047009389018057846, 0.015216151768981945, 0.10406019195215777, 0.01093768711143639, 0.048083024375955574, 0.016223008678935003, 0.04324552770412993, 0.008241518407885451, 0.09157120468444191, 0.016153662400029134, 0.0723383882723283, 0.07225816210848279, 0.10377619430073537, 0.027288757082715165, 0.03862994803057518, 0.029579420006484725, 0.030493081721942872, 0.03163395565934479, 0.0231656387768453, 0.05229797046922613, 0.040709430977585725, 0.05330592946847901, 0.010109987433679635, 0.04163083700404968, 0.03838608943624422, 0.018175415534642525, 0.007612711060573929, 0.012036235439154552, 0.020976700179744512, 0.06203069176990539, 0.02011145988944918, 0.06048120245395694, 0.07893948015407659, 0.027951535776082892, 0.025142976228380576, 0.06266185126150958, 0.01789981899491977, 0.05897968927456532, 0.04494346139836125, 0.032627505861455575, 0.038819615001557395, 0.04410328343510628, 0.07802972584613599, 0.03983142574725207, 0.015718021713837516, 0.028685228535323404, 0.011339176016917918, 0.03671448714158032, 0.07502916341763921, 0.05726076022256166, 0.008492419055983191, 0.02412610403553117, 0.034002991233137436, 0.02166433710954152, 0.035697648345376365, 0.05272519891150296, 0.01945016920217313, 0.008813504609861411, 0.0035990064270663424, 0.0283246783510549, 0.02727107726968825, 0.03561963007086888, 0.03044734687136952, 0.02947583474451676, 0.042498971670283936, 0.09817824116908014, 0.01082932241843082, 0.007803692096786108, 0.02691484824026702, 0.05451284712762572, 0.04762720469443593, 0.08949714683694765, 0.021321548374544363, 0.02019065632339334, 0.04614309116732329, 0.026510173665883485, 0.048180442390730605, 0.031155133110587485, 0.03149842465063557, 0.021634838594764005, 0.03537890705047175, 0.06594034057343379, 0.04888107803708408, 0.03222879073291551, 0.04219959300826304, 0.02318473423656542, 0.0044098897342337295, 0.03620805298851337, 0.03414788072404917, 0.04271751931810286, 0.020202528830850497, 0.04531884340394754, 0.06867054602480493, 0.04649245718610473, 0.08239149843575433, 0.126854604750406, 0.01417327657691203, 0.055736054928274825, 0.027886564457730856, 0.027515494330145884, 0.03586906961572822, 0.04522318427916616, 0.0676963065052405, 0.09879373392323032, 0.03404275921639055, 0.057421015881118365, 0.01565847735037096, 0.0305655357442447, 0.0045783818404743215, 0.10935627651633695, 0.032203361042775214, 0.01069735650162329, 0.018083676804963034, 0.06724885082803667, 0.042809482547454536, 0.07405873111565597, 0.05913552173296921, 0.013126800113241188, 0.029189772067184094, 0.058494803379289806, 0.013140093833499122, 0.028658433293458074, 0.04985523963114247, 0.019332885749463458, 0.03339017763209995, 0.046736531003261916, 0.05706807642127387, 0.057281677654827945, 0.04370470189314801, 0.04237495508277789, 0.0431553456292022, 0.028896039293613285, 0.0493247747363057, 0.06114128715125844, 0.04622399268555455, 0.015940986995701678, 0.02999394288053736, 0.02355083383008605, 0.031489121829508804, 0.01290644533582963, 0.049128602840937674, 0.05632435168081429, 0.04688522400101647, 0.01206816355988849, 0.009324091079179198, 0.02831213419995038, 0.03070102036872413, 0.024719265566091053, 0.06892532532219775, 0.06873092715977691, 0.028348243395157624, 0.021074698925076518, 0.031769141569384374, 0.03512872164719738, 0.02275040344102308, 0.0224528133549029, 0.06427778134820983, 0.0324177118454827, 0.02527630676922854, 0.011356766772223637, 0.03243545288569294, 0.0609257303585764, 0.06422247650334612, 0.06620054497034289, 0.058319830932305194, 0.026632997250999324, 0.04025823116535321, 0.005124710605741711, 0.010584512947389157, 0.009365227397211129, 0.004656709033952211, 0.03757954931643326, 0.027396541045163758, 0.03580672178941313, 0.02714258367632283, 0.0714768141915556, 0.04585508220770862, 0.03241602345951833, 0.0018393439040664816, 0.04485878976993263, 0.026886540872510523, 0.027727243905246723, 0.008763088662817609, 0.04119709992664866, 0.024100999034999404, 0.015532640645687934, 0.03587707738915924, 0.04221583862090483, 0.03375032334588468, 0.06255562024307437, 0.041571925321477465, 0.07359732306213118, 0.04724633079604246, 0.0429911491664825, 0.021555196872213855, 0.007468342464562738, 0.055793237406760454, 0.026862057420657948, 0.01908567635837244, 0.047647461615270004, 0.06050014206266496, 0.048020873218774796, 0.04702397964138072, 0.015746060053061228, 0.025672095980553422, 0.016503444021509495, 0.051859283266821876, 0.0026279926987626823, 0.052088120792177506, 0.05656303379510064, 0.04958781413733959, 0.024096412562357727, 0.06700292535242625, 0.022723337315255776, 0.053836483421036974, 0.00822345453343587, 0.030897941833245568, 0.024867652427928988, 0.04589892829244491, 0.04312705495976843, 0.0201751955319196, 0.0619342608115403, 0.019501681672409177, 0.02157246293791104, 0.02215848315245239, 0.05472076350997668, 0.052765282307518646, 0.07714748295256868, 0.01925537955685286, 0.04092497663805261, 0.04003988389740698, 0.022872544250276405, 0.058540601312415674, 0.03811872702499386, 0.055321480103884824, 0.06234816028154455, 0.02601455260446528, 0.03808168272371404, 0.0077746356237184955, 0.006809226269979263, 0.015878659578447696, 0.02102383026794996, 0.09053645786480047, 0.016042405186453834, 0.010639040392561583, 0.06626316739129834, 0.03031797197763808, 0.022162518580444157, 0.05544638726860285, 0.05526438297238201, 0.05256758529867511, 0.021161474542168435, 0.03298460505902767, 0.023450736662198324, 0.06186261758557521, 0.018252788140671328, 0.04638446727767587, 0.02785845190373948, 0.06518870082800277, 0.023966792759892996, 0.006882161760586314, 0.02984784554428188, 0.043276601427351125, 0.006174868585731019, 0.10255306071485393, 0.0775831904320512, 0.023208405036712065, 0.010225524983979994, 0.13477069325745106, 0.05041349053499289, 0.056730658980086446, 0.00607764074629813, 0.021630775336234365, 0.044126520078862086, 0.01869218409410678, 0.017093241767724976, 0.02159549363568658, 0.09008518754853867, 0.030128423750284128, 0.07250704875332303, 0.05791358300484717, 0.03961695620091632, 0.046067288203630596, 0.04998814714781474, 0.03136627041385509, 0.056835190480342135, 0.049366383245796897, 0.0292047319089761, 0.04947298904880881, 0.03450524709478486, 0.028088925864722114, 0.12839465023716912, 0.03413916791032534, 0.04561640751489904, 0.02414824972220231, 0.03734708639967721, 0.008335560578416334, 0.06796805871999823, 0.052091675679548644, 0.03854195158055518, 0.06510977342259139, 0.03130088349280413, 0.008015546500246273, 0.04594521233229898, 0.04683760409534443, 0.04902648332063109, 0.028515139420051128, 0.016828758889460005, 0.014835405891062692, 0.054403558460762724, 0.03243075880163815, 0.02560202239692444, 0.03847194107947871, 0.024210905539803207, 0.03944895252061542, 0.05382353294407949, 0.045827834255760536, 0.023120354780985508, 0.042363659595139325, 0.009125336509896442, 0.03591698266973253, 0.04010641743661836, 0.04552997699647676, 0.0341554654733045, 0.025598883112252224, 0.048502634672331624, 0.07800599196343683, 0.013156406239431817, 0.03806408269156236, 0.17154697532532737, 0.14141301886411384, 0.18939126312034205, 0.14145493536489084, 0.09411941326106898, 0.11485238472232595, 0.22439851745730266, 0.10058793530333787, 0.2266554775997065, 0.22448468080256134, 0.10397002100944519, 0.14205367042450234, 0.1593721762765199, 0.09451361242099665, 0.1442539453273639, 0.13422960822936147, 0.10699233578634448, 0.11102515141828917, 0.07908513405709527, 0.15750389371532947, 0.07309246968361549, 0.16546007303986698, 0.15480467292945832, 0.11842064559459686, 0.08350733973202296, 0.20886848360532895, 0.1051584591914434, 0.11052365996874869, 0.11278375939582475, 0.08294588275020942, 0.0636057517840527, 0.13688299397472292, 0.14692080847453326, 0.163870288815815, 0.16776620788732544, 0.4336880362825468, 0.1315590788726695, 0.10064756686915644, 0.24444058653898537, 0.215984151000157, 0.15982206619810313, 0.11981703355559148, 0.1400915061822161, 0.12822060176404193, 0.23504514538217336, 0.07456703548086807, 0.11829448048956692, 0.12957807892234996, 0.1307326677488163, 0.12806866929167882, 0.08589006421971135, 0.09527032845653594, 0.12930838245665655, 0.15299447084544227, 0.10580509246210568, 0.2210473793093115, 0.12479559023631737, 0.24573515926022083, 0.17192238330608234, 0.09904415681376122, 0.14564091543434188, 0.09660263196565211, 0.17217098793480545, 0.08201045755413361, 0.15127866994589567, 0.26520662067923695, 0.18665686453459784, 0.083127768302802, 0.17148662387626246, 0.11751169280614704, 0.12771530309692025, 0.21038617560407147, 0.18984799564350396, 0.07252690120367333, 0.23345653375145048, 0.09044158170581795, 0.10901919304160401, 0.14473727642325684, 0.11389396779122762, 0.17692883731797338, 0.05084206597530283, 0.12048438016790897, 0.1544530878891237, 0.09356619411846623, 0.22050478029996157, 0.13635047333082184, 0.05993074410071131, 0.11553504184121266, 0.1299545555957593, 0.15627672284608707, 0.09327049279818311, 0.10875689578824677, 0.20966663374565542, 0.12236329770530574, 0.24359842704143375, 0.10537554480833933, 0.09189285890897736, 0.15989549428923056, 0.19493736239382997, 0.14742156519787386, 0.14864499564282596, 0.19531891535734758, 0.12992013478651643, 0.13984713179524988, 0.17066769360098988, 0.17756424931576476, 0.08931361371651292, 0.12038286178722046, 0.12622870708582923, 0.10687656817026436, 0.05050021791248582, 0.17361372301820666, 0.15302003041142598, 0.22506998298922554, 0.10835580207640305, 0.21990720299072564, 0.10292987135471776, 0.15413299959618598, 0.19742045493330806, 0.13729720143601298, 0.20837140793446451, 0.13173765444662422, 0.11119328497443348, 0.18718125123996288, 0.18745918554486707, 0.26614021277055144, 0.16697953135007992, 0.1529121518251486, 0.10831615654751658, 0.08788054881733842, 0.06725118117174134, 0.11138421730720438, 0.14677436789497733, 0.12153644129284658, 0.10930687916697934, 0.09484235415584408, 0.1697474453249015, 0.10229557257844135, 0.1761107679340057, 0.16394477075664327, 0.1518350580590777, 0.1363373818458058, 0.10632524150423706, 0.14186271582730114, 0.11045829902286641, 0.16311000304995105, 0.07439179214998148, 0.11081655597081408, 0.14412169461138546, 0.1396551085053943, 0.17564076581038535, 0.15045481181005016, 0.12261549432878383, 0.18249626591568813, 0.09015081566758454, 0.13415493333013728, 0.19264857895905152, 0.13351557310670614, 0.1048052562691737, 0.11468986922409385, 0.100362648954615, 0.13693015003809705, 0.16557682771235704, 0.22502128325868398, 0.1591112371534109, 0.1524652453372255, 0.07360488554695621, 0.13110773434164003, 0.15274019620846957, 0.140336177428253, 0.11812337092123926, 0.13057522854069248, 0.21895731333643198, 0.21957537392154336, 0.06822990326327272, 0.13613180693937466], [0.010600181540212361, 0.03044355078600347, 0.06559037341503426, 0.04293315032555256, 0.01281324364754255, 0.05537299999559764, 0.025901889021042734, 0.017026040295604616, 0.04981454767403193, 0.02983536818646826, 0.05353193198970985, 0.05219544647843577, 0.02469616250891704, 0.04160158154263627, 0.007545939570263727, 0.07869624125305563, 0.08325509857968427, 0.1725808167248033, 0.07051700944430195, 0.016384841401304584, 0.07306192288524471, 0.05739022417401429, 0.06541806156747043, 0.021285071816237178, 0.043881949022761546, 0.04506578217842616, 0.006432821492126095, 0.0181539971526945, 0.028104891316615976, 0.04793554850039072, 0.026976695116900373, 0.036948059569112957, 0.025058356550289318, 0.09969556209398434, 0.05713980499422178, 0.11800489446613938, 0.04178999057330657, 0.030027562170289457, 0.050964368201675825, 0.005799628515887889, 0.05428494099760428, 0.06124377032392658, 0.037410001968964934, 0.018779380880005192, 0.03851645509712398, 0.0029669760715478333, 0.03473756158200558, 0.03687150703626685, 0.016097860316222068, 0.0387804630008759, 0.014553108685504412, 0.0815831586078275, 0.00957463271333836, 0.04167227110883687, 0.08154039605869912, 0.032945671991910785, 0.014097331677476177, 0.010861956507142168, 0.010767751991807017, 0.02277560121001443, 0.04316278937039897, 0.01194014586872072, 0.010934879937849473, 0.061228775230119936, 0.03249541841796599, 0.03986868527135812, 0.0585432730440516, 0.017350308735331055, 0.09035322902491316, 0.08308927310281433, 0.032353868591599166, 0.0010648256011336343, 0.04081393279193435, 0.05225004628300667, 0.019181322495569475, 0.021165159305382986, 0.019613647637015674, 0.02398125721811084, 0.07789084032992832, 0.10475648974534124, 0.032358926328015514, 0.03205109831469599, 0.016766001026553567, 0.031813150926609524, 0.011753414091799641, 0.028039376375090797, 0.05943504882452544, 0.05213801166974008, 0.04399000943521969, 0.04014964753878303, 0.052842146542388946, 0.05280875731841661, 0.021952210627205204, 0.08030286480789073, 0.07140383138903417, 0.029064111622574273, 0.04529385158093646, 0.023824133422749583, 0.03787095731240697, 0.04691793044912629, 0.07084000695613213, 0.015438449117937125, 0.05092466701171361, 0.022840127239760477, 0.03598311173846014, 0.05689983896445483, 0.03349048631207552, 0.019794841136899777, 0.018624286858539563, 0.01162106967967702, 0.03364636329934001, 0.026645441212167498, 0.019438767958490644, 0.05008160580473486, 0.06444680548156612, 0.060791375653934665, 0.04109677640371956, 0.07717817818047479, 0.041520282975398004, 0.004374342715891544, 0.023121898448152933, 0.03681190144561697, 0.0286708661224111, 0.06703871913487092, 0.0724312532111071, 0.024891759239835665, 0.07437980646500364, 0.04275848958059214, 0.06920438769157045, 0.03394609077076893, 0.06292348800343461, 0.10016559390351176, 0.07380849376204424, 0.01289492349314969, 0.016740855207899585, 0.028594192990567535, 0.02553674865339417, 0.020335417793830857, 0.06915947291417979, 0.09834421507548541, 0.017370955283695366, 0.06236727800569497, 0.038993570706225, 0.054952157734078355, 0.04412535119627137, 0.05201419917284511, 0.027580873829720076, 0.06510144652565941, 0.06269647245062515, 0.005537222723432933, 0.019615866658568848, 0.06286687697866, 0.03854954746202566, 0.034409528598189354, 0.02117998927133158, 0.02818736989866011, 0.017192973427881952, 0.03456697893852834, 0.02578882653324399, 0.09676845002104528, 0.03135501574433874, 0.04137376818107441, 0.06663012973149307, 0.10180569574004039, 0.03917710011592135, 0.05776544290711172, 0.044656194586423226, 0.015263510995282559, 0.019791315935435705, 0.07898907788330689, 0.015417990889545763, 0.05677851637301501, 0.020039994778926484, 0.03137347295705695, 0.03715836566698272, 0.025484169345872942, 0.0094642076328455, 0.0505382455594372, 0.13001597573747858, 0.024260063546535093, 0.0508642710337881, 0.03842711907054763, 0.008628870327811455, 0.044550319798872806, 0.031716066878288984, 0.05130222350999247, 0.03190744078892749, 0.032691278611309826, 0.029266187302710023, 0.04278715503460262, 0.09309575412771665, 0.06436277952161618, 0.04157740237133112, 0.08887550167855807, 0.0795229195500724, 0.051103992154821754, 0.05756025391747244, 0.03955458611017093, 0.05911150583415292, 0.03884159370500129, 0.034788161210599355, 0.038026834299671464, 0.05712385995138902, 0.03713532198162284, 0.03842530080873985, 0.0728811505541671, 0.03964520605222788, 0.009983300042222254, 0.0291536517397617, 0.03771509145735763, 0.02469433682563249, 0.08458660799078643, 0.02635551009007031, 0.05568507309362758, 0.11157062253914773, 0.03998819331172854, 0.056796094140736386, 0.06768918188754469, 0.05876668918062933, 0.05057722686615307, 0.03807013119512703, 0.025995772557507735, 0.03689197917992715, 0.06404140731319785, 0.019105983374174684, 0.020310845284257084, 0.008889071013982175, 0.07724111230345443, 0.03697048727190122, 0.0403318002645392, 0.03062227478949353, 0.040111464040819556, 0.022851821631775238, 0.02439008039800683, 0.018393532736808993, 0.0207249525556108, 0.03948200406739488, 0.008171950412361184, 0.011789756135840435, 0.051547254697652534, 0.018753114418359473, 0.022357178349921014, 0.020529738030745648, 0.03126856296148617, 0.030941466939111706, 0.09720020185341127, 0.021291021985234693, 0.03444830210355576, 0.015137131595110986, 0.03227436602173839, 0.02428174910164671, 0.030592223374696914, 0.02972367681650212, 0.07097845460521057, 0.06382660008966923, 0.012023048402625136, 0.04005182876426261, 0.02194168140704278, 0.03192970521922689, 0.020037330468767323, 0.0429117616295116, 0.010097412668983452, 0.04933988115226384, 0.036550606091623195, 0.03090282330958871, 0.04701760088209994, 0.03391979647858534, 0.0662845115584787, 0.036655323128798045, 0.06027239920513239, 0.02069062080408912, 0.06672931034700014, 0.04323118570027873, 0.011639069543889491, 0.04002980553195812, 0.04717483971035108, 0.06514558946946636, 0.06200767405971419, 0.052037751229363494, 0.02665666805114597, 0.030666044804092962, 0.05927970247284975, 0.024769700066826772, 0.06400845595635474, 0.027530680526979268, 0.010677597747417167, 0.021812161794514395, 0.02861988057702547, 0.06469360669143498, 0.03352010542585049, 0.12828113132854924, 0.010041659752459964, 0.023780667688697577, 0.008074364486674313, 0.05220473074587062, 0.027449012741271872, 0.045006788859609514, 0.054797705670353025, 0.04651639515941497, 0.012716103010461666, 0.031592977975378744, 0.033207167725777254, 0.0296645888738567, 0.017938759483513422, 0.031565091776428744, 0.05925163073698059, 0.035207678738515824, 0.04313635035941843, 0.06048892821127083, 0.061880262146587484, 0.05682326045644004, 0.018872566797654144, 0.024404728537774645, 0.09382409785757773, 0.045568483328679577, 0.05188243085285649, 0.0449330713308882, 0.09536475932691246, 0.017090065375668928, 0.05572423251578584, 0.08172916874173097, 0.0037489369560717023, 0.06873715377878398, 0.03622421696491074, 0.08307958065415733, 0.009961245268641505, 0.024351893189304974, 0.04787753852724563, 0.023654298493056558, 0.07886271239840426, 0.004183477640253841, 0.06480473588453606, 0.039424524729838595, 0.06196671492944006, 0.020415274739207234, 0.03259406097640749, 0.01804038733098423, 0.055605195739190094, 0.013980136354803108, 0.04378833080409095, 0.0333406132995151, 0.009526604626444168, 0.05662078030582052, 0.020240693775122054, 0.08899135835235938, 0.08320316308527254, 0.03149305150145665, 0.04136262483370956, 0.027911075740121305, 0.01655271520576207, 0.021116366806381848, 0.03204891268978827, 0.08953747514169663, 0.13016707700444385, 0.1581817417172715, 0.10377342608990148, 0.13346798659767956, 0.07134037776268087, 0.06642586100497283, 0.16851936903549358, 0.17012686090311036, 0.1305284138652496, 0.11507571180118248, 0.10503741490538232, 0.1508660803665407, 0.12321973612415604, 0.14379697531694546, 0.23815956810722128, 0.17723933706292883, 0.2869407122489065, 0.12177936107036658, 0.10842614283319563, 0.14424211549339816, 0.19056551886023954, 0.1392986549763009, 0.19450118736131117, 0.13228325173258781, 0.12327846969128586, 0.1896150503307581, 0.06323744615656324, 0.2172785604489036, 0.10436600874527358, 0.16546758357435465, 0.1790078156045638, 0.15477089036721736, 0.12772508460329846, 0.11759459070162848, 0.24431569792795926, 0.10538176400586963, 0.10050347147625871, 0.14076476771151647, 0.08123518040520139, 0.1929497573291883, 0.1684700310579501, 0.11317651878925972, 0.1314828306203708, 0.14968198374845088, 0.1077677687862888, 0.133414551964961, 0.10195367256528698, 0.09488493858953007, 0.12030043144477531, 0.05380882357712835, 0.18016054906183854, 0.08154844093951397, 0.10661937689292245, 0.19381199934286997, 0.17079653043765575, 0.07920388510683551, 0.07903759207692929, 0.08834031672449782, 0.08776759394095279, 0.1332271596766077, 0.07125736112357117, 0.11300644080620259, 0.17778696783352643, 0.105054395244224, 0.16800534271169454, 0.12597952358191833, 0.08680764076416381, 0.21494650980457664, 0.2323814734700136, 0.1332960755098611, 0.13223605114035308, 0.08456389085040428, 0.16792085662018508, 0.09613254820578732, 0.12068216994521208, 0.07513427379308268, 0.10190912886173464, 0.16053884726716205, 0.19491969927912578, 0.20371220482047647, 0.14083455927902833, 0.14081490720855072, 0.17497667722636834, 0.15167739620665088, 0.1559047881164588, 0.11270492104813457, 0.21123378246556967, 0.20928217156324536, 0.09570286696543917, 0.1258479111129418, 0.12813390407245606, 0.09770877339178696, 0.1561478414805606, 0.24374547618208453, 0.11431891412939876, 0.14148514077533036, 0.09101556614041328, 0.19901889259926975, 0.10110902687301859, 0.1589926122687757, 0.08328220923431218, 0.10814132139785215, 0.1677836335147731, 0.09852729548583739, 0.11048517961171456, 0.0676380553341005, 0.19382207770831883, 0.10290167716448195, 0.15304152300814167, 0.11299846271867864, 0.13528078619856387, 0.1328051893506199, 0.1952509643160738, 0.2743894810555503, 0.12155302829341963, 0.1473838640959002, 0.15862784668570384, 0.13029714580625296, 0.1609341151197441, 0.0977395947847981, 0.10171111644012854, 0.07626587830600329, 0.10153781753615476, 0.14737942605279386, 0.06408966917661019, 0.18499222729587927, 0.09959733142750338, 0.09744640192366205, 0.1269080542260781, 0.22247481130762026, 0.2746519341599196, 0.1567353107384406, 0.14206475811079144, 0.11756694570067339, 0.11656452683382668, 0.11563888314412907, 0.14945211092708632, 0.1267614058451727, 0.21484390046680346, 0.08145946485456079, 0.19493203377351165, 0.13721534254727885, 0.15526930190389976, 0.19700031029060483, 0.14528072148095816, 0.1641097353422083, 0.127300338645, 0.2270010660868138, 0.1289049509796314, 0.08013049358851276, 0.08866359625244513, 0.18510316353058442, 0.11884201478096657, 0.1429575914517045, 0.16802233789348975, 0.13561320898588747, 0.14212273468729109, 0.15144177916226909, 0.1779159827856347, 0.11496749924845062, 0.17982487566769123, 0.09231338204699568, 0.17575363162904978, 0.10305343152140267, 0.16874317108886316, 0.19567191047826782, 0.07788973452989012, 0.15642017999198288, 0.1771885296329856, 0.12116659941966645, 0.0818111166881863, 0.11167875345563516, 0.10102081520017236, 0.12237743561854586, 0.14801087498199195], [0.022140157670946792, 0.04950844515406061, 0.0704967265482992, 0.02805160140269436, 0.05591742468823213, 0.043903282057726756, 0.03994884835265111, 0.02900902385590598, 0.0713419659587089, 0.032135621513589285, 0.029786306658934336, 0.0537518674536841, 0.05219625170866493, 0.05401922986493446, 0.058921241434291005, 0.01834284219512483, 0.013296612778503913, 0.018161826810683124, 0.03731984215846751, 0.03942534851375967, 0.06866408191854134, 0.018523820472182706, 0.04921465486404486, 0.007915014248283114, 0.05181439817533828, 0.026090080973517615, 0.03436390878050588, 0.07134905346902087, 0.0555795656691771, 0.05219624799792655, 0.043091071929666214, 0.05994375023874454, 0.01602738968358608, 0.021632959105772898, 0.014081650097068632, 0.028007161599816754, 0.024718254389881622, 0.04200372539344244, 0.0073645521842991, 0.034904778585769236, 0.037448296789079905, 0.03469332958047744, 0.0497952110163169, 0.030761789275857154, 0.016748243288020603, 0.03125309289316647, 0.02377970660745632, 0.052514640483423136, 0.08073126213275827, 0.01384444949508179, 0.07497428901842795, 0.07057275215629488, 0.11707706144079566, 0.029126722911314573, 0.0600630059489049, 0.048839072478585877, 0.014158597823552554, 0.017396475886926055, 0.05699690074834507, 0.025155609437206294, 0.11401602139812894, 0.012270202132640406, 0.0431416901119519, 0.008058922248892486, 0.043137508109794, 0.01373532131765387, 0.03861050005070865, 0.047373260313179344, 0.03133162696030922, 0.027087596099590883, 0.02593801120383432, 0.01995910995901795, 0.03415494968066923, 0.06011848148773424, 0.01938638903084211, 0.013197749431128614, 0.06939509738003835, 0.03614222448959481, 0.07849669258575886, 0.03189072391251102, 0.013736345481447643, 0.041920523217413574, 0.010793348665174562, 0.02718494175496744, 0.04150107619352639, 0.026219925275654532, 0.033734882963472046, 0.054032870539231226, 0.020512369919742923, 0.03278139389294665, 0.02394408675172599, 0.01902042673464166, 0.04741461649246048, 0.01668784359935671, 0.04189466308162082, 0.038488769278046675, 0.04056227051478345, 0.03112932863587048, 0.0477542047156021, 0.0663106722640805, 0.043860534351551905, 0.006064449071345734, 0.04863058835326228, 0.03978733846452087, 0.045168988945079036, 0.021351904069888406, 0.04584131165756844, 0.0525080539227929, 0.024390520120505244, 0.05739965316024609, 0.042200405659968965, 0.03658854839159176, 0.08953193129855208, 0.0767027583788149, 0.03699543827679008, 0.05551415277295746, 0.021728523606725503, 0.01783703515684465, 0.08762930214288644, 0.044857754473923706, 0.022491718591481913, 0.034113775327568874, 0.07179803054896183, 0.049434857501182705, 0.09687500758445822, 0.03899969713529572, 0.014831197913736105, 0.03700583205500152, 0.00674112911838165, 0.03201211700798012, 0.04613552497175988, 0.025272434613725636, 0.023750521650072187, 0.03518791534588672, 0.021047035370429512, 0.041320719465147704, 0.009530252282274887, 0.01771492403349839, 0.03851609515550081, 0.027395457509555854, 0.10189120599534363, 0.03296066337497905, 0.013424623048194917, 0.034878269070759416, 0.08787131650024094, 0.07047583509120159, 0.06844908915809356, 0.012220626667840406, 0.025438547672820278, 0.015485264721064596, 0.07378298614639789, 0.01177917589302524, 0.04916387712000869, 0.055467980055254884, 0.02543572936701821, 0.036869035684503615, 0.07051342487102374, 0.038164740180945955, 0.05203185115533415, 0.004506511331783258, 0.08702437757165171, 0.03810591755609494, 0.026248100912198424, 0.08363479617401026, 0.010562566712906118, 0.07695489563047886, 0.05370423641579691, 0.060562055732589215, 0.013247245115053374, 0.04168411949649453, 0.031041165202623233, 0.06379833910614252, 0.01593876426341012, 0.05552596034249291, 0.029241817028378136, 0.006933837039468926, 0.014167109329719096, 0.04016737744677812, 0.02116143557941541, 0.035532075198716484, 0.04093983814527746, 0.058448716008570045, 0.016798258475319017, 0.015524340651609236, 0.046242290336522274, 0.05718874221201986, 0.06698771132505499, 0.05595826878561638, 0.01732707580231363, 0.06990231078816578, 0.07333323723287322, 0.03078722638747422, 0.04321362648624927, 0.034956328163389117, 0.013048053606325993, 0.014817125866102288, 0.06432188718463294, 0.03345804332639091, 0.04612554679624736, 0.04168458704953082, 0.029129643262422178, 0.023067495312716346, 0.0432199050555937, 0.05683313473127782, 0.11097645910922438, 0.06382099687471054, 0.05314940310199745, 0.02944098163425224, 0.05890724452910945, 0.041259451463702135, 0.0549492707796162, 0.027845224976772442, 0.041541044556652196, 0.031770280766068026, 0.013551526590163121, 0.0160784216132015, 0.050768407818395644, 0.041147828742396086, 0.03564225073205307, 0.09348247243906371, 0.03805152926361188, 0.0347351013624575, 0.05083903801278211, 0.03445695554546546, 0.046087942173471674, 0.020345446064311545, 0.05116288528370205, 0.049285756322206, 0.06203950477356557, 0.01729634346702369, 0.04652224699384533, 0.05448769574286416, 0.03097648517723428, 0.029348656607908197, 0.07810186260030605, 0.015766118449391797, 0.03733151614142116, 0.04543151626421604, 0.03822529200988356, 0.00848394929562346, 0.045791936572641134, 0.047617694071959704, 0.010825321314769099, 0.022364340075000655, 0.0338642318820348, 0.025751990033313632, 0.04514299893344287, 0.027538857139006723, 0.050568098449730314, 0.037563307414529845, 0.017258260158996563, 0.06892513236380182, 0.04963561586919241, 0.040493684937246144, 0.007596522964377073, 0.10755026756669395, 0.02451559055771213, 0.01800242276658537, 0.011333608053973876, 0.002719079961934767, 0.014439566584769636, 0.019350682450749446, 0.0069761315717187244, 0.09175085637252778, 0.029687432179343887, 0.05869372493179981, 0.034196183405583724, 0.03688648357638158, 0.047040844947332516, 0.01763570347975474, 0.07883957223384641, 0.048528687766520306, 0.05033157598518301, 0.05532695344300009, 0.07415163316181861, 0.021796064611407928, 0.03387187600310426, 0.02546196057664929, 0.09520098959910683, 0.023106487751647364, 0.020868808605882805, 0.025743412661540788, 0.05100391725136433, 0.05892420631425921, 0.028733015424222685, 0.0650596636114642, 0.030064166749070864, 0.026599272205203306, 0.03735307553142775, 0.04476581721974071, 0.07344514568103477, 0.04489061677304562, 0.02422540153929731, 0.04804770927876234, 0.027094859869976062, 0.06901937027578242, 0.0377936663426226, 0.0227060248653288, 0.017834960854088422, 0.0340255302580772, 0.05967730437987484, 0.08756464623729698, 0.03475355486443732, 0.03891049840603955, 0.06580204877536744, 0.040467038124916144, 0.024792962685751263, 0.042110127105843276, 0.07707619966822676, 0.04942165840475354, 0.0313412600371521, 0.030177379521774128, 0.015049295634526061, 0.059893762881984, 0.012196056941320421, 0.03172400043695234, 0.038811514459666796, 0.017003684952214826, 0.03617064132413361, 0.05172712160856463, 0.03136512008495629, 0.0059654943470377475, 0.0357032181636896, 0.026725346397142857, 0.03095202955591958, 0.08988877816591412, 0.08224378878367133, 0.028347866755211726, 0.0106988370862382, 0.05851243309734855, 0.017017657737596892, 0.04792675033968408, 0.026060426607728004, 0.018455823046679143, 0.025234514578187373, 0.02487591624230845, 0.04011359029391315, 0.02933799936727155, 0.06454819027567282, 0.07118975889170542, 0.02911525487434119, 0.04021542779810261, 0.006764293402738986, 0.0034864968392867013, 0.06249261190532707, 0.03186155008734204, 0.03402229449420702, 0.020104604300286155, 0.04728699306724593, 0.06173205896629952, 0.06362749671097845, 0.010699592221499188, 0.08784874778939411, 0.116069143259665, 0.1271275815088302, 0.06899090149090625, 0.08395024604396895, 0.13591002352768555, 0.12235465910634957, 0.18174019554862753, 0.2191664357087575, 0.10084338253363967, 0.1786693072062917, 0.13137103349436074, 0.12606837350176647, 0.17950281326193362, 0.1384135548141785, 0.0852685674908571, 0.09206701870425604, 0.13072699774056673, 0.1032061135629192, 0.08916852384572849, 0.17912149778567255, 0.07131153048248962, 0.15102794277481735, 0.1323351130122319, 0.18758128368062899, 0.08327763760462403, 0.29547731042839587, 0.16560379735892639, 0.24172665638616309, 0.16492062073666602, 0.15728558355476707, 0.15138846327317879, 0.08546541474061087, 0.17149567807791755, 0.12753402610542253, 0.19017960206838325, 0.08637739549158141, 0.043390361533965915, 0.10712321352912113, 0.10876753818592988, 0.13542342698201537, 0.13661015080288053, 0.11056261530029587, 0.19597445440012962, 0.10275907348841429, 0.0700429551943671, 0.1330151577712968, 0.17045186221366748, 0.21071687660878524, 0.10628910633386113, 0.11009584151906893, 0.11291336064459756, 0.1800358682521619, 0.10119002487044781, 0.19282195949926972, 0.2104408570448868, 0.09077753711608239, 0.15029220725409687, 0.1597640450927429, 0.049358898686477914, 0.18662000948097557, 0.1296484938939102, 0.1493282019509934, 0.11727252829587087, 0.09878192635369487, 0.17448136786697432, 0.14632070786319673, 0.17553463869262487, 0.10119961341843009, 0.08238547219661996, 0.10076628823298961, 0.07137626802432351, 0.15559549065073952, 0.10986774985212833, 0.12912005506223068, 0.13653739064466208, 0.18348670651903376, 0.13694156426936388, 0.2608720329590142, 0.14125344227068126, 0.13696287875063717, 0.09549012291245162, 0.0648157716204878, 0.20665630465373397, 0.1877401626552455, 0.1027737234835513, 0.11431614591856487, 0.08777234368608333, 0.11898601369466633, 0.13731556216953322, 0.11518797648022883, 0.11679771705530584, 0.12487878499086946, 0.07899626187281683, 0.21525757358176634, 0.12487407977459952, 0.1305896113626659, 0.16857059206813574, 0.18675663886824623, 0.20085885480511934, 0.10728630790254101, 0.10142431347048841, 0.20947802433511242, 0.1347818403155543, 0.11474813523818739, 0.15371609071735293, 0.12052219259203412, 0.1457668430521153, 0.08822430419968441, 0.1353551642387174, 0.1687146577751264, 0.12397338708979078, 0.2072077797492966, 0.2131798124173656, 0.17017747537465766, 0.12151436239946634, 0.11944221929297782, 0.1690233318367973, 0.10632334160618484, 0.1740016881376505, 0.07978626323165372, 0.18785636813845485, 0.14204881677869707, 0.18904025695519522, 0.2505821257364005, 0.18487795139662921, 0.14346017385832965, 0.14157972007524222, 0.12954043719219044, 0.14981453132349998, 0.056626528239576146, 0.15517683030338958, 0.13605195184936747, 0.1442223446792923, 0.16379828564822674, 0.10349762174882926, 0.09568763067363761, 0.1212058070814237, 0.14515393297187984, 0.08542239243979566, 0.20583326288033277, 0.09175171726383269, 0.18617509194882587, 0.1449182565556839, 0.2215507038636133, 0.11928663545404561, 0.18731139425653964, 0.10195960232522339, 0.15469216334167868, 0.279554650769569, 0.1278174523031339, 0.1235138344054576, 0.2548284869408235, 0.14245509810280055, 0.08014607868972234, 0.12688602728303522, 0.17733514832798392, 0.11433038773247972, 0.08313602840644307, 0.11007346576661803, 0.14471091533778235, 0.237911794683896, 0.12094385121599771, 0.14307946694316342, 0.11151775936014019, 0.14777775155380368, 0.12810821091989055, 0.12271909072296694, 0.11466212032246403, 0.164229933579918, 0.1600707450415939, 0.298537511844188, 0.11139953523525037, 0.16382412723032758, 0.15183913987129927, 0.11641462042462081]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05224197171628475, 0.0429396700928919, 0.05119740999361966, 0.03417187064769678, 0.12705068016657606, 0.040590242060716264, 0.05286575797072146, 0.030646207196696196, 0.017109745276684407, 0.026745497561933007, 0.0636862896499224, 0.013164226620574482, 0.04332880038418807, 0.018507487657188904, 0.036719793497468345, 0.0739798259746749, 0.07892474852269515, 0.005658651070916676, 0.02311354186531389, 0.06033344456227496, 0.029077633553242777, 0.009390023478772491, 0.0064087963164638495, 0.06847034426755272, 0.0107030200160807, 0.033722993757692166, 0.03734113066457212, 0.10631890356307849, 0.05109966172312852, 0.06818677706178278, 0.04989123379345983, 0.008216422684199642, 0.045047644089208916, 0.0697329304239247, 0.005700700230590883, 0.04714861592219677, 0.04211376734019723, 0.06799990427680314, 0.06946425070054829, 0.03516518707328942, 0.021311609161784872, 0.02936535864137113, 0.013608157096314244, 0.034621649247128516, 0.04451397682714742, 0.029214583919383585, 0.07527102934545837, 0.0561417833523592, 0.031747719476697966, 0.034652919639484026, 0.014677424915134907, 0.03209937131032348, 0.024557252872909885, 0.07485561218345538, 0.053758405774715357, 0.07009803739492781, 0.06096345743571874, 0.007828939960745629, 0.030933934140193742, 0.06857913569547236, 0.026502234541112557, 0.004665191781896283, 0.04604515364917461, 0.031285658333217725, 0.03565963554137852, 0.025810115039348602, 0.022663904273940716, 0.024388020938204136, 0.02043007501924876, 0.012323817663855152, 0.026948612248816062, 0.05476818303577602, 0.018125693495676387, 0.18453927972586825, 0.058803625870496035, 0.019439758725638967, 0.0368546973913908, 0.010227354378002929, 0.03499683829431888, 0.01803781578928465, 0.014347113537951373, 0.07418997993227094, 0.03013120309333317, 0.055704714031890035, 0.023053101358527783, 0.043976290835416876, 0.09472962934523821, 0.08457546835415997, 0.06416100441128947, 0.05215620913077146, 0.09551705545163713, 0.012928917567478493, 0.03212374715076294, 0.06348130104015581, 0.01815848158003064, 0.06417200303985737, 0.08309506185469218, 0.03356260080181528, 0.03025644793524407, 0.02443322886392707, 0.03748496630578302, 0.042122943996218964, 0.05334105160727631, 0.03654774140159134, 0.03284843209257815, 0.07624593679793179, 0.05952470026386436, 0.020432063975022174, 0.043893218535231426, 0.0506845377094578, 0.05502520361915231, 0.055549460448673926, 0.042514426895650104, 0.012482327420002548, 0.03631527848483529, 0.03273201880801935, 0.018961913956445642, 0.041854067603708245, 0.009552176252327627, 0.03500355473079253, 0.033124095425591804, 0.035775351207121275, 0.0038948680048633832, 0.04284094589820597, 0.06468997758929618, 0.03491602583380882, 0.08927497008698992, 0.042702264472609386, 0.05459680629428476, 0.04279002343537286, 0.05725102324504405, 0.0652346175047569, 0.04638725775294006, 0.02156160717277089, 0.03097503798926482, 0.019823803449980915, 0.04934101663820911, 0.10416761782835238, 0.030213579630071763, 0.049394610832678154, 0.0420353594381595, 0.00641801193523861, 0.12250111452885903, 0.058064725089934655, 0.016232573107117787, 0.023148638028942514, 0.020789365407836158, 0.0496686154656345, 0.03818138655333314, 0.03960139336413704, 0.062282650906126946, 0.03302881108538713, 0.013080398257443449, 0.07970802602358162, 0.011005414580722572, 0.019434647183516063, 0.05265040155791212, 0.012310822658037068, 0.024420200461463537, 0.031142609368544072, 0.07212435288238339, 0.059111773007316515, 0.011715052478393773, 0.04114206225494854, 0.013937707772129215, 0.018696505248954054, 0.03866118873702362, 0.03949821257265285, 0.033924126910278574, 0.025145857616735157, 0.022150430850160774, 0.08616219492978416, 0.025310324963356834, 0.017662608188402373, 0.06261313668801449, 0.038547031581401825, 0.04731224093120545, 0.025219096460205037, 0.05235001728578936, 0.03854513168334961, 0.01899404338473687, 0.013566664547397522, 0.050396662336424924, 0.06281902329646982, 0.03888145445671398, 0.03580359734769445, 0.03982895068475045, 0.024530802729714196, 0.04313912599172909, 0.020285324681026395, 0.013311260918271728, 0.04656631572288461, 0.04358093392511364, 0.018731256313913036, 0.04559474422421772, 0.03239778889110312, 0.015846903079363983, 0.024995079184009228, 0.047429700643988326, 0.070140710886335, 0.04956172764650546, 0.05074479639006313, 0.045672176202060655, 0.06772917622583918, 0.0571947536082007, 0.02231285543530248, 0.025398536636203062, 0.04783886150107719, 0.017899896920425817, 0.05415927684225608, 0.034341351201874204, 0.02563132053182926, 0.053242924841470085, 0.01712143039185321, 0.04192688713374082, 0.012627911746676546, 0.02845608672942035, 0.07126171010895632, 0.025109681628237013, 0.03246045955165755, 0.028507183596957475, 0.06496667250758037, 0.030411386105697602, 0.05862348436494358, 0.014351026511576492, 0.02463538618030725, 0.054385817420552485, 0.04286323630367406, 0.02645377600856591, 0.046102506821625866, 0.02686359923245618, 0.08326900642714463, 0.06766193764633499, 0.013083775957056787, 0.02908537229814101, 0.04067234585818369, 0.052559210162144154, 0.013210919769335305, 0.030868216963426676, 0.02759813804004807, 0.0960548676084727, 0.01556480347062461, 0.031450162787223235, 0.07014025817625225, 0.04527250370301772, 0.05116169042594265, 0.05271211855870206, 0.08460140641545877, 0.05493970820680261, 0.0315637076710118, 0.09640379576012492, 0.020485507884586696, 0.019258184875070583, 0.06199832299898844, 0.044171193658257835, 0.008515043427905766, 0.06876518469653092, 0.03654639069281984, 0.03998329884780105, 0.04194897715933621, 0.05231027527770493, 0.009022030480991816, 0.030986231431597844, 0.05049215447797906, 0.07865233579650521, 0.06887544557685032, 0.07867910506320186, 0.023766134581819642, 0.026842030565603636, 0.015075631672516465, 0.026586887615849264, 0.02174431094317697, 0.0254572664925945, 0.03516198841680307, 0.03657807668787427, 0.03705912567966152, 0.05016065937525127, 0.04252893959346693, 0.03355688997544348, 0.025441599755140487, 0.06832654573372565, 0.08891807126929052, 0.07978627807460725, 0.04324198765971232, 0.059011531120631844, 0.04608798670233227, 0.0707073109515477, 0.06739476448274218, 0.019543620437616482, 0.01643032763240626, 0.03325523292005528, 0.034695997601374984, 0.018716554368438665, 0.02099091601849068, 0.07860806668759324, 0.017726636979205068, 0.04164590260188561, 0.0431300495256437, 0.0275204259014572, 0.0368782902660314, 0.058533109331619926, 0.025991961629188154, 0.02229594003438251, 0.01297145561693469, 0.02423656715109246, 0.04023090528789908, 0.053261597277014516, 0.022798064164817333, 0.03447891940595582, 0.04709720735263545, 0.01899039387353696, 0.07817771751433611, 0.03968362703744788, 0.026750455108413007, 0.004616390006049187, 0.039242713392013684, 0.05426669529697392, 0.035635749518405646, 0.02881639200495556, 0.045313306982279755, 0.0022493322558148066, 0.01882570573798148, 0.051841312160831876, 0.0362720075645484, 0.018784557360049803, 0.06609728996409103, 0.02829236338584451, 0.048553093292866834, 0.01051771594575257, 0.025092897958529647, 0.0206025185980252, 0.03163151028275024, 0.04513265339483041, 0.0314701339812018, 0.024805703505990095, 0.045496172169805504, 0.02878181720006978, 0.03769828923395835, 0.027698376215994358, 0.05568174456129782, 0.04726031285827048, 0.025569943063601386, 0.029043878821539693, 0.031236361173796467, 0.02512677699996857, 0.023693520997767337, 0.07617976691108197, 0.019898003374692053, 0.03298686489870306, 0.020139136431680527, 0.029171878886700142, 0.045383651449810714, 0.23575196682941169, 0.13702070689760149, 0.20334411441581324, 0.09320334327640012, 0.21574915735982358, 0.152305475785397, 0.13425150158582255, 0.19173686538124457, 0.10815786386956461, 0.16405171423684806, 0.10754716538940556, 0.13854991702828556, 0.16906484757782891, 0.13240025873528793, 0.09781989516341127, 0.21446541999466717, 0.14958299609133974, 0.12597625813214108, 0.13764189934590831, 0.1275670516770333, 0.06817452420364134, 0.10784840313135646, 0.1171921833883971, 0.15647636057110503, 0.10565998774836771, 0.219229533104226, 0.18217873061075807, 0.1938576265820302, 0.1612710946938023, 0.09653571993112564, 0.1585907393018715, 0.1639284286648035, 0.09576029435265809, 0.1760205821483396, 0.2060703790630214, 0.13017500314163044, 0.10300716603524052, 0.14462657767580822, 0.15494002582272515, 0.10907092073466629, 0.10822723983437754, 0.12244475583429448, 0.16219564742641523, 0.13936360774096102, 0.15034614654723555, 0.10979430691804737, 0.17663128062849864, 0.20354482083348557, 0.11518823623191565, 0.18087532633217052, 0.1670698804082349, 0.12494399008573964, 0.22124246024759486, 0.14009702776093036, 0.13258330203825608, 0.18357435415964574, 0.17168443591799587, 0.12237482325872406, 0.1339460929739289, 0.1490183107671328, 0.1450331261730753, 0.18093515827786177, 0.13704326818697155, 0.09558117701089941, 0.1519693125737831, 0.06798963295295835, 0.13379525888012722, 0.11771996913012117, 0.13756434491369873, 0.11980112190940417, 0.18449200491886586, 0.2554996556136757, 0.2775497536640614, 0.28201938257552683, 0.17102367215557024, 0.11920952631044202, 0.10551876446697861, 0.11976295325439423, 0.14260354248108342, 0.09109723207075149, 0.16611926344921812, 0.08668975802720524, 0.0867238077626098, 0.16646796895656735, 0.11999801368801855, 0.08026715266169049, 0.1160951035853941, 0.12516691640485078, 0.14403667417354882, 0.1885900553315878, 0.1432503093383275, 0.12698960141278803, 0.12824823934352025, 0.2162725050584413, 0.07856727825128473, 0.12568364414619282, 0.10977829137118533, 0.1352213995414786, 0.23035123944282532, 0.10398610334959812, 0.09086399732041173, 0.21543938491959125, 0.08969072121544741, 0.10658434010110795, 0.10744067461928353, 0.21431308676255867, 0.14835419249720871, 0.0662584399105981, 0.1537333382293582, 0.14254176610847935, 0.15192767808912322, 0.1290774706285447, 0.1839199723326601, 0.10548385384026915, 0.09709918071166612, 0.16801835998194292, 0.07274361574673094, 0.11879442085046321, 0.1803470656159334, 0.11562386207515374, 0.18171232048189268, 0.17906046356074512, 0.07646023193956353, 0.15231380268232897, 0.15300779981771484, 0.0957751001988072, 0.1998928902321495, 0.10553452026215382, 0.1588612818159163, 0.1097347198810894, 0.12409311035298742, 0.09794790821615607, 0.07166610637796111, 0.17569656047271565, 0.19226775330025703, 0.14617045264458284, 0.16407982679083943, 0.15895192773314193, 0.0996884003689047, 0.14659769221907482, 0.15061706013511866, 0.1591074967291206, 0.2287458849605173, 0.15693692257627845, 0.08432465212536044, 0.0849437368742656, 0.07670639490243047, 0.16484898864291608, 0.08983066800283268, 0.19641667051473632, 0.1541392781655304, 0.1359428116120398, 0.09864175692200661, 0.24527961417334154, 0.10942806446109898, 0.09342213583295234, 0.1678650322719477, 0.13266205874970183, 0.1345209457213059, 0.1153067201084923, 0.11567420195206068, 0.12680094747338444, 0.13394561799941584, 0.11698432266712189, 0.13402943615801632, 0.07415436426526867, 0.14104387460974976, 0.05387250355852302, 0.1477623890968971, 0.16701010783435777, 0.12107115180697292, 0.2514304599026218, 0.07601532925036736, 0.07909084117272869, 0.21586690651020035, 0.11798405495937914], [0.056656225278857164, 0.039410583485732786, 0.049556373051018454, 0.032351182017009705, 0.016174672600755002, 0.02796448810840957, 0.030608578454121016, 0.028025132705806755, 0.01049848782713525, 0.05361678544431925, 0.022145267357700504, 0.0906800634402316, 0.03936516404792201, 0.03874647263728548, 0.024035981332417578, 0.03410501798498444, 0.0459555207635276, 0.02249660563393263, 0.02645127497089561, 0.030069115018704906, 0.08793970540864393, 0.0814953625376802, 0.0511983079923084, 0.04148594009166118, 0.044155664218124, 0.014769675726711284, 0.017082996419048868, 0.0838441782980226, 0.015544665293418802, 0.026320477008994203, 0.07085501318215393, 0.06873103106045164, 0.02076661116007017, 0.047408746104338206, 0.06275392210227437, 0.018130600947188213, 0.05165577895240858, 0.035665320392581634, 0.03634232605691068, 0.04671954324294347, 0.07380290539003909, 0.01483877709688386, 0.009868220768112224, 0.005446309633043711, 0.016308680351357907, 0.06713821887387894, 0.03143800640827976, 0.026457611056684982, 0.04128396831220016, 0.023126997002691496, 0.03221522056264803, 0.05643141019390896, 0.0362819894507993, 0.04110071349714417, 0.0818990240804851, 0.04831986967474222, 0.0274504896151484, 0.05679016809153836, 0.0256861986417789, 0.02605229637993034, 0.03532495662511792, 0.014856204579700716, 0.012713265223283088, 0.04108732515305746, 0.04791788538568653, 0.02409452194115147, 0.013232094170234632, 0.047048303531482816, 0.015038979781820672, 0.044207881728652865, 0.01243504890226177, 0.03317478782264516, 0.03104436385910958, 0.03393613485968672, 0.04366813627711963, 0.03788869464187883, 0.01374015269902884, 0.04209351413010154, 0.03127559109998401, 0.045934477166156285, 0.04434080779901706, 0.04744317433505785, 0.04417997697601095, 0.027542506650206633, 0.04207537975162268, 0.036536560946842656, 0.0534399836033117, 0.02272755456942832, 0.045057065653963946, 0.0424638124241028, 0.022126414951344486, 0.007325207225221675, 0.0720585318049416, 0.0170501675165724, 0.018292261120222975, 0.04157723538810387, 0.013703921049454948, 0.010370942327426746, 0.0735967219225131, 0.029780495642626192, 0.0802284422388766, 0.12083495588740334, 0.04484209515794646, 0.04188448452623561, 0.007866543655836722, 0.01869229912699666, 0.04402394413773436, 0.03441670516622253, 0.027720822472474538, 0.0466194126784103, 0.05609846790321171, 0.05099284440802876, 0.01789973921404453, 0.01633506555663189, 0.0469545999658294, 0.03925898497982416, 0.04006012597528752, 0.024592009503976442, 0.05133525650308002, 0.03807885143032763, 0.019595008598116692, 0.031669589880038984, 0.03266333675128408, 0.03005504946486326, 0.021022412765887566, 0.037409935175674036, 0.00827304762424319, 0.02957335480459733, 0.10306433367077261, 0.03979157241701614, 0.028223367771715857, 0.05619981558993459, 0.006426246991395601, 0.053457245958270505, 0.07324534468352795, 0.011735163752746303, 0.15538003033725545, 0.01954497300175717, 0.03191174895619042, 0.04659465092117898, 0.050067883494193666, 0.01574916223034961, 0.011311261987430044, 0.011354150701663457, 0.022750566713511944, 0.06226608616998419, 0.04891388838586863, 0.04930202791001648, 0.015475335712835658, 0.05091952392831445, 0.017844399117166176, 0.03417484665988013, 0.018985054121003486, 0.07783338325680234, 0.022421765606850386, 0.04941447070450522, 0.0187329688196769, 0.06912672193720937, 0.02274329923238838, 0.07695613501709886, 0.008964378594100708, 0.036931201684637927, 0.017219288129126653, 0.029728617664659396, 0.08206876067561097, 0.020573079455061816, 0.06346859547193162, 0.022002351979608648, 0.026248974791087676, 0.024920094438130036, 0.03587286941183265, 0.012869421443610918, 0.015444415057572769, 0.02909663067839574, 0.025487163911748212, 0.0268851734654163, 0.029427068220684305, 0.023946270521264523, 0.06041037187969778, 0.022436003710026853, 0.03704198206833098, 0.02681615744222654, 0.048372042656410486, 0.04422280260769185, 0.03069323895033449, 0.043121589042129926, 0.024644295663165394, 0.02687045853235759, 0.06934802295290865, 0.06471651679021306, 0.06647125817835331, 0.022920548217371106, 0.06411839771317318, 0.076759926014347, 0.010386050598754082, 0.022620234449277632, 0.05243311185040511, 0.04619173894752748, 0.068939522607252, 0.0437051249173237, 0.061960558814462274, 0.0282704329219996, 0.05539075587876141, 0.029136454322724603, 0.03266316605731845, 0.0451890046679182, 0.0313088356051594, 0.09456331405090168, 0.05156784187420271, 0.00803403618192533, 0.03414086371776648, 0.04925382541841827, 0.03964693896705285, 0.06120310063124634, 0.014706310230394593, 0.0230450416347594, 0.06746739847585559, 0.058934002663590945, 0.05910420310101472, 0.012027915036014747, 0.030788037183810957, 0.04789583988895174, 0.01078223222066299, 0.06040158485120628, 0.0868140603415668, 0.019470697006909177, 0.004192266060272232, 0.05672285158652812, 0.03357429704919923, 0.03505780943669379, 0.02862030731193954, 0.054511912021553144, 0.08745940969674848, 0.03955876440159045, 0.069729234528495, 0.01601583444426069, 0.030580595775973052, 0.09215215046424419, 0.020908893857267685, 0.018687564224819653, 0.0263615326184663, 0.023656439589103684, 0.023011878765828442, 0.029917969222879037, 0.04079743484908249, 0.015901517726888414, 0.07186929899035022, 0.02155590191250667, 0.03270851870183833, 0.02219156624050811, 0.043804739689221606, 0.036826462383032776, 0.026959015303873457, 0.020291556866141036, 0.05984369388897903, 0.08297684515127912, 0.03012679844687227, 0.05326408347173128, 0.07511701885960065, 0.024639429029775783, 0.019475033004709985, 0.03145251168461982, 0.06093696647440083, 0.03937251502065919, 0.0416327369021019, 0.029293247862369753, 0.0179943815965089, 0.0490866566542536, 0.07684260868700221, 0.017366982938256115, 0.04823117189516779, 0.03613759719883092, 0.016777804885350633, 0.041911572916433215, 0.01925071144796675, 0.02155376638256712, 0.03474227793049067, 0.016407044604420662, 0.08100211634882726, 0.0339325317327166, 0.04835213454498444, 0.03790294758800883, 0.026353745633969083, 0.07046339669614099, 0.060642671523964964, 0.04614088327798527, 0.07441368550644256, 0.024176191582228057, 0.0830171734560281, 0.020952647173544392, 0.034219572189613245, 0.028133386076660827, 0.023600889835506678, 0.012564753124024719, 0.020604129058483522, 0.021974645751470234, 0.015123987232072977, 0.021066832159704063, 0.05707176118448842, 0.03497867794067133, 0.0241612651370815, 0.06709237641189247, 0.005590145738096908, 0.03779529164603446, 0.05350720733986236, 0.0453165946964873, 0.08090843504760414, 0.12032675542286597, 0.04572118392388802, 0.05501541840203572, 0.01507798335296684, 0.05744959598814603, 0.08510528015904129, 0.04483644741412718, 0.08271698956377804, 0.03260595018218737, 0.024042415752774104, 0.018270618238602765, 0.02336251756787533, 0.03383267576282378, 0.036884309083689004, 0.06964313797652721, 0.02074692012683954, 0.04523921095824335, 0.020715540267701726, 0.027515334768395405, 0.028195800696266815, 0.0486895445646951, 0.028361030599626247, 0.0333584730833536, 0.07218796235974878, 0.06295955638051964, 0.08252465457189828, 0.07613650712301023, 0.07685712509555742, 0.042912351636914536, 0.03488744572678115, 0.012284930980968056, 0.004679190078604734, 0.054529849730897695, 0.11517257691593841, 0.06360240469803102, 0.04854098515352234, 0.006112408973422134, 0.004446618622750975, 0.057990877685369924, 0.05422881607955787, 0.034736600500764325, 0.03675412524899002, 0.008200316224247217, 0.04301415574445855, 0.049234032339882106, 0.17430156032787636, 0.19025228801183403, 0.1395477939513512, 0.1470336742931977, 0.1210794564394746, 0.13121709722327068, 0.15138895309064537, 0.19757833943003789, 0.14516659401124343, 0.20033105422044173, 0.12181935540866107, 0.12395015786751173, 0.24728859309107065, 0.1639420396531932, 0.2295286874868907, 0.14070196717511863, 0.1563904495560564, 0.19002127228304744, 0.06898736144648865, 0.08944642104324885, 0.16787037573521957, 0.14635100233135745, 0.13879700767574832, 0.20950981794157997, 0.1574323803652078, 0.15753521234728396, 0.15540836553554982, 0.11987627178314142, 0.1106408005580306, 0.1781835567089729, 0.1583083817968145, 0.14311002858448774, 0.21095023752423003, 0.1660097372950986, 0.20706645998870954, 0.12628614931600168, 0.20025499892653897, 0.20054066641023383, 0.14824067358858883, 0.18852099106879905, 0.11987148493062705, 0.20317601796705276, 0.14036841632332653, 0.09538476762827486, 0.10562274677795358, 0.23507646401412785, 0.1785913371713832, 0.09144063122221269, 0.1576514623593539, 0.13217279047239572, 0.14127966976957396, 0.12544623110443354, 0.16988925490295514, 0.1721866027219221, 0.1634448897675611, 0.15226413815980777, 0.15642856626072899, 0.12215680253575556, 0.13072641886537895, 0.17018197278957814, 0.0936055279453285, 0.2604309003800154, 0.10387023925432004, 0.11375818445230834, 0.13627296342747286, 0.0861325535515789, 0.12723700376227498, 0.12863878713687882, 0.17644221108639613, 0.09511815107543953, 0.12516292365035042, 0.09400014270795509, 0.09509879586403258, 0.0980595569126308, 0.1190850384591613, 0.12465143547160551, 0.18169476126786321, 0.17726994323311374, 0.11073618879891, 0.14510999782942235, 0.10815410860232078, 0.11941231074160896, 0.1292454038048163, 0.317115664947778, 0.17408958810847253, 0.18781923106871545, 0.15174809319432825, 0.10972682342980988, 0.08857994878781028, 0.09868074193946086, 0.08611058598035015, 0.1298117366968654, 0.18458800914231688, 0.07311698282137513, 0.20686523406766355, 0.12289018544834107, 0.06730181790771894, 0.11343666381435469, 0.1190648965712171, 0.08883938877261244, 0.20774473843630403, 0.14765203173737973, 0.15589655027724802, 0.1567246238118969, 0.12227182800415903, 0.12025398784317076, 0.1051560472114943, 0.24865818209946156, 0.1875816992833279, 0.15982016630005091, 0.2174559040577151, 0.10617948370054364, 0.14942855515982956, 0.08858166314894333, 0.14451567112701014, 0.1815102930413559, 0.15730152488686144, 0.14641595509601757, 0.14231863198801875, 0.16761806036811322, 0.197440032789018, 0.149044998397585, 0.2836149407085031, 0.1572531517012976, 0.07585779356304556, 0.1352590709575452, 0.16454654862172902, 0.12815860274713486, 0.12443400104530156, 0.10849645390408114, 0.18768451642245054, 0.13724349963013083, 0.17913809220772237, 0.22429642762290314, 0.11853550779051147, 0.13752072147326544, 0.16465617867652327, 0.09566134380293079, 0.2163166628452018, 0.1333932374836877, 0.15321854007197544, 0.06819503716542386, 0.09115181703236885, 0.07060385556542315, 0.11167729142471217, 0.16729212395148352, 0.0963549104926642, 0.1482601327006705, 0.13705089746508747, 0.15316509059630334, 0.14562233205651864, 0.11370815627742559, 0.121525368449511, 0.19083123741438612, 0.12459645717171952, 0.172723546565976, 0.10662754051736556, 0.15225615265080705, 0.1276798581238836, 0.16206884407438338, 0.12536778609501198, 0.13456372311338782, 0.08616243241704069, 0.1271925788023509, 0.20944108022376895, 0.1546864488045685, 0.12428811707650311, 0.06705847510602325, 0.1466065683052875, 0.13358765048906207, 0.17891310271807015, 0.14019274996826425, 0.09519934203126468, 0.1059182254539337, 0.18309041450265795, 0.1871062646387145], [0.02309016235813033, 0.05279165452520829, 0.026003138373198453, 0.03415928753383923, 0.009735495077620726, 0.034028914451482706, 0.08098292440990917, 0.022237256562220864, 0.013623513987113256, 0.06291804063948803, 0.027603642920439597, 0.05816043987579178, 0.05613877765426878, 0.04614603007212281, 0.02666545879037585, 0.05050153151387349, 0.023424366299877875, 0.020534587965812534, 0.0689322866674047, 0.028845996275776997, 0.02466322599502746, 0.008110502440104028, 0.07859450022806413, 0.018978204097948037, 0.00970895123828086, 0.006167672536321334, 0.030769372169743292, 0.014224775131879142, 0.048745175954536535, 0.01431808814231772, 0.038497927380376495, 0.06197959490236826, 0.07306532934308052, 0.02642513096361654, 0.038332539770635776, 0.011421139734011376, 0.019097652766504325, 0.046228026258177124, 0.02809705609251978, 0.02059383175947005, 0.015765888383612037, 0.005576695239142282, 0.04236831657181028, 0.012912045767734526, 0.04001824287115596, 0.0770708784693852, 0.023209759456221946, 0.02476025252690306, 0.03787906527577434, 0.03679246459796559, 0.022794952710682992, 0.07225057735922746, 0.016473663490614854, 0.0906032659986522, 0.026957970731018577, 0.03640976130554918, 0.026114900247193873, 0.04355575285444502, 0.05312189539836254, 0.015955813250911888, 0.024296352712553926, 0.03742498593055643, 0.026015398652816657, 0.0448188696464058, 0.12214310248964466, 0.04737039562314749, 0.07757725325063802, 0.04548441283986904, 0.10295736792613752, 0.027205399055674206, 0.053559012958430685, 0.0414409844961483, 0.03205339526175521, 0.029536785477830563, 0.020550429107970558, 0.019681505909829866, 0.03715171602379996, 0.022775009347242303, 0.027284166899335105, 0.06489677703939378, 0.03412028025195468, 0.04964713400113396, 0.03436778279137798, 0.03098403467447497, 0.04554825609375257, 0.01791580485587474, 0.04423632824909873, 0.04310115400585346, 0.02716964423598256, 0.02888060076656984, 0.0394126614992274, 0.028839669466833584, 0.04906208414467983, 0.03729875403223559, 0.02532280788727803, 0.07291187546798028, 0.027639282707241364, 0.02063604140857933, 0.059617361112032086, 0.06656047917203978, 0.030441994131251704, 0.03680489557154942, 0.07501065425458364, 0.05114526669785846, 0.013869092508684844, 0.03323476448713336, 0.024368649028474465, 0.047988419100875035, 0.003739642020264, 0.02591102856968064, 0.06119979436334688, 0.022508522670250386, 0.02320999323274009, 0.05654528162267525, 0.0153441286420275, 0.04174482717644423, 0.033384733978891745, 0.03689459525048733, 0.032466374468640424, 0.04230074773658998, 0.09357691815239377, 0.04910934410872869, 0.010985910012095701, 0.013721680643357104, 0.030534745892509818, 0.02496988141501788, 0.0307299975247588, 0.042897798120975494, 0.03962999202485662, 0.036404210040927865, 0.029493028450815473, 0.05719869070162531, 0.041057709750020877, 0.016319111236953177, 0.034537909014034085, 0.0886273497599177, 0.052110474280198105, 0.038523286566487513, 0.02771485746052349, 0.028551350660563912, 0.07378973226877861, 0.048823405741131864, 0.029075050879328046, 0.08138274904922582, 0.007480688091163756, 0.08633268109406345, 0.021801022157887928, 0.03825587220489979, 0.024327149985765573, 0.033274818197241984, 0.02385853567830054, 0.009554923126415815, 0.021532093815039843, 0.03348811515024863, 0.04234338412061334, 0.017591209871170577, 0.04991261877876241, 0.09022048106999137, 0.01422885230567772, 0.02429819323879201, 0.037324621589505114, 0.02384366118349135, 0.02246408286737278, 0.05790348608570639, 0.010243935812468408, 0.025367603921040427, 0.07098931964719668, 0.018966366842505522, 0.032820505075505935, 0.00429899988375837, 0.0423162586230319, 0.032690358348190784, 0.05415224870375823, 0.030825914545857813, 0.014417450584005564, 0.03436119994148612, 0.032545030990149826, 0.04809844620467629, 0.04842326197831426, 0.10105148816364817, 0.04841951042180881, 0.05727200747060124, 0.011457296241133008, 0.021840586050529964, 0.03471486299531534, 0.003629282573456294, 0.04628643328032922, 0.06835173422587104, 0.04572441226628143, 0.046634693499072455, 0.03916569701686967, 0.04482227981497999, 0.013516321887436789, 0.03651004772109445, 0.062245936860563233, 0.049546780792297795, 0.02243768652988365, 0.031325181407737546, 0.009578544759278884, 0.06213724933331832, 0.022271938978519756, 0.04839107503357809, 0.044033291487721726, 0.029595621090265922, 0.029626702234963886, 0.007292032760233269, 0.09083393291803077, 0.014723566091561224, 0.044662469445029274, 0.06213199121702928, 0.07747583134914748, 0.0249207883462077, 0.08029225209611468, 0.012944637182954466, 0.020971445774193853, 0.016606407734798267, 0.01317535698035499, 0.046549005128326826, 0.030523062632710207, 0.014590896989830071, 0.033302656156593, 0.04257396940374747, 0.030314864234242123, 0.013123889966664137, 0.04096906392078381, 0.08376168116228655, 0.007500025212721084, 0.014840664007351734, 0.07720125155174173, 0.014476622945949202, 0.030847433117742185, 0.035977233928861097, 0.04856024017499294, 0.04072224044648465, 0.013860661711078137, 0.02901146737713134, 0.03200903709512204, 0.04852110301726498, 0.005611925917037297, 0.018947128519357648, 0.10605155228404328, 0.025565005926182494, 0.0023339069412031677, 0.04447837971383706, 0.02538936369091971, 0.06898736144648865, 0.021728150677517988, 0.03675031432067044, 0.04064119792019483, 0.009830339695326984, 0.01412283372701495, 0.06844552684924565, 0.05483790780999698, 0.07618865041877143, 0.03543081656971481, 0.04124937309825327, 0.07004600542131811, 0.06388115536537953, 0.02231494087027386, 0.03270610672188923, 0.06310755547019653, 0.03780187449592631, 0.09551661016303115, 0.04712105626822449, 0.050177888333564624, 0.025011269135575276, 0.042496849127928726, 0.014581204541173065, 0.06320362648693845, 0.030526630507665686, 0.033450388073106296, 0.034810310608008876, 0.04881179855146911, 0.03626765115768649, 0.021104924744577147, 0.03779808212129865, 0.02654278363479534, 0.0435180665954249, 0.02607586699014064, 0.03164978566928767, 0.043022965037380345, 0.030457603352260776, 0.04110349284019321, 0.06168441679619718, 0.07034230045974255, 0.07053437569993548, 0.044434437149902806, 0.02820924284606008, 0.03252206151955761, 0.06928335962584242, 0.016875853725650813, 0.0164236353157321, 0.027368537957954686, 0.028693928361462895, 0.11353594090905972, 0.05025923142966349, 0.04250108679116238, 0.012635413932002848, 0.03885252554027829, 0.01767774243489839, 0.03146882037981413, 0.01708773688733345, 0.02391820991761051, 0.024591252513346262, 0.026761309018183965, 0.02645342163305031, 0.07915025009424426, 0.04786198311194312, 0.030133449945424218, 0.03982744412496686, 0.04260609326593112, 0.0780851197487209, 0.02966784690215718, 0.026478088766452856, 0.053371887843240984, 0.023274400518857874, 0.0699236623768229, 0.03168955365254078, 0.01978983164008241, 0.03338583235745318, 0.052150479750707746, 0.020819153360207565, 0.03581552366085816, 0.10302716691512614, 0.052857557238894515, 0.07462843335815705, 0.06965868597035296, 0.01496707123806118, 0.048111897631315514, 0.04239543835865334, 0.04723084217403084, 0.025903909518092405, 0.0435050085070543, 0.05275766416161787, 0.025518573456793092, 0.007962935651448788, 0.039655933796893805, 0.02908728889451595, 0.07132123777410015, 0.04256537162291352, 0.024359251583518926, 0.05523355786863249, 0.06665214183158241, 0.005918402757743024, 0.04975151336111594, 0.09567927409079857, 0.016624755480734166, 0.08868053948390298, 0.03484806737105828, 0.04087053639523219, 0.04522779672697652, 0.028104073098802473, 0.1603683314169757, 0.1525323503301479, 0.16259519004961476, 0.164469929295592, 0.14579963113646954, 0.20108138036448509, 0.18294370674993843, 0.06630146221141331, 0.13213363476097584, 0.1072656168253161, 0.1234826716245152, 0.16305236786138266, 0.22041662799892947, 0.13705828925594687, 0.12379566498566419, 0.20223084837198257, 0.06968736255657859, 0.105206617154181, 0.20337792666396126, 0.16665830014972016, 0.10079108338686638, 0.12219189869938418, 0.18798989534843713, 0.11311420807032846, 0.13891722075641155, 0.17324741376796737, 0.10648010545992292, 0.11347569336066954, 0.21931813069386408, 0.08026306342799217, 0.15767329634400085, 0.09197466584737413, 0.16980862797936425, 0.14419982791878283, 0.13178304419852793, 0.06946031731786206, 0.1903820302686654, 0.08939815175835975, 0.10665799825801514, 0.06399595076800324, 0.06594657461391762, 0.07361592128290795, 0.09189308897475712, 0.10859887770493515, 0.11894682829733938, 0.15054137591505423, 0.14282415329944342, 0.1274458144325763, 0.1531131551018916, 0.13385742116952315, 0.11235456797294319, 0.1944215252296999, 0.09001121026813053, 0.1863162632798776, 0.1329429616453126, 0.2466371507034637, 0.1092489693837706, 0.09280838712584227, 0.18459253624314442, 0.14310612488770857, 0.18376331980107352, 0.2041820585145615, 0.07844238221878186, 0.09027308449731208, 0.36520953581202775, 0.10498636998818256, 0.16622763185296208, 0.11382546756067313, 0.16103488393127918, 0.14048349374206737, 0.14704401983181015, 0.15243267989717424, 0.15652647038223222, 0.07105489581590518, 0.13833999313646927, 0.159650748828426, 0.1845527274417691, 0.14945194765459746, 0.18263299920363352, 0.16514284943696111, 0.20197204663418233, 0.13821856293361634, 0.16935389925492927, 0.18473321775672957, 0.17452346248319373, 0.11482848756713793, 0.19565751281334087, 0.11190176141099073, 0.11758423774153925, 0.07395774708129466, 0.18646021024324, 0.21734088601078838, 0.11463480186648667, 0.08848813027725555, 0.185155707586091, 0.16204390791244805, 0.12729702866636217, 0.10578544039162807, 0.1507158696767874, 0.15357871918240562, 0.16118908737553284, 0.10365327980252914, 0.15393579611554742, 0.13813477446092293, 0.1218428072752431, 0.1125139367650263, 0.2420085240737535, 0.17393495421856642, 0.19858625018969178, 0.18049107195110992, 0.2056569731212221, 0.10435075018904172, 0.12657971325097606, 0.18124360969522968, 0.1250547482050024, 0.13646431878441945, 0.07266731554409489, 0.13230051408754662, 0.1671180161065422, 0.07336385824601166, 0.14672454009996727, 0.12008695266558789, 0.14320399932330474, 0.09835197794018313, 0.21087177767185494, 0.09854101779637858, 0.1173111645039171, 0.15731402265373617, 0.06321177526842803, 0.1433862856356427, 0.11629481552517973, 0.15966326143825427, 0.21097394172102213, 0.09725919517222792, 0.14259638817748055, 0.23647852940484881, 0.10952874421491288, 0.14608179568313062, 0.1490484271198511, 0.12250667321495712, 0.22994141065282747, 0.10570785627351142, 0.11812754179118201, 0.130090071761515, 0.11720538619556464, 0.1258850481826812, 0.1510621260968037, 0.1875327917514369, 0.1528220550972037, 0.18682638590689749, 0.1838284803670831, 0.10572034661890939, 0.08371128191356547, 0.09751952573424205, 0.18134595185983926, 0.1273962389677763, 0.10167345986701548, 0.20817154756514356, 0.12514460744569078, 0.1134004989580717, 0.17073631257517263, 0.20056166918948293, 0.09766825212864205, 0.1717076206114143, 0.09430094258277677, 0.14470325637375936, 0.17849217139882967, 0.22633099579252303, 0.0780455929634627, 0.21777286048745736, 0.0749477869248949, 0.1896070351358503, 0.09145777483354323, 0.10627443407429382, 0.21875200560316443, 0.10427440545754507], [0.061282688548089936, 0.014651186284027062, 0.03841308876872063, 0.0705682324769441, 0.03040821713511832, 0.027317880812915973, 0.02024072346102912, 0.031020605856610928, 0.0569319591159001, 0.0033806916280809673, 0.015010728075139923, 0.06712224043440074, 0.034458532609278336, 0.021488542734005023, 0.013961165204818826, 0.02622816311486531, 0.07117802553693764, 0.06753906767698936, 0.08370614625164308, 0.043313716232660227, 0.04299224754504394, 0.04714830793091096, 0.013172704730095575, 0.02122124526067637, 0.025581414811313152, 0.01954296178155346, 0.05465083464514464, 0.013204521528678015, 0.017976204544538632, 0.026565569423837587, 0.02061625575151993, 0.03390838966879528, 0.08714554060134105, 0.03410291770705953, 0.017095694565796293, 0.040750445768935606, 0.06318371466477402, 0.09362126889755018, 0.027867962526215706, 0.05033019930124283, 0.019510158854245674, 0.07122694791178219, 0.053849040559725836, 0.018227299078716896, 0.04657190409488976, 0.04642224630515557, 0.033083759699366055, 0.037557960240519606, 0.045341686709434725, 0.049001933075487614, 0.012302744380576769, 0.03286332328571007, 0.06871189849334769, 0.09226728725479916, 0.12292839121073484, 0.09767874609678984, 0.09474861348280683, 0.03573944981326349, 0.03758970931812655, 0.040316627055290155, 0.025551927428750787, 0.067226690298412, 0.06926772999577224, 0.07921653130324557, 0.011071906374127138, 0.027587606964516453, 0.011083584067819174, 0.0610647420398891, 0.02334785272978479, 0.05425818657386117, 0.039803535837563686, 0.036270092823542655, 0.019008656272490043, 0.02772821611870313, 0.037763501750305295, 0.010399783113825833, 0.020334610708232503, 0.07431095000356436, 0.030286070759757422, 0.015344769672083203, 0.023725694954919163, 0.020306470323703252, 0.03933914063964039, 0.046770966655458324, 0.04874251164437737, 0.019981502409791574, 0.049232655655941926, 0.005566349236687529, 0.04576930106850341, 0.07922256496385671, 0.02150005158910062, 0.03264411512645893, 0.015810676995897666, 0.057237449364038184, 0.05422045578598045, 0.04353773721959442, 0.042325813774368726, 0.023682125320192426, 0.04443438519956544, 0.030844956199871376, 0.04912029078695923, 0.024305995066242758, 0.015941801502776798, 0.058373480787849985, 0.026383409276604652, 0.03460564854322001, 0.008472407043882413, 0.04707451618742198, 0.03845981809718069, 0.10157447220990434, 0.035178690450266004, 0.0443856817582855, 0.05103713207063265, 0.024230505659943447, 0.0201075599034084, 0.0625038034922909, 0.02428041880193632, 0.026917646137007978, 0.030326469568535686, 0.013319521949597402, 0.015260194522852544, 0.014439227979892166, 0.0266726186600863, 0.008299472719954792, 0.08532754596672021, 0.03687683565658517, 0.010215450329269515, 0.0556395868625259, 0.04530885038548149, 0.03395135630853474, 0.029272673673403915, 0.034655557974474505, 0.013440605198411504, 0.03224796411814168, 0.07217346821562387, 0.021632897878589574, 0.08694145741173998, 0.059223110001767054, 0.022397126303985715, 0.03502992323774379, 0.04934624877932947, 0.027317977292113937, 0.0395482184831053, 0.05863382619281765, 0.026362619864812586, 0.06639921048190445, 0.07339803414652124, 0.016088381235022098, 0.06815196291427128, 0.032281271705869585, 0.029253576358314604, 0.04681025595346, 0.03825002037046943, 0.08246641082223505, 0.07094318032613955, 0.027783420773630496, 0.03093620325671509, 0.012371183383947937, 0.056198594757006504, 0.1222522278840188, 0.01309285149545758, 0.03364097901794594, 0.022505526249005925, 0.03573774658434559, 0.03294274050858803, 0.06958060461329296, 0.03541129066434223, 0.031099119514692575, 0.025496357266092673, 0.009258831250917865, 0.04161635028140154, 0.05769738425442483, 0.016334959800587967, 0.04903206056042109, 0.02116191612003604, 0.04069719296239782, 0.08120002486975864, 0.003652807031357952, 0.045926480524940416, 0.03142695211863611, 0.039479814731748775, 0.01018843522615498, 0.03558159129170235, 0.01159091714725946, 0.042609722368069924, 0.020421113586053252, 0.02734403038630262, 0.030742209564778022, 0.03034139230294386, 0.03820608151727356, 0.02833471033227397, 0.01445855072233826, 0.07481726541300304, 0.048382243476225995, 0.0205262963208952, 0.044845382872154005, 0.028654329216806218, 0.02315099805855425, 0.03949557423766237, 0.06466107835876755, 0.021671506256097928, 0.04523144809354562, 0.010758949192677392, 0.041540194797562435, 0.009575040894560516, 0.01475094206398353, 0.02513537107006414, 0.08362425025552511, 0.07145001523895189, 0.005631810372506152, 0.012877613826276502, 0.0816586276050657, 0.01734217850753339, 0.04854333776165731, 0.07869653811212629, 0.0498905101994751, 0.06810094026150182, 0.07525211200118065, 0.021190321822359692, 0.017560201085871086, 0.024443323927698657, 0.1175602366856765, 0.04310147312935442, 0.029537247464759275, 0.039784035907359794, 0.1027165781124495, 0.057391166701563634, 0.02945658899989212, 0.04401209946081508, 0.026893030953942798, 0.04068336304044351, 0.08316246370668523, 0.086277272348525, 0.04100331032532267, 0.008241187224484747, 0.03905463090632111, 0.026529625356488395, 0.06543333496665582, 0.02538071395974839, 0.02756379144557286, 0.025654735291027464, 0.04103890743863303, 0.020469672308536246, 0.04454110603546724, 0.08318747408338822, 0.13226177397882566, 0.05041389500547666, 0.038881250366102904, 0.027712237679224927, 0.00982051829851116, 0.025544685922795907, 0.030099628420430236, 0.017584025881660637, 0.032873902600840665, 0.022604857149417512, 0.05852389556821436, 0.04405511062941514, 0.10656951941200532, 0.026605791972542647, 0.028670187057286967, 0.02739697891229298, 0.03419287342694588, 0.037385466566774994, 0.019863202214764897, 0.02100173653161619, 0.018415155209368095, 0.049126881058327854, 0.03895982896210626, 0.056823071208782494, 0.06321934517472982, 0.04055351317219902, 0.05229480520938523, 0.0361356527719181, 0.010099542632815428, 0.06991100875893608, 0.027131575770908967, 0.04202515119686723, 0.04593287412717473, 0.03906311365426518, 0.036618404992623255, 0.009093530843529152, 0.06378802325343713, 0.06874580722069368, 0.06677806944935583, 0.037615164983435534, 0.030985316734586377, 0.003772965610551182, 0.010313432376278797, 0.03345453296788037, 0.01530225945316488, 0.025847103679552674, 0.017047211913450155, 0.02994264377775835, 0.02325838682736503, 0.03102467282587895, 0.027265412827546243, 0.020176698380964808, 0.02253635506349383, 0.024140338427969255, 0.017754749533196446, 0.016380783708882518, 0.007131553065846674, 0.05825121566886082, 0.06509302314952947, 0.044126438442617655, 0.024606611259514466, 0.007509074312110897, 0.08721366975805722, 0.007086559435265372, 0.06435577364754863, 0.013661165921803331, 0.082946817856282, 0.10043567628599703, 0.02629443319165148, 0.037949821635265835, 0.0061613647449121345, 0.020709389718831517, 0.018540977071097586, 0.026081004507432226, 0.07491749987821095, 0.003579135423024127, 0.03284745616838336, 0.055031281808624044, 0.021530004669330083, 0.0996994212619029, 0.06709421693813056, 0.05673273328284267, 0.028839131409768015, 0.03639602044131607, 0.018986961440532468, 0.05079115093394648, 0.0168518211285118, 0.035574180947151035, 0.04928416441543959, 0.013671629276359454, 0.04027814298751764, 0.025365440560563002, 0.020982774658477865, 0.05382646442740224, 0.025797181260713842, 0.013951433793408796, 0.03694830076710787, 0.03892168999300338, 0.05883491110580508, 0.08591470352257602, 0.031742609789944254, 0.01947419066709699, 0.0721564210834913, 0.0641241048288066, 0.06431181624066085, 0.05833595780131873, 0.04326921705796849, 0.21118855598615482, 0.0851753463211935, 0.1550387017778121, 0.09243080465239473, 0.11664576973998919, 0.15683052828535438, 0.0864350306801498, 0.10176932308240794, 0.09270959242712706, 0.06434420356526971, 0.07216603189590387, 0.32013424672186375, 0.08561501686926931, 0.1346915209433064, 0.09364718469441868, 0.11221853230381384, 0.2435014580260031, 0.1137190881127026, 0.16245223756413907, 0.14410477364435792, 0.16812724788906053, 0.11514441983308643, 0.07802487220033072, 0.20340531191322953, 0.06623313267482445, 0.09369891238748096, 0.14998207858297974, 0.11372468390618451, 0.10727641507401131, 0.07461686327587813, 0.0900309588178061, 0.16210442263400182, 0.24581781966844574, 0.14105073205428198, 0.13720186514547095, 0.2625838411040604, 0.20522482052911073, 0.2452790946699679, 0.1266246725572273, 0.29596481239423156, 0.17569265677593648, 0.18318212911253795, 0.10350862779887393, 0.09282320781494491, 0.14590559498174116, 0.17194669606396928, 0.1402217530994676, 0.13961351854959503, 0.16421724285464734, 0.13772717211395502, 0.1492820552084595, 0.12383303212118335, 0.17722982272971421, 0.18262562225572765, 0.12980462692212313, 0.15412727021612227, 0.1947529090102762, 0.10956139871268533, 0.06822282317443751, 0.16146055015269667, 0.09158076354651712, 0.17904205829836428, 0.1386900938814506, 0.1767732683219947, 0.1158708191360347, 0.08536857189028524, 0.14748921938007697, 0.1601680851308629, 0.2159403939731419, 0.14913904335116968, 0.13573731092037633, 0.10662986343959346, 0.09790496013010852, 0.08392502044443972, 0.1323765842244029, 0.10548095946433023, 0.10249531420413405, 0.15730630431789905, 0.10713531053625047, 0.1660700887441635, 0.15370497334515676, 0.20329676539404318, 0.15197830740362406, 0.29083930305205286, 0.09724950272357091, 0.12272364750970155, 0.15728452970506623, 0.13591627241112292, 0.1451718038879335, 0.1277118595317006, 0.09942499731550924, 0.10832353349542245, 0.1395801961189136, 0.1361414697021246, 0.11203088026377372, 0.146114643139299, 0.13736708206124604, 0.11308311208267696, 0.1779233745764941, 0.1610364721273072, 0.10008662939071655, 0.1479843506240286, 0.1403950445819646, 0.10569111342192627, 0.10797143637319095, 0.14359408698510379, 0.1596598030300811, 0.16637879249174148, 0.20310831925598904, 0.21024433634011075, 0.1000031600415241, 0.12589699676027521, 0.12314889070694335, 0.04575930433929898, 0.08736539442907088, 0.16098317108117044, 0.1412405289011076, 0.11473097678390332, 0.10378843231592327, 0.05734130922064651, 0.13341646670596674, 0.12116040990804322, 0.09334585047326982, 0.18456152931321412, 0.19201935647288337, 0.20123536116443574, 0.13206495641497895, 0.2543936774600297, 0.27978073863778263, 0.10312041034922004, 0.11409710845327936, 0.20205503358738497, 0.1778404915239662, 0.2439189309370704, 0.15429204184329137, 0.16783018101705238, 0.1493870245758444, 0.12545807578135282, 0.20211740367813036, 0.13711326755583286, 0.13233756209956482, 0.17815082799643278, 0.15203931194264442, 0.12787755142198876, 0.07989581165020354, 0.18926759163150564, 0.12972184777026996, 0.06998264827416278, 0.1880683403578587, 0.1159302651649341, 0.11139779860968702, 0.1275787627673708, 0.12654082471271977, 0.14355580700794235, 0.1660913141677156, 0.08235385670559481, 0.11056857474613935, 0.14755752665223554, 0.06450598433730192, 0.3199052793206647, 0.17637105396715924, 0.10704214131692424, 0.08867036463925615, 0.13302213395945728, 0.11620546094491147, 0.1371089185704477, 0.12671252799918875, 0.19424465659540147, 0.12838829745305702, 0.14299983449745923, 0.13362342200707644, 0.13143594173016027, 0.1483103315695189, 0.12778154719853774, 0.16900434769922867, 0.11260772938840091], [0.004241891156198108, 0.05540145393752027, 0.0224426774730091, 0.032217443294939585, 0.040950821930891834, 0.04888369781838264, 0.012008378926111618, 0.031182729871943593, 0.012963143562956247, 0.04343199230788741, 0.02982977981446311, 0.0028825354365835665, 0.04471218591788784, 0.0296395358236623, 0.04956135657266714, 0.06348230293951929, 0.05512215408089105, 0.09596221789252013, 0.010221370812359964, 0.025891150144161656, 0.04616071717464365, 0.05189787865674589, 0.04630707611795515, 0.04124099425098393, 0.05603921483270824, 0.018034288732451387, 0.04688161345256958, 0.0407296878984198, 0.02604881756269606, 0.01670461984758731, 0.009159295332210604, 0.06684924883302301, 0.014960969856474549, 0.008152939371939283, 0.02837104217178421, 0.023643166277906857, 0.0039248354642040795, 0.024864767328836024, 0.0281731633367599, 0.05506325724127237, 0.010422965951875085, 0.07098737522028387, 0.013136465659044916, 0.045306824322324246, 0.14897070941515267, 0.05571317451540381, 0.016752534756960813, 0.13550056581152603, 0.036152202665107325, 0.022489091388706584, 0.011574389518500539, 0.02505777396436315, 0.06708168948534876, 0.05145584436831996, 0.04206516037811525, 0.06532688872539438, 0.06858174063381739, 0.024393527673964854, 0.012956358477822505, 0.00947996806644369, 0.02866678245482035, 0.02457284168485785, 0.04091614508070052, 0.062366090569412336, 0.03054410066397395, 0.0258216238944442, 0.0569448613532586, 0.043708160301321186, 0.03645609729574062, 0.030731021688552573, 0.0037206481420071214, 0.0023165650372902746, 0.095577726024203, 0.03397731663426384, 0.04150053071498405, 0.04740351767395623, 0.03300286189187318, 0.053664969382225536, 0.04071958355780225, 0.06817043496994302, 0.04991766909370199, 0.06813303814851679, 0.06616501836106181, 0.03416169580304995, 0.06398158278898336, 0.03094143539783545, 0.009603754588169977, 0.016353769533452578, 0.09142275288468227, 0.04848159849643707, 0.043161601934116334, 0.039716181345283985, 0.04113117865927052, 0.03365865697560366, 0.07247152956551872, 0.019039956350752618, 0.03745744746993296, 0.05795947370643262, 0.07527175665018149, 0.04795919332536869, 0.02563847112469375, 0.012090866785001708, 0.11097113791038282, 0.02933035524620209, 0.07723028436885215, 0.018296417147212196, 0.02758299080596771, 0.0640409323386848, 0.01221054923007614, 0.018254311398777645, 0.052692592653329484, 0.007505662752009812, 0.012460640937206335, 0.06539976762724109, 0.025867998847388662, 0.026021914709417615, 0.11071996545069851, 0.07039757561869919, 0.05321738382917829, 0.04119280660233926, 0.012265603600098984, 0.034478418456274085, 0.014459210306085879, 0.004407166516102734, 0.06022460489475634, 0.01921218656207202, 0.019607806934800465, 0.06488655024440959, 0.02065243730612565, 0.03839023062027991, 0.07830204951460473, 0.025485731566732284, 0.031503319114563055, 0.01588574523339048, 0.08896299346815795, 0.038310446034302004, 0.017297298982157372, 0.04630659743270371, 0.1044057952822186, 0.015550782445643563, 0.020050475759489927, 0.021825069597980473, 0.04867334719165228, 0.02914241747930646, 0.00823142427179846, 0.05568785985815339, 0.03595116599171888, 0.05261878606688697, 0.0365205268462887, 0.027896613137272652, 0.021514987311093137, 0.0501392075966578, 0.0718562891415786, 0.07186831935541704, 0.03295063324912917, 0.053627349916496314, 0.04279232780390885, 0.030976596499385778, 0.050655831437325105, 0.03479602797597181, 0.029387754802883137, 0.024415126026724465, 0.0343961291218875, 0.048680453255656175, 0.037692192490794696, 0.06557589411386289, 0.05945535398495849, 0.028794591416954063, 0.03051989737286931, 0.07883573533035815, 0.033186832879437134, 0.029941883076389786, 0.012366886348900152, 0.026085661484103184, 0.06713409995427355, 0.042160882585449144, 0.01814457558793947, 0.028094352819607593, 0.03933832427719608, 0.026972414780175313, 0.008508125683874823, 0.08329305943334475, 0.013866008885088377, 0.04413130693137646, 0.024355425812245812, 0.10498206553165801, 0.021900993160670623, 0.032853886878001504, 0.028367097656882834, 0.02357337285502581, 0.054224823325057514, 0.03217207209672779, 0.034662626931094564, 0.10172514303121716, 0.04333699369453825, 0.04646772882551886, 0.007538379404650186, 0.017150652456621174, 0.015573082127957605, 0.07396088636596687, 0.0616634103062097, 0.013849661227141041, 0.030952652959967963, 0.04232418847095687, 0.026234732977172825, 0.07583965547382832, 0.054308782491716556, 0.030171165890351404, 0.012001235754723893, 0.03232177441532258, 0.0342504789296072, 0.03526899126882199, 0.04599333318765275, 0.029953022713016253, 0.03710606280947104, 0.024851063571986742, 0.011015491090802243, 0.0899243493040558, 0.01904957458464196, 0.04210628649161663, 0.06655895776930265, 0.013994486707815668, 0.02420311855530599, 0.03723483285284601, 0.020853533351328224, 0.051266696900711395, 0.025344137211504858, 0.04463728466362227, 0.06088877882575616, 0.060668034420814365, 0.02747201746387873, 0.09111136998399161, 0.059913607910857536, 0.06144768281956203, 0.024975093147077132, 0.024206302368838806, 0.018898835114669055, 0.016599012233200483, 0.026813968106580433, 0.01976158921024762, 0.015221315261442214, 0.05897472430660855, 0.033985558184213005, 0.015965138336468954, 0.03828133158094715, 0.03815660995314829, 0.02832583795679966, 0.04851511388551444, 0.041452959048911, 0.061207668550196104, 0.030108155697234906, 0.03177998434694018, 0.021532104947254993, 0.04276336920156609, 0.016053609761002008, 0.03992472484242171, 0.04680483827542048, 0.08043375739362091, 0.037577248658635654, 0.03928216225176584, 0.005621497766696848, 0.04103943065274507, 0.03423445967200678, 0.028362722696329, 0.04493813648878131, 0.06055120182281826, 0.023350084738922305, 0.03881953707605135, 0.09267877103411593, 0.041565947321942076, 0.03238372148189228, 0.05693874605640303, 0.13549007184337825, 0.016712391989130992, 0.018095720006385818, 0.017223193681275006, 0.04629994407878257, 0.013192301139497431, 0.12506500468589365, 0.07889416461694054, 0.0424308796209516, 0.037888598162680864, 0.045154390900279395, 0.07663564596441574, 0.032590598857495934, 0.01569026539073093, 0.031065210787346587, 0.07354386616498232, 0.02439506206428632, 0.01793031198758399, 0.01653881849051686, 0.02909125752921682, 0.027449144472484477, 0.10269862556015141, 0.07082026582793333, 0.019604719600465614, 0.0831004127394408, 0.03336791691253893, 0.018126077557099052, 0.025585260991647374, 0.07672424355405383, 0.09172341175144538, 0.12282630879781209, 0.022961976756050717, 0.054611248488072306, 0.019417664989305194, 0.07588169813971035, 0.030775765771977603, 0.021794012573082, 0.04018733379780315, 0.045712044375250116, 0.0636093808861915, 0.058361005285405554, 0.012156345546827652, 0.028096881687815767, 0.0414658167574089, 0.033803932383307256, 0.06880997330881655, 0.0029227586810520734, 0.032079964148579165, 0.044145314968773164, 0.08922837805585004, 0.05570958623138722, 0.036054899683222175, 0.0630493339849636, 0.00991536477158661, 0.052727124784723856, 0.04173624423856381, 0.017093161986849736, 0.0647374898835551, 0.018636111126397736, 0.06455551527324133, 0.06008884753100574, 0.020516143740678672, 0.0520133828104008, 0.01113136353524169, 0.08145527172018774, 0.10695118369767442, 0.08602679750765674, 0.04603999201208353, 0.02188080303312745, 0.017292009324592073, 0.007068746499498957, 0.055872958910185844, 0.0069865986370132305, 0.020256321549823042, 0.01011821506835986, 0.0800894973508548, 0.06767990504158661, 0.03067309891775949, 0.012082127068424597, 0.042996147531084716, 0.13616447628010064, 0.2221451493096538, 0.22432280355133116, 0.125050057831686, 0.16837282455526292, 0.13158161047613248, 0.06565780495293438, 0.1344069221522659, 0.1292295812163502, 0.19230196630815044, 0.1314644847298041, 0.10380546460510232, 0.1122400323220063, 0.14253274159273133, 0.22162221721373498, 0.1810466733877547, 0.12480593577492982, 0.16589939477853477, 0.15731988562038168, 0.18777045712340623, 0.15975567366695032, 0.18188117392128333, 0.09468282951274887, 0.16147892572917044, 0.2225082227960229, 0.14553079556208104, 0.13465992029523477, 0.14144971064524725, 0.10873821593122557, 0.12549785489682108, 0.0974546917132102, 0.1519970243680291, 0.1718045154120773, 0.10590223217150196, 0.08774387490120716, 0.14315282081952319, 0.18712610966758803, 0.11354383736033924, 0.19902150495909154, 0.17273749894229695, 0.1103199107456021, 0.19946232583606616, 0.11930190143175423, 0.08946510090027004, 0.3498620999744162, 0.08807876904029399, 0.08800564522971399, 0.3293461992871016, 0.158976299862843, 0.13280029117595404, 0.07647296719369479, 0.08857505803462118, 0.18238577496958897, 0.18887456506490707, 0.12212261179229245, 0.2137638529529795, 0.15850760391913354, 0.163895076548215, 0.0810797449958045, 0.11491643206682056, 0.09022602491313592, 0.12826639227569103, 0.12503508129157126, 0.11939536008867435, 0.07915969763416797, 0.10221643737168051, 0.20143422705587, 0.1449020332074724, 0.11473093225504272, 0.14241806493373588, 0.1016281517513562, 0.18910782207967713, 0.2828493411652744, 0.12006978678982705, 0.09137984932749532, 0.08763049700064585, 0.11326625928631984, 0.16775378433521837, 0.06717776050209068, 0.15465968695934862, 0.17116114759119228, 0.2236381426337175, 0.18980296212248504, 0.1629571503144689, 0.22525179432705045, 0.11492884819745086, 0.17821779940277338, 0.08842894400004297, 0.15583480359055102, 0.1642041068407707, 0.13265575049445033, 0.24208817136241123, 0.22713834856403992, 0.23670482507441193, 0.13927453517680988, 0.17388594278600067, 0.17117775685619563, 0.09975716777262278, 0.14975394238717854, 0.16051548445830122, 0.10742449579993263, 0.09126017801463604, 0.21337927202694118, 0.10747793043265119, 0.17515682615339756, 0.20220193429850042, 0.10235864028800279, 0.147778790560551, 0.12578646128531545, 0.12260711548151448, 0.18713020632276312, 0.13256795442430303, 0.11391202424420044, 0.26618254487402737, 0.06775383779313415, 0.17389814369380474, 0.19293963443487883, 0.1969962433213368, 0.18664709787117317, 0.12390571806463413, 0.1474401931045577, 0.18800646008457989, 0.08189961779862642, 0.11512113123899326, 0.2677026711171493, 0.1721395950880833, 0.21795406326418743, 0.1384670488187112, 0.15089581080246717, 0.14640630717622116, 0.13849943614332005, 0.09166645933873951, 0.09325605802587233, 0.1196228654589504, 0.16679007589118555, 0.15677286341087893, 0.19003682769834995, 0.18373026454355568, 0.1313428467256017, 0.12509807478636503, 0.08061156113399193, 0.16369868943002075, 0.10595847954391502, 0.18882093747379258, 0.09977632260415703, 0.17237132327863947, 0.18436107522575185, 0.143598243012093, 0.11039359116693959, 0.09737606858834624, 0.11080193566158414, 0.08474916059640236, 0.12288675672607496, 0.18307435442693532, 0.07007683423580602, 0.13636544987093657, 0.12094949153834023, 0.1786646613618359, 0.09838558980845846, 0.09467166019021533, 0.1738579638185911, 0.15116049034986645, 0.1651618187315762, 0.1656977680977434, 0.12297997789573856, 0.10637382991262712, 0.1230301841860637, 0.1522233645664528, 0.1237506685720291, 0.128756046469789, 0.21749532694229856, 0.22972505976213142, 0.18314647633815184, 0.10644132824381813, 0.1365836858167313, 0.11665613754303195], [0.10068060728372075, 0.034185949189122766, 0.060195646292413585, 0.019606868117989507, 0.02326238143723458, 0.02273291287565371, 0.018615622284414712, 0.015197647244349355, 0.011253991378907813, 0.020864012476522475, 0.031352136211353354, 0.019250648365414236, 0.04132316113100387, 0.02317260568815982, 0.015899810787232127, 0.023580516026413534, 0.02402761732810177, 0.047104498953558505, 0.021321411077224184, 0.08067805756581947, 0.03160950189339928, 0.04711046953161713, 0.035052963212365285, 0.051925108055002056, 0.038529175508301705, 0.049225987459067255, 0.03223775216611102, 0.014633529663115041, 0.08010215096874163, 0.06514616092317738, 0.0683926859346684, 0.010556944016570924, 0.0390139983210247, 0.025001370740938, 0.05331109852704685, 0.022876099137647543, 0.02238630950159859, 0.10099769730004482, 0.032756275904830545, 0.0296934046127717, 0.017606490691832732, 0.041879797863657586, 0.05364031152566895, 0.042415955031174235, 0.046605775714851916, 0.034268171730218455, 0.039313670131377876, 0.07535819459008053, 0.02236873915535398, 0.09025553270475939, 0.06873590697068721, 0.03851363122521434, 0.053743611060781404, 0.0425640246248804, 0.06807295387261547, 0.09868733221082948, 0.009466356150369393, 0.012636233077500947, 0.0362875221617287, 0.006694666035400587, 0.03513993549859151, 0.032577711463090964, 0.034446561767254025, 0.034957382013089955, 0.11197492975043133, 0.04836439111386426, 0.08063942877925001, 0.0655643834033981, 0.040766980819171295, 0.02286706348968437, 0.04272173471690621, 0.013962870289105922, 0.03562862490070984, 0.05144437818671577, 0.017758131871232763, 0.014891089231241494, 0.022047183265385684, 0.05020756310841534, 0.01775713182723848, 0.03960700400057249, 0.05173974182980601, 0.06764487567124888, 0.04883722824160941, 0.008736342588235857, 0.050004214645014144, 0.027653121906041633, 0.028928378378623165, 0.009570678921591025, 0.08299800378154032, 0.012511478053056635, 0.054828104039188474, 0.07570123751065694, 0.04630166957213078, 0.011728939916793024, 0.009730355704959948, 0.048205174462054856, 0.04444494596100412, 0.024626751292089466, 0.03489091155643109, 0.050484072489780374, 0.03507627407088876, 0.01982407433388289, 0.04203862488793675, 0.02228742388979299, 0.005236730376054766, 0.03363570605870336, 0.032767901648185216, 0.039852914633229375, 0.011072199522459414, 0.034416827620589174, 0.023390628266497515, 0.03300633885373827, 0.06759799420251511, 0.009392377942276653, 0.04612832985003479, 0.02607692455057986, 0.04004221053037327, 0.018366945296293125, 0.03511902177706361, 0.01638139598071575, 0.030855433469696436, 0.012832725024054525, 0.047654704976594076, 0.025461943878326565, 0.011511604752740823, 0.04573269463435281, 0.028916628325532656, 0.027380792671465315, 0.060211917880224064, 0.026268862493452616, 0.026294485141988844, 0.019694267139129806, 0.04936407145578414, 0.042829379526665434, 0.0611463634413667, 0.049566232482902706, 0.06108674300776329, 0.0678993877954781, 0.0268651224905625, 0.022372948988049757, 0.008001551450433908, 0.01813025399314938, 0.01892537431558594, 0.016032848179747816, 0.04273806196579244, 0.02885092413634993, 0.0700686483469326, 0.023438264870492276, 0.054321220886777155, 0.019502093564369716, 0.026185493334196508, 0.0252291302967933, 0.018739711231319234, 0.13056611496722326, 0.05536127406230662, 0.02866630005883053, 0.012976007765246322, 0.009315599982073763, 0.020650032747653313, 0.012384049441607203, 0.0362003012560308, 0.010168143980990862, 0.04412132875586394, 0.053220270783640444, 0.018611251034599263, 0.035391167330089957, 0.020049225240654778, 0.04804892640095204, 0.044314468977972865, 0.03915977096767165, 0.028846651221101638, 0.047543434775434434, 0.04864068527240306, 0.10471697780303657, 0.0709090637974441, 0.06771524611394852, 0.01837449293816462, 0.037255687202559784, 0.03658448513306212, 0.03162048196827527, 0.020891505337203853, 0.022950692400627304, 0.01299635652685538, 0.03925583827367518, 0.004540438148978865, 0.02918356956797652, 0.0446750562696252, 0.04904020934191067, 0.04212905187159777, 0.03378623216121923, 0.017764432705007493, 0.03515080054057762, 0.02786916109471349, 0.057815827312879264, 0.03845597377221566, 0.05204600020078942, 0.058489456205279566, 0.014373967223946238, 0.015914327195787337, 0.029893949613324367, 0.10671832002117299, 0.0121779132859956, 0.05219178397965152, 0.05743656016420573, 0.011085774331149878, 0.03725150520040188, 0.04249366531439591, 0.005919309105593129, 0.04381261758680921, 0.021084085237816907, 0.04531550745014101, 0.030539684885297902, 0.022170435440784786, 0.012950984400958987, 0.02597862152470043, 0.046991544077172875, 0.03719328742590733, 0.09016343217808753, 0.023207200902106706, 0.008702164832357084, 0.046511637992807664, 0.042139916913583875, 0.0387759915611241, 0.06618870771490037, 0.047088294159038924, 0.02927078490756685, 0.03336355308420025, 0.03336890396894887, 0.04917246747936588, 0.09260049671866, 0.050861844210885465, 0.057025952119147405, 0.018066679767798632, 0.03392954087757971, 0.024986791249830276, 0.04157571769610513, 0.01042786690959474, 0.038936759301577695, 0.08789833809714764, 0.026715041676652618, 0.11861353719723411, 0.022955247331992723, 0.031494012582697906, 0.03385627976967953, 0.07149872981244698, 0.029167808206693735, 0.04513907297223341, 0.03336687048431486, 0.0859437437611632, 0.05113345541758463, 0.019946614047512412, 0.036717259063152596, 0.039696547828498296, 0.07553460309281945, 0.06736751282005571, 0.05521635488548782, 0.039116722691687755, 0.028752422585966997, 0.08377206380828284, 0.12169975831056945, 0.029722237050009426, 0.03316759270092007, 0.026054921727336477, 0.029123513122613076, 0.042187518265563995, 0.03368657286046073, 0.0554978106811177, 0.044427312532207, 0.01610445058759069, 0.06936302175745368, 0.007514840799558442, 0.051059982797596604, 0.03602078686526511, 0.056709507771302015, 0.0171593448612839, 0.026069861160067376, 0.026537703633948695, 0.02651857848832151, 0.044625851878663525, 0.06873319071019068, 0.03319197967357468, 0.029591604215966072, 0.034819075372070074, 0.06284229704760946, 0.035136933511239477, 0.04852409387240186, 0.02369111458392581, 0.049425643737777136, 0.04345103952800855, 0.040734563808655366, 0.05456915016111452, 0.03559106480679475, 0.05857095144165214, 0.05812164039525669, 0.062492322467733175, 0.05493172640854027, 0.035713864272111095, 0.01814418596040923, 0.026111285988008603, 0.07136651620385237, 0.0060255911466811085, 0.09304128048825078, 0.030996161367511377, 0.016052990067692008, 0.05272888738545589, 0.027719766767404508, 0.0845024039153941, 0.021890243151574396, 0.03628977829066571, 0.04003695612482261, 0.027871899619640317, 0.03402598296815995, 0.033529155916767195, 0.047151480612228625, 0.028727555072691757, 0.03793177631450817, 0.005784726190540823, 0.07156233928981237, 0.023659478683839552, 0.02699992990528699, 0.1077166199684143, 0.037991526623954996, 0.01054077540175058, 0.01697457606496755, 0.03607988779549487, 0.07893884932855144, 0.08496865077177063, 0.01172595091702533, 0.03603903256589547, 0.018971914396388456, 0.024884081722120754, 0.019812120190181304, 0.025227015175914858, 0.05826267813972663, 0.017211853664775845, 0.01929971360368654, 0.0031701614943813183, 0.021666693428414874, 0.024518301252101082, 0.023665475237066858, 0.07031368324533105, 0.028618208889383823, 0.06084809429012239, 0.035168998001609, 0.03660233378468547, 0.046446822525467724, 0.06212584252352826, 0.05772045762569178, 0.06453873531427234, 0.04414691800775472, 0.023343075154116377, 0.08533092273864895, 0.18087587552145123, 0.19112039299216121, 0.16770650952821597, 0.087559243402211, 0.1972423098050058, 0.16824670397909358, 0.11575235010241158, 0.08294632803881541, 0.12680856190854684, 0.12514496367657557, 0.13367543171625584, 0.12686872039921582, 0.14815918577369303, 0.12014986452413723, 0.1281745737651363, 0.08816448709694669, 0.10035155384684913, 0.12421007282682694, 0.14090813579969108, 0.2801852091215551, 0.211372742196545, 0.1763030287111178, 0.16719190432922915, 0.20052494772244245, 0.22978946333751082, 0.18951584002934396, 0.14675891638034955, 0.16541220451472327, 0.09700221169623546, 0.17687293875496835, 0.14354458573507145, 0.16870854247827083, 0.10576935805147514, 0.11012603950803168, 0.15397167153423652, 0.08940409636124969, 0.15834679536055773, 0.15142392308916897, 0.08261624301667325, 0.09526699621346779, 0.14542140299454331, 0.1760689850198105, 0.09051601169630885, 0.13989620259962976, 0.13195952691603452, 0.11691785592120141, 0.1223129355639685, 0.15342602971941233, 0.11260261599090882, 0.14919952838681638, 0.16711890668375418, 0.09894447153783403, 0.17652794398600236, 0.11488490563351661, 0.13509891548892483, 0.16035657579777762, 0.08140899881254882, 0.10748690299806185, 0.12123363019782118, 0.08412699593463913, 0.10560205570072867, 0.10497123017557897, 0.18662839574972168, 0.17956231866264716, 0.1861407156684436, 0.09201635970384814, 0.1641707547241822, 0.10936641425359994, 0.10979760947520845, 0.07647909733350389, 0.13312175986357033, 0.17044467822415754, 0.27791753236670047, 0.13177372282370925, 0.09881019475869834, 0.13493077451130375, 0.1172130303166341, 0.17702405486488715, 0.09001115831779316, 0.16222609032411128, 0.1324275994556956, 0.085758986097062, 0.1721406786236912, 0.23518783069448546, 0.1951668196124956, 0.15880660037510097, 0.10999864243785851, 0.13145541568519548, 0.12324266848736443, 0.06259937727008946, 0.20030484156450257, 0.1609809001092799, 0.18166887515690178, 0.12929103104397655, 0.06070323448511772, 0.24944818345829844, 0.17674975708359852, 0.05614504138065968, 0.08250429746112786, 0.1601616432890296, 0.12258666931302287, 0.0668172919540666, 0.11383935314370319, 0.12230787411681376, 0.12384678411763161, 0.07391238701529801, 0.08375808916753158, 0.23094926204066724, 0.08861499300110154, 0.13075243856292218, 0.08816079862299375, 0.17711692722514272, 0.1723153208149597, 0.07926132733700797, 0.15461009665159509, 0.11258011407335289, 0.14887219673255458, 0.09618638359825127, 0.15962743054842576, 0.10972320917062461, 0.16907203156733885, 0.08719014367670752, 0.09026224914123304, 0.1843615947291255, 0.14643176284153014, 0.2023961691884324, 0.13215494924224913, 0.07371903528110124, 0.1853171395487152, 0.15097569557838142, 0.1658042662893422, 0.11367490064003505, 0.20168116927379742, 0.111279262782773, 0.08105135784717277, 0.1090467044559773, 0.1370049882098101, 0.13492126017808914, 0.09370180676341988, 0.09951357264071703, 0.10796284972457215, 0.1614891822100617, 0.13953177840448916, 0.13142124720616266, 0.24355993926292285, 0.10461388606927358, 0.16978014435153455, 0.09277426317567006, 0.08259644993813708, 0.15188924968242645, 0.13965715683298185, 0.13168782665161416, 0.13411410036496818, 0.19458427821518853, 0.09622113095247187, 0.12213876092573628, 0.11217765480978414, 0.10289956946508028, 0.07105274358764291, 0.10247018508380279, 0.15291197370970622, 0.09536336408928037, 0.16375341539969668, 0.09527444737614132, 0.14516904309857637, 0.1554821350146085, 0.09723495662910864, 0.10565235847025178, 0.19809324148809537, 0.17565053247381002, 0.10960281797451898, 0.1442636823048815, 0.1787910787970759, 0.21809459634823725, 0.12485764862503856, 0.1942418364342302], [0.05444788323075045, 0.05245913525868673, 0.0652852097118739, 0.05279234472254757, 0.013648842559632612, 0.04199389193672687, 0.009371162723255111, 0.04490703679039143, 0.03585651618777774, 0.021671701069863047, 0.00414175920013804, 0.029034863582637627, 0.06364620625390671, 0.04654956173908431, 0.08399132391787134, 0.04450836990145035, 0.04623728455044329, 0.0254517115172348, 0.028378515598888043, 0.012444467683963012, 0.03527482826029882, 0.048586775665171444, 0.04659127414925024, 0.029601790192828048, 0.007093783779055229, 0.02447076669341186, 0.023883829926489852, 0.02889933814003598, 0.015521050154347904, 0.08842821669531986, 0.026847648623515852, 0.08405816173763014, 0.05189398238144349, 0.05087262390588876, 0.01981423902179813, 0.04623223052476533, 0.05403992465289775, 0.04123337239434477, 0.02325755933270557, 0.0204928328821552, 0.022079212503740564, 0.07710914360359311, 0.0506225015851669, 0.019778636342380196, 0.03555496303306427, 0.0518652538448805, 0.058196834797854535, 0.06926542191649787, 0.08204124183976091, 0.037895117930020206, 0.02598977785964962, 0.026410267601022497, 0.09386938370880671, 0.05795266821223777, 0.005657385245285695, 0.030305145810416434, 0.04112485556106549, 0.06735989838489331, 0.03559217802830972, 0.010004504129028646, 0.06053625496861059, 0.02628379636007594, 0.1086031598970294, 0.026564335603325162, 0.028326392712187953, 0.04021732027467806, 0.015233009653456975, 0.00751153917008196, 0.02047736466920469, 0.04729616972326767, 0.05644555181788746, 0.010343464309698902, 0.018893782944360282, 0.030019101686775684, 0.039662312556174584, 0.08963857791968621, 0.023628030176041648, 0.06409496811102144, 0.01622381947527174, 0.0033028009102054057, 0.016342655871994793, 0.032943319383775815, 0.0350431334663881, 0.023924757515487727, 0.04326214439061005, 0.05870602231880184, 0.015778747947479133, 0.056158362931455486, 0.04845154151553288, 0.05763521825429052, 0.02586567963589914, 0.046919878586777486, 0.04792848696524743, 0.013467715853039408, 0.026153265571338125, 0.07387585850665346, 0.018274236208526418, 0.0454504039225867, 0.03713662445079535, 0.030016253695066553, 0.07605090038850904, 0.05566001076658722, 0.03820753983745817, 0.019247709460614715, 0.039141131928772666, 0.03569364816939924, 0.028098690672777593, 0.05311647772032302, 0.07494295554351993, 0.052745403881999664, 0.03425161441555247, 0.00904343773072469, 0.006734207199770026, 0.015005808563728351, 0.025199778356181923, 0.02862455054128077, 0.03590947584598325, 0.06976884294999763, 0.00898157230039942, 0.033004702418111265, 0.06527632620418444, 0.05984528950648382, 0.05691097117960453, 0.012610406338353641, 0.036885158842778765, 0.025444594321015757, 0.048055564911919646, 0.020192277916066814, 0.009284557800128823, 0.08252189378254116, 0.053906519897282124, 0.04628642214811407, 0.03630303304817062, 0.03011650300322799, 0.01284231171666761, 0.021247344739094842, 0.013555870009440696, 0.02630872138979612, 0.021113607872393914, 0.028146076801931486, 0.01891184496344067, 0.005065933901278186, 0.04858928412431851, 0.007786157002556138, 0.012191733003419358, 0.05860264485818334, 0.07207995760836639, 0.021521586859307718, 0.006355556961352704, 0.01996495066123316, 0.044166855805087835, 0.02974704148073215, 0.020234064541000407, 0.032611520000500605, 0.04240895657858346, 0.019406362080189865, 0.07418514855089597, 0.009686048560979543, 0.027084566281700972, 0.0530818676634226, 0.011883599781867815, 0.022533321534865536, 0.04763922006532084, 0.050025848249788396, 0.058905311234411784, 0.023531204024038743, 0.06645211076829582, 0.03177911232342012, 0.16620909300399944, 0.004039493105665315, 0.019481081508274656, 0.0766980902699288, 0.014734832820977317, 0.03784024353080895, 0.01946443328051828, 0.020273860354791395, 0.04849027049203869, 0.047624488433939405, 0.024898566589399707, 0.0851047903415747, 0.026395166751171928, 0.01594618945091497, 0.012994614335184451, 0.04373618008685298, 0.07795600831741467, 0.08721746213268489, 0.03274938506365288, 0.03222504288714845, 0.07238023797981441, 0.010089328825415578, 0.023350797200691886, 0.00937051891014562, 0.05231472445302643, 0.057011595272342674, 0.037757282552774996, 0.039755485486239195, 0.08370898125576787, 0.07656449626665562, 0.027056605867983308, 0.05075014356407337, 0.03173316225002054, 0.05326664017047733, 0.055762471674825065, 0.027856711567437742, 0.07911706125014462, 0.03656937871710397, 0.028753713922924362, 0.005754987405452994, 0.11083859775681049, 0.03226991313567851, 0.0037014807867308264, 0.05460948588734027, 0.028892944537801668, 0.020908157275698613, 0.01589801293448545, 0.027315448423905764, 0.06849037483334541, 0.03721014531038236, 0.04940746854117606, 0.05492551834322512, 0.04506445744482335, 0.03714129255968146, 0.04653468538890593, 0.04972161965270061, 0.036656035590567626, 0.00439649536019715, 0.05402720795245841, 0.013369041753321653, 0.051051882255706005, 0.039585288759553805, 0.04337391925218981, 0.05468682138598524, 0.029643561974808108, 0.05052542495832313, 0.05639393915771507, 0.039075603999663144, 0.04032979275507387, 0.04624127730494365, 0.012662358531088103, 0.02101222678902559, 0.03968900389736518, 0.01639642632653704, 0.05666449651471339, 0.10218449533567764, 0.023469570514862426, 0.018158821112592705, 0.03998323947598692, 0.006972564160605543, 0.0403167049807962, 0.030450371123151854, 0.12581736431457102, 0.00695502535563719, 0.05398112058173865, 0.007328895699174609, 0.040923050764831714, 0.06681076105451211, 0.03126778741716407, 0.016107344963529613, 0.0199355950098834, 0.105481760983821, 0.045938024632050656, 0.02970273155369796, 0.05401586793595925, 0.028420836570148822, 0.04504826007178053, 0.03526581858750433, 0.010800642121466808, 0.0643221617792733, 0.021467129918164574, 0.032575199293205515, 0.01916049783176277, 0.050537366114440374, 0.009490398952038959, 0.06186849539517425, 0.020820702593482565, 0.01911857762024738, 0.0329228954797145, 0.02385517374932533, 0.03481339052086696, 0.05452775687444955, 0.042374468976049684, 0.04336014870204963, 0.00668936710098933, 0.020947431730746757, 0.019413636982790194, 0.06948802911210805, 0.027272450242890045, 0.040648504364071414, 0.02239131528767757, 0.023729014210402966, 0.12788767431629822, 0.058519453814369626, 0.014421425712498603, 0.03332348082039971, 0.028225703681528103, 0.0328360048297327, 0.04747415900055785, 0.0252111814552336, 0.008482770208502188, 0.0073058919042523485, 0.029240275216579903, 0.05550202236918267, 0.0422276424797019, 0.008189024447347037, 0.03321088959637564, 0.043266203938401304, 0.018243980703118723, 0.024264766907435842, 0.03592362118070014, 0.06940392151591368, 0.00865007163156406, 0.008575867996114539, 0.036744098833878525, 0.025971675022447016, 0.06799907307140529, 0.032692447493900545, 0.04328224174969364, 0.05393323350290302, 0.06305734175839461, 0.012823487140849466, 0.03009581192600308, 0.042934337761835195, 0.07445352399372496, 0.046885027331882156, 0.016473698742629495, 0.016088000884337816, 0.027508382700034417, 0.01626258370379219, 0.006577757367267623, 0.04123523518501315, 0.06636173944571055, 0.06367083813529462, 0.04094797950529028, 0.019396020252315793, 0.03851624729577452, 0.027188917811145075, 0.017955357616301626, 0.06601491899346001, 0.03536244621500373, 0.08719892328372225, 0.03785635555686895, 0.005718233469451661, 0.032982096599880606, 0.03425155133299995, 0.017268980482185725, 0.02682139143871609, 0.01636576449527638, 0.019863382185576484, 0.044763805999537, 0.03078776629990898, 0.05664404292474501, 0.026200512547802646, 0.2034896644181572, 0.11989252481725998, 0.2223492250777781, 0.26168700016569346, 0.12608931690920144, 0.14309643243905157, 0.12150357899372466, 0.12319969071540982, 0.13616379350423813, 0.13811639888444915, 0.09903738100547343, 0.18219910998595878, 0.09142873459495604, 0.15055277530336753, 0.13441045477520674, 0.07292029884411022, 0.18929530342575163, 0.178400382574182, 0.1669145785854198, 0.15244547452311963, 0.18699273088714108, 0.11133689797134139, 0.13674510293640196, 0.09937216382240877, 0.08556083266739734, 0.09581374382833019, 0.11098576564108953, 0.16282310360111296, 0.10794303438160568, 0.13962891069240868, 0.1964969263644889, 0.14314315805677325, 0.17388169770129025, 0.15136556059587747, 0.1635215536225587, 0.12677923223236576, 0.15259598207194358, 0.0899785038200207, 0.09827263493207283, 0.130888236744795, 0.14675081212772056, 0.18871457286877558, 0.10249139566440135, 0.2229901438113302, 0.07905518097686581, 0.1573473450844176, 0.09914630601997487, 0.16331719583831728, 0.24601748707937077, 0.09634622736484744, 0.1842351772938855, 0.1262086839415133, 0.24415529012912884, 0.17306540947174653, 0.2917604270623997, 0.15464460651855916, 0.16125251131597906, 0.19704384467331693, 0.15806479408638552, 0.16875284869456664, 0.12462712271371856, 0.08191117303795181, 0.17338361270958558, 0.08766234255745076, 0.11256743819103576, 0.11491427241708152, 0.14680933789350092, 0.1500581338768825, 0.09234054465196095, 0.07384366414044052, 0.11202375564607792, 0.09515215628198348, 0.14760398509679362, 0.12704866152489558, 0.20137562707532197, 0.2240476300357841, 0.14624857110902667, 0.13018226134590805, 0.12562565272673965, 0.13031250826315954, 0.09214058780344203, 0.16550693224417046, 0.08077711201622151, 0.1538210007129237, 0.22657317342236638, 0.16240306285908446, 0.11493028796394356, 0.14243480778532103, 0.10274476488120854, 0.14015206543263048, 0.16926360956858844, 0.18565039354143664, 0.13609740097308531, 0.06713196256896481, 0.18095485487719998, 0.1757020375225693, 0.05985347910609562, 0.11069005689932965, 0.14084359863772988, 0.06479407864389941, 0.09140229187323712, 0.1274813336203806, 0.10975308803608641, 0.11402615171391517, 0.10053944337414578, 0.12407120957504958, 0.17949315049918368, 0.12011337312287651, 0.1513113096007146, 0.12884391675470397, 0.08514065091731027, 0.24322037701494992, 0.1408201764570549, 0.07412838167510927, 0.18388673895969987, 0.14815716713201255, 0.08461265737423673, 0.13644603226566687, 0.09722039569169283, 0.13706265308428556, 0.14015773544088006, 0.12890597514342517, 0.13159565191017464, 0.090002297074534, 0.14593045692890882, 0.08523715237970464, 0.23889420524938032, 0.10711877548601478, 0.22651966457488015, 0.19535087223630399, 0.10352787910960615, 0.14839492156170309, 0.10795260066515766, 0.12211876004585065, 0.08157141783158295, 0.07984879659488797, 0.11058735108235851, 0.12946562870638445, 0.11777263935073279, 0.11713039217283949, 0.10569816382485442, 0.10580651738564484, 0.14207697386154905, 0.08239616654464044, 0.12020588925224729, 0.11458666616817936, 0.13860165956430137, 0.13506170420441777, 0.13900172169087455, 0.11913978669326752, 0.1199825324874837, 0.12160177255282179, 0.1254934910684824, 0.10852299310499802, 0.15924132079817355, 0.05700984751456417, 0.21160175412660465, 0.10073510318761691, 0.132472618133761, 0.15022703184513375, 0.12623632152099162, 0.21743041870649904, 0.11488120231661014, 0.17321789113339037, 0.15255059232003987, 0.14537415787344798, 0.12472429953049868, 0.10393589705927297, 0.3174567857058719, 0.18507690634578466, 0.10382231877883896, 0.1611168318777345, 0.16760122845880687, 0.17723955970723182, 0.08134844698361121, 0.10237680064165033], [0.047165744690573774, 0.051720538758672774, 0.028462649170251098, 0.04259686465957202, 0.07095455002854578, 0.05294268899888266, 0.03903912744135596, 0.01892547450552229, 0.027220614938414656, 0.06433721995563246, 0.024393895037064794, 0.0246375439746771, 0.0541539593541529, 0.020246389758540317, 0.03254622584790923, 0.010880563077080296, 0.024237951256509405, 0.010449786241224501, 0.036182118637952954, 0.04982633297913708, 0.0339368027925957, 0.037741823616670445, 0.02664108480530558, 0.020141579952905886, 0.03785542045079637, 0.08072286102105863, 0.016975442522380035, 0.03160450352879707, 0.04214107095322106, 0.044250080245547, 0.0423700606188504, 0.10698564161430113, 0.04642652107577305, 0.03846084597171284, 0.032984849967760965, 0.04338700702646747, 0.023409083623846527, 0.020254937444406096, 0.0369086329737911, 0.06324129790300503, 0.040844787581590936, 0.03946828546759207, 0.024797254154691473, 0.016965952308964916, 0.03461185660853516, 0.014395466314454097, 0.05852724636497442, 0.0500772605300881, 0.036593227632693015, 0.006466203294621664, 0.051786983240162954, 0.01869148461992154, 0.07293601011042483, 0.02776099121547304, 0.025409154914086685, 0.002882998583118024, 0.04070661081641447, 0.03234478099329863, 0.05094045991427265, 0.01445993390007061, 0.03903567645465955, 0.007892682097008219, 0.030294429197965655, 0.04764035555126611, 0.0711298082023859, 0.026605734456097707, 0.0874029693659395, 0.09240123748895712, 0.015772647493577097, 0.018615175140439533, 0.025846728894975968, 0.039548737986478955, 0.00927236153074773, 0.020567849169310648, 0.0571166054578498, 0.04079496720805764, 0.02594931225758046, 0.13055474526481703, 0.028700744987872895, 0.0549132617743453, 0.01991763503610855, 0.027183086385775823, 0.059038270701421425, 0.03677529872220475, 0.030343266225827392, 0.03512565657729283, 0.051157334019080736, 0.04386796324979514, 0.06638209655648097, 0.01048042580805486, 0.052048690486117266, 0.04348167167336214, 0.017924706917256117, 0.032207001277129166, 0.03329565399326384, 0.019839277229039, 0.043551685885176994, 0.06073348813515622, 0.08243445394327864, 0.048820466836332344, 0.038888842536835, 0.03144039983453695, 0.05072480293165427, 0.0028581973992913845, 0.06690705471555702, 0.08339604726643302, 0.032214333696174435, 0.022366069279087242, 0.04754596920975018, 0.026904113074124325, 0.011043390277336584, 0.039927552425069734, 0.06761016542441212, 0.044525357661768794, 0.04362312130979262, 0.04408438464452047, 0.03108881850494072, 0.12185881540062837, 0.015019195052445866, 0.049013651587301865, 0.03316004505904857, 0.04616921847627964, 0.04316711609135382, 0.022585114165849518, 0.04263772731064819, 0.056376138745690696, 0.03552132147888187, 0.027764727929024957, 0.03447472627158277, 0.06087418078095652, 0.03555404276994523, 0.1102231495315209, 0.02353765143197961, 0.07463441506843083, 0.020407652882568073, 0.08632508150185458, 0.016080084023997188, 0.05947057172306813, 0.035979022504761815, 0.05211965093621984, 0.11265694862231612, 0.08636262675281614, 0.0143842005127226, 0.017808648008212913, 0.030125818811939098, 0.062348108331207186, 0.021591250406345353, 0.052052041282877326, 0.04903629080217797, 0.06380259903380647, 0.007940379000501707, 0.018426354217808694, 0.015305272572732065, 0.027050019307353068, 0.025111588947765995, 0.03618122806074098, 0.09010467634652741, 0.027655031080939807, 0.01869892279501073, 0.06270741170737892, 0.04027466231491417, 0.02831595626048511, 0.0033686848382785683, 0.043422871312941425, 0.058354774955660105, 0.040437901407130994, 0.03905228200892452, 0.05324621255567763, 0.05889779327844735, 0.006281175210460788, 0.028267584930290468, 0.031171141235972755, 0.03636000030383002, 0.01719078038149746, 0.044389912000042386, 0.03382523944310378, 0.00576600319618592, 0.050295103137614205, 0.019356844131834805, 0.088528221094748, 0.04171560882241465, 0.05265807165415026, 0.03091024478635518, 0.018626735945872497, 0.03629023100074846, 0.015170485567068681, 0.03553765614924487, 0.015210370438580867, 0.01992484129004879, 0.03467761831416283, 0.06806012213928625, 0.017087170999730006, 0.0075140109856874915, 0.024199630461225752, 0.05458701365569141, 0.01977061929210322, 0.0418366382655222, 0.05302952769852709, 0.03622541182267014, 0.07192911609308794, 0.0319517470052233, 0.07417717046337202, 0.05631693762552459, 0.006952355943212751, 0.004399762665343587, 0.03931805622414686, 0.030749766483495478, 0.06780940981116146, 0.04136758980166633, 0.01046161607519025, 0.026982264935213607, 0.058505315901129507, 0.017054946947610006, 0.05935792483796831, 0.05550913585466333, 0.020931625840603374, 0.04546801508695353, 0.023908968323667068, 0.03784223248658236, 0.043787859540316276, 0.017157495058199856, 0.014694544406665955, 0.051398049618001096, 0.06049979325325694, 0.03364856747793965, 0.03092521019425476, 0.03975026818807237, 0.03809538648056332, 0.11588283450691961, 0.00536565441507264, 0.020455226404010318, 0.02532209357013926, 0.05284596489218529, 0.07020594566711225, 0.03712827900017146, 0.026354456240369473, 0.07672957217437215, 0.039184614361147396, 0.07722545298747718, 0.024559640733059496, 0.07907107778009959, 0.02246254291094374, 0.0364748921856517, 0.0869618367869407, 0.0404419498227071, 0.024550393573008478, 0.04593062913045287, 0.02218627658294281, 0.01982112615223741, 0.0327474777441239, 0.02628312100569019, 0.022383400282706134, 0.03138305037282407, 0.05356161418603733, 0.039115138206398115, 0.06454101370763965, 0.035871585496352054, 0.027625664297374897, 0.06013474936480634, 0.05134385799465235, 0.060404675896279514, 0.03484349945210852, 0.06296072155237198, 0.04985813771781977, 0.0707803011755459, 0.053593151751556434, 0.08332193639944308, 0.028521354906843044, 0.06800152215873823, 0.05309724496328272, 0.04836183812585659, 0.015362292706413427, 0.029071913450025022, 0.047447152246604674, 0.052675575207103975, 0.08645138761494309, 0.014327391891129082, 0.02793908068269957, 0.021653781914210413, 0.024754621481406502, 0.03368593461345881, 0.04268280536052771, 0.07995424093678594, 0.013031356211286038, 0.01957987064088229, 0.057139296623063274, 0.023213238273456227, 0.03149714073515497, 0.03749885559955146, 0.0855723062704783, 0.013614902291010367, 0.008896165945770917, 0.07628256920725107, 0.08667437330586836, 0.022815404445282184, 0.04469306819373742, 0.02103619815898128, 0.03301299591839779, 0.0315060984576121, 0.05425949646451045, 0.015589665417792276, 0.06379965270753019, 0.051240487955510616, 0.04278501764929388, 0.03416000741708558, 0.05896675735129975, 0.04311528078687843, 0.06933490178198554, 0.056023741053650156, 0.06574517057742923, 0.018406958188279532, 0.05169106807443313, 0.05738937070418615, 0.03983637216151692, 0.061613957295776345, 0.06367441528709605, 0.02287754075950943, 0.043365091405576095, 0.021757287395303138, 0.056498318517697044, 0.049997364621958695, 0.03187449685356114, 0.01039273920468986, 0.026265361411788035, 0.023763735589454882, 0.03803249688644428, 0.039809124209568836, 0.019870512369379867, 0.02181603580538649, 0.03832424627034925, 0.02497406898328336, 0.059098369820276275, 0.07546736451331526, 0.02884897228796035, 0.011060044071200537, 0.026011457848653663, 0.0419753827736713, 0.028433367733669, 0.030619122517236974, 0.010774126112664817, 0.1090445151203312, 0.09159244495094754, 0.020173852244624868, 0.03520689206197858, 0.06194725581735838, 0.10370281073846854, 0.020848245549132116, 0.041063342650886625, 0.02137388462870149, 0.06620043364819139, 0.08442257108981721, 0.02887997921789065, 0.11396890986361541, 0.15560794388875365, 0.12093458921299316, 0.19475915789371356, 0.12314014078583568, 0.12366018592729233, 0.1507189718540758, 0.15122956945560873, 0.10558681198745035, 0.10311888894648291, 0.10335794955608435, 0.09992665203753859, 0.21767676720628515, 0.11740863817976788, 0.16865292593138292, 0.14242781675420702, 0.13272353826323524, 0.08658369770273566, 0.19506971701048315, 0.12546344893053174, 0.2074324872228317, 0.12218768330058083, 0.0814541288127657, 0.1347532676300034, 0.1402369819697924, 0.11176657179021277, 0.11006900545908138, 0.11646507904515602, 0.11938795345486142, 0.11935857924981974, 0.10250971929053776, 0.2342241074074991, 0.1358429779065773, 0.09224365727277473, 0.10026939067756757, 0.14517975971102715, 0.15583153814077377, 0.1071751416020561, 0.14706034708069637, 0.23016450024442747, 0.17286477726884186, 0.08605784154497087, 0.12235082962433808, 0.09068788567674346, 0.09206934162648395, 0.10356476384913549, 0.15483122697332874, 0.14867080753901973, 0.09361464894027449, 0.10565494856564328, 0.14706362737342715, 0.1316314679570496, 0.24780728010227904, 0.0726671819575131, 0.1358942306251265, 0.08635331279947422, 0.1119350764201954, 0.11696683766786009, 0.1389900254434906, 0.09363487988593988, 0.20754973171278834, 0.10192288085818291, 0.14692627068143338, 0.09329542153864168, 0.22867953695822507, 0.094940681301523, 0.13549779017921537, 0.15413291053846478, 0.07233921205624938, 0.09953452346962877, 0.11486468210932799, 0.12522259232355282, 0.11220394168049097, 0.08699287340277806, 0.21726646344177425, 0.12149300338933244, 0.1205771931563504, 0.18257243995321915, 0.1767759252106771, 0.12950453208759427, 0.20410729455761611, 0.11663141660392284, 0.15244477690430358, 0.18183260777732357, 0.10653020784957334, 0.13655616698088124, 0.10051841833046637, 0.10635726517648436, 0.13179625442717224, 0.09879224220640026, 0.10608501572278328, 0.1340116691426374, 0.09606534673366696, 0.10176752708503045, 0.09574036026606336, 0.11569904905627482, 0.10680296938517131, 0.1357324721175246, 0.1327895448775962, 0.24152577185304835, 0.1681298899347894, 0.137697872123681, 0.12182110687717795, 0.14715388737386093, 0.1339066997752525, 0.11032195165171288, 0.13764433359028772, 0.181043200136628, 0.28933045745361596, 0.1016108448675368, 0.11260640094405971, 0.15160396811552346, 0.10046275725471787, 0.15387649851618335, 0.18339319591177627, 0.08499743125867099, 0.2212919614976272, 0.15649895154638216, 0.09537129022646695, 0.14117655577138066, 0.14690728654386476, 0.15390106360428035, 0.09433658793568611, 0.12425600434653461, 0.14163811225444078, 0.10746687243226916, 0.12111053758417256, 0.06702252547256649, 0.15261526306858286, 0.2304713783087209, 0.12064740032656118, 0.2819965244270861, 0.14553765300661325, 0.11249190982198343, 0.09014317896799184, 0.1460904788109474, 0.15279784623999149, 0.14580075920093805, 0.18943925038911402, 0.27772976900450885, 0.16989651310723275, 0.1963902055285871, 0.1274498665588908, 0.1944499197998084, 0.0812275214411784, 0.19278721214504912, 0.101411170035135, 0.1549738529138267, 0.1650889843585901, 0.1286508989869617, 0.09743416390847415, 0.12191683650598861, 0.08328590512974188, 0.15031591145088896, 0.13514616061002016, 0.16232292575296015, 0.1297937915660441, 0.09984274482121691, 0.09332921894383617, 0.10085045520099811, 0.07329460844630376, 0.10514838082599454, 0.08544015945517458, 0.10836565779754892, 0.13999799557495862, 0.21713097696192563, 0.1233864224923309, 0.36550152639392763, 0.1671237009577453, 0.19345174601767212, 0.24530489172320813, 0.102007314999355, 0.11267632609815337, 0.08054895355599001, 0.20303110621171072, 0.20972469937987626], [0.05229210750258062, 0.08416037031565793, 0.027943964014411904, 0.05421708643552847, 0.033760553851607256, 0.04904260276816785, 0.02310194951860467, 0.042333858655183576, 0.024188574316212907, 0.03659276379039511, 0.010270982456859201, 0.04409191744343843, 0.039767660418874584, 0.031587860867148265, 0.04284949543944094, 0.06306253679213114, 0.03541541700542439, 0.05705821327865124, 0.08270156031358056, 0.04433424350281712, 0.015882522457104642, 0.03023284578375751, 0.043579746488831006, 0.07659927330678329, 0.014300135590019636, 0.03499297541566193, 0.008035908249439672, 0.012686736226896755, 0.01573083489347482, 0.0687328344793059, 0.028723126306431368, 0.06126064676209353, 0.059265445815981366, 0.033818482188507915, 0.03667451877845451, 0.06989959452766925, 0.03142849207506515, 0.022512665709655266, 0.040464169724145904, 0.031180239966488443, 0.024955071858130395, 0.028876379801658913, 0.03908007172867656, 0.0616856302076485, 0.04487101665290538, 0.015246107632265193, 0.0526430357422214, 0.012089342599210795, 0.06482739365310408, 0.07552195689640939, 0.047247510810848325, 0.05275720403005835, 0.023968672248884104, 0.019896602570952382, 0.011571037794055883, 0.020109424549445976, 0.04578188047162257, 0.0007331948825139989, 0.041518676225678064, 0.02635704633576097, 0.04607167429639958, 0.06134632400062401, 0.047360339522128925, 0.026761093795357738, 0.014956473369238665, 0.07080540060997009, 0.012670641826844076, 0.05840065081429202, 0.030370456661330536, 0.061670854047406465, 0.002309247461198538, 0.055258538559428416, 0.019989803331554867, 0.01888542636152124, 0.02597450446046423, 0.006379712012858363, 0.020289740459702443, 0.024680735114088748, 0.017984548139793333, 0.025593075806682464, 0.03238164717913605, 0.05090604281576816, 0.057177936541847885, 0.035467879424686544, 0.023058994011080358, 0.05603379715466872, 0.04749381849251222, 0.03346661513205618, 0.015972955006873235, 0.02154381974833086, 0.05446006929560099, 0.018937679124064744, 0.010861736645892961, 0.03705229792103637, 0.04990036220988259, 0.027504321296873968, 0.06876860599732026, 0.04207874539133627, 0.027394342432671692, 0.06837165346951224, 0.003315812382425065, 0.02000105429033283, 0.020703430272988044, 0.0383633871388156, 0.10485561841051094, 0.041029407948371954, 0.09010055742692202, 0.04174417408648878, 0.022225296852411702, 0.010118072204932105, 0.015608527100994252, 0.03480642175418325, 0.009060345710167894, 0.023923848384583835, 0.09564869760652073, 0.005386377497416106, 0.02976724830659805, 0.05004466169339139, 0.020770694827660918, 0.035614186417660676, 0.006237529041754897, 0.025397792633157223, 0.08090662420727313, 0.04200582567136735, 0.005333117733243853, 0.018628483703651, 0.03986579460615758, 0.020825613755732775, 0.01680330136878183, 0.020465306624828372, 0.060547940083779395, 0.04491413172218017, 0.07720292138401419, 0.06934454228030518, 0.07899337491835468, 0.04659885889850557, 0.042918055041809566, 0.01347861985777854, 0.03177339407557156, 0.016045720731199253, 0.002843495685738162, 0.04787585756275803, 0.01517869464805699, 0.016404534289904404, 0.04218602283799555, 0.05543106562981848, 0.03573872250854038, 0.018562133845989592, 0.04494998858717736, 0.07292138980119489, 0.11628944979747757, 0.006412809016183019, 0.018045472897938453, 0.07358053568168543, 0.02055098386335885, 0.018073244063998573, 0.04833559207327198, 0.010560442315181717, 0.026395035019959323, 0.04669529356760904, 0.06227308462257497, 0.03910166080459021, 0.014857997794024413, 0.020214690775901545, 0.004371442773845047, 0.06381704864907078, 0.025855595704342704, 0.01397441903463914, 0.04985845684132073, 0.07844492036383599, 0.05620458017801866, 0.04483589080336969, 0.03684661540319212, 0.025044296562555246, 0.0317601504502818, 0.03017905863089254, 0.025677409757918213, 0.06923292326973751, 0.023702656835666858, 0.01870774507551687, 0.023096940021787304, 0.07795407131197862, 0.02383451421337668, 0.01756462614139309, 0.04881498607574031, 0.0894693385635037, 0.01636512253753608, 0.03540900113875978, 0.04125435290916357, 0.03189382237906102, 0.04591492899635341, 0.03731291420990601, 0.026220639592793304, 0.05233898526057601, 0.06731487228535116, 0.03799757883825805, 0.0750680519558955, 0.01858460051153088, 0.01802863356715534, 0.015367494233942125, 0.034775949170580134, 0.032302719773724675, 0.05783057007647585, 0.025332402001367882, 0.0013442988188216987, 0.04825103547773324, 0.015440327679243637, 0.011902212845598115, 0.08673727774294093, 0.03990745506598614, 0.05129860554006882, 0.04583028334309347, 0.04715702816611156, 0.06716386007610708, 0.03990801538748201, 0.0429198176425416, 0.056689380726311356, 0.09265960878110491, 0.005759521927757305, 0.04311794509703759, 0.05041814380092546, 0.03656761611637194, 0.09044538892339915, 0.027093945172964595, 0.027955224250035826, 0.02528306402382441, 0.0666488021670375, 0.02536702133511426, 0.03615150504629128, 0.08808535931166261, 0.03600424810429104, 0.016510512978129555, 0.07903436373453587, 0.02987909367220709, 0.0056357386529271025, 0.03427252442634199, 0.07899089614511468, 0.04248598408594262, 0.007003129512668238, 0.05830498426803388, 0.04166023718426004, 0.024878688163880724, 0.0231500573863741, 0.04304884001612663, 0.007449358790836413, 0.06875204868265428, 0.073581693432061, 0.006565273979504127, 0.01786765245924471, 0.03719851956702769, 0.07317024676012807, 0.02732097556872759, 0.019321258150739595, 0.041618057221057825, 0.1266098889755085, 0.05462000583065674, 0.0038854608192195883, 0.011613509050221182, 0.055264549955609255, 0.00457953959084989, 0.0883822406467516, 0.03453263976552989, 0.03160115644277539, 0.03999429005489219, 0.03603786739404313, 0.035448613271000795, 0.04726315528387204, 0.09374011642648838, 0.013970731488370802, 0.05021447621402331, 0.07180882137618028, 0.05120869434904307, 0.0661158213915769, 0.02108237829816062, 0.02410372457234189, 0.042673918142099865, 0.04083562576852273, 0.04368911679193843, 0.0074178499835397815, 0.061648096088902093, 0.11862744504469447, 0.024676564244145993, 0.015169000344030792, 0.025465797480137553, 0.05014295173168648, 0.05966059863567352, 0.042625971691450104, 0.007539807575085433, 0.017016321871778928, 0.04026100679766387, 0.03576598159270361, 0.020852223460678943, 0.026571244998194743, 0.02118858519679634, 0.060628362916759215, 0.02453511089697713, 0.06825207863585092, 0.054053261046647094, 0.052035172266187146, 0.037539562399615534, 0.0712511567689944, 0.025086342939175665, 0.1042620486987289, 0.030434056861849967, 0.03457234095549211, 0.057368894849787466, 0.07971903949510306, 0.04342796986747999, 0.13149221136700362, 0.022761420623282902, 0.02515201187634375, 0.051749241320067085, 0.037729407486040145, 0.010358744202676462, 0.013076748746243538, 0.054085841329651885, 0.005908756693315809, 0.044862185095553286, 0.027295299114484806, 0.022295257258519996, 0.07997168140718713, 0.08339652966242284, 0.02188286805903772, 0.057492291743983515, 0.004417536638356978, 0.058495994526310824, 0.03897634545865003, 0.023782419157214463, 0.031109388983168174, 0.07523985914303921, 0.05070299121143762, 0.03561571524187457, 0.01762298863468459, 0.03246913896873593, 0.015987220940587576, 0.02256595005746931, 0.05125792100443505, 0.019460700277704746, 0.03779620448767673, 0.024532463285140693, 0.010070685148093617, 0.05324923309672158, 0.015614816802553833, 0.026877764976234175, 0.060383825257304125, 0.0424190386547707, 0.017977323332161177, 0.018014035522355698, 0.05250331902061589, 0.01314921482844511, 0.009646220278227702, 0.06339475177810527, 0.10409030088339932, 0.14777110191062093, 0.1219718370703049, 0.15473833977011964, 0.12073203484760597, 0.10657248800271191, 0.12534617475466803, 0.07984950163518079, 0.11481990091851912, 0.2129128618980758, 0.10285088457749225, 0.0734454722260125, 0.13558499253122136, 0.10988160574925132, 0.09751136210979894, 0.11494260019389912, 0.19667749089421704, 0.1866022721515037, 0.2026905643288046, 0.12322500537266023, 0.09272904411773197, 0.17223571805516258, 0.09186557756038383, 0.23217104491777718, 0.09419131994945928, 0.12121880208724178, 0.16263290599454194, 0.10638351493980736, 0.09154229061095975, 0.20915002474794164, 0.054202881728997454, 0.1285110486787744, 0.20920672483043745, 0.14598268928239122, 0.1477490898105316, 0.11195710336323828, 0.11496496110339649, 0.16867173195350915, 0.106795956089627, 0.1359232040704228, 0.14011699153343216, 0.2102184502291493, 0.21635103912558407, 0.12205299834022298, 0.17453072068747133, 0.07936148016597144, 0.13084575621178374, 0.1271906789042987, 0.19606184971053153, 0.19869089301209897, 0.14880901027936488, 0.09793524717679247, 0.1784797923755832, 0.1381759042851627, 0.14296645269496366, 0.14400801243027672, 0.1105432007170748, 0.07276172415004112, 0.17666678497334942, 0.08268812744063325, 0.2544117858633399, 0.21014775324147195, 0.20939564594300464, 0.13158066052710637, 0.13648698397446424, 0.17186443641548976, 0.06195072164700832, 0.09716731728985906, 0.12674994708504528, 0.1551275813835673, 0.1157727740064729, 0.10680400097044185, 0.08010347199160606, 0.1727812411263585, 0.16193994786590338, 0.1209072039637249, 0.096270543144783, 0.11901847523404285, 0.19846688315737993, 0.16971759614534676, 0.20076304354006425, 0.1139222139318008, 0.1468994643073529, 0.11117542890133336, 0.19682738988194615, 0.1431011821841821, 0.13368003303185105, 0.11708733276464045, 0.15929944580420852, 0.19567232608096674, 0.1449089648667723, 0.19992054265458137, 0.09844809348578565, 0.15253355260938406, 0.15766035328852013, 0.1043091899191495, 0.19549520511645824, 0.115398635098245, 0.14733034040546045, 0.1206244679633528, 0.08731696187169291, 0.09843631560215726, 0.11948438070248812, 0.13258742837933823, 0.2677975472761318, 0.10749164532171562, 0.16365500661777332, 0.11669852159684524, 0.1358298715786077, 0.10890306177316234, 0.07894417794886976, 0.10004280557041056, 0.11785292488639243, 0.07433134422171861, 0.13028316374402493, 0.12916145205963403, 0.1856517294072546, 0.1368356597959064, 0.18937018612632528, 0.12916171923279762, 0.2143706477363594, 0.19371229922398925, 0.15993794513633475, 0.18208737223176286, 0.23686285800067708, 0.09494409518083557, 0.21214323991443962, 0.11625287675997242, 0.13363085832679644, 0.1469718385487795, 0.1308761100517586, 0.23927283415105194, 0.24090023041935638, 0.14953324251109734, 0.12206111001432873, 0.12743279716232792, 0.1710459217429161, 0.20385205512866378, 0.12117481499444693, 0.12298090558033437, 0.10803491968545131, 0.15115841233637184, 0.10974282413371839, 0.12491843051975593, 0.10426649416331202, 0.14884916046867147, 0.08604620466940105, 0.11433457344537601, 0.1499223505379632, 0.15535789949353784, 0.16450613125925884, 0.12181355923530646, 0.1235537396860309, 0.12192654379759915, 0.12751483416650444, 0.12329473014688119, 0.14361375389853492, 0.1259785142610781, 0.15008728543762118, 0.121325033105677, 0.1935657547437586, 0.1523800616269, 0.1240668012178503, 0.13191133184591308, 0.09218539868015796, 0.18262513243826106, 0.09424356714589521, 0.07516515455790795, 0.21105062041897327, 0.15862613974604756, 0.13793813501251861, 0.17605065397219732, 0.15762637776788324, 0.12067640345776454, 0.10009691555751488, 0.08288461845950224], [0.03429787990171462, 0.07992393162567168, 0.01765552253345959, 0.015503209851885913, 0.047318486103904434, 0.014722931555297691, 0.08316184772411361, 0.03501639388559852, 0.114730160421459, 0.036583783803507686, 0.03796221179072745, 0.03368438352481462, 0.03051179497560952, 0.010594657178444322, 0.09193401841912419, 0.03727514631464146, 0.06703113438561559, 0.02080104866763577, 0.09036145202117041, 0.08177685172995552, 0.03386447308002971, 0.027786428327090107, 0.016478609904879704, 0.026703002185968217, 0.05070107275969349, 0.03752539480046835, 0.020507575645751785, 0.03366741060744971, 0.029593053259304725, 0.01542432140922756, 0.030816567195870448, 0.012762855531036621, 0.0469349478953518, 0.04404997867823113, 0.004260295027052052, 0.06635946105234325, 0.027237354079261422, 0.056427996314596385, 0.03384075404028408, 0.0573625791730592, 0.0686023203888908, 0.054037045119912364, 0.041114239138551056, 0.030367519611900207, 0.031025042044348083, 0.07259869656991214, 0.09467770127230324, 0.0020164579109405167, 0.10637884683092125, 0.016059309455158655, 0.049840801148093306, 0.03506724584440235, 0.07196980062872171, 0.056269562628585845, 0.0481284994748421, 0.05390282029111404, 0.04662838895455934, 0.06456040602643043, 0.021547415453824215, 0.026212882294203155, 0.04345914006989915, 0.019291833850729745, 0.04316400649258867, 0.0968039914732799, 0.10575872307526879, 0.03665779819129966, 0.04256823631294537, 0.017760209884727374, 0.0626315716363024, 0.02547647884057369, 0.039059540213202126, 0.04678706383856479, 0.010137925582967, 0.06285840907366946, 0.07792788834194653, 0.053915232711005956, 0.03287216226453893, 0.06719284094288014, 0.013107675895298598, 0.02817790380504448, 0.03811880866123829, 0.02320130639418494, 0.016336418120772578, 0.04354744822194334, 0.011314846560708247, 0.029599660228996072, 0.023521969851572067, 0.07136480926419608, 0.01951465255842777, 0.05455506790895015, 0.09058229290531017, 0.015754442611068953, 0.042280312700313516, 0.0018154780582335661, 0.03043551703740377, 0.035988421805086546, 0.01975913084606873, 0.10248856066027656, 0.023823502597224433, 0.03284341517428402, 0.026160542329307646, 0.013278449641802581, 0.035626372482511215, 0.02829671422659885, 0.02015285317611415, 0.10122702093212865, 0.027531524719961453, 0.05156556348083541, 0.03301051714515779, 0.043705518255592324, 0.04021400287456345, 0.06336735910736024, 0.045563384774141014, 0.015988801715138834, 0.05735065285989549, 0.008623203102615662, 0.004633434355127974, 0.011807465634774417, 0.03161167638609186, 0.04081480852619279, 0.060089838298154064, 0.018998227242263965, 0.03516987002512906, 0.09639182491810061, 0.04685328938649036, 0.032566397421760485, 0.020262806065147743, 0.05068479375040624, 0.03438494495640043, 0.007765080472381669, 0.08212166096200235, 0.036052650975761935, 0.045201454195193946, 0.012696521444013342, 0.010083827655762434, 0.08895915656466968, 0.028388835162331816, 0.08325233036885038, 0.037692099722335115, 0.02552413585362956, 0.026087232981808484, 0.0333107344340533, 0.02567523712059483, 0.023434836148226168, 0.06155479328299407, 0.09696295950561762, 0.023167251092672814, 0.038516254717251286, 0.010489961478015175, 0.03933223495550919, 0.12183327809907496, 0.06543808471178636, 0.007616443135702866, 0.043908054067287594, 0.019736669746635016, 0.052271019376348704, 0.020160144777037203, 0.01335669519903604, 0.035176430610590614, 0.03369158606801648, 0.09039453696459532, 0.02710832799493801, 0.04301724678953178, 0.06846143849543296, 0.026875735202338547, 0.04584189795423299, 0.059232015773886815, 0.03787850495427847, 0.036552624733303674, 0.038585819929721765, 0.0020998143145334325, 0.0457405762426788, 0.05319936819432769, 0.024285641666210722, 0.035064013791270554, 0.05657012872688938, 0.040669058143976144, 0.0699869824165944, 0.047992538020480424, 0.0876086184871383, 0.017837255945778452, 0.05696158936189022, 0.03418556327233091, 0.08761353892623447, 0.07784378816722892, 0.07204184090369381, 0.02178657810873119, 0.02678339533304097, 0.013802884586766595, 0.09282096652896143, 0.0939351602573879, 0.03724238420545589, 0.04971508875314612, 0.016440107283415273, 0.09726656469865702, 0.05461862172523979, 0.04819885507458821, 0.06345641682855785, 0.03966457981732674, 0.03161837797961198, 0.04981065139872953, 0.0031384724843519507, 0.03524104198731948, 0.16622610302874818, 0.02047126978141023, 0.034532803038018756, 0.020335907611297444, 0.05333553745003883, 0.08188321633497253, 0.051972972869407386, 0.04666665037802886, 0.009260657861887012, 0.03836424803012051, 0.01260173527043662, 0.07770387848722748, 0.06054592886357568, 0.021343998341762926, 0.061775099820806645, 0.023890190132078715, 0.05833926777995657, 0.03639505936007481, 0.0182510459490004, 0.08883569287718274, 0.014300964940048289, 0.070735616463935, 0.022439794229285326, 0.015768328194099013, 0.02287866696860874, 0.060940205949009396, 0.06770942767616361, 0.009705468710308196, 0.05493307711731177, 0.05202233682211954, 0.06866145471576601, 0.03051242580113467, 0.017727150916471146, 0.04731886459921952, 0.06733021247782744, 0.017196498629346024, 0.05524328000319656, 0.016070656893134583, 0.01415216062014224, 0.03826686712272931, 0.032613334551570006, 0.04348613569163717, 0.01824570990720531, 0.036369830049807206, 0.04517051034781616, 0.01108575392208877, 0.017239003282156773, 0.059622856715577655, 0.01621989722480066, 0.045777891427860595, 0.009792825985641684, 0.04251824524544645, 0.02042670937953517, 0.09188556359731592, 0.030218782085285056, 0.028019991477776784, 0.04062792089825962, 0.0330721747741336, 0.06133517323178239, 0.05032334927818738, 0.02622552477987483, 0.050385622889734805, 0.03911083746061195, 0.041606112354202196, 0.03869391744956374, 0.07419998408295214, 0.015313390740629984, 0.031220879973261617, 0.053069158384460025, 0.03601466414693277, 0.06728612148435786, 0.03839420111034997, 0.10887993645155802, 0.03895727597409859, 0.023138112519518472, 0.010849188784050057, 0.030138990077830385, 0.057696285875863396, 0.06616648781346157, 0.02222358434664784, 0.019766669211094268, 0.035978265514131635, 0.05161509812751319, 0.03506056651531253, 0.026483734654902946, 0.03762471642403398, 0.05346032958186697, 0.016382201210944913, 0.039548199929413386, 0.040282681220560335, 0.02463473123498261, 0.027118491707369685, 0.05034437432186678, 0.06196759808517527, 0.05312733905157074, 0.01963095823157346, 0.04729516040242743, 0.03756589750992134, 0.03750878182472661, 0.03896209251252003, 0.014063813505345024, 0.057051452313316986, 0.012903738352179062, 0.06820759430411272, 0.05006938263250049, 0.030987563586677425, 0.014125792113190982, 0.07737056512269191, 0.04707775566203054, 0.06580448301974684, 0.03071374820137862, 0.04508516336500179, 0.01900124963867711, 0.003460946086306649, 0.058325731006334536, 0.05043571043643169, 0.03357011875777971, 0.0973714524297975, 0.012238249892106978, 0.01803996245143935, 0.020308507519075647, 0.026771237098728307, 0.03268287007813342, 0.017228663309651893, 0.04846871852350887, 0.006197045349836117, 0.05597267758275848, 0.02714335365453735, 0.04294001519156154, 0.016726834182918537, 0.10059179447125643, 0.10471771252923645, 0.011775839011534117, 0.061561836264445446, 0.029707407084060833, 0.05360384238883853, 0.07323689162149094, 0.03253364273405168, 0.014835553392913425, 0.03381661568710115, 0.04031343953101896, 0.02951808706711745, 0.011648702620732365, 0.020537051896099, 0.017816501786001027, 0.00705665737768868, 0.006877843388792826, 0.026066360078402795, 0.035309341838001274, 0.10804593315697275, 0.16059148038038984, 0.11872186107211746, 0.1141392847057432, 0.08962232488556765, 0.14670540753286332, 0.27941491920500994, 0.16961335408268496, 0.2205018710810691, 0.16112883982714266, 0.12760876037646085, 0.11402766569517553, 0.06873831895063631, 0.14770859823329374, 0.15540135966148227, 0.13916943222284317, 0.18922266201116145, 0.07994609215529636, 0.14086890587350354, 0.17267429764615372, 0.10898068299866281, 0.13439512200420722, 0.11823369859484956, 0.1776150122168474, 0.1436357363127172, 0.19059343845583498, 0.12876284454250708, 0.25825931690633297, 0.09151780715910718, 0.1276159443659708, 0.1403359993128106, 0.149835949705448, 0.22734772326657549, 0.16574863489950076, 0.1688761342666112, 0.15267460519680753, 0.19474731321679428, 0.1509545888984576, 0.15856844518566504, 0.16834548383485526, 0.12315951826167293, 0.17205694952281192, 0.1382061542244628, 0.14859825518215075, 0.15318785968702286, 0.13464365241816267, 0.2672324166633189, 0.10663261680747382, 0.16244732454651967, 0.14363201073138043, 0.15663927682908252, 0.059777297647087835, 0.13480079476721585, 0.1653514226200059, 0.14242919714888558, 0.20090838574105874, 0.09481021173996851, 0.20261958532501012, 0.13654733542352915, 0.16593736305367202, 0.11023840808775276, 0.10453031281940639, 0.09883258535410278, 0.16369336080970243, 0.17906702414620668, 0.13217090541729704, 0.1100296493677888, 0.13477640779456124, 0.1750435892608948, 0.09079880706849508, 0.12973278702702373, 0.13777815765934065, 0.09894854592857882, 0.15839650441193953, 0.19131574110360816, 0.15668629930587485, 0.1953964846325107, 0.13823938759742305, 0.17999812262132764, 0.1831706109805964, 0.17770969541743398, 0.14313264924567193, 0.09726695061544888, 0.1578270544996485, 0.09542746338411234, 0.13571883144322783, 0.21694968512747437, 0.23195435263914987, 0.09179041284369305, 0.1468278915854171, 0.13119201263180003, 0.19216060201870278, 0.20843106176471338, 0.16981642052996904, 0.30350725923199207, 0.1718762217205949, 0.1113957873894833, 0.12546542304335162, 0.0936987268505618, 0.18612600630149245, 0.20873243309324607, 0.11084243466029875, 0.11690897983498871, 0.07806341935065575, 0.16924201307119802, 0.1685710670426488, 0.09010059453430586, 0.16262204095255584, 0.12824786826968193, 0.14811075321631506, 0.1974639151012525, 0.14103968889685348, 0.13073327630991116, 0.11244443463510834, 0.12338503467617556, 0.07807173882611096, 0.10606742682284676, 0.1702384205418639, 0.11656396280159242, 0.13698349561309442, 0.1762610231526196, 0.17527549556689337, 0.10009687102865428, 0.17932205577380955, 0.22750431642634794, 0.11316278163576499, 0.13132548046996817, 0.08345706664840691, 0.08908425297704525, 0.10167260639718734, 0.24348346836632118, 0.1350849779555574, 0.20607775601092726, 0.11205017610336654, 0.1603936980245635, 0.13855978759238496, 0.24459827807731926, 0.11171802048920654, 0.09726300981128588, 0.07739678520010784, 0.06368463466060348, 0.14223944483092055, 0.12143064814154059, 0.09731562808156013, 0.19881085376255214, 0.20387884665979072, 0.09174911232548766, 0.08938164639403112, 0.12124745640903711, 0.1272224131389521, 0.23232800915138796, 0.15004234097432345, 0.10683095577405766, 0.19189949962310493, 0.17140406736871228, 0.1718704923405312, 0.13232463388703763, 0.1505838119192049, 0.2777496288763359, 0.14073428028495982, 0.23170263099018484, 0.13905444386182353, 0.1502713083755225, 0.2352111044456251, 0.16658466425724328, 0.16424067987827584, 0.13805297494400293, 0.14008423313498497, 0.16772151575423777, 0.09554633317748085, 0.09265117056202143, 0.09928301704348996, 0.13859852770110592, 0.10748779357527383, 0.07623321638675407, 0.16039766109315678], [0.03532345377607271, 0.03397149819647893, 0.006281053683778737, 0.029701019047934096, 0.06069163100619335, 0.037081085829413496, 0.049033021641662344, 0.043766489397967234, 0.02026215854129987, 0.03590565007471014, 0.058795959484996274, 0.013890934842493152, 0.049113993663922884, 0.018854827612813096, 0.04560781344480347, 0.011616818101174431, 0.07491090960684232, 0.0408245232392801, 0.09541855761199258, 0.04791443810972851, 0.011557964862731751, 0.06867115458589979, 0.01636125223740237, 0.038622678694082424, 0.02721813059906708, 0.01350101973002893, 0.01407320723956218, 0.04342792904935777, 0.020015836016682442, 0.00859070723890909, 0.022695493789797183, 0.09242410305887461, 0.037807511107530445, 0.058996591687900946, 0.04333722376031801, 0.07191716009401716, 0.0517027160822181, 0.045682996715186164, 0.013760191613982897, 0.012525266229204135, 0.016746996479923837, 0.047102227981667966, 0.02657744007592555, 0.019017497106688097, 0.02906213379901601, 0.03823842802376021, 0.0229191770995385, 0.06591089957510121, 0.032557974045630544, 0.00925269740037038, 0.04026146692922339, 0.04274360580893699, 0.017897102734423243, 0.005927910597165464, 0.04120016499655321, 0.04958115336194169, 0.05533808936888818, 0.023048659604683053, 0.03773175638343673, 0.0797830794181209, 0.01827777254220564, 0.056426322771585546, 0.031718534519313835, 0.013345229945116444, 0.023563214708701707, 0.045989195714355446, 0.01739411771268351, 0.023352505995717365, 0.022536844880960416, 0.07825723121641204, 0.014399360734387301, 0.0387965972913662, 0.01124284617617377, 0.015744861484563444, 0.07753056474030018, 0.021707012456317898, 0.0339367137348745, 0.07439693523338065, 0.03305323887616396, 0.061171878478489816, 0.0579111190745607, 0.06498154514702037, 0.007482621385861421, 0.004608058006851934, 0.11772008787374943, 0.08759470321820118, 0.054648485747748055, 0.026204011774098035, 0.055502293253084645, 0.07396687549771741, 0.01917196401336696, 0.0535002274409635, 0.003866576175823866, 0.04980150071787648, 0.04852073936490342, 0.08711555041372776, 0.021505164986592717, 0.1141414295125287, 0.03191205323673785, 0.046576063832617365, 0.05883009827812202, 0.028930653061252087, 0.07712855818681419, 0.058568914246279746, 0.027108049689559266, 0.04632374475477263, 0.050195514340884984, 0.0052184786454745336, 0.08674946380779147, 0.04168509542068932, 0.04120960511500016, 0.05442466514068656, 0.025186672028212342, 0.04499104048591107, 0.02560284803621471, 0.03299501368019264, 0.002976195169139828, 0.006707823849865235, 0.016881453229871113, 0.07888039777753875, 0.028040695542586036, 0.04198136077320669, 0.05446278184535913, 0.03132969366561156, 0.01858116807852639, 0.05381526912970003, 0.023301579822145868, 0.007876178588048788, 0.021032374243077356, 0.06704972518491559, 0.053674736045650207, 0.016472104980493896, 0.026118508940271568, 0.03378800589416642, 0.03216077289835084, 0.020805247368116397, 0.02190329752920661, 0.038716378548997454, 0.053578383012791164, 0.03428248775890097, 0.04984274186426774, 0.06983297193073668, 0.02347327012103051, 0.06043122622941155, 0.03869598062010482, 0.07946834943140857, 0.026046275706903543, 0.06532683677505702, 0.01891458719910588, 0.13403617485892028, 0.0112638869904913, 0.020704819944512565, 0.029844977143511642, 0.026504583438509144, 0.04908665294351522, 0.05841357902681921, 0.05493999022291973, 0.038356396107701585, 0.05988339878967963, 0.03718175816175062, 0.047970963787520304, 0.034757966932374984, 0.024442012181680184, 0.0927342168870382, 0.006839164507255191, 0.0724188148160465, 0.05218860758759547, 0.017142824654001743, 0.02711129101953702, 0.026251329254591838, 0.060518139143823646, 0.06873451915453188, 0.0137580885530042, 0.0327046298480127, 0.016939222005021293, 0.02790976213873364, 0.027836003791890107, 0.06703963197651319, 0.034107237006537616, 0.017894939373945817, 0.0023881113202151028, 0.05447988834930584, 0.06708664703182876, 0.07233276279293932, 0.03448592156928498, 0.07298816824913956, 0.05735864207963459, 0.07954286847962067, 0.03793178744672332, 0.03378716726729181, 0.06266739510465413, 0.04020908985694405, 0.056642914860276505, 0.020105313051317353, 0.046079129169811495, 0.09878458324237727, 0.01781702314474387, 0.04816317632503342, 0.054550448039663024, 0.0402553998719668, 0.04559027649520431, 0.05930714338319376, 0.006509121694762143, 0.013460628342727432, 0.0643346001743339, 0.05661876166414004, 0.05399033434514422, 0.062464863003697246, 0.027035979728680104, 0.027396448276704177, 0.052635514075518586, 0.05512196112249512, 0.12644725473364815, 0.05064895172836259, 0.07140428409911692, 0.040787304533296265, 0.05701707603293471, 0.031477050797548145, 0.045589953660964966, 0.06658624653937295, 0.014040998958080309, 0.0196641693401034, 0.010915159218711779, 0.027242708674748428, 0.05091459606774151, 0.04353412296040915, 0.04280433575331699, 0.03197481666575186, 0.01860368669440504, 0.016924297415243927, 0.023949163041834254, 0.027835794135171454, 0.012023215385852382, 0.024586712424934376, 0.05607825922197662, 0.03624681165092625, 0.046924398266128264, 0.05444109257950913, 0.01677303844189737, 0.035191039787605405, 0.02982747359055793, 0.05957193425274454, 0.04387447188491933, 0.025485091464361176, 0.04781320545589551, 0.03126673727820162, 0.03617431124439463, 0.027703550840669777, 0.05242630264547188, 0.04649297668947838, 0.022175034901010804, 0.0683136768930126, 0.04993005553842522, 0.0576106346125016, 0.011572304083529161, 0.02404580551228719, 0.03777636316954158, 0.04702432102931198, 0.018019998678937554, 0.029373891484283376, 0.009196905521093868, 0.0221475921352976, 0.010679189654183574, 0.02024057503149379, 0.03448977331572678, 0.07544407591922209, 0.034882952022599056, 0.028119930939283222, 0.024464170855935663, 0.021877587678318378, 0.07281266516656615, 0.04506310302531347, 0.04154104826739058, 0.08050169359194115, 0.06230980608961545, 0.02183215896366164, 0.06715764087857679, 0.059941642539342865, 0.07252216630149633, 0.06069969072996173, 0.025301029563706834, 0.0288787064346252, 0.05898331095522735, 0.010657652528607287, 0.03871513545163907, 0.03745972957403865, 0.0602886856358964, 0.025897738560161088, 0.06403915860573761, 0.03818456665612757, 0.016726168105378747, 0.0537778500438435, 0.024367487567360513, 0.013312804585439153, 0.0512137335317675, 0.02831802314176457, 0.05217824720602948, 0.025853827537503093, 0.00695455177265103, 0.05673028790624812, 0.023726502040517516, 0.050079472130164504, 0.016953230042418, 0.041425770468777046, 0.017425402947992552, 0.06372969786752947, 0.06039107604010496, 0.08761480057728477, 0.030885982123436406, 0.06680247126496397, 0.028678757007583044, 0.06118072116805706, 0.017970987246371806, 0.03357057888933923, 0.048572912346571684, 0.013726058386964723, 0.06002716763759963, 0.06615115504246205, 0.024702780610823538, 0.03184122637321707, 0.030623935344920028, 0.0200108877470484, 0.017696934373816475, 0.027278233428660315, 0.043850159127032384, 0.12472458154661581, 0.06445436054491438, 0.00785924277806771, 0.020814082636206876, 0.03416214109165594, 0.04625174529792275, 0.02381079702900024, 0.022359829672495835, 0.032595040611340664, 0.06187602448335383, 0.03187613699992653, 0.03676548752991948, 0.01513516119302949, 0.07963709154864773, 0.01337454663371318, 0.03216442797565833, 0.03390789614059031, 0.015491577614739072, 0.02780755912681343, 0.03288063388026785, 0.034821383451344445, 0.02337995989364572, 0.07608555126353167, 0.0435000509605743, 0.062389831873588264, 0.029092136974213645, 0.027189491120225284, 0.1479485197342001, 0.16615427797660232, 0.08727123073185794, 0.102376874856418, 0.223513298551552, 0.1479782650130801, 0.19827359821647406, 0.23684568470343947, 0.21274957456625998, 0.11700427159667015, 0.14948602707590908, 0.14579577196855098, 0.10219518226222135, 0.08723185979761183, 0.13514553720597178, 0.13826785638229921, 0.21536141488468274, 0.13668682950083166, 0.1796551316510886, 0.1368627927149646, 0.12831503263441846, 0.21904743975028396, 0.10325748502509668, 0.08992301343823783, 0.08116653174511157, 0.16527621337445453, 0.11583346684346907, 0.13105962832923979, 0.2681337995454669, 0.08200498050427996, 0.12576536944834515, 0.1671885052928701, 0.1309669786132872, 0.10899342567427084, 0.15120234747882932, 0.17217742977663875, 0.20172353106318042, 0.147584778314922, 0.16184299369342625, 0.06120122299762443, 0.1851147855632007, 0.13276140263769776, 0.12947618204634637, 0.10592759135761298, 0.144466481579002, 0.07618158517288975, 0.12254719447810203, 0.12799920426914468, 0.11830196875962429, 0.1574987728963606, 0.27154533367138356, 0.15935339994030073, 0.09829927803366445, 0.06730643406626768, 0.2210354307317175, 0.12068029231159016, 0.14238633069908246, 0.12162424478447065, 0.15258563653333113, 0.12882187496870756, 0.11975781759247184, 0.12243451419635676, 0.1399504387518391, 0.10977337093208916, 0.14383806061232463, 0.08613809739472345, 0.10547117795795202, 0.1549478925880976, 0.07882483318098821, 0.1708994960063137, 0.09230872878106311, 0.06879146414576098, 0.1359774253796786, 0.1503326988313347, 0.13887333014281467, 0.20303376310039312, 0.19898898404790089, 0.2141876786481589, 0.14336740539874882, 0.1736885166610591, 0.2439782879082486, 0.15571481315419078, 0.1445392268942669, 0.10961075153318234, 0.17885398323414847, 0.24555642041377723, 0.1421915614628233, 0.20107403310248628, 0.2075639067334123, 0.1786388791515492, 0.05767398433818016, 0.12998505786526948, 0.06986865439102985, 0.15168360056122765, 0.17001549422275275, 0.1771748295868747, 0.11708348101819865, 0.2804706688039005, 0.15717749716714025, 0.2081372306565754, 0.16977119405055419, 0.20106244075577706, 0.25184555794112384, 0.22518215118907392, 0.10365825219196267, 0.1587064252817072, 0.14393798337550834, 0.07998949295142666, 0.14342771231895313, 0.11427819990785792, 0.1497747967368923, 0.10882662056246772, 0.089791378704831, 0.119832588970894, 0.13412333268206567, 0.10343219400965609, 0.1046973851043731, 0.09041701661772095, 0.11826926231151447, 0.11124440410640091, 0.14468050212599337, 0.1161171676358208, 0.11617535201366991, 0.13453664956614375, 0.06619687876082025, 0.12812579981982708, 0.15733722219010815, 0.13306602457305416, 0.12337674488662742, 0.13359372125705704, 0.10150321861146949, 0.1248850635602139, 0.11402408112189732, 0.12958511448232457, 0.13956774288089946, 0.14471885631792247, 0.05812277959194034, 0.15091746667167172, 0.14530219923472032, 0.11467975375126116, 0.15033302537631243, 0.1593740316457115, 0.12033652208629064, 0.15564913308480754, 0.12507410341640934, 0.11371662418241613, 0.15320596809033304, 0.13952095789136365, 0.10725836604251526, 0.1992251057527028, 0.14305536198662594, 0.11364227582816966, 0.12365416710963473, 0.17589832074008882, 0.09848409506957978, 0.13411490188445896, 0.1462321399594657, 0.15945807244861498, 0.3166045033140108, 0.0964949611807242, 0.16172036121133715, 0.18381366709945723, 0.2281248409417458, 0.16464188491227105, 0.08237655900302343, 0.20088603225303814, 0.1382090782863088, 0.12752016278682277, 0.08706177439307794, 0.10532424756092951, 0.12957617902429774, 0.18960651563247666, 0.13499548978870735, 0.10368464296334423, 0.1465336448745802, 0.1467122946633026], [0.08373934251721948, 0.02098367636790499, 0.009449909230170306, 0.016077197069535032, 0.04678862234868575, 0.02539699667977402, 0.013887399436498526, 0.01893596476293169, 0.023495514142268803, 0.03825987980235368, 0.029471975576598197, 0.04318814113503322, 0.026587588945403695, 0.06904755704454146, 0.04848090458835941, 0.033290139836026356, 0.007222268559416989, 0.028917418712808285, 0.0868264542077668, 0.025279802284785546, 0.015393700396089116, 0.031417823702213354, 0.04083044557773974, 0.02124913331499556, 0.022060677365516312, 0.05602343677310273, 0.034416219059494324, 0.048804748148540966, 0.09678606860688888, 0.027410328293626662, 0.05838708435476292, 0.037483815976884216, 0.0271313252960681, 0.04539811590802856, 0.030830129944661167, 0.053227547541609965, 0.011447972083260538, 0.06339028404909186, 0.021300092885212507, 0.010713774663599906, 0.02279018997796811, 0.04602897854056209, 0.05472991419082973, 0.06873530583106913, 0.06999157631071284, 0.034052830160362646, 0.08007465439732186, 0.0562941165844677, 0.03150699645630084, 0.03313130539027043, 0.056031359199550934, 0.015719400253146887, 0.04939817314152606, 0.02524853374779923, 0.030612066548201256, 0.004906180583930109, 0.06530322905746289, 0.01701203225820791, 0.06396213851985522, 0.03673433588119224, 0.02733342695137253, 0.046111501651466824, 0.01241447935171891, 0.04072937990713399, 0.03845998508040793, 0.016390108794439584, 0.015875377430347726, 0.05689381272532046, 0.034638688957784325, 0.03005989197845338, 0.00909444739590981, 0.03192020572896581, 0.05848789027368184, 0.011925157268706243, 0.06336808641208336, 0.04293564394174609, 0.014698359045723919, 0.04832127975532785, 0.040115341762430035, 0.009026306179293897, 0.052464352556853555, 0.03355465982167516, 0.022749577801732812, 0.060217175996513106, 0.007664360828130157, 0.026901465462287888, 0.12370511554763652, 0.013046924614172895, 0.029127255402272567, 0.04638708334823605, 0.020241691963747144, 0.05883934543817304, 0.11647089006146416, 0.04895351536106318, 0.04420019678946119, 0.05307693609211128, 0.013335682215256384, 0.018420849337417167, 0.06509559840196744, 0.03417747015191708, 0.020107335403736215, 0.01495922117101145, 0.034546102324384265, 0.18665304989553988, 0.014369917880685534, 0.051150517392670736, 0.04605260481184814, 0.050883362782769836, 0.04142588179092854, 0.018803402344929054, 0.08745008090045303, 0.048070526609080844, 0.011493519541545538, 0.007289542854778119, 0.07453340876963921, 0.09699843416456133, 0.017487593067926355, 0.03166757494909689, 0.023885729824542068, 0.025866386531561147, 0.04699914738012012, 0.05837075710587669, 0.027963907377852593, 0.022489529255835805, 0.05934963875915855, 0.03000655196956359, 0.031052584999997634, 0.05446171315270476, 0.02071400773274945, 0.02257392628962407, 0.020952430095348973, 0.027405272412579507, 0.06874962185975164, 0.03781863961194176, 0.030480520872515626, 0.00966306517511839, 0.03581228789698798, 0.05183282570214942, 0.024017297764657997, 0.011314610001136316, 0.005912126507610083, 0.05272985217743553, 0.019075948657700792, 0.015693901914346498, 0.02915487071732059, 0.09426540855201893, 0.046544311044272035, 0.045208144656498916, 0.015378645002783742, 0.04722277502878569, 0.07482576300390065, 0.02930801474576583, 0.052510139357764274, 0.01026823187203263, 0.007669884726055898, 0.03234799820347689, 0.022806739871157333, 0.014292017422121717, 0.02744155044638319, 0.0496334487979766, 0.023446890481864102, 0.060523738648043945, 0.054384511240641586, 0.05256694334093481, 0.025821000490395818, 0.02483518903318327, 0.1444343020557426, 0.02208855057688197, 0.009580979003658285, 0.05505374290805776, 0.008730734734854195, 0.023999872137210332, 0.08824234580970369, 0.012837175127060618, 0.015479037174372934, 0.029367714960244484, 0.053545461341855116, 0.016932694816205185, 0.006413482051357278, 0.04021985841973219, 0.057295481601613574, 0.03228164277970791, 0.013105454090691637, 0.04802101422683336, 0.014695424779347377, 0.016298830196319614, 0.08398903810302727, 0.004112359947612276, 0.003707815017151006, 0.011998546397080645, 0.04651613540772814, 0.026974001120834146, 0.05509762981091626, 0.07079024595441297, 0.06956360201002099, 0.014831890894129174, 0.024401913942710962, 0.02484836400981294, 0.03889961481036153, 0.013075234764983179, 0.08387160807615146, 0.02347486388316611, 0.038862166038597934, 0.015536392202193383, 0.052874036628054455, 0.0055416988016077084, 0.05358545568014961, 0.018112800535163842, 0.024993036422529258, 0.018574980422272347, 0.003158668873766146, 0.07783594366628677, 0.02154067304218188, 0.045792945893481374, 0.05652793020999525, 0.02333716765861027, 0.03521235797961708, 0.018813248789228965, 0.031008046862552874, 0.07974897773237899, 0.03884481833665632, 0.05048550112405792, 0.041967883371398784, 0.03749221708858386, 0.07012589019723237, 0.027504280478751753, 0.03296149458037689, 0.05747131122916471, 0.009323108661192236, 0.021473983651958406, 0.02724406309425831, 0.07391862847725861, 0.0159602809799253, 0.049920017991098575, 0.0073700459324754775, 0.015239294716593577, 0.013038199740549317, 0.026876096999330912, 0.036661026533693075, 0.030322614111355506, 0.022634171982645057, 0.025261725422751624, 0.024879986922314856, 0.02030072981142439, 0.03259330027503893, 0.015137896007217932, 0.039890200132504106, 0.06796967660193332, 0.07362180651398376, 0.03703403737745248, 0.03662508803245146, 0.02370192396483617, 0.03437081446463708, 0.03346789533679839, 0.0384376835427247, 0.10749908906291239, 0.023224698888952844, 0.1172752000275068, 0.07292879643500783, 0.04760368974530138, 0.03601643045840319, 0.12362072593532503, 0.07675115382880904, 0.04788028076291084, 0.05072290303360205, 0.023622807311767247, 0.012057825442752801, 0.02190692292060703, 0.03660663453047164, 0.052342469643917866, 0.04569181714032311, 0.017868003124021925, 0.05284254359139595, 0.035774824282270856, 0.03179624109179713, 0.08152030612109229, 0.012514089485193836, 0.01219080068040057, 0.019203481169824954, 0.059632048214552924, 0.008652296219224809, 0.023320497166423593, 0.04477471928112209, 0.028348406667646486, 0.05605940124951303, 0.02358225450734608, 0.04862596106249839, 0.04236580069118645, 0.010426877997815609, 0.04938310383295175, 0.0363681936141802, 0.024408687895629555, 0.029979571190779097, 0.0296795505710179, 0.0922434865788091, 0.028870667119917925, 0.0674916741263587, 0.04834457577089779, 0.014010292597959051, 0.041862606012728065, 0.053907083929516375, 0.08523911164957099, 0.02841084911779035, 0.004886691322099068, 0.03411675133975223, 0.03916359302820638, 0.028286149754421785, 0.08003382143215276, 0.05061975563876331, 0.08256047804025002, 0.06474881505710073, 0.03925555254681967, 0.037631944942404516, 0.026933333283523098, 0.04296792365494184, 0.06000032044539694, 0.04598148851073347, 0.008909273201425094, 0.03978006912802812, 0.05467290240630973, 0.01610288836673135, 0.06768403138266876, 0.06980334539548494, 0.03512085859256331, 0.021616680096485652, 0.007183637453636038, 0.09208000628859736, 0.012082072335033445, 0.040945589789771475, 0.009391757321282057, 0.019960594254371244, 0.01766293658874929, 0.05309723754180595, 0.04468284882022999, 0.03621122938056942, 0.054143242741702124, 0.05515837459824979, 0.07612491477630101, 0.0777899008244276, 0.031288586105802096, 0.037369046549429186, 0.06069683346140664, 0.011483518173918128, 0.03051568568480434, 0.039106763069867156, 0.04290167213184759, 0.02609930030303076, 0.019390379929973278, 0.07525230495957658, 0.062061717253527604, 0.08325173665070906, 0.028703542884613853, 0.1030062828795053, 0.09678357499069534, 0.049153724539792165, 0.08617287443485111, 0.1598945740261115, 0.1435909848078154, 0.09990230959374458, 0.08023801594390534, 0.0920438340108376, 0.09656689755502157, 0.30383427918422967, 0.13257586571853608, 0.09709712496260181, 0.24040158139541745, 0.07825255568604916, 0.07420313078910112, 0.19511194521328434, 0.11075328045990318, 0.16253786656307057, 0.07867484513553791, 0.1586051963386126, 0.21286417701048777, 0.12515247421106324, 0.14535076537868008, 0.20835073170019314, 0.11362257180735469, 0.09393477434059605, 0.08740729608689435, 0.24001781683182344, 0.08693974305060692, 0.12711083865724504, 0.10451728812768124, 0.18324774981010705, 0.12639803549973294, 0.11277405952569097, 0.16526151885045692, 0.15677486720960587, 0.10354102996643633, 0.16025602963054553, 0.09951673418981954, 0.08778610310400836, 0.10773837231681682, 0.08850961545249447, 0.18910535814939067, 0.15055509080411866, 0.12425643479218706, 0.1908726937836036, 0.13804582064040005, 0.15256761718774214, 0.12317005675868131, 0.1039983265218325, 0.1684295097948052, 0.077781180589227, 0.08178770935046487, 0.12217598705319688, 0.1657264298410155, 0.12650163931539282, 0.08989537585875951, 0.09054459180333652, 0.1269475810113363, 0.09002024220535532, 0.23748289269860834, 0.16863192315213382, 0.12341650173766539, 0.15795280400197953, 0.14828935847617686, 0.15647615276975557, 0.11055437003960833, 0.10694570664782077, 0.0797896771109663, 0.15099613432539627, 0.14948291005566716, 0.17329994298052043, 0.07489464172977023, 0.16382347414037213, 0.11071690780227073, 0.10498412128072232, 0.09533775257295929, 0.13054015464149415, 0.20785355212865397, 0.11968383289058693, 0.24278136697830632, 0.18623976269736886, 0.14062640169868246, 0.10258210095344111, 0.16629243618808687, 0.21319766849046573, 0.14564864861313254, 0.14080888096941635, 0.1659129315521568, 0.14260995463700965, 0.15965058555593714, 0.15926791937090456, 0.14711440511746332, 0.19382785161724314, 0.13604717241832986, 0.10568194047664292, 0.11581460887100548, 0.11919336975552142, 0.15274745441274717, 0.19255116465501487, 0.11312317321426235, 0.14751639682799578, 0.2526664623292163, 0.08341526889125817, 0.12310537116718479, 0.16213428665651008, 0.16136536229168996, 0.18665564741240814, 0.09111494713579305, 0.1361177655053325, 0.1622048649005592, 0.0626515131443739, 0.10657365317456424, 0.08464658094453625, 0.23261283058673143, 0.10534596280194819, 0.1647276326548308, 0.13041572616202757, 0.09334044021670707, 0.16814612812595442, 0.17808811651775613, 0.08543439296772704, 0.07770790834911168, 0.20404250506544486, 0.16255826078122482, 0.16092102363472804, 0.10868678509723395, 0.1500868401490152, 0.099559081136249, 0.11493558689835481, 0.1481901333318092, 0.1815653603989631, 0.14633371029049158, 0.21819834859343246, 0.15304143395042047, 0.1701310317730531, 0.15632975671906024, 0.1484790217364207, 0.11804291469161399, 0.10361801294493489, 0.11978837923379615, 0.12176802847534418, 0.2221191889839247, 0.10651105301803909, 0.1992573743336834, 0.0888260969077237, 0.11548038266482763, 0.0946418555395212, 0.13180440320866182, 0.3174974553985521, 0.130699404689949, 0.14674034784547985, 0.11718434630893171, 0.07904053098172881, 0.16929154400713742, 0.15063071565236896, 0.14583884621970356, 0.11237450205953792, 0.11328602267894894, 0.13583756022853777, 0.1667310603079386, 0.2182908053509891, 0.1538667466957122, 0.07875023249653168, 0.19554436497855932, 0.28071474633179605, 0.17819596541812643, 0.1837742590578273, 0.07803208587574773, 0.1087012495554518, 0.11651621302007698, 0.18535825453000143, 0.09670794272096828, 0.14397232996998355, 0.09577768287272193], [0.021813872444909066, 0.06071093426726293, 0.03900668445567135, 0.0364277954940917, 0.058322792101535015, 0.060419800865929574, 0.01310284636929282, 0.008597604573878925, 0.015917776327114552, 0.05069796687166672, 0.01415558006556239, 0.04064873814058956, 0.02772803058178397, 0.06587244148249738, 0.03156664657581132, 0.024436789317405783, 0.011039346500183456, 0.05409191580838524, 0.019193953849026002, 0.04374804331746418, 0.05671096238074824, 0.046430896036326885, 0.007437260392180178, 0.007040909467832535, 0.03263912789407186, 0.023648576534469612, 0.04790387363755144, 0.03742739419976715, 0.008867458745953627, 0.011063970960094593, 0.07376229506917298, 0.03908632803359069, 0.022834514747955836, 0.01997846702579409, 0.025925921618181746, 0.07279017809196375, 0.044627607057918794, 0.04397315897222143, 0.011617937816481572, 0.05951677041593939, 0.0539130767720053, 0.03277156785770785, 0.04447061684913933, 0.061921221276861615, 0.032039442885434255, 0.04875519123743288, 0.05170201475266367, 0.02549681183154462, 0.019647374538180884, 0.016765988038969226, 0.025760829012142494, 0.05993952741846442, 0.028224638699612115, 0.009833478052314604, 0.04306176822865382, 0.06498740811366588, 0.033241677592741325, 0.04784810123965144, 0.05126336094690487, 0.020855154944001697, 0.02738547005719738, 0.019476764064165764, 0.018612948697409593, 0.04633735945390072, 0.014279508523031836, 0.03136583625746425, 0.07513671545893885, 0.06096327932027634, 0.058039811192429624, 0.033270628773607314, 0.014302921426860848, 0.04270180063031148, 0.016385425842599943, 0.017964545404538512, 0.08106510242214426, 0.0024076856971078087, 0.031795135291758925, 0.015697731396357995, 0.045506224560085684, 0.015581412735627964, 0.03555681098077912, 0.052231370136723854, 0.019143925674143247, 0.04737491901323665, 0.03999886539531872, 0.025399019032192882, 0.032015872275223956, 0.08467994048260152, 0.05891600187169388, 0.03303796547697857, 0.05429900840681512, 0.054489591930177994, 0.03541081940056756, 0.043363024524296634, 0.006446332754421746, 0.023546173142676707, 0.00415857719417545, 0.06487820850452408, 0.0251860616117483, 0.058614816080080345, 0.042006489893537946, 0.0371374111273326, 0.02165718651667703, 0.03788657209952362, 0.059529787686187774, 0.05770930314611178, 0.04594842583173886, 0.04792107290995773, 0.002804168584589206, 0.09901000317768194, 0.02463142682245234, 0.04267470110789873, 0.016156701494765002, 0.034337265678914264, 0.0013356003842091013, 0.06346440975903533, 0.010697670986701269, 0.06621857173740864, 0.031107401882763952, 0.04183660857961513, 0.017274318379350007, 0.07437585081788711, 0.021012280594732147, 0.043046936407336034, 0.11564837521291338, 0.023305823051487096, 0.006930497838766314, 0.042909460971714, 0.018403015528747346, 0.022113638879091013, 0.02911647199653089, 0.021456103459058795, 0.03236876720620785, 0.04066122477524914, 0.007398606094284332, 0.035811397319776006, 0.07127126154955477, 0.039282537036342546, 0.05546598738874309, 0.03706331139255781, 0.04343648601206951, 0.03121275716694072, 0.021341335886972956, 0.05228582151175942, 0.020243677208782174, 0.05008905325667001, 0.0411219537636498, 0.035062269744230434, 0.1122599293012172, 0.04731798886496108, 0.05743372516008094, 0.06527271194499917, 0.008827670353639405, 0.03221959552320186, 0.018071936028718483, 0.02683393187908223, 0.02030536637903424, 0.03232508068322204, 0.07055166774080135, 0.010043766524177045, 0.025103579318965785, 0.061954235716257244, 0.00848816562211141, 0.01796504635422025, 0.06623230889090337, 0.01679435848927824, 0.0453648417169461, 0.03587120329029858, 0.05597655901510734, 0.1036150666186586, 0.035436816833680496, 0.05770213399955537, 0.022467921626230236, 0.035962346446467564, 0.009191472072416218, 0.10462724472745322, 0.049180234054801986, 0.1261403172975406, 0.01992440713365795, 0.04742729608551599, 0.0384833849966526, 0.047349723099614494, 0.01714649271889357, 0.02972086407680763, 0.07602312180097215, 0.012955145994055783, 0.03080935166508425, 0.018600625335238874, 0.004719086546174367, 0.011886360571224941, 0.054912898121983744, 0.01795961012248881, 0.04878650615864899, 0.0217180333493161, 0.033688543262542225, 0.0162996743893018, 0.019546548210200854, 0.024438922991976142, 0.028641451099247206, 0.016919141344260424, 0.08560085669159889, 0.021816546031914186, 0.03113072016276419, 0.01875699028460076, 0.040901064639911056, 0.032287331341649406, 0.02758056769380346, 0.018736766760412138, 0.0364525386976311, 0.04581265733577311, 0.023177661569206975, 0.016180526290554553, 0.012086068800272187, 0.03583207726478577, 0.019328336384205613, 0.01796122614905471, 0.10245085955830291, 0.06385455679264851, 0.028192390527692623, 0.08564691437641159, 0.01775077162164962, 0.02389709396084072, 0.01901989795442205, 0.047150883183348924, 0.04924062632198911, 0.08997846671263687, 0.02999067186465254, 0.04358722362667322, 0.07776451937388629, 0.024110925260174554, 0.06514658394735307, 0.10337640676880255, 0.05033076333347708, 0.013413599372142926, 0.11715925429598428, 0.045717079847236164, 0.022457396116806194, 0.09683343247161247, 0.01935355827299645, 0.013521860164473765, 0.00882653394000954, 0.04009028314612806, 0.018638372821442317, 0.09920705822878517, 0.0300631852587685, 0.009607335450709797, 0.03088086687057512, 0.0076978261222393485, 0.04053530457895249, 0.03564687431207858, 0.08653305354528129, 0.008438857330475003, 0.019255349870945793, 0.0360881367669208, 0.07663077747565694, 0.03066664037760347, 0.015999484930944163, 0.007595582756039221, 0.008771772718318971, 0.005587000887317117, 0.01850707205448998, 0.11984570272034034, 0.011923911388294073, 0.04490172672376502, 0.05808011723274831, 0.048864364871405996, 0.008623684570920886, 0.056378754816250876, 0.023290148892556317, 0.024178854037018027, 0.0016326118270626466, 0.023249531150213443, 0.04523746691120323, 0.05496872247022111, 0.012273503762116889, 0.014922679674782557, 0.034953444919665344, 0.028345087412162684, 0.03819617755652871, 0.021603740751743317, 0.03125039889710024, 0.04181534233794082, 0.07851068949094042, 0.026808416841959115, 0.017754953623807523, 0.03781264305871446, 0.03802498635195661, 0.04635730838344898, 0.010719853780756239, 0.031014117630547844, 0.024925213401729707, 0.026877662930928636, 0.06141495039628353, 0.07715461499174125, 0.06258742127101868, 0.007441474399456638, 0.033478110999567434, 0.04880256252363324, 0.01960112203960307, 0.005765575069744955, 0.07666427060030401, 0.035395330778555945, 0.04287296214897651, 0.06151559675345197, 0.022321699980238918, 0.026560183287074324, 0.056803849583957344, 0.029639231543114875, 0.04268103533831891, 0.09370694242534228, 0.021790094033349305, 0.03389642995898612, 0.03807524459261913, 0.07116169828805141, 0.06268042721785605, 0.04321880667703226, 0.017977685129153542, 0.08761235148995183, 0.03144047404930461, 0.02532705297198845, 0.048625207782606594, 0.01824959876103094, 0.021170679028728046, 0.016107057381304912, 0.07815192788257264, 0.003523719719851215, 0.04279024236893747, 0.058661589937401004, 0.02508289566321764, 0.005570607308982289, 0.046331975172506645, 0.014227514584490564, 0.00465429473479162, 0.04979855439160019, 0.060698822417180054, 0.0617234537639888, 0.056388658776995726, 0.004312090441089822, 0.02729593365074834, 0.03838508011540398, 0.04316576167184394, 0.029011600963713136, 0.03552214155206457, 0.015610009540978353, 0.02451752941851737, 0.06665813838480972, 0.016249301115749404, 0.043252466784906574, 0.01812137234082911, 0.0290664957719855, 0.045193958503659815, 0.04067321046022698, 0.14222884696209803, 0.25855261366814375, 0.11741237860405818, 0.11848985828692093, 0.14830191561486572, 0.13048787775915116, 0.1204384709126316, 0.1758479289128445, 0.15187180921202525, 0.16674143553245813, 0.1904378694598563, 0.1403426637989469, 0.13698165508685634, 0.12239834934007376, 0.138576248427853, 0.13681067910511047, 0.14753882453078404, 0.10052146855741739, 0.09870837951893918, 0.12035371022648178, 0.09688786158221774, 0.20035800902405754, 0.07902392171672545, 0.10800641379319131, 0.1266747823683545, 0.13630695379106328, 0.1295124730677344, 0.11295376316411421, 0.14218203228665516, 0.15154159802477807, 0.17519620450912043, 0.18083366216160357, 0.08198010371415876, 0.15545902453595772, 0.06536428554682061, 0.21567215211689472, 0.18997775274328887, 0.20180145656922832, 0.09628853280446492, 0.13633245398523286, 0.20473598269745708, 0.11104410586995073, 0.16969405522104353, 0.16269478626782075, 0.11930371227208525, 0.1718436265946366, 0.13830013980623335, 0.1064130301529076, 0.10813899105414748, 0.16836418595630676, 0.1095302210887894, 0.09190611366648227, 0.19721241609659046, 0.12349453856586479, 0.13732883176999167, 0.1724767527775839, 0.19686007406562567, 0.19100489997072145, 0.1586814594338648, 0.16517255018698052, 0.08603292764746584, 0.34676063514780253, 0.09646635138778947, 0.08322835157741793, 0.05681896713213064, 0.13754574669292197, 0.16213033843087032, 0.21765162324300036, 0.19194747204892337, 0.11978333262959495, 0.1027984221582301, 0.16021335613913834, 0.11724850497557782, 0.16617110988590866, 0.15590259135933593, 0.08910562683013268, 0.12307118784519844, 0.11498790088808164, 0.16672558325808495, 0.11713763553416356, 0.14020279864780605, 0.1707116881152615, 0.10013514358433895, 0.08051669239648618, 0.09106429555686191, 0.17862462991615757, 0.08705236396053806, 0.2706054481677711, 0.12409006754751317, 0.0973750147386454, 0.15832988923648372, 0.20560851087793708, 0.11249022514675744, 0.07028798267128877, 0.11998521164059639, 0.12168061832198873, 0.12805262405890971, 0.24724925926420838, 0.2152344779460691, 0.12287631470826454, 0.12495006085373461, 0.11873001727508381, 0.20205268840072677, 0.11373059882316738, 0.11210329161258414, 0.10595477622700855, 0.11801076485426165, 0.18682199239265174, 0.0874315197870601, 0.18680991022847593, 0.10039920714916661, 0.06982992170378566, 0.17299500934313983, 0.11218997446121648, 0.1215477887308225, 0.13218365551438183, 0.13426270801573992, 0.15291810384951532, 0.12358843508991413, 0.1762335785315372, 0.0745584191463422, 0.18070914462441579, 0.13298435864271596, 0.12441706523532048, 0.20142481662333012, 0.21655089949490502, 0.12418030528351665, 0.14326800213893875, 0.12897650885861367, 0.14145584078505635, 0.1099803410761524, 0.1117382143274881, 0.14442469866480678, 0.1563892769627273, 0.18465487664798275, 0.1883357806946151, 0.1817163874511607, 0.1571832413901575, 0.2220786825637333, 0.1494210446253419, 0.0897864434227813, 0.11969039347604848, 0.22363490686984733, 0.1346567735890858, 0.1168725329625886, 0.19101892656181008, 0.12705995701253414, 0.12580177921336144, 0.22781362873502076, 0.1347403394174762, 0.18957492982735857, 0.20066687604412436, 0.09508552626357414, 0.12216249480843544, 0.1794452522881329, 0.1944258890580386, 0.10751670764875598, 0.10740250596427359, 0.2450378966750577, 0.15931134985294193, 0.10658162384061143, 0.16590268991421908, 0.11282278152066283, 0.12778304633684456, 0.18576803879113868, 0.14053522143512964, 0.10783507415908389, 0.11161331829498522, 0.13771457044640556, 0.1260626144357957, 0.10216496943030506, 0.09105020217248239, 0.10786785482196137, 0.14602056849980727, 0.10539797251112759, 0.18361681984970346], [0.04069922644703183, 0.049757910674088635, 0.01613100463146111, 0.052196277683833614, 0.04933217023790348, 0.02677365278941579, 0.044587063530343585, 0.05761030435678549, 0.01621803814487066, 0.09269350266549736, 0.02322872318472946, 0.0854631957190577, 0.03786870489420835, 0.018816677511495072, 0.020322116652096156, 0.062127349083311856, 0.015123000175663037, 0.020334419605205767, 0.005158797912372393, 0.07116289314581081, 0.02826940133672906, 0.014843267090327572, 0.03149478441628162, 0.08946611764258705, 0.07254223397467285, 0.03784786538744811, 0.08112759125651792, 0.043470988457556814, 0.05069480903330259, 0.00954210530835553, 0.04013284902612213, 0.048357938139815815, 0.05367331854358781, 0.08224691322539002, 0.09385785815538839, 0.07264046464115381, 0.050339234949206, 0.07180321073974483, 0.04259276800439693, 0.0394397276249947, 0.007456968123733532, 0.046694985576323234, 0.04218195957946591, 0.03468698421784211, 0.04608066170476377, 0.004150847262280877, 0.0076156907834956655, 0.056258589975186624, 0.027510581312526483, 0.04627940885256976, 0.06005025214108173, 0.02594369976577582, 0.06248359481105581, 0.07042577723041177, 0.012270350562175736, 0.05384151889302302, 0.0315185145882424, 0.026127767232537735, 0.02836882500560023, 0.06691572300042026, 0.03165498441376258, 0.0340501844038954, 0.05552529612032231, 0.05808539019199088, 0.051979514901177026, 0.012963956214662176, 0.034812522208085284, 0.013832842305419035, 0.029272126339492388, 0.034274966092198156, 0.056477642283425666, 0.03198398961103521, 0.051587512498372234, 0.02785659467917867, 0.02792971663438948, 0.027821862167911604, 0.04505248289206065, 0.016690110860508867, 0.04287091753212735, 0.05894849309697747, 0.008471347628074, 0.059049161718576215, 0.056848560270736925, 0.03318983486678917, 0.02230943598988233, 0.019833091428154148, 0.051098945550620556, 0.07632818902493455, 0.008803920700302115, 0.030618654964200687, 0.01377461896481691, 0.013019339912716532, 0.060554734445759095, 0.014393483852472855, 0.053742898599011824, 0.015473429320991272, 0.06477799630374648, 0.047779767992324196, 0.0249015555891674, 0.050045251700794324, 0.005709256729460321, 0.01797664983314462, 0.027065070062235463, 0.01853994919656543, 0.05724465190724004, 0.03684387687826529, 0.08781576674664393, 0.048652325858711265, 0.016763815401645843, 0.031090775919437874, 0.01495005193646648, 0.06765041209291667, 0.021723352692788467, 0.05685184798494447, 0.08937724545830861, 0.056837795418687165, 0.10650261479895562, 0.05448628195154015, 0.059034508012700826, 0.04136504794587381, 0.01060091441104305, 0.00938833509280812, 0.018647824072104413, 0.01741981272061821, 0.04559938264719676, 0.03328549770230893, 0.026359118783148006, 0.11631584056885913, 0.03521491838910151, 0.1256987394299358, 0.038176113594090566, 0.05847458727657795, 0.043573753646342084, 0.046670142182847485, 0.039717305699014105, 0.041560655809007585, 0.0743467289430555, 0.02461546508129686, 0.01587752965861, 0.06082391140807886, 0.024565204985265154, 0.05070527331554331, 0.03983382288424764, 0.053500728390645236, 0.01706850598566234, 0.05019473137508612, 0.024199049730668776, 0.010957492249872303, 0.03730330339749344, 0.03695570369018242, 0.018921971568488516, 0.021269933859002776, 0.04199558032269124, 0.04567359741486143, 0.03614500012190547, 0.05729701784730423, 0.014592802453989862, 0.02927965542767197, 0.026869939028983936, 0.016577196802245453, 0.04842702837777324, 0.06723825295921415, 0.0860532550723292, 0.020803028346563224, 0.02777189150947379, 0.04511368038947694, 0.04642547464754898, 0.04746078178868629, 0.035205923559260555, 0.023105548934836406, 0.046981881314422935, 0.11797769475379027, 0.02082904989947565, 0.04101882121176459, 0.017880319064715877, 0.0636427997960709, 0.04316171325626783, 0.019618723927123938, 0.008077783004409866, 0.006504280108856619, 0.01989359316212358, 0.036504221861832775, 0.012391875388857443, 0.018711815755523276, 0.05273951494018547, 0.02203647036367329, 0.02048383619694505, 0.025735651652212255, 0.03131770055915695, 0.022209817507246044, 0.015807211166247725, 0.025027791198226623, 0.05086271994514391, 0.0341226217278745, 0.06487736987764947, 0.04302840869058855, 0.046647235794807784, 0.01646173717745114, 0.02486572841007728, 0.046641016597277485, 0.009088964779948583, 0.03044109613256296, 0.00682109181980195, 0.03374621184775606, 0.017617886369407643, 0.015364599858003203, 0.0338995098718442, 0.008936739159253193, 0.019167789432685822, 0.033105608526966535, 0.05353998058126308, 0.026715071362559684, 0.06100882121245377, 0.04564121009025257, 0.04530699872702826, 0.07139211287721992, 0.03616581736423541, 0.04821954615181312, 0.004454062363947742, 0.03177559454343282, 0.039505407694377936, 0.02153174686100101, 0.02786428518447792, 0.02916145542258164, 0.018377851156401448, 0.0019181082689101459, 0.026192065051873215, 0.04372074341517873, 0.017557816936459858, 0.03634045955550391, 0.02200113856815733, 0.06932542455615476, 0.04251974438375328, 0.022804760192229878, 0.022320419775496703, 0.021990323621139396, 0.0452956364460988, 0.004960026180924615, 0.011753145063266857, 0.04562698683002964, 0.06342805936583318, 0.017883783038996626, 0.047711464430904016, 0.04085888467670884, 0.01991877237742301, 0.02766095713013783, 0.05294474845868535, 0.02844189315510448, 0.028463164962886367, 0.0431753316661343, 0.1000577821105253, 0.03683221773826517, 0.07748758696834557, 0.011668947481666692, 0.024506933405064046, 0.04043881424877327, 0.043751572229666635, 0.019569753312680405, 0.026674551954783965, 0.028428864752640948, 0.025073858159885276, 0.02175411100324709, 0.04726498096715659, 0.017996749047597405, 0.028055954098817892, 0.027957760539720766, 0.034786472824634984, 0.016689858530298807, 0.018992319746757858, 0.008246114157373086, 0.01854412377724657, 0.039178840452223085, 0.01731940941681387, 0.011476478903205134, 0.07657832247787155, 0.03861523495288566, 0.051215021157986484, 0.019024356406589504, 0.023622068874828983, 0.0275908501498634, 0.04805528289580252, 0.028108115948271006, 0.01519021649073693, 0.06708124419674277, 0.031925144721753895, 0.04425094484759029, 0.058602971403161064, 0.06496356290881522, 0.05282502890622709, 0.07510830604587682, 0.013748245819442673, 0.053489640704356134, 0.0016998850787786068, 0.015105367674550507, 0.06141943667898886, 0.022310940694296733, 0.023763347817293834, 0.003493436615826795, 0.016748818452470005, 0.053607601366820745, 0.04295552978874184, 0.022609172738157213, 0.03998804859293159, 0.02034706951235421, 0.009208444062096532, 0.022943081676203292, 0.020540532568702474, 0.11745572002837434, 0.06354560071486048, 0.07226251109386794, 0.06720390636473894, 0.021315857957233675, 0.04858001469983719, 0.06159184129501227, 0.015672396330046467, 0.04303383007936645, 0.04425323808391113, 0.012478460830607219, 0.012068156138411723, 0.061496033740695566, 0.05061709132860415, 0.022556740004802123, 0.044510243824333884, 0.0801427241822239, 0.05288748063321691, 0.06548202727572061, 0.04021768021630123, 0.055043916872818954, 0.0990595192706678, 0.03575497554265894, 0.035277796851005405, 0.042786390622495674, 0.007798922870279057, 0.04185691745078657, 0.009594180883141235, 0.02806246830004966, 0.05181836866540834, 0.027890627716260497, 0.09343392113805749, 0.024819051031954587, 0.024949542857939377, 0.09496937273070216, 0.02257234551507281, 0.08752892666961998, 0.03688636112201493, 0.030063775266171433, 0.029878837631258648, 0.012503789403126575, 0.06371276947902516, 0.0295404071584926, 0.07728506228886545, 0.0603407398739364, 0.13839317543897778, 0.13936611620010808, 0.08302649483084679, 0.09781810658751056, 0.10593458981020376, 0.08464036916848272, 0.19346871151356027, 0.15637286065611988, 0.11726515876944177, 0.17283691704506055, 0.0814073438232299, 0.19745509838685393, 0.1236813074501697, 0.14757575379917398, 0.12511235370766371, 0.18175791803514585, 0.16453514923341572, 0.1438723478349857, 0.12605600932147354, 0.143548890191596, 0.17599425074877217, 0.11120991650386713, 0.13197717518778518, 0.21727519109845161, 0.15556773432763293, 0.09381535535794683, 0.1519578686566092, 0.18371654965449125, 0.08262641043984331, 0.10442270882776938, 0.13896448072046041, 0.0989186744845938, 0.14426267298404127, 0.1592955569503829, 0.18117821164196357, 0.18439947394654155, 0.14876382832881063, 0.16794938477687538, 0.08764972604694776, 0.15075680654263124, 0.12416536585078575, 0.1428985016536899, 0.09831929375650361, 0.1167794676439371, 0.1291719905566424, 0.1259581942576915, 0.13436867186101153, 0.13146550889359787, 0.096150322642643, 0.14121872460236773, 0.1283813954796642, 0.14496950927423313, 0.1018129762087483, 0.2202484870213084, 0.130324887286406, 0.19182835734682158, 0.19646535540232435, 0.1074700042954646, 0.14149085531244054, 0.17738172551617026, 0.09279345511458814, 0.10185339357121848, 0.0822894753946457, 0.15484042960451916, 0.19735860434593633, 0.10846472709090449, 0.13447027187794447, 0.1642971721594222, 0.06641996093094349, 0.13246110000181943, 0.19590973912272602, 0.1441715966211632, 0.12324416020419449, 0.1653847747365944, 0.20964582392480224, 0.16663293354213238, 0.15131138381548226, 0.06576041429070756, 0.2016531754634343, 0.0831969958380796, 0.1739071385236457, 0.1452864211751148, 0.07973471365403384, 0.1777449474320747, 0.15917155891656876, 0.13003415835555643, 0.14452148956479505, 0.12479352706577629, 0.06689286485197954, 0.1807511056540534, 0.14446290442720056, 0.14551127707818523, 0.08789628234808333, 0.10919346415903419, 0.08977842080639675, 0.11588001434574835, 0.12752329465001822, 0.07598232594318688, 0.2742380235577002, 0.10623022433719598, 0.12250055049662478, 0.17636722448514774, 0.07715839994489215, 0.11162486611283384, 0.16351999511243775, 0.1460640286677517, 0.22894611640367657, 0.16569284023717046, 0.10653636767528951, 0.08008514836546965, 0.0713616848224774, 0.11934858252061531, 0.160667045856826, 0.17993840941926464, 0.12802826677216217, 0.17306319787167013, 0.1303451182320714, 0.17030892457114533, 0.117541757208528, 0.22150011907797307, 0.07276435135281645, 0.11231599855818786, 0.06993795614107512, 0.13846676680259407, 0.22430652083130553, 0.14879155496601015, 0.11348048021318391, 0.2228560674120672, 0.1318707363680005, 0.2070608048234135, 0.0969303198507987, 0.13611102680442855, 0.16770846879808232, 0.15665628685383126, 0.14316123677417636, 0.12334357088548131, 0.14741484133992344, 0.11261909166933037, 0.16645909287035465, 0.13906333479098976, 0.1362086192239076, 0.18714356498094276, 0.21530219150008634, 0.17055139906005934, 0.1515268738148734, 0.09984874879592098, 0.1254471216816455, 0.2541947818826884, 0.214457226684317, 0.1646664648433216, 0.1141503055987414, 0.1253188488772139, 0.11253917720750906, 0.18427782109938562, 0.08142496240907349, 0.15584366483381018, 0.09600488396245055, 0.15239664120599627, 0.1301215833518654, 0.11516321101225913, 0.13999508635606617, 0.12852960237069055, 0.18021441414020956, 0.08756475013797171, 0.06740167387761176, 0.14377493353094906, 0.17413367168046534, 0.1741982830571942, 0.08589712204411626, 0.08481613200274296, 0.1452055122354068, 0.23561155248899013, 0.14995436678873375, 0.08904673741199076, 0.09433900733711198, 0.14428842550842091], [0.022682530325255357, 0.04864281523623504, 0.05140337081684265, 0.018018941118498333, 0.0218103899169364, 0.04950130569341127, 0.05377170135034248, 0.02868962947104592, 0.039843860431574285, 0.09358780545881018, 0.0365732898353599, 0.02113240276230499, 0.029691903619095683, 0.008140449954225915, 0.04918505801470019, 0.010808212027768604, 0.023460202755813953, 0.0629535004554782, 0.056775974517222494, 0.07123113362467848, 0.029637645202456042, 0.02673173999937717, 0.04395046409626957, 0.03469794573902618, 0.0058924271252180915, 0.01095525096388883, 0.007034431446300005, 0.00941526948736282, 0.014795605438848725, 0.028412394640326966, 0.027840191360155586, 0.04489122162340209, 0.04139765791478567, 0.04873808844422456, 0.09679540482466109, 0.019756553738261573, 0.04314266603614669, 0.03997951760538854, 0.008814018547127489, 0.04096908618521411, 0.040434057082165964, 0.0484168127150042, 0.05446067785669584, 0.0983148482919205, 0.023218765418278053, 0.02715998147323262, 0.04084205276740249, 0.06155575436423533, 0.07184094894910231, 0.040002201349125244, 0.06634987250436097, 0.01851071785495151, 0.06383994390489534, 0.06767409402527846, 0.059602039473247714, 0.06176786759169772, 0.05013744499592576, 0.02966933861898724, 0.04059802718984429, 0.050710431241896003, 0.05560374112974387, 0.027894473896594718, 0.002102925072904327, 0.013648521580762463, 0.01658643283008132, 0.025010797871800605, 0.0475954296416603, 0.0176634208401083, 0.12847204139688984, 0.07334212816203944, 0.07911681634141132, 0.06110914473538287, 0.06788337967009284, 0.006230418803170323, 0.060967435347265564, 0.022738462284905836, 0.05445237322419416, 0.05406195530667901, 0.08960953025962226, 0.027790111234935466, 0.023886047092673834, 0.025570347534085158, 0.05173242054297589, 0.004053455686516827, 0.09297453914768994, 0.011175827457918786, 0.038566724470001645, 0.09291628797654994, 0.004194004541204777, 0.09274747906601988, 0.03148968215100467, 0.01251718238563626, 0.05898045368667226, 0.04169350395386573, 0.04024991540063638, 0.022354931497829966, 0.03269075168645941, 0.02573005585873034, 0.05217042125877924, 0.014677269064122811, 0.019831996760331094, 0.09576571203069761, 0.056807545479387045, 0.02988769887451781, 0.008185695915017277, 0.0026113945659744786, 0.019137268609483726, 0.09093901360756718, 0.026651443331502378, 0.036381225727382116, 0.046280941387522034, 0.018807628875947557, 0.04924142784147989, 0.0645416890620254, 0.03440062282606959, 0.08547244287910871, 0.028575210708368104, 0.027612190606305376, 0.018392721940472256, 0.03543576298397966, 0.02447087059408659, 0.04077275101735722, 0.054261685800156556, 0.02010900523600867, 0.04329849107307382, 0.033254049194511026, 0.03643158786871936, 0.06385085347574204, 0.014058109172765398, 0.05380556554882787, 0.06322719709714875, 0.04893904348136857, 0.016648799210088328, 0.0034551872522570193, 0.025954473894671537, 0.04706594438175671, 0.02445031681418186, 0.05327135651896242, 0.02419508480670629, 0.02348673267988488, 0.03856459450616967, 0.012194607897981768, 0.013609715606435202, 0.022377871282515116, 0.022132979247544426, 0.03892214270308614, 0.007118075200196472, 0.01830883884395007, 0.08854485262418166, 0.055846738832769915, 0.0486602185992524, 0.016380930283048656, 0.03457569546299055, 0.03192070667864755, 0.08443909129709937, 0.033076071049435996, 0.028174120707262773, 0.06793343010940589, 0.010706186203606194, 0.045575021649710834, 0.05188375187572092, 0.07792181015247479, 0.03918165690265596, 0.06170275897602551, 0.028400859810062684, 0.025198770890710875, 0.046124333384796046, 0.025574210412742104, 0.0779919653723482, 0.03063498963456368, 0.033407054070266895, 0.02289545434905449, 0.022111670332378708, 0.09002669889014214, 0.06328235351247713, 0.037311749038053676, 0.029938268817204516, 0.007839905192668084, 0.026335594557167497, 0.04342682696005795, 0.022105679345258977, 0.039997017447603866, 0.03257223070249893, 0.02740281961450819, 0.074544696835801, 0.04172995082626585, 0.06114186602644622, 0.016250071093963925, 0.011906092422577785, 0.029770869987260085, 0.033915428939508274, 0.05361649229598697, 0.050301656301598996, 0.05390139907831326, 0.046445126718026586, 0.0266382702102419, 0.021530143822019454, 0.017335024203930516, 0.020402274167281576, 0.028029058667016216, 0.03051384886930464, 0.02164061806979589, 0.019639530037238728, 0.052717035287059844, 0.06064569948648568, 0.04805757984286174, 0.01840984699811088, 0.06050810530723538, 0.06743365302099846, 0.01743808254104806, 0.006542332339449786, 0.0022031057324056746, 0.08305009512696415, 0.06909975229064003, 0.04913667740765959, 0.02369976617046632, 0.04529955498583149, 0.057515610023983754, 0.03345198740134947, 0.0405937969480874, 0.04572349942463916, 0.029569916805485263, 0.07255939242895693, 0.03520013109664433, 0.05437704152427614, 0.06495251975138672, 0.02614199234812986, 0.016384908194595482, 0.04621882733772509, 0.05275961972074583, 0.05754333295044489, 0.029807595165038947, 0.022820326739747543, 0.06376409641234204, 0.05799526748887729, 0.06389893722371198, 0.04240036250848789, 0.020346477649582084, 0.06135285861091688, 0.056977961139637046, 0.0771606263879221, 0.04621234467776958, 0.04060400518937968, 0.038946592758293264, 0.060586843464989215, 0.019963440390711185, 0.021920457838859875, 0.0442320868751267, 0.026600673008942977, 0.02337167752557434, 0.0647224168642424, 0.07605593957123347, 0.018925461517937947, 0.03811976974247955, 0.06323920504655689, 0.010263636122544995, 0.045350948712439276, 0.0447048238129355, 0.025349317402287852, 0.019696000053954776, 0.03540418831107672, 0.01372593964333646, 0.07487662238418125, 0.05887607803742867, 0.08677009551320225, 0.03296997361758258, 0.051604073523776606, 0.0353071005520178, 0.021947485001874156, 0.008315332415804733, 0.0887192202208098, 0.038791936603956856, 0.014896384454914369, 0.012665294652833836, 0.02886937578296056, 0.0700352071726229, 0.057765621022554114, 0.06011210643919185, 0.039982671733014286, 0.05167884119146038, 0.0278220625477843, 0.04357018020527903, 0.026632359003997408, 0.05209796167036984, 0.030496297076751944, 0.02631704272062052, 0.08286633194074966, 0.06586840419913642, 0.046161685677361675, 0.043689936865121126, 0.007774682007948286, 0.026712694634625223, 0.009353996847494273, 0.02906020421505673, 0.019974110618932173, 0.053483273077290505, 0.031544942467007786, 0.01778057441697456, 0.024526856359443627, 0.06879631779156625, 0.012558038542920258, 0.008504250745318132, 0.0382813649775926, 0.041760620079003274, 0.030872517709212843, 0.04877195635344833, 0.0506269062316278, 0.02452239605190698, 0.034300336410524324, 0.051944478109362535, 0.01069071242454811, 0.03054282602533931, 0.03516815937473439, 0.014054342773306416, 0.0653547489491757, 0.04862003130256198, 0.016433652453997638, 0.01333945881924592, 0.0036817169302594266, 0.03146941038721707, 0.06738076757756062, 0.010365118323534261, 0.037251854009809904, 0.042133582683163695, 0.039350803490378894, 0.024478527702740394, 0.0722940820560325, 0.06691439455607906, 0.027759319527831394, 0.02581655131507432, 0.06135583091236185, 0.04495571796724107, 0.01862390650785528, 0.1083525143621955, 0.041237877230742015, 0.05511151539394632, 0.05196425634494517, 0.05936182482400909, 0.048926619929261506, 0.026613992704369593, 0.0768209231318906, 0.054508653993252665, 0.0607150346331764, 0.07130169702577405, 0.04721718294604216, 0.06285142546403222, 0.05204594453971367, 0.01895003402751172, 0.054766435277997516, 0.028369483661663253, 0.029682816020795144, 0.004919445082123275, 0.08138183620758355, 0.16875333851203322, 0.0979071791516617, 0.105305990728084, 0.08790209336439148, 0.137710488634184, 0.1921449723886326, 0.0979303712665569, 0.15476088621653616, 0.20094387524295598, 0.10154871226404794, 0.13267721340525895, 0.1124968525255099, 0.138739402173087, 0.08395048353122547, 0.12265334386029281, 0.08764771482674405, 0.19908152986317873, 0.1123628429195378, 0.08484135018079542, 0.1251808539382182, 0.21266695868689567, 0.1581486567738466, 0.13714126136619598, 0.21729346277425066, 0.07868364700698294, 0.06496245710877702, 0.11799578089267015, 0.1359788651461713, 0.08696256409166381, 0.15442420350154862, 0.14057694497751072, 0.21310530079063028, 0.11398644681321457, 0.16536068462301046, 0.0661592221877072, 0.19182780815754086, 0.14619737776229158, 0.17876200145110488, 0.1505192302283831, 0.19849253178108484, 0.17461195617215708, 0.11528412913321517, 0.17446023150114343, 0.10252629144815728, 0.12325501040322706, 0.16129537776578218, 0.17870230309199542, 0.17908937763422728, 0.14535535185132176, 0.19505352334817871, 0.11369692016160116, 0.12674120458541438, 0.1490722203743644, 0.14467998262261972, 0.15721404051873833, 0.16422162152593955, 0.15252381563186646, 0.1663616340374574, 0.11737345295841806, 0.21558931359322742, 0.09391176034114324, 0.13868307316442952, 0.09395869376021437, 0.12044342103763483, 0.10378710387158208, 0.16115732345497236, 0.12156741853686981, 0.367731234873645, 0.14481022953987122, 0.15333217772422358, 0.17350894660921767, 0.1900735343224369, 0.11245460947975516, 0.15357466705609113, 0.11640333235845901, 0.09379961440572515, 0.11744737086701207, 0.14722122985403985, 0.08475087495753542, 0.11185513969394378, 0.07972572624566965, 0.09631372871808708, 0.1328306004870683, 0.18444798071868718, 0.1320777807268314, 0.2054364513605833, 0.20734016405185685, 0.19153552071657032, 0.1827796030556783, 0.20888273284072056, 0.14357878390001133, 0.08665973815368488, 0.1273622189182788, 0.15049215668113902, 0.16070347046479583, 0.10916040890151635, 0.11611072579398751, 0.23922339227283373, 0.12363889371044934, 0.15703824057709426, 0.21761672745924443, 0.19307053444208577, 0.12129773691412993, 0.11554829659871757, 0.2092211224953644, 0.14122500317171216, 0.147071672254242, 0.18351406208239496, 0.17215084604686126, 0.16357577493181452, 0.13605373300379142, 0.10881792259169742, 0.144587496179156, 0.09981294759199955, 0.21964323590509593, 0.08521467272657901, 0.13271668081870303, 0.07855963413021527, 0.11101390788098797, 0.16723625507438555, 0.0797026528744027, 0.08788773280684836, 0.1568755172775127, 0.11388190789148211, 0.12356926541542634, 0.13271911506308243, 0.1191817551443819, 0.07836404111003503, 0.09924159778165631, 0.1647818836499937, 0.1298872279585339, 0.12142574996687472, 0.08573102197260596, 0.12669197050854564, 0.12214503949508071, 0.11266891204286367, 0.12293394989683293, 0.06590703298570588, 0.07979424874065444, 0.1324929084512405, 0.09579051460605115, 0.09486488575930707, 0.15630014502676204, 0.17384675738867372, 0.09015100862598047, 0.1265349320601672, 0.07280266843736172, 0.2044526455574669, 0.1426185338641517, 0.23175426962552592, 0.1265113614499569, 0.0862675353710074, 0.10250695107970387, 0.13418650429230183, 0.13309192552696913, 0.053197676097624935, 0.25217676360625774, 0.16049117170041427, 0.14266203856095672, 0.1820857246639207, 0.16317272937158123, 0.1527680564322509, 0.15889099740888923, 0.15762314200401306, 0.13052099238848314, 0.16661301429849118, 0.15882312058238313, 0.16197490302147344, 0.1315688158501871, 0.11698081230861135, 0.08287059928989038, 0.2502263995120302, 0.13358447409700602, 0.11395811903639697, 0.1950027752900496], [0.08130458605592139, 0.02254452610941371, 0.018437132057442795, 0.019964839339081664, 0.06357694903272204, 0.016599941773165483, 0.06046115704521071, 0.053518309869104996, 0.04491856605454814, 0.04105118256120477, 0.06814161737565883, 0.06595303872018121, 0.06271769787417725, 0.04991567642719019, 0.02572077344666468, 0.0511628964159172, 0.02100300003803568, 0.06270118508837186, 0.0053940731049806345, 0.007309388811336248, 0.04717419775261078, 0.02898973358242074, 0.0170154424267821, 0.031090352895262185, 0.056930786522571, 0.025558020461176056, 0.023046249480103143, 0.022104916788521223, 0.04766764061059803, 0.04239139365381561, 0.03308640174509492, 0.05152088990143966, 0.032547509763389826, 0.0357100793189602, 0.016360213230655063, 0.02363982846873114, 0.030859858525218442, 0.03346569115819875, 0.0223735371400835, 0.07612337853061035, 0.03896724672813434, 0.0672052422305569, 0.083070756518282, 0.03470878851658199, 0.01245687732080114, 0.044991548857069574, 0.009299874800490215, 0.02613937442220049, 0.04813952407857869, 0.017941377409442794, 0.08215657158871181, 0.12401885847793892, 0.017819255153881386, 0.019436656548350584, 0.011934281046706019, 0.04160076889093034, 0.03088443845626898, 0.02661641210579546, 0.030219548352761194, 0.02465358735207701, 0.022765713947592303, 0.06546242715558037, 0.017759864786057733, 0.0880314274400007, 0.01801777965738438, 0.053215866137179546, 0.05792831834696699, 0.1146125968080014, 0.05912960310524795, 0.08361532964045182, 0.023498887203459162, 0.018051337719953153, 0.02911629944719607, 0.02152732922695577, 0.00841022156237159, 0.029328217860893346, 0.04260316178260837, 0.04163781319221016, 0.053660609264625236, 0.014972753306210507, 0.05185389156395104, 0.03705358183651697, 0.012931668152305065, 0.09743743677972816, 0.02533810355089372, 0.014937631167413201, 0.047783760746824555, 0.051645785933942534, 0.017839304273365997, 0.029061918576189782, 0.014066043659113348, 0.03943900032027159, 0.020185327703075018, 0.024712153935979586, 0.05081423914816696, 0.05567086467635818, 0.009226000493072206, 0.07062586024403572, 0.04545860465441365, 0.041749855226953514, 0.06254143037949689, 0.08780729884165339, 0.044765683633158915, 0.03149349307932425, 0.030021892162039876, 0.024618901225039735, 0.023288564407266676, 0.030858945683576167, 0.014213400791049935, 0.027952402233495377, 0.02844851496774936, 0.04432494068169035, 0.010082322951348033, 0.012245787329447921, 0.023053995646478143, 0.03368395678990055, 0.01885113728349097, 0.01759759419655893, 0.030670868763991166, 0.008043744401220465, 0.023587312243762426, 0.01642390991037246, 0.08206476792111062, 0.0466621269879397, 0.013348443444556324, 0.03241244259697851, 0.05965615317109041, 0.0037405309740279336, 0.10431422910187393, 0.03242740058340132, 0.04967085304087959, 0.025770558568183333, 0.03520616104651708, 0.007738498597973376, 0.05545286250708159, 0.03688066884933505, 0.040127724496414885, 0.08428347777226008, 0.01972593458049232, 0.02578810108389007, 0.049501669345772825, 0.03372090832272079, 0.06807196681620553, 0.00341862070854404, 0.02745200359640876, 0.0021105629321027664, 0.03156085411319509, 0.008918089915823657, 0.04849125012697186, 0.04227327342960052, 0.025470766158832703, 0.004936392952004098, 0.09161810841760598, 0.035215541793149896, 0.01064942767698085, 0.03907102865923662, 0.030916805371816736, 0.019629715134215076, 0.04749275351059623, 0.012031749156449223, 0.044462471778388135, 0.03978088920121081, 0.05222315085120499, 0.02269258642627392, 0.05727323943574447, 0.06137601361842826, 0.0681934786553029, 0.016984114517981652, 0.01695478113106219, 0.025258131572627462, 0.06843940413091332, 0.06582514441106468, 0.08080383675405756, 0.038568461095565, 0.032963357371045277, 0.017643457067606505, 0.03784649241424631, 0.04796031767909881, 0.030015812117198948, 0.03459099112660624, 0.022248941677389666, 0.03540563920978457, 0.04649315851565916, 0.02821083846356487, 0.017955251860257704, 0.06304989059572108, 0.047186665833578445, 0.03130364799289964, 0.033397691877326, 0.024642713033244945, 0.026651046282495372, 0.052656375846709125, 0.027444404004199896, 0.02925048345787218, 0.01941154227097286, 0.012561364292196231, 0.04564301350910682, 0.02922161391325062, 0.024148741395038087, 0.009732313119457103, 0.043586173487710766, 0.018309198785573244, 0.05477496626554057, 0.05011420835216995, 0.04622172913514078, 0.08053927595028654, 0.03311911190394312, 0.06550599122419953, 0.03154535806970671, 0.014168690104270354, 0.019025929759663995, 0.033434034849051386, 0.035624031006591395, 0.04455810121726245, 0.04474885172385257, 0.053984879559720866, 0.03263748403696809, 0.0711672569741495, 0.047467260737903416, 0.05520902246644255, 0.04203019409033004, 0.0511109312355984, 0.01655154632317135, 0.07352586166234687, 0.05164426453120541, 0.0389785867446335, 0.06900563312228769, 0.05335807647497859, 0.07380336552159861, 0.04915560959489085, 0.041236923570977524, 0.037636546257999726, 0.04674882839026395, 0.021459406016219873, 0.01277635612495942, 0.003259283689658332, 0.014711324365634937, 0.02289056730660377, 0.02034332908806391, 0.030370165368367452, 0.0849896609724965, 0.06576175015652552, 0.010913093265116913, 0.05480686748342123, 0.03200157108949497, 0.03313926492410246, 0.026597676587698516, 0.05789137052488513, 0.047850754417595454, 0.025776942893571686, 0.04084760403202381, 0.03004088743182365, 0.027015899067919236, 0.017129701627709437, 0.012242622069607023, 0.020452638163988013, 0.02276540039019892, 0.04686137879616581, 0.08741150406422094, 0.033518528362037614, 0.05075747598311864, 0.03612886583141517, 0.054893001142772846, 0.012954714620718732, 0.1318575706682168, 0.024633374960103538, 0.01927268644067226, 0.006690138934573042, 0.029651968652615324, 0.02912589170591673, 0.054542473662877455, 0.09392117819515988, 0.023748582789266948, 0.03886594728101045, 0.04543282986560371, 0.044349732124828734, 0.02432394576317165, 0.08934637953643687, 0.028078795548935886, 0.0235756326947012, 0.019407323161431123, 0.01100111940104398, 0.09612100780941546, 0.030054112503421493, 0.059843100170837715, 0.035008723789360374, 0.05847159642144106, 0.025332715558761265, 0.040247933866339736, 0.0015982829745553317, 0.04012411765870638, 0.028981740651943255, 0.07052953689708374, 0.040562114663771354, 0.04405827588925604, 0.015426934696733952, 0.05042093056545127, 0.07713878498179838, 0.0929808102955576, 0.018296803064004052, 0.02799684018100379, 0.04203268028504681, 0.010584150222712196, 0.022716014173056465, 0.0329166317533236, 0.05960529750154819, 0.05977118606097065, 0.07223517779493704, 0.028423467483662535, 0.03731843578862026, 0.06947049216250889, 0.011569893031264655, 0.005277876434774953, 0.06596247141715139, 0.038322724867612123, 0.01545153689221479, 0.028763346999767236, 0.08882850146619603, 0.03960805413953494, 0.026713509141700342, 0.039442737033823505, 0.004169513667875435, 0.06095447373809293, 0.035523343831300735, 0.061227866099216044, 0.013529588704841444, 0.009024283826875035, 0.031714909127913415, 0.09332151545095257, 0.05083377989649307, 0.059935386234428734, 0.029449024659697898, 0.021556575411523227, 0.06135076575446874, 0.010653982608346269, 0.023304526148422156, 0.03155232683639042, 0.04364123713457957, 0.05196972226258367, 0.016918119035835844, 0.021465241152327508, 0.02007728769967798, 0.08609169090050273, 0.01613127922610147, 0.031104229201446287, 0.08356081147212535, 0.025205633901350666, 0.06688091627438553, 0.0405943943769671, 0.04191970685496926, 0.017204784708155785, 0.016897830573725514, 0.26934376743156463, 0.09843336185440421, 0.1660955889383331, 0.10128183595952578, 0.1595086869201623, 0.13451583974529058, 0.10229011037154123, 0.2246945898514241, 0.0930231498205103, 0.12381867156364024, 0.1549075049115345, 0.16816708637634292, 0.13329370063729584, 0.15910930756945163, 0.0854593885014765, 0.15783400100190192, 0.129320761479903, 0.10272621861076914, 0.17235023144166917, 0.12128667149227113, 0.10372450371505693, 0.07737756357528269, 0.08151318150339648, 0.0964465583092533, 0.2653953933622688, 0.11593588322284631, 0.10660319807357155, 0.13695277069928125, 0.13250945834442973, 0.176464460673742, 0.07895320988609456, 0.13003371306695044, 0.12150225054938346, 0.12339844528469257, 0.13149943988537416, 0.0961927512253169, 0.13155873748473823, 0.08812036641757004, 0.1292521573486738, 0.21297711704391986, 0.13619738310808316, 0.15368664229754359, 0.2581390889827162, 0.10499270050786436, 0.134398179652635, 0.19057102559600025, 0.14672406512545422, 0.18251666013384238, 0.14361039939103648, 0.1423548042657785, 0.16392654360970482, 0.2660976134939119, 0.132742804416921, 0.10359893974964507, 0.06758269853889942, 0.175229808955919, 0.21823944873176515, 0.2193331517628394, 0.09286559929023497, 0.12314041538047604, 0.1907486660638824, 0.10704360334784724, 0.16481097583891824, 0.15979024290572852, 0.13100923650199547, 0.14972916949773207, 0.17846416274551302, 0.1387426527799107, 0.10760088945971802, 0.24209560768213123, 0.10890841265791096, 0.22447715542512015, 0.09339814962004311, 0.11403347671148367, 0.13969139952678233, 0.1342189806746319, 0.11704683376592584, 0.14086960349231958, 0.12231862041517161, 0.11424700744100846, 0.13853661774192005, 0.12834262568503618, 0.15997419162886217, 0.11753101833164692, 0.10004802286857739, 0.11855264398036525, 0.12603326991666108, 0.11308988789096475, 0.15332107519498095, 0.10263681950164028, 0.10549441460170783, 0.11260174025665037, 0.11121488889330067, 0.15237747895298526, 0.19234380859415978, 0.21672668459359556, 0.20721077802591026, 0.14433807518798858, 0.08130966976750642, 0.2520509250462055, 0.14401253953110427, 0.2397339601884596, 0.13567256595706567, 0.13318061217432842, 0.09916921611875296, 0.1066659318166785, 0.17446024634409696, 0.15389003528980538, 0.10350023410865106, 0.1954075277899392, 0.16263452387647703, 0.11683845354127698, 0.09539741382468492, 0.10297163200448267, 0.12512439134297892, 0.11101577067165636, 0.14390733267646283, 0.087958103249548, 0.1341617907746695, 0.11558248734218068, 0.23818339104764163, 0.128857230884023, 0.21877778781345114, 0.1181216565601062, 0.11475099250674248, 0.13231508986791596, 0.10535623412579298, 0.10314398095943034, 0.22743235778762028, 0.1466098931268789, 0.13487646414432675, 0.19412036170251667, 0.16062376380432397, 0.12332746628089808, 0.2176409660023637, 0.09650616761064157, 0.10520796044147573, 0.16982651373837143, 0.12530602456536144, 0.15697233786340803, 0.13121923460857943, 0.1797897572396323, 0.19503599382005632, 0.138072166882921, 0.09230470634065568, 0.08229990999097936, 0.15279959770850837, 0.17695653426926583, 0.11138754955027252, 0.15219712222460657, 0.0771927836467512, 0.1514502544887364, 0.24044205812970176, 0.11954658009926789, 0.15152397943893448, 0.13089620741084218, 0.2054581220727414, 0.14194644492818043, 0.16088476229924709, 0.09422325456398539, 0.10960846571833827, 0.10268954909406602, 0.29072744655422866, 0.11682945871143602, 0.06890082702739164, 0.2100177141255699, 0.2018255615257658, 0.09140021385974251, 0.08143320024828427, 0.22574870672542602, 0.15226489515043795, 0.1214597032230813, 0.199160969350487, 0.14763399754883721, 0.2191383231547661, 0.0932923193613533], [0.004900394151263754, 0.10146891654585488, 0.07870404864661396, 0.02482743358996231, 0.02607608592370525, 0.05252143855614122, 0.06520551047287881, 0.052150041883578524, 0.031220557139022276, 0.01599479826836614, 0.029623971131513827, 0.06922628846950829, 0.040467854487360455, 0.05257778611849062, 0.03255235969845671, 0.027277663830318488, 0.06804417338571511, 0.04367712368548382, 0.018834591101040132, 0.08163686041370966, 0.030328950197144877, 0.11540473555214703, 0.06667457695584744, 0.04160561511525884, 0.016884599936020095, 0.04771726802573539, 0.037859635849599726, 0.03368122568645049, 0.06085659559175838, 0.020832270820392296, 0.006569055221916642, 0.052225347608327866, 0.0045201584998721955, 0.061145495128585026, 0.03960396490583662, 0.06347742702928372, 0.011256693724135403, 0.0516978475934593, 0.04352345458755735, 0.06454485061112791, 0.024055529502220452, 0.0468239337351406, 0.03221395149012096, 0.056561653400422074, 0.07598003270686604, 0.040843477690941654, 0.048403186883660965, 0.04651856223063078, 0.08421798323979601, 0.03261593206843827, 0.015299144288292155, 0.004789146214534412, 0.02706399765884271, 0.031320268390118144, 0.046955037832958624, 0.07171902892878279, 0.07812034207745455, 0.0399646746518556, 0.04237888104398735, 0.011741343987523578, 0.053895781020401046, 0.022647769983450416, 0.02412405941868201, 0.06747137638740242, 0.0711051317921374, 0.0520126072660787, 0.028929296786373015, 0.057334132652613334, 0.04154175330768339, 0.06163506397570018, 0.02547122257965384, 0.03224970445444342, 0.007356958158197813, 0.024250371097878087, 0.016340570437023416, 0.040186984988395125, 0.0655045811436139, 0.010978728805639548, 0.015437398051290074, 0.050361054090899415, 0.06011031786329113, 0.028723321120196488, 0.009370575498905964, 0.08936891856137663, 0.04093364863365423, 0.02011821899941424, 0.03144163922115695, 0.011767863707063952, 0.023215908149722964, 0.01369634928778396, 0.03777228506805841, 0.08661392537760548, 0.0574401521589607, 0.04229477344779298, 0.05950809099886101, 0.015645243001927156, 0.06561844886164181, 0.06264616225962527, 0.044949146249564365, 0.04173884175543208, 0.05331202250090428, 0.023578185682708863, 0.06808701014961116, 0.05867634012247436, 0.048170033769565634, 0.017398494528606534, 0.04453189598280005, 0.031908353630569763, 0.009591226207703585, 0.05115805390232708, 0.010258313996018842, 0.023655213190068025, 0.04430385626619682, 0.015666551917092875, 0.028331248213362414, 0.03630809820606373, 0.05068834863777738, 0.018501385347917676, 0.00940053878366598, 0.08360885811271146, 0.0458303872437682, 0.04845927469432354, 0.09063030243851244, 0.07198237261036411, 0.060125758245703764, 0.052053358595003374, 0.03399949942831881, 0.027153791961609386, 0.02286418395669898, 0.04975807765731588, 0.012147438847023295, 0.01579057778144488, 0.02956872936920263, 0.08457944626570679, 0.037637370041920803, 0.0723261725215707, 0.03677695000078529, 0.02986111143400194, 0.02866977702069562, 0.02543547332606977, 0.039504454034613445, 0.011408631762606092, 0.023524604475824162, 0.015888220295892097, 0.014918503238732228, 0.04097718672710471, 0.010604409926600056, 0.01496434013461112, 0.0229600991224288, 0.01770364338881336, 0.05543358151044231, 0.08432265574811026, 0.038551747929886915, 0.010997088611475192, 0.014345581002999097, 0.016141706400958356, 0.0276007429783931, 0.018052886953228153, 0.022824746229161974, 0.005319626880009309, 0.012497611951403087, 0.026643192504707258, 0.14687577495351434, 0.004920072196910041, 0.06909064613864757, 0.043447325078886934, 0.16263513243757188, 0.07604647718835622, 0.03067498211748898, 0.0261349901848007, 0.008680251994519494, 0.03943926749343518, 0.024188396200770512, 0.042028190291603096, 0.04642683648853563, 0.019175765664840583, 0.021568683550867718, 0.08216526955948211, 0.039874307040008716, 0.030545792760676704, 0.060611219305428676, 0.024465278511343058, 0.015452136176463682, 0.04323565342929214, 0.03140819433610886, 0.0379771400912432, 0.06866440846351907, 0.04003918627859093, 0.026750267716124654, 0.07807704518199898, 0.054363693998311646, 0.07649244114873, 0.07097061010426842, 0.036445488294702955, 0.03245140163926408, 0.05575463088462129, 0.07188195260823704, 0.09295056035625748, 0.007613428624608787, 0.014198898297763662, 0.03931252722395584, 0.04440229844476562, 0.010208010298811132, 0.02280719443660928, 0.012597332479344914, 0.04360675324278418, 0.012526702284958446, 0.028156045700598042, 0.06671306473435834, 0.03448347248195205, 0.05615442954876926, 0.07239959319122136, 0.005509420016096556, 0.042562603412079625, 0.10290929902112111, 0.05814755990286358, 0.05486204616317991, 0.09125771408434957, 0.014893873212713515, 0.06358152808388695, 0.04915648532914929, 0.050778712538885884, 0.07861273479647934, 0.08381095234653912, 0.1344112859806046, 0.0634842473664321, 0.052476631390163675, 0.006486895763373468, 0.024617307462904137, 0.06901493965415284, 0.02881802287447499, 0.02116670297255041, 0.04161094744631555, 0.04983653379895259, 0.04308742056309711, 0.01716329308692366, 0.11264569024206139, 0.049540984618943185, 0.04806127573829144, 0.038805558724561706, 0.01553741079987958, 0.03657568697235547, 0.0356983274105005, 0.031781776633579284, 0.047566790162818506, 0.026470626471564174, 0.02842409274308011, 0.015592615454806946, 0.019917866957257502, 0.037188693531788886, 0.03977340835263021, 0.022507043941004667, 0.04615642756107263, 0.07628103296156041, 0.03507350957079325, 0.05027230436098762, 0.03211584327800665, 0.05263169572572224, 0.03662478375190403, 0.07805418703355826, 0.04832865670323372, 0.006059305060261977, 0.028353970919852145, 0.008858427736413432, 0.022299660049611703, 0.04150463850237429, 0.030107842139841523, 0.06626152724493295, 0.05232791983871721, 0.05403348281106446, 0.03306562161014881, 0.02111670077283634, 0.04387077598948963, 0.03344063996337354, 0.03630328537838068, 0.018203622712462675, 0.015197748361970298, 0.017812219593906775, 0.015472977538593113, 0.05046717378718313, 0.020000113618152682, 0.022578100870305207, 0.03347719073644839, 0.03644549571617972, 0.030497918669425417, 0.00578011467041506, 0.020389340388646815, 0.03758965736778919, 0.01001556491246447, 0.12111778094549663, 0.02827052383508999, 0.021356781835493166, 0.041517644640407525, 0.014043936935195234, 0.01289045298108249, 0.08874491337337531, 0.015429986779054161, 0.05328864855982829, 0.04396118441945873, 0.10566321609076113, 0.04356269564596005, 0.05975034655421041, 0.06362460975651629, 0.012993622640351532, 0.03992310324974824, 0.033030132108251564, 0.013050427551206667, 0.021314844925655052, 0.028962383585167117, 0.02003079585847445, 0.058938949077855796, 0.05185368376260158, 0.0346248182177078, 0.013915951712988317, 0.046729621608392335, 0.024127512260747608, 0.06459532407461666, 0.026665581244742498, 0.05892884473723825, 0.0256196484042448, 0.028619665354199242, 0.04781826319231186, 0.016188517365662847, 0.01845043876528507, 0.03921943964087404, 0.04962129612977151, 0.06606494716834277, 0.07437692693201825, 0.05566411113250069, 0.027441112579253968, 0.010356027942179935, 0.03366018208907917, 0.005169704700165312, 0.04229693309753202, 0.07415852029225789, 0.04337254256824963, 0.05379465226724278, 0.06891600394737907, 0.1035145649802871, 0.08842893657856621, 0.031071099729160778, 0.014289172213466372, 0.035367882446735166, 0.04662474129872862, 0.10596812004223466, 0.020306566802901216, 0.03306490914837923, 0.03132735218969174, 0.014880713079037378, 0.038102540784166194, 0.03800534541369416, 0.06678034042124636, 0.11289871807093732, 0.16759205551352352, 0.21547448850469664, 0.10087287548230961, 0.1462465079384856, 0.14820227486779913, 0.1761881887796335, 0.18313997512450442, 0.11857047778903507, 0.12181379672256298, 0.14165699249133468, 0.12906716961879283, 0.21920179162407294, 0.23035083868307993, 0.1496237696846947, 0.19864213390974328, 0.18115664483048022, 0.14255657937610522, 0.05883012054255232, 0.17012337280903012, 0.15019124548416585, 0.17989028856391087, 0.16746678098570555, 0.17045273794792593, 0.16213976370636374, 0.15295544872060418, 0.16310262610204518, 0.10132471725228243, 0.08148530643666163, 0.14975625788792968, 0.1526918972376734, 0.22630812280112877, 0.13877300661988556, 0.11593807255849242, 0.08871188038028777, 0.2432386190048419, 0.09810090938117355, 0.2076947028399445, 0.15360902849351987, 0.1746605520020239, 0.1401112918392755, 0.19835765386233106, 0.16318553884048015, 0.17678101634373888, 0.15177969384239987, 0.12936589890159667, 0.11419527232646942, 0.1441971116582863, 0.24991959566250443, 0.07751656783511862, 0.17317631602054462, 0.11752741891541518, 0.17000507446937263, 0.21125753119122237, 0.1179928494093474, 0.12481889367336407, 0.18679454777156934, 0.15333302377257496, 0.18222938961116597, 0.11874037023517303, 0.23005893715890124, 0.15826648013899103, 0.2293105999706313, 0.15268138842657208, 0.2230443205917254, 0.21923652413534, 0.08614252059487626, 0.17039599333656952, 0.14376767532667145, 0.0931670077261515, 0.16274219466140494, 0.08583511560573243, 0.1178666546184104, 0.1643555346527137, 0.16005548648536205, 0.1458422897849232, 0.16193145769648254, 0.12379729771055281, 0.22349361679516733, 0.15995039837434888, 0.07230033093946986, 0.15059295517858118, 0.13203893671743572, 0.23841001326218247, 0.13333128299564123, 0.06405910011380911, 0.201037178048864, 0.12417217876645736, 0.1181714769336395, 0.12610706908162683, 0.08714359617442824, 0.18844204139895737, 0.2504866855451837, 0.14487415814073756, 0.08215617082896642, 0.09025887979078107, 0.15560289728455245, 0.1233178554684855, 0.10118643287569284, 0.1176827133167535, 0.14075164654059336, 0.14481643389444798, 0.09687226163805462, 0.16924955329159275, 0.16164096625288948, 0.11082186974817887, 0.15440345305250958, 0.13317004399141297, 0.23319504543906078, 0.10637231593136676, 0.11598519151448272, 0.12613277707714587, 0.16380224871682003, 0.29784250538796186, 0.13565525907324627, 0.19882409367710352, 0.17256015533348545, 0.07491363328881562, 0.11898950178874657, 0.15826946357265115, 0.18779499252559617, 0.1296865809126757, 0.17335526266833767, 0.153938987350557, 0.14775171701330692, 0.1235843458562158, 0.0997453898889944, 0.10901759742409922, 0.10055462771560997, 0.19361734885023907, 0.13473287341184914, 0.12215562252094969, 0.12498350202804431, 0.12284912241739221, 0.14974006422562525, 0.13632158894324675, 0.20192886848235503, 0.1279394910670817, 0.1304983123554848, 0.2017316353158094, 0.11858820027555339, 0.21269017306622118, 0.10133602016139776, 0.14731325616594404, 0.10467604093719274, 0.21458386676386, 0.09762886635144241, 0.09677081747213379, 0.09778916282812133, 0.1545414628344588, 0.13741305068833753, 0.1589848197181709, 0.16232000169111416, 0.13459713460179046, 0.08668491180287674, 0.08915762911783531, 0.157148998696357, 0.2259200092521496, 0.15166623430559412, 0.2533501881407574, 0.1545665177400224, 0.12612746329978108, 0.2793920610565692, 0.1393294837907888, 0.17419397860066965, 0.13746580254519358, 0.22146801376948133, 0.1553333195624873, 0.19856587081449106, 0.08649922645417973, 0.07806788707966916, 0.14652450161520392, 0.16092378442408517, 0.09289161156630144, 0.12987213267479092, 0.1863316257367842], [0.03315122834465001, 0.011818678558483953, 0.06217159221705515, 0.012046340707456693, 0.0636813543678727, 0.047129138256423175, 0.015549255476798862, 0.03622664007707499, 0.003294124044259661, 0.03453740806435235, 0.0923078678897582, 0.04901236396108288, 0.0800684500427451, 0.020459560546441935, 0.058403752991580404, 0.04272458085324615, 0.04583627618558239, 0.033591036190046, 0.025743292062543333, 0.010083894449053332, 0.0947028749214951, 0.02850342461897526, 0.06452780347899534, 0.07140888541471213, 0.02803418319672346, 0.020148335352132563, 0.04038477847643662, 0.0344443984067766, 0.07070586376357824, 0.05782900785561651, 0.0015253138553816825, 0.03720195571077056, 0.04696239993791096, 0.022422030924644787, 0.037263067861204036, 0.03535231218847912, 0.09364170022308826, 0.08392619303776883, 0.02517418353818357, 0.06588110234588385, 0.017832829034887254, 0.059331270604161546, 0.05968149009277113, 0.012990095583518269, 0.04934271615638863, 0.033059465495171025, 0.027270956670690794, 0.005646800364047522, 0.04722104953543749, 0.03501848303130828, 0.07549742149421945, 0.02872194814699469, 0.025742069374246057, 0.01831302641221555, 0.01688437543634791, 0.030557219979527872, 0.010767462554213125, 0.08475986978737637, 0.017392067529726774, 0.048625497220200486, 0.07678478796151467, 0.029051090641587507, 0.0539290552114835, 0.0321307270496618, 0.03230218913813587, 0.037047852456453256, 0.09511748314253055, 0.1107201435661409, 0.04595688260451425, 0.030318690005515236, 0.02501460323401261, 0.11764271897845902, 0.009672680625953944, 0.021449099440360442, 0.03333365937578492, 0.06969268375542015, 0.1289120755973272, 0.08034663667785935, 0.07632433727849275, 0.034661573081393726, 0.019740469542739447, 0.03342448340845294, 0.03218751247914042, 0.0503608796861954, 0.10250380437355489, 0.055865938193164766, 0.03306355843960773, 0.06190733940456994, 0.031154446623986587, 0.04503893498622347, 0.01667776708927704, 0.07014163857093081, 0.018738943108473904, 0.10321595444111153, 0.0407114941481268, 0.03936891560442746, 0.042184512567473575, 0.019917477329727262, 0.032942606922006235, 0.028051696026523132, 0.06356265526846983, 0.049703114200383425, 0.03991057208622806, 0.028834587610617746, 0.027015808154828846, 0.05677521381585393, 0.08103998814476654, 0.04070001683430746, 0.026816908866749145, 0.05663709271175321, 0.039269727567443624, 0.009205008846038254, 0.021237177315924782, 0.03261969846789725, 0.037338369875214994, 0.05872367801202927, 0.035567742816056125, 0.035143976492690854, 0.02816157284541987, 0.016946879113675095, 0.02998584048327757, 0.03134373509965371, 0.071231593756238, 0.06946227658772841, 0.054853236870258115, 0.023525869837612845, 0.034360446661594324, 0.014687147049698979, 0.036660395708167925, 0.03523999926983379, 0.015196624008240178, 0.01571527391206473, 0.027293302737234626, 0.039953052619239315, 0.09706028475193307, 0.09200147964293137, 0.024378588241233956, 0.08466556508210488, 0.02577466264483519, 0.011790835960709956, 0.04875491664279252, 0.06907790346303955, 0.04188196122413501, 0.0069376270948851015, 0.030009737638465595, 0.04594781727064401, 0.0017212612510775216, 0.0600520295847673, 0.014314882064354606, 0.00894449274710496, 0.05909428058657795, 0.016721429492463358, 0.09010829060571268, 0.051357446718611754, 0.03273004469519947, 0.018265807266288903, 0.02524614774301881, 0.06004910552292131, 0.07373321772320196, 0.06325876063783653, 0.03378892615728546, 0.0050651166111492785, 0.060323165816953406, 0.022067694371799007, 0.05446570590720512, 0.04241065609676298, 0.053418023453559726, 0.0559079363301862, 0.020479277554841246, 0.010994779604516225, 0.08086311208899133, 0.007514060616813367, 0.04365914144727867, 0.01392659411067143, 0.03486941153823864, 0.028193171638122294, 0.011063665751862573, 0.01862389166490175, 0.03125905233900994, 0.07486721937311813, 0.026805695015355013, 0.010281584964104695, 0.0229297786790994, 0.049668203573673964, 0.023511282925028354, 0.043486217327881604, 0.013704957273148466, 0.015669121603423264, 0.05619635347102303, 0.012015523025183938, 0.04229945639963262, 0.0922532235563267, 0.012568518595799105, 0.013165070813556667, 0.018492273629817646, 0.025114260679401923, 0.03320769465062767, 0.06877679188619368, 0.08018052918487228, 0.05150506731297355, 0.03393722952750977, 0.06144700004369952, 0.03828594402875751, 0.03309023864858318, 0.051360092475079, 0.0340904199401848, 0.03435836493736133, 0.0631261091621127, 0.02864528800273547, 0.0196867436170578, 0.045390341911115684, 0.02449661940772785, 0.036723467128467746, 0.035161617342964746, 0.06379405691404827, 0.024471961551171262, 0.033525322724017315, 0.037960163463139907, 0.03413474471017253, 0.02863973488274496, 0.059660427941707894, 0.022644337550445925, 0.11922266232431866, 0.042805601115105674, 0.011331598689139355, 0.06647110974881798, 0.0474188170483103, 0.023662428720854223, 0.032269601433654316, 0.030788610492891166, 0.0746628615888767, 0.028861167629656848, 0.05037149239797145, 0.022747306829842273, 0.02233570430689724, 0.039484497683588415, 0.026551689406915102, 0.054661558679072186, 0.0321562457975233, 0.04803631360118743, 0.06242270901566371, 0.04799013346200809, 0.02645635868248064, 0.0711400349973701, 0.0470204878365621, 0.012181224192318041, 0.020747682683577295, 0.08660633320687339, 0.03188439710356761, 0.03803789601079188, 0.04134474278544076, 0.00882499583894969, 0.03758371647563763, 0.024399001013080124, 0.012582370782183716, 0.04451031803910155, 0.041795898068812676, 0.008717679429537384, 0.026515505996940192, 0.045668617603951134, 0.03718659696460236, 0.05763772671343759, 0.04701248006313108, 0.015543441677436931, 0.01777677647623932, 0.043251631868770346, 0.045300386191229336, 0.032891079608816653, 0.050490558860474266, 0.08070851530646905, 0.026343003046349622, 0.039488649999839254, 0.020514073148660827, 0.07871378562413156, 0.051271172051201575, 0.041127456788672134, 0.037422291934490204, 0.07559938516351394, 0.07857261429307982, 0.011041466259484878, 0.044883113660034724, 0.08137128286762163, 0.036212116247043014, 0.09804239845834672, 0.006977260563871823, 0.02498172423656797, 0.07060004834784195, 0.00451837595392135, 0.02696089108212618, 0.037147103575989604, 0.033855296424007975, 0.017334406365989707, 0.03821802638412919, 0.016154270961123984, 0.05378346068027895, 0.008639905136078596, 0.02246706444566371, 0.00438236857917218, 0.012207994386699283, 0.038955086638452485, 0.01820972316636471, 0.013816527116432553, 0.046280069364001974, 0.05747348943259567, 0.013853664186171954, 0.06778448849217966, 0.04070052891620435, 0.01240100102222641, 0.01770307935657911, 0.0625040038721636, 0.04634561584680341, 0.04957245539117139, 0.04008608259027824, 0.01568717991176527, 0.05023480363888666, 0.027706936889444478, 0.05770001887867693, 0.04050449060741812, 0.03713014921231661, 0.016206425389100332, 0.025576184525561985, 0.0631955593416933, 0.03541990328812972, 0.09582172191585414, 0.020054641063325107, 0.03411861413042061, 0.08019164655706845, 0.025809656763158273, 0.06791703606722876, 0.03538370874593966, 0.018904755597759504, 0.021692759510187898, 0.02238547458546236, 0.010320451237930683, 0.06297814717981964, 0.02138328578439541, 0.04726681778265629, 0.07396110901026987, 0.014765564228582662, 0.0421594984800322, 0.025424977502552792, 0.03587462459108792, 0.06194194946147036, 0.0033576885289221536, 0.051829823714797385, 0.0036174318665871397, 0.019003572560905013, 0.02608519764180528, 0.07585694751469418, 0.02950737045466667, 0.046277315996121615, 0.06622333632549271, 0.0960585635039024, 0.09194158090394922, 0.13705408870009705, 0.1949463423807174, 0.10816100315423682, 0.16246136598056182, 0.14964285772293806, 0.12483956990763545, 0.08924278314225376, 0.19018531660549343, 0.22759129613405094, 0.1235867801005952, 0.16819482785649598, 0.08701323793502524, 0.14349748904351145, 0.21478248032508418, 0.1467284734826535, 0.18125968461390585, 0.11110481354990043, 0.1296512398403138, 0.15278043545549735, 0.10817978691193275, 0.17470131075242534, 0.11258625905611552, 0.18096402782248333, 0.09538378799334168, 0.12274286171304993, 0.08947514957981184, 0.13039936922723427, 0.101189097185852, 0.1999370034900494, 0.2534431644016877, 0.15882196283200756, 0.10930008109426126, 0.14825839607510716, 0.1537815184565261, 0.14726540248375386, 0.1476986682973802, 0.07918658564449288, 0.12368339288514107, 0.14673905650852248, 0.1144784758798778, 0.19672725931741297, 0.09935389956808649, 0.19240410067141056, 0.13024516578298062, 0.23255581880221143, 0.09024112019687891, 0.21062513231299818, 0.17989825922995806, 0.16626459080725908, 0.08184030535630882, 0.1460677245631814, 0.10438488898216747, 0.1060681689705234, 0.12698194244876504, 0.22800232720328495, 0.1774867542553693, 0.07398594869300723, 0.07582548787468113, 0.11617956741247326, 0.1254263415466994, 0.14802481251535937, 0.18383475893642753, 0.1038789446465671, 0.1130159328749869, 0.19888457871275023, 0.21723861806094646, 0.16445263725472614, 0.10463263271958567, 0.09032021087477915, 0.16157023957930505, 0.0794808026694227, 0.16087127005448565, 0.09100443392526358, 0.145695507817436, 0.13444638956570998, 0.16232408350333571, 0.15998302318621427, 0.1866794703528285, 0.10930551361525431, 0.1738254725933075, 0.10002670096582733, 0.1109384982555639, 0.11950297892326489, 0.23116582073271275, 0.17753226275090128, 0.10526634519919753, 0.06589751865249127, 0.11042932557757013, 0.12340103538008407, 0.12474461953388527, 0.1687786160618998, 0.19605536333983764, 0.22058626811485738, 0.08649392751976848, 0.13736353459535167, 0.15190228179562837, 0.13601858488982543, 0.17809587938245386, 0.2128612677915953, 0.15411552943987772, 0.16192136448808014, 0.11991784689598717, 0.1176803903945256, 0.20885307661956176, 0.26665309618692845, 0.163438759627752, 0.15092460613232106, 0.20065699063707143, 0.13717191206524149, 0.0865340702875983, 0.12057058804202825, 0.12868229183368385, 0.19258779706433415, 0.19634201045846567, 0.10212398803560063, 0.09988460195017979, 0.15872299001784995, 0.10251273983158171, 0.159184962103609, 0.11558250960661098, 0.16220781864831224, 0.13531646865885705, 0.14325433177873492, 0.11540178922587074, 0.17381554265739396, 0.14626054937252775, 0.10663651308277622, 0.1370396465063095, 0.08397713405429386, 0.1476144790649414, 0.09185913571855053, 0.12672346725594252, 0.2936407324159518, 0.15842985652852803, 0.1827673873049207, 0.2871155325556174, 0.1536835846491158, 0.09554818854667246, 0.15241515036905184, 0.1431063178461045, 0.1635950559284538, 0.10559959919191897, 0.20899657829431817, 0.26304486324079335, 0.16657590691465884, 0.23879466840298846, 0.10568560668616556, 0.09428543911781162, 0.17176993133034557, 0.10192449131864123, 0.17256453400477767, 0.14867153484374285, 0.10693261516280472, 0.16173150826944038, 0.1610903668915853, 0.12222761826706119, 0.19762001844355837, 0.11406076548155397, 0.13635133422212675, 0.26434451225213706, 0.13668592408066615, 0.15480464324355125, 0.2176105824764818, 0.19794668216491118, 0.14827399601927027, 0.14667144685517997, 0.10653250108589418, 0.13614434923510998, 0.17487562639871612, 0.08793977220193483, 0.13242780725704506, 0.13145283301128075, 0.10571296224952675, 0.23876758001279086], [0.08776179776759818, 0.03725970964296721, 0.04934089047310408, 0.09014361683512107, 0.04407285166962538, 0.05388401055824943, 0.020281606521166395, 0.01566398594150087, 0.0657561988919042, 0.03986109310062602, 0.06756347691407427, 0.02083969044178957, 0.03453267316217534, 0.051585345427156426, 0.0501255966082681, 0.05221765153692104, 0.006650978584730183, 0.05070595980214421, 0.04595845595758874, 0.030821853142697364, 0.04343143569712993, 0.019180370691174176, 0.03749069197510835, 0.036624464628403075, 0.017261935645365156, 0.05219135353399906, 0.015786531221237965, 0.050399048341205344, 0.060476296857814305, 0.03886222169967368, 0.024338595758308657, 0.04199506824079435, 0.014581009727407945, 0.013985510431666626, 0.012983926480956143, 0.04284233000362292, 0.019610846029536333, 0.02797624187223846, 0.030746640186407603, 0.03089017340244027, 0.02276484006870305, 0.046909284428693354, 0.06632324424572289, 0.04033170007460285, 0.028835953162342776, 0.02339485665288521, 0.07952024039695971, 0.032197646505665034, 0.045497767787310295, 0.018372685808571987, 0.0167917331418721, 0.04355268778454047, 0.01243488934051129, 0.0352477213164093, 0.02088764802465448, 0.027644550100376364, 0.02741777203482343, 0.001787020405572548, 0.025333474404760636, 0.02172472381062107, 0.04815499414689839, 0.10409361828351393, 0.02790079885016894, 0.08642932356451638, 0.09179707732982934, 0.07424535157042556, 0.034487884549889714, 0.04308973977458663, 0.05500696162926033, 0.10430124893900938, 0.069192580122035, 0.1271321382955648, 0.08840647176839411, 0.024064403733063955, 0.11658591552986763, 0.04350760231318418, 0.07098569054505788, 0.02496616325515788, 0.04174649700871669, 0.0318108762439806, 0.04519533147686161, 0.02482094721926842, 0.0334377938270336, 0.012024156985717127, 0.026295782045053784, 0.054856932765687816, 0.026416477521706838, 0.013986668182042195, 0.03893727880495135, 0.09873050294118002, 0.011912389545614133, 0.016409449162892997, 0.01591242729773512, 0.03023266210220754, 0.07693791529163718, 0.04817428627575282, 0.04442714554897975, 0.015109531123016495, 0.040995406452566385, 0.037645403790520504, 0.023763416465953924, 0.022030544314475264, 0.0348243371990975, 0.03661794115032535, 0.05553399780183099, 0.036003524510306306, 0.030896481657691766, 0.020969577417417895, 0.07985678952536546, 0.028685799989034422, 0.01093982264137594, 0.052727043148479424, 0.07395823689876124, 0.06076838762965053, 0.020812724505958613, 0.015090031192812603, 0.027701869876182172, 0.04595469326886814, 0.02608896218589507, 0.01063058454747079, 0.045273750511114486, 0.026080036004714202, 0.009514320227026474, 0.031200912490021437, 0.031858767033554614, 0.016715995116101112, 0.024021182907745242, 0.04579185122565832, 0.10624206901411526, 0.05332672444637865, 0.04802831695997156, 0.033547713319421746, 0.007527701754952432, 0.07180862099630758, 0.022054165019653738, 0.08100298466160893, 0.015269936138793128, 0.026985233525920194, 0.006614455642193207, 0.011433120780566242, 0.0383050023810938, 0.03022935583430808, 0.004842001044380595, 0.06674102143733762, 0.03123513663013, 0.01738631402986357, 0.02087059347104514, 0.08099777478491887, 0.09054727837792598, 0.0620388331299182, 0.06449120817705989, 0.04079946091223974, 0.006393293315340998, 0.027578276312851813, 0.02713836085604271, 0.05125297830090858, 0.0402772672532592, 0.04490155974053778, 0.055462002055719495, 0.04442744982952718, 0.015519025018875254, 0.020365138952911366, 0.04359200676844921, 0.06207117221492808, 0.014687309394503245, 0.0627444226120133, 0.026521806830714922, 0.05230844959442038, 0.053282399676390924, 0.013420623799902387, 0.05118684552144259, 0.02536383195547387, 0.017278014274779707, 0.04934348056849558, 0.05759514599048998, 0.03899772302247584, 0.04311971140850801, 0.03534265313646756, 0.020102105117985047, 0.046309391618706286, 0.0402423417835962, 0.03769152084714733, 0.04304568959923927, 0.04547549964627251, 0.01425104623194784, 0.023457529168808833, 0.0070114448135427665, 0.03666901575343218, 0.031302724019042216, 0.05301672936184332, 0.04046890091558453, 0.03182783802913036, 0.05089360070996918, 0.0704702764051035, 0.050306109187658876, 0.03916507361282129, 0.03325968580611516, 0.01870414380391594, 0.036277358449297026, 0.05338573260814883, 0.006109413479862269, 0.0318071358196903, 0.06707502499921247, 0.008504192301188596, 0.03232279486837797, 0.012206985065859044, 0.03139034939522389, 0.14377839193912223, 0.027934781792282593, 0.07404546151519753, 0.05683438153937459, 0.0455669730581576, 0.04248059238307178, 0.026089437160408124, 0.013273826989461668, 0.0516122853878187, 0.05178566221729852, 0.04140500517678447, 0.02612522352137603, 0.018247311090817675, 0.03038747967366362, 0.04272729711374268, 0.041920827497961, 0.027511360567586962, 0.028486995324783493, 0.013542320248234319, 0.01706332765024854, 0.05592697983956896, 0.02046958510618424, 0.025716784402902704, 0.038510503072757274, 0.009727665419632103, 0.04702274025476072, 0.05057927148300223, 0.047281627339543775, 0.0417819939320907, 0.013689921361219604, 0.045237852827995084, 0.028528232760436367, 0.018997255028807558, 0.019742566109925974, 0.06500051444163546, 0.023277639993466437, 0.023413384369632695, 0.0378562776313629, 0.0335717589041451, 0.04115518713661004, 0.03353678148414474, 0.05248293593467679, 0.04287595671485178, 0.04744389050756581, 0.014205371680873213, 0.03259079181589186, 0.04376506447442807, 0.027313054997648578, 0.02392345319094602, 0.04852446494624019, 0.03252981696277857, 0.035243105157860555, 0.04048076043545734, 0.028651629654632416, 0.02220423655671766, 0.006998959570410079, 0.019977084775746334, 0.015962858087732457, 0.02087188851874089, 0.10960687752231024, 0.07853206334402785, 0.029947250659461133, 0.04871573866694234, 0.06403961131582037, 0.028310514462646097, 0.050991590178455226, 0.07027052735793404, 0.04374591706437059, 0.04629847462638281, 0.06912394630489871, 0.06566226526047103, 0.02169184295780724, 0.08858921079081483, 0.036088270353502594, 0.03082080300373491, 0.015241712262650253, 0.03439451123995241, 0.062192116311052814, 0.015768376433697995, 0.04416305971972179, 0.03657064778963104, 0.01972850426682271, 0.004547418975562323, 0.016530330176465213, 0.02165219557355158, 0.00949217361267074, 0.047050897337612696, 0.0234072523744544, 0.023767333150317427, 0.07599730990477838, 0.044675115641439334, 0.011566697157832095, 0.013734158928855322, 0.014215553946996806, 0.033467531684436835, 0.01166436657513259, 0.04061386833200231, 0.015895818032731768, 0.017786120115488302, 0.0016065559498201765, 0.07742364352452569, 0.019081297687080223, 0.064856315148063, 0.05077167326817289, 0.13838235492585227, 0.024264254825538956, 0.0350220416294178, 0.03294182024546899, 0.03142681853205431, 0.044589141543838196, 0.03146837138046976, 0.024961769740912132, 0.0703788734972477, 0.09002620907267556, 0.06132610418717377, 0.007752357278150157, 0.036488373298197985, 0.08831289436784573, 0.028205867929500528, 0.11550137802259997, 0.048036629013950005, 0.012675468569796067, 0.04954361924319528, 0.031981054416974075, 0.03549195469531696, 0.08492421839036979, 0.056986933705047704, 0.06328377101453952, 0.01798104334739037, 0.009895744242385263, 0.03809780588198919, 0.019517136897775345, 0.012401882322592428, 0.02785746670269873, 0.03698935266584158, 0.02478006230376195, 0.08259912909124978, 0.03356238557898905, 0.03752382886887062, 0.03149345597194042, 0.022324946876324248, 0.05572929767367896, 0.004716357761935797, 0.04774540284415707, 0.020527624765236396, 0.12915596016682684, 0.1608403818681836, 0.13106826692819595, 0.19701604382134974, 0.06005914678098634, 0.16620797978248447, 0.13235816411906853, 0.1392452055006288, 0.19424243015237153, 0.09140768728684634, 0.14502246893243864, 0.19184780161594972, 0.15450042206794024, 0.17107406398281455, 0.10142046914552338, 0.12099929706891999, 0.08909404932637699, 0.1846751372795552, 0.19694135407917202, 0.18213337054476142, 0.14785836363444105, 0.17624490370508283, 0.09363330653286539, 0.11947684790357016, 0.10291374448570423, 0.16708589595509693, 0.11191541692824103, 0.2257559946156107, 0.1681856400682591, 0.13505561859346926, 0.11024591120076366, 0.2040760056115687, 0.1820141074131243, 0.13792159996228293, 0.14557520567905158, 0.16759097197791561, 0.10503922574571334, 0.11626132240053266, 0.07159667846281081, 0.06818861758802086, 0.0843074639851693, 0.1325865971739404, 0.16766355402069166, 0.1110500653157942, 0.15590655442792922, 0.0636790537100751, 0.15545831207418814, 0.12514960952103138, 0.11331355635775253, 0.13599942263681442, 0.13013069692533463, 0.1671389743569307, 0.1272551715373993, 0.14742768049472943, 0.10020650108344853, 0.07441784153343178, 0.2001221990212798, 0.11022742430213839, 0.07586877734865993, 0.17246109346160665, 0.1095376796729397, 0.13239779480500147, 0.12172204500529915, 0.1762979821069166, 0.14600105001591146, 0.1694678931380622, 0.0895027352089528, 0.12155105418059975, 0.18369400320807472, 0.1123245555208996, 0.22166297596413642, 0.20787986868526787, 0.17396483308402821, 0.1364003011258319, 0.22776942641939968, 0.20684920367784798, 0.13297742698341608, 0.11143978190375492, 0.17552193312440068, 0.10876562344492413, 0.08742146368604153, 0.11030027351807803, 0.11754074788768776, 0.107447873451747, 0.12683520501013845, 0.09285195119446144, 0.0944707088638097, 0.0953324387955945, 0.1332619070308283, 0.1819250942207873, 0.18427685630740598, 0.10720492398831993, 0.05503046544617973, 0.10636790015269071, 0.28208000119775534, 0.1464052384835668, 0.13823321292875335, 0.22422990150516853, 0.10723270257585682, 0.14286642603110522, 0.17987488157814369, 0.13699683942832053, 0.18132643337594345, 0.16092084551928565, 0.12459328077966347, 0.25173812464345247, 0.13662900135386735, 0.1336810868815519, 0.2913261519279331, 0.1577657976304181, 0.18659358902368695, 0.1734637052868493, 0.0992009206674993, 0.10427857632748783, 0.12250888481503353, 0.10704922882723622, 0.12144404390710406, 0.09121009046793915, 0.16746213514124975, 0.12615566491149366, 0.22907835227670148, 0.19511668011546135, 0.13286663917824626, 0.10226915212115273, 0.15227372670779005, 0.1550258180941455, 0.06318694300716743, 0.11283676358289085, 0.13083777070278302, 0.11626595340203494, 0.1265545396017842, 0.19163470133207738, 0.07703766736085527, 0.1607033665641211, 0.08914499034290202, 0.216281158500351, 0.12939828622620553, 0.12107674760045484, 0.130476983031258, 0.1320407772436738, 0.10439169447636232, 0.12056458406732418, 0.10357984428992495, 0.09902619683998637, 0.2321943928836845, 0.11625066515989602, 0.10515628469875082, 0.18617190071381629, 0.18973189406096935, 0.1368194809765555, 0.13542963133659214, 0.14018792600836605, 0.06728472624672577, 0.19480448827380314, 0.12781863973941654, 0.1287564027006738, 0.16050644509959966, 0.1223191547614988, 0.13855895638698712, 0.22248022898565978, 0.12473915732698515, 0.13894353731302544, 0.13409124221652746, 0.12309153753449209, 0.09313092450611293, 0.12325158910243772, 0.11354231595760211, 0.24588066473370418, 0.1250080522731878, 0.11442957576946355, 0.12724849220830947, 0.08996349759399891, 0.12939712847582996, 0.16189519636100158, 0.08243846154073253, 0.10443485036375932], [0.009813748984015547, 0.027041326902690344, 0.030303863750305027, 0.06379958591423929, 0.044562850962392986, 0.0018678429546525877, 0.028837695354013704, 0.05896651986404322, 0.0335525261471048, 0.051382946912781335, 0.05746742608607747, 0.02487064884917345, 0.08260799775598571, 0.04042972665047273, 0.020259401462681126, 0.06905240326886997, 0.03484434178972151, 0.047588201123289764, 0.09752434227266349, 0.05830779700772837, 0.0217657497341861, 0.03058940877963323, 0.020224169857101515, 0.05611061686067842, 0.014001789440953871, 0.022460437066911254, 0.04000114007794764, 0.02235142485005781, 0.04943873893353157, 0.04394551768200472, 0.05830235706525855, 0.03864036036247853, 0.04041926978970878, 0.03202773550583515, 0.06899321699165739, 0.04128588676394429, 0.021714365284424275, 0.025493995381111745, 0.08114515789202414, 0.024967131757875904, 0.01703735990304267, 0.06024485810485203, 0.0236784349908703, 0.06181662669405341, 0.019875926336681005, 0.01445142610464245, 0.02531703397835372, 0.008226930567616364, 0.028884806888527237, 0.038673126182402484, 0.025904698049998842, 0.052387696123332717, 0.017510039324406534, 0.027316734194755554, 0.05951166072918568, 0.07135843421565369, 0.016674893122399226, 0.024404257273999974, 0.01100957802918856, 0.024650800587551203, 0.04789392514794599, 0.018126359573216178, 0.00669478709824034, 0.061386934321490116, 0.06794733053538948, 0.05085325385152828, 0.05300093274854589, 0.08284677634947002, 0.048072456193040125, 0.057132550500682555, 0.08120098966173828, 0.021345955756260082, 0.031305418015108444, 0.029713581752730533, 0.04399256984470412, 0.028256586301722564, 0.05165658047189936, 0.018123888221452944, 0.03355412918608636, 0.03437604660575744, 0.034816815532394685, 0.005322198885551188, 0.040709913373575546, 0.03668053759611212, 0.044580202375072986, 0.01986698160180822, 0.033675908198347315, 0.019274701371614356, 0.02351817562157521, 0.06351391100906767, 0.03328316364786588, 0.04636470017430838, 0.026934819434245583, 0.03193398370058276, 0.02301295673532877, 0.035796420779661275, 0.00980060183792375, 0.02456635902490234, 0.03911006933776662, 0.006340238569464418, 0.04034092497022357, 0.08696115401107818, 0.015492862457904266, 0.014706775928061688, 0.0274801681007375, 0.06268142911721952, 0.042160964221693575, 0.09980110291508026, 0.008318470772792352, 0.01909458398586139, 0.052375220620888285, 0.0260953075485304, 0.09310431109042838, 0.10564417258137837, 0.04978630895493552, 0.050437699392205104, 0.05304325371980667, 0.0977382663404569, 0.038220408678171225, 0.051606607958092354, 0.04306601331336424, 0.07601693228934892, 0.031238390947692096, 0.03173066863382701, 0.008406306733377278, 0.009085148285521427, 0.04241356531565543, 0.041756935315788724, 0.012609749537659809, 0.0281452771378099, 0.02192103671404766, 0.007078694525262108, 0.029915004342910834, 0.007899844749772456, 0.09656296417233534, 0.037863123943679966, 0.04022165070637129, 0.05151353150722571, 0.03649111182312481, 0.07309300402994268, 0.03896427442668937, 0.03006182156241266, 0.036496796674327925, 0.01954006183950696, 0.05228989219176583, 0.01029917664709501, 0.053529464348684996, 0.02952421535155736, 0.03984590875916183, 0.03362458497576881, 0.022850292807561345, 0.0345633572578663, 0.010365789967181627, 0.020838547534367535, 0.04256982821971178, 0.01892176005640067, 0.00374340447706345, 0.039238008175743744, 0.01894480003102217, 0.06845768322818913, 0.034625000043888576, 0.03811445596511476, 0.021825932344654575, 0.039297591501963325, 0.00907515712242457, 0.0335474795429036, 0.03065859364141943, 0.019539735294529237, 0.037735006990260445, 0.055414526868844405, 0.06532351195346564, 0.023509206766902935, 0.022153779791551642, 0.018656857864698395, 0.05072574916994199, 0.04754659632453695, 0.025681832958071027, 0.05061022275185678, 0.013443606258078944, 0.022889986576046795, 0.007292516083907685, 0.013645863764395472, 0.0669090956216678, 0.10123196363565512, 0.02485970031557372, 0.004822906976187369, 0.020429421929293312, 0.04228451696690172, 0.020025320663989987, 0.04013562465843279, 0.0218597445928026, 0.032154486907529645, 0.0607380968722282, 0.08012281978153624, 0.0350896327290684, 0.05926154954067897, 0.02788457364658825, 0.023737057235848624, 0.04574544102069922, 0.032980270916596055, 0.013819182149745757, 0.06958097568713129, 0.025164650651277043, 0.04963536353898235, 0.01856698378105648, 0.0519495321350405, 0.03807444678386673, 0.03532067814376205, 0.07786636429955252, 0.05981378162687179, 0.026147732860408723, 0.016361686393793207, 0.03105510459135985, 0.027383957931306213, 0.02977380147058284, 0.007292128775588935, 0.059205576762906276, 0.06329550436930731, 0.004968405492036254, 0.03071530671149958, 0.019054743643209804, 0.05955068285402376, 0.006221281109901611, 0.013260931245895335, 0.019800557529379148, 0.019852595069096424, 0.03026345009857323, 0.0902093859622255, 0.02766193305433262, 0.03387858872883953, 0.03732255470822565, 0.013621431335195666, 0.05025375066907145, 0.004593121821017121, 0.0324176895810524, 0.030760184381506406, 0.04831784732232336, 0.025800159128266387, 0.05069469771115109, 0.0192742486615316, 0.04325559493736364, 0.07601188568514772, 0.03662659088149667, 0.04115120551432483, 0.037610266808769666, 0.052823429577983916, 0.01345278291410068, 0.01303889828704996, 0.05293825095577631, 0.005505957897184999, 0.05458779662149027, 0.10486496947123669, 0.005781647205367335, 0.026912911234830972, 0.035938857472501695, 0.014000839491927763, 0.021314857913239393, 0.03221672712243162, 0.06879426204250194, 0.03752997385163326, 0.03785661901929416, 0.03677697226521559, 0.044058216517441906, 0.03604218298278283, 0.010921058365056524, 0.04872920864727348, 0.04914517128781881, 0.012928580817970214, 0.03364388452610001, 0.028407852696545888, 0.04052227988722734, 0.036769565631402656, 0.012197501346236095, 0.020386256765050348, 0.025030401702679228, 0.057217782450607046, 0.0503065915836487, 0.04408688568219077, 0.06307214018306695, 0.06019884123816155, 0.04970194902853109, 0.043272861003060825, 0.032280629748129286, 0.009537067981000291, 0.058552171394694597, 0.03625380268204026, 0.06883488720632158, 0.03943099996831734, 0.06110753056418616, 0.0454170072771376, 0.028733442159136757, 0.06725456536514685, 0.038599167455686256, 0.11869021589518525, 0.05459676918690093, 0.037189921786193736, 0.0584540594718419, 0.05906789723667316, 0.018712789824348874, 0.06562967755598947, 0.06375773620675318, 0.03128613330773078, 0.03317338887427468, 0.019213362866139505, 0.03136243351036683, 0.09793995981453918, 0.009481412471359363, 0.026258878751832526, 0.06499828799860552, 0.02733091478148708, 0.017879040715342853, 0.010859237463591853, 0.02727825012698304, 0.048399698789580725, 0.018659028646652587, 0.0039079483576642815, 0.05304445599904284, 0.055582359855179675, 0.05010273845982738, 0.0074425268576305825, 0.04801498056622222, 0.0303224601157126, 0.0314737630833406, 0.03195078963472042, 0.020488561822276097, 0.014598703455703799, 0.014648321593995206, 0.046208748972276226, 0.016645123723719735, 0.027708883171726484, 0.06732618261594325, 0.03364617034094408, 0.019138884636049625, 0.028640772034123074, 0.05122090267832391, 0.014583027441403829, 0.025638599145167973, 0.08073624194366857, 0.019740489951800555, 0.030072512199694756, 0.05676263812347315, 0.09442922280868515, 0.05272925103781745, 0.013063667465758044, 0.05397343935328536, 0.05629275845421944, 0.03684042960230727, 0.07784029265167192, 0.015827269562578294, 0.015925435291137546, 0.04531837214017287, 0.02142059169273125, 0.10598717097309418, 0.1716572733130306, 0.17051754228305072, 0.22686562413582578, 0.09481885776040144, 0.23909121577162296, 0.25138257653452456, 0.16243518301052973, 0.11217858991585672, 0.0988326892547775, 0.16152821917785332, 0.12333871723967604, 0.1757458836073056, 0.116101367311785, 0.14206107705831528, 0.15220406872686, 0.09067376260645688, 0.2024119917768985, 0.14333095110487193, 0.16240043565630913, 0.09948814666131511, 0.1028267054061871, 0.08953415774158202, 0.14964423811761662, 0.06341853018966503, 0.11822917891549878, 0.1303558942163363, 0.07701494279899634, 0.1220698599354364, 0.1274932228261605, 0.13230806915089488, 0.15242709894664586, 0.1691385279991664, 0.081520061212359, 0.09444471143069677, 0.23045024194289, 0.0590442746761255, 0.12855298002250493, 0.156167404493317, 0.15565242822049186, 0.1737174901063554, 0.3175565303536132, 0.10250963023281656, 0.22012736852047965, 0.1333325743325986, 0.11705545752192847, 0.22524990927195176, 0.14274735585786402, 0.14783703431021422, 0.11629167624050751, 0.1956312556285411, 0.11443733121268451, 0.14616028522141278, 0.09482471330557019, 0.17485218937508762, 0.25227380683645606, 0.11953948516747914, 0.06918623475939967, 0.08365560599486344, 0.08882369977072813, 0.10249861676129512, 0.11351609588018619, 0.20032228203490376, 0.12426293600583449, 0.16426456219051033, 0.15817390463780612, 0.08446453954093158, 0.21300929656717926, 0.17253459576750174, 0.12082731918781064, 0.09436893815291114, 0.09466019400861114, 0.20376660424517468, 0.16448548471089453, 0.13228719995822757, 0.2764283091528341, 0.12281923613045365, 0.09939277326338924, 0.17527592601254582, 0.1172117018722929, 0.10515696005313657, 0.28815430181566626, 0.1256437908159569, 0.1272928132675588, 0.2692450617905706, 0.14795368508202955, 0.1442512884386815, 0.19065993488766253, 0.08395386772463098, 0.14904412266332656, 0.09074417757801712, 0.21526545519009233, 0.11335909453919157, 0.16903997078770772, 0.16113351535750553, 0.13165410346118733, 0.11065384751418605, 0.2294841586262919, 0.08557616543839686, 0.14651644189143553, 0.15531904064118862, 0.18659465771634132, 0.1375927246408537, 0.10048459866084158, 0.10165696934564039, 0.131031782948412, 0.15675043570809066, 0.1211548363789916, 0.14599447458749637, 0.12770979636115953, 0.13533000543247908, 0.11087326347478665, 0.15929530462017283, 0.256581885041669, 0.12733516021398827, 0.12692390650045127, 0.1516765946871601, 0.29899841523729265, 0.18193530617281795, 0.17600416584173217, 0.18804652121616527, 0.20757993712322786, 0.16645797964883968, 0.19661201862618327, 0.14993112272350118, 0.08585407005739398, 0.21547324169659987, 0.0869406113633886, 0.1360831072088331, 0.14438380632782355, 0.11580348407733254, 0.12120146551751532, 0.07486727874493226, 0.11796719336416572, 0.23603258770890534, 0.08132235307130031, 0.16934874875005335, 0.10353645091527142, 0.12754403025610372, 0.11820856205304153, 0.1404201440163888, 0.12631389079615474, 0.10868384619243443, 0.09783864181372337, 0.12301917071454227, 0.12214573711389676, 0.1403583528008312, 0.11333849251968786, 0.14856567489914596, 0.17312071431661025, 0.15836235077586025, 0.12629171542357653, 0.10797865747008473, 0.13303473562700674, 0.1496020396007225, 0.1536815956933424, 0.08704915046109818, 0.15090563683770597, 0.2644569327821955, 0.09489537318586372, 0.08635104182758369, 0.10403162668808363, 0.11245408255490474, 0.09134665306191891, 0.21643089421559125, 0.17394727386999875, 0.1656195308896713, 0.1274900761200115, 0.13220335211372003, 0.1695242221467197, 0.16656432941090316, 0.10110530871315859, 0.0928433051740285, 0.1404662462300621, 0.18011698499321938, 0.11337261646986008], [0.03682447342725936, 0.013471003567246953, 0.005660697079292731, 0.08846539829391986, 0.04839563924178947, 0.05198254657443613, 0.08383718726690859, 0.04785199009347707, 0.043941461844951846, 0.049203793532797135, 0.09211241587763652, 0.032492895115865394, 0.07388444515527226, 0.040165377358789556, 0.035020189970964566, 0.012909047491120873, 0.05166547511180397, 0.054533957518287934, 0.035100497771054506, 0.012914438266307116, 0.03366613782418426, 0.008434612245764583, 0.027561860006244387, 0.00843255927975406, 0.03848774140351452, 0.01506709882960422, 0.03051301395316841, 0.005233310466792318, 0.08532825842848979, 0.02785261305689346, 0.014483446993835969, 0.04725946309918072, 0.07366427962551825, 0.03546853251464199, 0.04434322348970454, 0.05744076814153232, 0.02768259815638885, 0.08349909447133541, 0.023182001277746167, 0.03925978278857656, 0.02426345701678656, 0.04956906006555073, 0.013969279661978362, 0.06076969380956143, 0.0658655766164884, 0.01864352703705663, 0.03712361831276212, 0.021417858733912, 0.045231058466015384, 0.048438728335895576, 0.01694754890195327, 0.024714376668271143, 0.031119497034524102, 0.029843361116945744, 0.05916840258578304, 0.04459103773115203, 0.051070335757685825, 0.04082800020114519, 0.042050784977618605, 0.04775076115038246, 0.042502300202613696, 0.06984787425608374, 0.024046710932452697, 0.04308999210479669, 0.0713975157123059, 0.021316052770998795, 0.031716493613203056, 0.058904383549815975, 0.010218898532912135, 0.10278742352966219, 0.0834335850959178, 0.015171152572293067, 0.057487816593493335, 0.04102071739907842, 0.011822871692857007, 0.12364634487312287, 0.12993049516808242, 0.041969100493588485, 0.03521651029586792, 0.019517203691066243, 0.06185676946188323, 0.0013569686711889517, 0.026342400051362347, 0.00914573165573529, 0.012553696979011875, 0.03862238925648853, 0.09271002287277952, 0.05169576957996469, 0.03506641834974289, 0.09943914265022613, 0.02423823327262653, 0.04561619600281119, 0.019287724207970314, 0.06854395047412254, 0.022072893116273917, 0.020957179840479512, 0.0892387681233231, 0.0898908858653158, 0.007054775105643785, 0.037742476706625894, 0.036033325450262055, 0.027498157760419417, 0.029965947214805055, 0.021956708042125683, 0.012330214049143251, 0.025945716552087106, 0.031421382300322875, 0.015409724292112514, 0.09063357530976646, 0.06081302781240083, 0.0379572876408929, 0.08588563359808177, 0.10473026966792531, 0.06842813090770505, 0.02481789513694821, 0.03280120552517474, 0.03335543398861773, 0.056021054479060695, 0.023101114602468442, 0.014297588168119546, 0.030982581920397934, 0.0160855258218362, 0.06087935726100113, 0.06073156597267371, 0.05807515968626831, 0.05530609909328632, 0.05767463742813561, 0.034425892954459414, 0.09418720845133066, 0.028157092128822114, 0.046749748653382994, 0.0635015097213909, 0.057781009454629384, 0.020221598315401934, 0.10222603334113955, 0.010574541265668813, 0.0532497154927114, 0.043678530055331066, 0.01879765812191181, 0.03242309612687677, 0.11696662986651063, 0.05295158363878727, 0.015785696305101737, 0.055101377656683326, 0.01618174897885183, 0.010674459390429547, 0.059947516638203524, 0.036070254718651995, 0.0724265183089301, 0.10298540626536123, 0.015467286193597829, 0.059873535647057, 0.03184216890076641, 0.011305456537229475, 0.04668793517339509, 0.02778724468953442, 0.09648739869589917, 0.03769565460970625, 0.08363446220755577, 0.047542035827063955, 0.031160825383267365, 0.04458416915440466, 0.027995157361146994, 0.055772661362425424, 0.043506414876901545, 0.024182613015000243, 0.022777890735596884, 0.06089191811042838, 0.09235756209818646, 0.0980893244559411, 0.01973416128748795, 0.03519496945955325, 0.05482209635374602, 0.024090683182294015, 0.029048044125374872, 0.04288224270567298, 0.012247351405676454, 0.0075926021054328885, 0.04713931310107, 0.0524496469006408, 0.016820745549921412, 0.09822138221352361, 0.06070482268114574, 0.0528396121080732, 0.032713676628191024, 0.005916720401728526, 0.03578323281544726, 0.015576637015328743, 0.018027191945293453, 0.01427100907676504, 0.07276524935150519, 0.017786262978916056, 0.06269288787734695, 0.09483230547630228, 0.05558072341955267, 0.040636043704580516, 0.02485965764208231, 0.05376944151066709, 0.03325995297927875, 0.05342666947399266, 0.06180030686664395, 0.020216768789396156, 0.03874250214721542, 0.04486617042857688, 0.03806167442235164, 0.03441149528953247, 0.03571407578419894, 0.03285389801021665, 0.006644072900598985, 0.035469315480440855, 0.05141148991242517, 0.043424444666015916, 0.020267962136131246, 0.009450792385905515, 0.03331438951136079, 0.02025512483669445, 0.03874878071655985, 0.06393384785042144, 0.031349163909908384, 0.06779590272344649, 0.08559969151974656, 0.013937350613559829, 0.08193963440135121, 0.044066064729122445, 0.02096056403388502, 0.04875571445154492, 0.052849605126539245, 0.04975754702172708, 0.01879143892438151, 0.02869667801860487, 0.019679542929225136, 0.04716675030067563, 0.045944210432935506, 0.03478542268567253, 0.008764367939875228, 0.02957578904897673, 0.029602947943203617, 0.016736205652705394, 0.040320816478924826, 0.02024883699050406, 0.06176465038151946, 0.03463995431957301, 0.028014262097713072, 0.057344485612702556, 0.018157355370931327, 0.04453531728358939, 0.006199498611749732, 0.0759965974430088, 0.007934755376481917, 0.025795153342187405, 0.038262503294390626, 0.07293015456525609, 0.07113817962817848, 0.0418160770641407, 0.010548282225499861, 0.05109955782245379, 0.031231563189066947, 0.021228898658591788, 0.0361581175820902, 0.0307814765983494, 0.026048030886158813, 0.030905239000276197, 0.0682168266212102, 0.05217761638050433, 0.04308936127927154, 0.04515213848208077, 0.020137822830292862, 0.010907044761552243, 0.05567697255173698, 0.031155118267633952, 0.06213359796674922, 0.044828695681644604, 0.07788288450683467, 0.10490730157471262, 0.02392762962699635, 0.007411664646497229, 0.08137040713336319, 0.0381785626814235, 0.014455512555286987, 0.01994240978092421, 0.0795094421482645, 0.035043059251620434, 0.04260165893356316, 0.024522251333110034, 0.04839126057049725, 0.06890275661135092, 0.030522992128680926, 0.023911775497253984, 0.025574162173143122, 0.03196248217136599, 0.042186464415863156, 0.028940768534084782, 0.05418397922767326, 0.050676270184339955, 0.07775562844472006, 0.024271446236525662, 0.054474526332342066, 0.015966043756634463, 0.026709230660344474, 0.08883967078872956, 0.01975975239474792, 0.04426347601111047, 0.04733547386422288, 0.037196864577708766, 0.037101810303283855, 0.046521371259586886, 0.004951082373736426, 0.03136906831059605, 0.04462876109755598, 0.08932756609283388, 0.03411107762076426, 0.029405803834379185, 0.01850504970207112, 0.0384600592951756, 0.06096003984566778, 0.040263908595079556, 0.03789629052334931, 0.0427835741720628, 0.02673107577720657, 0.013971776988910278, 0.05250682937912643, 0.06157305382657796, 0.04500525632465724, 0.020312439046392683, 0.019922653809771873, 0.0628632478765212, 0.01761476192768896, 0.012552304524433566, 0.04129276276216842, 0.022992876074567903, 0.02983737755130278, 0.06012011792336125, 0.035334556305315346, 0.014254358065954875, 0.02635674947669031, 0.05467555558425374, 0.055478744907304645, 0.04063681924890261, 0.03937239256629255, 0.038820119661977515, 0.044383162166923285, 0.024101067683659494, 0.05014096648665145, 0.018227323198516387, 0.04108497625566088, 0.024172623707272578, 0.15179177600657567, 0.03612314387282822, 0.01415466165781254, 0.015672678346163593, 0.05917141570535023, 0.039059551345417276, 0.11945381906116381, 0.08851486985804513, 0.11322849139105529, 0.11665389625704847, 0.10967205293127336, 0.13617930439068004, 0.24297472613397986, 0.21047235379228368, 0.18412058969261125, 0.10350856100558303, 0.1780498810694553, 0.11412292034947313, 0.17954897484742105, 0.16065564646851271, 0.1273370155831799, 0.054598784117843024, 0.21825999137945473, 0.17324407410342246, 0.0802121298329439, 0.13761405396508053, 0.09501342661678791, 0.11475292951217853, 0.12407589994836599, 0.15413659159094095, 0.12569433107273653, 0.1483832995290868, 0.15792221267474815, 0.18702537054196, 0.1615329837659374, 0.14210441848263144, 0.10278708214173093, 0.1635779271600768, 0.12146668683271855, 0.10935520782368258, 0.15412167442264035, 0.14262374374084175, 0.13349601009394974, 0.21338289370760322, 0.06996109630563296, 0.12484328064601868, 0.12265608238521963, 0.19967474334407598, 0.13535544625483453, 0.13275383273139596, 0.11740362868295051, 0.21260341600282118, 0.1731319652753882, 0.15852630604058504, 0.10057252089609392, 0.15833558893064037, 0.21314056764822453, 0.25363549939356744, 0.14181363017996773, 0.08746388484723866, 0.16564411082072183, 0.12137523197452538, 0.12071085395291448, 0.17216205247677863, 0.12299859838094562, 0.1378820583340712, 0.07097040230291896, 0.19483062671497464, 0.15913725685095415, 0.12659617408644408, 0.12829181825509295, 0.09210112781147473, 0.13561306055635214, 0.15959884301992133, 0.1630017237039283, 0.1668631477514282, 0.25086256850045174, 0.17735183180775493, 0.12347837458946742, 0.14462167950114235, 0.1204743463313207, 0.24161634355550632, 0.1955429548979737, 0.12169808105682023, 0.1261454084306024, 0.11154512976645492, 0.12913123180624098, 0.10976182311424054, 0.1489736483199522, 0.0799046506290324, 0.13224464521044865, 0.1420665392652154, 0.25257075496483594, 0.2591495675733313, 0.10182065743720159, 0.1794716133736074, 0.13897013588575646, 0.11846988709294237, 0.1561391435097903, 0.1669270169804804, 0.17217232380062342, 0.1566144297248684, 0.14848332619294524, 0.1649982642265968, 0.11467376461951062, 0.1132378053443972, 0.12879560294095427, 0.14221649762475863, 0.17414201342035085, 0.0945690656953957, 0.1899502784362994, 0.13810017553623766, 0.11102320699137636, 0.06547608267283067, 0.21761313546448946, 0.1390355042531155, 0.11631662724539638, 0.16996970371110365, 0.24172226287191734, 0.15215556195471436, 0.12720575934508815, 0.13706824887776747, 0.1670557796023786, 0.10442139522638172, 0.15249050804413855, 0.07272039394592866, 0.13056926167337224, 0.11804688518168405, 0.24317618954228237, 0.1811254004132934, 0.10313256672816351, 0.1219481328735128, 0.1324768186896108, 0.08214995163143612, 0.20018292154418305, 0.14047248027054593, 0.11995908804237843, 0.169808286591433, 0.09301478581619449, 0.1417680919985287, 0.19524933159118518, 0.1277361426036805, 0.11334101582178846, 0.12112901706132106, 0.14257553382776678, 0.11203239424503408, 0.15489154873648658, 0.22988712997175753, 0.08611533572548069, 0.0971123983617872, 0.22082552168285474, 0.0900520283903461, 0.16103951493278146, 0.13854573131538928, 0.24764359201071784, 0.2484657580498606, 0.10135006159543991, 0.10202880017459393, 0.09210745090967976, 0.17572068027220666, 0.1082288428733591, 0.21261206944473088, 0.2005329926032573, 0.1016503493883647, 0.17209644662216306, 0.13839906809153035, 0.09241583553375676, 0.14137652004137635, 0.1649128578719683, 0.13594720512628555, 0.16870548482984304, 0.1313504166319035, 0.08759477743296884, 0.11283664483926259, 0.13116881309542805, 0.20183987013297155, 0.16968096373602748, 0.0965470599476248, 0.1315511972643435, 0.1205264896270819, 0.1662523008417338, 0.10722364837420173], [0.023817355759092607, 0.05121369271364529, 0.03176047699525952, 0.012240592295711394, 0.026722398215497378, 0.04616414589690976, 0.0598318380798446, 0.02780259972496424, 0.04071486349857878, 0.09916977272951044, 0.034251369506819174, 0.0480511936621042, 0.028587916276592296, 0.015586737645207904, 0.03883856574248057, 0.03786872715863865, 0.04242600371071603, 0.02455439931509318, 0.06643602842814289, 0.05791442163172178, 0.024753636280365754, 0.029166489039198495, 0.05646494413667824, 0.011781099910876947, 0.013573802152677672, 0.005015643191654817, 0.0324820263631409, 0.03218751247914042, 0.08225962621509098, 0.015177182522165822, 0.02648307414347073, 0.020343896831036545, 0.04414023496792652, 0.02419983455183683, 0.062470666598528624, 0.042133719980483875, 0.03126188363239635, 0.03920317176380195, 0.03842051766696386, 0.05775199519121088, 0.054031538384151645, 0.03091419486736413, 0.03247225969971623, 0.02884720412112074, 0.018818540302163456, 0.05853826725797262, 0.060350328421918675, 0.03226551962143276, 0.014561724092345685, 0.04329065028287005, 0.03983536655141506, 0.03405201750865672, 0.06414408344426192, 0.06722950303810649, 0.02326397519937018, 0.05202320513490122, 0.056288910418516025, 0.009289784375141608, 0.10938404768239707, 0.07876509029301815, 0.0713951705256477, 0.013977045309729874, 0.039871609333204105, 0.039195412609842606, 0.10095322781126015, 0.02052121446467936, 0.03060589930100832, 0.07038572352030315, 0.0361432894715108, 0.020631317638617475, 0.0635907900868915, 0.02964620402053697, 0.10508745792321861, 0.04110128866159357, 0.017690908134682104, 0.02234137060440844, 0.09550764501909725, 0.056471868374501355, 0.049126595331472345, 0.06661881197942421, 0.07348053128225729, 0.036377874930622056, 0.07548551002400927, 0.0521596972248517, 0.029611553145514335, 0.03245829248044174, 0.0487285184499342, 0.03996917948825285, 0.006150884228190989, 0.09581255639204755, 0.04432291090779472, 0.054428553994512185, 0.068757332774112, 0.037603335149469785, 0.05319851101376116, 0.01892391599540133, 0.043102526979055256, 0.00938197674258845, 0.0760548040852882, 0.08250126949860714, 0.06393382558599114, 0.07824336789781228, 0.021828767348779365, 0.015572093216178473, 0.024850989357219078, 0.0757395991240628, 0.09994948050007224, 0.045553551317425445, 0.04162492579780519, 0.05127415919560008, 0.0036761062938239775, 0.03029082978173392, 0.033589507365832105, 0.009705813808977837, 0.026886025079875253, 0.04040444538986776, 0.01901365649246145, 0.03680993846501224, 0.0042257114091626136, 0.10755789684480987, 0.03537764911015984, 0.03228224020858761, 0.08894901882740669, 0.014326587588584516, 0.012462002778192982, 0.031692518532508984, 0.019720296113518998, 0.05017714618588798, 0.05542339182284195, 0.02882561875594547, 0.03352044310304336, 0.01227301858307328, 0.0624206532665994, 0.07153866477892734, 0.046633190650027245, 0.028406804412952624, 0.02308868362888461, 0.04221195347781759, 0.037187624839134514, 0.0214900307400967, 0.015025532993604429, 0.04981351979949977, 0.014803941612626659, 0.030245705347624607, 0.04590743330481928, 0.013772019592579454, 0.04651197567000054, 0.06437293952330947, 0.04351937648607418, 0.05051264146459289, 0.01595032877958147, 0.05773789438535459, 0.04899847095657606, 0.023692220383964013, 0.014086896153457928, 0.04793059095391072, 0.03986278890806716, 0.05463528665131889, 0.05298550349834841, 0.02748566555965226, 0.026266932909493335, 0.04422308462380897, 0.013252359440230066, 0.011229222200199729, 0.0404451818758389, 0.03439641113800462, 0.05867456638952717, 0.02272872530738823, 0.014704687710036524, 0.07535455806646496, 0.06954972384846769, 0.021975703311909456, 0.00814694652945036, 0.017045774002326652, 0.05963042291114107, 0.04687066677433904, 0.017220416193595156, 0.06060758649255149, 0.10706989764003083, 0.03038804370589787, 0.011048844135075342, 0.008109379014058504, 0.05802054132800549, 0.010753884034784278, 0.036520712383207865, 0.09299773126258515, 0.03540215111570433, 0.13899900543037802, 0.055718978110235184, 0.045218723971629515, 0.0915887787414249, 0.02540515659347875, 0.04325422938563861, 0.020209748072375078, 0.029194837225077208, 0.05934285181865562, 0.006525917424369254, 0.03442180001002271, 0.025317380932392552, 0.04762074429891072, 0.034490882826503366, 0.030478145999950357, 0.04771440704644192, 0.013801055192743661, 0.05867415078682825, 0.042422678889124654, 0.04107508713786956, 0.04554575505608227, 0.03539510813425295, 0.06211043553776108, 0.04874042992014438, 0.07611488836118951, 0.09477405430516228, 0.011173619568580762, 0.046923652407713234, 0.06623531458899379, 0.04006539151305333, 0.040418969219899736, 0.01670945122896228, 0.04481937430682592, 0.06622583736316301, 0.015411689128086437, 0.03280197735875845, 0.008756477982387878, 0.04109337736736052, 0.024955103399406653, 0.036316948317107745, 0.0517504324670881, 0.06246531571378, 0.017902911895362195, 0.06319640539004467, 0.05061976677097846, 0.03570953012967948, 0.01466746251026052, 0.058630950370570645, 0.018965142298839055, 0.015032500832603546, 0.05627122875011992, 0.055056425771908835, 0.024345729652850423, 0.0434435475472128, 0.036553452227963135, 0.05415838255430572, 0.07363794822595082, 0.015798776657902636, 0.060970878912485205, 0.02236193737189751, 0.011143320461997064, 0.061274042527657, 0.029866087534173857, 0.05320910146110691, 0.009235307024937356, 0.04470636376936454, 0.04123848208109848, 0.013081423348921817, 0.02181104300689185, 0.04339274011726957, 0.048996689802152105, 0.04469660452741664, 0.01762081043125363, 0.04348439535533544, 0.03732956429303158, 0.03380090813152492, 0.03468974129646085, 0.008773973186180228, 0.06883696521981619, 0.05169230003957637, 0.06928235030500218, 0.028888751403428614, 0.004228335365041858, 0.022682964481646195, 0.04216010704112705, 0.01712224489892833, 0.022650755272479728, 0.01948587207152741, 0.06022811896400526, 0.04325497524405364, 0.039568891006638296, 0.03231464608688839, 0.07271717302501202, 0.0246760094887577, 0.09460477042011917, 0.017840551081462763, 0.0357068027369678, 0.056502222214476205, 0.04429135107784532, 0.0394708236126462, 0.03808051013038494, 0.0026471830142327235, 0.03166168971802108, 0.0034677216626732843, 0.03374758853169624, 0.028987800287723076, 0.0207320344998152, 0.0860853455378674, 0.07980362206581049, 0.010279081143380608, 0.035507550928741693, 0.013302646439115051, 0.010091248204844305, 0.061400326376315206, 0.02407769745332189, 0.07254740674397908, 0.07236354707856663, 0.05068933198344894, 0.04443020690814592, 0.12410358947818168, 0.021215675442363136, 0.021417452408059034, 0.053079511344549246, 0.05482379216118716, 0.021180892836127896, 0.027456716234155465, 0.032539153180550784, 0.05435837279947009, 0.0404587928642286, 0.050660351116675884, 0.0650423344632145, 0.026482185421627946, 0.0688070195610635, 0.010592068938422017, 0.05629387538647279, 0.0022559693752555177, 0.036609603121178225, 0.036461989948293194, 0.011261973177170148, 0.02996876366523793, 0.04523023839283269, 0.05054453526099678, 0.024332615903404076, 0.06738983662216924, 0.007672149204154266, 0.03788986352446955, 0.0600704867974855, 0.04281605055439286, 0.054050288745202124, 0.013407137121248525, 0.0266209187975619, 0.0324691463902127, 0.037812550290254876, 0.05751832628448028, 0.03789578957366757, 0.029657377053808887, 0.04011828808870632, 0.062203879351727664, 0.019714896989171393, 0.03147035291476641, 0.042668916066759266, 0.010494919952179771, 0.036691024142783135, 0.04226340286550112, 0.011319467357679969, 0.17434090899769217, 0.19338208803674206, 0.15705753641668707, 0.09382911477587186, 0.1561022736132145, 0.1238400825241115, 0.24447748612146825, 0.08635471545858309, 0.13256909733172506, 0.29103240987751633, 0.11023242637747899, 0.17572014592587948, 0.2239273427403532, 0.08733477341593243, 0.17022523999912664, 0.15556274709524587, 0.08756129172979854, 0.11471367732156068, 0.1534544094465673, 0.09164302973658778, 0.10893316328292713, 0.10753557304269634, 0.08731501002330333, 0.12962986598722637, 0.12670210824580863, 0.13455508451443166, 0.14270932821091264, 0.1260317410924472, 0.15121931297471747, 0.11962087650317699, 0.10274444575770758, 0.1593915611738339, 0.0923398692975752, 0.15635424759238958, 0.15414914872962981, 0.136786128859967, 0.12074535639840178, 0.16679341555573046, 0.18453423312166706, 0.1380051509477198, 0.15936368610709906, 0.157334906689357, 0.05368201280361973, 0.11091306485468522, 0.09453109742025845, 0.07214323311927728, 0.1426329612149857, 0.11124163589556701, 0.16221175203099847, 0.1510333752958104, 0.1576698973076418, 0.12620596768101677, 0.19674333423608914, 0.15243952249875292, 0.1430692698340863, 0.1570679116412066, 0.12249479885213077, 0.10854137610294856, 0.15591440635034814, 0.17529850214486942, 0.21547549782553688, 0.18526149331592023, 0.09523898756015114, 0.147989263641648, 0.1899260250502266, 0.09627130013541318, 0.15982420358341187, 0.19909757509594783, 0.142837482271716, 0.14365206356160343, 0.09040926117449999, 0.09244471992133185, 0.2649837388889864, 0.15360323974164203, 0.16683163616107777, 0.09724168048705906, 0.2178703638492152, 0.2869265520712361, 0.18684835347812623, 0.0758612593926955, 0.13323524908628315, 0.18161869113100693, 0.10465941682923585, 0.1615445761126466, 0.0814640884345863, 0.0900814397027716, 0.14792201021919027, 0.08187802872271277, 0.10994546013535, 0.22450292279245332, 0.16438484948594123, 0.13626686297357082, 0.08865152893122286, 0.15959011536324397, 0.164339222246781, 0.0945626015891321, 0.09156760526821017, 0.11018676203093491, 0.1638000668026507, 0.1345845774631016, 0.19233628321671858, 0.24752447730861604, 0.15715403045760468, 0.1547736066277139, 0.09847112974966876, 0.21483453456312418, 0.2320380965829827, 0.17005408590193838, 0.1441687616170384, 0.1372422676649876, 0.18253193353302777, 0.11501564978971146, 0.14356374798808247, 0.15179508598521352, 0.07426752694300376, 0.13140042254235595, 0.11639849355560727, 0.1347792279557325, 0.13172368722734973, 0.19474909437121823, 0.24066691403277218, 0.15621329890564084, 0.15943790087476373, 0.1397274827468209, 0.1592239990714006, 0.0957451322756242, 0.1523348648333922, 0.18586245481856167, 0.12249657258507796, 0.18284871184732765, 0.15518535015871748, 0.09157239212072454, 0.18607028585392982, 0.09792500553885475, 0.1132812506693881, 0.0844700462766923, 0.09208178744302131, 0.08435518408077769, 0.10344413516577333, 0.07352311571594328, 0.11302000726573169, 0.1304791946313344, 0.16695665835868567, 0.11327171407174319, 0.12702157313469797, 0.18757522775558755, 0.12189701374154538, 0.22966739488765597, 0.10924214904662222, 0.14797528157941997, 0.13310026726685464, 0.20729280018713325, 0.14629755285568535, 0.12190555586130358, 0.17350226728012785, 0.09695356391603127, 0.12024248455418274, 0.1543175123515539, 0.1500692660920322, 0.18456685793353245, 0.13373777212109417, 0.12990787450689822, 0.08296896354295313, 0.10321982103050686, 0.17999856790993363, 0.1462735517998226, 0.11830454401206225, 0.13386635662754998, 0.0951164738216903, 0.11830036572064273, 0.17173496133182198, 0.07707280805334449, 0.1169514752109535, 0.14791200606850907, 0.17160113726276904, 0.18249194661621004], [0.011818752773251617, 0.012760723711835453, 0.06000063585815951, 0.053550556185655296, 0.08449763932731003, 0.023742627054161858, 0.03147703224385623, 0.03832488080661278, 0.0635846822115127, 0.03289104250143282, 0.02373618150159018, 0.04325373956817202, 0.04492277032113634, 0.05507224836037494, 0.05300652854202781, 0.07168605530750938, 0.05891424669243861, 0.04171046202827711, 0.040170516731450334, 0.0327803660184145, 0.04297343039070256, 0.030574101983802393, 0.01750880550389411, 0.011399635077395942, 0.06521515097119845, 0.05212981464865152, 0.05010037471947726, 0.026395003478683066, 0.03816635064140428, 0.03889292434905656, 0.038522956310771406, 0.015132277021621121, 0.05075185421446804, 0.018978753287228756, 0.03617915375798475, 0.044314665647107176, 0.021044283857918344, 0.03020640306203859, 0.02828076176228933, 0.03041139352717437, 0.02152666314941598, 0.04030430740385782, 0.020607526239473373, 0.025693211937323213, 0.056240277481265366, 0.002754364909378637, 0.061102632389520295, 0.02961158097605221, 0.03601592208724469, 0.038343772175721824, 0.022014181813574396, 0.05598875250143465, 0.011574925720196916, 0.03866063583700452, 0.03609645624237601, 0.061430116184055805, 0.005903844603381003, 0.05411377576820087, 0.0457201040990185, 0.04823352079256438, 0.024509527211193927, 0.025981165235862136, 0.04631283889466431, 0.01826747895393055, 0.02222746206825832, 0.05804398206237238, 0.018771720060613006, 0.031702871492598206, 0.02728580333496211, 0.01912741474370705, 0.02995727707457263, 0.007146595007725409, 0.05679768975824118, 0.017723579330777284, 0.035962383553851396, 0.005748949106418877, 0.10775627291877754, 0.04153904075792525, 0.07753282829071395, 0.017385744431521744, 0.037136925020604394, 0.06717505908454768, 0.030366872088052332, 0.14195600379025564, 0.053129142470424995, 0.02691629357286729, 0.04932422554702498, 0.03803580315434374, 0.011681665109790629, 0.013447718683892163, 0.04166348408034537, 0.011840522747661453, 0.023682108621869702, 0.07246185195981525, 0.02222990744485287, 0.03039846345927799, 0.06625425419770181, 0.06273613282246515, 0.07094924367265776, 0.010899738317675656, 0.05646200152114034, 0.002136476641680929, 0.03403957169211935, 0.06077474041376263, 0.014750967111467617, 0.026583455182844773, 0.055149576437543146, 0.05452877732750494, 0.03413292273762636, 0.051968497718917206, 0.06991148373344913, 0.0024767534387137857, 0.03633743901445996, 0.006272897480812389, 0.06079740560380742, 0.02093443301419029, 0.06539538153447211, 0.026781059423228726, 0.03050145500310464, 0.015883696905802935, 0.03826731612207368, 0.020659905167121906, 0.06546726595843211, 0.03800829545070883, 0.04452039640455041, 0.02430328808259219, 0.02112556016072631, 0.06547346289153211, 0.043847854758496396, 0.06324038506136276, 0.023913957411423326, 0.060889940286870115, 0.07804446489899419, 0.03925101802451536, 0.06012973615725059, 0.050853491338784806, 0.04441829543793574, 0.04819322217372246, 0.09293611074099317, 0.04401987716846634, 0.0943764264229685, 0.04775763714860659, 0.08618874155217782, 0.02598053812107537, 0.019706610910361633, 0.03998997446615249, 0.1697194218286313, 0.06934280565474182, 0.0008061377945978165, 0.026074464331031777, 0.019127950945403427, 0.015208191307465313, 0.009362843247799901, 0.03653663516161032, 0.05553573813813273, 0.022722018147760537, 0.07237110956339166, 0.011149890324304579, 0.04887984607194085, 0.058875680988421664, 0.05433108031866141, 0.035133912970195524, 0.024496522928529885, 0.034592865049489774, 0.06555096537340432, 0.04309450065193232, 0.026252082534483634, 0.004875188033111044, 0.05198672857659403, 0.020190290815662593, 0.07071537809679285, 0.0566716211324092, 0.024560520178056322, 0.048354060418205336, 0.05881597891857382, 0.04288294032448903, 0.021647356770699844, 0.03804515421506949, 0.07776218160870485, 0.03275331844633911, 0.024651950916450005, 0.05993907470838167, 0.07838670630007982, 0.04278312517271843, 0.09521168394712731, 0.10300888781785034, 0.014513365749735385, 0.03260212441091426, 0.06807818601373583, 0.05547770590055734, 0.10997999968822114, 0.11701176728820428, 0.027532925523701124, 0.022539301389770117, 0.030799267733527813, 0.048599548026686534, 0.017356997341266833, 0.02601748037704965, 0.054640867601847276, 0.06048882059985772, 0.06364913773722947, 0.034183696770924143, 0.03466148773441091, 0.01067177188815549, 0.07531244118581526, 0.013965877842565533, 0.059521802177187055, 0.04998614705982618, 0.039737766710459255, 0.04788149046362378, 0.02071628983685514, 0.045576272168545984, 0.011830115054181078, 0.02061453396891011, 0.006783851313230116, 0.05410603516793344, 0.03979491950303782, 0.021393306633399334, 0.04223536823701579, 0.0696422993496526, 0.028146112053946126, 0.023208063648780808, 0.07094165150192566, 0.05829959627590142, 0.026056098031403963, 0.049793151556514204, 0.03525486448779702, 0.06424465929740109, 0.06187021717778407, 0.04031595541164279, 0.03892256201652344, 0.013089217754895799, 0.03285285900346935, 0.014104601941653527, 0.015099734773684759, 0.009569815247232327, 0.04163805067946669, 0.025675921751826536, 0.054640993766952306, 0.011770765504479641, 0.003039110970348702, 0.08739453114685602, 0.014681647735415027, 0.013796466864732793, 0.04426009181770496, 0.03772353709791787, 0.05223679523624014, 0.006748188334313454, 0.01608816415682668, 0.03852672271023039, 0.04999513075745199, 0.027771056593337562, 0.012056837458658265, 0.05068391059467103, 0.06512492065667175, 0.058448693744139746, 0.03860767246806063, 0.07994576561031863, 0.02041034873400349, 0.03012886347278254, 0.037324658696888946, 0.04000939276011195, 0.0627567719493527, 0.026398868212709203, 0.02460378182149725, 0.045172543832450174, 0.0412167668400798, 0.005188963432374294, 0.018661449903447647, 0.03126398391032126, 0.014275850662670564, 0.06580505447345786, 0.03860605829686392, 0.052642341834143735, 0.03423162837862037, 0.00648767223538016, 0.0190257293797913, 0.0215888495586114, 0.03693462298542727, 0.035860557181877084, 0.018681040746741928, 0.03567013322026469, 0.03403697788598947, 0.07245125409099273, 0.022866367726237513, 0.047787560542928986, 0.0021193000975472387, 0.03149834672512952, 0.01251905259778141, 0.05203365828492679, 0.008515020235790871, 0.06984732506680302, 0.0357247738429578, 0.035790784168057144, 0.05076460060081445, 0.016617512119410094, 0.07659832335775718, 0.05139833905559499, 0.06543401032104157, 0.010312048270861851, 0.01369394565699622, 0.03077681591094006, 0.031932087513268925, 0.06532956045703031, 0.02571432603872381, 0.030736313201487064, 0.0284941644713399, 0.011859309288411168, 0.04570332414004952, 0.07510657684179023, 0.0074245891482860316, 0.050502470330684446, 0.026177123763773125, 0.009433229461137671, 0.035570715117501095, 0.005152821768206195, 0.025590392942831386, 0.04397355602122843, 0.031140305000008084, 0.00581010996029363, 0.017874157383630518, 0.014344273895403603, 0.07951520863571204, 0.06056004080164712, 0.03715942322742194, 0.03486535570118576, 0.046167630280251615, 0.031861464740359224, 0.010820101233548485, 0.04647244517400395, 0.013904819497838616, 0.047278413840103894, 0.05997960710374173, 0.04509032500209287, 0.1317375950748101, 0.052331025726743974, 0.039802905012038536, 0.0361066162440693, 0.044861643327749334, 0.05557470831263345, 0.060776848113164306, 0.019189369231753517, 0.02330053710466018, 0.038162606506375596, 0.020992404024582356, 0.028808616152673494, 0.055889048671815544, 0.04539751847914886, 0.0802979592117481, 0.04326915026467759, 0.09351173532195389, 0.04123919454286806, 0.1256443845340982, 0.16441659856354818, 0.1425039314199239, 0.14830921834800392, 0.22837390570202842, 0.11325958737870678, 0.11004970961948857, 0.17443100572563708, 0.15407390979817137, 0.20177938509732485, 0.07933934932225384, 0.133136261429172, 0.16481490922160447, 0.1893965620547533, 0.17060259240679443, 0.20164714922429994, 0.1484294462716207, 0.08954828081186861, 0.191190377518069, 0.12907769327284768, 0.2043246102402918, 0.31489976041484624, 0.11631494257017039, 0.12580823589814827, 0.12777437805198133, 0.08236144145485014, 0.18599204864585772, 0.12307498764130287, 0.08111335686407983, 0.08139516517985612, 0.11951552864047699, 0.1364710129564628, 0.08569990372052416, 0.21178798866458237, 0.08118963480228558, 0.14090411335928366, 0.1322874819743447, 0.07681546092499048, 0.12738288030959666, 0.16768765897722915, 0.11140920541947708, 0.18467442481778562, 0.09612942376406863, 0.13092102482914925, 0.19373833376448601, 0.12828982929931954, 0.16983040259219706, 0.12341672438196838, 0.0960116671922151, 0.1850539888255298, 0.11303723993478343, 0.15449326776433736, 0.13147456309525296, 0.1487773354165256, 0.13228763040388003, 0.16036465036449954, 0.07154780803830363, 0.12612163001904264, 0.13865032960893586, 0.049588871697778814, 0.12446500797523186, 0.15241289424011484, 0.13926614890806377, 0.08161133053363301, 0.09539399994537234, 0.21732614695793018, 0.23551268357550725, 0.15296037658117712, 0.09209892363287508, 0.13973773922771215, 0.12110244817449711, 0.12130235307267867, 0.2117307690787129, 0.10221643737168051, 0.23310373158892617, 0.10160321558942087, 0.15627776185283437, 0.10952697048196569, 0.2481701606302522, 0.16968143871054053, 0.11629879343672656, 0.190709272865206, 0.10644267153111286, 0.1669185861828737, 0.13698638998903334, 0.11011466980562545, 0.15321864397265017, 0.11298403536784463, 0.20013610686874017, 0.08291542500955984, 0.12289983336813748, 0.07968860401888378, 0.1406517089344561, 0.11812008320703171, 0.04979365621693432, 0.22188838105648756, 0.166173737088684, 0.12760717218043283, 0.18040654133073986, 0.038746090431232005, 0.17335701413685456, 0.09582074970239773, 0.10604378941934556, 0.1653910384629853, 0.09007130938698538, 0.08472570872982033, 0.15247988048940897, 0.13947602827101946, 0.15277737780706957, 0.08811624007648788, 0.11296989003312774, 0.09847449167864397, 0.10274866115651093, 0.12810671178158373, 0.17950903245946392, 0.12398181788739748, 0.1381705459789373, 0.1277659324114211, 0.15513899561483413, 0.0582922304602107, 0.29240998439490795, 0.09826223744312301, 0.12454009847715497, 0.184032600664068, 0.09524526612949558, 0.12209268839797005, 0.10492630055523477, 0.1166117496904917, 0.10766128543764353, 0.1644196265260689, 0.07397401495836675, 0.1596077933209017, 0.15977974893758073, 0.1616208243649453, 0.15712628897745162, 0.18243098660605028, 0.18490207119612023, 0.1334019799833186, 0.2065137232420966, 0.14120354026090354, 0.14859953167615458, 0.10274339932948351, 0.23373411182546988, 0.1402517210226506, 0.15998459653928876, 0.13121875963406637, 0.2655544801382348, 0.17368105065543205, 0.10014862840762362, 0.1334177135140635, 0.3076661954401061, 0.07056758680846542, 0.07958318194141611, 0.2744954597437754, 0.24461984488880262, 0.08136213960824534, 0.14827032980974764, 0.13294894335558638, 0.22831091220723465, 0.1981727551901713, 0.11601669568335637, 0.1505129219731316, 0.11710873630363494, 0.21298162930179387, 0.1499863385106437, 0.17883778957184404, 0.12011470898869447, 0.10273389983922243, 0.15538461680989712, 0.14230347733246163, 0.19203718286007643, 0.17486778931925073, 0.19597938226070255, 0.1680562095134519, 0.16547616280149668, 0.13775590807199478], [0.02956059543066658, 0.027785957063315436, 0.014041657614143332, 0.04055353543662932, 0.01673028145887656, 0.03612003427406307, 0.04793153719219845, 0.00975885881416616, 0.06940045568626374, 0.05155421975359786, 0.01957080345164286, 0.02681374731764663, 0.017954474460566416, 0.028657145667239092, 0.02856135481124511, 0.0235972551672603, 0.038237715561990626, 0.02614829318190459, 0.025499470575596206, 0.01612533462321153, 0.01850041313446127, 0.019531818434188608, 0.09199342734063976, 0.04584686663292814, 0.018911175175162498, 0.022808127687312663, 0.049432560554123484, 0.018816625561157707, 0.02489713424438378, 0.006553999828611268, 0.08458640761091374, 0.03329124563606456, 0.023510861756221857, 0.06780356168746948, 0.06255976884858683, 0.04105515676201321, 0.04181793243333232, 0.05561649122682866, 0.03175911144353449, 0.005589716683971346, 0.04930805414915085, 0.008666029661981156, 0.014282191386882914, 0.07105130382115021, 0.014318783905764576, 0.060726307856384665, 0.037936648514005356, 0.033891995626618154, 0.012285356788197532, 0.013330643032531952, 0.026910276610578876, 0.020396489126142114, 0.0682316547317896, 0.06107682791480329, 0.010331115900044097, 0.03465391040663235, 0.02447903978463728, 0.016023864482122008, 0.02720602431509178, 0.043845602340297773, 0.038442121585831046, 0.01827603962738067, 0.01342083345662104, 0.047755989580764435, 0.022409334633266553, 0.04209792990877759, 0.054177407509996556, 0.03584727644920349, 0.02845657098077936, 0.037900086608715355, 0.03784639964578673, 0.029524794226745144, 0.03794736883719452, 0.04918317667033989, 0.047677218026365153, 0.03260878147557378, 0.05200356048590038, 0.026280590282112826, 0.18813836941262707, 0.012832746360800229, 0.03330430372443516, 0.09734183331602253, 0.04532694394583814, 0.059833541308762506, 0.0610293527279282, 0.044873751467093825, 0.05869845983397681, 0.05870630804565735, 0.013645899016410112, 0.054170256917132065, 0.02704747188545298, 0.07279343612026423, 0.09343838144559413, 0.027683269800036214, 0.014744057716598036, 0.0224769591295626, 0.03076613455050392, 0.04316123086027801, 0.04233813342580106, 0.07248462847201154, 0.023613589837623294, 0.0021555155126407044, 0.10537915164604783, 0.007291121310117887, 0.05193153505388182, 0.03798812387685757, 0.04703671489551198, 0.05151468554686289, 0.07363885364611633, 0.044846095333923586, 0.03607467791880481, 0.03197456804628018, 0.07170963333919644, 0.05160601423995104, 0.0878480427491013, 0.022959230809647124, 0.03654276159068104, 0.03394498497073073, 0.08744789156480692, 0.037837497584405355, 0.12397816652082838, 0.01168497137769009, 0.025146553380182013, 0.02951207567093661, 0.02738626044447301, 0.03050083716516383, 0.0463614421460079, 0.04820626912987791, 0.021939905818726402, 0.08669308284879662, 0.03936532732041087, 0.046868306744727306, 0.053009519397164695, 0.013068406078673434, 0.054628150901407935, 0.033270996136707254, 0.048762768565211445, 0.027935895013797563, 0.017873083124868572, 0.11572844552574679, 0.040009055082919076, 0.04297378662158735, 0.08151934875058942, 0.05594800488324836, 0.07889296233770438, 0.030486892210319638, 0.014903968276485102, 0.03780071303481236, 0.018591218613437377, 0.019341568877280224, 0.06058685830794275, 0.013879351772629889, 0.026229858922306448, 0.028284481777518522, 0.03946567310777027, 0.007804758006386692, 0.03226300745154731, 0.07515288685681298, 0.0576093729614513, 0.04378007441118825, 0.03857265051919967, 0.012815411646442953, 0.01254841938134632, 0.0342114159866469, 0.04249559860909358, 0.07094528802554123, 0.04669034344260581, 0.014385018730536103, 0.053477339606615715, 0.04722168036096264, 0.05335059933713637, 0.025501097734377254, 0.03428085503401235, 0.03326155601826031, 0.023413623712258413, 0.05438503445475362, 0.015597888414049521, 0.06570579222170636, 0.0839372658811044, 0.01853103229223052, 0.038703917889506556, 0.01160772215371253, 0.033457431054557674, 0.037608303828164935, 0.02049503891612403, 0.044446727115428075, 0.021771557039755862, 0.05415243795141578, 0.04153862886596471, 0.049725078060873784, 0.05077271969639696, 0.01427342569513712, 0.031033573031891137, 0.055560017499374226, 0.012761455654981546, 0.011998643803963205, 0.0301496102110832, 0.033731038638507016, 0.03545099185430445, 0.05019630472816061, 0.0507023974932963, 0.041468633207841776, 0.05214061660808511, 0.009115734974329825, 0.07010944420471787, 0.03485873945464846, 0.04674767063988838, 0.03816388671111781, 0.03277940493717324, 0.05286888983391691, 0.044493352543213405, 0.05239430123765487, 0.07369242928689346, 0.03157655053655617, 0.007934264631330734, 0.016493968651047908, 0.08616416904260404, 0.027806028447230347, 0.01426529453965486, 0.046766446976107545, 0.022591144115722273, 0.07537418787251227, 0.034816103070625104, 0.004319905256124912, 0.020459603219933342, 0.08898680898710154, 0.038422818324761465, 0.04038765429868363, 0.04359523511084262, 0.026412282531964593, 0.01398493619490182, 0.03336623223731294, 0.027751701381930616, 0.03555523762770463, 0.04889473726507276, 0.05117517153848894, 0.029003823256061878, 0.0625506552751176, 0.06411342532373965, 0.05978778419375885, 0.05448423733469099, 0.018574091700429562, 0.05262091974145733, 0.00900453434951487, 0.075870046421187, 0.051712735075852834, 0.031301332492148504, 0.029611182071676012, 0.01721052893117303, 0.029603231814689934, 0.05630661064060405, 0.10257984482450411, 0.024229045484389644, 0.058139926914009266, 0.16047898563556373, 0.021200225783104543, 0.07038671057671309, 0.016238640164374374, 0.08222308286349289, 0.06623895111260936, 0.023119824145396706, 0.04051327763590962, 0.01617589899979066, 0.10451805253978819, 0.015017000150692184, 0.053420902986545116, 0.005522478568309452, 0.023893073375802487, 0.03755095065571368, 0.03627171441621613, 0.0727125939738471, 0.016450128132419195, 0.049695963607518934, 0.021411253619589843, 0.009620706168789184, 0.07765785048832186, 0.03198901024006773, 0.05069826373073738, 0.08470889166346751, 0.04837230240809731, 0.06402064202120528, 0.021214378539298195, 0.04141217803407926, 0.01986182738619391, 0.04080948361661285, 0.04054639968671836, 0.03816973854554817, 0.04217927300487645, 0.10122120249434374, 0.022590329608647153, 0.031682915141573176, 0.02037477388512343, 0.021334253942768555, 0.03691904159495607, 0.002435392621009669, 0.03820348771114368, 0.029972082920721732, 0.026985111071553547, 0.031036465552460868, 0.022143614223750774, 0.03813825664110482, 0.03996076724433806, 0.04800756280019414, 0.050310320875723846, 0.06401575868949294, 0.0517903377476614, 0.016412213662988506, 0.03190581177477725, 0.006034683847246924, 0.00855183261592174, 0.024838777317199856, 0.03839716599031817, 0.08220531584811397, 0.03354187632794492, 0.07331049782806076, 0.06348043272737414, 0.027545686753001064, 0.09520222898572683, 0.031341145004262216, 0.039910260384203866, 0.035882350348401815, 0.008028322572499746, 0.0426509375392925, 0.0255356576963095, 0.00344640068760782, 0.08200304349884391, 0.0316603130340809, 0.04409673027112149, 0.009172834888886428, 0.012036528587486828, 0.04811109982256312, 0.041527570865582675, 0.058094552005059086, 0.04866981085797306, 0.07797130398103036, 0.03758167556952685, 0.01887746311695082, 0.07011499546933919, 0.03338469316076953, 0.01718531446385896, 0.04301820787077304, 0.006753542002115864, 0.023256290260178503, 0.025280845002271235, 0.03741795779205859, 0.048679028332117014, 0.045814316035830416, 0.037923289855825715, 0.024762384346104227, 0.009314304934378015, 0.016704879599274136, 0.03424601862207055, 0.09578586876159534, 0.1715493353549391, 0.15202068403596058, 0.10487829844350927, 0.12169417736004107, 0.0827272683090996, 0.1000589769682847, 0.1819372209138237, 0.1915113118593581, 0.19439906784100458, 0.1164012543449644, 0.1356888486770913, 0.11323255093884654, 0.21013311808928847, 0.13657832751050591, 0.11471389254438691, 0.12373593694064766, 0.1569708387251012, 0.06882631540065631, 0.072970898472704, 0.0706364432699047, 0.10328737873351201, 0.1557911653071642, 0.11117024871055037, 0.1413247181335464, 0.15333103481680155, 0.1036744235898368, 0.16563703073188663, 0.14109347976045683, 0.17414832167560235, 0.1824993235641159, 0.08354495177627541, 0.1475349356769584, 0.2307757775997743, 0.13076861738227308, 0.13673805253347382, 0.15852451004320756, 0.17339572455966845, 0.1629856784711592, 0.11738596556824632, 0.20227549597620964, 0.08619876054581255, 0.11504201087518595, 0.2336648546042852, 0.133479000069201, 0.21954387717414647, 0.1405420046648942, 0.1346093651955016, 0.08687240799190477, 0.19019722065422684, 0.10457274140208028, 0.12953021039720625, 0.11336954397847876, 0.10741276244516484, 0.10071349926874973, 0.12767139764036983, 0.1920777338091284, 0.1025045762071386, 0.12656525621423498, 0.09665038916864432, 0.11301821126835421, 0.19478403468383476, 0.1623895112425089, 0.10848275385797024, 0.1982769527239725, 0.18284243327798322, 0.18545393220847473, 0.06716242030961439, 0.18015326117165387, 0.10554058360867202, 0.10913280842942186, 0.07946009674924426, 0.1075720124936197, 0.16207810607738793, 0.10490056287380867, 0.16919408517424017, 0.156014388485346, 0.09182538284221664, 0.33599610964301974, 0.13380599033553153, 0.13094627269310877, 0.12256716567208059, 0.18001182266743854, 0.1212022002437152, 0.2531172725139186, 0.18315689609153196, 0.1490662683499977, 0.2659305412089452, 0.07719971530605108, 0.2961476775817573, 0.0853241172444541, 0.15542341629043221, 0.14705055073136464, 0.09809813374886289, 0.1878685542033054, 0.09320496857981198, 0.1181564484431874, 0.17381340527208522, 0.12872325838543475, 0.1459149460424669, 0.10008914527134039, 0.1264909969177097, 0.2476086962269619, 0.11436635220889002, 0.13435087515972555, 0.13365469611017033, 0.14019012276548892, 0.15718929731519893, 0.1950197556288913, 0.12014207197353244, 0.19650065194582567, 0.08147708344040439, 0.22144589776871726, 0.176025049877353, 0.15406037302454934, 0.11951642663916573, 0.12308488789130934, 0.08882364782039076, 0.15318842371925712, 0.2429707779083401, 0.18583858734928071, 0.10808147460920736, 0.10334528851672076, 0.19446903752395883, 0.13646094943396747, 0.11597949924180284, 0.13452354323817417, 0.12140180086134933, 0.10621410488965921, 0.11802473949501291, 0.11160124355228618, 0.12468674685806036, 0.21523913863347843, 0.11748409975552931, 0.11644035068457015, 0.14124118199106306, 0.21686732157832012, 0.13202890288084745, 0.21445589081849903, 0.24321733420947567, 0.15115387039259076, 0.21155155525775626, 0.2246012128307484, 0.10495724069187418, 0.10923408932285383, 0.09754204991622828, 0.1400507177459076, 0.16362791822757572, 0.1116527189151384, 0.1432449955609627, 0.11535061072208919, 0.13518116029445082, 0.07227250782307237, 0.13544117915444076, 0.13073873851681128, 0.18048770260065794, 0.13586797344032675, 0.14670856908196583, 0.11611532710958272, 0.07688355297432281, 0.15785420226166025, 0.16431946627562866, 0.13527156872441992, 0.11798546503996477, 0.19045272725634277, 0.13287376379594207, 0.11200352470041253, 0.14969454088713974, 0.15098811913048849, 0.16570928622968495, 0.11592907772865146, 0.1309101449442096, 0.09118400397710502, 0.1214994081237819, 0.13885170395951718, 0.25536776112858206], [0.05655517445120495, 0.05743457862990908, 0.019916816818295047, 0.019515186904754955, 0.04346694375271909, 0.04483356045966502, 0.02458828948874725, 0.0875616999110207, 0.01825185117922956, 0.02223313393187709, 0.025697217679407913, 0.02736243564868346, 0.04551713413093239, 0.04083345127583016, 0.030876677446940448, 0.038394230796257034, 0.022862161604280118, 0.051100273994961753, 0.049572967473068275, 0.03200099592504557, 0.06435508345020935, 0.024285370782308746, 0.009067947157745948, 0.016059036715887487, 0.05133022103109397, 0.04913648073852528, 0.021115774943609722, 0.027856509332195856, 0.026334112117183395, 0.05420487439550925, 0.013007249399379361, 0.07444605056662112, 0.014476653559540864, 0.03052170079172356, 0.01817499807657441, 0.061475869588321075, 0.04345583751273807, 0.0733638285601046, 0.03364198833878618, 0.021062878367956728, 0.0319881530595012, 0.05988399621855933, 0.04481655785639305, 0.014223421640053857, 0.05850085188285448, 0.025830327431322075, 0.06158010051876772, 0.05540840415051207, 0.05781117775768507, 0.017640438381931745, 0.13304658030392602, 0.042121934675378725, 0.11098155766376294, 0.031674432393629104, 0.016663838832755573, 0.0042542956907709595, 0.0030473583183265873, 0.03095192565524485, 0.04200566610961687, 0.029031961785221938, 0.020492888543230947, 0.0089932184528152, 0.037767631802125834, 0.03049661248951452, 0.0243450264679268, 0.005155156286491547, 0.022118308843346313, 0.045448537421179935, 0.023897787868918385, 0.012349881890258985, 0.048935696395346895, 0.027549750011530705, 0.05366428289562464, 0.010792087941808859, 0.025642742184572853, 0.02873135857953457, 0.008016903702809941, 0.04459397663595155, 0.04305671791371424, 0.039721446883049794, 0.042273633371223696, 0.04069464739586692, 0.06939425133168697, 0.038282218447420746, 0.034845150730689056, 0.015114707603061106, 0.043446579220471904, 0.05016776543925516, 0.021520616501220502, 0.04373075127659831, 0.02027404960244894, 0.03140479158901144, 0.028409511396603193, 0.029273373147589155, 0.0541478514787741, 0.0345132288930472, 0.023234411746670958, 0.04833276820136234, 0.07253880525240675, 0.07868151704315096, 0.01191448611280066, 0.02289988497068407, 0.05592272733338177, 0.00661254043734516, 0.0280674610985443, 0.03345874465594534, 0.0627355687902309, 0.04635412828065455, 0.015464036514458712, 0.04503973279497586, 0.023715175011602696, 0.02870812008040957, 0.03915644614608027, 0.02808427259878954, 0.02608863007480977, 0.024432158315903507, 0.02554403654357884, 0.05907841717998963, 0.06871713063446805, 0.0013605939466287964, 0.04469945066375658, 0.053707060287706554, 0.037169137940509245, 0.016970831929938868, 0.031421059466083534, 0.015546508602710674, 0.08809259525150992, 0.0062878341304895, 0.017455532288295217, 0.018696310435188934, 0.06696235213894397, 0.020692253528977744, 0.014232363591872854, 0.008245094632002292, 0.09530095689115115, 0.09090049614314921, 0.01757440208166372, 0.015378106018033577, 0.022979465466050897, 0.01765476554282941, 0.028242967891856097, 0.010870545938814757, 0.03554840244760271, 0.022121488946140744, 0.018432367469358724, 0.07919261930510402, 0.013669590225617867, 0.06186465107020922, 0.043536264056456275, 0.038657945551676676, 0.08455510382191278, 0.02100680911098607, 0.06504663149826229, 0.033104896065196954, 0.01635300141060725, 0.02749769020738313, 0.0971072626998648, 0.04703983933723066, 0.061703215396846645, 0.10610969955450855, 0.011578641097003128, 0.04002371621027123, 0.04833770348341204, 0.04867284253123216, 0.024970471422420815, 0.05241728184046224, 0.01660165798966773, 0.043948553066002205, 0.055032075906638056, 0.028633280053327326, 0.03639265109086409, 0.03200616127287503, 0.03137414460070431, 0.004199864724796498, 0.10269007601891644, 0.025079741535591893, 0.022825874293630477, 0.04475838090002071, 0.057499167742207646, 0.016736910692998208, 0.04738160947454162, 0.05583942496741656, 0.023036174825392663, 0.06822089359047823, 0.06880052576889284, 0.04484557583054993, 0.04911014562821947, 0.04001958615845069, 0.056079535715980455, 0.0331477105646627, 0.003982998969149776, 0.04061812454892788, 0.03227229914045893, 0.10153739451197907, 0.03220205115212593, 0.007502302214561496, 0.04425272600201424, 0.04487708371016197, 0.035209916313760914, 0.045058820833219215, 0.029565053882834036, 0.059655770965036936, 0.04892031538474839, 0.024917912523960695, 0.029973151613376103, 0.06794178669224493, 0.024583289268775843, 0.01497371531513636, 0.0212873242344358, 0.034814934188034385, 0.020569878943206277, 0.05134005448780954, 0.06775283589377068, 0.036422181146917865, 0.01022777461912483, 0.020547534732031636, 0.038986197469057515, 0.05660688359057531, 0.017984472069656476, 0.05888989682716783, 0.09078015689738095, 0.03263929858803749, 0.0480677695304621, 0.0076637179427052615, 0.045419378438964486, 0.01488848522058106, 0.0603891872742679, 0.058200196726829745, 0.06308146155788563, 0.026507852599024773, 0.04250717240211088, 0.02664582156285178, 0.028452774895413313, 0.05573702714173123, 0.03956256419769488, 0.01741416683216812, 0.056212023919215426, 0.024491622898494825, 0.039345972109003924, 0.034084312064806, 0.02746472215221729, 0.04001012748631183, 0.06957137229619548, 0.04080309743585531, 0.028646698083321098, 0.021867626201128587, 0.02476126370311249, 0.015258094244927634, 0.03277130068454426, 0.016235634466283955, 0.019140229778713547, 0.02885379068175098, 0.046053287587710656, 0.04657650912122335, 0.049400956195313483, 0.015451046147063607, 0.0237577779989806, 0.027096754201920703, 0.1103073832928203, 0.011725217118510045, 0.01625739980227081, 0.055031133379088715, 0.024368556260014884, 0.03087701141339494, 0.03137370302283671, 0.08298292334075086, 0.05029250191000756, 0.016256156704912428, 0.028510543670563493, 0.050145827553933486, 0.008644345034554135, 0.020666298769356217, 0.05438930922537111, 0.07989430509041995, 0.08846608849125914, 0.025201741336786654, 0.004634970600818633, 0.021906722540734336, 0.012661600612773327, 0.02885829180740984, 0.1108506353921257, 0.0015077773696248187, 0.06886481060064398, 0.07756544568110257, 0.05088750767754391, 0.052672005476779304, 0.006945313425603672, 0.046556771703762934, 0.007560944868600927, 0.027239135233685374, 0.01436417551303748, 0.049258233775617555, 0.02331171570403967, 0.08681224207975902, 0.034782342772814445, 0.04337481354014017, 0.0360707408253802, 0.07217628095531836, 0.03845166560495272, 0.014373264039022615, 0.08598681801231578, 0.012897396700282115, 0.06548489196575247, 0.03339107563078869, 0.008634105251985602, 0.03449499803537037, 0.03525322434143163, 0.029761151563434396, 0.03592270462831948, 0.02571238532254938, 0.04874211459537037, 0.06127424661826808, 0.03122540336335078, 0.01631812789128162, 0.04285938455723226, 0.049081495017162524, 0.01816058185795555, 0.07754077669233084, 0.02426912516966695, 0.034481965922168456, 0.04036005382658914, 0.055841803550720215, 0.06300007022218779, 0.03715629136422649, 0.031486954758292995, 0.028387527127051726, 0.08240234121331014, 0.0708450164529495, 0.02889593168220017, 0.051336354881641455, 0.03168127870594617, 0.01392905525790411, 0.08338944957358763, 0.02974242903292179, 0.10657386839739047, 0.060104091244284064, 0.02659051115188049, 0.018088992437697016, 0.06681565922917798, 0.06567555712535977, 0.019467826750769746, 0.01933038656716235, 0.03909583865606692, 0.06233843814698048, 0.013892640854464844, 0.01915628985443618, 0.04061253617692273, 0.05299046104482841, 0.02329689872567542, 0.05479831794218626, 0.11093535154941492, 0.05966207179881167, 0.15848079754505306, 0.10472143068909645, 0.175730075861793, 0.11854432450491004, 0.16970027441857383, 0.1333866620552726, 0.1293816027464345, 0.24179114901926368, 0.09771183104021475, 0.10107491034432314, 0.10798641291330568, 0.13644055521581322, 0.1291005068924278, 0.09156241023447365, 0.11219808613532223, 0.1672398767550476, 0.12394384219078347, 0.270350772771053, 0.17628566245548427, 0.09834031137870625, 0.12129953291150741, 0.12811079359380528, 0.14450305461650714, 0.1013553085795138, 0.253049410530366, 0.11215121950954199, 0.15965855622198433, 0.07128548109903932, 0.12585974094690755, 0.1278928990359418, 0.09899999160552397, 0.12789502157829702, 0.08277725937659852, 0.08375299061299302, 0.13017396413488314, 0.13439052068861201, 0.18890825856942683, 0.2035016129957512, 0.09102796000661328, 0.13492957223206758, 0.10935491096461192, 0.14675404789159074, 0.0763758720131591, 0.18701855762628838, 0.1859330479055643, 0.10964611486997455, 0.1525310886790976, 0.12521251395810395, 0.16436432168120518, 0.11587109373067506, 0.2517220051959157, 0.12070226730429567, 0.2104282405343838, 0.12278986192541197, 0.1835953866248019, 0.08845397664117627, 0.14186451182467863, 0.13870576804038137, 0.0990425908821635, 0.1811912437551655, 0.164606484468095, 0.11273090363829397, 0.1507507506175898, 0.11014275267370977, 0.09589110530214384, 0.1715660039917566, 0.1426244858885184, 0.25921205640770495, 0.08892880272469483, 0.09593923357897438, 0.09665093093644828, 0.171704770764336, 0.1890360563993454, 0.17197620385559276, 0.160907486861106, 0.16126561764394864, 0.14903947681887075, 0.11526147136464715, 0.11595536459935829, 0.09423859475646168, 0.0646731308370363, 0.22099584457464516, 0.2199702855432406, 0.1440232413006015, 0.1400609000120312, 0.08661603307700716, 0.18470011797035113, 0.1319241858436726, 0.11914210961549543, 0.19029598566703498, 0.14976094826124609, 0.06632366726989858, 0.19714719615876675, 0.11815841513453051, 0.11912213842151687, 0.1486704364651814, 0.10182619385886937, 0.21097900316817686, 0.20575930044287816, 0.19609353941632435, 0.10754721733974293, 0.07063501834636554, 0.08258828631369397, 0.19604206405347213, 0.16185523913009092, 0.12093220691895112, 0.11990191298536956, 0.11913369366084225, 0.0968694340554066, 0.1463642719318159, 0.08499210263835266, 0.12167779816081747, 0.14918193948687986, 0.11632348468992859, 0.19228292279876769, 0.20022872689878568, 0.11151822691317648, 0.13132182910339907, 0.16170971881365404, 0.18341471819439903, 0.12150699287303723, 0.1485072827199474, 0.11474621307570487, 0.08733927083085291, 0.23760003328789026, 0.1060283750121016, 0.1845453356509097, 0.0692046845506411, 0.13561754312831908, 0.0835429182916414, 0.2075327216880396, 0.1612821823800914, 0.1179421458800789, 0.07134889761800878, 0.13518185791326687, 0.19277751969639212, 0.14514851529384032, 0.20206579472869635, 0.06793898879550397, 0.09866005086223595, 0.080370927171316, 0.11502333843964152, 0.13892808579839766, 0.09058074923814274, 0.1243516820250079, 0.2092048100894317, 0.10301771937520243, 0.11790063013904728, 0.1405627402709797, 0.19749570870772004, 0.20255866984371096, 0.12235586138558574, 0.1882788579678163, 0.18722808075835928, 0.09778835388715379, 0.1435877342009917, 0.23582799243740737, 0.2338216407224536, 0.22926270175958052, 0.17778676003217697, 0.0832006917335093, 0.09741357673192397, 0.12254138346179388, 0.2066320215817541, 0.11266652974882163, 0.1443803627626039, 0.10768065549200401, 0.21350122173316777, 0.10883649112656713, 0.06674387870589271, 0.11410694190999493, 0.11167946591740474, 0.14109772484516725, 0.08057955230469815, 0.1988694240571931, 0.11271502167801373], [0.031193368558888324, 0.03628762235166505, 0.06446416431572288, 0.051623695908347145, 0.08829723505186848, 0.0796989792434033, 0.05160929082194343, 0.02991494311572751, 0.11857489356771111, 0.08516864472767338, 0.034575550744193606, 0.048446483779116534, 0.025722168684296776, 0.027095921141153667, 0.02052614789135987, 0.01574168880324578, 0.005831088155900943, 0.06848560282378457, 0.038997949377517216, 0.01978461990802316, 0.04499104790738784, 0.012456455224310048, 0.07024221442406997, 0.03436997583776247, 0.06042202359822113, 0.015427428224938922, 0.04850590383284725, 0.056899835253716446, 0.03254821109294426, 0.03458410399616696, 0.00887640162545722, 0.03374102794623468, 0.02021580956352409, 0.06903799076098949, 0.041411194688407704, 0.057176099726348184, 0.05085861586849205, 0.09850786605966277, 0.012817333808925468, 0.036397200456121936, 0.051784964598482475, 0.06113580267992802, 0.0177523690945236, 0.03458115766989067, 0.005760740905316197, 0.028774020938726608, 0.020490387505560648, 0.031917879095999524, 0.04192516906186938, 0.01808648397854995, 0.04638947306375485, 0.0745289187761955, 0.03831653535598889, 0.051101940116495825, 0.022787002453696914, 0.04793915162736084, 0.028456665604608133, 0.006767531949662953, 0.013849965507688466, 0.020085154465050437, 0.02930061182269128, 0.06944483611732721, 0.026329846623411868, 0.0778534212440718, 0.0357582150172675, 0.04344687236880418, 0.03072407333092997, 0.02339033511816524, 0.027007522076019086, 0.02093633847835008, 0.04289605036319699, 0.051150435756426305, 0.04959093486831989, 0.029464433500834275, 0.04973780960426666, 0.04210812330711633, 0.03225420558010228, 0.09256019809981808, 0.040485447098035365, 0.0355400384432869, 0.025880589382722974, 0.04039217768877279, 0.05060607785708271, 0.08436924777925014, 0.02374929525103653, 0.03981788897363003, 0.08162322716088966, 0.037115499217179604, 0.013472477658069693, 0.03471507821814157, 0.017644410727370996, 0.03554399037966505, 0.04200998169835657, 0.0056657654840819305, 0.04604938760166988, 0.042630079478840344, 0.06081584797357209, 0.053071087968419306, 0.09664693818194792, 0.004094381883987808, 0.05182289947697427, 0.06113083771197125, 0.02405014707619557, 0.029886468764743768, 0.04489991959417239, 0.026662664604373276, 0.02618973099743016, 0.03499524638755247, 0.039677311360719614, 0.0385906364681432, 0.036389430169947445, 0.04270636483852286, 0.06573354112333618, 0.06811417275457643, 0.013542887063522357, 0.03806307337072212, 0.0852660664531868, 0.036920425700373016, 0.052156457750243135, 0.012834969093091786, 0.01745360641507432, 0.039899907424114645, 0.0404278527275892, 0.12335883686318994, 0.04759010102134198, 0.07073146785842255, 0.0409273923287401, 0.025838483634288423, 0.022123294220364187, 0.028818592472816817, 0.03502496569126379, 0.010289197543897899, 0.0683249872236047, 0.021438811418192927, 0.018990271419170313, 0.04087700421223417, 0.033218377866433, 0.05075275221315678, 0.0661726773250848, 0.0683196289173793, 0.024598369709565304, 0.026403987176308874, 0.03547596883436199, 0.045039161341264844, 0.029001478069403674, 0.07572716815047897, 0.08394447213504463, 0.052345486474223435, 0.03086835797148524, 0.09717345485114492, 0.013055908311798703, 0.007879840159148443, 0.0974084113840945, 0.035739019367611036, 0.04926444926240947, 0.0682874271296896, 0.03504547494230792, 0.03681229107314721, 0.030860949482303113, 0.0517680287885014, 0.014915799038135447, 0.026316506518924143, 0.023128703942347784, 0.022517114884976763, 0.023333182325586677, 0.01789068501238944, 0.013306702276167925, 0.023441957055183593, 0.026974563297699206, 0.0159135163994506, 0.02160487994842697, 0.017912606199388392, 0.024787708280200604, 0.03254746523452923, 0.061399636178975925, 0.07402764254948124, 0.042441855985089205, 0.03880138785461895, 0.011463826213002903, 0.02435897884424776, 0.022031004446034785, 0.019905456392734777, 0.02941937214927748, 0.047191404446493834, 0.04751586769998539, 0.019265574810560793, 0.048513321598875336, 0.008501264528604224, 0.0161676797142718, 0.06491409876616672, 0.04389083624118939, 0.02494723848940339, 0.006899558165969211, 0.022189566152519546, 0.035962680412922055, 0.02686696116143139, 0.0612567801726982, 0.03844348342681769, 0.0319039860914927, 0.018435835154377855, 0.047824408175074495, 0.025993045164796058, 0.01724371591990348, 0.03019682008016389, 0.04128102940740064, 0.03685347284772433, 0.004857414060097653, 0.02820274905388942, 0.010434880205139052, 0.006301569892457337, 0.015054413670441136, 0.13372874760534614, 0.06880754648591392, 0.04409351677168161, 0.03196166951966006, 0.05788578215287998, 0.010848953152162721, 0.019402322941459715, 0.02892339300160529, 0.005132712349222857, 0.015040783200674923, 0.07280361838638783, 0.01867532806500094, 0.0802396857761778, 0.05006023566238582, 0.00410107188145048, 0.06463706988142803, 0.040541805792599916, 0.07020072094746865, 0.012119423699914478, 0.05383977113524452, 0.0804267218336463, 0.0124498927834793, 0.019646285436465405, 0.053898868354735896, 0.030655285518150777, 0.04216802946757525, 0.0707384514680598, 0.06184501755342353, 0.008446695337624988, 0.03418263549974654, 0.06626014685025439, 0.04198619586532004, 0.02236485215689754, 0.021794177700940054, 0.04865428141783923, 0.03174159304762725, 0.04517482593655586, 0.009923924517352134, 0.07411190599668771, 0.02361043014388997, 0.012702886288025184, 0.02626307003083639, 0.04449746775208041, 0.03815407551883254, 0.030494402744807303, 0.02643564348545624, 0.02258795288071269, 0.018939072506327648, 0.034379096832708456, 0.030443890318565536, 0.015372504658444086, 0.04385563988762442, 0.04572461635689251, 0.03526933636749163, 0.047232074139174074, 0.021025926835136488, 0.0712081789970398, 0.020888854014629032, 0.0842990777164232, 0.05236945042270236, 0.03421332330617588, 0.023354391050816048, 0.029312089136510622, 0.030268426198745146, 0.009283016916015185, 0.04942952888086438, 0.06278659886447713, 0.04107158420083579, 0.040385791508015245, 0.00755973145714961, 0.0381954279873753, 0.0295207977615064, 0.08068917493801564, 0.02901332831243053, 0.020353997460915707, 0.0016262379381259962, 0.03326793848827947, 0.02781119750579819, 0.040836924526956864, 0.057959688929258846, 0.04068888461915776, 0.04063108244736213, 0.004516870785664651, 0.037391103178379126, 0.023834590283513535, 0.055003406741889194, 0.033134893674287014, 0.05440056760562584, 0.055221802249434404, 0.05911082305829041, 0.021591537988570053, 0.026592262620397378, 0.07343704142840579, 0.029210980792413466, 0.035046695775236, 0.02558181186032016, 0.06624548943364061, 0.04757744369271677, 0.051826276248903014, 0.030685117999382783, 0.0038422300212914706, 0.056623095806571655, 0.03722950423252769, 0.03633958382124547, 0.04115032235858962, 0.038857817053212784, 0.031159296559053473, 0.01574817517393967, 0.05833551622345112, 0.029088005067023914, 0.013869958966097329, 0.031651206882088445, 0.024108322177198716, 0.049762248527258635, 0.048126324982149526, 0.005937861405982403, 0.11214880752959289, 0.060571685098693706, 0.020586939062923193, 0.05678514746250585, 0.04487050086027011, 0.019697467650985345, 0.05481886430061422, 0.009646174821682507, 0.026744393617263995, 0.03857299561786931, 0.02357972934987629, 0.033314812535536475, 0.018327678262721747, 0.031402732129208744, 0.025657195510575548, 0.047922134181135334, 0.020019268449686933, 0.020194470962451305, 0.07659827140741982, 0.04165847829426639, 0.09381807161844335, 0.029927696923550684, 0.02966786916658748, 0.027788057341240346, 0.042066908135893755, 0.16939845780143514, 0.1190702548774425, 0.12225157479406334, 0.13232341676484793, 0.1656787542742677, 0.22030535037629306, 0.11678239912725985, 0.1617267436813563, 0.2443676779512316, 0.10633376135956496, 0.1533698639832437, 0.15477501670829952, 0.14604351570596918, 0.09690680119092576, 0.20853307738434523, 0.07593514019390568, 0.1891249360051006, 0.149263798375614, 0.14661583030829206, 0.20292484550736845, 0.1968670799396932, 0.15851842443225905, 0.13179383502574638, 0.1961561618372798, 0.1082025485811755, 0.1264340296620503, 0.10843517477042042, 0.19755321030970663, 0.1976827744510956, 0.20906760182697326, 0.17214339488418773, 0.22509900096338242, 0.1652887259842828, 0.21468674327479675, 0.1783435489051044, 0.16943544644163921, 0.155270756513346, 0.26879223296418786, 0.1208721894363407, 0.3345887898467481, 0.14264250523410738, 0.12889004865428433, 0.12820362142520025, 0.1520198825164698, 0.05135929095558822, 0.2781712281284854, 0.08489696672768332, 0.16285057790810242, 0.12015518572297879, 0.11635742310318165, 0.18107205483829603, 0.1524728152435273, 0.1631323416950181, 0.13240692322142422, 0.15285885077901185, 0.20815478987060487, 0.09213423501932994, 0.09308770182542503, 0.19547056581359357, 0.12138480567955412, 0.12820056377677247, 0.15640354104107246, 0.141897359280847, 0.2245626359945163, 0.13879764592275023, 0.15255801379680634, 0.08727736829314381, 0.08239338349085301, 0.07608000742038712, 0.14835267851594836, 0.15951140318065882, 0.1517179619986564, 0.1966774760512635, 0.19941224571084604, 0.16315925196977332, 0.07610003056470305, 0.11274660748313181, 0.19522755697835237, 0.06725768238538876, 0.12078846033546142, 0.11108165112091228, 0.151318701391574, 0.18524307321058586, 0.22852298832731321, 0.11163852163008414, 0.09741594418301247, 0.11830245115561411, 0.12435499942512251, 0.11925570273888297, 0.1279286853969097, 0.1409072006936185, 0.13495844177668914, 0.11331361572956666, 0.15037538716569543, 0.1419796486152336, 0.14842595817754045, 0.11906756088137627, 0.11672330190776847, 0.16865577577846125, 0.08855890890117735, 0.24803213600534946, 0.19635916891274974, 0.2369844217901118, 0.07962900956044905, 0.07588152002426796, 0.16036144428653643, 0.1101300619484391, 0.17750204249750823, 0.10813514672918245, 0.1442378555657342, 0.08426245272858068, 0.09297790107666515, 0.2944855042733252, 0.15591169008985162, 0.14590776205295697, 0.1577766181435436, 0.13725902535952628, 0.1080678116704803, 0.11824693850940093, 0.07888810127042234, 0.1369176819571294, 0.15706835692981258, 0.10856995620997623, 0.24391216255025938, 0.18790561705827713, 0.15761398390168324, 0.19129389227600768, 0.1767707895487547, 0.05806237990327645, 0.16828811581945047, 0.16993048862786964, 0.11735380830941722, 0.11317091557430103, 0.16940901114139706, 0.14499708748189732, 0.1309732423396781, 0.21413626265712082, 0.14795448660152033, 0.13063976570265368, 0.16229089465923607, 0.12951777200214565, 0.1449321347172372, 0.12485684710554779, 0.08489888146868907, 0.0914837203163188, 0.19909518538042903, 0.1676160268834792, 0.1570031518349424, 0.11035869538318366, 0.15619309764588252, 0.07933336761198007, 0.22457422834122553, 0.18215547170257196, 0.12082669578376226, 0.10196231858571991, 0.17911642149556428, 0.1257772883400321, 0.18334630702156574, 0.131391427712515, 0.17035024735378101, 0.10818377966643311, 0.05279897952277679, 0.08807100617559627, 0.12722823157673702, 0.08487325510941446, 0.16683234862284735, 0.11477762076538056, 0.09994419640861452, 0.11815856356406584, 0.1577988380449824, 0.08391609240788966, 0.1983681775163859, 0.1570475471089594, 0.10736624462879263, 0.12500658282078803, 0.10205561397015117], [0.05577765972702764, 0.07143608512706123, 0.012825514131691307, 0.022110831705504097, 0.012760580848407699, 0.026653834902390372, 0.03488810623821337, 0.01460417865018826, 0.073327841819264, 0.02634534081153106, 0.028270471884752624, 0.08223085314966738, 0.0331725873547839, 0.05395507861976512, 0.039001081240712665, 0.019166175261489116, 0.05712048689019866, 0.04538342138403095, 0.029286165918165352, 0.009717736411403166, 0.05220725404797122, 0.05698241031495854, 0.056049630875349976, 0.010059639207611326, 0.024566422107454855, 0.03454800964391325, 0.03204588472726755, 0.025057718303287402, 0.030082438424869906, 0.021343447297113016, 0.04384089712402783, 0.044719195502693765, 0.05211427778704092, 0.05070849794719834, 0.02943701299955137, 0.06876782674225979, 0.050120349624194205, 0.04274852995877154, 0.021315147350833286, 0.016335956133843865, 0.05820037855301052, 0.07508266484364867, 0.0156346544099506, 0.024307126841449644, 0.047334427435998805, 0.052603301155613735, 0.03807101064012386, 0.06330658463411964, 0.042654741046135314, 0.10134085154277273, 0.049596964818192646, 0.03217601290089078, 0.010853141648112796, 0.05916549707762897, 0.03708922347868793, 0.03046539961360395, 0.023223988282552455, 0.03528783068759367, 0.03433729536482133, 0.02361443588597467, 0.025916219892678782, 0.05004160033422522, 0.034156697438447736, 0.041658533955342136, 0.011709194150171243, 0.034219271619804204, 0.1171563524985686, 0.05247598201094661, 0.037906098004896194, 0.008107673002086813, 0.01519930594440666, 0.0951289567456115, 0.026185662172792945, 0.026927327453449834, 0.05538083707506303, 0.029148974354029633, 0.038091041205916554, 0.03455126396147534, 0.005583267884503584, 0.10771535089588724, 0.011101320469606435, 0.053828464515390806, 0.0314544412685791, 0.06400565805961378, 0.03640308939793613, 0.04607235336152371, 0.021356264187488705, 0.08669519796967506, 0.0301647481683176, 0.0762419292004779, 0.005995327755954349, 0.048409120354335755, 0.07403698618873022, 0.06599392363568768, 0.0787482138548512, 0.04232153900375124, 0.011364463771315059, 0.053748316277051345, 0.027402426276239567, 0.02279514752444811, 0.044655367091763765, 0.008158911805367097, 0.037540449266089126, 0.019780163311224896, 0.02087955675960984, 0.030888690962456167, 0.03191163021256216, 0.031401964006363414, 0.06269848367082886, 0.06722361038555391, 0.051180526133975945, 0.007704299969191197, 0.027623836758721154, 0.023719416385574732, 0.025119646816165186, 0.014072051344555803, 0.04044818015245255, 0.04800847564183641, 0.03517546952934936, 0.05102333925606217, 0.032133510103449225, 0.05673995809047483, 0.02548954991652863, 0.013157980520190904, 0.041576077637728304, 0.0041763159151742, 0.0355803630372975, 0.02355262426135596, 0.08212628454202786, 0.039231570044648834, 0.025313974474556744, 0.012068735013599508, 0.02598080158350058, 0.03333159249450546, 0.0378229255147744, 0.016982810193439946, 0.020743944114656188, 0.04298934945836663, 0.12235360525664873, 0.03915440152923111, 0.001876725766578602, 0.06584363873116672, 0.038517078501172364, 0.01659474117332138, 0.042083914449904114, 0.04796192813955713, 0.033453712894697674, 0.04236935928929597, 0.05005953804356977, 0.05353218060918152, 0.03956793363613542, 0.03363739073392935, 0.052844439778709784, 0.06654452299699187, 0.050258760165888816, 0.10153824056033045, 0.01945557389262831, 0.02642716444825055, 0.0313188620202709, 0.023936687539389823, 0.03496647332212888, 0.04438488766027149, 0.03831087647995446, 0.04352002957602963, 0.005345227264115238, 0.026508635564823635, 0.03757331156521104, 0.027545013253984507, 0.03454796511505265, 0.03477421254501678, 0.03810360576608218, 0.031024318450363353, 0.018775555108732078, 0.06990253343246877, 0.03712354780873284, 0.13895416486775503, 0.03339874943776522, 0.0403967567399377, 0.0842296943301335, 0.014095859442022629, 0.019865115100401454, 0.03220521270122845, 0.06273027727729641, 0.05562584970903117, 0.0431270178523846, 0.06169783853692934, 0.08248933576396666, 0.06245536351343617, 0.037287785089574754, 0.015620032245351467, 0.03309001600428019, 0.07073937173117884, 0.04972256960172672, 0.020134047153987922, 0.03029842751857359, 0.018524325132602826, 0.057895652716979384, 0.023079173006408382, 0.017473696352681145, 0.049314881907776, 0.03522087041346822, 0.030751109770790208, 0.11070561231463216, 0.02125542116118595, 0.017904770975292195, 0.02539840676035965, 0.013361549772525905, 0.03817322663962841, 0.023085013708623592, 0.03321684533148073, 0.025665715365903452, 0.09671923820860684, 0.01572330394992605, 0.022805274129495956, 0.02308001905475976, 0.0447260715009179, 0.03865459104417823, 0.07385179807897657, 0.07249725982546806, 0.035381252237129956, 0.01814497449231567, 0.032771241312730126, 0.03395578321942594, 0.05168201387277804, 0.0455713777046185, 0.029061924142297357, 0.010946227375825401, 0.053987024366506375, 0.016885998884390574, 0.020370784841361456, 0.07491447191569023, 0.037608567290590145, 0.016230938526859973, 0.002177346946155012, 0.027813826563942712, 0.022709069526172243, 0.029864606949558947, 0.07148293690988794, 0.012633726473723073, 0.010513908728171373, 0.008484753598168027, 0.05770421943452675, 0.075918382499367, 0.05284427650622092, 0.0449527679302264, 0.04077572331880219, 0.010339547625335399, 0.034335202508373186, 0.00870067404321162, 0.015830677875783294, 0.05326921171217691, 0.025441690668230876, 0.016973516649159137, 0.024537350327591412, 0.0630047605955042, 0.03250685491366312, 0.048181499951169826, 0.0770118332002312, 0.017421840639144648, 0.03993875143351033, 0.046724433996132575, 0.032220289431279525, 0.006206630650922307, 0.09555362106766552, 0.05762744796811603, 0.01585790356330108, 0.008427765005762922, 0.10773080983199179, 0.08974287193268538, 0.07221777443191968, 0.04664399260946084, 0.03683638118673116, 0.03661014488898218, 0.05285033614200074, 0.057593784149503335, 0.022741625689377543, 0.015697642338636797, 0.03185602108715102, 0.026281059690518305, 0.060353530789143406, 0.03532099355652463, 0.029943031549919397, 0.003629530033322226, 0.02444712557917228, 0.05518584519450087, 0.00871927597472677, 0.020351182865852024, 0.006633210641666665, 0.01121085033446434, 0.09742063455632888, 0.04094548959983513, 0.02209087906521745, 0.03419277323700953, 0.020245070591045078, 0.01563075256854063, 0.05096302120364271, 0.07904818252427503, 0.014113662637100788, 0.009091071551665664, 0.03727424089447595, 0.04100820849998854, 0.06954739350476302, 0.04685322259319946, 0.05139767854416277, 0.03217284021957312, 0.044069794021197595, 0.052263768593547866, 0.041809954345808364, 0.03299475021776743, 0.029801396376569755, 0.04082044142705854, 0.04390617643366568, 0.01409787530064932, 0.02191350762586808, 0.007079746055751457, 0.0758239442075137, 0.05393315186665859, 0.022845081075502094, 0.024624456200399436, 0.023983743412827607, 0.04255869971530046, 0.11166431868332438, 0.02528740187699441, 0.05600296091870405, 0.08922102337237448, 0.015467323300981661, 0.023975538970262278, 0.05411663674749434, 0.03416456049308181, 0.06970846923650242, 0.08296245490782894, 0.0791372254025191, 0.03212931696907617, 0.027360758394934237, 0.006899707059346838, 0.02941830716736149, 0.037300375624909066, 0.027784086851170287, 0.11497932908241637, 0.07638517854502425, 0.026193118901574053, 0.07515422272263095, 0.004982974314771127, 0.054091281272121705, 0.024886560495360754, 0.00901474815691472, 0.04174567693553399, 0.07385353470453992, 0.021611453521472868, 0.03434775222558528, 0.030334271395986434, 0.06716966367093846, 0.1260168684530072, 0.22342792188283056, 0.19765498844208196, 0.09770178978214972, 0.05564674116612878, 0.10048355965409428, 0.15102734905667603, 0.14235256297979504, 0.1672942316508852, 0.15420929237734526, 0.22888600244186819, 0.27364614594262093, 0.09213097699102946, 0.13936529983766377, 0.11455329178716056, 0.19030564842978492, 0.1138256530975923, 0.06746854880475439, 0.11001193430274725, 0.10271548715536483, 0.17953904491150752, 0.20236326236044988, 0.12336904139374383, 0.07612218367285095, 0.15824976697331294, 0.12474867166019976, 0.17500634829048067, 0.17959806049475446, 0.06870665893075056, 0.13964123034384102, 0.18560482567409053, 0.27814237342681736, 0.12399372935760766, 0.11288142603007145, 0.18539473850978538, 0.26369507366325706, 0.1703884531161748, 0.17274971469305456, 0.1316099605173804, 0.10030124365584925, 0.13189924968173727, 0.14122929278528318, 0.18370362144196406, 0.19955206633312628, 0.17798955930629745, 0.11992354659014381, 0.10975659839459695, 0.12484264239901677, 0.10526072714128532, 0.2300613120314665, 0.12930609664181247, 0.17296848498517647, 0.17108017927967012, 0.16460272920085117, 0.1739038433879614, 0.15086659986991435, 0.18563939491286874, 0.08623311456176452, 0.11027569358702749, 0.0967033562483266, 0.13496866857167333, 0.11622635982348584, 0.10167366766836494, 0.1647278998279944, 0.11528888629982248, 0.106298739410704, 0.20970507699530572, 0.1751439573126845, 0.08836401349981315, 0.10635015540174209, 0.11004597661667503, 0.19498054054565728, 0.14108072966337204, 0.11340002398355864, 0.18755297816824168, 0.11726896598702297, 0.08004310569958761, 0.15648042754037306, 0.11981387942796573, 0.21357301709940657, 0.17147586273495108, 0.08629880947410129, 0.11775061982916668, 0.1592012299806811, 0.17197638197103515, 0.2562116424087435, 0.098697930079652, 0.2605448052054271, 0.1320307730929926, 0.12198210839414969, 0.24723794893361628, 0.14422601088881493, 0.1556342010735534, 0.15776754909893498, 0.1871084317099303, 0.0843695223738905, 0.15206294192466885, 0.144624455133453, 0.10486692874110304, 0.12232157416292466, 0.2166973103885539, 0.13173060404369608, 0.1301950856577605, 0.10267961173667572, 0.1258378179045394, 0.13379224576056004, 0.0772123911883682, 0.10290882404660806, 0.16790875961305574, 0.09855825788690709, 0.11863282561535016, 0.1207719549711328, 0.0715053423482459, 0.19381357269594446, 0.2079600651632063, 0.09931412787409499, 0.12959038373082876, 0.1510362102999352, 0.15238576132105663, 0.11838033955427818, 0.23608461226103827, 0.06336764112347737, 0.10216222348390147, 0.15212094818707556, 0.1837842632085085, 0.2752720133867115, 0.12367703267955221, 0.1418905463651754, 0.13637906085932627, 0.11646118276985362, 0.11370037856977433, 0.12879707239335403, 0.14405601454200223, 0.07080589784891345, 0.14452080678893253, 0.15840869047679007, 0.16438918362837285, 0.10728048204327933, 0.15410531748784706, 0.1983496980392374, 0.1798969678930007, 0.07752428617095575, 0.1385932881385088, 0.08743231388507411, 0.12549540580948815, 0.22231798066059127, 0.1304905049619265, 0.113310840097256, 0.13067908468656242, 0.16184628882911056, 0.20893765176879242, 0.1594888122053817, 0.1780861572478898, 0.1502849193639122, 0.14101271925028414, 0.21349644230213016, 0.1248339147423394, 0.11166655254783109, 0.09055291127879173, 0.10876291460590437, 0.09472545105381869, 0.10955607009236701, 0.1911492328508757, 0.08702007311512716, 0.10604161492665298, 0.2162254083668813, 0.10434119874844328, 0.11210724725970067, 0.11134693922940642, 0.14090185723034665, 0.13812374614644796, 0.15598611265886575, 0.129152204899583, 0.22022815217496827, 0.18054599087918177, 0.2760058193234727], [0.051565997637226246, 0.054270617547445, 0.05586417559243273, 0.019501577771734446, 0.03855958872009069, 0.03502450184896588, 0.09270125810871832, 0.026261470702593215, 0.02363011004490545, 0.004207418860460166, 0.048891111873672344, 0.01779257680027513, 0.02150665855879197, 0.04617041704477742, 0.07025026672636159, 0.012979932798771188, 0.02692036981898127, 0.04363804589956999, 0.011427261524659116, 0.028930653061252087, 0.030322222628456075, 0.020191890143905766, 0.08214841538574547, 0.022001591278240085, 0.0048914299350144574, 0.0223536846897332, 0.038525702257175, 0.04285063834686298, 0.026289186207577586, 0.04379074649477843, 0.08350157324457541, 0.10654860569047742, 0.06459087118855678, 0.028903106394864153, 0.02155083118850598, 0.04624083201633766, 0.009003486993606202, 0.023264242372533772, 0.05194642624701373, 0.007203212526292191, 0.032581912018940784, 0.04274135339073837, 0.051626278582261875, 0.03924639073375147, 0.026424824827699922, 0.03617300506448373, 0.04101951883058064, 0.04181518277619034, 0.025078398248297162, 0.0860939544509165, 0.0876382079150062, 0.024823778512654826, 0.033544878315296955, 0.07591700210468844, 0.032077759969979525, 0.03524807754729409, 0.01520708550742711, 0.043407115517766215, 0.09583172606653534, 0.04372979761683382, 0.05756848433520645, 0.03055850203963928, 0.05354711633117404, 0.04615614554495551, 0.021423376601887867, 0.04114049632335082, 0.04981259953638073, 0.02145963051589206, 0.05371774350351188, 0.03651816681667697, 0.015359800945589086, 0.0325695144420024, 0.06655256045632996, 0.044964260086999275, 0.05772696626081597, 0.02822392067173496, 0.036131029191892594, 0.031623561881133355, 0.04547128795820754, 0.020046115641889628, 0.056986325143952854, 0.014029719241079874, 0.054598071656073444, 0.04937095487548504, 0.03744841924344655, 0.09935764741385356, 0.017461864663346205, 0.021481681578734424, 0.034317769459448755, 0.04121887082874309, 0.026833011615963187, 0.01744111050356878, 0.04436471237568185, 0.00359390995981812, 0.039140556764323264, 0.04501418807194568, 0.03364464522746857, 0.07685918084462173, 0.034608899150043726, 0.044358363302308135, 0.02338782294827979, 0.015906176558928564, 0.05646153396810405, 0.05156169689144008, 0.04249524608894717, 0.06653327203821391, 0.008300249191961484, 0.0184592629011604, 0.05125110437802505, 0.0446068454766646, 0.008046698148973519, 0.03904180288373027, 0.01779457688826369, 0.05838641642185394, 0.034799430723069236, 0.025038454004970845, 0.1307959877885878, 0.012002964031125885, 0.014536808339471463, 0.027494411770021543, 0.04062558313307818, 0.050136279824073426, 0.023217587258841377, 0.0012831308913519024, 0.09712403523735702, 0.03978652210207656, 0.045542660300270654, 0.022401208116207272, 0.049961871409323066, 0.023412222908518743, 0.05662130351993255, 0.030025333871890325, 0.010819620692927856, 0.04651086615922395, 0.03312150533020031, 0.009662706161179813, 0.07502348598791286, 0.07641994816367514, 0.07637029106263071, 0.050348248332738876, 0.06754099726094864, 0.019676396223076154, 0.04501204326516017, 0.03250767127610743, 0.04359060782007873, 0.05377775727538392, 0.034654377959668636, 0.07043515055556782, 0.017933540329977404, 0.07310431436053477, 0.05308533720381092, 0.03709435914061032, 0.024515892982890364, 0.03300295466033276, 0.02563780319178477, 0.05929975530307274, 0.02794419964629924, 0.01914063610456651, 0.016125249276228715, 0.028307219326961786, 0.014756363452761434, 0.03438384286710061, 0.03496176810585894, 0.04720421762613114, 0.03071193179494003, 0.02194567787228152, 0.019649261448648758, 0.0455136126402067, 0.011396969839552185, 0.04935964825563133, 0.015373344213003293, 0.024409298312093597, 0.06887862196890637, 0.05487301139510237, 0.010679094102670206, 0.021136985524208285, 0.05696229069144465, 0.03656144515844062, 0.046989662732812576, 0.016541978184250183, 0.016318307862093206, 0.034847043207264505, 0.03016895800101338, 0.020010435036965646, 0.04003865193226375, 0.04070429531566333, 0.004224343074383796, 0.03960467365686782, 0.053031794959679246, 0.11291851857095025, 0.0476587274170015, 0.027577747532632202, 0.05473691264342051, 0.011126378158223815, 0.04488332517212257, 0.03109832356130937, 0.023165909660747275, 0.060223050095373765, 0.05227085610385984, 0.013409878429229138, 0.04847711221373174, 0.021347555084503256, 0.004967778377249488, 0.051204545743530616, 0.08411837217863649, 0.045923048091935925, 0.034055754222208634, 0.053556753118755296, 0.062147557764546946, 0.06297886706306599, 0.017100127042795066, 0.02832927038980415, 0.045688369864365086, 0.05067034042440355, 0.03697714062582236, 0.026224235298286658, 0.021096835334901698, 0.020800013371626846, 0.05505388391611632, 0.07526967121521011, 0.018058787027257495, 0.05501371146237943, 0.022411984100472182, 0.02757985708740307, 0.0566871802584501, 0.02524705316318432, 0.04678387260355521, 0.018314412373001687, 0.05719770364521537, 0.05634725806885399, 0.01575306407175958, 0.03448804040090181, 0.046215576730901375, 0.07188199713709764, 0.10431484508444555, 0.03070962557103485, 0.012084477821190376, 0.034411309752613306, 0.015122013119253097, 0.03376612366992049, 0.004229776986903744, 0.023316439474001527, 0.030672252869408112, 0.006483551460405579, 0.02751255356997717, 0.013972391116112703, 0.04626287009159569, 0.03997436710051261, 0.04336640500696376, 0.045129614300094545, 0.041916322661563754, 0.0386464088660432, 0.04607113995007239, 0.04169012718193699, 0.05553036869969219, 0.031563199299853295, 0.056223360224976204, 0.09871312184259295, 0.06102385341364425, 0.013988902046548901, 0.09175537605187856, 0.03231470545870252, 0.013731521521549439, 0.06371916679199785, 0.06617289254791103, 0.06519753238535486, 0.06609293355722912, 0.04457084389287047, 0.06659962746198289, 0.02030707702942891, 0.029152599745430052, 0.04939317477692384, 0.04758210438012611, 0.047281501174438745, 0.045767735136905685, 0.03772649455640931, 0.012139097107137786, 0.015771712387504522, 0.02284257447172422, 0.012393379165587248, 0.11140415139379911, 0.07366108839050867, 0.028674222485278733, 0.06989575020270422, 0.014649242784798844, 0.02747664289927343, 0.040976229356601834, 0.058379310357850045, 0.03303391335066408, 0.05069181446742732, 0.024608013918623328, 0.0423987668909831, 0.051381499724811874, 0.018688575401029084, 0.026720676432887558, 0.017383510567015037, 0.018034769273072015, 0.007523375961682177, 0.07178345476859249, 0.07257633566041477, 0.05782725267636124, 0.025905427210091148, 0.04298513405956328, 0.05996005151246209, 0.041312848989036866, 0.010214078283752315, 0.01139107718699961, 0.010976116445817752, 0.03232489885704126, 0.04840251895075198, 0.026064326593768783, 0.04300214408431202, 0.04115596639167052, 0.037440860469359905, 0.023184891942946706, 0.015291898143914295, 0.04731509819976054, 0.008327158539032098, 0.0530131484993035, 0.09426914897630922, 0.02430889871902764, 0.07360001705819741, 0.022592561617784668, 0.009450661582377506, 0.01145655223808717, 0.006538661491504172, 0.03278680786024779, 0.03360797942150384, 0.0499830448825378, 0.015194540428637993, 0.04017874343844596, 0.03786750261497218, 0.03702953254105523, 0.01110636985686142, 0.04831285266845953, 0.03511615337629337, 0.0679134440724738, 0.026494072772038635, 0.06191255299199838, 0.04505360724579077, 0.0318686413083924, 0.0826394945033826, 0.022156065606395714, 0.03632275933341589, 0.019615669989434537, 0.07135873849620111, 0.01096854561183136, 0.020560375742206816, 0.02142707620805595, 0.06856920575955883, 0.036661405029008165, 0.040731097979005426, 0.1586165660410188, 0.15902787912636995, 0.1646867551608011, 0.2247191994683817, 0.14411459967959672, 0.15073387417942286, 0.16944732080446556, 0.12155961856478825, 0.11683527714922093, 0.14868038124404848, 0.15642020967788994, 0.06153876660391688, 0.2140129473991692, 0.25211249361746013, 0.13302053092047572, 0.10002955823438242, 0.1594895840389654, 0.11441476250183769, 0.08505493286065757, 0.12711232295259833, 0.1010716226301156, 0.08040287662879564, 0.1912047603400424, 0.10100126703036949, 0.1410772415692918, 0.07760991516988724, 0.11000426791724749, 0.1214350268128328, 0.176620846032165, 0.16756904893554747, 0.1291244337335229, 0.14651121717179194, 0.1399877539370209, 0.11387693550204858, 0.1855059716035612, 0.12034323110128753, 0.15892522525973618, 0.11997583831544034, 0.14884402480674908, 0.10218756782705896, 0.11290302252746187, 0.11154172330861911, 0.12887379562016577, 0.1384484357549809, 0.10418341073091142, 0.1457084805588238, 0.09898681106278673, 0.12940270942635834, 0.15466606942936778, 0.19612188945757225, 0.218384048785083, 0.08297779510030523, 0.09263440544600599, 0.1377839909400791, 0.17610975861316547, 0.09846148925134912, 0.1286508544581011, 0.16083526104921475, 0.14084814058151096, 0.0896068659494631, 0.10030711404397152, 0.17034797638189048, 0.13065877952612936, 0.20983547234209254, 0.08964931679656729, 0.09918143186951056, 0.0964877697697375, 0.11612513088039123, 0.09371923239086755, 0.13267350266687572, 0.13805675989715382, 0.11159910616697744, 0.14103732886724174, 0.1027129267458804, 0.12494318856624886, 0.23941462888615206, 0.16515853843884543, 0.14860609226161614, 0.1965658867266029, 0.08291493519209325, 0.19957793760113418, 0.24971936421934515, 0.19200915936380625, 0.09669378996477462, 0.13258104590931907, 0.2133972616866231, 0.13975139474496245, 0.11606454194406979, 0.10621282097417861, 0.12184033592347987, 0.16463612584630027, 0.09860613383352757, 0.14806879218667746, 0.09957394635421224, 0.06233066786080599, 0.1433605924830772, 0.13140803697751835, 0.17072271642973647, 0.20414254657225683, 0.15841529559111223, 0.11881421392899938, 0.0640495189873036, 0.1671684079337865, 0.11533912969753146, 0.14133059594314545, 0.21445692982524633, 0.1232657567015849, 0.23756150098051876, 0.19095287541858852, 0.0955630315002054, 0.09332167130196467, 0.20559769036481157, 0.07503882618038915, 0.17838144296547398, 0.11992134983302094, 0.09556729884934612, 0.204832847812213, 0.09647830738686025, 0.10129490518011153, 0.16611344501143321, 0.15418423747178167, 0.21590851130895317, 0.14043399249203503, 0.14580102637410164, 0.18920410831924528, 0.0867693533655256, 0.20333020656835288, 0.2070451751933433, 0.226101360458415, 0.16938251646934077, 0.1455841411370784, 0.10062199246021919, 0.07052722881780937, 0.16493243572767824, 0.08311679936014116, 0.13362103229155764, 0.22147406969452277, 0.1434363509179093, 0.1814834718243219, 0.08285338888526894, 0.17671165522187948, 0.1320293778553605, 0.17141689168056473, 0.11829988332465291, 0.1615725105511956, 0.1983764153555967, 0.11900462675839663, 0.09906507053528912, 0.10510854976018891, 0.1598816309706308, 0.18732562864897773, 0.09276656710426323, 0.19142565317451954, 0.17097765899961814, 0.1786120282486081, 0.20097845932468772, 0.11257911217398942, 0.11168538825586438, 0.1011188529082574, 0.15690541098592803, 0.15885948581853881, 0.18437545804772526, 0.1738192088669166, 0.20571361383190379, 0.08242884330684319, 0.17248145799385384, 0.0720111011469271, 0.12621416099136695, 0.0663859854103066, 0.20354933309135959, 0.09629783933633007, 0.14405409980099648, 0.14897488028509542, 0.16671949764713645, 0.0980891240760684, 0.11589994101086631], [0.030191181613190565, 0.08451239322312176, 0.036562495297403075, 0.03416600768105127, 0.015248963045451092, 0.13377063442021608, 0.03076220858929446, 0.038985117644187994, 0.04024899513751734, 0.0338128196017351, 0.04714623362815473, 0.05041321594035253, 0.019057708523178007, 0.07059890544041991, 0.05413767292338889, 0.027621486005955376, 0.012388602517603431, 0.05076539840956684, 0.02406706062174635, 0.07919268609839492, 0.0708152266452089, 0.005578644304478075, 0.04859034168475773, 0.052420398860704154, 0.027265073294984177, 0.03384147392353043, 0.013458523426379543, 0.014916139498382108, 0.0037984286973369308, 0.023838616434659343, 0.028705728509521578, 0.01576211827341467, 0.08789911735220812, 0.04053754957567435, 0.050941038789460436, 0.011389554856577888, 0.046088906965451315, 0.050664095251704566, 0.02354129723244114, 0.028627209285332356, 0.038018436898710206, 0.12452224240405485, 0.030524814101227093, 0.0022358042951964308, 0.026414351268613245, 0.03329091166961007, 0.02618738952151034, 0.039212430056068115, 0.051829434087267146, 0.042854523489950225, 0.04242074930516537, 0.02630312188557582, 0.054654935011058114, 0.04176994516456034, 0.09064884870895185, 0.05364970340451691, 0.043132925347890705, 0.07456265680957586, 0.06122511644207407, 0.05017960640543606, 0.02062839728750987, 0.03253013237554114, 0.07515573670389131, 0.06454233473050408, 0.02229521458502859, 0.10140515863895416, 0.018464222303009592, 0.02721712127822684, 0.016881512601685245, 0.07100268572685309, 0.01981715195142897, 0.04855939783737995, 0.011568456047825748, 0.022459281171904877, 0.00600413612119155, 0.047002375722513534, 0.02354686334001599, 0.0408200072706677, 0.023265795316547155, 0.02621743351483019, 0.036270723649067804, 0.03672338178148493, 0.011141191425849684, 0.05015556453145109, 0.05753900251875166, 0.04819439105631318, 0.034006880086963065, 0.01242876569449436, 0.026642439224815462, 0.03350695827975869, 0.03533471215632744, 0.021213851614447776, 0.033645461589912884, 0.04959838232025504, 0.08670929135405459, 0.028729488367389422, 0.0628297176444903, 0.03484608212602325, 0.04895507387118414, 0.042815438282559626, 0.025040890104719438, 0.052420525025809184, 0.017952381604118273, 0.04653525313187856, 0.014841774445812916, 0.03742704167962074, 0.07548856025096029, 0.023028243122098502, 0.0325254494237015, 0.017737234848027583, 0.052195201569702476, 0.05091708597319666, 0.02719592554058181, 0.056236110322060995, 0.006476918051703251, 0.022161062115628738, 0.10296624401235022, 0.016208750166697428, 0.03703549569763709, 0.02345416352909524, 0.028763090958818793, 0.07920326170278713, 0.04343247099313885, 0.029002786104683764, 0.036313976015662774, 0.021834535691596102, 0.051700445110327564, 0.03808661800576374, 0.047037367985467426, 0.051028909074375406, 0.08965339860878885, 0.007893989204603713, 0.04821814720344264, 0.03646368204499595, 0.031693301498307846, 0.010806582085933769, 0.04594222147716209, 0.04488008940825239, 0.012521212247520452, 0.0632043018413242, 0.058744996204040945, 0.026278029872628395, 0.023855086546973325, 0.028703479802061338, 0.046535898800357245, 0.023071593823260628, 0.05663013507728465, 0.010988538142555626, 0.03727882736711763, 0.04865007344051264, 0.07323142941459082, 0.07630550899193622, 0.018041906878352165, 0.02187336856877664, 0.04104724917851854, 0.02548613047110848, 0.03271988840424456, 0.02825805018801475, 0.040622755550430156, 0.04023646397399716, 0.07298258729861118, 0.06219689574209042, 0.03865377097099554, 0.04309992946218699, 0.09557379264151677, 0.02866888458811445, 0.06835880689322948, 0.015719671137048863, 0.017457652975281235, 0.01889024661068106, 0.03988688644312788, 0.029690862756979186, 0.08228885941207409, 0.05920018506003544, 0.02146032256860053, 0.04932189520332031, 0.027510412473930046, 0.0735282216919586, 0.04314284415158909, 0.007578661789011676, 0.004465184838409186, 0.04700795667304192, 0.1020631096616853, 0.02985600360261742, 0.059305885442881845, 0.006248266990951379, 0.0941314063675236, 0.023515702414442785, 0.013427102749119513, 0.051978446208522655, 0.028123847623646725, 0.030480611785606015, 0.05115295534778852, 0.01575023834448075, 0.07083785472786985, 0.019413269619690254, 0.060022603429388255, 0.04339665865700226, 0.0138446684286464, 0.03060831870243419, 0.06607705159694888, 0.03363401396200061, 0.04701668432971928, 0.029836360808985773, 0.025919090148818213, 0.024046707221714314, 0.02968478642287664, 0.00936825257667806, 0.01950241825397825, 0.026000466641562525, 0.07959423994179815, 0.008960025897977175, 0.03638970847532619, 0.0600735629996052, 0.061068204158800654, 0.02551067515014438, 0.01628260128200054, 0.05842534206749406, 0.008117473062156932, 0.02954925726953661, 0.03146744740661234, 0.04846949035709258, 0.013644028804264963, 0.06855217347037978, 0.005114577043059398, 0.06743502599420026, 0.06686379492748529, 0.04739421856356785, 0.012224623133079149, 0.01763953852787381, 0.03305697930045426, 0.01588668590557063, 0.012335089031694224, 0.04039906481921207, 0.07483316963771358, 0.014432427124120295, 0.01891404543130193, 0.010975607146974653, 0.047106966594583355, 0.04776623121870216, 0.02641211925947573, 0.0037610065965054673, 0.06504539211164229, 0.05800367973279208, 0.07175002843723632, 0.013648038257088047, 0.004143401201872621, 0.03867851788527332, 0.013002185169170843, 0.03205993358278647, 0.014065331197343767, 0.14155760407447815, 0.0556998974934686, 0.01880375486507546, 0.039615538698853925, 0.08405423577642068, 0.031220486634992994, 0.041119872039416805, 0.06381327853887342, 0.09927949184202589, 0.06256573571590707, 0.05712586746085435, 0.11165861156769097, 0.02444045738229761, 0.027690715396602172, 0.02851295008440502, 0.021484804165083915, 0.03273257541877683, 0.022794047290517483, 0.0226428161477088, 0.06638935476075858, 0.039647844387218356, 0.01522969967481913, 0.00836616118249367, 0.018063301140500698, 0.04423638391017448, 0.08600817702244967, 0.033288703780272044, 0.02017872073338367, 0.045414569322019815, 0.023208850325318053, 0.021918854799878318, 0.029458086282829754, 0.008116017525026109, 0.03220597711333539, 0.02749483293882804, 0.045222865155665204, 0.03649060716270469, 0.0286871766729746, 0.033501933939987794, 0.03713693986355793, 0.015233884460030822, 0.03278778378444258, 0.012415970140864374, 0.008504853740305407, 0.014741190243512392, 0.001513740062364377, 0.037838495773030445, 0.025872440601233393, 0.029193892842158675, 0.042963177620549686, 0.02223446423158748, 0.049754032952478155, 0.024078712340269703, 0.11257825870416127, 0.04802933741302695, 0.042268983816029504, 0.015141770945774624, 0.07175284859840758, 0.09582207072526217, 0.02469068731443258, 0.022923986216483172, 0.01583963374287123, 0.02514718049496878, 0.035306232239236124, 0.03382427094038576, 0.04041924010380171, 0.0234757507496397, 0.07262284605531022, 0.031360032662632875, 0.06768642109818757, 0.011019110916095087, 0.033829176536528394, 0.0435439823922934, 0.0502642297942657, 0.039127969939727336, 0.027972336320090108, 0.034627111454028636, 0.02237298609543359, 0.04374440679384861, 0.04140458957408555, 0.045430955942720175, 0.07952959145768546, 0.028888807064504363, 0.04426994753885083, 0.04487137288379017, 0.02592745229776483, 0.012140907947468804, 0.051435242348816246, 0.029433070340019185, 0.10671685056877322, 0.03268087370088324, 0.05404343130066991, 0.009591177968104603, 0.028285012413107324, 0.02487100693542743, 0.023538425120932516, 0.12316771157202311, 0.08681231629452668, 0.057024438137887046, 0.09355948510346934, 0.0486620554147521, 0.23599816689966246, 0.19875320373103023, 0.08577966233133338, 0.10144662242964841, 0.11951077147386968, 0.21910356095759198, 0.15057316952152178, 0.10244217643048614, 0.08408416659221984, 0.11478590313345194, 0.2301472082035616, 0.2672067383537069, 0.11091439329902641, 0.11161357062519528, 0.19053136522416025, 0.0756356910278555, 0.1656276945141144, 0.28265323606319726, 0.17857383732916787, 0.10504314428544603, 0.16359133034711704, 0.10284200849127956, 0.13932411064160988, 0.21811543585499749, 0.1082463501370512, 0.12196768104331568, 0.09046618390129879, 0.14013956766575575, 0.0848978573048953, 0.07529789509135298, 0.09834350261371583, 0.135255835193675, 0.22264403582084924, 0.10166653562919237, 0.1157877802324947, 0.09859635974862613, 0.15153206884860992, 0.1168427654192783, 0.0710234881262295, 0.15183845709543675, 0.15996884816559032, 0.16516788949957117, 0.10399362872703932, 0.07487697861506604, 0.13854739372618496, 0.062117330089677125, 0.14935895655071363, 0.14254659006837755, 0.1621168461861089, 0.22310131753329188, 0.18175616656662896, 0.14070214529056102, 0.161339238693472, 0.14985653688199818, 0.1871150961960666, 0.12447244429495186, 0.13321464706677943, 0.1573293108958751, 0.20365597971249372, 0.14069764787564054, 0.1199042062216904, 0.16659471293678507, 0.300143311615102, 0.12299619382247329, 0.1544036014820449, 0.18570614367490634, 0.11772251469665207, 0.1464721653610468, 0.1775918126804754, 0.12836451904149726, 0.09861669459496625, 0.12615422514500096, 0.1261305357911624, 0.1471775767276995, 0.12072247598553076, 0.179352231498342, 0.13234556245151907, 0.07705893731326796, 0.10000197260524146, 0.23215491062728688, 0.22147540556034073, 0.0792455418559257, 0.11953570763580501, 0.1528680682531558, 0.19564586109481752, 0.2037283094250597, 0.21160469303140417, 0.15672459412598982, 0.2256626621237956, 0.08799953735433519, 0.17159582348540425, 0.11369589599780738, 0.08059265863266774, 0.13104972807923332, 0.16653295140713453, 0.22170233947690576, 0.13721023657126352, 0.09346885402919725, 0.10908955606282689, 0.11835140321636572, 0.12897281296318397, 0.15713859378593042, 0.11769905540859327, 0.13796185405226424, 0.06888815114507452, 0.16698931285645813, 0.1278607195126824, 0.10406441477243789, 0.09459668843192048, 0.10990425609634258, 0.16476254328154027, 0.08888507538358681, 0.14778897282667458, 0.13351027417229488, 0.13487872027326375, 0.07493580123991705, 0.2690632356097922, 0.07605000238982029, 0.09621532735764049, 0.11658577452180907, 0.08730201501748525, 0.11432726329076104, 0.07922216420411132, 0.13109151099342853, 0.10983699525240809, 0.116806800942868, 0.15500067413086072, 0.1240767831041012, 0.18599282047944143, 0.14766164997126907, 0.15330191294196993, 0.1571223555947654, 0.15943953359965235, 0.21486781246494502, 0.17262920475332066, 0.16636682907119393, 0.14202595863025635, 0.09309931643656455, 0.07012493282672949, 0.14192153845215216, 0.12150645852671005, 0.15152672538533807, 0.10750176821602508, 0.08233433080022223, 0.20658532564993948, 0.0837497622705996, 0.14755932264961302, 0.09955451692803763, 0.12661965563893318, 0.1012562912364956, 0.21655081043718383, 0.1935071696061641, 0.10578610832453705, 0.11904230559593998, 0.07593630536575802, 0.09553677431540564, 0.14127595903119072, 0.13329945970326662, 0.16368479642551392, 0.06858101332909428, 0.21167265891563147, 0.13653500092914328, 0.15310280956327915, 0.18852409324608743, 0.22281438839854673, 0.15205200266791508, 0.10603034170344472, 0.12491834146203473, 0.07387633348116651, 0.16413851582910866, 0.18405312846880406, 0.1749368238961324, 0.14197430515196174, 0.1807938385172747, 0.11451997677795589, 0.15406242135213688], [0.06930552015546709, 0.020657428249251097, 0.032167949466384016, 0.0338939548964845, 0.006843322389613604, 0.05509010443347506, 0.040845555704436265, 0.00662424828078656, 0.06875916587887332, 0.026427637567394413, 0.07531489769462496, 0.04945082480844576, 0.034977512768819, 0.031680837128078565, 0.002005911760534218, 0.02369524463574635, 0.01684642571490258, 0.03791628769249655, 0.011946043159696274, 0.00935726415264071, 0.04493735723372083, 0.033488738554297015, 0.07565594423795119, 0.030241295135056134, 0.03131027166091371, 0.04393865652673412, 0.020781259299837984, 0.022089097910793498, 0.044971948736929335, 0.07196289123385213, 0.019992371162516065, 0.06479162213508971, 0.016696007223799825, 0.02662568153027678, 0.03738406390766613, 0.016744838685553987, 0.04300506814615801, 0.0231808212629403, 0.03321503820188809, 0.05702524336811621, 0.05180988591746427, 0.03299430121842306, 0.048713478827266954, 0.034076883166562766, 0.0425425134744728, 0.03857107716612518, 0.07650778134120628, 0.0662586180260405, 0.026605637976899743, 0.03859585747704841, 0.045556041222880594, 0.07062232019961812, 0.07432493948726915, 0.027045824317610823, 0.07177851206506602, 0.04579297557938844, 0.0532938250398729, 0.10731352245784365, 0.07856238007661887, 0.03972349521063734, 0.05473142817209009, 0.040281775800394826, 0.0424953054607613, 0.0725370463624131, 0.04021930551971309, 0.04499698137806263, 0.06364836590364575, 0.01782172836101381, 0.01469142924179323, 0.02303618410223862, 0.04938770143780857, 0.028798125895264093, 0.06250594829907641, 0.03348199985339306, 0.03061051174881868, 0.072223325696541, 0.021102946921018884, 0.07663699667318724, 0.02453309039992746, 0.14850005420157686, 0.02225370812084293, 0.05008354281017091, 0.04215944652969483, 0.02028435617830837, 0.048423373300465755, 0.001486166145241441, 0.06332873032079078, 0.02003154171688948, 0.04783849413797725, 0.04024929570732638, 0.045277227472979575, 0.021109179106133524, 0.07795165933202952, 0.07035733637167141, 0.038574457648792304, 0.013272347332531353, 0.038441123397205956, 0.02126600047631655, 0.04302529167034663, 0.018116422215825878, 0.037358671324909665, 0.01573651232320117, 0.008790891370153986, 0.05812251241877675, 0.028660019634116907, 0.024166252369468566, 0.05039731171564199, 0.02499622765753884, 0.03107055239524925, 0.01668238139245659, 0.0882125337375328, 0.03565870414604433, 0.09373644279548898, 0.009474348153162282, 0.05166681468836032, 0.03401617919735145, 0.014105068567005219, 0.0708941243647132, 0.08874320643371902, 0.02089918099954957, 0.04920926316117402, 0.05685582960722968, 0.022662306801066734, 0.034899349775514565, 0.037394635801319964, 0.027103758220619056, 0.040597886181785725, 0.02408794651273638, 0.005348383710952476, 0.04698687967902515, 0.028468645723478403, 0.03545939296600409, 0.03556910465704277, 0.01945890242495807, 0.06321738590486348, 0.04119278062717058, 0.010260965318593662, 0.04577080391754862, 0.011409578928578412, 0.0485462172946427, 0.021206289129622746, 0.00699962564794987, 0.04244769297656603, 0.07275385738466866, 0.07727508040261455, 0.04528754703642335, 0.037447862632689066, 0.05418180844571907, 0.013323075909283943, 0.03763639040698763, 0.01870371706900187, 0.024980913440231234, 0.07204864639788866, 0.02964801671623718, 0.03874450223520398, 0.05333442793926224, 0.036102122539887205, 0.017568312759976834, 0.024730763288971502, 0.03744149500562344, 0.02117809679475613, 0.02909572340286104, 0.028098245384171605, 0.024715502877370454, 0.03241114754928276, 0.017950739602383692, 0.015913225106487516, 0.01139938089181669, 0.024263672239612788, 0.03481468927930109, 0.07603253223351203, 0.12647199793718755, 0.05230898765148595, 0.04750004882225767, 0.029843785996490624, 0.02440526288410183, 0.04648769259802066, 0.03845008854113985, 0.03884315592586063, 0.032329503883374855, 0.010098670609295368, 0.024609527899883687, 0.04105641470232513, 0.009796007016120711, 0.06767723330995068, 0.04982020655006636, 0.035793300048680976, 0.05408621240349021, 0.06809835758758709, 0.04114455216040369, 0.05981909540423658, 0.042361915548099205, 0.014389156203833409, 0.029492872599803377, 0.053761329836561345, 0.01368377174003399, 0.08359798564924859, 0.03726665243448224, 0.052376630701473914, 0.026403413867228664, 0.046762027486693114, 0.039556530537083745, 0.014411829743039561, 0.048760519857751206, 0.07532680916483514, 0.007043581199468463, 0.018456112484273035, 0.03813273877312895, 0.012314846953813685, 0.03311819535156246, 0.03526406711898744, 0.015077479620231315, 0.0728071658522822, 0.03363148323842324, 0.04529081248620059, 0.030400465402635746, 0.01736368594720261, 0.05224717046075966, 0.029202188197814394, 0.059157663708901964, 0.05302764264342841, 0.054874158013262786, 0.027466635037853848, 0.03873981928336434, 0.018154952667828184, 0.04033620862173848, 0.00847617900944897, 0.055136837472673506, 0.031925282019074075, 0.013127166548656533, 0.04700686942669563, 0.06340575782814994, 0.06747148770955391, 0.016659306165820453, 0.09545548688038252, 0.0299652514513582, 0.02939582380349748, 0.02643422041728627, 0.029065647868264932, 0.01800594796804944, 0.039969483768800274, 0.03351360421220306, 0.02180994091759203, 0.0796544949116651, 0.01771562350768363, 0.017611379589652643, 0.10413778349175118, 0.039476775637012906, 0.00779556929046521, 0.07707978424150497, 0.022487679452751763, 0.0353926850220887, 0.03522327126120217, 0.05921526921156328, 0.013309515943547012, 0.05739960492064711, 0.030610756657551974, 0.02024861805693945, 0.04016342922113836, 0.0377806305186823, 0.061216678222990595, 0.05166924151126295, 0.033529890642967075, 0.030680143754580058, 0.01695177357760258, 0.041687025004648603, 0.07455613333149813, 0.011287498418823816, 0.051211970931035466, 0.08546446479158476, 0.07437951702740975, 0.073614140128484, 0.04392319759062957, 0.024685967255209107, 0.014047045606275788, 0.09100426323129795, 0.033623004201217555, 0.05187415219552349, 0.01586368674907135, 0.04050599345646333, 0.07142434435081668, 0.05451485463709105, 0.09507727358140983, 0.032988096863846295, 0.04719946417026222, 0.021436379029182717, 0.07764355672406964, 0.04000035711214878, 0.1818374465801753, 0.02326214951608563, 0.014980850137362722, 0.0077369642076519085, 0.024999344677780755, 0.11345300590619445, 0.05165031674550846, 0.04546511328953784, 0.050014415464829654, 0.03413055899727624, 0.06854577615740709, 0.058055500194313936, 0.030304470456030685, 0.05831151516758837, 0.05958819470833987, 0.01707708706817357, 0.03558413314749487, 0.007585118009956204, 0.011593831004574895, 0.07150126795750111, 0.03524242609273642, 0.02903754088038113, 0.023143279722717125, 0.019557845553208608, 0.011303458304610103, 0.015702004311606288, 0.07803961125318892, 0.005627630225717439, 0.017581077700015157, 0.00537238476681523, 0.012600744503288297, 0.0735869404161349, 0.03732272540219128, 0.0823940068949014, 0.05537536373594776, 0.047487684641964734, 0.03261989513703156, 0.07354243381996639, 0.02266267973027425, 0.007811307459633099, 0.03621016439865343, 0.04364513712062035, 0.04357502642960753, 0.02164308200008236, 0.02494292290066369, 0.020419701650098432, 0.015786080366524402, 0.00723561376616999, 0.057984844024758786, 0.037350433485698886, 0.02430190026643686, 0.056466840323992074, 0.055583966604899615, 0.028412047686288133, 0.04241781040036585, 0.06418678662157618, 0.005418899336291361, 0.05900010575714987, 0.04024903966637794, 0.10492143206647597, 0.08458331285510212, 0.032419222116004676, 0.04448461746505927, 0.05846567037224304, 0.11372480264981277, 0.09519477040157653, 0.11708766673109494, 0.10788624524138868, 0.09856593169388361, 0.10196502742473967, 0.15148722828598693, 0.09302126476541162, 0.1600774985854514, 0.1286043514846824, 0.11621406985796057, 0.22250650101341307, 0.28462800197303295, 0.22629167680861428, 0.16231161542236805, 0.1322366003296338, 0.11061685145250522, 0.05918720860790927, 0.11861827952088788, 0.10346098191803321, 0.14238722127629444, 0.09571695292834193, 0.10865476142498665, 0.07108538324246183, 0.2213529363507405, 0.08443967017228715, 0.10271329039824195, 0.12363560599624179, 0.15726171608548611, 0.2830522443400696, 0.1575790881179273, 0.16266765334876254, 0.12022481401800178, 0.1847621169872582, 0.11097979877376929, 0.12299037538468838, 0.15730896120658144, 0.16892293409910053, 0.10261707837344147, 0.19598172744736075, 0.12762030819430947, 0.0919061953027267, 0.12875916349003091, 0.1814987006946467, 0.15507684816839173, 0.1354914522380568, 0.20951042650267482, 0.1637554043554701, 0.11920157048734836, 0.14249921136070043, 0.10641127126291394, 0.17827672592829913, 0.2052758654463105, 0.1686584623530507, 0.18236149189760908, 0.11012746443157084, 0.1392231191857718, 0.31626979471184313, 0.14500878372928128, 0.18043152202153578, 0.17096937663154677, 0.16853507288033143, 0.09383382741361856, 0.1582862064242363, 0.09883193968562409, 0.18653956067282706, 0.1787665137089789, 0.1548897082102485, 0.14320340560516343, 0.14240961929317564, 0.16735165903810412, 0.13690521387616172, 0.09255742988898419, 0.19054117641644552, 0.10420137812616304, 0.1569173892494291, 0.2047797545674257, 0.14018172165378928, 0.10671016381820664, 0.21752850094344467, 0.2026405732613057, 0.1649288585758768, 0.1179246831452474, 0.2240401937160641, 0.22923408454516903, 0.25040813663508743, 0.21990828652633354, 0.10202485194895416, 0.07593948175781406, 0.11846756417071447, 0.1674457039916888, 0.09293408467783593, 0.2403890242567286, 0.19947326509281993, 0.15430646919412538, 0.12922319874633104, 0.1607007542042993, 0.16358980152290314, 0.1034242233436089, 0.1534617567085661, 0.08282721333671361, 0.09936831207596697, 0.08147842672769912, 0.1438332663383335, 0.19295136036816984, 0.2716946537839249, 0.20233129063853994, 0.07482331391656771, 0.2413974396768026, 0.08053494922933169, 0.23456794442608953, 0.18183314212365076, 0.24267236032756045, 0.14528897416312248, 0.12748523731715977, 0.09114900429267436, 0.15960060933139175, 0.24636028509121388, 0.2651429740944877, 0.13907449669204652, 0.13609621353680268, 0.2149334628484212, 0.1938162444275804, 0.14636203064583242, 0.12922895781230181, 0.10659583596861921, 0.1461244246456772, 0.12860386166721582, 0.08866098389262334, 0.1307048520538956, 0.14020860224263743, 0.14053933293325827, 0.13775706582237035, 0.054756531317252666, 0.11164759809616953, 0.15110732289031148, 0.0854916125535965, 0.22117660206276923, 0.18364913295954466, 0.13059528137091547, 0.08659956482006237, 0.14069738070247695, 0.18085410090861842, 0.22814855998149142, 0.16652183403493837, 0.19609472685260698, 0.1332979160360992, 0.1681530152563937, 0.20839861506829038, 0.17557872226461768, 0.1859094327664934, 0.1430194717249833, 0.2795293880626559, 0.2041073836153373, 0.14428421010961756, 0.223768612195272, 0.1209811886656098, 0.20002573466626927, 0.09089821032830514, 0.11754269973607734, 0.11890365756698884, 0.07446137591614388, 0.10050715995021164, 0.10941664280835539, 0.1841584689100273, 0.06763530196622014, 0.1459087268449366, 0.19938533543609083, 0.12510619388194755, 0.17817951942561194, 0.15655107999918982, 0.30273996759206057, 0.16248637635726482, 0.15168040932621807, 0.11160936264786869, 0.09708300189231522], [0.05807941219245549, 0.07182995032053441, 0.03437444356677588, 0.017176724104501773, 0.019735693822440226, 0.028338274496491067, 0.004147519657635712, 0.030430912011070177, 0.07390436439891346, 0.024330766100320034, 0.012560150880744914, 0.05323356264852919, 0.05408761506259907, 0.06103505984356161, 0.023192289299913682, 0.024695756183064077, 0.05513493757462129, 0.023975167896423955, 0.11509157891850919, 0.05366025674447883, 0.029186447245592717, 0.019204310519853607, 0.05158275533176493, 0.07673478205106221, 0.020667669887188822, 0.045528373957495205, 0.04586293413012754, 0.02376638320129132, 0.04692092501500156, 0.04554697217827197, 0.036053786461707205, 0.04945878063153941, 0.04702642130723689, 0.01718918290862348, 0.03781361898290925, 0.039621127070859075, 0.015406063648697454, 0.021671675094694365, 0.043193402962060645, 0.009375719509989722, 0.09253770360373892, 0.06011307494190987, 0.010245106550428318, 0.021674625131709035, 0.04638660466298461, 0.06016994942910969, 0.10237366877845488, 0.04658442783693317, 0.0252484075826942, 0.032489740988239646, 0.012455622163543012, 0.029594444786198437, 0.012694630822807085, 0.041512742755003273, 0.07130968253477477, 0.021444592748594005, 0.014346639491122914, 0.050605257783900015, 0.07064561621518806, 0.05464128691528458, 0.0072294887286261655, 0.0443887134315446, 0.01625805289222626, 0.01426543833076721, 0.038400487101171166, 0.022798574391345028, 0.0762394504272379, 0.020440329644770827, 0.06914456316735595, 0.02646863751579076, 0.01668702909228159, 0.05386840690334793, 0.06210683612152934, 0.05634834160446189, 0.015353318285633577, 0.06448380896472372, 0.040907228176365606, 0.024416879350610543, 0.05571056215558201, 0.017002883432724047, 0.07559552599559538, 0.029610323035740294, 0.04422495112521574, 0.014678177267342107, 0.052819021220784634, 0.012261508800293086, 0.04009848016721662, 0.07085148055921309, 0.017277782353630755, 0.05084720534796361, 0.008765296552155633, 0.052405574460863136, 0.06840740272309631, 0.028994234708079603, 0.0729272527678404, 0.05887519859243184, 0.06306842202320695, 0.04928899208607618, 0.03779607461183332, 0.04230850317981094, 0.027219980402151123, 0.03406211813853588, 0.061186751117929816, 0.016493322982569225, 0.03686197414936032, 0.016886746598174796, 0.08246657409472391, 0.034449385639163665, 0.014924016468285117, 0.01003293395115179, 0.030214117687137332, 0.06336299527902156, 0.028570407157531008, 0.06583638794836588, 0.06262465481995605, 0.03366181852470618, 0.04547705815639347, 0.035692553501576185, 0.028174536309961695, 0.03532588802045211, 0.009080380914383568, 0.024181778098864015, 0.02673650458746124, 0.024267800436064135, 0.019374564762983937, 0.05982809394481592, 0.04713808113592677, 0.03577337338356301, 0.09946399717591703, 0.05396985849074554, 0.018050309845420998, 0.04910949995974079, 0.02018563012825325, 0.04568292621115688, 0.040492252592230216, 0.07952741696499288, 0.05753218589234166, 0.03384595278475899, 0.036008682436659, 0.035801723424810916, 0.02479746752214851, 0.05103867202706169, 0.04904045425064396, 0.024455207567370962, 0.04226433426083531, 0.045020685574854724, 0.04926417466776911, 0.030425917357206345, 0.02357962730457075, 0.016165280721907038, 0.05356135814508889, 0.048608661600155756, 0.06581019013538025, 0.03686728792672511, 0.04441809134732466, 0.048473854185431264, 0.04463771510927472, 0.034908426241599955, 0.049194438761333004, 0.0020042384494445287, 0.034973516303580254, 0.05690547557605896, 0.03072332747251494, 0.0021937632527624373, 0.022696299020026345, 0.04877217528701294, 0.06167947038193233, 0.05302903045958374, 0.023077237856341526, 0.011873578005179297, 0.027173653688805643, 0.02736813905357849, 0.055278999570873566, 0.05172753721126355, 0.04248349789122585, 0.02986781302752206, 0.015112755754671525, 0.06224098673556, 0.08241565534262918, 0.006098506228227052, 0.0129724714315671, 0.028784277419617865, 0.01620395774807548, 0.038057395940995775, 0.05070430852356367, 0.043281915204715915, 0.05700828158296645, 0.021219564296188764, 0.05509898423042614, 0.11129346748930402, 0.041772371987462975, 0.03831301015452482, 0.06589808268472552, 0.06413668423192576, 0.012503538928285707, 0.05354254099074751, 0.026917939285340253, 0.0014841232678008964, 0.03790148926782422, 0.033695886813802645, 0.04209506150800735, 0.037498195088119246, 0.026012172165792435, 0.011071128046751255, 0.05470241761940997, 0.06147645959572401, 0.04913890013995115, 0.06188560932059772, 0.15514003462158144, 0.015479059438803233, 0.014213052909326507, 0.014025632790435338, 0.04944878390233498, 0.03051228850381449, 0.06826904413173907, 0.03433985577430576, 0.13202070957049727, 0.04757102782605216, 0.014054391940589994, 0.02872572196793044, 0.03170707946992479, 0.04558415006613359, 0.033578122820472345, 0.012144290285505122, 0.04151075008849148, 0.04829172001336701, 0.03618475697294343, 0.03748496630578302, 0.028778642663382925, 0.027222932294534985, 0.03021325308509404, 0.01885763293103082, 0.021949665060674306, 0.041293441827292554, 0.034917179873446, 0.05949276564933825, 0.006748185087417369, 0.028351792716421187, 0.02221372491476359, 0.022149881660880055, 0.028365125399432145, 0.04581546636472922, 0.07120814188965596, 0.022457910054072272, 0.018865718629967887, 0.022768150047340896, 0.04600011270667892, 0.04607426068105269, 0.028687768535746727, 0.021815464351675473, 0.06338586084893905, 0.05161156179383397, 0.00590571110478777, 0.03979583234468009, 0.02605522415251471, 0.020724086098198313, 0.022947929755900986, 0.026138700923183933, 0.05007508232665714, 0.01204927590151783, 0.012930953835166292, 0.08761295262956992, 0.04668341549404431, 0.031470338071812876, 0.09113546751905233, 0.03785347602388356, 0.07683208503294736, 0.03975902924139518, 0.07380660128546879, 0.01650813068408752, 0.037047392324893735, 0.014522785459121224, 0.04973167946445756, 0.037501683182199486, 0.04671381015214138, 0.02408652344456641, 0.03126908246485982, 0.04314579789934214, 0.08309050506795757, 0.028308529217611067, 0.015418282182508847, 0.02136618670192547, 0.10948964045383036, 0.03716752376931254, 0.053101519733900204, 0.05334090688847937, 0.030559700608137064, 0.05755113663326483, 0.019517003311193548, 0.03307725848571863, 0.05510322189365979, 0.06303675458184443, 0.060739770415239036, 0.01594409844983602, 0.010918824500549817, 0.025791216248762794, 0.083486967778299, 0.02449447645631153, 0.06976473887334578, 0.025281371927121654, 0.09250648145098239, 0.04006351016869303, 0.04572582976834383, 0.045784708054270595, 0.09513631885056384, 0.06318830113741569, 0.010220354070042958, 0.09413775173015893, 0.02897842881793622, 0.014166366254357854, 0.03576568102289457, 0.061646938338526525, 0.028726208074658643, 0.07102503921487369, 0.03255046351114288, 0.003630622845776088, 0.04606450514984317, 0.057751241911319084, 0.054105200251797214, 0.019484113181533758, 0.04608511088008527, 0.0137368417927064, 0.03690641024149954, 0.0584622045425931, 0.011403321695979685, 0.008064005960477516, 0.023214318098325748, 0.03580744538339786, 0.07225328619824722, 0.006178849744173931, 0.045560839207610115, 0.04853974576690234, 0.12044091999996454, 0.05374313608626835, 0.042509298655204475, 0.08944153771153651, 0.08696054544998333, 0.06932878648512997, 0.02477290057868231, 0.014328843717521522, 0.05387714569224045, 0.03516612960083876, 0.03232878771086689, 0.048777136544231325, 0.0400131443166174, 0.017047731416823808, 0.06422971986467019, 0.056911631691036746, 0.04965137908584438, 0.02100739726301981, 0.04505285767663736, 0.05386236582126003, 0.14975643600337207, 0.1962511270539835, 0.1470298448111862, 0.12031903708702885, 0.10186891930061392, 0.1736665194039233, 0.1606227841693908, 0.13202764122979715, 0.11828589384094812, 0.14213413407560438, 0.1666544855106622, 0.10589220575639047, 0.12508131709182635, 0.11965882251388393, 0.19693718320922926, 0.12515014386735857, 0.1199015938618686, 0.26694167288951576, 0.23657828889554366, 0.10690663999412209, 0.1407170030870475, 0.08810861079837196, 0.12580553448060527, 0.14049893041374162, 0.10601906848023646, 0.1291700906585902, 0.1409852597862482, 0.07033287518424913, 0.14998540340457112, 0.17095913499360904, 0.24242521030828357, 0.18112826510332525, 0.17092453606892377, 0.12647950847167522, 0.07563813269371167, 0.1761229391559027, 0.12887900549685583, 0.08904290792997926, 0.10242049829685129, 0.07314295799005777, 0.2972552884602919, 0.1014546821534168, 0.12700382096227258, 0.09639504583901726, 0.14763607556233183, 0.16837365576066077, 0.15677255170885473, 0.13929264358012006, 0.14848219812847674, 0.12750450347084552, 0.09279988953494467, 0.17042208724888042, 0.14194439660059288, 0.13800365180941299, 0.1397898083087057, 0.11471694277133793, 0.18271660956088454, 0.11998081812635064, 0.14855823857942596, 0.1045549669652246, 0.1372648437973112, 0.1530698878923431, 0.12717280798824504, 0.11256179786869325, 0.16817746160086244, 0.10540668532485142, 0.19588456547353417, 0.1097185633261688, 0.1058225700398907, 0.20839914941461757, 0.13747917604632676, 0.10970210991217755, 0.13743236137088388, 0.1006577342923265, 0.18766018882161006, 0.11609947483520955, 0.10628091302351095, 0.12435633529094048, 0.21788593410747126, 0.07886256396886893, 0.16224400576902553, 0.09789693751372397, 0.1291721241432242, 0.14653478778200224, 0.12198018623166718, 0.16661253932397813, 0.12622602051123977, 0.1648334925994277, 0.16981539636617526, 0.19334161130245775, 0.1653889604494907, 0.08884412367478944, 0.14066281146369874, 0.08143279948853888, 0.17505932279163972, 0.25291327096056193, 0.1907740326714702, 0.1776503532892093, 0.1355425119982101, 0.15626311185769737, 0.10906344730756246, 0.16958319320110604, 0.12277055124286562, 0.08007844677194953, 0.12222514691529796, 0.14278432965511456, 0.19175390509190038, 0.15692798711825162, 0.12156007869634777, 0.16131465876242146, 0.18795534095261246, 0.22585615486605093, 0.09117447480093688, 0.187970005790703, 0.23647201334824786, 0.23631248128367588, 0.1525491673965007, 0.1280629844404757, 0.08844855154165998, 0.18884205899666995, 0.15853491495363414, 0.0988069293089211, 0.16526668419828638, 0.12421308594639413, 0.1863731860066764, 0.16470611037220806, 0.10115390454302542, 0.14460930047789589, 0.29016863903962076, 0.20678221742855385, 0.12334144092164934, 0.12207420149934478, 0.12270601408090442, 0.12332483907812275, 0.13359706092160195, 0.26332168432418257, 0.13064568804111332, 0.15034163428936154, 0.12690979085164145, 0.1280961139127612, 0.1725530604016967, 0.1417158151161857, 0.17971144581679255, 0.11009081717929803, 0.14116671489318833, 0.16347184457117692, 0.14948190073482692, 0.11023827450117096, 0.11661083684884943, 0.082332876190776, 0.12349199299933389, 0.09107041085371748, 0.29225481615867466, 0.03738214174518362, 0.17717652168357745, 0.15244670648826286, 0.21782469208119437, 0.18216740543721244, 0.11070402411860414, 0.2157028770307079, 0.11939774980419315, 0.17674631351837888, 0.16455543955089524, 0.13166020391508937, 0.10137248187675141, 0.12429968715878204, 0.18965276627568528, 0.17760463699232787, 0.11485227340017445, 0.06687224056804553, 0.17294712597504258, 0.09702374882181175, 0.1910661716829054, 0.14857282920274884, 0.14829930325504392, 0.21346246678149328], [0.04316922008001711, 0.05063763768703211, 0.056138521613320336, 0.024863756152626593, 0.03399902816454414, 0.0037051307617730345, 0.016325573487847578, 0.008824961514619645, 0.07635923306224868, 0.04748818188090809, 0.022891500557307154, 0.028797634222428314, 0.03206739216693677, 0.031097720566322096, 0.03830450885288883, 0.012326311280048685, 0.05107669967401307, 0.026403508491057437, 0.036656228548963554, 0.00835903470942867, 0.006299536871665623, 0.023539109752164222, 0.0174245290691033, 0.01393680142427911, 0.014280382401921088, 0.03821744008746464, 0.019838227090076543, 0.026288590634067077, 0.04872606565186288, 0.025120578211499378, 0.03877272982208524, 0.01753297354298411, 0.0400876188359689, 0.022692040947731584, 0.06195714864588808, 0.04534164218057413, 0.03888381448632572, 0.039857942683738656, 0.0737478157680016, 0.058848896878771484, 0.04423916696396191, 0.054799690915388055, 0.05397729481046554, 0.029578022913483437, 0.04111123344046064, 0.05610422325844411, 0.06780037787393667, 0.019900322586181574, 0.017756020461092703, 0.036562725363182835, 0.04410286412166897, 0.050953877944266424, 0.03290033790108282, 0.035668808486661874, 0.058807206733035855, 0.054432261022157036, 0.014608858818974113, 0.0697761531046126, 0.018642200448084623, 0.03710455996042583, 0.04647492394724395, 0.02519519559427863, 0.07973545580171049, 0.035931157690356486, 0.057580035863793455, 0.03841521502181422, 0.04944740350765642, 0.028286346423556097, 0.04421247933350969, 0.049787611424108036, 0.05961482667771634, 0.013665814549312927, 0.008742392019485123, 0.04872345700277947, 0.08827260317048058, 0.023879475374997128, 0.026821129831660073, 0.04463914745429065, 0.04093625357199926, 0.1113995278137736, 0.04351255985966418, 0.019031160045415163, 0.16509900335222483, 0.04521743634541053, 0.019716642891580705, 0.018404930269753095, 0.03640230272139888, 0.010845619053725386, 0.03625945784733631, 0.009392884458065964, 0.06842520684585907, 0.024509299000783358, 0.022196876307134517, 0.00723031993402401, 0.039746798647684045, 0.022896790214872453, 0.04888887800916564, 0.07039583899313584, 0.03594959634938277, 0.01815366318624001, 0.05520462153072003, 0.04580708009598311, 0.05486346366524231, 0.07094829372363165, 0.03286199855210725, 0.07957445428473875, 0.06366033674567007, 0.03408425640373025, 0.027352514989615884, 0.0359175652556587, 0.031223778059938923, 0.034323220534133725, 0.04336585581768304, 0.06555834974278696, 0.03362913805176504, 0.023838722190703265, 0.03328038801555522, 0.0707628607051447, 0.06807902464061044, 0.07633428205735981, 0.012315963886067038, 0.030390930660360027, 0.039812200411688536, 0.03663570445496589, 0.0939442367234733, 0.016703614237485453, 0.02389148146903608, 0.06539162626722828, 0.022131018122308888, 0.0006258661233005114, 0.0105254333539051, 0.041865808379952796, 0.05349810860934667, 0.054878139635547996, 0.03652804851299152, 0.02476668138115201, 0.04591443546814844, 0.04119599412661046, 0.03364402553415857, 0.037133321893634275, 0.012787919713446172, 0.019590167939895764, 0.04399811368784867, 0.022385372540156823, 0.05081253962998744, 0.06438852462451905, 0.03323591852677055, 0.04834658328036312, 0.014304743399407016, 0.07978333174833097, 0.04323746055888478, 0.030001830054970924, 0.014959150666982168, 0.043361350981285796, 0.04253197126672603, 0.047197901949402876, 0.005081027793494286, 0.03582687109883409, 0.044054795216652565, 0.030240766354836524, 0.04462269032956101, 0.06663436739472672, 0.04206136058201082, 0.08197164323064499, 0.061486255945055746, 0.03973410050093662, 0.027899746855837293, 0.02226697401056299, 0.03137915780826006, 0.014004864715388976, 0.03234294788853731, 0.018678751221159473, 0.03430198768910486, 0.04199709801468998, 0.04623598579200916, 0.03589671461668331, 0.016796570089354645, 0.025703371939016506, 0.056851395274861716, 0.058828231776715256, 0.03443522917223163, 0.011979206956311828, 0.04947331930452492, 0.007897878986113938, 0.049218803469557315, 0.04578457817842718, 0.0532523055881029, 0.010812548025569413, 0.027567984579945914, 0.07750417396891862, 0.027723507191694807, 0.027338983782101423, 0.040613066812511533, 0.0489212430693442, 0.040284573697135784, 0.05405322393926326, 0.01179699856947991, 0.1259512032265775, 0.001545348247873335, 0.030402012780541554, 0.020751916636072565, 0.0771861859539058, 0.07673342392081395, 0.032474753315909766, 0.02799176760163391, 0.08531707426300272, 0.02581472748715896, 0.007248961755976779, 0.07091712352121249, 0.03284150043327827, 0.10523500430281274, 0.01571455959492596, 0.039007805098663084, 0.018763200205285102, 0.03646465054771397, 0.0012501466017056373, 0.03562988655176014, 0.05161717985174619, 0.04080572092789225, 0.011270301929471316, 0.04243461633450352, 0.04389692927361466, 0.02502168146747863, 0.022104527160990983, 0.05096326240163762, 0.07178240091889165, 0.005667398208970553, 0.02332289059268078, 0.016426926740678027, 0.051415950219961815, 0.02320252351637464, 0.034480381436878815, 0.026109612444997765, 0.06720366145600565, 0.026264199950674083, 0.04562404050375335, 0.030771455749345478, 0.029848971753381193, 0.038767467995057814, 0.04450396525498945, 0.03742150896869134, 0.01732806471409276, 0.06162598750961479, 0.009198799853038508, 0.02146363625797676, 0.025099068916460965, 0.05018084579205606, 0.06495813038782217, 0.07434750819811597, 0.0369738120934926, 0.05413612554548308, 0.0494450842961669, 0.03852114547044039, 0.042780126896104775, 0.050294127213419415, 0.12046377072692849, 0.053379275923362, 0.022869724089105148, 0.014565301244147122, 0.040873638572520576, 0.02347074681892991, 0.03687253120006062, 0.02586449776572408, 0.04378418219857849, 0.039650723920203745, 0.023484350385842845, 0.03046505451493431, 0.09298330391175114, 0.014784431477892213, 0.008658890201331815, 0.0636738289904315, 0.018526161948102526, 0.012279939110158011, 0.04575949358695652, 0.05037945193180349, 0.006725795883539831, 0.07582462698337622, 0.044459224882302806, 0.004395341784402262, 0.056555619739810936, 0.019994232097815257, 0.019216932596464176, 0.04205078868835699, 0.023037314022076316, 0.010064747966680443, 0.025139972385659348, 0.01403576681695995, 0.04321368214732502, 0.03969473698816728, 0.08533816609997302, 0.05664566451741848, 0.041436661485931836, 0.01191350555018289, 0.03628536251198966, 0.04208232625387609, 0.0444191229325952, 0.009861265916697448, 0.022365970944520086, 0.023602092114742845, 0.0628084699565079, 0.015554119327134686, 0.0054934972376941005, 0.14479356090305373, 0.02088138244289439, 0.025316280698461924, 0.03018407369381748, 0.04104842919332441, 0.027333228426869027, 0.050118112048949115, 0.07080422059516422, 0.028368969724397175, 0.06008132215356454, 0.026458097163413186, 0.08150828332873061, 0.04163835496001411, 0.06527818899485283, 0.024150253520929255, 0.058066688070539385, 0.06512972235213965, 0.05988700933812652, 0.018253713969897944, 0.07840756807127036, 0.038661801008856855, 0.037546471794485115, 0.005818148811158608, 0.14257494010962546, 0.04708124746684916, 0.0011616642768785823, 0.03232246461266186, 0.03957174085371662, 0.03547247331880499, 0.05605731210380327, 0.008823236021271441, 0.009235333927790634, 0.06843576760729775, 0.02278115618537413, 0.055795512089389376, 0.04241074886522256, 0.027378911327105016, 0.03487120382487774, 0.06812103762058541, 0.017793391307350248, 0.046299417153932154, 0.039006198348943144, 0.0273785383978975, 0.0018012967757385923, 0.007578264276162372, 0.0843374319083523, 0.008918480471038492, 0.017896139797812793, 0.037267977168085054, 0.01949764438904822, 0.11888960871146992, 0.12645880255149677, 0.18821253965143114, 0.18904037569882348, 0.1335898324032314, 0.0989047517941799, 0.13195525214541703, 0.1710428047226742, 0.1793324903701432, 0.11770974233513698, 0.10976604593452066, 0.1515450415899977, 0.06409864174202085, 0.13617529679322615, 0.10692722717067227, 0.12879046727903187, 0.12931053468491882, 0.11473721824586391, 0.16716275276849046, 0.11259533552220091, 0.08967885427409783, 0.2140927579603158, 0.1063633656303864, 0.08132840157486498, 0.201075027580373, 0.21920441882684827, 0.1469094239291735, 0.09748884534928948, 0.13849680894054472, 0.25131735659670085, 0.16239188611507416, 0.11766035982873291, 0.09201719833072275, 0.10390560259111226, 0.24066826474154368, 0.15384299797005951, 0.09747763891937211, 0.09698134250356816, 0.12225409067468718, 0.15693647728767246, 0.11042324738809839, 0.1521382699138485, 0.1321488933172077, 0.1310210514930077, 0.12596647662576288, 0.19820435583824292, 0.16040889720898122, 0.0871017093595583, 0.10744848201284185, 0.15000934508861974, 0.12124590532039292, 0.13399362011114135, 0.1979516545543447, 0.13273173157358542, 0.13046061125351116, 0.13098501280182973, 0.12763693230226636, 0.1719701776164584, 0.10936169419437647, 0.1590203240630217, 0.1551577719510533, 0.07387438163277693, 0.2038243433344178, 0.19142010190989822, 0.19035758392419666, 0.11013487106538378, 0.14344050694489852, 0.09862179314950481, 0.06620799613301642, 0.16964804206509143, 0.15553548058960587, 0.16927241144003347, 0.12276246925466694, 0.12106035355827771, 0.14787068328587338, 0.12264020784641616, 0.11344700193149038, 0.19098857272183523, 0.12291826089494862, 0.28736379579640925, 0.11746098927687854, 0.09798362778383307, 0.24946712306700647, 0.2857117750681937, 0.11807570277596824, 0.18609016056871042, 0.13993219676194713, 0.05902463002712466, 0.1383391025592573, 0.06858871682197787, 0.12568239733809605, 0.1827786976355128, 0.17311212024651468, 0.09499200081336312, 0.1367105485405773, 0.1321079712943174, 0.1044727444241289, 0.16194082360016182, 0.1427138998406008, 0.07960980277857743, 0.19635444885352626, 0.065931308636209, 0.11521113890921697, 0.12741583166643977, 0.10423557629110292, 0.11806978785898536, 0.21369860332924873, 0.12062250869348645, 0.09644160818425007, 0.11662869292194955, 0.14425001194467768, 0.23390265356283635, 0.1841721689561382, 0.15976906201103702, 0.1505433500278741, 0.17459435242926702, 0.18724598136032, 0.07088647282216698, 0.16950008750427514, 0.17193256557220593, 0.11180222456459887, 0.08566566102672368, 0.14495177194476128, 0.20437716913875192, 0.3059475892223418, 0.1168130201403983, 0.20382121147122234, 0.19524207338690758, 0.11244680208619684, 0.12783860351191834, 0.1454222490428947, 0.10332036719773896, 0.12952940887771547, 0.14250425796490163, 0.13061307807220146, 0.1825674675637856, 0.11540210092789494, 0.14891991682816297, 0.1307344192173332, 0.15041083213873208, 0.07142015121644363, 0.16108114941744134, 0.16813109221402556, 0.11013651121174917, 0.10808125938638113, 0.16475022363010794, 0.12875457701738924, 0.126043823256623, 0.16149275936186314, 0.24354291439522058, 0.1431296212831512, 0.11269617854850367, 0.05164904025150463, 0.10067419512779452, 0.10935745653114282, 0.15694867819547653, 0.10165598228923045, 0.12534636771306396, 0.12772898830007762, 0.14779787859879434, 0.15826113667571917, 0.18681130546610802, 0.07412792154354975, 0.16172531875781715, 0.1957987732021138, 0.1144412942812778, 0.12909505952848122, 0.17160858842544258, 0.10227531936834566, 0.07013103328063153, 0.12452084716642275, 0.24710805824724957, 0.1021016419690568, 0.0881008330907207, 0.15022710605990142, 0.11078544514020905], [0.03809566107520368, 0.06354766388540156, 0.02047454265266424, 0.04456266171473544, 0.07185942100477405, 0.027469909764477052, 0.050552847314975224, 0.045949635532451794, 0.0591699833603343, 0.039765159381204285, 0.03959244306315668, 0.030697341171617154, 0.039611831671209075, 0.018622286770551, 0.0554779582307674, 0.0506516716995975, 0.035570292093325406, 0.034093659414793365, 0.04275464154488873, 0.0509634442278184, 0.005902925267946557, 0.01909343551233178, 0.049339402467012405, 0.08106427863822319, 0.03868147905450314, 0.03887345410475973, 0.005912473925491213, 0.05499443046574015, 0.06241891664103605, 0.03296263748779893, 0.04565147028188221, 0.010112051531905308, 0.023047616887197364, 0.024302514393639285, 0.03388299708603881, 0.031579470887663774, 0.03492745861876756, 0.041316474380437285, 0.044959577135159634, 0.051279907129355706, 0.010655456699169008, 0.022377169952960685, 0.02006543003517436, 0.029401382489595562, 0.007500336914745276, 0.05800266299047507, 0.014344452938530594, 0.04155871138209477, 0.030812297991360538, 0.014396148162632016, 0.09825923916650936, 0.026772326200443786, 0.10089021205203608, 0.02049944541795412, 0.06880910499603488, 0.026848695051739924, 0.009651188956922852, 0.02085026975692017, 0.07111563318176195, 0.009130131711572176, 0.03593215958971996, 0.03236197284422815, 0.055119174357969314, 0.14593372237868607, 0.04303996764065232, 0.08063701679930091, 0.07275059935636818, 0.04469439292734023, 0.08957679412560537, 0.07627137762028724, 0.026484638219699264, 0.014396243714145385, 0.029598472792713437, 0.060901232063770294, 0.004893526966043282, 0.05406760305049829, 0.00854424786666641, 0.02127519197529182, 0.042097558834939264, 0.026145669689867646, 0.06279859197093174, 0.01830813751439564, 0.06596458653802983, 0.02955586609459715, 0.09367443635710515, 0.018642029754118994, 0.05817594334075693, 0.014607931134378305, 0.020445224108698312, 0.017338979851047043, 0.0357514429197181, 0.06318168118014, 0.11398184549761936, 0.024326823440787848, 0.052258432551752776, 0.013890230729884934, 0.014184365190885728, 0.021832095881109126, 0.09898183125187643, 0.05870482375030406, 0.15296125231543556, 0.03901294447132386, 0.023185394747997634, 0.05690658879757393, 0.03349738828546833, 0.08827859972370788, 0.04540347792499233, 0.013062546822766308, 0.015070470963109983, 0.028554393466038164, 0.08285960066132247, 0.06675081778666936, 0.06893679892527871, 0.0027648489049170166, 0.014947821782698156, 0.06316386221442372, 0.04686729371314868, 0.00579229377763113, 0.03702851950947661, 0.028414381740731187, 0.013261540734674782, 0.08739989687455818, 0.019379451805434655, 0.06230453684111126, 0.04662446670408826, 0.012942808716616128, 0.060359564449754544, 0.043985448937746696, 0.025503275937808212, 0.013611265767394798, 0.03768935006519314, 0.04911239062494133, 0.02591143304016441, 0.03700883775309194, 0.032197980472119525, 0.10746865358669311, 0.03832394941127859, 0.017508425153209828, 0.02129885720933089, 0.033209082466783, 0.01852329540270148, 0.039387090801028535, 0.021530282974708825, 0.06083459833462257, 0.012291293969610706, 0.04481027186557185, 0.018241099314764142, 0.04844842820602935, 0.020649067955673672, 0.05852646710991394, 0.10674504475900903, 0.01727627208310878, 0.03105415278696455, 0.027837723719130736, 0.04725904007500503, 0.031773883893038146, 0.014246736209315713, 0.041926248886738904, 0.03718697917065583, 0.07219408507808112, 0.011581082762859296, 0.021469877719937358, 0.024779720915830694, 0.032397291652159765, 0.023165783495642245, 0.04809461301192641, 0.06977509925491177, 0.00861395687024924, 0.05801196210086346, 0.03286229170043953, 0.015413903511216631, 0.025687478846521117, 0.09621436256566085, 0.035537715521059, 0.0885395536897704, 0.0679642589238938, 0.02518765722925309, 0.05349068342184182, 0.03595938156649936, 0.03960253256082069, 0.03124929680780042, 0.007032738421912654, 0.044681312574539334, 0.03711977398779709, 0.08153312301146798, 0.02110411394824041, 0.05120792251545936, 0.010722009719756898, 0.04494231478020083, 0.03901210584444925, 0.028011015201627742, 0.03281915436673444, 0.07431974445353262, 0.03265523620939348, 0.08522105519659817, 0.0388059149554465, 0.007927209589979611, 0.06490753818070516, 0.0275932843942428, 0.032662932280800305, 0.049262972388532944, 0.06470801177783869, 0.028164446812297683, 0.053070479407324456, 0.02099963996442966, 0.008168942858901573, 0.021151201362954453, 0.06072058589779772, 0.041335799905937165, 0.05063305492512882, 0.0066417518337402726, 0.050595424327184446, 0.03965441239415668, 0.10081581174745224, 0.05670671729603782, 0.0642315529694315, 0.02861101005692035, 0.06344601191813126, 0.037283024212229066, 0.04133555499720387, 0.035777978409896605, 0.03787457899306901, 0.029693812793993857, 0.032408045371994376, 0.03902117117831949, 0.025812491767283063, 0.06023586698574945, 0.05364573291444685, 0.0035965165216111927, 0.05115426152769942, 0.052221570076653734, 0.06446354833315127, 0.06003783972118981, 0.036254255392123014, 0.029422555962810293, 0.029314751591300592, 0.019177474459866062, 0.0041114146370091476, 0.06494037821539678, 0.036671490815933794, 0.024471308461215813, 0.05014337475586217, 0.09204833142575808, 0.02868463852792047, 0.10010081925429404, 0.04239210611558519, 0.030992727079137694, 0.06563895440194756, 0.10357732098782435, 0.031272106716642156, 0.022271584603004158, 0.040034484773059376, 0.05004713675589301, 0.0369377362949308, 0.06172933157358784, 0.019873896562785376, 0.07378311231150292, 0.034240066597703844, 0.031983752123778686, 0.03847441985271871, 0.03979262626671698, 0.025299769768025726, 0.08638969287858345, 0.03187471578712575, 0.057687183434609324, 0.021693249327654485, 0.014173737636156147, 0.009387941754539497, 0.0891531168599613, 0.026785924201249145, 0.07953415566589683, 0.0131465171216405, 0.05442775247502141, 0.1364408669178374, 0.023183489283837844, 0.060919570532860234, 0.04978093951649498, 0.04164394333201926, 0.015378019743366167, 0.07723878195974976, 0.06284023387706839, 0.05461058426590171, 0.0035287122864247067, 0.028652818946284242, 0.029224753197922837, 0.09264757856726646, 0.042302610527258366, 0.10335951548768207, 0.03768957270949613, 0.07683732459554449, 0.027963233878836036, 0.026199458698101807, 0.04059827209857758, 0.019968488850281574, 0.05348987448087428, 0.022258122044149786, 0.0028326055962679675, 0.029994519900355954, 0.0436827936937334, 0.0408188124129083, 0.037786096436320804, 0.015220193690765882, 0.05926062927755993, 0.027314110702718608, 0.02496888322639279, 0.02941533486591652, 0.056819939345587045, 0.03353742715262342, 0.06129054418124724, 0.029817838658345863, 0.04596840444719419, 0.024571800822741352, 0.06449293738114648, 0.03511216062179301, 0.04968228211509995, 0.05394655134296045, 0.029926678325864486, 0.017852811361080967, 0.03159314124786761, 0.10878181710722856, 0.03783362728427164, 0.015070510853547603, 0.019251496269134805, 0.022614445697399788, 0.05866294806764927, 0.06199690920766443, 0.05636759291519411, 0.02990289434819715, 0.03435119579080492, 0.02701546862226678, 0.04140371012908872, 0.061803627977496944, 0.02476140100043267, 0.03286020255472977, 0.03750001334992703, 0.029470342851709574, 0.02793407860735897, 0.05318290364812128, 0.040530992700951174, 0.015143837827054085, 0.09652066175476648, 0.0603915324609261, 0.02361543407459976, 0.056800339225446805, 0.0621442923147697, 0.03389504585356917, 0.021647390167345293, 0.03826890060736332, 0.0023613455323356902, 0.03002196637680754, 0.07980853508342989, 0.03420804292545654, 0.16990169329801574, 0.1450166801805608, 0.2173773106187582, 0.0944310039631091, 0.1886475717765279, 0.1545200592954643, 0.0897247857938055, 0.08599204273195937, 0.22077213157899678, 0.1126034843036905, 0.14617585547966883, 0.17523847724078223, 0.21399654593551531, 0.16597509384155273, 0.22492487827548757, 0.13082792982459068, 0.17614141863305122, 0.11341148274368607, 0.2176629038876854, 0.17701494129141793, 0.1648772941553034, 0.1114814831817057, 0.10115118828252889, 0.15952675079461187, 0.14478731201961637, 0.09260727252694778, 0.17200296570081264, 0.1542211667401716, 0.21491373656317592, 0.20334979926701635, 0.14952071505831555, 0.09799976207432337, 0.10657990205800161, 0.08880778812454082, 0.17361548932967708, 0.1250710160820745, 0.11752642443752848, 0.2124898080364801, 0.15025357104605064, 0.1459477489697747, 0.07090182043612003, 0.14462553866906092, 0.23472424072679132, 0.10503282101126388, 0.08963489686721005, 0.1518326683435589, 0.07245425236760639, 0.10242106975056231, 0.12158120021922514, 0.08590046913013794, 0.19088608212769032, 0.1592665835050866, 0.13599033874925226, 0.1209035525971558, 0.2093166220583953, 0.18200290098320693, 0.1994146205834113, 0.11911110268556513, 0.1702305389335379, 0.11019540805136785, 0.1894860205356963, 0.09369543913635425, 0.1594565436244011, 0.1816744264215231, 0.1215590990614146, 0.1510506821796298, 0.1406566664809361, 0.07748475196422078, 0.19339365069754422, 0.18596933892695233, 0.08067011658567935, 0.15879954997217283, 0.13422419055132195, 0.18205771601060405, 0.1296161362552084, 0.13348746055271477, 0.130293108522892, 0.13178391993278638, 0.09110120256082155, 0.10312666665413417, 0.2913859096588567, 0.12821154756238684, 0.19649750523967668, 0.10182617901591584, 0.14562705211574212, 0.1670205721165985, 0.2009968349011615, 0.12290429367567413, 0.1226501377823297, 0.031181583253783174, 0.15118811308639124, 0.09935194771969691, 0.22997678141109645, 0.12838844588259235, 0.12730529619148, 0.1351582130882889, 0.22726236144080758, 0.17928042128914967, 0.15682991972425953, 0.10391319476184435, 0.2748667710693553, 0.16149834031239152, 0.13036865915637463, 0.15080985525855795, 0.16493337083375081, 0.1757134369108826, 0.11230962350964546, 0.12421113409800455, 0.09321874284069054, 0.1533538187504746, 0.1453693932853639, 0.18513578834244981, 0.19431360211456195, 0.27672531665302813, 0.11242151711485349, 0.1276078846422024, 0.17657184944255278, 0.10076610269607045, 0.148640735715162, 0.0888519681757316, 0.08863566181389615, 0.14858874084893614, 0.16168003290658817, 0.11775009290431626, 0.13208153599407524, 0.09415515509317629, 0.18019738927250728, 0.1275279256515205, 0.13042115868302062, 0.12671996431890875, 0.11499205691507086, 0.16225075931288302, 0.11182255198946223, 0.14102995191933587, 0.16614005842711776, 0.15540688124019653, 0.1182494024396874, 0.11782367684645578, 0.14930322126019746, 0.12328200973570347, 0.1295067140017636, 0.14374285790836439, 0.1263671918422915, 0.14887604105751961, 0.10330734250601381, 0.08945893365307711, 0.05979021472739987, 0.14740465907379985, 0.10927263647317886, 0.18454162491252646, 0.22437899897340685, 0.09584369690855965, 0.11800977037637495, 0.11539322484168224, 0.08796138354227878, 0.3175480995560065, 0.14192603586707264, 0.12118204351281747, 0.1530947201536037, 0.17998676776187494, 0.08019023647648282, 0.1463787883403711, 0.15546177048236132, 0.0828361339517869, 0.14082641049753875, 0.12680740415817127, 0.16800791054265574, 0.12349309879937209, 0.11441354537964799, 0.14100605476414785, 0.12395334168104455, 0.1846253836993128, 0.16172873263712972, 0.08870784309692681, 0.29936203791294247, 0.20599819777999073], [0.03018583814991871, 0.06880216591525823, 0.018790492686093785, 0.06289826240390539, 0.052575563386199065, 0.020266472274670377, 0.005281294024825911, 0.06192396722326521, 0.0673877215012908, 0.017965554725378752, 0.08909066513297148, 0.014931434234313201, 0.05078263478935696, 0.06276521758991294, 0.015768001649121288, 0.019126958322885912, 0.0416773548204219, 0.04300728716771118, 0.023686221975367516, 0.041094798580161296, 0.106227077631047, 0.10394247990916483, 0.04434059257619083, 0.09450231693335809, 0.0936056615319103, 0.048626595598761924, 0.024064348071988206, 0.05933936372457538, 0.033567302307346836, 0.12751582864439115, 0.06164467478811275, 0.031198786236927845, 0.04140721677686088, 0.033933756276383065, 0.02329002458282048, 0.08554066851502284, 0.03204024440492503, 0.04243994124408346, 0.032431786676170304, 0.03128952121187467, 0.03840671372017823, 0.035150117764715105, 0.01819570028601447, 0.04537077147688251, 0.036362738828756846, 0.0949656694137957, 0.023362777319562156, 0.04287903291697148, 0.04453251196537167, 0.06660392449703068, 0.0527056915598223, 0.04576505227305461, 0.041385100776096806, 0.04294798956834711, 0.012561993262352189, 0.030755614607187454, 0.07639091534656473, 0.06710344183375128, 0.03662322153104469, 0.007382798812614055, 0.03902811025909614, 0.03961011359933764, 0.06431586094549857, 0.030161824106471613, 0.01693944650469348, 0.05856465802935418, 0.04491487386985682, 0.03738504725333769, 0.040328583054360934, 0.03535770018061157, 0.01693902348051779, 0.05061116527940612, 0.01389141352774459, 0.001920131780934753, 0.04796803601493593, 0.0060285541712801205, 0.03748553404875565, 0.027311539161019027, 0.055753187407390215, 0.01123288933740696, 0.056194694770965725, 0.025372192249051295, 0.011036502219212707, 0.0591977582371328, 0.06098877209296916, 0.06046597729437053, 0.06440833254600875, 0.05182880697248038, 0.02382379945629509, 0.019698844334925525, 0.016173689255083445, 0.02884474761231104, 0.01925161872350145, 0.02105254210619023, 0.018780902282742318, 0.02708024883759208, 0.10270536426105537, 0.031006531025923323, 0.03990011151472572, 0.013055799772700993, 0.02346600820601452, 0.07544715583208017, 0.027952307609666605, 0.04883895373495761, 0.013502757283276878, 0.01088796321710106, 0.047005737651488744, 0.08417392935371026, 0.022185445377544966, 0.0760944199282676, 0.04203134070849046, 0.01597848029632587, 0.017178141606564168, 0.04402420760015957, 0.027661292951961514, 0.046305421128636226, 0.028046176303178072, 0.04107938046217896, 0.02528519955376396, 0.05063822398369666, 0.0328937253652839, 0.013031802427576622, 0.04339680337579921, 0.07745151116978377, 0.04535807704087347, 0.03307855724415276, 0.044180811892147176, 0.03352568266564049, 0.02277217248774832, 0.05369528982555494, 0.07646915997611359, 0.05908974606427364, 0.08519692797563039, 0.0318610936665209, 0.039113991588237695, 0.0274708727010875, 0.023491866486438084, 0.051031042748945765, 0.04950292357534636, 0.053947271226206794, 0.07287204440217465, 0.03681355272419751, 0.05907376762479544, 0.060340791824273765, 0.029758210803265683, 0.04785164870554581, 0.04966833344951738, 0.011595779142226093, 0.03294891517725773, 0.06202061711519491, 0.00973947577222134, 0.036737044720212, 0.052585960875148885, 0.03933377120119985, 0.047318775541498326, 0.08170766872353852, 0.03051237014005892, 0.0801378334290348, 0.030769028926442843, 0.049441421797382645, 0.07851289366954006, 0.007591742141812574, 0.015026225973997498, 0.00754293108911952, 0.05653252039337531, 0.06763867131667212, 0.05034401809098199, 0.004678123705161852, 0.04421925143105909, 0.0478129865223309, 0.0374819606076926, 0.0336751586291939, 0.023913463883218355, 0.03656936016341206, 0.0541473653720459, 0.05194366545765661, 0.0217642227653414, 0.05780557454272639, 0.028784893402189482, 0.06594802922336385, 0.04253822386090178, 0.03905728037352674, 0.01749092902173288, 0.06981676342547871, 0.07222377098514698, 0.05548531662498135, 0.048117003607330844, 0.023912922115414403, 0.004158348983764881, 0.0913868032512255, 0.012735394211631501, 0.011028520420950372, 0.04439564509084448, 0.07098772402969189, 0.027658814178721514, 0.03173956327373162, 0.008560051901440602, 0.03426147384743672, 0.04259852707036771, 0.04021047025162261, 0.03311170898086857, 0.04111161193577573, 0.014258016854000743, 0.054325339806382544, 0.03229680114600342, 0.006182239039844717, 0.056056651592371054, 0.0511635606380878, 0.021995197676005773, 0.023968534951563925, 0.01717564242426306, 0.033574968692846596, 0.04459978394152131, 0.02473691198247252, 0.0980443725711666, 0.04362971900263801, 0.061813680367777124, 0.04480516588955652, 0.020951674960087985, 0.03529055436956696, 0.04510829981882125, 0.10631132623529993, 0.06634094446781091, 0.035122161061735824, 0.05895005160709843, 0.05299723685311619, 0.016002811607904732, 0.046990338087198325, 0.04542316710285377, 0.05662812014634255, 0.010593675688141957, 0.03891399763233494, 0.04027554918138776, 0.05116065884067211, 0.034956970121129416, 0.06572862068424001, 0.025756053291843273, 0.036097669653827325, 0.07458222724380903, 0.02412651592749171, 0.05333873981726356, 0.06851777492556721, 0.052180098864482716, 0.03640013936092146, 0.07196085032774135, 0.07212304670247249, 0.03819116063823458, 0.03842426180199254, 0.03917156740499195, 0.05985842552036047, 0.09025103528983891, 0.047129379454418086, 0.06307648174697533, 0.042615941565600224, 0.04691270944022108, 0.08746662337216549, 0.04632833122741431, 0.0069935994088154985, 0.014901929225743515, 0.07740313798421994, 0.024197869715862907, 0.027899527922272682, 0.058518258956610225, 0.013585047545348061, 0.026602769576129504, 0.010320863129891222, 0.01571753375174012, 0.02009936659305822, 0.04899231484159827, 0.019756546316784807, 0.0623587507288903, 0.03912976222636644, 0.009904736289172433, 0.08258565168944187, 0.07104379328666255, 0.034494979481678456, 0.02100239333231002, 0.08626167982583866, 0.03149744130496401, 0.059667200039257295, 0.03511464310577139, 0.02254625902423868, 0.0072909705613710685, 0.062479423941113055, 0.02116263971402077, 0.04469746912945993, 0.048931106211966835, 0.008147165463014971, 0.047626566447434016, 0.023847331103752367, 0.007937364953249926, 0.01965857169125229, 0.04018710373202339, 0.09389981176354922, 0.03318460272566881, 0.034928141394630075, 0.021901948675804306, 0.07391968974843621, 0.025317972795164678, 0.01663539973378647, 0.02985855102451751, 0.03909523380571045, 0.020246326675987802, 0.014619569865317317, 0.00778381274358253, 0.09154626852250658, 0.026797076825459953, 0.09142101625911891, 0.01702226833003806, 0.05769018913269974, 0.047072412198758684, 0.001989755901377066, 0.05080621653178241, 0.016020565635699313, 0.024676625471329316, 0.07121574890334159, 0.04827818695048336, 0.021453852896229364, 0.04882257082499564, 0.034222577887703665, 0.04603576548106503, 0.05337071524991188, 0.06063454500690568, 0.07911370674264617, 0.011326573421683861, 0.01973244136024732, 0.0473395630979212, 0.041441170033067465, 0.006215732164491783, 0.07329074185690843, 0.04493071872275323, 0.05034788468037732, 0.0023831053022149717, 0.05278673408611212, 0.007664115455554565, 0.1119537340127863, 0.007505385838157963, 0.021240177447907627, 0.033620503163547255, 0.03226848450140096, 0.052378615946508944, 0.011505762195156422, 0.057849142322083935, 0.031838940558373, 0.04345381516031921, 0.05380222588428296, 0.016962035624601413, 0.04829768316994887, 0.07780768268276006, 0.01340982276815339, 0.02902075349993538, 0.016198200537473895, 0.1200184746994637, 0.2167763639590703, 0.17315145407337695, 0.11952025612117723, 0.176719774317462, 0.08227123340475373, 0.07710433448664844, 0.22390184254618362, 0.1716937276069075, 0.10426800814457238, 0.23956099525094032, 0.08469166641589254, 0.1147388583922293, 0.16028010490117595, 0.1088446844369173, 0.06296487015788443, 0.15064714680192992, 0.110574274440296, 0.08879678949597292, 0.12962818873347715, 0.18027718499070033, 0.2577353606466204, 0.13380217569647357, 0.15100780088687316, 0.11469900506199338, 0.23110174370231107, 0.10981249695760198, 0.12515253358287737, 0.1454396895132959, 0.22792754840338603, 0.1116908504627645, 0.13942556222900748, 0.17938230332219973, 0.12890308076748624, 0.19036712794331834, 0.15110466600162908, 0.10144369094632566, 0.1304277341114357, 0.14335440297145396, 0.0913668394787237, 0.15125983423786238, 0.15885728906141594, 0.1384155882988125, 0.13534747558878735, 0.09665348392445594, 0.1796925804228522, 0.16075268969871104, 0.1397698000073433, 0.18593071756185964, 0.18825518345693126, 0.16720153740607202, 0.1883807103149593, 0.1196404395159334, 0.10519021569052711, 0.12219411029946059, 0.11694070664816536, 0.22387346281902865, 0.2418372660758905, 0.11259940249146894, 0.1242712554812897, 0.20758667582413182, 0.16190181631827727, 0.18670320423552766, 0.1269491098355502, 0.11761351546738297, 0.22559193545021117, 0.21694931405363604, 0.18739856692263857, 0.1822497689863667, 0.24187481874832883, 0.09818552163778804, 0.16084180679172277, 0.21197506925091147, 0.18645528238266706, 0.1533308270154521, 0.12361969435005449, 0.12562439107568935, 0.2614063199143857, 0.16678514803061262, 0.15187455515842885, 0.1541409851051867, 0.0898224078991916, 0.09469380587688647, 0.12813023786293343, 0.14098049519816414, 0.0606792037433479, 0.12375356294796802, 0.16139721526997164, 0.1429671057849191, 0.09710010097478516, 0.10557021756540053, 0.08932535449275747, 0.11659767857054248, 0.09814491131692193, 0.14400820538867265, 0.1869464060291648, 0.19679020828334615, 0.09711281396448612, 0.17648436507442966, 0.11515049802255817, 0.1753725387970917, 0.14716335717821494, 0.1994504960021004, 0.17444019351387396, 0.11759468718082644, 0.11167999284225516, 0.08256104207248427, 0.169760744611267, 0.09266092238249257, 0.15164150594500825, 0.13609556044684723, 0.08137727942084894, 0.17471772705903277, 0.12378102983348072, 0.12579719274071977, 0.10518844937905669, 0.13251275348011404, 0.19002312765223905, 0.17479871021350846, 0.1285836158785969, 0.09619816148187965, 0.16419966879766434, 0.12393036478897557, 0.1296388459741138, 0.13452014420181513, 0.08116694734781049, 0.11549367452971637, 0.14582807023543864, 0.14067483425606042, 0.2639747742796317, 0.17147341364761814, 0.1573208355694078, 0.11828148548374884, 0.1832468740758486, 0.21148961561266333, 0.11684422002872452, 0.1248588360613212, 0.15450298989890143, 0.1360479145660065, 0.15969597530784085, 0.14267446211306378, 0.13636844814755023, 0.18145074311178178, 0.1807469199411571, 0.12074213547748514, 0.1527205589809455, 0.09631160617573187, 0.10621633133268915, 0.08496676571667194, 0.11152204155223444, 0.07998437955393456, 0.11060974909923971, 0.13670695654582232, 0.1497178294812329, 0.12252503394847736, 0.1610851867008023, 0.07174189449870028, 0.15647294669179246, 0.1596426742617041, 0.1659197741537355, 0.14968759438488632, 0.13050185982137918, 0.10163901679334231, 0.12002713556285016, 0.18358144909143448, 0.13126612349878997, 0.20845908526098356, 0.09398921087267809, 0.09611499641323462, 0.14348533266456798, 0.1751679732115008, 0.17239277134649456, 0.1667265480500646, 0.06837932727648877, 0.25624969974160194, 0.12463648861739784], [0.02412167341390159, 0.021781850628030952, 0.02175795532821212, 0.01554696316816262, 0.043089134924230166, 0.036384127524797805, 0.02118754062394146, 0.05410317789937835, 0.043429802972241305, 0.027014500119548757, 0.08264498639618978, 0.0489404312975239, 0.035628632322186604, 0.05505816610821057, 0.025483852077741176, 0.015995328903954942, 0.037465061905095354, 0.028485652037488762, 0.08684131200425327, 0.01627986832318129, 0.055071632377803326, 0.05029163359722588, 0.04805703807505779, 0.02167446928069694, 0.06434950992115773, 0.01503732479250175, 0.03772011579712853, 0.02393952996499138, 0.024515800214430783, 0.0015470892799385183, 0.05993740487610921, 0.030214626058295835, 0.0758538008085452, 0.03448669711360708, 0.025827262361417525, 0.02882932578359032, 0.013289942726260051, 0.01769759488524869, 0.05478395367390476, 0.013736057899222942, 0.01081990085367579, 0.061487803322961554, 0.07973225714522414, 0.024174293539545033, 0.06549939353135414, 0.0658333525643684, 0.025068212271435186, 0.05898053161217831, 0.013205849045334617, 0.03079370904742973, 0.015987475126166828, 0.016156005731318146, 0.024420515874226112, 0.059246027522021905, 0.009035041257448029, 0.06926965215825476, 0.025004600938700605, 0.025609351105231326, 0.07989395628101192, 0.10517392554902472, 0.02811696605931502, 0.0453951844247058, 0.01882663527794648, 0.055727620419929735, 0.03894501940521877, 0.04143632380873896, 0.048837406357051805, 0.05337067814252805, 0.021379953541327268, 0.03749759023776278, 0.022842066100565717, 0.03622433199780062, 0.07249228001455776, 0.10739691017079167, 0.009272318857256323, 0.04759584895509761, 0.07499700615881011, 0.08161488542100415, 0.011323716153128771, 0.06634273304371163, 0.1221725286450237, 0.057165646576322615, 0.0114731225403375, 0.012245511807122966, 0.0211770188252558, 0.0656843589968048, 0.030054711787670385, 0.02478510890796315, 0.011211654637008905, 0.009678188289399259, 0.014069555872993078, 0.0060345674228301505, 0.06523325937450863, 0.008821810170047684, 0.011281924889772199, 0.11229138151975349, 0.042155041883233935, 0.033849088358692825, 0.0850044668186456, 0.03377653600182384, 0.037709243333665654, 0.04489251667109784, 0.052471673843683675, 0.03975898842327297, 0.025245836040994618, 0.016574454566580243, 0.06416534597519785, 0.03650449274573475, 0.06356528247124515, 0.019075629534199834, 0.017610225550015457, 0.04799170681508258, 0.06668959802482277, 0.08564783463953063, 0.01273077341465978, 0.018699011852731928, 0.021190494371694513, 0.07148642500396818, 0.035905575859942473, 0.038547009316971526, 0.09804717788938433, 0.022713375838065986, 0.02073152983939508, 0.048621237292536534, 0.026126551965717226, 0.014732694507983979, 0.022071475614211522, 0.02579217547463486, 0.0543524838576559, 0.012324332528805826, 0.042284019727958366, 0.06695355026749894, 0.09313142174505629, 0.046720303944312036, 0.025254552565456834, 0.04635168661479838, 0.004950016464135842, 0.0167430872170371, 0.12087393348338082, 0.049346690357197076, 0.012854936576331966, 0.01893348784506088, 0.023958896308613475, 0.019782673625741154, 0.09264340769732371, 0.02946200667793164, 0.06603950634598732, 0.042605740745784715, 0.019968481428804807, 0.058698853172245435, 0.03875362323014997, 0.06538324741995893, 0.053921177313895896, 0.026902357894869056, 0.02431270964734722, 0.09900959499645978, 0.046780722186667845, 0.05463357600092422, 0.021594992686004844, 0.08494433801388368, 0.015381776865979191, 0.04795183122041635, 0.035666904877871275, 0.010018087286880473, 0.048381991146015935, 0.025663661472208332, 0.03791164555877913, 0.059744865793618374, 0.05721306239138357, 0.07723205068032257, 0.01702494377241237, 0.0723957340233028, 0.060345151941874065, 0.04697553966252599, 0.04194218279735651, 0.04549054669041652, 0.0350114623142872, 0.0433581411925843, 0.0068875863962603034, 0.007915811129350914, 0.030058639604249038, 0.05283231679641176, 0.04095067721209489, 0.028659915733442176, 0.024739785949350335, 0.042728506814455613, 0.0443758334586164, 0.015275197038135957, 0.04697159514762461, 0.02252620990475407, 0.037503976418520324, 0.048059316468425095, 0.022844325940241106, 0.023781641757523175, 0.02307392602233449, 0.011575037042348413, 0.022494293843919877, 0.017834587924880907, 0.008451429312117398, 0.033876273228088394, 0.013628210854221834, 0.03301577155070845, 0.04749007064674515, 0.04939122292853426, 0.027880584602826275, 0.0077832533497712575, 0.026351142550993245, 0.02315489804459503, 0.03525174004607834, 0.023773749016982038, 0.043365640594856814, 0.027109632319479715, 0.005437284189611091, 0.02850918554031523, 0.050037013861583546, 0.03396778003661893, 0.04031594799016602, 0.023770507687004283, 0.07036880997475237, 0.04084597501787357, 0.019432036679063458, 0.05863398575456813, 0.01439693298380007, 0.046582835930166766, 0.03513389441650361, 0.021027234870416578, 0.014194685682014097, 0.05227359833952505, 0.031718326717964374, 0.052609728154493496, 0.05840743033331819, 0.035029897262575105, 0.038759170784032904, 0.0019913812047889223, 0.025424888444831595, 0.02559971431765007, 0.026016129668278154, 0.04681027450715192, 0.04832365091715474, 0.017440863739466295, 0.02626028512167977, 0.023622953885933384, 0.006989024532231269, 0.048994270400726236, 0.038635336022707634, 0.015215656385407783, 0.02754226174147334, 0.046393276570597664, 0.02770668641460361, 0.12833382381359115, 0.05060861229139846, 0.027154218696523458, 0.0424606916931225, 0.02539998011343414, 0.022399319350370206, 0.047118889197008684, 0.08546387849492021, 0.0317489291774109, 0.028964598895981908, 0.023106697408366017, 0.008384265875065466, 0.05212547679548152, 0.022188000220921822, 0.055342909618048, 0.0395421774010174, 0.07462864115950651, 0.04049135088280309, 0.07135881271096878, 0.06875943305203691, 0.0492279467289336, 0.04441397242771927, 0.00729930951820279, 0.049388057668693364, 0.04124192564631812, 0.04823665636649821, 0.04954845062457025, 0.0027806527077700594, 0.09354447887744755, 0.06763225916074589, 0.009563474523019977, 0.040542406932218, 0.05489866001880728, 0.033857764065032825, 0.05236495671852026, 0.02702753965422744, 0.01928341604070738, 0.01902906718896702, 0.014240689561120234, 0.04524730407865718, 0.02532252030505333, 0.022319701747619547, 0.0190880530863069, 0.00829571745271096, 0.04599255022185389, 0.021255621541058645, 0.057528645847924054, 0.08089983355603181, 0.025587806558178272, 0.06526342767756432, 0.041529029185767286, 0.04042819782625884, 0.021135599563422147, 0.01800950656615896, 0.058135897052125074, 0.014676655864604982, 0.02847953302989481, 0.035282260869280435, 0.008983631760202115, 0.031470189642277546, 0.04193161461444106, 0.030229277908802032, 0.036499872876447625, 0.019071972601523157, 0.017005668341880664, 0.012309335579629987, 0.03837333191768266, 0.030102014425210655, 0.015156991466938052, 0.035177658864995465, 0.023314691716223024, 0.0543045893573435, 0.030824157511233352, 0.03137608160614036, 0.026710438505688217, 0.062279526464408264, 0.03771336225327104, 0.048595725966151804, 0.06807918049162254, 0.07385072196484543, 0.04001145964139141, 0.011227494851482334, 0.04728610620077234, 0.04973956478352193, 0.009818733433348825, 0.002807316914186231, 0.052489678346319124, 0.02605807028885465, 0.039475877638324164, 0.022251466834859457, 0.0404359087406192, 0.041592983761802316, 0.013852641877747374, 0.010286900596838677, 0.018808029635692947, 0.04193989698251244, 0.08790614549070597, 0.08491688597132452, 0.0786453892942518, 0.05384138901717961, 0.07089289239956997, 0.06554024133947678, 0.027109136935905553, 0.10078089369926602, 0.08405286280321889, 0.1327825538464822, 0.11753105543903075, 0.07695141495787539, 0.1023074246768374, 0.14846926991594955, 0.11911723282537423, 0.09006017717183568, 0.05846107276738621, 0.1874965155730024, 0.11526988731930032, 0.0771849910961464, 0.14173757488606498, 0.11786236500483938, 0.23657883808482438, 0.10677296435460448, 0.10197549170698039, 0.12933787540532649, 0.11653302266495302, 0.13188148266635835, 0.08246552024502307, 0.1759224256966263, 0.12055735554895364, 0.24711110105272382, 0.10779892414575443, 0.1407417908194475, 0.094230512768263, 0.1431732892524451, 0.08237606176408008, 0.11202778550796211, 0.116227784747025, 0.13786513736704364, 0.13579708349425346, 0.09441969363251701, 0.23153944755904377, 0.034325769811403006, 0.1062506037123967, 0.11416131164878607, 0.06935574871022254, 0.12542712822323665, 0.11810233103460632, 0.17934761533979326, 0.11580447855521925, 0.13298254780238494, 0.11803981993580237, 0.108000639884267, 0.16194490541238338, 0.09196706625516526, 0.0921318749897182, 0.111760144791333, 0.13564568536821753, 0.07604382772115059, 0.1122200908139348, 0.13656961469678208, 0.13422778254607692, 0.1652451025438495, 0.0927104904258158, 0.20770435075974092, 0.2019607214606367, 0.07608732499647886, 0.19612494710600004, 0.10973220400046557, 0.10922550267423503, 0.12604658404598013, 0.13054790266323835, 0.11987164820311591, 0.11337894698954187, 0.1269962510559708, 0.05047345606726594, 0.0869279725884553, 0.22178703336976469, 0.13512679055565968, 0.30420211725868285, 0.19084863335592672, 0.172604788094759, 0.2166582882637158, 0.15322409133659676, 0.09766955830855295, 0.1415118877775967, 0.21874299593036994, 0.1269606576533988, 0.1101786429353524, 0.13573745934991166, 0.10112619274877943, 0.14347666437970474, 0.1547381913405843, 0.16537827352294698, 0.16639382840367034, 0.13132077525369823, 0.16517477663001046, 0.1179880254494492, 0.13110305881127715, 0.10675690427888185, 0.22589645348489285, 0.1807741419179365, 0.12321863032411784, 0.11292251874692738, 0.15940616664011031, 0.15421050949953496, 0.10569288715487346, 0.17065573018044233, 0.24679595546331257, 0.12193610265967436, 0.07996371816261671, 0.18657205189811066, 0.11295798598439433, 0.11213097372092307, 0.114342455053702, 0.07668074627872556, 0.06291578451055102, 0.06919219420524314, 0.2637520112330094, 0.22133948863483965, 0.19393800117541105, 0.09696692257421091, 0.10115430530277081, 0.10518595576286316, 0.19329636998008937, 0.19602732500061393, 0.21875120408367366, 0.12285782038816251, 0.15795284853084013, 0.09986750286770985, 0.11179095876286738, 0.12138462756411172, 0.11140447051730007, 0.11738005065126345, 0.10097060890984721, 0.12326731521170586, 0.11909400360309519, 0.16976720129605383, 0.18176159908762202, 0.1416648889426142, 0.19611595227615908, 0.14417495112866163, 0.1226301740098279, 0.18515244213631377, 0.20714318321552128, 0.11810751122538932, 0.08294500701595098, 0.12628567434148863, 0.14895482745487243, 0.13093098445096985, 0.16974523372482508, 0.11112650652648881, 0.11707688332535326, 0.16117823717650026, 0.1436874343198724, 0.12163661638624035, 0.17207930301083252, 0.08982313520391472, 0.15045745385577902, 0.1042683569539804, 0.08882389272912405, 0.19229101220844314, 0.1202809797541704, 0.14979965868405998, 0.1444472005823627, 0.22053378343116492, 0.12110808849683963, 0.10129013317055069, 0.1804792569600977, 0.0668024861079175, 0.21151167224161327, 0.10837169887963682, 0.10253280750475824, 0.12605232826899737, 0.13574697368312627, 0.18152816395740956, 0.12898384127765894, 0.13286748522659764, 0.14708341303048655, 0.1738352986285463, 0.25097911537159234, 0.1638159339199774], [0.015834440564503893, 0.026848958514165133, 0.05651764775393531, 0.044730520676239394, 0.035442082371446304, 0.06734095135470852, 0.04582869143632706, 0.027209072686673608, 0.03981247871706728, 0.04796028799319174, 0.040108191169565544, 0.024794421005935874, 0.01674106857535662, 0.03183537824952509, 0.05476006765093189, 0.05746490649471525, 0.0805838344967924, 0.03722883258888032, 0.09195232720230706, 0.05008701606129762, 0.03820458608970512, 0.011321014735585777, 0.07334180161706172, 0.01138656214607181, 0.036739876013598405, 0.029484133810910862, 0.19078216661000624, 0.004065429311594926, 0.05947113946604077, 0.02539792621973902, 0.023907174181658775, 0.03071305985940853, 0.07188232368207537, 0.03720405598869547, 0.03352947504026815, 0.04794554151885677, 0.054902500633033924, 0.03991191908426117, 0.0016156881929418887, 0.04267500167770777, 0.09968304948415607, 0.022744965353922453, 0.014911375837982632, 0.017186286677315366, 0.07058453746140003, 0.07532085714046843, 0.02599378360173432, 0.03376752261829097, 0.019245347575633787, 0.07721700734691694, 0.012424904671206605, 0.050290453582420014, 0.043181020228075795, 0.015909737012407277, 0.08579246437875554, 0.035581320407800376, 0.060315707232803106, 0.01823152746510459, 0.07839461759431288, 0.06958924321224913, 0.019440024043433368, 0.029277564426593017, 0.08600405068136752, 0.051590829898486845, 0.01974559036170831, 0.0116418117795547, 0.013605463100248016, 0.08228092585341074, 0.07807836620486341, 0.00690276517161692, 0.01510446410975419, 0.014832416891294997, 0.05227511232078541, 0.03635911714809481, 0.030703621596330777, 0.01093557106287335, 0.035770360263995826, 0.003605699439503951, 0.038014188103261404, 0.05102670860651415, 0.033191608599736355, 0.019118720483675133, 0.05798388294351753, 0.03645257209427655, 0.04965418811480049, 0.09662331562140025, 0.026721863869170193, 0.058674399406299926, 0.05512416530109476, 0.04783186304848641, 0.018184642285632435, 0.020318511669756845, 0.08556472894269973, 0.0304718507322832, 0.04578739833959844, 0.037816346375620924, 0.058387065801071, 0.06635346449911594, 0.06549912635819055, 0.038070754599175416, 0.030325319239636883, 0.06804516044212505, 0.04908410737698432, 0.06353314747684635, 0.010750763303803978, 0.05096493594464846, 0.08013979269890115, 0.018631771417858545, 0.06506080651888624, 0.050706004331004806, 0.031246892249328084, 0.048854323613340966, 0.08336001599673182, 0.0714151565625798, 0.058895373877021484, 0.047022035214467905, 0.04538308741757646, 0.03944113399484195, 0.0192805123879225, 0.04960813414072618, 0.024066687692538835, 0.03238848606997635, 0.047418809626833536, 0.010830228766280925, 0.0244501312772627, 0.07141595066059381, 0.059184833735344, 0.04661515646148473, 0.018342055518587586, 0.013273659078549827, 0.06638807826675475, 0.036229961187927984, 0.0464662816375494, 0.05471709730045404, 0.014188886725605698, 0.026083757875312585, 0.08898059721104801, 0.04317537990573328, 0.055974221249925904, 0.015653482696507126, 0.023202905722428113, 0.047550711533403955, 0.03577300602046307, 0.04300119042454753, 0.012187393294880167, 0.034736875095404685, 0.02930563616246218, 0.04221671064442489, 0.009301131813117536, 0.01613194715901045, 0.04144011989410501, 0.010169802681048168, 0.004176697657385375, 0.02485997676558327, 0.0269370069145225, 0.0361537352000596, 0.016289282466459554, 0.070920285070315, 0.014618389850511448, 0.0417052187549416, 0.04630267147149425, 0.10363376131863333, 0.046764988655922934, 0.04151421591814142, 0.016457894707855303, 0.014949946180422558, 0.07814255455741659, 0.038286500639515, 0.02097424367093481, 0.06096984361647628, 0.03215842029021587, 0.0119314302719431, 0.05644532917358447, 0.024870769448170904, 0.013693736927962163, 0.03366408578585833, 0.03521069185808301, 0.04700452052929904, 0.030292616502265446, 0.023964584870554972, 0.03457494589383714, 0.03586275393899996, 0.07768666808260605, 0.023934611381264403, 0.06647073125350289, 0.041567747030057944, 0.04715660885267425, 0.03683907518279739, 0.05418462118541356, 0.05076991437817924, 0.09694231295725331, 0.05234082207607571, 0.0817329017445445, 0.03333586355438456, 0.06403078717994504, 0.07547409579274245, 0.06109746333095245, 0.032947954096016474, 0.04505862787482329, 0.02142311499483185, 0.024507289635948837, 0.006361408795783063, 0.10577557724900544, 0.010545072436798364, 0.09903237893013284, 0.025902477173076477, 0.06270679572480731, 0.10804107951116748, 0.04655615572119132, 0.020327083475422114, 0.04043467306473758, 0.08846830751281232, 0.026101192779606208, 0.0801539677195251, 0.02212390463682823, 0.01486195344114094, 0.06875298378872685, 0.055125671860878356, 0.07529068141593598, 0.017902397958096117, 0.029301845643203706, 0.03576008522941265, 0.013405782701738644, 0.02334764678380452, 0.03765517787542194, 0.03563074002158828, 0.029178387521824334, 0.037767197645734996, 0.01507655564637389, 0.013339355846255785, 0.08922237408114597, 0.021091358285048045, 0.026428301789565012, 0.052844016754534096, 0.014616786811529892, 0.020598199298547115, 0.041905721082002856, 0.10192314060986973, 0.011388710663595702, 0.04572212274069898, 0.023176539070846047, 0.02838468655681936, 0.031135109966271557, 0.03538864773872774, 0.02673059338121675, 0.043043771147495136, 0.042542268565739505, 0.025435000206925906, 0.036827916992479004, 0.04846979463764001, 0.05233531534031499, 0.06375095297698863, 0.036192449333611876, 0.022398330438591074, 0.057346285320818424, 0.06327128066914156, 0.0395562967605656, 0.02646944089065073, 0.027425275147834327, 0.04428117252246011, 0.06755916503607295, 0.05341702897567302, 0.03550279747287277, 0.05102776245621499, 0.028098104376113042, 0.01836136249039555, 0.04158765514148399, 0.0027877249112862046, 0.035168296672054566, 0.02428263225738192, 0.039507712062913924, 0.0817579789145384, 0.06381546787451953, 0.013681807831744663, 0.026292722541256808, 0.05489468952873722, 0.01027623036861769, 0.005806733188364888, 0.01336206649284577, 0.04026462476758752, 0.0509057236922672, 0.03768926842894871, 0.029588591096398886, 0.04520663067523856, 0.11017798984539695, 0.07927205137093551, 0.02670659789146157, 0.07178657921031117, 0.05409620171121787, 0.06488142942544073, 0.02550798857555492, 0.11307082211715169, 0.011334178580000298, 0.06974292715312913, 0.036359499354148284, 0.061320211534621194, 0.0014773643897569855, 0.080067277449416, 0.04641968960640952, 0.026646977457858156, 0.04023374400276225, 0.026430415055074263, 0.04405121064337436, 0.031130920542636886, 0.015192245336947963, 0.03203871186997276, 0.009903333630063571, 0.041124647759716026, 0.05458408217236865, 0.019312018412165344, 0.007118524199540843, 0.05389836740505416, 0.09970639002858661, 0.03449968840868678, 0.0517883450811496, 0.010617719417496119, 0.12453773844754323, 0.018579509378469083, 0.05875913782801945, 0.025153407113975845, 0.08008615026483312, 0.07916464033769444, 0.020319430077506695, 0.035842266952386126, 0.04812534163647797, 0.009427153127035126, 0.053161492687650025, 0.03361783514264971, 0.009865292995527852, 0.072597397811478, 0.01186048837553244, 0.0065370125321351225, 0.03535482435836457, 0.04421040874149185, 0.02924904925748706, 0.04618512270099018, 0.058572424604790285, 0.047533645847579464, 0.045476687082555145, 0.02675075753359124, 0.056944059833767824, 0.024834344840201084, 0.06620527245104313, 0.07424642026307993, 0.0681227000313811, 0.09503349428996444, 0.04642497740860563, 0.02568276620877441, 0.09277032237150706, 0.07158248117775656, 0.044394568976713344, 0.006397953075065743, 0.21970746136503294, 0.10270926053635776, 0.15524197602644563, 0.14559177041519433, 0.1269460076582618, 0.07940356736071408, 0.15796273393789306, 0.2727490378310904, 0.23390909540466964, 0.10437933771754615, 0.11533524084370583, 0.09770348187885247, 0.19500825233990327, 0.16400350432377309, 0.1237915460660588, 0.2526276034768671, 0.12322804075665772, 0.08990085290861316, 0.10886101168580353, 0.16466199711430818, 0.12409551491145976, 0.1356038430822082, 0.19289031130028889, 0.11282937179203145, 0.1136057918483857, 0.09677969355834648, 0.2588038158137351, 0.13373609486734495, 0.20839531993260607, 0.1971332437824458, 0.16229840519372374, 0.14519832824589685, 0.19517018896294758, 0.14136823767330498, 0.09548265690682456, 0.1964545645751059, 0.14226329745724797, 0.18831958703231066, 0.1581377917318605, 0.2194570458959788, 0.20306082180468366, 0.08967283545644023, 0.231597468664404, 0.19838275329675525, 0.16083894210169092, 0.0953323497378733, 0.06197257789608557, 0.10565497825155035, 0.07699294554186054, 0.19821182184386998, 0.07972723280545324, 0.14278991060564294, 0.15826518880203366, 0.13788226613542065, 0.1303204195573926, 0.06775358546292409, 0.11696228830260225, 0.14595546730561182, 0.15907482738839462, 0.18820854689693078, 0.1098425242525991, 0.11999870388535783, 0.16218530188780278, 0.1922218143590726, 0.08816477653454058, 0.10495797541807406, 0.07371835250523873, 0.09987940691644326, 0.23589946125866845, 0.0758178585965652, 0.12506645929533988, 0.21135077462531626, 0.15404363017296419, 0.1134302219725214, 0.224051637633238, 0.1967354229418561, 0.1712901922292076, 0.14310443279100582, 0.09552968680509366, 0.165811836195644, 0.14312173967482522, 0.17892778239911422, 0.18259237403981388, 0.16278391820378602, 0.2077578892931342, 0.29655146528966725, 0.09468628049944527, 0.17185621341923252, 0.17789174424251541, 0.1457315168227069, 0.19971312722191215, 0.14402914879610762, 0.20359288231702521, 0.14087531802942976, 0.14269932406023145, 0.24271230271551758, 0.1379437604919076, 0.08966767753008753, 0.14779590448597446, 0.15297955367714167, 0.12878012174041942, 0.12452053546439856, 0.13732198916841298, 0.12822100252378732, 0.18407862866297364, 0.1992844181950204, 0.1604830229189247, 0.12509302818216383, 0.21438081515952945, 0.17541893786983564, 0.18405955546768382, 0.16540182929020375, 0.17007562302751467, 0.22769936767872423, 0.13019357167650014, 0.1384653418790549, 0.11219122869079001, 0.155728438985534, 0.11311489084619097, 0.16571270010899752, 0.09443062546779402, 0.13606394495582208, 0.09938899573171511, 0.1353371745790355, 0.13434201391646639, 0.1108358518104069, 0.1566972682485357, 0.09319323522504419, 0.06721517216647044, 0.11926719118491746, 0.09306140011176467, 0.09742605965584517, 0.1980893823201768, 0.12653874669922516, 0.0939465373812709, 0.18845919985324144, 0.25437972508370876, 0.09988598234485835, 0.1820660280645825, 0.08864502029609866, 0.29696962097659707, 0.09884257466183044, 0.18869530671508983, 0.18297468399396166, 0.13943353289505467, 0.12549343169666827, 0.15081512450706214, 0.2100218998384662, 0.14046982338186353, 0.1204619302006904, 0.15164763608481735, 0.1774434425169602, 0.0735343963606283, 0.14823387551587075, 0.06397045799531043, 0.09636959759518504, 0.11906105224625207, 0.12265920682693832, 0.07625993370311335, 0.23580814740853384, 0.08874208579072729, 0.1467084206524305, 0.1689796193386428, 0.16512753150891513, 0.10152960196137428, 0.1278544112574309, 0.11790253745857626, 0.1153911542496644, 0.24466872273478657, 0.20252919173799455, 0.11598063472774811, 0.1306898458278738, 0.22542162740137428, 0.1870589898317121, 0.13530435680877417, 0.20690330624347553], [0.05057926035078708, 0.07388502403046004, 0.0419072387740016, 0.06967723966226913, 0.02515666143153794, 0.09011468049720861, 0.02867226878151996, 0.0829923634591978, 0.019059955375269055, 0.07987743607372977, 0.027997094366583042, 0.07152225589379668, 0.02589100542536471, 0.1379233514307998, 0.04233101622958202, 0.028636122478928883, 0.021563421723840293, 0.023264828669198323, 0.0440887596050743, 0.057222806790377945, 0.03394599429157097, 0.08028678988921456, 0.024555521813454106, 0.027986459390376695, 0.0598808829090558, 0.029418435187835712, 0.012679940009547863, 0.00860060470586177, 0.07552346345619299, 0.03457974016782828, 0.027109686125186272, 0.05845992243848741, 0.026832043113245163, 0.024905969512474257, 0.05519797188753728, 0.04162834709859453, 0.036732038934133016, 0.07429400677210651, 0.039859029930084944, 0.039813599360059015, 0.030155230124364607, 0.006062033844500547, 0.03103359900705982, 0.049032045717467554, 0.03318789786135312, 0.03667078577564098, 0.0022275223909673514, 0.051302535212016664, 0.027846699995279778, 0.01064126961864531, 0.04577770218020305, 0.0582123568165116, 0.06674191943602636, 0.07054789020912722, 0.019689012733579148, 0.022881210679770447, 0.07903373290901072, 0.03461654698185157, 0.038846295210532844, 0.033704540255712345, 0.008661572137498297, 0.01824940394726582, 0.015347105581895448, 0.023652010822843295, 0.023933833981573116, 0.03967620927141979, 0.05844692743266933, 0.0636047350417357, 0.00895363971721963, 0.10168762746616267, 0.025103364096139558, 0.03573172776668798, 0.021661131031578407, 0.03112647322268458, 0.1546277300803922, 0.26046492042951286, 1.1126128351315856, 0.8404351025819778, 1.6594917210750282, 1.313771903514862, 3.8220847584307194, 2.3505275091156363, 3.465203633531928, 4.000353617593646, 1.6247112373821437, 1.2818496976979077, 0.5370457260869443, 0.6690818129573017, 0.9358632413204759, 1.2312466255389154, 1.0698048071935773, 1.4353994582779706, 1.0890815290622413, 0.8268421632237732, 0.40595062309876084, 0.4354413750115782, 0.26232403004541993, 0.2292515547014773, 0.02620383365865564, 0.06814399966970086, 0.07748008385533467, 0.02742304128332762, 0.047972882239264436, 0.036359992882353254, 0.08149986737407744, 0.07330893189646304, 0.01696514151262818, 0.04983325721696019, 0.035588307728176005, 0.007410180351143936, 0.055124465870903805, 0.04649319191230461, 0.06893636847962625, 0.014624985687987646, 0.05444928588985931, 0.048940435008262284, 0.037553095462499186, 0.09104521494009532, 0.06821064453106374, 0.044900491047883406, 0.09001259808428586, 0.010702639665396418, 0.09108736150665209, 0.05179953666811343, 0.06701415404677391, 0.02485039563907776, 0.07758171355817467, 0.00869992818479659, 0.04086127439222764, 0.024538250181649346, 0.06070728661143221, 0.049951069449889474, 0.054285601509036496, 0.02401660200121114, 0.0425927308970131, 0.016620452879578806, 0.031880077804089524, 0.039147948555182666, 0.05666933531756513, 0.06524516342324205, 0.030177969529177062, 0.04058464997797273, 0.04727142280898988, 0.033646804877207614, 0.03742242181033362, 0.00908446365428972, 0.017616179429751355, 0.03873285422741901, 0.0431857996591134, 0.041732882309588604, 0.01791719452739926, 0.03618657523475122, 0.0558144739625277, 0.058936251371051185, 0.03590366482967511, 0.0081063037396234, 0.035063798568444327, 0.005853417060279753, 0.0357607828482287, 0.07288803768460639, 0.06392854149453342, 0.008673491029185243, 0.044922521701664664, 0.03416928797378205, 0.024459959167870693, 0.07155994957429357, 0.016920371454034466, 0.06218359645572491, 0.012861891427746741, 0.017735472247295547, 0.023329161740548443, 0.054077829845482484, 0.039425626819138415, 0.02700415272556711, 0.12596622429555282, 0.033240263801417314, 0.03666947959573008, 0.013845135053998092, 0.06374664852046408, 0.06398170153261162, 0.035476555131026544, 0.05458399682538584, 0.10612128447974101, 0.03599611787649337, 0.054913024287088774, 0.04566160059766844, 0.09735734420246445, 0.030833929740765598, 0.02593655102828052, 0.028824637265643105, 0.005784760978713166, 0.04887811686785426, 0.03387727512745187, 0.050469819543650374, 0.0607417705032276, 0.04682330290961545, 0.05576953320996836, 0.10699961625505239, 0.027939871069975197, 0.019900140760000795, 0.07311730194487609, 0.0650934610166587, 0.042850471363635734, 0.021936343509878498, 0.03134157173917629, 0.01956319458258804, 0.04374159034341574, 0.017831096120062284, 0.06748512838385068, 0.029308706798474304, 0.04263559363607783, 0.09017736971145496, 0.025086111018026713, 0.027522242307895795, 0.08277984947199002, 0.028596558586286847, 0.01730387069983408, 0.02221569902758347, 0.08233119893702678, 0.05300392731442116, 0.033255277448915876, 0.10690534865716472, 0.039381398528348655, 0.03839253127807751, 0.0609703482768964, 0.03803511295700446, 0.02365038551943144, 0.048214388225460425, 0.035857874318026006, 0.04935163306072354, 0.029068612748233136, 0.02376350552367512, 0.0757103436626494, 0.017245777235075366, 0.04265434770786669, 0.014132130982034141, 0.010293939867551671, 0.021133990958333015, 0.03747673217731062, 0.03607419552281499, 0.04028846997243818, 0.034263384877704084, 0.020925588469253853, 0.044357914302963763, 0.09156600965070538, 0.014930190209270222, 0.052687037677969784, 0.046969750910648145, 0.024209052025980782, 0.08931213684263639, 0.1408397246268578, 0.2322752127656713, 0.9412800881545991, 0.6883713591378182, 1.122880952898413, 1.1195796425454319, 3.1981836492195725, 2.319430927745998, 2.9543922934681177, 3.2953180745244026, 1.1896104784682393, 0.6980266410391778, 0.2286606715642847, 0.841050788294524, 0.7835713913664222, 1.0558739234693348, 1.0742696863599122, 1.5473388391546905, 1.0038637393154204, 0.561977494508028, 0.35427496943157166, 0.37354477448388934, 0.23483290598960593, 0.05770133248006459, 0.06997096686973237, 0.07457260158844292, 0.15123385906917974, 0.03616563182731625, 0.05220184750214685, 0.03402708505745977, 0.034983041769010015, 0.09205029069562443, 0.032955780043266714, 0.05372173254727386, 0.06889839278301224, 0.058439064378035255, 0.035328426165506244, 0.04175960704742465, 0.08238436639658175, 0.03402454320166726, 0.05460299951664638, 0.016180093989532907, 0.041336660797242075, 0.07252476381836459, 0.021491945481102448, 0.032787546297186054, 0.08412836148636416, 0.02382604816375533, 0.07706926800892688, 0.041626595630077645, 0.11990756072918884, 0.04271373065421358, 0.1271870720665902, 0.009413190546183614, 0.04143169651797507, 0.047572285766364075, 0.04434130132722203, 0.01893228185508633, 0.0831226326408796, 0.018952013706439175, 0.027340204615029506, 0.0671164071536623, 0.06599817614187486, 0.0037058705902381917, 0.004018994522994035, 0.022966414799157064, 0.06819625428761356, 0.07525009335950017, 0.05831498470797669, 0.04544415874988772, 0.0587217447173316, 0.013283366370160365, 0.022305357888399158, 0.028018549855914898, 0.011802969147538533, 0.07821541861630976, 0.024480442443746142, 0.040211245795944706, 0.07275717478478327, 0.008554929227102548, 0.047977965950849466, 0.01110909446651931, 0.021031582000432536, 0.04110666552151088, 0.06398558296496049, 0.041826251908787526, 0.04042416796437465, 0.05506171357410494, 0.0087181404887815, 0.01773909207258839, 0.021890417556278408, 0.06013658989104442, 0.02021872620389331, 0.054590809741057456, 0.014785296079935506, 0.015631609749107156, 0.024922345000959467, 0.026723659866547678, 0.040267248259624466, 0.050020716298604384, 0.042448190215509385, 0.014535148711729562, 0.13407121907221153, 0.18607038975460455, 0.19343210879014805, 0.15205492672976106, 0.1410627251607366, 0.1938415813492611, 0.10926410919637419, 0.15449159051058814, 0.1300336536951363, 0.16402668901719153, 0.1970982737839222, 0.1684928298345767, 0.09027252046507783, 0.15594487893395126, 0.10246895311865956, 0.11958175789914094, 0.12110701238270849, 0.12191015717689879, 0.14557986636646092, 0.26633860368747264, 0.1395355782005936, 0.14712317730300128, 0.12839904375141487, 0.1123279619787354, 0.1701772675733082, 0.13776574895018712, 0.13045455532846972, 0.08610876771854237, 0.20654875261243433, 0.07586476975120604, 0.1978094590594992, 0.08613393394625746, 0.15438717033248395, 0.09387037818669342, 0.07128945158910938, 0.10560283495578915, 0.16218260047025979, 0.19065441330894828, 0.13452922808937728, 0.13635228417115286, 0.09920849799527787, 0.1588521830854006, 0.2056719793472439, 0.16932471800828353, 0.1653202375746332, 0.22529690206283703, 0.08530629085726105, 0.1672881015110761, 0.12181509548099712, 0.1486542576458305, 0.22603588819038123, 0.10389452974777669, 0.11396681700716726, 0.13675665075425059, 0.10485171471373178, 0.12181767815491185, 0.2519598783692345, 0.07843247454729863, 0.22375786589691415, 0.12381926528178155, 0.13321869919309393, 0.09417655121069402, 0.1062044347054325, 0.12918165331939235, 0.1805673647322692, 0.14997735852375627, 0.16621041402686387, 0.13985565165057778, 0.1804106231429614, 0.2878149028401822, 0.12486346706282347, 0.12323187023866922, 0.09452622151002288, 0.2037949691293761, 0.3697789093712345, 0.8453441422898322, 1.8856140249408782, 1.8107646913267672, 2.474322491325438, 2.571120159700513, 5.5606225691735744, 4.315631724894047, 5.797899411991239, 6.253244178369641, 3.2655746955424547, 1.8539219442754984, 1.1739100771956146, 1.4340418623760343, 1.8165021459572017, 2.6616576639935374, 2.637835079804063, 3.0256370455026627, 1.6788432514294982, 1.26125349663198, 0.913045525085181, 0.9231331525370479, 0.69850446539931, 0.3714931517606601, 0.13145428762072697, 0.2874672511825338, 0.23751323169562966, 0.2235593562363647, 0.2873229776741937, 0.16504647413967177, 0.1366404749569483, 0.29907319403719157, 0.12426098415744491, 0.17360263533191755, 0.10841004565008916, 0.19372702343389392, 0.13592626171885058, 0.10387085523689166, 0.13650709617650136, 0.1398193754721433, 0.18116356164682657, 0.14888573350617662, 0.17941375554073602, 0.19800877023953944, 0.17628831934416667, 0.13765718758804724, 0.14998948521679267, 0.12447114553651772, 0.185258227866143, 0.1473789956071414, 0.21016399143263698, 0.15476196975214407, 0.24149853503331542, 0.0813935324549675, 0.17500100482720882, 0.12725313805276528, 0.13829167932271957, 0.12378777595586143, 0.17407867853762582, 0.08609713826444931, 0.18302381417015567, 0.12401378960930742, 0.141255802300293, 0.24944916309323162, 0.12579606467625126, 0.14921554393367842, 0.21233845443930477, 0.14344353490741923, 0.0947892980184406, 0.09435819927603006, 0.13165817043045536, 0.06743476624251343, 0.12590781727340072, 0.13118304748786613, 0.10963494554744102, 0.16328605532180518, 0.1085409456572961, 0.14090218377532437, 0.087669548811391, 0.13258923921966925, 0.13550417264923453, 0.1431104145012796, 0.09658566646976396, 0.09945488360244781, 0.21356850484153256, 0.11521050808369182, 0.1579271405353211, 0.10166840584133752, 0.16281747812172398, 0.08970500755822286, 0.10412261399324052, 0.11503752088174224, 0.07505152432713658, 0.1462948662810959, 0.10486893253982998, 0.07389902835711837, 0.0952568362117745, 0.08846199183608405, 0.2720379119273275, 0.08038902073167264, 0.17254621780011803, 0.10817201662575826], [0.01788171059160959, 0.09254132528440095, 0.026531519688433036, 0.06969889553147368, 0.03015105554368347, 0.03401947804377414, 0.036128917781752534, 0.031020032547530718, 0.03976602398324758, 0.03310344887722749, 0.033328813151456416, 0.04814203624846414, 0.027336998537066393, 0.0737029752053786, 0.031634393526474014, 0.025025809663929977, 0.016015301953302696, 0.01088610413717106, 0.04869131829764228, 0.02083202405628981, 0.02253730686788913, 0.026229523100482766, 0.038508632860612124, 0.03312212873424869, 0.018924359428638127, 0.009473760928813135, 0.03817676297330763, 0.036700078344438225, 0.02229148529295344, 0.03630537452409044, 0.04075921424373519, 0.062377096619457006, 0.018886684301833156, 0.020747198432218283, 0.014821407130511943, 0.05689772755431477, 0.023968204695847817, 0.0374428086070111, 0.11740662695956416, 0.05962389943306334, 0.04188451792288106, 0.059002514026360586, 0.03674407285870984, 0.05792454081529286, 0.04698227465269156, 0.06727561267325655, 0.06587664945982397, 0.03423594025662169, 0.029791650122206192, 0.033262539363931865, 0.05329729458026122, 0.02973312064568745, 0.03406175077543594, 0.012977189635421382, 0.03661162918433547, 0.016150415503943805, 0.03985178656876087, 0.026576234085951, 0.08051853292272426, 0.024809247261146083, 0.04391698952531442, 0.017028552465490066, 0.011880801885126857, 0.06530958926305175, 0.012599660039995797, 0.038843426809762605, 0.029043296235613525, 0.039790199443814345, 0.04890766547759995, 0.40035702637396753, 0.44606824696529657, 1.4415537030436099, 4.00017075240612, 8.404272180050611, 14.274261798709631, 18.153554387390614, 28.4664062038064, 28.15799955278635, 32.9228849709034, 30.748637840151787, 37.28839851915836, 41.5770497918129, 48.321072310209274, 44.29927311837673, 31.76823902875185, 19.272966720163822, 24.50334995985031, 20.57213220745325, 27.83806052058935, 32.25168898701668, 24.769791662693024, 27.30917450040579, 38.55596110224724, 32.487743720412254, 20.668432340025902, 20.8198257163167, 13.32816006615758, 13.661858160048723, 6.129294354468584, 5.3153276816010475, 1.8702510930597782, 0.22526960587128997, 0.16159688268089667, 0.028178287866467144, 0.02956695192551706, 0.0553831228899071, 0.10273323932779022, 0.0024330931228178088, 0.04574114769638982, 0.04698397788160946, 0.053703375524492, 0.12843483011238277, 0.0876645690004807, 0.022832022987131495, 0.034258887462783605, 0.03903092299879063, 0.07019398966804147, 0.020742036795127206, 0.0436982414976228, 0.03994877784862183, 0.019581709311751183, 0.038543280024896376, 0.010723059858719353, 0.04214259606669657, 0.029325197319849394, 0.036842882400378585, 0.053659529439755715, 0.038570876786252484, 0.0484124971262645, 0.04141503159189597, 0.022857647491036914, 0.055597577593289316, 0.028489989890658762, 0.026497551589272916, 0.00871826016009436, 0.09347432365757413, 0.08299092369270511, 0.04202351105050184, 0.056088074125000276, 0.005850841807841789, 0.08920757565647364, 0.08521549651050009, 0.04608091774571221, 0.04397873992274981, 0.036551778684952296, 0.051208675795351155, 0.0044172634352435125, 0.037772132927784696, 0.06882408895762637, 0.03855274982925039, 0.00539375769221806, 0.01012333403195953, 0.020642666931962594, 0.029029239958617836, 0.025346358088427223, 0.10269624326610938, 0.025660644641902763, 0.0443800822540652, 0.05816982433316298, 0.026745126488094684, 0.05188315444684122, 0.042716665848274715, 0.0541731921111932, 0.04700473204138689, 0.036605276400223374, 0.014385407430381747, 0.01210272259413614, 0.046522714546881616, 0.0269989094522316, 0.017629616013437044, 0.05627155158435926, 0.04049184812174644, 0.028332639740256127, 0.03140363383863587, 0.0052906260680174455, 0.052484438783722, 0.040492000262020156, 0.008334531776199583, 0.07023674479569308, 0.07491453870898113, 0.05344087418052368, 0.012221338201925391, 0.044007089963997714, 0.03251027621445246, 0.016801642668724526, 0.05761086467828136, 0.05965259457298089, 0.03681112219055649, 0.010268217029079096, 0.0665325002046302, 0.019746560719795525, 0.05492667238286231, 0.03506608809402678, 0.010181493362324545, 0.04064024054969195, 0.02227321547252359, 0.03184758657880593, 0.12020346985082142, 0.06769045096007176, 0.057445989150437526, 0.07935115689178929, 0.02731742810283322, 0.024808603448036592, 0.02460922176396707, 0.021561829817073885, 0.027630835211311933, 0.02631166029459564, 0.026125750446226448, 0.06426192907383665, 0.03461482890998013, 0.018004526755248662, 0.0220113041359582, 0.025664539061835967, 0.04075307668244932, 0.11496807070216164, 0.028323425976850558, 0.04621912419679575, 0.012102019409212517, 0.0888881330320146, 0.016272585999104194, 0.0533069276571041, 0.07840104459319264, 0.09053757108631544, 0.017927122607943602, 0.05229381815297529, 0.020765253029821906, 0.03856325121887494, 0.014575144905393245, 0.07987520963069983, 0.02437240615108749, 0.020258080439816695, 0.046130942209856585, 0.057224331903853454, 0.043666136189131066, 0.01232056705703144, 0.02647234268806642, 0.029323204653337598, 0.01881275155028561, 0.013999551865708781, 0.0796964114124421, 0.030046151114220265, 0.0170582903228933, 0.019445081779849716, 0.05129757395479828, 0.0437889171007555, 0.3599217929877341, 0.4363560274941847, 1.2054399540647864, 3.6705550644546747, 8.691635560244322, 15.225712694227695, 18.195306546986103, 28.528538569808006, 28.71158804744482, 33.463599756360054, 30.85678953677416, 39.67640317976475, 43.30815330147743, 50.6181326508522, 46.855308562517166, 36.27634182572365, 23.230935037136078, 27.88015466183424, 24.442007951438427, 33.674473240971565, 38.044234961271286, 29.082436747848988, 31.86080016195774, 42.9097218811512, 37.28054814040661, 26.417841129004955, 26.699871495366096, 18.38450599461794, 17.7130364254117, 7.808128343895078, 7.8252768237143755, 3.516029231250286, 0.4918800137238577, 0.16812916263006628, 0.0342701977933757, 0.1608449683408253, 0.06835396809037775, 0.020654762083722744, 0.017843350833572913, 0.05155140701390337, 0.03489563532639295, 0.06852637641713955, 0.12273700616788119, 0.026646300248103216, 0.02718020314205205, 0.0355308766302187, 0.02753309436229756, 0.04120213910937309, 0.07352653701673262, 0.04094345240446273, 0.027856856286234688, 0.05983732997265179, 0.03982623071351554, 0.029506860228138976, 0.025256047993025277, 0.032193609222304076, 0.027720082180167083, 0.026321812874812167, 0.05041330499807373, 0.041266234693466686, 0.043508837989065796, 0.03350295439304318, 0.03739373409189284, 0.04822214366868138, 0.03647067307610996, 0.09012559748953208, 0.0658656434097793, 0.02353488507651491, 0.019167492573615164, 0.020652363091357984, 0.04130950190301519, 0.049975077927228995, 0.0166876024013618, 0.0479984529374633, 0.03041434356418904, 0.005237697487245896, 0.04182724267593585, 0.019025148649234325, 0.019901780906366184, 0.08099641665467061, 0.03527731816575397, 0.0603049089841079, 0.007582587750221137, 0.027046139730373397, 0.04800839400559198, 0.03644070886366535, 0.09075270485482179, 0.01095565821742639, 0.055284587942878716, 0.08150570065481588, 0.05979012195894029, 0.05532537637918722, 0.0688428059220314, 0.05936215879046358, 0.019699200565810315, 0.013945267473900458, 0.0007901784886144014, 0.02494290063623339, 0.049453125466243364, 0.06931186551810242, 0.03740200161701068, 0.050314473191974685, 0.05715547544241417, 0.031376178085338324, 0.03481566520349588, 0.0624330693972297, 0.07979383313795552, 0.12743845232762396, 0.08794139750534669, 0.22897234390256926, 0.1712508435593918, 0.20371913647977635, 0.1429616881068796, 0.13415356777841225, 0.11690972940414213, 0.1364574464969337, 0.11629199536400847, 0.1416689410689287, 0.10053027785033919, 0.10578266475931741, 0.1780922873876989, 0.09285690874094144, 0.10565995806246065, 0.09011290676426142, 0.1384556049015373, 0.17045153566868976, 0.06974975491175428, 0.10104838598635979, 0.2424609669833444, 0.14405231864657253, 0.12676412210566923, 0.120305812015431, 0.1929897887748666, 0.13064850820228457, 0.12411590170813724, 0.18341393151786178, 0.09358201670693234, 0.1655154669424519, 0.12724696338409558, 0.16437399928690866, 0.1786182029172778, 0.19791272148722783, 0.14277716050855815, 0.09977440044167452, 0.09651281725382432, 0.3043733455706388, 0.1036312677024398, 0.203826688521076, 0.15396816859720275, 0.15175520296907052, 0.08967226400272921, 0.12256479079951532, 0.11436799977673218, 0.2060816893936135, 0.1634411938721314, 0.19108778302324936, 0.08223359167459421, 0.0605551092303358, 0.12114797893445939, 0.17694072652375326, 0.11469093791674823, 0.1499254527152516, 0.15065857587615028, 0.11110784151242115, 0.2081468192045577, 0.14631851110607386, 0.07932016480481252, 0.1356451361789368, 0.13032565911998972, 0.07514036682550795, 0.10940405598375946, 0.11766679424908943, 0.09212650184053928, 0.11429299833253026, 0.17107545922044665, 0.17313134187133983, 0.6387033336795866, 1.3440388231538236, 2.214510957710445, 6.747913984581828, 14.11848345771432, 25.475240908563137, 29.91379413753748, 40.09007178246975, 42.398611307144165, 45.6608160585165, 44.143420681357384, 56.82161897420883, 61.32522851228714, 67.4665729701519, 60.36345832049847, 48.80309544503689, 33.13153177499771, 36.80601440370083, 35.65312586724758, 49.70002591609955, 48.092742562294006, 44.285768643021584, 45.72076924145222, 53.721357733011246, 49.51835386455059, 37.813553139567375, 38.01010139286518, 29.456165693700314, 24.39736034721136, 14.047887045890093, 12.476720754057169, 5.953002814203501, 1.0230009374208748, 0.26879980287048966, 0.20030389161547646, 0.30114084715023637, 0.22879428783198819, 0.22224997024750337, 0.1817629497963935, 0.1655211072647944, 0.104056466370821, 0.15629315399564803, 0.28032265487127006, 0.1454912539338693, 0.13496575935278088, 0.13792243116768077, 0.18129584204871207, 0.2542625548085198, 0.12225992395542562, 0.07790038434905, 0.08249038219219074, 0.1325376154272817, 0.15893377480097115, 0.14916423184331506, 0.1302421378204599, 0.12000065573374741, 0.144495781569276, 0.1612595171900466, 0.23153377755079418, 0.1421762435347773, 0.12065483664628118, 0.09494990619714372, 0.1435751622193493, 0.14801577315665781, 0.1157267385860905, 0.21514960593776777, 0.22089745063567534, 0.19423410325543955, 0.0841690534434747, 0.13905205414630473, 0.15438231668667868, 0.2060869289562106, 0.142998379888013, 0.18534510367317125, 0.08230070408899337, 0.16780619480414316, 0.08466509010759182, 0.14439507212955505, 0.14224314072635025, 0.15588570007821545, 0.1698076631873846, 0.13144524826202542, 0.0659027136862278, 0.1395473931916058, 0.15442476753378287, 0.08934216413763352, 0.19296335347462445, 0.06304481430561282, 0.07133097475161776, 0.17965226696105674, 0.19400014862185344, 0.1316623413003981, 0.26311958266887814, 0.15440366085385904, 0.12645728857023641, 0.1504399540135637, 0.07826468980056234, 0.11883981802384369, 0.2099140064092353, 0.23711085406830534, 0.20417656662175432, 0.08613860205514356, 0.14251075917854905, 0.15905416599707678, 0.1560512138530612, 0.10949829389574006, 0.2874680230161175], [0.0054564019137615105, 0.03221214436052833, 0.02743948727584211, 0.03402201247808989, 0.013381366043176968, 0.041095648339251056, 0.015398200594063383, 0.010335178230889142, 0.04806367287528701, 0.03096298736636527, 0.06575962019269355, 0.01630396585824201, 0.06356306344969198, 0.03461953041551169, 0.03289423002570402, 0.1419795595575124, 0.05778970000392292, 0.021058872625872027, 0.04153766407398507, 0.03925606462871656, 0.00625795387350081, 0.03505881875753403, 0.015654065282433294, 0.04715392227808479, 0.012782938047166681, 0.011789676354965195, 0.013524082896765321, 0.03700770226714667, 0.01653846411500126, 0.020840844481426757, 0.021739954536315054, 0.0487303775298642, 0.022216977376956493, 0.01934065603563795, 0.04087540117325261, 0.02022952259721933, 0.013690259966097074, 0.02560590197390411, 0.02514860356313875, 0.054478656384162605, 0.010645479451341089, 0.06624203844694421, 0.040563999718870036, 0.014691795677208574, 0.05306293176545296, 0.015657356707379222, 0.08704472726094536, 0.03840168566966895, 0.021478748240042478, 0.019764841672440525, 0.046229506842792034, 0.05184200235817116, 0.08162988422554918, 0.008104530006676214, 0.06501744283013977, 0.028883519262308255, 0.027474963790155016, 0.09344486039481126, 0.03280441160313785, 0.06485754711320624, 0.050047652548528276, 0.07974189764354378, 0.06734276961651631, 0.06194884030264802, 0.09141214759438299, 0.10701992883696221, 0.8630431175697595, 2.2533845342695713, 5.921746641397476, 9.638812635093927, 24.834078513085842, 35.72732448577881, 48.57171446084976, 65.24613931775093, 66.66732385754585, 71.55586794018745, 82.027498036623, 79.59725484251976, 81.5762722492218, 81.64016962051392, 88.91917303204536, 91.33005246520042, 93.60087141394615, 95.10729297995567, 83.83536502718925, 99.37721505761147, 86.13887742161751, 82.33283445239067, 81.24752908945084, 77.491734623909, 77.26857259869576, 82.38961860537529, 81.04299366474152, 80.88225468993187, 84.78794351220131, 83.32855582237244, 84.90054666996002, 71.74560695886612, 60.581635013222694, 66.34593710303307, 52.98773489892483, 29.535600431263447, 7.30964639224112, 1.5211073029786348, 0.24046570295467973, 0.029692617936234456, 0.016881846568139736, 0.062036918388912454, 0.04642343003069982, 0.0952669071557466, 0.06046524256817065, 0.060810263312305324, 0.04890300850092899, 0.005707887466996908, 0.005253180543149938, 0.11334418479236774, 0.06709892957587726, 0.04563096103083808, 0.06384165826602839, 0.09209981421008706, 0.0189203815170913, 0.013726399774895981, 0.048109693452715874, 0.012694324686890468, 0.033920123023563065, 0.03549883811501786, 0.052543350466294214, 0.07307790874619968, 0.025216669637302402, 0.02240244379208889, 0.02597507591417525, 0.04534544197667856, 0.056266497558681294, 0.06039690561010502, 0.13192748097935691, 0.023428889689967036, 0.022532720395247452, 0.02023197910602903, 0.026019515717052855, 0.0770364650816191, 0.04519424051977694, 0.03855031929560937, 0.03651610735687427, 0.020990658122173045, 0.01578322124260012, 0.016680284825270064, 0.05434491024061572, 0.030225003138184547, 0.05016062597860582, 0.06743167148670182, 0.027866183227160946, 0.04773902037413791, 0.014052902079129126, 0.046992954157758504, 0.05209459603065625, 0.026452080201124772, 0.027390837640268728, 0.010797002814797452, 0.014234003738238243, 0.07352363521931693, 0.07673171698115766, 0.024095397675409913, 0.0024033622230490437, 0.05139422384672798, 0.02217954159277724, 0.07024872305919416, 0.0443225175695261, 0.07281379323103465, 0.032697371643735096, 0.03820645630185027, 0.04585989132465329, 0.004128452492295764, 0.016209115674428176, 0.07208517490653321, 0.036201685361447744, 0.12072459110640921, 0.00645540829282254, 0.007604587790410733, 0.030226747185224667, 0.06126511078036856, 0.030647077364847064, 0.06156821131298784, 0.03804495383519679, 0.020620819959731307, 0.018355920692556538, 0.008235172117565526, 0.023120831610867754, 0.006262807983148377, 0.004441845685505541, 0.03735676400538068, 0.07181363049312495, 0.014009864007675787, 0.059898597974097356, 0.021470872197824065, 0.036009443138027564, 0.023030692209431436, 0.01591967808053596, 0.0445791819220176, 0.048875563879846595, 0.029111729672877118, 0.01935668828082271, 0.02611559786600992, 0.03151287426589988, 0.010912459656537976, 0.05269923116429709, 0.03239309480704833, 0.009042223391588777, 0.07354653047514148, 0.046344472939381376, 0.007349232864726218, 0.05156980856554583, 0.05967285149381496, 0.045817343998351134, 0.03145199218124617, 0.04596015547576826, 0.017416695700376295, 0.019527924014255404, 0.07842670805985108, 0.02475943987519713, 0.06646651585469954, 0.021120853089087177, 0.08839068628731184, 0.04534536405117251, 0.013982391556055518, 0.07692031897022389, 0.0351676472928375, 0.018797732336679474, 0.034627846180228516, 0.03760064115340356, 0.045868526212871075, 0.058386872842675075, 0.07553163450211287, 0.08068618408287875, 0.05387819212046452, 0.07984501906321384, 0.1965912533341907, 0.111454016296193, 0.028950288433406968, 0.04668742680223659, 0.03138267929898575, 0.0341753179236548, 0.2438923917361535, 1.1954322410747409, 2.8342729015275836, 6.407478852197528, 11.386978179216385, 27.355332523584366, 38.46413902938366, 53.71185444295406, 74.13390800356865, 75.6542444229126, 77.23355367779732, 89.88954216241837, 89.03288573026657, 89.46740761399269, 91.80374264717102, 99.20370116829872, 101.75918564200401, 107.26329669356346, 106.62903472781181, 91.67127415537834, 107.66371920704842, 95.11257469654083, 95.58412939310074, 96.77737936377525, 90.67693591117859, 91.36580854654312, 95.73040634393692, 92.0513753592968, 96.43582329154015, 95.09609118103981, 94.93628695607185, 98.06574583053589, 84.2669914662838, 71.91182523965836, 77.32342645525932, 63.36114786565304, 36.28962591290474, 10.50525639206171, 2.1458367677405477, 0.2345984912244603, 0.020933794767188374, 0.040764387013041414, 0.0647897222370375, 0.0646868531475775, 0.15532190533122048, 0.05186538000998553, 0.04698845303209964, 0.05364752891182434, 0.04443672296474688, 0.030191582372935954, 0.1399371839943342, 0.040509477839805186, 0.044673338197753765, 0.05821410828502849, 0.028547749388962984, 0.047996178254834376, 0.018979083542944863, 0.008457385974907083, 0.02230907975899754, 0.027876510212081484, 0.02453199016599683, 0.039408642769558355, 0.05521197250345722, 0.0494982220698148, 0.01252278838364873, 0.018216075950476807, 0.06846195799880661, 0.05729579701437615, 0.015620956219208892, 0.004538632410913124, 0.06550269608851522, 0.06105215521529317, 0.003496035524221952, 0.02352931896894006, 0.0695457162510138, 0.03699544569826685, 0.05154404119821265, 0.04487739541218616, 0.016118735074996948, 0.03666866323328577, 0.029936571154394187, 0.0829529702605214, 0.023330447511398233, 0.031043174567457754, 0.018774389936879743, 0.04522008210187778, 0.027317355743434746, 0.030600529862567782, 0.061309940210776404, 0.02876117250707466, 0.07563999548438005, 0.0319374495302327, 0.05225755681749433, 0.03100271638686536, 0.06115885007602628, 0.034324448788538575, 0.03147246803564485, 0.004064865743202972, 0.023391778595396318, 0.03183996843290515, 0.07633281260496005, 0.0577631014311919, 0.05923582299146801, 0.06896094098920003, 0.026646606384019833, 0.05435472143290099, 0.04414527786138933, 0.019190868370060343, 0.003936405082640704, 0.054364187526516616, 0.02990113916894188, 0.054842631579958834, 0.13076349656330422, 0.1338878640672192, 0.13770045479759574, 0.11643275851383805, 0.18346289842156693, 0.10486291372217238, 0.12471200956497341, 0.10596603460726328, 0.07872708491049707, 0.15071238158270717, 0.08081274252617732, 0.1606757883564569, 0.15704769553849474, 0.2177431745803915, 0.19212132756365463, 0.1359543891157955, 0.15120861120522022, 0.22400109737645835, 0.12267395330127329, 0.09194990780088119, 0.1587370314518921, 0.24609780230093747, 0.08882805617759004, 0.12057167899911292, 0.08710803245776333, 0.09040825927513652, 0.11317188778775744, 0.09986641191062517, 0.10357389226555824, 0.09976872301194817, 0.13673554407432675, 0.10328892240067944, 0.20231417671311647, 0.17138928378699347, 0.14255217101890594, 0.10549985454417765, 0.16047756071202457, 0.07933739747386426, 0.11284960273769684, 0.07326755716348998, 0.18504511273931712, 0.09700250855530612, 0.1370015149586834, 0.10637107654474676, 0.15705202968092635, 0.2834972064010799, 0.1033747592009604, 0.11733104664017446, 0.13333530543604866, 0.11629106767941266, 0.17750646569766104, 0.13563682412495837, 0.15804340539034456, 0.2152660785941407, 0.21466912468895316, 0.12616439256817102, 0.15171370207099244, 0.18852832348784432, 0.3499860386364162, 0.15816050145076588, 0.11773321646614932, 0.17584635555977002, 0.17395119240973145, 0.15451416664291173, 0.3242507023969665, 2.1881239861249924, 4.889205247163773, 11.141844782978296, 18.552447482943535, 41.20054319500923, 53.83945919573307, 70.51558256149292, 90.0536173582077, 92.89907947182655, 94.53855469822884, 104.42035764455795, 105.25480046868324, 104.83431503176689, 109.05181512236595, 115.12442886829376, 114.30487364530563, 122.02333867549896, 119.35080528259277, 110.37686482071877, 128.4742221236229, 113.2658725976944, 115.96569612622261, 113.54768067598343, 107.71125465631485, 108.97663235664368, 109.98974159359932, 105.73724538087845, 110.9143915772438, 113.69565233588219, 112.32039973139763, 113.26746091246605, 99.78699266910553, 90.6162379682064, 92.20456033945084, 75.49399942159653, 48.78381907939911, 14.915795624256134, 3.467588243074715, 0.5454461846966296, 0.14278075250331312, 0.11174048529937863, 0.15596876124618575, 0.13301049708388746, 0.12471478519728407, 0.17815605271607637, 0.14913383347447962, 0.17322780622635037, 0.1427595567656681, 0.1634281172300689, 0.20709000091301277, 0.1510015074745752, 0.16769352194387466, 0.20437690196558833, 0.182387140521314, 0.2266440336825326, 0.13363027945160866, 0.10602190348436125, 0.12494707742007449, 0.12877350178314373, 0.2557638305006549, 0.12864286894910038, 0.13398686656728387, 0.14581540919607505, 0.1637620391556993, 0.087234078819165, 0.1308963113115169, 0.19908896618289873, 0.1339992307475768, 0.1650427930871956, 0.19324407825479284, 0.1537638998706825, 0.09570039561367594, 0.0785687699681148, 0.17979054391616955, 0.16725513531127945, 0.1115421908616554, 0.1498113400884904, 0.18852271285140887, 0.07710413410677575, 0.09241644409485161, 0.1867638822295703, 0.27831232524476945, 0.17248733580345288, 0.26869771303609014, 0.09030351997353137, 0.11070146370911971, 0.07714684470556676, 0.1307321630883962, 0.1702502800617367, 0.19189528422430158, 0.14285763900261372, 0.10979586542816833, 0.05552968963456806, 0.17479716654634103, 0.20337617519544438, 0.17112944304244593, 0.053582090040436015, 0.11838741222163662, 0.12028006691252813, 0.1959071564488113, 0.12628358148504049, 0.20635407243389636, 0.20981573121389374, 0.1173319446388632, 0.22810311085777357, 0.1133902498986572, 0.16870922525413334, 0.1769479995709844, 0.17042323015630245, 0.16065575036918744], [0.0390833371784538, 0.013698375350941205, 0.03987454081652686, 0.08404926338698715, 0.01277873099752469, 0.07575033800094388, 0.06299179527559318, 0.02703707625187235, 0.005601488537649857, 0.045347330742515624, 0.06370913295540959, 0.034111548884538934, 0.048439830425195396, 0.03520911108353175, 0.03150822842144407, 0.030695148125232663, 0.04056786259752698, 0.022205390596354846, 0.0416343733377289, 0.026419457244628575, 0.040636329431436025, 0.039723962763673626, 0.005452748691823217, 0.013396851882134797, 0.046086565489531495, 0.07381710267509334, 0.016294175075017847, 0.0528885678795632, 0.013935319911979605, 0.0430357225559419, 0.10716588702052832, 0.036211040132911876, 0.010205586258962285, 0.029720505990553647, 0.06364844753989018, 0.09242338317562826, 0.035889293139916845, 0.04004196933237836, 0.07498382561607286, 0.036753223539562896, 0.0235219624300953, 0.04236723303620238, 0.06817589717684314, 0.08641510401503183, 0.0072873391400207765, 0.0888369174208492, 0.023817582114133984, 0.01586431942996569, 0.07199976113042794, 0.02091503698466113, 0.011430784870753996, 0.06419512093998492, 0.041123382397927344, 0.03645183736807667, 0.02221276383352233, 0.07353665248956531, 0.06270234283874743, 0.028932111381436698, 0.07357971931924112, 0.030307685810839757, 0.03004725691425847, 0.0684910205018241, 0.17140549229225144, 1.7312657134607434, 5.348033951595426, 18.1070638820529, 31.241420097649097, 53.23835425078869, 61.32015958428383, 56.63154177367687, 72.47065365314484, 85.83537250757217, 83.97444516420364, 86.48047909140587, 76.54921799898148, 71.92976787686348, 74.29866716265678, 74.8380634188652, 78.26864093542099, 79.5823672413826, 69.3305629491806, 59.03795264661312, 63.62776815891266, 56.35463923215866, 71.83161914348602, 67.62542724609375, 72.22306653857231, 71.18106365203857, 73.02594065666199, 79.11376878619194, 69.73886623978615, 60.44352002441883, 64.03012096881866, 64.2591954767704, 65.10165587067604, 67.42812663316727, 60.63130594789982, 73.79295229911804, 77.78556525707245, 76.34282067418098, 80.61547100543976, 86.78399160504341, 62.7194344997406, 36.007893830537796, 14.712596777826548, 1.9279284356161952, 0.4683592461515218, 0.3279075014870614, 0.03719641186762601, 0.12988120171939954, 0.09582627870258875, 0.03848061307508033, 0.0400894779158989, 0.01243233542481903, 0.04554288665531203, 0.04211965628201142, 0.06301200395682827, 0.07628708146512508, 0.05798023899842519, 0.00875200468726689, 0.009322840560344048, 0.026099445021827705, 0.024531695162295364, 0.08910291056963615, 0.03533266011800151, 0.04869503645750228, 0.0732881146541331, 0.08324886453920044, 0.050403375062160194, 0.0738509075017646, 0.01931496288307244, 0.06564196010003798, 0.04161821307206992, 0.0397324900404783, 0.0551011401694268, 0.04432476627698634, 0.013191373454901623, 0.004174641444478766, 0.015433304179168772, 0.059842836708412506, 0.04282865222194232, 0.012879897785751382, 0.05676935827068519, 0.1293700549285859, 0.03015540452906862, 0.007340511237998726, 0.025319540582131594, 0.03581064775062259, 0.03537432428856846, 0.0439610582543537, 0.10009955760324374, 0.024275995601783507, 0.019296633690828457, 0.055348668684018776, 0.0440863698895555, 0.05947905818175059, 0.030692695327161346, 0.018078602370223962, 0.059526897020987235, 0.028137779590906575, 0.017804989220167045, 0.028455587635107804, 0.028504647307272535, 0.05334121859050356, 0.03530177564243786, 0.02759719736786792, 0.0245575590088265, 0.01004259671390173, 0.033348951328662224, 0.07630010615685023, 0.054385049297707155, 0.030736508015252184, 0.1288499281508848, 0.04433562389749568, 0.020888798353553284, 0.01989109212445328, 0.04881629596638959, 0.00677747858389921, 0.09367482227389701, 0.029424626554828137, 0.035701537199201994, 0.040251729951705784, 0.03085229232965503, 0.040784402735880576, 0.07262826373334974, 0.035650321588036604, 0.04156657072599046, 0.03258851713326294, 0.038749411542085, 0.045974412132636644, 0.027691743271134328, 0.025436441828787792, 0.01973371414351277, 0.05669555168424267, 0.06672991890809499, 0.051519724729587324, 0.03522752376738936, 0.0771816736960318, 0.042960491045960225, 0.023841648107918445, 0.08273818530142307, 0.05496633275470231, 0.051751846258412115, 0.016911775528569706, 0.01688491534878267, 0.08156211872119457, 0.042289641496608965, 0.02334781933313934, 0.013439863050734857, 0.0413369428133592, 0.016455816694360692, 0.02241790272819344, 0.05637122943880968, 0.05052913198596798, 0.029226745864434633, 0.06510768056614324, 0.040592654040665366, 0.04367157984233927, 0.06420965961297043, 0.053041869614389725, 0.05664565338520333, 0.04940654085658025, 0.021099829900776967, 0.03419384564040229, 0.039804522893973626, 0.016721047286409885, 0.063910663157003, 0.05420168687123805, 0.015081749752425821, 0.04742963385069743, 0.07532114657806233, 0.06020612170686945, 0.04947389446897432, 0.03595742229663301, 0.06416934615117498, 0.02809306519338861, 0.01646042914217105, 0.029167119864723645, 0.260442448197864, 2.9667193070054054, 7.711738916113973, 21.92075964063406, 36.22554615139961, 59.59081918001175, 67.74601757526398, 63.240424543619156, 83.9933529496193, 96.40974909067154, 94.72980603575706, 94.86539795994759, 87.20592856407166, 86.11683860421181, 86.6881075501442, 86.89839586615562, 91.83898955583572, 90.70975095033646, 87.33807027339935, 75.79304337501526, 80.24382814764977, 79.67537105083466, 85.80140992999077, 84.27622497081757, 86.09730765223503, 85.17657145857811, 81.4287793636322, 91.02547600865364, 79.267318546772, 74.04715865850449, 77.31331139802933, 75.92688739299774, 78.39795559644699, 82.41713672876358, 72.75080502033234, 85.44492825865746, 88.97722631692886, 90.15736699104309, 90.78969106078148, 96.98607936501503, 74.8597526550293, 43.48753787577152, 18.27216312289238, 2.2090931609272957, 0.5560799140948802, 0.23531482700491324, 0.03430814751482103, 0.08032246492803097, 0.04351726507593412, 0.031218378935591318, 0.049975742149399593, 0.018401900451863185, 0.018045994256681297, 0.020828779015573673, 0.03994681115727872, 0.05468113282404374, 0.05795565535663627, 0.0349172689311672, 0.026790386364154983, 0.04956626216880977, 0.004672516779464786, 0.036904265434714034, 0.03111824280495057, 0.02634592710819561, 0.004016737002530135, 0.05331705426215194, 0.024697374064999167, 0.04342177664511837, 0.016334690772055183, 0.014220308330550324, 0.07918318660813384, 0.09375676279887557, 0.027533005304576363, 0.010851995029952377, 0.03779724349442404, 0.027723954335669987, 0.09758159896591678, 0.02849003441951936, 0.05748349729401525, 0.020370647544041276, 0.007933374981803354, 0.05206264657317661, 0.025784449717320967, 0.026974823049386032, 0.018362668670306448, 0.048901153131737374, 0.060266933287493885, 0.06738741722074337, 0.0615672242565779, 0.021880474632780533, 0.013781976431346266, 0.0739808872458525, 0.08266886870842427, 0.0660106071154587, 0.04752631713927258, 0.02022686014242936, 0.0661433550703805, 0.026588967484713066, 0.02469624228979228, 0.06536787754157558, 0.04684341882239096, 0.014940566361474339, 0.032411418433184735, 0.05273501752526499, 0.009536982634017477, 0.03424144699238241, 0.03639189038949553, 0.010589251560304547, 0.03497071469610091, 0.029745507090410683, 0.03855454582662787, 0.031282927229767665, 0.05217187957896385, 0.026701098577177618, 0.1414756412850693, 0.06940197708900087, 0.18298437644261867, 0.15980527881765738, 0.10095236691995524, 0.13378819363424554, 0.2448788395849988, 0.1688864649622701, 0.1112150595872663, 0.09591341426130384, 0.13855407305527478, 0.1604978510295041, 0.09985608121496625, 0.3123584092827514, 0.0977903873717878, 0.09103934455197304, 0.13849628943717107, 0.13190673053031787, 0.14775045536225662, 0.1825878320960328, 0.14142578380415216, 0.12831826839828864, 0.17474307882366702, 0.08713270144653507, 0.17286679591052234, 0.1741597062209621, 0.1098600760451518, 0.12277142697712407, 0.09917907926137559, 0.1897226765868254, 0.12347736526862718, 0.10099284365423955, 0.15644749102648348, 0.19163499819114804, 0.10426046050270088, 0.16620471433270723, 0.14115648809820414, 0.1372579566668719, 0.16522849327884614, 0.10626571383909322, 0.11772560945246369, 0.10751724941655993, 0.19521545997122303, 0.15118054318008944, 0.17771941755199805, 0.23107244371203706, 0.2510601282119751, 0.15546534763416275, 0.1481287577189505, 0.1178566059388686, 0.22957337961997837, 0.18129403120838106, 0.15549248055322096, 0.20265244762413204, 0.112496563087916, 0.11584500723984092, 0.14012658008141443, 0.14290403807535768, 0.1623033924261108, 0.14261088974308223, 0.10953829565551132, 0.15839377330848947, 0.5913499183952808, 4.10077890381217, 11.423876099288464, 29.672364592552185, 48.67871671915054, 75.66923081874847, 86.52910888195038, 83.09026300907135, 100.58229759335518, 108.69537144899368, 108.4393259882927, 109.35819268226624, 100.234335064888, 96.32711872458458, 95.1853559911251, 99.46068897843361, 101.03635802865028, 103.3958338201046, 93.86598318815231, 85.32756015658379, 85.22416770458221, 79.52546149492264, 96.2383782863617, 90.23787707090378, 95.10739177465439, 91.29155293107033, 92.82438308000565, 102.39972487092018, 93.81068855524063, 85.41052490472794, 86.27445414662361, 88.76900508999825, 90.26126861572266, 95.24356126785278, 85.9426711499691, 97.67774105072021, 101.13063097000122, 101.76468014717102, 101.2923426926136, 110.46627402305603, 90.52891105413437, 54.75805230438709, 23.57361774891615, 4.933071993291378, 1.6960089490748942, 0.5484075320418924, 0.20114847051445395, 0.16298138885758817, 0.163947130786255, 0.14172439434332773, 0.13963881094241515, 0.12805260921595618, 0.10342645720811561, 0.12357782237813808, 0.16335356107447296, 0.11931099274079315, 0.11846927853184752, 0.16890028375200927, 0.079957988782553, 0.11229371186345816, 0.12459136603865772, 0.11811348551418632, 0.1361687362077646, 0.12547125632409006, 0.09093626023968682, 0.23849224322475493, 0.17794534214772284, 0.11237260958296247, 0.1266793836839497, 0.10162548001972027, 0.2437972038751468, 0.1503303981735371, 0.1773597876308486, 0.1718229058315046, 0.11510403957800008, 0.11345666469424032, 0.17304755339864641, 0.12387960188789293, 0.10836456684046425, 0.11401633310015313, 0.16232739348197356, 0.1880099778645672, 0.11956534901401028, 0.10088640483445488, 0.1096371200401336, 0.12673125980654731, 0.24908981518819928, 0.10546717036049813, 0.18299035815289244, 0.0821780419209972, 0.1298657205188647, 0.13206535717472434, 0.19711347296833992, 0.11662133823847398, 0.12922995229018852, 0.12464751693187281, 0.14606733864638954, 0.09848777612205595, 0.08293244245578535, 0.1887195452582091, 0.19852520112181082, 0.11371619373676367, 0.12716563884168863, 0.1179631931881886, 0.1099442875420209, 0.11429601145209745, 0.14293721207650378, 0.08384394081076607, 0.13722806295845658, 0.13021939841564745, 0.3270011016866192, 0.08816603818559088, 0.11921259880182333, 0.115275713178562], [0.01880551932117669, 0.03440221102209762, 0.048104242378030904, 0.04470896128623281, 0.03864597842039075, 0.03794018855842296, 0.035103755799354985, 0.043831627699546516, 0.0049049759854824515, 0.1576969856978394, 0.03415706851228606, 0.04070635106472764, 0.05037224567786325, 0.05983595328871161, 0.029736881479038857, 0.05399548485002015, 0.04504911725234706, 0.04105433668883052, 0.009788888892217074, 0.05257983815681655, 0.037233630573609844, 0.05155149607162457, 0.06273748353123665, 0.03851723806292284, 0.02873902125429595, 0.014287627618614351, 0.034247911098646, 0.07105120734195225, 0.06954149343073368, 0.03601375501602888, 0.038138724194141105, 0.02037663110968424, 0.02718739826377714, 0.024673655025253538, 0.01629618629522156, 0.056572269822936505, 0.01875253739854088, 0.07424675422953442, 0.02964614464872284, 0.04009028314612806, 0.050592129191500135, 0.03637535533925984, 0.05407476477557793, 0.02261140845803311, 0.030521947555826046, 0.01402724139552447, 0.06873927632113919, 0.038571292388951406, 0.013390397980401758, 0.009510536201560171, 0.056211381961475126, 0.03570572291209828, 0.008113010899251094, 0.05728993404773064, 0.032205680254264735, 0.039595363414264284, 0.028799233550671488, 0.053354699703049846, 0.04799520975211635, 0.13911647256463766, 1.4820277062244713, 7.680048616603017, 20.807274989783764, 42.47408285737038, 63.37068535387516, 75.7996018230915, 87.21069350838661, 80.22158414125443, 72.02056780457497, 65.50961717963219, 64.4228906929493, 71.39748483896255, 62.55122512578964, 65.74731722474098, 51.184594854712486, 40.52512563765049, 43.71358014643192, 36.53946630656719, 41.28346614539623, 39.98254895210266, 19.908589012920856, 29.83456838876009, 31.740570813417435, 23.49500186741352, 40.61562158167362, 37.40924723446369, 30.232931412756443, 41.184363663196564, 54.08151760697365, 47.32998289167881, 43.93397971987724, 40.17760768532753, 34.64955411851406, 44.93679530918598, 44.99033443629742, 42.72941775619984, 47.80048884451389, 48.85209001600742, 55.096370950341225, 62.742788046598434, 79.64528426527977, 73.91384661197662, 84.36597615480423, 73.28501835465431, 59.83460269868374, 33.74646037817001, 19.742693714797497, 11.685920488089323, 5.648210719227791, 1.7853933339938521, 0.3943247313145548, 0.08208279468817636, 0.11391699663363397, 0.04649466878618114, 0.08216480200644583, 0.06947691173991188, 0.07019208976998925, 0.014702445496368455, 0.019950061323470436, 0.008530323320883326, 0.04667839857575018, 0.06550038058776408, 0.011333710099279415, 0.03282781894085929, 0.021760955460194964, 0.057179428258677945, 0.04358965787105262, 0.04258111999661196, 0.03591681939724367, 0.037522763886954635, 0.01572934132127557, 0.08250777813373134, 0.03831338122836314, 0.030786955503572244, 0.04439917400304694, 0.03328150494780857, 0.03160693777317647, 0.051940277553512715, 0.05220570667006541, 0.02793590243527433, 0.04112044349312782, 0.04614303550624754, 0.010097951653733617, 0.054830846274853684, 0.027093524004158098, 0.04996731135179289, 0.04058494683704339, 0.08157091317116283, 0.07386863740975969, 0.03781248349696398, 0.026693393228924833, 0.06465317448601127, 0.02303318582562497, 0.032807283714646474, 0.047109571532928385, 0.08223158787586726, 0.0884253297408577, 0.0596644986217143, 0.03040097377379425, 0.0124150127703615, 0.09660226831329055, 0.016239705146290362, 0.02016904498304939, 0.04157046329055447, 0.037586143298540264, 0.010888358410738874, 0.013742894007009454, 0.020234888324921485, 0.06074711025576107, 0.06605076472624205, 0.07824287808034569, 0.03570598266378511, 0.017866088383016177, 0.01813395916542504, 0.010229614217678318, 0.058707989010144956, 0.028821800406149123, 0.05801004735985771, 0.05201514912187122, 0.04578388427034952, 0.029841867544746492, 0.03136017738142982, 0.02632652180182049, 0.08171503824996762, 0.04622883519914467, 0.0804070252343081, 0.009437031112611294, 0.05278779164655134, 0.0632883352227509, 0.047394504290423356, 0.028649768719333224, 0.099735296680592, 0.06057161088392604, 0.05096518085338175, 0.026581392012303695, 0.04489747792831622, 0.034510861441958696, 0.07558691708254628, 0.12613991653779522, 0.035355670406715944, 0.0495969314215472, 0.0454505597735988, 0.024944056531239767, 0.04923582833725959, 0.03351607185322791, 0.021523572104342747, 0.02482012343534734, 0.027536127890925854, 0.1028257109283004, 0.021013894765928853, 0.02658261284523178, 0.043399634669185616, 0.027207529019506183, 0.05063439079094678, 0.018515762603783514, 0.015958462718117516, 0.06411416004993953, 0.024054291970969643, 0.06050418676750269, 0.02435444617731264, 0.05283988299197517, 0.03354470019985456, 0.04716272414952982, 0.089590820716694, 0.05395422886067536, 0.014301297978818184, 0.04234592597640585, 0.016332659142790362, 0.03685744333779439, 0.03454778699961025, 0.06727172381943092, 0.013415557714324677, 0.014423507436731597, 0.026833224983420223, 0.026076651811308693, 0.1220571321027819, 2.072015991434455, 11.120098549872637, 26.353535279631615, 52.91949816048145, 71.62951558828354, 87.64910638332367, 97.22628727555275, 93.74988421797752, 84.11120742559433, 80.03160193562508, 74.87530902028084, 81.67546972632408, 75.54408833384514, 81.21998056769371, 62.40054041147232, 51.9858692586422, 55.19236899912357, 52.89945423603058, 55.088277384638786, 57.80915938317776, 35.544858276844025, 39.089995846152306, 44.8277335613966, 36.019365414977074, 51.92364759743214, 50.08820928633213, 48.549911230802536, 56.36580303311348, 70.20644634962082, 63.679832965135574, 58.97024028003216, 49.419467970728874, 44.265112951397896, 56.559820622205734, 56.895669400691986, 56.37526452541351, 67.676922082901, 61.23116835951805, 65.37479281425476, 72.37952694296837, 90.65863609313965, 83.16442742943764, 95.71627110242844, 86.05556309223175, 73.30443531274796, 41.38089671730995, 23.450840637087822, 14.806958064436913, 7.18544720672071, 2.3385268030688167, 0.5035927367862314, 0.10490832573850639, 0.12693071941612288, 0.023433824972016737, 0.05290128829074092, 0.06574082901352085, 0.050068859418388456, 0.08149830886395648, 0.009398298425367102, 0.026731252037279774, 0.012942594421474496, 0.04770539737364743, 0.014788323114771629, 0.03383300601853989, 0.014656011171609862, 0.0119396189438703, 0.017026626592269167, 0.05488011745910626, 0.0448952477745479, 0.051034601347055286, 0.05038856921601109, 0.07779078398016281, 0.046344907095772214, 0.025612583158363122, 0.024470913267578, 0.029269964834384155, 0.07691890888963826, 0.021296454506227747, 0.04281641049601603, 0.02353903924813494, 0.0269205405129469, 0.06039569962013047, 0.023466780039598234, 0.06143545964732766, 0.019720442687685136, 0.031559043272864074, 0.09795388250495307, 0.05138027889188379, 0.08800554132903926, 0.03872961475281045, 0.03470845826086588, 0.04595519792928826, 0.01579085052071605, 0.03174996076268144, 0.023768869396008085, 0.06475426984252408, 0.028332326182862744, 0.017649284782237373, 0.05782097781775519, 0.046703397820238024, 0.03361742325068917, 0.0355872019281378, 0.03173411590978503, 0.04330443567596376, 0.04578326457703952, 0.006074566399547621, 0.01558234969706973, 0.006906345106472145, 0.0571772686089389, 0.03663002331450116, 0.0742647513106931, 0.06893508456414565, 0.04070190560014453, 0.008755097587709315, 0.0340576429880457, 0.032749344245530665, 0.14632986596552655, 0.18564506492111832, 0.07654946777620353, 0.18089762044837698, 0.13483537884894758, 0.15036431432235986, 0.09623274556361139, 0.2498972718603909, 0.07256112163304351, 0.17826520779635757, 0.07438774744514376, 0.20249962457455695, 0.1523350874776952, 0.17837994382716715, 0.12739039084408432, 0.18246813851874322, 0.12544879893539473, 0.13397767877904698, 0.09504114583251067, 0.2155246725305915, 0.1181763454223983, 0.13861936720786616, 0.2380794458440505, 0.12886120879556984, 0.20260036370018497, 0.14217526389984414, 0.15496598614845425, 0.11327302767313085, 0.17652343172812834, 0.07187576309661381, 0.07623939847690053, 0.10421919709187932, 0.14326167904073372, 0.12262739837751724, 0.11002432816894725, 0.13188372395234182, 0.08357875660294667, 0.16306609759340063, 0.13777054322417825, 0.15362471749540418, 0.33859430928714573, 0.12126437737606466, 0.14050602534553036, 0.1306151709286496, 0.10002091221394949, 0.06903821340529248, 0.1636560753104277, 0.17876136320410296, 0.14143853390123695, 0.10282370712957345, 0.17650419526034966, 0.1463391279685311, 0.12326779760769568, 0.12431782524799928, 0.2003560942830518, 0.11422035691794008, 0.25891650351695716, 0.12689067312749103, 0.21320691565051675, 0.22464094741735607, 3.513724417425692, 14.750712532550097, 34.95153531432152, 66.88995391130447, 86.12638369202614, 101.14856600761414, 110.41648149490356, 105.231614112854, 93.95893380045891, 92.13031992316246, 89.71064016222954, 96.01162165403366, 85.10733157396317, 89.51338514685631, 69.58262622356415, 60.77042028307915, 64.51923072338104, 56.20204322040081, 62.13192902505398, 62.39418335258961, 37.17511899769306, 47.96232596039772, 51.47098548710346, 38.10322679579258, 59.95767429471016, 58.303706645965576, 49.83061730861664, 59.62123654782772, 76.54005289077759, 68.36469277739525, 66.2669925391674, 58.42220328748226, 54.25496689975262, 66.94389581680298, 66.23092487454414, 63.39365892112255, 69.770298153162, 69.52654123306274, 78.77044200897217, 88.57346758246422, 103.95402386784554, 97.46838748455048, 106.8404021859169, 100.00859677791595, 86.1967559158802, 53.958168625831604, 34.8968942463398, 21.409251987934113, 11.35306404903531, 4.287065332755446, 1.1916953790932894, 0.31938435102347285, 0.2539715438615531, 0.17875373392598704, 0.17019246675772592, 0.1390694352448918, 0.23231012339238077, 0.13401490490650758, 0.11975746878306381, 0.13437336223432794, 0.11177872816915624, 0.20064821845153347, 0.06765801168512553, 0.2016165282111615, 0.09454251165152527, 0.10786057435325347, 0.08926983442506753, 0.21340687992051244, 0.10146632645046338, 0.15833876532269642, 0.1994417535024695, 0.16468874411657453, 0.12721684703137726, 0.11390016472432762, 0.12983251683181152, 0.11358336414559744, 0.1330151577712968, 0.12904149130918086, 0.2548096067039296, 0.07016316085355356, 0.0994291013921611, 0.12905560695799068, 0.2047300900449045, 0.19546704803360626, 0.0809869245858863, 0.12316339227254502, 0.18704297428485006, 0.13320085796294734, 0.16976631071884185, 0.12525897240266204, 0.13057301694061607, 0.21019670530222356, 0.13406767160631716, 0.14540718344505876, 0.15893801988568157, 0.1642410657950677, 0.18770375289022923, 0.15652489702915773, 0.1536484810640104, 0.1467275235336274, 0.18857280781958252, 0.13121960568241775, 0.17595610435819253, 0.11997114052064717, 0.20728113362565637, 0.09540352170006372, 0.08569240802899003, 0.165509203216061, 0.20452855242183432, 0.1893000680138357, 0.18800451565766707, 0.10626111252349801, 0.1290374540258199, 0.09861877260846086, 0.1506369051639922, 0.18419758009258658], [0.06499335271655582, 0.07360872987192124, 0.015488867848034715, 0.04490742641792167, 0.04222931602271274, 0.03957493579946458, 0.06517845176858827, 0.036964561222703196, 0.034644815386855043, 0.09535684061120264, 0.03190606410498731, 0.026623725971148815, 0.042806829369510524, 0.0495795800088672, 0.07459115528035909, 0.026040685479529202, 0.025240173454221804, 0.03424655667913612, 0.01737199429044267, 0.013244837773527252, 0.013160193975636503, 0.049367782194167376, 0.0681253123912029, 0.07013613925664686, 0.01337667566986056, 0.012748982935590902, 0.06868856537039392, 0.06368627480696887, 0.019619948470790405, 0.0989781873067841, 0.042302506626583636, 0.021150078864593524, 0.057505880467942916, 0.06777141185011715, 0.027500406467879657, 0.07470546086551622, 0.0698519783327356, 0.016589340193604585, 0.024267457192763686, 0.09483626112341881, 0.03480536790448241, 0.0632203693385236, 0.041139861787087284, 0.04224814802000765, 0.04806077107787132, 0.0307526608594344, 0.011898766497324686, 0.024659374248585664, 0.028254818134882953, 0.12854910601163283, 0.012237755436217412, 0.07164117763750255, 0.054033868727856316, 0.01341732773653348, 0.05560672827414237, 0.07155300307204016, 0.0837599445367232, 0.16822426143335178, 3.5423430567607284, 12.733865305781364, 42.2774738073349, 64.70235049724579, 77.41125494241714, 81.73489853739738, 75.55475056171417, 65.49190253019333, 64.30250555276871, 54.48959670960903, 56.228193417191505, 39.40979428589344, 42.59336605668068, 40.631660521030426, 36.08806952834129, 33.7575975805521, 21.312516778707504, 19.84336171299219, 27.229059599339962, 13.084157109260559, 20.705094672739506, 33.8135039806366, 71.88243001699448, 42.11450435221195, 17.67249260097742, 34.81041468679905, 23.181376196444035, 22.458240799605846, 18.370600640773773, 25.967608988285065, 22.401789128780365, 12.009328734129667, 16.842375844717026, 20.269636139273643, 29.538959451019764, 26.03565763682127, 16.2777641415596, 11.713020633906126, 13.273522797971964, 30.08445058017969, 32.95908562839031, 29.467487186193466, 37.46395669877529, 52.1611462533474, 54.9494594335556, 73.41688647866249, 76.49675041437149, 72.13114947080612, 68.81083443760872, 57.30903021991253, 43.98526556789875, 31.222939789295197, 11.844388134777546, 3.101258212700486, 0.8600335009396076, 0.420048133819364, 0.15650588320568204, 0.08402615290833637, 0.07582342470414005, 0.03331647123559378, 0.08823254946037196, 0.019669108332891483, 0.034993943918379955, 0.02971464487927733, 0.042940568091580644, 0.029613564365718048, 0.028898002274218015, 0.03043773234821856, 0.03890292478899937, 0.04053144541103393, 0.05200203537242487, 0.023268845543498173, 0.029863271083740983, 0.04007226751127746, 0.0386290797177935, 0.046895079722162336, 0.04343391447036993, 0.026391409628558904, 0.02586979670013534, 0.030934282949601766, 0.025475269139860757, 0.06001946414471604, 0.0644735450623557, 0.031922046255203895, 0.02237391563539859, 0.07391509585431777, 0.03245761341531761, 0.023135717237892095, 0.03395468113012612, 0.04319047147873789, 0.053962051097187214, 0.00698145972819475, 0.00928812845813809, 0.07192207311163656, 0.010927421353699174, 0.045177709180279635, 0.04138772426813375, 0.018251259316457435, 0.027279094319965225, 0.02506429002096411, 0.07402308576274663, 0.010155926374864066, 0.07588050328195095, 0.05358187481760979, 0.061287300995900296, 0.0617717230488779, 0.014662042049167212, 0.022962670664128382, 0.027174317910976242, 0.08986850269138813, 0.060378307389328256, 0.08128076311550103, 0.01890275365440175, 0.029502416618925054, 0.04350282659288496, 0.020371840546431486, 0.07879976343247108, 0.017581107385922223, 0.07552028706413694, 0.009375337303936249, 0.04786868470546324, 0.02463266620907234, 0.017133334440586623, 0.06851364858448505, 0.03091856611717958, 0.056390848112641834, 0.03662858725874685, 0.07612501867697574, 0.06852755643194541, 0.03604817953601014, 0.02746664988080738, 0.04410833746078424, 0.06669841473922133, 0.029535317880799994, 0.049428879501647316, 0.03423674177611247, 0.04114611438126303, 0.024995834319270216, 0.037939654212095775, 0.05662214956828393, 0.03631144900282379, 0.05198993836529553, 0.03261630314227659, 0.0399487852700986, 0.00793823141066241, 0.06883205962367356, 0.07663260315894149, 0.04441110031621065, 0.09954386710887775, 0.011343708683853038, 0.04229279191349633, 0.032371412962675095, 0.034882974287029356, 0.01754741202603327, 0.07271790032973513, 0.10178261494729668, 0.1294281057198532, 0.02892135951697128, 0.05349961887986865, 0.03740189400559757, 0.03229095302231144, 0.031676488142693415, 0.10928341245744377, 0.027594009843596723, 0.047926449769875035, 0.018383766073384322, 0.08192997906007804, 0.07932652501040138, 0.05241436148935463, 0.06802056566812098, 0.07917672250187024, 0.03543755527061876, 0.039450299518648535, 0.08026616560528055, 0.04576455874484964, 0.08941907290136442, 5.913747595623136, 19.883987233042717, 52.98671655356884, 76.5066222846508, 88.21747988462448, 94.5394666492939, 86.63956135511398, 78.20586070418358, 75.72786927223206, 65.5133181810379, 64.69922706484795, 52.38085426390171, 56.41772344708443, 54.53595042228699, 51.30802363157272, 46.542775332927704, 35.269080474972725, 31.483279019594193, 41.25564783811569, 24.93382316082716, 35.90020380914211, 39.64027091860771, 52.24113196134567, 50.166272297501564, 31.40338070690632, 32.20763795077801, 40.826221480965614, 38.09959419071674, 25.8748122677207, 40.64020246267319, 37.00826235115528, 26.035197861492634, 28.76127988100052, 30.893301777541637, 40.60039579868317, 38.689352944493294, 30.531033016741276, 28.30436769872904, 21.56222227960825, 38.409862741827965, 47.30771988630295, 43.567348793148994, 53.4462258964777, 65.97429424524307, 67.08837926387787, 84.54967349767685, 88.06776031851768, 84.3936462700367, 81.0745395720005, 67.84720614552498, 51.013493835926056, 35.562515929341316, 13.579359836876392, 3.73801426962018, 0.7078378926962614, 0.08387202367885038, 0.06175265727506485, 0.07500757434172556, 0.07117070053936914, 0.03254722403653432, 0.022515201999340206, 0.06746633720467798, 0.047250828210962936, 0.09094380046008155, 0.05269016954116523, 0.011751882484531961, 0.026055072012241, 0.04725290993519593, 0.02223986892204266, 0.06343413755530491, 0.030314797440951224, 0.01657213164435234, 0.07169746211729944, 0.003210719864910061, 0.028642382494581398, 0.07243868210935034, 0.004973044378857594, 0.036146269194432534, 0.029514034940802958, 0.056439896652591415, 0.07723518996499479, 0.05370066668547224, 0.03275516639405396, 0.05608610372291878, 0.03934729684260674, 0.03197765538061503, 0.056170148236560635, 0.03745852729480248, 0.010442007605888648, 0.054887375663383864, 0.03969421006331686, 0.06790418949094601, 0.06056472746422514, 0.01149996602180181, 0.03135834056593012, 0.021698197597288527, 0.052906731943949126, 0.036270860946387984, 0.015827959759917576, 0.045497444953070953, 0.03806991226156242, 0.022965817370277364, 0.0526683763746405, 0.15037296776426956, 0.04284616690711118, 0.017376669820805546, 0.0062352450822800165, 0.07731765741482377, 0.08443009646725841, 0.08657297366880812, 0.026107102130481508, 0.05061335461505223, 0.03373814841324929, 0.0418153905775398, 0.037341731804190204, 0.03507831868773792, 0.056775458724587224, 0.04393659335619304, 0.19277401675935835, 0.2249067253433168, 0.1836075578466989, 0.08424354280577973, 0.1618611763115041, 0.14782348269363865, 0.15386312501505017, 0.16975553473457694, 0.18009429011726752, 0.19515804742695764, 0.2012201471370645, 0.07564984378404915, 0.19685493840370327, 0.12386467729811557, 0.21769640443380922, 0.08421315927989781, 0.08762900528381579, 0.10248407066683285, 0.08279706729808822, 0.09630875632865354, 0.16305993776768446, 0.1366339292144403, 0.07641653428436257, 0.1418238421319984, 0.12087976676411927, 0.09430376274394803, 0.15733876585727558, 0.1899838977260515, 0.09310664143413305, 0.1776064478326589, 0.18208783236332238, 0.1845943767693825, 0.1658946747193113, 0.1802864024648443, 0.12432223360519856, 0.12779165524989367, 0.1288589378236793, 0.16368328244425356, 0.2312093402724713, 0.15088545042090118, 0.15939766162773594, 0.28448743920307606, 0.10838939910172485, 0.12002716524875723, 0.17839771084254608, 0.18038697831798345, 0.1689226075541228, 0.1328478628420271, 0.21663627616362646, 0.19690933782840148, 0.10924205998890102, 0.1766284604673274, 0.22046388796297833, 0.154516986804083, 0.21365814143791795, 0.1310947912861593, 0.20246554515324533, 0.30808648851234466, 7.3118949215859175, 25.390336364507675, 64.45149555802345, 89.1328963637352, 103.02098393440247, 105.15376389026642, 96.99238702654839, 85.59505820274353, 85.87922975420952, 75.16552224755287, 75.6896661221981, 61.33905977010727, 66.0689015686512, 61.135181710124016, 56.50007642805576, 54.01965692639351, 33.465298265218735, 33.222628086805344, 46.985067799687386, 24.79363728314638, 34.808104410767555, 49.806063026189804, 87.92928814888, 59.050860553979874, 34.25957724452019, 50.076327323913574, 40.95976911485195, 37.587081491947174, 33.42473924160004, 41.87882959842682, 39.546735137701035, 26.345561407506466, 29.867898300290108, 34.36053402721882, 45.16948722302914, 43.468588292598724, 31.53706893324852, 25.562172643840313, 24.107282012701035, 46.754446774721146, 52.39783935248852, 49.32870224118233, 59.18918073177338, 75.34826964139938, 81.68967336416245, 97.63075277209282, 101.18791669607162, 97.57823199033737, 92.41674095392227, 81.37224599719048, 63.1252109259367, 47.831799164414406, 20.625274255871773, 7.651731111109257, 1.6588591737672687, 0.7776906131766737, 0.36426160542760044, 0.29531973763369024, 0.1818085918785073, 0.17322832572972402, 0.16534662834601477, 0.13695391360670328, 0.0878415341139771, 0.16492505877977237, 0.18761830200674012, 0.1002582955698017, 0.10611445672111586, 0.1522285002283752, 0.06159160009701736, 0.13626831758301705, 0.15748936246382073, 0.16555865993723273, 0.14401170832570642, 0.17712256754748523, 0.11303700986900367, 0.1762025716016069, 0.1118643200607039, 0.1716094047878869, 0.1564213674282655, 0.11236420847126283, 0.17810033226851374, 0.19316291698487476, 0.15351213369285688, 0.2110161996097304, 0.06868489173939452, 0.15524699294473976, 0.18004888552241027, 0.12704518827376887, 0.13116057525621727, 0.10590106699964963, 0.09988398596760817, 0.194467538385652, 0.09491897348198108, 0.23540903523098677, 0.11849014772451483, 0.17411868029739708, 0.15850666881306097, 0.11994351778412238, 0.12060172855854034, 0.11209674587007612, 0.13697987393243238, 0.10252870342810638, 0.15416241833008826, 0.2348984227865003, 0.15562415239401162, 0.11120000141090713, 0.1345030451193452, 0.17269865493290126, 0.15658769756555557, 0.23579655506182462, 0.13634073635330424, 0.170522173284553, 0.11736398315406404, 0.15414686291478574, 0.12514405825641006, 0.08286823183880188, 0.20705638162326068, 0.15626498206984252], [0.022559070348506793, 0.032400390118709765, 0.04113749433599878, 0.06525904158479534, 0.01937337361596292, 0.028573412855621427, 0.09983513780753128, 0.032876793266041204, 0.016000121322576888, 0.028347384359221905, 0.016723208791518118, 0.03389255594811402, 0.05242286279099062, 0.02610817267850507, 0.03595403439248912, 0.009375499648740515, 0.0285982284185593, 0.10811593994731084, 0.017508157980046235, 0.021708418826165143, 0.011448583427409176, 0.03798173398536164, 0.021820147303515114, 0.0459493460948579, 0.07176919069024734, 0.045516588652390055, 0.03457895349129103, 0.0354026891727699, 0.03683198396174703, 0.04304571557440795, 0.017594751770957373, 0.05850074056070298, 0.08159634657204151, 0.04401323494676035, 0.04842392991122324, 0.04047047426865902, 0.05645345197990537, 0.005954601474513765, 0.028750793571816757, 0.07050558037008159, 0.04042747423227411, 0.00862950022565201, 0.05599577692919411, 0.007634185567439999, 0.029039106811978854, 0.022425268543884158, 0.007822145598765928, 0.016867658559931442, 0.00989718771961634, 0.06222644435183611, 0.10070639691548422, 0.015775502906762995, 0.07575324721983634, 0.1789692387683317, 0.3830148163251579, 0.36477389512583613, 4.730754224583507, 18.511671870946884, 49.92977298796177, 74.54342722892761, 81.10185250639915, 71.067556142807, 60.91290503740311, 52.8853227943182, 46.35774426162243, 36.31928712129593, 34.27985295653343, 42.146886214613914, 42.50802643597126, 25.418857634067535, 27.331211417913437, 25.42726468294859, 15.918852500617504, 26.473827324807644, 25.721199810504913, 23.127601481974125, 20.12760356068611, 34.110906422138214, 19.18090905994177, 51.67808197438717, 109.22684893012047, 56.425121650099754, 40.94874210655689, 59.193406105041504, 49.635581374168396, 54.298732951283455, 52.91248753666878, 47.338931411504745, 33.44501115381718, 38.021303191781044, 28.971651792526245, 21.055200286209583, 16.959565356373787, 19.81598038226366, 23.15755907446146, 30.042407736182213, 56.46328680217266, 35.442590564489365, 24.630223251879215, 19.445207677781582, 14.76152390241623, 24.036822393536568, 27.893919423222542, 38.98423232138157, 63.585404232144356, 60.540088042616844, 61.86547592282295, 66.58285439014435, 67.18708276748657, 67.13456198573112, 53.46236743032932, 36.00570134818554, 23.35532136261463, 14.467519428581, 8.678096886724234, 3.01194756757468, 0.9048910439014435, 0.1197059266269207, 0.03585770733479876, 0.08253844367573038, 0.026241850173391867, 0.052127792296232656, 0.006431564943341073, 0.03853479356621392, 0.02250499190267874, 0.038613027063547634, 0.01512528135208413, 0.026872612615989055, 0.03602606724598445, 0.0399164944246877, 0.06003264839819167, 0.025989403075072914, 0.04510925347858574, 0.0458452821476385, 0.039474111326853745, 0.033312552695861086, 0.04833104270801414, 0.03399648630875163, 0.03237415148760192, 0.03481769497739151, 0.011634885686362395, 0.06004877155646682, 0.07216367186629213, 0.058994227947550826, 0.018145800131605938, 0.06846552772913128, 0.02993604608491296, 0.0305617953199544, 0.018518595752539113, 0.04006111303169746, 0.02120318324159598, 0.028442520269891247, 0.026370353043603245, 0.016488254113937728, 0.025944881635950878, 0.01640901686187135, 0.024897188050090335, 0.08756761482800357, 0.05534937001357321, 0.03012423803738784, 0.0334290513274027, 0.06241771436179988, 0.06795756475185044, 0.012143552776251454, 0.028467319134506397, 0.03815332966041751, 0.04066860543389339, 0.02248434906505281, 0.08144472580170259, 0.009659989900683286, 0.04354362616140861, 0.013086759390716907, 0.07344719400862232, 0.012351687164482428, 0.026904218830168247, 0.0837386745843105, 0.026580924459267408, 0.03967597920564003, 0.051021391118410975, 0.02027688460657373, 0.04346052046457771, 0.051540300773922354, 0.03319464027299546, 0.034794450912158936, 0.07093466047081165, 0.10251229454297572, 0.046821391879348084, 0.05187667178688571, 0.017229559452971444, 0.01786608096153941, 0.01635402557440102, 0.01413252524798736, 0.03432192919717636, 0.049769736797316, 0.05903531695366837, 0.07782049215165898, 0.02622531697852537, 0.05507872730959207, 0.009499256484559737, 0.008599781849625288, 0.04710073255409952, 0.07428484866977669, 0.0630295260634739, 0.04269338838639669, 0.04284945462131873, 0.00552879331735312, 0.05440097207610961, 0.030564554253942333, 0.06792065032641403, 0.04691109155828599, 0.02358338071644539, 0.05693102029908914, 0.03526731401507277, 0.009190674263663823, 0.10119269660208374, 0.01956384767254349, 0.006586267018064973, 0.019945216954511125, 0.05716892315831501, 0.040916360303526744, 0.040490026149200276, 0.0023577806723551475, 0.012032854956487427, 0.016710905838408507, 0.04403566264954861, 0.02751586911472259, 0.05671302184055094, 0.05229064918239601, 0.013211149835115066, 0.059073908632854, 0.3166356438305229, 0.464117040974088, 7.283899448812008, 23.028550297021866, 62.09698989987373, 85.55602669715881, 90.8342170715332, 80.63700065016747, 73.96371513605118, 63.24078172445297, 58.24294410645962, 52.88393586874008, 50.874824076890945, 54.44580785930157, 57.80895799398422, 36.54037065804005, 37.5721824914217, 29.6413354575634, 23.575232662260532, 35.55342301726341, 25.773692093789577, 33.525916412472725, 34.08287152647972, 33.530856147408485, 21.241190806031227, 52.40833818912506, 111.10600769519806, 53.72165031731129, 32.62572951614857, 46.19540937244892, 46.27675920724869, 43.687581941485405, 45.87592251598835, 42.765105441212654, 41.410972103476524, 36.94762520492077, 33.73510658740997, 26.025534979999065, 30.808319337666035, 30.681314952671528, 25.681336149573326, 22.459485232830048, 42.49936670064926, 50.6107534468174, 35.88023208081722, 32.30730280280113, 30.60577690601349, 43.54989252984524, 42.7064061909914, 51.94631338119507, 72.52595588564873, 76.98407426476479, 75.85262417793274, 78.7365174293518, 78.4318345785141, 78.57468411326408, 61.60398915410042, 42.08587288856506, 28.09493623673916, 17.548079676926136, 8.975114598870277, 2.840788601897657, 0.7791879109572619, 0.014975050253269728, 0.008857699504005723, 0.035206910615670495, 0.07807772053638473, 0.06922035870957188, 0.023401105536322575, 0.02579379521193914, 0.040722385165281594, 0.045914728616480716, 0.016030942715588026, 0.025372125455760397, 0.014701673662784742, 0.11158105713548139, 0.041675896500237286, 0.05019457923481241, 0.026877239906752948, 0.01695738606940722, 0.025211231550201774, 0.023822057264624164, 0.05547871522139758, 0.027832148334709927, 0.032080732271424495, 0.020069660276931245, 0.05735817081585992, 0.0650931047857739, 0.07021948986221105, 0.04251899110386148, 0.03577800809580367, 0.09165710827801377, 0.05005100705602672, 0.014435879038501298, 0.029702592401008587, 0.04226276832923759, 0.044913845995324664, 0.03031226857274305, 0.04280513727280777, 0.026429680328874383, 0.0481230112927733, 0.01561721208418021, 0.014420410825550789, 0.07028610503766686, 0.0755416312313173, 0.017149897321360186, 0.029171472560847178, 0.05028628642321564, 0.06563454604474828, 0.0348851116723381, 0.03337860012834426, 0.04513064959610347, 0.01853973211837001, 0.0721353069820907, 0.028545085078803822, 0.032886159169720486, 0.04767744067066815, 0.033987636197707616, 0.043321531047695316, 0.08705856089363806, 0.020660406116803642, 0.036322306623333134, 0.10273213352775201, 0.10437072138302028, 0.15229162730975077, 0.16795883973827586, 0.18972573423525319, 0.1606024641660042, 0.22122840397059917, 0.12703083513770252, 0.149263575731311, 0.20484513777773827, 0.12168672619736753, 0.16549517662497237, 0.07583801532746293, 0.1625007443362847, 0.10727878994657658, 0.08593565435148776, 0.18406029761536047, 0.17640660284087062, 0.14285686716903, 0.1248153907363303, 0.11775661638239399, 0.154249279294163, 0.12145800370490178, 0.11546831534360535, 0.14768133172765374, 0.18547138752182946, 0.1104165161086712, 0.14514781767502427, 0.08538904032320715, 0.13630107598146424, 0.17550213262438774, 0.1343665790045634, 0.2732903603464365, 0.10183555976254866, 0.14581080788047984, 0.11785811249865219, 0.27577569417189807, 0.1899453208898194, 0.24678702000528574, 0.13715111708734185, 0.09638457413529977, 0.07557444900157861, 0.16775841533672065, 0.14487126376479864, 0.11516480662976392, 0.1303448955877684, 0.12540915340650827, 0.09225338682881556, 0.15039505407912657, 0.1264973942306824, 0.254542967886664, 0.17387016472639516, 0.15244112553773448, 0.2447214152198285, 0.660065074916929, 0.9713994094636291, 9.323685094714165, 30.9645726531744, 75.2828599512577, 99.19218018651009, 101.6841472685337, 90.91066896915436, 81.48637667298317, 68.60411033034325, 63.406566828489304, 56.72131955623627, 51.65575057268143, 62.12469421327114, 59.88355167210102, 41.49989493191242, 47.15336836874485, 43.2592461258173, 31.036170311272144, 47.48186074197292, 40.302544981241226, 35.603762716054916, 35.08741222321987, 51.33505538105965, 32.60074205696583, 69.06363487243652, 123.40704962611198, 74.37074169516563, 59.91585373878479, 80.51083222031593, 65.68666487932205, 74.45236131548882, 74.43671375513077, 66.71165987849236, 54.53417971730232, 54.618725180625916, 45.43251670897007, 37.05219179391861, 30.045966245234013, 31.14587802439928, 40.88677503168583, 43.447108045220375, 72.47772887349129, 51.81493163108826, 39.956596344709396, 34.89096276462078, 30.978835187852383, 40.07968693971634, 47.2393349558115, 59.930418357253075, 87.72710859775543, 88.10124412178993, 86.40218809247017, 92.27726563811302, 93.87469232082367, 91.55030384659767, 76.74836531281471, 54.90911319851875, 39.91617031395435, 25.392658039927483, 13.84510237723589, 4.8188586719334126, 1.6962042823433876, 0.23171221953816712, 0.1435088290600106, 0.16677146282745525, 0.14771036454476416, 0.1948706730036065, 0.07454081540345214, 0.09768108386197127, 0.1008223500684835, 0.09517580110696144, 0.10057631327072158, 0.0660871596483048, 0.09837339632213116, 0.2217216501594521, 0.11189941622433253, 0.1911022252170369, 0.09702656156150624, 0.09114619897445664, 0.10058935280540027, 0.12950539297889918, 0.12456332769943401, 0.14293206157162786, 0.10287449971656315, 0.10189165870542638, 0.12611392652615905, 0.314633299713023, 0.18388421565759927, 0.1279162915307097, 0.18133510166080669, 0.15483746101381257, 0.07576764488476329, 0.10132738156244159, 0.12177562806755304, 0.1362280041212216, 0.08103350177407265, 0.12768592889187858, 0.09674983695731498, 0.08636486061732285, 0.11438798581366427, 0.08936494807130657, 0.1267173222731799, 0.19991652021417394, 0.16020100680179894, 0.10086775466334075, 0.14067431475268677, 0.14820132491877303, 0.17557950894115493, 0.11095023161033168, 0.19400037126615644, 0.1458275952609256, 0.12071703604306094, 0.14863006363157183, 0.09700683527626097, 0.17586375150131062, 0.09336992574390024, 0.13821862230543047, 0.13849627459421754, 0.2338558092014864, 0.13947582046967, 0.1451080830884166], [0.056292261215276085, 0.06842172617325559, 0.05513964279089123, 0.04332049204094801, 0.06568034397787414, 0.05517111727385782, 0.010106233094120398, 0.033803757978603244, 0.02621834079036489, 0.0561304284929065, 0.02130478882463649, 0.08895476305042394, 0.03622957527113613, 0.027167811131221242, 0.06250905789784156, 0.09651897707954049, 0.016855429821589496, 0.06313139325357042, 0.03001394376042299, 0.08400487553444691, 0.029331082550925203, 0.05122181923070457, 0.0059644149860105244, 0.02033321918133879, 0.011922748999495525, 0.021540418856602628, 0.043887351857847534, 0.011002316114172572, 0.05445293354569003, 0.05173900710360613, 0.04384832602227107, 0.033518851196276955, 0.04995600844267756, 0.042092326693818904, 0.022716644998581614, 0.025744726262928452, 0.04295869875932112, 0.05599273783445824, 0.008283138977276394, 0.05434058723039925, 0.042858367814915255, 0.016927160249906592, 0.0432862567686243, 0.029793282847094815, 0.06831310543930158, 0.0435155655577546, 0.009836202661972493, 0.011796824164775899, 0.04516478467849083, 0.022980127832852304, 0.11687928650644608, 0.044784344936488196, 1.977573127951473, 4.175198385491967, 9.380870126187801, 28.10348577797413, 50.235098004341125, 70.93098387122154, 82.2822667658329, 67.6758961379528, 56.54284693300724, 53.188880905508995, 28.57618421316147, 27.75030992925167, 26.267646588385105, 17.707294933497906, 16.12000610679388, 26.149512827396393, 23.54883547872305, 49.48821768164635, 45.54575823247433, 40.05246140062809, 45.088399574160576, 37.49331772327423, 54.51993428170681, 58.55682626366615, 56.84073954820633, 78.85634779930115, 64.31873068213463, 47.55266234278679, 35.4062607139349, 64.64900135993958, 61.8237541615963, 34.03196945786476, 55.62424622476101, 53.56186509132385, 46.55547425150871, 65.90109497308731, 64.38050776720047, 68.74966531991959, 50.98856337368488, 61.688109040260315, 55.40391504764557, 45.99723480641842, 41.87431924045086, 56.52371495962143, 40.19000642001629, 28.89035325497389, 30.957364439964294, 21.10236905515194, 16.458902321755886, 21.745900623500347, 16.533317528665066, 25.458183623850346, 38.26785296201706, 29.374082498252392, 30.971435084939003, 39.62604068219662, 52.803630977869034, 53.97491052746773, 69.25290271639824, 66.48825466632843, 74.4769535958767, 58.81605975329876, 43.30878786742687, 30.83579756319523, 19.146682396531105, 7.083374233916402, 0.9205618780106306, 0.43521537620108575, 0.05186139096622355, 0.054291579508571886, 0.023766984340909403, 0.035230377325206064, 0.049986588637693785, 0.05152976969839074, 0.009882357753667748, 0.02681471210962627, 0.0866837021021638, 0.026126230986847077, 0.04868028627242893, 0.05400669127993751, 0.024968426805571653, 0.07298171156435274, 0.01911433439090615, 0.039686354430159554, 0.06631390802795067, 0.02357787212531548, 0.04522100978647359, 0.05404532748798374, 0.026042987992696, 0.017255360216950066, 0.011425437696743757, 0.050657048559514806, 0.029731792201346252, 0.014972762583056465, 0.08983176638139412, 0.023834555031498894, 0.04832425205677282, 0.05580922697845381, 0.013155154792912072, 0.07150018442189321, 0.0031554233692077105, 0.02252824338938808, 0.03512208684696816, 0.0957689032657072, 0.04250998514180537, 0.04579152096994221, 0.021797975641675293, 0.032949687010841444, 0.033757054625311866, 0.05220349135925062, 0.04939905629726127, 0.018702447996474802, 0.018935285697807558, 0.023282469519472215, 0.05618546616460662, 0.04038710882014129, 0.008861917685862863, 0.013694842728000367, 0.07136222659028135, 0.09031555760884658, 0.06059747473045718, 0.055411268840543926, 0.013782301120954799, 0.04307559072913136, 0.05358386748412158, 0.06216917281562928, 0.0015650765044483705, 0.019490247032081243, 0.030813912162557244, 0.06718790566083044, 0.05298659816617146, 0.06905955757247284, 0.0527806967147626, 0.03632589490734972, 0.02434648478811141, 0.06574776067282073, 0.02791646558762295, 0.05122593815030996, 0.06546802294906229, 0.043116353190271184, 0.022068449507059995, 0.029970270225021522, 0.012492406713136006, 0.04746277816593647, 0.023590718701598234, 0.04191491629171651, 0.027759742552007083, 0.027561503775359597, 0.06050620540918317, 0.014111963118921267, 0.04538421177130658, 0.0319007763027912, 0.04947912661009468, 0.01835134349676082, 0.08971085568191484, 0.03217969024262857, 0.023850084471632726, 0.02277092196891317, 0.027822858501167502, 0.0034771756963891676, 0.02337631409318419, 0.01982764406420756, 0.04190035906503908, 0.0244581872902927, 0.021608902388834395, 0.03345181299664546, 0.04740978140034713, 0.056096497501130216, 0.06327814553515054, 0.04148427768086549, 0.018643753392098006, 0.016627278782834765, 0.04611615862813778, 0.019943695551774, 0.06292238962487318, 0.09740193985635415, 2.481196797452867, 5.459011746570468, 11.743398103863, 33.64958457648754, 61.05961136519909, 82.8231829404831, 93.74400973320007, 78.82570624351501, 69.21474516391754, 65.44843286275864, 43.37044335901737, 43.74275878071785, 39.53886196017265, 30.885042920708656, 25.37954304367304, 38.92744816839695, 42.14846692979336, 44.275410398840904, 45.641551092267036, 44.81809347867966, 38.0178339779377, 36.04331932961941, 46.06936253607273, 42.22949758172035, 38.92211325466633, 63.601283580064774, 45.61703100800514, 46.01999178528786, 46.871849074959755, 51.69231601059437, 48.642660453915596, 40.26198975741863, 41.47176504135132, 44.56186182796955, 39.94470678269863, 50.640730038285255, 49.59986329078674, 53.97446595132351, 40.150222554802895, 48.77740882337093, 35.2196641266346, 38.49978871643543, 47.54774160683155, 60.21602623164654, 57.99558497965336, 39.4191037863493, 39.38808985054493, 31.321586295962334, 25.509104691445827, 34.14024844765663, 29.57927528768778, 38.3661612868309, 57.579883486032486, 39.76216457784176, 45.74610248208046, 52.856558337807655, 63.596507236361504, 65.53129881620407, 82.87368223071098, 77.7946163713932, 83.76124620437622, 68.11740964651108, 50.37336878478527, 36.830321699380875, 22.146693617105484, 7.3269482888281345, 0.9292467869818211, 0.26644802594091743, 0.06423605038435198, 0.10372837772592902, 0.04564047165331431, 0.03412522666621953, 0.0797177258937154, 0.07562202066765167, 0.036575772319338284, 0.03405865230888594, 0.05772290300228633, 0.03546062122040894, 0.09419112699106336, 0.03514414718665648, 0.01007517050311435, 0.03870693843055051, 0.014788166336074937, 0.03838594471744727, 0.0037328031294237007, 0.01975481896806741, 0.0585917204443831, 0.05780260224128142, 0.012831763942813268, 0.027921565997530706, 0.08357254482689314, 0.04605695008649491, 0.034942498241434805, 0.03869278938509524, 0.0314179238921497, 0.05591019245912321, 0.044112597388448194, 0.07454155755112879, 0.03020705800736323, 0.027481767428980675, 0.04004751317552291, 0.023179394484031945, 0.055281374443438835, 0.040125728119164705, 0.05611793814750854, 0.04373651034256909, 0.05551361471589189, 0.05985565730952658, 0.036414043497643434, 0.03060146867937874, 0.0420411593222525, 0.05015037691919133, 0.029721559840254486, 0.006665244054602226, 0.007168818619902595, 0.05750463737058453, 0.02412756050034659, 0.03015427089849254, 0.0650645988935139, 0.052576773086912, 0.026261049533786718, 0.049261491803918034, 0.0376294253510423, 0.02253208771435311, 0.15497848391532898, 0.14860401424812153, 0.12058851832989603, 0.09379126524436288, 0.17164535442134365, 0.16875543136848137, 0.17133062443463132, 0.2041883222409524, 0.20477908663451672, 0.14389406307600439, 0.11710178237990476, 0.16264255391433835, 0.12405593617586419, 0.09417117064003833, 0.1509798367624171, 0.23862268310040236, 0.1770282702636905, 0.17805938055971637, 0.08352646487765014, 0.1187365704390686, 0.16797705204226077, 0.12102325359592214, 0.19756973051698878, 0.10926027229288593, 0.084269020735519, 0.14920784044079483, 0.13228280644398183, 0.0907609352725558, 0.17732239823089913, 0.12131401963415556, 0.19285740447230637, 0.1793508362607099, 0.14839601994026452, 0.16074026614660397, 0.12577708053868264, 0.10610744342557155, 0.09929674677550793, 0.18879987532272935, 0.05375636857934296, 0.1525665633380413, 0.15498939348617569, 0.1302376255625859, 0.23248280631378293, 0.1179929162026383, 0.17959470598725602, 0.11606901709455997, 0.10004362193285488, 0.1088622139650397, 0.13539411214878783, 0.13679957657586783, 0.20851234177825972, 0.3617108438629657, 4.112185891717672, 8.45087667927146, 16.38448901474476, 41.834603771567345, 74.32669445872307, 95.44299736618996, 102.92503908276558, 87.39617675542831, 75.58008760213852, 71.901915371418, 46.862759962677956, 43.70922178030014, 43.36673095822334, 28.49649678915739, 28.55475716292858, 43.17163422703743, 39.80525806546211, 67.22044497728348, 66.36080950498581, 62.839979231357574, 65.99729061126709, 56.96422912180424, 77.147526293993, 76.44507318735123, 75.19661977887154, 99.1475173830986, 88.76145869493484, 65.91717571020126, 53.012163788080215, 84.39420104026794, 81.40226438641548, 50.72718299925327, 72.91898399591446, 70.89610934257507, 61.561701223254204, 82.66876682639122, 81.36614352464676, 92.77941629290581, 66.49859771132469, 82.39436835050583, 78.33516776561737, 63.765594363212585, 59.759549126029015, 71.95075035095215, 51.69358514249325, 43.20199839770794, 46.31176292896271, 36.92795366048813, 28.157042004168034, 32.78576172888279, 29.59351882338524, 42.359165623784065, 57.4186809360981, 47.29197733104229, 49.851048812270164, 57.99159899353981, 76.62174090743065, 76.541086435318, 92.85265356302261, 89.48441550135612, 99.26323637366295, 83.17993059754372, 64.03449833393097, 50.16043961048126, 31.937928423285484, 13.197548724710941, 2.83171231392771, 1.0061896895058453, 0.28011921735014766, 0.24217736267019063, 0.12371958000585437, 0.12578052410390228, 0.16675375518389046, 0.1530133659252897, 0.31347415409982204, 0.19754068285692483, 0.1502735199755989, 0.183599037991371, 0.19615473691374063, 0.10770712047815323, 0.06010472206980921, 0.18734980782028288, 0.0880238130048383, 0.15675539325457066, 0.11098799208411947, 0.09968998856493272, 0.16772515227785334, 0.09426927514141425, 0.0714049297675956, 0.17884445405798033, 0.16631795122520998, 0.16762356710387394, 0.09542111060000025, 0.10889984827372245, 0.13032445684075356, 0.17308089067228138, 0.1566239885869436, 0.1496042066719383, 0.10714863950852305, 0.20516311837127432, 0.0823068936006166, 0.10132766357855871, 0.08652937991428189, 0.16690711257979274, 0.21197484660660848, 0.16804987157229334, 0.15591869596391916, 0.14031775732291862, 0.07286801454029046, 0.10514459587284364, 0.21195356181124225, 0.06470348467701115, 0.09289096589782275, 0.09330470580607653, 0.17510497971670702, 0.11689210339682177, 0.1243800988595467, 0.09938524788594805, 0.12658655585255474, 0.18412753619486466, 0.15989392093615606, 0.11259988488745876, 0.06307081173872575, 0.19148077990394086], [0.02380695084866602, 0.031666858776588924, 0.021295972110237926, 0.04889117866696324, 0.0670469124452211, 0.07936469366541132, 0.02245468171167886, 0.06782840879168361, 0.011760895868064836, 0.028522709326352924, 0.0428287227259716, 0.006306541354206274, 0.02025000587309478, 0.07251760209328495, 0.0254126263098442, 0.012570609596878057, 0.07230211951537058, 0.054768498448538594, 0.0367426442244323, 0.017131009662989527, 0.040345073575736023, 0.028252144547877833, 0.053807049844181165, 0.01790496207831893, 0.02668072105734609, 0.0064135655429709, 0.024631836859043688, 0.0810226441535633, 0.019564875547075644, 0.04712056274001952, 0.06277465770835988, 0.07512629570555873, 0.0608004855166655, 0.02519605834095273, 0.03506800654577091, 0.03395677027583588, 0.04754384666739497, 0.04422661724674981, 0.04122982863918878, 0.03695567029353697, 0.022986005642451346, 0.0429831154178828, 0.051989968051202595, 0.04926345107378438, 0.05288971078698523, 0.03526676482579205, 0.030062008954701014, 0.09205956012010574, 0.0842864166770596, 0.27378605562262237, 4.227019529789686, 18.010203279554844, 36.82395704090595, 42.65316344797611, 64.13992747664452, 72.92223662137985, 72.69637674093246, 70.50764858722687, 56.205356642603874, 43.093544617295265, 30.06745219230652, 25.365354605019093, 27.64359075576067, 23.694114983081818, 25.819025561213493, 37.63115532696247, 50.59238523244858, 34.465096816420555, 42.94304609298706, 58.25460568070412, 48.52745823562145, 36.158396154642105, 59.32190001010895, 61.8710882216692, 51.31536103785038, 75.78405305743217, 71.73620626330376, 62.334822937846184, 48.12553860247135, 32.36891649663448, 25.048195123672485, 16.51240725070238, 10.219656117260456, 6.704884618520737, 4.700614716857672, 3.627073047682643, 6.117552984505892, 14.46117851883173, 23.57783742249012, 26.88132505863905, 38.55697184801102, 39.29340273141861, 58.09653036296368, 64.3022395670414, 51.92019738256931, 42.56986431777477, 41.69754132628441, 62.23398394882679, 61.079218313097954, 53.979094102978706, 53.06338123977184, 38.00902985036373, 24.66775193810463, 16.832676865160465, 14.174821134656668, 27.85627294331789, 17.727179266512394, 22.59874776005745, 36.55844248831272, 39.94222551584244, 52.6667433232069, 60.26526778936386, 57.29597792029381, 66.48636236786842, 79.19269055128098, 68.36537674069405, 64.52059864997864, 49.506042525172234, 31.596911922097206, 18.246261812746525, 4.412135621532798, 0.6042056379374117, 0.1980037978501059, 0.0073326212805113755, 0.031388401257572696, 0.029581713242805563, 0.03727467134012841, 0.006778741626476403, 0.021595131838694215, 0.032636560063110664, 0.005851132173120277, 0.05753913239459507, 0.04363353735243436, 0.047206277085933834, 0.003696398002830392, 0.024742377900111023, 0.058072885003639385, 0.06876204541185871, 0.027756610688811634, 0.02133197554940125, 0.056817575605236925, 0.004080147027707426, 0.023115643998607993, 0.014641596808360191, 0.02526714866689872, 0.025416129246877972, 0.014384547466761433, 0.08794157562078908, 0.014205570205376716, 0.005559037226703367, 0.07894159527495503, 0.06800831280997954, 0.017203268871526234, 0.017496945984021295, 0.04574963415507227, 0.04887801667791791, 0.02711821154662175, 0.07538817735621706, 0.06552864899276756, 0.08480476230033673, 0.07545278131146915, 0.07594503302243538, 0.022239269637793768, 0.027829973842017353, 0.02091631347866496, 0.006019899801685824, 0.03806048698606901, 0.02747721620835364, 0.04942062310874462, 0.06512206338811666, 0.06603013302083127, 0.10067368304589763, 0.018738121179922018, 0.049435154360253364, 0.026912321227428038, 0.03473524237051606, 0.02117169577104505, 0.013855080760549754, 0.026721233043645043, 0.044997953591519035, 0.03582655197533313, 0.050707288246485405, 0.01395787099681911, 0.044858132969238795, 0.13507958996342495, 0.02131795266905101, 0.047470841600443237, 0.05134224382345565, 0.09752578946063295, 0.03514926429488696, 0.056029466722975485, 0.04852121805015486, 0.017211245103680994, 0.060961045455769636, 0.06808216392528266, 0.0270733171782922, 0.09001931452075951, 0.07149754979764111, 0.01578023780894, 0.009013493927341187, 0.05206520698266104, 0.06579260865692049, 0.02058588150248397, 0.06498652495793067, 0.08747273124754429, 0.06383774714777246, 0.03670662779768463, 0.024999496818054467, 0.07116437001968734, 0.04587225921568461, 0.08067301838309504, 0.08848436758853495, 0.04248964658472687, 0.028373719469527714, 0.02957116175821284, 0.1006255102402065, 0.0521911679970799, 0.05595866583462339, 0.036770378283108585, 0.03587271727155894, 0.035738603764912114, 0.06847925746114925, 0.04591199009155389, 0.06528062323923223, 0.038882181761437096, 0.6484469608403742, 5.8093116246163845, 22.72378195077181, 42.18293108046055, 52.11118273437023, 76.13278314471245, 84.58649352192879, 84.0817666053772, 78.2067422568798, 65.68160355091095, 55.90246729552746, 49.493070021271706, 40.179378390312195, 34.44993942975998, 32.9613047093153, 29.2719591781497, 33.157860562205315, 39.15992349386215, 39.41046305000782, 37.05579400062561, 64.3413470685482, 48.16815711557865, 45.54405592381954, 58.622334748506546, 56.06429681181908, 48.83675403892994, 56.95260554552078, 56.6128695756197, 51.28098428249359, 42.62216471135616, 33.65308418869972, 25.53924847394228, 18.496333993971348, 11.680406983941793, 5.866242069751024, 5.154377818107605, 4.018205059692264, 6.485396046191454, 11.438409369438887, 19.925695694983006, 21.967740319669247, 27.34634030610323, 31.83321174234152, 44.44637082517147, 46.961767449975014, 43.01059506833553, 34.36453141272068, 31.526938676834106, 44.77329768240452, 48.15056785941124, 42.971400171518326, 39.78982709348202, 32.73035690188408, 31.915923804044724, 27.292229309678078, 23.954359218478203, 39.332441836595535, 29.56778660416603, 31.658780202269554, 47.70420961081982, 47.87306495010853, 66.35438024997711, 68.69176402688026, 69.15800660848618, 75.85169702768326, 88.17695125937462, 78.02523359656334, 71.82247683405876, 55.54868347942829, 35.92388793826103, 21.63722835481167, 5.699079539626837, 0.7915198523551226, 0.24516888573998585, 0.034443808399373665, 0.01653783143410692, 0.056555938863311894, 0.07034513546386734, 0.08765256105107255, 0.030875859229126945, 0.06781502786907367, 0.04160104719630908, 0.07231613126350567, 0.03591476735891774, 0.06722456033458002, 0.01890649593406124, 0.02363279661949491, 0.06746797735104337, 0.04242983690346591, 0.016225454055529553, 0.018825646366167348, 0.03603711040341295, 0.01375971756715444, 0.0920535487239249, 0.045043031641398557, 0.007726737876510015, 0.04202749638352543, 0.05670088401529938, 0.03457506092672702, 0.04878193081822246, 0.019657120792544447, 0.05976508189633023, 0.026267287285008933, 0.02870690295821987, 0.04193580032733735, 0.010803718323586509, 0.0932063118671067, 0.09269043017411605, 0.02675234016351169, 0.036563712419592775, 0.024459808882966172, 0.06663828593445942, 0.04556863546895329, 0.034388058265903965, 0.041658003319753334, 0.03203545755241066, 0.015389161235361826, 0.03494978984235786, 0.04510648526775185, 0.010133660089195473, 0.04887966795649845, 0.025713713766890578, 0.023465590747946408, 0.006860207176941913, 0.08662971085868776, 0.03049443428608356, 0.041041976219275966, 0.09361522781546228, 0.10785149788716808, 0.1536560064414516, 0.2240762917790562, 0.13975181034766138, 0.11066628590924665, 0.1591785647906363, 0.20359843358164653, 0.26033819129224867, 0.09187970805214718, 0.18062589049804956, 0.13891281239921227, 0.14837084629107267, 0.17960953409783542, 0.09107645935728215, 0.09285486783483066, 0.10986425433657132, 0.15368955151643604, 0.15140200004680082, 0.09225409929058515, 0.14370273740496486, 0.21069780341349542, 0.11539539191289805, 0.07683624848141335, 0.12421518622431904, 0.16873699642019346, 0.16468374204123393, 0.2053067833185196, 0.12272678679437377, 0.1897174073383212, 0.14208435080945492, 0.1323217395110987, 0.17383828206220642, 0.1719883008627221, 0.15353991970187053, 0.2040194094297476, 0.14767891232622787, 0.1481069385772571, 0.10940173306153156, 0.12109039569622837, 0.09954735520295799, 0.1830447872634977, 0.14879115420626476, 0.13723536569159478, 0.2793819084763527, 0.1636791115743108, 0.16558511008042842, 0.13399860734352842, 0.16140070336405188, 1.5080737648531795, 9.283962976187468, 30.75286701321602, 50.951709151268005, 63.50433178246021, 87.92340606451035, 94.19458955526352, 94.59642559289932, 89.86421272158623, 75.19212082028389, 61.846628934144974, 46.43741838634014, 39.85733047127724, 38.66465426981449, 35.333266630768776, 38.79014253616333, 51.957328990101814, 70.67143499851227, 50.78150488436222, 59.14679020643234, 80.60822859406471, 69.98806446790695, 57.02071689069271, 81.65347650647163, 82.61094152927399, 70.53131371736526, 95.73906987905502, 94.92652907967567, 79.73533943295479, 63.389064967632294, 46.599871069192886, 35.67305959761143, 23.09326272457838, 13.418742455542088, 9.120385553687811, 6.490942323580384, 5.244197398424149, 9.492987859994173, 18.52516684681177, 32.6155536621809, 34.164939522743225, 50.01531019806862, 52.86565884947777, 74.40253838896751, 85.46613112092018, 70.37411615252495, 55.11889234185219, 58.27735885977745, 82.15325608849525, 80.10917097330093, 72.96474874019623, 74.54969689249992, 54.09445971250534, 39.892186000943184, 31.042544469237328, 27.57180880755186, 44.14443142712116, 28.540842309594154, 38.34765248000622, 54.736632853746414, 59.85586255788803, 73.63751783967018, 80.85610449314117, 78.39523494243622, 86.66912376880646, 100.74038431048393, 94.03473973274231, 84.81672316789627, 67.96120762825012, 50.202674344182014, 30.117769092321396, 9.856321513652802, 1.423062589019537, 0.4851163469720632, 0.06815365501097403, 0.13402294978732243, 0.08742325226194225, 0.13728042889852077, 0.1604209645302035, 0.12460457626730204, 0.15725327044492587, 0.12349110984359868, 0.15090884291566908, 0.11291549060842954, 0.12872244202299044, 0.10223743272945285, 0.09822412073845044, 0.27253711014054716, 0.16228844557190314, 0.11406288802390918, 0.15897624049102888, 0.14177707198541611, 0.08519453083863482, 0.19983899546787143, 0.1433591972454451, 0.14510787528706715, 0.1094945683144033, 0.08299283101223409, 0.21694846800528467, 0.13704849290661514, 0.1569334790110588, 0.19712893932592124, 0.14162172563374043, 0.15529790427535772, 0.12607597309397534, 0.0972860906040296, 0.25101738050580025, 0.17653204064117745, 0.1451146139879711, 0.13270960072986782, 0.11827856884337962, 0.23070530325639993, 0.2097626231261529, 0.09985098266042769, 0.079499415733153, 0.16730337491026148, 0.12078099432983436, 0.11563451931579039, 0.09411025515873916, 0.13156704953871667, 0.11113543456303887, 0.21310780924977735, 0.1428944495273754, 0.0929898422327824, 0.19292679528007284, 0.07970860489876941, 0.12515003996668383], [0.0979129085317254, 0.04481113646761514, 0.03980395144026261, 0.03525134299707133, 0.047892837901599705, 0.045647674196516164, 0.07797932659741491, 0.00662743534121546, 0.04320017877034843, 0.01699676813586848, 0.020295000431360677, 0.06939255923498422, 0.011728764584404416, 0.0657650972425472, 0.059427274827612564, 0.044490565778687596, 0.0452398417837685, 0.018919310969067737, 0.0740752142155543, 0.04979554869350977, 0.06966530592762865, 0.05005530780181289, 0.07145031209802255, 0.02497646612027893, 0.025583735878171865, 0.03642703108198475, 0.02721759068663232, 0.024288341228384525, 0.059752658344223164, 0.08019275977858342, 0.039748038034304045, 0.0313503773213597, 0.0402100954670459, 0.03562640216841828, 0.023578868458571378, 0.014539124767907197, 0.059955379692837596, 0.07379154310910963, 0.06319547770544887, 0.05852887166838627, 0.05536408680200111, 0.061069536313880235, 0.019351252049091272, 0.01928812311234651, 0.03254015507991426, 0.05930327308306005, 0.2040389130706899, 1.2934745801612735, 7.023407751694322, 24.301481992006302, 51.47147946059704, 70.04398986697197, 71.6236563026905, 70.6282389163971, 67.31739297509193, 53.386838883161545, 62.79612198472023, 45.35262979567051, 26.756292767822742, 30.886034667491913, 17.993757762014866, 25.00634226948023, 35.36253646016121, 43.241151496768, 56.78018219769001, 60.932523384690285, 57.579017132520676, 62.29048311710358, 75.2336297929287, 42.82001629471779, 48.537466898560524, 50.21364435553551, 40.13824939727783, 29.75705824792385, 33.57944034039974, 24.531789533793926, 16.13837242126465, 14.161323308944702, 10.539375711232424, 5.9828948602080345, 1.6509098815731704, 1.1313046258874238, 0.7057818467728794, 0.3392155165784061, 0.08954209130024537, 0.07270318354130723, 0.05403311544796452, 0.06017114057613071, 0.3246706095524132, 0.9285344439558685, 1.6395931388251483, 2.398847616277635, 4.929564781486988, 11.291949078440666, 24.79319840669632, 39.61224362254143, 50.53995944559574, 45.97073122859001, 54.527621269226074, 66.88754484057426, 72.04785794019699, 80.4452933371067, 65.01053676009178, 55.103890746831894, 77.48721286654472, 44.568313881754875, 23.235964067280293, 20.803993865847588, 27.040426321327686, 27.214945256710052, 25.859354697167873, 36.822706907987595, 41.53212480247021, 51.6986882686615, 53.36214780807495, 64.52731668949127, 64.23147216439247, 72.56599053740501, 78.14993530511856, 57.39431284368038, 46.843396201729774, 21.837428212165833, 4.838490793481469, 0.7674656587187201, 0.08756135110161267, 0.03878001771226991, 0.020852180787187535, 0.01617641479242593, 0.05070464620075654, 0.054303984506987035, 0.02218145818915218, 0.08718180935829878, 0.015455958236998413, 0.045411975515889935, 0.035129975876770914, 0.012008430876448983, 0.015951826062519103, 0.04950061920681037, 0.061715713163721375, 0.05458757768792566, 0.040769530096440576, 0.040661885286681354, 0.025282084388891235, 0.02730614745814819, 0.042590215016389266, 0.05040336764068343, 0.06969917012611404, 0.013049832905380754, 0.05699537563486956, 0.05782072548754513, 0.05714732666092459, 0.030818192499282304, 0.07719846107647754, 0.06863383940071799, 0.014518705502268858, 0.004063941769345547, 0.05858850694494322, 0.044659189152298495, 0.012853416101279436, 0.037036100547993556, 0.05750010284828022, 0.01573272551468108, 0.043598277916316874, 0.05707148287910968, 0.01904933338664705, 0.00871868967806222, 0.006848741459180019, 0.025104427222686354, 0.02200120907218661, 0.026964714998030104, 0.01764160540915327, 0.01662267004576279, 0.058144309296039864, 0.0857706081296783, 0.042324745081714354, 0.016001230833353475, 0.0278393249027431, 0.10932544770184904, 0.04442793593625538, 0.022381160852091853, 0.009660537234594813, 0.07012625384959392, 0.10241245341603644, 0.005641372945319745, 0.015667000916437246, 0.012721577277261531, 0.05954840074991807, 0.042154834081884474, 0.025241715266020037, 0.060001133097102866, 0.03746351823792793, 0.037247542131808586, 0.03484506167296786, 0.0188431851711357, 0.03965427880757488, 0.03400025270821061, 0.13111068808939308, 0.031199461591313593, 0.020143253495916724, 0.04868321033427492, 0.022168789728311822, 0.024727633281145245, 0.04228730373142753, 0.013186855630920036, 0.04919655388221145, 0.07221695806947537, 0.05802523541206028, 0.03967199387261644, 0.06162179066450335, 0.03871469016303308, 0.020187823174637742, 0.038970107707427815, 0.025553207633493003, 0.06049679868738167, 0.05299581192957703, 0.023605021742696408, 0.0444481817248743, 0.03830591151199769, 0.007713094419159461, 0.05112911756441463, 0.09553044379572384, 0.01766325942298863, 0.19773506617639214, 1.1158902780152857, 8.97518489509821, 29.076670557260513, 59.51233059167862, 78.06454628705978, 81.22634142637253, 80.51311209797859, 76.6882373392582, 63.81043195724487, 73.22774022817612, 58.87803062796593, 40.711729824543, 45.47763168811798, 33.62113930284977, 35.175894275307655, 43.139062374830246, 44.216817542910576, 51.59286394715309, 48.74023161828518, 60.02391993999481, 52.43462137877941, 55.983475148677826, 47.15125188231468, 54.533385559916496, 48.749001547694206, 39.993100985884666, 33.78754377365112, 32.11779557168484, 26.348187066614628, 19.397427141666412, 15.480277184396982, 9.487491454929113, 5.294875279068947, 1.4659149083308876, 1.0009874124079943, 0.6053755595348775, 0.37689815391786397, 0.10020011861342937, 0.17583280394319445, 0.028671986765402835, 0.12268253252841532, 0.40597333281766623, 0.7265823462512344, 1.6995131922885776, 2.7177911018952727, 4.594048960134387, 9.873525090515614, 17.613582462072372, 22.7864158898592, 30.956146605312824, 30.172149874269962, 42.87320204079151, 57.430631294846535, 61.6972741484642, 57.83871419727802, 46.22412443161011, 37.00712241232395, 62.39865571260452, 44.133191630244255, 20.546496883034706, 29.341645538806915, 36.57063603401184, 39.46870632469654, 33.14110346138477, 49.4563639909029, 51.841024830937386, 67.51574233174324, 65.67477151751518, 72.67938405275345, 74.33810904622078, 82.79946461319923, 86.82984754443169, 64.75199863314629, 54.43864904344082, 28.52612379938364, 6.4905210211873055, 0.8756855735555291, 0.1022701985493768, 0.0336740083002951, 0.07628651743289083, 0.05421891211881302, 0.04612684926541988, 0.045336202238104306, 0.04117634947760962, 0.03961369817261584, 0.03522721948684193, 0.05724294125684537, 0.033885820957948454, 0.04611991760612, 0.046355052254511975, 0.05940620154433418, 0.0694676126295235, 0.06002245128911454, 0.05058288203144912, 0.07290024601388723, 0.015816608611203264, 0.02398714244918665, 0.014620471574744442, 0.05276988733385224, 0.03634358770796098, 0.08339623280335218, 0.07618169649504125, 0.03895142785040662, 0.00630969826488581, 0.060581381258089095, 0.03805322507105302, 0.0731344529776834, 0.05192750148125924, 0.046685979614267126, 0.025223154152627103, 0.05108996185299475, 0.03273166628787294, 0.0403218183782883, 0.03307066079287324, 0.055810830017435364, 0.0452645404584473, 0.03210482238500845, 0.00988240599326673, 0.044762908000848256, 0.07895024871686473, 0.009046114100783598, 0.03363459283718839, 0.020883059696643613, 0.08920989857870154, 0.04676743774325587, 0.024855381016095635, 0.013011250503041083, 0.032457182969665155, 0.0348812153970357, 0.18376192456344143, 0.2070888876914978, 0.14536927454173565, 0.1306229189503938, 0.1284284921712242, 0.14142000989522785, 0.17317704332526773, 0.16566716192755848, 0.14754672098206356, 0.08186682971427217, 0.14136277546640486, 0.15289108967408538, 0.1289707052637823, 0.15190226695267484, 0.09991905244532973, 0.10726793232606724, 0.17803432565415278, 0.16203408187720925, 0.1447955350158736, 0.10861882663448341, 0.2433008555090055, 0.11808999654022045, 0.10333814905607142, 0.09987850149627775, 0.1623558474238962, 0.08572668783017434, 0.1351326535223052, 0.07469959047739394, 0.1488423623959534, 0.11883007362484932, 0.09639418494771235, 0.11199964326806366, 0.12584964773850515, 0.12011928803985938, 0.07824322688975371, 0.17782005277695134, 0.11071382046793588, 0.09536456636851653, 0.21469083992997184, 0.10359230494941585, 0.16916865919483826, 0.12774872942827642, 0.11032277543563396, 0.1647476409561932, 0.20598179631633684, 0.16550430504139513, 0.4438587842741981, 2.3800452752038836, 13.601596243679523, 40.37156827747822, 72.73921564221382, 89.33530390262604, 92.20093533396721, 92.27140635251999, 88.59327211976051, 72.42827832698822, 83.03327366709709, 65.04252344369888, 41.99609890580177, 45.09488582611084, 27.979912608861923, 39.188953936100006, 52.71948829293251, 61.014287397265434, 76.37253507971764, 82.47031107544899, 77.92510136961937, 81.77227333188057, 97.16415300965309, 60.40954224765301, 69.86422911286354, 68.73882070183754, 54.67679746448994, 40.87276138365269, 45.2131050825119, 34.805539548397064, 24.378652051091194, 21.231945902109146, 15.13927398249507, 8.812491875141859, 2.6770439883694053, 2.239693868905306, 1.6149501549080014, 0.8642668894026428, 0.2555197529727593, 0.3333526389906183, 0.19701779528986663, 0.2348968939622864, 0.6787857203744352, 1.6535266349092126, 2.706512832082808, 3.4544965205714107, 7.006312943994999, 15.416575502604246, 32.7850853651762, 50.10444201529026, 64.44109931588173, 56.66130177676678, 69.23574283719063, 81.83413401246071, 90.03636628389359, 97.2126992046833, 83.3045107126236, 74.56277579069138, 98.31425249576569, 59.04881626367569, 36.28345884382725, 32.720595225691795, 40.66260986030102, 43.307666927576065, 38.67904789745808, 55.91065965592861, 62.000828459858894, 73.35323229432106, 71.63665160536766, 86.99857369065285, 83.52195024490356, 92.12059244513512, 97.96187460422516, 77.35789060592651, 66.75007581710815, 38.74828018248081, 10.381429586559534, 1.66064175311476, 0.21218241046881303, 0.07163544825743884, 0.2071003316086717, 0.11629140164586715, 0.13917968870373443, 0.16815487062558532, 0.18125720584066585, 0.15519352862611413, 0.10216725524514914, 0.09206221700878814, 0.21637928526615724, 0.136418825131841, 0.20883964374661446, 0.16833924979437143, 0.15748971869470552, 0.196550598484464, 0.1966117662959732, 0.24512820120435208, 0.08755070870392956, 0.1806600738200359, 0.15596151788486168, 0.10214200738118961, 0.23320994776440784, 0.14933692960767075, 0.19642722385469824, 0.1911483274307102, 0.16288534010527655, 0.12957289873156697, 0.12171237482107244, 0.21757253998657688, 0.09908400272252038, 0.17226893658516929, 0.07236408142489381, 0.12965085392352194, 0.1798220703494735, 0.0856488588033244, 0.13013060786761343, 0.20030200656037778, 0.1869153990992345, 0.11423023490351625, 0.1266845193458721, 0.13356127456063405, 0.19001398439286277, 0.08666488123708405, 0.10277314460836351, 0.11535904151969589, 0.11290861089946702, 0.18133571022190154, 0.10874005645746365, 0.17304828070336953, 0.1369727196288295, 0.11312396731227636], [0.020379757406772114, 0.01712823774141725, 0.061073324977769516, 0.02393604187091114, 0.020574398622557055, 0.030137544745230116, 0.05164629430510104, 0.035386736708460376, 0.02010502361372346, 0.023566058989672456, 0.025117511286225636, 0.018719023864832707, 0.04640105056751054, 0.020282951663830318, 0.01434339166735299, 0.06077477381040808, 0.022169112562551163, 0.05416969288489781, 0.06097589212004095, 0.061708024513791315, 0.0066730955131788505, 0.04712701942480635, 0.0260100997184054, 0.030265494715422392, 0.03173234588757623, 0.0467211314389715, 0.03089186364377383, 0.061404044536175206, 0.024500526815245394, 0.00910421220396529, 0.05914838686294388, 0.03181815300195012, 0.06015899904014077, 0.06668145666480996, 0.05808767229609657, 0.03978864464443177, 0.0970070059702266, 0.033855674919323064, 0.01464118306103046, 0.056701084395172074, 0.031487103187828325, 0.06005728027957957, 0.03593493522203062, 0.05961181355814915, 0.10148777451831847, 0.9560032293666154, 5.703321537002921, 24.395226761698723, 45.35100728273392, 64.04838278889656, 70.11560082435608, 62.07255341112614, 61.797949746251106, 60.02357795834541, 41.78760789334774, 31.46730087697506, 37.11116082966328, 19.10813346505165, 16.923292502760887, 21.86046827584505, 36.98886439204216, 46.80158704519272, 47.22009278833866, 62.00483724474907, 55.61820834875107, 63.33551064133644, 49.14125069975853, 58.474583476781845, 44.25021015107632, 38.545420467853546, 22.77138389647007, 15.068464782088995, 11.42601728439331, 3.990481747314334, 3.180826180614531, 1.0289074829779565, 0.9752756170928478, 0.4005407227668911, 0.050244470112374984, 0.026663397475203965, 0.2194348705234006, 0.0366402835061308, 0.05687161879905034, 0.03458285718807019, 0.10664435758371837, 0.07947858364786953, 0.20176329533569515, 0.10509428568184376, 0.07058997740386985, 0.04088418078026734, 0.02037171994743403, 0.02103935599734541, 0.13985878351377323, 0.05213679825828876, 0.19634391035651788, 0.7705788791645318, 1.1124695115722716, 3.6448741424828768, 5.102145345881581, 12.669475860893726, 26.216419637203217, 36.567474603652954, 59.09794382750988, 68.61459016799927, 62.84747622907162, 57.522084787487984, 65.44061288237572, 50.69532170891762, 38.28928381204605, 27.7655129134655, 33.179941177368164, 21.28236349672079, 21.80370882153511, 16.460959911346436, 37.59193763136864, 47.5150253623724, 54.30041626095772, 68.21042105555534, 66.83624759316444, 71.78144663572311, 79.02134254574776, 72.48328417539597, 43.35403583943844, 18.156161047518253, 7.165070325136185, 1.532029698137194, 0.05644161472446285, 0.027062040244345553, 0.03879300900734961, 0.05828223002026789, 0.038663545055896975, 0.108771983650513, 0.01713861111056758, 0.07199874438811094, 0.04700572280853521, 0.01936652544827666, 0.06362872125464492, 0.03160129374009557, 0.04593986886902712, 0.049710929015418515, 0.055660830839769915, 0.02479538208717713, 0.06761740878573619, 0.0808814876654651, 0.015402641420223517, 0.03637689529568888, 0.03648756064649206, 0.033950532524613664, 0.0241913870559074, 0.019737736583920196, 0.05592903929937165, 0.04301775887142867, 0.034128981933463365, 0.09205551541526802, 0.032181846181629226, 0.05097744113299996, 0.020116803352721035, 0.010713063129514921, 0.07611660272232257, 0.03019934709300287, 0.020938169727742206, 0.056529165885876864, 0.013333106035133824, 0.08718486700672656, 0.047560441089444794, 0.02560080713010393, 0.03151537530357018, 0.010863309071282856, 0.06509270402602851, 0.006032401743141236, 0.06259476111154072, 0.020761028354172595, 0.040009374206420034, 0.028143701929366216, 0.012143259627919178, 0.056283058584085666, 0.06295842089457437, 0.02162216456781607, 0.017090727742470335, 0.00990280484984396, 0.0183703369111754, 0.01595787085534539, 0.025758875308383722, 0.025549491329002194, 0.06641681422479451, 0.04991347224859055, 0.04112576840270776, 0.00149005604271224, 0.04561371722957119, 0.03821658290689811, 0.01876869395346148, 0.027961248633801006, 0.051904691572417505, 0.04415541188791394, 0.02134796326572541, 0.0075489030587050365, 0.025777241608011536, 0.03740862899576314, 0.010903820129897213, 0.019453523709671572, 0.03778956597670913, 0.033292273510596715, 0.07507876856834628, 0.03856548879412003, 0.02309177096321946, 0.02225685111625353, 0.0661280816711951, 0.038236750770010985, 0.07990129612153396, 0.03555998737283517, 0.03494886957923882, 0.048053108403109945, 0.013402687945927028, 0.1149643822282087, 0.05510037204658147, 0.0653052625420969, 0.039492483192589134, 0.03551418201823253, 0.03447893053817097, 0.07730896686553024, 0.07049834443023428, 0.8245366369374096, 6.876704273745418, 28.76423992216587, 54.21792648732662, 72.98226580023766, 79.32395070791245, 76.03246852755547, 75.43751925230026, 70.84128588438034, 56.47757403552532, 42.31429003179073, 55.088721960783005, 35.506723523139954, 31.262429170310497, 27.362835220992565, 25.963079631328583, 41.52811221778393, 41.87282972037792, 48.99296745657921, 54.20316807925701, 56.38341888785362, 50.97129710018635, 55.50200678408146, 44.617912620306015, 38.00328455865383, 28.199981600046158, 18.324932791292667, 11.951246000826359, 5.547387404367328, 3.856104095466435, 1.5007884870283306, 0.9714787302073091, 0.39531318296212703, 0.22787788388086483, 0.11250626295804977, 0.18357468070462346, 0.058139537286479026, 0.04874757680227049, 0.05881586388568394, 0.24084753793431446, 0.0796147677465342, 0.06553890547365882, 0.02714611815463286, 0.14644151466200128, 0.04671966569731012, 0.08054916877881624, 0.02059847018244909, 0.06195291098265443, 0.11986620083916932, 0.30465420393738896, 0.5735714442562312, 0.733361835591495, 2.4740607803687453, 5.276943566277623, 10.095214694738388, 17.636128552258015, 32.89728194475174, 47.47351638972759, 60.537705570459366, 59.62562531232834, 46.99592761695385, 54.28272441029549, 38.63552123308182, 38.01120713353157, 29.23616509884596, 37.20421403646469, 34.622906148433685, 33.74299496412277, 25.728155337274075, 45.89058592915535, 61.817936673760414, 60.84753334522247, 79.94001165032387, 74.44812074303627, 82.90145874023438, 89.1765408217907, 82.44719311594963, 54.22306001186371, 23.96294105798006, 8.896218482404947, 1.7393555981107056, 0.06319322157651186, 0.0585434288950637, 0.02835239385603927, 0.0759579092846252, 0.0644448833190836, 0.1373401124146767, 0.04679575809859671, 0.0659732919302769, 0.04378821577120107, 0.04523836490989197, 0.028118066293245647, 0.02560274599090917, 0.04152895126026124, 0.02374875719397096, 0.07264088024385273, 0.042381790262879804, 0.021473087508638855, 0.032212634177994914, 0.02959190107503673, 0.030058019910939038, 0.055913194446475245, 0.03514973184792325, 0.05306770748575218, 0.04237086955981795, 0.058973262275685556, 0.03268581269367132, 0.02233629802503856, 0.06338454724755138, 0.007712957121839281, 0.02505244905478321, 0.018701832013903186, 0.024040003772825003, 0.0566127280035289, 0.04907413662294857, 0.04525920070591383, 0.018723382127063815, 0.03319010946142953, 0.034151083091273904, 0.0639303374919109, 0.018416949351376388, 0.02809880199492909, 0.04644107088097371, 0.002102774324157508, 0.013630065295728855, 0.17034258838975802, 0.03136417755740695, 0.02279620137414895, 0.05220773644396104, 0.008199537896871334, 0.04003949426987674, 0.14121381158474833, 0.07680646609514952, 0.12687072419794276, 0.11739455963834189, 0.2297396503854543, 0.175825159822125, 0.10001847796957009, 0.09466043891734444, 0.17009950533974916, 0.12735041877022013, 0.0824039887811523, 0.18555891641881317, 0.10999380363500677, 0.09730423611472361, 0.14794264192460105, 0.11515585632878356, 0.11153365616337396, 0.15106616338016465, 0.13181734626414254, 0.13962435390567407, 0.09999374218750745, 0.11270756309386343, 0.0736871971457731, 0.07818268248229288, 0.15557279577478766, 0.10381035535829142, 0.17912543116835877, 0.1293973214342259, 0.14250403532059863, 0.13800693210214376, 0.14960003580199555, 0.1594884114456363, 0.13920278433943167, 0.1444279938004911, 0.18333955347770825, 0.1547086241771467, 0.14450649818172678, 0.21550861245486885, 0.11559509643120691, 0.1103830971987918, 0.13332307484233752, 0.1439937631948851, 0.12349941447610036, 0.31541561242192984, 0.3296039323322475, 1.5495541202835739, 9.794478882104158, 37.269783318042755, 66.9600297510624, 83.37746679782867, 89.6221125125885, 81.60643503069878, 83.68073612451553, 81.62282735109329, 61.231274753808975, 46.90098971128464, 52.99220725893974, 34.5055266469717, 27.587091587483883, 34.52171377837658, 50.91232426464558, 62.82537281513214, 62.37416982650757, 79.31486919522285, 73.08626621961594, 81.10714182257652, 67.44036957621574, 76.51162281632423, 60.70652291178703, 52.22767688333988, 35.691253021359444, 22.96617664396763, 15.95186322927475, 7.526314090937376, 4.960453324019909, 2.1770848659798503, 1.659095473587513, 0.9636338730342686, 0.3891834884416312, 0.3392384044127539, 0.582320059183985, 0.21390235255239531, 0.14874436921672896, 0.2301906980574131, 0.3785686689661816, 0.2220862524700351, 0.3658482281025499, 0.39934280735906214, 0.3569760307436809, 0.23444470338290557, 0.25491769309155643, 0.3248683176934719, 0.30698383518029004, 0.5432575615122914, 0.5693428055383265, 1.0725374543108046, 1.4633388840593398, 5.828317729756236, 7.8551622200757265, 17.359778881072998, 33.054760694503784, 47.26554214954376, 72.9167877137661, 86.16380408406258, 77.03517392277718, 77.481619566679, 87.89391964673996, 67.33516082167625, 56.40163131058216, 43.45454804599285, 51.452636271715164, 35.34009486436844, 32.17236064374447, 28.166706785559654, 53.02154928445816, 66.37771099805832, 73.78046616911888, 88.04459676146507, 85.47702893614769, 92.8251126408577, 99.27731841802597, 95.10556027293205, 71.11129939556122, 34.617974013090134, 12.886200081557035, 2.8246138198301196, 0.10555715576629154, 0.15609419904649258, 0.12068565061781555, 0.21347854170016944, 0.08796813708613627, 0.26256300159730017, 0.13871033967006952, 0.1153427291137632, 0.17125645419582725, 0.2111694382620044, 0.2072499634232372, 0.0747334620973561, 0.17382836696924642, 0.19800828042207286, 0.1801987548242323, 0.16133578028529882, 0.21827838179888204, 0.15054916846565902, 0.1610892833559774, 0.09712232829770073, 0.17940974794328213, 0.12934033933561295, 0.09864658830338158, 0.1322917122161016, 0.17146943573607132, 0.13424044358544052, 0.0710171576065477, 0.21181372634600848, 0.08606227216660045, 0.07720636494923383, 0.1160601558513008, 0.12141627274104394, 0.20614603359717876, 0.17567993636475876, 0.19711068249307573, 0.12283479154575616, 0.10404830274637789, 0.21538418397540227, 0.21997129486408085, 0.1255992619553581, 0.08532640305929817, 0.15807490213774145, 0.09611736386432312, 0.0833323561528232, 0.27728733024559915, 0.16081066627521068, 0.10443608232890256, 0.19652471237350255, 0.13292198855197057, 0.21253678598441184], [0.04190539453702513, 0.012437891327863326, 0.0673395190096926, 0.038929987204028293, 0.034625894331838936, 0.0529771394940326, 0.05114037594466936, 0.06659282196778804, 0.041362216652487405, 0.05752022989327088, 0.009768989129952388, 0.04215597698930651, 0.036529295321088284, 0.048157261408050545, 0.021539843692153227, 0.026962390220433008, 0.04875048602116294, 0.04372794966911897, 0.05482246742758434, 0.07693333624047227, 0.03639747134002391, 0.01945110059750732, 0.03496469587844331, 0.04867939198447857, 0.058911934902425855, 0.05132279584358912, 0.03867792045639362, 0.06889558004331775, 0.035174571530660614, 0.021447533508762717, 0.03871067143336404, 0.05089880316518247, 0.04692799397162162, 0.05996822255838197, 0.02053026681096526, 0.03724429894646164, 0.031082506538950838, 0.04403020786412526, 0.022858877600810956, 0.06631352211115882, 0.028398496069712564, 0.04184857571090106, 0.06795862602302805, 0.3580328787211329, 4.583684066310525, 16.94737371057272, 46.786543652415276, 59.784623980522156, 76.66108399629593, 63.64807806909084, 58.10873530805111, 61.19970224797726, 43.05475249886513, 36.2498002499342, 25.864664912223816, 25.910059176385403, 9.824397526681423, 23.03194161504507, 47.84439168870449, 65.52993848919868, 105.06357192993164, 84.71917480230331, 74.0968219935894, 65.902538895607, 52.14363679289818, 39.04839567840099, 28.05038172751665, 18.478484451770782, 10.953550636768341, 5.508790500462055, 3.189347698353231, 1.3179559540003538, 0.04995469484128989, 0.11020651800208725, 0.15166719909757376, 0.1077823519881349, 0.18916370579972863, 0.053013100259704515, 0.07471147968317382, 0.03984554510680027, 0.05322139884810895, 0.06282662288867868, 0.10134736759937368, 0.09417972760275006, 0.05792516050860286, 0.016231250228884164, 0.0451802844327176, 0.050214439106639475, 0.06537304288940504, 0.08824371136142872, 0.09070747837540694, 0.1263289267080836, 0.025874999155348632, 0.008889602577255573, 0.1600644367863424, 0.05122634633153211, 0.29228978615719825, 0.03316692847874947, 0.13386209669988602, 0.7138685847166926, 3.518823981285095, 3.28114649746567, 6.140100499615073, 7.5257897190749645, 16.558491177856922, 32.59832538664341, 45.92831790447235, 60.1895796507597, 51.67636066675186, 54.35269005596638, 35.04142329096794, 25.995750278234482, 20.521608218550682, 33.98596912622452, 16.76558766514063, 20.471272319555283, 43.845030292868614, 46.55149586498737, 49.26212601363659, 56.13165199756622, 67.59964942932129, 62.528365552425385, 79.8331005871296, 67.8689181804657, 48.89978125691414, 21.514329649508, 7.589763086289167, 0.757503246422857, 0.06163794721942395, 0.04480102099478245, 0.022873807756695896, 0.022422222027671523, 0.003635584798757918, 0.020017687675135676, 0.03979976572736632, 0.07878641219576821, 0.010836793062480865, 0.027595123065111693, 0.022009903332218528, 0.047214206933858804, 0.02002696637646295, 0.01983774098334834, 0.04139306030992884, 0.0422661525226431, 0.0941348350897897, 0.016729554154153448, 0.02372551869484596, 0.04383746098028496, 0.036392424735822715, 0.03291640539828222, 0.04131827037781477, 0.02681383823073702, 0.02036710564425448, 0.02668503664608579, 0.057801941729849204, 0.06912087381351739, 0.01992606954445364, 0.06086784655053634, 0.018615227090776898, 0.05148295502294786, 0.05892267006856855, 0.03428523370530456, 0.033917095061042346, 0.033427800808567554, 0.025207231374224648, 0.10422155712149106, 0.02895880643336568, 0.010298945653630653, 0.048536569374846295, 0.06733638714649715, 0.05966659518890083, 0.021017325343564153, 0.06542753879330121, 0.05540125355764758, 0.014355524854181567, 0.02371457201661542, 0.05328798804839607, 0.009382725384057267, 0.014747312034160132, 0.040257348009618, 0.053024128574179485, 0.016385626222472638, 0.06194209046952892, 0.07912425266113132, 0.07120309528545476, 0.027803844677691814, 0.028023295890307054, 0.023363547297776677, 0.0551790656754747, 0.015684992431488354, 0.059370036688051187, 0.02760885650786804, 0.08873713566572405, 0.022744911548215896, 0.046144619991537184, 0.029250707957544364, 0.04103475141164381, 0.06428918073652312, 0.03934823937015608, 0.07971970742801204, 0.034089277032762766, 0.026245013577863574, 0.030013639479875565, 0.03806218650424853, 0.05393367508077063, 0.0351558953843778, 0.028822379281336907, 0.033467717221356, 0.013940018634457374, 0.031635061459382996, 0.053462055075215176, 0.05572628084337339, 0.020710100325231906, 0.042123003368033096, 0.036382658072398044, 0.05365593002352398, 0.03413949816604145, 0.02473925160302315, 0.014488758915831568, 0.35806784871965647, 5.306939631700516, 22.78778001666069, 53.743043169379234, 70.02228543162346, 86.06218233704567, 71.84560239315033, 65.81141218543053, 67.41437897086143, 51.35204426944256, 52.10453309118748, 42.20182366669178, 35.59449501335621, 20.23005746304989, 32.505017593503, 42.40434139966965, 61.57948046922684, 73.21307301521301, 68.91529843211174, 58.45279164612293, 58.40155519545078, 48.93813259899616, 40.34712418913841, 30.08482675999403, 20.492771565914154, 13.232809882611036, 8.108592946082354, 4.459915207698941, 1.7254288704134524, 0.22051549691241235, 0.17211700411280617, 0.0696857892035041, 0.17672409361694008, 0.23915584199130535, 0.036680786215583794, 0.06618720115511678, 0.020738385428558104, 0.014922082245902857, 0.05793145021016244, 0.10126904133358039, 0.16070486570242792, 0.3799563070060685, 0.2738024719292298, 0.05884812133444939, 0.2038875743164681, 0.05090500751975924, 0.034818960339180194, 0.026952412044920493, 0.04894999758107588, 0.038334421114996076, 0.03190673203789629, 0.0563120431615971, 0.050732651143334806, 0.08452756272163242, 0.004223680243740091, 0.1302030563238077, 0.7411305780988187, 2.5512227648869157, 2.285537221468985, 5.42296783067286, 8.038177024573088, 16.127307415008545, 30.54240580648184, 39.55123409628868, 48.486120253801346, 47.250221371650696, 47.58620694279671, 39.07154023647308, 26.373011134564877, 25.089022032916546, 42.36796975135803, 31.16954505443573, 29.559028074145317, 52.91520059108734, 55.85227958858013, 61.27274192869663, 65.34809544682503, 78.12551781535149, 72.26142928004265, 87.31297641992569, 79.33524370193481, 59.68860313296318, 26.8155524879694, 8.503109626471996, 0.7203646330162883, 0.021325264679035172, 0.04282956135284621, 0.023586096976941917, 0.04414437986270059, 0.12105485424399376, 0.02141398101230152, 0.0357788875408005, 0.019134743452013936, 0.0297235265315976, 0.043264804990030825, 0.037695209321100265, 0.0669141644902993, 0.03463055872998666, 0.07163618298363872, 0.026099879178218544, 0.020077267290616874, 0.008612714700575452, 0.015682736302551348, 0.051378367861616425, 0.037242721882648766, 0.01448578846975579, 0.020401125693751965, 0.03612506603531074, 0.07123586852685548, 0.058673193416325375, 0.03183350432664156, 0.09755715262144804, 0.05730398290324956, 0.047789716481929645, 0.05770838288299274, 0.035664058741531335, 0.031463565974263474, 0.03201863306458108, 0.0280052041853196, 0.05708712735213339, 0.02869683758035535, 0.0507893326721387, 0.009669086775829783, 0.06249592930544168, 0.0341251672944054, 0.06882727277115919, 0.05295543909596745, 0.012720193171844585, 0.022011285582266282, 0.05649278209602926, 0.02859279775293544, 0.0455559299007291, 0.018582537340989802, 0.08550477083190344, 0.15628942841431126, 0.1634294234099798, 0.1184030863805674, 0.10302692942786962, 0.1418740113149397, 0.16398450534325093, 0.19939097575843334, 0.12038340355502442, 0.12914987455587834, 0.08210161555325612, 0.15585712739266455, 0.2022237831261009, 0.10467210755450651, 0.14153228199575096, 0.14268706378061324, 0.2401595373521559, 0.1402738518663682, 0.27567900717258453, 0.19074042822467163, 0.10969858471071348, 0.12426257235347293, 0.1173853050568141, 0.15501115325605497, 0.15523882932029665, 0.13322687766049057, 0.13123453769367188, 0.15095629583811387, 0.13387757790042087, 0.15205816249363124, 0.20898837014101446, 0.12871654937043786, 0.13455281354254112, 0.2998360031051561, 0.1740513081313111, 0.11925507933483459, 0.08837974703055806, 0.17670683126198128, 0.09021891513839364, 0.20433281839359552, 0.14340057939989492, 0.10408879432361573, 0.16877732472494245, 0.8435125218238682, 8.492825478315353, 30.606037192046642, 65.72866782546043, 81.09945103526115, 96.53439000248909, 81.74644991755486, 77.52370610833168, 76.15788459777832, 61.86621308326721, 54.446731209754944, 38.59088122844696, 38.172603473067284, 17.48273268342018, 34.66060012578964, 59.60145480930805, 80.57278409600258, 122.04053655266762, 104.69499930739403, 92.56829962134361, 85.07710039615631, 68.39448317885399, 54.692232236266136, 39.07385811209679, 25.889205895364285, 16.836337968707085, 9.834219049662352, 5.867068050429225, 2.6038010185584426, 0.5273096985183656, 0.5730572249740362, 0.3858940227655694, 0.6631807296071202, 0.29539540701080114, 0.33867066144011915, 0.3857297112699598, 0.20341261464636773, 0.11140389164211228, 0.2910306880949065, 0.2861109020886943, 0.41590225941035897, 0.41561466234270483, 0.5232925422023982, 0.1867878090706654, 0.38684459519572556, 0.15396923728985712, 0.3075560904107988, 0.24685841461177915, 0.5264124122913927, 0.06865879040560685, 0.15527568437391892, 0.32526141847483814, 0.2736988681135699, 0.36001025699079037, 0.1532712473999709, 0.6038232240825891, 1.4941183011978865, 4.793849838897586, 4.642128255218267, 8.27558258548379, 10.424239039421082, 23.65939624607563, 41.97569020092487, 57.98862375319004, 78.03312197327614, 69.55971345305443, 75.02789363265038, 52.315968945622444, 38.649006709456444, 32.36762836575508, 50.0252390652895, 27.740588150918484, 35.42369797825813, 60.9760956466198, 65.30577331781387, 69.87141072750092, 75.1907604932785, 85.93447118997574, 80.32515898346901, 98.42204511165619, 95.13473510742188, 72.63944819569588, 35.043243393301964, 12.611291483044624, 1.500397464260459, 0.4182644560933113, 0.17661173245869577, 0.13842496904544532, 0.15652192843845114, 0.2909231063676998, 0.08684996544616297, 0.1744925742968917, 0.21690744208171964, 0.14150304137729108, 0.16414733254350722, 0.08147820408339612, 0.14651558100013062, 0.08499368341290392, 0.16696746402885765, 0.07890243956353515, 0.11740569185349159, 0.24955508240964264, 0.11037082207622007, 0.08288884127978235, 0.16224888910073787, 0.1391625005635433, 0.12167123015387915, 0.11162607581354678, 0.17865394474938512, 0.21150490385480225, 0.1463789664558135, 0.1928101445082575, 0.16432709555374458, 0.14568045706255361, 0.1900156171177514, 0.1476932060904801, 0.12749449932016432, 0.19080885424045846, 0.13586230343207717, 0.18512746144551784, 0.1302175727323629, 0.14708651520777494, 0.20061225397512317, 0.0692309120495338, 0.07651719177374616, 0.15459984017070383, 0.14270765095716342, 0.10056780083687045, 0.07024300852208398, 0.24063255259534344, 0.15269664698280394, 0.19837098283460364, 0.096232344803866], [0.03211916809959803, 0.032862688749446534, 0.02138249354175059, 0.06489359322586097, 0.005427482738014078, 0.02988107891724212, 0.03138634921924677, 0.01903329000924714, 0.05110884580062702, 0.03178751343511976, 0.08130122412694618, 0.02587016591860447, 0.0128370684433321, 0.013099022453388898, 0.05196024874749128, 0.0809696844953578, 0.036013402495882474, 0.0039483601540268864, 0.022739497580914758, 0.019976350049546454, 0.010627788506099023, 0.042342107626609504, 0.10716244345530868, 0.034454124252079055, 0.013393727440416114, 0.07796706631779671, 0.07133852981496602, 0.024954244363470934, 0.08509301987942308, 0.007029992939351359, 0.05128314660396427, 0.013911929272580892, 0.03918760521628428, 0.020483684056671336, 0.015843615365156438, 0.046070913595031016, 0.05712344063795172, 0.02711217603064142, 0.03110113259026548, 0.014981582080508815, 0.0990907711093314, 0.2921605040319264, 3.051992431282997, 18.954642601311207, 35.77503092586994, 58.885223641991615, 62.55549229681492, 68.72667655348778, 62.60883003473282, 54.76567469537258, 63.20793628692627, 92.66633436083794, 96.75141915678978, 13.986258152872324, 18.987421542406082, 22.332116067409515, 42.91758745908737, 54.72789332270622, 73.12223508954048, 60.700435638427734, 54.29743342101574, 41.98745436966419, 29.47742935270071, 19.94087778031826, 11.563791241496801, 6.5318371541798115, 3.2720400486141443, 1.7009471403434873, 0.7504309946671128, 0.32605061831418425, 0.0898251538455952, 0.11250973620917648, 0.07720482870354317, 0.18332410196308047, 0.6259795976802707, 0.2612319152103737, 0.022167012284626253, 0.06278204207774252, 0.04543054034002125, 0.046334672879311256, 0.33078641106840223, 0.07466295806807466, 0.1360727022984065, 0.11300141646643169, 0.29202026780694723, 0.3847749828128144, 0.024935996807471383, 0.03851120811305009, 0.02464320099534234, 0.016149602852237877, 0.15880232560448349, 0.06389607995515689, 0.136230215721298, 0.009801700216485187, 0.1233490182494279, 0.09512569871731102, 0.17193663254147395, 0.15484415518585593, 0.053295736070140265, 0.014414156376005849, 0.03001549299369799, 0.1326048094779253, 0.22116646432550624, 0.9192945272661746, 1.5863118041306734, 2.3307980177924037, 7.834929255768657, 14.853434320539236, 31.235211230814457, 34.98388297855854, 46.65029816329479, 54.44768115878105, 47.581472396850586, 14.536878056824207, 20.54713524878025, 26.481856293976307, 21.57000996172428, 28.643505200743675, 21.664890870451927, 49.84094895422459, 40.91094933450222, 53.566816225647926, 67.93780848383904, 68.7079131603241, 70.59252083301544, 61.41702018678188, 45.02858318388462, 13.178842328488827, 2.139054606668651, 0.14002829004311934, 0.13553758413763717, 0.02014621095440816, 0.0683211800060235, 0.048591480881441385, 0.014629144498030655, 0.05572155707341153, 0.02506626413378399, 0.022717231295246165, 0.002329199869564036, 0.029418895319395233, 0.10341747722122818, 0.062132488455972634, 0.01979810287593864, 0.009291648093494587, 0.0572739630297292, 0.03505697080981918, 0.021303978028299753, 0.05802619278256316, 0.04685452506237198, 0.02341981507925084, 0.04684173414716497, 0.056242181090055965, 0.020538261596811935, 0.006055721878510667, 0.05957226450846065, 0.026285314052074682, 0.025740139790286776, 0.03758406899578404, 0.07418658831738867, 0.014501383775495924, 0.08460224504233338, 0.03949585625377949, 0.0401357545342762, 0.0404898220585892, 0.024472714831063058, 0.031575133034493774, 0.013369266252993839, 0.058506863279035315, 0.03995881910668686, 0.03574304922949523, 0.06417736876755953, 0.005297767847878276, 0.1164121861802414, 0.041125645948341116, 0.0032294771835950087, 0.026660311996238306, 0.026207113951386418, 0.03385534466360696, 0.046985209846752696, 0.03767213594983332, 0.03272436355473474, 0.014985711204644758, 0.021119763987371698, 0.04290067023248412, 0.03535786716383882, 0.02887412738346029, 0.07962011120980605, 0.018427973955112975, 0.04246080672601238, 0.02683857030206127, 0.040063907217700034, 0.06481234289822169, 0.03276132250903174, 0.0417931484116707, 0.056649594189366326, 0.02693141854251735, 0.05019152529712301, 0.042712283466244116, 0.03508499059535097, 0.02995795242895838, 0.019222149894631002, 0.04629297531209886, 0.014750904956599697, 0.0051879485454264795, 0.06771803658921272, 0.044541336101247, 0.062899323675083, 0.008206169914046768, 0.06582904068636708, 0.02461710337229306, 0.03424942507990636, 0.012937170249642804, 0.10164105027797632, 0.03782563435379416, 0.0570842700835783, 0.03725704533280805, 0.12155978925875388, 0.31047768832650036, 3.8976358668878675, 21.647062227129936, 43.86735409498215, 68.69665056467056, 72.3788657784462, 76.54572978615761, 72.28494241833687, 64.67306166887283, 75.09062066674232, 96.07380911707878, 94.3899142742157, 23.50790597498417, 26.127903386950493, 30.843399055302143, 27.7063861861825, 39.16632615029812, 52.95326694846153, 54.870484471321106, 56.24601446092129, 43.713006377220154, 32.79136262834072, 22.50753555446863, 14.624474756419659, 7.95782558619976, 4.1827096324414015, 2.4141598446294665, 0.8866983326151967, 0.43993130908347666, 0.052852659064228646, 0.06921043619513512, 0.045684455035370775, 0.28022335551213473, 1.0151645704172552, 0.5116692034061998, 0.3387515852227807, 0.0753480197454337, 0.05609133957477752, 0.07080476978444494, 0.08407034038100392, 0.10863248215173371, 0.2582602668553591, 0.19812141341390088, 1.2727444362826645, 0.29146003536880016, 0.1960400157258846, 0.13901663885917515, 0.269607140799053, 0.05127483083924744, 0.28186160197947174, 0.2698035427602008, 0.12226994294906035, 0.08904628470190801, 0.1302721057436429, 0.08858132918248884, 0.07467722956789657, 0.19552943296730518, 0.1156514031754341, 0.05844814826559741, 0.042847350632655434, 0.2863664977485314, 0.16334426938556135, 0.796884570736438, 1.3454008125700057, 2.633064198307693, 7.221409901976585, 13.743194695562124, 27.97291338443756, 37.742584347724915, 40.4346638917923, 44.41982924938202, 42.722479328513145, 24.720829389989376, 23.064342476427555, 32.435709312558174, 35.80388277769089, 44.92227628827095, 37.05354452133179, 61.703836396336555, 53.552194610238075, 60.59658721089363, 77.89597973227501, 75.88489964604378, 78.95521849393845, 68.52502897381783, 51.94472126662731, 16.163633465766907, 2.6955789187923074, 0.08118435813230462, 0.12808136001694947, 0.09138924491708167, 0.025319412561657373, 0.052073934639338404, 0.05282752994389739, 0.10434331386932172, 0.028174029794172384, 0.06054721277905628, 0.0539898519491544, 0.08679184786160477, 0.03676139087474439, 0.04140612953051459, 0.05513670388609171, 0.028876199830847327, 0.09621141623938456, 0.04977676122507546, 0.06286894757067785, 0.030447114950220566, 0.011184290724486345, 0.02755230485490756, 0.04145694067119621, 0.04100743666640483, 0.055615526434849016, 0.08079433726379648, 0.04630382180039305, 0.0288328491296852, 0.03940191149013117, 0.056933513915282674, 0.032997655725921504, 0.009763731941347942, 0.018202683895651717, 0.05556396943575237, 0.034057980665238574, 0.03703539179696236, 0.05049710460298229, 0.06472075445344672, 0.009108094563998748, 0.09751589663210325, 0.00857708047988126, 0.045148309000069275, 0.052429271236178465, 0.0923547642014455, 0.03756777514354326, 0.01876815404102672, 0.07084762881277129, 0.026060458149004262, 0.09779675499885343, 0.116661792708328, 0.1327688983292319, 0.12488654785556719, 0.10799248368130066, 0.16448704322101548, 0.10012438986450434, 0.1275961587089114, 0.08145340150804259, 0.12881881732027978, 0.17182873911224306, 0.13754533109022304, 0.10036109044449404, 0.0866218440933153, 0.16240337456110865, 0.14791019522817805, 0.08598064334364608, 0.134698779147584, 0.16697996179573238, 0.15759887377498671, 0.094283806392923, 0.21021634252974764, 0.24656081339344382, 0.13836436526617035, 0.15337160060880706, 0.18826928426278755, 0.07231689567561261, 0.060066430960432626, 0.25167456711642444, 0.2050350682111457, 0.17196818866068497, 0.10641829197993502, 0.26213398086838424, 0.08874218226992525, 0.17023411608533934, 0.1252936603850685, 0.201148945488967, 0.241010483878199, 0.12974451296031475, 0.10013038641773164, 0.4097067512338981, 0.6980486086104065, 6.260020639747381, 28.737692646682262, 54.826228246092796, 81.63528308272362, 82.28175759315491, 85.9739662706852, 83.48285794258118, 75.13101249933243, 80.33074468374252, 104.14089784026146, 104.14146780967712, 24.0705493837595, 28.482933416962624, 34.919058457016945, 58.70652303099632, 72.07707837224007, 91.3400611281395, 78.70719820261002, 70.1650133728981, 54.59389351308346, 41.61174193024635, 26.79835081100464, 17.03171018511057, 10.489571783691645, 5.995560055598617, 3.4481674851849675, 1.669362522661686, 0.8528138883411884, 0.3652835130924359, 0.3042109636589885, 0.3100528533104807, 0.3636929125059396, 1.5180263807997108, 0.9553464583586901, 0.6385018257424235, 0.2196577374706976, 0.3057307336712256, 0.22061948664486408, 0.6587315245997161, 0.24677355744643137, 0.4804711852921173, 0.3199678868986666, 1.7644361522980034, 0.9217422490473837, 0.34468793543055654, 0.2784326422261074, 0.5325506860390306, 0.14922930335160345, 0.31917794491164386, 0.2460531546967104, 0.30827564711216837, 0.2887664845911786, 0.25086411216761917, 0.23268642195034772, 0.28414329048246145, 0.44681713334284723, 0.20910310617182404, 0.09913553745718673, 0.14605423231841996, 0.5986874434165657, 0.5527404870372266, 1.930023548193276, 2.7862370666116476, 4.463041964918375, 11.95498215034604, 19.578493125736713, 41.99909694492817, 49.07226540148258, 65.27216032147408, 76.0885839164257, 67.05725133419037, 24.87933788448572, 33.27046371996403, 41.46779805421829, 34.030016362667084, 45.0374861061573, 37.84988299012184, 68.58822718262672, 57.61485680937767, 72.96577468514442, 85.98009914159775, 85.74670046567917, 90.8106355369091, 85.43222934007645, 62.53692649304867, 23.881517127156258, 4.75293505936861, 0.19696511764777824, 0.275969454087317, 0.2409287288901396, 0.21008550189435482, 0.15893689182121307, 0.11526178306667134, 0.2161444103694521, 0.14177914999891073, 0.16107570205349475, 0.17171012907056138, 0.14796996780205518, 0.27346262766513973, 0.0993054299033247, 0.13152391591574997, 0.11974629946053028, 0.22200960345799103, 0.14168626279570162, 0.23577538901008666, 0.1394115504808724, 0.13648664258653298, 0.0985563060385175, 0.11005077089066617, 0.21753417095169425, 0.2802422654349357, 0.15270522620994598, 0.14585763739887625, 0.1436517370166257, 0.17506172735011205, 0.1311969998641871, 0.12429428432369605, 0.09352018096251413, 0.1631116060889326, 0.14050660422071815, 0.1281487915548496, 0.1593098952434957, 0.15758978988742456, 0.06969806432607584, 0.1382563085644506, 0.17482700088294223, 0.20379755180329084, 0.06786280733649619, 0.13183719129301608, 0.21441186661832035, 0.16781104844994843, 0.09886321378871799, 0.11208937634364702, 0.10090799391036853], [0.05266278429189697, 0.02921665636677062, 0.03682661823404487, 0.027746467385441065, 0.03388851495401468, 0.07193920188001357, 0.018386179908702616, 0.06097402561863419, 0.04083616011484992, 0.044086091584176756, 0.06902558947331272, 0.023586690695083234, 0.035828540931106545, 0.1022987267060671, 0.021164194513403345, 0.12199019038234837, 0.03956161053793039, 0.04455847600183915, 0.02073124411253957, 0.027036039100494236, 0.06164842263387982, 0.01076060510968091, 0.1101019345514942, 0.07299409800907597, 0.039394631021423265, 0.04703297818196006, 0.019613647637015674, 0.018713698955252767, 0.04296854334825184, 0.046731502952752635, 0.026272680843248963, 0.06960943705053069, 0.10711012204410508, 0.028659188428719062, 0.08763574398471974, 0.037468230875674635, 0.08230740568251349, 0.04490486971917562, 0.06342694614431821, 0.21957019373076037, 3.759681419469416, 14.088730104267597, 39.78966370224953, 64.96886819601059, 69.84171912074089, 66.83410450816154, 60.342859625816345, 68.01894932985306, 52.514192909002304, 38.195782229304314, 16.52252610772848, 25.813417062163353, 48.50227318704128, 29.812455475330353, 44.576871022582054, 52.40182153880596, 68.96363943815231, 62.80379377305508, 45.97473241388798, 31.757920682430267, 18.194624483585358, 9.345751460641623, 4.601520784199238, 1.666657067835331, 0.6214941758662462, 0.07537874465924688, 0.16651677258778363, 0.04702624319179449, 0.023851726473367307, 0.013430433136818465, 0.04928853566525504, 0.04192284985037986, 0.06598114385269582, 0.7389664161019027, 0.5190824274905026, 0.10027643365901895, 0.04612097516655922, 0.043139341214555316, 0.13597162178484723, 0.1367287163157016, 0.2342219848651439, 0.07027803047094494, 0.15733471373096108, 0.22840394783997908, 1.095970084425062, 0.2792443142971024, 0.11224798814509995, 0.08387327790842392, 0.03813227122009266, 0.0466789255006006, 0.09602628007996827, 0.07300807264982723, 0.04368538749986328, 0.051319667691132054, 0.0393512005393859, 0.0726605174713768, 0.15630876878276467, 0.22681288712192327, 0.05146918447280768, 0.11946032027481124, 0.04114791037864052, 0.06496020840131678, 0.00942524209676776, 0.016488729088450782, 0.0597525396005949, 0.2622960659209639, 0.351802222430706, 1.4049002761021256, 4.257503869011998, 13.724712487310171, 25.65079528838396, 47.12869629263878, 63.26683312654495, 68.3902882039547, 54.811975210905075, 38.119018748402596, 29.178444296121597, 16.54671560972929, 28.494201712310314, 37.3226422816515, 52.827934473752975, 39.54918220639229, 61.083781868219376, 51.43070384860039, 64.15985360741615, 67.46543303132057, 68.92218366265297, 57.085549011826515, 34.95332881808281, 11.549595203250647, 1.6514197667129338, 0.048687165981391445, 0.10877111533773132, 0.04257634798705112, 0.06325317226583138, 0.013163744224584661, 0.062150723024387844, 0.05680202390067279, 0.07425437608617358, 0.04959954378136899, 0.07925328987766989, 0.058179000989184715, 0.015768194607517216, 0.0921193475369364, 0.0009969173493118433, 0.004415988332766574, 0.044346808062982745, 0.06096827768487856, 0.06687857850920409, 0.032499644948984496, 0.07699761365074664, 0.026410495811433066, 0.05540875667065848, 0.05171522498130798, 0.06157326162792742, 0.05042619981395546, 0.031156157274381258, 0.03276429109973833, 0.037363228111644275, 0.027487528350320645, 0.07602872501593083, 0.06604355847230181, 0.03838197051663883, 0.031855694542173296, 0.03272725793067366, 0.07291226138477214, 0.052873164604534395, 0.039816708958824165, 0.007095178552845027, 0.008652824071759824, 0.057296561426483095, 0.03380442220077384, 0.022719708213116974, 0.06775036454200745, 0.01672176531428704, 0.07915426511317492, 0.03312737571832258, 0.03448590672633145, 0.023363671607512515, 0.012906886913697235, 0.03810050729953218, 0.045571489026769996, 0.07380753639154136, 0.04670297850680072, 0.015929702640278265, 0.06927116613951512, 0.024286049847432878, 0.055813835715525784, 0.03298290554084815, 0.08055236743530259, 0.020734314748551697, 0.09315609815530479, 0.04438670592207927, 0.04604319066856988, 0.0025874730590658146, 0.006995849043960334, 0.031363932648673654, 0.025427398759347852, 0.08367880553123541, 0.032444328971905634, 0.060917986047570594, 0.03183003107551485, 0.05259877405478619, 0.038697294221492484, 0.07711335900239646, 0.013792352583550382, 0.025906011651386507, 0.032164483636734076, 0.04396424948936328, 0.05590372464212123, 0.07745833150693215, 0.04668396839406341, 0.006660717417616979, 0.06722956983139738, 0.07970617807586677, 0.24519785918528214, 4.148061191663146, 16.832215189933777, 47.440796345472336, 74.74923178553581, 78.02727028727531, 78.05849701166153, 66.00331708788872, 77.38949730992317, 64.56092208623886, 48.91039788722992, 28.213079497218132, 44.87851023674011, 64.64243531227112, 20.7004152238369, 33.04658733308315, 43.04744929075241, 57.5595697760582, 54.13337342441082, 42.250457257032394, 29.729414731264114, 18.022366426885128, 10.128793492913246, 4.748808005824685, 2.4597737845033407, 0.6510155042633414, 0.19997047435026616, 0.21833638806128874, 0.010859824687941, 0.03822614176897332, 0.050981801250600256, 0.23848676617490128, 0.049555961159057915, 0.30573610682040453, 0.76310028671287, 0.41795489145442843, 0.27710084337741137, 0.2310733194462955, 0.38081865292042494, 0.06234631975530647, 0.36955896648578346, 1.02036589756608, 0.3270820848410949, 0.13481304020388052, 0.4792903392808512, 1.2561723380349576, 1.9213522947393358, 0.5771258566528559, 0.0650793824752327, 0.1517369906650856, 0.23038726329104975, 0.45018728531431407, 0.3442165825981647, 0.14353597682202235, 0.19550445227650926, 0.07840200938517228, 0.21904184395680204, 0.22886065067723393, 0.06345408648485318, 0.2169711925671436, 0.3074413840658963, 0.02051523646514397, 0.10226123340544291, 0.03504433574562427, 0.015461537332157604, 0.03753076794964727, 0.21428742329590023, 0.21181408257689327, 1.4406556449830532, 4.085503248497844, 11.325280889868736, 24.782978855073452, 41.919704005122185, 49.0045340359211, 34.27166819572449, 37.03595146536827, 39.271797090768814, 30.574825666844845, 22.233794443309307, 26.257630325853825, 38.3568973839283, 54.34857487678528, 49.36947025358677, 72.30227708816528, 62.19033569097519, 74.19494792819023, 76.5070478618145, 78.15309673547745, 65.96914932131767, 42.59202092885971, 16.379883661866188, 3.6911549465730786, 0.07569923371192999, 0.07247503992402926, 0.08505401259753853, 0.02157977309252601, 0.04211344821669627, 0.032140957555384375, 0.003122634589090012, 0.02930581056716619, 0.05259580175334122, 0.09143488699919544, 0.05541174752579536, 0.042840637906920165, 0.06759762312867679, 0.015869547860347666, 0.05079159622255247, 0.05173556724912487, 0.05747691073338501, 0.014102522072789725, 0.014657946321676718, 0.06118226483522449, 0.02243778115371242, 0.08450316832750104, 0.04161441698670387, 0.08000198329682462, 0.042758289200719446, 0.0251737122744089, 0.026608430307533126, 0.03979011038609315, 0.017095883813453838, 0.0536309604649432, 0.023280699497263413, 0.04447927400178742, 0.045448652454069816, 0.0029853249770894763, 0.0030372344963325304, 0.023518745219917037, 0.010662377226253739, 0.008553432871849509, 0.005696853122572065, 0.09282307422836311, 0.022434617749240715, 0.034992303772014566, 0.011992490472039208, 0.06811337123508565, 0.061333777994150296, 0.1269352316739969, 0.14656575018307194, 0.11382445823983289, 0.19174740387825295, 0.2377805532887578, 0.14048524521058425, 0.10944176450720988, 0.17461988230934367, 0.16262227843981236, 0.12916244653752074, 0.13785045768599957, 0.11111049840110354, 0.10636175516992807, 0.31809084699489176, 0.15832166624022648, 0.286994562484324, 0.14147912937914953, 0.1833548565628007, 0.0850500124215614, 0.21523711999179795, 0.22385008516721427, 0.11174018844030797, 0.24132944410666823, 0.19369162298971787, 0.14201251091435552, 0.12634960294235498, 0.1603597225039266, 0.10231903186650015, 0.17283659050008282, 0.09620754222851247, 0.1832034732797183, 0.16000338771846145, 0.196969511162024, 0.18733115022769198, 0.15849592251470312, 0.20777908503077924, 0.14697250648168847, 0.1442050377954729, 0.13038660428719595, 0.5879381764680147, 7.328293891623616, 23.63369632512331, 59.9905501306057, 87.29773923754692, 88.6325392127037, 85.26425555348396, 77.58010268211365, 85.70082172751427, 72.52818256616592, 57.69524149596691, 27.48054340481758, 39.82285872101784, 59.397804737091064, 43.3937057107687, 61.54047556221485, 70.60655727982521, 89.75509017705917, 82.08207070827484, 61.95493832230568, 43.03556352853775, 25.43426390737295, 14.310471955686808, 7.291483366861939, 3.666339903138578, 1.4387612091377378, 0.5107721546664834, 0.6636431766673923, 0.2279070799704641, 0.2166200231295079, 0.10894129722146317, 0.2371645113453269, 0.2581473713507876, 0.7668415422085673, 1.447929642163217, 1.2005228991620243, 0.22444286820245907, 0.20896677364362404, 0.508455882081762, 0.5092538392636925, 0.4813663341337815, 1.0852684336714447, 1.0211282316595316, 0.4030270955991, 1.0127056273631752, 4.324148017913103, 3.8207949651405215, 0.8815044863149524, 0.3964277700288221, 0.501830818830058, 0.39216223172843456, 0.37762067920994014, 0.42117937467992306, 0.24081148440018296, 0.4703880404122174, 0.2756384859094396, 0.6405583466403186, 0.5548269907012582, 0.666080805240199, 0.15782821225002408, 0.3874400054337457, 0.5116010445635766, 0.24270274385344237, 0.09499185980530456, 0.13884057174436748, 0.17384757375111803, 0.7246055616997182, 0.7719571958296001, 2.8097649291157722, 6.050260495394468, 18.516294322907925, 34.08879540860653, 61.53330534696579, 80.15766397118568, 88.02282392978668, 72.7255667746067, 54.63691480457783, 42.79794327914715, 26.127871088683605, 41.988605707883835, 50.59048153460026, 68.66102367639542, 55.5525478720665, 78.47375392913818, 72.40612551569939, 84.37543004751205, 86.24539330601692, 90.412318110466, 80.53085714578629, 56.015135049819946, 22.843777611851692, 4.963118880987167, 0.19359069090569392, 0.18973216123413295, 0.20353033411083743, 0.160276067617815, 0.15584946842864156, 0.17785309319151565, 0.12465286039514467, 0.14471799542661756, 0.11960998177528381, 0.1567524395068176, 0.11145020165713504, 0.12944754998898134, 0.18615543987834826, 0.05699046632798854, 0.18859156931284815, 0.11591211223276332, 0.16859916475368664, 0.08888465235941112, 0.12352849924354814, 0.24218745587859303, 0.10873901745071635, 0.14332017512060702, 0.10356985498219728, 0.23798189795343205, 0.10180736557231285, 0.1632515009259805, 0.092030156229157, 0.11128896265290678, 0.1382152084261179, 0.17855948419310153, 0.12145034474087879, 0.164641632582061, 0.13020516402320936, 0.10843173120520078, 0.26404759380966425, 0.06554142135428265, 0.09695589425973594, 0.12442307663150132, 0.16850727202836424, 0.15197921282378957, 0.15688221144955605, 0.1484856565366499, 0.13614103925647214, 0.18307956430362538, 0.17193154140841216], [0.03414938357309438, 0.01395385412251926, 0.01939935620612232, 0.04065659006300848, 0.017566904534760397, 0.03884135992848314, 0.09002781211165711, 0.05492598589626141, 0.023667666428082157, 0.04143055732129142, 0.03234786832763348, 0.03522482234984636, 0.027506544029165525, 0.012580797429109225, 0.04997689989977516, 0.059924714150838554, 0.05312346875143703, 0.017223028553416952, 0.06731058267178014, 0.028466808907978702, 0.02771143615973415, 0.05020351098210085, 0.011998568661510944, 0.039793116084183566, 0.019339260798005853, 0.023110903530323412, 0.0199835989769781, 0.04230049540637992, 0.06985369269386865, 0.05305333579599392, 0.03602352167945355, 0.05975912987196352, 0.011839346443593968, 0.06589316966710612, 0.021345041059248615, 0.03672435399494134, 0.007002388756518485, 0.11887626489624381, 1.3943705661222339, 13.90553243458271, 43.654808700084686, 54.63055394589901, 65.98531365394592, 71.64307326078415, 57.76663966476917, 65.10730236768723, 68.98819372057915, 45.160781890153885, 21.786113865673542, 24.467472285032272, 24.80341225862503, 11.725763250142336, 10.34490879625082, 42.588654309511185, 63.912160098552704, 54.31638680398464, 29.791172817349434, 14.669295251369476, 6.44859217107296, 1.7643935233354568, 1.1947976751253009, 0.3967722749803215, 0.03305669728433713, 0.029996193443366792, 0.11433144900365733, 0.04975396986992564, 0.06302191904978827, 0.07351045467657968, 0.11880620615556836, 0.12078367348294705, 0.00536694250513392, 0.07493977172998711, 0.07184911999502219, 0.03650553175248206, 0.038431460634456016, 0.08777669267146848, 0.38335569959599525, 0.039410019453498535, 0.13431924482574686, 0.11728212426532991, 0.6267317791935056, 0.21242803166387603, 0.08212523811380379, 0.7140575058292598, 0.7692491286434233, 0.8667121175676584, 0.7208086748141795, 0.02971198427985655, 0.018445830028213095, 0.16884033306268975, 0.3266478987643495, 0.7066733145620674, 0.12510539236245677, 0.2757850452326238, 0.05432060861494392, 0.18799314595526084, 0.15489816869376227, 0.08486742182867602, 0.2066962915705517, 0.17660503828665242, 0.06671172144706361, 0.03288344661996234, 0.02931332666776143, 0.024354175293410663, 0.04214449967548717, 0.001721346829981485, 0.037785202148370445, 0.03399847155378666, 0.06620044106966816, 0.7977583457250148, 1.5414814534597099, 6.942073591053486, 24.3043527379632, 52.46927171945572, 54.37472507357597, 66.58945083618164, 74.53539445996284, 50.99265195429325, 60.64862921833992, 106.70224159955978, 82.49161273241043, 41.36509336531162, 32.72966913878918, 34.099218249320984, 50.68461388349533, 50.777230113744736, 59.33385416865349, 62.51896485686302, 65.33742561936378, 55.97786284983158, 34.029613584280014, 14.435888025909662, 3.1495690578594804, 0.0415502286341507, 0.02746628066233825, 0.0973714079009369, 0.028346812905510888, 0.03778778111154679, 0.08319179338286631, 0.02713221216254169, 0.06898966210428625, 0.04670270391216036, 0.11931604676647112, 0.04834809726162348, 0.0363409493729705, 0.05940995310083963, 0.06357259262586012, 0.047305761981988326, 0.033440105617046356, 0.007751078928777133, 0.038855360544403084, 0.011332103349559475, 0.03197874262696132, 0.02248842160042841, 0.04873317542660516, 0.05597930867224932, 0.007419912226396264, 0.09537761332467198, 0.008808081365714315, 0.026926212376565672, 0.019117918964184355, 0.03668010715045966, 0.037338566544349305, 0.04138150507060345, 0.06646876456215978, 0.018453826669428963, 0.13505843875464052, 0.10753249312983826, 0.07259464444359764, 0.0064252330321323825, 0.029846630277461372, 0.026813658259925433, 0.10140792684978805, 0.02599292271042941, 0.008509799226885661, 0.022383995856216643, 0.03788753689150326, 0.030201616209524218, 0.03062171261262847, 0.016500338133482728, 0.016564825200475752, 0.020972468082618434, 0.05491145093401428, 0.017997852992266417, 0.01853943154856097, 0.06775773406843655, 0.012570420349220512, 0.02118576318025589, 0.02446110393066192, 0.03132106990960892, 0.0077771723772457335, 0.10426456457935274, 0.05096013053844217, 0.0809001675224863, 0.014382047356775729, 0.024897896801121533, 0.09468358650337905, 0.05070128056104295, 0.022119125205790624, 0.07354804445640184, 0.04452617773495149, 0.006241452683752868, 0.05808963156596292, 0.04924026638036594, 0.058800686965696514, 0.04614972225681413, 0.03212285286281258, 0.006628270721193985, 0.041550362220732495, 0.06623519584536552, 0.028129163256380707, 0.03253378003137186, 0.020043965268996544, 0.15146082267165184, 1.588157198857516, 15.15619257465005, 49.258109629154205, 61.17532655596733, 76.6114890575409, 79.36040595173836, 67.55057886242867, 71.82790294289589, 82.89954364299774, 55.8476248383522, 34.851889461278915, 39.87873092293739, 31.310766376554966, 17.04746413975954, 20.930304788053036, 39.27294842898846, 54.01345945894718, 45.97043104469776, 30.965925380587578, 17.325233034789562, 7.611287031322718, 2.877337890677154, 1.5572737623006105, 0.41580049612093717, 0.14574779954273254, 0.04241260794515256, 0.06514593827887438, 0.04181316413450986, 0.04167227853031363, 0.08417068616836332, 0.16006298217689618, 0.11610702989855781, 0.24520922888768837, 0.2586932061240077, 0.249172609183006, 0.404883474111557, 0.295162342954427, 1.2327912426553667, 2.5001276191323996, 0.42341819673310965, 0.12945232942001894, 1.3689306937158108, 1.0879293596372008, 0.13819148938637227, 0.05446461866085883, 0.36392440320923924, 1.1016006697900593, 1.4378693257458508, 1.9661434600129724, 0.40677808807231486, 0.23300887027289718, 0.21372377697844058, 1.82705192361027, 1.6404374060221016, 0.2533554722322151, 0.9730289876461029, 0.299084652797319, 0.8703599218279123, 0.5803344876039773, 0.06604962924029678, 1.549057534430176, 0.5010429548565298, 0.09095818328205496, 0.0462257070466876, 0.05459621628688183, 0.05216853620368056, 0.08787577680777758, 0.03045471454242943, 0.07541485014371574, 0.05562335609283764, 0.10145503096282482, 0.7018838496878743, 0.76658048434183, 6.8970973044633865, 20.187967121601105, 49.3887922167778, 43.50831136107445, 58.18053625524044, 63.59994225203991, 39.90443654358387, 53.21047134697437, 105.9235417842865, 88.04043978452682, 42.26421631872654, 37.64108419418335, 46.36968322098255, 62.897983118891716, 58.54824252426624, 68.12636956572533, 70.24357035756111, 76.26458287239075, 67.87619099020958, 46.80044710636139, 20.90174552053213, 4.878229536116123, 0.06043072156899143, 0.01800125388399465, 0.04248925695719663, 0.0240977020439459, 0.03723379755683709, 0.05559776684094686, 0.019008498566108756, 0.03766028385143727, 0.041018357369466685, 0.05567483887716662, 0.04057605219713878, 0.0896450197615195, 0.02641164799570106, 0.00997261126030935, 0.06534245898365043, 0.008767938597884495, 0.05585962993791327, 0.008394847045565257, 0.027290974248899147, 0.01314628891122993, 0.05789882539829705, 0.09388217091327533, 0.02302808170497883, 0.07426887765177526, 0.07574795570690185, 0.02081729984638514, 0.04331333773734514, 0.01772071835148381, 0.0420510076219216, 0.013861979950888781, 0.02491968440153869, 0.016588653707003687, 0.03985416144132614, 0.00259651496890001, 0.014225803006411297, 0.01933948715304723, 0.054341589129762724, 0.10644085326930508, 0.03615540132159367, 0.07403101932140999, 0.003105839787167497, 0.008109866048471304, 0.04207732046779711, 0.11487740252050571, 0.08858509187120944, 0.14723582047736272, 0.1337593686184846, 0.085648680687882, 0.09931711872923188, 0.1193227335170377, 0.20602259959559888, 0.11808512062998489, 0.1586502298596315, 0.14379774715052918, 0.11868666842929088, 0.11045582024962641, 0.1370355350081809, 0.08563357056118548, 0.21112397429533303, 0.15888641093624756, 0.12789056869223714, 0.1428307287278585, 0.053960444347467273, 0.11811114774900489, 0.13257865619380027, 0.09639604031690396, 0.14576736255548894, 0.2140803195652552, 0.10541203620960005, 0.21186644851695746, 0.15806835639523342, 0.1353406478301622, 0.14806981635047123, 0.18378847860731184, 0.10705922555644065, 0.11818228260381147, 0.21917923033470288, 0.12744023348204792, 0.11472760743345134, 0.06718406133586541, 0.26271600276231766, 2.078248132020235, 20.92046521604061, 61.426420882344246, 73.68427813053131, 89.12567675113678, 87.85499453544617, 77.14571759104729, 83.84567767381668, 89.16541501879692, 62.85325191915035, 36.42867185175419, 40.4798586666584, 38.857805505394936, 21.24402355402708, 22.877711690962315, 61.41914427280426, 84.674481600523, 70.74751451611519, 39.4161931425333, 21.748858764767647, 10.56444201618433, 3.758240584284067, 2.249507079832256, 0.8741633396130055, 0.5275417235679924, 0.23542758892290294, 0.24770156858721748, 0.19438275543507189, 0.1879357037250884, 0.264054688741453, 0.2435181860346347, 0.20601295167580247, 0.380765960435383, 0.5249201017431915, 0.29521598538849503, 0.3289820422651246, 0.30301447317469865, 0.9975599963217974, 2.5166600570082664, 0.382424482377246, 0.3223144687945023, 1.4267259486950934, 1.3469764217734337, 0.5005548591725528, 0.48831141146365553, 2.1665893541648984, 3.987504607066512, 3.218903224915266, 3.772726356983185, 0.7848517445381731, 0.7046857837121934, 0.798096883809194, 2.1709363209083676, 1.7284763068892062, 0.24715901410672814, 0.82830092869699, 0.1485543794115074, 0.6903122831135988, 0.39064498501829803, 0.4373976169154048, 1.5067376615479589, 0.5386568396352232, 0.2073063369607553, 0.253203985048458, 0.13395363319432363, 0.3387328237295151, 0.3629248193465173, 0.15976456459611654, 0.1728360413108021, 0.16160989995114505, 0.3518165310379118, 1.9038890255615115, 2.491280031390488, 10.228332951664925, 32.18194752931595, 69.28584694862366, 72.66008868813515, 80.58674454689026, 92.0427118241787, 67.93322592973709, 71.3549955189228, 114.85009878873825, 94.76127594709396, 58.89174409210682, 48.70719999074936, 50.6989961117506, 69.09395724534988, 71.77049562335014, 80.07636353373528, 80.8924001455307, 87.37072572112083, 81.86097577214241, 62.47775986790657, 25.72585456073284, 5.532104624435306, 0.160114947357215, 0.13479830115102232, 0.1932227934594266, 0.12903760245535523, 0.23020086548058316, 0.16030809871153906, 0.08294616476632655, 0.14961725362809375, 0.17335569311399013, 0.29893093917053193, 0.10642767272656783, 0.09183941685478203, 0.23537327855592594, 0.10259315895382315, 0.38249281933531165, 0.18513973656808957, 0.19652900198707357, 0.09692314328276552, 0.10751462963526137, 0.09590407062205486, 0.08901596796931699, 0.17168538586702198, 0.17166760400868952, 0.18064769479678944, 0.2348282453021966, 0.1007296187162865, 0.10809040264575742, 0.13322018348844722, 0.07528967209509574, 0.13795796519843861, 0.12850778322899714, 0.1139119871368166, 0.1190328506345395, 0.23450319946277887, 0.15381019504275173, 0.1295180688612163, 0.12055198982125148, 0.19251442834502086, 0.16891319712158293, 0.19535661645932123, 0.08794520472292788, 0.10989909816998988, 0.06191226726514287], [0.0412885622063186, 0.02477870788425207, 0.050391637996654026, 0.028130191130912863, 0.057377373886993155, 0.009048891588463448, 0.03310562336992007, 0.03844407343422063, 0.04901150306977797, 0.022672283121210057, 0.06954956057597883, 0.05700934285414405, 0.04250626327120699, 0.014578993868781254, 0.08351286873221397, 0.05746956347138621, 0.05148167852894403, 0.016400528547819704, 0.09283081482863054, 0.025565158066456206, 0.0453245616517961, 0.05987268959870562, 0.03912711646989919, 0.033014398577506654, 0.03685319083160721, 0.02643115720275091, 0.09879878052743152, 0.013253473589429632, 0.02281428565765964, 0.04071752780873794, 0.047738441498950124, 0.06513767075375654, 0.020668224642577115, 0.017306013651250396, 0.019013754827028606, 0.03833983137155883, 0.18500466569093987, 6.788972206413746, 32.08667144179344, 56.33526027202606, 62.500034272670746, 70.5891466140747, 67.64849960803986, 60.94530209898949, 65.4474525153637, 62.56513237953186, 22.582114152610302, 18.52959170937538, 26.000775508582592, 23.075844459235668, 23.75506181269884, 53.930205926299095, 49.16224457323551, 34.43551540374756, 28.288431353867054, 12.566767372190952, 3.82816300727427, 1.0990323638543487, 0.06234682441572659, 0.09313070186180994, 0.03583637058909517, 0.12131522933486849, 0.03163221161230467, 0.04240213253069669, 0.05006416904507205, 0.028692755768133793, 0.07392014987999573, 0.02694358419830678, 0.04035880701849237, 0.10897786283749156, 0.13512748817447573, 0.055496912682428956, 0.1497069199103862, 0.1832139227190055, 0.14486997242784128, 1.0414862330071628, 1.4361768728122115, 1.1179907340556383, 0.2022209481219761, 0.4837973427493125, 0.4215427895542234, 0.7820549164898694, 0.12326216470682994, 0.2897163445595652, 0.5617966479621828, 1.0181970451958477, 0.7202316401526332, 0.08212475571781397, 0.20017973030917346, 0.06878197207697667, 1.520692293997854, 0.8895082818344235, 0.18810562585713342, 0.2138213545549661, 0.045072327920934185, 0.13490105891833082, 0.09255855053197592, 0.23400694015435874, 2.848278949968517, 1.3933839253149927, 0.1092700834851712, 0.05917743452300783, 0.051365595500101335, 0.09941082971636206, 0.1093979406869039, 0.08076514859567396, 0.04772845219122246, 0.023398584089591168, 0.06840710586402565, 0.05363306816434488, 0.12988091970328242, 0.10630461722030304, 0.10765327766421251, 2.1391251403838396, 15.813651345670223, 33.978703916072845, 73.24730157852173, 64.43311974406242, 40.73183834552765, 28.73265601694584, 32.207311168313026, 57.43590161204338, 44.97143045067787, 27.15612631291151, 23.469904214143753, 37.588985189795494, 44.866533279418945, 48.530950248241425, 58.05110760033131, 72.21055760979652, 66.00529298186302, 71.72280818223953, 40.94142749905586, 5.7648402359336615, 0.5423981545027345, 0.10076534570544027, 0.03424029295274522, 0.015033794952614699, 0.03701213659951463, 0.0620654576778179, 0.09653763467213139, 0.04592215751472395, 0.045267048917594366, 0.014371962497534696, 0.06791825318941846, 0.04355294753622729, 0.031197183197946288, 0.044028560296283104, 0.02358094832743518, 0.0733687193132937, 0.07752329911454581, 0.03733532335900236, 0.0381123445549747, 0.04807447854545899, 0.03763874672586098, 0.015767528529977426, 0.05346498284779955, 0.009709663700050442, 0.013355582905205665, 0.05056625421275385, 0.08557249922887422, 0.06047062313882634, 0.029894350373069756, 0.04185214173048735, 0.05044900601205882, 0.014957601433707168, 0.05213719901803415, 0.05633899425447453, 0.04803390162123833, 0.011295022868580418, 0.033470938142272644, 0.03541629273968283, 0.045983032177900895, 0.06967802633880638, 0.038237058761296794, 0.05858965727384202, 0.07768349169055, 0.04894390454865061, 0.04098657489521429, 0.0601690625626361, 0.034135869063902646, 0.027455916570033878, 0.020659259498643223, 0.008481608747388236, 0.057651345123304054, 0.01609058541362174, 0.05503342290467117, 0.012884476836916292, 0.03586951490433421, 0.00849735712108668, 0.04293884259823244, 0.02169332354242215, 0.03789413829508703, 0.011961110612901393, 0.06672887990134768, 0.05620204203296453, 0.019604975641414057, 0.021494535576493945, 0.06467048879130743, 0.015497591793973697, 0.07387920559267513, 0.019404638442210853, 0.0879815848020371, 0.022810691807535477, 0.0032734921069277334, 0.023673160176258534, 0.021580580178124364, 0.07461523055098951, 0.018262931444041897, 0.019683509708556812, 0.07220987055916339, 0.027887243522854988, 0.2516460686456412, 6.82383201085031, 35.908042788505554, 64.562928378582, 72.43875056505203, 79.1871352493763, 77.27880924940109, 71.42651528120041, 71.18346512317657, 75.15210896730423, 36.13724648952484, 34.20550234615803, 37.5071831792593, 28.889057524502277, 30.878685861825943, 40.73161415755749, 40.753804966807365, 37.6533879339695, 29.342758879065514, 13.039754591882229, 3.9114732993766665, 0.881075287470594, 0.20108840108150616, 0.08628058974863961, 0.1473144584451802, 0.11300525336991996, 0.018645953859959263, 0.02865013051632559, 0.12399646788253449, 0.14666629635030404, 0.10800842501339503, 0.2359736611833796, 0.4403444775380194, 0.46561751514673233, 1.3660983019508421, 1.18089813971892, 1.2023831368423998, 1.354339001700282, 1.2653310340829194, 2.082256441935897, 4.240506906062365, 2.9910361021757126, 0.26340833748690784, 0.8372736722230911, 1.1169776134192944, 0.3684202744625509, 0.18995044170878828, 0.3219685982912779, 1.2834200821816921, 2.3292336892336607, 1.2310172128491104, 0.4819056380074471, 0.09860629710601643, 0.24473992438288406, 2.02119633089751, 2.7261741645634174, 1.1474786954931915, 2.255455660633743, 0.9238421707414091, 1.9284130283631384, 0.9529417217709124, 1.823630325961858, 5.318921338766813, 1.5388815617188811, 0.32017444144003093, 0.2071737893857062, 0.11714933920302428, 0.15147024794714525, 0.2637735928874463, 0.071614341577515, 0.011229606261622394, 0.02977451207698323, 0.008351431406481424, 0.06193319211888593, 0.16197892546188086, 0.01844502294261474, 0.20718548563309014, 1.612641541287303, 15.383111648261547, 30.573961213231087, 68.60219523310661, 61.925539299845695, 46.0424941778183, 51.03990241885185, 51.98833532631397, 68.5422420501709, 47.80103601515293, 28.842656314373016, 29.83597621321678, 49.33822073042393, 56.05216786265373, 57.75501988828182, 68.69594380259514, 81.06286659836769, 77.95182153582573, 83.09900254011154, 51.41526147723198, 11.0543810762465, 0.5682553513906896, 0.02493049563781824, 0.010818193914019503, 0.0242585792511818, 0.011230925429117633, 0.05409999408584554, 0.09077291353605688, 0.03510846843710169, 0.02926615019532619, 0.056845023937057704, 0.05901281503611244, 0.03873919587931596, 0.03297097922768444, 0.010700617312977556, 0.03041145104361931, 0.019031460615224205, 0.043428552453406155, 0.051909671383327805, 0.04285726201487705, 0.028535353667393792, 0.023416633121087216, 0.06331054770271294, 0.04045515634061303, 0.017145637393696234, 0.01757714617269812, 0.04972089976945426, 0.07227169146062806, 0.0420733388455119, 0.046468675063806586, 0.020629057798942085, 0.06403909181244671, 0.023421345758833922, 0.040437868010485545, 0.004601491855282802, 0.051367076084716246, 0.022029145366104785, 0.05691964688594453, 0.0890416833863128, 0.027809423772851005, 0.037110037010279484, 0.0943764932162594, 0.03130640878225677, 0.19469123653834686, 0.10502856850507669, 0.12471705616917461, 0.178624140098691, 0.16253786656307057, 0.10827494508703239, 0.1537004907731898, 0.12759773206198588, 0.11914638438611291, 0.17518890177598223, 0.21114833158208057, 0.12961295986315235, 0.18275074835401028, 0.12652927689487115, 0.13920315541327, 0.15584050328470767, 0.1104477234184742, 0.11966717167524621, 0.20258161704987288, 0.14805960439844057, 0.13933619280578569, 0.19729142513824627, 0.11941141274292022, 0.12000536837149411, 0.1839423258206807, 0.06533839943585917, 0.18981869565322995, 0.14335274056065828, 0.12766339728841558, 0.12688580463873222, 0.17967151827178895, 0.21104848303366452, 0.08969163405708969, 0.11359257419826463, 0.14091796183492988, 0.19386509258765727, 0.5580775975249708, 10.899619180709124, 46.77411451935768, 74.50018554925919, 79.4211494922638, 88.75855565071106, 84.13274466991425, 82.08558171987534, 84.47210446000099, 80.68426251411438, 39.85150918364525, 34.571601301431656, 40.71180962026119, 35.791164860129356, 37.21078008413315, 71.91230401396751, 67.09367617964745, 50.09755678474903, 39.5065712928772, 18.326826989650726, 5.781674757599831, 1.7923333053477108, 0.5381479638163, 0.48197284690104425, 0.22175912861712277, 0.23546083713881671, 0.22947940888116136, 0.11024502062355168, 0.16757982491981238, 0.16046921897213906, 0.30837646045256406, 0.39290194516070187, 0.35877000947948545, 0.30045679479371756, 0.8592905814293772, 0.6805776210967451, 0.4973073990549892, 0.4962554492522031, 0.5125504592433572, 1.654209648258984, 5.638805748894811, 4.626101665198803, 0.47514081350527704, 0.8635952160693705, 1.5888855722732842, 1.3927284604869783, 0.6237471580971032, 1.6654861369170249, 2.395264646038413, 5.713296476751566, 3.411634345538914, 0.5403732194099575, 0.6050040700938553, 0.6338477286044508, 4.933447698131204, 3.9363736007362604, 0.6963626865763217, 0.9842010412830859, 0.7400722161401063, 0.9139477391727269, 0.38840562861878425, 1.0121016972698271, 11.116288304328918, 4.3528027553111315, 0.2873014553915709, 0.2986350003629923, 0.13285875756992027, 0.3583538724342361, 0.26366298319771886, 0.2436488782404922, 0.10556966837611981, 0.22339005750836805, 0.16973010875517502, 0.170710114762187, 0.3972110920585692, 0.4099335812497884, 0.4102493799291551, 3.0669679027050734, 23.407659754157066, 44.22615744173527, 84.17483881115913, 80.89320570230484, 53.065543323755264, 37.90319412946701, 42.208636701107025, 68.8223934173584, 60.995603799819946, 44.088042452931404, 36.73436924815178, 54.04746763408184, 62.97620192170143, 68.4240759909153, 78.79963964223862, 90.9493736922741, 87.96152561903, 98.07668164372444, 65.35020053386688, 16.9108709692955, 0.5373434163630009, 0.3538698755437508, 0.12381055246805772, 0.10609138334984891, 0.17080111691029742, 0.18145181180443615, 0.4788131680106744, 0.1342526444932446, 0.1170322579855565, 0.15113620727788657, 0.16396639693994075, 0.16057058150181547, 0.15687026287196204, 0.13549857685575262, 0.07607248204294592, 0.11195495855645277, 0.2441656801966019, 0.17502036003861576, 0.13714026688830927, 0.09038719712407328, 0.14157139317831025, 0.23616969207068905, 0.14567175909178331, 0.11699738446623087, 0.07434966784785502, 0.21999039774527773, 0.16317553468979895, 0.14812089095357805, 0.18569667387055233, 0.13894736679503694, 0.15439105918630958, 0.07939875082229264, 0.16242218058323488, 0.18475425022188574, 0.15710019506514072, 0.20596459333319217, 0.11814353507361375, 0.21064834669232368, 0.11270779315964319, 0.15492335718590766, 0.11051030131056905, 0.12328379089012742], [0.06120608035416808, 0.04375367621832993, 0.10579032372334041, 0.019129887950839475, 0.029238887400424574, 0.023410274770867545, 0.024615684014861472, 0.03679744440887589, 0.04341532367106993, 0.021119648954481818, 0.0320663902675733, 0.05447363204439171, 0.08531126324669458, 0.04896366794127971, 0.054504178842762485, 0.00921866714634234, 0.01988731644814834, 0.07368024322204292, 0.09084649005671963, 0.03665562740934547, 0.03304319761809893, 0.045957487454870716, 0.021268039527058136, 0.02903791009885026, 0.042306822215323336, 0.03689319630211685, 0.04430655768373981, 0.10729233414167538, 0.025146534826490097, 0.08255540917161852, 0.01592839831573656, 0.04967149128788151, 0.027581300564634148, 0.028912574343848974, 0.13943460158770904, 1.0512606147676706, 11.365329790860415, 45.97824342548847, 63.33923064172268, 68.56846064329147, 62.9829503595829, 63.79575714468956, 52.77305021882057, 65.55076137185097, 52.31227934360504, 19.55683048814535, 20.71936670690775, 9.645073749125004, 13.559590447694063, 36.34263686835766, 42.0173055678606, 46.74818091094494, 43.32764245569706, 20.04372876137495, 4.75871454924345, 0.21770548832137138, 0.07529571317718364, 0.043117915411130525, 0.074840910237981, 0.025840943853836507, 0.0554537901916774, 0.10134503725566901, 0.08884093243977986, 0.1362257479922846, 0.047390819527208805, 0.04801033101102803, 0.03436936727666762, 0.29332784295547754, 0.18497848272090778, 1.045452388934791, 0.7003975950647146, 0.6631214171648026, 1.7067976389080286, 1.6193748987279832, 0.618493880610913, 3.0239679850637913, 3.1389961251989007, 1.7028408637270331, 0.25704828032758087, 1.2383909546770155, 0.3262823761906475, 0.32332298811525106, 0.2600036608055234, 0.1909818043350242, 1.0166498157195747, 0.8112095051910728, 1.2868769466876984, 0.6687170325312763, 0.24834110692609102, 0.2744150999933481, 1.864328042138368, 1.8503069132566452, 0.2593139681266621, 3.2865918427705765, 1.3991936948150396, 2.8908901009708643, 1.686815817374736, 0.5171245231758803, 1.2534896819852293, 0.4631366638932377, 0.24170822143787518, 0.062277864053612575, 0.20910325460135937, 0.11566025699721649, 0.07440179630066268, 0.02893346765631577, 0.0076741126486012945, 0.02090366542688571, 0.04720243647170719, 0.11022640755982138, 0.07190256204921752, 0.05086616722110193, 0.15389943087939173, 0.5707629199605435, 0.21400430880021304, 3.1617051316425204, 8.464335557073355, 27.855539582669735, 43.098423555493355, 44.27422486245632, 35.73438450694084, 12.363792713731527, 23.12346540391445, 32.980767264962196, 42.1552761644125, 27.47339978814125, 23.62080741673708, 35.17674922943115, 57.76152893900871, 60.04067324101925, 64.42667528986931, 63.78299742937088, 64.70305725932121, 54.94841068983078, 13.95625401288271, 0.7042959483806044, 0.04860611603362486, 0.01741939711791929, 0.02847925657988526, 0.0444749398593558, 0.03831662812444847, 0.06997834381763823, 0.04188538252492435, 0.05770310621301178, 0.10040150038548745, 0.05126004354679026, 0.057616690537543036, 0.05733942045480944, 0.07545094820670784, 0.13251631578896195, 0.057020627209567465, 0.036724339151987806, 0.027750000008381903, 0.043335769150871783, 0.026841544458875433, 0.06123916529759299, 0.03198227896064054, 0.06586875300854445, 0.05825589490996208, 0.06261350776185282, 0.048384699985035695, 0.02746442158240825, 0.03175024648953695, 0.08817164882202633, 0.018536635507189203, 0.07999033899977803, 0.03664724114059936, 0.10313994367606938, 0.014169139103614725, 0.041495116747682914, 0.06757446069968864, 0.017018169819493778, 0.03802162813371979, 0.07204410445410758, 0.008054383088165196, 0.08521432391717099, 0.03239756995753851, 0.08366017020307481, 0.04438778945768718, 0.05869344291568268, 0.05055142981291283, 0.08895263308659196, 0.027685004570230376, 0.04756958434882108, 0.07619283613166772, 0.007682411714995396, 0.006388175743268221, 0.028113797088735737, 0.009469597480347147, 0.07582654914585873, 0.05303887133777607, 0.014221969813661417, 0.03680373039969709, 0.057799292262643576, 0.029100690226186998, 0.01460309418689576, 0.036738900089403614, 0.02663029768882552, 0.053701839278801344, 0.035184371590730734, 0.026305949468223844, 0.021366559631132986, 0.04043947847094387, 0.07795964484103024, 0.04763109354826156, 0.015007378206064459, 0.016897266541491263, 0.03567807791114319, 0.020313517015893012, 0.051684173522517085, 0.1162017130991444, 1.0638976679183543, 13.44136644154787, 52.437942400574684, 72.9585474729538, 78.8856290280819, 70.7384406030178, 74.60698261857033, 62.49380260705948, 73.31515073776245, 64.52390447258949, 30.447826981544495, 27.150855995714664, 15.801394153386354, 25.025736428797245, 35.90297386050224, 31.385071389377117, 43.569374084472656, 41.40560299158096, 18.22685245424509, 5.07309970445931, 0.34870642761234194, 0.03779305407078937, 0.024597072806500364, 0.052441780135268345, 0.016006865589588415, 0.07834214033209719, 0.07490325064281933, 0.11713640356902033, 0.1044641800399404, 0.21001691260607913, 0.2636755700223148, 0.3012565925018862, 0.8169601997360587, 1.3190227467566729, 3.4675357583910227, 4.514486929401755, 3.6266009230166674, 2.9221545858308673, 4.268789738416672, 4.484648080542684, 5.601801909506321, 6.835403814911842, 4.378887880593538, 0.7720231579151005, 0.7111968530807644, 0.37210969836451113, 0.33242204517591745, 0.37146607821341604, 0.596434164326638, 1.2241866043768823, 0.2811501792166382, 0.5746145476587117, 0.9873293421696872, 0.5841393303126097, 0.28960460680536926, 0.7962980365846306, 0.9538743935991079, 2.6193212857469916, 5.261088442057371, 4.6474778931587934, 5.026641972362995, 3.878231020644307, 2.4751204485073686, 5.795900244265795, 2.2780136251822114, 0.5755905609112233, 0.6805874174460769, 0.8656590397004038, 0.8255272556561977, 0.2842441631946713, 0.2881348872324452, 0.27033874997869134, 0.10499563941266388, 0.11284663414699025, 0.2230010979110375, 0.06764397767256014, 0.026632318185875192, 0.168119128793478, 0.5367511825170368, 0.12859899317845702, 2.624656199477613, 10.251379664987326, 27.712247371673584, 43.71375493705273, 33.89195837080479, 26.43643733114004, 22.839062064886093, 39.406781047582626, 35.12667931616306, 36.992307007312775, 27.822884134948254, 28.82042370736599, 43.27077470719814, 64.82634544372559, 70.4176390171051, 73.14003333449364, 74.61526617407799, 74.56033632159233, 67.94526368379593, 23.206166066229343, 1.4696217281743884, 0.07081269592163153, 0.07021485886070877, 0.03195057070115581, 0.02279112879477907, 0.06287012016400695, 0.07806957175489515, 0.12273507658392191, 0.06545136173372157, 0.024651008388900664, 0.04403179606015328, 0.030058760203246493, 0.03313938737846911, 0.07652662447071634, 0.008432529593846994, 0.04152239067479968, 0.03956192223995458, 0.03767545334994793, 0.03556604700861499, 0.03344019838550594, 0.029240703806863166, 0.024492749107594136, 0.03252111899200827, 0.0425003965938231, 0.010099663231812883, 0.09559396421536803, 0.0994154681393411, 0.04242622264428064, 0.04803782016097102, 0.0389732098847162, 0.02062774234218523, 0.042421209436724894, 0.0692631138372235, 0.03070382197620347, 0.023081056206137873, 0.025762192708498333, 0.014683416829939233, 0.10350971133448184, 0.05295977694913745, 0.031136805773712695, 0.047633334834245034, 0.12848321814090014, 0.17797729902667925, 0.1873490063007921, 0.13312110677361488, 0.159464618191123, 0.14403516019228846, 0.09351328641059808, 0.19406189530855045, 0.19438667397480458, 0.19925661734305322, 0.10673322234652005, 0.17189743230119348, 0.12453065835870802, 0.21909980569034815, 0.17895426222821698, 0.11157883811392821, 0.13142160343704745, 0.22521176288137212, 0.18258581345435232, 0.15615325915860012, 0.16097281069960445, 0.12672529293922707, 0.11158997032907791, 0.10741895937826484, 0.10758268457720987, 0.0978968855633866, 0.05885099344595801, 0.2556580299278721, 0.17163833370432258, 0.14932170073734596, 0.07789139694068581, 0.07869351014960557, 0.06090686125389766, 0.14952558354707435, 0.2434005556278862, 1.9876402127556503, 21.600541323423386, 66.77906066179276, 82.71849855780602, 87.12255343794823, 82.20532849431038, 83.35190936923027, 72.45191305875778, 81.03195905685425, 70.49871146678925, 36.32144160568714, 34.51234348118305, 20.21939143538475, 20.109641924500465, 51.08733907341957, 57.402881383895874, 65.76249361038208, 58.53636436164379, 27.787853814661503, 7.757085682824254, 0.9036971954628825, 0.1617059190175496, 0.08934322540881112, 0.16449688409920782, 0.23075775825418532, 0.17238073371117935, 0.3079434618121013, 0.24940015166066587, 0.24131056386977434, 0.22540926322108135, 0.269089299836196, 0.2442210295703262, 0.6588972313329577, 0.5888568365480751, 3.2579299807548523, 3.1330019468441606, 2.6149111473932862, 4.324978273361921, 5.007833931595087, 4.522228064015508, 7.151421932503581, 13.953848741948605, 4.172634948045015, 0.8066321758087724, 1.214203352574259, 1.512957215309143, 1.30767323076725, 0.8008848060853779, 1.399199275765568, 3.646053741686046, 4.494454879313707, 5.754600260406733, 5.28538528829813, 1.3507455820217729, 1.0328127234242857, 7.813408160582185, 8.238110896199942, 3.1659965263679624, 9.403870292007923, 4.71701986156404, 6.258806129917502, 5.23093088530004, 1.7893736204132438, 5.424667289480567, 2.3029269883409142, 0.2555774920620024, 0.29813378350809216, 0.7725288870278746, 0.6345263484399766, 0.1984765162342228, 0.2810788439819589, 0.23659393336856738, 0.21272067533573136, 0.4222769814077765, 0.2837544941576198, 0.12836195121053606, 0.19893145276000723, 0.49763812974561006, 1.026893591042608, 0.5818343977443874, 4.363526254892349, 13.269893992692232, 39.00221675634384, 60.81206224858761, 62.79527083039284, 50.43099649250507, 20.492230094969273, 32.51420170068741, 45.46486437320709, 55.4348111897707, 40.74791148304939, 37.68845625221729, 52.44483903050423, 75.60633659362793, 80.53990066051483, 85.1774226129055, 84.86169755458832, 83.70836064219475, 81.79998144507408, 29.6327593177557, 1.7667282605543733, 0.15544998517725617, 0.10047627176390961, 0.16165626933798194, 0.1523152127629146, 0.16551153355976567, 0.19972313137259334, 0.22340381692629308, 0.11472008947748691, 0.1681394933257252, 0.21964040090097114, 0.143685445364099, 0.13554470875533298, 0.20613574743038043, 0.15936165262246504, 0.17215074214618653, 0.1204139503533952, 0.1562026416650042, 0.15291587740648538, 0.1018227799795568, 0.09690240025520325, 0.13300791440997273, 0.1194529804342892, 0.11447134384070523, 0.22018163435859606, 0.18140205822419375, 0.15831687196623534, 0.10784957572468556, 0.20245641673682258, 0.16448052716441453, 0.1535353480721824, 0.1349348117946647, 0.3844317246694118, 0.11171499252668582, 0.14339563669636846, 0.13420130271697417, 0.15892489871475846, 0.14631683385232463, 0.09686721503385343, 0.1454579018172808, 0.23531225917395204], [0.04186415710137226, 0.0039059742448444013, 0.023094118005246855, 0.12691264069871977, 0.02168850329326233, 0.014238264593586791, 0.04482903706957586, 0.09840068509220146, 0.10175341143622063, 0.057187610436812975, 0.01512382952569169, 0.022306810642476194, 0.008947383412305498, 0.05181632404855918, 0.07905529972049408, 0.018800498692144174, 0.028079691692255437, 0.04041273889015429, 0.01957676104211714, 0.026915946618828457, 0.00930253168917261, 0.01973243022803217, 0.02898708411521511, 0.029249644830997568, 0.029455123258230742, 0.030211355042411014, 0.06766796388546936, 0.0769247199059464, 0.01803199920686893, 0.04048391827382147, 0.06297822139458731, 0.01561622502777027, 0.09597734286217019, 0.01771812268998474, 1.1444437270984054, 17.63618554919958, 45.67415714263916, 61.68710209429264, 63.561590909957886, 50.16957812011242, 52.86810211837292, 46.19477480649948, 37.539215460419655, 37.250438556075096, 25.18643170595169, 19.800771698355675, 22.11022887378931, 40.6818026304245, 30.75419694185257, 32.61241503059864, 47.90419287979603, 33.30691136419773, 7.678570970892906, 0.32439494621939957, 0.11805649599409662, 0.04350163915660232, 0.033358925793436356, 0.08703061903361231, 0.0380483602930326, 0.1255918256356381, 0.07559545920230448, 0.18804843595717102, 0.043082834090455435, 0.01450301371733076, 0.08226485835621133, 0.32259909727144986, 0.06492183936643414, 0.7669611764140427, 1.536001672502607, 1.9085088651627302, 4.44769031368196, 4.41948015242815, 3.8058263808488846, 5.863437820225954, 4.379291608929634, 4.644483178853989, 3.7910484988242388, 2.4276073230430484, 0.17389796557836235, 1.904952374752611, 0.7886226859409362, 0.0527130388218211, 0.20292174333008006, 0.33950813056435436, 0.9338515461422503, 1.1840962618589401, 1.9369775312952697, 0.7194957858882844, 0.6285954604391009, 0.528930074069649, 0.5931510217487812, 2.024178458377719, 4.052896248176694, 7.483194479718804, 3.073314274661243, 8.10864519327879, 3.495968207716942, 4.363936157897115, 5.275295404717326, 0.8519512752536684, 1.7944068065844476, 0.7139792537782341, 0.8142188843339682, 0.3621269215364009, 0.5177928716875613, 0.10337517480365932, 0.28966567071620375, 0.0712018262129277, 0.13508120784536004, 0.14677384839160368, 0.06995161907980219, 0.10199170021223836, 0.027445409614301752, 0.1290294388309121, 0.07583863873151131, 0.05286891209834721, 0.040672479444765486, 1.3688919832929969, 9.581279922276735, 47.809399366378784, 68.59033226966858, 49.66416344046593, 26.279251165688038, 18.448114581406116, 26.109964549541473, 51.380288153886795, 36.71511188149452, 21.7893360927701, 30.97144838422537, 44.25614543259144, 53.338380083441734, 59.05089475214481, 73.78543630242348, 78.07087674736977, 77.58183538913727, 21.916614063084126, 1.4967312547378242, 0.09447524338611402, 0.0252387800719589, 0.01780435282853432, 0.08990864545921795, 0.038708990468876436, 0.06845784650067799, 0.03134469618089497, 0.03307304308691528, 0.05805857639643364, 0.04209123944747262, 0.06264556112000719, 0.01949972240254283, 0.09785339570953511, 0.07666329096537083, 0.020329000071797054, 0.03531354610458948, 0.028294667754380498, 0.03913000342436135, 0.034405606347718276, 0.046252977263065986, 0.01146087895904202, 0.04336041587521322, 0.02831492467521457, 0.03657582798041403, 0.041542098406353034, 0.0035327755449543474, 0.040914664496085607, 0.045847720102756284, 0.024055559188127518, 0.030065300379646942, 0.054590305080637336, 0.06539144073030911, 0.07364948862232268, 0.07848112232750282, 0.016349505895050243, 0.03547364591213409, 0.024323385441675782, 0.03969993573264219, 0.0074172015320073115, 0.08009381665033288, 0.000681171663927671, 0.024989232915686443, 0.14601618982851505, 0.02502044208085863, 0.049094464047811925, 0.04473867687920574, 0.003977843362008571, 0.08744809936615638, 0.022255988369579427, 0.04014856771391351, 0.03565490806067828, 0.03125057330180425, 0.023963885396369733, 0.0425026749871904, 0.020081844486412592, 0.014943605456210207, 0.03156496190058533, 0.01198974545332021, 0.020331378655100707, 0.007778667804814177, 0.053910468122921884, 0.034548915064078756, 0.023487118596676737, 0.012182154659967637, 0.03154665682814084, 0.04119164885196369, 0.05487465525220614, 0.003448009524618101, 0.06694390234770253, 0.0993648091389332, 0.024804853746900335, 0.0978758605197072, 0.04389206078485586, 1.3990362407639623, 20.733262561261654, 57.220323979854584, 71.17702826857567, 72.47975796461105, 58.62268812954426, 62.901927307248116, 57.49530762434006, 45.89280501008034, 49.17934365570545, 47.14908979833126, 27.648078314960003, 28.43050193041563, 24.10303194075823, 16.556528583168983, 35.96610747277737, 44.18678775429726, 31.389228366315365, 8.973718173801899, 0.32868144277017564, 0.06245254335226491, 0.08250941085861996, 0.04407677763083484, 0.22868965985253453, 0.23774268891429529, 0.4105854837689549, 0.21259707806166261, 0.589701400604099, 0.48911575111560524, 0.5140734650194645, 0.8722550107631832, 1.4277702989056706, 1.3910649809986353, 2.9720900813117623, 4.715421572327614, 4.9734049290418625, 8.182865660637617, 8.375955149531364, 9.247471634298563, 6.1041895765811205, 7.814446929842234, 8.779823128134012, 9.097550678998232, 1.6164111765101552, 1.0529514052905142, 2.0632251631468534, 0.6766357482410967, 0.06699782679788768, 0.3103254589950666, 0.342523060971871, 1.0105029330588877, 0.4010069993091747, 0.90485880500637, 0.4140374797862023, 0.41873034671880305, 0.5594255751930177, 0.9426492021884769, 0.43224084831308573, 2.7071972703561187, 8.864968959242105, 2.689718445762992, 9.67110900208354, 4.513410162180662, 6.276616724207997, 4.894204353913665, 2.6115965377539396, 2.3813279438763857, 3.2005430851131678, 3.6367765394970775, 2.2126823058351874, 2.578095872886479, 1.3460270664654672, 1.2114490941166878, 1.0284188529476523, 0.8052074303850532, 0.7484567037317902, 0.3844960837159306, 0.14644360751844943, 0.044350708049023524, 0.06164075995911844, 0.07239390091854148, 0.04811759361473378, 0.06089522808906622, 1.196905137039721, 10.01264227554202, 42.01467990875244, 52.37113818526268, 39.377435222268105, 27.289605550467968, 29.3653429672122, 36.56368240714073, 54.45110097527504, 34.16705600917339, 28.32322608679533, 48.57144087553024, 59.07096907496452, 64.04347345232964, 66.06039762496948, 80.04017427563667, 85.88214039802551, 91.71587616205215, 33.598359525203705, 2.1539908926934004, 0.14372414094395936, 0.0423739568941528, 0.01916318626172142, 0.03359276910487097, 0.014231186360120773, 0.025019017157319468, 0.022109553356131073, 0.024129343510139734, 0.06060201667423826, 0.0454633729532361, 0.044541380630107597, 0.090174794459017, 0.04867079420364462, 0.05121203401358798, 0.041698090426507406, 0.01376815393086872, 0.03215831638954114, 0.03043026263185311, 0.00885026596733951, 0.04971852118615061, 0.059771100713987835, 0.037740732659585774, 0.031564887685817666, 0.025395579177711625, 0.03076111763220979, 0.05038495495682582, 0.07163641304941848, 0.02984670820296742, 0.03730837597686332, 0.00869651337779942, 0.0648380360507872, 0.029667108465218917, 0.07000233003054745, 0.06452370682382025, 0.04242572911607567, 0.0341499327623751, 0.04132536159886513, 0.021733803987444844, 0.015524519694736227, 0.182584997091908, 0.12003921772702597, 0.11851354021928273, 0.26460684661287814, 0.1587582123465836, 0.09589948414941318, 0.29205470345914364, 0.25059765146579593, 0.24823922489304096, 0.17374627059325576, 0.14083880436373875, 0.09562120845657773, 0.14039488130947575, 0.17045812594005838, 0.13952987850643694, 0.09398016409249976, 0.08255465960246511, 0.10070993695990182, 0.08871159094269387, 0.17688509513391182, 0.2207427573739551, 0.14293314510723576, 0.12947426730534062, 0.11990989849437028, 0.11058355870773084, 0.1772862853249535, 0.13016225304454565, 0.22380794602213427, 0.11335378818330355, 0.0906553425011225, 0.20713010657345876, 0.14476040174486116, 0.2395519262063317, 0.2006940238061361, 3.1624465668573976, 31.039139851927757, 71.73774898052216, 81.03806912899017, 82.11133673787117, 68.53819146752357, 76.84576168656349, 64.35022339224815, 53.27361635863781, 51.682048961520195, 43.47237668931484, 35.0112035125494, 36.66661888360977, 56.19079202413559, 44.13417957723141, 46.510404869914055, 65.18328309059143, 45.52305445075035, 11.833641361445189, 0.6132068205624819, 0.38306163100060076, 0.18286017060745507, 0.17394906986737624, 0.48544966033659875, 0.2593529754085466, 0.331228879513219, 0.19076309341471642, 0.5789907847065479, 0.3328225971199572, 0.2673179714474827, 0.815903915790841, 1.6620291536673903, 1.6843029647134244, 4.119361806660891, 5.64818887040019, 5.1300225500017405, 12.012840695679188, 12.055720444768667, 10.263284426182508, 13.28385729342699, 15.938772931694984, 13.336891047656536, 14.069797620177269, 8.703085295855999, 2.05972365103662, 4.3984288070350885, 2.2603004006668925, 0.5836154334247112, 0.5159598856698722, 1.2095831567421556, 2.531001912429929, 4.371428405866027, 4.947697883471847, 4.685554224997759, 1.8411162751726806, 1.3945642369799316, 4.068554732948542, 7.2339259553700686, 11.985807046294212, 16.003967933356762, 10.87354687973857, 14.881415069103241, 9.33478144928813, 8.186844997107983, 10.519419182091951, 5.996489580720663, 5.29693191871047, 4.133052946999669, 4.019591985270381, 1.8189493333920836, 2.2078442154452205, 1.239135714713484, 1.2659603753127158, 0.7807061669882387, 0.5267663870472461, 1.121380152180791, 0.35737622645683587, 0.21586693619610742, 0.10116206074599177, 0.21122817182913423, 0.18171580857597291, 0.17504483606899157, 0.35707512230146676, 2.051874459721148, 13.772978447377682, 67.57490515708923, 92.58798256516457, 68.43444183468819, 42.014299929142, 28.741509541869164, 34.86103177070618, 59.87035118043423, 52.24614769220352, 37.923504039645195, 47.913973554968834, 63.30422692000866, 72.03730970621109, 79.52562108635902, 92.52486035227776, 95.95875889062881, 99.66686591506004, 39.242838844656944, 2.3544583981856704, 0.27545389893930405, 0.08908991556381807, 0.11301013670163229, 0.20038330141687766, 0.1592517999233678, 0.17745029996149242, 0.1297462050570175, 0.10466216277563944, 0.15118033537873998, 0.13027169014094397, 0.18787520384648815, 0.15588706562994048, 0.23649739479878917, 0.14015386143000796, 0.18823358695954084, 0.08502048236550763, 0.15267714334186167, 0.1543886397848837, 0.11930275490158238, 0.1110438238538336, 0.08407621819060296, 0.2293860467034392, 0.09675026740296744, 0.11065629660151899, 0.16756708966568112, 0.16879494331078604, 0.24638094648253173, 0.18806133448379114, 0.15540324471658096, 0.12507815554272383, 0.15573529643006623, 0.09133054103585891, 0.126847391074989, 0.2005853585433215, 0.11352480869391002, 0.20016151800518855, 0.1523586580879055, 0.17812828155001625, 0.06796469679102302], [0.07217240694444627, 0.05597137882432435, 0.0012144392098889512, 0.0425468735920731, 0.0470692654926097, 0.0339608595095342, 0.016940910390985664, 0.07418695196975023, 0.04031572534586303, 0.040243054245365784, 0.04038286744616926, 0.05141013920365367, 0.017233982653124258, 0.035386369345360436, 0.03714754886459559, 0.0755950584425591, 0.03746589682123158, 0.05690206911822315, 0.01428539932021522, 0.05693590363080148, 0.037264778511598706, 0.004017744468001183, 0.05070243088994175, 0.03204790336894803, 0.037135169841349125, 0.11586903056013398, 0.016733507945900783, 0.20514772622846067, 0.06812208404880948, 0.09926947284839116, 0.13648279826156795, 0.1863410955411382, 0.08797675342066213, 2.8099805675446987, 20.58998554944992, 50.031675919890404, 62.62704245746136, 72.52819776535034, 60.15915088355541, 52.41252936422825, 34.6490715444088, 28.192585296928883, 29.757620617747307, 14.835750069469213, 8.624363020062447, 28.28464485704899, 45.62915995717049, 67.65343174338341, 74.21728312969208, 41.62120722234249, 25.054079107940197, 6.151708401739597, 0.23395107127726078, 0.0838703612680547, 0.06844347852165811, 0.06559357207152061, 0.07999808702152222, 0.1103595265885815, 0.2131740385084413, 0.4402362130349502, 0.28058089257683605, 0.24924501311033964, 0.37894719396717846, 0.728968974435702, 1.1220964137464762, 1.7240367201156914, 0.99795505637303, 2.2835995629429817, 5.072912564501166, 7.486833734437823, 7.699552970007062, 8.185587264597416, 5.212565045803785, 4.567063758149743, 6.660992223769426, 5.216760970652103, 4.3983399868011475, 2.2894543362781405, 0.7214264385402203, 0.6335536006372422, 0.4167898977175355, 0.7161530340090394, 0.643990037497133, 0.21268965356284752, 1.8819148046895862, 4.935795022174716, 17.574807442724705, 22.700614593923092, 24.306699112057686, 22.038551419973373, 8.296944089233875, 2.385788904502988, 1.7221965501084924, 5.260068196803331, 4.7889310028404, 6.709561692550778, 3.531844220124185, 4.877655291929841, 5.876418398693204, 2.319525210186839, 1.122119331266731, 0.6060987082310021, 0.4790725337807089, 2.9294680058956146, 1.7568073491565883, 1.9692939659580588, 0.41918703471310437, 0.03674855543067679, 0.1426628846093081, 0.2218170161359012, 0.49033946357667446, 0.11516989034134895, 0.28363396937493235, 0.23326701892074198, 0.13582964893430471, 0.15739556984044611, 0.028807217204303015, 0.10360403088270687, 0.18805936037097126, 1.5913525898940861, 17.363067604601383, 50.609499514102936, 69.11262944340706, 42.458739280700684, 22.274205274879932, 21.052990704774857, 43.174195289611816, 32.506841495633125, 12.84896682947874, 18.68873666971922, 20.65220721065998, 35.40447100996971, 50.545484349131584, 58.33165034651756, 74.3494476377964, 73.30802232027054, 27.1957353875041, 1.4434080035425723, 0.1021921617211774, 0.11775169594329782, 0.11357675903127529, 0.07009718392509967, 0.03521337472193409, 0.01937154978804756, 0.10526181809836999, 0.09900057790218852, 0.11597438584431075, 0.06899789252202027, 0.06638036735239439, 0.12267687736311927, 0.04324571695178747, 0.05230077207670547, 0.0508741193334572, 0.08411725895712152, 0.034492689956096, 0.04229000514897052, 0.041375163418706506, 0.0402492697321577, 0.04367511617601849, 0.04241740964062046, 0.08606452829553746, 0.02974571118102176, 0.015183126197371166, 0.06213883752934635, 0.02753242828475777, 0.05848571949172765, 0.06978913326747715, 0.11056602917960845, 0.05461434324388392, 0.025839209083642345, 0.05163414534763433, 0.04342859327152837, 0.04817117296624929, 0.05911527594435029, 0.01663504164753249, 0.027856717133545317, 0.04231622522638645, 0.02110748886479996, 0.05501232735696249, 0.046362098946701735, 0.029423119995044544, 0.05439527980342973, 0.06329866591840982, 0.03179435974743683, 0.027222793141845614, 0.06681669823592529, 0.04190239997114986, 0.02585711896244902, 0.026004233041021507, 0.03243774612201378, 0.020718610903713852, 0.09809619674342684, 0.04914965757052414, 0.023276315259863622, 0.03604312179959379, 0.022269501023401972, 0.04410516477946658, 0.07820634957170114, 0.05152071920747403, 0.011543792625161586, 0.02604555025754962, 0.039394367558998056, 0.05120343623275403, 0.054600643197773024, 0.04583928188367281, 0.027386379188101273, 0.049417840054957196, 0.1748653847607784, 0.113359398819739, 2.4325852934271097, 21.77543453872204, 59.155016764998436, 72.50222235918045, 80.97678601741791, 71.96352526545525, 61.4254405349493, 45.56954115629196, 41.72229319810867, 38.26732479035854, 24.419615752995014, 19.336410015821457, 34.982575848698616, 48.46740625798702, 65.7967221736908, 51.58830799162388, 34.46175679564476, 24.320822954177856, 6.687730439007282, 0.20089680823730305, 0.03931669438316021, 0.03893613589752931, 0.047889383204164915, 0.08293209364637733, 0.13830707146553323, 0.6504012434743345, 0.7918994163628668, 0.6631580495741218, 0.9366269409656525, 2.1483375085517764, 2.4370479164645076, 3.3378902776166797, 3.203388419933617, 3.0408597411587834, 4.532285649329424, 6.606164965778589, 5.9674016665667295, 8.346272092312574, 9.256306160241365, 6.8868079315871, 7.717431485652924, 5.489630503579974, 9.145176373422146, 5.761260828003287, 6.702916799113154, 1.5523846121504903, 2.2648468567058444, 0.9355933964252472, 0.8429268188774586, 0.4072955728042871, 0.8778950362466276, 2.1747242426499724, 4.652930125594139, 13.509228900074959, 19.00492910295725, 21.49556055665016, 19.788129776716232, 7.330456925556064, 2.200106643140316, 1.0096374107524753, 5.881219441071153, 6.347671961411834, 7.977249193936586, 4.759232746437192, 4.569820035248995, 3.7642694357782602, 3.929422586224973, 5.436359262093902, 6.404334995895624, 5.657123140990734, 4.468128941953182, 4.768992522731423, 2.172653116285801, 1.5472148708067834, 2.0398155692964792, 1.906955698505044, 1.3263791520148516, 1.1764738708734512, 0.5082376906648278, 0.47963392396923155, 0.24331577267730609, 0.18177841615397483, 0.13972702261526138, 0.05841319311002735, 0.062178416264941916, 0.028416161039785948, 1.8799873581156135, 18.56115471571684, 43.253101855516434, 56.08500950038433, 33.96740712225437, 26.17144525051117, 35.360286980867386, 55.251315236091614, 35.20250044763088, 16.607417352497578, 35.41626937687397, 32.745453491806984, 45.36833055317402, 57.09700159728527, 66.36763393878937, 80.14874964952469, 85.54104790091515, 43.50422278046608, 5.22627423517406, 0.19888408889528364, 0.20561195444315672, 0.021917270314588677, 0.03133614663966, 0.04579305350489449, 0.08085620269412175, 0.046250346349552274, 0.08216118032578379, 0.05416479099949356, 0.09228949231328443, 0.030649973596155178, 0.04803121875738725, 0.05674708270817064, 0.03555704475729726, 0.02516961561923381, 0.040358432233915664, 0.007180853008321719, 0.04278828309907112, 0.020588159895851277, 0.04134830509428866, 0.0058192049800709356, 0.07806923778844066, 0.06849151774076745, 0.011273021900706226, 0.004499550914260908, 0.05618595598207321, 0.009560990183672402, 0.01782822400855366, 0.060625346086453646, 0.019551917648641393, 0.03868078885716386, 0.045391937528620474, 0.05596823953965213, 0.07312493122299202, 0.06706784100970253, 0.022372358980646823, 0.02295776877872413, 0.012991114181204466, 0.14601659058826044, 0.1321985133108683, 0.15417786984471604, 0.1338750249124132, 0.12743117928039283, 0.14301182760391384, 0.2732699958141893, 0.146469107712619, 0.08395066164666787, 0.23432417860021815, 0.1076326756447088, 0.07633801506017335, 0.13032089453190565, 0.07405837488477118, 0.13140431139618158, 0.22035373840481043, 0.16542634984944016, 0.20733326207846403, 0.09412607774720527, 0.09011301808641292, 0.19942744489526376, 0.20231916394550353, 0.16631290462100878, 0.1733113720547408, 0.10255690503981896, 0.14859037357382476, 0.13465690717566758, 0.4071045439923182, 0.1291104665142484, 0.22418065258534625, 0.19840513647068292, 0.37628481339197606, 0.24251943337731063, 3.678561234846711, 29.877156503498554, 70.6557646393776, 82.30775579810143, 90.56459873914719, 79.78749543428421, 71.82770535349846, 51.467231288552284, 44.10061217844486, 41.33550055325031, 23.479705788195133, 14.728076197206974, 41.732594445347786, 59.49102893471718, 83.06861937046051, 90.4793693125248, 57.992005571722984, 37.04158276319504, 9.692792538553476, 0.7086052140221, 0.26520958926994354, 0.4999129311181605, 0.19340510945767164, 0.1729574566707015, 0.14561980875441805, 0.639480451354757, 0.9387408150359988, 0.9229787858203053, 1.2732181046158075, 1.6176566784270108, 2.766667166724801, 3.221989134326577, 4.398835860192776, 3.9892724622040987, 7.822608891874552, 14.289935007691383, 19.04062058776617, 14.884872883558273, 18.767401948571205, 14.12765521556139, 16.350079961121082, 13.268719855695963, 18.321053199470043, 13.95166290923953, 11.577287167310715, 2.842430113814771, 2.5572136184200644, 2.389457132667303, 1.2611252535134554, 1.2665272573940456, 1.9410895043984056, 4.607465090230107, 5.320803662762046, 14.331154245883226, 18.544217124581337, 18.0422792583704, 18.89914657920599, 7.920143958181143, 2.518439549021423, 7.745701493695378, 12.989853769540787, 11.349065713584423, 14.924348965287209, 11.492109037935734, 17.384544052183628, 18.603967018425465, 12.314527407288551, 11.535433363169432, 10.88250869885087, 8.384840972721577, 7.653819099068642, 6.282686898484826, 5.617101788520813, 2.0837521366775036, 2.1675566397607327, 1.2201550207100809, 0.907828405033797, 1.5796454180963337, 0.3633003163849935, 0.5962426902260631, 0.5381354363635182, 0.35420523723587394, 0.2762401005020365, 0.22298156458418816, 0.32125865982379764, 0.37034680077340454, 2.901275656186044, 23.677148893475533, 67.90606498718262, 91.73052057623863, 61.07114374637604, 37.057435512542725, 33.320780619978905, 55.175383910536766, 47.9202052205801, 25.35698365420103, 31.112517714500427, 35.354104712605476, 53.876765593886375, 69.3053551018238, 78.09418469667435, 88.68288651108742, 95.66505745053291, 49.3854483962059, 4.693471575155854, 0.2975222538225353, 0.21726839302573353, 0.21002629335271195, 0.20995201921323314, 0.14271793712396175, 0.13571682764450088, 0.17129851912613958, 0.22501595463836566, 0.2726950391661376, 0.1557885084184818, 0.17906315013533458, 0.14998926257248968, 0.12943010951858014, 0.11804070309153758, 0.20907873404212296, 0.13005625951336697, 0.12425247914507054, 0.12013210493023507, 0.13772295671515167, 0.15148529870202765, 0.1245774285052903, 0.21656010212609544, 0.10768965774332173, 0.10692627722164616, 0.07605677077663131, 0.19352401635842398, 0.08066010501352139, 0.10585098687442951, 0.13641924073453993, 0.1417533084168099, 0.14247443847125396, 0.1483164171804674, 0.16335243301000446, 0.24344379315152764, 0.2215378498658538, 0.15348808810813352, 0.16639500099699944, 0.1780187850818038], [0.0716456824738998, 0.10316279440303333, 0.05149598713614978, 0.04899843013845384, 0.08921188753447495, 0.15212354570394382, 0.05000281198590528, 0.008720490313862683, 0.0674903902108781, 0.15768684796057642, 0.17544261238072067, 0.18172149342717603, 0.08579678367823362, 0.06830701982835308, 0.059554657054832205, 0.022775673569412902, 0.035152103009750135, 0.07066559483064339, 0.043464758127811365, 0.061132091941544786, 0.1600292738294229, 0.028338458178041037, 0.03619397815782577, 0.19500707974657416, 0.035603536598500796, 0.08344476926140487, 0.06471097294706851, 0.05745268703321926, 0.09631242995965295, 0.22297598363365978, 0.35242084704805166, 0.10277491091983393, 3.783042090944946, 17.23484918475151, 49.82494421303272, 66.65223106741905, 61.42340384423733, 47.102109119296074, 50.96906282007694, 37.0089653134346, 25.800822637975216, 16.920938529074192, 17.412770837545395, 26.617182232439518, 36.74591302871704, 33.64775687456131, 37.09642142057419, 45.99780857563019, 47.66382157802582, 25.622053630650043, 7.819461235776544, 0.04782048592460342, 0.08465304505079985, 0.06967154738958925, 0.03355921289767139, 0.07608611529576592, 0.1748716039583087, 0.5860761576332152, 0.9057192807085812, 1.1649106163531542, 1.7206169036217034, 1.083879608195275, 1.943864542990923, 2.0520594622939825, 1.871766617987305, 1.6846075421199203, 1.6266955621540546, 2.3955966532230377, 6.561990436166525, 3.8341073133051395, 8.940750192850828, 5.997440479695797, 11.083172131329775, 3.6866393638774753, 6.544731762260199, 5.3134771808981895, 4.5089093036949635, 2.401697225868702, 1.0025422414764762, 0.7612411770969629, 0.30425899545662105, 0.6172427977435291, 1.5971430041827261, 1.8631241004914045, 17.77899708598852, 58.99824857711792, 85.6818151473999, 68.5627381503582, 71.06390073895454, 62.76123605668545, 60.319791063666344, 29.3489221483469, 6.924123354256153, 8.689805958420038, 2.6183630246669054, 6.71713943593204, 2.076141620054841, 2.548728911206126, 2.1654145047068596, 1.7543764295987785, 2.230645604431629, 2.853546179831028, 4.674271680414677, 4.175604963675141, 3.7013412499800324, 2.324083778075874, 1.5692139090970159, 2.182712364010513, 2.294053277000785, 0.49087217717897147, 0.20858900563325733, 0.2152603937429376, 0.05500892089912668, 0.039673652572673745, 0.12334132959949784, 0.09689533500932157, 0.057578084015403874, 0.038720441807527095, 0.11706920951837674, 0.01464843569920049, 0.15804469672730193, 8.08462668210268, 28.187047094106674, 55.162658393383026, 49.47847120463848, 34.42580312490463, 24.34543803334236, 42.560228034853935, 47.375968024134636, 27.113692089915276, 32.77927927672863, 42.729672342538834, 30.718406662344933, 46.727297231554985, 72.94571176171303, 75.73449611663818, 79.45781752467155, 50.29168076813221, 7.769828299060464, 0.47613074944820255, 0.24320850265212357, 0.12127533147577196, 0.0242616999821621, 0.04072238887601998, 0.07609974112710916, 0.2633578417589888, 0.048132165684364736, 0.17517655243864283, 0.09598456395906396, 0.18290474399691448, 0.1926254536374472, 0.1791730770491995, 0.05662513671268243, 0.01928629742906196, 0.10476331750396639, 0.04991750953195151, 0.04704614017100539, 0.05908209081098903, 0.0187331896086107, 0.12933826132211834, 0.008088149879768025, 0.03704134753206745, 0.07450795310433023, 0.007745851889922051, 0.044297358763287775, 0.11454276813310571, 0.054255451759672724, 0.19732428743736818, 0.07140475907362998, 0.04266876763722394, 0.032999229078995995, 0.07492134420317598, 0.047476545005338266, 0.036236941086826846, 0.0642603482992854, 0.12446885972167365, 0.07390472805127501, 0.039420357570634224, 0.03322496442706324, 0.02708297994104214, 0.006689174606435699, 0.01858438343333546, 0.0238898394673015, 0.030598926823586226, 0.02616384117573034, 0.10031593075837009, 0.15290792158339173, 0.03452620163443498, 0.01774963613570435, 0.08736692325328477, 0.0506405840133084, 0.0560196592414286, 0.06330426913336851, 0.04727651765279006, 0.051460453105391935, 0.05597017654508818, 0.130779170722235, 0.048623853363096714, 0.0521013792604208, 0.19188716512871906, 0.025359052524436265, 0.07104583419277333, 0.043105209842906334, 0.03461804983089678, 0.0860839057713747, 0.16229981527430937, 0.29668157862033695, 0.08576913867727853, 3.5253945412114263, 20.751999355852604, 61.46759547293186, 77.97952204942703, 71.1624750494957, 57.833029702305794, 60.66668584942818, 49.719549268484116, 38.237853571772575, 24.1844292730093, 29.575441293418407, 29.620964750647545, 22.998851090669632, 36.457626298069954, 37.580838426947594, 50.65670058131218, 45.7845564186573, 24.31540634483099, 8.429022151976824, 0.05987294192891568, 0.10963925742544234, 0.11341288540279493, 0.1274954344262369, 0.22942999668885022, 0.6526829022914171, 1.0213720123283565, 2.114038886502385, 3.3883651066571474, 4.870793335139751, 2.228337465785444, 3.8925251411274076, 4.083195347338915, 5.312114953994751, 3.7308260053396225, 5.319635700434446, 4.490153510123491, 10.198032427579165, 8.632239997386932, 9.028439987450838, 7.434173310175538, 8.711861874908209, 7.2742099687457085, 6.826371224597096, 7.601208072155714, 6.054578488692641, 2.979631726630032, 1.260137187782675, 3.3384987199679017, 1.1534448503516614, 0.3328668588073924, 3.0046662082895637, 2.3619088483974338, 20.439357832074165, 60.08079908788204, 94.45232972502708, 77.5964418053627, 80.76143637299538, 73.74606281518936, 63.95181477069855, 32.56188154220581, 7.358466647565365, 3.845434980466962, 4.438888086006045, 4.858807353302836, 2.908316678367555, 5.9343082923442125, 2.752008503302932, 4.814441883936524, 1.946805703919381, 2.9656553640961647, 3.2914548693224788, 2.2323552751913667, 3.872832697816193, 3.177499221637845, 2.1855595987290144, 3.770424393005669, 4.798272801563144, 1.1896268650889397, 1.7983336583711207, 2.3591739451512694, 1.1957650794647634, 0.42780607065651566, 0.23413616290781647, 0.11483156747999601, 0.19155060115735978, 0.0314786538365297, 0.03127652991679497, 0.024687776240170933, 0.12282278359634802, 5.750611424446106, 24.730524569749832, 50.3966349363327, 49.463826790452, 31.41584973782301, 33.167816027998924, 45.49424059689045, 34.13329102098942, 18.11831507831812, 26.95302151143551, 48.720746263861656, 40.5838742852211, 54.58464100956917, 75.56865021586418, 83.68762135505676, 93.06910514831543, 68.51821973919868, 14.31719284504652, 0.5928411602508277, 0.22709609067533165, 0.06915720936376601, 0.028746938114636578, 0.01086225707695121, 0.08937967970268801, 0.2015255854348652, 0.05210399533098098, 0.11434043641202152, 0.06682697698124684, 0.08939291219576262, 0.07025828192126937, 0.09722568720462732, 0.0474809644947527, 0.015335743300965987, 0.04964488158293534, 0.04944430504110642, 0.023634037861484103, 0.036756388799403794, 0.09021167919854634, 0.03984280658187345, 0.03788066089327913, 0.022990812904026825, 0.09937600072589703, 0.039866388324298896, 0.0665755892987363, 0.04776333684276324, 0.12405278946971521, 0.15486267919186503, 0.02288749295985326, 0.0036455527697398793, 0.023382822728308383, 0.010257266640110174, 0.03709937976964284, 0.04746819213323761, 0.09183589907479472, 0.1283011247869581, 0.19082411279669032, 0.17686887178570032, 0.16537533461814746, 0.21348223759559914, 0.2981419471325353, 0.2511523920111358, 0.09500924090389162, 0.1321734138764441, 0.1962587860180065, 0.2628006669692695, 0.2998289972310886, 0.20055123459314927, 0.11873434399603866, 0.21757144160801545, 0.17328180489130318, 0.19289611489512026, 0.21870682365261018, 0.2262616198277101, 0.21787774079712108, 0.2963532228022814, 0.260085059562698, 0.13638314267154783, 0.16494037670781836, 0.33278062124736607, 0.1832120376639068, 0.1392791364924051, 0.233431983506307, 0.1537034593638964, 0.20954364503268152, 0.4128528042929247, 0.4669614555314183, 0.2840717771323398, 4.607949564233422, 28.56427565217018, 71.32116973400116, 85.70980444550514, 81.10785618424416, 66.30362257361412, 69.47519078850746, 53.995163440704346, 41.11980892717838, 26.480406671762466, 27.887818850576878, 39.73986737430096, 53.032469898462296, 47.640487030148506, 53.38901236653328, 59.06004086136818, 59.9838624894619, 38.87995071709156, 11.308614034205675, 0.2416901575634256, 0.2275810544961132, 0.2937796921469271, 0.2351704050670378, 0.2711424959124997, 0.5609103455208242, 1.5280847973190248, 2.4386533303186297, 3.0403375066816807, 4.732760041952133, 3.5485958587378263, 6.503268387168646, 7.731026681140065, 9.243093319237232, 6.064253719523549, 8.180642779916525, 10.521508120000362, 20.504668727517128, 14.538516718894243, 21.327480375766754, 18.664782755076885, 23.4147634729743, 15.253311563283205, 17.816689163446426, 16.743925027549267, 18.019809164106846, 5.67565712146461, 2.733877063728869, 2.701386669650674, 0.8916231652256101, 1.8055196665227413, 3.5759441787377, 4.199541779235005, 22.5331898778677, 60.96419848501682, 85.19919544458389, 70.063057243824, 73.21637123823166, 61.93839021027088, 56.25281609594822, 33.06997127830982, 11.222784239798784, 20.177257396280766, 9.459913484752178, 16.753118634223938, 8.884424865245819, 11.520388070493937, 7.680026767775416, 9.066009521484375, 8.120562303811312, 11.198029518127441, 13.684593290090561, 13.638115134090185, 10.707479640841484, 7.249315604567528, 6.8606192618608475, 6.919197393581271, 8.600913528352976, 4.6511793695390224, 2.538646152243018, 2.1488248324021697, 0.8204251388087869, 0.2497363742440939, 0.14753711759112775, 0.18986086448421702, 0.20570265973219648, 0.1937111117877066, 0.1819199140300043, 0.3019308188231662, 0.47694726032204926, 11.551327910274267, 36.9144681841135, 76.09625190496445, 66.66300728917122, 49.75916214287281, 35.71336403489113, 51.207747012376785, 61.45998828113079, 38.90333466231823, 45.39977386593819, 58.79231482744217, 46.98567196726799, 62.50765286386013, 88.16502749919891, 93.4637139737606, 104.00554150342941, 76.73955738544464, 15.280358511954546, 1.3160743424668908, 0.4407050128793344, 0.32637006836012006, 0.19284585665445775, 0.09927379956934601, 0.11027846921933815, 0.4511735698906705, 0.184950859984383, 0.30975014611613005, 0.33395452075637877, 0.2667030575685203, 0.28716071450617164, 0.3310175455408171, 0.11860466853249818, 0.09934203262673691, 0.2841623191488907, 0.19810778758255765, 0.09537955033010803, 0.1932339256745763, 0.10162737991777249, 0.1684594777179882, 0.12095843441784382, 0.09457063162699342, 0.24429646146018058, 0.130607467435766, 0.13673017092514783, 0.1638862895197235, 0.21361681865528226, 0.3043940366478637, 0.14662944129668176, 0.12623768707271665, 0.145455734746065, 0.18994101643329486, 0.15463489922694862, 0.1882943243253976, 0.3610444546211511, 0.2564456267282367], [0.09835634176852182, 0.028525223351607565, 0.021760704985354096, 0.06901258704601787, 0.20931843289872631, 0.12399485742207617, 0.03836158000922296, 0.02015345246036304, 0.15028174297185615, 0.14809289714321494, 0.21256866864860058, 0.12174954157671891, 0.0490538574376842, 0.023503724150941707, 0.18097606545779854, 0.12248532904777676, 0.06269337027333677, 0.055025489346007816, 0.03217472156393342, 0.22152119607198983, 0.0892744654265698, 0.0762470648624003, 0.039843470804044046, 0.03563756406947505, 0.2825048955855891, 0.09984758362406865, 0.07962532108649611, 0.18106173898559064, 0.2573366789147258, 0.16013223939808086, 0.23084552463842556, 1.4146558963693678, 15.77699376270175, 45.784651413559914, 69.83731895685196, 62.11638405919075, 62.07326017320156, 52.34477899968624, 32.08568349480629, 21.731567792594433, 18.007186241447926, 27.844427078962326, 21.861879900097847, 37.21582241356373, 57.14181259274483, 40.61921998858452, 51.542581245303154, 38.653011694550514, 16.50052908807993, 4.38734432682395, 0.1627121228375472, 0.04475018387893215, 0.07676089822780341, 0.05807287758216262, 0.04109089859412052, 0.3166310128290206, 0.4981492320075631, 1.047305976971984, 2.0837006019428372, 1.966461930423975, 1.2651494750753045, 1.384175713174045, 3.9318943535909057, 2.7747747441753745, 5.080982381477952, 4.018250657245517, 3.503635721281171, 2.3483632877469063, 4.99193605966866, 5.599187649786472, 4.197227703407407, 6.776570621877909, 2.2123795095831156, 5.70595289580524, 2.8201117739081383, 6.7903876304626465, 4.9679056741297245, 5.976991401985288, 1.5674347733147442, 4.185871062800288, 1.8849128438159823, 5.245064701884985, 6.048854095861316, 11.383622009307146, 45.21623231470585, 70.28766319155693, 58.749050348997116, 54.12099368870258, 58.11565853655338, 60.197167843580246, 66.2720462679863, 60.61755068600178, 39.759459123015404, 16.982766911387444, 5.360938059166074, 5.269001517444849, 2.053758683614433, 2.877169749699533, 1.0332353319972754, 3.0015045404434204, 4.4338305573910475, 6.13108548335731, 5.095882806926966, 1.348881188314408, 3.647747738286853, 1.194062177091837, 1.1013894248753786, 2.7624344313517213, 3.7445245077833533, 1.9083611480891705, 0.5920587584841996, 1.4640291407704353, 0.6083913508336991, 0.2177193813258782, 0.07748183532385156, 0.11818534025223926, 0.0667491924832575, 0.006035074866304058, 0.0883238113601692, 0.16043883544625714, 0.00816880185084301, 0.0744852508069016, 1.3623924320563674, 13.590989112854004, 39.47276070713997, 57.67157256603241, 41.792878210544586, 48.44540923833847, 71.10162511467934, 103.16302791237831, 88.1023308634758, 62.51975901424885, 31.982211247086525, 43.28195370733738, 60.72439715266228, 52.95936182141304, 62.656806260347366, 77.17037066817284, 63.53343062102795, 13.713740576058626, 0.2087794555700384, 0.2717254380695522, 0.15982754324795678, 0.22639572591288015, 0.17045546905137599, 0.16760461265221238, 0.10152279646717943, 0.06489930776297115, 0.02661974991497118, 0.13833019678713754, 0.14659028558526188, 0.1275489284307696, 0.13321636884938926, 0.037727422241005115, 0.08345950089278631, 0.0543362382450141, 0.18853339977795258, 0.04358947975561023, 0.06567501535755582, 0.015857046382734552, 0.055092894908739254, 0.11231170152314007, 0.0773425045190379, 0.032499952940270305, 0.023285107854462694, 0.06656286888755858, 0.0922311817703303, 0.10205023339949548, 0.08855605905409902, 0.12475308001739904, 0.06255472224438563, 0.08772623405093327, 0.06271046193432994, 0.06159939264762215, 0.10430497452034615, 0.05728895070205908, 0.08774288042332046, 0.13060611672699451, 0.040811164581100456, 0.09665683843195438, 0.08439073295448907, 0.07656347210286185, 0.04910452385956887, 0.05444318172521889, 0.0630204941262491, 0.07871224195696414, 0.10733733797678724, 0.13439173781080171, 0.058598050964064896, 0.05888797095394693, 0.12444320367649198, 0.12583937641466036, 0.08318507694639266, 0.01998046711378265, 0.03801589504291769, 0.1545452923164703, 0.045178109940025024, 0.07787380061927252, 0.020961393383913673, 0.03334819062729366, 0.17035133088938892, 0.15134323679376394, 0.06176904760650359, 0.18552730092778802, 0.2846895408583805, 0.03548461485479493, 0.14709279377711937, 1.8072649603709579, 20.414731353521347, 59.85238194465637, 79.9024772644043, 72.14437276124954, 69.9221608042717, 57.367467284202576, 41.867225021123886, 31.70731119811535, 26.48819625377655, 31.1599999666214, 19.93210595101118, 36.98738247156143, 55.432158932089806, 41.906834095716476, 44.19288642704487, 41.02117761969566, 19.530695490539074, 4.48887012898922, 0.03646447614300996, 0.16261669748928398, 0.13661285222042352, 0.4511797445593402, 0.6996717152651399, 0.9239919064566493, 0.9533348225522786, 1.9587190146557987, 2.124947151169181, 4.3586634658277035, 5.292213521897793, 3.532888451591134, 5.325713949277997, 4.776135664433241, 5.626230798661709, 4.7747397143393755, 4.729560613632202, 3.4216275718063116, 8.543927036225796, 7.287829387933016, 3.5397644201293588, 7.504609655588865, 4.822531174868345, 3.95112797152251, 2.9205890698358417, 2.435611831024289, 2.691717376001179, 2.8448683954775333, 2.1873678267002106, 2.246864796616137, 1.9932148698717356, 5.561766782775521, 7.464444860816002, 13.912297021597624, 49.97196212410927, 82.30144053697586, 72.41551101207733, 64.20081540942192, 66.7224968969822, 72.67747655510902, 78.82800132036209, 68.9620891213417, 44.8670956492424, 16.135746762156487, 2.9001124436035752, 2.236624821089208, 1.8173719430342317, 0.5152239720337093, 0.9258795739151537, 2.1860229363664985, 0.5783889326266944, 2.174015580676496, 1.0416924906894565, 0.6528031302150339, 0.629308515926823, 0.8578318753279746, 1.2109618890099227, 2.5384929729625583, 3.0586843471974134, 1.3390366290695965, 1.2973546469584107, 3.0154628539457917, 1.8932541087269783, 2.4111154954880476, 0.7729359995573759, 0.28898657590616494, 0.23415177769493312, 0.2751665096729994, 0.23074974305927753, 0.08544479045667686, 0.06490041356300935, 0.07460066219209693, 1.4797269296832383, 13.117490820586681, 31.886547580361366, 51.98770835995674, 38.07275243103504, 48.00700016319752, 67.29883477091789, 78.4338028728962, 81.20620250701904, 69.36958685517311, 41.95370078086853, 50.1632172614336, 69.37942072749138, 61.088736802339554, 67.08339393138885, 84.07317906618118, 79.52666983008385, 22.12478779256344, 0.287415508646518, 0.23954842326929793, 0.14721921121235937, 0.174428719910793, 0.1817634841427207, 0.1378935616230592, 0.06183870558743365, 0.022538323610206135, 0.05772426855401136, 0.03824633931799326, 0.08805680889054202, 0.2510861330665648, 0.050271346990484744, 0.03461684384092223, 0.0779040357156191, 0.09061586766620167, 0.025101608916884288, 0.03988320539065171, 0.05444017231639009, 0.02852852219803026, 0.03983849841461051, 0.06832612270954996, 0.015508775031776167, 0.025204472440236714, 0.08236449168180116, 0.03909607985406183, 0.05614105975837447, 0.06477142087533139, 0.07183596913819201, 0.01895277626317693, 0.03766294816159643, 0.04846148629439995, 0.11500081425765529, 0.05483444198034704, 0.13458846631692722, 0.12681614665780216, 0.37230313173495233, 0.2955579967238009, 0.10880094967433251, 0.2231314784148708, 0.3703350748401135, 0.3593825484858826, 0.12213838985189795, 0.12668267881963402, 0.24731585959671065, 0.34722661483101547, 0.382216265425086, 0.31736835138872266, 0.15990067448001355, 0.17259657994145527, 0.43192163575440645, 0.25326593953650445, 0.16203195933485404, 0.16091467085061595, 0.13755630003288388, 0.363792241550982, 0.2576611755648628, 0.2655877877259627, 0.09687120036687702, 0.13252115459181368, 0.4746344609884545, 0.296476092771627, 0.21969322697259486, 0.4548759071622044, 0.5046714039053768, 0.3885674464982003, 0.4471116769127548, 2.529227170161903, 27.626541070640087, 71.16601645946503, 89.00216817855835, 79.99279841780663, 79.75265130400658, 68.70447814464569, 47.92379982769489, 34.383374601602554, 30.358013100922108, 43.279514238238335, 32.11335361003876, 54.77354407310486, 76.19938597083092, 55.39517931640148, 68.52203473448753, 55.14487914741039, 27.619325257837772, 7.418405106291175, 0.2064572012750432, 0.4253797821002081, 0.1720701003796421, 0.6052735587581992, 0.5281874514184892, 1.3449919782578945, 0.7805067370645702, 2.564344173297286, 4.80249959975481, 5.4469516687095165, 5.6580436415970325, 6.492163958027959, 11.120013054460287, 14.599002823233604, 16.811762787401676, 14.336499609053135, 14.124990608543158, 12.914784997701645, 12.663123551756144, 13.55777034536004, 15.34494649618864, 17.749696858227253, 13.575558140873909, 15.772930830717087, 11.717594638466835, 19.440965205430984, 10.91471292078495, 17.103144451975822, 7.824974739924073, 10.511889886111021, 4.8954179137945175, 8.70558651164174, 13.360604625195265, 17.142740227282047, 58.51415455341339, 80.82518935203552, 72.63700872659683, 66.06615051627159, 68.1923720240593, 71.29776298999786, 76.46248385310173, 65.7277862727642, 52.60343112051487, 25.32842628657818, 11.08807671815157, 11.484004072844982, 8.315478544682264, 7.092420598492026, 5.007902327924967, 9.147613942623138, 10.89950518682599, 15.444311164319515, 13.71118426322937, 9.035833440721035, 10.694796871393919, 5.124910399317741, 5.040364461019635, 8.28808106482029, 10.7157470472157, 6.71970714814961, 4.33808614499867, 6.105980230495334, 4.871905250474811, 2.437240043655038, 0.8331529120914638, 0.30670342210214585, 0.2053100339253433, 0.22618443646933883, 0.3364397358382121, 0.43662652547936887, 0.19121293880743906, 0.23306671326281503, 2.4145614355802536, 19.249556176364422, 52.59511336684227, 76.63685649633408, 60.03017820417881, 64.35976088047028, 79.09271031618118, 108.56612518429756, 100.20335912704468, 75.32648921012878, 44.7275747358799, 59.98852103948593, 79.74929228425026, 73.98988053202629, 78.87979254126549, 93.93038213253021, 90.4706297814846, 25.50034236162901, 0.7239809702150524, 0.4058553313370794, 0.3431433183141053, 0.37031741172540933, 0.3421908162999898, 0.278237308957614, 0.39980409666895866, 0.33389998774509877, 0.2550406818045303, 0.2654730516951531, 0.35181472019758075, 0.36426576145458966, 0.22124631941551343, 0.1437771154451184, 0.30971885717008263, 0.21881629043491557, 0.2380085558979772, 0.2596511406591162, 0.19097944430541247, 0.14937247848138213, 0.09008681285195053, 0.25038403167854995, 0.22506794950459152, 0.16874858876690269, 0.25688215799164027, 0.2266680941102095, 0.33241673139855266, 0.20938610192388296, 0.13407317834207788, 0.22705205163219944, 0.22413030528696254, 0.1906525282538496, 0.15058716642670333, 0.1591910922434181, 0.4570076521486044, 0.23015529761323705], [0.022599400508624967, 0.031070589502633084, 0.03401903646590654, 0.06810126680647954, 0.07402489660307765, 0.06873707214253955, 0.06206397709320299, 0.042885393122560345, 0.0712292263051495, 0.12646343355299905, 0.07317059556953609, 0.045478223328245804, 0.019260893714090344, 0.09409410602529533, 0.12986039189854637, 0.009767637493496295, 0.1050293403386604, 0.014608779038098874, 0.022048172177164815, 0.04778216884005815, 0.06092186376918107, 0.06516406894661486, 0.02278264975757338, 0.08918539286241867, 0.15514717408223078, 0.10731842805398628, 0.05869586231710855, 0.22735662903869525, 0.06286827963776886, 0.061661191284656525, 0.10197601863183081, 12.332836724817753, 51.07043758034706, 59.2044673115015, 63.154321163892746, 63.63433040678501, 44.067299365997314, 34.52109821140766, 26.6548116132617, 20.132822580635548, 22.785450741648674, 22.59866986423731, 41.803236454725266, 43.34602206945419, 33.453541696071625, 45.54208382964134, 28.69866494089365, 7.2499563451856375, 0.8398261258844286, 0.03251107031246647, 0.24125200841808692, 0.09072917877347209, 0.1182036564568989, 0.041831517446553335, 0.4016982653411105, 0.5183621286414564, 1.16179003380239, 1.2844195473007858, 1.0050306329503655, 5.449368814006448, 9.520662724971771, 3.1353932060301304, 2.456680038012564, 1.82691311230883, 2.6642225263640285, 3.5685932356864214, 4.060807898640633, 3.504367657005787, 9.836827609688044, 11.225751880556345, 7.163732321932912, 13.300465252250433, 9.482023548334837, 7.843664512038231, 9.324751887470484, 11.21934162452817, 9.212308321148157, 10.418146066367626, 7.786875609308481, 13.31072660163045, 14.99990601092577, 17.116172052919865, 23.41251779347658, 29.86386101692915, 39.9119221419096, 51.45523153245449, 41.3976576179266, 53.608112409710884, 50.520626083016396, 56.02682702243328, 46.719245463609695, 49.602352157235146, 49.63379926979542, 31.91960960626602, 12.681176383048296, 8.214118033647537, 8.151057567447424, 9.769206438213587, 4.712864784523845, 5.62979880720377, 3.023893414065242, 7.041325690224767, 2.8824448166415095, 0.5123054317664355, 1.2470512837171555, 2.034517703577876, 1.1145589244551957, 2.530019427649677, 3.3600675500929356, 0.4969591536791995, 1.7235895316116512, 2.814692077226937, 1.8932543462142348, 2.3816901119425893, 0.6381955265533179, 0.29939389089122415, 0.428310998249799, 0.17196179134771228, 0.026317495430703275, 0.049035730480682105, 0.10978966849506833, 0.11571272683795542, 0.018263801612192765, 0.7202891714405268, 8.961327038705349, 33.28755900263786, 51.130432561039925, 69.29407730698586, 67.63630226254463, 58.76955024898052, 64.65611457824707, 107.76170074939728, 81.09567403793335, 37.049376145005226, 42.66838163137436, 47.118136659264565, 59.9540188908577, 59.02818337082863, 73.93874287605286, 65.96724942326546, 17.11249005049467, 0.12196239695185795, 0.09492119250353426, 0.10572776067419909, 0.12893070350401103, 0.06779372823075391, 0.04052862153912429, 0.036305081375758164, 0.07767162474920042, 0.016282870310533326, 0.06954789816518314, 0.010825678473338485, 0.06944402717635967, 0.06870092955068685, 0.01577777944476111, 0.04988538195902947, 0.06074077231460251, 0.07727000411250629, 0.025687168999866117, 0.07019713637419045, 0.08675511155161075, 0.10473458154592663, 0.05152955818630289, 0.039095000029192306, 0.05340704708942212, 0.017075120376830455, 0.08432064452790655, 0.06904833629960194, 0.01906120960484259, 0.09389234575792216, 0.052734846831299365, 0.10769117914605886, 0.11323813188937493, 0.05047286977060139, 0.08778176896157674, 0.047887891487334855, 0.05468889568874147, 0.07522214407799765, 0.035496548589435406, 0.06171234752400778, 0.04121718244277872, 0.029509877058444545, 0.02925671564298682, 0.01144495525295497, 0.0530893930408638, 0.0493351759359939, 0.055231316582649015, 0.04209599661407992, 0.040768094040686265, 0.03775612480239943, 0.11755642204661854, 0.0808169282390736, 0.10195002862019464, 0.021065182736492716, 0.013270350027596578, 0.09100102746742778, 0.11591427188250236, 0.05376396075007506, 0.02107092510414077, 0.08243153730290942, 0.11219057560083456, 0.043466294373502024, 0.06607573799556121, 0.11424052849179134, 0.06147039995994419, 0.08199234915082343, 0.2328587041120045, 15.952169112861156, 62.30411298573017, 67.1523830294609, 74.28542867302895, 71.93985253572464, 55.23082673549652, 48.69549281895161, 35.24025522172451, 27.106430679559708, 23.217502757906914, 22.496510446071625, 38.552579283714294, 40.220583379268646, 28.119391724467278, 36.722582280635834, 27.895883917808533, 7.898524068295956, 1.0722219524905086, 0.042755487593240105, 0.10621626453939825, 0.17659314908087254, 0.4724606510717422, 0.4808092484017834, 1.0680197342298925, 1.769599956460297, 2.3589554568752646, 2.7808252070099115, 5.266198692843318, 5.201302925124764, 5.744545049965382, 5.391157837584615, 3.4583186404779553, 3.841692181304097, 3.5692838486284018, 3.1496885139495134, 3.2604062603786588, 2.776632606983185, 6.819392899051309, 7.185035878792405, 5.3504567965865135, 8.00543513149023, 6.821883665397763, 7.101434664800763, 7.460602317005396, 9.49702039361, 8.316935766488314, 9.82032224535942, 8.538850508630276, 12.830410525202751, 15.296579841524363, 20.062385760247707, 26.35919887572527, 34.82082612812519, 48.56304332613945, 59.63508300483227, 49.38247695565224, 59.53952573239803, 58.09901162981987, 63.087288960814476, 54.32360261678696, 59.962686225771904, 58.051544576883316, 34.899147525429726, 14.846661183983088, 8.751599192619324, 7.779315914958715, 8.523626625537872, 5.196677623316646, 5.226007299497724, 4.616257818415761, 8.319878708571196, 5.421227049082518, 0.6126996071543545, 0.7140050211455673, 0.6765266822185367, 0.3464921854902059, 0.9890983847435564, 0.030169560996000655, 0.5124621139839292, 2.00536020565778, 3.128168606199324, 1.9815168413333595, 3.520632446743548, 3.0102799320593476, 2.0085287606343627, 1.2071471312083304, 0.9464451391249895, 0.33333996310830116, 0.05379186179197859, 0.12932564481161535, 0.04250637830409687, 0.008196631461032666, 0.4167295165825635, 7.530034091323614, 29.613481052219868, 44.03204865753651, 68.29524770379066, 73.43179687857628, 72.67243042588234, 79.73609939217567, 103.03502798080444, 78.69595840573311, 50.77356331050396, 55.08970230817795, 58.91389310359955, 69.28171277046204, 65.5461560189724, 79.42041993141174, 82.34526738524437, 29.25793033093214, 0.48125697125215083, 0.12633882695809007, 0.09662350115831941, 0.13960542913991958, 0.023424175196851138, 0.06374337564921007, 0.039980434157769196, 0.06905071859364398, 0.009354042304039467, 0.06055416670278646, 0.03252421745855827, 0.03326575657411013, 0.04678421770222485, 0.03889352548867464, 0.04790060447703581, 0.03485124005237594, 0.08886436946340837, 0.0361184794746805, 0.05257913682726212, 0.06237299996428192, 0.05630534898955375, 0.015775109568494372, 0.08647895840113051, 0.017613260934012942, 0.024384649732382968, 0.06523253206978552, 0.07175508988439105, 0.07280406367499381, 0.0830198080802802, 0.04288679578166921, 0.08205054837162606, 0.02723513505770825, 0.059777401547762565, 0.01417422838130733, 0.04191154323052615, 0.15668278152588755, 0.14683224057080224, 0.16315132583258674, 0.1332560885930434, 0.1857376255793497, 0.20125654205912724, 0.1203837152570486, 0.15277993079507723, 0.295951483421959, 0.38951326918322593, 0.24818109988700598, 0.27369963994715363, 0.16268663748633116, 0.21387259243056178, 0.22295235365163535, 0.13985274243168533, 0.20946009404724464, 0.07292329712072387, 0.19739621639018878, 0.1885818620212376, 0.3916498232865706, 0.2677963301539421, 0.1387814967893064, 0.20100214867852628, 0.3510385227855295, 0.13663597754202783, 0.1535475192940794, 0.49732669489458203, 0.20134172576945275, 0.1884985188371502, 0.5798869428690523, 23.90228111296892, 75.92245683073997, 78.03088769316673, 82.03104704618454, 79.461290538311, 61.2674830108881, 49.09925535321236, 38.988138511776924, 30.250552967190742, 36.70254595577717, 36.08607463538647, 58.04349660873413, 57.867186069488525, 44.80116918683052, 58.724070489406586, 39.98762167990208, 10.868835132569075, 1.684689475223422, 0.1586476174998097, 0.647198015358299, 0.3745051135774702, 0.5231102707330137, 0.37859514879528433, 1.599868645425886, 2.1926412312313914, 3.9965485967695713, 5.585541157051921, 8.440527934581041, 12.144450433552265, 18.745593018829823, 11.215128600597382, 9.340863972902298, 7.869480801746249, 10.7288021966815, 11.083240527659655, 13.40204045176506, 9.896708596497774, 16.62985324859619, 20.204988308250904, 14.56348042935133, 21.42788428813219, 17.28328138589859, 14.944889713078737, 15.276390574872494, 16.905606351792812, 13.206912372261286, 15.493872854858637, 11.472328249365091, 19.758202582597733, 20.804884918034077, 24.319785609841347, 34.97572861611843, 40.67289590835571, 55.46669527888298, 65.69928020238876, 56.89099945127964, 65.05942493677139, 63.193637654185295, 67.14017808437347, 59.993282184004784, 62.86661960184574, 63.24925906956196, 41.53752811253071, 19.97262317687273, 13.459006994962692, 12.785113155841827, 15.467697959393263, 8.390633761882782, 10.070935897529125, 8.781428541988134, 14.113312885165215, 6.538545694202185, 0.9995404025539756, 6.086188517510891, 5.322567718103528, 5.270770322531462, 8.708327114582062, 11.487710773944855, 3.969227825291455, 8.338401764631271, 11.889485064893961, 5.307988375425339, 7.548173367977142, 4.606834324076772, 2.4944186629727483, 1.0983323701657355, 0.533185014501214, 0.19055469834711403, 0.1919332376564853, 0.1812108958256431, 0.23674760246649384, 0.15798850130522624, 1.408318905159831, 13.293879255652428, 46.421763226389885, 67.52695173025131, 81.4101679623127, 77.46997699141502, 67.00338542461395, 70.55909022688866, 112.6307974755764, 89.03777986764908, 51.62015788257122, 60.33415049314499, 65.78372687101364, 79.16668474674225, 78.00526946783066, 90.53428396582603, 92.01229825615883, 33.7100887298584, 0.7606867630966008, 0.3616010653786361, 0.2821851783664897, 0.40968018234707415, 0.3208957496099174, 0.15997003560187295, 0.21463305631186813, 0.22459491941845044, 0.1824601975386031, 0.10232819739030674, 0.16613156825769693, 0.18004701531026512, 0.1922542610554956, 0.09427979137399234, 0.11694681452354416, 0.1420247563510202, 0.21224362280918285, 0.0816624570870772, 0.1866620298824273, 0.23373843112494797, 0.3549638605909422, 0.14783854829147458, 0.26567830005660653, 0.141143812215887, 0.13111476990161464, 0.18853964866138995, 0.18557482806500047, 0.15081883524544537, 0.19339086022228003, 0.227854298427701, 0.16412523138569668, 0.31195079209282994, 0.23540294962003827, 0.19910659961169586, 0.1561523982672952], [0.029767311389150564, 0.025795407527766656, 0.034811457226169296, 0.044053741366951726, 0.031715918448753655, 0.03993388294475153, 0.0494287496258039, 0.048784134996822104, 0.04227859462844208, 0.03958778608648572, 0.05281559620925691, 0.09241121937520802, 0.07428003213135526, 0.07967057725181803, 0.022218417143449187, 0.07549124682554975, 0.07659415248781443, 0.028606818777916487, 0.06233394815353677, 0.02618004411488073, 0.1027873567363713, 0.06329016832751222, 0.0428653514245525, 0.08135370881063864, 0.08407293789787218, 0.05532745439268183, 0.09822566440561786, 0.11360855263774283, 0.20728330069687217, 0.1603298881673254, 10.300161447376013, 48.483350202441216, 61.90674930810928, 62.4664668738842, 63.85703265666962, 41.569210812449455, 41.99565812945366, 18.288441449403763, 20.556047670543194, 19.64413460344076, 25.822437778115273, 31.142304316163063, 32.0923787355423, 43.83477084338665, 57.427982836961746, 19.611251167953014, 1.428233755286783, 0.15774877276271582, 0.13599848753074184, 0.07132535669370554, 0.07073147527989931, 0.14387202129000798, 0.5992254114244133, 1.4525170647539198, 0.9630395611748099, 1.5625773277133703, 1.8183597712777555, 2.6060364861041307, 1.3584020524285734, 4.000443387776613, 3.6771448608487844, 2.4996516946703196, 2.7343636751174927, 1.6884593479335308, 3.275698064826429, 3.7848600558936596, 6.369068613275886, 9.739821664988995, 25.77819485217333, 23.901631347835064, 17.59387481957674, 21.89007628709078, 20.497855693101883, 19.00692969560623, 24.452105909585953, 22.331377007067204, 32.52024717628956, 41.92439675331116, 43.13220754265785, 36.12190671265125, 43.65534067153931, 39.667010083794594, 38.34691531956196, 45.24332486093044, 27.616452611982822, 38.040606155991554, 43.563370406627655, 49.82801824808121, 42.93153651058674, 49.25710268318653, 43.67680951952934, 40.7567498087883, 40.13816960155964, 41.76700919866562, 30.364638045430183, 29.10512153059244, 30.65240990370512, 26.444023624062538, 25.298075415194035, 23.741773925721645, 23.332351595163345, 30.080052316188812, 37.86439061164856, 32.09888018667698, 20.46163223683834, 13.128802813589573, 6.829243395477533, 1.968303406611085, 1.1603030073456466, 1.2658850918523967, 2.0659517543390393, 1.5256789326667786, 1.0424292949028313, 2.464735130779445, 2.3473055195063353, 0.456317929783836, 1.2800160585902631, 0.7709072646684945, 0.18399912980385125, 0.14559312112396583, 0.1025230334198568, 0.03176082951540593, 0.011682053809636272, 0.03185060711984988, 0.09185487579088658, 2.424296513199806, 15.440218783915043, 33.84612523019314, 36.47031381726265, 30.723705478012562, 32.01170526444912, 69.38899621367455, 36.94887913763523, 12.206537202000618, 15.543985515832901, 30.709621533751488, 46.48862063884735, 49.83424611389637, 66.00041404366493, 76.57100602984428, 72.02061340212822, 11.755244918167591, 0.4658569616731256, 0.07857106320443563, 0.04046386915433686, 0.05696689200703986, 0.07506837107939646, 0.06536315006087534, 0.06434875293052755, 0.032482223032275215, 0.00450177689344855, 0.03365728771314025, 0.037272177723934874, 0.04145580889598932, 0.047433496729354374, 0.03279943921370432, 0.04237492168613244, 0.062471059936797246, 0.035272976601845585, 0.040856491250451654, 0.06840537665993907, 0.07932170105050318, 0.0593844863033155, 0.031173575480352156, 0.037952485945424996, 0.020468397669901606, 0.05399219342507422, 0.07033009955193847, 0.002859544861166796, 0.05461611697683111, 0.07072500375215895, 0.06985053114476614, 0.12038183020194992, 0.02582978380814893, 0.023895581834949553, 0.06066764850402251, 0.015491808608203428, 0.031001473289506976, 0.02706996452616295, 0.03087211323872907, 0.091580036241794, 0.011199884174857289, 0.05853401846252382, 0.030938323943701107, 0.07203493150882423, 0.04043241322506219, 0.01627802223083563, 0.010542024992901133, 0.030700075985805597, 0.06517527537653223, 0.02188907612435287, 0.031038140950840898, 0.12416514320648275, 0.03392203034309205, 0.07251972463564016, 0.03986154209997039, 0.055213746236404404, 0.09591447553248145, 0.033749514404917136, 0.05701868278265465, 0.08795067435130477, 0.14334286999655887, 0.18267424777150154, 0.09870863927062601, 0.13912619469920173, 0.039769875729689375, 12.082021683454514, 57.66352079808712, 71.69843629002571, 71.39392822980881, 72.08237528800964, 51.21424846351147, 49.773897752165794, 25.927076563239098, 32.554012164473534, 26.850482113659382, 32.78444319963455, 24.851694367825985, 35.587647780776024, 43.8612250238657, 43.98774303495884, 16.375012323260307, 1.0358123062178493, 0.07486154936486855, 0.06676626930129714, 0.16220223769778386, 0.13085145590594038, 0.5276093480642885, 1.3739489181898534, 2.1157587692141533, 2.9374900879338384, 3.456353908404708, 4.086605664342642, 5.294728986918926, 5.301556745544076, 4.365206239745021, 4.382110107690096, 3.6063358979299664, 2.797913602553308, 1.7483315477147698, 1.5518430224619806, 3.0854401364922523, 6.309451712295413, 11.000221632421017, 20.896775387227535, 22.827622778713703, 19.187760092318058, 21.666141003370285, 22.652670666575432, 21.506838351488113, 25.858788527548313, 24.5198904722929, 34.30869720876217, 43.79728965461254, 43.600551411509514, 38.76952484250069, 46.458062678575516, 42.65235789120197, 41.45875073969364, 47.61739946901798, 35.78627072274685, 44.83563333749771, 48.87958534061909, 56.791061013937, 49.48344513773918, 57.43031211197376, 50.73813021183014, 47.33543559908867, 46.94858975708485, 46.800872683525085, 34.901564195752144, 32.665061205625534, 32.619923427700996, 29.630500338971615, 27.261597253382206, 26.32426545023918, 24.88774113357067, 31.999412924051285, 40.8387304097414, 34.06374715268612, 22.51826047897339, 14.81903001666069, 8.0252168700099, 3.1574113620445132, 0.8626159373670816, 0.48383985296823084, 1.485406793653965, 0.6305934407282621, 1.0134347132407129, 2.0522501645609736, 2.534996448084712, 2.910009487532079, 3.224453777074814, 1.8351432331837714, 0.8699646242894232, 0.7224638422485441, 0.19479377166135237, 0.14685166999697685, 0.11257376128924079, 0.057702516205608845, 0.050709414499579, 2.2708208486437798, 11.99232179671526, 37.86316707730293, 44.71339009702206, 35.44449806213379, 34.84567679464817, 84.64300408959389, 42.1615382283926, 18.814593516290188, 30.76633159071207, 44.69720296561718, 54.02189880609512, 58.36709104478359, 76.54333591461182, 81.14052683115005, 86.62035718560219, 19.564129896461964, 0.4479860753053799, 0.08754866037634201, 0.02393676360952668, 0.038236910331761464, 0.05381412251153961, 0.04233135019603651, 0.04017591956653632, 0.04169365609413944, 0.0518855478730984, 0.043360007693991065, 0.0516358782624593, 0.040263919727294706, 0.028485297661973163, 0.0838627913617529, 0.03216388249711599, 0.07180791595601477, 0.0823876095819287, 0.02077184330119053, 0.034450658422429115, 0.09900187666062266, 0.013191911511967191, 0.059023041831096634, 0.0651066267164424, 0.06664449028903618, 0.05659638591168914, 0.06840847141575068, 0.06771711632609367, 0.03621932992246002, 0.10565490403678268, 0.09487778428592719, 0.06618076673476025, 0.044514214314403944, 0.022466218397312332, 0.018236802279716358, 0.12780360382748768, 0.17443450866267085, 0.16648563207127154, 0.205048723728396, 0.17487757082562894, 0.1609049635590054, 0.1939593453425914, 0.11732620783732273, 0.13461512426147237, 0.08263924217317253, 0.13484551658621058, 0.1998450662358664, 0.1162151459720917, 0.12460177094908431, 0.12471095571527258, 0.22702704125549644, 0.2247367289965041, 0.14330411504488438, 0.22225329506909475, 0.15605784865329042, 0.17506411706563085, 0.1854801003355533, 0.16109588847029954, 0.19017048849491403, 0.2427849589730613, 0.3116097010206431, 0.4580372484633699, 0.2801281231222674, 0.3431402606656775, 0.5334701773244888, 19.204317703843117, 69.77699339389801, 80.68130627274513, 79.60705831646919, 81.37405470013618, 58.317442908883095, 53.67531180381775, 28.662756867706776, 29.403401724994183, 31.480708457529545, 40.41020080447197, 46.21929109096527, 45.11246748268604, 60.35072520375252, 73.23983877897263, 26.655362583696842, 2.501140977256, 0.4245364054804668, 0.39752519864123315, 0.41797617624979466, 0.24725663621211424, 0.4700584971578792, 1.5203824918717146, 3.55986462906003, 5.046714395284653, 5.249410243704915, 6.2518007308244705, 9.094574488699436, 9.647507518529892, 11.076775174587965, 11.209989376366138, 9.248653370887041, 9.616186749190092, 7.409373940899968, 9.105425756424665, 8.521003816276789, 11.102867424488068, 13.852520529180765, 30.87517485022545, 29.089570865035057, 22.650527581572533, 26.339103654026985, 27.175499573349953, 25.155909843742847, 28.957488052546978, 25.536432825028896, 36.975998282432556, 45.24696126580238, 47.7640487998724, 40.36518082022667, 49.816637858748436, 48.406499326229095, 49.39540006220341, 56.72438219189644, 43.278742879629135, 50.69037817418575, 57.25018657743931, 63.33867207169533, 54.44768875837326, 64.10043999552727, 57.394727021455765, 53.95543657243252, 53.04790087044239, 51.09544783830643, 40.546438694000244, 36.98951795697212, 34.455688521265984, 30.79321514815092, 29.664122834801674, 29.878872111439705, 27.09736816585064, 34.226355627179146, 44.15491126477718, 36.648452058434486, 24.489630796015263, 14.815456308424473, 9.6994374319911, 3.967206571251154, 5.303084263578057, 4.936924036592245, 5.493433624505997, 4.8222689889371395, 5.930263884365559, 11.774110905826092, 9.69421461224556, 3.957562926225364, 5.677316207438707, 2.6794846449047327, 1.028584975283593, 0.623108436120674, 0.24348202859982848, 0.14532137633068487, 0.23626251990208402, 0.21600423351628706, 0.22082552168285474, 3.9662228990346193, 22.307854369282722, 49.12293568253517, 52.073188573122025, 43.3876146376133, 41.63359835743904, 78.48024398088455, 44.14125859737396, 24.47338856756687, 27.99721498042345, 45.767647325992584, 60.43576464056969, 69.82917219400406, 86.28272250294685, 90.62560826539993, 97.77287274599075, 23.727874271571636, 1.0503177903592587, 0.24979443987831473, 0.16519141558092088, 0.19568047486245632, 0.17945708212209865, 0.2718723239377141, 0.18477321951650083, 0.2959130401723087, 0.12381668260786682, 0.19906621193513274, 0.17882026004372165, 0.15905947977444157, 0.2027475761133246, 0.17674635804723948, 0.1471375601249747, 0.1897361985174939, 0.12767847772920504, 0.12343821697868407, 0.30472743907012045, 0.23717671225313097, 0.0859525085252244, 0.18164453271310776, 0.15900816768407822, 0.11993019623332657, 0.20744480687426403, 0.10624641799950041, 0.17929051449755207, 0.13553709432017058, 0.3258606285089627, 0.228647283220198, 0.2795535820769146, 0.2538218378322199, 0.13828522263793275, 0.16297196358209476], [0.06291242258157581, 0.05328398787241895, 0.02657241202541627, 0.04993250091501977, 0.026461639063199982, 0.07576622738270089, 0.03457480859651696, 0.08695348020410165, 0.037450512099894695, 0.13048217806499451, 0.04230668862874154, 0.02144109908840619, 0.07621913784532808, 0.028937074494024273, 0.039000747274258174, 0.05270571753499098, 0.10584462666884065, 0.0926055655872915, 0.009695624121377477, 0.03368973812030163, 0.06523615375044756, 0.09235504621756263, 0.05651893909089267, 0.04777193462359719, 0.058093197585549206, 0.025157583550026175, 0.24378823873121291, 0.13098845636704937, 0.8423263323493302, 6.793941864743829, 54.74011726677418, 69.15764942765236, 66.12528294324875, 59.942330718040466, 41.53861105442047, 38.013483211398125, 65.3921426832676, 44.927861988544464, 22.55840912461281, 30.693069621920586, 19.34863205999136, 38.34821864962578, 40.790488198399544, 33.60543094575405, 8.995836786925793, 0.4752324539003894, 0.05563001686823554, 0.07297385964193381, 0.0997130767791532, 0.1409487461205572, 0.043928793384111486, 0.4513035051058978, 0.6567659019492567, 2.3540948051959276, 1.247486479114741, 1.2904521985910833, 1.9577472168020904, 2.7098400285467505, 4.617412006482482, 2.2068636305630207, 2.5560067081823945, 4.679717738181353, 2.9774658428505063, 8.345149252563715, 10.473610740154982, 17.987053021788597, 22.989256605505943, 32.311619371175766, 37.54836916923523, 39.19381007552147, 34.89458777010441, 35.510762706398964, 35.79329654574394, 43.98668669164181, 44.67074878513813, 51.51823215186596, 55.257755890488625, 62.48499467968941, 64.99556556344032, 62.57447987794876, 55.7764508575201, 49.99226063489914, 47.530783116817474, 56.589481830596924, 37.794508561491966, 32.64163926243782, 53.04814785718918, 46.724561378359795, 37.90951319038868, 46.68696999549866, 44.89484556019306, 33.8315150141716, 37.755541652441025, 55.39384178817272, 38.187217488884926, 55.53869381546974, 59.732787162065506, 59.78061139583588, 57.30018809437752, 57.782264426350594, 67.29834079742432, 65.80545410513878, 72.07731395959854, 64.32409599423409, 68.53704392910004, 67.0806048810482, 59.15383122861385, 50.8854179084301, 34.5021828263998, 13.954341765493155, 3.5239677177742124, 0.32783604750875384, 2.0695993211120367, 2.1382751734927297, 2.101264209486544, 2.7470169961452484, 1.7143320408649743, 2.0600181352347136, 1.0403122147545218, 0.28522308566607535, 0.25950220646336675, 0.16383493290049955, 0.04943367006490007, 0.050326685231993906, 0.11104503355454654, 0.027344598129275255, 0.19615167926531285, 3.992588734254241, 29.423907324671745, 53.20276156067848, 58.289787992835045, 16.383318677544594, 22.51136004924774, 24.162306860089302, 11.99468906968832, 13.468702174723148, 27.11766667664051, 47.94350557029247, 58.82819250226021, 59.59945611655712, 73.73892679810524, 58.9850252866745, 5.349255586043, 0.18089873366989195, 0.05095340668049175, 0.031030485697556287, 0.05880696182430256, 0.10549611411988735, 0.08426381828030571, 0.08964933163952082, 0.01785568347258959, 0.12681797234108672, 0.09610580120352097, 0.04427727253641933, 0.038547870208276436, 0.05539549078093842, 0.03036695929040434, 0.016668417883920483, 0.06482222088379785, 0.08910754157113843, 0.0522520315280417, 0.04401752456033137, 0.019512361177476123, 0.024378519592573866, 0.04436510942468885, 0.02303653662238503, 0.0876942029572092, 0.05545079562580213, 0.025520083727315068, 0.013629820386995561, 0.03890018255333416, 0.04646567678719293, 0.043865261832252145, 0.04227897683449555, 0.045505204107030295, 0.033164019259857014, 0.02754026536422316, 0.01923007603181759, 0.04170817992417142, 0.047446903627133, 0.018149047027691267, 0.05342787546396721, 0.0687076682515908, 0.05058954280684702, 0.011194624203199055, 0.04424767568707466, 0.054211973038036376, 0.0580635636288207, 0.04661692277295515, 0.05078911744931247, 0.05729405296733603, 0.047561350220348686, 0.06584278526133858, 0.07645932651939802, 0.04857524640101474, 0.0438955266145058, 0.051700456242542714, 0.01822593723773025, 0.04559590568533167, 0.049060956080211326, 0.03350032347952947, 0.0026974908860211144, 0.1241634288453497, 0.06170208362163976, 0.6506792816799134, 9.209130741655827, 64.29400160908699, 77.96385928988457, 72.9214158654213, 69.81597930192947, 50.25889232754707, 49.89040710031986, 68.990807980299, 39.77854549884796, 22.98308953642845, 25.921190679073334, 22.829933054745197, 42.003432512283325, 36.15887112915516, 29.941599145531654, 7.761004222556949, 0.33822917263023555, 0.012097197304683505, 0.10931903554592282, 0.0990807669586502, 0.33046660479158163, 0.9229972504545003, 0.956352751236409, 3.4595300629734993, 5.6947496719658375, 3.9274018071591854, 3.4989413106814027, 5.253372481092811, 3.166865729726851, 3.170372941531241, 3.8078697212040424, 2.213848130777478, 2.897530719637871, 2.905501266941428, 5.58401363901794, 9.449400398880243, 18.59570626169443, 24.511943198740482, 33.758672922849655, 38.42930629849434, 41.44687257707119, 37.677216455340385, 35.72364628314972, 37.00540870428085, 44.628236666321754, 47.444850727915764, 51.81786127388477, 57.533894553780556, 65.51036193966866, 66.01185142993927, 65.69307133555412, 58.65706488490105, 55.897747948765755, 51.40645354986191, 60.46353355050087, 43.45103323459625, 40.014744624495506, 56.887591034173965, 52.53020524978638, 44.94343735277653, 54.47881668806076, 51.687494069337845, 40.255955681204796, 41.85743674635887, 58.518144339323044, 43.49241301417351, 61.52350187301636, 63.46409574151039, 60.21640241146088, 58.340655863285065, 60.83728529512882, 68.74917894601822, 70.08451849222183, 75.0106805562973, 68.71956333518028, 70.74990078806877, 70.16298428177834, 61.36448420584202, 52.23474070429802, 37.17095822095871, 16.123441122472286, 4.54298397526145, 0.7177235966082662, 0.8325332484673709, 0.9874189936090261, 1.6022809222340584, 2.2783197462558746, 3.241030862554908, 2.798961396329105, 2.7232514088973403, 1.4593861461617053, 0.7744873850606382, 0.5342111375648528, 0.2229754938161932, 0.13239383173640817, 0.006884092272230191, 0.013119518716848688, 0.0958022108534351, 4.3608141504228115, 29.432251676917076, 48.73958185315132, 42.70592741668224, 21.72804158180952, 17.68622126430273, 24.633909054100513, 16.866660341620445, 21.94429747760296, 41.26943729817867, 56.81806996464729, 66.7598868906498, 66.78636386990547, 81.84889242053032, 73.28401520848274, 9.984673876315355, 0.17003496817778796, 0.10532116764807142, 0.06787503050873056, 0.03192134863638785, 0.0432899303996237, 0.06527462668600492, 0.05072266925708391, 0.05574041875661351, 0.03535650532285217, 0.04548178934783209, 0.05323199671693146, 0.040000917433644645, 0.055566214432474226, 0.08523027267074212, 0.035362843264010735, 0.012122975804231828, 0.04418933174747508, 0.06012715348333586, 0.04100251622730866, 0.0457639687374467, 0.036996429043938406, 0.031150483555393293, 0.03677558444906026, 0.06283293856540695, 0.03380076712346636, 0.055691826637485065, 0.0224242851982126, 0.030098884417384397, 0.027890959827345796, 0.04933299402182456, 0.0299305486259982, 0.028074949368601665, 0.03723141897353344, 0.25163627229630947, 0.13979311828734353, 0.15617297060089186, 0.10587322161882184, 0.1162956838379614, 0.18911027116701007, 0.1222890755161643, 0.245696033234708, 0.14609347708756104, 0.1759091264102608, 0.14014580170623958, 0.14092073746724054, 0.1988383725984022, 0.1496314731775783, 0.09000788544653915, 0.12963090499397367, 0.2834816509857774, 0.19457514979876578, 0.20521567726973444, 0.15290789189748466, 0.2021193184191361, 0.20885280944639817, 0.2725671522784978, 0.19654935167636722, 0.11957780225202441, 0.12117524544009939, 0.3393786703236401, 0.1976058434229344, 1.039002591278404, 14.060872849076986, 79.88145679235458, 86.09356105327606, 84.3495762348175, 78.46546277403831, 59.5462703704834, 51.445758640766144, 76.48111045360565, 55.315759778022766, 33.96175682544708, 40.75059413909912, 31.203317642211914, 53.703460693359375, 55.68428300321102, 45.980724692344666, 12.487879805266857, 1.074528784956783, 0.27242397714871913, 0.27462860103696585, 0.21446803235448897, 0.2811669814400375, 0.7053658878430724, 1.2037269584834576, 3.3133210334926844, 7.17970666475594, 5.583068439736962, 6.071398761123419, 7.6474368665367365, 7.583852028474212, 13.345441538840532, 9.03483409434557, 8.604947961866856, 9.350567702203989, 8.234927617013454, 14.179986007511616, 13.345494735985994, 22.48274378478527, 26.270656026899815, 36.22842639684677, 41.17088198661804, 42.61950105428696, 37.287079989910126, 37.691340297460556, 40.97296580672264, 47.980500385165215, 47.70715445280075, 52.599429935216904, 55.49511395394802, 62.49645106494427, 67.15903267264366, 68.02374467253685, 63.114309310913086, 63.21944206953049, 54.33464862406254, 60.81604063510895, 48.30292448401451, 47.4417918920517, 64.54751640558243, 59.828013852238655, 49.28174056112766, 59.67058449983597, 57.03890651464462, 46.82528257369995, 46.494677513837814, 62.807753160595894, 47.378453090786934, 67.41996467113495, 65.65448820590973, 61.81657634675503, 59.40873675048351, 61.667939722537994, 68.24439883232117, 72.87349283695221, 79.0602296590805, 71.63400694727898, 73.52325037121773, 70.73476999998093, 63.806274980306625, 55.49978010356426, 41.18204578757286, 16.50619648396969, 6.179878190159798, 3.7013885099440813, 4.942750548943877, 7.289793882519007, 9.023617096245289, 8.603868819773197, 8.481485936790705, 8.336680456995964, 3.9489373890683055, 2.5664138747379184, 1.0741152008995414, 0.6870844750665128, 0.3930712438886985, 0.23082711937604472, 0.3567325766198337, 0.19365760294022039, 0.5957017536275089, 7.644411278888583, 41.72955460846424, 72.3121489584446, 77.47191488742828, 28.991376534104347, 36.29131682217121, 37.899588122963905, 20.107753425836563, 23.25003281235695, 42.76198960840702, 64.79335561394691, 77.36392468214035, 80.59127390384674, 89.93628725409508, 82.44772508740425, 13.610744252800941, 0.4205636295955628, 0.18395388848148286, 0.18099472305038944, 0.1313905668212101, 0.15499748289585114, 0.18651481746928766, 0.24520903592929244, 0.1328663423191756, 0.21189551101997495, 0.2103925432311371, 0.12464739818824455, 0.10950126248644665, 0.19245722360210493, 0.16719126608222723, 0.12005961194518022, 0.14575220789993182, 0.1478481516824104, 0.26177478139288723, 0.17720490141073242, 0.14859113056445494, 0.17258501728065312, 0.14852548018097878, 0.1655279053375125, 0.1819086482282728, 0.11886289139511064, 0.11415927816415206, 0.13622488710097969, 0.13622754398966208, 0.198721558554098, 0.15937793534249067, 0.19316894322400913, 0.1406882522860542, 0.1342448074137792], [0.008723710307094734, 0.048847896614461206, 0.061302700560190715, 0.07152288671932183, 0.03407966622035019, 0.06838106390205212, 0.07501536689233035, 0.011639343210845254, 0.022729656702722423, 0.0325182134838542, 0.07882011312176473, 0.03713970065291505, 0.05001750650990289, 0.07654775341507047, 0.09480723572778516, 0.06767074693925679, 0.04819067289645318, 0.18637294851941988, 0.07033424815745093, 0.025377955025760457, 0.014032013405085308, 0.015892005249042995, 0.042040892149088904, 0.05457479419419542, 0.05447184717922937, 0.11775043429224752, 0.0406539739924483, 0.08796263777185231, 3.4219196811318398, 44.024004489183426, 67.31680780649185, 63.354749009013176, 67.05180242657661, 55.464316606521606, 38.37248034775257, 16.71283509582281, 64.9484632909298, 65.55902972817421, 41.81285373866558, 52.88085423409939, 43.82263049483299, 39.41656172275543, 37.51949831843376, 7.937919879332185, 0.3107409132644534, 0.11965052530285902, 0.033389966120012105, 0.043056473004980944, 0.09401635863468982, 0.19642159837530926, 1.0837535024620593, 1.3368255039677024, 3.087054812349379, 2.7248328365385532, 2.0346549712121487, 2.017593174241483, 4.397438010200858, 3.2335768500342965, 1.3580515212379396, 2.879046374000609, 5.800770632922649, 11.564897932112217, 14.425158351659775, 27.23231792449951, 37.191260531544685, 46.74722336232662, 50.84141626954079, 61.525283977389336, 61.10744699835777, 65.50373509526253, 53.748549073934555, 50.90660937130451, 58.61206769943237, 56.33746795356274, 63.56890931725502, 64.04794961214066, 63.814231753349304, 68.71814221143723, 67.29579493403435, 61.548394337296486, 59.48421590030193, 63.616832345724106, 62.028183192014694, 64.63185667991638, 44.757380336523056, 23.834439553320408, 50.33092126250267, 42.959643602371216, 41.85341276228428, 45.40256671607494, 33.14073108136654, 40.056504383683205, 53.98091420531273, 65.59841081500053, 63.104034662246704, 64.2203539609909, 62.84569412469864, 62.13496886193752, 65.19839107990265, 73.15202549099922, 65.6386886537075, 71.30471661686897, 67.93064966797829, 65.5920347571373, 62.1920607984066, 67.03123033046722, 61.39514856040478, 65.80910190939903, 65.34614995121956, 70.1402235031128, 52.889160588383675, 34.945634230971336, 13.735331017524004, 2.2759968833997846, 0.5245005805045366, 2.7237187838181853, 1.8688267632387578, 2.179663027636707, 2.167739742435515, 1.679527333471924, 0.5584500962868333, 0.5005117552354932, 0.1992107229307294, 0.06875657578348182, 0.01943808518262813, 0.03764172644878272, 0.041408775286981836, 0.029709095470025204, 4.1035271063447, 26.82333067059517, 46.477080658078194, 62.262980192899704, 53.84404554963112, 41.53612598776817, 42.58643142879009, 24.293945096433163, 16.55393522232771, 26.163807660341263, 37.74190038442612, 54.30210717022419, 64.8128941655159, 77.68229439854622, 33.894941210746765, 1.3683622679673135, 0.19628940703114495, 0.09177548825391568, 0.03585093894798774, 0.05836804455611855, 0.09287952940212563, 0.10453791983309202, 0.06261009388254024, 0.06484835190349258, 0.03897533613780979, 0.0492479772947263, 0.04964231004123576, 0.0738915623514913, 0.050268857085029595, 0.02785504544590367, 0.08953746772021987, 0.0967369310092181, 0.04602861117746215, 0.06090713584853802, 0.04584240261465311, 0.035753673073486425, 0.07998139612027444, 0.0804079306544736, 0.017796827451093122, 0.03347922051034402, 0.051937995449407026, 0.04359668972028885, 0.03282195597421378, 0.0535201021557441, 0.02351450199057581, 0.04806910168554168, 0.015766888427606318, 0.04493949090829119, 0.011859940113936318, 0.05653049433021806, 0.03878611074469518, 0.031919612010824494, 0.03265962230216246, 0.0418073345645098, 0.011435857450123876, 0.04238142661051825, 0.035368743338040076, 0.03199400860466994, 0.07727514719590545, 0.050746466222335584, 0.031239827003446408, 0.08070615527685732, 0.14229025226086378, 0.04993171794922091, 0.061456796393031254, 0.12785553932189941, 0.041427662945352495, 0.03138606349239126, 0.051754083833657205, 0.038609435068792664, 0.013939102082076715, 0.017776206877897494, 0.017158662085421383, 0.07760635286103934, 0.019573243262129836, 0.07545139349531382, 5.061100423336029, 52.440746650099754, 78.09254318475723, 73.71924385428429, 77.16837957501411, 63.22081379592419, 46.614139303565025, 25.908603854477406, 67.0583076775074, 54.80711907148361, 38.439884930849075, 38.118486776947975, 36.87763676047325, 42.18720585107803, 33.641209825873375, 7.814640244469047, 0.24981857452075928, 0.03873030495014973, 0.029101558538968675, 0.45242613705340773, 0.788158813957125, 1.0016636573709548, 2.558888141065836, 3.566231424920261, 4.200527826324105, 5.065565658733249, 4.353629685938358, 4.610668318346143, 4.477751925587654, 3.096999591216445, 2.706738207489252, 4.066911321133375, 5.691314656287432, 9.878234937787056, 15.002712160348892, 27.60547500103712, 38.90467219054699, 48.75919260084629, 54.104008600115776, 62.82032668590546, 63.94891932606697, 65.26680260896683, 55.28159201145172, 54.17948395013809, 61.27791725099087, 57.50734157860279, 64.21697214245796, 63.39945361018181, 65.79993680119514, 67.6785559952259, 67.27478206157684, 63.71185764670372, 63.22679467499256, 67.28101372718811, 65.56190237402916, 65.62756285071373, 47.88128770887852, 29.585617147386074, 56.18332162499428, 48.36837597191334, 46.96788892149925, 51.71531617641449, 39.87422056496143, 43.66656146943569, 55.82957200706005, 67.0176650583744, 65.12695491313934, 65.78484401106834, 62.183876037597656, 63.300088942050934, 65.87581872940063, 73.28575551509857, 67.67268151044846, 72.17463433742523, 71.00628823041916, 68.14053520560265, 66.07633396983147, 69.62285846471786, 65.5592805147171, 69.39674779772758, 68.96784201264381, 71.38442113995552, 57.885520085692406, 37.8025983273983, 15.214879475533962, 2.984461742453277, 0.5632013850845397, 0.7896481559146196, 0.6266231881454587, 2.9467513784766197, 3.822269286029041, 1.6215969482436776, 1.651664616074413, 0.983793216291815, 1.620652936398983, 0.2725550998002291, 0.1512910341261886, 0.05294471877277829, 0.1752202946227044, 0.03241947815695312, 3.222590214572847, 25.825226828455925, 48.41993920505047, 50.278753861784935, 46.5950795263052, 29.653827287256718, 26.47515345364809, 24.598597548902035, 21.98355697095394, 42.85719729959965, 47.72432953119278, 62.412669360637665, 70.5767896771431, 83.47723424434662, 44.776698499917984, 1.7874021199531853, 0.22167201532283798, 0.05577270589128602, 0.1045016956049949, 0.03442913985054474, 0.06268901386647485, 0.04525332660705317, 0.03764891414903104, 0.10455046955030411, 0.038782477931817994, 0.03569043466995936, 0.019065053929807618, 0.018470825561962556, 0.024220186096499674, 0.032275991325150244, 0.024658478105266113, 0.05252618830127176, 0.08036742423428223, 0.03117526757705491, 0.050259457784704864, 0.07202191423857585, 0.051309433474671096, 0.11016583346645348, 0.02648380701430142, 0.0375655969401123, 0.029312406404642388, 0.010808896659000311, 0.04799185524461791, 0.018323490694456268, 0.036265068483771756, 0.03215893237211276, 0.03311356806079857, 0.06760037649655715, 0.1117676701687742, 0.21562186419032514, 0.22301877586869523, 0.13321403850568458, 0.07147707394324243, 0.1654580098693259, 0.14356532134115696, 0.10816502559464425, 0.15468138735741377, 0.11383841803763062, 0.18002121825702488, 0.08164808168658055, 0.27171383087988943, 0.25519000191707164, 0.27590227487962693, 0.159646236570552, 0.19368400855455548, 0.2947025082539767, 0.14575102046364918, 0.16509459499502555, 0.15722291660495102, 0.16561832861043513, 0.12371069649816491, 0.10625880444422364, 0.17420646152459085, 0.25468207604717463, 0.09341257697087713, 0.1818555104546249, 8.003627378493547, 63.180406764149666, 88.28219801187515, 80.48389926552773, 87.09555208683014, 72.14816495776176, 54.73495714366436, 26.545105800032616, 71.87324970960617, 70.84490329027176, 58.58184792101383, 71.41650661826134, 57.37002074718475, 52.607303112745285, 50.39089724421501, 12.940061241388321, 0.7697607949376106, 0.2259057154878974, 0.3219038830138743, 0.32593537762295455, 0.5667265865486115, 1.058921122457832, 2.579076220281422, 4.751353869214654, 7.741362601518631, 9.173579849302769, 7.301828311756253, 10.414361469447613, 10.868768636137247, 9.80106107890606, 8.212875500321388, 9.39013497903943, 11.352820862084627, 17.514825761318207, 19.801157377660275, 31.148961558938026, 39.96231883764267, 50.77401928603649, 56.96031153202057, 63.79935175180435, 66.6490164399147, 67.83741787075996, 54.77742366492748, 57.83246353268623, 66.96390554308891, 61.52865819633007, 65.2797219157219, 64.16136592626572, 63.55699695646763, 66.90589025616646, 65.68815439939499, 65.57726114988327, 63.39281536638737, 71.02624475955963, 65.02480119466782, 71.19741797447205, 54.34009753167629, 35.20330220460892, 62.30650685727596, 55.092536956071854, 51.560170501470566, 58.21135260164738, 44.31041032075882, 49.1412241011858, 58.4865528345108, 68.96421700716019, 66.95478603243828, 67.24429249763489, 61.53318755328655, 61.869936883449554, 67.44821235537529, 74.92077738046646, 67.71197140216827, 75.3586582839489, 73.07283014059067, 73.14245760440826, 66.93906247615814, 71.08672231435776, 66.52709618210793, 70.68174004554749, 71.09510466456413, 75.88588759303093, 58.716060519218445, 42.233289778232574, 16.976352855563164, 4.017862603068352, 4.899752056226134, 9.264382626861334, 8.650280479341745, 7.92686864733696, 8.880578521639109, 5.559790888801217, 3.4522916888818145, 1.245914907194674, 1.8834014749154449, 0.2459618408465758, 0.10313994367606938, 0.12210240311105736, 0.5426282796543092, 0.12281719522434287, 6.294245878234506, 36.805900409817696, 65.38016572594643, 84.68120723962784, 76.61873906850815, 56.27858631312847, 60.83934098482132, 37.0518384128809, 27.60917790234089, 41.53843246400356, 53.283792212605476, 72.09131240844727, 82.47936978936195, 92.963607609272, 53.78816954791546, 3.1676898105069995, 0.6432633264921606, 0.2202845405554399, 0.12104533991077915, 0.20031704247230664, 0.18939000146929175, 0.19614186807302758, 0.18276051501743495, 0.207478589436505, 0.1579488260904327, 0.19665915984660387, 0.12399890212691389, 0.194705500616692, 0.21086800756165758, 0.09900093413307332, 0.10697732213884592, 0.310662304982543, 0.18027819431154057, 0.12888948462205008, 0.11472568527096882, 0.21583399968221784, 0.189861755061429, 0.17984840174904093, 0.08914000311051495, 0.13788519019726664, 0.21057116333395243, 0.12517665338236839, 0.17915082746185362, 0.1554489164846018, 0.1287499608588405, 0.08277472123154439, 0.1204310345929116, 0.2545893075875938], [0.08140919919242151, 0.005170280792299309, 0.021930673501628917, 0.04782128373335581, 0.009239811861334601, 0.03580802425858565, 0.034895906210294925, 0.04441399098141119, 0.06685748667223379, 0.02831647576385876, 0.035175996454199776, 0.04121884485357441, 0.0754113843140658, 0.1226088372641243, 0.05065062898211181, 0.022708277283527423, 0.03802011415245943, 0.018109946977347136, 0.02001236833166331, 0.09658231938374229, 0.052494246265268885, 0.014187226170179201, 0.0402944182860665, 0.03699805063661188, 0.04796638844709378, 0.08907246025046334, 0.09427864104509354, 0.5047270352952182, 23.824024312198162, 64.49573278427124, 71.90863341093063, 71.23910933732986, 52.61009216308594, 37.723710760474205, 22.402775175869465, 33.73059622943401, 40.000020414590836, 59.22514960169792, 42.344775795936584, 33.513593673706055, 46.44392743706703, 34.02360610663891, 7.0066705998033285, 0.07503135275328532, 0.06221242147148587, 0.043618545969366096, 0.05410083642345853, 0.13794177153613418, 0.3005076467525214, 0.8640266116708517, 2.2831678111106157, 0.9425767092034221, 5.174117283895612, 5.617056665942073, 3.3779831137508154, 2.1994127053767443, 3.075272594578564, 5.082143694162369, 9.06112203374505, 16.20033949613571, 26.083405874669552, 30.6607960537076, 39.91982191801071, 51.76441714167595, 59.2117515206337, 64.58195015788078, 67.58046805858612, 66.61576822400093, 71.99157536029816, 70.25729522109032, 63.68734136223793, 63.82808580994606, 61.888871267437935, 62.09587275981903, 64.03697580099106, 65.65453380346298, 64.28545206785202, 64.02769669890404, 65.42890191078186, 65.33662766218185, 66.82295590639114, 66.43040657043457, 70.23750588297844, 53.69822457432747, 63.18997085094452, 33.630756586790085, 29.577263295650482, 47.40852847695351, 45.03127343952656, 34.400473684072495, 36.86526462435722, 58.72445426881313, 65.833770185709, 68.50548282265663, 72.39066794514656, 71.94471627473831, 70.93894824385643, 67.8605130314827, 64.62277516722679, 63.62524129450321, 61.691506057977676, 63.00025463104248, 60.71433149278164, 58.68954174220562, 62.42143929004669, 66.7870706319809, 65.92975303530693, 67.06043556332588, 63.74417871236801, 61.446236819028854, 64.65782448649406, 73.43646302819252, 69.6203126013279, 53.04584138095379, 23.400252051651478, 7.490732800215483, 0.6494628719519824, 0.8074548910371959, 3.184003997594118, 0.6693632947281003, 1.1061646998859942, 0.5289167154114693, 1.0987402545288205, 0.5275430297479033, 0.09273083269363269, 0.012053358641423983, 0.03402397174795624, 0.056251498754136264, 0.0561379316059174, 2.7380174165591598, 16.277372762560844, 35.634408071637154, 39.07614938914776, 56.03008724749088, 50.13639070093632, 34.84926000237465, 33.795314356684685, 15.755234230309725, 20.849963799118996, 40.42919218540192, 60.23981675505638, 67.82607927918434, 55.28007589280605, 14.577573873102665, 0.29015994106885046, 0.08623917790828273, 0.07049921274301596, 0.10512990134884603, 0.0717932808038313, 0.0379201060422929, 0.08295678489957936, 0.07265999054652639, 0.010201598142884905, 0.06650077339145355, 0.00386991723189567, 0.044252076622797176, 0.031847512364038266, 0.07466001916327514, 0.0516116211656481, 0.0517457198293414, 0.019556120059860405, 0.019306710200908128, 0.022107961449364666, 0.0455508387676673, 0.04644353852199856, 0.042789856452145614, 0.03996200663095806, 0.06324233690975234, 0.0897953640378546, 0.05364266413380392, 0.03742063694517128, 0.03252571288612671, 0.013040081084909616, 0.03929851547582075, 0.033772086826502346, 0.04334617035055999, 0.04113650356885046, 0.014761989859835012, 0.0841971585759893, 0.11337403397192247, 0.030368146726686973, 0.02610141356854001, 0.042656763398554176, 0.009499792686256114, 0.016090320095827337, 0.027777301766036544, 0.018609241669764742, 0.08608488540630788, 0.03917393856681883, 0.06477569564594887, 0.05909020248509478, 0.05723602072976064, 0.07075956556946039, 0.05435390135971829, 0.05190526302612852, 0.08753149450058118, 0.053352770119090565, 0.034738711910904385, 0.009760085213201819, 0.022416648498619907, 0.006795020171921351, 0.01076151238521561, 0.06142353333416395, 0.9797806909773499, 31.529674530029297, 75.01172930002213, 81.89691424369812, 77.36991316080093, 62.33939029276371, 47.01471000909805, 33.58539082109928, 32.517165541648865, 45.062484964728355, 63.71422491967678, 36.653509587049484, 38.785901963710785, 43.523084968328476, 32.09248133003712, 5.618553785607219, 0.0229814562771935, 0.07224787594168447, 0.0896030364674516, 0.4311689792666584, 0.38117375574074686, 1.2574672373011708, 3.1759631540626287, 5.320584224537015, 6.112917233258486, 6.8690885324031115, 4.593252427875996, 3.604119666852057, 3.1360011734068394, 3.914185641333461, 4.400242259725928, 10.65019866451621, 19.55608192831278, 28.08451719582081, 34.7170726954937, 45.864040553569794, 56.27791374921799, 59.9872101098299, 67.7390943467617, 67.89113938808441, 69.83875527977943, 72.77940228581429, 73.18237826228142, 64.26257729530334, 64.04220432043076, 64.34639319777489, 64.51702684164047, 65.07202506065369, 65.81686869263649, 65.35010933876038, 64.35064896941185, 63.575182780623436, 65.8804240822792, 69.05600488185883, 68.06611999869347, 67.56389334797859, 56.515625193715096, 67.85770878195763, 38.016089871525764, 36.09318785369396, 51.45410679280758, 48.87868478894234, 40.923883840441704, 41.64384260773659, 59.40944731235504, 67.60706663131714, 71.63079231977463, 75.78052684664726, 74.08817365765572, 69.6390075981617, 69.00542959570885, 66.42253339290619, 66.4430370926857, 64.26776021718979, 65.03695294260979, 64.22750517725945, 62.5283807516098, 62.932014092803, 69.99412894248962, 69.95846405625343, 70.20671233534813, 65.52978649735451, 65.48636242747307, 67.21588522195816, 76.42187163233757, 73.11440750956535, 54.8673914372921, 27.27379459887743, 9.653395302593708, 2.9332146048545837, 0.9156106843147427, 0.6233151687774807, 0.7947809679899365, 1.2712157308124006, 2.2388693131506443, 1.2974144937470555, 1.8919799895957112, 0.6793524837121367, 0.24228274764027447, 0.07540962542407215, 0.12767564272508025, 0.06253305153222755, 2.2034977236762643, 16.256783567368984, 32.32861205935478, 41.597329303622246, 51.40204578638077, 44.668453708291054, 30.796933248639107, 43.678166046738625, 25.95861867070198, 31.83043409138918, 48.729174211621284, 65.88449746370316, 76.7375510931015, 69.26923424005508, 22.36706279218197, 0.442675682133995, 0.11465038696769625, 0.02728427451074822, 0.09433526691282168, 0.07894431153545156, 0.03877628842019476, 0.043043585610575974, 0.06280537520069629, 0.013029323654336622, 0.08662151754833758, 0.022058990834921133, 0.057558450498618186, 0.036669642868218943, 0.03295641829026863, 0.03651516482932493, 0.01891146461275639, 0.02885147332563065, 0.032763400522526354, 0.019752928346861154, 0.03579751544748433, 0.04806506811291911, 0.10412345262011513, 0.040740141048445366, 0.08695836353581399, 0.09636936752940528, 0.06191648637468461, 0.038533064362127334, 0.0527805185993202, 0.028896948424517177, 0.06709740075166337, 0.047874636729829945, 0.02810718084219843, 0.16039593931054696, 0.12423021471477114, 0.12005884753307328, 0.20588270475855097, 0.12243164208484814, 0.21093420713441446, 0.2348060254007578, 0.1412060932489112, 0.21227520861430094, 0.08457221774733625, 0.14395340520422906, 0.13514844642486423, 0.13482990179909393, 0.2810373727697879, 0.19854237441904843, 0.12591385835548863, 0.1970426127081737, 0.166503636573907, 0.11286750333965756, 0.14668041199911386, 0.17293440556386486, 0.23473789624404162, 0.13288210553582758, 0.10525790698011406, 0.09208557981764898, 0.1606402691686526, 0.11674988563754596, 1.9395585427992046, 40.71214780211449, 84.724912494421, 89.8508982360363, 89.46876034140587, 69.73062828183174, 52.801453694701195, 34.50242601335049, 48.109514862298965, 50.45448303222656, 66.67531102895737, 58.525854125618935, 45.88312312960625, 61.15013010799885, 47.26615011692047, 10.498428158462048, 0.21313445235136896, 0.24111570557579398, 0.14060940651688725, 0.376185187487863, 0.494891174021177, 1.483368321787566, 3.5801990004256368, 8.673292994499207, 7.983326967805624, 13.647885359823704, 13.539849556982517, 12.939840853214264, 6.861920217052102, 8.453813921660185, 11.143841575831175, 12.391528375446796, 20.82790218293667, 30.303307436406612, 36.56410038471222, 47.067568972706795, 59.17876549065113, 65.32867848873138, 69.72742885351181, 70.98903715610504, 71.45531013607979, 76.52748316526413, 74.36113581061363, 64.46359410881996, 66.186383664608, 64.22645643353462, 65.65925315022469, 65.74678525328636, 65.0832724571228, 65.39992466568947, 63.97832214832306, 64.58768025040627, 67.2911211848259, 68.81457343697548, 67.18508407473564, 69.02947470545769, 57.989167124032974, 66.86903983354568, 43.03639568388462, 41.279875338077545, 56.68555587530136, 55.56368887424469, 45.7862663269043, 46.31680905818939, 62.81426601111889, 68.60143527388573, 73.23296874761581, 76.92572459578514, 74.35713082551956, 73.07601436972618, 71.42692565917969, 68.6439473927021, 67.92914494872093, 66.02098613977432, 68.93495097756386, 67.00631126761436, 64.1050073504448, 67.59749114513397, 72.1030081808567, 70.67338809370995, 73.45797747373581, 68.3811154961586, 67.03517451882362, 69.02912512421608, 78.99964570999146, 74.66221645474434, 57.44648404419422, 27.900842651724815, 10.809069089591503, 6.265415400266647, 3.6693282052874565, 8.377073239535093, 4.860665928572416, 3.3964743465185165, 4.268583599478006, 3.7163212336599827, 1.969533353112638, 0.45297989796381444, 0.27546363591682166, 0.20023754361318424, 0.40395454270765185, 0.2306085271993652, 4.044574219733477, 25.844501294195652, 47.979257851839066, 54.61836040019989, 76.70399129390717, 70.44501274824142, 49.95317593216896, 49.77354057133198, 26.40283953398466, 34.66437712311745, 57.873436734080315, 78.38245242834091, 83.90867069363594, 76.5562704205513, 24.437187910079956, 0.614992487244308, 0.19869510841090232, 0.12247833801666275, 0.25667299109045416, 0.27466876606922597, 0.14601935137761757, 0.14686912531033158, 0.15174614876741543, 0.16861259762663394, 0.20151835691649467, 0.08379463251912966, 0.15969726664479822, 0.07414796695229597, 0.17115667986217886, 0.14970147254643962, 0.15270740812411532, 0.15907717257505283, 0.1041665936645586, 0.10711119073675945, 0.18891768384492025, 0.16479215497383848, 0.17092325957491994, 0.16816367249703035, 0.2070435424684547, 0.18876175861805677, 0.15569124254398048, 0.12201056233607233, 0.18032523163128644, 0.07108113815775141, 0.1873809186508879, 0.1290019348380156, 0.13134427164914086], [0.05409747449448332, 0.03199357073754072, 0.04657112483982928, 0.04828605000511743, 0.06553769577294588, 0.018720868101809174, 0.034898845115094446, 0.04531250546278898, 0.03315535839647055, 0.034350694841123186, 0.07162130292272195, 0.05291898109135218, 0.03512415372824762, 0.0135507566119486, 0.0734567602921743, 0.0452231100643985, 0.020044061748194508, 0.04525718206423335, 0.06981190977967344, 0.05483633816766087, 0.03344192016811576, 0.05548919063585345, 0.033399283784092404, 0.021562865113082808, 0.04728365340270102, 0.03553261325578205, 0.15236793493386358, 11.9672317430377, 51.16803154349327, 68.23853954672813, 63.55895385146141, 59.97663527727127, 44.55090321600437, 21.90979152917862, 21.79906167089939, 27.233666852116585, 14.078347161412239, 25.24142235517502, 56.20754912495613, 44.0387324988842, 34.11464162170887, 4.892374277114868, 0.15787492302479222, 0.04096482996828854, 0.13666029029991478, 0.06981922735576518, 0.16197012359043583, 0.4803440108662471, 0.6306125584524125, 1.7966851405799389, 3.6030576238408685, 4.4019094202667475, 2.9146098531782627, 2.3457074677571654, 2.4151052813977003, 4.013448189944029, 7.919906945899129, 19.05524980276823, 34.45422559976578, 41.6081777215004, 49.58054132759571, 53.45257915556431, 59.63255234062672, 66.4935439825058, 67.89309248328209, 65.3015099465847, 62.62340605258942, 63.625716269016266, 66.05670422315598, 70.7019929587841, 68.46572935581207, 66.51596277952194, 67.43729934096336, 62.9780638217926, 63.3024638146162, 64.3370608985424, 65.81065982580185, 68.3084785938263, 68.08369785547256, 67.72106811404228, 64.41374078392982, 65.51619842648506, 65.47397509217262, 68.73822793364525, 66.47633850574493, 58.98687958717346, 26.862916946411133, 38.387291952967644, 37.98105575144291, 34.06976982951164, 56.548957005143166, 62.57543742656708, 63.70679631829262, 61.496006548404694, 63.412904888391495, 64.1821052134037, 61.928145959973335, 58.48164729773998, 61.52243033051491, 58.62600535154343, 58.13369616866112, 54.49773207306862, 60.35867817699909, 59.30898830294609, 64.91363435983658, 68.07379558682442, 64.64397802948952, 69.77396115660667, 65.08512675762177, 58.17023120820522, 59.51598219573498, 62.27634407579899, 67.20226675271988, 69.0995429456234, 64.88396555185318, 53.11375893652439, 36.20527043938637, 21.93320967257023, 5.0193653628230095, 0.667015970684588, 1.16547571728006, 1.650079982355237, 1.2969092396087945, 1.4277935726568103, 0.7007464638445526, 0.013865903129044455, 0.08095462631899863, 0.1763244767789729, 0.16005186480470002, 0.08050637654378079, 1.7410199088044465, 10.972302630543709, 29.661303386092186, 35.986668169498444, 45.3455925732851, 54.93821203708649, 23.77375490963459, 28.603105768561363, 17.32127744704485, 43.88234429061413, 50.05592621862888, 59.03391346335411, 69.12554115056992, 51.862641870975494, 7.3895565792918205, 0.17514863284304738, 0.047480641660513356, 0.05296426323184278, 0.031946065864758566, 0.06080035564082209, 0.026832664661924355, 0.08433211070951074, 0.0712600328552071, 0.07674445965676568, 0.06984886873397045, 0.028207433861098252, 0.0718511312152259, 0.04186889200354926, 0.08152312628226355, 0.04625816858606413, 0.02761258579994319, 0.08340345390024595, 0.05601682794804219, 0.031127220936468802, 0.013845044140907703, 0.03818945369857829, 0.04217949935991783, 0.04643370506528299, 0.023955311735335272, 0.06725781597197056, 0.04272919330105651, 0.037675664862035774, 0.050006819583359174, 0.043487263756105676, 0.044485745529527776, 0.044708545683533885, 0.013511197357729543, 0.04915213263302576, 0.017518557324365247, 0.019116516305075493, 0.1005461449676659, 0.03023606856004335, 0.0641885974619072, 0.0357509790774202, 0.07087267629685812, 0.03327302591060288, 0.03963855269830674, 0.010273985371895833, 0.034551186035969295, 0.038211261708056554, 0.0465841124241706, 0.03685399977257475, 0.024789407798380125, 0.02302678480191389, 0.060443133988883346, 0.04321473228628747, 0.019666599873744417, 0.0857729978451971, 0.008214928184315795, 0.055877367267385125, 0.05699753157387022, 0.06105865271820221, 0.060967505851294845, 16.159784272313118, 64.25857231020927, 77.6405194401741, 71.00283041596413, 66.78083136677742, 54.99230973422527, 34.152221605181694, 26.795713752508163, 30.391831286251545, 19.24964167177677, 35.811307579278946, 53.35793383419514, 43.59246164560318, 33.66403140127659, 5.302887624129653, 0.0916828608023934, 0.11305832435027696, 0.1319965155562386, 0.3107454552082345, 0.8774560410529375, 1.4232838083989918, 4.365886403247714, 4.819579208269715, 3.9681873936206102, 5.072804745286703, 3.3094127057120204, 1.6218640026636422, 2.612706790678203, 4.342801691964269, 8.758039847016335, 20.79314734786749, 33.95724266767502, 40.992443561553955, 51.89475774765015, 55.133700147271156, 61.1668948084116, 70.81285580992699, 71.82657301425934, 68.83625507354736, 66.81093335151672, 65.67832052707672, 69.42073971033096, 71.17278769612312, 67.93515622615814, 66.25025823712349, 67.24955141544342, 65.33035799860954, 64.2627064883709, 65.50183519721031, 68.2993134856224, 68.5392402112484, 69.6723622083664, 68.9013683795929, 67.12415054440498, 67.4425582587719, 67.28283002972603, 67.15165346860886, 65.51300659775734, 58.915887996554375, 30.967390201985836, 43.58743831515312, 43.114895671606064, 39.00592155754566, 57.30633616447449, 65.0186151266098, 65.55433318018913, 64.36360627412796, 65.26554867625237, 65.94234555959702, 65.4129883646965, 62.69166938960552, 64.26784381270409, 61.15280896425247, 60.70358946919441, 57.297201454639435, 60.92135198414326, 62.47874401509762, 69.09236133098602, 68.19943204522133, 67.25538790225983, 72.92400732636452, 67.63924330472946, 60.74540242552757, 61.726714968681335, 65.92993542551994, 71.73670783638954, 70.28681203722954, 67.96002209186554, 58.471710830926895, 39.097378849983215, 25.241410955786705, 5.6378880981355906, 0.9466212359257042, 0.8772642107214779, 1.0096786147914827, 1.858657083939761, 2.546528591774404, 1.4419152773916721, 0.5256867699790746, 0.3625857172301039, 0.14937460102373734, 0.1467620927724056, 0.1238918918534182, 1.8599062669090927, 11.737703159451485, 30.037023425102234, 38.943813890218735, 47.975963428616524, 52.39229924976826, 21.75316583365202, 29.04518734663725, 23.779950477182865, 52.486306205391884, 58.27379085123539, 62.49142773449421, 79.4142946600914, 69.0944816172123, 10.482847094535828, 0.25252874940633774, 0.020251607056707144, 0.08968347785412334, 0.040566719690104946, 0.035642380607896484, 0.011507623130455613, 0.04457578659639694, 0.02534614657633938, 0.0324431192711927, 0.024807065346976742, 0.007052159498925903, 0.06555188563652337, 0.052016143599757925, 0.022576846640731674, 0.03855876864690799, 0.06358661179547198, 0.018041504263237584, 0.07297387448488735, 0.03734521247679368, 0.025118856428889558, 0.030202254456526134, 0.038090629313956015, 0.04579932094202377, 0.03234533389331773, 0.02062979623588035, 0.03474949160590768, 0.0068789682063652435, 0.021920363215031102, 0.05359708142350428, 0.0482995348284021, 0.05413654485892039, 0.1320306840352714, 0.15947941661579534, 0.15826260612811893, 0.21889973751967773, 0.1561489695450291, 0.15054971765493974, 0.2714393549831584, 0.13336919189896435, 0.17903200961882249, 0.07560083977296017, 0.2550660929409787, 0.18275235139299184, 0.14652708428911865, 0.07064333040034398, 0.1858907751739025, 0.16933911567321047, 0.13900883146561682, 0.11177450534887612, 0.1360896381083876, 0.12154665324487723, 0.0940531468950212, 0.15596660901792347, 0.24700699257664382, 0.16488440393004566, 0.19854724290780723, 0.1361918170005083, 0.421282562892884, 21.081027500331402, 79.00976076722145, 87.69318401813507, 82.15461641550064, 75.54475709795952, 60.84302298724651, 36.34468495845795, 33.96257758140564, 39.389552772045135, 24.481402337551117, 40.675779953598976, 76.7979146540165, 61.65963716804981, 47.878437861800194, 7.827229918912053, 0.37865104735828936, 0.15171451843343675, 0.5518207582645118, 0.3674471704289317, 1.0541952447965741, 2.50096523668617, 4.691762616857886, 6.7592597007751465, 11.26489358022809, 14.144399967044592, 12.427163813263178, 10.546573475003242, 8.375505823642015, 9.212034735828638, 13.512751311063766, 25.166260488331318, 38.57107289135456, 46.39659717679024, 53.097803592681885, 55.83290062844753, 60.94377838075161, 69.75087359547615, 73.98334488272667, 72.57356733083725, 69.75205153226852, 69.07406151294708, 70.90247020125389, 74.16650265455246, 69.71280723810196, 66.67369231581688, 67.7419213950634, 65.08962571620941, 64.69689399003983, 64.92926672101021, 67.8678922355175, 70.30505105853081, 71.5950134396553, 71.94555222988129, 69.47294130921364, 69.20970663428307, 69.04554024338722, 68.25867086648941, 66.67622298002243, 62.17849172651768, 34.71599355340004, 48.71251970529556, 48.255164846777916, 43.44294726848602, 60.86340509355068, 66.40614867210388, 67.447110414505, 67.61215835809708, 65.60126826167107, 69.81414020061493, 68.25659617781639, 64.55130860209465, 68.00698757171631, 64.12064731121063, 61.457263827323914, 59.58093211054802, 64.54754680395126, 64.87701952457428, 70.69331422448158, 71.24604776501656, 69.41101223230362, 75.33597350120544, 71.526670306921, 63.20998057723045, 65.19412010908127, 68.46574455499649, 74.71445605158806, 72.8903791308403, 70.65549105405807, 63.74897785484791, 45.889407992362976, 26.39186952263117, 7.014704318717122, 2.703118189238012, 3.30514719709754, 5.514416573569179, 5.9649336989969015, 4.16754987090826, 1.9354032282717526, 0.4151766170980409, 0.4880241706268862, 0.40466937934979796, 0.3060074063250795, 0.1914819673402235, 3.2137837121263146, 17.768752835690975, 41.968060210347176, 50.70106700062752, 60.41504055261612, 67.13473677635193, 33.674910217523575, 41.45953729748726, 28.52192882448435, 61.670641377568245, 65.7983560860157, 74.59380492568016, 86.98801025748253, 78.97098764777184, 11.248397715389729, 0.3674003260675818, 0.16132847755216062, 0.21207255776971579, 0.2662078372668475, 0.1472328370437026, 0.11213189398404211, 0.1248252167715691, 0.14650479017291218, 0.17365201783832163, 0.14903925417456776, 0.23597544233780354, 0.11425039905589074, 0.18491829454433173, 0.15144074015552178, 0.16366131487302482, 0.2213051717262715, 0.14277000620495528, 0.16288943676045164, 0.097847265569726, 0.14227879350073636, 0.1183781650615856, 0.10319807610358112, 0.14184821426169947, 0.0956623160163872, 0.07693955543800257, 0.19743964687222615, 0.10602946596918628, 0.10738358861999586, 0.11385642254026607, 0.13477651169523597, 0.13376693852478638], [0.05386383527365979, 0.01901393108710181, 0.0730179728998337, 0.0005055090775840654, 0.022778809143346734, 0.023729047607048415, 0.0333410994062433, 0.055657765769865364, 0.0809497875161469, 0.036511498619802296, 0.01710932410787791, 0.06532294792123139, 0.059063941589556634, 0.037587898477795534, 0.03896050802723039, 0.0711496606527362, 0.011306744163448457, 0.0740925878926646, 0.046126719389576465, 0.06603462301427498, 0.09020524477818981, 0.07142708287574351, 0.07591421905090101, 0.0679441393003799, 0.06894627615110949, 0.00869332863658201, 4.719325862824917, 55.23597925901413, 68.30236092209816, 63.86642575263977, 62.58777156472206, 45.46903654932976, 25.839888341724873, 19.03199315071106, 26.617121435701847, 40.052928775548935, 39.20056611299515, 27.78593111783266, 30.53089052438736, 33.65868128836155, 6.294109560549259, 0.08543887553969398, 0.06537428969750181, 0.03870953594741877, 0.16167942434549332, 0.6831893278285861, 1.4871587371453643, 1.0311835608445108, 3.979665390215814, 4.134781854227185, 2.588710840791464, 6.741149397566915, 4.289024602621794, 1.5174350375309587, 11.054565366357565, 21.57012775540352, 39.88147437572479, 49.48844566941261, 52.76128605008125, 58.72932180762291, 59.566504284739494, 63.80158603191376, 64.85887929797173, 69.76460605859756, 63.4588710218668, 62.90667325258255, 58.75796087086201, 57.51610390841961, 63.50480675697327, 65.73613822460175, 65.45475572347641, 65.67997723817825, 62.45500288903713, 64.45960432291031, 64.5416571199894, 66.23394191265106, 64.43338572978973, 64.38775777816772, 61.43782027065754, 63.47642607986927, 61.61585591733456, 61.785600408911705, 62.20984764397144, 62.542614787817, 62.96507231891155, 65.55209130048752, 47.068845704197884, 21.803556829690933, 32.405405938625336, 49.628281965851784, 64.56417471170425, 63.294533640146255, 63.640558272600174, 57.47789315879345, 56.45398870110512, 56.3860597461462, 57.59065590798855, 53.78633804619312, 55.36110274493694, 51.36377424001694, 53.6652347445488, 52.739061042666435, 58.02684970200062, 62.90891893208027, 62.95090287923813, 63.06449398398399, 63.051031306385994, 64.49138581752777, 66.37353122234344, 52.73276478052139, 55.823674723505974, 62.467849999666214, 67.02347114682198, 60.65077230334282, 58.201549127697945, 49.44573596119881, 65.42922109365463, 58.97036947309971, 48.005138263106346, 24.87719289958477, 4.3057584296911955, 0.5032074730843306, 0.86617112159729, 2.371331392787397, 1.0545456572435796, 0.737738428870216, 0.09879060206003487, 0.13791318400762975, 0.07188581919763237, 0.12558296439237893, 0.07173765683546662, 0.28381932817865163, 4.1675422713160515, 22.749004997313023, 45.085808113217354, 32.909137308597565, 59.14883069694042, 34.44350637495518, 18.596183136105537, 25.681841522455215, 47.27716572582722, 50.15270322561264, 65.4373450577259, 67.18012154102325, 23.712411001324654, 0.964510201010853, 0.1733890749164857, 0.162760021048598, 0.10292305843904614, 0.029009858772042207, 0.04838481872866396, 0.04829819896258414, 0.07768634153762832, 0.0421767163061304, 0.024132063481374644, 0.011966794536419911, 0.009227082173310919, 0.11877948141773231, 0.03317891045298893, 0.009605252798792208, 0.03515775075356942, 0.15127053600735962, 0.03367719953530468, 0.03190341834852006, 0.032238479470834136, 0.03769042989006266, 0.059090610666316934, 0.08139973680954427, 0.027931764961977024, 0.07980981899891049, 0.03265132509113755, 0.013187285148887895, 0.06051282165572047, 0.03710290868184529, 0.07493410172173753, 0.027153732589795254, 0.04683914034103509, 0.0577382691699313, 0.029403729531622957, 0.029502190263883676, 0.06873447462567128, 0.05448458614409901, 0.033321721930406056, 0.014379376552824397, 0.041957738212659024, 0.07308583488338627, 0.013261114927445306, 0.01868019469839055, 0.07548762514488772, 0.03355618864588905, 0.06560008812812157, 0.030186615549609996, 0.02094355771987466, 0.046726396976737306, 0.042043545327032916, 0.021811187725688796, 0.04326685331761837, 0.035763291307375766, 0.021057328958704602, 0.03974195242335554, 0.025235583270841744, 0.10305562085704878, 6.727630672976375, 67.0460419356823, 77.2149270772934, 73.60430002212524, 69.68562349677086, 57.44388498365879, 33.95421423017979, 26.291237622499466, 31.268873624503613, 31.266673542559147, 42.093875259160995, 35.49704164266586, 37.73946091532707, 34.359226897358894, 6.5195253398269415, 0.04895121470326558, 0.05442881374619901, 0.05728393007302657, 0.5866607918869704, 1.5430844924412668, 3.504585432820022, 3.475067666731775, 5.911204582080245, 8.671707529574633, 5.842442521825433, 4.930551303550601, 0.2034940430894494, 2.759987125173211, 11.11705206334591, 23.579910211265087, 41.63447231054306, 50.39993315935135, 53.168513998389244, 59.28883798420429, 60.25796078145504, 62.48412072658539, 67.34865009784698, 69.82639074325562, 66.0591284930706, 64.57288384437561, 61.60292141139507, 59.78724583983421, 66.31645068526268, 66.21488213539124, 64.54621687531471, 62.216349095106125, 61.45996168255806, 62.836232632398605, 66.51571959257126, 67.81312197446823, 67.51606151461601, 66.24561488628387, 64.3077340722084, 66.73822045326233, 64.17059183120728, 65.95608562231064, 64.00140970945358, 66.69355005025864, 64.81644317507744, 66.1258453130722, 49.22863461077213, 27.021885216236115, 37.52805545926094, 52.528822124004364, 65.54915025830269, 65.14697223901749, 64.78260219097137, 58.9885400980711, 60.07169857621193, 58.27263571321964, 60.940696746110916, 56.96595422923565, 58.98687958717346, 55.370400846004486, 56.33847489953041, 55.782910510897636, 61.766187250614166, 64.71701011061668, 64.85169768333435, 66.84314802289009, 64.54086676239967, 68.56435686349869, 67.92069420218468, 57.21751973032951, 58.724883645772934, 66.01707994937897, 72.77610406279564, 66.3950152695179, 63.35119999945164, 56.42163343727589, 70.96797868609428, 63.22182834148407, 52.43989169597626, 28.203836493194103, 5.539329936727881, 0.4340484825661406, 1.3627097150310874, 1.3340073614381254, 3.1150984950363636, 3.4725555265322328, 0.6648282380774617, 0.7634269504342228, 0.15092396788531914, 0.15803239191882312, 0.03753848257474601, 0.07590487541165203, 4.099931549280882, 19.677553810179234, 45.97483120858669, 30.17166920006275, 41.33365385234356, 28.683423958718777, 19.233008064329624, 39.503174275159836, 52.85287253558636, 60.38868136703968, 69.67037111520767, 80.51921457052231, 35.86574725806713, 1.4304428617469966, 0.1854000671301037, 0.04568900440062862, 0.11459972796728835, 0.035794353898381814, 0.005764558791270247, 0.05407584831118584, 0.01105033399653621, 0.05675114967743866, 0.05394979081756901, 0.08542438139556907, 0.04678047356719617, 0.03180028579663485, 0.029814651134074666, 0.013168456862331368, 0.024683948613528628, 0.05619521427433938, 0.031601482987753116, 0.0154280970855325, 0.032961817414616235, 0.0363427639240399, 0.06282875285251066, 0.044277127817622386, 0.03283396021288354, 0.09062169352546334, 0.045679909380851313, 0.02862645786080975, 0.03571744142391253, 0.10205309808952734, 0.057356167017132975, 0.0787841560668312, 0.19254546496085823, 0.08178160147508606, 0.20445910224225372, 0.13818277657264844, 0.15328969719121233, 0.16204957792069763, 0.1655500807100907, 0.07696889995713718, 0.1619823244982399, 0.17021538427798077, 0.12060845983796753, 0.11526452901307493, 0.1774842309532687, 0.23080302926246077, 0.1901886859559454, 0.1279920499655418, 0.17006043868605047, 0.23635953344637528, 0.13661849254276603, 0.20309433719376102, 0.18950736470287666, 0.3425773268099874, 0.09507229377049953, 0.20455972262425348, 0.127481511735823, 0.4483521025395021, 9.495957400649786, 78.4850849211216, 89.14903789758682, 82.98264518380165, 80.98082140088081, 63.93403172492981, 38.85411590337753, 28.957423456013203, 39.76587317883968, 55.37857800722122, 54.89070698618889, 39.56107176840305, 44.664201736450195, 46.63717746734619, 9.934437721967697, 0.24310006003361195, 0.18480041180737317, 0.22156153921969235, 0.316021412727423, 1.7713581933639944, 4.653276856988668, 4.097039429470897, 9.77033307775855, 10.16323959454894, 7.86338877864182, 13.629555143415928, 9.46271013468504, 6.509994501248002, 15.203994009643793, 25.840163826942444, 43.57220873236656, 52.76073507964611, 58.26120972633362, 61.47056311368942, 60.232771933078766, 63.28035280108452, 67.80192017555237, 75.05067721009254, 68.950165361166, 67.48795822262764, 65.01987665891647, 63.13534498214722, 68.40594336390495, 69.14973065257072, 66.50310426950455, 63.132358342409134, 60.93370892107487, 65.41402190923691, 68.69214400649071, 70.20035907626152, 69.24459636211395, 69.66201156377792, 66.79354548454285, 70.76910495758057, 67.17528820037842, 69.8374405503273, 67.60387480258942, 68.8685305416584, 69.1211485862732, 66.66559115052223, 50.72117172181606, 30.219206549227238, 42.50589855015278, 53.28494735062122, 67.23440542817116, 67.00678244233131, 67.75291800498962, 62.786812484264374, 62.572887763381004, 62.325597032904625, 62.285592779517174, 59.759309738874435, 63.557095751166344, 56.849954053759575, 60.12668922543526, 56.76543518900871, 63.64079765975475, 68.0652916431427, 66.291174441576, 66.59405618906021, 67.76604250073433, 70.64121142029762, 71.99314087629318, 59.98868443071842, 60.300214514136314, 68.93051281571388, 75.11650487780571, 69.5060907304287, 65.69109544157982, 55.97821623086929, 70.39073646068573, 66.26525223255157, 54.44555327296257, 29.01553563773632, 6.718411892652512, 3.6884715780615807, 4.499019384384155, 7.596022775396705, 5.295749707147479, 3.2868509413674474, 0.3880908095743507, 0.6787572812754661, 0.3570989007130265, 0.32890868838876486, 0.1822720779455267, 0.6433490593917668, 6.940917503088713, 32.531999945640564, 62.733672335743904, 48.645472303032875, 77.1508701145649, 50.94373717904091, 29.420367814600468, 41.94275736808777, 62.00588978827, 69.01745975017548, 77.82361641526222, 87.7924194931984, 39.69460800290108, 1.8392498628236353, 0.33997066668234766, 0.24066035344731063, 0.22045826248358935, 0.18961782596306875, 0.13699442002689466, 0.2770850801607594, 0.1566650887252763, 0.1362650076043792, 0.12385165260639042, 0.11700874674716033, 0.09051487621036358, 0.2779973577708006, 0.08501100513967685, 0.08845477816066705, 0.10192879577516578, 0.2810318215051666, 0.13182447088183835, 0.10029861645307392, 0.1621940147015266, 0.18694138911087066, 0.20380822388688102, 0.23108369467081502, 0.12308511053561233, 0.23627032729564235, 0.13736028398852795, 0.09618089912692085, 0.15271738258888945, 0.18035021232208237, 0.12560893956106156, 0.21455634792800993], [0.012923810663778568, 0.0552187928406056, 0.02034020650171442, 0.015329243942687754, 0.008140028785419418, 0.05707245880330447, 0.023226971716212574, 0.055773648418835364, 0.01743675038596848, 0.0273382138038869, 0.03393526283616666, 0.007406480281133554, 0.03646136283350643, 0.04800974842510186, 0.02564820068073459, 0.1113783914479427, 0.0377925160137238, 0.05699031418771483, 0.03200146718882024, 0.11046084458939731, 0.06449114880524576, 0.06633779776166193, 0.03277767202234827, 0.02746276844845852, 0.02818247172399424, 0.13625785330077633, 21.8012560531497, 73.17191362380981, 70.75826793909073, 65.16143426299095, 55.05589172244072, 28.23584407567978, 20.00935200601816, 27.27983247488737, 22.694715410470963, 33.406542018055916, 25.765558630228043, 38.60095448791981, 36.24399036169052, 7.850036295130849, 0.27852594503201544, 0.05236950237303972, 0.07598801821586676, 0.08418233788688667, 0.3307575860526413, 0.296223257901147, 0.9345328970812261, 1.410422211047262, 3.6950689740478992, 7.131450204178691, 2.1507472917437553, 2.7388614462688565, 9.101879596710205, 25.73238831013441, 50.643800273537636, 55.94565577805042, 65.92559605836868, 63.987700045108795, 64.13731321692467, 58.24476420879364, 61.74621932208538, 57.912985011935234, 64.11465123295784, 63.959247171878815, 61.351036727428436, 56.127890199422836, 54.739566296339035, 58.29267963767052, 62.094607427716255, 65.82082808017731, 63.26483063399792, 58.865928277373314, 62.40593612194061, 62.4271921813488, 63.210668340325356, 62.378402799367905, 61.25600762665272, 59.5819428563118, 58.05754825472832, 57.3555663228035, 61.2264110147953, 61.00831791758537, 60.79403981566429, 65.05009263753891, 63.49036753177643, 61.56357832252979, 66.99475228786469, 26.23957559466362, 28.37737128138542, 59.292064011096954, 57.198706939816475, 65.76785892248154, 60.01470163464546, 60.3304722905159, 53.982882499694824, 53.68733435869217, 51.14019803702831, 52.94010825455189, 52.08567090332508, 54.75836008787155, 51.53197221457958, 56.48073546588421, 57.694481536746025, 65.40567755699158, 65.34347489476204, 56.286573484539986, 59.05974067747593, 65.18117040395737, 63.0024129152298, 55.4785430431366, 50.03041058778763, 56.965110674500465, 60.17651975154877, 69.90751639008522, 64.79276284575462, 64.85232844948769, 53.56824114918709, 55.144065991044044, 58.02262432873249, 59.29813228547573, 43.52724954485893, 13.406815845519304, 0.6783803889993578, 1.6687774728052318, 1.8021653965115547, 1.293884958140552, 0.6889330164995044, 0.4826380783924833, 0.02425413935270626, 0.10362923421780579, 0.005122756438140641, 0.1526631909655407, 0.22760578285669908, 1.4302377915009856, 12.909765467047691, 48.23035217821598, 48.958252519369125, 46.48123003542423, 30.90024210512638, 23.028345108032227, 38.05344946682453, 48.79651419818401, 58.852723985910416, 67.0877180993557, 60.57791881263256, 19.2451199144125, 0.5286103568505496, 0.40147193998564035, 0.054410111624747515, 0.1638248100061901, 0.06557397937285714, 0.053379843666334637, 0.03208829846698791, 0.060961654016864486, 0.023407966691593174, 0.05185060384974349, 0.05797186015115585, 0.03095825988566503, 0.0020025484400321147, 0.013663539866684005, 0.04534654777671676, 0.03679044595628511, 0.06257537621422671, 0.022789150971220806, 0.012396708625601605, 0.04574624625092838, 0.029040297958999872, 0.01288384415602195, 0.031786240651854314, 0.047260984501917847, 0.008243734646384837, 0.02263214406411862, 0.04991915338905528, 0.013687420323549304, 0.028706619086733554, 0.0199740382595337, 0.0662087308592163, 0.023259295958268922, 0.039190970855997875, 0.02360151138418587, 0.030295366159407422, 0.02752290281932801, 0.0572262021159986, 0.03371426239027642, 0.019673837668960914, 0.05749036216002423, 0.014449304489971837, 0.03536073927534744, 0.08766832426772453, 0.082108547212556, 0.02667674871190684, 0.023024252222967334, 0.01576752296386985, 0.07386057026451454, 0.02642245737661142, 0.039158286672318354, 0.04494150954997167, 0.07675873857806437, 0.04272484060493298, 0.05717503845517058, 0.022757726583222393, 0.30353032518178225, 29.881030395627022, 84.33291032910347, 77.77183279395103, 74.49792087078094, 65.86426734924316, 39.3569391220808, 28.439363054931164, 27.3617921769619, 24.407188519835472, 42.486189007759094, 36.0630364716053, 34.401769414544106, 29.974784664809704, 6.664080983027816, 0.2843666769331321, 0.034260264146723785, 0.3025207668542862, 0.5737154802773148, 1.8014916451647878, 3.325817850418389, 4.753364436328411, 3.2175003876909614, 4.284820603206754, 5.376464975997806, 2.2997501213103533, 2.6188731472939253, 9.445392563939095, 29.495911560952663, 50.96924901008606, 59.63816083967686, 66.21400058269501, 66.43786936998367, 67.60313764214516, 59.81898933649063, 61.769436076283455, 60.10581314563751, 66.68053194880486, 67.75034934282303, 63.80571261048317, 58.42425897717476, 55.82992918789387, 60.6744260340929, 63.057703748345375, 67.58115202188492, 63.70833523571491, 59.1082488745451, 63.52716475725174, 64.01735365390778, 64.89828318357468, 63.91685664653778, 63.664295598864555, 62.03716591000557, 61.72386132180691, 61.072994247078896, 63.72961029410362, 63.600443825125694, 63.09146873652935, 66.45781069993973, 65.17663344740868, 64.12380114197731, 65.60754552483559, 29.24038477241993, 31.559962704777718, 59.731784015893936, 57.829275503754616, 66.75425559282303, 61.92572548985481, 63.26536640524864, 56.059725657105446, 56.40033558011055, 53.13435383141041, 55.93826897442341, 55.010301768779755, 56.40062436461449, 54.19186368584633, 58.86929489672184, 60.73948614299297, 67.28156849741936, 66.23274117708206, 56.73367269337177, 62.71707862615585, 67.21053510904312, 66.08761176466942, 58.112565502524376, 52.85946898162365, 59.25017885863781, 63.20831626653671, 72.79463186860085, 69.70991179347038, 67.67062202095985, 57.11225397884846, 58.951518684625626, 60.25702603161335, 63.65903668105602, 50.2394487708807, 17.37208642065525, 1.7947565065696836, 1.0285240598022938, 2.773479726165533, 1.9479867280460894, 2.1459296252578497, 1.5188482054509223, 0.22977975604590029, 0.1439842488616705, 0.03482896448986139, 0.18826751795131713, 0.10485273887752555, 1.5383193106390536, 11.760901864618063, 45.06738670170307, 50.09952887892723, 45.166895762085915, 29.761787094175816, 27.096574008464813, 49.63873140513897, 57.323355451226234, 67.60769739747047, 70.882498472929, 78.65038365125656, 31.732500046491623, 0.8105625305324793, 0.4902496637078002, 0.1878764951834455, 0.08009840312297456, 0.04203610529657453, 0.03763345521292649, 0.033925240131793544, 0.021212935062067118, 0.033784206098061986, 0.04786778299603611, 0.05352330452296883, 0.04083528066985309, 0.028823559296142776, 0.05131998310389463, 0.06529765552841127, 0.02003218552999897, 0.0343669367430266, 0.0676939167897217, 0.030464867122645956, 0.020366582430142444, 0.030581345345126465, 0.020028454382554628, 0.03266446481575258, 0.046216300324886106, 0.02306849906744901, 0.03734818848897703, 0.05316518487234134, 0.04755648544232827, 0.04727810955955647, 0.07708003657171503, 0.105183068808401, 0.13113143853843212, 0.10084416921017691, 0.11005690845195204, 0.051599286671262234, 0.16580006573349237, 0.160957284970209, 0.053982122481102124, 0.21761199255706742, 0.1253881654702127, 0.07513647797168233, 0.10636258637532592, 0.1748644793406129, 0.24344815697986633, 0.20188687776681036, 0.24765680223936215, 0.19812325394013897, 0.1760139176622033, 0.11142034505610354, 0.1654987537767738, 0.12776033661793917, 0.16415919206338003, 0.14936140563804656, 0.14814658410614356, 0.1384893132490106, 0.576909149531275, 42.70111307501793, 92.25084185600281, 87.28381678462029, 85.07596045732498, 71.39093399047852, 42.29621820151806, 31.694627478718758, 40.58106243610382, 34.85540807247162, 46.96322277188301, 33.396594151854515, 50.6434278935194, 48.09218779206276, 12.41688821464777, 0.7352853042539209, 0.1261836735648103, 0.3788511600578204, 0.5489905038848519, 2.004527812823653, 3.647214104421437, 4.161704834550619, 5.971413776278496, 9.734984524548054, 14.966734740883112, 8.077229429036379, 7.153291432186961, 12.531997337937355, 31.80277917534113, 56.79652892053127, 62.15174116194248, 69.24800097942352, 69.26389932632446, 67.07315728068352, 61.49132899940014, 63.429027423262596, 59.36855390667915, 68.95533308386803, 71.59292355179787, 66.41734287142754, 61.943451538681984, 59.10014010965824, 63.650832921266556, 64.54756200313568, 70.94749018549919, 65.34304171800613, 58.81460443139076, 64.20216053724289, 64.92406100034714, 67.35988989472389, 65.64611345529556, 66.57400086522102, 65.1897731423378, 63.03558513522148, 64.6471318602562, 67.15695038437843, 66.63251012563705, 65.75180858373642, 70.45341029763222, 66.8364679813385, 66.86057388782501, 67.96857923269272, 33.92531298100948, 37.638739719986916, 59.457780718803406, 58.80023740231991, 68.92840012907982, 64.30416986346245, 65.56191757321358, 58.13398115336895, 59.634041860699654, 57.71286495029926, 57.87638157606125, 59.36605364084244, 60.7600012421608, 56.3214860111475, 60.59554986655712, 63.58597420156002, 69.91896137595177, 68.83163452148438, 59.06184196472168, 62.46562711894512, 69.7581996023655, 70.23728549480438, 59.76473204791546, 56.209517419338226, 62.55525290966034, 67.47169509530067, 77.38890454173088, 71.46828263998032, 68.9107994735241, 59.30732399225235, 60.17914921045303, 62.58328780531883, 66.80058270692825, 50.57690106332302, 16.804106198251247, 2.327034082263708, 6.031716540455818, 7.586112432181835, 4.939692188054323, 3.8696023961529136, 0.8400820184033364, 0.20054603955941275, 0.2471484013949521, 0.2988754858961329, 0.5022048018872738, 0.5659420473966748, 2.6725048944354057, 19.019869901239872, 65.90395241975784, 67.00215429067612, 63.06715004146099, 48.04665103554726, 36.20376192033291, 53.739638552069664, 66.2542100250721, 77.55506202578545, 79.18994709849358, 89.18024942278862, 33.57317067682743, 1.185652872081846, 0.5663482693489641, 0.2196527799242176, 0.2148684358689934, 0.09399612026754767, 0.22210854658624157, 0.2987937902798876, 0.2767682424746454, 0.13127324811648577, 0.17479802743764594, 0.17334407108137384, 0.065835653222166, 0.13538777420762926, 0.14107789465924725, 0.16058975859778002, 0.1586454504285939, 0.12278936468646862, 0.21043898683274165, 0.12695761484792456, 0.12493949267081916, 0.0689805114234332, 0.1594148646108806, 0.08684330096002668, 0.13483954971889034, 0.14198111806763336, 0.11191805897396989, 0.16086162213468924, 0.1588795831776224, 0.14399417879758403, 0.10421033584862016], [0.010121140057890443, 0.0071993264555203496, 0.06006310613884125, 0.04221839531965088, 0.07193935773102567, 0.059021928609581664, 0.10738616387243383, 0.09691615967312828, 0.021561312169069424, 0.032017260091379285, 0.03955291998863686, 0.038828992037451826, 0.014476618307526223, 0.013848727976437658, 0.03407086434890516, 0.03550457491655834, 0.01872882763564121, 0.08660170962684788, 0.039246375890797935, 0.053038392652524635, 0.016549620449950453, 0.01811226989957504, 0.12173297684057616, 0.03239744379243348, 0.03843711208901368, 6.288566133007407, 55.90975530445576, 67.1117328107357, 65.80471694469452, 57.61647172272205, 36.07165440917015, 28.07133760303259, 23.516254127025604, 39.78231869637966, 41.336617693305016, 27.400591894984245, 44.337563663721085, 37.6130037009716, 8.461924586445093, 0.17409929540008307, 0.09645856625866145, 0.03186524598277174, 0.10134768672287464, 0.2536700537893921, 1.4255480119027197, 2.3306222772225738, 5.135560277849436, 3.8079865649342537, 2.7037499053403735, 2.8844786575064063, 11.828746274113655, 27.63050615787506, 52.00152441859245, 64.53667178750038, 64.69797313213348, 63.47110636532307, 63.297174498438835, 65.70302680134773, 62.12730847299099, 68.33436280488968, 57.08138823509216, 60.39279654622078, 66.05546548962593, 58.687778636813164, 57.27789469063282, 51.83911733329296, 52.78050921857357, 54.118276834487915, 60.662430077791214, 62.63933099806309, 62.258606627583504, 58.87301489710808, 63.625226095318794, 61.82886488735676, 61.348369270563126, 57.302441373467445, 58.38419012725353, 53.0804955214262, 55.7992572337389, 51.038789078593254, 57.76718683540821, 52.55361199378967, 58.95096391439438, 53.805181235075, 61.67095676064491, 55.86772195994854, 70.3750205039978, 34.77359466254711, 29.668015725910664, 67.40111768245697, 54.29030500352383, 61.85006394982338, 58.35767135024071, 63.48943658173084, 57.48499497771263, 63.829848915338516, 57.93858803808689, 58.12761649489403, 54.67328645288944, 54.557016491889954, 54.35779698193073, 58.19406732916832, 61.07091575860977, 62.82556280493736, 62.62777201831341, 58.23826275765896, 62.679453045129776, 66.08882769942284, 54.83864977955818, 48.51467952132225, 48.66519324481487, 53.80815267562866, 58.39557811617851, 65.73552265763283, 65.62994912266731, 60.66372200846672, 62.77949407696724, 60.34800834953785, 62.96234406530857, 65.57151585817337, 65.41533663868904, 60.81183426082134, 30.266804695129395, 3.501406190916896, 3.4379199100658298, 4.880071487277746, 1.6708140447735786, 1.610731550026685, 0.2320819575106725, 0.14373095385963097, 0.04404424558742903, 0.12041654787026346, 0.03566751714970451, 0.037946882730466314, 0.5508436763193458, 9.819317199289799, 38.61368000507355, 33.73810462653637, 32.70668037235737, 21.569994762539864, 15.682836715131998, 42.52480633556843, 49.50725086033344, 54.5658054202795, 58.816751316189766, 56.55560664832592, 11.755900382995605, 0.6124369462486356, 0.19975532573880628, 0.07888927386375144, 0.022675622785754967, 0.0768083511502482, 0.0499223149381578, 0.07185771406511776, 0.04626914866094012, 0.024953071770141833, 0.08884790120646358, 0.04086317800101824, 0.017081742189475335, 0.08639603824121878, 0.023862840134825092, 0.04995304727344774, 0.0041413918370381, 0.033185571228386834, 0.027108051544928458, 0.023616309808858205, 0.03469658018730115, 0.07840250662411563, 0.056930222490336746, 0.06085576809709892, 0.042359151048003696, 0.0389800710399868, 0.0031949840149536612, 0.09770368968020193, 0.07897845032857731, 0.09872500362689607, 0.03801710845436901, 0.03661191862192936, 0.009161322323052445, 0.0455471206078073, 0.039826338324928656, 0.054280046533676796, 0.048035263462224975, 0.025834266380115878, 0.06734899623552337, 0.040536503147450276, 0.12947337672812864, 0.012966570429853164, 0.013460882528306684, 0.08286604992463253, 0.05748495561419986, 0.06392259689164348, 0.02796625627524918, 0.043628631756291725, 0.08296319705550559, 0.02916229590482544, 0.0017474169703746156, 0.05557290860451758, 0.0761488193529658, 0.06453651629271917, 0.06446753366617486, 10.636252462863922, 70.9087398648262, 75.51141008734703, 75.93908473849297, 66.29891082644463, 47.47425734996796, 34.51108954846859, 26.88768781721592, 32.91797183454037, 35.65923593938351, 29.31019652634859, 33.322213143110275, 30.174439251422882, 8.147916086018085, 0.46164779691025615, 0.05432236379419919, 0.10544055694481358, 0.4165393189759925, 1.3820257410407066, 3.5087350476533175, 3.917856956832111, 3.633912205696106, 2.266856236383319, 1.7700211401097476, 1.8421023222617805, 7.535901926457882, 26.920244470238686, 54.64081719517708, 67.55140721797943, 66.59493014216423, 67.52079606056213, 66.14347636699677, 68.561020642519, 62.78655029833317, 68.5638476908207, 58.96452158689499, 62.22984977066517, 66.75658866763115, 60.994513258337975, 58.9436075091362, 53.96332874894142, 55.97128540277481, 57.56404973566532, 63.14686596393585, 64.55417364835739, 62.46083937585354, 60.20512841641903, 66.35365828871727, 63.02644282579422, 63.98951634764671, 60.04725068807602, 60.02745755016804, 54.59038630127907, 58.190248534083366, 54.882742613554, 59.69415843486786, 55.30462637543678, 60.69293104112148, 58.338786363601685, 64.57327902317047, 58.77912953495979, 72.26276680827141, 38.55483636260033, 31.435019709169865, 65.37664711475372, 55.359552428126335, 63.82702946662903, 60.552281588315964, 66.11933246254921, 60.62109589576721, 63.394373282790184, 60.99674753844738, 60.61361409723759, 58.76058652997017, 57.74011328816414, 56.99328616261482, 60.49452468752861, 64.22932907938957, 64.85491991043091, 62.22154721617699, 60.74399270117283, 65.23011177778244, 66.11272841691971, 56.3502998650074, 51.06343075633049, 51.96343906223774, 55.58250166475773, 60.69290064275265, 67.59035512804985, 67.70717605948448, 61.97591319680214, 64.86592411994934, 64.11611795425415, 67.91624844074249, 67.74897381663322, 68.15719351172447, 63.13194416463375, 33.04585017263889, 4.596975753083825, 0.9234334551729262, 1.5670944540761411, 2.7717790799215436, 2.892756750807166, 0.7620752323418856, 0.40708919637836516, 0.21014647674746811, 0.03365811149706133, 0.005423565589808277, 0.05320376170857344, 0.6539151642937213, 11.201199498027563, 40.301378443837166, 37.36939877271652, 29.672318994998932, 27.999764643609524, 28.112333603203297, 51.237647607922554, 57.71664574742317, 61.06676258146763, 62.27127514779568, 69.73585680127144, 21.998051293194294, 0.946432730415836, 0.24635440728161484, 0.08009714147192426, 0.05063094351498876, 0.06330536009045318, 0.04592050252540503, 0.04017971936264075, 0.0315618931199424, 0.03208118869224563, 0.035962817710242234, 0.053264109446899965, 0.06459679352701642, 0.02728891293372726, 0.03823549282969907, 0.013123885328241158, 0.026006964144471567, 0.0824695872142911, 0.0407011597417295, 0.022052370877645444, 0.034748671532724984, 0.02471493698976701, 0.05762322514783591, 0.06774368521291763, 0.08605485068983398, 0.033789976296247914, 0.0240042174118571, 0.12158193494542502, 0.02761543008091394, 0.006502207661469583, 0.10850740058231167, 0.08652811826323159, 0.1300331045058556, 0.1609304192243144, 0.11521860491484404, 0.1516325111151673, 0.1672023389255628, 0.12545676960144192, 0.1351071978569962, 0.19717855931958184, 0.1816193145350553, 0.10307129501597956, 0.07682980663958006, 0.16886596684344113, 0.18534434668254107, 0.16316431341692805, 0.0821842833829578, 0.13035487005254254, 0.1932055756333284, 0.1591360248858109, 0.1157964114099741, 0.20169852068647742, 0.21993700764141977, 0.15526334987953305, 0.13518907158868387, 15.959886498749256, 85.04249945282936, 83.14996540546417, 87.28761658072472, 73.74356254935265, 53.57687048614025, 39.50670048594475, 34.859804436564445, 53.7260352820158, 55.29061272740364, 37.37377993762493, 56.859806925058365, 50.47156311571598, 12.948718126863241, 0.5919569358229637, 0.18845614220481366, 0.15190836740657687, 0.7712257944513112, 0.8259655977599323, 5.901663294062018, 6.062819296494126, 10.083593018352985, 10.164136346429586, 8.857995383441448, 8.029808923602104, 16.1716453358531, 31.75437357276678, 57.572971656918526, 69.04400512576103, 69.03621554374695, 68.87353107333183, 67.91500970721245, 69.08138751983643, 63.050860315561295, 67.88762837648392, 59.642378613352776, 62.85375349223614, 68.76316979527473, 65.06323233246803, 60.544393211603165, 55.92542186379433, 57.37089470028877, 60.29731906950474, 65.38086488842964, 67.25951448082924, 62.042812407016754, 62.32307016849518, 68.40649053454399, 65.5985552072525, 65.01988425850868, 62.68587090075016, 63.58041889965534, 58.19736175239086, 61.167346984148026, 56.97066977620125, 63.040802255272865, 58.92549008131027, 63.794852793216705, 61.01025201380253, 66.48433327674866, 62.31721468269825, 73.51141020655632, 40.6131137162447, 37.57133133709431, 65.90968251228333, 57.46976159512997, 65.71824878454208, 62.68117055296898, 66.51853904128075, 63.083728551864624, 66.59417778253555, 63.3785205334425, 61.44420012831688, 60.779011622071266, 61.10078975558281, 60.00052459537983, 63.17115046083927, 66.93423673510551, 65.54638400673866, 64.02556121349335, 61.45873814821243, 67.82643646001816, 69.72777083516121, 60.03172092139721, 51.93856179714203, 55.06740130484104, 57.43350774049759, 64.46053147315979, 71.83813959360123, 71.84687912464142, 61.399476528167725, 66.80556043982506, 65.233334004879, 70.19872516393661, 71.52918577194214, 73.08525547385216, 67.58334070444107, 37.338821813464165, 5.359773896634579, 7.687681932002306, 13.449518904089928, 7.051712907850742, 3.694096226245165, 0.7993448793422431, 0.350826921639964, 0.30195513158105314, 0.18747928290395066, 0.15545598173048347, 0.2655523724388331, 1.47247169399634, 15.371744558215141, 55.54600082337856, 46.2526760995388, 47.72493749856949, 33.73004525899887, 27.66349408775568, 57.23195135593414, 67.21759513020515, 72.15893357992172, 68.888418674469, 80.48442363739014, 23.39933630079031, 0.9665879176463932, 0.4018014535540715, 0.21842085930984467, 0.10902282214374281, 0.13012321607675403, 0.08955887868069112, 0.1495113639975898, 0.19075712654739618, 0.113704170944402, 0.17863136861706153, 0.11653193170786835, 0.21109920140588656, 0.18135168123990297, 0.1045387881458737, 0.15816593397175893, 0.13890086382161826, 0.122771397291217, 0.08014163322513923, 0.12489830347476527, 0.12858864763984457, 0.22956824395805597, 0.12705353001365438, 0.13077614275971428, 0.1535596905159764, 0.10007220946135931, 0.056085387550410815, 0.2660319482674822, 0.2156086391187273, 0.17455492954468355], [0.01688768170424737, 0.0526722726499429, 0.029113330856489483, 0.05240535923803691, 0.04688379536673892, 0.04074189993843902, 0.015790752186148893, 0.009230372670572251, 0.06845678522950038, 0.03493811214866582, 0.05130220866703894, 0.018119758169632405, 0.03960325244406704, 0.033465969463577494, 0.032341511832783, 0.011650470787571976, 0.054051264669396915, 0.02646665227075573, 0.0539657729677856, 0.05557229262194596, 0.03425156988669187, 0.032361657431465574, 0.019383984472369775, 0.03168140858178958, 0.6180158781353384, 37.661283910274506, 68.94756630063057, 62.7675437182188, 55.28359830379486, 38.88223819434643, 30.655730925500393, 25.461445748806, 26.186061166226864, 36.183854788541794, 34.798414930701256, 54.26948972046375, 42.84147374331951, 4.751442689448595, 0.2579004439758137, 0.06832652346929535, 0.18821723002474755, 0.06977816432481632, 0.295952403685078, 1.268761893734336, 1.4927548868581653, 3.1574322609230876, 4.938961202278733, 1.5547661343589425, 2.0461676409468055, 12.868009507656097, 36.45897522568703, 57.81157985329628, 66.88794001936913, 65.66150262951851, 62.37170375883579, 64.75780472159386, 63.94538551568985, 67.28033736348152, 65.77935710549355, 63.67156460881233, 61.0713717341423, 60.56494250893593, 64.6924102306366, 54.781892225146294, 51.619295328855515, 48.3698882907629, 52.73505225777626, 56.552977189421654, 61.70229747891426, 62.47292272746563, 60.51311708986759, 59.55602824687958, 62.58103832602501, 57.65495605766773, 57.6129113137722, 53.07940497994423, 52.273187041282654, 53.358781188726425, 54.577554389834404, 51.68242894113064, 55.223823711276054, 51.05903059244156, 54.24898222088814, 48.64087454974651, 60.15307120978832, 55.79807549715042, 67.60696783661842, 38.75345930457115, 34.80371184647083, 64.03776615858078, 48.72975558042526, 59.51872184872627, 56.2889863550663, 60.216239020228386, 59.683933183550835, 62.489417642354965, 58.0932929366827, 61.034593507647514, 57.374413311481476, 59.85852621495724, 55.40446221828461, 61.81591138243675, 58.99743542075157, 63.00465099513531, 58.399096727371216, 59.77080412209034, 62.73488067090511, 59.24415998160839, 47.843992710113525, 46.02078214287758, 48.7421353161335, 58.63460049033165, 60.94215586781502, 66.18642166256905, 62.823849096894264, 64.26396042108536, 64.00424435734749, 67.55562499165535, 65.22435888648033, 63.244429528713226, 62.32640638947487, 66.88098639249802, 62.32250779867172, 37.674404606223106, 5.932822097092867, 0.6673567648977041, 2.7900772355496883, 4.448889149352908, 1.1650053737685084, 0.32353366899769753, 0.09411973238456994, 0.1095417540636845, 0.023885390291980002, 0.018540949240559712, 0.019748646154766902, 0.6716573622543365, 17.16597218066454, 49.50720526278019, 43.18108431994915, 27.91312739253044, 25.57671256363392, 25.0962283462286, 46.613067761063576, 58.3215656876564, 61.82480290532112, 64.564638286829, 59.157760217785835, 9.302602875977755, 0.358545376220718, 0.07556563970865682, 0.023808897130948026, 0.06878378291730769, 0.041481427833787166, 0.07811578529071994, 0.036333015814307146, 0.052172295181662776, 0.029729033267358318, 0.013343463633646024, 0.012456948752515018, 0.031422814645338804, 0.0052170254275552, 0.08918353749322705, 0.010002232229453512, 0.018287197817699052, 0.0914737384300679, 0.02999911936058197, 0.039068375481292605, 0.021965406012895983, 0.0518225172709208, 0.04371036447992083, 0.06470810825703666, 0.04642468054953497, 0.0700811090064235, 0.05713820195524022, 0.03869324951665476, 0.049833824959932826, 0.0215696613304317, 0.07138489920180291, 0.03868549036269542, 0.07538229212514125, 0.01011897391435923, 0.04514599721005652, 0.044001008063787594, 0.039483614527853206, 0.040253807965200394, 0.029204229103925172, 0.06583861439139582, 0.0030075077711444465, 0.02126743653207086, 0.027323227986926213, 0.061043119567329995, 0.024559857811254915, 0.01606628007721156, 0.08236703724833205, 0.023470967607863713, 0.027859425972565077, 0.09264659151085652, 0.04024964080599602, 0.030536254307662603, 0.012251425796421245, 0.9648019541054964, 49.1681494563818, 78.75190660357475, 73.11347275972366, 65.05403682589531, 52.41392768919468, 41.71959534287453, 32.20101870596409, 31.961228772997856, 39.07937541604042, 33.24260361492634, 41.79493390023708, 33.11283677816391, 4.27559707313776, 0.19822718430077657, 0.07678813504753634, 0.2420823826105334, 0.3418798861093819, 1.3329763105139136, 2.4391328170895576, 3.550344002433121, 3.538890229538083, 3.4753930242732167, 1.4723088964819908, 2.593626114539802, 12.649034857749939, 38.68988871574402, 60.15604645013809, 69.34048041701317, 67.13567912578583, 66.99018493294716, 65.87590992450714, 66.1146131157875, 68.88455808162689, 66.77956223487854, 63.631959334015846, 63.42183440923691, 61.621069237589836, 67.64843881130219, 59.24208149313927, 55.92990182340145, 49.04610000550747, 55.37095941603184, 59.2349074780941, 64.30351629853249, 63.14778931438923, 61.603533178567886, 62.2468538582325, 64.12673458456993, 59.964711517095566, 60.40427953004837, 54.892591685056686, 55.925900638103485, 55.51212564110756, 56.35221876204014, 54.16535630822182, 56.91950552165508, 54.2805091291666, 57.80736207962036, 52.269698828458786, 61.80559493601322, 58.45346800982952, 71.24517381191254, 43.14000092446804, 36.91971570253372, 64.99410644173622, 51.4210257679224, 60.3832970559597, 57.50570006668568, 61.40207938849926, 60.033981800079346, 62.653907015919685, 60.10712027549744, 61.99496917426586, 59.76847864687443, 61.90671890974045, 58.3709554374218, 63.812293857336044, 61.09653398394585, 62.859882563352585, 57.973397970199585, 60.88130593299866, 64.68148961663246, 60.57713225483894, 50.859792083501816, 49.07839447259903, 51.66149586439133, 62.08728902041912, 65.14080137014389, 70.08573442697525, 64.3183583021164, 63.551916629076004, 65.39731800556183, 68.8656122982502, 67.33523681759834, 65.98299577832222, 65.72087824344635, 67.96458184719086, 66.49762496352196, 41.20390981435776, 8.753350898623466, 0.5440602684393525, 2.648203535936773, 7.047478035092354, 2.617393364198506, 1.2323914328590035, 0.20019341551233083, 0.10892142992815934, 0.09769338124897331, 0.0280258748534834, 0.08046356204431504, 0.5616079643368721, 19.092520102858543, 43.52220341563225, 40.58100923895836, 29.41963255405426, 29.063903242349625, 38.43891978263855, 52.580119371414185, 68.01894173026085, 72.6295155286789, 69.7623185813427, 73.84014576673508, 16.461265794932842, 0.41575736249797046, 0.08249524325947277, 0.02605869925901061, 0.03363460025866516, 0.03179090876074042, 0.10014842802775092, 0.06311111035756767, 0.0020347015242805355, 0.011986797271674732, 0.02775093882519286, 0.0238789503055159, 0.0227561977590085, 0.07747301118797623, 0.06450530156143941, 0.027467917097965255, 0.020362248287710827, 0.05417545195086859, 0.016417994993389584, 0.04876437902566977, 0.04263365663064178, 0.05712761150789447, 0.022626179052167572, 0.043987742174067535, 0.005565578330788412, 0.04100518795894459, 0.024508243295713328, 0.07840787977329455, 0.08925652771722525, 0.09271204893593676, 0.13449765712721273, 0.09788191644474864, 0.12970060750376433, 0.18766864930512384, 0.14072549325646833, 0.09535171979223378, 0.22023953672032803, 0.14080162276513875, 0.11630113120190799, 0.14837394846836105, 0.0917378391022794, 0.09141230344539508, 0.10291648301063105, 0.13692725566215813, 0.09585838401108049, 0.11872556438902393, 0.11282586885499768, 0.18303926568478346, 0.1016008852457162, 0.18002993107074872, 0.16088315926026553, 0.10882331058382988, 0.1811117448960431, 1.532338431570679, 59.362508431077, 88.47554683685303, 81.45164653658867, 72.42950946092606, 54.503492563962936, 43.61320473253727, 35.6894139200449, 38.18100482225418, 53.3049912750721, 47.555496990680695, 70.29264852404594, 55.57489447295666, 7.191549679264426, 0.6103955651633441, 0.19406067818636075, 0.39347895013634115, 0.25175798451527953, 1.9390680128708482, 4.624781236052513, 7.741019669920206, 9.083648175001144, 12.084653042256832, 7.5920814368873835, 6.803569598123431, 17.375339046120644, 41.12923622131348, 62.752830907702446, 71.52762785553932, 69.79356810450554, 69.03790265321732, 69.31875318288803, 69.15274009108543, 71.20589911937714, 68.10566827654839, 63.888304978609085, 63.61376591026783, 62.812050729990005, 70.53106293082237, 62.011171504855156, 56.889593526721, 52.219412326812744, 58.04812856018543, 61.60201705992222, 67.17702090740204, 65.83782076835632, 62.76174142956734, 64.4883231818676, 67.52558380365372, 61.78255297243595, 61.52037464082241, 57.242465391755104, 57.72576905786991, 60.31294763088226, 58.82327176630497, 58.03659237921238, 59.347339645028114, 57.87470206618309, 58.6313820630312, 54.95329722762108, 64.4523923099041, 62.40962192416191, 72.96702861785889, 46.762205958366394, 42.055029943585396, 65.77954709529877, 52.70237781107426, 60.83009608089924, 59.14938546717167, 62.69678391516209, 61.42694905400276, 62.973967641592026, 61.221182495355606, 63.05694378912449, 62.32269398868084, 64.49688032269478, 59.817097038030624, 67.4366457760334, 63.58819708228111, 64.91886287927628, 59.85793724656105, 63.50262567400932, 67.806236743927, 64.38240766525269, 51.80844157934189, 51.85997821390629, 53.984220027923584, 64.92080837488174, 68.14059600234032, 71.63760915398598, 66.8910938501358, 64.66740757226944, 67.00023919343948, 71.21001049876213, 70.71077048778534, 68.44584122300148, 67.30792388319969, 71.84817105531693, 69.07109767198563, 43.72837655246258, 8.56193047016859, 4.479743018746376, 13.141523580998182, 14.667111318558455, 4.296471253037453, 0.7930832309648395, 0.23476504400605336, 0.4998276138212532, 0.2568335918476805, 0.15677746472647414, 0.2360574941849336, 1.7836057674139738, 27.36981924623251, 66.1122040450573, 57.73998409509659, 40.30585080385208, 37.55113162100315, 39.271762892603874, 60.936870351433754, 76.8719194829464, 82.16245919466019, 77.7043180167675, 84.30327951908112, 17.02261157333851, 0.7703521382063627, 0.26499267434701324, 0.11564723230549134, 0.21594990830635652, 0.15298356127459556, 0.20108011871343479, 0.23137339943787083, 0.21649571339366958, 0.14895766245899722, 0.09451003526919521, 0.09415416061528958, 0.20138585387030616, 0.2291642632917501, 0.24822359526297078, 0.11865018444950692, 0.15714230452431366, 0.28820441162679344, 0.07131380145438015, 0.10114038261235692, 0.1981095687369816, 0.1113810038077645, 0.12353183148661628, 0.19683451449964195, 0.10848538106074557, 0.1749237917829305, 0.19620953709818423, 0.1642033498501405, 0.27888662880286574], [0.018624405602167826, 0.03135406950605102, 0.007167401581682498, 0.03401208254217636, 0.028309200861258432, 0.12175706695416011, 0.050586151191964746, 0.08773602297878824, 0.01751906569552375, 0.02152505454432685, 0.0552418550796574, 0.06783558535971679, 0.04165067461144645, 0.026857684315473307, 0.013713291591557208, 0.01431490989489248, 0.050275948306079954, 0.050170006725238636, 0.05328007675416302, 0.07486033966415562, 0.01711294949927833, 0.09141568763880059, 0.0749997075763531, 0.09083048935281113, 10.558444038033485, 64.74962756037712, 65.76960682868958, 62.6277682185173, 51.0293085873127, 20.55612176656723, 32.63916179537773, 41.52443781495094, 22.80463021248579, 24.7205938026309, 37.94116169214249, 37.196568846702576, 3.3041328890249133, 0.1993116847006604, 0.05821384482260328, 0.06387605681084096, 0.06904915266204625, 0.1742131556966342, 0.5521877354476601, 2.615052927285433, 2.1702547324821353, 3.1566673144698143, 0.5986476643010974, 3.3968106284737587, 16.23051557689905, 40.043539479374886, 63.29234875738621, 66.31431519985199, 62.107625529170036, 59.760673865675926, 57.18817390501499, 57.689199820160866, 60.80866143107414, 61.58779442310333, 62.25039906799793, 60.64035326242447, 60.24902746081352, 61.77776902914047, 60.10723426938057, 55.59390485286713, 48.91608618199825, 46.741926446557045, 55.5385722219944, 56.950515657663345, 61.90841741859913, 62.37226992845535, 59.896957352757454, 61.01943992078304, 60.205451399087906, 57.180741503834724, 55.30150294303894, 47.219196036458015, 47.27472625672817, 45.66499963402748, 51.49443402886391, 51.895536705851555, 53.94407898187637, 53.14948841929436, 54.93584096431732, 48.417131155729294, 54.5159824937582, 55.76743394136429, 63.57721947133541, 31.049178913235664, 30.671084001660347, 59.28909257054329, 53.129763677716255, 55.027203261852264, 52.91784144937992, 56.9840944558382, 56.66327767074108, 57.20614314079285, 52.81269729137421, 58.713446259498596, 55.58027498424053, 61.60308480262756, 60.23006267845631, 61.14918015897274, 57.04037703573704, 56.89171761274338, 57.79804117977619, 62.090773433446884, 59.56237010657787, 51.08595214784145, 45.26316739618778, 46.81427076458931, 52.83141888678074, 62.56194815039635, 63.70451644062996, 66.12967550754547, 60.76271049678326, 60.819836631417274, 62.912946715950966, 65.92838510870934, 66.309694647789, 65.50573378801346, 59.98988516628742, 62.90324583649635, 66.46160289645195, 69.54771369695663, 46.0107658803463, 10.844539236277342, 0.6860449339728802, 4.059811877086759, 0.7016478467267007, 2.1583540085703135, 0.42866868374403566, 0.17580055020516738, 0.10158253935514949, 0.17269665113417432, 0.07590120178065263, 0.00853684679896105, 2.0059605734422803, 31.989544853568077, 35.925571247935295, 48.13761055469513, 21.369783505797386, 12.002991624176502, 26.846479028463364, 44.09997001290321, 51.34921342134476, 52.84559592604637, 61.70845314860344, 46.89988397061825, 3.1197594199329615, 0.04738628129416611, 0.054707252711523324, 0.05279664917907212, 0.056090679063345306, 0.06918063154444098, 0.061514520639320835, 0.011298881108814385, 0.04264067734766286, 0.036039047408849, 0.03286814724560827, 0.05116650696436409, 0.008171336285158759, 0.08161695601302199, 0.015980241041688714, 0.0307988057465991, 0.08247737976489589, 0.057148339692503214, 0.044713814932038076, 0.04311792283260729, 0.034638470024219714, 0.009797998754947912, 0.04804177209734917, 0.035323824849911034, 0.07540820050053298, 0.043758503888966516, 0.009915701521094888, 0.03429451055126265, 0.012836414425692055, 0.033492961374577135, 0.04429965942108538, 0.03805800821282901, 0.02157570983399637, 0.06091505456424784, 0.009397491339768749, 0.032971261243801564, 0.03152137185679749, 0.030310819529404398, 0.006759387342754053, 0.015814888683962636, 0.010383741591795115, 0.019498406945785973, 0.030106810554570984, 0.012048584776493954, 0.08378007158171386, 0.04262017180735711, 0.06877447638544254, 0.07132268496206962, 0.009349044867121847, 0.048577780835330486, 0.16117060789838433, 0.1227181704598479, 15.328386034816504, 78.00699457526207, 73.0099131166935, 70.57004883885384, 56.91930793225765, 30.550392977893353, 35.09594276547432, 42.86513887345791, 24.76772077381611, 25.293969735503197, 43.21410834789276, 30.29337476938963, 2.986035095527768, 0.1364496094174683, 0.030431865670834668, 0.06910987518494949, 0.18239928205730394, 1.3033794611692429, 2.782808463089168, 3.5704477736726403, 2.848085635341704, 4.436223953962326, 2.141376044601202, 4.750332674011588, 16.161083802580833, 41.35665021836758, 64.10262867808342, 66.57057344913483, 64.6395094692707, 63.05267281830311, 60.0154197961092, 61.94396831095219, 64.30657893419266, 65.36775559186935, 62.01565146446228, 62.54939362406731, 62.149693071842194, 65.13534486293793, 62.44481183588505, 59.00152400135994, 50.66376060247421, 48.25978919863701, 56.71570345759392, 58.498130813241005, 64.22976985573769, 64.9042184650898, 60.60646668076515, 62.31280691921711, 62.20093712210655, 59.05542030930519, 58.77943351864815, 49.61082190275192, 50.779707580804825, 48.77427019178867, 54.79815535247326, 56.336635798215866, 55.59409484267235, 54.79312442243099, 57.30401448905468, 50.821881517767906, 57.67908476293087, 59.31412562727928, 67.48401403427124, 35.13264499604702, 33.77104505896568, 61.341757625341415, 53.511985167860985, 56.44186355173588, 54.75975841283798, 57.13365063071251, 57.245862409472466, 59.90979306399822, 53.59012417495251, 60.141816213727, 57.94155187904835, 63.121631518006325, 62.887571677565575, 62.77898870408535, 57.67701007425785, 56.93338617682457, 58.51181007921696, 63.77035170793533, 62.00575679540634, 54.71024326980114, 47.602663859725, 48.165166676044464, 55.704942494630814, 65.59874519705772, 67.59095549583435, 66.60066023468971, 61.601336896419525, 59.80388514697552, 62.4834443628788, 68.36294487118721, 68.87518018484116, 66.63087621331215, 64.2943511903286, 64.77323949337006, 69.3478824198246, 70.92144638299942, 49.93797294795513, 12.731270045042038, 1.230970190372318, 2.7587764151394367, 3.839424178004265, 4.234649520367384, 1.848290408961475, 0.5555010982789099, 0.24448032112559304, 0.04314763100410346, 0.02707857158384286, 0.08920704131014645, 1.8344324338249862, 32.094134241342545, 39.399835020303726, 40.645362585783005, 21.55992530286312, 21.017812192440033, 41.66824869811535, 53.56056936085224, 58.491492569446564, 59.08989205956459, 67.66855493187904, 62.633171528577805, 7.646324001252651, 0.26088761806022376, 0.07163436472183093, 0.018985488277394325, 0.04636999168724287, 0.046868603603797965, 0.030689758277731016, 0.0329226950998418, 0.08005897281691432, 0.038603527573286556, 0.04021128290332854, 0.06382463339832611, 0.007295151635844377, 0.022615256493736524, 0.048986039982992224, 0.026150452831643634, 0.028737102802551817, 0.16076627100119367, 0.04490327410167083, 0.06749044216121547, 0.016973525926005095, 0.013751056703767972, 0.025393284086021595, 0.015379650612885598, 0.030555028788512573, 0.03151960554532707, 0.020062676667294, 0.01724457866657758, 0.12213599271490239, 0.1813733667950146, 0.1455741815152578, 0.2270109366509132, 0.11915409530047327, 0.29263740812893957, 0.10670168107026257, 0.11987130681518465, 0.1015316354460083, 0.07542531442595646, 0.10328124117222615, 0.16488087130710483, 0.09772681500180624, 0.13683741126442328, 0.14685734000522643, 0.0905961413809564, 0.2781490230700001, 0.14881398266879842, 0.20037206530105323, 0.22068090678658336, 0.17991685745073482, 0.20602821023203433, 0.19084513041889295, 0.28205432288814336, 20.373142585158348, 93.57280611991882, 84.0797983109951, 79.86185744404793, 65.49188733100891, 33.47078517079353, 42.99215845763683, 53.80505584180355, 32.50100500881672, 37.83702827990055, 53.59601005911827, 48.69047328829765, 5.158752808347344, 0.5402344081085175, 0.26061017357278615, 0.22145711904158816, 0.24857417098246515, 0.9514396742451936, 3.3290550392121077, 9.068790972232819, 7.015586821362376, 10.856858175247908, 7.088572354987264, 8.31881096586585, 19.532616287469864, 44.70329023897648, 67.2517628967762, 70.66842555999756, 66.22581034898758, 64.63095232844353, 62.191566824913025, 63.49028393626213, 66.10000669956207, 67.08037689328194, 62.03996255993843, 64.81624558568001, 65.04814714193344, 65.79644858837128, 64.12008494138718, 61.825775653123856, 52.650890573859215, 50.6242161244154, 59.34625670313835, 61.86779759824276, 66.73132762312889, 65.86247384548187, 61.84887081384659, 63.36034990847111, 64.47921127080917, 60.725278705358505, 60.75685881078243, 51.63657680153847, 52.21625469624996, 51.499062180519104, 56.91884055733681, 57.591271474957466, 57.15349316596985, 59.43655885756016, 59.99148488044739, 53.3220599591732, 59.74236644804478, 62.02936492860317, 70.30560582876205, 38.828649669885635, 37.904706448316574, 63.91339883208275, 53.63072879612446, 55.709977224469185, 55.49677446484566, 59.74270462989807, 59.09639731049538, 61.228880882263184, 53.6792977899313, 60.76992250978947, 58.57526287436485, 65.26903688907623, 65.50197198987007, 64.28344577550888, 59.526382237672806, 57.40059390664101, 60.680532306432724, 65.7070241868496, 65.58026298880577, 57.11073026061058, 50.140376687049866, 50.745972990989685, 58.39257247745991, 68.39108616113663, 68.91450047492981, 69.75508376955986, 61.59675054252148, 61.01600870490074, 64.5155981183052, 71.24132081866264, 72.78767824172974, 70.62956124544144, 68.47462847828865, 68.86267125606537, 71.98702320456505, 74.21710073947906, 53.54037344455719, 14.934453573077917, 5.66550406627357, 13.897645007818937, 7.444968530908227, 7.658117143437266, 1.2048393487930298, 0.44171831163112074, 0.39517155149951577, 0.29705550230573863, 0.3097222710493952, 0.2866791794076562, 3.6173237208276987, 44.657924473285675, 52.137245535850525, 64.92927432060242, 32.760607078671455, 22.260590605437756, 39.71239484846592, 57.129231467843056, 67.02518105506897, 70.32189935445786, 76.37532413005829, 72.57422849535942, 7.997662648558617, 0.5445160064846277, 0.22591804998228326, 0.14152597374049947, 0.16920655325520784, 0.28687525482382625, 0.1227997918613255, 0.14952332741813734, 0.2141953821410425, 0.13876493205316365, 0.20354982290882617, 0.11070481079514138, 0.08171656707418151, 0.18682065652683377, 0.13119656941853464, 0.11366016900865361, 0.16886209283256903, 0.3496676275972277, 0.1688686979468912, 0.17280693427892402, 0.09647735001635738, 0.06642065854975954, 0.13171300030080602, 0.12648082949453965, 0.11868290574057028, 0.12133160111261532, 0.11128620928502642, 0.16400984226493165], [0.021126886749698315, 0.05228817040915601, 0.0780973354994785, 0.0392495485721156, 0.01584102526976494, 0.03981491667218506, 0.017848152529040817, 0.03446532697125804, 0.04084225314727519, 0.09584363011526875, 0.029790932094329037, 0.08015608284040354, 0.03333266118715983, 0.04240576163283549, 0.0023630909709027037, 0.04593687430315185, 0.019944513769587502, 0.03203311607649084, 0.02996719031216344, 0.04840775851334911, 0.0900169915985316, 0.07968843332491815, 0.06069220617064275, 0.4234993876889348, 39.540476873517036, 66.35408386588097, 62.92790271341801, 65.89245423674583, 39.01730574667454, 36.05795994400978, 43.56896370649338, 30.666993521153927, 49.68350060284138, 41.65480121970177, 33.511990159749985, 3.6104800505563617, 0.22603444842388853, 0.02890366671636002, 0.09732195117976516, 0.019149118852510583, 0.46446074440609664, 0.6533181807026267, 1.5662820101715624, 1.074549446348101, 1.210713714826852, 1.325994897633791, 4.358931351453066, 20.05055509507656, 41.99502736330032, 61.321725100278854, 66.83494806289673, 63.227208852767944, 60.33271797001362, 53.0852984637022, 54.29356902837753, 59.81971509754658, 63.49198244512081, 63.27361196279526, 63.73421564698219, 55.223550125956535, 60.667096227407455, 62.84572832286358, 59.74003717303276, 53.61182101070881, 45.5364715307951, 47.37632140517235, 59.44173038005829, 57.69586466252804, 60.67821443080902, 59.34966892004013, 60.38369603455067, 60.13091079890728, 59.997340366244316, 52.43057459592819, 48.458001762628555, 45.144188180565834, 49.6944934129715, 49.08141151070595, 53.2154680788517, 51.32182069122791, 55.34139320254326, 53.98521177470684, 51.903280690312386, 48.295210897922516, 54.10397820174694, 56.864290684461594, 62.77939908206463, 32.4488490074873, 27.141481898725033, 57.602659463882446, 54.1393581032753, 62.154154032468796, 56.240858137607574, 60.085750222206116, 58.8142928481102, 55.72853542864323, 54.70859415829182, 57.81755693256855, 54.78304736316204, 56.032078340649605, 56.165276393294334, 57.040297240018845, 52.82233737409115, 57.22164250910282, 58.14523994922638, 61.167415380477905, 52.47880920767784, 46.207580119371414, 42.19346411526203, 50.79248629510403, 59.742484241724014, 64.01665449142456, 63.500516787171364, 59.47820462286472, 57.908106073737144, 61.48312143981457, 63.83491024374962, 63.25042560696602, 61.50874346494675, 65.44808328151703, 68.70804235339165, 61.05690211057663, 60.30928082764149, 61.830312609672546, 67.58110642433167, 49.22324649989605, 15.245920959860086, 2.4618278117850423, 2.9688087198883295, 3.699910151772201, 0.42201817966997623, 0.2928141283337027, 0.1932762874639593, 0.039655358632444404, 0.03271660811151378, 0.03604599020036403, 0.10371570926508866, 8.054271060973406, 34.38156969845295, 38.11492636799812, 43.1856706738472, 24.26305465400219, 19.0055313706398, 27.022854164242744, 50.96279315650463, 50.92050522565842, 54.37991179525852, 58.47225420176983, 39.14962224662304, 1.8461588420905173, 0.18237112497445196, 0.017077829215850215, 0.017013959986798, 0.06095577249652706, 0.09646252190577798, 0.08473580935969949, 0.11843975589727052, 0.03734276338946074, 0.020528806635411456, 0.09581780337612145, 0.030020183367014397, 0.035334155545569956, 0.020194198223180138, 0.019288596231490374, 0.07281302139745094, 0.01662518592638662, 0.028142059927631635, 0.043730009128921665, 0.022948445548536256, 0.08686060042236932, 0.05734246697102208, 0.08855631138430908, 0.09060282813152298, 0.027119972291984595, 0.009023447055369616, 0.08594758808612823, 0.05777437094366178, 0.021684631137759425, 0.006337948580039665, 0.022101066897448618, 0.038721955788787454, 0.015121136457310058, 0.012612256141437683, 0.03430758719332516, 0.05058080772869289, 0.04487565136514604, 0.06281613634200767, 0.04146899314946495, 0.06990446301642805, 0.04192318381683435, 0.08069350908044726, 0.017388271444360726, 0.06746762112015858, 0.015881882354733534, 0.025616154744056985, 0.04422480269568041, 0.05368357873521745, 0.03104414678091416, 0.07208456634543836, 1.2078631552867591, 51.90583415329456, 75.05996391177177, 71.81932300329208, 72.53100201487541, 49.85479921102524, 35.463025867938995, 46.89929500222206, 39.581868052482605, 27.94841419905424, 43.649678975343704, 34.388014152646065, 4.896156024187803, 0.17365341307595372, 0.026341618940932676, 0.05539527555811219, 0.19347898283740506, 1.912160231731832, 3.907149131409824, 4.0995928924530745, 3.5568882012739778, 3.016651952639222, 0.974520348245278, 5.588226662948728, 22.325485423207283, 45.24103358387947, 64.19720560312271, 68.83835256099701, 64.8577469587326, 62.75719687342644, 55.439412742853165, 56.53946131467819, 62.13711574673653, 64.6497917175293, 65.64853772521019, 63.98403704166412, 56.54756247997284, 62.14967407286167, 64.26942452788353, 63.478196784853935, 55.06373830139637, 48.299128487706184, 49.85410004854202, 61.19540087878704, 61.82018995285034, 63.40430215001106, 60.80592177808285, 60.40787793695927, 62.16964200139046, 63.33166524767876, 54.136052280664444, 50.2403911203146, 47.546879053115845, 52.54758931696415, 50.22429898381233, 55.82295276224613, 53.780440762639046, 59.03701409697533, 55.17362080514431, 55.75073383748531, 49.10128064453602, 56.31227910518646, 59.069897532463074, 66.66182175278664, 34.47603262960911, 29.637311473488808, 59.9448461830616, 57.077561840415, 62.76681415736675, 57.02073968946934, 62.35332794487476, 59.8834490776062, 57.43397131562233, 55.02058781683445, 59.86837908625603, 55.300906375050545, 57.72146388888359, 57.36655533313751, 58.83880153298378, 53.060820177197456, 57.60280765593052, 61.2548790872097, 61.97228439152241, 53.98107759654522, 47.87464566528797, 45.62840759754181, 52.87801958620548, 61.319950595498085, 65.77632486820221, 63.94283205270767, 58.871255591511726, 57.17186518013477, 62.373447865247726, 66.20475187897682, 65.1348964869976, 63.79970133304596, 69.02106195688248, 69.80241402983665, 66.24836593866348, 64.38557669520378, 65.45442894101143, 66.35751888155937, 53.97817075252533, 15.924126617610455, 3.0055228248238564, 3.434700295329094, 3.993345843628049, 3.2519939867779613, 1.8126505776308477, 0.6701632705517113, 0.5830562696792185, 0.1977963824174367, 0.19415491609834135, 0.025332862132927403, 7.007991028949618, 37.301743403077126, 40.87872326374054, 34.840311482548714, 20.78219823539257, 31.93582333624363, 45.67139849066734, 62.09872640669346, 64.59648057818413, 60.452913120388985, 67.83486440777779, 56.119606643915176, 3.939630025997758, 0.15449987287865952, 0.028738720684486907, 0.04000208260549698, 0.017780062335077673, 0.05997729160299059, 0.09683175521786325, 0.16473278315970674, 0.06547838333062828, 0.024537001518183388, 0.05567264212004375, 0.009628938441892387, 0.04205894118058495, 0.05121368158143014, 0.02136302886356134, 0.07009642693446949, 0.09632044515456073, 0.03730050550075248, 0.015491194481001003, 0.023823999836167786, 0.055003028246574104, 0.007002519560046494, 0.017164942510135006, 0.030911569519957993, 0.034336864919168875, 0.03516219250741415, 0.0425090055068722, 0.16123757930472493, 0.1923377378261648, 0.12782441364834085, 0.10252195730572566, 0.10657936029019766, 0.10231007414404303, 0.19845980306854472, 0.09379399634781294, 0.1256670051952824, 0.27323526330292225, 0.21990870212903246, 0.14698837359901518, 0.11304899555398151, 0.1672489903285168, 0.13312263559782878, 0.07940607581986114, 0.1125063223298639, 0.1679570140549913, 0.1443459271104075, 0.14654192724265158, 0.16978624480543658, 0.17344610154395923, 0.1807569686206989, 1.9840978528372943, 64.35751140117645, 84.26275089383125, 80.47572210431099, 84.59921523928642, 55.250802263617516, 49.44527618587017, 52.92051650583744, 44.05601777136326, 63.63767422735691, 60.595793053507805, 48.476901948451996, 6.600025445222855, 0.428717962349765, 0.11950156884267926, 0.3221084485994652, 0.19145409227348864, 1.6045852610841393, 4.0543116722255945, 5.99363355897367, 7.753158593550324, 8.881022147834301, 6.254323795437813, 9.28611746057868, 24.814701452851295, 45.43055981397629, 65.70876449346542, 71.10513612627983, 68.41630160808563, 65.30644968152046, 58.34361210465431, 58.68976593017578, 66.2144185602665, 67.31948286294937, 67.35348343849182, 65.09523421525955, 57.90725111961365, 62.79290735721588, 64.61573794484138, 66.90817773342133, 58.80488075315952, 49.748739302158356, 53.380664214491844, 64.89784240722656, 63.240724727511406, 64.58072662353516, 60.798192992806435, 60.74771270155907, 63.99026110768318, 65.27672007679939, 57.970259338617325, 53.854692578315735, 49.924331679940224, 56.10431246459484, 54.57573048770428, 58.38393174111843, 56.358879804611206, 61.507155150175095, 59.61139887571335, 57.64857620000839, 51.01619929075241, 58.914843052625656, 62.834465727210045, 68.55087518692017, 38.55800919234753, 33.58586199581623, 61.58308267593384, 59.34803120791912, 64.64270129799843, 60.10917976498604, 62.80169628560543, 62.72093161940575, 59.888631999492645, 56.11571565270424, 60.309896394610405, 57.24047429859638, 57.3342190682888, 58.41779172420502, 59.70672816038132, 52.878673151135445, 59.23677697777748, 62.408227398991585, 65.82325994968414, 57.03510291874409, 49.9532937258482, 47.13860996067524, 56.720863580703735, 65.50788447260857, 66.78469955921173, 65.52942171692848, 58.169786632061005, 57.67436541616917, 64.20093700289726, 71.58848538994789, 69.20550405979156, 67.52178400754929, 71.42904594540596, 73.20151403546333, 66.90688580274582, 65.11516034603119, 67.60932371020317, 69.06133219599724, 55.87869577109814, 18.562813326716423, 9.05974080786109, 10.707098711282015, 11.871421784162521, 5.925848046317697, 1.1160016595385969, 0.5695155181456357, 0.4633732308866456, 0.2820923802210018, 0.3225087036844343, 0.2285008574835956, 12.474460825324059, 49.07710254192352, 55.895870849490166, 57.86018304526806, 34.11204256117344, 32.789040952920914, 40.011852979660034, 65.19798830151558, 69.50756505131721, 68.27085301280022, 75.75759887695312, 66.18560090661049, 4.398729465901852, 0.36604284890927374, 0.1621856729616411, 0.1454368099803105, 0.22536826698342338, 0.15175549982814118, 0.22220895916689187, 0.3167014574864879, 0.16289715509628877, 0.12756648764479905, 0.16900477814488113, 0.11182456320966594, 0.09839623962761834, 0.13960330659756437, 0.12898983783088624, 0.1918433338869363, 0.1453478413168341, 0.10987533460138366, 0.15913504525087774, 0.13752651022514328, 0.2491526899393648, 0.1346820659819059, 0.17869906732812524, 0.2514293318381533, 0.20025660196552053, 0.10624339745845646, 0.1362389136920683], [0.048958016486722045, 0.057115028394036926, 0.017474280793976504, 0.005971583668724634, 0.05637550420942716, 0.08174509523087181, 0.012637546678888611, 0.038596354715991765, 0.044665820241789334, 0.01832147390814498, 0.01662448645220138, 0.058185817615594715, 0.026374817061878275, 0.04926207067910582, 0.036396291325218044, 0.042731516223284416, 0.02802953364152927, 0.07547995875938796, 0.054664449344272725, 0.05217936784902122, 0.06514936700114049, 0.03478315542452037, 0.011149677884532139, 10.966473743319511, 58.98085691034794, 63.92301991581917, 56.47196173667908, 49.07177522778511, 29.091225676238537, 33.648961409926414, 24.846617840230465, 34.436883330345154, 50.92000365257263, 31.665150560438633, 14.546057414263487, 0.05978800683806185, 0.09227089409250766, 0.16745919623645023, 0.06255619169678539, 0.28209704090841115, 0.29509394662454724, 3.2132405787706375, 2.7142703533172607, 2.262568403966725, 1.198205854743719, 4.260642975568771, 23.774984143674374, 46.932699009776115, 62.38600619137287, 62.59117618203163, 66.66793942451477, 59.7761732339859, 58.53315353393555, 47.62815669178963, 56.82400904595852, 61.00715517997742, 64.65153962373734, 58.53819206357002, 60.70114620029926, 50.38327105343342, 56.057160794734955, 59.83754754066467, 59.76702332496643, 56.34610489010811, 46.86373271048069, 48.813871666789055, 58.222216218709946, 57.28612884879112, 60.30419670045376, 57.5151539593935, 62.21011742949486, 58.25503125786781, 57.482692301273346, 49.46934409439564, 45.269326865673065, 44.19815294444561, 49.2694216221571, 48.11026722192764, 52.939348295331, 51.73403777182102, 58.03498886525631, 49.916382506489754, 52.70848788321018, 45.19316755235195, 53.79190094769001, 54.109563902020454, 67.3052716255188, 32.92752832174301, 32.32135824859142, 62.836696207523346, 53.96371252834797, 61.430923640728, 53.2869004458189, 59.31227132678032, 55.704330727458, 58.01415838301182, 58.29546868801117, 59.970567002892494, 57.568932473659515, 59.60702531039715, 54.50192704796791, 55.326923578977585, 54.56644378602505, 57.34103210270405, 60.77482424676418, 58.277054876089096, 49.471289590001106, 43.509398102760315, 44.790487959980965, 51.084914803504944, 60.190590396523476, 62.11836375296116, 59.665393978357315, 55.41022650897503, 59.39059652388096, 64.00124251842499, 61.10849194228649, 61.311933025717735, 62.64248862862587, 62.307870984077454, 65.95455050468445, 65.98205342888832, 66.45082667469978, 62.18409262597561, 54.30466063320637, 65.18117040395737, 51.70076675713062, 18.958584889769554, 1.9375831237994134, 3.8452801387757063, 4.105816958472133, 2.2753991279751062, 0.4943996050860733, 0.3082671866286546, 0.1930408040061593, 0.039500802668044344, 0.1671370299300179, 0.3873349470086396, 15.27059018611908, 38.70115891098976, 35.67681759595871, 44.22580026090145, 21.890889443457127, 13.287116568535566, 22.038638815283775, 36.73845022916794, 51.38834752142429, 51.67641766369343, 61.27953216433525, 29.15662206709385, 0.7713810517452657, 0.1851918056490831, 0.041234274103771895, 0.029362174827838317, 0.003912166075679124, 0.024715350737096742, 0.07404756179312244, 0.03362605442816857, 0.015444891887455015, 0.04844364506425336, 0.038350670438376255, 0.03340705778100528, 0.01267033754629665, 0.03000217144290218, 0.043588017724687234, 0.041247988992836326, 0.10853962463443168, 0.04002939363999758, 0.09806036585359834, 0.05437039930257015, 0.025829960068222135, 0.05117624765262008, 0.06736114519299008, 0.08785476660705172, 0.03071841631026473, 0.06472984576248564, 0.054310066407197155, 0.0764180111582391, 0.029416422112262808, 0.034139297786168754, 0.013160135531506967, 0.04224055213853717, 0.010089176685141865, 0.018185352892032824, 0.030765906340093352, 0.04678250705183018, 0.0030874549338477664, 0.06496001544292085, 0.021618507635139395, 0.01200910437546554, 0.029306558280950412, 0.01874848527222639, 0.051694489375222474, 0.06292862366535701, 0.09926672690198757, 0.04963965686329175, 0.008756544775678776, 0.049568377289688215, 0.007199332021627924, 15.90195195749402, 72.28227496147156, 73.18417936563492, 65.60599520802498, 59.580430537462234, 39.23300117254257, 36.74499347805977, 35.50959996879101, 27.06082932651043, 51.49195276200771, 38.862958028912544, 12.932199463248253, 0.060731977864634246, 0.028531858151836786, 0.13986109901452437, 0.1940380723681301, 1.0369282588362694, 2.797203753143549, 5.185890952125192, 4.186683744192123, 2.8380812471732497, 1.6858965042047203, 5.244253445416689, 26.007250361144543, 46.87243804335594, 63.66561032831669, 63.90475049614906, 68.93762603402138, 60.61560899019241, 61.94767311215401, 50.96383050084114, 59.07481446862221, 63.31374540925026, 66.76969036459923, 61.39935493469238, 60.65199963748455, 54.18709494173527, 56.505206152796745, 60.03425158560276, 62.61096931993961, 58.113139271736145, 47.172477543354034, 50.16761362552643, 61.93979613482952, 60.81058032810688, 61.16456553339958, 56.372376680374146, 63.93163025379181, 60.22261507809162, 58.685190975666046, 49.84435737133026, 48.16434971988201, 48.226890563964844, 51.6390086710453, 51.31404630839825, 55.71319945156574, 54.58798483014107, 60.12613445520401, 53.545043393969536, 54.931076020002365, 48.03254999220371, 55.823933109641075, 57.68983818590641, 69.90864872932434, 35.98319515585899, 35.316802114248276, 63.103856071829796, 55.97524859011173, 63.10808904469013, 55.390741154551506, 61.401311829686165, 59.87266145646572, 60.32680168747902, 59.082041680812836, 61.880956292152405, 59.78588551282883, 60.517878234386444, 56.180669367313385, 56.47951193153858, 54.653573110699654, 57.36046425998211, 62.0344490557909, 61.03794492781162, 51.40113763511181, 45.34392066299915, 46.630809009075165, 55.09016968309879, 63.58808308839798, 63.96842747926712, 60.36763049662113, 55.323613956570625, 61.08838342130184, 64.18941602110863, 62.94392265379429, 64.15327996015549, 65.09102404117584, 65.9288638830185, 68.18605676293373, 68.71413722634315, 66.25994011759758, 64.51720923185349, 60.80221697688103, 66.18292585015297, 54.248860627412796, 21.167090982198715, 2.4271247489377856, 0.9821423829998821, 3.0327457515522838, 2.734074415639043, 1.4384160214103758, 0.9167734812945127, 0.3029428707668558, 0.054814964314573444, 0.1523365272441879, 0.3689207194838673, 16.6813537850976, 40.809046402573586, 41.48205868899822, 39.9479404091835, 24.383677281439304, 21.698574163019657, 34.133287221193314, 44.27602976560593, 59.94114898145199, 56.92669093608856, 70.57549014687538, 42.34258331358433, 1.140918347518891, 0.3089814295526594, 0.04211467647110112, 0.03593244531657547, 0.011161278580402723, 0.048014917483669706, 0.06674382675555535, 0.09627228719182312, 0.010447700806253124, 0.05870922468602657, 0.046339882756001316, 0.04812911545741372, 0.02362135270232102, 0.07849880028516054, 0.052382623543962836, 0.02387223572441144, 0.06332627381198108, 0.053497882254305296, 0.04662885650759563, 0.036352018505567685, 0.022001422439643648, 0.07188397124991752, 0.024933647910074797, 0.01928450699779205, 0.0732607145619113, 0.05365440119931009, 0.08472130037262104, 0.15978665091097355, 0.19584503868827596, 0.11688639628118835, 0.19885587244061753, 0.14642468275269493, 0.18208265217253938, 0.19222359551349655, 0.13295839831698686, 0.1417342945933342, 0.18227716907858849, 0.21219517540885136, 0.10494720685528591, 0.16655851097311825, 0.08320337830809876, 0.18034929205896333, 0.10132168186828494, 0.16341529291821644, 0.23797884030500427, 0.16843396268086508, 0.17561686865519732, 0.2883255004417151, 0.11130985411000438, 22.33321040868759, 84.53683018684387, 82.86937326192856, 75.78129440546036, 65.25243178009987, 44.983156621456146, 45.15454262495041, 33.327460661530495, 48.761058300733566, 67.07669869065285, 45.658254995942116, 21.265729889273643, 0.3356085007544607, 0.20213965326547623, 0.2623579907231033, 0.4320875502889976, 0.539270150475204, 2.4076344072818756, 9.643306843936443, 10.733496844768524, 8.470981400460005, 6.498538590967655, 8.840880151838064, 27.953424230217934, 49.461402520537376, 63.973397612571716, 64.15431350469589, 71.84539720416069, 63.3213260024786, 64.86951112747192, 52.55153350532055, 62.55369499325752, 66.31634429097176, 68.867496997118, 63.089036867022514, 60.1834961771965, 54.921386539936066, 57.38104395568371, 62.80752897262573, 66.31745383143425, 61.097039356827736, 51.30488120019436, 52.97275610268116, 64.5835080742836, 61.75296775996685, 61.915317848324776, 56.608674600720406, 66.29367470741272, 61.96210093796253, 62.89572983980179, 53.70841562747955, 50.831476002931595, 51.2516650557518, 54.86420340836048, 52.52815715968609, 58.319354206323624, 56.89967818558216, 63.60350266098976, 57.05978639423847, 56.57696150243282, 50.21015614271164, 59.04420331120491, 60.38266249001026, 71.88274919986725, 40.579162538051605, 38.05250331759453, 64.57676723599434, 59.29284676909447, 65.64813494682312, 58.37323151528835, 63.788377940654755, 60.885162726044655, 63.25550973415375, 63.34851734340191, 62.35028810799122, 60.871312469244, 61.972060203552246, 56.65125511586666, 55.008329674601555, 55.39679042994976, 59.25381526350975, 65.24918675422668, 64.74908798933029, 55.240615010261536, 48.811804577708244, 49.155268147587776, 56.94855876266956, 65.75709030032158, 65.99565669894218, 58.486176654696465, 55.374413430690765, 62.15841360390186, 68.61523613333702, 66.01886585354805, 66.28058061003685, 68.8724747300148, 72.44802206754684, 70.29829502105713, 69.8238068819046, 69.62630867958069, 67.2671976685524, 65.32889127731323, 68.76025915145874, 59.63441044092178, 21.620596647262573, 8.27536029741168, 10.872159954160452, 13.340388759970665, 6.4955101534724236, 1.1870534531772137, 0.7453279278706759, 0.3954216849524528, 0.14953665639040992, 0.379507634206675, 0.7706168771255761, 22.656694650650024, 53.262163773179054, 54.011259377002716, 60.1138649135828, 32.539580538868904, 20.422038361430168, 34.66885708272457, 48.73718038201332, 68.68928655982018, 65.32265201210976, 81.97778150439262, 48.12846824526787, 1.5940052038058639, 0.6232546688988805, 0.14748555317055434, 0.17875735560664907, 0.12637167441425845, 0.10487728912266903, 0.13328336994163692, 0.19058275152929127, 0.07675835266127251, 0.20862402016064152, 0.10884990173508413, 0.15343998209573328, 0.09578045850503258, 0.12016273336485028, 0.1527634699596092, 0.09172901496640407, 0.15708624268881977, 0.12203694568597712, 0.18966049945447594, 0.14644762995885685, 0.13541413529310375, 0.11130060694995336, 0.30996228160802275, 0.12169382112915628, 0.11517210194142535, 0.13800782267935574], [0.05456062288430985, 0.057672804323374294, 0.03906757396180183, 0.04046268171805423, 0.02576302576926537, 0.07034987778752111, 0.0706986797740683, 0.0099823380332964, 0.02067043438728433, 0.022960943315410987, 0.03122347749012988, 0.06758322546374984, 0.016317660338245332, 0.06797046327847056, 0.011514654052007245, 0.014774901374039473, 0.10002355425967835, 0.03589556428778451, 0.039440532855223864, 0.04070572766067926, 0.06237330424482934, 0.0716767784615513, 0.5941968562547117, 41.21777147054672, 72.91631653904915, 60.87613061070442, 56.266662552952766, 34.348310083150864, 23.187653459608555, 20.43360684067011, 21.827911622822285, 58.314912244677544, 38.752364963293076, 20.85617646574974, 0.7425558578688651, 0.08505240955855697, 0.03980470100941602, 0.0902986217988655, 0.020386330979818013, 1.477063272614032, 3.5428619664162397, 5.3172223549336195, 3.662683549337089, 1.7243309668265283, 6.944146854802966, 27.96329040080309, 52.36959546804428, 61.64352983236313, 66.41162037849426, 64.54196870326996, 63.713233172893524, 60.67586615681648, 53.6389097571373, 49.05486233532429, 55.394658744335175, 62.77499131858349, 60.337414517998695, 62.458966076374054, 59.92839306592941, 57.531519681215286, 56.97190850973129, 57.78313457965851, 60.022704005241394, 55.89021675288677, 46.87205046415329, 44.062944799661636, 59.76211778819561, 57.18013733625412, 60.68558983504772, 57.788404896855354, 56.67788028717041, 56.215243712067604, 53.88420179486275, 44.34319116175175, 44.42780502140522, 45.650340020656586, 49.69825141131878, 51.455535516142845, 52.95571021735668, 52.557480186223984, 52.82742530107498, 50.4686638712883, 51.58203072845936, 42.543155550956726, 56.78955629467964, 54.243715703487396, 65.30890434980392, 31.754880845546722, 35.38167983293533, 67.45733186602592, 53.09693343937397, 59.21443037688732, 53.09861674904823, 57.04003505408764, 53.108557015657425, 54.490972235798836, 55.749096125364304, 58.044872134923935, 57.231662571430206, 59.71210487186909, 58.350577130913734, 54.32968609035015, 49.29922342300415, 61.19813673198223, 57.04755865037441, 53.7411280721426, 44.96456041932106, 43.99472326040268, 42.475393787026405, 53.13725307583809, 60.50976186990738, 59.691221192479134, 56.15251287817955, 55.567636862397194, 60.940172374248505, 62.50755786895752, 58.066508173942566, 58.10280382633209, 61.400411278009415, 64.25040274858475, 60.65342836081982, 63.16687569022179, 59.59187172353268, 56.157566606998444, 63.841407895088196, 52.71636486053467, 56.339421048760414, 54.270614460110664, 15.969076305627823, 1.531416387297213, 2.308042226359248, 3.6538858339190483, 1.351546982768923, 2.0943089202046394, 0.17777516768546775, 0.10084870373248123, 0.12242180862813257, 0.21491720981430262, 2.3075881507247686, 29.325315915048122, 31.53785739094019, 29.18224599212408, 47.25552588701248, 41.0628841817379, 32.02812798321247, 42.07843288779259, 44.11122880876064, 48.724029287695885, 49.33463752269745, 60.63570611178875, 16.33634939789772, 0.3873708669561893, 0.1823633917956613, 0.09632339148083702, 0.045695746812270954, 0.060160887805977836, 0.034851518357754685, 0.047294904361478984, 0.08545620468794368, 0.06825462420238182, 0.06534547952469438, 0.0786466509453021, 0.014060972007428063, 0.05913040462473873, 0.007601527358929161, 0.04382033963338472, 0.06317673847661354, 0.03807437627983745, 0.020207785091770347, 0.0032690772559362813, 0.02715553971938789, 0.059232498169876635, 0.013386414502747357, 0.0478643988026306, 0.05159162399650086, 0.06305660703219473, 0.015797064152138773, 0.03632193183875643, 0.06807896526879631, 0.03348306112457067, 0.02173315646359697, 0.005939803513683728, 0.05265453532047104, 0.05887850857106969, 0.02009664476645412, 0.03891027576173656, 0.01018943527014926, 0.005529586487682536, 0.03842228397843428, 0.06248065590625629, 0.039376797212753445, 0.035088664226350375, 0.04099120960745495, 0.02119418655638583, 0.06608847324969247, 0.023243770228873473, 0.025053590106836054, 0.15808753349119797, 1.1306414427235723, 51.496911495923996, 83.09170693159103, 69.77829292416573, 61.61397121846676, 44.94760952889919, 32.932623848319054, 23.28799657523632, 23.034096099436283, 61.65709130465984, 48.17298665642738, 19.061000794172287, 0.8276256336830556, 0.04694916002335958, 0.10987583926180378, 0.296521155978553, 0.593031031312421, 3.6116544250398874, 5.230854414403439, 4.131512129679322, 1.6335961106233299, 1.2482443009503186, 7.736115083098412, 31.68589174747467, 52.47651793062687, 61.80782161653042, 67.31558427214622, 67.90835246443748, 66.15264147520065, 62.52988167107105, 55.34107781946659, 50.17191119492054, 57.48732045292854, 64.16508972644806, 62.36161150038242, 62.94272191822529, 61.543815582990646, 58.07714380323887, 57.94865369796753, 59.161396622657776, 61.699804812669754, 58.04540030658245, 49.272670447826385, 46.296153366565704, 61.65646053850651, 59.58387695252895, 61.18234097957611, 59.47253532707691, 58.288708850741386, 57.45977193117142, 56.6022377461195, 47.4861279129982, 46.3921894133091, 47.59742014110088, 51.98296241462231, 53.83200019598007, 56.26230038702488, 55.376317128539085, 56.36153966188431, 52.7422870695591, 54.59216460585594, 45.00709913671017, 58.74340005218983, 56.338923275470734, 66.85176596045494, 33.6099299043417, 37.291453555226326, 67.91176468133926, 55.09502962231636, 62.70207703113556, 55.840602815151215, 59.224800020456314, 54.64984551072121, 56.60725347697735, 57.70893216133118, 59.91847179830074, 59.99358996748924, 62.1968599408865, 59.60863642394543, 54.36459481716156, 49.08721759915352, 62.796992138028145, 60.65013013780117, 55.68938612937927, 47.932831943035126, 46.612835973501205, 44.29158233106136, 55.66293574869633, 63.783362209796906, 60.431166887283325, 57.137925401329994, 55.948137044906616, 63.22451859712601, 64.99656870961189, 61.04542672634125, 60.601621940732, 63.09193231165409, 66.9116735458374, 64.01163876056671, 63.49220663309097, 62.93907031416893, 60.22326484322548, 65.34624114632607, 57.37119488418102, 58.70709680020809, 57.0624690502882, 19.76972546428442, 3.045601649209857, 2.5298914220184088, 6.9611656665802, 4.679017150774598, 2.4682974396273494, 1.2199636059813201, 0.2596099366201088, 0.0511103338067187, 0.12356787759927101, 1.9361980981193483, 31.908278614282608, 36.0755529999733, 29.014714881777763, 28.410875983536243, 29.049906693398952, 39.13620136678219, 50.972885414958, 49.87712301313877, 56.63339227437973, 54.86943572759628, 73.20073887705803, 22.70961631089449, 0.6671933142933995, 0.1305144911748357, 0.03737124330655206, 0.049523117413627915, 0.047937374183675274, 0.029342914240260143, 0.03845116836600937, 0.04979477314918768, 0.01669985711487243, 0.03047703648917377, 0.04568242897221353, 0.037593546221614815, 0.0763607322005555, 0.03774231343413703, 0.04239488916937262, 0.02650477454153588, 0.01762683481501881, 0.03426708448387217, 0.03377492554136552, 0.01785964468581369, 0.05726259703806136, 0.06450245913583785, 0.03371417333255522, 0.04244452029524837, 0.03907697697286494, 0.18304493569303304, 0.11086907776189037, 0.18543767917435616, 0.16173155279830098, 0.12743187689920887, 0.13753862207522616, 0.28200640983413905, 0.1039719431719277, 0.14479713805485517, 0.11677460657665506, 0.10683726402930915, 0.127625280583743, 0.08727701206225902, 0.15570636751363054, 0.1083727453078609, 0.1814338073018007, 0.17391527246218175, 0.11738578745280392, 0.13280979066621512, 0.21757203532615677, 0.20773878641193733, 0.19588564900914207, 1.7623183596879244, 64.78889465332031, 91.46332651376724, 79.11907330155373, 72.81507477164268, 49.325802996754646, 34.65016968548298, 30.88891301304102, 31.85188964009285, 72.25038707256317, 51.237366423010826, 30.302496179938316, 1.0698430426418781, 0.26264520187396556, 0.32051395915914327, 0.4547380161238834, 0.27590770740062, 4.256410477682948, 10.438740961253643, 15.498713795095682, 10.287756063044071, 5.954824341461062, 10.243178755044937, 34.14931856095791, 55.804861932992935, 62.697726264595985, 67.8334204852581, 70.55337533354759, 67.75835931301117, 66.08379676938057, 58.44541244208813, 52.5129009783268, 60.108833983540535, 67.34074652194977, 64.58859980106354, 68.27368766069412, 63.70224416255951, 59.22393746674061, 58.347062319517136, 60.03278486430645, 64.70566391944885, 60.75733378529549, 51.903178095817566, 49.063202887773514, 63.40630084276199, 62.806142047047615, 61.804432198405266, 61.229971423745155, 60.181577280163765, 60.6496399641037, 58.78474563360214, 51.12232379615307, 49.05464194715023, 49.97313246130943, 55.52546672523022, 57.70671688020229, 59.72545735538006, 55.48268482089043, 61.745219975709915, 55.76724015176296, 56.120275408029556, 47.509979233145714, 61.92563809454441, 58.88830527663231, 69.3317560851574, 37.29469858109951, 40.80526940524578, 70.10516658425331, 57.85642884671688, 63.51476602256298, 57.76970610022545, 60.806700736284256, 58.191696256399155, 57.14772507548332, 60.43996341526508, 62.37260431051254, 63.18020157516003, 65.06686493754387, 61.143028289079666, 54.14884239435196, 49.25164997577667, 64.94171485304832, 61.26493714749813, 59.74230945110321, 50.78570365905762, 47.787326350808144, 47.17128060758114, 57.37620681524277, 66.43041417002678, 62.71764099597931, 57.471585497260094, 56.412817910313606, 63.686942383646965, 68.20775359869003, 64.09024894237518, 63.41530255973339, 66.63714587688446, 70.32591193914413, 67.04734906554222, 66.10467284917831, 61.27371847629547, 64.24155682325363, 67.44098514318466, 61.92441835999489, 61.64987549185753, 61.3666120916605, 19.470985494554043, 5.507203135639429, 8.593188542872667, 12.94581888243556, 8.499046694487333, 3.251757686957717, 1.0070644738152623, 0.3332465415587649, 0.1841580681502819, 0.44494229019619524, 3.361036260612309, 42.8257691860199, 44.14572715759277, 43.3924213796854, 63.28883774578571, 53.85098397731781, 42.78679087758064, 54.366597309708595, 59.07784290611744, 67.97518327832222, 63.1772643327713, 83.24629783630371, 25.773885883390903, 0.833243572851643, 0.2638822136214003, 0.20824697945499793, 0.16925100790103897, 0.1504841711721383, 0.10968556001898833, 0.07193632976850495, 0.21451061678817496, 0.1038380448881071, 0.15375652292277664, 0.11458170862169936, 0.06793204971472733, 0.14779928867937997, 0.13091277214698493, 0.2230918625718914, 0.16888610873138532, 0.20835944451391697, 0.15988079976523295, 0.09783219255041331, 0.15618573554093018, 0.11971594562055543, 0.16116560582304373, 0.15729864535387605, 0.12412963144015521, 0.1501695005572401], [0.029582286551885772, 0.03270003966463264, 0.024872168396541383, 0.05098506298963912, 0.04919526254525408, 0.05478301114635542, 0.07145141047658399, 0.11818781902547926, 0.04455486545339227, 0.06516903391457163, 0.01837407919083489, 0.06801692172302864, 0.06451844499679282, 0.040439519289066084, 0.028447431432141457, 0.022790240072936285, 0.07018255317234434, 0.0392606807872653, 0.030459119188890327, 0.0721870272536762, 0.036312818265287206, 0.13764704985078424, 8.215276021510363, 67.44952708482742, 62.51593641936779, 58.72569680213928, 43.49956043064594, 29.300165064632893, 16.682463325560093, 24.190917424857616, 44.82614524662495, 23.852249197661877, 37.146042957901955, 4.582780664786696, 0.08239007351221517, 0.06120044374256395, 0.006938945798538043, 0.1485868261079304, 0.5615002638660371, 2.313611777499318, 4.598647663369775, 2.7467714343219995, 1.913351349066943, 11.78376143798232, 40.810649916529655, 60.16208432614803, 67.43468508124352, 63.59760917723179, 64.28884908556938, 62.669163197278976, 63.068920746445656, 52.92770192027092, 47.67394043505192, 46.827456057071686, 50.79672686755657, 56.25172935426235, 57.647687047719955, 57.45202034711838, 60.23046925663948, 61.25340856611729, 56.565402522683144, 56.57683230936527, 58.32337439060211, 54.689074605703354, 48.59971135854721, 40.58614656329155, 48.04429516196251, 56.62619546055794, 58.475012853741646, 59.0725801885128, 58.8032316416502, 54.99165616929531, 52.357147336006165, 43.887246027588844, 44.52015906572342, 47.462952956557274, 52.20814973115921, 50.00282786786556, 55.237715765833855, 51.89382679760456, 51.92814655601978, 49.159341529011726, 46.33852869272232, 42.70587041974068, 55.76803430914879, 53.81305821239948, 65.5053386092186, 32.74946227669716, 39.485516622662544, 66.07957899570465, 52.38253757357597, 59.12792041897774, 52.037052512168884, 56.78856834769249, 51.01383201777935, 53.62779915332794, 50.807062312960625, 54.452434703707695, 54.57485653460026, 58.2535607367754, 57.674912586808205, 55.73700897395611, 50.30087247490883, 60.799986496567726, 55.292596220970154, 52.57163442671299, 40.747930482029915, 43.677128702402115, 40.72483912110329, 49.42752733826637, 57.70937293767929, 61.80459938943386, 56.46807074546814, 54.64582532644272, 58.914824053645134, 62.104331105947495, 54.90773007273674, 52.530459836125374, 56.14896386861801, 62.96312302350998, 63.223925828933716, 58.1964536011219, 55.23271903395653, 61.74233593046665, 61.520420238375664, 66.06706246733665, 51.45290605723858, 53.83780248463154, 50.349190682172775, 21.07760578393936, 2.188053927384317, 2.00218191370368, 2.136586639098823, 2.4859413178637624, 0.6010781088843942, 0.09357605726108886, 0.04469077495741658, 0.14819565491052344, 0.08007330368855037, 9.206227697432041, 42.550717145204544, 46.44504077732563, 64.9907474219799, 49.15241450071335, 18.62115539610386, 14.262187946587801, 36.42006151378155, 46.95514440536499, 49.84655745327473, 56.29615277051926, 49.19449344277382, 2.779969540424645, 0.09998619454563595, 0.0370659682812402, 0.02571028504462447, 0.016480882732139435, 0.022825621963420417, 0.09216395061230287, 0.00842339653900126, 0.07694699175772257, 0.012179407785879448, 0.05155558159458451, 0.030244577283156104, 0.03933490297640674, 0.05431138000858482, 0.08756452007219195, 0.02270072222017916, 0.08929362025810406, 0.016833720146678388, 0.018080051413562614, 0.028597660675586667, 0.010464956667419756, 0.009843407988228137, 0.07911507971584797, 0.03156766702886671, 0.0395180093619274, 0.020598520277417265, 0.05236813311057631, 0.10650349795469083, 0.05258181598037481, 0.06431073270505294, 0.019180302042514086, 0.06506528166937642, 0.09833513118792325, 0.025673754680610728, 0.010819244052981958, 0.035210628775530495, 0.10784760161186568, 0.039174984995042905, 0.05049439576396253, 0.026764466856548097, 0.026846435212064534, 0.06286987525527366, 0.06442149824579246, 0.02798498622723855, 0.09507564827799797, 0.029791781853418797, 0.09056175025762059, 12.60547874495387, 79.74093273282051, 72.42399975657463, 65.57520166039467, 51.783587113022804, 37.02667996287346, 28.293268494307995, 31.021052822470665, 28.053790144622326, 31.363921724259853, 37.234487012028694, 4.33356486260891, 0.043085357392556034, 0.05443354122689925, 0.09610498484107666, 0.45628969848621637, 1.731851000804454, 4.066831050440669, 4.1265438962727785, 1.1840789252892137, 0.6233245495241135, 12.728379350155592, 41.75924241542816, 63.72562810778618, 68.12169581651688, 66.78280726075172, 65.04460573196411, 65.34677311778069, 64.59275677800179, 56.871365904808044, 48.55278767645359, 49.03408505022526, 53.068769350647926, 58.31904262304306, 60.46849988400936, 60.56613564491272, 62.37123638391495, 62.40640729665756, 55.592514127492905, 57.50820033252239, 61.43251195549965, 58.29280503094196, 50.81122688949108, 44.044219404459, 50.3372061252594, 59.152288511395454, 61.71597674489021, 60.99809646606445, 59.61100369691849, 56.953319907188416, 54.20531116425991, 47.69505210220814, 46.43170729279518, 49.296612963080406, 54.02381770312786, 52.861239686608315, 56.714156940579414, 54.84730951488018, 54.187752306461334, 53.06666046380997, 49.22824703156948, 46.12551972270012, 57.8759977966547, 55.99884532392025, 66.92394688725471, 35.5558966845274, 41.09403111040592, 67.00394779443741, 55.04523329436779, 60.17476424574852, 53.80708873271942, 59.38267394900322, 53.52058410644531, 55.220521688461304, 54.833379462361336, 57.161123156547546, 55.86489871144295, 60.15376657247543, 60.68422570824623, 55.63742771744728, 50.32965213060379, 62.060040682554245, 57.48922415077686, 55.032169595360756, 43.269832357764244, 46.374778747558594, 45.006118789315224, 52.4816020578146, 60.38189873099327, 63.38916376233101, 56.61513425409794, 54.64315786957741, 61.44195444881916, 64.09572824835777, 56.91439099609852, 55.11086717247963, 57.747245505452156, 66.28064900636673, 64.53662618994713, 63.05291220545769, 58.54467071592808, 64.27259355783463, 63.22446919977665, 66.59388139843941, 55.32128848135471, 59.30167369544506, 52.60821506381035, 22.16018669307232, 3.062398172914982, 3.951675617136061, 6.538575142621994, 4.337975950911641, 2.448481977917254, 0.7488747406750917, 0.08067954186117277, 0.08243020143709145, 0.15503907285165042, 10.722429938614368, 42.767104133963585, 47.61577695608139, 68.15113663673401, 36.702671349048615, 17.205619253218174, 23.004890866577625, 48.06794509291649, 53.27383674681187, 57.234311029314995, 62.054637372493744, 60.58788947761059, 4.29569466970861, 0.04707364416390192, 0.061375742734526284, 0.047084449834073894, 0.014198725748428842, 0.03881818265654147, 0.031263085911632515, 0.03196265286533162, 0.019865528847731184, 0.045961676878505386, 0.030034675655770116, 0.07333233181270771, 0.08273552841274068, 0.033721902800607495, 0.01136569851951208, 0.02150917258404661, 0.04605934722349048, 0.03987241827417165, 0.010534976445342181, 0.00791481386841042, 0.02906083504058188, 0.054817224154248834, 0.14190252462867647, 0.04420949589984957, 0.03360749331477564, 0.1214807282667607, 0.14785808161832392, 0.26545025291852653, 0.12313265993725508, 0.14135118311969563, 0.17936091462615877, 0.15687444858485833, 0.16406753682531416, 0.12356519844615832, 0.1231890037888661, 0.09458681786782108, 0.22906986210728064, 0.11727642457117327, 0.13270336668938398, 0.1934585886192508, 0.15576625883113593, 0.13822743901982903, 0.1287766484892927, 0.14072958991164342, 0.1986285377643071, 0.1307430281303823, 0.23507496487582102, 16.60946924239397, 95.3343839943409, 79.82731729745865, 76.96223303675652, 59.792177975177765, 44.41264383494854, 26.807531118392944, 35.926103219389915, 58.93066920340061, 33.716764971613884, 51.58533655107021, 6.531246285885572, 0.2700603852281347, 0.1733022287953645, 0.30459872097708285, 0.6563801039010286, 1.1141907004639506, 10.801668036729097, 14.639116320759058, 8.897954989224672, 6.507658576592803, 15.04085736349225, 45.74376940727234, 66.44133478403091, 70.8101199567318, 68.64914551377296, 70.28040558099747, 67.79321864247322, 68.15385729074478, 58.8227815926075, 50.396482944488525, 51.08852840960026, 55.43851979076862, 59.63085763156414, 63.9895923435688, 64.55285891890526, 63.713122978806496, 64.21850726008415, 57.30923920869827, 58.76349337399006, 62.168585658073425, 59.64623540639877, 52.81857557594776, 44.60807494819164, 52.99823373556137, 61.62854343652725, 63.238323256373405, 63.69334124028683, 63.05304519832134, 59.94277149438858, 56.33249022066593, 49.81100656092167, 48.61294224858284, 51.614047810435295, 56.8067541718483, 55.1605799049139, 60.32427862286568, 58.17504934966564, 58.81409525871277, 55.63861705362797, 51.800986379384995, 47.52951018512249, 61.29142552614212, 59.620339795947075, 69.37580332159996, 40.01594536006451, 42.57669635117054, 68.51723179221153, 58.45511332154274, 62.970160245895386, 57.53995522856712, 62.95780710875988, 56.511920392513275, 58.532439172267914, 58.13213065266609, 60.315641686320305, 58.27420122921467, 63.36401671171188, 63.927306085824966, 56.8640398979187, 50.77093005180359, 64.51983109116554, 61.664554104208946, 57.33105383813381, 45.16860947012901, 48.92073333263397, 47.23020024597645, 54.13435377180576, 63.90312418341637, 66.00688129663467, 58.22922684252262, 55.321873649954796, 62.64870509505272, 67.4172592163086, 59.82121221721172, 57.708525583148, 61.09483927488327, 69.13116484880447, 70.85418239235878, 65.43808981776237, 66.01235300302505, 64.81523483991623, 67.02990040183067, 70.5445446074009, 57.60183870792389, 61.44446611404419, 58.50270576775074, 26.063669733703136, 6.463075093924999, 7.787211891263723, 11.184773929417133, 7.524544335901737, 1.7753511853516102, 0.5255434464197606, 0.19277015759143978, 0.43431102472823113, 0.27294267900288105, 14.628839772194624, 60.1835797727108, 52.39256143569946, 72.60601758956909, 64.43576440215111, 31.363874226808548, 25.327907614409924, 51.92611746490002, 63.000763803720474, 66.30455732345581, 69.72112879157066, 71.04273587465286, 6.406837161630392, 0.2138271284638904, 0.1517168784630485, 0.13427449332084507, 0.12194949842523783, 0.1590685933479108, 0.1650651911040768, 0.10187815903918818, 0.17104489757912233, 0.28895317926071584, 0.14277448877692223, 0.1109061406168621, 0.15360562945716083, 0.18635107000591233, 0.26248014823067933, 0.08548166035325266, 0.11494874517666176, 0.11553665972314775, 0.10527925856877118, 0.1401315673138015, 0.17495364096248522, 0.11922051751753315, 0.4477147164288908, 0.1893175975419581, 0.18671767611522228], [0.050684508023550734, 0.04476778020034544, 0.015894714088062756, 0.026250511036778335, 0.02396148269326659, 0.0374886659119511, 0.03644191114290152, 0.03139064625429455, 0.057580803986638784, 0.026873017086472828, 0.026432134982314892, 0.030084650024946313, 0.022500260711240117, 0.05183632121770643, 0.03456670434388798, 0.026899350341409445, 0.054785860993433744, 0.028909913744428195, 0.02408118554740213, 0.02234869189123856, 0.06045020665624179, 0.06070019539038185, 26.807274632155895, 76.31701245903969, 70.02238422632217, 60.046714916825294, 34.79935348033905, 32.11614266037941, 20.961005240678787, 18.154774121940136, 32.7873994410038, 56.73105463385582, 20.698165744543076, 0.09973257299861871, 0.05083444782940205, 0.019918963480449747, 0.10732953800470568, 0.18448208982590586, 1.9608176895417273, 4.842004654929042, 2.9407897358760238, 0.8349904697388411, 14.652476403862238, 47.94830471277237, 62.24920213222504, 65.58349281549454, 62.18438521027565, 61.83347783982754, 61.956709027290344, 60.488122031092644, 53.27958203852177, 52.33060196042061, 50.3805086016655, 46.640034914016724, 48.96912753582001, 48.07647943496704, 52.899214848876, 58.53280395269394, 58.74295927584171, 58.835659101605415, 57.18776732683182, 55.420136377215385, 59.0926431119442, 56.89483344554901, 49.28581394255161, 41.84332050383091, 43.79139617085457, 43.88419859111309, 50.952780693769455, 50.230956226587296, 54.5339061319828, 47.725834250450134, 47.35489435493946, 43.23700591921806, 44.17017884552479, 48.084542602300644, 53.283260241150856, 52.644518315792084, 57.84556902945042, 49.37021881341934, 53.325149193406105, 48.79107668995857, 45.003409534692764, 45.099468380212784, 58.24950635433197, 53.78696121275425, 62.090534046292305, 32.26728715002537, 46.521758660674095, 62.57394790649414, 52.70530365407467, 54.458267390728, 52.201712876558304, 53.18876691162586, 52.76276417076588, 52.874865755438805, 49.60227236151695, 48.35630401968956, 50.5182284116745, 54.210984259843826, 58.975563794374466, 57.641238793730736, 52.695215195417404, 57.7752386033535, 57.1645125746727, 51.17716245353222, 43.544094040989876, 42.36325040459633, 42.81506136059761, 47.80274972319603, 56.47222392261028, 59.522848427295685, 60.5383325368166, 52.400487810373306, 56.96743994951248, 59.13369990885258, 56.36139526963234, 52.911275401711464, 46.80570602416992, 55.33572010695934, 61.840370669960976, 58.94521102309227, 52.42242403328419, 58.771431148052216, 61.07038378715515, 62.29755073785782, 67.73530215024948, 56.597560197114944, 45.07749415934086, 45.00346653163433, 10.942078102380037, 5.311047211289406, 3.473659842275083, 2.0167842926457524, 2.6967808417975903, 0.37647910765372217, 0.0804863459779881, 0.07208629554952495, 0.12705802742857486, 0.1158643772942014, 18.691719509661198, 31.17631059139967, 25.55956408381462, 54.99007165431976, 63.78200188279152, 22.02932931482792, 12.9844837076962, 29.688143245875835, 49.471167996525764, 53.916177079081535, 60.400570929050446, 15.271421391516924, 0.3640731889754534, 0.09051602653926238, 0.03484745138848666, 0.04936571160214953, 0.01512654300313443, 0.10282687610015273, 0.00896842608199222, 0.018261447148688603, 0.03265125829784665, 0.03153242985717952, 0.03841138182906434, 0.07101159149897285, 0.008398037352890242, 0.051670759203261696, 0.03424117239774205, 0.03711347315402236, 0.10505075129913166, 0.03585562189982738, 0.06417854136088863, 0.038254239480011165, 0.019510125457600225, 0.032513656697119586, 0.023966410553839523, 0.05977791362965945, 0.02908493628638098, 0.008865158088156022, 0.023056177560647484, 0.021467604892677628, 0.011456217343948083, 0.03289208150818013, 0.04594485610141419, 0.08947771741077304, 0.05296832649037242, 0.03987265576142818, 0.025896818297042046, 0.045455320650944486, 0.030746916636417154, 0.032217981352005154, 0.05695600470062345, 0.1049550884636119, 0.02080549227684969, 0.020287894367356785, 0.050784278646460734, 0.07692784434766509, 0.030757351232750807, 0.13585108215920627, 34.88881587982178, 87.02384233474731, 77.3988676071167, 66.4622488617897, 45.30958950519562, 39.79372188448906, 21.9643547013402, 20.858349949121475, 31.379314698278904, 46.328440234065056, 20.68143144249916, 0.026486888782528695, 0.03527896944433451, 0.1955024930066429, 0.301724323653616, 1.7111060139723122, 3.598269405774772, 2.319956962019205, 1.1965478374622762, 1.1890773195773363, 16.03094268590212, 51.4555849134922, 65.10854870080948, 69.11949947476387, 63.18483732640743, 65.58855414390564, 62.900555580854416, 61.238615959882736, 56.17164485156536, 54.177299067378044, 50.933872908353806, 47.991553992033005, 49.850817024707794, 51.47802650928497, 54.788769856095314, 60.56281842291355, 61.360467821359634, 60.63658766448498, 57.368778213858604, 56.68577626347542, 61.83783620595932, 58.46546396613121, 52.1227303147316, 43.37286002933979, 45.483183190226555, 46.61756671965122, 52.90258526802063, 53.2053492218256, 55.92401973903179, 50.51100119948387, 49.11730818450451, 45.177614986896515, 48.52691486477852, 49.73961979150772, 53.840766325592995, 55.278491377830505, 59.75264869630337, 51.903725266456604, 55.41545882821083, 51.14984951913357, 47.442004680633545, 48.0455756932497, 60.87671957910061, 56.85424402356148, 64.6996146440506, 34.966377317905426, 48.735022097826004, 65.06952479481697, 55.526948645710945, 56.808133497834206, 54.83971752226353, 55.5147323012352, 55.62238052487373, 54.45307306945324, 51.76081493496895, 50.9896083176136, 52.189580127596855, 57.012307941913605, 60.949656665325165, 59.25190396606922, 52.61997543275356, 60.87529085576534, 59.60368148982525, 53.42963978648186, 45.722585543990135, 43.86053346097469, 43.94984386861324, 49.91613171994686, 58.56654234230518, 60.712416395545006, 60.617041513323784, 54.07878555357456, 59.3667946010828, 64.29197251796722, 58.76658260822296, 53.94185610115528, 48.651817962527275, 57.46414169669151, 64.5727850496769, 62.37257771193981, 58.05010065436363, 60.346374437212944, 61.9123350083828, 64.39541816711426, 67.64723807573318, 60.03681264817715, 52.27202050387859, 48.06883804500103, 13.465357404202223, 2.127399919554591, 3.9867142494767904, 5.752210188657045, 7.126168962568045, 2.1851924434304237, 0.1816889428300783, 0.09462736881687306, 0.16999499610392377, 0.15902298095170408, 21.832585372030735, 37.060034573078156, 31.081638671457767, 54.496922716498375, 54.75853107869625, 21.86836425215006, 22.755952924489975, 37.85054035484791, 55.399625077843666, 59.686779230833054, 66.93427473306656, 21.441084779798985, 0.4168362374184653, 0.06192572611325886, 0.004829751896977541, 0.019476433808449656, 0.04975028510671109, 0.04110452071472537, 0.02319394985534018, 0.06505037934402935, 0.02964285322377691, 0.028177727544971276, 0.02949883390101604, 0.021685208157578018, 0.007800816274539102, 0.06173802583361976, 0.04489174112677574, 0.050309675207245164, 0.032963149569695815, 0.011568012614588952, 0.025467085106356535, 0.023954710595717188, 0.009180198849207954, 0.04497362970141694, 0.020040308336319868, 0.054779322672402486, 0.10114791541127488, 0.10738136959844269, 0.1337603185675107, 0.07620980162755586, 0.11708790421835147, 0.15240620006807148, 0.17979563504923135, 0.1871027468587272, 0.1402719964971766, 0.11587989560212009, 0.12961569096660241, 0.11723900548531674, 0.11078629861003719, 0.15899204823654145, 0.18589098297525197, 0.1344676298322156, 0.14322697621537372, 0.10955519435810857, 0.11379552190192044, 0.1164978819724638, 0.18104088463587686, 0.31693974626250565, 46.45620457828045, 98.52723866701126, 84.00207728147507, 76.05528250336647, 49.560702592134476, 44.33777265250683, 30.413081645965576, 27.98496823757887, 45.0563520938158, 75.03350973129272, 29.471165388822556, 0.34007729846052825, 0.15875407116254792, 0.30726614815648645, 0.3118883032584563, 0.951101848622784, 8.130358178168535, 12.320352494716644, 10.50925187766552, 4.718177849426866, 17.873593010008335, 53.74723434448242, 67.53805473446846, 71.8009015917778, 67.0228859782219, 68.4900176525116, 66.91361904144287, 65.5698211491108, 59.548329859972, 56.45739331841469, 54.624633863568306, 51.20942272245884, 52.77062214910984, 53.38474899530411, 58.292797431349754, 64.57654684782028, 65.89004516601562, 62.125708758831024, 56.99169024825096, 56.49628043174744, 64.15833368897438, 62.51412391662598, 55.77865853905678, 45.996022671461105, 47.45932035148144, 48.65273371338844, 54.602602645754814, 54.15888525545597, 59.09097880125046, 50.8343106508255, 51.805952712893486, 46.97306044399738, 50.639339312911034, 52.348100021481514, 57.63763278722763, 56.890224292874336, 62.91648052632809, 56.11274801194668, 58.958445712924004, 53.779847994446754, 49.549117013812065, 49.692570716142654, 63.891914784908295, 59.44421924650669, 67.71330893039703, 37.74380788207054, 53.30107368528843, 66.18479534983635, 58.2522764056921, 58.30386243760586, 57.66666702926159, 58.93379643559456, 59.620305597782135, 57.72132709622383, 53.41668248176575, 53.67971956729889, 55.40487639605999, 58.884794265031815, 62.58202627301216, 59.59390461444855, 53.88157233595848, 62.21072539687157, 61.435954570770264, 56.498552709817886, 47.3278322070837, 46.83085687458515, 48.13762575387955, 52.12990052998066, 60.75954906642437, 65.43766424059868, 63.586707562208176, 54.88640941679478, 59.95168961584568, 66.01103067398071, 61.62774547934532, 56.432899832725525, 51.247268691658974, 59.921424239873886, 67.46892124414444, 64.10150393843651, 60.278760865330696, 64.30108442902565, 63.26355770230293, 65.84538236260414, 71.36546775698662, 64.20115739107132, 53.98924335837364, 52.10670657455921, 15.099936593323946, 10.109673868864775, 12.972125820815563, 8.451392501592636, 9.881169330328703, 1.637558110523969, 0.1949347203481011, 0.21064968255814165, 0.3920088446466252, 0.4336456151213497, 29.62583038955927, 43.21260362863541, 33.135806545615196, 63.9905346930027, 75.30713304877281, 34.43892382085323, 27.424505911767483, 42.88614794611931, 66.44307509064674, 67.85308822989464, 77.37029314041138, 25.87465837597847, 0.8476446219719946, 0.23685798951191828, 0.07799985440215096, 0.10965370704070665, 0.12994104850804433, 0.22589591913856566, 0.08324073060066439, 0.12032752725644968, 0.12984011642402038, 0.14150513423373923, 0.06570518366061151, 0.1907813354046084, 0.13612156530143693, 0.1840344411903061, 0.18931145255919546, 0.1587290014140308, 0.18464775203028694, 0.14641289744758978, 0.14395154983503744, 0.14452261762926355, 0.08685240711201914, 0.12962689739651978, 0.08383177701034583, 0.11791865690611303], [0.06545941403601319, 0.059594191261567175, 0.02544010989367962, 0.06532782383146696, 0.009099176731979242, 0.03474084929621313, 0.01175859335489804, 0.046442269449471496, 0.02030208608630346, 0.00899700711670448, 0.08197677147109061, 0.011549090631888248, 0.06033504760125652, 0.03610131359891966, 0.030861298291711137, 0.024197545026254375, 0.04193662782199681, 0.13450276310322806, 0.03242404607590288, 0.06858646811451763, 0.0570273696212098, 2.2828666772693396, 62.806905806064606, 71.54737919569016, 60.97789295017719, 48.05167816579342, 44.287603944540024, 36.0193008184433, 32.20619782805443, 40.571015775203705, 36.852033734321594, 43.97754818201065, 1.7554255295544863, 0.10163967730477452, 0.11703548632794991, 0.04673754403484054, 0.29500010947231203, 0.991229951614514, 3.2929925993084908, 1.2607458676211536, 1.904670239891857, 17.838826775550842, 53.1738793104887, 65.28841584920883, 60.21283060312271, 58.06410290300846, 56.38373427093029, 55.3480314463377, 49.13876563310623, 49.74158048629761, 47.65247158706188, 52.23114229738712, 52.67731435596943, 53.49265560507774, 53.46133768558502, 48.50848965346813, 46.1712920665741, 50.241888239979744, 54.881880059838295, 58.53309653699398, 56.8714153021574, 57.14314632117748, 59.5512443035841, 56.11248962581158, 49.05639745295048, 46.42555922269821, 47.00202628970146, 47.73328185081482, 46.1584335565567, 44.182695373892784, 44.460730254650116, 45.24891056120396, 42.86567084491253, 44.76008199155331, 45.76348274946213, 51.92521691322327, 52.21138335764408, 55.02160616219044, 50.18834911286831, 49.12617310881615, 50.366194769740105, 43.591618090867996, 43.9751923084259, 49.49721559882164, 59.05095174908638, 55.06408028304577, 58.358226120471954, 37.47822493314743, 50.23084223270416, 59.7407591342926, 53.21808233857155, 50.328326001763344, 51.52729086577892, 53.524813279509544, 51.129053235054016, 52.086970433592796, 47.85278543829918, 48.65259692072868, 43.91995467245579, 51.09724894165993, 58.31969238817692, 58.33369083702564, 50.11711813509464, 55.685802921652794, 58.153424710035324, 52.37600952386856, 44.924981743097305, 42.08632506430149, 42.39937126636505, 45.522697269916534, 54.83383163809776, 58.62980514764786, 56.672712564468384, 51.49248093366623, 53.97144131362438, 58.61698843538761, 57.90646456182003, 53.44702385365963, 50.169163942337036, 44.64909374713898, 54.04368683695793, 60.306525975465775, 61.2856612354517, 57.74961277842522, 59.74940367043018, 62.03620836138725, 62.55192048847675, 68.59644994139671, 59.38888281583786, 46.591002345085144, 35.588213950395584, 6.553963366895914, 4.93272858671844, 3.3879143558442593, 4.687247984111309, 1.996180610731244, 0.11092176282545552, 0.16993252211250365, 0.09032908696099184, 0.052658717322628945, 3.4780239081010222, 27.88614884018898, 57.26702347397804, 72.54176303744316, 82.13609620928764, 81.9336886703968, 19.493045210838318, 29.752893671393394, 40.96437446773052, 49.850638434290886, 55.81300489604473, 38.518073335289955, 1.569763335864991, 0.06935798257472925, 0.03567159525118768, 0.07470174270565622, 0.022653712730971165, 0.03662514740426559, 0.04969428264303133, 0.09269868285628036, 0.02487186782673234, 0.07073295215377584, 0.04285453091142699, 0.03229929105145857, 0.06250388512853533, 0.021402180864242837, 0.022290915694611613, 0.03196803714672569, 0.014999625545897288, 0.023799486698408145, 0.033546507329447195, 0.030257603830250446, 0.010210643995378632, 0.06390615089912899, 0.030766312665946316, 0.008524555905751185, 0.0664643116760999, 0.04204077340546064, 0.048098965708049946, 0.05302324912918266, 0.027959259678027593, 0.041118127992376685, 0.0011518503015395254, 0.0813278004352469, 0.07555363175924867, 0.0821151449054014, 0.08929396164603531, 0.05236739838437643, 0.013853040782123571, 0.04651188290154096, 0.05922429743804969, 0.03911894171324093, 0.025548893900122494, 0.029785746337438468, 0.009548401503707282, 0.03927939775167033, 0.008365489538846305, 3.036408517509699, 72.3106138408184, 79.70219761133194, 69.27435636520386, 55.048143938183784, 50.74110925197601, 41.63305498659611, 29.0433007478714, 33.70603434741497, 35.38940101861954, 41.56282715499401, 2.5960748456418514, 0.0391434474295238, 0.05074556822364684, 0.3665090957656503, 0.5388056847732514, 4.445513030514121, 4.3462371826171875, 3.3473852556198835, 1.4052074658684433, 19.246079362928867, 56.08071193099022, 66.38490781188011, 63.61274756491184, 61.19315519928932, 59.6171897649765, 57.429859936237335, 53.30664798617363, 51.83404080569744, 49.58518847823143, 53.663885816931725, 54.79609206318855, 56.26575440168381, 57.08990357816219, 51.50828428566456, 47.9638534784317, 53.93370933830738, 59.408900141716, 61.71840101480484, 56.353100314736366, 55.67582845687866, 60.00508815050125, 58.246310725808144, 53.01351651549339, 47.338726222515106, 49.527602568268776, 49.21596609055996, 47.6298476010561, 46.140669509768486, 46.328618824481964, 46.389692947268486, 45.459799244999886, 46.48319073021412, 47.28293001651764, 52.18247830867767, 54.994711205363274, 57.91850991547108, 53.7965252995491, 52.50765725970268, 53.692646473646164, 45.67888788878918, 44.61714506149292, 51.267232820391655, 60.38369223475456, 57.23847180604935, 60.400339141488075, 39.19561117887497, 51.58536694943905, 62.593057081103325, 56.11535087227821, 53.24349917471409, 53.15502092242241, 55.257885083556175, 53.4489693492651, 54.15274478495121, 50.23863561451435, 49.11389596760273, 47.36149840056896, 54.191457107663155, 61.13381378352642, 60.30953921377659, 50.40801912546158, 55.62108859419823, 60.353381261229515, 53.454661443829536, 46.509812101721764, 44.01028722524643, 44.744198843836784, 47.2316137701273, 57.91266582906246, 60.76861537992954, 58.906798884272575, 54.21975418925285, 54.210486486554146, 59.119085893034935, 61.71505719423294, 56.514356061816216, 52.52856753766537, 47.50232644379139, 57.57676385343075, 62.12767705321312, 63.21490131318569, 59.48189802467823, 61.03040613234043, 64.21109765768051, 65.96653506159782, 68.53550121188164, 62.66781806945801, 51.94712653756142, 38.64214427769184, 7.530478667467833, 1.967131169512868, 3.6509082186967134, 8.635844103991985, 5.131683060899377, 2.1639487333595753, 0.4011940798955038, 0.019118375385005493, 0.03859436204947997, 3.4178610239177942, 28.192687891423702, 47.53861829638481, 69.72237512469292, 76.60357788205147, 78.03536385297775, 24.319219440221786, 38.286525160074234, 48.128757029771805, 56.34202390909195, 62.71431237459183, 46.85242831707001, 2.0553507981821895, 0.13406713725998998, 0.05117821434396319, 0.06902107721543871, 0.023317977575061377, 0.05393223531427793, 0.012501155706559075, 0.01740389365295414, 0.009497428945905995, 0.03424441187235061, 0.04873045916610863, 0.02652111477800645, 0.057698842574609444, 0.09324935643235222, 0.06896296705235727, 0.00970359107668628, 0.03641121962573379, 0.018973803162225522, 0.03253606955695432, 0.04238045439706184, 0.03290220811322797, 0.07662823190912604, 0.01730489300825866, 0.03286698578449432, 0.15986420534318313, 0.18666001124074683, 0.07580136807519011, 0.11952706903684884, 0.14833032502792776, 0.12382856439216994, 0.13949006970506161, 0.2006493613589555, 0.18923370516858995, 0.1579790611867793, 0.23091732000466436, 0.09205521855619736, 0.11176223022630438, 0.2390365640167147, 0.14515664923237637, 0.09294819290516898, 0.10258062407956459, 0.20599567447789013, 0.11049902808736078, 0.16878958500456065, 0.15242114692227915, 5.039615426212549, 85.63845187425613, 86.02220088243484, 80.02359956502914, 63.17395471036434, 60.11886164546013, 42.89372853934765, 45.40662109851837, 54.39479939639568, 50.60729183256626, 62.250254675745964, 3.2380214240401983, 0.20638187328586355, 0.24712782906135544, 0.5408404162153602, 0.3765264566754922, 4.4651000294834375, 10.033644698560238, 10.389200169593096, 6.280203256756067, 22.45388813316822, 59.375499933958054, 68.92325520515442, 65.27643129229546, 65.0551463663578, 60.99448285996914, 60.169623121619225, 54.052152782678604, 54.18782450258732, 53.03726144134998, 55.708947479724884, 56.2352230399847, 58.992343693971634, 58.8401048630476, 53.94171930849552, 49.49629224836826, 55.60376912355423, 60.86272493004799, 64.95960429310799, 57.40081809461117, 57.143370509147644, 61.42176233232021, 59.96897108852863, 53.37229706346989, 51.4865380525589, 51.61617189645767, 53.01391929388046, 51.45634487271309, 48.88251878321171, 49.69535976648331, 48.46242092549801, 47.3426666110754, 49.111251309514046, 50.44623367488384, 56.022449657320976, 57.16209590435028, 59.825414791703224, 57.213533744215965, 55.52077017724514, 56.21891811490059, 49.48005951941013, 47.831274792551994, 55.75331389904022, 63.245748057961464, 59.7667421400547, 62.81333886086941, 42.65279106795788, 56.0231564193964, 65.9208995103836, 59.445286989212036, 55.66409468650818, 55.14595828950405, 57.90505863726139, 57.140832245349884, 57.14591637253761, 54.64122757315636, 53.699216321110725, 49.6862668544054, 57.361551001667976, 64.9374970793724, 61.359069496393204, 50.19475556910038, 58.32447253167629, 64.23910215497017, 57.04940915107727, 49.3097298592329, 46.005685552954674, 47.50331059098244, 49.7468926012516, 61.30838021636009, 64.13264706730843, 61.253723949193954, 55.73470629751682, 54.37407910823822, 61.407665088772774, 65.39471134543419, 60.36484144628048, 54.91165906190872, 50.011757388710976, 60.030087009072304, 66.05820134282112, 66.27368777990341, 63.44635829329491, 65.18470421433449, 68.54033455252647, 67.94716358184814, 72.01783955097198, 67.48144537210464, 53.652756214141846, 43.72417017817497, 11.778200436383486, 10.456457510590553, 11.944198329001665, 15.171086825430393, 5.14807490631938, 1.3939639879390597, 0.27580926893278956, 0.20110239798668772, 0.27808861224912107, 5.850706128403544, 43.77105966210365, 69.94562834501266, 74.00822594761848, 83.67928460240364, 91.06199204921722, 33.96499805152416, 43.824477195739746, 56.01687915623188, 65.24603292346, 68.72226119041443, 55.918791219592094, 3.114465828984976, 0.2811984781874344, 0.20344819320598617, 0.20410932804225013, 0.1647012567264028, 0.11068855776102282, 0.1719123643124476, 0.22968802659306675, 0.07289159999345429, 0.09225193221936934, 0.13739859365159646, 0.10222863827948458, 0.15995348570868373, 0.16019167058402672, 0.18055660359095782, 0.08625834016129375, 0.17317744408501312, 0.07589902728796005, 0.19079588149907067, 0.12547946447739378, 0.14372013334650546, 0.18699002946959808, 0.14317656954517588, 0.12208001993712969], [0.035886539772036485, 0.04321492153394502, 0.02027165061008418, 0.01457109370676335, 0.04314227269787807, 0.0613075727596879, 0.04238232460920699, 0.060779809282394126, 0.05384341136959847, 0.013389561208896339, 0.028102700125600677, 0.113175969599979, 0.04156582486757543, 0.04605017427820712, 0.08418469049502164, 0.08742562713450752, 0.027912155564990826, 0.053215235311654396, 0.07168334646848962, 0.06883951820782386, 0.0054175639343156945, 15.595757737755775, 76.01155444979668, 61.063688546419144, 69.44948896765709, 50.61191998422146, 36.38292610645294, 22.763998992741108, 42.259040996432304, 40.95962472259998, 51.61601610481739, 16.76253452897072, 0.022839123485027812, 0.07906791623099707, 0.02479960490745725, 0.24083869153400883, 0.7288033864460886, 5.121716195717454, 1.8888808996416628, 0.5785850971005857, 10.832852963358164, 49.79185178875923, 64.48964551091194, 62.73669317364693, 60.00017501413822, 61.379865780472755, 56.52235083281994, 55.43742924928665, 53.67107503116131, 54.21349212527275, 50.967881083488464, 54.601189121603966, 56.971927508711815, 59.82807084918022, 59.17200185358524, 57.19010040163994, 49.256342723965645, 48.55745382606983, 55.08222810924053, 56.8950804322958, 59.41782966256142, 52.9805950820446, 56.13759487867355, 56.700728461146355, 53.387063071131706, 51.535988599061966, 52.011730670928955, 53.78356419503689, 52.725510969758034, 49.5157890021801, 44.01960052549839, 42.639309391379356, 43.93446609377861, 42.58262023329735, 46.17769472301006, 50.621529668569565, 54.65046487748623, 53.69436778128147, 51.2340833991766, 51.132138669490814, 46.728326976299286, 40.55078946053982, 44.793250411748886, 52.99322560429573, 60.32254211604595, 52.39338219165802, 53.96826848387718, 38.3368344604969, 46.6313523799181, 59.047148153185844, 50.18726997077465, 50.65048411488533, 48.05309168994427, 51.440967097878456, 48.99410739541054, 50.47019138932228, 46.210616156458855, 45.94794765114784, 42.17913128435612, 51.7489405721426, 57.61331029236317, 59.626214280724525, 50.29868759214878, 54.774209037423134, 58.48880231380463, 51.75714813172817, 42.39612624049187, 40.09108252823353, 42.032964527606964, 48.533093333244324, 54.42137897014618, 55.753754675388336, 59.8618358373642, 56.42296716570854, 52.47352369129658, 56.38025365769863, 59.62754800915718, 56.79352708160877, 53.35799843072891, 47.340895906090736, 48.08400683104992, 56.247313991189, 57.59521946310997, 61.58301427960396, 55.38148105144501, 57.23570175468922, 60.438386499881744, 58.18107582628727, 65.04873231053352, 62.49640166759491, 48.51191706955433, 26.899261996150017, 4.608637327328324, 5.79328503459692, 8.034661263227463, 5.835260432213545, 0.7463253743480891, 0.5117252503987402, 0.06115693904575892, 0.1747961126966402, 0.37394399056211114, 9.24238845705986, 43.46648320555687, 61.71206295490265, 73.4692856669426, 74.64198634028435, 31.306324414908886, 19.87120281904936, 40.66518992185593, 54.42930534482002, 51.8027076870203, 51.31125345826149, 5.004316745325923, 0.1436597076826729, 0.10888384014833719, 0.023417171178152785, 0.0662733125500381, 0.03967670651036315, 0.11574388961889781, 0.07314043468795717, 0.04892659024335444, 0.008034610418690136, 0.04716785238997545, 0.07417850632918999, 0.03002551198733272, 0.027571762111620046, 0.055267845091293566, 0.08418654586421326, 0.03216731493012048, 0.10302657319698483, 0.06536646746098995, 0.03975005296524614, 0.051762781804427505, 0.02166785860026721, 0.047443916482734494, 0.08532706357073039, 0.007622326975251781, 0.024536495002394076, 0.043672448155120946, 0.05815808726765681, 0.005259586669126293, 0.06966042259591632, 0.024796358011371922, 0.024530457631044555, 0.031218961521517485, 0.031217213763738982, 0.019932309151045047, 0.04416260700963903, 0.031454960771952756, 0.02192834872403182, 0.025411876740690786, 0.033101797598646954, 0.04874803693383001, 0.04375678581709508, 0.05577688047196716, 0.0706564515712671, 0.07169333577621728, 18.300868682563305, 87.15565726161003, 68.05669650435448, 77.80057445168495, 57.22988046705723, 42.60200299322605, 28.146983943879604, 35.54105468094349, 38.82199242711067, 50.7860304415226, 18.464345410466194, 0.07682032199227251, 0.028255879406060558, 0.16634900268400088, 0.5828208010643721, 3.0445586051791906, 5.696825310587883, 3.087238152511418, 0.974997638259083, 13.274115566164255, 50.78031934797764, 66.73283234238625, 64.21735972166061, 63.478067591786385, 63.5767824947834, 60.13394683599472, 57.41494193673134, 56.10431246459484, 56.34293586015701, 51.52487799525261, 55.52089177072048, 58.990158811211586, 61.72722414135933, 61.48595988750458, 57.98461116850376, 50.162962675094604, 50.72207607328892, 56.864017099142075, 58.80878694355488, 62.49529592692852, 52.87945970892906, 58.499734327197075, 59.9743440002203, 55.521606132388115, 53.50077196955681, 54.617551043629646, 56.40217088162899, 55.75073003768921, 51.68056704103947, 46.000335440039635, 44.97774951159954, 44.44509409368038, 45.35601541399956, 47.55523860454559, 52.47170738875866, 56.08847111463547, 56.27525009214878, 54.76259686052799, 53.50447677075863, 49.551347494125366, 42.89559043943882, 46.3278778642416, 55.33396080136299, 62.58421875536442, 56.92824125289917, 55.21088920533657, 39.88274730741978, 49.55062173306942, 60.998191460967064, 51.90031684935093, 53.08052971959114, 51.337403655052185, 53.95570255815983, 51.357348784804344, 54.41777676343918, 48.462854102253914, 47.65216760337353, 44.68969076871872, 54.77301970124245, 58.09429608285427, 62.006626948714256, 49.57498222589493, 56.145323663949966, 61.59624136984348, 53.558772057294846, 44.56100307404995, 42.39952325820923, 44.16440695524216, 50.65633200109005, 55.312723740935326, 57.66191728413105, 59.989672377705574, 56.10930539667606, 52.25572317838669, 57.40843668580055, 60.65886586904526, 60.26649512350559, 55.65720185637474, 49.537463039159775, 50.989482924342155, 59.93100732564926, 60.6292350590229, 63.00281569361687, 58.16694438457489, 59.41942177712917, 62.15171456336975, 60.676846504211426, 67.14298233389854, 63.058106526732445, 53.60785402357578, 30.62781762331724, 5.464243590831757, 2.0610191440209746, 3.000951432622969, 10.126225780695677, 4.305550865828991, 2.5738899735733867, 0.19046776316827163, 0.1620618678862229, 0.2642547123832628, 9.792161006480455, 48.17517913877964, 66.43225327134132, 79.83918786048889, 75.0737115740776, 38.56397867202759, 29.79939367622137, 45.56797184050083, 61.857940927147865, 56.43816635012627, 58.968351781368256, 7.661428190767765, 0.20171443233266473, 0.11427565434132703, 0.053086532061570324, 0.0865998023073189, 0.09174091901513748, 0.010044904793176102, 0.04770846244355198, 0.1266638727975078, 0.007354023891821271, 0.026606647297739983, 0.05978765802865382, 0.03685079740535002, 0.017249539923795965, 0.0744529376970604, 0.05528519279323518, 0.052047232165932655, 0.03084293941356009, 0.006112113042036071, 0.05580636970989872, 0.015539576015726198, 0.0323395414307015, 0.06308380674454384, 0.07987622637301683, 0.14067128679016605, 0.07328342428081669, 0.18631903891218826, 0.14353048492921516, 0.08199758871342055, 0.18949891906231642, 0.21517038607271388, 0.10223373683402315, 0.0811417588556651, 0.1426264748442918, 0.10347974341129884, 0.19282187044154853, 0.09610187524231151, 0.1238621020456776, 0.2024516966775991, 0.1801410157349892, 0.162789098394569, 0.08426724700257182, 0.18369122757576406, 0.21072116622235626, 0.12238579962286167, 23.42032067477703, 98.44197124242783, 76.03842660784721, 86.91734924912453, 65.27151435613632, 50.054273307323456, 31.5809565782547, 56.46785415709019, 51.30649231374264, 67.23762765526772, 23.824421390891075, 0.16659932909533381, 0.2569059660891071, 0.28704660187941045, 0.589047004468739, 3.6202972987666726, 13.031168952584267, 9.733899682760239, 4.331635516136885, 13.32059657201171, 56.46394416689873, 68.88008192181587, 66.53995469212532, 65.61409637331963, 67.97427132725716, 62.87784419953823, 61.98557607829571, 58.83454576134682, 60.39133742451668, 55.190784484148026, 59.60637554526329, 62.486845180392265, 65.23330360651016, 63.756710439920425, 61.19108811020851, 52.690773233771324, 53.22428360581398, 59.730480685830116, 61.02827824652195, 64.24695253372192, 53.35145518183708, 59.69238393008709, 61.600778326392174, 58.273616060614586, 56.17219962179661, 56.281626150012016, 59.645224660634995, 57.87964180111885, 55.16604781150818, 48.67766037583351, 46.14149406552315, 47.10708685219288, 46.237560510635376, 49.90189768373966, 55.210722014307976, 59.54237177968025, 59.07323755323887, 57.808942794799805, 57.21550203859806, 51.64186991751194, 45.14816656708717, 49.550044164061546, 59.27371859550476, 64.33009207248688, 59.660059064626694, 55.82638017833233, 42.673119977116585, 54.21745531260967, 63.03881116211414, 54.817830696702, 55.80781817436218, 54.66945245862007, 56.94205351173878, 54.06485550105572, 57.6409500092268, 50.631545931100845, 51.00599303841591, 46.732297763228416, 58.41048091650009, 61.696255803108215, 65.06442546844482, 49.31798681616783, 57.6409500092268, 64.95939910411835, 56.934548914432526, 46.69089138507843, 44.27256055176258, 46.70691132545471, 54.570771753787994, 59.093197882175446, 60.78139029443264, 64.00577947497368, 58.15495602786541, 53.414554595947266, 59.27723340690136, 61.94640778005123, 60.45277252793312, 57.69532889127731, 53.7235464155674, 53.25533173978329, 61.08027845621109, 64.77588415145874, 65.95660999417305, 60.190332010388374, 61.80782161653042, 64.14944216609001, 64.605463296175, 69.81875315308571, 68.11999350786209, 54.74985994398594, 32.59547933936119, 8.819812182337046, 12.86736449226737, 14.933726862072945, 18.175234124064445, 2.9682909976691008, 1.233008662238717, 0.2714656270109117, 0.6000668287742883, 0.39546876680105925, 15.109558627009392, 56.719191670417786, 67.87893444299698, 75.66809847950935, 80.26437744498253, 43.23037527501583, 29.421574249863625, 54.20757584273815, 70.5501227080822, 63.87679919600487, 67.32136756181717, 9.391185622662306, 0.50944650080055, 0.21249288052786142, 0.18301523494301364, 0.224705811124295, 0.17286746384343132, 0.16490692069055513, 0.12715266610030085, 0.14378471503732726, 0.08975284639745951, 0.19680580822750926, 0.16559355572098866, 0.1253154646838084, 0.21166139311389998, 0.21762633085018024, 0.16960775828920305, 0.13160357804736122, 0.18181501887738705, 0.08443448998150416, 0.10947363974992186, 0.10089849442010745, 0.13702389813261107, 0.12399631945299916, 0.12119322767830454], [0.0604535240563564, 0.041216258468921296, 0.08749413478653878, 0.06333580298814923, 0.05487613954755943, 0.03595013069570996, 0.039816126372898, 0.04249377663654741, 0.05395996937295422, 0.023217891539388802, 0.029067017130728345, 0.06493519060313702, 0.016785092775535304, 0.054359159476007335, 0.03620714385760948, 0.023711616413493175, 0.03204441898560617, 0.028123984920966905, 0.009568605546519393, 0.1392562486580573, 0.3850935125956312, 34.164065569639206, 70.07577136158943, 58.88883724808693, 46.1649464070797, 35.97648471593857, 23.818512707948685, 25.50121821463108, 57.11062006652355, 54.920474588871, 30.74934270232916, 2.287947479635477, 0.12502289522672072, 0.04890106036327779, 0.1265754978521727, 0.31365123053546995, 2.6078112283721566, 3.8302854308858514, 1.3914279802702367, 7.242845026776195, 42.39097371697426, 65.06341472268105, 66.82521298527718, 65.33528253436089, 63.90636920928955, 61.55463360249996, 63.33171844482422, 63.22538875043392, 61.52990072965622, 58.10378797352314, 55.68264149129391, 55.63554301857948, 57.76941351592541, 59.3475866317749, 59.712796434760094, 58.02599474787712, 54.44638542830944, 50.26747606694698, 52.79646076261997, 56.49957865476608, 58.779558911919594, 53.44127856194973, 56.274885311722755, 56.38389766216278, 56.98317110538483, 55.3757281601429, 56.799515560269356, 57.258663922548294, 57.28425554931164, 56.21171370148659, 51.086202934384346, 42.20427833497524, 43.75276744365692, 43.73118460178375, 49.30801995098591, 49.977464228868484, 55.147265419363976, 49.546783939003944, 51.09294757246971, 48.66909563541412, 43.44444438815117, 40.01661792397499, 48.18548798561096, 54.284042939543724, 57.88430795073509, 50.53190007805824, 56.70020408928394, 37.8363861143589, 46.28758862614632, 61.216721534729004, 48.99431638419628, 46.93051792681217, 47.02733673155308, 49.2669365555048, 48.73027615249157, 52.64095790684223, 45.34989774227142, 47.082749158144, 39.83088009059429, 45.538854002952576, 55.24497717618942, 58.95167447626591, 54.18055169284344, 52.763835713267326, 55.98334215581417, 52.3347095400095, 42.0292217284441, 41.253128573298454, 43.79409782588482, 50.05083829164505, 54.12621080875397, 58.199508637189865, 56.8757014721632, 52.040783911943436, 51.220875307917595, 53.581950813531876, 56.354187056422234, 58.840264454483986, 56.90143369138241, 52.62071259319782, 42.52441495656967, 48.120800256729126, 53.624740317463875, 55.5074442923069, 59.4768138974905, 58.06819148361683, 55.646889209747314, 61.18264876306057, 58.56023088097572, 63.00793781876564, 64.91789773106575, 47.90111884474754, 20.624050721526146, 1.8304620031267405, 5.601696940138936, 8.220266103744507, 5.906588304787874, 2.0058686658740044, 0.12608342425664887, 0.18651624239282683, 0.17213821469340473, 0.5976476054638624, 13.618585132062435, 44.005275294184685, 43.63423280417919, 39.87332761287689, 14.700947552919388, 23.758282139897346, 41.77147015929222, 45.106748789548874, 50.37984363734722, 57.20364287495613, 20.230764225125313, 0.10543152500758879, 0.07501211628550664, 0.0498712774424348, 0.0720072939293459, 0.03250310335715767, 0.07710813428275287, 0.053144842604524456, 0.011280499038548442, 0.04626659196219407, 0.018753849144559354, 0.021636146630044095, 0.04321422391512897, 0.09309385422966443, 0.024564206796640065, 0.035928311554016545, 0.007818615758878877, 0.030676677924930118, 0.018870820895244833, 0.021442036049847957, 0.03926509656594135, 0.027240309682383668, 0.051008229129365645, 0.04288969015760813, 0.0070503797360288445, 0.12648241769056767, 0.11761516303522512, 0.08227648781030439, 0.021671823524229694, 0.031470404865103774, 0.03139007851132192, 0.04131469322601333, 0.013048467353655724, 0.019922035971831065, 0.020471967400226276, 0.0328558350156527, 0.0631247584533412, 0.028668153572652955, 0.03334534449095372, 0.023677117678744253, 0.0937122710456606, 0.05131892925419379, 0.05634731744066812, 0.1093099219724536, 0.6153852317947894, 42.0197868347168, 79.16802987456322, 65.4757533967495, 55.04320040345192, 45.965468510985374, 36.36248700320721, 29.95452795177698, 51.30695968866348, 57.6956632733345, 37.55643613636494, 3.2990606362000108, 0.15667300001950935, 0.12908888485981151, 0.4851414612494409, 1.109873775858432, 5.903481971472502, 2.5167434150353074, 1.4591555460356176, 7.975385393947363, 43.217129185795784, 67.74548560380936, 67.22961768507957, 67.86186575889587, 65.48378616571426, 64.5971417427063, 65.07749676704407, 64.79266405105591, 63.708156645298004, 59.45757173001766, 57.18533545732498, 57.50729978084564, 60.74126064777374, 62.1294629573822, 60.80766208469868, 60.610559061169624, 57.76028260588646, 52.74699501693249, 55.78581355512142, 59.0045790374279, 61.75545662641525, 54.658144265413284, 55.837300792336464, 59.93473492562771, 57.90948159992695, 58.107762560248375, 58.956842198967934, 58.6589115858078, 59.06377986073494, 58.62111881375313, 53.27102489769459, 44.703510627150536, 44.80425842106342, 45.78633472323418, 49.996022433042526, 52.86198824644089, 58.371852189302444, 51.855927631258965, 53.03259149193764, 51.12109646201134, 45.62108539044857, 41.43745668232441, 50.91321721673012, 56.78563870489597, 61.32067635655403, 53.66762101650238, 56.43947347998619, 38.387079164385796, 49.53217752277851, 62.55241446197033, 50.88883012533188, 49.95864383876324, 48.20559270679951, 52.341609969735146, 50.8285653591156, 55.299945026636124, 48.6005625128746, 49.07232239842415, 40.94200126826763, 48.65052983164787, 56.75606109201908, 62.14205548167229, 55.323921740055084, 55.01563288271427, 58.05387385189533, 54.88699458539486, 44.847606495022774, 42.92549103498459, 46.30945645272732, 51.6864263266325, 55.96326403319836, 59.92697574198246, 59.4365930557251, 52.97777183353901, 51.146767884492874, 54.24691133201122, 57.30319373309612, 61.40370950102806, 59.94874857366085, 54.712846130132675, 44.75370213389397, 51.426843255758286, 55.030102506279945, 59.89766791462898, 61.06950223445892, 59.75485637784004, 58.023331090807915, 63.56819115579128, 61.52059502899647, 65.67569106817245, 64.65720891952515, 52.13795989751816, 23.560941629111767, 3.299246826209128, 2.1204671915620565, 6.2446528393775225, 3.415308748371899, 5.289115263149142, 0.644447022350505, 0.16318438109010458, 0.30493654659949243, 0.6232601311057806, 17.961592487990856, 53.266624733805656, 53.962979167699814, 49.41973775625229, 23.29631432890892, 25.44686783105135, 47.84664876759052, 52.26277939975262, 56.15644946694374, 65.68541094660759, 26.489583179354668, 0.032430317223770544, 0.041590527252992615, 0.039319703791989014, 0.06586360250366852, 0.02073257626761915, 0.040967475724755786, 0.024814186253934167, 0.02498780613677809, 0.021284496651787776, 0.02096181455272017, 0.08456938274321146, 0.017915350290422793, 0.019629993439593818, 0.07020537421340123, 0.010106689514941536, 0.08467070816550404, 0.05601654964266345, 0.017793734550650697, 0.03551994850568008, 0.011202034547750372, 0.009368933497171383, 0.021176998416194692, 0.08580709953093901, 0.13264169421745464, 0.17040966369677335, 0.2581923158140853, 0.21383459446951747, 0.1881322986446321, 0.1524838584009558, 0.11224989546462893, 0.11079733434598893, 0.08664142194902524, 0.09409107806277461, 0.169312531943433, 0.1304813617025502, 0.11796043239883147, 0.14107391674770042, 0.13277257938170806, 0.13998698210343719, 0.1929442654363811, 0.11957875962252729, 0.1437141961650923, 0.36299942003097385, 0.8453431923408061, 51.429886892437935, 87.7556374669075, 76.22094601392746, 62.78864398598671, 51.70691482722759, 32.272891849279404, 35.26070952415466, 69.96325939893723, 68.0215559899807, 46.577300280332565, 4.705493180081248, 0.22135617211461067, 0.1767708786064759, 0.4744336358271539, 1.649609045125544, 9.106456451117992, 13.913047481328249, 6.327764829620719, 10.339089408516884, 45.62133617699146, 67.60331243276596, 68.4390015900135, 68.78305792808533, 67.65061229467392, 66.73539340496063, 67.31224805116653, 66.63751065731049, 68.26456815004349, 61.86677165329456, 60.44921211898327, 59.297740906476974, 62.84844517707825, 64.83212113380432, 62.87003181874752, 64.15206402540207, 62.362075075507164, 55.9664748609066, 59.37739983201027, 62.095910757780075, 64.43999737501144, 54.89081718027592, 57.360582053661346, 61.57766416668892, 61.939438953995705, 60.97795754671097, 61.16874910891056, 61.6107489913702, 61.80482737720013, 62.06803925335407, 57.211664244532585, 47.874512672424316, 48.045218512415886, 47.48247630894184, 54.32615227997303, 55.95134027302265, 59.844383373856544, 56.65407836437225, 55.54559424519539, 54.29029740393162, 48.4999743103981, 44.4644920527935, 53.34482453763485, 59.769394397735596, 63.368116691708565, 57.93202579021454, 56.93516828119755, 40.9701881557703, 53.55568282306194, 65.05610391497612, 53.1908567994833, 51.207849606871605, 51.67775519192219, 54.69253621995449, 52.6412732899189, 58.101409301161766, 51.15183301270008, 51.855388060212135, 42.828786224126816, 51.19928486645222, 60.46308517456055, 63.766673505306244, 57.129957228899, 54.441476091742516, 60.70189096033573, 57.90913201868534, 46.60547196865082, 45.528940334916115, 48.46179775893688, 54.725237265229225, 58.36504675447941, 62.310109063982964, 61.45877234637737, 54.24584738910198, 52.578781843185425, 54.7706638276577, 58.60423631966114, 64.41690221428871, 63.288624957203865, 58.091632425785065, 47.54720963537693, 52.846808061003685, 58.622984513640404, 61.818974018096924, 66.15777119994164, 63.01403269171715, 61.15581080317497, 66.11331358551979, 66.04607239365578, 67.07658469676971, 69.12939414381981, 53.774908259510994, 25.400574915111065, 4.360299753025174, 13.175203073769808, 20.849749110639095, 16.10560677945614, 5.735023710876703, 0.30958856572397053, 0.4542329104151577, 0.4370507667772472, 1.2696224288083613, 24.603717774152756, 58.059159368276596, 49.778898283839226, 54.307890459895134, 23.775162734091282, 34.63770255446434, 56.932383030653, 61.408755630254745, 65.46518996357918, 73.4971609711647, 33.94318722188473, 0.16453431802801788, 0.13045722706010565, 0.19227334909373894, 0.1075423340080306, 0.12334496612311341, 0.15941606689011678, 0.11324972423608415, 0.09882925311103463, 0.15369171858765185, 0.23700371762970462, 0.16445250366814435, 0.1303193360217847, 0.1378518677665852, 0.1429507340071723, 0.10584219242446125, 0.1626280671916902, 0.13867857574950904, 0.11320302088279277, 0.09654870009399019, 0.13511687546269968, 0.18796809104969725, 0.1668122215778567, 0.24557981290854514], [0.036553901227307506, 0.04589425276208203, 0.016376972780562937, 0.03058565536775859, 0.11015001087798737, 0.05778913226095028, 0.04220614988298621, 0.01722594148304779, 0.019204885684303008, 0.027312238635204267, 0.05828578119690064, 0.026456533087184653, 0.02919695049058646, 0.011823085987998638, 0.041182416534866206, 0.054053079220466316, 0.047040807839948684, 0.07539432233897969, 0.03482576212263666, 0.03575808514142409, 4.846738250926137, 65.59813722968102, 68.86961728334427, 56.39544904232025, 52.045997232198715, 30.381856821477413, 16.131181307137012, 26.571559980511665, 29.956108666956425, 33.00878316164017, 19.264008700847626, 0.14123328553978354, 0.11333054411807097, 0.1234669603582006, 0.2500712312757969, 0.7694021891802549, 3.775116903707385, 2.8386923018842936, 2.4629041040316224, 31.612242199480534, 65.28263255953789, 64.40210580825806, 64.62874084711075, 67.1029780805111, 66.8587651848793, 65.63324734568596, 63.084131330251694, 57.501942068338394, 63.25626589357853, 60.60178533196449, 58.08615691959858, 55.40276750922203, 57.89733365178108, 58.98127868771553, 56.463119611144066, 59.80817511677742, 56.598521545529366, 55.06088465452194, 52.72959195077419, 53.85513335466385, 59.714453145861626, 54.55415904521942, 53.39768350124359, 54.01472099125385, 58.1301661580801, 57.14701451361179, 57.78882287442684, 52.60682053864002, 55.9044735878706, 56.714278534054756, 55.26767335832119, 46.05054594576359, 41.46704949438572, 43.17805588245392, 47.90578119456768, 51.790616735816, 53.62295061349869, 50.838380232453346, 52.348134219646454, 44.16978366672993, 41.69689916074276, 42.640559524297714, 51.10315762460232, 57.01124019920826, 55.943041518330574, 49.97283987700939, 58.74100238084793, 37.9357735812664, 49.21176731586456, 57.77157559990883, 50.93322314321995, 44.95964728295803, 41.61228530108929, 47.29079559445381, 47.90272615849972, 50.76970651745796, 45.8257158100605, 43.52878466248512, 40.64894959330559, 43.21773335337639, 52.408683970570564, 56.70317552983761, 54.48284067213535, 51.27736307680607, 58.84646952152252, 51.00246302783489, 42.964830324053764, 40.46855807304382, 43.32632772624493, 50.898998379707336, 57.167750000953674, 56.17136366665363, 53.70267793536186, 50.19569791853428, 54.354567155241966, 53.09137053787708, 57.16711163520813, 56.44551135599613, 58.0457878857851, 55.50780147314072, 46.019345819950104, 43.6591062694788, 48.2664692401886, 52.792296186089516, 51.70941889286041, 52.019721642136574, 53.85015182197094, 52.28618994355202, 60.738973170518875, 57.4901133030653, 62.145216912031174, 59.75729204714298, 46.717075780034065, 17.596948854625225, 2.1845916006714106, 7.142532784491777, 6.399322114884853, 8.31256790086627, 1.1909528751857579, 0.06763556913938373, 0.09528363516437821, 0.03873907342494931, 6.103605832904577, 27.619199864566326, 24.683108814060688, 16.760336346924305, 20.967048816382885, 26.528985165059566, 22.836464904248714, 42.98173561692238, 47.16386720538139, 55.29534727334976, 35.861882865428925, 1.4790030685253441, 0.050833393979701214, 0.022851213070680387, 0.04570059303659946, 0.04590011572872754, 0.014354162085510325, 0.011279167811153457, 0.03003986697876826, 0.04046602509333752, 0.08222432967158966, 0.04223199517582543, 0.010820167099154787, 0.05365672412153799, 0.049431621737312526, 0.022464273970399518, 0.06622525848797522, 0.018477430676284712, 0.013243488920124946, 0.028518282415461726, 0.04928526650473941, 0.06161086253996473, 0.04325386202253867, 0.09411693448782898, 0.04025634982099291, 0.036936697288183495, 0.056822247424861416, 0.06888823278131895, 0.048450168542331085, 0.032776529114926234, 0.02921358944149688, 0.027017960383091122, 0.034278487582923844, 0.026953618034895044, 0.1371826435206458, 0.050483912928029895, 0.031089859367057215, 0.038342900152201764, 0.07007494175923057, 0.022853641748952214, 0.02045138578978367, 0.0254404679799336, 0.0569655116123613, 0.040623327004141174, 6.415136391296983, 75.00710874795914, 77.8442645072937, 63.16948615014553, 59.985728189349174, 36.558377891778946, 18.813166692852974, 22.49003179371357, 30.177895165979862, 41.33156016469002, 22.383251823484898, 0.09396342866239138, 0.04393806651933119, 0.36829321878030896, 0.5995780206285417, 3.886846345849335, 3.9522531861439347, 0.9527311299461871, 3.6201448319479823, 33.820328414440155, 63.49355936050415, 65.34147620201111, 66.72076418995857, 68.39797899127007, 68.41951623558998, 68.62896859645844, 64.7949667274952, 60.36144822835922, 64.47547987103462, 62.91168138384819, 60.29273271560669, 56.98550038039684, 60.20583137869835, 59.70245718955994, 58.16526107490063, 60.96176281571388, 58.571577072143555, 56.342046707868576, 54.734960943460464, 57.57036119699478, 61.641519740223885, 56.027370393276215, 53.22638489305973, 55.97046084702015, 60.18245883285999, 58.99487055838108, 57.483000084757805, 55.18614873290062, 57.68915802240372, 58.8131795078516, 57.30484664440155, 48.472106605768204, 43.81682440638542, 45.810250639915466, 49.55608583986759, 53.13369266688824, 55.284407660365105, 51.90490320324898, 54.04680646955967, 45.61149850487709, 44.690047949552536, 44.06624682247639, 54.617855027318, 58.913152143359184, 58.88580121099949, 54.16509412229061, 56.90499410033226, 39.041981622576714, 50.46298697590828, 60.233421698212624, 53.93196143209934, 46.332262828946114, 44.095083475112915, 50.0242093205452, 50.49257978796959, 52.718583941459656, 48.198034912347794, 46.43008477985859, 42.96772196888924, 45.61132751405239, 53.565246909856796, 60.055032670497894, 55.06527341902256, 52.48687617480755, 59.704178497195244, 53.70017006993294, 44.70135234296322, 42.04359255731106, 45.0781325250864, 54.20589253306389, 59.24989007413387, 57.12683379650116, 55.383399948477745, 51.984375938773155, 54.757968708872795, 52.87744581699371, 59.071751832962036, 59.803505167365074, 61.02038227021694, 57.60670244693756, 48.56199078261852, 46.02050855755806, 50.300070717930794, 53.58546942472458, 52.45272360742092, 54.45229411125183, 55.41447468101978, 55.14213189482689, 62.27392740547657, 60.30010811984539, 64.7012485563755, 61.38458892703056, 48.54972884058952, 22.13403269648552, 3.3529749931767583, 2.3819214245304465, 3.2679505180567503, 4.209368051961064, 3.33356112241745, 0.3360288531985134, 0.03322490134451073, 0.03885891172103584, 6.153492880985141, 31.558347791433334, 21.550617702305317, 24.27012987434864, 20.987715907394886, 31.07288584113121, 30.86870189756155, 48.94870363175869, 53.72284345328808, 61.32271684706211, 46.507874205708504, 2.1538142021745443, 0.045794975667377, 0.02204354117566254, 0.06393548057531007, 0.08241964067565277, 0.10629777461872436, 0.047514138495898806, 0.03142003159155138, 0.03138544379908126, 0.036855840298812836, 0.03484325083263684, 0.02842947702447418, 0.06904727502842434, 0.01663358518271707, 0.002807883033710823, 0.03674535677419044, 0.019727569160750136, 0.03545197891071439, 0.030517103186866734, 0.07283601313247345, 0.022937357862247154, 0.029750750363746192, 0.024430950470559765, 0.08675521545228548, 0.20085088413907215, 0.11218384432140738, 0.15223121648887172, 0.29553309024777263, 0.17249796335818246, 0.15822716115508229, 0.12647009803913534, 0.08693409530678764, 0.15727296704426408, 0.3237106860615313, 0.09821427243878134, 0.15770170575706288, 0.18375984654994681, 0.16902135772397742, 0.12569381156936288, 0.10147146211238578, 0.18940833251690492, 0.14738266181666404, 0.20709282107418403, 7.529959045350552, 86.32952079176903, 85.00028371810913, 72.04175546765327, 67.6054859161377, 43.30170124769211, 23.054774589836597, 37.35610328614712, 42.504283636808395, 49.29824687540531, 29.059527777135372, 0.42132192640565336, 0.2865981962531805, 0.6479831482283771, 0.6355325819458812, 5.3385857585817575, 11.786352898925543, 6.5166493691504, 5.168122630566359, 34.687829464673996, 65.78762546181679, 64.94365274906158, 66.43321081995964, 68.30506637692451, 69.0002466738224, 69.66277912259102, 69.40115556120872, 62.248772755265236, 67.59214103221893, 63.817628771066666, 63.34381699562073, 60.10401964187622, 62.07795672118664, 60.38083478808403, 60.07897898554802, 62.64641381800175, 60.78633762896061, 59.88549716770649, 57.685931995511055, 60.407361164689064, 62.47627034783363, 55.65531335771084, 54.662099853158, 55.711383149027824, 62.17326320707798, 60.25971628725529, 61.858085319399834, 56.94341763854027, 59.0042332559824, 60.84467589855194, 61.908672004938126, 49.83079969882965, 46.37191370129585, 47.81722314655781, 53.302680999040604, 55.52868515253067, 59.801996648311615, 55.781717374920845, 56.273882165551186, 49.21970508992672, 47.33862742781639, 47.13067218661308, 56.56931631267071, 61.553717851638794, 62.29818530380726, 56.31344564259052, 57.64294870197773, 43.716103211045265, 54.11364108324051, 62.64363616704941, 57.076965272426605, 48.122266978025436, 45.772587060928345, 52.54067748785019, 53.79399463534355, 55.14931730926037, 51.04324243962765, 49.111954271793365, 46.25482678413391, 47.686810344457626, 56.24488212168217, 61.684275045990944, 57.15592883527279, 53.12349781394005, 63.06603290140629, 55.04132330417633, 47.39723548293114, 43.678671419620514, 47.47208386659622, 55.27742363512516, 62.38409109413624, 58.985097482800484, 56.87016136944294, 52.048337906599045, 56.113705560564995, 56.211660504341125, 62.40259230136871, 58.853366151452065, 64.7332352399826, 61.19700439274311, 51.76204986870289, 48.3177474886179, 52.63746589422226, 58.88642057776451, 56.59079276025295, 56.445385962724686, 57.83019885420799, 57.86830320954323, 65.3842543065548, 63.193869441747665, 68.23237627744675, 62.82736010849476, 51.226510405540466, 24.750403203070164, 5.832389686256647, 15.134964063763618, 16.373853385448456, 19.13824874907732, 4.102134481072426, 0.2262137216166593, 0.2930634008953348, 0.13636304531246424, 8.927895482629538, 43.04342530667782, 38.61942529678345, 28.3781236410141, 28.553603924810886, 38.254059702157974, 34.61801201105118, 58.33379723131657, 61.080521643161774, 69.74813014268875, 54.29342843592167, 3.236049567349255, 0.2370927159790881, 0.11852538489620201, 0.12266331090359017, 0.18261457909829915, 0.22849888337077573, 0.11437889450462535, 0.1069669469143264, 0.12204705373733304, 0.14664602087577805, 0.08931624834076501, 0.13948618085123599, 0.19515758729539812, 0.13804095215164125, 0.21979899785947055, 0.1333346078172326, 0.05383095071010757, 0.15463001589523628, 0.07805967892636545, 0.19914769975002855, 0.14237027062335983, 0.14764265099074692, 0.18773044052068144], [0.029700328850594815, 0.021612704040308017, 0.03284971600805875, 0.026524656677793246, 0.009472492783970665, 0.016790291520010214, 0.07772887402097695, 0.01812878454074962, 0.07844712454243563, 0.07050908330711536, 0.005986749456496909, 0.025089259579544887, 0.04644882632419467, 0.07165724513470195, 0.04735845075629186, 0.032024559113779105, 0.01493213370849844, 0.11873254057718441, 0.09049429645529017, 0.03328377220896073, 14.488530401140451, 70.02474769949913, 60.25947690010071, 49.88114319741726, 34.90175038576126, 22.88329739123583, 28.870113641023636, 43.704046458005905, 39.138169661164284, 43.29669311642647, 6.160450307652354, 0.1020704346592538, 0.0928522035246715, 0.08247634817962535, 0.012645184306165902, 2.4048185208812356, 3.1005402887240052, 0.7069984346162528, 18.46034612506628, 57.99598015844822, 63.98319348692894, 66.29242077469826, 64.8165875673294, 62.23184086382389, 63.76101940870285, 64.65958759188652, 67.69241005182266, 67.13314846158028, 57.84390091896057, 57.79560171067715, 61.53892524540424, 57.61912398040295, 61.53310775756836, 56.37798137962818, 55.34528039395809, 58.50686654448509, 58.84546257555485, 55.21866738796234, 53.11186283826828, 56.05955846607685, 57.12701618671417, 54.03636083006859, 51.27941116690636, 54.274250864982605, 52.886382937431335, 53.374250158667564, 52.501794174313545, 50.55224038660526, 52.91220635175705, 55.71967050433159, 56.931178495287895, 47.46895283460617, 43.79406362771988, 44.16861332952976, 49.89231839776039, 52.12236173450947, 52.86593623459339, 50.24343095719814, 49.9814236164093, 42.35012970864773, 41.26314863562584, 43.31502713263035, 54.88304279744625, 54.41006317734718, 52.4244075268507, 54.25530128180981, 56.47282809019089, 36.69152654707432, 46.23503364622593, 58.77209231257439, 48.05366925895214, 47.11980476975441, 40.839539766311646, 41.9425293803215, 43.41704025864601, 47.07877077162266, 45.74927531182766, 42.64784753322601, 40.76975651085377, 41.32597826421261, 49.04400631785393, 54.9333330988884, 56.57375447452068, 52.147166803479195, 55.71206331253052, 54.061637073755264, 42.56339706480503, 39.922139793634415, 42.04296559095383, 52.96338200569153, 58.015750497579575, 55.7910230755806, 49.40789379179478, 55.07095791399479, 55.56124560534954, 56.23328894376755, 55.318134650588036, 56.67791448533535, 57.79867574572563, 56.528392508625984, 45.081221759319305, 44.025205224752426, 45.66128343343735, 47.71794207394123, 49.06779304146767, 50.48338048160076, 50.76551154255867, 54.82731878757477, 52.80896209180355, 60.52797049283981, 61.17815360426903, 58.990603387355804, 54.85484831035137, 48.874018639326096, 17.644864283502102, 4.3477879744023085, 1.3001673272810876, 4.8434476274997, 3.433356354944408, 0.2908801211742684, 0.1351139514008537, 0.019920419945265166, 0.012013414398097666, 20.66343180835247, 44.37694855034351, 33.57705406844616, 34.46528300642967, 13.87916849926114, 28.97082343697548, 39.91570673882961, 47.080750465393066, 51.32160410284996, 49.666975289583206, 8.748165126889944, 0.23347735841525719, 0.14206931489752606, 0.055793894207454287, 0.01634514392208075, 0.021388484528870322, 0.04486815938435029, 0.030735060827282723, 0.02251625213830266, 0.051303681830177084, 0.010627890551404562, 0.06269138131756335, 0.03921272320440039, 0.06754664500476792, 0.06469748070230708, 0.11032303518732078, 0.028645744423556607, 0.060356811081874184, 0.008554261294193566, 0.017390909779351205, 0.02471385716489749, 0.04152908855758142, 0.007992680002644192, 0.0261299435805995, 0.0039000384549581213, 0.03459342537098564, 0.012373145436868072, 0.016688626565155573, 0.06176387112645898, 0.03918311522284057, 0.038176696180016734, 0.1334791336557828, 0.018642660579644144, 0.033088557684095576, 0.04782388867170084, 0.01388079896059935, 0.06084022010327317, 0.014989011906436644, 0.05634408167679794, 0.028909067696076818, 0.08773803419899195, 0.0696014663844835, 0.05339210394595284, 18.243003487586975, 81.35252505540848, 69.33900609612465, 58.84032905101776, 42.84459337592125, 32.68043898046017, 28.675060607492924, 31.919526010751724, 34.175084978342056, 45.309870690107346, 7.59348688647151, 0.1693218236323446, 0.08009150857105851, 0.29704261862207204, 2.0960138412192464, 3.3138807909563184, 2.6323571987450123, 0.6793484464287758, 18.327201269567013, 57.93138362467289, 66.41532897949219, 69.17985543608665, 66.6384682059288, 65.06608977913857, 65.21488219499588, 66.18730321526527, 67.18202903866768, 67.22318843007088, 60.80559879541397, 59.42976102232933, 63.07930178940296, 60.98212592303753, 60.716489776968956, 57.6823677867651, 57.16947890818119, 58.88971880078316, 60.589242205023766, 57.652926966547966, 57.215281650424004, 57.08131983876228, 58.64816576242447, 54.93527479469776, 52.534928396344185, 53.14743272960186, 53.07179778814316, 54.07661586999893, 54.30347889661789, 50.92434301972389, 52.34180375933647, 57.89437361061573, 58.42882253229618, 49.72808741033077, 44.97890084981918, 47.076555490493774, 51.7894122004509, 54.58583414554596, 53.54488380253315, 54.41828973591328, 50.28299443423748, 45.064327865839005, 42.81620889902115, 45.78429043292999, 57.648226618766785, 56.56550891697407, 56.51584938168526, 55.17346881330013, 56.486169174313545, 38.60467068850994, 47.34337717294693, 60.67005626857281, 51.73847213387489, 47.82016038894653, 42.194934636354446, 45.67863330245018, 45.647433176636696, 49.29983139038086, 47.49077506363392, 44.649606719613075, 43.31731840968132, 43.35864879190922, 51.59185700118542, 58.30002844333649, 57.45341867208481, 52.265625447034836, 57.28665702044964, 55.6365841627121, 44.111547991633415, 42.17178247869015, 43.86003568768501, 55.44511243700981, 59.67474527657032, 56.929616779088974, 50.18636181950569, 55.044663324952126, 56.49014376103878, 58.23228567838669, 56.70635975897312, 59.436703249812126, 60.43859928846359, 58.26622925698757, 46.78025119006634, 45.179157704114914, 47.70043261349201, 49.64168764650822, 53.65615703165531, 51.42956770956516, 52.432026118040085, 56.66042402386665, 55.92468470335007, 61.54123932123184, 62.71341182291508, 58.57381895184517, 55.88887922465801, 50.21127328276634, 19.592808857560158, 3.2193770119920373, 1.0504484083503485, 4.584937999024987, 6.360112968832254, 2.0326997386291623, 0.41249232832342386, 0.13590656511951238, 0.10318988279323094, 22.4606878682971, 48.85396331548691, 32.9670500010252, 32.024035602808, 15.351364351809025, 32.13314674794674, 46.542767733335495, 52.03956417739391, 58.240884616971016, 59.40522953867912, 12.349340189248323, 0.2748569450341165, 0.14876316039590165, 0.10018077082349919, 0.0124182884246693, 0.059080569408251904, 0.03369529309566133, 0.0514437065430684, 0.0670962430012878, 0.02926532270066673, 0.0425795169576304, 0.021997607800585683, 0.02805025811539963, 0.03643343210569583, 0.03668948047561571, 0.10539731199969538, 0.03659160604001954, 0.0458514122874476, 0.015478742170671467, 0.06203794255270623, 0.021193644788581878, 0.05672358260198962, 0.03375557775143534, 0.08991656417492777, 0.2631720376666635, 0.18757503479719162, 0.09147456221398897, 0.23120698024285957, 0.15098043048055843, 0.13418163580354303, 0.09714984713355079, 0.2883643296081573, 0.1067101712396834, 0.1452766396687366, 0.10504840611247346, 0.3020691848360002, 0.159167610690929, 0.10421951621538028, 0.11739919063984416, 0.08112422190606594, 0.29868870216887444, 0.26879561715759337, 0.15630912501364946, 22.161068245768547, 94.09520208835602, 77.08983778953552, 68.95533308386803, 50.50061255693436, 34.79204647243023, 37.70975410938263, 61.51248246431351, 50.18606923520565, 61.70911431312561, 9.765453189611435, 0.3146216628374532, 0.45528557267971337, 0.3502064268104732, 1.4773990795947611, 5.7805367186665535, 9.121003970503807, 4.53798676840961, 20.258358344435692, 61.11709848046303, 65.50052806735039, 71.27668172121048, 68.71758744120598, 65.25437727570534, 65.79199522733688, 65.77868834137917, 65.16531005501747, 68.63276839256287, 64.32095736265182, 62.835408076643944, 64.0550172328949, 60.93758471310139, 62.299211248755455, 59.28463540971279, 57.48599052429199, 61.180004104971886, 62.169520407915115, 60.610053688287735, 59.229963943362236, 60.2718186378479, 62.35017791390419, 58.13613183796406, 52.24196791648865, 55.37777245044708, 54.007664769887924, 55.44488064944744, 54.23966132104397, 52.10743233561516, 53.3935759216547, 59.63983274996281, 62.094546630978584, 51.757733300328255, 48.23795557022095, 49.33462232351303, 56.02554649114609, 58.49201314151287, 55.995710492134094, 57.593874335289, 53.70787225663662, 48.66295516490936, 45.58054156601429, 49.36389595270157, 58.45200888812542, 60.03036439418793, 59.5719987899065, 58.969765305519104, 57.24471867084503, 40.96595898270607, 50.44760540127754, 62.429270669817924, 53.00329886376858, 51.79889269173145, 45.01320160925388, 46.78229168057442, 48.212185353040695, 53.2856123149395, 50.8296786993742, 48.4185066819191, 45.73014333844185, 46.15067057311535, 53.5083943605423, 60.78044034540653, 60.12742638587952, 52.95363932847977, 59.664029851555824, 58.79666179418564, 46.81835554540157, 43.344901129603386, 47.4645184725523, 57.77198597788811, 62.41309113800526, 58.59287492930889, 50.03816977143288, 57.31596104800701, 59.425683841109276, 59.6887893229723, 59.65617947280407, 60.971163511276245, 63.48179139196873, 61.227330565452576, 50.052677392959595, 49.10292215645313, 51.08751006424427, 51.840888038277626, 56.70591898262501, 54.59268517792225, 55.53881920874119, 60.56232824921608, 59.02461916208267, 64.2760057747364, 65.92477530241013, 60.701963156461716, 53.915842697024345, 53.951575979590416, 22.178070433437824, 7.988741677254438, 4.495488423854113, 15.349338110536337, 11.173098105937243, 1.1696709296666086, 0.3565978619735688, 0.21724865189753473, 0.14349095814395696, 31.12775679677725, 64.48491856455803, 47.3109383136034, 47.33249455690384, 22.281616777181625, 41.5259425342083, 52.88316830992699, 61.19115650653839, 64.91832330822945, 66.67797088623047, 14.763501696288586, 0.4283106420189142, 0.2667559578549117, 0.24122242641169578, 0.15386361483251676, 0.20179430226562545, 0.1444406993687153, 0.11399413546314463, 0.1421916059916839, 0.12318946392042562, 0.12026769531075843, 0.1652120176004246, 0.11874751711729914, 0.1902794506167993, 0.17478266498073936, 0.23014104837784544, 0.1043839093472343, 0.33070480450987816, 0.13206991396145895, 0.1362482795957476, 0.14488159446045756, 0.1693757629254833, 0.12265278724953532], [0.01962648308108328, 0.02173833108827239, 0.014165749344101641, 0.013781004217889858, 0.026990033366018906, 0.03510100614221301, 0.06890834498335607, 0.07044349971693009, 0.04386267173686065, 0.007691244200032088, 0.028216091013746336, 0.04451638880709652, 0.050474480231059715, 0.032491611200384796, 0.05187749928154517, 0.02585006113804411, 0.0498546125163557, 0.034590078284963965, 0.06614413432544097, 0.2490638697054237, 31.908214017748833, 68.63378673791885, 59.87339101731777, 49.682581052184105, 34.040686190128326, 19.380048774182796, 19.253067187964916, 37.355423122644424, 41.717535853385925, 25.668061561882496, 0.3365396289154887, 0.025617639039410278, 0.12844386947108433, 0.22194938559550792, 1.37295491527766, 3.248096345923841, 0.4189693776424974, 3.901219549588859, 42.49800257384777, 67.2732925415039, 66.94170713424683, 63.73160898685455, 61.19443953037262, 62.18730345368385, 59.91326987743378, 63.1184396892786, 61.50813929736614, 66.801737844944, 66.57223775982857, 55.87990790605545, 58.86914670467377, 59.56800140440464, 58.004457503557205, 55.76190523803234, 55.208096355199814, 55.82873985171318, 58.365677520632744, 57.02762492001057, 57.71820366382599, 58.47389951348305, 54.207245260477066, 53.067200034856796, 56.12520754337311, 53.31400819122791, 56.98504440486431, 53.940058797597885, 55.28832145035267, 52.90688283741474, 52.14008778333664, 57.63662964105606, 55.66209599375725, 51.139848455786705, 44.04431439936161, 44.03457932174206, 49.75347384810448, 48.80743861198425, 51.415481865406036, 48.82168784737587, 44.9744588881731, 40.762859880924225, 41.07416197657585, 46.55721455812454, 57.380071207880974, 51.32994465529919, 55.9580697119236, 50.071106404066086, 55.33288165926933, 35.208557322621346, 45.2752735465765, 60.26362627744675, 49.971692338585854, 49.59311865270138, 41.64627827703953, 41.20944991707802, 39.96102690696716, 42.402692288160324, 41.42207510769367, 40.89501678943634, 39.96751695871353, 40.383552834391594, 49.03358727693558, 56.30369916558266, 55.10086610913277, 51.257740929722786, 55.13868547976017, 52.970385029911995, 41.674050986766815, 40.10130777955055, 43.34511011838913, 54.70740482211113, 55.92384494841099, 54.705041348934174, 50.43956883251667, 58.63886386156082, 54.64865617454052, 56.21079035103321, 56.13288693130016, 57.34127528965473, 56.73754468560219, 55.1135878264904, 44.1716493666172, 43.171630427241325, 42.20348037779331, 45.3772334754467, 46.83679595589638, 50.17505742609501, 53.55500265955925, 54.334827214479446, 58.46865959465504, 60.35009443759918, 60.22163853049278, 60.99317952990532, 60.32418742775917, 66.33032754063606, 56.605414375662804, 25.381252951920033, 0.4458166885888204, 1.758742870297283, 3.6517695849761367, 1.3860019901767373, 0.1685567881213501, 0.07867497130064294, 0.09145363364950754, 3.0516979470849037, 17.18076478689909, 37.052263990044594, 33.35499778389931, 27.623195350170135, 16.999387219548225, 29.41208615899086, 48.474207893013954, 51.604289934039116, 59.26155164837837, 21.877783946692944, 1.031370225828141, 0.04600866224791389, 0.023397671247948892, 0.03262248523242306, 0.06540768634295091, 0.07592480949824676, 0.02567177129094489, 0.03870192522299476, 0.05980451220239047, 0.03529111469106283, 0.034021582032437436, 0.18402854853775352, 0.0638625051942654, 0.051525060771382414, 0.01801112444809405, 0.056178720042225905, 0.039696499588899314, 0.0100946797101642, 0.11298789453576319, 0.06600213921046816, 0.04025407513836399, 0.015199985937215388, 0.03740769017895218, 0.0359876573929796, 0.05237350254901685, 0.04114496034162585, 0.020446728813112713, 0.004049919352837605, 0.04644351254682988, 0.020523834245977923, 0.035380584304220974, 0.014101685301284306, 0.08481795768602751, 0.01656201060541207, 0.07070415682392195, 0.011747323842428159, 0.08822880903608166, 0.03880584074067883, 0.020200884973746724, 0.08589759701862931, 0.017147117978311144, 0.20382351212901995, 38.693118542432785, 76.81439056992531, 65.95761314034462, 57.380390390753746, 38.73044773936272, 23.72429296374321, 21.423446126282215, 38.2014287263155, 44.05714251101017, 30.34467961639166, 0.42782913660630584, 0.29650076176039875, 0.3482551424531266, 0.9285600332077593, 3.2760566705837846, 3.5716781951487064, 1.8527267896570265, 5.007354207336903, 45.188607797026634, 67.02251359820366, 68.88574361801147, 65.44845566153526, 64.27475944161415, 64.72727715969086, 63.70486222207546, 65.87597072124481, 62.34849080443382, 64.35067936778069, 66.4763993024826, 57.53492049872875, 59.34224791824818, 60.65733075141907, 60.13396583497524, 55.97370207309723, 57.56216503679752, 57.962009981274605, 58.85976500809193, 59.54865284264088, 58.873596265912056, 59.77714978158474, 57.66356639564037, 53.61146003007889, 57.550134882330894, 54.90175299346447, 58.629219979047775, 55.47575779259205, 55.88001050055027, 53.47190111875534, 52.9486919939518, 58.492659106850624, 57.5147245824337, 53.27417112886906, 45.840717405080795, 46.02291762828827, 52.036288753151894, 52.45691858232021, 53.11909765005112, 51.833778619766235, 47.58987374603748, 43.491090685129166, 43.29825863242149, 49.74253423511982, 60.389046147465706, 53.95561896264553, 58.740800991654396, 52.52849534153938, 56.93997122347355, 36.13850422203541, 48.288572654128075, 63.07262174785137, 50.99808566272259, 50.71569241583347, 43.374740928411484, 43.97502891719341, 41.38049013912678, 45.672986805438995, 44.05394308269024, 43.440933376550674, 40.77052786946297, 43.71166504919529, 51.82986102998257, 58.7745925784111, 56.31227150559425, 52.6074855029583, 58.42393979430199, 54.683158323168755, 43.314920738339424, 42.413833290338516, 45.110028013587, 56.84282563626766, 58.00575703382492, 55.25760389864445, 50.08109226822853, 59.12812940776348, 57.35443398356438, 58.24962414801121, 57.30596378445625, 59.88331988453865, 60.04445783793926, 58.81136320531368, 47.43664316833019, 46.15957349538803, 44.91040572524071, 48.052772507071495, 48.438269421458244, 54.45978730916977, 54.52697530388832, 55.48189826309681, 59.225331991910934, 62.470088079571724, 62.01564386487007, 61.16716839373112, 62.45973363518715, 66.63171976804733, 59.67616260051727, 28.84006105363369, 0.8823210862465203, 2.0237407693639398, 5.707217752933502, 3.984114001505077, 0.5755446071270853, 0.15406577585963532, 0.07428057389915921, 3.6554620368406177, 21.99459347873926, 38.36022600531578, 31.642422080039978, 29.8627457767725, 25.567382164299488, 35.518540889024734, 54.268247187137604, 57.665952667593956, 67.39858701825142, 28.175974488258362, 1.0464386735111475, 0.10450473098899238, 0.03736807804671116, 0.013961401764390757, 0.12677089049248025, 0.023545956064481288, 0.02003675344894873, 0.0402194131311262, 0.055730247622705065, 0.023218216228997335, 0.01644656582357129, 0.08194668480427936, 0.01401939782226691, 0.028960301860934123, 0.04771508611156605, 0.021970352427160833, 0.013001190691284137, 0.0229483026851085, 0.031213347174343653, 0.05389995560108218, 0.05314646419719793, 0.013200521352700889, 0.1779444218846038, 0.11774425962357782, 0.1066733681363985, 0.15082818630617112, 0.09226864538504742, 0.15447625773958862, 0.14721483254106715, 0.2792805014178157, 0.16474249045131728, 0.0754992249130737, 0.16813946363981813, 0.12465415173210204, 0.2931993029778823, 0.0850883888779208, 0.3541217604652047, 0.1505606569116935, 0.179124629648868, 0.1808656784123741, 0.13108949235174805, 0.3014426043955609, 50.44646166265011, 87.05546423792839, 75.12766867876053, 66.6107676923275, 47.88151569664478, 28.74314535409212, 29.302764125168324, 50.70363566279411, 57.37641580402851, 38.75456124544144, 0.506848330842331, 0.3439835779136047, 0.7044190261512995, 1.136448837351054, 4.379229387268424, 12.375972010195255, 6.15845731459558, 4.273367067798972, 48.26504051685333, 71.32358640432358, 71.17768183350563, 66.60808503627777, 66.79658532142639, 67.64625012874603, 64.50870528817177, 68.83912771940231, 64.72927585244179, 63.52920904755592, 66.07678234577179, 62.727148085832596, 59.44616474211216, 62.84861996769905, 62.49497674405575, 57.32978090643883, 59.74025756120682, 59.59879495203495, 60.20024187862873, 62.34053783118725, 61.59507483243942, 61.6052582859993, 58.72584879398346, 55.313065722584724, 59.10891763865948, 56.1731381714344, 61.55613832175732, 57.861946150660515, 57.43859186768532, 54.135436713695526, 52.49241627752781, 62.23456151783466, 60.1681450009346, 56.208924651145935, 47.99210496246815, 48.52985590696335, 54.78585161268711, 53.414999172091484, 56.38338088989258, 53.913475424051285, 48.20784218609333, 46.21566988527775, 45.05843438208103, 53.33069309592247, 62.29718595743179, 58.48100893199444, 60.88281065225601, 54.809212759137154, 58.27905736863613, 40.24454869329929, 52.15946674346924, 65.66686034202576, 53.783750385046005, 53.65461051464081, 46.5030712634325, 45.89074172079563, 44.2482228577137, 48.51278342306614, 45.91722629964352, 46.136003360152245, 44.99329827725887, 45.53924158215523, 53.920128867030144, 61.36556714773178, 58.67353320121765, 54.55429203808308, 60.513470470905304, 58.23141172528267, 46.73452824354172, 45.392698645591736, 47.56600342690945, 60.025139674544334, 60.04899099469185, 55.466965064406395, 51.538466066122055, 62.610387951135635, 59.07061189413071, 61.273087710142136, 61.160264164209366, 63.075532391667366, 62.71691903471947, 61.750159710645676, 50.20203597843647, 48.44611980021, 46.152072697877884, 50.959753319621086, 50.99726490676403, 56.66751444339752, 60.08493326604366, 58.6100310087204, 62.77890510857105, 65.49855977296829, 64.81667876243591, 62.37395703792572, 65.17984047532082, 68.80169972777367, 62.94090561568737, 29.83882036060095, 1.5293203247711062, 5.807358529418707, 11.536194272339344, 6.745496364310384, 0.3605487890308723, 0.3186263213865459, 0.29851943312678486, 5.468044811859727, 30.962718352675438, 50.29641531407833, 48.911731615662575, 38.06518703699112, 26.512530148029327, 41.54388137161732, 62.269823625683784, 65.09893521666527, 75.53147301077843, 34.00870330631733, 1.1988545511849225, 0.2410888101439923, 0.19706937455339357, 0.07536048782640137, 0.2663107286207378, 0.13416333444183692, 0.09212664284859784, 0.17503143288195133, 0.1547586894594133, 0.0907016005658079, 0.14282854681368917, 0.16543681413168088, 0.14830999018158764, 0.16828634950798005, 0.13500586501322687, 0.10101904146722518, 0.14603696996346116, 0.15005467546870932, 0.2687694045016542, 0.1263661083066836, 0.11212105862796307, 0.16827362909680232], [0.049804053705884144, 0.03464487104793079, 0.011572694638743997, 0.0673581320734229, 0.03721490989846643, 0.03676061904116068, 0.04839246284973342, 0.08756820112466812, 0.025187020837620366, 0.012362336055957712, 0.026707783472375013, 0.008848700035741786, 0.07881213503424078, 0.01914191074320115, 0.08289835561299697, 0.07453202095348388, 0.07661738913157023, 0.09799174687941559, 0.06766569291357882, 2.8230948513373733, 52.91803903877735, 62.59577013552189, 57.27851025760174, 41.96999050676823, 35.02196453511715, 25.254366360604763, 38.458363339304924, 42.669080793857574, 35.74565850198269, 9.703494664281607, 0.06904765352373943, 0.006892357014294248, 0.13672347675310448, 0.23334681463893503, 3.628518395125866, 1.546109605114907, 2.824677941389382, 24.976979345083237, 68.82720395922661, 66.61588221788406, 62.41742670536041, 60.0854804366827, 62.79673375189304, 58.17253768444061, 59.205892235040665, 58.153683096170425, 61.2458735704422, 58.82113628089428, 63.785832077264786, 57.25181668996811, 55.15220895409584, 55.8152961730957, 57.472410053014755, 57.190620973706245, 57.70258270204067, 54.977425932884216, 55.58101214468479, 54.12833109498024, 57.77637094259262, 56.78373880684376, 52.43722803890705, 55.41232019662857, 56.918213590979576, 55.37213355302811, 56.60600334405899, 53.70606355369091, 55.79035811126232, 52.42840491235256, 53.25367122888565, 54.738270565867424, 54.809265956282616, 49.05873812735081, 45.262852013111115, 45.79258158802986, 51.20220310986042, 52.21827618777752, 50.273247957229614, 47.90954299271107, 44.392265528440475, 39.245548099279404, 42.39567406475544, 50.73761343955994, 55.89109070599079, 51.270405650138855, 55.47502063214779, 50.11195421218872, 56.313704028725624, 31.324654631316662, 42.472699731588364, 61.25630021095276, 51.96893356740475, 50.61524100601673, 44.49043706059456, 42.727555856108665, 40.11402189731598, 40.29108099639416, 40.81157706677914, 40.86558736860752, 39.3317274749279, 38.53065446019173, 46.83652997016907, 55.83940587937832, 52.115928679704666, 53.31674784421921, 54.482388496398926, 47.35708303749561, 41.53439708054066, 38.49652849137783, 42.81000383198261, 53.8801322132349, 56.56701743602753, 52.89841689169407, 50.803110525012016, 54.2733009159565, 54.786299988627434, 54.39676009118557, 51.783989891409874, 55.2237781137228, 53.98004025220871, 51.06631860136986, 43.66234749555588, 43.91420938074589, 41.18461064994335, 46.06888756155968, 50.532055869698524, 51.07309743762016, 53.67117002606392, 57.282667234539986, 59.27140071988106, 60.70183016359806, 57.093368992209435, 60.786831602454185, 60.82379221916199, 56.83775290846825, 57.70361244678497, 53.91786798834801, 11.763803008943796, 1.6258999798446894, 5.971036646515131, 4.530109316110611, 1.0324093513190746, 0.19627303525339812, 0.07890641747508198, 0.46844729455187917, 15.789686031639576, 35.97202755510807, 40.16232490539551, 18.123868480324745, 20.065212808549404, 34.014205411076546, 36.44805081188679, 45.04893109202385, 54.32482235133648, 35.66134862601757, 2.3714330373331904, 0.07006194675341249, 0.09288943707360886, 0.05633312015561387, 0.02177820853830781, 0.07929540675831959, 0.020533255810732953, 0.06615505131776445, 0.08424398809438571, 0.06811923420173116, 0.08183750745956786, 0.014082716006669216, 0.052012562737218104, 0.03593499830458313, 0.05887693892873358, 0.07035527320113033, 0.009173312646453269, 0.021648184265359305, 0.03183774198987521, 0.01759997092449339, 0.033467887915321626, 0.04292945443012286, 0.04620136089215521, 0.005898549843550427, 0.09797482591238804, 0.03257798234699294, 0.06776597190764733, 0.029473489557858557, 0.06074937009543646, 0.056254964583786204, 0.06731655696057715, 0.02772225852822885, 0.027169004133611452, 0.03413239952351432, 0.05272343631077092, 0.047074787071323954, 0.027546903875190765, 0.03133326339593623, 0.01675745519605698, 0.014501226996799232, 0.08313720842124894, 3.948792046867311, 62.42056913673878, 70.17825186252594, 64.19855073094368, 48.27377624809742, 42.904546558856964, 32.54900403320789, 30.06932359188795, 36.29044286906719, 42.056006491184235, 10.75092650949955, 0.10867163044167683, 0.10817890375619754, 0.30652486137114465, 2.2455206187441945, 6.836526179686189, 2.3043319629505277, 1.9194749579764903, 25.50652462989092, 70.48834562301636, 70.00273928046227, 64.09688338637352, 62.221323028206825, 64.94918525218964, 61.60058833658695, 63.562594056129456, 62.54019811749458, 64.86571133136749, 60.61909720301628, 62.78010584414005, 60.540483221411705, 56.02398857474327, 58.079001903533936, 59.35868203639984, 59.10637937486172, 58.70716519653797, 56.645376831293106, 57.13410660624504, 56.82435482740402, 59.806670397520065, 58.85098747909069, 54.87928859889507, 56.13521620631218, 58.34914840757847, 57.06321761012077, 58.10362458229065, 55.03333993256092, 56.73186779022217, 53.89161519706249, 53.98051902651787, 56.511312425136566, 57.40329176187515, 51.03295259177685, 47.4674329161644, 48.55266608297825, 52.0548165589571, 54.28692698478699, 53.6162705719471, 51.51644624769688, 46.821520775556564, 41.01605549454689, 44.03483010828495, 52.60343112051487, 59.12995710968971, 54.57709841430187, 57.57987968623638, 52.415766790509224, 56.352815330028534, 32.66079403460026, 44.033127799630165, 62.70213782787323, 54.27848383784294, 53.685753643512726, 46.46240584552288, 44.896065294742584, 42.03267194330692, 44.27634134888649, 42.344304621219635, 43.32458361983299, 41.59901641309261, 40.4160562902689, 48.40540498495102, 57.41161331534386, 54.299591705203056, 56.22286230325699, 56.72918513417244, 50.8453718572855, 43.438265919685364, 40.51600992679596, 44.32003900408745, 57.34026834368706, 58.58564391732216, 53.39996337890625, 51.450253799557686, 57.77351729571819, 57.02212281525135, 56.91656067967415, 54.468728229403496, 56.8245904147625, 55.7604993134737, 53.00277829170227, 46.19987413287163, 46.082829013466835, 43.77988278865814, 49.735481813549995, 52.231564074754715, 53.82524415850639, 54.87293913960457, 60.13363525271416, 59.8205928504467, 62.25401267409325, 59.69877518713474, 63.457666486501694, 62.38859765231609, 59.30881731212139, 60.422643944621086, 56.82397864758968, 13.708472158759832, 1.729132009204477, 3.172273552045226, 6.638177772983909, 2.9252711310982704, 0.5603215552400798, 0.131353800825309, 0.42309194861445576, 18.903007172048092, 36.18382439017296, 38.05011324584484, 21.62829503417015, 22.543650716543198, 37.15540185570717, 44.26449738442898, 49.78940472006798, 60.4001035541296, 45.65597511827946, 2.9400974605232477, 0.035038710266235285, 0.030618708769907244, 0.045049191467114724, 0.04638272323063575, 0.12007104844087735, 0.020720568318211008, 0.024482718981744256, 0.027460914934636094, 0.04125671664951369, 0.043618545969366096, 0.031641829846194014, 0.032270966985379346, 0.09178906213492155, 0.02890216015657643, 0.03247900211135857, 0.03993902231741231, 0.026857804914470762, 0.019527662407199387, 0.043411130536696874, 0.010737040065578185, 0.010712241200963035, 0.19522375718224794, 0.1850456916145049, 0.1616603956790641, 0.13222463690908626, 0.12792856665328145, 0.10637846091412939, 0.1322201543371193, 0.22823105711722746, 0.12940023065311834, 0.12692555406829342, 0.13513767044059932, 0.13127171929227188, 0.18784452346153557, 0.16357813496142626, 0.0852546448004432, 0.15269606810761616, 0.1727260698680766, 0.2098756522173062, 0.23320257081650198, 5.886897761374712, 75.86456313729286, 77.39521220326424, 73.4941591322422, 56.57172538340092, 48.3953545242548, 36.400207579135895, 55.03820367157459, 57.158128917217255, 53.06208550930023, 14.29632531479001, 0.20677114458521828, 0.5546284513548017, 0.6016492063645273, 2.2132385009899735, 11.300803553313017, 9.194561373442411, 5.980308149009943, 26.80431079119444, 74.0181890130043, 71.02211058139801, 68.51191967725754, 63.72173711657524, 68.38888227939606, 63.30213703215122, 65.20857453346252, 63.88802379369736, 67.35793679952621, 63.804147094488144, 65.55579990148544, 60.49776591360569, 58.607002571225166, 57.230743020772934, 62.63005569577217, 60.771267637610435, 62.03884541988373, 57.91863530874252, 60.236244946718216, 57.254883125424385, 61.17882236838341, 59.270925745368004, 57.88523510098457, 57.101952731609344, 61.21490903198719, 59.88399624824524, 61.2718565762043, 58.06164063513279, 58.74021202325821, 55.19353933632374, 54.91488128900528, 57.48778782784939, 58.80567491054535, 54.27362769842148, 49.99955624341965, 50.413255244493484, 56.84721440076828, 58.247032687067986, 56.07327952980995, 53.17435808479786, 48.55113096535206, 44.65610437095165, 46.529981419444084, 55.627217665314674, 63.79259571433067, 57.80377507209778, 59.88897778093815, 55.74532672762871, 57.09988944232464, 36.648425459861755, 47.05976039171219, 64.80789363384247, 58.444785475730896, 55.41099786758423, 49.84369620680809, 47.256764620542526, 44.74576435983181, 46.512908935546875, 45.896996185183525, 45.46700365841389, 44.73595328629017, 42.52922169864178, 52.61413514614105, 60.13319447636604, 58.20018880069256, 57.329932898283005, 58.9761071652174, 52.43503175675869, 46.097519025206566, 42.38669894635677, 46.58696696162224, 59.57872822880745, 61.45143873989582, 54.27003689110279, 52.53404304385185, 58.675851076841354, 61.0394686460495, 59.40534733235836, 57.549371123313904, 59.74906928837299, 59.19163540005684, 55.30709244310856, 49.71040315926075, 49.574397057294846, 46.22464120388031, 51.38905808329582, 56.098244190216064, 55.67512929439545, 57.639076709747314, 62.92239300906658, 63.87926146388054, 63.223291262984276, 62.14622005820274, 65.10180026292801, 65.14898613095284, 62.05842196941376, 62.590157836675644, 60.0090741366148, 14.088986590504646, 3.89036210719496, 11.46341297775507, 14.729855451732874, 3.9339578803628683, 0.9076677449047565, 0.18631329468917102, 0.440488513559103, 25.54177723824978, 51.298258155584335, 54.20702487230301, 26.308591291308403, 29.38392587006092, 45.85142143070698, 49.53519456088543, 57.90214419364929, 69.14443373680115, 52.55470633506775, 3.7880525970831513, 0.34843411878682673, 0.20034954854054376, 0.13910807145293802, 0.10415891985758208, 0.33581849886104465, 0.09297671364038251, 0.15271340467734262, 0.09726681702886708, 0.23799294111086056, 0.1583332140580751, 0.06282607369939797, 0.11234506106120534, 0.26328255829866976, 0.18817378469975665, 0.17149716237327084, 0.08109150061500259, 0.09758296451764181, 0.10222473458270542, 0.12060185472364537, 0.06871229183161631, 0.19311302981805056], [0.07778795639751479, 0.04099709483853076, 0.02230429476185236, 0.06621461609029211, 0.07371691273874603, 0.017267947041545995, 0.03170675663568545, 0.036966167972423136, 0.08854347965097986, 0.07133924969821237, 0.06322885950794443, 0.04895063211733941, 0.03301946373539977, 0.04412737725942861, 0.08289912002510391, 0.04110296591534279, 0.012569490809255512, 0.07472119439626113, 0.141312368796207, 11.23566459864378, 60.88893212378025, 57.006596848368645, 52.16693714261055, 43.04487302899361, 28.262387551367283, 16.492344327270985, 39.12258289754391, 41.44659899175167, 23.930566795170307, 1.0296501056291163, 0.0946654929430224, 0.11346516228513792, 0.14950993907405064, 1.6279829805716872, 2.311870758421719, 1.1100480915047228, 5.51529242657125, 52.622642889618874, 67.67087280750275, 60.05285918712616, 61.62784807384014, 56.47560954093933, 54.090758711099625, 52.05892413854599, 51.783074140548706, 53.664307594299316, 58.58083337545395, 60.28538390994072, 57.02186442911625, 59.917495250701904, 55.58832295238972, 55.301062166690826, 58.384338319301605, 57.13432319462299, 56.98720648884773, 54.02280695736408, 57.15451531112194, 54.0460617095232, 56.53465077280998, 53.78303222358227, 53.65795813500881, 54.89179752767086, 51.526838690042496, 51.94374471902847, 53.53795297443867, 52.709947004914284, 52.78523996472359, 54.72021773457527, 55.06553940474987, 54.87541280686855, 56.218177154660225, 48.9062637090683, 48.37390087544918, 45.76939143240452, 52.53260672092438, 50.60348063707352, 50.67511059343815, 46.523027792572975, 43.88579450547695, 39.49494391679764, 45.01464173197746, 51.78698793053627, 55.740941762924194, 51.431156024336815, 56.39845088124275, 48.85111726820469, 54.693269580602646, 30.911512300372124, 43.75640384852886, 59.10313054919243, 50.11470906436443, 49.20640580356121, 46.078782230615616, 45.796632170677185, 38.885639011859894, 40.23541018366814, 39.787174835801125, 38.973003923892975, 41.11944794654846, 40.134107619524, 46.05108551681042, 54.33754786849022, 54.50077950954437, 56.183044239878654, 52.22651034593582, 44.66749235987663, 41.65246434509754, 40.14594778418541, 41.05320990085602, 52.04805672168732, 57.039389088749886, 52.93639965355396, 50.901646837592125, 56.118139922618866, 53.023061603307724, 51.65196217596531, 50.01916319131851, 47.84327074885368, 49.945401549339294, 48.937680423259735, 44.64294947683811, 42.444968819618225, 42.97138497233391, 48.35583284497261, 51.67915351688862, 52.813837230205536, 55.477710887789726, 58.76749835908413, 60.37822052836418, 59.29361812770367, 60.3418792784214, 59.98664014041424, 59.70266617834568, 57.92316846549511, 58.12665514647961, 62.1857151389122, 42.290830090641975, 2.777616991661489, 3.8601074181497097, 3.163837529718876, 4.0921994391828775, 0.8253432030323893, 0.10505423197173513, 0.1977583992993459, 2.7187123149633408, 31.09696324914694, 39.47490379214287, 36.708150655031204, 49.11719799041748, 37.687137722969055, 29.03568785637617, 43.66755701601505, 48.06550942361355, 54.9410542845726, 11.295701377093792, 0.18891999934567139, 0.1122844498604536, 0.0383410781796556, 0.047573606789228506, 0.03802542792982422, 0.033053175793611445, 0.0629572408797685, 0.013718637837882852, 0.044567611839738674, 0.06017020175931975, 0.04002946414402686, 0.04395786701934412, 0.05727286836190615, 0.03373671606823336, 0.06082647552830167, 0.02491476210707333, 0.008776582762948237, 0.04206165001960471, 0.031687089722254314, 0.032585670996923, 0.04668674402637407, 0.07190337099018507, 0.09331251319963485, 0.016466340348415542, 0.05576674644544255, 0.04524781987129245, 0.06376526900567114, 0.1351298185181804, 0.0346463516325457, 0.06579388515092432, 0.03741117827303242, 0.04271432808309328, 0.04142646437685471, 0.012901022091682535, 0.039467213064199314, 0.10553737753070891, 0.04279483255231753, 0.038786233199061826, 0.04229989426676184, 0.03537013857567217, 16.073238216340542, 73.15391018986702, 62.71899372339249, 58.907733634114265, 47.60029658675194, 36.74427531659603, 24.15150973945856, 44.58165116608143, 43.234220668673515, 30.721476897597313, 1.4160662144422531, 0.13388171908445656, 0.469309373293072, 0.7100994244683534, 4.184528784826398, 5.673952912911773, 1.340661516878754, 6.425958210602403, 54.32559750974178, 70.66523373126984, 64.13257867097855, 63.453414514660835, 59.35391329228878, 57.55146101117134, 54.83700826764107, 53.814787119627, 56.596728041768074, 59.65559810400009, 62.98127084970474, 59.682637453079224, 60.117246732115746, 58.49359005689621, 57.65600860118866, 62.446525543928146, 57.97652140259743, 59.59537513554096, 56.64423689246178, 58.07839773595333, 55.34756027162075, 59.69853959977627, 54.98503312468529, 55.45439153909683, 56.59567549824715, 54.82157349586487, 53.28825317323208, 56.204790472984314, 54.42403882741928, 57.3770921677351, 58.16121429204941, 54.466505348682404, 56.92077465355396, 58.157300502061844, 52.81746603548527, 51.308642998337746, 49.006091952323914, 54.48479376733303, 52.56803222000599, 53.67754228413105, 49.46539990603924, 45.31504601240158, 40.03510393202305, 46.961664855480194, 52.78881557285786, 58.395296931266785, 52.97521077096462, 57.70130977034569, 51.851649060845375, 56.42333194613457, 32.092762514948845, 47.25913189351559, 61.713183894753456, 51.80032901465893, 52.29198083281517, 46.50597810745239, 46.64720892906189, 42.440089881420135, 43.23360130190849, 42.05267407000065, 41.74347326159477, 41.947024539113045, 40.989331528544426, 47.03645624220371, 56.243559792637825, 56.48909121751785, 59.01793912053108, 54.75140266120434, 46.54822804033756, 42.791559621691704, 42.82198078930378, 44.47065532207489, 54.76503632962704, 58.45963127911091, 54.30733188986778, 51.09356313943863, 58.58318544924259, 54.37122546136379, 54.5746361464262, 52.251106426119804, 49.55659881234169, 50.47144912183285, 50.37353977560997, 45.82399070262909, 43.561071529984474, 45.471263229846954, 50.027568340301514, 53.19397263228893, 55.85691533982754, 57.09187567234039, 62.2983904927969, 63.421644419431686, 61.54126591980457, 61.31934642791748, 64.39392864704132, 61.60344958305359, 60.30024491250515, 61.09824389219284, 65.02998411655426, 46.055242493748665, 4.7988570202142, 2.841835208237171, 4.281348064541817, 7.801705738529563, 4.245533086359501, 0.08034058075281791, 0.21166587568586692, 2.719430001452565, 36.10835283994675, 35.08661046624184, 27.93902300298214, 48.583839610219, 42.579504400491714, 33.85780580341816, 48.16325917840004, 54.879976361989975, 62.69136540591717, 17.20560595393181, 0.16391560435295105, 0.1164856662217062, 0.04459563162527047, 0.022457843260781374, 0.03662934796011541, 0.045622808538610116, 0.019263960639364086, 0.04367983252450358, 0.059105334876221605, 0.14153011492453516, 0.02413046229776228, 0.03316371497930959, 0.04351854899141472, 0.11405204524635337, 0.0450457219267264, 0.026528417511144653, 0.03465585483354516, 0.025833288600551896, 0.0812445166229736, 0.019717208779184148, 0.02324506527656922, 0.22342801094055176, 0.1795579251484014, 0.19765521108638495, 0.18632123566931114, 0.16301152005326003, 0.13323605060577393, 0.1875400944845751, 0.11296747063170187, 0.16626205266220495, 0.22551843314431608, 0.18562349810963497, 0.15820241795154288, 0.11911180030438118, 0.13411957741482183, 0.20408497075550258, 0.1337152553605847, 0.11335163595504127, 0.2260154642863199, 0.26354017260018736, 18.743075653910637, 86.02124333381653, 70.39907321333885, 68.70743438601494, 57.57108315825462, 40.20137920975685, 23.954877890646458, 51.64459817111492, 57.35669866204262, 39.17036533355713, 2.3051809798926115, 0.18418656662106514, 0.6437546282541007, 0.8737635298166424, 4.897983251139522, 9.727017302066088, 7.433901624754071, 6.926697241142392, 56.390649899840355, 72.1665407717228, 66.1751514673233, 66.00970074534416, 61.68031185865402, 59.015883430838585, 56.22096620500088, 57.04418823122978, 58.04982706904411, 64.17294010519981, 64.85943406820297, 60.74506804347038, 59.14243943989277, 58.62971395254135, 60.40082171559334, 64.41716060042381, 62.049948424100876, 62.2017502784729, 59.34521555900574, 61.31054230034351, 57.60815776884556, 60.152919217944145, 56.77407592535019, 58.21132220327854, 58.86048696935177, 57.494490668177605, 56.79721288383007, 57.8016509860754, 58.14284227788448, 59.6782410889864, 60.253359228372574, 55.798782259225845, 59.31994691491127, 61.00535407662392, 53.00972431898117, 53.4178414195776, 51.56435027718544, 57.935692593455315, 55.595952942967415, 56.95187218487263, 52.07774072885513, 48.609541431069374, 43.49079430103302, 49.35541480779648, 56.11377775669098, 61.63239262998104, 58.22574622929096, 59.29605759680271, 54.18527863919735, 55.86290381848812, 34.557709246873856, 50.510685816407204, 61.668695881962776, 53.81069473922253, 54.86926093697548, 49.64899845421314, 48.23753759264946, 43.85446518659592, 46.05828233063221, 44.5073651522398, 42.868437096476555, 45.25518402457237, 43.7576387822628, 50.49754612147808, 59.15573872625828, 59.17951785027981, 61.542896032333374, 57.957499623298645, 48.69692914187908, 47.36990734934807, 45.03389149904251, 45.30121095478535, 56.42159163951874, 63.25026601552963, 55.89451052248478, 52.000601068139076, 60.62607742846012, 58.02578195929527, 58.45515891909599, 55.14284245669842, 52.802114859223366, 52.40402162075043, 53.30125607550144, 49.06474180519581, 47.09031455218792, 48.66750732064247, 54.209224954247475, 56.689975038170815, 58.51212926208973, 59.679464623332024, 63.97931769490242, 65.69200739264488, 63.88807699084282, 64.61048662662506, 65.97592815756798, 65.3355561196804, 61.46149680018425, 63.04968237876892, 66.11192286014557, 46.547509878873825, 4.704593103379011, 8.227294776588678, 9.007356818765402, 13.075778558850288, 2.790993698872626, 0.22004533151630312, 0.262973053031601, 3.5720045026391745, 46.00712187588215, 52.936426252126694, 50.662852451205254, 56.42756871879101, 46.214450150728226, 42.391733676195145, 58.39263327419758, 61.398207396268845, 72.71349102258682, 20.212492905557156, 0.4575821931939572, 0.257366067962721, 0.16939652821747586, 0.1285737453144975, 0.14286403631558642, 0.14147060952382162, 0.16534962662262842, 0.09050009262864478, 0.15421640215208754, 0.1914755254983902, 0.15508754993788898, 0.18053574924124405, 0.21091413946123794, 0.1334877425688319, 0.12063839065376669, 0.16994559875456616, 0.04824557327083312, 0.11443311581388116, 0.14092122728470713, 0.21254169900203124, 0.07271925103850663], [0.04595261154463515, 0.057663327097543515, 0.07688027268159203, 0.040949285685201176, 0.06233688705833629, 0.0604410411324352, 0.025737933756317943, 0.04772833715833258, 0.0622279063827591, 0.019768754646065645, 0.035884784592781216, 0.05494840988831129, 0.046835095636197366, 0.04302095010643825, 0.06871327888802625, 0.03406712021387648, 0.056921212817542255, 0.03333607135573402, 0.08608170159277506, 23.439395651221275, 61.474894881248474, 59.48336474597454, 50.242222622036934, 35.27700684964657, 20.50046995282173, 29.95003279298544, 37.38628886640072, 37.38506153225899, 13.27841978520155, 0.041926111589418724, 0.026598572731018066, 0.05135163570230361, 0.2557329571573064, 4.250019220635295, 5.3878971375525, 0.9445148427039385, 16.971612609922886, 65.90896055102348, 66.07286095619202, 65.07518649101257, 57.100220024585724, 50.14334812760353, 48.21089722216129, 48.46467800438404, 47.17280812561512, 48.300724402070045, 57.12615743279457, 58.57909306883812, 61.1490585654974, 58.11710625886917, 62.620841190218925, 58.11592452228069, 55.95886766910553, 52.183363661170006, 54.88761395215988, 55.62128618359566, 56.57653212547302, 52.68633507192135, 54.40174162387848, 53.33531744778156, 55.28578698635101, 54.19500611722469, 51.57805234193802, 48.71945433318615, 45.39002738893032, 49.28252711892128, 52.85439245402813, 54.61257331073284, 51.57532028853893, 54.27469164133072, 54.82898309826851, 50.76327346265316, 47.47074633836746, 47.69370697438717, 52.13458947837353, 48.14141795039177, 50.93533582985401, 43.95597293972969, 41.394731774926186, 41.599498987197876, 46.121598333120346, 51.831479743123055, 53.03975410759449, 49.990216344594955, 57.16972589492798, 50.26730127632618, 54.829074293375015, 28.722421266138554, 43.795655742287636, 60.37770755589008, 49.06074821949005, 51.26411698758602, 47.83097840845585, 45.81098400056362, 44.38794136047363, 39.610518515110016, 37.8670808672905, 40.95006823539734, 37.2737693041563, 39.76190619170666, 39.627993777394295, 48.210452646017075, 51.392379105091095, 50.82754321396351, 44.73202049732208, 40.95040261745453, 41.03094309568405, 42.13326774537563, 40.67205235362053, 51.31764091551304, 55.45886009931564, 53.57268691062927, 50.11649116873741, 54.64780882000923, 51.568017080426216, 50.048630610108376, 45.14813996851444, 46.392041221261024, 46.54927298426628, 43.998819440603256, 44.48129095137119, 44.3214525282383, 43.54241073131561, 47.34693758189678, 52.22767308354378, 56.91991589963436, 57.56057672202587, 58.76251682639122, 58.432591930031776, 59.16281394660473, 59.17219564318657, 57.46789209544659, 55.50603076815605, 53.73222514986992, 56.315531730651855, 59.3892589956522, 56.79729647934437, 27.774227745831013, 2.318968065083027, 4.822310786694288, 7.029383406043053, 1.035659364424646, 0.04463538476557005, 0.11376727576134726, 0.5597008822951466, 17.390944808721542, 49.83282119035721, 43.222901076078415, 19.952571652829647, 14.453832563012838, 28.443400338292122, 38.94156061112881, 51.69662497937679, 51.48651525378227, 29.493998363614082, 0.8851523499470204, 0.08067192742601037, 0.00648253750114236, 0.011737034892576048, 0.06914414014318027, 0.023562062524433713, 0.06783168166293763, 0.06103874460677616, 0.004128170476178639, 0.05432033402030356, 0.02168131930375239, 0.02767127298284322, 0.04104805069800932, 0.0322863368637627, 0.0584981467545731, 0.024747613751969766, 0.02749284583842382, 0.009568784589646384, 0.04150777036556974, 0.01755400971887866, 0.06598606429179199, 0.029048424476059154, 0.038060817241785116, 0.029327102784009185, 0.019434237146924715, 0.073200979095418, 0.043210353614995256, 0.025689940921438392, 0.06912007971550338, 0.07204165536677465, 0.07747709300019778, 0.06195962741912808, 0.05678368172084447, 0.050639133114600554, 0.003956737609769334, 0.02292563563969452, 0.04641397506929934, 0.025471380286035128, 0.06367695343215019, 0.10348539857659489, 31.357636861503124, 73.33296418190002, 64.09682258963585, 59.693090692162514, 43.65543946623802, 24.900968223810196, 21.57908957451582, 34.43821705877781, 42.4977707862854, 16.108340732753277, 0.08525679702870548, 0.04099894278624561, 0.3511957690352574, 0.9865883819293231, 6.306507345288992, 2.9623761400580406, 0.7179394725244492, 17.841959707438946, 69.88611593842506, 67.05742612481117, 66.77170425653458, 59.08796936273575, 53.134513422846794, 49.75694686174393, 50.666918233036995, 49.408801943063736, 50.360783860087395, 58.342145383358, 61.07345022261143, 62.69598215818405, 56.86636157333851, 64.20314848423004, 59.015590846538544, 58.57964783906937, 55.41073948144913, 57.691445499658585, 56.61694675683975, 58.705804869532585, 54.90911319851875, 54.541703313589096, 55.25728091597557, 55.7719025015831, 56.1253747344017, 54.82632704079151, 50.006612464785576, 47.220867946743965, 51.40431426465511, 55.41126765310764, 56.62217527627945, 51.259181052446365, 55.43211333453655, 56.312700882554054, 52.780547216534615, 48.83182570338249, 49.87000219523907, 54.48211871087551, 52.04676479101181, 53.26851323246956, 46.45080886781216, 43.92689310014248, 42.62583151459694, 48.35559345781803, 54.65922340750694, 55.70260941982269, 53.2990749925375, 58.57136808335781, 52.13800549507141, 56.01764291524887, 30.569922029972076, 44.80424702167511, 61.542082875967026, 51.170376017689705, 52.87687964737415, 49.31659609079361, 47.654531076550484, 46.958860605955124, 43.30798231065273, 40.088095888495445, 41.983297392725945, 39.87493112683296, 42.336423844099045, 42.832859605550766, 51.57519489526749, 52.85209357738495, 52.39543408155441, 46.652357652783394, 43.14890004694462, 42.63675592839718, 43.02576005458832, 43.67476902902126, 53.215198293328285, 58.31678934395313, 55.31618155539036, 52.19217538833618, 57.87412829697132, 55.10713957250118, 51.479649022221565, 46.41055382788181, 48.48243065178394, 47.828702330589294, 47.251129522919655, 45.15866160392761, 46.41666769981384, 45.310615450143814, 50.42768307030201, 56.25634990632534, 59.47983093559742, 59.98231217265129, 60.61389148235321, 59.54740650951862, 60.43341636657715, 60.411092564463615, 60.91645784676075, 56.68886549770832, 56.681022718548775, 59.378665164113045, 63.240956515073776, 58.50810907781124, 29.757806807756424, 2.8826751792803407, 3.8679226487874985, 7.939127264544368, 4.670794392004609, 0.14680029853479937, 0.03323745848319959, 0.3305061167338863, 18.654756993055344, 50.01079224050045, 36.174970865249634, 23.748889043927193, 22.812799774110317, 35.75034745037556, 45.77036038041115, 55.71089677512646, 58.60211223363876, 39.425791427493095, 1.9179939874447882, 0.14353314181789756, 0.03283528123574797, 0.03147997114865575, 0.021473054111993406, 0.02994883143401239, 0.029081201428198256, 0.03195029610651545, 0.02815186555380933, 0.011513767185533652, 0.09353342829854228, 0.019167744903825223, 0.057186085323337466, 0.03963186223700177, 0.03241164107748773, 0.04144990140048321, 0.045318309057620354, 0.034094141810783185, 0.020708838674181607, 0.018323705917282496, 0.032279620427289046, 0.17567710136063397, 0.08199732154025696, 0.17180439666844904, 0.0986108835786581, 0.2592597616603598, 0.19187137222616002, 0.1481590818730183, 0.20989175682188943, 0.152067068265751, 0.1402135004173033, 0.14597845904063433, 0.10066867354908027, 0.16752293187892064, 0.07151126468670554, 0.09401843664818443, 0.10701188395614736, 0.1354022609302774, 0.20263937098206952, 0.23700656747678295, 41.806470081210136, 84.0417167544365, 73.4138086438179, 67.58432105183601, 51.22257761657238, 31.197049878537655, 42.47568257153034, 51.38777755200863, 52.71040678024292, 21.001469269394875, 0.32425111799966544, 0.1566449913661927, 0.36194153304677457, 1.1941705900244415, 10.351818725466728, 16.431418396532536, 4.604947725310922, 18.79088468849659, 69.22223836183548, 70.69669604301453, 69.36272442340851, 63.33659738302231, 55.067617893218994, 53.20479065179825, 52.957325130701065, 51.52578994631767, 51.472231820225716, 61.98386996984482, 63.105930760502815, 64.54521372914314, 57.902919352054596, 64.82245445251465, 61.42690725624561, 59.73034009337425, 57.68032729625702, 59.84633646905422, 59.721634760499, 61.06563024222851, 55.77706642448902, 56.550792306661606, 57.88158729672432, 59.14114750921726, 57.55358889698982, 57.916929200291634, 53.53678643703461, 49.73760969936848, 54.700831174850464, 57.3437375575304, 59.27129052579403, 53.11568163335323, 56.3126514852047, 59.90576907992363, 57.13700585067272, 52.68022879958153, 52.68591709434986, 57.2945985943079, 55.24468079209328, 55.925676450133324, 48.41704376041889, 46.58600181341171, 44.21376250684261, 50.01003988087177, 55.89378856122494, 59.36894528567791, 54.45683866739273, 61.18091605603695, 54.9881337583065, 56.44381284713745, 32.72783763706684, 49.85324889421463, 61.862922459840775, 54.751022681593895, 56.00745566189289, 52.63733670115471, 49.57904800772667, 49.326049983501434, 44.819415807724, 43.059551641345024, 45.830932930111885, 41.12508684396744, 44.36131998896599, 44.64858457446098, 53.945503905415535, 55.69386228919029, 56.22343987226486, 49.46248546242714, 44.8592072725296, 45.64192347228527, 46.383218094706535, 45.95101408660412, 56.390547305345535, 61.65712170302868, 56.053653582930565, 53.651623874902725, 58.812085166573524, 57.67466939985752, 54.596059396862984, 49.841230139136314, 51.986545622348785, 50.842768996953964, 48.789047598838806, 48.016001880168915, 48.74478377401829, 48.413711339235306, 51.65648013353348, 59.04285058379173, 61.28361314535141, 61.62993036210537, 62.788666784763336, 61.762360855937004, 62.35670976340771, 62.952494993805885, 63.36824968457222, 60.71821488440037, 58.92655022442341, 60.99954418838024, 64.03541028499603, 60.824681371450424, 32.1656996011734, 4.73079364746809, 12.120719756931067, 16.36147554963827, 5.028200838714838, 0.19289427436888218, 0.2582627010997385, 0.622396330581978, 23.74594420194626, 67.88903430104256, 58.342251777648926, 27.775097899138927, 22.766216173768044, 40.07473200559616, 52.01336458325386, 64.84181061387062, 66.94865316152573, 46.17816969752312, 2.5632937671616673, 0.23153858666773885, 0.10056259096018039, 0.14194032963132486, 0.18997620907612145, 0.09571057787979953, 0.21098810189869255, 0.15595795557601377, 0.1089884087559767, 0.1226905699877534, 0.20782903156941757, 0.07933250672067516, 0.13339534518308938, 0.14163873565848917, 0.14511081419186667, 0.1187117604422383, 0.19613527780165896, 0.19144885271089152, 0.1631275177351199, 0.06696031865430996, 0.16015579516533762], [0.07163230897276662, 0.09664941695518792, 0.03051246105314931, 0.0021968420060147764, 0.04251942526025232, 0.03331049323605839, 0.05305059356032871, 0.040826861004461534, 0.024749335534579586, 0.028418977490218822, 0.009401333809364587, 0.04109741836145986, 0.06164882339362521, 0.02834810053172987, 0.05700218112906441, 0.06801922980230302, 0.11012699687853456, 0.12265477620530874, 2.6480667432770133, 36.95140220224857, 62.510685101151466, 53.09294365346432, 42.75818221271038, 30.304893851280212, 20.822686962783337, 49.667659252882004, 44.737784788012505, 32.113308012485504, 3.3780142245814204, 0.1355948334094137, 0.1550150421098806, 0.19207467616070062, 1.0095063177868724, 4.755531745031476, 2.3949271766468883, 1.9961157767102122, 35.59497378766537, 69.56325486302376, 61.82462431490421, 60.270458310842514, 57.15270280838013, 52.89127327501774, 48.03913123905659, 45.394465550780296, 44.99799482524395, 45.332825258374214, 50.84014713764191, 57.5594025850296, 60.2936826646328, 58.090287297964096, 60.69287024438381, 57.604870945215225, 51.29904851317406, 53.013406321406364, 50.83967976272106, 53.88736702501774, 53.708461225032806, 56.297558695077896, 55.62301509082317, 53.70210036635399, 55.34076243638992, 55.405902341008186, 51.39292627573013, 42.247037440538406, 41.04231208562851, 47.308916822075844, 51.937623247504234, 54.66523468494415, 53.823823034763336, 54.80821721255779, 54.85227204859257, 51.34111985564232, 48.9861848205328, 48.93030121922493, 50.648557618260384, 47.875550016760826, 50.156719610095024, 40.63889913260937, 41.5535556524992, 40.47852113842964, 48.699908182024956, 52.481058686971664, 53.02161008119583, 54.65539701282978, 55.98795510828495, 51.0546912252903, 58.40155899524689, 32.15857498347759, 42.18054100871086, 59.609149396419525, 49.13768649101257, 51.96411542594433, 44.35891851782799, 48.45890611410141, 45.01217946410179, 43.880736976861954, 38.531304225325584, 39.74283121526241, 37.50764675438404, 40.004804357886314, 38.70767556130886, 44.08920519053936, 45.576137602329254, 46.42784669995308, 40.617878660559654, 40.686005204916, 41.95111691951752, 40.9550915658474, 40.584717839956284, 47.83811442553997, 54.4063887745142, 56.119553446769714, 50.93999817967415, 55.58868773281574, 55.80031357705593, 52.13609799742699, 43.990114107728004, 43.411701545119286, 43.40293921530247, 43.3259591460228, 40.58712691068649, 42.97752544283867, 44.45186533033848, 46.38169817626476, 52.27428138256073, 56.61982320249081, 56.55806511640549, 58.387169167399406, 58.32498550415039, 57.897945418953896, 57.37488068640232, 55.614792332053185, 50.756228640675545, 51.75444267690182, 55.9491515904665, 61.68207496404648, 59.57060046494007, 43.564202561974525, 12.557089291512966, 3.3789328252896667, 5.613638749346137, 11.303227823227644, 0.16077945154393092, 0.4521789128193632, 0.10460052741109394, 4.385049249976873, 32.86004774272442, 35.555037930607796, 33.22851397097111, 12.635210249572992, 19.70654435455799, 35.324245914816856, 41.69414050877094, 46.18891932070255, 52.210657596588135, 6.967867556959391, 0.0168683543233783, 0.03140423126751557, 0.04507985329837538, 0.023245067131938413, 0.05033453715441283, 0.07835461583454162, 0.060232783362152986, 0.06744323414750397, 0.05094378844660241, 0.025965285130951088, 0.025703980500111356, 0.060909662861377, 0.029299068155523855, 0.04426685278303921, 0.012616998465091456, 0.07336073380429298, 0.03161010674375575, 0.04284284579625819, 0.013610535679617897, 0.025420897545700427, 0.05713648388336878, 0.014666781589767197, 0.06534416592330672, 0.02330257986614015, 0.06570990371983498, 0.03838628610537853, 0.032794489088701084, 0.0050754774565575644, 0.0397862475074362, 0.04318228930060286, 0.06262901864829473, 0.0256344765148242, 0.020197450685373042, 0.0589146697166143, 0.03172158474626485, 0.04048127622809261, 0.15182744362391531, 0.12380275991745293, 3.24619407299906, 47.09762156009674, 68.8073082268238, 59.55272622406483, 46.439154893159866, 38.772617876529694, 24.066576696932316, 41.44183024764061, 41.353982761502266, 41.17544174194336, 3.86035630479455, 0.07382963012787513, 0.41634861670900136, 0.4349342209752649, 3.185064378194511, 8.442518077790737, 2.208779202774167, 1.8040966428816319, 37.82106913626194, 71.20798140764236, 65.39921030402184, 63.173126354813576, 60.47219328582287, 53.694740161299706, 50.075514167547226, 47.16640166938305, 49.135372415184975, 46.77717715501785, 54.407475516200066, 59.290323704481125, 62.0182391256094, 57.548592165112495, 61.83891534805298, 61.24566078186035, 53.292676135897636, 54.43478845059872, 53.58868785202503, 56.58340595662594, 56.37254387140274, 59.00781646370888, 56.79187037050724, 55.76894246041775, 55.456177443265915, 57.83010385930538, 52.53799483180046, 44.90468703210354, 43.23308452963829, 49.747264981269836, 54.21708673238754, 56.323043927550316, 54.133977591991425, 56.5883456915617, 57.81576342880726, 53.71466629207134, 51.50709114968777, 50.91555409133434, 52.145821675658226, 49.920721873641014, 52.48999960720539, 43.28500114381313, 44.21807147562504, 42.57661275565624, 49.92895983159542, 53.60140956938267, 56.69894635677338, 56.58171884715557, 58.39090436697006, 54.45979870855808, 58.695720210671425, 34.050580859184265, 43.90184484422207, 60.230541452765465, 50.78370116651058, 53.566892221570015, 47.69072413444519, 50.380326211452484, 45.69961577653885, 45.71878954768181, 41.07019878923893, 41.924943923950195, 40.722677037119865, 41.33400723338127, 41.538812443614006, 46.548881605267525, 48.14085178077221, 48.95520128309727, 43.784997314214706, 42.31660030782223, 43.630634397268295, 41.7385221272707, 42.92145945131779, 50.474979132413864, 55.58322362601757, 58.76833811402321, 52.2922620177269, 56.014781668782234, 58.30895036458969, 53.79781723022461, 47.192278280854225, 44.941780641674995, 44.828459322452545, 44.36378985643387, 44.0667711943388, 45.58864273130894, 45.974876806139946, 48.018247559666634, 54.319175854325294, 57.18883126974106, 59.9344727396965, 58.76096270978451, 59.88800883293152, 59.964213743805885, 60.06101354956627, 57.13765561580658, 53.35113599896431, 53.809999376535416, 57.56365455687046, 63.58571581542492, 63.57593134045601, 46.3874738663435, 15.829935371875763, 3.2649368047714233, 3.2480839965865016, 13.53763997554779, 2.39773475099355, 0.28760166896972805, 0.28436961583793163, 3.9278335589915514, 39.44908797740936, 36.44383683800697, 33.530255779623985, 19.73545130342245, 27.76812717318535, 41.73651583492756, 47.420737221837044, 50.68173363804817, 62.71376520395279, 12.10151368752122, 0.06860413122922182, 0.007802651234669611, 0.0678985714330338, 0.034928556997329, 0.0191438700130675, 0.0962037943827454, 0.011887940418091603, 0.04707075720943976, 0.03933651343686506, 0.02470338917191839, 0.06564329596585594, 0.0027307414211463765, 0.053439608818734996, 0.027622504603641573, 0.06749275766196661, 0.043738246968132444, 0.03945131255022716, 0.06409835230442695, 0.021855527338630054, 0.027525305522431154, 0.20581329910783097, 0.15138960618060082, 0.20029698964208364, 0.15591455477988347, 0.07957815760164522, 0.13378547737374902, 0.1675848418381065, 0.10326431278372183, 0.0892078947799746, 0.11910930668818764, 0.1939106752979569, 0.11675052388454787, 0.21120357705513015, 0.19382194412173703, 0.134623970661778, 0.13242975168395787, 0.37336419511120766, 0.17973068228457123, 4.178414912894368, 62.087953984737396, 78.29385638237, 70.5863119661808, 55.967987179756165, 43.516214936971664, 30.981472246348858, 65.37312850356102, 61.29399798810482, 50.40677659213543, 6.081655835732818, 0.26592677109874785, 0.8036554511636496, 0.2449227450415492, 6.073780283331871, 14.745967537164688, 8.519089668989182, 3.800005568191409, 41.0391316562891, 71.68857961893082, 66.05676501989365, 64.99599874019623, 61.75219640135765, 57.783784344792366, 53.25528234243393, 49.0989475697279, 49.20591562986374, 49.27633345127106, 56.11578784883022, 61.75077527761459, 64.26026701927185, 60.16667068004608, 62.556320652365685, 63.12065877020359, 55.532959923148155, 58.56678172945976, 55.58361120522022, 58.62141899764538, 58.43101881444454, 61.30440942943096, 59.25575315952301, 57.70632930099964, 57.246063798666, 60.12103512883186, 55.12046545743942, 47.724857702851295, 45.00511184334755, 52.309391498565674, 57.634026780724525, 60.02426952123642, 56.56309984624386, 57.855258509516716, 60.24749234318733, 56.15470916032791, 54.01637390255928, 53.23205418884754, 57.3670607060194, 52.388267666101456, 55.61310142278671, 46.42492085695267, 45.29839530587196, 46.30499929189682, 53.128562942147255, 59.07970480620861, 59.036892503499985, 59.81984429061413, 59.655316919088364, 58.19759353995323, 60.72047956287861, 37.11867302656174, 47.131188958883286, 62.669505178928375, 55.32313898205757, 56.47556014358997, 50.085598826408386, 53.292322754859924, 47.385262325406075, 47.5840562582016, 43.472285494208336, 45.45716978609562, 44.075772911310196, 43.49745154380798, 43.48222576081753, 49.2701967805624, 51.01765461266041, 51.18286594748497, 45.08148014545441, 45.426133051514626, 46.68917007744312, 43.987765833735466, 46.26569040119648, 51.11041523516178, 57.91611984372139, 61.843182519078255, 53.53684723377228, 58.35432752966881, 60.51444701850414, 57.06456273794174, 49.17288400232792, 46.70035667717457, 47.33189418911934, 45.95307357609272, 46.11140348017216, 46.84722259640694, 48.0681236833334, 49.79201517999172, 57.312191650271416, 60.54423741996288, 62.44971737265587, 61.69230781495571, 62.62415461242199, 61.1273617297411, 62.0382222533226, 60.500463768839836, 56.746983379125595, 57.00383059680462, 60.981943532824516, 68.78409147262573, 63.71679738163948, 47.37873427569866, 16.162877306342125, 7.07878740504384, 12.073526289314032, 19.510740861296654, 2.8982728673145175, 0.9853825403843075, 0.2897884219419211, 5.564806144684553, 46.699015349149704, 50.32536596059799, 47.33895041048527, 20.51327906548977, 28.658366203308105, 48.01030978560448, 56.063137874007225, 58.18369768559933, 71.64510235190392, 16.104208454489708, 0.2646951621863991, 0.13989547529490665, 0.09926821119734086, 0.12221981087350287, 0.11878593068104237, 0.3005675825988874, 0.073755430203164, 0.14436412457143888, 0.19157887698384002, 0.12789525906555355, 0.1793835056014359, 0.1416870197863318, 0.16095526632852852, 0.13860026432666928, 0.15642310405382887, 0.1774860269506462, 0.2449014305602759, 0.1743928444921039, 0.0829862778482493, 0.1278087543323636], [0.0036268935537009384, 0.027415102158556692, 0.039787676141713746, 0.017364825143886264, 0.026478704749024473, 0.08015551138669252, 0.029446178523357958, 0.047390370527864434, 0.03554314433131367, 0.0888033426599577, 0.02728565490542678, 0.03085392505454365, 0.046715001299162395, 0.04928928523440845, 0.030093995519564487, 0.011992611071036663, 0.027598750311881304, 0.07395863765850663, 11.427668295800686, 59.808505699038506, 57.245493829250336, 49.69130918383598, 36.805471032857895, 21.475130952894688, 14.164501838386059, 29.545888379216194, 36.70342370867729, 20.70381984114647, 0.3086746850749478, 0.018966005045513157, 0.1366528242942877, 0.1780457844142802, 1.602286621928215, 4.094254653900862, 2.415047809481621, 9.747459255158901, 53.74782711267471, 62.891037091612816, 68.17292466759682, 59.90057095885277, 58.463761657476425, 54.161693304777145, 51.805086359381676, 48.55411380529404, 44.53860707581043, 44.00542348623276, 49.69330407679081, 56.58711835741997, 59.07346934080124, 57.07391403615475, 55.975472778081894, 56.133000925183296, 49.78832557797432, 46.0939472168684, 48.07602345943451, 48.75207558274269, 52.34053082764149, 53.951085805892944, 56.48059107363224, 54.63958986103535, 54.84847605228424, 52.82902501523495, 50.15295781195164, 41.71944335103035, 39.655485302209854, 45.53945057094097, 53.602101132273674, 52.581620290875435, 50.79996049404144, 50.93168802559376, 57.05707713961601, 51.26928091049194, 50.83110362291336, 51.007224172353745, 47.788929864764214, 50.66165551543236, 46.1065511405468, 39.52557787299156, 40.37316419184208, 40.40626421570778, 50.05219101905823, 47.444284558296204, 52.05604389309883, 49.70407649874687, 56.143495962023735, 51.326574236154556, 61.102518662810326, 31.386682502925396, 39.55822952091694, 60.39414167404175, 47.04101599752903, 50.69348640739918, 44.41044755280018, 47.16407999396324, 47.08505943417549, 44.84477564692497, 40.558392852544785, 39.076479971408844, 37.00764678418636, 38.76216843724251, 37.976507395505905, 40.81459030508995, 40.30309975147247, 41.638112515211105, 38.50447006523609, 40.798490568995476, 38.512989208102226, 41.09801709651947, 41.07851654291153, 45.24163395166397, 50.40863089263439, 55.43188534677029, 53.0949005484581, 53.502139896154404, 53.974188566207886, 50.4572568833828, 45.745171532034874, 42.04219423234463, 42.4079854041338, 40.52288755774498, 43.47510114312172, 43.654181733727455, 44.631348699331284, 43.45277354121208, 47.048053219914436, 55.07563926279545, 57.73354344069958, 57.9189582914114, 57.988224774599075, 56.96228362619877, 54.649518728256226, 50.91985546052456, 48.84498439729214, 54.46371629834175, 56.617695316672325, 57.57839396595955, 61.312746182084084, 53.736355528235435, 27.745151706039906, 10.066508185118437, 3.112733834423125, 7.249629087746143, 3.717130827717483, 0.07267471475643106, 0.2743319497676566, 0.0557239542104071, 18.634941056370735, 37.70776681602001, 36.93614982068539, 23.4912533685565, 13.99203384295106, 28.95145207643509, 43.85602310299873, 44.04987350106239, 54.21460546553135, 23.88778869062662, 0.2000782045070082, 0.07112972656614147, 0.026087190308317076, 0.057408403081353754, 0.034704732679529116, 0.09787454691831954, 0.07366730758803897, 0.02658293382410193, 0.07456814870238304, 0.031687000664533116, 0.006289349503276753, 0.05828631554322783, 0.049107696540886536, 0.03675101565022487, 0.041976065549533814, 0.03163833804137539, 0.03223226027330384, 0.049556844314793125, 0.0663623702712357, 0.014812049575994024, 0.028252767951926216, 0.05915916284720879, 0.0120203785263584, 0.031218638687278144, 0.010974754604831105, 0.039650460457778536, 0.037805674292030744, 0.03854496841086075, 0.03615396526583936, 0.04525330805336125, 0.015917433083814103, 0.032541335094720125, 0.042682593848439865, 0.0289143610643805, 0.09239769002306275, 0.041785545108723454, 0.0336690507538151, 0.07745881390292197, 15.467850901186466, 71.23692825436592, 64.62302595376968, 59.37049560248852, 42.52593107521534, 27.62777790427208, 16.527519039809704, 33.16789582371712, 40.49182802438736, 26.983991749584675, 0.23360849590972066, 0.017576886421011295, 0.41629019484389573, 0.7758748449850827, 4.022316914051771, 3.1305867014452815, 1.1287594749592245, 11.20274506509304, 56.542789936065674, 64.88936886191368, 69.80243682861328, 62.97343946993351, 61.22341677546501, 56.18873633444309, 54.779004380106926, 49.59522753953934, 46.40200048685074, 46.17175944149494, 52.76783689856529, 59.09369945526123, 61.62870682775974, 58.230275586247444, 57.710653468966484, 57.59938023984432, 54.10406559705734, 48.86826194822788, 50.28752759099007, 51.635581254959106, 53.852044120430946, 57.19196990132332, 58.41539025306702, 55.93753181397915, 57.47634284198284, 54.778445810079575, 52.857322096824646, 44.290674179792404, 41.73759877681732, 48.44974860548973, 58.04065056145191, 55.00779390335083, 50.49457848072052, 52.45952904224396, 58.16352836787701, 54.30375628173351, 52.19602458178997, 52.400829792022705, 52.83048413693905, 52.34076641499996, 47.25889250636101, 41.88842408359051, 42.640460729599, 42.34439581632614, 51.420900374650955, 51.06555484235287, 55.052810087800026, 53.23194399476051, 57.93134942650795, 52.37637810409069, 63.21068353950977, 32.35375910997391, 41.57404415309429, 62.238600701093674, 51.367957815527916, 51.61090537905693, 46.153068244457245, 49.3756715208292, 48.25061649084091, 47.605319917201996, 44.09474529325962, 41.21976636350155, 40.73862478137016, 41.12490825355053, 39.940390214324, 41.520657017827034, 41.713831052184105, 42.17164188623428, 40.51425442099571, 43.28525573015213, 41.10234886407852, 42.3608261346817, 42.19693712890148, 46.87779575586319, 53.157452791929245, 57.259720265865326, 54.7346455603838, 53.13339628279209, 56.6717816144228, 53.39818887412548, 46.876952201128006, 43.32114480435848, 45.098115652799606, 43.99148963391781, 45.371723771095276, 44.37835447490215, 46.34706683456898, 45.02962812781334, 49.99317638576031, 57.249969989061356, 60.48961915075779, 60.20324371755123, 59.642181023955345, 58.273581862449646, 57.03872412443161, 53.29006187617779, 50.85930570960045, 56.19383566081524, 58.803159445524216, 60.0177376717329, 63.16784083843231, 53.93284298479557, 31.819739565253258, 9.016039352864027, 1.7965593910776079, 7.571224356070161, 8.653271868824959, 0.17574684839928523, 0.373679370386526, 0.04917795937217306, 21.031381264328957, 41.10859572887421, 31.45391419529915, 23.500766158103943, 22.22394537180662, 35.63014090061188, 50.5546722561121, 48.529080748558044, 60.64018227159977, 34.91611361503601, 0.6908366549760103, 0.0639442156534642, 0.021507621495402418, 0.013940383214503527, 0.0366173771180911, 0.03773453943722416, 0.04882756918959785, 0.03512145973218139, 0.10407719455542974, 0.0020160191161266994, 0.041912389278877527, 0.05616309412289411, 0.02857341656635981, 0.06470988198998384, 0.038836910753161646, 0.01982810234039789, 0.027389099159336183, 0.02540075009164866, 0.04670478563639335, 0.025507825303066056, 0.1613251824164763, 0.13938371994299814, 0.10695341756218113, 0.14971763652283698, 0.12637437583180144, 0.11887277680216357, 0.1948616188019514, 0.1461003939039074, 0.05507090136234183, 0.243133426993154, 0.11387340287910774, 0.09704364580102265, 0.17792367143556476, 0.14685386675409973, 0.27143018203787506, 0.14033687504706904, 0.1471027237130329, 0.185225558525417, 20.56862309575081, 80.63320085406303, 71.57295942306519, 67.79882714152336, 53.518460020422935, 32.91836701333523, 23.09128873050213, 43.39144863188267, 51.7465391010046, 32.547624707221985, 0.9353706333786249, 0.3279769961955026, 0.5535713362041861, 1.3197653694078326, 7.458805488422513, 17.528467029333115, 5.147404242306948, 13.636203836649656, 58.31279195845127, 67.23373666405678, 73.28917533159256, 65.65340146422386, 62.13490806519985, 60.40596663951874, 56.73001728951931, 53.618865832686424, 48.63737113773823, 47.4634051322937, 54.47705738246441, 61.881917640566826, 63.29227276146412, 59.77498009800911, 59.23815630376339, 60.72281263768673, 56.03916496038437, 50.449296310544014, 52.32653997838497, 53.58483485877514, 55.36476194858551, 58.36319625377655, 61.08521819114685, 58.51153649389744, 59.943512454628944, 57.95433059334755, 55.43792702257633, 47.469249218702316, 41.62965416908264, 51.296096071600914, 61.75560101866722, 56.678484454751015, 50.714278891682625, 53.90821270644665, 61.16502910852432, 55.75349248945713, 53.94868053495884, 54.98552709817886, 55.39590127766132, 54.5968421548605, 51.01311765611172, 43.792688101530075, 44.79721739888191, 44.44121070206165, 54.24005649983883, 53.1391491740942, 54.76293884217739, 54.87909860908985, 60.75723119080067, 55.11010341346264, 63.95671650767326, 35.5595862865448, 43.304862678050995, 63.081045895814896, 53.68486829102039, 54.73381720483303, 48.40735048055649, 51.615290343761444, 52.1786443144083, 49.75637309253216, 47.13074058294296, 43.6989851295948, 41.28599300980568, 43.577365055680275, 43.307967111468315, 44.044952765107155, 44.121495857834816, 46.20980679988861, 43.36908683180809, 45.03093525767326, 44.36332628130913, 44.904170259833336, 45.129292979836464, 49.673370346426964, 55.969951674342155, 60.55809527635574, 55.533586889505386, 55.360084399580956, 58.751888796687126, 54.831756949424744, 49.41523499786854, 45.70256821811199, 46.63061901926994, 44.97114546597004, 47.46620178222656, 46.68019115924835, 48.64679463207722, 47.17009887099266, 51.70735560357571, 58.92596125602722, 63.91851335763931, 63.59841473400593, 62.857078313827515, 62.48887047171593, 60.46145886182785, 56.27930447459221, 53.86796146631241, 61.203749030828476, 60.96883423626423, 63.78079354763031, 63.49271200597286, 55.42166009545326, 31.448106206953526, 14.456768855452538, 8.253362327814102, 16.320479549467564, 8.856970388442278, 0.1146945299115032, 0.8574096229858696, 0.14372485340572894, 25.517249554395676, 52.05657206475735, 51.24289512634277, 33.00605110824108, 21.878650300204754, 39.529035687446594, 60.41746102273464, 56.9818639755249, 68.7212124466896, 42.647395357489586, 1.1047704122029245, 0.17422525270376354, 0.11664916877634823, 0.17960868804948404, 0.12176119329524226, 0.20632392639527097, 0.1529043889604509, 0.08064457186264917, 0.18383459566393867, 0.08477919531287625, 0.13111613545333967, 0.174579925078433, 0.1592877643997781, 0.10290888341842219, 0.11380950396414846, 0.16636801650747657, 0.12197965188533999, 0.1578905081260018, 0.1493327142088674, 0.16068887984147295], [0.07003475446254015, 0.04909840485197492, 0.1077888160943985, 0.024465972419420723, 0.026601450408634264, 0.02762889078439912, 0.0229840018437244, 0.05632829248497728, 0.07057054055621848, 0.05762863169366028, 0.08297454449348152, 0.04628164642781485, 0.09392744192155078, 0.0786913801857736, 0.06304402762907557, 0.013317223147168988, 0.03882085809891578, 0.17123082041507587, 24.7353408113122, 59.126142114400864, 56.33557565510273, 52.64773294329643, 35.251080840826035, 18.654225021600723, 25.134668983519077, 39.71163488924503, 34.93954695761204, 10.242225006222725, 0.06526509008836001, 0.034486934600863606, 0.3644755814457312, 0.9134188550524414, 2.9876179480925202, 4.719509202986956, 2.6125951716676354, 37.66467332839966, 65.29788494110107, 55.13203203678131, 60.755772069096565, 58.372726142406464, 60.655237063765526, 55.34761346876621, 53.37206527590752, 51.411123499274254, 45.7637183368206, 43.80381390452385, 47.33209937810898, 54.64766822755337, 58.35872769355774, 57.26111479103565, 56.97602368891239, 56.58470928668976, 47.627529725432396, 42.75796562433243, 45.690728053450584, 47.559665367007256, 47.81310796737671, 51.6988630592823, 51.0573510825634, 52.03095003962517, 54.96527038514614, 52.40896135568619, 47.818602472543716, 39.21069256961346, 37.937293499708176, 45.290943905711174, 52.571022659540176, 54.80287469923496, 50.92694588005543, 51.23066358268261, 56.087327376008034, 50.43146386742592, 54.92925211787224, 46.821307986974716, 51.383555978536606, 46.88305847346783, 43.16311128437519, 40.72057195007801, 41.6356198489666, 41.280304715037346, 48.92677120864391, 47.513976618647575, 51.009530648589134, 47.35319584608078, 54.76496413350105, 50.3594159334898, 59.87831935286522, 31.08212884515524, 39.38050925731659, 58.60547885298729, 48.55981729924679, 50.96214719116688, 46.16490080952644, 46.76673911511898, 45.5399901419878, 46.4142282307148, 41.71316608786583, 39.733073338866234, 38.83912570774555, 39.289549738168716, 38.556816056370735, 38.877340257167816, 38.65612372756004, 40.06038777530193, 39.96229983866215, 40.56289181113243, 39.65111933648586, 41.11342906951904, 40.23480221629143, 44.10972788929939, 48.88382591307163, 55.08937172591686, 53.22545774281025, 52.275349125266075, 54.515298530459404, 51.68360307812691, 46.415881142020226, 42.9205247014761, 43.85004602372646, 40.536475628614426, 43.43039274215698, 41.537121534347534, 44.94231641292572, 43.19430761039257, 43.02182726562023, 44.40348632633686, 51.63151927292347, 51.72598600387573, 53.89869041740894, 51.52526557445526, 48.95117349922657, 47.27122664451599, 51.162100061774254, 54.17071022093296, 57.64504238963127, 61.029406785964966, 59.07153904438019, 53.37721399962902, 48.59830163419247, 16.161940656602383, 3.132393741980195, 7.7923050429672, 3.1144836405292153, 0.3522234654519707, 0.19477686553727835, 0.0399826902867062, 3.849666053429246, 35.541377663612366, 44.203970432281494, 35.17131172120571, 15.605317074805498, 23.390446677803993, 32.13447667658329, 37.9325969517231, 46.27775855362415, 39.86011952161789, 2.5429579708725214, 0.13541986467316747, 0.05585596001765225, 0.06505255383672193, 0.011115281195088755, 0.03981991874752566, 0.01215930949911126, 0.03594670197344385, 0.08428732951870188, 0.04697748037870042, 0.013540237596316729, 0.04936443881888408, 0.04299121967051178, 0.10465985469636507, 0.012555003158922773, 0.054881375399418175, 0.01672786947892746, 0.10196254123002291, 0.017496714062872343, 0.025272974526160397, 0.08220107076340355, 0.051272734272060916, 0.010143351610167883, 0.028008881527057383, 0.02086833177600056, 0.04079940896190237, 0.05383164832892362, 0.09851504262769595, 0.03229769914469216, 0.012388376162562054, 0.06915487159858458, 0.016019018257793505, 0.03797714380198158, 0.04695200615969952, 0.041885248938342556, 0.09030557572259568, 0.06236438362975605, 0.5159576295409352, 34.04207691550255, 69.80682939291, 61.644855961203575, 58.89819994568825, 42.71938629448414, 27.631307914853096, 23.691992796957493, 32.83273100852966, 40.79500995576382, 13.902828879654408, 0.08169293709215708, 0.08298759887111373, 1.0993451345711946, 4.239077707752585, 4.641117509454489, 1.4080032845959067, 3.137720818631351, 40.66745080053806, 67.15767234563828, 58.88530343770981, 62.24078178405762, 61.35414496064186, 62.69198477268219, 57.601492926478386, 56.01087547838688, 51.831206157803535, 47.867745235562325, 46.087700352072716, 49.64266039431095, 56.85353346168995, 59.846708849072456, 58.486967012286186, 59.83655199408531, 58.605148270726204, 49.548911824822426, 44.598567858338356, 46.67547941207886, 49.108720645308495, 51.20756842195988, 53.2924747467041, 53.65929566323757, 55.49359783530235, 58.39263707399368, 54.666317626833916, 48.22606600821018, 41.65685310959816, 40.790241211652756, 46.987640261650085, 55.41046589612961, 57.45498798787594, 51.75908602774143, 53.22694346308708, 58.7003293633461, 53.09979848563671, 56.34486995637417, 50.37711538374424, 54.24104444682598, 49.57540400326252, 44.35441575944424, 42.33673922717571, 43.236390352249146, 42.10321515798569, 52.24264048039913, 48.67348439991474, 53.15960347652435, 49.37442518770695, 56.39510706067085, 52.24480636417866, 62.53562696278095, 33.080033138394356, 41.59022368490696, 60.22510014474392, 51.70010179281235, 53.21665361523628, 48.48832793533802, 48.30060660839081, 47.84498445689678, 49.69485439360142, 45.87953232228756, 42.3644245415926, 40.347306579351425, 41.67433597147465, 41.64759300649166, 40.9793646633625, 41.67364440858364, 41.44524246454239, 42.430373802781105, 42.1159178763628, 41.20533473789692, 43.08572843670845, 42.09411844611168, 46.79471701383591, 52.23447471857071, 56.53812378644943, 53.306507393717766, 53.84440653026104, 57.61020965874195, 54.605897068977356, 48.6442905664444, 45.17362520098686, 46.30311839282513, 42.35253497958183, 45.21617911756039, 43.19555774331093, 46.0446372628212, 44.7688215225935, 45.08868835866451, 47.543945610523224, 51.787865683436394, 54.89142894744873, 55.52405320107937, 53.49452130496502, 52.07159265875816, 48.62701289355755, 52.75145597755909, 57.18357615172863, 58.461960554122925, 61.828948482871056, 59.366042241454124, 54.83495257794857, 49.689800664782524, 19.439354091882706, 2.1218633791431785, 5.583012867718935, 10.81606736406684, 2.0654637180268764, 0.4454913310473785, 0.2161190882907249, 4.15955557487905, 39.645256251096725, 41.67430557310581, 30.477619282901287, 17.079074643552303, 31.99727363884449, 39.85378906130791, 44.35156591236591, 52.165801003575325, 50.22800378501415, 4.429549612104893, 0.2086358648375608, 0.042496114401728846, 0.04977075725037139, 0.016013743443181738, 0.02738432343903696, 0.011361696488165762, 0.017992708053498063, 0.03826044012384955, 0.06449475564295426, 0.06319626438198611, 0.018977454528794624, 0.054540544078918174, 0.04383065548609011, 0.07064592791721225, 0.03430393582675606, 0.01609352431842126, 0.07027895073406398, 0.044603520655073225, 0.05929260099946987, 0.18700920656556264, 0.13844549685018137, 0.16590656392509118, 0.16527008323464543, 0.09745152274263091, 0.08811740524834022, 0.10829796650796197, 0.1377144962316379, 0.1632556421100162, 0.11861746315844357, 0.17346995417028666, 0.1171612877806183, 0.18589030019938946, 0.23378055542707443, 0.1329476965474896, 0.1540331362048164, 0.15584149776259437, 0.6419700896367431, 45.7696308195591, 78.50709334015846, 72.23738417029381, 68.08318108320236, 48.20183090865612, 29.66905876994133, 36.138717010617256, 53.777807503938675, 51.122509986162186, 16.605783440172672, 0.23236519074998796, 0.3460054553579539, 0.784047256456688, 5.216765245422721, 12.191091030836105, 12.18485651537776, 5.180600685998797, 45.40561035275459, 68.13577026128769, 60.267988443374634, 65.85132524371147, 63.25042940676212, 64.92761760950089, 60.21399334073067, 58.7600963562727, 56.1005886644125, 49.96302880346775, 48.31173621118069, 52.486701384186745, 58.71310047805309, 60.2439471334219, 60.76087899506092, 62.30056017637253, 61.825011894106865, 53.120286986231804, 48.09332013130188, 49.6139757335186, 51.870796233415604, 54.138358756899834, 58.43459062278271, 55.87460719048977, 58.553543239831924, 60.68741753697395, 57.81934663653374, 51.613721027970314, 44.97503645718098, 43.081024289131165, 51.1585358530283, 57.85436175763607, 59.34488117694855, 52.70026512444019, 54.462819546461105, 61.2282083183527, 55.22453807294369, 58.63311856985092, 54.09915626049042, 55.729622170329094, 52.94294290244579, 46.679738983511925, 45.07139928638935, 45.36227747797966, 44.88719657063484, 55.07622443139553, 51.68544217944145, 55.491652339696884, 53.23160961270332, 58.7105356156826, 55.660944655537605, 63.261236026883125, 35.3740194439888, 44.04200792312622, 62.12795823812485, 55.12920878827572, 56.350372061133385, 49.95367370545864, 51.204068809747696, 50.02998121082783, 53.09996947646141, 47.69825913012028, 44.510644376277924, 43.691628724336624, 44.640019834041595, 43.73307690024376, 43.76324348151684, 44.84169401228428, 43.47353182733059, 45.54588742554188, 44.6610327064991, 43.71068850159645, 45.53683631122112, 44.597477316856384, 49.38715070486069, 53.51988114416599, 60.96690014004707, 54.988631531596184, 54.63656522333622, 59.781280159950256, 58.402603939175606, 51.347032338380814, 46.85375064611435, 48.98991622030735, 43.86120222508907, 47.76235789060593, 46.169859543442726, 49.197149500250816, 47.781246677041054, 48.16833570599556, 49.17168326675892, 54.120017141103745, 57.55001708865166, 57.294218614697456, 55.551430732011795, 53.57499718666077, 51.40963017940521, 55.150111466646194, 59.20991621911526, 61.47061251103878, 64.05883982777596, 60.86644873023033, 55.98677717149258, 51.633430570364, 22.12370105087757, 6.4150722697377205, 15.50386631861329, 10.724689867347479, 1.2256159214302897, 0.2627976390067488, 0.1893803387065418, 5.825749542564154, 47.82981567084789, 61.81082345545292, 47.506225034594536, 21.60357926040888, 34.41398195922375, 44.29110735654831, 53.506882041692734, 59.1153658926487, 60.82038760185242, 5.945495367050171, 0.29194822011049837, 0.10757952302810736, 0.17939496436156332, 0.10023223134339787, 0.14313926920294762, 0.19026045163627714, 0.1443980258773081, 0.22419096843805164, 0.13473057275405154, 0.21936837409157306, 0.10082691427669488, 0.19292741868412122, 0.2214469070895575, 0.13897602853830904, 0.16042883129557595, 0.10511778207728639, 0.16691722063114867, 0.14389805583050475, 0.13358827389311045], [0.026756182633107528, 0.02805537893436849, 0.02960731362691149, 0.05906477650569286, 0.02869165182346478, 0.006598588988708798, 0.03183001252182294, 0.011460988425824326, 0.05459321058879141, 0.06872001016745344, 0.02886343303543981, 0.009127523062488763, 0.06355650286423042, 0.01876907244877657, 0.012160393034719164, 0.03800483333179727, 0.027625361872196663, 4.55333461984992, 46.902471631765366, 56.792998909950256, 58.47177542746067, 40.132720693945885, 25.483564361929893, 12.628681249916553, 20.759642645716667, 41.94656476378441, 29.895919896662235, 4.854968609288335, 0.1347299196640961, 0.19521632086252794, 0.39243124541826546, 0.8370525122154504, 2.74380165617913, 0.10719451165641658, 22.0839798822999, 64.06341478228569, 61.08377426862717, 62.58803375065327, 58.03697235882282, 59.373159259557724, 56.53216190636158, 58.289480209350586, 54.917689338326454, 51.27974554896355, 45.01535229384899, 43.38397443294525, 44.607656970620155, 51.153003349900246, 55.93858815729618, 59.61314678192139, 54.95164051651955, 55.3465761244297, 44.79173429310322, 39.31022822856903, 41.82836450636387, 42.52492032945156, 43.88141714036465, 44.937346279621124, 47.98446737229824, 49.917036071419716, 50.70818021893501, 48.535331413149834, 42.574967443943024, 40.048479214310646, 38.916390761733055, 44.826882407069206, 52.68084056675434, 53.06138634681702, 49.81808938086033, 51.173522248864174, 52.97290049493313, 53.48556138575077, 50.85442677140236, 50.96440427005291, 51.04805678129196, 44.28851209580898, 41.91912263631821, 38.67764197289944, 39.5501359552145, 41.05437643826008, 47.0634575933218, 44.052369967103004, 48.43280911445618, 45.11588729918003, 52.19784088432789, 48.997234627604485, 62.037428095936775, 33.102147951722145, 38.82005453109741, 60.312993228435516, 48.819350972771645, 51.47609241306782, 45.30874975025654, 49.74529288709164, 45.700143948197365, 46.9720458984375, 42.77005277574062, 41.80962771177292, 39.02385279536247, 38.02421383559704, 38.57864588499069, 40.4582454264164, 39.387683272361755, 39.59649346768856, 38.75484623014927, 40.33884063363075, 38.493351861834526, 40.01409485936165, 41.31069168448448, 45.29115289449692, 48.29827353358269, 54.66636322438717, 52.84374922513962, 52.01634742319584, 54.750312119722366, 50.67879639565945, 47.510845586657524, 44.90622594952583, 42.58279122412205, 41.81196838617325, 39.6604098379612, 42.49177470803261, 41.47447429597378, 42.79871463775635, 42.481302469968796, 43.09172831475735, 40.670581832528114, 45.10679438710213, 45.407069474458694, 44.93839882314205, 42.9405952244997, 47.52381809055805, 54.32908572256565, 58.64719681441784, 57.8952893614769, 58.041357323527336, 55.26284761726856, 57.74840824306011, 54.91535246372223, 37.79946729540825, 6.720905983820558, 3.5970810195431113, 6.51980509981513, 1.626016586087644, 0.08752362773520872, 0.13092765962937847, 0.10297394750523381, 19.63317409157753, 35.776319056749344, 35.02220772206783, 26.260578967630863, 12.65162916854024, 30.611227713525295, 40.58551199734211, 43.7766719609499, 41.62070944905281, 8.043257351964712, 0.08042042099987157, 0.07787112146615982, 0.019054929180128966, 0.015360496709035942, 0.04575784601911437, 0.08697414901689626, 0.04859599685005378, 0.022030167674529366, 0.029231464068288915, 0.03729662406840362, 0.04435011062014382, 0.041029753047041595, 0.046566642267862335, 0.1135343527130317, 0.1247211082954891, 0.030961998454586137, 0.07054560439428315, 0.01340023978627869, 0.037986201714375056, 0.005964002630207688, 0.05818322752020322, 0.014065552913962165, 0.03445720787567552, 0.034273003111593425, 0.06348300055833533, 0.051507549796951935, 0.06196658876433503, 0.03608581755543128, 0.024034730813582428, 0.07852799637475982, 0.03694440078106709, 0.0454126026306767, 0.07241415412863716, 0.0130828213696077, 0.017123699508374557, 0.11201371438801289, 5.513699362054467, 58.195108473300934, 64.66439053416252, 66.46894410252571, 48.19960042834282, 33.74372452497482, 17.37959671765566, 27.229568772017956, 43.572159335017204, 34.4500458240509, 4.452518429607153, 0.1646897237515077, 0.07375857690931298, 0.8430677675642073, 3.4929917799308896, 3.6380271473899484, 1.135927909053862, 24.953483305871487, 66.71760275959969, 60.942437052726746, 62.69798845052719, 60.98260469734669, 63.45534101128578, 58.95876869559288, 61.67656145989895, 55.41342593729496, 53.24044793844223, 46.51793986558914, 44.41259823739529, 48.13249222934246, 53.439439460635185, 58.41672018170357, 60.99242717027664, 57.126263827085495, 56.8490307033062, 48.02196376025677, 41.99726924300194, 43.956105932593346, 45.88646315038204, 46.160287857055664, 47.24159583449364, 50.65584942698479, 51.96796081960201, 53.14970500767231, 51.275140196084976, 43.18826213479042, 42.03978896141052, 41.12781509757042, 47.19926230609417, 55.42322181165218, 55.85509903728962, 50.237602069973946, 54.37003992497921, 56.186844035983086, 54.20001804828644, 53.93323436379433, 52.73387432098389, 52.74349920451641, 46.49796813726425, 43.212379440665245, 40.722908824682236, 41.907681450247765, 44.186426773667336, 49.13986757397652, 46.3754703104496, 50.99558539688587, 46.96042612195015, 53.6287909001112, 50.894298031926155, 62.654583379626274, 34.75813329219818, 42.07676097750664, 62.91365347802639, 51.454334780573845, 53.06585110723972, 46.20606020092964, 50.10449521243572, 46.349114924669266, 49.3634969741106, 44.885501861572266, 42.805444076657295, 40.72936087846756, 40.97465291619301, 40.313640385866165, 43.397269919514656, 41.26056097447872, 42.928454875946045, 41.0514809936285, 41.40657193958759, 40.982890874147415, 41.883894726634026, 43.67558218538761, 46.820312440395355, 51.307233273983, 56.44500218331814, 54.741865172982216, 53.34197089076042, 56.11533187329769, 53.95734027028084, 49.22362267971039, 47.48136676847935, 45.08678086102009, 44.36970993876457, 42.809730246663094, 44.49859522283077, 43.3160150796175, 44.729828014969826, 44.509006664156914, 45.02391703426838, 43.11472088098526, 47.54124015569687, 47.84892484545708, 46.98221035301685, 45.016332641243935, 49.5978569984436, 55.667419508099556, 61.830586194992065, 59.364773109555244, 60.407326966524124, 57.3487912863493, 57.461930215358734, 56.64050929248333, 40.42271353304386, 7.550595263019204, 2.055571898818016, 11.074576042592525, 5.043860748410225, 1.4366571907885373, 0.47349125670734793, 0.15765949239721522, 21.852245517075062, 39.78575371205807, 27.36294161528349, 25.82731481641531, 20.045282877981663, 35.76636739075184, 48.279114961624146, 48.73786814510822, 51.857823729515076, 14.046086892485619, 0.15992650121916085, 0.05390132857428398, 0.02593337278085528, 0.030749783181818202, 0.03663409028376918, 0.04695941650425084, 0.07109123878763057, 0.020856377632298972, 0.04961924409144558, 0.02487286601535743, 0.04381843231385574, 0.0359648177982308, 0.07013117428869009, 0.036018601240357384, 0.017709691892378032, 0.01784637694072444, 0.060711468613590114, 0.032779122921056114, 0.03675707528600469, 0.165318560320884, 0.13760621688561514, 0.08901745968614705, 0.17239471577340737, 0.0867560986080207, 0.12599818117450923, 0.09562693783664145, 0.12582291557919234, 0.15082379279192537, 0.11170499579748139, 0.22421643894631416, 0.11770594253903255, 0.14152285672025755, 0.13094296271447092, 0.10937321232631803, 0.18268169893417507, 0.1989119639620185, 6.227250248193741, 68.54557827115059, 74.30531680583954, 74.80198815464973, 54.68827284872532, 37.78568543493748, 18.262029066681862, 31.999808102846146, 59.32865984737873, 44.54893872141838, 6.814401391893625, 0.288127139210701, 0.6199589394964278, 0.7118031580466777, 5.580580048263073, 11.400593798607588, 2.8513921704143286, 27.9249694570899, 69.97954532504082, 60.2837385982275, 63.72036539018154, 63.397812098264694, 64.3566146492958, 61.72439709305763, 62.809546664357185, 60.536083057522774, 56.66641630232334, 49.636926501989365, 46.54163159430027, 49.92953360080719, 56.16945616900921, 60.46915724873543, 63.999730199575424, 59.32364411652088, 59.77101691067219, 49.79426085948944, 43.79253230988979, 45.47371409833431, 48.25431369245052, 49.03612554073334, 49.19911399483681, 53.03245849907398, 55.1815015822649, 56.46045595407486, 52.802054062485695, 46.20260238647461, 44.77279230952263, 42.72779904305935, 50.67476861178875, 57.34822891652584, 58.014215379953384, 51.54332220554352, 55.71561612188816, 57.75987982749939, 58.71630750596523, 55.5951701849699, 54.69002455472946, 55.89647501707077, 49.757904410362244, 45.4761877655983, 42.212273105978966, 43.80974918603897, 46.40657164156437, 51.52686528861523, 49.8622278124094, 53.46601903438568, 49.4396410882473, 55.85724592208862, 54.172385931015015, 65.17400398850441, 36.588612869381905, 44.087708070874214, 64.67952892184258, 54.19109232723713, 57.10232511162758, 50.44459216296673, 53.9532744884491, 49.45347614586353, 50.77395088970661, 47.466023191809654, 45.571087673306465, 43.73802423477173, 42.90588788688183, 43.61402168869972, 45.44888623058796, 44.19431895017624, 44.984862729907036, 44.34278458356857, 44.70362842082977, 41.82423792779446, 44.1180494427681, 44.81808967888355, 49.73524622619152, 53.40550348162651, 58.858457878232, 56.777613535523415, 54.003986567258835, 58.76642681658268, 55.02586953341961, 52.0019917935133, 50.73694087564945, 47.153201177716255, 46.558734476566315, 44.48440298438072, 45.776231065392494, 45.8820553869009, 47.3170255869627, 47.93055586516857, 49.00400586426258, 44.71973955631256, 50.46076789498329, 49.77925546467304, 48.687551245093346, 47.498891428112984, 53.260731250047684, 58.45826335251331, 64.53410312533379, 60.047873854637146, 62.39822633564472, 57.52276495099068, 58.79184365272522, 57.2401475161314, 42.145909667015076, 8.922436125576496, 8.700594529509544, 11.587703358381987, 4.152908781543374, 0.6306748394854367, 0.28387409867718816, 0.1254262970178388, 27.1869008615613, 50.50886191427708, 50.119846388697624, 37.01106660068035, 18.227775804698467, 42.99573786556721, 55.30416280031204, 56.341453939676285, 60.75120851397514, 21.762327142059803, 0.12086263799574226, 0.15861983149079606, 0.1949697794043459, 0.24914028123021126, 0.09777980434591882, 0.17071384034352377, 0.20548083179164678, 0.10669115741620772, 0.1468014414422214, 0.18097429914632812, 0.1935265990323387, 0.11377836344763637, 0.1412925831391476, 0.18765812565106899, 0.18724135035881773, 0.13580527680460364, 0.11746623626095243, 0.14735143224243075, 0.13540758955059573], [0.015097386803972768, 0.03397814783966169, 0.04877380430116318, 0.03394817620574031, 0.07445321971317753, 0.1052895892644301, 0.016445675246359315, 0.030656474809802603, 0.05168234041775577, 0.005875901351828361, 0.021834402105014306, 0.08082601212663576, 0.027867090502695646, 0.025017100560944527, 0.02326857837033458, 0.06328958203084767, 0.16866500809555873, 9.693849831819534, 61.318749859929085, 59.24421697854996, 44.522564336657524, 25.70554655045271, 19.175899028778076, 22.65787448734045, 34.09435071051121, 35.395393297076225, 29.368436001241207, 1.5635045967064798, 0.17452113213948905, 0.0406391681462992, 2.533336649648845, 4.36502574943006, 1.9039764208719134, 8.505729585886002, 57.58705750107765, 65.93754261732101, 67.42862060666084, 59.126974269747734, 61.23418539762497, 57.46512584388256, 61.62022568285465, 57.162475883960724, 55.39542630314827, 51.576566621661186, 44.260275810956955, 41.768137738108635, 41.20440758764744, 45.44545501470566, 55.22203020751476, 57.36213997006416, 56.556681990623474, 53.57966713607311, 46.25887356698513, 39.427763521671295, 41.24810144305229, 40.693950578570366, 41.12231679260731, 40.46966381371021, 43.30955162644386, 43.452123776078224, 44.54701982438564, 45.34009046852589, 40.05437269806862, 37.145313397049904, 39.76107783615589, 43.24742116034031, 52.218606770038605, 49.402300491929054, 49.44670490920544, 49.681817293167114, 50.71889564394951, 50.46757332980633, 53.24572205543518, 48.31957519054413, 46.86455346643925, 39.4483508169651, 38.269110694527626, 37.71518401801586, 40.67888058722019, 41.30255252122879, 43.14455308020115, 42.42598123848438, 49.996296018362045, 45.37434183061123, 52.814247608184814, 50.38034901022911, 60.253275632858276, 35.90950571000576, 37.02511064708233, 58.926683217287064, 48.73325899243355, 50.46342775225639, 43.8631971180439, 46.03620931506157, 44.25066612660885, 46.989277973771095, 42.22556859254837, 41.525828540325165, 37.83966153860092, 39.97946731746197, 38.19922484457493, 39.5309241861105, 38.47388170659542, 39.90412496030331, 38.61950509250164, 39.13760349154472, 38.82078029215336, 41.15553840994835, 44.81497764587402, 49.837517738342285, 51.64198771119118, 53.98518517613411, 54.072082713246346, 53.63576352596283, 53.206021785736084, 51.254233717918396, 47.752056643366814, 47.00649484992027, 45.855620205402374, 42.032561749219894, 42.52326741814613, 41.44899286329746, 40.26964254677296, 42.002600356936455, 44.16713900864124, 40.68805329501629, 42.437088042497635, 42.90682263672352, 42.175046503543854, 43.8165508210659, 42.30897031724453, 46.0952315479517, 55.620571821928024, 57.444694340229034, 58.996736258268356, 60.43879687786102, 58.29621724784374, 58.97248975932598, 58.89119692146778, 55.839903652668, 22.9773423448205, 3.634235425852239, 7.2459375858306885, 7.28654220700264, 2.3817649204283953, 0.30635345494374633, 0.3654398687649518, 4.783694408833981, 31.13477312028408, 42.736018002033234, 31.906880289316177, 19.682066068053246, 22.393549270927906, 30.578408874571323, 42.33120672404766, 47.31396675109863, 23.460938595235348, 1.211392453406006, 0.08449913104414009, 0.09973668449674733, 0.04872390600212384, 0.03445672176894732, 0.06885364869958721, 0.005408080214692745, 0.031624641706002876, 0.06912106677191332, 0.05212812255194876, 0.03866126666252967, 0.06166608945932239, 0.03322264521557372, 0.02804308711347403, 0.02782486229989445, 0.019021384105144534, 0.019271909040980972, 0.033495429015601985, 0.033061209542211145, 0.03790683644183446, 0.03608821098168846, 0.04576411716698203, 0.029863708950870205, 0.03142604298773222, 0.1240111624065321, 0.05716465209843591, 0.04290734956157394, 0.05444012407679111, 0.04967573637259193, 0.04340923434938304, 0.029321304755285382, 0.04570476019580383, 0.017920365353347734, 0.024408261160715483, 0.08183974132407457, 0.035706060589291155, 14.791939370334148, 72.59179875254631, 66.02351680397987, 51.64369001984596, 32.13860705494881, 26.30045972764492, 22.262503802776337, 29.98398207128048, 38.43869559466839, 34.66426692903042, 1.364799840375781, 0.1835078577278182, 0.06317750288872048, 3.771523484028876, 4.157598679885268, 0.7533827831503004, 10.281416103243828, 59.77913327515125, 66.25994771718979, 68.04155811667442, 60.76208733022213, 62.72711768746376, 58.894278556108475, 64.09676939249039, 59.07889544963837, 60.36472745239735, 53.87377895414829, 46.58098988234997, 42.622183710336685, 44.075377732515335, 47.94606663286686, 56.47502437233925, 59.64907765388489, 60.22380441427231, 56.659215688705444, 48.183603286743164, 41.4322205632925, 43.18209506571293, 41.46264173090458, 43.81558187305927, 42.83501788973808, 45.98252199590206, 46.59488193690777, 48.71003083884716, 47.081168442964554, 43.197415843605995, 39.21670004725456, 41.9156040251255, 47.49839745461941, 54.730458185076714, 51.80029481649399, 51.349536404013634, 52.56039842963219, 54.9640316516161, 52.513045370578766, 55.11511914432049, 51.93350426852703, 49.77027654647827, 42.31221154332161, 42.56301328539848, 40.93495264649391, 43.00338685512543, 43.858356177806854, 45.99320322275162, 44.56378072500229, 51.74198314547539, 49.17305499315262, 53.997211530804634, 52.126150131225586, 63.08263801038265, 36.822646111249924, 39.44475241005421, 61.33503198623657, 52.432892471551895, 53.11174124479294, 46.01213380694389, 47.95821078121662, 44.89707604050636, 48.85223440825939, 44.58335727453232, 43.02709378302097, 39.12512496113777, 42.44238115847111, 39.80066031217575, 40.255336314439774, 40.29116079211235, 42.13648997247219, 41.2799247354269, 41.33479759097099, 40.938737243413925, 42.827764078974724, 46.22774563729763, 51.20443359017372, 53.4418523311615, 56.34380981326103, 54.93486061692238, 56.224754601716995, 55.750692039728165, 53.35030384361744, 50.02779632806778, 48.38006414473057, 45.66045127809048, 43.82436700165272, 44.02951039373875, 44.07066598534584, 42.315087988972664, 43.835811987519264, 44.416489228606224, 42.95180842280388, 45.20314581692219, 45.47999136149883, 43.70405785739422, 46.57746747136116, 43.680696710944176, 50.1860274374485, 55.50465524196625, 58.62899199128151, 61.07476495206356, 61.55962273478508, 61.62659414112568, 62.34198175370693, 59.18264888226986, 58.96490156650543, 25.623666644096375, 3.9335812255740166, 5.470786364749074, 8.34703965112567, 4.054102208465338, 0.5930103699211031, 0.2321383755770512, 4.460669467225671, 38.410060331225395, 37.08124503493309, 26.994773671031, 18.879060856997967, 30.433779135346413, 35.395469292998314, 48.14447298645973, 52.59035222232342, 38.29041615128517, 2.073226938955486, 0.1148184685735032, 0.05496772057085764, 0.06655049728578888, 0.03412635101994965, 0.09205126290908083, 0.022199958075361792, 0.07244909444125369, 0.08503066463163123, 0.01808407385397004, 0.012000174483546289, 0.025967075562220998, 0.0448411118122749, 0.030730463222425897, 0.007024118376648403, 0.04284471971914172, 0.028214469421072863, 0.10793100416776724, 0.06329806477879174, 0.17352561524603516, 0.09941399868694134, 0.22950667538680136, 0.11105264798970893, 0.14933553437003866, 0.2235798246692866, 0.10260495910188183, 0.16636107000522316, 0.18067073106067255, 0.08055348065681756, 0.1500477289664559, 0.1656035301857628, 0.17380003177095205, 0.10853604748263024, 0.0839385275321547, 0.26638547773472965, 0.26703064155299217, 18.194603584706783, 85.7281194627285, 74.64041322469711, 60.73668569326401, 39.541316628456116, 29.61073949933052, 33.33121106028557, 46.92155420780182, 49.36217464506626, 40.74505403637886, 2.176359104923904, 0.32954815251287073, 0.370766143896617, 5.045792469754815, 10.733033269643784, 9.247059356421232, 10.918519366532564, 65.11861056089401, 67.43045970797539, 71.00346118211746, 60.993646904826164, 64.16524171829224, 60.38403421640396, 68.1661306321621, 60.525021851062775, 62.664333656430244, 56.037196666002274, 49.10617098212242, 46.148060113191605, 46.34873874485493, 49.465715289115906, 58.48293922841549, 62.186885476112366, 63.04774448275566, 58.36438179016113, 51.55149556696415, 43.47750261425972, 45.78092381358147, 43.93353894352913, 46.631340980529785, 45.41352152824402, 47.75188945233822, 48.424533158540726, 48.79579983651638, 50.02363175153732, 45.78820802271366, 41.232643872499466, 45.14179430902004, 49.37423899769783, 58.16031754016876, 52.88406126201153, 53.336529582738876, 57.4454391002655, 58.30523796379566, 56.60020485520363, 59.04100388288498, 53.98024924099445, 52.0224004983902, 43.30061450600624, 43.54875639081001, 42.407993003726006, 45.32778672873974, 46.28802180290222, 46.774650290608406, 47.72864609956741, 54.516962841153145, 49.14555586874485, 56.25486418604851, 57.29569673538208, 66.33911266922951, 40.70012144744396, 43.01854804158211, 64.30663213133812, 56.6781310737133, 55.5767335742712, 49.117004200816154, 50.17345771193504, 48.49365904927254, 51.27431944012642, 47.22568228840828, 44.95523191988468, 41.38999342918396, 44.00630883872509, 42.618786692619324, 42.84474156796932, 41.31202541291714, 45.19530303776264, 42.89348915219307, 42.810459807515144, 43.67897920310497, 45.36764279007912, 49.50344726443291, 54.20964673161507, 55.72274073958397, 57.33062066137791, 55.80596387386322, 59.04154345393181, 59.02912572026253, 56.09151475131512, 53.04969057440758, 51.81639075279236, 49.73743110895157, 46.05857491493225, 46.44996531307697, 45.31264454126358, 44.89816278219223, 45.85876263678074, 46.870811730623245, 44.02409948408604, 47.153869941830635, 48.16146567463875, 46.97848655283451, 47.90935680270195, 46.47972531616688, 51.24091923236847, 59.59453538060188, 61.168289333581924, 64.05704632401466, 64.90700751543045, 63.60882617533207, 64.28100630640984, 62.78707467019558, 59.2095248401165, 28.23912899941206, 6.675145989283919, 16.64892442524433, 17.07492906600237, 4.673063820227981, 0.6418903532903641, 0.5238674988504499, 6.062498213723302, 44.72323916852474, 59.64885726571083, 44.13320302963257, 28.55748161673546, 34.61483918130398, 41.795458272099495, 57.13155314326286, 59.329708591103554, 49.253177493810654, 3.476930041797459, 0.20476489677093923, 0.2276542005711235, 0.13878684025257826, 0.08961839150288142, 0.180865173751954, 0.08724432045710273, 0.11628494496108033, 0.16401309287175536, 0.17992399691138417, 0.11648326908471063, 0.20189752016449347, 0.21416007075458765, 0.07272070564795285, 0.13511022581951693, 0.1167336548678577, 0.07970903534442186, 0.25330925127491355, 0.0888446431781631], [0.04500077375269029, 0.06302511028479785, 0.026120195470866747, 0.060553357761818916, 0.07047079590847716, 0.038468044804176316, 0.06600580541999079, 0.024539944133721292, 0.03744862704479601, 0.039322954398812726, 0.011375139565643622, 0.05075874134490732, 0.031208037107717246, 0.04708381158707198, 0.05450017124530859, 0.04508431731665041, 0.06109189351263922, 19.614657685160637, 62.345827147364616, 46.018008291721344, 43.29631693661213, 29.793196208775043, 20.381545834243298, 29.272124469280243, 43.83302293717861, 44.39507357776165, 19.747458659112453, 0.020521301667031366, 0.02960710768093122, 0.06103431398514658, 1.0957442340441048, 2.7217326778918505, 0.8487672242335975, 34.491482600569725, 66.32060006260872, 62.587638571858406, 63.07191498577595, 63.711321875452995, 61.82533107697964, 57.45345667004585, 59.44995693862438, 58.863614201545715, 58.11459079384804, 54.10944610834122, 51.05502940714359, 42.691890969872475, 42.618334516882896, 40.03531292080879, 47.81693436205387, 52.20457412302494, 54.4727598130703, 49.53906275331974, 42.28877440094948, 39.81751620769501, 40.556481555104256, 40.84460109472275, 39.595801904797554, 39.46518391370773, 39.81411539018154, 40.11780649423599, 42.50029385089874, 41.27568036317825, 41.46782085299492, 38.78667712211609, 39.67245899140835, 40.59074051678181, 50.29606573283672, 52.9691918939352, 52.69983574748039, 50.860635638237, 51.939663738012314, 52.8807782381773, 51.74091920256615, 44.82883170247078, 42.91934676468372, 38.43502499163151, 40.06106033921242, 37.78434790670872, 42.14679881930351, 40.31090073287487, 44.3722178041935, 43.6349281668663, 50.23949436843395, 48.68525616824627, 53.80333453416824, 47.84589260816574, 63.897249698638916, 36.36313296854496, 37.10026301443577, 61.03519007563591, 47.8081264346838, 49.74017456173897, 40.99866762757301, 44.18584540486336, 40.042999908328056, 43.84631462395191, 42.17442333698273, 40.69790616631508, 38.42707961797714, 39.21571210026741, 38.168385699391365, 40.98494656383991, 39.80837769806385, 39.33295860886574, 39.237059354782104, 40.702397525310516, 39.33877609670162, 42.214442789554596, 49.71663482487202, 51.51524171233177, 51.72138825058937, 54.32489454746246, 53.212865218520164, 58.06129105389118, 53.82530115544796, 49.40718322992325, 49.39054012298584, 45.65051481127739, 43.94374139606953, 40.2892304956913, 43.615465611219406, 42.10467807948589, 41.72179162502289, 41.34071387350559, 45.61505891382694, 44.39351946115494, 47.119310796260834, 43.882040306925774, 43.53149391710758, 42.51763992011547, 43.87911446392536, 42.36709579825401, 50.30405290424824, 56.62826254963875, 58.34773488342762, 57.88207367062569, 58.27978692948818, 57.24294796586037, 60.19646108150482, 60.40433272719383, 50.80796666443348, 13.491354659199715, 8.654680643230677, 6.178400544449687, 5.663252687081695, 0.24844098516041413, 0.0848469756601844, 0.07605914564919658, 18.61669823527336, 32.84391760826111, 44.23950232565403, 26.19387924671173, 17.185288444161415, 37.261404767632484, 42.79621057212353, 48.62930417060852, 44.10271346569061, 4.776164162904024, 0.21958693658234552, 0.0681881648779381, 0.047052214649738744, 0.08985291016870178, 0.09225278568919748, 0.05567189626162872, 0.046767938692937605, 0.09002517748740502, 0.08478292089421302, 0.012859338439739076, 0.005719261343983817, 0.036604233682737686, 0.045125539909349754, 0.03064066891965922, 0.019672670641739387, 0.03199183782271575, 0.04758343653520569, 0.051667041043401696, 0.005198460139581584, 0.020608069862646516, 0.024195329715439584, 0.057266092553618364, 0.062198290979722515, 0.03282177043729462, 0.05977817709208466, 0.03345333811012097, 0.029121895240677986, 0.019591487107391004, 0.023017608145892154, 0.011326027943141526, 0.035911821032641456, 0.029725240892730653, 0.06819110378273763, 0.0482860351621639, 0.04459844436496496, 30.41717402637005, 70.41797339916229, 54.42983351647854, 50.50087854266167, 37.650762274861336, 24.04214210808277, 29.806694984436035, 36.25527575612068, 49.341237768530846, 20.336951427161694, 0.05651267907524016, 0.07461629182216711, 0.3929401212371886, 3.4346266742795706, 2.942498931661248, 2.259373962879181, 35.673333182930946, 69.04760733246803, 64.95955109596252, 64.4518755376339, 64.65495184063911, 64.88395035266876, 58.28877344727516, 62.11669184267521, 59.81860935688019, 60.160997584462166, 57.503511384129524, 53.008022010326385, 45.39773337543011, 44.525471180677414, 42.72588014602661, 52.276918441057205, 54.65898782014847, 57.71148182451725, 52.655693516135216, 44.428040608763695, 41.34454786777496, 41.17802560329437, 42.964959517121315, 42.032725140452385, 42.33630605041981, 41.059509962797165, 42.453723549842834, 45.05606710910797, 43.903771340847015, 42.227742075920105, 41.422462686896324, 40.8587971329689, 43.175567016005516, 52.65195071697235, 55.008888244628906, 55.632757768034935, 52.58147589862347, 54.98464174568653, 53.91465716063976, 53.434438928961754, 47.88768656551838, 44.986698031425476, 40.626428201794624, 41.92600406706333, 40.29241852462292, 43.767864033579826, 42.4862802028656, 46.79187096655369, 45.30088037252426, 51.96676388382912, 50.717307329177856, 56.75527073442936, 51.24175138771534, 63.19339066743851, 37.28180207312107, 38.010747358202934, 61.803094670176506, 49.925232231616974, 50.758390724658966, 43.18029776215553, 45.82890383899212, 43.07330310344696, 45.87360844016075, 44.2718043923378, 43.738313019275665, 40.04272632300854, 40.9383724629879, 41.14866837859154, 42.87365421652794, 41.42542652785778, 41.04423478245735, 41.67474254965782, 43.10942396521568, 42.537847235798836, 44.363839253783226, 51.2854490429163, 53.36641117930412, 54.61582213640213, 57.455808743834496, 54.47204165160656, 57.44434855878353, 55.248632580041885, 52.554497346282005, 50.59652701020241, 48.68164636194706, 46.60578355193138, 42.51493826508522, 45.43078400194645, 43.2147429138422, 43.019695580005646, 42.76164762675762, 47.029194831848145, 46.69786021113396, 49.70740891993046, 45.2907957136631, 45.91345690190792, 44.65429946780205, 45.852918550372124, 45.122210159897804, 51.92280784249306, 59.3978351354599, 60.252865254879, 58.97662773728371, 60.55901862680912, 58.83291944861412, 60.37797354161739, 60.46936243772507, 57.44504772126675, 13.332181200385094, 1.2784137320704758, 7.463990310207009, 8.11461467295885, 0.7996569969691336, 0.09838624289841391, 0.2516851056134328, 22.007676176726818, 38.278028815984726, 36.79654911160469, 29.340847581624985, 25.16260888427496, 42.29695916175842, 51.258109509944916, 53.256471678614616, 56.000247448682785, 10.515214707702398, 0.22522246465086937, 0.06996833224548027, 0.012512449338828446, 0.05544204941543285, 0.06403020088328049, 0.07888893247582018, 0.000949673503782833, 0.034951081179315224, 0.01954262967046816, 0.008168240601662546, 0.05148633550561499, 0.06435005911043845, 0.025036949300556444, 0.01215419702930376, 0.037055437205708586, 0.01432872033547028, 0.008365614776266739, 0.06550147896632552, 0.14276647358201444, 0.13047966960584745, 0.19875952682923526, 0.1660656655440107, 0.15253349323756993, 0.0975414487766102, 0.17313147545792162, 0.08395164870307781, 0.1259444942115806, 0.1741991884773597, 0.08630669850390404, 0.20440770109416917, 0.11494049991597421, 0.12054155522491783, 0.14041756134247407, 0.10377247614087537, 0.34438436734490097, 39.37686525285244, 79.90867093205452, 61.7281398922205, 58.46978433430195, 42.784537598490715, 29.43076405674219, 40.38337804377079, 58.497823029756546, 61.680691838264465, 24.75700154900551, 0.14894293824909255, 0.34017950703855604, 1.1819789442233741, 5.627617724239826, 9.979573599994183, 2.8502527065575123, 39.13045987486839, 70.88383600115776, 67.41593688726425, 66.94363743066788, 67.64437302947044, 64.79991406202316, 60.792679488658905, 63.18156950175762, 63.64261016249657, 64.79413837194443, 60.11905923485756, 56.4825289696455, 48.083094879984856, 47.95168273150921, 45.84968872368336, 54.47584144771099, 57.432831376791, 60.05393072962761, 54.76447016000748, 46.67167581617832, 44.35925669968128, 43.850604593753815, 45.518015921115875, 44.36988852918148, 44.28181305527687, 44.188406467437744, 44.40116845071316, 47.50811353325844, 45.981237664818764, 45.302624478936195, 43.387158662080765, 43.58299635350704, 45.1299237459898, 55.25575339794159, 58.7503232806921, 56.760069876909256, 55.3168161213398, 57.01996833086014, 57.671610563993454, 55.935343131423, 49.53387223184109, 46.86025969684124, 42.834402322769165, 45.2412311732769, 42.125671952962875, 45.56353747844696, 45.82530543208122, 49.68913570046425, 48.262954428792, 55.79096607863903, 54.360346645116806, 58.074765130877495, 51.96929834783077, 62.97346606850624, 39.95494343340397, 42.20373876392841, 63.907471150159836, 52.64368616044521, 53.975096717476845, 45.51290899515152, 48.826699778437614, 44.48924772441387, 49.19022627174854, 47.43580721318722, 44.846090376377106, 43.39678734540939, 42.817930206656456, 44.89541552960873, 45.1397006213665, 44.233282059431076, 43.012327775359154, 43.949460089206696, 45.70256441831589, 44.09628801047802, 46.51947118341923, 55.05423501133919, 55.32931365072727, 56.40369459986687, 58.03580962121487, 55.89482590556145, 60.435247868299484, 59.8938263207674, 53.93376253545284, 54.237335845828056, 50.52178122103214, 49.4037140160799, 44.49884980916977, 49.16680432856083, 45.892888605594635, 45.540191531181335, 45.034290477633476, 50.571767538785934, 48.88074427843094, 52.2859163582325, 47.62203522026539, 49.679381623864174, 46.06932833790779, 48.439435958862305, 47.25860372185707, 56.320737451314926, 61.43189638853073, 63.63105118274689, 62.50330209732056, 64.57049757242203, 61.312894374132156, 63.82656589150429, 62.475449591875076, 57.48624511063099, 15.24680346250534, 15.306689199060202, 15.846181400120258, 12.803981993347406, 0.8231249533127993, 0.3295110451290384, 0.36580930987838656, 27.72768784314394, 47.52708971500397, 60.769329741597176, 36.65572106838226, 27.85677071660757, 49.20636020600796, 57.77113862335682, 60.96757270395756, 64.01838719844818, 15.740885250270367, 0.5811355914920568, 0.17587808979442343, 0.14008476748131216, 0.15242334367940202, 0.21720544405980036, 0.12322824855800718, 0.12497940537286922, 0.22116999694844708, 0.23222087271278724, 0.10390861571067944, 0.10552145104156807, 0.16102305409731343, 0.16307589394273236, 0.06470638647442684, 0.1219692024460528, 0.20719111111247912, 0.13726754521485418, 0.1542291374062188], [0.09396086083143018, 0.02271992158057401, 0.06476604772615246, 0.021700574325222988, 0.04038671177113429, 0.06159789350931533, 0.020792128052562475, 0.022389702971850056, 0.03893113011145033, 0.0303733640248538, 0.008621261458756635, 0.03152367251459509, 0.007076669853631756, 0.0338560868112836, 0.054538673866773024, 0.0577246804459719, 0.6515182054135948, 40.91678962111473, 59.56210032105446, 49.932265654206276, 33.74137245118618, 22.977621629834175, 23.596123941242695, 33.012134581804276, 39.910007044672966, 39.801332876086235, 11.1000014282763, 0.16509964159922674, 0.07962616713484749, 0.2855034393724054, 3.0113255884498358, 3.6173619562759995, 10.783258024603128, 51.80254429578781, 66.65112912654877, 61.415941044688225, 60.064372569322586, 59.0941022336483, 63.08649480342865, 60.49633339047432, 56.91356264054775, 57.503032609820366, 60.55915541946888, 55.69742649793625, 56.23781830072403, 47.75111809372902, 41.92834094166756, 42.06334389746189, 41.05812303721905, 42.45667979121208, 43.77417169511318, 40.81845469772816, 41.455030739307404, 41.223999336361885, 39.93754796683788, 39.64971341192722, 41.09830588102341, 39.366184026002884, 39.62591528892517, 41.61828897893429, 41.01707763969898, 38.755769580602646, 41.11413203179836, 37.98613987863064, 39.73442226648331, 39.578927010297775, 45.535525381565094, 51.54010757803917, 52.89111748337746, 49.96351897716522, 48.35061952471733, 45.301416143774986, 43.08658339083195, 39.53782461583614, 40.19443318247795, 39.21011120080948, 41.89223527908325, 38.52967791259289, 42.50297650694847, 38.70053194463253, 45.42307801544666, 44.5519557595253, 52.928598672151566, 48.226856365799904, 55.63102886080742, 49.56649348139763, 59.053349420428276, 32.73597680032253, 35.541411861777306, 59.10669095814228, 49.715354293584824, 50.62782973051071, 42.35875144600868, 42.99473851919174, 40.67984573543072, 40.287528187036514, 42.252463549375534, 41.635144874453545, 38.23321782052517, 38.96654047071934, 38.602744191884995, 40.48516318202019, 39.64422270655632, 39.92318473756313, 39.800021946430206, 41.11884757876396, 40.733909234404564, 44.620511680841446, 50.21343916654587, 53.17652776837349, 54.269269332289696, 54.59508664906025, 54.47378195822239, 54.96864080429077, 52.36074574291706, 52.48558424413204, 48.62975634634495, 47.359210923314095, 42.527694180607796, 40.6179204583168, 42.60930620133877, 41.30483239889145, 40.47092914581299, 42.51847207546234, 48.50723572075367, 51.583562046289444, 50.76398782432079, 47.78021693229675, 43.46630461513996, 42.14023657143116, 43.120899349451065, 43.15310642123222, 43.50393019616604, 46.644176691770554, 50.80353610217571, 53.92167158424854, 56.66922815144062, 56.08212925493717, 58.09938780963421, 59.14794534444809, 62.5019683688879, 33.645378202199936, 4.631883054971695, 6.652635997161269, 5.411591716110706, 1.1397516913712025, 0.4540092567913234, 0.09044418664416298, 6.732914289459586, 28.661170452833176, 32.82471723854542, 23.153360299766064, 16.369014345109463, 28.41731283813715, 37.86267690360546, 49.68054436147213, 48.406962901353836, 22.09858249872923, 0.3309663670370355, 0.02391905967670027, 0.037930945109110326, 0.01311285886913538, 0.02030290059337858, 0.013700000654353062, 0.009555924098094692, 0.11113798755104654, 0.08364494875422679, 0.013275417040858883, 0.02921935036283685, 0.012002990933979163, 0.009922569170157658, 0.03637809757492505, 0.00927982011489803, 0.029643543421116192, 0.05909267383685801, 0.07952026266139, 0.060116073218523525, 0.05581983226875309, 0.03795920238189865, 0.05799471829959657, 0.065700560080586, 0.03521049889968708, 0.0763161365466658, 0.025868894990708213, 0.09410200989805162, 0.058333152483101, 0.03399480163352564, 0.005908708453716827, 0.06540212023537606, 0.006641309328188072, 0.051538994594011456, 0.04245427582645789, 1.5465582185424864, 50.69275684654713, 68.3854928612709, 57.28091932833195, 40.76869256794453, 28.97134590893984, 29.891375340521336, 31.48268435150385, 37.56588622927666, 47.481640353798866, 11.617507059127092, 0.07278764736838639, 0.18879551149439067, 1.009960393421352, 4.720632042735815, 3.0360613111406565, 11.517071798443794, 56.089318469166756, 66.26181721687317, 64.91037413477898, 62.11653985083103, 61.97531282901764, 65.05358844995499, 60.81870049238205, 57.25178249180317, 59.25206355750561, 62.6268220692873, 59.79498602449894, 58.7987706810236, 49.42901685833931, 43.0611627548933, 43.942977637052536, 43.044975623488426, 44.934732019901276, 45.862566232681274, 42.8511518239975, 44.258809089660645, 42.619972229003906, 41.82203784584999, 41.95075213909149, 42.451956644654274, 41.12155303359032, 41.99829898774624, 43.24128068983555, 44.050587862730026, 40.29916316270828, 42.94918276369572, 40.22460736334324, 41.64695464074612, 41.3274297863245, 49.459042847156525, 53.393887504935265, 54.38251465559006, 52.35680915415287, 51.66810750961304, 46.95656172931194, 47.4494256824255, 42.46892653405666, 42.43222810328007, 40.26391625404358, 42.781030386686325, 41.76318660378456, 44.43677254021168, 42.73289076983929, 46.99093088507652, 45.22428408265114, 55.01054875552654, 51.89870573580265, 57.081209644675255, 50.76293148100376, 59.44282852113247, 34.86512415111065, 37.60460615158081, 61.99032582342625, 51.50217421352863, 52.584090158343315, 44.82112191617489, 44.18137304484844, 41.669650822877884, 41.61550372838974, 43.58823627233505, 43.480466455221176, 41.34081646800041, 40.46967141330242, 40.91129891574383, 40.436924770474434, 40.968390852212906, 43.47555711865425, 42.270702570676804, 42.09848441183567, 42.64722436666489, 47.32134975492954, 52.25960277020931, 56.05206906795502, 56.49166747927666, 57.34269641339779, 55.17861373722553, 54.57761898636818, 54.38881851732731, 54.45128716528416, 51.061565056443214, 48.98809231817722, 45.95603361725807, 43.161777555942535, 44.5859981328249, 42.87626467645168, 42.41512142121792, 44.64415401220322, 50.62205024063587, 54.94267299771309, 52.419995963573456, 48.921842873096466, 45.32719016075134, 42.225409001111984, 44.87409867346287, 44.859116077423096, 46.394005715847015, 48.390566781163216, 53.811507895588875, 55.35589322447777, 58.78124222159386, 57.4120768904686, 61.4343548566103, 61.062806993722916, 63.66591051220894, 37.68900342285633, 3.1926898565143347, 4.141013519838452, 8.702243641018867, 2.424087286926806, 0.4663517663720995, 0.21720707678468898, 5.87239108979702, 35.02730704843998, 35.36783717572689, 23.904264606535435, 23.43983642756939, 34.988894909620285, 43.36532883346081, 55.56759126484394, 55.7859693467617, 36.468569710850716, 1.3274661311879754, 0.09712897051940672, 0.025384231739735696, 0.08345070644281805, 0.02573968522483483, 0.05480981009895913, 0.04526794691628311, 0.003187524271197617, 0.04119071003515273, 0.02294431735208491, 0.05473888304550201, 0.06789863080484793, 0.047173822968034074, 0.011088148276030552, 0.02751794527284801, 0.04726863233372569, 0.03338728325616103, 0.04214799148030579, 0.1286531551158987, 0.11465340008726344, 0.14626813412178308, 0.22678159817587584, 0.15743101481348276, 0.12798450974514708, 0.22289151238510385, 0.09897863259539008, 0.3195559058804065, 0.14848181221168488, 0.15051681082695723, 0.12622055830433965, 0.17803698254283518, 0.1025344773370307, 0.11992513478617184, 0.18700408574659377, 2.467827689833939, 63.42026889324188, 75.27626350522041, 65.73324277997017, 47.53867149353027, 34.14946675300598, 33.48851881921291, 45.021899342536926, 53.98547776043415, 54.03831012547016, 13.989339787513018, 0.3544519271235913, 0.2517589641502127, 0.5399579729419202, 11.261350270360708, 7.7769989892840385, 13.29265097156167, 56.424779668450356, 69.11469653248787, 67.87199601531029, 64.85956326127052, 65.84065541625023, 67.30202659964561, 62.597860023379326, 58.63822549581528, 61.28419451415539, 64.81249138712883, 61.330396234989166, 59.84405659139156, 53.01872983574867, 46.54004707932472, 46.22512757778168, 46.01777270436287, 46.196860894560814, 48.1554239988327, 44.64070379734039, 46.07946239411831, 44.60648663341999, 43.861692398786545, 44.99698027968407, 45.78452982008457, 44.98893231153488, 43.89472782611847, 46.25573493540287, 46.181699708104134, 43.23433846235275, 46.09280347824097, 42.54831187427044, 43.93969841301441, 43.45685452222824, 50.315368697047234, 57.532469630241394, 57.163479030132294, 55.5850475281477, 53.973922580480576, 49.826730117201805, 49.694577008485794, 44.246341958642006, 43.48947197198868, 43.455486595630646, 45.81864058971405, 44.46503542363644, 47.574283182621, 45.0051574409008, 49.671690836548805, 49.28215093910694, 57.07613691687584, 51.026295349001884, 58.69783289730549, 52.47493341565132, 60.081274062395096, 36.2956827878952, 41.76506370306015, 64.42009404301643, 53.56660343706608, 56.08434833586216, 48.634521290659904, 46.830628886818886, 44.967995434999466, 44.9701689183712, 46.419483348727226, 45.49808979034424, 42.277701795101166, 42.85505801439285, 42.68875613808632, 42.54204601049423, 43.612532168626785, 45.635315626859665, 43.98969613015652, 45.51833510398865, 44.50384274125099, 49.018106907606125, 54.842844754457474, 59.53685827553272, 57.3758078366518, 58.05802322924137, 56.5567047894001, 57.396425530314445, 58.733870163559914, 56.1686772108078, 53.98755244910717, 51.961128786206245, 47.97325037419796, 44.19167809188366, 47.39512659609318, 45.982540994882584, 44.27058085799217, 47.54799619317055, 53.883814215660095, 57.04036943614483, 55.473052337765694, 52.47121341526508, 47.66781136393547, 45.02397783100605, 47.033534198999405, 48.73526908457279, 48.03620159626007, 49.36040014028549, 56.53849996626377, 59.81683865189552, 61.17388263344765, 61.09900005161762, 63.87818992137909, 65.33386141061783, 66.05333760380745, 39.249879866838455, 5.30403658747673, 14.416867196559906, 13.617784325033426, 1.7092348518781364, 1.265862649306655, 0.4248221026500687, 9.701097942888737, 44.36392284929752, 48.85936662554741, 31.850103735923767, 25.12373887002468, 38.02198335528374, 52.15509697794914, 61.289020255208015, 62.80280202627182, 42.93864592909813, 2.136167474091053, 0.2612035651691258, 0.15092938556335866, 0.12685030029388145, 0.11880317077157088, 0.11832661548396572, 0.2299970420426689, 0.28431950602680445, 0.1275917948805727, 0.11805055881268345, 0.15024006395833567, 0.15753975429106504, 0.08641160849947482, 0.10947920585749671, 0.1218579470878467, 0.19475132081424817, 0.13667491060914472, 0.12712982279481366], [0.05766986170783639, 0.0215467326779617, 0.022338930793921463, 0.010614672901283484, 0.0298114561883267, 0.05196167367103044, 0.0385492283385247, 0.013753817493125098, 0.0269664423467475, 0.0796839952818118, 0.027933546116400976, 0.034722644413704984, 0.010463677390362136, 0.07001309117185883, 0.048569357459200546, 0.09852624163613655, 4.0700072050094604, 44.802810698747635, 54.1057413071394, 41.51238486170769, 27.357468008995056, 17.343559451401234, 22.62490175664425, 39.85625132918358, 39.37030300498009, 43.07989574968815, 2.3029334004968405, 0.15826855815248564, 0.32014338998124003, 0.3583707637153566, 2.2964837215840816, 1.668402599170804, 23.528352677822113, 61.0234335064888, 64.21123445034027, 58.55678826570511, 57.617391273379326, 57.481301575899124, 59.89147424697876, 61.1772720515728, 59.699934124946594, 59.42357875406742, 58.245223984122276, 58.5352586209774, 58.177291229367256, 53.97074595093727, 45.055975914001465, 40.54327726364136, 41.3300022482872, 41.742625907063484, 42.84485936164856, 40.88641785085201, 41.00710317492485, 39.423355758190155, 42.5864352285862, 39.150355607271194, 40.86092121899128, 41.906575709581375, 39.551142901182175, 41.008265912532806, 39.71281662583351, 39.418374225497246, 40.22882893681526, 40.88578328490257, 40.05458168685436, 38.35931785404682, 39.90999944508076, 40.945588275790215, 43.37454333901405, 42.2491767257452, 38.54467190802097, 38.881763219833374, 39.07479666173458, 39.556287825107574, 39.69109319150448, 38.67901749908924, 40.49368232488632, 39.10648316144943, 41.3687601685524, 39.42992560565472, 43.97105433046818, 45.5586851388216, 50.89118979871273, 50.27091488242149, 57.288180738687515, 51.4699899405241, 57.9855041205883, 32.06960655748844, 33.01022708415985, 61.32197208702564, 50.20341530442238, 52.5859634578228, 46.654493138194084, 47.773631885647774, 40.17564319074154, 43.04652974009514, 39.116560220718384, 39.43727821111679, 38.825374245643616, 39.581773057579994, 38.07744897902012, 40.20797185599804, 39.15873795747757, 38.9057969301939, 39.81827236711979, 42.00908660888672, 39.50017623603344, 46.308476105332375, 49.5223930478096, 55.643476992845535, 53.40431794524193, 53.88761021196842, 51.41924366354942, 52.15945154428482, 54.33657132089138, 53.36996018886566, 46.28355324268341, 43.18223565816879, 40.605677515268326, 43.123061433434486, 39.547662287950516, 42.671877443790436, 40.41153073310852, 45.677497163414955, 51.57424494624138, 56.36638440191746, 55.674449130892754, 54.19506311416626, 49.396247416734695, 43.555284440517426, 41.91975720226765, 41.39683686196804, 42.345539554953575, 42.53145597875118, 42.84700244665146, 45.764998868107796, 48.64597387611866, 53.0512560904026, 55.57470068335533, 56.96742855012417, 59.17721517384052, 61.110243648290634, 11.624952759593725, 3.4056330425664783, 7.10127554833889, 1.5307919145561755, 0.04291110111807939, 0.05830957445141394, 1.1424798262305558, 21.62758257240057, 35.82261957228184, 31.745852530002594, 18.986678682267666, 34.11757506430149, 42.777059599757195, 48.72854344546795, 49.586795791983604, 51.116171926259995, 7.287522554397583, 0.1555148043553345, 0.07116406573913991, 0.049319824611302465, 0.03015502603375353, 0.04780580995429773, 0.028271839291846845, 0.01749379556713393, 0.05577901043579914, 0.08581444679293782, 0.054118410480441526, 0.07189082127297297, 0.05064814649813343, 0.013844782533851685, 0.03187627800798509, 0.02950623311335221, 0.03135659280815162, 0.08983272375189699, 0.07508050519390963, 0.05503362699528225, 0.021293832869559992, 0.029511348366213497, 0.04311965203669388, 0.030961401025706436, 0.051458697926136665, 0.050945020411745645, 0.051232684272690676, 0.03591742795833852, 0.007943777109176153, 0.03872444940498099, 0.04296535953471903, 0.00917686660613981, 0.016477439166919794, 0.03707589450641535, 6.707902131602168, 56.67523942887783, 60.118789449334145, 50.13634890317917, 32.477480471134186, 20.42661901563406, 23.23469303548336, 31.773792430758476, 41.95833273231983, 48.727707490324974, 2.1377560263499618, 0.2473389552324079, 0.41793330979999155, 3.929173699580133, 9.555175323039293, 3.1920780893415213, 26.92536659538746, 63.61775949597359, 66.53924033045769, 60.568670108914375, 59.58975523710251, 59.22871761023998, 61.76812134683132, 63.536307066679, 62.33979307115078, 58.86276684701443, 59.506649896502495, 59.751067981123924, 60.00309705734253, 57.01778344810009, 47.61273331940174, 42.83578164875507, 43.94504852592945, 44.130018800497055, 45.31336270272732, 43.55446368455887, 43.951439782977104, 41.6948776692152, 43.926041945815086, 42.5128635764122, 43.51923957467079, 43.69510933756828, 41.54564827680588, 42.38052807748318, 42.6378882676363, 41.19067132472992, 41.8558332324028, 42.10117846727371, 42.533070892095566, 41.70906990766525, 42.55585826933384, 43.80967319011688, 45.75150579214096, 45.043379589915276, 42.49244727194309, 41.07039637863636, 41.2144960463047, 40.29524937272072, 42.083232030272484, 41.30477920174599, 41.83811478316784, 39.22108121216297, 42.7680578827858, 40.996619537472725, 46.48232437670231, 47.60728441178799, 53.01149882376194, 52.69853241741657, 57.79416538774967, 52.55643144249916, 58.56591537594795, 32.96702720224857, 35.60799948871136, 61.974032297730446, 52.014295533299446, 53.799006566405296, 48.51868450641632, 47.926357090473175, 41.91120386123657, 45.72692111134529, 40.76888255774975, 41.5837412327528, 40.359336733818054, 41.21496342122555, 40.52848845720291, 41.41308479011059, 41.41227163374424, 41.80557332932949, 42.43127055466175, 44.75388452410698, 40.93643456697464, 49.16941478848457, 51.53742112219334, 57.01315149664879, 55.178454145789146, 55.82036130130291, 54.70002941787243, 54.527108296751976, 56.61598540842533, 56.20339974761009, 49.42834809422493, 44.60748977959156, 43.05111989378929, 44.2578249424696, 41.10602706670761, 45.275113955140114, 42.38647095859051, 47.00179450213909, 52.9157629609108, 57.326486483216286, 57.3199812322855, 55.46651668846607, 51.54138430953026, 46.53185851871967, 43.09632606804371, 44.03457552194595, 44.19131711125374, 45.436046719551086, 45.892820209264755, 48.36466357111931, 51.32136091589928, 56.21055096387863, 57.88321740925312, 59.37581151723862, 59.43293385207653, 63.42368111014366, 14.905674867331982, 1.1098090605810285, 5.245593823492527, 5.61084589920938, 1.1792850075289607, 0.1130641353665851, 0.905619120458141, 25.725953355431557, 35.14936789870262, 28.39676544070244, 16.791084297001362, 39.9030876159668, 47.93419227004051, 54.29503574967384, 53.79816301167011, 59.91994611918926, 12.217667754739523, 0.17871402902528644, 0.10359962994698435, 0.05885347221919801, 0.04615619749529287, 0.03127136827970389, 0.01432136379662552, 0.08252717045252211, 0.0055903015891090035, 0.04636346820916515, 0.005079322245364892, 0.03689667326398194, 0.08954475561040454, 0.006519938033306971, 0.028457409607653972, 0.06913757955771871, 0.036393389527802356, 0.021164953359402716, 0.15783278387971222, 0.1983446069061756, 0.07469777221558616, 0.11851906921947375, 0.2304643575916998, 0.11203017522348091, 0.1520662073744461, 0.13225589616922662, 0.221375928085763, 0.09214769015670754, 0.1392923467210494, 0.15153954969719052, 0.11867751774843782, 0.1784683039295487, 0.14950980548746884, 0.17146493832115084, 11.31593244150281, 69.36718538403511, 67.3686446249485, 59.31953653693199, 39.31875117123127, 27.671002484858036, 32.31047943234444, 53.51402945816517, 55.40299169719219, 55.53310051560402, 2.9147872561588883, 0.29940442938823253, 0.8449012285564095, 3.0711350915953517, 11.450787205249071, 6.147624095901847, 28.944477550685406, 65.32614782452583, 69.11810874938965, 63.40864911675453, 62.10586242377758, 63.49698677659035, 64.80435982346535, 66.05443194508553, 63.17208521068096, 61.42599530518055, 59.865495041012764, 61.51965267956257, 63.66585351526737, 59.77607063949108, 50.16230911016464, 45.27708224952221, 45.857782289385796, 45.850235894322395, 47.565874233841896, 45.22497944533825, 45.6352586299181, 43.136634305119514, 46.75522193312645, 45.98558463156223, 46.72925412654877, 47.31765255331993, 43.64246316254139, 44.99784663319588, 45.46800680458546, 44.7249186784029, 44.99497778713703, 44.80570614337921, 44.21836405992508, 44.40646916627884, 45.27155354619026, 45.875113159418106, 48.09677414596081, 47.13726103305817, 42.74472713470459, 43.388066813349724, 43.09372700750828, 42.744122967123985, 43.66449058055878, 45.54248280823231, 44.46376629173756, 41.691492050886154, 45.979121178388596, 42.47074283659458, 47.95978009700775, 52.14936688542366, 55.23023396730423, 55.20097553730011, 60.652638003230095, 55.895639061927795, 59.7556771337986, 36.66882276535034, 38.488985896110535, 63.6344064027071, 54.87915560603142, 56.11217424273491, 51.86253547668457, 50.94353199005127, 44.24417607486248, 46.31483316421509, 42.11159750819206, 44.77009065449238, 42.851767390966415, 43.1061789393425, 44.75645698606968, 43.54407884180546, 44.08191718161106, 44.007349982857704, 43.434990495443344, 47.75814771652222, 43.55958580970764, 52.16858625411987, 53.77597980201244, 59.5707942545414, 57.25986085832119, 57.12795853614807, 56.72639228403568, 57.20012806355953, 59.544826447963715, 58.647098019719124, 50.88769778609276, 47.14088223874569, 45.83931528031826, 47.187596932053566, 42.75765024125576, 48.59679311513901, 44.7711393982172, 50.62034793198109, 54.91705857217312, 60.40036953985691, 60.774303674697876, 59.34143856167793, 52.77663342654705, 47.86703087389469, 45.95199443399906, 46.17058150470257, 47.35905893146992, 48.85560482740402, 48.070935532450676, 52.42686979472637, 54.600896537303925, 59.02608208358288, 60.405218079686165, 63.21747377514839, 61.96624271571636, 67.59716436266899, 15.288282036781311, 7.079317951574922, 20.04283580929041, 11.115281358361244, 0.5129044933710247, 0.21784391370601952, 1.6357096284627914, 31.188458539545536, 51.43657073378563, 44.36326548457146, 26.233338229358196, 46.601645573973656, 52.877096235752106, 63.91474395990372, 60.04388026893139, 68.1727422773838, 16.002265624701977, 0.4976222477853298, 0.26148008939344436, 0.17848558112746105, 0.16438167309388518, 0.1283300091745332, 0.10865360367461108, 0.1776346197584644, 0.179047787678428, 0.2467294887173921, 0.09573438597726636, 0.13731250452110544, 0.17210152291227132, 0.048370458171120845, 0.11930528562515974, 0.1817932294216007, 0.11019750832929276, 0.10935546015389264], [0.04814462263311725, 0.036536260377033614, 0.009059710246219765, 0.04415372350194957, 0.08442614082014188, 0.010508141313039232, 0.05302632533130236, 0.050373629783280194, 0.0757546944078058, 0.009357432991237147, 0.0627068402536679, 0.041440561471972615, 0.04766980026033707, 0.0743477679498028, 0.07186059359810315, 0.15925362560665235, 15.604613162577152, 62.90707603096962, 54.33921977877617, 47.43403270840645, 26.540310457348824, 20.718931630253792, 37.39224314689636, 44.70731422305107, 38.216544315218925, 30.29880467802286, 0.30793289362918586, 0.04354747790785041, 0.35127983952406794, 2.373371170833707, 3.3149328595027328, 2.453473247587681, 24.499888345599174, 65.64466193318367, 62.46124975383282, 60.305256843566895, 52.83700078725815, 51.17970071732998, 56.64531223475933, 57.433530539274216, 59.531964138150215, 55.60296356678009, 54.46543760597706, 52.577881291508675, 54.68852363526821, 57.10010603070259, 46.820449233055115, 41.19526147842407, 42.41052746772766, 41.79385855793953, 41.806272491812706, 42.01260522007942, 41.017792001366615, 39.8329471796751, 42.68408238887787, 43.39797668159008, 43.99179741740227, 44.7166845202446, 41.76307640969753, 42.46943570673466, 41.24486781656742, 40.15712298452854, 39.25822041928768, 39.44561496376991, 39.7821819037199, 39.54020708799362, 38.92688199877739, 37.60945849120617, 38.75940218567848, 39.21997927129269, 38.30224871635437, 38.946713134646416, 40.972730219364166, 38.9451590180397, 41.77030362188816, 38.05144317448139, 40.35734944045544, 39.935792461037636, 40.9624669700861, 39.478855580091476, 43.27594242990017, 40.41017420589924, 47.4929029494524, 47.48847618699074, 54.505335465073586, 48.55353243649006, 61.747363060712814, 31.68203115463257, 29.86984569579363, 59.19055625796318, 50.412749871611595, 55.00606119632721, 48.241854161024094, 50.319100096821785, 45.75228855013847, 45.857679694890976, 42.809756845235825, 40.06901331245899, 39.24471594393253, 39.46791596710682, 37.45018243789673, 40.145917385816574, 38.298471719026566, 39.27420996129513, 39.67443108558655, 41.14719785749912, 39.98667173087597, 42.29044251143932, 46.35252334177494, 51.72093607485294, 52.62448959052563, 51.81782327592373, 54.0596953779459, 55.12494541704655, 52.794028893113136, 50.049162581562996, 42.004743441939354, 41.14504337310791, 38.81637252867222, 40.27287237346172, 40.430966690182686, 42.33540549874306, 39.77385275065899, 45.48089951276779, 53.552855774760246, 57.28200986981392, 56.39674477279186, 56.594242975115776, 52.875663712620735, 51.76679581403732, 46.33975222706795, 43.8406453281641, 44.45796400308609, 45.477608889341354, 45.113345235586166, 44.60750497877598, 44.37780350446701, 47.66588866710663, 51.4798504114151, 56.22833400964737, 53.13230574131012, 64.94315877556801, 36.346132680773735, 1.6716149705462158, 5.32058184966445, 7.816016245633364, 0.13866567722288892, 0.19669813744258136, 0.10270808052155189, 11.564004980027676, 36.619311422109604, 31.49170696735382, 24.85696278512478, 42.24118955433369, 45.142181888222694, 36.840201169252396, 50.41493095457554, 47.83636651933193, 29.76608846336603, 0.9245029790326953, 0.0999261176912114, 0.09111033839872107, 0.011270202667219564, 0.03974538114562165, 0.02025035097176442, 0.030668184044770896, 0.03615026565967128, 0.005049591345596127, 0.016873443601070903, 0.012249346855242038, 0.10419726662803441, 0.03887862687406596, 0.06178016868943814, 0.05874040973139927, 0.03341797106259037, 0.038090169182396494, 0.028269013564568013, 0.051420265808701515, 0.019546724470274057, 0.08434515024418943, 0.037099479959579185, 0.038819028704892844, 0.05157714469532948, 0.05623614000796806, 0.11814976911409758, 0.035933855397161096, 0.04690912115620449, 0.0706144905416295, 0.05717621104849968, 0.04703696722572204, 0.026520328101469204, 0.09926140570314601, 22.355638705193996, 73.55127766728401, 60.82542613148689, 53.09377960860729, 33.94998885691166, 25.73970291763544, 34.86177273094654, 42.03005388379097, 44.58783723413944, 34.56183582544327, 0.2602393372217193, 0.01752555948769441, 0.6995990441646427, 6.354303555563092, 9.370914660394192, 3.259507608599961, 27.064743116497993, 65.88233157992363, 64.50806692242622, 62.14281924068928, 54.462621957063675, 54.896440878510475, 59.379892498254776, 59.61033873260021, 60.940936133265495, 59.288009628653526, 56.90397575497627, 56.43589787185192, 55.22114485502243, 59.85869340598583, 49.00452643632889, 42.15645030140877, 43.8793158531189, 44.15946342051029, 43.863132521510124, 43.615841791033745, 41.66255280375481, 43.363079354166985, 44.53931003808975, 45.4893958568573, 46.18191249668598, 46.07381969690323, 43.353766053915024, 43.21830332279205, 42.73610159754753, 42.705277651548386, 40.76785661280155, 40.9695003926754, 41.4307576417923, 40.64658232033253, 42.00047627091408, 40.67044883966446, 40.56924507021904, 40.70012144744396, 40.68266898393631, 41.32548049092293, 41.9372096657753, 41.15945599973202, 43.47277946770191, 40.19355162978172, 42.0410580933094, 42.07153245806694, 44.11361128091812, 42.29967221617699, 45.46140655875206, 43.31183910369873, 50.95038682222366, 50.53585946559906, 55.99848814308643, 51.66743874549866, 61.996052116155624, 33.82241830229759, 30.450410842895508, 60.410397201776505, 51.18615657091141, 56.65525630116463, 48.391911908984184, 51.419768035411835, 48.58733542263508, 48.81210096180439, 43.918339759111404, 43.04077684879303, 40.56281961500645, 41.43738828599453, 39.67742532491684, 42.299774810671806, 40.624558702111244, 41.2634564191103, 39.84827935695648, 43.41837398707867, 42.82845564186573, 46.08979023993015, 49.300925731658936, 53.595174103975296, 55.43013744056225, 55.279270336031914, 55.12510500848293, 58.16750295460224, 53.21625083684921, 52.957393527030945, 45.03409668803215, 42.75925375521183, 41.06984160840511, 42.25257754325867, 42.2713827341795, 43.84177766740322, 41.34024269878864, 47.62683816254139, 53.94218288362026, 59.66072402894497, 57.82041057944298, 57.98351302742958, 55.22809088230133, 53.50936330854893, 48.999909684062004, 45.677367970347404, 45.80744259059429, 46.83456547558308, 47.20578275620937, 46.745509654283524, 46.68108031153679, 49.4815718382597, 53.440005630254745, 58.558809757232666, 54.564528688788414, 66.82074442505836, 38.21323089301586, 1.676039476878941, 2.412752020172775, 7.445750813931227, 1.630038907751441, 0.1881779110408388, 0.02821832302288385, 12.727043721824884, 41.79807633161545, 25.18046412616968, 23.8133392855525, 51.46392546594143, 50.73491558432579, 43.73761385679245, 55.89747056365013, 54.91371475160122, 39.854146242141724, 1.4895403780974448, 0.12472985079512, 0.030183181261236314, 0.022404905867006164, 0.026804913904925343, 0.07386520868749358, 0.023339687249972485, 0.05060729126853403, 0.016799841105239466, 0.03831645371974446, 0.016202321312448476, 0.10390394018031657, 0.03583186575269792, 0.054839455187902786, 0.04604558780556545, 0.07845219341106713, 0.03172144373820629, 0.18175475648604333, 0.2266328569385223, 0.08092735239188187, 0.33900471695233136, 0.17042404651874676, 0.13286558532854542, 0.13049106899416074, 0.17687957355519757, 0.14461335260421038, 0.20198751299176365, 0.17719409574056044, 0.23423363658366725, 0.13048830820480362, 0.15750662481877953, 0.22831707203295082, 0.27957848855294287, 32.166106179356575, 82.19007611274719, 70.45992314815521, 61.58692046999931, 40.4973529279232, 31.832360588014126, 48.60238641500473, 61.2570221722126, 52.06748507916927, 37.994480431079865, 0.47978021611925215, 0.14533307257806882, 1.132912770844996, 4.731930261477828, 9.55557620152831, 5.07708141580224, 31.536491364240646, 69.3569715321064, 66.27962306141853, 64.23374444246292, 57.86970913410187, 56.369941011071205, 61.39608331024647, 59.51585300266743, 61.8278731405735, 60.70585034787655, 59.11992944777012, 58.287584111094475, 59.363633170723915, 62.912448942661285, 52.616984993219376, 44.130653366446495, 46.37668624520302, 47.23920576274395, 47.223345413804054, 47.21257299184799, 43.870002552866936, 44.44753736257553, 47.26744964718819, 47.55380228161812, 47.49382629990578, 49.38464663922787, 46.36985041201115, 44.900807440280914, 45.49268268048763, 46.24239005148411, 42.3728296905756, 43.54680709540844, 44.23370003700256, 43.9733874052763, 43.73696409165859, 42.294808477163315, 42.09890998899937, 42.87302725017071, 41.83735482394695, 44.69460770487785, 45.27274668216705, 43.52417171001434, 45.36890052258968, 41.183326318860054, 43.447852805256844, 44.05538320541382, 45.681365355849266, 44.43865343928337, 48.6911116540432, 46.325677782297134, 53.558848053216934, 53.33634339272976, 57.58491061627865, 54.67827558517456, 64.01733085513115, 37.26659148931503, 33.820286616683006, 61.482236087322235, 54.62983198463917, 58.33562113344669, 51.61958411335945, 54.86975111067295, 51.01949371397495, 51.88383713364601, 47.7421809732914, 46.04773789644241, 45.07168427109718, 43.2620769739151, 40.82162752747536, 44.44607824087143, 42.781759947538376, 42.69718028604984, 42.03149400651455, 44.422485306859016, 45.249913707375526, 48.4476625174284, 51.47112227976322, 54.941236674785614, 59.203866943717, 57.97623261809349, 59.013208374381065, 60.11833727359772, 56.15243308246136, 55.74035659432411, 47.73798979818821, 45.016461834311485, 42.57642276585102, 44.430544674396515, 44.793721586465836, 46.956782117486, 43.67765687406063, 50.69566369056702, 56.21197588741779, 62.73998759686947, 58.65328408777714, 61.26712962985039, 58.49317967891693, 56.75476536154747, 51.19982823729515, 47.66016997396946, 47.95398160815239, 48.29577326774597, 49.74367417395115, 49.28187355399132, 49.69268091022968, 52.93495573103428, 57.22066216170788, 61.53757631778717, 57.92173594236374, 69.48582261800766, 41.58578932285309, 3.389301518909633, 12.932591792196035, 20.7567984983325, 2.66122804954648, 0.5115446413401514, 0.2580466470681131, 15.185933578759432, 53.23857843875885, 44.66588504612446, 37.30467304587364, 50.32525956630707, 54.99020464718342, 52.926805168390274, 63.071964383125305, 61.99829399585724, 46.953168511390686, 2.52980450168252, 0.15138663758989424, 0.24329223175300285, 0.14399747393326834, 0.1807843687129207, 0.15495507657760754, 0.27852401544805616, 0.14081977569730952, 0.08410505062784068, 0.09890425455523655, 0.1003907986159902, 0.1934164494741708, 0.11234536534175277, 0.15463095100130886, 0.11917088268091902, 0.19902125262888148, 0.10039603817858733], [0.06622325468924828, 0.014574978849850595, 0.027859503898071125, 0.028305339837970678, 0.04089846712304279, 0.04759011215355713, 0.03439702712057624, 0.07025161001365632, 0.09087432059459388, 0.025932068456313573, 0.04222065887006465, 0.02712902092753211, 0.035242359299445525, 0.021268462551233824, 0.0502718442294281, 0.22340926429023966, 34.784298688173294, 57.28644423186779, 51.41115389764309, 40.47460354864597, 27.573199532926083, 16.180935837328434, 45.78387625515461, 39.378825947642326, 44.33439463376999, 21.29977986216545, 0.10235505571472459, 0.10718838151660748, 0.30254792945925146, 13.237822763621807, 10.059828143566847, 2.132469085045159, 34.59452927112579, 65.49940332770348, 60.16843378543854, 60.68752013146877, 52.97977812588215, 50.03314644098282, 50.327417850494385, 57.17355228960514, 59.05610807240009, 60.202156975865364, 56.34021520614624, 54.67031881213188, 56.458050683140755, 52.23105110228062, 47.570889964699745, 39.92085166275501, 40.60499355196953, 42.226336151361465, 40.94080053269863, 41.129920184612274, 40.95914974808693, 42.98103645443916, 45.242450907826424, 45.67672200500965, 45.96862234175205, 46.98624573647976, 45.08039340376854, 42.30081595480442, 41.22716836631298, 39.950387477874756, 40.500803142786026, 39.15201611816883, 41.31338573992252, 39.45370472967625, 40.06707541644573, 39.092131331562996, 39.21693943440914, 39.21923831105232, 39.923633113503456, 40.016560927033424, 38.51538687944412, 38.38148966431618, 40.41980668902397, 40.0354915112257, 40.810125544667244, 39.07776050269604, 40.949524864554405, 39.63935896754265, 41.193969547748566, 38.637937903404236, 42.1966977417469, 41.35837532579899, 52.69804984331131, 48.72363790869713, 59.07965160906315, 31.364447996020317, 26.694084405899048, 56.08434073626995, 48.10516029596329, 55.03158442676067, 49.39929485321045, 54.0555763989687, 49.20104429125786, 50.69613106548786, 41.80673226714134, 37.85933308303356, 37.94854089617729, 38.696025386452675, 38.043847382068634, 39.82215195894241, 38.78475822508335, 39.834964871406555, 39.093940034508705, 39.95315372943878, 40.79724423587322, 41.934435814619064, 42.28519879281521, 44.37388211488724, 45.46853117644787, 48.14475417137146, 48.35802152752876, 51.59729450941086, 45.33557631075382, 42.07182504236698, 38.910938054323196, 39.19225595891476, 40.762749686837196, 41.210202276706696, 39.403547421097755, 40.738704577088356, 41.18339851498604, 48.304900377988815, 53.45414087176323, 56.293766498565674, 52.737791910767555, 57.781211882829666, 55.54146006703377, 55.026868879795074, 51.72531723976135, 47.78023213148117, 48.21822702884674, 46.190139055252075, 42.06891819834709, 44.1224230080843, 44.4101207703352, 47.02763691544533, 50.8135599642992, 57.804911211133, 57.68661975860596, 58.594653233885765, 52.105722427368164, 9.378411658108234, 0.64738052431494, 5.89515614323318, 5.410234713926911, 0.1023928310314659, 0.05879189622646663, 4.74526422098279, 33.31247426569462, 46.34084276854992, 22.21546422690153, 12.235086970031261, 29.370455592870712, 35.815620347857475, 45.407137870788574, 47.18054451048374, 46.06484837830067, 4.761901153251529, 0.07229291688418016, 0.03466749913059175, 0.063470680906903, 0.03365950673469342, 0.007800566727382829, 0.029535744615714066, 0.037048401645733975, 0.040410085712210275, 0.03341338458994869, 0.03955092361138668, 0.04561167261272203, 0.02290155851369491, 0.04354885459179059, 0.03789013440837152, 0.01281422606552951, 0.020556080562528223, 0.04937884761602618, 0.032628930784994736, 0.03289286447397899, 0.02504825035430258, 0.05567845313635189, 0.030048731932765804, 0.05576296891376842, 0.05011725857912097, 0.037322246716939844, 0.0226325244148029, 0.011301643753540702, 0.05057650327216834, 0.06409484936739318, 0.049293901392957196, 0.02246482687041862, 0.49510310171172023, 43.955144584178925, 64.68253076076508, 55.66475585103035, 45.26192106306553, 31.141257472336292, 22.02405519783497, 42.523028030991554, 41.76159828901291, 51.67745880782604, 22.960919626057148, 0.11834600038127974, 0.09937563707353547, 1.7470328486524522, 8.635355830192566, 8.02914110943675, 2.864096313714981, 36.125972494482994, 67.16350123286247, 63.07739429175854, 62.02260509133339, 56.24113172292709, 50.53547568619251, 52.48641259968281, 58.739444464445114, 58.87912876904011, 62.27821357548237, 59.70374912023544, 56.5618497133255, 58.261878490448, 54.727843925356865, 50.18961064517498, 42.598377987742424, 43.2668799161911, 43.74037250876427, 43.63888755440712, 42.05561891198158, 42.71495193243027, 44.95646685361862, 47.10958331823349, 48.72040428221226, 48.55975270271301, 49.650408178567886, 47.63180069625378, 44.90046165883541, 43.548004031181335, 41.28793850541115, 42.315509766340256, 40.25780998170376, 43.22350524365902, 40.8435333520174, 41.63511447608471, 41.577562764286995, 40.97202725708485, 41.18568979203701, 42.70242780447006, 41.13925248384476, 40.641350001096725, 40.3535458445549, 43.07883940637112, 41.047411412000656, 42.81930573284626, 41.97872243821621, 43.43519948422909, 41.3005044311285, 42.37563394010067, 39.99777853488922, 44.351782500743866, 42.74077534675598, 54.75160405039787, 51.741139590740204, 61.88347555696964, 32.36571326851845, 26.841594390571117, 56.653804779052734, 49.65883992612362, 57.73562952876091, 50.65507046878338, 56.131800189614296, 51.218473836779594, 51.5758066624403, 43.80890943109989, 40.02238601446152, 39.35720130801201, 40.998739823699, 40.504557341337204, 41.72166623175144, 41.618304178118706, 42.53676429390907, 41.7132268846035, 42.150659412145615, 41.77069500088692, 43.14315855503082, 43.31942729651928, 45.44142723083496, 48.785521388053894, 50.11415809392929, 50.875200256705284, 52.728083431720734, 49.30234685540199, 44.03377756476402, 40.829113125801086, 43.35384584963322, 41.931563168764114, 42.3876678943634, 41.642562076449394, 42.35481105744839, 42.6752744615078, 50.06898611783981, 56.12137354910374, 58.20650406181812, 54.662320241332054, 58.98673139512539, 57.016947492957115, 57.416344061493874, 55.26669301092625, 50.59188365936279, 48.87143857777119, 48.17096136510372, 44.64161954820156, 45.913194715976715, 46.91423200070858, 48.248021230101585, 53.38890217244625, 59.18069578707218, 60.44803038239479, 59.80003595352173, 57.25603446364403, 10.621158722788095, 0.9667747013736516, 7.8258406184613705, 4.282837109640241, 0.10202925288467668, 0.13776879175566137, 3.6821425426751375, 38.549801632761955, 43.081495463848114, 25.543057769536972, 17.561667747795582, 35.98707854747772, 44.053031131625175, 53.476981446146965, 53.93521025776863, 55.98887845873833, 9.02927404269576, 0.16237544012255967, 0.05677770372130908, 0.07020605698926374, 0.025184428886859678, 0.05307725150487386, 0.04480680974666029, 0.05840456193254795, 0.010466328712936956, 0.044820123875979334, 0.045612492685904726, 0.09461032168474048, 0.0434256432345137, 0.05352785017748829, 0.033604105410631746, 0.03919462593330536, 0.03816395721514709, 0.16478206176543608, 0.09465293580433354, 0.15183047158643603, 0.13182779570342973, 0.1424179907189682, 0.14829611202003434, 0.14804300997639075, 0.12539022864075378, 0.23185963975265622, 0.1367626918363385, 0.10268258774885908, 0.13031295355176553, 0.15323860774515197, 0.10138278288650326, 0.17674315196927637, 1.1586201726458967, 52.17235945165157, 71.34732753038406, 66.42621159553528, 53.69183711707592, 37.65050008893013, 24.73497223109007, 58.61290365457535, 53.815505281090736, 58.85075569152832, 26.93025503307581, 0.28572587587404996, 0.36158928007353097, 0.8860875747632235, 24.035912342369556, 19.296267069876194, 5.239045824855566, 40.83693690598011, 69.4245395064354, 64.87834945321083, 65.82525864243507, 58.81459683179855, 53.57156217098236, 56.10420227050781, 60.699493288993835, 63.227064460515976, 63.71538765728474, 62.83928766846657, 58.33825819194317, 61.64209730923176, 58.31340752542019, 52.90542371571064, 45.43282829225063, 45.30286006629467, 45.90627148747444, 45.69585397839546, 45.26256702840328, 45.384088307619095, 47.83706568181515, 50.3775105625391, 49.73770849406719, 50.66021919250488, 50.22389620542526, 49.600946232676506, 46.30465731024742, 45.3782594203949, 44.55490060150623, 43.88311944901943, 41.18972897529602, 45.733475759625435, 43.34939628839493, 43.327064886689186, 43.56731079518795, 43.8860072940588, 42.79697433114052, 43.83023388683796, 43.95525097846985, 42.14219346642494, 42.02295586466789, 45.80863192677498, 43.94156411290169, 46.3799274712801, 43.72308723628521, 46.088281720876694, 43.84794093668461, 44.351550713181496, 42.9939291626215, 47.11737670004368, 44.38858352601528, 58.086411505937576, 54.12902645766735, 61.28117747604847, 36.112665608525276, 30.777464993298054, 55.87741903960705, 52.52869293093681, 59.12067040801048, 54.033605977892876, 57.44698941707611, 53.623273596167564, 53.28917272388935, 47.317485362291336, 42.21690505743027, 42.17777855694294, 42.82163120806217, 42.34060361981392, 44.48868155479431, 43.98740105330944, 44.97593700885773, 44.77720007300377, 44.262650683522224, 45.21380424499512, 45.126739516854286, 44.95028458535671, 47.459008768200874, 51.125382632017136, 51.874995008111, 52.44928479194641, 56.9971277564764, 50.77440306544304, 44.68306012451649, 42.05457776784897, 43.76387044787407, 45.21497078239918, 45.37464961409569, 44.1354601085186, 44.458397179841995, 45.25698892772198, 51.884749084711075, 59.038222432136536, 61.511863097548485, 55.646494030952454, 60.037093833088875, 61.200112625956535, 58.810037076473236, 57.6352921128273, 53.85481797158718, 51.097598522901535, 50.41898153722286, 47.719009816646576, 48.0097284168005, 49.16358970105648, 51.30574755370617, 56.375625506043434, 62.745501101017, 63.811625093221664, 62.47760407626629, 58.15027467906475, 12.204790245741606, 2.72531992290169, 13.69814146310091, 9.329956658184528, 0.3042399964760989, 0.29103264736477286, 5.452247159555554, 45.50549179315567, 64.06640902161598, 32.79466085135937, 19.733781293034554, 40.00010021030903, 47.971582263708115, 61.14492058753967, 61.34285196661949, 65.96719622612, 11.949024070054293, 0.2938465151237324, 0.20860370015725493, 0.157541312801186, 0.10558143883827142, 0.11745772382710129, 0.09423814204637893, 0.22388121084077284, 0.10828883809153922, 0.11330920737236738, 0.14946828974643722, 0.12819067836971954, 0.12975809426279739, 0.10910151948337443, 0.09376344212796539, 0.10637104685883969, 0.1690075537771918], [0.04446036778972484, 0.03616889356635511, 0.03951135229726788, 0.07034719863440841, 0.005508824442586047, 0.01379200562951155, 0.044408502799342386, 0.004922370071653859, 0.02395235984295141, 0.03869876738463063, 0.05707781339879148, 0.07244959168019705, 0.02391033758613048, 0.12130755552789196, 0.021026325739512686, 3.476782562211156, 54.71120461821556, 55.413422137498856, 52.93930269777775, 37.793281227350235, 31.358687505126, 18.767172060906887, 39.25953894853592, 39.77321818470955, 47.474967911839485, 9.038832429796457, 0.3845168638508767, 0.2731776429573074, 1.2708568875677884, 6.247096583247185, 9.192135203629732, 3.0101001542061567, 38.14435958862305, 64.26205292344093, 60.404138937592506, 57.37797372043133, 51.30709268152714, 46.67998597025871, 46.926094964146614, 48.96435119211674, 53.635201156139374, 56.449630334973335, 59.47442762553692, 57.11916580796242, 54.83690947294235, 48.369599506258965, 42.563845440745354, 41.452218890190125, 40.764695182442665, 39.52610604465008, 41.637538745999336, 39.51184920966625, 42.10608400404453, 43.21183606982231, 49.363386780023575, 49.08038176596165, 52.01157107949257, 50.68513445556164, 49.49815794825554, 42.28548377752304, 40.85386499762535, 41.064544692635536, 41.07133872807026, 39.14248622953892, 42.200645729899406, 39.31967452168465, 40.67018665373325, 39.09789942204952, 40.23523159325123, 38.39367941021919, 40.285248309373856, 38.59450243413448, 39.14114490151405, 37.64279030263424, 40.54080739617348, 37.80759125947952, 43.639860302209854, 44.1783332079649, 48.12502183020115, 44.85598884522915, 47.792779058218, 44.45726104080677, 46.39201462268829, 41.85724675655365, 51.24327890574932, 46.962120831012726, 59.112903624773026, 30.50881750881672, 28.94756868481636, 53.85307386517525, 45.62216833233833, 53.35886098444462, 50.154834911227226, 55.02816081047058, 51.30536377429962, 52.7759874612093, 47.703187465667725, 40.440329387784004, 39.15544733405113, 41.72410190105438, 38.91811966896057, 40.30202440917492, 39.489711597561836, 42.28799544274807, 38.966582268476486, 39.721069782972336, 42.074633091688156, 39.72886696457863, 39.94352504611015, 40.28761938214302, 39.95710551738739, 40.2350378036499, 40.402392223477364, 39.38896760344505, 38.7912330776453, 39.92486044764519, 39.29824747145176, 39.142672419548035, 40.379145070910454, 39.48300115764141, 40.748059675097466, 41.93117938935757, 48.753785490989685, 52.04207584261894, 55.068073868751526, 54.58797723054886, 53.091750517487526, 50.000908970832825, 53.00207532942295, 56.328686624765396, 52.894776687026024, 52.12521918118, 48.08266170322895, 47.88284182548523, 45.106836184859276, 43.91958229243755, 45.32924585044384, 47.92794540524483, 52.904124185442924, 57.80836522579193, 57.006201669573784, 60.43156586587429, 60.791341960430145, 27.428269609808922, 0.7615652878303081, 2.0814489852637053, 3.713822392746806, 0.06776109599741176, 0.2822590369032696, 0.34778473956976086, 21.829798221588135, 35.07818631827831, 34.40815307199955, 26.96770392358303, 19.378059580922127, 27.83292319625616, 37.33526900410652, 46.66895516216755, 52.24164493381977, 19.064354114234447, 0.662117499159649, 0.14914918108843267, 0.05564270388276782, 0.046949208262958564, 0.01433850462490227, 0.017745188815752044, 0.05138091342814732, 0.03160312684485689, 0.04502342409978155, 0.08020442634006031, 0.03651678271126002, 0.015402342705783667, 0.005520729882846354, 0.008654678513266845, 0.07106315591954626, 0.03197222285962198, 0.00859560077515198, 0.10436462092911825, 0.06239261492737569, 0.07270710208103992, 0.05128032644279301, 0.05437493011413608, 0.015102391662367154, 0.0330733473674627, 0.02929470061644679, 0.03317105110909324, 0.015778579108882695, 0.05963884628727101, 0.021219232185103465, 0.00979726866717101, 0.012116366051486693, 5.626183301210403, 64.23661708831787, 60.46594262123108, 60.87427631020546, 43.65994222462177, 38.580671176314354, 18.367387913167477, 34.28955763578415, 43.49484868347645, 52.35470786690712, 9.459131676703691, 0.23762444994645193, 0.13313480681972578, 2.360530234873295, 19.322816245257854, 10.854722689837217, 3.671315023675561, 37.94960103929043, 67.24849507212639, 61.26856595277786, 59.621042758226395, 53.567861169576645, 50.43019473552704, 49.47544276714325, 51.31343834102154, 56.88730984926224, 58.54814752936363, 59.67900104820728, 58.88470686972141, 57.03482173383236, 51.047426015138626, 44.56956401467323, 43.2558187097311, 42.14128151535988, 41.54815994203091, 44.63332079350948, 42.15059481561184, 43.16559635102749, 45.99402777850628, 50.972357243299484, 51.1535619199276, 54.52974155545235, 54.3871808052063, 52.66499921679497, 44.61682967841625, 42.73363173007965, 43.86595956981182, 42.78525575995445, 40.45778185129166, 42.27257966995239, 40.81534646451473, 43.74697655439377, 42.35083647072315, 41.89453795552254, 40.406663194298744, 41.387759149074554, 40.603276044130325, 41.29298083484173, 40.514566004276276, 41.627093106508255, 41.036699786782265, 44.93146039545536, 46.47215232253075, 51.185271218419075, 47.10129976272583, 50.70984832942486, 45.447681695222855, 48.1074021756649, 43.46513047814369, 53.502432480454445, 49.459875002503395, 61.12523764371872, 33.09913471341133, 30.04160027951002, 53.30668978393078, 46.021283715963364, 54.20648530125618, 51.09709694981575, 55.593141093850136, 52.295294255018234, 53.790130242705345, 48.328474313020706, 41.73467293381691, 41.918434873223305, 43.42518702149391, 40.00792399048805, 41.95312321186066, 40.839437171816826, 43.20465065538883, 40.227681398391724, 42.90071256458759, 43.341762498021126, 41.36348985135555, 40.54650329053402, 42.499172911047935, 41.90600574016571, 41.85896426439285, 44.092442616820335, 40.58521181344986, 41.17096558213234, 41.91049709916115, 41.05466902256012, 41.24890699982643, 41.25828869640827, 41.3673884421587, 42.84747362136841, 44.30779606103897, 50.54070420563221, 54.23073559999466, 57.311059311032295, 55.341210812330246, 52.15502858161926, 51.167495772242546, 56.96673318743706, 57.742571756243706, 56.0054075717926, 55.75474262237549, 50.52442587912083, 48.9777834713459, 47.07866817712784, 47.05269657075405, 48.51174607872963, 50.13262890279293, 54.24834385514259, 58.3820204436779, 59.323826506733894, 63.12094375491142, 62.69936017692089, 31.171095371246338, 1.9179823505692184, 2.5053221778944135, 5.826393133029342, 0.09779792017070577, 0.13522745546652004, 0.2184022165602073, 23.944878727197647, 43.83668594062328, 33.400032967329025, 28.490058034658432, 30.742446072399616, 33.03377062082291, 44.06718157231808, 50.66979467868805, 59.877939373254776, 27.720686718821526, 0.645918968366459, 0.16605770972091705, 0.04435999602719676, 0.059138534852536395, 0.03331350635562558, 0.03097347947914386, 0.056878420582506806, 0.0358675259485608, 0.04047714246553369, 0.05554566807404626, 0.061051773009239696, 0.06980790218221955, 0.03553435359208379, 0.05442123641842045, 0.0358135235728696, 0.05561704412684776, 0.09394190637976862, 0.2409288179478608, 0.15542987297521904, 0.19507799937855452, 0.08745791055844165, 0.11359333861037157, 0.26558642217423767, 0.11488407442811877, 0.131406300351955, 0.13600967911770567, 0.12811852677259594, 0.1363677208428271, 0.1498268955037929, 0.16600985603872687, 0.17696762195555493, 8.750386107712984, 74.47608724236488, 67.67078161239624, 67.79023960232735, 51.679244711995125, 44.91419792175293, 29.417871348559856, 52.55572088062763, 52.318841591477394, 61.85965843498707, 10.776066910475492, 0.38680713158100843, 0.5826809804420918, 2.315277513116598, 20.082760266959667, 18.605553433299065, 5.411751307547092, 41.92856892943382, 69.01337116956711, 63.65854650735855, 63.33937883377075, 56.128163784742355, 52.407817617058754, 51.08609274029732, 53.75858433544636, 59.5293764770031, 61.087726056575775, 63.005661740899086, 62.3489885777235, 59.39030013978481, 53.919194117188454, 46.281892731785774, 46.416652500629425, 44.42083239555359, 42.03471623361111, 47.283218801021576, 43.5715551674366, 46.164285242557526, 49.208089113235474, 55.072059854865074, 53.11328776180744, 56.62736959755421, 56.8585491925478, 54.73686844110489, 47.2980760037899, 45.57704195380211, 45.34993954002857, 44.69320558011532, 42.689421102404594, 45.907491222023964, 43.40732418000698, 44.20521676540375, 43.98293249309063, 44.8948759585619, 42.74957947432995, 43.40413995087147, 43.44725623726845, 42.48924024403095, 41.94764770567417, 44.32805277407169, 42.015831246972084, 48.390027210116386, 49.06652390956879, 54.46390628814697, 50.885851085186005, 53.12312163412571, 48.218933790922165, 50.47863453626633, 45.827657505869865, 56.025029718875885, 51.86587929725647, 61.923514008522034, 37.135255336761475, 31.717468053102493, 54.2316285520792, 48.22950482368469, 55.24879977107048, 53.820726200938225, 57.54901014268398, 54.47734236717224, 57.90494464337826, 51.43434405326843, 43.95584374666214, 43.67769867181778, 46.57757006585598, 43.90664018690586, 43.884673565626144, 42.945493161678314, 45.96064656972885, 43.225876316428185, 44.65057946741581, 46.72003582119942, 44.39479239284992, 43.3955068141222, 44.69924345612526, 45.15027165412903, 43.63245829939842, 46.0128253698349, 43.158999904990196, 42.65087217092514, 43.94403398036957, 43.55469547212124, 43.5599771887064, 43.570555821061134, 43.77539522945881, 45.106030628085136, 46.80207721889019, 53.71126927435398, 57.64233313500881, 60.529995784163475, 58.04256945848465, 54.45404201745987, 52.63821445405483, 57.771932780742645, 59.67672877013683, 57.75669179856777, 57.805572375655174, 53.20666395127773, 52.08759360015392, 49.503557458519936, 49.32565480470657, 49.54143762588501, 52.597081661224365, 56.92315332591534, 62.519242241978645, 61.1897087842226, 66.22765704989433, 62.3525033891201, 34.25730116665363, 4.219388589262962, 7.872580960392952, 9.373883251100779, 0.16977089719148353, 0.42776121525093913, 0.4098689847160131, 30.824173986911774, 51.69830068945885, 47.58155599236488, 37.80661851167679, 30.82260277122259, 36.864580661058426, 52.92235940694809, 58.961781933903694, 67.99606695771217, 33.64996075630188, 1.0966971516609192, 0.3338848182465881, 0.11282918625511229, 0.13923018443165347, 0.09586674059391953, 0.133250507642515, 0.10024106290074997, 0.10430729002109729, 0.10462882550200447, 0.2592966315569356, 0.1603310162317939, 0.0926885822264012, 0.11514116922626272, 0.12709722766885534, 0.18521432240959257, 0.1018920743081253], [0.03400355526537169, 0.021210270751907956, 0.03024456244020257, 0.04065695371537004, 0.061336004437180236, 0.01832912916142959, 0.06731495392159559, 0.03141845081700012, 0.03715087739692535, 0.042994355244445615, 0.11212027937290259, 0.058778415113920346, 0.028304798070166726, 0.026660174698918127, 0.031774388553458266, 14.369456190615892, 54.74617414176464, 54.12324696779251, 52.12634392082691, 36.0265888273716, 13.10281315818429, 23.75772926956415, 42.02419839799404, 36.983647271990776, 48.16632181406021, 1.8089264212176204, 0.03254573231970426, 0.11780830696807243, 8.649131041020155, 12.080779150128365, 8.411416746675968, 4.69532635062933, 44.027792885899544, 64.30802285671234, 61.44597843289375, 57.211622446775436, 49.987719878554344, 46.286566480994225, 45.52039459347725, 43.23827505111694, 45.356391593813896, 45.01841492950916, 48.22424590587616, 44.45829838514328, 43.65151807665825, 40.78232243657112, 41.27402365207672, 40.07414683699608, 40.658988654613495, 39.55593444406986, 39.193627685308456, 39.92799147963524, 42.824283465743065, 44.32462155818939, 50.96472725272179, 53.56407657265663, 54.556442722678185, 51.961770951747894, 52.40706905722618, 44.61083360016346, 40.03278225660324, 40.31165689229965, 39.463660195469856, 40.23754566907883, 40.015823766589165, 40.60630448162556, 39.83006693422794, 39.74844731390476, 38.97257074713707, 40.45636832714081, 40.57411640882492, 39.601949974894524, 38.69500324130058, 38.436214327812195, 40.37247642874718, 42.54611939191818, 48.88128764927387, 50.216137021780014, 53.28405059874058, 51.164562329649925, 52.7417778968811, 49.94927354156971, 52.69679591059685, 45.99928289651871, 55.1256749778986, 50.94937987625599, 60.53749278187752, 32.233411967754364, 30.79727903008461, 52.63631075620651, 48.545974642038345, 53.664649575948715, 49.470396637916565, 50.38812719285488, 50.28806336224079, 54.42466959357262, 47.30978697538376, 40.627492144703865, 39.103431925177574, 40.280703753232956, 37.77293711900711, 40.07171876728535, 39.633294492959976, 39.65883672237396, 40.12900069355965, 40.21104969084263, 40.427527874708176, 40.918970704078674, 40.04538998007774, 40.049026384949684, 40.210772305727005, 39.706619158387184, 40.458860993385315, 39.2345704883337, 39.710985124111176, 38.653167486190796, 39.108044877648354, 40.57054080069065, 38.629053980112076, 41.216411143541336, 40.06002299487591, 45.099255591630936, 54.56647418439388, 53.52816849946976, 53.07343550026417, 54.571809098124504, 53.10386806726456, 55.03440387547016, 53.289989680051804, 52.49450996518135, 57.15395674109459, 53.925068601965904, 47.372331619262695, 44.31238241493702, 42.113144025206566, 42.16776989400387, 49.50460620224476, 52.20696799457073, 58.095295429229736, 57.55475923418999, 61.289552226662636, 58.433568477630615, 58.97372469305992, 54.25746716558933, 14.368694331496954, 1.6876812209375203, 9.116574358195066, 0.33879860769957304, 0.05432668680441566, 0.08249329883255996, 11.114805433899164, 43.498481288552284, 38.395491912961006, 25.056017003953457, 11.93112513050437, 24.479916617274284, 39.5129169523716, 47.503789365291595, 51.03298299014568, 40.39991095662117, 2.6242883317172527, 0.1563879707828164, 0.04438314732396975, 0.02340130591619527, 0.03356726148922462, 0.03923762596969027, 0.0874647605814971, 0.060513341159094125, 0.04449006111826748, 0.028444713316275738, 0.01888267299364088, 0.07876091942307539, 0.03193235468643252, 0.04301731358282268, 0.0032994617095027934, 0.06452704648836516, 0.08566869641072117, 0.03951752696593758, 0.11897002041223459, 0.07283171609742567, 0.019564231733966153, 0.02317417718586512, 0.07777796708978713, 0.03702058224007487, 0.013710369385080412, 0.06748336207238026, 0.04953309929987881, 0.06868390468298458, 0.0073054994936683215, 0.0336654439161066, 0.16325245087500662, 18.893488682806492, 64.92717683315277, 60.281033143401146, 59.799853563308716, 41.771473959088326, 24.43841714411974, 25.29039792716503, 37.168913930654526, 41.52344986796379, 52.82057046890259, 2.0742115611210465, 0.15357439988292754, 0.22524008323671296, 5.613143350929022, 10.522075239568949, 6.100578345358372, 3.7439842242747545, 45.375667959451675, 66.23563662171364, 64.02733191847801, 59.04538504779339, 52.444683238863945, 47.169836685061455, 47.85736799240112, 44.88538406789303, 47.376773580908775, 46.92053206264973, 50.87219461798668, 47.654413282871246, 47.3043342679739, 43.65309879183769, 43.773780316114426, 43.755678087472916, 42.05118454992771, 41.78195379674435, 40.560535937547684, 42.67904385924339, 44.122130423784256, 47.91328579187393, 52.91672430932522, 54.5036331564188, 55.19836127758026, 53.02333898842335, 56.37143053114414, 45.71723163127899, 43.373756781220436, 41.27886459231377, 41.6137520223856, 43.200520277023315, 41.309905126690865, 41.66167125105858, 42.7606026828289, 41.96891136467457, 41.017997190356255, 42.35078327357769, 42.18410521745682, 41.252288818359375, 41.51135511696339, 39.91405002772808, 42.33791336417198, 45.07141448557377, 51.451838314533234, 53.21948066353798, 54.71219636499882, 53.63950252532959, 55.70920966565609, 51.203346848487854, 54.08328451216221, 47.463906705379486, 58.126157373189926, 52.68803358078003, 60.68996720016003, 33.41563493013382, 32.70438149571419, 53.61448846757412, 49.9972839653492, 55.37764325737953, 49.9503792822361, 53.496060222387314, 53.896471336483955, 56.38161018490791, 48.97490322589874, 42.691351398825645, 41.16382956504822, 42.54204221069813, 40.4868046939373, 40.94529569149017, 40.86893878877163, 40.42282372713089, 42.52262905240059, 41.929093301296234, 41.067945510149, 43.182459846138954, 42.43790879845619, 41.75040788948536, 41.43681451678276, 42.121530175209045, 41.61026380956173, 40.574815571308136, 40.64648352563381, 39.7222401201725, 41.30894757807255, 42.2132458537817, 41.37646995484829, 43.09856794774532, 40.89391864836216, 46.36127807199955, 55.98214901983738, 54.58277530968189, 54.93400186300278, 55.45281462371349, 55.85376910865307, 56.292026191949844, 56.6103845089674, 56.29834525287151, 58.58261927962303, 54.36678349971771, 49.983080327510834, 45.826422572135925, 44.17945794761181, 44.51991207897663, 52.18417301774025, 54.70603309571743, 59.07359093427658, 60.05874887108803, 62.470209673047066, 58.44971001148224, 61.20327785611153, 56.48271895945072, 16.496014930307865, 0.5907841050066054, 11.526739429682493, 0.9776834410149604, 0.05526759647182189, 0.06719747194438241, 12.457563132047653, 48.79137687385082, 37.28282041847706, 30.25216408073902, 15.035988874733448, 28.600345216691494, 46.1001218855381, 53.67816165089607, 57.15269900858402, 50.0348449498415, 5.330968117341399, 0.15464321128092706, 0.0867395412933547, 0.0544025676936144, 0.030006763481651433, 0.06344022316625342, 0.08990863803774118, 0.05471828473673668, 0.01588175062352093, 0.029917405190644786, 0.04718631331343204, 0.0177447119858698, 0.031062936104717664, 0.023423175152856857, 0.019526682772266213, 0.027527715647011064, 0.27075928053818643, 0.1639200423960574, 0.15647397085558623, 0.21337520505767316, 0.09698711641249247, 0.22145002410979941, 0.18855320027796552, 0.13225163624156266, 0.12331464939052239, 0.14195040799677372, 0.22186029818840325, 0.17728535021888092, 0.12580602429807186, 0.14496634772513062, 0.24065242731012404, 24.852064847946167, 73.01232978701591, 67.32565373182297, 67.09108471870422, 46.90846771001816, 20.727519169449806, 33.4921058267355, 56.56427778303623, 50.29152877628803, 60.80635875463486, 2.963505629450083, 0.22991556907072663, 0.3482705494388938, 16.87752205878496, 27.077578827738762, 16.375901475548744, 9.207303039729595, 47.490942254662514, 68.51296082139015, 67.88415536284447, 62.86720857024193, 55.15519939363003, 50.33675394952297, 48.821186274290085, 47.50008076429367, 50.02593442797661, 49.21501614153385, 53.52299317717552, 49.52241584658623, 47.76440218091011, 45.57673417031765, 45.96867933869362, 45.920680314302444, 44.36808742582798, 43.972783237695694, 42.65038579702377, 43.65324318408966, 45.614006370306015, 50.92390984296799, 55.55174231529236, 57.7189864218235, 57.77727149426937, 56.472843289375305, 58.89720439910889, 49.170444533228874, 44.70805898308754, 44.232187718153, 42.95753851532936, 45.97944416105747, 43.45571078360081, 44.46983456611633, 45.19282177090645, 43.71571563184261, 42.76892423629761, 44.285856038331985, 44.47391554713249, 43.090371787548065, 40.89011125266552, 41.82934105396271, 44.8334826529026, 48.25295336544514, 52.96536169946194, 56.22405543923378, 58.62569756805897, 56.58923104405403, 56.98725588619709, 53.90049532055855, 57.87053368985653, 51.69679217040539, 60.9086112678051, 54.753097370266914, 62.96000339090824, 35.71695864200592, 35.24814359843731, 54.870792254805565, 52.33355440199375, 56.578952595591545, 52.465794906020164, 55.22243678569794, 54.777803644537926, 59.2852433770895, 51.41924366354942, 45.52869714796543, 42.59100638329983, 45.454886108636856, 41.74321487545967, 43.128745928406715, 42.02461637556553, 43.16203594207764, 43.61390009522438, 44.919715225696564, 45.503249913454056, 43.589987978339195, 44.99399743974209, 44.03047934174538, 43.50157052278519, 43.758714124560356, 44.979459419846535, 42.92703755199909, 43.29060584306717, 41.99986830353737, 42.932125478982925, 45.03707192838192, 42.349210157990456, 45.406906083226204, 43.769570142030716, 48.05050402879715, 59.69841420650482, 56.00416123867035, 56.45192161202431, 55.87068200111389, 56.06003724038601, 58.95882949233055, 56.965950429439545, 58.35746996104717, 60.58809846639633, 57.5425048917532, 51.84516280889511, 47.95927852392197, 46.45662635564804, 47.56847709417343, 54.95180390775204, 56.716816797852516, 62.08399839699268, 63.51689390838146, 64.68601137399673, 61.76356539130211, 63.39382991194725, 57.89907395839691, 18.670877628028393, 6.638444233685732, 15.671303384006023, 0.6171436468139291, 0.09464991526328959, 0.15772404440212995, 14.657801818102598, 57.7335624396801, 53.38695667684078, 36.008938774466515, 18.52529413998127, 36.26890942454338, 51.61888115108013, 62.05318205058575, 62.08552211523056, 57.09686100482941, 6.6270101722329855, 0.35009742015972733, 0.2862952812574804, 0.15832093893550336, 0.12470414279960096, 0.17865413770778105, 0.26934973429888487, 0.16785784828243777, 0.12480906763812527, 0.15039069025078788, 0.11085810881922953, 0.1493018408655189, 0.12281144357984886, 0.18807141284924, 0.126732922217343, 0.17769126046914607], [0.01397059048031224, 0.014611173392040655, 0.010200958968198393, 0.028983069096284453, 0.06050200485333335, 0.04250354701071046, 0.018388081662124023, 0.07317840296309441, 0.02732848239247687, 0.030604387175117154, 0.062450747354887426, 0.06132704671472311, 0.030477268410322722, 0.06547477649291977, 0.7232293230481446, 25.055695921182632, 60.02866208553314, 53.950040861964226, 43.94395798444748, 26.94806467741728, 15.722830519080162, 30.955076962709427, 34.535575434565544, 46.38547897338867, 30.880796648561954, 0.051942503996542655, 0.05215625365963206, 0.22559006523806602, 1.9901753892190754, 12.5400329567492, 6.292803380638361, 2.3217499908059835, 46.74103729426861, 61.93371266126633, 57.68440067768097, 53.26426886022091, 47.73349463939667, 45.78519858419895, 45.10575704276562, 43.20824146270752, 42.00089804828167, 41.09522044658661, 41.29834994673729, 40.32519556581974, 40.50242565572262, 40.52905082702637, 40.763528645038605, 40.88823415338993, 42.14384637773037, 38.14254708588123, 39.94010142982006, 40.78871749341488, 41.12663336098194, 43.5335648059845, 50.11638857424259, 55.36110274493694, 54.159181639552116, 52.879273518919945, 54.0922786295414, 49.428173303604126, 43.77429708838463, 39.286247715353966, 40.5133006721735, 39.307435378432274, 40.96741810441017, 39.139123409986496, 40.37987843155861, 41.59990556538105, 40.27153864502907, 40.04790164530277, 39.652776047587395, 38.78873661160469, 38.114610984921455, 36.27102971076965, 44.75135765969753, 49.72972512245178, 54.45675507187843, 53.53791117668152, 54.44684140384197, 52.115206718444824, 54.50889207422733, 52.77275003492832, 53.681592866778374, 48.74472677707672, 55.81982932984829, 51.39861077070236, 61.417605355381966, 29.123005270957947, 36.93379394710064, 59.56566832959652, 48.8357774913311, 53.268441036343575, 48.74758422374725, 53.50688584148884, 51.500692293047905, 52.83998362720013, 42.75535896420479, 41.2670586258173, 42.087271213531494, 38.33812639117241, 38.582301288843155, 40.32287389039993, 38.85912023484707, 39.58770073950291, 39.782869666814804, 41.293999180197716, 39.29771929979324, 40.40706977248192, 38.16826790571213, 39.71807174384594, 39.47290509939194, 39.09259490668774, 40.24588242173195, 39.487044140696526, 40.20831383764744, 40.573820024728775, 39.65887472033501, 39.38305892050266, 39.642262011766434, 39.731823205947876, 39.58758294582367, 50.37787914276123, 55.6542494148016, 54.32232208549976, 51.03700317442417, 53.83200399577618, 56.16697110235691, 53.18063534796238, 56.50394842028618, 54.557240679860115, 57.3684324324131, 52.41597197949886, 52.31406144797802, 44.65606637299061, 41.21119782328606, 45.1923543959856, 55.39500452578068, 54.0954552590847, 60.244665294885635, 56.48149162530899, 59.25396345555782, 58.23255926370621, 60.67589655518532, 57.80390426516533, 43.06412659585476, 2.4611706845462322, 1.4249814860522747, 2.66237273812294, 0.026513192351558246, 0.20700293214758858, 2.620544107630849, 39.35921140015125, 38.435150384902954, 38.546655401587486, 34.91406552493572, 26.74298208206892, 34.03873689472675, 45.27395121753216, 45.12980215251446, 52.590333223342896, 12.349735368043184, 0.4123867949238047, 0.03649523816420697, 0.05184120454941876, 0.0812421937007457, 0.07047497419989668, 0.10633158686687239, 0.007386941388176638, 0.04776908106578048, 0.014863747583149234, 0.02579549287474947, 0.00815171390058822, 0.05135473416885361, 0.030901656282367185, 0.04240764297719579, 0.05545986467041075, 0.0415799293841701, 0.009424218860658584, 0.010675617140805116, 0.02736325201112777, 0.04563095360936131, 0.04511913517490029, 0.058886330807581544, 0.06937825062777847, 0.020216638913552742, 0.049611904250923544, 0.041511815070407465, 0.02263396789203398, 0.03219720492779743, 0.027295043073536362, 1.1022735899314284, 33.487112894654274, 69.91419643163681, 57.91159048676491, 53.44677306711674, 33.33482466638088, 15.340056158602238, 29.565288238227367, 38.724143877625465, 49.84329342842102, 35.940800830721855, 0.021448837833304424, 0.051933850554632954, 0.3982600138988346, 6.64640243165195, 13.18330043926835, 5.8161636069417, 5.147465514019132, 47.386455461382866, 64.67705145478249, 57.94977843761444, 56.48882903158665, 49.86336775124073, 47.96512261033058, 46.738024055957794, 44.86768461763859, 43.535723090171814, 42.53015264868736, 43.91420558094978, 42.39318899810314, 42.50443562865257, 42.305029928684235, 42.760063111782074, 42.53467820584774, 43.036794662475586, 40.232244953513145, 41.450805366039276, 43.22407901287079, 44.386972412467, 45.76255939900875, 52.094155848026276, 57.76553392410278, 55.68258449435234, 54.51518073678017, 55.081502348184586, 53.004849180579185, 45.078922882676125, 40.35690486431122, 41.60087451338768, 41.70404277741909, 41.91887564957142, 40.84930144250393, 41.36255130171776, 42.53222353756428, 40.93352012336254, 41.01269647479057, 43.04496802389622, 40.781193897128105, 42.477392479777336, 38.83532591164112, 47.40578502416611, 53.62863890826702, 56.45149223506451, 54.35706362128258, 55.971733778715134, 53.83707292377949, 56.6394529491663, 54.342312812805176, 56.37386620044708, 49.16631035506725, 58.71423281729221, 52.413247525691986, 61.365768536925316, 30.908204577863216, 37.201945558190346, 61.85367755591869, 51.63383714854717, 55.425623282790184, 51.786752343177795, 55.4469059407711, 53.701796382665634, 54.769288301467896, 45.35951882600784, 42.92805589735508, 40.6818900257349, 40.35067319869995, 40.137326046824455, 42.56383404135704, 40.68646498024464, 40.78889608383179, 41.363980025053024, 43.35673749446869, 40.306557565927505, 41.45516373217106, 40.85864894092083, 41.20914213359356, 41.63643300533295, 41.27869360148907, 40.39956897497177, 41.80174693465233, 41.01209990680218, 42.29521885514259, 41.14970572292805, 40.669939666986465, 41.232617273926735, 42.27829456329346, 41.012791469693184, 53.008166402578354, 57.07613691687584, 54.4430074095726, 50.54699286818504, 54.72803771495819, 56.43378518521786, 56.69694386422634, 58.05327348411083, 56.319517716765404, 58.642348274588585, 53.597256392240524, 55.08418880403042, 46.032637506723404, 42.81794920563698, 47.30130963027477, 57.11285814642906, 56.491184905171394, 62.55924269556999, 57.40008473396301, 60.97308240830898, 61.22074171900749, 62.983486130833626, 60.96647076308727, 47.19273805618286, 3.655562256462872, 3.054410289041698, 8.288097213953733, 0.18639503483427688, 0.055827216638135724, 2.675643526017666, 44.39682148396969, 40.772138983011246, 33.765729144215584, 35.992671847343445, 35.08116535842419, 39.59053918719292, 50.77773168683052, 49.064293429255486, 61.741241589188576, 17.74997804313898, 0.46954101242590696, 0.06478878713096492, 0.03784028805966955, 0.041539322774042375, 0.0016012919195418363, 0.02730542571953265, 0.03807593107922003, 0.022473964563687332, 0.045699272013735026, 0.03428948992223013, 0.022764428176742513, 0.056916002940852195, 0.07596959068905562, 0.051075085502816364, 0.040015203776420094, 0.13558319653384387, 0.1418966319761239, 0.1606750165228732, 0.05866728963155765, 0.21633809607010335, 0.15864694956690073, 0.13963330420665443, 0.1250575386802666, 0.12395930854836479, 0.26392965170089155, 0.10764384496724233, 0.17826100724050775, 0.23787170386640355, 0.15539021260337904, 1.4830275275744498, 40.91063015162945, 78.47288757562637, 68.00289139151573, 57.34664440155029, 38.8144688308239, 24.016786068677902, 41.7391262948513, 48.902942687273026, 60.01552239060402, 38.60028952360153, 0.18635694781551138, 0.326023010420613, 0.9506531758233905, 7.43661230430007, 27.152461409568787, 16.17026600986719, 5.14738904312253, 51.76024116575718, 66.71884149312973, 62.853829488158226, 58.58552612364292, 54.26036261022091, 50.77417507767677, 48.274741396307945, 47.330613657832146, 44.39779423177242, 44.880220144987106, 45.39074935019016, 44.013080075383186, 45.05615450441837, 45.06491303443909, 44.97236140072346, 44.62153002619743, 46.414946392178535, 41.70281544327736, 42.90653385221958, 45.16691096127033, 46.303562968969345, 48.12036707997322, 55.15791244804859, 62.386507764458656, 58.094094693660736, 57.66594886779785, 58.4172597527504, 54.767445400357246, 47.81124226748943, 42.572729364037514, 45.48066772520542, 43.5038959980011, 43.37150350213051, 44.20103698968887, 44.315722435712814, 44.97017651796341, 43.94296243786812, 43.05217623710632, 43.68439391255379, 42.6588137447834, 44.42622810602188, 39.725496545434, 51.182835549116135, 56.214077174663544, 59.31515157222748, 58.37244115769863, 59.32388350367546, 54.887822940945625, 59.577060118317604, 56.9600835442543, 59.411901980638504, 52.079868614673615, 61.37027129530907, 56.16221755743027, 63.0836221575737, 33.11510145664215, 40.01029126346111, 62.86180146038532, 55.711580738425255, 58.24194476008415, 53.67125742137432, 56.56094156205654, 54.97579202055931, 56.900745928287506, 48.476206585764885, 45.27449458837509, 43.74433949589729, 42.36510470509529, 41.63002274930477, 45.19176162779331, 43.63564632833004, 43.33343714475632, 44.2057791352272, 47.07427941262722, 42.79073126614094, 44.32261906564236, 40.9812493622303, 43.99582140147686, 44.65962678194046, 43.55326674878597, 43.17458286881447, 42.8646183013916, 42.80536808073521, 44.70651626586914, 43.541555777192116, 42.402411103248596, 43.40531408786774, 44.44946385920048, 44.615845531225204, 55.67993603646755, 60.36956079304218, 56.20312236249447, 53.496728986501694, 55.93563951551914, 60.81133648753166, 58.46029244363308, 60.64443424344063, 58.72464045882225, 62.41708092391491, 55.75284652411938, 58.59428845345974, 48.17245088517666, 46.38881519436836, 49.88269351422787, 60.76560594141483, 58.389559239149094, 65.21598413586617, 59.21271666884422, 64.09911766648293, 64.22110632061958, 65.6830170750618, 61.85313418507576, 50.400161147117615, 4.234279040247202, 5.182549981400371, 6.375363450497389, 0.15192295802989975, 0.40358438913244754, 3.4062186861410737, 51.88696436583996, 51.80886335670948, 52.09409885108471, 47.01029844582081, 38.369071930646896, 43.625189289450645, 60.37191666662693, 55.170520171523094, 70.68493187427521, 20.90136744081974, 0.6219236715696752, 0.22241917991777882, 0.1444178115343675, 0.10497733805095777, 0.20064645214006305, 0.1967599435010925, 0.11632002628175542, 0.12677310209255666, 0.15368739928817376, 0.11445757700130343, 0.12793745758244768, 0.23082545696524903, 0.11193426747922786, 0.14228041138267145, 0.20390363439219072], [0.01419334610545775, 0.03767115260416176, 0.029442282248055562, 0.04024750342068728, 0.04635502627934329, 0.050066195108229294, 0.030517789673467632, 0.10712527669966221, 0.05195562516746577, 0.006960134114706307, 0.03838765907858033, 0.0214004182635108, 0.05353114160243422, 0.050372620462439954, 1.4856088953092694, 48.636595979332924, 47.127244770526886, 50.845976024866104, 24.229897633194923, 37.53875948488712, 49.71707180142403, 33.49801830947399, 34.361689165234566, 48.1663978099823, 14.700946602970362, 0.37779000762384385, 0.2861729159485549, 0.9416961064562201, 4.494566023349762, 4.366491520777345, 2.9347098246216774, 3.6207520868629217, 44.702670872211456, 58.89120452105999, 57.62844108045101, 50.49506865441799, 52.47542358934879, 51.85031533241272, 53.42584379017353, 49.172443225979805, 47.77712769806385, 41.680054664611816, 41.97796627879143, 40.67376226186752, 40.68150244653225, 41.71663150191307, 43.360001519322395, 38.06960240006447, 40.067831575870514, 39.90665562450886, 38.95979963243008, 40.62910705804825, 41.688482612371445, 39.82239134609699, 46.480975449085236, 52.14658543467522, 53.587627708911896, 50.08005112409592, 54.03145909309387, 53.414125218987465, 51.02277673780918, 38.4772065281868, 39.826407730579376, 39.934823513031006, 40.172234773635864, 37.81766451895237, 38.959001675248146, 40.3401705622673, 40.68025231361389, 38.081020787358284, 40.46989180147648, 39.868923649191856, 38.76835070550442, 39.550398141145706, 53.76603953540325, 50.20731009542942, 53.44710364937782, 49.15054880082607, 48.643431812524796, 49.61154006421566, 50.310018584132195, 50.605904906988144, 52.79673054814339, 50.31306602060795, 55.16350954771042, 48.53568099439144, 57.85039857029915, 26.647029630839825, 37.30470344424248, 57.04517237842083, 49.0218611061573, 50.97532868385315, 48.723987489938736, 48.07439714670181, 42.864424511790276, 43.03785480558872, 37.95028880238533, 40.60770660638809, 39.46065075695515, 39.564768970012665, 38.78354988992214, 39.05712381005287, 40.14806047081947, 40.755716264247894, 39.89135384559631, 40.25089055299759, 39.17659319937229, 39.36518847942352, 39.88628871738911, 39.01771992444992, 40.22982068359852, 39.94490437209606, 39.63201396167278, 39.53043021261692, 41.877093091607094, 39.74020555615425, 39.98476043343544, 39.54921640455723, 41.462964713573456, 38.17915432155132, 43.20373870432377, 49.12106238305569, 56.07254236936569, 50.24066090583801, 53.00506956875324, 54.5784929394722, 51.10089294612408, 51.2749046087265, 54.74453642964363, 53.394016698002815, 54.52727548778057, 53.16298149526119, 49.843187034130096, 40.71000471711159, 42.85587877035141, 51.08551137149334, 58.433002308011055, 58.52854058146477, 52.99020476639271, 55.40817081928253, 59.554850310087204, 57.14678272604942, 60.110239908099174, 54.24395129084587, 62.28637553751469, 8.665959388017654, 0.6607603188604116, 4.813114330172539, 0.1322126289596781, 0.21714535978389904, 0.3454620548291132, 33.808374255895615, 39.613372161984444, 45.73142766952515, 25.957436934113503, 9.864373281598091, 26.390982270240784, 47.3296333104372, 50.83380527794361, 53.538902923464775, 27.530744411051273, 1.1877008434385061, 0.0920225640584249, 0.11607955559156835, 0.06077809121052269, 0.04335853453085292, 0.018374806495558005, 0.013929045981058152, 0.018846984967240132, 0.03187390313541982, 0.024785756431811024, 0.07260792146553285, 0.02944883355667116, 0.06100653168687131, 0.06173470843350515, 0.03258300668676384, 0.020353006693767384, 0.02689467481104657, 0.012750399509968702, 0.06714891322189942, 0.03177923848852515, 0.047219476182362996, 0.027188964195374865, 0.09520029198029079, 0.009373739831062267, 0.032270714655169286, 0.037266485451254994, 0.08515895227901638, 0.11736350817955099, 0.02728243955061771, 2.291129333898425, 58.67517091333866, 53.706565126776695, 57.319316267967224, 29.278574623167515, 42.059935480356216, 46.78682863712311, 28.251753821969032, 39.079611003398895, 54.22907128930092, 17.713099122047424, 0.4185916838468984, 0.5639295210130513, 2.171744015067816, 4.4008611515164375, 7.1307329926639795, 5.356535520404577, 4.724400965496898, 46.91935412585735, 61.813718900084496, 60.204756036400795, 52.194683253765106, 53.391839414834976, 55.219837725162506, 55.30374862253666, 51.21271714568138, 48.934070616960526, 44.630740731954575, 43.927611261606216, 43.01945619285107, 43.164581805467606, 43.594695925712585, 45.06506122648716, 40.11900343000889, 43.04509721696377, 42.48487047851086, 41.242470145225525, 41.9392691552639, 42.794793248176575, 43.2117410749197, 50.66948689520359, 54.08623315393925, 54.94157485663891, 51.39844357967377, 55.28656214475632, 54.254921302199364, 51.970491483807564, 40.71401730179787, 42.33309902250767, 40.05659557878971, 40.480728819966316, 40.09538769721985, 41.16348758339882, 41.181449219584465, 42.8567261248827, 40.406860783696175, 42.72779144346714, 40.49775190651417, 42.02609829604626, 41.53693914413452, 54.459741711616516, 54.11079503595829, 54.23658348619938, 51.10292583703995, 51.67350322008133, 50.760970786213875, 53.383495062589645, 52.45784193277359, 54.63342659175396, 50.69003999233246, 56.80470608174801, 49.29203800857067, 59.461287930607796, 27.547070235013962, 39.448438212275505, 59.44755166769028, 50.97474351525307, 52.891322672367096, 48.32636542618275, 50.26679590344429, 45.64517989754677, 44.6790437400341, 39.86637018620968, 41.94977179169655, 40.28293803334236, 42.24169872701168, 39.598461762070656, 40.97581185400486, 41.25228501856327, 42.65319004654884, 41.107394993305206, 41.16332419216633, 41.060410514473915, 41.549075692892075, 41.51044696569443, 41.183428913354874, 40.45343868434429, 41.82661660015583, 42.05977588891983, 41.361441761255264, 42.748374938964844, 40.357889011502266, 41.683903858065605, 41.707793176174164, 43.64349290728569, 41.52854919433594, 45.060547068715096, 50.72928808629513, 56.75919212400913, 52.57881984114647, 53.32824222743511, 56.93899467587471, 54.801563769578934, 54.48606289923191, 55.19374452531338, 55.20697541534901, 57.15780593454838, 55.46383783221245, 50.122943222522736, 42.64708757400513, 45.62871918082237, 53.22416961193085, 60.39188079535961, 61.09234660863876, 56.361820846796036, 56.842134073376656, 62.10847668349743, 60.2782516926527, 63.65570425987244, 56.05690620839596, 65.80181390047073, 10.687209628522396, 0.22714750666636974, 5.711680613458157, 0.34601201594341546, 0.1723075727932155, 0.3179325914243236, 36.44184194505215, 43.11366833746433, 42.59378403425217, 28.85649137198925, 15.384226888418198, 33.06769520044327, 54.943235367536545, 54.495345801115036, 58.844071850180626, 37.07862317562103, 1.7133627366274595, 0.09387946207425557, 0.02500395341485273, 0.04110778245376423, 0.05038912582676858, 0.020435522383195348, 0.029582694733107928, 0.0712255972030107, 0.045191791432444006, 0.007885044469730929, 0.06453061621868983, 0.030543781540472992, 0.049187451440957375, 0.06395252770744264, 0.01919989659654675, 0.07634792273165658, 0.08895376115106046, 0.14707805472426116, 0.1306665869196877, 0.13076026079943404, 0.1616838327026926, 0.17768444755347446, 0.2549024345353246, 0.08573842118494213, 0.12912557664094493, 0.10909072123467922, 0.140328963752836, 0.17410698405001312, 0.14461847342317924, 3.0984812742099166, 67.36093863844872, 60.63765540719032, 66.30220904946327, 34.29304204881191, 47.50052534043789, 57.2862808406353, 46.76825903356075, 47.71992936730385, 59.559455662965775, 20.417009331285954, 0.4861424403497949, 0.9128552384208888, 2.774633914232254, 12.633273303508759, 12.645221762359142, 9.100368227809668, 5.168371517211199, 49.8466182500124, 63.602681905031204, 63.263740092515945, 54.86991070210934, 56.98751427233219, 57.1653713285923, 57.9980244487524, 53.43427173793316, 52.34336547553539, 45.81357926130295, 45.599487349390984, 45.02788782119751, 44.38647843897343, 45.47999896109104, 48.807750195264816, 41.97838805615902, 44.72062110900879, 43.800002709031105, 43.18184047937393, 44.95607927441597, 46.02884531021118, 44.886102229356766, 52.01834611594677, 58.515093103051186, 57.38186851143837, 52.027655616402626, 57.32899434864521, 56.66943334043026, 55.974196046590805, 42.49315403401852, 43.83930400013924, 42.89109148085117, 43.39375130832195, 40.97192086279392, 42.58950926363468, 42.931927889585495, 43.90357755124569, 41.502984166145325, 45.37939175963402, 43.338623866438866, 42.87073977291584, 44.95555870234966, 57.67887197434902, 56.5769387036562, 55.473542511463165, 52.054383382201195, 52.19387389719486, 50.985941514372826, 52.7009566873312, 54.0592660009861, 57.23114959895611, 53.29998314380646, 60.61437025666237, 51.07226528227329, 61.27019986510277, 30.467376932501793, 40.79878695309162, 62.92570263147354, 53.76515418291092, 55.619439482688904, 53.643872290849686, 52.81733304262161, 47.36857742071152, 46.9011265039444, 41.6522591561079, 44.81254197657108, 44.02275435626507, 43.92135299742222, 43.50196570158005, 43.15795876085758, 44.322360679507256, 44.062549620866776, 42.83414013683796, 42.272796258330345, 42.69132100045681, 43.84097971022129, 42.988214269280434, 43.30110467970371, 42.32956141233444, 44.25791993737221, 43.923245295882225, 45.04560627043247, 45.06072945892811, 41.929427683353424, 44.23444479703903, 43.86528700590134, 45.931057557463646, 42.192738354206085, 46.918943747878075, 54.01111878454685, 60.58286614716053, 53.171249851584435, 54.87137742340565, 59.53278109431267, 56.16859741508961, 56.799325570464134, 58.730689734220505, 57.168642953038216, 59.90405537188053, 57.57052458822727, 54.02546301484108, 45.57450369000435, 46.8500230461359, 57.16001741588116, 63.60373064875603, 64.08980056643486, 60.89208975434303, 58.067708909511566, 65.66669315099716, 62.221760004758835, 68.16600903868675, 56.40563629567623, 74.33706030249596, 12.46800972148776, 1.8968261545524001, 11.620434802025557, 0.2853936015162617, 0.459219430340454, 0.6821364280767739, 42.22633995115757, 53.022753819823265, 61.24123401939869, 32.744252756237984, 17.438332065939903, 37.231701761484146, 61.33850879967213, 61.871711388230324, 66.47490978240967, 41.76111191511154, 2.2840194404125214, 0.2922555583063513, 0.22037723480025306, 0.19283359637483954, 0.10938212551991455, 0.0859081800444983, 0.16501839127158746, 0.20934075670083985, 0.20237748190993443, 0.11159105386468582, 0.18082025897456333, 0.07257735240273178, 0.14143617387162521, 0.13327676482731476, 0.10553892119787633], [0.0030433984966293792, 0.06918869126820937, 0.033442272688262165, 0.034263088018633425, 0.06647151050856337, 0.050260949501534924, 0.07717334679909982, 0.02980358014610829, 0.02422692850814201, 0.056967240816447884, 0.07698012865148485, 0.10538594229728915, 0.0954836216988042, 0.06248239253181964, 5.523296697065234, 50.55373750627041, 56.22739925980568, 45.69638215005398, 37.02442668378353, 28.057251758873463, 12.292744126170874, 29.0923086181283, 37.640540823340416, 48.3361878991127, 6.680798185989261, 0.6869023223407567, 1.7937326990067959, 7.96500482596457, 4.660119814798236, 7.991228643804789, 2.5594868464395404, 6.701634842902422, 38.869691267609596, 64.12888526916504, 53.78729559481144, 58.32033835351467, 56.2450797110796, 60.916214659810066, 56.68821953237057, 56.927766278386116, 52.482696399092674, 50.89620552957058, 45.89959144592285, 48.248192220926285, 47.85765677690506, 48.17251168191433, 46.233802512288094, 43.88256847858429, 40.825784504413605, 40.51808841526508, 38.84952574968338, 41.04449316859245, 39.762719348073006, 39.38135661184788, 41.99235610663891, 51.33428402245045, 51.498085632920265, 53.406776413321495, 51.19440972805023, 54.216661155223846, 52.32843227684498, 48.24071802198887, 41.92075274884701, 40.87732873857021, 39.058601930737495, 38.72263915836811, 38.94366569817066, 39.342689886689186, 39.70863685011864, 39.48566861450672, 39.325632601976395, 39.64620999991894, 38.11658687889576, 45.74196830391884, 53.35966654121876, 51.85037612915039, 51.84475623071194, 46.080161556601524, 51.38925947248936, 46.150112003088, 49.69070881605148, 49.46952648460865, 55.01225106418133, 53.35077501833439, 57.61294171214104, 49.04547303915024, 57.93294154107571, 28.79126977175474, 39.31458279490471, 57.98135854303837, 47.84355193376541, 47.66754537820816, 39.22091782093048, 40.8052846044302, 37.71337151527405, 40.39241015911102, 41.46959915757179, 42.03604996204376, 39.65184889733791, 39.89515744149685, 37.12339237332344, 39.17832970619202, 38.00778351724148, 41.8415118008852, 40.267111882567406, 41.478167697787285, 40.388956144452095, 39.07588340342045, 39.4829935580492, 41.12335413694382, 39.18149493634701, 40.52362471818924, 38.43310609459877, 41.32208727300167, 41.713230684399605, 43.13281551003456, 43.486021757125854, 43.83947119116783, 41.89444296061993, 39.45827208459377, 46.76402986049652, 50.69325461983681, 53.69718722999096, 51.005886644124985, 51.22953504323959, 53.637595027685165, 51.46857641637325, 45.56426323950291, 45.50806425511837, 49.92267496883869, 51.61340944468975, 45.55826336145401, 41.7923728376627, 41.64140313863754, 48.09595339000225, 53.65715257823467, 56.916659474372864, 40.88301703333855, 35.629316344857216, 64.26462918519974, 57.07753524184227, 58.82482208311558, 54.72711816430092, 60.36632716655731, 58.117752224206924, 25.783482268452644, 1.0779246152378619, 8.153863716870546, 1.7561151925474405, 0.10646091352100484, 0.08133451687172055, 17.174356430768967, 48.321201503276825, 32.880118265748024, 45.92436231672764, 28.14533293247223, 22.221633195877075, 34.54882152378559, 42.81965531408787, 52.80615024268627, 45.96362181007862, 3.0596613697707653, 0.08284849813207984, 0.09968756916350685, 0.020245822015567683, 0.08300190005684271, 0.011643078996712575, 0.04768454673467204, 0.037148331830394454, 0.07535024618846364, 0.04673326184274629, 0.08875715881003998, 0.029293412990227807, 0.02639330024976516, 0.029090140596963465, 0.05701740628865082, 0.05967979057459161, 0.029935354032204486, 0.012003301708318759, 0.033197783268406056, 0.0482179134269245, 0.03755540354177356, 0.07312036701478064, 0.042522026487858966, 0.04488307284191251, 0.019440411815594416, 0.05560296558542177, 0.03680033507407643, 0.01042642621541745, 0.11284920197795145, 7.642181748524308, 60.73692508041859, 61.87382407486439, 53.203080743551254, 39.81243208050728, 38.68313267827034, 18.123471401631832, 29.407784789800644, 45.91370768845081, 52.226787731051445, 7.585023315623403, 1.0014702240005136, 2.7246580459177494, 20.220628269016743, 7.7640872821211815, 8.945967312902212, 5.961976982653141, 8.600028175860643, 44.75343994796276, 65.85959360003471, 56.71353377401829, 59.4889884442091, 59.555142894387245, 62.36897550523281, 59.88818362355232, 58.47731553018093, 55.8597157895565, 51.891729310154915, 47.95705944299698, 48.49128037691116, 49.41530339419842, 50.11124365031719, 49.266324788331985, 44.61426481604576, 42.42795333266258, 42.77197167277336, 41.7515554279089, 42.420794516801834, 41.03773333132267, 41.638807877898216, 45.807993561029434, 53.391075655817986, 55.23857831954956, 55.242731496691704, 51.547779366374016, 55.18209435045719, 53.242013454437256, 50.318001955747604, 44.02233637869358, 43.05374935269356, 40.87284117937088, 40.80967336893082, 41.30996972322464, 41.03985361754894, 41.52912676334381, 41.03074170649052, 42.07225061953068, 40.367046520113945, 40.97878709435463, 47.85503871738911, 55.83048015832901, 53.24345737695694, 53.21334399282932, 47.47946687042713, 51.63316838443279, 47.765382528305054, 50.75785115361214, 48.87999191880226, 54.97928783297539, 53.9483917504549, 60.46214662492275, 51.58073499798775, 58.50017510354519, 27.34054371714592, 41.53790049254894, 60.797079652547836, 49.526341035962105, 49.35053966939449, 42.910394445061684, 43.40771935880184, 41.21445804834366, 41.90530277788639, 43.12833555042744, 43.48661072552204, 42.36194707453251, 42.725785151124, 39.55659180879593, 42.44155280292034, 40.06868273019791, 41.10605366528034, 42.42383815348148, 43.209035620093346, 42.8274866938591, 41.87874220311642, 41.39084458351135, 42.04907946288586, 41.38843171298504, 42.146707624197006, 41.481868699193, 42.10181683301926, 43.474823758006096, 44.77750025689602, 44.95275065302849, 45.39606526494026, 45.518460497260094, 41.27842001616955, 47.51466058194637, 53.460250943899155, 56.47615671157837, 52.300925552845, 51.815854981541634, 55.395088121294975, 54.06675919890404, 47.39756226539612, 46.06288008391857, 52.93816275894642, 54.512984454631805, 48.50841365754604, 45.18302209675312, 44.2227566242218, 50.037652999162674, 55.382294207811356, 59.923574924468994, 42.01303459703922, 38.97090643644333, 64.54772159457207, 59.92420569062233, 61.23476296663284, 58.138195127248764, 60.61000809073448, 62.437778413295746, 29.67904083430767, 0.44118921970948577, 6.772017991170287, 2.602235502563417, 0.3434393461793661, 0.11775433798902668, 18.48860900849104, 51.62985876202583, 34.88136447966099, 37.78765752911568, 22.56346855312586, 27.35239528119564, 37.42980793118477, 50.15133149921894, 59.755312353372574, 55.63526563346386, 4.333571512252092, 0.14283421682193875, 0.09177232670481317, 0.0446783328516176, 0.04146301143919118, 0.03828322034678422, 0.02773288608295843, 0.04974048504664097, 0.10140724407392554, 0.02523610834032297, 0.12466227082768455, 0.06714628601912409, 0.031844057666603476, 0.04872392084507737, 0.04534029147180263, 0.08300351051730104, 0.2109167815069668, 0.09758048574440181, 0.13526221766369417, 0.16275003174087033, 0.2455676713725552, 0.24086726421955973, 0.1046216489339713, 0.14555677073076367, 0.1611406696611084, 0.24944245407823473, 0.23120367026422173, 0.19923913234379143, 0.1679028818034567, 11.365125551819801, 68.6592073738575, 70.7155354321003, 61.96667209267616, 47.87293195724487, 39.802165031433105, 18.314097672700882, 43.028191924095154, 52.47501701116562, 61.89435437321663, 8.642707485705614, 1.3362347544170916, 2.6370862824842334, 18.405991941690445, 13.391363024711609, 19.65850543230772, 10.969975255429745, 9.139720816165209, 43.94717261195183, 69.5806959271431, 58.426459059119225, 63.18964406847954, 63.044035881757736, 66.65805235505104, 60.22187031805515, 60.02825550734997, 58.92721138894558, 55.714008808135986, 49.79202277958393, 51.60188466310501, 52.28554777801037, 53.61024409532547, 51.98924347758293, 48.66512484848499, 44.10575330257416, 44.417682364583015, 43.343134224414825, 43.75262305140495, 43.089874014258385, 43.269653767347336, 47.709191143512726, 56.27330839633942, 58.01485374569893, 57.94214464724064, 52.16039389371872, 57.41429977118969, 55.38041710853577, 51.648511961102486, 46.70713551342487, 45.25561340153217, 43.75276744365692, 42.89089769124985, 42.61198125779629, 43.26700150966644, 43.23736310005188, 41.568481251597404, 44.13382239639759, 43.90241101384163, 43.27447950839996, 50.541179180145264, 57.84034051001072, 54.4067307561636, 54.00402456521988, 48.367851600050926, 53.32025125622749, 49.95890222489834, 52.375979125499725, 51.12203121185303, 54.47725497186184, 54.356273263692856, 62.56221033632755, 52.00220078229904, 59.96766395866871, 31.627114601433277, 43.38066101074219, 63.04856523871422, 52.10107907652855, 52.700979486107826, 44.2861258238554, 45.40214113891125, 42.256555929780006, 43.46705697476864, 44.68600496649742, 47.17549838125706, 44.114059656858444, 44.92987968027592, 42.42679439485073, 43.66972669959068, 41.45919531583786, 43.950660824775696, 44.3538723886013, 46.66993550956249, 44.98661443591118, 43.71155105531216, 44.298942536115646, 44.35047537088394, 43.91221068799496, 44.263722226023674, 42.35652856528759, 44.90604355931282, 46.436187252402306, 49.06584374606609, 47.98840396106243, 47.635193914175034, 46.74691557884216, 41.99613310396671, 51.862470880150795, 57.77822144329548, 59.439659491181374, 53.36624778807163, 53.4989632666111, 59.39316898584366, 58.318085074424744, 49.83531765639782, 48.02369646728039, 56.193421483039856, 56.951845586299896, 49.64632339775562, 47.00913190841675, 46.48585818707943, 53.51160138845444, 58.47957640886307, 61.468214839696884, 45.34915678203106, 45.54151386022568, 66.71403855085373, 62.21215412020683, 62.925235256552696, 60.215167477726936, 64.54767599701881, 64.37271058559418, 31.643991395831108, 1.8242838908918202, 18.80440816283226, 5.417820531874895, 0.18064711592160165, 0.16462965431855991, 21.896915920078754, 60.89862920343876, 44.05068665742874, 57.95729823410511, 37.42175996303558, 33.54745365679264, 44.7020249068737, 57.21173644065857, 67.00499653816223, 63.70913319289684, 6.229529175907373, 0.24549988360377029, 0.18327240395592526, 0.29207468207459897, 0.1168846373911947, 0.2259307258646004, 0.24274608527775854, 0.08912095217965543, 0.23826649674447253, 0.10615863677230664, 0.18817707983544096, 0.1272451228578575, 0.1650804199744016, 0.11159535832121037, 0.12457900185836479], [0.013666052036569454, 0.036362816754262894, 0.02478525733749848, 0.012507753399404464, 0.05442252404463943, 0.06751117034582421, 0.06091370385547634, 0.023715655552223325, 0.09728551915031858, 0.047705267497804016, 0.03545590487192385, 0.013684986079169903, 0.06858088716398925, 0.06814040767494589, 14.283296763896942, 51.94868065416813, 48.852716982364655, 40.90972200036049, 29.128912054002285, 13.71629973873496, 27.6612389087677, 31.757504604756832, 41.65417805314064, 41.347249522805214, 1.593409941997379, 0.06899842686834745, 0.3678510175086558, 5.417640516534448, 3.8653915096074343, 3.4956941474229097, 3.6841858830302954, 9.349736496806145, 40.38511075079441, 64.4842877984047, 57.637378200888634, 57.609054520726204, 53.90424571931362, 54.098270907998085, 47.38109394907951, 56.121791526675224, 54.770101457834244, 56.660006046295166, 53.474142998456955, 57.34351336956024, 51.804432794451714, 52.8808618336916, 47.960692048072815, 42.01216444373131, 40.50409756600857, 39.73377250134945, 38.61880972981453, 43.98151136934757, 44.3119378387928, 43.04256655275822, 41.61624848842621, 45.44831246137619, 50.92938914895058, 53.67129161953926, 50.55712692439556, 52.93611466884613, 53.33528324961662, 50.997808277606964, 49.495718479156494, 45.60986079275608, 41.841017827391624, 37.99329109489918, 39.12536434829235, 38.34668733179569, 38.63864466547966, 39.540191888809204, 39.966164231300354, 37.562831193208694, 38.674792125821114, 46.46987244486809, 52.824256271123886, 49.257817044854164, 46.80977560579777, 48.61947789788246, 50.726206451654434, 48.84596474468708, 51.24272793531418, 51.96224592626095, 53.22006583213806, 49.885417968034744, 51.75968639552593, 47.20181576907635, 57.62522265315056, 25.32483547925949, 38.007772117853165, 57.19798117876053, 48.670383766293526, 49.62189070880413, 40.49624338746071, 44.00776036083698, 43.420695662498474, 46.08945965766907, 43.46726596355438, 43.63910794258118, 43.17930981516838, 44.29542772471905, 40.85612967610359, 40.050895884633064, 37.79560290277004, 39.050291776657104, 40.99491722881794, 40.861080810427666, 40.37938445806503, 41.75715632736683, 41.0676035284996, 39.56856496632099, 39.6917961537838, 39.18660566210747, 39.55275021493435, 41.608082726597786, 45.47564439475536, 49.48091447353363, 45.05931593477726, 46.016499772667885, 43.65699738264084, 44.47147227823734, 48.12395788729191, 50.731670558452606, 53.3707619458437, 50.859902277588844, 53.592806831002235, 56.04260757565498, 51.27093382179737, 47.68076866865158, 42.59164474904537, 41.47330775856972, 41.538949236273766, 40.1826386153698, 42.997185587882996, 41.68736167252064, 47.40465648472309, 55.27672067284584, 56.11733056604862, 45.22249437868595, 54.521036222577095, 57.356577068567276, 53.94295044243336, 54.731092751026154, 51.03074111044407, 59.12752903997898, 62.01406314969063, 49.791863188147545, 2.441076412796974, 4.018321903422475, 1.7209347803145647, 0.05865458406333346, 0.02039757266175002, 6.133706867694855, 46.40255905687809, 29.215570203959942, 58.50955680012703, 55.97739167511463, 22.705155350267887, 32.70093508064747, 50.11329174041748, 49.2964343726635, 44.234858974814415, 6.900859102606773, 0.2543828421039507, 0.05693795937986579, 0.0032900106907618465, 0.02143120625987649, 0.014736399680259638, 0.051133258748450316, 0.05439859349280596, 0.040690324385650456, 0.02409950175206177, 0.056520627476857044, 0.05364689066482242, 0.013434859120025067, 0.030778817854297813, 0.053498101187869906, 0.008815314522507833, 0.05117797314596828, 0.03494672477245331, 0.04382263286970556, 0.050590407408890314, 0.02937139230198227, 0.005451321912914864, 0.05161029643204529, 0.056249765839311294, 0.040978719262056984, 0.02114111186529044, 0.03609238927310798, 0.07315619790460914, 0.05264086867100559, 20.347459763288498, 62.9346739500761, 55.3192213922739, 49.33280222117901, 32.52155050635338, 17.447449676692486, 23.876146115362644, 35.98265938460827, 45.95553204417229, 47.156168818473816, 1.5981797548010945, 0.302839771611616, 0.3380358876893297, 7.927160281687975, 6.3387153670191765, 8.30737927928567, 6.375328302383423, 10.84354653954506, 42.29777991771698, 66.94677606225014, 60.708145424723625, 59.48513925075531, 57.21475347876549, 56.680859327316284, 50.77926680445671, 58.908307403326035, 57.59099788963795, 57.59136646986008, 57.12227404117584, 57.814509496092796, 54.74447563290596, 54.619420543313026, 50.51109999418259, 43.68403673171997, 42.86277160048485, 41.53741791844368, 41.12724132835865, 45.360198989510536, 44.888553097844124, 45.352667793631554, 43.743199557065964, 48.01467575132847, 53.84748816490173, 54.29286606609821, 51.422169506549835, 53.863481506705284, 56.195173189044, 52.778533324599266, 51.36530935764313, 47.388727739453316, 43.36699694395065, 40.267651453614235, 41.23406119644642, 41.32704220712185, 40.065646693110466, 41.86053358018398, 41.99409641325474, 39.62004080414772, 40.711049661040306, 47.97934904694557, 55.952210426330566, 52.161856815218925, 49.49881911277771, 51.03667639195919, 51.81922160089016, 49.21323403716087, 50.97807213664055, 54.21280816197395, 54.46053206920624, 51.62307612597942, 54.159215837717056, 49.36953105032444, 57.58712209761143, 25.77149961143732, 40.336648151278496, 60.270545706152916, 48.74174013733864, 50.2381606400013, 41.405785381793976, 45.12105502188206, 46.33820950984955, 48.278051018714905, 46.076278164982796, 45.75776405632496, 45.46196512877941, 46.52486689388752, 41.53871364891529, 41.82706117630005, 40.43741874396801, 40.06512992084026, 42.858550027012825, 42.35084407031536, 41.57325379550457, 42.91069082915783, 42.33907230198383, 40.81275500357151, 40.416071489453316, 40.503812581300735, 41.78167641162872, 43.05576704442501, 48.066200986504555, 51.35022796690464, 46.89935199916363, 46.62661023437977, 46.52411833405495, 47.70775482058525, 50.890832617878914, 52.522837445139885, 55.516434609889984, 53.341020941734314, 52.95809268951416, 56.53639107942581, 54.83904495835304, 48.927690759301186, 44.5195434987545, 43.646308556199074, 44.06811252236366, 41.965487748384476, 44.79027517139912, 43.18677641451359, 49.52085793018341, 56.180574372410774, 58.928947895765305, 50.886649042367935, 58.59847582876682, 59.869492426514626, 57.18345835804939, 56.33128188550472, 54.217105731368065, 62.1935199201107, 65.19896864891052, 55.13167105615139, 3.107389658689499, 4.142185756936669, 8.650999590754509, 0.6184193096123636, 0.00831379709779867, 6.3829924911260605, 50.026625990867615, 33.86784486472607, 53.10074083507061, 51.32698081433773, 29.48114935308695, 38.732590824365616, 55.60414530336857, 53.99779289960861, 53.714841082692146, 10.069004651159048, 0.2009596533025615, 0.0765730235434603, 0.04338818333053496, 0.029726381944783498, 0.07774100071401335, 0.009096749909076607, 0.0798762783233542, 0.027327576972311363, 0.02963213290058775, 0.03528910347085912, 0.03747242401004769, 0.023519572714576498, 0.01242273017851403, 0.03645979319117032, 0.0726993614807725, 0.2053706080187112, 0.14454307121923193, 0.12086906499462202, 0.1811473976704292, 0.1628288032952696, 0.16434812801890075, 0.07041261153062806, 0.2959083201130852, 0.08304483329993673, 0.1322475544293411, 0.18300910480320454, 0.34428904589731246, 0.1436851336620748, 26.016856245696545, 69.98288914561272, 63.39705593883991, 53.38144697248936, 41.524586006999016, 21.249556057155132, 37.11796246469021, 46.25999070703983, 54.54698123037815, 52.02689565718174, 2.2566191107034683, 0.4755492619005963, 1.0435596155002713, 8.84132282808423, 6.8581161461770535, 10.485729239881039, 9.762737285345793, 15.160201359540224, 44.39373604953289, 68.42314124107361, 62.47848182916641, 61.82506889104843, 58.916685953736305, 57.29008063673973, 51.034871488809586, 61.4739753305912, 59.9355024844408, 60.44977828860283, 58.35384115576744, 61.330411434173584, 58.14408101141453, 56.42113946378231, 53.30090269446373, 46.72977849841118, 45.2894201874733, 43.667807802557945, 42.21798799932003, 47.828865721821785, 48.05940315127373, 47.284761518239975, 47.29031302034855, 50.78245483338833, 54.470175951719284, 57.930745258927345, 52.39881210029125, 54.78525124490261, 59.68231827020645, 54.739224314689636, 53.27369995415211, 49.15616109967232, 45.029289945960045, 41.40500262379646, 44.42180894315243, 42.537178471684456, 41.82389594614506, 43.30908045172691, 45.10365195572376, 41.505625024437904, 43.737507462501526, 50.276774168014526, 56.476092115044594, 54.121176078915596, 51.69087588787079, 52.82206378877163, 53.70567597448826, 51.43454164266586, 51.05961196124554, 54.85215425491333, 55.8985611051321, 55.19742272794247, 56.54260754585266, 51.48827835917473, 60.428396835923195, 27.927245534956455, 42.35075667500496, 62.91190177202225, 53.49987901747227, 52.814581990242004, 45.2601807564497, 47.41900831460953, 47.712595760822296, 50.866513922810555, 47.83314049243927, 48.597784861922264, 47.8724379837513, 49.007843658328056, 43.6154580116272, 43.932729586958885, 42.81516395509243, 43.07556018233299, 44.89892274141312, 44.461380019783974, 43.375360295176506, 44.89139914512634, 46.60486780107021, 42.734912261366844, 43.7669862806797, 43.09843875467777, 42.59129136800766, 46.21368259191513, 50.157791152596474, 53.1143669039011, 47.41290584206581, 48.52476418018341, 47.05686874687672, 50.87326616048813, 52.79676474630833, 54.512821063399315, 58.081334978342056, 54.66006316244602, 55.369481295347214, 58.518839702010155, 56.91548153758049, 51.710862815380096, 46.7590407282114, 46.87871530652046, 46.10916920006275, 44.44091431796551, 49.052065685391426, 46.000574827194214, 51.850919499993324, 58.38268920779228, 63.46386395394802, 53.319574892520905, 58.211367800831795, 61.867090836167336, 60.378087535500526, 58.679985255002975, 55.01618765294552, 64.59167003631592, 65.18002286553383, 57.690837532281876, 4.241286339238286, 9.791141711175442, 6.371329966932535, 0.3697327774716541, 0.21168874867726117, 7.814335310831666, 57.76964150369167, 41.98939226567745, 73.97781237959862, 65.69235697388649, 35.56231454014778, 44.115286991000175, 64.33347389101982, 60.86433984339237, 62.149419486522675, 13.328171465545893, 0.41785669047385454, 0.1917298001353629, 0.17700977594358847, 0.13936046103481203, 0.1255149836651981, 0.20913052110699937, 0.18082757655065507, 0.13290439965203404, 0.15031303191790357, 0.1305832585785538, 0.14020103233633563, 0.11111730389529839, 0.08422740109381266, 0.14408852061023936], [0.01598823582753539, 0.019674629911605734, 0.07326936058234423, 0.028244220266060438, 0.04512034487561323, 0.031949049298418686, 0.03652145453088451, 0.0383793210494332, 0.08484330945066176, 0.08352478020242415, 0.07494014280382544, 0.033969401629292406, 0.03443383022386115, 0.2741104632150382, 29.621147140860558, 58.48393477499485, 49.517122730612755, 46.82908236980438, 36.30316838622093, 26.41523826867342, 44.737777188420296, 37.06884630024433, 49.33771915733814, 32.12319888174534, 0.10255470086121932, 0.10729927322245203, 0.5678080441430211, 1.6042121686041355, 6.008975235745311, 7.197441263124347, 3.90702563803643, 21.004729494452477, 49.53726164996624, 59.05483894050121, 53.0389903485775, 56.27559207379818, 55.80144211649895, 54.839466735720634, 51.1406996101141, 53.75848934054375, 53.213663175702095, 56.03054702281952, 56.98381707072258, 54.18668456375599, 54.025193229317665, 54.11802224814892, 46.51132442057133, 40.14657475054264, 40.00775299966335, 39.07711833715439, 42.61569365859032, 49.71247784793377, 49.79577697813511, 49.63647812604904, 45.42522110044956, 46.789089515805244, 50.78750096261501, 53.60757663846016, 50.526173785328865, 48.672226667404175, 51.92801736295223, 52.65506274998188, 52.17990204691887, 50.794260799884796, 47.91786074638367, 40.39990335702896, 38.273586854338646, 39.801340475678444, 39.3098558485508, 38.953571766614914, 38.936841264367104, 37.39824302494526, 40.63948430120945, 45.87366543710232, 52.06942677497864, 51.499886736273766, 50.58240696787834, 49.78089317679405, 51.62618815898895, 50.46016372740269, 50.2142409235239, 47.12119549512863, 49.17948044836521, 50.302096009254456, 51.21036887168884, 47.278640046715736, 52.280030474066734, 28.7889176979661, 41.417386159300804, 53.86271394789219, 48.23059156537056, 47.85427875816822, 43.29246774315834, 47.46224619448185, 47.15102769434452, 45.29273360967636, 45.58842994272709, 46.221928149461746, 44.57681402564049, 47.33110763132572, 44.27467703819275, 42.4815646559, 37.74829164147377, 38.866362646222115, 40.23363187909126, 41.380110159516335, 39.08418595790863, 38.96717883646488, 39.23634499311447, 41.3069336861372, 37.892170920968056, 40.35940133035183, 42.724124640226364, 49.529772251844406, 50.31434655189514, 51.355471685528755, 50.955619141459465, 50.66613927483559, 49.4028514623642, 50.33187501132488, 52.80219465494156, 51.87209956347942, 53.91010120511055, 50.315832272171974, 52.17927888035774, 55.03182001411915, 52.63771288096905, 45.373000502586365, 41.22889347374439, 40.874216705560684, 39.68237265944481, 43.61985057592392, 42.05847255885601, 42.472794726490974, 43.8643142580986, 53.65196205675602, 56.22195415198803, 60.25490194559097, 61.29782438278198, 56.7955257743597, 49.5136459171772, 46.50942072272301, 50.536429435014725, 58.83301064372063, 57.778639420866966, 64.21097606420517, 11.611138600856066, 1.2123440648429096, 5.682094926014543, 1.6024165274575353, 0.030298030469566584, 1.0225631296634674, 43.92585575580597, 37.44176208972931, 60.30777610838413, 56.46772116422653, 16.162181943655014, 26.558766067028046, 40.14294974505901, 49.8825491219759, 46.087932139635086, 12.220212668180466, 0.11675727742840536, 0.042745631872094236, 0.04325912756030448, 0.03741367931070272, 0.044476082766777836, 0.0144266940333182, 0.012331665875535691, 0.010461148522153962, 0.04713716829428449, 0.05682602866727393, 0.039653384519624524, 0.014448643050855026, 0.017331113085674588, 0.08837497502099723, 0.02026253889198415, 0.04380658021545969, 0.06307184332399629, 0.00902725056221243, 0.06211612038896419, 0.031503857171628624, 0.0402524127275683, 0.019043290449189954, 0.013386179798544617, 0.055979672324610874, 0.08120179860270582, 0.0630753833684139, 0.0831808170187287, 0.6130962108727545, 37.276900336146355, 65.0117526948452, 55.232107266783714, 51.041182950139046, 41.4699487388134, 22.952769063413143, 35.571912825107574, 40.828683748841286, 53.820030838251114, 37.397365272045135, 0.02855796876247041, 0.057632939860923216, 2.3217343166470528, 5.816699378192425, 8.258686792105436, 12.493509203195572, 9.32906560599804, 20.254467353224754, 49.812701269984245, 60.35789541900158, 53.44891615211964, 56.7547881603241, 57.7369936555624, 56.59861274063587, 51.03159986436367, 53.66553872823715, 54.628673046827316, 56.822891905903816, 58.889209628105164, 55.414185896515846, 56.38851821422577, 56.41945995390415, 49.38226796686649, 41.946853548288345, 42.39222005009651, 41.86233848333359, 44.57350820302963, 52.73304596543312, 52.804660722613335, 51.545111909508705, 47.9926635324955, 49.68689002096653, 52.4432697147131, 55.08724004030228, 51.27219155430794, 49.392250031232834, 55.21147057414055, 55.17196409404278, 53.82849298417568, 52.28919938206673, 50.70575974881649, 42.20136769115925, 38.38987201452255, 41.24345049262047, 40.01048505306244, 40.714359283447266, 40.32363764941692, 38.98799031972885, 42.202317640185356, 48.52885276079178, 53.80125604569912, 52.01416254043579, 52.15048782527447, 51.70411817729473, 53.49803611636162, 51.76365718245506, 51.90802663564682, 50.03603048622608, 50.38074038922787, 51.414854899048805, 52.869386449456215, 50.15045374631882, 53.601287975907326, 29.9313909932971, 42.47266933321953, 56.53239369392395, 51.64182431995869, 50.79000122845173, 44.591492637991905, 50.671489387750626, 48.99058498442173, 49.469891265034676, 47.14745968580246, 49.19296592473984, 47.067698165774345, 48.62394645810127, 47.99706369638443, 45.296005234122276, 39.06918816268444, 40.65309517085552, 41.533006355166435, 43.696636855602264, 42.495844289660454, 40.66925190389156, 39.39786672592163, 43.14698874950409, 39.5244113355875, 41.74700327217579, 43.173868507146835, 51.60896748304367, 51.79896488785744, 54.840557277202606, 51.98877610266209, 51.29521831870079, 50.80972217023373, 52.02674366533756, 53.46968583762646, 54.5175252109766, 55.194987058639526, 50.050439313054085, 51.71172916889191, 57.25582927465439, 55.46236351132393, 48.63720014691353, 42.45934724807739, 42.866472601890564, 41.89814396202564, 46.587160751223564, 43.30591142177582, 44.84561540186405, 45.028628781437874, 56.27349078655243, 57.272753566503525, 61.70652285218239, 61.879086792469025, 59.74029555916786, 52.08566330373287, 49.78681705892086, 51.83035120368004, 59.484671875834465, 58.465159982442856, 69.96864750981331, 12.689797170460224, 0.20512440794846043, 14.684158153831959, 3.4595504868775606, 0.07674661930650473, 1.1098915874026716, 46.99721574783325, 40.044987201690674, 53.874725103378296, 58.58530193567276, 26.865493208169937, 34.597018137574196, 47.81390592455864, 56.24081254005432, 55.381701439619064, 16.21686100959778, 0.11007858658558689, 0.06073584074329119, 0.034294117212994024, 0.028869385059806518, 0.0274841738428222, 0.016752332521718927, 0.028940887277713045, 0.049897445569513366, 0.03627615617006086, 0.03486830202746205, 0.06124251609435305, 0.03378386471013073, 0.03081106046010973, 0.0569925554736983, 0.1355133010656573, 0.15991324646165594, 0.2248688758118078, 0.07809952483512461, 0.13390095555223525, 0.10902251044171862, 0.13513262383639812, 0.131098487181589, 0.18074604420689866, 0.2193072359659709, 0.16339130670530722, 0.1430627834633924, 0.21921145438682288, 0.7602193881757557, 45.34596115350723, 74.22775536775589, 62.75552116334438, 61.78840845823288, 49.57765728235245, 37.668271735310555, 58.28017830848694, 50.59879168868065, 61.41786374151707, 38.818667605519295, 0.20115261169848964, 0.14571125619113445, 3.0853513162583113, 5.928087551146746, 13.828191384673119, 14.612615592777729, 10.185772385448217, 25.46386431902647, 52.0024249702692, 59.933385998010635, 55.32480329275131, 58.228132501244545, 58.47758911550045, 57.02498786151409, 52.26071611046791, 54.526686519384384, 56.85298629105091, 58.45033697783947, 60.500307977199554, 57.68138363957405, 58.61334063112736, 58.983151987195015, 51.60552866756916, 42.89739154279232, 45.30491195619106, 44.19001758098602, 47.99164518713951, 57.33762368559837, 55.71767941117287, 54.60844673216343, 49.983999878168106, 51.851588264107704, 55.673028007149696, 57.13145434856415, 52.04301059246063, 51.13522790372372, 54.01960372924805, 57.29291908442974, 56.54360309243202, 55.019546672701836, 52.73827448487282, 44.4002640992403, 40.772575959563255, 43.72275285422802, 43.81515249609947, 42.98091486096382, 43.280456587672234, 39.92490604519844, 44.168985709548, 49.77260962128639, 57.29323826730251, 54.333736672997475, 54.48444798588753, 54.83374044299126, 54.75240960717201, 53.61031249165535, 53.94254766404629, 55.4909797757864, 53.60200233757496, 54.080837443470955, 53.513949662446976, 51.03672958910465, 55.70104390382767, 31.78436156362295, 46.11987702548504, 57.48556114733219, 54.20423962175846, 53.486610129475594, 47.57203750312328, 53.587601110339165, 51.125219240784645, 51.14444240927696, 48.928899094462395, 50.289302095770836, 49.795233607292175, 51.42627328634262, 49.07053269445896, 47.822124883532524, 41.8890168517828, 42.99494370818138, 44.393432065844536, 44.9097103625536, 44.268148988485336, 43.415611535310745, 41.671873703598976, 45.49966670572758, 40.37324778735638, 45.18451541662216, 46.27917967736721, 52.901620119810104, 53.3246286213398, 57.541121765971184, 54.52269673347473, 55.16121827065945, 54.3525380641222, 54.97909404337406, 57.043272480368614, 56.444287821650505, 58.55119116604328, 50.93308635056019, 54.17727246880531, 61.05144560337067, 58.13630282878876, 49.712447449564934, 44.63015556335449, 44.95635285973549, 43.19914475083351, 48.320369347929955, 46.5310225635767, 46.79013065993786, 47.08702012896538, 59.66927357017994, 59.2341323196888, 64.01191234588623, 67.10060700774193, 63.94042298197746, 55.30771180987358, 50.78460171818733, 54.71584036946297, 62.45392754673958, 61.35851472616196, 70.7929676771164, 15.000810362398624, 6.30296403542161, 13.623769953846931, 2.909593884833157, 0.2007982658687979, 1.6918619466014206, 53.59338819980621, 48.33389662206173, 68.53447526693344, 61.64720043540001, 26.04015849530697, 37.60783977806568, 55.68070739507675, 63.3232145011425, 64.93235975503922, 20.85517141968012, 0.44154313509352505, 0.176484290859662, 0.14321514638140798, 0.11234806675929576, 0.16730273666325957, 0.13418470829492435, 0.08068196126259863, 0.16007162077585235, 0.14633353217504919, 0.23139526310842484, 0.13852802367182449, 0.16910447826376185, 0.09498095765593462, 0.18303119111806154], [0.020990047705709003, 0.05445025068183895, 0.057694311763043515, 0.03162093838909641, 0.09074410336324945, 0.028917162671859842, 0.03102600127022015, 0.011580050249904161, 0.04294191508961376, 0.028816800186177716, 0.03391669801203534, 0.013292355633893749, 0.05901735326915514, 0.9530589217320085, 33.29763226211071, 52.70829029381275, 46.392128616571426, 39.13881942629814, 23.618772625923157, 16.50944910943508, 35.4633754491806, 36.0903912037611, 54.727817326784134, 20.17227966338396, 0.21010732103604823, 0.13215300481533632, 0.5010752531234175, 5.519928177818656, 4.882651548832655, 15.511711947619915, 13.392661605030298, 28.33079718053341, 50.72157450020313, 54.44622203707695, 56.73658333718777, 59.217622205615044, 58.00236761569977, 56.93771794438362, 56.517513692379, 57.746911123394966, 54.384091570973396, 59.16075825691223, 50.99203258752823, 52.994996309280396, 53.39015990495682, 53.71167205274105, 41.475519239902496, 38.22765491902828, 39.89522583782673, 41.6466810554266, 50.08253239095211, 52.52699442207813, 52.76931121945381, 51.01843737065792, 51.372441574931145, 49.98878002166748, 52.19029448926449, 52.87087596952915, 49.48034070432186, 48.0855343490839, 50.156187638640404, 46.776819974184036, 52.10126146674156, 56.977912187576294, 48.90274129807949, 43.47459577023983, 38.0572796612978, 38.91979157924652, 37.492230981588364, 39.74930986762047, 37.96944737434387, 38.361096158623695, 40.607949793338776, 46.20291776955128, 48.64332161843777, 50.59623822569847, 49.02150772511959, 49.37960051000118, 48.308339193463326, 47.95817278325558, 47.344752699136734, 48.56748528778553, 51.57896429300308, 49.10076767206192, 52.84261308610439, 51.035574451088905, 52.38077066838741, 32.62034900486469, 41.742481514811516, 55.24955593049526, 48.60386833548546, 50.19664406776428, 45.821748822927475, 51.35963626205921, 48.006639182567596, 48.47272217273712, 48.328945487737656, 48.325643464922905, 46.29663974046707, 47.690959721803665, 47.59429670870304, 48.12897361814976, 42.93478913605213, 39.388462230563164, 40.33748410642147, 39.275596886873245, 38.603371158242226, 40.42719729244709, 39.345193952322006, 41.22468329966068, 39.51996937394142, 43.34275044500828, 49.84153792262077, 53.100410252809525, 54.181767627596855, 52.09788724780083, 53.37703160941601, 52.197495102882385, 51.47801510989666, 55.70348337292671, 53.69704283773899, 49.60477642714977, 49.81744721531868, 51.64246268570423, 51.71911217272282, 54.25093151628971, 54.450489208102226, 45.15120640397072, 39.04936082661152, 40.33605918288231, 39.457827508449554, 42.35642597079277, 41.31693854928017, 40.518551990389824, 40.49968600273132, 44.570962339639664, 49.121043384075165, 47.73787580430508, 47.13072158396244, 44.42474238574505, 42.74766817688942, 46.94841876626015, 50.39169140160084, 54.76353541016579, 58.34395028650761, 69.53949853777885, 33.974569737911224, 1.9293112051673234, 19.446678198873997, 1.0445970785804093, 0.1358108429121785, 0.21424915816169232, 26.339105553925037, 50.745133236050606, 55.43625511229038, 48.40424604713917, 17.099886126816273, 23.133095987141132, 40.90254798531532, 47.68437087535858, 49.641976431012154, 22.07942582666874, 0.4561838088557124, 0.026319799799239263, 0.021611325500998646, 0.03173678764142096, 0.039063785297912546, 0.025725929517648183, 0.08473783542285673, 0.04791852734342683, 0.020539124343486037, 0.037360404239734635, 0.012397962855175138, 0.05237470111751463, 0.003620441275415942, 0.049716483990778215, 0.0909479268011637, 0.08956694582593627, 0.14336801395984367, 0.051631291789817624, 0.08694153162650764, 0.09671485211583786, 0.0251197989564389, 0.034269125389982946, 0.03067848134378437, 0.07776915037538856, 0.057044231216423213, 0.011573458123166347, 0.00730254296286148, 1.4690084173344076, 42.99045994877815, 60.63235469162464, 53.4546310454607, 44.92612928152084, 32.217832803726196, 22.50561285763979, 37.97506347298622, 38.32427613437176, 60.340682342648506, 21.609613336622715, 0.20024134340928867, 0.10632469231495634, 1.841931331437081, 6.771179661154747, 6.056522084400058, 8.371284250169992, 7.7417435310781, 30.38553312420845, 53.251094967126846, 55.04080273211002, 58.84402625262737, 59.7068003565073, 58.527089059352875, 60.00152014195919, 59.04345475137234, 56.605570167303085, 57.281192913651466, 59.33218985795975, 52.28861041367054, 55.24097219109535, 54.09873068332672, 55.00054009258747, 45.369451493024826, 40.69977566599846, 41.38892188668251, 42.77068734169006, 52.48007073998451, 55.64597725868225, 54.29593250155449, 52.53596194088459, 53.547049686312675, 53.31113174557686, 54.07524794340134, 53.935711830854416, 49.85079042613506, 48.69965739548206, 50.82123935222626, 47.76050738990307, 53.08415472507477, 58.44317056238651, 51.55585013329983, 46.83108106255531, 39.43475514650345, 40.63896752893925, 39.606091752648354, 41.07678383588791, 39.88587073981762, 39.61471349000931, 41.9042844325304, 49.11986544728279, 51.14928334951401, 52.69837662577629, 51.35226845741272, 50.45285291969776, 51.789529994130135, 49.4118607789278, 47.91547827422619, 49.81922931969166, 53.414683789014816, 50.33112645149231, 54.77542497217655, 51.98349058628082, 54.444956704974174, 32.95905523002148, 44.31169465184212, 57.54416160285473, 51.301157400012016, 51.09848387539387, 49.14896808564663, 53.23466844856739, 49.83122527599335, 51.55333086848259, 48.573336973786354, 49.974865168333054, 48.74444559216499, 49.83462609350681, 50.53999364376068, 49.83480468392372, 44.828417524695396, 40.695451498031616, 41.91811569035053, 40.51835440099239, 40.726013258099556, 41.88565783202648, 40.949019491672516, 42.28129260241985, 41.085800752043724, 45.070966109633446, 51.96175955235958, 54.509921818971634, 56.12603969871998, 53.49200204014778, 54.7754667699337, 54.43080246448517, 53.267840668559074, 55.670497342944145, 56.672431379556656, 51.82880088686943, 50.316090658307076, 51.54893450438976, 53.51557217538357, 54.74870100617409, 54.52267773449421, 47.193950191140175, 41.353560984134674, 42.503956854343414, 41.1618422716856, 42.927615121006966, 41.60702258348465, 42.91733667254448, 42.70164504647255, 47.0843792706728, 51.854392513632774, 50.32838299870491, 49.604419246315956, 47.35307805240154, 45.91599516570568, 48.50501663982868, 51.33255511522293, 57.12123289704323, 60.050385519862175, 70.66839516162872, 36.2292205542326, 0.8583574346266687, 12.230508215725422, 2.292397990822792, 0.2196064847521484, 0.07181518158176914, 28.217483460903168, 53.10900539159775, 59.42903146147728, 51.90556816756725, 18.11295546591282, 29.07349392771721, 47.23306529223919, 53.85895974934101, 57.43292257189751, 30.228063873946667, 0.6764833407942206, 0.051772800798062235, 0.012624339233298087, 0.03949473561078776, 0.03606426929763984, 0.013329620724107372, 0.15632156340871006, 0.04695947587606497, 0.033683069923426956, 0.07935364308650605, 0.05340785231965128, 0.03238155069993809, 0.035799793840851635, 0.04182834847597405, 0.15392939880257472, 0.16851579188369215, 0.18472609313903376, 0.10621856519719586, 0.21004107693443075, 0.2115497741033323, 0.26763528410810977, 0.12626890180399641, 0.12666609924053773, 0.1158151135314256, 0.1343204322620295, 0.14365203387569636, 0.24121781025314704, 2.3442766070365906, 52.92507626116276, 68.29927548766136, 59.8151895403862, 51.77800141274929, 34.654512852430344, 25.205478183925152, 50.39632335305214, 48.167473152279854, 67.05552622675896, 24.381703287363052, 0.2741549623897299, 0.36436369526199996, 2.2715128865092993, 16.41522366553545, 13.354417607188225, 28.068521954119205, 21.50733232498169, 32.670703902840614, 52.82879702746868, 59.47346247732639, 60.06202049553394, 64.9245473742485, 61.70295864343643, 61.64773240685463, 59.68478813767433, 58.119853511452675, 59.17684279382229, 60.75392156839371, 54.26563672721386, 57.52620376646519, 55.80407917499542, 58.02187576889992, 47.05661416053772, 43.42687413096428, 44.351816698908806, 45.35727694630623, 53.98738905787468, 58.75879682600498, 57.00447276234627, 55.18556356430054, 56.20016612112522, 55.14734901487827, 56.99856027960777, 55.32071851193905, 50.820996165275574, 51.70490473508835, 52.84477137029171, 48.16884867846966, 53.453871086239815, 60.366441160440445, 55.14538832008839, 49.03024725615978, 41.83382101356983, 43.23414467275143, 41.831362545490265, 43.07655572891235, 41.79718717932701, 41.706774830818176, 44.18363392353058, 51.20722644031048, 52.61415034532547, 54.44614604115486, 52.23706617951393, 52.5990005582571, 52.62456178665161, 52.502196952700615, 49.651247933506966, 51.18305593729019, 54.86945852637291, 52.45151147246361, 57.06011697649956, 54.731077551841736, 55.88917560875416, 35.236273035407066, 46.225450560450554, 58.9255128800869, 55.43165735900402, 55.09876102209091, 51.36791601777077, 57.57092736661434, 53.01375210285187, 53.53111334145069, 53.07258054614067, 52.40989990532398, 51.14577613770962, 52.48809210956097, 53.57752785086632, 52.292182222008705, 47.104837372899055, 43.548972979187965, 44.10231448709965, 41.782630160450935, 40.9622959792614, 44.13000740110874, 43.62658381462097, 45.21989531815052, 42.86789372563362, 46.82958394289017, 53.331631645560265, 57.9830988496542, 59.316701889038086, 55.77731341123581, 57.578614354133606, 58.11399042606354, 55.12423865497112, 59.981852397322655, 58.87165457010269, 52.18141816556454, 51.4626145362854, 52.839793637394905, 56.84463053941727, 57.95819878578186, 59.04018312692642, 51.42633408308029, 43.22000943124294, 45.56171737611294, 43.366012796759605, 45.07482670247555, 44.82770696282387, 45.33216409385204, 44.344502091407776, 49.333869963884354, 55.159527361392975, 52.719518691301346, 53.194952979683876, 50.017612874507904, 47.37526126205921, 52.87439078092575, 55.036448165774345, 58.32858771085739, 63.52571323513985, 72.56539016962051, 39.204894080758095, 3.030613115988672, 33.57608512043953, 3.7426604703068733, 0.29326588846743107, 0.33792216097936034, 31.02093692868948, 66.31877616047859, 65.387864112854, 57.79304824769497, 24.92530781775713, 33.42010349035263, 54.060892313718796, 60.134687796235085, 66.16682231426239, 37.24543422460556, 1.122733117081225, 0.16913878032937646, 0.07741109380731359, 0.15863908280152828, 0.18762786086881533, 0.1273035744088702, 0.16888728132471442, 0.18014150555245578, 0.10992176336003467, 0.151782009343151, 0.13639580371091142, 0.17879406223073602, 0.07137670589145273, 0.1496467465767637], [0.011916802541236393, 0.047485012910328805, 0.08292891725432128, 0.03382446389878169, 0.03590122316381894, 0.08618232939625159, 0.02723559704463696, 0.11082155062467791, 0.03191988660546485, 0.10303159011527896, 0.07874151968280785, 0.01219335274072364, 0.05138096537848469, 1.4087026845663786, 41.02424405515194, 55.74476815760136, 44.46842864155769, 29.337119981646538, 17.465945184230804, 23.530180379748344, 35.91967776417732, 36.795515567064285, 58.642143085598946, 14.262889958918095, 0.13744595751632005, 0.13846685586031526, 1.0591474478133023, 5.6085688713938, 6.733008809387684, 12.691964004188776, 22.006629332900047, 40.90772330760956, 52.917811051011086, 58.844877406954765, 59.45732094347477, 55.55115334689617, 55.317241698503494, 54.08079944550991, 55.52756421267986, 53.90420012176037, 57.225134521722794, 55.90367943048477, 54.19182948768139, 55.11900633573532, 54.146239534020424, 46.30466490983963, 38.57043072581291, 41.78058587014675, 41.260067000985146, 46.8429022282362, 52.354498878121376, 53.034913167357445, 51.851451471447945, 51.126685962080956, 52.89927564561367, 51.02179259061813, 50.817523151636124, 49.31172855198383, 50.46473108232021, 49.88636031746864, 52.269098460674286, 49.68179069459438, 48.41847628355026, 47.11160480976105, 53.35484839975834, 46.73165939748287, 37.62100227177143, 38.46568174660206, 38.186890706419945, 39.16642874479294, 38.53579558432102, 37.06699199974537, 40.709111765027046, 45.27329005300999, 48.67838233709335, 50.192357897758484, 52.37019583582878, 46.50797300040722, 48.553984612226486, 47.96330250799656, 47.95637167990208, 47.49045588076115, 47.89815500378609, 50.162920877337456, 54.68074545264244, 49.61146026849747, 55.908425375819206, 30.09740598499775, 38.41514065861702, 56.713385581970215, 48.59165579080582, 48.848069831728935, 48.530171290040016, 48.24630372226238, 47.21000052988529, 50.648550018668175, 51.328588128089905, 52.32538104057312, 48.713378459215164, 50.00643007457256, 46.968379095196724, 46.86495244503021, 48.19528765976429, 42.645328268408775, 39.134149476885796, 40.09025037288666, 40.05745053291321, 40.4122868925333, 40.43067790567875, 39.61424991488457, 37.982362881302834, 47.093149200081825, 52.5858760625124, 53.116506189107895, 51.81301273405552, 50.63462756574154, 53.16171236336231, 52.812514901161194, 54.1212672740221, 51.85680918395519, 52.943201288580894, 49.629167318344116, 51.78192280232906, 53.72358061373234, 52.30985887348652, 52.46123515069485, 47.7450118213892, 41.47995740175247, 40.86193196475506, 45.20234405994415, 46.0326337069273, 45.131318271160126, 42.08797037601471, 41.576422825455666, 43.158167749643326, 40.26325508952141, 41.055934354662895, 42.82584898173809, 45.034571662545204, 47.97825090587139, 53.09622287750244, 55.078097730875015, 55.292425230145454, 56.21929049491882, 57.323184460401535, 60.22844396531582, 43.365849405527115, 1.7123536532744765, 16.49066861718893, 3.466173056513071, 0.1358526703552343, 0.15825454640435055, 14.219493437558413, 49.57575358450413, 32.31925316154957, 36.86586879193783, 23.744665570557117, 30.322657898068428, 40.27099147439003, 50.88500373065472, 51.50418430566788, 30.703769847750664, 1.1539997393265367, 0.018820746336132288, 0.05053804146882612, 0.029584377552964725, 0.07028353720670566, 0.03310478845378384, 0.02456789712596219, 0.03756144091312308, 0.06502314994577318, 0.01547553887576214, 0.027387633417674806, 0.011585230440687155, 0.06652883399510756, 0.058758766754181124, 0.03266655025072396, 0.008122902800096199, 0.10953588367556222, 0.05605669241049327, 0.031930239565554075, 0.05437814361357596, 0.04238396846631076, 0.03793462616158649, 0.02588814630144043, 0.07383504780591466, 0.04552854094072245, 0.004865947366852197, 0.07778447572491132, 2.938856352120638, 50.79389601945877, 62.90545731782913, 50.76031342148781, 34.31023992598057, 23.326822891831398, 24.406306967139244, 36.90671660006046, 38.11472877860069, 64.17844980955124, 14.391111228615046, 0.19862405519234017, 0.02648036530445097, 3.5403073159977794, 9.476757030934095, 9.106958024203777, 4.27371047437191, 15.043264534324408, 43.11845988035202, 54.233106672763824, 58.81981015205383, 59.14695739746094, 58.36054779589176, 54.93781305849552, 57.18556344509125, 56.1488688737154, 57.21080169081688, 59.77321699261665, 57.016647309064865, 56.812548860907555, 57.671739757061005, 56.23361572623253, 47.57006160914898, 41.027181297540665, 43.3566614985466, 42.34329007565975, 49.67113986611366, 54.102678671479225, 55.58108054101467, 53.680023550987244, 53.459521383047104, 55.10500408709049, 52.98475205898285, 53.13784584403038, 48.862091079354286, 50.29146417975426, 51.37379810214043, 52.611342296004295, 49.94912534952164, 50.26490740478039, 49.66822922229767, 54.56553563475609, 49.04423050582409, 39.153684228658676, 40.859416499733925, 40.73082000017166, 40.48873119056225, 41.05552397668362, 41.02508381009102, 42.41780787706375, 47.08491124212742, 50.96288815140724, 51.825658455491066, 53.47750961780548, 48.67882311344147, 50.576072707772255, 48.546548411250114, 50.34814953804016, 49.78735662996769, 49.7881393879652, 51.45675145089626, 55.929905623197556, 53.16267371177673, 60.00839777290821, 31.048992723226547, 39.152886271476746, 58.40456463396549, 49.704961851239204, 50.59719197452068, 50.69124072790146, 51.479253843426704, 50.414189994335175, 53.776067197322845, 50.865879356861115, 52.68653646111488, 48.637830913066864, 51.381659880280495, 49.459042847156525, 50.40736936032772, 48.28052468597889, 45.160755291581154, 40.634411573410034, 41.51358179748058, 41.994977965950966, 41.31261818110943, 40.93350112438202, 42.74978846311569, 40.64565896987915, 48.76429572701454, 53.50501634180546, 55.68791180849075, 52.094456031918526, 50.18973223865032, 53.83229278028011, 54.947111159563065, 55.29793493449688, 53.56820695102215, 51.91443309187889, 49.26087588071823, 53.311762511730194, 55.467531234025955, 54.81661096215248, 54.861300364136696, 49.90660943090916, 43.363010957837105, 43.53520631790161, 45.65006643533707, 48.57324957847595, 47.306739538908005, 43.864625841379166, 42.60976977646351, 45.40190175175667, 41.683174297213554, 42.11070075631142, 43.866202756762505, 48.40234994888306, 49.56173233687878, 55.302912667393684, 57.88366578519344, 58.102480843663216, 58.22371333837509, 58.918889835476875, 61.38010896742344, 48.77738982439041, 1.2892053904943168, 3.216433357447386, 3.5317390132695436, 0.7108133111614734, 0.1737295277416706, 14.651164524257183, 54.99162197113037, 40.27984119951725, 41.698335483670235, 21.599750965833664, 30.603295639157295, 45.17182409763336, 56.502375304698944, 59.916663095355034, 39.93434853851795, 1.703656988684088, 0.054722047425457276, 0.04434231806953903, 0.05619621617370285, 0.03721771150594577, 0.08507656646543182, 0.0466025696368888, 0.06796337576815858, 0.046600758796557784, 0.045530507632065564, 0.08082867643679492, 0.0940442708088085, 0.037262322002789006, 0.04495649722230155, 0.14659887965535745, 0.08507718244800344, 0.32173841376788914, 0.194903579831589, 0.1857268050662242, 0.22162957931868732, 0.11314970499370247, 0.19594831595895812, 0.1636065443744883, 0.222516609064769, 0.21055036835605279, 0.10312676313333213, 0.14974609046475962, 5.53219866938889, 59.55207645893097, 68.49496498703957, 59.458354488015175, 39.14792753756046, 28.030780479311943, 33.48826423287392, 46.82569295167923, 48.052464723587036, 69.73945140838623, 17.88360357284546, 0.3454820334445685, 0.25821018673013896, 4.235727712512016, 15.681754723191261, 18.506169766187668, 22.122686505317688, 25.677323564887047, 45.733680948615074, 57.59105108678341, 60.622950196266174, 62.75481440126896, 61.03789173066616, 58.87480840086937, 59.894137904047966, 58.3466899394989, 59.09666329622269, 63.88399600982666, 60.78938126564026, 59.19023707509041, 60.62935285270214, 58.69113765656948, 48.28932501375675, 42.83027954399586, 46.06293708086014, 45.15206515789032, 51.903288289904594, 58.10359798371792, 59.398234114050865, 55.21707907319069, 54.085416197776794, 57.60920271277428, 54.61954213678837, 53.2310738414526, 50.59944525361061, 52.513060569763184, 53.908638283610344, 54.11599315702915, 51.99065700173378, 51.3417886197567, 52.61636562645435, 57.39710949361324, 51.6124252974987, 40.102527514100075, 42.46806018054485, 40.94807714223862, 42.89864927530289, 42.59945712983608, 42.31319949030876, 44.6922442317009, 50.129459872841835, 51.740436628460884, 54.51194331049919, 55.36233767867088, 51.603218391537666, 52.23347917199135, 51.14572674036026, 53.06016281247139, 51.21216997504234, 50.58720991015434, 53.77691835165024, 58.342783749103546, 52.750912606716156, 60.167153254151344, 33.08124527335167, 41.51889011263847, 60.88051177561283, 53.02781894803047, 52.486059218645096, 53.67382988333702, 52.05708123743534, 51.82905547320843, 55.24877317249775, 54.22084093093872, 56.24976485967636, 51.36678367853165, 53.96223060786724, 50.60206711292267, 52.206679210066795, 51.84034086763859, 47.7255492657423, 43.53061616420746, 42.990315556526184, 44.49662312865257, 44.28677938878536, 43.86174939572811, 43.96717093884945, 43.331085070967674, 51.42343483865261, 56.21011018753052, 57.80463382601738, 54.2937134206295, 52.29915864765644, 55.345265194773674, 55.114780962467194, 57.554139867424965, 53.8283371925354, 53.34698662161827, 50.888613536953926, 54.34558443725109, 59.12816360592842, 57.782564610242844, 58.502143397927284, 53.09683844447136, 45.1213476061821, 44.92882713675499, 49.722653701901436, 51.97581119835377, 49.32055927813053, 46.34870454668999, 44.86538574099541, 48.299162685871124, 45.01417055726051, 45.2081273496151, 45.57793490588665, 50.16586571931839, 51.45579010248184, 58.17320264875889, 61.34000211954117, 59.37709964811802, 60.86286172270775, 62.536014541983604, 64.67918694019318, 50.69759398698807, 2.1705599036067724, 35.78694328665733, 9.397476185113192, 0.4122815583832562, 0.2433095089509152, 16.81252084672451, 62.418638840317726, 44.733806401491165, 50.935176238417625, 31.928151547908783, 39.76930059492588, 53.32221195101738, 65.70130929350853, 65.96285685896873, 48.00847828388214, 2.816152386367321, 0.15894662879873067, 0.13757981127128005, 0.12273888380150311, 0.10534176224609837, 0.22374812891939655, 0.17375519120832905, 0.21034322009654716, 0.25212623819243163, 0.19723237986909226, 0.17262098175706342, 0.1947616515099071, 0.11115438901470043, 0.12488576117902994], [0.02978237327624811, 0.01930068767251214, 0.02470067105605267, 0.00626904851742438, 0.02275951515912311, 0.07607044113683514, 0.028563319647219032, 0.07755549348075874, 0.09595143448677845, 0.1780650208820589, 0.017021181083691772, 0.06046945425623562, 0.07176999963121489, 6.309239873662591, 52.72148318588734, 55.90891934931278, 41.45546771585941, 33.52874346077442, 19.00318119674921, 38.42657804489136, 46.54969096183777, 37.72573605179787, 54.80105459690094, 5.824063858017325, 0.12535390793345869, 0.14200675184838474, 2.595359771512449, 4.566438216716051, 3.812057333998382, 4.368787547573447, 20.544619783759117, 47.30374529957771, 54.687436893582344, 56.95811904966831, 55.883023738861084, 56.87455013394356, 53.42764109373093, 50.02473369240761, 48.85077528655529, 49.88096080720425, 53.59437994658947, 54.44964565336704, 53.53874333202839, 51.700778156518936, 44.77437302470207, 39.702161997556686, 39.087594375014305, 41.656951904296875, 47.322774678468704, 52.93961048126221, 51.77537575364113, 53.02737817168236, 50.05135126411915, 49.93660122156143, 49.00397926568985, 48.80818337202072, 51.520192846655846, 51.03844329714775, 51.277822852134705, 50.67805163562298, 51.934837996959686, 54.028673842549324, 51.89970128238201, 52.40151755511761, 53.173343539237976, 43.29829283058643, 37.14400626718998, 38.4706936776638, 38.936267495155334, 37.83087641000748, 38.25247898697853, 38.48678961396217, 37.80805483460426, 44.20112058520317, 46.2589343637228, 51.16448633372784, 50.915409699082375, 52.061424404382706, 52.18341685831547, 50.795203149318695, 48.16765934228897, 50.429647564888, 52.36673042178154, 47.5069659948349, 52.791764214634895, 46.75271786749363, 55.89747056365013, 34.45674106478691, 38.9010775834322, 57.47497871518135, 48.121605813503265, 52.480158135294914, 48.29079553484917, 50.29206834733486, 50.72307161986828, 53.13860200345516, 52.166469767689705, 51.09187602996826, 52.09272712469101, 49.38631474971771, 48.27295929193497, 47.47863471508026, 47.00817056000233, 45.48478290438652, 39.957865476608276, 38.98647800087929, 39.10187020897865, 40.52294075489044, 40.096121057868004, 37.94964663684368, 41.469542160630226, 50.155743062496185, 52.79895342886448, 48.30909535288811, 49.75857317447662, 52.022259905934334, 51.655355393886566, 50.761939734220505, 48.73516649007797, 45.92106029391289, 52.254115864634514, 54.95740480720997, 50.98491556942463, 51.292915642261505, 50.88509492576122, 45.85964038968086, 40.47517731785774, 44.37360092997551, 49.120074436068535, 51.270569041371346, 52.97183655202389, 49.31952193379402, 44.77978393435478, 40.5112411826849, 43.40086072683334, 44.38163749873638, 48.38700257241726, 51.18044167757034, 55.65138436853886, 55.92517867684364, 58.87574315071106, 57.529881969094276, 58.847845047712326, 60.206032767891884, 62.68212430179119, 64.03019696474075, 58.88351373374462, 2.1569100860506296, 1.8155426974408329, 3.214857392013073, 0.12517496128566563, 0.21705934486817569, 2.7166544878855348, 48.0696702003479, 44.087571278214455, 36.899952962994576, 25.024415999650955, 31.621262915432453, 38.86556848883629, 40.659684017300606, 48.86481933295727, 32.276684045791626, 2.426189761608839, 0.1484245777828619, 0.026987643650500104, 0.044687223780783825, 0.020314652501838282, 0.08297215477796271, 0.04433724177943077, 0.040252008257084526, 0.022334184759529307, 0.06624921501497738, 0.020388483208080288, 0.07169137650635093, 0.08644048546557315, 0.022758212689950597, 0.0496996001311345, 0.03588099221815355, 0.018850886808650102, 0.03408303557080217, 0.017938084129127674, 0.021021600114181638, 0.013650034634338226, 0.04191418527625501, 0.11930232445592992, 0.028882207516289782, 0.045875435607740656, 0.08922062261262909, 0.013291316627146443, 9.228226616978645, 62.455846443772316, 62.07522086799145, 47.72974044084549, 37.75844469666481, 24.678056985139847, 42.31506139039993, 42.06296391785145, 42.26775772869587, 60.68767972290516, 6.6755706164985895, 0.1768103608628735, 0.17284114728681743, 2.7062755823135376, 5.5699733924120665, 3.931412729434669, 4.36920172534883, 20.106256306171417, 47.97429531812668, 55.420204773545265, 58.45121093094349, 58.41962322592735, 57.11299113929272, 55.36985367536545, 52.36448474228382, 50.75090512633324, 54.520838633179665, 56.30794733762741, 56.34680785238743, 57.15371735394001, 54.09490808844566, 48.05458500981331, 40.04523038864136, 41.50112226605415, 42.98039048910141, 50.332049801945686, 54.42305468022823, 54.30464543402195, 53.89294512569904, 49.53342005610466, 50.097226202487946, 49.94727864861488, 49.43063177168369, 50.74770949780941, 51.840287670493126, 52.94791683554649, 52.48727895319462, 54.004313349723816, 55.3215354681015, 54.16789837181568, 53.27126808464527, 54.05185639858246, 45.662465170025826, 38.56111742556095, 40.673720464110374, 41.48865133523941, 40.935564413666725, 40.83977535367012, 39.92599658668041, 41.40500262379646, 46.54175318777561, 47.453787848353386, 52.70788751542568, 51.72925382852554, 54.41701680421829, 53.747553527355194, 52.057582810521126, 49.2463568598032, 49.41172398626804, 52.49737501144409, 50.50409696996212, 55.52346423268318, 49.71239045262337, 57.04771064221859, 35.19924782216549, 39.94532994925976, 59.661123007535934, 49.69665169715881, 53.82806360721588, 50.864910408854485, 54.37655657529831, 52.44323171675205, 53.89038026332855, 53.2249865680933, 54.22971345484257, 53.66936892271042, 52.63034127652645, 49.38210837543011, 48.603830337524414, 49.161921590566635, 47.66179248690605, 42.56929434835911, 39.55272741615772, 41.687779650092125, 42.64150947332382, 41.13966666162014, 40.834299847483635, 42.81500056385994, 53.262095376849174, 54.00706820189953, 49.318161606788635, 51.395893916487694, 53.099768087267876, 53.14065769314766, 52.898234501481056, 49.207002371549606, 47.068085744977, 53.46023574471474, 57.73651108145714, 53.03242430090904, 53.94403338432312, 53.4419397264719, 46.979862079024315, 42.42932505905628, 45.19333854317665, 51.51356220245361, 54.28880788385868, 53.75712141394615, 51.244646832346916, 45.932292491197586, 44.43397209048271, 46.79919317364693, 46.19353227317333, 50.506878420710564, 52.16797448694706, 57.55649954080582, 59.70996178686619, 61.053733080625534, 60.38217231631279, 61.01627089083195, 63.74321736395359, 64.90028187632561, 66.13949418067932, 62.01582245528698, 2.6426456216722727, 3.554001306183636, 6.395113365724683, 0.6549476995132864, 0.29116739169694483, 2.764611477032304, 52.244863361120224, 48.97284373641014, 38.83474454283714, 26.15186110138893, 35.46130836009979, 44.47088710963726, 48.51800814270973, 54.783009365200996, 45.13106748461723, 3.2057718420401216, 0.1469449431169778, 0.06119615041825455, 0.04766541416756809, 0.0368720488040708, 0.006964968279135064, 0.13049535860773176, 0.02581393524451414, 0.02034717341302894, 0.004035107012896333, 0.022160132575663738, 0.03544617531588301, 0.09282665880164132, 0.03375591171788983, 0.14997375168604776, 0.08382703468669206, 0.05525226741156075, 0.05784911634691525, 0.0906706381647382, 0.22772832628106698, 0.1135898134089075, 0.20021177624585107, 0.20746420661453158, 0.20923075557220727, 0.08975170349003747, 0.18585117417387664, 0.2820661378791556, 12.081140130758286, 69.97185453772545, 70.71110486984253, 54.57119733095169, 45.46365223824978, 28.522388599812984, 49.56911914050579, 61.15914702415466, 49.569552317261696, 66.65878191590309, 7.720954371616244, 0.32412349828518927, 0.4373901360668242, 5.972173735499382, 12.70614294335246, 11.180721446871758, 9.696741476655006, 23.009108640253544, 49.89819288253784, 55.90107277035713, 59.55532528460026, 60.87346315383911, 59.100417494773865, 59.350238889455795, 54.778814390301704, 53.38728345930576, 54.714776426553726, 57.30798527598381, 58.87059822678566, 58.678218349814415, 56.7550503462553, 49.74427834153175, 42.47263893485069, 43.47801558673382, 47.84155324101448, 52.96899050474167, 56.89088545739651, 56.84468373656273, 55.45709319412708, 49.787455424666405, 49.95420567691326, 50.44279865920544, 52.32557103037834, 52.63043627142906, 53.4789003431797, 53.91270786523819, 55.12127101421356, 55.67230224609375, 58.12753289937973, 55.68978130817413, 55.63395470380783, 57.086517959833145, 49.316702485084534, 39.544599652290344, 43.96589420735836, 42.536988481879234, 42.684139385819435, 42.71029718220234, 43.46132308244705, 42.29207642376423, 49.16458144783974, 50.56511029601097, 55.90642288327217, 54.08880181610584, 55.3781296312809, 55.54907485842705, 54.13333162665367, 50.487936437129974, 52.83557206392288, 53.16797062754631, 53.167203068733215, 56.51403307914734, 51.64619028568268, 57.61632353067398, 39.62343782186508, 43.926684111356735, 61.84359289705753, 51.80634029209614, 56.80557243525982, 53.302331417798996, 55.8705186098814, 54.79783616960049, 54.990501031279564, 56.56687304377556, 55.34817583858967, 56.16168178617954, 53.61909382045269, 53.29002007842064, 50.21940864622593, 51.60484850406647, 50.32351166009903, 44.44029875099659, 42.08945609629154, 42.38460145890713, 45.47612316906452, 43.7935696542263, 43.58632117509842, 44.332308545708656, 55.70491209626198, 55.53629234433174, 53.26985076069832, 52.0926359295845, 54.37853626906872, 54.390007853507996, 52.696947902441025, 49.504260420799255, 47.17355288565159, 53.85121576488018, 59.47149038314819, 55.73287099599838, 56.867284923791885, 56.628475338220596, 50.48637472093105, 45.27418300509453, 47.753686755895615, 54.53848488628864, 56.162662133574486, 56.64535403251648, 53.1937712430954, 48.48090313374996, 46.048767641186714, 48.01083415746689, 48.39118234813213, 54.38759118318558, 55.803019031882286, 59.532393515110016, 61.76696240901947, 63.5662342607975, 62.10376873612404, 64.66109231114388, 65.58188170194626, 69.04296398162842, 66.82812362909317, 64.61436241865158, 3.271476016379893, 8.426242601126432, 7.547323163598776, 0.4783339484129101, 0.7245908968616277, 3.3786245668306947, 58.795757442712784, 57.06609025597572, 52.510719895362854, 33.569298684597015, 42.253500893712044, 49.07515324652195, 57.88110852241516, 61.45322844386101, 58.54215905070305, 4.701605988666415, 0.5387786112260073, 0.1289092405932024, 0.11892857888597064, 0.14688141527585685, 0.20334840402938426, 0.19371960195712745, 0.1368172693764791, 0.14399937383132055, 0.1429849915439263, 0.13431969011435285, 0.10511832384509034, 0.14933615777408704, 0.10949905088637024], [0.029662494162039366, 0.0472107782115927, 0.027149292691319715, 0.05669500620570034, 0.03092033242865, 0.05656390952935908, 0.024155977334885392, 0.06393487943569198, 0.029995573750056792, 0.13076940405881032, 0.19278988387668505, 0.01628671834623674, 0.00976539899056661, 13.593021053820848, 50.61111822724342, 51.70043617486954, 45.61857372522354, 35.93130514025688, 21.71672198921442, 23.218281716108322, 32.44265154004097, 42.00884722173214, 52.14671082794666, 2.0703269820660353, 0.09693072061054409, 0.21086349530378357, 5.070873023942113, 6.813484691083431, 4.203893495723605, 5.462050158530474, 36.879422664642334, 47.273578718304634, 54.98043917119503, 54.83262710273266, 57.845299243927, 55.065843388438225, 54.918377101421356, 51.22068151831627, 45.93305625021458, 40.55304653942585, 42.32381612062454, 42.7084618806839, 43.63615930080414, 40.98403841257095, 39.219128116965294, 40.69931209087372, 39.403916001319885, 46.40141151845455, 53.581411242485046, 53.09377200901508, 50.55701673030853, 50.68780571222305, 53.88997748494148, 45.166132003068924, 49.37327764928341, 50.845470651984215, 52.151069194078445, 49.97994549572468, 52.4717415869236, 48.08678448200226, 49.68512311577797, 50.58558739721775, 52.66406066715717, 53.91718402504921, 47.35494375228882, 37.069792449474335, 37.13650546967983, 37.22812235355377, 39.29488465189934, 36.7312990128994, 39.09075580537319, 37.547491416335106, 39.57477003335953, 38.81077162921429, 42.762251794338226, 46.94370701909065, 51.12772710621357, 49.59628388285637, 53.2600586861372, 50.96973538398743, 52.21888795495033, 50.391877591609955, 53.22186313569546, 48.65912117063999, 52.47966416180134, 47.77130641043186, 57.807966247200966, 34.771470576524734, 32.73902043700218, 55.846040323376656, 49.65964928269386, 51.05102442204952, 48.70605245232582, 52.44692511856556, 50.25183230638504, 50.35927914083004, 48.62643912434578, 51.689321771264076, 51.14767223596573, 51.93285070359707, 46.593362018465996, 46.98143519461155, 48.22414331138134, 48.57063911855221, 42.768475860357285, 38.98360915482044, 37.98835135996342, 40.524521470069885, 38.383005782961845, 40.05174703896046, 40.9002985060215, 52.34993912279606, 49.890084117650986, 49.6795754134655, 53.40799614787102, 52.40578852593899, 52.02753022313118, 53.94642725586891, 50.17951458692551, 47.523734495043755, 52.38632217049599, 49.089383482933044, 49.50812481343746, 48.266533836722374, 44.100391790270805, 40.116993337869644, 41.36736184358597, 51.051978170871735, 52.60538801550865, 54.62824746966362, 55.81096440553665, 52.29898005723953, 46.891718208789825, 43.124706745147705, 43.662894666194916, 50.93872904777527, 53.27329717576504, 56.4932481944561, 55.37303410470486, 59.207978323102, 56.76126681268215, 55.4613945633173, 55.67042514681816, 59.66894678771496, 58.110464215278625, 56.744642704725266, 55.80399177968502, 7.952804155647755, 0.9023194131441414, 4.079890474677086, 2.310285293497145, 0.05630198334984016, 0.5208391800988466, 29.36605542898178, 51.62919759750366, 37.78509646654129, 27.02868115156889, 21.992454193532467, 37.85389557480812, 44.0424183011055, 50.43331436812878, 41.64663925766945, 4.049826487898827, 0.09726215634145774, 0.04177375238214154, 0.03090268415689934, 0.03152082266751677, 0.10320242508896627, 0.04025248694233596, 0.023766828489897307, 0.030922642363293562, 0.02979220858833287, 0.05093009953270666, 0.13824636378558353, 0.0308542905622744, 0.03565998806152493, 0.030255327292252332, 0.061537965084426105, 0.029381439126154874, 0.08516864472767338, 0.02401593406830216, 0.040802488874760456, 0.010245904359180713, 0.05059501614596229, 0.046528885504812934, 0.03501112834783271, 0.047146007273113355, 0.040060500759864226, 0.04594582089339383, 17.770614735782146, 58.57922226190567, 58.29725839197636, 50.9915766119957, 39.600278064608574, 26.356451623141766, 28.97648323327303, 37.73371182382107, 47.46022090315819, 57.833291888237, 1.8981630890630186, 0.2582415350480005, 0.6980202882550657, 5.0268827844411135, 3.6400624131783843, 5.227925721555948, 7.708055963739753, 35.218512788414955, 50.518422201275826, 53.83556440472603, 58.509545400738716, 57.24121145904064, 57.01142638921738, 56.90066233277321, 53.8038133084774, 46.44866198301315, 43.52197542786598, 45.92126548290253, 44.88061532378197, 44.92841295897961, 43.09638686478138, 40.96505843102932, 43.95234793424606, 41.51108533143997, 48.491230979561806, 55.30238829553127, 55.09181499481201, 52.64750115573406, 53.447989001870155, 54.27116923034191, 45.748268365859985, 47.450322434306145, 52.74405017495155, 52.70856387913227, 52.777161598205566, 54.17997792363167, 49.91228632628918, 53.04263435304165, 52.6536226272583, 53.565630689263344, 55.07301740348339, 51.016176491975784, 38.96704204380512, 38.909752517938614, 38.500932455062866, 41.36822059750557, 39.657354801893234, 40.71094706654549, 40.719040632247925, 41.68597474694252, 42.56416842341423, 44.72122147679329, 47.954483181238174, 53.38301248848438, 52.61216305196285, 55.93582570552826, 53.80122944712639, 54.309725761413574, 52.18560554087162, 53.14174823462963, 49.40950870513916, 54.09838490188122, 50.460752695798874, 57.739740908145905, 36.45626977086067, 35.274293795228004, 56.26622557640076, 51.44364595413208, 54.068814888596535, 50.408212915062904, 54.567701518535614, 52.173449993133545, 52.09787204861641, 50.54362244904041, 53.220582604408264, 53.75418417155743, 52.88586236536503, 49.52561907470226, 48.96796099841595, 49.25558276474476, 49.588631093502045, 44.92305524647236, 41.0369847714901, 40.68134285509586, 41.82942844927311, 40.92516057193279, 42.458990067243576, 43.51745747029781, 53.624869510531425, 52.88867801427841, 52.8866071254015, 56.4120389521122, 54.878441244363785, 54.734482169151306, 55.19988499581814, 49.87899251282215, 47.53408133983612, 54.4474683701992, 51.80998809635639, 51.78174041211605, 50.94759777188301, 44.60946947336197, 42.91577495634556, 43.16773943603039, 51.544511541724205, 53.84639382362366, 56.30623362958431, 57.35852636396885, 54.89515654742718, 48.27127978205681, 46.2675940990448, 44.5251177996397, 52.85491302609444, 54.6260891854763, 59.38589237630367, 57.77856342494488, 59.79548379778862, 58.98112289607525, 56.9764606654644, 58.15727390348911, 58.45497652888298, 60.702210143208504, 53.928268030285835, 58.295628279447556, 8.182260543107986, 1.2289044074714184, 8.391699604690075, 1.270208191126585, 0.02809849214827409, 0.32866918249055743, 33.625748455524445, 57.2350899875164, 43.260363265872, 28.012910038232803, 24.127417132258415, 42.93384678661823, 53.69410179555416, 54.082467555999756, 53.89691211283207, 6.461126273497939, 0.19281142100226134, 0.10147850509383716, 0.013086289054626832, 0.05857080301211681, 0.09754713362781331, 0.11146077726152726, 0.035481995073496364, 0.02057967343716882, 0.03349849037476815, 0.07241836952744052, 0.059095705510117114, 0.06108039022365119, 0.031983247463358566, 0.09781933113117702, 0.14628652454121038, 0.20760972693096846, 0.20630657498259097, 0.09138622437603772, 0.11828722228528932, 0.12063239410053939, 0.20890133106149733, 0.16935109393671155, 0.2506161160999909, 0.3605899040121585, 0.16446356166852638, 0.1845153231988661, 21.728662848472595, 67.68470406532288, 65.88079646229744, 60.90768411755562, 47.84316435456276, 28.489522263407707, 33.40232424438, 47.85184308886528, 52.882043570280075, 63.35272751748562, 2.863432061858475, 0.4442592174746096, 1.3186572538688779, 12.492454759776592, 13.697344455868006, 11.759876869618893, 8.712599985301495, 37.43884764611721, 55.03042548894882, 57.989896684885025, 59.353772699832916, 61.39124996960163, 59.336757212877274, 59.0705206990242, 56.42780050635338, 50.154481530189514, 45.44021889567375, 46.28003463149071, 46.093179658055305, 48.1819199770689, 45.03341272473335, 44.36487279832363, 46.38097621500492, 44.23086918890476, 50.36844044923782, 58.88004072010517, 57.529349997639656, 55.55012360215187, 53.310459181666374, 54.66985143721104, 46.797365471720695, 50.55445186793804, 55.02741985023022, 55.80175369977951, 54.96231034398079, 57.032047882676125, 52.01143428683281, 54.71508041024208, 55.38988620042801, 56.58472068607807, 59.14058893918991, 51.378042474389076, 40.499199628829956, 40.48747345805168, 39.31493617594242, 43.88545252382755, 40.947457775473595, 42.60875143110752, 42.5688611716032, 44.09910745918751, 44.0621430426836, 46.9492357224226, 50.97968325018883, 55.583029836416245, 54.533837735652924, 58.88957440853119, 56.49575226008892, 56.626355051994324, 55.77985927462578, 54.6258307993412, 51.61180593073368, 56.15522973239422, 52.50283531844616, 58.094094693660736, 39.3565059453249, 36.13167218863964, 57.50560887157917, 52.699554562568665, 55.506342351436615, 52.91165918111801, 56.09253689646721, 52.724295035004616, 53.17728012800217, 52.07352675497532, 53.924228847026825, 55.549956411123276, 54.3609394133091, 51.78055867552757, 51.13889090716839, 53.40913608670235, 52.50970155000687, 46.93836070597172, 43.082498610019684, 42.88886100053787, 44.554558619856834, 41.46837942302227, 43.71267959475517, 44.71183218061924, 56.41162857413292, 56.229975521564484, 56.37740381062031, 58.26904110610485, 57.15442031621933, 56.14435851573944, 56.91298887133598, 53.209293410182, 47.662472650408745, 56.09926253557205, 53.06439198553562, 54.62143063545227, 52.807628363370895, 46.71881228685379, 45.58254025876522, 45.657198652625084, 54.069107472896576, 55.60672156512737, 58.31819906830788, 59.98224377632141, 56.476358100771904, 51.19526468217373, 48.19961942732334, 44.81473445892334, 55.029999911785126, 56.40365280210972, 61.300989612936974, 59.74495030939579, 62.39618964493275, 59.886298924684525, 60.59806153178215, 58.00649419426918, 61.98838792741299, 61.95735119283199, 59.851834774017334, 60.35944573581219, 9.487322364002466, 2.9399701673537493, 12.114734128117561, 6.842460986226797, 0.1332404589629732, 0.5090599902905524, 37.18564063310623, 64.7079361975193, 53.17857205867767, 37.83414043486118, 32.32447408139706, 48.7650290876627, 62.84632869064808, 62.79323033988476, 65.03743171691895, 10.714732501655817, 0.4823254857910797, 0.22282152785919607, 0.12251077729160897, 0.12971171003300697, 0.24549540103180334, 0.14694008947117254, 0.14604808733565733, 0.1785670392564498, 0.09093718050280586, 0.1743755376082845, 0.2448769990587607, 0.15125723672099411, 0.14637332613347098], [0.022268506545515265, 0.04304439455154352, 0.025347838673042133, 0.04429544402228203, 0.0333405465062242, 0.019353584248165134, 0.06054462639440317, 0.06448276253649965, 0.0859923247480765, 0.039335437322733924, 0.074332761723781, 0.040874302794691175, 0.2214217185974121, 20.00416338443756, 49.77791793644428, 51.18610717356205, 33.69871214032173, 35.006731152534485, 17.002995125949383, 26.198442801833153, 35.56271731853485, 50.48278011381626, 39.99442331492901, 0.3640930191613734, 0.07646427664440125, 0.49175248306710273, 1.772967881988734, 2.048512827605009, 3.206861433573067, 10.147321298718452, 28.740077018737793, 50.07704548537731, 57.6987487077713, 53.06421339511871, 58.4208619594574, 58.61353822052479, 57.094881311059, 54.5632329583168, 53.232168182730675, 44.110039472579956, 41.04663625359535, 41.13467752933502, 41.18767708539963, 38.77303585410118, 41.66917584836483, 38.605909422039986, 44.13264065980911, 49.8329009860754, 54.31645520031452, 51.67938910424709, 53.6800729483366, 48.67892950773239, 47.94502168893814, 46.27784974873066, 50.67908897995949, 50.65326936542988, 50.12263163924217, 47.54548452794552, 46.91631808876991, 46.50737263262272, 45.02439580857754, 48.79628621041775, 46.831031665205956, 45.875515937805176, 39.9747783690691, 36.03023663163185, 38.286844342947006, 37.587879449129105, 39.43867273628712, 38.30902375280857, 37.90861263871193, 38.06862585246563, 39.227195084095, 37.586097344756126, 39.37457017600536, 42.70514465868473, 44.60667662322521, 45.26334598660469, 48.8444372266531, 45.12695610523224, 48.97805705666542, 46.02880351245403, 50.91152250766754, 49.27505671977997, 51.72738432884216, 50.07663890719414, 58.94132003188133, 35.65700925886631, 31.626126654446125, 52.424377128481865, 47.51160554587841, 52.799310609698296, 50.62527246773243, 50.6014933437109, 50.802054181694984, 50.90526804327965, 53.19243371486664, 53.68288479745388, 52.292592599987984, 48.248750790953636, 41.70035317540169, 47.27536842226982, 46.435765475034714, 46.50097377598286, 45.053601041436195, 39.752239510416985, 38.893288001418114, 38.76703977584839, 37.63604186475277, 37.98956349492073, 38.94702471792698, 49.87875312566757, 51.93205274641514, 54.410245567560196, 53.44936452805996, 50.40825851261616, 49.85271692276001, 54.49201337993145, 50.775429010391235, 51.30625292658806, 51.3074916601181, 49.790567457675934, 48.849905133247375, 40.676346123218536, 39.07980099320412, 41.98230944573879, 49.476742297410965, 54.32748220860958, 55.30497595667839, 51.88292518258095, 52.310618832707405, 52.395358085632324, 51.15341752767563, 43.21134589612484, 46.556823179125786, 51.98719918727875, 57.066622227430344, 55.99763698875904, 52.58952006697655, 50.96399389207363, 54.6524141728878, 53.58995698392391, 55.57018272578716, 51.40038147568703, 56.977570205926895, 57.3572002351284, 50.52856765687466, 9.24426555633545, 0.9668927325401455, 4.583310736343265, 5.235943291336298, 1.7956298659555614, 0.570384127786383, 21.76028475165367, 53.8167630136013, 35.01329340040684, 34.38077934086323, 24.131959788501263, 33.581389635801315, 45.08162833750248, 50.92789202928543, 49.05492313206196, 9.911251366138458, 0.11188213160494342, 0.10452684698975645, 0.12847371865063906, 0.04515958593401592, 0.008990297174022999, 0.012870007740275469, 0.05338088267308194, 0.060640240990323946, 0.03959034278523177, 0.02825338207912864, 0.04752574568556156, 0.044911293007317, 0.03562342986697331, 0.07538719772128388, 0.025948848415282555, 0.01145511154390988, 0.04447320694453083, 0.03984717041021213, 0.02385585095908027, 0.023673388386669103, 0.009576059492246713, 0.033310326252831146, 0.030238402614486404, 0.05754803445597645, 0.03540294521371834, 0.3450038825394586, 25.102534107863903, 59.761221036314964, 57.893013283610344, 40.455414578318596, 43.34917210042477, 23.89089122414589, 26.594282761216164, 42.535137981176376, 56.68147869408131, 44.178356006741524, 0.4596951470011845, 0.05220032238867134, 0.6335560348816216, 5.182200400158763, 3.4757575672119856, 3.3090125396847725, 9.500831589102745, 31.94863624870777, 50.8581505715847, 59.04775992035866, 54.93948496878147, 60.64250394701958, 59.656312465667725, 59.194960221648216, 55.625203773379326, 53.90864208340645, 45.09539119899273, 42.748728320002556, 43.516043946146965, 44.304034262895584, 40.37607483565807, 43.96556742489338, 39.906378239393234, 46.51635155081749, 52.410975247621536, 55.887131318449974, 55.129436776041985, 53.51121000945568, 51.46353408694267, 50.16654968261719, 46.97620287537575, 51.638529896736145, 53.94397258758545, 52.37116098403931, 50.19096717238426, 49.113401994109154, 48.24262171983719, 47.02643238008022, 49.45698335766792, 49.17256101965904, 49.228121638298035, 42.05034479498863, 38.525414541363716, 38.854906260967255, 38.974143862724304, 41.06432430446148, 41.24231435358524, 39.75820519030094, 39.491649493575096, 40.722555443644524, 38.637474328279495, 43.478064984083176, 44.22491490840912, 46.15762040019035, 48.5566520690918, 51.381918266415596, 47.544340789318085, 52.01302260160446, 48.85594680905342, 52.019740641117096, 51.111532375216484, 53.415918722748756, 52.21710205078125, 59.50386844575405, 37.59036831557751, 33.71846728026867, 54.02954779565334, 49.39967103302479, 53.94162431359291, 49.73570600152016, 52.048174515366554, 51.614887565374374, 52.08806477487087, 53.79025563597679, 55.264565125107765, 52.77488932013512, 50.51623731851578, 45.40572054684162, 48.384316116571426, 47.22840674221516, 48.146661669015884, 46.30825951695442, 41.11607372760773, 40.741413831710815, 42.43917033076286, 40.68468667566776, 40.13507656753063, 40.53394876420498, 52.71860674023628, 53.18318121135235, 55.49478717148304, 56.19857780635357, 52.13212341070175, 52.674909085035324, 56.37961149215698, 53.89623574912548, 51.85089290142059, 54.19439435005188, 52.24998168647289, 51.323477402329445, 44.347519129514694, 41.8987101316452, 43.12387079000473, 51.47158585488796, 55.47166161239147, 58.22049491107464, 54.8278583586216, 54.87692892551422, 53.771898820996284, 52.032447159290314, 45.37888638675213, 48.30876097083092, 54.121088683605194, 58.127665892243385, 57.06202447414398, 53.25346603989601, 51.60121209919453, 55.56764826178551, 54.58905257284641, 56.8724412471056, 51.91702455282211, 56.899681985378265, 55.83374798297882, 52.40807980298996, 12.155721578747034, 1.4377721934579313, 6.954857055097818, 10.284073110669851, 3.0043786112219095, 0.6367048190440983, 24.091852940618992, 59.76297654211521, 38.94959717988968, 35.70327177643776, 29.220451042056084, 38.675726875662804, 49.68620985746384, 56.17549404501915, 58.114066421985626, 13.646428138017654, 0.12142900057369843, 0.07260096012032591, 0.07750187331112102, 0.05534188174351584, 0.05256478369119577, 0.035547270672395825, 0.04331353440647945, 0.03193499673216138, 0.05157680330739822, 0.026494174817344174, 0.040041806059889495, 0.029395920282695442, 0.030274966375145596, 0.16577364527620375, 0.1557440240867436, 0.100429353187792, 0.16411479678936303, 0.15542592474957928, 0.18997539271367714, 0.20094666571822017, 0.1742569127236493, 0.14635033439844847, 0.17486807133536786, 0.2602199523244053, 0.21490999613888562, 0.6606622959952801, 30.51778882741928, 70.69517612457275, 66.3478522002697, 47.24129945039749, 47.67432801425457, 22.94815231114626, 34.183178544044495, 51.57505810260773, 60.826953649520874, 51.55749924480915, 0.6280257878825068, 0.134564925392624, 0.9904255229048431, 8.754437640309334, 7.425408605486155, 6.9339448772370815, 12.271243929862976, 34.059559777379036, 53.85548673570156, 61.14438861608505, 57.37650699913502, 62.817393243312836, 63.09817157685757, 61.429095938801765, 58.69101606309414, 56.493544578552246, 47.19250246882439, 45.451945066452026, 46.08678840100765, 46.4070276170969, 43.13544116914272, 45.71025900542736, 42.20451772212982, 49.008212238550186, 56.08921207487583, 57.579465508461, 56.95263594388962, 55.85500404238701, 54.468428045511246, 51.83048419654369, 45.84761783480644, 52.141018733382225, 55.93102656304836, 55.22923082113266, 52.330651357769966, 50.47322742640972, 50.66187970340252, 49.77617383003235, 53.59901189804077, 49.63787265121937, 49.972551092505455, 43.55190262198448, 40.21613381803036, 41.67802557349205, 42.016218826174736, 42.57508143782616, 41.949726194143295, 42.42026634514332, 41.82739935815334, 44.11801524460316, 41.296244859695435, 45.3636834025383, 47.73930452764034, 48.14964450895786, 50.622757002711296, 54.08737309277058, 48.36397960782051, 54.15978580713272, 51.144693195819855, 55.2734300494194, 53.76286670565605, 55.38947582244873, 53.7504755705595, 59.60933938622475, 40.68488046526909, 38.56905899941921, 53.87176886200905, 51.110966205596924, 54.58955034613609, 52.88873881101608, 53.75640705227852, 54.89937052130699, 55.05974091589451, 56.25977732241154, 58.966877460479736, 56.97668865323067, 52.29699656367302, 47.41386719048023, 51.19713418185711, 50.50039976835251, 49.74681660532951, 48.24997812509537, 42.77896709740162, 42.373202070593834, 43.11473228037357, 41.644226387143135, 41.75274096429348, 42.43337944149971, 54.66764755547047, 56.17034152150154, 57.9026647657156, 58.55879835784435, 54.21698413789272, 54.08966436982155, 58.02142359316349, 56.62082254886627, 52.391911670565605, 55.551054552197456, 55.76983921229839, 53.736594915390015, 45.36012299358845, 44.102903455495834, 45.90255908668041, 54.40322354435921, 57.97258101403713, 60.33048368990421, 54.823070615530014, 55.879284739494324, 56.06379523873329, 55.88470704853535, 46.99884586036205, 50.8718716353178, 55.776469856500626, 60.76133117079735, 59.160872250795364, 55.340815633535385, 52.552285864949226, 56.7814589291811, 54.90686371922493, 58.093365132808685, 52.98263557255268, 60.127297192811966, 56.69878676533699, 58.51173408329487, 12.865961417555809, 3.904534396715462, 13.275279253721237, 9.839467518031597, 3.409172552637756, 1.0852296045050025, 27.85292722284794, 65.02746105194092, 49.776933789253235, 44.36366826295853, 37.32416220009327, 44.26933452486992, 57.38583169877529, 62.08937130868435, 67.53313019871712, 18.24028093367815, 0.6435864872764796, 0.18630456703249365, 0.2788498776499182, 0.11445110547356308, 0.14696132973767817, 0.09364592304336838, 0.1251042791409418, 0.12038511791615747, 0.10617770996759646, 0.11035220901248977, 0.1157865853747353, 0.10202063655015081, 0.22131608129711822], [0.016335631444235332, 0.03723235407960601, 0.03446025068114977, 0.054240742392721586, 0.012158593326603295, 0.09225032175891101, 0.10905339862802066, 0.06874150276416913, 0.017457766152801923, 0.06160401251690928, 0.0206868191526155, 0.016407716248068027, 0.6332571571692824, 30.44165801256895, 56.31114296615124, 46.209073439240456, 34.47394274175167, 18.806735537946224, 20.215238258242607, 37.98219569027424, 35.31314291059971, 55.84940314292908, 25.903713516891003, 0.03476243837212678, 0.029502808101824485, 0.5481033108662814, 2.366178394295275, 1.3433393044397235, 4.599893996492028, 17.419671267271042, 49.8271518945694, 60.00825718045235, 54.61668089032173, 56.05249464511871, 55.577018558979034, 55.74699103832245, 56.20065629482269, 53.51361148059368, 51.36538155376911, 45.56641012430191, 40.95297507941723, 40.865803956985474, 42.10590921342373, 39.56869035959244, 38.889773190021515, 38.00011932849884, 43.741759434342384, 47.85367079079151, 51.234774962067604, 50.730716809630394, 50.87677717208862, 51.384327337145805, 53.26954297721386, 47.491227239370346, 50.09149231016636, 49.57334451377392, 48.598085045814514, 45.2313707023859, 41.65086843073368, 38.643580600619316, 39.60936717689037, 39.568903148174286, 41.083315685391426, 38.70905488729477, 37.64182895421982, 37.99861080944538, 38.07540088891983, 37.013642862439156, 39.980117082595825, 37.48125337064266, 39.10840205848217, 35.93274526298046, 36.88651688396931, 36.83445207774639, 37.67794981598854, 37.72402234375477, 39.83825549483299, 40.39603516459465, 46.88185773789883, 42.25291572511196, 46.718215718865395, 45.23798994719982, 50.47721341252327, 48.80656845867634, 54.4907708466053, 49.59609769284725, 57.51037381589413, 36.05925187468529, 28.897510170936584, 55.37649191915989, 49.61378954350948, 51.23040519654751, 50.11059008538723, 53.01872603595257, 51.33473239839077, 52.104419097304344, 51.022351160645485, 49.37945991754532, 48.02694909274578, 44.26342584192753, 42.543060556054115, 46.43366798758507, 47.33192078769207, 47.327953800559044, 44.446306228637695, 40.37768214941025, 37.1883574873209, 38.562527149915695, 38.408388420939445, 39.400777369737625, 37.443000823259354, 42.761358842253685, 50.104670003056526, 51.46767966449261, 47.60529711842537, 46.213462203741074, 50.42792625725269, 50.94632104039192, 51.77615091204643, 49.659033715724945, 50.66987827420235, 51.14455260336399, 46.75958409905434, 40.974873304367065, 41.41692258417606, 49.229082986712456, 53.10533858835697, 54.6025076508522, 50.40695138275623, 50.090177580714226, 54.29605029523373, 51.107048615813255, 47.27847285568714, 48.269406482577324, 52.30873413383961, 51.59495763480663, 56.52284100651741, 54.63136330246925, 53.04189719259739, 50.817610546946526, 55.552829056978226, 55.733414366841316, 60.148887634277344, 56.88970372080803, 51.2971980124712, 56.679358407855034, 50.163718834519386, 14.102703854441643, 0.8464960742276162, 4.6850574016571045, 18.03124275058508, 5.157659417018294, 0.3921711375005543, 14.892609268426895, 55.44162042438984, 46.78038038313389, 38.33723343908787, 16.58772300928831, 31.322914324700832, 53.36605779826641, 52.257205098867416, 50.60159973800182, 16.658796295523643, 0.1985798528767191, 0.08816998641123064, 0.01422581784936483, 0.013845174016751116, 0.03885527519742027, 0.02592271182948025, 0.011019082157872617, 0.04527323100774083, 0.03675989544717595, 0.025536262546665967, 0.0441855208191555, 0.014093669178691925, 0.03628191152529325, 0.03355974353326019, 0.04596285318257287, 0.055815490704844706, 0.03505561267957091, 0.04069029098900501, 0.0674819148844108, 0.031221956087392755, 0.07671582017792389, 0.05105626092699822, 0.00857169805385638, 0.04664757718273904, 0.04339695551607292, 0.8953441749326885, 38.72543580830097, 63.75573009252548, 53.98606292903423, 41.69985920190811, 25.8730111643672, 15.314617473632097, 34.987059608101845, 42.495578303933144, 61.781819611787796, 28.748548664152622, 0.10061799970571883, 0.07618903633556329, 1.5421278937719762, 3.991036517545581, 3.081947648897767, 4.789529470726848, 17.476474419236183, 49.056610241532326, 61.105201318860054, 57.86085560917854, 57.289107888937, 57.611995562911034, 56.869933381676674, 58.15881662070751, 54.34082329273224, 55.17911151051521, 47.483912631869316, 42.97706186771393, 43.38510677218437, 44.30890940129757, 41.24508440494537, 41.61955811083317, 40.95639869570732, 45.49276627600193, 49.7696153819561, 53.33691716194153, 52.60812006890774, 53.349692076444626, 53.455911576747894, 54.08727049827576, 49.24132972955704, 51.40383169054985, 52.584500536322594, 51.084846407175064, 48.13834771513939, 45.8879678696394, 41.888165697455406, 42.00822025537491, 41.416983380913734, 43.40953566133976, 38.91620837152004, 39.698688983917236, 39.76708151400089, 39.8117633163929, 39.294101893901825, 40.71772590279579, 39.5674554258585, 40.46749792993069, 38.75272214412689, 38.849958926439285, 37.27982237935066, 40.596698597073555, 39.74302880465984, 41.77325986325741, 43.85570392012596, 48.25285457074642, 45.636884942650795, 47.657198533415794, 48.20772439241409, 51.02980636060238, 49.54507403075695, 56.45554281771183, 52.519125044345856, 57.94143408536911, 36.934014335274696, 30.84895245730877, 54.84730191528797, 50.36119423806667, 53.17832127213478, 52.09548957645893, 54.74771685898304, 53.37576247751713, 54.98463414609432, 52.77544789016247, 51.10547550022602, 50.47462955117226, 45.53930997848511, 45.243267863988876, 49.00861121714115, 49.66176576912403, 49.95119243860245, 46.585412845015526, 41.311637833714485, 39.92853485047817, 40.71400970220566, 41.02850362658501, 41.238054782152176, 39.63625833392143, 45.94217196106911, 52.027697414159775, 54.30971056222916, 50.91453954577446, 46.40517331659794, 52.76653356850147, 53.54755125939846, 52.522339671850204, 52.226023972034454, 52.92705215513706, 55.63026890158653, 49.03759226202965, 43.669943287968636, 42.26238861680031, 51.635125279426575, 55.347298085689545, 56.32992535829544, 53.02203945815563, 50.04243314266205, 54.194253757596016, 54.29086357355118, 50.72944387793541, 49.389027804136276, 53.389608934521675, 54.033552780747414, 57.04381585121155, 55.56321009993553, 53.98643150925636, 51.81333191692829, 56.57133400440216, 57.93159641325474, 62.666427344083786, 58.62035125494003, 56.77058011293411, 57.56276920437813, 50.62073551118374, 17.451608553528786, 3.54156409855932, 7.8606087528169155, 23.77426788210869, 6.773056760430336, 0.4654558753827587, 17.095590457320213, 60.386842265725136, 47.58931137621403, 38.25898043811321, 27.681858502328396, 38.434002846479416, 58.80210690200329, 58.06477166712284, 58.69576580822468, 21.43859401345253, 0.2801825077040121, 0.02262379119201796, 0.04199158756819088, 0.026150577141379472, 0.04111059148272034, 0.020755599543917924, 0.01669522054726258, 0.018616978559293784, 0.011366604867362184, 0.021607592498185113, 0.027208345381950494, 0.03883961959218141, 0.005882901195946033, 0.1363254926400259, 0.13793764519505203, 0.14142910862574354, 0.14523173973429948, 0.08403473213547841, 0.2180369760026224, 0.21812054183101282, 0.20580160286044702, 0.15674953028792515, 0.1484109222656116, 0.17443070886656642, 0.08624908557976596, 1.6478313342668116, 45.75710669159889, 73.43713939189911, 60.940996930003166, 49.796897917985916, 28.715954013168812, 28.663357235491276, 51.891368329524994, 47.322569489479065, 67.4472776055336, 32.301378920674324, 0.22512478317366913, 0.24589610140537843, 1.7302796663716435, 9.327922817319632, 8.107003681361675, 10.549395773559809, 21.00458700209856, 53.81455533206463, 63.6528430134058, 60.627882331609726, 61.757018342614174, 60.53990565240383, 61.221824660897255, 60.99550120532513, 57.558923810720444, 56.47434040904045, 49.87905710935593, 45.48723757266998, 44.70039859414101, 45.60136824846268, 43.38105618953705, 43.28230708837509, 42.89570823311806, 47.961695194244385, 52.38866284489632, 54.88540627062321, 55.82319214940071, 53.939298838377, 56.08260802924633, 55.818488001823425, 50.501763895154, 53.155317306518555, 55.01777596771717, 53.375108912587166, 51.11368305981159, 46.30569085478783, 42.70463548600674, 44.55029904842377, 43.51012386381626, 46.216688230633736, 42.978190407156944, 41.38590104877949, 42.27167531847954, 41.33756384253502, 40.99074125289917, 42.8668487817049, 41.129920184612274, 43.389389142394066, 40.74370890855789, 41.62674352526665, 39.49701480567455, 43.20526622235775, 42.22008928656578, 45.46840958297253, 44.22565966844559, 52.30482794344425, 47.43418850004673, 50.192350298166275, 51.266590654850006, 53.4357650578022, 52.466060891747475, 59.950716868042946, 56.173689141869545, 59.98788267374039, 40.29184475541115, 31.914468482136726, 55.79231880605221, 53.88056538999081, 54.35360200703144, 54.814289286732674, 57.13408000767231, 53.92200596630573, 57.73358143866062, 56.11212104558945, 53.212033063173294, 53.41721445322037, 47.65863485634327, 46.74164146184921, 51.334204226732254, 52.02220670878887, 51.527849435806274, 49.03758466243744, 44.325943887233734, 40.385775715112686, 41.51424676179886, 42.74752378463745, 43.676133155822754, 41.40389308333397, 47.665577083826065, 53.975860476493835, 58.1768124550581, 51.42490915954113, 49.27730619907379, 54.818826243281364, 54.39057782292366, 54.66143108904362, 52.90483474731445, 55.479329600930214, 56.66053041815758, 52.32066549360752, 46.65201187133789, 44.4471687823534, 53.883582428097725, 57.816523388028145, 59.569110944867134, 53.69032859802246, 50.9210067987442, 56.546684727072716, 56.461428701877594, 54.0341417491436, 52.34232813119888, 58.09452027082443, 55.935392528772354, 59.431995302438736, 56.50278188288212, 56.340116411447525, 54.288750886917114, 59.02639366686344, 58.60947623848915, 67.14169800281525, 59.46918770670891, 58.88934262096882, 57.46117785573006, 55.23004397749901, 18.668151274323463, 4.735022820532322, 14.63744631037116, 32.50998392701149, 6.399487880989909, 0.6607535504736006, 19.66246671974659, 68.43267112970352, 59.98916320502758, 47.72621802985668, 26.076798029243946, 42.43423819541931, 70.76479598879814, 64.44938287138939, 65.35224482417107, 28.879054561257362, 0.6749084440525621, 0.2125996013637632, 0.13358969881664962, 0.11884121326147579, 0.13491320045432076, 0.13350521272514015, 0.12621753034181893, 0.09886546249617822, 0.11403921351302415, 0.17298110149567947, 0.20637485256884247, 0.11232157950871624, 0.10964632267132401], [0.0544863376126159, 0.008629372205177788, 0.02717577252042247, 0.03238951394450851, 0.04140864170040004, 0.027734086506825406, 0.06179885225719772, 0.021534746992983855, 0.046801275966572575, 0.06609939766349271, 0.017214232248079497, 0.04692807560786605, 1.957840786781162, 38.7945730984211, 53.244920298457146, 50.391869992017746, 39.40502554178238, 26.395435631275177, 38.57310578227043, 39.92926061153412, 39.78956490755081, 62.34008565545082, 15.059247426688671, 0.06512992273201235, 0.06817552610300481, 1.1018645181320608, 3.3789815101772547, 2.2627263329923153, 3.3532234048470855, 31.119230054318905, 60.482163950800896, 53.1302310526371, 56.92191459238529, 52.61944726109505, 53.64909701049328, 48.753443509340286, 48.65819402039051, 46.69495716691017, 44.91541765630245, 39.47160176932812, 41.60990282893181, 38.20053577423096, 39.81584049761295, 36.945641711354256, 39.04599040746689, 38.11752922832966, 39.79603596031666, 41.117966026067734, 43.67563918232918, 45.24473458528519, 48.5768935829401, 50.312154069542885, 52.6113460958004, 51.48363500833511, 48.65023724734783, 50.20765207707882, 51.48446336388588, 47.79216729104519, 48.2578095048666, 41.61551512777805, 38.490813598036766, 37.44588486850262, 36.953864470124245, 39.060676619410515, 38.55754181742668, 37.752874195575714, 39.1549039632082, 37.50442832708359, 39.74385716021061, 39.73100244998932, 39.179914221167564, 37.27827966213226, 37.26865857839584, 35.86505189538002, 39.695196971297264, 37.04739645123482, 39.56541493535042, 41.228106915950775, 46.62167429924011, 42.55005218088627, 48.02847661077976, 44.66591164469719, 52.74438835680485, 51.04290805757046, 54.23235051333904, 48.15599396824837, 56.36167645454407, 33.70689310133457, 27.322610579431057, 56.18693143129349, 52.7332853525877, 52.21001163125038, 50.26026405394077, 51.91350594162941, 50.04928417503834, 48.57987642288208, 47.124482318758965, 42.167363315820694, 40.636246874928474, 43.08187924325466, 45.08125975728035, 48.52803200483322, 49.92243938148022, 49.863242357969284, 46.76843762397766, 41.31899803876877, 38.57623301446438, 41.61608129739761, 38.04545469582081, 41.1923698335886, 41.17695026099682, 37.97602102160454, 40.70086620748043, 40.27238979935646, 39.98268574476242, 43.584052696824074, 51.52312248945236, 53.869956359267235, 51.2628098577261, 43.420988246798515, 52.79256597161293, 52.493271231651306, 48.95953305065632, 40.255970880389214, 46.709700375795364, 52.62602470815182, 52.86134608089924, 54.494555443525314, 50.171770602464676, 51.020747646689415, 52.89761133491993, 52.04909406602383, 53.640467673540115, 49.46477293968201, 53.36665816605091, 53.551404252648354, 54.0275377035141, 52.98776529729366, 56.788693740963936, 55.18295310437679, 53.7024537473917, 53.597017005085945, 53.61266456544399, 60.41818678379059, 61.32456734776497, 38.14841017127037, 36.06848157942295, 17.752993181347847, 1.8822960904799402, 5.793930049985647, 3.7226127460598946, 1.4189966884441674, 0.056543912360211834, 6.326461024582386, 49.40387360751629, 42.2057868540287, 44.45354104042053, 21.307100169360638, 22.94906046241522, 41.229786425828934, 47.17154659330845, 55.391383320093155, 17.126676589250565, 0.44584275281522423, 0.0036291524656917318, 0.0799035670934245, 0.027230585692450404, 0.02638338330143597, 0.04005572132882662, 0.07921912882011384, 0.051246076327515766, 0.048525552192586474, 0.02766243771475274, 0.048928835240076296, 0.023013017962512095, 0.029210190405137837, 0.06854190956801176, 0.09237048288923688, 0.1541201159125194, 0.013675483805855038, 0.09092844542465173, 0.02112327620125143, 0.04233261555782519, 0.03464376524789259, 0.028862653780379333, 0.04090579583134968, 0.04680460820964072, 0.022126387120806612, 2.700379486195743, 49.03473861515522, 58.75368990004063, 57.61173717677593, 44.22604724764824, 31.8885500729084, 37.62062609195709, 44.001433700323105, 44.96454142034054, 64.74227875471115, 17.163283824920654, 0.11654948350042105, 0.08702286359039135, 4.010216938331723, 2.1741131879389286, 5.4991779662668705, 6.226773848757148, 34.10586029291153, 61.24586597084999, 57.02658377587795, 57.577242627739906, 54.29283186793327, 56.292626559734344, 52.11308263242245, 50.86622893810272, 49.059019312262535, 48.04825834929943, 42.4389423429966, 43.96036930382252, 40.39390727877617, 42.34913796186447, 39.35014508664608, 40.9521809220314, 40.35433240234852, 42.48733654618263, 43.09849955141544, 47.6644067466259, 47.014729008078575, 49.69824381172657, 51.20211951434612, 53.7341820448637, 50.457872450351715, 48.6049360781908, 52.1786405146122, 53.84037874639034, 50.933952704072, 49.23814170062542, 43.02941545844078, 41.253994926810265, 41.00353516638279, 39.583566561341286, 38.15748408436775, 39.79260094463825, 39.062751308083534, 40.823649019002914, 39.3242646753788, 40.7527182251215, 41.84513680636883, 40.25898031890392, 38.61542411148548, 39.32187460362911, 36.912822872400284, 41.95445694029331, 40.3596331179142, 43.09596508741379, 42.78576113283634, 47.65470966696739, 45.12550078332424, 49.96940866112709, 47.422994300723076, 53.740702494978905, 52.61398695409298, 56.253473460674286, 49.63126480579376, 57.64950715005398, 36.682023257017136, 28.042168468236923, 58.53475324809551, 53.969909995794296, 54.38288323581219, 52.10877746343613, 53.68584483861923, 50.55880643427372, 50.162757486104965, 47.088517248630524, 43.60944293439388, 43.23863223195076, 46.10247015953064, 46.7508939653635, 48.890053778886795, 51.06762193143368, 50.628570690751076, 48.592476546764374, 44.245046228170395, 42.2009003162384, 42.480143532156944, 40.0890838354826, 42.75732725858688, 41.956603825092316, 39.11070853471756, 42.92392551898956, 43.198958560824394, 43.93231920897961, 44.609431475400925, 53.54863040149212, 54.55063283443451, 53.42771328985691, 44.54336442053318, 54.25541527569294, 54.1766607016325, 49.609510973095894, 42.290229722857475, 48.21091242134571, 54.48393501341343, 53.70608255267143, 56.18009179830551, 52.118542939424515, 51.22274860739708, 53.67318771779537, 54.18954961001873, 56.39528565108776, 53.29713709652424, 54.58762384951115, 55.52936531603336, 54.781174063682556, 54.114974811673164, 59.661715775728226, 57.13069438934326, 54.87645775079727, 54.27232436835766, 56.96286119520664, 60.416347682476044, 63.335951417684555, 45.7533410936594, 39.18528713285923, 18.111184760928154, 1.2744494760408998, 11.845092996954918, 4.795325109735131, 3.24158800765872, 0.08397145662456751, 6.672003082931042, 56.79252773523331, 49.36378575861454, 40.295230373740196, 21.718397699296474, 28.411109670996666, 46.56120054423809, 53.82278569042683, 62.03721530735493, 23.888896331191063, 0.6195243378169835, 0.08480099219013937, 0.060602439698413946, 0.04499007569393143, 0.06333051147521473, 0.05030284373788163, 0.02823067978170002, 0.013288309073686833, 0.051601030718302354, 0.03989995566371363, 0.03102641501754988, 0.019122878366033547, 0.08074507350102067, 0.19448779901722446, 0.17094362410716712, 0.16594243934378028, 0.12970500101801008, 0.16080668836366385, 0.10426937369629741, 0.14080855442443863, 0.1655293451040052, 0.16853247536346316, 0.14042759517906234, 0.22873819631058723, 0.24001020239666104, 4.054022887721658, 58.13825212419033, 67.63774618506432, 63.91153693199158, 49.70496565103531, 36.56217008829117, 51.39532774686813, 51.65818244218826, 52.87749521434307, 72.55129292607307, 19.191820174455643, 0.22465255460701883, 0.24480710359057412, 2.6337336748838425, 7.4605633690953255, 6.499477615579963, 5.927112428471446, 33.43951664865017, 64.50430512428284, 58.86840954422951, 61.109411492943764, 57.680984660983086, 58.79470869898796, 52.708997055888176, 53.19907195866108, 50.9664523601532, 50.634589567780495, 44.104499369859695, 45.68340964615345, 41.91082388162613, 43.514706417918205, 42.073971927165985, 43.282326087355614, 40.748599246144295, 43.96602340042591, 45.52393980324268, 49.3996824324131, 49.86871786415577, 52.322614789009094, 54.04587931931019, 57.454778999090195, 54.33921977877617, 49.36429113149643, 53.39489825069904, 55.173100233078, 53.467155173420906, 51.89151652157307, 45.92543385922909, 42.89376273751259, 41.98381796479225, 41.32967546582222, 40.98978370428085, 41.94494225084782, 41.967338249087334, 42.69070543348789, 41.58750683069229, 43.80424328148365, 45.854077488183975, 42.87494234740734, 41.479797810316086, 40.62096789479256, 38.949088007211685, 44.94523845613003, 41.98314920067787, 44.88264821469784, 45.956405997276306, 51.023817881941795, 48.27206254005432, 52.45838910341263, 48.70515190064907, 57.133605033159256, 56.72128155827522, 57.36511521041393, 51.78001910448074, 58.57728436589241, 38.30380663275719, 31.82080540806055, 58.48310261964798, 56.389912739396095, 55.879740715026855, 54.30347129702568, 54.80980932712555, 54.468933418393135, 52.055789306759834, 50.17302453517914, 45.24522855877876, 44.91472989320755, 47.73452818393707, 48.66308435797691, 51.0151581466198, 54.908402636647224, 53.697981387376785, 50.583189725875854, 45.8435520529747, 44.01804260909557, 45.472824946045876, 41.02182738482952, 46.03890337049961, 44.31315377354622, 40.404691100120544, 45.575959011912346, 44.57153990864754, 46.17536924779415, 47.398983389139175, 56.15359202027321, 57.99331270158291, 54.23510156571865, 46.06518276035786, 57.97121308743954, 56.83160103857517, 53.85324865579605, 43.92824202775955, 51.44596002995968, 56.61858446896076, 56.053379997611046, 58.086787685751915, 53.48442144691944, 52.65989989042282, 55.19366092979908, 56.291357427835464, 57.70859397947788, 55.91583117842674, 60.36030448973179, 57.5237262994051, 57.37469829618931, 53.319901674985886, 60.948911905288696, 58.629417568445206, 58.920063972473145, 56.70472964644432, 60.49126826226711, 63.073590695858, 66.11754655838013, 47.85487152636051, 42.31472700834274, 22.64157146215439, 3.4129906352609396, 16.150047294795513, 8.171699959784746, 3.271129047498107, 0.16285802907077596, 8.817329965531826, 60.2247429639101, 57.72013396024704, 57.44147211313248, 28.36630627512932, 33.16185034811497, 51.38177387416363, 61.282416209578514, 67.97735676169395, 32.15604431927204, 1.0325682302936912, 0.1950109686003998, 0.13084675068967044, 0.11673353612422943, 0.17841329594375566, 0.08297685999423265, 0.14429406583076343, 0.13736714143306017, 0.23495249566622078, 0.1020085098571144, 0.09069400097359903, 0.07454547609086148, 0.23378555750241503], [0.008242634412454208, 0.02722003420785768, 0.0433469421841437, 0.03910154577170033, 0.013228954885562416, 0.09726201533339918, 0.034964714432135224, 0.08350621166755445, 0.022148148746055085, 0.05000649674911983, 0.033337247659801506, 0.03461839492956642, 3.985668830573559, 43.81604924798012, 47.367228493094444, 41.721031665802, 26.406694427132607, 19.420754089951515, 19.2847802862525, 30.244389697909355, 45.02690367400646, 59.16295453906059, 11.244032699614763, 0.4878574248868972, 0.4025848943274468, 3.38261554017663, 2.06504977773875, 2.2796119144186378, 16.822970286011696, 50.488829389214516, 62.425455674529076, 55.125158205628395, 55.106789991259575, 50.367764085531235, 46.856756284832954, 38.8106956332922, 42.16957859694958, 39.1795152425766, 39.47637811303139, 39.08238485455513, 40.33032529056072, 40.36982037127018, 39.52451393008232, 40.32639630138874, 39.899021834135056, 39.395871832966805, 38.57567444443703, 36.79751805961132, 39.72102038562298, 38.305383548140526, 42.14918129146099, 45.48900447785854, 51.76032096147537, 51.047570407390594, 52.54786670207977, 47.97173425555229, 51.009352058172226, 52.292953580617905, 51.0697004199028, 48.662776574492455, 42.94046603143215, 37.08119183778763, 39.7996761649847, 39.48895163834095, 39.567341431975365, 39.04876425862312, 39.241801500320435, 38.164251521229744, 39.0610907971859, 38.380535915493965, 39.43291984498501, 35.61697460711002, 37.722768411040306, 36.690246015787125, 38.09262156486511, 37.916018441319466, 40.26281051337719, 41.54119871556759, 46.05105511844158, 43.43328818678856, 46.95946857333183, 45.4324597120285, 52.21329465508461, 50.017776265740395, 54.19909469783306, 47.88082033395767, 54.449991434812546, 33.30932043492794, 30.26007905602455, 57.93384589254856, 45.89244782924652, 48.23630265891552, 48.15454624593258, 49.10950340330601, 44.8231016099453, 44.51338402926922, 42.55149610340595, 40.82119435071945, 44.69941444694996, 47.26466439664364, 50.20983695983887, 47.56720036268234, 54.39914636313915, 54.58407483994961, 45.4521806538105, 40.46312816441059, 36.90532587468624, 38.17652866244316, 39.48926702141762, 40.371446684002876, 37.913787961006165, 41.18412047624588, 39.451550245285034, 39.90922048687935, 40.12129470705986, 48.685791939496994, 49.695865139365196, 53.780372366309166, 43.30193303525448, 48.25761191546917, 53.384600803256035, 51.167871952056885, 44.97747212648392, 41.272800117731094, 49.55619603395462, 53.1074208766222, 55.20188368856907, 53.278860077261925, 56.49971164762974, 51.72614939510822, 52.86198824644089, 53.08833450078964, 50.32769523561001, 55.33729702234268, 53.730541840195656, 53.940100595355034, 48.634977266192436, 54.92645926773548, 57.94149108231068, 53.403474390506744, 50.72728179395199, 49.42611001431942, 53.087255358695984, 55.618204548954964, 59.640140533447266, 48.07639583945274, 45.14829196035862, 20.576612167060375, 1.7071297648362815, 10.75730161741376, 0.6311938678845763, 1.2923142174258828, 0.010429488502268214, 2.51526624429971, 44.05084244906902, 47.57793478667736, 42.73227520287037, 37.10662007331848, 20.863975547254086, 33.96868385374546, 48.03145945072174, 53.39421048760414, 24.070281498134136, 0.9686154057271779, 0.1392498958739452, 0.04409969144035131, 0.015061041976878187, 0.028662407494266517, 0.025627114409871865, 0.027731116060749628, 0.0221343355224235, 0.04187147467746399, 0.10195396200288087, 0.02837805361195933, 0.02826932155585382, 0.00151859405605137, 0.04592281431541778, 0.04774653090862557, 0.09953194079571404, 0.1285043841926381, 0.03614370507420972, 0.06071232208341826, 0.06442062251153402, 0.050610352627700195, 0.046179267155821435, 0.10597367130685598, 0.022225551037990954, 0.043471860481076874, 5.752621991559863, 55.303144454956055, 55.43268330395222, 48.97376328706741, 33.55096846818924, 23.965407125651836, 18.552722968161106, 30.78531727194786, 49.3392238765955, 62.43272088468075, 12.14787594974041, 0.5810836411546916, 0.27282316354103386, 3.9009623508900404, 6.471771877259016, 5.507062068209052, 17.562066726386547, 51.435822173953056, 65.06874203681946, 60.03907352685928, 57.30372950434685, 53.19190174341202, 47.925148755311966, 40.955296754837036, 43.18355418741703, 41.86638526618481, 41.98004476726055, 42.3188079893589, 41.83531433343887, 40.98706305027008, 41.383754163980484, 41.63855329155922, 42.17164188623428, 40.830534249544144, 40.948658511042595, 37.95133374631405, 41.550979390740395, 39.279001504182816, 44.96595114469528, 47.76034779846668, 53.52857127785683, 53.10597315430641, 52.51569762825966, 49.295712411403656, 52.30113074183464, 54.885379672050476, 53.49314197897911, 49.434097185730934, 42.74440795183182, 38.56754668056965, 42.03071504831314, 40.66898591816425, 40.83188317716122, 40.50963766872883, 42.17648662626743, 40.14409348368645, 41.32912449538708, 39.75255869328976, 40.58982476592064, 37.341386675834656, 39.877249002456665, 38.73357117176056, 39.78387661278248, 40.124342143535614, 42.95197181403637, 42.71975487470627, 47.20291770994663, 45.03938600420952, 49.28011804819107, 49.08341020345688, 54.945944622159004, 53.41496117413044, 55.11328004300594, 51.900005266070366, 55.87456539273262, 34.60383117198944, 31.269082613289356, 59.16286714375019, 48.59349109232426, 50.47182150185108, 49.55604784190655, 49.849403500556946, 48.662647381424904, 47.17100702226162, 43.511465191841125, 42.16564200818539, 45.66414847970009, 49.6605384349823, 53.12396138906479, 50.075453370809555, 51.86378560960293, 56.358192041516304, 47.059277817606926, 43.183447793126106, 39.43585708737373, 40.7882197201252, 40.95700666308403, 41.55049681663513, 39.69121478497982, 43.83998416364193, 41.44965782761574, 41.025311797857285, 41.747634038329124, 50.11517643928528, 52.689196318387985, 57.029023244977, 44.194812923669815, 48.940184488892555, 55.9946845471859, 52.73360833525658, 46.55980981886387, 42.942920699715614, 52.173955366015434, 54.030714333057404, 56.7744293063879, 54.60952587425709, 55.56913398206234, 54.40139964222908, 55.16728654503822, 55.738935470581055, 53.75945068895817, 54.927534610033035, 55.9169065207243, 54.41588446497917, 50.688569471240044, 56.26519963145256, 58.7483511865139, 55.841393172740936, 52.47693210840225, 51.66881047189236, 55.59710808098316, 56.95821784436703, 62.19586439430714, 47.928921952843666, 50.26948995888233, 20.26154637336731, 1.2244145921431482, 11.37713385745883, 6.839097216725349, 3.6476449063047767, 0.05663378273311537, 2.4034451320767403, 46.45952180027962, 52.584587931632996, 41.417815536260605, 35.02644069492817, 26.448264196515083, 39.84273545444012, 50.83491101861, 60.70423163473606, 35.00259317457676, 1.6032256465405226, 0.11631924702669494, 0.013798196996503975, 0.03586009333957918, 0.015160945258685388, 0.022823473445896525, 0.050243772493558936, 0.04054752404044848, 0.026329442152928095, 0.06795718625653535, 0.03712336969329044, 0.025637109283707105, 0.027484372367325705, 0.13343611877644435, 0.1456130255246535, 0.16419012477854267, 0.19845995149808004, 0.06952518102480099, 0.2479026757646352, 0.0897161100874655, 0.2654265338787809, 0.09458264699787833, 0.2525840245652944, 0.14716970996232703, 0.10279575784807093, 7.229910045862198, 65.98708435893059, 60.44235348701477, 56.72708384692669, 37.50202305614948, 27.9847364500165, 25.755890049040318, 41.03074170649052, 55.11391460895538, 70.18458992242813, 14.479318745434284, 0.677744576241821, 0.713300455827266, 9.631637670099735, 6.798137314617634, 6.023534629493952, 22.199201099574566, 55.659846514463425, 65.91001689434052, 62.32589341700077, 59.71973106265068, 54.9228722602129, 49.840500578284264, 44.74580615758896, 46.78079076111317, 43.37677001953125, 43.09064917266369, 43.92437383532524, 43.43670420348644, 43.38052421808243, 42.7744073420763, 44.24802526831627, 45.06709411740303, 41.965985521674156, 42.861893847584724, 40.45363247394562, 43.24453331530094, 41.46554857492447, 46.34042479097843, 49.68538150191307, 56.21291443705559, 55.75908198952675, 54.829146489501, 50.297395661473274, 53.99112045764923, 56.545578986406326, 56.72582991421223, 53.565049320459366, 45.5706886947155, 41.01862035691738, 44.35691982507706, 44.08200077712536, 43.2247743755579, 42.268654480576515, 43.82195793092251, 43.658916279673576, 42.48417131602764, 42.676729783415794, 43.247014582157135, 39.03574995696545, 42.63684332370758, 41.24892219901085, 42.9685465246439, 42.25239135324955, 44.71731148660183, 46.060284823179245, 51.32810555398464, 47.6928748190403, 52.22219757735729, 48.93982730805874, 57.037690579891205, 55.846306309103966, 57.8546429425478, 53.451127633452415, 56.27576686441898, 36.2380550801754, 35.505009815096855, 63.25674846768379, 51.62351690232754, 51.183128133416176, 52.785323560237885, 54.07818138599396, 49.72238011658192, 48.484585136175156, 47.339163199067116, 44.41846892237663, 48.003508150577545, 52.02537193894386, 55.49477957189083, 52.41644315421581, 55.07541887462139, 56.614522486925125, 49.859358966350555, 44.538154900074005, 41.063397154212, 41.90581575036049, 43.35599273443222, 43.448806554079056, 41.48603327572346, 46.53984569013119, 44.11155939102173, 43.66655386984348, 44.98535290360451, 53.177800700068474, 53.849916234612465, 58.39704103767872, 44.87016588449478, 50.48887498676777, 57.13783800601959, 56.67232118546963, 49.12991210818291, 46.145119071006775, 54.819453209638596, 57.57384940981865, 59.862253814935684, 57.078861370682716, 59.934723526239395, 56.2500574439764, 56.61591321229935, 57.45085760951042, 55.05073539912701, 55.5909638106823, 57.19261206686497, 56.54277853667736, 50.98292447626591, 58.72163861989975, 61.9931984692812, 59.55477051436901, 54.85815793275833, 54.074818566441536, 59.09724846482277, 61.11075662076473, 65.937360227108, 53.224074617028236, 51.37797027826309, 26.441285870969296, 3.2206354569643736, 19.257233664393425, 10.888897106051445, 4.424944734200835, 0.11217672712518834, 3.1344045465812087, 52.788986563682556, 61.762284860014915, 58.516259640455246, 50.04027105867863, 32.28647992014885, 48.172241896390915, 60.15550307929516, 69.22622814774513, 43.183052614331245, 2.6128537952899933, 0.18226191052235663, 0.14795815281104296, 0.16239604214206338, 0.1171237054222729, 0.1259808594477363, 0.15900598576990888, 0.13282800297020003, 0.09054946771357208, 0.30208803538698703, 0.12781013472704217, 0.12627363670617342, 0.1208263766602613], [0.02587466518889414, 0.04851634585065767, 0.029547819358413108, 0.0714287898153998, 0.10694632263039239, 0.04827283606573474, 0.07699568406678736, 0.01407565725457971, 0.014785800740355626, 0.0674609788984526, 0.07058092320221476, 0.061820337432436645, 8.080307263880968, 49.79368329048157, 46.521800458431244, 44.31456349790096, 26.5306418761611, 25.006220676004887, 62.58896850049496, 36.72554612159729, 42.680373787879944, 53.328853994607925, 6.580457920208573, 0.5699800432194024, 0.32775533152744174, 6.526782950386405, 2.197478609159589, 4.678935930132866, 26.288372576236725, 59.237286150455475, 56.461926475167274, 52.08640046417713, 51.210429668426514, 43.150499761104584, 40.96550680696964, 39.75897654891014, 39.487652108073235, 38.65781083703041, 40.565331280231476, 39.53939773142338, 40.2465283870697, 42.24117815494537, 43.84343057870865, 46.81078255176544, 48.1560205668211, 45.64622484147549, 43.06867875158787, 42.22174979746342, 42.52231366932392, 38.534040078520775, 38.36721383035183, 41.848693415522575, 46.30130209028721, 48.296008855104446, 53.27906146645546, 51.586993262171745, 48.78185838460922, 49.52620804309845, 51.91027231514454, 50.50214387476444, 46.44488878548145, 38.03868345916271, 36.66110917925835, 38.70115511119366, 38.84978413581848, 37.533709555864334, 40.4767694324255, 38.11956971883774, 39.09555494785309, 38.881713822484016, 37.84406170248985, 36.8448331207037, 38.26299302279949, 36.00518837571144, 37.325488328933716, 36.839110627770424, 41.83550052344799, 39.438817128539085, 45.48605963587761, 45.618980303406715, 51.07598528265953, 52.235002890229225, 55.55591829121113, 51.80941432714462, 51.72339454293251, 45.374535620212555, 47.56512187421322, 35.03337912261486, 31.516139656305313, 54.70397740602493, 51.337095871567726, 46.39065809547901, 43.40022996068001, 46.137762665748596, 43.20370830595493, 42.48829789459705, 42.7982434630394, 46.31246209144592, 48.28466646373272, 51.167571768164635, 50.032671466469765, 56.088794097304344, 57.06544429063797, 48.35154287517071, 49.154067412018776, 40.40770813822746, 40.79330764710903, 41.372727155685425, 38.83308783173561, 40.01852922141552, 38.42851214110851, 38.96864175796509, 39.66534577310085, 40.205437391996384, 41.133514791727066, 48.89483392238617, 52.896611988544464, 49.7872806340456, 45.7482797652483, 53.719283044338226, 50.873984321951866, 51.51709221303463, 40.54748743772507, 41.39439359307289, 50.565577670931816, 54.130204394459724, 52.43267208337784, 53.23037087917328, 52.5508913397789, 51.559980511665344, 54.87826265394688, 51.901274397969246, 52.842924669384956, 53.30809570848942, 52.408436983823776, 47.56885327398777, 52.38947220146656, 55.692406967282295, 54.507934525609016, 51.53506524860859, 46.88293308019638, 46.009314358234406, 50.913411006331444, 55.08901074528694, 57.67922915518284, 52.70414091646671, 51.63927465677261, 34.31880846619606, 1.768543494399637, 17.698067128658295, 3.9879767317324877, 4.253306519240141, 0.25934294157195836, 0.2836400252999738, 37.43991158902645, 50.37841871380806, 37.68939480185509, 29.55272801220417, 13.024569656699896, 26.917301528155804, 38.66005651652813, 55.251771211624146, 33.88274386525154, 3.5124726220965385, 0.2516360051231459, 0.033942673180717975, 0.06791187814087607, 0.0471698339242721, 0.0727576126519125, 0.035129931347910315, 0.031389514479087666, 0.057259632158093154, 0.06599358966923319, 0.044880308341817, 0.03807161177974194, 0.04095568299817387, 0.039531753936898895, 0.033168164154631086, 0.028996765431656968, 0.0358190117549384, 0.05249790505331475, 0.05396566535637248, 0.11533944882103242, 0.04747602179122623, 0.023943802880239673, 0.06994827199378051, 0.09354061228805222, 0.13399004295933992, 11.118203401565552, 59.184890761971474, 53.41023042798042, 52.711516320705414, 29.983472898602486, 25.232331342995167, 47.68116004765034, 38.887474313378334, 47.95841597020626, 59.34401102364063, 6.794199300929904, 0.5632573133334517, 1.1034290841780603, 10.270843170583248, 6.07399164699018, 6.6221630573272705, 32.46508173644543, 60.113971307873726, 60.125359296798706, 54.070376604795456, 55.78857220709324, 45.97520358860493, 42.18705765902996, 41.73606365919113, 41.19235843420029, 41.59963198006153, 42.38493204116821, 41.84576377272606, 42.87509433925152, 44.47284020483494, 47.41536431014538, 47.52635255455971, 49.0135433524847, 48.03806729614735, 45.59345327317715, 45.245650336146355, 43.07625934481621, 40.8181469142437, 41.193239986896515, 44.128749668598175, 48.97927299141884, 50.06689243018627, 54.1782034188509, 53.39149363338947, 50.165527537465096, 49.755700528621674, 53.736887499690056, 51.544416546821594, 47.98214569687843, 39.84607547521591, 38.49030062556267, 40.16301266849041, 41.052590534090996, 39.307032600045204, 41.50329574942589, 39.55681599676609, 40.17391808331013, 40.42519100010395, 40.30091106891632, 38.95087011158466, 39.8519803583622, 37.926452681422234, 39.76481683552265, 38.00084888935089, 43.062424287199974, 41.60159647464752, 45.910861641168594, 48.43906357884407, 53.22287768125534, 52.671230882406235, 58.169220462441444, 54.95270825922489, 53.349570482969284, 46.58044271171093, 47.824252769351006, 37.17190437018871, 34.480953365564346, 57.17397786676884, 54.73264306783676, 48.21528598666191, 46.53226889669895, 46.746205016970634, 45.4255098849535, 46.18335261940956, 44.81549821794033, 48.06994378566742, 50.456071346998215, 53.48110042512417, 51.63553185760975, 54.24070246517658, 59.879086911678314, 51.401133835315704, 50.52823707461357, 42.386683747172356, 41.52446821331978, 42.80015096068382, 42.52834394574165, 41.17816999554634, 38.862342461943626, 40.79622209072113, 42.07502827048302, 42.50941336154938, 43.11208002269268, 51.93424142897129, 54.08372908830643, 51.73430755734444, 45.3786925971508, 55.419311821460724, 52.52401538193226, 53.489570170640945, 42.37671688199043, 44.813864305615425, 53.2988204061985, 56.07637636363506, 54.09975662827492, 54.328865334391594, 53.89581397175789, 52.18462139368057, 57.57996708154678, 52.56047822535038, 53.89584057033062, 54.23096738755703, 53.65054473280907, 48.95203225314617, 53.27236622571945, 58.26949328184128, 55.83914749324322, 54.06268201768398, 50.59744656085968, 48.84007886052132, 54.238688573241234, 56.7707435041666, 59.38898541033268, 54.94084529578686, 55.0232058763504, 39.2697262018919, 0.4473396943649277, 13.674366138875484, 7.185625797137618, 3.7250301288440824, 0.32016791054047644, 0.2485962276114151, 39.99456010758877, 58.24151538312435, 41.51211507618427, 33.516561314463615, 18.712185211479664, 30.263664163649082, 45.31139820814133, 61.866251081228256, 44.47266921401024, 4.485418489202857, 0.3137081384193152, 0.010352885874453932, 0.006600473579965183, 0.09162344445940107, 0.04854201673879288, 0.06827835808508098, 0.038262833550106734, 0.04035351550555788, 0.05573886024649255, 0.02334234228328569, 0.026913879737548996, 0.033316890549031086, 0.13872519746655598, 0.13694582419702783, 0.11860268699820153, 0.11099705370725133, 0.181920463219285, 0.211625354422722, 0.297993101994507, 0.08812216241494752, 0.1405253805569373, 0.1895804810919799, 0.13034298084676266, 0.135496944130864, 15.071146488189697, 69.39918726682663, 59.830149337649345, 59.71427455544472, 35.52860654890537, 35.702591612935066, 70.28742760419846, 49.46143291890621, 51.28118947148323, 64.81284856796265, 8.183917254209518, 0.6732625979930162, 1.0837753512896597, 16.132674627006054, 5.295308455824852, 12.066590711474419, 31.275367476046085, 63.32076743245125, 61.701032146811485, 56.46625064313412, 56.518376246094704, 47.999024391174316, 45.49999728798866, 44.704316183924675, 43.09496194124222, 44.43349711596966, 44.26873415708542, 42.95306235551834, 46.77113927900791, 47.22743779420853, 49.04147185385227, 50.83733908832073, 52.12179556488991, 50.15536308288574, 48.464252427220345, 46.9455499202013, 46.208746656775475, 43.891422003507614, 42.42583304643631, 47.479185685515404, 52.226658537983894, 51.866681054234505, 57.91620723903179, 55.225917398929596, 50.46370513737202, 50.998914018273354, 55.606732964515686, 56.15149073302746, 51.12488865852356, 41.68407864868641, 41.0004573315382, 41.74006104469299, 42.9337327927351, 41.13727658987045, 42.69504860043526, 41.78225018084049, 43.12743499875069, 42.66030706465244, 42.2772192209959, 39.27911549806595, 42.92070709168911, 40.73666408658028, 42.16742031276226, 40.05897805094719, 47.31356397271156, 44.26241509616375, 49.620959758758545, 50.79351983964443, 56.49790674448013, 55.24838179349899, 60.21394394338131, 55.88023088872433, 54.04724724590778, 47.81125366687775, 49.84125293791294, 37.45599992573261, 34.9770737439394, 58.51237244904041, 56.51184059679508, 50.141482427716255, 48.627138286828995, 49.817982986569405, 47.77497321367264, 46.70089244842529, 47.382211089134216, 49.60888400673866, 52.25125081837177, 55.93590930104256, 55.29741056263447, 55.85361711680889, 58.182812333106995, 54.96389865875244, 53.31270486116409, 45.23750737309456, 44.17862579226494, 46.40722520649433, 42.68664725124836, 43.65202724933624, 42.055903896689415, 42.35317714512348, 46.07218198478222, 44.01788681745529, 44.94785651564598, 53.38282249867916, 56.95328190922737, 53.37465673685074, 47.28624723851681, 56.89963258802891, 55.76879046857357, 57.370210736989975, 45.575905814766884, 45.95847308635712, 55.23877210915089, 57.474743127822876, 56.63996212184429, 57.91246823966503, 58.245402574539185, 55.691411420702934, 60.12204587459564, 54.37122546136379, 53.599562868475914, 56.42101787030697, 56.49980664253235, 48.568518832325935, 55.439234152436256, 59.226369336247444, 59.56711605191231, 57.65974760055542, 53.906753584742546, 52.79148302972317, 55.63268557190895, 60.72606146335602, 62.050529792904854, 58.90728145837784, 58.251269459724426, 41.2438190728426, 2.001019176095724, 28.106039240956306, 11.355854999274015, 5.804127277806401, 0.7079334813170135, 0.4574286279967055, 45.867574363946915, 63.148659467697144, 53.59535649418831, 40.324222818017006, 23.035306334495544, 36.82582654058933, 52.88346849381924, 67.92099058628082, 55.2172614634037, 6.471624635159969, 0.4610220773611218, 0.2032424253411591, 0.2128382315277122, 0.16927028889767826, 0.21559348446317017, 0.11338757816702127, 0.1224764010112267, 0.08853685969370417, 0.12799239135347307, 0.13319167017471045, 0.09161984504316933, 0.12704417895292863], [0.041917851485777646, 0.022901645716046914, 0.016784413710411172, 0.018885170320572797, 0.004762938660860527, 0.03579299205739517, 0.02712927325774217, 0.04475937537790742, 0.035648384582600556, 0.041123430637526326, 0.09180048378766514, 0.11031832997105084, 11.381911151111126, 52.26421192288399, 49.26697835326195, 37.89600871503353, 24.961345084011555, 35.68203091621399, 42.564867585897446, 29.515936486423016, 49.75728504359722, 48.74085858464241, 3.6854353034868836, 0.3980728145688772, 0.40729969914536923, 1.3953467574901879, 9.638429805636406, 5.929572796449065, 49.43935990333557, 58.215038403868675, 55.20206607878208, 51.16335779428482, 44.239661917090416, 40.93840666115284, 38.785499185323715, 39.672303199768066, 44.02276575565338, 43.96334454417229, 42.40287087857723, 39.589156061410904, 40.83889380097389, 42.98529602587223, 47.28193826973438, 51.82513788342476, 53.822002932429314, 51.99177034199238, 50.26255913078785, 48.83371040225029, 47.445736080408096, 45.19125245511532, 43.612361177802086, 42.105844616889954, 42.77343839406967, 44.908688217401505, 48.27119618654251, 50.85312344133854, 51.28552503883839, 48.06929022073746, 49.63471122086048, 49.386025965213776, 48.659903928637505, 40.75973644852638, 37.13328704237938, 37.68535941839218, 37.36613094806671, 38.10081012547016, 38.42022478580475, 37.529062405228615, 39.530004635453224, 39.99154306948185, 40.03634266555309, 36.71729676425457, 37.57270686328411, 35.17142951488495, 36.988397017121315, 37.38036498427391, 38.87751504778862, 40.31014837324619, 43.6687121540308, 49.609271585941315, 53.20249177515507, 52.10928663611412, 51.231757923960686, 47.42822661995888, 53.42449106276035, 50.66918671131134, 53.25870595872402, 40.66365860402584, 34.89825077354908, 54.69754055142403, 47.9774035513401, 47.182364612817764, 39.756776466965675, 45.11511214077473, 44.15952421724796, 43.901601657271385, 43.406427428126335, 47.715578600764275, 51.78386069834232, 56.16645812988281, 53.2230144739151, 53.515621572732925, 46.18010379374027, 50.73564514517784, 49.93141449987888, 40.37775434553623, 39.587115570902824, 40.14920420944691, 38.88862565159798, 38.67229945957661, 39.91615131497383, 37.49143302440643, 39.626785442233086, 40.26989333331585, 40.724090561270714, 51.376207172870636, 54.94904525578022, 47.72397235035896, 48.25728513300419, 54.94125187397003, 50.05569063127041, 47.807822450995445, 39.06521737575531, 43.031417950987816, 49.69110019505024, 50.84045112133026, 49.62882913649082, 49.152745082974434, 46.589064449071884, 48.19228582084179, 53.65393415093422, 53.36535483598709, 44.26813378930092, 47.42034964263439, 46.34225629270077, 52.74078615009785, 56.28098018467426, 53.06742042303085, 49.83123667538166, 47.083072140812874, 46.65303401648998, 53.707043901085854, 52.025117352604866, 56.11937865614891, 55.37240333855152, 58.09144623577595, 55.225358828902245, 51.3948717713356, 3.7085589626803994, 16.233135536313057, 14.9983024969697, 2.3096120171248913, 1.2480642856098711, 0.07649108301848173, 28.124935626983643, 52.46103376150131, 39.75515015423298, 38.63414190709591, 20.818396992981434, 29.096129313111305, 39.21636946499348, 50.82374721765518, 40.233711674809456, 5.065730474889278, 0.17050206108251587, 0.1095378355239518, 0.037664328556274995, 0.00870365747687174, 0.043023540201829746, 0.022711169804097153, 0.024922055563365575, 0.012468917739170138, 0.00862825620060903, 0.050223174184793606, 0.02735683799983235, 0.03898408234817907, 0.06979761601542123, 0.027010034245904535, 0.03136639286822174, 0.033304656244581565, 0.013998807862662943, 0.08748283929890022, 0.04564257193123922, 0.07489349882234819, 0.030807683688180987, 0.0011726038815140782, 0.06111363472882658, 0.07089448801707476, 16.966963559389114, 62.53945715725422, 54.43104945123196, 45.64896069467068, 28.56614325195551, 39.52053554356098, 58.028571009635925, 35.047316774725914, 50.53860291838646, 54.40345533192158, 4.376899637281895, 0.4301365034189075, 0.9703924634959549, 3.436946449801326, 3.7269373890012503, 11.446084007620811, 52.805587872862816, 61.959178894758224, 57.722736820578575, 53.36052909493446, 46.165983751416206, 42.20616303384304, 42.03194998204708, 43.27109768986702, 45.533990263938904, 45.55427737534046, 45.36190889775753, 43.21914307773113, 42.355229035019875, 43.4418985247612, 47.87747271358967, 54.68927979469299, 54.77130599319935, 54.82234105467796, 52.94304929673672, 50.22125914692879, 48.59732128679752, 47.78294138610363, 44.8296220600605, 43.535954877734184, 44.4914174079895, 47.941989451646805, 50.846302807331085, 52.77602165937424, 52.62737363576889, 47.6322490721941, 50.73437221348286, 51.75312414765358, 51.451332941651344, 41.88737913966179, 38.64480033516884, 39.21926490962505, 39.78573091328144, 41.01624548435211, 39.997960925102234, 39.40622627735138, 40.823048651218414, 41.18423067033291, 41.42858795821667, 38.804946541786194, 39.313344061374664, 37.88649782538414, 39.50950473546982, 39.44547437131405, 41.07946269214153, 42.638785019516945, 44.83190953731537, 52.088452354073524, 54.11168418824673, 54.119519367814064, 53.60113978385925, 47.9329839348793, 53.8435135781765, 51.04219749569893, 54.59870025515556, 41.68013446033001, 35.91214656829834, 58.08976672589779, 49.529745653271675, 48.24558176100254, 41.02269373834133, 46.59738980233669, 45.03608778119087, 47.50433273613453, 46.649306416511536, 49.325217828154564, 52.07079090178013, 56.15404039621353, 53.29469382762909, 55.92963583767414, 49.29691694676876, 51.62726350128651, 52.30779558420181, 41.76032155752182, 42.113656997680664, 41.88439629971981, 40.283591598272324, 40.34350298345089, 41.42530873417854, 40.13867497444153, 42.15727485716343, 40.9786769002676, 42.46669605374336, 53.916443064808846, 57.754396721720695, 48.559532314538956, 49.89020571112633, 56.71183906495571, 52.81168274581432, 49.35385309159756, 41.53930641710758, 44.40193220973015, 52.10937783122063, 53.795867934823036, 51.28132626414299, 50.633791610598564, 47.482179924845695, 49.88721527159214, 54.004028365015984, 55.649279281497, 46.73250675201416, 47.245942801237106, 46.739087998867035, 54.275083020329475, 57.943668365478516, 54.977243542671204, 53.051541075110435, 50.71883104741573, 49.21835996210575, 54.98763598501682, 54.03242044150829, 58.12346711754799, 57.52766288816929, 59.73917841911316, 56.91192872822285, 58.56661073863506, 4.488016599789262, 12.210662830621004, 19.520120657980442, 1.6756693529896438, 1.0195373045280576, 0.0504552957136184, 29.74529977887869, 58.07760737836361, 46.11681818962097, 40.56695759296417, 23.629754036664963, 35.772770047187805, 44.83087979257107, 55.86902529001236, 51.5659423917532, 7.73982890881598, 0.20110069104703143, 0.0785550253931433, 0.07882998368586414, 0.019284302907180972, 0.019165351477568038, 0.06704501996864565, 0.019422993609623518, 0.03405851130082738, 0.02132427576725604, 0.039054879525792785, 0.02169776529626688, 0.05348112455976661, 0.20834460156038404, 0.15387063554953784, 0.11856379103846848, 0.13212333375122398, 0.05355959554435685, 0.22362738149240613, 0.10128786219866015, 0.22070646635256708, 0.11869124005897902, 0.08263098206953146, 0.32485724485013634, 0.2872017404297367, 21.857004761695862, 74.41320061683655, 60.283510610461235, 51.72048769891262, 33.45527060329914, 47.53574565052986, 50.60446098446846, 39.78375501930714, 59.29110646247864, 59.14173647761345, 5.23187798447907, 0.4784919071244076, 1.2999285338446498, 5.891228104010224, 15.933962389826775, 13.671402297914028, 52.90026739239693, 62.975913137197495, 60.443387031555176, 54.98028337955475, 48.804919347167015, 45.03303274512291, 43.59477572143078, 43.41931253671646, 48.11921954154968, 46.65684521198273, 46.21849313378334, 45.29781013727188, 44.62921321392059, 46.54813304543495, 50.18231883645058, 55.841769352555275, 57.5894133746624, 57.27319434285164, 55.62162436544895, 52.53844700753689, 51.3146048784256, 49.96752016246319, 47.95088857412338, 45.368797928094864, 46.2501036375761, 49.60221156477928, 53.5186842083931, 54.83690567314625, 54.45371523499489, 49.90825094282627, 50.87189443409443, 54.349532425403595, 54.553562477231026, 45.063529908657074, 40.431882441043854, 41.81301712989807, 41.31866745650768, 42.98616237938404, 41.85534305870533, 41.54346339404583, 42.76456207036972, 43.378464728593826, 43.64700011909008, 41.139172688126564, 40.61492241919041, 38.90102818608284, 42.4476932734251, 41.90428823232651, 43.17185081541538, 44.871473014354706, 46.766142547130585, 53.56724180281162, 56.64446108043194, 56.33039653301239, 54.38307702541351, 51.84391647577286, 55.57951882481575, 52.782450914382935, 54.9773271381855, 41.67726181447506, 39.66425523161888, 58.856675773859024, 52.0741955190897, 51.39699965715408, 43.642466962337494, 49.11572366952896, 47.3390644043684, 48.62512819468975, 48.08398023247719, 52.04948924481869, 54.72413532435894, 56.51427626609802, 54.30776886641979, 54.95379500091076, 53.968253284692764, 52.62856297194958, 53.15929189324379, 45.30505634844303, 44.04861196875572, 44.52390566468239, 41.03944703936577, 40.954608991742134, 42.97401823103428, 40.811884850263596, 44.00458373129368, 43.61418128013611, 44.70406159758568, 55.63464246690273, 59.744182750582695, 49.865446239709854, 50.064665749669075, 60.475981682538986, 54.12453509867191, 51.17171734571457, 43.98601412773132, 48.42299424111843, 55.10914586484432, 54.57951508462429, 54.004518538713455, 53.716725781559944, 51.83408260345459, 51.100144386291504, 58.05946335196495, 56.091769337654114, 49.1205570101738, 48.57932545244694, 47.928868755698204, 56.546753123402596, 60.083006769418716, 58.01891192793846, 55.33469416201115, 53.16977173089981, 50.993100330233574, 59.618101716041565, 56.59052297472954, 63.259727507829666, 60.49604460597038, 64.10566091537476, 61.08573496341705, 61.33720546960831, 5.505442405119538, 21.94438297301531, 27.501332089304924, 5.394629426300526, 2.286250158213079, 0.2553408656967804, 34.697731733322144, 63.67206618189812, 58.12189780175686, 46.82814382016659, 32.17157028615475, 43.343529403209686, 52.68677204847336, 63.15066955983639, 61.62339851260185, 10.826980378478765, 0.4387412901269272, 0.16195703210541978, 0.19915523997042328, 0.11702920775860548, 0.11841320927487686, 0.16480324266012758, 0.24919819843489677, 0.14592824532883242, 0.1059134014940355, 0.2705243759555742, 0.0959139560291078, 0.14809307525865734], [0.04196297777525615, 0.009675100027379813, 0.05818926860229112, 0.03094378800597042, 0.02606780170026468, 0.0770525548432488, 0.04020067019155249, 0.018191789167758543, 0.025127348453679588, 0.018814419527188875, 0.028784000969608314, 0.12570709601277485, 20.9051501378417, 51.033609956502914, 45.66994696855545, 47.888959497213364, 23.97243294864893, 31.266493052244186, 29.45271547883749, 32.602026388049126, 53.67999315261841, 44.10112515091896, 1.5927733574062586, 0.38660874066408724, 2.0371331507340074, 10.745739787817001, 5.6705140974372625, 18.129830360412598, 61.22248962521553, 55.64956806600094, 54.622103199362755, 44.64226931333542, 42.40728244185448, 40.99671073257923, 48.164216727018356, 51.54712200164795, 54.1841235011816, 52.03034967184067, 50.71784310042858, 42.34657309949398, 40.584668442606926, 40.393090322613716, 46.996463388204575, 52.582194060087204, 55.205645486712456, 50.90179122984409, 50.183869153261185, 51.275071799755096, 51.373813301324844, 52.0440973341465, 51.56867064535618, 48.20806637406349, 46.89551040530205, 45.11824697256088, 48.71755063533783, 48.672295063734055, 52.047574147582054, 48.57923425734043, 46.66886016726494, 48.82290378212929, 50.24693436920643, 41.77996650338173, 36.41669489443302, 36.78243286907673, 37.10587151348591, 40.6306079775095, 38.412837982177734, 38.44481326639652, 37.94579744338989, 39.78665806353092, 38.79605881869793, 37.14495621621609, 36.161397993564606, 37.16955989599228, 37.595923617482185, 38.192472606897354, 37.328497767448425, 40.11333793401718, 47.77679331600666, 51.474865078926086, 52.580848932266235, 51.83568611741066, 46.542509347200394, 51.379687786102295, 53.81541408598423, 50.63273526728153, 53.84575165808201, 47.37206183373928, 35.825404822826385, 53.89378868043423, 49.39319238066673, 45.26217184960842, 41.13821893930435, 43.813191801309586, 45.03232218325138, 46.2539604306221, 48.15099723637104, 56.629315093159676, 53.52564163506031, 49.90306802093983, 48.44372592866421, 49.02306944131851, 51.54594026505947, 55.19236899912357, 47.188546881079674, 39.38313111662865, 39.3717697262764, 39.10709872841835, 40.7054677605629, 38.967634811997414, 39.08964246511459, 37.765960693359375, 38.70141729712486, 39.477430656552315, 41.68693229556084, 50.17742469906807, 53.31729121506214, 49.950041100382805, 46.77889086306095, 54.171040803194046, 50.729945451021194, 50.042904317379, 42.015147283673286, 43.23333531618118, 46.201793029904366, 48.61249387264252, 46.70917980372906, 43.015097826719284, 41.74776703119278, 49.864279702305794, 52.4759441614151, 52.5983963906765, 52.6387008279562, 53.02282601594925, 54.438481852412224, 57.91477471590042, 54.549318104982376, 51.83587230741978, 45.37141598761082, 45.63778929412365, 49.22059044241905, 54.39542256295681, 51.172655895352364, 55.834496542811394, 57.80421204864979, 60.286976024508476, 51.64017900824547, 66.89736351370811, 13.056280855089426, 7.231603804975748, 34.49192337691784, 2.9553056694567204, 0.35003166587557644, 0.06449344946304336, 17.317365556955338, 56.85618571937084, 41.522363126277924, 36.417477652430534, 21.334718987345695, 20.936348363757133, 36.20971620082855, 52.975837737321854, 43.50154772400856, 7.871393049135804, 0.083076730807079, 0.07706761301960796, 0.04620500112650916, 0.028951602034794632, 0.0690374564146623, 0.0746898609213531, 0.022027970917406492, 0.03681315196445212, 0.03315412272058893, 0.06218898073711898, 0.056541147860116325, 0.025117489021795336, 0.02463893179083243, 0.02019713898334885, 0.06750977510819212, 0.03866095867124386, 0.05276488525851164, 0.12190490277134813, 0.0656572706066072, 0.05086547702376265, 0.035278876675874926, 0.06614486163016409, 0.024390325306740124, 0.20050553313922137, 27.304823733866215, 60.60194872319698, 52.388001680374146, 50.23217976093292, 30.40258850902319, 35.463592037558556, 30.290084145963192, 34.48649726808071, 56.91743083298206, 49.94538635015488, 2.1812736662104726, 0.38956578355282545, 2.5078915525227785, 3.8401532638818026, 4.826082084327936, 20.8915563672781, 61.2444144487381, 58.34135502576828, 58.157319501042366, 48.07580307126045, 44.77088861167431, 42.94046223163605, 48.44761312007904, 54.17770944535732, 55.02033703029156, 54.01267670094967, 51.098597869277, 44.36391904950142, 42.88100682199001, 43.85043740272522, 50.71677155792713, 55.13971522450447, 56.926067769527435, 52.20683120191097, 53.60458619892597, 52.05414019525051, 52.96568088233471, 53.519599959254265, 53.95544417202473, 50.46642579138279, 49.942623898386955, 47.04428382217884, 50.31083554029465, 51.05617694556713, 53.916416466236115, 48.74605290591717, 47.16682344675064, 51.61205671727657, 50.60857616364956, 42.92036131024361, 39.84564609825611, 38.32875229418278, 39.40473295748234, 41.331970542669296, 40.577996000647545, 39.446029141545296, 40.51772363483906, 42.33189068734646, 40.16735203564167, 37.42436282336712, 39.0421412140131, 38.58682684600353, 39.60807904601097, 39.955266416072845, 39.94648888707161, 41.542927622795105, 48.97699311375618, 53.352203741669655, 54.04141075909138, 52.036471143364906, 49.61005434393883, 54.63836632668972, 54.965137392282486, 52.30599448084831, 57.596226409077644, 49.85061563551426, 38.86032857000828, 54.06943425536156, 51.919942796230316, 48.01386259496212, 41.517115607857704, 44.6544324606657, 46.037569642066956, 49.3228505551815, 48.601394668221474, 56.36980801820755, 55.097503289580345, 52.44899980723858, 51.45355962216854, 50.640456452965736, 53.075798973441124, 56.310333609580994, 49.31139796972275, 42.00202278792858, 40.481363385915756, 40.666793435812, 43.24044853448868, 41.723923310637474, 40.411868914961815, 39.63227614760399, 39.78358402848244, 41.170729994773865, 43.379912450909615, 52.64585204422474, 55.3097864985466, 51.32536210119724, 48.23230907320976, 55.23520030081272, 52.82028928399086, 51.133168414235115, 41.758311465382576, 44.366711899638176, 47.89925314486027, 51.95194847881794, 48.337392434477806, 45.97483120858669, 43.24660800397396, 50.92274330556393, 54.37525324523449, 54.78109806776047, 54.35139052569866, 54.66506369411945, 55.50431706011295, 57.953665629029274, 55.83015717566013, 53.329632952809334, 48.20624627172947, 47.70194873213768, 51.361919939517975, 56.2695237994194, 52.62906074523926, 57.07810141146183, 60.8190842717886, 63.772753179073334, 55.05765862762928, 71.23938292264938, 14.012516643851995, 6.919979201629758, 33.47999967634678, 4.78770699352026, 0.7245686324313283, 0.05161962893907912, 18.96773859858513, 60.281211733818054, 47.897965013980865, 37.93255515396595, 24.138675928115845, 26.588845252990723, 42.32521824538708, 61.34000211954117, 55.15817083418369, 11.131812371313572, 0.19482280447846279, 0.08231604428146966, 0.06071313844586257, 0.05171244192752056, 0.029681064552278258, 0.031424146800418384, 0.09164565693936311, 0.04952525479893666, 0.03733027304406278, 0.07494936769944616, 0.03633249260019511, 0.003908160797436722, 0.0880832590337377, 0.08600858520367183, 0.23531478247605264, 0.14718571066623554, 0.09162646500044502, 0.2830261504277587, 0.10098194892634638, 0.08209043880924582, 0.11479353241156787, 0.1481506956042722, 0.138764635194093, 0.38639903941657394, 33.32915537059307, 67.84512385725975, 58.767889738082886, 58.1695282459259, 33.458891808986664, 40.724941715598106, 37.0480690151453, 44.043983817100525, 63.489884957671165, 56.17414511740208, 2.892364184372127, 0.5733410816174, 4.263498522341251, 22.96795304864645, 11.44241625443101, 22.392954602837563, 65.1300099492073, 59.87887792289257, 59.12939473986626, 49.037846848368645, 47.754047736525536, 45.40614992380142, 51.80208832025528, 57.08188220858574, 58.301278576254845, 57.22202628850937, 54.09473329782486, 46.788249760866165, 45.64120151102543, 45.40296949446201, 54.016309306025505, 56.95261314511299, 58.56537200510502, 54.72839869558811, 54.917510747909546, 54.57999385893345, 54.520504251122475, 55.566265136003494, 57.34938025474548, 52.592149525880814, 50.92679388821125, 49.51249077916145, 53.15932609140873, 53.38658809661865, 56.8014382570982, 51.49471141397953, 46.89314313232899, 52.89408892393112, 53.52943763136864, 44.362216740846634, 42.746326848864555, 40.36884382367134, 41.111236587166786, 44.58684168756008, 43.577741235494614, 41.845015212893486, 43.07970196008682, 43.08229722082615, 42.68711842596531, 41.07332982122898, 39.67183202505112, 41.12241178750992, 42.05964669585228, 43.02504189312458, 41.760188564658165, 44.70173232257366, 51.547615975141525, 55.319335386157036, 57.05742672085762, 54.28398974239826, 50.84533005952835, 56.665097773075104, 55.50014108419418, 55.38482487201691, 57.88628004491329, 51.07427537441254, 41.80332764983177, 57.67592333257198, 52.633681297302246, 50.83322390913963, 44.97533284127712, 48.605665639042854, 49.5549800992012, 51.46275892853737, 53.14504265785217, 57.27270796895027, 54.38054256141186, 52.26675018668175, 55.2946063131094, 54.530288726091385, 54.81646277010441, 57.52147302031517, 50.640137270092964, 42.62709304690361, 42.770919129252434, 42.608223259449005, 44.72376734018326, 43.00588712096214, 43.57239492237568, 41.099563613533974, 42.067250087857246, 43.27254541218281, 46.95777766406536, 55.60340814292431, 58.82901705801487, 52.37876817584038, 48.19730915129185, 57.687569707632065, 54.96231034398079, 54.57684002816677, 45.30347563326359, 47.07497477531433, 49.21962149441242, 52.55982086062431, 51.14440821111202, 47.41931229829788, 44.012882485985756, 53.07309351861477, 58.53232517838478, 57.549097537994385, 56.94722883403301, 56.252717301249504, 58.14726144075394, 61.09985500574112, 59.948247000575066, 56.294967234134674, 50.43198823928833, 49.28582154214382, 53.265594989061356, 58.937790021300316, 55.80615386366844, 60.28482533991337, 62.9777180403471, 66.82951435446739, 58.07614825665951, 76.69995591044426, 15.775249656289816, 10.981258749961853, 45.709130465984344, 8.241209629923105, 0.8030109107494354, 0.17546748917084187, 21.963220462203026, 67.48348966240883, 56.7667993158102, 47.76345603168011, 31.772489100694656, 31.281032972037792, 49.17486749589443, 67.62578442692757, 65.13340696692467, 15.29101599007845, 0.41970211488660425, 0.20646612189011648, 0.17633667768677697, 0.1624630729202181, 0.13926942920079455, 0.1660065757459961, 0.17370242450851947, 0.11950008454732597, 0.11295601187157445, 0.2117371663916856, 0.13464498828398064, 0.09072065891814418], [0.017000412080960814, 0.14685726579045877, 0.04221232084091753, 0.03856849820294883, 0.06267568489420228, 0.0455600451095961, 0.1139456064265687, 0.09601203826605342, 0.03587409024476074, 0.011144176714878995, 0.029158293873479124, 0.7289396447595209, 30.047852843999863, 55.176489651203156, 48.01272265613079, 33.84503088891506, 14.861848969012499, 47.83911757171154, 58.770367205142975, 31.417468450963497, 48.80871534347534, 39.77981083095074, 1.1352993990294635, 0.3602646949002519, 2.9706979310140014, 4.3930525705218315, 1.8502576346509159, 38.668773248791695, 61.02181099355221, 55.98570942878723, 52.470271065831184, 46.13552078604698, 45.02183094620705, 50.32934054732323, 52.06802845001221, 51.79885469377041, 53.290753439068794, 53.041483014822006, 51.19185246527195, 43.50957289338112, 39.890206307172775, 42.31909677386284, 47.67112858593464, 51.377784088253975, 51.393777430057526, 51.619998291134834, 49.065965339541435, 48.59511740505695, 53.02793674170971, 50.98152995109558, 51.39916934072971, 50.71678675711155, 51.40210658311844, 51.151536628603935, 49.046320393681526, 48.74261789023876, 49.58046153187752, 48.967907801270485, 48.496752083301544, 49.44550797343254, 48.53760749101639, 38.35779033601284, 37.10787780582905, 38.622750118374825, 36.1961205303669, 38.005800023674965, 36.517997458577156, 37.399147376418114, 36.84719279408455, 40.86771905422211, 37.14569337666035, 38.38913485407829, 38.78609575331211, 37.115610390901566, 37.461327239871025, 40.033549815416336, 38.830013796687126, 42.365708872675896, 48.86919289827347, 52.34069801867008, 52.17079773545265, 51.39974690973759, 53.80423128604889, 52.48922064900398, 50.569153279066086, 49.20101009309292, 51.6928555816412, 48.82791571319103, 38.965028151869774, 54.90537039935589, 50.72138071060181, 46.1531138420105, 41.07650265097618, 43.55142004787922, 46.6807497292757, 51.09104007482529, 54.32283505797386, 49.29681055247784, 43.506232872605324, 50.50514951348305, 51.24801345169544, 52.908436954021454, 52.39873230457306, 47.79160872101784, 42.76735872030258, 38.307868614792824, 38.79279859364033, 38.5920287668705, 39.4383155554533, 38.11200812458992, 38.2684039324522, 40.674545019865036, 40.75765796005726, 39.26610879600048, 38.63341614603996, 45.73922485113144, 54.269911497831345, 49.46865253150463, 48.379144594073296, 51.50524824857712, 51.388374119997025, 50.81799052655697, 45.90196631848812, 39.62943769991398, 40.89330308139324, 42.16754570603371, 41.255427449941635, 40.025007873773575, 41.63565404713154, 46.59385219216347, 51.14411562681198, 54.18569281697273, 53.848981484770775, 54.23189453780651, 54.74714308977127, 53.40430274605751, 51.027161702513695, 43.95516738295555, 42.4056751281023, 48.131261095404625, 50.203947275877, 51.726966351270676, 52.30319023132324, 52.0304636657238, 55.49009822309017, 59.46637585759163, 58.61742161214352, 60.198117792606354, 35.79121805727482, 0.14622701914049685, 5.290491264313459, 3.8360732328146696, 1.408073224592954, 0.01844536618591519, 8.176404107362032, 56.78996667265892, 44.458929151296616, 45.73689937591553, 22.514430284500122, 24.286014921963215, 39.64782491326332, 49.7209057956934, 51.471175476908684, 13.674637824296951, 0.17386376741342247, 0.05971486447378993, 0.07071994230500422, 0.018529373592173215, 0.00925984613786568, 0.02783610027108807, 0.014845842342765536, 0.08876247258740477, 0.048447919834870845, 0.04421826437464915, 0.15634225448593497, 0.012312145536270691, 0.032353286005673, 0.07959023234434426, 0.04536409214779269, 0.014505674316751538, 0.010542362670094008, 0.030460000489256345, 0.07837218247004785, 0.03733611745701637, 0.03671731101348996, 0.06393589617800899, 0.053392270929180086, 1.1497712787240744, 35.852322578430176, 62.121027410030365, 54.09817971289158, 42.780000641942024, 21.82227272540331, 50.97250923514366, 52.22410507500172, 34.90565277636051, 56.734121069312096, 43.07818964123726, 1.552612124942243, 0.06656136232777499, 7.2661197278648615, 10.047696344554424, 3.1659402418881655, 39.64347794651985, 63.82155016064644, 58.72902162373066, 53.88642467558384, 47.89054021239281, 46.10979236662388, 53.56667563319206, 54.998769387602806, 55.767061561346054, 54.16638605296612, 54.32434357702732, 53.10967415571213, 46.58292777836323, 41.71390324831009, 42.878992930054665, 48.86214427649975, 53.500699773430824, 54.751022681593895, 52.0043058693409, 50.71549862623215, 50.722786635160446, 52.24240489304066, 53.38762924075127, 53.533115833997726, 52.38565340638161, 53.29739548265934, 51.38622343540192, 50.89152418076992, 51.14614851772785, 52.840865179896355, 49.402532279491425, 49.28468160331249, 51.61077618598938, 51.252808794379234, 40.719580203294754, 37.42985352873802, 40.288694724440575, 38.75488042831421, 40.03701902925968, 38.61719861626625, 37.92634628713131, 38.55303145945072, 42.501240000128746, 39.423621743917465, 40.387379229068756, 40.319659262895584, 41.036099418997765, 39.999119862914085, 41.438687816262245, 41.82191625237465, 44.030821323394775, 51.107743978500366, 55.765750631690025, 53.18815894424915, 51.750642880797386, 53.69679965078831, 53.75820815563202, 53.396323174238205, 49.610308930277824, 54.32888053357601, 50.053543746471405, 41.095543429255486, 56.13917179405689, 52.799105420708656, 48.570388332009315, 42.32402890920639, 47.35397860407829, 48.44889745116234, 53.73625673353672, 54.588976576924324, 53.289013132452965, 46.8247240036726, 51.75086706876755, 51.74673669040203, 53.58926922082901, 53.610779866576195, 50.0423913449049, 44.73676264286041, 39.682566449046135, 39.5592250674963, 39.25939455628395, 41.42270967364311, 39.659285098314285, 40.14650255441666, 42.530000656843185, 40.73732905089855, 42.351292446255684, 39.75682206451893, 47.59749993681908, 57.37195864319801, 51.45284526050091, 48.8368034362793, 51.498317420482635, 53.952544927597046, 52.94933035969734, 47.79495254158974, 40.59010215103626, 43.2366069406271, 44.9467583745718, 43.282721266150475, 41.592587158083916, 43.65373715758324, 48.84035624563694, 52.598479986190796, 55.39751619100571, 55.97772225737572, 54.714913219213486, 56.71741336584091, 54.88032214343548, 54.17183116078377, 46.85618631541729, 44.2941851913929, 48.25911283493042, 52.37262390553951, 54.51822057366371, 54.980511367321014, 54.80296969413757, 57.001957297325134, 61.6011431068182, 58.461618572473526, 67.17594936490059, 36.88943512737751, 0.34403825935442, 5.577751575037837, 9.058221839368343, 2.806508978828788, 0.07185747657786123, 8.908332232385874, 59.28542956709862, 52.264937683939934, 41.40993095934391, 21.6315533593297, 28.159606866538525, 46.35392926633358, 54.197392389178276, 62.71989427506924, 18.60033441334963, 0.30003837193362415, 0.07468971991329454, 0.007125038864614908, 0.017331983253825456, 0.023902480097603984, 0.03331909472763073, 0.011554587163118413, 0.03097499160503503, 0.020229552283126395, 0.013173009938327596, 0.09498929197434336, 0.015240297543641645, 0.1335088344058022, 0.1921808032784611, 0.09517575657810085, 0.12693316850345582, 0.12753502058330923, 0.12978858168935403, 0.19534833409124985, 0.17199811205500737, 0.1788496639346704, 0.09802025277167559, 0.17486585973529145, 1.6602818411774933, 44.654614850878716, 70.73993012309074, 62.7853761613369, 46.03259950876236, 23.299338966608047, 58.08264210820198, 64.2607381939888, 43.212447836995125, 62.79611058533192, 48.26723299920559, 2.5133178988471627, 0.7341179356444627, 4.318445473909378, 7.629525102674961, 3.7944659404456615, 45.42394816875458, 65.24816080927849, 63.98089841008186, 55.63860945403576, 49.69267711043358, 50.04364527761936, 57.08041928708553, 55.87832719087601, 57.967816069722176, 56.67793728411198, 56.90978184342384, 56.17998160421848, 48.836355060338974, 44.52564597129822, 44.69888247549534, 51.42415300011635, 55.90802639722824, 55.095565393567085, 52.38477565348148, 52.23722957074642, 51.56570300459862, 56.62017658352852, 54.91409853100777, 56.49292901158333, 56.29705712199211, 55.95958583056927, 55.36557890474796, 52.909903675317764, 53.160952404141426, 55.07627762854099, 51.02367348968983, 50.19874915480614, 52.7447759360075, 54.13750000298023, 43.23433846235275, 40.43523386120796, 43.83505962789059, 39.568842351436615, 41.94534122943878, 40.58753348886967, 40.08950561285019, 39.595520719885826, 45.60309335589409, 40.45051284134388, 43.337936103343964, 42.20762215554714, 43.8160340487957, 42.072812989354134, 43.916892036795616, 43.61785568296909, 47.455322965979576, 53.026185035705566, 57.121745869517326, 54.629288613796234, 53.44255909323692, 56.680217161774635, 56.91804639995098, 54.795579090714455, 53.909067660570145, 55.831555500626564, 53.57987992465496, 43.19796301424503, 58.26294623315334, 53.83163921535015, 50.94545088708401, 44.918997064232826, 49.659470692276955, 50.24297498166561, 54.16406437754631, 55.207249000668526, 51.69210322201252, 48.013797998428345, 54.60497371852398, 54.706405475735664, 55.452609434723854, 57.05743812024593, 51.439002603292465, 46.46710619330406, 42.02855296432972, 40.83749167621136, 41.731059327721596, 43.65943305194378, 40.46586021780968, 41.49273231625557, 43.68681438267231, 43.67810145020485, 44.607322588562965, 43.098887130618095, 49.634585827589035, 59.91262771189213, 53.484520241618156, 49.29562121629715, 54.240489676594734, 56.86617538332939, 55.89770995080471, 50.356585085392, 43.45591217279434, 45.91534160077572, 46.439523473381996, 46.85238651931286, 44.211570024490356, 46.023677587509155, 52.01163187623024, 54.63153809309006, 58.09401109814644, 58.11010703444481, 58.14258009195328, 59.27197828888893, 57.85187669098377, 56.9954938441515, 49.318590983748436, 46.199923530220985, 51.69812209904194, 55.086829662323, 56.23722553253174, 56.498123332858086, 56.7056529968977, 59.33411255478859, 65.14677464962006, 60.80209918320179, 67.90997117757797, 45.29555685818195, 0.22872701956657693, 9.47394898161292, 11.570717319846153, 2.8768370300531387, 0.1277006827876903, 10.33843394368887, 67.07257211208344, 59.48922023177147, 57.982555478811264, 35.62856398522854, 36.549201384186745, 54.46711711585522, 61.16877190768719, 72.02095538377762, 24.68357238918543, 0.4751703212969005, 0.17726400605170056, 0.1898132186033763, 0.09510974996373989, 0.14051224454306066, 0.12427569352439605, 0.13028138258960098, 0.15552324999589473, 0.1643452633288689, 0.15327586355851963, 0.16661337052937597, 0.09972613115678541], [0.05071362989838235, 0.034627063214429654, 0.058934956323355436, 0.019192272884538397, 0.016152810785570182, 0.03155342892569024, 0.062442932539852336, 0.007018146407062886, 0.028586829030246008, 0.040866016715881415, 0.04854605402215384, 0.9361947735305876, 35.932551473379135, 51.60817712545395, 49.078063890337944, 31.864276975393295, 17.15365894138813, 39.53588292002678, 44.73013959825039, 28.756304048001766, 54.91786792874336, 38.73404994606972, 0.8103360864333808, 0.11683527714922093, 2.3074135975912213, 1.5759268426336348, 5.004608379676938, 36.13354168832302, 59.89816948771477, 55.32948464155197, 50.18958404660225, 48.03595460951328, 54.14498560130596, 52.35976159572601, 52.286866307258606, 57.1073142439127, 54.03279282152653, 51.3506193459034, 53.2345924526453, 45.629536136984825, 38.23691502213478, 41.195075288414955, 45.099658370018005, 47.269873917102814, 51.203046664595604, 48.07280123233795, 48.26049216091633, 48.316124975681305, 46.003664061427116, 44.06157307326794, 47.577167227864265, 50.78205965459347, 49.36974383890629, 49.20112408697605, 49.51842226088047, 51.0332527756691, 49.53827619552612, 47.41077035665512, 48.260780945420265, 49.543147534132004, 49.53871697187424, 38.68299588561058, 36.87995843589306, 36.96022912859917, 37.34024293720722, 37.73618169128895, 37.421444579958916, 38.54209944605827, 38.45693461596966, 38.79169285297394, 37.5686676800251, 38.96263428032398, 38.171531930565834, 39.553175792098045, 38.70568446815014, 38.35343576967716, 38.385878428816795, 41.97668194770813, 48.38799051940441, 52.015579864382744, 51.500684693455696, 52.11147151887417, 52.69343689084053, 49.41754147410393, 45.19610099494457, 46.71889588236809, 51.191780269145966, 52.50170297920704, 37.06354558467865, 51.357683166861534, 52.56371945142746, 49.47669669985771, 43.623380586504936, 43.76924715936184, 47.94311799108982, 49.87456955015659, 42.36765816807747, 43.09171311557293, 50.760328620672226, 52.57407769560814, 49.722231924533844, 47.52392068505287, 43.1783826649189, 39.997911527752876, 39.141361489892006, 38.89830373227596, 39.41213496029377, 37.88271322846413, 37.95520193874836, 38.224159106612206, 39.63742487132549, 39.15793240070343, 38.42327982187271, 39.147783145308495, 40.00212550163269, 41.352850422263145, 51.0465444624424, 52.39557087421417, 51.739802062511444, 51.45178511738777, 52.477680668234825, 51.77055761218071, 49.12619590759277, 42.802598029375076, 39.19078543782234, 39.794645234942436, 43.11660557985306, 40.111118853092194, 39.44210775196552, 43.81460912525654, 49.02366600930691, 49.739786982536316, 50.98244950175285, 52.65708044171333, 52.11417697370052, 48.25334094464779, 41.82913966476917, 39.571380615234375, 44.25832271575928, 46.47899575531483, 51.04261927306652, 51.874827817082405, 52.827607691287994, 52.98783369362354, 54.1060034930706, 55.54210223257542, 58.41421231627464, 60.27279518544674, 52.76694394648075, 5.698263058438897, 1.5287445369176567, 5.817889664322138, 2.7430248353630304, 0.006334215113383834, 5.63319250009954, 48.22039291262627, 48.58994588255882, 48.22769232094288, 31.670006699860096, 27.25394256412983, 38.047510385513306, 55.13456270098686, 58.463488072156906, 20.613787472248077, 0.32469094439875335, 0.19250221259426326, 0.056800706588546745, 0.060724586073774844, 0.054538354743272066, 0.04578958767524455, 0.03502784893498756, 0.014102893146628048, 0.07024148711934686, 0.013278857823024737, 0.04141908371821046, 0.043493905977811664, 0.030715533066540956, 0.05528703703021165, 0.035535841598175466, 0.030960966869315598, 0.07434166749590077, 0.04611871161614545, 0.019190501006960403, 0.020618626913346816, 0.05650148377753794, 0.00930293894271017, 0.06247689321753569, 1.2577087618410587, 44.00641903281212, 60.179346799850464, 54.724629297852516, 37.88911588490009, 22.93345469981432, 47.960399463772774, 41.14082179963589, 31.168938986957073, 58.27594913542271, 42.76539422571659, 0.5095895275007933, 0.07879740340285935, 7.090268488973379, 4.2780503164976835, 11.517999898642302, 41.037976518273354, 61.977349519729614, 57.62919344007969, 53.674631640315056, 49.99649740755558, 54.894734770059586, 54.43612217903137, 55.491120368242264, 58.420877158641815, 56.175060868263245, 53.74531164765358, 54.33551877737045, 48.020341247320175, 40.281638503074646, 41.678637340664864, 47.17443443834782, 49.21378120779991, 53.47983129322529, 48.98712337017059, 47.50364117324352, 48.56759928166866, 47.555960565805435, 46.568450555205345, 48.957652151584625, 51.47855848073959, 51.238035187125206, 51.970818266272545, 52.35870145261288, 53.12029458582401, 52.39392936229706, 46.4817164093256, 49.22126680612564, 51.6676477342844, 50.88171310722828, 40.41482515633106, 39.23677057027817, 38.94995056092739, 39.2371429502964, 40.30303135514259, 40.99220797419548, 38.93505536019802, 39.81045238673687, 41.51604026556015, 39.93994943797588, 39.754770174622536, 38.711752742528915, 40.92222332954407, 41.85741014778614, 40.70859879255295, 40.67945055663586, 43.10342028737068, 50.01335710287094, 52.80684180557728, 54.1104606539011, 52.759177163243294, 54.11769166588783, 52.045731246471405, 48.24102580547333, 48.69118385016918, 53.44383582472801, 53.102184757590294, 40.25731600821018, 52.56093040108681, 52.86029353737831, 50.243389159440994, 43.9717572927475, 46.39271378517151, 50.0589432567358, 52.81515195965767, 47.57178671658039, 44.050055891275406, 51.49916097521782, 53.40346299111843, 52.51528725028038, 48.90470199286938, 45.40705047547817, 43.04336071014404, 39.94109697639942, 41.210004687309265, 40.47702021896839, 39.386585131287575, 40.09827174246311, 39.69348706305027, 43.30455109477043, 41.56698793172836, 41.75308674573898, 42.0943084359169, 42.03480742871761, 42.37472578883171, 53.82855378091335, 54.890497997403145, 52.53094621002674, 51.44722916185856, 53.70723009109497, 53.52106288075447, 51.414452120661736, 43.80062587559223, 42.35020570456982, 42.1391536295414, 44.250894114375114, 41.931255385279655, 40.604605972766876, 44.92155432701111, 50.77769748866558, 52.99301661550999, 53.05122569203377, 53.789925053715706, 55.24091899394989, 49.6439029276371, 45.67584045231342, 42.880452051758766, 46.491360291838646, 48.022537529468536, 53.42800207436085, 52.51597121357918, 55.02862438559532, 54.050849452614784, 56.09817959368229, 56.77474848926067, 60.01212157309055, 63.021765276789665, 59.3059978634119, 5.148046407848597, 2.331208633258939, 14.608280025422573, 6.44934025593102, 0.06775094341719523, 5.413459315896034, 53.46397094428539, 53.0623172968626, 43.30789491534233, 35.89595943689346, 35.712889060378075, 46.95963956415653, 60.38216471672058, 67.33801066875458, 28.57167575508356, 0.4884728731121868, 0.03797270204813685, 0.004031861508337897, 0.03860987664666027, 0.013454125273710815, 0.034907635854324326, 0.0660450650320854, 0.006788593636883888, 0.061646159083466046, 0.07010853878455237, 0.016625295393168926, 0.04797392124601174, 0.11943286081077531, 0.13074742164462805, 0.14440522470977157, 0.07863641672884114, 0.1274496884434484, 0.17639324418269098, 0.21429159416584298, 0.20721171313198283, 0.10973972937790677, 0.11504317604703829, 0.1189421972958371, 2.2559040365740657, 51.28487907350063, 67.81263560056686, 59.57941599190235, 44.93692450225353, 25.121966265141964, 51.35522089898586, 50.09095273911953, 40.59620842337608, 65.94245195388794, 47.93234936892986, 1.0835426137782633, 0.2860842738300562, 4.855968430638313, 3.615676509216428, 9.530674237757921, 45.962956845760345, 64.00473073124886, 59.43302124738693, 55.494422391057014, 51.840827241539955, 58.47327634692192, 56.68581426143646, 58.07799495756626, 61.64149694144726, 58.22561323642731, 54.26484256982803, 56.7409873008728, 50.182797610759735, 42.14263044297695, 44.04416620731354, 49.03619773685932, 51.02486662566662, 55.280797854065895, 51.918004900217056, 50.08322015404701, 50.44246807694435, 48.1007981300354, 45.70066452026367, 49.04822029173374, 52.51888185739517, 53.50763060152531, 52.99862511456013, 53.70273873209953, 56.15926891565323, 51.45559251308441, 48.7905029207468, 51.210292875766754, 55.628684386610985, 53.441677540540695, 43.83976377546787, 40.99512241780758, 41.449904814362526, 40.659452229738235, 41.3929458707571, 41.70824155211449, 42.83979423344135, 40.93625217676163, 44.338996186852455, 42.59205512702465, 43.4822029620409, 41.83543212711811, 42.60396368801594, 42.34918735921383, 43.907517939805984, 43.90771172940731, 45.67193046212196, 51.81658834218979, 55.29532827436924, 57.57112875580788, 55.69877542555332, 57.15206444263458, 54.7532569617033, 50.139852315187454, 50.754332542419434, 56.11689738929272, 56.45512863993645, 42.47562177479267, 55.73175385594368, 56.05434134602547, 53.133742064237595, 46.952568143606186, 49.05462294816971, 52.56335847079754, 52.92123846709728, 45.782576724886894, 45.50557918846607, 53.38798262178898, 55.527925193309784, 53.223018273711205, 52.047805935144424, 46.004579812288284, 44.286969378590584, 42.235022485256195, 42.697560265660286, 43.61054867506027, 40.81585183739662, 43.069628700613976, 42.80132129788399, 45.35137206315994, 42.571426033973694, 42.6131895929575, 43.2136257737875, 44.460798650979996, 45.33791698515415, 55.94626374542713, 57.09524229168892, 54.91099409759045, 52.20286801457405, 56.86704933643341, 57.40054830908775, 53.92792224884033, 46.95088863372803, 45.40274150669575, 44.230732396245, 47.63698361814022, 44.405188634991646, 43.073048517107964, 48.18481162190437, 53.62507089972496, 54.68951918184757, 57.773597091436386, 56.951716393232346, 57.610186859965324, 52.03522861003876, 48.0340851098299, 45.219701528549194, 48.6201998591423, 49.435392916202545, 56.48461125791073, 53.97599346935749, 58.34354370832443, 58.280174508690834, 58.68001565337181, 60.002527087926865, 63.70388187468052, 63.82756143808365, 62.91370667517185, 7.3306668642908335, 6.180897010490298, 15.95461618155241, 6.35760985314846, 0.11038628101232462, 7.270461469888687, 59.10329394042492, 61.86951890587807, 60.40787793695927, 45.803373008966446, 37.776087149977684, 54.09126028418541, 66.53893634676933, 77.0393992960453, 34.67255048453808, 0.8648264687508345, 0.27542284748051316, 0.10402172643807717, 0.16619426489342004, 0.1528829408925958, 0.13354312162846327, 0.24836222844896838, 0.15655756636988372, 0.1731805017334409, 0.09863108483841643, 0.0934976345160976, 0.16456446406664327], [0.03370104845089372, 0.09242015483323485, 0.06335087600746192, 0.05065294819360133, 0.04778911534231156, 0.06705454172333702, 0.010303938452125294, 0.06256020671571605, 0.07098160873283632, 0.15163835923885927, 0.09170324017759413, 1.8698664824478328, 42.43965670466423, 56.284806579351425, 42.92152404785156, 36.11127868294716, 16.258799359202385, 46.112987995147705, 49.08352039754391, 32.00805366039276, 56.234812662005424, 35.47679252922535, 0.2294181371689774, 0.26941985241137445, 14.067583288997412, 8.544846586883068, 3.238996546715498, 20.96888031810522, 63.7775257229805, 52.50006906688213, 55.68851217627525, 53.23626436293125, 52.835427671670914, 55.080480203032494, 53.82349245250225, 47.619759142398834, 44.612125530838966, 49.63662251830101, 53.49993981420994, 46.18091695010662, 38.83845694363117, 38.542882204055786, 44.44829732179642, 47.16170892119408, 50.6484018266201, 52.681452333927155, 51.96071080863476, 50.18027074635029, 47.646068930625916, 44.98813435435295, 47.295590937137604, 47.72000536322594, 50.51082640886307, 46.819138303399086, 48.273601457476616, 46.15658685564995, 48.73005196452141, 49.0095079690218, 50.71655876934528, 47.99026966094971, 43.7136485427618, 36.01244978606701, 37.60005779564381, 37.59729914367199, 38.600274324417114, 37.539857625961304, 38.245707750320435, 36.7346428334713, 37.12374955415726, 36.49481110274792, 38.72886702418327, 38.25333774089813, 38.617031425237656, 38.76217223703861, 39.34431999921799, 41.0825215280056, 40.47873392701149, 40.181916654109955, 45.41088446974754, 50.34427374601364, 53.30513186752796, 48.58052238821983, 48.58910612761974, 41.77666448056698, 43.4644541144371, 49.5605544000864, 52.70606741309166, 51.44432231783867, 38.50175321102142, 50.261422991752625, 52.91030265390873, 47.958358973264694, 44.45695325732231, 43.689390644431114, 51.48777678608894, 48.06648217141628, 45.85714012384415, 48.64706441760063, 48.49993251264095, 50.47121733427048, 51.253948733210564, 51.49527758359909, 47.8861628472805, 40.43366074562073, 37.308792024850845, 38.079143688082695, 39.66547876596451, 38.61920490860939, 39.22323189675808, 38.92616763710976, 39.06060442328453, 37.77762986719608, 40.199711099267006, 39.72911395132542, 38.2936155796051, 38.70343878865242, 45.515770241618156, 52.87113435566425, 52.36814394593239, 51.61443918943405, 54.20898176729679, 51.85498148202896, 50.3186821192503, 48.0793596804142, 42.358291670680046, 41.41649320721626, 41.65629453957081, 40.04716828465462, 40.19234709441662, 40.43737314641476, 40.61591036617756, 43.3901908993721, 43.3749271184206, 42.45048612356186, 42.43656747043133, 40.52885703742504, 40.96913941204548, 41.15757130086422, 43.35801042616367, 46.64265297353268, 49.117665365338326, 50.58486543595791, 51.168806701898575, 48.4407164901495, 52.70122267305851, 55.140326991677284, 57.73713804781437, 59.25714768469334, 66.58486068248749, 14.779715426266193, 1.1622400721535087, 13.63494610413909, 2.5048719020560384, 0.057123589067487046, 2.155573032796383, 47.87532962858677, 47.0561695843935, 46.80550843477249, 30.327690728008747, 25.05212791264057, 41.116552501916885, 50.07813222706318, 52.84996949136257, 28.29073403030634, 1.2270894111134112, 0.05742086003010627, 0.05793181015178561, 0.05562204991292674, 0.029792494315188378, 0.054371256483136676, 0.030929368076613173, 0.04403570717840921, 0.019581427295634057, 0.03402180096600205, 0.07115764616173692, 0.04364592379715759, 0.0411703566351207, 0.050768418950610794, 0.05147260948433541, 0.0645526876905933, 0.05630107792967465, 0.1561656827107072, 0.016823138976178598, 0.054881030300748535, 0.1127146060753148, 0.06902301422087476, 0.03706379378854763, 3.1519510550424457, 51.55919015407562, 62.53399685025215, 50.646372735500336, 40.29781423509121, 17.004000172019005, 41.27799063920975, 45.301131159067154, 31.87379166483879, 60.45920938253403, 37.72583864629269, 0.32648237014655024, 0.2619416458765045, 6.211012294515967, 8.590864017605782, 3.402214413508773, 23.352382220327854, 66.17985561490059, 54.535562843084335, 56.54790826141834, 55.562013164162636, 54.44493010640144, 56.14969342947006, 55.62779523432255, 47.74808965623379, 46.42215080559254, 50.71039170026779, 56.303353384137154, 47.33697831630707, 40.15904188156128, 41.842089369893074, 46.42077147960663, 48.20060357451439, 52.856258153915405, 55.17496973276138, 53.08018393814564, 51.117562651634216, 48.319468796253204, 46.68636582791805, 49.06759165227413, 47.686046585440636, 50.45855261385441, 47.42371246218681, 47.46555581688881, 46.7605834454298, 48.40661711990833, 49.482624381780624, 53.1854534894228, 51.38957105576992, 45.87865836918354, 38.71380843222141, 38.29236164689064, 38.51613163948059, 38.900963589549065, 39.18283626437187, 39.758250787854195, 40.4271174967289, 39.847800582647324, 38.30666407942772, 39.21696603298187, 40.04015766084194, 40.079287961125374, 40.172192975878716, 42.30745419859886, 40.92589773237705, 42.188550978899, 41.499606147408485, 47.50297620892525, 51.924855932593346, 54.98686082661152, 51.50164604187012, 50.395890176296234, 45.60924902558327, 46.83033250272274, 51.080260053277016, 53.37064415216446, 53.018311858177185, 39.721274971961975, 51.75483025610447, 55.901958122849464, 50.33912882208824, 47.1085649728775, 46.933306977152824, 53.524634689092636, 49.888925179839134, 48.258645460009575, 49.456736370921135, 49.186977446079254, 52.3394250869751, 53.16449761390686, 52.57880464196205, 49.34062220156193, 41.95476472377777, 40.15353597700596, 41.24475762248039, 39.19086143374443, 40.81461690366268, 41.67353041470051, 39.73417907953262, 41.03773333132267, 39.47336867451668, 40.70774383842945, 41.02291412651539, 41.213983073830605, 40.34915328025818, 46.957823261618614, 54.7048931568861, 52.88537219166756, 50.83387367427349, 54.4094780087471, 53.888727352023125, 53.7237174063921, 50.38875415921211, 45.10107569396496, 41.95103332400322, 44.241580814123154, 42.466278076171875, 41.63108669221401, 41.6548316180706, 43.58211100101471, 45.62632530927658, 44.61271449923515, 43.6503629386425, 45.087472423911095, 41.16487830877304, 43.08493047952652, 42.321452647447586, 44.85587105154991, 48.8532679527998, 51.420771181583405, 52.706321999430656, 53.507972583174706, 50.57444639503956, 56.01831167936325, 58.601504266262054, 59.91437941789627, 60.54421842098236, 71.34844467043877, 16.013697311282158, 0.9105882444418967, 9.772023987025023, 5.339834941551089, 0.1448636344866827, 2.7181929303333163, 50.91410256922245, 51.715585961937904, 47.945033088326454, 35.104427710175514, 29.754499085247517, 48.51575866341591, 54.574639946222305, 61.192558631300926, 36.87112011015415, 1.800489448942244, 0.0534457166941138, 0.12160384314483963, 0.02472553856932791, 0.09331145192845725, 0.03536705124133732, 0.07673199899727479, 0.04503555079281796, 0.04057357342389878, 0.019250223485869355, 0.049781722482293844, 0.039442462439183146, 0.12194455572171137, 0.18934622959932312, 0.12216587158036418, 0.25119297264609486, 0.12937703111674637, 0.20086553413420916, 0.08837357978336513, 0.1802055083680898, 0.12352298508631065, 0.16908206540392712, 0.18168481648899615, 4.45649016648531, 62.38563381135464, 68.36652427911758, 55.73737375438213, 46.112311631441116, 25.183414667844772, 56.58910185098648, 58.86723920702934, 42.58646182715893, 67.44644924998283, 42.767780497670174, 0.5399735877290368, 0.5735825467854738, 22.721823155879974, 14.661309029906988, 4.944041054695845, 28.041380010545254, 69.34692487120628, 57.62904904782772, 59.3899467587471, 57.950158417224884, 58.096203580498695, 59.7164898365736, 57.6575893163681, 48.76154847443104, 46.13435424864292, 51.25077970325947, 59.624071195721626, 49.58720996975899, 42.537144273519516, 43.43781754374504, 50.05822129547596, 49.67484466731548, 54.22457993030548, 57.35159933567047, 55.63206620514393, 53.25527474284172, 48.846910893917084, 45.948103442788124, 50.435157269239426, 49.24647465348244, 51.937847435474396, 46.82809442281723, 49.919950515031815, 48.32616783678532, 49.57818165421486, 50.02291738986969, 55.10949544608593, 51.9783266633749, 47.615472972393036, 40.7395139336586, 41.34192980825901, 41.06195703148842, 43.73836621642113, 40.191777125000954, 41.43731988966465, 41.423484832048416, 41.75247497856617, 39.73678953945637, 41.88014052808285, 42.80007876455784, 42.59978391230106, 41.94453187286854, 44.21437807381153, 44.452188313007355, 44.40510883927345, 42.991687282919884, 49.96791534125805, 54.32407759130001, 57.635637894272804, 54.11515720188618, 53.39953400194645, 47.47167728841305, 47.489828914403915, 55.28904341161251, 57.48733565211296, 55.82212820649147, 43.562393859028816, 53.01435247063637, 58.69144544005394, 53.0340202152729, 48.465555757284164, 48.34093004465103, 57.022700384259224, 51.69729374349117, 49.61818590760231, 49.713632985949516, 49.790730848908424, 54.984406158328056, 54.69299599528313, 54.350296184420586, 52.53212034702301, 44.44261282682419, 42.041943445801735, 42.84687705338001, 42.98039808869362, 42.02815778553486, 43.66104796528816, 41.615868508815765, 43.065445125103, 41.0322730243206, 43.17636117339134, 42.89130426943302, 43.13371606171131, 43.698396161198616, 47.89704166352749, 55.87045781314373, 54.7698050737381, 52.144449949264526, 55.53197957575321, 56.66484318673611, 55.58820515871048, 53.41832399368286, 47.394739016890526, 45.034032091498375, 46.479200944304466, 43.890848234295845, 45.247512236237526, 45.20518250763416, 44.64352324604988, 47.84812308847904, 47.627332136034966, 46.0141970962286, 46.39963701367378, 43.54244872927666, 43.790989592671394, 45.05358584225178, 47.501429691910744, 51.63447931408882, 54.86466318368912, 55.57397112250328, 56.68193846940994, 52.53875859081745, 58.34765508770943, 60.57947672903538, 62.20688000321388, 62.26266101002693, 75.15939697623253, 19.068938568234444, 2.8482214780524373, 23.740335702896118, 4.68649229966104, 0.17291849391767755, 2.9614782007411122, 57.36180558800697, 60.779429599642754, 62.01122470200062, 42.008611634373665, 36.27020515501499, 55.95567584037781, 62.30888552963734, 70.05987301468849, 46.17547944188118, 2.306198850274086, 0.1268679485656321, 0.2455380151513964, 0.16974495170870796, 0.18237116950331256, 0.11624290971667506, 0.18239675875520334, 0.14177818520693108, 0.1346924263634719, 0.1386325477506034, 0.1270032866159454, 0.14756708551431075], [0.02942378236184595, 0.02994439153553685, 0.074986363761127, 0.03628235681389924, 0.06267556615057401, 0.012542682579805842, 0.06458800649852492, 0.04620559855538886, 0.029085090282023884, 0.1436861281399615, 0.10001599919633009, 3.550632786937058, 44.586381912231445, 50.40122888982296, 48.455927073955536, 34.257662147283554, 30.38369782269001, 55.633023753762245, 42.0610336214304, 35.44217638671398, 54.520736038684845, 31.1992746591568, 0.11624538106843829, 0.06226934419828467, 5.029697008430958, 9.291113242506981, 2.408051434904337, 21.760624833405018, 65.89560806751251, 55.25888442993164, 55.77197089791298, 53.54086361825466, 56.816895827651024, 48.24933975934982, 54.16536770761013, 50.20853362977505, 50.57078339159489, 57.563863545656204, 52.57409669458866, 45.44331572949886, 37.3128692060709, 40.62072470784187, 47.222129479050636, 48.10332119464874, 48.464320823550224, 51.57705679535866, 48.68608072400093, 44.6124105155468, 48.10760356485844, 46.53268687427044, 49.05432656407356, 51.21340870857239, 50.67630372941494, 50.44366501271725, 50.59145428240299, 50.98293587565422, 49.6649955958128, 50.65288558602333, 48.912666365504265, 48.22037771344185, 38.6148389428854, 34.83373783528805, 38.309232741594315, 37.70963631570339, 35.286247953772545, 36.55863247811794, 37.94130988419056, 35.54539404809475, 39.44621533155441, 37.854096964001656, 37.55032606422901, 36.75801157951355, 39.18853975832462, 40.18276400864124, 41.70707881450653, 41.97062507271767, 39.48028810322285, 37.569347843527794, 41.54908709228039, 43.999590799212456, 45.43712966144085, 43.28741021454334, 40.90212240815163, 40.69952867925167, 45.36115653812885, 51.113823652267456, 50.55557660758495, 52.08762399852276, 37.933828085660934, 49.969917833805084, 52.11752839386463, 49.38514821231365, 47.308194860816, 44.460730254650116, 46.48980237543583, 50.825696513056755, 51.58716805279255, 51.72802649438381, 52.37470619380474, 51.216862723231316, 52.69292771816254, 50.846773982048035, 50.91784156858921, 46.427671909332275, 38.61090995371342, 38.89917768537998, 39.0255893021822, 37.07660548388958, 38.2840970903635, 39.394971281290054, 39.581260085105896, 40.03384239971638, 39.45446848869324, 39.18454997241497, 39.076179787516594, 38.95712837576866, 40.45871280133724, 50.575506538152695, 51.712751314044, 50.54976671934128, 51.78330212831497, 51.58024862408638, 52.189082354307175, 51.25458709895611, 48.736994192004204, 46.24217726290226, 45.41346073150635, 45.08908353745937, 40.995411202311516, 41.53885804116726, 40.2013374119997, 38.63558202981949, 37.58091442286968, 40.12557327747345, 40.27467727661133, 39.677163138985634, 39.46261145174503, 40.28089754283428, 43.360275104641914, 47.61993773281574, 47.40562163293362, 48.55896234512329, 49.084436148405075, 49.02309224009514, 51.80384382605553, 52.920759692788124, 56.50194592773914, 56.19880199432373, 68.60825210809708, 34.056865721940994, 1.5717613161541522, 18.094661347568035, 6.430692281574011, 0.06147228130430449, 1.1963921645656228, 46.13798305392265, 48.85638378560543, 45.26452772319317, 37.005769684910774, 19.97573520988226, 33.61252136528492, 48.8491527736187, 52.81913794577122, 31.778107099235058, 1.9852977572008967, 0.12204634127556346, 0.030325092884595506, 0.0338443349028239, 0.019358745885256212, 0.028144110110588372, 0.010005745371017838, 0.07469715623301454, 0.05435186787508428, 0.035746926951105706, 0.012210892473376589, 0.05612168228253722, 0.04239528992911801, 0.028098096954636276, 0.03334898472530767, 0.028520675841718912, 0.0393244201404741, 0.015032094506750582, 0.09487874165643007, 0.009598104061296908, 0.06942559964954853, 0.0626784456835594, 0.14100795466220006, 5.513141741976142, 54.10853795707226, 60.33532842993736, 52.52196729183197, 42.28423364460468, 26.079778969287872, 51.13146610558033, 45.88395908474922, 39.7357863932848, 60.0405478477478, 35.68151034414768, 0.15620299789588898, 0.18905279925093055, 6.629459615796804, 6.765968715772033, 2.8333818493410945, 22.663745172321796, 68.40078324079514, 56.47590592503548, 57.26025603711605, 56.60407304763794, 57.99315311014652, 49.561207965016365, 55.023730248212814, 49.55987423658371, 52.16299295425415, 58.73181827366352, 53.11855807900429, 47.591933235526085, 38.84288750588894, 43.40930387377739, 48.16754534840584, 50.34033715724945, 51.50891125202179, 52.27395839989185, 50.55091045796871, 46.83254398405552, 48.180198669433594, 46.45661115646362, 50.51811441779137, 51.931775361299515, 50.24563103914261, 52.19586119055748, 51.37756749987602, 50.273369550704956, 51.70434236526489, 53.16419743001461, 50.41559211909771, 49.79005068540573, 40.52226059138775, 38.816095143556595, 39.530073031783104, 39.41081263124943, 38.3331448584795, 37.09927126765251, 39.42179784178734, 38.28011490404606, 40.51710806787014, 38.50730471313, 39.683003425598145, 38.0235792696476, 41.55965432524681, 41.58754102885723, 44.29860055446625, 42.558483928442, 41.23919852077961, 40.00805698335171, 43.879958018660545, 45.37281051278114, 47.38424398005009, 45.100129544734955, 44.46632735431194, 42.408163994550705, 47.23232813179493, 51.52640551328659, 51.02688431739807, 54.77558456361294, 40.45245073735714, 52.12960794568062, 55.13285659253597, 51.06751933693886, 48.77271227538586, 47.055717408657074, 47.78103768825531, 51.562750563025475, 55.51603943109512, 54.89812798798084, 53.2866420596838, 53.045624792575836, 55.105178877711296, 52.76310995221138, 52.975864335894585, 49.06524337828159, 41.3763103634119, 39.890867471694946, 40.18573924899101, 38.2507386803627, 40.004040598869324, 39.95778188109398, 41.788702234625816, 41.91609799861908, 40.06410777568817, 39.48973439633846, 42.00595557689667, 39.86986979842186, 42.40233510732651, 51.35785415768623, 53.42772848904133, 52.78370104730129, 49.71900209784508, 54.1799209266901, 54.70895133912563, 52.95376852154732, 50.1027625054121, 48.50333712995052, 45.98575942218304, 46.67901322245598, 43.50122854113579, 42.71354980766773, 41.85007654130459, 42.50767305493355, 39.45205561816692, 41.442639604210854, 41.81997075676918, 41.478399485349655, 41.56878903508186, 41.921934485435486, 45.350927487015724, 49.61324617266655, 49.96147848665714, 50.4208168387413, 52.4617937207222, 51.416519209742546, 53.97413156926632, 53.74619700014591, 59.932158663868904, 58.73012736439705, 70.36428228020668, 37.99346208572388, 0.7351632951758802, 3.251948864199221, 3.3554434357210994, 0.27923425077460706, 1.2914239964447916, 50.31244285404682, 55.07797233760357, 50.63970789313316, 40.92497818171978, 28.522365801036358, 41.381542682647705, 56.37039318680763, 60.90737633407116, 42.02843137085438, 3.0983698926866055, 0.07423786330036819, 0.06931073003215715, 0.028124730779381935, 0.03458761806541588, 0.03591715336369816, 0.05825542364618741, 0.04582648725772742, 0.005097726580061135, 0.04134628645260818, 0.04182855256658513, 0.017424451143597253, 0.10798097297083586, 0.10225398262264207, 0.1431472843978554, 0.07754934107651934, 0.1944052573526278, 0.11838029502541758, 0.16613098938250914, 0.14579085895093158, 0.23122575657907873, 0.3932708816137165, 0.3049135993933305, 6.885043401271105, 66.09803080558777, 63.973747193813324, 61.270249262452126, 46.15048438310623, 42.364268749952316, 66.45672395825386, 54.1981865465641, 46.67679414153099, 65.11034220457077, 38.64924229681492, 0.20025473175337538, 0.5390535027254373, 12.938534673303366, 16.877362467348576, 5.830335421487689, 25.717179626226425, 69.46813076734543, 58.74393582344055, 59.806035831570625, 58.581053763628006, 60.804702043533325, 50.94399556517601, 54.5921266078949, 51.58769242465496, 54.46678273379803, 62.08613008260727, 57.718956023454666, 48.35283100605011, 41.656146347522736, 45.45615904033184, 51.40171900391579, 52.296597585082054, 52.766313180327415, 54.24324452877045, 51.06051631271839, 48.61657105386257, 49.900579154491425, 49.84599128365517, 53.92064183950424, 56.637230068445206, 54.13756459951401, 54.81457807123661, 54.11841742694378, 53.825358152389526, 53.23575899004936, 56.415929943323135, 52.14464753866196, 53.46457131206989, 41.8679241836071, 39.52034555375576, 43.01175780594349, 41.02098762989044, 39.036753103137016, 40.17015628516674, 41.29368379712105, 39.400184601545334, 43.79582293331623, 41.16300880908966, 43.64026688039303, 39.864762872457504, 43.831294029951096, 44.57809075713158, 45.592320933938026, 45.56385286152363, 44.434557259082794, 41.42204850912094, 45.87360464036465, 46.59403458237648, 49.0535894036293, 46.4531609416008, 45.88716611266136, 44.14022505283356, 50.69853253662586, 55.60135245323181, 53.409341275691986, 55.014443546533585, 43.27098369598389, 53.80910262465477, 56.237575113773346, 53.042364567518234, 50.96764549612999, 49.51683394610882, 49.92277756333351, 54.405537620186806, 54.811606630682945, 57.20452822744846, 54.52472202479839, 54.4931685179472, 57.03135631978512, 56.07571519911289, 55.04502050578594, 50.351763144135475, 42.89744473993778, 41.93638511002064, 42.28235274553299, 40.17979256808758, 42.19598338007927, 42.3503652960062, 43.977244198322296, 42.74553269147873, 42.20558166503906, 41.9753710180521, 43.06546412408352, 43.73673990368843, 44.86722104251385, 54.98028337955475, 56.91239230334759, 56.33038133382797, 51.211664602160454, 56.59359700977802, 59.026500061154366, 55.19958861172199, 53.9398992061615, 51.74395143985748, 48.5342712700367, 49.09134037792683, 44.6353954821825, 45.71861855685711, 43.564297556877136, 43.65395374596119, 40.657879114151, 45.262757018208504, 44.14510399103165, 43.35077561438084, 42.45023533701897, 43.97778756916523, 48.63490127027035, 52.23533347249031, 54.130265191197395, 52.47809484601021, 55.10227583348751, 53.663878217339516, 57.398671209812164, 57.63328202068806, 62.34432242810726, 61.32935129106045, 71.87081024050713, 42.710962146520615, 2.0382657274603844, 28.02971463650465, 12.191152777522802, 0.46321455971337855, 1.4944212161935866, 55.32883107662201, 61.71705588698387, 60.314235761761665, 49.974352195858955, 31.278559304773808, 47.02661097049713, 62.57903963327408, 70.71303516626358, 54.87925060093403, 5.653444938361645, 0.2238740268512629, 0.1270059880334884, 0.14068066753679886, 0.11463545495644212, 0.13801652065012604, 0.09944081248249859, 0.17198318004375324, 0.14070324366912246, 0.10579203808447346, 0.08536463850759901, 0.13146064040483907], [0.09730938661959954, 0.01725537691527279, 0.09036551899043843, 0.03696437197504565, 0.07972091712872498, 0.03303461096948013, 0.12706653244094923, 0.05433828286186326, 0.008633132110844599, 0.04890287120360881, 0.04457646937225945, 4.402148332446814, 51.57034255564213, 52.30399578809738, 47.17479541897774, 30.01354068517685, 50.97306780517101, 64.88862410187721, 66.67528823018074, 36.228259205818176, 49.62593749165535, 25.888307243585587, 0.04720687822555192, 0.12447844826965593, 1.5001517836935818, 9.825193583965302, 2.19211139716208, 27.621730528771877, 42.273225635290146, 52.73095227777958, 58.1450005620718, 55.06686173379421, 53.616756945848465, 54.26679566502571, 54.9792156368494, 56.97961449623108, 53.154785335063934, 51.744939386844635, 48.683082684874535, 40.04633232951164, 40.54472118616104, 39.85576115548611, 43.6181216686964, 47.95914553105831, 50.433492958545685, 52.34615072607994, 48.953217789530754, 47.72662840783596, 43.59240084886551, 50.59174306690693, 46.72519974410534, 47.69396536052227, 45.17359860241413, 49.11938287317753, 49.683455005288124, 51.946309581398964, 49.87227447330952, 50.848943665623665, 44.96576115489006, 38.73363956809044, 35.8687224984169, 35.8754101395607, 36.445098370313644, 39.251175597310066, 35.98993219435215, 37.1468561142683, 40.97025275230408, 37.812379002571106, 36.58264338970184, 36.951455399394035, 38.93487296998501, 36.826841086149216, 39.205923825502396, 43.33760552108288, 40.607262030243874, 41.46710269153118, 38.90464559197426, 39.9388474971056, 37.49211698770523, 39.07012291252613, 40.17356090247631, 38.94029147922993, 38.718637973070145, 42.48543664813042, 44.791893884539604, 50.244042724370956, 51.86759680509567, 52.7963961660862, 39.2448603361845, 51.07327602803707, 51.61905974149704, 51.708126962184906, 47.14864142239094, 42.84518614411354, 45.73141627013683, 48.93279768526554, 49.25481520593166, 54.199938252568245, 51.20982930064201, 50.580788254737854, 51.845671981573105, 53.3656170219183, 49.815368726849556, 48.22155945003033, 46.81190729141235, 38.60109128057957, 37.75698937475681, 37.026334181427956, 37.542946860194206, 40.38749702274799, 39.99674879014492, 40.692654848098755, 40.01264713704586, 38.43396484851837, 38.47516983747482, 37.457082867622375, 37.60285064578056, 42.38369330763817, 52.05556891858578, 49.71477672457695, 52.22553379833698, 50.89283891022205, 51.36298008263111, 52.84695245325565, 51.78012549877167, 52.110293582081795, 51.988445520401, 50.49011372029781, 47.16873474419117, 42.805778458714485, 42.442894130945206, 40.596622601151466, 39.643249958753586, 41.187897473573685, 40.30567601323128, 38.879259154200554, 40.10478839278221, 40.782729014754295, 42.7335025370121, 45.1263253390789, 47.364082261919975, 44.73679304122925, 46.413821652531624, 45.928853675723076, 47.536262422800064, 51.37862004339695, 58.71170595288277, 58.38883347809315, 66.2279686331749, 47.299295738339424, 1.4949246891774237, 0.7062452437821776, 3.3112537069246173, 0.11555785546079278, 1.1711380071938038, 38.7155981361866, 58.52463439106941, 44.78636518120766, 39.37160633504391, 18.0472094938159, 28.030774779617786, 45.372692719101906, 52.32590161263943, 40.04868820309639, 3.986736098304391, 0.03447596565820277, 0.06733505128067918, 0.05439161730464548, 0.02974477978568757, 0.11331179004628211, 0.059346659036236815, 0.11385877514840104, 0.03600375086534768, 0.05550305395445321, 0.024790200041024946, 0.024962049901660066, 0.055480340524809435, 0.057633110554888844, 0.008107533849397441, 0.04186837621091399, 0.06344789697322994, 0.04375632939627394, 0.05143298621987924, 0.02467349546350306, 0.005315444414009107, 0.020837506672251038, 0.07336169859627262, 6.591249816119671, 60.45419365167618, 57.19901092350483, 55.894145742058754, 35.34861020743847, 51.11390724778175, 65.22894144058228, 69.29596960544586, 40.672542527318, 56.19939096271992, 28.134096935391426, 0.07504704175516963, 0.2812783035915345, 6.841233652085066, 16.639641523361206, 0.6893956416752189, 30.38904793560505, 44.13952589035034, 56.44714146852493, 57.619944736361504, 57.48838059604168, 52.562944293022156, 54.539678022265434, 55.881720408797264, 59.90030117332935, 54.52570237219334, 54.95545171201229, 49.17337417602539, 42.29689456522465, 42.07222402095795, 41.94436088204384, 45.83702400326729, 50.453567281365395, 51.56981818377972, 53.0053773522377, 49.00181718170643, 47.77979135513306, 43.695557713508606, 51.60255342721939, 48.04502472281456, 49.58879068493843, 48.34230937063694, 50.75771056115627, 52.14337840676308, 54.12414371967316, 50.33868804574013, 53.05224023759365, 48.392523676157, 41.09128765761852, 37.01394684612751, 37.58675470948219, 38.03015671670437, 40.64993754029274, 37.38986827433109, 39.653650000691414, 43.076103553175926, 39.56312745809555, 38.209203109145164, 37.24937081336975, 41.179750710725784, 39.226796105504036, 41.513832584023476, 45.46957612037659, 42.43887014687061, 42.8567299246788, 41.522648110985756, 41.62823684513569, 40.74079446494579, 41.03189304471016, 40.536707416176796, 41.80275388062, 40.53622104227543, 43.57878997921944, 49.24750819802284, 53.52373793721199, 52.279825285077095, 55.29584884643555, 41.220362931489944, 50.70652350783348, 53.35989832878113, 52.76017650961876, 48.998762145638466, 45.36326922476292, 47.12085731327534, 51.59650035202503, 50.67016325891018, 53.28212030231953, 53.29131580889225, 50.29376305639744, 53.01027148962021, 55.11572331190109, 52.4870927631855, 48.04329961538315, 48.1742025911808, 40.2604166418314, 39.78402100503445, 40.28663143515587, 39.2920234054327, 41.798057332634926, 40.34639082849026, 43.6637382209301, 41.167925745248795, 40.121203511953354, 39.71146769821644, 40.42109861969948, 39.69345286488533, 44.71477322280407, 54.267339035868645, 53.10915358364582, 52.90238007903099, 51.50040730834007, 53.34166310727596, 55.025960728526115, 54.23465698957443, 53.9994116127491, 53.823788836598396, 54.46136802434921, 49.41515900194645, 44.24813166260719, 43.744350895285606, 41.3225394487381, 41.47643119096756, 43.12936149537563, 42.61886648833752, 40.44978708028793, 41.80005602538586, 42.23587363958359, 44.32305984199047, 47.683071345090866, 50.32028943300247, 48.95973064005375, 48.26838433742523, 47.88248464465141, 49.0950071811676, 53.551491647958755, 61.01687125861645, 60.45416325330734, 67.07412242889404, 50.69655284285545, 2.2881391318514943, 1.473317148629576, 1.331422075163573, 0.05702270151232369, 0.974651025608182, 43.28515313565731, 61.506341993808746, 53.68213623762131, 42.1560475230217, 22.557704262435436, 33.25654126703739, 48.7441948056221, 61.15852765738964, 50.340299159288406, 5.9102570079267025, 0.3861441562185064, 0.043594734161160886, 0.05149596487171948, 0.033790024535846896, 0.08862124930601567, 0.03651323895610403, 0.09452284473809414, 0.02742575012234738, 0.027017928841814864, 0.008496944301441545, 0.07067152459057979, 0.15730514656752348, 0.10558034045970999, 0.12755918491166085, 0.12478810938773677, 0.1888546161353588, 0.14639121189247817, 0.19215643114876002, 0.18631583283422515, 0.0984733339282684, 0.2185696005471982, 0.14398787054233253, 9.079923424869776, 70.77922001481056, 62.48435631394386, 61.61201812326908, 39.285012781620026, 62.54842087626457, 69.74300801753998, 74.81603980064392, 47.186669781804085, 62.544324696063995, 31.199021972715855, 0.16348367440514266, 0.3365860873600468, 3.203946752473712, 15.518253296613693, 4.857557695358992, 33.72436836361885, 49.10842426121235, 60.35262510180473, 61.23830057680607, 58.99318724870682, 55.23909889161587, 55.62422342598438, 57.91772335767746, 61.71492040157318, 58.0311244726181, 57.685202434659004, 52.09428124129772, 43.393306732177734, 44.65425007045269, 43.366920948028564, 47.97272980213165, 51.610567197203636, 54.00613725185394, 55.279502123594284, 49.82478082180023, 48.79573903977871, 46.13468863070011, 53.18806394934654, 51.75718612968922, 52.06533059477806, 49.00694690644741, 51.37319773435593, 54.531291872262955, 55.834762528538704, 51.686164140701294, 56.65132351219654, 49.89347353577614, 41.88167564570904, 38.68837259709835, 39.196667522192, 39.68969486653805, 43.55727933347225, 39.683398604393005, 41.70406937599182, 45.229254215955734, 43.12255226075649, 40.42096942663193, 39.622685462236404, 44.285050481557846, 41.34730651974678, 44.26613889634609, 48.19156005978584, 44.663806557655334, 44.917408749461174, 42.32030890882015, 44.28066931664944, 42.70979180932045, 42.28100001811981, 43.19958172738552, 43.490361124277115, 41.74969732761383, 46.65442854166031, 50.95096819102764, 56.365738436579704, 55.07875509560108, 55.940906032919884, 43.048688024282455, 51.78433187305927, 55.47761209309101, 56.31290607154369, 53.29704970121384, 48.65587614476681, 50.0385307520628, 53.692897260189056, 52.22670793533325, 57.52666734158993, 54.70784939825535, 53.30683797597885, 54.43935200572014, 55.78744746744633, 53.46448011696339, 51.087616458535194, 48.757224306464195, 43.512399941682816, 42.26458489894867, 41.79029054939747, 39.954707846045494, 42.485417649149895, 41.43847122788429, 44.78385351598263, 42.698441818356514, 42.0836728066206, 41.48850314319134, 41.51634804904461, 41.271367594599724, 47.258907705545425, 54.10666085779667, 56.36030092835426, 56.65867231786251, 50.60545273125172, 55.52538312971592, 57.226969823241234, 56.54597416520119, 56.734318658709526, 56.193987652659416, 56.62954308092594, 51.44894666969776, 45.790894478559494, 45.84487818181515, 43.90839569270611, 41.770341619849205, 46.07960298657417, 44.31729555130005, 44.06547926366329, 44.83689107000828, 45.670121759176254, 47.09637902677059, 51.44943304359913, 53.579078167676926, 52.07380793988705, 51.23109295964241, 52.36075334250927, 52.00274035334587, 57.10158795118332, 62.346374318003654, 63.997822701931, 69.13269996643066, 54.92932051420212, 3.4322867123410106, 3.9953340869396925, 8.653379213064909, 0.3139936277875677, 1.6910605458542705, 48.42101454734802, 69.03637513518333, 62.30125553905964, 51.40271455049515, 28.960163109004498, 43.53673003613949, 58.48822474479675, 69.30461034178734, 61.246264949440956, 8.799430076032877, 0.469308037427254, 0.20151065342361107, 0.1707709560287185, 0.1793237478705123, 0.2211964619345963, 0.16168205154826865, 0.21226973156444728, 0.09828609006945044, 0.19245562056312338, 0.09832940180785954, 0.10337735671782866], [0.05113929983053822, 0.03836037030851003, 0.037811218135175295, 0.019463177195575554, 0.03965953321312554, 0.054370588550227694, 0.07773118210025132, 0.03500587394228205, 0.08771994806011207, 0.2568108821287751, 0.07896196722867899, 6.102968417108059, 50.68958021700382, 53.31681624054909, 46.39475427567959, 23.86116161942482, 31.376706138253212, 58.906635493040085, 55.813111290335655, 30.53355798125267, 56.774235516786575, 22.774338237941265, 0.007847084543755045, 0.029028607277723495, 10.937861278653145, 4.6813388261944056, 4.176024366170168, 28.230148181319237, 17.72389244288206, 32.7147663384676, 49.04651418328285, 53.57779763638973, 55.00690095126629, 56.59648485481739, 56.40909790992737, 51.69060230255127, 48.25014531612396, 48.10410015285015, 40.702481120824814, 40.90408690273762, 38.76735515892506, 39.613227769732475, 44.17566955089569, 51.52558095753193, 47.797464206814766, 52.22283974289894, 49.41708169877529, 47.978345900774, 44.66182306408882, 49.25448462367058, 50.73619231581688, 46.574503630399704, 45.26555746793747, 42.47065544128418, 45.87464578449726, 47.03004978597164, 48.50076086819172, 43.77333953976631, 36.67764209210873, 37.27403149008751, 37.58388206362724, 36.63668408989906, 36.70108303427696, 36.27112850546837, 36.0552316904068, 36.29164360463619, 37.61331148445606, 37.72698998451233, 36.45165681838989, 37.537243366241455, 37.15200483798981, 37.98871614038944, 43.74315395951271, 46.61040410399437, 47.831377387046814, 44.790309369564056, 40.461406856775284, 40.96065826714039, 40.452420338988304, 39.39421892166138, 40.20548678934574, 41.13018997013569, 40.433805137872696, 41.79926946759224, 49.48026850819588, 50.55590718984604, 52.744916528463364, 55.930384397506714, 40.71005791425705, 51.746903881430626, 50.122650638222694, 48.407665863633156, 45.09537599980831, 42.64120168983936, 44.650267884135246, 47.45878458023071, 46.228957772254944, 47.1348025649786, 50.74902422726154, 50.94277583062649, 50.682189613580704, 49.33694399893284, 48.67137931287289, 49.98644694685936, 48.950679525732994, 43.74224580824375, 37.311064302921295, 39.24687422811985, 37.11132042109966, 39.73198659718037, 41.36497177183628, 40.33399969339371, 38.252885565161705, 41.308628395199776, 38.51585805416107, 38.16840849816799, 38.638435676693916, 38.259831592440605, 45.79117566347122, 52.87573590874672, 50.27305416762829, 52.17439614236355, 50.51785983145237, 51.820152550935745, 52.23470650613308, 52.763645723462105, 50.936642959713936, 52.15431421995163, 51.06638699769974, 48.44827428460121, 43.25655587017536, 43.59326720237732, 38.51214565336704, 36.919890493154526, 39.29637037217617, 40.70483319461346, 41.121268048882484, 40.84071770310402, 42.76910662651062, 44.304695427417755, 43.90165105462074, 44.147254675626755, 43.78422595560551, 45.20177789032459, 50.18017195165157, 50.75081393122673, 59.315774738788605, 59.91374485194683, 65.82177802920341, 43.589387610554695, 11.233875844627619, 0.3088175633456558, 1.686665725428611, 0.030162753646436613, 0.28893803944811225, 32.44550138711929, 59.47643391788006, 40.77082425355911, 51.52094140648842, 29.186526462435722, 22.844140492379665, 48.84133279323578, 51.27936936914921, 50.71574941277504, 7.918106317520142, 0.3110586415277794, 0.10345856993808411, 0.06014418206177652, 0.01925124950503232, 0.12159785401308909, 0.043646673366311006, 0.05307322535372805, 0.06097581790527329, 0.039867431041784585, 0.04453218913113233, 0.10543950309511274, 0.05252329763607122, 0.03234079194953665, 0.02337888192414539, 0.04537078631983604, 0.03031761574675329, 0.016567606398893986, 0.04170249136222992, 0.030294599891931284, 0.0652939967403654, 0.14989474264439195, 0.03179701292538084, 8.475592453032732, 62.398408725857735, 58.09902302920818, 53.38422082364559, 26.965123862028122, 44.68632034957409, 70.33099606633186, 64.00312721729279, 36.76124520599842, 60.32003045082092, 24.015581533312798, 0.05040143063524738, 0.2414475049590692, 2.2842623898759484, 2.6449615973979235, 2.534600794315338, 30.844586491584778, 18.030895069241524, 36.62014737725258, 49.31551314890385, 54.762049689888954, 55.72282433509827, 58.60990561544895, 57.88841553032398, 54.23180714249611, 50.60174413025379, 49.791692197322845, 44.81288395822048, 42.28117860853672, 39.931719079613686, 41.429100930690765, 46.44460380077362, 53.5107996314764, 49.74595785140991, 52.40662828087807, 50.72614945471287, 49.250871017575264, 45.2496325224638, 51.575605273246765, 50.38781940937042, 48.35832171142101, 46.76601715385914, 45.81690788269043, 49.1852181404829, 49.89397510886192, 50.35872057080269, 46.8831192702055, 40.83787925541401, 39.905941262841225, 39.38955657184124, 38.6443367600441, 38.827654123306274, 37.519836500287056, 37.60247826576233, 38.14511954784393, 39.25353147089481, 39.9489701539278, 37.06940487027168, 38.190937489271164, 38.80774699151516, 41.03738754987717, 45.597378462553024, 49.03304010629654, 48.95443372428417, 47.950178012251854, 42.297012358903885, 42.69811883568764, 42.74332121014595, 42.0399409532547, 42.30449415743351, 42.2131584584713, 42.84151554107666, 44.67420659959316, 49.715380892157555, 53.69326204061508, 55.55559150874615, 56.225852742791176, 41.63780093193054, 52.607398107647896, 50.853180438280106, 50.19008941948414, 46.94015420973301, 44.11032825708389, 47.05392770469189, 47.625933811068535, 47.90551520884037, 50.46373553574085, 52.27551631629467, 52.63449065387249, 54.48158673942089, 50.14304794371128, 50.332684367895126, 50.811101496219635, 50.15408635139465, 44.962823912501335, 40.216259211301804, 40.42433984577656, 38.96132715046406, 41.369185745716095, 42.288933992385864, 41.24422185122967, 39.62702862918377, 44.15448568761349, 40.15886329114437, 39.92407388985157, 41.51869252324104, 38.99999387562275, 46.76988534629345, 55.20419776439667, 51.77690327167511, 54.239984303712845, 51.23224049806595, 51.23816817998886, 53.22784021496773, 55.279863104224205, 53.86912040412426, 56.09950192272663, 52.70226761698723, 51.27716928720474, 45.77005259692669, 46.419547945261, 41.064081117510796, 40.205764174461365, 40.78070372343063, 43.01293574273586, 42.71984986960888, 42.60162681341171, 44.56072948873043, 46.78229168057442, 46.492876410484314, 47.30705872178078, 45.58452755212784, 47.946629002690315, 51.13098733127117, 53.24716977775097, 60.05002073943615, 61.79016396403313, 66.81454315781593, 46.752706468105316, 13.820470198988914, 0.3666649467777461, 0.7622701500076801, 0.19319937127875164, 0.23750542430207133, 35.47175019979477, 62.53715068101883, 48.19414772093296, 53.15479293465614, 36.30093030631542, 34.872632548213005, 56.87625244259834, 58.94802667200565, 62.76521444320679, 11.767185777425766, 0.34048678586259484, 0.08316916530020535, 0.008497055623593042, 0.028642289726121817, 0.09209937634295784, 0.02046544021141017, 0.07486696704290807, 0.035931743987021036, 0.060298663811408915, 0.039026132435537875, 0.08345077323610894, 0.23537192784715444, 0.12807867344236, 0.11292705326923169, 0.10655339996446855, 0.22078149748267606, 0.14131653966614977, 0.20038613642100245, 0.1785740748164244, 0.1432936656055972, 0.4407835321035236, 0.14539054449414834, 12.180373705923557, 72.05424159765244, 64.79636505246162, 59.84885573387146, 32.168678641319275, 42.395636066794395, 65.45211106538773, 64.11097303032875, 41.16616263985634, 68.249741345644, 26.925077810883522, 0.17887862253701314, 0.4098188452189788, 17.30068065226078, 10.5230631865561, 6.304050302132964, 32.86863528192043, 19.386943504214287, 37.31848530471325, 51.0883916169405, 55.57128846645355, 58.41741934418678, 60.08877485990524, 60.04712909460068, 56.617524325847626, 53.13823342323303, 51.23509034514427, 45.40838800370693, 43.90027932822704, 42.45728015899658, 43.38609091937542, 49.202302023768425, 55.654435604810715, 53.181300312280655, 55.50046406686306, 52.536737099289894, 49.24887232482433, 47.31004536151886, 53.016107976436615, 53.5228867828846, 52.40028642117977, 48.67949567735195, 48.28873984515667, 49.946431294083595, 52.63366989791393, 53.215308487415314, 48.654588013887405, 41.37328952550888, 42.466251477599144, 42.431874722242355, 40.63808977603912, 39.86000932753086, 39.48044389486313, 39.55846510827541, 39.80866648256779, 40.172793343663216, 42.932425662875175, 39.67150144279003, 39.96610723435879, 40.79097077250481, 41.730071380734444, 49.117125794291496, 52.7029287815094, 52.203335389494896, 50.219610035419464, 44.62700553238392, 44.29432958364487, 44.47395734488964, 44.20806661248207, 42.60079085826874, 44.186624363064766, 45.23885630071163, 46.54146820306778, 53.56881871819496, 56.065212562680244, 58.51275622844696, 57.487031668424606, 43.86173419654369, 54.60275083780289, 53.158094957470894, 53.583193346858025, 49.700075313448906, 46.6618837416172, 48.62964615225792, 51.809228137135506, 50.38683906197548, 51.14463619887829, 55.73581583797932, 54.9823846668005, 56.54149040579796, 53.88208530843258, 50.73023043572903, 54.45933513343334, 51.678412556648254, 47.092541232705116, 42.43175312876701, 42.990376353263855, 40.78114829957485, 43.6683663725853, 44.89407420158386, 43.201967999339104, 42.43904113769531, 46.873349994421005, 42.207899540662766, 41.04791298508644, 43.701139613986015, 41.818029060959816, 51.2043309956789, 56.7072831094265, 56.52922846376896, 57.83883959054947, 49.64716695249081, 52.812199518084526, 54.47818972170353, 58.0541056394577, 55.26910588145256, 58.052513524889946, 55.752029567956924, 51.19046933948994, 47.35438898205757, 48.240113854408264, 42.45458610355854, 42.36440174281597, 43.14601220190525, 45.52500754594803, 44.82583746314049, 44.56368952989578, 46.878753304481506, 49.03884619474411, 49.98515881597996, 48.55980969965458, 48.654588013887405, 49.065057188272476, 54.61260370910168, 55.912943333387375, 64.44593265652657, 64.43397089838982, 70.2754658460617, 47.98021920025349, 16.354362331330776, 0.5414385278709233, 5.087390737608075, 0.6086915347259492, 0.41518314799759537, 40.63557431101799, 68.70412096381187, 57.3907296359539, 63.349509090185165, 39.74632702767849, 33.955034986138344, 64.55672711133957, 65.06504863500595, 76.4589424431324, 15.156367365270853, 0.43896319228224456, 0.18291004293132573, 0.11039324235753156, 0.08965667148004286, 0.1790301245637238, 0.13618463301099837, 0.15760356414830312, 0.11777427949709818, 0.14727286848938093, 0.22072378807934, 0.2023075270699337], [0.0470735810813494, 0.00647861571451358, 0.026737415573734324, 0.016120531072374433, 0.04558558983262628, 0.033593615153222345, 0.06600380162126385, 0.004154320977249881, 0.10140270213014446, 0.08286279189633206, 0.04687407323217485, 5.2372166980057955, 55.41627958416939, 49.556173235177994, 45.62160216271877, 25.088775046169758, 36.3162586838007, 42.94498398900032, 31.476678773760796, 35.464956164360046, 62.114974334836006, 17.19144221395254, 0.2281061833491549, 0.022954488485993352, 1.3766502169892192, 4.960448574274778, 2.5118521274998784, 30.53358267992735, 26.012811362743378, 40.39122462272644, 55.06118483841419, 54.53138306736946, 51.486731842160225, 54.368903785943985, 51.51523411273956, 48.5243234038353, 41.70237086713314, 37.4832596629858, 37.97965742647648, 41.14398702979088, 41.38176687061787, 39.45376932621002, 38.65709647536278, 46.204031109809875, 45.26637442409992, 50.213420167565346, 49.139704182744026, 52.215734124183655, 45.47157481312752, 47.09876149892807, 49.352994337677956, 45.51222503185272, 43.906036019325256, 40.78999802470207, 39.63493600487709, 39.71521809697151, 38.64565148949623, 37.57319323718548, 36.81286923587322, 38.88033449649811, 37.873931899666786, 37.65250638127327, 37.676711082458496, 37.774305045604706, 36.66935853660107, 37.2368086874485, 38.07042695581913, 40.20842023193836, 37.25424975156784, 36.69453218579292, 37.16128394007683, 38.428572937846184, 46.08773835003376, 49.31888736784458, 49.162917137145996, 48.53386469185352, 46.37612767517567, 42.818933352828026, 40.945580676198006, 42.02606409788132, 42.16106705367565, 38.54513928294182, 40.80883741378784, 42.29907184839249, 48.50578419864178, 50.60884214937687, 51.4886811375618, 49.91717666387558, 41.3143090903759, 48.44542823731899, 51.87376767396927, 47.305075228214264, 40.86849421262741, 41.17207892239094, 46.88392102718353, 47.463047951459885, 49.27275784313679, 51.1828887462616, 47.02548623085022, 48.95213484764099, 50.32509997487068, 51.87225915491581, 49.5759017765522, 50.633920803666115, 53.357151076197624, 51.100478768348694, 38.583023250103, 38.121720403432846, 36.74367114901543, 38.917435705661774, 39.79635514318943, 40.2677084505558, 38.58218349516392, 39.926840141415596, 38.67688961327076, 37.970230132341385, 40.42935557663441, 37.4448399245739, 39.110301956534386, 45.80115772783756, 52.74396277964115, 50.47385439276695, 51.05356268584728, 49.153972417116165, 50.53783915936947, 49.36291940510273, 51.788192465901375, 52.15994171798229, 49.87116113305092, 48.519930839538574, 48.81929397583008, 42.88023926317692, 41.90801963210106, 39.4636107981205, 41.34991317987442, 40.45718528330326, 41.98871210217476, 39.40989688038826, 44.016465693712234, 43.58297735452652, 44.56546023488045, 43.01855944097042, 47.08226278424263, 47.33516961336136, 53.47404420375824, 52.52743139863014, 61.00784674286842, 58.413030579686165, 70.08009552955627, 46.210950538516045, 30.849034152925014, 0.6543058308307081, 0.6976533704437315, 0.2352620751480572, 0.17268076917389408, 24.709099419414997, 65.68008363246918, 43.948130160570145, 45.086777061223984, 32.65905372798443, 17.879064716398716, 33.92855420708656, 47.95085817575455, 55.29474690556526, 9.619958996772766, 0.23278021457372233, 0.0398699728975771, 0.04571618927002419, 0.05641308285703417, 0.042078968035639264, 0.03246119427785743, 0.03989955861470662, 0.030548201029887423, 0.014278504768299172, 0.07386716053588316, 0.049591272545512766, 0.02581929169537034, 0.03201395753421821, 0.01377957187287393, 0.020318457864050288, 0.027971484705631156, 0.039313566230703145, 0.004503072868828895, 0.0305409910652088, 0.02413911759504117, 0.21817379834828898, 0.012454926400096156, 9.284534845501184, 64.07183513045311, 54.81316454708576, 51.55170455574989, 29.389184787869453, 35.63418388366699, 53.9838058501482, 41.46055564284325, 38.095144629478455, 66.76950797438622, 21.212648637592793, 0.3076267725555226, 0.012022778446407756, 2.3641827888786793, 4.492324618622661, 4.630637196823955, 32.68146112561226, 27.841757722198963, 44.57168810069561, 58.00069950520992, 57.24201701581478, 54.99283030629158, 55.442175194621086, 54.250642731785774, 50.995038226246834, 44.19350579380989, 39.197647869586945, 41.11499458551407, 41.643660217523575, 42.56414942443371, 40.74264116585255, 41.281410455703735, 46.59812696278095, 48.26590307056904, 51.78677514195442, 51.96536935865879, 51.751490235328674, 46.2519009411335, 49.0407232940197, 51.31583221256733, 49.018973261117935, 45.82354612648487, 42.19322852790356, 41.638815477490425, 41.6353652626276, 40.87239660322666, 38.47062528133392, 39.03894938528538, 40.52807427942753, 38.356832787394524, 39.30423595011234, 38.049311488866806, 37.981728315353394, 38.79283659160137, 38.79515826702118, 40.32514996826649, 39.93132010102272, 39.14739176630974, 38.51893208920956, 39.78942811489105, 40.17157360911369, 47.69461512565613, 49.75228451192379, 50.61610735952854, 51.87109261751175, 48.606034219264984, 45.323033183813095, 42.90885932743549, 43.973315209150314, 43.789078295230865, 41.42431698739529, 43.29678051173687, 44.922477677464485, 48.838121965527534, 52.52322502434254, 53.08035872876644, 53.21269802749157, 41.52810841798782, 50.407099574804306, 53.271237686276436, 49.96098071336746, 42.82677233219147, 43.52832868695259, 47.63409577310085, 48.00390712916851, 49.89479586482048, 51.33251331746578, 49.50509637594223, 50.484463423490524, 51.20983310043812, 51.97879783809185, 51.552821695804596, 52.559634670615196, 55.262019261717796, 51.65063224732876, 41.3940592110157, 39.92443487048149, 39.086188450455666, 40.25554910302162, 39.97819058597088, 40.9090456366539, 40.129684656858444, 41.005967035889626, 40.12635603547096, 40.17667293548584, 41.822444424033165, 39.47502538561821, 39.93666261434555, 48.870758414268494, 52.9437218606472, 53.474906757473946, 52.46195711195469, 50.826441273093224, 50.60592770576477, 51.28641799092293, 52.62306846678257, 52.8079741448164, 52.127590253949165, 51.609339863061905, 48.9422781765461, 45.37177696824074, 43.64739529788494, 42.092940509319305, 43.15686821937561, 43.145810812711716, 44.01612751185894, 42.303563207387924, 45.78011825680733, 46.63362845778465, 45.88477984070778, 46.17642939090729, 49.66638632118702, 51.12626798450947, 56.2388214468956, 56.11162707209587, 62.01273322105408, 62.93307043612003, 68.95258203148842, 52.73413270711899, 35.483666360378265, 0.5018114042468369, 1.2333240453153849, 0.1807431349880062, 0.14167986548272893, 27.110173478722572, 68.96813839673996, 49.86733093857765, 51.7325596511364, 31.456237770617008, 21.42272036522627, 41.69243440032005, 56.08048774302006, 63.100759238004684, 13.17229337990284, 0.40323569846805185, 0.20783559215487912, 0.030579374943044968, 0.021971523165120743, 0.07101316485204734, 0.005175668320589466, 0.08346767936018296, 0.008659142531541875, 0.025733679394761566, 0.09578860728652216, 0.06356405792757869, 0.10060732762212865, 0.14397348772035912, 0.1631403568899259, 0.1240058708935976, 0.08882400405127555, 0.14440835657296702, 0.1731737333466299, 0.1555802469374612, 0.17345233558444306, 0.20974052196834236, 0.09345982951344922, 13.63127265125513, 75.89266642928123, 61.71041764318943, 59.999852031469345, 33.777219727635384, 47.08612337708473, 52.217208445072174, 44.613299667835236, 45.61483092606068, 74.12016034126282, 23.364184387028217, 0.5436339788138866, 0.07245766624691896, 7.825305797159672, 14.85134918242693, 5.014668814837933, 35.47486983239651, 30.10697577148676, 48.16583923995495, 60.05293518304825, 58.87599393725395, 57.67492398619652, 59.0136681497097, 56.75476536154747, 53.60187314450741, 46.85226112604141, 40.09481392800808, 41.561991199851036, 44.80264350771904, 44.65540140867233, 42.48008653521538, 42.43136174976826, 50.05388952791691, 50.16595311462879, 55.176352858543396, 51.75975859165192, 54.069981426000595, 47.84106686711311, 51.24709390103817, 52.29251280426979, 50.42481042444706, 48.45965847373009, 45.125770568847656, 45.14586389064789, 42.77743577957153, 41.7115131765604, 42.16114304959774, 41.796058639883995, 43.3599217236042, 41.08343347907066, 39.7784049063921, 41.27518258988857, 40.496969148516655, 40.4240320622921, 41.20252288877964, 42.03525960445404, 43.44709284603596, 39.796085357666016, 41.11500598490238, 42.08868853747845, 41.607155576348305, 49.413183107972145, 52.214320600032806, 54.594809263944626, 53.70965056121349, 51.011031568050385, 46.82445041835308, 44.17135298252106, 46.8093728274107, 45.98091088235378, 41.017396822571754, 46.11236482858658, 46.51963837444782, 50.872981175780296, 54.49721910059452, 56.78244307637215, 53.92484061419964, 45.20086973905563, 54.17922556400299, 54.409447610378265, 53.14984180033207, 44.80532996356487, 46.70606017112732, 50.409447848796844, 51.538827046751976, 51.40949338674545, 56.13961637020111, 53.09775799512863, 53.075225204229355, 55.04508130252361, 54.04660128057003, 52.63393968343735, 53.54559816420078, 57.95345664024353, 54.417491778731346, 42.9620298743248, 40.80472603440285, 41.41837790608406, 40.80489322543144, 42.565331161022186, 43.1424517929554, 42.22311392426491, 43.62570606172085, 41.203058660030365, 41.09036810696125, 44.98845353722572, 41.20757281780243, 41.30189135670662, 49.99559685587883, 55.93500874936581, 55.754362642765045, 56.801829636096954, 51.682459339499474, 51.26100115478039, 51.14789642393589, 54.787295535206795, 58.091788217425346, 53.90082590281963, 53.51985454559326, 53.712337017059326, 46.91946431994438, 46.35177098214626, 43.5526891797781, 45.100353732705116, 44.48531873524189, 46.891547217965126, 45.36433316767216, 49.32912401854992, 49.40192811191082, 49.397011175751686, 48.78167599439621, 53.263786286115646, 51.66896626353264, 60.50629265606403, 57.185612842440605, 65.07176667451859, 63.106360137462616, 75.92923566699028, 45.897638350725174, 35.637778490781784, 0.4416447796393186, 3.0590507900342345, 1.1070525459945202, 0.24664286524057388, 30.445064529776573, 74.62595880031586, 58.99303525686264, 60.178541243076324, 41.67485274374485, 28.102214746177197, 51.7702080309391, 61.1935655772686, 73.95792424678802, 18.471642918884754, 0.7931703294161707, 0.37298813404049724, 0.157717083056923, 0.12479723780415952, 0.17863439657958224, 0.11164620285853744, 0.12161398830357939, 0.09838574565947056, 0.08081530293566175, 0.352172227576375, 0.14291307743405923], [0.0503102652146481, 0.03240297650336288, 0.014348492077260744, 0.027420328733569477, 0.02063687632471556, 0.10066819115309045, 0.03620918476372026, 0.04498272843193263, 0.006874562168377452, 0.12456461903639138, 0.034911869806819595, 8.71160063892603, 54.51120235025883, 45.7094382494688, 48.800811767578125, 29.732047989964485, 29.566257186233997, 23.438797183334827, 29.01279028505087, 41.01036339998245, 59.05000559985638, 14.84229426831007, 0.3299232042627409, 0.3736224625026807, 1.3730887393467128, 0.31608939345460385, 4.863308686763048, 41.71157397329807, 51.64908953011036, 57.10635669529438, 53.171952813863754, 52.43303686380386, 50.83891220390797, 47.011578977108, 40.68521864712238, 38.72807666659355, 39.32616837322712, 47.396289333701134, 47.13802099227905, 49.41034086048603, 48.34862843155861, 46.936343014240265, 41.68648771941662, 41.65787525475025, 44.90041986107826, 49.96595844626427, 49.18631628155708, 50.826338678598404, 44.234995767474174, 44.532607197761536, 50.01099742949009, 47.858492732048035, 48.310147896409035, 40.33259376883507, 38.03010731935501, 36.44616611301899, 35.183687657117844, 37.73876175284386, 36.15189470350742, 37.8892070800066, 37.63488672673702, 36.874372735619545, 37.48914934694767, 37.695816457271576, 36.89967937767506, 36.94845736026764, 38.73461231589317, 38.91601078212261, 39.02011759579182, 36.103618294000626, 37.48875416815281, 38.34080904722214, 44.956675842404366, 50.93025170266628, 58.82965162396431, 52.031170427799225, 49.94629070162773, 48.69965739548206, 48.221111074090004, 49.04692456126213, 49.73423548042774, 44.846637547016144, 42.80286021530628, 40.247147753834724, 47.13637188076973, 53.43777135014534, 51.40903361141682, 51.939682736992836, 40.60446158051491, 48.8070510327816, 53.43563586473465, 47.55950577557087, 41.87870800495148, 43.3618900179863, 49.58112649619579, 53.38865138590336, 55.64980365335941, 51.68313950300217, 52.435791715979576, 51.407171711325645, 52.84659907221794, 52.45926685631275, 52.95087307691574, 47.13209331035614, 49.51208800077438, 50.20659193396568, 39.292422384023666, 37.92494796216488, 37.35653646290302, 37.927851006388664, 39.52060014009476, 39.35192719101906, 38.154562041163445, 38.83325882256031, 38.61903391778469, 39.227746054530144, 39.98407647013664, 38.37336950004101, 38.79064030945301, 37.88180127739906, 44.65705431997776, 52.66386307775974, 52.15592913329601, 52.39459052681923, 49.623129442334175, 50.327923223376274, 52.53377705812454, 53.68123188614845, 49.639020189642906, 47.705786526203156, 46.78523272275925, 45.30003301799297, 43.3309330791235, 44.286122024059296, 42.69434563815594, 40.53838312625885, 38.95487889647484, 39.68869172036648, 43.947024419903755, 45.26699759066105, 45.734786689281464, 48.590489253401756, 51.59802407026291, 51.99722304940224, 55.4058263450861, 56.24348759651184, 59.27805416285992, 59.4803287088871, 64.85892489552498, 53.680240139365196, 52.830411940813065, 5.677724210545421, 0.9976288676261902, 0.4871291999006644, 0.25620151951443404, 22.273982986807823, 59.33330699801445, 49.90190528333187, 43.740680292248726, 59.678351283073425, 54.93149019777775, 42.992185056209564, 48.03151644766331, 52.88792185485363, 19.2238562554121, 0.33022368501406163, 0.07303412203327753, 0.09209678624756634, 0.009063643628905993, 0.09088262522709556, 0.03117638079856988, 0.0619367618492106, 0.061689170252066106, 0.022875128779560328, 0.027463501319289207, 0.025233922715415247, 0.022034255052858498, 0.047326957719633356, 0.04118185992410872, 0.04790877923369408, 0.04177070215519052, 0.04666892877139617, 0.08026212090044282, 0.04666475790145341, 0.03466222246061079, 0.10765796803752892, 0.09951645217370242, 12.391978651285172, 63.52646939456463, 52.41336531937122, 55.49976870417595, 32.03923478722572, 33.293794468045235, 35.39821274578571, 36.464709118008614, 45.33859334886074, 65.63048869371414, 16.270692721009254, 0.20475067722145468, 0.10561655726633035, 1.5409187274053693, 2.1242852741852403, 5.466114990413189, 45.03721632063389, 53.75473514199257, 60.30026391148567, 55.70007495582104, 54.122923985123634, 53.10906998813152, 50.35061180591583, 42.6344608515501, 40.90800829231739, 40.900336503982544, 46.79687149822712, 50.675004199147224, 51.00814372301102, 51.529376953840256, 48.875956535339355, 43.82815919816494, 43.577904626727104, 46.05388596653938, 51.28482207655907, 51.67452536523342, 52.286368533968925, 45.881124436855316, 46.87091052532196, 52.55489632487297, 50.522769168019295, 50.72071574628353, 42.585652470588684, 39.45271298289299, 39.12083879113197, 37.662116065621376, 39.55597244203091, 37.96577297151089, 38.60280878841877, 39.01012793183327, 40.04252873361111, 39.77376535534859, 38.23434256017208, 38.423078432679176, 38.77299405634403, 39.76039007306099, 39.85422983765602, 39.532911479473114, 38.60082529485226, 38.236421048641205, 41.32960706949234, 47.138640359044075, 53.26821304857731, 57.88797855377197, 53.083140179514885, 52.31303550302982, 50.755989253520966, 48.757490292191505, 50.5038233846426, 49.38161060214043, 46.60704508423805, 44.40601319074631, 41.37905761599541, 49.17409613728523, 55.38802810013294, 53.95882599055767, 51.73467993736267, 42.84448318183422, 50.11624038219452, 55.69090984761715, 47.648880779743195, 43.1301062554121, 45.23778095841408, 51.047475412487984, 54.358089566230774, 55.60922563076019, 53.16145017743111, 53.59176188707352, 52.02791020274162, 52.555834874510765, 54.69255901873112, 54.12791691720486, 49.1601736843586, 52.55588807165623, 52.808202132582664, 39.95449125766754, 40.12418255209923, 39.20828729867935, 39.181510135531425, 41.38165667653084, 40.69222167134285, 39.24628905951977, 40.885038524866104, 41.29173070192337, 40.74767969548702, 40.1245891302824, 40.309643000364304, 39.19137820601463, 38.96631248295307, 48.13665680587292, 54.898078590631485, 54.436733946204185, 53.2174401730299, 52.634581848978996, 51.66922464966774, 52.96215087175369, 54.23691786825657, 53.34436856210232, 50.12233525514603, 47.85998985171318, 46.86066247522831, 44.67462457716465, 44.226868003606796, 43.72695542871952, 43.27993981540203, 40.16473397612572, 41.93367585539818, 45.346880704164505, 47.36261174082756, 47.88499251008034, 50.04876360297203, 51.6819653660059, 54.39842440187931, 59.03188057243824, 57.39915378391743, 61.470289528369904, 62.27083817124367, 62.95338794589043, 60.27369573712349, 62.39748917520046, 7.097701840102673, 0.5727825115900487, 0.6790502218063921, 0.1344972415245138, 23.167696930468082, 67.61061564087868, 54.077622815966606, 49.47903357446194, 58.522647097706795, 61.859001070261, 50.620062947273254, 53.52321356534958, 62.68071837723255, 23.314180970191956, 0.6229469447862357, 0.03933935586246662, 0.03895056695910171, 0.08910524833481759, 0.05734048914746381, 0.012020372032566229, 0.05347631544282194, 0.039124170143622905, 0.05145551040186547, 0.04710889246780425, 0.0900008795724716, 0.0683076358109247, 0.15622784500010312, 0.1737052298267372, 0.12934529688209295, 0.10242653195746243, 0.2046033609076403, 0.10594026723993011, 0.1181442549568601, 0.11796355684055015, 0.24674470274476334, 0.1745700990431942, 15.665326304733753, 74.02331113815308, 60.52107386291027, 63.2456910610199, 39.44540597498417, 39.6107617020607, 31.315113343298435, 41.16232484579086, 50.89883118867874, 70.81238463521004, 18.78814123570919, 0.3361144079826772, 0.8195221528876573, 5.187029941007495, 3.2136709056794643, 7.072101188823581, 46.83902643620968, 54.12423111498356, 61.9169669598341, 57.46495485305786, 57.75343917310238, 55.86113691329956, 53.543645069003105, 43.98117318749428, 43.52064169943333, 43.377769365906715, 50.83022966980934, 53.679844960570335, 54.304907619953156, 53.88537973165512, 51.59576699137688, 45.94768926501274, 45.956911370158195, 50.24950683116913, 54.4328011572361, 54.07845877110958, 53.41803900897503, 45.799770802259445, 48.03392931818962, 53.9150333404541, 53.56304682791233, 54.45833578705788, 44.00739178061485, 40.80875001847744, 40.020755901932716, 40.21838329732418, 41.845193803310394, 39.75483477115631, 41.46027825772762, 40.43635480105877, 41.50279797613621, 41.03264540433884, 42.52874292433262, 39.345535933971405, 40.23474521934986, 42.036840319633484, 42.814172208309174, 42.13503085076809, 39.59499254822731, 41.80115416646004, 42.23806232213974, 49.34129096567631, 54.85219605267048, 58.92039455473423, 53.7057975679636, 53.817956149578094, 52.83090591430664, 50.586259961128235, 53.041114434599876, 54.240318685770035, 48.973379507660866, 46.64552181959152, 42.97644630074501, 50.62815271317959, 56.409257501363754, 55.45669041574001, 54.29430618882179, 46.41067162156105, 52.05714963376522, 58.448824658989906, 51.184268072247505, 45.06036847829819, 46.676463559269905, 54.98028717935085, 56.17623120546341, 55.51167346537113, 56.54179438948631, 56.10871642827988, 54.18140284717083, 55.077223777770996, 56.09479017555714, 55.46891815960407, 50.17930939793587, 55.01774936914444, 53.57713267207146, 43.41120757162571, 42.194083482027054, 42.154869586229324, 40.37949085235596, 43.669274523854256, 41.58656448125839, 41.734676733613014, 42.55841553211212, 42.6844547688961, 43.17371651530266, 43.010123893618584, 41.67494393885136, 41.183189526200294, 40.87102867662907, 49.93632383644581, 57.49288335442543, 57.217116951942444, 56.462253257632256, 54.45352904498577, 52.81075939536095, 54.460391476750374, 57.750957906246185, 54.52347569167614, 51.04602389037609, 50.62255181372166, 49.83348995447159, 47.176474928855896, 48.06105226278305, 47.1724471449852, 44.91863988339901, 43.15732799470425, 43.63633029162884, 47.736321687698364, 50.55487744510174, 51.017498821020126, 53.3482101559639, 56.999875009059906, 56.17179684340954, 62.235427871346474, 60.14729171991348, 64.99335408210754, 64.68124642968178, 68.45311403274536, 54.57749739289284, 61.3048692047596, 10.190520230680704, 1.597126261331141, 1.375966491177678, 0.35080729925539345, 26.26824125647545, 73.29451024532318, 60.502599254250526, 59.084408953785896, 73.61679375171661, 64.27742689847946, 55.43303668498993, 63.21946866810322, 71.3963221013546, 31.203325241804123, 1.1129501857794821, 0.07730011304374784, 0.14055540785193443, 0.26634774694684893, 0.2549975778674707, 0.12935524166096002, 0.11319151759380475, 0.13995392684591934, 0.105572236207081, 0.0914253132941667, 0.2527999598532915], [0.05827677152410615, 0.021159210991754662, 0.023485111087211408, 0.021833841783518437, 0.024238814003183506, 0.04266814052243717, 0.03825094063358847, 0.04302876492147334, 0.05096957065688912, 0.03539032499247696, 0.01624215794436168, 11.473364643752575, 52.12326228618622, 43.63979570567608, 37.34895206987858, 30.48419862985611, 20.39132270962, 27.316042631864548, 39.756339490413666, 39.88097280263901, 58.676607236266136, 12.328987531363964, 0.3467011742759496, 0.06195337853569072, 0.8539653453044593, 3.4098866768181324, 5.645746076479554, 40.59603363275528, 56.52649641036987, 54.417533576488495, 53.80849465727806, 50.20752288401127, 44.71301011741161, 40.70968173444271, 43.37262064218521, 46.76588796079159, 50.275212451815605, 50.435662642121315, 52.12798163294792, 53.44269588589668, 52.64027774333954, 48.94471004605293, 50.33234618604183, 47.491569221019745, 47.31003016233444, 47.86136917769909, 49.452074021101, 52.07988761365414, 44.614432007074356, 46.537862196564674, 48.008079305291176, 46.372806653380394, 48.52995850145817, 39.994343519210815, 36.63595832884312, 38.11198532581329, 37.93451204895973, 37.02655076980591, 37.044136226177216, 38.653699457645416, 37.85681001842022, 36.98197156190872, 34.91102948784828, 35.195565819740295, 36.110442727804184, 38.31628896296024, 37.077707424759865, 39.15767401456833, 37.565806433558464, 35.11398799717426, 36.339787021279335, 36.46071933209896, 46.722520887851715, 48.24765644967556, 52.20257543027401, 55.884859040379524, 53.04650254547596, 50.01842603087425, 52.843908816576004, 53.656339421868324, 51.69901505112648, 47.99971215426922, 47.636782228946686, 43.73137839138508, 46.80858626961708, 52.92540684342384, 50.831080824136734, 52.664600238204, 41.598340049386024, 47.53474250435829, 53.64163801074028, 46.13518640398979, 42.87860915064812, 48.52050840854645, 52.46972009539604, 52.71189630031586, 59.575714990496635, 55.09399987757206, 52.36574247479439, 52.04562485218048, 53.59134390950203, 52.23031394183636, 52.08870314061642, 49.955459609627724, 50.549078956246376, 46.32109522819519, 38.72799687087536, 37.60977387428284, 36.78918890655041, 37.68304914236069, 39.14438992738724, 37.31215484440327, 40.183322578668594, 38.8004931807518, 38.83326642215252, 37.40864306688309, 39.478604793548584, 37.561717852950096, 42.11390398442745, 41.23744681477547, 38.74548353254795, 40.153231993317604, 48.569924756884575, 50.926121324300766, 52.112223878502846, 51.15155562758446, 50.52692614495754, 51.05493061244488, 49.47544276714325, 50.12959286570549, 49.837783724069595, 46.58580422401428, 48.500061705708504, 45.533914268016815, 42.95350693166256, 40.59091530740261, 39.14301440119743, 40.71234919130802, 46.94500274956226, 47.55263194441795, 48.659501150250435, 48.113451451063156, 51.15284375846386, 51.89790017902851, 55.904386192560196, 55.729014202952385, 58.26163150370121, 57.63429656624794, 61.895612105727196, 63.31864334642887, 65.32128408551216, 11.655520219355822, 0.32553913013543934, 0.18286943261045963, 0.006653760710833012, 12.940084040164948, 61.83017201721668, 48.91211159527302, 45.82951180636883, 31.732099168002605, 28.92907127737999, 35.135692432522774, 52.96060435473919, 53.273380771279335, 26.928784511983395, 0.8266061008907855, 0.16732805874198675, 0.04037010621686932, 0.1301827808492817, 0.02359817171964096, 0.016890062142920215, 0.029306118558452, 0.0639394139579963, 0.015764912459417246, 0.028447398035496008, 0.08305110444780439, 0.10234862871584482, 0.040378113990300335, 0.04479305032873526, 0.01664547438849695, 0.03261073703470174, 0.06896304126712494, 0.026429852878209203, 0.029422927036648616, 0.050422804488334805, 0.10649536401615478, 0.060811688235844485, 15.395954009145498, 63.25939692556858, 49.88484039902687, 44.94497627019882, 33.32220174372196, 25.231457389891148, 26.09084777534008, 42.06149339675903, 45.53195357322693, 62.89177805185318, 14.10955298691988, 0.40082962601445615, 0.11954778979998082, 2.4656249955296516, 3.783528464846313, 6.2863921746611595, 42.282075360417366, 57.205189391970634, 57.03023537993431, 54.897736608982086, 53.246018439531326, 45.95669098198414, 43.64022508263588, 44.19884070754051, 49.87559549510479, 50.55156782269478, 51.8241461366415, 53.497629538178444, 54.163365215063095, 52.67751194536686, 52.30519272387028, 50.91002158820629, 49.63553577661514, 48.0040667206049, 49.285825341939926, 52.55556508898735, 52.4532175809145, 47.842484191060066, 48.45828674733639, 51.25065051019192, 48.17674085497856, 51.76442474126816, 42.394579723477364, 38.943616300821304, 40.371959656476974, 39.54000949859619, 38.35962563753128, 39.31508056819439, 39.44099061191082, 38.92785094678402, 39.616229608654976, 37.560216933488846, 36.71789713203907, 37.7844163030386, 40.89174896478653, 38.82188603281975, 40.38646347820759, 39.56300586462021, 37.990536242723465, 38.25342133641243, 39.842074289917946, 48.399595096707344, 53.199565932154655, 53.59385557472706, 55.6363295763731, 56.01251319050789, 52.668194845318794, 54.04445819556713, 53.622373044490814, 53.88860195875168, 51.77499957382679, 50.10401263833046, 44.98173549771309, 49.1318766027689, 54.55070503056049, 53.32201436161995, 54.4115374982357, 42.95736752450466, 48.6165938526392, 53.70515540242195, 47.79229648411274, 44.39921535551548, 50.456371530890465, 54.91686478257179, 55.327394753694534, 59.6172733604908, 55.097176507115364, 53.5126843303442, 53.29955756664276, 54.06451351940632, 53.216775208711624, 54.89628508687019, 49.99185025691986, 52.89742134511471, 47.887511774897575, 39.241603910923004, 39.994138330221176, 38.94184559583664, 39.476400911808014, 40.53198426961899, 39.903604388237, 41.243670880794525, 39.540663063526154, 40.47827795147896, 39.12942253053188, 41.28104567527771, 40.194273591041565, 42.6642132550478, 42.487313747406006, 40.16632989048958, 44.55841541290283, 51.093920320272446, 53.33708055317402, 53.926782310009, 52.268695682287216, 52.75704927742481, 52.23864309489727, 51.192285642027855, 52.84925892949104, 50.64381927251816, 49.80278380215168, 48.733213394880295, 46.17174804210663, 44.67144034802914, 43.3729512244463, 41.37811906635761, 43.055584654212, 49.16629135608673, 51.15714892745018, 50.096755027770996, 50.267890244722366, 52.269972413778305, 55.45730218291283, 58.468074426054955, 57.388407960534096, 59.983695298433304, 59.9673979729414, 62.86957964301109, 66.94711044430733, 71.07371181249619, 16.235747896134853, 0.19771884282818064, 0.3320167731726542, 0.09910143577144481, 15.000414233654737, 65.8979943394661, 53.18358398973942, 52.51554563641548, 40.13778582215309, 34.56506945192814, 41.67051337659359, 61.03855289518833, 62.13950201869011, 34.73575249314308, 1.4016799489036202, 0.08828197649563663, 0.08550623286282644, 0.04788483383890707, 0.030436105189437512, 0.08622403809567913, 0.055235724939848296, 0.02946961369161727, 0.04019666630483698, 0.04053658849443309, 0.04583100322633982, 0.15874880191404372, 0.16867470054421574, 0.12453699629986659, 0.2200694364728406, 0.062284877349156886, 0.22249291971093044, 0.09091895335586742, 0.10075124489958398, 0.19024982408154756, 0.1599498640280217, 0.14478098892141134, 21.539963074028492, 72.61208966374397, 57.66490392386913, 50.31384117901325, 42.9072368144989, 30.625798031687737, 34.84145142138004, 54.57485653460026, 52.534962594509125, 68.99786040186882, 14.712660424411297, 0.629276039544493, 0.2948169474257156, 6.598562048748136, 9.378826785832644, 8.16688371822238, 43.81650522351265, 58.827314749360085, 59.91018444299698, 59.600436463952065, 55.16324736177921, 49.6973280608654, 44.71047185361385, 47.24907763302326, 51.262232288718224, 53.40556047856808, 54.55101661384106, 57.04723946750164, 57.24605619907379, 56.77832789719105, 53.89255754649639, 55.11245168745518, 51.80550813674927, 50.90764291584492, 51.14144057035446, 54.73514713346958, 55.09376049041748, 46.80144265294075, 49.27569508552551, 53.261616602540016, 50.40785193443298, 54.446552619338036, 45.94035945832729, 41.491725370287895, 41.6389636695385, 41.778898760676384, 40.85904411971569, 40.30096806585789, 41.83992348611355, 40.879490822553635, 40.33125624060631, 38.85756991803646, 37.71519921720028, 39.68851312994957, 42.4730721116066, 40.79704284667969, 41.9980937987566, 42.378297597169876, 38.93562912940979, 40.84453269839287, 41.67820416390896, 51.28260679543018, 55.12120641767979, 57.18913905322552, 56.925699189305305, 57.20016226172447, 54.52576696872711, 55.55850975215435, 56.544556841254234, 53.65016095340252, 52.54378192126751, 52.096135541796684, 46.938239112496376, 50.40796972811222, 56.60771705210209, 55.356379598379135, 57.34036713838577, 45.420285165309906, 51.59474104642868, 57.725009098649025, 50.07160037755966, 47.43440128862858, 52.21824958920479, 56.82709068059921, 56.72073058784008, 59.38315272331238, 56.57209016382694, 56.31545193493366, 55.449755787849426, 57.20340348780155, 54.68351550400257, 55.45332379639149, 53.44014622271061, 54.0870501101017, 51.09260179102421, 42.15849079191685, 40.495126247406006, 40.48177756369114, 41.6569709032774, 44.28871348500252, 41.073512211441994, 43.254595175385475, 41.20791479945183, 42.29315936565399, 40.128905698657036, 41.91258318722248, 42.165186032652855, 45.39033517241478, 45.38056589663029, 41.325890868902206, 45.365412309765816, 52.92302817106247, 55.15442043542862, 55.8745501935482, 54.98111553490162, 54.56655777990818, 55.25389909744263, 52.636063769459724, 55.15722468495369, 52.32916943728924, 52.71239027380943, 52.39334799349308, 51.17553234100342, 46.70045927166939, 45.209316685795784, 42.744449749588966, 44.22359257936478, 53.08820150792599, 53.27663719654083, 53.85971590876579, 53.34479793906212, 56.551073491573334, 56.98647692799568, 60.37358857691288, 60.560891926288605, 62.71321803331375, 61.761984676122665, 68.15228417515755, 65.30452698469162, 70.1740112900734, 23.014082573354244, 0.6385116220917553, 1.121167482342571, 0.1914867022424005, 15.558647979050875, 72.36467733979225, 61.21840864419937, 57.82794177532196, 42.70993620157242, 39.11049574613571, 49.76882882416248, 68.8953723013401, 72.44943559169769, 44.138997718691826, 2.303952220827341, 0.20200973289320245, 0.20290406537242234, 0.13986573001602665, 0.1361914013978094, 0.12356691280729137, 0.13583708525402471, 0.15175386710325256, 0.1499378465814516, 0.11982455151155591, 0.12862018891610205], [0.010438461995363468, 0.10166439082240686, 0.06690853901091032, 0.09318956159404479, 0.05806032415421214, 0.015147001231525792, 0.08106459034024738, 0.026188473057118244, 0.01651039423450129, 0.11505450122058392, 0.03588846935599577, 12.379272133111954, 53.47205311059952, 43.14640738070011, 43.021975457668304, 21.390078216791153, 17.476658709347248, 32.99799934029579, 34.279693365097046, 41.949870586395264, 58.87887418270111, 9.966789186000824, 0.3287805343279615, 0.04380108090117574, 0.9480612992774695, 1.9505163235589862, 10.045084934681654, 45.553490817546844, 55.43133817613125, 53.59041675925255, 47.65817888081074, 48.750905245542526, 49.70509484410286, 48.01573969423771, 49.32462126016617, 52.71415337920189, 52.92634159326553, 54.512213096022606, 50.01892380416393, 49.33424234390259, 48.047825172543526, 53.0347041785717, 49.83081489801407, 49.68457214534283, 50.73172375559807, 50.86474321782589, 48.5223513096571, 49.38883401453495, 43.11577722430229, 46.15417778491974, 46.94853276014328, 48.01586128771305, 44.87946778535843, 36.57186336815357, 37.29628309607506, 35.48759914934635, 36.18438296020031, 40.37925526499748, 39.26025331020355, 38.28707613050938, 37.4074537307024, 38.18709209561348, 34.971427246928215, 36.279769241809845, 35.57409010827541, 37.05982558429241, 37.67636530101299, 36.96402132511139, 37.69718438386917, 35.77348820865154, 37.15912185609341, 37.1749784052372, 44.747732654213905, 52.338300347328186, 47.12806932628155, 41.97121784090996, 48.386801183223724, 51.944158896803856, 49.648975655436516, 51.4596126973629, 50.53778976202011, 51.96675628423691, 46.62277244031429, 46.019342020154, 44.9113442748785, 48.03261078894138, 48.392265290021896, 52.620028629899025, 43.35656650364399, 49.74242024123669, 51.3999292999506, 46.716748997569084, 44.666800796985626, 51.87029846012592, 50.88177390396595, 52.86464050412178, 44.63289141654968, 42.56816580891609, 45.93647226691246, 50.26928097009659, 51.81011348962784, 50.986044108867645, 49.50465939939022, 52.03168720006943, 46.470400616526604, 40.41771300137043, 38.254181295633316, 37.493131533265114, 36.12785339355469, 36.97782218456268, 39.21614147722721, 40.62742754817009, 38.44400390982628, 37.05037549138069, 37.78354234993458, 39.531927332282066, 39.046655371785164, 39.87545549869537, 40.10307088494301, 40.69930449128151, 41.74527816474438, 40.241429060697556, 39.733263328671455, 45.712561681866646, 52.82787747681141, 52.05405279994011, 51.45688824355602, 52.09384046494961, 52.45668299496174, 49.47605833411217, 50.621419474482536, 49.89268697798252, 49.103799909353256, 47.11266115307808, 44.942776188254356, 39.27020877599716, 39.749765843153, 39.58387814462185, 46.51750288903713, 49.60950717329979, 50.38594990968704, 47.41079695522785, 50.2229842543602, 49.21808257699013, 54.220749735832214, 53.53172890841961, 57.16671645641327, 57.33654834330082, 62.33196169137955, 62.42093771696091, 74.01017144322395, 17.858809903264046, 0.5427974299527705, 0.2031699471990578, 0.012660291649808642, 8.793439697474241, 58.33859257400036, 53.85934732854366, 47.48730584979057, 33.475614711642265, 33.69496174156666, 44.592195600271225, 53.64807866513729, 57.047467455267906, 25.89054722338915, 1.3277798518538475, 0.10878699729801156, 0.045368930950644426, 0.03069639678869862, 0.03003143247042317, 0.05013309229980223, 0.03525261578033678, 0.10282894669217058, 0.03716112274560146, 0.06352387063088827, 0.06283446738962084, 0.03193952012225054, 0.05001486817491241, 0.034656463394640014, 0.03791373841522727, 0.02360695132665569, 0.026844670755963307, 0.07929740313556977, 0.0525191638735123, 0.08954949793405831, 0.08089451977866702, 0.142510506848339, 16.422241888940334, 59.44750986993313, 48.938649371266365, 48.364310190081596, 28.482122160494328, 21.83009460568428, 36.303856149315834, 42.31833681464195, 45.33559150993824, 64.45087999105453, 11.208495106548071, 0.3295488946605474, 0.047438903275178745, 1.8556111911311746, 2.0878110313788056, 9.928696230053902, 45.84437280893326, 58.828086107969284, 56.22066982090473, 50.556967332959175, 50.3672207146883, 50.92066861689091, 50.73023043572903, 51.99490897357464, 54.95715782046318, 54.545012935996056, 55.12176498770714, 52.18187794089317, 50.917735174298286, 50.36554880440235, 54.301795586943626, 52.26906806230545, 51.33972533047199, 51.71303629875183, 52.83674240112305, 50.491306856274605, 50.018581822514534, 44.99520197510719, 46.957686468958855, 49.988723024725914, 50.57869836688042, 48.9539435505867, 38.893512189388275, 39.244632348418236, 36.836538165807724, 37.56855368614197, 40.9411995112896, 40.29603973031044, 38.24688568711281, 39.37460817396641, 40.12770116329193, 36.51010528206825, 37.73121915757656, 37.779696956276894, 38.973064720630646, 38.715962916612625, 39.280415028333664, 38.60260359942913, 38.0655138194561, 38.05862858891487, 38.41506086289883, 47.03838273882866, 54.23150695860386, 50.10262951254845, 45.049656853079796, 48.71104538440704, 52.337544187903404, 50.43872527778149, 52.975358963012695, 51.5703159570694, 55.29190085828304, 49.17374275624752, 47.10820019245148, 45.83553448319435, 50.0415325909853, 50.17316892743111, 53.47671166062355, 46.497139781713486, 51.89778998494148, 53.9367263764143, 49.25893798470497, 46.242944821715355, 53.53177450597286, 50.70650450885296, 55.04755116999149, 46.821323186159134, 43.920843824744225, 48.13598804175854, 51.171078979969025, 53.51753666996956, 52.302608862519264, 52.73572862148285, 52.460608184337616, 47.846435979008675, 42.757844030857086, 41.044314578175545, 39.30557727813721, 37.888929694890976, 40.3378526866436, 40.93971759080887, 40.72505570948124, 40.72262763977051, 39.53825019299984, 39.75190132856369, 41.14499777555466, 41.157043129205704, 40.55632196366787, 40.23756466805935, 43.36364932358265, 42.84313425421715, 41.69464208185673, 41.48853734135628, 48.435313180089, 54.730587378144264, 54.21487145125866, 52.88610175251961, 53.82692366838455, 53.66072438657284, 51.22291959822178, 51.97852045297623, 50.15303760766983, 50.3264033049345, 47.81813129782677, 45.50681412220001, 41.7095410823822, 42.62027621269226, 41.66375733911991, 49.38126482069492, 51.39400161802769, 53.35201755166054, 50.55153362452984, 53.28483335673809, 51.37749910354614, 56.741067096590996, 55.95628000795841, 59.07131485641003, 59.385147616267204, 62.92349494993687, 62.058874145150185, 74.5922926068306, 23.6456086859107, 0.6633321277331561, 0.22415685933083296, 0.0676642828329932, 9.782371781766415, 63.308022916316986, 59.57793027162552, 50.73350585997105, 40.02052031457424, 36.634206622838974, 51.45402319729328, 62.40854278206825, 64.8597152531147, 34.655534997582436, 1.9765999051742256, 0.06594959515496157, 0.03843738297291566, 0.03840798650344368, 0.029070451419102028, 0.06337309590890072, 0.06116612312325742, 0.05305217804561835, 0.022133554411993828, 0.02833676422596909, 0.05423181806690991, 0.14471884147496894, 0.2043925761245191, 0.1340047671692446, 0.15846970985876396, 0.1854023232590407, 0.08718598022824153, 0.24161125242244452, 0.09331407913123257, 0.22196995792910457, 0.18371877609752119, 0.2851933997590095, 20.552000887691975, 69.40700724720955, 57.46849246323109, 56.95350989699364, 34.67259228229523, 26.750154197216034, 43.03582191467285, 46.88879616558552, 51.094991862773895, 69.8830609023571, 12.624054048210382, 0.38366122695151716, 0.2735707734245807, 3.98745140992105, 5.18996243365109, 12.125155068933964, 49.04317036271095, 60.407729744911194, 57.91822873055935, 51.22256621718407, 53.96341614425182, 53.573298677802086, 51.92688122391701, 54.54987667500973, 58.795715644955635, 55.49985229969025, 57.15247482061386, 52.74029977619648, 52.10528925061226, 51.00026674568653, 57.605471312999725, 55.32656639814377, 53.5591596364975, 55.281158834695816, 55.55335722863674, 51.911264061927795, 52.053448632359505, 44.79702740907669, 48.52925553917885, 51.56506083905697, 51.28360614180565, 51.3791748136282, 40.81287659704685, 40.84299758076668, 40.06630785763264, 39.16675552725792, 44.30817984044552, 43.67944277822971, 41.733863577246666, 42.346337512135506, 41.63555145263672, 38.211046010255814, 40.29995732009411, 39.98420566320419, 40.36502122879028, 40.60774840414524, 40.93895383179188, 41.143048480153084, 40.05949482321739, 41.75708033144474, 40.81062711775303, 48.937087655067444, 57.81700976192951, 52.95413330197334, 48.04396837949753, 48.76307599246502, 52.84072458744049, 52.595048770308495, 53.94983567297459, 53.76035124063492, 57.39873580634594, 52.06719249486923, 50.91974526643753, 48.62176917493343, 52.2164598852396, 50.96866764128208, 54.078736156225204, 48.91247257590294, 54.103545024991035, 55.05133576691151, 52.17539928853512, 48.41140106320381, 56.012406796216965, 53.548953384160995, 57.960877642035484, 51.29764258861542, 44.50541205704212, 47.52211198210716, 54.22578066587448, 55.03370091319084, 55.13917565345764, 53.665257543325424, 55.451108515262604, 50.01963436603546, 44.603610187768936, 42.406663075089455, 40.35416901111603, 40.521090254187584, 41.06810890138149, 43.14349673688412, 43.30244220793247, 42.605814188718796, 42.671706452965736, 41.641414538025856, 43.43584164977074, 43.797498643398285, 43.25017221271992, 42.5295864790678, 46.35008007287979, 45.62731705605984, 43.82597051560879, 43.72811436653137, 50.21868668496609, 57.80206136405468, 55.9808798879385, 55.441411435604095, 54.634923711419106, 57.32630789279938, 54.01988111436367, 55.302304700016975, 54.335940554738045, 53.50616008043289, 52.27603688836098, 50.048398822546005, 43.04766587913036, 45.15126720070839, 43.79223592579365, 50.64044505357742, 55.17685063183308, 56.81510992348194, 53.202636167407036, 55.153276696801186, 53.383829444646835, 61.10010199248791, 59.00701090693474, 62.253864482045174, 63.76341328024864, 67.17620775103569, 64.85231325030327, 77.58132621645927, 28.700975216925144, 0.9397319087292999, 0.7106560945976526, 0.12147789326263592, 10.502540487796068, 68.2261598110199, 66.50508776307106, 61.47991441190243, 46.72659806907177, 49.157213643193245, 60.74137084186077, 69.09533277153969, 74.00144711136818, 44.3949443846941, 3.103213207796216, 0.1819584463373758, 0.15009384602308273, 0.09891056281048805, 0.1514960004715249, 0.1318280480336398, 0.1488340354990214, 0.3169210144551471, 0.16145490983035415, 0.1475123001728207, 0.112100182013819], [0.015428505266754655, 0.04583996837027371, 0.04633976401237305, 0.04591100674588233, 0.022655479042441584, 0.03129709482891485, 0.04851595622312743, 0.04226335833664052, 0.05877473406144418, 0.0512013619299978, 0.03899193798133638, 10.868446603417397, 52.8182639926672, 49.29145283997059, 42.6483491063118, 21.527077965438366, 13.627504203468561, 20.636489354074, 35.96449635922909, 42.2562937438488, 58.1250212341547, 9.530997220426798, 0.14011197461513802, 0.09788112234673463, 0.6629763124510646, 4.471017261967063, 11.89937498420477, 45.60364432632923, 55.01682601869106, 52.951416447758675, 51.29864193499088, 52.62414000928402, 51.47965282201767, 53.057989329099655, 52.11684823036194, 54.99444521963596, 51.55617691576481, 49.8341017216444, 46.6819466650486, 49.04477007687092, 46.00784383714199, 46.15325063467026, 47.204137444496155, 50.478471145033836, 50.09953647851944, 48.46156597137451, 48.04424576461315, 45.60049049556255, 46.2556741386652, 43.693927600979805, 47.154401913285255, 48.97955797612667, 40.626481398940086, 37.457854226231575, 37.554076462984085, 37.96734608709812, 35.694049671292305, 36.43071994185448, 37.580633237957954, 36.28147915005684, 36.03205293416977, 36.324781626462936, 35.48204384744167, 35.62045142054558, 35.83488531410694, 36.13079443573952, 37.55867801606655, 36.2752702832222, 38.27444560825825, 38.04683022201061, 36.77482567727566, 36.60745985805988, 38.61567109823227, 49.12322446703911, 53.750220984220505, 48.251691833138466, 42.18907915055752, 46.518114656209946, 48.27818401157856, 49.827125295996666, 52.17667602002621, 48.43430243432522, 46.46162688732147, 44.308312833309174, 44.53563563525677, 45.12846082448959, 50.137872621417046, 53.31477954983711, 45.794667676091194, 49.3628966063261, 49.88554336130619, 42.99254223704338, 45.1385834813118, 51.04228489100933, 51.878977194428444, 51.59979857504368, 51.67206309735775, 47.24811628460884, 46.838885843753815, 48.44798929989338, 49.70776230096817, 50.12103572487831, 48.2299380004406, 43.95334728062153, 40.895176380872726, 37.67837919294834, 38.730968311429024, 36.865747198462486, 36.03768803179264, 38.136281222105026, 38.02484080195427, 39.01509806513786, 39.00541238486767, 36.50339104235172, 36.57153278589249, 37.35033519566059, 39.509956911206245, 38.84553976356983, 38.86559508740902, 40.1906181871891, 39.7023443877697, 38.70964765548706, 38.37394326925278, 38.0678278952837, 41.35168008506298, 46.94159813225269, 51.765321493148804, 51.145920529961586, 52.16137424111366, 50.51286309957504, 50.24309657514095, 49.785844311118126, 50.06933569908142, 48.19051891565323, 46.59837394952774, 39.689375683665276, 40.862391740083694, 38.93254369497299, 45.64481891691685, 47.816242799162865, 50.36993756890297, 48.04083734750748, 48.20637546479702, 47.05826707184315, 49.14462111890316, 45.964868143200874, 51.40374809503555, 52.22617596387863, 59.76590238511562, 59.09798942506313, 69.2669315636158, 18.510429337620735, 1.0130549711175263, 0.3528852533781901, 0.11911635709111579, 8.310426715761423, 56.48298114538193, 56.79763086140156, 44.202420115470886, 24.72590781748295, 21.74320086836815, 30.685496628284454, 47.409607619047165, 56.64617098867893, 23.244447112083435, 1.053214066196233, 0.07667624144232832, 0.0522654866654193, 0.026996584674634505, 0.011800179599958938, 0.021269701937853824, 0.05053582615801133, 0.04030769159726333, 0.03682680748170242, 0.025431569629290607, 0.010828922586370027, 0.009477786152274348, 0.041815060321823694, 0.06152658424980473, 0.016653422790113837, 0.026200948559562676, 0.07045357808237895, 0.0461496406205697, 0.02603067761810962, 0.04279205320926849, 0.0883475600858219, 0.05190760821278673, 14.547719825059175, 60.52073948085308, 57.434602081775665, 47.900176495313644, 29.587228260934353, 19.139922559261322, 20.76771531254053, 42.218728959560394, 47.2309336066246, 62.19364911317825, 10.066384691745043, 0.233930662216153, 0.10588702556560747, 1.5059520537033677, 3.3861581375822425, 13.963720612227917, 44.73084256052971, 56.492343842983246, 53.93893025815487, 53.05507868528366, 54.93703030049801, 53.285695910453796, 54.98941048979759, 53.419828712940216, 55.75701490044594, 51.79674580693245, 50.560584738850594, 46.80206201970577, 47.96991415321827, 47.62360453605652, 45.79941362142563, 48.72939459979534, 51.87127120792866, 53.100984022021294, 51.64679445326328, 48.27829420566559, 45.59436522424221, 45.330948159098625, 44.942054226994514, 51.59710071980953, 49.4342415779829, 42.407658621668816, 38.99568110704422, 38.74403201043606, 39.053320214152336, 37.64079920947552, 39.3984404951334, 38.98311138153076, 37.64225073158741, 37.912089452147484, 37.3845561593771, 37.051519230008125, 38.3895680308342, 38.62660691142082, 38.184686824679375, 38.2525359839201, 37.20359466969967, 40.22333063185215, 38.67465153336525, 38.94487023353577, 37.506176233291626, 41.63121208548546, 52.08411678671837, 53.165565356612206, 48.58651466667652, 44.06109809875488, 47.00381599366665, 47.99195297062397, 52.60751970112324, 53.33479307591915, 50.800389871001244, 48.352895602583885, 46.91806599497795, 46.543402299284935, 48.14358003437519, 52.31042504310608, 54.274551048874855, 47.627795711159706, 51.735189110040665, 51.497245877981186, 46.52067571878433, 47.849532812833786, 53.207910284399986, 52.94125199317932, 53.72936770319939, 53.215566873550415, 46.49460531771183, 50.09095273911953, 50.31080134212971, 51.644670367240906, 51.041312143206596, 50.00532813370228, 47.22830414772034, 42.388534247875214, 39.460700154304504, 39.15954731404781, 37.68385849893093, 37.69896648824215, 40.02118907868862, 40.272701382637024, 39.85954575240612, 40.058313086628914, 39.387649074196815, 38.43119479715824, 40.178352445364, 41.660261526703835, 40.159809440374374, 40.00825837254524, 40.99155440926552, 42.16737471520901, 40.93916282057762, 38.68111498653889, 40.42495161294937, 43.36822807788849, 50.27956701815128, 54.48057219386101, 52.28085123002529, 52.01485030353069, 53.884680569171906, 53.30209203064442, 51.75796128809452, 52.602287381887436, 52.127727046608925, 48.277416452765465, 42.9732620716095, 42.816292494535446, 41.18560239672661, 47.22650684416294, 51.29759319126606, 52.72072322666645, 52.07070730626583, 49.93378557264805, 49.19179178774357, 50.08549623191357, 49.715244099497795, 54.7993940860033, 56.53628848493099, 62.18503497540951, 60.43802931904793, 69.87898752093315, 23.360057808458805, 1.3141746819019318, 0.3941809921525419, 0.07123611343558878, 8.489012382924557, 60.836874917149544, 60.75686641037464, 51.936380714178085, 33.24443131685257, 28.660220503807068, 38.48159149289131, 53.2634063065052, 65.47220438718796, 31.73235185444355, 1.7543357005342841, 0.13022159517277032, 0.06128107437689323, 0.050396836741128936, 0.08200400829082355, 0.08464949016342871, 0.04076839832123369, 0.05870348417374771, 0.09129976417170838, 0.006285858626142726, 0.05440608176286332, 0.09064369820407592, 0.11873383191414177, 0.14055879204533994, 0.1068676401337143, 0.23229081270983443, 0.13676425034645945, 0.11474989412818104, 0.14429773204028606, 0.12148061694460921, 0.18501619866583496, 0.14810238179052249, 16.94156002253294, 70.78248023986816, 63.44398722052574, 57.00529731810093, 33.02771754562855, 24.922568164765835, 30.00498354434967, 49.24337022006512, 51.80216431617737, 68.27081501483917, 11.26029772683978, 0.2918420039350167, 0.4588369867997244, 3.9763593301177025, 10.022398252040148, 14.757963493466377, 49.27596867084503, 57.072154730558395, 56.96137547492981, 56.048843041062355, 58.57666879892349, 56.865852400660515, 57.042371928691864, 55.99686183035374, 58.2432746887207, 53.82939353585243, 50.93252778053284, 48.3754625916481, 49.485789611935616, 46.774623692035675, 46.7504645884037, 49.03318829834461, 54.32316944003105, 53.6115550249815, 52.1298473328352, 49.09347206354141, 47.33720250427723, 45.935936495661736, 46.501479148864746, 54.01729725301266, 52.1600329130888, 43.2568484544754, 41.69798210263252, 41.34782329201698, 42.111840695142746, 38.77754621207714, 41.03213243186474, 40.374824702739716, 39.994556307792664, 39.989969953894615, 38.96650247275829, 38.680024445056915, 40.49201801419258, 40.168393179774284, 39.71660502254963, 39.44227494299412, 39.87358219921589, 42.44102083146572, 40.70196054875851, 42.09107480943203, 40.49205981194973, 43.92115160822868, 52.716953828930855, 56.71009115874767, 50.88780038058758, 46.16116940975189, 48.5444775223732, 50.258455350995064, 53.88507194817066, 55.038891434669495, 52.667415887117386, 51.59422427415848, 48.82765352725983, 49.39876288175583, 48.41838888823986, 53.0020335316658, 56.73845283687115, 50.05278378725052, 54.305971562862396, 51.826027035713196, 47.43796169757843, 50.25093175470829, 55.457875952124596, 55.475222021341324, 54.918795078992844, 55.35462409257889, 50.12723699212074, 51.99232131242752, 49.95311513543129, 53.11428710818291, 53.84310320019722, 52.61158928275108, 49.02396239340305, 44.51433017849922, 41.48114673793316, 41.72181062400341, 38.82489547133446, 39.31286908686161, 43.24880428612232, 41.527268663048744, 43.091135546565056, 42.615161687135696, 39.71577286720276, 39.386053159832954, 40.59329777956009, 44.613702446222305, 41.58946372568607, 41.98108971118927, 43.53951148688793, 43.77886824309826, 43.905082270503044, 40.2457570284605, 42.862726002931595, 45.18984653055668, 51.93375505506992, 56.5448722243309, 54.8018791526556, 56.32885001599789, 55.36210209131241, 54.932618737220764, 54.086309149861336, 54.90293473005295, 54.70431178808212, 50.98449759185314, 44.579333290457726, 44.41369257867336, 42.92346954345703, 49.446119740605354, 52.15704247355461, 54.1031688451767, 55.32964803278446, 53.05152967572212, 52.46078297495842, 53.160264641046524, 51.015895307064056, 56.92010208964348, 58.07025097310543, 64.64624270796776, 66.09084159135818, 72.32984840869904, 28.524626679718494, 1.2017293344251812, 0.8393589884508401, 0.15371879213489592, 9.688793253153563, 66.22266411781311, 67.44947388768196, 60.979173481464386, 36.63953013718128, 33.21391135454178, 44.92976948618889, 62.173969969153404, 73.61821487545967, 43.99837106466293, 2.8594558127224445, 0.25258770561777055, 0.18061407550703734, 0.1504299498628825, 0.15748712117783725, 0.15126054669963196, 0.13155386899597943, 0.1351620425703004, 0.3103690972784534, 0.2963306911988184, 0.15182066039415076], [0.09569605404976755, 0.06256359090912156, 0.02976127216243185, 0.0653260649414733, 0.05199407954933122, 0.03531638110871427, 0.012701209961960558, 0.043093654603580944, 0.03605478836107068, 0.04367746507341508, 0.052177356628817506, 10.272244345396757, 49.733243733644485, 49.0965460985899, 38.85267578065395, 23.26259683817625, 16.349430195987225, 32.706429585814476, 36.69443719089031, 43.54462221264839, 55.16302317380905, 8.128263540565968, 0.18719299201620743, 0.1548611355246976, 0.8280284120701253, 1.8138036970049143, 15.930403880774975, 48.100509345531464, 53.32203336060047, 54.21728432178497, 52.19977118074894, 52.22430646419525, 51.06355234980583, 53.45828264951706, 52.29677237570286, 49.864408895373344, 50.0911845266819, 52.87190571427345, 52.874892354011536, 52.936452850699425, 50.36037728190422, 50.09661823511124, 47.3053640127182, 47.52461604773998, 48.54145668447018, 47.02227160334587, 45.43522596359253, 48.11130076646805, 47.84790650010109, 47.00957648456097, 49.49432775378227, 44.782143607735634, 36.73336610198021, 36.0063511133194, 36.05525068938732, 36.735463589429855, 36.51706650853157, 37.59385272860527, 38.15053805708885, 36.733404099941254, 36.642448380589485, 35.24996370077133, 34.43866163492203, 36.72883674502373, 36.538447961211205, 36.57301850616932, 37.47752957046032, 34.79775756597519, 36.4138488471508, 36.808233484625816, 35.141285732388496, 37.61428043246269, 35.56804843246937, 44.64046820998192, 48.51256683468819, 49.417666867375374, 49.64247800409794, 46.61508545279503, 48.22772651910782, 53.582258597016335, 52.236469611525536, 49.9466060847044, 46.691822335124016, 42.69687630236149, 43.131120800971985, 45.168491676449776, 49.57030847668648, 54.258078932762146, 47.858116552233696, 50.50868332386017, 51.142189130187035, 45.81234432756901, 42.96507731080055, 46.148721277713776, 49.12023022770882, 51.4918577671051, 54.925896897912025, 53.98539416491985, 52.2172312438488, 49.97975170612335, 49.86993379890919, 49.48687255382538, 50.24363614618778, 47.82979667186737, 43.332817777991295, 40.17995975911617, 38.911112844944, 37.14827723801136, 36.98236294090748, 38.73375356197357, 38.97836543619633, 37.81866766512394, 37.200513035058975, 38.52940432727337, 37.830215245485306, 36.977309212088585, 38.50178740918636, 38.4369894862175, 38.90227071940899, 38.89810234308243, 38.33257108926773, 38.83455075323582, 39.20887626707554, 38.73541787266731, 38.55087697505951, 39.986968114972115, 41.96290388703346, 45.665311217308044, 48.61742980778217, 49.017061963677406, 49.47037383913994, 48.38167145848274, 49.83252480626106, 45.98103627562523, 44.151730835437775, 40.214374512434006, 42.396475821733475, 41.48394338786602, 43.27932044863701, 49.65143792331219, 49.22899939119816, 48.95331658422947, 48.665485829114914, 46.34278826415539, 46.09753042459488, 48.03413450717926, 54.35049757361412, 58.84442903101444, 60.539882853627205, 59.87975187599659, 68.6001205444336, 17.98572689294815, 0.3755587851628661, 0.16785505780717358, 0.1855689354124479, 6.317732417955995, 55.51594063639641, 57.495493814349174, 45.529840886592865, 27.03058484941721, 23.40493530035019, 34.61355485022068, 47.54638507962227, 53.651597276329994, 30.14715861529112, 1.2491220538504422, 0.13073777372483164, 0.014752064562344458, 0.027346926617610734, 0.025168528372887522, 0.022852689944556914, 0.017525312723591924, 0.05198152983211912, 0.04152568209974561, 0.018988826086570043, 0.05457214472698979, 0.027680620332830586, 0.06921718231751584, 0.03951914855861105, 0.042254949803464115, 0.013849383849446895, 0.08907312076189555, 0.01917280078487238, 0.04053895594552159, 0.04598433464707341, 0.046007211349206045, 0.1129961917467881, 13.588908724486828, 57.835450172424316, 55.81316448748112, 46.826050132513046, 25.510689206421375, 21.508297473192215, 31.142093427479267, 41.51943348348141, 48.94808806478977, 60.511456578969955, 9.543345607817173, 0.22130407334771007, 0.19889229704858735, 0.7919803995173424, 3.4192308504134417, 18.650024347007275, 48.492678701877594, 55.94181798398495, 56.11014135181904, 55.66806547343731, 55.2122837305069, 53.79258871078491, 55.18977373838425, 53.78152370452881, 51.36199213564396, 51.0722728818655, 53.40562127530575, 52.94656790792942, 54.29498255252838, 50.433226972818375, 49.66598354279995, 47.402600795030594, 47.2882117331028, 49.00475822389126, 47.36042305827141, 47.28634603321552, 48.452898636460304, 50.27532644569874, 50.94976365566254, 50.7892906665802, 46.65851712226868, 38.56152780354023, 37.736968249082565, 37.14285492897034, 38.44529964029789, 37.70121976733208, 40.05209282040596, 38.91215778887272, 39.08752977848053, 38.2943831384182, 37.22661763429642, 36.644488871097565, 38.20071056485176, 37.37979881465435, 37.49259956181049, 37.95201390981674, 37.92768381536007, 38.99847395718098, 38.810057267546654, 36.65982864797115, 39.120523408055305, 36.93640820682049, 47.58516579866409, 52.52840034663677, 51.75427168607712, 50.61593256890774, 49.66873459517956, 50.81121549010277, 56.06001064181328, 52.6479609310627, 51.89337082207203, 49.11778315901756, 44.71490241587162, 45.84217272698879, 46.69081538915634, 50.65100088715553, 54.07536193728447, 48.97480063140392, 51.69052250683308, 53.18092793226242, 48.241709768772125, 45.031159445643425, 48.30800861120224, 50.031033754348755, 54.6739362180233, 54.789206832647324, 55.43167635798454, 51.65339469909668, 50.76025642454624, 49.6758858114481, 50.95546714961529, 51.010020822286606, 48.289233818650246, 44.33176897466183, 41.84435024857521, 40.3745511174202, 40.132257118821144, 40.05102887749672, 39.822341948747635, 40.35394862294197, 40.129582062363625, 39.96893048286438, 39.261910021305084, 38.47987398505211, 38.09242017567158, 40.09924069046974, 40.44611647725105, 39.028819128870964, 40.49941621720791, 40.65223641693592, 41.39412380754948, 41.59211218357086, 40.74235238134861, 38.93525294959545, 42.51505985856056, 43.73632192611694, 48.665485829114914, 51.71025864779949, 51.93756625056267, 52.63306573033333, 51.44638940691948, 52.707974910736084, 48.30135136842728, 47.481123581528664, 42.77921408414841, 42.97967612743378, 41.8353371322155, 44.75168064236641, 52.727912440896034, 50.68166524171829, 50.49439989030361, 51.15903362631798, 48.706595823168755, 48.49995531141758, 49.096656292676926, 55.76694376766682, 61.34848326444626, 61.52856320142746, 60.874306708574295, 69.99423533678055, 19.796037152409554, 0.4474218946415931, 0.2602736244443804, 0.16558264615014195, 6.733986781910062, 61.01158954203129, 61.11279331147671, 52.21793420612812, 34.53614920377731, 29.20366734266281, 40.68491846323013, 53.58388490974903, 61.50204822421074, 40.35905174911022, 2.432914450764656, 0.15790864621521905, 0.1252828844008036, 0.07502661785110831, 0.04388130706502125, 0.03383772236702498, 0.07504376888391562, 0.017734817301970907, 0.028249357783352025, 0.05494016091688536, 0.017340965096082073, 0.259468512958847, 0.17911042494233698, 0.140923646686133, 0.14026752876816317, 0.14590936509193853, 0.16430189221864566, 0.1601901269168593, 0.13587782916147262, 0.13434802531264722, 0.1109506472130306, 0.21546426170971245, 17.536613792181015, 67.43224561214447, 61.45569831132889, 54.216170981526375, 32.41357930004597, 25.959000550210476, 46.45120024681091, 47.45605632662773, 54.25869069993496, 65.20029097795486, 10.503843817859888, 0.3452191350515932, 0.5945486342534423, 3.3571521565318108, 2.9653406934812665, 20.079068765044212, 49.54619497060776, 55.857394114136696, 58.226399794220924, 56.35898619890213, 55.26998743414879, 54.764143377542496, 56.64046369493008, 55.153010711073875, 52.761707827448845, 52.90528692305088, 55.49837797880173, 56.414634212851524, 55.74579410254955, 53.178325071930885, 51.718792989850044, 49.51046548783779, 48.538770228624344, 50.252333879470825, 47.9780875146389, 47.355962097644806, 49.01015393435955, 52.00588658452034, 53.7610200047493, 52.34708547592163, 48.427405804395676, 40.69339580833912, 39.990680515766144, 39.019422233104706, 41.78541541099548, 39.168313443660736, 41.83558411896229, 42.90986627340317, 42.187737822532654, 40.6782878190279, 39.37872715294361, 38.501247838139534, 39.73794087767601, 40.23484021425247, 39.63197976350784, 39.85906697809696, 37.917656153440475, 41.819666773080826, 40.67360267043114, 38.86696681380272, 41.11296929419041, 39.65811476111412, 49.260587096214294, 53.103187903761864, 53.620632737874985, 52.6802933961153, 51.99745483696461, 51.94099746644497, 57.386846244335175, 54.39444221556187, 55.11237949132919, 50.20802825689316, 46.139449775218964, 48.41117687523365, 49.761772602796555, 53.47038500010967, 57.55546219646931, 51.215232610702515, 54.539533630013466, 54.23884056508541, 50.631143152713776, 46.9586668163538, 50.4824723303318, 51.96020543575287, 56.23123325407505, 58.36465537548065, 57.27175422012806, 52.8879826515913, 51.39749363064766, 52.90549971163273, 53.26467543840408, 54.386147260665894, 49.755727127194405, 47.17002287507057, 43.896388337016106, 42.29307197034359, 41.864918544888496, 40.90081907808781, 42.131443843245506, 42.10821568965912, 41.28769911825657, 40.168427377939224, 41.014182195067406, 40.78729636967182, 40.778518840670586, 42.38961718976498, 43.16467300057411, 42.24216990172863, 42.745091915130615, 43.14464047551155, 43.26903820037842, 43.89131560921669, 42.296051010489464, 42.06392526626587, 44.28353436291218, 45.04838392138481, 51.2292842566967, 52.32441209256649, 54.25292640924454, 55.28385668992996, 53.85185033082962, 56.918418779969215, 51.843810081481934, 49.56576772034168, 45.09203977882862, 45.71854256093502, 44.23113517463207, 46.47501356899738, 55.55694803595543, 53.094330579042435, 54.0442606061697, 53.85167174041271, 52.112755849957466, 50.84152266383171, 52.0561008900404, 58.512733429670334, 64.51115235686302, 63.79346206784248, 65.25430887937546, 71.68611735105515, 24.088083542883396, 0.29116382938809693, 0.5453120043966919, 0.22847473388537765, 7.865325724706054, 67.07948014140129, 66.51068106293678, 59.35645915567875, 38.22951681911945, 33.78325380384922, 45.95339275896549, 61.914580687880516, 70.71979880332947, 52.8838674724102, 4.655448915436864, 0.28441473841667175, 0.28206207090988755, 0.1168377633439377, 0.14433296921197325, 0.12187820029794239, 0.17592938704183325, 0.10290728037944064, 0.22237453231355175, 0.1786136906594038, 0.14579342678189278], [0.03827700114925392, 0.02031187501415843, 0.03548078166204505, 0.04528000681602862, 0.04366520108305849, 0.05772261727543082, 0.009863630584732164, 0.03855592251056805, 0.021136002178536728, 0.04886095841357019, 0.06668470727163367, 9.799837544560432, 49.84101355075836, 48.40204976499081, 39.94823299348354, 29.240396171808243, 22.975075766444206, 17.903976179659367, 34.979813396930695, 43.79406362771988, 56.09391622245312, 9.087142087519169, 0.2984119107713923, 0.07295645627891645, 0.7750446489080787, 5.0168009754270315, 20.99190328270197, 43.4232909232378, 52.584356144070625, 53.65396834909916, 53.96675616502762, 53.559938594698906, 53.474845960736275, 54.078557565808296, 50.0309007614851, 51.99101038277149, 49.6600216627121, 50.56574486196041, 50.8366247266531, 49.66823302209377, 49.89006891846657, 52.014842703938484, 52.20199026167393, 49.79742608964443, 51.61925733089447, 49.33806873857975, 52.317960038781166, 49.29216340184212, 45.774551555514336, 49.37087997794151, 41.5079391002655, 37.424796000123024, 37.093940153717995, 37.45631530880928, 38.45126532018185, 36.57329209148884, 37.8516498953104, 37.447906360030174, 34.70467396080494, 36.8513497710228, 35.04799693822861, 35.44230937957764, 35.63365951180458, 35.47667853534222, 36.78207188844681, 38.18980894982815, 36.447636634111404, 36.57711088657379, 37.570267394185066, 35.1791051030159, 34.94162164628506, 38.25590640306473, 36.56036518514156, 39.38886500895023, 46.120629385113716, 47.443573996424675, 48.51951666176319, 47.99593135714531, 48.57822351157665, 52.52525791525841, 51.64399020373821, 49.672720581293106, 46.50258868932724, 45.58518871665001, 43.78323420882225, 44.23875756561756, 47.343449369072914, 53.5288030654192, 50.468796864151955, 50.336636155843735, 50.515154376626015, 47.469249218702316, 49.2981518805027, 47.68426068127155, 44.61542375385761, 47.34637901186943, 50.9884075820446, 51.561207845807076, 52.33247146010399, 50.610476061701775, 52.20979884266853, 52.55968026816845, 48.057678043842316, 54.23849858343601, 48.793189376592636, 39.579356387257576, 38.50418508052826, 36.67623996734619, 36.852136328816414, 37.45151996612549, 38.668978437781334, 38.17932531237602, 37.87205100059509, 37.99259193241596, 36.56412698328495, 36.69360503554344, 38.14991869032383, 38.16248461604118, 39.17802192270756, 37.342929393053055, 39.15317505598068, 37.56544925272465, 38.37151139974594, 38.73758755624294, 38.889397010207176, 38.52369703352451, 37.926308289170265, 40.43159745633602, 40.78443892300129, 42.06700690090656, 43.29415485262871, 44.039044082164764, 43.39505083858967, 43.9782739430666, 42.65138514339924, 41.920372769236565, 41.78275175392628, 40.343491584062576, 41.441028490662575, 45.70471130311489, 48.339569717645645, 48.253166154026985, 47.11236856877804, 46.34746961295605, 46.20677836239338, 53.163722455501556, 60.30086047947407, 60.07567696273327, 61.95591486990452, 60.552969351410866, 61.05611175298691, 18.312247171998024, 0.6005210825242102, 0.1561121887061745, 0.018395185870758723, 4.849940054118633, 54.6274571120739, 55.98306857049465, 52.50241354107857, 33.459545373916626, 18.237345591187477, 26.818981803953648, 46.10322251915932, 51.376017183065414, 39.76963497698307, 1.87668141676113, 0.11510533833643422, 0.058868496998911723, 0.06836792788817547, 0.03138925843813922, 0.03231182592571713, 0.011574505479075015, 0.03599495641537942, 0.03507655979774427, 0.026037739153252915, 0.0826168070489075, 0.05957191940979101, 0.01820265420974465, 0.056466658497811295, 0.028154910214652773, 0.05035245259932708, 0.0415185797464801, 0.03252885588153731, 0.04488089092774317, 0.04961739243299235, 0.06709707420668565, 0.13790539145702496, 12.23965622484684, 57.547349631786346, 54.05587278306484, 47.904420867562294, 31.10043056309223, 27.119074501097202, 27.668868899345398, 37.09011375904083, 49.56289507448673, 59.98255915939808, 9.948480818420649, 0.36924759100656956, 0.05920864183281083, 1.0107774683274329, 4.527590051293373, 20.887232199311256, 46.0084518045187, 52.79962599277496, 54.45625729858875, 54.656696543097496, 56.13775447010994, 56.291779205203056, 54.90078404545784, 52.569958716630936, 52.879505306482315, 52.27650426328182, 52.6501040160656, 52.68875554203987, 51.9784976541996, 52.63659194111824, 53.505973890423775, 53.96566182374954, 52.207750752568245, 50.96911981701851, 49.31841999292374, 53.20152662694454, 50.17523601651192, 48.244916796684265, 50.75318120419979, 46.033564656972885, 40.19392021000385, 37.94603303074837, 39.759459123015404, 41.19613543152809, 38.723646104335785, 40.55458925664425, 38.47454287111759, 37.02194161713123, 37.827445194125175, 38.22371453046799, 37.98724561929703, 38.237853571772575, 36.85676068067551, 37.97182984650135, 40.561995059251785, 37.545887902379036, 38.69874984025955, 38.84560436010361, 37.49405488371849, 36.68297700583935, 40.42598895728588, 38.81248913705349, 41.56294874846935, 49.7431156039238, 50.050302520394325, 49.75225791335106, 50.330788269639015, 49.33096691966057, 52.67577163875103, 52.47362248599529, 53.75310502946377, 49.36920426785946, 46.83583080768585, 45.21410442888737, 45.13767533004284, 50.35184293985367, 56.52929686009884, 51.56612478196621, 52.09695249795914, 52.12466061115265, 48.920744732022285, 50.874523892998695, 48.63002233207226, 47.79811777174473, 49.7385710477829, 52.719860672950745, 53.21527808904648, 53.76971393823624, 52.31147758662701, 54.90353889763355, 53.06279607117176, 51.19043134152889, 54.13719981908798, 50.54806441068649, 41.883602142333984, 38.67797635495663, 38.64949308335781, 38.41545604169369, 39.47865039110184, 39.01551604270935, 40.70536896586418, 39.3927787989378, 38.32746036350727, 38.705551475286484, 38.78258474171162, 38.9271479845047, 38.56006868183613, 40.535385087132454, 39.23773191869259, 41.67332902550697, 40.29371805489063, 40.7224490493536, 39.41121160984039, 42.23169766366482, 40.76397702097893, 39.54264275729656, 42.0902768522501, 42.148995101451874, 43.05445611476898, 46.00282430648804, 45.5176055431366, 45.94453163444996, 47.133126854896545, 44.5926857739687, 42.190534472465515, 44.14012625813484, 43.30063350498676, 43.99726152420044, 46.831305250525475, 50.551016852259636, 49.652653858065605, 49.683857783675194, 48.5642858594656, 49.46231447160244, 56.6722147911787, 62.41403728723526, 62.91711129248142, 64.02079626917839, 62.211462557315826, 61.85379154980183, 20.51979571580887, 0.5791949050035328, 0.21099547884659842, 0.09592755217454396, 4.900824073702097, 59.419003799557686, 61.25197224318981, 56.83163143694401, 34.24301393330097, 23.61946228891611, 33.62843871116638, 52.866677194833755, 60.285072326660156, 49.56052780151367, 2.8083856031298637, 0.09414374828338623, 0.04412048641825095, 0.024568372100475244, 0.0583841677143937, 0.05750387666921597, 0.015649851738999132, 0.08617202096502297, 0.014526061113429023, 0.04088200628757477, 0.10047005998785608, 0.15642089245375246, 0.1020634213637095, 0.08910391246899962, 0.12080031985533424, 0.05932020518230274, 0.13476766529493034, 0.14196974836522713, 0.14258953073294833, 0.12536704394733533, 0.16912087972741574, 0.18050619692075998, 16.48818925023079, 65.88691413402557, 60.66844895482063, 53.54723207652569, 40.334356874227524, 32.035085409879684, 28.136420510709286, 46.425794810056686, 53.91831636428833, 64.58890378475189, 11.943083088845015, 0.49252019030973315, 0.3240397840272635, 2.7403037063777447, 9.559789225459099, 23.740041218698025, 46.08646921813488, 53.302468210458755, 56.090234220027924, 56.140562519431114, 58.49305808544159, 57.835731357336044, 57.32140235602856, 55.85889883339405, 55.22739551961422, 53.497048169374466, 56.0385075956583, 55.3579793125391, 52.983205541968346, 55.21135278046131, 56.41273811459541, 57.25236386060715, 53.47860395908356, 54.759709015488625, 52.27303124964237, 57.00507692992687, 52.15553395450115, 50.51043502986431, 52.1578898280859, 45.512080639600754, 42.35220819711685, 40.68939842283726, 41.37057267129421, 43.25681425631046, 40.15634782612324, 43.195717334747314, 42.309103310108185, 37.53990702331066, 40.43095529079437, 39.87520091235638, 40.090428963303566, 40.61272233724594, 39.15123336017132, 41.28846287727356, 42.92327955365181, 39.34642508625984, 40.6979213654995, 40.97965344786644, 40.13420261442661, 38.867665976285934, 42.18116797506809, 40.651313066482544, 43.8750334829092, 52.220544666051865, 52.879402711987495, 52.23616182804108, 51.34265497326851, 50.632112100720406, 55.83618365228176, 53.17546762526035, 55.780440643429756, 51.6158527135849, 49.05714601278305, 46.86709553003311, 47.852903231978416, 51.234843358397484, 59.16191339492798, 54.68570798635483, 54.04282808303833, 53.80057208240032, 50.76122537255287, 53.44289727509022, 52.603100538253784, 49.30255204439163, 51.45920991897583, 55.605395436286926, 55.708502903580666, 55.105547457933426, 54.62061747908592, 56.49688459932804, 55.87002843618393, 53.150164783000946, 55.60268998146057, 52.759237959980965, 44.37648497521877, 42.11038917303085, 39.781285151839256, 39.68269944190979, 41.92038416862488, 40.835800766944885, 42.34583593904972, 41.32057495415211, 41.6604895144701, 39.50951233506203, 40.914631336927414, 41.26884073019028, 40.09310021996498, 42.948536798357964, 41.702348068356514, 44.17315028607845, 42.033059522509575, 43.00502456724644, 41.22789032757282, 43.474059998989105, 42.45179705321789, 42.16939240694046, 43.59178528189659, 43.449175134301186, 45.97133919596672, 49.2962671816349, 47.514911368489265, 48.68615671992302, 48.49065721035004, 47.120469734072685, 45.41275016963482, 45.16950622200966, 44.190370962023735, 45.374930799007416, 49.73490044474602, 53.960706889629364, 53.069084733724594, 50.80774627625942, 50.73776163160801, 52.09806203842163, 59.40652146935463, 65.51186665892601, 66.59232348203659, 66.58831089735031, 64.78218421339989, 63.83690133690834, 24.53788250684738, 0.8643270330503583, 1.4151109219528735, 0.14775144984014332, 5.492468476295471, 64.93061184883118, 66.43796056509018, 68.3685989677906, 43.644955828785896, 27.70508475601673, 39.201094284653664, 60.37016116082668, 66.90696939826012, 61.61037661135197, 5.080154975876212, 0.44438903394620866, 0.15124467958230525, 0.12246460828464478, 0.09567265413352288, 0.11035784933483228, 0.11568781294045039, 0.17240276065422222, 0.14109512732829899, 0.11522125438204966, 0.14607532415539026], [0.03539926416124217, 0.021805217147630174, 0.03881012664351147, 0.09766203293111175, 0.020340273295005318, 0.012827865812141681, 0.07297276126337238, 0.04918456448649522, 0.08519071619957685, 0.0266146328067407, 0.07088962694979273, 8.431215584278107, 50.243134573102, 50.57692386209965, 41.221795454621315, 22.448661513626575, 21.412417218089104, 30.3312511369586, 40.74910841882229, 36.41359806060791, 50.67427083849907, 11.593745984137058, 0.194735691184178, 0.08530983090167865, 0.6081941176671535, 3.231182503513992, 18.988983258605003, 47.369390577077866, 51.09267018735409, 52.73520044982433, 53.05252142250538, 52.6469349861145, 53.198365196585655, 53.49203243851662, 51.148869171738625, 49.4792615622282, 46.92783907055855, 47.94043533504009, 48.12573239207268, 47.813043370842934, 47.86114498972893, 47.77310371398926, 48.56476083397865, 50.706371515989304, 47.592867985367775, 48.967102244496346, 46.54612675309181, 45.30664466321468, 43.47267687320709, 40.84764093160629, 35.818185210227966, 36.042570769786835, 36.222263127565384, 36.096440479159355, 38.29550787806511, 37.44359739124775, 34.89773400127888, 36.6510359197855, 36.484236270189285, 36.76177337765694, 36.74864888191223, 36.25452719628811, 36.666957065463066, 36.84781976044178, 35.3856810182333, 37.457725033164024, 36.481637209653854, 36.871165707707405, 36.064343601465225, 35.945235192775726, 35.25801166892052, 36.93868048489094, 37.91788414120674, 36.1683364212513, 40.89812122285366, 45.19076228141785, 45.99340461194515, 49.287231266498566, 49.93396796286106, 51.353875771164894, 50.37906847894192, 51.41904607415199, 48.70959386229515, 45.449680387973785, 43.53627026081085, 45.87366543710232, 50.38168653845787, 52.70053870975971, 47.896695882081985, 49.29507404565811, 54.566800966858864, 52.45434232056141, 51.144719794392586, 49.644738882780075, 48.097997680306435, 44.82122451066971, 48.51647302508354, 51.780741065740585, 51.292246878147125, 49.83180284500122, 51.21731869876385, 51.0566671192646, 47.65815228223801, 51.261084750294685, 54.46783147752285, 46.34690724313259, 38.05158756673336, 37.05128364264965, 37.70464338362217, 38.68999511003494, 37.03907109797001, 37.38756559789181, 37.8454714268446, 39.16482903063297, 38.66161823272705, 37.032353058457375, 36.89742609858513, 36.389849334955215, 38.148421570658684, 40.15619583427906, 42.479296177625656, 41.217790469527245, 40.63589729368687, 40.743849501013756, 39.072398990392685, 38.415722027421, 38.14120575785637, 40.06323382258415, 38.93607370555401, 36.86804607510567, 38.56626234948635, 39.934789314866066, 40.27418330311775, 39.100646674633026, 42.88077883422375, 41.834227591753006, 41.2686051428318, 41.91804729402065, 42.10926443338394, 43.57521437108517, 47.69554987549782, 45.48503749072552, 44.99836340546608, 45.10952264070511, 49.01968002319336, 55.48136629164219, 57.522369772195816, 60.70640131831169, 61.67940370738506, 58.536873534321785, 60.447433814406395, 17.67298087477684, 0.5161885265260935, 0.18826008163159713, 0.13001912244362757, 2.26050843950361, 46.59544050693512, 59.26408611238003, 53.8039842993021, 40.23026145994663, 26.249886341392994, 28.027411960065365, 39.70879644155502, 51.71503499150276, 36.28912054002285, 1.8431808706372976, 0.03817610988335218, 0.10151568669243716, 0.04726105871668551, 0.03610470150306355, 0.0726720949751325, 0.03926799836335704, 0.05476986771100201, 0.04211635372485034, 0.0361833914212184, 0.0655392839689739, 0.08274374398752116, 0.031173549505183473, 0.04738204363093246, 0.05897364819247741, 0.04091985210834537, 0.008587361080572009, 0.01668306787905749, 0.032085218554129824, 0.018772421390167437, 0.09777809740626253, 0.010728526704042451, 11.046364456415176, 57.45335787534714, 58.19879047572613, 46.10928699374199, 29.500106535851955, 24.05414756387472, 24.03739806264639, 35.316714718937874, 41.50152504444122, 59.00153160095215, 11.742301862686872, 0.3023529227357358, 0.035492047463776544, 1.2615812290459871, 4.984269021078944, 21.6502046585083, 47.00733460485935, 50.76580412685871, 54.32082496583462, 55.751653388142586, 55.47404408454895, 55.13197883963585, 55.71448378264904, 53.156046867370605, 51.823032796382904, 50.431916043162346, 50.88356740772724, 49.616122618317604, 50.6567157804966, 50.94041995704174, 49.88351806998253, 51.77206993103027, 51.825571060180664, 51.91995419561863, 50.95325946807861, 49.42345015704632, 49.66635212302208, 46.57533958554268, 42.08731301128864, 36.89134642481804, 37.86817140877247, 39.18960750102997, 39.558997079730034, 39.45322595536709, 38.050193041563034, 38.17420318722725, 38.07388477027416, 38.48028816282749, 38.679287284612656, 37.80258312821388, 38.07586446404457, 37.97185264527798, 38.40833902359009, 38.410892486572266, 38.79990801215172, 37.578885331749916, 38.16061891615391, 38.39671924710274, 38.91012869775295, 37.45944254100323, 38.388382494449615, 40.24098448455334, 39.63411904871464, 42.94750325381756, 46.3733234256506, 48.68123218417168, 52.49981828033924, 52.38641336560249, 52.86411993205547, 52.97731965780258, 52.69903019070625, 49.16150361299515, 47.211813032627106, 45.42184688150883, 46.74204804003239, 50.95837779343128, 55.66320173442364, 50.745467618107796, 49.59857515990734, 56.13797105848789, 52.64171786606312, 52.08413578569889, 50.3143085539341, 50.419171527028084, 45.0820729136467, 51.504628881812096, 52.76710733771324, 53.809984177351, 52.97246351838112, 55.01081474125385, 52.05413639545441, 47.82302923500538, 52.89753153920174, 55.14130733907223, 48.02809663116932, 38.77362862229347, 38.09362091124058, 39.211813509464264, 39.4849618524313, 38.750039488077164, 38.53641875088215, 39.252178743481636, 41.13921828567982, 39.46188569068909, 39.90786015987396, 40.38498155772686, 39.03492920100689, 40.48159897327423, 41.11941374838352, 43.15067835152149, 43.19248370826244, 42.64810971915722, 42.14889630675316, 40.77933579683304, 39.65626806020737, 40.48784963786602, 42.00943239033222, 42.27483294904232, 38.679758459329605, 40.453313291072845, 41.25247500836849, 41.54332660138607, 40.628658682107925, 44.33570556342602, 43.88026960194111, 43.86041946709156, 43.69898892939091, 45.930970162153244, 46.090580597519875, 50.19279487431049, 46.13730289041996, 47.72123269736767, 46.72745682299137, 50.38576751947403, 58.44263859093189, 59.760354682803154, 63.316074684262276, 63.11305157840252, 60.359502732753754, 59.9627660214901, 20.093597285449505, 0.24214292701799423, 0.34554559097159654, 0.16861998941749334, 2.4637013487517834, 50.729569271206856, 65.19310936331749, 58.461652770638466, 36.37780398130417, 27.124677300453186, 35.58043956756592, 44.93278652429581, 60.35835139453411, 47.42776684463024, 3.4932287922129035, 0.14200531208189204, 0.0596465275157243, 0.06250129503314383, 0.03017688784893835, 0.11102697710157372, 0.027298950481053907, 0.014996945465099998, 0.030664681107737124, 0.0062006480129639385, 0.022718288855685387, 0.11777344087022357, 0.1156412654381711, 0.10746469793957658, 0.16964755224762484, 0.10445177133078687, 0.1942367007723078, 0.123151666339254, 0.13879534526495263, 0.14337678614538163, 0.17417063063476235, 0.198099609115161, 13.989372085779905, 66.69765383005142, 64.20625671744347, 53.64583678543568, 34.23032261431217, 29.279670864343643, 41.00289300084114, 53.60715866088867, 49.02102515101433, 64.02841106057167, 14.336062632501125, 0.2574894129065797, 0.20714019978186116, 2.3179803555831313, 5.443516653031111, 21.983053497970104, 49.07496705651283, 50.694238767027855, 55.668491050601006, 58.41941423714161, 57.69019916653633, 58.63154925405979, 58.46027724444866, 56.20851427316666, 53.97105373442173, 51.46701090037823, 52.489505633711815, 51.98430374264717, 53.80431488156319, 53.00633870065212, 52.85387188196182, 54.098544493317604, 55.294397324323654, 54.02070187032223, 52.124922797083855, 51.265800297260284, 51.48528411984444, 46.23364292085171, 45.10095030069351, 38.531574010849, 40.41906572878361, 41.3446656614542, 40.682604387402534, 42.84916453063488, 41.21280513703823, 37.94294759631157, 40.42467802762985, 41.63917265832424, 41.33757144212723, 40.72427675127983, 40.153061002492905, 40.19165173172951, 41.53425648808479, 39.722680896520615, 41.95253424346447, 40.19866995513439, 39.26922842860222, 38.15420486032963, 40.70643670856953, 38.0316386371851, 39.14519168436527, 42.40325465798378, 40.42637653648853, 44.36823941767216, 49.43332962691784, 50.5261205881834, 51.63549765944481, 53.36601980030537, 52.65166953206062, 54.34029132127762, 55.14692723751068, 51.06259100139141, 49.78500835597515, 47.414315566420555, 49.0829124301672, 54.46263715624809, 57.72128149867058, 51.603199392557144, 51.142318323254585, 58.105695471167564, 56.000855416059494, 54.05089505016804, 52.70003333687782, 54.62679974734783, 47.44903430342674, 54.3581959605217, 56.035224571824074, 55.120959430933, 52.80270382761955, 56.950945034623146, 54.475252479314804, 49.31293308734894, 55.71611389517784, 56.616555377840996, 50.87793990969658, 41.23632587492466, 40.68207621574402, 40.789538249373436, 40.92155456542969, 39.76840764284134, 41.066497787833214, 41.396540477871895, 44.34311516582966, 41.11625611782074, 40.99423706531525, 40.89372105896473, 39.906480833888054, 43.09562690556049, 43.58622618019581, 45.56707888841629, 44.48437638580799, 44.5780223608017, 44.3418650329113, 43.483141511678696, 42.08519272506237, 42.01557666063309, 44.0864123404026, 44.12023812532425, 41.17446519434452, 42.85675272345543, 43.61101225018501, 44.32672284543514, 44.11554157733917, 46.69507876038551, 45.97580395638943, 45.5941866338253, 46.31446458399296, 47.684131488204, 47.4845016002655, 53.05193245410919, 49.03813563287258, 50.26496060192585, 49.30680401623249, 53.87832351028919, 60.353749841451645, 61.50495506823063, 67.81517386436462, 65.39358660578728, 61.750003919005394, 61.38189487159252, 21.63811180740595, 1.0316292056813836, 1.0981515236198902, 0.38370830880012363, 2.660258151590824, 56.946708261966705, 69.68037977814674, 69.76301774382591, 54.95487414300442, 40.52881523966789, 42.122499123215675, 55.125458389520645, 69.3524269759655, 58.714354410767555, 6.686797114089131, 0.1839626012952067, 0.16091382480226457, 0.159521629975643, 0.2415051995194517, 0.2518209780100733, 0.17818520427681506, 0.11647735416772775, 0.13072025903966278, 0.16905625350773335, 0.11342923491611145], [0.04037633283587638, 0.05049413230153732, 0.03391636404558085, 0.011833027056127321, 0.0552112897275947, 0.03178475635650102, 0.05841425809194334, 0.042751906730700284, 0.026066874015668873, 0.03768881200812757, 0.1030759557033889, 6.885933978483081, 50.00013381242752, 48.607022166252136, 42.513509541749954, 17.37822499126196, 33.431666269898415, 64.67727184295654, 48.33622209727764, 31.467838548123837, 43.786445036530495, 14.9029029160738, 0.3995673218742013, 0.054023356206016615, 1.2108424329198897, 2.2992124501615763, 21.250555403530598, 42.725188583135605, 52.944531217217445, 55.2300363779068, 51.184378266334534, 51.151502430438995, 48.13045173883438, 47.49123863875866, 45.238772705197334, 46.19498759508133, 43.36075007915497, 42.19372250139713, 40.59300899505615, 39.94762122631073, 38.47974859178066, 41.230037212371826, 43.46087470650673, 42.81456358730793, 43.92154298722744, 40.9798776358366, 39.77773234248161, 37.384115383028984, 34.44525808095932, 34.93208035826683, 35.1330591738224, 35.35366013646126, 34.61459219455719, 34.537403136491776, 35.219078958034515, 35.76030291616917, 35.97051523625851, 35.363596603274345, 35.348135232925415, 37.04224392771721, 36.31532393395901, 35.18533296883106, 36.191385984420776, 35.27787320315838, 36.13166458904743, 36.03400982916355, 36.64677634835243, 38.50182920694351, 35.23610584437847, 35.01179628074169, 34.85551066696644, 36.59707501530647, 37.187392339110374, 35.798950642347336, 40.500210374593735, 44.79066655039787, 46.74962483346462, 49.46449555456638, 50.799971893429756, 50.96431687474251, 50.49041770398617, 50.410785377025604, 45.962766855955124, 46.45801328122616, 42.20213145017624, 46.981138810515404, 50.223770812153816, 51.213689893484116, 52.89260320365429, 45.677531361579895, 51.58085659146309, 47.553498297929764, 51.121951416134834, 51.81827165186405, 52.143651992082596, 46.561797112226486, 45.58752179145813, 49.72022943198681, 49.895004853606224, 53.251144364476204, 52.54182502627373, 47.78734154999256, 43.653357177972794, 51.73648104071617, 53.85186553001404, 47.48539835214615, 39.03638072311878, 36.26132883131504, 36.74911245703697, 36.74801431596279, 37.27292574942112, 37.94870428740978, 37.45947293937206, 38.01884092390537, 38.18747207522392, 36.275000497698784, 36.89308673143387, 37.662328854203224, 37.32172653079033, 39.12780001759529, 40.41628807783127, 40.99773287773132, 41.066661179065704, 40.760826990008354, 42.293934524059296, 40.35413101315498, 40.98770521581173, 39.13152761757374, 38.835500702261925, 39.21369820833206, 40.013243705034256, 39.43051837384701, 40.458184629678726, 39.11603204905987, 39.532698690891266, 41.592423766851425, 41.36960752308369, 40.17081744968891, 40.629259049892426, 42.01050393283367, 42.878495156764984, 44.22286681830883, 43.05607482790947, 44.31337796151638, 45.38637958467007, 55.306222289800644, 58.16532947123051, 61.557517647743225, 60.69661304354668, 60.40333718061447, 60.55784069001675, 24.134262464940548, 0.2810974867315963, 0.24188278941437602, 0.07825404740287922, 1.8090801942162216, 44.70835156738758, 58.87076921761036, 50.1845683157444, 48.20123054087162, 27.194682843983173, 23.61388798803091, 43.286726251244545, 51.92750819027424, 35.316878110170364, 1.6032286151312292, 0.0608453483437188, 0.06466243648901582, 0.03541872327332385, 0.02516285650926875, 0.10589241355773993, 0.08361855056136847, 0.028413658146746457, 0.08855542822857387, 0.008945613390096696, 0.013957975825178437, 0.07995421125087887, 0.009630825352360262, 0.029941536122350954, 0.04267483098374214, 0.01503072060586419, 0.057633169926702976, 0.030997016692708712, 0.01701763176242821, 0.017889633018057793, 0.04741935139463749, 0.010402712741779396, 9.548888560384512, 58.604935482144356, 54.91512827575207, 49.88398924469948, 22.959451004862785, 28.22907093912363, 55.484090745449066, 48.49769063293934, 38.6000045388937, 48.102542236447334, 16.10064424574375, 0.4037033108761534, 0.062051675995462574, 1.579220553394407, 2.4950947891920805, 23.282443173229694, 44.50413152575493, 54.6796815097332, 56.50311626493931, 54.131123945117, 54.39564675092697, 51.99219971895218, 49.3553502112627, 48.77522774040699, 48.35442692041397, 46.98512859642506, 44.58286330103874, 44.230006635189056, 43.56989085674286, 42.48135566711426, 44.56734873354435, 44.87797066569328, 45.88044427335262, 44.819438606500626, 44.76874552667141, 41.54418535530567, 39.84067976474762, 37.670578211545944, 36.28682166337967, 38.432912304997444, 37.02013671398163, 36.58382512629032, 36.40225566923618, 36.708272248506546, 37.83140458166599, 38.07849012315273, 37.37544044852257, 36.29900760948658, 37.86370284855366, 38.0498206615448, 37.798650339245796, 38.13400514423847, 37.037334591150284, 37.26464219391346, 38.532360568642616, 39.12222571671009, 38.62202435731888, 38.031125664711, 37.67169155180454, 36.12307325005531, 38.23640964925289, 39.256757497787476, 36.56777858734131, 41.66007533669472, 47.272241190075874, 49.2526151239872, 50.772358775138855, 50.9699709713459, 52.36226566135883, 53.21577586233616, 51.89218148589134, 48.93154375255108, 48.40037785470486, 45.453993156552315, 50.190070420503616, 52.11062416434288, 52.66065984964371, 55.1096398383379, 46.69739283621311, 52.75649830698967, 50.75808674097061, 52.151540368795395, 54.430319890379906, 54.287842735648155, 48.67785036563873, 49.01701256632805, 49.78327564895153, 50.75475811958313, 53.268577829003334, 53.11986520886421, 49.3516606092453, 45.65163195133209, 51.15065507590771, 56.661814749240875, 49.787447825074196, 41.826327815651894, 37.9890201240778, 39.11342538893223, 39.593024253845215, 39.99465510249138, 41.08900398015976, 39.255427569150925, 40.54034382104874, 38.35027813911438, 39.34203252196312, 38.669502809643745, 39.04062509536743, 39.42658178508282, 41.18631295859814, 42.417348101735115, 42.44842283427715, 43.103226497769356, 42.27969668805599, 43.241596072912216, 41.37457765638828, 42.10841327905655, 40.98891735076904, 40.50816334784031, 41.31452567875385, 41.548201739788055, 40.31861051917076, 41.34328253567219, 42.150127440690994, 40.832567140460014, 42.29842968285084, 43.83117623627186, 41.61412440240383, 45.35597361624241, 44.548984318971634, 43.98248791694641, 46.24844692647457, 45.68263828754425, 46.72083377838135, 47.75046832859516, 58.22709895670414, 60.70217974483967, 62.939742878079414, 62.78367005288601, 61.36406622827053, 59.60572198033333, 26.36223491281271, 0.2853872487321496, 0.32795580045785755, 0.013388141851464752, 2.1084109134972095, 49.274403154850006, 63.444572389125824, 53.4985338896513, 47.477205991744995, 30.425877459347248, 28.553938306868076, 50.039419904351234, 59.18767601251602, 46.12238489091396, 2.720070742070675, 0.10114872435224243, 0.04324640714912675, 0.017673348920652643, 0.046855990804033354, 0.021668062690878287, 0.015396434282592963, 0.08196768758352846, 0.06889212905662134, 0.005786628407804528, 0.036107057821936905, 0.12795038579497486, 0.1662363891955465, 0.17984178179176524, 0.15872036281507462, 0.1195807485783007, 0.21226533805020154, 0.11254789744270965, 0.13879947160603479, 0.09551131122861989, 0.207790914864745, 0.19722584896953776, 11.82654619216919, 67.46094927191734, 60.748457461595535, 55.71801379323006, 26.17942102253437, 42.51882925629616, 73.66955772042274, 59.56792160868645, 46.11011914908886, 58.32751236855984, 19.22691509127617, 0.540143153630197, 0.2905386738711968, 3.3453381154686213, 6.323823491111398, 24.40744310617447, 46.35676011443138, 57.4325729906559, 60.47308623790741, 57.724511325359344, 56.288442984223366, 53.14478427171707, 51.961026191711426, 50.684249103069305, 52.103347554802895, 48.867285400629044, 47.036406844854355, 45.60365952551365, 44.30718049407005, 42.425658255815506, 45.345706567168236, 47.61259652674198, 47.3912888020277, 48.153410106897354, 45.928697884082794, 45.46012602746487, 42.541259452700615, 39.33819092810154, 37.747258096933365, 40.5266759544611, 38.31381909549236, 39.72762443125248, 38.13978083431721, 38.55397380888462, 41.65698230266571, 40.03919631242752, 38.53359170258045, 38.08556914329529, 40.01642033457756, 40.15178047120571, 39.230979681015015, 40.769273936748505, 39.41529259085655, 39.23796370625496, 39.65031377971172, 39.84737120568752, 42.33857452869415, 40.088722854852676, 39.17739875614643, 38.41937743127346, 41.25023312866688, 40.78191965818405, 38.86844493448734, 43.36830027401447, 48.89287702739239, 50.90078428387642, 52.49533832073212, 53.79702307283878, 54.15145665407181, 56.290080696344376, 54.434256479144096, 48.943957686424255, 49.77387875318527, 48.029635548591614, 51.76037795841694, 54.86645668745041, 54.50999781489372, 57.33575038611889, 47.53868669271469, 54.857800751924515, 52.979303151369095, 54.80223633348942, 55.21017484366894, 56.24971926212311, 49.71539229154587, 50.57537354528904, 52.212793081998825, 52.2551304101944, 57.57825717329979, 53.93129646778107, 50.94541288912296, 46.15821696817875, 51.86265327036381, 57.62361153960228, 52.33844093978405, 43.21624383330345, 39.45056609809399, 40.1640348136425, 41.9468991458416, 41.37631416320801, 42.429712638258934, 40.62706656754017, 42.74039536714554, 40.858645141124725, 40.63675604760647, 40.439831614494324, 41.44781872630119, 41.302411928772926, 44.07562471926212, 44.59849186241627, 44.10992547869682, 45.570684894919395, 44.402479380369186, 45.03965958952904, 43.397972881793976, 44.45382982492447, 43.13321828842163, 42.14312821626663, 43.81427474319935, 45.25251656770706, 42.02650487422943, 44.275676384568214, 44.58419322967529, 42.63902820646763, 43.84517088532448, 46.06714725494385, 43.41979131102562, 46.535658314824104, 46.56776279211044, 46.45011730492115, 48.65307569503784, 47.204730212688446, 47.39169918000698, 49.73126783967018, 62.071155086159706, 63.416541293263435, 65.95463410019875, 67.21666797995567, 61.85575224459171, 64.64805901050568, 31.04329112917185, 1.7745217611081898, 1.3309963792562485, 0.2554690494434908, 2.3780819680541754, 54.62881363928318, 69.06278371810913, 65.92064872384071, 61.537553519010544, 39.75518435239792, 35.96630126237869, 59.62691344320774, 68.33870217204094, 60.587114319205284, 5.634264042600989, 0.22651862556813285, 0.1252678781747818, 0.18418862979160622, 0.09640682372264564, 0.1877470943145454, 0.19537230546120554, 0.18545886006904766, 0.13078455871436745, 0.11790751726948656, 0.10469941116753034], [0.053451839412446134, 0.03575681977963541, 0.03706093651999254, 0.03816434313193895, 0.04481554111407604, 0.07469409116310999, 0.043883830367121845, 0.023977822929737158, 0.013093409033899661, 0.05408164819527883, 0.025242283008992672, 7.7407152112573385, 46.32525600492954, 51.56587399542332, 34.79584626853466, 25.35331305116415, 48.807096630334854, 71.54848873615265, 48.04534010589123, 27.49261535704136, 53.80451627075672, 18.543187379837036, 0.21202333853580058, 0.11341097808326595, 0.5516068416181952, 3.261850895360112, 27.64330767095089, 53.29632394015789, 54.68190059065819, 51.00517988204956, 50.034635961055756, 49.46926049888134, 46.80912584066391, 45.46642608940601, 44.743298292160034, 42.36570127308369, 41.84951797127724, 39.74088951945305, 38.111179769039154, 37.66815014183521, 38.24656270444393, 35.99079854786396, 37.61658310890198, 36.64432927966118, 36.454472467303276, 34.381934478878975, 35.769939199090004, 34.3145526945591, 36.28322705626488, 35.81016004085541, 34.20626990497112, 33.85781340301037, 33.452040776610374, 34.65091824531555, 35.16913823783398, 36.49521768093109, 34.859941229224205, 36.410695016384125, 37.15781092643738, 35.671908259391785, 36.092503890395164, 36.5260948240757, 35.067820474505424, 37.186313197016716, 37.81256899237633, 37.57393799722195, 36.04015029966831, 37.440796941518784, 37.60311283171177, 36.157624796032906, 35.241999328136444, 37.63201788067818, 36.455912590026855, 36.68839931488037, 39.04082268476486, 44.05653074383736, 47.74165280163288, 51.06348775327206, 48.600725904107094, 49.58677679300308, 49.676508978009224, 49.884414821863174, 45.345619171857834, 44.439633786678314, 43.397174924612045, 50.2253021299839, 51.56147003173828, 51.83939851820469, 46.98273852467537, 44.287904128432274, 50.2138951420784, 47.86882437765598, 52.50108741223812, 51.67825676500797, 51.89575709402561, 44.793960973620415, 49.63724188506603, 49.99559685587883, 52.68521413207054, 49.646710976958275, 49.84944149851799, 49.034947603940964, 44.19661782681942, 45.69246456027031, 44.208078011870384, 50.02081610262394, 37.992569133639336, 35.30223749577999, 37.82793916761875, 36.92974716424942, 37.94292859733105, 36.759181916713715, 37.23473399877548, 39.1104007512331, 38.22351314127445, 36.078980416059494, 36.21988445520401, 37.82879792153835, 38.077669367194176, 38.01158711314201, 40.276235193014145, 37.71682932972908, 38.04608926177025, 40.31332120299339, 37.70027741789818, 36.715267673134804, 39.28338646888733, 39.499313682317734, 39.70135644078255, 39.46444675326347, 39.08563748002052, 39.69028763473034, 39.565259143710136, 38.82046490907669, 39.97024141252041, 42.30555050075054, 40.895054787397385, 41.491288393735886, 42.27227948606014, 43.03791180253029, 42.190979048609734, 43.267286494374275, 42.87839636206627, 44.856612011790276, 45.346907302737236, 46.935305669903755, 53.17073307931423, 57.74015888571739, 61.447000578045845, 59.31404583156109, 64.84450086951256, 30.77907420694828, 0.11226523565710522, 0.07224239889183082, 0.023710963323537726, 1.4873837563209236, 44.41415995359421, 62.3720533400774, 48.35820771753788, 48.42683583498001, 33.498972058296204, 37.51751862466335, 47.33216017484665, 51.72886244952679, 35.11197790503502, 1.7564095580019057, 0.04550013894913718, 0.05353434396965895, 0.08877939355443232, 0.04451613647688646, 0.016589188053330872, 0.08634615849587135, 0.01697047940979246, 0.09594711518730037, 0.022226495420909487, 0.11425589094869792, 0.04854547143622767, 0.009484426518611144, 0.036582243847078644, 0.02075781114399433, 0.08689873196999542, 0.10871652295463718, 0.056017555252765305, 0.021161363220016938, 0.03827229964372236, 0.05050325329648331, 0.01860700038378127, 8.811892457306385, 55.23499511182308, 57.183408960700035, 40.8877819776535, 23.569950945675373, 50.54065480828285, 80.14577820897102, 57.01759345829487, 34.37495045363903, 56.86677575111389, 19.801275171339512, 0.30572251067496836, 0.14379621832631528, 1.053885561414063, 1.5073805395513773, 26.720057912170887, 53.49568024277687, 56.522141844034195, 53.40716779232025, 53.81789915263653, 51.8724225461483, 48.3936408162117, 48.740079626441, 47.089505195617676, 44.205368757247925, 42.725994139909744, 41.86561390757561, 39.995844438672066, 38.14546912908554, 38.963588029146194, 37.32663966715336, 39.24698442220688, 38.836633041501045, 37.61418163776398, 37.28589445352554, 36.76948316395283, 36.36566363275051, 37.72091791033745, 36.8918251991272, 35.97451262176037, 36.67991816997528, 36.130517050623894, 36.42752431333065, 37.7156475931406, 39.218409955501556, 36.62930868566036, 38.182543739676476, 37.31673739850521, 38.61982807517052, 37.68585719168186, 38.79833109676838, 38.562131971120834, 38.15488502383232, 38.48623864352703, 39.633541479706764, 37.21583001315594, 39.988605827093124, 39.68456894159317, 37.671634554862976, 36.21818594634533, 38.14470537006855, 38.504549860954285, 38.59465442597866, 39.55213464796543, 47.200656831264496, 49.635718166828156, 51.606330424547195, 49.0402065217495, 53.78459393978119, 51.41323998570442, 50.66999986767769, 47.208108231425285, 47.483156472444534, 45.51980562508106, 51.63093790411949, 51.89939349889755, 55.50748988986015, 49.1284453868866, 44.84396629035473, 53.35485219955444, 51.3591992855072, 52.55336880683899, 51.82939365506172, 52.613941356539726, 47.45676688849926, 50.46323396265507, 52.44648814201355, 53.084067329764366, 52.55059115588665, 50.92046342790127, 51.0498882830143, 45.667773485183716, 47.087799087166786, 46.78663484752178, 50.58515802025795, 41.71698488295078, 37.2305504232645, 39.52293321490288, 38.417272344231606, 40.561565682291985, 38.11063639819622, 37.82416597008705, 42.55326680839062, 39.26696754992008, 37.80841201543808, 38.94338831305504, 38.287228122353554, 40.856654047966, 39.77563485503197, 42.445698380470276, 39.20962482690811, 40.13113997876644, 39.98821064829826, 39.9518845975399, 39.607113897800446, 40.00546932220459, 40.71077987551689, 40.44702462852001, 39.598400965332985, 40.11157102882862, 41.7715385556221, 40.95417961478233, 41.43299572169781, 42.02888734638691, 43.83611977100372, 43.41987490653992, 43.79393443465233, 44.68463324010372, 44.554285034537315, 44.10238288342953, 45.471400022506714, 44.67950351536274, 46.824195832014084, 46.59309223294258, 48.71511496603489, 56.2453418970108, 59.77127529680729, 64.72098469734192, 61.46882280707359, 66.05317041277885, 33.48675951361656, 0.20554778835503384, 0.22720174281857908, 0.037827248524990864, 1.3984091556631029, 48.61596688628197, 66.92818745970726, 54.1652575135231, 56.739744767546654, 35.768138095736504, 41.76377557218075, 55.75938977301121, 59.61006514728069, 45.380204916000366, 3.4847305482253432, 0.06921027292264625, 0.05656665547576267, 0.009849928683252074, 0.039508491317974404, 0.05263024111627601, 0.026868425047723576, 0.06294103237451054, 0.01591989515873138, 0.040971687412820756, 0.03690716723212972, 0.16014705266570672, 0.10977867728797719, 0.12435263197403401, 0.1511886325897649, 0.15178428031504154, 0.2376747378730215, 0.13436070119496435, 0.13865798857295886, 0.1112791959894821, 0.2259092777967453, 0.10549560203799047, 11.530900206416845, 62.91747227311134, 66.01923063397408, 46.644837856292725, 36.081579476594925, 58.7153347581625, 76.84489533305168, 57.481624558568, 41.209780499339104, 66.594048589468, 22.93930258601904, 0.3068717708811164, 0.2696294349152595, 1.846133430954069, 5.614089500159025, 31.02380007505417, 56.885216161608696, 59.84225168824196, 56.60311549901962, 56.670124903321266, 53.98279890418053, 51.73690661787987, 51.266271471977234, 50.06838954985142, 48.22177603840828, 45.8336915820837, 43.63713964819908, 43.07326130568981, 40.7656679302454, 41.47581562399864, 40.57782880961895, 40.88113993406296, 41.766310036182404, 40.905663818120956, 38.69967699050903, 38.578835874795914, 37.74507321417332, 39.970974773168564, 38.89007717370987, 38.98541785776615, 39.070556089282036, 38.08205433189869, 38.48970025777817, 41.46174497902393, 40.765287950634956, 39.12738583981991, 40.27098387479782, 40.60578390955925, 39.74917687475681, 38.10969404876232, 41.436244547367096, 39.10736471414566, 41.233286038041115, 41.600783318281174, 41.31729193031788, 39.72420081496239, 41.39802999794483, 42.11532510817051, 38.628366217017174, 37.821768298745155, 39.96867969632149, 39.91771683096886, 41.000597923994064, 41.3758809864521, 47.808901593089104, 51.06939263641834, 53.212264850735664, 50.01532159745693, 54.24701392650604, 51.78279295563698, 53.49770173430443, 48.079397678375244, 50.386998653411865, 47.30593018233776, 54.04391102492809, 54.870818853378296, 55.591947957873344, 51.32843613624573, 47.4465948343277, 54.97200362384319, 53.26325051486492, 53.74254159629345, 54.0328574180603, 54.96773265302181, 49.138305857777596, 53.6030662804842, 55.27425080537796, 56.28780081868172, 54.152953773736954, 53.363367542624474, 52.84412160515785, 45.8587284386158, 48.48678521811962, 50.68956881761551, 54.54956889152527, 43.9979986846447, 38.3641017973423, 41.75791248679161, 38.712223917245865, 41.2530829757452, 40.414011999964714, 39.62899312376976, 44.55124519765377, 41.16797514259815, 38.45903970301151, 40.22642366588116, 41.27658471465111, 43.49976561963558, 41.171269565820694, 46.350794434547424, 41.576988995075226, 42.77692660689354, 44.01387043297291, 41.13941967487335, 41.26214548945427, 43.045480996370316, 43.761465176939964, 43.1656913459301, 43.65180306136608, 43.27903166413307, 44.36511218547821, 43.44480536878109, 43.471084758639336, 43.79124037921429, 45.87717644870281, 45.34977234899998, 46.468052342534065, 46.556169614195824, 47.469925582408905, 47.02468067407608, 48.9162989705801, 46.519847363233566, 49.19292412698269, 49.13670614361763, 52.25631594657898, 58.81359748542309, 61.57251164317131, 68.26336741447449, 65.4858760535717, 67.04439282417297, 37.286016047000885, 0.65893879160285, 0.8014398731756955, 0.22328857623506337, 1.8679494853131473, 52.74493932723999, 71.88886687159538, 62.31267772614956, 62.516840770840645, 45.19195921719074, 49.150875583291054, 64.41755577921867, 66.33500128984451, 58.60438831150532, 6.658523306250572, 0.22016932955011725, 0.2469550570822321, 0.20584356389008462, 0.12514330126577988, 0.12218567950185388, 0.1948185742367059, 0.13402398879406974, 0.12528931139968336, 0.08764038240769878, 0.20649381884140894], [0.0072890437604655745, 0.06754967296728864, 0.05740495209465735, 0.04513587802648544, 0.016642693190078717, 0.01928417488670675, 0.016577063215663657, 0.08010368721443228, 0.018473512136552017, 0.07809719449141994, 0.07862256083171815, 6.160181472077966, 51.37504443526268, 54.706439673900604, 45.91132901608944, 33.46727415919304, 35.4645723849535, 42.90184870362282, 36.737538278102875, 40.99767968058586, 55.71610249578953, 24.99377254396677, 0.2622948191128671, 0.22488604910904542, 0.8100658853072673, 0.36169793049339205, 25.377586148679256, 53.74586261808872, 53.80847565829754, 52.94974073767662, 48.99414539337158, 45.4903420060873, 41.711619570851326, 40.92887297272682, 39.08094473183155, 39.95508782565594, 40.787178575992584, 38.7292356044054, 39.94242690503597, 35.86985103785992, 37.581567987799644, 38.47306475043297, 38.71454179286957, 37.10774481296539, 37.551769986748695, 36.570913419127464, 36.23877324163914, 36.65929287672043, 35.1821905374527, 33.73249612748623, 30.91093473136425, 35.04973724484444, 36.58436469733715, 36.288694962859154, 37.400503903627396, 36.99331775307655, 36.57535158097744, 37.02912323176861, 36.828076019883156, 36.768905594944954, 35.21062061190605, 36.997691318392754, 38.062302991747856, 37.21552982926369, 37.011138796806335, 36.6010420024395, 36.3225207477808, 36.4743036031723, 34.977541118860245, 36.62823714315891, 36.231884211301804, 36.367468535900116, 37.834820598363876, 37.23947234451771, 39.43112634122372, 45.248891562223434, 47.74932838976383, 53.194367811083794, 45.618045553565025, 50.76478198170662, 51.01408280432224, 48.421155139803886, 47.77042105793953, 43.70724208652973, 42.611506283283234, 50.359343737363815, 50.036349669098854, 52.81525835394859, 46.93621002137661, 48.87043543159962, 56.527054980397224, 51.24063424766064, 52.343050092458725, 48.98543246090412, 47.922960072755814, 45.04336819052696, 50.8305374532938, 48.89155089855194, 51.53770610690117, 50.34459672868252, 53.33988480269909, 46.63184255361557, 52.067599073052406, 46.2254885584116, 45.249594524502754, 49.23371873795986, 38.40059123933315, 39.53189313411713, 36.97978287935257, 38.25423449277878, 39.311808943748474, 38.113452047109604, 36.950847432017326, 38.16723056137562, 38.1212492287159, 35.35103067755699, 38.339821100234985, 36.6155344247818, 38.17711763083935, 37.873346731066704, 37.01914496719837, 36.138648614287376, 37.77168698608875, 37.00863853096962, 36.634970381855965, 36.556352600455284, 36.850867196917534, 37.59654298424721, 39.58110809326172, 39.30567607283592, 40.99011428654194, 38.29174987971783, 39.25298810005188, 39.212801456451416, 40.1010911911726, 39.86076928675175, 40.383115857839584, 40.34986764192581, 40.3459994494915, 40.74870944023132, 42.78110258281231, 40.66588148474693, 41.17575712502003, 41.5286897867918, 44.90034006536007, 43.06512214243412, 48.95623482763767, 55.385964810848236, 59.81297425925732, 56.9737134128809, 66.04165703058243, 29.99619271606207, 0.22703560563968495, 0.07737942636595108, 0.048514776208321564, 1.1782753304578364, 40.21472029387951, 59.331365302205086, 46.060189828276634, 33.92106480896473, 25.517574436962605, 26.487333700060844, 43.70332449674606, 49.798098653554916, 39.99405473470688, 3.4557245671749115, 0.08815495792077854, 0.061415451345965266, 0.09603350859833881, 0.058790567782125436, 0.042777714916155674, 0.08129932422889397, 0.022427207404689398, 0.07050298285321333, 0.01742268112138845, 0.04648586691473611, 0.03961668902775273, 0.015076151175890118, 0.025257253982999828, 0.04489534425374586, 0.014542981152771972, 0.023800711242074613, 0.07841116006602533, 0.027015014056814834, 0.006978475366850034, 0.08339272244484164, 0.057545722665963694, 7.184486808255315, 57.022624388337135, 62.4969108402729, 51.31482146680355, 37.24508464336395, 39.12555433809757, 53.62532928586006, 45.16894765198231, 43.49232941865921, 61.58533215522766, 25.92435210943222, 0.1894496552995406, 0.2695087023312226, 0.502186871599406, 1.0816384409554303, 28.13247062265873, 55.464331805706024, 57.13034860789776, 54.89376202225685, 51.88997380435467, 46.81965887546539, 44.693596959114075, 43.468998670578, 41.6384506970644, 42.62283727526665, 42.914152443408966, 40.098093152046204, 41.278640404343605, 36.998584270477295, 40.38405440747738, 39.93393816053867, 41.25798471271992, 38.51284481585026, 38.086663484573364, 38.50830405950546, 37.69754156470299, 37.875037640333176, 36.51317931711674, 36.08405314385891, 32.28123240172863, 37.76545152068138, 37.349913418293, 37.886904403567314, 39.4772482663393, 38.19312237203121, 38.47121424973011, 39.546290561556816, 38.70439633727074, 39.605088606476784, 38.66370812058449, 38.28005790710449, 37.51751482486725, 37.99177497625351, 38.71951572597027, 38.93464498221874, 37.347078770399094, 38.56348469853401, 37.865218967199326, 38.87142397463322, 37.50743016600609, 37.51100957393646, 38.1006733328104, 38.41659598052502, 42.132462188601494, 47.9181457310915, 51.00086711347103, 53.178788647055626, 46.676239371299744, 52.861710861325264, 51.81064546108246, 49.15550373494625, 49.53321486711502, 45.4988269507885, 44.318116307258606, 51.9556000828743, 51.54325380921364, 54.508439898490906, 50.28228007256985, 49.619158655405045, 58.36876295506954, 54.684264063835144, 54.91567924618721, 51.90441682934761, 49.39906306564808, 47.240349501371384, 53.37885931134224, 49.38512161374092, 53.28238628804684, 51.97100065648556, 54.46996696293354, 48.00233781337738, 49.85328309237957, 48.83555710315704, 46.778902262449265, 51.018243581056595, 40.18173806369305, 40.414578169584274, 38.919366002082825, 39.252281337976456, 40.22965349256992, 39.487883895635605, 39.92146722972393, 39.28760424256325, 38.164509907364845, 36.975139528512955, 38.71825039386749, 40.81092730164528, 38.751832991838455, 39.636467322707176, 40.42485661804676, 39.548707231879234, 39.97968390583992, 40.26296250522137, 38.80899332463741, 38.070567548274994, 39.2694716155529, 39.2655274271965, 41.60453751683235, 41.531410440802574, 42.050888165831566, 39.872712045907974, 41.35419934988022, 41.51185669004917, 42.840489596128464, 42.57186681032181, 41.46485701203346, 42.267282754182816, 42.620948776602745, 42.14703060686588, 43.33154484629631, 42.13523603975773, 43.50651025772095, 43.7626963108778, 45.64058214426041, 45.61912089586258, 51.071813106536865, 57.557818070054054, 62.28867441415787, 59.785102754831314, 67.28399276733398, 32.297503128647804, 0.2343703104997985, 0.3419859241694212, 0.13441346789477393, 1.2655238737352192, 43.95091541111469, 66.2770240008831, 52.29142986238003, 40.63676744699478, 34.965613558888435, 36.563959792256355, 51.6696198284626, 57.15377055108547, 50.34275382757187, 5.833927653729916, 0.17054485331755131, 0.013009499034524197, 0.1465673977509141, 0.05818837431434076, 0.03834035087493248, 0.07483799359761178, 0.05260052552330308, 0.09139987247181125, 0.017005082045216113, 0.030200302608136553, 0.1985491279629059, 0.15042353770695627, 0.114678328827722, 0.14069102791836485, 0.1381294903694652, 0.08665188623126596, 0.2308275646646507, 0.16599435999523848, 0.16023079660953954, 0.20885476871626452, 0.17377873213263229, 8.365788795053959, 65.44644936919212, 67.74976417422295, 59.44635093212128, 44.428906962275505, 44.753477945923805, 51.67679764330387, 50.494171902537346, 52.08618767559528, 65.75134500861168, 31.031726449728012, 0.26019798475317657, 0.5725093418732285, 1.8995020422153175, 1.72930276254192, 30.099908150732517, 58.22725474834442, 60.56034095585346, 57.73960791528225, 55.02317927777767, 48.91316033899784, 47.474367544054985, 45.66954419016838, 44.79942508041859, 44.420486614108086, 45.524353981018066, 43.91837015748024, 44.80359725654125, 39.237386137247086, 41.276702508330345, 42.296514585614204, 44.401613026857376, 40.461323261260986, 40.54754823446274, 39.925647005438805, 40.87262839078903, 39.53040361404419, 37.71296113729477, 37.535810843110085, 34.14918936789036, 40.16736343502998, 40.40591083467007, 40.59815771877766, 42.52528131008148, 41.24098062515259, 40.17945058643818, 43.768908977508545, 40.66769398748875, 42.69451282918453, 40.59569925069809, 40.62490448355675, 41.128035485744476, 40.802142173051834, 39.74763795733452, 39.77447211742401, 39.3944089114666, 40.68795070052147, 37.66374617815018, 41.399249732494354, 39.08405676484108, 38.814430832862854, 41.29343681037426, 40.294295623898506, 44.25905227661133, 50.24976521730423, 52.11407817900181, 53.59172388911247, 48.26423116028309, 54.10289905965328, 53.0633432418108, 51.18102304637432, 52.55414396524429, 46.48083105683327, 47.431543841958046, 54.83229272067547, 53.03357183933258, 56.35429345071316, 52.67161466181278, 53.16061042249203, 61.49564556777477, 55.75212836265564, 57.78427071869373, 53.73968034982681, 51.12104706466198, 49.620017409324646, 56.0895274579525, 53.39269056916237, 54.44347098469734, 53.78577947616577, 54.40279796719551, 49.894028306007385, 52.24577911198139, 50.27115806937218, 50.76446279883385, 50.922355726361275, 42.62745022773743, 42.50612273812294, 40.50640024244785, 40.560801923274994, 43.381755352020264, 41.90513178706169, 40.827182829380035, 40.72558008134365, 40.24464748799801, 37.457751631736755, 42.09298610687256, 42.51617319881916, 42.05867774784565, 42.524631544947624, 41.16208925843239, 40.47436036169529, 41.219530776143074, 42.80753396451473, 39.991668462753296, 40.33784508705139, 40.9027835726738, 41.55334286391735, 45.03218539059162, 44.034472927451134, 44.55097921192646, 41.38540327548981, 44.72366854548454, 44.01408702135086, 43.774046301841736, 45.74832536280155, 44.61825080215931, 44.431950598955154, 45.508778616786, 44.191799685359, 47.63256445527077, 46.803015768527985, 46.65698200464249, 46.594878137111664, 47.902604565024376, 47.78499707579613, 53.53187710046768, 60.59771575033665, 65.36520212888718, 61.897447407245636, 69.9451419711113, 36.54927738010883, 0.49256602535024285, 1.1716972896829247, 0.4679355095140636, 1.693205174524337, 47.15587243437767, 71.4441767334938, 59.701264053583145, 46.67305514216423, 37.49023988842964, 38.48121911287308, 60.63297025859356, 64.53415632247925, 61.87611535191536, 8.956464249640703, 0.2979792089900002, 0.11354618254699744, 0.32028122164774686, 0.1809394478914328, 0.2546876866836101, 0.1828761416254565, 0.10830497238202952, 0.2131142362486571, 0.1087344012921676, 0.13877073564799502], [0.05797266538138501, 0.02647223878739169, 0.0688725066720508, 0.028268373462196905, 0.006533994774144958, 0.07846507709473372, 0.05085866039735265, 0.015120861862669699, 0.02152124732674565, 0.02106296185957035, 0.05345491932530422, 2.4478808976709843, 44.007118195295334, 49.24282304942608, 43.28313544392586, 25.57808429002762, 22.418407537043095, 27.314100936055183, 35.817755833268166, 42.95428588986397, 55.19388131797314, 26.672573760151863, 0.27410363545641303, 0.2341470427927561, 0.6194431765470654, 1.3121048617176712, 33.58705513179302, 57.232878506183624, 53.39077927172184, 51.52330867946148, 46.83274157345295, 43.797506242990494, 44.02110144495964, 41.02903559803963, 39.1190604865551, 38.70546407997608, 38.60749013721943, 37.494119480252266, 37.60787017643452, 36.304277926683426, 35.59728026390076, 37.37324796617031, 36.48826785385609, 36.86762049794197, 35.8227601647377, 35.22894702851772, 36.05914168059826, 35.56638792157173, 33.369102627038956, 34.68384347856045, 33.16981092095375, 36.36756733059883, 35.89980103075504, 38.70615944266319, 38.50740730762482, 38.9343485981226, 39.04959261417389, 38.33186812698841, 36.52332477271557, 36.40089154243469, 36.45145162940025, 36.55012473464012, 36.19579754769802, 36.67092025279999, 36.457823887467384, 36.693084463477135, 36.75541251897812, 34.48363222181797, 36.46057493984699, 37.9660427570343, 35.526927039027214, 36.13473862409592, 36.92537359893322, 35.55175110697746, 39.626561254262924, 49.07403610646725, 48.010815158486366, 52.504708617925644, 42.15542435646057, 55.780585035681725, 49.368600100278854, 48.0546610057354, 43.86889301240444, 43.021701872348785, 39.69415582716465, 48.08667428791523, 50.63423998653889, 54.45816099643707, 50.13173595070839, 50.29084101319313, 52.748818919062614, 49.006813913583755, 47.84157983958721, 43.89203757047653, 46.62168189883232, 46.428306475281715, 50.00664286315441, 51.968519389629364, 54.05614636838436, 52.245429530739784, 48.05581994354725, 51.95655383169651, 52.83106550574303, 42.28936716914177, 50.009720697999, 43.547745645046234, 37.649166360497475, 36.91073678433895, 38.40760186314583, 36.66511796414852, 37.1894746273756, 38.28416928648949, 38.397695794701576, 36.72177292406559, 38.441891223192215, 36.499336659908295, 37.48633369803429, 36.69621169567108, 36.39696255326271, 37.32841797173023, 36.174860671162605, 36.74102269113064, 36.99034631252289, 36.74886927008629, 36.96115627884865, 37.18015372753143, 36.71574644744396, 37.224402353167534, 38.43749865889549, 39.017731323838234, 38.719606921076775, 39.376827254891396, 40.78494429588318, 41.01712703704834, 38.92087832093239, 40.30558101832867, 40.86407504975796, 41.28623239696026, 42.45982222259045, 46.45982578396797, 46.94775000214577, 45.61977446079254, 44.91429291665554, 43.99553261697292, 46.00766524672508, 42.464511170983315, 47.48219892382622, 52.994532734155655, 59.30703140795231, 57.78807431459427, 69.58597004413605, 29.550242945551872, 0.0981435457651969, 0.1843735878355801, 0.21412446250906214, 0.6586160464212298, 39.924446269869804, 61.21269375085831, 52.98623777925968, 44.57575008273125, 27.55967415869236, 32.62770161032677, 43.441936522722244, 53.80322054028511, 36.93001314997673, 2.0256371051073074, 0.1604332248098217, 0.06710686313454062, 0.06683269151835702, 0.014821250351815252, 0.04603713474352844, 0.10264416676363908, 0.05889044601644855, 0.020802744475076906, 0.024682395669515245, 0.037541744313784875, 0.012318188473727787, 0.06604481270187534, 0.06786400961573236, 0.041504401015117764, 0.010930917796940776, 0.049402748481952585, 0.025296693565906025, 0.04608633171301335, 0.023707740547251888, 0.06597047919058241, 0.051687765517272055, 3.208115128800273, 50.2217873185873, 56.239022836089134, 50.4720912873745, 31.330443620681763, 29.338259920477867, 38.19585062563419, 44.465780183672905, 49.513786509633064, 58.951697275042534, 30.340919718146324, 0.17387552303262055, 0.1133321768429596, 0.6849461398087442, 1.2580697424709797, 36.765751764178276, 58.219719752669334, 57.074058428406715, 54.442779421806335, 50.01994974911213, 46.48789867758751, 45.469652116298676, 42.71877832710743, 41.27996653318405, 40.581803396344185, 41.15602858364582, 39.60066184401512, 39.74166847765446, 39.995673447847366, 36.80448688566685, 38.41290257871151, 38.90739284455776, 38.96994508802891, 37.77539558708668, 36.99863746762276, 38.22896584868431, 36.643459126353264, 35.09596936404705, 36.223327070474625, 34.637140184640884, 37.20614053308964, 37.25814834237099, 39.86745312809944, 39.455042257905006, 41.624022871255875, 40.83832003176212, 38.690306693315506, 38.17691624164581, 37.94433072209358, 37.16074436903, 37.451101988554, 38.31983797252178, 37.323265448212624, 38.4013208001852, 38.2511642575264, 37.0217402279377, 37.9217941313982, 36.45294114947319, 37.634400352835655, 37.57554531097412, 39.209826216101646, 37.95073337852955, 37.14636594057083, 40.879183039069176, 50.370902717113495, 49.4609921425581, 55.15815943479538, 44.04530234634876, 56.45936921238899, 51.599992364645004, 51.0598361492157, 47.56159566342831, 44.759960398077965, 43.45310032367706, 50.219165459275246, 53.340276181697845, 55.020717009902, 51.51837274432182, 52.91566036641598, 53.14877785742283, 52.64022834599018, 49.88863259553909, 47.60090835392475, 46.75705723464489, 49.13722291588783, 53.62632863223553, 53.812708631157875, 54.92735981941223, 53.43220844864845, 49.823352098464966, 51.040677577257156, 57.325046360492706, 44.34236280620098, 52.013676166534424, 44.52997773885727, 38.20329822599888, 38.51966544985771, 40.308871641755104, 38.672170266509056, 38.57322737574577, 38.89025196433067, 41.37273855507374, 39.298680648207664, 39.11457672715187, 37.12175466120243, 38.35846669971943, 39.38259914517403, 39.14373256266117, 38.818865194916725, 38.29189047217369, 38.59579436480999, 38.001263067126274, 38.83814916014671, 38.88077147305012, 40.10331027209759, 38.34975376725197, 38.88992138206959, 40.9195938706398, 40.34975744783878, 40.066212862730026, 42.132412791252136, 42.6052176207304, 41.60570785403252, 43.202499970793724, 42.486549988389015, 42.82557159662247, 43.31602267920971, 45.23120351135731, 48.241519778966904, 49.13422107696533, 47.007224410772324, 45.91027647256851, 45.427497178316116, 47.661762088537216, 46.32272534072399, 49.958324655890465, 55.55892772972584, 61.36345066130161, 60.8638496696949, 72.49880254268646, 31.882960572838783, 0.265265695634298, 0.5048438196536154, 0.11212491037440486, 0.764252693625167, 44.67736043035984, 67.4928143620491, 56.9401004165411, 44.800014048814774, 25.4758944734931, 32.80232883989811, 48.975883573293686, 61.57711699604988, 45.958617478609085, 3.433555606752634, 0.0387599908572156, 0.007530604016210418, 0.05584260507021099, 0.0873780925758183, 0.04586596209264826, 0.03295461487141438, 0.02575076177890878, 0.02945562606328167, 0.031744023581268266, 0.06890173986903392, 0.07788364149746485, 0.12530166073702276, 0.20619937917217612, 0.1787067114491947, 0.14213039365131408, 0.16427566471975297, 0.13045001338468865, 0.2039468867587857, 0.13964691519504413, 0.2003176510334015, 0.11051379682612605, 3.552887965925038, 58.90344746410847, 63.0985401570797, 56.29261516034603, 38.282280787825584, 33.47920171916485, 37.27627716958523, 48.465392366051674, 54.7169005125761, 63.86273235082626, 33.37811954319477, 0.32061981910374016, 0.33095294900704175, 1.5731656970456243, 1.7952636606059968, 40.195569321513176, 60.58011509478092, 60.38788340985775, 55.76472848653793, 51.133426800370216, 49.504723995923996, 48.776158690452576, 45.04052214324474, 44.91200543940067, 44.43139582872391, 44.16105553507805, 41.87466122210026, 42.1672797203064, 41.80736303329468, 39.98905420303345, 41.68231554329395, 42.09765985608101, 41.56195320188999, 39.6183954924345, 38.934888169169426, 39.85451102256775, 39.8049882799387, 37.10605010390282, 39.174966886639595, 37.069389671087265, 41.45085096359253, 40.92201814055443, 42.278233766555786, 43.285764902830124, 44.98845733702183, 43.56748178601265, 42.0369429141283, 41.4822942763567, 39.86242599785328, 39.49826493859291, 39.21918511390686, 38.11759002506733, 39.493602588772774, 41.36105798184872, 39.18240688741207, 40.74308954179287, 38.09799067676067, 38.63429769873619, 40.77800586819649, 38.198081105947495, 39.870800748467445, 39.47066701948643, 39.802704602479935, 43.510538041591644, 53.337042555212975, 52.28674091398716, 53.649161607027054, 42.75195434689522, 60.46702556312084, 52.983403131365776, 53.7152324616909, 47.88903169333935, 47.40258939564228, 45.14648325741291, 52.98089146614075, 56.220673620700836, 57.60753460228443, 54.00597006082535, 56.141026094555855, 54.83079180121422, 54.01281729340553, 51.43846683204174, 50.221137553453445, 49.39006134867668, 51.45191431045532, 54.57150511443615, 55.42776636779308, 57.56121128797531, 55.445731803774834, 52.55012758076191, 52.884281650185585, 54.93060864508152, 49.45563443005085, 54.498853012919426, 46.4980935305357, 41.03144086897373, 40.15356257557869, 42.41354450583458, 40.28345100581646, 40.822816863656044, 41.78946979343891, 42.51412890851498, 40.95126897096634, 41.27020105719566, 39.09594252705574, 41.67115934193134, 41.07220508158207, 41.167446970939636, 40.277074947953224, 41.56789608299732, 41.08179196715355, 41.36772282421589, 40.94822533428669, 40.82488775253296, 41.56948059797287, 40.93996077775955, 41.093924716115, 43.82985010743141, 41.876545920968056, 42.16276556253433, 44.521682783961296, 44.06056992709637, 44.081449806690216, 43.36556062102318, 44.47988122701645, 44.306025356054306, 45.43364904820919, 47.71437406539917, 50.76128236949444, 51.91731333732605, 50.94481632113457, 48.47257778048515, 49.32064667344093, 51.430084481835365, 48.79253961145878, 53.273973539471626, 57.701701149344444, 63.53906951844692, 63.4567279368639, 74.66008096933365, 33.899785950779915, 0.7035473291762173, 1.6091443039476871, 0.3033234440954402, 0.8655355463270098, 50.167191848158836, 72.3461951315403, 66.39817669987679, 59.9485319852829, 39.407499209046364, 43.66124175488949, 58.616038486361504, 68.82010594010353, 57.86366745829582, 6.486651403829455, 0.5576297559309751, 0.08547605713829398, 0.15715380781330168, 0.1902884157607332, 0.1668914977926761, 0.18213190109236166, 0.10357983686844818, 0.11624688762822188, 0.0490731792524457, 0.11249740171479061], [0.03817206517851446, 0.03265239007305354, 0.08321359768160619, 0.008746510011405917, 0.042376869823783636, 0.008057519589783624, 0.06186517057358287, 0.024148533593688626, 0.028045250473951455, 0.016593334803474136, 0.023572905301989522, 0.6324060028418899, 31.66074849665165, 54.46681693196297, 45.18701948225498, 35.02222292125225, 24.70334842801094, 30.641018114984035, 34.373343139886856, 43.21514189243317, 56.051647290587425, 29.77514337748289, 0.20105495990719646, 0.07393692241748795, 0.37903331278357655, 2.315088235773146, 30.934316776692867, 59.08804915845394, 54.250068962574005, 51.61330305039883, 50.891296193003654, 45.31150460243225, 40.211467668414116, 37.858702316880226, 36.00437141954899, 36.76048904657364, 36.48614376783371, 37.9980294406414, 36.7323287576437, 37.70084738731384, 37.33154520392418, 38.89247104525566, 37.5496307015419, 36.38372786343098, 34.172915294766426, 36.640305295586586, 41.64943590760231, 42.195018231868744, 40.83663672208786, 42.5765747576952, 39.89247478544712, 38.99022839963436, 38.49476918578148, 38.18435624241829, 38.41279998421669, 38.78040745854378, 38.263373002409935, 39.59426298737526, 35.90211510658264, 34.95063096284866, 35.99979646503925, 36.456623151898384, 36.26718811690807, 35.30083157122135, 37.15518906712532, 36.2285365909338, 35.51507547497749, 35.59655450284481, 37.69383296370506, 36.645697206258774, 35.512153431773186, 35.37940755486488, 36.280137822031975, 36.23559661209583, 39.768996611237526, 50.38457818329334, 49.53197233378887, 38.04243765771389, 39.859522953629494, 51.53588980436325, 49.96274381875992, 49.648287892341614, 43.38854178786278, 41.65653772652149, 38.12789507210255, 44.10885013639927, 49.0486154705286, 54.38698701560497, 50.88237427175045, 49.012395814061165, 51.626917719841, 50.085203647613525, 43.79407122731209, 45.06030388176441, 48.83285164833069, 49.46160390973091, 49.189610704779625, 50.70596493780613, 50.32893396914005, 53.466904386878014, 57.2343984246254, 53.62114191055298, 42.5790636241436, 49.44584235548973, 45.51802732050419, 37.89093978703022, 37.38134913146496, 37.030107378959656, 38.60279358923435, 37.13569611310959, 37.48998910188675, 37.919970229268074, 37.860579416155815, 38.217547461390495, 37.783591747283936, 37.497892677783966, 37.341120690107346, 36.488351449370384, 37.120918706059456, 35.50613835453987, 38.305185958743095, 36.76389366388321, 37.361829578876495, 39.06002305448055, 42.080993950366974, 40.2328909188509, 40.31234085559845, 38.41105967760086, 38.433615267276764, 39.375387132167816, 40.18179506063461, 37.856274247169495, 39.078205078840256, 39.03815142810345, 39.23516325652599, 39.670148715376854, 41.883191764354706, 40.522727966308594, 46.816976219415665, 52.701158076524734, 53.96152384579182, 53.674228861927986, 53.64560879766941, 50.97002416849136, 50.605931505560875, 47.12998442351818, 48.40012326836586, 55.13986721634865, 60.80504782497883, 58.306518495082855, 66.52609303593636, 25.888183750212193, 0.10606247669784352, 0.3256470087217167, 0.10595841275062412, 0.5485039518680423, 36.195542961359024, 60.84677718579769, 48.984243124723434, 42.231446877121925, 31.11342016607523, 33.89432184398174, 41.82943984866142, 49.96891848742962, 39.46418076753616, 2.0759872533380985, 0.22578109405003488, 0.024057850569079164, 0.03703636029968038, 0.08161636229488067, 0.09347772269393317, 0.06153200192784425, 0.02286418210132979, 0.022376318338501733, 0.0751002314791549, 0.042486151069169864, 0.1219336832582485, 0.027630824079096783, 0.05809169844724238, 0.024742492933000904, 0.05097571192891337, 0.0472652444295818, 0.05621189033263363, 0.037058179441373795, 0.019686428204295225, 0.019008142335223965, 0.05209778726566583, 0.628419304266572, 36.58759452402592, 61.65704570710659, 51.37251757085323, 38.581556528806686, 25.629791915416718, 32.649387046694756, 42.60731890797615, 49.02857914566994, 59.342434108257294, 31.844839118421078, 0.09964974931790493, 0.06351811156491749, 0.43281227233819664, 2.754484307952225, 33.87678578495979, 59.96495470404625, 56.13192178308964, 54.126362800598145, 53.950538635253906, 47.85556308925152, 43.78953047096729, 40.475857481360435, 37.39084102213383, 39.06065382063389, 38.6215265840292, 39.857904240489006, 38.349373787641525, 40.19317924976349, 37.778944596648216, 40.856106877326965, 38.24824221432209, 37.67346225678921, 36.15370340645313, 37.690112963318825, 42.605445608496666, 43.90122547745705, 41.871647983789444, 42.74579107761383, 41.21567778289318, 40.10524816811085, 41.34168662130833, 39.60317350924015, 39.46233406662941, 40.917298793792725, 40.6565909832716, 41.28425270318985, 38.82142625749111, 37.60332562029362, 38.0759746581316, 37.81182803213596, 37.9598680883646, 37.50516168773174, 37.79531791806221, 37.54827417433262, 35.551933497190475, 37.49438166618347, 38.633324950933456, 37.51260168850422, 37.93921239674091, 38.02832901477814, 38.7336091697216, 37.23571814596653, 41.45737521350384, 53.31889472901821, 50.77279955148697, 42.167887687683105, 41.740482822060585, 53.56523551046848, 51.590595468878746, 51.29705362021923, 43.967167139053345, 43.60452599823475, 40.21616421639919, 46.94764740765095, 51.98960825800896, 55.02940334379673, 51.847473084926605, 52.118603736162186, 55.33442057669163, 51.44917845726013, 45.0000087171793, 46.36510826647282, 48.336404487490654, 51.71553656458855, 51.859100461006165, 52.520728558301926, 52.60117024183273, 52.754222229123116, 56.155963093042374, 57.45146557688713, 45.62344126403332, 51.75167262554169, 48.67905110120773, 39.543056935071945, 39.92305934429169, 38.69022689759731, 40.22130914032459, 38.2675451785326, 41.11136198043823, 39.016154408454895, 39.00668911635876, 38.93158234655857, 39.97034780681133, 38.996190279722214, 39.212774857878685, 38.896145448088646, 38.406123742461205, 37.99482241272926, 39.256901890039444, 39.17916566133499, 39.45696495473385, 40.48856399953365, 43.4273225069046, 41.77056200802326, 42.35431708395481, 40.30874244868755, 39.96062032878399, 40.59361696243286, 42.05224849283695, 41.46177537739277, 40.27434669435024, 42.35014110803604, 40.352022126317024, 40.822379887104034, 43.804015293717384, 41.91745072603226, 49.045085459947586, 55.23510530591011, 55.610589757561684, 55.45130230486393, 56.84806935489178, 53.27442191541195, 52.673392966389656, 47.87885583937168, 51.39271728694439, 57.16844916343689, 61.7995760589838, 60.05836509168148, 67.87829607725143, 28.713050968945026, 0.23586794966831803, 0.4593097645556554, 0.10139687627088279, 0.575878870440647, 40.236489325761795, 66.9239316880703, 54.59900423884392, 46.91134035587311, 38.881816416978836, 41.700231581926346, 48.70347999036312, 57.88436874747276, 46.984003856778145, 3.503890782594681, 0.10777672650874592, 0.04796396904566791, 0.05714071783586405, 0.026982973686244804, 0.026770556178234983, 0.01299060209930758, 0.02935042848548619, 0.049151958228321746, 0.10249162573018111, 0.03410646888369229, 0.2557229530066252, 0.09047068873769604, 0.1256780928815715, 0.07143060065573081, 0.11911781170056202, 0.15797437081346288, 0.24508514179615304, 0.1133942352316808, 0.11450808757217601, 0.11714052991010249, 0.11861894745379686, 1.0739819705486298, 43.497641533613205, 70.04845082759857, 58.74309226870537, 48.38226042687893, 35.183843448758125, 39.770033955574036, 47.49814286828041, 56.071079447865486, 63.971398919820786, 36.49980403482914, 0.24579769262345508, 0.19134790578391403, 0.8239212480839342, 3.454087805002928, 37.57495254278183, 62.11519092321396, 60.903033167123795, 56.30402214825153, 57.14422546327114, 50.50377398729324, 46.80955521762371, 41.50206461548805, 38.38475748896599, 41.050120666623116, 41.188102662563324, 43.565540090203285, 40.33401869237423, 41.56674474477768, 41.52466960251331, 42.871712520718575, 40.22715322673321, 39.20256860554218, 37.95546032488346, 41.01518914103508, 45.558403953909874, 47.30408728122711, 44.44071672856808, 46.41102120280266, 43.08058351278305, 42.25487641990185, 42.73415230214596, 42.45066471397877, 41.87637872993946, 43.5912761092186, 42.38403528928757, 44.63002257049084, 40.950562208890915, 40.22201210260391, 41.11169636249542, 40.64891539514065, 39.77987542748451, 38.48436914384365, 40.82733482122421, 37.28463292121887, 37.97019973397255, 38.77331703901291, 40.133879631757736, 38.44054989516735, 38.530962243676186, 39.790853038430214, 40.31056635081768, 40.6766577064991, 43.28073017299175, 57.307647094130516, 54.01886656880379, 44.10788118839264, 42.36397236585617, 52.94231213629246, 54.76590648293495, 53.64750109612942, 46.098624765872955, 44.38934728503227, 43.154257759451866, 48.593567088246346, 53.7364961206913, 57.27336913347244, 55.06963938474655, 53.58228899538517, 56.26450426876545, 54.04598571360111, 46.69161714613438, 48.0051838606596, 50.91074354946613, 53.1211381405592, 53.037991002202034, 55.60835927724838, 56.09482057392597, 56.714012548327446, 56.19623713195324, 55.07983423769474, 49.06115099787712, 53.40636223554611, 47.85963647067547, 42.600342482328415, 42.972137331962585, 41.25237241387367, 41.931829154491425, 41.526763290166855, 42.72961534559727, 41.34799048304558, 40.87851047515869, 40.77191099524498, 42.68689423799515, 42.591621950268745, 41.77466958761215, 42.180620804429054, 40.666345059871674, 38.80591168999672, 42.38951839506626, 42.73533783853054, 40.808780416846275, 43.54595594108105, 47.29342885315418, 43.456189557909966, 45.281220227479935, 42.192635759711266, 43.28436277806759, 43.14409330487251, 44.18180622160435, 43.630539402365685, 42.85881221294403, 43.57315868139267, 43.17352272570133, 43.3092400431633, 45.440640673041344, 44.638157933950424, 51.002303436398506, 57.547262236475945, 58.60433891415596, 58.773581832647324, 60.245041474699974, 55.90254329144955, 56.14307038486004, 51.21780887246132, 52.23751075565815, 60.80071225762367, 67.37714096903801, 63.771681636571884, 70.70149898529053, 31.68452762067318, 0.5066660593729466, 1.5050940122455359, 0.39698889304418117, 0.5984219326637685, 44.79025237262249, 71.08072623610497, 62.175068110227585, 56.96433551609516, 45.75912058353424, 44.816094785928726, 59.37036640942097, 67.90961399674416, 61.8417651951313, 6.024273214861751, 0.24407959106611088, 0.11205654373043217, 0.1321474980795756, 0.1568230177508667, 0.11760892899474129, 0.10220538679277524, 0.1146969864203129, 0.18415628699585795, 0.18084662006003782, 0.15136348258238286], [0.030980861993157305, 0.02155546775611583, 0.06103064035414718, 0.04650285467505455, 0.05029031257436145, 0.031001567913335748, 0.06580575951375067, 0.06423904123948887, 0.023435058792529162, 0.006422770957215107, 0.1972108130576089, 0.03774380144022871, 21.834319978952408, 55.2222353965044, 48.77545192837715, 29.42232470959425, 23.61834704875946, 32.22336910665035, 34.567596316337585, 43.53164590895176, 53.72668504714966, 35.160596296191216, 0.30551752948667854, 0.16799844073830172, 0.1377203146694228, 0.4962575272656977, 22.354508265852928, 58.77877235412598, 51.05277992784977, 52.697384878993034, 48.35900567471981, 43.03366743028164, 38.27588193118572, 41.10313922166824, 41.339900717139244, 42.91811183094978, 41.57397575676441, 42.92446129024029, 40.20617075264454, 38.54866549372673, 39.61604341864586, 39.01023432612419, 35.07904887199402, 38.069564402103424, 42.649530842900276, 51.38591565191746, 50.5267171561718, 48.2707554101944, 50.06055437028408, 49.696370512247086, 48.41827109456062, 44.52780045568943, 43.379612267017365, 41.07255086302757, 42.02617049217224, 42.39014156162739, 40.65271899104118, 40.58615796267986, 37.5163558870554, 35.48617422580719, 36.81918449699879, 36.48279994726181, 35.518901869654655, 34.961737766861916, 35.81947334110737, 37.16772459447384, 37.18370273709297, 37.057496309280396, 37.18288958072662, 38.054935187101364, 37.3088414222002, 37.90555380284786, 35.219850316643715, 35.65835438668728, 36.026680022478104, 48.96497815847397, 52.60672554373741, 49.51183341443539, 47.72581905126572, 50.30747652053833, 50.627343356609344, 47.211957424879074, 46.15754820406437, 42.21841357648373, 39.87450174987316, 40.96073046326637, 48.55566792190075, 53.70748847723007, 49.97702345252037, 49.51182201504707, 52.10442669689655, 47.717011123895645, 47.238704189658165, 48.477946892380714, 50.486720502376556, 53.919555097818375, 55.12113802134991, 56.1888275295496, 56.78378440439701, 51.38849951326847, 47.917970940470695, 39.96323078870773, 49.990155547857285, 48.10172148048878, 40.64310170710087, 35.129399970173836, 36.60643391311169, 36.75594449043274, 38.00776071846485, 36.87503769993782, 37.025433629751205, 35.3341443836689, 36.36097468435764, 36.43826253712177, 37.23240092396736, 35.07952004671097, 36.23142823576927, 37.00057536363602, 37.91780434548855, 35.93587629497051, 37.116286754608154, 34.9378826469183, 42.16746211051941, 43.5418825596571, 45.06531961262226, 45.10429032146931, 43.646034970879555, 40.638340562582016, 38.6733254045248, 36.52254581451416, 39.243165627121925, 38.56906659901142, 38.98960143327713, 40.092811435461044, 41.40873782336712, 39.408494755625725, 39.57687892019749, 38.775087743997574, 46.71614482998848, 52.32276678085327, 54.108260571956635, 55.12411706149578, 55.463081672787666, 58.062715977430344, 56.46581366658211, 54.22990724444389, 53.3706783503294, 53.965775817632675, 57.67595753073692, 58.51554907858372, 69.18338924646378, 20.076285414397717, 0.2154431550297886, 0.052935775893274695, 0.15124873170861974, 0.6840368011035025, 36.950391456484795, 60.84066331386566, 51.98188707232475, 42.26746514439583, 15.225583501160145, 21.231256239116192, 43.048551231622696, 47.98320583999157, 45.682710483670235, 2.8413882572203875, 0.04054027325764764, 0.1257095896289684, 0.0777887727599591, 0.062466607050737366, 0.027987435314571485, 0.030391785985557362, 0.017826808361860458, 0.01944720803294331, 0.036129652507952414, 0.022808773355791345, 0.04564137336274143, 0.02165322901419131, 0.013635187970066909, 0.05704466537281405, 0.05180380401725415, 0.008069906962191453, 0.04759929623105563, 0.023384533378703054, 0.017265434871660545, 0.0685317198804114, 0.23847043892601505, 0.07373029366135597, 26.98145918548107, 61.794149950146675, 54.07789260149002, 35.64099691808224, 26.25269439071417, 31.417061872780323, 40.61512000858784, 50.024011731147766, 57.4503256380558, 39.21151712536812, 0.3369051218032837, 0.11865924607263878, 0.37707071809563786, 0.6113949115388095, 24.97057668864727, 60.51237232983112, 52.689188718795776, 56.041604429483414, 50.12407936155796, 45.435427352786064, 39.72645029425621, 42.50534377992153, 42.49554790556431, 44.86642308533192, 43.61489184200764, 44.71127361059189, 40.90173862874508, 39.59139794111252, 40.94075873494148, 41.728631258010864, 36.7512783408165, 39.70969699323177, 43.55227880179882, 51.99236311018467, 53.56181189417839, 50.50845913589001, 52.03136421740055, 51.24636434018612, 49.215251728892326, 46.11678019165993, 45.36423057317734, 43.17950740456581, 43.30056130886078, 44.89829197525978, 43.52605260908604, 42.52714321017265, 39.170764312148094, 37.684557661414146, 38.543721958994865, 37.23185755312443, 38.27718146145344, 37.836234122514725, 36.760682836174965, 39.12663348019123, 37.48758763074875, 37.50565566122532, 38.684637397527695, 38.28890383243561, 39.11068193614483, 39.0571466088295, 36.62755697965622, 36.76521599292755, 39.13130342960358, 50.27954421937466, 55.36443516612053, 49.66829761862755, 51.34983278810978, 51.02001428604126, 53.394309282302856, 51.56177781522274, 49.07139904797077, 43.13956394791603, 41.43433704972267, 43.1606338173151, 48.93674187362194, 55.693185925483704, 52.38257937133312, 51.36893056333065, 53.35020124912262, 51.00662760436535, 49.4534457474947, 51.13153450191021, 52.40746043622494, 54.6353454887867, 55.333972200751305, 55.04655562341213, 58.300807401537895, 53.80283676087856, 53.69110755622387, 41.75912082195282, 49.76893901824951, 50.08421950042248, 43.041270822286606, 36.221928745508194, 37.23833240568638, 38.17735321819782, 39.6594712883234, 39.56364043056965, 40.25654464960098, 38.20225328207016, 38.33629868924618, 37.988564148545265, 38.601269870996475, 38.81247393786907, 37.58192136883736, 37.37992040812969, 38.60973581671715, 37.74240955710411, 40.14419987797737, 37.59967401623726, 43.99426348507404, 45.25370590388775, 47.80301570892334, 47.088399454951286, 45.69030247628689, 42.39482671022415, 40.524460673332214, 38.76938045024872, 41.55860558152199, 40.31108692288399, 42.529229298233986, 42.60405868291855, 42.9819256067276, 40.74139103293419, 41.68663591146469, 40.982161313295364, 48.768380507826805, 55.182329937815666, 55.78552097082138, 59.04512666165829, 58.38732875883579, 60.53142070770264, 59.15451139211655, 56.3611900806427, 55.27938053011894, 57.37036652863026, 59.85682770609856, 61.880895495414734, 69.96543288230896, 21.549665853381157, 0.15854857047088444, 0.7827386423014104, 0.08236077352194116, 0.8603185450192541, 39.31685887277126, 67.38518133759499, 56.25577613711357, 48.689667731523514, 26.271043606102467, 27.180937081575394, 49.64848928153515, 55.25858424603939, 54.510662779212, 4.534254418686032, 0.09972263564122841, 0.045023427810519934, 0.08765552964177914, 0.023312057091970928, 0.09044204183737747, 0.031077680723683443, 0.034358877019258216, 0.035982017070637085, 0.02744988105405355, 0.050671680000959896, 0.1069493728573434, 0.079706393298693, 0.08571004887926392, 0.23332481738179922, 0.2592010726220906, 0.08564062096411362, 0.07221235675388016, 0.20578454830683768, 0.11163167902850546, 0.14243893412640318, 0.345619271392934, 0.12967298476723954, 30.59816211462021, 70.25709763169289, 62.986966744065285, 41.194303929805756, 34.18546602129936, 42.15802721679211, 46.52927465736866, 55.23710019886494, 63.41037042438984, 43.73362027108669, 0.5134061852004379, 0.25246115459594876, 0.5511018249671906, 0.6525810202583671, 27.83037543296814, 61.54118612408638, 54.508181512355804, 58.21052044630051, 52.65935651957989, 46.4793149381876, 42.92145565152168, 45.49689665436745, 45.72247534990311, 48.432790115475655, 47.721411287784576, 48.049470484256744, 43.542737513780594, 42.127849236130714, 43.388591185212135, 43.004173412919044, 39.157157242298126, 43.17198000848293, 46.50729663670063, 55.072652623057365, 55.98042391240597, 50.7028529047966, 53.251832127571106, 51.97171501815319, 52.39333659410477, 48.71095798909664, 48.52321766316891, 44.763699397444725, 45.46488717198372, 48.39042238891125, 46.02748118340969, 45.11373281478882, 41.35568507015705, 40.340292155742645, 42.57697753608227, 40.81738315522671, 40.481937155127525, 39.43203069269657, 39.336317628622055, 40.75770355761051, 39.983453303575516, 40.59349536895752, 40.73752284049988, 40.34037575125694, 41.386938393116, 41.28744073212147, 38.14916253089905, 39.09319907426834, 41.08459621667862, 53.70010167360306, 57.913175001740456, 53.97247485816479, 51.09543263912201, 53.890555053949356, 54.232008531689644, 52.32947342097759, 51.398861557245255, 45.82495205104351, 44.2748062312603, 45.26156768202782, 51.259044259786606, 56.8550343811512, 53.17109405994415, 53.6462015658617, 56.77515886723995, 52.33996465802193, 52.7446049451828, 52.731248661875725, 55.020986795425415, 56.91714204847813, 58.2279197126627, 57.01686769723892, 59.39668379724026, 49.96487930417061, 53.288617953658104, 47.999442368745804, 52.41762489080429, 51.55546635389328, 45.678481310606, 38.48935067653656, 40.367373302578926, 40.15210345387459, 41.766602620482445, 41.63581743836403, 41.425019949674606, 39.16788786649704, 40.10734565556049, 40.0221998244524, 41.53644897043705, 38.88093866407871, 39.14134629070759, 40.35650588572025, 40.825723707675934, 39.748793095350266, 40.987625420093536, 39.3978401273489, 47.538553699851036, 48.62840361893177, 50.05086109042168, 49.67305116355419, 48.88455167412758, 45.003238543868065, 42.01958544552326, 40.637181624770164, 42.92697295546532, 43.08892026543617, 44.46555219590664, 45.32505087554455, 47.060683742165565, 42.94780343770981, 43.95740166306496, 42.829584181308746, 51.332866698503494, 56.695556938648224, 58.666222393512726, 61.75660036504269, 61.6828653216362, 62.48827010393143, 61.9541821628809, 59.70321714878082, 58.79256561398506, 59.93470072746277, 62.559151500463486, 65.59754446148872, 72.87429079413414, 24.04024600982666, 0.6870334746781737, 1.7611323483288288, 0.34380374068859965, 1.0309814591892064, 44.2368158698082, 73.58466267585754, 66.00308910012245, 57.085009440779686, 25.20565677434206, 30.95035381615162, 58.069681003689766, 63.83427947759628, 66.17314517498016, 7.619551587849855, 0.13067702151602134, 0.1566407165955752, 0.26335525908507407, 0.14418640988878906, 0.15593135700328276, 0.11566795306862332, 0.13219257612945512, 0.0971705382107757, 0.18521022575441748, 0.12036510961479507], [0.03421236964641139, 0.0066454797342885286, 0.02670576111995615, 0.03025430312845856, 0.05423230417363811, 0.08915356214856729, 0.06169507403683383, 0.024577235199103598, 0.047018498880788684, 0.04320961517805699, 0.14617671637097374, 0.057791429208009504, 10.068822260946035, 54.26612310111523, 47.44276084005833, 43.23671333491802, 29.5365047827363, 24.725056663155556, 29.427978806197643, 44.17033463716507, 51.589565724134445, 42.65100136399269, 1.0643136268481612, 0.1514402503380552, 0.2434696941054426, 0.2977918612305075, 17.55797054618597, 52.01165087521076, 53.73437203466892, 52.22838744521141, 48.65629032254219, 43.57983112335205, 45.200322568416595, 49.20780412852764, 49.94851738214493, 52.5381164252758, 49.886284321546555, 52.477912455797195, 47.04865358769894, 41.23691104352474, 38.232340067625046, 34.974402487277985, 40.09493552148342, 48.5870124399662, 51.16287901997566, 44.51271906495094, 45.44308394193649, 45.511670261621475, 42.23617382347584, 44.94009733200073, 47.48592272400856, 48.51432614028454, 47.81720794737339, 46.69137015938759, 48.08754824101925, 47.272009402513504, 45.72104662656784, 43.66368882358074, 38.50850164890289, 34.58825960755348, 34.918792471289635, 36.48260235786438, 35.61555728316307, 34.61055301129818, 36.68798893690109, 37.48952552676201, 34.56456407904625, 36.12082377076149, 38.77799838781357, 37.499401196837425, 36.305691450834274, 37.14794285595417, 35.686339884996414, 37.62991659343243, 36.941036358475685, 43.52072909474373, 49.30762857198715, 52.0607328414917, 50.47261565923691, 49.517677500844, 51.61488376557827, 49.86712954938412, 46.30397714674473, 43.194577395915985, 39.25888158380985, 41.196515411138535, 47.72942505776882, 51.413095593452454, 50.56811213493347, 50.14813207089901, 54.71886120736599, 48.97442825138569, 49.350000098347664, 53.46687778830528, 54.610038846731186, 51.067447140812874, 47.87594899535179, 45.06995916366577, 41.60874389111996, 40.762757286429405, 44.09835509955883, 53.05563725531101, 50.06579428911209, 42.59665288031101, 36.024065762758255, 37.22920149564743, 35.861909464001656, 37.26361624896526, 36.35764606297016, 35.88797986507416, 37.2013033926487, 35.576578974723816, 35.278564766049385, 38.015147522091866, 37.11256295442581, 37.24630817770958, 36.541012823581696, 36.53782479465008, 37.09143988788128, 36.30978383123875, 37.608341351151466, 41.4221853017807, 47.26253651082516, 48.05807322263718, 53.97972106933594, 50.68668857216835, 49.55676980316639, 49.680445566773415, 43.30951362848282, 39.27001878619194, 38.86312521994114, 36.2753576785326, 38.73021215200424, 38.074340745806694, 39.702933356165886, 40.597101375460625, 39.8289991915226, 38.79279099404812, 39.60286192595959, 46.89818166196346, 54.72988061606884, 54.369135573506355, 58.02514359354973, 57.095546275377274, 56.840959936380386, 55.91191738843918, 58.28703314065933, 57.85211607813835, 63.331570252776146, 59.91831600666046, 57.5349584966898, 12.812661677598953, 0.10623082547681406, 0.3196478134486824, 0.050204809740534984, 0.7380386721342802, 35.89406333863735, 58.19822810590267, 51.33685648441315, 40.00731222331524, 30.15559036284685, 30.710149705410004, 37.220990136265755, 44.32089015841484, 37.361700385808945, 2.4476398481056094, 0.12760978454025462, 0.01924036962009268, 0.034445092314854264, 0.03468506947683636, 0.033591229148441926, 0.054070052137831226, 0.03721669847436715, 0.04177485818217974, 0.007643380313311354, 0.023821396753191948, 0.01897600548545597, 0.022636782487097662, 0.04270567835192196, 0.03001573604706209, 0.055994808426476084, 0.08879013985279016, 0.058032775632455014, 0.05212327632762026, 0.046758242533542216, 0.04169689927948639, 0.11824117944343016, 0.06664339191047475, 13.827781956642866, 61.49898938834667, 52.76990018785, 47.0058336853981, 30.90987838804722, 27.53123078495264, 36.17321535944939, 49.74007576704025, 56.88331626355648, 45.06815046072006, 0.8948375552427024, 0.24352716602152213, 0.43036042421590537, 0.4644243197981268, 18.124187663197517, 54.216102585196495, 55.69880202412605, 54.945781230926514, 50.39773307740688, 46.201990619301796, 46.38965114951134, 50.88511012494564, 52.43810959160328, 54.19674642384052, 51.45725302398205, 54.03772495687008, 47.96310871839523, 41.524722799658775, 40.64571596682072, 37.52281554043293, 41.66183844208717, 49.900674149394035, 53.94242227077484, 45.60675635933876, 45.31158819794655, 45.37605933845043, 43.384593799710274, 46.2154570966959, 49.240451976656914, 49.69266191124916, 50.43565884232521, 49.20235142111778, 50.18443912267685, 49.54639256000519, 47.57856175303459, 45.18519937992096, 39.1031089425087, 36.28886975347996, 37.49436266720295, 38.1641261279583, 37.659182623028755, 36.802769377827644, 39.95997816324234, 38.77319164574146, 36.93952023983002, 37.65018850564957, 40.494088903069496, 38.62707428634167, 38.384419307112694, 37.24995598196983, 38.37145060300827, 39.88895997405052, 38.50869543850422, 45.112794265151024, 50.834572836756706, 54.09168966114521, 51.781854405999184, 52.04708397388458, 52.44142301380634, 50.904648676514626, 49.81169432401657, 44.77369666099548, 40.73739364743233, 42.52961687743664, 48.66295516490936, 52.53896377980709, 52.516465187072754, 52.498647943139076, 55.70808492600918, 50.86275972425938, 50.42906619608402, 54.40966039896011, 56.096401289105415, 53.177458718419075, 51.346287578344345, 49.40435618162155, 46.6922365128994, 45.189234763383865, 45.05666367709637, 53.33796590566635, 53.04324612021446, 43.7626127153635, 37.98030339181423, 37.4563305079937, 37.72404134273529, 38.3084461838007, 39.122092723846436, 38.87578994035721, 38.521690741181374, 37.597432136535645, 38.54087591171265, 39.08106632530689, 39.10403989255428, 39.446808099746704, 38.601079881191254, 39.15345624089241, 38.14830757677555, 39.57427605986595, 41.012586280703545, 43.11894625425339, 48.43487240374088, 50.87798550724983, 55.763710141181946, 52.465126141905785, 53.46022814512253, 51.68021745979786, 46.1350192129612, 39.73276175558567, 39.929454401135445, 38.77254568040371, 40.48785723745823, 41.44558444619179, 43.1594330817461, 41.849061995744705, 41.79714918136597, 40.72813354432583, 42.31612153351307, 48.4997995197773, 56.93602703511715, 56.65174908936024, 59.75109077990055, 58.78832124173641, 59.292493388056755, 60.113234147429466, 61.53961680829525, 59.74321000277996, 64.5379713177681, 62.51581482589245, 59.37971010804176, 14.064787589013577, 0.35727490845602006, 0.9187870169989765, 0.11287834611721337, 0.7300038251560181, 39.202671200037, 65.42923629283905, 57.50967085361481, 48.40705029666424, 25.012735426425934, 30.83334669470787, 46.65988124907017, 50.93337893486023, 47.02988259494305, 4.012834997847676, 0.09530971423373558, 0.04694058821769431, 0.009958881528291386, 0.029012968370807357, 0.030328612519952003, 0.032826861570356414, 0.022999995126156136, 0.01883960245322669, 0.09681263007223606, 0.05353349421056919, 0.12289906895603053, 0.14788260217756033, 0.13835073943482712, 0.07045607912004925, 0.24172374716727063, 0.1681080856360495, 0.23332311044214293, 0.1728213467868045, 0.10320353088900447, 0.09740607361891307, 0.29482398298569024, 0.20247881475370377, 16.03042781352997, 68.9444200694561, 59.818202778697014, 55.58542750775814, 40.71474306285381, 34.071050360798836, 42.111719101667404, 56.54644913971424, 60.79405881464481, 51.40291213989258, 1.2290333630517125, 0.2917115343734622, 0.847416277974844, 1.025974634103477, 20.659088641405106, 54.854871109128, 56.752086505293846, 56.817781180143356, 54.59412910044193, 49.34810779988766, 49.70681615173817, 53.553995713591576, 54.676117300987244, 57.10135616362095, 53.2942758500576, 58.556271493434906, 50.59912987053394, 44.35481853783131, 41.997045055031776, 39.35767248272896, 44.785008653998375, 52.61782854795456, 54.12312537431717, 44.71847042441368, 45.35842448472977, 45.35860687494278, 43.232556357979774, 46.36626340448856, 51.5436489880085, 51.59102864563465, 52.30246067047119, 52.138104289770126, 53.73107761144638, 50.69931149482727, 48.80211889743805, 48.72354671359062, 42.40304186940193, 38.63204061985016, 39.985220208764076, 40.556945130228996, 38.80061097443104, 39.142364636063576, 41.087731048464775, 41.41209304332733, 37.57944390177727, 39.398109912872314, 42.87266626954079, 41.252554804086685, 41.40213757753372, 39.50187474489212, 39.648824259638786, 41.63804031908512, 40.47206528484821, 47.24245838820934, 53.62786754965782, 57.727950140833855, 52.67167925834656, 52.946039736270905, 55.16428850591183, 52.348487600684166, 51.1588816344738, 47.066866010427475, 42.927090749144554, 45.81519037485123, 51.78397089242935, 54.40725512802601, 54.43009950220585, 54.39825341105461, 57.97415032982826, 52.50230334699154, 52.923263758420944, 56.83497525751591, 56.33548066020012, 53.80983978509903, 49.76607397198677, 48.86132352054119, 45.66659554839134, 48.026291728019714, 50.74639476835728, 56.67946480214596, 54.23352085053921, 46.49359457194805, 38.60375873744488, 40.03400199115276, 39.17836770415306, 40.755545273423195, 41.476237401366234, 40.91045916080475, 40.561736673116684, 38.73555086553097, 40.731405168771744, 40.257156416773796, 41.78400568664074, 41.69979840517044, 40.89728906750679, 42.246703058481216, 40.83749167621136, 41.82192765176296, 42.259580567479134, 45.74527032673359, 51.83619149029255, 54.314589500427246, 57.15507388114929, 55.93618668615818, 54.75077569484711, 54.64976191520691, 49.30131331086159, 42.2288516163826, 43.669684901833534, 40.143379122018814, 42.98422448337078, 43.14370572566986, 44.35371279716492, 44.99395564198494, 44.987503588199615, 41.768901497125626, 45.62178835272789, 50.67865580320358, 60.60346484184265, 57.714479863643646, 63.59674662351608, 61.61489076912403, 59.91273410618305, 62.224400863051414, 63.30994941294193, 62.561267986893654, 69.63133201003075, 64.75899025797844, 62.43511475622654, 16.928239837288857, 0.5529061937704682, 2.762157521210611, 0.36730120482388884, 0.7971991819795221, 43.6182052642107, 69.42237362265587, 64.93299052119255, 54.91179585456848, 43.135433569550514, 43.97683002054691, 50.44925831258297, 60.502074882388115, 57.45523117482662, 7.5102784764021635, 0.3180589940166101, 0.10483966223546304, 0.1901107159210369, 0.1283591755782254, 0.129985295352526, 0.14493629074422643, 0.14076481224037707, 0.07518595695728436, 0.15013635624200106, 0.07763868823531084], [0.00879090157468454, 0.04724608959804755, 0.05532653412956279, 0.010154767696803901, 0.021154884270799812, 0.022928979014977813, 0.04974674877303187, 0.04210141058138106, 0.0617934791080188, 0.05907022758037783, 0.07375826520728879, 0.10746212268713862, 3.241950888186693, 47.75021754205227, 49.49950307607651, 46.82981953024864, 26.920200772583485, 24.112375639379025, 31.420236602425575, 44.10111375153065, 50.534388944506645, 48.545674458146095, 3.736727563664317, 0.2779740543337539, 0.18216696014860645, 0.12999734783079475, 7.877239510416985, 49.35587838292122, 54.106828048825264, 51.95633344352245, 50.332767963409424, 49.78794939815998, 50.09265124797821, 51.11125499010086, 53.15015718340874, 53.82384963333607, 53.508975729346275, 49.748336523771286, 47.63957507908344, 38.26895110309124, 35.22884823381901, 40.3265330940485, 49.48607839643955, 50.91478653252125, 44.560338109731674, 40.67707948386669, 46.4705716073513, 48.5423344373703, 48.84701728820801, 45.86051434278488, 46.1050958186388, 47.60150112211704, 46.82856559753418, 49.29152883589268, 47.52721890807152, 45.26668980717659, 47.93278254568577, 44.25188206136227, 40.83362728357315, 33.48532699048519, 36.79433383047581, 36.33873447775841, 35.67113310098648, 36.10166899859905, 35.55191829800606, 35.36286324262619, 36.69199772179127, 36.849290281534195, 36.6781322658062, 37.45579473674297, 37.95033819973469, 36.29241116344929, 36.87609784305096, 37.095148488879204, 38.52795660495758, 36.33183404803276, 43.63185413181782, 46.12740822136402, 50.915170311927795, 50.45611314475536, 50.219378247857094, 47.82455675303936, 45.86168088018894, 42.1244902163744, 39.498964101076126, 40.300922468304634, 47.6743508130312, 54.62236538529396, 51.14727705717087, 49.4280631095171, 52.549162432551384, 47.63575628399849, 51.788526847958565, 51.92498132586479, 45.50202637910843, 39.397980719804764, 43.17346952855587, 46.59818775951862, 45.66834345459938, 50.654253512620926, 55.1827023178339, 47.85075634717941, 44.9878341704607, 37.76891313493252, 37.65557661652565, 37.28085212409496, 37.15958163142204, 38.04952807724476, 37.11943298578262, 37.21538923680782, 38.44178482890129, 37.307796478271484, 36.871595084667206, 38.391528725624084, 38.22284817695618, 36.71827331185341, 38.05031083524227, 36.40046216547489, 35.631486028432846, 37.82839514315128, 40.32292328774929, 45.11190891265869, 50.78396335244179, 49.95194099843502, 45.50024427473545, 53.93805630505085, 48.759162202477455, 50.99727250635624, 52.86841370165348, 49.068005830049515, 47.29446239769459, 43.33366133272648, 40.26205435395241, 38.02722327411175, 38.74263368546963, 37.902924343943596, 39.76732090115547, 39.89877104759216, 39.03046064078808, 40.41396640241146, 48.186905309557915, 52.88265913724899, 56.49413354694843, 54.74575616419315, 58.24912257492542, 57.583022117614746, 59.63544778525829, 59.88182656466961, 60.09883292019367, 59.34027582406998, 52.65965670347214, 7.050251886248589, 0.3037592925829813, 0.6424488045740873, 0.05587151172221638, 0.39854645321611315, 30.337526500225067, 62.646660804748535, 49.386873319745064, 40.706144124269485, 34.12610940635204, 34.663886949419975, 40.10041482746601, 45.72039306163788, 32.82231196761131, 1.1259763617999852, 0.014992740270827198, 0.0480181940656621, 0.025750240420165937, 0.027990227645204868, 0.10698787547880784, 0.05050389525422361, 0.05440119843115099, 0.031703836284577847, 0.11855147880851291, 0.029150757363822777, 0.08150711815687828, 0.05851835914654657, 0.05546890773985069, 0.022836546377220657, 0.012633300666493597, 0.026519747370912228, 0.034591477233334444, 0.029438623460009694, 0.01941418431670172, 0.036956939366064034, 0.12296472676098347, 0.04281237692339346, 6.137445867061615, 55.42322561144829, 56.48906461894512, 52.68180951476097, 33.43370296061039, 28.60727034509182, 37.963857874274254, 52.848780155181885, 52.76920102536678, 53.2903316617012, 3.7016183976083994, 0.13481038331519812, 0.37145877548027784, 0.37728249735664576, 10.065761525183916, 51.66787952184677, 55.5430293828249, 55.10821491479874, 53.09497654438019, 51.8123933672905, 51.85399733483791, 54.38334681093693, 56.03685848414898, 55.406578704714775, 53.2548263669014, 53.09701323509216, 49.715080708265305, 39.577733874320984, 36.39193922281265, 42.92420290410519, 50.7354399561882, 52.37854778766632, 45.445135831832886, 40.08215680718422, 46.515352204442024, 47.80162878334522, 48.15328471362591, 46.37131713330746, 47.48830519616604, 49.721950739622116, 49.065038189291954, 49.84705522656441, 50.01284793019295, 48.57350796461105, 49.35128062963486, 45.83262003958225, 42.68114514648914, 36.49383835494518, 37.38810516893864, 37.46815547347069, 37.18719094991684, 37.75388114154339, 36.56180530786514, 36.6792456060648, 36.674005687236786, 38.22868466377258, 40.43520346283913, 38.65121819078922, 39.851497784256935, 38.37801665067673, 38.64272564649582, 40.72196267545223, 39.61401052772999, 39.50144536793232, 44.81919921934605, 47.141942381858826, 52.78820380568504, 52.37936474382877, 52.58284002542496, 49.95926320552826, 46.299379393458366, 43.560927137732506, 42.30109713971615, 42.25524120032787, 50.330548882484436, 54.740276858210564, 53.726236671209335, 51.23601749539375, 52.90663205087185, 48.35932485759258, 53.7970344722271, 54.433792904019356, 47.91419394314289, 41.61991149187088, 44.46073405444622, 47.61372126638889, 46.476199105381966, 50.505362302064896, 55.589143708348274, 51.8554412573576, 45.52508354187012, 40.658620074391365, 38.02965134382248, 39.30129870772362, 38.79750274121761, 40.16473777592182, 37.23028063774109, 39.38344269990921, 39.52279642224312, 39.321646615862846, 38.9020237326622, 39.38196837902069, 40.329299345612526, 38.294003158807755, 40.37055753171444, 38.945519998669624, 38.19789871573448, 40.54695546627045, 41.59808546304703, 47.04582653939724, 52.632693350315094, 51.61546133458614, 49.71245504915714, 56.1208301782608, 51.63867808878422, 53.60211253166199, 54.765781089663506, 51.89976207911968, 47.508033737540245, 43.98589253425598, 41.145081371068954, 38.892338052392006, 40.55608257651329, 39.90435294806957, 41.92182049155235, 42.299189642071724, 41.29147991538048, 43.2647330313921, 50.532321855425835, 54.3876975774765, 56.46568447351456, 57.78848849236965, 59.38597597181797, 58.89990985393524, 61.153899505734444, 60.70607453584671, 63.21232125163078, 59.92235518991947, 53.35257992148399, 8.549241051077843, 0.20531028625555336, 0.6239848234690726, 0.05198367092816625, 0.4412447917275131, 33.75093653798103, 67.7586480975151, 54.903823882341385, 47.47238405048847, 33.08198243379593, 37.96042665839195, 46.14020213484764, 54.15914744138718, 39.79356229305267, 2.1922365529462695, 0.07598957672598772, 0.038587987000937574, 0.04886831680778414, 0.05673965752066579, 0.030774537517572753, 0.02276805171277374, 0.016365541850973386, 0.0419747185515007, 0.0720036425627768, 0.030770639386901166, 0.10573564228252508, 0.16839676623931155, 0.1278462921618484, 0.07910775471827947, 0.19022416061488912, 0.1564780081389472, 0.16353667859220877, 0.10800764575833455, 0.08149839792167768, 0.21789996069855988, 0.19626463414169848, 0.2289978737826459, 7.673433171585202, 63.043477311730385, 63.755175322294235, 60.24291358888149, 38.744191601872444, 33.12522031366825, 42.68508553504944, 58.06552402675152, 58.395699709653854, 60.39694972336292, 4.713351633399725, 0.2647817856632173, 1.633438419084996, 0.5846679769456387, 10.263897143304348, 53.02026495337486, 56.989729553461075, 57.371419072151184, 55.30382841825485, 53.30602861940861, 53.70314531028271, 56.581901237368584, 59.15440119802952, 59.091328382492065, 57.77485102415085, 53.11905965209007, 52.4007423967123, 42.757878229022026, 38.65352086722851, 46.02578267455101, 54.754298105835915, 53.39944280683994, 45.871716141700745, 41.703016832470894, 47.82814756035805, 48.889282420277596, 49.70208540558815, 46.80046610534191, 49.29528683423996, 51.374550461769104, 48.80589209496975, 52.98072427511215, 51.89071476459503, 48.99528153240681, 51.73035576939583, 48.13970044255257, 44.465574994683266, 37.962657138705254, 40.07383145391941, 40.59101790189743, 39.35131162405014, 38.991079553961754, 37.89156675338745, 38.66036430001259, 39.14609603583813, 38.76975663006306, 41.535818204283714, 40.37681199610233, 41.79163567721844, 39.852759316563606, 40.67712888121605, 42.409022748470306, 42.457530945539474, 42.07319296896458, 47.24976159632206, 48.90961512923241, 54.60638724267483, 54.88699458539486, 54.832315519452095, 52.773327603936195, 49.337909147143364, 46.18608087301254, 44.77904297411442, 44.219355806708336, 53.22786681354046, 57.443193420767784, 52.87673145532608, 52.973816245794296, 55.94314031302929, 51.052073165774345, 54.06577505171299, 54.82984185218811, 47.536950185894966, 41.871416196227074, 45.900830179452896, 49.999039471149445, 49.07638058066368, 53.051651269197464, 56.37520752847195, 53.04048366844654, 48.6520079523325, 41.71367526054382, 41.37431927025318, 40.94036355614662, 42.28127360343933, 43.21567006409168, 41.09208941459656, 40.316779017448425, 41.60302519798279, 39.539310336112976, 39.0191600471735, 40.53796134889126, 42.49910071492195, 39.79398787021637, 41.84678211808205, 40.918826311826706, 38.752965331077576, 43.439595848321915, 42.95132204890251, 50.43492928147316, 54.97772991657257, 53.56606386601925, 52.29400232434273, 56.4280740916729, 54.54998306930065, 55.134581699967384, 56.62057176232338, 53.56242746114731, 51.61880135536194, 46.63567274808884, 43.54117959737778, 41.11316308379173, 43.49548324942589, 41.80302366614342, 43.41670207679272, 44.72420431673527, 42.9138370603323, 45.70984482765198, 51.566721349954605, 57.172929123044014, 59.4823881983757, 58.940096497535706, 62.56815321743488, 59.062848910689354, 63.2402915507555, 62.96059615910053, 64.16146472096443, 62.73031711578369, 55.84143117070198, 9.888139106333256, 0.4777336696861312, 1.691148178651929, 0.49179457768332213, 0.5348950414918363, 36.99329495429993, 74.48196172714233, 60.316781625151634, 59.145847856998444, 48.36595930159092, 48.87614272534847, 53.72391499578953, 60.65713316202164, 52.57962539792061, 3.987610526382923, 0.11057692390750162, 0.12749004643410444, 0.09805733046960086, 0.09819646089454181, 0.20297703333199024, 0.11916492323507555, 0.1439989879145287, 0.17111244786065072, 0.24783643166301772, 0.16929602657910436], [0.012842372943850933, 0.024568783992435783, 0.0721002924547065, 0.022493878241220955, 0.12017390268738382, 0.022968220073380508, 0.029555187029473018, 0.045029799148323946, 0.04592470308125485, 0.022052638050809037, 0.06592197983991355, 0.029735304415225983, 1.1369420983828604, 36.975029334425926, 50.10273590683937, 41.50372512638569, 24.18173521757126, 20.20548988133669, 28.55550192296505, 41.095706820487976, 48.55575531721115, 49.53860677778721, 7.298516314476728, 0.26541433297097683, 0.07095373366610147, 0.3635671630036086, 1.65081144310534, 31.303048990666866, 56.38610154390335, 54.83390763401985, 51.59003309905529, 50.2304432541132, 54.085321202874184, 53.31580929458141, 40.963527113199234, 46.879824846982956, 53.98175396025181, 50.80343350768089, 45.83191707730293, 34.17024023830891, 40.50851292908192, 49.052932038903236, 51.75570420920849, 44.23638269305229, 46.516313552856445, 51.39617130160332, 49.42035712301731, 49.655655696988106, 49.50313948094845, 48.37044686079025, 48.94735090434551, 48.106771409511566, 45.49922972917557, 46.22285529971123, 45.46870596706867, 48.141680136322975, 50.65144166350365, 44.0572565048933, 39.20338176190853, 35.41493184864521, 37.20978453755379, 35.04828952252865, 35.04969544708729, 34.872271567583084, 36.0979375988245, 36.8183409422636, 36.69586971402168, 37.632367461919785, 37.42834120988846, 36.14840269088745, 35.768267288804054, 37.06380017101765, 37.03737638890743, 37.13909313082695, 37.11832344532013, 37.186525985598564, 36.976005882024765, 38.32724757492542, 40.01093342900276, 42.93144151568413, 43.15491132438183, 44.63740937411785, 43.24435472488403, 40.93263857066631, 40.06552889943123, 43.475097343325615, 49.37432639300823, 50.83290472626686, 51.35118171572685, 48.84489320218563, 51.68884299695492, 49.336203038692474, 49.38431225717068, 48.59041705727577, 46.66847638785839, 49.64777112007141, 52.54964880645275, 54.048200994729996, 51.53633438050747, 50.927835032343864, 51.81420587003231, 44.40376751124859, 39.73571419715881, 38.86858552694321, 36.80966600775719, 36.79245673120022, 37.102755680680275, 37.0978007465601, 36.691009774804115, 36.42381951212883, 37.2145988792181, 37.46597819030285, 37.14181378483772, 37.67799161374569, 39.36532527208328, 37.3982810229063, 38.33222910761833, 37.54381701350212, 36.46485351026058, 36.96500927209854, 39.13313113152981, 47.32378162443638, 49.80584643781185, 50.15779875218868, 48.0357950180769, 42.917093485593796, 50.45745447278023, 42.84412980079651, 48.596800714731216, 51.6986046731472, 53.3908324688673, 50.0772088766098, 45.65326206386089, 43.33815649151802, 41.11857399344444, 37.78087869286537, 37.66235925257206, 37.61545456945896, 39.23460088670254, 39.4550346583128, 39.282721504569054, 44.32778678834438, 52.29548804461956, 56.29336751997471, 56.984892413020134, 54.50189284980297, 55.70794813334942, 59.55447033047676, 59.023300632834435, 61.00924126803875, 44.39538136124611, 2.6844338793307543, 0.3835634415736422, 0.38508309284225106, 0.10485707301995717, 0.3847209841478616, 33.296993896365166, 61.4600832760334, 52.49316103756428, 44.69428852200508, 26.003391668200493, 33.19074399769306, 45.08554592728615, 49.9137644469738, 31.055611968040466, 1.1265246011316776, 0.1676920970203355, 0.0386173055449035, 0.05900068463233765, 0.059265056188451126, 0.055661795631749555, 0.06797999987611547, 0.06439118151320145, 0.053722508091595955, 0.03247021508286707, 0.07415218235109933, 0.019006062466360163, 0.01624312088097213, 0.08564052448491566, 0.03891201980877668, 0.07008449319982901, 0.024757677274465095, 0.04626163441571407, 0.020596249305526726, 0.06878807995235547, 0.05010703549487516, 0.06219881048309617, 0.019444449098955374, 1.7661286052316427, 44.81729932129383, 54.91519667208195, 48.45539890229702, 28.164529502391815, 21.444781981408596, 34.6791735291481, 48.99170972406864, 53.64506922662258, 55.34770466387272, 7.461609737947583, 0.36415515176486224, 0.512723884312436, 1.0294775711372495, 2.972192200832069, 35.137090757489204, 60.16040861606598, 58.19115288555622, 54.2451748251915, 52.080237194895744, 55.47318913042545, 54.54391099512577, 42.15460740029812, 47.945933640003204, 54.952050894498825, 53.15311722457409, 48.212246149778366, 36.722840666770935, 41.49911977350712, 48.887249529361725, 52.48732075095177, 46.387359872460365, 46.15409038960934, 51.29801116883755, 51.96258790791035, 50.76077699661255, 50.21470069885254, 50.23259773850441, 49.88336607813835, 47.32632748782635, 46.00139558315277, 48.261715695261955, 46.74424812197685, 47.3838260024786, 51.1013413220644, 46.36846348643303, 40.39831884205341, 36.16690769791603, 38.37129481136799, 37.40901544690132, 37.44766317307949, 36.67205259203911, 38.59505720436573, 39.02026578783989, 38.5953763872385, 39.70170982182026, 40.49793429672718, 38.43440182507038, 39.114751517772675, 39.57754388451576, 38.66662256419659, 38.27318787574768, 38.58201250433922, 38.00902225077152, 38.53383108973503, 41.90770424902439, 43.0266036093235, 45.410234704613686, 46.00284330546856, 46.90495289862156, 46.245380491018295, 42.09994353353977, 42.071699649095535, 45.01691401004791, 53.884593173861504, 52.90223948657513, 53.43506209552288, 50.64888820052147, 53.938257694244385, 51.81705191731453, 52.48054951429367, 50.826270282268524, 47.179887145757675, 50.44692523777485, 52.7081611007452, 54.990295842289925, 53.01219038665295, 53.37204247713089, 53.71567323803902, 47.57127374410629, 39.61358495056629, 40.20363248884678, 37.75819770991802, 37.64474719762802, 38.491653352975845, 38.39262306690216, 37.401104271411896, 38.607752323150635, 38.90371464192867, 38.94576698541641, 38.7138844281435, 39.622009098529816, 41.00678399205208, 39.24755819141865, 39.55333538353443, 38.81639912724495, 38.70061174035072, 38.089330941438675, 42.36423835158348, 48.50527502596378, 51.61029741168022, 52.53814682364464, 47.90538601577282, 45.79447768628597, 51.87326990067959, 44.70485955476761, 49.7898530960083, 53.187011405825615, 56.70040927827358, 52.61823892593384, 46.82132698595524, 44.692696407437325, 42.36298821866512, 39.73842345178127, 39.76666733622551, 39.79183718562126, 41.616373881697655, 41.73940367996693, 41.53599299490452, 47.06447593867779, 54.2469797283411, 58.24126839637756, 59.093034490942955, 57.99774706363678, 57.665394097566605, 60.62372915446758, 60.91788277029991, 61.44817091524601, 47.09908068180084, 3.9171587442979217, 0.8940044499468058, 0.1597871704143472, 0.015872438525548205, 0.41058028873521835, 36.758649945259094, 66.44589453935623, 58.74124936759472, 46.435792073607445, 29.71357338130474, 38.25337953865528, 53.521005883812904, 57.653166353702545, 39.4609547406435, 1.8557106982916594, 0.10306129086529836, 0.029973316741234157, 0.028765744136762805, 0.0519941055244999, 0.058453684687265195, 0.0774258996534627, 0.025919145809893962, 0.03978292639658321, 0.048765581304905936, 0.039439694228349254, 0.08382348722079769, 0.19716059934580699, 0.26275400072336197, 0.22841461992356926, 0.21396965050371364, 0.10959437233395875, 0.14869163220282644, 0.14932973077520728, 0.128205313521903, 0.17953211325220764, 0.21348219306673855, 0.12072399738826789, 2.0953681133687496, 49.63987894356251, 62.07805551588535, 54.88415613770485, 35.4927858710289, 29.16307982057333, 39.6467799693346, 54.568233489990234, 56.93855009973049, 61.640045419335365, 9.315203949809074, 0.3861124813556671, 2.0504283998161554, 1.6848628409206867, 2.574842059984803, 36.31177492439747, 59.55625243484974, 60.84557645022869, 55.92954844236374, 56.020211577415466, 58.05490739643574, 56.318240985274315, 43.11423450708389, 50.216437205672264, 57.5101800262928, 56.257159262895584, 50.51418922841549, 38.607091158628464, 44.36934135854244, 51.982035264372826, 54.623201340436935, 46.44128657877445, 49.851607382297516, 53.06367002427578, 54.21943500638008, 53.16705107688904, 53.92903558909893, 51.27503380179405, 51.803121864795685, 49.714875519275665, 47.13029220700264, 47.67364405095577, 46.9735012203455, 50.52249938249588, 53.65705758333206, 48.773191049695015, 42.673849537968636, 39.36430312693119, 42.374934777617455, 37.37493887543678, 38.643888384103775, 39.147570356726646, 39.43081475794315, 41.5635871142149, 40.22624507546425, 40.852204486727715, 40.420391857624054, 39.821870774030685, 41.045104935765266, 40.92054761946201, 41.11326187849045, 41.0515645891428, 42.0084710419178, 40.74307434260845, 40.39098523557186, 42.7438759803772, 43.89977015554905, 46.570517644286156, 47.70743563771248, 48.39817777276039, 48.09607498347759, 43.46408933401108, 45.1324126124382, 46.83328874409199, 54.25779774785042, 55.40159337222576, 55.37653751671314, 52.238817885518074, 53.824472799897194, 52.16722972691059, 53.67225296795368, 53.29296492040157, 48.56132581830025, 52.50176377594471, 52.7470064163208, 57.07071840763092, 54.38819535076618, 55.46528175473213, 58.41772332787514, 49.20146606862545, 43.119029849767685, 42.895723432302475, 39.877514988183975, 39.109530597925186, 40.37781894207001, 41.70466594398022, 39.4006709754467, 38.36523413658142, 40.894693806767464, 42.662400752305984, 40.632363483309746, 40.96741050481796, 42.88886480033398, 42.11530990898609, 42.43788979947567, 40.57839497923851, 39.960445538163185, 41.09557002782822, 43.94838474690914, 50.51627151668072, 53.473903611302376, 52.716748639941216, 49.23235081136227, 47.16197490692139, 52.03823804855347, 45.0137297809124, 49.73130203783512, 55.460114032030106, 58.99156093597412, 54.41355139017105, 50.68454548716545, 45.75736507773399, 44.346371591091156, 42.67566964030266, 42.4219686537981, 41.50583781301975, 44.73566070199013, 43.93185943365097, 44.57102693617344, 49.48580861091614, 56.92621596157551, 63.03632989525795, 61.6684564948082, 61.34659096598625, 60.31814955174923, 63.64105224609375, 63.557285740971565, 63.86587858200073, 48.821015283465385, 4.392047049477696, 1.6724986606277525, 2.422799631021917, 0.3248256293591112, 0.6880860775709152, 40.97239963710308, 71.73568189144135, 65.50346910953522, 58.666085600852966, 38.177440613508224, 46.592100486159325, 61.43094263970852, 66.39206662774086, 51.052460744977, 3.4943361952900887, 0.25376092235092074, 0.09944349163561128, 0.15667841769754887, 0.17040203441865742, 0.10186358325881884, 0.11773542806622572, 0.11183912414708175, 0.1979926656349562, 0.13201177411247045, 0.14547839993610978], [0.052679534564958885, 0.03875028727634344, 0.009596244053682312, 0.05850524168636184, 0.06150950001028832, 0.0322118400799809, 0.06668570174952038, 0.042987813212675974, 0.05048017992521636, 0.0843285780865699, 0.11834493911010213, 0.031311674320022576, 0.535601566080004, 20.94318989664316, 45.281125232577324, 49.96948845684528, 39.119657054543495, 30.438549779355526, 36.040598675608635, 43.73450942337513, 46.553186774253845, 54.57399398088455, 12.53191564232111, 0.12521512631792575, 0.0744741185917519, 0.0950152894074563, 0.5980971094686538, 12.156224101781845, 50.58587998151779, 53.510176464915276, 52.90604688227177, 51.40392668545246, 53.40673081576824, 50.94948627054691, 50.46028912067413, 52.499856278300285, 51.63413733243942, 45.115093141794205, 36.9148975610733, 36.760055869817734, 47.744639441370964, 51.15014590322971, 50.26031345129013, 47.00798436999321, 50.41874215006828, 46.15522272884846, 46.73170119524002, 44.358762726187706, 45.45808173716068, 48.045150116086006, 48.74618969857693, 49.42465849220753, 51.43096223473549, 48.59749987721443, 50.091857090592384, 48.774425983428955, 47.15123288333416, 41.10452614724636, 35.695945769548416, 35.15770465135574, 36.82478919625282, 35.53928777575493, 34.754398092627525, 35.706516802310944, 36.82851679623127, 35.02562373876572, 35.85380829870701, 37.72512428462505, 37.38024719059467, 36.25722885131836, 35.89766554534435, 36.82722106575966, 35.757445469498634, 36.68287821114063, 35.18108479678631, 35.541153475642204, 36.407195404171944, 36.904763504862785, 38.234456554055214, 36.758520752191544, 37.63342000544071, 36.87121890485287, 39.57816705107689, 37.719561383128166, 40.51534876227379, 50.93013010919094, 49.97089818120003, 53.14895264804363, 50.62345236539841, 49.11874070763588, 54.43396009504795, 49.34920214116573, 49.57852363586426, 51.19064413011074, 50.9938108921051, 49.02233988046646, 49.920421689748764, 49.879862666130066, 48.547011986374855, 51.13594986498356, 47.81534604728222, 37.871332839131355, 37.5257071852684, 38.48788395524025, 38.7948352843523, 35.35580322146416, 35.69197118282318, 36.62011697888374, 36.13355688750744, 37.49788887798786, 37.46755510568619, 37.2663938999176, 37.453241273760796, 36.54377527534962, 38.26283723115921, 35.75575836002827, 37.901491820812225, 35.95908164978027, 38.21342088282108, 36.43021076917648, 38.120398074388504, 44.450748190283775, 49.66908797621727, 48.822181820869446, 52.9314561188221, 49.533450454473495, 49.63856041431427, 51.95304661989212, 49.466957822442055, 49.83004733920097, 49.87545870244503, 54.481119364500046, 57.95470677316189, 51.44808031618595, 46.496307626366615, 45.119569301605225, 36.84514470398426, 35.33511333167553, 38.133476972579956, 39.37577471137047, 42.13518284261227, 40.933770909905434, 41.678834930062294, 46.780745163559914, 53.026595413684845, 55.67086972296238, 58.47228080034256, 57.48116858303547, 57.64640271663666, 57.667031809687614, 29.50288988649845, 0.9329046844504774, 0.2277855310239829, 0.3820048423949629, 0.05206861344049685, 0.4779798845993355, 31.46883599460125, 68.28410670161247, 51.77696406841278, 42.97526836395264, 27.999283969402313, 36.51130221784115, 47.586799710989, 52.060618847608566, 30.091812685132027, 0.08865661264280789, 0.06342399239656515, 0.008020052264328115, 0.025654379060142674, 0.027058414852945134, 0.0415762557531707, 0.018265859216626268, 0.045228112139739096, 0.07362292715697549, 0.07710926976869814, 0.0305646062042797, 0.06537776294862852, 0.09214734876877628, 0.03463389468379319, 0.035976751532871276, 0.07499379265937023, 0.05593169618805405, 0.06138598808320239, 0.05864316612132825, 0.01640862537897192, 0.038924354303162545, 0.07396345419692807, 0.07855851348722354, 0.5470024980604649, 26.812212467193604, 53.46096150577068, 55.319042801856995, 40.076278522610664, 26.545008905231953, 36.915577724575996, 50.61841383576393, 53.07108722627163, 58.11669208109379, 14.179414138197899, 0.3375653363764286, 0.24419351073447615, 2.3218635097146034, 0.4465029970742762, 15.212715491652489, 55.04648722708225, 55.44310234487057, 54.96795304119587, 53.97206827998161, 53.16948674619198, 51.18688613176346, 51.83247148990631, 53.50521773099899, 53.04666593670845, 47.955991700291634, 37.699091881513596, 38.54560665786266, 49.983331114053726, 53.8575804233551, 50.253302827477455, 46.88533455133438, 52.779468074440956, 49.75130036473274, 48.31318013370037, 47.94232003390789, 47.64825381338596, 49.070536494255066, 51.480051800608635, 52.05854795873165, 51.275508776307106, 49.52431194484234, 51.25726595520973, 51.00105330348015, 50.0210402905941, 44.66954044997692, 36.95321470499039, 37.03540049493313, 37.43134684860706, 37.142509147524834, 35.89622162282467, 37.073523849248886, 39.52537268400192, 37.42198795080185, 37.18405991792679, 40.030650570988655, 39.0643510222435, 39.20394793152809, 36.83218739926815, 36.56470835208893, 39.51095625758171, 36.73374988138676, 38.095547407865524, 38.86486552655697, 40.23679330945015, 39.07513864338398, 38.0211815983057, 38.268913105130196, 39.94560733437538, 39.86762411892414, 40.78125849366188, 40.7158488035202, 43.17980758845806, 51.803558841347694, 52.970780208706856, 55.01575447618961, 52.50522539019585, 52.0639930665493, 55.333911404013634, 50.94742678105831, 52.286763712763786, 52.96538449823856, 52.98760950565338, 49.65538591146469, 52.4873511493206, 52.14315801858902, 50.969906374812126, 51.883206367492676, 50.85417218506336, 40.76383262872696, 38.15925858914852, 40.21733455359936, 40.11497564613819, 38.072300255298615, 37.954236790537834, 39.32896502315998, 38.21837201714516, 38.74755822122097, 39.12922114133835, 40.54001323878765, 37.2305466234684, 39.506920874118805, 39.24089714884758, 37.57614187896252, 40.75838752090931, 37.18084529042244, 38.853773921728134, 37.54134714603424, 40.312112867832184, 46.65848292410374, 51.45221069455147, 51.58698946237564, 55.163095369935036, 50.09020037949085, 51.6262299567461, 52.552491053938866, 50.39712890982628, 50.05864307284355, 49.85640652477741, 57.50441573560238, 58.099239617586136, 51.80808059871197, 48.122103586792946, 46.14869087934494, 38.985619246959686, 37.335307002067566, 40.25401398539543, 41.67170651257038, 43.08619201183319, 41.79436393082142, 43.81709039211273, 49.602549746632576, 57.33022928237915, 57.951385751366615, 60.084978863596916, 59.92759130895138, 59.47737246751785, 60.25623947381973, 32.414236664772034, 1.5108427475206554, 1.298793819732964, 0.870945209171623, 0.1732819978496991, 0.45451350160874426, 34.29384760558605, 71.35513991117477, 56.63794822990894, 47.20755726099014, 32.53980092704296, 38.85055169463158, 53.5153441876173, 58.792318627238274, 39.14887748658657, 0.9381801076233387, 0.03564662198186852, 0.028288281573622953, 0.023618619743501768, 0.006509732575068483, 0.04808041201613378, 0.045983996969880536, 0.025612354947952554, 0.06616754908463918, 0.02505730270058848, 0.003939607913707732, 0.13148446334525943, 0.16219250072026625, 0.13066351442830637, 0.1768658438231796, 0.20748495706357062, 0.27589773293584585, 0.20668360084528103, 0.16998686216538772, 0.20220588252414018, 0.2507312083616853, 0.21430676366435364, 0.12814251298550516, 0.7323982904199511, 30.650063529610634, 61.00186586380005, 62.38704353570938, 48.97731989622116, 40.576631873846054, 47.39363707602024, 57.78365135192871, 56.240326166152954, 64.49108183383942, 16.112058833241463, 0.3385886095929891, 0.6766671559307724, 4.076610300689936, 0.8924806723371148, 14.984287898987532, 54.08440925180912, 55.66721811890602, 57.10411861538887, 54.30198177695274, 55.489437058568, 52.94833101332188, 51.879311576485634, 54.69969503581524, 55.76959602534771, 48.53185459971428, 40.00188231468201, 41.28036171197891, 52.81279608607292, 55.04020616412163, 51.501634642481804, 49.527610167860985, 54.15943242609501, 51.410310342907906, 50.33661715686321, 51.387002393603325, 50.66250666975975, 52.566253915429115, 52.14823454618454, 53.8309096544981, 53.44747602939606, 52.41736650466919, 51.94652616977692, 52.177884355187416, 52.949375957250595, 45.76037831604481, 39.21651765704155, 40.38865976035595, 40.307936891913414, 39.73344951868057, 38.011579513549805, 40.10517977178097, 40.14028988778591, 38.1597525626421, 38.42015638947487, 42.9707770049572, 40.843518152832985, 39.74027395248413, 37.82032057642937, 39.40614268183708, 40.499868392944336, 37.606521248817444, 40.03239847719669, 40.09316861629486, 42.417374700307846, 40.59124208986759, 40.65139666199684, 40.07668510079384, 42.37764783203602, 41.72775350511074, 43.75927649438381, 42.10272878408432, 46.197917237877846, 52.85317271947861, 55.005928203463554, 57.32468917965889, 53.2753224670887, 54.077193439006805, 57.92476437985897, 54.02572900056839, 53.373410403728485, 53.82682867348194, 54.9763809889555, 50.897429063916206, 54.48287107050419, 54.01827000081539, 53.795848935842514, 54.74275432527065, 50.90532884001732, 43.010139092803, 41.14086739718914, 42.502524331212044, 43.490961492061615, 39.69144657254219, 39.828980192542076, 40.49931742250919, 40.186024233698845, 40.975705459713936, 41.079352498054504, 42.410375475883484, 38.19090709090233, 41.28137245774269, 41.305060386657715, 40.28050236403942, 42.081328332424164, 39.06673729419708, 41.671375930309296, 39.50723625719547, 42.28747867047787, 47.688763439655304, 53.11160825192928, 52.482928186655045, 57.905172631144524, 54.692118242383, 53.79291549324989, 53.95854860544205, 53.52484367787838, 51.15886643528938, 51.38317599892616, 57.633297219872475, 62.153466269373894, 55.85358291864395, 51.992359310388565, 48.80923591554165, 42.30157971382141, 39.19808104634285, 43.439493253827095, 44.215195029973984, 47.70229451358318, 45.01422755420208, 46.837745904922485, 52.03938938677311, 58.22091668844223, 60.99790267646313, 63.24444852769375, 61.062901988625526, 62.09795504808426, 62.30180650949478, 35.17706461250782, 1.6475253319367766, 1.2469407333992422, 2.130147172138095, 0.4283900518203154, 0.5607602535746992, 38.38012173771858, 79.78485077619553, 64.4597715139389, 59.34637829661369, 43.52823369204998, 49.04363013803959, 64.2176105082035, 66.2813101708889, 50.89269071817398, 2.6838935958221555, 0.32269703107886016, 0.1355897868052125, 0.11174207349540666, 0.2258810168132186, 0.1505392385297455, 0.09585794614395127, 0.16247539257165045, 0.14099380932748318, 0.12393057259032503, 0.16609134385362267], [0.040092220151564106, 0.06129458517534658, 0.039034978835843503, 0.03181290601787623, 0.04450731605174951, 0.006896795521242893, 0.0726903072791174, 0.09124330899794586, 0.056758600840112194, 0.06708091023028828, 0.015343870745709864, 0.07379018497886136, 0.08055049722315744, 11.614118590950966, 51.5746895223856, 49.63353328406811, 37.15035192668438, 20.00354591757059, 30.971615575253963, 39.897718504071236, 48.74463178217411, 55.44807627797127, 17.575954981148243, 0.2477279445156455, 0.10281399983796291, 1.6172246891073883, 1.7378209554590285, 1.2479872209951282, 30.469461120665073, 54.613553658127785, 52.986925542354584, 53.7535610049963, 51.65553018450737, 53.0828969925642, 52.740930542349815, 49.001239612698555, 44.97493386268616, 35.377667248249054, 36.696899458765984, 43.77160303294659, 51.799812242388725, 49.36171106994152, 49.93185147643089, 49.5963104814291, 45.6444351375103, 44.94628719985485, 44.28544566035271, 43.963488936424255, 43.84344197809696, 44.6216744184494, 46.684481129050255, 46.506160497665405, 48.029035180807114, 49.16807346045971, 46.252501308918, 46.1116086691618, 43.56640264391899, 37.96139180660248, 35.73210082948208, 34.59628477692604, 35.95172144472599, 35.48325598239899, 36.14157445728779, 35.63243217766285, 37.86550015211105, 37.41631105542183, 36.92318491637707, 37.207793444395065, 38.2366718351841, 35.883560702204704, 37.833935245871544, 39.22398805618286, 37.633104622364044, 37.932114377617836, 36.29797026515007, 36.91076718270779, 39.30450193583965, 40.59249222278595, 40.352253913879395, 40.94504490494728, 38.487382382154465, 37.778952196240425, 39.4712445884943, 37.82540090382099, 46.57016046345234, 54.91872288286686, 50.83326570689678, 51.62730909883976, 45.62013544142246, 48.2830211520195, 52.42027334868908, 47.79003940522671, 51.58701606094837, 51.94346733391285, 53.35277371108532, 49.18943591415882, 50.64231835305691, 50.96388749778271, 51.348525658249855, 50.644081458449364, 42.17325679957867, 36.50051459670067, 38.0658558011055, 36.60605013370514, 37.32951231300831, 37.36082263290882, 37.546788454055786, 38.062215596437454, 37.68136203289032, 37.29040861129761, 37.438080087304115, 36.636429503560066, 37.54770040512085, 37.23442241549492, 37.58925877511501, 36.47445559501648, 37.058172672986984, 35.410330295562744, 36.69945292174816, 36.1390969902277, 35.98461627960205, 42.09306590259075, 44.99634191393852, 48.85025851428509, 44.84135963022709, 47.000768557190895, 46.82980813086033, 47.85593546926975, 49.80761334300041, 50.625139474868774, 48.99446077644825, 45.56793384253979, 50.43792352080345, 57.95662946999073, 52.16030269861221, 50.046153143048286, 46.891083642840385, 37.20437362790108, 37.39334508776665, 40.10927975177765, 44.53675277531147, 44.608352333307266, 45.8911444991827, 43.704510033130646, 43.35141018033028, 49.110726937651634, 54.834595397114754, 58.80804218351841, 56.17513686418533, 57.426557913422585, 18.459185287356377, 0.5538591707590967, 1.2735408497974277, 0.2435480203712359, 0.05262864178803284, 0.42114057519938797, 29.900016076862812, 63.550579100847244, 51.57284662127495, 48.204467967152596, 23.581338934600353, 43.94132472574711, 52.39128090441227, 51.136417239904404, 25.24551473557949, 0.7422563864383847, 0.10903650734690018, 0.050189673638669774, 0.025135742143902462, 0.0391503976425156, 0.041545415806467645, 0.01928728263010271, 0.039498450059909374, 0.0503964471135987, 0.04262758215190843, 0.05119076406117529, 0.028221824104548432, 0.04029460011224728, 0.10263486023177393, 0.014636693067586748, 0.024040387834247667, 0.06939514933037572, 0.059915374222327955, 0.029005561736994423, 0.04052060263347812, 0.08509202540153638, 0.006764088384443312, 0.023304490896407515, 0.10375637153629214, 14.71182256937027, 57.8740257024765, 53.93133066594601, 43.53457935154438, 25.74615117162466, 36.69016242027283, 50.949197486042976, 52.55991205573082, 60.210337936878204, 19.729025848209858, 0.11111435014754534, 0.13826292852172628, 2.750285533256829, 3.4155260492116213, 2.548727486282587, 34.73522812128067, 55.415926203131676, 53.354373425245285, 53.99289496243, 52.89459049701691, 55.02497658133507, 55.27323246002197, 51.76580406725407, 47.548938542604446, 38.03684055805206, 37.73032620549202, 44.66349497437477, 53.21288801729679, 51.08754426240921, 51.0651520639658, 51.62251375615597, 48.76197785139084, 47.196412459015846, 46.569111719727516, 45.46868696808815, 46.59652724862099, 47.42800623178482, 49.09976452589035, 49.6619937568903, 49.59571771323681, 51.389901638031006, 48.78023587167263, 48.98217223584652, 45.70616662502289, 41.25964902341366, 37.7874219417572, 37.49283894896507, 36.32518820464611, 37.472422644495964, 37.919772639870644, 37.042479515075684, 39.12047781050205, 38.68597112596035, 38.55590410530567, 39.609446972608566, 39.515709802508354, 37.77308911085129, 38.76754514873028, 39.909646064043045, 38.49935173988342, 40.193965807557106, 38.95377315580845, 39.62200149893761, 41.284146308898926, 42.487176954746246, 43.44934992492199, 40.95506116747856, 41.08825922012329, 40.28827674686909, 39.91904675960541, 40.46823509037495, 48.03379252552986, 55.52633307874203, 51.1069156229496, 53.87174226343632, 46.1224190890789, 50.82679085433483, 55.788671001791954, 50.11434808373451, 52.86089390516281, 54.67325985431671, 53.03411900997162, 52.05055318772793, 53.40222805738449, 52.75891877710819, 52.83262342214584, 52.00917340815067, 43.50910171866417, 37.89824679493904, 39.258866384625435, 39.6015889942646, 39.16524700820446, 38.75529080629349, 39.837134554982185, 39.037231877446175, 39.16294813156128, 39.59587790071964, 38.64314742386341, 39.10289615392685, 38.79674278199673, 39.355225414037704, 38.79409432411194, 38.523389250040054, 38.490794599056244, 38.57578843832016, 37.853899374604225, 37.68251337110996, 39.23607900738716, 44.92991387844086, 47.81425550580025, 49.80113849043846, 48.32411974668503, 49.77191425859928, 49.702792167663574, 49.31937374174595, 52.89104908704758, 53.21159988641739, 49.510416090488434, 47.608998119831085, 53.31447936594486, 58.889733999967575, 54.79602366685867, 52.81165234744549, 49.542763754725456, 40.06997086107731, 39.411667585372925, 42.21248209476471, 45.85044488310814, 46.923617497086525, 47.23099060356617, 44.51619207859039, 46.38291411101818, 54.26013462245464, 58.44728194177151, 62.450811713933945, 59.01441290974617, 59.95943360030651, 21.220468617975712, 0.8724049245938659, 3.4813964646309614, 0.7461356220301241, 0.011821081261587096, 0.31723651627544314, 33.46725136041641, 69.18037220835686, 59.01295758783817, 54.352465867996216, 29.13022108376026, 46.95115461945534, 61.068457290530205, 57.483839839696884, 35.21068140864372, 0.6583793903701007, 0.18190375005360693, 0.0731368204287719, 0.04341343119449448, 0.035210365313105285, 0.04274530161637813, 0.0033846454198283027, 0.05880159238586202, 0.010253829568682704, 0.10010409954702482, 0.05844323524797801, 0.11697427398758009, 0.19061975501244888, 0.23373955918941647, 0.12757425050949678, 0.1620084629394114, 0.11276355813606642, 0.17176449880935252, 0.21371873037423939, 0.1913270217482932, 0.14390374068170786, 0.12740383855998516, 0.13243307650554925, 0.10402721090940759, 17.734376080334187, 65.86483731865883, 61.94755531847477, 49.37121815979481, 31.668129600584507, 40.06145551800728, 54.159550219774246, 57.92023882269859, 67.09597125649452, 22.249022126197815, 0.4141782206716016, 0.9466053242795169, 8.469782564789057, 3.4214373445138335, 1.6025856183841825, 34.82626363635063, 55.69165840744972, 55.519326254725456, 57.12318979203701, 55.67072153091431, 57.017023488879204, 56.37635886669159, 54.68106843531132, 48.9114086329937, 40.670076459646225, 40.39829224348068, 48.05977173149586, 56.53158813714981, 52.334869131445885, 52.90725141763687, 54.68879722058773, 51.040951162576675, 49.33560647070408, 48.48737798631191, 47.78161145746708, 48.74715104699135, 49.96364817023277, 52.72564776241779, 50.10508418083191, 53.52987080812454, 52.95966200530529, 50.6518292427063, 51.194481924176216, 48.739954233169556, 43.010424077510834, 39.58682678639889, 38.35691638290882, 38.83795537054539, 40.40170446038246, 39.88457880914211, 38.86054515838623, 41.708522737026215, 39.899629801511765, 39.67839427292347, 41.71654790639877, 42.16666795313358, 39.33290161192417, 41.115925535559654, 43.71723935008049, 40.41802458465099, 41.81541480123997, 41.712938100099564, 41.93650670349598, 44.55485500395298, 44.4451928883791, 45.702279433608055, 45.05645468831062, 42.63380728662014, 42.10356093943119, 42.71780177950859, 42.56512977182865, 51.25933684408665, 58.081908747553825, 52.39924147725105, 54.47923846542835, 47.181954234838486, 52.282390147447586, 57.22909390926361, 52.25874401628971, 55.782849714159966, 55.093901082873344, 55.15266872942448, 52.06562697887421, 55.912247970700264, 55.19005872309208, 53.86017568409443, 54.61560554802418, 44.68516141176224, 38.54785993695259, 41.566474959254265, 41.149318143725395, 40.437217354774475, 41.09088867902756, 42.30771258473396, 41.18109203875065, 41.17153935134411, 42.21263028681278, 40.86683750152588, 42.02576771378517, 42.5956155359745, 40.64726248383522, 41.227533146739006, 39.9455389380455, 41.80932752788067, 40.51558814942837, 39.53152075409889, 40.53923048079014, 41.336849480867386, 47.61097401380539, 49.81704443693161, 53.30550044775009, 50.24796411395073, 52.934644147753716, 51.785209625959396, 52.38345332443714, 54.98002499341965, 53.64140622317791, 51.97379730641842, 49.26917463541031, 54.967014491558075, 60.53612105548382, 56.76039665937424, 55.17995126545429, 51.83037780225277, 42.78275549411774, 41.47851727902889, 44.890585988759995, 50.065866485238075, 50.010666847229004, 49.978794157505035, 48.67138311266899, 49.13612097501755, 55.50414986908436, 61.03582464158535, 64.69185546040535, 61.8975044041872, 62.731194868683815, 23.11238519847393, 1.4969590050168335, 5.050707506015897, 2.5467653665691614, 0.19743446668144315, 0.49275554018095136, 36.37413337826729, 71.81005150079727, 66.43796816468239, 61.271518394351006, 36.33628360927105, 59.532967284321785, 66.55800372362137, 65.9633356332779, 46.0003924369812, 2.7505657682195306, 0.39607183600310236, 0.2085203124443069, 0.19423860067036003, 0.3132905764505267, 0.19078730227192864, 0.12120103507186286, 0.18451808398822322, 0.09668691025581211, 0.2725616900715977, 0.12264246397535317], [0.053415819274960086, 0.03877772447594907, 0.029241392148833256, 0.018016742506006267, 0.01626724624657072, 0.0447655537573155, 0.04182035925623495, 0.040181099757319316, 0.07822100698831491, 0.013821130287396954, 0.07226925721624866, 0.028042964659107383, 0.11506958908285014, 6.700614597648382, 48.14443498849869, 50.56292541325092, 38.07642683386803, 20.24641178548336, 21.63799401372671, 36.45987957715988, 49.08187508583069, 51.81894801557064, 23.50379079580307, 0.11001868784660473, 0.13390983163844794, 2.9133504582569003, 1.9780710199847817, 1.3819727813825011, 10.94720022752881, 45.60654357075691, 54.074655175209045, 53.905894830822945, 51.77190653979778, 49.942031130194664, 45.67611403763294, 40.64405545592308, 37.13281586766243, 34.79749538004398, 43.65620322525501, 47.83084161579609, 51.62208437919617, 49.67667616903782, 49.391968846321106, 46.581803038716316, 44.905420392751694, 44.92999367415905, 41.19707018136978, 41.629194393754005, 41.06129586696625, 41.709765270352364, 44.1311739385128, 45.05242310464382, 47.080450281500816, 45.716403275728226, 44.86174173653126, 40.83310291171074, 38.57864208519459, 35.31660832464695, 36.31671465933323, 34.95985686779022, 36.36120647192001, 35.32877527177334, 35.826639756560326, 36.77696496248245, 38.50462585687637, 37.83418983221054, 36.404520347714424, 38.54398034512997, 37.31978103518486, 35.96260406076908, 36.83459646999836, 36.58898524940014, 36.63605712354183, 39.16910000145435, 36.30295179784298, 38.28597418963909, 40.04847161471844, 43.373137414455414, 44.10781279206276, 42.514265701174736, 43.70911918580532, 40.45379586517811, 38.77586670219898, 35.662313774228096, 45.36923870444298, 52.962907031178474, 49.411708787083626, 50.656138211488724, 44.35273624956608, 46.41069442033768, 53.68263401091099, 49.637861251831055, 49.2999529838562, 51.157152727246284, 52.805200293660164, 50.39615236222744, 51.246463134884834, 49.059653878211975, 52.38511003553867, 49.20251101255417, 41.10718220472336, 35.767685920000076, 37.745259404182434, 36.800436303019524, 39.09197933971882, 37.63499312102795, 37.5107853859663, 36.77034951746464, 37.733727023005486, 38.39036978781223, 37.889598459005356, 35.952830985188484, 38.24578754603863, 37.422079145908356, 35.683501437306404, 34.68703530728817, 35.97091041505337, 37.69640922546387, 37.51588091254234, 36.145868226885796, 35.94299331307411, 37.42579534649849, 41.52310788631439, 42.29910224676132, 44.318021312355995, 44.778963178396225, 45.45935086905956, 45.84326706826687, 46.51443265378475, 48.2515512406826, 51.2501185387373, 50.91189868748188, 44.95035298168659, 44.22117590904236, 53.15903350710869, 55.66280655562878, 50.24178184568882, 45.02349525690079, 37.09131449460983, 39.84857194125652, 42.7888997644186, 47.15207263827324, 49.76423867046833, 52.28398986160755, 49.6740847080946, 48.92999343574047, 51.280285120010376, 56.29514202475548, 55.0557055324316, 56.67082406580448, 12.791236527264118, 0.3069030598271638, 1.651210302952677, 0.4940662917215377, 0.06786556812585331, 0.22459811065346003, 29.72893785685301, 63.61995577812195, 50.1247975230217, 52.2002499550581, 35.51475629210472, 39.557959735393524, 46.466243639588356, 50.93993738293648, 28.88245537877083, 0.6937013450078666, 0.11433452149503864, 0.07734853075817227, 0.06884152942802757, 0.11056946532335132, 0.07649552106158808, 0.06863046262878925, 0.03321367265016306, 0.032719357768655755, 0.03406391784665175, 0.06703483028104529, 0.003002035127792624, 0.0949977598793339, 0.02346723646041937, 0.041661984942038544, 0.018639816298673395, 0.04654206975828856, 0.008195628633984597, 0.04194379325781483, 0.028062084238626994, 0.028963678632862866, 0.047639153272029944, 0.1395974139450118, 0.12756467680446804, 9.182271882891655, 56.637811437249184, 55.45859791338444, 42.65693284571171, 22.965650372207165, 27.075378745794296, 44.57621745765209, 53.866715133190155, 59.96450252830982, 26.614366583526134, 0.06099848309531808, 0.05375525535782799, 5.34713719971478, 5.948553727939725, 1.5097411628812551, 14.488751739263535, 48.725769594311714, 55.01820534467697, 56.89195699989796, 53.983714655041695, 51.997359842062, 49.16407227516174, 43.34031097590923, 39.448043033480644, 36.77164904773235, 45.50133481621742, 49.681243523955345, 53.32083262503147, 50.60467757284641, 50.822687074542046, 47.98317924141884, 47.404565289616585, 47.015200182795525, 43.700136467814445, 43.645024225115776, 43.734703212976456, 43.89536239206791, 46.27636402845383, 46.70912280678749, 48.39100755751133, 47.91482090950012, 47.41594187915325, 43.931726440787315, 40.395628586411476, 37.77145519852638, 37.68771529197693, 36.82666629552841, 37.616932690143585, 37.66845412552357, 36.915558725595474, 37.84832887351513, 38.632097616791725, 39.383583292365074, 40.023533552885056, 39.20461669564247, 40.27623899281025, 37.063944563269615, 39.41448703408241, 38.846683502197266, 37.99629673361778, 41.41311518847942, 38.591519594192505, 38.41027311980724, 41.2215256690979, 44.44773495197296, 44.12215322256088, 43.94845314323902, 44.20248471200466, 40.46453408896923, 41.39746002852917, 38.94586198031902, 47.97777973115444, 56.15548811852932, 52.1611462533474, 50.62202364206314, 45.25105744600296, 48.16097930073738, 54.435191228985786, 50.865810960531235, 51.333888843655586, 52.0480415225029, 54.79183629155159, 51.3633106648922, 52.18633510172367, 51.61695845425129, 53.9224087446928, 49.8796346783638, 43.12512092292309, 38.05267050862312, 39.41314950585365, 38.52885715663433, 38.83494213223457, 38.898315131664276, 39.7488234937191, 39.2331113666296, 38.9689951390028, 40.30060328543186, 39.33437593281269, 39.28731165826321, 39.140939712524414, 39.555087089538574, 38.22007052600384, 37.26746164262295, 37.795458510518074, 38.24038803577423, 38.258098885416985, 37.98604488372803, 38.15567918121815, 39.59882654249668, 43.967562317848206, 45.46626269817352, 47.7077966183424, 46.33426532149315, 48.086738884449005, 48.79614181816578, 48.1292662024498, 49.80321317911148, 53.15376318991184, 51.46842822432518, 47.647600248456, 47.66331620514393, 55.92161066830158, 55.93799538910389, 52.464860156178474, 46.17800250649452, 38.866860419511795, 41.1784777790308, 45.06213538348675, 49.90775316953659, 53.49094569683075, 53.57622072100639, 50.6912787258625, 51.14186994731426, 54.002219662070274, 58.240987211465836, 56.06388263404369, 58.91249857842922, 14.895694702863693, 1.3272240129299462, 3.570099617354572, 1.4225652907043695, 0.14959745312808082, 0.17584073008038104, 33.4953660517931, 68.32230985164642, 57.483893036842346, 60.821269154548645, 40.83716109395027, 46.760021075606346, 55.171276330947876, 57.74423606693745, 35.03820866346359, 1.1431869445368648, 0.11863210573210381, 0.03271555426181294, 0.05971262318780646, 0.03308866158477031, 0.05473204786540009, 0.015948566178849433, 0.023963512467162218, 0.041454688252997585, 0.053570030140690506, 0.0032493873823113972, 0.12326931901043281, 0.1603336731204763, 0.17382593272486702, 0.13250549527583644, 0.21813814557390288, 0.13370649801800027, 0.21458104660268873, 0.12205500213894993, 0.14227646315703169, 0.13110504776705056, 0.1802446789224632, 0.3319874731823802, 0.17517963977297768, 10.657148491591215, 62.43832178413868, 63.1341328471899, 50.082236006855965, 31.94982558488846, 30.739411935210228, 49.34148095548153, 59.69108819961548, 62.9570509493351, 31.109743863344193, 0.1634808542439714, 0.7254465040750802, 5.937435049563646, 6.435631541535258, 2.1340355509892106, 13.864084258675575, 49.84928950667381, 55.21214313805103, 58.5446023195982, 55.81240452826023, 54.990922808647156, 50.125181302428246, 44.86848637461662, 42.26910285651684, 38.962748274207115, 49.60050545632839, 52.48338796198368, 55.14930970966816, 53.14797230064869, 54.49316471815109, 50.51501378417015, 50.23604415357113, 49.36027094721794, 47.74679012596607, 45.694938227534294, 46.93499028682709, 46.08913667500019, 48.575540855526924, 49.059482887387276, 50.61931058764458, 50.43698117136955, 50.176725536584854, 44.06920686364174, 41.23119994997978, 40.34322939813137, 40.93400649726391, 38.09512183070183, 40.619637966156006, 38.993644416332245, 39.2878208309412, 40.18519587814808, 42.58945606648922, 42.51452408730984, 41.34550541639328, 41.488126963377, 40.075412169098854, 37.77325250208378, 41.0405907779932, 40.07192775607109, 39.79129001498222, 43.43128189444542, 40.47664403915405, 40.49053609371185, 43.01196679472923, 46.95664532482624, 47.87325493991375, 47.424005046486855, 46.71782433986664, 43.31791877746582, 42.80537188053131, 41.33318267762661, 50.166925862431526, 58.15988056361675, 53.58466386795044, 51.40846364200115, 45.22543542087078, 50.1790776103735, 56.789541095495224, 52.21736043691635, 52.89422571659088, 55.18507719039917, 56.539377719163895, 52.83795453608036, 54.67952571809292, 54.276017770171165, 56.654560938477516, 51.89343921840191, 44.615742936730385, 38.64720940589905, 40.64829982817173, 40.274992659687996, 41.71548776328564, 40.52471145987511, 41.15973338484764, 41.721943616867065, 41.56083606183529, 43.5760997235775, 41.1482086032629, 40.00082217156887, 41.3266546279192, 41.71201854944229, 40.12063354253769, 38.84563095867634, 39.59800198674202, 41.373069137334824, 40.88377699255943, 40.17999015748501, 39.91066440939903, 42.091903164982796, 48.599019795656204, 47.720244750380516, 50.688588470220566, 50.302627980709076, 50.253739804029465, 52.1147583425045, 51.744741797447205, 51.70494273304939, 55.046137645840645, 53.75147491693497, 50.20775847136974, 49.789085537195206, 55.39342001080513, 57.161206752061844, 56.58017612993717, 49.1205570101738, 41.273305490612984, 44.33240734040737, 48.3433011174202, 51.570125967264175, 56.10330931842327, 56.58820889890194, 54.885345473885536, 55.46325646340847, 57.592213824391365, 61.22573845088482, 59.00840163230896, 60.406555607914925, 16.721441633999348, 1.4227555179968476, 5.422366037964821, 2.436492908746004, 0.45051190070807934, 0.3678028075955808, 36.12030319869518, 74.53811511397362, 62.93455995619297, 66.1132375895977, 46.933135986328125, 52.46518313884735, 62.64968924224377, 65.30608490109444, 45.721589997410774, 2.3637056769803166, 0.2220960785052739, 0.14352812489960343, 0.14304253767477348, 0.1557682774728164, 0.2805736195296049, 0.24079422204522416, 0.09634230140363798, 0.18578303017420694, 0.1201472818502225, 0.14237460476579145], [0.07003202335909009, 0.019216106957173906, 0.043857732744072564, 0.057549385164747946, 0.023201621806947514, 0.0828635117795784, 0.03490371360385325, 0.08018493754207157, 0.04190673411358148, 0.018312558859179262, 0.07706409523962066, 0.08869106313795783, 0.04745353842736222, 3.7270948430523276, 35.86309500038624, 51.43454164266586, 46.369018256664276, 27.78298817574978, 26.848684810101986, 38.25615718960762, 46.23654216527939, 53.589702397584915, 30.659122243523598, 0.25750719476491213, 0.12266170044313185, 2.1626729518175125, 21.688409708440304, 5.120013412088156, 5.074965879321098, 43.08206543326378, 58.055796548724174, 51.10833294689655, 49.506232514977455, 45.090918838977814, 38.057329058647156, 36.64750970900059, 40.786604806780815, 46.46472752094269, 51.22546926140785, 52.516894564032555, 49.1597481071949, 48.922827020287514, 47.31043294072151, 44.53831449151039, 43.87921325862408, 40.70767164230347, 38.32293100655079, 37.98373460769653, 38.87581653892994, 40.419723093509674, 41.123171746730804, 42.721312791109085, 41.402490958571434, 39.9800942838192, 40.08043169975281, 36.88535414636135, 34.70030419528484, 36.008270010352135, 36.25667028129101, 36.77409611642361, 36.29771187901497, 33.747885301709175, 37.300903648138046, 36.798061430454254, 37.882196456193924, 36.24567747116089, 35.994704738259315, 38.097021728754044, 36.45083986222744, 36.70399747788906, 36.4228505641222, 37.378902062773705, 35.95084369182587, 38.4724073857069, 40.25007739663124, 37.22193628549576, 39.34104457497597, 44.46018308401108, 46.53757341206074, 47.79655985534191, 48.92266362905502, 43.643394112586975, 41.864530965685844, 38.25273737311363, 40.15213005244732, 50.533161610364914, 50.473934188485146, 53.57288829982281, 49.25472401082516, 45.295678451657295, 55.40873318910599, 50.05389712750912, 50.08614979684353, 48.51710379123688, 51.61032401025295, 53.14370512962341, 52.44628295302391, 51.38375736773014, 51.967577040195465, 46.28267928957939, 36.873396188020706, 37.60111793875694, 38.6859255284071, 37.5627513974905, 37.58739307522774, 37.59420610964298, 36.88025861978531, 36.826917082071304, 39.23701375722885, 38.19691076874733, 38.15019607543945, 36.787497997283936, 37.86848299205303, 36.05717718601227, 36.90830111503601, 36.20016351342201, 34.693152979016304, 35.977639853954315, 37.19304643571377, 36.429131627082825, 34.81511503458023, 35.77913090586662, 36.21994525194168, 37.631862089037895, 36.30992442369461, 38.52266728878021, 42.25804924964905, 42.622947469353676, 45.68577691912651, 47.474967911839485, 45.131181478500366, 48.074389547109604, 52.251828387379646, 49.870309978723526, 41.665201261639595, 49.893625527620316, 54.711679592728615, 49.36790473759174, 44.572318866848946, 40.23860201239586, 41.162807419896126, 42.93277904391289, 50.13943053781986, 53.58237259089947, 51.570787131786346, 54.52670931816101, 54.119314178824425, 56.10436946153641, 55.137549340724945, 46.98563776910305, 10.625782124698162, 0.7414682849776, 2.789374985732138, 0.723985304357484, 0.33318348869215697, 0.3427186020417139, 33.16398963332176, 64.80236873030663, 48.92567306756973, 39.78092037141323, 25.068527832627296, 31.243893764913082, 46.84231325984001, 48.58322024345398, 28.574107624590397, 0.43616808601655066, 0.0424892198498128, 0.0679851503809914, 0.05042726108513307, 0.04877138489973731, 0.08970131166279316, 0.08923653425881639, 0.02103502927639056, 0.030888767032593023, 0.05967699267785065, 0.11590203386731446, 0.02242472120997263, 0.02356318131205626, 0.02505911725165788, 0.023870942532084882, 0.01889994091470726, 0.07938484297483228, 0.042551345031824894, 0.0791449734242633, 0.022828191649750806, 0.049882435632753186, 0.03726662274857517, 0.09391346728079952, 0.08305004317662679, 4.580827569589019, 43.16106699407101, 56.23455427587032, 51.99461258947849, 29.69938114285469, 25.490603484213352, 44.62348312139511, 54.27703991532326, 57.25368618965149, 34.32866893708706, 0.20963289571227506, 0.035113396297674626, 4.2313403729349375, 16.95025585591793, 7.0713944267481565, 6.934975096955895, 43.57194274663925, 60.93457527458668, 55.37304550409317, 52.04268001019955, 48.07107612490654, 41.35973945260048, 38.47126744687557, 41.12095646560192, 46.76965735852718, 53.323655873537064, 54.21515643596649, 50.73197454214096, 52.169642597436905, 47.43663936853409, 47.98668645322323, 44.59760271012783, 42.9168426990509, 40.154493525624275, 40.19462697207928, 41.60019055008888, 42.40972191095352, 44.97800409793854, 43.63837458193302, 45.063564106822014, 42.74568848311901, 43.710392117500305, 38.51683460175991, 36.38659290969372, 37.28247843682766, 39.16885681450367, 38.039002642035484, 37.76356682181358, 36.621583700180054, 38.30136716365814, 37.39291951060295, 39.8052466660738, 36.92127361893654, 37.72334598004818, 40.09307362139225, 37.38362140953541, 37.92041100561619, 39.07100826501846, 38.331742733716965, 39.04624119400978, 41.18350110948086, 40.144074484705925, 39.76968437433243, 41.01207710802555, 46.60795323550701, 47.50932566821575, 48.789818957448006, 50.53976185619831, 46.4495625346899, 43.164710998535156, 39.67140644788742, 40.56077152490616, 51.38296701014042, 53.008519783616066, 55.25776728987694, 48.39160792529583, 48.54681819677353, 55.8174392580986, 51.46731488406658, 52.52981387078762, 50.119170024991035, 52.262786999344826, 54.11274433135986, 51.73297002911568, 51.7240709066391, 52.873490229249, 47.53025494515896, 38.66997018456459, 39.35491383075714, 40.303263142704964, 38.981716856360435, 38.64503972232342, 39.79563318192959, 40.124976709485054, 37.95891813933849, 40.57751722633839, 39.92080606520176, 38.63517165184021, 40.8262974768877, 39.61293898522854, 38.50569359958172, 39.1128896176815, 38.49417641758919, 37.65889383852482, 36.16683170199394, 38.4828682243824, 38.80966208875179, 37.34641760587692, 38.05154576897621, 38.834026381373405, 38.5772779583931, 37.84875825047493, 41.241527795791626, 43.7716980278492, 45.108071118593216, 48.16993921995163, 48.712238520383835, 47.96137981116772, 51.713150292634964, 54.00653623044491, 49.63152699172497, 44.749043583869934, 54.58083361387253, 57.90160082280636, 52.626476883888245, 46.01704314351082, 41.473554745316505, 42.15544335544109, 45.01543588936329, 50.59555046260357, 56.843171417713165, 53.33711855113506, 58.2889748364687, 58.077896162867546, 58.2950659096241, 58.40578056871891, 50.60962110757828, 11.683419272303581, 2.142895725555718, 4.567371541634202, 0.6194968486670405, 0.1516866878955625, 0.32230520679149777, 34.957561790943146, 71.24887481331825, 54.9142125248909, 45.9595712274313, 30.21248660981655, 37.0784217864275, 54.101949110627174, 57.53337398171425, 35.90711943805218, 1.0105880722403526, 0.060994635059614666, 0.07467707371688448, 0.025176539857056923, 0.046215127731557004, 0.05829579647979699, 0.03298395939054899, 0.055339577374979854, 0.036617785299313255, 0.04178648392553441, 0.0200998805303243, 0.20188880735076964, 0.1524148089811206, 0.16713182005332783, 0.10561050134128891, 0.19585256406571716, 0.14798605756368488, 0.11357726369169541, 0.19233801984228194, 0.18754542310489342, 0.18730435869656503, 0.20948611374478787, 0.18436595855746418, 0.10671351090422831, 5.660822717472911, 50.52368871867657, 64.46618556976318, 59.663748666644096, 38.89814414083958, 37.07068160176277, 52.13042110204697, 60.497135147452354, 63.23612317442894, 38.03626298904419, 0.5592993507161736, 0.30750835547223687, 6.3054742757231, 35.57292737066746, 12.567685972899199, 7.485968330875039, 46.68035835027695, 62.11697302758694, 56.54646433889866, 54.411719888448715, 50.63418298959732, 42.38737910985947, 40.84933944046497, 44.78033870458603, 51.44839949905872, 57.41606667637825, 55.82936681807041, 52.18220852315426, 52.65682205557823, 52.782211527228355, 51.73778057098389, 47.83413603901863, 45.64681001007557, 42.415873780846596, 41.74617491662502, 44.1875097155571, 44.688615426421165, 45.21305188536644, 45.98842307925224, 47.319670245051384, 44.454623982310295, 45.5918725579977, 40.345505475997925, 38.52510295808315, 39.07331854104996, 41.214009672403336, 40.990505665540695, 39.761096835136414, 37.380668967962265, 40.57133875787258, 40.0438966602087, 42.22624495625496, 39.39161226153374, 39.933535382151604, 41.40680372714996, 38.957998529076576, 38.01206208765507, 40.72823993861675, 40.66770538687706, 41.270793825387955, 42.8039925545454, 42.66463503241539, 41.75202280282974, 43.34675543010235, 47.3057895898819, 50.497557520866394, 53.03979970514774, 53.00367884337902, 48.752086982131004, 45.63857965171337, 40.573356449604034, 43.715776428580284, 52.87831977009773, 55.32707557082176, 58.72138403356075, 50.81272020936012, 50.307180136442184, 58.10342699289322, 52.67519026994705, 53.85462798178196, 52.164463475346565, 53.89863342046738, 54.96432803571224, 54.6448639780283, 54.853161200881004, 55.15537038445473, 50.54556034505367, 40.92932514846325, 41.27461262047291, 42.932201474905014, 41.620671451091766, 40.146270766854286, 41.27502299845219, 40.2918903529644, 39.34446819126606, 42.19705872237682, 42.16244637966156, 41.39441639184952, 41.42820417881012, 41.80787980556488, 40.22127874195576, 40.67888058722019, 40.07842920720577, 39.39584523439407, 38.518571108579636, 41.42119735479355, 40.93765810132027, 37.91637562215328, 38.912313580513, 40.746600553393364, 41.01401500403881, 41.178276389837265, 43.704749420285225, 47.854290157556534, 46.28447659313679, 50.724397748708725, 51.76702380180359, 50.87237320840359, 52.24666826426983, 54.857295379042625, 50.599593445658684, 45.761069878935814, 57.8010506182909, 58.2810864597559, 55.26076152920723, 48.87544356286526, 44.00505490601063, 44.46158520877361, 47.209985330700874, 54.43556360900402, 59.95338812470436, 54.89855736494064, 61.06232441961765, 60.76407082378864, 63.23546580970287, 61.41520768404007, 51.46617114543915, 13.728392589837313, 2.336735911667347, 9.44648215547204, 3.4689003601670265, 0.5206094111781567, 0.37851956847589463, 38.84872019290924, 75.6335811316967, 63.253123462200165, 52.37695187330246, 36.129198521375656, 44.638526514172554, 64.05419647693634, 65.13417452573776, 43.69852535426617, 1.525261311326176, 0.2015173327527009, 0.2011975264758803, 0.12369949748972431, 0.17276596772717312, 0.1774076561559923, 0.2011251077055931, 0.11048489017412066, 0.15496134030399844, 0.24103852221742272, 0.2265657519455999], [0.08868525954312645, 0.04457731913134921, 0.03936326414986979, 0.05087405625090469, 0.03133135978714563, 0.03042611959244823, 0.04220942275424022, 0.024958446774689946, 0.0749859852658119, 0.07409124460536987, 0.05053570741438307, 0.09509280673228204, 0.04454377405636478, 0.7630953588522971, 28.777867890894413, 53.082669004797935, 48.164551109075546, 35.124768018722534, 20.55908750742674, 31.887763515114784, 43.64725470542908, 51.384353935718536, 41.722141206264496, 2.9887699987739325, 0.13975286419736221, 10.356896203011274, 43.19425441324711, 7.625023769214749, 6.56692304648459, 47.225070521235466, 54.89368602633476, 49.310778602957726, 44.29951250553131, 37.17505060136318, 40.08221760392189, 47.131101563572884, 49.37863916158676, 49.81190711259842, 50.536497831344604, 50.20945318043232, 50.22329583764076, 48.27934294939041, 45.041380897164345, 41.57604664564133, 39.06015604734421, 36.751669719815254, 35.58801256120205, 36.063408851623535, 35.78525997698307, 37.774270847439766, 38.59921798110008, 38.07364918291569, 35.887839272618294, 37.17407405376434, 37.14017987251282, 36.92377768456936, 35.59626191854477, 37.28767275810242, 35.0820355117321, 34.41713958978653, 37.05117344856262, 37.089300602674484, 35.83472952246666, 36.90371096134186, 36.41670249402523, 37.107266038656235, 36.62224106490612, 37.267674431204796, 38.51608604192734, 36.79403744637966, 38.25090207159519, 37.27437727153301, 35.885217413306236, 40.19828997552395, 40.76452799141407, 36.03141076862812, 39.066258519887924, 45.7552295923233, 46.726457476615906, 50.21902486681938, 49.528408125042915, 44.629995971918106, 42.594004422426224, 40.560193955898285, 37.99539238214493, 44.36897277832031, 50.43490648269653, 53.377783969044685, 49.24643665552139, 47.06517890095711, 54.83601272106171, 49.22346688807011, 50.25592848658562, 50.58776468038559, 51.05892039835453, 49.95735950767994, 50.648310631513596, 50.217603743076324, 50.65832309424877, 42.805349081754684, 36.17638058960438, 36.70499302446842, 37.65454687178135, 37.22525350749493, 36.585869416594505, 37.6039981842041, 38.418043702840805, 38.57452690601349, 38.754432052373886, 38.57320457696915, 38.84796403348446, 37.39274092018604, 36.45634576678276, 37.85985365509987, 35.301238149404526, 37.995988950133324, 36.799554750323296, 36.32036626338959, 35.43926194310188, 37.378689274191856, 35.23319140076637, 34.22884829342365, 35.06576098501682, 37.00867272913456, 36.92157760262489, 36.56529352068901, 38.238393142819405, 41.88934363424778, 42.63503462076187, 43.175411224365234, 45.037470906972885, 48.83065916597843, 46.64924941956997, 50.42388707399368, 53.85859116911888, 41.92902870476246, 50.10526657104492, 48.30234311521053, 50.134031027555466, 45.68295367062092, 40.83643913269043, 41.021831184625626, 43.78842853009701, 50.14847405254841, 54.535597041249275, 55.34146919846535, 55.70017755031586, 57.20409885048866, 57.00135312974453, 41.224531307816505, 6.164370272308588, 2.287792875431478, 3.526771254837513, 0.9645317529793829, 0.09754883314599283, 0.4701848700642586, 35.95724634826183, 59.41418945789337, 51.840519458055496, 47.89417661726475, 35.282277166843414, 31.399227529764175, 39.92831826210022, 48.286060988903046, 18.361935205757618, 0.37415995553601533, 0.05001346922654193, 0.04915032550343312, 0.04978847973688971, 0.039225421351147816, 0.0392197364999447, 0.0805393056361936, 0.02053764746960951, 0.04829176454222761, 0.052621075592469424, 0.029307545337360352, 0.023667902059969492, 0.02025490590312984, 0.03120971807220485, 0.04904656583676115, 0.015763110895932186, 0.05784072265669238, 0.05766048838268034, 0.10867996476008557, 0.027260253045824356, 0.08043127119890414, 0.005429132625067723, 0.012260254570719553, 0.02727713690546807, 1.2103357538580894, 35.9176866710186, 60.822435691952705, 51.426379680633545, 39.50741104781628, 23.560358360409737, 35.36691762506962, 50.77275015413761, 57.25126951932907, 47.025680020451546, 2.583224647678435, 0.16291936015477404, 3.687751516699791, 34.984255358576775, 9.313480742275715, 6.351070404052734, 50.11995278298855, 56.32682852447033, 53.121943697333336, 46.873281598091125, 38.64278644323349, 41.32838353514671, 48.035844415426254, 51.94108486175537, 52.395890057086945, 51.83977089822292, 49.92248497903347, 52.546985149383545, 51.81516721844673, 48.83696682751179, 44.675787314772606, 40.025547444820404, 39.32616077363491, 38.2046053558588, 37.62276537716389, 38.263141214847565, 40.31302101910114, 40.34018576145172, 40.6038574129343, 38.859108835458755, 39.406351670622826, 38.27410742640495, 37.945086881518364, 38.224029913544655, 38.840501233935356, 37.33382888138294, 36.930290535092354, 38.16540665924549, 38.54221723973751, 38.03080268204212, 38.362391889095306, 38.461486771702766, 37.52952218055725, 38.2892382144928, 38.71641129255295, 39.20570723712444, 37.88484871387482, 39.73512522876263, 37.485148161649704, 37.4197156727314, 40.63259907066822, 40.25513872504234, 36.99914664030075, 41.61291226744652, 47.571285143494606, 48.99550952017307, 51.18569299578667, 50.934302285313606, 46.90113790333271, 44.797338992357254, 42.581510692834854, 38.27827200293541, 44.91299718618393, 52.739961594343185, 54.94643859565258, 49.86663557589054, 49.86796550452709, 55.02004824578762, 52.194398269057274, 50.75838692486286, 51.38609044253826, 54.16899651288986, 52.09425464272499, 52.75504298508167, 53.03985670208931, 52.205649465322495, 44.88826431334019, 37.748390436172485, 38.86948227882385, 39.009071588516235, 38.16467709839344, 38.79347115755081, 40.38479536771774, 40.347846150398254, 40.15171967446804, 38.86123292148113, 38.95543746650219, 39.23831708729267, 39.86951261758804, 37.64588713645935, 39.38734509050846, 37.03950807452202, 39.34549033641815, 38.66933561861515, 39.432976841926575, 38.650336638092995, 38.37594956159592, 37.286057844758034, 36.64774529635906, 37.279841378331184, 38.11374843120575, 39.17718976736069, 39.46890391409397, 40.52848845720291, 43.88474576175213, 44.7503887116909, 45.729326382279396, 47.09918327629566, 50.077588856220245, 49.640707299113274, 52.290236726403236, 52.902710661292076, 43.5879360884428, 54.887461960315704, 51.92984126508236, 51.531656831502914, 49.11945506930351, 43.261643797159195, 42.9588570445776, 44.27288733422756, 52.956519573926926, 55.39155811071396, 57.724716514348984, 58.536907732486725, 57.82556310296059, 59.79467824101448, 44.611832946538925, 7.630070373415947, 2.6230804715305567, 2.7644846588373184, 1.7054819595068693, 0.08752704903599806, 0.4987132048700005, 38.96087497472763, 66.31163254380226, 57.09322080016136, 47.07657068967819, 30.388924442231655, 36.524753496050835, 47.92420260608196, 55.95555804669857, 24.347556419670582, 0.4976011114194989, 0.08190266802557744, 0.03893284818332177, 0.012344584811216919, 0.02440887899865629, 0.08471603112411685, 0.02673293671250576, 0.0586071459838422, 0.0313807868224103, 0.049910102898138575, 0.04401976955705322, 0.12356070845271461, 0.1369541956228204, 0.22135305509436876, 0.14155788609059528, 0.09208799179759808, 0.22972109669353813, 0.12567591096740216, 0.2695978491101414, 0.1479616854339838, 0.1504907020716928, 0.08503666118485853, 0.19985321501735598, 0.14452603150857612, 1.1550255655311048, 42.1531330794096, 68.57692658901215, 60.7699529081583, 48.71892996132374, 32.771907672286034, 45.01116491854191, 57.63106293976307, 60.633559226989746, 53.846967592835426, 3.93770020455122, 0.16729712602682412, 13.296755701303482, 52.401456758379936, 12.107094638049603, 7.2705702390521765, 53.598156943917274, 57.940974310040474, 56.19124040007591, 48.446279391646385, 42.01911047101021, 43.16510997712612, 52.09885239601135, 53.48017327487469, 55.19209921360016, 52.83573925495148, 54.38586227595806, 54.357439801096916, 54.11316990852356, 49.453453347086906, 47.07573853433132, 42.497440204024315, 41.118456199765205, 39.61442090570927, 39.92429427802563, 39.919206351041794, 41.851300075650215, 44.187171533703804, 41.48042097687721, 41.041878908872604, 41.75432167947292, 40.249883607029915, 39.359059408307076, 40.19681565463543, 40.56557446718216, 38.589505702257156, 36.86903402209282, 41.40858583152294, 41.798794493079185, 39.68848653137684, 41.02820344269276, 40.60990288853645, 39.9848972260952, 40.80685772001743, 41.07422657310963, 41.64603129029274, 39.091462567448616, 41.53316594660282, 39.990741312503815, 39.38256874680519, 45.03707192838192, 43.32355007529259, 39.09402742981911, 44.68691311776638, 51.03330597281456, 50.82691624760628, 54.589242562651634, 53.31846535205841, 47.91832432150841, 47.192073091864586, 44.866274893283844, 40.38204051554203, 46.76645793020725, 54.360817819833755, 56.67866684496403, 51.97426848113537, 53.473079055547714, 56.701458021998405, 53.62575486302376, 52.81104438006878, 54.14735287427902, 55.19928462803364, 53.438272923231125, 54.80961173772812, 54.62311014533043, 54.514929950237274, 46.22509717941284, 39.437779784202576, 40.82879774272442, 40.33887103199959, 41.04091756045818, 40.2447272837162, 43.658521100878716, 42.698931992053986, 42.505260184407234, 40.93195840716362, 40.81515647470951, 41.49871699512005, 42.40027941763401, 39.71461392939091, 41.79643861949444, 38.92194986343384, 41.43269553780556, 40.5825861543417, 40.98992049694061, 39.341899529099464, 41.46959535777569, 38.9585343003273, 38.272264525294304, 39.10475805401802, 39.52292941510677, 42.111411318182945, 42.16792568564415, 43.753310814499855, 46.2645048648119, 47.7522998303175, 48.38965103030205, 49.71566967666149, 52.56136357784271, 51.266168877482414, 55.522240698337555, 54.180129915475845, 44.13743980228901, 57.24488966166973, 52.518300488591194, 54.81740891933441, 53.07217016816139, 46.64634257555008, 45.80319061875343, 47.335792779922485, 55.05443260073662, 57.621096074581146, 60.997556895017624, 61.0663940012455, 63.794981986284256, 61.03220723569393, 47.528039664030075, 8.481124956160784, 4.770156210288405, 9.422433245927095, 3.961755526252091, 0.36241858557332307, 0.6149300874676555, 42.75242932140827, 71.13903790712357, 65.70242643356323, 60.94692841172218, 47.5307185202837, 45.653588846325874, 54.37235780060291, 66.31790980696678, 30.830882526934147, 0.5912871030159295, 0.17202153423568234, 0.18465811241185293, 0.13595522032119334, 0.11243578119319864, 0.14671863260446116, 0.19997859344584867, 0.14458423072937876, 0.14117392856860533, 0.14334557141410187, 0.10792215034598485], [0.09581236343365163, 0.11709016776876524, 0.07200684864073992, 0.039300070275203325, 0.0254981217221939, 0.06280270346906036, 0.05726302748371381, 0.06869502205518074, 0.046288366575026885, 0.07785488327499479, 0.044732197929988615, 0.05548755420022644, 0.09038218020577915, 0.17451097955927253, 22.830516323447227, 48.956193029880524, 44.433417320251465, 33.64701971411705, 21.77067719399929, 34.19888310134411, 45.58135472238064, 50.6230191886425, 47.55688011646271, 6.882244376465678, 0.379154312540777, 5.135613474994898, 27.52630814909935, 11.27147862687707, 6.421328634023666, 52.20786474645138, 53.76598633825779, 49.513505324721336, 41.03829190135002, 45.47338731586933, 48.972942531108856, 52.378627583384514, 48.23043957352638, 50.63508354127407, 50.899503752589226, 51.83685265481472, 49.188565760850906, 45.27889855206013, 44.10877414047718, 36.33242301642895, 35.20842432975769, 36.81212067604065, 34.524977803230286, 34.335379377007484, 34.2233157902956, 35.86120270192623, 36.841580495238304, 35.79099766910076, 34.68488462269306, 35.63691973686218, 36.34765259921551, 36.6428055614233, 36.01641297340393, 35.63030809164047, 36.23773209750652, 35.90586170554161, 36.695561930537224, 36.53562471270561, 35.68026401102543, 37.3972474783659, 37.53636561334133, 37.25580386817455, 35.42638063430786, 38.93901474773884, 37.41859473288059, 38.74925673007965, 36.92819684743881, 38.610761761665344, 35.859378799796104, 38.29320140182972, 38.32399494946003, 36.73964336514473, 38.88737931847572, 45.8580406755209, 46.81615926325321, 60.52003271877766, 51.73503711819649, 46.42982259392738, 44.446435421705246, 40.1633470505476, 37.644397616386414, 42.19197079539299, 49.413551688194275, 54.94257800281048, 49.954243674874306, 44.09544825553894, 54.29349683225155, 50.10828360915184, 52.31772065162659, 48.7307321280241, 52.93837554752827, 49.50070761144161, 50.295750349760056, 51.2825345993042, 50.05775772035122, 40.634555965662, 35.60864545404911, 38.21996033191681, 39.73265156149864, 37.41258345544338, 36.37400038540363, 36.186788231134415, 38.00074249505997, 37.07180254161358, 38.608155101537704, 38.50347451865673, 37.759881019592285, 36.825872138142586, 37.92936712503433, 37.70713225007057, 38.22838068008423, 37.2265188395977, 36.94528453052044, 37.115120217204094, 37.45585173368454, 36.1071103066206, 36.283249855041504, 35.95046751201153, 35.93945190310478, 37.15446710586548, 34.996802285313606, 36.30234383046627, 37.094977498054504, 37.94579364359379, 41.99366323649883, 43.10735687613487, 44.299953281879425, 44.830473214387894, 51.434655636548996, 53.14439669251442, 49.133571311831474, 49.2713937163353, 44.62276875972748, 49.68544989824295, 48.26388917863369, 45.11763520538807, 44.47948984801769, 47.22764678299427, 44.97540503740311, 41.546134650707245, 48.89878951013088, 55.33466376364231, 55.04072293639183, 55.041935071349144, 53.48534859716892, 35.37608653306961, 5.935941254720092, 2.367616379633546, 2.161310249939561, 0.5652956070844084, 0.04091478323971387, 0.628820420242846, 34.49041485786438, 62.156202122569084, 44.45318765938282, 39.33679260313511, 27.600301578640938, 33.880809769034386, 46.42446108162403, 44.153771325945854, 11.228987406939268, 0.1276923855766654, 0.09562350911437534, 0.07100038506905548, 0.025158429598377552, 0.10127272238605656, 0.04067342568305321, 0.017374441522406414, 0.02259575470816344, 0.034182950912509114, 0.0321039911796106, 0.1233503466937691, 0.0898599234642461, 0.06352547366986983, 0.07731794685241766, 0.04098478631931357, 0.06841592257842422, 0.045747767653665505, 0.0070069715184217785, 0.06694615105516277, 0.060523705251398496, 0.01897998710774118, 0.015297220270440448, 0.039079437192413025, 0.11861538514494896, 0.2125158128910698, 27.30203278362751, 55.49674406647682, 51.41346797347069, 40.310399159789085, 24.0729508548975, 40.834307447075844, 51.848749816417694, 55.11474296450615, 52.171512097120285, 7.871005944907665, 0.47068056534044445, 4.088340271264315, 27.780499309301376, 7.341794092208147, 5.874662417918444, 55.682261511683464, 55.06064526736736, 51.34438008069992, 42.67232581973076, 46.23210780322552, 51.18862643837929, 54.533100575208664, 49.50414262712002, 51.9846723228693, 52.938158959150314, 54.365730956196785, 51.05205796658993, 48.21612574160099, 46.2169124186039, 38.57988841831684, 36.81340120732784, 38.738480508327484, 36.93653739988804, 37.83206954598427, 36.33383274078369, 39.45446088910103, 39.01854448020458, 38.02931696176529, 36.60142578184605, 39.595691710710526, 37.741839587688446, 37.534697502851486, 36.820776611566544, 37.56415352225304, 38.414612486958504, 37.787330746650696, 37.79314063489437, 37.86481238901615, 38.31497423350811, 38.97702410817146, 39.16109003126621, 37.84217320382595, 36.62871591746807, 40.576350688934326, 39.045944809913635, 39.82674591243267, 38.367210030555725, 40.66939629614353, 38.07010397315025, 41.32166929543018, 39.760276079177856, 38.48659202456474, 40.39752468466759, 47.82813236117363, 48.98682698607445, 56.94325424730778, 55.80761298537254, 48.893834576010704, 45.20344220101833, 41.992337107658386, 40.780354142189026, 43.92389506101608, 51.437706872820854, 55.05339525640011, 50.812363028526306, 48.99761080741882, 55.474773645401, 51.07413478195667, 53.12660984694958, 51.59043587744236, 53.99267077445984, 51.46203696727753, 53.622160255908966, 52.524311766028404, 52.37596772611141, 41.87860161066055, 38.30466918647289, 40.34596525132656, 40.18711477518082, 39.43576969206333, 38.074709326028824, 39.016496390104294, 38.942768946290016, 39.050728753209114, 39.923640713095665, 41.972980946302414, 39.04515825212002, 38.01143892109394, 39.378662556409836, 39.55376476049423, 40.48272371292114, 38.04046556353569, 38.13438132405281, 38.380133137106895, 39.908711314201355, 38.496258705854416, 37.41881512105465, 39.00450423359871, 38.14893074333668, 37.76182271540165, 36.196770295500755, 38.2381347566843, 38.88502724468708, 40.256255865097046, 43.89104962348938, 46.855110973119736, 46.33123308420181, 47.93074205517769, 52.916602715849876, 54.14520598948002, 51.51739999651909, 50.8748696744442, 47.729865834116936, 51.69609300792217, 50.179719775915146, 48.963268250226974, 47.387131825089455, 49.28732626140118, 46.87714219093323, 45.44231258332729, 51.5385914593935, 57.88529209792614, 58.017825186252594, 58.40283192694187, 55.533089116215706, 38.16449470818043, 6.228958256542683, 1.9264348782598972, 4.004510119557381, 0.27834162523504347, 0.12484473525546491, 0.6305195821914822, 39.5864924043417, 68.303082883358, 50.43682537972927, 51.00509628653526, 37.32310965657234, 41.65270373225212, 52.072983384132385, 53.12751419842243, 15.58403916656971, 0.34152629727032036, 0.007537246701758704, 0.03203273758117575, 0.04995050170691684, 0.09767798910615966, 0.028501741799118463, 0.01626708482945105, 0.015575766847177874, 0.010613420527079143, 0.005919503455515951, 0.05846244574058801, 0.16633401130093262, 0.22683874354697764, 0.16313219326548278, 0.11987178921117447, 0.14468750800006092, 0.1757717103464529, 0.15546907321549952, 0.1423815215821378, 0.12978163518710062, 0.14232876972528175, 0.19853358739055693, 0.09926558399456553, 0.2334467670880258, 0.2860411105211824, 31.454218178987503, 62.52817936241627, 57.665549889206886, 46.70189179480076, 33.90944883227348, 46.48294374346733, 58.673115223646164, 57.44877152144909, 58.71451020240784, 9.360904097557068, 0.37752802949398756, 6.412694547325373, 34.134978130459785, 17.70562682300806, 7.4366450775414705, 60.09235046803951, 56.41287110745907, 55.01665122807026, 45.91585837304592, 51.48186810314655, 51.89517192542553, 57.17469982802868, 51.02964676916599, 52.80591085553169, 54.280357137322426, 56.48144602775574, 52.933306619524956, 50.811435878276825, 48.806264474987984, 39.46015678346157, 37.903593108057976, 40.33925101161003, 40.15808433294296, 39.25844840705395, 38.920224756002426, 40.35000443458557, 40.86113400757313, 39.01455469429493, 37.84275457262993, 39.3489595502615, 40.045040398836136, 39.961653873324394, 39.09695327281952, 40.29399164021015, 39.87941488623619, 40.083817318081856, 40.111685022711754, 42.54471346735954, 40.06761498749256, 40.64385026693344, 41.57746396958828, 40.25595188140869, 38.51726397871971, 42.13251918554306, 42.4865347892046, 41.68450802564621, 40.13122357428074, 43.64986516535282, 39.766800329089165, 42.98274256289005, 40.82292325794697, 40.35977751016617, 42.655086144804955, 49.748036339879036, 51.062526404857635, 57.251334115862846, 57.34729416668415, 52.64904007315636, 47.53109849989414, 44.89392600953579, 43.650484532117844, 45.136231407523155, 53.50948870182037, 59.60553199052811, 53.87148767709732, 50.21316938102245, 57.01728567481041, 51.91258639097214, 56.990706101059914, 52.14220426976681, 55.45092612504959, 53.10119681060314, 55.69321632385254, 55.69497562944889, 53.705140203237534, 43.88769440352917, 40.54136596620083, 42.15151436626911, 41.49411924183369, 41.124193891882896, 39.290602281689644, 40.77433906495571, 40.60063138604164, 40.1153252273798, 41.547008603811264, 43.01189839839935, 40.7658427208662, 39.87751878798008, 40.86646892130375, 41.17005743086338, 42.06031545996666, 41.45534232258797, 41.00260801613331, 41.423234045505524, 43.32657091319561, 40.16845017671585, 38.79651479423046, 41.096690967679024, 39.703636318445206, 39.985896572470665, 38.564731031656265, 40.0316309183836, 40.73889836668968, 42.755674347281456, 48.95440712571144, 49.85132239758968, 47.71173320710659, 49.92310054600239, 54.57932509481907, 55.36474674940109, 53.94580788910389, 52.282431945204735, 48.03095407783985, 55.3382583707571, 51.01249448955059, 50.07250472903252, 49.08362679183483, 51.86011120676994, 49.69745725393295, 47.20238193869591, 54.637256786227226, 62.79031589627266, 61.456139087677, 61.46628834307194, 56.98768526315689, 38.187156692147255, 8.41516524553299, 5.162307992577553, 9.311743285506964, 3.959857290610671, 0.3287204500520602, 0.6514036178123206, 42.56717026233673, 73.17062169313431, 55.89419133961201, 56.13873861730099, 41.7160539329052, 49.707101136446, 60.03509894013405, 64.82311561703682, 22.473282292485237, 0.5917814327403903, 0.18089729390339926, 0.14947437535738572, 0.12208589774672873, 0.2042876958148554, 0.06434992552385665, 0.10308702854672447, 0.23521000606706366, 0.2571801748126745, 0.1198399807617534, 0.272820521495305], [0.03181282809237018, 0.031609457364538684, 0.11158768451423384, 0.012490638546296395, 0.08701563507202081, 0.07119392976164818, 0.0673591265513096, 0.07354277520789765, 0.018060505099128932, 0.07401909300824627, 0.04062085565237794, 0.06614034937229007, 0.016072664402599912, 0.023967831766640302, 14.302334692329168, 51.59809626638889, 42.76825167238712, 40.85220828652382, 27.74828463792801, 29.198474921286106, 41.974371671676636, 49.8979838937521, 49.96895648539066, 14.19821172952652, 0.35862092685420066, 2.5001960154622793, 18.89649622142315, 3.4042589413002133, 4.9577350448817015, 46.5131027251482, 55.76990760862827, 50.60525894165039, 49.373410642147064, 48.870690017938614, 51.66045852005482, 50.7901456207037, 52.64275901019573, 51.81242376565933, 51.12206920981407, 50.15427254140377, 46.20025411248207, 46.31732203066349, 39.01523485779762, 35.103451162576675, 35.79654537141323, 35.79035550355911, 36.01032570004463, 34.49972055852413, 34.351767897605896, 34.79846812784672, 35.98950281739235, 35.31834103167057, 34.938764199614525, 36.32059045135975, 35.95390632748604, 35.36247566342354, 34.860336408019066, 36.953256502747536, 35.416375771164894, 35.23867070674896, 36.43893130123615, 36.57920077443123, 37.1351071447134, 36.64056748151779, 37.62682355940342, 36.645632609725, 36.864478066563606, 37.57493734359741, 38.306789472699165, 36.458922028541565, 36.11970283091068, 38.04941788315773, 37.64791242778301, 35.94168998301029, 36.55376113951206, 35.17501272261143, 40.704479813575745, 46.80436089634895, 50.10429762303829, 52.22727790474892, 45.00154383480549, 48.56554739177227, 42.10171803832054, 39.56217370927334, 38.43950495123863, 40.78950025141239, 51.47989980876446, 53.3529257029295, 50.76855517923832, 43.44321325421333, 51.24470002949238, 50.101599767804146, 49.67809349298477, 50.6887024641037, 53.81542928516865, 52.298527881503105, 49.275045320391655, 52.5870767980814, 46.15879073739052, 38.49785462021828, 37.73718483746052, 36.55971921980381, 38.45274344086647, 38.068614453077316, 37.90015049278736, 38.50059427320957, 37.71330311894417, 37.12628021836281, 37.9274520277977, 36.62998124957085, 36.60750165581703, 37.14783266186714, 37.161272540688515, 36.05127610266209, 36.390696689486504, 35.48110909759998, 36.497003585100174, 35.58764398097992, 35.37730626761913, 35.64911708235741, 35.76588861644268, 35.55974207818508, 36.35211355984211, 35.200874134898186, 36.75245247781277, 38.263999968767166, 38.392144292593, 39.80517826974392, 39.10198800265789, 43.98329347372055, 44.785031452775, 49.24390219151974, 49.08769637346268, 48.24826821684837, 46.4365254342556, 50.76976731419563, 49.528871700167656, 47.101508751511574, 46.84665262699127, 45.37539057433605, 49.33357737958431, 53.18889610469341, 53.767612650990486, 49.02804717421532, 45.19864305853844, 49.62176151573658, 54.80010084807873, 52.47413545846939, 53.438212126493454, 32.35896863043308, 6.240166705101728, 1.7261594999581575, 0.7577550422865897, 0.7063931389711797, 0.20544097846141085, 0.4940984712447971, 37.44972266256809, 59.04829189181328, 51.59517802298069, 33.21471311151981, 20.148487240076065, 36.57174937427044, 41.933356672525406, 47.818876057863235, 10.036437548696995, 0.05535185249755159, 0.02656327804288594, 0.020720139727927744, 0.07738945278106257, 0.04656762561353389, 0.020563518737617414, 0.03534326169756241, 0.06749401189154014, 0.0849958579055965, 0.06136819509265479, 0.01628434532904066, 0.05227532012213487, 0.03899160772562027, 0.014086930477787973, 0.035118179439450614, 0.05058063703472726, 0.052597883477574214, 0.03213805946870707, 0.10284707735991105, 0.05447720177471638, 0.03460550382442307, 0.009217604019795544, 0.012329532200965332, 0.05649955048284028, 0.043143037109985016, 18.40180266648531, 58.57320338487625, 48.58536332845688, 44.61296908557415, 27.84559741616249, 36.78768418729305, 47.87305735051632, 53.940795958042145, 55.481157302856445, 15.551120582967997, 0.2350153704173863, 2.9088246636092663, 25.046933591365814, 5.018100030720234, 6.140993926674128, 50.76769262552261, 56.397295743227005, 50.95975711941719, 50.04834182560444, 52.54576921463013, 53.91422778367996, 52.96169109642506, 54.03131850063801, 54.8591610789299, 52.949710339307785, 52.57503904402256, 50.04493720829487, 49.09790642559528, 40.80610916018486, 36.55523166060448, 38.06169502437115, 38.63278158009052, 37.87001051008701, 37.6876886934042, 36.582423001527786, 36.45683974027634, 38.052184134721756, 37.49467425048351, 37.47372977435589, 37.78876706957817, 37.11856283247471, 37.21759311854839, 37.505686059594154, 38.402282148599625, 37.032421454787254, 37.479695454239845, 37.890704199671745, 37.46432147920132, 39.26357053220272, 38.373985067009926, 39.60791565477848, 38.30550134181976, 39.51872304081917, 40.38074478507042, 39.142269641160965, 38.39738041162491, 38.69406469166279, 39.82995294034481, 36.21640384197235, 36.71798072755337, 38.118984550237656, 36.1831746250391, 41.43823564052582, 48.128662034869194, 52.77233965694904, 57.61001966893673, 48.357979729771614, 52.326080203056335, 44.487355425953865, 42.85500481724739, 39.785434529185295, 41.147277653217316, 53.330335915088654, 53.120640367269516, 49.91089180111885, 48.348522037267685, 55.40743365883827, 50.79694725573063, 52.67307758331299, 54.45798620581627, 53.36482286453247, 52.95456647872925, 51.89407378435135, 53.46959464251995, 47.735706120729446, 40.348009541630745, 39.153767824172974, 39.27206687629223, 40.0745952129364, 39.80112388730049, 38.57764653861523, 40.49778610467911, 38.538189455866814, 39.00418125092983, 40.53772576153278, 40.117688700556755, 38.65465320646763, 39.120926186442375, 37.35921151936054, 37.542825266718864, 37.55616635084152, 37.07511216402054, 38.81216995418072, 38.227476328611374, 36.97845295071602, 38.81806343793869, 37.66841612756252, 36.92686311900616, 39.65898871421814, 36.54194377362728, 37.77143619954586, 38.21222014725208, 40.29645770788193, 41.042650267481804, 41.17460958659649, 47.108454778790474, 46.959882751107216, 50.33370651304722, 52.01195865869522, 51.83690205216408, 45.97497560083866, 52.851310819387436, 51.979626193642616, 48.70558127760887, 49.042554795742035, 48.663171753287315, 52.098092436790466, 54.26137715578079, 56.03391744196415, 51.92166030406952, 46.504986360669136, 52.21633069217205, 58.26453074812889, 55.47286234796047, 54.75845128297806, 35.03213658928871, 7.036709887906909, 2.466962286271155, 2.989661288447678, 0.6532247888389975, 0.11163507064338773, 0.5887669476214796, 40.15442132949829, 66.26395270228386, 56.27984784543514, 40.11477045714855, 22.970067635178566, 41.408597230911255, 49.30662162601948, 55.80098234117031, 14.564864505082369, 0.09279582256567664, 0.0633875752100721, 0.04298779836972244, 0.01681753019511234, 0.04140096418268513, 0.04629503848263994, 0.026864692044910043, 0.057117804026347585, 0.11536488964338787, 0.06712071161018685, 0.02698469175811624, 0.1429511941387318, 0.16533975605852902, 0.16295443405397236, 0.1134398921567481, 0.08319735949044116, 0.0740017341740895, 0.15020390652352944, 0.25904967449605465, 0.21764075820101425, 0.1369607710512355, 0.1335510180797428, 0.12005573793430813, 0.2316464504110627, 0.10432406998006627, 21.290352568030357, 67.51897975802422, 54.100113809108734, 52.479318380355835, 37.7039822191, 42.20448352396488, 53.75560909509659, 58.01351621747017, 62.029608115553856, 18.7730997428298, 0.3958898317068815, 4.984114179387689, 25.002196691930294, 6.852381303906441, 6.50814020074904, 53.853955417871475, 57.256855219602585, 54.909732565283775, 51.97152882814407, 53.526204004883766, 55.690332278609276, 52.75571554899216, 56.36598542332649, 56.869325414299965, 54.79248605668545, 54.36090901494026, 52.281592190265656, 52.9933737963438, 43.509603291749954, 38.85540023446083, 39.91314947605133, 40.30830167233944, 40.52226819097996, 39.82970215380192, 38.46060901880264, 38.885589614510536, 39.74501229822636, 39.47669729590416, 39.74471591413021, 40.496239587664604, 38.95241662859917, 40.30101366341114, 40.15274561941624, 40.84186904132366, 38.28716352581978, 38.14677245914936, 39.40103955566883, 40.864766612648964, 41.17071099579334, 40.02432771027088, 40.42367868125439, 40.361096039414406, 40.96456065773964, 44.06696878373623, 40.820981562137604, 40.254120379686356, 39.4645531475544, 42.6248549669981, 39.06440421938896, 38.42897191643715, 39.403308033943176, 37.676110714673996, 43.86555299162865, 52.05228969454765, 53.507543206214905, 54.861076176166534, 52.42505729198456, 53.65946665406227, 46.854905784130096, 44.305630177259445, 42.29707695543766, 42.87094496190548, 56.65885470807552, 56.123748421669006, 53.08007754385471, 49.1853017359972, 54.90630894899368, 52.949942126870155, 53.96168723702431, 55.52058398723602, 55.92360936105251, 55.44901102781296, 53.57145197689533, 55.27088038623333, 50.27639038860798, 42.272359281778336, 40.691085532307625, 41.00632801651955, 42.06553258001804, 41.19778074324131, 41.98122650384903, 42.48164065182209, 40.768175795674324, 40.89867979288101, 42.52073295414448, 40.5911660939455, 41.00702337920666, 40.41823737323284, 40.34199446439743, 39.3926116079092, 40.158627703785896, 38.767001777887344, 41.606152430176735, 41.050052270293236, 39.36703138053417, 43.1392827630043, 40.97347877919674, 38.916014581918716, 41.24007247388363, 37.63522110879421, 38.85636918246746, 42.13488645851612, 43.59460473060608, 44.35109093785286, 43.213279992341995, 49.53043721616268, 49.791426211595535, 52.414182275533676, 53.68357256054878, 53.48900780081749, 47.51406021416187, 53.47427599132061, 53.66182632744312, 52.100132927298546, 50.84167465567589, 51.49033784866333, 55.145574510097504, 57.74804726243019, 59.62352402508259, 54.17583994567394, 49.73082326352596, 54.231905937194824, 61.482133492827415, 57.082505375146866, 56.98660232126713, 37.728110924363136, 8.366438560187817, 6.032775258645415, 4.415160734206438, 3.1179238809272647, 0.8700940548442304, 0.6568102526944131, 44.38104473054409, 70.11343494057655, 62.75005705654621, 46.77689976990223, 33.81709098815918, 50.51998771727085, 54.05976377427578, 65.9286130964756, 19.89017140120268, 0.21809775789733976, 0.16996542894048616, 0.2024508803151548, 0.1301330272690393, 0.15737418114440516, 0.13792790821753442, 0.2088302926858887, 0.13055679359240457, 0.22789663053117692, 0.12985443987417966, 0.21838134736754], [0.023942463303683326, 0.022907243364898022, 0.024579778910265304, 0.05453488149214536, 0.06308667143457569, 0.10535228590015322, 0.02759274448180804, 0.057129337001242675, 0.08268731849966571, 0.06980888181715272, 0.018465018256392796, 0.09091407002415508, 0.08358493869309314, 0.1668394880834967, 7.093819873407483, 44.070232808589935, 44.725393652915955, 41.20835557579994, 34.32363040745258, 35.12740507721901, 37.361924573779106, 48.75483803451061, 51.06572963297367, 21.978997215628624, 0.4494987503858283, 1.8684868002310395, 15.20872475579381, 2.060502371750772, 3.6349761486053467, 40.19514374434948, 57.265370562672615, 50.59673219919205, 48.78193438053131, 54.035783261060715, 54.99966613948345, 53.22450019419193, 50.63059218227863, 50.1403196901083, 48.88753831386566, 47.45658069849014, 43.85787360370159, 38.778321370482445, 36.17712154984474, 37.97055311501026, 35.79714193940163, 36.303343176841736, 33.958595395088196, 34.54945608973503, 33.33165943622589, 34.32677283883095, 35.94563037157059, 33.90010513365269, 36.32888920605183, 34.677391424775124, 36.91616669297218, 36.08540967106819, 37.18520745635033, 37.22450874745846, 36.6710190474987, 36.558187901973724, 35.19519343972206, 35.57678036391735, 36.109998151659966, 34.92158532142639, 35.36739639937878, 35.299634635448456, 38.45003418624401, 38.10865670442581, 38.90452019870281, 37.42714807391167, 38.91670994460583, 37.69089192152023, 36.519266590476036, 35.63167981803417, 36.99051730334759, 35.381562039256096, 40.66769778728485, 48.63758772611618, 49.31370444595814, 40.55950239300728, 46.07392609119415, 49.38501141965389, 42.499302104115486, 40.66140532493591, 37.85407416522503, 38.95895607769489, 49.04167324304581, 53.90390373766422, 52.56702147424221, 43.43327298760414, 49.78099577128887, 50.20982936024666, 52.3358266800642, 50.37141568958759, 51.82061992585659, 51.82221204042435, 50.32003104686737, 52.5566366314888, 43.1456246227026, 36.970887556672096, 35.43139636516571, 38.653072491288185, 38.1884790211916, 37.33789086341858, 36.80998899042606, 39.52284201979637, 38.546423614025116, 39.105757400393486, 37.87163682281971, 38.83078895509243, 37.16068737208843, 36.87854491174221, 38.49034622311592, 35.81140257418156, 36.00796602666378, 35.895917639136314, 35.34140959382057, 35.8745513856411, 35.33862054347992, 35.07418133318424, 33.1558770686388, 35.98126865923405, 34.98006418347359, 36.6986283659935, 34.09927524626255, 35.88474243879318, 35.88078685104847, 39.504811987280846, 45.6711895018816, 45.594258829951286, 48.83238047361374, 46.007083877921104, 46.73115402460098, 49.45111647248268, 52.62274168431759, 49.92670275270939, 49.16030287742615, 45.1192045211792, 43.81922967731953, 47.461915612220764, 52.143180817365646, 54.39261071383953, 55.46170614659786, 52.0114266872406, 49.73826706409454, 52.462390288710594, 51.679913476109505, 52.840230613946915, 51.62803865969181, 30.556786134839058, 4.808146096765995, 1.2781093921512365, 2.297219932079315, 0.7591463020071387, 0.17947189538972452, 1.228749684523791, 39.5792917907238, 61.27463422715664, 44.71701130270958, 45.98586581647396, 27.886403426527977, 33.43844510614872, 45.4094747453928, 44.15973700582981, 4.577325107529759, 0.07477721912437119, 0.05371755425585434, 0.058522262843325734, 0.009440401390747866, 0.07886094608693384, 0.01644297382881632, 0.04921020568872336, 0.01350729829937336, 0.0776774283440318, 0.01965680352441268, 0.04279011620383244, 0.04348665148427244, 0.03779772960115224, 0.07989157398696989, 0.05351685525965877, 0.011726887878467096, 0.10233002307359129, 0.04430239052453544, 0.06398792073014192, 0.04670005444495473, 0.023247746285051107, 0.04218026377202477, 0.03443122528551612, 0.06913794321008027, 0.12399796702084132, 9.037948027253151, 51.500931680202484, 48.31551320850849, 48.26735459268093, 33.760781809687614, 37.395039796829224, 46.66733644902706, 52.51901105046272, 55.8570559322834, 23.38708385825157, 0.3929962869733572, 0.9463671839330345, 18.471401631832123, 3.444856437854469, 3.695623269304633, 43.55556182563305, 57.68404729664326, 53.36297616362572, 51.31908103823662, 53.33935663104057, 55.09398467838764, 56.63103640079498, 52.613424584269524, 52.5058713555336, 51.383468583226204, 50.847940519452095, 46.52135208249092, 41.54601685702801, 37.130771577358246, 39.31360624730587, 37.25977845489979, 38.130338340997696, 35.93095935881138, 35.348101034760475, 34.69547465443611, 36.90368436276913, 36.631257981061935, 36.38260692358017, 36.88102997839451, 36.62031836807728, 37.980519980192184, 38.06109085679054, 39.23984080553055, 37.3032633215189, 38.65315228700638, 36.97728641331196, 37.51094877719879, 38.523792028427124, 36.3334945589304, 37.45154656469822, 36.94924011826515, 36.69778101146221, 39.49392557144165, 39.1979518532753, 40.02522826194763, 38.31866003572941, 39.319321140646935, 38.610180392861366, 37.964313849806786, 37.87331633269787, 38.83550450205803, 38.38885746896267, 42.365503683686256, 50.58893881738186, 53.562321066856384, 46.81054696440697, 47.2786932438612, 51.020876839756966, 45.12942977249622, 43.19130577147007, 39.41649712622166, 42.29549624025822, 50.903979912400246, 56.29742570221424, 52.70952522754669, 48.30048881471157, 54.40427988767624, 51.978357061743736, 53.59836593270302, 52.6724012196064, 52.09357067942619, 53.202404379844666, 52.50065803527832, 52.01439052820206, 45.81520937383175, 38.61755959689617, 37.27824926376343, 41.03327997028828, 38.932980671525, 40.042414739727974, 38.33333104848862, 40.5708371847868, 40.99854223430157, 39.514493867754936, 40.009675696492195, 41.462577134370804, 38.474083095788956, 37.43328474462032, 39.20592002570629, 36.86456926167011, 38.74343924224377, 38.969428315758705, 37.538007125258446, 39.09229092299938, 37.7065584808588, 37.91363976895809, 36.53456076979637, 36.698651164770126, 38.40012386441231, 37.57423058152199, 36.876952797174454, 37.33564518392086, 38.87808121740818, 41.82634301483631, 46.85181275010109, 49.65294264256954, 50.35819619894028, 48.412320613861084, 48.447350934147835, 50.23448623716831, 54.8661907017231, 51.46337449550629, 51.19460731744766, 46.178948655724525, 47.57507734000683, 48.09397749602795, 53.26214477419853, 56.83073468506336, 56.93403974175453, 54.31387133896351, 50.380687192082405, 54.6631295979023, 55.30939131975174, 55.86472772061825, 53.61561320722103, 33.31859953701496, 5.764798913151026, 2.703413385897875, 3.7248945236206055, 0.6754394655581564, 0.2129331522155553, 1.198314861394465, 43.48322510719299, 66.9521413743496, 52.78287649154663, 46.93188585340977, 32.5301418453455, 39.726522490382195, 50.50567388534546, 54.76283244788647, 7.831508964300156, 0.05379935748351272, 0.006593066946152248, 0.06989698216784745, 0.05496561287145596, 0.09914076959830709, 0.010598171247693244, 0.03805550717515871, 0.016886804114619736, 0.05262168786430266, 0.02819419951265445, 0.028247960690350737, 0.14520184602588415, 0.16553866647882387, 0.10795860463986173, 0.16523836384294555, 0.13096736453007907, 0.22768252092646435, 0.19617118290625513, 0.30770962592214346, 0.14366717368829995, 0.14271655672928318, 0.16571667802054435, 0.1654140153550543, 0.29789748368784785, 0.24943862459622324, 11.037338990718126, 57.7934206277132, 55.298523902893066, 52.43768021464348, 44.17746305465698, 48.36787439882755, 50.21888807415962, 58.42676684260368, 62.879820093512535, 27.100373804569244, 0.3975160850677639, 4.294655425474048, 21.91988568753004, 4.788264138624072, 5.065938513725996, 44.58586893975735, 60.24810031056404, 55.00304035842419, 53.15597467124462, 57.5762926787138, 56.537010446190834, 59.674570485949516, 54.82120491564274, 54.74130280315876, 54.532500207424164, 52.5616941601038, 48.55194412171841, 41.49911217391491, 39.50798101723194, 41.53176762163639, 38.931449353694916, 40.51018863916397, 37.16834396123886, 37.367685064673424, 37.18922384083271, 38.46252031624317, 38.698495253920555, 38.18632833659649, 38.14299166202545, 37.72018074989319, 40.297783836722374, 39.773814752697945, 42.042741402983665, 38.544261530041695, 40.77265955507755, 39.2773561924696, 38.59206296503544, 38.63337814807892, 39.09630350768566, 38.390115201473236, 39.001601189374924, 38.422485664486885, 41.29760518670082, 43.09884153306484, 42.50901818275452, 41.7813154309988, 41.76380597054958, 41.35217785835266, 39.653384014964104, 39.884700402617455, 40.18257021903992, 40.03750920295715, 43.446644470095634, 53.71463969349861, 51.54987685382366, 46.66990511119366, 50.14259576797485, 53.458305448293686, 47.6000913977623, 45.50390727818012, 42.98013210296631, 44.17309328913689, 52.01154448091984, 57.17330150306225, 54.304280653595924, 48.02724927663803, 53.47304865717888, 53.0404456704855, 57.752698212862015, 53.86619456112385, 55.27541734278202, 55.19768871366978, 54.12200443446636, 54.74276192486286, 48.865647688508034, 41.66555844247341, 39.31569993495941, 43.06962490081787, 40.73618531227112, 41.82892307639122, 40.85920371115208, 43.803817704319954, 41.76142729818821, 42.53894917666912, 41.18086785078049, 43.63626569509506, 40.90485066175461, 39.81804057955742, 41.522553116083145, 39.50069680809975, 41.35117471218109, 39.768498837947845, 40.428667813539505, 40.964864641427994, 39.01473328471184, 37.83877618610859, 38.372947722673416, 39.28349666297436, 39.63865600526333, 40.088403671979904, 37.26164795458317, 39.2623545974493, 40.326768681406975, 44.250464737415314, 51.33360765874386, 51.55995771288872, 51.93683288991451, 48.85038010776043, 51.18517242372036, 55.05174994468689, 56.44149497151375, 53.05155247449875, 53.971452713012695, 49.29458387196064, 50.37938006222248, 50.9737403690815, 55.46303607523441, 58.82451809942722, 60.181740671396255, 57.07877777516842, 54.88737836480141, 58.167445957660675, 58.15763868391514, 59.34979431331158, 55.55668964982033, 34.9390833824873, 6.537448028102517, 5.642538098618388, 9.74191440269351, 1.7204795172438025, 0.48086244554724544, 1.3941735704429448, 47.216897159814835, 71.35289043188095, 57.05945581197739, 61.944754868745804, 42.01141208410263, 49.207215160131454, 60.165051966905594, 63.50576050579548, 13.574939724057913, 0.18671441066544503, 0.14919010311132297, 0.16771669179433957, 0.07307645413675345, 0.20806681568501517, 0.11138035071780905, 0.1768037409055978, 0.07246564433444291, 0.14202497899532318, 0.13584842527052388, 0.18641507282154635], [0.0159653275841265, 0.036421034528757446, 0.04216011075186543, 0.032863378946785815, 0.06778046605177224, 0.062269017653306946, 0.06594060032512061, 0.004996562111045932, 0.026404445452499203, 0.03517761062539648, 0.08582056208979338, 0.02331171570403967, 0.12388158342218958, 0.12810870073735714, 3.4576418017968535, 41.499716341495514, 48.31113204360008, 40.59383735060692, 27.09272861480713, 25.186975076794624, 35.762814581394196, 44.318063110113144, 50.53877390921116, 25.570923574268818, 0.1763792324345559, 0.2665196283487603, 10.903143491595984, 3.6351761128753424, 0.8785522228572518, 23.905396945774555, 49.5555766671896, 55.00118985772133, 54.347020760178566, 53.34146551787853, 51.14948473870754, 48.52619290351868, 45.44419348239899, 45.881698206067085, 43.32454562187195, 40.67525938153267, 38.3750756084919, 37.03626684844494, 36.111096292734146, 35.12412205338478, 33.49370554089546, 35.02484478056431, 33.06813217699528, 33.60334865748882, 33.70847761631012, 34.505853429436684, 34.29530672729015, 34.87021587789059, 35.26472970843315, 35.71032799780369, 37.01286390423775, 37.6251782476902, 37.34126888215542, 35.808434933423996, 35.5975728482008, 35.33638246357441, 36.023396998643875, 35.76463848352432, 37.269190549850464, 36.29716470837593, 37.30670213699341, 36.07207998633385, 37.07663968205452, 37.22414776682854, 38.04592587053776, 38.75532500445843, 38.02378825843334, 36.93747214972973, 36.926604732871056, 37.57899932563305, 37.02074088156223, 36.13011047244072, 42.15155616402626, 52.80250623822212, 43.80529202520847, 39.13891822099686, 49.061188995838165, 47.85767197608948, 43.886543065309525, 39.570202678442, 37.56193824112415, 37.69852951169014, 49.106379970908165, 53.17663796246052, 52.409611120820045, 41.4127504080534, 47.88126491010189, 49.770253747701645, 51.18676833808422, 51.76509730517864, 51.40341751277447, 52.6152066886425, 49.50074560940266, 48.619987070560455, 41.65021866559982, 35.6388196349144, 36.61749891936779, 37.97823630273342, 38.0863519012928, 37.68853984773159, 36.60415783524513, 37.850357964634895, 38.61388899385929, 38.0551365762949, 38.51173907518387, 36.45154282450676, 37.938596829771996, 37.84139804542065, 37.24715553224087, 36.90583124756813, 34.851965457201004, 36.16756126284599, 36.83593399822712, 35.7637645304203, 36.23047448694706, 35.91740928590298, 34.094092324376106, 34.83847618103027, 35.167378932237625, 35.445653200149536, 36.34756900370121, 36.03784382343292, 37.22350940108299, 41.95213906466961, 45.02113938331604, 45.20810455083847, 41.96115218102932, 44.76879492402077, 49.10098426043987, 51.44985482096672, 49.4875793159008, 49.35272075235844, 50.49219220876694, 44.75260779261589, 43.92551377415657, 49.83193963766098, 50.66353261470795, 48.10562767088413, 48.724226877093315, 55.312225967645645, 54.5231869071722, 54.098886474967, 52.822318375110626, 53.157418593764305, 50.21332897245884, 28.36437787860632, 3.738291417248547, 1.6026780009269714, 1.4091609162278473, 0.5894847528543323, 0.17968532221857458, 1.5949914883822203, 44.14764605462551, 58.51251684129238, 50.45004107058048, 34.93031345307827, 19.350334368646145, 41.85627020895481, 50.13275809586048, 41.10544189810753, 3.0637587374076247, 0.04220499213261064, 0.011049221702705836, 0.03830829380603973, 0.02426785053103231, 0.0381613003264647, 0.022929418737476226, 0.053205765507300384, 0.016459284379379824, 0.05236030716332607, 0.05393907049437985, 0.04074306882102974, 0.00892489912075689, 0.034427247373969294, 0.03401345922611654, 0.09142129827523604, 0.012977762944501592, 0.019701278579304926, 0.04882942455878947, 0.025808821847022045, 0.03292057626822498, 0.06192942200868856, 0.035671138830366544, 0.024620251933811232, 0.05561695135838818, 0.061012617297819816, 4.571065418422222, 48.53882722556591, 54.067450761795044, 45.990155786275864, 34.466692730784416, 30.227642096579075, 41.99938952922821, 50.892994701862335, 55.159234777092934, 28.24466910213232, 0.18349207966821268, 0.348636606358923, 11.606307160109282, 3.4099408239126205, 1.5530031477101147, 27.165014035999775, 51.738928109407425, 57.58064724504948, 54.07674126327038, 55.839823856949806, 52.128996178507805, 51.75128884613514, 48.40388506650925, 49.20504167675972, 45.86958445608616, 44.018935561180115, 39.62810397148132, 37.52324491739273, 38.4653739631176, 36.510914638638496, 34.608603715896606, 37.0855426043272, 35.52061937749386, 35.6417340785265, 35.12922137975693, 37.227875366806984, 36.1259762942791, 36.797453463077545, 36.597933769226074, 37.16437317430973, 38.964480981230736, 39.30687680840492, 38.08751083910465, 38.0916678160429, 37.74837523698807, 37.2371506690979, 38.82366433739662, 37.01099820435047, 37.518035396933556, 36.716400012373924, 38.51843051612377, 38.15914459526539, 39.35083664953709, 39.275425896048546, 39.45270158350468, 39.707341119647026, 38.81623953580856, 38.82660157978535, 38.11015762388706, 38.45510311424732, 39.4576071202755, 39.18210290372372, 45.08195511996746, 52.93244406580925, 49.09357085824013, 45.001593232154846, 50.7398097217083, 49.11195807158947, 45.89821591973305, 40.8969546854496, 38.785404190421104, 40.71197301149368, 50.385763719677925, 56.07429027557373, 52.96419136226177, 44.82924588024616, 50.70580914616585, 54.02224458754063, 51.930369436740875, 53.84605944156647, 52.15099319815636, 53.90723995864391, 51.2618713080883, 50.13211593031883, 43.3026359975338, 38.078733310103416, 38.55428159236908, 39.28213253617287, 40.33223278820515, 39.617430344223976, 39.971506744623184, 38.85696955025196, 41.49126939475536, 40.05431950092316, 39.90941807627678, 39.03307490050793, 38.52616690099239, 40.024141520261765, 38.9941193908453, 38.39142233133316, 37.22999945282936, 37.925331741571426, 38.26757177710533, 37.82340221107006, 38.5330331325531, 36.672573164105415, 36.56191550195217, 37.414943128824234, 36.53537392616272, 37.132375091314316, 38.66773970425129, 38.414844274520874, 41.59908100962639, 45.50553739070892, 47.479615062475204, 47.09356717765331, 44.337632060050964, 46.82299129664898, 50.767419040203094, 55.340173467993736, 51.950709745287895, 51.563719511032104, 52.53341227769852, 46.919114738702774, 45.34457802772522, 50.648154839873314, 52.91179597377777, 51.109628677368164, 50.19650727510452, 57.82081715762615, 56.94372542202473, 55.833793580532074, 56.876681819558144, 55.02892456948757, 51.57577246427536, 30.77968217432499, 4.025469794869423, 2.4837398109957576, 3.4304699348285794, 0.8630269090645015, 0.07870706176618114, 1.6282912390306592, 46.57168798148632, 64.27403748035431, 54.77920576930046, 44.34033751487732, 26.20249528437853, 45.567888244986534, 56.752094104886055, 49.19146500527859, 5.002010744065046, 0.14330807811347768, 0.01818846805690555, 0.02454072153341258, 0.033775278061511926, 0.04203807569865603, 0.03582601391826756, 0.022230760914681014, 0.05900341202504933, 0.007056496888253605, 0.03404295217478648, 0.02984441311127739, 0.08100420178379864, 0.12572507082950324, 0.19662466482259333, 0.1633457388379611, 0.13607412722194567, 0.16702140332199633, 0.1717723358888179, 0.13381121505517513, 0.06197122347657569, 0.1445017781225033, 0.18239242461277172, 0.11699058639351279, 0.23514303466072306, 0.32450552622321993, 5.46970484778285, 55.32536946237087, 60.93818888068199, 51.13916449248791, 40.22692523896694, 38.875846937298775, 48.983779549598694, 54.51591029763222, 60.395741388201714, 32.197139114141464, 0.22685358650051057, 0.8776709670200944, 19.44765094667673, 7.9043838288635015, 2.47490291018039, 27.781975530087948, 53.057654947042465, 60.01830384135246, 54.0706729888916, 58.555773720145226, 53.95246133208275, 54.10266727209091, 49.52885650098324, 51.07076056301594, 47.163817808032036, 43.956147730350494, 42.30609007179737, 40.55941499769688, 40.75322359800339, 39.03218574821949, 36.724546775221825, 39.86825868487358, 36.66560433804989, 37.932729944586754, 36.67842485010624, 39.32398349046707, 37.88291081786156, 39.61197003722191, 38.81363667547703, 39.47395384311676, 40.93755550682545, 41.61607749760151, 40.69757178425789, 41.07126273214817, 40.32814800739288, 38.90057981014252, 40.125311091542244, 39.33020755648613, 40.91301642358303, 38.406955897808075, 40.174860432744026, 40.127644166350365, 40.112046003341675, 39.93588365614414, 43.4142892062664, 42.68828496336937, 41.16036035120487, 40.42636513710022, 39.56392541527748, 39.95478384196758, 39.476769492030144, 40.62911465764046, 46.12740062177181, 57.15681038796902, 49.002345353364944, 44.49274733662605, 53.387405052781105, 52.25321151316166, 47.15333417057991, 43.19651149213314, 42.261974439024925, 42.39311300218105, 50.63720002770424, 60.07856100797653, 57.370149940252304, 45.386333987116814, 50.55489644408226, 53.949611485004425, 53.60363245010376, 55.402341932058334, 52.78530456125736, 54.91960063576698, 52.966646030545235, 51.32516451179981, 46.11561365425587, 41.1557549983263, 39.42983441054821, 40.74747830629349, 41.61845237016678, 40.39183259010315, 41.49636872112751, 39.965358674526215, 43.737883642315865, 42.19219498336315, 42.930651158094406, 39.93836872279644, 41.55579753220081, 41.90729007124901, 40.76164774596691, 41.77283428609371, 39.41374607384205, 39.78495575487614, 42.768776044249535, 39.70768690109253, 40.248040705919266, 39.63949576020241, 38.56144420802593, 39.28329147398472, 38.69259797036648, 39.17997881770134, 40.26940695941448, 40.7761287689209, 42.34065301716328, 47.865275368094444, 49.049329832196236, 49.98764008283615, 46.2064553797245, 49.17489789426327, 54.137879982590675, 57.16649606823921, 53.72841015458107, 52.40645349025726, 54.551521986722946, 50.79146794974804, 47.9550189524889, 54.31144706904888, 55.77128693461418, 53.80275696516037, 52.433929815888405, 59.21614408493042, 59.16969917714596, 58.95481690764427, 58.282309994101524, 57.236438915133476, 53.00780922174454, 32.54227839410305, 5.184741038829088, 4.116119630634785, 6.150110587477684, 2.2998679149895906, 0.474091594805941, 1.7013628617860377, 51.434800028800964, 67.74565279483795, 62.01179847121239, 49.121404364705086, 32.40883335471153, 55.48745736479759, 61.937527656555176, 60.47500513494015, 8.961583524942398, 0.2541952865431085, 0.0913573028810788, 0.31891371065285057, 0.11388270198949613, 0.18075633037369698, 0.1619771443074569, 0.11817644932307303, 0.16148777212947607, 0.12112209282349795, 0.08523393888026476, 0.11879030193085782], [0.09297583790612407, 0.032979421157506295, 0.041867403997457586, 0.02533789574954426, 0.035801712292595766, 0.04927256093651522, 0.01656226479099132, 0.01782257626473438, 0.025532659419695847, 0.04048265291203279, 0.045405708078760654, 0.07207523754914291, 0.059648575843311846, 0.03944821408367716, 0.4021250893129036, 28.294921405613422, 48.783952072262764, 47.28095792233944, 33.454366251826286, 31.19119819253683, 34.67482276260853, 37.97158665955067, 52.333421409130096, 32.6280701905489, 0.8958804211579263, 0.044331902026897296, 2.5628589279949665, 1.3830846967175603, 0.10408684989670292, 9.591867104172707, 35.4314761608839, 49.194763228297234, 50.658410489559174, 53.85447598993778, 49.302536845207214, 46.40800416469574, 41.52170576155186, 39.2879044264555, 38.43221314251423, 35.73615901172161, 37.558013051748276, 36.0736683011055, 36.309525445103645, 36.68157868087292, 35.01296281814575, 38.11563692986965, 38.63481447100639, 38.17959889769554, 38.51927027106285, 40.133758038282394, 38.72877582907677, 39.35328371822834, 36.625349298119545, 38.553172051906586, 35.459062680602074, 35.62701366841793, 35.90380221605301, 37.990528643131256, 35.520915761590004, 34.80610951781273, 35.63339352607727, 36.89092844724655, 35.9218018501997, 36.34064197540283, 37.16479115188122, 35.948123037815094, 37.49669574201107, 40.04850961267948, 37.63758458197117, 38.132842406630516, 37.611213997006416, 38.04986625909805, 35.00912502408028, 36.642319187521935, 36.967197954654694, 36.48967757821083, 43.92212055623531, 53.39835986495018, 38.84997792541981, 39.917758628726006, 50.27514025568962, 44.49163019657135, 45.717585012316704, 40.090607553720474, 39.93966445326805, 40.106866881251335, 52.54199981689453, 50.001680329442024, 51.005647256970406, 41.846728920936584, 45.92384934425354, 50.26274152100086, 49.01504047214985, 51.27245754003525, 51.86097376048565, 53.30922044813633, 49.04678776860237, 47.7862624078989, 41.2343043833971, 35.74256166815758, 37.767598405480385, 37.547867596149445, 37.45266370475292, 38.51432293653488, 38.798163905739784, 38.19244600832462, 36.06565073132515, 36.88382662832737, 38.66248078644276, 38.531543612480164, 36.57972514629364, 34.942073822021484, 37.22561068832874, 37.70390622317791, 37.67272129654884, 38.433968648314476, 39.37759481370449, 38.24471600353718, 35.80472253262997, 37.111837193369865, 34.78108786046505, 34.87544059753418, 33.44021201133728, 35.63634976744652, 33.63354943692684, 35.54691396653652, 39.960213750600815, 41.129878386855125, 43.226434886455536, 41.24391406774521, 46.41897037625313, 48.848172426223755, 49.49022777378559, 49.73140463232994, 51.3753180205822, 49.714370146393776, 50.0166667252779, 47.653349339962006, 43.763490468263626, 46.48489683866501, 54.00114431977272, 54.715479388833046, 42.10438549518585, 42.52550929784775, 54.29112195968628, 55.75140260159969, 53.07048685848713, 51.006384417414665, 51.838881745934486, 28.366777449846268, 2.496144245378673, 1.127794326748699, 2.218879535794258, 0.09534067663480528, 0.12438204328645952, 1.9428813457489014, 41.28253139555454, 56.86182841658592, 40.96974737942219, 37.889632657170296, 34.56495925784111, 49.0891744941473, 52.10743993520737, 40.654888674616814, 5.254813078790903, 0.20188517082715407, 0.049273325348622166, 0.040970756017486565, 0.017318398240604438, 0.040855288971215487, 0.027623929527180735, 0.1243022846756503, 0.01084413754142588, 0.03549628141627181, 0.058622345168259926, 0.02447127135383198, 0.08272029954241589, 0.03756876591069158, 0.06722125035594217, 0.021138028241693974, 0.038077122226241045, 0.08989244437543675, 0.03143996567814611, 0.0722370480070822, 0.03344600940181408, 0.027114884869661182, 0.06438682510633953, 0.04771276318933815, 0.009632834717194783, 0.023091247749107424, 0.9889764350373298, 36.04542061686516, 54.959194511175156, 53.23721431195736, 36.05347998440266, 34.705844298005104, 40.64131960272789, 44.724595695734024, 57.45131358504295, 35.58144271373749, 0.8381287450902164, 0.15168499579885975, 4.806293221190572, 3.0331373680382967, 0.6752764899283648, 11.949653886258602, 38.21147918701172, 49.961489886045456, 52.056157886981964, 55.83765797317028, 51.89715921878815, 49.84273485839367, 45.02628430724144, 42.01417453587055, 40.50118312239647, 38.07475872337818, 37.965514585375786, 38.685811534523964, 38.614603355526924, 38.32003556191921, 37.126474007964134, 39.84456315636635, 39.58027593791485, 39.590846970677376, 39.38044086098671, 41.204403787851334, 39.13392148911953, 39.21792358160019, 38.87863218784332, 38.40464562177658, 38.336021304130554, 37.87936560809612, 37.19219148159027, 38.6000919342041, 37.1664060652256, 36.649933978915215, 36.61927342414856, 38.30820679664612, 39.14098531007767, 37.56831809878349, 38.13061572611332, 37.85884290933609, 38.77088136970997, 40.993682295084, 39.658350348472595, 39.18454997241497, 39.63712468743324, 38.28514203429222, 37.12859809398651, 38.15461903810501, 38.293592780828476, 38.9346107840538, 45.02436921000481, 53.140156120061874, 43.64709131419659, 44.98999625444412, 51.792961210012436, 49.20855648815632, 45.364887937903404, 42.717478796839714, 39.94672827422619, 43.143055960536, 52.639407590031624, 52.22696252167225, 52.604103684425354, 45.198513865470886, 50.229694694280624, 53.280927166342735, 51.526348516345024, 52.30772338807583, 53.046437948942184, 54.62731271982193, 51.34238138794899, 50.21910086274147, 42.48633719980717, 37.0502083003521, 38.87236252427101, 39.846387058496475, 39.06578354537487, 40.84574103355408, 39.76752609014511, 38.73194865882397, 38.405747562646866, 39.289291352033615, 39.01048891246319, 41.288956850767136, 38.448974043130875, 37.94947184622288, 39.466612637043, 38.41655418276787, 39.405648708343506, 39.62006360292435, 40.14230377972126, 39.7883527725935, 38.099354803562164, 38.843921050429344, 38.00976701080799, 35.57991899549961, 37.18059830367565, 37.44272343814373, 35.230440348386765, 37.915220484137535, 41.41699098050594, 43.163141682744026, 45.667720288038254, 43.32734227180481, 47.5720527023077, 50.77672094106674, 51.390851587057114, 52.06729508936405, 52.748906314373016, 50.29443182051182, 52.14334800839424, 49.66992013156414, 47.030566558241844, 48.78598876297474, 56.07310093939304, 56.30181446671486, 42.39859230816364, 44.582772105932236, 55.47910921275616, 57.901528626680374, 56.51484243571758, 51.87792085111141, 52.67425552010536, 29.99260000884533, 3.498879801481962, 2.0093884645029902, 4.016649518162012, 0.740381246432662, 0.290600509615615, 1.983706948813051, 47.06501550972462, 63.305800035595894, 48.27405743300915, 41.669514030218124, 39.13931339979172, 58.087954223155975, 57.698193937540054, 49.26891624927521, 6.1442536767572165, 0.21604344859952107, 0.07170407465309836, 0.06217203750566114, 0.01261469131350168, 0.06355564197292551, 0.04656502067518886, 0.05364826363802422, 0.0436765967606334, 0.03195235556631815, 0.049082185214501806, 0.02177187430788763, 0.22116803767858073, 0.15266786649590358, 0.18760495819151402, 0.09602035774150863, 0.112988599576056, 0.14154972246615216, 0.14930725854355842, 0.11512485682033002, 0.08214330940973014, 0.2006956416880712, 0.17056328826583922, 0.20963869930710644, 0.10560657538007945, 0.11046080748201348, 1.449458347633481, 41.495498567819595, 63.60335446894169, 59.21101056039333, 45.40457680821419, 45.01329280436039, 46.718747690320015, 52.37656809389591, 62.68218129873276, 41.07012279331684, 1.085094592999667, 0.2055373092298396, 7.8229062259197235, 5.841669263318181, 0.9105450811330229, 11.922132913023233, 38.91932040452957, 52.571493834257126, 52.85801745951176, 58.23754079639912, 54.020690470933914, 52.30563350021839, 46.52707077562809, 43.750669956207275, 43.497546538710594, 38.84958274662495, 40.76091058552265, 40.2457532286644, 41.38147048652172, 40.223668813705444, 38.43296930193901, 42.227818071842194, 42.66083523631096, 42.08116494119167, 43.171493634581566, 45.25009609758854, 43.41453239321709, 41.06559343636036, 41.285647228360176, 41.05693370103836, 40.285977870225906, 39.47042763233185, 40.32180234789848, 40.938144475221634, 39.309536665678024, 38.26167069375515, 39.652783647179604, 40.021698251366615, 40.503622591495514, 40.06095014512539, 40.557028725743294, 39.72870737314224, 40.6137178838253, 43.25299546122551, 42.113425210118294, 40.826985239982605, 42.428230717778206, 40.94431534409523, 38.367407619953156, 40.81673339009285, 39.78508114814758, 39.9048925191164, 47.99280792474747, 56.6906514018774, 42.8920604288578, 43.86888541281223, 52.39920347929001, 50.774220675230026, 49.356474950909615, 44.38887231051922, 42.940941005945206, 45.784902200102806, 55.762338414788246, 54.08608116209507, 53.12521152198315, 45.18401764333248, 50.6713829934597, 54.03100311756134, 54.11117881536484, 53.33120606839657, 54.1978445649147, 57.31101371347904, 51.48035578429699, 50.93607299029827, 45.738217905163765, 40.02403512597084, 41.178876757621765, 40.47461114823818, 41.12525403499603, 42.0960259437561, 42.98244997859001, 40.602375492453575, 39.257304668426514, 41.233286038041115, 42.45270520448685, 44.347614124417305, 40.7888200879097, 40.04150278866291, 41.98791794478893, 38.80544051527977, 42.13237479329109, 42.762935757637024, 43.30514766275883, 42.23730996251106, 39.54073525965214, 42.66741268336773, 39.3352384865284, 39.585538655519485, 39.053593799471855, 39.14913587272167, 36.9399344176054, 41.23534932732582, 43.70617814362049, 45.390392169356346, 48.95476050674915, 46.51729390025139, 50.25412358343601, 53.83874103426933, 52.73684196174145, 55.470111295580864, 55.63588500022888, 54.01728205382824, 53.37277963757515, 52.93135732412338, 47.88656562566757, 51.49411864578724, 58.78433145582676, 59.24010559916496, 42.64892667531967, 46.157802790403366, 58.00649419426918, 59.79155480861664, 56.496364027261734, 53.44263508915901, 54.924190789461136, 33.31277444958687, 4.259788496419787, 2.763196765445173, 8.400071505457163, 2.445881492458284, 0.4818584967870265, 2.310691634193063, 51.77404582500458, 68.43083202838898, 54.21210519969463, 51.406005173921585, 46.5605241805315, 63.898465633392334, 67.82574489712715, 57.15544246137142, 8.912493959069252, 0.47639985219575465, 0.14715154218720272, 0.12547768332296982, 0.12929364340379834, 0.15555881371255964, 0.11889593180967495, 0.18101042689522728, 0.1164520469319541, 0.18897867354098707, 0.17063851235434413, 0.141422102751676], [0.012104521374567412, 0.08609748707385734, 0.011359250183886616, 0.03257721422414761, 0.004727471423393581, 0.03530396497808397, 0.05403921961260494, 0.008960339455370558, 0.02344181419175584, 0.00891220654011704, 0.030027265311218798, 0.016979411157080904, 0.07636747832293622, 0.06714247880154289, 0.057286278970423155, 17.448169738054276, 47.54069298505783, 41.90465681254864, 42.57004290819168, 25.84306877106428, 32.936005666852, 45.19632898271084, 51.90549977123737, 42.20019355416298, 2.6251363987103105, 0.2835593093186617, 1.2001691618934274, 1.8686239491216838, 0.24478850536979735, 1.339556963648647, 17.61183835566044, 41.25047251582146, 54.31520886719227, 51.607306972146034, 49.71335940063, 46.70551300048828, 48.529483526945114, 49.064088240265846, 46.94296605885029, 43.437760546803474, 40.416371673345566, 37.9720426350832, 39.737481102347374, 42.54206880927086, 45.64942046999931, 46.97112634778023, 46.928899213671684, 45.204859524965286, 48.10462452471256, 46.38503059744835, 46.70513302087784, 46.786053478717804, 45.51341436803341, 42.239791229367256, 41.32235325872898, 38.09067226946354, 37.79455415904522, 37.33897380530834, 36.73578277230263, 37.867688834667206, 35.42833372950554, 36.83631777763367, 35.26265121996403, 36.46976664662361, 37.06351138651371, 36.55052751302719, 37.2867988049984, 38.78362588584423, 35.97712688148022, 39.17414233088493, 37.69717298448086, 38.6054952442646, 35.42044535279274, 36.08185686171055, 35.425825864076614, 36.99706815183163, 43.36632817983627, 54.85484831035137, 40.64486101269722, 38.06236378848553, 49.83631320297718, 48.823511749506, 44.18175682425499, 39.19268153607845, 37.60876692831516, 40.49765311181545, 53.194265216588974, 51.64585590362549, 52.76903763413429, 43.1258998811245, 47.039511278271675, 52.18690127134323, 49.91874597966671, 52.9159377515316, 52.07223482429981, 51.81035287678242, 50.910728350281715, 46.092518493533134, 38.4578275680542, 35.76977960765362, 35.670741721987724, 36.38071842491627, 37.53266841173172, 37.38797977566719, 37.907373905181885, 38.118118196725845, 35.96746779978275, 38.007437735795975, 36.84713579714298, 38.51866230368614, 36.79433763027191, 35.80518610775471, 36.61294676363468, 35.68438678979874, 36.026767417788506, 37.531593069434166, 37.19913370907307, 36.62084273993969, 37.38682843744755, 37.77325250208378, 36.531897112727165, 36.30349896848202, 36.26610517501831, 35.85638456046581, 34.30526219308376, 33.945166915655136, 36.94051958620548, 42.87857115268707, 43.30509066581726, 48.65604713559151, 46.75247088074684, 47.607238814234734, 48.90513516962528, 51.34545922279358, 49.24450255930424, 51.65786325931549, 49.83896926045418, 46.374763548374176, 41.91870465874672, 46.79272212088108, 50.801351219415665, 56.41668610274792, 56.41462281346321, 44.68351989984512, 54.27914880216122, 54.56663757562637, 52.08964928984642, 48.81660372018814, 50.981438755989075, 23.34093153476715, 2.0361525658518076, 1.5773426229134202, 2.899785186164081, 0.6143849354702979, 0.21629450231557712, 2.5763099687173963, 46.083558574318886, 58.01730081439018, 49.57589417695999, 33.850153014063835, 17.477606758475304, 37.70612150430679, 52.79095485806465, 30.934212282299995, 0.9461785003077239, 0.0904334922961425, 0.09733545084600337, 0.0064433497846039245, 0.012544931287266081, 0.032495603954885155, 0.09572730588843115, 0.03452128861681558, 0.04269795630534645, 0.044255022949073464, 0.025472191082371864, 0.027251749888819177, 0.020985184783057775, 0.033090516953961924, 0.031190934314508922, 0.044566624783328734, 0.036228265380486846, 0.04377776633191388, 0.04776153713464737, 0.040409992943750694, 0.06348139009787701, 0.06731154746375978, 0.026758980529848486, 0.012262163745617727, 0.06872775818919763, 0.04109575595066417, 0.1920409974991344, 23.266409933567047, 54.171485379338264, 47.827269807457924, 48.100106567144394, 35.3145944327116, 37.79383599758148, 49.599677100777626, 57.44324281811714, 45.264592319726944, 2.44992780033499, 0.28337982832454145, 2.1394495479762554, 4.021252496168017, 0.746658390853554, 2.8572353068739176, 20.39724089205265, 43.087274953722954, 57.37497188150883, 53.8598906993866, 52.13763311505318, 49.185803309082985, 49.641300067305565, 48.426015079021454, 47.605954483151436, 43.773487731814384, 41.17714025080204, 40.201675593853, 41.775254756212234, 43.38231012225151, 46.33219823241234, 47.089417800307274, 48.540590330958366, 47.87164002656937, 49.08322401344776, 46.76287092268467, 48.47607359290123, 47.01904937624931, 45.91125302016735, 44.23393942415714, 42.825423404574394, 40.00860035419464, 39.22812603414059, 39.79801945388317, 38.35958383977413, 38.17120514810085, 37.556956708431244, 38.9142020791769, 37.94621542096138, 37.695067897439, 38.669578805565834, 37.22842633724213, 38.74356463551521, 40.6747730076313, 38.090942054986954, 39.30844232439995, 39.118859097361565, 39.65625286102295, 37.57396079599857, 37.82231546938419, 36.459453999996185, 38.53293053805828, 44.565277844667435, 54.92992088198662, 42.680734768509865, 42.650302201509476, 54.15280178189278, 50.81224523484707, 47.28340499103069, 41.40667073428631, 39.74934786558151, 43.54377865791321, 54.787664115428925, 52.60058507323265, 52.36595906317234, 44.756247997283936, 50.828907340765, 52.86970183253288, 52.44046166539192, 54.702598080039024, 54.12763953208923, 54.12352815270424, 51.866175681352615, 47.725294679403305, 39.70276616513729, 38.83998826146126, 36.91415660083294, 38.55065658688545, 38.78318510949612, 38.91233257949352, 39.0004688501358, 39.660193249583244, 38.24836380779743, 41.28208301961422, 38.82773771882057, 39.691450372338295, 38.42396758496761, 37.82333381474018, 39.16599936783314, 38.680727407336235, 39.24790397286415, 38.50511983036995, 38.756806924939156, 39.65039737522602, 39.424769282341, 38.060277700424194, 38.02011385560036, 39.07236099243164, 37.09592364728451, 37.4215167760849, 36.74392193555832, 35.96186310052872, 38.6847285926342, 44.45170573890209, 45.47659434378147, 49.82685551047325, 50.017715469002724, 48.06728392839432, 50.81011734902859, 53.492537811398506, 51.104354560375214, 53.408319130539894, 52.555766478180885, 47.56529286503792, 43.86847883462906, 48.18811744451523, 52.6969289034605, 57.72351197898388, 57.23584994673729, 46.47358104586601, 55.22422268986702, 55.140551179647446, 51.104346960783005, 51.43983855843544, 53.64970117807388, 26.214643232524395, 2.2847307147458196, 1.4324708841741085, 5.183783965185285, 2.052032626233995, 0.18899813265306875, 2.484781905077398, 49.95033748447895, 63.300157338380814, 54.39517177641392, 37.27935880422592, 23.128433637320995, 45.478372648358345, 59.96384136378765, 37.87131004035473, 1.855585661251098, 0.17000169027596712, 0.08740786754060537, 0.028694030406768434, 0.05903322780795861, 0.060106595992692746, 0.07428178359987214, 0.06112099683377892, 0.011629443888523383, 0.10800592397572473, 0.022551116380782332, 0.02994747701450251, 0.17607320041861385, 0.19940363679779693, 0.12788754072971642, 0.12413038843078539, 0.11820897765574045, 0.16954060876742005, 0.18073693063342944, 0.17432885651942343, 0.14880222704960033, 0.18159017781727016, 0.09961260482668877, 0.12327856617048383, 0.14537829905748367, 0.1246578773134388, 0.3825720213353634, 29.625630900263786, 61.892370879650116, 54.47457231581211, 52.73876465857029, 38.52556653320789, 45.55086515843868, 56.67324833571911, 61.427036449313164, 51.547049805521965, 3.4135385183617473, 0.7620459620375186, 5.976917780935764, 5.536242602393031, 1.6271571186371148, 2.403677157126367, 20.64381156116724, 44.46119002997875, 59.37495656311512, 58.02813783288002, 55.009572207927704, 51.28225341439247, 51.270679235458374, 52.13406130671501, 51.76546968519688, 47.369097992777824, 44.56983380019665, 42.458036318421364, 44.29586470127106, 46.19767785072327, 48.963971212506294, 51.25148266553879, 52.348753586411476, 50.58731250464916, 52.10021272301674, 49.90378998219967, 50.70355586707592, 49.762570559978485, 48.42221908271313, 45.932094901800156, 44.52907718718052, 42.3431570827961, 40.94499930739403, 42.257977053523064, 39.77793753147125, 40.90128265321255, 38.241831958293915, 40.772378370165825, 39.37412939965725, 41.135023310780525, 41.578797698020935, 38.83694842457771, 40.46787790954113, 41.68538577854633, 39.2327693849802, 41.49462841451168, 40.95318786799908, 41.98050074279308, 39.062150940299034, 39.09786522388458, 37.85898730158806, 41.01862795650959, 47.15308718383312, 58.68321508169174, 43.27873907983303, 41.98446772992611, 52.48815670609474, 53.651050105690956, 47.90475904941559, 44.06924866139889, 41.73713140189648, 45.28761148452759, 56.47788941860199, 55.17043277621269, 54.34361234307289, 46.89606137573719, 48.65126319229603, 55.37964574992657, 52.18307487666607, 56.659379079937935, 55.43384224176407, 56.449459344148636, 54.136086478829384, 48.761939853429794, 42.64252781867981, 40.59558905661106, 39.693559259176254, 40.304927453398705, 39.269380420446396, 41.46802604198456, 40.52927501499653, 41.58035181462765, 39.502376317977905, 43.188129141926765, 42.480006739497185, 43.73428523540497, 41.59167520701885, 40.56631922721863, 39.6580957621336, 41.54181808233261, 40.610085278749466, 41.011385545134544, 40.19210770726204, 41.2469919025898, 42.00112983584404, 41.74321487545967, 39.94358204305172, 41.60863749682903, 39.78037320077419, 39.94373023509979, 38.1690164655447, 38.35284300148487, 39.44314509630203, 48.13970044255257, 48.16320218145847, 53.27757574617863, 52.04170346260071, 52.01812192797661, 53.20524662733078, 55.585792288184166, 52.6219817250967, 57.00717441737652, 55.86679860949516, 50.64405485987663, 46.333395168185234, 50.80463044345379, 54.8481834679842, 60.01435965299606, 58.2641089707613, 46.20741292834282, 56.39930963516235, 56.95697911083698, 52.67772473394871, 51.43124721944332, 56.671907007694244, 28.522949069738388, 3.385035772807896, 5.5113843362778425, 7.357934201136231, 1.9798368564806879, 0.5930772225838155, 3.103383486159146, 54.789225831627846, 67.51846298575401, 62.910340055823326, 46.368357092142105, 28.744192197918892, 53.96975040435791, 65.8957676589489, 47.478277534246445, 2.625910369679332, 0.2427587760030292, 0.3361923334887251, 0.08314989172504283, 0.1246879788232036, 0.15688287938246503, 0.2017213639919646, 0.14497173571726307, 0.33657082880381495, 0.3088842675788328, 0.14745436812518165, 0.09589364344719797], [0.07830141126760282, 0.05820185171614867, 0.011206510625925148, 0.03113347353064455, 0.03325054996821564, 0.08873563652741723, 0.03151232136588078, 0.055308871014858596, 0.0915891349723097, 0.05159651474968996, 0.01824866922106594, 0.06374946868163534, 0.023334097022598144, 0.012168948142061708, 0.057942393177654594, 12.195619437843561, 45.44917121529579, 45.06341211497784, 39.15021501481533, 20.867174975574017, 32.87437677383423, 41.0128028690815, 48.95414873957634, 47.26425401866436, 7.0858830492943525, 0.4402578837471083, 0.7330536365043372, 2.0272681675851345, 0.493337205844, 0.5611075786873698, 7.455155784264207, 28.66328503936529, 49.59019660949707, 53.26626755297184, 51.655321195721626, 50.243047177791595, 50.42663432657719, 47.87520043551922, 50.46085529029369, 48.71573433279991, 47.950907573103905, 45.549307242035866, 50.187744945287704, 48.384167924523354, 50.76856657862663, 49.217694997787476, 50.81692278385162, 48.68576914072037, 48.25097367167473, 48.999377712607384, 48.657487258315086, 49.457823112607, 48.57291519641876, 46.161009818315506, 44.80584293603897, 42.34612852334976, 40.73838919401169, 37.27027729153633, 36.70350730419159, 36.418875977396965, 37.17851981520653, 36.36044271290302, 36.816783025860786, 37.06646762788296, 37.062717229127884, 36.1128555983305, 36.88434340059757, 37.981059551239014, 38.03022891283035, 37.46627077460289, 36.984297037124634, 38.40887099504471, 36.83761350810528, 35.501168221235275, 39.301055520772934, 35.647726356983185, 43.022370636463165, 50.48501819372177, 49.31934334337711, 37.66325980424881, 48.85617479681969, 47.40281358361244, 45.42569227516651, 40.651879236102104, 38.409228175878525, 37.785795629024506, 49.51569780707359, 51.75001971423626, 53.07837903499603, 46.4711719751358, 43.237967267632484, 51.125021651387215, 50.126294642686844, 50.41881814599037, 49.76522281765938, 49.303935170173645, 51.55038222670555, 44.80625331401825, 38.571962043643, 36.52490168809891, 36.99560523033142, 37.728392109274864, 38.99332143366337, 38.662051409482956, 37.13186211884022, 38.43183696269989, 38.219561353325844, 38.609226644039154, 39.01522345840931, 36.81321121752262, 37.339463979005814, 35.83857871592045, 36.64587579667568, 36.383898854255676, 36.06799140572548, 37.23055422306061, 35.579956993460655, 35.66733330488205, 35.16382612287998, 35.53824283182621, 36.04097865521908, 36.31682485342026, 35.87596110999584, 35.33274605870247, 34.571798890829086, 33.836956322193146, 35.783120691776276, 38.1408029794693, 42.8718189150095, 45.642056465148926, 46.292748749256134, 49.19174998998642, 49.635862559080124, 47.84827508032322, 51.31538383662701, 48.434667214751244, 49.86965261399746, 46.94342203438282, 41.81701071560383, 40.64685970544815, 49.63346488773823, 48.485417291522026, 53.66200111806393, 54.08826984465122, 54.5781509578228, 54.25119370222092, 55.264675319194794, 50.94431474804878, 48.91839265823364, 20.177928060293198, 1.8126946315169334, 1.106348040048033, 1.8426738353446126, 1.7595461709424853, 0.08221114912885241, 2.7739307144656777, 51.230120211839676, 54.73117254674435, 43.04279454052448, 32.413294315338135, 31.75018049776554, 40.654573291540146, 49.40277926623821, 21.468798592686653, 0.638701255666092, 0.06548892182763666, 0.054498946701642126, 0.05195529491174966, 0.053728293132735416, 0.055922178144101053, 0.06800023824325763, 0.06199725430633407, 0.06619658932322636, 0.060402575618354604, 0.020160849817330018, 0.047096569105633534, 0.0364804248965811, 0.026812391042767558, 0.010268571404594695, 0.004397693464852637, 0.1072645110252779, 0.04807383658771869, 0.022493193609989248, 0.08287277378258295, 0.06802524861996062, 0.041218711266992614, 0.057212683896068484, 0.04003649599326309, 0.010657590373739367, 0.040905814385041595, 0.031875866116024554, 15.117626544088125, 53.71288038790226, 50.78494369983673, 43.06273587048054, 23.218593299388885, 40.448932126164436, 48.44579681754112, 52.05005921423435, 51.07180170714855, 7.7038405649363995, 0.4127935809083283, 0.5014229938387871, 3.7531262962147593, 2.161375558935106, 1.6723964223638177, 9.58152025938034, 30.746424458920956, 53.745410442352295, 52.9100176692009, 54.16935749351978, 50.87333455681801, 51.96264870464802, 50.94522289931774, 52.760507091879845, 51.065277457237244, 48.8930594176054, 47.11100824177265, 51.37933820486069, 49.953084737062454, 53.3081679046154, 51.940317302942276, 52.25891500711441, 49.24761839210987, 50.064673349261284, 50.4871878772974, 50.617817267775536, 49.99127268791199, 51.3061161339283, 48.21315810084343, 48.79488788545132, 44.93668511509895, 42.747159004211426, 39.35860723257065, 38.6394502222538, 39.467919766902924, 40.192328095436096, 37.89877876639366, 38.97766627371311, 38.19100208580494, 38.608421087265015, 37.36504040658474, 39.21545371413231, 40.029757618904114, 39.80366975069046, 38.68829660117626, 39.28673408925533, 41.15363851189613, 37.225705683231354, 37.627727910876274, 39.95169460773468, 38.62174317240715, 44.96666930615902, 53.3412679284811, 51.4204216003418, 42.38104484975338, 52.237780541181564, 50.28190389275551, 48.686753287911415, 41.45899772644043, 40.311333909630775, 40.718474462628365, 52.72455342113972, 53.106980100274086, 54.124732688069344, 47.01379045844078, 48.44152584671974, 53.27966943383217, 51.44000194966793, 53.49052771925926, 52.00780928134918, 51.71488679945469, 52.99610584974289, 47.06929787993431, 40.180149748921394, 37.753561958670616, 38.45579467713833, 38.27494338154793, 40.59045173227787, 40.284321159124374, 39.20718915760517, 40.35069979727268, 40.50437495112419, 39.945808723568916, 39.58082690834999, 38.53196159005165, 38.66000331938267, 37.99257293343544, 38.403524681925774, 38.02050523459911, 38.96352343261242, 39.0382844209671, 38.468303605914116, 37.74331770837307, 36.70734889805317, 37.053517922759056, 38.3406038582325, 37.713428512215614, 36.44839659333229, 36.304612308740616, 36.15510933101177, 36.623069420456886, 37.51340724527836, 40.99036507308483, 46.12792119383812, 48.14454138278961, 47.429613545536995, 51.675764098763466, 52.04604662954807, 50.19235409796238, 53.826026916503906, 51.47819750010967, 51.14433601498604, 50.29798462986946, 45.3900957852602, 42.587977945804596, 51.37498363852501, 52.15459160506725, 55.00560902059078, 56.156445667147636, 56.599893271923065, 57.45279170572758, 56.31682366132736, 52.80545487999916, 50.36496743559837, 20.666796527802944, 2.617257284000516, 1.7322985455393791, 2.210096069611609, 2.2775849606841803, 0.07165950868511572, 3.0305183585733175, 57.73374482989311, 58.92712019383907, 54.59052689373493, 35.68301886320114, 31.750721968710423, 46.54262334108353, 56.892872750759125, 29.05841253697872, 0.745735812233761, 0.052427193222683854, 0.037950315163470805, 0.06840231159003451, 0.05011047534935642, 0.009748856518854154, 0.03141218709060922, 0.05490820774866734, 0.008970308354037115, 0.05740359396440908, 0.01977414449356729, 0.02005743339395849, 0.2507389266975224, 0.1980955124599859, 0.18557283910922706, 0.1276502019027248, 0.18704539368627593, 0.21035454527009279, 0.15328395296819508, 0.17634524207096547, 0.18839415803086013, 0.21699961682315916, 0.2511732908897102, 0.16014044755138457, 0.16547249659197405, 0.2310037802089937, 0.22641500690951943, 18.304505087435246, 62.41832725703716, 58.94920840859413, 48.17672945559025, 31.772747486829758, 47.25515730679035, 51.68020226061344, 58.82790371775627, 58.51801134645939, 10.075861383229494, 0.6964027625508606, 3.3066806523129344, 5.471738688647747, 2.6283880742266774, 1.9665153650566936, 10.305328220129013, 31.858275197446346, 54.258755296468735, 56.39005333185196, 56.79576516151428, 54.35715101659298, 55.12219436466694, 54.0955426543951, 55.54463289678097, 54.05872642993927, 51.747185066342354, 49.07971300184727, 55.059163346886635, 53.37257444858551, 56.01045750081539, 53.28404679894447, 54.09032553434372, 50.89612193405628, 50.93656696379185, 52.04089790582657, 51.456280276179314, 53.06743182241917, 53.035608530044556, 51.738251745700836, 49.320768266916275, 47.23360486328602, 45.442665964365005, 40.38237489759922, 40.709693133831024, 41.28132306039333, 42.646399810910225, 40.232757925987244, 40.88404677808285, 41.300747618079185, 40.379874631762505, 39.87712740898132, 39.73807767033577, 41.59173980355263, 40.16489736735821, 40.79076558351517, 41.65523439645767, 44.11820523440838, 40.5198173224926, 40.50589106976986, 43.432771414518356, 39.60967876017094, 45.57841368019581, 55.525120943784714, 53.995334431529045, 44.80643570423126, 54.33494880795479, 51.880280524492264, 50.52301235496998, 42.78863377869129, 42.47681871056557, 42.058613151311874, 53.21019396185875, 54.52653832733631, 55.7117023319006, 48.41216862201691, 48.44010852277279, 53.34149591624737, 53.26694771647453, 54.01008903980255, 53.047133311629295, 53.04835304617882, 55.146433264017105, 48.605426251888275, 42.34906956553459, 38.862684443593025, 41.67416878044605, 42.058202773332596, 44.05779987573624, 42.4045579880476, 41.48639425635338, 43.457861468195915, 42.615169286727905, 41.832323893904686, 42.903611809015274, 40.03965608775616, 40.8134313672781, 38.744613379240036, 41.43581137061119, 40.91718479990959, 40.7296534627676, 41.97663635015488, 41.01566791534424, 39.484908655285835, 38.60315077006817, 39.25257012248039, 40.42459823191166, 39.46258865296841, 38.77306625247002, 40.39271414279938, 38.318451046943665, 39.37835477292538, 39.03405524790287, 43.94748039543629, 47.936768531799316, 50.96358731389046, 50.260290652513504, 52.15708427131176, 53.84621903300285, 53.024323135614395, 56.35601095855236, 53.04110303521156, 52.44200058281422, 51.86814397573471, 48.12401868402958, 43.358500599861145, 54.07119736075401, 53.30812610685825, 56.56089976429939, 57.469203025102615, 57.07185074687004, 58.381541669368744, 57.74002969264984, 53.67607556283474, 52.15580753982067, 23.85934341698885, 3.179331198334694, 3.0633751954883337, 7.6817290764302015, 4.440589444711804, 0.16725863824831322, 3.2238469971343875, 61.66958883404732, 65.48624843358994, 59.89762991666794, 46.106110364198685, 42.78490237891674, 56.01388871669769, 64.7142818570137, 38.74880075454712, 1.2164759868755937, 0.22032115812180564, 0.16584940371103585, 0.23840459558414295, 0.2167630201438442, 0.14355985913425684, 0.13970897358376533, 0.16878308379091322, 0.205881368892733, 0.14301044720923528, 0.10451617490616627, 0.14107500028330833], [0.029677403908863198, 0.053940087236696854, 0.021075335316709243, 0.040504175194655545, 0.0781580431794282, 0.0042159563417953905, 0.05919552808336448, 0.11214591315365396, 0.09204348520142958, 0.03567751758964732, 0.025598768079362344, 0.046752342459512874, 0.06325643029413186, 0.01397374646330718, 0.017135341950051952, 6.289129927754402, 42.486591786146164, 42.1344380825758, 50.62994621694088, 30.10907705873251, 25.536250434815884, 42.603249326348305, 49.48159843683243, 51.055880561470985, 16.70803215354681, 0.02895817560784053, 0.4170520539628342, 3.138611395843327, 0.9580201492644846, 1.361526078544557, 2.1270899986848235, 16.825630143284798, 48.6226849257946, 52.24394381046295, 49.65818636119366, 45.7918444275856, 51.47635079920292, 47.654515877366066, 50.22259287536144, 50.53274743258953, 50.82272507250309, 47.25715979933739, 51.476552188396454, 50.00867575407028, 51.21685512363911, 48.654895797371864, 49.124645590782166, 49.025592505931854, 51.905096992850304, 47.73879535496235, 46.11036993563175, 48.965396136045456, 52.282561138272285, 48.8993176817894, 48.76986242830753, 45.98638258874416, 42.22910240292549, 40.05366213619709, 40.13234071433544, 35.56281231343746, 35.57530604302883, 34.865481331944466, 34.89060938358307, 35.93510873615742, 36.99172183871269, 36.61851726472378, 38.43790523707867, 37.58640892803669, 35.31423345208168, 36.33250281214714, 36.80575981736183, 37.43661716580391, 37.522348165512085, 34.88718956708908, 37.04638570547104, 35.63464365899563, 47.95104056596756, 48.69832746684551, 52.709631621837616, 46.700721457600594, 46.76999554038048, 48.12070146203041, 46.55240021646023, 41.38024315237999, 40.80981396138668, 38.759721368551254, 47.49212399125099, 52.7938275039196, 54.57285784184933, 49.023141637444496, 41.22979782521725, 48.69211480021477, 49.086244851350784, 49.337042793631554, 50.36831505596638, 51.896129474043846, 47.31888748705387, 42.05351762473583, 36.129035130143166, 35.598154217004776, 36.892801746726036, 35.21213673055172, 39.48181942105293, 38.16896706819534, 37.29594871401787, 37.10214011371136, 39.02069516479969, 38.3679623901844, 36.49652861058712, 35.95900185406208, 37.37667538225651, 35.953020974993706, 36.92114822566509, 37.10030101239681, 36.867160722613335, 37.9140767455101, 38.17307084798813, 38.2548538595438, 36.31259188055992, 35.76353654265404, 36.61747232079506, 36.10675312578678, 36.79085321724415, 34.60021376609802, 35.057667419314384, 33.6377178132534, 34.45485256612301, 36.29394628107548, 39.56011801958084, 43.87607462704182, 46.18212528526783, 48.483057618141174, 49.6943224221468, 48.76926586031914, 46.25281289219856, 49.00462903082371, 50.09491212666035, 50.546890273690224, 45.59222213923931, 38.088833168148994, 36.73798285424709, 42.338129952549934, 47.05097906291485, 45.316311344504356, 47.41827495396137, 52.65321984887123, 52.521002143621445, 53.45385208725929, 45.17816215753555, 16.169585846364498, 1.1628311779350042, 1.0316919023171067, 2.6498136995360255, 2.3301449278369546, 0.2396363826119341, 4.1666873171925545, 37.971601858735085, 51.24290652573109, 41.3332586735487, 25.762345902621746, 19.1201389208436, 37.186149805784225, 54.105961695313454, 15.29625590890646, 0.24043460696702823, 0.0687410871614702, 0.10301496600732207, 0.016960480825218838, 0.04533060644462239, 0.03221542836399749, 0.03500563274428714, 0.013119117957103299, 0.04535934240266215, 0.010530891850066837, 0.060867137799505144, 0.06121107500803191, 0.05676900575053878, 0.03941558927181177, 0.03236175391066354, 0.04954846546752378, 0.041904262761818245, 0.02130206885340158, 0.019768133097386453, 0.043981819835607894, 0.054065012955106795, 0.06128523040388245, 0.05726382900320459, 0.021674289309885353, 0.03901350108208135, 0.0867806636961177, 0.02950581936602248, 7.661602031439543, 48.798968866467476, 49.79471683502197, 52.933272421360016, 29.69416592270136, 32.32887804508209, 47.12439872324467, 55.610718950629234, 55.61491012573242, 17.35413048416376, 0.09058251554961316, 0.41400532994885, 2.2157280799001455, 3.9475727872923017, 2.386282877996564, 3.7558141769841313, 20.069561675190926, 50.778677836060524, 53.967215940356255, 52.35240899026394, 50.34545548260212, 53.03498916327953, 50.297087877988815, 52.59285248816013, 52.141653299331665, 52.29119807481766, 50.002478286623955, 52.99890249967575, 51.2189944088459, 52.63341911137104, 50.0706922262907, 50.98303847014904, 50.046905502676964, 50.57016022503376, 50.3205706179142, 48.741994723677635, 51.00637301802635, 53.76639671623707, 49.097135066986084, 49.57358010113239, 47.21808649599552, 44.4918429851532, 43.5788431763649, 42.0010956376791, 36.88420660793781, 37.32019521296024, 36.207326129078865, 37.78348155319691, 38.51218745112419, 38.530730456113815, 37.85348899662495, 40.36752909421921, 41.141178980469704, 37.65052668750286, 37.80094161629677, 38.21006566286087, 38.93474757671356, 39.557944536209106, 36.496300622820854, 38.341097831726074, 36.65598705410957, 48.66338074207306, 48.91687273979187, 54.98937249183655, 47.68315114080906, 49.025360718369484, 48.77985589206219, 48.38158406317234, 43.104674220085144, 43.02865169942379, 41.657176092267036, 48.425080329179764, 53.22209492325783, 55.28263695538044, 49.90329220890999, 44.57490272819996, 52.697540670633316, 52.43502035737038, 52.044804096221924, 53.73379446566105, 53.04017208516598, 50.696674436330795, 42.82353490591049, 37.37755313515663, 37.09541827440262, 37.40314096212387, 38.82340595126152, 40.40961943566799, 41.497634053230286, 38.99187371134758, 38.81171017885208, 41.12930841743946, 38.39061677455902, 37.834630608558655, 38.17254267632961, 37.593453750014305, 38.614664152264595, 38.7455253303051, 38.688760176301, 39.48707453906536, 39.77202504873276, 39.43018399178982, 39.3013709038496, 38.23980286717415, 38.27645190060139, 38.50813306868076, 37.795648500323296, 40.0639595836401, 35.78551076352596, 37.350905165076256, 36.502175107598305, 37.2990645468235, 38.96162733435631, 41.01222909986973, 46.89946599304676, 49.539545327425, 48.776724860072136, 51.266195476055145, 50.82391820847988, 49.943402856588364, 51.129197627305984, 52.429651245474815, 53.01556080579758, 46.94601729512215, 39.68774937093258, 40.46329915523529, 45.24707905948162, 49.13197919726372, 48.58917452394962, 50.19483536481857, 55.60591600835323, 54.442008063197136, 55.79346254467964, 48.91765929758549, 17.629155926406384, 1.5777628566138446, 1.5172924264334142, 5.027774786576629, 4.063744191080332, 0.07988445679075085, 4.943101555109024, 46.32190078496933, 58.10156889259815, 49.23020772635937, 34.989537075161934, 28.57176125049591, 43.37963126599789, 61.88701316714287, 20.285885967314243, 0.3817776561481878, 0.08620192209491506, 0.20398129272507504, 0.01781038834451465, 0.047728893769090064, 0.015716542984591797, 0.07982946364791133, 0.013446664834191324, 0.03363156116392929, 0.08006370771909133, 0.07749725715257227, 0.05119346547871828, 0.12741897837258875, 0.10841872135642916, 0.12592598504852504, 0.11183150229044259, 0.09426476288354024, 0.09469095602980815, 0.14085214817896485, 0.14796401577768847, 0.1338572133681737, 0.13573739997809753, 0.1509542771964334, 0.16806406143587083, 0.12536201218608767, 0.12492444191593677, 0.12256661648279987, 9.107042569667101, 56.16539418697357, 56.58711455762386, 59.39676359295845, 41.7193977534771, 38.36878314614296, 52.41112343966961, 60.96674434840679, 60.53064174950123, 20.900404192507267, 0.16715196194127202, 1.8209625128656626, 9.797537717968225, 5.9847985580563545, 2.895472892560065, 3.5336643224582076, 20.907346419990063, 52.924688681960106, 55.98032511770725, 54.6336355805397, 51.216570138931274, 56.47188954055309, 52.358378469944, 55.4800059646368, 55.66583499312401, 55.5383176356554, 51.793132200837135, 53.9838932454586, 53.46917666494846, 54.09723736345768, 52.136234790086746, 52.24182732403278, 51.73117272555828, 53.11753213405609, 50.77912241220474, 50.801848992705345, 53.24345737695694, 56.094797775149345, 49.91523876786232, 52.4377828091383, 49.49107512831688, 45.34532658755779, 45.35462848842144, 44.43510442972183, 39.28202234208584, 38.15533719956875, 38.26652683317661, 40.10566234588623, 39.64568182826042, 40.98043620586395, 40.59254541993141, 41.99503496289253, 41.66161425411701, 37.88988344371319, 38.77572610974312, 40.391418412327766, 40.839041993021965, 40.79947471618652, 38.01901571452618, 40.94032555818558, 39.152464494109154, 52.612459436059, 50.96038408577442, 56.278289929032326, 51.86395280063152, 53.52455489337444, 51.19987763464451, 49.71722759306431, 45.74933610856533, 44.91685777902603, 42.42481470108032, 50.446184277534485, 55.749776288867, 58.023794665932655, 52.619093880057335, 44.795169308781624, 53.51223975419998, 55.10965883731842, 53.50609928369522, 54.73088376224041, 57.668361738324165, 52.10125386714935, 44.81090426445007, 38.369584903120995, 39.0671780705452, 40.38094997406006, 39.62076276540756, 43.59979145228863, 43.40997263789177, 40.229706689715385, 40.64663551747799, 42.56927914917469, 41.593829691410065, 40.45751206576824, 40.652050226926804, 40.491721630096436, 40.23576736450195, 40.500510558485985, 39.18396480381489, 41.29471354186535, 41.982731223106384, 41.50650657713413, 42.30711221694946, 41.10980026423931, 38.72003249824047, 40.48582434654236, 40.74074886739254, 41.957306787371635, 37.79188670217991, 39.23673637211323, 38.17151293158531, 38.926380425691605, 41.003291979432106, 44.80783402919769, 48.34432706236839, 50.29482699930668, 52.41471044719219, 55.45588865876198, 52.14874751865864, 50.65416991710663, 53.66718403995037, 54.12960022687912, 55.6326437741518, 50.701861158013344, 41.04061357676983, 42.25965656340122, 47.184739485383034, 51.68807163834572, 50.41434958577156, 52.6844921708107, 57.61905178427696, 57.09480531513691, 57.584462240338326, 49.311481565237045, 19.773329570889473, 1.8015392613597214, 2.6476587401703, 10.6776512414217, 9.583617746829987, 0.32673511595930904, 5.000719288364053, 49.617460146546364, 65.55009260773659, 59.39775533974171, 39.42407771945, 34.3423406034708, 50.059296637773514, 71.25657320022583, 26.779536120593548, 0.47063603647984564, 0.2405898048891686, 0.20978135493351147, 0.15399893803987652, 0.1123849292343948, 0.1321378501597792, 0.16000310570234433, 0.0630107348843012, 0.11265933091635816, 0.20218816003762186, 0.18835071270586923, 0.13325240754056722], [0.04620514955604449, 0.051815021579386666, 0.02387607077253051, 0.055623556472710334, 0.036839323802269064, 0.015758459485368803, 0.05816481483634561, 0.0473587513261009, 0.02146565489965724, 0.03753729513846338, 0.007476748678527656, 0.019626455250545405, 0.042251116610714234, 0.052399822816369124, 0.0552125291142147, 2.3748663906008005, 34.06245522201061, 44.750715494155884, 48.282732367515564, 26.734385043382645, 30.317398980259895, 45.04959225654602, 49.300538152456284, 52.98268496990204, 30.5377434566617, 0.8976551634259522, 0.4729176952969283, 1.4374875649809837, 3.8738370314240456, 2.3961112881079316, 1.2239681161008775, 8.973643127828836, 43.111441656947136, 52.49277725815773, 54.240079298615456, 51.06836289167404, 50.896536111831665, 50.755149498581886, 50.680871084332466, 51.428078189492226, 51.30118399858475, 50.57635009288788, 49.97998729348183, 48.709407672286034, 49.72565174102783, 48.9948445558548, 50.05116127431393, 48.24876978993416, 48.126948326826096, 43.081161081790924, 48.99150833487511, 45.00286616384983, 49.236378595232964, 47.34350636601448, 48.971251621842384, 46.4546162635088, 47.34205864369869, 42.99179747700691, 42.539218962192535, 40.43169245123863, 37.877541705965996, 35.31151279807091, 37.371484860777855, 35.77255725860596, 36.157788187265396, 35.46831898391247, 38.19998100399971, 35.345463976264, 36.92438565194607, 37.06256903707981, 35.95637619495392, 36.73685811460018, 35.97738906741142, 36.160907819867134, 36.36017672717571, 36.80267058312893, 45.94708129763603, 49.36917386949062, 49.22186337411404, 49.08475153148174, 46.95666432380676, 47.37579703330994, 46.713568568229675, 42.93592907488346, 42.68146052956581, 39.6232820302248, 46.94487735629082, 52.2420971095562, 54.26919333636761, 44.06924486160278, 42.00084485113621, 45.54269179701805, 49.636550322175026, 52.082684263587, 53.70471462607384, 49.593209847807884, 47.77430444955826, 40.30590020120144, 36.32204197347164, 34.76009398698807, 37.60110653936863, 36.79102420806885, 38.62631432712078, 39.03019465506077, 38.1716763228178, 36.55007913708687, 38.530259281396866, 38.04773077368736, 38.14239889383316, 37.27594658732414, 38.47915582358837, 37.58973754942417, 36.66306607425213, 36.274460926651955, 35.549908205866814, 36.53693184256554, 34.97880645096302, 36.22262790799141, 36.84769816696644, 36.6410006582737, 36.04462645947933, 37.54458077251911, 36.56531251966953, 36.004401817917824, 34.65045087039471, 35.99901370704174, 34.16572228074074, 34.06105689704418, 37.30612836778164, 42.62783020734787, 46.20208561420441, 48.02370026707649, 51.148705780506134, 46.447541043162346, 49.00132320821285, 47.14940518140793, 49.35431286692619, 53.79042662680149, 51.654052063822746, 44.91240441799164, 42.66194857656956, 38.3039016276598, 43.53114053606987, 42.17897929251194, 46.38708248734474, 47.22798116505146, 53.94969888031483, 52.68356502056122, 44.92203310132027, 8.195714671164751, 1.0903506609611213, 0.6794493191409856, 1.5720509318634868, 1.3789965910837054, 0.11942422963329591, 5.2504627872258425, 51.51860453188419, 50.01427665352821, 43.41284528374672, 21.146416291594505, 22.74779286235571, 43.09569530189037, 45.94531439244747, 13.606193996965885, 0.11825164372567087, 0.05039799078076612, 0.03663624251203146, 0.052039231813978404, 0.031385417823912576, 0.04322002379922196, 0.0312599466269603, 0.036270812706789, 0.026980311231454834, 0.15208124328637496, 0.03286818064225372, 0.02934776603069622, 0.029686096313525923, 0.06033767851477023, 0.05232236115261912, 0.03487483292701654, 0.032423927332274616, 0.041115578715107404, 0.03378391294972971, 0.03886880454956554, 0.025314104350400157, 0.0335388261009939, 0.021742811804870144, 0.12969980598427355, 0.02844424576323945, 0.04366959088656586, 0.10380941283074208, 3.2549894135445356, 42.981082051992416, 49.2644514888525, 51.61921173334122, 32.28030905127525, 33.43263901770115, 50.488160625100136, 54.78553622961044, 58.14796060323715, 32.10928022861481, 0.8204243669752032, 0.16739614336984232, 1.7435186309739947, 3.6197631899267435, 5.22857928648591, 2.783089173026383, 9.938485454767942, 45.88812366127968, 53.183238208293915, 54.50438931584358, 53.12707342207432, 53.46606843173504, 53.01245257258415, 51.35718159377575, 51.619519516825676, 54.938219636678696, 52.84309186041355, 52.32667297124863, 51.14871338009834, 50.24170204997063, 49.92278516292572, 49.95294414460659, 48.05118799209595, 51.575597673654556, 45.9657496958971, 48.79861168563366, 46.256947070360184, 50.252060294151306, 49.17392514646053, 50.163487046957016, 48.72811406850815, 48.324332535266876, 46.3705837726593, 44.13853794336319, 41.46468602120876, 39.671102464199066, 37.38325662910938, 37.78743714094162, 36.80715054273605, 37.213572934269905, 36.50861196219921, 40.927185863256454, 38.30441080033779, 37.63685502111912, 37.778815403580666, 37.909045815467834, 38.61434876918793, 36.15310303866863, 38.18946696817875, 37.11673513054848, 37.86795862019062, 45.94162479043007, 50.56266322731972, 51.805667728185654, 51.35154269635677, 47.935541197657585, 48.49432401359081, 47.691430896520615, 45.09797506034374, 43.54551516473293, 41.98227904736996, 48.21910098195076, 55.97275212407112, 54.14765685796738, 46.01223640143871, 44.436084777116776, 50.42984515428543, 51.173917427659035, 54.67974990606308, 55.153816267848015, 52.39950366318226, 49.964533522725105, 41.35330639779568, 37.526087164878845, 36.616051197052, 38.39568570256233, 39.541187435388565, 41.336480900645256, 40.711726024746895, 39.38139081001282, 38.43473240733147, 39.97276447713375, 40.85231468081474, 40.51449000835419, 39.087620973587036, 39.809677228331566, 38.46038483083248, 38.06747451424599, 37.19781897962093, 38.64740699529648, 38.47906082868576, 38.881026059389114, 37.63738699257374, 38.72965358197689, 37.164418771862984, 38.305657133460045, 39.23702895641327, 38.67607265710831, 37.06853851675987, 36.32223576307297, 37.722536623477936, 35.96564009785652, 36.312139704823494, 39.57461804151535, 45.06841644644737, 49.467360600829124, 50.112284794449806, 51.03335916996002, 48.33899214863777, 51.29418857395649, 48.99633787572384, 52.495475113391876, 54.70080457627773, 53.59703980386257, 45.96961788833141, 45.23313380777836, 39.84020099043846, 44.25151728093624, 44.03109110891819, 48.59328970313072, 50.15443213284016, 55.63138984143734, 56.416693702340126, 45.23905389010906, 10.707040764391422, 1.4977583871223032, 2.0338382525369525, 1.979112639091909, 1.5803056326694787, 0.06911153017426841, 5.698131015524268, 54.802198335528374, 55.282196179032326, 51.96447640657425, 25.72982344776392, 25.283214412629604, 48.612406477332115, 55.17526611685753, 17.39540956914425, 0.06871068137115799, 0.11016621196176857, 0.05180535139515996, 0.022404827941500116, 0.04307154602429364, 0.020577361647156067, 0.037198434220044874, 0.032001745494198985, 0.04166840451944154, 0.15691385662648827, 0.04198809576337226, 0.010848536621779203, 0.11405499899410643, 0.17008248047204688, 0.17853885248769075, 0.1704622819670476, 0.12796215625712648, 0.19493635307298973, 0.15471355203771964, 0.10222184762824327, 0.1268973821424879, 0.12686996720731258, 0.1784565334673971, 0.18161523272283375, 0.08304162722197361, 0.1419514766894281, 0.14603431307477877, 3.882309626787901, 50.75410835444927, 57.490778267383575, 58.94899941980839, 38.66196781396866, 42.37565293908119, 56.45957440137863, 59.709384217858315, 63.039096146821976, 37.66746237874031, 1.603850950486958, 1.1079846834763885, 6.5950980596244335, 9.638702441006899, 6.132008833810687, 3.6661518132314086, 11.230351533740759, 49.4206041097641, 55.4789762198925, 58.2721721380949, 55.68780921399593, 55.80902650952339, 53.96101467311382, 53.32161918282509, 53.400301560759544, 56.046365574002266, 54.197992756962776, 54.42897096276283, 52.68366761505604, 51.62898100912571, 50.8629535138607, 52.28385306894779, 51.44550025463104, 50.564487129449844, 45.89306719601154, 51.786246970295906, 47.79866874217987, 52.68571950495243, 52.28992514312267, 53.61710272729397, 49.99433912336826, 49.63821843266487, 47.419050112366676, 46.289807707071304, 43.36272217333317, 43.00185553729534, 38.535480201244354, 40.84034912288189, 38.02227973937988, 38.4103225171566, 37.436047196388245, 43.07292312383652, 39.83916364610195, 40.375371873378754, 40.44508293271065, 39.724147617816925, 41.23365841805935, 38.80000680685043, 40.89676469564438, 39.368707090616226, 40.30309595167637, 48.91585819423199, 52.994806319475174, 53.243058398365974, 53.14460568130016, 51.08896158635616, 51.49499639868736, 51.61833398044109, 47.37896606326103, 47.10849657654762, 45.27948372066021, 50.33187881112099, 57.489611729979515, 57.121058106422424, 47.0117461681366, 44.5035919547081, 48.42752739787102, 53.50680224597454, 57.15811751782894, 58.830145597457886, 53.51035885512829, 52.311150804162025, 43.05051192641258, 40.2815967053175, 39.75366063416004, 41.23123034834862, 40.96380069851875, 42.50714108347893, 43.78726579248905, 41.37359730899334, 39.6155646443367, 42.40635149180889, 42.49195709824562, 41.30533017218113, 40.83198197185993, 42.23825231194496, 41.03487968444824, 40.776561945676804, 38.454650938510895, 39.57665093243122, 40.6576207280159, 40.54723285138607, 39.28644150495529, 40.945459082722664, 40.21248981356621, 40.39605796337128, 41.33273430168629, 40.832954719662666, 39.48838546872139, 38.436480313539505, 40.242937579751015, 37.69313380122185, 37.55770146846771, 41.98758736252785, 46.67147442698479, 53.46283100545406, 52.99230605363846, 54.76428396999836, 49.55555386841297, 52.406746074557304, 49.718827307224274, 52.671325877308846, 58.53427827358246, 56.16110801696777, 49.26537863910198, 48.720480278134346, 43.43473210930824, 49.034142047166824, 46.14600822329521, 52.37936474382877, 52.11104974150658, 58.41835789382458, 56.47468999028206, 49.08785976469517, 10.20500410348177, 2.7362326998263597, 4.51493720524013, 4.980422202497721, 5.112950541079044, 0.22022053773980588, 6.20376655831933, 61.41653761267662, 60.317872166633606, 56.5488126128912, 32.4034034460783, 34.53973241150379, 55.67596144974232, 63.03022742271423, 23.553760014474392, 0.396179388044402, 0.24230447772424668, 0.13198057422414422, 0.15581102517899126, 0.11158943598275073, 0.19424652680754662, 0.10952788332360797, 0.15348278917372227, 0.12695157376583666, 0.25840442162007093, 0.10546761564910412, 0.09530387353152037], [0.031205658524413593, 0.031130486386246048, 0.05838925513671711, 0.07675596294575371, 0.016532590016140603, 0.038517883731401525, 0.039713197911623865, 0.022720147935615387, 0.030230289085011464, 0.035762738407356665, 0.03122681715467479, 0.053015063240309246, 0.05995951345539652, 0.04645553162845317, 0.07453861864632927, 0.46587702934630215, 17.158990055322647, 40.290659219026566, 47.3674488812685, 25.31270083039999, 25.002550072968006, 38.921733275055885, 51.825890243053436, 51.53099946677685, 43.462166637182236, 3.040634603239596, 0.22287318133749068, 0.3679862368153408, 2.8400768525898457, 3.6213963897898793, 1.990084194112569, 3.5945023829117417, 42.26874187588692, 55.67759916186333, 52.44377128779888, 53.67271274328232, 50.59476390480995, 51.013132855296135, 47.00554110109806, 48.79732735455036, 47.47101232409477, 47.94329658150673, 47.77053125202656, 50.631443336606026, 49.76454645395279, 50.416086092591286, 48.48320960998535, 50.57886175811291, 46.50218591094017, 45.89053653180599, 48.674130365252495, 47.29599371552467, 49.45204742252827, 46.48172400891781, 48.480922132730484, 48.85788090527058, 49.05139312148094, 47.059927582740784, 46.8732625991106, 43.77622738480568, 39.36699718236923, 34.864443987607956, 36.574052050709724, 36.45179361104965, 36.207360327243805, 36.732153967022896, 39.79776866734028, 38.580465987324715, 37.93116822838783, 38.71547274291515, 36.99342034757137, 38.30931633710861, 35.72931557893753, 37.00590267777443, 35.50192438066006, 36.51586577296257, 45.52278846502304, 50.08401431143284, 48.56927879154682, 48.492773696780205, 49.68835674226284, 48.187737464904785, 47.31149688363075, 43.28022480010986, 44.923207238316536, 40.07672309875488, 44.982263669371605, 51.091819033026695, 54.23753723502159, 46.734277456998825, 42.58890509605408, 45.63205540180206, 50.10282330214977, 52.87334583699703, 52.25717090070248, 48.94194759428501, 47.81149685382843, 38.10654781758785, 33.638310581445694, 34.19735178351402, 36.52796432375908, 36.92632734775543, 39.114219546318054, 40.83086483180523, 36.6103895008564, 38.913628309965134, 37.795390114188194, 38.65556515753269, 38.44352513551712, 36.44985571503639, 36.572345942258835, 36.919502913951874, 36.64703093469143, 35.87903514504433, 36.77716255187988, 37.72314079105854, 38.29097852110863, 37.78113327920437, 36.65872670710087, 37.737447023391724, 37.3716938495636, 36.992231011390686, 37.65448607504368, 36.400405168533325, 35.285742580890656, 34.18874144554138, 34.32329602539539, 35.758467614650726, 36.12331263720989, 39.762616753578186, 46.23161002993584, 47.91680060327053, 48.16123008728027, 49.08295042812824, 48.4468075633049, 45.636242777109146, 48.62387426197529, 49.79958437383175, 49.901008531451225, 50.849920213222504, 51.111251190304756, 49.117760360240936, 47.06957146525383, 47.879706993699074, 48.10343138873577, 49.315915927290916, 51.74701027572155, 53.33745673298836, 37.3819874972105, 6.5397868026047945, 0.408369965152815, 0.9515400126110762, 2.7153407083824277, 2.0977598475292325, 0.037000306765548885, 6.086128195747733, 54.546924233436584, 45.833607986569405, 38.992014303803444, 28.663328737020493, 30.203424096107483, 41.545260697603226, 45.81403523683548, 8.639657199382782, 0.019729183331946842, 0.029380511441559065, 0.0357818301563384, 0.03560249759175349, 0.04657271674659569, 0.01844358503149124, 0.04710235043603461, 0.050299990180064924, 0.02265558850922389, 0.012507888841355452, 0.0145754204277182, 0.06109736685175449, 0.0050773411749105435, 0.029606671669171192, 0.08316872743307613, 0.07109281214070506, 0.03753395918465685, 0.04863891525019426, 0.028514712685137056, 0.029432554547383916, 0.036531499499687925, 0.06859807530418038, 0.03876919348840602, 0.017537936655571684, 0.0456338999356376, 0.04308461895561777, 0.05259232479147613, 0.6763051659800112, 25.856301560997963, 49.294382482767105, 52.86656700074673, 30.064440853893757, 35.85959918797016, 47.22473993897438, 55.126016959548, 55.55742301046848, 44.95702162384987, 3.4648288786411285, 0.3740278829354793, 0.3813608066411689, 4.867249075323343, 8.602116163820028, 2.5794079899787903, 4.643287668004632, 44.59996618330479, 57.92892135679722, 51.86104595661163, 55.16419731080532, 52.96417996287346, 53.54685589671135, 50.43932184576988, 49.442939311265945, 48.90320487320423, 49.76853623986244, 49.28598113358021, 50.312754437327385, 51.01154074072838, 50.830636247992516, 49.582046046853065, 51.702484264969826, 47.812230214476585, 47.032591849565506, 50.10195694863796, 48.096394166350365, 48.50225418806076, 49.81920652091503, 49.693668857216835, 49.68272924423218, 49.27642464637756, 47.35961750149727, 47.88808934390545, 44.34279218316078, 40.05498826503754, 35.69477163255215, 38.30037161707878, 39.05901990830898, 38.595266193151474, 39.13319952785969, 41.05177357792854, 40.560535937547684, 39.0916183590889, 39.85173337161541, 38.43257412314415, 40.02732574939728, 37.78434030711651, 39.78228069841862, 37.299383729696274, 39.199517369270325, 47.00353480875492, 52.63374209403992, 49.439527094364166, 50.60314625501633, 51.48358941078186, 49.279863461852074, 48.943691700696945, 45.60470446944237, 45.05634069442749, 41.836165487766266, 47.020398303866386, 53.46341237425804, 55.707412362098694, 49.48616959154606, 47.51088738441467, 49.74034935235977, 53.29814024269581, 51.949072033166885, 53.55725973844528, 50.4247572273016, 48.75152461230755, 40.462341606616974, 35.21597072482109, 35.73219582438469, 37.96316251158714, 38.611115142703056, 42.587024196982384, 41.49441182613373, 38.94443325698376, 40.09889870882034, 39.17017534375191, 39.48379911482334, 40.07944755256176, 39.257297068834305, 39.30905029177666, 41.023898273706436, 39.446895495057106, 38.465936332941055, 39.335443675518036, 39.1624503582716, 39.240927547216415, 40.457257479429245, 39.303259402513504, 39.4269959628582, 39.50990751385689, 38.52386802434921, 39.12649668753147, 38.5855957120657, 35.225895792245865, 37.874513268470764, 36.54423885047436, 37.32690945267677, 37.88938947021961, 43.45439985394478, 49.09540615975857, 50.016009360551834, 49.82959136366844, 51.29225067794323, 49.36867609620094, 48.43280531466007, 49.57172580063343, 49.55851770937443, 50.80031007528305, 52.65003181993961, 52.63962797820568, 50.946830213069916, 48.37942577898502, 50.31952187418938, 49.310820400714874, 52.13445268571377, 53.85392501950264, 55.52513614296913, 39.47598293423653, 6.830006679520011, 1.0678994469344616, 2.516442993655801, 5.775473015382886, 1.386815384030342, 0.03984496994235087, 6.1295717395842075, 60.92300869524479, 51.04952350258827, 42.5799185782671, 28.946191258728504, 34.172014743089676, 48.331612944602966, 53.597248792648315, 11.661327257752419, 0.09053963425685652, 0.08411172253545374, 0.06740871685906313, 0.021070342518214602, 0.11550104405614547, 0.015110735257621855, 0.061926958078402095, 0.031895651773083955, 0.05192854419874493, 0.05765974252426531, 0.10239885727060027, 0.05021608296374325, 0.0804825387604069, 0.21233826148090884, 0.15257060062140226, 0.17360916623147205, 0.14403858891455457, 0.215666645381134, 0.1551847712835297, 0.16855472495080903, 0.05943924938037526, 0.23131554160499945, 0.08756115072173998, 0.12187854168587364, 0.12773504422511905, 0.12549920560559258, 0.21786516881547868, 0.8577999332919717, 31.3095960393548, 55.56235134601593, 59.17098730802536, 36.51121102273464, 37.146909311413765, 50.2192110568285, 61.98884770274162, 60.81805072724819, 52.16452807188034, 4.369023134931922, 0.7137206301558763, 2.782173422165215, 9.680238962173462, 10.325287599116564, 4.523861976340413, 5.305997282266617, 46.26414768397808, 59.69332627952099, 55.400738418102264, 58.58133114874363, 53.97452674806118, 55.86888089776039, 50.84809631109238, 50.264398232102394, 50.28064616024494, 49.64498966932297, 50.27389772236347, 53.09677764773369, 53.32150138914585, 53.24127249419689, 52.47687891125679, 54.10032659769058, 49.125948920845985, 49.27377998828888, 51.4782202988863, 50.748408660292625, 52.14371278882027, 50.793531239032745, 50.81876568496227, 51.49312309920788, 52.868185713887215, 50.64451843500137, 51.64617508649826, 46.38088122010231, 42.246513068675995, 36.221354976296425, 39.686332046985626, 40.73651969432831, 39.62072856724262, 39.77048613131046, 42.994449734687805, 43.63299787044525, 42.39840991795063, 42.50238373875618, 40.1958467066288, 41.84199057519436, 39.86735053360462, 41.81247375905514, 39.8155365139246, 39.94812659919262, 49.04888905584812, 56.41381725668907, 50.564984902739525, 51.93334087729454, 52.770489156246185, 53.211295902729034, 50.28829135000706, 48.184264451265335, 48.400222063064575, 44.01602491736412, 49.38153460621834, 54.495661184191704, 57.59092189371586, 49.48961600661278, 45.42115531861782, 49.5903106033802, 53.95403824746609, 54.97364893555641, 55.19549623131752, 52.420611530542374, 51.3425599783659, 41.92682862281799, 35.68466417491436, 36.92394107580185, 40.22651106119156, 40.68057909607887, 43.80620777606964, 45.768608674407005, 40.902730375528336, 41.8941617757082, 42.783963829278946, 41.75482325255871, 41.769767850637436, 40.63886113464832, 41.12306535243988, 42.45553605258465, 41.201455146074295, 39.98770907521248, 40.60310125350952, 41.21014527976513, 41.93788222968578, 42.53375105559826, 40.875615030527115, 42.20267102122307, 42.28697329759598, 41.05526179075241, 40.02692677080631, 43.214085549116135, 38.02729167044163, 38.54496069252491, 37.079481929540634, 38.86488452553749, 39.508353397250175, 44.37760591506958, 50.49289897084236, 52.1464828401804, 53.162031546235085, 53.590678945183754, 51.61380462348461, 51.168464720249176, 49.74213145673275, 51.245213001966476, 51.58322386443615, 55.13782672584057, 55.81423982977867, 55.48836171627045, 53.38975332677364, 54.468701630830765, 52.86543466150761, 55.03884583711624, 55.90378202497959, 57.91673921048641, 39.51041288673878, 8.661624770611525, 2.4535060208290815, 3.7606235314160585, 11.785729732364416, 6.421777009963989, 0.20324693759903312, 6.904742019250989, 64.7195103764534, 56.30995362997055, 51.189686581492424, 40.73228672146797, 43.22816759347916, 54.335176795721054, 62.89220742881298, 15.382306091487408, 0.18836729228496552, 0.21134471870027483, 0.1511628503794782, 0.11780241431551985, 0.2698061551200226, 0.09454778090002947, 0.08456757190288045, 0.11454087565653026, 0.17840689863078296, 0.13412993779638782, 0.14536715199938044, 0.16439264203654602], [0.06353297678288072, 0.04803996496775653, 0.05110521669848822, 0.04057752536027692, 0.014861997042316943, 0.08661630025017075, 0.014888606747263111, 0.03529951209202409, 0.050684452362474985, 0.0325019901356427, 0.03739538908121176, 0.0535126213071635, 0.025791663392737973, 0.041630061459727585, 0.11921406083274633, 0.116785731370328, 10.660240575671196, 40.705919936299324, 43.02693799138069, 26.492892801761627, 23.63981019705534, 37.038634121418, 51.04745261371136, 51.23247608542442, 45.428473725914955, 5.238736616447568, 0.10130745489732362, 0.48767788452096283, 2.1284033032134175, 8.192366100847721, 3.5113837430253625, 0.5020622501615435, 28.733605965971947, 49.502622708678246, 52.32461728155613, 49.820882230997086, 49.950341284275055, 50.86332589387894, 52.18062020838261, 48.146327286958694, 49.43111054599285, 49.71683621406555, 52.435043156147, 51.195450872182846, 51.32222346961498, 50.11274456977844, 47.41384819149971, 47.80519299209118, 45.579166039824486, 48.341044038534164, 49.32693533599377, 45.473888888955116, 46.18153251707554, 44.78573061525822, 46.49111710488796, 47.35394060611725, 50.11224679648876, 46.97356961667538, 48.6735337972641, 46.144526302814484, 43.7678412348032, 37.801864966750145, 37.506449818611145, 36.94286786019802, 36.816524639725685, 37.47457332909107, 37.96062044799328, 36.079170405864716, 35.55792577564716, 37.90521942079067, 37.652776166796684, 37.90407948195934, 37.24251218140125, 37.48438060283661, 36.45854964852333, 37.943407371640205, 44.69090290367603, 47.13594250380993, 48.09460446238518, 48.45147751271725, 50.81307739019394, 48.270797207951546, 48.415691033005714, 45.00704973936081, 44.548942521214485, 41.632933393120766, 43.92348848283291, 50.292782709002495, 55.42510271072388, 46.30852170288563, 45.63287615776062, 46.00366786122322, 49.80410613119602, 51.787162721157074, 50.38204751908779, 49.30485472083092, 45.893215388059616, 39.07356932759285, 35.354009717702866, 36.715586856007576, 36.46772235631943, 38.149519711732864, 38.20101834833622, 38.12454745173454, 37.90097884833813, 36.89017228782177, 38.64912450313568, 39.61948983371258, 37.01392404735088, 37.44628004729748, 36.7879843711853, 37.71038107573986, 36.76104001700878, 35.59923715889454, 38.72714191675186, 36.75583429634571, 37.072691693902016, 38.16780433058739, 39.22692149877548, 39.2273660749197, 39.27522070705891, 40.01785285770893, 37.21508905291557, 36.19271211326122, 36.71311318874359, 38.419312834739685, 35.20553648471832, 36.56771779060364, 36.2136147916317, 37.01443701982498, 44.48246508836746, 50.009561106562614, 51.038222908973694, 47.52908080816269, 46.60053603351116, 48.25473167002201, 50.49281917512417, 49.824226051568985, 49.93276722729206, 49.76569779217243, 50.33936060965061, 53.221604749560356, 53.853313252329826, 52.98845686018467, 51.35595425963402, 54.29887734353542, 54.41591486334801, 50.03663845360279, 27.810715287923813, 3.3761722734197974, 0.6639742339029908, 1.5550221456214786, 2.8942248970270157, 0.4300433787284419, 0.06387988629285246, 9.823260437697172, 55.697776079177856, 43.81853811442852, 35.56608773767948, 24.308754801750183, 31.751324236392975, 45.918434634804726, 42.00893081724644, 2.9972155205905437, 0.04187445068964735, 0.020781385464943014, 0.024903394260036293, 0.03912615167791955, 0.039858662566985004, 0.02391513371549081, 0.017517674168630037, 0.03359318841830827, 0.08651630327221937, 0.014445141969190445, 0.010320197980036028, 0.06156075272883754, 0.0665693033079151, 0.0334210398432333, 0.04625875488272868, 0.03637525514932349, 0.013287592901178868, 0.04736853654321749, 0.05278732780425344, 0.09828349255258217, 0.027179412754776422, 0.06660672239377163, 0.015395460213767365, 0.013959037096356042, 0.013491561985574663, 0.08836923079797998, 0.07638295952347107, 0.07971118757268414, 16.338591277599335, 49.53510716557503, 49.59658406674862, 31.40776377171278, 29.044909961521626, 43.53720501065254, 54.2073592543602, 56.73922799527645, 49.81959030032158, 6.182722812518477, 0.11583279148908332, 0.8110790653154254, 5.710110347718, 6.019577141851187, 3.5892513021826744, 0.8751403028145432, 32.98000730574131, 54.68866802752018, 54.079560711979866, 53.12010459601879, 51.93049103021622, 54.648986756801605, 52.95725293457508, 50.49990579485893, 50.554052889347076, 50.500430166721344, 52.11563229560852, 51.73202767968178, 51.29927270114422, 51.81285314261913, 48.615347519516945, 51.22625581920147, 47.58201576769352, 49.10813547670841, 49.17615942656994, 47.21581421792507, 46.890209689736366, 47.147729471325874, 48.43090921640396, 49.494354352355, 51.870693638920784, 48.89681741595268, 47.99371227622032, 48.95078971982002, 46.12477496266365, 39.53986130654812, 38.70869770646095, 38.63181263208389, 38.52715104818344, 39.266747161746025, 38.20103734731674, 38.20146292448044, 37.31909327208996, 39.64839108288288, 38.952253237366676, 40.7029864937067, 38.53324592113495, 38.09876203536987, 36.96386553347111, 41.16829812526703, 47.4603158980608, 49.657396003603935, 50.82623988389969, 51.478816866874695, 52.44353570044041, 50.695078521966934, 50.13439200818539, 47.34100989997387, 45.59886798262596, 42.57446967065334, 45.51887847483158, 52.95831687748432, 54.41704340279102, 49.09954413771629, 45.03744050860405, 47.69102431833744, 50.92650890350342, 54.26707684993744, 53.293344900012016, 52.03966677188873, 47.60394059121609, 40.72153329849243, 37.883765771985054, 39.077346324920654, 38.8069224357605, 39.28290009498596, 41.83804638683796, 39.72716465592384, 39.55250322818756, 39.344730377197266, 40.222931653261185, 40.54444380104542, 39.20521326363087, 39.568971544504166, 37.7507159113884, 39.80100229382515, 38.41144725680351, 38.2100048661232, 39.67500485479832, 38.97095203399658, 38.66321414709091, 39.75502856075764, 39.91232872009277, 40.06656624376774, 39.841850101947784, 41.3587287068367, 39.27677482366562, 38.877545446157455, 37.718942016363144, 38.636839762330055, 37.58829362690449, 38.773503229022026, 37.653737515211105, 39.74163427948952, 46.9876516610384, 51.73820994794369, 51.32830314338207, 50.979774445295334, 49.910861402750015, 50.7655343413353, 50.16437999904156, 50.75875170528889, 50.41993908584118, 51.578409522771835, 51.66596442461014, 53.75039577484131, 54.5329599827528, 56.4272191375494, 55.02066381275654, 56.70045867562294, 56.942893266677856, 52.143720388412476, 30.715209133923054, 4.19833866879344, 1.0886528645642102, 4.143672427162528, 4.0589820966124535, 1.581843481399119, 0.049862880041473545, 10.070369727909565, 60.40669620037079, 49.85042564570904, 43.014052882790565, 25.44432196766138, 35.29020734131336, 50.46673737466335, 52.20080852508545, 5.682308189570904, 0.19616943143773824, 0.04753406887175515, 0.04223663730954286, 0.01871017004305031, 0.033149068694910966, 0.047893090231809765, 0.03471755328064319, 0.018299547155038454, 0.08593057806137949, 0.012750187070196262, 0.0444012408843264, 0.05127080839884002, 0.1194852712797001, 0.11452583232312463, 0.162541443714872, 0.11306390530080535, 0.09634552232455462, 0.11131317151011899, 0.1218518392124679, 0.11061237630201504, 0.22860803845105693, 0.1480972906574607, 0.11141566952574067, 0.10635211467160843, 0.13136625406332314, 0.10292834253050387, 0.21531773207243532, 0.20827200467465445, 22.144037559628487, 59.96447592973709, 56.78357921540737, 39.90324720740318, 32.67351575195789, 49.581958651542664, 60.45374147593975, 61.645593121647835, 53.10273952782154, 7.397468229755759, 0.5167152138892561, 2.7934417175129056, 9.02522535994649, 16.146456487476826, 8.029198106378317, 1.1469625169411302, 36.66751183569431, 55.8873251080513, 56.50581032037735, 55.05182974040508, 53.54201875627041, 56.32432445883751, 55.72887361049652, 50.17831765115261, 51.74235552549362, 51.18840605020523, 55.985489040613174, 52.404770180583, 53.11201862990856, 52.9367758333683, 50.21804451942444, 50.94177648425102, 49.815136939287186, 50.855828896164894, 51.562674567103386, 47.80184917151928, 47.64652110636234, 48.793523758649826, 49.339007288217545, 51.80907614529133, 54.790958538651466, 50.25021739304066, 50.733144879341125, 50.66592648625374, 48.075453490018845, 41.736702024936676, 41.54674641788006, 41.37050427496433, 38.969755098223686, 40.80582417547703, 40.443555414676666, 39.25768844783306, 38.17491754889488, 40.992682948708534, 41.29042737185955, 43.70650492608547, 42.068637013435364, 40.60717463493347, 39.78734202682972, 41.90973334014416, 48.11909794807434, 51.74686588346958, 51.59062586724758, 52.922895178198814, 54.20293249189854, 52.15258911252022, 52.70213462412357, 49.75161574780941, 49.02654245495796, 45.008923038840294, 47.76452757418156, 54.713146314024925, 57.41358540952206, 51.38892509043217, 44.58231993019581, 48.73800873756409, 53.76852460205555, 56.51915520429611, 55.11936351656914, 53.9009664952755, 49.85934376716614, 43.221529349684715, 39.55647401511669, 42.181889936327934, 40.260097458958626, 39.93243724107742, 42.525756284594536, 41.76915228366852, 41.76855571568012, 41.36605851352215, 41.254724487662315, 43.08702036738396, 39.07228119671345, 41.07212148606777, 40.33007450401783, 41.30423963069916, 39.93540868163109, 39.64747913181782, 42.945736348629, 40.97030594944954, 40.895628556609154, 41.812960132956505, 42.797023728489876, 42.80166707932949, 40.97089111804962, 43.19276489317417, 41.23005621135235, 40.35019442439079, 40.5233359336853, 41.70846574008465, 39.64807949960232, 40.668533742427826, 40.06487153470516, 41.88017092645168, 49.68743339180946, 54.39924515783787, 55.335499718785286, 53.070654049515724, 50.09137071669102, 52.4334966391325, 52.54457987844944, 53.26504021883011, 51.09781131148338, 51.70981787145138, 53.70901599526405, 56.84549309313297, 57.19846375286579, 58.80493015050888, 55.80190949141979, 60.50702981650829, 57.05391190946102, 54.736119881272316, 32.75288209319115, 5.052823992446065, 2.169151366688311, 6.316784843802452, 7.411998175084591, 2.4711534613743424, 0.16170424176380038, 11.737822853028774, 68.00889506936073, 54.85410735011101, 51.26157492399216, 34.55128379166126, 44.898903742432594, 60.40565125644207, 59.999285861849785, 8.322169985622168, 0.24791328847641125, 0.11368460793164559, 0.14608466037316248, 0.1156081582303159, 0.1595579061540775, 0.1942915009567514, 0.17832273908425122, 0.0813734128314536, 0.2780468441778794, 0.08096756195300259, 0.1217907085083425, 0.13637606258271262], [0.010428633177070878, 0.0464903383544879, 0.06078426958993077, 0.06608565308852121, 0.008028944121178938, 0.13969059800729156, 0.06368217073031701, 0.011524565434228862, 0.0456463160662679, 0.05691343882062938, 0.01314468679993297, 0.04377464560093358, 0.03890951877110638, 0.031054592509462964, 0.03387126744200941, 0.08631698467070237, 8.529986534267664, 44.302818328142166, 50.849407240748405, 29.72043391317129, 22.110130079090595, 40.31114771962166, 47.465422824025154, 49.710604548454285, 49.274684339761734, 12.197761572897434, 0.0231042223458644, 0.07475297315977514, 4.18917641043663, 7.703138552606106, 1.682543777860701, 0.22302753321127966, 22.822836935520172, 57.77269273996353, 53.969051241874695, 48.59921358525753, 49.47697788476944, 50.726962611079216, 51.31315715610981, 51.93714067339897, 51.600079759955406, 51.9397359341383, 50.31956747174263, 49.39172185957432, 48.09365451335907, 49.928705245256424, 47.9695113748312, 50.0515678524971, 46.31577551364899, 48.07599686086178, 45.463143065571785, 45.223980098962784, 45.150336250662804, 46.92916139960289, 47.09868170320988, 46.08785234391689, 47.62912943959236, 47.73557312786579, 47.80947536230087, 45.031828209757805, 46.364222913980484, 40.89934475719929, 35.37949874997139, 35.8874136954546, 34.61638189852238, 36.550025939941406, 37.24017910659313, 37.898653373122215, 35.88619016110897, 37.53327637910843, 38.39510813355446, 38.48077453672886, 35.86209945380688, 36.33233942091465, 36.938927471637726, 37.42654010653496, 43.4862345457077, 46.30738936364651, 47.23679669201374, 49.468785524368286, 51.17844678461552, 50.251828506588936, 47.12711177766323, 47.37395793199539, 47.42492839694023, 43.75674583017826, 43.817204385995865, 50.27110107243061, 55.67814253270626, 48.04296523332596, 46.97448916733265, 45.01417435705662, 50.52156463265419, 50.61490662395954, 50.571759939193726, 48.54399114847183, 44.13364380598068, 36.99737973511219, 35.983616933226585, 37.423226684331894, 37.71960698068142, 38.917986676096916, 39.913092479109764, 39.39631260931492, 38.12919460237026, 37.12358616292477, 38.20533111691475, 38.15678492188454, 38.37972275912762, 38.02455201745033, 38.07611905038357, 37.89144515991211, 36.81851953268051, 37.10833378136158, 35.81774443387985, 36.55121527612209, 37.15694077312946, 39.10601958632469, 36.99109487235546, 39.11588005721569, 39.98012848198414, 42.688691541552544, 42.14175269007683, 38.53892661631107, 36.637364253401756, 36.08004055917263, 36.95655092597008, 37.291426956653595, 35.613657385110855, 38.14029760658741, 41.52331307530403, 45.72751767933369, 49.60259534418583, 50.36720171570778, 47.950763180851936, 49.224641025066376, 50.053380355238914, 53.114629089832306, 50.81602223217487, 50.388096794486046, 52.09327049553394, 56.44857779145241, 54.26521874964237, 53.938352689146996, 51.69882886111736, 52.305112928152084, 49.82229195535183, 47.10695005953312, 16.24594084918499, 1.7773249419406056, 0.40647829009685665, 3.0137249222025275, 3.011379260569811, 0.5919910152442753, 0.07187414521467872, 12.450269423425198, 57.82098054885864, 47.22712241113186, 36.2541738152504, 19.969932921230793, 28.562926724553108, 47.38555110991001, 30.74433647096157, 2.1986012114211917, 0.0331645313417539, 0.14733887510374188, 0.04680124628066551, 0.055570793483639136, 0.08115120639558882, 0.05848155233252328, 0.05643037489790004, 0.017776392414816655, 0.03454823228821624, 0.05804193002404645, 0.03416642328375019, 0.04274720522516873, 0.06650659182923846, 0.05974056133709382, 0.06254522275412455, 0.06618081126362085, 0.0155457061555353, 0.024403893621638417, 0.10010927231633104, 0.02450499825499719, 0.043117959939991124, 0.04289242497179657, 0.03462087370280642, 0.02838033757143421, 0.04146691884670872, 0.035773332565440796, 0.029350252225412987, 0.1091819534485694, 11.646378859877586, 51.02988235652447, 56.35208576917648, 33.094533160328865, 24.52819112688303, 43.01309913396835, 56.88697546720505, 54.320976957678795, 55.1519163697958, 12.241664417088032, 0.10124208652996458, 0.5389147507958114, 4.835565900430083, 5.706026991829276, 3.3977484656497836, 0.4931113851489499, 27.135558016598225, 62.054371386766434, 54.94192063808441, 51.03191524744034, 50.456276535987854, 52.657726407051086, 53.79644550383091, 53.676140159368515, 52.2771692276001, 54.72631260752678, 52.58379377424717, 50.218367502093315, 49.397626742720604, 53.50880093872547, 49.32970918715, 51.622829139232635, 49.66827481985092, 48.70300881564617, 47.15468689799309, 46.120063215494156, 46.6286089271307, 47.5431514531374, 48.424335569143295, 47.468595653772354, 49.586161226034164, 49.10165302455425, 49.01440970599651, 46.90840311348438, 48.58027160167694, 42.53563575446606, 36.51164039969444, 39.228114634752274, 37.61865019798279, 37.993450686335564, 38.50199639797211, 39.03504699468613, 37.993203699588776, 38.9071686565876, 40.75414314866066, 38.51738937199116, 38.51882569491863, 38.476921543478966, 37.76090316474438, 39.55796353518963, 46.48931600153446, 47.31414154171944, 48.96288067102432, 52.13780790567398, 52.29499027132988, 52.0119434595108, 50.24388313293457, 49.8214104026556, 47.943817153573036, 46.32953837513924, 44.817303121089935, 53.07403966784477, 54.82167609035969, 50.487636253237724, 48.07968646287918, 47.60997086763382, 52.70331636071205, 52.62247569859028, 52.59228251874447, 50.390015691518784, 47.238274812698364, 40.30216880142689, 37.47810713946819, 38.925016298890114, 39.33322459459305, 41.54294662177563, 41.07232287526131, 39.58402633666992, 37.70204432308674, 38.58736261725426, 41.05011686682701, 39.395735040307045, 40.183056592941284, 39.552480429410934, 38.994476571679115, 39.45657357573509, 39.2897093296051, 39.191936776041985, 38.21938656270504, 37.69490070641041, 39.438490346074104, 39.9512842297554, 39.15575131773949, 41.129783391952515, 41.70506872236729, 43.39169181883335, 44.56099547445774, 40.99632315337658, 38.614071384072304, 38.96696984767914, 37.566459998488426, 38.427672386169434, 37.09161847829819, 39.53087858855724, 43.66077437996864, 48.99174012243748, 50.88131792843342, 52.17715859413147, 50.250361785292625, 50.975488275289536, 51.953187212347984, 54.07552532851696, 53.212967813014984, 52.35598839819431, 53.81359778344631, 56.830609291791916, 56.1810265481472, 54.51386600732803, 52.37043522298336, 54.66529168188572, 52.34516277909279, 49.02359381318092, 18.645840771496296, 2.003162973560393, 1.2643378623761237, 4.181367829442024, 4.389998009428382, 1.33314409526065, 0.0727051353896968, 12.786881010979414, 63.73261593282223, 53.81566867232323, 42.23344177007675, 25.223462618887424, 35.864284336566925, 54.30054545402527, 39.099411740899086, 3.2417855970561504, 0.04404764091304969, 0.02621791591082001, 0.058073192994925193, 0.09767479044967331, 0.029017339620622806, 0.04206816236546729, 0.06072295334888622, 0.026223281638522167, 0.03458480161498301, 0.04527707162196748, 0.04858001469983719, 0.026800568630278576, 0.22979249130003154, 0.14166824345011264, 0.102774495317135, 0.14541469397954643, 0.09270879090763628, 0.23086112458258867, 0.13907341315643862, 0.16082510846899822, 0.13877741497708485, 0.12629127013497055, 0.19499884190736338, 0.22148045216454193, 0.15409204788738862, 0.1369717251509428, 0.12070038967067376, 0.17552706878632307, 15.901072304695845, 60.63831277191639, 63.19225452840328, 40.452978909015656, 31.439712457358837, 50.018676817417145, 59.924141094088554, 58.48477452993393, 59.929810389876366, 15.609869230538607, 0.2578321663895622, 2.178553487174213, 11.60785747691989, 14.80453759431839, 6.596753820776939, 0.9918623801786453, 29.010255821049213, 64.46631476283073, 56.90922327339649, 53.431197702884674, 53.25923033058643, 55.5898542702198, 54.63167868554592, 55.376985892653465, 57.232878506183624, 57.6900889724493, 54.524235650897026, 53.8789276778698, 51.96801781654358, 54.816675558686256, 51.103678196668625, 55.31400807201862, 50.728600323200226, 51.520500630140305, 48.42283084988594, 46.32593236863613, 49.784951359033585, 48.87469880282879, 50.84362395107746, 48.851174265146255, 51.51515431702137, 50.22516913712025, 50.15055254101753, 49.138039872050285, 50.96924141049385, 43.61645355820656, 37.6933503895998, 40.16208551824093, 36.98624633252621, 38.691876009106636, 41.66024632751942, 42.04030953347683, 40.64490281045437, 40.86365707218647, 41.94610118865967, 40.7442294806242, 39.95012529194355, 41.987895146012306, 40.97969524562359, 41.83922812342644, 47.70366244018078, 49.43193510174751, 51.86500534415245, 54.36358027160168, 54.057651087641716, 53.27272340655327, 51.88840068876743, 52.40847498178482, 50.84590382874012, 48.425707295536995, 46.51522681117058, 55.13068310916424, 59.17253002524376, 51.74226813018322, 47.405895218253136, 48.13618943095207, 54.519869685173035, 55.214134231209755, 54.98556509613991, 52.28302851319313, 48.66836987435818, 42.053194642066956, 39.95920680463314, 41.36586852371693, 41.284720078110695, 41.440333127975464, 42.729862332344055, 42.20221124589443, 40.04963055253029, 40.79751022160053, 42.97419302165508, 41.19996942579746, 41.60513788461685, 41.65072403848171, 42.222680747509, 40.87469927966595, 41.545724272727966, 40.775121822953224, 40.3631479293108, 39.642322808504105, 41.314407885074615, 42.825620993971825, 41.7963208258152, 43.85557472705841, 44.54266905784607, 46.214689537882805, 46.43092453479767, 43.76567915081978, 41.72080747783184, 40.26318669319153, 40.89782103896141, 40.86372546851635, 38.91689233481884, 42.63332851231098, 46.28269448876381, 51.33485399186611, 53.10418725013733, 55.53725749254227, 51.454095393419266, 52.613606974482536, 55.11662386357784, 57.44396857917309, 56.072063595056534, 54.26647648215294, 55.7130778580904, 60.470741763710976, 57.97887347638607, 55.788526609539986, 53.62087972462177, 56.28959812223911, 52.65888534486294, 51.614811569452286, 20.01765266060829, 2.536744591780007, 1.8165821791626513, 7.714331327006221, 9.466672372072935, 2.9419218376278877, 0.1911396294599399, 15.302485674619675, 69.43163752555847, 58.4778057038784, 50.02861328423023, 33.95423702895641, 42.53536976873875, 59.35285694897175, 47.896027117967606, 4.849009579047561, 0.1064127184508834, 0.24385526950936764, 0.18821037258021533, 0.11875333555508405, 0.21662045357516035, 0.17621380771743134, 0.11753239872632548, 0.09009208210045472, 0.12378018378512934, 0.16562569071538746, 0.1249974692473188, 0.19782421295531094], [0.04804943848284893, 0.020890668565698434, 0.04267243384674657, 0.029958857849123888, 0.04132788490096573, 0.0855148491973523, 0.034149903076468036, 0.031442025137948804, 0.03820542471657973, 0.00843654275740846, 0.024131269383360632, 0.03658316782093607, 0.06898924650158733, 0.02487410540197743, 0.11576219840208068, 0.060713936254614964, 4.245154531672597, 35.278230383992195, 50.861935168504715, 34.33392785489559, 30.54935183376074, 43.74053969979286, 43.34546349942684, 49.76831965148449, 51.11873298883438, 21.266487948596478, 0.2323116670595482, 0.4266847745748237, 4.594892514869571, 3.1283631082624197, 1.917436842340976, 0.130017742048949, 23.19689266383648, 62.03978396952152, 51.042699068784714, 51.711546778678894, 46.93392634391785, 50.99023528397083, 47.047555446624756, 50.64469322562218, 50.80349050462246, 50.455744564533234, 48.75536620616913, 48.781208619475365, 47.19917491078377, 48.0640085041523, 48.20491634309292, 48.334390595555305, 49.94816020131111, 47.08198539912701, 46.58113807439804, 47.22485773265362, 46.57708369195461, 51.406905725598335, 50.421660393476486, 51.152307987213135, 48.95372316241264, 50.67949555814266, 45.387363731861115, 45.94794765114784, 47.51827418804169, 44.32688243687153, 36.07184819877148, 36.71328417956829, 35.17980806529522, 38.58768180012703, 36.26562640070915, 37.375968620181084, 37.531007900834084, 38.795625641942024, 37.39902198314667, 37.812629789114, 37.22244545817375, 37.134689167141914, 36.576985493302345, 38.1661020219326, 40.44551610946655, 40.856270268559456, 43.221924528479576, 47.68232278525829, 50.34597985446453, 48.95192965865135, 49.195295199751854, 48.44661757349968, 47.79271446168423, 45.60449168086052, 44.8261034488678, 48.38894806802273, 52.62648068368435, 49.72010783851147, 48.36179092526436, 44.18178342282772, 51.00172966718674, 49.78622429072857, 49.053103029727936, 47.473227605223656, 41.65115721523762, 36.99586361646652, 36.76352508366108, 36.690751388669014, 35.96428357064724, 37.42504298686981, 38.55048939585686, 38.039207831025124, 37.395229786634445, 39.004629626870155, 38.16407673060894, 38.14262308180332, 38.539979159832, 37.54357382655144, 34.69875007867813, 36.63789622485638, 36.41756884753704, 37.97479368746281, 36.694421991705894, 38.26630264520645, 35.8394830673933, 36.30206264555454, 38.74566212296486, 45.012483447790146, 49.302939623594284, 52.294530496001244, 49.516746550798416, 47.55898900330067, 42.727495059370995, 39.478433802723885, 36.172166615724564, 36.2564080953598, 35.0273222476244, 37.08469904959202, 36.5078292042017, 42.20667600631714, 45.36315143108368, 48.05983632802963, 47.0939015597105, 48.96939352154732, 48.39987628161907, 47.83279851078987, 47.19905711710453, 50.69866552948952, 46.83205381035805, 51.691594049334526, 51.581589952111244, 51.42075218260288, 52.89769113063812, 53.74857947230339, 50.221137553453445, 37.402605190873146, 5.778861008584499, 0.47076763410586864, 1.4464569836854935, 2.597888298332691, 2.9678677953779697, 0.8784134709276259, 0.09674338027252816, 17.19095204025507, 55.410283505916595, 41.82857349514961, 33.02101090550423, 24.203232564032078, 36.42076447606087, 44.587917029857635, 26.186488643288612, 1.136188313830644, 0.05613993540464435, 0.06238438450964168, 0.04886849863396492, 0.04637158730474766, 0.08736527568544261, 0.05000674536859151, 0.03465473790129181, 0.043677105131791905, 0.020564060505421367, 0.0895511158159934, 0.02863054338376969, 0.022243754065129906, 0.01420983198840986, 0.042566113770590164, 0.0456895832758164, 0.01924304506246699, 0.03550842666300014, 0.04881895656581037, 0.018325806195207406, 0.03876413946272805, 0.05398436747782398, 0.007861059184506303, 0.019795974767475855, 0.07194648234872147, 0.056711415090831, 0.09967999925720505, 0.02887132763135014, 0.047633268040954135, 6.466123480349779, 43.617171719670296, 56.6915937513113, 41.19091831147671, 28.25869034975767, 45.391737297177315, 50.61522960662842, 55.56056544184685, 55.980199724435806, 22.373968921601772, 0.16864351549884304, 0.30882231309078634, 4.277973370626569, 6.379551775753498, 2.967648357152939, 0.1814292059862055, 26.716277115046978, 63.179411217570305, 53.72705362737179, 54.1018883138895, 49.65711861848831, 52.16755650937557, 49.35743249952793, 53.62091772258282, 53.0699472874403, 52.21394442021847, 50.793831422924995, 50.37171207368374, 48.69498364627361, 50.121845081448555, 49.37077738344669, 50.04618354141712, 50.582520961761475, 47.986967638134956, 46.46869070827961, 47.99905098974705, 49.59445238113403, 53.843631371855736, 50.41469916701317, 51.95706680417061, 49.74582485854626, 51.16124890744686, 47.66044735908508, 46.84895530343056, 49.67471547424793, 45.72334550321102, 38.28009970486164, 38.350471928715706, 37.71858103573322, 39.48002211749554, 37.91108250617981, 39.439459294080734, 40.25361880660057, 39.60889220237732, 37.559814155101776, 39.147722348570824, 37.389913871884346, 37.57591389119625, 39.156256690621376, 39.13444586098194, 42.35392190515995, 43.885498121380806, 45.00495605170727, 50.4142089933157, 51.91693335771561, 50.33496804535389, 51.905457973480225, 49.71519470214844, 47.96369768679142, 48.03667277097702, 45.75176037847996, 50.05393512547016, 54.30428445339203, 51.19219824671745, 48.25565882027149, 48.15174199640751, 53.30285578966141, 52.34187215566635, 52.04216703772545, 48.82203742861748, 44.57918509840965, 38.96509274840355, 39.88686628639698, 38.20824936032295, 37.83661790192127, 39.911925941705704, 39.32423047721386, 39.520520344376564, 38.58819097280502, 39.9964752048254, 39.84989047050476, 39.185712710022926, 40.13776682317257, 39.234399497509, 38.26228626072407, 38.47584240138531, 39.05942268669605, 39.90074314177036, 39.171896651387215, 40.537307783961296, 37.66967386007309, 39.085021913051605, 38.190964087843895, 47.42537297308445, 51.05746127665043, 53.661742731928825, 50.53921088576317, 48.59955556690693, 44.140437841415405, 41.04209929704666, 36.97211869060993, 37.54286706447601, 38.34201358258724, 40.02870887517929, 39.24570769071579, 44.78143684566021, 47.53547586500645, 50.41554652154446, 48.504993841052055, 50.557609498500824, 51.201298758387566, 49.48414050042629, 50.6391417235136, 52.317325472831726, 49.08925049006939, 54.769132509827614, 54.22516129910946, 55.934613570570946, 53.9366389811039, 55.10235942900181, 50.8070433139801, 39.61428791284561, 7.620863942429423, 0.8193502714857459, 2.1082973945885897, 4.4987391494214535, 4.876361936330795, 1.8399497377686203, 0.06621305015869439, 18.249795623123646, 60.913657397031784, 49.164820834994316, 38.14291566610336, 26.327481977641582, 41.36308327317238, 49.75002743303776, 32.58818753063679, 1.4346462674438953, 0.06168511070427485, 0.03479725251963828, 0.06575351231731474, 0.02568358257121872, 0.022268107641139068, 0.06907696835696697, 0.03393120699911378, 0.056501899380236864, 0.06502436706796288, 0.09530525392619893, 0.044179513133713044, 0.06105222571932245, 0.07570986126665957, 0.11548542926902883, 0.10279400637955405, 0.12482392543461174, 0.09098231050302275, 0.17396737122908235, 0.16787929635029286, 0.10718904944951646, 0.12746643129503354, 0.06007719952322077, 0.1377624983433634, 0.1610847859410569, 0.21721044613514096, 0.12111608142731711, 0.1802474248688668, 0.1861531985923648, 7.2675299271941185, 49.633050709962845, 64.79156211018562, 46.82503178715706, 40.67776344716549, 55.981449857354164, 56.02849893271923, 59.64950703084469, 60.8418944478035, 26.07348270714283, 0.44564035430084914, 1.9883593241684139, 11.828199103474617, 11.49799682199955, 5.354160647839308, 0.7100242597516626, 28.1506260484457, 66.27311781048775, 54.490953236818314, 55.464495196938515, 52.47382007539272, 55.89762255549431, 49.61633160710335, 55.57297557592392, 55.43669208884239, 53.95706668496132, 53.71540725231171, 53.7188308686018, 49.97943252325058, 51.62388168275356, 50.304934456944466, 52.197992876172066, 54.35753859579563, 49.13138262927532, 47.00762718915939, 50.436924174427986, 51.05399966239929, 55.148800536990166, 54.035407081246376, 55.017145201563835, 52.286934703588486, 52.211865931749344, 47.66395077109337, 48.88571821153164, 52.369838654994965, 47.58140780031681, 39.076780155301094, 39.47524577379227, 39.38182018697262, 41.23603329062462, 40.60834117233753, 41.53820067644119, 40.69102853536606, 40.969960168004036, 39.80132907629013, 40.184625908732414, 41.1224839836359, 41.17545694112778, 41.0768636316061, 41.19752615690231, 45.34004487097263, 44.5679946988821, 46.18093594908714, 52.60584779083729, 56.14263340830803, 49.87454295158386, 53.97060915827751, 50.56096851825714, 50.639004930853844, 50.09704761207104, 48.40306431055069, 51.70952908694744, 56.725579127669334, 51.16225965321064, 48.76478210091591, 48.78366708755493, 55.311454609036446, 54.6845718473196, 51.60360977053642, 52.11136132478714, 44.61674228310585, 41.9721981883049, 41.37868523597717, 40.74081726372242, 39.61948983371258, 41.564613059163094, 41.23616248369217, 42.629771903157234, 40.1448230445385, 43.693661615252495, 42.753383070230484, 40.99691592156887, 41.34836666285992, 40.77689252793789, 39.23563443124294, 40.003493428230286, 40.694121569395065, 42.03647933900356, 41.3146510720253, 41.500419303774834, 39.27878111600876, 39.872514456510544, 42.257308289408684, 50.88927090167999, 54.89867515861988, 55.96265226602554, 54.195864871144295, 51.48406818509102, 46.7263662815094, 43.965563625097275, 41.09029971063137, 38.998815938830376, 38.808077573776245, 41.73597626388073, 41.18343651294708, 47.28771395981312, 48.27004864811897, 52.81764082610607, 49.987043514847755, 51.418438106775284, 53.11749033629894, 51.73871912062168, 52.228357046842575, 54.97223541140556, 51.95707060396671, 57.516324296593666, 57.19364941120148, 57.17450983822346, 57.42366246879101, 58.1083819270134, 52.03212037682533, 42.89607681334019, 8.834385350346565, 0.9308122436050326, 2.579258135519922, 10.115374512970448, 9.760802239179611, 3.597155590541661, 0.14834570232778788, 20.763516537845135, 66.68030396103859, 54.54463675618172, 45.62691807746887, 35.08610889315605, 48.7932425737381, 57.47256204485893, 39.10467825829983, 2.144077462144196, 0.1869426210760139, 0.15776199783431366, 0.18668171163881198, 0.11416676643420942, 0.19336000172188506, 0.10346607305109501, 0.10178388401982374, 0.13510789547581226, 0.14545779791660607, 0.21070262737339363, 0.21332525851903483, 0.1070932752918452], [0.06420253499527462, 0.05588851803622674, 0.04552475227683317, 0.08967968547949567, 0.04714422240795102, 0.021895840800425503, 0.016659580760460813, 0.03291608998551965, 0.014598980833397945, 0.016895630105864257, 0.0180910982817295, 0.024207137284975033, 0.05684887197276112, 0.03120881265203934, 0.10346040304284543, 0.062323238962562755, 1.4212842844426632, 27.70058199763298, 54.41135510802269, 38.940736055374146, 35.43598271906376, 39.58382114768028, 39.81934390962124, 46.23302735388279, 49.42365154623985, 28.882761262357235, 0.7595455774571747, 0.11170759331434965, 1.8796323146671057, 4.029461955651641, 1.6638890351168811, 0.33232871268410236, 17.263294458389282, 58.62113021314144, 51.86905212700367, 48.3838677406311, 46.534510776400566, 47.97580383718014, 47.317131981253624, 48.72971758246422, 47.36253194510937, 46.63023144006729, 45.51840730011463, 47.074112221598625, 48.2498337328434, 49.91335406899452, 48.56571078300476, 49.17419113218784, 50.33382050693035, 51.12168923020363, 51.03263720870018, 50.04193536937237, 47.74051286280155, 45.69194778800011, 47.25994125008583, 49.10313494503498, 49.48473706841469, 51.09141245484352, 48.83844114840031, 46.99169464409351, 49.52251464128494, 45.03845885396004, 35.90993128716946, 34.367742240428925, 37.1541441231966, 36.468174532055855, 36.49484530091286, 37.3635508865118, 36.90301939845085, 39.45459008216858, 37.01108939945698, 37.66026936471462, 36.63173295557499, 36.673215329647064, 36.52271680533886, 37.22795516252518, 37.709191739559174, 37.81945802271366, 39.719534665346146, 45.59705927968025, 49.91141997277737, 49.91138957440853, 50.90347073972225, 50.16851417720318, 47.163285836577415, 48.35909307003021, 46.069263741374016, 48.737450167536736, 53.23951318860054, 51.80325485765934, 48.647349402308464, 43.688277304172516, 51.29864573478699, 49.55628342926502, 48.646673038601875, 47.77004487812519, 41.14298768341541, 37.18246780335903, 37.10511535406113, 37.5841898471117, 38.412906378507614, 37.87089966237545, 36.837963089346886, 36.838236674666405, 37.08197079598904, 38.24985332787037, 36.85582593083382, 38.01400378346443, 38.18004347383976, 37.46160462498665, 36.99264898896217, 36.522747203707695, 35.13035371899605, 35.95006473362446, 35.696622133255005, 36.881618946790695, 35.784055441617966, 36.02550968527794, 46.480082497000694, 50.88535711169243, 50.57639569044113, 46.26807667315006, 49.106243178248405, 50.335359424352646, 48.406738713383675, 45.8770814538002, 40.51407963037491, 36.550272926688194, 35.3126185387373, 34.86222870647907, 36.68958865106106, 37.78894945979118, 40.049163177609444, 45.49676366150379, 43.89924958348274, 43.963557332754135, 44.860951378941536, 45.708283111453056, 44.90134701132774, 46.086704805493355, 46.9955438375473, 48.34650434553623, 46.63714326918125, 49.986135363578796, 50.3450071066618, 52.543075159192085, 52.83897288143635, 31.847041100263596, 2.5828057201579213, 0.31430215341970325, 1.184630251955241, 1.6161917382851243, 2.2794392611831427, 1.0782188619486988, 0.10284816831699573, 20.724789015948772, 56.03249251842499, 43.353028893470764, 31.4964472129941, 28.153082616627216, 37.73550532758236, 46.01500265300274, 15.646689254790545, 0.1391632278682664, 0.001953986470653035, 0.02963733350043185, 0.07585083221783862, 0.08207272374420427, 0.005181940859984024, 0.030518644998664968, 0.013143208998371847, 0.06571438629180193, 0.026848984489333816, 0.04040562911541201, 0.0583548862778116, 0.008624516704003327, 0.041292799869552255, 0.031251898035407066, 0.04565392307995353, 0.020923204319842625, 0.03192261399817653, 0.04186724443570711, 0.04107373642909806, 0.03928697136871051, 0.013929620217822958, 0.01421695196768269, 0.03232292474422138, 0.061054355683154427, 0.041541077953297645, 0.020757597776537295, 0.04683027167629916, 0.03716923441970721, 2.3380515910685062, 34.839361533522606, 59.59508255124092, 42.331852689385414, 38.347975462675095, 51.369397938251495, 48.499917313456535, 51.877673864364624, 55.0491014868021, 31.976652145385742, 0.7955760159529746, 0.18811622372595593, 2.639113236218691, 6.207203948870301, 3.5293057188391685, 0.4754465486621484, 22.118789814412594, 59.31061841547489, 55.05490757524967, 51.551784351468086, 47.89541155099869, 49.929666593670845, 49.5760727673769, 51.46264113485813, 49.52169008553028, 49.826490730047226, 47.88536489009857, 47.64604613184929, 49.49754238128662, 52.46897533535957, 49.248359352350235, 49.95099104940891, 49.587722942233086, 51.406202763319016, 52.166830748319626, 51.87758266925812, 50.27674376964569, 47.36321210861206, 49.622270688414574, 51.23619608581066, 50.629573836922646, 51.999271139502525, 49.57565478980541, 49.016503393650055, 51.53942361474037, 46.50508135557175, 38.199350237846375, 37.04816401004791, 38.08167055249214, 38.76176945865154, 39.43288944661617, 38.13984163105488, 38.07230405509472, 40.62583543360233, 39.91819940507412, 40.46677976846695, 38.14165413379669, 38.674579337239265, 39.34648208320141, 39.83759433031082, 38.5961439460516, 40.76354384422302, 39.657852575182915, 48.222980573773384, 50.72710320353508, 52.50445783138275, 52.038827016949654, 52.31588535010815, 48.515644669532776, 50.06784237921238, 47.30829745531082, 49.97906394302845, 54.75950002670288, 54.06598784029484, 49.803258776664734, 47.41583168506622, 52.96510711312294, 50.94668202102184, 52.18242131173611, 49.47149857878685, 42.97445520758629, 38.43436382710934, 39.90597166121006, 39.40098635852337, 38.893880769610405, 38.32984283566475, 38.890905529260635, 39.17504668235779, 39.24929849803448, 38.46542336046696, 38.65235812962055, 38.95655080676079, 39.131774604320526, 39.040929079055786, 38.22628319263458, 39.46380078792572, 37.45483718812466, 38.44624578952789, 37.99574576318264, 38.78920018672943, 37.97330416738987, 38.49253490567207, 47.40958482027054, 53.07610295712948, 52.72389605641365, 49.55584645271301, 51.75399050116539, 52.63281114399433, 50.89975453913212, 48.6183075606823, 41.78564339876175, 38.75084884464741, 37.55102902650833, 37.07594811916351, 37.398094832897186, 39.53243650496006, 42.548505663871765, 46.474698185920715, 46.44143097102642, 47.62002132833004, 47.49431647360325, 49.49324481189251, 47.157012373209, 48.34603697061539, 50.14650195837021, 49.71159629523754, 49.055014327168465, 52.53283090889454, 53.968606665730476, 54.17630732059479, 53.372346460819244, 33.72585788369179, 3.60839799977839, 0.8826264948584139, 4.809928201138973, 6.65554759092629, 4.273417890071869, 1.915033352561295, 0.16494076262461022, 22.705506831407547, 61.009305864572525, 48.08899216353893, 36.411793157458305, 31.605358868837357, 43.890840634703636, 54.59908023476601, 22.15117357671261, 0.08310303994221613, 0.06301174420514144, 0.03692804013553541, 0.03377397188160103, 0.04434574679180514, 0.028839673177571967, 0.019162477510690223, 0.026022686543001328, 0.11234040779527277, 0.014126080623100279, 0.03245894185965881, 0.012774560127581935, 0.054838687065057456, 0.25627813884057105, 0.13585433276602998, 0.17335723678115755, 0.30632474867161363, 0.11291537186480127, 0.10560539536527358, 0.06305214672465809, 0.09464545495575294, 0.11628800260950811, 0.1733167006750591, 0.17045857122866437, 0.17483509029261768, 0.1628187100868672, 0.15589298796840012, 0.27434732706751674, 0.1673982955981046, 2.629207642748952, 41.2325032800436, 65.18313109874725, 51.61529794335365, 43.45203638076782, 50.23890160024166, 52.590177431702614, 58.45372639596462, 59.63728308677673, 37.42921516299248, 1.0563893895596266, 0.8739253180101514, 8.096320554614067, 12.32509084045887, 6.09945978038013, 0.9382156119681895, 23.42965677380562, 62.7088862657547, 56.68367117643356, 53.54756645858288, 50.32432101666927, 52.76257798075676, 50.975264087319374, 54.46276634931564, 51.97796568274498, 51.63484789431095, 50.31939648091793, 50.356949865818024, 51.86422638595104, 53.329693749547005, 50.926961079239845, 52.241553738713264, 51.05099402368069, 52.67023913562298, 54.15871046483517, 53.75840574502945, 51.85275860130787, 49.001581594347954, 51.00241743028164, 54.32188130915165, 53.495110273361206, 52.60015569627285, 52.582581639289856, 51.9656353443861, 52.615286484360695, 48.55361223220825, 40.669837072491646, 37.438783049583435, 41.07268385589123, 39.766568541526794, 41.53318494558334, 40.969762578606606, 39.23436909914017, 42.998462319374084, 40.61130501329899, 42.36292742192745, 39.88045983016491, 40.34947246313095, 41.48005239665508, 41.29828155040741, 40.83858221769333, 42.36083373427391, 42.91213475167751, 49.61185164749622, 54.42720405757427, 53.16913716495037, 54.77749966084957, 54.43426787853241, 51.23599849641323, 52.26411312818527, 50.36317013204098, 51.25401332974434, 58.36574211716652, 54.112599939107895, 51.3626305013895, 47.80399605631828, 56.32288433611393, 52.80532568693161, 53.45636375248432, 50.6403424590826, 45.13173624873161, 41.24284252524376, 42.17710979282856, 42.271834909915924, 41.17544174194336, 41.35533168911934, 41.75436347723007, 40.866294130682945, 40.65092548727989, 40.60716703534126, 39.177334159612656, 41.546108052134514, 41.19276501238346, 41.17117457091808, 41.025801971554756, 40.051085874438286, 38.055166974663734, 38.81186977028847, 39.58879508078098, 40.25093995034695, 40.21315857768059, 38.27928654849529, 49.44019965827465, 55.71017101407051, 55.367672592401505, 51.24807044863701, 52.90092475712299, 54.705573320388794, 53.81923668086529, 51.402163580060005, 45.21560534834862, 42.08745360374451, 39.80040952563286, 38.74800659716129, 40.0338613986969, 41.31459787487984, 43.504158183932304, 50.12616544961929, 47.55398467183113, 49.28112119436264, 49.1290495544672, 50.470939949154854, 48.757722079753876, 50.392341166734695, 51.163661777973175, 52.92351074516773, 51.92049376666546, 55.09829744696617, 56.937185972929, 56.516138166189194, 55.61199568212032, 37.47474431991577, 4.347647856920958, 1.3452882436104119, 3.8990831142291427, 8.259758334606886, 9.54462043941021, 4.357593348249793, 0.33581639116164297, 26.049975268542767, 65.82203641533852, 55.35509146749973, 44.127917513251305, 39.75795440375805, 50.73645830154419, 62.095762565732, 26.73410575836897, 0.31681120628491044, 0.18221604579593986, 0.10539952359977178, 0.14495735289528966, 0.26241691724862903, 0.08452747366391122, 0.1394184524542652, 0.06267265693168156, 0.2943594875978306, 0.13730017002671957, 0.24287606502184644, 0.17446789046516642, 0.21197487629251555], [0.06448322266805917, 0.020264086269889958, 0.005230448095971951, 0.05518737030797638, 0.07805171568179503, 0.04557183783617802, 0.04211787512758747, 0.034708588136709295, 0.04521220791502856, 0.04633173026377335, 0.025907521921908483, 0.03128077500150539, 0.03712885045388248, 0.04006800758361351, 0.07245432658237405, 0.04258363587723579, 0.6259976467117667, 23.06148122996092, 52.10047870874405, 47.951644733548164, 25.286696925759315, 23.3511795848608, 32.04371474683285, 46.52088090777397, 50.58797746896744, 43.27209323644638, 3.698658593930304, 0.19350384478457272, 2.0833208598196507, 4.304819405078888, 2.6619559479877353, 0.40617979830130935, 16.589645706117153, 48.75610336661339, 57.11740270256996, 47.25212126970291, 47.986333072185516, 44.828903898596764, 46.63867838680744, 45.45587785542011, 46.55182644724846, 45.537121295928955, 48.10149349272251, 47.093012407422066, 50.46647518873215, 49.59578610956669, 50.46469308435917, 47.88390576839447, 39.043482542037964, 48.71447280049324, 50.237404480576515, 47.77601815760136, 47.128487303853035, 44.41651202738285, 45.425874665379524, 46.069366335868835, 46.472064927220345, 50.098795518279076, 48.69613878428936, 49.239646419882774, 50.55165521800518, 41.38232544064522, 35.931008756160736, 35.063275918364525, 37.20169097185135, 37.43920102715492, 37.93931879103184, 36.15686483681202, 37.834227830171585, 37.73021601140499, 36.73744708299637, 37.833464071154594, 35.950627103447914, 36.785191521048546, 35.98246559500694, 37.49677173793316, 36.640578880906105, 37.434272691607475, 37.280673533678055, 41.515675485134125, 45.792156010866165, 50.14070726931095, 51.5443329513073, 51.63584344089031, 48.7707743793726, 49.8944690823555, 46.71079471707344, 50.388377979397774, 51.39094278216362, 51.30624532699585, 43.79506677389145, 45.625899732112885, 51.41012795269489, 50.03118954598904, 49.99191105365753, 44.06161107122898, 40.597906932234764, 38.332901671528816, 39.17737975716591, 36.44216872751713, 38.80955569446087, 38.38627740740776, 37.86575473845005, 35.43672367930412, 38.588517755270004, 38.215343579649925, 38.560281470417976, 37.29080379009247, 37.617293670773506, 37.94055752456188, 37.91269361972809, 36.87646642327309, 35.948244631290436, 37.859937250614166, 36.14731974899769, 35.88178239762783, 36.68942525982857, 39.15293946862221, 49.85549837350845, 46.024543941020966, 47.82196909189224, 41.59110143780708, 47.363044917583466, 48.436126336455345, 49.27485913038254, 49.21485275030136, 46.07145622372627, 40.72023756802082, 37.935902774333954, 34.028576239943504, 36.21930308640003, 35.272048115730286, 36.80074408650398, 38.76622661948204, 39.08083453774452, 42.39858850836754, 41.24037645757198, 39.341599345207214, 40.69136671721935, 40.273157358169556, 41.40607036650181, 41.88737154006958, 44.36029024422169, 48.52702125906944, 50.23156799376011, 52.167028337717056, 52.525580897927284, 28.177821189165115, 1.752319314982742, 0.7769712642766535, 4.86599181778729, 4.437793744727969, 3.937321174889803, 1.0050301579758525, 0.2120687728165649, 26.28964550793171, 53.415386751294136, 39.00134660303593, 25.3290456533432, 23.268790505826473, 41.888507679104805, 37.86087580025196, 8.72019862756133, 0.051371781300986186, 0.03566699393559247, 0.09691420040326193, 0.0373572909302311, 0.0068527323583111865, 0.04471935135370586, 0.04064643748279195, 0.07520987637690268, 0.046997614845167845, 0.017585460082045756, 0.026882844977080822, 0.029518647388613317, 0.0356944088707678, 0.05983751550957095, 0.07147386786527932, 0.08904109708964825, 0.10413715266622603, 0.07789391282130964, 0.034438943621353246, 0.002680285815586103, 0.017391744695487432, 0.006280616280491813, 0.034937080563395284, 0.013976284608361311, 0.053439905677805655, 0.024851950438460335, 0.020108966273255646, 0.07213744436739944, 0.03486000852717552, 1.038887172471732, 28.0857103317976, 58.9078476279974, 52.714544758200645, 29.167837165296078, 32.26227901875973, 41.792011857032776, 51.53223820030689, 55.97283571958542, 45.71404740214348, 3.843460511416197, 0.36736416863277555, 0.9062211506534368, 5.493658762425184, 4.199492381885648, 1.4329512021504343, 18.038048185408115, 51.44497588276863, 57.973766550421715, 49.92857985198498, 49.39028933644295, 47.01117619872093, 47.581848576664925, 47.707390040159225, 50.15341378748417, 47.294982969760895, 47.937847673892975, 48.100570142269135, 52.15800382196903, 50.035380721092224, 52.059486508369446, 49.32106465101242, 40.35344325006008, 50.2990447729826, 52.029095739126205, 48.443011566996574, 49.11508910357952, 47.73707024753094, 47.54781760275364, 48.44798929989338, 48.889624401926994, 51.963298469781876, 49.21680584549904, 50.877206549048424, 51.034031733870506, 42.46478095650673, 38.06200660765171, 35.879950895905495, 37.57002040743828, 38.52330565452576, 39.99796472489834, 37.65779569745064, 38.71662028133869, 39.063214883208275, 38.824276104569435, 39.344327598810196, 38.31712871789932, 37.23625011742115, 37.81987600028515, 40.5847330391407, 39.2659568041563, 39.82975535094738, 40.144880041480064, 43.69868114590645, 47.8014349937439, 50.784673914313316, 51.85667619109154, 53.84725637733936, 52.27372661232948, 50.339808985590935, 49.96211685240269, 52.943801656365395, 53.54325369000435, 53.36696594953537, 44.10384200513363, 47.00096994638443, 54.13499213755131, 52.503226697444916, 50.725530087947845, 47.542505487799644, 42.491523921489716, 38.86971406638622, 40.239061787724495, 38.949129804968834, 40.4605633020401, 40.235451981425285, 39.58491548895836, 38.270619213581085, 40.488324612379074, 40.23120000958443, 39.56329844892025, 39.64477367699146, 39.29693654179573, 40.28092794120312, 39.77631501853466, 40.17947718501091, 37.965043410658836, 38.936867862939835, 38.31997476518154, 38.43868799507618, 37.92686685919762, 40.12736678123474, 51.92592367529869, 49.97617989778519, 49.984410256147385, 42.0850483328104, 48.83274905383587, 50.31090773642063, 51.3032890856266, 51.38776995241642, 49.18268367648125, 41.9865158200264, 38.97383227944374, 35.10126248002052, 39.20401632785797, 37.40361213684082, 38.65266211330891, 41.30984053015709, 40.97165107727051, 44.86401781439781, 43.66105556488037, 42.18929573893547, 44.21165741980076, 41.913248151540756, 43.3124964684248, 43.44715744256973, 46.61335274577141, 52.03297533094883, 52.418966218829155, 54.23710025846958, 52.08369120955467, 31.657898649573326, 2.866400652565062, 1.2898194137960672, 7.4320439994335175, 8.566426578909159, 2.6161750545725226, 0.8836750010959804, 0.25655377248767763, 27.782256714999676, 60.14725752174854, 46.84730239212513, 30.990171879529953, 25.573847517371178, 47.251653894782066, 46.02626144886017, 12.03096667304635, 0.043072770567960106, 0.06428505439544097, 0.024834882897266652, 0.023804434968042187, 0.012781998302671127, 0.05942110386968125, 0.035217296972405165, 0.06778970579034649, 0.01257769989024382, 0.04173743538558483, 0.038615839803242125, 0.027540773735381663, 0.007710318786848802, 0.1654731942107901, 0.10922846384346485, 0.2832827850943431, 0.17916057928232476, 0.2521933283424005, 0.12072734447428957, 0.10174781564273871, 0.15242448658682406, 0.1451405743137002, 0.1570860794163309, 0.08610073025920428, 0.1267850209842436, 0.20697027764981613, 0.08411852060817182, 0.24093102954793721, 0.10976879930240102, 1.1879789410158992, 33.03750202059746, 65.44688254594803, 61.0986390709877, 33.624650314450264, 35.20021677017212, 44.56915743649006, 58.86297583580017, 60.23459583520889, 53.73955495655537, 4.8636900912970304, 0.6576640787534416, 4.907993339002132, 13.835426196455956, 7.467991020530462, 1.476112729869783, 22.826507538557053, 50.82381561398506, 60.36406248807907, 52.0100549608469, 53.73839221894741, 49.02683883905411, 49.8248416185379, 48.05585794150829, 51.36367164552212, 48.75022508203983, 51.69084928929806, 51.11581854522228, 57.10439220070839, 51.33728586137295, 53.181661292910576, 49.84892472624779, 42.77196407318115, 51.64950370788574, 56.30726717412472, 51.258744075894356, 52.21298307180405, 50.104438215494156, 48.92682060599327, 48.89747858047485, 50.628217309713364, 53.59656862914562, 52.86872148513794, 52.68385000526905, 54.660074561834335, 43.607147857546806, 40.31323000788689, 37.29365363717079, 40.4322624206543, 41.37412928044796, 42.26660259068012, 39.45827968418598, 40.68182922899723, 41.261165142059326, 40.35366363823414, 39.939409866929054, 39.80238161981106, 39.65660624206066, 39.54230457544327, 40.843115374445915, 42.04211823642254, 41.00601643323898, 41.06120467185974, 46.16739347577095, 50.14849305152893, 53.4524879604578, 55.04271782934666, 55.68629689514637, 54.03749696910381, 52.24480256438255, 51.39596611261368, 54.40216340124607, 56.44497558474541, 52.827075719833374, 47.313582971692085, 49.05226327478886, 55.496394485235214, 54.18288476765156, 52.234197333455086, 47.19952829182148, 45.509424582123756, 42.35005371272564, 43.126549646258354, 41.01533353328705, 43.721377328038216, 43.552521988749504, 41.58001363277435, 39.736230969429016, 42.624148204922676, 42.19248756766319, 42.034697234630585, 42.548239678144455, 41.93550355732441, 42.373194471001625, 40.67221574485302, 41.28975860774517, 40.14109164476395, 42.49083615839481, 40.45139439404011, 39.92616757750511, 40.371891260147095, 42.222270369529724, 54.62638936936855, 50.623570159077644, 55.22359572350979, 45.635915994644165, 48.375215604901314, 51.9813247025013, 52.982646971940994, 53.4992216527462, 51.648006588220596, 44.77552816271782, 42.25191257894039, 36.9529715180397, 40.8738025277853, 38.631824031472206, 40.28549909591675, 43.24194185435772, 42.83524587750435, 47.839216366410255, 45.34113921225071, 44.16720740497112, 46.64170302450657, 44.05703991651535, 43.949460089206696, 46.76171958446503, 48.941392824053764, 53.87476310133934, 56.01460687816143, 56.57004587352276, 55.99368900060654, 34.756233394145966, 3.531950614415109, 1.7672839807346463, 9.920727107673883, 9.809374082833529, 10.861213691532612, 3.316442328505218, 0.30161573260556906, 31.899314895272255, 64.8275537788868, 50.47411657869816, 36.14248260855675, 34.327585995197296, 54.491048231720924, 52.710000202059746, 15.569432750344276, 0.06894859165186062, 0.2313620297354646, 0.17435560352168977, 0.17554652789840475, 0.09489359945291653, 0.150510398671031, 0.2065756035153754, 0.2882950130151585, 0.12562480667838827, 0.09968494196073152, 0.15505951159866527, 0.1476409292081371, 0.12322424096055329], [0.061922356762806885, 0.06353931472403929, 0.04732049361336976, 0.009340007363789482, 0.01635217577131698, 0.027014576189685613, 0.017152570908365306, 0.08061790649662726, 0.08836910463287495, 0.014046442611288512, 0.06043251385563053, 0.041303253019577824, 0.0738705595722422, 0.005939090588071849, 0.04742232740682084, 0.029759442768408917, 0.15932398120639846, 11.792385075241327, 46.77193343639374, 40.822372287511826, 23.01341000944376, 27.36158698797226, 41.28888465464115, 48.63029211759567, 48.940613865852356, 46.43775276839733, 9.735132716596127, 0.18476484809070826, 0.39668900601100177, 4.4125298503786325, 1.6138575947843492, 0.628804627340287, 10.800263062119484, 50.26634752750397, 55.47379709780216, 50.51073521375656, 46.31837077438831, 43.88265587389469, 45.013083815574646, 45.56780084967613, 43.764972388744354, 47.58412845432758, 48.24450641870499, 48.56777407228947, 49.7884813696146, 51.115658953785896, 46.37509033083916, 46.7816761136055, 47.78938204050064, 47.70450219511986, 47.92106777429581, 47.43852786719799, 45.41997358202934, 42.391194105148315, 42.938300147652626, 44.00481931865215, 45.29043473303318, 47.11320452392101, 48.678845912218094, 48.68079900741577, 44.65418927371502, 39.234916269779205, 36.94857135415077, 36.69146575033665, 35.29357396066189, 37.52380348742008, 38.3538993448019, 37.07018382847309, 38.52852277457714, 37.036350443959236, 36.71178326010704, 36.84954486787319, 35.77863313257694, 36.226321309804916, 38.52340064942837, 37.71475464105606, 36.61994218826294, 37.62022711336613, 37.61029064655304, 37.99566976726055, 42.21740663051605, 47.789180651307106, 50.3065949678421, 49.56296347081661, 50.02965822815895, 49.80891287326813, 49.04426470398903, 50.12276843190193, 50.62405653297901, 52.42248862981796, 40.005138739943504, 48.0661515891552, 52.171436101198196, 49.27642084658146, 49.36502829194069, 45.63669115304947, 39.94135536253452, 38.54133188724518, 39.28657829761505, 38.41218821704388, 39.428303092718124, 35.86907967925072, 35.893284380435944, 37.14666232466698, 36.5724903345108, 37.82929949462414, 38.4361307322979, 38.52553993463516, 37.283800765872, 36.69503755867481, 38.98321017622948, 36.642406582832336, 37.13948830962181, 35.34448362886906, 36.52503848075867, 36.17196902632713, 38.31380769610405, 36.93627141416073, 49.22766946256161, 47.28660061955452, 48.32956865429878, 52.44981296360493, 47.89752043783665, 49.62244547903538, 49.91559974849224, 51.22074991464615, 49.33445133268833, 45.55267386138439, 40.66927470266819, 37.13756561279297, 33.84434312582016, 35.8649493008852, 35.03732331097126, 35.17718620598316, 35.888534635305405, 35.75948975980282, 37.83077001571655, 36.64896883070469, 36.66039861738682, 37.693483382463455, 38.1470650434494, 39.526695013046265, 39.894579872488976, 47.56071791052818, 49.15801540017128, 53.00986111164093, 52.25942797958851, 26.975010931491852, 2.525659161619842, 0.8291156287305057, 7.858523614704609, 11.659537553787231, 0.46862828952725977, 1.107918187044561, 0.5616404407192022, 26.169931031763554, 54.87838424742222, 37.43929982185364, 33.01636755466461, 31.72453187406063, 43.058567494153976, 36.55728355050087, 4.540074756368995, 0.038487255296786316, 0.019158794602844864, 0.06660605446086265, 0.021230091660981998, 0.04532539285719395, 0.029874247447878588, 0.05698879649571609, 0.045192845282144845, 0.009614701266400516, 0.0989642646163702, 0.043297945594531484, 0.035022735537495464, 0.10632910809363239, 0.04949075977492612, 0.05053400047472678, 0.023480595118599012, 0.05533832314540632, 0.012058601914759493, 0.015340054251282709, 0.060089726976002567, 0.010396442521596327, 0.10952757162158377, 0.035962943875347264, 0.04424821003340185, 0.051206646021455526, 0.06008388627378736, 0.024302998644998297, 0.12703257176326588, 0.06326234521111473, 0.23383740393910557, 18.402980603277683, 56.17302417755127, 49.15094397962093, 28.804458864033222, 30.084230192005634, 48.15399907529354, 53.86645294725895, 52.710513174533844, 50.57111017405987, 9.372614119201899, 0.1406294890330173, 1.1933720391243696, 5.749424463137984, 3.4954397985711694, 1.05372917605564, 12.60561553761363, 51.1199527233839, 57.09504470229149, 52.53501959145069, 49.65227007865906, 47.12733596563339, 47.773821875452995, 47.05049268901348, 44.87039007246494, 48.55745382606983, 50.18456071615219, 50.877594128251076, 50.978197529911995, 52.8439924120903, 47.871845215559006, 47.4738659709692, 47.90032088756561, 49.714335948228836, 51.13724559545517, 49.20767493546009, 48.532485365867615, 43.546674102544785, 46.0648749768734, 47.28985324501991, 48.03924523293972, 48.44693675637245, 51.17204412817955, 50.80336511135101, 46.3309670984745, 40.65678857266903, 38.3696760982275, 37.170817628502846, 37.483141869306564, 39.854541420936584, 39.599738493561745, 37.99277052283287, 39.23403091728687, 38.160846903920174, 38.693692311644554, 38.70790354907513, 37.953826412558556, 38.44759851694107, 40.359963700175285, 38.47210340201855, 38.9960040897131, 38.93317066133022, 39.30833213031292, 40.53939767181873, 44.165425300598145, 49.15166974067688, 51.585150361061096, 52.998256534338, 51.66860908269882, 50.51861219108105, 51.338965371251106, 50.10343886911869, 52.3816180229187, 53.61893802881241, 43.32315109670162, 49.091674759984016, 52.785023376345634, 51.093688532710075, 50.745665207505226, 46.92494362592697, 41.33042402565479, 40.929963514208794, 39.968018531799316, 41.79161287844181, 40.81161506474018, 38.388982862234116, 37.64860399067402, 38.63163784146309, 37.94618122279644, 41.12893603742123, 40.37452071905136, 39.673853516578674, 38.16730655729771, 37.73538373410702, 39.86860066652298, 39.34032641351223, 38.15822884440422, 36.560623571276665, 38.62162537872791, 38.68186354637146, 40.443133637309074, 37.844722867012024, 51.294294968247414, 49.30515110492706, 50.731807351112366, 52.80183747410774, 50.33203840255737, 49.369842633605, 50.22002041339874, 52.52102494239807, 51.240554451942444, 48.1615948677063, 42.744499146938324, 38.17915812134743, 36.908202320337296, 37.51932352781296, 37.28280521929264, 37.38007239997387, 37.7094691246748, 38.515010699629784, 39.28467459976673, 40.09909249842167, 38.54073151946068, 40.16580931842327, 40.25933749973774, 39.99549485743046, 42.43962250649929, 49.68439735472202, 52.38884523510933, 55.7610122859478, 53.42226818203926, 29.446436315774918, 3.288084212690592, 2.5726920878514647, 9.479509983211756, 13.411096315830946, 4.958336837589741, 0.550733779091388, 0.2761468867538497, 28.92662040889263, 60.123087018728256, 43.17299075424671, 33.99625517427921, 35.42827293276787, 47.55285993218422, 42.68043078482151, 6.153803989291191, 0.1898679742589593, 0.03207765978004318, 0.08114973694318905, 0.035476373304845765, 0.019501449751260225, 0.01544881042718771, 0.07449815675499849, 0.02763054577371804, 0.029229412029962987, 0.045559967184090056, 0.025523775912006386, 0.06615865073399618, 0.056960977090056986, 0.09739324930706061, 0.16857195761986077, 0.13305983506143093, 0.0879220274509862, 0.14487338630715385, 0.09673057080362923, 0.17590568284504116, 0.20319282019045204, 0.2776376239489764, 0.14764659921638668, 0.1559938013087958, 0.19310106639750302, 0.2275524372817017, 0.13087547180475667, 0.19686307234223932, 0.14473479765001684, 0.3821544296806678, 21.512627340853214, 61.989774852991104, 54.7131235152483, 36.635878533124924, 38.519068881869316, 53.374371752142906, 60.6449244171381, 60.46886086463928, 56.65192387998104, 11.749186143279076, 0.2642720192670822, 3.7025108747184277, 10.59770543128252, 5.200873073190451, 2.045344985090196, 13.86117646470666, 54.83055621385574, 59.15300287306309, 54.40940961241722, 50.099259093403816, 47.99602635204792, 49.91113118827343, 49.92918781936169, 46.32692791521549, 52.53801383078098, 52.28012166917324, 53.18625904619694, 53.95664870738983, 54.76229667663574, 48.67574527859688, 48.3576225489378, 51.05771206319332, 53.54516498744488, 52.588463723659515, 50.90348593890667, 51.44917845726013, 46.9189665466547, 46.83519624173641, 49.084941521286964, 48.899264484643936, 50.07625512778759, 53.18809054791927, 52.27789118885994, 49.514713659882545, 43.57484199106693, 41.60634241998196, 39.832153022289276, 40.180715918540955, 41.59659594297409, 41.69977180659771, 39.35879722237587, 42.52019718289375, 41.111947149038315, 41.88239760696888, 40.71781329810619, 39.90696720778942, 40.54037421941757, 43.040849044919014, 41.99670307338238, 41.01436838507652, 41.51716500520706, 40.90924322605133, 43.095463514328, 45.70818431675434, 52.82665394246578, 54.286444410681725, 56.15269906818867, 52.67915725708008, 51.92477993667126, 52.00444646179676, 52.90981628000736, 54.01576593518257, 54.32176731526852, 46.630938202142715, 50.8184465020895, 56.40178330242634, 54.50370155274868, 53.15768077969551, 47.9099989682436, 43.84726457297802, 43.1104651093483, 42.097477465867996, 43.54965694248676, 43.579302951693535, 38.837909772992134, 40.63090056180954, 40.43865367770195, 39.395659044384956, 43.61816346645355, 42.15528756380081, 41.97412468492985, 40.779624581336975, 39.705471619963646, 42.201192900538445, 40.22822856903076, 40.31829513609409, 38.47185641527176, 41.47814869880676, 40.234912410378456, 43.08005914092064, 40.68608120083809, 53.45401167869568, 51.3171773403883, 51.3741172850132, 55.24514056742191, 52.52404198050499, 51.160549744963646, 51.27913758158684, 54.629847183823586, 54.228432923555374, 50.35248510539532, 45.648033544421196, 41.208408772945404, 37.48942673206329, 38.72550420463085, 39.88477259874344, 38.75792786478996, 39.16729889810085, 40.41682004928589, 42.25988455116749, 40.52552841603756, 41.25121347606182, 42.49370880424976, 42.86575824022293, 42.231952250003815, 44.72046531736851, 50.95594212412834, 54.87648814916611, 57.84469127655029, 55.39272844791412, 32.90370739996433, 3.6756090307608247, 3.604138665832579, 16.360212117433548, 24.844757840037346, 10.443436559289694, 3.4132753824815154, 0.7189104391727597, 32.525278106331825, 66.29956439137459, 49.10713613033295, 46.221738159656525, 44.880269542336464, 54.3452462553978, 49.46988746523857, 7.636303463950753, 0.24513894750270993, 0.1887497358256951, 0.21600279374979436, 0.11091025953646749, 0.08882453839760274, 0.11361443786881864, 0.18312765547307208, 0.14791767607675865, 0.12364627807983197, 0.2592640067450702, 0.10153265960980207, 0.1858202859875746, 0.17903236584970728], [0.006363022503137472, 0.033217817544937134, 0.00639405633592105, 0.06047910217603203, 0.04383765764941927, 0.039588376093888655, 0.09659533665399067, 0.025671467010397464, 0.058880055948975496, 0.024134499581123237, 0.021175499277887866, 0.0427266069164034, 0.04691795271355659, 0.011824876419268548, 0.12658168736379594, 0.012957377075508703, 0.08392893156269565, 6.024797586724162, 34.13746699690819, 41.2117487937212, 19.46677152067423, 14.856965281069279, 27.876447960734367, 44.93625953793526, 47.49837465584278, 51.123581528663635, 12.888842839747667, 0.03273159949458204, 0.6049550883471966, 2.3765893606469035, 4.119292460381985, 0.6646414543502033, 9.725983757525682, 46.5602657943964, 55.05787901580334, 51.260757967829704, 48.06702174246311, 45.15353187918663, 43.93821269273758, 45.31012907624245, 46.776835173368454, 49.03438523411751, 49.618387296795845, 48.57256181538105, 51.625443398952484, 45.98637118935585, 46.33358895778656, 46.35019786655903, 48.978224247694016, 47.9662549495697, 47.38772839307785, 44.399477541446686, 42.29238800704479, 39.874847531318665, 42.063552886247635, 41.43950097262859, 45.53771026432514, 47.18267239630222, 47.770519852638245, 45.31319931149483, 41.386858597397804, 37.068128138780594, 37.97583483159542, 35.60696594417095, 37.33783766627312, 35.99681742489338, 36.97743460536003, 37.61046543717384, 36.388614401221275, 38.40237334370613, 37.65255957841873, 36.10461764037609, 37.018031626939774, 37.18583822250366, 38.93745683133602, 37.52319552004337, 39.14228864014149, 37.05023109912872, 39.653137028217316, 37.96057865023613, 38.20772498846054, 42.44228236377239, 49.96541127562523, 50.92480279505253, 50.20303152501583, 51.51214487850666, 48.03482607007027, 51.617296636104584, 55.73227442800999, 46.90322019159794, 40.26631772518158, 50.766818672418594, 50.73075480759144, 50.423913672566414, 46.95151939988136, 42.51961961388588, 38.71457599103451, 38.75185579061508, 40.08507885038853, 40.2673626691103, 40.82620248198509, 38.63860286772251, 35.83674721419811, 36.818086355924606, 37.58622273802757, 37.57041558623314, 38.73038314282894, 37.82916650176048, 37.06828013062477, 36.9071801751852, 36.87165588140488, 37.286057844758034, 38.73749256134033, 36.166071742773056, 37.19220668077469, 36.84478372335434, 37.69200146198273, 36.01302355527878, 44.063928946852684, 46.986371129751205, 48.3205821365118, 46.71712517738342, 47.60571509599686, 49.96077932417393, 49.679605811834335, 50.856163278222084, 50.92965133488178, 47.75096610188484, 43.81900928914547, 39.89223159849644, 37.62372672557831, 37.12007515132427, 36.64180241525173, 35.21341726183891, 37.77736768126488, 37.575868293643, 36.25112257897854, 36.2492036819458, 36.942879259586334, 36.48352950811386, 37.326559871435165, 38.69614318013191, 44.07566271722317, 48.89740638434887, 51.32055535912514, 50.16077779233456, 53.27298939228058, 24.830727092921734, 1.8974767508916557, 3.0068425415083766, 5.9541636519134045, 7.9392388835549355, 1.629255199804902, 0.14743873849511147, 0.7307398575358093, 35.8991626650095, 47.170874029397964, 40.68162404000759, 26.766523718833923, 25.55700872093439, 48.239650279283524, 26.11931584775448, 1.2166253663599491, 0.09973925232770853, 0.06416720876586623, 0.022541919315699488, 0.03464819586952217, 0.02991028428368736, 0.030888768887962215, 0.022785514447605237, 0.07393860709271394, 0.01867700531875016, 0.04193148102785926, 0.04113068884180393, 0.048689036193536595, 0.06553253042511642, 0.03372392886376474, 0.014226840157789411, 0.01159381894467515, 0.08300846064230427, 0.008983040825114585, 0.05949741149379406, 0.05470234711538069, 0.06461648270487785, 0.02222579780209344, 0.050803455742425285, 0.04088116023922339, 0.0433321808668552, 0.012584766063810093, 0.0036086613044972182, 0.0795848443522118, 0.05162295747140888, 0.11067622326663695, 8.50731410086155, 41.11132778227329, 46.97601668536663, 26.178300082683563, 23.133637458086014, 36.69223710894585, 51.03619001805782, 53.79721686244011, 55.23993104696274, 15.010565388947725, 0.032873316304176114, 1.0757468570955098, 5.417199265211821, 5.041929027065635, 1.0417003277689219, 10.874246042221785, 48.673925176262856, 56.87771916389465, 53.37591826915741, 51.233171448111534, 46.11554905772209, 45.84223352372646, 46.945834904909134, 50.080822482705116, 50.012631341814995, 50.98627209663391, 50.54650269448757, 52.86252401769161, 47.111749202013016, 47.2420784085989, 47.40264259278774, 50.52625358104706, 49.07026290893555, 49.331821873784065, 45.72256274521351, 44.30133640766144, 41.4111202955246, 43.99670295417309, 43.95125359296799, 47.42118559777737, 49.37669366598129, 49.1927607357502, 49.292049407958984, 43.1228144466877, 38.15209977328777, 39.43210668861866, 37.548992335796356, 38.42956468462944, 39.536171704530716, 38.171455934643745, 39.45585921406746, 38.33079278469086, 39.487712904810905, 39.551348090171814, 38.581822514534, 37.5522867590189, 38.95492069423199, 41.19885988533497, 40.27419850230217, 39.79065164923668, 38.107562363147736, 41.53736092150211, 41.10491372644901, 39.94199752807617, 45.81721946597099, 49.52489711344242, 50.89681349694729, 50.7272057980299, 53.19537475705147, 50.06855674088001, 52.181999534368515, 55.235014110803604, 49.11468632519245, 42.01799713075161, 51.34082347154617, 53.563609197735786, 52.56919115781784, 49.90350879728794, 45.25582239031792, 40.68014971911907, 40.75797714293003, 41.113147884607315, 42.034226059913635, 43.18654082715511, 38.98607902228832, 38.97423505783081, 37.96081803739071, 38.71534734964371, 39.04859706759453, 41.23656526207924, 39.136292561888695, 38.014676347374916, 38.71449239552021, 37.89721705019474, 39.25838001072407, 39.0461689978838, 37.734137400984764, 39.88758064806461, 38.17608408629894, 38.892550840973854, 37.70795300602913, 45.67345418035984, 49.9718177318573, 48.12627576291561, 46.61743752658367, 49.462816044688225, 50.1029334962368, 51.28858007490635, 52.04978182911873, 52.85366669297218, 49.2059650272131, 47.63767138123512, 41.89997926354408, 40.48813462257385, 39.21298384666443, 38.83221007883549, 38.62645111978054, 39.53222371637821, 39.72089499235153, 37.51876875758171, 38.45561608672142, 38.569473177194595, 38.3980605751276, 39.73351411521435, 40.52169822156429, 45.60199901461601, 50.75201466679573, 52.33568988740444, 54.65735390782356, 53.84536027908325, 26.285000257194042, 2.223177580162883, 3.9292739192023873, 8.475684598088264, 10.84829818457365, 4.3162886146456, 0.5049391114152968, 0.7468964124564081, 38.149082735180855, 53.54264572262764, 44.09822590649128, 31.469535157084465, 31.607270166277885, 53.44630569219589, 33.716533184051514, 1.734311725012958, 0.03952625091187656, 0.02478062262525782, 0.05756627273513004, 0.02221257829660317, 0.04015170699858572, 0.047016387470648624, 0.04309937285142951, 0.0702463259221986, 0.08765032718656585, 0.028825715235143434, 0.03513837327773217, 0.0800546832033433, 0.014490764569927705, 0.11118291717139073, 0.1321896817535162, 0.0979081736295484, 0.174523358582519, 0.11250726485741325, 0.14191288501024246, 0.27254634245764464, 0.164950811304152, 0.12333141450653784, 0.17978631367441267, 0.11864973173942417, 0.12190057605039328, 0.17111857800045982, 0.0847961608087644, 0.18716372171184048, 0.10996023629559204, 0.195925502339378, 11.41679422929883, 50.12405276298523, 55.26204586029053, 32.37997770309448, 25.493497028946877, 38.3499551564455, 55.653405860066414, 57.91884049773216, 60.88424317538738, 16.92584216594696, 0.14683978079119697, 2.0860935235396028, 9.986765664070845, 13.31703806295991, 3.4032923681661487, 12.473684716969728, 51.25576123595238, 58.08654449880123, 55.733885541558266, 54.02961619198322, 49.481579437851906, 47.93227717280388, 49.847746789455414, 51.86776399612427, 52.78309307992458, 54.08877521753311, 52.05343723297119, 53.56393977999687, 48.421307131648064, 47.90774568915367, 50.164300203323364, 52.67378814518452, 50.625310465693474, 52.78543375432491, 47.73727923631668, 46.52102530002594, 42.117498591542244, 45.15472121536732, 45.70801332592964, 50.00923812389374, 52.740767151117325, 51.51708081364632, 50.83684131503105, 44.60289962589741, 40.61384707689285, 40.65389312803745, 38.72123323380947, 42.11200788617134, 39.40104715526104, 39.97684545814991, 40.42888820171356, 40.03948509693146, 41.89402878284454, 41.09419450163841, 40.50208367407322, 39.3069452047348, 41.062648594379425, 42.52210088074207, 40.780000761151314, 42.395601868629456, 39.623183235526085, 43.82163494825363, 42.50196576118469, 40.85582569241524, 47.2577715665102, 53.03713984787464, 53.15805695950985, 51.57165348529816, 55.156354531645775, 50.48868119716644, 54.72961463034153, 55.42614005506039, 50.45394346117973, 46.56833656132221, 52.983505725860596, 56.1666215211153, 53.82012203335762, 50.661549121141434, 46.84249944984913, 42.39945866167545, 43.16281870007515, 43.41499216854572, 43.61483484506607, 44.63019356131554, 43.08261640369892, 41.64174132049084, 39.881322383880615, 40.99380388855934, 40.98705165088177, 44.182680174708366, 41.70719660818577, 39.886459708213806, 40.69010518491268, 38.27336646616459, 40.65697856247425, 41.408802419900894, 39.84347641468048, 40.92418022453785, 40.31638003885746, 40.91978006064892, 40.42679451406002, 46.9295147806406, 52.09549717605114, 51.90693609416485, 50.33348232507706, 51.538241878151894, 52.13195621967316, 52.550834342837334, 51.89237527549267, 54.05066326260567, 52.94334948062897, 49.761328026652336, 43.40966485440731, 42.98882223665714, 41.077980771660805, 40.7943943887949, 39.78357642889023, 42.60223478078842, 41.38147048652172, 39.22484681010246, 41.244940012693405, 41.42584070563316, 38.99867154657841, 40.91075174510479, 43.30080829560757, 49.030190259218216, 53.92458222806454, 55.97155138850212, 56.000608429312706, 54.029737785458565, 29.228605404496193, 3.175934893079102, 7.2779465932399035, 14.17744679376483, 18.8944823294878, 7.995797898620367, 0.7032848463859409, 0.8694680978078395, 43.613493517041206, 57.402334213256836, 52.78877377510071, 39.16576758027077, 38.367783799767494, 60.801229029893875, 39.79220196604729, 2.519454094581306, 0.1881990919355303, 0.1543390197912231, 0.12110562456655316, 0.11421307644923218, 0.12103261207812466, 0.12156361874076538, 0.15408277104143053, 0.13613235612865537, 0.13671832624822855, 0.14164421270834282, 0.14796021598158404, 0.1635316023021005, 0.23810426326235756], [0.0779076202888973, 0.03317035720101558, 0.019542729860404506, 0.0587725595687516, 0.08429101799265482, 0.0540364180051256, 0.029449414287228137, 0.11413360727601685, 0.03363022529811133, 0.010368480252509471, 0.028007781293126754, 0.07798996899509802, 0.040303027199115604, 0.06398307450581342, 0.03450216718192678, 0.09958374270354398, 0.023663603169552516, 4.531226456165314, 27.09177866578102, 43.295017406344414, 26.3501363620162, 22.11766317486763, 41.84856042265892, 44.28819291293621, 49.43270266056061, 52.241109162569046, 29.229542054235935, 0.45221860287711024, 0.3224857267923653, 4.295099526643753, 2.1165655134245753, 0.3322719532297924, 7.757670851424336, 41.879699751734734, 57.09361597895622, 50.52835866808891, 47.97916665673256, 45.471719205379486, 45.58387018740177, 47.61917397379875, 47.49629996716976, 50.37423513829708, 51.64679445326328, 50.30022270977497, 46.32502421736717, 47.67444960772991, 49.1861604899168, 48.194580897688866, 47.112452164292336, 46.174746081233025, 44.773723259568214, 44.72099348902702, 41.550147235393524, 40.258759930729866, 38.40805783867836, 38.32087531685829, 42.27391339838505, 44.58369925618172, 44.621454030275345, 42.6178253442049, 38.13650541007519, 37.68343672156334, 37.79347121715546, 33.643808886408806, 36.67882762849331, 36.44675128161907, 38.687981218099594, 37.06120491027832, 38.18265773355961, 38.44490446150303, 37.305763587355614, 38.553635627031326, 35.96546910703182, 37.71652914583683, 37.72702418267727, 37.33168199658394, 40.07700428366661, 37.70460918545723, 38.8612063229084, 36.30955584347248, 38.46257731318474, 37.70102597773075, 45.518616288900375, 48.28725412487984, 50.92119298875332, 51.29493333399296, 52.505008801817894, 44.462839141488075, 61.010035425424576, 45.33086076378822, 38.77154253423214, 55.005859807133675, 50.49513325095177, 50.00630468130112, 46.157707795500755, 40.392394959926605, 38.99296425282955, 40.403490364551544, 41.160842925310135, 43.640282079577446, 41.53997518122196, 42.249856889247894, 38.15705470740795, 37.175696566700935, 36.568796932697296, 38.783929869532585, 37.97094449400902, 37.76159852743149, 37.10866056382656, 37.86396883428097, 37.895282953977585, 37.12407633662224, 36.658388525247574, 35.70770613849163, 35.7577608525753, 36.51185318827629, 37.42366746068001, 36.28610350191593, 37.651567831635475, 42.599339336156845, 42.616001442074776, 47.67280429601669, 44.638963490724564, 47.08628676831722, 49.57251235842705, 46.64400190114975, 48.05091820657253, 49.548106268048286, 47.017396464943886, 47.8949099779129, 42.569780722260475, 40.99914640188217, 42.4782208353281, 41.382648423314095, 42.74698421359062, 41.070023998618126, 43.35911236703396, 38.00410911440849, 39.43290464580059, 38.73023875057697, 39.73542541265488, 41.480105593800545, 45.43367184698582, 49.92341212928295, 51.92012898623943, 51.983646377921104, 52.113158628344536, 21.92773226648569, 1.0370541270822287, 2.2180982027202845, 9.210226982831955, 10.132883973419666, 2.948674075305462, 0.3347851027501747, 1.5142829879187047, 38.01477134227753, 46.39578402042389, 38.561900183558464, 31.173436045646667, 33.241159692406654, 47.533724159002304, 18.77825226634741, 0.1910232607042417, 0.04344411529018544, 0.020887985701847356, 0.00736496175704815, 0.03664548225060571, 0.058517294164630584, 0.03840820543700829, 0.03660573282104451, 0.014588762387575116, 0.03170581039739773, 0.03942364528484177, 0.05475325102452189, 0.030492050136672333, 0.041238656485802494, 0.036620471873902716, 0.03637314002844505, 0.02245244599180296, 0.040515006839996204, 0.0449863204266876, 0.05697079570381902, 0.0369024360406911, 0.05509523267392069, 0.04111124828341417, 0.04133424881729297, 0.01520397127023898, 0.03367303237610031, 0.07506827460019849, 0.0472838352288818, 0.07991538208443671, 0.0786480461829342, 0.015577844860672485, 5.781543664634228, 34.34605300426483, 47.17573396861553, 31.280839182436466, 22.03843552619219, 42.179009690880775, 49.922446981072426, 53.511016219854355, 57.90702313184738, 28.29070933163166, 0.4550074751023203, 0.4539574251975864, 5.573075450956821, 5.810402166098356, 0.815512714907527, 9.191750474274158, 43.83241876959801, 57.64967814087868, 52.92716234922409, 50.67261412739754, 47.79145672917366, 47.437194138765335, 51.93186275660992, 50.803889483213425, 51.141957342624664, 51.979326009750366, 50.82236789166927, 47.17935137450695, 48.456405848264694, 50.939713194966316, 50.2632886916399, 48.18605035543442, 49.01786372065544, 45.84398902952671, 46.56734101474285, 44.10675644874573, 41.522594913840294, 39.857569858431816, 41.20434299111366, 44.006776213645935, 46.72174572944641, 45.52020080387592, 44.24219258129597, 39.8440083861351, 40.803901478648186, 38.67442734539509, 35.86631342768669, 38.37691091001034, 38.12677413225174, 39.32499423623085, 38.6794126778841, 38.417675122618675, 38.466175720095634, 39.88537296652794, 41.04412078857422, 36.316669061779976, 39.46566268801689, 38.2182352244854, 39.516363367438316, 39.84428957104683, 40.25727041065693, 40.357269644737244, 39.912226125597954, 39.83615040779114, 40.691522508859634, 45.84598772227764, 51.50852367281914, 51.53230659663677, 53.380622416734695, 53.629748448729515, 48.518346324563026, 58.44364933669567, 46.33901506662369, 41.47291637957096, 55.317260697484016, 51.999966502189636, 51.875401586294174, 47.327235639095306, 42.25331090390682, 40.57488776743412, 42.02217310667038, 43.628137931227684, 44.57679882645607, 43.052932396531105, 42.587810754776, 40.183375775814056, 37.51236990094185, 38.457325994968414, 37.89669647812843, 40.08621118962765, 37.79495693743229, 39.778290912508965, 38.952055647969246, 38.355445861816406, 38.5696479678154, 38.41281898319721, 37.91113570332527, 36.77238240838051, 38.79822090268135, 38.907541036605835, 37.44563028216362, 39.578737020492554, 43.9081297069788, 45.44414408504963, 48.16757574677467, 48.306032717227936, 49.31120418012142, 50.269835740327835, 47.221931889653206, 50.30999578535557, 51.51533670723438, 49.82378147542477, 49.7062423825264, 45.44202759861946, 42.71725080907345, 44.75747533142567, 43.378308936953545, 44.82418455183506, 43.3907912671566, 43.85883875191212, 39.48025770485401, 40.51161736249924, 40.975815653800964, 40.85625506937504, 43.18500570952892, 47.36970216035843, 53.15215207636356, 55.530619248747826, 53.43649081885815, 51.82478070259094, 25.193845108151436, 1.6267347475513816, 4.653129139915109, 11.113719642162323, 9.211667105555534, 4.9365488067269325, 0.2933112782193348, 1.4159876061603427, 43.39649096131325, 50.48254832625389, 42.49739460647106, 34.31290738284588, 34.92840215563774, 55.84689147770405, 25.50674121826887, 0.3146231471328065, 0.10770241526188329, 0.05367358200601302, 0.10551094965194352, 0.07729692923021503, 0.03436665843764786, 0.055920938757481053, 0.036445350997382775, 0.055822708091000095, 0.06956280049053021, 0.07851314599975012, 0.06152690708404407, 0.017407127561455127, 0.08501991833327338, 0.17581242456799373, 0.1842386950738728, 0.07885217390139587, 0.245239938958548, 0.15818518528249115, 0.23885337228421122, 0.18403838941594586, 0.19942501065088436, 0.09240650673746131, 0.1380936594796367, 0.15410813764901832, 0.18177768884925172, 0.1478413981385529, 0.1961047013173811, 0.12434117321390659, 0.15006267582066357, 0.18400129687506706, 7.029868829995394, 38.492595702409744, 56.02224066853523, 39.63020905852318, 34.5011492818594, 54.394928589463234, 55.153755471110344, 60.868664011359215, 63.60875017940998, 35.64206466078758, 0.9222767141181976, 1.887405866291374, 12.364511825144291, 8.531253766268492, 0.978124929824844, 10.083295684307814, 46.44626051187515, 60.4486383497715, 54.32755820453167, 51.95229046046734, 50.87088368833065, 49.79677252471447, 53.50768379867077, 51.53926782310009, 53.427956476807594, 54.38481733202934, 51.174920573830605, 47.24492445588112, 49.942091926932335, 54.41083073616028, 54.433002546429634, 50.86913198232651, 51.5013724565506, 48.364583775401115, 50.10324887931347, 46.21334061026573, 44.35257665812969, 43.63967031240463, 42.25756287574768, 46.53173312544823, 48.9406518638134, 47.51843377947807, 46.49547167122364, 41.314913257956505, 41.724911257624626, 41.434375047683716, 36.99010692536831, 40.24021692574024, 40.08919782936573, 42.33559928834438, 42.21361443400383, 41.95950306952, 41.358656510710716, 40.14942839741707, 45.233696177601814, 38.77071797847748, 42.160736471414566, 40.26778444647789, 42.69238494336605, 41.811314821243286, 41.43323890864849, 43.374106362462044, 40.94022676348686, 41.767168790102005, 41.58081918954849, 47.040275037288666, 54.33295011520386, 52.912400141358376, 56.219507083296776, 53.54176037013531, 50.655393451452255, 58.09914082288742, 49.650423377752304, 43.10663491487503, 56.29123583436012, 55.41636697947979, 52.61044554412365, 48.63416410982609, 42.56604552268982, 41.242770329117775, 45.39599686861038, 46.632370725274086, 48.28149363398552, 44.54550750553608, 44.630706533789635, 43.15443255007267, 38.95232543349266, 39.8500956594944, 42.14394137263298, 42.85756208002567, 39.431510120630264, 41.41660340130329, 40.78743316233158, 40.49491345882416, 40.5150143802166, 40.32086379826069, 37.933014929294586, 38.382481411099434, 41.040902361273766, 41.378970220685005, 41.02586656808853, 42.03062765300274, 46.7618677765131, 47.37151466310024, 51.273605078458786, 50.53357198834419, 51.90264232456684, 53.091826513409615, 48.816812708973885, 51.32934808731079, 53.504453971982, 50.54425321519375, 51.352067068219185, 47.24620118737221, 44.30631794035435, 45.77989026904106, 45.46209432184696, 47.13967390358448, 46.27544067800045, 48.569685369729996, 42.191511020064354, 43.91831316053867, 42.58040875196457, 44.86273728311062, 47.18841768801212, 49.55771595239639, 55.297269970178604, 58.737669959664345, 55.841803550720215, 54.46473464369774, 26.761481389403343, 2.217548182234168, 5.75587366707623, 17.922351993620396, 20.975947938859463, 10.34979723393917, 0.8704639412462711, 1.764571163803339, 48.68367925286293, 58.05382825434208, 49.88719627261162, 44.12916384637356, 46.34153053164482, 61.99209652841091, 31.05938896536827, 0.664557502605021, 0.35761742445174605, 0.10716202785260975, 0.13322267710464075, 0.15881889034062624, 0.24239720165496692, 0.17302810912951827, 0.14679353014798835, 0.11652727102045901, 0.16820036427816376, 0.19419215706875548, 0.26647512917406857, 0.06897976185427979, 0.12349175551207736], [0.05316026814398356, 0.047790358439669944, 0.058361821647849865, 0.02785233660688391, 0.03457376216829289, 0.12116947153117508, 0.05443122201540973, 0.06442184705520049, 0.030936379516788293, 0.02593158234958537, 0.06472546709119342, 0.034457052024663426, 0.006747447578163701, 0.07185205889982171, 0.09198992440360598, 0.03106413467321545, 0.03408486125408672, 1.5757449273951352, 18.587384708225727, 45.38442648947239, 37.64479659497738, 26.067053452134132, 19.020869247615337, 34.82454992830753, 47.63763718307018, 51.23437978327274, 38.38642939925194, 3.186219991184771, 0.24548440240323544, 3.658449864014983, 4.032751154154539, 0.6356659310404211, 7.4196438398212194, 39.59371581673622, 56.028194949030876, 51.597978472709656, 49.5776192843914, 46.171668246388435, 48.909432739019394, 49.6120910346508, 52.123577669262886, 51.01115696132183, 48.808031380176544, 45.28501622378826, 46.67287275195122, 49.18385021388531, 48.84118840098381, 45.58736979961395, 48.41011293232441, 46.77322916686535, 46.12638607621193, 42.64307878911495, 40.840379521250725, 39.93153288960457, 37.882257252931595, 38.464564606547356, 39.95587818324566, 40.80064885318279, 39.3423593044281, 35.882059782743454, 37.16472275555134, 36.14126667380333, 37.71054446697235, 35.40890917181969, 37.69491210579872, 37.63313502073288, 36.80485166609287, 37.78770312666893, 40.55292874574661, 40.08612759411335, 36.40738159418106, 35.83260163664818, 37.610123455524445, 38.973030522465706, 37.58553497493267, 38.05298589169979, 37.717699483036995, 38.22404891252518, 38.928515911102295, 36.898683831095695, 37.41287983953953, 37.658513858914375, 39.83690656721592, 49.14849691092968, 53.78512591123581, 49.8680566996336, 51.95082753896713, 45.01435674726963, 63.1272704154253, 46.594159975647926, 42.18321606516838, 54.34390872716904, 50.66825956106186, 51.07431337237358, 44.170699417591095, 42.01157167553902, 39.67639558017254, 42.20795653760433, 44.969701543450356, 45.47998756170273, 41.184758841991425, 41.9382394105196, 38.45982626080513, 37.21443168818951, 36.17821589112282, 38.653011694550514, 36.14291198551655, 38.10615263879299, 38.88253457844257, 36.48475684225559, 37.372917383909225, 37.895016968250275, 37.3374804854393, 36.618300676345825, 35.52990607917309, 35.62576733529568, 36.91526234149933, 36.25472478568554, 35.944342240691185, 36.72044299542904, 38.28212879598141, 41.34349152445793, 43.103123903274536, 45.5219829082489, 46.401217728853226, 50.96979238092899, 48.650780618190765, 46.88899375498295, 48.11163514852524, 48.27526956796646, 46.587194949388504, 46.7123906314373, 47.14103803038597, 47.4189855158329, 47.91577845811844, 47.73170493543148, 47.89508476853371, 45.24324506521225, 45.355506241321564, 44.91353675723076, 43.892922922968864, 46.36308677494526, 48.89498211443424, 48.21310110390186, 53.46640281379223, 50.85166051983833, 48.37229736149311, 16.98258452117443, 1.1178996576927602, 3.022132683545351, 8.429189343005419, 5.4215167835354805, 3.1356019573286176, 0.3621921414742246, 3.118837969377637, 42.411534413695335, 44.862459897994995, 32.873559817671776, 22.813525535166264, 36.21214047074318, 44.74788084626198, 13.508182056248188, 0.13333919428987429, 0.06309766264166683, 0.018211888382211328, 0.007125486472432385, 0.07898424650193192, 0.08636045968160033, 0.032066204730654135, 0.012710263235931052, 0.04283588445105124, 0.03747586015379056, 0.08352564109372906, 0.03228096742532216, 0.03130849050648976, 0.03902839598595165, 0.047756850472069345, 0.03865664308250416, 0.008554835530958371, 0.035994229110656306, 0.01791550614143489, 0.03252262555179186, 0.03260295190557372, 0.02803877152473433, 0.03397322368982714, 0.015194778843579115, 0.033228088868781924, 0.06059263592760544, 0.060959783804719336, 0.04118964134249836, 0.052515085772029124, 0.06839440029580146, 0.07827050081687048, 2.4196607619524, 24.40740130841732, 53.37209567427635, 42.31857620179653, 28.410866484045982, 30.412401482462883, 45.61739958822727, 53.74720774590969, 55.09754128754139, 41.87468782067299, 3.2873909873887897, 0.29559804301243275, 5.885956836864352, 8.651156332343817, 1.3164135930128396, 8.947032205760479, 41.17818899452686, 56.77695997059345, 53.70246134698391, 50.92911556363106, 48.233433812856674, 49.98445585370064, 52.38645136356354, 52.85924479365349, 52.27557331323624, 49.26782950758934, 46.75731562077999, 47.25301422178745, 50.78460551798344, 51.12693674862385, 48.51944826543331, 47.8497190028429, 47.80955135822296, 48.24526637792587, 45.171535313129425, 44.336792305111885, 41.604624912142754, 40.19611269235611, 39.59548272192478, 42.567584440112114, 43.33620719611645, 42.104070112109184, 39.55135948956013, 39.362908601760864, 38.38696517050266, 40.121632888913155, 37.83377945423126, 37.65228599309921, 38.523442447185516, 38.09799447655678, 40.16632229089737, 42.25464083254337, 40.99480323493481, 39.01913344860077, 36.89643055200577, 38.073193207383156, 39.791111424565315, 39.62146192789078, 39.72999170422554, 39.48031850159168, 38.39070796966553, 38.78326490521431, 39.2215371876955, 38.44949461519718, 40.55021569132805, 42.20975004136562, 52.1998243778944, 53.62537108361721, 52.760180309414864, 51.56520903110504, 47.97226622700691, 57.45088040828705, 48.21904398500919, 44.586955681443214, 56.33604682981968, 53.15787456929684, 52.43548393249512, 47.5091090798378, 43.752239271998405, 41.69465348124504, 44.593723118305206, 46.47817499935627, 46.55019633471966, 43.84274281561375, 44.11589875817299, 40.13787321746349, 39.011454060673714, 37.635772079229355, 39.94432680308819, 37.80294790863991, 39.194440841674805, 39.48575980961323, 39.122890681028366, 39.092328920960426, 39.55014355480671, 39.09876577556133, 37.820901945233345, 36.44679307937622, 37.21820868551731, 38.08359704911709, 38.781262412667274, 38.0092616379261, 39.210244193673134, 40.74457906186581, 42.99147829413414, 46.36284738779068, 47.732445895671844, 49.82725828886032, 51.05165138840675, 47.97022573649883, 48.18184398114681, 50.65307937562466, 51.049371510744095, 49.192741736769676, 49.14426773786545, 48.332726284861565, 49.99607942998409, 48.093958497047424, 49.59301605820656, 49.593871012330055, 48.12996916472912, 46.635946333408356, 45.25977797806263, 46.64589039981365, 48.01328882575035, 50.38343824446201, 50.93034669756889, 56.46187327802181, 51.92740559577942, 48.656370118260384, 19.687262289226055, 1.4093466312624514, 5.069663263857365, 11.62728488445282, 7.244244776666164, 4.388393545523286, 0.3059433144517243, 2.3510953411459923, 47.14932918548584, 50.38279987871647, 43.29854741692543, 30.92279389500618, 43.34675543010235, 50.415329933166504, 19.131673201918602, 0.15231375815346837, 0.01723860994388815, 0.08182015604688786, 0.04174370282271411, 0.020226526175974868, 0.09709971505799331, 0.03665759781142697, 0.08468141735647805, 0.04391130467411131, 0.018655620333447587, 0.03280845259723719, 0.014875874276185641, 0.03819051868049428, 0.06390871873009019, 0.1129764951474499, 0.11915024355403148, 0.09829451344558038, 0.17135263653472066, 0.08082708081929013, 0.2344475977588445, 0.16107294126413763, 0.15978985698893666, 0.17459919123211876, 0.07947346282890067, 0.12072737416019663, 0.21098664728924632, 0.10328259188099764, 0.12032101119984873, 0.22162959416164085, 0.13343266036827117, 0.24748738476773724, 2.6187957264482975, 28.90677597373724, 62.65510395169258, 51.925927475094795, 36.967748925089836, 30.015108101069927, 46.26692533493042, 59.873444214463234, 60.552539974451065, 47.14203737676144, 4.808746464550495, 1.3480173284187913, 11.65744861587882, 12.968807648867369, 2.222233568318188, 11.249723844230175, 43.21425274014473, 58.870773017406464, 57.29768022894859, 54.08085644245148, 50.81461250782013, 54.22857731580734, 53.856862261891365, 54.13379140198231, 55.15975534915924, 49.53541114926338, 45.6808789819479, 49.677367731928825, 53.805857598781586, 52.144921123981476, 50.31571067869663, 51.71467401087284, 51.90043464303017, 50.11650636792183, 47.49253436923027, 45.7920154184103, 43.019273802638054, 42.22694791853428, 41.08944855630398, 44.69732455909252, 46.26458466053009, 43.703609481453896, 39.23477567732334, 39.39665079116821, 39.603735879063606, 41.90919756889343, 39.59282286465168, 39.83521565794945, 41.722646579146385, 39.6000424772501, 41.25682197511196, 44.02633756399155, 41.921805292367935, 40.00438638031483, 39.367643147706985, 40.912883430719376, 41.76855571568012, 41.87450923025608, 41.20929412543774, 41.32170729339123, 40.8923227339983, 41.03086329996586, 41.34658835828304, 41.09278477728367, 42.10782431066036, 43.53528991341591, 54.53020133078098, 55.76980121433735, 53.01238417625427, 54.37752552330494, 46.45936980843544, 58.491777554154396, 48.17596949636936, 46.27504549920559, 57.01913617551327, 56.09521575272083, 54.69811052083969, 49.35674473643303, 46.233194544911385, 44.61343266069889, 45.89593984186649, 49.08137731254101, 48.95112790167332, 45.599160566926, 46.83446288108826, 42.69684590399265, 39.91351045668125, 39.63481441140175, 42.68535152077675, 40.95150835812092, 40.67407004535198, 42.191830202937126, 39.131550416350365, 39.92299474775791, 42.62908793985844, 40.751935467123985, 39.14157047867775, 38.356293216347694, 39.14028234779835, 41.19088031351566, 39.54632095992565, 38.631102070212364, 40.35355344414711, 43.08933824300766, 46.344980746507645, 47.34350636601448, 50.66101714968681, 51.158285066485405, 54.75778631865978, 50.37091411650181, 48.85343134403229, 52.65265367925167, 53.12627546489239, 51.45354062318802, 51.77924394607544, 50.680217519402504, 52.185601741075516, 52.218614369630814, 51.49235554039478, 51.4121912419796, 49.69752565026283, 49.732738360762596, 50.010093078017235, 47.91517049074173, 50.54507777094841, 55.51135428249836, 52.90738821029663, 56.73899620771408, 52.685723304748535, 50.28851933777332, 20.82855384796858, 2.490638103336096, 7.9449590016156435, 19.246421344578266, 13.46610501408577, 9.76914944127202, 0.7152024318929762, 3.342953030951321, 52.40575432777405, 56.61375492811203, 45.597275868058205, 34.64997969567776, 48.19372974336147, 59.540042504668236, 22.502692714333534, 0.32677424198482186, 0.21036097226897255, 0.1457050518365577, 0.1324221075628884, 0.11463419330539182, 0.21104781510075554, 0.13183100178139284, 0.178809602803085, 0.16275120433419943, 0.08932974058552645, 0.16795904753962532, 0.10713447933085263, 0.13434654101729393, 0.131646518711932], [0.05580343451583758, 0.04211289902741555, 0.05573099719185848, 0.04676912983995862, 0.04286110633984208, 0.009333105390396668, 0.06813447049353272, 0.04649942224205006, 0.015773701343277935, 0.012222825280332472, 0.04608304770954419, 0.030658461910206825, 0.034210080120828934, 0.05398041925218422, 0.024605266116850544, 0.033892455758177675, 0.06583506692550145, 0.5073712777812034, 10.056897550821304, 39.36153307557106, 38.83247226476669, 26.141702346503735, 37.766971439123154, 35.06636135280132, 38.031653836369514, 48.66282217204571, 50.2169843763113, 10.641945507377386, 0.08419798235991038, 3.631958873011172, 4.88500552251935, 0.6949849042575806, 4.283645041286945, 37.078034207224846, 53.914451971650124, 54.86869856715202, 48.053904846310616, 49.64942403137684, 47.89798021316528, 53.52419011294842, 50.014527440071106, 48.46574954688549, 46.14219322800636, 46.875417083501816, 45.62335766851902, 49.91088040173054, 48.72319333255291, 46.61416210234165, 46.51702791452408, 43.79891976714134, 44.80650030076504, 43.038869351148605, 42.09002986550331, 38.327703550457954, 36.53313584625721, 37.298939153552055, 37.709450125694275, 35.86781054735184, 36.614185497164726, 36.513631492853165, 37.07545034587383, 37.65934981405735, 37.385418713092804, 36.55695676803589, 36.602067947387695, 36.30857169628143, 36.62852592766285, 36.428352668881416, 40.75763896107674, 37.72138528525829, 37.96725869178772, 36.07033967971802, 38.05498078465462, 38.27209733426571, 37.002083882689476, 38.26861672103405, 36.22010104358196, 39.01134766638279, 41.36914774775505, 41.362334713339806, 40.20650893449783, 37.572547271847725, 37.12311878800392, 43.951261192560196, 51.5648290514946, 50.072451531887054, 50.30311055481434, 45.73899686336517, 60.55521123111248, 44.358641132712364, 46.53815858066082, 55.3843042999506, 50.030972957611084, 47.73503355681896, 42.765929996967316, 42.005131021142006, 42.660128474235535, 44.564514085650444, 44.19747278094292, 45.75443923473358, 43.653820753097534, 43.56816574931145, 39.372119307518005, 36.663898229599, 37.19455115497112, 38.40096361935139, 36.86002470552921, 37.41710141301155, 37.42105320096016, 38.12453605234623, 36.92416526377201, 37.043338268995285, 36.29618816077709, 35.165612027049065, 35.804737731814384, 35.946941301226616, 35.901909917593, 35.59133358299732, 34.991604164242744, 36.73384107649326, 35.79136244952679, 36.60492539405823, 40.48352926969528, 45.0775283575058, 44.79227766394615, 47.44528770446777, 47.52491243183613, 46.1562904715538, 47.49159201979637, 49.189584106206894, 49.293508529663086, 48.806591257452965, 48.448988646268845, 47.19824776053429, 51.95344939827919, 42.53221593797207, 48.06380331516266, 50.88841214776039, 47.58032105863094, 50.23595675826073, 47.7926080673933, 48.142143711447716, 47.10153914988041, 51.04204170405865, 52.199904173612595, 52.166709154844284, 44.93782885372639, 14.293464068323374, 0.7262927899137139, 4.62521156296134, 11.410850398242474, 4.196777902543545, 2.2719033155590296, 0.1291116836364381, 1.9266692781820893, 37.64587573707104, 36.89365290105343, 29.90447323769331, 22.16651525348425, 36.56091995537281, 39.25716407597065, 6.023044930770993, 0.017909921480168123, 0.029820040981576312, 0.042814176631509326, 0.009817707414185861, 0.04273996928532142, 0.0711784782470204, 0.05109450008603744, 0.15128857019590214, 0.08890812649042346, 0.049369674670742825, 0.025957602047128603, 0.03640103364887182, 0.1150217057147529, 0.04160278011113405, 0.03808397967077326, 0.09046292587299831, 0.04632266121916473, 0.060357556940289214, 0.060224174449103884, 0.06180597687489353, 0.047299368379754014, 0.019798679895757232, 0.045539665734395385, 0.07830795701011084, 0.06739184042089619, 0.03244415456720162, 0.051651066314661875, 0.09153457227512263, 0.015848830807954073, 0.037900498500675894, 0.06050345204130281, 0.5760599544737488, 14.737365748733282, 47.93338671326637, 44.19547788798809, 29.32510692626238, 29.225974045693874, 37.58078522980213, 45.9410510212183, 54.660006165504456, 50.946708619594574, 10.920163728296757, 0.20534625073196366, 3.958970750682056, 9.076957684010267, 1.233021724037826, 6.3123025093227625, 39.7239576280117, 55.41023410856724, 56.34594149887562, 50.9109715372324, 51.281561851501465, 50.714769065380096, 55.27330085635185, 50.613819882273674, 48.32959525287151, 47.78325296938419, 46.366882771253586, 46.607656851410866, 51.803817227482796, 49.9217364192009, 48.6929127573967, 48.30593392252922, 46.046993136405945, 45.735979825258255, 44.53373573720455, 42.96601586043835, 41.074766144156456, 40.56079052388668, 39.25444342195988, 40.363368317484856, 39.29675415158272, 38.281775414943695, 38.47409449517727, 38.91701392829418, 39.555311277508736, 38.054327219724655, 38.57643060386181, 37.44908429682255, 38.340128883719444, 38.34528140723705, 39.34272028505802, 42.41148881614208, 39.80305418372154, 40.60258828103542, 39.22127120196819, 40.4099690169096, 39.52600724995136, 37.67901375889778, 39.49620544910431, 38.21733087301254, 39.801572263240814, 42.35446907579899, 41.932934895157814, 40.979391261935234, 39.61857408285141, 39.606958106160164, 45.34603714942932, 52.95378752052784, 50.602526888251305, 51.72290816903114, 47.65974059700966, 54.43351551890373, 47.27926701307297, 47.816903963685036, 56.034411415457726, 52.32808269560337, 49.693266078829765, 45.47745309770107, 43.18904489278793, 43.65216784179211, 46.169323772192, 46.70039847493172, 45.506928116083145, 44.58122558891773, 44.27348010241985, 39.62335802614689, 38.34601856768131, 38.828854858875275, 38.55617009103298, 39.436879232525826, 38.5113400965929, 38.51157568395138, 39.507452845573425, 38.293095007538795, 38.926141038537025, 39.05274264514446, 38.058905974030495, 38.1071861833334, 38.40152218937874, 38.704008758068085, 37.66751177608967, 36.75223208963871, 37.23632611334324, 36.94205470383167, 38.74714784324169, 42.35630817711353, 46.33103929460049, 47.4195820838213, 49.7827322781086, 48.955911844968796, 47.78045251965523, 49.40629027783871, 50.46563543379307, 50.21798372268677, 49.48395051062107, 50.373965352773666, 49.68399837613106, 54.55572076141834, 47.413149029016495, 51.72469027340412, 52.13718093931675, 50.3309478610754, 50.713944509625435, 50.477707386016846, 49.22413185238838, 49.58193585276604, 52.31743186712265, 54.670656993985176, 51.94681115448475, 47.67024703323841, 16.229343339800835, 1.7418528953567147, 4.915294172242284, 10.017360672354698, 7.385053345933557, 4.068498685956001, 0.1696445539710112, 2.805267870426178, 41.997816413640976, 43.592533841729164, 34.48302045464516, 24.860261008143425, 42.33236946165562, 46.10110983252525, 9.245446342974901, 0.10923152149189264, 0.06527838937472552, 0.05835774354636669, 0.020991596938984003, 0.017160706702270545, 0.1227900994126685, 0.018953069411509205, 0.06327612689347006, 0.04018076208012644, 0.03320336792967282, 0.015630372217856348, 0.04678877448895946, 0.05622397249680944, 0.03860513061226811, 0.2206226927228272, 0.2091453195316717, 0.16018080554204062, 0.140891645278316, 0.143615594424773, 0.1839956862386316, 0.1312123771640472, 0.2057027191040106, 0.17415721260476857, 0.18430247524520382, 0.12838118767831475, 0.10530243584071286, 0.09836368903052062, 0.2111443833564408, 0.16786185587989166, 0.10844747957889922, 0.11312203772831708, 0.6996929703745991, 17.74155769497156, 55.940898433327675, 53.441403955221176, 36.642284989356995, 47.7342963963747, 47.92422540485859, 49.81970429420471, 57.6442938297987, 62.272924259305, 13.7103521078825, 0.30429969483520836, 9.163576886057854, 9.647338427603245, 1.467702118679881, 6.961108194664121, 42.388997822999954, 56.936186626553535, 58.82914625108242, 53.19056801497936, 54.24525462090969, 51.00407414138317, 57.43153564631939, 51.69838808476925, 49.36065852642059, 47.787147760391235, 48.72167721390724, 46.63227193057537, 53.25420320034027, 52.57606498897076, 50.05416311323643, 49.461744502186775, 48.191092684865, 47.50834912061691, 47.92786940932274, 47.02553942799568, 42.96708360314369, 41.38135269284248, 41.023966670036316, 41.79973304271698, 40.04084922373295, 40.19271947443485, 40.030608773231506, 39.286547899246216, 41.940070912241936, 39.35105703771114, 40.90394631028175, 39.09171715378761, 40.0934612005949, 39.94530335068703, 40.14485344290733, 44.78735312819481, 41.17537334561348, 41.504846066236496, 40.921037793159485, 41.93836100399494, 42.64416553080082, 40.4800296574831, 42.259804755449295, 41.075005531311035, 43.11306416988373, 45.11868394911289, 43.512339144945145, 43.79146456718445, 41.97840325534344, 41.59845784306526, 46.80715374648571, 55.58251306414604, 51.73904970288277, 53.846709206700325, 45.61490312218666, 58.525287955999374, 49.13937360048294, 48.44189442694187, 57.9279638081789, 54.213222339749336, 51.38568006455898, 48.44812989234924, 45.69577418267727, 45.360772758722305, 47.9389838129282, 48.75288113951683, 48.26885551214218, 48.68576914072037, 46.49498529732227, 42.60203339159489, 41.285955011844635, 42.084520161151886, 41.66199803352356, 39.53181713819504, 41.63712076842785, 41.5341766923666, 42.21165373921394, 39.66424003243446, 40.677786245942116, 39.85107980668545, 39.55387495458126, 39.519251212477684, 40.64109541475773, 40.90433768928051, 39.20977681875229, 38.68436001241207, 40.62600262463093, 40.49932882189751, 40.19385561347008, 44.17498558759689, 47.58157879114151, 48.08968372642994, 51.19851350784302, 50.89381545782089, 48.48364278674126, 48.571691662073135, 52.66911059617996, 53.942433670163155, 51.82075671851635, 53.66779960691929, 51.25888466835022, 54.41374137997627, 47.98087276518345, 54.43858064711094, 52.827942073345184, 52.53896377980709, 54.21972379088402, 52.56643630564213, 52.0500174164772, 52.71783538162708, 54.98122952878475, 57.88689561188221, 52.97797702252865, 48.86512711644173, 17.8045754134655, 2.0881204772740602, 9.033810999244452, 21.42132394015789, 10.979380700737238, 7.265585856512189, 0.3580337989842519, 2.7919417480006814, 45.69097883999348, 48.39648686349392, 40.64689390361309, 34.07891973853111, 48.78359109163284, 53.086039423942566, 11.196035575121641, 0.15276198566425592, 0.19781017152126878, 0.15599040227243677, 0.12738408258883283, 0.13986114354338497, 0.2563180070137605, 0.15275236743036658, 0.20506470958935097, 0.15124457568163052, 0.14334371604491025, 0.08847080855048262, 0.16595554567174986, 0.2302447857800871, 0.2077239434584044], [0.12290475380723365, 0.016041774360928684, 0.024945143777586054, 0.02118028798577143, 0.06669780617812648, 0.033848906532512046, 0.036059764461242594, 0.05381543611292727, 0.052285135025158525, 0.03154132820782252, 0.044622063214774244, 0.03862216661218554, 0.02410500106634572, 0.05187679795199074, 0.03635572924395092, 0.07029495143797249, 0.031487388914683834, 0.028304566149017774, 6.53177160769701, 37.23980292677879, 39.2283920198679, 44.189196825027466, 71.87683671712875, 59.507018476724625, 38.96872155368328, 41.33895456790924, 50.682516396045685, 13.862833175808191, 0.11428749901824631, 3.272927775979042, 10.736090205609798, 1.3932794309221208, 4.869847660884261, 33.8345168530941, 53.190852999687195, 54.19545069336891, 49.64884266257286, 53.66957411170006, 50.636649057269096, 50.71679815649986, 48.45667943358421, 45.21847419440746, 47.492427974939346, 45.902475491166115, 46.43503971397877, 48.71249310672283, 48.172568678855896, 48.26019197702408, 48.533283323049545, 45.13313077390194, 45.156203135848045, 42.85716690123081, 41.03394113481045, 39.72980551421642, 39.869736805558205, 37.77474582195282, 37.41912670433521, 36.74199923872948, 36.87982924282551, 37.91760675609112, 38.480709940195084, 36.726321280002594, 36.61148004233837, 36.06498196721077, 36.99425630271435, 40.44458135962486, 37.833695858716965, 39.104788452386856, 36.662549301981926, 37.81929463148117, 38.1029000133276, 35.710711777210236, 36.12093396484852, 36.98136359453201, 36.82723626494408, 36.90140828490257, 36.04047328233719, 40.966931730508804, 44.99860659241676, 45.397140607237816, 44.88481029868126, 41.8691249191761, 38.80291365087032, 40.42796865105629, 46.231959611177444, 49.04379352927208, 49.13481384515762, 51.07674144208431, 46.86217859387398, 39.677326530218124, 50.4978197067976, 53.27243462204933, 49.62150312960148, 46.12462677061558, 41.51204288005829, 42.70242020487785, 41.439364179968834, 46.76144599914551, 45.45926347374916, 46.408239752054214, 44.46321152150631, 43.71412351727486, 37.842819169163704, 34.650568664073944, 36.00730486214161, 35.65930053591728, 36.23765990138054, 38.05007144808769, 36.607813239097595, 37.81292237341404, 37.85509631037712, 37.61664770543575, 37.38849274814129, 37.27250017225742, 36.4931695908308, 36.76527678966522, 35.672850608825684, 35.50269953906536, 34.98974226415157, 35.10366775095463, 36.55589282512665, 37.79844895005226, 40.18338717520237, 44.053160324692726, 45.21434001624584, 49.474169835448265, 49.855783358216286, 47.46666915714741, 46.134297251701355, 47.24961340427399, 46.69434919953346, 48.94130542874336, 49.457500129938126, 49.663570672273636, 40.00215210020542, 44.37591500580311, 47.88640223443508, 50.36108024418354, 51.624516248703, 49.439732283353806, 49.97434839606285, 47.30189859867096, 52.32095807790756, 52.433337047696114, 54.413726180791855, 46.53380401432514, 38.311273232102394, 10.367327593266964, 0.7373064395505935, 2.804337157867849, 7.165692066773772, 7.465958129614592, 3.7428321735933423, 0.07717933593085036, 3.972598956897855, 38.7147431820631, 34.56584461033344, 37.94004835188389, 31.565008834004402, 44.951694309711456, 37.82677263021469, 2.639048877172172, 0.08605766342952847, 0.07971066806931049, 0.05259740479232278, 0.037694901329814456, 0.07125301213818602, 0.05368660298699979, 0.05423068629170302, 0.01965121329703834, 0.04809945552551653, 0.007412272279907484, 0.06270974947256036, 0.045403585536405444, 0.07138000102713704, 0.07702350718318485, 0.06070621049730107, 0.020459248844417743, 0.03340372182719875, 0.056857670133467764, 0.05304985141265206, 0.0149648095430166, 0.03811729467997793, 0.05327072569343727, 0.045802827589795925, 0.10413281852379441, 0.06869260265375488, 0.0383074588899035, 0.036781647795578465, 0.03637593792518601, 0.035984451315016486, 0.08338515253853984, 0.024571633839514107, 0.08183769299648702, 9.28005488589406, 45.62130957841873, 45.88267855346203, 46.54662072658539, 63.885097950696945, 54.278316646814346, 41.53551422059536, 46.85653209686279, 60.01405946910381, 16.320422552525997, 0.08083335938863456, 2.9065065504983068, 8.212880250066519, 1.0819459869526327, 5.809459341689944, 33.79348665475845, 53.01533281803131, 57.21668377518654, 52.70214602351189, 54.404747262597084, 51.362615302205086, 52.67213523387909, 49.45028431713581, 45.79315535724163, 48.692156597971916, 47.56028853356838, 47.81993240118027, 51.165702268481255, 50.07389925420284, 49.69219073653221, 49.36256222426891, 48.027766048908234, 46.592358872294426, 44.10403199493885, 43.1355095654726, 41.427497416734695, 39.97271507978439, 37.76352122426033, 36.756681650877, 38.46749804913998, 37.14438244700432, 39.338418915867805, 39.654200971126556, 39.74062353372574, 37.82484993338585, 36.67128503322601, 37.697685956954956, 40.614405646920204, 39.4233101606369, 40.20872041583061, 39.11497190594673, 39.22601714730263, 38.655302971601486, 36.7806051671505, 39.20604541897774, 38.4748088568449, 37.540758177638054, 39.870671555399895, 37.85489872097969, 42.10110627114773, 46.23414449393749, 46.24806694686413, 45.36525271832943, 42.34271250665188, 39.34221871197224, 43.05125288665295, 49.55990843474865, 52.289104387164116, 50.31254544854164, 51.94963060319424, 45.0024139881134, 44.163445606827736, 50.96566580235958, 55.417708307504654, 50.61199598014355, 48.777811601758, 41.93655230104923, 44.520345255732536, 42.82123602926731, 48.050842210650444, 47.31091931462288, 48.069632202386856, 45.202199667692184, 45.994848534464836, 39.72176894545555, 37.16894052922726, 38.58457736670971, 37.418708726763725, 37.095406875014305, 39.61529105901718, 38.341132029891014, 39.81319963932037, 39.75961871445179, 38.33763241767883, 38.39885473251343, 37.463025748729706, 38.348670825362206, 39.136919528245926, 37.1414490044117, 37.37479068338871, 36.912720277905464, 38.29785235226154, 37.86550775170326, 39.02707502245903, 44.15665157139301, 45.979368165135384, 47.766849249601364, 50.31872771680355, 51.0669531673193, 46.895935982465744, 47.56129167973995, 48.69838446378708, 46.97373680770397, 50.7638206332922, 52.39383436739445, 49.989308193325996, 43.34154970943928, 45.63230238854885, 50.12275703251362, 51.750084310770035, 53.30398052930832, 52.5480642914772, 52.11438596248627, 49.80356656014919, 53.933876529335976, 52.9294004291296, 55.4932102560997, 48.2535233348608, 42.56882317364216, 12.645881026983261, 1.683185468427837, 6.758829848840833, 8.516245521605015, 9.346076343208551, 3.617251762188971, 0.048284573131240904, 3.798381155356765, 42.0161048322916, 39.274000972509384, 36.321460604667664, 32.591272965073586, 50.20421706140041, 44.11812923848629, 4.235312584787607, 0.14040921960258856, 0.017072838272724766, 0.031056603729666676, 0.034920935140689835, 0.008948269351094496, 0.014655081631644862, 0.019646573018690106, 0.015110825243027648, 0.010959944120259024, 0.0716106679465156, 0.044813054919359274, 0.07042568817269057, 0.07038410563836806, 0.06489757855888456, 0.14918492292053998, 0.12723036896204576, 0.10393667631433345, 0.1505598850781098, 0.17828803625889122, 0.14031437312951311, 0.1600264833541587, 0.10069129421026446, 0.14885680458974093, 0.22549339308170602, 0.12560574832605198, 0.2499272843124345, 0.1773677731398493, 0.18003702600253746, 0.1419672992778942, 0.3274908597813919, 0.12734385818475857, 0.13399145303992555, 12.291046567261219, 54.974199905991554, 51.80917114019394, 56.36131927371025, 77.3356693983078, 64.2941763997078, 49.241010546684265, 49.278457537293434, 60.98103538155556, 17.538000717759132, 0.26465285976883024, 8.693545907735825, 19.978674352169037, 3.849515486508608, 7.480043498799205, 38.04996505379677, 56.03650130331516, 57.578295171260834, 54.94340255856514, 57.30965718626976, 53.55878345668316, 55.36961808800697, 50.69759398698807, 47.60958328843117, 48.428614139556885, 48.28734152019024, 48.80950950086117, 52.968173548579216, 52.11941309273243, 52.619960233569145, 51.804527789354324, 50.30887484550476, 49.47475880384445, 46.737784668803215, 43.98545555770397, 43.62569846212864, 42.14870251715183, 40.99246256053448, 40.118931233882904, 40.32379724085331, 39.15801219642162, 41.220450326800346, 42.74891071021557, 42.770645543932915, 39.44481700658798, 37.54042759537697, 38.64316642284393, 43.61675374209881, 41.32277503609657, 43.722517266869545, 41.25302217900753, 41.719602942466736, 41.467319279909134, 38.31816986203194, 39.95174780488014, 40.50851672887802, 39.91884157061577, 40.811326280236244, 39.82675351202488, 45.723752081394196, 49.033971056342125, 49.55088011920452, 49.40189391374588, 44.88905847072601, 42.651149556040764, 43.12251806259155, 51.49221494793892, 52.31642872095108, 52.159987315535545, 51.00960284471512, 55.74970029294491, 44.95249226689339, 53.036414086818695, 57.19971388578415, 52.79446966946125, 50.598624497652054, 43.63554373383522, 46.351497396826744, 44.14461001753807, 50.479550287127495, 49.16654214262962, 52.612242847681046, 48.6628145724535, 48.49387563765049, 40.486405715346336, 39.29386630654335, 39.35835264623165, 38.3547542989254, 39.77561205625534, 41.097359731793404, 41.380436941981316, 42.24624328315258, 42.22002848982811, 41.059715151786804, 40.662556663155556, 39.39996041357517, 39.977537021040916, 40.72469472885132, 38.808145970106125, 38.37163299322128, 39.94828999042511, 39.9537692964077, 40.70835180580616, 41.705957874655724, 44.55248773097992, 47.29108437895775, 49.33756336569786, 52.50669211149216, 53.33755172789097, 49.3601493537426, 48.61800737679005, 49.608276039361954, 47.26443260908127, 53.2429976016283, 52.42055833339691, 52.366890013217926, 45.43109558522701, 46.95064924657345, 50.722794234752655, 54.481685534119606, 56.77808091044426, 53.88058438897133, 55.297467559576035, 52.195762395858765, 57.29987271130085, 55.20119972527027, 57.57558211684227, 47.97299958765507, 43.51507879793644, 15.482421219348907, 2.016935097053647, 9.160952176898718, 17.562328912317753, 18.777672797441483, 11.020123064517975, 0.13866020017303526, 4.877829132601619, 47.40427650511265, 47.92593531310558, 50.68188562989235, 42.19166301190853, 58.21914978325367, 53.425923585891724, 5.827130768448114, 0.18870194151531905, 0.15836337493965402, 0.1232524128863588, 0.1494557474507019, 0.20643924130126834, 0.11042129553970881, 0.08794173147180118, 0.1556913019157946, 0.13508583884686232, 0.14382409339305013, 0.24062855984084308, 0.1651149001554586, 0.20349650701973587, 0.14244487130781636], [0.05994625127641484, 0.040421251324005425, 0.013043899434705963, 0.041940078808693215, 0.045641788965440355, 0.060779530977015384, 0.024863414764695335, 0.05287244843202643, 0.01725507820083294, 0.012015446027362486, 0.001323116300682159, 0.02982538630021736, 0.0410029503836995, 0.022795435106672812, 0.021692826303478796, 0.015996627662389074, 0.005079231332274503, 0.06434076000005007, 1.995986821129918, 25.060903541743755, 45.56655451655388, 39.799900352954865, 51.68573096394539, 66.3836918771267, 55.47358050942421, 33.18238444626331, 44.125774428248405, 24.562041610479355, 0.07776060825563036, 2.4225471820682287, 6.638516904786229, 3.494789795950055, 4.852028517052531, 31.120371893048286, 49.961394891142845, 53.03888015449047, 52.09354028105736, 52.73569442331791, 50.61989575624466, 44.46245156228542, 41.63599982857704, 46.37709282338619, 47.75396414101124, 48.32343578338623, 47.73097537457943, 48.02198275923729, 47.9137721657753, 50.1206861436367, 46.65409415960312, 47.5998330116272, 46.20402731001377, 43.72211068868637, 43.2400381565094, 40.870135724544525, 39.896981343626976, 38.36130894720554, 35.71673445403576, 36.59245826303959, 36.97233907878399, 36.382644921541214, 37.563792541623116, 36.27425953745842, 37.38993667066097, 37.73029960691929, 41.3479220867157, 40.765595734119415, 38.015352711081505, 37.218976244330406, 36.887197047472, 37.02995538711548, 36.55935063958168, 36.49800293147564, 35.84018222987652, 35.86507469415665, 37.07361504435539, 35.83714999258518, 36.76633693277836, 45.04304900765419, 48.74468877911568, 50.178184658288956, 49.24425557255745, 42.14635044336319, 39.168279245495796, 40.88551349937916, 44.246452152729034, 49.31651249527931, 52.08158992230892, 47.86740705370903, 28.91272835433483, 40.00259667634964, 49.29764270782471, 52.269345447421074, 47.7589912712574, 45.9730339050293, 43.279309049248695, 44.990820810198784, 48.903755843639374, 50.024695694446564, 47.28657782077789, 47.67695367336273, 45.83339519798756, 46.70503422617912, 41.474360302090645, 35.86612343788147, 36.34968549013138, 37.04134717583656, 37.14055985212326, 38.03484946489334, 36.636832281947136, 37.28324979543686, 37.49650575220585, 36.75077676773071, 37.064244747161865, 35.39487272500992, 37.784860879182816, 37.06625483930111, 34.27857622504234, 35.67529387772083, 36.82595573365688, 36.12192191183567, 37.551344409585, 39.59142453968525, 42.84200191497803, 45.23247264325619, 48.01142692565918, 48.07641103863716, 48.342047184705734, 45.90471737086773, 45.994856134057045, 47.192149087786674, 48.31520162522793, 46.45136743783951, 47.63959027826786, 43.29972915351391, 47.24028490483761, 47.29168854653835, 44.641589149832726, 47.35177472233772, 48.99350322782993, 49.45642478764057, 53.12084175646305, 47.54530593752861, 50.83411306142807, 49.51863884925842, 50.42902819812298, 41.60307839512825, 33.68533305823803, 13.51482504978776, 1.5257879393175244, 6.455714888870716, 6.427044002339244, 5.030763801187277, 2.458064826205373, 0.07516012279666029, 7.743009813129902, 42.70860627293587, 38.192541003227234, 25.585450194776058, 21.561431922018528, 42.68028639256954, 31.209353618323803, 1.12074154894799, 0.09448971526580863, 0.04920920007862151, 0.0773475511232391, 0.013053949041932356, 0.047488731070188805, 0.023721188263152726, 0.021606219524983317, 0.03198424194124527, 0.005309442294674227, 0.02617253914650064, 0.05820368853164837, 0.015167978963290807, 0.04783327312907204, 0.04940140890539624, 0.03776927194849122, 0.024762219218246173, 0.05252885261143092, 0.06528568468638696, 0.012303613621043041, 0.00932282015128294, 0.004729959937321837, 0.04265487092197873, 0.006919739944351022, 0.04461843411263544, 0.024972512328531593, 0.019613443546404596, 0.015590838011121377, 0.02326749854546506, 0.024073209315247368, 0.06496202666312456, 0.006771345661036321, 0.022151621997181792, 3.282095496542752, 34.191994071006775, 51.74804002046585, 45.062321573495865, 59.65024419128895, 67.29159235954285, 52.41959698498249, 37.845486626029015, 48.88669855892658, 23.804276771843433, 0.018215972049802076, 2.619591783732176, 7.986280359327793, 3.7154563050717115, 6.3874696008861065, 35.37640191614628, 51.51863493025303, 53.517259284853935, 53.57427902519703, 53.824970573186874, 51.49653151631355, 45.71474276483059, 45.11756680905819, 46.69957011938095, 49.39699977636337, 48.813202902674675, 49.03738707304001, 50.163365453481674, 51.292151883244514, 51.2469495087862, 50.192555487155914, 50.16771242022514, 46.57952316105366, 44.796970412135124, 44.751547649502754, 42.43149474263191, 43.18358838558197, 39.72746483981609, 37.26168215274811, 39.43185210227966, 38.346596136689186, 37.71709531545639, 39.47301909327507, 37.68615737557411, 39.414943009614944, 39.71321180462837, 43.56275483965874, 42.38172881305218, 39.594490975141525, 38.8031530380249, 39.137991070747375, 38.46832640469074, 37.44251064956188, 37.76068277657032, 38.24357606470585, 37.505910247564316, 38.63747052848339, 37.85043016076088, 38.85278217494488, 46.57658211886883, 51.743009090423584, 52.613124400377274, 48.80784898996353, 43.73664490878582, 40.51488138735294, 42.91689209640026, 46.28924913704395, 49.70252238214016, 53.797855228185654, 51.09490446746349, 31.2587433680892, 41.63111709058285, 50.75065813958645, 53.2158974558115, 51.21344290673733, 48.136140033602715, 44.48518954217434, 46.258003413677216, 50.04535138607025, 51.98005177080631, 48.56121942400932, 48.59309211373329, 47.922488898038864, 47.31963984668255, 41.954578533768654, 36.61501005291939, 36.77775152027607, 39.235455840826035, 39.1932363063097, 40.710757076740265, 38.757202103734016, 37.89028242230415, 39.20387573540211, 37.468900233507156, 38.06566961109638, 37.72469110786915, 38.717102855443954, 38.53669993579388, 37.00506292283535, 37.11128242313862, 36.35103441774845, 37.7488312125206, 38.366077691316605, 41.4855583012104, 44.554421827197075, 47.227608785033226, 48.46989132463932, 49.341237768530846, 50.21354176104069, 46.489969566464424, 47.28056654334068, 47.617608457803726, 49.64516445994377, 47.995216995477676, 48.03335554897785, 43.32538537681103, 47.611433789134026, 48.88176642358303, 45.86403675377369, 49.393587559461594, 51.26772679388523, 52.00584098696709, 54.73347142338753, 50.44481635093689, 51.903314888477325, 50.70084661245346, 51.93132698535919, 44.133655205368996, 37.0553570240736, 15.647947937250137, 1.0020447056740522, 8.043142408132553, 5.085168806836009, 9.468461126089096, 3.624067883938551, 0.18304236786207184, 7.881396487355232, 45.2945651113987, 41.24780125916004, 34.20114018023014, 28.635221645236015, 48.49419862031937, 39.98822204768658, 1.7961896234191954, 0.13819472515024245, 0.038239125642576255, 0.024864524275471922, 0.016491178175783716, 0.030885449632478412, 0.03893026179866865, 0.05014312613639049, 0.02129665488610044, 0.05196897269343026, 0.022765164758311585, 0.03541442994901445, 0.014081116678426042, 0.009969182538043242, 0.016718969272915274, 0.21538425819016993, 0.07537991725257598, 0.13817927363561466, 0.17467775498516858, 0.17944063612958416, 0.15122617041924968, 0.08190975553588942, 0.13917050091549754, 0.06841081660240889, 0.11931294458918273, 0.131095785764046, 0.10082951921503991, 0.1600113435415551, 0.11550078430445865, 0.14848556747892871, 0.22343207790981978, 0.13312486204085872, 0.12360859182081185, 4.571160413324833, 41.540518552064896, 60.22103436291218, 51.62809185683727, 61.21492423117161, 69.89959761500359, 61.68915018439293, 43.49271319806576, 53.56253005564213, 29.983290508389473, 0.15063319442560896, 6.58016961067915, 16.070842444896698, 5.0768434535712, 8.061249386519194, 40.12155309319496, 53.38752664625645, 55.05643129348755, 54.87319752573967, 54.2745016515255, 51.600687727332115, 45.89838691055775, 44.12420891225338, 47.157985121011734, 48.05395424365997, 49.845174327492714, 50.259587690234184, 50.86462542414665, 53.20825606584549, 53.94184470176697, 54.188215881586075, 53.14623959362507, 50.53029276430607, 47.92407341301441, 46.080093160271645, 44.25451532006264, 44.67069938778877, 41.876948699355125, 39.48083907365799, 42.29966081678867, 39.57521080970764, 40.1846981048584, 41.038732677698135, 38.35931025445461, 42.477297484874725, 40.68779870867729, 44.634187147021294, 45.45464672148228, 42.33071655035019, 41.62307672202587, 41.47814869880676, 40.496068596839905, 38.26365418732166, 39.83901925384998, 39.369117468595505, 39.922979548573494, 39.89606559276581, 39.10428687930107, 41.60827651619911, 49.162126779556274, 53.224845975637436, 55.32292239367962, 52.8434756398201, 45.85537701845169, 43.716000616550446, 45.781626775860786, 46.385851353406906, 52.53026604652405, 55.28821125626564, 52.641277089715004, 37.41030737757683, 43.81549447774887, 51.34380251169205, 55.239353477954865, 52.46005341410637, 50.114127695560455, 47.83801183104515, 48.09140123426914, 51.90690569579601, 54.529695957899094, 51.47594042122364, 49.844026789069176, 50.20715430378914, 51.65783666074276, 46.11747935414314, 39.21215549111366, 39.64627459645271, 41.4804931730032, 40.546833872795105, 43.57561714947224, 39.81218509376049, 40.880364775657654, 41.492470130324364, 40.42543798685074, 40.41993968188763, 37.55425505340099, 41.27645172178745, 40.50088293850422, 38.79644639790058, 38.320210352540016, 39.521747678518295, 40.111514031887054, 40.44052317738533, 42.7470488101244, 46.3821617513895, 47.93677233159542, 51.203768625855446, 50.91818355023861, 51.93011485040188, 48.36701184511185, 49.87334221601486, 46.99167564511299, 53.00389163196087, 49.20000694692135, 50.50003118813038, 45.188976377248764, 48.69714193046093, 48.453704193234444, 47.218037098646164, 48.99517893791199, 52.37640470266342, 51.11433282494545, 57.11055926978588, 51.20625749230385, 52.935852482914925, 52.34685368835926, 53.06037940084934, 44.9190578609705, 41.60559006035328, 20.14916740357876, 2.4509611073881388, 13.194319847971201, 14.145366065204144, 14.707610495388508, 7.342811012640595, 0.1768948617973365, 9.694476798176765, 51.26768119633198, 50.007786601781845, 36.96262300014496, 31.18100143969059, 56.709502190351486, 44.88960184156895, 3.489993028342724, 0.2770094107836485, 0.14837535854894668, 0.22329044644720852, 0.1359817446791567, 0.13496155879693106, 0.15227319236146286, 0.20581410062732175, 0.1063522779440973, 0.08555922962841578, 0.1610495339264162, 0.13284671993460506, 0.1299303022096865, 0.1463064586278051, 0.1506504716235213], [0.06484344630734995, 0.054606164776487276, 0.0627676147269085, 0.017029309456120245, 0.04038591396238189, 0.037080477268318646, 0.005086992805445334, 0.008975262189778732, 0.023134177281463053, 0.0772732992481906, 0.04460296404431574, 0.02391516896750545, 0.03393011233129073, 0.05021268021664582, 0.06126070613390766, 0.0047780770819372265, 0.024294024224218447, 0.08405484433751553, 0.22105980286141858, 14.275683872401714, 51.93369805812836, 39.14859250187874, 34.03002396225929, 39.80444870889187, 52.712853848934174, 47.23614692687988, 53.70835483074188, 32.010629922151566, 1.5223511424846947, 1.9968391628935933, 1.7648619669489563, 5.215603457763791, 21.84232234954834, 30.334524661302567, 40.62690697610378, 52.213290855288506, 51.96430541574955, 47.911564484238625, 48.94456185400486, 47.77455523610115, 44.70721162855625, 47.730466201901436, 49.45425510406494, 49.12009343504906, 49.283636659383774, 49.366867393255234, 51.12332694232464, 48.07358779013157, 47.62443669140339, 48.20235528051853, 46.40229307115078, 43.635444939136505, 45.27070999145508, 43.04616875946522, 41.95395916700363, 40.139598324894905, 35.39066255092621, 36.16701789200306, 36.10684432089329, 38.505545407533646, 37.88065753877163, 38.09579059481621, 37.167884185910225, 37.19267025589943, 37.63149730861187, 38.05631831288338, 36.86084546148777, 35.50938718020916, 36.370443776249886, 38.71965631842613, 35.96898011863232, 36.31392940878868, 37.017381861805916, 37.117692679166794, 37.7729295194149, 36.81067295372486, 37.94232062995434, 48.263995572924614, 52.083866000175476, 48.79121348261833, 48.9038622379303, 46.262274384498596, 43.55069428682327, 40.65658338367939, 44.070962369441986, 45.20553968846798, 50.15600524842739, 45.94965375959873, 41.46676450967789, 44.49258394539356, 49.04680676758289, 52.93830335140228, 47.97214463353157, 50.25479234755039, 48.02977994084358, 51.311090067029, 47.77367748320103, 49.451067075133324, 51.16578586399555, 50.303167551755905, 45.875591933727264, 45.78335948288441, 42.51101687550545, 36.82951234281063, 35.09790726006031, 36.56544551253319, 35.811486169695854, 36.71359196305275, 36.69085018336773, 37.518970146775246, 37.126360014081, 36.28923453390598, 35.90054199099541, 35.93304544687271, 35.707538947463036, 35.64947046339512, 37.031513303518295, 36.03956513106823, 33.599655255675316, 36.885829120874405, 42.55442954599857, 45.04310600459576, 44.67053219676018, 46.9729882478714, 47.42659650743008, 47.819613218307495, 47.386018484830856, 45.71228429675102, 46.88839338719845, 48.955824449658394, 49.50234912335873, 48.66862066090107, 45.62255971133709, 48.76124829053879, 47.685385420918465, 46.919544115662575, 45.87012402713299, 46.07866443693638, 48.086833879351616, 46.805417239665985, 48.51282522082329, 47.855878472328186, 47.759595438838005, 48.63688476383686, 49.14112910628319, 37.92266808450222, 22.552012167871, 12.660524491220713, 0.88845205726102, 5.569475619122386, 7.908126153051853, 5.367943933233619, 2.663632370531559, 0.17275633465033025, 9.494669269770384, 43.19005183875561, 32.78720565140247, 25.39220206439495, 20.987989492714405, 43.65362696349621, 18.126184456050396, 0.22247010609135032, 0.10239980721962638, 0.09048628868185915, 0.04386395194160286, 0.04159361829806585, 0.024387538542214315, 0.009528510090603959, 0.07486149741453119, 0.0859502523962874, 0.025635398633312434, 0.03326628720969893, 0.0428617223224137, 0.027443647013569716, 0.08055191472521983, 0.0031143376099862508, 0.08692726754816249, 0.027421959603088908, 0.009470453733229078, 0.03505962398776319, 0.03400040113774594, 0.04637081176042557, 0.05235277065366972, 0.025857007640297525, 0.051526793686207384, 0.07238645717734471, 0.02837362299032975, 0.008835842327243881, 0.03629240920417942, 0.020506518085312564, 0.025386723500560038, 0.08612029327196069, 0.013293466072354931, 0.026958989328704774, 0.2637538517592475, 20.540859885513783, 56.505437940359116, 44.21227678656578, 43.34357500076294, 52.02449418604374, 61.110141053795815, 46.826031133532524, 55.01659043133259, 33.72876852750778, 1.3639036822132766, 1.0816605272702873, 0.6817713507916778, 6.571189742535353, 18.202699050307274, 36.14282079041004, 43.62900048494339, 53.853047266602516, 52.5982253998518, 50.84402292966843, 48.308380991220474, 47.75255061686039, 45.86095131933689, 50.03232568502426, 49.15714144706726, 50.439409241080284, 50.63544072210789, 50.749917179346085, 51.9670944660902, 50.399963557720184, 49.82327610254288, 51.52888298034668, 48.045818880200386, 45.58148391544819, 44.8742962628603, 45.09993575513363, 41.28049090504646, 41.646156683564186, 37.37781152129173, 38.29972185194492, 38.17942030727863, 40.82556031644344, 40.001331344246864, 40.17101123929024, 38.44338074326515, 38.965852707624435, 40.62568724155426, 40.077676847577095, 39.38628114759922, 37.871135249733925, 37.947051376104355, 40.93769609928131, 37.282782420516014, 36.57122500240803, 38.70095752179623, 39.12172794342041, 38.59610974788666, 39.40246447920799, 39.047213941812515, 49.47643831372261, 54.09951724112034, 52.54590600728989, 48.93618330359459, 46.36307917535305, 45.97276791930199, 42.4189630150795, 46.65258564054966, 46.48430787026882, 53.956884294748306, 46.07802987098694, 41.56909681856632, 45.75841762125492, 49.4687969237566, 53.61147902905941, 48.741436153650284, 50.37282541394234, 48.95893648266792, 52.4908659607172, 51.12653397023678, 50.61405546963215, 51.17907755076885, 51.75886943936348, 47.95306585729122, 49.850209057331085, 42.56750084459782, 39.06696528196335, 37.211600840091705, 38.28774869441986, 38.527550026774406, 39.61655639111996, 39.24482613801956, 38.4066367149353, 39.97900754213333, 37.90228217840195, 37.05270476639271, 38.25376711785793, 37.83170096576214, 37.96755887567997, 37.59503826498985, 36.47425040602684, 34.58955153822899, 38.63105267286301, 43.034966960549355, 46.50617189705372, 46.81525871157646, 48.7746349722147, 49.256908893585205, 50.63818037509918, 49.04293857514858, 48.45865532755852, 48.81838962435722, 49.4963264465332, 50.09076274931431, 48.34761768579483, 45.59368506073952, 47.723656967282295, 49.591906517744064, 45.792251005768776, 45.458032339811325, 45.454095751047134, 47.688687443733215, 46.96358375251293, 49.39756594598293, 48.066930547356606, 50.57134196162224, 51.269668489694595, 51.266366466879845, 39.788246378302574, 29.091200977563858, 15.959462821483612, 3.423931673169136, 7.676307242363691, 12.104212492704391, 7.017231658101082, 3.535327920690179, 0.17614757845876738, 10.37010619416833, 48.620861023664474, 42.02750042080879, 32.0299556851387, 24.192424044013023, 50.198935344815254, 24.449949525296688, 0.5380183551460505, 0.17236437677638605, 0.07222116604680195, 0.01946049804246286, 0.030933396083128173, 0.028143894887762144, 0.04985448635125067, 0.025553506347932853, 0.04766995240061078, 0.06280059576965868, 0.07149861106881872, 0.032444996904814616, 0.010203782840108033, 0.07826635221135803, 0.05351742671336979, 0.15974077134160325, 0.0924303667852655, 0.09799785475479439, 0.1130507024936378, 0.16502817277796566, 0.20005515340017155, 0.165000386768952, 0.11762013542465866, 0.1607185063767247, 0.2532015508040786, 0.10434703202918172, 0.09935689784470014, 0.12815517402486876, 0.1757938857190311, 0.13318454555701464, 0.18314862856641412, 0.09933157576597296, 0.10545746306888759, 0.38359811471309513, 25.95514375716448, 64.95388180017471, 50.1055933535099, 46.642497181892395, 50.64092382788658, 61.129314824938774, 56.62081114947796, 62.36881211400032, 38.871226385235786, 2.348364000208676, 3.30340214073658, 7.887536007910967, 13.542349822819233, 34.42115597426891, 44.87811505794525, 42.582042664289474, 55.79843267798424, 51.52303509414196, 50.82133814692497, 48.98447871208191, 48.7454829365015, 45.50503581762314, 48.789765760302544, 50.47583408653736, 51.15794688463211, 52.35424429178238, 53.396330773830414, 54.8534993827343, 52.82879702746868, 51.88845008611679, 52.64053612947464, 51.14249691367149, 48.00358034670353, 47.89169915020466, 47.854540944099426, 45.76537884771824, 43.895487785339355, 39.1838014125824, 40.605384930968285, 39.67351533472538, 43.724557757377625, 40.89479260146618, 42.81300947070122, 40.23039825260639, 41.44595302641392, 41.89711041748524, 42.61908307671547, 40.10514177381992, 39.514604061841965, 39.3513648211956, 43.25909413397312, 38.38643699884415, 39.57961857318878, 41.795348078012466, 40.74213579297066, 40.88498152792454, 40.693916380405426, 41.19898907840252, 52.803855165839195, 56.51428006589413, 53.31848055124283, 52.794063091278076, 48.950964510440826, 47.3165962100029, 45.46176373958588, 47.96621695160866, 48.38015913963318, 54.446320831775665, 50.58088704943657, 44.59965839982033, 47.67104119062424, 50.86491800844669, 55.27813799679279, 50.796111300587654, 52.70911484956741, 49.82942417263985, 55.458909496665, 52.55241885781288, 52.755354568362236, 53.54958415031433, 54.7299338132143, 50.17763368785381, 50.615214407444, 44.91513267159462, 39.80552785098553, 38.99348862469196, 40.36763548851013, 39.15455438196659, 39.090793803334236, 42.11897291243076, 41.39286607503891, 41.80445618927479, 40.226541459560394, 38.3857986330986, 38.8718381524086, 37.60112553834915, 38.9250922948122, 41.51365399360657, 39.72629450261593, 36.33448250591755, 41.77902415394783, 46.850273832678795, 49.32699993252754, 48.812670931220055, 50.13330526649952, 51.502219811081886, 53.87060232460499, 51.35298661887646, 48.84845361113548, 50.48546276986599, 51.249765157699585, 52.28186957538128, 51.704285368323326, 47.44566008448601, 49.191609397530556, 49.74838972091675, 47.655097246170044, 45.31555138528347, 46.713534370064735, 49.19648073613644, 47.97758214175701, 48.874094635248184, 47.60424457490444, 49.69104319810867, 53.16726006567478, 51.92313842475414, 42.57016070187092, 30.95478817820549, 17.519700899720192, 3.5503413900732994, 14.111912660300732, 20.199535600841045, 12.313155680894852, 6.257052049040794, 0.19920882303267717, 12.030709236860275, 53.97912450134754, 46.292114183306694, 38.700930923223495, 30.70913325995207, 57.114849239587784, 29.2586237937212, 0.8733174693770707, 0.2456482982961461, 0.19525403680745512, 0.08782727745710872, 0.11635884802672081, 0.06865556206321344, 0.1809069566661492, 0.2938705013366416, 0.1816121008596383, 0.09618563402909786, 0.1327075227163732, 0.12307731056353077, 0.09079839888727292, 0.20438971143448725, 0.11384317520423792], [0.03603752971685026, 0.13251333235530183, 0.1023382534913253, 0.059783390679513104, 0.0435527694207849, 0.08432178743532859, 0.03469515897450037, 0.030549535040336195, 0.01921722388942726, 0.02851093144272454, 0.046602918446296826, 0.022156386585265864, 0.02928012669144664, 0.019735994392249268, 0.028526015594252385, 0.050668433104874566, 0.025781213953450788, 0.03394837287487462, 0.03349590770085342, 3.428055876865983, 38.62874619662762, 47.3966047167778, 32.277865782380104, 23.64627555012703, 32.99164608120918, 42.51138925552368, 48.097758293151855, 42.78541535139084, 3.1814388977363706, 1.1662938608787954, 1.0114784119650722, 2.132787792943418, 12.35900592058897, 24.800304025411606, 32.72647351026535, 49.85558956861496, 49.4194071739912, 49.216030687093735, 45.4733607172966, 55.147865787148476, 45.40466420352459, 50.26966094970703, 50.11761970818043, 49.60807844996452, 48.43350447714329, 49.34638649225235, 47.43522584438324, 50.8283905684948, 49.09639410674572, 49.00800324976444, 48.53527441620827, 47.71218918263912, 46.51900380849838, 45.829295217990875, 44.68432165682316, 41.19735896587372, 40.53229585289955, 36.459754183888435, 37.242789566516876, 38.18044625222683, 37.76430018246174, 36.39124386012554, 35.93991927802563, 36.03934474289417, 38.51123750209808, 37.38933630287647, 36.72835797071457, 37.939394786953926, 35.87626129388809, 38.302347511053085, 38.10925327241421, 35.91971956193447, 36.121283546090126, 35.66185399889946, 37.92682126164436, 36.15426577627659, 41.14773742854595, 50.51499478518963, 49.223835468292236, 47.01914817094803, 48.53479944169521, 48.119177743792534, 44.226841405034065, 42.05401539802551, 41.62201277911663, 44.45461258292198, 48.18394146859646, 50.04463702440262, 53.564053773880005, 43.20091165602207, 46.97618767619133, 53.41450899839401, 50.78944645822048, 52.28283852338791, 47.43952341377735, 50.40394574403763, 53.58306795358658, 56.92374229431152, 51.655655577778816, 50.943186208605766, 49.55009736120701, 50.1215410977602, 44.30479422211647, 36.95213556289673, 35.02001903951168, 37.381877303123474, 38.401286602020264, 37.08760589361191, 37.4269162863493, 36.91256068646908, 37.9363701492548, 37.22703941166401, 35.68590670824051, 35.110260397195816, 35.03173381090164, 37.007863372564316, 36.71112969517708, 36.017678305506706, 34.98987525701523, 40.839136987924576, 44.98743899166584, 47.56576783955097, 48.78549478948116, 47.81825289130211, 49.47722487151623, 47.89315827190876, 46.44024923443794, 48.72720591723919, 47.09023855626583, 45.09445644915104, 47.083303928375244, 48.12379829585552, 47.52441085875034, 50.120800137519836, 47.3027041554451, 50.34821793437004, 48.79660539329052, 48.68095859885216, 45.57040750980377, 49.206367805600166, 45.759124383330345, 47.714548856019974, 45.31191498041153, 48.85669156908989, 42.661956176161766, 25.666431449353695, 7.598038092255592, 2.4628758430480957, 1.3274936797097325, 6.11411701887846, 7.1992285922169685, 7.40801171399653, 2.898095939308405, 0.1298266093363054, 13.396317958831787, 40.73364704847336, 32.789831310510635, 28.450855538249016, 28.27414982020855, 41.65610074996948, 9.755392279475927, 0.018129753043467645, 0.01756861704052426, 0.05446942406706512, 0.043769291005446576, 0.031344206363428384, 0.01814735307561932, 0.04942503888742067, 0.030497195075440686, 0.08796144291409291, 0.00820701039629057, 0.06295951927313581, 0.05883248057216406, 0.05164805690583307, 0.05239872814854607, 0.018147701885027345, 0.04142287238209974, 0.03452619421295822, 0.05128108343342319, 0.021344091110222507, 0.08975819728220813, 0.030314157338580117, 0.04362440522527322, 0.042427180014783517, 0.04511642262514215, 0.04914356453809887, 0.03787035617278889, 0.05320944655977655, 0.027043929985666182, 0.03233907016692683, 0.023055732272041496, 0.04608549308613874, 0.11448666176875122, 0.03745105757843703, 0.07490852731280029, 6.713797990232706, 48.130919113755226, 50.284293964505196, 34.936621114611626, 33.14754791557789, 46.26964598894119, 52.92724594473839, 54.205390959978104, 46.297688484191895, 3.2813611859455705, 0.6162113905884326, 3.1431725760921836, 4.13036079145968, 20.341281294822693, 31.848542019724846, 37.27339692413807, 50.76288588345051, 50.28609126806259, 48.741652742028236, 47.66193687915802, 52.69953556358814, 46.72794699668884, 50.28096914291382, 51.06781952083111, 49.59373041987419, 50.04746787250042, 49.94797021150589, 49.74205546081066, 51.119207963347435, 50.31143970787525, 50.38263648748398, 49.69819061458111, 49.4524198025465, 48.80754500627518, 45.76183743774891, 46.08954705297947, 44.192875027656555, 41.14140696823597, 37.227772772312164, 37.09180846810341, 40.04499480128288, 38.175099939107895, 37.66864791512489, 38.33770461380482, 37.579622492194176, 39.45345014333725, 37.79727481305599, 38.51958565413952, 39.007646664977074, 37.28445053100586, 39.72118377685547, 40.10146737098694, 36.98410704731941, 37.75651440024376, 38.39192010462284, 39.10150542855263, 36.42761930823326, 42.55252204835415, 52.80200086534023, 52.90730461478233, 49.65707682073116, 51.263999193906784, 50.40828511118889, 46.3058390468359, 43.40136609971523, 43.809821382164955, 45.75551077723503, 49.32693533599377, 52.411644011735916, 54.55211475491524, 45.0305400788784, 49.803311973810196, 55.70190645754337, 52.461516335606575, 54.49806645512581, 50.569024085998535, 51.287873312830925, 51.57768756151199, 55.97195416688919, 54.38797876238823, 52.08408258855343, 51.597119718790054, 51.18484564125538, 46.82634271681309, 39.485980197787285, 36.58168584108353, 38.62470701336861, 39.337791949510574, 38.16976122558117, 38.74261848628521, 36.812975630164146, 38.888545855879784, 37.472757026553154, 36.960278525948524, 36.68498709797859, 37.628552466630936, 37.129141464829445, 38.53152081370354, 38.273260071873665, 37.241759821772575, 42.926775366067886, 49.04719814658165, 50.370070561766624, 49.88192595541477, 49.291517436504364, 50.106744691729546, 48.54561746120453, 48.33591431379318, 49.182022511959076, 49.379817098379135, 48.267597779631615, 49.65037018060684, 48.66439528763294, 49.63891379535198, 50.50028197467327, 48.75552959740162, 50.414121598005295, 49.98954378068447, 48.92666481435299, 47.49454826116562, 49.44023385643959, 46.06019362807274, 48.26622225344181, 46.178013905882835, 49.7787880897522, 45.553456619381905, 30.27005922049284, 10.627577528357506, 4.140966022387147, 1.7504492215812206, 4.091413831338286, 11.370125133544207, 6.857643546536565, 1.0559332952834666, 0.13305835076607764, 13.933559730648994, 45.98865486681461, 38.91340412199497, 31.292382963001728, 30.00894483178854, 49.46060076355934, 14.313350301235914, 0.08306635558255948, 0.04041433821839746, 0.005663502861352754, 0.03373532083060127, 0.08026635114219971, 0.07069625295116566, 0.024622552591608837, 0.029285227101354394, 0.04900149520835839, 0.09334883390692994, 0.08152301496011205, 0.040096899392665364, 0.07518796075601131, 0.043774326477432624, 0.012384040164761245, 0.1478807913372293, 0.15835945639992133, 0.2670898649375886, 0.11406960446038283, 0.2284842630615458, 0.2340468528564088, 0.1762818478164263, 0.11782230387325399, 0.1728840434225276, 0.1175329256511759, 0.11902821963303722, 0.13904277730034664, 0.0666488244314678, 0.12354104896076024, 0.1538642679224722, 0.17135809874162078, 0.20346135890576988, 0.11502415480208583, 0.21908309252467006, 7.27022398263216, 54.73898112773895, 59.47768785059452, 45.11947810649872, 35.86206145584583, 44.66976463794708, 53.61316993832588, 57.429799139499664, 51.62447825074196, 4.118468379601836, 2.042656154371798, 8.930492643266916, 3.908529644832015, 16.24132789671421, 34.69723775982857, 41.92030817270279, 51.17940053343773, 49.311207979917526, 49.60739068686962, 48.303897231817245, 55.732350423932076, 48.474834859371185, 52.56205514073372, 52.04352356493473, 52.63169780373573, 52.469507306814194, 52.86798432469368, 49.86435949802399, 54.09780353307724, 50.991823598742485, 51.554527804255486, 51.015078350901604, 51.12541303038597, 49.996527805924416, 49.26641218364239, 48.36934871971607, 46.00292690098286, 44.29423078894615, 38.95178586244583, 40.06343901157379, 40.92686668038368, 40.10901756584644, 38.89860391616821, 39.94729444384575, 39.69320967793465, 41.993237659335136, 38.32484990358353, 40.48061102628708, 40.568272322416306, 38.35504688322544, 41.93062461912632, 41.73486292362213, 40.314043164253235, 38.146449476480484, 40.17476163804531, 41.24975435435772, 38.418514877557755, 44.6668615937233, 55.86972825229168, 53.133837059140205, 50.35685487091541, 54.38395477831364, 51.959601268172264, 47.712310776114464, 46.070677265524864, 45.36483094096184, 47.455801740288734, 51.19794733822346, 54.369333162903786, 59.04589802026749, 46.417518854141235, 49.99241262674332, 56.37947089970112, 55.126085355877876, 57.139221131801605, 52.87755221128464, 52.96274743974209, 51.98062174022198, 56.9513364136219, 57.15900667011738, 52.6874104142189, 53.29991854727268, 56.04891523718834, 47.60188490152359, 41.065992414951324, 39.44684989750385, 40.42564697563648, 41.14025942981243, 39.39970202744007, 40.06543770432472, 38.797692731022835, 41.85404732823372, 39.301340505480766, 38.46933335065842, 37.5516863912344, 38.59747767448425, 41.328573524951935, 41.48717701435089, 39.4623264670372, 37.376964166760445, 45.6709349155426, 50.96752010285854, 52.18542315065861, 52.853719890117645, 52.40483097732067, 51.47516906261444, 50.26846021413803, 50.33841826021671, 52.627635821700096, 50.686262995004654, 48.40388126671314, 49.83874127268791, 51.705322712659836, 50.33589519560337, 51.53003051877022, 50.92353366315365, 52.713446617126465, 51.87577396631241, 51.80184133350849, 48.74536894261837, 50.39821945130825, 47.417427599430084, 48.360312804579735, 46.646228581666946, 49.207317754626274, 46.37450136244297, 32.431860119104385, 12.498163003474474, 3.567541167140007, 3.083561137318611, 13.919695224612951, 13.796287346631289, 14.433204419910908, 6.5479392651468515, 0.24356503039598465, 16.187746971845627, 51.88770532608032, 45.62631770968437, 41.77629970014095, 39.22602854669094, 55.27660667896271, 17.67406191676855, 0.18206430628197268, 0.1275410913513042, 0.13612131297122687, 0.1225258651538752, 0.1420290904934518, 0.1334332540864125, 0.1409456884721294, 0.11866418877616525, 0.10947275659418665, 0.10712086834246293, 0.1664074690779671, 0.17671518784482032, 0.1714424364035949, 0.18257111893035471, 0.09928208193741739], [0.044786445214413106, 0.03720644199347589, 0.04407321903272532, 0.011139325852127513, 0.033779649311327375, 0.0585633258742746, 0.02876056209061062, 0.024243853185907938, 0.01779154707037378, 0.08034527854761109, 0.022601313394261524, 0.04011055119917728, 0.04584399452141952, 0.04906965776172001, 0.036724784440593794, 0.03858581621898338, 0.035670200013555586, 0.12751520524034277, 0.03503739295410924, 0.23283456946955994, 21.893942579627037, 54.91852909326553, 34.97194021940231, 27.228360436856747, 29.716404229402542, 41.701911091804504, 47.61950835585594, 47.32900254428387, 3.7846220936626196, 0.46224843186791986, 2.845796258188784, 1.1071619088761508, 1.3966386881656945, 2.440780266188085, 27.605039924383163, 48.23859393596649, 52.378388196229935, 48.01964968442917, 44.345110058784485, 50.37315219640732, 43.819776847958565, 51.788124069571495, 50.696811228990555, 49.061515778303146, 48.112885281443596, 48.29429134726524, 48.725461810827255, 48.81026566028595, 47.95027680695057, 51.582885682582855, 52.05994248390198, 50.03631167113781, 47.44551569223404, 46.51886701583862, 45.91227136552334, 42.61248283088207, 41.26023419201374, 38.7715957313776, 37.638576328754425, 36.561721712350845, 37.22344480454922, 35.51635220646858, 35.66327512264252, 37.65827067196369, 39.03765745460987, 38.07629004120827, 37.78349295258522, 37.69590385258198, 38.26070174574852, 36.911280155181885, 36.58705495297909, 36.12109735608101, 36.936465203762054, 36.61409430205822, 37.55718469619751, 36.84521310031414, 45.45920267701149, 50.26593714952469, 48.43801103532314, 49.05574768781662, 49.92805927991867, 49.401836916804314, 48.9187840372324, 45.982191413640976, 42.97426521778107, 41.973075941205025, 48.55259008705616, 49.06253032386303, 51.83093637228012, 41.40286713838577, 40.514360815286636, 49.44762445986271, 46.991318464279175, 54.14275512099266, 53.85804399847984, 57.53578305244446, 53.36173363029957, 48.387606739997864, 49.51713413000107, 51.930696219205856, 50.89194595813751, 49.5728125423193, 42.47497580945492, 34.6730824559927, 35.2666600048542, 36.22512437403202, 37.38493613898754, 37.25707679986954, 36.34347282350063, 37.884350940585136, 39.02615927159786, 36.745985224843025, 36.22685708105564, 36.54353588819504, 36.565407514572144, 36.08496889472008, 35.93847535550594, 35.284944623708725, 37.00385458767414, 44.79947067797184, 47.5428132712841, 47.86820501089096, 45.847363248467445, 46.397007554769516, 45.35976581275463, 45.44067107141018, 47.884312346577644, 48.63613240420818, 47.259139493107796, 46.470100432634354, 44.98841933906078, 45.62211513519287, 46.950379461050034, 45.80225966870785, 47.49829486012459, 45.010081976652145, 45.95232121646404, 48.70712399482727, 47.63460114598274, 47.8866758197546, 49.18585650622845, 49.59240049123764, 47.56028853356838, 43.03718604147434, 39.65348660945892, 12.078955247998238, 2.3010760126635432, 0.44959534832742065, 2.0538000063970685, 4.729712605476379, 9.662291575223207, 3.8847918435931206, 1.37948177754879, 0.2753562916768715, 14.296662546694279, 40.71193881332874, 32.54896983504295, 25.545347146689892, 30.95980580896139, 37.856608629226685, 5.835205810144544, 0.04118827579077333, 0.058846076717600226, 0.05373778891225811, 0.0635674643854145, 0.04266635936801322, 0.06869476230349392, 0.01110078612327925, 0.018338908812438603, 0.03411031320865732, 0.1080553732754197, 0.10793453679070808, 0.03358911402756348, 0.015536065657215659, 0.06641610918450169, 0.05763102511991747, 0.047874889060040005, 0.055061509483493865, 0.07709423385676928, 0.02479790538927773, 0.04672641181969084, 0.058333338020020165, 0.022293006695690565, 0.03816790173004847, 0.0801239775319118, 0.026306750987714622, 0.0021551425834331894, 0.03998069019871764, 0.06482441021944396, 0.04818248329684138, 0.00789234534749994, 0.10732564172940329, 0.036928619010723196, 0.12418213838827796, 0.02229573408840224, 0.5439637892413884, 28.55730302631855, 62.06436865031719, 39.66317608952522, 30.627329349517822, 36.66202872991562, 49.26818288862705, 49.95847284793854, 54.304573237895966, 3.086009630933404, 0.12831918866140768, 3.5921740578487515, 2.545449212193489, 2.5871462747454643, 4.517154386267066, 34.063640758395195, 51.159280613064766, 50.548110008239746, 48.62759806215763, 46.78110994398594, 53.80759410560131, 45.02466179430485, 51.549880653619766, 52.59126417338848, 50.23974895477295, 50.71375451982021, 49.45274658501148, 49.374938160181046, 49.9303125590086, 51.06302797794342, 51.060683503746986, 52.4104280769825, 51.114602610468864, 49.81121554970741, 48.49015563726425, 48.5448195040226, 44.64841738343239, 42.19611257314682, 41.02234035730362, 38.507688492536545, 38.53510022163391, 39.920270293951035, 38.6190415173769, 36.75228528678417, 38.559627905488014, 39.325359016656876, 39.647802114486694, 39.83879126608372, 39.53596651554108, 39.27441895008087, 39.60366368293762, 38.94639775156975, 37.261370569467545, 38.01614306867123, 35.98052769899368, 39.924404472112656, 37.021360248327255, 46.636314913630486, 52.71310083568096, 50.30946001410484, 50.26130899786949, 51.22478149831295, 51.298763528466225, 50.374717712402344, 46.83497965335846, 45.439637526869774, 44.16175089776516, 49.56368163228035, 50.5681349337101, 52.7061852067709, 43.28641086816788, 42.20525108277798, 50.09662963449955, 49.743438586592674, 53.50474655628204, 52.11657464504242, 56.1739931255579, 57.016012743115425, 51.43035426735878, 50.843403562903404, 51.94717973470688, 51.28141365945339, 50.14768369495869, 46.469218879938126, 35.71318544447422, 37.128411903977394, 39.39084470272064, 38.03160823881626, 37.98995487391949, 38.79914805293083, 40.252817049622536, 40.08040890097618, 37.732328698039055, 37.1515678614378, 38.289432004094124, 38.02896738052368, 38.705646470189095, 38.12560759484768, 38.086363300681114, 39.44494999945164, 46.739893555641174, 50.522024407982826, 48.88412609696388, 47.906324565410614, 47.45450980961323, 48.098256066441536, 47.836453914642334, 48.809653893113136, 49.45108987390995, 48.68769943714142, 47.944459319114685, 47.01796643435955, 47.80248373746872, 47.79222048819065, 48.40994954109192, 51.13541029393673, 47.699706852436066, 48.98863568902016, 50.83716429769993, 47.94818311929703, 48.92949566245079, 49.697176069021225, 49.38916839659214, 47.70603351294994, 46.75482675433159, 42.78549514710903, 15.424974001944065, 3.759939568117261, 2.1837347466498613, 1.312780869193375, 1.7515174392610788, 10.18745569512248, 4.821019330993295, 0.5292243801523, 0.20034101384226233, 15.991185419261456, 45.61087153851986, 38.00353154540062, 29.99696597456932, 34.85717497766018, 43.88428598642349, 8.030289597809315, 0.015634730480087455, 0.04135871000471525, 0.02121724137396086, 0.03760435931326356, 0.04681117250584066, 0.004332960561441723, 0.05754103229264729, 0.06181595876114443, 0.0690858370217029, 0.011155350675835507, 0.02711960863962304, 0.0590963289141655, 0.015499244927923428, 0.049765061266953126, 0.039230044931173325, 0.1407896148157306, 0.1593947078799829, 0.12168694884167053, 0.12338706816080958, 0.09951069310773164, 0.17422223958419636, 0.10417678335215896, 0.1336564772645943, 0.1803715861751698, 0.14093927631620318, 0.26839355123229325, 0.17773046070942655, 0.0917423736245837, 0.06678468198515475, 0.10770531705929898, 0.191562416148372, 0.07204112102044746, 0.22873515350511298, 0.12817571667255834, 0.8113410731311888, 34.066118225455284, 70.42058765888214, 47.05460026860237, 38.18964555859566, 40.81805571913719, 55.14343902468681, 56.868219673633575, 59.2344781011343, 4.643304292112589, 0.5459055444225669, 9.180293139070272, 5.184451779350638, 3.0048740096390247, 4.762468747794628, 36.73757627606392, 52.22907520830631, 52.558775916695595, 47.87387050688267, 50.34442573785782, 54.759948402643204, 45.676520615816116, 52.21783921122551, 53.00397902727127, 52.06773206591606, 51.4176781475544, 50.25825776159763, 52.064604833722115, 52.22017228603363, 51.33944034576416, 52.766708359122276, 55.26546187698841, 53.036174699664116, 51.198631301522255, 50.330282896757126, 50.978661105036736, 47.46062368154526, 45.64401715993881, 43.19883316755295, 41.03858068585396, 39.80148866772652, 41.61936812102795, 39.19339969754219, 38.68178375065327, 40.21479249000549, 42.25284732878208, 42.19629876315594, 41.09182722866535, 41.958507522940636, 40.81681698560715, 40.42467422783375, 40.72864651679993, 39.49925288558006, 40.03014899790287, 37.630665153265, 41.32460653781891, 39.61785972118378, 48.286026790738106, 54.15468268096447, 52.871727123856544, 53.24347637593746, 52.51242980360985, 52.466566264629364, 52.59255990386009, 49.012164026498795, 47.58352428674698, 46.870948523283005, 51.4880807697773, 53.45435366034508, 53.81048195064068, 45.967467203736305, 44.4276150316, 51.70279964804649, 48.86050656437874, 55.24303928017616, 51.129155829548836, 55.01594066619873, 56.29954218864441, 53.151004537940025, 53.16226713359356, 52.16841146349907, 53.40287022292614, 52.09445223212242, 47.43893064558506, 37.605442106723785, 38.68733525276184, 40.91835513710976, 40.12884110212326, 39.98397007584572, 38.759310990571976, 41.20887994766235, 42.345607951283455, 39.60521399974823, 39.36031334102154, 40.4186287522316, 39.25116039812565, 40.18920846283436, 39.659995660185814, 39.686544835567474, 41.38074852526188, 48.25148284435272, 52.88991294801235, 51.218842417001724, 49.15445499122143, 48.55380602180958, 48.21851581335068, 47.652053609490395, 51.310425102710724, 53.43100391328335, 50.840667709708214, 49.94717985391617, 47.98218749463558, 49.735113233327866, 50.67125380039215, 50.43318897485733, 51.81001469492912, 48.90010043978691, 50.62941424548626, 51.617159843444824, 51.72671936452389, 49.82828043401241, 51.71833321452141, 49.779198467731476, 48.24986033141613, 49.20023873448372, 46.28060460090637, 19.459299221634865, 4.501412305980921, 4.268031679093838, 6.727243568748236, 14.35874741524458, 20.927534736692905, 11.215339489281178, 3.957580500282347, 0.248690836597234, 18.3391098305583, 51.88149645924568, 45.261807069182396, 37.95030780136585, 40.36423847079277, 51.57793074846268, 10.31140599399805, 0.14860064489766955, 0.19814859086181968, 0.23837256449041888, 0.1980756822740659, 0.1700739309308119, 0.09694516280433163, 0.14509669854305685, 0.1669659055187367, 0.1505602858378552, 0.1897440801258199, 0.11238587918342091, 0.15451964369276538, 0.12632800644496456, 0.18889222817961127, 0.13383989164140075], [0.021784461132483557, 0.025600551089155488, 0.0477146334014833, 0.07926612903247587, 0.05122958209540229, 0.026244983891956508, 0.07222502521472052, 0.051016845463891514, 0.08403857646044344, 0.0484050608065445, 0.013490592555172043, 0.06957943201996386, 0.055966922227526084, 0.040286685107275844, 0.09778966748854145, 0.015605994522047695, 0.0316527653922094, 0.05311381341016386, 0.0139592012965295, 0.038570991819142364, 3.1672594835981727, 41.29201948642731, 42.77964726090431, 32.598055601119995, 27.547963187098503, 41.289222836494446, 39.189596101641655, 54.5966711640358, 5.503194825723767, 0.21357196324970573, 4.015236468985677, 2.968367706052959, 5.832440508529544, 0.1064708805643022, 11.852008625864983, 39.44445222616196, 50.697145611047745, 49.024391770362854, 43.12248766422272, 47.228874117136, 45.57473927736282, 49.707697704434395, 49.93695840239525, 49.82119381427765, 50.10240912437439, 50.118638053536415, 50.124219954013824, 50.807970464229584, 48.87514717876911, 48.80435697734356, 49.15383942425251, 49.68661643564701, 48.26750658452511, 45.197294130921364, 45.524771958589554, 43.002775087952614, 41.353158205747604, 38.490315824747086, 37.88941226899624, 37.48168654739857, 37.334372252225876, 37.610484436154366, 37.42352306842804, 36.87926307320595, 37.61862739920616, 37.56585583090782, 37.241433039307594, 36.47955112159252, 39.19667512178421, 37.12014354765415, 38.21049503982067, 36.84978045523167, 37.06032335758209, 36.94111615419388, 35.91334730386734, 36.73177018761635, 46.593628004193306, 48.5865792632103, 48.54566305875778, 47.42812022566795, 50.785460472106934, 48.51037435233593, 48.47072347998619, 46.96406252682209, 44.68344010412693, 43.3428530395031, 47.39398665726185, 48.37517760694027, 52.62106977403164, 43.531444519758224, 40.40573984384537, 47.96628154814243, 45.49864076077938, 46.181882098317146, 47.497211918234825, 45.209350883960724, 43.42318452894688, 48.92436593770981, 49.36930686235428, 50.34055754542351, 48.64898331463337, 48.811204209923744, 38.54074291884899, 36.3532193005085, 36.877587363123894, 37.69766315817833, 38.19395072758198, 37.16156892478466, 35.77218867838383, 37.59144365787506, 37.5048691034317, 36.05949506163597, 35.67512668669224, 36.55656158924103, 35.69059945642948, 36.491645872592926, 36.014908254146576, 35.526851043105125, 40.303624123334885, 48.139643445611, 48.69791328907013, 45.8365224301815, 45.62906876206398, 45.762004628777504, 47.02630698680878, 45.414874255657196, 46.3399688154459, 48.05358186364174, 46.14895686507225, 44.01919014751911, 44.21132683753967, 43.22473257780075, 43.26746888458729, 43.13016705214977, 44.691092893481255, 44.716673120856285, 45.73367714881897, 43.90372954308987, 46.01821728050709, 45.0117576867342, 48.61823916435242, 46.787641793489456, 48.17253828048706, 40.95254190266132, 23.896693512797356, 3.4851831989362836, 1.5735262027010322, 3.8672241987660527, 1.2691208557225764, 1.6203842195682228, 5.986232981085777, 6.563994353637099, 0.1362885336857289, 0.06905477071995847, 12.08151726052165, 31.30811221897602, 25.36705881357193, 19.509346336126328, 33.954085037112236, 30.91617275029421, 1.2531050713732839, 0.07531067487434484, 0.11408235455746762, 0.02654096908372594, 0.06840751404524781, 0.0796703175001312, 0.04153186790063046, 0.02235051571915392, 0.03486907015030738, 0.027736069896491244, 0.05079760761873331, 0.0048449176847498165, 0.08991328388219699, 0.04320893611293286, 0.05307152954628691, 0.015925385196169373, 0.03660038193629589, 0.017304865177720785, 0.016189688103622757, 0.049418734342907555, 0.044300423833192326, 0.024979087756946683, 0.054875293499208055, 0.045184433038230054, 0.09093311353353783, 0.008525075409124838, 0.07243222542456351, 0.013769924880762119, 0.0472609065764118, 0.015315546679630643, 0.03039875846297946, 0.05243061823421158, 0.06570256387931295, 0.013126915146131068, 0.049248997747781686, 0.025478436255070847, 7.493756487965584, 49.73873443901539, 47.71373189985752, 33.611890599131584, 29.726644679903984, 52.379596531391144, 45.431312173604965, 57.343566566705704, 5.277379592880607, 0.21506774704903364, 1.088873608969152, 5.702852262184024, 8.352783042937517, 0.1781539004878141, 16.469716541469097, 42.69170477986336, 53.15362259745598, 48.72279815375805, 45.16040951013565, 47.8923375159502, 48.29141490161419, 50.719716399908066, 50.79887755215168, 51.567785292863846, 50.58328852057457, 51.23885594308376, 52.322709783911705, 50.26540517807007, 51.54250904917717, 50.66659525036812, 51.68980434536934, 51.52107819914818, 48.96879695355892, 46.10916920006275, 45.74803277850151, 44.820681139826775, 41.98691099882126, 39.74570766091347, 40.17744429409504, 38.89573886990547, 38.538672029972076, 37.872943952679634, 38.299303874373436, 38.27386423945427, 39.06500458717346, 39.08618085086346, 39.7015730291605, 38.28042268753052, 39.95081305503845, 38.7807722389698, 38.13167966902256, 37.499393597245216, 37.510215416550636, 38.91891002655029, 37.84857966005802, 38.87151896953583, 47.04978972673416, 50.91996565461159, 50.71907043457031, 51.33327707648277, 51.698958054184914, 50.44605888426304, 49.7855669260025, 49.6653413772583, 46.81813895702362, 46.078884825110435, 49.62679624557495, 50.38010202348232, 54.107284024357796, 44.146559312939644, 42.76815287768841, 47.73831658065319, 45.06617456674576, 46.40120632946491, 49.99293699860573, 49.877468794584274, 47.743070125579834, 50.38892135024071, 51.52025364339352, 51.80531054735184, 49.58698198199272, 50.73921695351601, 40.88656224310398, 37.971335873007774, 38.8412231951952, 38.94039407372475, 40.22911012172699, 38.235718086361885, 37.91092291474342, 37.951234951615334, 39.20116648077965, 37.29163974523544, 37.413031831383705, 37.84343473613262, 37.439588606357574, 37.88537308573723, 37.956398874521255, 36.291183829307556, 41.199961826205254, 50.59738576412201, 49.881542176008224, 46.23975299298763, 46.04496784508228, 46.43396057188511, 46.94806918501854, 47.19927370548248, 47.707089856266975, 50.012699738144875, 49.09362405538559, 46.43720179796219, 45.04875250160694, 45.41189901530743, 45.4690707474947, 46.418514400720596, 46.07763089239597, 47.81476467847824, 47.282565236091614, 46.26119904220104, 47.37525746226311, 48.71699586510658, 50.85396319627762, 49.93427574634552, 48.67775537073612, 43.66329364478588, 29.270530454814434, 5.582745457068086, 2.6608433201909065, 6.0505792032927275, 1.2129967985674739, 0.9083473740611225, 2.1397872548550367, 2.212871345691383, 0.6727657152805477, 0.11729794685379602, 14.583518654108047, 39.698662385344505, 32.957124933600426, 25.48548325896263, 37.239487543702126, 38.78510780632496, 2.999976547434926, 0.08779373238212429, 0.09244252316420898, 0.0038411745481425896, 0.022976276086410508, 0.050414793004165404, 0.0494591368624242, 0.055364517247653566, 0.00983897643891396, 0.06233172171050683, 0.03476593759842217, 0.055690898952889256, 0.060047918086638674, 0.01069349455065094, 0.06603198839002289, 0.088336116168648, 0.07050791813526303, 0.08916472404962406, 0.1123266335343942, 0.16764443629654124, 0.17152523039840162, 0.14362089335918427, 0.13973371678730473, 0.11609567503910512, 0.19556551618734375, 0.11436981803853996, 0.07099772818037309, 0.09807528302189894, 0.129363791202195, 0.19752757652895525, 0.13042549282545224, 0.16592488012975082, 0.11901805963134393, 0.16461565741337836, 0.13612441514851525, 0.21979665267281234, 9.703682754188776, 56.58223181962967, 55.89465111494064, 45.72059825062752, 35.59593513607979, 56.38593055307865, 48.71539235115051, 66.59287065267563, 5.892229825258255, 0.25817503861617297, 7.552219200879335, 6.738162757828832, 8.712585736066103, 0.46990597096737474, 16.280427798628807, 45.328546687960625, 51.83663986623287, 48.41269679367542, 46.49572245776653, 49.85801383852959, 50.11843666434288, 51.159246414899826, 52.672070637345314, 52.57268317043781, 52.470407858490944, 51.97730451822281, 53.02242323756218, 53.4872180968523, 52.26925045251846, 53.38447540998459, 53.0489382147789, 54.42573353648186, 51.67935110628605, 47.37763233482838, 47.291004583239555, 47.05365791916847, 43.94466854631901, 42.47093662619591, 41.60908967256546, 40.77303573489189, 40.1019461452961, 39.661986753344536, 40.39787046611309, 40.873300954699516, 40.37782274186611, 40.4729088395834, 42.120671421289444, 40.15363097190857, 42.21498616039753, 40.367920473217964, 41.0992406308651, 40.1780940592289, 39.431544318795204, 40.111753419041634, 38.16972702741623, 41.16042114794254, 48.898964300751686, 53.34034077823162, 54.24827165901661, 51.52551256120205, 54.541703313589096, 51.35389856994152, 52.94695928692818, 53.22847098112106, 49.944261610507965, 47.551845386624336, 50.33194720745087, 51.684579625725746, 55.89802913367748, 48.612535670399666, 44.99896377325058, 47.56846949458122, 46.487723886966705, 45.999195501208305, 51.345584616065025, 51.996698677539825, 50.95817260444164, 51.46256513893604, 53.642671555280685, 54.78207841515541, 50.95095679163933, 53.08210663497448, 42.3454749584198, 39.64603900909424, 40.65272279083729, 41.25391513109207, 42.90887072682381, 41.56172901391983, 39.16997395455837, 40.15444032847881, 42.00184039771557, 39.5685725659132, 39.023127034306526, 39.780452996492386, 39.59577530622482, 40.27226820588112, 39.1420416533947, 39.11407135426998, 44.298513159155846, 51.81893281638622, 52.311545982956886, 48.69072027504444, 47.29607731103897, 47.52750389277935, 49.162366166710854, 48.6740467697382, 49.06494699418545, 50.81766374409199, 48.97768847644329, 48.075746074318886, 47.10419520735741, 47.3867404460907, 47.71137982606888, 47.67851538956165, 48.00840988755226, 49.40898433327675, 49.30282182991505, 48.154800832271576, 49.21904772520065, 49.71630044281483, 52.43818558752537, 51.09391652047634, 51.439431980252266, 44.33407925069332, 30.76859626919031, 8.09558529406786, 4.5907132141292095, 10.742588806897402, 6.810682341456413, 4.642687775194645, 15.778341740369797, 14.327189158648252, 1.2666515819728374, 0.2539175155106932, 15.858832821249962, 42.974614799022675, 38.6724666506052, 31.421395540237427, 42.949634939432144, 45.72566717863083, 4.114047316834331, 0.32050606270786375, 0.25588857068214566, 0.13513453857740387, 0.13297091092681512, 0.1725240721134469, 0.09518832113826647, 0.15834888821700588, 0.21626906149322167, 0.12916111067170277, 0.18945422692922875, 0.11080132710048929, 0.19530399818904698, 0.15626633277861401, 0.14540623349603266, 0.28735067462548614], [0.03245173931645695, 0.02955051892058691, 0.014271236359491013, 0.020463718428800348, 0.02097151071211556, 0.014696675298182527, 0.02223593182861805, 0.09848293731920421, 0.005452270470414078, 0.05471399512316566, 0.019818088912870735, 0.04753553461341653, 0.07120783018763177, 0.02384709361649584, 0.15623363375198096, 0.01593104963831138, 0.048351603909395635, 0.12798951182048768, 0.02497396693797782, 0.013733475225308212, 0.3460995003115386, 23.56141660362482, 45.79671196639538, 37.63462834060192, 28.84081531316042, 37.89160095155239, 36.18414357304573, 54.09607082605362, 9.055395741015673, 0.00788525227108039, 1.108600131701678, 2.1706180879846215, 4.479938233271241, 0.11907277817954309, 2.900272272527218, 24.23879485577345, 47.726863995194435, 49.72861938178539, 44.60002698004246, 47.8594084829092, 50.22054858505726, 49.12406042218208, 51.90708048641682, 47.511806935071945, 50.27554303407669, 49.1383970528841, 49.0937190502882, 48.3863528072834, 50.073352083563805, 49.94871497154236, 50.66145792603493, 49.86399091780186, 48.22005473077297, 45.41663736104965, 45.91526560485363, 43.73022325336933, 40.852231085300446, 39.635771960020065, 38.82054090499878, 36.82955414056778, 37.931745797395706, 36.092769876122475, 38.13028134405613, 38.385114669799805, 38.48184607923031, 36.62495791912079, 36.713656559586525, 39.18921612203121, 36.42923802137375, 38.67082893848419, 37.62664496898651, 36.2608652561903, 36.6150214523077, 37.31888808310032, 35.91763727366924, 37.57780618965626, 46.273027807474136, 48.09523902833462, 48.750415071845055, 45.99611386656761, 49.80905346572399, 50.696203261613846, 51.4795084297657, 48.15692111849785, 48.789127394557, 45.91380648314953, 48.7770364433527, 48.71685527265072, 52.092620730400085, 41.80979870259762, 43.34026537835598, 49.383563697338104, 49.48016591370106, 50.89350387454033, 45.87710805237293, 47.76040479540825, 51.46556317806244, 49.342609494924545, 48.74709025025368, 48.24712447822094, 48.685176372528076, 40.252285078167915, 35.314537435770035, 36.8830780684948, 35.94871200621128, 35.972468331456184, 36.95766046643257, 35.60788169503212, 36.35396026074886, 36.56672224402428, 36.01255618035793, 35.22347912192345, 35.060068890452385, 38.221415653824806, 39.2551501840353, 34.558454006910324, 34.91118147969246, 34.2155110090971, 38.93074259161949, 47.856262251734734, 48.91779229044914, 45.40705047547817, 45.47347091138363, 44.50419992208481, 43.77316854894161, 45.87628349661827, 46.683185398578644, 46.74580603837967, 46.770858094096184, 43.54777604341507, 42.151765152812004, 40.76092578470707, 40.235178396105766, 40.54667428135872, 42.52999305725098, 40.135232359170914, 40.32217092812061, 41.38991743326187, 41.7894621938467, 41.03585243225098, 45.79422689974308, 48.456090465188026, 45.46957232058048, 37.51144275069237, 15.238176975399256, 0.9404191374778748, 5.077872723340988, 2.9524938203394413, 0.8180116151925176, 0.4407797026215121, 0.9789377299603075, 1.2798387743532658, 0.05894243346119765, 0.3306470060488209, 15.990860536694527, 34.18701633810997, 26.140980385243893, 19.551174491643906, 38.849187567830086, 23.776295073330402, 0.4416885069804266, 0.12288850819459185, 0.0029498612184397643, 0.01277034287340939, 0.025330262760689948, 0.020899205119349062, 0.05408434219134506, 0.047123067488428205, 0.06731571833370253, 0.024067613521765452, 0.047865582528174855, 0.035655256870086305, 0.09636253977078013, 0.041327547223772854, 0.03611908803577535, 0.006199037088663317, 0.04282169458747376, 0.0549901037447853, 0.019393196380406152, 0.06914969140780158, 0.08837150176987052, 0.021520254704228137, 0.05686820120899938, 0.021032094082329422, 0.022861311845190357, 0.02525259700632887, 0.0414987495605601, 0.02554667673393851, 0.040313665886060335, 0.05602144039585255, 0.061420086058205925, 0.025941759049601387, 0.050410559051670134, 0.0674248585710302, 0.037227459615678526, 0.07203974804724567, 0.7568403007462621, 32.521231323480606, 53.665645122528076, 41.05855241417885, 28.95658940076828, 41.44041672348976, 42.48086169362068, 59.285315573215485, 9.084633272141218, 0.025373923308507074, 2.0022716838866472, 3.4214223828166723, 9.98111441731453, 0.7351123541593552, 3.4506670385599136, 28.824761174619198, 50.074260234832764, 50.502489656209946, 45.78831061720848, 49.35965538024902, 49.323203936219215, 50.54836079478264, 52.672097235918045, 49.53040301799774, 51.842491552233696, 50.407578349113464, 49.690891206264496, 49.01996500790119, 51.3375024497509, 51.0245094448328, 52.352268397808075, 51.06854908168316, 50.06930150091648, 47.72067032754421, 47.65075407922268, 45.16218401491642, 42.77837052941322, 40.63732981681824, 41.04834236204624, 37.90182240307331, 38.55178512632847, 37.288580909371376, 39.38872441649437, 39.49858792126179, 38.589452505111694, 37.70970471203327, 38.945288211107254, 39.82800744473934, 37.628499269485474, 40.10004624724388, 39.05764438211918, 36.85919634997845, 38.27587813138962, 39.20931324362755, 37.040439024567604, 38.13270181417465, 48.07779796421528, 51.18113324046135, 49.890958070755005, 48.71570773422718, 50.7645919919014, 51.47673077881336, 53.579788729548454, 50.45279212296009, 49.58462230861187, 47.626594975590706, 51.20512515306473, 50.815946236252785, 53.52279178798199, 44.64800700545311, 43.943954184651375, 51.342172399163246, 51.315201446413994, 50.111091658473015, 46.776124611496925, 47.78974302113056, 51.65725149214268, 53.11817429959774, 49.356775134801865, 51.122867166996, 50.65678417682648, 43.21945086121559, 37.83641651272774, 38.78684051334858, 36.83447107672691, 38.97262394428253, 39.00445103645325, 37.758475095033646, 36.71148307621479, 38.3826220035553, 39.050352573394775, 37.30137102305889, 36.54622234404087, 38.26238125562668, 40.50920829176903, 37.34645560383797, 36.713124588131905, 35.670509934425354, 40.80748088657856, 50.082399398088455, 50.0323598831892, 45.960684567689896, 47.231689766049385, 45.184895396232605, 45.323720946908, 46.02832093834877, 48.905249163508415, 48.043595999479294, 46.93386934697628, 44.798737317323685, 43.65101270377636, 43.26900780200958, 42.49593548476696, 42.02934332191944, 44.29048039019108, 43.054931089282036, 43.39846685528755, 44.315346255898476, 44.43860404193401, 45.28239816427231, 47.51080758869648, 49.78248529136181, 48.25826548039913, 39.647999703884125, 18.57807520776987, 2.182158068753779, 6.6515454556792974, 5.220783529803157, 0.2944821200799197, 0.62032051384449, 1.1563639249652624, 0.47515325190033764, 0.121934811322717, 0.19275613100035116, 17.436371371150017, 38.49685147404671, 30.748301558196545, 20.614539831876755, 43.54104280471802, 29.220711328089237, 1.0182095132768154, 0.03797430879785679, 0.04678492645325605, 0.01878495440905681, 0.052053521867492236, 0.02222969036665745, 0.1033239666139707, 0.07120704351109453, 0.01231658543474623, 0.04114639639738016, 0.04215042572468519, 0.065312632068526, 0.025193468245561235, 0.04177762268227525, 0.01614272314327536, 0.009864890380413271, 0.05095997839816846, 0.19464442186290398, 0.09570528636686504, 0.14654164522653446, 0.22285842744167894, 0.10810149775352329, 0.10149087669560686, 0.20470279385335743, 0.124318597081583, 0.20104364957660437, 0.11308330504107289, 0.18829135573469102, 0.1669950273935683, 0.19801791349891573, 0.26092068816069514, 0.18853558169212192, 0.13765990384854376, 0.2428097912343219, 0.12721954844892025, 0.1470007377793081, 1.0934929735958576, 39.94315266609192, 58.38825970888138, 51.745368763804436, 40.91233246028423, 49.3668369948864, 45.69215677678585, 63.040304481983185, 11.197133716195822, 0.1895438041538, 4.719555275514722, 6.354962820187211, 8.264461532235146, 0.6090613023843616, 5.790466535836458, 29.50133576989174, 50.74830986559391, 51.540327966213226, 48.70632603764534, 49.48732852935791, 51.45467296242714, 50.247249752283096, 54.216395169496536, 51.02499581873417, 51.46941997110844, 50.73502957820892, 50.21126948297024, 49.44822482764721, 52.379300147295, 52.74419076740742, 53.32650572061539, 53.082095235586166, 52.260282933712006, 50.19383601844311, 49.43239867687225, 47.49679774045944, 46.25810220837593, 43.66867035627365, 43.33780691027641, 39.45742093026638, 40.72511650621891, 38.706281036138535, 41.41493909060955, 41.53613738715649, 40.34134849905968, 40.139761716127396, 40.80746568739414, 41.57650262117386, 38.39057877659798, 42.470051273703575, 40.519118160009384, 38.62001046538353, 40.386520475149155, 40.56175947189331, 38.44849906861782, 40.49972400069237, 50.37203885614872, 53.46432812511921, 53.114765882492065, 51.04309044778347, 52.68179811537266, 54.11607675254345, 55.6845223903656, 50.75877070426941, 53.01951639354229, 50.091393515467644, 53.315801694989204, 53.6180754750967, 55.151319801807404, 46.901046708226204, 47.17988334596157, 52.675380259752274, 53.201933205127716, 54.90517280995846, 50.66368840634823, 51.13096833229065, 53.83247137069702, 54.31591562926769, 52.052152901887894, 51.43309012055397, 51.31256818771362, 44.757159948349, 38.21989953517914, 40.13483338057995, 40.16530394554138, 39.77487109601498, 41.36963792145252, 38.6691190302372, 40.78968644142151, 40.469910800457, 40.342059060931206, 37.720667123794556, 37.85738758742809, 40.42562037706375, 42.06176698207855, 38.769661635160446, 38.6331919580698, 36.3779141753912, 41.20455577969551, 51.548945903778076, 53.847985938191414, 46.99523605406284, 48.9161241799593, 45.59027664363384, 47.38524332642555, 47.817572727799416, 49.887211471796036, 50.8591765165329, 49.907122403383255, 47.04929195344448, 45.44666334986687, 45.29166206717491, 44.23582412302494, 44.8243061453104, 46.758124977350235, 44.12708915770054, 44.746155738830566, 46.51736989617348, 47.234220430254936, 45.619314685463905, 50.86212515830994, 52.583121210336685, 48.76032494008541, 41.21647574007511, 23.30434139817953, 3.7158723827451468, 10.992170814424753, 14.688552618026733, 2.2834480460733175, 2.316182814538479, 5.93369510024786, 5.917194485664368, 0.49523321504238993, 0.5252877320162952, 20.553528405725956, 47.68845185637474, 37.82131992280483, 29.645344242453575, 50.97830772399902, 35.57466007769108, 1.3939430890604854, 0.27403586253058165, 0.1393650475074537, 0.1421610443503596, 0.1276623285957612, 0.16710735886590555, 0.2103120053652674, 0.23456120572518557, 0.1200566285115201, 0.188411672716029, 0.13809006748488173, 0.22626702266279608, 0.1847472443478182, 0.1700784283457324, 0.1324004220077768, 0.0854532360972371], [0.028671812360698823, 0.0403330396511592, 0.03380372087121941, 0.024804093045531772, 0.09956075838999823, 0.021614136385323945, 0.014036817883607, 0.0440460452955449, 0.04392736103909556, 0.04246901487931609, 0.0759111242950894, 0.04370710645162035, 0.08726220621610992, 0.024867073552741203, 0.03447393588430714, 0.032316720389644615, 0.11585916741751134, 0.04213320789858699, 0.06251371116377413, 0.062482281209668145, 0.03642972507805098, 10.790563132613897, 42.29716055095196, 35.2123761177063, 25.227279514074326, 40.02257980406284, 35.06322272121906, 47.424426823854446, 18.67952786386013, 0.02554641141614411, 1.1711572436615825, 4.799325345084071, 4.450868843123317, 1.467720523942262, 0.44073576747905463, 8.74492485076189, 36.611689031124115, 48.171702325344086, 50.713986307382584, 46.21404357254505, 52.08422318100929, 49.78812798857689, 52.49710522592068, 50.282356068491936, 49.39625881612301, 48.976423144340515, 49.840287789702415, 50.06464675068855, 49.59715023636818, 49.15038160979748, 51.45604468882084, 49.76212218403816, 49.74518649280071, 46.77870087325573, 47.73406080901623, 44.896699860692024, 46.365989819169044, 44.691092893481255, 42.46533192694187, 41.892007291316986, 40.988704562187195, 37.08517782390118, 38.079478070139885, 38.16802091896534, 38.509850576519966, 35.296708792448044, 35.96008099615574, 38.192309215664864, 38.68593692779541, 38.70123490691185, 38.546704798936844, 37.331370413303375, 37.60338641703129, 37.83746525645256, 36.33906126022339, 37.313868552446365, 45.73779992759228, 47.22332261502743, 49.76552680134773, 46.14229962229729, 49.30205047130585, 48.36801499128342, 49.589299857616425, 48.143549636006355, 49.33173447847366, 48.55285607278347, 50.08870705962181, 48.64255025982857, 52.2450153529644, 42.33256325125694, 43.96502025425434, 50.34691080451012, 48.92026215791702, 50.28284624218941, 51.77011303603649, 50.059984400868416, 47.792668864130974, 48.024992197752, 48.359712436795235, 47.14734189212322, 41.17245510220528, 36.59064956009388, 35.30292145907879, 35.322015434503555, 34.718030244112015, 36.72009341418743, 36.27933606505394, 36.31635367870331, 36.59153871238232, 36.07007369399071, 37.97928884625435, 36.045804396271706, 36.10897600650787, 35.87355203926563, 40.72282522916794, 39.385840371251106, 34.86350543797016, 33.53329561650753, 38.1462936848402, 43.8887545466423, 48.915128633379936, 47.51325465738773, 46.42602279782295, 45.41768990457058, 44.82981584966183, 43.14145624637604, 47.54808358848095, 48.40908698737621, 48.76425392925739, 44.587077274918556, 43.99382270872593, 43.344798535108566, 40.42695410549641, 38.93965691328049, 38.674218356609344, 38.387595936656, 40.771333426237106, 39.783838614821434, 41.62941858172417, 43.14345873892307, 46.047164127230644, 47.85352639853954, 45.825092643499374, 23.912076987326145, 4.36727000400424, 0.03556972435035277, 4.430763171985745, 1.9514103443361819, 0.20861550030531362, 0.4164432850666344, 0.38097391021437943, 0.34424947458319366, 0.13771072612144053, 0.4320184711832553, 18.541507869958878, 30.757561661303043, 36.72648087143898, 27.977093160152435, 36.55847668647766, 12.769528292119503, 0.028752441139658913, 0.03660033740743529, 0.06609901916817762, 0.01750751973304432, 0.011782639867305988, 0.03471586118394043, 0.03206401539500803, 0.026169919365202077, 0.1034326986700762, 0.02955441890662769, 0.007342736289501772, 0.09065120131708682, 0.06827865494415164, 0.018466257643012796, 0.044320127854007296, 0.0185634604349616, 0.05542949598748237, 0.03030613843293395, 0.020309628162067384, 0.03053706510399934, 0.07889463216997683, 0.03204091975931078, 0.030051398098294158, 0.0211946800845908, 0.02405577812169213, 0.016179459453269374, 0.04732478322694078, 0.055938026707735844, 0.05914680237765424, 0.005829148367411108, 0.06444303537136875, 0.05357869100407697, 0.15281677100574598, 0.09739244036609307, 0.09675143999629654, 0.12499144300818443, 0.13917486474383622, 16.48428685963154, 48.87836940586567, 42.0016086101532, 31.34663075208664, 42.64744855463505, 40.82425698637962, 54.73209969699383, 18.163697943091393, 0.041726065683178604, 1.1746415379457176, 1.6761847003363073, 2.698121457360685, 3.1459749257192016, 0.5459133815020323, 12.904110420495272, 41.35977365076542, 49.91352505981922, 51.39291487634182, 47.728972882032394, 53.069453313946724, 51.87972955405712, 53.018680438399315, 51.179867908358574, 51.57365597784519, 50.42121581733227, 50.28718180954456, 52.015880048274994, 50.41235089302063, 50.620287135243416, 52.85457484424114, 50.63797138631344, 51.110050454735756, 49.14905548095703, 48.71599651873112, 46.556264609098434, 48.65530617535114, 45.41363552212715, 44.58970293402672, 43.51359687745571, 42.62482836842537, 40.114645063877106, 39.587168768048286, 39.22792464494705, 40.65559923648834, 37.773841470479965, 37.96833023428917, 41.62089563906193, 40.76351344585419, 40.762430503964424, 39.80448290705681, 38.30993190407753, 36.94128714501858, 38.84528137743473, 37.267948016524315, 39.045979008078575, 47.47166968882084, 50.355262756347656, 49.288413003087044, 48.16945664584637, 51.8327222764492, 49.25144098699093, 50.6721505522728, 49.143861159682274, 50.002976059913635, 49.479991123080254, 50.57519115507603, 49.135064631700516, 54.86479617655277, 45.347857251763344, 44.934310242533684, 51.93091660737991, 50.61549939215183, 51.11486479640007, 52.48723715543747, 52.91269652545452, 50.36500543355942, 48.46681348979473, 50.648979395627975, 49.685111716389656, 44.12135146558285, 38.0329267680645, 37.99943156540394, 37.06943526864052, 36.46510049700737, 38.91005650162697, 37.71123602986336, 37.381972298026085, 38.17851975560188, 36.65222905576229, 39.20932464301586, 37.355252131819725, 37.30727210640907, 37.02232539653778, 41.54030576348305, 40.19947551190853, 36.913278847932816, 35.38980759680271, 38.550477996468544, 46.28100737929344, 49.71639923751354, 49.282591715455055, 48.64338621497154, 46.228486597537994, 44.774684607982635, 45.78624352812767, 48.306899070739746, 49.31991711258888, 50.79648368060589, 47.0254672318697, 46.86612658202648, 43.11489187180996, 41.312914565205574, 41.28634639084339, 40.04098981618881, 40.98788380622864, 41.74798741936684, 42.36886650323868, 42.79465265572071, 44.63342718780041, 48.30404542386532, 48.733874559402466, 46.29048407077789, 26.858408488333225, 7.328501930460334, 0.4236424737609923, 4.576059300452471, 3.2659539626911283, 0.12741161626763642, 0.14711965952301398, 0.34277420374564826, 0.12807769380742684, 0.15954056958435103, 0.39046013087499887, 20.48825740814209, 37.065855860710144, 38.71828459203243, 28.450973331928253, 43.48894760012627, 17.23118808120489, 0.07922680262709036, 0.009970675182557898, 0.06045752052159514, 0.04317766572057735, 0.0222430694338982, 0.019974919559899718, 0.0302357475811732, 0.021242123730189633, 0.03200757135346066, 0.08631101038190536, 0.030488493393932004, 0.04066908782988321, 0.06235719964024611, 0.03275017545092851, 0.02001368564378936, 0.038981251054792665, 0.13644891179865226, 0.18852251989301294, 0.11061333367251791, 0.13150090933777392, 0.16299943788908422, 0.13885704742278904, 0.10164814520976506, 0.10304166105925106, 0.10138549914699979, 0.10688787850085646, 0.1283620996400714, 0.19911819195840508, 0.14348432334372774, 0.08232748819864355, 0.1518090086756274, 0.12247311329701915, 0.4398635064717382, 0.17876709258416668, 0.19131112494505942, 0.21472021413501352, 0.39234331576153636, 19.523905254900455, 57.19461835920811, 47.41092994809151, 37.176939100027084, 47.87324734032154, 47.27676294744015, 58.21519799530506, 22.96640843153, 0.14679988293210045, 2.901115114800632, 12.086493093520403, 12.704567927867174, 5.223689898848534, 1.128596558701247, 13.558019232004881, 41.718983575701714, 50.00781700015068, 51.4143381267786, 48.59125301241875, 55.93103416264057, 53.37504431605339, 54.65959198772907, 54.060196951031685, 52.13640198111534, 51.98221005499363, 52.54567041993141, 52.895532846450806, 53.193691447377205, 51.42306625843048, 53.771393448114395, 52.90663585066795, 53.253006264567375, 50.74931301176548, 50.91559588909149, 48.878004625439644, 51.02597236633301, 47.908349856734276, 46.84176608920097, 45.47184459865093, 43.65065172314644, 41.16871990263462, 40.72343699634075, 41.17709085345268, 43.19696746766567, 37.40971840918064, 39.107592701911926, 42.293581143021584, 43.26166279613972, 43.22660967707634, 41.5177995711565, 40.33430367708206, 40.38954511284828, 41.086537912487984, 39.34441119432449, 39.48953680694103, 48.97617235779762, 52.05676585435867, 51.63533426821232, 50.21317318081856, 53.32918077707291, 50.90185962617397, 51.605840250849724, 50.65040431916714, 53.6543445289135, 52.93491393327713, 54.98714581131935, 52.083497419953346, 54.22384276986122, 48.889548406004906, 47.77602955698967, 52.480914294719696, 52.56630711257458, 53.19152556359768, 55.70187605917454, 52.9592402279377, 52.79415048658848, 50.99621616303921, 51.477847918868065, 51.931638568639755, 44.37687635421753, 40.76615430414677, 38.80412578582764, 37.947685942053795, 37.842040210962296, 40.048855394124985, 39.348503574728966, 39.70020890235901, 39.859678745269775, 39.11423474550247, 40.92790402472019, 38.92527848482132, 39.63713988661766, 39.157328233122826, 44.240999445319176, 42.8352040797472, 37.93887801468372, 37.08650015294552, 41.78622096776962, 48.5687468200922, 52.34416343271732, 52.14106433093548, 51.41549326479435, 47.1180834621191, 47.28885009884834, 46.26914821565151, 49.794203862547874, 50.623106583952904, 54.186380580067635, 48.24393264949322, 48.08638170361519, 47.15868428349495, 44.086294546723366, 44.22621823847294, 41.39883175492287, 42.38149702548981, 44.51683044433594, 44.8616049438715, 44.31857228279114, 47.33821325004101, 50.578268989920616, 49.380656853318214, 45.74388340115547, 28.085687533020973, 8.397366050630808, 0.7650783180724829, 8.864734321832657, 5.7712742406874895, 0.35906841221731156, 0.9915554872713983, 3.3365031145513058, 0.6446349935140461, 0.4267984419129789, 0.6689611100591719, 24.57255184650421, 43.32028225064278, 46.61997199058533, 36.20191901922226, 51.27151899039745, 20.223324224352837, 0.15141788200708106, 0.1159054106392432, 0.18513899442041293, 0.1618531165877357, 0.11192683115950786, 0.14019892463693395, 0.070020490384195, 0.10333767408155836, 0.24539717036532238, 0.2953594276914373, 0.11573362571652979, 0.1745987607864663, 0.16025567339966074, 0.10671523268683814, 0.12026678246911615, 0.10622746354783885], [0.020335774024715647, 0.046195802206057124, 0.04806310142157599, 0.022499136357509997, 0.04740375887195114, 0.06181211814691778, 0.009560724865878, 0.04370297639979981, 0.023227571000461467, 0.03412952370126732, 0.022619239971390925, 0.006711619471388985, 0.056888884864747524, 0.05285773535433691, 0.03158013510983437, 0.02278585026942892, 0.04509193175181281, 0.0809236268105451, 0.05065020595793612, 0.08423865205259062, 0.07164119248045608, 2.180407550185919, 35.440447479486465, 39.01362754404545, 25.476337149739265, 29.15195021778345, 32.707311138510704, 37.68788628280163, 23.159802854061127, 0.17110988002968952, 0.6211723212618381, 1.1384407617151737, 4.769482696428895, 2.9252910800278187, 0.34546763577964157, 1.3320552161894739, 18.445753008127213, 44.01276849210262, 51.88444510102272, 50.61368688941002, 47.381686717271805, 50.41266247630119, 49.02570270001888, 48.3653399348259, 49.31634530425072, 50.406430810689926, 47.90041208267212, 49.28452581167221, 50.46391412615776, 49.45339635014534, 50.32684788107872, 51.072345077991486, 51.42880015075207, 50.514022037386894, 51.1451605707407, 51.62477843463421, 49.236507788300514, 48.137177377939224, 47.815676629543304, 46.38786144554615, 44.842719957232475, 40.54602451622486, 37.41515211760998, 36.80059589445591, 35.76414830982685, 36.41925975680351, 36.59797556698322, 35.308731347322464, 38.411261066794395, 44.649667516350746, 38.120116889476776, 36.91701404750347, 36.5143496543169, 37.10711024701595, 36.799186170101166, 36.47982470691204, 43.94484333693981, 46.80373013019562, 50.37392355501652, 46.87832772731781, 46.59194089472294, 51.56956359744072, 50.227612406015396, 50.62830850481987, 50.901912823319435, 50.63083156943321, 50.050541907548904, 50.55891662836075, 50.063636004924774, 41.98210805654526, 48.40287432074547, 50.919038504362106, 47.728406712412834, 47.07449220120907, 45.01033276319504, 45.29258921742439, 43.84072132408619, 44.57701161503792, 41.57805293798447, 39.79300372302532, 35.08907653391361, 35.655778124928474, 36.38959854841232, 35.63069187104702, 35.33643566071987, 36.62435755133629, 37.430575489997864, 34.96628612279892, 36.726389676332474, 37.28562466800213, 35.92261120676994, 34.70478035509586, 35.60433268547058, 35.712417885661125, 35.74603848159313, 37.777075096964836, 37.553381100296974, 35.34164518117905, 35.96341721713543, 39.14313979446888, 43.46799172461033, 44.74925637245178, 47.32135355472565, 47.514842972159386, 47.98341482877731, 45.916675329208374, 45.9529709815979, 47.470267564058304, 48.14130015671253, 48.155374601483345, 46.79803043603897, 44.452317506074905, 44.61183674633503, 39.23197142779827, 40.06073735654354, 38.79051871597767, 39.10412348806858, 42.16734051704407, 43.549170568585396, 43.55945281684399, 49.97355043888092, 47.5958052277565, 37.151556462049484, 9.693386256694794, 0.2251076395623386, 0.17782820155844092, 0.3237032942706719, 0.38830223260447383, 0.05646839512337465, 0.1505598850781098, 0.17757244262611493, 0.0911623852152843, 0.14125906775007024, 0.6035195966251194, 24.162531048059464, 22.175963446497917, 40.0467237085104, 46.57558277249336, 25.348692499101162, 4.279691828414798, 0.09794891011551954, 0.10792460685479455, 0.047645205486333, 0.08785202808212489, 0.035773458730545826, 0.02340191447729012, 0.030235742015065625, 0.033597414949326776, 0.071480710466858, 0.02621637595439097, 0.08533780244761147, 0.07259370933752507, 0.011588808520173188, 0.0638844801869709, 0.048649156888131984, 0.04022755449113902, 0.03498032921925187, 0.028873190422018524, 0.04238515961333178, 0.006083942971599754, 0.0575065706652822, 0.08693782830960117, 0.028138952184235677, 0.045276700548129156, 0.04263369002728723, 0.044472995432442985, 0.025314239792351145, 0.03494559299724642, 0.014947938670957228, 0.020848520143772475, 0.025895300605043303, 0.03714824277267326, 0.10562532945186831, 0.04820815418497659, 0.048320136847905815, 0.017907179244502913, 0.04202597869152669, 4.080956792458892, 43.70823763310909, 45.07225044071674, 29.009904339909554, 39.57393407821655, 42.289021387696266, 45.22701993584633, 24.45628948509693, 0.13609858840936795, 0.265308502712287, 1.698135647457093, 0.8263702166732401, 3.4990156441926956, 0.4683491529431194, 2.7917555579915643, 23.554181791841984, 46.460129767656326, 52.29810230433941, 50.409919023513794, 50.70740506052971, 51.06728754937649, 51.25334456562996, 50.229257717728615, 51.84672452509403, 51.315459832549095, 48.542243242263794, 50.29112219810486, 51.39715924859047, 50.714047104120255, 52.99702540040016, 52.58674621582031, 52.374546602368355, 51.754233688116074, 51.672823056578636, 51.91362373530865, 52.180996388196945, 49.82504680752754, 49.72634710371494, 49.042083621025085, 46.304026544094086, 41.6262723505497, 38.69264356791973, 38.13911207020283, 38.163335770368576, 38.286893740296364, 38.16503047943115, 37.23525457084179, 39.220389649271965, 44.70633007586002, 39.17545326054096, 38.11683766543865, 38.99800278246403, 38.11046160757542, 37.54072777926922, 37.49961398541927, 44.50898766517639, 48.49769063293934, 51.916279792785645, 49.49978806078434, 48.363846614956856, 53.51917438209057, 54.081977382302284, 53.21462832391262, 51.44571304321289, 52.12762825191021, 50.367764085531235, 51.14989131689072, 52.54872925579548, 43.74570742249489, 49.49533849954605, 52.000000700354576, 50.23662932217121, 49.05597947537899, 48.103932961821556, 47.82587148249149, 45.7826679199934, 47.941244691610336, 44.182824566960335, 41.8718645721674, 36.64184421300888, 37.74834483861923, 37.97743074595928, 37.815259248018265, 37.37442210316658, 38.48034515976906, 37.442651242017746, 36.9445663690567, 37.07808740437031, 38.57461430132389, 37.82342880964279, 36.3967839628458, 37.23821081221104, 37.26336166262627, 38.55894774198532, 39.54633615911007, 38.709849044680595, 36.84198707342148, 37.496460154652596, 40.800299271941185, 46.169669553637505, 45.79926162958145, 49.50785122811794, 47.36917398869991, 49.17017474770546, 48.01925450563431, 45.67460551857948, 49.43297244608402, 50.485398173332214, 50.49506485462189, 49.21690843999386, 45.81932835280895, 46.49892948567867, 41.38661541044712, 41.72359652817249, 40.426969304680824, 41.728323474526405, 42.87339583039284, 45.08218690752983, 47.15515047311783, 50.94048835337162, 48.60770232975483, 39.418442621827126, 12.207648642361164, 0.7812701992224902, 0.7213471771683544, 1.522180864121765, 0.5158580036368221, 0.02654650179465534, 0.13748705765465274, 0.1615698536625132, 0.1297622948186472, 0.060916553702554666, 0.3124938363907859, 28.887613601982594, 30.930410586297512, 42.79982037842274, 47.11887761950493, 31.8042553961277, 6.595940189436078, 0.11133473090012558, 0.1007479868712835, 0.05813285424665082, 0.09061106597073376, 0.010213717414444545, 0.040399391364189796, 0.04302855712012388, 0.05590541673882399, 0.03285557897470426, 0.07832619157852605, 0.01638741850911174, 0.02311799104063539, 0.09392272186232731, 0.05585256469203159, 0.007140543721106951, 0.051378115531406365, 0.11235692800255492, 0.12816223927075043, 0.12337857056991197, 0.15195181273156777, 0.25420745776500553, 0.19683927908772603, 0.10439224366564304, 0.12529501109384, 0.18777964491164312, 0.15781673864694312, 0.07121044996893033, 0.21959636185783893, 0.14137411548290402, 0.12819869356462732, 0.054427440772997215, 0.08395251701585948, 0.11213012025109492, 0.14361412497237325, 0.2257557719713077, 0.162608147948049, 0.14617438602726907, 4.712463906034827, 48.6845988035202, 52.88854502141476, 36.636212915182114, 40.03879353404045, 43.799143955111504, 47.06981845200062, 29.017133451998234, 0.2398926016758196, 1.6610250575467944, 5.495122633874416, 8.694791290909052, 8.17901836708188, 0.5569052416831255, 3.3922898210585117, 24.080774635076523, 47.77488961815834, 52.90535531938076, 50.86010366678238, 50.11243298649788, 54.15660917758942, 55.509488582611084, 53.14576841890812, 52.98606678843498, 53.384224623441696, 47.996201142668724, 50.919251292943954, 52.34099440276623, 52.009260803461075, 54.73657205700874, 54.72469009459019, 55.24017423391342, 54.618219807744026, 55.11057458817959, 55.11857695877552, 53.87909486889839, 51.971221044659615, 52.03062325716019, 50.72998724877834, 49.176911786198616, 43.73856380581856, 39.80459310114384, 40.121898874640465, 38.85209061205387, 40.99573418498039, 40.46931803226471, 38.28937120735645, 41.93112999200821, 46.651320308446884, 41.82242162525654, 39.522287249565125, 40.759223476052284, 40.398733019828796, 39.45307016372681, 39.39898006618023, 47.73736283183098, 51.09429270029068, 54.500859305262566, 51.12827427685261, 51.79966785013676, 55.612083077430725, 53.38572554290295, 55.56073263287544, 54.83930714428425, 54.19652983546257, 53.31791818141937, 53.47412399947643, 52.558031156659126, 45.368497744202614, 50.96377730369568, 55.03309294581413, 52.448053658008575, 49.86724354326725, 49.94760163128376, 50.39580658078194, 47.27782689034939, 49.3492591381073, 45.797300934791565, 42.66498081386089, 38.09735611081123, 39.3696266412735, 40.39729669690132, 39.457261338829994, 38.36194731295109, 41.35691240429878, 39.50363025069237, 38.29251743853092, 40.30918322503567, 40.2431845664978, 40.3077507019043, 37.90966518223286, 38.486371636390686, 38.87469179928303, 39.78084817528725, 40.47320902347565, 39.68655243515968, 39.0834753960371, 40.32710686326027, 41.6939353197813, 47.811800837516785, 47.99787685275078, 49.89484146237373, 49.03913877904415, 50.26013106107712, 49.9179632216692, 46.077786684036255, 50.39896801114082, 52.14089334011078, 52.56028823554516, 51.39874376356602, 48.05331587791443, 48.729576990008354, 43.82364884018898, 43.85627768933773, 42.14903689920902, 43.62679660320282, 46.244472339749336, 48.122369572520256, 49.08041596412659, 54.42582853138447, 48.780471459031105, 41.15277595818043, 15.704694092273712, 1.4279763191007078, 0.9629109618254006, 1.4197431108914316, 0.711377402767539, 0.2703882066998631, 0.3632052621105686, 0.5158660188317299, 0.279035473940894, 0.331436651176773, 1.6167570766992867, 33.81438933312893, 34.856236428022385, 48.02940376102924, 54.56253759562969, 39.52864430844784, 7.9072474502027035, 0.23020134045509622, 0.2210438615293242, 0.17551023687701672, 0.1783054618863389, 0.09726085016154684, 0.1257396169239655, 0.1786758826347068, 0.13489651697454974, 0.1761397859081626, 0.1603281663847156, 0.20345910277683288, 0.2527389256283641, 0.12415781820891425, 0.21163243451155722, 0.16413373639807105, 0.18800828576786444], [0.017721352887747344, 0.01621570780116599, 0.01160371177320485, 0.05215474338911008, 0.011287854649708606, 0.031141210420173593, 0.04300021450035274, 0.020666953714680858, 0.04524018688243814, 0.06068474016501568, 0.08160350087564439, 0.08451248970231973, 0.07152835634769872, 0.037791410213685594, 0.02768705289781792, 0.045173234029789455, 0.028218877778272144, 0.07394410640699789, 0.06270911122555844, 0.016885596269275993, 0.011958538143517217, 0.3223105502547696, 16.236352063715458, 47.59973041713238, 34.18285556137562, 31.44377063959837, 29.72457569092512, 32.01316058635712, 24.10220168530941, 0.7795641501434147, 0.30152067833114415, 1.060578664764762, 0.3306559711927548, 3.1969199795275927, 2.5666109891608357, 0.44467823405284435, 3.7781847640872, 28.93952451646328, 50.07940895855427, 50.752284452319145, 51.8070812523365, 50.641132816672325, 47.65630558133125, 47.911530286073685, 47.56172485649586, 46.85406222939491, 50.092696845531464, 46.99276618659496, 49.044853672385216, 46.910530999302864, 48.26737359166145, 50.55254057049751, 48.891083523631096, 48.71886536478996, 51.55127137899399, 50.99416807293892, 50.845444053411484, 49.82210576534271, 49.41258653998375, 49.61951203644276, 48.2310551404953, 45.22630177438259, 41.4948146045208, 36.41677848994732, 35.70439271628857, 38.260971531271935, 37.91799433529377, 36.026064455509186, 37.75242581963539, 41.110301837325096, 38.62617373466492, 37.57798857986927, 38.1237380951643, 37.286274433135986, 36.21823914349079, 36.41818821430206, 39.700729474425316, 45.730207934975624, 46.79776445031166, 51.92109413444996, 47.06205926835537, 50.23225195705891, 48.040483966469765, 49.580020755529404, 50.398994609713554, 49.98479403555393, 48.02655391395092, 49.491895884275436, 49.306131452322006, 41.92970506846905, 47.77765206992626, 49.66131739318371, 46.30377575755119, 45.18884338438511, 40.097785368561745, 39.82353128492832, 38.061600029468536, 38.009539023041725, 37.28640742599964, 37.326499074697495, 35.278830751776695, 33.48860241472721, 35.68445898592472, 36.14087529480457, 35.27341604232788, 36.52895227074623, 36.06160394847393, 36.747786328196526, 37.17123560607433, 35.342397540807724, 34.75805349647999, 35.20099952816963, 36.69446378946304, 35.230964720249176, 34.40431147813797, 35.851916000247, 35.022697895765305, 35.11318624019623, 34.586667492985725, 35.17652504146099, 37.60612986981869, 42.35733412206173, 42.86660939455032, 44.772317335009575, 48.02621193230152, 47.98738181591034, 47.17299431562424, 45.75528658926487, 44.40994217991829, 47.060261964797974, 49.397687539458275, 46.42317675054073, 45.16573682427406, 44.98607486486435, 42.09028825163841, 40.285685285925865, 37.693278193473816, 40.56754656136036, 45.057769417762756, 46.02066434919834, 46.70773588120937, 46.283796429634094, 23.23034416884184, 1.9282174576073885, 0.9714683995116502, 1.2451101816259325, 1.8478698190301657, 0.9329132933635265, 0.046729424939258024, 0.1230478695651982, 0.060002828904544, 0.014590776390832616, 0.2837582939537242, 5.852193273603916, 30.10021783411503, 19.457524716854095, 32.456315606832504, 50.45208156108856, 18.69516022503376, 0.493017666740343, 0.03713890284416266, 0.009041938592417864, 0.04729325679363683, 0.06406561617041007, 0.02922451385529712, 0.012799979613191681, 0.01640993341425201, 0.036274683006922714, 0.026223541390208993, 0.021076300108688883, 0.04066766661708243, 0.036668796819867566, 0.0685304582293611, 0.022989963144937064, 0.0510483422112884, 0.03022626849997323, 0.07172215337050147, 0.059906401656917296, 0.027447728825791273, 0.03753418925043661, 0.02929325528384652, 0.012193719176138984, 0.03832647642411757, 0.036226636366336606, 0.05501003412064165, 0.06387512170476839, 0.0586963595560519, 0.053723918172181584, 0.03514344214636367, 0.03529136702127289, 0.0214301412779605, 0.05510436480108183, 0.018592467276903335, 0.10375333615229465, 0.04579409251164179, 0.039989440119825304, 0.021701216282963287, 0.5580379371531308, 24.14205014705658, 52.1211875975132, 35.935629308223724, 33.41452158987522, 36.06950372457504, 35.24208292365074, 26.879124976694584, 0.3877468389691785, 0.17478487658081576, 0.4427157581085339, 0.1916084293043241, 3.0772741371765733, 2.980980179272592, 0.4561305226525292, 6.473523108288646, 33.47642406821251, 51.954619735479355, 51.4537800103426, 52.38465026021004, 51.423978209495544, 50.99298633635044, 50.024490505456924, 49.837551936507225, 50.03224968910217, 50.74502304196358, 48.311322033405304, 50.09061835706234, 46.46449193358421, 49.72612291574478, 52.82809026539326, 50.16635589301586, 51.27123400568962, 53.36598940193653, 51.78436607122421, 52.15070441365242, 50.01371428370476, 50.87617680430412, 51.45562291145325, 49.00934837758541, 45.53983815014362, 42.44691051542759, 38.10735337436199, 38.37186858057976, 39.72342185676098, 39.90619584918022, 37.80292510986328, 39.52042154967785, 43.09692643582821, 40.421395003795624, 38.36519993841648, 38.39414678514004, 39.021101742982864, 38.80313403904438, 37.99585975706577, 41.354453936219215, 47.34318718314171, 49.7177367657423, 51.951378509402275, 48.53369750082493, 51.052168160676956, 49.47570875287056, 51.146733686327934, 52.4040862172842, 51.38361297547817, 50.62635540962219, 51.482426673173904, 49.49745498597622, 44.112011566758156, 50.6627194583416, 51.873216703534126, 49.14530888199806, 46.7425724118948, 42.60386489331722, 42.85624735057354, 42.1586237847805, 40.58840364217758, 39.05868172645569, 38.27214293181896, 37.52624675631523, 36.69679306447506, 37.57198870182037, 37.111605405807495, 36.74179024994373, 38.23365859687328, 37.9102997481823, 37.780684903264046, 38.82770352065563, 37.56688177585602, 37.276136577129364, 36.61189042031765, 38.361635729670525, 37.93635115027428, 36.59141331911087, 36.870941519737244, 37.93582297861576, 37.61146478354931, 36.51415966451168, 37.53329157829285, 40.164612382650375, 44.26893174648285, 45.35223461687565, 46.13304331898689, 49.19993095099926, 49.751216769218445, 48.76466430723667, 47.3516683280468, 45.95663778483868, 47.733741626143456, 51.335233971476555, 48.53894501924515, 47.03255005180836, 46.09095297753811, 43.234699442982674, 41.952401250600815, 39.437745586037636, 42.22349390387535, 46.73490062355995, 47.25732319056988, 50.05195163190365, 48.09943400323391, 27.672605998814106, 3.180717173963785, 1.2725681019946933, 3.7692806543782353, 1.8783477460965514, 1.0319778369739652, 0.02648040983331157, 0.08149436063831672, 0.050466917746234685, 0.12121838648454286, 0.5051177018322051, 6.219754200428724, 37.29933053255081, 26.038678474724293, 36.8627567589283, 56.14514507353306, 24.551092498004436, 1.0358871147036552, 0.05227423658652697, 0.04048691283969674, 0.05778612656285986, 0.05813632749777753, 0.027621838526101783, 0.008023626633075764, 0.023307338888116647, 0.012636720111913746, 0.011760752076952485, 0.05338821509212721, 0.014707064437970985, 0.05414657498477027, 0.06949054499273188, 0.055424753663828596, 0.04171703003521543, 0.06772617794922553, 0.12246436337591149, 0.11385127203539014, 0.12828418897697702, 0.19535971863660961, 0.09101216710405424, 0.08025176051887684, 0.13462641974911094, 0.11085956342867576, 0.11673009255900979, 0.10459471639478579, 0.1420020911609754, 0.17800563422497362, 0.13043045037193224, 0.1958043096237816, 0.11583781582885422, 0.07548030756879598, 0.11896952317329124, 0.15974145411746576, 0.17705835693050176, 0.0961887881567236, 0.1561755978036672, 0.701747591374442, 25.142270475625992, 59.0694073587656, 43.86370629072189, 39.3013709038496, 38.21641892194748, 40.68893484771252, 30.79824797809124, 1.0535811027511954, 0.5300448392517865, 4.211529660969973, 0.6059880391694605, 6.9112244714051485, 5.469736196100712, 1.0139261931180954, 7.384809209033847, 33.96579600870609, 52.44353570044041, 51.8743072450161, 54.08054865896702, 53.10170218348503, 52.1721238642931, 52.19015769660473, 54.132708460092545, 51.06544464826584, 53.84818732738495, 49.86573122441769, 50.36015309393406, 48.125310614705086, 50.74692294001579, 53.69117975234985, 51.12836927175522, 51.967052668333054, 53.715927824378014, 53.842130452394485, 54.294313788414, 53.02123390138149, 52.74639844894409, 52.92405791580677, 52.01788254082203, 47.88125351071358, 45.00158183276653, 39.79523800313473, 39.0398271381855, 42.24562391638756, 41.064483895897865, 39.400872364640236, 42.443809881806374, 43.41714285314083, 42.38804027438164, 40.42182058095932, 40.91501511633396, 42.47079223394394, 39.94126416742802, 39.05786857008934, 43.45336250960827, 49.82317730784416, 51.328553929924965, 53.98599833250046, 50.239779353141785, 52.38533042371273, 49.89735312759876, 54.12101648747921, 54.8284625262022, 52.594843581318855, 50.54045721888542, 51.30249112844467, 50.25084815919399, 46.53048299252987, 52.821193635463715, 52.409918904304504, 50.71342393755913, 48.674221560359, 43.661496341228485, 44.75733853876591, 42.66928978264332, 42.79022969305515, 40.200353264808655, 40.034887343645096, 38.964214995503426, 37.07365684211254, 39.137029722332954, 39.70598079264164, 38.52835938334465, 39.421391263604164, 40.36587618291378, 40.52131824195385, 40.83946757018566, 39.186218082904816, 37.80672490596771, 37.853675186634064, 39.32594418525696, 37.59777791798115, 38.01653824746609, 38.08887116611004, 38.159912154078484, 38.64004299044609, 39.001585990190506, 38.451751694083214, 42.214989960193634, 45.72240695357323, 47.0819777995348, 48.29402156174183, 51.24148540198803, 51.883985325694084, 50.72051055729389, 48.400461450219154, 46.39934442937374, 48.03500086069107, 52.45623841881752, 49.909702464938164, 49.73238117992878, 48.45067575573921, 45.7074623554945, 44.5841970294714, 41.66566863656044, 45.60116305947304, 48.596534729003906, 50.24880386888981, 52.1817297488451, 47.38162972033024, 28.627888038754463, 4.250659486278892, 1.48762195603922, 4.06147476285696, 3.850994794629514, 2.180334641598165, 0.2513384335907176, 0.5214372323825955, 0.15828072937438264, 0.31469181063584983, 0.8296843513380736, 12.70812263712287, 38.92502389848232, 29.131811298429966, 40.65584622323513, 58.80121394991875, 29.331792667508125, 1.3225884991697967, 0.201736860035453, 0.12914326944155619, 0.12604941905010492, 0.17039507307345048, 0.1242958205693867, 0.16094175924081355, 0.08539027970982715, 0.1615484946523793, 0.1398998242802918, 0.17227900010766461, 0.0607063366624061, 0.200931258732453, 0.14858710812404752, 0.14930647186702117, 0.1434054330457002, 0.19821014459012076], [0.022316931681416463, 0.04987746324331965, 0.02864905254682526, 0.05101743547129445, 0.033618688612477854, 0.07669777114642784, 0.053727499034721404, 0.0512410890951287, 0.10548277030466124, 0.08650576477521099, 0.03752630764211062, 0.042932066789944656, 0.020582374854711816, 0.03318850271170959, 0.029221754921309184, 0.05870154716831166, 0.04243739938829094, 0.0695332110626623, 0.03849445412924979, 0.01633536427107174, 0.010674245095287915, 0.013384967314777896, 5.963890179991722, 36.7146635055542, 40.1564884185791, 28.1990734487772, 37.563028782606125, 33.637885004282, 24.457404725253582, 1.3764812448062003, 0.038482769014080986, 0.2230994324781932, 0.0568351533729583, 0.5183343426324427, 5.587716540321708, 1.7145973141305149, 0.5851735279429704, 9.601873867213726, 40.700965002179146, 53.004112020134926, 52.047669142484665, 52.06621594727039, 50.588368847966194, 50.20358629524708, 50.728847309947014, 48.13691899180412, 51.117175072431564, 48.463439270853996, 47.50844791531563, 49.77394714951515, 48.986671194434166, 48.49335506558418, 49.61690157651901, 47.76986248791218, 48.553992211818695, 47.626233994960785, 50.43287359178066, 49.84568729996681, 48.879995718598366, 49.15288187563419, 49.641334265470505, 45.8836854994297, 41.81310452520847, 38.4600580483675, 36.85275189578533, 36.734813824296, 36.17540404200554, 36.29838444292545, 36.951026022434235, 36.10403627157211, 37.09474951028824, 36.35356888175011, 36.66337385773659, 38.817459270358086, 35.87932772934437, 36.178744062781334, 37.295534536242485, 44.14324589073658, 47.218724861741066, 48.58551152050495, 48.067101538181305, 45.103963539004326, 50.43039992451668, 46.554174721241, 48.083231672644615, 48.311607018113136, 49.03721608221531, 42.551344111561775, 46.0847707092762, 39.52871270477772, 48.246649503707886, 48.799637630581856, 47.967372089624405, 43.382177129387856, 38.527018055319786, 38.88669155538082, 37.098005935549736, 36.08297020196915, 34.924108386039734, 36.5437600761652, 36.62456654012203, 36.67755849659443, 37.539618238806725, 38.35305579006672, 36.443589851260185, 36.120227202773094, 36.279556453228, 35.19738592207432, 35.701630264520645, 35.05069479346275, 37.318910881876945, 37.472320050001144, 34.792035073041916, 35.232876017689705, 34.69496548175812, 35.51812671124935, 37.09087751805782, 35.7568185031414, 34.74318869411945, 35.74423357844353, 35.11869974434376, 37.300687059760094, 38.40029485523701, 41.25451549887657, 43.92997853457928, 44.16386738419533, 46.42834447324276, 46.36076129972935, 45.46788141131401, 45.72709210216999, 45.07546126842499, 47.50022895634174, 48.7557727843523, 42.37499937415123, 41.7963208258152, 41.637588143348694, 39.66905057430267, 42.946059331297874, 42.880991622805595, 47.237340062856674, 45.84083519876003, 42.054969146847725, 11.504467874765396, 0.281175768468529, 0.8047322183847427, 1.0266751027666032, 2.379418546333909, 0.33085474802646786, 0.04122446662222501, 0.05532690149266273, 0.01647962479182752, 0.0739786088524852, 0.3615107905352488, 9.350156374275684, 34.54859733581543, 27.712503857910633, 32.57839925587177, 34.7384275496006, 6.445254050195217, 0.13051771209575236, 0.027919603016925976, 0.0528413598658517, 0.04742420504044276, 0.01981019802769879, 0.06593177618924528, 0.014602302871935535, 0.06034382349753287, 0.0258471203778754, 0.026583581347949803, 0.023306049406528473, 0.08946495989221148, 0.026600029195833486, 0.03733241042937152, 0.08060465916059911, 0.01425072525307769, 0.0056578931526019005, 0.009824197495618137, 0.0162739571169368, 0.04783121738000773, 0.01571742985106539, 0.019348637833900284, 0.07562381666502915, 0.04293276811949909, 0.04248228076903615, 0.028689098835457116, 0.05455676371639129, 0.026839837519219145, 0.1026309936423786, 0.026065257989102975, 0.01297217271712725, 0.027635557125904597, 0.015148005913943052, 0.1000156652298756, 0.012472372436604928, 0.08705854605068453, 0.03590363514376804, 0.022159626059874427, 0.03851263674732763, 9.714306984096766, 45.930498987436295, 42.26648859679699, 29.624122381210327, 37.59299777448177, 37.06141009926796, 26.856271103024483, 1.4033282292075455, 0.11783539535827003, 0.31837693008128554, 0.13738228124566376, 1.0002164100296795, 4.52063262462616, 1.7997630941681564, 1.5468743140809238, 11.721006855368614, 43.82520295679569, 54.92406539618969, 53.44282887876034, 53.74573342502117, 51.10083594918251, 51.64742521941662, 50.71358732879162, 49.258915185928345, 51.58868037164211, 47.95315705239773, 48.75822365283966, 51.67504593729973, 49.596348479390144, 49.49352599680424, 50.11035069823265, 48.64831455051899, 48.661910220980644, 47.964792028069496, 51.803798228502274, 50.20069845020771, 49.94190193712711, 52.14060075581074, 51.778168603777885, 47.72233463823795, 42.758554592728615, 40.1653191447258, 37.068112939596176, 38.47352832555771, 37.31712497770786, 38.319993764162064, 37.700068429112434, 37.88685120642185, 37.851034328341484, 37.619771137833595, 39.847963973879814, 39.402947053313255, 37.40030251443386, 38.66177402436733, 39.857201278209686, 45.89841730892658, 48.509299010038376, 49.358405247330666, 50.63907332718372, 46.26690253615379, 51.38083912432194, 47.61254332959652, 50.201868787407875, 48.557731211185455, 49.5938216149807, 43.88715103268623, 44.654778242111206, 43.08849088847637, 50.07832981646061, 50.60066118836403, 49.803121984004974, 45.066805332899094, 40.75376696884632, 40.43241821229458, 39.406180679798126, 37.68992677330971, 37.77911938726902, 37.66343839466572, 38.85770671069622, 37.629323825240135, 38.402985110878944, 40.851269736886024, 37.7380245923996, 38.78287352621555, 37.00405217707157, 37.72812992334366, 37.5660116225481, 36.62870451807976, 38.415779024362564, 39.08024176955223, 36.19563415646553, 37.76840016245842, 37.61569395661354, 36.688676699995995, 37.4007622897625, 37.380866557359695, 36.32117561995983, 36.15725241601467, 37.610013261437416, 39.746965393424034, 41.34362831711769, 43.78449194133282, 46.716209426522255, 47.05077387392521, 48.307704627513885, 48.77028040587902, 46.91406860947609, 47.69067853689194, 46.194246634840965, 49.226183742284775, 49.3602329492569, 45.777458399534225, 43.90508607029915, 44.037638157606125, 42.49203309416771, 44.55400004982948, 45.53449183702469, 49.33200426399708, 47.255126908421516, 43.265021815896034, 13.465052470564842, 1.5647808532230556, 3.161411597393453, 5.669171344488859, 3.924879217520356, 0.2207153127528727, 0.05614657391561195, 0.01920660746691283, 0.02820480294758454, 0.5410307028796524, 1.1572226788848639, 12.14691935107112, 36.95004187524319, 24.908256232738495, 35.457014590501785, 42.880159467458725, 11.211826577782631, 0.1410256326198578, 0.03773488824663218, 0.05419936765974853, 0.010344080292270519, 0.03012246987054823, 0.039637035006308, 0.04512875711952802, 0.06739322823705152, 0.03150797238049563, 0.06177015711728018, 0.042763933233800344, 0.03893725654052105, 0.028744758055836428, 0.01685192317381734, 0.09179085071082227, 0.054856806600582786, 0.08244156371802092, 0.2221033367095515, 0.25197896640747786, 0.1281695271609351, 0.12081856926670298, 0.12964212626684457, 0.1785376205225475, 0.1850738635403104, 0.15034890733659267, 0.24919205345213413, 0.24099651665892452, 0.10383379980339669, 0.19809897086815909, 0.07664814373129047, 0.10891216050367802, 0.07274043193319812, 0.10628051226376556, 0.20592358225258067, 0.18813967559253797, 0.1882249632035382, 0.09172447302262299, 0.1160564154270105, 0.19912016607122496, 11.14659832790494, 49.079557210206985, 51.188736632466316, 37.698791697621346, 45.36911331117153, 43.665269538760185, 31.37257196009159, 1.9181783962994814, 0.25920534739270806, 1.5880344179458916, 0.4097517253831029, 1.3757160608656704, 9.549720715731382, 4.306738302111626, 2.134666317142546, 12.743402794003487, 46.006304919719696, 54.60513710975647, 53.37947107851505, 55.131606459617615, 53.758436143398285, 52.410416677594185, 52.42169447243214, 50.71429409086704, 53.2803799957037, 49.96659301221371, 49.606528133153915, 54.55407924950123, 51.223584562540054, 49.55293580889702, 52.0911768078804, 48.72358091175556, 49.543132334947586, 48.89495171606541, 52.16582000255585, 51.025026217103004, 50.63647046685219, 52.182626500725746, 53.325947150588036, 49.16288673877716, 45.38985259830952, 41.77186153829098, 39.34151954948902, 41.439888551831245, 40.01141220331192, 41.188866421580315, 41.292996034026146, 39.01257500052452, 40.32060921192169, 40.31663462519646, 41.55970752239227, 42.690253257751465, 39.38941977918148, 39.71165768802166, 42.31911197304726, 49.37389321625233, 49.3101554363966, 51.95173189043999, 52.27443337440491, 48.008892461657524, 52.68974728882313, 47.16770499944687, 52.11592487990856, 49.93864171206951, 50.50885811448097, 42.50350467860699, 44.69011254608631, 43.20637196302414, 54.24919880926609, 51.20623089373112, 52.61346638202667, 47.918449714779854, 43.148820251226425, 41.978760436177254, 41.17256909608841, 39.63634192943573, 38.42734940350056, 39.41856801509857, 40.33894322812557, 39.105491414666176, 40.019965544342995, 42.61589504778385, 39.385745376348495, 40.28883531689644, 39.91616651415825, 38.461186587810516, 38.55536833405495, 38.72907221317291, 40.26923976838589, 39.92644116282463, 39.169419184327126, 40.024665892124176, 39.468717724084854, 38.46716366708279, 40.03715202212334, 39.38200257718563, 38.81544917821884, 38.97495701909065, 39.688809514045715, 41.84843122959137, 43.12319062650204, 45.92176705598831, 47.63763338327408, 48.37530680000782, 50.441081151366234, 50.12065574526787, 46.94828577339649, 47.524661645293236, 46.562781259417534, 50.72730839252472, 50.51962673664093, 48.136569410562515, 46.04371391236782, 45.465042963624, 44.638758301734924, 47.56865568459034, 46.3859311491251, 51.62367269396782, 48.690526485443115, 44.050063490867615, 15.103206317871809, 1.676670836750418, 4.2311290092766285, 6.0486052092164755, 5.1643408834934235, 0.5630876286886632, 0.23208075523143634, 0.2813997189514339, 0.10253124157316051, 0.8287328586447984, 2.9793398547917604, 17.292784675955772, 46.467847153544426, 36.92333310842514, 41.66296698153019, 46.130413860082626, 13.225337583571672, 0.278332392917946, 0.08144799125147983, 0.2797180420020595, 0.11371942950063385, 0.18488293862901628, 0.15746061166282743, 0.14004561176989228, 0.26439349399879575, 0.08820333852781914, 0.1509384100791067, 0.177581942116376, 0.16941111884079874, 0.14989126939326525, 0.16648328688461334, 0.1958386116893962, 0.0938224428682588, 0.1363821778795682], [0.07200992113212124, 0.01838141160988016, 0.01529071070763166, 0.08780709104030393, 0.02040050228970358, 0.07483803812647238, 0.041389943289686926, 0.05964803778624628, 0.07363544718828052, 0.031723458669148386, 0.01961046567885205, 0.010989786806021584, 0.047656586320954375, 0.05089380851131864, 0.04623543289199006, 0.023426318148267455, 0.01991957575228298, 0.037145556198083796, 0.021217972389422357, 0.054630904269288294, 0.04276874977222178, 0.028892055815958884, 1.1624519107863307, 22.326792553067207, 39.778720289468765, 33.58662575483322, 30.994891226291656, 34.426946863532066, 28.778905235230923, 6.372042903676629, 0.033845221769297495, 0.03393835017050151, 0.06151046109152958, 0.14459453173913062, 0.46962736872956157, 4.059400549158454, 1.2177825230173767, 0.9145133150741458, 16.83150462806225, 48.23374539613724, 50.69058336317539, 52.70674377679825, 51.58093258738518, 52.39145569503307, 52.365791872143745, 51.39920353889465, 50.04174157977104, 52.76629418134689, 51.45177371799946, 52.10666477680206, 51.17102578282356, 50.177626088261604, 50.75981564819813, 48.819822147488594, 49.04614180326462, 52.030034288764, 53.45796346664429, 48.033933117985725, 49.25006926059723, 49.00820083916187, 50.1879995316267, 49.71439674496651, 44.86823558807373, 38.14214810729027, 36.96225441992283, 35.939463302493095, 37.42342807352543, 37.27414928376675, 38.26902709901333, 36.878043338656425, 37.29633629322052, 36.85329146683216, 38.67295302450657, 37.73419439792633, 37.72896967828274, 38.29124070703983, 38.78893420100212, 40.43486528098583, 46.59846134483814, 48.761639669537544, 51.93834140896797, 33.55655036866665, 35.64144529402256, 46.30347937345505, 44.02352951467037, 43.62850271165371, 43.871845453977585, 43.67114782333374, 44.942054226994514, 38.46329927444458, 44.42651309072971, 51.858705282211304, 46.798007637262344, 44.35409277677536, 42.331537306308746, 41.024209856987, 38.63848127424717, 37.10050240159035, 38.64507772028446, 37.92392201721668, 37.39978954195976, 35.50771526992321, 37.2132233530283, 35.62269330024719, 36.67515702545643, 36.363832131028175, 35.54019972681999, 34.47249881923199, 36.19133658707142, 34.676722660660744, 37.97189824283123, 38.5772817581892, 36.287650018930435, 35.141137540340424, 35.829888582229614, 37.32481576502323, 34.05268594622612, 35.00238798558712, 34.40775789320469, 35.080743581056595, 33.71671937406063, 34.477693140506744, 33.17681394517422, 37.93553039431572, 40.6805182993412, 43.039633110165596, 44.944953471422195, 46.63906216621399, 46.95588156580925, 45.65874896943569, 45.90855896472931, 45.617445185780525, 45.091553404927254, 43.37196707725525, 44.61372524499893, 44.005267694592476, 41.730192974209785, 42.6739901304245, 44.32731941342354, 47.14378148317337, 47.353705018758774, 26.480209082365036, 4.576308662071824, 0.17041278071701527, 2.79778559692204, 6.455687815323472, 0.9111132100224495, 0.20719495543744415, 0.04402939521241933, 0.07891876681242138, 0.11071447355789132, 0.38457899645436555, 0.4260213836096227, 19.8311073705554, 43.690344393253326, 33.67896839976311, 39.36295039951801, 22.51214660704136, 1.2208945560269058, 0.06546545511810109, 0.05000430370273534, 0.11520264873979613, 0.039975476611289196, 0.020096481493965257, 0.05642673837428447, 0.018661370122572407, 0.01765440931194462, 0.03966023083194159, 0.047939233263605274, 0.014181535752868513, 0.053881939966231585, 0.04685980544309132, 0.03528874723997433, 0.018346302458667196, 0.033573016844457015, 0.031246869984897785, 0.05470474796311464, 0.04180851829005405, 0.062017548334551975, 0.01801551981770899, 0.07997339576832019, 0.07689147169003263, 0.04926869805785827, 0.04014841186290141, 0.05134087456099223, 0.08172601461410522, 0.034688954619923607, 0.03252012080338318, 0.10747982290922664, 0.03918309295841027, 0.05345706042135134, 0.016554934227315243, 0.009649421717767837, 0.016763665116741322, 0.01953867216798244, 0.025557111330272164, 0.04667362285545096, 0.01421956989361206, 1.9134507374837995, 29.754181802272797, 45.49259528517723, 33.28840635716915, 36.27161867916584, 39.408057779073715, 31.87004316598177, 6.086106821894646, 0.10404955697595142, 0.1179707630944904, 0.0332363044435624, 0.18426688184263185, 0.9596409997902811, 4.059318378567696, 4.200103199109435, 2.196714375168085, 21.018826737999916, 49.95393589138985, 51.99383743107319, 52.22164660692215, 53.995908200740814, 53.05539406836033, 51.645852103829384, 51.505100056529045, 50.482859909534454, 53.22298787534237, 52.424206137657166, 52.35432408750057, 52.391174510121346, 52.300670966506004, 52.37931154668331, 51.17338165640831, 50.651681050658226, 53.198141008615494, 52.63871982693672, 48.62026825547218, 50.234102457761765, 49.955478608608246, 52.49278865754604, 50.34884870052338, 46.49584785103798, 40.085660219192505, 39.64856207370758, 37.772443145513535, 37.993743270635605, 38.270026445388794, 40.12910708785057, 39.275125712156296, 39.78274807333946, 38.52901294827461, 39.86503265798092, 40.25368720293045, 39.06035743653774, 39.69067521393299, 40.39232276380062, 42.99763396382332, 48.7026060372591, 51.40235736966133, 52.72070802748203, 36.85873657464981, 39.216111078858376, 47.07121677696705, 44.59625378251076, 44.070840775966644, 44.61062081158161, 43.576456904411316, 44.445774257183075, 40.946154445409775, 47.80077762901783, 52.46759980916977, 47.37168185412884, 46.79572395980358, 44.68574658036232, 43.067337423563, 41.81438885629177, 37.57040038704872, 40.5873890966177, 38.95849630236626, 38.39820496737957, 37.05976098775864, 39.418476819992065, 37.9676728695631, 38.30765202641487, 37.43285536766052, 35.116845443844795, 37.492565363645554, 38.278294801712036, 37.79970668256283, 40.47204628586769, 40.08587300777435, 37.18573562800884, 37.608888521790504, 37.36103542149067, 36.32027126848698, 35.99412716925144, 35.0883811712265, 36.326434537768364, 36.54078483581543, 34.160368368029594, 34.59833666682243, 35.40457360446453, 39.71635803580284, 43.82468618452549, 45.93292325735092, 49.27818775177002, 47.24639117717743, 47.45180055499077, 47.09992043673992, 46.324142664670944, 45.56918777525425, 46.63191094994545, 45.83105452358723, 47.88632243871689, 45.422386452555656, 42.68731601536274, 44.9037104845047, 46.390103325247765, 47.949064671993256, 47.51101657748222, 28.851513639092445, 6.164635308086872, 0.744950738735497, 8.202027082443237, 10.198943428695202, 4.240945307537913, 0.6139090110082179, 0.013277866128191818, 0.01272778998099966, 0.1205848521203734, 0.4532086872495711, 0.9433401713613421, 24.101715311408043, 46.265230625867844, 34.47972983121872, 41.51535630226135, 29.05360769480467, 2.1269719675183296, 0.07176226645242423, 0.04215537213895004, 0.036530111683532596, 0.0480883307318436, 0.023192387634480838, 0.05093599218525924, 0.0322405240876833, 0.028790958604076877, 0.019314625205879565, 0.04940608443575911, 0.010837157642527018, 0.037955925799906254, 0.020396949257701635, 0.05803050837130286, 0.030997820067568682, 0.08005313211469911, 0.028592847847903613, 0.16741806641221046, 0.1584894658299163, 0.2050261030672118, 0.19490972481435165, 0.13572766300057992, 0.14806359715294093, 0.1374541359837167, 0.1655552163720131, 0.19007964961929247, 0.21063003048766404, 0.16906878096051514, 0.10601862319163047, 0.18352041486650705, 0.13603960251202807, 0.1585981310927309, 0.0915639019513037, 0.10837984023964964, 0.16781875194283202, 0.09553723444696516, 0.16206419822992757, 0.11692471336573362, 0.12183841376099735, 2.4890417139977217, 34.6597907692194, 52.34432302415371, 43.69089916348457, 40.58476343750954, 45.69190979003906, 38.07233065366745, 9.804009720683098, 0.1710027435910888, 0.5132928444072604, 0.5560276075266302, 0.3621752798790112, 1.3584836293011904, 7.032338697463274, 6.710039991885424, 2.012617103755474, 21.548128835856915, 50.30478626489639, 51.557879224419594, 53.364097103476524, 56.57632313668728, 54.81455147266388, 54.07310485839844, 53.9458192884922, 51.10780097544193, 54.185385033488274, 53.7510721385479, 53.73694069683552, 53.28839756548405, 52.94702388346195, 54.7812120616436, 52.815980315208435, 51.35192647576332, 53.16608592867851, 56.16919778287411, 50.15659421682358, 50.86167298257351, 50.94868451356888, 52.56631851196289, 53.016837537288666, 49.428473487496376, 40.49917683005333, 40.33463045954704, 39.521686881780624, 41.01119935512543, 40.60558632016182, 42.47113421559334, 41.53646796941757, 41.73593446612358, 39.35253515839577, 42.62821018695831, 43.05722236633301, 40.821198150515556, 41.64819337427616, 43.118326887488365, 43.55309575796127, 51.4554101228714, 52.96715900301933, 56.91376402974129, 37.04395763576031, 40.03488354384899, 49.904242157936096, 44.262753278017044, 43.52665297687054, 43.69849495589733, 44.08799685537815, 44.78369392454624, 42.46419198811054, 49.547779485583305, 55.67629963159561, 50.07997892796993, 48.79769213497639, 46.22907176613808, 45.707982927560806, 43.46339017152786, 39.53557513654232, 42.97333046793938, 41.639879420399666, 40.12926667928696, 38.154261857271194, 40.58418206870556, 38.58769699931145, 40.148824229836464, 40.31315021216869, 38.17732661962509, 38.17835256457329, 39.91833619773388, 39.911454766988754, 40.4285804182291, 41.13784275949001, 39.811751917004585, 38.52863296866417, 40.46427570283413, 39.77199845016003, 36.96518026292324, 37.00895391404629, 37.30615496635437, 38.77162992954254, 37.0833957195282, 37.256430834531784, 36.45055867731571, 41.74737945199013, 44.24122363328934, 48.498374596238136, 49.607326090335846, 49.95344191789627, 49.05903071165085, 47.96517960727215, 47.91449032723904, 46.87517769634724, 48.05186815559864, 48.50388430058956, 49.44004386663437, 47.53961004316807, 44.98079314827919, 47.886140048503876, 48.67196448147297, 50.46987600624561, 49.669718742370605, 29.26266297698021, 7.326601557433605, 0.7486452686134726, 9.337491653859615, 13.238816410303116, 3.7896955339238048, 0.6195240409579128, 0.2230744221014902, 0.18076124339131638, 0.4769787867553532, 2.1140507608652115, 2.559197824448347, 32.69580535590649, 54.47695478796959, 42.1856327354908, 50.958081409335136, 33.582392781972885, 2.2557506198063493, 0.14461906714132056, 0.13967594801215455, 0.17873792618047446, 0.1748272977420129, 0.11694942688336596, 0.19434184825513512, 0.09980737406294793, 0.16733124997699633, 0.11011698530637659, 0.18096650659572333, 0.1308550627436489, 0.14248102874262258, 0.15779548353748396, 0.17197583278175443, 0.15979999472619966, 0.2444139582803473, 0.09568365276209079], [0.0418983849522192, 0.025603668109397404, 0.035581721167545766, 0.03573136040358804, 0.11055347946239635, 0.056433161662425846, 0.07542420120444149, 0.010650657786754891, 0.04545320553006604, 0.015311925926653203, 0.045364281395450234, 0.04738544637802988, 0.036822042893618345, 0.10454012401169166, 0.08728484172024764, 0.07558213765150867, 0.07457999337930232, 0.09845132182817906, 0.04729411768494174, 0.0707963241438847, 0.053306029658415355, 0.0233834609753103, 0.03163087574648671, 9.646722860634327, 36.0909041762352, 32.991733476519585, 24.899366609752178, 33.630027025938034, 29.657349698245525, 11.10403586179018, 0.35971316043287516, 0.09166330521111377, 0.09750738419825211, 0.2870666398666799, 0.04643546766601503, 2.656271690502763, 2.8999070171266794, 0.3716274508042261, 4.361877618357539, 32.84438878297806, 50.456002950668335, 55.15375167131424, 50.40288180112839, 50.72556808590889, 50.05359314382076, 51.49483680725098, 52.33034357428551, 52.647520154714584, 51.93946614861488, 49.41898539662361, 49.363618567585945, 47.62146905064583, 47.03100733458996, 48.53576838970184, 50.8326805382967, 51.25270999968052, 52.23410613834858, 50.541464164853096, 49.81014400720596, 48.43792364001274, 50.58950498700142, 48.0580960214138, 42.32038110494614, 39.46559429168701, 35.98697975277901, 36.58304236829281, 35.64997583627701, 36.315741911530495, 38.023997247219086, 36.293087527155876, 38.88193421065807, 38.525026962161064, 38.040803745388985, 39.64117147028446, 36.959446370601654, 36.9485105574131, 35.47232396900654, 37.1399936825037, 43.79583813250065, 47.70630709826946, 52.222421765327454, 49.51008550822735, 41.140768602490425, 47.6981071382761, 49.028001576662064, 49.4845774769783, 48.983703553676605, 45.391866490244865, 43.65367256104946, 39.4880510866642, 44.634308740496635, 52.12390825152397, 47.48734004795551, 44.332042559981346, 42.42494769394398, 44.26592230796814, 44.995581954717636, 46.71348497271538, 43.76203894615173, 44.40272256731987, 41.19312599301338, 36.149880811572075, 36.36363834142685, 35.81873998045921, 37.51627989113331, 35.24451859295368, 35.33322483301163, 35.16899764537811, 35.09873181581497, 36.77932843565941, 33.92854280769825, 34.53541964292526, 35.332529470324516, 34.767218604683876, 35.583600997924805, 35.333000645041466, 36.61102406680584, 35.47327771782875, 34.780080914497375, 33.835755586624146, 34.287308156490326, 33.33388611674309, 33.90531845390797, 35.06740249693394, 34.865283742547035, 39.16873902082443, 41.12646996974945, 44.49807085096836, 47.597986310720444, 46.108656227588654, 46.895472407341, 46.100289076566696, 43.967740908265114, 44.20052781701088, 45.2501454949379, 44.311744049191475, 41.85298338532448, 44.713808074593544, 44.53495167195797, 46.38640612363815, 39.34441119432449, 17.61749055236578, 1.4510263572447002, 0.9491098648868501, 7.145374082028866, 8.732954543083906, 6.861541662365198, 0.3150954796001315, 0.05920604431594256, 0.023760076801409014, 0.41998555592726916, 0.6440676364582032, 4.864987246692181, 31.728685051202774, 25.883665792644024, 32.12584733963013, 40.86530618369579, 10.190847963094711, 0.05815138196339831, 0.08157899515936151, 0.03768288966966793, 0.07196746286354028, 0.05663363801431842, 0.009618232033972163, 0.01997180068428861, 0.05582272293395363, 0.05607019207673147, 0.11983572825556621, 0.037004266123403795, 0.04714645256171934, 0.017312321906501893, 0.03285567174316384, 0.015267760718415957, 0.011056673793063965, 0.036649526955443434, 0.062110123835736886, 0.08566190575947985, 0.05565536121139303, 0.012844251505157445, 0.0354713638080284, 0.04195277695544064, 0.10735610689152963, 0.009410899165231967, 0.0067875509193982, 0.0803248026932124, 0.025110449751082342, 0.019412510773690883, 0.004764361729030497, 0.10061123874038458, 0.05572110436332878, 0.05624468583846465, 0.08568843753891997, 0.05745837930589914, 0.07826999615645036, 0.052066283096792176, 0.05489853756444063, 0.014593066844099667, 0.018409461081319023, 0.1089898485224694, 15.435235351324081, 44.06167946755886, 36.831514835357666, 29.973602928221226, 40.50448514521122, 35.04632882773876, 13.501839246600866, 0.3883162443526089, 0.16236271971138194, 0.13403538818238303, 0.18733394070295617, 0.08852248429320753, 2.399057080037892, 3.871743343770504, 0.3617882647085935, 5.149159748107195, 36.07073485851288, 52.0134823769331, 57.14792646467686, 51.50706075131893, 52.45947204530239, 52.40790881216526, 53.25880475342274, 53.1049320101738, 53.70441824197769, 54.3708872795105, 50.539826452732086, 52.52840794622898, 49.62727501988411, 49.5826730132103, 50.99819205701351, 52.80709259212017, 52.935073524713516, 53.16390864551067, 50.68782851099968, 51.772662699222565, 50.05278758704662, 50.61728149652481, 51.21056646108627, 45.29969483613968, 41.12392410635948, 38.95139828324318, 37.5034935772419, 37.100080624222755, 38.32030534744263, 39.57016088068485, 38.68821680545807, 41.44821770489216, 40.86305670440197, 40.17734929919243, 40.33099785447121, 38.00190903246403, 38.433907851576805, 38.11546593904495, 38.111609145998955, 46.28824599087238, 48.964529782533646, 54.51804578304291, 51.492674723267555, 43.17829146981239, 47.31189966201782, 48.370123878121376, 50.79638108611107, 49.236310198903084, 45.584523752331734, 42.75837600231171, 42.1543338149786, 48.54939445853233, 53.87260861694813, 49.82611455023289, 47.1904543787241, 43.67991015315056, 45.890779718756676, 45.996064469218254, 47.81845808029175, 45.67281201481819, 44.96474660933018, 41.81625075638294, 38.235212713479996, 37.041837349534035, 37.25068174302578, 37.7400840818882, 38.14158953726292, 37.30268195271492, 36.62883371114731, 36.61122165620327, 38.40684190392494, 35.204328149557114, 36.756309270858765, 36.009162962436676, 37.42578014731407, 37.73140534758568, 36.46783635020256, 38.06375451385975, 36.32558338344097, 36.60733066499233, 36.43695920705795, 36.70398607850075, 36.08286760747433, 35.86483910679817, 36.8742473423481, 37.56829150021076, 42.27679744362831, 43.53709101676941, 46.84403836727142, 49.377921000123024, 47.78910845518112, 48.4105309098959, 46.46581806242466, 45.74481055140495, 45.65130516886711, 46.45557761192322, 45.72402186691761, 44.61556814610958, 45.692700147628784, 46.99653558433056, 47.88386017084122, 40.7448336482048, 19.593553617596626, 2.489294637925923, 2.5625145714730024, 8.565511777997017, 11.030015833675861, 2.7708272309973836, 0.7405004650354385, 0.07470042168279178, 0.097637809230946, 0.8967788354493678, 1.9382898858748376, 6.961365155875683, 39.44982893764973, 35.310053676366806, 35.88748209178448, 44.79344800114632, 14.08760441467166, 0.09096495166886598, 0.06218668007932138, 0.04175292771833483, 0.08734171991818585, 0.08877914122422226, 0.0664938788395375, 0.013858769234502688, 0.06261122936848551, 0.011241115116717992, 0.11390819476218894, 0.1045361312571913, 0.009850478800217388, 0.04096472235687543, 0.07671386832953431, 0.004814950689251418, 0.0883843854535371, 0.01838781263359124, 0.06282039626967162, 0.19783774972893298, 0.13814406614983454, 0.10084778346936218, 0.059839760506292805, 0.1471601362572983, 0.11937757080886513, 0.20738297112984583, 0.09333958674687892, 0.16366992378607392, 0.12003919546259567, 0.17667255888227373, 0.1244484877679497, 0.1678783167153597, 0.20525665866443887, 0.1396891285548918, 0.1939679542556405, 0.2809254569001496, 0.22523413121234626, 0.12942714092787355, 0.13010299997404218, 0.09071454362128861, 0.07923944140202366, 0.24451913544908166, 15.358227733522654, 50.95978371798992, 43.87677378952503, 35.64246363937855, 44.6522019803524, 40.06647124886513, 17.799675576388836, 0.5379427154548466, 0.3894465649500489, 0.36507039796561, 0.685805071843788, 0.20732790377223864, 4.127352302893996, 8.09337381273508, 1.2417537742294371, 6.823531351983547, 36.316737458109856, 53.119302839040756, 58.187615275382996, 53.08439411222935, 54.33713749051094, 52.8448473662138, 52.8404776006937, 54.657939076423645, 54.902744740247726, 56.135976165533066, 51.3886933028698, 54.0439148247242, 51.92725360393524, 50.39945438504219, 53.27420152723789, 54.63395096361637, 53.96805189549923, 55.9568727761507, 51.73261284828186, 52.51563683152199, 51.22352756559849, 54.00705300271511, 52.37294688820839, 46.60908557474613, 43.55164423584938, 40.508296340703964, 39.32614177465439, 37.798733934760094, 39.80824090540409, 42.53554455935955, 40.74660435318947, 43.11477787792683, 42.52123072743416, 41.8678367882967, 42.66214996576309, 40.09847693145275, 41.96229211986065, 38.87210413813591, 40.185328871011734, 47.59764812886715, 50.674996599555016, 55.70726417005062, 53.36361072957516, 40.12442193925381, 50.00212490558624, 49.573640897870064, 51.398732364177704, 50.353039875626564, 47.043523862957954, 42.504359632730484, 44.97569002211094, 49.63719628751278, 56.68134570121765, 50.11195421218872, 47.1478358656168, 46.1630617082119, 48.19734714925289, 49.48191002011299, 51.0004111379385, 48.457994163036346, 47.21198782324791, 44.471483677625656, 41.08030624687672, 40.01963496208191, 39.63101081550121, 40.76003663241863, 38.9262056350708, 38.91775868833065, 38.81187357008457, 38.78107622265816, 40.881120935082436, 37.79603607952595, 38.33605170249939, 39.573516100645065, 39.67102266848087, 37.98143573105335, 38.066178783774376, 40.17975077033043, 38.38232181966305, 38.132508024573326, 38.042475655674934, 38.29290881752968, 38.112072721123695, 37.25830793380737, 37.9496656358242, 39.758170992136, 44.297122433781624, 45.10142907500267, 47.75188185274601, 51.29526011645794, 47.93108403682709, 48.547407165169716, 48.078816309571266, 47.930806651711464, 46.997466534376144, 49.613086581230164, 48.97454224526882, 46.24402396380901, 47.213997915387154, 49.41089183092117, 48.95176626741886, 42.37638249993324, 20.024078115820885, 2.8654796769842505, 2.7335775922983885, 14.344925656914711, 17.902313768863678, 13.09480033814907, 1.5908758342266083, 0.4761084553319961, 0.1841092051472515, 1.8247909261845052, 3.416240648366511, 10.978908576071262, 45.17789617180824, 36.38164557516575, 42.239088267087936, 51.738217547535896, 16.43769945949316, 0.2817257889546454, 0.20896635804092512, 0.1783045713091269, 0.18567837250884622, 0.15916784817818552, 0.17604164429940283, 0.08600273707997985, 0.1765486053773202, 0.12164181884145364, 0.2855827601160854, 0.22350262646796182, 0.09292363523854874, 0.16601229028310627, 0.17365013278322294, 0.10209862142801285, 0.1826522802002728, 0.08537692105164751, 0.1385135666350834], [0.060278295568423346, 0.036369692752487026, 0.029473053546098527, 0.020079107816854957, 0.002388661901022715, 0.10040964916697703, 0.04077330020663794, 0.021442921060952358, 0.026393715852464084, 0.032233956080744974, 0.04005527604022063, 0.037929683458060026, 0.041871983048622496, 0.02354784111957997, 0.029251132837089244, 0.027593692575464956, 0.08210650630644523, 0.05996350620989688, 0.08697820114321075, 0.03711013720021583, 0.07200539403129369, 0.02774193842924433, 0.014555396355717676, 0.7256958656944335, 16.488316543400288, 40.2984943985939, 30.263572968542576, 29.339285865426064, 29.40483994781971, 12.825130708515644, 1.1441036453470588, 0.1442720537306741, 0.18133630394004285, 0.06630493546254002, 0.06085012406401802, 0.7823077810462564, 1.0488540376536548, 0.7613950688391924, 0.32041240367107093, 12.986686639487743, 41.932497918605804, 52.547912299633026, 53.159424886107445, 51.19702398777008, 51.6998016089201, 49.425179064273834, 50.00801458954811, 50.877445936203, 48.16640540957451, 45.96347741782665, 47.53582164645195, 45.9403670579195, 46.97437897324562, 46.87267743051052, 46.414406821131706, 50.22576950490475, 50.47694742679596, 49.72761243581772, 48.496280908584595, 50.47753259539604, 51.278396621346474, 48.95587384700775, 44.77862499654293, 38.61170411109924, 37.07443580031395, 38.507293313741684, 38.451117128133774, 37.71010749042034, 38.38270179927349, 38.37099842727184, 39.04595620930195, 39.25073482096195, 36.90444052219391, 38.79373334348202, 37.14555278420448, 37.3779521137476, 37.017663046717644, 36.65919788181782, 39.01273839175701, 48.9997348934412, 47.306207567453384, 52.78961732983589, 56.09590731561184, 51.90302610397339, 51.56879223883152, 52.162867560982704, 51.92007578909397, 50.116741955280304, 50.94864271581173, 39.92279335856438, 45.81237472593784, 52.54410110414028, 47.84779630601406, 47.91026875376701, 48.30925114452839, 48.26356999576092, 49.35252696275711, 46.9144219905138, 49.49705220758915, 48.66635598242283, 47.699209079146385, 41.986101642251015, 35.069826766848564, 35.291951447725296, 35.3366294503212, 35.7565601170063, 36.003622859716415, 33.940504565835, 35.852554365992546, 34.47927005589008, 35.27756541967392, 35.60328394174576, 35.03989577293396, 33.935013860464096, 35.68608529865742, 34.96366806328297, 34.93614614009857, 33.27414192259312, 35.47213397920132, 34.56736832857132, 34.76697161793709, 36.387774646282196, 33.90259400010109, 31.79985713213682, 35.589980855584145, 32.99416534602642, 36.48222617805004, 40.62070570886135, 45.7144083827734, 44.562002420425415, 49.7207386046648, 43.75742979347706, 42.7774053812027, 45.177751779556274, 43.70066463947296, 47.995266392827034, 44.78553682565689, 45.61679922044277, 45.798311680555344, 43.63847337663174, 28.58720362186432, 6.6297773737460375, 0.5193104746285826, 1.0078398697078228, 5.959896119311452, 11.985039487481117, 1.5149840502999723, 1.107559462543577, 0.06133252376457676, 0.05525412278075237, 0.8481796807609499, 0.17475743195973337, 13.191303759813309, 33.39123263955116, 28.69405008852482, 39.529472663998604, 29.084494337439537, 1.9335192418657243, 0.057391155569348484, 0.055273949255933985, 0.1084929658100009, 0.07127868302632123, 0.032215743776760064, 0.01463708640585537, 0.03159173487802036, 0.0627258540771436, 0.017738743263180368, 0.023253653780557215, 0.09213876954163425, 0.04897953134786803, 0.031022585535538383, 0.017216939231730066, 0.04000154083769303, 0.04059840939589776, 0.03615565365180373, 0.08015113271540031, 0.02842571248038439, 0.059099757636431605, 0.025132645532721654, 0.0847366479865741, 0.016148304093803745, 0.03614144152379595, 0.04307037343096454, 0.05707763528334908, 0.03713383397553116, 0.028091222811781336, 0.036192137631587684, 0.06941114261280745, 0.051746161407209, 0.04636111560103018, 0.023421969162882306, 0.043516916266526096, 0.031638868676964194, 0.013653582100232597, 0.06998923112405464, 0.08198526906198822, 0.03486222012725193, 0.044700281869154423, 0.0730969374126289, 1.8381909071467817, 24.928708635270596, 42.84028820693493, 31.776913963258266, 37.17882759869099, 35.56505039334297, 14.703879095613956, 1.184563518036157, 0.13083034922601655, 0.21567059360677376, 0.0692608131794259, 0.02652272152772639, 1.0919798235408962, 1.3026650995016098, 1.379352940712124, 0.6514890538528562, 13.69439771398902, 44.78552922606468, 53.14888425171375, 55.48057593405247, 52.99935467541218, 54.246227368712425, 51.719685941934586, 52.069510370492935, 51.40135422348976, 50.23221775889397, 47.61744886636734, 48.88443388044834, 48.61216329038143, 49.30053435266018, 47.2722601890564, 49.609408378601074, 50.209004804492, 51.00704938173294, 51.15306794643402, 49.31995131075382, 49.96755816042423, 52.262992188334465, 51.19499869644642, 46.31589710712433, 40.87716534733772, 38.743283450603485, 40.21832250058651, 40.62798231840134, 39.55048933625221, 38.93163174390793, 39.332449436187744, 41.64801478385925, 41.20819218456745, 39.40039359033108, 40.8944658190012, 39.57844823598862, 38.255131244659424, 38.38544525206089, 37.89630509912968, 41.01418599486351, 49.98067505657673, 47.2742360830307, 53.527283146977425, 56.5423833578825, 53.401741683483124, 54.32255767285824, 52.786851078271866, 55.07584445178509, 52.893211171031, 49.74549047648907, 43.02365116775036, 48.681144788861275, 52.960558757185936, 51.25821590423584, 49.777895137667656, 50.10864078998566, 50.25733441114426, 51.307913437485695, 49.8279232531786, 50.5840028822422, 50.67354127764702, 48.192643001675606, 43.33233520388603, 36.92381948232651, 36.62660703063011, 37.31091991066933, 36.3984102755785, 37.68380910158157, 35.20659662783146, 36.236421167850494, 35.33754140138626, 37.18800790607929, 36.15695983171463, 37.20478780567646, 35.37217274308205, 37.100620195269585, 36.94580130279064, 36.14917404949665, 34.94000293314457, 37.27199859917164, 36.04766629636288, 36.3643679022789, 36.70532360672951, 35.55644765496254, 33.47583889961243, 34.90654952824116, 35.75769625604153, 38.46856579184532, 43.30070190131664, 47.17118181288242, 47.8176449239254, 50.551503226161, 46.78782798349857, 46.601789966225624, 47.47024096548557, 45.441636219620705, 49.848331958055496, 46.736618131399155, 46.270394548773766, 47.494434267282486, 45.455433279275894, 31.78507212549448, 8.950381726026535, 1.0842151776887476, 5.78734215348959, 13.74282706528902, 9.08728837966919, 2.580180773511529, 0.676241519395262, 0.13152830942999572, 0.09176679028314538, 1.866033438127488, 1.2632118165493011, 15.341689120978117, 37.74705670773983, 27.960533648729324, 43.38356025516987, 35.59856079518795, 3.332665082998574, 0.04297903360566124, 0.028784921232727356, 0.07527933397796005, 0.03540771722327918, 0.024509777686034795, 0.02236957778222859, 0.05661039394908585, 0.04479560702748131, 0.059993028844473884, 0.009203188728861278, 0.05526018612727057, 0.02259178421809338, 0.043390153732616454, 0.015472213126486167, 0.04601970169460401, 0.046124838045216165, 0.02141662120266119, 0.02757896279945271, 0.1928969906293787, 0.22314645495498553, 0.1567743328632787, 0.23622421023901552, 0.09115209904848598, 0.2375635493081063, 0.1293424767209217, 0.18920743314083666, 0.16520199860678986, 0.1239635981619358, 0.10602293506963179, 0.3022659133421257, 0.13980705582071096, 0.0938682556443382, 0.09284706044127233, 0.13650988665176556, 0.15063209604704753, 0.14967076247557998, 0.17194426181958988, 0.17249777039978653, 0.14924732269719243, 0.1676642071106471, 0.2541799983009696, 2.341159349307418, 28.26607335358858, 53.41297008097172, 39.309099689126015, 41.99729584157467, 40.272720381617546, 20.894484110176563, 2.162100845016539, 0.4323639557696879, 0.6981225858908147, 0.253283305792138, 0.42018543113954365, 1.7591564543545246, 2.932548690587282, 2.6203916408121586, 1.2529818154871464, 15.576546918600798, 46.15419298410416, 54.53842408955097, 56.94096677005291, 55.38090728223324, 56.482171788811684, 52.42307759821415, 53.600155636668205, 54.66026835143566, 52.52412937581539, 50.4172108322382, 51.28655478358269, 50.012296959757805, 50.85985288023949, 51.2717279791832, 50.59097170829773, 53.583793714642525, 52.44939498603344, 52.55415916442871, 51.20350643992424, 52.42155008018017, 54.20706667006016, 53.44917453825474, 49.93153229355812, 43.29983554780483, 41.170129626989365, 42.17852711677551, 42.49772518873215, 42.979417741298676, 41.28320395946503, 41.55105538666248, 42.9807248711586, 43.239441588521004, 40.575320944190025, 41.479866206645966, 41.963591650128365, 40.66264405846596, 41.655975356698036, 40.53564727306366, 42.142402455210686, 52.574830055236816, 50.51058702170849, 56.450865268707275, 57.13571012020111, 52.232669815421104, 55.701127499341965, 53.62051494419575, 56.14692337810993, 54.17373105883598, 50.682558193802834, 44.715445786714554, 50.34984044730663, 54.64196853339672, 52.39471971988678, 52.88930878043175, 53.249901831150055, 53.93004633486271, 52.519337832927704, 51.615009158849716, 53.73770825564861, 52.82625496387482, 51.24613255262375, 46.419232562184334, 38.96483816206455, 37.85109132528305, 39.771044701337814, 37.10890755057335, 39.3835224956274, 37.813245356082916, 38.23299363255501, 37.886193841695786, 38.502380177378654, 39.859222769737244, 38.552434891462326, 38.22392351925373, 39.578053057193756, 39.622924849390984, 39.337012991309166, 35.90364642441273, 39.01998080313206, 38.39659385383129, 37.64948934316635, 39.24061216413975, 37.75084130465984, 35.51540985703468, 38.60225401818752, 36.50709964334965, 39.28182475268841, 44.861954525113106, 48.77804718911648, 49.599943086504936, 51.89381539821625, 47.696336433291435, 46.78166851401329, 49.68701161444187, 48.211619183421135, 51.336195319890976, 49.287299662828445, 48.775755912065506, 48.9590884745121, 45.36682963371277, 31.20159063488245, 8.396389503031969, 1.0501538054086268, 4.563460601493716, 14.419498555362225, 19.213114231824875, 7.325584637001157, 2.1799598867073655, 0.25177362898830324, 0.2494929201202467, 3.8400221709161997, 2.218510005623102, 21.72430068254471, 41.49682089686394, 38.814096450805664, 49.77512128651142, 39.90561068058014, 3.841548739001155, 0.15902885876130313, 0.09647153900004923, 0.20490082853939384, 0.2521133841946721, 0.14727548084920272, 0.0858933519339189, 0.13828874041792005, 0.15764936950290576, 0.1743876197724603, 0.11572238960070536, 0.18606483848998323, 0.12574786960612983, 0.10212824054178782, 0.17077187629183754, 0.16397217084886506, 0.09713087041745894, 0.1550089119700715, 0.1452791629708372], [0.033257203322136775, 0.024848336179275066, 0.024634221008454915, 0.042670107213780284, 0.060736968807759695, 0.020637466332118493, 0.061769730382366106, 0.03771356263314374, 0.009922578447003616, 0.06582439484191127, 0.014846939793642377, 0.0882012234069407, 0.015471585084014805, 0.05932626852882095, 0.03957827175327111, 0.08904821428586729, 0.05623864846711513, 0.05729425334720872, 0.09603712285752408, 0.047353764093713835, 0.005093687905173283, 0.009104281780309975, 0.09566371867549606, 0.1209443410334643, 5.760608687996864, 34.755093455314636, 35.12664511799812, 28.959097266197205, 36.46822772920132, 18.05719155818224, 1.491159328725189, 0.12231947388499975, 0.19296826649224386, 0.04148706815612968, 0.16456468671094626, 0.051067281819996424, 0.34391984227113426, 0.893657065462321, 0.2027228774386458, 2.960816086269915, 26.713906042277813, 46.85593172907829, 52.8399608284235, 51.61410100758076, 51.294142976403236, 49.41926658153534, 48.24260652065277, 48.19525346159935, 47.987719997763634, 49.39225383102894, 48.75209838151932, 49.819176122546196, 49.775562062859535, 44.15760912001133, 46.3750409334898, 48.00422631204128, 49.40298065543175, 50.04869520664215, 50.3994619846344, 48.59463483095169, 50.51970653235912, 47.09890589118004, 39.72603991627693, 36.760348454117775, 37.49978877604008, 37.99172177910805, 37.371089681982994, 38.142395094037056, 38.61345201730728, 37.62713514268398, 38.39338302612305, 40.55828645825386, 37.1997644752264, 38.05499218404293, 36.34551331400871, 35.879118740558624, 37.50921607017517, 36.72856695950031, 35.95468148589134, 40.62151126563549, 50.061185136437416, 48.25709894299507, 48.72302994132042, 48.313560113310814, 48.317162320017815, 49.26216021180153, 47.47685641050339, 48.30829359591007, 52.032629549503326, 42.19637855887413, 43.90275299549103, 51.88916824758053, 49.033439084887505, 47.84732513129711, 47.422469928860664, 48.21192316710949, 48.20489354431629, 55.43907456099987, 51.38007156550884, 50.157456770539284, 48.548957481980324, 44.490391463041306, 36.46766535937786, 36.312759071588516, 35.540089532732964, 34.88944664597511, 35.729646161198616, 34.92662005126476, 34.72443290054798, 36.33107028901577, 35.34622013568878, 34.332799315452576, 35.65499536693096, 35.373327881097794, 34.993165880441666, 34.89553011953831, 35.88781267404556, 36.6966562718153, 38.13444212079048, 40.732727497816086, 41.74093879759312, 41.61244109272957, 41.65849842131138, 40.265823751688, 36.643690913915634, 35.1084440946579, 34.44349117577076, 36.7038606852293, 38.91620837152004, 43.68169225752354, 45.61409376561642, 45.528499558568, 41.2680883705616, 46.317318230867386, 40.37638641893864, 46.84827134013176, 45.47993056476116, 47.31604903936386, 41.72496445477009, 30.93522872775793, 13.064071387052536, 2.0153078343719244, 0.2676602202700451, 8.421178422868252, 8.782594129443169, 6.082533588632941, 0.9321485250256956, 0.2872696617851034, 0.024575038441980723, 0.04066128043632489, 0.08562731425627135, 0.76474619214423, 18.920761719346046, 34.94194842875004, 31.01825427263975, 40.29856659471989, 13.494838122278452, 0.09201371765811928, 0.1209913264028728, 0.03866604238282889, 0.019217273984395433, 0.03214490207028575, 0.03090633366809925, 0.021354414384404663, 0.031876990469754674, 0.015599066573486198, 0.05468092502269428, 0.01121882007282693, 0.03802305305725895, 0.03093832765443949, 0.012127991794841364, 0.07391052422462963, 0.05625707970466465, 0.06311422737780958, 0.0023833727072997135, 0.0271653416348272, 0.05476568199810572, 0.04254852487065364, 0.029538796698034275, 0.006347638245642884, 0.04609897790942341, 0.029383472610788886, 0.023755416113999672, 0.026239905746479053, 0.01661117417825153, 0.051346889667911455, 0.028120470851717982, 0.03482041123788804, 0.051170024744351394, 0.06322418397758156, 0.016966831753961742, 0.04316511229262687, 0.07509617193136364, 0.08902416870114394, 0.07612233952386305, 0.0516174210497411, 0.04004809947218746, 0.02387823784374632, 0.06401021484634839, 0.21405559120466933, 9.248747415840626, 43.17564681172371, 37.61109620332718, 30.242656990885735, 39.807241559028625, 21.96661937981844, 1.8856231682002544, 0.13816177379339933, 0.33875182271003723, 0.018226586616947316, 0.27855007967446, 0.08169825086952187, 0.32610906986519694, 1.4464375097304583, 1.238966267555952, 2.571236053481698, 30.11727511882782, 49.738251864910126, 53.4814728051424, 52.54405550658703, 53.30583482980728, 50.88635265827179, 50.496976152062416, 49.976951256394386, 49.7545225918293, 50.24377293884754, 51.715319976210594, 51.88169404864311, 50.12924328446388, 47.035798877477646, 48.73710818588734, 48.62881399691105, 51.36911295354366, 51.274118050932884, 50.57793840765953, 49.9663308262825, 52.73460388183594, 49.60055485367775, 41.8295082449913, 38.768837079405785, 39.825214594602585, 39.2043013125658, 39.1306346654892, 38.9960952848196, 39.96696598827839, 38.64153631031513, 40.85148632526398, 41.26804277300835, 40.527359917759895, 39.998211711645126, 37.9611524194479, 36.867221519351006, 38.79858188331127, 37.45249651372433, 37.55414865911007, 43.8191232830286, 51.597412303090096, 50.34026496112347, 50.04550337791443, 49.95215758681297, 50.76914794743061, 50.74322193861008, 48.88558901846409, 50.418571159243584, 54.0458033233881, 44.09002214670181, 45.54255500435829, 51.80434159934521, 51.189849972724915, 48.40321630239487, 49.02353301644325, 50.76576612889767, 51.05043925344944, 53.82889196276665, 53.49826030433178, 53.12503293156624, 50.55961959064007, 45.569123178720474, 38.397995978593826, 36.979144513607025, 37.494822442531586, 37.63175569474697, 37.116784527897835, 36.391882225871086, 36.4474618434906, 37.841800823807716, 37.067383378744125, 36.55558884143829, 37.49695032835007, 36.1082274466753, 36.86710372567177, 36.597352400422096, 38.07293102145195, 36.9693486392498, 39.3478462100029, 41.821467876434326, 42.367456778883934, 43.462611213326454, 42.683744207024574, 40.489981323480606, 37.39886239171028, 36.62746958434582, 37.315301075577736, 39.141608476638794, 43.17526303231716, 44.50121708214283, 48.010188192129135, 46.119428649544716, 43.72898072004318, 47.048695385456085, 43.00932213664055, 48.66877265274525, 47.78219662606716, 48.814403638243675, 44.907358288764954, 33.49850468337536, 15.34064132720232, 3.1176930433139205, 1.2827954906970263, 10.480411425232887, 10.542006120085716, 8.099065907299519, 3.3452566573396325, 0.7606974500231445, 0.22514623124152422, 0.12733150884741917, 0.21537125576287508, 0.9526806639041752, 23.801252134144306, 40.72835773229599, 33.33892084658146, 45.492994263768196, 18.852124102413654, 0.24737676023505628, 0.024447530049656052, 0.02102667454892071, 0.025084181434067432, 0.03577114322979469, 0.09263560772524215, 0.009755584087542957, 0.05189857256482355, 0.019393259462958667, 0.03804606334597338, 0.007515984170822776, 0.017453650943934917, 0.023568626820633654, 0.016919534682529047, 0.007466013976227259, 0.10341966655687429, 0.007997160719241947, 0.07993280771188438, 0.006511682568088872, 0.13084878417430446, 0.1628020266070962, 0.0936204005847685, 0.11688698999932967, 0.1414079574169591, 0.1183114385639783, 0.12919881177367643, 0.09794554076506756, 0.1217090425780043, 0.13780906068859622, 0.07815334538463503, 0.11791856042691506, 0.17127416183939204, 0.1567573970532976, 0.1258854934712872, 0.24924498342443258, 0.15637164353393018, 0.17386160034220666, 0.21953219576971605, 0.22459221800090745, 0.22217269783141091, 0.10217781600658782, 0.15032193769002333, 0.23949173802975565, 11.114244014024734, 49.22920078039169, 47.377183958888054, 38.24356086552143, 47.61497899889946, 27.48482007533312, 3.9031726447865367, 0.4009472415782511, 0.8008042385336012, 0.31863688956946135, 0.45651020540390164, 0.255339797004126, 1.583414578344673, 3.295807298272848, 1.3735935185104609, 4.413768108934164, 29.61422771215439, 50.70696048438549, 53.59122611582279, 54.65416967868805, 54.22140710055828, 54.38320241868496, 52.313149496912956, 52.27784939110279, 51.42490915954113, 53.541577979922295, 53.99784989655018, 54.633627980947495, 53.415265157818794, 49.240615367889404, 50.87334215641022, 51.47826209664345, 52.81769782304764, 52.06658832728863, 52.84557692706585, 51.32108733057976, 55.12203097343445, 51.716889292001724, 42.66905799508095, 41.57063953578472, 41.4005758613348, 41.85470849275589, 40.731629356741905, 41.26150332391262, 42.23926305770874, 40.55723391473293, 42.53252752125263, 44.90899220108986, 41.524832993745804, 41.25388853251934, 39.07830387353897, 38.80641706287861, 41.33536756038666, 38.860146179795265, 38.247482255101204, 44.179549142718315, 52.92157664895058, 52.08890073001385, 52.454296723008156, 52.94798903167248, 51.89361400902271, 52.940792217850685, 48.82503166794777, 53.91830496490002, 55.67588925361633, 47.21106067299843, 48.354328125715256, 52.85592757165432, 53.18107612431049, 50.93572340905666, 51.21823064982891, 51.597085520625114, 53.67538020014763, 55.09254835546017, 54.32605728507042, 55.37694789469242, 51.69581562280655, 48.503527119755745, 40.76927773654461, 39.02251146733761, 39.37539093196392, 39.183326438069344, 39.67077948153019, 37.742154970765114, 37.96674191951752, 40.48127979040146, 39.70572620630264, 37.870527282357216, 40.10244391858578, 38.37463863193989, 38.590448051691055, 38.26200507581234, 39.609325379133224, 40.45623913407326, 41.11363805830479, 44.63251903653145, 44.73244987428188, 46.219405084848404, 46.49907007813454, 44.311880841851234, 40.134958773851395, 38.131254091858864, 39.50385823845863, 40.943205803632736, 42.46596269309521, 47.75114469230175, 49.12190593779087, 47.96144440770149, 45.64875170588493, 47.873722314834595, 45.05658008158207, 49.60403546690941, 47.776120752096176, 49.629672691226006, 44.76053036749363, 32.23357155919075, 15.04901647567749, 2.819530642591417, 1.6935338568873703, 18.669127821922302, 17.707524821162224, 16.96876846253872, 6.317127300426364, 1.3417867315001786, 0.1932741649216041, 0.3361495560966432, 0.35530225024558604, 1.6354567045345902, 29.831821136176586, 46.30091451108456, 39.56187352538109, 51.578949093818665, 21.456648744642735, 0.4009848239365965, 0.38653182447887957, 0.10326150004402734, 0.09763210953678936, 0.14062929607462138, 0.14319240697659552, 0.1562955288682133, 0.11937087663682178, 0.12382469780277461, 0.21321850799722597, 0.12789619417162612, 0.1403570911497809, 0.14872125873807818, 0.13284971821121871, 0.12142243256676011, 0.18373948201769963, 0.13116053072735667, 0.1512815643218346, 0.17604020453291014], [0.019543932139640674, 0.03910750150680542, 0.04800554786925204, 0.013149144324415829, 0.06376420031301677, 0.07265993859618902, 0.04170366024482064, 0.01865002453996567, 0.009999259928008541, 0.05049376864917576, 0.032555988800595514, 0.0032936993966359296, 0.04421959652972873, 0.01649911173444707, 0.025742195539351087, 0.014496429012069711, 0.041156927472911775, 0.015435118730238173, 0.034948316679219715, 0.006813785375925363, 0.030775582090427633, 0.029597148059110623, 0.008188696047000121, 0.08098507663817145, 1.7717990884557366, 17.68095474690199, 37.701896131038666, 27.868702076375484, 36.536415070295334, 27.196696735918522, 3.8587368791922927, 0.953679297817871, 0.3269767592428252, 0.17391694971593097, 0.06428671680623665, 0.023682481551077217, 0.4398640408180654, 1.4216538146138191, 1.1576115642674267, 0.14097415725700557, 6.848258525133133, 31.353626176714897, 49.98582758009434, 53.789358884096146, 52.236177027225494, 50.29079161584377, 50.70057302713394, 49.9965164065361, 52.72438243031502, 50.54690547287464, 52.21049040555954, 51.83741122484207, 49.705828204751015, 48.49129177629948, 44.18230019509792, 47.452731505036354, 50.666549652814865, 49.60962116718292, 49.662172347307205, 50.76610431075096, 48.77537593245506, 44.66301620006561, 39.12142775952816, 38.93394201993942, 38.43918576836586, 37.35822357237339, 38.76805052161217, 37.95548312366009, 39.687711372971535, 40.92890337109566, 41.33751064538956, 42.57435567677021, 40.98357103765011, 38.00535924732685, 37.888363525271416, 36.47219471633434, 34.83631029725075, 36.73732548952103, 35.813614055514336, 36.00241832435131, 39.03583735227585, 45.16974180936813, 47.78338976204395, 46.53893753886223, 43.687445148825645, 45.53978495299816, 49.0637918561697, 46.95797145366669, 51.62416286766529, 44.48982909321785, 42.57778689265251, 48.37600216269493, 48.58356222510338, 49.647250548005104, 50.032842457294464, 51.35021276772022, 53.56870852410793, 47.863003090023994, 45.8463829010725, 50.85693083703518, 48.00325736403465, 45.17119713127613, 35.00561781227589, 34.667428359389305, 36.547597870230675, 35.37218414247036, 36.28095097839832, 34.817527905106544, 36.9035779684782, 35.515189468860626, 35.7133374363184, 35.273229852318764, 35.07677659392357, 34.75229300558567, 34.88249681890011, 35.31337469816208, 35.77973887324333, 40.853910595178604, 42.62630268931389, 45.24658888578415, 43.71331416070461, 45.14454536139965, 45.97098581492901, 45.940747037529945, 43.31786938011646, 42.469982877373695, 39.164213463664055, 39.46163110435009, 38.55731002986431, 41.75659015774727, 44.35605727136135, 47.339436784386635, 41.27806283533573, 43.05608242750168, 40.967969074845314, 44.75937522947788, 47.24632278084755, 42.24791519343853, 32.59136416018009, 18.057459443807602, 4.215898001566529, 0.4527430341113359, 0.25207262544427067, 8.510727267712355, 13.77865344285965, 4.1003652010113, 1.6580081381835043, 0.4323997866595164, 0.453854919760488, 0.18259439268149436, 0.19668393273605034, 4.566135182976723, 27.533637955784798, 25.732243917882442, 32.38137222826481, 32.3716751486063, 5.656015500426292, 0.007077068294165656, 0.0303829024778679, 0.0328516530134948, 0.06117017524957191, 0.009506915448582731, 0.06304763446678407, 0.032314701747964136, 0.054043809795985, 0.06901995657244697, 0.0490806155721657, 0.06977431999985129, 0.04984782557585277, 0.029866655277146492, 0.04718517782748677, 0.011037833446607692, 0.05964442352706101, 0.01594163080881117, 0.019389398439670913, 0.0335301281302236, 0.01755023218720453, 0.0756430828187149, 0.025486102640570607, 0.033493777737021446, 0.035647052427520975, 0.014786211704631569, 0.02415832623228198, 0.035339617752470076, 0.022726294773747213, 0.068012461415492, 0.07943697142763995, 0.019784193173109088, 0.019719240408448968, 0.05589743122982327, 0.019537276930350345, 0.038363119965652004, 0.01744850229442818, 0.06374328659148887, 0.04703397637058515, 0.024827298148011323, 0.042006649455288425, 0.027382180487620644, 0.01970829373021843, 0.09917018833220936, 3.169504925608635, 25.318176336586475, 43.012586161494255, 29.979519210755825, 42.84036800265312, 29.583626054227352, 5.8005070220679045, 0.8340915211010724, 0.43445894960314035, 0.488583393744193, 0.04875966638792306, 0.11660986463539302, 0.11997781242826022, 3.6190799390897155, 3.2177970092743635, 0.48746200860477984, 7.0719316229224205, 31.264526657760143, 52.04134248197079, 54.34553503990173, 52.57677175104618, 52.129535749554634, 51.03070691227913, 51.28146305680275, 54.75271739065647, 52.487807124853134, 53.36811728775501, 52.40354284644127, 52.26251721382141, 49.75386142730713, 46.35129600763321, 50.66869653761387, 52.018171325325966, 51.26011960208416, 51.190210953354836, 51.65580756962299, 52.02910713851452, 46.25059001147747, 41.913951113820076, 38.3715645968914, 41.35583706200123, 39.46565508842468, 39.89330314099789, 40.89664690196514, 41.206497475504875, 40.77830225229263, 43.916873037815094, 43.75035837292671, 41.71838320791721, 40.08290156722069, 38.9702832698822, 38.760074749588966, 37.30365090072155, 38.68625611066818, 37.57463715970516, 38.78444284200668, 42.06976555287838, 47.62377172708511, 49.35910440981388, 48.00642639398575, 47.306671142578125, 49.613686949014664, 49.42532725632191, 50.996463149785995, 53.272016644477844, 47.97068551182747, 46.19313709437847, 48.870013654232025, 52.215939313173294, 51.150628477334976, 51.363918632268906, 51.44252881407738, 54.634699523448944, 50.53558208048344, 46.56028479337692, 52.1788989007473, 49.9425783008337, 47.26939134299755, 38.02527017891407, 36.89009249210358, 37.53125488758087, 37.0382085442543, 37.93031707406044, 35.52149333059788, 38.633666932582855, 37.77187317609787, 37.31191925704479, 36.72011621296406, 36.947142630815506, 36.655816063284874, 37.48384103178978, 36.11736215651035, 37.28877849876881, 42.06030786037445, 43.553715124726295, 45.51914066076279, 45.9254452586174, 46.361376866698265, 47.50365637242794, 47.120906710624695, 46.12106256186962, 43.26203517615795, 39.12832818925381, 39.765496999025345, 39.46554109454155, 43.48384827375412, 47.068967297673225, 48.07713679969311, 44.650678262114525, 44.769007712602615, 41.813252717256546, 45.92720836400986, 49.125622138381004, 45.26794753968716, 35.2840668708086, 19.148576594889164, 6.687749437987804, 1.19432317558676, 2.583279269747436, 10.337085016071796, 8.27196042984724, 6.492198156192899, 5.056165913119912, 2.136039943434298, 0.5308759852778167, 0.13467926066368818, 0.1660941491718404, 4.166919104754925, 33.470769971609116, 30.536487624049187, 36.34598828852177, 38.67767997086048, 8.314579892903566, 0.009374386427225545, 0.05562644713791087, 0.05340091323887464, 0.041990708123194054, 0.0576682438259013, 0.08523615790181793, 0.08424638523138128, 0.03904117205820512, 0.08080323561443947, 0.012289797614357667, 0.01038296790284221, 0.05138339591212571, 0.02931661994807655, 0.010552140465733828, 0.020170729658275377, 0.015369484117400134, 0.021685254541807808, 0.03171494623529725, 0.03012423803738784, 0.17993480258155614, 0.14362488611368462, 0.1086289643717464, 0.12624426250113174, 0.17840954067651182, 0.07320230011828244, 0.09095641697058454, 0.15404406061861664, 0.10218327821348794, 0.205864240124356, 0.16902086790651083, 0.10610002937028185, 0.11209051925106905, 0.10412420218926854, 0.08111596922390163, 0.1597206442966126, 0.09224181674653664, 0.11840942432172596, 0.17434319481253624, 0.15170001686783507, 0.14059588458621874, 0.14179020799929276, 0.083365507889539, 0.2457275299821049, 3.2134063448756933, 28.742731176316738, 50.016104355454445, 39.00882460176945, 47.900913655757904, 36.80392071604729, 9.850351084023714, 2.500372468493879, 1.2094505201093853, 1.4782819384709, 0.19492382562020794, 0.30696540023200214, 1.1951142456382513, 3.7440720945596695, 3.04672971367836, 0.4167781420983374, 9.934184085577726, 34.449266865849495, 53.723869398236275, 55.91191738843918, 54.94952782988548, 53.19718345999718, 53.78977306187153, 52.232506424188614, 57.97473169863224, 54.257075786590576, 56.34241908788681, 55.338680148124695, 54.551392793655396, 52.25425645709038, 47.19735860824585, 52.94211834669113, 53.911845311522484, 52.61979304254055, 51.51994206011295, 52.91847601532936, 53.338638469576836, 48.350391536951065, 43.46062012016773, 41.65813364088535, 41.80593051016331, 40.530711337924004, 43.00622150301933, 42.189926505088806, 41.639081463217735, 43.49397473037243, 45.31256474554539, 47.31382615864277, 44.654014483094215, 41.52688108384609, 40.310433357954025, 40.488651394844055, 38.49774822592735, 40.21534726023674, 38.349217996001244, 40.59117369353771, 42.13115505874157, 47.451162189245224, 51.90296530723572, 50.03958709537983, 47.79474355280399, 51.73112712800503, 52.562241330742836, 52.33706161379814, 54.588068425655365, 50.502121075987816, 47.2984179854393, 49.8968705534935, 52.38533042371273, 52.549481615424156, 53.25513795018196, 54.42590832710266, 53.527343943715096, 51.607238575816154, 49.616020023822784, 54.51681084930897, 52.47940957546234, 48.92789974808693, 39.45715494453907, 38.3685589581728, 39.93535928428173, 38.91442246735096, 40.53355358541012, 37.462288588285446, 41.50412030518055, 39.260511696338654, 38.9178042858839, 38.41827929019928, 38.0901250988245, 38.156233951449394, 40.04058703780174, 38.08458499610424, 40.04733167588711, 44.27640214562416, 45.40532536804676, 47.8994507342577, 46.733745485544205, 48.415683433413506, 50.655659437179565, 49.40308324992657, 49.27340380847454, 45.47355830669403, 42.08597548305988, 42.08850234746933, 41.14796161651611, 45.31441144645214, 49.664581418037415, 50.946469232439995, 46.13919898867607, 44.38566528260708, 43.763213083148, 46.53837516903877, 50.505799278616905, 45.54164305329323, 34.45399381220341, 19.462764635682106, 5.763870337978005, 0.9511966060381383, 2.126259980723262, 14.071928355842829, 23.347322791814804, 12.834800239652395, 5.024592457339168, 1.485768249258399, 0.8899645542260259, 0.519908705027774, 0.45138321176636964, 8.118618708103895, 39.9589142203331, 35.18489979207516, 44.0412213653326, 43.14153604209423, 9.83634503558278, 0.13547537731938064, 0.22901596734300256, 0.1894223887939006, 0.14724610664416105, 0.0968308126903139, 0.16090159420855343, 0.1948676598840393, 0.10606835450744256, 0.22220938961254433, 0.1390902153798379, 0.11931055487366393, 0.11560276281670667, 0.11026263178791851, 0.09569436937454157, 0.07170072756707668, 0.1200850898749195, 0.1311529311351478, 0.18866124213673174, 0.1156709439237602], [0.046578702167607844, 0.04444964746653568, 0.013574022013926879, 0.03959973466407973, 0.06366775080095977, 0.06910968222655356, 0.044093078904552385, 0.042347580965724774, 0.06241353607038036, 0.03241173013520893, 0.07301997669856064, 0.02882793796743499, 0.03308223087515216, 0.031175408585113473, 0.10095284189446829, 0.023823920055292547, 0.009939623723767, 0.005671465642080875, 0.04103881095943507, 0.05604507779935375, 0.01856398921518121, 0.020986823074053973, 0.038806167285656556, 0.041466967086307704, 0.08740719218621962, 5.525651145726442, 29.047560319304466, 27.382692955434322, 28.274493701756, 39.860757887363434, 13.505882229655981, 3.145982287824154, 0.36777902918402106, 0.6140855234116316, 0.06498951581306756, 0.055222607479663566, 0.34796992025803775, 1.5111942286603153, 0.8896470337640494, 1.4439390250481665, 0.45794875477440655, 6.5031429938972, 29.512805454432964, 44.36408244073391, 53.73410604894161, 52.22129322588444, 55.25031968951225, 49.7562400996685, 53.22964511811733, 51.87116101384163, 50.56697599589825, 50.89204475283623, 51.199258267879486, 46.6322111338377, 47.853176817297935, 49.967877343297005, 51.648743748664856, 52.0619335770607, 50.97357697784901, 48.58939491212368, 47.83223994076252, 42.02017821371555, 39.25014965236187, 37.03207567334175, 38.33810739219189, 37.89314366877079, 37.6844322681427, 39.01691056787968, 40.571555346250534, 39.30616244673729, 46.085606664419174, 43.262973725795746, 43.94755259156227, 41.02161839604378, 39.505256563425064, 36.88958331942558, 38.83763998746872, 35.934618562459946, 38.17014120519161, 37.009740471839905, 36.68718338012695, 37.46206060051918, 38.49443480372429, 38.6070341616869, 39.57823544740677, 39.45308156311512, 46.16669811308384, 46.6854614764452, 54.42790701985359, 44.41085033118725, 41.25000134110451, 47.15972922742367, 48.777762204408646, 50.30990459024906, 48.93215931952, 50.934370681643486, 46.10390268266201, 46.30574405193329, 51.448889672756195, 49.553129598498344, 47.82763458788395, 40.4685390740633, 33.791814744472504, 36.5801165252924, 35.82302235066891, 35.04727117717266, 34.71661292016506, 36.13994434475899, 38.70480291545391, 39.60005007684231, 37.54840336740017, 34.698522090911865, 34.36237692832947, 35.941442996263504, 35.88557079434395, 34.366568103432655, 37.4166302382946, 42.00391508638859, 44.52548258006573, 45.20616665482521, 46.51093304157257, 44.439496994018555, 46.326278150081635, 46.34540252387524, 45.6815629452467, 44.12030652165413, 44.34650078415871, 41.95118151605129, 42.69050404429436, 43.93458388745785, 43.290001675486565, 46.311048567295074, 43.35132658481598, 41.47619180381298, 44.95929390192032, 40.49857646226883, 47.12542846798897, 33.203849494457245, 19.767646975815296, 5.301842205226421, 1.1021732515655458, 1.7124478169716895, 2.5888851564377546, 8.21277480572462, 5.011125979945064, 5.271583003923297, 4.483181834220886, 1.149750854820013, 0.5784239619970322, 0.09992182065616362, 0.06133232709544245, 8.335474021732807, 33.33932742476463, 24.67740722000599, 33.8181359320879, 16.10887460410595, 0.9647982136812061, 0.017343328836432192, 0.03192961616150569, 0.016550794898648746, 0.045091308347764425, 0.019521856956998818, 0.04740343974845018, 0.09179664688417688, 0.020441819506231695, 0.01586395206686575, 0.04956626959028654, 0.026764316571643576, 0.07778682833304629, 0.028925656552019063, 0.016958790583885275, 0.03118585802440066, 0.03981926194683183, 0.04315687074267771, 0.015655054194212426, 0.043795592719106935, 0.006932435771886958, 0.031249604799086228, 0.010724765870691044, 0.047900192585075274, 0.09539772552670911, 0.08976809011073783, 0.03883533368934877, 0.05966021271888167, 0.04058264988998417, 0.03149000127450563, 0.043113588690175675, 0.009922093267960008, 0.040973713475978, 0.031972872238839045, 0.08740002303966321, 0.013606186694232747, 0.02233982137113344, 0.025522065261611715, 0.05435894425318111, 0.0376667405362241, 0.0798107021546457, 0.019600313098635525, 0.05244856707577128, 0.06866000010631979, 0.17605381552129984, 9.123681876808405, 36.37673623859882, 31.776921562850475, 35.417173728346825, 43.77276577055454, 15.119550190865993, 4.138619173318148, 0.5212151817977428, 0.9609433205332607, 0.049778256652643904, 0.061613534271600656, 0.6174175289925188, 1.4449815941043198, 5.261008646339178, 2.1885495632886887, 0.7900786609388888, 8.932938762009144, 32.66098402440548, 47.54114896059036, 54.45092238485813, 53.7663359194994, 56.32563538849354, 50.47970987856388, 52.55935348570347, 52.942566722631454, 51.84559978544712, 52.1861869096756, 52.694880813360214, 49.428317695856094, 49.83097068965435, 50.73874957859516, 52.18375883996487, 52.65360362827778, 53.102443143725395, 50.34939967095852, 48.589030131697655, 44.326012283563614, 40.281235724687576, 39.36318598687649, 39.39085230231285, 40.02538025379181, 39.44425083696842, 40.53146369755268, 41.55899316072464, 41.76464952528477, 46.380482241511345, 45.5234382301569, 45.77441096305847, 42.08103194832802, 40.237766057252884, 37.69520089030266, 40.19765540957451, 38.8089819252491, 39.261978417634964, 37.909611985087395, 38.33712324500084, 40.02766393125057, 41.03483788669109, 41.77857957780361, 41.84173598885536, 42.50272572040558, 47.15709216892719, 49.33897688984871, 53.846743404865265, 47.3774803429842, 42.0342792570591, 48.363212049007416, 49.92987938225269, 52.30220228433609, 50.87732434272766, 51.36541195213795, 48.36738422513008, 45.88131822645664, 53.19928474724293, 50.485056191682816, 50.03859154880047, 43.58488105237484, 34.715165197849274, 38.36846396327019, 38.060543686151505, 37.07571633160114, 35.998975709080696, 37.75351256132126, 39.0351115912199, 38.82318936288357, 39.531763941049576, 36.98040224611759, 36.67215518653393, 36.06030061841011, 36.7098643630743, 35.27851156890392, 39.592116102576256, 42.3362148553133, 45.895058289170265, 47.77751907706261, 48.8602177798748, 45.743393227458, 47.592875584959984, 46.70034907758236, 48.82935583591461, 46.37905351817608, 46.08898088335991, 43.859925493597984, 43.59355978667736, 45.16157604753971, 44.771914556622505, 47.89581432938576, 45.689827501773834, 43.99898663163185, 46.167765855789185, 42.49766819179058, 47.93141841888428, 34.44357477128506, 21.974701546132565, 7.154513541609049, 3.1969636771827936, 2.2788448305800557, 3.0621637729927897, 11.22567968443036, 7.218694947659969, 7.81811373308301, 6.315482463687658, 3.8001138623803854, 1.068503139540553, 0.350264017470181, 0.1012811457621865, 9.359736610203981, 37.44942627847195, 27.311357483267784, 38.81230294704437, 22.34867937862873, 1.5870794816873968, 0.08710834415978752, 0.014399127885553753, 0.08922230728785507, 0.01037531914334977, 0.04289737880753819, 0.05601505050435662, 0.052036983106518164, 0.024662912437634077, 0.027952318741881754, 0.018285505720996298, 0.06773118002456613, 0.04135091003263369, 0.019843783920805436, 0.05316646878782194, 0.08474283749819733, 0.012131244257034268, 0.039546867774333805, 0.023335731602855958, 0.06666170811513439, 0.11790378426667303, 0.12844713492086157, 0.13050748530076817, 0.11012749411747791, 0.13594716059742495, 0.14714726741658524, 0.17670660861767828, 0.3047434100881219, 0.23261274152901024, 0.0765951766516082, 0.11089522362453863, 0.12549273407785222, 0.09724446354084648, 0.10942053166218102, 0.20411728386534378, 0.07365170764387585, 0.1741483513615094, 0.1530204460141249, 0.0968110270332545, 0.1587320739054121, 0.1308566954685375, 0.17545782640809193, 0.1743578299647197, 0.18177403748268262, 0.17759273294359446, 9.696834571659565, 43.09109374880791, 38.89961466193199, 40.37741616368294, 50.31683161854744, 22.295651324093342, 6.206847243010998, 1.85992217855528, 1.5270873508416116, 0.39008344640024006, 0.1732075455947779, 1.1370057449676096, 4.649579180404544, 4.5838560070842505, 2.8196052135899663, 0.8155220956541598, 8.418301027268171, 33.33985939621925, 48.9834413677454, 55.60129925608635, 54.35868613421917, 57.40608461201191, 51.36792741715908, 54.15947422385216, 55.209753066301346, 54.21632297337055, 53.70268173515797, 55.290323942899704, 51.13017797470093, 53.343620002269745, 52.87879854440689, 53.873334378004074, 53.529787212610245, 54.308525025844574, 52.18375124037266, 51.53758451342583, 46.23053468763828, 43.127640187740326, 39.5571655780077, 41.41906946897507, 41.980880722403526, 42.39094331860542, 42.97774963080883, 44.29982788860798, 44.29284006357193, 49.670569896698, 47.022480592131615, 47.76681885123253, 44.82000857591629, 43.71728114783764, 38.68999890983105, 42.03287333250046, 40.4398088157177, 41.89730800688267, 40.61177998781204, 39.48900103569031, 42.486747577786446, 43.03291127085686, 43.784609735012054, 43.46365235745907, 43.893344700336456, 50.485056191682816, 51.29765398800373, 56.67175501585007, 50.62127888202667, 43.274110928177834, 49.2949790507555, 50.95734804868698, 52.240113615989685, 51.22299179434776, 50.32767243683338, 50.2750338613987, 48.97577717900276, 57.07246631383896, 53.333071768283844, 53.05536366999149, 44.10042978823185, 36.31227649748325, 40.63579089939594, 39.64299917221069, 37.4102807790041, 37.800295650959015, 40.72307601571083, 40.84898225963116, 42.89380833506584, 41.04506693780422, 38.005860820412636, 36.96731574833393, 37.71223157644272, 38.58215309679508, 38.182680532336235, 41.77151195704937, 45.194440484046936, 47.34626121819019, 50.104977786540985, 50.881169736385345, 48.049101904034615, 49.61456090211868, 49.33809153735638, 49.46118973195553, 47.521101236343384, 48.40135060250759, 46.62444815039635, 46.71783573925495, 48.84305030107498, 46.457340717315674, 49.4771982729435, 46.00749425590038, 45.977688655257225, 47.79478535056114, 44.197145998477936, 47.43363372981548, 35.591147392988205, 21.189564876258373, 5.938950218260288, 2.042625993490219, 4.166584722697735, 7.806281642988324, 18.524245396256447, 11.4763237349689, 13.361013103276491, 10.332445465028286, 5.346884513273835, 1.1879480676725507, 0.544747319072485, 0.17045667133061215, 11.968146543949842, 46.41647011041641, 34.31324936449528, 45.34094162285328, 24.83042500913143, 1.6994451521895826, 0.1635008180164732, 0.12152821087511256, 0.12251868858584203, 0.18086649477481842, 0.12734592135529965, 0.1103940735629294, 0.17688295774860308, 0.1310776179889217, 0.13443124975310639, 0.12372058932669461, 0.1180570971337147, 0.1440729503519833, 0.1953151897760108, 0.16446094930870458, 0.11024297229596414, 0.13479827146511525, 0.13880373153369874, 0.12899056513560936, 0.12107307396945544], [0.05318118186551146, 0.05821678743814118, 0.027544159784156363, 0.04368863068521023, 0.03715270679094829, 0.015476524076802889, 0.05581376150075812, 0.035370680343476124, 0.02108815035171574, 0.017173505038954318, 0.02400801906333072, 0.01595775396708632, 0.0174145694472827, 0.03356009976414498, 0.024989221783471294, 0.048197678770520724, 0.019603354048740584, 0.03975458377681207, 0.023269413286470808, 0.03411033176234923, 0.04486325378820766, 0.035521622048690915, 0.0735038124548737, 0.034338037512497976, 0.03500323189655319, 0.748585956171155, 16.87792483717203, 34.10890392959118, 24.12704285234213, 33.665999695658684, 20.049523450434208, 0.6787803769111633, 0.6483169365674257, 0.23793975880835205, 0.25787812017370015, 0.3086406650254503, 0.1571453918586485, 4.763513691723347, 8.822953663766384, 2.829379476606846, 0.9641223249491304, 0.0989942102751229, 8.619731068611145, 25.437299944460392, 45.31276613473892, 50.473368018865585, 52.563081085681915, 54.43495184183121, 50.74736751616001, 52.19833865761757, 50.98936893045902, 49.88777004182339, 47.93208718299866, 45.888017266988754, 48.48310321569443, 50.19395001232624, 51.5060880035162, 49.49148170650005, 51.73300422728062, 49.45889085531235, 45.31674072146416, 45.42922608554363, 45.50470143556595, 42.94415183365345, 37.7201921492815, 36.70959837734699, 37.788128703832626, 39.14465591311455, 39.069233760237694, 43.19520816206932, 48.06337013840675, 47.687897086143494, 47.74773247539997, 44.44885969161987, 38.58915992081165, 37.328976541757584, 37.343864142894745, 35.95209002494812, 37.11809545755386, 36.584607884287834, 36.12107835710049, 37.411196529865265, 37.1846716850996, 37.38255746662617, 39.12913374602795, 42.517153546214104, 47.395073398947716, 48.916815742850304, 51.117004081606865, 43.72202709317207, 43.46367135643959, 47.45488598942757, 47.927352637052536, 51.12370312213898, 49.4717987626791, 44.66698698699474, 48.118809163570404, 52.27229408919811, 47.19162471592426, 47.91614703834057, 44.69659499824047, 36.180879548192024, 35.18054902553558, 35.698389038443565, 34.94953662157059, 35.75274512171745, 36.289158537983894, 36.26381769776344, 41.88311576843262, 43.21145609021187, 45.21106459200382, 39.19068284332752, 34.48268227279186, 35.31807504594326, 35.30720762908459, 34.80258330702782, 37.78096228837967, 45.317348688840866, 45.495908707380295, 46.90898448228836, 46.06431260704994, 44.53899845480919, 47.32898734509945, 46.60570375621319, 47.071041986346245, 46.00904077291489, 47.286904603242874, 44.18386951088905, 44.29342903196812, 44.44336138665676, 45.07254682481289, 46.37319043278694, 46.01662516593933, 42.82090924680233, 45.926357209682465, 42.116282656788826, 40.37782274186611, 19.291158244013786, 7.140927370637655, 1.7090684920549393, 2.7439208747819066, 1.1440817965194583, 2.289044433273375, 9.533841367810965, 5.387576529756188, 6.228370238095522, 6.91598704084754, 6.336972685530782, 0.9054655255749822, 0.3562756808241829, 0.11141536524519324, 17.555836960673332, 31.562164686620235, 27.62861765921116, 36.84319540858269, 6.991615807637572, 0.03033081298781326, 0.05710238961910363, 0.039957368207979016, 0.037413274840218946, 0.015426918926095823, 0.02336561788979452, 0.010435859840072226, 0.03266794177761767, 0.014683743374916958, 0.023489586237701587, 0.017677922405709978, 0.007528592332164408, 0.016376020976167638, 0.030143134972604457, 0.04041512118419632, 0.03059352584386943, 0.011500847322167829, 0.04724039732536767, 0.01649733243539231, 0.05228003275988158, 0.006305046854322427, 0.02700838853343157, 0.04796096705831587, 0.05163353678653948, 0.0853215271490626, 0.04182706827123184, 0.07757703060633503, 0.07137355918530375, 0.017742530071700457, 0.0269397955344175, 0.025884400311042555, 0.04424505961651448, 0.0263454205924063, 0.0582991806732025, 0.06891592231113464, 0.06442324229283258, 0.021962929095025174, 0.028714330001093913, 0.04610741983924527, 0.03241512917156797, 0.040792985673760995, 0.02842419664375484, 0.04794506654434372, 0.050763405743055046, 0.09435694504645653, 1.300809730309993, 23.6265280097723, 39.536316096782684, 28.142842166125774, 44.00917388498783, 24.08470742404461, 1.843095850199461, 1.2654240103438497, 0.6790002901107073, 0.20595291192876175, 0.13167350320145488, 0.5099829251412302, 3.8902279268950224, 10.312448088079691, 3.1636731885373592, 1.7662551859393716, 1.1768647748976946, 14.547310397028923, 29.431873597204685, 46.72463357448578, 51.64541892707348, 53.59158329665661, 53.999271020293236, 52.35447607934475, 54.260385408997536, 52.858640626072884, 51.47114507853985, 50.82913152873516, 46.50259628891945, 50.976620614528656, 51.61081798374653, 51.85901306569576, 51.23199351131916, 52.27964289486408, 49.727711230516434, 48.105141296982765, 46.66079320013523, 48.130352944135666, 43.7451184540987, 38.856099396944046, 37.94773153960705, 39.77162227034569, 40.22846415638924, 39.92082506418228, 45.538759008049965, 49.76013109087944, 49.07666556537151, 48.32756616175175, 43.42899061739445, 40.876112803816795, 38.74800279736519, 39.8713631182909, 37.05438047647476, 38.88334393501282, 37.8719712048769, 38.49486418068409, 38.34954857826233, 39.6663299202919, 39.580367133021355, 39.536145105957985, 43.273571357131004, 49.15008902549744, 49.81867454946041, 53.43012236058712, 45.21266430616379, 44.83187913894653, 46.74207463860512, 49.45358254015446, 50.962941348552704, 50.464510694146156, 47.31721557676792, 47.16754540801048, 53.79088260233402, 49.729736521840096, 48.5958431661129, 46.86796188354492, 37.52597697079182, 36.53521813452244, 37.09074832499027, 37.4391820281744, 38.03838327527046, 37.5826433300972, 37.31084771454334, 43.80589239299297, 44.16336961090565, 47.51877196133137, 40.77063046395779, 35.677790343761444, 37.05668695271015, 37.08752229809761, 36.16234414279461, 40.304566472768784, 46.66041702032089, 48.07863391935825, 47.98040919005871, 47.593373358249664, 46.331552267074585, 48.349149003624916, 48.10463972389698, 47.26546235382557, 47.891353368759155, 48.824598491191864, 46.58525325357914, 46.02873511612415, 46.66502997279167, 46.710771918296814, 46.8907530605793, 47.21620939671993, 43.57158176600933, 47.15907946228981, 43.3940514922142, 43.127442598342896, 22.697299271821976, 10.402908883988857, 2.9256178624927998, 4.858152363449335, 4.065601816400886, 5.307471128180623, 9.36151111498475, 6.265692310407758, 8.077405169606209, 8.176888581365347, 5.181975737214088, 0.7832088670693338, 0.7532246760092676, 0.13043316663242877, 20.22863443940878, 36.30283780395985, 31.134396940469742, 41.23981028795242, 10.045606456696987, 0.010244023014820414, 0.047822226260905154, 0.01820467285142513, 0.005114263485666015, 0.0696372304810211, 0.022472684358945116, 0.008217325321311364, 0.04616471363988239, 0.05291788271279074, 0.023361408057098743, 0.040471984539180994, 0.017746507983247284, 0.029943580739200115, 0.061788399107172154, 0.0225613264774438, 0.03495433549687732, 0.02910342318500625, 0.018261721743328962, 0.027879289555130526, 0.02995501723489724, 0.21289699478074908, 0.1348828911432065, 0.13241584383649752, 0.13357012096093968, 0.14887817844282836, 0.11650869506411254, 0.15910752641502768, 0.12605394615093246, 0.13123375101713464, 0.07758014762657695, 0.14574153581634164, 0.11564282394829206, 0.08926757829613052, 0.11053111855289899, 0.14879314316203818, 0.24767019058344886, 0.143960589193739, 0.19970052555436268, 0.11452657447080128, 0.13110206433339044, 0.1487689936766401, 0.09081980984774418, 0.19563863257644698, 0.09932677407050505, 0.07803426778991707, 1.226440358441323, 26.800566092133522, 48.61864574253559, 33.24020214378834, 44.480382800102234, 27.089477889239788, 1.8154934188351035, 1.9739668839611113, 2.0272104581817985, 0.44434207084123045, 0.361552796093747, 0.2635912620462477, 12.143158502876759, 21.518682315945625, 3.6831582756713033, 2.1568181784823537, 0.99238823633641, 10.918745454400778, 28.60387522727251, 47.906058579683304, 51.55644670128822, 54.11932557821274, 53.95872339606285, 50.59355936944485, 56.352902725338936, 51.88866667449474, 53.17424789071083, 52.10591621696949, 49.64465528726578, 52.09645852446556, 53.444842770695686, 54.2420057952404, 52.283340096473694, 54.927732199430466, 51.6245998442173, 49.81685444712639, 49.15789760649204, 51.508573070168495, 48.28741751611233, 40.990600660443306, 39.21526372432709, 41.632564812898636, 42.95452527701855, 42.32681415975094, 46.408505737781525, 51.415633857250214, 51.70963928103447, 50.17118163406849, 47.76315584778786, 42.26729795336723, 41.113885045051575, 40.95502316951752, 38.98036412894726, 40.932562574744225, 40.005704909563065, 39.46234926581383, 41.19773514568806, 40.5890192091465, 40.935864597558975, 41.73107452690601, 46.843730583786964, 52.09103241562843, 52.53548316657543, 55.641048923134804, 46.83447428047657, 47.00588308274746, 46.62830114364624, 49.90944787859917, 53.363154754042625, 52.51306816935539, 48.84431183338165, 52.538640797138214, 55.28352990746498, 51.31756491959095, 50.64031586050987, 47.135972902178764, 40.09186528623104, 38.569568172097206, 38.42827655375004, 38.99551011621952, 40.048916190862656, 39.35716710984707, 39.493423998355865, 46.90921247005463, 45.767400339245796, 49.469967260956764, 42.908817529678345, 36.69772021472454, 38.031859025359154, 39.04010832309723, 38.43352787196636, 42.6486074924469, 49.75193113088608, 49.46045637130737, 49.11454193294048, 49.50122058391571, 48.801514729857445, 48.89114812016487, 50.629418045282364, 48.4250233322382, 49.668981581926346, 51.243309304118156, 48.01978647708893, 48.31317253410816, 47.31830611824989, 48.567086309194565, 48.25888104736805, 49.63078983128071, 46.28772161900997, 47.882640436291695, 45.303327441215515, 43.30457769334316, 21.524435207247734, 8.706055786460638, 2.67533621750772, 6.614941544830799, 4.594533434137702, 10.12236898764968, 19.433713294565678, 13.075457476079464, 13.45592251047492, 14.529577698558569, 13.394971881061792, 2.400744901970029, 1.2060627643950284, 0.31796325696632266, 24.09719355404377, 41.236888244748116, 37.652863562107086, 49.49218086898327, 11.266202609986067, 0.1747082720976323, 0.21108122658915818, 0.13079258875222877, 0.1554276910610497, 0.23948704765643924, 0.13331884460058063, 0.06086892266466748, 0.1330912279081531, 0.17867738177301362, 0.07772061391733587, 0.07122737835743465, 0.07633805216755718, 0.11310065645375289, 0.20410569151863456, 0.08977953402791172, 0.1162945112446323, 0.15535506448941305, 0.2065744754509069, 0.1259609402040951, 0.08361549291294068], [0.013765492403763346, 0.03296760987723246, 0.011132229064969579, 0.06640297317062505, 0.03484604130790103, 0.03520085840136744, 0.023229372563946526, 0.03700717534229625, 0.035898451242246665, 0.013370581709750695, 0.08489589803502895, 0.03304061865492258, 0.039994260368985124, 0.020756107915076427, 0.03592464534449391, 0.03233080264180899, 0.02004834579565795, 0.00665130234665412, 0.043305912549840286, 0.03084852778556524, 0.03319082563393749, 0.03355189903231803, 0.06995049101533368, 0.043029759399360046, 0.07801987754646689, 0.05051758787885774, 4.226908385753632, 27.372891381382942, 28.345354199409485, 26.44246380776167, 31.826932579278946, 2.5738393887877464, 0.022600086995225865, 0.8129529585130513, 0.05287104577291757, 0.07826262663002126, 0.35706992726773024, 0.9860679879784584, 5.625462764874101, 3.0389745673164725, 1.1567370174452662, 0.9755446307826787, 2.319633266888559, 8.121372610330582, 26.557082757353783, 45.22348612546921, 52.13806249201298, 49.94795881211758, 54.243525713682175, 49.44443263113499, 49.508599787950516, 49.365051090717316, 48.173218443989754, 49.209753423929214, 53.96736033260822, 50.18833011388779, 49.2334109544754, 49.95887562632561, 51.13331660628319, 50.35672947764397, 51.49856440722942, 48.72184060513973, 51.05072043836117, 49.983578100800514, 43.61197739839554, 38.12256395816803, 39.08470652997494, 38.589452505111694, 38.15300792455673, 42.8909432888031, 47.27222219109535, 52.81145855784416, 52.37622991204262, 45.15807643532753, 41.920570358633995, 37.68316313624382, 36.24522149562836, 36.11459210515022, 38.2273243367672, 36.65119931101799, 38.4210379421711, 35.67766115069389, 37.723437175154686, 39.86737333238125, 46.72205351293087, 46.7237938195467, 49.27453614771366, 48.0285108089447, 52.26278319954872, 43.473554626107216, 42.455129474401474, 50.69132052361965, 50.65477408468723, 53.540935814380646, 47.98128314316273, 47.728809490799904, 49.68519151210785, 47.855878472328186, 47.57195770740509, 44.495604783296585, 37.34054692089558, 35.535913556814194, 35.27397081255913, 34.29447457194328, 34.994700998067856, 33.7747460603714, 36.49214364588261, 39.70550201833248, 45.818857178092, 47.430111318826675, 48.36027480661869, 45.40353566408157, 39.83144626021385, 33.75560648739338, 35.408745780587196, 34.214162081480026, 41.30520857870579, 46.30471050739288, 48.00409331917763, 44.18284356594086, 45.69698251783848, 43.92626613378525, 47.46236778795719, 45.7673167437315, 46.76065944135189, 46.49451792240143, 48.10085512697697, 45.68707264959812, 46.131527200341225, 44.53684777021408, 45.926220417022705, 45.259945169091225, 48.475777208805084, 43.56489412486553, 47.03913129866123, 40.81624701619148, 30.23279272019863, 9.807800017297268, 2.7604276640340686, 1.2192092277109623, 2.753830743022263, 2.607908835634589, 1.317686049733311, 6.310869036242366, 3.789113452658057, 5.001293532550335, 5.614698892459273, 1.8638091324828565, 1.4022290194407105, 0.5639326083473861, 1.612090333364904, 26.29492722451687, 23.72759498655796, 29.353369809687138, 27.622553184628487, 2.1544340439140797, 0.07049611056572758, 0.002519589970688685, 0.07646131547517143, 0.03209096648788545, 0.02073599385767011, 0.044008077020407654, 0.06079806240450125, 0.08190844193450175, 0.045796159392921254, 0.06135366755188443, 0.08580499183153734, 0.029898445172875654, 0.05190122203202918, 0.04907056318188552, 0.037831541849300265, 0.03388936100236606, 0.05259030243905727, 0.05276547155517619, 0.04710852510470431, 0.06389176065567881, 0.023700610363448504, 0.036874026627629064, 0.06402162907761522, 0.027900578061235137, 0.02216142205725191, 0.05664107433403842, 0.064733838516986, 0.040250412639579736, 0.05645240926241968, 0.008003835409908788, 0.03544131795933936, 0.020523147759377025, 0.06831048565800302, 0.06533810999826528, 0.026228205788356718, 0.029644098176504485, 0.06220309267519042, 0.04931765754008666, 0.023679830228502396, 0.03671833888802212, 0.015227865642373217, 0.013978966544527793, 0.03468115835858043, 0.07620395350386389, 0.04813560924958438, 0.11019921526894905, 7.235348979011178, 34.937753453850746, 28.33896294236183, 31.43782965838909, 35.05835138261318, 2.1916019869968295, 0.03856359631754458, 1.4348450442776084, 0.12937161343870685, 0.3525332675781101, 1.8270125007256866, 3.4795554634183645, 8.195106703788042, 4.625611491501331, 4.639073694124818, 2.845715512521565, 3.119442849420011, 11.436669062823057, 31.122803762555122, 48.992116302251816, 53.07036146521568, 52.16944880783558, 54.21786569058895, 52.729918733239174, 51.61057859659195, 48.51438693702221, 50.609643906354904, 51.411123499274254, 54.097575545310974, 52.45274260640144, 50.772332176566124, 50.92421002686024, 52.39959105849266, 50.45173577964306, 54.10150833427906, 51.6980043053627, 52.35851526260376, 50.93906342983246, 44.12906885147095, 39.49207507073879, 41.644336581230164, 41.16775095462799, 40.964830443263054, 46.32542319595814, 49.649446830153465, 52.851455211639404, 52.1980232745409, 46.76638953387737, 42.73544803261757, 38.277230858802795, 38.99980388581753, 38.86556848883629, 40.027253553271294, 38.55102136731148, 38.642816841602325, 37.949479445815086, 39.34798680245876, 41.07247866690159, 46.8456456810236, 48.26605886220932, 49.83128607273102, 50.451690182089806, 52.73054949939251, 45.52657686173916, 43.822022527456284, 49.879638478159904, 51.52777723968029, 54.303338304162025, 49.719051495194435, 47.28056274354458, 50.5741386115551, 50.69698981940746, 50.11777549982071, 46.35213576257229, 39.96169947087765, 36.2904466688633, 37.765326127409935, 35.592948496341705, 35.5363467335701, 36.08205445110798, 37.887333780527115, 41.64866454899311, 47.77358628809452, 49.287162870168686, 51.60604164004326, 47.8437115252018, 41.161135509610176, 35.70994421839714, 37.67801061272621, 36.91473037004471, 42.443638890981674, 47.751475274562836, 49.73843425512314, 46.59815356135368, 47.77938097715378, 44.52045165002346, 48.639461025595665, 46.943615823984146, 48.49532335996628, 47.37632900476456, 48.4981732070446, 47.54606209695339, 49.06403884291649, 46.47432580590248, 47.448958307504654, 46.49378076195717, 47.635452300310135, 44.10092756152153, 47.680529281497, 42.00643815100193, 32.3755319416523, 12.646744530647993, 4.664547527208924, 2.90265379473567, 3.472093613818288, 4.352985620498657, 5.864003514871001, 8.535714726895094, 4.56535717472434, 10.557045713067055, 7.822080720216036, 4.1845957562327385, 0.22046286379918456, 0.5304237501695752, 1.2858536140993237, 30.791220255196095, 27.683815397322178, 32.16071046888828, 35.07310979068279, 3.0826071510091424, 0.04562305715808179, 0.06150858345790766, 0.06585140159586444, 0.03630448023614008, 0.06918303610291332, 0.015292301686713472, 0.02859680349502014, 0.06930937932338566, 0.029133533971617, 0.019903237371181604, 0.042204903074889444, 0.02653056046256097, 0.006130512274467037, 0.03299592652183492, 0.05999053522828035, 0.020703547161247116, 0.07038812807877548, 0.08507584658218548, 0.033620343601796776, 0.04544658928352874, 0.10322622576495633, 0.12525006663054228, 0.2807877736631781, 0.15477169188670814, 0.11823634806205519, 0.16494865907588974, 0.16333033185219392, 0.08783398647210561, 0.11190755758434534, 0.14586936333216727, 0.1646982436068356, 0.14117348327999935, 0.1300323475152254, 0.10348340962082148, 0.11158742476254702, 0.2404316680622287, 0.17880422965390608, 0.13559515995439142, 0.16803404898382723, 0.15639917721273378, 0.09557876503095031, 0.17832086887210608, 0.24785038403933868, 0.12412865180522203, 0.199559829197824, 0.2699358231620863, 7.476570960134268, 41.937574446201324, 38.27984131872654, 35.16325235366821, 43.636106103658676, 4.476748304441571, 0.22667420940706506, 3.016218775883317, 0.3246098425006494, 0.4320853832177818, 2.215732354670763, 2.9167792992666364, 12.778131980448961, 9.711854215711355, 3.671559398062527, 2.3875230364501476, 4.000144628807902, 11.539167612791061, 30.07393654435873, 49.330381751060486, 52.27558471262455, 50.85783138871193, 56.780820563435555, 53.11094328761101, 53.034005016088486, 52.6573084294796, 52.78398983180523, 53.31135593354702, 58.023133501410484, 54.461611211299896, 52.20164068043232, 53.95275391638279, 55.73916345834732, 54.26011562347412, 57.2109042853117, 53.62174607813358, 55.54456830024719, 53.09491954743862, 46.83274917304516, 42.18317046761513, 43.01706612110138, 41.86031699180603, 41.47987000644207, 47.30805046856403, 51.11242912709713, 54.64956812560558, 55.44236518442631, 50.49489386379719, 45.91194458305836, 42.28658191859722, 40.11372551321983, 41.73855632543564, 42.20307379961014, 40.497090741992, 40.570544600486755, 40.179378390312195, 40.89274451136589, 44.67814698815346, 52.86366395652294, 49.938911497592926, 51.535688415169716, 51.72749072313309, 55.560314655303955, 47.84995079040527, 44.78154703974724, 51.634122133255005, 53.75011458992958, 56.12149514257908, 52.810896188020706, 49.76398028433323, 52.5797051936388, 52.95585460960865, 53.60444940626621, 48.19324716925621, 42.47946336865425, 38.12576338648796, 39.172668009996414, 36.59124992787838, 38.09941940009594, 36.600662022829056, 38.889807388186455, 43.40481251478195, 49.404306784272194, 50.224781557917595, 53.50321143865585, 49.22673091292381, 43.55644337832928, 37.72219464182854, 38.89056734740734, 38.00602801144123, 43.90586122870445, 49.8901791125536, 50.05058750510216, 47.68858104944229, 48.99057738482952, 46.834117099642754, 51.02070964872837, 48.07663902640343, 50.59848390519619, 49.19997274875641, 50.92242792248726, 50.1332026720047, 50.26734687387943, 47.29089818894863, 49.11898389458656, 48.283032551407814, 50.60441918671131, 45.588049963116646, 49.36541207134724, 42.96948507428169, 32.57659815251827, 11.565580945461988, 5.386544885113835, 2.771725645288825, 6.488572675734758, 8.76430381089449, 7.040343442931771, 15.602965950965881, 12.44537053629756, 15.791831966489553, 15.09615769609809, 7.696911636739969, 2.6283353520557284, 1.3472520257346332, 2.5416888389736414, 36.43939107656479, 31.95836752653122, 39.821080416440964, 38.32770735025406, 3.7364860391244292, 0.11550323339179158, 0.11446719523519278, 0.24028488609474152, 0.09449462828342803, 0.13742716633714736, 0.13217198895290494, 0.13236840575700626, 0.17821922432631254, 0.10609585107886232, 0.10505934536922723, 0.31096239981707186, 0.12176458491012454, 0.15805296425241977, 0.10797793016536161, 0.1312608690932393, 0.1249011978507042, 0.09521418498479761, 0.18671488563995808, 0.14241773838875815, 0.14672071061795577], [0.059414272400317714, 0.047937789786374196, 0.036262174107832834, 0.030972336571721826, 0.07717467524344102, 0.027161250545759685, 0.0076727568375645205, 0.02201952342147706, 0.030717744666617364, 0.06137852949905209, 0.04702874051872641, 0.03361670707818121, 0.03474743585684337, 0.02630763228808064, 0.03699072934978176, 0.08406173888943158, 0.01118865640819422, 0.055797623499529436, 0.054147628834471107, 0.018604126416903455, 0.04132031499466393, 0.021083968349557836, 0.09814091114094481, 0.1251045017852448, 0.043907330473302864, 0.04168882100202609, 0.5176461045630276, 12.419268786907196, 36.74049451947212, 25.743495114147663, 36.66378043591976, 10.174844171851873, 0.0740191746444907, 0.07975346030434594, 0.047177886226563714, 0.28492753277532756, 1.7219543131068349, 3.4898821217939258, 8.615702334791422, 3.86058880481869, 3.688604333437979, 4.225571807473898, 2.269298080354929, 0.6397599738556892, 9.508940353989601, 28.8718843460083, 49.64031971991062, 53.18693161010742, 53.186908811330795, 51.847112104296684, 51.376780942082405, 51.5836114436388, 52.566956877708435, 53.1443776935339, 51.9596316665411, 49.118634313344955, 49.74581725895405, 50.143557116389275, 51.18654415011406, 51.18825405836105, 51.03872448205948, 51.86125114560127, 51.92337021231651, 49.47503238916397, 46.7947132140398, 37.23229832947254, 40.953108072280884, 37.93116442859173, 37.18969501554966, 46.40454635024071, 51.37953199446201, 50.838919803500175, 52.19420067965984, 46.46021716296673, 45.88972717523575, 39.251559376716614, 37.70222291350365, 36.91982589662075, 37.179845944046974, 36.75576210021973, 37.91777014732361, 37.12448671460152, 40.560520738363266, 46.20085068047047, 50.13862498104572, 48.9189550280571, 52.22866103053093, 50.089489817619324, 50.26320889592171, 42.2504648566246, 44.64391462504864, 50.82438938319683, 49.420402720570564, 47.897972613573074, 48.35511848330498, 46.64274036884308, 46.21266424655914, 47.14136481285095, 42.48300477862358, 38.72817926108837, 36.03844799101353, 35.09091183543205, 34.21380490064621, 34.81386110186577, 33.67619454860687, 35.211764350533485, 36.671843603253365, 41.514261960983276, 47.36841402947903, 47.96701490879059, 48.28580640256405, 47.03405477106571, 43.615062832832336, 36.046146377921104, 35.45082092285156, 34.1067760437727, 40.992838740348816, 45.74916511774063, 48.178853541612625, 43.771215453743935, 45.69905340671539, 43.64791966974735, 44.38727639615536, 47.877297922968864, 44.85531248152256, 47.188204899430275, 45.83793215453625, 46.37458115816116, 46.87623783946037, 45.40679968893528, 45.72059065103531, 44.72416631877422, 47.46270217001438, 42.66417145729065, 47.55737788975239, 35.952830985188484, 20.541378557682037, 5.090124690905213, 1.3077990990132093, 3.1463287817314267, 2.964723464101553, 3.496234668418765, 5.776757346466184, 6.348287528380752, 3.1302326079458, 8.337188679724932, 5.8005421701818705, 3.6356750736013055, 0.3617584006860852, 0.20022100856294855, 9.467781912535429, 30.243916623294353, 25.657931305468082, 35.55104434490204, 12.056128922849894, 0.20505544758634642, 0.13796185405226424, 0.017985858030442614, 0.037927742741885595, 0.028190902521600947, 0.07066488979035057, 0.025443041377002373, 0.09185063070617616, 0.00741599786124425, 0.009902036726998631, 0.005841846514158533, 0.02256581461551832, 0.019290683521830942, 0.03117136388027575, 0.03894120847689919, 0.08102573890937492, 0.04560339766612742, 0.04630182171240449, 0.07915558613603935, 0.08749302898650058, 0.02440196774841752, 0.03234718184103258, 0.041753747791517526, 0.03627237492764834, 0.01086496591597097, 0.06368920629029162, 0.026195540158369113, 0.02531657570216339, 0.023233190913742874, 0.05370825143472757, 0.07960760602145456, 0.028096397436456755, 0.04176722148258705, 0.07007825915934518, 0.02441813729092246, 0.06991152826230973, 0.06637471218709834, 0.0841257194406353, 0.07439288310706615, 0.032077852738439105, 0.03327374579384923, 0.025720777157403063, 0.034624332110979594, 0.06673896568827331, 0.058947394718416035, 0.04403519138577394, 0.011057065275963396, 0.7087893853895366, 16.98949445039034, 42.05171272158623, 25.120871923863888, 41.40667833387852, 10.907997731119394, 0.05234926029515918, 0.2892233803868294, 0.28740476234816015, 0.48377472208812833, 2.0503913518041372, 5.88218791410327, 6.101252334192395, 6.20208372361958, 7.966767931357026, 9.171688500791788, 5.632623955607414, 2.2659343108534813, 10.839545354247093, 32.26994700729847, 51.57876670360565, 54.958799332380295, 55.150343254208565, 52.81087338924408, 53.43896068632603, 52.139749601483345, 52.23718777298927, 54.80423882603645, 54.277499690651894, 51.30238093435764, 51.264025792479515, 50.45838162302971, 53.28853815793991, 53.6273317784071, 52.33048416674137, 53.784411549568176, 53.78223806619644, 50.14905542135239, 47.461436837911606, 40.07300689816475, 42.92166084051132, 39.93804194033146, 38.67385737597942, 49.09919835627079, 52.23876088857651, 52.68644906580448, 55.15221655368805, 48.784818425774574, 45.86638882756233, 41.534518674016, 38.76833550632, 38.16938504576683, 37.618836387991905, 37.47112311422825, 38.9621365070343, 39.17988762259483, 43.18066634237766, 47.350653782486916, 52.20778875052929, 50.99778547883034, 53.1117108464241, 52.31729507446289, 51.01466417312622, 42.45352976024151, 44.49410006403923, 51.850851103663445, 52.6286693662405, 50.826657861471176, 49.08954307436943, 50.27611680328846, 47.86847099661827, 49.415147602558136, 46.254264414310455, 39.357455894351006, 39.43424217402935, 36.61809168756008, 36.01737052202225, 36.91479876637459, 35.26069052517414, 35.89334897696972, 38.0023156106472, 42.63894461095333, 50.118911638855934, 49.34452839195728, 50.249263644218445, 50.17732210457325, 44.64788541197777, 37.29939892888069, 37.04276829957962, 36.66277348995209, 42.662864327430725, 47.066360637545586, 49.81584370136261, 45.637751296162605, 47.69602485001087, 45.9812680631876, 46.5336824208498, 49.09383304417133, 45.64932927489281, 49.353032335639, 46.43212527036667, 47.84995838999748, 47.84306935966015, 46.356034353375435, 46.021534502506256, 45.575529634952545, 47.09459692239761, 45.07232643663883, 47.71939739584923, 39.61223602294922, 20.938024073839188, 6.8029283825308084, 2.3655134299769998, 3.8844935595989227, 4.665100397542119, 7.945262510329485, 7.089101001620293, 6.9687472097575665, 6.593481721356511, 7.276904974132776, 5.838514482602477, 2.376847271807492, 0.3630617307499051, 0.26415743166580796, 10.173483844846487, 36.76452822983265, 24.91098638623953, 39.44902718067169, 17.509112767875195, 0.30612537811975926, 0.15012351708719507, 0.0076056597299611894, 0.012795574966730783, 0.04436643786903005, 0.07150638877646998, 0.019476858687994536, 0.055940861711860634, 0.09987441226257943, 0.06334941397653893, 0.09086522928555496, 0.017104613325500395, 0.02260316876345314, 0.05224156724580098, 0.025978421144827735, 0.055270427765208296, 0.044777298244298436, 0.031210100278258324, 0.02276238170452416, 0.05260793957859278, 0.028343747835606337, 0.127972754125949, 0.0932461503543891, 0.10216927388682961, 0.06625648806220852, 0.1441874192096293, 0.1534860991523601, 0.10443110993946902, 0.09460880028200336, 0.17124416423030198, 0.13621230027638376, 0.09699493122752756, 0.18989728909218684, 0.20578481548000127, 0.10240493546007201, 0.19798755965894088, 0.2508871187455952, 0.12797330331522971, 0.19202336407033727, 0.18639046320458874, 0.07011589346802793, 0.12522680772235617, 0.08949376264354214, 0.26158021995797753, 0.15806004434125498, 0.11735665815649554, 0.14738799043698236, 0.8121768501587212, 21.108275838196278, 52.823165729641914, 33.47491554915905, 46.344748958945274, 15.710525829344988, 0.14779050165088847, 0.43854868796188384, 0.22674195264698938, 1.0836589825339615, 6.462589669972658, 12.328208573162556, 19.84329331666231, 8.85177606716752, 8.390530217438936, 7.911120867356658, 3.975108484737575, 1.7234964366070926, 11.596421040594578, 32.40945652127266, 51.113557666540146, 56.86235658824444, 55.86896829307079, 54.30242635309696, 54.89948831498623, 53.66822138428688, 56.41591854393482, 57.10839718580246, 55.21355666220188, 51.85086250305176, 52.21029281616211, 52.0083374530077, 55.46864457428455, 55.78376166522503, 54.25977364182472, 55.63996598124504, 55.894943699240685, 53.537299409508705, 49.72810260951519, 41.36839918792248, 45.388378277421, 40.48516318202019, 40.47142691910267, 51.628711223602295, 54.39641050994396, 55.601903423666954, 54.11955736577511, 48.604833483695984, 48.73345658183098, 43.55009771883488, 40.54487317800522, 39.690679013729095, 38.56854982674122, 38.95419493317604, 40.85889592766762, 39.91256430745125, 45.77625386416912, 49.6289849281311, 55.816618502140045, 53.01973298192024, 55.78515999019146, 55.17848454415798, 51.78357191383839, 45.03071866929531, 47.73719564080238, 52.526386454701424, 53.82143676280975, 52.82479964196682, 52.71995186805725, 51.10799476504326, 49.62535232305527, 50.503371208906174, 46.34489335119724, 41.120926067233086, 41.18608117103577, 38.687407448887825, 38.92162688076496, 39.032421335577965, 37.905812188982964, 38.437335267663, 40.03684803843498, 44.870511665940285, 52.15586073696613, 50.707598850131035, 51.9956461340189, 51.9629792869091, 47.681304439902306, 40.124744921922684, 38.966221287846565, 38.70679780840874, 44.05734769999981, 49.03415724635124, 51.39582172036171, 46.98091082274914, 48.88957880437374, 47.332646548748016, 47.394970804452896, 50.29711827635765, 46.88107118010521, 51.08583815395832, 49.359013214707375, 49.899165630340576, 49.7068427503109, 46.74888767302036, 46.72959990799427, 47.41794437170029, 48.9651795476675, 45.7740043848753, 48.56463924050331, 39.94747303426266, 22.083356715738773, 7.279662201181054, 3.9723631320521235, 6.732502011582255, 9.459880236536264, 10.77541334554553, 12.360647432506084, 15.514008924365044, 11.804245188832283, 17.722661308944225, 13.940937984734774, 7.823564540594816, 1.989343708846718, 0.29409320501144975, 13.29626077786088, 39.124767780303955, 32.76300095021725, 48.515078499913216, 19.010569900274277, 0.5751098867040128, 0.22057259775465354, 0.09377654845593497, 0.18320532864890993, 0.09463509457418695, 0.116357697697822, 0.15040775964735076, 0.18285699421539903, 0.22158196312375367, 0.13058417884167284, 0.20389328885357827, 0.21266131836455315, 0.07359319672104903, 0.11887659144122154, 0.10308691722457297, 0.13972246582852677, 0.14325354510219768, 0.17474840744398534, 0.12030951533233747, 0.1572830305667594, 0.1519589521922171], [0.04607395640050527, 0.01256258605280891, 0.025854348896245938, 0.05300196062307805, 0.05013085472455714, 0.06024197857186664, 0.026968258753186092, 0.013352951064007357, 0.04345935529272538, 0.025474122521700338, 0.05535419397347141, 0.04100422687770333, 0.06116250515333377, 0.019481137169350404, 0.04073494601470884, 0.08814856802928261, 0.04989526736608241, 0.022786816916777752, 0.04831967300560791, 0.06624608315178193, 0.045318446354940534, 0.03498792881146073, 0.08913173558539711, 0.025601925917726476, 0.04554601851850748, 0.07301432153326459, 0.14817196555668488, 1.1439678026363254, 20.716737248003483, 29.071666225790977, 27.012399025261402, 23.73330608010292, 0.5587986682076007, 0.04766003730765078, 0.2718563232338056, 0.7494807487819344, 1.4271113905124366, 4.81742424890399, 2.349237003363669, 17.949748523533344, 29.193918965756893, 9.997824020683765, 4.0727221593260765, 1.0116381221450865, 1.5222848835401237, 13.650213684886694, 35.75199656188488, 51.168464720249176, 53.39844726026058, 53.630493208765984, 52.44729369878769, 52.861961647868156, 52.81101018190384, 51.57478451728821, 52.18776002526283, 50.83497181534767, 48.43266472220421, 50.8608104288578, 52.89679057896137, 52.4615353345871, 54.06716197729111, 52.72494480013847, 52.5213061273098, 52.24961690604687, 45.49213171005249, 38.829626217484474, 39.58149567246437, 39.33213785290718, 37.608158960938454, 44.83231231570244, 51.968872770667076, 50.12169308960438, 52.683158442378044, 49.894260093569756, 46.626393646001816, 41.89561329782009, 39.67022091150284, 36.25770762562752, 36.67922280728817, 36.6715282201767, 37.24018670618534, 38.07310961186886, 47.77946837246418, 50.235398188233376, 52.25598156452179, 51.509534418582916, 49.48179602622986, 46.678230464458466, 49.52776975929737, 44.42147836089134, 46.273799166083336, 53.47720943391323, 48.418951258063316, 47.99675591289997, 45.06582498550415, 45.36416977643967, 45.18781743943691, 42.08718381822109, 39.80517067015171, 36.258725970983505, 34.85637702047825, 34.07651446759701, 34.62676294147968, 34.731527119874954, 35.76297417283058, 35.408760979771614, 36.59462034702301, 40.97553446888924, 49.02636766433716, 46.28078319132328, 50.13803221285343, 46.398242488503456, 45.5094625800848, 37.760754972696304, 35.75109601020813, 34.884997084736824, 39.2571184784174, 47.82826915383339, 46.14115208387375, 49.77191425859928, 44.663662165403366, 45.95302037894726, 45.39941668510437, 45.74592009186745, 46.22052222490311, 45.58742679655552, 46.85135297477245, 44.29505154490471, 44.636185839772224, 46.075780391693115, 46.86555281281471, 47.17856101691723, 46.04782909154892, 45.17109453678131, 46.33583843708038, 30.946381129324436, 12.54273746162653, 2.9016534984111786, 1.359150493517518, 2.4927439028397202, 2.2735711885616183, 4.944803863763809, 6.158585082739592, 5.569640910252929, 2.2963552409783006, 5.717342309653759, 3.622880447655916, 1.4111881074495614, 0.2024827926652506, 0.25204899546224624, 21.647153422236443, 27.672493904829025, 27.574839144945145, 28.0680013820529, 3.7563076755031943, 0.04420573321112897, 0.056351373277720995, 0.033650649202172644, 0.10378539693192579, 0.059503419179236516, 0.04208935810311232, 0.05023186844482552, 0.042650495961424895, 0.014710802079207497, 0.04654029602534138, 0.03448971765465103, 0.010549399157753214, 0.04571972931444179, 0.048093273435370065, 0.0565737095894292, 0.021665509702870622, 0.07648261511349119, 0.018790702342812438, 0.06339760904666036, 0.05589487453107722, 0.05314693917171098, 0.09106232144404203, 0.008618894007668132, 0.029627197618538048, 0.01336584216915071, 0.040850914010661654, 0.04951249356963672, 0.04891394775768276, 0.05034033703850582, 0.06060526728106197, 0.016235007351497188, 0.03798520723648835, 0.04889579853625037, 0.12958223494933918, 0.036035329248989, 0.06063145767257083, 0.041341147079947405, 0.05814653944980819, 0.0597545322671067, 0.05687131451850291, 0.04712836642283946, 0.025795069850573782, 0.010205800554103917, 0.0841934626805596, 0.02431421249639243, 0.07269668974913657, 0.05815916709252633, 0.2676769037498161, 3.779446058906615, 30.421937070786953, 31.800176315009594, 35.24177514016628, 24.48761310428381, 0.3545612603193149, 0.026363606921222527, 0.5807956878561527, 0.48400327388662845, 1.1328104138374329, 6.606922075152397, 7.485882360488176, 18.10458831489086, 26.158603839576244, 15.15849620103836, 10.202291049063206, 3.057366767898202, 2.6101181795820594, 16.495697647333145, 38.61588768661022, 54.425353556871414, 55.354878678917885, 54.78663057088852, 54.1026596724987, 54.606375843286514, 54.16846074163914, 52.88256414234638, 51.97924621403217, 51.74301289021969, 48.52695666253567, 51.475685834884644, 51.25119008123875, 54.4898284971714, 53.93202982842922, 54.00433614850044, 53.506901040673256, 53.28014060854912, 46.82417303323746, 40.032786056399345, 41.34842365980148, 41.85675658285618, 39.754033014178276, 46.59725300967693, 53.51914018392563, 53.05606663227081, 53.87287460267544, 51.748112216591835, 48.88196021318436, 42.781338170170784, 42.282880917191505, 38.930282816290855, 38.33586171269417, 39.05197888612747, 38.43503259122372, 39.93797354400158, 49.33771915733814, 52.919881939888, 55.07125049829483, 52.54989579319954, 51.56548261642456, 48.855692222714424, 49.399222657084465, 45.70037193596363, 47.59114287793636, 54.83347825706005, 50.661043748259544, 49.89281237125397, 47.908315658569336, 48.72567839920521, 47.5196573138237, 44.021603018045425, 40.716099590063095, 38.847789242863655, 36.389951929450035, 36.244225949048996, 37.03174129128456, 36.57269932329655, 36.83504864573479, 37.373320162296295, 38.2746621966362, 43.588958233594894, 50.16906134784222, 49.32731531560421, 50.78427113592625, 48.33923153579235, 47.705212756991386, 39.09028083086014, 37.24568881094456, 36.549303978681564, 41.19393914937973, 48.64208668470383, 47.7519616484642, 49.53737944364548, 45.253154933452606, 47.7031646668911, 46.5936242043972, 48.855958208441734, 47.96046786010265, 46.67410008609295, 47.60717421770096, 45.92423692345619, 46.514478251338005, 46.84811934828758, 47.506833001971245, 47.734786570072174, 47.770383059978485, 46.99891045689583, 47.53451071679592, 31.110330931842327, 14.662161134183407, 3.924103109166026, 2.532122852280736, 4.743113536387682, 4.618773283436894, 5.539157520979643, 7.537065139040351, 6.03537954390049, 6.019531544297934, 6.975099993869662, 3.369964356534183, 0.6001672858837992, 0.24093571992125362, 0.14305617834907025, 24.769246391952038, 31.969166547060013, 30.074345022439957, 36.36231981217861, 5.774766253307462, 0.03251628018915653, 0.0870780274271965, 0.04061859581270255, 0.09583403414580971, 0.086769531480968, 0.021799734531668946, 0.06060125226213131, 0.013438470596156549, 0.01127448393162922, 0.027019940062018577, 0.05901176489714999, 0.08507436970830895, 0.04274342027201783, 0.04745702652144246, 0.019793590618064627, 0.030058086704229936, 0.10533605513046496, 0.012967672519152984, 0.03777408477617428, 0.03519966354360804, 0.04067643138114363, 0.10932411183603108, 0.07666020363103598, 0.11847525282064453, 0.11068138861446641, 0.11316358315525576, 0.2157707983860746, 0.16495425486937165, 0.24599556403700262, 0.15926927007967606, 0.13263759756227955, 0.17229195800609887, 0.10736681608250365, 0.2691112970933318, 0.10917283245362341, 0.246787361393217, 0.16796865093056113, 0.1114751526620239, 0.14147953013889492, 0.19381795136723667, 0.16729173803469166, 0.10237161302939057, 0.08330731609021313, 0.16384127084165812, 0.15394957037642598, 0.18376749067101628, 0.14163336250931025, 0.27418536075856537, 5.0508020259439945, 37.39832662045956, 39.09826040267944, 37.32876755297184, 29.94455348700285, 1.4719261857680976, 0.288310123141855, 0.8875911065842956, 2.2499716049060225, 4.41187628544867, 10.571501087397337, 7.956392113119364, 28.44060368835926, 38.81688170135021, 17.093720957636833, 7.9448093846440315, 2.3555035796016455, 2.5889901258051395, 15.950668193399906, 38.956303820014, 54.74413365125656, 57.782788798213005, 56.23143844306469, 56.22628211975098, 54.96058143675327, 54.6576426923275, 52.50465542078018, 54.61526356637478, 53.8059525936842, 48.963595032691956, 52.86396034061909, 53.892124369740486, 54.981848895549774, 57.566333413124084, 54.53023552894592, 55.15223555266857, 55.788663402199745, 48.50648336112499, 41.07614926993847, 42.49403178691864, 43.859925493597984, 42.031592801213264, 47.97842189669609, 56.30394235253334, 54.97061289846897, 54.416564628481865, 53.695811703801155, 50.40466010570526, 45.28293013572693, 44.78953801095486, 40.21274819970131, 39.3986114859581, 40.26355527341366, 38.819704949855804, 42.26677358150482, 50.18562085926533, 54.840523079037666, 57.75185085833073, 53.81556987762451, 52.03833304345608, 49.45219561457634, 49.534597992897034, 47.35712483525276, 50.347552970051765, 56.13921359181404, 53.19759763777256, 51.15806847810745, 48.968500569462776, 49.9898287653923, 48.25594000518322, 45.35997100174427, 43.886809051036835, 40.87426610291004, 39.381706193089485, 36.7762316018343, 38.331776931881905, 39.82713349163532, 39.04176503419876, 38.64829234778881, 41.16506069898605, 44.67385321855545, 51.73880651593208, 48.6710449308157, 52.12537117302418, 50.72852052748203, 49.784677773714066, 41.596257761120796, 38.273233473300934, 38.876147121191025, 43.98991271853447, 51.01822078227997, 49.37694825232029, 50.626666992902756, 46.87417075037956, 48.99754621088505, 49.29542362689972, 50.90467147529125, 49.07281257212162, 48.05411383509636, 49.77997362613678, 48.42455595731735, 46.47832699120045, 47.19993107020855, 49.21980768442154, 49.02075916528702, 49.43407438695431, 48.99977669119835, 49.07522924244404, 31.277187578380108, 14.278424475342035, 4.400055119767785, 4.2714833188802, 6.404017237946391, 6.274989936500788, 11.391482837498188, 15.35323765128851, 12.906216457486153, 9.480617623776197, 13.513831403106451, 10.778554826974869, 2.4062966415658593, 0.5077508417889476, 0.5675297684501857, 29.884959384799004, 37.56899446249008, 38.202420473098755, 41.728802248835564, 7.063419604673982, 0.10277588313329034, 0.15763252275064588, 0.12104836787329987, 0.18627657322213054, 0.2665761800017208, 0.1455557465669699, 0.2052176365396008, 0.11090418134699576, 0.06990275607677177, 0.1165635694633238, 0.10326422372600064, 0.18698977713938802, 0.1782287089736201, 0.13710689992876723, 0.11799091240391135, 0.11768210475565866, 0.22919452807400376, 0.08191126951714978, 0.16685964481439441, 0.14217548654414713, 0.1327223953558132], [0.05804711763630621, 0.011999405433016364, 0.0032134588536791853, 0.02472784479323309, 0.02092685754178092, 0.06274894229136407, 0.0823874759953469, 0.06845262920251116, 0.03093193590757437, 0.04759256124089006, 0.0665792184008751, 0.0784989635576494, 0.05122839465911966, 0.04857705353060737, 0.06488080602139235, 0.025706010274006985, 0.07312901303521357, 0.02828250395396026, 0.011981630996160675, 0.0318370146851521, 0.020397049447637983, 0.04389797570183873, 0.14044378884136677, 0.04721269666333683, 0.0345783634838881, 0.03944255149690434, 0.21160807722480968, 0.6520193035248667, 9.0300359018147, 23.87626200914383, 28.90399642288685, 41.08614273369312, 8.070789724588394, 0.031941015549818985, 0.6558968767058104, 0.47192847181577235, 0.6247369456104934, 4.5008285623043776, 5.232852157205343, 17.039999440312386, 14.827129282057285, 18.293056301772594, 17.729282453656197, 4.386373478919268, 0.27572237828280777, 4.0174460504204035, 26.429795287549496, 46.81058116257191, 54.172043949365616, 52.700747698545456, 54.62221719324589, 52.690241262316704, 54.76854734122753, 53.039579316973686, 52.83153288066387, 54.55540157854557, 52.88907699286938, 52.966528236866, 53.0238975584507, 53.08260440826416, 52.936821430921555, 53.23208838701248, 49.73526902496815, 46.734646037220955, 39.908753111958504, 38.59327889978886, 39.00118701159954, 38.31636115908623, 39.12476398050785, 47.290275022387505, 53.66079658269882, 52.075624242424965, 52.71215468645096, 50.01542419195175, 49.190218672156334, 43.16674388945103, 39.34037961065769, 37.196998223662376, 36.13633073866367, 38.15853662788868, 36.604271829128265, 43.556751161813736, 53.45710091292858, 49.25214394927025, 50.432163029909134, 51.333098486065865, 51.345611214637756, 49.102033004164696, 47.61315129697323, 41.582380905747414, 46.32549159228802, 51.920858547091484, 48.22623319923878, 44.88785773515701, 41.946184784173965, 44.354989528656006, 40.91723419725895, 40.959651321172714, 36.76487401127815, 36.28192752599716, 35.062983334064484, 34.3947321921587, 35.610157772898674, 35.326996967196465, 36.36818289756775, 36.89929939806461, 36.6410880535841, 41.994290202856064, 48.10138329863548, 47.96241335570812, 46.43881291151047, 48.759872764348984, 45.910116881132126, 41.53198421001434, 36.34726122021675, 36.00713387131691, 35.29209963977337, 43.58149543404579, 45.78766465187073, 48.39468955993652, 46.07627436518669, 47.40728214383125, 49.98388208448887, 45.290841311216354, 46.21376998722553, 45.11666625738144, 43.53984206914902, 47.514637783169746, 48.41680437326431, 48.35511468350887, 46.35478422045708, 48.077889159321785, 45.00819727778435, 47.422659918665886, 41.25185564160347, 26.311253048479557, 6.5999717731028795, 1.6966911312192678, 1.9537549372762442, 3.345714770257473, 4.164712848141789, 5.462186951190233, 5.247514145448804, 4.598516095429659, 7.070534247905016, 4.011800978332758, 2.8980042692273855, 0.12172309885499999, 0.14969376905355603, 6.853391574695706, 39.33504469692707, 26.424492672085762, 35.63751630485058, 12.732616122812033, 0.5170478741638362, 0.0640780026151333, 0.03254279712564312, 0.07343824370764196, 0.03391541038581636, 0.018847491483029444, 0.04003789865237195, 0.040575610619271174, 0.05205939225561451, 0.07263669453095645, 0.019110252578684594, 0.018143683155358303, 0.01746860707498854, 0.015086312105268007, 0.06620154686970636, 0.06998569107963704, 0.06702704515191726, 0.05393996478233021, 0.03557581738277804, 0.03994504855654668, 0.019183879194315523, 0.031732579664094374, 0.016803050893940963, 0.046883453978807665, 0.019590364609030075, 0.029104623608873226, 0.014969761523389025, 0.059234323853161186, 0.03496400568110403, 0.05663832096615806, 0.07168655254645273, 0.055912092357175425, 0.07160403314628638, 0.07615396243636496, 0.05090596489026211, 0.042235843211528845, 0.04825669435376767, 0.024314147558470722, 0.09820284336456098, 0.030127032223390415, 0.04065078275743872, 0.012541092528408626, 0.0394553090154659, 0.030909148263162933, 0.07068633785820566, 0.05915462832490448, 0.0195875926874578, 0.0653099974442739, 0.08430330053670332, 0.9761469578370452, 14.475523699074984, 30.249715112149715, 30.236261934041977, 42.0161048322916, 7.4723997339606285, 0.010310276393283857, 0.24560166173614562, 0.2986135968239978, 0.6992641871329397, 4.763897471129894, 7.335354862734675, 19.37059488147497, 15.65500320866704, 9.840251225978136, 15.78754199668765, 5.747495116665959, 0.9607865789439529, 4.804443195462227, 28.157121799886227, 48.769022673368454, 55.57893365621567, 55.32072991132736, 54.82053615152836, 54.10657726228237, 54.99143198132515, 53.18349279463291, 52.361828684806824, 55.709711238741875, 54.48645427823067, 54.79410097002983, 53.43007676303387, 53.13496179878712, 54.569666013121605, 54.717622473835945, 51.16097912192345, 48.99432398378849, 43.237469494342804, 39.73177380859852, 40.724622532725334, 40.78040733933449, 39.15700905025005, 49.830913692712784, 54.302000775933266, 55.02246871590614, 54.14197616279125, 54.09181885421276, 50.388875752687454, 45.11497534811497, 40.45668751001358, 39.17112149298191, 37.99522519111633, 38.48505310714245, 37.026429176330566, 43.81808213889599, 54.67056579887867, 51.19383595883846, 51.99434280395508, 51.74393244087696, 51.550017446279526, 48.535301014781, 47.671930342912674, 44.174130633473396, 49.34657648205757, 52.867019176483154, 48.35296779870987, 46.68086752295494, 44.824952110648155, 45.10150507092476, 44.22417014837265, 42.51099407672882, 39.65438716113567, 38.113049268722534, 37.42123559117317, 35.48528507351875, 37.11699351668358, 37.1758371591568, 36.768537014722824, 38.343970477581024, 39.03226174414158, 44.48278807103634, 52.31651611626148, 50.89815482497215, 47.334926426410675, 50.890627428889275, 47.64679089188576, 44.598917439579964, 36.84710919857025, 35.54730914533138, 36.93424232304096, 45.61332240700722, 47.497322112321854, 50.1682747900486, 47.28558987379074, 47.621286660432816, 49.34415601193905, 47.83740006387234, 49.07236039638519, 46.10060065984726, 47.419186905026436, 49.34381403028965, 48.83836515247822, 49.25155498087406, 48.39836776256561, 48.53108324110508, 46.16591155529022, 47.21843607723713, 43.42652074992657, 27.71882101893425, 8.36226923391223, 2.1263616252690554, 4.092456875368953, 4.090492380782962, 4.221560647711158, 6.97096249088645, 6.650484837591648, 6.149287456646562, 6.475749788805842, 3.7029086658731103, 1.068192149978131, 0.028223228619026486, 0.1301465491997078, 5.988881438970566, 40.852709859609604, 28.532568253576756, 38.57670038938522, 18.4790126234293, 0.8192342589609325, 0.09905603859806433, 0.03881595250277314, 0.006420258787329658, 0.05966068769339472, 0.03423222580750007, 0.05473628923937213, 0.07329949177801609, 0.05594737405772321, 0.06182917641126551, 0.07357960799708962, 0.016786116939329077, 0.016847845072334167, 0.02102204911352601, 0.010471802052052226, 0.06623046836466528, 0.09947122569428757, 0.012958505139977206, 0.052113012425252236, 0.03543693557730876, 0.022631136598647572, 0.03409180404560175, 0.12703724729362875, 0.0936676531273406, 0.0928767018194776, 0.0942354480503127, 0.07818301644874737, 0.19598208367824554, 0.16413127246778458, 0.0997451004514005, 0.08455651390249841, 0.15022260864498094, 0.23540545807918534, 0.1604350801790133, 0.15982843382516876, 0.12585270538693294, 0.2087685014703311, 0.10515419926377945, 0.20036382746184245, 0.12635221530217677, 0.10872399638174102, 0.11386041529476643, 0.16914180829189718, 0.10514363850234076, 0.16876083420356736, 0.15663810423575342, 0.15396015340229496, 0.12937522027641535, 0.18634715146617964, 1.0231207497417927, 19.79816123843193, 39.3529911339283, 35.429891645908356, 49.53103378415108, 10.431105270981789, 0.12153945441241376, 2.27952903136611, 1.183721269480884, 2.944402629509568, 13.554548118263483, 14.805569238960743, 24.70262836664915, 19.879999347031116, 26.634904481470585, 27.61597953736782, 10.457467306405306, 1.4585245423950255, 4.8414114117622375, 30.41620507836342, 50.924457013607025, 57.85153850913048, 56.17063030600548, 57.14579097926617, 54.22445073723793, 57.66193248331547, 55.76466768980026, 54.74191077053547, 58.24029564857483, 56.922894939780235, 55.07774814963341, 55.827003344893456, 55.767095759510994, 56.83422289788723, 58.51849012076855, 53.6441420763731, 51.163593381643295, 44.163928180933, 41.07792757451534, 43.422796949744225, 41.38302460312843, 41.36495277285576, 52.00742170214653, 57.162107303738594, 56.12771540880203, 55.839094296097755, 54.680441468954086, 52.827968671917915, 47.17495121061802, 42.61426493525505, 40.84443390369415, 39.35389928519726, 41.52058482170105, 39.51309934258461, 45.937574207782745, 58.307392448186874, 52.18375504016876, 52.856995314359665, 52.183363661170006, 53.82768362760544, 50.12883670628071, 46.79003186523914, 44.03453752398491, 50.13776622712612, 55.604544281959534, 51.87717229127884, 48.809087723493576, 46.6261200606823, 47.18967542052269, 45.77300503849983, 43.71535085141659, 40.229440703988075, 39.912921488285065, 38.73825632035732, 38.925650864839554, 39.23076689243317, 37.78902545571327, 39.35372829437256, 40.7636084407568, 41.22097469866276, 47.16073617339134, 53.60628470778465, 51.50460608303547, 49.05834674835205, 51.7981593310833, 50.12605145573616, 46.24565787613392, 40.66802076995373, 38.40828202664852, 39.19898919761181, 47.448274344205856, 50.046734511852264, 51.90594434738159, 48.72568219900131, 49.74203646183014, 49.983502104878426, 50.014778226614, 49.97004322707653, 48.86429116129875, 48.15949738025665, 52.304744347929955, 51.45001441240311, 52.520523369312286, 49.14032734930515, 50.17400488257408, 49.68263424932957, 50.47295764088631, 43.30531105399132, 29.238536171615124, 7.837220057845116, 3.5465263947844505, 5.049051744863391, 8.688359186053276, 9.256225414574146, 13.077654708176851, 12.020906712859869, 12.570239435881376, 16.205702908337116, 11.288812346756458, 5.708950459957123, 1.0839664097875357, 0.20016548107378185, 8.843832593411207, 49.09458540380001, 33.65468010306358, 50.77613577246666, 22.239638529717922, 0.9598905395250767, 0.23362995882052928, 0.1187636810936965, 0.1336686039576307, 0.11589137662667781, 0.12293800944462419, 0.17359586694510654, 0.17945215426152572, 0.35121372900903225, 0.1375700149219483, 0.13486648967955261, 0.11058053816668689, 0.07356570757110603, 0.1084732246818021, 0.22230554226553068, 0.15757374465465546, 0.22503551765112206, 0.1300250447820872, 0.11125886114314198, 0.08881995934643783, 0.10088193710544147, 0.150698340148665], [0.021327596878109034, 0.033053509760065936, 0.038550107783521526, 0.04136830226343591, 0.03497727528156247, 0.004969582259946037, 0.013971621137898182, 0.054619293368887156, 0.03586736638681032, 0.014569064860552317, 0.07536357516073622, 0.053435820154845715, 0.026661024458007887, 0.07055721900542267, 0.037210761292953975, 0.01945141972100828, 0.05459053143567871, 0.0387544358818559, 0.06463168931077234, 0.031048592245497275, 0.06433166126953438, 0.047056381808943115, 0.016310799182974733, 0.008717355667613447, 0.033509463028167374, 0.045562249288195744, 0.19424271216848865, 0.2480108808958903, 5.023766001686454, 24.685335494577885, 31.766854003071785, 41.34008690714836, 18.206582441926003, 0.4339144506957382, 0.05108187615405768, 0.07179853520938195, 0.6046283058822155, 4.365769559517503, 8.564254995435476, 5.029902197420597, 5.100872414186597, 7.766940454021096, 12.519832290709019, 4.343376886099577, 1.136499303393066, 1.1044513480737805, 15.763215702027082, 40.04565976560116, 51.45522013306618, 54.77389745414257, 54.324107989668846, 52.95185722410679, 52.59432300925255, 53.140558898448944, 53.507706597447395, 53.22096258401871, 53.84302720427513, 52.914467230439186, 52.14954927563667, 49.614287316799164, 49.408338367938995, 44.280958101153374, 41.36287808418274, 40.559935569763184, 39.56672966480255, 38.78953076899052, 38.7535884976387, 39.07058268785477, 39.69718046486378, 48.89828033745289, 53.62017676234245, 51.09527684748173, 52.4734590947628, 53.534365966916084, 49.27837014198303, 44.45259869098663, 40.521075055003166, 38.08306127786636, 36.44063360989094, 39.09829840064049, 38.015257716178894, 47.14994855225086, 51.57225005328655, 50.756597220897675, 49.548911824822426, 49.02936190366745, 48.566117361187935, 47.04006984829903, 48.75885061919689, 46.30485109984875, 48.65730106830597, 51.58101998269558, 49.58976723253727, 45.56887999176979, 41.9553042948246, 41.64253167808056, 38.36090996861458, 38.65906476974487, 36.731397807598114, 35.40533356368542, 33.50979767739773, 35.416831746697426, 36.347641199827194, 35.50479702651501, 35.12838162481785, 36.33629500865936, 36.0572075843811, 41.0199236869812, 47.500882521271706, 47.46489465236664, 48.369333520531654, 48.701519295573235, 51.17381103336811, 45.173062831163406, 40.93394570052624, 34.279134795069695, 35.11803478002548, 37.652399986982346, 43.19127157330513, 46.84408396482468, 49.07379291951656, 45.34438043832779, 44.207606837153435, 45.366088673472404, 46.484729647636414, 43.572812899947166, 43.31513352692127, 45.03149762749672, 45.34742407500744, 45.82733832299709, 44.75305996835232, 41.74308568239212, 45.33945590257645, 46.910857781767845, 36.99960261583328, 17.20691118389368, 4.293447565287352, 1.3606562814675272, 2.929615010507405, 2.6471780659630895, 3.114225729368627, 2.966392287053168, 4.730616481974721, 4.259114982560277, 3.19767780136317, 3.878286830149591, 0.5211247585248202, 0.2246424465556629, 0.16988457937259227, 21.68585814535618, 42.72296190261841, 25.114756152033806, 31.595230512320995, 5.559499729424715, 0.10212741675786674, 0.023756327100272756, 0.02710088054300286, 0.048770698413136415, 0.016458859499834944, 0.07517406775150448, 0.018946321433759294, 0.01680218629189767, 0.13086499267956242, 0.03405786192161031, 0.050096593477064744, 0.04178169336228166, 0.018129274358216207, 0.06872051482787356, 0.02541492140153423, 0.011050892462662887, 0.048503785001230426, 0.011552329178812215, 0.011869105637742905, 0.007052133987599518, 0.06025073962518945, 0.04387113222037442, 0.01622063195100054, 0.031945145601639524, 0.10201427634456195, 0.07409326324705034, 0.04057623402331956, 0.02408289805316599, 0.025918268220266327, 0.05125103016325738, 0.03567945088434499, 0.036217292727087624, 0.04924400680465624, 0.007184934820543276, 0.017987498176808003, 0.03970455189119093, 0.07651739957509562, 0.01614806846191641, 0.0344345278426772, 0.008997661134344526, 0.028537914076878224, 0.0688266716315411, 0.016063775328802876, 0.031334877567132935, 0.024271162365039345, 0.022614111730945297, 0.03314287547254935, 0.06540640242747031, 0.15385841979878023, 0.2488011642708443, 8.351524360477924, 31.74542885273695, 33.92826922237873, 47.05353632569313, 21.025066003203392, 0.2991731761721894, 0.06515829503769055, 0.07471806253306568, 0.33868571219500154, 3.0933541618287563, 8.669152166694403, 6.3588713854551315, 6.0811438132077456, 12.458493132144213, 9.755097795277834, 9.331290386617184, 1.078137878794223, 1.7357468605041504, 17.51292396336794, 42.306530848145485, 53.921029418706894, 56.7260617017746, 55.84917135536671, 54.337373077869415, 54.44361537694931, 55.11940911412239, 54.32231068611145, 53.729246109724045, 54.899416118860245, 54.955789893865585, 53.96629258990288, 52.43696965277195, 50.64151279628277, 47.34336197376251, 44.179986119270325, 43.9817051589489, 41.005005687475204, 41.27926357090473, 40.1240723580122, 40.26126779615879, 41.48254506289959, 50.57151295244694, 54.958928525447845, 53.401699885725975, 54.05466824769974, 54.211094453930855, 51.65348969399929, 45.881398022174835, 41.01729042828083, 40.02250000834465, 39.46519151329994, 39.97893534600735, 38.266238048672676, 48.18107642233372, 52.62688726186752, 52.28534638881683, 48.99226829409599, 49.63845022022724, 49.590192809700966, 47.03648664057255, 48.68022903800011, 45.961463525891304, 50.4221011698246, 52.64799512922764, 50.089140236377716, 47.66077034175396, 45.51063671708107, 43.78585986793041, 40.87692975997925, 39.68518450856209, 36.77832908928394, 37.55566857755184, 34.649265334010124, 36.91251888871193, 38.96355003118515, 36.90041273832321, 35.37517458200455, 37.59710915386677, 37.26388223469257, 42.12244592607021, 49.454806074500084, 48.83357360959053, 48.020702227950096, 49.35589358210564, 50.39519101381302, 46.929833963513374, 41.78553320467472, 35.720572248101234, 37.1321889013052, 40.17699211835861, 45.3459345549345, 48.014801144599915, 50.152680426836014, 47.41936169564724, 45.585827082395554, 45.76934203505516, 48.09742771089077, 46.58714175224304, 45.03634616732597, 45.898968279361725, 47.13069498538971, 46.223907843232155, 47.939888164401054, 44.29029040038586, 46.44192494452, 49.45922143757343, 37.92175233364105, 19.447449557483196, 5.3285823203623295, 1.9223093683831394, 3.660159297287464, 4.028093554079533, 6.139677297323942, 6.322632730007172, 6.150301527231932, 6.190578415989876, 4.862698344513774, 2.5602213945239782, 0.6395198742393404, 0.19715951581019908, 0.1434018707368523, 22.74640403687954, 46.765910759568214, 27.80699908733368, 38.84550556540489, 7.9200617875903845, 0.11408162725274451, 0.02143002438970143, 0.020974614744773135, 0.06119949379353784, 0.03205838620488066, 0.04177185248408932, 0.013925625607953407, 0.033424553912482224, 0.03733767596713733, 0.057388895729673095, 0.06751606109901331, 0.0502160050382372, 0.030247286122175865, 0.00829118942419882, 0.023638524144189432, 0.03395395753614139, 0.04352000731159933, 0.04240695277985651, 0.017445910343667492, 0.08130652306135744, 0.04273729384294711, 0.05097315523016732, 0.0694911609753035, 0.11129412057925947, 0.1664515378070064, 0.12798691430361941, 0.09824662265600637, 0.2646341873332858, 0.15716122929006815, 0.15354901843238622, 0.05857138930878136, 0.21996779192704707, 0.1204151674755849, 0.12688469141721725, 0.08192595661967061, 0.199299335363321, 0.12979512743186206, 0.10053303863969631, 0.14252846682211384, 0.11430533282691613, 0.1275094907032326, 0.2249377768021077, 0.14931404177332297, 0.13112893007928506, 0.09801389256608672, 0.1928180261165835, 0.13787337520625442, 0.1097473363915924, 0.2558375406078994, 0.30774432874750346, 10.479841455817223, 41.90321668982506, 39.26941841840744, 50.6110118329525, 23.457646071910858, 0.7556393276900053, 0.27566404547542334, 0.34357020165771246, 1.5875808172859251, 10.313066504895687, 18.604861870408058, 11.449138093739748, 11.697856597602367, 20.859831869602203, 21.400653049349785, 8.420308269560337, 2.177959056571126, 2.0337525196373463, 17.843314334750175, 43.79393823444843, 54.980366975069046, 59.634437039494514, 57.77676232159138, 56.02121092379093, 57.116171568632126, 57.260035648941994, 57.44584187865257, 57.47649863362312, 57.77501821517944, 57.16396540403366, 56.19811803102493, 54.65194299817085, 53.75958368182182, 48.255043253302574, 44.75427970290184, 43.91119234263897, 43.20412628352642, 44.53920744359493, 42.43179112672806, 42.714674547314644, 42.88233295083046, 52.72414684295654, 58.261969685554504, 55.93055158853531, 56.159523501992226, 56.51845224201679, 54.035912454128265, 48.0664099752903, 44.18285496532917, 41.720066517591476, 40.199186727404594, 42.35977739095688, 40.97848691046238, 50.75466692447662, 55.12990415096283, 52.90159732103348, 50.80172739923, 49.35871683061123, 50.524843856692314, 47.28895269334316, 48.84140878915787, 48.958689495921135, 52.76918962597847, 54.90030527114868, 55.04460632801056, 49.78680185973644, 46.734319254755974, 46.97827756404877, 42.04705037176609, 41.41370415687561, 39.15924713015556, 40.01941077411175, 36.8556397408247, 39.41065303981304, 40.0248558819294, 39.25305649638176, 38.38223062455654, 39.364641308784485, 39.76953238248825, 44.21385370194912, 51.912833377718925, 50.61236456036568, 50.08832708001137, 51.66186064481735, 56.36720895767212, 49.12266209721565, 45.132329016923904, 37.5687550753355, 39.018495082855225, 42.24949970841408, 44.8861326277256, 50.85881553590298, 52.35035330057144, 49.53023202717304, 45.47720991075039, 47.18835689127445, 49.10468526184559, 47.77012847363949, 47.35553652048111, 48.36931832134724, 49.91483598947525, 48.10849651694298, 49.40901853144169, 45.45420214533806, 48.05906876921654, 50.87275318801403, 39.41553197801113, 18.706280328333378, 6.184728154912591, 3.2729918975383043, 8.19601010531187, 6.466972259804606, 9.687222987413406, 9.328190702944994, 12.55256088450551, 13.752812929451466, 10.796686504036188, 7.98366229981184, 1.5158197679556906, 0.480056413798593, 0.2992299653124064, 27.112508453428745, 51.74103319644928, 33.52302096784115, 44.45284187793732, 9.964514058083296, 0.16925109695876017, 0.21261864487314597, 0.11068844643887132, 0.20000958553282544, 0.22143440932268277, 0.17839833424659446, 0.06909008952789009, 0.1989139083889313, 0.17713185923639685, 0.15392588102258742, 0.1687070878688246, 0.16460488142911345, 0.08713518021977507, 0.14208662178134546, 0.13028803223278373, 0.08952325559221208, 0.12481828511226922, 0.13218114705523476, 0.12729683570796624, 0.18944674608064815, 0.14318796893348917, 0.15077997639309615], [0.021721642042393796, 0.020474110351642594, 0.06386985987774096, 0.03955317231884692, 0.005026557864766801, 0.014778470176679548, 0.06163471516629215, 0.06293129539699294, 0.03257369273342192, 0.00594445306887792, 0.028424202209862415, 0.030804045309196226, 0.0979180441936478, 0.06564665789483115, 0.025268850040447433, 0.03982061636634171, 0.026550130896794144, 0.029048519099887926, 0.014028160730958916, 0.03338246671773959, 0.05853302398463711, 0.017412413508282043, 0.025517660615150817, 0.08906829680199735, 0.013532548946386669, 0.035683143069036305, 0.07097053588950075, 0.10292433493304998, 1.4025808568112552, 24.847210608422756, 33.77476505935192, 32.59569972753525, 33.35581474006176, 3.3710812591016293, 0.11629784348770045, 0.02572636367403902, 0.17401911376509815, 1.6839529084973037, 4.534445833414793, 4.873409494757652, 6.671902863308787, 5.413844045251608, 9.720265064388514, 7.35794180072844, 0.5686341435648501, 0.1774480438325554, 7.724105352535844, 33.54174256324768, 50.60899794101715, 54.374307096004486, 51.807202845811844, 52.026625871658325, 51.45607888698578, 49.83378253877163, 51.276751309633255, 52.44897700846195, 50.32250091433525, 48.261708095669746, 43.87807711958885, 42.960209771990776, 39.34438079595566, 38.837506994605064, 38.72822105884552, 38.01991246640682, 38.045203909277916, 37.563465759158134, 39.78725463151932, 37.45798721909523, 40.21654799580574, 48.54809872806072, 52.85871662199497, 52.88499981164932, 49.952955543994904, 53.3428068459034, 48.12786027789116, 46.28591671586037, 40.56465111672878, 38.32011915743351, 38.18295031785965, 38.19983281195164, 38.648957312107086, 46.40573188662529, 51.68263413012028, 51.16103231906891, 50.625644847750664, 47.5052522867918, 48.67080554366112, 47.03909710049629, 48.745767921209335, 45.267730951309204, 47.053403332829475, 53.258424773812294, 46.8489933013916, 47.685051038861275, 42.36473612487316, 38.97211477160454, 38.618471547961235, 36.08551986515522, 34.34086628258228, 35.58161370456219, 35.463462844491005, 36.40006698668003, 34.95742119848728, 35.22269256412983, 35.43719485402107, 35.88270954787731, 35.24154335260391, 38.20297524333, 45.773385018110275, 48.94637815654278, 48.35872828960419, 48.910770267248154, 50.411127358675, 48.12740430235863, 44.866430684924126, 38.582840859889984, 33.03146034479141, 33.21048393845558, 40.16178913414478, 44.141467586159706, 45.95025412738323, 46.856345906853676, 46.72240309417248, 48.5376188904047, 47.93820485472679, 47.31782354414463, 45.203898176550865, 43.83666694164276, 42.48324416577816, 41.46321929991245, 41.25713735818863, 42.90707342326641, 45.90044640004635, 45.481940656900406, 32.952895760536194, 11.889164932072163, 2.86124290432781, 1.069877715781331, 2.4704580986872315, 2.9684567637741566, 2.527390206232667, 5.134742371737957, 4.684171574190259, 2.763404091820121, 3.831563349813223, 1.185677689500153, 0.18554150563431904, 0.060794874880230054, 3.5011558793485165, 32.084117978811264, 31.898551136255264, 35.19310735166073, 18.394434861838818, 1.192191846203059, 0.06511421146569774, 0.07714326755376533, 0.01534898414320196, 0.019716186470759567, 0.054219717349042185, 0.034566459435154684, 0.033636040025157854, 0.01311587755481014, 0.037198838690528646, 0.08125624255626462, 0.03563374943041708, 0.06803143071010709, 0.05749877811467741, 0.066486331197666, 0.10527404127060436, 0.013673772227775771, 0.0714422449527774, 0.01584363948495593, 0.03618513175752014, 0.0380646281701047, 0.035649772398755886, 0.008938947976275813, 0.08169059932697564, 0.009782390461623436, 0.06531578619615175, 0.03313404391519725, 0.023890039847174194, 0.014693499833811074, 0.053182974152150564, 0.07053064269712195, 0.03988809614384081, 0.01597284554009093, 0.02607468511996558, 0.04242236718710046, 0.06675679207546636, 0.027343830006429926, 0.05504382410435937, 0.027986118002445437, 0.025687072520668153, 0.07594275462906808, 0.08175183393177576, 0.06294569306191988, 0.04982026221114211, 0.07383210147963837, 0.030508069394272752, 0.05952101178991143, 0.013975015535834245, 0.022093099942139816, 0.030635715083917603, 0.09891426612739451, 2.75852182880044, 32.467908784747124, 37.73481756448746, 36.84302821755409, 37.19926290214062, 3.188855624757707, 0.09171017925837077, 0.0418458223430207, 0.2936733275419101, 1.7120380327105522, 6.677252501249313, 9.036555401980877, 7.9405521880835295, 8.438090365380049, 7.732054051011801, 11.423896048218012, 1.8143805535510182, 0.2835344919003546, 8.438715431839228, 34.57279823720455, 52.51098968088627, 56.611091271042824, 53.91954369843006, 53.72040398418903, 53.253067061305046, 52.052840664982796, 53.21460172533989, 52.73171603679657, 53.05556885898113, 50.98740063607693, 47.040419429540634, 45.37875719368458, 43.04393447935581, 41.24137580394745, 40.936841145157814, 38.3776518702507, 39.65085715055466, 40.75015716254711, 41.37995056807995, 38.572741001844406, 41.37067526578903, 52.01356217265129, 55.41076608002186, 54.32270586490631, 52.61874049901962, 54.42007564008236, 50.95652349293232, 47.44895450770855, 43.118497878313065, 40.60961790382862, 40.31853072345257, 39.07268397510052, 40.35537734627724, 48.89210946857929, 54.35188449919224, 52.18111418187618, 51.70341521501541, 50.55056467652321, 49.186179488897324, 48.028051033616066, 48.21902498602867, 46.024087965488434, 49.23748433589935, 54.84906122088432, 49.65570889413357, 50.3542710095644, 44.50112968683243, 40.28524070978165, 40.245646834373474, 37.189117446541786, 35.86566746234894, 37.74924539029598, 37.87852965295315, 37.9721300303936, 37.661059722304344, 36.483696699142456, 38.083456456661224, 37.534112334251404, 37.078539580106735, 40.33189080655575, 48.96535813808441, 49.753762632608414, 49.079788997769356, 48.73018495738506, 50.80700911581516, 50.99133722484112, 46.76252134144306, 39.012973979115486, 34.45068798959255, 36.16335108876228, 41.93907156586647, 47.2086326032877, 47.61771485209465, 48.562712743878365, 46.74791492521763, 50.23031026124954, 49.746972396969795, 48.869337290525436, 46.66713885962963, 44.72290858626366, 42.89105348289013, 43.39454546570778, 44.02392089366913, 44.14339028298855, 46.68272562325001, 47.27608658373356, 33.64549979567528, 12.61660834774375, 2.2680738335475326, 3.072857824154198, 2.3329693637788296, 5.375577248632908, 6.6901385597884655, 7.761678686365485, 8.458311930298805, 4.776486195623875, 2.7371750492602587, 0.8352615020703524, 0.1391464108019136, 0.01770122027664911, 2.958673951216042, 37.59517885744572, 38.771496936678886, 36.73819184303284, 25.28746258467436, 2.1401266241446137, 0.028489466676546726, 0.07458170774043538, 0.03764369685086422, 0.030101817756076343, 0.0475435089902021, 0.026327204577683005, 0.05173368219402619, 0.11634265436441638, 0.06690735157462768, 0.056940456706797704, 0.03634838940342888, 0.03407460106245708, 0.05528658060939051, 0.028881038633699063, 0.04477861926716287, 0.0571010240673786, 0.04090730239113327, 0.06469299070886336, 0.003716959899975336, 0.05701231515558902, 0.022918921058590058, 0.040017085120780393, 0.15838390274439007, 0.10628062358591706, 0.14356226369272918, 0.09648253020714037, 0.15378009353298694, 0.13534897472709417, 0.16711424599634483, 0.11513144709169865, 0.11072501205489971, 0.10762860867544077, 0.15792289545061067, 0.09690821869298816, 0.19876837322954088, 0.16554653324419633, 0.16440824198070914, 0.15075906267156824, 0.14976094826124609, 0.08659794693812728, 0.2329216679208912, 0.08498895593220368, 0.20777926314622164, 0.10823183372849599, 0.07488165414542891, 0.23250751983141527, 0.07054720001178794, 0.10399771053926088, 0.14891295548295602, 0.1431880283053033, 3.7479497864842415, 41.24694250524044, 44.447009190917015, 42.59872376918793, 39.923640713095665, 5.604025740176439, 0.20739073399454355, 0.39905437908601016, 1.1233242228627205, 5.702301291748881, 13.747214879840612, 18.052154928445816, 13.87393618002534, 10.723926108330488, 19.260594584047794, 17.770170159637928, 1.9930963637307286, 0.5512213998008519, 9.968274906277657, 36.227373853325844, 55.35521686077118, 59.572070986032486, 54.8881421238184, 57.69982784986496, 54.97139185667038, 54.17141318321228, 55.85217699408531, 57.587566673755646, 54.42930534482002, 53.65809492766857, 47.73733243346214, 48.119899705052376, 42.2298813611269, 41.87738947570324, 42.61975944042206, 41.60162307322025, 40.64517259597778, 42.068587616086006, 43.38248111307621, 40.805683583021164, 43.452055379748344, 53.32868680357933, 56.89022809267044, 56.217250004410744, 52.50805243849754, 56.31859816610813, 52.61296860873699, 51.49078622460365, 43.572125136852264, 42.45580203831196, 42.06030026078224, 42.1310942620039, 42.94806942343712, 50.63667565584183, 56.307422965765, 52.948448807001114, 51.438102051615715, 52.00112544000149, 48.954616114497185, 48.649287298321724, 48.051830157637596, 47.52345331013203, 52.20284901559353, 57.85178169608116, 51.197669953107834, 51.744012236595154, 46.27031855285168, 41.498139426112175, 42.74342380464077, 39.876648634672165, 37.18109227716923, 39.784302189946175, 39.544599652290344, 39.65228587388992, 39.858588203787804, 37.211737632751465, 40.25188609957695, 37.98398919403553, 39.05123792588711, 41.63381114602089, 51.124926656484604, 52.2140584141016, 51.104210168123245, 49.65192049741745, 51.616259291768074, 53.36017191410065, 49.98115383088589, 41.88826069235802, 36.30633741617203, 36.43499091267586, 44.57101933658123, 47.774395644664764, 49.146597012877464, 50.21416112780571, 48.355426266789436, 49.942555502057076, 49.901342913508415, 50.76192453503609, 48.565045818686485, 46.91081218421459, 46.86669275164604, 45.64604625105858, 45.223364531993866, 45.3677985817194, 49.73096385598183, 49.19446684420109, 34.100608974695206, 12.923591025173664, 4.337306711822748, 3.5306104738265276, 6.739979535341263, 6.909898342564702, 8.276442289352417, 15.47684596851468, 13.432884346693754, 7.665589917451143, 10.169786643236876, 3.699319758452475, 0.86046002805233, 0.10788270519697107, 4.859404396265745, 41.12756811082363, 42.67239801585674, 44.36370626091957, 31.56415767967701, 2.6900782389566302, 0.1974807766964659, 0.1543020163080655, 0.12182942635263316, 0.09658414506702684, 0.11453103477833793, 0.09513401819276623, 0.19804639712674543, 0.23858217668021098, 0.2294015872757882, 0.1546457048971206, 0.17765725526260212, 0.14438281184993684, 0.10236367947072722, 0.16102774447062984, 0.19449679384706542, 0.09390547435032204, 0.10581641021417454, 0.11748041128157638, 0.1428713242057711, 0.1445718071772717, 0.10607315620291047, 0.10035112340119667], [0.06528507612529211, 0.014115932681306731, 0.016645079194859136, 0.06334292018436827, 0.04090273447218351, 0.0449186625337461, 0.06025532980856951, 0.006381697257893393, 0.014876702698529698, 0.014226241801225115, 0.0200021675118478, 0.02578616407845402, 0.025541066097503062, 0.020966376905562356, 0.026561020058579743, 0.0700455230253283, 0.05678580797393806, 0.05727194438804872, 0.040402693921350874, 0.04170559725025669, 0.006913827810421935, 0.03441649365413468, 0.05109748351969756, 0.016717625985620543, 0.0690388071234338, 0.08268273202702403, 0.04895602753094863, 0.017303685162914917, 0.2882186905480921, 10.937478449195623, 34.47507508099079, 25.03973487764597, 39.37240809202194, 16.86073075979948, 0.8185478020459414, 0.10655883248546161, 0.07452315228874795, 0.7763831864576787, 5.718883601948619, 5.9392608515918255, 4.401479568332434, 13.329364601522684, 3.813559440895915, 11.508489958941936, 1.7602516268379986, 0.18291464424692094, 1.5951118944212794, 23.04199207574129, 48.19305717945099, 55.31838923692703, 53.13499979674816, 51.21340490877628, 49.91431921720505, 49.28724266588688, 46.46283142268658, 45.2713293582201, 43.63275468349457, 41.04776859283447, 40.464967265725136, 40.32239891588688, 41.41371175646782, 40.378768891096115, 43.86591777205467, 44.16813835501671, 44.85790014266968, 40.62405712902546, 38.981929644942284, 38.68116058409214, 39.64592881500721, 48.918350860476494, 51.66602522134781, 54.70545172691345, 50.93939781188965, 53.34369599819183, 50.28319202363491, 45.23998484015465, 41.53038449585438, 39.39621761441231, 38.362870663404465, 38.09062287211418, 36.85734964907169, 44.28397133946419, 49.816516265273094, 50.913532599806786, 52.24740922451019, 48.65127079188824, 48.87185275554657, 48.22131626307964, 47.91119210422039, 44.09580923616886, 47.40591041743755, 54.6436670422554, 50.017278492450714, 48.940081894397736, 43.86434085667133, 44.55664470791817, 40.652984976768494, 37.2977764159441, 37.11021088063717, 35.590170845389366, 36.1828326433897, 36.253486052155495, 34.14455361664295, 35.36179170012474, 34.36561435461044, 36.224493607878685, 34.77785803377628, 38.964393585920334, 43.58592599630356, 48.88399690389633, 48.727392107248306, 46.188706532120705, 48.73712718486786, 50.58508202433586, 48.010119795799255, 42.77571067214012, 37.508258521556854, 34.04262028634548, 34.013802632689476, 38.433178290724754, 43.368953838944435, 47.12955504655838, 46.35278932750225, 45.6266824901104, 47.294014021754265, 45.23914888501167, 46.08238443732262, 46.38115480542183, 44.08881761133671, 45.24937033653259, 42.04189784824848, 45.62683828175068, 46.55841149389744, 42.73716554045677, 25.064408853650093, 5.23546451702714, 0.4741462168749422, 2.194876936264336, 0.9289140079636127, 4.718806715682149, 6.0200245678424835, 3.604565905407071, 5.36546646617353, 4.393584541976452, 2.1270745620131493, 0.4893534164875746, 0.084658633422805, 0.15044314524857327, 15.663877632468939, 34.03562866151333, 19.74498689174652, 32.11311802268028, 9.39422545954585, 0.06138258162536658, 0.0349632375582587, 0.040925358844106086, 0.007294355682461173, 0.026613478767103516, 0.037932366321911104, 0.007849692265153863, 0.07323131809243932, 0.0498924583371263, 0.046170958812581375, 0.041891030268743634, 0.025033257115865126, 0.04453271976672113, 0.034305167791899294, 0.01603968150448054, 0.04315090016461909, 0.017358398145006504, 0.06174709116749, 0.026912284120044205, 0.05234901909716427, 0.03344453623867594, 0.062167766445782036, 0.04501586161495652, 0.11367974686436355, 0.01846014605689561, 0.016569725230510812, 0.06350808514980599, 0.012957673006894765, 0.01995574617467355, 0.060797342521254905, 0.05352845502784476, 0.01346303011814598, 0.030510243886965327, 0.03517051569360774, 0.05940352981269825, 0.03130446064460557, 0.05202436288527679, 0.036222320777596906, 0.029479478689609095, 0.041534446863806807, 0.0545563629566459, 0.00486464304231049, 0.04224015137879178, 0.07131180507712997, 0.0571029499405995, 0.029512238943425473, 0.03606914891861379, 0.040212370149674825, 0.1266032541752793, 0.05915282490605023, 0.047907870102790184, 0.5107525619678199, 17.92796239256859, 42.22711890935898, 28.286812640726566, 42.953810915350914, 16.558605171740055, 0.7433167076669633, 0.1215018423681613, 0.13518641470000148, 0.3311700717313215, 1.7471321183256805, 5.7730900682508945, 5.652706352993846, 7.857775529846549, 6.616502311080694, 10.1292684674263, 4.756251806393266, 1.0739053809083998, 2.2899247985333204, 24.34546273201704, 49.464043378829956, 57.50092372298241, 54.63436134159565, 54.34466488659382, 52.37744204699993, 51.04016840457916, 47.67134137451649, 47.35639147460461, 47.13813118636608, 42.5250419229269, 42.353230342268944, 41.49124659597874, 42.08100914955139, 41.130117774009705, 45.14065816998482, 45.266154035925865, 44.9416970461607, 41.302358731627464, 41.63223423063755, 40.5611515045166, 42.95232139527798, 50.44433757662773, 53.00724685192108, 56.098912954330444, 52.75853119790554, 54.56707455217838, 51.98602885007858, 48.07414636015892, 43.30835849046707, 40.654470697045326, 39.59921792149544, 38.72262015938759, 37.811649441719055, 46.501083970069885, 51.9359627366066, 52.93434016406536, 53.413293063640594, 50.14437027275562, 50.25629326701164, 48.267160803079605, 48.17558951675892, 44.946332797408104, 48.53439286351204, 53.85584011673927, 50.58858923614025, 48.6333167552948, 45.83983205258846, 45.59516318142414, 43.37626464664936, 39.13514122366905, 37.09553226828575, 38.154957219958305, 38.11542794108391, 37.995852157473564, 35.402168333530426, 37.046176716685295, 36.47087238729, 37.64941714704037, 36.718725487589836, 39.388496428728104, 44.70227189362049, 50.578276589512825, 49.313145875930786, 48.01788277924061, 50.855950489640236, 51.24123461544514, 49.5428853482008, 44.7401824593544, 37.751304879784584, 35.84847338497639, 36.34974628686905, 40.600935369729996, 45.33110775053501, 49.952381774783134, 47.97542005777359, 47.14813984930515, 47.98685364425182, 47.071307972073555, 47.45519757270813, 46.450550481677055, 46.60223834216595, 45.05418241024017, 42.7239840477705, 47.36576557159424, 47.74779327213764, 43.23897421360016, 25.764374993741512, 7.095022508874536, 1.423203181475401, 2.8867649473249912, 3.359587350860238, 5.4595370683819056, 8.012960627675056, 6.751995915547013, 7.328919908031821, 3.355902498587966, 0.816602484555915, 0.5899571150075644, 0.1361422860645689, 0.012875691663793987, 15.806165747344494, 41.95815034210682, 24.45494245737791, 38.08893956243992, 14.062601756304502, 0.23729640583042055, 0.07116326421964914, 0.01758316870109411, 0.048033678976935335, 0.04830787656828761, 0.04275891631550621, 0.01442356680854573, 0.058808364483411424, 0.05913895045523532, 0.06698756289551966, 0.037597965711029246, 0.03427297342568636, 0.07866250321967527, 0.02119602151651634, 0.03664397569082212, 0.07958306319778785, 0.06310300610493869, 0.03668997400382068, 0.017087985506805126, 0.005974125524517149, 0.04119223514862824, 0.06822755807661451, 0.05236586956016254, 0.3308695019222796, 0.07102158822817728, 0.1230565452715382, 0.1513844556757249, 0.12708633294096217, 0.1530333296977915, 0.12280248585739173, 0.18602112599182874, 0.13583111838670447, 0.12154928044765256, 0.10670334348105825, 0.12112572934711352, 0.1150760828750208, 0.11309646331937984, 0.21146856830455363, 0.10431212140247226, 0.13510802906239405, 0.19173824577592313, 0.12793189147487283, 0.09565962202032097, 0.12027668271912262, 0.14158265898004174, 0.15831574390176684, 0.09433882922166958, 0.12336427680565976, 0.2617952646687627, 0.18456230114679784, 0.21423289028462023, 0.6950966420117766, 22.803148292005062, 52.44127482175827, 34.967695847153664, 48.362448289990425, 22.46988147497177, 1.7889628862030804, 0.39974653569515795, 0.47316907555796206, 2.984699229709804, 13.796740472316742, 14.309693947434425, 14.190984517335892, 23.426307253539562, 10.650513097643852, 22.539140358567238, 7.049570772796869, 1.21579653583467, 1.9762960402294993, 24.815780594944954, 52.61413514614105, 60.8529594540596, 57.96008348464966, 55.57576082646847, 53.603807240724564, 53.273380771279335, 48.78817364573479, 48.90853978693485, 48.48780356347561, 44.40971799194813, 44.71435524523258, 43.29258933663368, 45.862893015146255, 43.54424223303795, 47.19080775976181, 49.01832729578018, 48.153368309140205, 44.197009205818176, 44.012848287820816, 42.20488630235195, 44.16345700621605, 52.72652551531792, 55.569190979003906, 57.66293182969093, 54.787253737449646, 55.25425247848034, 54.28364396095276, 49.784909561276436, 45.76326996088028, 43.14057469367981, 41.17661967873573, 40.53616784512997, 39.462569653987885, 48.09302754700184, 52.82665394246578, 54.411385506391525, 55.805093720555305, 50.84807351231575, 50.767255648970604, 49.091682359576225, 47.77160279452801, 46.85803681612015, 51.04978568851948, 57.692019268870354, 53.467565551400185, 50.97591385245323, 48.8801971077919, 48.90622951090336, 44.88984502851963, 41.16075932979584, 40.11065147817135, 38.8669478148222, 40.148721635341644, 39.03891138732433, 37.97896966338158, 38.661587834358215, 37.12263621389866, 39.07339833676815, 37.94747695326805, 41.44990101456642, 48.239498287439346, 52.98572480678558, 53.05573605000973, 48.65611173212528, 53.06911513209343, 51.58663608133793, 52.751562371850014, 47.60871313512325, 41.599799171090126, 37.35104575753212, 36.951626390218735, 41.959723457694054, 47.159212455153465, 51.31775110960007, 51.31320655345917, 48.5803247988224, 47.90810666978359, 47.625489234924316, 49.8912962526083, 49.79081064462662, 49.20906186103821, 48.91749210655689, 45.17782397568226, 49.12890136241913, 50.26167757809162, 44.00461032986641, 26.991372853517532, 6.400261614471674, 1.7696195491589606, 4.58944265730679, 4.333496941253543, 10.325364544987679, 13.624718952924013, 14.789553098380566, 12.67898105084896, 8.743761163204908, 5.085338372737169, 1.789034844841808, 0.3622771619120613, 0.2547766256611794, 21.09235279262066, 43.20924460887909, 27.63238325715065, 45.799634009599686, 16.81745868176222, 0.43780176085419953, 0.15010681876447052, 0.10157413824344985, 0.07757752042380162, 0.1735416753217578, 0.1735473601729609, 0.12327449177973904, 0.11340594632201828, 0.22904382756678388, 0.16197960823774338, 0.06477536910097115, 0.14641338726505637, 0.2272924777935259, 0.2114407971384935, 0.0774478301173076, 0.15259397827321663, 0.20879735617199913, 0.13347436906769872, 0.10787086794152856, 0.13511285302229226, 0.10282052331604064, 0.18728009046753868, 0.19587776740081608], [0.08170219167368487, 0.04594860023644287, 0.017755267181200907, 0.08010460747755133, 0.013917384985688841, 0.08404230946325697, 0.04551022102532443, 0.040895487400121056, 0.03474066747003235, 0.06469342857599258, 0.09679412833065726, 0.02781590272206813, 0.03304031437437516, 0.002782625197141897, 0.07543228319264017, 0.030935143840906676, 0.026043088182632346, 0.0338654490042245, 0.04564655355352443, 0.04434867456438951, 0.021689796485588886, 0.02084187977743568, 0.045844643900636584, 0.034556455284473486, 0.04870262862823438, 0.016478062570968177, 0.07883733094786294, 0.03286910832684953, 0.16750189941376448, 2.5070441979914904, 29.61319226771593, 25.030788257718086, 30.76440889388323, 29.352191872894764, 4.956266898661852, 0.29813621775247157, 0.11222323009860702, 0.3696772054536268, 1.5561576909385622, 4.184824218973517, 4.374728053808212, 4.990233276039362, 6.423632260411978, 6.659065252169967, 2.4447567528113723, 0.7523037598002702, 0.07549008907517418, 11.61560146138072, 42.103925719857216, 54.821467101573944, 54.72554124891758, 52.360654547810555, 52.37863138318062, 48.33154074847698, 44.09659959375858, 44.549318701028824, 44.072470888495445, 42.17763036489487, 43.676133155822754, 45.28348110616207, 47.08943299949169, 48.13310019671917, 49.90433715283871, 52.42983743548393, 52.827102318406105, 49.627476409077644, 43.52057330310345, 39.28366385400295, 41.400271877646446, 48.570859506726265, 53.339941799640656, 53.13205115497112, 51.497014090418816, 52.891269475221634, 52.73900404572487, 46.64094306528568, 43.82279008626938, 38.93610790371895, 37.868270203471184, 37.693183198571205, 38.15724469721317, 40.559722781181335, 52.04638481140137, 51.98987044394016, 51.015260741114616, 49.70283016562462, 49.602352157235146, 47.97102369368076, 48.97105783224106, 46.51008188724518, 45.58333821594715, 52.54820108413696, 49.29924242198467, 47.89875537157059, 47.11609996855259, 42.44423545897007, 42.607280910015106, 37.2617619484663, 36.167614459991455, 37.50374436378479, 35.975204184651375, 34.381641894578934, 36.23226419091225, 35.432540103793144, 34.31414231657982, 35.98557002842426, 35.01767076551914, 35.691948384046555, 39.792072772979736, 44.866328090429306, 49.81847696006298, 48.864731937646866, 44.794200360774994, 49.11985404789448, 47.075278759002686, 45.933998599648476, 42.7112091332674, 39.69888277351856, 34.3123260140419, 34.22043174505234, 36.59129932522774, 43.87556545436382, 47.0129469037056, 46.49184286594391, 44.30965036153793, 47.20138259232044, 44.122601598501205, 49.84839655458927, 45.3098326921463, 45.91341130435467, 45.09146220982075, 45.99191129207611, 45.30268907546997, 35.009159222245216, 17.21749171614647, 2.3563138861209154, 0.5815990478731692, 2.6660925010219216, 2.1817161049693823, 3.7437336752191186, 8.07658726349473, 5.465966798365116, 6.547287600114942, 2.838193103671074, 0.4233451694017276, 0.13739038549829274, 0.04809654630662408, 2.0833875937387347, 32.01492369174957, 26.461403891444206, 26.529234051704407, 26.732498444616795, 2.0993206137791276, 0.06976308388402686, 0.045120044305804186, 0.046456693089567125, 0.03811994414718356, 0.04184251978585962, 0.05020505836000666, 0.041014902672031894, 0.04640500250388868, 0.04745730111608282, 0.01086363561626058, 0.05409335186413955, 0.025303610382252373, 0.04698515789641533, 0.0035538738757168176, 0.047243918816093355, 0.03276821706094779, 0.020760685110872146, 0.04265311574272346, 0.06915214049513452, 0.04388883986393921, 0.0029252664444356924, 0.05127813339640852, 0.026547839515842497, 0.08591655147029087, 0.035835977250826545, 0.029635789833264425, 0.032439475326100364, 0.028796719525416847, 0.10376481717685238, 0.052260428929002956, 0.04050321782415267, 0.02778825772111304, 0.028447475961002056, 0.10300437555997632, 0.06328772666165605, 0.039746409020153806, 0.033592479667277075, 0.09741936548380181, 0.04364518536021933, 0.03648601326858625, 0.038215187669266015, 0.0219756049773423, 0.07079380826326087, 0.04771105996042024, 0.04350389899627771, 0.04371860602986999, 0.05625259342195932, 0.029814627014275175, 0.06450188768212683, 0.08048976727877744, 0.05190917414438445, 0.1558272633701563, 5.165167339146137, 39.48626138269901, 27.999232672154903, 37.244640067219734, 33.85394521057606, 4.7739023342728615, 0.33147592563182116, 0.06523971605929546, 0.26078992174007, 0.25834386236965656, 3.5228064050897956, 6.492317374795675, 5.86497388780117, 7.34699078835547, 10.725930500775576, 5.9891607239842415, 1.4783081808127463, 0.3138357581337914, 12.92476611211896, 43.75785157084465, 55.932873263955116, 56.06762543320656, 54.20989751815796, 53.18986885249615, 51.00203365087509, 46.338300704956055, 44.859321266412735, 44.57009598612785, 44.45463538169861, 44.095015078783035, 46.35494761168957, 47.861521169543266, 49.459350630640984, 52.028100192546844, 53.291741386055946, 54.229059889912605, 50.57247430086136, 42.94971473515034, 39.759314730763435, 43.307032361626625, 50.709726735949516, 55.367475003004074, 54.095725044608116, 53.89922238886356, 54.29437458515167, 53.5452713817358, 48.71141396462917, 45.44167801737785, 39.801196083426476, 38.52541834115982, 41.23908072710037, 39.77142088115215, 42.88525879383087, 53.66584651172161, 53.17088507115841, 53.01031328737736, 51.8684783577919, 50.83827383816242, 48.63401971757412, 49.737317115068436, 47.269832119345665, 47.62887105345726, 54.19700860977173, 50.374778509140015, 49.36510808765888, 48.29453073441982, 44.273704290390015, 43.406188040971756, 39.32744890451431, 38.614569157361984, 39.457629919052124, 37.63807475566864, 37.35729642212391, 37.87162162363529, 37.01002165675163, 37.16293305158615, 38.41636799275875, 37.4856611341238, 37.13850416243076, 41.346348971128464, 47.35450677573681, 50.96881203353405, 47.88576386868954, 46.8840654194355, 50.81948384642601, 48.372532948851585, 47.498788833618164, 44.21431727707386, 39.767168909311295, 35.81847779452801, 37.09569565951824, 39.492223262786865, 46.18650645017624, 49.724633395671844, 47.45325207710266, 46.13598056137562, 48.64247806370258, 46.36918544769287, 49.68079134821892, 47.37826310098171, 47.95325204730034, 46.94817557930946, 48.40047664940357, 46.41022704541683, 37.44343400001526, 18.418213985860348, 4.568303916603327, 1.3960795244202018, 3.2019373727962375, 4.768988722935319, 4.205207275226712, 6.794430138543248, 5.88154099881649, 7.025639181956649, 2.024554875679314, 0.2669813926331699, 0.15002248110249639, 0.06497949681943282, 1.764582444448024, 35.80390177667141, 30.85277885198593, 25.7882035151124, 33.73674049973488, 3.5443161008879542, 0.12105396366678178, 0.044466924664448015, 0.048670148535165936, 0.07193512006779201, 0.025125441134150606, 0.10012491678935476, 0.061835198939661495, 0.055590623669559136, 0.04213859960145783, 0.012295052019908326, 0.03469934097665828, 0.027108003305329476, 0.028090799787605647, 0.03212514609913342, 0.02435563175822608, 0.04299861517210957, 0.03390167323232163, 0.009027821088238852, 0.09621169083402492, 0.02650919403095031, 0.06054789926565718, 0.05417612359451596, 0.06627142749493942, 0.21770710620330647, 0.09168971824692562, 0.10646809008903801, 0.16603188298176974, 0.1134795747930184, 0.24808766349451616, 0.15239968401147053, 0.14503030601190403, 0.12897028966108337, 0.14271811523940414, 0.2747723995707929, 0.10989729475113563, 0.1255517645040527, 0.12612452439498156, 0.2143105783034116, 0.13394867564784363, 0.09089049199246801, 0.16528700420167297, 0.16177958459593356, 0.1097249161102809, 0.11360208111000247, 0.12206634957692586, 0.1306781347375363, 0.2290561472182162, 0.14571054372936487, 0.16008788865292445, 0.28558810357935727, 0.17169856640975922, 0.2716320165200159, 7.028495203703642, 49.24650125205517, 34.157051146030426, 42.99914628267288, 37.06623204052448, 7.589259138330817, 0.7902447832748294, 0.2354357673902996, 0.9712588170077652, 3.7075885897502303, 13.85549196973443, 13.516481760889292, 12.448597513139248, 14.563979152590036, 15.440508518368006, 5.3066997695714235, 2.5603090273216367, 0.5544396489858627, 13.956921827048063, 44.28531266748905, 58.98374855518341, 60.22209070622921, 57.68865644931793, 56.95337310433388, 53.61874043941498, 49.200337529182434, 48.545108288526535, 47.29462958872318, 46.95659972727299, 47.15745694935322, 48.96779000759125, 50.538230538368225, 51.389909237623215, 54.45657268166542, 57.146372348070145, 57.83470921218395, 53.117038160562515, 47.17008747160435, 42.916105538606644, 45.37314109504223, 53.139582350850105, 57.123752161860466, 55.935050547122955, 54.91441771388054, 56.104221269488335, 56.47916994988918, 49.90445114672184, 48.26483152806759, 41.40301913022995, 41.11940994858742, 41.63780093193054, 41.614530980587006, 43.18931847810745, 56.03933975100517, 56.691038981080055, 54.66482810676098, 53.66912193596363, 51.77279569208622, 49.51428048312664, 48.46343167126179, 46.97647266089916, 50.300629287958145, 55.795575231313705, 52.348126620054245, 51.105676889419556, 52.09489680826664, 46.58579662442207, 46.38011746108532, 40.441754311323166, 41.176646277308464, 41.59205138683319, 40.27934342622757, 37.98368141055107, 39.80800911784172, 38.28491024672985, 38.57510827481747, 39.27197948098183, 39.67814348638058, 40.153292790055275, 43.24511468410492, 49.478148221969604, 52.5026149302721, 50.79119436442852, 46.83583080768585, 50.33261597156525, 49.278423339128494, 50.78788474202156, 45.74694603681564, 43.76270391047001, 37.97097489237785, 38.03990699350834, 39.400245398283005, 47.19381719827652, 50.85079796612263, 50.983566641807556, 47.18451909720898, 49.849608689546585, 46.558723077178, 51.19998402893543, 48.11283588409424, 49.88732546567917, 48.98656100034714, 50.33408269286156, 49.107744097709656, 37.80038304626942, 19.02397558093071, 3.796267518773675, 1.2266191863454878, 6.284613395109773, 7.169355545192957, 9.46452358737588, 15.18979512155056, 12.356252018362284, 14.198995437473059, 6.700345762073994, 1.8391592614352703, 0.45407474390231073, 0.19724441750440747, 2.966386112384498, 42.130543291568756, 35.23539528250694, 34.917549937963486, 40.74557840824127, 5.031057335436344, 0.29588270117528737, 0.11557028643437661, 0.19184843986295164, 0.2935962926130742, 0.15042622428154573, 0.21446941274916753, 0.18471217044861987, 0.12133522279327735, 0.172919147007633, 0.1777388618211262, 0.14328937599202618, 0.1684299550834112, 0.11780914559494704, 0.11155549756949767, 0.15765204123454168, 0.10503063167561777, 0.06064042652724311, 0.12085536494851112, 0.17786481912480667, 0.13059868040727451, 0.13460241869324818, 0.11008824934833683, 0.27707136527169496], [0.017601137951714918, 0.041087154459091835, 0.04797673398570623, 0.018058595924230758, 0.11346757426508702, 0.02935727665317245, 0.04662998457206413, 0.02522258826502366, 0.016146513662533835, 0.07271034526638687, 0.032040556106949225, 0.0648946693399921, 0.08238971728133038, 0.03139733300486114, 0.03852982488751877, 0.008572779734095093, 0.06686945009278134, 0.040498252856195904, 0.01046261426381534, 0.04137491479923483, 0.03966747048252728, 0.07118495719623752, 0.05755290294473525, 0.07176501982030459, 0.05649296392221004, 0.03392221959074959, 0.07253896110341884, 0.07254026728332974, 0.08839513917337172, 0.09069595282198861, 15.23102955892682, 33.50064016878605, 20.72930697351694, 37.16685064136982, 14.577833209186792, 2.8443537605926394, 0.4542939446400851, 0.2416001053643413, 0.09467793875955977, 2.0150252245366573, 2.291955314576626, 4.5241388864815235, 4.324797308072448, 8.004779666662216, 6.878551924601197, 0.9387040045112371, 0.31534792855381966, 1.6433379566296935, 29.524577222764492, 54.280999302864075, 56.10460124909878, 53.301533460617065, 53.120176792144775, 49.50848579406738, 50.716619566082954, 48.65644991397858, 49.61657479405403, 49.4615925103426, 49.220275059342384, 50.562214851379395, 52.337012216448784, 53.29240255057812, 53.64669933915138, 54.01422701776028, 52.73941062390804, 52.89015993475914, 46.37792117893696, 38.53396028280258, 42.788071408867836, 49.06588554382324, 54.19063255190849, 54.14732247591019, 51.2969434261322, 54.49406906962395, 52.10571102797985, 49.14495550096035, 44.27104823291302, 38.70443053543568, 38.944475054740906, 38.08550074696541, 38.224330097436905, 39.30797874927521, 48.56644794344902, 51.092263609170914, 51.70062616467476, 48.9686943590641, 47.72342897951603, 47.973888739943504, 48.87700907886028, 44.54824335873127, 46.62666343152523, 57.86646030843258, 50.77811546623707, 50.3056526184082, 46.15144573152065, 47.4023462086916, 43.66351403295994, 41.04713022708893, 36.90285220742226, 35.33967688679695, 35.58531850576401, 36.47136256098747, 35.66874302923679, 36.733062118291855, 34.551192596554756, 35.50920478999615, 36.19248412549496, 37.85351939499378, 37.020493894815445, 40.69407977163792, 45.258744433522224, 51.214453652501106, 48.771629333496094, 47.2837545722723, 48.7977035343647, 47.358697950839996, 46.775094866752625, 43.553376942873, 43.214207142591476, 40.56807093322277, 36.935617849230766, 38.816429525613785, 41.77957132458687, 46.46304041147232, 45.06376929581165, 46.45026549696922, 46.090880781412125, 46.13624654710293, 49.0343776345253, 48.83635126054287, 47.839611545205116, 46.91260188817978, 39.583779349923134, 26.130308657884598, 7.220317460596561, 2.0556792430579662, 1.2417225446552038, 1.481517346110195, 4.829851957038045, 2.2937592677772045, 4.418342113494873, 2.622131472453475, 5.17820586450398, 1.3148808502592146, 0.22977742570219561, 0.2299047337146476, 0.03271506815508474, 10.212800335139036, 37.13363662362099, 25.408814772963524, 30.607686303555965, 13.579837661236525, 0.2967383380746469, 0.05405393640103284, 0.11196523730177432, 0.0775989462272264, 0.027407213128753938, 0.02107931508362526, 0.07160099034081213, 0.045540170394815505, 0.0754099000187125, 0.06194827627041377, 0.05956048291409388, 0.03022416822204832, 0.03121855334029533, 0.03362918629136402, 0.025860185887722764, 0.039509871712652966, 0.015282115709851496, 0.013038314773439197, 0.04232811072142795, 0.05002841237001121, 0.021587799419648945, 0.028409227525116876, 0.06714944014674984, 0.05875266630027909, 0.04197946829663124, 0.0650536893226672, 0.05418065811682027, 0.028232648328412324, 0.030684283083246555, 0.014980451232986525, 0.09216193197062239, 0.005769283488916699, 0.07591398898512125, 0.0530874671676429, 0.07545756074250676, 0.038946871063672006, 0.054587184349657036, 0.039081526338122785, 0.01031406691254233, 0.038482561212731525, 0.01866255570348585, 0.058017617266159505, 0.05186495698580984, 0.03837461583316326, 0.02355691573029617, 0.04609771625837311, 0.051541862994781695, 0.03355685286805965, 0.009178450163744856, 0.04475042507692706, 0.09481280183536, 0.09088671446079388, 0.10097210804815404, 0.439611918409355, 24.27115011960268, 35.40289029479027, 25.69416806101799, 42.24800258874893, 18.069271109998226, 2.6985961943864822, 0.28941797150764614, 0.1712580572348088, 0.08169258828274906, 0.9772428427822888, 3.985741976648569, 6.386547675356269, 9.273787122219801, 8.562841471284628, 7.674325173720717, 3.739679530262947, 0.5857888574246317, 3.069882346317172, 32.4569995701313, 55.515921637415886, 56.767597272992134, 55.69569379091263, 54.16751079261303, 51.20985969901085, 50.96622057259083, 50.03308564424515, 51.082273945212364, 49.94959272444248, 49.178446903824806, 53.25507715344429, 54.64298687875271, 53.8148745149374, 54.18455667793751, 57.059189826250076, 54.21762250363827, 53.311496526002884, 48.11339445412159, 40.4921206086874, 43.479581102728844, 49.89791929721832, 54.409960582852364, 56.00877419114113, 52.594775184988976, 55.99736340343952, 54.828200340270996, 51.46437384188175, 44.82853911817074, 41.03892266750336, 39.889244958758354, 40.56202545762062, 40.10359525680542, 41.52915336191654, 50.20277313888073, 53.16202774643898, 54.102576076984406, 50.93254677951336, 50.106512904167175, 47.95563831925392, 50.08829668164253, 46.00674569606781, 46.99200622737408, 56.68487951159477, 52.17647843062878, 51.76159769296646, 48.49576413631439, 47.788014113903046, 45.57441249489784, 42.14279003441334, 37.26591132581234, 37.186225801706314, 36.34519413113594, 37.45174415409565, 37.6879470795393, 37.51667506992817, 36.272181048989296, 37.87322133779526, 38.386273607611656, 39.60605375468731, 38.67869831621647, 42.31112860143185, 47.65932261943817, 52.67135247588158, 48.245311975479126, 48.851911425590515, 50.31661503016949, 50.103872045874596, 48.904853984713554, 46.159147918224335, 43.453951478004456, 41.34530782699585, 36.029237285256386, 40.6407306343317, 43.32631632685661, 49.50981952250004, 46.66567213833332, 48.85660037398338, 47.312579825520515, 47.35604949295521, 49.891334250569344, 49.321205243468285, 49.05707761645317, 47.98939570784569, 40.35471238195896, 28.84290900081396, 8.970482647418976, 3.2469970174133778, 2.5939918449148536, 3.5626928647980094, 3.7100309086963534, 4.131435658782721, 7.0632775872945786, 5.280671641230583, 4.0795437432825565, 0.530618370976299, 0.1274391944753006, 0.0859677151311189, 0.04095804302778561, 10.1473193988204, 42.920163720846176, 25.859005115926266, 32.81009562313557, 20.187742933630943, 0.49111292988527566, 0.05274779730825685, 0.06539892157888971, 0.04202789343253244, 0.01582750704983482, 0.026587473912513815, 0.025725256018631626, 0.03674200597743038, 0.05892052155104466, 0.08927751565352082, 0.02372275419475045, 0.05231164082942996, 0.00908687377886963, 0.02626571022119606, 0.018604324941406958, 0.04250198107911274, 0.02440970278257737, 0.06705200357828289, 0.004390616622913512, 0.09701382630737498, 0.08687127992743626, 0.014772944887226913, 0.04781519812240731, 0.044400710248737596, 0.07954485001391731, 0.08905539827537723, 0.15208020427962765, 0.14346977724926546, 0.1287507326924242, 0.1739047042792663, 0.14418657316127792, 0.12167435459559783, 0.15541731583653018, 0.18161797866923735, 0.14331404498079792, 0.2488576268660836, 0.12390849369694479, 0.2120554883731529, 0.10394152253866196, 0.09523460146738216, 0.09047972067492083, 0.08026776122278534, 0.18186257570050657, 0.09734711740748025, 0.15460412978427485, 0.1478376577142626, 0.07757306753774174, 0.13912738213548437, 0.15933086833683774, 0.1397269929293543, 0.18904542230302468, 0.3810880525270477, 0.2032746939221397, 0.7637524860911071, 30.719831585884094, 45.5850937217474, 29.67185541987419, 47.16892473399639, 21.891335919499397, 4.098428254947066, 0.8644304587505758, 0.5802101630251855, 0.5343267344869673, 6.572463624179363, 10.456518307328224, 13.752716984599829, 12.52620929852128, 15.930393431335688, 13.908107746392488, 3.9712904021143913, 0.820780360372737, 2.2816381556913257, 32.02457897365093, 58.21726508438587, 58.83870653808117, 56.400229185819626, 56.81263245642185, 53.70053865015507, 54.38117332756519, 52.596595287323, 53.246067836880684, 53.858363181352615, 51.88078589737415, 55.61877451837063, 58.159325793385506, 56.127331629395485, 56.18586368858814, 57.7766939252615, 55.84054961800575, 55.39573408663273, 49.74688500165939, 41.99349604547024, 46.060721799731255, 52.181972935795784, 57.94440172612667, 58.95223304629326, 53.195165768265724, 55.911442413926125, 56.12534053623676, 54.128540083765984, 47.572793662548065, 41.8576305359602, 42.26773492991924, 43.78962926566601, 41.73917569220066, 42.35977739095688, 51.85345396399498, 55.154150649905205, 54.53552104532719, 52.849011942744255, 50.162525698542595, 49.624064192175865, 48.29607345163822, 46.401730701327324, 48.60577963292599, 58.344797641038895, 54.228527918457985, 52.99377277493477, 49.684192165732384, 50.28437376022339, 47.72266522049904, 44.611437767744064, 39.363372176885605, 39.553510174155235, 38.68176855146885, 38.50691333413124, 39.847253412008286, 40.83461903035641, 37.258668914437294, 39.79943297803402, 39.999781027436256, 42.060570046305656, 39.57900680601597, 44.51170451939106, 50.310824140906334, 55.461519956588745, 51.230120211839676, 50.61313211917877, 50.8831874281168, 51.361083984375, 52.261628061532974, 46.970043405890465, 47.001479119062424, 45.08922792971134, 40.740410685539246, 41.89157031476498, 45.82798808813095, 50.18420733511448, 47.750213742256165, 48.36557172238827, 49.280395433306694, 48.40869560837746, 50.328918769955635, 51.28036491572857, 50.80619215965271, 48.86812135577202, 41.864462569355965, 27.781852036714554, 8.749504555016756, 3.8494836632162333, 3.071009935811162, 4.58659945987165, 9.925607945770025, 8.833778332918882, 13.482147753238678, 11.315430868417025, 13.015009369701147, 4.429295500740409, 0.7465480780228972, 0.5946522974409163, 0.12868092628195882, 13.96852070465684, 45.70520527660847, 33.76346826553345, 40.383013263344765, 23.81596114486456, 0.6935070804320276, 0.20320888026617467, 0.15768586832564324, 0.34320037462748587, 0.12213999289087951, 0.1326299979700707, 0.14451383060077205, 0.138850724324584, 0.1859037479152903, 0.3689407871570438, 0.09250955394236371, 0.11083598539698869, 0.15575796162011102, 0.13750400830758736, 0.15590668801451102, 0.12007871482637711, 0.16385687078582123, 0.17610641894862056, 0.17178562033222988, 0.1856430759653449, 0.1540010902681388, 0.08371457704924978, 0.17435186309739947, 0.10224839425063692], [0.03206047535059042, 0.03769410352106206, 0.04750746287754737, 0.04360983686638065, 0.080865442432696, 0.08683755673700944, 0.027106387278763577, 0.025179007498081774, 0.029741146972810384, 0.05465018897666596, 0.05690906757081393, 0.05188759620068595, 0.08242542200605385, 0.017598360464035068, 0.05919903102039825, 0.012404211738612503, 0.026046578132081777, 0.04745506725157611, 0.01864079593360657, 0.061451712681446224, 0.031493700880673714, 0.04259258246747777, 0.0615349556755973, 0.043954211942036636, 0.03776675606786739, 0.01274807380468701, 0.056188349408330396, 0.019637138466350734, 0.07386048120679334, 0.05700599947886076, 6.5203004982322454, 39.37939211726189, 24.86918482929468, 29.277647472918034, 30.292405821383, 9.019741304218769, 2.3242782801389694, 0.2715557534247637, 0.07496904203435406, 0.8420058432966471, 3.7381225638091564, 3.6752440128475428, 7.28457011282444, 8.282350972294807, 6.838372405618429, 1.7590253613889217, 0.6195249315351248, 0.03206957037036773, 9.74616827443242, 39.359735772013664, 55.22249758243561, 54.851094111800194, 53.475788310170174, 55.05230471491814, 49.913878440856934, 53.40355798602104, 50.74917621910572, 52.019003480672836, 52.89041832089424, 53.079864755272865, 55.80392338335514, 54.64171014726162, 53.2706943154335, 53.53985287249088, 55.469742715358734, 54.77051943540573, 45.14993727207184, 40.185860842466354, 41.485516503453255, 51.008561700582504, 52.96778976917267, 53.466288819909096, 52.349422350525856, 50.73957033455372, 53.31497713923454, 50.05871146917343, 46.956151351332664, 40.60903653502464, 40.55018149316311, 37.3481161147356, 37.441697493195534, 41.62081204354763, 47.88459733128548, 51.43634654581547, 50.67181997001171, 48.693794310092926, 48.929757848381996, 48.44808429479599, 50.04608474671841, 45.30922472476959, 52.01839171350002, 55.24137116968632, 49.46576088666916, 50.84213823080063, 46.60070702433586, 43.74216601252556, 43.235231414437294, 39.613201171159744, 36.86499863862991, 35.81130377948284, 35.656215101480484, 36.486250162124634, 36.10632374882698, 36.420186907052994, 35.3524100035429, 36.14828869700432, 36.66815020143986, 38.74830678105354, 39.80060711503029, 43.60395222902298, 46.26644656062126, 47.68491804599762, 50.87800830602646, 46.68723218142986, 48.956717401742935, 45.51730155944824, 46.76909878849983, 44.910926297307014, 45.485345274209976, 46.078026071190834, 44.52030345797539, 45.3449884057045, 44.44478631019592, 45.49638748168945, 45.00545762479305, 45.451059713959694, 47.026348784565926, 48.01952809095383, 45.671288296580315, 47.68535502254963, 49.653090834617615, 42.22882121801376, 28.268737010657787, 15.906138382852077, 2.4377017188817263, 1.6842307685874403, 2.549722557887435, 1.9587375386618078, 2.754179611802101, 1.5713211335241795, 4.811576837673783, 4.9467275105416775, 3.2617464009672403, 0.49477118358481675, 0.12818126793717965, 0.03347994039359037, 1.3796146516688168, 27.949499040842056, 33.40205825865269, 25.61649452894926, 27.96687550842762, 3.5550771234557033, 0.036452271524467506, 0.07850248133763671, 0.015058244080137229, 0.03287221792561468, 0.025323223489976954, 0.04405444640724454, 0.05368099606130272, 0.04171383137872908, 0.0474691903218627, 0.07814820230123587, 0.01777683399268426, 0.13881927210604772, 0.016431446420028806, 0.044447265172493644, 0.012454763127607293, 0.032792733909445815, 0.09290096262702718, 0.04626074754924048, 0.015895825454208534, 0.03285354177933186, 0.03972481623350177, 0.02332767744519515, 0.06043196095561143, 0.049438438363722526, 0.03325477649923414, 0.0317068345611915, 0.06835151158156805, 0.024858961878635455, 0.10005300267948769, 0.08168549335096031, 0.015738731344754342, 0.038806349111837335, 0.027582202274061274, 0.03640123402874451, 0.003336123340886843, 0.04829524892556947, 0.04592392382619437, 0.039838984521338716, 0.06543671173858456, 0.03009650026797317, 0.015404986606881721, 0.03255097930377815, 0.033530692162457854, 0.00678539080581686, 0.05700604400772136, 0.025976380238716956, 0.050579059970914386, 0.023924833585624583, 0.05729716256610118, 0.0430463241355028, 0.024786988396954257, 0.04816730637685396, 0.029677771271963138, 0.026186387622146867, 10.761327501386404, 44.602151066064835, 25.99204547703266, 32.15844199061394, 34.679169729352, 10.502780824899673, 2.150153098627925, 0.2804329677019268, 0.08658570892293938, 0.44880926550831646, 1.9058986427262425, 4.719084100797772, 5.785764763131738, 8.147557005286217, 6.025757985189557, 6.947887754067779, 2.0321734668686986, 0.25370662682689726, 12.504983637481928, 41.994419395923615, 56.92027688026428, 55.32978482544422, 54.77104760706425, 57.400833293795586, 53.391451835632324, 54.365130588412285, 52.54069648683071, 53.333261758089066, 54.78932462632656, 55.99761039018631, 56.910545602440834, 56.240128576755524, 54.75864887237549, 55.24454779922962, 55.37844881415367, 54.63788375258446, 47.407711520791054, 42.630596458911896, 43.954475820064545, 51.238650754094124, 56.53687745332718, 55.02661049365997, 51.732084676623344, 53.96869786083698, 55.81913396716118, 52.43154734373093, 48.776561468839645, 43.12619626522064, 40.68023331463337, 39.72322426736355, 39.70039129257202, 44.40743811428547, 49.3718109279871, 52.5358821451664, 52.89752773940563, 50.207655876874924, 50.7401555031538, 50.55173501372337, 49.945203959941864, 46.777503937482834, 49.97663967311382, 56.25073000788689, 52.75100760161877, 51.08847141265869, 48.53887282311916, 45.12274593114853, 45.269969031214714, 41.6297871619463, 38.53817045688629, 37.66294822096825, 37.44356319308281, 36.9745771586895, 37.231082394719124, 37.59685076773167, 37.3298466950655, 36.38695769011974, 36.532900258898735, 39.697359055280685, 39.882257133722305, 44.364849999547005, 47.34414093196392, 48.64528231322765, 50.42074844241142, 47.11832284927368, 51.25332936644554, 48.21902498602867, 48.71291868388653, 48.612167090177536, 46.82924576103687, 46.89987637102604, 46.45010970532894, 45.83553448319435, 46.25274449586868, 46.442008540034294, 46.365115866065025, 45.63231758773327, 47.83334568142891, 46.6869205981493, 45.44081166386604, 48.914262279868126, 51.04030899703503, 42.97038942575455, 30.616023056209087, 17.440942525863647, 3.6190773267298937, 2.8051486518234015, 3.4473894769325852, 3.5624228417873383, 4.376185275614262, 5.129672018811107, 5.502515137195587, 2.3237028485164046, 1.228774026967585, 0.3311014379141852, 0.1482658027089201, 0.08520771138137206, 1.2961307563818991, 28.066616356372833, 37.64294609427452, 26.705022118985653, 32.314457818865776, 5.910715833306313, 0.06766747406800278, 0.007215454252218478, 0.023422407030011527, 0.03923551455955021, 0.05982326627417933, 0.06617108912905678, 0.03746148104255553, 0.032239960055449046, 0.06119877019955311, 0.007002781167102512, 0.02288807740114862, 0.09003844708786346, 0.05131355610501487, 0.008923863824747968, 0.04654874537664, 0.03462262517132331, 0.04498163747484796, 0.008185866608982906, 0.035917650602641515, 0.13469827448716387, 0.01903882272017654, 0.013351487177715171, 0.08833238316583447, 0.02858900166756939, 0.14529359032167122, 0.10902823982178234, 0.15610482660122216, 0.19068401015829295, 0.17009827337460592, 0.18950421799672768, 0.10499735377379693, 0.13342894962988794, 0.16050282341893762, 0.1690407723071985, 0.10438971294206567, 0.11318201810354367, 0.1551278485567309, 0.10223603749182075, 0.17234813858522102, 0.14741659280844033, 0.14207841362804174, 0.10346478913561441, 0.24324102356331423, 0.13777521875454113, 0.168446994794067, 0.17591892275959253, 0.10697517733206041, 0.11981468836893328, 0.12592168059200048, 0.12426626082742587, 0.10044583628769033, 0.16690162068698555, 0.1299966056831181, 0.2809859567787498, 12.196233104914427, 53.39778229594231, 35.04617303609848, 37.55268953740597, 40.809319987893105, 13.132584560662508, 3.170681674964726, 0.6060416519176215, 0.19610283110523596, 2.00470925308764, 9.553147181868553, 12.03069593757391, 17.93580897152424, 16.562346071004868, 15.038703829050064, 9.21889241784811, 1.8831156590022147, 0.45734384504612535, 12.088324595242739, 41.65368787944317, 58.50506164133549, 57.91200466454029, 57.67952173948288, 60.19902594387531, 54.46691192686558, 57.84773111343384, 54.46019008755684, 56.173852533102036, 57.31683500111103, 58.16339537501335, 58.61895672976971, 58.42052757740021, 56.38589255511761, 55.513227581977844, 57.616422325372696, 56.43570028245449, 49.67083968222141, 44.80971112847328, 45.35935163497925, 54.757497534155846, 59.154260605573654, 54.9222718924284, 52.90420398116112, 55.381667241454124, 57.019759342074394, 53.911108151078224, 50.245627239346504, 44.16964687407017, 43.06017480790615, 41.64155513048172, 40.51032543182373, 44.94715355336666, 50.79447738826275, 54.95931230485439, 54.53132227063179, 53.16885218024254, 51.69882886111736, 51.53590880334377, 51.03104129433632, 47.543808817863464, 49.991983249783516, 55.797657519578934, 54.81392450630665, 52.972528114914894, 51.11501678824425, 47.76226669549942, 48.32673400640488, 43.6245509237051, 40.810752511024475, 40.06330981850624, 38.94637115299702, 39.69301588833332, 40.3522615134716, 40.6234035640955, 39.65187929570675, 39.40056078135967, 39.469078704714775, 42.62654967606068, 44.05962377786636, 47.301799803972244, 49.59849916398525, 51.05365388095379, 52.00320012867451, 48.48619244992733, 51.616886258125305, 48.728642240166664, 49.34255249798298, 50.5492727458477, 49.95926320552826, 49.723991230130196, 48.89325700700283, 48.891398906707764, 48.39472755789757, 49.38127242028713, 48.314985036849976, 48.09481345117092, 48.06850366294384, 50.39821945130825, 46.15502893924713, 48.504898846149445, 50.52607499063015, 44.67589370906353, 30.80679751932621, 18.2022487744689, 3.4937467519193888, 4.265250228345394, 5.91752459295094, 5.790194850414991, 6.243431204929948, 8.993215877562761, 13.775193728506565, 9.51421732082963, 8.69273655116558, 1.899656883906573, 0.48763958970084786, 0.21298154024407268, 2.287443056702614, 34.59851525723934, 42.61651821434498, 34.12371173501015, 39.986762925982475, 6.811410477384925, 0.15442944306414574, 0.2419690863462165, 0.08154061870300211, 0.11170201978529803, 0.09268532419810072, 0.11731839302228764, 0.1006601908011362, 0.1891191620961763, 0.17381558718625456, 0.14227076346287504, 0.10788839746965095, 0.2403798809973523, 0.11478043350507505, 0.12208988307975233, 0.13426209945464507, 0.11569163500098512, 0.22100319183664396, 0.17318761150818318, 0.15827532653929666, 0.19814750732621178, 0.17679599288385361, 0.09588313463609666, 0.17232804122613743, 0.11702265459462069], [0.12447993256500922, 0.05699129753338639, 0.04506630910327658, 0.05172501761990134, 0.008452382044197293, 0.013157713347027311, 0.050306302146054804, 0.03116988329566084, 0.018154794961446896, 0.02475207034876803, 0.013637455231219064, 0.05746804577938747, 0.009159774017462041, 0.009369120889459737, 0.047331362366094254, 0.08720634476048872, 0.02457960079482291, 0.05834426614455879, 0.03516369535645936, 0.043592541114776395, 0.030096939990471583, 0.01639076002902584, 0.04906696376565378, 0.05928632243012544, 0.022107432669145055, 0.01901101815747097, 0.020996856910642236, 0.01354524152702652, 0.05232769348367583, 0.1398372315452434, 0.607173991156742, 22.17629212886095, 34.12471108138561, 26.070220582187176, 32.73015171289444, 22.590956278145313, 9.580480065196753, 2.24243494682014, 0.20941605500411242, 0.07853835675632581, 1.3680639839731157, 3.465855298563838, 4.963074708357453, 5.237829415127635, 3.5710666654631495, 6.839822502806783, 2.269773529842496, 0.43008743261452764, 0.9366293158382177, 18.43348916620016, 45.02699866890907, 57.46836706995964, 57.492457777261734, 54.90937918424606, 54.996041133999825, 53.08712996542454, 54.06340017914772, 54.97495986521244, 54.833379462361336, 54.970419108867645, 53.64913500845432, 54.371210262179375, 54.505008682608604, 56.58735774457455, 53.60827960073948, 49.940686002373695, 43.91346462070942, 40.83482801914215, 44.978680461645126, 48.675338700413704, 53.279631435871124, 53.76846760511398, 49.46316562592983, 49.90419656038284, 55.2804596722126, 51.25259220600128, 49.20799791812897, 44.380208775401115, 39.662799909710884, 37.62460447847843, 39.09255310893059, 42.11779497563839, 49.62365761399269, 49.31957893073559, 50.75297221541405, 48.227243945002556, 52.485021874308586, 49.76482763886452, 51.040111407637596, 46.19208075106144, 47.88515590131283, 55.04341319203377, 51.217539086937904, 47.00511932373047, 47.674419209361076, 46.858591586351395, 41.632504016160965, 39.23691116273403, 34.86890874803066, 35.773765593767166, 34.65955898165703, 35.154490023851395, 36.21288523077965, 37.07416221499443, 37.16017059981823, 37.91823752224445, 42.93879792094231, 47.28578746318817, 48.1189801543951, 47.587225288152695, 47.8083810210228, 48.37327390909195, 48.9811272919178, 47.809631153941154, 45.086127296090126, 48.12139302492142, 49.82304811477661, 46.21332921087742, 49.10029649734497, 47.75632381439209, 47.15854749083519, 44.65413987636566, 46.699437126517296, 46.35235995054245, 48.60172525048256, 45.84640569984913, 46.607656851410866, 46.653911769390106, 50.809463784098625, 48.96719343960285, 44.89806018769741, 34.16864052414894, 17.0394541695714, 5.520339505746961, 0.48382417880930007, 1.4698362979106605, 2.6214560586959124, 3.896209755912423, 2.071693246252835, 3.039105422794819, 3.8670491706579924, 1.4692951831966639, 0.740350135602057, 0.1832424063468352, 0.1479803430265747, 0.29099515406414866, 12.207678090780973, 35.96598207950592, 24.971196055412292, 29.24492932856083, 19.76734109222889, 0.5056650505866855, 0.03404248462175019, 0.03198499522113707, 0.04383020648674574, 0.06930802119313739, 0.029869217542000115, 0.022095615822763648, 0.06564305105712265, 0.016452438067062758, 0.046473862676066346, 0.046091857002465986, 0.059918231490883045, 0.05360220224247314, 0.016811285022413358, 0.026776686318044085, 0.04615933677996509, 0.024955955013865605, 0.022014423011569306, 0.03322634853248019, 0.02275559847475961, 0.002606580114843382, 0.027299857756588608, 0.02990888533531688, 0.03881382624967955, 0.01626987159397686, 0.06558472567121498, 0.026982879062416032, 0.0713728170376271, 0.05803558466141112, 0.03499879385344684, 0.023995204028324224, 0.008910587730497355, 0.030158727495290805, 0.02397448512056144, 0.029930689634056762, 0.014571605788660236, 0.03695009305374697, 0.04563400012557395, 0.06666594577836804, 0.01713007084617857, 0.06433894915971905, 0.030465247473330237, 0.11402210700907744, 0.02131413246388547, 0.04284560287487693, 0.03416814506636001, 0.09159645254840143, 0.05855012306710705, 0.02742280008533271, 0.04340556442912202, 0.023087132540240418, 0.016628549710731022, 0.03631174215115607, 0.07907596853328869, 0.06898906096466817, 1.8719828501343727, 30.46886645257473, 37.99318850040436, 28.94733689725399, 38.97231996059418, 27.67755713313818, 10.219858456403017, 1.9768560351803899, 0.3500920470105484, 0.17349811125313863, 0.25133893825113773, 2.2059124941006303, 4.47211635299027, 7.393043842166662, 5.047718016430736, 7.099909046664834, 5.136961927637458, 0.558674877975136, 0.9873371198773384, 23.030180409550667, 49.37845677137375, 58.73858191072941, 58.29591706395149, 58.197965919971466, 55.777302011847496, 55.423506796360016, 54.362026154994965, 56.39277018606663, 57.759876027703285, 57.91117250919342, 54.82802554965019, 55.35655438899994, 54.986610040068626, 56.55782572925091, 54.71531979739666, 52.400856390595436, 45.75647212564945, 44.0785201638937, 46.34893253445625, 52.06246554851532, 55.247595235705376, 54.894434586167336, 49.993028193712234, 52.06350289285183, 56.64148584008217, 53.76981273293495, 49.35840144753456, 44.71335589885712, 41.7564457654953, 40.298137217760086, 40.60738742351532, 44.651605412364006, 50.80640874803066, 52.06411086022854, 51.96415342390537, 51.71175956726074, 53.957534059882164, 51.47754393517971, 51.05290152132511, 46.12118415534496, 48.566383346915245, 54.120207130908966, 54.36893418431282, 48.897641971707344, 50.73467239737511, 47.11684092879295, 43.60608011484146, 41.44231662154198, 37.389826476573944, 37.81725034117699, 36.66436940431595, 36.55553184449673, 38.67046415805817, 39.10030849277973, 39.07443568110466, 38.63457128405571, 45.17862193286419, 48.69605518877506, 49.84723001718521, 49.87448215484619, 48.13027694821358, 50.184408724308014, 49.22825463116169, 48.46104919910431, 48.03047150373459, 47.73116156458855, 50.24082809686661, 48.38063031435013, 49.72401782870293, 47.087814286351204, 46.78749740123749, 47.32404001057148, 48.54703098535538, 47.20221474766731, 47.544865161180496, 47.23628751933575, 48.00153985619545, 48.4341162443161, 50.78076012432575, 47.24085867404938, 44.70303185284138, 35.269449055194855, 19.362092837691307, 8.500516265630722, 1.804236879106611, 2.3178217140957713, 4.6676139626652, 5.1465739868581295, 5.304772797971964, 6.088796127587557, 6.490753758698702, 1.9686204520985484, 0.08649150811834261, 0.10791294771479443, 0.06657495847321115, 0.21991265035467222, 11.540963966399431, 40.0750245898962, 29.273083917796612, 32.1735879778862, 26.106860116124153, 1.1012325645424426, 0.03345064411405474, 0.022221792060008738, 0.05606502672890201, 0.026483892361284234, 0.01258986832908704, 0.008959492479334585, 0.07765964648569934, 0.023768889805069193, 0.0543845520587638, 0.032654097012709826, 0.02217732442659326, 0.0010042942972177116, 0.03135628481686581, 0.027709378555300646, 0.009683819334895816, 0.03842672202154063, 0.014428615268116118, 0.04599827589117922, 0.07718791515799239, 0.018653392035048455, 0.015273692333721556, 0.050821723707485944, 0.07336625538300723, 0.026653909117158037, 0.172664278652519, 0.1805276598315686, 0.2025410215719603, 0.10965304652927443, 0.1443796799867414, 0.0748511147685349, 0.120842466421891, 0.13388087303610519, 0.1258017643704079, 0.18682280875509605, 0.11148446661536582, 0.17082240170566365, 0.11093910681665875, 0.14606331620598212, 0.09050289052538574, 0.18029904866125435, 0.12607554264832288, 0.22099808586062863, 0.1819795381743461, 0.26313314912840724, 0.18410775053780526, 0.2017906360561028, 0.1562523952452466, 0.19838581094518304, 0.08416313110501505, 0.13431366387521848, 0.08990696820546873, 0.07781827313010581, 0.1665194146335125, 0.32767877157311887, 2.0823374250903726, 34.24357250332832, 46.11128568649292, 35.057659819722176, 41.49724267423153, 32.234578505158424, 13.176481705158949, 3.3526890585199, 0.7074970391113311, 0.5732173507567495, 3.1205229414626956, 9.220572877675295, 14.18118104338646, 14.160314463078976, 12.420531269162893, 13.040206767618656, 5.456949407234788, 0.9101420058868825, 2.138806194998324, 20.315611772239208, 49.322234988212585, 61.00632302463055, 62.06827864050865, 61.51114113628864, 58.73024895787239, 56.881252974271774, 58.38582783937454, 58.23849834501743, 61.15640737116337, 59.08913590013981, 57.3851515352726, 57.03368939459324, 56.24071754515171, 58.93204852938652, 58.11647169291973, 53.81305441260338, 47.78218902647495, 45.43407082557678, 50.51022984087467, 54.08254735171795, 57.8950309753418, 55.19948601722717, 49.8490235209465, 51.82557485997677, 57.72937886416912, 54.897436425089836, 52.93228067457676, 48.10487911105156, 42.62149214744568, 41.731237918138504, 44.1710451990366, 45.12079283595085, 54.16107773780823, 53.3923751860857, 54.33946676552296, 52.16366171836853, 56.146729588508606, 53.621540889143944, 52.4066586792469, 46.549523770809174, 52.425707057118416, 57.46701054275036, 55.835997462272644, 51.407266706228256, 52.64038413763046, 53.22497516870499, 45.61419636011124, 44.582110941410065, 38.4232722222805, 39.7188962996006, 38.897319585084915, 38.09650495648384, 40.284123569726944, 41.70289903879166, 41.29425376653671, 42.441754192113876, 47.63984486460686, 52.118140161037445, 52.09080822765827, 53.41807320713997, 50.961596220731735, 51.53474226593971, 49.94653008878231, 47.64174856245518, 46.76485821604729, 48.45809295773506, 51.53036870062351, 48.01683783531189, 51.787481904029846, 51.20938092470169, 50.81996642053127, 48.49903576076031, 50.511605367064476, 50.55966518819332, 50.34690700471401, 47.50664681196213, 49.89762671291828, 49.61901806294918, 52.86108769476414, 48.603298366069794, 44.677862003445625, 35.45921087265015, 19.678363166749477, 7.09869833663106, 1.268941790331155, 4.1436938010156155, 6.6925272066146135, 9.283976275473833, 6.665704920887947, 10.482584908604622, 10.592987984418869, 5.390044497326016, 2.0079174684360623, 0.4725814430275932, 0.42704216320998967, 0.5627338914200664, 16.877719648182392, 43.48008647561073, 32.67962962388992, 39.039633348584175, 29.42732524126768, 1.2050586682744324, 0.10142351195099764, 0.11584416861296631, 0.15102579054655507, 0.17728388076648116, 0.14384398295078427, 0.05005837287171744, 0.19403617247007787, 0.08443837883532979, 0.17085520463297144, 0.13781348388874903, 0.10482023280928843, 0.19923516927519813, 0.0808073693769984, 0.14426927809836343, 0.1048594775784295, 0.18253193353302777, 0.18630897538969293, 0.08350982592673972, 0.11998861067695543, 0.1554615775239654, 0.08510833780746907, 0.0957525463309139, 0.11623723970842548, 0.16291532287141308], [0.04684986066422425, 0.08128573550493456, 0.05134672639542259, 0.015355846226157155, 0.03192615033185575, 0.04343857886851765, 0.024823604107950814, 0.08373891207156703, 0.02809791698382469, 0.09625660561141558, 0.057557738036848605, 0.012600007921719225, 0.028625739832932595, 0.061549186357297, 0.04816872387891635, 0.03433243058680091, 0.031629918375983834, 0.015473512812604895, 0.0026715409967437154, 0.08141423095366918, 0.010105085548275383, 0.00789655703556491, 0.054153606834006496, 0.01631201259442605, 0.06493028500699438, 0.041431269783061, 0.05465886839374434, 0.049449099315097556, 0.033750957882148214, 0.06653792530414648, 0.06985223808442242, 5.478324210271239, 30.36943718791008, 25.615358389914036, 27.728711888194084, 27.20553696155548, 22.46503483504057, 10.65896574407816, 1.9688195851631463, 0.10032663252786733, 0.2323749425704591, 0.829779643099755, 2.8111575543880463, 6.496817758306861, 3.455174546688795, 5.6292592361569405, 4.158230870962143, 1.1082333326339722, 0.7104146294295788, 3.0961724231019616, 25.841151773929596, 45.49220770597458, 58.086419105529785, 55.266134440898895, 54.29812118411064, 55.340591445565224, 54.45310726761818, 52.35656976699829, 53.35596174001694, 54.224918112158775, 55.14307044446468, 56.913539841771126, 56.081506088376045, 55.055158361792564, 53.38942654430866, 45.01566767692566, 43.42607617378235, 42.76562221348286, 48.57223883271217, 51.166971400380135, 56.85261771082878, 50.44644646346569, 51.269702687859535, 54.52068664133549, 52.888499423861504, 54.32817757129669, 46.81857593357563, 45.477361902594566, 40.10492518544197, 38.91689993441105, 39.87156070768833, 42.24633067846298, 48.83657544851303, 50.92656970024109, 50.127822160720825, 50.103784650564194, 52.4385541677475, 51.116745695471764, 49.671098068356514, 47.30933099985123, 37.92172193527222, 49.159083142876625, 49.633643478155136, 50.06828315556049, 45.92745915055275, 42.56897136569023, 40.477202609181404, 37.61673130095005, 36.82934135198593, 35.77234447002411, 35.19610919058323, 36.53418838977814, 37.64623671770096, 36.17815889418125, 36.37642465531826, 45.19704334437847, 48.911355435848236, 49.53153915703297, 49.69430722296238, 50.37011615931988, 47.92832538485527, 50.62671639025211, 49.09447520971298, 45.382545590400696, 48.12700532376766, 48.573226779699326, 48.32925707101822, 47.23711207509041, 47.935970574617386, 48.1924682110548, 50.64770266413689, 47.18467868864536, 48.53729210793972, 45.30654966831207, 49.71839413046837, 47.22188629209995, 47.855859473347664, 48.01097474992275, 41.17972411215305, 51.38575606048107, 37.630087584257126, 19.939553551375866, 8.123707585036755, 1.2476721941493452, 2.2583359060809016, 1.735315821133554, 2.5481774657964706, 3.0150743247941136, 5.143217816948891, 5.325598530471325, 4.194013075903058, 1.1118823243305087, 0.07495855548768304, 0.10997796620358713, 0.49430081038735807, 5.058006914332509, 23.607572726905346, 32.55354478955269, 20.218924060463905, 27.546122185885906, 6.719670575112104, 0.007988962770468788, 0.03628942205978092, 0.02317337566637434, 0.05243199491815176, 0.05100804730318487, 0.02577936971647432, 0.05206464295042679, 0.059153912152396515, 0.014688256560475565, 0.04910429379378911, 0.013269958544697147, 0.05571134512138087, 0.02885109668568475, 0.051329400957911275, 0.04683578954427503, 0.07181700726505369, 0.044656825411948375, 0.0521025963826105, 0.03891630200087093, 0.0806672073667869, 0.02582704899396049, 0.02213205341831781, 0.03667284894618206, 0.013746463737334125, 0.04229520018270705, 0.09875491217826493, 0.050899196503451094, 0.05982183021842502, 0.04640642371668946, 0.0292890992568573, 0.011657900613499805, 0.012243153632880421, 0.01737199429044267, 0.06357001737342216, 0.04819270638108719, 0.024437195643258747, 0.022957386572670657, 0.03940013033570722, 0.06228653233847581, 0.0502458393748384, 0.056156125356210396, 0.03831777103187051, 0.019357213350303937, 0.10501868309802376, 0.08179667449439876, 0.012582435720105423, 0.039953568411874585, 0.011788398933276767, 0.02628804144478636, 0.018618724461703096, 0.040127115935320035, 0.019655350770335644, 0.05090308535727672, 0.029537661212089006, 0.005565400215346017, 0.14947618619771674, 9.557269010692835, 36.51240415871143, 29.232046119868755, 29.200464114546776, 35.148771330714226, 27.45006714016199, 10.684127043932676, 1.8639816669747233, 0.04467918261070736, 0.21498455229448155, 0.835390635766089, 2.5627931440249085, 4.700209563598037, 5.553526924923062, 7.09885080344975, 6.886716261506081, 1.334064002148807, 0.3244279569480568, 4.064954426139593, 27.799408994615078, 47.79938690364361, 57.620640099048615, 56.70161001384258, 56.728109791874886, 56.244768127799034, 57.13737063109875, 54.83274109661579, 55.11404000222683, 55.38377232849598, 55.79990319907665, 57.238247618079185, 57.93191559612751, 57.13843837380409, 53.63337345421314, 47.7513612806797, 43.95596534013748, 43.28276686370373, 50.37140429019928, 52.29581102728844, 56.66335366666317, 52.22583398222923, 50.63479855656624, 55.500331073999405, 56.140494123101234, 55.99997766315937, 49.68465194106102, 46.166454926133156, 40.71190841495991, 39.79149520397186, 39.95640255510807, 46.49555146694183, 51.53300955891609, 53.19324687123299, 52.4701988697052, 52.311846166849136, 53.11448469758034, 53.58582280576229, 49.97209891676903, 48.57864148914814, 40.52240878343582, 51.20105937123299, 53.73927757143974, 51.96919195353985, 47.707534432411194, 45.871871933341026, 42.043881341814995, 39.89263437688351, 38.36759001016617, 37.66401216387749, 36.17942422628403, 38.42611066997051, 38.68715286254883, 38.25061708688736, 39.20677877962589, 47.019007578492165, 50.78651301562786, 51.30194015800953, 50.664782747626305, 50.875827223062515, 50.93646056950092, 51.961162984371185, 48.86231146752834, 47.124011144042015, 47.726400420069695, 49.215327724814415, 49.75110277533531, 47.8532300144434, 48.38110148906708, 49.10805568099022, 50.45638673007488, 48.2307131588459, 50.389175936579704, 45.83601325750351, 49.852249547839165, 48.60521726310253, 48.131690472364426, 49.00706849992275, 45.69328911602497, 50.94892390072346, 38.816387727856636, 23.623366579413414, 10.232988651841879, 3.521647467277944, 3.974965517409146, 2.0879003265872598, 5.695435535162687, 4.40947481431067, 6.8517001904547215, 6.760609103366733, 2.76611952111125, 0.8835013385396451, 0.0981894253345672, 0.051921790654887445, 0.42195162386633456, 4.553239149972796, 25.914883017539978, 38.33304226398468, 22.449881248176098, 32.16478005051613, 10.761429145932198, 0.039839351884438656, 0.07593234229716472, 0.0983976868155878, 0.03423026282689534, 0.010989310903823934, 0.08487542960210703, 0.02770109989796765, 0.06301174420514144, 0.021297621533449274, 0.05990710669721011, 0.05221551044087391, 0.017610553950362373, 0.012553479900816455, 0.01395503599269432, 0.08226468024076894, 0.036567452843883075, 0.07521953171817586, 0.03358846464834642, 0.04918999329674989, 0.02452999193337746, 0.04850361801800318, 0.039291624634643085, 0.06288898555794731, 0.04196033944026567, 0.032833381337695755, 0.12295731270569377, 0.18385297124041244, 0.14888185949530452, 0.09697894536657259, 0.10738537719589658, 0.13991998101118952, 0.13388094725087285, 0.14005992037709802, 0.1542688423069194, 0.2158420445630327, 0.09731038109748624, 0.09879709585220553, 0.10601521673379466, 0.18695825070608407, 0.1228806414292194, 0.12046034200466238, 0.16885250428458676, 0.152538257825654, 0.16753001196775585, 0.2569059660891071, 0.18872515589464456, 0.20920132199535146, 0.1939587070955895, 0.15772824495797977, 0.14701274572871625, 0.14055024250410497, 0.14236563962185755, 0.17122185527114198, 0.13756403321167454, 0.11869351103086956, 0.17778871930204332, 9.532462991774082, 44.141836166381836, 36.81891091167927, 36.62906549870968, 37.88674861192703, 29.67446208000183, 13.763474207371473, 2.8033788967877626, 0.37618566246237606, 0.727778747677803, 2.749307560734451, 7.2286551631987095, 18.92311569303274, 8.483599573373795, 10.206998996436596, 7.684159995988011, 2.8024237230420113, 1.1671332595869899, 3.8784421468153596, 28.215019293129444, 49.193957671523094, 60.24471089243889, 58.450393974781036, 57.67043262720108, 58.45586948096752, 57.87227779626846, 55.80383598804474, 55.19584961235523, 56.437212601304054, 57.80332289636135, 60.374131947755814, 61.41370676457882, 60.29961794614792, 56.1031611263752, 48.04873712360859, 46.572968512773514, 46.00231513381004, 52.12245672941208, 54.019276946783066, 58.258067294955254, 52.87499114871025, 52.028502970933914, 55.58054856956005, 56.363302767276764, 58.10973085463047, 51.0533232986927, 50.56201346218586, 43.2249491661787, 43.14842127263546, 43.57404783368111, 46.10292613506317, 54.87645395100117, 55.84901176393032, 54.34318296611309, 54.17600713670254, 56.06115438044071, 54.98923949897289, 51.84569478034973, 48.603796139359474, 43.57059381902218, 52.78153516352177, 55.001691430807114, 56.79025925695896, 49.29496385157108, 46.75019860267639, 44.136748239398, 42.15477079153061, 40.66342681646347, 40.826016291975975, 38.89122851192951, 41.65569797158241, 41.39799199998379, 39.210373386740685, 39.84427057206631, 49.85411524772644, 53.18505451083183, 55.71106016635895, 53.10946136713028, 53.206340968608856, 52.29882426559925, 54.34447109699249, 48.565019220113754, 46.03342406451702, 52.11328022181988, 50.6760111451149, 51.135714277625084, 50.08698955178261, 48.994764760136604, 49.33127090334892, 52.49473415315151, 48.482913225889206, 53.31572949886322, 47.06712059676647, 50.79560212790966, 49.55704718828201, 50.96909321844578, 51.30605533719063, 47.11393028497696, 50.861403197050095, 40.380406603217125, 21.76893498748541, 8.652253523468971, 2.998223891481757, 4.587994460016489, 5.340280467644334, 7.747932448983192, 5.762987360358238, 11.23659934848547, 12.116680573672056, 10.169830340892076, 3.899700343608856, 0.6406429514754564, 0.21652128780260682, 0.8468680980149657, 6.817519124597311, 29.941061474382877, 42.88874700665474, 28.05778943002224, 39.658411145210266, 11.30359260365367, 0.16161392239155248, 0.20690713572548702, 0.1556160332984291, 0.13741634582402185, 0.113677698536776, 0.1103063888149336, 0.12158054712926969, 0.10184762708377093, 0.14049079647520557, 0.15324009204050526, 0.1550882327137515, 0.11310734320431948, 0.13330794987268746, 0.11572995208553039, 0.14394641417311504, 0.09723397699417546, 0.22704571369104087, 0.1571384898852557, 0.09330112123279832, 0.2135769504820928, 0.1222756649076473, 0.1882514133467339, 0.14005683304276317, 0.09171871395665221, 0.11450764970504679], [0.07983001283719204, 0.05015961665776558, 0.02712574991164729, 0.030760399604332633, 0.047636559465900064, 0.03768247777770739, 0.015381864996015793, 0.03902101161656901, 0.020855587245023344, 0.0192994130338775, 0.015019744241726585, 0.04223023999657016, 0.04041205611429177, 0.04437093528395053, 0.029874577703594696, 0.09614976603188552, 0.03501497267279774, 0.03332127664180007, 0.021625530207529664, 0.064828031900106, 0.022911275082151406, 0.08931443007895723, 0.030313066381495446, 0.07098462927388027, 0.04009773430880159, 0.06190080108353868, 0.03868317486194428, 0.14147730369586498, 0.003193630291207228, 0.1107078164932318, 0.05476025689858943, 0.28018960263580084, 16.46798573434353, 31.02176148444414, 28.30383002758026, 26.660458110272884, 30.946225337684155, 27.311150394380093, 10.137753412127495, 0.6898151035420597, 0.21155532536795363, 0.7130388636142015, 1.8940879264846444, 2.214205074124038, 4.179787114262581, 6.3377905916422606, 9.239003788679838, 0.9231941273901612, 0.37654008250683546, 0.10832376356120221, 4.196937493979931, 24.60253033787012, 41.131550297141075, 50.68152844905853, 53.329024985432625, 51.817948669195175, 51.632716208696365, 55.90622529387474, 54.278031662106514, 55.303505435585976, 54.63790275156498, 53.02403435111046, 53.99231359362602, 50.62665559351444, 47.141505405306816, 42.52096474170685, 41.03206783533096, 49.207853525877, 51.593414917588234, 54.858959689736366, 54.33814063668251, 51.18521802127361, 54.34480167925358, 53.528544679284096, 55.534597635269165, 50.980633199214935, 47.29994550347328, 43.02352957427502, 40.934192687273026, 39.17126588523388, 38.311934396624565, 45.162590593099594, 50.88092274963856, 51.66342616081238, 51.08520358800888, 49.3235307186842, 51.03740215301514, 51.13189548254013, 50.01499101519585, 50.05583122372627, 41.330431625247, 52.01312139630318, 51.585526540875435, 49.578143656253815, 44.55271951854229, 41.1421175301075, 38.12731370329857, 37.9994011670351, 36.469082683324814, 36.47418200969696, 34.623232930898666, 37.28004276752472, 35.263000801205635, 38.70047114789486, 42.436324283480644, 44.945895820856094, 47.92655847966671, 52.41150721907616, 48.173305839300156, 51.13871991634369, 46.95308871567249, 47.200269252061844, 50.60605689883232, 48.33865776658058, 46.6241517663002, 45.46533554792404, 46.983042508363724, 48.221540451049805, 48.21701109409332, 48.56820724904537, 47.07652889192104, 49.35155041515827, 47.613105699419975, 47.04286649823189, 45.7663743942976, 47.76502154767513, 41.59258335828781, 54.589930325746536, 46.63760684430599, 32.60314732789993, 24.122804179787636, 7.473645592108369, 2.1804759465157986, 2.662737756036222, 4.021214973181486, 0.6032695225439966, 4.8194129671901464, 4.491754174232483, 4.794608373194933, 5.293553899973631, 3.21557080373168, 0.6635640340391546, 0.07129559657187201, 0.16550513624679297, 2.6814698008820415, 14.653104320168495, 36.034477204084396, 26.272578723728657, 29.29958749562502, 19.07669585198164, 1.1672009434551, 0.025053432400454767, 0.028166055417386815, 0.05063728887762409, 0.048161988888750784, 0.03201220606570132, 0.0731046409055125, 0.011305465814075433, 0.037546816893154755, 0.009729804660310037, 0.014438357811741298, 0.02767606911220355, 0.018816315714502707, 0.03879634496115614, 0.048827754726517014, 0.02065892367681954, 0.055271047458518296, 0.04257055181369651, 0.027528086720849387, 0.06094183125242125, 0.07384145254036412, 0.018590944018797018, 0.02420206099486677, 0.023713857699476648, 0.03821558100753464, 0.05930899133090861, 0.01425101283530239, 0.020650355581892654, 0.03490533519652672, 0.08962233230704442, 0.04915071142022498, 0.058973021077690646, 0.014319968558993423, 0.020832346890529152, 0.06614592290134169, 0.04293222264095675, 0.0418098578666104, 0.039010217078612186, 0.03110469304374419, 0.02154982001229655, 0.017623133353481535, 0.04003273330454249, 0.05077446374343708, 0.05125103016325738, 0.0055711782988510095, 0.038578372477786615, 0.025478699717496056, 0.060720433757524006, 0.07369887855020352, 0.006059114421077538, 0.04338449114584364, 0.08029289776459336, 0.06105572494561784, 0.036354256080812775, 0.023893572470115032, 0.0529683302011108, 0.016903326177271083, 0.7560302317142487, 22.610897608101368, 36.07997976243496, 31.496040634810925, 28.446379378437996, 38.806774243712425, 31.172755882143974, 9.728621765971184, 0.4433394590159878, 0.15519493870669976, 0.2283264379366301, 1.115614080335945, 3.065805877558887, 5.234586289152503, 10.47784086316824, 8.139853868633509, 2.1797827212139964, 1.8456921796314418, 0.524870288791135, 7.0837760623544455, 27.981911301612854, 44.77453641593456, 52.758166417479515, 53.03232550621033, 53.516100347042084, 52.00282774865627, 54.546513855457306, 53.70486281812191, 57.16975249350071, 55.90393781661987, 54.76796977221966, 54.85953725874424, 53.95204335451126, 49.062655717134476, 43.913495019078255, 42.85131521522999, 50.10749325156212, 53.723037242889404, 56.265898793935776, 56.30265802145004, 51.772970482707024, 53.641805201768875, 56.76420025527477, 56.71024315059185, 51.80457338690758, 48.96459437906742, 45.48214964568615, 41.25046871602535, 40.11914782226086, 40.40657579898834, 46.732810735702515, 51.629672572016716, 53.475127145648, 51.85771353542805, 52.573902904987335, 53.770656287670135, 52.32222341001034, 50.633225440979004, 50.13391703367233, 42.579899579286575, 51.72343634068966, 52.311382591724396, 49.59100216627121, 46.64752051234245, 42.200497537851334, 40.30591160058975, 39.28418442606926, 39.54845644533634, 38.646897822618484, 37.82329961657524, 39.12807360291481, 38.08023042976856, 40.17540380358696, 43.254560977220535, 47.742838338017464, 49.84458535909653, 53.28057378530502, 49.72243331372738, 52.563689053058624, 48.55707384645939, 48.465848341584206, 50.74121944606304, 48.556967452168465, 49.526504427194595, 48.59794445335865, 47.88772076368332, 50.36506623029709, 47.905450612306595, 50.64195357263088, 48.004674687981606, 49.151107370853424, 48.18644553422928, 48.66136685013771, 47.40608520805836, 49.481020867824554, 45.352625995874405, 54.23579312860966, 46.06742464005947, 37.05900862812996, 26.83641716837883, 10.528815127909184, 4.010679563507438, 3.6067439010366797, 5.621309587731957, 4.119351357221603, 7.045228555798531, 6.08228612691164, 8.659317344427109, 5.330531615763903, 1.8005095166154206, 0.2270888621569611, 0.0978599266090896, 0.2539702970534563, 3.251362033188343, 16.091268248856068, 37.84184642136097, 29.490439854562283, 29.074191190302372, 24.930517338216305, 1.9862084020860493, 0.02665170864929678, 0.013188048633310245, 0.03987349438830279, 0.015398977066070074, 0.09612930502044037, 0.03295491544122342, 0.02066359549644403, 0.021296671584423166, 0.00821930685560801, 0.02055676519375993, 0.06386072403984144, 0.02983274098369293, 0.030399405986827333, 0.02219596346549224, 0.04974303432391025, 0.06392383627826348, 0.035503706603776664, 0.07977822577231564, 0.055460992734879255, 0.06286645395448431, 0.1307351910509169, 0.004479194731175085, 0.023951255898282398, 0.01698310148640303, 0.030559040096704848, 0.14259692252380773, 0.10403760097688064, 0.17413206864148378, 0.11426985074649565, 0.11038467055186629, 0.24367259728023782, 0.09164310395135544, 0.08469860549666919, 0.10220125303021632, 0.19821787776891142, 0.1073637064837385, 0.07030266235233285, 0.10219037314527668, 0.1291514775948599, 0.12177019554655999, 0.18821717065293342, 0.11583721468923613, 0.12173311042715795, 0.08394612712436356, 0.13392890483373776, 0.08760344571783207, 0.19552812678739429, 0.14414061937713996, 0.22820291487732902, 0.11792926961788908, 0.14704637986142188, 0.1560687433811836, 0.1836303120944649, 0.18448807153617963, 0.1521762678748928, 0.2059982719947584, 0.8362286095507443, 24.58166565746069, 45.16045890748501, 39.42983441054821, 35.3542947024107, 41.49279311299324, 35.203078016638756, 12.793820388615131, 0.9169456001836807, 0.431109755882062, 1.2315286416560411, 6.818767357617617, 8.833224512636662, 10.730895884335041, 16.78223457187414, 18.482827618718147, 2.3715705424547195, 1.9407412293367088, 0.5979281372856349, 5.181486513465643, 27.8878378495574, 45.312940925359726, 52.66686871647835, 53.24626922607422, 51.80703945457935, 52.507942244410515, 55.460858792066574, 54.59082327783108, 58.37490722537041, 57.650430500507355, 56.30153328180313, 57.364568039774895, 55.33593289554119, 51.17326766252518, 46.37224808335304, 44.797468185424805, 53.2258453220129, 56.54664292931557, 58.193223774433136, 57.909804582595825, 52.90931850671768, 55.85729531943798, 58.043998181819916, 60.93770630657673, 54.46738310158253, 50.516484305262566, 46.57909758388996, 43.075305595993996, 42.40783341228962, 40.6734848767519, 49.766617342829704, 53.858841955661774, 55.22379331290722, 53.36932182312012, 53.12400698661804, 56.41713447868824, 54.69739995896816, 51.90902978181839, 52.66576677560806, 46.49674840271473, 54.458221793174744, 55.049302875995636, 53.4614896774292, 48.46823841333389, 45.38343474268913, 41.72944441437721, 41.47935703396797, 41.241637989878654, 40.38188472390175, 39.271565303206444, 40.76509416103363, 39.462755843997, 43.96904803812504, 45.4954831302166, 49.11949686706066, 51.630922704935074, 55.39025478065014, 52.159428745508194, 53.89329090714455, 49.514139890670776, 47.96144060790539, 52.21983790397644, 53.01418147981167, 51.36270649731159, 49.8836624622345, 51.12127885222435, 52.62838818132877, 50.649252980947495, 51.12930402159691, 50.56363217532635, 51.4088474214077, 48.75048726797104, 50.13046681880951, 49.06829081475735, 51.6384083032608, 45.649234279990196, 56.58608861267567, 48.6377739161253, 36.43878310918808, 26.198746785521507, 10.645882096141577, 3.4192956844344735, 4.966770485043526, 7.25933994166553, 3.802568055689335, 12.418042402714491, 11.129677835851908, 10.471116174012423, 10.930637866258621, 6.371791642159224, 2.099724104627967, 0.3669502877164632, 0.5301644734572619, 4.334102058783174, 20.802242159843445, 44.75323095917702, 34.322783052921295, 37.996376529335976, 28.951978348195553, 2.0141887944191694, 0.16743957385187969, 0.14120251609710976, 0.21194220695178956, 0.1896908087655902, 0.10721390397520736, 0.19385440566111356, 0.07673357235034928, 0.11269276466919109, 0.1108950306661427, 0.10945414353045635, 0.18507914763176814, 0.08320986467879266, 0.11602482962189242, 0.19625163171440363, 0.15158124355366454, 0.16297597117954865, 0.17387298488756642, 0.17299808183452114, 0.1660839223768562, 0.18484310014173388, 0.2559752238448709, 0.08259085414465517, 0.06054760240658652, 0.15113849309273064, 0.09406046447111294], [0.0164918015798321, 0.039441508779418655, 0.07332830937230028, 0.04075343291333411, 0.015941222627589013, 0.024270279209304135, 0.017101637313317042, 0.019883665081579238, 0.012285498723940691, 0.01619003691303078, 0.04171655877144076, 0.045363810131675564, 0.022334537279675715, 0.0552949928533053, 0.05247836801572703, 0.00460224930975528, 0.029585856282210443, 0.04318510204029735, 0.002437116258988681, 0.04710950473963749, 0.05295631111948751, 0.08966105757281184, 0.03643884236225858, 0.029242457130749244, 0.054976051178527996, 0.08627254486782476, 0.03655966771475505, 0.048781567165860906, 0.03490636678179726, 0.04513063104241155, 0.03342474316013977, 0.0505667959805578, 2.912871683947742, 23.527250736951828, 31.532167196273804, 27.178127132356167, 25.484457314014435, 37.113714292645454, 29.902050867676735, 9.240359365940094, 0.5913668393623084, 0.16620389797026291, 0.31377318024169654, 1.4040805888362229, 5.116167543455958, 7.225248645991087, 4.7581536043435335, 2.244362630881369, 1.7108578397892416, 0.3869854548247531, 0.07750980686978437, 3.1837973836809397, 17.07828238606453, 34.911819845438, 46.31799079477787, 53.643032535910606, 53.9373267441988, 50.96770629286766, 55.00182442367077, 54.27765168249607, 53.112888783216476, 51.35829113423824, 49.28939715027809, 47.40885905921459, 44.85776335000992, 41.89617186784744, 48.069476410746574, 55.87027922272682, 53.43192346394062, 54.18731153011322, 51.685556173324585, 50.359944105148315, 53.84921707212925, 55.79703815281391, 52.982844561338425, 50.81020474433899, 45.66955178976059, 42.66344949603081, 41.71791963279247, 38.84866699576378, 38.67781676352024, 43.48072484135628, 49.75202612578869, 51.85734495520592, 52.69304171204567, 52.06132560968399, 54.25302520394325, 51.53066888451576, 52.19016149640083, 46.64812467992306, 44.1058748960495, 56.23768910765648, 49.55362357199192, 49.762597158551216, 46.12098276615143, 41.750609278678894, 36.237853690981865, 38.39926891028881, 36.50432959198952, 37.16913811862469, 36.65058374404907, 36.54325470328331, 36.16437703371048, 45.38664177060127, 46.68993383646011, 47.01984353363514, 46.5316229313612, 51.00573465228081, 50.60567691922188, 48.51396135985851, 48.11982370913029, 47.967714071273804, 48.763303980231285, 49.268741458654404, 45.91833584010601, 42.53426782786846, 40.94478651881218, 41.69537544250488, 44.15327735245228, 46.7827932536602, 45.387834906578064, 46.202959567308426, 46.470351219177246, 44.92720082402229, 44.478539898991585, 44.539028853178024, 45.82582600414753, 49.21374320983887, 48.91977198421955, 31.42232459038496, 11.54312890022993, 1.7405754514038563, 0.5887753784190863, 3.1313155498355627, 4.273672001436353, 2.73911627009511, 4.513445310294628, 5.280000502243638, 8.935369681566954, 3.388342782855034, 0.8694026700686663, 0.23382596002193168, 0.20259576238458976, 2.6501058088615537, 16.52726825326681, 28.212843909859657, 31.176445484161377, 22.15409941971302, 28.025185279548168, 6.547762099653482, 0.10453412003698759, 0.047672549917479046, 0.046728449015063234, 0.025072249554796144, 0.01109694179831422, 0.11245676170801744, 0.05201183172175661, 0.035044172473135404, 0.028904449682158884, 0.03718516090884805, 0.09068623810890131, 0.03639809103333391, 0.038644482992822304, 0.0171849508114974, 0.045466438023140654, 0.05368599813664332, 0.07982230934430845, 0.01719069874525303, 0.05823809820867609, 0.033750453221728094, 0.032215528553933837, 0.0410061156435404, 0.02165620131563628, 0.04286846473405603, 0.03222155850380659, 0.012185306932224194, 0.021904332825215533, 0.07704787931288593, 0.01564110552862985, 0.0625770386250224, 0.03087375152972527, 0.015257563609338831, 0.057109462286462076, 0.013246442667878, 0.03906989688402973, 0.028583485654962715, 0.015773463856021408, 0.031150327704381198, 0.025061429041670635, 0.02165986195905134, 0.054668924494762905, 0.06862928261398338, 0.023903435612737667, 0.03158107392664533, 0.009269048769056099, 0.06695291944197379, 0.08620207794592716, 0.05836915777763352, 0.01784620439138962, 0.054132938021211885, 0.04266345757059753, 0.06546066826558672, 0.011499453012220329, 0.04326139853219502, 0.0817106595786754, 0.06066781177651137, 0.0164883264733362, 0.08160681085428223, 5.360800791531801, 31.075323410332203, 35.02624310553074, 29.04678326100111, 29.241266325116158, 42.99356058239937, 29.983617290854454, 7.665475448593497, 0.6058732140809298, 0.10508564708288759, 0.30556639248970896, 0.22888744220836088, 4.463484641164541, 5.312847839668393, 7.892442494630814, 6.189971398562193, 4.2821483965963125, 1.2130368151701987, 0.9166328888386488, 5.606566378846765, 21.917683705687523, 40.329246148467064, 50.276473984122276, 53.549029380083084, 53.94302263855934, 51.72207601368427, 55.933454632759094, 56.049006432294846, 55.86216665804386, 54.32894892990589, 51.68708749115467, 49.59790259599686, 45.51048092544079, 42.39429093897343, 48.436418920755386, 56.74412213265896, 54.53213542699814, 56.70344151556492, 54.965882152318954, 50.255198925733566, 53.61023269593716, 56.736625134944916, 54.93172578513622, 52.148530930280685, 47.57644906640053, 44.65115323662758, 42.38853044807911, 40.65306097269058, 40.49234859645367, 45.24226851761341, 50.86015686392784, 53.435673862695694, 54.355201721191406, 54.135049134492874, 53.29941317439079, 52.05575130879879, 52.076300606131554, 48.32845911383629, 45.79998359084129, 59.21136014163494, 51.98969565331936, 51.39439679682255, 47.279358208179474, 42.661636993288994, 38.66835527122021, 39.74430173635483, 37.43538983166218, 38.53890001773834, 37.516644671559334, 39.108941629529, 37.38862194120884, 44.80884097516537, 48.047137409448624, 49.207576140761375, 48.93851637840271, 52.944804802536964, 50.819719433784485, 50.700645223259926, 48.99208590388298, 49.093586057424545, 50.076122134923935, 50.29692068696022, 46.76144979894161, 45.868904292583466, 43.82303707301617, 46.02473773062229, 46.575996950268745, 47.70626910030842, 46.53399780392647, 48.45656543970108, 48.726464956998825, 47.54224330186844, 45.48433072865009, 46.48150362074375, 46.17990620434284, 51.40558339655399, 48.40906038880348, 32.800919115543365, 15.216230303049088, 3.1161823868751526, 1.774202340748161, 4.688367024064064, 2.933450429700315, 7.047904087230563, 9.379637092351913, 6.950920941308141, 6.473183976486325, 2.072964278049767, 0.855847728671506, 0.012508214458648581, 0.1148145277693402, 2.317245095036924, 15.894944183528423, 31.40368089079857, 34.674674570560455, 25.229825377464294, 33.27948063611984, 10.587216094136238, 0.09658285373006947, 0.028687963349511847, 0.01807513468520483, 0.05341925541870296, 0.04055571735079866, 0.103543360310141, 0.03988063755969051, 0.026228400602121837, 0.05259579804260284, 0.04038437771669123, 0.02966681346151745, 0.03321285257698037, 0.035240533616160974, 0.03410516641451977, 0.06825101736467332, 0.038169961189851165, 0.015094127847987693, 0.011222818393434864, 0.053570364107144997, 0.046267987199826166, 0.03509286107146181, 0.029310634527064394, 0.015097609448275762, 0.025745529637788422, 0.09427910117665306, 0.05137080166605301, 0.08470405286061577, 0.28216401231475174, 0.11803040950326249, 0.15661361336242408, 0.10785266305902041, 0.09255691038561054, 0.18159832659875974, 0.1468321811989881, 0.07785414854879491, 0.2309546945616603, 0.11041321355151013, 0.13218653504736722, 0.16353212180547416, 0.23351838433882222, 0.1989904831862077, 0.1714709200314246, 0.10514932335354388, 0.11623962942394428, 0.07753758545732126, 0.12966752256033942, 0.17123951838584617, 0.2209025714546442, 0.15762732771690935, 0.1551771123195067, 0.2028618223266676, 0.20563574769767, 0.19411069893976673, 0.13106458587571979, 0.18801541038556024, 0.21582783985650167, 0.18105719704180956, 0.20956812106305733, 5.026217820122838, 34.008201733231544, 44.501144886016846, 36.41562335193157, 35.19792169332504, 46.23138964176178, 36.47330425679684, 10.925747528672218, 0.9739901579450816, 0.39481193642131984, 0.9883310634177178, 6.2272469233721495, 13.34819259122014, 15.42926112189889, 12.311624363064766, 5.868079271167517, 2.6112583559006453, 0.643299602670595, 0.9175459085963666, 4.748015748336911, 20.78687958419323, 40.90338014066219, 51.564380675554276, 55.12695170938969, 56.29218578338623, 52.15119458734989, 59.041239470243454, 57.45105899870396, 58.22705335915089, 55.414296090602875, 52.87540152668953, 52.969655469059944, 47.172633334994316, 45.15021465718746, 52.29597821831703, 59.877585992217064, 55.51836110651493, 57.52016969025135, 53.53719301521778, 50.27963921427727, 54.89728823304176, 58.207655400037766, 56.7915815860033, 53.92651252448559, 48.49843919277191, 46.6279211640358, 44.76287484169006, 43.01205039024353, 42.53641091287136, 47.58841462433338, 54.249742180109024, 56.016841158270836, 56.888199001550674, 57.27734751999378, 56.31354063749313, 55.34589596092701, 52.20502249896526, 49.95677813887596, 48.0833038687706, 61.70925110578537, 54.73870374262333, 53.96409630775452, 49.5240193605423, 44.94119167327881, 40.1868411898613, 42.9118687659502, 41.354480534791946, 40.71521423757076, 40.69577448070049, 40.6928676366806, 40.29195494949818, 48.71753163635731, 50.08015751838684, 51.28538444638252, 50.7066261023283, 54.349524825811386, 52.71171011030674, 52.20295920968056, 50.02560384571552, 49.504758194088936, 50.602424293756485, 51.92376919090748, 48.93686346709728, 47.365351393818855, 44.1994334757328, 47.09247283637524, 47.3877739906311, 50.382830277085304, 48.159679770469666, 49.98270034790039, 49.71847012639046, 49.4159759581089, 47.47673101723194, 48.80613528192043, 49.235592037439346, 51.898538544774055, 49.217770993709564, 33.55211980640888, 14.263402931392193, 3.011055327951908, 1.8929806421510875, 6.2735075410455465, 10.087450761348009, 8.200475815683603, 10.713296178728342, 13.258749190717936, 18.658351600170135, 8.775862790644169, 2.933633769862354, 0.3462686506099999, 0.3740925982128829, 3.6623363429680467, 21.689621843397617, 36.512096375226974, 40.304714664816856, 31.591322422027588, 37.54213370382786, 11.305114421993494, 0.20964074763469398, 0.11237265411182307, 0.14527067280141637, 0.13479567394824699, 0.07563289313111454, 0.19254424783866853, 0.15577170619508252, 0.11957893773796968, 0.16088857693830505, 0.09752997517352924, 0.10907702118856832, 0.0773411760746967, 0.1378681801725179, 0.08763289413764141, 0.08203798381146044, 0.13550323754316196, 0.11183971786522307, 0.08912380944821052, 0.21868383191758767, 0.0904038360749837, 0.11471297228126787, 0.09281099948566407, 0.13684455072507262, 0.20627294084988534, 0.14216114825103432, 0.09097873335122131], [0.011544616409082664, 0.07197869897936471, 0.048425506975036114, 0.048135204779100604, 0.0260905930554145, 0.032538960222154856, 0.05845240819326136, 0.011397516245779116, 0.01363570097964839, 0.04845246177865192, 0.025568323326297104, 0.08890675351722166, 0.012514223999460228, 0.03966600103012752, 0.09234925746568479, 0.011458872377261287, 0.028054262002115138, 0.016270569212792907, 0.0671758531825617, 0.011178354470757768, 0.0459121867606882, 0.07356161833740771, 0.03280040400568396, 0.012486126288422383, 0.0636764636146836, 0.04787232122907881, 0.027069894022133667, 0.031161849547061138, 0.021823386778123677, 0.0825130548037123, 0.04752187909616623, 0.0241562630617409, 0.08405692235101014, 5.887839635834098, 26.867482401430607, 30.793914310634136, 22.479610852897167, 28.584283478558064, 37.38526672124863, 27.909050211310387, 6.524623716250062, 0.548342876136303, 0.2727518876781687, 0.3032797761261463, 3.5307289799675345, 7.810423420742154, 5.923206238076091, 5.20329924300313, 4.216710207983851, 2.297849510796368, 0.3914343036012724, 0.33052912331186235, 2.510122270323336, 11.026920899748802, 27.16315783560276, 40.26265472173691, 50.630147606134415, 53.88132534921169, 54.96870540082455, 56.628859117627144, 54.54397179186344, 50.82426019012928, 48.050473630428314, 50.438740476965904, 46.607056483626366, 43.35781663656235, 51.881010085344315, 55.41351333260536, 56.37238807976246, 51.71375826001167, 49.79272574186325, 51.26193210482597, 57.45129458606243, 54.972562193870544, 54.36481140553951, 46.92843943834305, 43.748910650610924, 41.57514229416847, 41.49123899638653, 38.783945068717, 37.9658717662096, 40.661827102303505, 50.40270321071148, 49.95042107999325, 53.20195980370045, 50.73503717780113, 54.415295496582985, 49.53384183347225, 51.24747388064861, 45.57380072772503, 42.13113605976105, 54.145692363381386, 51.16481311619282, 52.47522599995136, 48.91284875571728, 46.479413732886314, 41.784894838929176, 37.6521909981966, 37.833266481757164, 38.13452951610088, 37.38359481096268, 36.955958157777786, 41.213409304618835, 50.54860778152943, 50.33614218235016, 50.77121123671532, 47.47631683945656, 46.44376024603844, 49.32916581630707, 48.40497560799122, 49.70273517072201, 48.758159056305885, 46.72676905989647, 43.8524778932333, 40.738841369748116, 38.99354562163353, 40.96077226102352, 42.59802460670471, 38.82307156920433, 40.542821288108826, 40.66013239324093, 42.244377583265305, 41.053757071495056, 42.986534759402275, 43.10756966471672, 46.54610775411129, 47.797335013747215, 45.90021841228008, 38.32823932170868, 16.042929142713547, 2.9307663487270474, 0.7037015771493316, 1.873970974702388, 3.1620530504733324, 2.0024512242525816, 9.147132318466902, 7.837666058912873, 3.6767161963507533, 6.09035974368453, 2.615075963549316, 0.6988986348733306, 0.05767189148173202, 1.3680024747736752, 12.399977222084999, 24.894126690924168, 30.232549533247948, 25.662639252841473, 22.87367630749941, 17.291549742221832, 1.5019260509870946, 0.11881280384841375, 0.08875073181116022, 0.07612626548507251, 0.05855124742083717, 0.01541993902719696, 0.059783527976833284, 0.007090613880791352, 0.023405912797898054, 0.014349031062010908, 0.036569460353348404, 0.011827721627923893, 0.04139862270676531, 0.0180676167292404, 0.06712818503729068, 0.07862362210289575, 0.032963413032121025, 0.05688878838554956, 0.028450526187953074, 0.10297592903953046, 0.04746689708554186, 0.04607283204677515, 0.0322306312591536, 0.024366227771679405, 0.03075534557865467, 0.06224958080565557, 0.029205093705968466, 0.015196802123682573, 0.044177264426252805, 0.020981717098038644, 0.06034525955328718, 0.06627093767747283, 0.012772060945280828, 0.010918826355919009, 0.04079620659467764, 0.02829218155966373, 0.0049428069632995175, 0.02326119956705952, 0.05486603520694189, 0.018591046064102557, 0.05348662016331218, 0.060886734208907, 0.03348712809383869, 0.03829305380349979, 0.025135102041531354, 0.028480074797698762, 0.03522943108691834, 0.052721536412718706, 0.036940036952728406, 0.029141588129277807, 0.029906419549661223, 0.04753801338665653, 0.03259532633819617, 0.0520624053751817, 0.036274144949857146, 0.04896246195130516, 0.1936210150597617, 0.0365417300054105, 0.03555248425982427, 0.2090288171893917, 10.030843298882246, 34.59419868886471, 32.037452682852745, 23.723569102585316, 33.922432735562325, 42.6678154617548, 29.352974630892277, 5.982752367854118, 0.41734039317816496, 0.11643664736766368, 0.3816365293459967, 1.7433810071088374, 1.9519192795269191, 7.515888875350356, 13.65688232704997, 7.896239440888166, 3.8239476084709167, 1.708393672015518, 1.2000001897104084, 4.7161592077463865, 15.463229399174452, 31.649554297327995, 45.33244147896767, 52.86919265985489, 53.41040521860123, 55.876602083444595, 58.770067021250725, 54.65596318244934, 52.465658113360405, 49.97237250208855, 51.132997423410416, 47.08648435771465, 45.24846978485584, 53.16014684736729, 57.064349949359894, 57.62450069189072, 54.16168950498104, 50.693209022283554, 51.337779834866524, 57.46667616069317, 55.48752576112747, 55.80193608999252, 49.846375063061714, 44.74972754716873, 43.68761993944645, 42.44385547935963, 40.266682505607605, 40.43666638433933, 43.579910919070244, 51.2391447275877, 52.5887905061245, 54.44268062710762, 52.389331609010696, 54.10449497401714, 50.25478094816208, 51.65896899998188, 45.18113359808922, 44.77644771337509, 54.67077098786831, 52.60665334761143, 53.92417564988136, 50.55455446243286, 46.82920776307583, 42.84058839082718, 39.91583973169327, 40.4525875300169, 39.91856798529625, 39.20305497944355, 38.77867855131626, 43.564107567071915, 52.092286348342896, 51.42570711672306, 52.70852968096733, 49.07427929341793, 49.01551924645901, 50.36534741520882, 49.23685356974602, 50.68644538521767, 50.3372935205698, 48.82005013525486, 45.460646599531174, 44.14790444076061, 41.25978961586952, 43.173610121011734, 41.966825276613235, 41.418586894869804, 42.815167754888535, 43.23150381445885, 44.70706723630428, 44.05234336853027, 44.9254947155714, 44.80716526508331, 47.09949105978012, 49.57327611744404, 47.09717318415642, 40.14582999050617, 18.404534719884396, 5.439249956980348, 1.1746037774719298, 2.1655826456844807, 5.171033749356866, 3.904709662310779, 3.0801778938621283, 9.124285094439983, 10.600129701197147, 6.153987804427743, 0.7486787543166429, 0.5036409466993064, 0.16965476592304185, 1.3498878967948258, 13.015482444316149, 32.286578714847565, 35.63816986978054, 30.108621083199978, 26.385780349373817, 22.609045207500458, 2.493557296693325, 0.07692088300245814, 0.05087309516966343, 0.055104108760133386, 0.025247734083677642, 0.056285262762685306, 0.04394824136397801, 0.07958843634696677, 0.042934371158480644, 0.01315999081271002, 0.04539583380392287, 0.029836891444574576, 0.07674963242607191, 0.025453188391111325, 0.04184158839052543, 0.07593206770252436, 0.06753260357072577, 0.0374491168622626, 0.04477830014366191, 0.06239504917175509, 0.04373516705527436, 0.022602899734920356, 0.014985959824116435, 0.01822051955969073, 0.017169131933769677, 0.034646448111743666, 0.03895371737598907, 0.11062445104471408, 0.13950094959000126, 0.14911315724020824, 0.11031582893338054, 0.11543106695171446, 0.1083567000750918, 0.1548192635527812, 0.16936998901655897, 0.1622181196580641, 0.09810223782551475, 0.0871812082186807, 0.1313877763459459, 0.13648604886839166, 0.24097484594676644, 0.2956213167635724, 0.12284700729651377, 0.10658272964064963, 0.06023977810400538, 0.22927726269699633, 0.1128523115767166, 0.16629678517347202, 0.16050896840170026, 0.1284423258039169, 0.13695765403099358, 0.19540718640200794, 0.15201590460492298, 0.14228956948500127, 0.14882462506648153, 0.07599301286973059, 0.2798987104324624, 0.17232390004210174, 0.14140764571493492, 0.29386245645582676, 9.928829222917557, 40.34857951104641, 42.315756753087044, 32.72937275469303, 39.450075924396515, 46.66987471282482, 34.64712604880333, 8.433959987014532, 0.7596900884527713, 0.39013260626234114, 1.3809527736157179, 8.087605722248554, 15.269384700804949, 11.799932420253754, 13.65109333768487, 10.22482194006443, 4.853259176015854, 2.087131580337882, 1.066012610681355, 3.6459235986694694, 13.300468102097511, 30.141776204109192, 44.55644331872463, 52.619333267211914, 54.67401221394539, 58.43812823295593, 60.63110075891018, 58.41533325612545, 55.92918746173382, 52.35326774418354, 54.478983879089355, 49.4735998660326, 47.25057855248451, 56.42419829964638, 59.804542511701584, 59.67365473508835, 55.06652355194092, 50.774923637509346, 52.91338808834553, 60.17405368387699, 58.62627513706684, 59.3608745187521, 49.65047277510166, 46.95754587650299, 45.785073190927505, 43.96796889603138, 43.12862053513527, 42.07772992551327, 44.8360551148653, 54.585701152682304, 53.659770637750626, 56.305823251605034, 53.7127435952425, 55.20866632461548, 51.950519755482674, 50.42601116001606, 48.3216954767704, 48.27563434839249, 55.0561349093914, 54.81400430202484, 56.684051156044006, 54.734181985259056, 50.690165385603905, 44.91409532725811, 41.286821365356445, 40.56908927857876, 42.75863438844681, 41.02392867207527, 40.36312513053417, 45.79780250787735, 54.740440249443054, 54.017373248934746, 55.23648843169212, 50.981678143143654, 50.21820031106472, 53.07701110839844, 50.78473851084709, 51.5965573489666, 53.19687947630882, 51.20900094509125, 47.0229821652174, 45.07609583437443, 42.981184646487236, 45.68059399724007, 45.344369038939476, 42.73925542831421, 45.40481619536877, 44.194117560982704, 45.84353685379028, 45.1435574144125, 46.24848872423172, 46.833835914731026, 48.58010821044445, 52.3752723634243, 48.04753638803959, 41.37921720743179, 17.849659994244576, 5.2904124185442924, 1.4326817728579044, 4.022236168384552, 8.386150002479553, 8.684608787298203, 16.71202003955841, 15.148866567760706, 12.895939908921719, 12.327810544520617, 6.588803697377443, 1.5331696369685233, 0.28349115047603846, 2.2776545444503427, 16.910430192947388, 32.26207762956619, 40.54629050195217, 34.295796900987625, 33.52850407361984, 26.284143403172493, 2.6697025448083878, 0.28808246192056686, 0.2242131289676763, 0.14150942384731025, 0.1629790585138835, 0.14250845852075145, 0.12845935067161918, 0.16281084332149476, 0.14324460964417085, 0.0496967020444572, 0.12713022355455905, 0.12919017317472026, 0.16031998791731894, 0.25635544094257057, 0.19494784151902422, 0.18504389561712742, 0.14820689102634788, 0.21215597516857088, 0.220506101322826, 0.27213269902858883, 0.1149198088387493, 0.2069200194091536, 0.14902089344104752, 0.0963548882282339, 0.08335726262885146, 0.12786992214387283, 0.10807703656610101], [0.0168028876214521, 0.03391335834749043, 0.06307373580057174, 0.031195676638162695, 0.03762651984288823, 0.02298259176313877, 0.06951345509150997, 0.04637471916794311, 0.05247928827884607, 0.0803001485473942, 0.023222208983497694, 0.06581652065506205, 0.012367293602437712, 0.013731108701904304, 0.07242302279337309, 0.035611774437711574, 0.04533462517429143, 0.10423643718240783, 0.05771631273091771, 0.035172471252735704, 0.05172518460312858, 0.04570668977976311, 0.037305125370039605, 0.057242050679633394, 0.059261634887661785, 0.026446679221407976, 0.005141258179719443, 0.031550875937682576, 0.05340647934644949, 0.017618830752326176, 0.09971613442758098, 0.06892977820825763, 0.009604281513020396, 0.42552019644062966, 9.22262191772461, 32.26506806910038, 25.677766241133213, 19.63697388768196, 30.00150103121996, 38.449479416012764, 29.29022289812565, 6.571234865114093, 0.8918824419379234, 0.07884025500970893, 0.6590830651111901, 0.7255810999777168, 7.050484623759985, 15.650888029485941, 12.286372818052769, 3.88618684373796, 0.7732575573027134, 0.7752639683894813, 0.6257754180114716, 1.0276778927072883, 5.750414784997702, 18.224128000438213, 35.99636524915695, 47.740250676870346, 56.73668213188648, 54.88328218460083, 51.808525174856186, 52.52958208322525, 53.55692155659199, 51.8358039110899, 46.844821125268936, 46.37530691921711, 56.54865302145481, 55.30059479176998, 56.63425102829933, 47.877400517463684, 50.4967937618494, 50.042197555303574, 54.68887321650982, 53.42783488333225, 54.271807596087456, 50.350957587361336, 45.03444626927376, 40.697370395064354, 40.344802513718605, 39.26788330078125, 39.22447822988033, 39.57188978791237, 46.320798844099045, 49.53090079128742, 53.03042560815811, 52.06189177930355, 54.00101512670517, 51.312279403209686, 53.16128298640251, 46.74216203391552, 41.39223150908947, 50.970419347286224, 49.87917110323906, 54.268281385302544, 49.95637156069279, 52.0203448086977, 48.21837142109871, 41.3807675242424, 36.725815907120705, 35.86832731962204, 38.12621936202049, 36.54181458055973, 44.80786442756653, 50.19106216728687, 51.474640890955925, 53.4880730509758, 48.332414701581, 47.43233419954777, 45.54177224636078, 46.63853779435158, 45.387998297810555, 46.55178464949131, 44.344646483659744, 42.27634906768799, 42.01543226838112, 46.16069443523884, 48.151628002524376, 46.79518438875675, 44.30699050426483, 40.861012414097786, 39.324260875582695, 41.77796021103859, 45.369595885276794, 45.582886040210724, 48.649674877524376, 48.00695076584816, 47.20315329730511, 39.56532374024391, 18.8186763972044, 2.1800843300297856, 0.513822203502059, 1.71611568890512, 1.2162954965606332, 4.170032562687993, 1.619681732263416, 2.5518889166414738, 11.894165463745594, 9.964576754719019, 3.1618822971358895, 0.4143126681447029, 0.09119152935454622, 1.0835593566298485, 9.2830253764987, 25.922685898840427, 29.63575355708599, 26.312771067023277, 20.907042436301708, 22.391670271754265, 7.7400008495897055, 0.0626738221035339, 0.10177954987739213, 0.1225159723253455, 0.05686357391823549, 0.0630590041691903, 0.045502127904910594, 0.018758392943709623, 0.05805052409414202, 0.006181905537232524, 0.06620395884965546, 0.0645539716060739, 0.01671155150688719, 0.024954437321866862, 0.06058268372726161, 0.028818026585213374, 0.026651714215404354, 0.06869348580949008, 0.12063326983479783, 0.062155970008461736, 0.04070460330694914, 0.055512920807814226, 0.015216819701890927, 0.028203463371028192, 0.008953493143053493, 0.09063813209650107, 0.04253671730111819, 0.06431255096686073, 0.03662372248072643, 0.015338568100560224, 0.011872917493747082, 0.03985149713116698, 0.02418127900455147, 0.055123927813838236, 0.040063265259959735, 0.06759515919839032, 0.08202012773836032, 0.06946264766156673, 0.035651746511575766, 0.03218648831534665, 0.009003486065921606, 0.06347649192321114, 0.01532649799628416, 0.11242179913097061, 0.0453358274535276, 0.04727854742668569, 0.04308074865548406, 0.033937370535568334, 0.044008767217746936, 0.011515214373503113, 0.03751864867808763, 0.012994797089049825, 0.030824827299511526, 0.042698041652329266, 0.016257292190857697, 0.07558817873359658, 0.11330800509313121, 0.03297451927210204, 0.056165235218941234, 0.013385916336119408, 0.031339742345153354, 0.9792206366546452, 15.417489353567362, 37.63642944395542, 27.245294228196144, 23.32523837685585, 35.49311265349388, 47.078348994255066, 30.411253944039345, 6.476033823564649, 0.7032888836693019, 0.1553705011610873, 0.603271956788376, 0.15831115742912516, 8.286020625382662, 8.340062275528908, 8.241748251020908, 7.466807384043932, 2.839684998616576, 1.7976716626435518, 1.991405573207885, 2.8267946653068066, 9.27360663190484, 22.43854645639658, 38.56332890689373, 50.47511212527752, 58.291288912296295, 56.37898452579975, 53.39062348008156, 54.39220413565636, 54.00784716010094, 53.16622652113438, 47.644731402397156, 47.73910313844681, 57.36820824444294, 57.790711373090744, 58.28905463218689, 49.11350838840008, 50.60627728700638, 52.00686313211918, 55.527917593717575, 57.04125478863716, 56.2854715436697, 52.265256866812706, 46.51425026357174, 43.257578015327454, 42.578037679195404, 40.373091995716095, 39.366742596030235, 41.53090126812458, 48.14739502966404, 51.91439129412174, 54.40505884587765, 53.53998966515064, 54.85575646162033, 52.231890857219696, 53.58153663575649, 47.60896772146225, 43.92844721674919, 53.35200995206833, 52.25349649786949, 54.88032974302769, 52.09918297827244, 53.65974023938179, 48.38984102010727, 41.811048835515976, 38.46896097064018, 36.80383712053299, 38.781733587384224, 37.59281538426876, 47.12165907025337, 51.464419439435005, 52.034350857138634, 53.58834207057953, 49.95333932340145, 48.58038179576397, 47.95071378350258, 48.95808532834053, 47.49064587056637, 47.16985568404198, 47.06865191459656, 44.67061959207058, 42.2477176040411, 46.61572001874447, 50.31625024974346, 49.134601056575775, 46.03479579091072, 42.229645773768425, 41.46082162857056, 44.51626807451248, 46.814369559288025, 46.018069088459015, 48.54904867708683, 47.5493299216032, 49.610601514577866, 40.569970831274986, 23.346570432186127, 3.712956039234996, 1.230679030995816, 3.1039278069511056, 3.5494598373770714, 4.316500928252935, 3.6610679235309362, 5.407132655382156, 5.695825964212418, 6.605070624500513, 4.939658939838409, 0.748539111809805, 0.06020399545377586, 0.7852475170511752, 9.352736435830593, 28.88618677854538, 30.50705250352621, 29.1873662173748, 25.95682706683874, 26.546658016741276, 11.287322826683521, 0.1231730030849576, 0.10427303990582004, 0.006496695823443588, 0.030607556145696435, 0.03562345584214199, 0.05705694049538579, 0.02160150503186742, 0.030555045486835297, 0.1062568451743573, 0.039441783374059014, 0.03705172646732535, 0.018559176387498155, 0.040426713530905545, 0.03196594429027755, 0.06846635893452913, 0.026221871557936538, 0.04378484271001071, 0.0391684132773662, 0.03387566837773193, 0.03299632357084192, 0.01616660360014066, 0.021776427383883856, 0.03285238773969468, 0.0761028729903046, 0.05368738595279865, 0.03700391360325739, 0.0582136407319922, 0.09093365530134179, 0.08289674515253864, 0.21814016421558335, 0.09603629165212624, 0.11255303310463205, 0.13852607924491167, 0.16119343636091799, 0.24842437589541078, 0.1858002776862122, 0.15249077521730214, 0.15065145125845447, 0.1669707740074955, 0.11704042903147638, 0.2114936083671637, 0.20643925614422187, 0.21264782611979172, 0.12538740847958252, 0.20016931055579334, 0.20767971145687625, 0.1713438198203221, 0.236206843983382, 0.10796353250043467, 0.21660577389411628, 0.09117028166656382, 0.1933856651885435, 0.07134861560189165, 0.06959769627428614, 0.2537562616635114, 0.2339181792922318, 0.25991976843215525, 0.16985970258247107, 0.14740180922672153, 0.10788842715555802, 0.7849685882683843, 15.593944285064936, 44.00375157594681, 36.970963552594185, 29.418796598911285, 40.52809327840805, 49.50907476246357, 35.090235471725464, 9.327417444437742, 1.4717215904965997, 0.46983062813524157, 2.769355047494173, 3.7685470562428236, 14.859423749148846, 29.17872928082943, 22.50502198934555, 9.103459361940622, 2.107559759169817, 2.3906412441283464, 2.1844479208812118, 2.2340471344068646, 7.582584796473384, 20.968361645936966, 36.997923105955124, 50.79130835831165, 59.54864144325256, 58.30546595156193, 54.14012186229229, 56.43124312162399, 56.20016612112522, 56.85418702661991, 50.09844593703747, 50.07067322731018, 59.440012872219086, 60.528992637991905, 60.12845993041992, 50.608135387301445, 49.969705045223236, 51.41770474612713, 56.236777156591415, 57.624869272112846, 57.477957755327225, 54.97388832271099, 47.92180493474007, 45.343734472990036, 42.90907971560955, 42.48881086707115, 41.8042965978384, 43.17179001867771, 48.2644135504961, 54.050370678305626, 55.891941860318184, 55.23943707346916, 56.72139175236225, 55.61474673449993, 52.28182017803192, 49.00660492479801, 45.69918639957905, 54.149104580283165, 52.54225440323353, 57.051274850964546, 53.75929109752178, 56.55390813946724, 53.14044110476971, 45.105909034609795, 39.5280097424984, 37.47474431991577, 40.44702082872391, 40.05628399550915, 48.4285419434309, 53.44174973666668, 54.98122572898865, 55.9115070104599, 51.97246357798576, 51.73029877245426, 50.40900707244873, 51.93600453436375, 48.09981398284435, 49.60978835821152, 48.2989726960659, 46.18116393685341, 46.29963777959347, 50.7479564845562, 53.03181633353233, 51.82127729058266, 48.945929780602455, 45.74340082705021, 42.952226400375366, 45.94337269663811, 49.709943383932114, 49.15962651371956, 51.50688216090202, 51.086202934384346, 50.289917662739754, 42.133362740278244, 21.842301450669765, 3.1323438696563244, 1.2314805504865944, 4.261126974597573, 5.1129871141165495, 8.538599722087383, 5.734839895740151, 9.776795580983162, 20.5082880333066, 16.986078433692455, 6.698225475847721, 1.293129629921168, 0.2629603474633768, 1.607052634935826, 12.581658773124218, 34.5610074698925, 37.19194069504738, 35.924575701355934, 32.2036861628294, 33.25561411678791, 11.54265297576785, 0.28362604323774576, 0.23775367269990966, 0.17900291742989793, 0.09194782236590981, 0.13261384883662686, 0.24254597257822752, 0.0859613623470068, 0.06591746016056277, 0.2056817608536221, 0.2059533423744142, 0.09395936169312336, 0.10457326090545394, 0.08545181117369793, 0.11402316085877828, 0.15471913298824802, 0.11625568207819015, 0.19211406935937703, 0.21584922855254263, 0.18020423187408596, 0.11968716513365507, 0.13494465267285705, 0.08024664712138474, 0.14732749055838212, 0.13349549059057608, 0.21732582041295245, 0.14554969064192846, 0.11916760238818824], [0.03699463304656092, 0.027515796755324118, 0.048582014787825756, 0.03687919568619691, 0.029844834280083887, 0.038588632669416256, 0.10361631342675537, 0.040543089708080515, 0.03404854054679163, 0.01734178702463396, 0.015681675031373743, 0.04591431672452018, 0.022980435824138112, 0.00855670388773433, 0.051575990655692294, 0.09444893425097689, 0.031906164294923656, 0.01594209094037069, 0.05967274759314023, 0.06672957009868696, 0.026155850100622047, 0.04954789030307438, 0.05180473170184996, 0.11323373095365241, 0.06932722797500901, 0.013770946261502104, 0.039094781095627695, 0.03410807563341223, 0.18246540741529316, 0.09381016774568707, 0.025660106584837195, 0.08098431964754127, 0.058659641799749807, 0.054672149126417935, 1.3694317918270826, 14.564841706305742, 32.482359409332275, 22.41548739373684, 20.15090961009264, 27.41145931184292, 38.05655010044575, 29.243931882083416, 10.337836425751448, 0.7215955294668674, 0.20737712300615385, 0.2695968101033941, 7.797727826982737, 8.842674605548382, 3.076968491077423, 5.397798456251621, 5.326765067875385, 2.6243377290666103, 1.2042514490894973, 0.39428471471183, 0.5429075646679848, 2.8684176318347454, 9.733731541782618, 28.596205338835716, 48.69693674147129, 58.59354369342327, 56.33562505245209, 53.21744777262211, 53.12847934663296, 51.44607402384281, 47.848913446068764, 48.35801772773266, 54.822230860590935, 57.48381324112415, 58.89282323420048, 53.58177222311497, 52.86682918667793, 54.36077982187271, 56.007330268621445, 54.556047543883324, 54.10142853856087, 51.42864815890789, 50.45664131641388, 43.618843629956245, 40.70441521704197, 39.001798778772354, 40.04228554666042, 38.817725256085396, 41.06982260942459, 46.634247824549675, 53.45716550946236, 55.24816520512104, 54.80337627232075, 54.06678959727287, 58.72673034667969, 46.55132867395878, 38.871644362807274, 52.66904219985008, 49.37328904867172, 52.574332281947136, 53.90507027506828, 53.69112275540829, 50.97173407673836, 44.44435313344002, 38.616567850112915, 37.3899594694376, 37.46889263391495, 37.81575322151184, 47.15345956385136, 51.8664188683033, 52.666325345635414, 50.59288300573826, 52.12962694466114, 47.11006209254265, 43.53474274277687, 44.4367079436779, 43.17113645374775, 43.827357441186905, 40.812219232320786, 41.071908697485924, 48.19487348198891, 49.85460922122002, 50.33642716705799, 49.32579159736633, 48.45247305929661, 45.2082185447216, 44.23188753426075, 43.96766871213913, 47.607702389359474, 48.496014922857285, 49.94014263153076, 48.24653930962086, 38.26132491230965, 22.79879942536354, 2.9153816867619753, 0.35974516184069216, 1.1055074539035559, 2.3217720771208405, 2.2248525777831674, 1.9576336978934705, 2.715051448903978, 1.88993961783126, 2.4296896113082767, 7.292472738772631, 2.93378789909184, 0.1747251782217063, 0.44999213016126305, 7.8476799465715885, 19.208672270178795, 40.176163762807846, 32.77612544596195, 21.131950467824936, 30.43917864561081, 17.354314774274826, 1.6250175959430635, 0.04387231594591867, 0.052001950025442056, 0.11940146054257639, 0.0778643976082094, 0.014617924152844353, 0.022068416110414546, 0.03285589067672845, 0.05210883042309433, 0.030893149414623622, 0.01579868945555063, 0.10441004036692902, 0.03185357571055647, 0.02172979453462176, 0.008679020957060857, 0.020726255024783313, 0.02303354391187895, 0.016448074238724075, 0.035031674706260674, 0.027321786365064327, 0.04429054584761616, 0.06239536829525605, 0.005244864314590814, 0.052270147352828644, 0.037690492972615175, 0.05654924098053016, 0.05694413775927387, 0.0075793459564010845, 0.044774463240173645, 0.022983228154771496, 0.02208371734013781, 0.06230081125977449, 0.0394355901516974, 0.0374162063235417, 0.05255440475593787, 0.03707637319166679, 0.005981784024697845, 0.01983339385333238, 0.020347592726466246, 0.06074631986848544, 0.018392272941127885, 0.061138459568610415, 0.056523659150116146, 0.06164642996736802, 0.028430167221813463, 0.021271217774483375, 0.01464014312659856, 0.023755879956297576, 0.0732855022943113, 0.021743665274698287, 0.027159001838299446, 0.015426353966176976, 0.010446517080708873, 0.010473082256794441, 0.0027396701534598833, 0.008434306109847967, 0.028812931741413195, 0.034987056787940674, 0.04269230856152717, 0.0801948452135548, 0.06992219292442314, 0.05726303861592896, 2.441991213709116, 20.936317965388298, 37.898900359869, 26.367949806153774, 26.84164948761463, 34.46662053465843, 46.37742720544338, 28.71662087738514, 8.45748832449317, 0.5815957824233919, 0.3642120596487075, 0.10500125004909933, 3.487821682356298, 3.9744043350219727, 5.2108741365373135, 6.358724143356085, 6.564261764287949, 4.739071503281593, 2.0480777509510517, 2.02796115539968, 1.3810953847132623, 4.529824331402779, 13.75410296022892, 32.630992233753204, 50.93282036483288, 60.62964163720608, 55.86714059114456, 55.332634672522545, 54.64147076010704, 52.79685594141483, 49.96361397206783, 50.692308470606804, 57.43698835372925, 58.11373583972454, 60.442991852760315, 53.75908590853214, 53.03412660956383, 51.25128887593746, 55.2675973623991, 56.406890228390694, 55.28168700635433, 51.8033080548048, 51.06205143034458, 43.8178351521492, 42.57987678050995, 40.33158302307129, 43.345482498407364, 39.58247981965542, 42.53191575407982, 50.51336847245693, 54.61761564016342, 55.48949785530567, 56.33699677884579, 56.41841500997543, 57.223789393901825, 46.96625500917435, 42.70365513861179, 52.56268210709095, 49.23442170023918, 54.62125584483147, 55.238848105072975, 55.49747362732887, 52.008516043424606, 46.81933209300041, 40.555178225040436, 40.20262934267521, 37.7747268229723, 40.909083634614944, 48.79336416721344, 54.35365900397301, 54.52534519135952, 52.20043234527111, 53.07024747133255, 50.2348206192255, 45.77811576426029, 45.88913060724735, 44.914064928889275, 46.356763914227486, 41.9502467662096, 43.07814784348011, 50.18224284052849, 52.40676887333393, 51.834986954927444, 51.6305161267519, 50.84394693374634, 46.28290727734566, 45.56232914328575, 45.79847127199173, 47.53199905157089, 50.7671682536602, 49.720989391207695, 51.39934413135052, 40.27223400771618, 27.57204059511423, 5.465479949489236, 1.0176922660320997, 2.2046295879408717, 3.321389425545931, 3.538103671744466, 4.051099894568324, 4.0754808112978935, 3.8372300332412124, 4.3438138626515865, 1.4865747559815645, 1.1679563904181123, 0.15306022512959316, 0.3528707369696349, 7.858527889475226, 22.414394952356815, 44.156944155693054, 32.84155413508415, 22.6995487511158, 32.26540245115757, 22.31918156147003, 3.152959900908172, 0.06450925720855594, 0.015697826020186767, 0.02296023456437979, 0.07538474121247418, 0.02745789253822295, 0.06996778305619955, 0.01581349530169973, 0.003907032269125921, 0.03295618822448887, 0.06031253455148544, 0.09311796660767868, 0.041570867761038244, 0.04555268300464377, 0.025438794436922763, 0.05280480909277685, 0.034316348246647976, 0.026966230834659655, 0.0026200320053249015, 0.014950423010304803, 0.071707740862621, 0.017214915023942012, 0.021904108325543348, 0.09236824902473018, 0.0412595702073304, 0.040592527875560336, 0.06106532091507688, 0.033434699071221985, 0.1044022775022313, 0.13597518409369513, 0.11912760062841699, 0.09417413923074491, 0.13948996580438688, 0.10445504420204088, 0.12260378323844634, 0.23107377957785502, 0.08676665194798261, 0.10442317638080567, 0.2383103725151159, 0.1224290148820728, 0.1737197017064318, 0.10937149796518497, 0.12081712950021029, 0.17253230995265767, 0.1037811666901689, 0.0770726076734718, 0.09872241353150457, 0.1595046347938478, 0.1300180537509732, 0.14916148589691147, 0.16945411887718365, 0.21735114249167964, 0.1356689294334501, 0.13191167323384434, 0.14421830739593133, 0.08190980748622678, 0.3144099726341665, 0.11355687689501792, 0.15774149971548468, 0.25914463971275836, 0.12527651677373797, 0.18544841062976047, 2.573089641518891, 22.876444458961487, 46.18564009666443, 33.23057346045971, 31.94269336760044, 36.99077948927879, 46.58407911658287, 36.32105402648449, 11.428239215165377, 1.38134581502527, 0.6035409111063927, 0.5126185587141663, 14.154552072286606, 16.59683682024479, 8.77763444557786, 10.929375384002924, 13.362740110605955, 7.305113710463047, 3.8738441560417414, 2.0721166860312223, 1.5523668006062508, 5.062319207936525, 13.457571621984243, 32.36349418759346, 51.81479103863239, 62.45990842580795, 60.20644694566727, 58.006095215678215, 57.25306302309036, 54.37814109027386, 51.73489652574062, 53.60325627028942, 59.23469468951225, 61.49454362690449, 62.34822861850262, 55.30068598687649, 53.157281801104546, 52.83904127776623, 55.74852995574474, 57.23247952759266, 58.091700822114944, 54.749711751937866, 55.84309548139572, 46.81182749569416, 44.266355484724045, 42.24820777773857, 45.05722604691982, 42.87922091782093, 43.300823494791985, 50.11731192469597, 56.66944094002247, 61.96968913078308, 58.88563022017479, 60.26631273329258, 58.72526742517948, 49.63229455053806, 45.732009038329124, 55.36842115223408, 51.979538798332214, 53.027461767196655, 58.47786270081997, 58.06134045124054, 54.73213389515877, 50.33357352018356, 43.48757587373257, 40.9126478433609, 40.300778076052666, 41.94051928818226, 52.27553531527519, 55.577843114733696, 56.34667105972767, 54.310086742043495, 55.97089022397995, 51.948179081082344, 47.49621257185936, 47.84103646874428, 47.6016379147768, 48.50935980677605, 45.280380472540855, 44.53001193702221, 52.850410267710686, 54.041099175810814, 54.52913358807564, 52.802114859223366, 51.59242697060108, 48.382663205266, 48.058491200208664, 48.11367183923721, 49.23260159790516, 51.889491230249405, 51.75976239144802, 51.075989082455635, 40.51749184727669, 26.198129318654537, 3.9721175702288747, 0.7940920174587518, 2.0954749826341867, 5.924623562023044, 5.965207759290934, 6.094088768586516, 7.105484772473574, 7.436631778255105, 8.762170225381851, 14.046072643250227, 6.496750311926007, 0.5176366050727665, 0.7137152866926044, 9.722137413918972, 24.330637827515602, 50.57749763131142, 40.622107833623886, 29.34658147394657, 39.98488202691078, 24.466754123568535, 2.8210028260946274, 0.1650379245984368, 0.11461845977464691, 0.20299845171393827, 0.16257224284345284, 0.15052212460432202, 0.19470505532808602, 0.17494207830168307, 0.14669252384919673, 0.09143424875219353, 0.14514023292576894, 0.22119333007140085, 0.19306385511299595, 0.16227462678216398, 0.12316100997850299, 0.12300436486839317, 0.13347626896575093, 0.08924975190893747, 0.13603507541120052, 0.16501720383530483, 0.26430835481733084, 0.0807302157045342, 0.10684268170734867, 0.16953164362348616, 0.11447893601143733, 0.13948459265520796, 0.18004354205913842, 0.07069228988257237], [0.05053707667684648, 0.1123390496650245, 0.06484046287368983, 0.029654686768481042, 0.08597812004154548, 0.028519360384962056, 0.042385393389849924, 0.030865838380123023, 0.019329247370478697, 0.022534618437930476, 0.032115872963913716, 0.038251371079240926, 0.06145534178358503, 0.03570129971194547, 0.02864218953618547, 0.020336577399575617, 0.0346148363314569, 0.0210781332134502, 0.017036597346304916, 0.042062076754518785, 0.019973802627646364, 0.014364773869601777, 0.03056023495446425, 0.05831528898852412, 0.05183672939892858, 0.06770239953766577, 0.08006947420653887, 0.04615084661054425, 0.10880014815484174, 0.009090624407690484, 0.026885073275479954, 0.039056779423845, 0.031530285050394014, 0.05444822832942009, 0.13400970987277105, 1.8414033972658217, 20.116141475737095, 29.535744823515415, 21.823918037116528, 17.163859494030476, 28.847523853182793, 36.50080718100071, 30.375279374420643, 7.932830527424812, 1.1260278965346515, 0.21987776941386983, 2.9503516852855682, 1.3838646048679948, 3.5519995260983706, 6.159176900982857, 4.79524246416986, 4.0592024847865105, 1.1995868431404233, 3.186316885985434, 0.4474172933259979, 0.9292828850448132, 0.6325142970308661, 5.288594691082835, 23.40612083673477, 50.79259268939495, 58.08409363031387, 55.04862651228905, 56.24063014984131, 52.85641014575958, 50.440009608864784, 49.633624479174614, 54.820197969675064, 56.2816147506237, 58.19138467311859, 55.544526502490044, 53.84789474308491, 53.50174091756344, 53.38796742260456, 55.65343625843525, 56.18278965353966, 53.82899075746536, 53.42229098081589, 48.04464854300022, 40.244309306144714, 39.47807662189007, 42.105400040745735, 40.290503427386284, 40.015094205737114, 39.50198873877525, 46.59481734037399, 53.12065936625004, 55.29499389231205, 53.23218338191509, 57.03560829162598, 53.6647217720747, 38.77984128892422, 54.035646468400955, 47.8473175317049, 53.53672184050083, 56.17808170616627, 54.93300251662731, 51.51695542037487, 47.09105171263218, 37.64025203883648, 38.070860132575035, 39.961387887597084, 38.34236316382885, 48.81573736667633, 51.90152898430824, 53.125587701797485, 51.81703671813011, 51.9790980219841, 48.43566656112671, 45.78445002436638, 40.62540985643864, 40.576411485672, 41.85125067830086, 44.19196307659149, 44.80637490749359, 48.91061447560787, 47.30844184756279, 49.90428015589714, 48.03374692797661, 45.12157939374447, 50.64379267394543, 45.168601870536804, 47.38113954663277, 46.58768892288208, 50.36481164395809, 47.81401991844177, 37.61491119861603, 20.10106958448887, 3.870069058611989, 0.3214507276425138, 0.5441029567737132, 2.462497763335705, 3.455166472122073, 2.4176174215972424, 3.0053304601460695, 2.7344451332464814, 4.3530236184597015, 2.3203673399984837, 0.6094660994131118, 0.15536248596617952, 0.7764906494412571, 5.753543917089701, 24.342447593808174, 29.102258384227753, 35.56997872889042, 44.534518495202065, 30.055982507765293, 22.98993866890669, 5.849620336666703, 0.14922054600901902, 0.03613019798649475, 0.03196312412910629, 0.03457097540376708, 0.009251919072994497, 0.04645105276722461, 0.05175464415515307, 0.023750313848722726, 0.09085801561013795, 0.013332841645024018, 0.03398822249437217, 0.04286370014597196, 0.023817799192329403, 0.021890744101256132, 0.10227367922198027, 0.04202893243927974, 0.045711677012150176, 0.058092221661354415, 0.09559324433212169, 0.03507021443510894, 0.029499587180907838, 0.022766843867429998, 0.05655388311424758, 0.029750050889560953, 0.043595628449111246, 0.06472223132732324, 0.024397704110015184, 0.051384241960477084, 0.015181812595983502, 0.02482003066688776, 0.11085124395322055, 0.0343860359134851, 0.09187339237541892, 0.03350680985022336, 0.026169058473897167, 0.05758097468060441, 0.02147270344721619, 0.08090087256277911, 0.05423886475909967, 0.06711084846756421, 0.030376803879335057, 0.04715775176009629, 0.030120653464109637, 0.05416683561634272, 0.04335801502747927, 0.028998257148487028, 0.0659363107115496, 0.024410431942669675, 0.06015257204126101, 0.04605989270203281, 0.012061453617207007, 0.017601685285626445, 0.022900855328771286, 0.08230008068494499, 0.04098664168850519, 0.05139794942806475, 0.05843890852702316, 0.004261486637915368, 0.03568481661204714, 0.01888361181045184, 0.014121228832664201, 0.0673890944744926, 0.16678632062394172, 3.35730058606714, 28.590220659971237, 34.94264379143715, 25.734012722969055, 21.61422248929739, 31.126776449382305, 47.31683939695358, 32.546613961458206, 7.487559020519257, 0.8599312626756728, 0.11957120455917902, 1.2589131784625351, 1.3187062949873507, 3.116872999817133, 5.559156322851777, 7.88795018568635, 8.755955658853054, 4.3659519497305155, 3.306954950094223, 2.0323727186769247, 1.8707270175218582, 1.4892873354256153, 7.6988082099705935, 28.331540040671825, 53.96544523537159, 59.71192628145218, 56.215528696775436, 56.66111558675766, 53.57583314180374, 52.12228573858738, 51.558403596282005, 55.4543649405241, 57.803197503089905, 59.858704805374146, 54.90637354552746, 53.89832943677902, 54.37770411372185, 54.26628649234772, 56.16949036717415, 57.29933314025402, 54.76041957736015, 53.3385244756937, 49.25457201898098, 41.84690371155739, 41.534214690327644, 44.70549792051315, 42.43282087147236, 41.46571196615696, 41.94689154624939, 49.419004395604134, 57.971494272351265, 57.76657126843929, 57.13493876159191, 58.4216333180666, 54.22344759106636, 43.538090363144875, 55.07922627031803, 49.47936035692692, 54.240216091275215, 55.22886224091053, 55.414090901613235, 52.167404517531395, 48.23722220957279, 40.763452649116516, 39.343590438365936, 40.826426669955254, 40.41359022259712, 50.87227821350098, 54.40082587301731, 53.586658760905266, 51.82928346097469, 53.94511632621288, 51.34382151067257, 46.456793546676636, 43.30266259610653, 41.66351795196533, 43.66188012063503, 45.90859696269035, 47.038504332304, 50.2992157638073, 50.53959086537361, 50.97930707037449, 49.85174797475338, 47.88054294884205, 51.204976961016655, 46.55454710125923, 49.28226873278618, 47.147524282336235, 51.887492537498474, 47.45331667363644, 39.61989261209965, 23.056193813681602, 7.413436397910118, 1.0618165670894086, 2.0864058192819357, 3.7370481714606285, 3.6037007393315434, 2.8892027540132403, 3.9673424139618874, 5.597114386036992, 4.308025008067489, 2.114199665375054, 0.7904979446902871, 0.20647591823944822, 0.630024183774367, 5.367191098630428, 26.122766062617302, 33.15894730389118, 43.18203806877136, 45.95834009349346, 31.293386109173298, 29.934189543128014, 9.427305534482002, 0.19955016643507406, 0.061764542770106345, 0.025668359267001506, 0.041624747682362795, 0.027354457561159506, 0.029513684276025742, 0.044694648968288675, 0.0442201791156549, 0.04922680753224995, 0.047221264758263715, 0.035128061135765165, 0.021569485070358496, 0.005337494549166877, 0.03602410426537972, 0.090469323185971, 0.07496332749724388, 0.022658909620076884, 0.03705207898747176, 0.008616264949523611, 0.04756369540700689, 0.003944534382753773, 0.030315075746329967, 0.06465211321483366, 0.030876386153977364, 0.009580261903465725, 0.04894737408903893, 0.021728972606069874, 0.0727090539294295, 0.1624570763669908, 0.1890596715384163, 0.22040773706976324, 0.20344148419098929, 0.16448932903585956, 0.2516929426928982, 0.11896535230334848, 0.14220842305803671, 0.13955220230855048, 0.12580795388203114, 0.15295724471798167, 0.11740375484805554, 0.12179415207356215, 0.1262294640764594, 0.16148072172654793, 0.10889933619182557, 0.1216841880523134, 0.1425581972580403, 0.1512949526659213, 0.1302977098384872, 0.24156566971214488, 0.12972300552064553, 0.15384329482913017, 0.13914445153204724, 0.1419622081448324, 0.16840421740198508, 0.19776273344177753, 0.1421283750096336, 0.19398987729800865, 0.12959786457940936, 0.13822586566675454, 0.08371698160772212, 0.09607650863472372, 0.2163046845817007, 0.2327281900215894, 3.4025525953620672, 30.646155439317226, 41.836165487766266, 33.85554112493992, 26.183703392744064, 34.77053962647915, 48.786079958081245, 38.1494627147913, 10.53937191143632, 1.6711284779012203, 0.5006947391666472, 4.8067753203213215, 4.078248962759972, 6.470741657540202, 15.073152780532837, 11.562720648944378, 7.384209791198373, 5.95635280944407, 6.4403304643929005, 1.3188345381058753, 2.9124375572428107, 1.1767190764658153, 7.599053587764502, 26.500385999679565, 56.12442098557949, 62.48954303562641, 59.962842017412186, 58.61833356320858, 57.87969119846821, 55.12482762336731, 54.30175758898258, 58.17331664264202, 60.08560582995415, 61.13317921757698, 57.41535611450672, 54.07668426632881, 53.55784110724926, 54.935920760035515, 58.66192862391472, 59.79533560574055, 58.36617909371853, 55.49328625202179, 51.965304762125015, 42.82519541680813, 43.69099035859108, 47.13003762066364, 43.63297887146473, 43.9597537368536, 43.5563787817955, 50.504530146718025, 58.91189441084862, 60.348631516098976, 58.98295819759369, 61.77646189928055, 55.251847207546234, 48.49253050982952, 54.932740330696106, 51.11229233443737, 54.734531566500664, 58.41301158070564, 57.447749376297, 53.84308040142059, 50.809627175331116, 41.10030457377434, 41.21700011193752, 43.88475336134434, 42.71837554872036, 53.85722704231739, 55.835518687963486, 54.74886439740658, 53.69614988565445, 55.350068137049675, 52.528138160705566, 49.68303322792053, 45.863295793533325, 44.84069086611271, 45.71642607450485, 48.14731143414974, 49.931038320064545, 52.575848400592804, 51.666082218289375, 52.08659805357456, 52.32498586177826, 50.313928574323654, 52.29825049638748, 47.95604109764099, 51.507011353969574, 49.7104449570179, 53.55621859431267, 47.1761329472065, 39.998717084527016, 21.365634128451347, 5.744777312502265, 1.1033047595992684, 2.4352330388501287, 7.1115815453231335, 6.77169643342495, 7.421182757243514, 9.647934045642614, 8.977969195693731, 10.904755555093288, 7.983151227235794, 3.093289090320468, 0.46139208250679076, 1.1475786776281893, 8.370933718979359, 30.58042846620083, 35.527793392539024, 46.609294563531876, 51.2280835211277, 39.46786276996136, 33.05975362658501, 9.013290200382471, 0.27060586377047, 0.24557405384257436, 0.07201806249213405, 0.09737328553455882, 0.138444428157527, 0.15630955545930192, 0.15341761376475915, 0.11427083038142882, 0.16300317831337452, 0.11102595293777995, 0.11597250078921206, 0.12528650608146563, 0.17959985649213195, 0.22719513770425692, 0.2462800292414613, 0.13765914685791358, 0.11326353560434654, 0.2061701237107627, 0.25976035511121154, 0.13574952667113394, 0.09103976015467197, 0.20171232463326305, 0.12691601004917175, 0.18051962979370728, 0.12398797029163688, 0.14832621352979913, 0.11380594165530056, 0.23149487416958436], [0.04617656202754006, 0.02976612580823712, 0.053336394630605355, 0.0872279041504953, 0.09109771446674131, 0.05796311023004819, 0.07074418826960027, 0.014372273271874292, 0.01698046315141255, 0.04934751785185654, 0.027954354081884958, 0.025087227950280067, 0.022337945592880715, 0.09999645844800398, 0.022637209222011734, 0.04407312997500412, 0.04453296467545442, 0.04586019189446233, 0.05941138544585556, 0.04745052159705665, 0.013561155956267612, 0.01624497068405617, 0.05230904702330008, 0.03376478038262576, 0.013095280173729407, 0.01877035821962636, 0.06302678753854707, 0.04049494658829644, 0.062367730715777725, 0.04019070685899351, 0.07924096280476078, 0.01704465892544249, 0.027372183758416213, 0.08664388587931171, 0.06294771912507713, 0.06433408067096025, 2.137369397096336, 18.893141001462936, 31.39975380152464, 19.26119115203619, 15.456404965370893, 21.740056537091732, 33.086542189121246, 27.216394878923893, 11.10124871134758, 1.1041867872700095, 0.9661866829264909, 0.9569160710088909, 2.8794356156140566, 3.894830667413771, 6.057704770937562, 7.864836975932121, 3.3438882557675242, 3.008356997743249, 3.1873216945677996, 1.217871461994946, 0.8820975513663143, 0.0809978118923027, 3.832269636914134, 25.808804109692574, 52.60281555354595, 59.16742689907551, 54.48110416531563, 55.747485011816025, 54.27760608494282, 51.14624351263046, 51.923586800694466, 53.29806424677372, 56.28829479217529, 55.31662233173847, 56.40847094357014, 53.34784537553787, 53.87982442975044, 53.69896553456783, 53.69513913989067, 56.53642527759075, 53.478216379880905, 49.46151651442051, 41.37137062847614, 41.54888570308685, 42.12701328098774, 41.07209108769894, 43.255571722984314, 42.480831295251846, 41.447605937719345, 46.147930920124054, 51.65698930621147, 55.690195485949516, 52.39921487867832, 56.711371690034866, 38.36481615900993, 56.5107386559248, 52.93997526168823, 53.758873119950294, 55.12223616242409, 52.21922233700752, 50.30442528426647, 47.9018522053957, 39.90655682981014, 40.32250910997391, 39.21847455203533, 39.59269367158413, 49.78086277842522, 54.51326563954353, 54.025698602199554, 55.914280861616135, 52.15836860239506, 50.21571904420853, 46.14820450544357, 42.66595356166363, 41.60323418676853, 43.19252550601959, 45.04804953932762, 49.008527621626854, 48.4950003772974, 50.23949056863785, 46.491831466555595, 48.55387441813946, 49.19217936694622, 49.66778464615345, 49.147755950689316, 49.50591333210468, 50.87270759046078, 47.72151008248329, 36.612448990345, 20.212485305964947, 4.1820484679192305, 0.6161686428822577, 1.0619367356412113, 1.3734805933199823, 2.870373814366758, 1.522128141950816, 1.0114138154312968, 2.512861448340118, 4.368886342272162, 2.0790204405784607, 1.3892594841308892, 0.44482087483629584, 0.3580733999842778, 5.065882941707969, 20.529713183641434, 34.10559430718422, 23.13743345439434, 21.888364478945732, 37.13417999446392, 32.45589002966881, 13.138677533715963, 0.9253088326659054, 0.07872517759096809, 0.012452752835088177, 0.029535824396589305, 0.001525369284536282, 0.08990385860670358, 0.058017194241983816, 0.019711755849129986, 0.03241178208554629, 0.05235736825852655, 0.06907662696903571, 0.038246792028076015, 0.009173344187729526, 0.04275172119378112, 0.04257226246409118, 0.07642037118785083, 0.09143826377112418, 0.01740304389386438, 0.0817006999568548, 0.021024626221333165, 0.03336864792800043, 0.03668796278361697, 0.013476545555022312, 0.04206412879284471, 0.001121772679653077, 0.034045965294353664, 0.03817977609287482, 0.011531424734130269, 0.021867730101803318, 0.036562172463163733, 0.059785698758787476, 0.10003645278629847, 0.05035405934904702, 0.04102164508367423, 0.047286124754464254, 0.02109073302563047, 0.03888739905960392, 0.015690545551478863, 0.037269116364768706, 0.022748902447347064, 0.03701826302858535, 0.11023657498299144, 0.10620811575790867, 0.10488752333912998, 0.023444736398232635, 0.015246419334289385, 0.016146764137374703, 0.018277789240528364, 0.012635564216907369, 0.021003788569942117, 0.05814069874759298, 0.03143386522424407, 0.074440588359721, 0.01419544174495968, 0.03553717746399343, 0.04635993187548593, 0.02615669058286585, 0.11035039817215875, 0.015883251617196947, 0.036239876280887984, 0.05610571868601255, 0.044343112167553045, 0.05485392335685901, 0.06521656105178408, 0.2071791180060245, 4.9277883768081665, 26.314306184649467, 35.966293662786484, 20.296295508742332, 16.97037387639284, 30.34046184271574, 43.1239277869463, 30.067412294447422, 9.702106788754463, 1.3364736665971577, 0.284914203803055, 0.2037310108426027, 0.4039072530576959, 3.8970013009384274, 5.0269796792417765, 12.778914738446474, 7.46591585688293, 3.2747806515544653, 5.357541516423225, 2.6622777432203293, 2.501078280620277, 0.2525064256042242, 6.016808515414596, 30.395452491939068, 56.41925476491451, 59.17858690023422, 55.50832584500313, 56.5708514302969, 56.07109844684601, 52.43878595530987, 53.83554920554161, 54.78143244981766, 58.87299969792366, 57.556267753243446, 56.299743577837944, 53.40720199048519, 53.69279086589813, 54.031333699822426, 56.3248336315155, 57.55002088844776, 55.25285795331001, 51.431832388043404, 43.21751296520233, 42.85292252898216, 43.32180976867676, 43.53005759418011, 45.052263513207436, 44.150993674993515, 44.78038050234318, 47.648717388510704, 54.05294694006443, 56.46651662886143, 55.48433393239975, 57.59279139339924, 42.81192272901535, 56.7080544680357, 51.26423858106136, 55.36407418549061, 55.85161842405796, 53.488764613866806, 53.21654722094536, 50.13224512338638, 40.48833221197128, 41.379699781537056, 41.26851014792919, 42.64496348798275, 52.325677424669266, 54.19288583099842, 55.97664311528206, 54.04565893113613, 54.72644180059433, 51.85770973563194, 46.373733803629875, 44.31897886097431, 43.914403170347214, 44.82133850455284, 46.85033082962036, 50.54252810776234, 50.8120172470808, 52.112489864230156, 47.27418668568134, 48.93268369138241, 48.89825753867626, 50.713541731238365, 50.0120385736227, 50.32186634838581, 51.668457090854645, 48.85811269283295, 39.706638157367706, 23.683789037168026, 6.144408518448472, 1.6459702653810382, 2.9570098780095577, 3.713839491829276, 3.8824770553037524, 4.45729429833591, 3.2121376879513264, 4.453058475628495, 4.765947461128235, 3.180558532476425, 0.921445389976725, 0.11769690318033099, 0.1749607062083669, 4.870745362713933, 21.18204887956381, 38.8543476909399, 28.18238854408264, 25.70604432374239, 44.62727151811123, 37.01605573296547, 16.515471786260605, 1.4921893109567463, 0.05253760624327697, 0.04819245034013875, 0.06458084477344528, 0.03431035169342067, 0.032906115520745516, 0.03075133983656997, 0.0107384751936479, 0.04082242296135519, 0.08210945263272151, 0.08676163502968848, 0.026645693542377558, 0.05437841078673955, 0.038608195682172664, 0.038302037501125596, 0.04404623083246406, 0.04387493201647885, 0.047627531239413656, 0.04259009256202262, 0.012397157624945976, 0.04814699379494414, 0.08532928259228356, 0.025716225936776027, 0.018639888658071868, 0.006020868768246146, 0.07988188895978965, 0.03601861608331092, 0.024480329266225453, 0.02960774778330233, 0.21079600439406931, 0.15684700396377593, 0.1881470376974903, 0.22685410600388423, 0.23112543305614963, 0.1567973245983012, 0.11609417590079829, 0.06687520173727535, 0.0922039152646903, 0.14004777884110808, 0.08929566116421483, 0.16996392980217934, 0.13182585127651691, 0.22666766366455704, 0.24362198280869052, 0.17391960660461336, 0.06880284869112074, 0.10540283357840963, 0.19736019254196435, 0.105184530839324, 0.10065369700896554, 0.11348159343469888, 0.09940786854713224, 0.1672885616426356, 0.11982415075181052, 0.1402306737145409, 0.1637300822767429, 0.0784728919097688, 0.22414228355046362, 0.13994959270348772, 0.16220715071540326, 0.13341521989786997, 0.19391839363379404, 0.21032316726632416, 0.1786644832463935, 0.20168726972769946, 4.931894531473517, 29.759334325790405, 46.99728414416313, 29.993986934423447, 22.71738499403, 34.33605194091797, 44.14218194782734, 33.864577040076256, 13.698039818555117, 2.002241760492325, 1.2567527568899095, 2.179255736991763, 6.921110115945339, 9.239064585417509, 12.683931235224009, 16.287996992468834, 8.589399196207523, 7.404935779049993, 9.70662759616971, 3.2580931345000863, 1.8139021354727447, 0.7601241557858884, 5.805941205471754, 29.7938459739089, 57.27664835751057, 62.23341017961502, 59.541558623313904, 58.92667941749096, 58.80918592214584, 55.46768702566624, 57.68746331334114, 56.95566438138485, 60.36612957715988, 58.264097571372986, 58.352815210819244, 52.4946353584528, 53.63896295428276, 54.35147412121296, 56.17122307419777, 60.44961489737034, 58.70689541101456, 53.69142293930054, 45.67270942032337, 44.88502688705921, 45.2290528267622, 45.60223460197449, 47.274916246533394, 46.99500806629658, 47.09358237683773, 50.13438060879707, 56.52954384684563, 59.510799273848534, 56.67949140071869, 59.46271285414696, 46.143188774585724, 55.8354464918375, 52.87222109735012, 55.56373447179794, 57.71142102777958, 55.67950665950775, 55.83821654319763, 51.22472830116749, 42.356224581599236, 43.71246300637722, 41.648094579577446, 44.409603998064995, 53.72190870344639, 58.288982436060905, 57.85415656864643, 56.133111119270325, 56.22457981109619, 53.15907530486584, 50.60207471251488, 46.59568749368191, 45.93971349298954, 46.47516556084156, 50.18297620117664, 53.18411596119404, 52.98180341720581, 53.03771361708641, 48.59343409538269, 50.38364723324776, 51.903451681137085, 53.796605095267296, 51.83405980467796, 52.66197457909584, 53.75300623476505, 50.53557068109512, 39.68489572405815, 22.599395625293255, 6.062651630491018, 1.3534179073758423, 2.8659199783578515, 4.402493638917804, 7.381553258746862, 7.913455367088318, 5.119724627584219, 8.780461493879557, 10.237493310123682, 8.368247263133526, 4.467128170654178, 1.026454120874405, 0.513302996987477, 6.665646024048328, 25.230142660439014, 43.47676545381546, 31.84666682034731, 29.742506928741932, 46.578508615493774, 40.402555614709854, 19.494416937232018, 1.4438585168682039, 0.15963909710990265, 0.1072062375897076, 0.15530811622738838, 0.17482674855273217, 0.13020062207942829, 0.17486194119555876, 0.13120364950736985, 0.1262706532725133, 0.16281808668281883, 0.20667873235652223, 0.1619723648764193, 0.11897462914930657, 0.12188056032755412, 0.1298426990979351, 0.279883214388974, 0.21538872591918334, 0.1476655388250947, 0.14528409083141014, 0.14722848805831745, 0.09323953039711341, 0.19574985082726926, 0.13469172874465585, 0.10533090462558903, 0.11546163601451553, 0.22586329432670027, 0.11125883887871169, 0.11708564808941446, 0.13332791364518926], [0.05629160070384387, 0.010714052041294053, 0.03809670379268937, 0.03428083648032043, 0.06265220334171318, 0.041641145435278304, 0.07919973650132306, 0.021032949407526758, 0.016902860479603987, 0.017101609482779168, 0.049432790619903244, 0.04850535835430492, 0.031525639205938205, 0.0533271994208917, 0.053773530744365416, 0.01899936829431681, 0.025065982117666863, 0.058385151060065255, 0.046336394661921076, 0.050106567941838875, 0.04089733163709752, 0.03771044561290182, 0.07677062778384425, 0.03545742998539936, 0.03532123475451954, 0.07756325634545647, 0.028960140443814453, 0.05124419498315547, 0.02810480411426397, 0.05146092065842822, 0.030555052908312064, 0.06415782059775665, 0.03665638068923727, 0.028387265519995708, 0.020156107493676245, 0.09463931739446707, 0.16039233247283846, 2.890608203597367, 19.924029484391212, 33.233107924461365, 21.149503625929356, 18.485970050096512, 24.31051030755043, 31.878347620368004, 29.376856349408627, 13.98941008374095, 2.105822777375579, 0.16724293440347537, 0.9445468441117555, 2.9830486932769418, 4.223054442554712, 15.187272056937218, 4.634173857048154, 1.895963957067579, 4.606995340436697, 1.1731947655789554, 2.9880456626415253, 0.5305626802146435, 0.07249912261613645, 4.98653607442975, 27.794923335313797, 49.02092255651951, 61.22464030981064, 56.75784319639206, 56.141318678855896, 52.97274090349674, 53.69754821062088, 50.29730066657066, 56.92335091531277, 55.14966309070587, 55.1188163459301, 55.99045917391777, 55.221844017505646, 53.35983753204346, 53.9203492552042, 57.00837895274162, 54.185548424720764, 50.50107233226299, 42.09251493215561, 42.69727148115635, 45.66649295389652, 43.09386000037193, 42.0874498039484, 44.30414445698261, 42.591553553938866, 43.387253656983376, 47.92745143175125, 53.443151861429214, 53.45940738916397, 58.653094097971916, 41.94333493709564, 48.604149520397186, 56.64467766880989, 51.45008660852909, 51.70629546046257, 52.830301746726036, 50.1765925437212, 46.97874873876572, 42.604742646217346, 38.896685019135475, 39.17289599776268, 42.671216279268265, 50.8611524105072, 51.517251804471016, 54.608948305249214, 52.803794369101524, 51.6813687980175, 49.90463733673096, 49.41835843026638, 45.31342729926109, 41.727962493896484, 47.096519619226456, 48.94596017897129, 49.91514377295971, 50.50732679665089, 50.013334304094315, 52.14655123651028, 50.93402110040188, 48.689823523163795, 49.77377615869045, 48.83492633700371, 51.32108733057976, 42.23037913441658, 32.50025264918804, 17.79929369688034, 4.978380287066102, 0.16575023793848231, 0.7954674249049276, 1.706987153738737, 2.2274381015449762, 2.007714416831732, 2.2192067932337523, 2.76237434707582, 2.083082660101354, 5.718211038038135, 2.7699091052636504, 0.31531174143310636, 0.3341102827107534, 4.838527841493487, 18.735654652118683, 29.11556527018547, 25.095506384968758, 23.50665584206581, 19.51894462108612, 24.126309491693974, 17.65139613300562, 3.5298671387135983, 0.10093313787365332, 0.05964558127743658, 0.039424101705662906, 0.0530552653799532, 0.04497285786783323, 0.07950657745823264, 0.041516728088026866, 0.050183135317638516, 0.08084876637440175, 0.03871211491059512, 0.023401769758493174, 0.07915461392258294, 0.03066224500798853, 0.00772716832216247, 0.044262091905693524, 0.07327088940655813, 0.011269428050582064, 0.015306646473618457, 0.11189816941623576, 0.07822231316822581, 0.04547960001218598, 0.018512721653678454, 0.06803785028751008, 0.05853853443113621, 0.040566270690760575, 0.019520209389156662, 0.03225925589504186, 0.11791346929385327, 0.059917956896242686, 0.016221945552388206, 0.030689780542161316, 0.008739304685150273, 0.052140186162432656, 0.008131762187986169, 0.045888185704825446, 0.007792050582793308, 0.031763931692694314, 0.04854354185226839, 0.02235687406937359, 0.019580503321776632, 0.05958747111435514, 0.04281213943613693, 0.10336891849874519, 0.0292173910929705, 0.05648953148920555, 0.03162267501465976, 0.02441809276206186, 0.10840726259630173, 0.07355004825512879, 0.04419693133968394, 0.03342321433592588, 0.12224868783960119, 0.02150023527065059, 0.03283316982560791, 0.02660182519321097, 0.05951172381173819, 0.06517048110254109, 0.009160230438283179, 0.05181327382160816, 0.03453307392192073, 0.0364673890726408, 0.023031738637655508, 0.07913476147223264, 0.0795342521450948, 0.04079562771948986, 0.21462841046741232, 5.716940481215715, 28.556140288710594, 32.728612795472145, 22.12539006024599, 18.044684529304504, 30.158138126134872, 38.898854702711105, 31.788782626390457, 12.406201288104057, 1.7379084695130587, 0.11820407205959782, 0.14135979203274474, 1.645054395776242, 2.206940338946879, 11.14080173894763, 12.189533114433289, 2.8923603845760226, 5.651906495913863, 4.26158532500267, 3.0614771973341703, 2.1221374394372106, 0.29239077761303633, 7.9358428157866, 31.898836120963097, 53.62789794802666, 61.58070020377636, 58.20895493030548, 57.46424809098244, 54.79352340102196, 53.70249554514885, 53.02710458636284, 58.060360103845596, 57.49422088265419, 56.45630657672882, 57.22477354109287, 55.82710973918438, 53.28530453145504, 55.17855294048786, 60.3698343783617, 55.23992344737053, 53.29198457300663, 44.297825396060944, 44.16518211364746, 46.114591509103775, 44.26623769104481, 44.29610788822174, 47.12411753833294, 43.68316277861595, 46.497120782732964, 49.88061882555485, 55.021518766880035, 55.15078403055668, 60.52241139113903, 43.71722795069218, 52.78373524546623, 56.98616914451122, 51.50210961699486, 53.68282400071621, 54.562112018465996, 53.12550410628319, 48.320308551192284, 43.2192038744688, 40.90405270457268, 41.359462067484856, 44.090333729982376, 51.5385876595974, 53.27582024037838, 55.075669661164284, 51.933207884430885, 52.733957916498184, 51.355498284101486, 51.9141861051321, 47.482700496912, 44.00799974799156, 47.17736788094044, 50.00755861401558, 50.72450414299965, 51.686756908893585, 51.93903297185898, 51.477540135383606, 52.08706922829151, 50.77370770275593, 51.85563504695892, 50.61534360051155, 51.46607235074043, 46.47905275225639, 35.250377878546715, 22.922900766134262, 6.784530244767666, 0.7043440395500511, 2.1862770477309823, 4.133581118658185, 5.772806508466601, 3.0692380433902144, 5.005439110100269, 5.4210057109594345, 4.78068164549768, 1.6112162615172565, 0.5256607057526708, 0.14244821097236127, 0.06000382338243071, 4.9351823050528765, 19.846040569245815, 36.42584480345249, 31.873571276664734, 24.454347789287567, 21.761027611792088, 28.8075689971447, 24.072097800672054, 5.362306935712695, 0.08340172469615936, 0.15995771595044062, 0.020404135102580767, 0.026853275958274025, 0.07988628989551216, 0.052204552630428225, 0.04245613861712627, 0.045003497434663586, 0.05683245566615369, 0.04759281357110012, 0.054176041958271526, 0.04668848807341419, 0.09754930069902912, 0.02391242673184024, 0.0725803581008222, 0.06460428179707378, 0.06879415072035044, 0.021689703717129305, 0.05933739332249388, 0.014823925794189563, 0.015462221963389311, 0.035067987992079, 0.03090709993557539, 0.03430763914366253, 0.004866592571488582, 0.06020134227583185, 0.05683897172275465, 0.04812146391486749, 0.0078611705066578, 0.18176881276303902, 0.10248891689116135, 0.1756301530986093, 0.15102176810614765, 0.20326580299297348, 0.15267390757799149, 0.1538823317969218, 0.10520333686145023, 0.11778163418057375, 0.0851951097138226, 0.11953717708820477, 0.15233784826705232, 0.09576601631124504, 0.1227949233725667, 0.08742032820009626, 0.1635443078703247, 0.15004386979853734, 0.19023435772396624, 0.16989673575153574, 0.12846456054830924, 0.14793817419558764, 0.0939256459241733, 0.2594239544123411, 0.10740386409452185, 0.06111236565629952, 0.09668918864917941, 0.10220186159131117, 0.13191446370910853, 0.09574983007041737, 0.12986355344764888, 0.10307174772606231, 0.12579245783854276, 0.17247020703507587, 0.16998944483930245, 0.2011904018581845, 0.19896872341632843, 0.34994634857866913, 6.225260104984045, 32.88215495646, 46.5571765601635, 30.991879887878895, 25.511812046170235, 34.64657887816429, 41.40469864010811, 38.39661285281181, 17.76844695210457, 3.0733033502474427, 0.3899428836302832, 2.074698409996927, 7.3802589531987906, 9.771701004356146, 24.494564831256866, 14.132281467318535, 7.0824451837688684, 11.768597401678562, 5.296521065756679, 6.545117441564798, 1.480789566412568, 0.36309744289610535, 6.486625280231237, 31.050269454717636, 53.13772425055504, 65.9846068918705, 63.44304487109184, 60.98453879356384, 58.03015932440758, 57.32147075235844, 55.74205130338669, 60.26468262076378, 58.60112428665161, 56.210923343896866, 55.06365090608597, 55.33798098564148, 53.986621499061584, 55.04691280424595, 60.14998957514763, 56.33930705487728, 54.26046520471573, 46.538789346814156, 45.69431126117706, 51.137086004018784, 45.97081862390041, 46.650051176548004, 47.95847676694393, 46.643998101353645, 48.22375953197479, 52.16665215790272, 56.57320350408554, 58.076900616288185, 62.48836129903793, 47.61574275791645, 51.93652890622616, 58.724549263715744, 53.87734696269035, 54.728505089879036, 55.304842963814735, 55.39064235985279, 50.398120656609535, 46.341481134295464, 43.340637758374214, 43.22605490684509, 46.56136393547058, 54.22429874539375, 54.741101413965225, 57.70373024046421, 52.61922687292099, 53.89083243906498, 53.180023580789566, 54.27288293838501, 51.18008449673653, 45.17497792840004, 51.35208986699581, 51.45985208451748, 52.81647048890591, 54.55646172165871, 52.5855378806591, 51.12744592130184, 52.43202231824398, 49.70197141170502, 51.78902842104435, 51.214449852705, 53.941669911146164, 46.237241327762604, 35.632196590304375, 20.10286308825016, 6.233570734038949, 0.7489572674967349, 2.299796906299889, 5.580732990056276, 6.020668633282185, 5.239862781018019, 7.300068531185389, 8.551295790821314, 8.589398246258497, 11.943708155304193, 5.394670749083161, 0.6330137921031564, 0.6385920115280896, 6.441166419535875, 23.37858561426401, 35.8738674223423, 33.583019748330116, 33.45599256455898, 28.57026793062687, 34.18616138398647, 24.081806279718876, 5.19337322562933, 0.1673075309372507, 0.26323716854676604, 0.0934481258445885, 0.14269203617004678, 0.16721945285098627, 0.1709385626600124, 0.09043469457537867, 0.16062106238678098, 0.20165455585811287, 0.21529389428906143, 0.20460625528357923, 0.20733813056722283, 0.14631085214205086, 0.17047662026016042, 0.20532214577542618, 0.1858265497139655, 0.1717640832066536, 0.0808802928077057, 0.1670629932777956, 0.16334416548488662, 0.14799122291151434, 0.08204841840779409, 0.14981033076765016, 0.06407457389286719, 0.16442617226857692, 0.07943537581013516, 0.15299294202122837, 0.21009445219533518, 0.13301563274580985], [0.07134473416954279, 0.05140577537531499, 0.02829703335009981, 0.03617915004724637, 0.042261710768798366, 0.10479436896275729, 0.013529978332371684, 0.034109919870388694, 0.06470484280725941, 0.03882752629579045, 0.024617728631710634, 0.012813098928745603, 0.033762090097297914, 0.02580896656581899, 0.038954422416281886, 0.01503583307567169, 0.009952587188308826, 0.01716858274448896, 0.01939516678248765, 0.05480199528392404, 0.018232954244012944, 0.020827921835007146, 0.05400041271059308, 0.03434149220993277, 0.034261930268257856, 0.045355204929364845, 0.015137861682887888, 0.01939407582540298, 0.0601769849890843, 0.009346768329123734, 0.08430964589933865, 0.008877008331182878, 0.03522150123899337, 0.03556300049240235, 0.04711471090558916, 0.018017518050328363, 0.01417558743924019, 0.11955054316786118, 4.601376391947269, 26.25010672956705, 33.5922646522522, 26.525791436433792, 28.537312299013138, 27.819920293986797, 35.85182100534439, 32.55308881402016, 17.89809599518776, 2.733662612736225, 0.11952200016821735, 0.9893682890105993, 2.1994165051728487, 10.704420804977417, 12.275417055934668, 1.384534912649542, 2.826246307231486, 4.597204215824604, 2.9823785042390227, 1.5153515618294477, 0.6479762017261237, 0.1370125581161119, 5.821388326585293, 27.46300544589758, 48.35629262030125, 57.390387654304504, 55.96231788396835, 55.200876742601395, 53.23995016515255, 54.3216647207737, 55.8690594881773, 56.541410610079765, 57.57292985916138, 54.53646719455719, 54.41870391368866, 55.46467378735542, 57.43004232645035, 56.14708296954632, 53.930745497345924, 51.15463726222515, 48.88973079621792, 47.920638397336006, 48.13983343541622, 47.13367782533169, 46.37396939098835, 44.312686398625374, 42.99140229821205, 43.1484554708004, 46.37764759361744, 53.2177821546793, 52.24363222718239, 57.25070334970951, 47.09577105939388, 48.556032702326775, 53.95222194492817, 53.463328778743744, 54.81265917420387, 52.85859502851963, 51.84247635304928, 49.86461788415909, 43.197355046868324, 40.74340112507343, 41.200847178697586, 47.00747899711132, 53.454137071967125, 52.927458733320236, 53.9503638446331, 50.61182498931885, 54.64659668505192, 52.72074222564697, 51.33431062102318, 46.05733998119831, 44.84412968158722, 48.577034175395966, 50.20153820514679, 49.84426997601986, 52.38721512258053, 50.802122578024864, 48.669164031744, 49.73101705312729, 50.91037876904011, 49.60108682513237, 46.39510005712509, 37.682824954390526, 24.807088561356068, 13.159176483750343, 3.8044629665091634, 0.17152911925222725, 0.3159995045280084, 2.213238263502717, 5.010584983974695, 6.063807243481278, 3.0207241466268897, 2.6642455626279116, 3.3534433180466294, 5.354744391515851, 1.3796321069821715, 0.7104107108898461, 0.9688695170916617, 3.6441954039037228, 19.384616129100323, 29.7021321952343, 19.28190004080534, 23.862442150712013, 19.054292254149914, 20.281223617494106, 9.56664215773344, 1.287085935473442, 0.05925823585130274, 0.05605711543466896, 0.028212233701196965, 0.04540752634056844, 0.03751638883841224, 0.038537220389116555, 0.050802617115550674, 0.03950325546611566, 0.041906363039743155, 0.017356490825477522, 0.012963898698217236, 0.06201243864779826, 0.02383526007179171, 0.01770919465343468, 0.024172829653252847, 0.022673368512187153, 0.0040551088204665575, 0.050427394671714865, 0.04437426010554191, 0.04774489818373695, 0.06027334173268173, 0.031114418889046647, 0.06297061438090168, 0.03966968950408045, 0.029279250957188196, 0.024405567164649256, 0.058128805831074715, 0.014646486633864697, 0.10931211872957647, 0.06467829618486576, 0.049771451158449054, 0.04044026143674273, 0.06701370875816792, 0.01243028616954689, 0.039145629343693145, 0.022819597579655237, 0.02427446121146204, 0.028779251224477775, 0.04453271234524436, 0.03243776838644408, 0.024497474732925184, 0.013936142768216087, 0.03688222364871763, 0.07263775580213405, 0.036094856914132833, 0.027173412490810733, 0.038068275825935416, 0.013718116479140008, 0.045713020299444906, 0.12630881450604647, 0.0054548768002860015, 0.04711064393632114, 0.024354221677640453, 0.030973744796938263, 0.02952559389086673, 0.028238498307473492, 0.09873669245280325, 0.04779249582497869, 0.028340966637188103, 0.032986857477226295, 0.01526573929368169, 0.02738304694503313, 0.017197771412611473, 0.029965577996335924, 0.01280992810279713, 0.05503556771145668, 0.003407432368476293, 0.22701001638779417, 8.568025343120098, 33.57836879789829, 37.322478890419006, 26.266660541296005, 26.811118125915527, 30.5795032158494, 37.102713882923126, 34.21521842479706, 15.045036189258099, 1.9320457521826029, 0.15820299682673067, 0.4170310957124457, 0.6905165815260261, 4.362157378345728, 9.682908318936825, 5.455111730843782, 3.37672324385494, 3.8401031540706754, 4.111739890649915, 3.137717731297016, 1.290700847748667, 0.5232319235801697, 8.631109558045864, 31.520332731306553, 51.32750138640404, 60.235386192798615, 58.69972139596939, 58.29244025051594, 56.5272031724453, 54.99008685350418, 58.602541610598564, 57.38562270998955, 56.87057934701443, 54.63688440620899, 56.63857139647007, 56.514603048563, 57.043941244482994, 59.00446504354477, 57.14732229709625, 53.27868148684502, 49.450683295726776, 49.95476424694061, 48.23170490562916, 48.93840618431568, 45.662499368190765, 45.95490127801895, 44.15146104991436, 45.02335846424103, 47.463845908641815, 53.866038769483566, 54.40216340124607, 59.459023252129555, 47.86332227289677, 49.96696539223194, 52.499529495835304, 54.569802805781364, 54.729550033807755, 54.15011152625084, 53.07327590882778, 51.59165181219578, 45.031786412000656, 42.08898112177849, 42.28410825133324, 49.36307139694691, 53.76068562269211, 55.05760923027992, 55.80036677420139, 50.79172633588314, 55.496094301342964, 53.52234721183777, 52.343460470438, 48.13294060528278, 47.967364490032196, 50.8646672219038, 51.66616581380367, 52.35501565039158, 53.26227776706219, 50.40594443678856, 49.55597944557667, 49.52475652098656, 51.30656071007252, 49.933310598134995, 47.57538132369518, 41.43653713166714, 29.161590300500393, 17.95976098626852, 6.768852761015296, 0.949713735608384, 0.8186090737581253, 3.926812601275742, 3.747069896198809, 5.45190280303359, 4.009238965809345, 4.740170119330287, 5.2304673101753, 4.820422288030386, 1.6153363091871142, 0.19587974151363596, 0.23444623220711946, 3.1471713865175843, 19.89504273980856, 34.06890347599983, 23.7314023822546, 24.405467212200165, 23.39790377765894, 25.213746540248394, 16.19859728962183, 3.6746536195278168, 0.05251055124972481, 0.08827243247651495, 0.06098353253037203, 0.04688019966124557, 0.014671827266283799, 0.03470369367278181, 0.01829867142078001, 0.04373027630208526, 0.004405621921250713, 0.028489210635598283, 0.04764815552334767, 0.021844664152013138, 0.04384935389680322, 0.03163681292789988, 0.004523352054093266, 0.04331687407102436, 0.021348761074477807, 0.05242925268248655, 0.010874773397517856, 0.07999536333954893, 0.010676876936486224, 0.01397867525156471, 0.06689112822641619, 0.048057824751595035, 0.05839907375047915, 0.06068717812013347, 0.025908176867233124, 0.055126369479694404, 0.02959074146929197, 0.012922635287395678, 0.14808887470280752, 0.19100792793324217, 0.14214051654562354, 0.12847527716076002, 0.10297783635905944, 0.15702093369327486, 0.06628885312238708, 0.12137760684709065, 0.20889488921966404, 0.136292852985207, 0.0859253088128753, 0.08245198347140104, 0.15349405497545376, 0.13544784364057705, 0.10145726482733153, 0.15375995164504275, 0.12014328167424537, 0.12483723956393078, 0.07190890741185285, 0.20767785608768463, 0.06915384001331404, 0.1294995448552072, 0.08431675567408092, 0.1045633977628313, 0.1800624668248929, 0.12375587102724239, 0.2138466024189256, 0.12074400568963028, 0.12076905317371711, 0.07446288247592747, 0.14407094655325636, 0.08122272716718726, 0.17497676628408954, 0.07869511318858713, 0.11285294982371852, 0.1688331490731798, 0.1556397374952212, 0.3691834694473073, 8.428618423640728, 37.05074407160282, 47.3159958422184, 34.288550689816475, 41.18600517511368, 37.25414715707302, 45.23844212293625, 41.66205123066902, 21.67063806205988, 3.4333993401378393, 0.379090309725143, 2.098879124969244, 5.525065027177334, 20.440123490989208, 24.716163240373135, 9.400212038308382, 7.4512125458568335, 10.1363854855299, 7.241336507722735, 3.944141333922744, 1.4728050073608756, 0.7830964168533683, 7.1383914817124605, 30.917705968022346, 53.52111227810383, 61.45698644220829, 61.04976609349251, 59.523156210780144, 58.6519655585289, 58.383395969867706, 59.93274763226509, 57.97052912414074, 58.62310990691185, 55.73621101677418, 56.56198650598526, 53.88367362320423, 58.53766389191151, 61.406319960951805, 58.655776754021645, 56.13833203911781, 53.365058451890945, 54.1172356903553, 49.612049236893654, 51.639859825372696, 49.828592017292976, 49.62922431528568, 46.49729557335377, 47.24951080977917, 49.27154950797558, 57.28214666247368, 56.917252242565155, 60.54902896285057, 52.132423594594, 51.27648152410984, 53.41582752764225, 55.36164231598377, 57.68625497817993, 55.14699183404446, 55.96588969230652, 54.21274736523628, 47.136941850185394, 44.64494816958904, 44.540898352861404, 52.92806290090084, 56.8485177308321, 58.54398675262928, 57.097742557525635, 51.1040011793375, 56.25847399234772, 55.83320461213589, 56.38412944972515, 50.16763262450695, 48.481378108263016, 53.74053530395031, 55.60583621263504, 53.00425261259079, 53.84946785867214, 51.48698262870312, 49.19843763113022, 50.98088018596172, 51.69726334512234, 50.108260810375214, 48.17436218261719, 40.44839635491371, 28.932130113244057, 15.18189249560237, 5.3064527828246355, 0.8120073436293751, 0.6108048744499683, 5.4563371650874615, 9.362308122217655, 10.722318794578314, 8.019681517034769, 8.648744411766529, 9.923058282583952, 11.26887671649456, 3.6515760328620672, 1.330806389451027, 1.353734596632421, 4.6739615220576525, 25.08267067372799, 36.87856011092663, 26.710471026599407, 33.04646193981171, 28.759697265923023, 31.718522496521473, 16.4610568061471, 3.205623412504792, 0.22368075675331056, 0.17345393862342462, 0.1878027108614333, 0.10438769430038519, 0.14358926302520558, 0.09302964361268096, 0.10311220219591632, 0.1952587568666786, 0.1672045059967786, 0.12764091021381319, 0.09693034953670576, 0.10119406957528554, 0.17783685500035062, 0.17067334876628593, 0.17415926093235612, 0.1219171704724431, 0.0875667019863613, 0.1143954369763378, 0.17850256146630272, 0.24482086300849915, 0.13907571381423622, 0.20524658029899, 0.19456760957837105, 0.14521425473503768, 0.11248387236264534, 0.11558550788322464, 0.1398551173042506, 0.08419453879469074, 0.23809146863641217, 0.16073517501354218], [0.025685970431368332, 0.040322571658180095, 0.030587540422857273, 0.016575154040765483, 0.03631475898146164, 0.028521152671601158, 0.04748907987959683, 0.05145794464624487, 0.037001442251494154, 0.0430302566383034, 0.012560145314637339, 0.02197755497036269, 0.02767439371382352, 0.06718893724610098, 0.03553299917257391, 0.061233925734995864, 0.04377776633191388, 0.03303027311631013, 0.04499598318943754, 0.04746867823996581, 0.0250339491685736, 0.07128850906156003, 0.03448501985985786, 0.02183159493142739, 0.027098835926153697, 0.06183755896927323, 0.07724174312897958, 0.03665348260255996, 0.018641593742358964, 0.05901462216570508, 0.050407230519340374, 0.13133070518961176, 0.023555329389637336, 0.024646061974635813, 0.040456781644024886, 0.03845732819172554, 0.03285857354057953, 0.08018049949896522, 0.15101623168447986, 3.6330548767000437, 20.952402502298355, 27.777273282408714, 25.440364480018616, 26.701119728386402, 27.241711020469666, 29.857701547443867, 28.452310860157013, 18.850416094064713, 4.5754489582031965, 0.4959181579761207, 0.09214130768668838, 3.374134632758796, 9.562203045934439, 2.326473374851048, 2.8662854712456465, 2.2186826588585973, 2.474653786048293, 2.7383783971890807, 0.7176385761704296, 0.14134692319203168, 0.13287826121086255, 5.9158802311867476, 25.79955730587244, 46.30689159035683, 57.44344420731068, 56.687873750925064, 60.81770874559879, 55.80693282186985, 59.00197237730026, 59.321793615818024, 52.07856148481369, 59.749027490615845, 55.34325510263443, 57.65214420855045, 57.42590814828873, 60.69674223661423, 53.74400071799755, 56.58548064529896, 55.679115280508995, 55.944344848394394, 53.551457449793816, 53.014033287763596, 49.696609899401665, 48.33106577396393, 46.82928375899792, 48.14717844128609, 48.23790617287159, 54.171853959560394, 54.8421797901392, 61.09230861067772, 46.15052618086338, 47.4762674421072, 54.88449051976204, 54.64463599026203, 56.97458736598492, 52.74713180959225, 53.35270531475544, 48.79489168524742, 43.11695896089077, 41.39141455292702, 43.12485113739967, 46.22196614742279, 51.72514624893665, 52.42044813930988, 52.81992830336094, 52.9629298299551, 53.424776047468185, 53.7262062728405, 53.08292739093304, 51.03690817952156, 49.93165008723736, 49.32299114763737, 52.54362612962723, 51.770914793014526, 53.20070207118988, 50.60001142323017, 51.59987077116966, 48.91376830637455, 47.00599707663059, 41.14800341427326, 31.513920575380325, 21.538825035095215, 9.970465488731861, 2.7319489046931267, 0.8008791657630354, 0.2672765892930329, 1.7264862824231386, 2.4954417580738664, 1.153896194882691, 6.135161239653826, 2.4867746606469154, 5.3224314004182816, 4.967303406447172, 3.8025416946038604, 0.2529560780385509, 0.2848111937055364, 3.22114035487175, 19.664478711783886, 29.197798557579517, 20.451046004891396, 24.009784944355488, 25.873349346220493, 20.547741316258907, 7.297313679009676, 1.390574094839394, 0.09765123468241654, 0.026524946115387138, 0.06591970886802301, 0.029704160187975504, 0.014738018489879323, 0.02003247125685448, 0.05520088110642973, 0.06342695356579497, 0.054033545893616974, 0.03129455668386072, 0.08119664067635313, 0.022420752575271763, 0.05342676966392901, 0.026968895144818816, 0.05721928158891387, 0.04764742079714779, 0.03009235908393748, 0.04614329525793437, 0.021262495683913585, 0.03709291195264086, 0.025684964821266476, 0.06471340719144791, 0.04610594296536874, 0.03252245114708785, 0.015250644937623292, 0.009408542846358614, 0.07301071469555609, 0.03245717925892677, 0.02388028060522629, 0.05157734136446379, 0.044687695044558495, 0.011351426092005568, 0.0528160637622932, 0.01372587563309935, 0.04458455507119652, 0.03689013494295068, 0.05841301128384657, 0.030524734320351854, 0.03341900264786091, 0.014560292675014352, 0.05359874383429997, 0.06696188458590768, 0.012729955196846277, 0.010692201358324382, 0.016606450408289675, 0.051298828184371814, 0.03881763346726075, 0.036497624168987386, 0.047142300245468505, 0.023350372321147006, 0.022462262750195805, 0.02568057316238992, 0.06269628691370599, 0.060338472612784244, 0.02221362472482724, 0.037263594786054455, 0.030303529783850536, 0.02173530312575167, 0.02425747901725117, 0.026316358089388814, 0.05870068256626837, 0.06585723487660289, 0.05218610654992517, 0.01461433494114317, 0.09846951186773367, 0.10395417615654878, 0.08712750641279854, 0.053386912622954696, 0.05537087745324243, 0.30711448285728693, 7.5760776456445456, 29.67166543006897, 34.65079665184021, 30.514505803585052, 27.735393829643726, 33.48206676542759, 36.24163068830967, 34.1073764115572, 16.345373913645744, 3.786793202161789, 0.3267877787584439, 0.1374733427655883, 1.766656064428389, 3.8899538666009903, 4.318265458568931, 4.897775212302804, 5.554016148671508, 5.218350235372782, 6.065380834043026, 3.0753827886655927, 0.31730719842016697, 0.5652236484456807, 9.138445984572172, 30.352087318897247, 49.76680353283882, 58.455873280763626, 58.86100374162197, 59.64105248451233, 57.990763038396835, 59.44317810237408, 59.24515172839165, 54.84266996383667, 59.826471135020256, 56.858530193567276, 55.903922617435455, 57.545651122927666, 62.76640757918358, 57.36992195248604, 58.895513489842415, 56.57344289124012, 57.45280310511589, 54.47494849562645, 55.73423512279987, 52.3088139295578, 49.820684641599655, 47.9821152985096, 50.10393664240837, 49.48069028556347, 55.72609595954418, 56.75488695502281, 61.496223136782646, 48.05849879980087, 49.47081081569195, 54.58727426826954, 54.126252606511116, 58.50072607398033, 55.79450748860836, 55.48040874302387, 50.99898621439934, 44.71288852393627, 44.131922498345375, 43.82356524467468, 48.550792783498764, 53.56020078063011, 53.76495659351349, 54.077998995780945, 52.03945778310299, 54.049109145998955, 55.9847366809845, 55.26243343949318, 52.15852439403534, 50.296882688999176, 50.903789922595024, 52.911302000284195, 53.69375981390476, 52.64262221753597, 50.39663873612881, 52.0725654065609, 49.95919480919838, 48.25265698134899, 43.27908866107464, 34.44933146238327, 25.525291822850704, 12.713205814361572, 5.83929724059999, 1.9379886332899332, 1.914753473829478, 2.0995611883699894, 4.81984899379313, 2.6967585179954767, 4.82089108787477, 6.287243803963065, 3.16877702716738, 1.6731715807691216, 1.2505068420432508, 0.33467971778009087, 0.19271832599770278, 3.230188856832683, 19.437887370586395, 33.488594815135, 23.968004286289215, 22.7651921287179, 28.34011998027563, 24.116251431405544, 13.227199483662844, 2.363778823055327, 0.1965488470159471, 0.06352079071803018, 0.03436430954025127, 0.031654168051318265, 0.05807933055621106, 0.04380728154501412, 0.06103972053097095, 0.046529701867257245, 0.03579413867555559, 0.03172879842168186, 0.055540313478559256, 0.021032520817243494, 0.044299804139882326, 0.024927239464886952, 0.01841354474890977, 0.0687240697152447, 0.019395847702980973, 0.047250082352547906, 0.04209798928059172, 0.00638495343082468, 0.04160768570727669, 0.02147956460248679, 0.017445719240640756, 0.04177103241090663, 0.056288301857421175, 0.03800728612986859, 0.024978132241813, 0.0462989867082797, 0.023475893613067456, 0.02077361146803014, 0.04107608532649465, 0.08105411863652989, 0.11055896393372677, 0.1320497869164683, 0.13119236886268482, 0.13501649256795645, 0.14709855284309015, 0.116893558006268, 0.15980567957740277, 0.1638125942554325, 0.14585814205929637, 0.15346462139859796, 0.12306533972150646, 0.113285035622539, 0.15428735146997496, 0.1137943567300681, 0.17711640772176906, 0.1547810429474339, 0.11173042919836007, 0.11132490486488678, 0.190746899752412, 0.08506334881531075, 0.19619637139840052, 0.13578724261606112, 0.16725571418646723, 0.12293642124859616, 0.12400306557537988, 0.09174200997222215, 0.1083041782840155, 0.12422496030922048, 0.2909633901435882, 0.1793625473510474, 0.2592815808020532, 0.12817815091693774, 0.21648055873811245, 0.16462560219224542, 0.18930618331069127, 0.10289657860994339, 0.1848606445128098, 0.3029967803740874, 7.511880565434694, 33.282767459750175, 42.588509917259216, 38.146742060780525, 39.21554870903492, 38.874380216002464, 40.477297604084015, 38.241292387247086, 23.745967000722885, 5.77245787717402, 0.7699418195988983, 0.27489351807162166, 6.638395311310887, 16.951315999031067, 7.433802355080843, 8.151553440839052, 8.907923754304647, 7.074442813172936, 7.968427017331123, 3.2440322265028954, 0.4049050260800868, 0.5250852147582918, 7.755042817443609, 28.7304350361228, 50.60769461095333, 60.32705247402191, 61.43394447863102, 63.237293511629105, 60.271153673529625, 60.83382748067379, 62.77940288186073, 54.2972282320261, 62.21906214952469, 55.927941128611565, 57.09913708269596, 58.50177861750126, 64.76756259799004, 58.84249493479729, 59.882928505539894, 58.96603390574455, 59.903622195124626, 56.742036044597626, 59.46825295686722, 54.80678848922253, 52.46348462998867, 52.651388347148895, 52.036075964570045, 52.13661476969719, 57.090720534324646, 60.544925183057785, 64.81444448232651, 51.618447974324226, 49.279548078775406, 55.720628052949905, 54.66761335730553, 59.30088713765144, 57.92378783226013, 57.546696066856384, 53.32679830491543, 46.63117378950119, 46.246949806809425, 46.37027218937874, 50.29563635587692, 54.7711768001318, 56.76107682287693, 55.40589094161987, 52.93805256485939, 54.56016652286053, 57.04415783286095, 57.64202155172825, 54.36637692153454, 53.913946598768234, 52.637230306863785, 55.31282253563404, 55.24982951581478, 53.90847109258175, 49.8925843834877, 51.176216304302216, 50.08980140089989, 47.689116820693016, 42.44404546916485, 33.7095757573843, 23.66129234433174, 12.767113521695137, 4.795943526551127, 1.7015494080260396, 1.6812981572002172, 3.7707801489159465, 5.903908023610711, 5.062251761555672, 12.72610992193222, 9.296753089874983, 12.305007968097925, 11.87511233612895, 8.732488118112087, 1.9255743431858718, 0.4635011177742854, 4.79677140712738, 25.632945746183395, 38.746653869748116, 27.897814214229584, 32.59098798036575, 35.72373367846012, 29.167793467640877, 12.537299003452063, 2.378118303604424, 0.17547096242196858, 0.25219588133040816, 0.10233238310320303, 0.11040854544262402, 0.07691470833378844, 0.10976058372762054, 0.16282944154227152, 0.26330924592912197, 0.1914593912078999, 0.12354372069239616, 0.22575228387722746, 0.0916568336833734, 0.2201503305695951, 0.10358314684708603, 0.13265131245134398, 0.22500741994008422, 0.10370201664045453, 0.12881354807177559, 0.10352286219131202, 0.10756087285699323, 0.08019686385523528, 0.1136231432610657, 0.08288887838716619, 0.13942064921138808, 0.11319074576022103, 0.11536410296685062, 0.16827279789140448, 0.15114024456124753, 0.07812938143615611, 0.1998018880840391, 0.1038925778993871], [0.036079550118301995, 0.061626718525076285, 0.02901296094933059, 0.028624556107388344, 0.03925900724425446, 0.022901612319401465, 0.06442034791689366, 0.03679910681967158, 0.09122662551817484, 0.04192923974187579, 0.04075090590049513, 0.028905963663419243, 0.037547436586464755, 0.09277685327106155, 0.08091437222901732, 0.06178956798976287, 0.01951691425347235, 0.010048428139270982, 0.026273372895957436, 0.047671815191279165, 0.026890919543802738, 0.04295932958484627, 0.06054857833078131, 0.02263589747599326, 0.028021887665090617, 0.08235054672695696, 0.017892928153742105, 0.07597903080750257, 0.017583504522917792, 0.05660077200445812, 0.04473781598790083, 0.03652061219327152, 0.035938594010076486, 0.0907583674415946, 0.04695517884101719, 0.035430000207270496, 0.0751384966133628, 0.017519416360300966, 0.05869186214113142, 0.049965404032263905, 1.6786443558521569, 17.220831736922264, 24.996445700526237, 26.90380085259676, 17.04868197441101, 21.133510284125805, 34.14692468941212, 30.3092123195529, 18.700308948755264, 6.434075050055981, 1.3740639807656407, 0.6042924395296723, 2.23002671264112, 5.3005564492195845, 2.226439705118537, 2.8794021299108863, 4.518404994159937, 5.529226278886199, 4.403902413323522, 0.18270990054588765, 0.4976934049045667, 0.8397243625950068, 5.644306903705001, 21.122891753911972, 37.26389363408089, 50.66043198108673, 55.94265773892403, 59.36839051544666, 52.95974560081959, 57.250182777643204, 51.478851065039635, 56.17578282952309, 60.01740708947182, 56.321106031537056, 59.33051034808159, 56.8747591227293, 59.162399768829346, 57.076760083436966, 57.228592336177826, 57.80410945415497, 56.62431836128235, 55.09290553629398, 51.42686605453491, 51.51061736047268, 50.00519894063473, 50.014174059033394, 55.02519316971302, 56.95083484053612, 56.163562685251236, 58.074096366763115, 47.65161283314228, 41.67440816760063, 48.60524766147137, 59.29911643266678, 56.390554904937744, 54.861041978001595, 51.64179392158985, 46.74084730446339, 44.153790324926376, 45.1427898555994, 44.22505550086498, 51.738464534282684, 52.16291695833206, 55.906555876135826, 52.70423211157322, 54.56365093588829, 53.02404575049877, 54.147972241044044, 53.74684676527977, 51.75414629280567, 50.01347869634628, 51.85614801943302, 51.1380435526371, 52.75486059486866, 53.183504194021225, 52.16428868472576, 44.828390926122665, 41.40805386006832, 32.84834437072277, 23.59926827251911, 13.164284359663725, 5.813451502472162, 0.6538253941107541, 0.5615406960714608, 0.8941857714671642, 1.9012291682884097, 1.4339278684929013, 3.5728338081389666, 2.1715366886928678, 3.037468660622835, 5.037490865215659, 2.2276979126036167, 1.642946933861822, 0.8897210704162717, 0.332918037311174, 4.0823546424508095, 20.97635641694069, 32.234312519431114, 22.927711308002472, 19.991321973502636, 25.63946809619665, 21.171432249248028, 5.9087765123695135, 0.401207230752334, 0.022021720178599935, 0.03317918504762929, 0.06985407118918374, 0.07476207189029083, 0.048754345189081505, 0.013270299932628404, 0.023401827274938114, 0.04185638310445938, 0.05508561815076973, 0.027270466853224207, 0.0348429502628278, 0.020074615968042053, 0.03998293148470111, 0.03343918164318893, 0.06934195218491368, 0.06082977066398598, 0.05592228946625255, 0.0427425630914513, 0.06503961820271797, 0.0486584708414739, 0.01965917654160876, 0.07897413102909923, 0.07160268243751489, 0.01791572693036869, 0.012272014828340616, 0.04310371441533789, 0.06839035559096374, 0.024823826752253808, 0.022621961797995027, 0.07273810901097022, 0.03678608212794643, 0.043834210373461246, 0.09584009749232791, 0.0447612381685758, 0.05363136122468859, 0.016344433315680362, 0.03144365415209904, 0.04493509739404544, 0.08546244614990428, 0.05720388944610022, 0.06253991639823653, 0.06553857150720432, 0.06176262060762383, 0.03306884995254222, 0.03069400707317982, 0.005369401796997408, 0.08834986816509627, 0.048949537449516356, 0.04812606151972432, 0.02133079367922619, 0.010859780159080401, 0.0292955169788911, 0.03780428276513703, 0.05597653303993866, 0.0291046737038414, 0.05565754312556237, 0.021009742449678015, 0.03809518981142901, 0.031055731706146616, 0.03172338445438072, 0.0318380759563297, 0.06155986957310233, 0.040356320823775604, 0.03882485456415452, 0.018422216744511388, 0.07018382966634817, 0.015383673980977619, 0.0658951660443563, 0.012004502132185735, 0.007128283905331045, 0.02985935439937748, 0.09784506881260313, 5.7423763163387775, 24.272029772400856, 32.65751861035824, 33.33303116261959, 22.593633234500885, 23.90426840633154, 38.90170454978943, 39.89823527634144, 19.78329263627529, 5.857873968780041, 0.5505083443131298, 0.3574299579486251, 0.906792723108083, 2.659473968669772, 3.2193031534552574, 5.4425890278071165, 3.4685590909793973, 5.959177482873201, 3.8258116459473968, 1.1130956467241049, 1.3912249286659062, 0.8888243185356259, 7.715530637651682, 26.055718660354614, 42.00626716017723, 53.67849983274937, 57.940624728798866, 60.228364169597626, 59.08402517437935, 59.17320638895035, 52.06524699926376, 57.4446639418602, 58.324715718626976, 55.671705678105354, 58.953798562288284, 59.342016130685806, 60.91502532362938, 59.26228120923042, 58.39614808559418, 58.203452825546265, 59.27844554185867, 56.531823724508286, 53.71165305376053, 53.973288014531136, 50.77616237103939, 51.65859282016754, 56.988452821969986, 58.529456332325935, 57.80237674713135, 61.91564843058586, 50.104050636291504, 42.80292481184006, 49.53517556190491, 57.57168352603912, 56.653831377625465, 56.26817487180233, 53.40158589184284, 49.73425827920437, 45.18166556954384, 47.38560810685158, 45.64492151141167, 52.68745981156826, 54.13579009473324, 55.90163893997669, 54.0136456489563, 54.68168020248413, 52.16873064637184, 56.19237653911114, 54.26694005727768, 53.88706684112549, 53.57415743172169, 52.78990611433983, 53.74436929821968, 53.239782974123955, 53.583083152770996, 52.86468990147114, 47.093757167458534, 43.4936061501503, 35.48879988491535, 27.770498245954514, 15.257236752659082, 7.992257438600063, 1.5381448762491345, 1.878447134513408, 2.760325069539249, 3.2578943576663733, 3.702762611210346, 6.780283497646451, 3.0846623657271266, 2.6083633862435818, 3.8005154533311725, 2.23321664147079, 0.625318611273542, 0.13328884699149057, 0.2499005669960752, 3.3492326689884067, 19.49802104383707, 35.618631318211555, 26.60854909569025, 19.446351416409016, 27.448568120598793, 27.089080810546875, 10.764373987913132, 1.3401477131992579, 0.10435851305373944, 0.007926241087261587, 0.05346609606931452, 0.09617745556170121, 0.03142616173136048, 0.06984707273659296, 0.05283787919324823, 0.01813030965422513, 0.03601471980800852, 0.05074758686532732, 0.047629846740164794, 0.02300004522112431, 0.034352587317698635, 0.06393480522092432, 0.03293500361905899, 0.016660521432640962, 0.05083629206637852, 0.08251701787230559, 0.06846415475592948, 0.040374510863330215, 0.040699916644371115, 0.013774945509794634, 0.003516898223097087, 0.026589295885059983, 0.018823419923137408, 0.029424888161884155, 0.023506416291638743, 0.014537415972881718, 0.052062242102692835, 0.05298789321386721, 0.047340520468424074, 0.033185296633746475, 0.23491711006499827, 0.1735115292831324, 0.10154851930565201, 0.163610017625615, 0.0885494465183001, 0.1649602217366919, 0.1891735615208745, 0.18313985638087615, 0.17330772068817168, 0.11805063302745111, 0.36632881325203925, 0.10562427560216747, 0.11040902783861384, 0.15138573216972873, 0.23320383246755227, 0.11547876478289254, 0.17718018789310008, 0.12533790722955018, 0.1267292263219133, 0.18063066992908716, 0.14354016253491864, 0.1414686650969088, 0.16926009178860113, 0.12106147420126945, 0.08545740696717985, 0.18896464694989845, 0.09723910523462109, 0.1292020920664072, 0.16056431777542457, 0.2096414749394171, 0.1461722337990068, 0.1376287336461246, 0.0991094732307829, 0.22074959997553378, 0.09425126321730204, 0.15092905901838094, 0.269390344619751, 0.07042323166388087, 0.1713461650069803, 0.19357227080035955, 5.586583251133561, 29.399406239390373, 40.33490404486656, 41.631364077329636, 30.653280057013035, 30.18573224544525, 43.58420468866825, 40.99175199866295, 24.467430487275124, 8.129404429346323, 2.081377739086747, 1.0817071935161948, 4.730072161182761, 10.23226859048009, 7.833502432331443, 9.762620441615582, 11.032037325203419, 10.624847374856472, 9.139858558773994, 2.7836432307958603, 1.2341780494898558, 1.3489391352050006, 6.76994520239532, 23.83402917534113, 39.5784330368042, 53.79793122410774, 59.43413458764553, 61.29789657890797, 59.83763873577118, 57.99655772745609, 54.91914086043835, 57.50097692012787, 59.17927846312523, 55.69552659988403, 59.26575422286987, 59.92552801966667, 65.00510305166245, 61.601131707429886, 60.80475904047489, 60.76958432793617, 62.40112937986851, 59.62914392352104, 55.29481150209904, 56.40085995197296, 54.259792640805244, 53.68502028286457, 59.71807435154915, 61.77906475961208, 60.158774703741074, 60.809778571128845, 54.071748331189156, 44.655849784612656, 47.316250428557396, 60.15404395759106, 58.500908464193344, 59.201682060956955, 55.05528375506401, 51.111653968691826, 47.571121752262115, 49.476434513926506, 49.217763394117355, 55.7340869307518, 56.534525379538536, 58.28930921852589, 55.01920469105244, 55.51307559013367, 52.727380469441414, 56.72161974012852, 56.888096407055855, 56.29891902208328, 54.49888341128826, 55.68427160382271, 55.55742301046848, 53.5282938927412, 52.608477249741554, 52.33058676123619, 47.8773283213377, 44.732313081622124, 35.24251610040665, 25.659211836755276, 15.254392605274916, 7.620922839269042, 0.8720141393132508, 2.004610220901668, 3.0060645332559943, 5.425519393756986, 5.22786539979279, 12.46462220326066, 9.536051899194717, 6.810086248442531, 10.738254189491272, 7.089347038418055, 5.778820160776377, 2.3717237217351794, 0.5192255135625601, 5.0426234398037195, 26.043181233108044, 40.82353122532368, 33.05427052080631, 26.60543706268072, 34.90686111152172, 31.024457439780235, 8.949050847440958, 1.0590535216033459, 0.217489434289746, 0.13214360922574997, 0.09937800452462398, 0.1653715645079501, 0.18970358854858205, 0.20201022271066904, 0.09293884926592, 0.08154718670994043, 0.11141112016048282, 0.13829113013343886, 0.15503684640862048, 0.15311146300518885, 0.15822444489458576, 0.17352318100165576, 0.1672155936830677, 0.14120278327027336, 0.1493740369915031, 0.21520287729799747, 0.08599389067967422, 0.11873995463247411, 0.13803749374346808, 0.16440058301668614, 0.08719746867427602, 0.06419624900445342, 0.13080777309369296, 0.1340436260215938, 0.15502817812375724, 0.07307495499844663, 0.10651487507857382, 0.19236663705669343, 0.2981402550358325, 0.14929493889212608], [0.07730854384135455, 0.017576496793481056, 0.04902963373751845, 0.03904752113157883, 0.005663221309077926, 0.04528225923422724, 0.01092028003768064, 0.05961242954072077, 0.018849142761609983, 0.060119264453533106, 0.03792947194597218, 0.01140410837251693, 0.026780747721204534, 0.030380058196897153, 0.029008595265622716, 0.027023576585634146, 0.05101578419271391, 0.02376231066591572, 0.018273141540703364, 0.03395304098376073, 0.07461244007572532, 0.040577402905910276, 0.03220287122530863, 0.07253335788846016, 0.015700173062214162, 0.032488913493580185, 0.014071028108446626, 0.04180164229182992, 0.018508777138777077, 0.01587463528267108, 0.01185674609587295, 0.03550831534084864, 0.05995618863380514, 0.025660804203653242, 0.08706245716894045, 0.05807550849567633, 0.05169076750462409, 0.04528833000222221, 0.043152503203600645, 0.06898750987602398, 0.044991849426878616, 2.0061940234154463, 13.745278883725405, 27.50863339751959, 29.0776889026165, 25.602017305791378, 28.05894836783409, 17.034941911697388, 26.018657349050045, 21.434338241815567, 8.288289103657007, 1.7540986882522702, 0.42753984744194895, 1.959849453996867, 3.6059637553989887, 5.480096340179443, 2.072134022600949, 6.1979699693620205, 2.859590230509639, 0.71952173137106, 1.3363567041233182, 0.16004579403670505, 0.7678639842197299, 4.485648851841688, 13.347001355141401, 25.507867857813835, 34.56152804195881, 44.92483735084534, 52.78203293681145, 48.21695789694786, 57.75794193148613, 46.47250570356846, 55.16953602433205, 63.61782789230347, 59.021389335393906, 59.07334394752979, 58.68427902460098, 59.55014996230602, 58.79590563476086, 61.77283689379692, 58.182633742690086, 57.524607852101326, 51.06274679303169, 52.898283898830414, 48.72600518167019, 55.25422967970371, 53.851553946733475, 57.6823677867651, 59.562620893120766, 37.17728868126869, 41.593468710780144, 52.61603124439716, 58.70240405201912, 56.68651342391968, 55.62039703130722, 54.17170196771622, 50.966680347919464, 49.184499979019165, 46.122814267873764, 45.28935179114342, 46.7859660834074, 49.263117760419846, 52.776226848363876, 54.86745223402977, 54.78380352258682, 53.97177189588547, 55.20606346428394, 54.59526903927326, 52.073059380054474, 55.33675745129585, 53.106721714138985, 55.68497076630592, 52.24694944918156, 52.64829911291599, 45.5828632414341, 39.59677465260029, 31.928026154637337, 20.809773355722427, 12.582936454564333, 5.632084384560585, 1.9493833906017244, 0.9781134116929024, 0.23971263086423278, 2.035755249671638, 3.6902805184945464, 2.7753048157319427, 2.24172106012702, 4.385419730097055, 1.0619640466757119, 2.0553166000172496, 4.095655828714371, 0.964014446362853, 0.21153942856471986, 0.25509405706543475, 4.172762241214514, 18.452657237648964, 29.629917070269585, 26.479069143533707, 20.665067620575428, 28.204919435083866, 22.284272834658623, 6.351944832131267, 0.27778258023317903, 0.1002089872781653, 0.02973071052110754, 0.046481135723297484, 0.04847826625336893, 0.00966754681940074, 0.02930065820692107, 0.03944271848013159, 0.03556120449502487, 0.04283122005290352, 0.03539091871061828, 0.046263853437267244, 0.05976344174996484, 0.07795406389050186, 0.08465610269922763, 0.028009775815007742, 0.09365193443954922, 0.034690973261604086, 0.09995522472308949, 0.03545862484315876, 0.03200014616595581, 0.04200970710371621, 0.0454183579859091, 0.01617688420083141, 0.031451001414097846, 0.03925615739717614, 0.054946684394963086, 0.033298618873232044, 0.07492097312933765, 0.015083360212884145, 0.027892520192835946, 0.05732553487177938, 0.10410503993625753, 0.051429961968096904, 0.06593281519599259, 0.0060568230401258916, 0.031943049034453, 0.016002071315597277, 0.03812687209574506, 0.05318878516845871, 0.01282787508898764, 0.014112106910033617, 0.05334699621016625, 0.0438700969243655, 0.038017312544980086, 0.04364805747172795, 0.050896602697321214, 0.0704606730141677, 0.08598189015174285, 0.011917132796952501, 0.04036156038637273, 0.02430110987916123, 0.006298161115410039, 0.05822582679684274, 0.08743352358578704, 0.0969572078611236, 0.06185364502016455, 0.11030679699615575, 0.062259043188532814, 0.019606087007559836, 0.04203016069368459, 0.07055357506033033, 0.057795963730313815, 0.05520826547581237, 0.06759550800779834, 0.010067551429528976, 0.0497020566399442, 0.027400275903346483, 0.09104483644478023, 0.025536878529237583, 0.021742644821642898, 0.09205572321661748, 0.03501059771224391, 0.09448184850043617, 0.005516791861737147, 5.339618353173137, 20.246691070497036, 33.85739162564278, 31.376690939068794, 26.127734296023846, 30.67905407398939, 23.88161402195692, 31.71002045273781, 24.317006058990955, 8.716946002095938, 1.1031251004897058, 0.3098085382953286, 0.34859786625020206, 2.4418734200298786, 5.89868045412004, 2.263111062347889, 8.023214377462864, 10.229639131575823, 4.514445131644607, 3.2779266452416778, 0.6962038076017052, 0.9434837324079126, 5.697273686528206, 15.47250185161829, 29.644287899136543, 37.179872542619705, 50.050671100616455, 53.0024629086256, 52.04388454556465, 58.79701517522335, 49.235709831118584, 57.137610018253326, 62.5289811193943, 60.3106639534235, 59.34024162590504, 60.70127159357071, 63.02189826965332, 61.71728387475014, 61.86932131648064, 59.58120569586754, 60.007698610424995, 53.6620619148016, 53.28014820814133, 49.58514288067818, 57.528388649225235, 57.02068269252777, 59.435380920767784, 60.504081174731255, 39.646635577082634, 45.074302330613136, 54.337973445653915, 56.3745653629303, 59.593346044421196, 57.6409500092268, 57.03025817871094, 53.381435573101044, 49.04246740043163, 48.34512501955032, 46.836708560585976, 48.50415028631687, 53.01148742437363, 52.71291844546795, 56.55671238899231, 56.685954853892326, 54.08179499208927, 55.371016412973404, 54.35994006693363, 55.31661853194237, 56.480868458747864, 54.86307106912136, 54.92588169872761, 52.53598093986511, 53.72501313686371, 47.04059422016144, 42.97045402228832, 34.50190544128418, 24.837602823972702, 16.844414435327053, 8.686786070466042, 4.2615463770926, 2.3683732515200973, 1.4026309666223824, 2.902481616474688, 4.494445379823446, 3.679787856526673, 5.386328296735883, 5.41699075140059, 3.01817424595356, 2.576055619865656, 1.8755065673030913, 0.6977359566371888, 0.06079006947402377, 0.3039961267495528, 3.4075581142678857, 19.917997308075428, 36.74212843179703, 34.12889465689659, 23.70461381971836, 29.758937247097492, 26.91144224256277, 11.177960895001888, 0.6961200339719653, 0.025473044552200008, 0.041020813878276385, 0.03758686318178661, 0.036582199318218045, 0.0758649775525555, 0.01863178811618127, 0.032087823492474854, 0.02425265691272216, 0.04997872558305971, 0.04844814247917384, 0.0026740188422991196, 0.02935990571131697, 0.09505791094852611, 0.012090677537344163, 0.05618345123366453, 0.12180838646600023, 0.07465233051334508, 0.013293222091306234, 0.033763930623536, 0.046786035964032635, 0.03588899999158457, 0.006646905121669988, 0.05835110874613747, 0.03616234040237032, 0.07664582080906257, 0.0419114653050201, 0.061576237640110776, 0.05192815086047631, 0.07214767116238363, 0.05006791318010073, 0.058248280474799685, 0.020503957675828133, 0.057220294620492496, 0.1499957637861371, 0.0717904235352762, 0.17455225781304762, 0.16186702443519607, 0.1120738431927748, 0.1635578298009932, 0.08748477630433626, 0.13908953260397539, 0.09166771356831305, 0.12123697728384286, 0.14466660912148654, 0.22149808559333906, 0.1443768449826166, 0.10599608416669071, 0.14476003067102283, 0.12133888900279999, 0.23081968305632472, 0.13083909172564745, 0.11609191235038452, 0.13141421164618805, 0.2038877079030499, 0.1746111991815269, 0.13425617711618543, 0.2573690365534276, 0.09907482235576026, 0.12199721852084622, 0.15246983180986717, 0.14205196348484606, 0.12747374887112528, 0.13299373938934878, 0.17716359347105026, 0.08615637649199925, 0.14000320545164868, 0.10415221084258519, 0.22786871093558148, 0.16412784374551848, 0.06177343369927257, 0.1482142086024396, 0.07571766123874113, 0.19650740548968315, 0.2163047291105613, 4.0989759005606174, 22.853083312511444, 42.108702063560486, 42.59303167462349, 36.37982927262783, 39.49074514210224, 25.04645861685276, 35.01759856939316, 27.19788797199726, 11.064451485872269, 2.2868388891220093, 0.7682900363579392, 5.1436329446733, 9.803155716508627, 12.53016583621502, 7.093283627182245, 15.225156974047422, 8.88626491650939, 2.2523158416152, 2.4050866439938545, 0.8167186751961708, 1.0663817846216261, 6.1399356834590435, 15.185688491910696, 27.826948016881943, 36.33575923740864, 46.41503378748894, 53.900122940540314, 52.97808341681957, 59.681258127093315, 54.78615179657936, 55.62318988144398, 62.37107679247856, 59.69337947666645, 58.68891477584839, 62.178301736712456, 63.198250606656075, 62.32873946428299, 62.21983350813389, 61.545297503471375, 61.44774533808231, 57.32709065079689, 56.4162415266037, 53.36843267083168, 58.84995013475418, 59.84189830720425, 59.963176399469376, 63.80789369344711, 39.08126011490822, 48.78392927348614, 57.098137736320496, 55.59687249362469, 59.89115886390209, 59.82572637498379, 60.43566584587097, 55.05533315241337, 50.80245316028595, 50.742036402225494, 49.01450090110302, 51.73827074468136, 54.36877839267254, 54.26524914801121, 58.2549324631691, 58.34711171686649, 54.43456046283245, 54.287747740745544, 55.83568587899208, 55.66039748489857, 58.62225495278835, 57.030615359544754, 58.222687393426895, 52.90615327656269, 53.35763745009899, 46.44623391330242, 41.39450378715992, 33.03276747465134, 23.180648535490036, 14.564021900296211, 6.308305598795414, 2.700850423425436, 1.638889939058572, 1.3368664705194533, 3.8680397300049663, 9.383998308330774, 5.657478421926498, 6.678689774125814, 11.177336778491735, 7.112412275746465, 8.073287140578032, 8.837955258786678, 4.239371242001653, 0.5073281738441437, 0.621461640112102, 5.725246835500002, 24.358363039791584, 37.012407928705215, 39.863193556666374, 30.614049062132835, 39.380178675055504, 30.703813545405865, 10.22087775170803, 0.7137143961153924, 0.15476155414944515, 0.14747274370165542, 0.15152657695580274, 0.1877521409187466, 0.12759005825500935, 0.06648250913713127, 0.1397065244964324, 0.14277868933277205, 0.23972726601641625, 0.21802416653372347, 0.14529654406942427, 0.1105953885416966, 0.1626651152037084, 0.19108543783659115, 0.1970542495837435, 0.1531863011769019, 0.1658105300157331, 0.18302457116078585, 0.1229174445325043, 0.18358636210905388, 0.19602923974161968, 0.08704473468242213, 0.09317456278949976, 0.08972779149189591, 0.11484464412205853, 0.16267094848444685, 0.11388650920707732, 0.15354060247773305, 0.190692366741132, 0.21433863148558885, 0.18600635725306347, 0.14507305371807888, 0.11266684145084582], [0.04676992022723425, 0.04705057079263497, 0.07581326470244676, 0.0561280833062483, 0.04258812958141789, 0.07276069256477058, 0.059245226002531126, 0.04757918773975689, 0.0375148934108438, 0.016918376932153478, 0.03214234908227809, 0.09050617081811652, 0.032862736989045516, 0.04064059306983836, 0.04971967893652618, 0.04803229487151839, 0.026756692859635223, 0.0382430107856635, 0.01007207203656435, 0.040167188199120574, 0.026704169213189743, 0.03769808514334727, 0.07374193053692579, 0.028101048847020138, 0.05839150384417735, 0.037833434325875714, 0.03422379872063175, 0.04505770019022748, 0.06276791900745593, 0.03728633419086691, 0.032645168976159766, 0.053545160772046074, 0.06732207111781463, 0.03829475703241769, 0.012264871656952891, 0.022901827542227693, 0.08650318952277303, 0.05999595290631987, 0.013972457909403602, 0.04094239484402351, 0.016788465836725663, 0.03635948451119475, 1.3304464775137603, 12.634705826640129, 30.41724432259798, 31.128756143152714, 28.81606914103031, 27.940613217651844, 12.636762466281652, 19.260113909840584, 23.086155205965042, 10.316554717719555, 1.9859818392433226, 0.07579952754895203, 1.255445508286357, 4.873745301738381, 0.6033678422681987, 3.3621576754376292, 8.189482055604458, 7.419500397518277, 6.5555531065911055, 0.22303439065581188, 0.44014258368406445, 0.012232806238898775, 1.9247665302827954, 7.6195615623146296, 12.291297353804111, 19.19181067496538, 34.57559108734131, 47.61366046965122, 47.16106295585632, 56.308893486857414, 48.110316619277, 57.223413214087486, 62.52586908638477, 55.45852191746235, 59.102955758571625, 58.540346547961235, 57.70928934216499, 62.203209400177, 59.50827620923519, 58.11960652470589, 53.75495932996273, 52.22262315452099, 51.3860372453928, 54.656711742281914, 57.47471272945404, 54.147303476929665, 62.13916003704071, 62.44728550314903, 46.027260795235634, 42.042502015829086, 61.44365295767784, 57.84298896789551, 60.70505239069462, 58.28992858529091, 54.79247085750103, 51.65295012295246, 54.01252090930939, 49.13763329386711, 53.91960829496384, 52.576748952269554, 55.46616330742836, 59.01963762938976, 56.4389681071043, 56.53540313243866, 53.9317524433136, 52.141079530119896, 53.16051162779331, 53.00589792430401, 55.22179841995239, 55.38308076560497, 48.86559449136257, 39.11545068025589, 27.689327001571655, 20.64460001885891, 14.377980083227158, 9.420612193644047, 3.894840879365802, 1.4553849608637393, 0.6141313584521413, 0.6802081502974033, 1.0891585936769843, 2.9509164299815893, 2.687306050211191, 1.6959865065291524, 6.204881798475981, 3.477125493809581, 2.1049991715699434, 1.5226768562570214, 0.5620045680552721, 0.4550787212792784, 0.7007686095312238, 5.22562874481082, 20.989712700247765, 29.499135687947273, 26.979599185287952, 24.237136244773865, 24.887549243867397, 20.83122130483389, 5.04938755184412, 0.5164983286522329, 0.02364459120144602, 0.03126703042653389, 0.05526552959054243, 0.13100067211780697, 0.04527004719420802, 0.0330169552762527, 0.03744466397620272, 0.09671441424870864, 0.03025324742338853, 0.0344171096367063, 0.04250979960488621, 0.0819411632255651, 0.03358758149261121, 0.024533442920073867, 0.01684973198280204, 0.061918994833831675, 0.03577988944016397, 0.04377488679892849, 0.01713771682261722, 0.08126390894176438, 0.014326574601000175, 0.013568697104346938, 0.06570046360138804, 0.022082997456891462, 0.034759540285449475, 0.03996406609076075, 0.04487754013098311, 0.02233216797321802, 0.025100664533965755, 0.026367952195869293, 0.02347858204302611, 0.03560368873877451, 0.05987020340398885, 0.02863130965124583, 0.056753402095637284, 0.06404032377758995, 0.03529963083565235, 0.06518199923448265, 0.011996589910268085, 0.07621478885994293, 0.03846250838250853, 0.009793854787858436, 0.020279829077480827, 0.04331272175477352, 0.06741774879628792, 0.05499993720150087, 0.027774939881055616, 0.03104266434093006, 0.055767072990420274, 0.020243150283931755, 0.012296490858716425, 0.058857205222011544, 0.016289262057398446, 0.11035756731871516, 0.059756146438303404, 0.10194564252742566, 0.025791203261178453, 0.019657241391541902, 0.07957232432090677, 0.08634215831989422, 0.037484984859474935, 0.047478608175879344, 0.04716660929261707, 0.04664957355998922, 0.03651919098047074, 0.03003500034537865, 0.025712186798045877, 0.12282800089451484, 0.033628844903432764, 0.09295131734688766, 0.052756283766939305, 0.028044996288372204, 0.054784324747743085, 0.01994564925553277, 0.019508533550833818, 0.13975037058116868, 3.6794753232970834, 21.035754829645157, 37.661796882748604, 37.49184340238571, 29.00918237864971, 23.53118732571602, 20.813901834189892, 30.415671207010746, 25.133639238774776, 10.634499806910753, 1.6238337219692767, 0.3089617774821818, 0.6118469091597944, 2.4441250367090106, 4.3304533045738935, 6.093071848154068, 13.49588306620717, 12.41741543635726, 7.8811224270612, 1.6141542163677514, 0.898036805447191, 0.486182130407542, 3.7384543335065246, 9.367352351546288, 14.92731660604477, 21.158628836274147, 40.86057923734188, 48.36898393929005, 51.94023370742798, 58.44955801963806, 49.57014128565788, 59.40600089728832, 63.49082350730896, 57.3567670583725, 58.07042956352234, 61.36819280683994, 60.07590115070343, 63.6350903660059, 61.209475323557854, 59.75752003490925, 55.583759397268295, 53.88492755591869, 53.36448088288307, 57.311925664544106, 59.09469500184059, 54.935844764113426, 63.27214524149895, 60.19947811961174, 46.694858372211456, 45.60127705335617, 59.93539609014988, 58.531967997550964, 61.119195967912674, 58.7743303924799, 58.02522338926792, 53.13252992928028, 53.684089332818985, 51.57054394483566, 54.26458798348904, 53.49663019180298, 56.54406666755676, 58.97548779845238, 56.40005059540272, 57.56244242191315, 54.499495178461075, 53.092392683029175, 55.091894790530205, 55.3729847073555, 57.49640196561813, 58.19868788123131, 51.565923392772675, 42.35117085278034, 32.688798531889915, 23.414347395300865, 17.400801479816437, 11.571938954293728, 5.479249460622668, 2.4491987144574523, 1.4452188438735902, 1.9269731431268156, 3.015457154251635, 2.851835321635008, 3.398902891203761, 6.004259213805199, 4.740091748535633, 4.007953684777021, 2.832045271061361, 0.6215723091736436, 0.8967607270460576, 0.2363763059838675, 0.21106679923832417, 4.938500477001071, 22.29059189558029, 35.311072021722794, 32.74010717868805, 26.829474940896034, 27.62641567736864, 26.840462051331997, 10.00739285722375, 1.2202076241374016, 0.023768258979544044, 0.025021137844305485, 0.06340633670333773, 0.12884706346085295, 0.07372490566922352, 0.029696439996769186, 0.03165227186400443, 0.017980251104745548, 0.02301985314261401, 0.005522334777197102, 0.011675831829052186, 0.025216602844011504, 0.04700433499237988, 0.0471691474376712, 0.017349876434309408, 0.05492656848218758, 0.054423470282927155, 0.043042921388405375, 0.0817556559923105, 0.06518054462503642, 0.03146663846564479, 0.049370212727808394, 0.013959080697532045, 0.03203925734851509, 0.026349788131483365, 0.06352047901600599, 0.06135110343166161, 0.027633198951662052, 0.023571265155624133, 0.016927264150581323, 0.03269588363764342, 0.02748180824710289, 0.03408877608308103, 0.04482063224713784, 0.21817805827595294, 0.16097545274533331, 0.17204850388225168, 0.17230070050572976, 0.10735336836660281, 0.22768008668208495, 0.15076758252689615, 0.14662169327493757, 0.1091711329354439, 0.107352440682007, 0.1272608118597418, 0.17136301175924018, 0.16903614130569622, 0.10588594202999957, 0.1409481227165088, 0.08786481528659351, 0.18598805589135736, 0.17468697245931253, 0.09888175263768062, 0.19729380001081154, 0.17046312801539898, 0.14748176821740344, 0.11838470338261686, 0.10107535563292913, 0.24864786624675617, 0.17401464603608474, 0.1187736852443777, 0.19907814566977322, 0.22000829834723845, 0.14942855515982956, 0.09506327667622827, 0.10575292690191418, 0.07430543584632687, 0.21296450053341687, 0.10095441524754278, 0.12142858497099951, 0.15098768868483603, 0.1370037710876204, 0.14120619714958593, 0.13977621216326952, 0.09877316901111044, 0.17129967687651515, 3.4720525285229087, 22.125245667994022, 43.67564678192139, 46.71439312398434, 41.32475472986698, 34.15485866367817, 22.22559828311205, 29.091694951057434, 29.180800169706345, 14.382637683302164, 2.3596805054694414, 0.4635475465329364, 3.3735195407643914, 9.905762560665607, 5.830459864810109, 11.085150875151157, 17.6562237739563, 14.499422516673803, 13.225521873682737, 1.8644952331669629, 0.7108988659456372, 0.1245028426637873, 2.6284267846494913, 8.993041086941957, 13.830279372632504, 21.293354406952858, 37.95886494219303, 49.663551673293114, 52.152972891926765, 61.40261135995388, 56.70058786869049, 59.62329223752022, 64.57437336444855, 55.255141630768776, 60.09617306292057, 60.87698556482792, 59.79871742427349, 65.5627915263176, 63.4117079526186, 61.87480442225933, 57.73281767964363, 55.525155141949654, 56.71875089406967, 60.47707602381706, 61.41888968646526, 57.80861981213093, 65.45635163784027, 60.383000671863556, 48.806557059288025, 48.14765341579914, 59.755734130740166, 57.755829244852066, 63.880956172943115, 62.59035162627697, 58.44190143048763, 55.76691336929798, 58.03382992744446, 53.76040443778038, 57.86464400589466, 56.66341446340084, 60.57862937450409, 61.82612523436546, 59.093840047717094, 58.432094156742096, 54.99757245182991, 53.12570929527283, 54.9828976392746, 55.9247113019228, 57.690415754914284, 58.63646239042282, 51.50575362145901, 41.59770168364048, 30.589137598872185, 23.177880384027958, 15.952066518366337, 11.451464518904686, 5.212215464562178, 2.0113306352868676, 1.818426267709583, 2.227950836531818, 2.953728991560638, 6.82914650067687, 8.669471349567175, 7.981350123882294, 12.297618314623833, 11.23393664136529, 5.821432499215007, 5.033436007797718, 2.715952000580728, 0.9994742623530328, 1.0435932199470699, 6.5772774908691645, 25.750063061714172, 37.58985914289951, 37.3710972815752, 34.52784284949303, 34.80170175433159, 30.090009681880474, 8.930347301065922, 1.001118030399084, 0.12164651663624682, 0.10385287299868651, 0.11289741189102642, 0.26372971711680293, 0.08205256701330654, 0.12604343733983114, 0.15202669543214142, 0.13235452759545296, 0.128309644642286, 0.0982083501003217, 0.10731403453974053, 0.1293437829008326, 0.11893810064066201, 0.1450120788649656, 0.10516283786273561, 0.13742727023782209, 0.21213231550063938, 0.1334701685118489, 0.3233135479968041, 0.13976411515614018, 0.12787462736014277, 0.1335049603949301, 0.15829686366487294, 0.10219341595075093, 0.14635018596891314, 0.08975767777883448, 0.2331768479780294, 0.17652243725024164, 0.11940859258174896, 0.10912862271652557, 0.12343530033831485, 0.1884632371366024, 0.15466204698896036, 0.1289200462633744], [0.04266783995262813, 0.03906436788383871, 0.06231081541045569, 0.024873947695596144, 0.02984981965710176, 0.045048746178508736, 0.019839080559904687, 0.0421390931296628, 0.10254854103550315, 0.006134779159765458, 0.037840904042241164, 0.029862037263228558, 0.031175913245533593, 0.03882922952470835, 0.05173433157324325, 0.04317091959819663, 0.01086390371710877, 0.04002911533461884, 0.04596144310198724, 0.09871235000900924, 0.06446950035751797, 0.03490237031655852, 0.014726992030773545, 0.05377284425776452, 0.009951018473657314, 0.0594867134350352, 0.02432141875033267, 0.005115635067340918, 0.024553325056331232, 0.07348804181674495, 0.0138508653617464, 0.05121705835335888, 0.032675556212780066, 0.052680439985124394, 0.059754702961072326, 0.0394145205791574, 0.03690715238917619, 0.024831647133396473, 0.053253103396855295, 0.10236016911221668, 0.04337330326961819, 0.06317961800959893, 0.03382105744094588, 1.1694535100832582, 10.925980266183615, 27.076226100325584, 35.6081248819828, 26.62435434758663, 26.508025489747524, 15.80716984346509, 20.61536628752947, 26.91817168146372, 15.351029969751835, 3.0660932371392846, 0.19995451817521825, 1.671195924282074, 3.232850139029324, 5.616112416610122, 19.000287652015686, 16.794405318796635, 6.7969712521880865, 2.347045708447695, 1.851026974618435, 0.5654501519165933, 0.1904626126633957, 0.5574951600283384, 2.0024308003485203, 5.134325344115496, 10.108938608318567, 17.38901261240244, 33.23852263391018, 42.097055688500404, 55.500673055648804, 49.419604763388634, 55.08903734385967, 63.20764370262623, 58.15505862236023, 59.86635759472847, 58.99607889354229, 60.99494643509388, 60.211170092225075, 56.54155880212784, 56.80798150599003, 55.11122055351734, 53.475248739123344, 53.95708568394184, 57.37868808209896, 61.508922055363655, 56.577546671032906, 64.76114094257355, 44.48186472058296, 37.859002500772476, 59.924277886748314, 54.65092845261097, 57.06946827471256, 58.00920344889164, 55.04806034266949, 52.15983532369137, 54.309778958559036, 53.62985484302044, 53.086955174803734, 54.02014710009098, 54.56474147737026, 56.35375767946243, 57.361285015940666, 55.313168317079544, 55.850018709897995, 56.95705510675907, 53.89234095811844, 56.94609649479389, 51.914634481072426, 40.666063874959946, 31.663700938224792, 19.194542728364468, 12.013119030743837, 7.222394999116659, 2.7190041868016124, 1.1099668708629906, 0.654926800634712, 1.1939051980152726, 1.1543144099414349, 4.195623714476824, 3.862733314745128, 2.225744342431426, 0.9682600060477853, 4.688334725797176, 3.03435567766428, 3.0031265784054995, 1.607181471772492, 0.5750914814416319, 0.8087738358881325, 0.9448716673068702, 5.533368056640029, 17.37323395907879, 26.934888884425163, 25.645249485969543, 22.921445444226265, 24.18802957981825, 20.753321684896946, 6.790363406762481, 0.14671314071165398, 0.019866883267241064, 0.0930604427412618, 0.01225532856551581, 0.11444429997936822, 0.04007532144896686, 0.05251503382169176, 0.03905110199411865, 0.06744172016624361, 0.025334617312182672, 0.04011773518868722, 0.019076401367783546, 0.1283597099245526, 0.056573832043795846, 0.052807636675424874, 0.03371207305463031, 0.0128781676539802, 0.008095854300336214, 0.05639436589262914, 0.02987775966175832, 0.0879408631590195, 0.028551443429023493, 0.024237116340373177, 0.06854973180452362, 0.024956242596090306, 0.058555715149850585, 0.0324838854430709, 0.06886551564093679, 0.04513830484938808, 0.08795119385467842, 0.027165406572748907, 0.04081699044036213, 0.008654601515445393, 0.03779589278565254, 0.06823018527938984, 0.01535682122266735, 0.07291724119568244, 0.08051064389292151, 0.06766503240214661, 0.013153416311979527, 0.036919965568813495, 0.02121637862728676, 0.015334190356952604, 0.06073903197830077, 0.016814587579574436, 0.024765672060311772, 0.029011224323767237, 0.07510673269280232, 0.015071081379574025, 0.039059503105818294, 0.04082384788489435, 0.06181822973303497, 0.019808207216556184, 0.00546106074580166, 0.061802629788871855, 0.04670617345254868, 0.0841786123055499, 0.04019156775029842, 0.024745500486460514, 0.0449064022541279, 0.02485717886884231, 0.031977039398043416, 0.034836185586755164, 0.015753116022096947, 0.020611832551367115, 0.044706927801598795, 0.03189438270055689, 0.033497989425086416, 0.060411585291149095, 0.013374659811233869, 0.04518149413343053, 0.040450091182719916, 0.027667753347486723, 0.011774230406444985, 0.04967462686181534, 0.08466165396384895, 0.08426535452599637, 0.04529150639427826, 0.03702569563756697, 2.92263169772923, 18.071680180728436, 34.166645631194115, 40.37730976939201, 25.87368942797184, 20.654595382511616, 18.53036116808653, 31.015070043504238, 27.84844346344471, 13.02460290491581, 2.6466570189222693, 0.1705302923801355, 0.7630789722315967, 1.106525205541402, 2.9383635660633445, 11.456594243645668, 15.499767288565636, 10.787679087370634, 4.327154131606221, 3.6868716264143586, 4.489010246470571, 1.365070219617337, 2.063737898133695, 3.2562571205198765, 6.861073337495327, 12.21413679420948, 22.85388506948948, 36.753136441111565, 48.02607513964176, 58.48408676683903, 52.127734646201134, 59.42307338118553, 61.563958302140236, 60.29389165341854, 60.37346698343754, 60.306347385048866, 62.02170833945274, 62.26524107158184, 58.33330325782299, 59.355254620313644, 56.577246487140656, 56.91649228334427, 55.49717724323273, 60.19802659749985, 63.08829590678215, 58.19464109838009, 64.32079017162323, 47.59852208197117, 41.08280271291733, 59.170983508229256, 56.13639794290066, 58.764629513025284, 59.296027198433876, 57.087179124355316, 54.556469321250916, 56.448026821017265, 56.52704358100891, 55.43330267071724, 55.57574562728405, 56.71571105718613, 57.76323884725571, 57.23882518708706, 56.61677196621895, 57.06919088959694, 55.74689604341984, 55.52310325205326, 56.9468754529953, 52.2099432349205, 44.50303718447685, 35.73888346552849, 22.15190313756466, 13.703526724129915, 9.570348858833313, 3.9008865924552083, 2.079515364021063, 1.4002647623419762, 2.155480175279081, 2.796945129521191, 3.354035373777151, 4.220257792621851, 4.07898897305131, 3.3958879904821515, 4.906465820968151, 5.234888372942805, 1.5707504516467452, 1.3322043581865728, 0.06621057880693115, 0.4115767258917913, 0.5141880526207387, 6.419053506106138, 19.017738215625286, 31.56448446214199, 28.87846939265728, 26.688276417553425, 28.944487050175667, 26.681144200265408, 11.031016130000353, 0.6316994782537222, 0.04306385737436358, 0.06266004784265533, 0.030853696844133083, 0.08767870691372082, 0.01164122548289015, 0.0689022519509308, 0.02763395223155385, 0.012388637769618072, 0.04548301389149856, 0.03341281684697606, 0.05899037620110903, 0.03523801773553714, 0.0635188611340709, 0.06485217396402732, 0.010249712504446507, 0.042081127685378306, 0.06614503974560648, 0.03966394157032482, 0.018196403470938094, 0.022460231120930985, 0.013295750959514407, 0.025398670222784858, 0.05326058053469751, 0.04776895118993707, 0.05274055394693278, 0.07064489633194171, 0.030393071756407153, 0.03458613377006259, 0.038613810029346496, 0.0634521123720333, 0.003960024860134581, 0.008047685205383459, 0.013558752325479873, 0.017401557743141893, 0.0820444330747705, 0.15161325980443507, 0.18246441293740645, 0.1920815632911399, 0.1469976207590662, 0.08711126080015674, 0.13354190450627357, 0.17058019438991323, 0.14736991171957925, 0.2131996871321462, 0.1771997063769959, 0.09798672996112145, 0.1449456121190451, 0.12631092220544815, 0.24415230669546872, 0.16833273373777047, 0.19808662153081968, 0.10649934192770161, 0.20416843268321827, 0.18601414980366826, 0.2728707203641534, 0.19580708525609225, 0.13751203834544867, 0.12411187926772982, 0.12224715159391053, 0.0966090070141945, 0.1717765216017142, 0.1345709664747119, 0.1723251468501985, 0.11787982773967087, 0.15711678948719054, 0.10772200796054676, 0.10695921373553574, 0.17476759938290343, 0.10653314675437286, 0.10989497182890773, 0.10029447526903823, 0.20000473188702017, 0.09546033310471103, 0.18478096753824502, 0.22635726782027632, 0.14493617200059816, 0.1791107960161753, 0.13684150791959837, 2.8026505233719945, 17.91540216654539, 39.66116599738598, 47.57962189614773, 37.61485420167446, 33.45015227794647, 22.839833423495293, 30.94298031181097, 32.39236883819103, 19.36338286846876, 3.7787454714998603, 0.43994253035634756, 2.9813860449939966, 8.438497893512249, 14.006416071206331, 33.74878205358982, 28.281314335763454, 16.330119632184505, 9.07645421102643, 5.581715712323785, 2.9904955811798573, 0.4938565904740244, 0.7699965010397136, 2.408712599426508, 6.23060024343431, 11.108234636485577, 19.35692321509123, 35.374821200966835, 47.30678133666515, 58.448634669184685, 59.64870527386665, 60.53137890994549, 60.863142907619476, 59.15579192340374, 60.250144600868225, 61.637746542692184, 63.013481721282005, 63.59865792095661, 60.23853242397308, 61.31007872521877, 59.23968382179737, 58.678191751241684, 58.129269406199455, 62.560686618089676, 64.59248319268227, 59.0315005928278, 64.06197845935822, 50.061964094638824, 43.21376636624336, 59.26359973847866, 55.63304275274277, 57.43424870073795, 61.90670371055603, 60.50598867237568, 57.031268924474716, 59.19106923043728, 59.519914984703064, 57.371821850538254, 58.924996107816696, 59.3252020329237, 59.762360975146294, 58.52327026426792, 57.23769284784794, 57.35656566917896, 57.39877760410309, 55.80064795911312, 57.93957218527794, 51.607367768883705, 41.97178781032562, 32.84433178603649, 21.53946340084076, 14.017646368592978, 8.175508305430412, 3.3752429857850075, 1.7651315149851143, 1.4721664041280746, 2.4351810291409492, 3.2191243255510926, 8.974045906215906, 8.229701947420835, 5.802321899682283, 5.566990077495575, 10.953285600990057, 11.59812904894352, 9.11172391846776, 6.138242874294519, 1.8392346636392176, 1.340528167784214, 1.4584405906498432, 8.412708677351475, 22.42966253310442, 35.12581296265125, 34.553806856274605, 33.071612790226936, 38.21899138391018, 30.573691427707672, 11.179306972771883, 0.5122962885070592, 0.185735963168554, 0.15075330360559747, 0.30593396339099854, 0.23906813497887924, 0.13096389127895236, 0.15787682292284444, 0.12928049254696816, 0.20230838796123862, 0.09230090654455125, 0.09720879592350684, 0.11469234057585709, 0.2991377905709669, 0.11673271976178512, 0.13190735393436626, 0.11196540799573995, 0.13889316032873467, 0.22211052069906145, 0.12165746331447735, 0.11624449791270308, 0.21150579443201423, 0.09199540145345964, 0.1757503958651796, 0.15748596342746168, 0.09837768593570217, 0.11875312033225782, 0.12434306569048204, 0.16331979335518554, 0.21440422249725088, 0.1152757354429923, 0.20384608826134354, 0.15832396689802408, 0.09377713475259952, 0.17551902390550822, 0.1577935242676176, 0.12880636408226565], [0.0723965058568865, 0.06032795638020616, 0.061255548207554966, 0.03853388443531003, 0.036598070146283135, 0.010920849636022467, 0.03416121340706013, 0.03309715917566791, 0.03520338541420642, 0.01565330458106473, 0.04215337576169986, 0.04518191344686784, 0.04396731827000622, 0.036554587713908404, 0.01511751755970181, 0.04139793622016441, 0.048471423651790246, 0.016126937662193086, 0.055243413589778356, 0.03833987590041943, 0.0824543583439663, 0.045905581646366045, 0.03327303333207965, 0.034050176982418634, 0.02144302681699628, 0.05101204376842361, 0.06990691210376099, 0.022289090011327062, 0.03738814943062607, 0.048451099937665276, 0.021883107401663437, 0.048778238633531146, 0.01440849471691763, 0.04197569076495711, 0.05057723799836822, 0.021259486275084782, 0.05567443811742123, 0.051523754591471516, 0.07288154389243573, 0.11909279390238225, 0.09070366373634897, 0.07596797280712053, 0.052495507916319184, 0.18528645916376263, 1.0013610986061394, 7.250457443296909, 26.860163994133472, 38.04842233657837, 39.90585766732693, 24.845702089369297, 10.72283461689949, 28.176346868276596, 24.64536353945732, 16.205351427197456, 4.551954818889499, 1.494721518829465, 1.8913969583809376, 2.102028918452561, 6.630909712985158, 9.378323312848806, 7.169204978272319, 2.213747911155224, 2.293775179423392, 9.419256616383791, 3.940570238046348, 2.1071612555533648, 0.1625560491811484, 0.32333474373444915, 1.3332132040522993, 4.308444885537028, 10.508950743824244, 21.203268840909004, 29.20760203152895, 48.4875375777483, 44.07495595514774, 46.47723264992237, 56.632556319236755, 57.0399134606123, 59.07617099583149, 61.89770199358463, 59.82990235090256, 63.943409621715546, 59.87366080284119, 59.979811906814575, 54.93036545813084, 59.93362158536911, 58.66789050400257, 63.4954896569252, 58.79633881151676, 61.49721868336201, 39.912013337016106, 44.824659526348114, 57.778080850839615, 59.166419953107834, 60.92105560004711, 58.30963812768459, 60.72749398648739, 60.78878849744797, 55.95863588154316, 56.195393577218056, 57.491720616817474, 57.7032894641161, 58.38762514293194, 58.8448204100132, 57.71030768752098, 59.32928681373596, 54.66938026249409, 54.645908921957016, 52.483665347099304, 43.77807788550854, 33.62767495214939, 20.111680515110493, 8.863004464656115, 4.2013495322316885, 1.550052606035024, 0.6183250271715224, 0.3911934024654329, 0.5455338768661022, 1.0674745822325349, 1.5478467056527734, 2.1297030709683895, 0.7797320536337793, 3.069994915276766, 2.3524578055366874, 2.7169266482815146, 5.005596801638603, 1.8764699343591928, 0.9354670532047749, 0.48147943743970245, 0.23357582656899467, 1.1197844753041863, 10.609272960573435, 18.217875435948372, 29.47488158941269, 27.09817372262478, 18.33333984017372, 31.492584720253944, 20.516731180250645, 9.02891306206584, 0.3720829216763377, 0.08966106499428861, 0.0344715535902651, 0.049861443985719234, 0.09156345666269772, 0.09113056192290969, 0.017242162975890096, 0.03200425024260767, 0.04878939682384953, 0.09039692668011412, 0.003241302842980076, 0.03781832419917919, 0.03528265420754906, 0.03791349350649398, 0.03225358588679228, 0.029667991620954126, 0.03878599942254368, 0.03968753073422704, 0.010930298103630776, 0.03265778177592438, 0.01864168094471097, 0.014473434493993409, 0.04442049961653538, 0.0637382325658109, 0.0192776792391669, 0.04416394658619538, 0.009326313811470754, 0.0692224144586362, 0.05892815825063735, 0.0071043955631466815, 0.01740832612995291, 0.1002225760021247, 0.04484808800043538, 0.06539264300954528, 0.036911130300723016, 0.033249295738642104, 0.036841654145973735, 0.028722744100377895, 0.01383486187478411, 0.08098715465166606, 0.05605654398095794, 0.0787344470154494, 0.06142514008388389, 0.05202078573347535, 0.0456865516025573, 0.03851575747830793, 0.0368894447456114, 0.06055927267880179, 0.029799999283568468, 0.01701150533335749, 0.02109793742420152, 0.020555407063511666, 0.04616907375748269, 0.05632177271763794, 0.08406197637668811, 0.06434444105252624, 0.0568785764335189, 0.09009718065499328, 0.039905874291434884, 0.0848718301858753, 0.057817504566628486, 0.07015085604507476, 0.042033225763589144, 0.028686503173958044, 0.0043108923364343354, 0.033626666700001806, 0.005773281809524633, 0.02703619124076795, 0.04369809677882586, 0.02831351273925975, 0.014143750231596641, 0.04301034852687735, 0.04544160947261844, 0.02917133897426538, 0.02655586398759624, 0.009251784558728104, 0.05790743060060777, 0.04003227317298297, 0.03613036125898361, 0.03329621802549809, 0.13509915297618136, 2.2571712685748935, 14.518785327672958, 35.04617303609848, 41.303954645991325, 38.09804767370224, 19.430724754929543, 13.167223501950502, 34.36164356768131, 29.396326504647732, 20.490909665822983, 4.482888774946332, 0.5482174828648567, 0.9763371257577091, 0.8945397462230176, 3.205065317451954, 8.699829820543528, 9.164160154759884, 7.126827277243137, 3.8179092574864626, 11.987083777785301, 6.766717750579119, 3.012714651413262, 0.726867449702695, 0.9550089889671654, 3.1748968362808228, 5.554368579760194, 12.256971895694733, 23.02091270685196, 34.5967635512352, 52.393807768821716, 46.060208827257156, 50.36301054060459, 56.68253883719444, 58.94117943942547, 58.67328241467476, 62.72927217185497, 61.536516174674034, 63.45599837601185, 62.49061077833176, 62.04580284655094, 57.75152787566185, 60.68166844546795, 60.341100320219994, 64.25023555755615, 60.42966216802597, 62.04437032341957, 43.05200904607773, 44.05299313366413, 58.39097656309605, 58.745558336377144, 60.77693313360214, 59.077497124671936, 62.042538821697235, 60.5270129442215, 59.183287248015404, 57.21998579800129, 58.24902758002281, 58.91056448221207, 60.27581222355366, 59.607846066355705, 57.56851069629192, 57.99720749258995, 55.10314978659153, 56.81065656244755, 52.880850434303284, 45.64995624125004, 38.38266380131245, 22.242418080568314, 13.75963356345892, 6.746704699471593, 3.256871737539768, 1.7318711872212589, 1.6989805083721876, 1.4959531277418137, 2.450323454104364, 3.3186027500778437, 4.489054894074798, 4.950736295431852, 4.9331555888056755, 3.817592211998999, 4.951331438496709, 3.4054390154778957, 1.976634815800935, 0.9626288863364607, 0.18262320285430178, 0.3612288337899372, 1.0441658017225564, 10.690579097718, 22.580742426216602, 32.535267770290375, 31.322652138769627, 20.858798325061798, 31.677610091865063, 25.066836923360825, 13.822986613959074, 0.9284693724475801, 0.12407670888933353, 0.048995795514201745, 0.04344906541518867, 0.020598681694536936, 0.06428118038456887, 0.020098347995372023, 0.021053174787084572, 0.06450308253988624, 0.018442375330778304, 0.09026045314385556, 0.02206710065365769, 0.04732011511805467, 0.0739931029966101, 0.007405737669614609, 0.012241559870744823, 0.06670629634754732, 0.005489625082191196, 0.018071535268973093, 0.022378986359399278, 0.06016273575369269, 0.05664022086421028, 0.02005950955208391, 0.04181133845122531, 0.06412217524484731, 0.04703566475654952, 0.01981253022677265, 0.0719093601219356, 0.045035810544504784, 0.04188727129076142, 0.048582207746221684, 0.007502199241571361, 0.06768642851966433, 0.03895348731020931, 0.060445943017839454, 0.046175548995961435, 0.05396198059315793, 0.12517188879428431, 0.1125377745484002, 0.18676455016247928, 0.14396652637515217, 0.15325468266382813, 0.16671182384015992, 0.14472433336777613, 0.14681638829642907, 0.06269637597142719, 0.12787719519110397, 0.1470828935271129, 0.1415100324084051, 0.15026992798084393, 0.10773062429507263, 0.09305092840804718, 0.12901677779154852, 0.17762494215276092, 0.1299365659360774, 0.3301531512988731, 0.12310940845054574, 0.1391808019252494, 0.1410264044534415, 0.17799815337639302, 0.11817112812423147, 0.07367054335190915, 0.14777773671085015, 0.1631637939135544, 0.0896913223550655, 0.21456820744788274, 0.1623306589317508, 0.07695471751503646, 0.2177822115481831, 0.1144440624921117, 0.09504099740297534, 0.10377943748608232, 0.11406403093133122, 0.10796590737299994, 0.2144768787547946, 0.23552296974230558, 0.19802379130851477, 0.176306041830685, 0.23024411784717813, 0.18486916436813772, 0.29338489926885813, 2.0617838529869914, 14.784153588116169, 40.13163015246391, 49.17169466614723, 53.1487550586462, 30.321839042007923, 17.2748002409935, 37.330667451024055, 31.515463292598724, 21.12404689192772, 5.800724560394883, 1.7663886537775397, 2.3015322256833315, 5.1796588115394115, 15.547604821622372, 21.570287346839905, 17.671398259699345, 5.155159151181579, 7.661496587097645, 17.193013429641724, 8.746051490306854, 4.326539039611816, 0.35939023713581264, 0.4715006682090461, 2.381661138497293, 4.466780964285135, 11.788497883826494, 22.242456078529358, 33.599602058529854, 51.43554478883743, 51.71115159988403, 49.65477034449577, 58.32099951803684, 60.41807658970356, 60.7130965590477, 62.53779284656048, 60.86036145687103, 65.63235059380531, 64.38191369175911, 65.08593991398811, 60.110008120536804, 63.260867446660995, 62.842373102903366, 66.63823261857033, 61.18303254246712, 62.3622802644968, 45.97276031970978, 49.962295442819595, 59.04365614056587, 59.84010860323906, 61.13196708261967, 59.93330620229244, 64.16172310709953, 63.54786604642868, 61.38301961123943, 61.9671318680048, 60.482532531023026, 61.33966013789177, 62.02314466238022, 61.88466489315033, 58.03693436086178, 60.59331938624382, 54.830419421195984, 56.93122409284115, 54.21091586351395, 46.37334622442722, 35.793444737792015, 20.705693140625954, 10.607509855180979, 5.261857425794005, 2.2272015642374754, 1.2935303896665573, 0.9179594926536083, 1.7987504485063255, 2.5268658343702555, 3.9322819327935576, 5.289705656468868, 5.055505223572254, 11.01417163386941, 8.4156459197402, 5.995907261967659, 12.52624349668622, 6.504732258617878, 3.409183477051556, 1.76967428997159, 0.8493409340735525, 1.8054953240789473, 13.026254866272211, 23.464992977678776, 37.95293726027012, 34.64467138051987, 26.829066462814808, 42.24892973899841, 30.12974414974451, 13.02902776747942, 0.5994314909912646, 0.2154949717805721, 0.1916066333069466, 0.1684955312521197, 0.22526785440277308, 0.14104846108239144, 0.09719957102788612, 0.09312924725236371, 0.15078330121468753, 0.18500183068681508, 0.20145564543781802, 0.18190070724813268, 0.12317529632127844, 0.11797881539678201, 0.07080232811858878, 0.13662953570019454, 0.13681484997505322, 0.14109401410678402, 0.07566592612420209, 0.15703251119703054, 0.0867222789383959, 0.08462764133582823, 0.1777139405021444, 0.19873695069691166, 0.12757086631609127, 0.10487082501640543, 0.06570983692654409, 0.19565354974474758, 0.171362032124307, 0.1589952246285975, 0.18234249291708693, 0.17513175640488043, 0.11938839132199064, 0.09835383330937475, 0.10896222578594461, 0.12060752473189496, 0.1174846118374262], [0.014493165417661658, 0.04640105427824892, 0.02813146205880912, 0.034304722503293306, 0.009960900169971865, 0.06833590421592817, 0.15034127805847675, 0.05760500171163585, 0.023844095339882188, 0.00680250983350561, 0.027293247076158877, 0.051507560929167084, 0.04820938986085821, 0.036992169116274454, 0.08276742591988295, 0.04862668465648312, 0.021571535253315233, 0.06996433206950314, 0.011858171947096707, 0.024791012692730874, 0.027607464980974328, 0.011916604944417486, 0.07488176546758041, 0.02284321828483371, 0.019710943197424058, 0.08319524436956272, 0.017647069471422583, 0.015892428273218684, 0.04879405751125887, 0.022481265441456344, 0.04971983107679989, 0.07432209706166759, 0.03222964791348204, 0.05696576394257136, 0.0037276039211064926, 0.053708759805886075, 0.07882248057285324, 0.0011034509088858613, 0.02040327606664505, 0.06632812757743523, 0.016299958260788117, 0.013735284210270038, 0.024521898812963627, 0.07459802014636807, 0.06731350673362613, 0.4336725699249655, 5.824612453579903, 20.231862366199493, 36.77891805768013, 36.47543594241142, 18.097870275378227, 14.456324279308319, 23.908166997134686, 23.964327983558178, 17.907105311751366, 8.666570205241442, 1.7553336219862103, 0.5031290429178625, 3.992536012083292, 8.710175715386868, 8.869261778891087, 8.140028659254313, 5.450082225725055, 8.996218666434288, 8.485806304961443, 4.04065378010273, 1.3344374508596957, 1.8612815556116402, 0.28592209971975535, 0.5459453829098493, 0.8550938253756613, 4.785545859485865, 8.392572607845068, 14.215760137885809, 29.6346041187644, 22.847793996334076, 32.322156205773354, 45.84394723176956, 50.063894391059875, 58.054451420903206, 60.799652114510536, 61.685699969530106, 61.388818100094795, 60.952753499150276, 62.129979729652405, 60.65251260995865, 62.44956538081169, 62.63641655445099, 60.91223247349262, 49.354134276509285, 47.318100929260254, 49.79629375040531, 50.89460201561451, 53.12313683331013, 62.592863291502, 61.584040224552155, 62.078116312623024, 61.58904455602169, 59.6643528342247, 58.18772166967392, 58.74897055327892, 59.3772554397583, 58.75790387392044, 55.02434201538563, 58.35282281041145, 53.83273355662823, 50.83437904715538, 42.57053308188915, 33.35643790662289, 19.638822488486767, 8.106997981667519, 2.502020155079663, 1.2546120467595756, 0.32183346804231405, 0.24846991407684982, 1.2465345114469528, 1.3402157532982528, 0.7837346638552845, 2.181180096231401, 3.757502711378038, 4.964743293821812, 5.429089777171612, 2.6727962912991643, 3.7356424843892455, 4.26927943713963, 2.3694968037307262, 1.6684082988649607, 0.4430956783471629, 0.5166005669161677, 3.3065426722168922, 12.480865381658077, 26.668209694325924, 17.93521810323, 24.27175998687744, 20.034462958574295, 21.93217422813177, 24.536776766180992, 9.338313359767199, 0.5754817323759198, 0.0131784090626752, 0.017564882182341535, 0.10947563612717204, 0.09325468505267054, 0.09223783883498982, 0.08607637297245674, 0.04629733171896078, 0.03205296852684114, 0.011524929086590419, 0.0334502322220942, 0.02926053770352155, 0.08910760836442932, 0.04758852766826749, 0.04883881643763743, 0.005701304153262754, 0.0910075286810752, 0.038544196577277035, 0.023864649119786918, 0.008960377490438987, 0.016041599956224672, 0.038493177635245956, 0.012050899349560495, 0.025026947005244438, 0.02949323068605736, 0.08198789626476355, 0.013958494400867494, 0.000436601535511727, 0.055368740067933686, 0.028753498700098135, 0.053228523465804756, 0.0727947497216519, 0.01659521058172686, 0.05287633728585206, 0.04180610259936657, 0.052885525074088946, 0.04373690368083771, 0.025438399243284948, 0.11753171595046297, 0.03119415523542557, 0.02069284539174987, 0.07685360731557012, 0.09427743876585737, 0.09844267580774613, 0.0402870042307768, 0.024893850240914617, 0.010901825608016225, 0.04487382568186149, 0.03080716047406895, 0.031283053394872695, 0.027353719124221243, 0.040535664520575665, 0.04164390622463543, 0.01186127876280807, 0.022147593990666792, 0.04093826479220297, 0.07016940231551416, 0.022846828833280597, 0.03237399934732821, 0.02161080228688661, 0.03185985056916252, 0.062767948693363, 0.03800793179834727, 0.05619535157165956, 0.03220272650651168, 0.024536083110433538, 0.044290438236203045, 0.055605952729820274, 0.025260430375055876, 0.012033401362714358, 0.0399510636634659, 0.10629436816088855, 0.02188864196796203, 0.049024115869542584, 0.10453178969328292, 0.03394186423975043, 0.030016294513188768, 0.06234030835912563, 0.05687466160452459, 0.08582249167375267, 0.016051815618993714, 0.11825529509223998, 0.13565598637796938, 1.2235413515008986, 11.994572225958109, 29.266078993678093, 41.81191898882389, 35.50034746527672, 16.7735368385911, 19.7985203191638, 31.990411207079887, 27.556761614978313, 25.559592582285404, 10.359695702791214, 1.1798472586087883, 0.2140567934839055, 0.34098592470400035, 1.1075359513051808, 3.2344543654471636, 7.8674474358558655, 7.135449489578605, 6.614634236320853, 6.110681528225541, 5.064166383817792, 1.7687438149005175, 2.5706458976492286, 0.5930006329435855, 1.0845180926844478, 2.5253266794607043, 7.272512884810567, 10.95135435461998, 18.756882213056087, 33.04785266518593, 26.213294304907322, 39.29413989186287, 49.05095994472504, 53.01241837441921, 58.95951345562935, 61.146672293543816, 62.99489311873913, 63.88487756252289, 62.8821037709713, 62.00176700949669, 62.43717044591904, 64.63099792599678, 64.31392014026642, 61.68486401438713, 54.494984820485115, 44.96273271739483, 47.90584959089756, 55.3545480966568, 56.75422579050064, 61.75019770860672, 60.9538022428751, 63.5494239628315, 62.528289556503296, 60.18797233700752, 59.29709494113922, 58.76690939068794, 59.83372114598751, 61.07062317430973, 58.28859105706215, 57.307217717170715, 55.02923235297203, 52.82335191965103, 44.6145574003458, 37.22364999353886, 24.435113221406937, 10.813943278044462, 5.231481855735183, 2.5543022621423006, 1.75743906525895, 0.9288580797147006, 1.3783679623156786, 3.4331941511482, 3.338310867547989, 4.807699620723724, 5.036089215427637, 5.19489124417305, 4.617123221978545, 5.819427156820893, 3.9929991122335196, 4.064470902085304, 1.9139430485665798, 0.3291136695770547, 0.06147880478238221, 0.2834999078186229, 2.6037668203935027, 12.552678678184748, 33.15927788615227, 22.582452334463596, 27.103630229830742, 21.07518531382084, 22.952639870345592, 32.64791652560234, 13.370365351438522, 1.6192172071896493, 0.013687463924725307, 0.07694119558436796, 0.08367419679416344, 0.00845251563077909, 0.04748458988615312, 0.027616940351435915, 0.031925237490213476, 0.03154607053147629, 0.0608314924465958, 0.02799813522869954, 0.11197003899724223, 0.07554364245152101, 0.03316230118798558, 0.02978734195494326, 0.03741589833225589, 0.09229727744241245, 0.05173650606593583, 0.05322873126715422, 0.05075471519376151, 0.022298810290521942, 0.04095560507266782, 0.03315966656373348, 0.026933446461043786, 0.01333189633442089, 0.11258044061833061, 0.030040620258660056, 0.04862207963014953, 0.03208711103070527, 0.026814637894858606, 0.06271911537623964, 0.002409398898635118, 0.01334585056611104, 0.08666333014843985, 0.05788559290522244, 0.011960889823967591, 0.029553452259278856, 0.016066641874203924, 0.16889017570065334, 0.16091159835923463, 0.1307967002503574, 0.23303716094233096, 0.1286445462028496, 0.1765577486366965, 0.21953814779408276, 0.10032488848082721, 0.13863720843801275, 0.0911885904497467, 0.12814916262868792, 0.12326630589086562, 0.15602213650709018, 0.18230979389045388, 0.11786321105319075, 0.08333407051395625, 0.09293403272749856, 0.20348010555608198, 0.15163622185355052, 0.1504100306192413, 0.10728276043664664, 0.10933029392617755, 0.16965961956884712, 0.1017658349883277, 0.13466318574501202, 0.11941739445319399, 0.16070474695879966, 0.07041258926619776, 0.16287208534777164, 0.12065715956850909, 0.14437101170187816, 0.17032697360264137, 0.09636753442464396, 0.28530267358291894, 0.08654169214423746, 0.12399066428770311, 0.19710199936525896, 0.10387526359409094, 0.10980661172652617, 0.20974721614038572, 0.12438567238859832, 0.15219179360428825, 0.10378181978012435, 0.236836007097736, 0.1445198419969529, 1.0926630743779242, 11.785134114325047, 32.96779856085777, 50.844896882772446, 48.588824942708015, 23.93207721412182, 24.059313386678696, 31.473359651863575, 30.6944964453578, 22.90524311363697, 10.429287068545818, 2.7933813957497478, 1.2831904320046306, 5.527363903820515, 14.904672671109438, 14.955647885799408, 12.666311580687761, 13.126873467117548, 14.737320151180029, 13.61903540790081, 7.744787642732263, 4.186053927987814, 4.583606645464897, 0.9103289083577693, 1.0252948268316686, 1.748716039583087, 5.651694657281041, 9.465273097157478, 15.898307003080845, 31.295570991933346, 27.642671205103397, 36.89264215528965, 50.443877801299095, 52.13590420782566, 57.622946575284004, 61.986955404281616, 64.0244896709919, 64.93987575173378, 65.97196117043495, 66.0447196662426, 63.3993624150753, 66.13953977823257, 66.76180958747864, 61.45196311175823, 54.782982766628265, 49.9201975017786, 49.87015798687935, 57.712207585573196, 56.13083504140377, 62.11255006492138, 61.67604088783264, 63.133251294493675, 63.91774579882622, 62.87979729473591, 62.3001080006361, 62.64550566673279, 61.31038270890713, 62.11526311933994, 57.91208066046238, 59.54221598803997, 55.09768567979336, 51.40429146587849, 43.30019272863865, 35.81193834543228, 21.917683705687523, 9.665035028010607, 3.969577644020319, 2.1358007937669754, 1.1205110675655305, 0.9484405070543289, 2.70920071285218, 3.6249627359211445, 1.8279231456108391, 4.8212639428675175, 8.052292317152023, 11.475209444761276, 10.196672100573778, 6.859686886891723, 8.11321634799242, 10.482423417270184, 5.280860681086779, 5.054648844525218, 1.4510896475985646, 0.5312431405764073, 4.350531427189708, 15.16298945993185, 33.34507271647453, 25.0627426430583, 31.85598772019148, 28.22009202092886, 31.435369290411472, 36.94194070994854, 13.224062751978636, 1.2496813363395631, 0.16062928538303822, 0.18570868181996047, 0.29982380219735205, 0.1872767211170867, 0.18220837198896334, 0.18063350493321195, 0.1311617626924999, 0.1638736730092205, 0.15869468450546265, 0.16921887290664017, 0.2931664406787604, 0.13704127923119813, 0.09989589001634158, 0.08888226264389232, 0.0927230624074582, 0.2582213486311957, 0.15642017999198288, 0.11429123944253661, 0.10560431925114244, 0.13743571587838233, 0.28743162809405476, 0.10299834932084195, 0.18293524626642466, 0.10850377148017287, 0.2442907023942098, 0.08867775643011555, 0.09278272365918383, 0.11072301567764953, 0.10022187096183188, 0.11158768451423384, 0.15872831863816828, 0.08366211462998763, 0.15866608213400468, 0.09781166474567726, 0.09455240448005497, 0.26737428561318666, 0.19511636841343716], [0.009196664323098958, 0.04215976194245741, 0.04924934284645133, 0.02881903033994604, 0.08119189093122259, 0.017995830639847554, 0.028743732036673464, 0.004282823847461259, 0.018322577852813993, 0.08935872887377627, 0.09600167788448744, 0.05134812163305469, 0.07237502810312435, 0.071744477172615, 0.02494889162335312, 0.0457424575870391, 0.07451878846040927, 0.013506549657904543, 0.06282605143496767, 0.02371232330915518, 0.03838099088170566, 0.011091328378824983, 0.04669016532716341, 0.04834535502595827, 0.07652222353499383, 0.08326630500960164, 0.006984327201280394, 0.019274159603810403, 0.07502542299334891, 0.028274512878851965, 0.13870042457710952, 0.06473573841503821, 0.041236478282371536, 0.04353199670731556, 0.024479273561155424, 0.06686113803880289, 0.03961449969210662, 0.05668042300385423, 0.03752883836568799, 0.041848341934382915, 0.016137181155500002, 0.06284885021159425, 0.06149050845124293, 0.04368274545413442, 0.08796715745120309, 0.06547580065671355, 0.19333853881107643, 4.541196171194315, 14.2970453761518, 34.79814134538174, 34.71363767981529, 20.977741442620754, 22.442188560962677, 33.80555860698223, 23.427555486559868, 23.318227753043175, 15.431779436767101, 4.50354921631515, 1.2619937444105744, 0.6290663976687938, 1.337919607758522, 14.208503477275372, 4.856779212132096, 10.918707456439734, 7.3983692564070225, 1.6997808404266834, 2.139513907022774, 1.415999480523169, 1.2483731377869844, 0.5006158933974802, 0.39909596904180944, 0.4136422713054344, 0.6838230625726283, 1.3199098804034293, 3.9399560960009694, 8.091698102653027, 10.773345306515694, 15.068922657519579, 24.286537393927574, 35.684755370020866, 52.27143153548241, 60.46020492911339, 59.96742457151413, 60.90173743665218, 60.30426889657974, 65.42273104190826, 62.29148246347904, 64.06456992030144, 57.577284425497055, 38.77803258597851, 43.079481571912766, 38.8851298391819, 47.67274729907513, 47.14352689683437, 65.18816962838173, 61.70032538473606, 62.779376283288, 63.44434440135956, 63.34111534059048, 58.93220812082291, 64.10614728927612, 62.548998445272446, 58.821827843785286, 51.067173555493355, 45.90136595070362, 34.203176870942116, 21.532276086509228, 10.372025091201067, 3.856421378441155, 0.9921895188745111, 0.4748181573813781, 0.4190454329364002, 0.6309220637194812, 0.7836620521266013, 1.1726667126640677, 0.3639340808149427, 4.437826042994857, 4.530765730887651, 5.618184255436063, 4.109125155955553, 3.729310599155724, 3.517336598597467, 5.125864623114467, 1.7049739742651582, 4.804955217987299, 1.2964456644840539, 0.21374458679929376, 1.06851703254506, 7.18607084825635, 14.035838842391968, 24.226589910686016, 18.827993497252464, 19.641366451978683, 28.782009668648243, 25.116521157324314, 22.004296258091927, 10.439956896007061, 0.6280834972858429, 0.01373997365590185, 0.037493846102734096, 0.06874523576698266, 0.030790156015427783, 0.04752070650283713, 0.04982357218977995, 0.14264113968238235, 0.028704338837997057, 0.05060051546024624, 0.02937343691883143, 0.028705186741717625, 0.0883748043270316, 0.07159913497162051, 0.058731708049890585, 0.03048408318136353, 0.03697328887938056, 0.0312674720044015, 0.0486021010146942, 0.06285817158641294, 0.06405901105608791, 0.025956412755476777, 0.04065287190314848, 0.04754449604661204, 0.04902535896690097, 0.02916756144259125, 0.007812083003955195, 0.027222587195865344, 0.035033890017075464, 0.01434818315829034, 0.05497206213476602, 0.008571354810555931, 0.015398178329633083, 0.04478717994061299, 0.014997404668974923, 0.09386093806824647, 0.05436033206933644, 0.005214336533754249, 0.03537680306180846, 0.05953446321655065, 0.008930531093938043, 0.03041629726794781, 0.04358405094535556, 0.02215557949966751, 0.02208344274549745, 0.0893413700396195, 0.024236611679953057, 0.07700271962676197, 0.05643026357574854, 0.04561699752230197, 0.025825633347267285, 0.054735161174903624, 0.06286378964432515, 0.0038579753800149774, 0.014632063921453664, 0.004992137519366224, 0.04218105044856202, 0.03587971572414972, 0.03389936144230887, 0.02240711746708257, 0.024776633581495844, 0.06323683017399162, 0.02430520467896713, 0.013551849424402462, 0.022944964875932783, 0.03696300271258224, 0.027660378254950047, 0.06534466316225007, 0.05168386553123128, 0.10484116137376986, 0.0373344068066217, 0.02593351193354465, 0.04268374788807705, 0.04269698780262843, 0.04657167402911, 0.04110211244551465, 0.08395901080803014, 0.054555843453272246, 0.11761316665797494, 0.00546047212992562, 0.030018869765626732, 0.09882532714982517, 0.054219487283262424, 0.012743084716930753, 0.060640240990323946, 0.4863829555688426, 8.296492863446474, 23.303091265261173, 41.6928181797266, 32.42682918906212, 19.681233912706375, 24.523901157081127, 32.619003877043724, 24.0694797411561, 29.273192211985588, 17.826257050037384, 4.474791884422302, 0.5155912460759282, 0.552872292464599, 0.49081078672315925, 8.246522694826126, 5.266622845083475, 3.5500979656353593, 5.424256911501288, 5.919295772910118, 4.139952901750803, 1.877377729397267, 2.2248053178191185, 1.3047605683095753, 2.0298506040126085, 1.2432064837776124, 1.3384854211471975, 2.4562948336824775, 5.580666018649936, 10.23662980645895, 12.742346450686455, 19.15978979319334, 29.47272140532732, 40.55817246437073, 54.81716953217983, 59.35082025825977, 59.71487492322922, 62.36101493239403, 62.07195684313774, 65.25944620370865, 63.789168298244476, 62.958574667572975, 57.417913377285004, 45.250487476587296, 45.125211998820305, 39.158794954419136, 52.28904739022255, 50.28271704912186, 62.92190283536911, 59.12431061267853, 62.7828910946846, 61.636306419968605, 61.73882491886616, 61.91964961588383, 65.88239997625351, 62.86408133804798, 61.52760565280914, 54.819821789860725, 49.765853583812714, 39.44352887570858, 26.181790195405483, 15.883047971874475, 7.093290276825428, 3.9531432883813977, 1.2531593372114003, 1.056788843125105, 2.483114507049322, 2.1457804832607508, 3.2637574430555105, 2.6050542388111353, 8.028173111379147, 10.472561996430159, 9.260955210775137, 7.733070021495223, 6.0460498463362455, 5.217182748019695, 3.595554926432669, 2.2073777904734015, 0.8209686283953488, 0.2423820469994098, 0.12263455268112011, 0.8159872738178819, 7.570645362138748, 19.294644556939602, 32.73713953793049, 22.52420336008072, 17.949910014867783, 27.944918386638165, 27.060553841292858, 26.68829921633005, 15.007878933101892, 1.8941404111683369, 0.01523267661468708, 0.1106508269731421, 0.0742871715920046, 0.01605303830729099, 0.012603320683410857, 0.06755543203325942, 0.046839385249768384, 0.025320026688859798, 0.04658003803342581, 0.05250504822470248, 0.023250007980095688, 0.039378233268507756, 0.14187776658218354, 0.003112884623988066, 0.07738206099020317, 0.03733184639713727, 0.03650148704764433, 0.039973201928660274, 0.05299657263094559, 0.024203398716053925, 0.07174386119004339, 0.030816402068012394, 0.04314260295359418, 0.057663546031108126, 0.003601018574954651, 0.005131289744895184, 0.02809026544127846, 0.021364227432059124, 0.03438911953708157, 0.06539016423630528, 0.019610009258030914, 0.028248495036677923, 0.048406044152216054, 0.0782164502015803, 0.07332494744332507, 0.047367924271384254, 0.018705385045905132, 0.04755569505505264, 0.15716146677732468, 0.1178055684431456, 0.1704152743332088, 0.13135225715814158, 0.15236630220897496, 0.12027490156469867, 0.15666390128899366, 0.08452017835224979, 0.2275852402090095, 0.14261820731917396, 0.1761863037245348, 0.11546858251676895, 0.1568056663381867, 0.22743451001588255, 0.10562682859017514, 0.09234941331669688, 0.10221357268164866, 0.14103066438110545, 0.1776071306085214, 0.08908195231924765, 0.1665183756267652, 0.12853846361394972, 0.14957092877011746, 0.1329421007540077, 0.16373903257772326, 0.21546268835663795, 0.14095535123487934, 0.1728757462115027, 0.20434792852029204, 0.1918115105945617, 0.28946303471457213, 0.15303715917980298, 0.1461895852116868, 0.13392019202001393, 0.11785457245423459, 0.11028404274838977, 0.12903620721772313, 0.19243415765231475, 0.19980638549895957, 0.14603866206016392, 0.10003649731515907, 0.29512152483221143, 0.18614260072354227, 0.1362764960504137, 0.19405215833103284, 0.30744105752091855, 0.4356690956046805, 8.029616083949804, 25.83156868815422, 49.484398886561394, 45.96975088119507, 29.599809385836124, 31.980717927217484, 43.7960509210825, 31.957162991166115, 30.599043667316437, 18.7408147752285, 5.061846608296037, 1.30336734931916, 1.6928259073756635, 3.4611692000180483, 19.1447065025568, 11.516430582851171, 22.069671750068665, 18.78210335969925, 6.2904194835573435, 5.330703556537628, 4.077726965770125, 5.476746344938874, 1.9474021531641483, 1.4593830588273704, 1.482761304359883, 1.2021471932530403, 1.7702068551443517, 4.289078749716282, 9.65879861265421, 12.566402591764927, 17.890604697167873, 28.64598836749792, 38.803928196430206, 54.18911263346672, 59.86650198698044, 61.00097291171551, 62.72430203855038, 63.49340356886387, 66.60049304366112, 64.67876896262169, 63.69909033179283, 58.15828084945679, 50.2476791292429, 45.22091366350651, 41.20859116315842, 53.047528490424156, 53.62519629299641, 62.34922036528587, 59.90598566830158, 62.53101021051407, 61.892044097185135, 62.97293409705162, 63.06771241128445, 67.06692561507225, 64.98595207929611, 61.41194745898247, 53.29929158091545, 47.084470465779305, 38.221164867281914, 22.355365119874477, 12.693262584507465, 4.549314435571432, 1.7603231105022132, 0.8339449914637953, 1.154653423000127, 2.598439031280577, 4.23641262575984, 3.174186274409294, 2.1772886300459504, 8.838805463165045, 13.168363440781832, 12.286730948835611, 11.614279132336378, 7.377583421766758, 8.67275532335043, 12.101424392312765, 7.580590853467584, 10.163979604840279, 3.4815695928409696, 0.4940119368257001, 1.6250221082009375, 8.609212283045053, 17.82485492527485, 31.322125867009163, 25.43200872838497, 28.474359177052975, 39.18781779706478, 34.16235566139221, 32.92953461408615, 15.790787972509861, 1.5510171605274081, 0.08125486958306283, 0.22280831763055176, 0.18465181899955496, 0.13187775708502159, 0.11894619005033746, 0.23112592287361622, 0.2153640569304116, 0.12332259779213928, 0.20880534168099985, 0.08973355797934346, 0.12749139714287594, 0.13885718100937083, 0.2613165200455114, 0.16881432820810005, 0.14294362423243, 0.1390044973231852, 0.17023669875925407, 0.1452640231582336, 0.16575877263676375, 0.11030585446860641, 0.1531342024100013, 0.1241372458753176, 0.12246965488884598, 0.1682712690671906, 0.1213583629578352, 0.0827038090210408, 0.23981258331332356, 0.11336723589920439, 0.16660845751175657, 0.14571026171324775, 0.11223906753002666, 0.10115155193489045, 0.1479666875093244, 0.14749141613719985, 0.24698245717445388, 0.17716111469781026, 0.15324260049965233, 0.21383250161306933], [0.014974163386796135, 0.07309633627301082, 0.036009294708492234, 0.08357267099199817, 0.04887402021267917, 0.07784496076055802, 0.016358721513825003, 0.06900714710354805, 0.0631212406733539, 0.03357469780894462, 0.00810230449133087, 0.047276521363528445, 0.05855433475517202, 0.019866688453475945, 0.02935702617833158, 0.011207272254978307, 0.06513212691061199, 0.0303116822760785, 0.08037477149628103, 0.013715700788452523, 0.03795406300923787, 0.012289990572753595, 0.06084941531298682, 0.051080903940601274, 0.024580823483120184, 0.03559680902981199, 0.02313090441020904, 0.0854133753455244, 0.07914699206594378, 0.11422100258641876, 0.04736528222565539, 0.029769389402645174, 0.06585960974916816, 0.03516345044772606, 0.011187083982804324, 0.06156123512482736, 0.008624112233519554, 0.04569366137729958, 0.021743732067989185, 0.03279591030150186, 0.080911522381939, 0.01632386654819129, 0.052805009472649544, 0.0931790453614667, 0.11531840151292272, 0.042474020665395074, 0.2709566324483603, 0.1210558413004037, 1.6874202224425972, 15.615514777600765, 37.17157378792763, 31.900204047560692, 26.877116784453392, 17.669513560831547, 20.881659798324108, 19.163703583180904, 23.220762982964516, 19.1240831092, 7.840249445289373, 1.643308389466256, 0.48328745760954916, 3.3591836225241423, 0.9504766040481627, 0.4998523718677461, 2.655624537728727, 7.746065324172378, 4.2608120664954185, 1.6054529207758605, 0.874041864881292, 1.1752543738111854, 2.152609429322183, 1.3524129800498486, 0.5607969453558326, 0.10704301705118269, 0.15675934148021042, 0.3095917124301195, 0.5907306110020727, 0.7555543072521687, 4.87311358563602, 8.90345899388194, 27.77382306754589, 42.125440165400505, 54.29656706750393, 59.48923923075199, 59.72668468952179, 63.387195467948914, 62.01427213847637, 60.637081637978554, 53.67352209985256, 38.46115618944168, 35.358998849987984, 27.506085634231567, 42.30008639395237, 53.76083001494408, 60.26045344769955, 62.555112317204475, 63.893845081329346, 53.768125623464584, 56.529551446437836, 45.128856003284454, 41.93704627454281, 40.54813340306282, 31.2033898383379, 16.04630146175623, 8.667500205338001, 3.935741172172129, 1.3922883966006339, 0.05188811199332122, 0.14392481767572463, 1.1448936467058957, 0.3231770225102082, 0.7538506330456585, 2.086050775833428, 1.893445998430252, 2.613498098216951, 2.346764048561454, 5.918778050690889, 9.615665227174759, 6.308528836816549, 4.612006321549416, 3.804198643192649, 3.6976794339716434, 4.076939933001995, 1.7884919489733875, 0.809426688356325, 0.3755784372333437, 3.236254993826151, 8.993760198354721, 18.62702038139105, 15.597706083208323, 19.807083159685135, 22.692899107933044, 25.72743907570839, 25.530907921493053, 20.42361907660961, 13.071937914937735, 2.15825782623142, 0.0334520690375939, 0.020828187152801547, 0.02076133263472002, 0.04558734130114317, 0.04714731345302425, 0.019199660964659415, 0.07366806457866915, 0.08605647599324584, 0.05891307780984789, 0.014422037056647241, 0.04499670678342227, 0.04663054489356, 0.050321980015723966, 0.019714431291504297, 0.043359217306715436, 0.09642919205361977, 0.06577306790859438, 0.031189765431918204, 0.11671746862703003, 0.0354961738048587, 0.055997528397710994, 0.02272707031806931, 0.012093092300347053, 0.05906571161176544, 0.0749293965054676, 0.058788352471310645, 0.03382596303708851, 0.030234940495574847, 0.012630333003471605, 0.02500293110642815, 0.05765169764345046, 0.03541952479281463, 0.022032494307495654, 0.03403183109185193, 0.043465997514431365, 0.022335973335430026, 0.03357775174663402, 0.039307792321778834, 0.03913625230779871, 0.044663697699434124, 0.014156781417113962, 0.04764137229358312, 0.054858929142937995, 0.03040464554942446, 0.012792780780728208, 0.02514483901904896, 0.04549052442598622, 0.039633005144423805, 0.04998019874619786, 0.03430063326959498, 0.03159369785862509, 0.008646546430099988, 0.031111973512452096, 0.011461046869953861, 0.09995040076319128, 0.04543129361991305, 0.03027012757229386, 0.040077288140309975, 0.09366052850964479, 0.01823136604798492, 0.05017850060539786, 0.052094328857492656, 0.033255355374421924, 0.031034326311782934, 0.014919422574166674, 0.06709783119731583, 0.03743950233911164, 0.03732462901098188, 0.014209725304681342, 0.07334278867347166, 0.015087976371432887, 0.08894469210645184, 0.050527313724160194, 0.06944490291061811, 0.07575908050057478, 0.05798432081064675, 0.06085189408622682, 0.04199779934424441, 0.04029828487546183, 0.029475022092810832, 0.011938531697524013, 0.03798219782765955, 0.07071050960803404, 0.0533416082180338, 0.059370630406192504, 0.2983641461469233, 0.3084601747104898, 4.13069374859333, 22.883151099085808, 45.93533232808113, 36.4432592689991, 27.14434314519167, 23.294190242886543, 24.889766424894333, 27.44460493326187, 33.67567777633667, 21.301221884787083, 8.554643411189318, 1.8927737907506526, 0.37208167486824095, 1.2451865337789059, 1.195592782460153, 1.4760901685804129, 1.8222983786836267, 2.8544094460085034, 4.38818883150816, 3.9244918758049607, 2.4865948827937245, 1.7119704675860703, 4.52632044441998, 3.1455562356859446, 1.2180264224298298, 0.8030069328378886, 0.40025760827120394, 1.1542677436955273, 1.2880497775040567, 2.3025413090363145, 6.7960460018366575, 12.59021781384945, 32.11511291563511, 47.024376690387726, 56.1735637485981, 59.95072826743126, 59.77065593004227, 62.96889491379261, 61.59817546606064, 62.10516706109047, 53.947270810604095, 46.657684966921806, 40.00682584941387, 32.39988103508949, 50.45806623995304, 57.89536915719509, 61.70192509889603, 61.70645445585251, 63.96441489458084, 58.5012162476778, 62.105155661702156, 50.77233977615833, 48.58723662793636, 48.077957555651665, 37.53723956644535, 21.97912260890007, 13.373279795050621, 6.71844894066453, 2.6174422865733504, 0.44313153892289847, 1.0027767601422966, 2.5028024381026626, 1.8885520985350013, 2.2171112056821585, 3.8980460073798895, 3.655584342777729, 4.123174902051687, 3.8324627140536904, 9.328653328120708, 14.099776111543179, 11.93995775654912, 6.15937021560967, 6.756511498242617, 2.9667454306036234, 2.1521855145692825, 0.5136998381931335, 0.29476431431248784, 0.26849062414839864, 2.5720109743997455, 9.843151420354843, 24.018108397722244, 23.47888693213463, 21.082743108272552, 20.2234648168087, 28.041843585669994, 32.14855872094631, 27.286470718681812, 18.5483456030488, 4.178561680018902, 0.032325384963769466, 0.01614619824977126, 0.051314940210431814, 0.02480474613548722, 0.08476299422909506, 0.04301165470678825, 0.0070305732060660375, 0.09057191768079065, 0.05981286878522951, 0.03876896342262626, 0.024816778204694856, 0.07248279536725022, 0.0506274591316469, 0.03650657075922936, 0.054356818000087515, 0.07607764739077538, 0.04805378746823408, 0.010167989985347958, 0.04279865090211388, 0.055088271328713745, 0.029469251894624904, 0.01012758561046212, 0.0149302393765538, 0.06994585259235464, 0.036306413530837744, 0.06424042163416743, 0.03192046548065264, 0.033509084532852285, 0.028653798581217416, 0.034557475737528875, 0.012876508026238298, 0.05269116401905194, 0.02885147332563065, 0.0103319341178576, 0.013900363828724949, 0.053004699148004875, 0.024388494057347998, 0.05872219000593759, 0.06443326870794408, 0.1787975651677698, 0.21440775512019172, 0.10395145989605226, 0.18389101373031735, 0.12495209433836862, 0.11914199087186716, 0.1920767838601023, 0.21211140177911147, 0.16509544104337692, 0.21779929578769952, 0.1240407295699697, 0.11210941433091648, 0.13025117717916146, 0.08951785275712609, 0.15137681155465543, 0.2001810513320379, 0.15798710606759414, 0.08773004868999124, 0.146486904413905, 0.2588558552088216, 0.13572270545409992, 0.12665467016631737, 0.15366090461611748, 0.14720312145072967, 0.16511185734998435, 0.14407584472792223, 0.09541601204546168, 0.10228854443994351, 0.1411136958631687, 0.29628782474901527, 0.1257911219727248, 0.08647468363051303, 0.14398603001609445, 0.1455751759931445, 0.19286905619082972, 0.21944891195744276, 0.24535169155569747, 0.13080104923574254, 0.15652946865884587, 0.14488730899756774, 0.16143346176249906, 0.11081497519626282, 0.15429167076945305, 0.17306744295638055, 0.16077927342848852, 0.2908939844928682, 0.46379432547837496, 0.4337250249227509, 4.2632444109767675, 25.159348659217358, 52.42702558636665, 45.36690182983875, 36.91759541630745, 28.375965356826782, 30.3836028277874, 27.512763775885105, 31.639853417873383, 25.418703742325306, 9.380446448922157, 3.049378409050405, 0.8788863674271852, 4.013783046975732, 3.192236968316138, 3.0752353090792894, 8.714084755629301, 20.091575793921947, 10.379028115421534, 6.780284447595477, 4.118864983320236, 5.73083633556962, 6.827207654714584, 4.775826456025243, 1.8736078566871583, 0.6546336226165295, 0.3289108257740736, 0.7616045919712633, 0.7843498152215034, 1.6589767299592495, 5.66016772761941, 10.822698958218098, 30.156766399741173, 43.77558521926403, 56.01925402879715, 60.696054473519325, 61.214407458901405, 63.51160079240799, 63.6898036301136, 61.74626111984253, 59.492628648877144, 49.7631861269474, 43.02271641790867, 36.19823321700096, 52.47176058590412, 63.855102360248566, 64.12826970219612, 63.61730732023716, 65.01553729176521, 59.477064684033394, 64.54940870404243, 49.82217416167259, 44.75397191941738, 42.93147951364517, 33.24561305344105, 18.193444646894932, 9.94392866268754, 4.399261437356472, 1.922914960887283, 0.26382788841146976, 0.7896061206702143, 2.83836433198303, 1.4604804874397814, 2.432594792917371, 4.960994319990277, 5.874195992946625, 7.3149713315069675, 5.497875586152077, 12.522343955934048, 20.422361344099045, 14.160435106605291, 12.532348819077015, 12.97472583130002, 10.205905605107546, 8.696173466742039, 4.703854518011212, 2.648252695798874, 0.7007296022493392, 4.579074438661337, 12.00670687481761, 23.531958684325218, 21.423926800489426, 28.018311448395252, 30.35455908626318, 36.091732531785965, 34.83884856104851, 31.895423904061317, 19.892071299254894, 3.4916459396481514, 0.14466880587860942, 0.1929143420420587, 0.14411667769309133, 0.09229086528648622, 0.21957383025437593, 0.09919656426063739, 0.20757722086273134, 0.22715431958204135, 0.2056762095890008, 0.13255594647489488, 0.08452368128928356, 0.14357820502482355, 0.19486139615764841, 0.1877054153010249, 0.14138067606836557, 0.15190958452876657, 0.1775522413663566, 0.1181402473594062, 0.15487115451833233, 0.1336722553241998, 0.17476581822847947, 0.08765342936385423, 0.10259143717121333, 0.19125202030409127, 0.07936130947200581, 0.22043323726393282, 0.17402065743226558, 0.16121458756970242, 0.19769877515500411, 0.1784924088860862, 0.1454519497929141, 0.09939387164195068, 0.12124510380090214, 0.10671450538211502, 0.13080545759294182, 0.10590138612315059, 0.1092019840143621, 0.131024569272995, 0.12112212993088178], [0.05056017602328211, 0.06749690626747906, 0.06604273468838073, 0.04053595766890794, 0.07149961296818219, 0.02117123378411634, 0.03437737133936025, 0.012745229523716262, 0.04477731679799035, 0.03628264254075475, 0.06367111272993498, 0.012304258361837128, 0.010254099524900084, 0.04786734141816851, 0.03793769865296781, 0.05154010039404966, 0.02032956967013888, 0.010968329461320536, 0.028756897736457177, 0.040430672888760455, 0.011027610362361884, 0.015126417765713995, 0.05914323264732957, 0.034317253666813485, 0.051658031370607205, 0.042196791400783695, 0.05450669472338632, 0.01636615597817581, 0.020849817046837416, 0.008130483838613145, 0.029668186434719246, 0.06890151722473092, 0.0060612680408667075, 0.09169394848868251, 0.13193965220125392, 0.09210331714712083, 0.04596408143697772, 0.06137435862910934, 0.035970703029306605, 0.04985556617612019, 0.013580824725067941, 0.058627139442251064, 0.03282028243120294, 0.029974040335218888, 0.03257312870118767, 0.027396030818636063, 0.026001019541581627, 0.02729824173002271, 0.06136531927040778, 1.4358024741522968, 11.246125437319279, 27.219406217336655, 31.82176485657692, 25.441985093057156, 14.361725505441427, 15.388504508882761, 29.497573971748352, 30.19090186804533, 25.321732945740223, 14.886761382222176, 5.275993142277002, 0.9582755074370652, 0.4130297026131302, 0.8232473186217248, 0.66058742813766, 1.7438158462755382, 3.394315824843943, 2.872429504059255, 1.2807984603568912, 0.706114269560203, 3.748738719150424, 1.4810911752283573, 0.3623354947194457, 1.4735145005397499, 0.4795957775786519, 0.86544731981121, 0.5574876791797578, 0.12800990603864193, 0.13987619429826736, 0.8199094946030527, 5.559693519026041, 17.228492125868797, 27.781099677085876, 43.70751567184925, 46.5190190076828, 50.893773660063744, 52.294317707419395, 47.210019528865814, 44.88696478307247, 36.184379160404205, 28.365344926714897, 24.45003692060709, 33.569059297442436, 57.75604963302612, 65.57361334562302, 49.551423490047455, 46.73047386109829, 34.942932575941086, 23.11867006123066, 12.91239207610488, 4.606979666277766, 4.311392102390528, 2.951751435175538, 0.5944599921349436, 0.08326531053171493, 0.17012432275805622, 0.026297129043086898, 0.36095830611884594, 0.34943248552735895, 2.266721581108868, 2.9274025792255998, 2.2051758086308837, 3.5632025124505162, 2.574767963960767, 5.935600223019719, 2.9489714093506336, 11.135071646422148, 15.698726512491703, 14.001112505793571, 5.958920521661639, 6.735431179404259, 3.9071534061804414, 0.6419333978556097, 0.32977836672216654, 1.017551317345351, 7.039559260010719, 13.308553118258715, 23.0690124258399, 24.353867881000042, 21.24496590346098, 29.428461380302906, 23.206680938601494, 21.666009910404682, 19.403810799121857, 11.504263635724783, 2.8457972081378102, 0.09154701809165999, 0.029157308672438376, 0.01226543847224093, 0.05538124525628518, 0.06469520973041654, 0.07480195490643382, 0.0792256671411451, 0.03238581804907881, 0.015100045548024355, 0.04268709868483711, 0.023425742983818054, 0.011545938359631691, 0.0032329935720554204, 0.037470364550244994, 0.09261971834348515, 0.042755131362355314, 0.0043360868585295975, 0.031395470214192756, 0.011226595925108995, 0.04319841245887801, 0.0772037154820282, 0.10293310711858794, 0.07340949290664867, 0.015895357901172247, 0.0396877162711462, 0.03089840382017428, 0.013446865214064019, 0.01915722867124714, 0.02816080472257454, 0.04053846241731662, 0.0773177390510682, 0.05579147480602842, 0.046302170521812513, 0.05658895330270752, 0.015721886447863653, 0.046103757340461016, 0.0678559647349175, 0.01870160565886181, 0.09795510704861954, 0.10192019428359345, 0.060813992604380473, 0.0761478471395094, 0.01588869341503596, 0.018137968618248124, 0.039540511279483326, 0.049551831107237376, 0.02530314839532366, 0.05428471835330129, 0.04516655841143802, 0.009100280676648254, 0.03180423031153623, 0.06636959878960624, 0.046800370546407066, 0.08873220038367435, 0.07884202132117935, 0.05560991579841357, 0.049557968668523245, 0.031376385886687785, 0.08069577263086103, 0.0804081978276372, 0.036310844152467325, 0.02979638687975239, 0.03563270300219301, 0.032450229045934975, 0.08767458057263866, 0.03554440969310235, 0.029605473100673407, 0.015206939860945567, 0.03261897116317414, 0.01007294406008441, 0.018288049432158004, 0.031501768025918864, 0.014299014019343304, 0.03922833799151704, 0.1163976252428256, 0.06404514031601138, 0.05192272205022164, 0.04389166373584885, 0.11008908797521144, 0.030036519892746583, 0.019776148292294238, 0.028547485926537775, 0.036758926944457926, 0.06294575243373401, 0.029413746669888496, 0.015785770519869402, 0.04203442804282531, 0.12720461643766612, 0.1529617272899486, 3.431209707632661, 19.05267734080553, 32.70399011671543, 37.017279267311096, 26.376277059316635, 18.407861441373825, 16.9096265360713, 32.341390773653984, 36.95187717676163, 28.667466714978218, 17.923123352229595, 5.096185365691781, 0.726534848799929, 0.36677255819085985, 0.35336895554792136, 0.06876260202261619, 1.0919547686353326, 1.07044329168275, 2.913938001729548, 3.5091834235936403, 4.098803959786892, 3.314793216995895, 2.552812029607594, 2.393914768472314, 2.0123157324269414, 1.625959707889706, 1.7496789316646755, 1.7063481942750514, 0.6725934182759374, 1.0574453766457736, 1.736329891718924, 7.709652353078127, 20.10569203644991, 33.33225980401039, 45.91578997671604, 49.470472633838654, 54.214506670832634, 56.43020957708359, 52.409189343452454, 52.49165631830692, 42.25733868777752, 32.56297968327999, 27.315252274274826, 41.7289162427187, 60.76340585947037, 65.55997207760811, 56.01609259843826, 52.63105943799019, 40.02442270517349, 30.303917303681374, 17.783572040498257, 7.825312921777368, 7.983522657305002, 4.702942566946149, 1.1514062597416341, 0.5626523739192635, 0.25571757985744625, 0.38883423374500126, 1.3445184286683798, 2.0575786661356688, 2.574770338833332, 4.690383765846491, 5.959907993674278, 7.5153550039976835, 6.082680830731988, 5.119998687878251, 6.577367736026645, 8.206562139093876, 12.065037544816732, 6.044857185333967, 3.4556578332558274, 1.1052354122512043, 0.7870796124916524, 0.3748769295634702, 0.3648790129227564, 0.8019906654953957, 6.111896988004446, 17.249258011579514, 29.268016889691353, 26.55473068356514, 17.687674686312675, 26.221137084066868, 26.61587130278349, 27.348601184785366, 24.906800910830498, 17.086672335863113, 5.16642602160573, 0.259806071408093, 0.08081705440417863, 0.021123240949236788, 0.030828202216071077, 0.05271995934890583, 0.08727708627702668, 0.02982917125336826, 0.04450824002560694, 0.031811763110454194, 0.0573465562047204, 0.01567218296258943, 0.02140318090823712, 0.018262721787323244, 0.02940171460068086, 0.042361388623248786, 0.04403313192597125, 0.055843480804469436, 0.020004149046144448, 0.037432611497933976, 0.013630979992740322, 0.02759687638899777, 0.030608127599407453, 0.011898694137926213, 0.05860017721715849, 0.038579485699301586, 0.0696238421369344, 0.02645505064720055, 0.02265199836983811, 0.047327781503554434, 0.01447466274839826, 0.04001911489467602, 0.06254273655940779, 0.0451969938876573, 0.1026071335945744, 0.07371731349849142, 0.04361292791145388, 0.05260892663500272, 0.00691557510435814, 0.02538692202506354, 0.05731573110097088, 0.1437500270549208, 0.12847278354456648, 0.29244157020002604, 0.0957230014319066, 0.1687080823467113, 0.1346753421239555, 0.08236979061621241, 0.13542451051762328, 0.24669346486916766, 0.15536800754489377, 0.10471754925674759, 0.135516329028178, 0.08075457299128175, 0.13036422111326829, 0.1691024744650349, 0.24262772756628692, 0.18504080828279257, 0.25917361315805465, 0.23465970356483012, 0.1220238690439146, 0.10937549071968533, 0.1123515103245154, 0.20842954778345302, 0.10910874800174497, 0.1760449691209942, 0.15092423505848274, 0.1782948788604699, 0.11744901101337746, 0.12647227995330468, 0.13666373386513442, 0.10271550941979513, 0.17877601319923997, 0.07239427941385657, 0.2033306666999124, 0.1951170660322532, 0.2675158280180767, 0.19147988932672888, 0.12973749224329367, 0.15930569468764588, 0.1324382863822393, 0.1311884354799986, 0.13655025948537514, 0.14290473569417372, 0.1314850422204472, 0.0827991304686293, 0.1252290786942467, 0.17253186466405168, 0.15754398453282192, 0.13231329387053847, 2.8345175134018064, 20.493820309638977, 40.29615372419357, 46.597203612327576, 36.385547965765, 24.277467280626297, 24.77441981434822, 38.52563112974167, 39.72505196928978, 33.139553144574165, 20.05678866058588, 6.378040881827474, 1.5753647102974355, 1.2037252960726619, 2.6454776572063565, 3.4141483856365085, 6.925173047930002, 11.65379511192441, 5.871335221454501, 6.195416506379843, 5.240323981270194, 9.38601789996028, 5.505894105881453, 2.0336349634453654, 3.2858276087790728, 1.6625203960575163, 1.7950132302939892, 1.9548914325423539, 0.7341359846759588, 0.6103823252487928, 1.5987379685975611, 6.962681785225868, 20.357293635606766, 29.65689942240715, 45.37915997207165, 48.11862297356129, 53.52218762040138, 55.6572512537241, 54.03385676443577, 56.76620274782181, 48.58576610684395, 39.05067935585976, 33.60185533761978, 45.34015126526356, 65.92617362737656, 71.83297947049141, 57.72436313331127, 50.91608606278896, 38.118452578783035, 25.895809940993786, 15.549496170133352, 6.075394246727228, 5.873783715069294, 3.788345418870449, 0.8694131788797677, 0.45172204670961946, 0.35254766524303705, 0.29275021457578987, 0.6261211400851607, 1.424740911461413, 4.119149018079042, 6.356397718191147, 8.139424491673708, 12.059171609580517, 7.938800482079387, 12.910014353692532, 9.913070518523455, 18.21889378130436, 24.3883890286088, 24.06409353017807, 14.827224276959896, 12.059471793472767, 7.774886302649975, 2.233297862112522, 1.0060855513438582, 1.532497548032552, 8.678146284073591, 17.073716931045055, 32.369775250554085, 29.45069208741188, 29.339973628520966, 38.653414472937584, 32.73397050797939, 32.781650349497795, 30.87055429816246, 18.15206676721573, 4.568318165838718, 0.33115683181677014, 0.2249087142990902, 0.1052948807773646, 0.16128068324178457, 0.10927887793513946, 0.19815317733446136, 0.09945374069502577, 0.11417888570576906, 0.1409922359744087, 0.24199344363296404, 0.16705689282389358, 0.0735232864099089, 0.10659467079676688, 0.1263157610082999, 0.1511763277812861, 0.10526264930376783, 0.12054076854838058, 0.1295749025302939, 0.11615319148404524, 0.11924529040697962, 0.10655830556061119, 0.137547112244647, 0.13627236970933154, 0.17632860312005505, 0.1600529334973544, 0.19616146077169105, 0.11106676363851875, 0.12997410376556218, 0.08474962072796188, 0.13123195501975715, 0.16310742037603632, 0.15765644959174097, 0.10151832873816602, 0.1945473934756592, 0.20844537037191913, 0.12198829048429616, 0.1157630592933856, 0.1061923080123961, 0.3065742884064093, 0.19272319448646158], [0.007101328637872939, 0.010527045669732615, 0.04071900839335285, 0.036158525763312355, 0.032708526123315096, 0.055715560520184226, 0.02132785662979586, 0.04615554069459904, 0.05132434322149493, 0.059586124116322026, 0.05415765896032099, 0.02865806221961975, 0.05723550864786375, 0.03426550370932091, 0.041279775177827105, 0.0971049175132066, 0.04342267093306873, 0.04386034139315598, 0.03191742638591677, 0.08101261773845181, 0.014095167389314156, 0.01809368095564423, 0.04185363344731741, 0.028190900666231755, 0.03520870661304798, 0.037681461035390384, 0.03762720632948913, 0.04895922989817336, 0.012366599694360048, 0.037315934750949964, 0.05342542637663428, 0.021412452188087627, 0.014094126527197659, 0.05964066083834041, 0.07000436351518147, 0.05740145286836196, 0.022691287667839788, 0.07622080025612377, 0.046595367093686946, 0.0575391917664092, 0.04628841481462587, 0.07654132641619071, 0.019325644243508577, 0.07206895897979848, 0.03258578974055126, 0.04676278076658491, 0.05890847649425268, 0.04107717628357932, 0.030413961358135566, 0.06645438916166313, 0.23999510711291805, 10.940889716148376, 26.15913201123476, 39.98240455985069, 32.15179614722729, 23.3509648963809, 13.768440540879965, 13.329302854835987, 23.696468956768513, 21.992488391697407, 19.544882029294968, 12.252908013761044, 4.577928325161338, 0.5660669656936079, 0.3881723864469677, 0.891698804916814, 0.6375383993145078, 5.066432012245059, 1.751390383578837, 3.017171574756503, 2.853197786025703, 2.1126253623515368, 1.7404050542972982, 1.041609845124185, 1.606904324144125, 2.2935374546796083, 1.0614996403455734, 0.8228803414385766, 0.8546778664458543, 0.24386361124925315, 0.19044496439164504, 1.6274878196418285, 9.398736767470837, 13.131448421627283, 17.400279007852077, 18.259354010224342, 17.591137066483498, 10.975229423493147, 13.238514326512814, 28.42149641364813, 22.88196936249733, 22.903198823332787, 26.445678435266018, 33.411884531378746, 30.902483984827995, 16.116685084998608, 8.389970697462559, 4.736899444833398, 2.320750169456005, 0.5424173315986991, 0.44098266516812146, 0.007754961752652889, 0.08315723156556487, 0.006119894460425712, 0.09586538246367127, 0.2930430957349017, 0.7092462514992803, 2.774269371293485, 2.5136007461696863, 3.552819094620645, 2.8235681634396315, 5.969871059060097, 5.170842334628105, 5.013603921979666, 1.6598370275460184, 3.9671695232391357, 9.716989640146494, 12.569671366363764, 5.654027732089162, 1.292225990910083, 1.8718346580863, 0.3210468211909756, 0.9640145057346672, 3.652238859795034, 12.249095868319273, 20.127377472817898, 16.57504688948393, 16.413245871663094, 17.692905105650425, 22.541501931846142, 26.44295208156109, 21.62929628044367, 19.864184595644474, 10.41872838512063, 1.4045224338769913, 0.10131302100489847, 0.05056494803284295, 0.02943798892374616, 0.03949550744437147, 0.05826854110637214, 0.05018653806473594, 0.03357499837875366, 0.05048119666753337, 0.022766220463381615, 0.037298308743629605, 0.025363616732647642, 0.03168902672769036, 0.04743475466966629, 0.02309570620127488, 0.01818491316953441, 0.018869403393182438, 0.05403643655881751, 0.06439221309847198, 0.10419034981168807, 0.03259001256083138, 0.06479347008280456, 0.07697816196014173, 0.013232915171101922, 0.01579741481691599, 0.030909267006791197, 0.023402849583362695, 0.01904084136185702, 0.028077122005925048, 0.03345380937389564, 0.011272342835582094, 0.027291187616356183, 0.04336580015660729, 0.016092691257654224, 0.04575964943796862, 0.0861622765660286, 0.0036697746145364363, 0.03402846916287672, 0.021028700612077955, 0.018703080677369144, 0.02401115092652617, 0.022500099294120446, 0.014637645799666643, 0.033729624847183004, 0.015371007375506451, 0.04098060431715567, 0.06583796130144037, 0.038301807435345836, 0.03586205632018391, 0.021812093145854305, 0.06280144923948683, 0.09495609570876695, 0.016121000480779912, 0.01700670734862797, 0.03683730887132697, 0.03244428815378342, 0.0532604283944238, 0.020793300645891577, 0.025429005509067792, 0.05486583482706919, 0.07444901173585095, 0.02155238042178098, 0.019067079992964864, 0.049964969875873066, 0.014364103153639007, 0.02411724279227201, 0.016773229544924106, 0.04345349603681825, 0.037838703574379906, 0.05542082399188075, 0.03676687534607481, 0.083861707826145, 0.03152078184939455, 0.05888270912691951, 0.024452654579363298, 0.08023896589293145, 0.011936913815588923, 0.014861485888104653, 0.027086276932095643, 0.0200018576651928, 0.016433303644589614, 0.06108440524258185, 0.025715109004522674, 0.012513142319221515, 0.043166585455765016, 0.041760070889722556, 0.015554710262222216, 0.009607087758922717, 0.11734910309314728, 0.0190248888975475, 0.009860543250397313, 0.06398842539056204, 1.794118497055024, 16.865355111658573, 32.22326271235943, 42.57223539054394, 30.694492645561695, 23.15716579556465, 17.045566141605377, 22.022413685917854, 29.799610264599323, 27.91474800556898, 25.626765377819538, 14.008341617882252, 3.5431894613429904, 0.31061893387231976, 0.27229629806242883, 0.8536994783207774, 0.859698347048834, 1.123571447096765, 1.4012132864445448, 2.5352973444387317, 3.9627909706905484, 3.715978777036071, 3.0244106613099575, 3.7977879121899605, 2.672787504270673, 3.9585503982380033, 3.950788602232933, 2.069148807786405, 3.0397361889481544, 0.9907068859320134, 0.686524361371994, 3.06952896527946, 11.004909630864859, 17.85194557160139, 22.273665703833103, 23.569128289818764, 23.98333266377449, 17.59228080511093, 21.546189039945602, 36.492820009589195, 27.259725853800774, 27.83839490264654, 33.85924592614174, 42.58863531053066, 40.04081882536411, 22.64349415898323, 13.247046768665314, 7.875340562313795, 3.945944574661553, 1.1887324880808592, 0.5345521098934114, 0.16978401836240664, 0.23072309995768592, 0.2115132159087807, 0.6072565773501992, 1.3122135121375322, 2.081410987302661, 5.515782600268722, 6.594712380319834, 6.0139168705791235, 6.590703595429659, 2.8814024850726128, 6.38521964661777, 7.3713664803653955, 5.269126435741782, 5.649619968608022, 5.5545158218592405, 3.8782851677387953, 1.3324468326754868, 0.4350205772789195, 0.47866589622572064, 0.5382513301447034, 0.9681528399232775, 3.5161187639459968, 12.101688478142023, 27.247120030224323, 24.774389415979385, 25.12975014746189, 15.849809255450964, 19.328829422593117, 31.01513274013996, 25.84319606423378, 25.529484897851944, 16.619840785861015, 3.0921797873452306, 0.09245840512448922, 0.05110376951051876, 0.09323842459707521, 0.0027858577141159913, 0.05041117503424175, 0.028943707438884303, 0.01992363715544343, 0.031385094989673235, 0.004477923339436529, 0.05428713404398877, 0.04624523295206018, 0.09153233841061592, 0.037967117386870086, 0.03662655748485122, 0.05804178159451112, 0.061965735294506885, 0.054412787067121826, 0.07887076470069587, 0.04676784221373964, 0.017479308844485786, 0.01265995768335415, 0.02697873602301115, 0.031131184005062096, 0.029629732052853797, 0.025777480950637255, 0.08001160153071396, 0.05860966557520442, 0.03226500382879749, 0.06304304057266563, 0.12969484843779355, 0.01660747828282183, 0.09088541570235975, 0.054439174127765, 0.024127371252689045, 0.042348924253019504, 0.02797005607135361, 0.017105305378208868, 0.04634837663616054, 0.03721224558830727, 0.010547218171268469, 0.01893526714411564, 0.09732860824442469, 0.15255563892424107, 0.12766928994096816, 0.12001211449387483, 0.14734662312548608, 0.09082360222237185, 0.18581016309326515, 0.10944601701339707, 0.2091932771145366, 0.15742221294203773, 0.14366361137945205, 0.06690852416795678, 0.15955539769493043, 0.14396617014426738, 0.2586529520340264, 0.14524782949592918, 0.12215078371809795, 0.11551105562830344, 0.07081832882249728, 0.29382071807049215, 0.11541495492565446, 0.13202280242694542, 0.14049897494260222, 0.12290105791180395, 0.11980072114965878, 0.09273483286960982, 0.1453688886249438, 0.11754200211726129, 0.15834122925298288, 0.1397110367543064, 0.12541183998109773, 0.14068488293560222, 0.138508653617464, 0.27505869045853615, 0.0778395653469488, 0.24917528091464192, 0.08881621150067076, 0.12183389408164658, 0.09956712601706386, 0.11143121009808965, 0.2274002821650356, 0.16392093297326937, 0.1188644276408013, 0.1852058619260788, 0.09939707029843703, 0.10431380607769825, 0.2256112906616181, 0.2535175869707018, 0.15598715166561306, 0.20816991484025493, 1.2299397331662476, 16.238082870841026, 37.818302884697914, 52.999233081936836, 42.43343263864517, 34.73618187010288, 23.096946626901627, 22.224367149174213, 32.16170981526375, 31.084429621696472, 27.223316207528114, 16.32845152169466, 5.335275186225772, 1.087996568530798, 0.9273531823419034, 2.0404073875397444, 4.548413883894682, 11.488713920116425, 8.67649907246232, 7.119421474635601, 7.958413604646921, 6.517094420269132, 7.233066726475954, 6.239689830690622, 3.845441867597401, 5.918432744219899, 2.5224072486162186, 2.3138138791546226, 2.698958362452686, 0.7552300777751952, 0.4931748239323497, 2.272836877964437, 12.504581809043884, 17.17881929129362, 20.478700920939445, 21.48393888026476, 20.8616291731596, 15.007178820669651, 19.039347656071186, 38.44035230576992, 31.36592611670494, 30.252243876457214, 37.72253282368183, 44.0887264162302, 35.52105255424976, 20.647485964000225, 10.45671684667468, 5.95344596542418, 3.4950270457193255, 1.0413525276817381, 0.6994679511990398, 0.21446037339046597, 0.21551619720412418, 0.1891833430272527, 0.3888068039668724, 1.254353541880846, 1.7338684550486505, 7.4050939455628395, 8.41217765584588, 9.010953325778246, 9.379959125071764, 11.935596540570259, 9.879193436354399, 11.059975326061249, 7.227224539965391, 13.001834526658058, 18.069081120193005, 20.33289134502411, 12.327797245234251, 5.032335966825485, 4.208066621795297, 1.0014951601624489, 1.4835205511189997, 5.062714861705899, 14.99542985111475, 28.86613715440035, 23.14951680600643, 25.155254378914833, 25.920480117201805, 31.0426926612854, 38.71758162975311, 31.746582090854645, 30.28891760855913, 15.658059194684029, 2.375775254331529, 0.17569892050232738, 0.19274660182418302, 0.17957949195988476, 0.1380075851920992, 0.12526866485131904, 0.09148315628408454, 0.07868392902310006, 0.13952321402030066, 0.17250894714379683, 0.12832802021875978, 0.13506157061783597, 0.10965709865558892, 0.09352360968478024, 0.1563944571535103, 0.24465343449264765, 0.23369975038804114, 0.09628396859625354, 0.18459639541106299, 0.18075686472002417, 0.1710557032492943, 0.2423478933633305, 0.17799945955630392, 0.11963547454797663, 0.07308807616936974, 0.2105548806139268, 0.1722743987920694, 0.12072424971847795, 0.1471667265286669, 0.1394419340067543, 0.19085829611867666, 0.1218580584099982, 0.18387766991509125, 0.0864485526108183, 0.19277797982795164, 0.1791507235611789, 0.18009215273195878, 0.12081746346666478, 0.1658342342125252, 0.07650064930203371, 0.14333617582451552, 0.08064761466812342], [0.04066353656526189, 0.07681997318286449, 0.04607786380802281, 0.04205934194033034, 0.0796505986363627, 0.03106432948698057, 0.03656782762845978, 0.018985350980074145, 0.017644525760260876, 0.0355347061122302, 0.11343785867211409, 0.07427742719301023, 0.026967978592438158, 0.09594138580723666, 0.02895442405133508, 0.019216379696445074, 0.01959249271749286, 0.08551763225113973, 0.026891915877058636, 0.01285876884139725, 0.01969689990801271, 0.06251859449548647, 0.06223126460099593, 0.033802336765802465, 0.04232808103552088, 0.012877552599093178, 0.01792031340301037, 0.02407994801615132, 0.024670725397299975, 0.027542029820324387, 0.05982953000057023, 0.022344242715917062, 0.04483238786633592, 0.05555075920710806, 0.018661208705452736, 0.10122777050128207, 0.047076601622393355, 0.016130390504258685, 0.09346685765194707, 0.04895987185591366, 0.04413028647832107, 0.042008464006357826, 0.0023938260892464314, 0.046779263866483234, 0.01902506144688232, 0.030652550703962334, 0.017559052612341475, 0.008965067863755394, 0.031117031248868443, 0.05201823645620607, 0.041748122312128544, 0.9066373470705003, 6.388120790943503, 20.127708055078983, 36.1194634437561, 37.768240571022034, 27.20820251852274, 14.434095472097397, 13.903745580464602, 24.72789131104946, 28.564828522503376, 25.9127152338624, 19.89723712205887, 10.95216941088438, 4.040697952732444, 1.1058310302905738, 0.11754618783015758, 0.4734150232980028, 1.059772395528853, 3.8137952657416463, 1.0208415845409036, 2.3629787284880877, 2.96150432433933, 3.1501794001087546, 2.1181258046999574, 2.573069455102086, 3.824447044171393, 2.165723475627601, 3.599863895215094, 1.5377857955172658, 0.7052922074217349, 0.2764942415524274, 0.45932781358715147, 0.20637097855797037, 0.7846683450043201, 0.9210429084487259, 0.7845872431062162, 0.24028764688409865, 0.6151492882054299, 3.4976733662188053, 5.2306601498275995, 4.247013106942177, 6.954608168452978, 3.1481885444372892, 1.018943467643112, 0.0895686008152552, 0.12176418415037915, 0.20719608350191265, 0.4111043340526521, 0.4788615560391918, 0.1067624035931658, 0.39978159475140274, 0.2831570355920121, 0.797201378736645, 0.721801312174648, 0.660841598873958, 1.8358838371932507, 4.431561604142189, 3.899139161221683, 3.5522676492109895, 5.924289654940367, 1.233705806080252, 6.758098863065243, 7.175597185268998, 4.886153535917401, 4.001157749444246, 3.819017135538161, 3.153712023049593, 0.8417218085378408, 0.30796100618317723, 0.39485426852479577, 2.9075408075004816, 8.86270523071289, 19.83180083334446, 20.685723312199116, 22.46614247560501, 17.78046190738678, 13.44817092642188, 17.529770359396935, 19.95878241956234, 22.770952619612217, 16.04516912251711, 6.943309474736452, 0.5984555371105671, 0.11375402842531912, 0.026393715852464084, 0.11209708725800738, 0.06710882982588373, 0.02122390771546634, 0.06287530777626671, 0.023176275608420838, 0.047349645174108446, 0.02516483062208863, 0.023451527049473953, 0.05446461866085883, 0.04312044613470789, 0.0486201166495448, 0.051300642735441215, 0.02869698600989068, 0.0047093625562411034, 0.006220535251486581, 0.0720510286919307, 0.02571501252532471, 0.04209026723401621, 0.019020178115169983, 0.05098105168144684, 0.07894429669249803, 0.0443279834871646, 0.025327192124677822, 0.05807625064335298, 0.017233678372576833, 0.04851833851716947, 0.042117860284633934, 0.04833288323425222, 0.03581500415748451, 0.05762080574641004, 0.05909642168262508, 0.03431026634643786, 0.05874489972484298, 0.02197257515945239, 0.06403598963515833, 0.03780895087402314, 0.024746823364694137, 0.041828062749118544, 0.09623294594348408, 0.03155752187012695, 0.01963782124221325, 0.016486801359860692, 0.07762106222799048, 0.09159009976428933, 0.03122498033917509, 0.04069074369908776, 0.06146914201963227, 0.029035307015874423, 0.0216709366577561, 0.01563350593642099, 0.04058994891238399, 0.07744161834125407, 0.008694482676219195, 0.040397773482254706, 0.026176782375841867, 0.01714038855425315, 0.08315415165270679, 0.028424680895113852, 0.06145842911791988, 0.04183326520433184, 0.06945645072846673, 0.06906202150275931, 0.07223137799883261, 0.07514133903896436, 0.03311113381641917, 0.03120663073787, 0.03595863570808433, 0.0033987888991759974, 0.02869632178772008, 0.03605235782742966, 0.035856130270985886, 0.054347604236681946, 0.08375356206670403, 0.039883602439658716, 0.017146264508483, 0.061535337881650776, 0.017560243759362493, 0.026606836545397528, 0.0098446334595792, 0.02783504271064885, 0.03062634732486913, 0.02614096818433609, 0.019799164147116244, 0.06835031672380865, 0.027994181436952204, 0.018527861466282047, 0.03551512454578187, 0.011220296946703456, 0.09078063929337077, 0.014531092874676688, 0.061108417430659756, 1.792227504774928, 11.521541308611631, 28.20638805627823, 44.47865769267082, 39.51035588979721, 25.329338237643242, 15.379785876721144, 18.7734417244792, 25.063208118081093, 32.54415549337864, 31.554996371269226, 25.06918329745531, 12.187847904860973, 2.8004174306988716, 0.8308783185202628, 0.1315407923539169, 0.49536932492628694, 0.294916721759364, 1.798801627010107, 0.9013267757836729, 3.3224564557895064, 2.757037770934403, 3.3050434151664376, 3.0391783313825727, 6.114363530650735, 4.499411713331938, 4.198958510532975, 5.302170412614942, 3.6072048638015985, 2.1944710705429316, 0.7192165008746088, 1.4129792363382876, 0.9737721446435899, 1.9316381053067744, 1.9595154281705618, 1.9388872850686312, 0.6715216382872313, 2.1107337763532996, 7.082848437130451, 8.966637253761292, 7.717311792075634, 11.596284247934818, 6.332224365323782, 2.770179365761578, 0.663285223999992, 0.3890070354100317, 0.2939073712332174, 0.40275665698572993, 0.6494469603057951, 0.9179118764586747, 0.5629397334996611, 1.4932511164806783, 2.0320008136332035, 2.7445746771991253, 2.653339672833681, 5.776752596721053, 5.3381098341196775, 7.295521600171924, 5.92874919064343, 6.791984494775534, 5.708472635596991, 1.4831342780962586, 5.165060944855213, 3.036355320364237, 2.111800331622362, 0.6948408088646829, 0.8264612930361181, 0.2616599859902635, 0.18857460381696, 0.4687093914253637, 3.460541758686304, 8.588656336069107, 24.150031618773937, 29.25817921757698, 30.420506447553635, 18.374854512512684, 12.45383933186531, 17.66880489885807, 25.66479753702879, 28.918796628713608, 24.793745577335358, 11.451466418802738, 1.6878461558371782, 0.037090919286129065, 0.01376775131575414, 0.0750492830411531, 0.013899893492634874, 0.02710800887143705, 0.03587140738090966, 0.07555799558758736, 0.01425484602805227, 0.025353512392030098, 0.048793293099151924, 0.028398407011991367, 0.02685999425011687, 0.04034914054500405, 0.08350126896402799, 0.07916926391771995, 0.02853247227903921, 0.060914843052159995, 0.05260978752630763, 0.052298549344413914, 0.055757332302164286, 0.013740605409111595, 0.030690001331095118, 0.02255563606013311, 0.014620935417042347, 0.06970882546738721, 0.04674432726460509, 0.025786780061025638, 0.028772250916517805, 0.032131580519489944, 0.024356989888474345, 0.05528942674573045, 0.06216397036041599, 0.012378430456010392, 0.048337603293475695, 0.06389636197127402, 0.05974193431029562, 0.04323708577430807, 0.015013635438663187, 0.01696837727649836, 0.009551022212690441, 0.05212051924900152, 0.05224411652307026, 0.11919875774765387, 0.2077275057672523, 0.11764264476369135, 0.21493597130756825, 0.1471642477554269, 0.09831943476456217, 0.12635368475457653, 0.09111361126997508, 0.17012896860251203, 0.2014214769587852, 0.27125598513521254, 0.12636472791200504, 0.10236528993118554, 0.1712812716141343, 0.06830899394117296, 0.06739300559274852, 0.19706116640008986, 0.1902142900507897, 0.13037259253906086, 0.10062728397315368, 0.1103990979027003, 0.23290948185604066, 0.17368916975101456, 0.23966879962245002, 0.11802623121184297, 0.15941076795570552, 0.13423055817838758, 0.07911337277619168, 0.0837882945779711, 0.2725982037372887, 0.15983644902007654, 0.1565244814264588, 0.1918084084172733, 0.07896201175753959, 0.1962810949771665, 0.25333638419397175, 0.1044421159895137, 0.10272220359183848, 0.15840563282836229, 0.17819133441662416, 0.12560592644149438, 0.11112489606603049, 0.10076189471874386, 0.21581418433925137, 0.25137007876764983, 0.05373351785237901, 0.10648440249497071, 0.09041925048222765, 0.12887820397736505, 0.22404191549867392, 0.19775612832745537, 1.3446062989532948, 9.736256506294012, 31.271387189626694, 49.210387989878654, 53.64541880786419, 38.04831974208355, 23.533875681459904, 23.139536641538143, 34.409224614501, 40.23050084710121, 35.06101883947849, 27.529731765389442, 13.793501146137714, 5.36284888163209, 1.7551361513324082, 0.6236459885258228, 1.9034681981429458, 3.777175205759704, 9.920618813484907, 6.086763711646199, 8.969719838351011, 7.297202534973621, 7.194552468135953, 6.984010990709066, 6.769118746742606, 7.303429925814271, 6.663464941084385, 8.696123119443655, 4.9773272685706615, 2.2025544242933393, 0.6834591133520007, 0.8853496424853802, 0.6197200273163617, 1.3387841801159084, 1.4646266587078571, 1.2789025995880365, 0.9622384572867304, 2.198934406042099, 5.207351250573993, 7.418662067502737, 6.564138270914555, 10.291920639574528, 5.0866184290498495, 1.7524821124970913, 0.4167173453606665, 0.2647119644097984, 0.2801508625270799, 0.5481668387074023, 1.117077951785177, 0.4080562148010358, 0.9177117934450507, 1.2135952664539218, 2.412004410289228, 2.328671319410205, 1.8764496291987598, 8.744054697453976, 12.159376982599497, 12.445860709995031, 10.599036309868097, 15.047466158866882, 9.388147685676813, 17.88931466639042, 20.403263568878174, 12.331774681806564, 11.012744810432196, 7.638490721583366, 6.2751200795173645, 2.4167171074077487, 0.9991777595132589, 0.6179147679358721, 4.572588186711073, 11.932045631110668, 26.668108999729156, 29.54474464058876, 31.145125664770603, 24.484556168317795, 19.83622569590807, 29.129229336977005, 30.853124633431435, 35.370808616280556, 27.255200296640396, 11.51092467829585, 1.2685610982589424, 0.2924103109398857, 0.10439890073030256, 0.2823995996732265, 0.09370437459438108, 0.1087755459593609, 0.15514426486333832, 0.12539097078843042, 0.0771790390717797, 0.10000863709137775, 0.1751206984044984, 0.2313767242594622, 0.08656278398120776, 0.13858882040949538, 0.18768649053527042, 0.13751064310781658, 0.10736919095506892, 0.15590170078212395, 0.11632870940957218, 0.15951523266267031, 0.1740786636946723, 0.12006637291051447, 0.14261255215387791, 0.1493883752846159, 0.1910395285813138, 0.20582233846653253, 0.2107068576151505, 0.13266484922496602, 0.07168106807512231, 0.08478787101921625, 0.12430684888386168, 0.12713803094811738, 0.1352573640178889, 0.15115455316845328, 0.12574625172419474, 0.11769729651859961, 0.13187124102842063, 0.19518393353791907, 0.1279600485577248, 0.11805657763034105, 0.13304330001119524, 0.21202460018685088, 0.15806614479515702], [0.045629120504599996, 0.05897629394894466, 0.008239344842877472, 0.04716760748124216, 0.06541296301293187, 0.023390075366478413, 0.05911045569519047, 0.034592360389069654, 0.054190131631912664, 0.046497099319822155, 0.022409104567486793, 0.039525178508483805, 0.016057292668847367, 0.0010644510484780767, 0.02094567840686068, 0.012649557411350543, 0.07607217034092173, 0.03505018386931624, 0.07388167694443837, 0.02713641271839151, 0.0766325586300809, 0.048994233293342404, 0.03577340306947008, 0.0363664013275411, 0.12057370506227016, 0.026228866299788933, 0.025649954004620668, 0.017714512141537853, 0.026526584406383336, 0.027011685524485074, 0.06710494839353487, 0.06194416848302353, 0.05245899053988978, 0.025517749672872014, 0.03871627093758434, 0.10682476626243442, 0.039482419670093805, 0.06365580222336575, 0.03482432977762073, 0.042428152228239924, 0.008246799716289388, 0.03077874735026853, 0.10907407486229204, 0.032175281885429285, 0.06186643222463317, 0.0869790991418995, 0.05821404520247597, 0.08849301360896789, 0.019340273829584476, 0.05545381616684608, 0.046292830593301915, 0.03124392736935988, 0.21939261263469234, 2.925575114786625, 12.47642531991005, 30.913554690778255, 40.630159601569176, 30.05626179277897, 18.32785103470087, 14.360302481800318, 17.630869634449482, 25.78064952045679, 26.654087752103806, 23.899530060589314, 18.61101184040308, 13.4280576556921, 4.85180432908237, 1.3282987615093589, 0.7754566299263388, 0.510463718092069, 1.950384161900729, 2.751839174889028, 1.131966384127736, 2.336978861130774, 2.2964827716350555, 5.706258779391646, 7.9936776123940945, 2.3922511702403426, 2.973607862368226, 3.212731168605387, 2.6554521219804883, 0.15325337648391724, 0.13518242194550112, 0.1855116119259037, 0.09444698240258731, 0.2843679237412289, 0.17360149242449552, 0.15480240195756778, 0.19578115461627021, 0.06625778682064265, 0.11357710784068331, 0.08074991972534917, 0.04214737178699579, 0.10162564329220913, 0.09387138750753365, 0.10288146848324686, 0.10682390537112951, 0.34841028100345284, 0.404321460518986, 1.1297893384471536, 1.042846085038036, 0.20445515401661396, 1.5075650671496987, 2.1759722381830215, 2.9422930302098393, 4.7007804829627275, 3.6882511898875237, 4.260387439280748, 6.883058482781053, 5.359389167279005, 4.87322710454464, 1.6822824231348932, 1.570448367856443, 2.9530792264267802, 2.913259263150394, 0.26591023604851216, 0.5527957028243691, 0.8584335492923856, 1.0091936658136547, 3.596519837155938, 9.203403498977423, 12.295567374676466, 17.946835979819298, 23.689068853855133, 24.595931991934776, 15.600787717849016, 21.248427517712116, 25.87777990847826, 25.659295432269573, 24.68503151088953, 14.102898593991995, 3.7082010693848133, 0.20374720450490713, 0.06248029225389473, 0.05770109128206968, 0.03966128839238081, 0.09391619096277282, 0.08592364640207961, 0.05499682389199734, 0.06788567290641367, 0.020053717089467682, 0.09537632940919138, 0.04411260480992496, 0.010830519131559413, 0.017397244009771384, 0.04052059892273974, 0.0397968713514274, 0.020045297424076125, 0.017505738578620367, 0.03749017989321146, 0.007373295611614594, 0.018309189508727286, 0.012095915244572097, 0.03052654144994449, 0.05105300289869774, 0.08703066356247291, 0.006220920704436139, 0.027083820423285943, 0.06792965257773176, 0.08824017873848788, 0.09382957490743138, 0.08366373251192272, 0.04393278242787346, 0.03490136470645666, 0.010434950709168334, 0.06770809923182242, 0.017310783805442043, 0.028064149264537264, 0.020944168136338703, 0.11916182847926393, 0.015966483479132876, 0.04998980955861043, 0.07186912829638459, 0.061796859590685926, 0.02831418994901469, 0.016175147575268056, 0.03400664259970654, 0.049656741102808155, 0.07774261859594844, 0.07038262876449153, 0.09099860064452514, 0.02272576413815841, 0.049928452499443665, 0.07261397739057429, 0.015206327589112334, 0.03621476571424864, 0.060810701179434545, 0.010609159671730595, 0.010356009388488019, 0.04027737486467231, 0.02304067038494395, 0.025611989440221805, 0.05392204562667757, 0.017287031369050965, 0.008646624355606036, 0.021372728733695112, 0.07066428122925572, 0.042415094139869325, 0.09779143380001187, 0.0511803368863184, 0.023388973277178593, 0.05761778149462771, 0.03911284125933889, 0.07346770697040483, 0.021044057502876967, 0.044926870687049814, 0.026485640119062737, 0.04947079600242432, 0.04044446941406932, 0.021058729762444273, 0.02015018144447822, 0.07413533559883945, 0.034913669514935464, 0.03793765041336883, 0.060612102461163886, 0.09254299511667341, 0.023334004254138563, 0.04484487079025712, 0.075086531433044, 0.16197460616240278, 0.040597299885121174, 0.024329916341230273, 0.06550536782015115, 0.03930860126274638, 0.01802327526092995, 0.03464755020104349, 0.06576139392564073, 0.030783591719227843, 0.3547512204386294, 5.197673169896007, 19.636797197163105, 39.095543548464775, 42.96102672815323, 30.705810338258743, 19.410583935678005, 19.651194624602795, 24.488431960344315, 32.30639085173607, 30.592261031270027, 31.330088339746, 26.16403564810753, 14.81923520565033, 4.563958374783397, 0.5148291494697332, 0.3185276157455519, 0.2245132831740193, 0.43762420944403857, 1.2778524309396744, 1.1744424048811197, 2.4472522689029574, 1.4091549790464342, 2.419164413586259, 6.37085166759789, 1.8809659243561327, 5.952495066449046, 4.537268606945872, 4.242900777608156, 2.2342727473005652, 1.412056004628539, 0.5738773278426379, 0.7335699338000268, 0.526937615359202, 0.8398848446086049, 0.8954719430767, 0.6071381305810064, 0.5629034573212266, 0.3402199095580727, 0.3556640323949978, 0.5155756906606257, 0.061074690529494546, 0.4238377179717645, 0.42457784700673074, 0.90471280971542, 1.0261304257437587, 1.7908403417095542, 2.675655400380492, 2.762799449265003, 1.3464189204387367, 2.2483220184221864, 4.297566069290042, 4.715196434408426, 5.5616717878729105, 5.831546131521463, 4.849117398262024, 8.948222491890192, 4.018819676712155, 3.982676016166806, 3.8542718812823296, 0.8112804545089602, 1.3699958240613341, 0.8640333206858486, 0.2795275178505108, 0.3370991488918662, 0.3819526842562482, 1.0240616742521524, 2.8330700285732746, 10.592423714697361, 18.67874700576067, 25.589966252446175, 30.31427174806595, 27.687902078032494, 14.856608100235462, 15.342424381524324, 21.802753172814846, 27.791038043797016, 30.072775706648827, 21.939260847866535, 6.269000032916665, 0.3846461756620556, 0.03336532310640905, 0.024539250225643627, 0.06888927178806625, 0.05936644098255783, 0.02201433395384811, 0.020232778770150617, 0.0386129899561638, 0.032521675602765754, 0.07372472013230436, 0.02038507675024448, 0.047926861661835574, 0.0019767968433370697, 0.07660373361431994, 0.04224595868436154, 0.046718615558347665, 0.023871944431448355, 0.015123671819310402, 0.019036646372114774, 0.02685902018129127, 0.01926312757859705, 0.06971071794396266, 0.06185297708725557, 0.017600046994630247, 0.016168375477718655, 0.04307729395804927, 0.0307117611009744, 0.07592988578835502, 0.028755378189089242, 0.07438600339810364, 0.017829339085437823, 0.028938889045093674, 0.07633564760908484, 0.05410802783444524, 0.0791922482312657, 0.06933368465979584, 0.054853248002473265, 0.07335166475968435, 0.020179531529720407, 0.03298348070529755, 0.01580815554916626, 0.052852829758194275, 0.02408953099802602, 0.022843670994916465, 0.08085596520686522, 0.18486567627405748, 0.179991754994262, 0.12809044390451163, 0.20064222189830616, 0.10374322067946196, 0.17141616437584162, 0.22914162778761238, 0.12256790039828047, 0.16374081373214722, 0.1677641150308773, 0.16674330574460328, 0.13377657160162926, 0.19408947351621464, 0.12078581828973256, 0.12443469124264084, 0.15413469169288874, 0.09433961589820683, 0.15195688902167603, 0.10088108363561332, 0.2940809744177386, 0.17710662621539086, 0.1548797040595673, 0.13532648765249178, 0.33137641847133636, 0.1555613667005673, 0.13637725001899526, 0.11172890037414618, 0.10765662475023419, 0.12840524810599163, 0.14286842982983217, 0.19370982045074925, 0.17531993536977097, 0.14040938287507743, 0.15057275391882285, 0.18029088503681123, 0.15679552860092372, 0.14164076914312318, 0.17217089887708426, 0.14980626379838213, 0.10065339272841811, 0.1360595365986228, 0.15285429399227723, 0.33752588380593807, 0.19321881554787979, 0.19036735058762133, 0.1686281233560294, 0.22482163069071248, 0.18262925877934322, 0.1626419453532435, 0.25583472044672817, 0.20425504131708294, 0.452267614309676, 4.552088286727667, 18.716868460178375, 43.0558430403471, 55.640072375535965, 41.90021485090256, 28.015125319361687, 24.7579799965024, 26.560842655599117, 35.6172101944685, 35.47164000570774, 34.36811462044716, 23.26772466301918, 17.063109800219536, 6.2274939101189375, 1.9650569558143616, 1.1289844941347837, 1.2422528536990285, 4.744849093258381, 8.942845780402422, 7.000827938318253, 7.269007572904229, 8.520153611898422, 15.299144703894854, 21.945123933255672, 10.262048542499542, 9.52561765909195, 9.193847011774778, 7.975599132478237, 2.0634871115908027, 1.2720125005580485, 0.6963237980380654, 0.5099278874695301, 0.7511753391008824, 0.7942635426297784, 0.8309723041020334, 0.754796426044777, 0.5322927155066282, 0.4544266703305766, 0.58303258032538, 0.5595564900431782, 0.24594232236268, 0.25657707592472434, 0.2483481276431121, 0.6725958525203168, 0.8628206513822079, 1.648170466069132, 2.037932532839477, 3.3205591700971127, 1.1649831687100232, 4.353248281404376, 6.30798309110105, 9.766387939453125, 12.918291259557009, 9.708752632141113, 9.547285996377468, 14.597186520695686, 14.50916899368167, 13.666473012417555, 8.676235936582088, 6.481476556509733, 6.954616717994213, 5.881100222468376, 2.1023644879460335, 1.1451886058785021, 1.347245138604194, 1.5936198807321489, 4.855751367285848, 13.01621675491333, 16.71182245016098, 27.083633802831173, 32.9960348457098, 32.30464294552803, 23.364965245127678, 30.142387971282005, 36.13490581512451, 35.91328650712967, 35.802302062511444, 22.502092346549034, 5.968728270381689, 0.3211283090058714, 0.15328966750530526, 0.12011695027467795, 0.16195066447835416, 0.17248386255232617, 0.16344779898645356, 0.10372851131251082, 0.2197822550078854, 0.2090139000210911, 0.16161748470040038, 0.0955259389593266, 0.12071202654624358, 0.0651587477477733, 0.10082644672365859, 0.15529211552347988, 0.14624720555730164, 0.09609357060980983, 0.07002241996815428, 0.1483127658138983, 0.11541862113517709, 0.096824994252529, 0.12549179897177964, 0.2736019139410928, 0.09236090918420814, 0.06999158373218961, 0.2432685423991643, 0.20430972275789827, 0.18946164840599522, 0.18549270200310275, 0.240396193403285, 0.13119314069626853, 0.20477383222896606, 0.15399524214444682, 0.14019337337231264, 0.1601949508767575, 0.12617840431630611, 0.12290039740037173, 0.289559424854815, 0.10302510374458507, 0.2114325444563292, 0.12038191925967112, 0.13825767411617562, 0.13030352827627212, 0.10595733663649298], [0.03704214534081984, 0.06250901336898096, 0.007946465539134806, 0.0435160071356222, 0.01087734215616365, 0.03142897076031659, 0.01646444230573252, 0.05949630569375586, 0.08114666445180774, 0.06987264714553021, 0.01761596791766351, 0.0423551657149801, 0.09268392896046862, 0.027408715977799147, 0.06008233889588155, 0.03414699385757558, 0.03765765664866194, 0.017208170756930485, 0.05989140656311065, 0.09593892929842696, 0.030886655622452963, 0.0405925575614674, 0.0861497268488165, 0.05792728676169645, 0.05606208411336411, 0.0588769129535649, 0.023794864973751828, 0.046172977454261854, 0.01949219516973244, 0.01414279657183215, 0.040667944922461174, 0.08981631486676633, 0.05833916387928184, 0.059695876625482924, 0.05049762410635594, 0.020860613440163434, 0.022533479241246823, 0.061717754069832154, 0.016048513061832637, 0.014925686300557572, 0.059319978827261366, 0.04771176500071306, 0.021812794475408737, 0.01415897724655224, 0.018949794684886, 0.04279182685422711, 0.050563289332785644, 0.022231070761336014, 0.021688382694264874, 0.023421887526637875, 0.10844014715985395, 0.03224918124033138, 0.07320408869418316, 0.08473724912619218, 0.6310618843417615, 6.234929636120796, 26.184640042483807, 38.82316656410694, 40.16747362911701, 22.248480655252934, 14.725326094776392, 10.806567873805761, 18.743436634540558, 19.217223711311817, 17.885530069470406, 23.675708770751953, 23.1394986435771, 17.748967297375202, 5.707921190187335, 2.648404687643051, 0.39949429454281926, 0.20836104755289853, 0.5393592081964016, 2.4549755919724703, 1.309796841815114, 3.1014256412163377, 1.6728240181691945, 1.0449324105866253, 5.987392868846655, 2.070548082701862, 2.008474851027131, 1.4639084972441196, 1.083797081373632, 0.3501530218636617, 0.5416476947721094, 0.605952653568238, 1.7182004707865417, 0.8806067844852805, 0.801901132799685, 0.4417812160681933, 0.17147093487437814, 0.08109299233183265, 0.2077768585877493, 0.07550090958829969, 0.23809550591977313, 0.5923476023599505, 1.2892192834988236, 1.8731667241081595, 0.4673666681628674, 1.0611063614487648, 3.9257239596918225, 1.9603288220241666, 1.0112157510593534, 1.9065106473863125, 1.9226006465032697, 2.657698751427233, 6.831158017739654, 2.51328868791461, 6.40368428081274, 1.7935005552135408, 3.1281346455216408, 3.0436825146898627, 0.376806691638194, 0.41993696009740233, 0.880702076246962, 0.7510091573931277, 2.7160873683169484, 5.719596538692713, 13.88032078742981, 24.552247636020184, 18.420233577489853, 17.68580138683319, 14.394002873450518, 23.949886858463287, 20.264740101993084, 25.600068010389805, 27.653259336948395, 30.360353775322437, 24.12422150373459, 10.506651867181063, 1.828884850256145, 0.1466314896242693, 0.07812886193278246, 0.07191523793153465, 0.08599643624620512, 0.01055653769071796, 0.0701421506528277, 0.04471014501177706, 0.07881721874582581, 0.04346657638961915, 0.07503429165808484, 0.04010289594589267, 0.02919582613685634, 0.03609835242968984, 0.07892845926107839, 0.030438070025411434, 0.05424120623501949, 0.04719708929769695, 0.08120900485664606, 0.08207103164750151, 0.050634646831895225, 0.04036091471789405, 0.05562514837947674, 0.0414398786961101, 0.07349036473897286, 0.026169765369559173, 0.06632333330344409, 0.05653189327858854, 0.06920276980963536, 0.03748845439986326, 0.050428875256329775, 0.046042589528951794, 0.0433319582225522, 0.1112212787847966, 0.04470223000680562, 0.024670038910699077, 0.041023288940778, 0.0066164993313577725, 0.038965276326052845, 0.04594982849084772, 0.047219728512573056, 0.006717909172948566, 0.04736441020213533, 0.02095531704981113, 0.041999810564448126, 0.07186181814176962, 0.067215535818832, 0.035225271349190734, 0.03295303038612474, 0.037671282480005175, 0.0405350374057889, 0.051186930868425407, 0.014365794322657166, 0.028820436709793285, 0.07330527310841717, 0.03134673708700575, 0.013829200215695892, 0.04876972991041839, 0.11017597862519324, 0.07503588727558963, 0.020997636165702716, 0.009625599705032073, 0.02597785154648591, 0.042399850426591, 0.026370857704023365, 0.024932660853664856, 0.001502730765423621, 0.04725252030766569, 0.06796858564484864, 0.07201536107459106, 0.045088128244969994, 0.07080625407979824, 0.08421144491876476, 0.01384697929097456, 0.0047517586699541425, 0.02157642044039676, 0.009246125682693673, 0.060021067183697596, 0.04359976221167017, 0.02259149663586868, 0.018643651346792467, 0.0456871935602976, 0.0400991926289862, 0.04463003388082143, 0.010784840869746404, 0.010139208570763003, 0.06285898052738048, 0.05919746879953891, 0.051995775356772356, 0.03227719360438641, 0.08272245919215493, 0.023296902436413802, 0.08099606784526259, 0.05272001872071996, 0.06091195609769784, 0.04663818530389108, 0.04863238806137815, 0.034541248678578995, 0.03203311607649084, 0.1909094597795047, 2.0095345191657543, 11.301705054938793, 34.465670585632324, 41.59129522740841, 39.72014643251896, 22.54970759153366, 15.96012968569994, 14.322795644402504, 24.164387248456478, 24.22915857285261, 27.52544179558754, 36.05757236480713, 32.96138450503349, 19.31867826730013, 7.522469647228718, 1.8456414761021733, 0.432828213670291, 0.4156348784454167, 0.4917051934171468, 0.3490741766290739, 0.7226163684390485, 1.2888992694206536, 2.024031928740442, 1.2783644534647465, 2.343743210658431, 2.0713249035179615, 2.594916857779026, 2.883433476090431, 2.092014318332076, 1.9000591873191297, 1.1343075335025787, 2.190349716693163, 1.4693562174215913, 1.3199317292310297, 1.9394113007001579, 1.233233562670648, 0.5149136355612427, 0.3636483836453408, 1.1323708249256015, 0.3646589512936771, 1.4343421650119126, 2.0607073232531548, 2.275760821066797, 1.5570948156528175, 1.819474536459893, 2.6807464146986604, 3.493858608417213, 3.3881682297214866, 4.548459006473422, 3.9270778745412827, 4.88427453674376, 3.2920668739825487, 4.583260864019394, 3.450942998751998, 5.6105737388134, 1.7174926400184631, 1.6245490335859358, 0.3205586364492774, 0.3379393194336444, 0.3190435271244496, 0.24465015419991687, 0.5680805607698858, 2.380399131216109, 7.16567924246192, 15.254698488861322, 23.528935946524143, 28.61088205128908, 25.517023466527462, 17.980302684009075, 25.386844351887703, 19.428539872169495, 22.51894824206829, 29.795229099690914, 34.645123556256294, 30.258443243801594, 17.060358747839928, 3.889038828201592, 0.25320558808743954, 0.028409004880813882, 0.049864887550938874, 0.03309821673610713, 0.02511992697691312, 0.05144818911503535, 0.08159051329130307, 0.08924805981223471, 0.060590227658394724, 0.04204562705126591, 0.07534019750892185, 0.045753805025015026, 0.04001599045295734, 0.06965529435547069, 0.03022936696652323, 0.08741505895159207, 0.04815841544768773, 0.033578030052012764, 0.023104237188817933, 0.04815358035557438, 0.028903071142849512, 0.013501871344487881, 0.059017293897341006, 0.009764589121914469, 0.0199129762040684, 0.04636383557226509, 0.018241182806377765, 0.0896639890561346, 0.023088691050361376, 0.025531820792821236, 0.034774906453094445, 0.029934862359368708, 0.13050729234237224, 0.05924588280322496, 0.019723645054909866, 0.009020001634780783, 0.03602057906391565, 0.03962770992075093, 0.08884853203198873, 0.06068983500881586, 0.015343514514825074, 0.021107184584252536, 0.08158908094628714, 0.020308501952968072, 0.030542399290425237, 0.19183033145964146, 0.17865532514406368, 0.1067225428414531, 0.17354347131913528, 0.07640111245564185, 0.15057054231874645, 0.07689305988606066, 0.17841402324847877, 0.15182852715952322, 0.1432776649016887, 0.17797260865336284, 0.07535360811743885, 0.19107314787106588, 0.1940648045274429, 0.10698835787479766, 0.14821898803347722, 0.1360412797657773, 0.1051099895266816, 0.14259623974794522, 0.17051547911250964, 0.09304197810706683, 0.2617978473426774, 0.16617709159618244, 0.26235882192850113, 0.06884708811412565, 0.17033963464200497, 0.15462206007214263, 0.07243597327033058, 0.10062598521471955, 0.08531953077181242, 0.13061015401035547, 0.25629170530010015, 0.13867410802049562, 0.13331467373063788, 0.15329604997532442, 0.15958702802890912, 0.20579332049237564, 0.13729607337154448, 0.10964155808323994, 0.09895955940010026, 0.13785586052108556, 0.2205233636777848, 0.13852468400727957, 0.09672446292825043, 0.21456556540215388, 0.13221025408711284, 0.14925967203453183, 0.1138760894536972, 0.12305545431445353, 0.1788249652599916, 0.2517152961809188, 0.13084888807497919, 0.13063402147963643, 0.36703521909657866, 1.6637333622202277, 10.240886528044939, 36.18869572877884, 52.36396797001362, 53.67852263152599, 34.10791598260403, 22.742756232619286, 18.711052872240543, 28.024451918900013, 29.232249408960342, 26.68489269912243, 33.74677196145058, 31.368050202727318, 22.06007346510887, 8.317721374332905, 2.9803669871762395, 0.7917583489324898, 1.1514031724072993, 1.99272018391639, 6.176232285797596, 4.92440608330071, 9.310503602027893, 6.614648960530758, 8.274624086916447, 14.022821690887213, 7.308817086741328, 7.481354903429747, 7.4235842283815145, 5.011275596916676, 2.4301054514944553, 3.11530320905149, 2.1422678092494607, 3.7659924058243632, 2.666453244164586, 3.358925236389041, 1.337366143707186, 0.7565363764297217, 0.37593998189549893, 0.722301104106009, 0.2844858658500016, 1.7886863322928548, 2.5949607929214835, 2.928044982254505, 5.3971748147159815, 4.043325036764145, 4.476536940783262, 12.45143786072731, 6.031170319765806, 6.872545396909118, 7.994135487824678, 8.986134007573128, 9.781881608068943, 15.472444854676723, 7.9011668264865875, 15.85881382226944, 7.669741194695234, 7.9991768673062325, 6.602546609938145, 1.6903172107413411, 1.4900773367844522, 1.5132214198820293, 1.190108370501548, 3.8428276078775525, 7.772370837628841, 18.975664973258972, 31.526207216084003, 24.012378305196762, 24.774828292429447, 23.532815538346767, 36.29980556666851, 28.57447810471058, 35.57169623672962, 39.93836112320423, 41.543269604444504, 33.20557460188866, 16.206046789884567, 2.939314227551222, 0.28350498410873115, 0.1390431632171385, 0.14112209697486833, 0.1943003770429641, 0.10001019560149871, 0.20425487804459408, 0.1717095947242342, 0.15281798812793568, 0.2272429913864471, 0.162221904611215, 0.10002853407058865, 0.10595391533570364, 0.18113853642717004, 0.21173578599700704, 0.08170513057848439, 0.21903031098190695, 0.1848639248055406, 0.2012997944257222, 0.15257195133017376, 0.21191317413467914, 0.10272175830323249, 0.09990291815483943, 0.23386826243950054, 0.12462146754842252, 0.18129962700186297, 0.15605191147187725, 0.11710410530213267, 0.17173932516016066, 0.14759466372197494, 0.19074318901402876, 0.1459139960934408, 0.15772490529343486, 0.22666776756523177, 0.1695092159206979, 0.12043276379699819, 0.2882882743142545, 0.19442605233052745, 0.10801269236253574, 0.11782504239818081, 0.21035493118688464, 0.1259829374612309, 0.12703092419542372, 0.16823046578792855, 0.19306818925542757, 0.31424171291291714], [0.03778489044634625, 0.03830847192148212, 0.0581734274601331, 0.022658362286165357, 0.04921122243104037, 0.03270388027885929, 0.026613515874487348, 0.030589698217227124, 0.042864093484240584, 0.03379699701326899, 0.05290230874379631, 0.02133230766048655, 0.054635026899632066, 0.02721765933529241, 0.005549916695599677, 0.048910760233411565, 0.03557289332093205, 0.0751261027471628, 0.028755027524312027, 0.0633019462111406, 0.025469589854765218, 0.035775455107796006, 0.017745628538250457, 0.03892459921189584, 0.03659793655970134, 0.0995198215241544, 0.0394237046566559, 0.022697516142216045, 0.02234223149571335, 0.07633509841980413, 0.03275344832218252, 0.047986971912905574, 0.03632992105849553, 0.09297541488194838, 0.03708750169607811, 0.018018998634943273, 0.0735596961749252, 0.0398618500912562, 0.056519952122471295, 0.04296396058634855, 0.034959779150085524, 0.04549561555904802, 0.09909109765430912, 0.05937840440310538, 0.13540304760681465, 0.047380158575833775, 0.04814059277123306, 0.003119851767223736, 0.0709809704858344, 0.09121737835812382, 0.04740636381029617, 0.08986079919850454, 0.04142774087085854, 0.03786961031437386, 0.06073571086744778, 0.37431372853461653, 4.7714609652757645, 16.592993326485157, 32.79083825647831, 43.92705649137497, 38.400378450751305, 28.266310840845108, 23.623881451785564, 20.101546458899975, 15.695433039218187, 18.298330418765545, 21.318562254309654, 23.24883207678795, 29.836088307201862, 22.06243123859167, 12.75433100759983, 5.980671979486942, 2.003746717236936, 0.2039054303895682, 0.20964803552487865, 0.21005667687859386, 2.5579374795779586, 0.8824165561236441, 1.935091051273048, 2.0027129352092743, 1.9052524399012327, 3.185467394068837, 1.922366009093821, 1.6449383832514286, 1.6888802940957248, 2.261119019240141, 0.7319390494376421, 2.3039184976369143, 1.015612471383065, 1.3380203023552895, 0.32367725973017514, 0.44240889488719404, 0.9899253153707832, 0.42350395931862295, 1.3015980692580342, 2.511603715829551, 2.635402260348201, 0.8536955597810447, 2.2559778951108456, 3.657231079414487, 1.5754367876797915, 3.1253624567762017, 3.3680920070037246, 3.627178017050028, 4.676950061693788, 2.9954721266403794, 2.5035875709727407, 2.7149493293836713, 5.273366533219814, 0.9119128296151757, 0.9616515075322241, 0.5926611449103802, 1.2316093873232603, 2.4422132642939687, 6.363149480894208, 9.884866531938314, 22.429244555532932, 13.653166126459837, 39.8593557626009, 57.68199160695076, 20.513985827565193, 23.348170146346092, 18.246254213154316, 16.879866532981396, 27.419818863272667, 23.701137006282806, 28.987225256860256, 24.859428852796555, 5.812310613691807, 0.05398823406721931, 0.03330195111630019, 0.05938630456512328, 0.09463755850447342, 0.03570223481801804, 0.06889552067150362, 0.04815507578314282, 0.06317574399872683, 0.031981570209609345, 0.027077799750259146, 0.061395483862725087, 0.014117921637080144, 0.04448242441867478, 0.025780291834962554, 0.005906238957322785, 0.030918259981262963, 0.03338727583468426, 0.10135849981452338, 0.09596743519068696, 0.07970208142069168, 0.045567622437374666, 0.0454778040148085, 0.024705361429369077, 0.04588449723087251, 0.0444390199118061, 0.005901791637370479, 0.006837004393673851, 0.034723932039923966, 0.015861964966461528, 0.04568635864416137, 0.043859502766281366, 0.03463536784693133, 0.0466744985897094, 0.07627905142726377, 0.05763566725363489, 0.021567013718595263, 0.08038993357331492, 0.03674976142065134, 0.040898689767345786, 0.025189486623276025, 0.00391316519198881, 0.0354000322840875, 0.03155574442644138, 0.01980153716431232, 0.044513449902297, 0.07072118911310099, 0.06064198132662568, 0.03766445101064164, 0.07653395688976161, 0.05999690285534598, 0.013148070993338479, 0.04925159897538833, 0.057118950644508004, 0.039946569959283806, 0.029365534901444335, 0.046735313881072216, 0.021093775831104722, 0.0038617601012447267, 0.045862444312660955, 0.03895092690072488, 0.05271877562336158, 0.06493368404335342, 0.014340182806336088, 0.05914618639508262, 0.044535825654747896, 0.04359905717137735, 0.040649150032550097, 0.036057504621567205, 0.02951183261757251, 0.05248587855021469, 0.018923442876257468, 0.02179505529056769, 0.05046042766480241, 0.0431658358866116, 0.03880292038957123, 0.024867680258466862, 0.0666845885280054, 0.06433256668969989, 0.07147238356992602, 0.05249773064861074, 0.02253180013212841, 0.034852045282605104, 0.033198792589246295, 0.06206586585904006, 0.021561314024438616, 0.027757222960644867, 0.049156604072777554, 0.03353148254973348, 0.04152468391112052, 0.035120246320730075, 0.03011902630532859, 0.09064363141078502, 0.07302212892682292, 0.020154433950665407, 0.006230744420463452, 0.03660662710899487, 0.03623448086727876, 0.02943135597888613, 0.03462789813056588, 0.04209621554764453, 0.07402946081128903, 0.08224162171245553, 0.8919114747550339, 8.880591820925474, 25.079340152442455, 41.27448722720146, 45.31166039407253, 34.58150736987591, 22.201002202928066, 20.825139731168747, 21.292942129075527, 13.177569396793842, 21.24282281845808, 30.773387812078, 36.81721240282059, 35.813416466116905, 24.438094161450863, 13.69992546737194, 5.438876152038574, 1.5731184370815754, 0.47129755723290145, 0.3016073611797765, 0.14360418019350618, 0.32777732878457755, 0.1557277562096715, 0.5804851732682437, 0.6720189959742129, 0.7862536911852658, 1.6390527365729213, 0.4699983831960708, 1.8634204845875502, 0.31412255368195474, 2.076034750789404, 1.672319951467216, 2.350603980012238, 1.3671792251989245, 2.9447944834828377, 1.4788435958325863, 1.4536014315672219, 1.8463482381775975, 1.3328632665798068, 1.6576793370768428, 2.834424893371761, 2.1355908550322056, 2.645319728180766, 3.061125003732741, 3.627025787718594, 3.5757316276431084, 3.425578884780407, 3.4839608520269394, 2.1534050116315484, 2.2749350778758526, 1.1291276989504695, 0.4303472733590752, 0.17863493092590943, 0.7854154205415398, 0.2733037783764303, 0.31248899758793414, 0.29348039883188903, 0.6393168226350099, 1.8177649844437838, 6.494012558832765, 11.268169954419136, 27.76125144213438, 24.2360096052289, 43.8756338506937, 61.1920228600502, 18.984406404197216, 16.3205973431468, 17.637517377734184, 20.982766672968864, 27.08550900220871, 32.10247479379177, 34.71848241984844, 30.87617989629507, 11.40580901876092, 1.297000553458929, 0.05157230218173936, 0.02817524135025451, 0.05223445376032032, 0.09934787332895212, 0.05781527441286016, 0.07326481863856316, 0.047222815846907906, 0.04046602509333752, 0.03859423588437494, 0.07513122356613167, 0.012538957926153671, 0.022714652332069818, 0.017019234801409766, 0.02314181769179413, 0.05736929189879447, 0.03990979283116758, 0.03083278312260518, 0.04697414442489389, 0.019726836289919447, 0.04485531651880592, 0.0538963450526353, 0.06840913934865966, 0.01760467614076333, 0.022691742233291734, 0.01566098209877964, 0.01687022639089264, 0.026795481207955163, 0.04480260919081047, 0.0701491862128023, 0.058533131596050225, 0.04313545607146807, 0.012690318944805767, 0.02759195409453241, 0.015191280544968322, 0.021267879965307657, 0.033197289740201086, 0.02740784766501747, 0.04811945269466378, 0.10198844960541464, 0.027299913417664357, 0.036581546228262596, 0.052466096603893675, 0.07132575745345093, 0.005627724849546212, 0.058284705082769506, 0.09121000883169472, 0.08623803500086069, 0.245813203509897, 0.20705500122858211, 0.10712831950513646, 0.20618750480934978, 0.12593821564223617, 0.12314089777646586, 0.14241083641536534, 0.09961387389921583, 0.1186709942703601, 0.1354169999831356, 0.11851196686620824, 0.13463229755870998, 0.2676215098472312, 0.2616926108021289, 0.11338386742863804, 0.11844634616863914, 0.17191347753396258, 0.1605034913518466, 0.16898465109989047, 0.14497437776299194, 0.07668320278753527, 0.12648372387047857, 0.12680125917540863, 0.09326854094979353, 0.18007857142947614, 0.1810593344271183, 0.15171708626439795, 0.1620322561939247, 0.1727988597122021, 0.15677134942961857, 0.1625369759858586, 0.14960900094592944, 0.13799961452605203, 0.09762615009094588, 0.09029486653162166, 0.16021871444536373, 0.11891926493262872, 0.22308497544145212, 0.14648184296675026, 0.13454652013024315, 0.11310197005514055, 0.34358997247181833, 0.11194416772923432, 0.17401369608705863, 0.10813628963660449, 0.18853175221011043, 0.08704305000719614, 0.11680988085572608, 0.1814620682853274, 0.08417483477387577, 0.18163320753956214, 0.14563530479790643, 0.21148318861378357, 0.23079364851582795, 0.5948522023390979, 7.981360573321581, 23.959259055554867, 45.83674281835556, 56.09168194234371, 53.4138098359108, 37.40884065628052, 35.062211975455284, 30.53737487643957, 22.89546813815832, 29.477664940059185, 31.009718030691147, 31.93486198782921, 38.66267457604408, 29.901127517223358, 16.416181214153767, 7.189198080450296, 2.7444250602275133, 0.6109167309477925, 1.8608904141001403, 1.3352047721855342, 5.632619205862284, 2.3717211093753576, 7.8940103854984045, 9.56984443590045, 5.663291634991765, 8.492056969553232, 6.733330842107534, 5.9634527284651995, 5.84104229696095, 7.621719371527433, 4.779938785359263, 8.60481021925807, 7.5079696252942085, 5.9225251246243715, 2.456572693772614, 2.7965373639017344, 3.155039339326322, 1.7303895042277873, 5.321536548435688, 7.6551400031894445, 7.997641749680042, 5.641233343631029, 7.00185245834291, 11.135466825217009, 5.7440677005797625, 9.6452846378088, 9.43777872249484, 13.607616070657969, 10.143989827483892, 8.336973991245031, 6.318071549758315, 7.833983106538653, 9.371368736028671, 3.4236628375947475, 2.502850410528481, 1.5776882856152952, 1.8555934983305633, 3.200769410468638, 8.82326239719987, 13.67619764059782, 30.146571546792984, 18.48179217427969, 44.9531876295805, 68.54218125343323, 22.565908022224903, 31.81584097445011, 27.686026878654957, 27.803592570126057, 38.493754640221596, 37.9298534989357, 40.523886904120445, 32.34407722949982, 10.663341209292412, 0.9608224988915026, 0.19179071561666206, 0.27900750981643796, 0.15795583196450025, 0.14487289648968726, 0.21510825346922502, 0.1588066152180545, 0.11573510259040631, 0.12949996045790613, 0.1781616485095583, 0.15478629735298455, 0.10342563342419453, 0.1431539488839917, 0.1432554895291105, 0.14892594306729734, 0.11176634914590977, 0.09249330832972191, 0.13119509996613488, 0.19332660507643595, 0.1500233865226619, 0.12868091143900529, 0.13824407797073945, 0.14675476035336033, 0.1176556471909862, 0.1108605504850857, 0.1903982981457375, 0.08340328320628032, 0.1093590521486476, 0.11899523859028704, 0.14224711863789707, 0.10853119383682497, 0.22945873264688998, 0.06671972922049463, 0.18299503368325531, 0.14559439761796966, 0.09420719448826276, 0.17215589265106246, 0.0898202630924061, 0.18490977468900383, 0.3314667526865378, 0.08868851757142693, 0.08865949217579328, 0.16691181779606268, 0.14574784407159314, 0.1363925531040877, 0.1330952058196999, 0.13234761077910662], [0.04533746017841622, 0.010204065783909755, 0.036560027656378224, 0.0438415242388146, 0.021979352823109366, 0.057569386044633575, 0.012760429635818582, 0.07325424303417094, 0.02624362205096986, 0.05567594838794321, 0.014893824045429938, 0.059272503640386276, 0.05840361940499861, 0.015270951953425538, 0.021208907055552118, 0.025323809786641505, 0.026004700594057795, 0.09166726085823029, 0.010817785732797347, 0.060430176090449095, 0.060086903104092926, 0.026919052506855223, 0.03612879903812427, 0.060610970685957, 0.04132362126256339, 0.06991579561145045, 0.031068075477378443, 0.05581565768807195, 0.05341969328583218, 0.02636645491293166, 0.04237914821715094, 0.021625391054840293, 0.0018625094639901363, 0.037846206687390804, 0.037464260385604575, 0.07617345865583047, 0.04554001454380341, 0.0656459602760151, 0.06546217482537031, 0.07549769608885981, 0.023550475743832067, 0.06091129929700401, 0.04525837692199275, 0.015643773549527396, 0.12891719641629606, 0.019716321912710555, 0.043975370572297834, 0.024089911348710302, 0.03504326334223151, 0.028498201754700858, 0.015046883654576959, 0.09345492391730659, 0.045584365288959816, 0.04925728382659145, 0.04685418367444072, 0.03354343854880426, 0.014628453373006778, 1.1949237808585167, 7.02762552537024, 24.318558275699615, 37.70101457834244, 42.08905711770058, 37.30800926685333, 36.27962484955788, 29.491625390946865, 19.82324179261923, 18.62211674451828, 19.16612785309553, 20.907711200416088, 24.364332519471645, 24.57317691296339, 27.714152969419956, 19.87758457660675, 12.997366916388273, 6.03601885959506, 2.122651361860335, 0.815782262943685, 0.21990224544424564, 0.14233535999665037, 0.2439982516807504, 0.8176121022552252, 0.7011303026229143, 0.6473289302084595, 1.7601966485381126, 0.6426989380270243, 2.153409286402166, 1.8493909249082208, 0.7522852951660752, 0.89426503283903, 2.339488626457751, 1.074080765247345, 0.5537924368400127, 2.4560248106718063, 1.874523488804698, 1.5676363999955356, 1.3106550020165741, 1.0421783896163106, 1.9574779062531888, 1.7205128842033446, 2.1599534852430224, 2.8648211248219013, 2.9487441340461373, 3.8830111641436815, 0.7996923825703561, 2.1687540505081415, 0.9245356335304677, 0.5725197913125157, 0.634200694039464, 0.7310301263350993, 1.3444152404554188, 3.452566936612129, 7.4064955953508615, 16.256080605089664, 20.83007376641035, 23.697073124349117, 28.735617958009243, 23.427116610109806, 13.372048661112785, 42.31138318777084, 48.60911585390568, 24.42594811320305, 26.12953919917345, 26.835830099880695, 35.159163773059845, 33.28860394656658, 18.859218321740627, 12.18161053955555, 3.694976116530597, 0.1726022647926584, 0.06616374186705798, 0.1435255867545493, 0.08232720618252642, 0.026349469007982407, 0.06423149359761737, 0.0708931966801174, 0.06514787528431043, 0.027881317473656964, 0.015569915012747515, 0.04080733509908896, 0.059113413153681904, 0.05481478990986943, 0.06795737921493128, 0.022096185421105474, 0.03205458640877623, 0.013824845664203167, 0.05589024724031333, 0.019247505370003637, 0.018412346180411987, 0.010347767838538857, 0.035184683292754926, 0.024005202612897847, 0.08623945250292309, 0.06270076206419617, 0.03247919878049288, 0.021330589588615112, 0.026697753346525133, 0.03902015814674087, 0.04165240752627142, 0.01645102984184632, 0.07970879785716534, 0.09511478172498755, 0.0422939051350113, 0.05033849651226774, 0.047506049086223356, 0.034893898700829595, 0.03565065184375271, 0.04405764506373089, 0.032873282907530665, 0.026451644189364742, 0.00865401985720382, 0.058491645540925674, 0.006758318186257384, 0.04752944900246803, 0.02452033102599671, 0.024467111616104376, 0.08298392524011433, 0.06221023213583976, 0.019271753189968877, 0.01616333258425584, 0.053799969755345955, 0.06163716425362509, 0.0459895816311473, 0.036518979468382895, 0.06132017071649898, 0.02201050447183661, 0.06326037109829485, 0.0437647045328049, 0.07793680895701982, 0.050751182570820674, 0.058285039049224, 0.02610294053738471, 0.025461257391725667, 0.02450264564686222, 0.03983656511991285, 0.051455094799166545, 0.05303843347064685, 0.008242696567322128, 0.023639603969058953, 0.07634823443368077, 0.043895752969547175, 0.028501368869910948, 0.043477233630255796, 0.019500201087794267, 0.03296649665571749, 0.042143612809013575, 0.03925973083823919, 0.03726897535671014, 0.025140246980299708, 0.036101847945246845, 0.03795582189923152, 0.012230243974045152, 0.01065949305484537, 0.06119996505731251, 0.07114421328878962, 0.011596563963394146, 0.01600953361048596, 0.01950124937138753, 0.015023490232124459, 0.034782776929205284, 0.010543951793806627, 0.09394492692081258, 0.037434433470480144, 0.048088108087540604, 0.009633534191380022, 0.03565099323168397, 0.035171198469470255, 0.015839023326407187, 0.12010986276436597, 0.0996028604276944, 0.09050764769199304, 0.11040116849471815, 0.03917579393601045, 0.06912245458806865, 2.945503145456314, 13.439500741660595, 32.934280559420586, 43.37759077548981, 44.748306423425674, 38.52273568511009, 35.43045401573181, 25.469362623989582, 17.9569149389863, 16.260889247059822, 19.671449437737465, 28.479555398225784, 37.748082652688026, 35.34542977809906, 32.89138086140156, 20.31907718628645, 12.860304471105337, 6.0098981112241745, 2.462156256660819, 0.9321109426673502, 0.3660422848770395, 0.11405909564928152, 0.12397712009260431, 0.3874074399936944, 0.4751747741829604, 0.6068531458731741, 0.6342552567366511, 0.600414628861472, 0.9191660466603935, 0.9588624571915716, 1.0412599076516926, 0.7868632022291422, 1.088558107148856, 0.794900186592713, 0.7147728174459189, 0.2580729784676805, 0.8623532764613628, 0.592473529977724, 1.1122057819738984, 1.548097967170179, 1.1772357299923897, 1.3308124453760684, 1.2634521536529064, 0.9935963340103626, 0.975855739088729, 1.0739033622667193, 0.47165518335532397, 0.3842352930223569, 0.317147221066989, 0.16354107210645452, 0.24708583834581077, 0.807892105076462, 1.0815582890063524, 2.874441733583808, 6.937015112489462, 16.007572039961815, 25.3031899407506, 31.49172216653824, 36.98737487196922, 36.90361976623535, 13.758027199655771, 45.150533840060234, 54.59782250225544, 17.449938543140888, 19.806868471205235, 24.94511805474758, 34.39063601195812, 38.58083076775074, 25.074033737182617, 19.70468245446682, 8.040917627513409, 0.8758234942797571, 0.027347895120328758, 0.04549662487988826, 0.004360467337392038, 0.0017902461968333228, 0.06223102340300102, 0.07251717906910926, 0.04215321991068777, 0.022360911352734547, 0.02127396743162535, 0.005680466501871706, 0.010023604227171745, 0.061820945993531495, 0.052790103436564095, 0.03672395694593433, 0.020570986598613672, 0.030916597570467275, 0.045810275041731074, 0.011487197371025104, 0.009390760060341563, 0.03700048488099128, 0.03536070216796361, 0.0687165443378035, 0.022852882902952842, 0.03548836270056199, 0.008995353055070154, 0.020410281940712593, 0.014465162330452586, 0.06726035411702469, 0.17906720226164907, 0.03345225457451306, 0.06594606253202073, 0.057808576530078426, 0.07609332154970616, 0.03488705609925091, 0.052171593852108344, 0.06082535859604832, 0.02983687289088266, 0.02690202021767618, 0.026411952276248485, 0.05673787265550345, 0.011040869758289773, 0.03283871366875246, 0.07018118019914255, 0.05354817760235164, 0.04161298835242633, 0.05159523083420936, 0.04623755914508365, 0.1802209747256711, 0.11785843904362991, 0.13955655129393563, 0.23513734980951995, 0.21061913575977087, 0.1515092997578904, 0.12409757808200084, 0.35309065016917884, 0.1857228419976309, 0.08323336849571206, 0.14025488257175311, 0.09674467160948552, 0.12938149884575978, 0.19646281725727022, 0.1293612679000944, 0.1575080942711793, 0.11865255190059543, 0.23384019441436976, 0.1429479435319081, 0.18327856378164142, 0.15933023008983582, 0.11779219494201243, 0.19841294386424124, 0.14183751249220222, 0.0740128663892392, 0.2485487301601097, 0.09754737111506984, 0.16583993390668184, 0.12603748531546444, 0.07924111123429611, 0.1798920994042419, 0.09705719741759822, 0.11191136480192654, 0.20296270988183096, 0.12579213129356503, 0.32770225312560797, 0.07781456981319934, 0.20952166261849925, 0.2076918084640056, 0.2106132431072183, 0.09659763731178828, 0.1975836235214956, 0.12108073293347843, 0.08965669374447316, 0.18541152589023113, 0.14630034333094954, 0.17030347720719874, 0.13422395306406543, 0.07941838804981671, 0.11110201565315947, 0.1005608840205241, 0.2551130560459569, 0.2683462022105232, 0.30076529073994607, 0.12560071656480432, 0.09178372609312646, 0.12766798376105726, 2.1323562785983086, 13.38111212477088, 34.20449160039425, 50.97120590507984, 56.34005181491375, 52.721988558769226, 48.96087437868118, 42.9623718559742, 28.337621614336967, 29.187058433890343, 27.692800015211105, 30.080525390803814, 36.04310654103756, 35.19988238811493, 36.87660701572895, 26.49131778627634, 18.27777922153473, 8.353003431111574, 3.2137758750468493, 1.3502875878475606, 0.8522867260035127, 0.30340959259774536, 1.0327505017630756, 2.299116742797196, 2.805093079805374, 2.9222384188324213, 5.606515556573868, 2.905517416074872, 6.456219786778092, 3.4150244761258364, 2.8920998610556126, 3.7660755263641477, 6.74042553640902, 4.447872703894973, 3.1320282490924, 6.606601942330599, 6.226559160277247, 6.420012004673481, 6.2683516927063465, 8.45838887616992, 6.692717671394348, 7.776644183322787, 7.987176161259413, 8.91004404053092, 8.32092935219407, 8.058468885719776, 3.3045228431001306, 4.81916313059628, 3.5226959735155106, 1.271803630515933, 1.4043057267554104, 1.4478766825050116, 1.8428023159503937, 4.667618712410331, 9.742378927767277, 21.312446482479572, 27.47662391513586, 30.673189088702202, 36.67020209133625, 33.100783824920654, 18.20356920361519, 48.28085906803608, 58.4143453091383, 29.892422184348106, 35.087321028113365, 36.49194985628128, 47.38080516457558, 42.77086593210697, 30.664023980498314, 18.237461484968662, 5.994850918650627, 0.620393956778571, 0.08261147100711241, 0.19522199087077752, 0.23642208165256307, 0.07876442236010917, 0.22655509470496327, 0.19961645506555215, 0.1857922476483509, 0.10456032527144998, 0.0929139056825079, 0.2923962101340294, 0.24626723461551592, 0.14380211097886786, 0.1529533410212025, 0.13064366939943284, 0.10056600483949296, 0.09193022604449652, 0.17982541001401842, 0.09296852033003233, 0.16691569180693477, 0.11474799423012882, 0.17780857917387038, 0.10442259008414112, 0.195806298579555, 0.15422659926116467, 0.16771629103459418, 0.0979315883887466, 0.13277942198328674, 0.21089362649945542, 0.2784830192103982, 0.17525634815683588, 0.26414710097014904, 0.17224916577106342, 0.17847933224402368, 0.1378865705919452, 0.1202859595650807, 0.17778143141185865, 0.1969999837456271, 0.08816947432933375, 0.10635269354679622, 0.11300668571493588, 0.10840932576684281, 0.12250823914655484, 0.19988624058896676, 0.13697616319404915, 0.19080692465649918, 0.21793176914798096, 0.15316593664465472], [0.047264747190638445, 0.09484140420681797, 0.028590278161573224, 0.07082972821081057, 0.04082958839717321, 0.030142580217216164, 0.030581118990085088, 0.017570400050317403, 0.01628116337087704, 0.06684600564767607, 0.02523917155485833, 0.01927768851601286, 0.05543080216739327, 0.08752730878768489, 0.04714508329925593, 0.028253337550268043, 0.05238518395344727, 0.05165778646187391, 0.04250741360010579, 0.03760658946703188, 0.09754673286806792, 0.018174393226217944, 0.08458982149022631, 0.04859309505263809, 0.014509094689856283, 0.0346427447948372, 0.05047178994573187, 0.0037661615078832256, 0.04003433263278566, 0.04464688434381969, 0.010120161350641865, 0.05799434722575825, 0.04483745673496742, 0.060258064622757956, 0.04438892865437083, 0.03143311936582904, 0.005427901123766787, 0.027115165030409116, 0.025524441989546176, 0.035799920005956665, 0.01663827926677186, 0.028523330875032116, 0.04096064054465387, 0.04614028584910557, 0.021785169883514754, 0.026035021037387196, 0.018485718610463664, 0.02305919068021467, 0.07230956325656734, 0.024544649349991232, 0.010605764346109936, 0.0528046866384102, 0.02493676307494752, 0.05130444624228403, 0.011779219494201243, 0.03799750833422877, 0.033656675441307016, 0.022586197701457422, 0.11037125994334929, 2.3783339420333505, 14.068387895822525, 25.495993494987488, 38.146768659353256, 39.69442941248417, 40.008611753582954, 34.73069876432419, 31.215950064361095, 28.73587254434824, 23.45194637775421, 17.26080559194088, 24.74440522491932, 22.858467623591423, 30.700401328504086, 20.78382644802332, 23.502052389085293, 21.513090915977955, 12.980918549001217, 7.802612464874983, 4.754637842997909, 2.8318008966743946, 0.8897938602603972, 0.43908739811740816, 0.37701330555137247, 0.28237124963197857, 0.24619983276352286, 0.46904573275242, 0.775482872268185, 0.8637554012238979, 0.3778911178233102, 0.7059695804491639, 0.8115076704416424, 0.2291992778191343, 0.15904260333627462, 0.2903027005959302, 0.3999294008826837, 0.9242875780910254, 0.4953206400386989, 1.4734267489984632, 0.950568214757368, 0.9365038038231432, 0.6788751936983317, 0.2650487807113677, 0.5142119200900197, 0.1676861895248294, 0.37511465430725366, 1.3303765375167131, 4.433770710602403, 6.6763904225081205, 11.948484499007463, 18.23406256735325, 24.651663601398468, 33.102919310331345, 27.83823911100626, 25.205491483211517, 23.792934380471706, 21.760765425860882, 16.206525564193726, 24.808714874088764, 31.9659823179245, 37.84484066069126, 29.771328382194042, 32.6173509657383, 35.74985347688198, 28.111001774668694, 18.755069710314274, 4.45067030377686, 0.38829890778288245, 0.033464800580986775, 0.05043823002779391, 0.0025784299896258744, 0.11495435581309721, 0.02177672053221613, 0.042248040408594534, 0.023541167356597725, 0.08769489315454848, 0.028636987080972176, 0.08124324755044654, 0.0478557676251512, 0.08940650091972202, 0.03164313602610491, 0.04039123516122345, 0.04931988769385498, 0.05311316403094679, 0.003542621061569662, 0.07313895039260387, 0.03116361956926994, 0.019049316688324325, 0.015085697050380986, 0.020814310846617445, 0.03391865728190169, 0.053808920056326315, 0.07714065519394353, 0.05209660354012158, 0.05501150728377979, 0.007095248129189713, 0.1060668627906125, 0.055218291890923865, 0.04510011392994784, 0.025574453466106206, 0.03839802688162308, 0.022808268695371225, 0.03450217089266516, 0.02419475269562099, 0.07537101148045622, 0.0843265446019359, 0.02148889525415143, 0.07248757479828782, 0.037998343250364996, 0.04061547137098387, 0.06205091158335563, 0.05550742891500704, 0.023572497120767366, 0.14445667038671672, 0.02811572852806421, 0.021500712100532837, 0.025598721695132554, 0.018641432325239293, 0.04151066474150866, 0.05800539409392513, 0.05546110405703075, 0.06740827899193391, 0.022159050895425025, 0.041977201035479084, 0.0524844610481523, 0.06600076623726636, 0.05390172933402937, 0.06095943128457293, 0.031840246738283895, 0.011219518619327573, 0.02605211269838037, 0.02570268916315399, 0.005730013208449236, 0.02329115079191979, 0.04874490878137294, 0.07155206054449081, 0.06386786350049078, 0.05653595653711818, 0.029715422278968617, 0.059077886544400826, 0.015706564809079282, 0.01837966570747085, 0.02284605143358931, 0.0278188972879434, 0.0326836715976242, 0.04348972397565376, 0.030132368265185505, 0.04788664838997647, 0.026050719316117465, 0.029488213767763227, 0.03545575644238852, 0.018649009653017856, 0.01091271755285561, 0.04680173980887048, 0.06447379739256576, 0.01664516454184195, 0.057585383037803695, 0.02655377484188648, 0.05516353252460249, 0.05093409970868379, 0.020417477062437683, 0.02369577341596596, 0.008108773236017441, 0.05428226926596835, 0.04280131892301142, 0.0265719184972113, 0.03725719747308176, 0.04522693212493323, 0.02851368295523571, 0.03343396063428372, 0.026406354627397377, 0.06768763822037727, 0.07518849510233849, 0.020169059826002922, 0.05662752271746285, 0.3629988559987396, 5.8827597834169865, 20.37512417882681, 33.78601245582104, 44.98335801064968, 44.31586302816868, 44.42972771823406, 32.418773621320724, 27.135843001306057, 24.23554603010416, 19.364978782832623, 19.11659561097622, 25.314074456691742, 31.085909642279148, 39.763190522789955, 33.78741078078747, 30.748550444841385, 23.89729008078575, 17.715327702462673, 8.970968071371317, 4.948814548552036, 2.5749057065695524, 0.9778960514813662, 0.5128862662240863, 0.347615351784043, 0.16690927965100855, 0.15480342612136155, 0.34760098380502313, 0.012122763364459388, 0.2935125189833343, 0.12223696932778694, 0.40605942194815725, 0.4915744566824287, 0.48700077866669744, 0.22236498829443008, 0.20020693744299933, 0.4106001782929525, 0.478221676312387, 0.2571675879880786, 0.5716376448981464, 0.26361539668869227, 0.14954069367377087, 0.3389962564688176, 0.15684361977037042, 0.17516102670924738, 0.31638928048778325, 0.3097889159107581, 1.2443692213855684, 3.6297986889258027, 6.641415674239397, 11.542457286268473, 17.6493214443326, 27.00093314051628, 39.01911064982414, 40.90013891458511, 36.416501104831696, 29.52292051166296, 26.540679037570953, 16.37901920825243, 14.23776475712657, 31.347508504986763, 39.99540366232395, 27.539449743926525, 35.285947769880295, 42.042175233364105, 37.492481768131256, 26.01263277232647, 8.777515701949596, 1.4735503611154854, 0.05656355700921267, 0.026152738646487705, 0.05061151779955253, 0.019413039553910494, 0.021038617560407147, 0.040647231580805965, 0.03910992090823129, 0.03079802649153862, 0.0075182426189712714, 0.040510969556635246, 0.10408696864033118, 0.021448941733979154, 0.020256889292795677, 0.0420262644183822, 0.05229159913142212, 0.0136581184779061, 0.07025920960586518, 0.04253849103406537, 0.0551494317187462, 0.017857171478681266, 0.019088797089352738, 0.010640612817951478, 0.05260436984826811, 0.030340208577399608, 0.054927151068113744, 0.06620979213039391, 0.03665304102469236, 0.07235487137222663, 0.02294422829436371, 0.0061694935811829055, 0.030919330529286526, 0.03287644445663318, 0.05388511635828763, 0.0515243557310896, 0.049716357825673185, 0.01948384229763178, 0.03699007997056469, 0.05019272386562079, 0.022198228871275205, 0.034227936193929054, 0.02170391584513709, 0.030258453589340206, 0.009118020789173897, 0.01537766722321976, 0.08525926838046871, 0.10169812143431045, 0.024239982885774225, 0.07720603098277934, 0.017316383309662342, 0.1100870619120542, 0.23894280107924715, 0.16540828597499058, 0.17193305538967252, 0.1703219863702543, 0.1868833531625569, 0.1740562656777911, 0.16406820475822315, 0.16002585995011032, 0.11969111335929483, 0.12516090500866994, 0.1292860141256824, 0.1599372475175187, 0.21515788830583915, 0.18700767774134874, 0.07555442585726269, 0.16425035748397931, 0.12835436646128073, 0.17209341865964234, 0.14507870888337493, 0.21269918273901567, 0.14531252993037924, 0.28809620649553835, 0.1980546349659562, 0.07050964733934961, 0.0527953912387602, 0.09772662946488708, 0.1306059237685986, 0.126797815610189, 0.1563824640470557, 0.15479959663935006, 0.12688059476204216, 0.18501205748179927, 0.17660910525592044, 0.14531597349559888, 0.08141400088788942, 0.18037241738056764, 0.1880564511520788, 0.19744089368032292, 0.11507457631523721, 0.08554073530831374, 0.13743501825956628, 0.24117368215229362, 0.08776818765909411, 0.17312973883235827, 0.1873903290834278, 0.22238346777157858, 0.09558245350490324, 0.16042635252233595, 0.2077422448201105, 0.15853484073886648, 0.13359413685975596, 0.15965082304319367, 0.17035320110153407, 0.21934418007731438, 0.10886556847253814, 0.12541224074084312, 0.13578814803622663, 0.380240460508503, 4.557154839858413, 19.575117006897926, 34.75365713238716, 51.13105572760105, 54.35055837035179, 55.44512763619423, 45.30758321285248, 42.67612561583519, 40.193631425499916, 34.04688745737076, 25.84648098796606, 34.00031715631485, 32.447165697813034, 44.06758055090904, 31.98033794760704, 33.56807895004749, 31.140237227082253, 18.76787692308426, 11.89940633252263, 7.611307930201292, 4.193737115710974, 1.6199585236608982, 0.8539673045743257, 0.6018299935385585, 1.3267774181440473, 1.396467222366482, 1.6826423350721598, 2.1013432927429676, 2.1477772761136293, 1.3587937876582146, 2.39849922247231, 2.3401424288749695, 2.4883845867589116, 1.418941947631538, 2.2154815681278706, 2.956130700185895, 3.826495371758938, 2.2970175929367542, 4.421106465160847, 3.056640294380486, 2.75307125877589, 2.3142781667411327, 0.9711885207798332, 1.5159475360997021, 1.0524039971642196, 0.8708330558147281, 2.5971587374806404, 5.547900376841426, 9.66976672410965, 16.25746563076973, 24.263883009552956, 32.981519624590874, 43.21058593690395, 36.70689672231674, 33.76112759113312, 31.321637593209743, 29.571681395173073, 24.39296778291464, 31.09253078699112, 40.442723259329796, 49.17045593261719, 37.40813389420509, 45.55287525057793, 48.660941272974014, 40.054000318050385, 25.437594428658485, 7.819209974259138, 1.1161371460184455, 0.12968916358659044, 0.1236612323555164, 0.12639340449823067, 0.335554561461322, 0.16968690091744065, 0.22889232554007322, 0.20917417423333973, 0.17677041847491637, 0.10904175433097407, 0.27723315346520394, 0.17938052216777578, 0.23265853204065934, 0.0765220973698888, 0.15563638298772275, 0.11761495523387566, 0.13889130495954305, 0.09196858765790239, 0.1614746212726459, 0.11499451342388056, 0.17123107274528593, 0.08160105920978822, 0.1261644222540781, 0.19030219002161175, 0.1361701759742573, 0.1545887376414612, 0.1707575231557712, 0.15286604961147532, 0.12430931281414814, 0.19364550593309104, 0.15985359263140708, 0.18555578455561772, 0.2752612967742607, 0.09031134963151999, 0.15319773025112227, 0.1353512011701241, 0.10349988529924303, 0.1840086589800194, 0.19952284055761993, 0.09026498766615987, 0.10220255921012722, 0.11313957467791624, 0.115295766008785, 0.1514353818492964, 0.13761626556515694, 0.3185166319599375, 0.2474525780417025, 0.11037664051400498, 0.19930496084271, 0.08872181773767807], [0.027045677743444685, 0.04141338031331543, 0.005753328705395688, 0.045653047345695086, 0.06193087661813479, 0.03384017887583468, 0.027814377608592622, 0.009716470121929888, 0.013962717221147614, 0.03778778853302356, 0.024627142774988897, 0.055106461368268356, 0.017450712039135396, 0.009361438733321847, 0.06255692642298527, 0.03544017505191732, 0.044564572745002806, 0.032957973089651205, 0.0836356051149778, 0.03775281482376158, 0.04312868397391867, 0.07403295632684603, 0.03824012012046296, 0.06519204791402444, 0.036709132546093315, 0.0032514280565010267, 0.03230795562558342, 0.01650813068408752, 0.03981034504249692, 0.015317235065595014, 0.03603442011808511, 0.04926730282022618, 0.025996171461883932, 0.041427596152061597, 0.07988881319761276, 0.018219346966361627, 0.041405973679502495, 0.025096794233832043, 0.02424332626105752, 0.039911659332574345, 0.025863846531137824, 0.10018825909355655, 0.054026191210141405, 0.02170793271943694, 0.013315925316419452, 0.059841575057362206, 0.09515545883914456, 0.02385963591223117, 0.033214674549526535, 0.059204233475611545, 0.05510311799298506, 0.0376392736507114, 0.035019774368265644, 0.054925466392887756, 0.08508697137585841, 0.047092632012208924, 0.017053234441846143, 0.05832914117490873, 0.058137366504524834, 0.003058035272260895, 0.3137078118743375, 3.2414652267470956, 10.644121840596199, 24.689526669681072, 32.544554471969604, 40.46021372079849, 39.29312914609909, 34.44247663021088, 28.960544988512993, 35.168313682079315, 28.194977268576622, 31.541877575218678, 22.504545114934444, 17.672289311885834, 20.566073432564735, 26.85706526041031, 15.941668376326561, 22.323032654821873, 24.902503341436386, 21.79871778935194, 18.138362802565098, 11.662630587816238, 7.994679808616638, 4.9615158420056105, 3.4346447233110666, 2.6805476378649473, 0.962934591807425, 0.8746475167572498, 0.5464984313584864, 0.47976412635762244, 0.4140120092779398, 0.14488955028355122, 0.3959165490232408, 0.08997057768283412, 0.10203689700574614, 0.09318018084741198, 0.36230212775990367, 0.19676659314427525, 0.7363045995589346, 0.7357225776650012, 1.8843711353838444, 3.1263133557513356, 6.373271187767386, 8.630694430321455, 12.9726292937994, 18.57610311359167, 18.579667322337627, 23.303674533963203, 28.6936492100358, 26.879656948149204, 27.22083304077387, 24.969336055219173, 28.34190398454666, 20.414978340268135, 20.62878906726837, 16.780159883201122, 19.556000232696533, 21.99696645140648, 31.111630462110043, 34.00967985391617, 36.81096933782101, 21.931913942098618, 14.109717328101397, 6.426773266866803, 0.728471438633278, 0.008307262487505795, 0.04710450637503527, 0.011661146581900539, 0.03552958900399972, 0.03232446098991204, 0.0416355904599186, 0.02890661304263631, 0.0144914297197829, 0.020971978265151847, 0.03181984509865288, 0.060794923119829036, 0.07495960933738388, 0.0500709300104063, 0.03277233598055318, 0.045372177846729755, 0.024660684139234945, 0.013424496883089887, 0.03566948013030924, 0.05388841520471033, 0.03378027642611414, 0.021955422271275893, 0.011342877478455193, 0.05330410007445607, 0.007799812519806437, 0.014117801038082689, 0.1176779784145765, 0.048820318406797014, 0.09380751085700467, 0.03458071609202307, 0.030060658245929517, 0.05304534286551643, 0.06409871595678851, 0.04627808040822856, 0.01792527280485956, 0.014994379489507992, 0.050429873444954865, 0.010646513819665415, 0.021298070532793645, 0.03770438226638362, 0.03417335123231169, 0.07327888975851238, 0.009196990868076682, 0.022656443834421225, 0.025280371883127373, 0.04133162903599441, 0.00716788583304151, 0.043144825685885735, 0.011916887888219208, 0.027719603494915646, 0.05905076475755777, 0.07122440976672806, 0.022444649730459787, 0.003969574445363833, 0.03766252142668236, 0.012304766732995631, 0.04431991263118107, 0.035495398260536604, 0.03403515962418169, 0.06256149805267341, 0.04136754527280573, 0.008931487536756322, 0.020630512408388313, 0.0294656673213467, 0.008712101262062788, 0.02302368633536389, 0.020081202528672293, 0.06236439847270958, 0.03146644921798725, 0.010612630139803514, 0.02267615527671296, 0.051077438110951334, 0.014358847820403753, 0.06524786484078504, 0.009016155454446562, 0.09536409881548025, 0.06739891308825463, 0.0650537561159581, 0.03007246024935739, 0.06832692422904074, 0.04315084450354334, 0.00875963582075201, 0.048927102325251326, 0.021906802321609575, 0.008622421992185991, 0.03524630010360852, 0.06746241124346852, 0.018765806998999324, 0.03305180282040965, 0.02777975270873867, 0.04303718829760328, 0.01707991094008321, 0.017994658046518452, 0.018481382612662856, 0.04327587412262801, 0.05424924740509596, 0.1363889907952398, 0.056177792357630096, 0.028920275981363375, 0.05005561950383708, 0.0205699846992502, 0.033392099794582464, 0.033948320924537256, 0.06156922805530485, 0.06155465969641227, 0.012408634011080721, 0.009478968022449408, 0.06264343857765198, 0.07255871707457118, 0.06768322986317798, 0.03256496878748294, 0.028036379953846335, 1.4015217823907733, 7.064050370827317, 19.377844892442226, 33.30441489815712, 40.28380438685417, 46.15595608949661, 43.97145330905914, 39.06089320778847, 32.01162166893482, 30.22011660039425, 25.67156307399273, 26.37117013335228, 24.703925997018814, 19.61973611265421, 25.703091882169247, 36.245107501745224, 26.67874652892351, 29.841740503907204, 30.285575687885284, 21.782196275889874, 16.944077387452126, 13.273874279111624, 8.154822215437889, 6.399751491844654, 3.9240928972139955, 3.30276140011847, 1.8264777981676161, 1.0691018449142575, 0.8895438455510885, 0.39262818172574043, 0.4420862684492022, 0.22937399422517046, 0.27213554887566715, 0.21705575287342072, 0.22517115256050602, 0.22206070774700493, 0.3708778222789988, 0.26282821549102664, 0.5927884380798787, 0.761716685956344, 1.9150598323903978, 3.0757057713344693, 6.490426501259208, 11.157457195222378, 16.21800284832716, 23.15887190401554, 27.362799122929573, 33.98540295660496, 36.803996711969376, 36.86236537992954, 37.41108253598213, 32.311600372195244, 27.726156525313854, 18.745087645947933, 17.569841109216213, 14.418058432638645, 14.959789663553238, 21.552449204027653, 32.561018988490105, 38.378392830491066, 40.83789825439453, 30.63999406993389, 21.145403645932674, 11.249417960643768, 2.5121770100668073, 0.09033245631144382, 0.044114389675087295, 0.08519490933394991, 0.020515627948043402, 0.05203999251534697, 0.03238192177377641, 0.014652959089289652, 0.0651090832252521, 0.013736643268202897, 0.032700447845854796, 0.06349054820020683, 0.05708449643861968, 0.03556291514541954, 0.028440922797017265, 0.02702302925172262, 0.04725942970253527, 0.05879663112864364, 0.041210978088201955, 0.07809145768987946, 0.05431942488939967, 0.08468553627608344, 0.026815522905963007, 0.07088840240612626, 0.056630290928296745, 0.05502039450220764, 0.12331193313002586, 0.0402207415754674, 0.05973847219138406, 0.01909225364215672, 0.050483226441429, 0.010865176500374218, 0.09454571772948839, 0.10242650969303213, 0.007300483503058786, 0.024423246977676172, 0.0486347889091121, 0.025428667831874918, 0.03003975194587838, 0.0640236477192957, 0.0404666930262465, 0.006991920299697085, 0.032934851478785276, 0.04026606082334183, 0.051507538664736785, 0.0637382325658109, 0.0799147438374348, 0.04614827506884467, 0.02209995553130284, 0.01534134187750169, 0.04616570440703072, 0.03496183860988822, 0.14411911193747073, 0.1124073940445669, 0.1015736410045065, 0.10339336484321393, 0.16202073806198314, 0.13127863610861823, 0.1451768950209953, 0.14669087628135458, 0.14346815936733037, 0.1238971165730618, 0.19379164965357631, 0.13178209424950182, 0.09580454119713977, 0.0698592810658738, 0.10702215527999215, 0.14672998746391386, 0.12717868579784408, 0.06862530470243655, 0.2963177184574306, 0.18949581688502803, 0.16921584494411945, 0.14222298399545252, 0.09598405187716708, 0.14876851870212704, 0.11368406616384163, 0.1529010641388595, 0.11064814782002941, 0.12882142968010157, 0.1496576116187498, 0.06200726216775365, 0.22513886913657188, 0.0997392597491853, 0.18787553039146587, 0.10911399498581886, 0.16580229217652231, 0.09528818452963606, 0.1555644688778557, 0.09997374130762182, 0.15501674904953688, 0.1795519285951741, 0.1517293168581091, 0.18548759602708742, 0.10173140675760806, 0.16866730875335634, 0.23390801186906174, 0.1830059284111485, 0.15676603565225378, 0.23644099157536402, 0.21237158391159028, 0.2597442059777677, 0.12350106204394251, 0.13947752740932629, 0.18200503836851567, 0.147724034904968, 0.1346627256134525, 0.14044226001715288, 0.14785981824388728, 0.20410135737620294, 0.1577485798043199, 0.14938424894353375, 0.9601809270679951, 6.059463601559401, 17.492281571030617, 34.748162627220154, 47.29768082499504, 54.35616686940193, 55.81539496779442, 50.68386912345886, 40.44791758060455, 46.14031992852688, 41.15738891065121, 42.39540807902813, 32.948582991957664, 25.740356482565403, 31.56037498265505, 38.734236136078835, 25.930129699409008, 34.506548792123795, 35.92035032808781, 30.25224767625332, 23.13042663037777, 16.704878322780132, 11.60028638318181, 7.888147300109267, 4.622104279696941, 3.657544325105846, 1.7210276378318667, 1.5157498279586434, 1.0958082368597388, 0.8028766117058694, 1.0235374211333692, 0.6040784041397274, 0.8842788124457002, 0.26278932695277035, 0.4984853358473629, 0.2677106863120571, 0.5612073233351111, 0.5026474187616259, 1.2729724240489304, 1.2624328583478928, 2.9751192312687635, 5.056444723159075, 8.248676229268312, 11.809745393693447, 17.841222546994686, 25.871170163154602, 25.438854061067104, 33.1689939647913, 38.927083387970924, 38.16289119422436, 37.878852635622025, 32.437312826514244, 35.94072103500366, 28.67699470371008, 29.371209852397442, 26.829081661999226, 29.74120169878006, 33.12801696360111, 44.24995556473732, 45.85278935730457, 50.39411187171936, 37.15270020067692, 22.381351925432682, 10.720228906720877, 1.6346770338714123, 0.1330614381004125, 0.24548282905016094, 0.15422069176565856, 0.18350056983763352, 0.14895831554895267, 0.12411507792421617, 0.14345540927024558, 0.13971419830340892, 0.12576685374369845, 0.07534714401117526, 0.21068334637675434, 0.21419760858407244, 0.1587498260778375, 0.1288201828720048, 0.10424390318803489, 0.11425212083850056, 0.1374003302771598, 0.10268940808600746, 0.19829739147098735, 0.11036314826924354, 0.1518752973061055, 0.12679796403972432, 0.16020231298170984, 0.15244263951899484, 0.21291893266607076, 0.3538257029140368, 0.14225566817913204, 0.176751553080976, 0.17837700492236763, 0.14701473468448967, 0.172696057416033, 0.20578019932145253, 0.21760555071523413, 0.13971580134239048, 0.16187671688385308, 0.14778922515688464, 0.11733683539205231, 0.0974704697728157, 0.12236081893206574, 0.1681658098823391, 0.16405535076046363, 0.12070490935002454, 0.091158867435297, 0.09601085825124756, 0.27458926721010357, 0.15651101886760443, 0.11389398263418116, 0.0813301010930445, 0.07050957312458195, 0.22983534290688112, 0.16172089555766433], [0.05645235360134393, 0.04486093086597975, 0.01969238950550789, 0.021892035438213497, 0.03304418838524725, 0.02065162279905053, 0.01032498668791959, 0.0521820061840117, 0.005999371996949776, 0.07552286973805167, 0.05195531346544158, 0.05490997034939937, 0.02223982068244368, 0.03436022030655295, 0.052862607553834096, 0.03129304641333874, 0.005590578502960852, 0.05842291153385304, 0.12935384642332792, 0.02270364999276353, 0.06101010883867275, 0.012909045635751681, 0.0167836993932724, 0.02546191604778869, 0.0445666544692358, 0.0018876667627409915, 0.027902041947527323, 0.015978612027538475, 0.06878741944092326, 0.03516635224514175, 0.018326665231143124, 0.06961846898775548, 0.0522685851319693, 0.02023909259150969, 0.004981199190297048, 0.049905375417438336, 0.05212714662775397, 0.06261377493501641, 0.03395522289793007, 0.06341453743516468, 0.05932974177994765, 0.05708870812668465, 0.029126288754923735, 0.054228678782237694, 0.04489708830078598, 0.047506806076853536, 0.061532914769486524, 0.03787934729189146, 0.05220948420173954, 0.015813536119821947, 0.07490730276913382, 0.03890247950039338, 0.05150861106812954, 0.029907193238614127, 0.003075173781326157, 0.04857085659750737, 0.04515534827078227, 0.04023944740765728, 0.03540296005667187, 0.004283240841687075, 0.0679580619907938, 0.005659170574290329, 0.273957610479556, 1.2640106049366295, 9.091395009309053, 12.056377809494734, 28.906872868537903, 37.23356746137142, 44.16626885533333, 37.98961289227009, 36.60449601709843, 43.29993434250355, 36.76426604390144, 28.451763689517975, 26.401914283633232, 26.203956305980682, 41.655279994010925, 16.3686590641737, 42.0955053716898, 52.63239696621895, 29.050326570868492, 24.17642120271921, 25.093217007815838, 19.948378577828407, 20.597159564495087, 16.651223301887512, 18.360850363969803, 13.45553683117032, 12.43202280253172, 11.326268836855888, 10.40647404268384, 13.406537510454655, 9.521319139748812, 9.38670376315713, 9.101240281015635, 11.69798769056797, 10.780766308307648, 14.545132163912058, 17.000996433198452, 21.492399126291275, 19.850689619779587, 22.052692361176014, 23.640294671058655, 21.855615936219692, 20.449123308062553, 23.969239220023155, 26.14579852670431, 21.289700902998447, 18.552964255213737, 23.602625392377377, 19.0414185449481, 25.328829064965248, 35.671205297112465, 32.96375557780266, 30.88684592396021, 36.61963440477848, 33.88986848294735, 38.721202835440636, 31.13941267132759, 32.3936303704977, 22.167146019637585, 6.815174650400877, 1.291631560306996, 0.08128655186737888, 0.05556917189096566, 0.05827789587783627, 0.02717343289987184, 0.09735577084938996, 0.08171943176421337, 0.0585185075760819, 0.10356851169490255, 0.06869687742437236, 0.04554706123599317, 0.0373058786499314, 0.07809033704688773, 0.03889669074851554, 0.03701088979141787, 0.03996165411081165, 0.03608658938901499, 0.014745018797839293, 0.05226073320955038, 0.04353035656095017, 0.04282185785996262, 0.023459083968191408, 0.03908157828846015, 0.06239991766051389, 0.030185767645889428, 0.05029990483308211, 0.040820482245180756, 0.038866919494466856, 0.01759250862960471, 0.12470788322389126, 0.03448984381975606, 0.05875440292584244, 0.054151172589627095, 0.038923059255466796, 0.023073506708897185, 0.043268085282761604, 0.0753059473936446, 0.04574446880724281, 0.012483817281463416, 0.04465379744942766, 0.02131267414370086, 0.03463484092208091, 0.020382854017952923, 0.05134716055181343, 0.04776230896823108, 0.017657995740592014, 0.04238918947521597, 0.06645260800723918, 0.004531755485004396, 0.05059625553258229, 0.06850429010228254, 0.042673803109209985, 0.03429579817748163, 0.023794527296558954, 0.06333714627544396, 0.07839871424948797, 0.01339120970442309, 0.0502034998498857, 0.049374966183677316, 0.01780430644430453, 0.013666382292285562, 0.022442948356911074, 0.020394286802911665, 0.06703581733745523, 0.07495100784581155, 0.02620571685838513, 0.03762042681046296, 0.023404682688124012, 0.027607461270235945, 0.10248852355289273, 0.025994316092692316, 0.03892982022080105, 0.06404010855476372, 0.03037786329514347, 0.04422032383445185, 0.07740384302451275, 0.03943533040001057, 0.019398385848035105, 0.035524813283700496, 0.02796505028527463, 0.06342961045447737, 0.026844680032809265, 0.08880663779564202, 0.040867141069611534, 0.07255885808262974, 0.03946664903196506, 0.013277225098136114, 0.02663096005562693, 0.03479053979390301, 0.0242064582198509, 0.05792749085230753, 0.0992417758970987, 0.021570344106294215, 0.09400069931871258, 0.04630477546015754, 0.04376885684905574, 0.025932749376806896, 0.06479025658336468, 0.01581666056154063, 0.04209410413750447, 0.02432548200886231, 0.015442705334862694, 0.07307787906029262, 0.05774270721303765, 0.05319994335877709, 0.030778899490542244, 0.0317972429911606, 0.028801916414522566, 0.06221216171979904, 0.029509500418498646, 0.07139841371099465, 0.010103671756951371, 0.010022371334343916, 0.03090820202487521, 0.11019653611583635, 0.08677013262058608, 0.9916956047527492, 4.131952906027436, 14.606405775994062, 22.074064314365387, 37.69584685564041, 43.768103420734406, 46.980660036206245, 45.33664025366306, 42.890312522649765, 46.92217357456684, 34.73685823380947, 20.698000453412533, 19.92585528641939, 25.521794110536575, 26.429436206817627, 20.96309892833233, 47.91501849889755, 51.670189797878265, 34.849214404821396, 32.89410911500454, 32.93192468583584, 31.244547329843044, 26.826968975365162, 23.168555684387684, 21.68381005525589, 17.77792364358902, 16.83267306536436, 16.539712585508823, 13.9544234611094, 16.68620802462101, 13.267011847347021, 12.147114090621471, 13.284075781702995, 15.467298980802298, 17.065036296844482, 15.864435620605946, 18.398179560899734, 23.998594544827938, 31.05080522596836, 32.62319125235081, 36.79567515850067, 31.744222417473793, 32.06017166376114, 32.377526834607124, 29.594529569149017, 23.434402719140053, 22.046152912080288, 24.800661206245422, 19.340105317533016, 22.449896447360516, 29.487949088215828, 28.256043791770935, 28.768514692783356, 35.18377885222435, 34.19705539941788, 40.728198140859604, 37.93910600244999, 38.374053463339806, 28.3680921792984, 11.307888273149729, 3.080071024596691, 0.20514235307928175, 0.05313601846864913, 0.03405903451493941, 0.06799755166866817, 0.12365635644528084, 0.01856590766692534, 0.02544221017160453, 0.03769038165046368, 0.07695370819419622, 0.03709152413648553, 0.04179141920758411, 0.05552580078074243, 0.0444029886421049, 0.028594903596967924, 0.021324025292415172, 0.036500826536212116, 0.04836589396290947, 0.027665781090036035, 0.0583982870739419, 0.032271449381369166, 0.05679734094883315, 0.02799240028252825, 0.03528554858348798, 0.04291791032301262, 0.011597205921134446, 0.013980769963382045, 0.03529562323819846, 0.07002653888775967, 0.07221233448944986, 0.06128054374130443, 0.01174312978037051, 0.05028080566262361, 0.07311276000109501, 0.037494154094019905, 0.05255643824057188, 0.02919895800005179, 0.01500641526945401, 0.008594863265898312, 0.018365167852607556, 0.03525959938997403, 0.021363503838074394, 0.02619647711981088, 0.04663483450713102, 0.007384826267298195, 0.019464704164420255, 0.056699373744777404, 0.025115143835137133, 0.03847060892439913, 0.13883610401535407, 0.06394797092070803, 0.020974095241399482, 0.02011340988246957, 0.025335745376651175, 0.1548252155771479, 0.20684924820670858, 0.1142454934597481, 0.12771800451446325, 0.23898862127680331, 0.13130541279679164, 0.06077118552639149, 0.1145595035632141, 0.06187349747051485, 0.17267683579120785, 0.19698374555446208, 0.12856813467806205, 0.14571685198461637, 0.09254692849935964, 0.12493532180087641, 0.20613196247722954, 0.14856888097710907, 0.20431263197679073, 0.242500671884045, 0.07212538446765393, 0.17618968791794032, 0.1959439372876659, 0.10407916866824962, 0.1297908229753375, 0.1374517462681979, 0.07949796112370677, 0.1562806116999127, 0.1771086745429784, 0.1637152541661635, 0.09429378085769713, 0.21754402667284012, 0.13470389996655285, 0.1406842001597397, 0.13828284776536748, 0.12227651095599867, 0.14816190203418955, 0.2440270915394649, 0.2237117339973338, 0.1488526930916123, 0.21239698020508513, 0.15640778612578288, 0.21581885986961424, 0.19128611456835642, 0.22717174520948902, 0.11508667332236655, 0.22339804301736876, 0.10963389911921695, 0.17918990895850584, 0.24541226564906538, 0.1742031960748136, 0.25307259522378445, 0.16065702686319128, 0.1116105129767675, 0.14904605224728584, 0.11105439203674905, 0.07171854653279297, 0.17914411844685674, 0.09258868914912455, 0.08065865782555193, 0.21143968391697854, 0.32368186104577035, 0.10610136523609981, 0.7189153670333326, 3.31698854919523, 13.414388839155436, 21.566324159502983, 39.61789771914482, 50.71352273225784, 58.43267172574997, 55.76207622885704, 53.02324779331684, 58.09774249792099, 54.04849737882614, 37.895841524004936, 37.377290949225426, 38.41980300843716, 51.300735622644424, 23.933272249996662, 55.567587465047836, 62.982954159379005, 41.677121222019196, 35.269088074564934, 36.828797981143, 30.402231328189373, 30.042820014059544, 25.033199228346348, 25.780482329428196, 20.867807641625404, 16.771809831261635, 17.301552705466747, 14.32307967916131, 19.313330054283142, 13.978803902864456, 13.52320360019803, 13.691648561507463, 15.117966625839472, 16.246924996376038, 20.758578702807426, 23.443453833460808, 29.385432489216328, 28.116695769131184, 31.01942840963602, 35.033116936683655, 30.20872101187706, 29.933239594101906, 34.088799208402634, 33.40274982154369, 28.185743764042854, 27.778947092592716, 32.90107414126396, 27.46008340269327, 36.5010579675436, 46.48646615445614, 43.18709559738636, 43.35070721805096, 48.46674509346485, 45.737891122698784, 52.33935289084911, 46.705387607216835, 43.02065692842007, 29.75769281387329, 11.059412006288767, 2.093692165799439, 0.1606619101949036, 0.14367947849677876, 0.24127470329403877, 0.1288543810369447, 0.20161925931461155, 0.14736606739461422, 0.13971673644846305, 0.30290288385003805, 0.17597863596165553, 0.08793006491032429, 0.16692082746885717, 0.16272313630906865, 0.0852868243237026, 0.12381199223455042, 0.10055873179226182, 0.12053769605699927, 0.09601992729585618, 0.09361743941553868, 0.13338047254364938, 0.1266932173166424, 0.10515764282899909, 0.09390758947120048, 0.1367913535796106, 0.2409004233777523, 0.08974123178631999, 0.09823885979130864, 0.13748312427196652, 0.11565948516363278, 0.1938792972941883, 0.21122710313647985, 0.13916399970185012, 0.20790581416804343, 0.11930210923310369, 0.20923801377648488, 0.1125746889738366, 0.16116020298795775, 0.10179324250202626, 0.10032099220552482, 0.09626662460505031, 0.10221851538517512, 0.15239563188515604, 0.19575903861550614, 0.1800260422169231, 0.15945400547934696, 0.08849877267493866, 0.12893623992567882, 0.15973526460584253, 0.17300010047620162, 0.19881870568497106, 0.2835559844970703, 0.11280535589321516, 0.10624241040204652, 0.12540674884803593], [0.05625115736620501, 0.04275401443010196, 0.06625883324886672, 0.044875840612803586, 0.0915692379930988, 0.007203168925116188, 0.06761484837625176, 0.023819381822249852, 0.022374231048161164, 0.038800196707597934, 0.006877135565446224, 0.03775980956561398, 0.0064619067234161776, 0.05516686476767063, 0.09216846287017688, 0.03243894469051156, 0.04199992188659962, 0.04585193550155964, 0.03330341314722318, 0.032352799898944795, 0.022377214481821284, 0.08354972378583625, 0.02616179841425037, 0.020645902695832774, 0.060650935338344425, 0.031964482259354554, 0.041207189424312674, 0.06634829172980972, 0.04114881950954441, 0.039473447104683146, 0.04921624677081127, 0.06749965963535942, 0.03168651455780491, 0.025375934528710786, 0.038882133521838114, 0.0713862721750047, 0.025884710157697555, 0.038916728735785, 0.04287061696231831, 0.04383628096547909, 0.04229201265843585, 0.05277570948237553, 0.041022075529326685, 0.06540692193084396, 0.0069437762522284174, 0.11828674731077626, 0.021465007375809364, 0.08655218611238524, 0.03083313935348997, 0.027700682439899538, 0.04448560452146921, 0.08948630405939184, 0.04821898583031725, 0.015938960932544433, 0.04219138114422094, 0.03336457724799402, 0.047558674777974375, 0.07407686178339645, 0.055287192881223746, 0.11821124120615423, 0.01780503003828926, 0.05643029697239399, 0.027983279287582263, 0.02940485574072227, 0.14531555789289996, 0.22690347366733477, 2.26219127420336, 7.631570817902684, 14.07430037856102, 24.523416683077812, 26.54855601489544, 29.426532983779907, 41.5839958190918, 46.82551056146622, 41.16430073976517, 36.97160191833973, 43.1217011064291, 27.23296768963337, 34.7835349291563, 61.10130652785301, 60.954767391085625, 39.080587550997734, 17.427732534706593, 23.502483665943146, 20.782107040286064, 26.943938098847866, 20.070570521056652, 21.37540340423584, 17.336501330137253, 21.429360508918762, 18.04714109748602, 13.798246141523123, 20.053068660199642, 19.07980788499117, 17.602120377123356, 21.294473446905613, 19.620342180132866, 31.81582197546959, 52.38935820758343, 28.814674615859985, 16.092997156083584, 19.082874320447445, 22.799213603138924, 32.37067960202694, 27.799543887376785, 28.079495765268803, 38.426661640405655, 33.2406847178936, 33.02454471588135, 33.50173071026802, 37.00547710061073, 39.04610440135002, 37.34688498079777, 39.97151054441929, 34.11726348102093, 32.13399410247803, 26.103313006460667, 18.776105381548405, 14.02049906551838, 7.206846233457327, 1.5975031536072493, 0.10858085835934617, 0.07507651243940927, 0.04367819237813819, 0.02667473007022636, 0.016062869908637367, 0.02599977087811567, 0.06528085330501199, 0.04105167980014812, 0.05417820531874895, 0.026638266499503516, 0.017336374912702013, 0.045985774413566105, 0.022778703387302812, 0.019409796368563548, 0.07493735232856125, 0.05186480855627451, 0.015641719655832276, 0.008635006033728132, 0.03031319625733886, 0.08684819913469255, 0.06601146800676361, 0.02225426102086203, 0.04565537026792299, 0.10238040747935884, 0.04527230703388341, 0.0898708330350928, 0.04387237160699442, 0.00959320124820806, 0.0662311066116672, 0.0797607259301003, 0.04423407583090011, 0.014221022647689097, 0.08846913871821016, 0.022908543978701346, 0.047763804395799525, 0.0462344940751791, 0.04133814509259537, 0.04568501164612826, 0.0331799123523524, 0.03900244308169931, 0.035106130671920255, 0.043080158648081124, 0.07570052504888736, 0.014663063429907197, 0.02157524970243685, 0.07204017107142136, 0.05699537563486956, 0.02942154107586248, 0.10957402264466509, 0.0690286916506011, 0.09003019440569915, 0.03607573547924403, 0.013660581480507972, 0.023769147701386828, 0.013256677812023554, 0.024651568710396532, 0.0321524163155118, 0.002598296123323962, 0.012644043254113058, 0.08000935282325372, 0.014000367300468497, 0.04944822358083911, 0.03929688275093213, 0.040033805707935244, 0.05119283465319313, 0.05684909461706411, 0.03850705579679925, 0.03128493102849461, 0.03026903661520919, 0.0639006812707521, 0.09958052178262733, 0.02961531212349655, 0.02920133658335544, 0.09448416400118731, 0.04011568315036129, 0.0378233448282117, 0.04284743969037663, 0.03513032839691732, 0.01907965382997645, 0.03420321154408157, 0.027692348121490795, 0.04615688027115539, 0.05389934332924895, 0.00759305110477726, 0.02771473129541846, 0.030718835623702034, 0.06649830946116708, 0.04655495715269353, 0.01174093209556304, 0.033098676867666654, 0.0758391285489779, 0.08839781832648441, 0.05385673663113266, 0.028002827457385138, 0.049896157943294384, 0.05253614050161559, 0.053460010458366014, 0.037151385768083856, 0.055552647972945124, 0.06611165052163415, 0.031091813070815988, 0.061074252662365325, 0.0623142218682915, 0.03505307453451678, 0.05363134267099667, 0.05121779307955876, 0.017594900200492702, 0.08212405067752115, 0.04809380778169725, 0.008662303152959794, 0.0823589701030869, 0.015068994089233456, 0.035108483280055225, 0.07940702576888725, 0.08652950607938692, 0.04112264396098908, 0.1041755365440622, 0.0573317726230016, 0.04546245269011706, 0.17655371135333553, 1.2332799914292991, 6.07160110026598, 14.495097398757935, 23.99346861988306, 32.85017967224121, 36.52196064591408, 38.853500336408615, 50.28717800974846, 50.47425717115402, 41.67640306055546, 35.947746858000755, 42.15972952544689, 21.450884453952312, 37.97805391252041, 68.91160503029823, 51.92432016134262, 36.25898815691471, 21.47070039063692, 27.111387513577938, 27.633946873247623, 32.10759311914444, 29.657321199774742, 30.596729591488838, 28.791083581745625, 29.57064215093851, 29.15921352803707, 28.42240646481514, 29.36076231300831, 28.73564075678587, 28.02770644426346, 30.75070682913065, 28.700369149446487, 37.697632759809494, 53.412548303604126, 33.55445668101311, 21.965982913970947, 23.211280591785908, 21.27591334283352, 25.554352663457394, 18.631281852722168, 22.159436233341694, 27.65182301402092, 27.015978433191776, 26.962426006793976, 31.413102485239506, 34.76174309849739, 39.77476090192795, 42.26749174296856, 45.12067884206772, 42.37302727997303, 39.87190268933773, 35.02588972449303, 28.94097413867712, 20.289909951388836, 12.572661805897951, 3.7070537684485316, 0.2994873421266675, 0.0806696861400269, 0.012198523654660676, 0.07459324071533047, 0.06568904937012121, 0.014638128195656464, 0.03371956503542606, 0.06571351055754349, 0.02275211223604856, 0.037289265674189664, 0.03942410541640129, 0.034158278212998994, 0.050394862628309056, 0.080897443840513, 0.03207836482033599, 0.08076217258349061, 0.02068528290692484, 0.044463651793194, 0.05752717268478591, 0.049019700090866536, 0.0317148015165003, 0.0021135788347237394, 0.032618852419545874, 0.02981797410029685, 0.08150478039169684, 0.10754647519206628, 0.0421507114515407, 0.02933552059403155, 0.065230832551606, 0.051776311156572774, 0.012525273650680901, 0.04202898438961711, 0.04999833312467672, 0.0723386109166313, 0.039314646055572666, 0.015372640100395074, 0.05794130593130831, 0.027465831662993878, 0.0817837611248251, 0.05401664719101973, 0.01924443473399151, 0.06700349680613726, 0.0647099562047515, 0.0813091873715166, 0.02032100899668876, 0.016322736628353596, 0.03680603105749469, 0.03281293516920414, 0.061230597202666104, 0.026082334807142615, 0.0846832875686232, 0.011126145309390267, 0.047710959770483896, 0.10886036601732485, 0.05807777946756687, 0.1388019058504142, 0.1321633651969023, 0.15212292229989544, 0.09523404485662468, 0.15694827743573114, 0.14635018596891314, 0.1718660246115178, 0.09650541804148816, 0.1089355158910621, 0.16889053193153813, 0.17690583073999733, 0.23483734403271228, 0.10288298988598399, 0.11433068459155038, 0.20191448566038162, 0.18427206203341484, 0.13072024419670925, 0.17095616640290245, 0.13878427242161706, 0.22240173944737762, 0.09646662598242983, 0.15368726570159197, 0.15610393602401018, 0.13131880114087835, 0.10526714671868831, 0.10038414155133069, 0.1265262340893969, 0.14138863189145923, 0.19275746686616912, 0.14091221761191264, 0.11327040047035553, 0.1738598637166433, 0.13556664664065465, 0.0918332050787285, 0.12592346174642444, 0.24459913896862417, 0.14292582753114402, 0.11844107692013495, 0.21152311615878716, 0.17231906123925, 0.16610817576292902, 0.18191416980698705, 0.08969394955784082, 0.24406019132584333, 0.16549155494431034, 0.1506327639799565, 0.10030902878497727, 0.2242088838829659, 0.16375691833673045, 0.09370971805765294, 0.11370420805178583, 0.09259760976419784, 0.20615118410205469, 0.19944117462728173, 0.07378817375865765, 0.1659750789985992, 0.10103534645168111, 0.18205915577709675, 0.1619754225248471, 0.3084286185912788, 0.10233544817310758, 0.24807446810882539, 0.07570424320874736, 0.12126025845645927, 0.12799121876014397, 1.0947811044752598, 4.387308703735471, 11.915311329066753, 20.985114946961403, 37.13349223136902, 43.03655907511711, 45.845854729413986, 57.94833831489086, 61.78426668047905, 57.1729177236557, 52.519596219062805, 60.252340883016586, 34.73463915288448, 42.94965773820877, 70.89644372463226, 66.9131326675415, 53.24663020670414, 23.174266777932644, 32.085113525390625, 30.393016822636127, 38.72809946537018, 28.750885538756847, 31.58378552645445, 26.43214926123619, 32.38410048186779, 30.436997562646866, 21.9160345941782, 30.48716627061367, 28.719731010496616, 26.671777702867985, 31.69377252459526, 30.505445189774036, 43.27703297138214, 66.88781082630157, 35.4283831268549, 22.48221181333065, 27.28321049362421, 32.019179463386536, 41.49037264287472, 36.222255527973175, 37.18324676156044, 47.6891054213047, 44.21710252761841, 45.350292921066284, 46.059418469667435, 49.06275071203709, 52.90186330676079, 54.68544200062752, 55.424779728055, 48.663540333509445, 44.95291404426098, 37.36070103943348, 29.939729645848274, 20.282587744295597, 10.174975264817476, 2.4712047586217523, 0.2829711127560586, 0.1391991032869555, 0.1068305030639749, 0.19280429638456553, 0.12596462125657126, 0.06997841061092913, 0.13342865277081728, 0.1852616565884091, 0.16432993055786937, 0.12145795917604119, 0.08283913964987732, 0.13722770672757179, 0.11305907391943038, 0.13879452890250832, 0.2777314907871187, 0.23597955383593217, 0.11492223566165194, 0.15603561390889809, 0.2039074935601093, 0.14563135657226667, 0.07992524522705935, 0.1287829122156836, 0.128329252183903, 0.15632867318345234, 0.11855454387841746, 0.1764950668439269, 0.1415758312214166, 0.13590917747933418, 0.13583632826339453, 0.1525861263507977, 0.10735326446592808, 0.13283678999869153, 0.11680869341944344, 0.2323429411626421, 0.09774982157978229, 0.1070734896347858, 0.11506163325975649, 0.07699352441704832, 0.10717085198848508, 0.10614446917315945, 0.14474738447461277, 0.20593325985828415, 0.24994194915052503, 0.1699360547354445, 0.1291188082541339, 0.14666574716102332, 0.20535294490400702, 0.17858701787190512, 0.1641525127342902, 0.19794571737293154, 0.22192348464159295, 0.16344532021321356, 0.08328343377797864, 0.12662824970902875, 0.0905825749214273], [0.0309859976550797, 0.027808989616460167, 0.028102286378270946, 0.01466156429160037, 0.035653787417686544, 0.08705555519554764, 0.017742719319358002, 0.07886038205469958, 0.06704298648401164, 0.0737005409609992, 0.037125058079254813, 0.02446672755468171, 0.005687868497261661, 0.03352802414156031, 0.059384415799286216, 0.05264941450150218, 0.045106329416739754, 0.042672255731304176, 0.0335296642879257, 0.03286545324954204, 0.05219741316977888, 0.08199247531592846, 0.024729583274165634, 0.05372634499508422, 0.0928336795186624, 0.06889109004987404, 0.020265744969947264, 0.020297865121392533, 0.04335154721047729, 0.06257065615500323, 0.046964930661488324, 0.049006742192432284, 0.044032063233316876, 0.06299489745288156, 0.017745428158377763, 0.06266454525757581, 0.04640313229174353, 0.047911532601574436, 0.08090648319921456, 0.06944750784896314, 0.015044930878502782, 0.024775140009296592, 0.03624513810791541, 0.07012917791143991, 0.0354478154622484, 0.011490920169308083, 0.056783607506076805, 0.02528822009480791, 0.043800424100481905, 0.0238148120479309, 0.0453415160154691, 0.03867098879709374, 0.0655371614266187, 0.056022880162345245, 0.0545533312833868, 0.024289614011649974, 0.06454580056015402, 0.008881490903149825, 0.010775900773296598, 0.02500245056580752, 0.08686088243848644, 0.06082065337977838, 0.05506587702257093, 0.04800591523235198, 0.043932841799687594, 0.03790439848671667, 0.0367270405695308, 0.06527015153551474, 0.3673629811964929, 1.837118414696306, 4.827093780040741, 9.930979907512665, 10.863240882754326, 17.420127242803574, 28.207626789808273, 40.455851554870605, 48.14507715404034, 50.070848017930984, 37.843651324510574, 49.03645992279053, 70.32885298132896, 46.91972270607948, 25.525067634880543, 32.99892649054527, 27.992273345589638, 27.301618605852127, 21.269702576100826, 21.498064622282982, 30.455392375588417, 24.639209769666195, 23.719548918306828, 31.334611997008324, 24.96611762791872, 20.92235181480646, 26.929626166820526, 31.63315247744322, 23.751581199467182, 36.75395719707012, 99.0797670185566, 33.29362727701664, 32.98469625413418, 32.55463533103466, 35.33592648804188, 33.659749031066895, 42.95792609453201, 47.04062841832638, 49.05280664563179, 42.11700841784477, 47.60107174515724, 36.886292695999146, 36.27199865877628, 28.799401335418224, 19.133723191916943, 15.20175687968731, 9.339719284325838, 6.518215360119939, 3.329926379956305, 1.3850871892645955, 0.4494320758385584, 0.15315214754082263, 0.0379827395954635, 0.02538123902922962, 0.026977051347785164, 0.04837017615500372, 0.04090749906026758, 0.07230669114505872, 0.006712978529321845, 0.03650276725238655, 0.017125142985605635, 0.10640001288265921, 0.03396128995518666, 0.0242096680085524, 0.011653514520730823, 0.036809430093853734, 0.04498105117818341, 0.03946988479583524, 0.04512923209404107, 0.03664499985461589, 0.04702362712123431, 0.021485574143298436, 0.07641495350981131, 0.018313263899472076, 0.05027846789744217, 0.025978454541473184, 0.03180278312356677, 0.039069867198122665, 0.041030936772585846, 0.07326539009227417, 0.05992014994262718, 0.09093667584238574, 0.06220738599949982, 0.032852179938345216, 0.04022410721518099, 0.009177642150461907, 0.08739126569707878, 0.029903933354944456, 0.03826969470537733, 0.042131378504564054, 0.037037532893009484, 0.044949617513339035, 0.08518811126123182, 0.041768264200072736, 0.03734307138074655, 0.01829617965995567, 0.0507328737876378, 0.04281884845113382, 0.042593242978909984, 0.04466537124244496, 0.043489968884387054, 0.02932119714387227, 0.026091351901413873, 0.017992264620261267, 0.011234247467655223, 0.09925701218890026, 0.03030693253094796, 0.036522972222883254, 0.04057877216837369, 0.05658538357238285, 0.010880253230425296, 0.008880483437678777, 0.009860867940005846, 0.005875330825801939, 0.04832650076423306, 0.03306749182229396, 0.13730575097724795, 0.041078523281612433, 0.04918785591144115, 0.01481523524489603, 0.013085634109302191, 0.03374071995494887, 0.05053477601904888, 0.04234908381476998, 0.05696165615518112, 0.07166845898609608, 0.03652708743175026, 0.03151673714455683, 0.07826154309441335, 0.04376423326903023, 0.033635546496952884, 0.02040623909124406, 0.04361792256531771, 0.13133763684891164, 0.04611569478583988, 0.06575990220881067, 0.06181670833029784, 0.0421762079349719, 0.02109337321599014, 0.030563205400540028, 0.038361297993105836, 0.07612918212544173, 0.01602086063940078, 0.02818874843796948, 0.051835274789482355, 0.005668391759172664, 0.02832940583175514, 0.01141678332714946, 0.013498135558620561, 0.010588643926894292, 0.07386845929431729, 0.01814451807149453, 0.0547545757581247, 0.07977346860570833, 0.05438706051791087, 0.02418776351987617, 0.027262318071734626, 0.04765481629874557, 0.053785991403856315, 0.03829514665994793, 0.08323742062202655, 0.059627907030517235, 0.004396306112539605, 0.02435145346680656, 0.03896349517162889, 0.06256899374420755, 0.01624063283088617, 0.03874143716529943, 0.16503068123711273, 0.05626489823043812, 0.09893916518194601, 0.04889001349511091, 0.05412037717178464, 0.011587711996980943, 0.03086806296778377, 0.1622723409673199, 0.8592575113289058, 4.349680747836828, 9.893071241676807, 16.79290819913149, 21.404701732099056, 30.83205856382847, 40.1124107837677, 49.656237065792084, 52.951906621456146, 50.49796789884567, 36.987686455249786, 53.13165217638016, 78.87067303061485, 46.53450317680836, 21.062119714915752, 23.091003745794296, 22.89837498217821, 23.599709048867226, 16.97197549045086, 17.417932860553265, 17.98153381794691, 23.65251861512661, 20.095141902565956, 18.460737504065037, 20.787542648613453, 18.3674943074584, 17.85078853368759, 23.85289516299963, 17.78080578893423, 34.741801768541336, 94.28297281265259, 25.55200818926096, 15.835774708539248, 21.672914139926434, 27.287105284631252, 31.18985876441002, 37.49368630349636, 44.52387526631355, 48.829374834895134, 45.05478277802467, 51.73513971269131, 43.33540923893452, 43.905804231762886, 38.40585395693779, 30.40720336139202, 25.555333010852337, 16.53093695640564, 12.559661753475666, 7.05033453181386, 3.5790137015283108, 1.3234240980818868, 0.2797296195058152, 0.025008400734805036, 0.06549635072587989, 0.03407814852835145, 0.056705422248342074, 0.04226410419505555, 0.03729687268787529, 0.024313232861459255, 0.03424421891395468, 0.007834406806068728, 0.08279576853965409, 0.012015104639431229, 0.05147500291059259, 0.02676790114492178, 0.05836189215187915, 0.03000388023792766, 0.08696104268892668, 0.024240589591499884, 0.004072619331054739, 0.02468343467626255, 0.1003289183427114, 0.04893785975582432, 0.015603833016939461, 0.08662761800223961, 0.03125795024971012, 0.04962524806614965, 0.04220236121909693, 0.06143747457826976, 0.03868644402245991, 0.07257073986693285, 0.05321130563970655, 0.15061640704516321, 0.016285677484120242, 0.012601968119270168, 0.043532820491236635, 0.034513340215198696, 0.022749434938305058, 0.032930799352470785, 0.013994866130815353, 0.037288612584234215, 0.04048856411827728, 0.017239142434846144, 0.05236142409557942, 0.04507110337726772, 0.007999468798516318, 0.021604911489703227, 0.03700369466969278, 0.038661248108837754, 0.02315205376362428, 0.005854614701092942, 0.0284669202301302, 0.013175078674976248, 0.011204794409422902, 0.060306352461338975, 0.017337400931864977, 0.04140174714848399, 0.05915856541832909, 0.13588262343546376, 0.15085383492987603, 0.1130645138619002, 0.15974605543306097, 0.1286099769640714, 0.11613259688601829, 0.11993713531410322, 0.1505771474330686, 0.3589499060763046, 0.164101260015741, 0.2342827370739542, 0.11322075821226463, 0.12469281762605533, 0.1743603977956809, 0.16835342481499538, 0.12797092844266444, 0.1484438290935941, 0.2084895726875402, 0.16234130132943392, 0.1720317907165736, 0.16055938991485164, 0.11214607642614283, 0.1311740675009787, 0.13394423760473728, 0.14686195616377518, 0.18468453286914155, 0.1658413143013604, 0.17593213298823684, 0.12728548084851354, 0.18529612192651257, 0.1309755429974757, 0.12294102256419137, 0.14834913105005398, 0.18717731785727665, 0.1666779225342907, 0.15525667055044323, 0.1104326058703009, 0.18697122344747186, 0.16524836799362674, 0.19066337845288217, 0.19959004945121706, 0.06644765046075918, 0.13648965570610017, 0.15255602484103292, 0.1174670377804432, 0.14298506575869396, 0.17766242061043158, 0.09257880374207161, 0.09133549116086215, 0.12398457867675461, 0.17049794958438724, 0.14269518287619576, 0.30979805917013437, 0.1774779226980172, 0.1182419215911068, 0.12273821586859412, 0.14020373375387862, 0.12605366413481534, 0.10047972275060602, 0.1708921042154543, 0.22621848620474339, 0.21303208050085232, 0.14428520458750427, 0.1269749811035581, 0.17450107930926606, 0.12290909537114203, 0.12090316668036394, 0.18967875628732145, 0.6896403129212558, 2.6144881825894117, 7.294184071943164, 15.650162268429995, 22.213590927422047, 32.07390412688255, 44.90740388631821, 58.12371410429478, 66.67322874069214, 69.11216586828232, 48.8271177560091, 63.91972169280052, 79.32406470179558, 60.888232961297035, 35.56939736008644, 42.9027758538723, 38.788474425673485, 36.457223519682884, 32.071650847792625, 30.69174349308014, 40.95173254609108, 37.006506845355034, 33.95153537392616, 40.27154244482517, 34.06713657081127, 31.508114486932755, 37.72351697087288, 42.37388223409653, 32.39992283284664, 44.35914270579815, 109.82363730669022, 38.74272108078003, 42.7514261752367, 43.70071403682232, 45.396783426404, 48.49258370697498, 54.56010192632675, 62.003290727734566, 62.2755841165781, 57.13078938424587, 62.29480728507042, 51.846279948949814, 50.21287299692631, 41.469960138201714, 30.323275364935398, 22.535002380609512, 14.132546503096819, 9.603551477193832, 5.3094584215432405, 2.5436200853437185, 0.9608736773952842, 0.18362228205660358, 0.08669567294418812, 0.07155776023864746, 0.16864658799022436, 0.12554134475067258, 0.23428310814779252, 0.1392575548379682, 0.0945032668823842, 0.24904528632760048, 0.1296964069479145, 0.2330748620443046, 0.1010158279677853, 0.13360093493247405, 0.09472016696236096, 0.12035749517963268, 0.16364865383366123, 0.21474362147273496, 0.10756237941677682, 0.08334967787959613, 0.17200450936798006, 0.13093828718410805, 0.15400897187646478, 0.16062676208093762, 0.15679969947086647, 0.19154677167534828, 0.2735527837648988, 0.09883657068712637, 0.14820886513916776, 0.10416941382572986, 0.2990379568655044, 0.1494415130582638, 0.2804213605122641, 0.13362693978706375, 0.1326808796147816, 0.12493104703025892, 0.2159532776568085, 0.09568360823323019, 0.17084548249840736, 0.11383493736502714, 0.11635016489890404, 0.11951031876378693, 0.19816221669316292, 0.11166939497343265, 0.16771321854321286, 0.16627628705464303, 0.13580085360445082, 0.1917370583396405, 0.19525653042364866, 0.16049768775701523, 0.11596736512728967, 0.15329070651205257, 0.11190472258022055, 0.1234147057402879, 0.1420984516153112, 0.15058842807775363, 0.10184303318965249, 0.0720955130236689], [0.052626905162469484, 0.06795323803089559, 0.0643853259680327, 0.01609236656804569, 0.021468775630637538, 0.013889801211917074, 0.029636097824550234, 0.0645764809451066, 0.008923746936488897, 0.04932930925861001, 0.027064658170274924, 0.044360842075548135, 0.02277726547617931, 0.021931274641247, 0.029669904506590683, 0.08333480524015613, 0.018800758443831, 0.04505200049607083, 0.06572974874870852, 0.05077061941847205, 0.02549302502302453, 0.05400236084824428, 0.02088398367050104, 0.060030566673958674, 0.05327438819222152, 0.019808392753475346, 0.011138570716866525, 0.028445308889786247, 0.08052739416598342, 0.05401254311436787, 0.013446985813061474, 0.021624593246087898, 0.035452939991955645, 0.01063040086592082, 0.03650936865597032, 0.029942515757284127, 0.1135008002165705, 0.03457398481259588, 0.0626004979130812, 0.07584681719890796, 0.028867887776868884, 0.002895817560784053, 0.06899039683048613, 0.017974167349166237, 0.018019930030277465, 0.03180411898938473, 0.04407301123137586, 0.0753442793211434, 0.03899986040778458, 0.03874856178299524, 0.022203010157682, 0.04204259537800681, 0.041535374548402615, 0.07662642106879503, 0.055521514877909794, 0.009936018741427688, 0.026636062320903875, 0.03223854997486342, 0.008950343653850723, 0.07539661557530053, 0.012880517479061382, 0.04638186605006922, 0.04243301329552196, 0.03686511343403254, 0.07246482055052184, 0.05770103191025555, 0.10100671439431608, 0.11278876147116534, 0.13035167881753296, 0.020061652503500227, 0.028764677299477626, 0.15787538315635175, 0.05254997784504667, 1.7408883408643305, 4.276449652388692, 11.116076465696096, 20.855959877371788, 34.104047790169716, 49.129885509610176, 56.76764287054539, 53.40408995747566, 54.709270521998405, 49.21835236251354, 44.60081733763218, 49.45262499153614, 46.48183800280094, 43.5383715480566, 45.68051040172577, 46.78768739104271, 38.953966945409775, 43.120401576161385, 51.64627008140087, 40.114979445934296, 42.401654943823814, 39.16857182979584, 41.352918818593025, 35.47664813697338, 41.69001393020153, 70.03721103072166, 50.35535775125027, 48.56014788150787, 44.47541646659374, 45.80514371395111, 45.97648411989212, 41.50212921202183, 33.09401638805866, 34.772371128201485, 24.984873421490192, 18.03201410919428, 10.464035253971815, 6.512070614844561, 2.273172684945166, 0.7539132703095675, 0.20930448052240536, 0.02700031953281723, 0.003723433746927185, 0.0639911787584424, 0.014175230280670803, 0.034769937774399295, 0.03703299465996679, 0.023029267285892274, 0.04808308745850809, 0.08487154816975817, 0.023091268158168532, 0.03693417027534451, 0.051158091009710915, 0.057568870251998305, 0.03448506809945684, 0.07507585192797706, 0.08592512327595614, 0.05966616474324837, 0.023700304227531888, 0.0060868113723699935, 0.005215437231527176, 0.0007342058847825683, 0.01875822781585157, 0.03347861194924917, 0.04162736004218459, 0.01499936857726425, 0.07163999762269668, 0.06280395027715713, 0.005375800965339295, 0.0395160389598459, 0.015111451430129819, 0.046804062731098384, 0.01019746716337977, 0.04286352574126795, 0.024810737122606952, 0.08717083299416117, 0.01415415235896944, 0.03651327235274948, 0.03570044624211732, 0.0214320448867511, 0.031473377166548744, 0.03361842886079103, 0.027288473211228848, 0.05369615442759823, 0.0799657590687275, 0.010622854151733918, 0.05823604988108855, 0.06459364682086743, 0.060260094396653585, 0.03935119311790913, 0.06362472107866779, 0.04282167232304346, 0.009223962370015215, 0.07453337166225538, 0.02973169943288667, 0.031312820938182995, 0.008729102937650168, 0.05050183579442091, 0.0815991370473057, 0.013642202193295816, 0.05598788789939135, 0.023512774641858414, 0.02251356370834401, 0.025444625862292014, 0.06851383412140422, 0.11054507092921995, 0.019651838556455914, 0.0009924920618686883, 0.052469046640908346, 0.046347270836122334, 0.01944033760082675, 0.014250433960114606, 0.03530496316670906, 0.06535368025652133, 0.020641819028242026, 0.01107551135646645, 0.0011715266077771957, 0.028662747026828583, 0.08269350058981217, 0.03635227454651613, 0.02489184458681848, 0.060106915116193704, 0.0468826710130088, 0.034116484166588634, 0.10025863695773296, 0.020524110695987474, 0.049293359625153244, 0.05108580211526714, 0.058760970932780765, 0.040211750456364825, 0.035284773039165884, 0.031316906461142935, 0.022365867043845356, 0.05574277507548686, 0.05122266898979433, 0.03466777372523211, 0.029260775190778077, 0.03733254401595332, 0.03424820795771666, 0.07202787368441932, 0.010818305236171, 0.009644194215070456, 0.017939768804353662, 0.025713895593071356, 0.037058316738693975, 0.026149146651732735, 0.06020407337928191, 0.04994831237127073, 0.04426942061400041, 0.03685351737658493, 0.05086850869702175, 0.0389780338446144, 0.03245910142140929, 0.009928015606419649, 0.021738839459430892, 0.06352460535708815, 0.027013809922209475, 0.018131684482796118, 0.02357700195716461, 0.04180017283943016, 0.01793111536244396, 0.042423851482453756, 0.030662341487186495, 0.0019278474496786657, 0.028834368677053135, 0.0034807489055310725, 0.014544949699484278, 0.03552007838152349, 0.03332669431983959, 0.040211980522144586, 0.025879385248117615, 0.05943581694737077, 0.07455054495949298, 0.04097159093362279, 0.5523460207041353, 0.6821763259358704, 4.362733522430062, 9.284085519611835, 20.690955631434917, 34.191557094454765, 47.23037123680115, 57.45746925473213, 63.142203614115715, 60.591522082686424, 56.05099372565746, 48.44471387565136, 46.25676088035107, 48.32155108451843, 39.35580678284168, 39.548004269599915, 39.47662129998207, 41.5239704400301, 35.34428223967552, 37.375926822423935, 42.26368434727192, 33.81904028356075, 35.257582291960716, 32.874657958745956, 37.61509358882904, 28.32849070429802, 43.51268112659454, 80.217966735363, 49.0090823918581, 44.96978513896465, 44.71103422343731, 48.35434332489967, 49.798467233777046, 50.66704362630844, 45.04935286939144, 43.81385676562786, 35.21440900862217, 28.004035614430904, 17.85781055688858, 12.780706342309713, 6.304778438061476, 2.4929431546479464, 1.218428963329643, 0.5204880551900715, 0.2259077489725314, 0.06957576581044123, 0.09321086865384132, 0.012720208014798118, 0.05622497439617291, 0.02734470574068837, 0.04152704022999387, 0.08866435324307531, 0.052438336570048705, 0.054905005381442606, 0.10949145129416138, 0.07053142195218243, 0.03171427459164988, 0.04963399798725732, 0.02699479053262621, 0.04163776866334956, 0.011992919062322471, 0.06492767264717259, 0.031011824394227006, 0.028114058695791755, 0.03301590513729025, 0.038733741093892604, 0.049301371109322645, 0.03975529252784327, 0.07365865414612927, 0.05067362813861109, 0.006431038482332951, 0.061149510147515684, 0.023304878668568563, 0.029431235379888676, 0.031407185015268624, 0.046364188092411496, 0.02131044584530173, 0.005552860702664475, 0.02464278724801261, 0.014266873458836926, 0.05892193163163029, 0.05469319272378925, 0.04212708518025465, 0.018251168403367046, 0.08471941531752236, 0.05150975026481319, 0.04488344020501245, 0.08472459550830536, 0.09177581479889341, 0.043683806725312024, 0.04177434981102124, 0.020897301510558464, 0.035796097945421934, 0.019129960310237948, 0.02922030402260134, 0.07409355268464424, 0.022119895184005145, 0.04928959322569426, 0.021195342451392207, 0.015445615481439745, 0.032708399958210066, 0.046461695164907724, 0.025375151562911924, 0.02888881634135032, 0.03186239242495503, 0.12008156467345543, 0.15513580437982455, 0.19788984849583358, 0.07353529435931705, 0.11326941341394559, 0.14216946030501276, 0.15721142815891653, 0.09169975950499065, 0.18991691147675738, 0.10681240208214149, 0.1258296097512357, 0.1641862210817635, 0.10964219633024186, 0.16679405380273238, 0.09736656909808517, 0.17729081242578104, 0.0975585998094175, 0.1449173066066578, 0.1674102441756986, 0.11324086299282499, 0.10274938103975728, 0.15526266710367054, 0.17254195787245408, 0.17436565220123157, 0.2441759960493073, 0.1510851178318262, 0.12567559926537797, 0.10801982440170832, 0.11772379861213267, 0.12469673616578802, 0.10957513586618006, 0.09293303082813509, 0.09837090270593762, 0.08233060521888547, 0.10478993834112771, 0.12158229117630981, 0.2452886090031825, 0.08807065736618824, 0.18568104424048215, 0.10822107258718461, 0.12267370839253999, 0.09324669212219305, 0.1222145787323825, 0.2137840393697843, 0.21255645289784297, 0.09923618752509356, 0.1178603240987286, 0.09949792816769332, 0.12033348670229316, 0.12613831349881366, 0.12557057052617893, 0.11248477778281085, 0.11245348141528666, 0.13397243921644986, 0.24911834334488958, 0.21877363178646192, 0.12032576836645603, 0.10265534350764938, 0.13122532021952793, 0.17131204105680808, 0.11514810830703937, 0.149783895467408, 0.11133734325994737, 0.18287973362021148, 0.11916565053979866, 0.16918791050557047, 0.17532009864225984, 0.1362518864334561, 0.2477159959380515, 0.26014024566393346, 0.16484903317177668, 0.401122507173568, 0.4431298765121028, 3.3506654296070337, 7.930363034829497, 20.023777931928635, 34.15677756071091, 50.09784556925297, 67.55002409219742, 73.86033788323402, 68.4554623067379, 70.08672997355461, 64.34747993946075, 61.23166233301163, 67.61538818478584, 60.56199386715889, 59.590754583477974, 59.09735105931759, 59.52441394329071, 53.6274229735136, 57.39391766488552, 62.86187745630741, 52.749358490109444, 54.21992518007755, 50.95140516757965, 54.44508209824562, 48.35126169025898, 53.353233486413956, 85.27601972222328, 61.30683369934559, 64.05649155378342, 61.14915356040001, 61.35191448032856, 61.716725304722786, 58.40350829064846, 50.29284730553627, 47.81969681382179, 34.396932274103165, 26.540622040629387, 15.7350392639637, 9.351896680891514, 4.280533483251929, 1.5354052232578397, 0.8223891584202647, 0.2711579028982669, 0.15389732317999005, 0.17338327132165432, 0.10977426150930114, 0.10599543107673526, 0.09659696195740253, 0.04966708664142061, 0.189139986759983, 0.15884210471995175, 0.1515602704603225, 0.16589123115409166, 0.2145284877042286, 0.11131232546176761, 0.12883199786301702, 0.1931397768203169, 0.13842330663464963, 0.2186816351604648, 0.1758151111425832, 0.14546937542036176, 0.1793014389113523, 0.10527438265853561, 0.06087318259233143, 0.13613648246973753, 0.08004225965123624, 0.1029348437441513, 0.3419726248830557, 0.1229399761359673, 0.11515171514474787, 0.13854777964297682, 0.09693309548310935, 0.15278705541277304, 0.18710301403189078, 0.11256084791966714, 0.07301864083274268, 0.1438274627435021, 0.07295161747606471, 0.16201969905523583, 0.1715520813013427, 0.2347848445060663, 0.07263213032274507, 0.08921953907702118, 0.14341294358018786, 0.13002759777009487, 0.2118088281713426, 0.1438969129230827, 0.14118246326688677, 0.13260501727927476, 0.1562049868516624, 0.1689436548622325, 0.1202130138699431, 0.15558550134301186, 0.09780448075616732, 0.14424656837945804, 0.09011736707179807, 0.20349730853922665, 0.18519988021580502, 0.16986443748464808, 0.18430851632729173, 0.1274248561821878, 0.14262776618124917, 0.09793555887881666, 0.08320046908920631], [0.02787297202303307, 0.0477783059614012, 0.025388231915712822, 0.025187731444020756, 0.08433248178334907, 0.09683492418844253, 0.06238442161702551, 0.028868954614154063, 0.07279109093360603, 0.04728986146801617, 0.0071591015876038, 0.04868386342423037, 0.0153599085570022, 0.09603241764125414, 0.0444705797417555, 0.06592296689632349, 0.10898818611167371, 0.019079407065873966, 0.031821633674553595, 0.05372865678509697, 0.012246616679476574, 0.05000854878744576, 0.013041429938311921, 0.020456588244996965, 0.025381162959092762, 0.06259219328057952, 0.04324363522755448, 0.06544569172547199, 0.020863797253696248, 0.005376830695240642, 0.06243965224712156, 0.0338319187721936, 0.011019698140444234, 0.02552180550992489, 0.07109242622391321, 0.040429652435705066, 0.009277274548367132, 0.03699644388689194, 0.0303262005400029, 0.0657541208784096, 0.07024922029813752, 0.041491743686492555, 0.031964738300303, 0.03690591671329457, 0.055903784013935365, 0.05153541002073325, 0.0490706114214845, 0.06808206002460793, 0.01700935867120279, 0.03363636657013558, 0.03760502353543416, 0.009827251433307538, 0.012125119683332741, 0.02871788488846505, 0.11029054396203719, 0.017571596763445996, 0.043677472494891845, 0.01611795581993647, 0.05985147159663029, 0.01674720799201168, 0.040882047105696984, 0.06836853644927032, 0.01025459861921263, 0.010607805252220714, 0.0406255126290489, 0.017552258250361774, 0.04949498630594462, 0.00861276386785903, 0.030965310288593173, 0.057763327786233276, 0.027215555346629117, 0.020266043684387114, 0.07344435158302076, 0.02326495297893416, 0.04586881565046497, 0.16215986106544733, 0.6828515022061765, 4.222248885780573, 9.350485056638718, 17.124413810670376, 22.903795391321182, 31.70930039137602, 31.05377096682787, 34.03770714998245, 34.24795366823673, 43.77327874302864, 48.75146001577377, 48.33741903305054, 48.232833445072174, 51.7067514359951, 47.583984062075615, 47.35426738858223, 45.716015696525574, 49.688094556331635, 50.449486300349236, 50.59912607073784, 52.375017777085304, 43.62315259873867, 44.95704062283039, 50.63727982342243, 44.51298505067825, 36.54491141438484, 30.35785160958767, 21.215849965810776, 14.678334016352892, 6.955038020387292, 3.17597265355289, 1.4088338962756097, 0.3130569780478254, 0.035507988795870915, 0.12038809392834082, 0.024796948018774856, 0.08351243828656152, 0.032627190448693, 0.0596229791699443, 0.030324072431540117, 0.05956160355708562, 0.018637669636518694, 0.03880764787027147, 0.15519345441134647, 0.04642974570742808, 0.04791612649569288, 0.02346937941183569, 0.04446064980584197, 0.0366606220632093, 0.073496175755281, 0.011220706983294804, 0.049410733990953304, 0.038233949162531644, 0.05111328384373337, 0.0741384897264652, 0.06467828876338899, 0.08165344741428271, 0.03266374864324462, 0.021899981984461192, 0.028692998821497895, 0.01897851579997223, 0.03359536291100085, 0.035624472584459, 0.008753544643695932, 0.045994943648111075, 0.05954013693553861, 0.035537734074750915, 0.005272652178973658, 0.03802815903327428, 0.060617816998274066, 0.03919805465557147, 0.048868083031265996, 0.13548164104577154, 0.04687088199716527, 0.06919515537447296, 0.06730658991727978, 0.06257934670429677, 0.08468767366139218, 0.04088575784408022, 0.043278300945530646, 0.04482899254071526, 0.018763361622404773, 0.03136137966066599, 0.022357510461006314, 0.0716119073331356, 0.09228243448887952, 0.017438950853829738, 0.0480951473582536, 0.02327671230887063, 0.02929631849838188, 0.07650916173588485, 0.04097143879334908, 0.04829916375456378, 0.02276096976856934, 0.020592495893652085, 0.0570175658504013, 0.03240260171878617, 0.024753742036409676, 0.03343534473970067, 0.04851329933444504, 0.03406466741580516, 0.03010301817994332, 0.03963087518059183, 0.02634935768583091, 0.09117321314988658, 0.0955183913174551, 0.08165192601154558, 0.029615026396641042, 0.059782507523777895, 0.01848441799666034, 0.07292698559467681, 0.03301050601294264, 0.06510040009743534, 0.028414107146090828, 0.029693089200009126, 0.05799632504931651, 0.096612613851903, 0.04621206266165245, 0.02773316253296798, 0.057357922196388245, 0.06693887800793163, 0.02550848395912908, 0.028217859180585947, 0.06640967476414517, 0.01605675646715099, 0.05919340554100927, 0.04634251738025341, 0.0414813313545892, 0.04524077317910269, 0.027878172622877173, 0.02684538692847127, 0.0741916720289737, 0.018277529488841537, 0.009926971033564769, 0.06805358381825499, 0.020247605025360826, 0.023954892421897966, 0.024924359931901563, 0.026381934258097317, 0.036022894564666785, 0.06735365692293271, 0.06056557351257652, 0.044158168966532685, 0.05888351435714867, 0.005805239616165636, 0.013544729445129633, 0.04060082879732363, 0.08129797352012247, 0.04346381188952364, 0.057868182120728306, 0.030993764230515808, 0.05128143966430798, 0.016189454327104613, 0.03241859871195629, 0.06786861835280433, 0.0019873571409334545, 0.007319912929233396, 0.05435155988379847, 0.05348991529899649, 0.03373744337295648, 0.03265811574237887, 0.059873602440347895, 0.009457834439672297, 0.01409335376592935, 0.023909896008262876, 0.04841119465709198, 0.023971414484549314, 0.0339782999799354, 0.10679454600904137, 0.034397550334688276, 0.08387513327761553, 0.02388236789556686, 0.02209673089964781, 0.0609393636113964, 0.07192267425125465, 0.5999158462509513, 2.300840662792325, 8.458364177495241, 16.915523819625378, 28.924340531229973, 35.75768485665321, 44.465472400188446, 42.32409730553627, 44.71110261976719, 46.983566880226135, 54.11618694663048, 57.1435035020113, 55.483395382761955, 54.697745740413666, 57.745573595166206, 56.514751240611076, 57.37697437405586, 55.31764827668667, 58.26755538582802, 57.739440724253654, 55.68549893796444, 57.46908903121948, 52.21313126385212, 55.577045157551765, 59.266742169857025, 55.7452317327261, 47.03106813132763, 41.786376759409904, 31.094757467508316, 22.488509975373745, 12.147781904786825, 6.895609209313989, 3.4844845114275813, 1.409678638447076, 0.14063735579838976, 0.21517618966754526, 0.05286257044645026, 0.09235897217877209, 0.02620825129270088, 0.01618139645870542, 0.020672117207141127, 0.06379978629411198, 0.030766954623686615, 0.012479072174755856, 0.027492508161230944, 0.004069689703101176, 0.021016904174757656, 0.04154315967753064, 0.02309971008799039, 0.013448329100356204, 0.0491250776394736, 0.0900455642840825, 0.04217382564092986, 0.02993658414197853, 0.05996065265208017, 0.010063598565466236, 0.03656207969470415, 0.06325819660560228, 0.019260290719103068, 0.05496631420101039, 0.0456518710416276, 0.026868213535635732, 0.014699239418405341, 0.00873539263920975, 0.03246897569624707, 0.02152261287847068, 0.04817730310605839, 0.050024998490698636, 0.03210075170500204, 0.037924551506876014, 0.06309286836767569, 0.12272250460227951, 0.04900291271042079, 0.03940612688893452, 0.007826970486348728, 0.05816223958390765, 0.02513571616873378, 0.023502803887822665, 0.04167249375313986, 0.057261572874267586, 0.04463461664272472, 0.04317948027164675, 0.011940707117901184, 0.057808609926723875, 0.07758019215543754, 0.0731256214203313, 0.025487796592642553, 0.027290373109281063, 0.0256443470789236, 0.06983120561926626, 0.07164989045122638, 0.04887253962806426, 0.04667167100706138, 0.03816539698163979, 0.020186240544717293, 0.12001864539342932, 0.028697253183054272, 0.02195499368099263, 0.024027736071730033, 0.08194993541110307, 0.043721826950786635, 0.1309006751398556, 0.13527305301977322, 0.16853921406436712, 0.08345160444150679, 0.17181655304739252, 0.22643327858531848, 0.2302911106380634, 0.24083392694592476, 0.25043636793270707, 0.108444340294227, 0.08344635003595613, 0.10221869350061752, 0.14918927190592512, 0.16408105875598267, 0.09902244157274254, 0.14367633179062977, 0.22105166892288253, 0.08480773831252009, 0.09811557421926409, 0.15341121645178646, 0.09804124812944792, 0.12099852523533627, 0.06051174925232772, 0.0931421754648909, 0.1614741759840399, 0.17154317552922294, 0.10365445239585824, 0.11084377052611671, 0.12846031546359882, 0.1372998286387883, 0.1315885569783859, 0.19589059171266854, 0.1520732874632813, 0.06989457760937512, 0.17845029942691326, 0.13033983414061368, 0.07493308497942053, 0.10047526986454614, 0.10575415144558065, 0.22242465696763247, 0.1457408381975256, 0.16227870859438553, 0.10490342014236376, 0.15240667504258454, 0.16031652950914577, 0.14755442447494715, 0.15418058610521257, 0.17246691189939156, 0.13726862875046209, 0.2557924477150664, 0.11394583649234846, 0.12148538895417005, 0.1218687453365419, 0.13462600414641201, 0.1747058378532529, 0.11781824432546273, 0.09447425632970408, 0.1226128671260085, 0.21812998194945976, 0.08065996400546283, 0.08390365401282907, 0.14766570209758356, 0.12768031825544313, 0.07538052581367083, 0.14901462971465662, 0.12210570566821843, 0.12833153799874708, 0.11075810441980138, 0.1871882867999375, 0.14006987999891862, 0.19059360172832385, 0.1094746713351924, 0.15340188023401424, 0.1411905378336087, 0.19704476493643597, 0.3505290829343721, 1.7033272376284003, 6.7385137639939785, 14.120394755154848, 26.74963742494583, 34.914616495370865, 42.415706589818, 44.29621048271656, 47.19717621803284, 50.11514604091644, 59.53832499682903, 64.4787248969078, 64.77186396718025, 64.44535508751869, 65.95151826739311, 64.23266530036926, 67.41214469075203, 64.0849444270134, 67.8624053299427, 69.61042553186417, 67.41133153438568, 70.72422936558723, 63.11837889254093, 64.9702513217926, 67.03372299671173, 61.75350733101368, 53.040650859475136, 42.17729978263378, 30.06910700351, 19.479193054139614, 10.188019964843988, 4.195385277271271, 2.4421536549925804, 0.7544564036652446, 0.11706111268722452, 0.241635802667588, 0.1497577124973759, 0.17171827785205096, 0.12612253543920815, 0.1782951015047729, 0.13220556371379644, 0.131716147006955, 0.09751817502547055, 0.0790484348544851, 0.1660370928584598, 0.15826661372557282, 0.09786804570467211, 0.09898328586132266, 0.14039357512956485, 0.1138317609729711, 0.13213635102147236, 0.18531500216340646, 0.12779597454937175, 0.1947846432449296, 0.1625468910788186, 0.15072481997776777, 0.12808386847609654, 0.18397992302197963, 0.12032211699988693, 0.1262656957260333, 0.15493024431634694, 0.12058525288011879, 0.16922201961278915, 0.10689830567571335, 0.15054827788844705, 0.14643882808741182, 0.18299271818250418, 0.20368410710943863, 0.11567948604351841, 0.13859883940313011, 0.14970739488489926, 0.29100604879204184, 0.09806196147110313, 0.28533007367514074, 0.10328074393328279, 0.15491321944864467, 0.11436606277129613, 0.17171106417663395, 0.18927719502244145, 0.16886357712792233, 0.1935098264948465, 0.1425334095256403, 0.10165680607315153, 0.20806629618164152, 0.17113689420511946, 0.18813071044860408, 0.22494540608022362, 0.09031837034854107, 0.156594198779203, 0.14618992659961805, 0.10935308528132737, 0.16319149086484686, 0.20855796901741996, 0.1205080324143637, 0.09631258581066504, 0.15169839898589998, 0.11797706392826512, 0.1320399163523689, 0.11776150713558309, 0.1763764864881523, 0.15411003754707053], [0.024414920080744196, 0.028407401841832325, 0.031976519894669764, 0.021334216835384723, 0.045585430270875804, 0.025444761304243002, 0.025153087990474887, 0.03837424847006332, 0.0705633194593247, 0.05058821065176744, 0.029430808644974604, 0.040330007977900095, 0.05628390092169866, 0.05945858603809029, 0.04137489253480453, 0.014051706293685129, 0.01644962903810665, 0.05015631781134289, 0.014630054556619143, 0.03292111803602893, 0.15972178720403463, 0.03962626644351985, 0.08969205708126538, 0.05645259851007722, 0.07286912034032866, 0.00975282144281664, 0.05048556049587205, 0.056362609393545426, 0.026152035461564083, 0.017829385469667614, 0.01630879909498617, 0.061072022508597, 0.014635381321568275, 0.04044519300805405, 0.008550728671252728, 0.04330699608544819, 0.021095237862027716, 0.047399988761753775, 0.03678115797811188, 0.04826578195206821, 0.060402152594178915, 0.10088295384775847, 0.0260135302960407, 0.07075428889947943, 0.033923050796147436, 0.014779564844502602, 0.027495317190187052, 0.02321995470992988, 0.047622903948649764, 0.0853649947384838, 0.07554477051598951, 0.01276430086363689, 0.03571671411918942, 0.03986654046457261, 0.03315523223136552, 0.03228560213756282, 0.07000006648013368, 0.042312054356443696, 0.03160413616569713, 0.014285353863670025, 0.04276111678336747, 0.030844269713270478, 0.014823109431745252, 0.025753275804163422, 0.02216349821537733, 0.07508665759814903, 0.03156191167363431, 0.04375693795736879, 0.020483645093918312, 0.03708107098645996, 0.009481487613811623, 0.06723590035107918, 0.035111132747260854, 0.03073883464821847, 0.01592414209881099, 0.0026257699664711254, 0.03737658305908553, 0.05963251576758921, 0.13206942414399236, 0.4417616530554369, 0.6378825777210295, 1.556189632974565, 3.060033512301743, 4.30768920108676, 5.28881935402751, 6.749429628252983, 9.340340550988913, 11.38688888400793, 11.412037834525108, 12.543855551630259, 11.198687832802534, 11.404042113572359, 10.463621076196432, 10.77146915718913, 10.203468035906553, 11.915838550776243, 14.376150481402874, 16.182651445269585, 16.02782115340233, 14.764234106987715, 7.599880043417215, 4.238230353221297, 1.2757625430822372, 0.4501730063930154, 0.22129776509245858, 0.10623888520058244, 0.048955571110127494, 0.004751041105919285, 0.04870398304774426, 0.03713178193720523, 0.03578915886464529, 0.013713476200791774, 0.05710435631044675, 0.06209663159097545, 0.046004584146430716, 0.027489752937981393, 0.06030831915268209, 0.07191063661593944, 0.04950701280904468, 0.08423893406870775, 0.04059076156408992, 0.028261341612960678, 0.02205917080573272, 0.07768920622766018, 0.04591220531438012, 0.0750134521513246, 0.03977207248681225, 0.07439835273544304, 0.018170884723076597, 0.03607710845244583, 0.0395781196129974, 0.013346319046831923, 0.07336884547839873, 0.04645433677069377, 0.0064701232258812524, 0.01965886669495376, 0.01165663154097274, 0.02702015157410642, 0.06041849097528029, 0.04824270487006288, 0.005564556022363831, 0.05320853371813428, 0.03988198084698524, 0.0724663790606428, 0.09225403991877101, 0.03315424888569396, 0.066075077484129, 0.013761354002781445, 0.04618720071448479, 0.029821926036674995, 0.04764674544276204, 0.017003857501549646, 0.0264752908697119, 0.011155139163747663, 0.05020588585466612, 0.03832956375845242, 0.08820080038276501, 0.009877297234197613, 0.07665408091270365, 0.0869403887190856, 0.10844267788343132, 0.035851068823831156, 0.07533544776379131, 0.01566790262586437, 0.06317952895187773, 0.025280125119024888, 0.036447829770622775, 0.07747973504592665, 0.02635950098920148, 0.04198636655928567, 0.018401243651169352, 0.01785415650374489, 0.03811976232100278, 0.05651693900290411, 0.08458645213977434, 0.09746881478349678, 0.07028468753560446, 0.01467672265789588, 0.040679570665815845, 0.006753888956154697, 0.046124207219691016, 0.04458251045434736, 0.061068193026585504, 0.1498034139513038, 0.007309378142963396, 0.02310934130946407, 0.04356549725343939, 0.009603203543520067, 0.012822438857256202, 0.05385730808484368, 0.026744003989733756, 0.024350230778509285, 0.07715782106970437, 0.011783592599385884, 0.062305004394147545, 0.053726604746771045, 0.08828334204736166, 0.08433322393102571, 0.0956014079565648, 0.024484607747581322, 0.07310631073778495, 0.0377787937031826, 0.0017584070178600086, 0.007748027774141519, 0.0191051391811925, 0.021816119297000114, 0.011565170188987395, 0.026443864626344293, 0.027522515047166962, 0.042755131362355314, 0.044155141004011966, 0.029132943964214064, 0.03627666454121936, 0.005930968245593249, 0.021786303514090832, 0.04581316199619323, 0.027778967887570616, 0.02711716697376687, 0.02113051770720631, 0.03078086803725455, 0.06447957130149007, 0.02646738514158642, 0.032453431413159706, 0.032176554668694735, 0.023758188035571948, 0.04939626211125869, 0.04623552937118802, 0.02239371428004233, 0.052531427863868885, 0.05975066938844975, 0.019066727472818457, 0.020942784030921757, 0.07487634778954089, 0.09772178324055858, 0.036025005974806845, 0.008793713386694435, 0.0836692021402996, 0.04347922258602921, 0.0493601640482666, 0.03551918409357313, 0.05133690778166056, 0.02975438503199257, 0.01694458958809264, 0.018988371521118097, 0.08871401034411974, 0.08317918429384008, 0.026765426082420163, 0.04425816223374568, 0.04746778024127707, 0.02760884537565289, 0.008991719314508373, 0.030828625240246765, 0.038588792231166735, 0.034662786492845044, 0.28081529249902815, 0.6842899031471461, 1.730088370386511, 4.20394716784358, 6.732061710208654, 9.386675264686346, 10.608170069754124, 13.358791172504425, 17.54889853298664, 20.139122642576694, 19.8185433447361, 22.495541498064995, 19.414273537695408, 20.291692055761814, 19.80451449751854, 20.07178645581007, 19.999628327786922, 21.671086438000202, 25.225128829479218, 24.549460485577583, 23.845291770994663, 21.62887830287218, 14.260100908577442, 8.75549778342247, 4.0570432506501675, 1.6450790944509208, 0.5913737264927477, 0.08976518831332214, 0.03723163048562128, 0.06064425229851622, 0.05313428926456254, 0.018820236109604593, 0.03167172355460934, 0.05232213850831613, 0.003534640886755369, 0.008929061641538283, 0.04457452865608502, 0.11240072213695385, 0.03630322971730493, 0.06021987370331772, 0.028254571370780468, 0.06538543675560504, 0.022665306933049578, 0.04727656960312743, 0.056218220852315426, 0.06445268329116516, 0.10873174440348521, 0.015798268286744133, 0.028078194409317803, 0.03135183564154431, 0.06721820012899116, 0.030692890140926465, 0.07420020672725514, 0.010357358241890324, 0.027642488785204478, 0.04720861485111527, 0.018012172731687315, 0.04678023236920126, 0.06654107201029547, 0.01912059997266624, 0.05792394709715154, 0.02100192021316616, 0.034077788586728275, 0.040381487051490694, 0.021782637304568198, 0.047659673655289225, 0.04886012349743396, 0.028706194207188673, 0.03836777694232296, 0.02541594370995881, 0.05663959374942351, 0.0510724879859481, 0.060083047646912746, 0.02625391563924495, 0.04907807371637318, 0.018847541577997617, 0.02590631407656474, 0.01595459983946057, 0.021265594150463585, 0.04274531645933166, 0.034500003821449354, 0.07054890695144422, 0.021088951871206518, 0.013214874488767236, 0.06163647776702419, 0.0100533151817217, 0.047970963787520304, 0.05268688553769607, 0.03120195891824551, 0.004535174930424546, 0.03179578467097599, 0.07557242293842137, 0.0338747221394442, 0.034006249261437915, 0.024249872003565542, 0.024896002469176892, 0.02419130727503216, 0.09117413341300562, 0.28138306515756994, 0.09922263590851799, 0.09333517838967964, 0.07767836345010437, 0.1450008130632341, 0.1014325290452689, 0.1486597495386377, 0.28760261891875416, 0.1394671670277603, 0.12959081417648122, 0.09464858681894839, 0.16356394509784877, 0.15712437423644587, 0.24868423148291185, 0.11431524049839936, 0.13540607556933537, 0.17912036972120404, 0.06350658601149917, 0.13118579343426973, 0.08262151226517744, 0.2572781383059919, 0.13715179986320436, 0.19204332784283906, 0.154206694860477, 0.1925498287891969, 0.08496329246554524, 0.1256460914737545, 0.10868570898310281, 0.15783165581524372, 0.09479359505348839, 0.08749173022806644, 0.11192277903319336, 0.11322459511575289, 0.1297720317961648, 0.15582793130306527, 0.11097418071585707, 0.19043533131480217, 0.17959080229047686, 0.10673996846890077, 0.09888449858408421, 0.14298184483777732, 0.16356056090444326, 0.13560598046751693, 0.1622587745077908, 0.16816840739920735, 0.128244973893743, 0.07176782513852231, 0.07600174794788472, 0.16218438162468374, 0.1665865196264349, 0.18317987298360094, 0.11560385377379134, 0.17326350352959707, 0.13070912682451308, 0.059722846272052266, 0.09622896803193726, 0.30301761988084763, 0.23064374952809885, 0.1458547281799838, 0.10619664957630448, 0.14208193140802905, 0.1112419698620215, 0.1410070640849881, 0.1811350038042292, 0.1386264176107943, 0.10785386533825658, 0.14232170447940007, 0.18969005177496, 0.12966038309969008, 0.1306782237952575, 0.07339747011428699, 0.19532854843419045, 0.1302655303152278, 0.15827874041860923, 0.13123505719704553, 0.09284177634981461, 0.13290548318764195, 0.0839121887111105, 0.258049318799749, 0.48497329058591276, 1.127604574430734, 2.3727221181616187, 4.43999002687633, 6.179335294291377, 8.307234887033701, 10.870218258351088, 13.293630369007587, 16.364255100488663, 16.242291145026684, 18.737944029271603, 16.785498596727848, 16.296609230339527, 17.37177863717079, 17.8745923563838, 16.520428620278835, 18.76551155000925, 22.825719080865383, 23.355874232947826, 21.459924168884754, 19.18216109275818, 12.83781347796321, 6.919336086139083, 2.694398369640112, 0.8608357328921556, 0.3134146932279691, 0.13746733136940747, 0.1791604605386965, 0.18099791428539902, 0.12145649714511819, 0.14963816734962165, 0.21248081320663914, 0.16357233136659488, 0.2558181853964925, 0.112909278832376, 0.16583019692916423, 0.19964851584518328, 0.09792009252123535, 0.15402909892145544, 0.09516843900200911, 0.14519261370878667, 0.15442227391758934, 0.16464503161842003, 0.15734073997009546, 0.17943124053999782, 0.16433349286671728, 0.11766378112952225, 0.17413805035175756, 0.14452767907641828, 0.09687980185844935, 0.10321081135771237, 0.1283645338844508, 0.07758718318655156, 0.1398708953638561, 0.16593414213275537, 0.20772302319528535, 0.22306354221655056, 0.10443161459988914, 0.12655645434278995, 0.14519855089019984, 0.09722101167426445, 0.1411685108905658, 0.10980501610902138, 0.07860873462050222, 0.1648878029664047, 0.2061741758370772, 0.11678284441586584, 0.0849847256904468, 0.0977195864834357, 0.25384579435922205, 0.18903963355114684, 0.19075742340646684, 0.18887383776018396, 0.15376545838080347, 0.15072581445565447, 0.17034675925970078, 0.10667410286259837, 0.18083027796819806, 0.11273526004515588, 0.24577633361332119, 0.25655332719907165, 0.2540570095879957, 0.10826474797795527, 0.19365095329703763, 0.08910489952540956, 0.12851125648012385, 0.20971009391359985, 0.06471544067608193, 0.14153410767903551, 0.1346801660838537, 0.1620309500140138, 0.11838595019071363, 0.15887055866187438, 0.13116839749272913, 0.10582895993138663, 0.22891929518664256, 0.19952941598603502], [0.05429954646388069, 0.04470911342650652, 0.02558862848673016, 0.026557819546724204, 0.031656932551413774, 0.04523906252870802, 0.06208791506651323, 0.039372897226712666, 0.07077490576193668, 0.05521138620679267, 0.003822712465080258, 0.08799855029792525, 0.02849293621693505, 0.014856857669656165, 0.041682802184368484, 0.037179787759669125, 0.07431400023051538, 0.06762644072296098, 0.0611229932110291, 0.01286281447391957, 0.022633919652434997, 0.049105169528047554, 0.023023621397442184, 0.06872831479995511, 0.03602644945203792, 0.031999815910239704, 0.045831975439796224, 0.030246699825511314, 0.03943373478250578, 0.026323712772864383, 0.025394412150490098, 0.0048899335797614185, 0.03614897061197553, 0.014706037491123425, 0.017494971871201415, 0.0698234056471847, 0.057431895766058005, 0.00944554169109324, 0.013929379947512643, 0.033698617917252705, 0.06041616805305239, 0.04371335533505771, 0.05920386982324999, 0.040268439406645484, 0.0333212914847536, 0.014117726823315024, 0.0033324833384540398, 0.030779463522776496, 0.04317244100093376, 0.04325158733990975, 0.02241172805952374, 0.10170097128138877, 0.012445058619050542, 0.01624865544727072, 0.02890984880650649, 0.01636435255932156, 0.09668625716585666, 0.047544444096274674, 0.08463650257908739, 0.03181057567417156, 0.04622358450433239, 0.04702174577687401, 0.01085238372979802, 0.03303838850115426, 0.027169078348379117, 0.04804726399015635, 0.013354683978832327, 0.032518933367100544, 0.0169122412262368, 0.045048746178508736, 0.07657759517314844, 0.08148001492372714, 0.023582467874803115, 0.08232623396907002, 0.03260478872107342, 0.05879801894479897, 0.044259475835133344, 0.0359362673771102, 0.09804014232940972, 0.03358996007591486, 0.07080076218699105, 0.05821314349304885, 0.07626476508448832, 0.07431236008414999, 0.12039370456477627, 0.06419778525014408, 0.037433687612065114, 0.09260606282623485, 0.19207472068956122, 0.007400889589916915, 0.10442627113661729, 0.11125294622615911, 0.0665882058092393, 0.03133158985292539, 0.012982778007426532, 0.07851568414480425, 0.12463188730180264, 0.16649951023282483, 0.040587024850538, 0.14039410947589204, 0.07572661153972149, 0.10782270997879095, 0.05602788965916261, 0.04715954033599701, 0.05468588256917428, 0.060579121418413706, 0.038702919700881466, 0.034505454896134324, 0.02811280075547984, 0.04236998640408274, 0.03471320800599642, 0.024278928940475453, 0.04065190711116884, 0.023672768693359103, 0.01611948278878117, 0.017817477710195817, 0.05600319098448381, 0.052270815285737626, 0.02634921853314154, 0.06688290523015894, 0.007195438065537019, 0.016148176073329523, 0.01221717104272102, 0.02914396671258146, 0.05167573159269523, 0.05066077414085157, 0.06708859145874158, 0.060802496736869216, 0.01169881057649036, 0.021847898060514126, 0.08604498754721135, 0.010584761566860834, 0.04779820665135048, 0.08408645240706392, 0.0642066984437406, 0.016163748186954763, 0.017701019896776415, 0.024250612295872997, 0.047860706617939286, 0.0324157414434012, 0.018307089230802376, 0.01419131633156212, 0.07899456235463731, 0.07767777715343982, 0.020126729577896185, 0.028616362797038164, 0.011310923382552573, 0.0498577555117663, 0.05398073837568518, 0.03678905814012978, 0.053917514815111645, 0.024717523374420125, 0.012545341323857429, 0.014654555634479038, 0.04856271523749456, 0.04037043276184704, 0.01791097347449977, 0.0406937234220095, 0.07677514004171826, 0.03069451358896913, 0.016297531437885482, 0.0484038436843548, 0.07484910354833119, 0.01094707527954597, 0.059688440305762924, 0.06219764531124383, 0.0058654843815020286, 0.053389665990835056, 0.007423258384733344, 0.056063182491925545, 0.0984463123313617, 0.0371832684322726, 0.0017641038130022935, 0.0485289104108233, 0.009332658246421488, 0.06167067964270245, 0.03198062026058324, 0.024634907495055813, 0.013720901388296625, 0.053257879117154516, 0.06107964065449778, 0.0076834321680507855, 0.04391816211864352, 0.028464571332733613, 0.011040615572710522, 0.08787300859694369, 0.0443379208445549, 0.043375533423386514, 0.022434378406614996, 0.012145862710895017, 0.05287660074827727, 0.022089897574915085, 0.05919628878473304, 0.033730611903592944, 0.024061190233624075, 0.024582623191236053, 0.06495200766948983, 0.037710898322984576, 0.016138333339767996, 0.07127089047571644, 0.053823299167561345, 0.05202352796914056, 0.007939684164739447, 0.047381327458424494, 0.04711292604042683, 0.01789553865819471, 0.07483549998141825, 0.03721422341186553, 0.052917288994649425, 0.06557754910318181, 0.05570625027758069, 0.06274008104810491, 0.02171120187995257, 0.04685530802817084, 0.018267120867676567, 0.007701809136051452, 0.024832639755913988, 0.05320493801264092, 0.0616739228280494, 0.05903148005018011, 0.04397434640850406, 0.05799254009616561, 0.060247448200243525, 0.03220281556423288, 0.020377339860715438, 0.08103858548565768, 0.012624209357454674, 0.011340689070493681, 0.040261852846015245, 0.045597516145789996, 0.01887692320451606, 0.06160307370009832, 0.02516873431886779, 0.07352257394813932, 0.02338980819331482, 0.03590478176192846, 0.04284229289623909, 0.07388154335785657, 0.025973226111091208, 0.024116398599289823, 0.0661689146363642, 0.019915119155484717, 0.06554792256793007, 0.014154894506646087, 0.010734005609265296, 0.05600794072961435, 0.033863122371258214, 0.027308854441798758, 0.052961068286094815, 0.06018698542902712, 0.029784870603180025, 0.0663821336638648, 0.01307916536461562, 0.05708186552510597, 0.10439014338771813, 0.013522929784812732, 0.03755866157007404, 0.013691040148842148, 0.06620452288188972, 0.07503606539103203, 0.18077673943480477, 0.22717973071848974, 0.26600315293762833, 0.3318740730173886, 0.703291199170053, 0.22621625976171345, 0.5475164798554033, 0.3743606322677806, 0.16386500472435728, 0.06738179174135439, 0.1843889057636261, 0.24585826671682298, 0.22480714396806434, 0.45115804416127503, 0.3269689518492669, 0.3801442187977955, 0.09357401635497808, 0.04462097225768957, 0.054381435038521886, 0.10811760977958329, 0.07995478270458989, 0.032651076471665874, 0.03717485989909619, 0.015557172337139491, 0.024566088141000364, 0.03930404447601177, 0.0903107707563322, 0.0128818858138402, 0.006865039022159181, 0.04309790339902975, 0.011187353011337109, 0.014685126552649308, 0.09815179102588445, 0.05858973519934807, 0.04388216053484939, 0.08252017199993134, 0.02948655321233673, 0.018963413094752468, 0.045862054685130715, 0.037056491055409424, 0.0676593698153738, 0.05073400927358307, 0.048889289901126176, 0.07860989237087779, 0.01949587993294699, 0.005843647613801295, 0.06853812461486086, 0.016176192148122936, 0.03338105663715396, 0.07906763421487994, 0.0010267345237480185, 0.04623335487849545, 0.012561589719553012, 0.010483145779289771, 0.03860165365040302, 0.02046205787337385, 0.014401186417671852, 0.06830851154518314, 0.05735530241508968, 0.011413308220653562, 0.08795900124823675, 0.025420875281270128, 0.020327948077465408, 0.0445449206745252, 0.01746941972669447, 0.030325072475534398, 0.03219475955120288, 0.017259388223465066, 0.031446158900507726, 0.034309565016883425, 0.049182493894477375, 0.0328985493251821, 0.028234520395926666, 0.05636377085465938, 0.08722326572751626, 0.006351740466925548, 0.03103201452177018, 0.04492997657507658, 0.04729323452920653, 0.02517455090128351, 0.07556371012469754, 0.07455807775841095, 0.04610456628142856, 0.05400819412898272, 0.05942114097706508, 0.05487682232342195, 0.010130934551852988, 0.03079140282352455, 0.0019953591163357487, 0.027702617589966394, 0.00830428925837623, 0.048927514217211865, 0.25590664939954877, 0.18384394672466442, 0.1055164192803204, 0.13700086186872795, 0.18256237643072382, 0.11212336670723744, 0.15603095322148874, 0.15011210285592824, 0.20306707068812102, 0.22292247478617355, 0.05366863188100979, 0.18883610697230324, 0.14812963345320895, 0.08888053343980573, 0.1393374099279754, 0.17454063578043133, 0.19024188310140744, 0.11153025712701492, 0.16867992526385933, 0.11830574629129842, 0.17489066231064498, 0.10208830557530746, 0.11838308550068177, 0.0991826193057932, 0.19625397690106183, 0.1256201311480254, 0.06582404603250325, 0.1738945665420033, 0.1771592444856651, 0.11208219235413708, 0.11909971814020537, 0.08984006359241903, 0.1382164700771682, 0.1444855993031524, 0.09022026584716514, 0.14494429109618068, 0.1579029465210624, 0.16863987897522748, 0.10326911447918974, 0.07788380476995371, 0.07768429321004078, 0.22512312076287344, 0.1747715030796826, 0.1262893553939648, 0.12525848258519545, 0.16880766372196376, 0.11042159239877947, 0.15287265472579747, 0.18588007340440527, 0.14336837019072846, 0.1378271245630458, 0.1791108405450359, 0.09004356048535556, 0.17915774427819997, 0.14155791577650234, 0.11718575638951734, 0.19379084813408554, 0.2012675703736022, 0.1251199681428261, 0.16913631639909, 0.20309893850935623, 0.22976350301178172, 0.0871251018543262, 0.11533849887200631, 0.13476871914463118, 0.18139655148843303, 0.1607953483471647, 0.12494722584960982, 0.12169364301371388, 0.1853264609235339, 0.11200773267773911, 0.12777930591255426, 0.18006659316597506, 0.13922359416028485, 0.18765233689919114, 0.19455484463833272, 0.12064863229170442, 0.13670079672010615, 0.229867284942884, 0.1513871570932679, 0.22617254726355895, 0.12304272648179904, 0.2266939208493568, 0.1545125784468837, 0.21014111844124272, 0.2045577485114336, 0.16743811924243346, 0.3071807121159509, 0.4766164405737072, 0.16053000086685643, 0.30199416854884475, 0.18762751948088408, 0.34081439953297377, 0.11023987754015252, 0.21880257554585114, 0.17472272913437337, 0.25697768724057823, 0.34255476552061737, 0.20721794717246667, 0.29338296968489885, 0.18955987907247618, 0.20730464486405253, 0.2307955187279731, 0.1446086770738475, 0.10726319000241347, 0.15521237917710096, 0.10474381386302412, 0.10779341740999371, 0.11667201950331219, 0.12061226705554873, 0.10915161445154808, 0.0974208052502945, 0.15989568724762648, 0.15461440110811964, 0.0514103098976193, 0.10429381261928938, 0.16065114905359223, 0.18163604254368693, 0.11374026900739409, 0.2127626066794619, 0.15642727492377162, 0.08012293110368773, 0.1282513266778551, 0.0990163633832708, 0.18243790342239663, 0.13182004768168554, 0.11967053360422142, 0.18442751228576526, 0.2186216993140988, 0.1463304299977608, 0.16432841657660902, 0.0888306982233189, 0.15173927647992969, 0.3623219282599166, 0.09445438903640024, 0.14247969287680462, 0.08297078180476092, 0.12616615887964144, 0.11233115321374498, 0.13574350043199956, 0.11714461914380081, 0.09501903725322336, 0.207572782819625, 0.18843162164557725, 0.15855383971938863, 0.12098775667254813, 0.09748601776664145, 0.19611518044257537, 0.19429369771387428, 0.1791435098857619, 0.09055464790435508, 0.16571299696806818, 0.08051111886743456, 0.1016489541507326, 0.16762604587711394, 0.17168917082017288, 0.08098113583400846, 0.17774677311535925, 0.1749170827679336, 0.13240840751677752, 0.10320585381123237, 0.19395389797864482, 0.186309450364206, 0.13179594272514805, 0.2260481336270459, 0.17084282560972497, 0.139827583625447, 0.13640229008160532, 0.15971498913131654, 0.15936043550027534, 0.14763028681045398, 0.16053623490734026, 0.13723422278417274, 0.1146052272815723, 0.08876802385202609, 0.1074963876453694], [0.024582318910688628, 0.03076345910812961, 0.042969923742930405, 0.025414286865270697, 0.05231711045780685, 0.016929800440266263, 0.07265579741215333, 0.06360409679473378, 0.036489234189502895, 0.0724761828314513, 0.0657859441707842, 0.022171491145854816, 0.03788984497077763, 0.019913623727916274, 0.0242672326930915, 0.0692546830396168, 0.0979835535690654, 0.06771767293685116, 0.0685554018127732, 0.02709913835133193, 0.018530420020397287, 0.09029930457472801, 0.027036104038415942, 0.02991053661389742, 0.05920322044403292, 0.030876516029820777, 0.021612692908092868, 0.016597835929132998, 0.04019851054181345, 0.025161624544125516, 0.02208771009463817, 0.01812924467230914, 0.039148096984717995, 0.02159864776331233, 0.0524627272534417, 0.025983755331253633, 0.028471089244703762, 0.036931279610143974, 0.02552271278545959, 0.026457640742592048, 0.03181887288519647, 0.07329612984904088, 0.03389513120055199, 0.02867553794203559, 0.1197243393107783, 0.019837893123622052, 0.0052266074817453045, 0.020475687415455468, 0.01662285372731276, 0.02953611754492158, 0.045056123126414604, 0.037640884111169726, 0.05599052252364345, 0.019618918740889058, 0.04771422522026114, 0.02414581918856129, 0.0032789566330393427, 0.034360917925368994, 0.06772268985514529, 0.04165286023635417, 0.03744554713193793, 0.04435010319866706, 0.02169465384213254, 0.019982849407824688, 0.06329756753984839, 0.07547471177531406, 0.03116564934316557, 0.012115440222260077, 0.01986764767934801, 0.02837904066836927, 0.028614594630198553, 0.027543358264665585, 0.05652871688653249, 0.13284648244734854, 0.05454537917103153, 0.013296049673954258, 0.09603076265193522, 0.035727415888686664, 0.04355521479737945, 0.014532482546201209, 0.04783390766533557, 0.040085666987579316, 0.05478978324390482, 0.0015045458962958946, 0.01943484014191199, 0.05230308015597984, 0.0731739574985113, 0.04379411955596879, 0.025045779002539348, 0.0730857384041883, 0.046985955705167726, 0.03431562094192486, 0.009754517250257777, 0.023195675348688383, 0.025649560666352045, 0.06489776409580372, 0.03344408352859318, 0.03128025549813174, 0.0338227346946951, 0.018547726904216688, 0.060932238993700594, 0.06051927091903053, 0.012626199240912683, 0.0317699764855206, 0.062312396185006946, 0.019871946569764987, 0.01846851006121142, 0.025305905473942403, 0.027808689046651125, 0.024594542082923, 0.014513659825752256, 0.02345614691876108, 0.0635634567879606, 0.02687405238248175, 0.018312035645067226, 0.0373412234330317, 0.023112445342121646, 0.025769987114472315, 0.08580394540331326, 0.08806266443571076, 0.05152510530024301, 0.04875758466369007, 0.04751704771479126, 0.04939726029988378, 0.030039640623726882, 0.009870732010313077, 0.031049993049236946, 0.03341277231811546, 0.01127912513766205, 0.01731142390781315, 0.03349207079736516, 0.0578553021478001, 0.0454616029310273, 0.034155090688727796, 0.01853015841334127, 0.022757693186576944, 0.02780818809696939, 0.03706642099132296, 0.060827087800134905, 0.01854059115430573, 0.05449076823424548, 0.046467699139611796, 0.037837185882381164, 0.05499854567460716, 0.027964922264800407, 0.034014936099993065, 0.03925278433598578, 0.05266942651360296, 0.03897666829288937, 0.009442129667149857, 0.036375544586917385, 0.038983477497822605, 0.03637918853200972, 0.03487135225441307, 0.0194316952911322, 0.031948611431289464, 0.019634611453511752, 0.015514207552769221, 0.026630930369719863, 0.03737792263564188, 0.06082018211600371, 0.06873546168208122, 0.020047995130880736, 0.06342034845147282, 0.03561044228263199, 0.03788465364777949, 0.04250045967637561, 0.06615188234718516, 0.046057499275775626, 0.07191420634626411, 0.04637898280634545, 0.02832468020642409, 0.09181657354929484, 0.05198706625378691, 0.044278723435127176, 0.02233216982858721, 0.07094064218108542, 0.02143975765648065, 0.047631282795919105, 0.0076894212998013245, 0.037093535356689245, 0.019264765869593248, 0.043160158456885256, 0.022361827905115206, 0.024637011483719107, 0.008400665483350167, 0.06414465489797294, 0.018190193550253753, 0.042712580325314775, 0.04238272536895238, 0.03342901050928049, 0.05583068988926243, 0.020921159702993464, 0.03450021904427558, 0.0645404496754054, 0.026259715523337945, 0.032897450946620665, 0.06958454541745596, 0.039082569055608474, 0.01981137989787385, 0.05523599211301189, 0.08413832110818475, 0.059278778498992324, 0.021952084462100174, 0.04516165281529538, 0.007700651385675883, 0.02835206174495397, 0.0522086084674811, 0.04666382650611922, 0.04783066447998863, 0.06731553279678337, 0.05694925486750435, 0.019683630307554267, 0.0347772405075375, 0.037009268198744394, 0.015161063074629055, 0.04881819215370342, 0.06510681967483833, 0.026460724366188515, 0.039924453958519734, 0.03351323313836474, 0.07598111624247395, 0.04734392692625988, 0.04575557504722383, 0.10078668987262063, 0.06133299131761305, 0.08046634509810247, 0.04994540686311666, 0.05832506678416394, 0.019768246274907142, 0.024949811886472162, 0.05454048099636566, 0.06817350003984757, 0.10072617515106685, 0.05192146039917134, 0.019121232653560583, 0.05225659944699146, 0.016041110138758086, 0.021716821793233976, 0.04109690256882459, 0.06328201954602264, 0.03725188740645535, 0.029101658728905022, 0.0859651250357274, 0.03647132616606541, 0.059579856679192744, 0.024728529424464796, 0.07851855625631288, 0.07575638650450855, 0.047051528163137846, 0.022783868735132273, 0.0256043768604286, 0.02477636640833225, 0.03270437380706426, 0.007637219096068293, 0.031021958420751616, 0.08076051017269492, 0.05422263027867302, 0.04034679164760746, 0.008565917651139898, 0.04192584070551675, 0.06614462414290756, 0.03561554825864732, 0.013049598201178014, 0.022577006202482153, 0.030662582685181405, 0.03622230222390499, 0.0237054139142856, 0.013604014056909364, 0.008604331214883132, 0.026937895636365283, 0.00782991124651744, 0.041478258863207884, 0.0986596204165835, 0.04899703119008336, 0.034658908771234564, 0.05860376921191346, 0.05917596507060807, 0.05652820480463561, 0.05712007128749974, 0.021095686861372087, 0.007260978518388583, 0.026908970430667978, 0.01581807435286464, 0.017558386534801684, 0.05007164989365265, 0.01590223575476557, 0.096067283739103, 0.021104575935169123, 0.053079555873409845, 0.028904601822432596, 0.03466202579147648, 0.0592479979241034, 0.030696376379637513, 0.08069368719588965, 0.04659262856876012, 0.03444405330810696, 0.02026269845373463, 0.03757511127332691, 0.03993832098785788, 0.03886009544658009, 0.018735328849288635, 0.014953172667446779, 0.03789810878515709, 0.04144929283938836, 0.03594996000174433, 0.08714820491150022, 0.012657344395847758, 0.014496469830191927, 0.048982863590936176, 0.05209282971918583, 0.042833683983189985, 0.037665397248929366, 0.09543846201268025, 0.054306693346006796, 0.033135825069621205, 0.011293450443190522, 0.007782200427755015, 0.024413003484369256, 0.03556501542334445, 0.030361267017724458, 0.027043130321544595, 0.08195051428629085, 0.055503614275949076, 0.014942691686883336, 0.009685671921033645, 0.06747631909092888, 0.03594036403228529, 0.020185507673886605, 0.018682320951484144, 0.09592168920789845, 0.05416878375399392, 0.028774497768608853, 0.06873598118545488, 0.026627674196788576, 0.06759711846825667, 0.04943740677845199, 0.06925879453774542, 0.08810003899270669, 0.10696489858673885, 0.02878034589230083, 0.052876860499964096, 0.05120528418046888, 0.0797025860811118, 0.09208883042447269, 0.0575295215821825, 0.0307303519002744, 0.015032976734801196, 0.05827931337989867, 0.029101332183927298, 0.02085209358483553, 0.010390096231276402, 0.18311659747269005, 0.111697158718016, 0.1430526457261294, 0.16540629701921716, 0.13741034927079454, 0.099596262734849, 0.10444763756822795, 0.18191137933172286, 0.07377188361715525, 0.1350710997940041, 0.14857419475447387, 0.11430044207372703, 0.13590019749244675, 0.07042619283311069, 0.1159501398797147, 0.1737364148721099, 0.12301114067668095, 0.07919862327980809, 0.17688660911517218, 0.08763010366237722, 0.06722369944327511, 0.19651730573968962, 0.20144019392319024, 0.1328461113735102, 0.21889325114898384, 0.12219475596793927, 0.14324316987767816, 0.1476248394465074, 0.10113319862284698, 0.1283746270928532, 0.08969273243565112, 0.10041675894171931, 0.21177768765483052, 0.1304303019423969, 0.2080313113401644, 0.07115838830941357, 0.07893225163570605, 0.15536759194219485, 0.18051908060442656, 0.15715008223196492, 0.13676989066880196, 0.2211581077426672, 0.1430527347838506, 0.06586613322724588, 0.1403730473248288, 0.1554329157806933, 0.1699135231319815, 0.1592242662445642, 0.23171193752205, 0.11550974202691577, 0.16293742402922362, 0.10420597944175825, 0.09347214174340479, 0.13207375828642398, 0.09362871263874695, 0.21957360761007294, 0.12187920961878262, 0.24179928295779973, 0.1551812535035424, 0.13650460256030783, 0.11390687373932451, 0.12442081308108754, 0.09065636666491628, 0.05692932820238639, 0.14734729105839506, 0.12251835461938754, 0.14973742217989638, 0.2663968474371359, 0.12514080764958635, 0.15902682527666911, 0.09765947994310409, 0.1377899429644458, 0.12113028613384813, 0.17734283697791398, 0.19878210296155885, 0.12290876140468754, 0.19216555956518278, 0.23628096969332546, 0.12219412514241412, 0.19457013288047165, 0.11828365255496465, 0.213363197108265, 0.12632894155103713, 0.11631191460764967, 0.11900661571417004, 0.11651210894342512, 0.1774633617606014, 0.12002966628642753, 0.12036026339046657, 0.11478513129986823, 0.15092049463419244, 0.09168843433144502, 0.10827913079992868, 0.1037380330672022, 0.10502629011170939, 0.10525755074922927, 0.14627160737290978, 0.15272282995283604, 0.10260991664836183, 0.09084820441785268, 0.17167474346933886, 0.12745615997118875, 0.20715438964543864, 0.16144549939781427, 0.11016345859388821, 0.1102506386814639, 0.10209756015683524, 0.18007113510975614, 0.1271032093791291, 0.12956141028553247, 0.1950141746783629, 0.12835726083721966, 0.15600937156705186, 0.14930185570847243, 0.1517022878397256, 0.12649268901441246, 0.12460344820283353, 0.10060896034701727, 0.20670783938840032, 0.14874251384753734, 0.1215380294888746, 0.1868325160467066, 0.18632286839419976, 0.11118528462247923, 0.12259347480721772, 0.09955836125300266, 0.10903892674832605, 0.1253166818059981, 0.09279288366087712, 0.0865500709915068, 0.11072816618252546, 0.14332626073155552, 0.08325879447511397, 0.12677859398536384, 0.149622552562505, 0.1858120333054103, 0.1029422132705804, 0.1641457443474792, 0.13178485503885895, 0.0848269450943917, 0.15833840909181163, 0.12944324553245679, 0.10389698625658639, 0.15245565678924322, 0.18984464113600552, 0.10837744310265407, 0.1936501220916398, 0.17450332059524953, 0.11252443073317409, 0.16362172871595249, 0.1055673231894616, 0.17877614678582177, 0.06120852202002425, 0.22392145008780062, 0.14626415621023625, 0.10912368743447587, 0.12205594466649927, 0.20512749528279528, 0.10457810712978244, 0.1475375035079196, 0.15817580453585833, 0.1426688811625354, 0.15837618440855294, 0.2645212027709931, 0.10904969531111419, 0.11347769715939648, 0.13076180446660146, 0.12944021756993607, 0.23798792419256642, 0.16114642872707918, 0.13618242141092196, 0.11802900684415363, 0.14834709756541997, 0.1106124950456433, 0.2423883552546613, 0.07161359200836159], [0.11292821844108403, 0.02983827369462233, 0.028913871246913914, 0.027622022207651753, 0.02626670840982115, 0.02189360879128799, 0.03407094598514959, 0.01603264408913674, 0.047867348839645274, 0.02445943966449704, 0.06777594637242146, 0.08642942746519111, 0.025891331970342435, 0.01939027788466774, 0.055996782539295964, 0.04635150849935599, 0.023016784361971077, 0.014783769111090805, 0.07820512502803467, 0.04136171570280567, 0.0373171444516629, 0.04806028497114312, 0.03184815803251695, 0.02446716356644174, 0.057893968041753396, 0.02510062371584354, 0.013672957720700651, 0.0368174935283605, 0.017437741153116804, 0.022033032364561222, 0.01404222257406218, 0.04038481187308207, 0.007713315208093263, 0.05229003319982439, 0.008636421680421336, 0.06608540075831115, 0.02771341212792322, 0.0055862884255475365, 0.029413607517199125, 0.02416203511529602, 0.04364271029771771, 0.03793346098973416, 0.007745851889922051, 0.040841447917046025, 0.12428435438778251, 0.11383579083485529, 0.01031468011206016, 0.01955120333150262, 0.027931996883125976, 0.055601147323613986, 0.045532815711339936, 0.06708221641019918, 0.016390555938414764, 0.04069802045705728, 0.029806205493514426, 0.021269425487844273, 0.030297650118882302, 0.041736095809028484, 0.08992944785859436, 0.028308698056207504, 0.029208733940322418, 0.07466934795957059, 0.05323654237145092, 0.007807470556144835, 0.026185842143604532, 0.011941548527829582, 0.07244966589496471, 0.04928522939735558, 0.03229211077268701, 0.012621892001334345, 0.035931892416556366, 0.00944905854339595, 0.031075465412868652, 0.030330059707921464, 0.015947733118082397, 0.053015979792689905, 0.057256741492892615, 0.03655646534753032, 0.05920552110183053, 0.021911424046265893, 0.020156838509137742, 0.041851759524433874, 0.023272786347661167, 0.022630806342931464, 0.022778239545004908, 0.014585451481252676, 0.016607151737844106, 0.03681938229419757, 0.020092013764951844, 0.05306751081661787, 0.04385554711916484, 0.04514327352808323, 0.022107159929873887, 0.02889034331019502, 0.03636563691543415, 0.05499746584973764, 0.03642710158601403, 0.01617324767721584, 0.019271382116130553, 0.020675996784120798, 0.041327766157337464, 0.013811959197482793, 0.016698920153430663, 0.03012359422427835, 0.03606308928283397, 0.05665029922965914, 0.028939473486389033, 0.020940025096933823, 0.040665087653906085, 0.0815903945476748, 0.03719335792993661, 0.03279792523244396, 0.0588030358630931, 0.05275397197692655, 0.04155795439146459, 0.06959537335205823, 0.028684026256087236, 0.025810384067881387, 0.010838507423613919, 0.04480748139030766, 0.04025086163892411, 0.023368833244603593, 0.06836998363723978, 0.04484124910959508, 0.0712862603540998, 0.02875398666219553, 0.012933658035763074, 0.024416768028459046, 0.07738836924545467, 0.012696027915808372, 0.07968465579324402, 0.03703657552250661, 0.0317972207267303, 0.007584359163956833, 0.037247300933813676, 0.05013821311877109, 0.0835689008818008, 0.07094580010743812, 0.06054314952052664, 0.12076373939635232, 0.0653425554628484, 0.047310292793554254, 0.027016745116270613, 0.08853026942233555, 0.057424585611443035, 0.016003488817659672, 0.04351945441158023, 0.00946881544223288, 0.08421885897405446, 0.05391981547290925, 0.018912308805738576, 0.060952666608500294, 0.09760730696143582, 0.03218173485947773, 0.023053296172292903, 0.03646214579930529, 0.059924599117948674, 0.0753256439929828, 0.02115312723617535, 0.050958089632331394, 0.05888117288122885, 0.03996664134319872, 0.033295130779151805, 0.03281719138612971, 0.03183737462677527, 0.018955459127028007, 0.03123190086625982, 0.03117618412943557, 0.03152206205413677, 0.039374823099933565, 0.04248694887792226, 0.04236868022417184, 0.03226466244086623, 0.028986126744712237, 0.05877191018953454, 0.04320771528000478, 0.09557221928844228, 0.02592146316601429, 0.07252164679812267, 0.012818631639675004, 0.03323904667922761, 0.03583135738153942, 0.02874236091884086, 0.012876867040176876, 0.04892299824859947, 0.06683024985250086, 0.07406336211715825, 0.08388716349145398, 0.025064149012905546, 0.006839027209935011, 0.04654897173168138, 0.039814137417124584, 0.007153746064432198, 0.02579856722149998, 0.06378800098900683, 0.030184125644154847, 0.03042078169528395, 0.02410541110293707, 0.05048829902079888, 0.016782259626779705, 0.04104581312276423, 0.0378594428912038, 0.029400261846603826, 0.043484139314386994, 0.09061571923666634, 0.04949920912622474, 0.022258407771005295, 0.015795520484971348, 0.04704448889242485, 0.05029994936194271, 0.02024113720835885, 0.0917650610790588, 0.0279373477678746, 0.04531918850261718, 0.050935012550326064, 0.008851614820741815, 0.0061722770988126285, 0.011733595965779386, 0.018240865538246, 0.01277325116461725, 0.10902625828748569, 0.11009063906385563, 0.02781302133371355, 0.04139757627854124, 0.030467991564364638, 0.006786210415157257, 0.021138811207492836, 0.02368485085753491, 0.0286122605757555, 0.019256921368651092, 0.06764023724826984, 0.04062154584971722, 0.046357942919712514, 0.014137188718450489, 0.04423309248522855, 0.03800974263867829, 0.05919661161897238, 0.07998838715138845, 0.01755115059495438, 0.043690189195331186, 0.03157693274260964, 0.014693004450236913, 0.07008761022007093, 0.06140528763353359, 0.0339522060676245, 0.031116162936086766, 0.057228406294598244, 0.03425698756473139, 0.0472583387454506, 0.01738039354677312, 0.03021243857801892, 0.036667947060777806, 0.03954995139793027, 0.020717740735562984, 0.02150073993107071, 0.05470264768518973, 0.011919845346710645, 0.020298970921430737, 0.06031887620338239, 0.016906728924368508, 0.025698859681142494, 0.026381518655398395, 0.054517938260687515, 0.026689125879784115, 0.07038579773507081, 0.1156996724603232, 0.02286359951540362, 0.02687749594770139, 0.04924443725030869, 0.018936179985757917, 0.01660045385506237, 0.06784953773603775, 0.03402154121431522, 0.02873270001146011, 0.08199832343962044, 0.04207441867038142, 0.01796074375306489, 0.09044382299180143, 0.028318153017607983, 0.014456086792051792, 0.04359185833891388, 0.049062722391681746, 0.05483249384269584, 0.03401343696168624, 0.015052012822707184, 0.05945886063273065, 0.028627049723581877, 0.0051346006512176245, 0.05297876850818284, 0.04680293466662988, 0.05890735956199933, 0.002914814917858166, 0.04937083613185678, 0.005591842937064939, 0.03756016070838086, 0.10932909164694138, 0.061920475418446586, 0.06361265375744551, 0.05910113803111017, 0.008802590400591725, 0.024264668572868686, 0.034737012392724864, 0.04458330826309975, 0.032996453446685337, 0.049285281347692944, 0.03912219974154141, 0.07876073388615623, 0.06608459181734361, 0.01250353150680894, 0.06972844785195775, 0.022557051706826314, 0.021082383864268195, 0.055707756837364286, 0.031997222104109824, 0.059165615821257234, 0.1166776152967941, 0.03323524688312318, 0.02148462604964152, 0.06264338662731461, 0.041989906603703275, 0.0566486924799392, 0.01445629088266287, 0.040302923298440874, 0.04974521252734121, 0.023492868385801557, 0.01784708940249402, 0.04255475891113747, 0.038713302346877754, 0.04990820300008636, 0.06794128945330158, 0.04123006983718369, 0.0032827088853082387, 0.04045937916089315, 0.05616860456939321, 0.04963970510289073, 0.030145585915306583, 0.050473125811549835, 0.026360690280853305, 0.026007962333096657, 0.0730995052435901, 0.012242804823472397, 0.011613561000558548, 0.09160162531770766, 0.04083865373104345, 0.13790240802336484, 0.008543092899344629, 0.06530285798362456, 0.00790880711065256, 0.06745878956280649, 0.05952609179075807, 0.027621899753285106, 0.024032608271227218, 0.1559768506558612, 0.10035940576926805, 0.11092244560131803, 0.10877265900489874, 0.10118233622051775, 0.12674286699621007, 0.13393993314821273, 0.14225436199922115, 0.18092576268827543, 0.09414280575583689, 0.16274784982670099, 0.20107664546230808, 0.13954299967736006, 0.0862709195644129, 0.11073890505940653, 0.11984570272034034, 0.08829909784253687, 0.10882021582801826, 0.2782792551442981, 0.2649192017270252, 0.12246578087797388, 0.14088008261751384, 0.07877810014178976, 0.1244574306474533, 0.1725029802764766, 0.1443474559346214, 0.06839459325419739, 0.12571710016345605, 0.16519708558917046, 0.22823165083536878, 0.14855038665700704, 0.1531142386374995, 0.1142421537952032, 0.13027878507273272, 0.09877533608232625, 0.1429082831600681, 0.09048729800269939, 0.15878611709922552, 0.19446584628894925, 0.13496742176357657, 0.17779715009965003, 0.1210283966793213, 0.1194070563360583, 0.09691445273347199, 0.12698583130259067, 0.25162463542073965, 0.11904756000149064, 0.16758795885834843, 0.10310126293916255, 0.21719006675994024, 0.07648927959962748, 0.1937294428353198, 0.17584631103090942, 0.10936381673673168, 0.19136852264637128, 0.12608906457899138, 0.07391387873212807, 0.14966147078666836, 0.1231682013894897, 0.17326253873761743, 0.17799701046897098, 0.11119797534774989, 0.1011869969079271, 0.17401871300535277, 0.12795185524737462, 0.057631652234704234, 0.1410174838383682, 0.1772192693897523, 0.09918480121996254, 0.11119080620119348, 0.19419056887272745, 0.12002921357634477, 0.1802577852504328, 0.08846423312206753, 0.12502933706855401, 0.16294347995426506, 0.12739828729536384, 0.14073597238166258, 0.15379685122752562, 0.1182332013559062, 0.13804936810629442, 0.14940314402338117, 0.12985384615603834, 0.12388545001158491, 0.08616484439698979, 0.19266224931925535, 0.10494906222447753, 0.1463207820779644, 0.0689582915219944, 0.24681240145582706, 0.08111051443847828, 0.08047181472647935, 0.1633047722862102, 0.14557357295416296, 0.12657634390052408, 0.17267533665290102, 0.14574416301911697, 0.17529963020933792, 0.1743004471063614, 0.10594952924293466, 0.08002497503184713, 0.3046509681735188, 0.1065986264438834, 0.17206002201419324, 0.12971246702363715, 0.2030878359801136, 0.16005927143851295, 0.10628779273247346, 0.39849141554441303, 0.20811606460483745, 0.10873031947994605, 0.10730336245615035, 0.09349969026516192, 0.09506516173132695, 0.2048859855858609, 0.15666088816942647, 0.21942804276477545, 0.13433298940071836, 0.09491842429270037, 0.14535977505147457, 0.10505598344025202, 0.13674366316990927, 0.1810615460271947, 0.18060105823678896, 0.18719817220699042, 0.07438346525304951, 0.16538085619686171, 0.17223390721483156, 0.16386117524234578, 0.12600870482856408, 0.18318184709642082, 0.1674215990351513, 0.12385010151774622, 0.16872803127625957, 0.1586165660410188, 0.09420971779036336, 0.18389519944321364, 0.11471493897261098, 0.16795233852462843, 0.3071748639922589, 0.15404932986712083, 0.15102010569535196, 0.11969152896199375, 0.146997754345648, 0.08505733741912991, 0.11321466517983936, 0.17780302790924907, 0.1852302488987334, 0.15825122158275917, 0.10080918436869979, 0.19135142356390134, 0.13790853816317394, 0.19550684199202806, 0.15915874944766983, 0.17209383426234126, 0.07723892296780832, 0.24694107502000406, 0.20715038204798475, 0.12808363098884, 0.1406399384723045, 0.1652200031094253, 0.11587023283937015, 0.12838054943131283, 0.17885226145153865, 0.15434737637406215, 0.08982965126051567, 0.12856424582423642, 0.13438860594760627, 0.26736288622487336, 0.13794089580187574, 0.1341841887915507, 0.14130174124147743, 0.1879263823502697, 0.10041293688118458, 0.09922619821736589, 0.20343588839750737], [0.04220144466671627, 0.07356089845416136, 0.035877589471056126, 0.048556893088971265, 0.04039291241497267, 0.03528931127220858, 0.0774602907767985, 0.07387462654151022, 0.04273653685231693, 0.042563913302728906, 0.0048439301644975785, 0.03886747239448596, 0.03407227071875241, 0.046517089067492634, 0.03684032570163254, 0.08226808669860475, 0.059689690824598074, 0.025350512260047253, 0.051669586609932594, 0.019975409377366304, 0.07486382775823586, 0.021963294602755923, 0.050117562859668396, 0.03377485874807462, 0.055159821786219254, 0.007143399598135147, 0.02897434329497628, 0.03565862622053828, 0.03425916576816235, 0.07651661289855838, 0.02604902721941471, 0.023148825421230868, 0.02750143248704262, 0.041046473634196445, 0.08338757936144248, 0.019552066078176722, 0.02059695434581954, 0.03823067258053925, 0.06024948168487754, 0.08022114692721516, 0.043932155313086696, 0.06378254620358348, 0.031077151943463832, 0.062176041392376646, 0.0558641384850489, 0.013589038444479229, 0.052576836169464514, 0.016866296718944795, 0.01836612707847962, 0.012345495797490003, 0.011091774595115567, 0.04109857611183543, 0.02072159062663559, 0.014698016730108066, 0.015356360163423233, 0.055992136694840156, 0.07455662314896472, 0.04123214413993992, 0.029014471219852567, 0.04897264050669037, 0.03463379449385684, 0.050515461625764146, 0.10212974710157141, 0.1176471718645189, 0.03363464478752576, 0.03193317475961521, 0.05335011694114655, 0.071929591067601, 0.06027272575011011, 0.020800839010917116, 0.009557888006384019, 0.05394985018938314, 0.028994015774514992, 0.054476314908242784, 0.006069108367228182, 0.02202833642513724, 0.015538711413682904, 0.034706959122559056, 0.021826227348356042, 0.05378544592531398, 0.01049981998221483, 0.05620966760034207, 0.03751474498130847, 0.043550843547564, 0.030439517213380896, 0.016122232445923146, 0.12141892962972634, 0.019901055457012262, 0.050426741581759416, 0.013469297555275261, 0.032314746276824735, 0.025692551425890997, 0.006441038922275766, 0.02204534459451679, 0.07595453251269646, 0.0448678254178958, 0.03855336210108362, 0.014085724487813422, 0.04843742215598468, 0.058430307035450824, 0.02834479426383041, 0.021341792307794094, 0.06544957315782085, 0.0190242692042375, 0.02072677823889535, 0.07632166554685682, 0.040125876548700035, 0.022525152344314847, 0.035118112646159716, 0.011055800841859309, 0.007792427222739207, 0.0034123305431421613, 0.014193805309332674, 0.03353668871568516, 0.021263093112793285, 0.035817479219986126, 0.024423913055215962, 0.03780644983635284, 0.05626236379612237, 0.03431760247622151, 0.05493449090863578, 0.030303553903650027, 0.05905663514568005, 0.05282187477860134, 0.007011258812781307, 0.03201480729330797, 0.10266732177115045, 0.022106263786554337, 0.033038210385711864, 0.05386573888245039, 0.012739986250380753, 0.06290747987804934, 0.02943071031040745, 0.0661667698295787, 0.035853443696396425, 0.06700287340208888, 0.02965644009236712, 0.02828511260304367, 0.03722580091562122, 0.005328849920260836, 0.03898944065440446, 0.0227029263987788, 0.06414821720682085, 0.0562334756978089, 0.07295370291103609, 0.009971139024855802, 0.02326203633856494, 0.05739111846196465, 0.09640489413868636, 0.043988350735162385, 0.04563908383715898, 0.037521064368775114, 0.03862558791297488, 0.031372816156363115, 0.017750712249835487, 0.05123421309690457, 0.03020181287865853, 0.0280045622275793, 0.023833109698898625, 0.03446863694989588, 0.04085721855517477, 0.026993254286935553, 0.01807463930163067, 0.019624662963906303, 0.06046187692845706, 0.012452005121303955, 0.04928775641019456, 0.023423095371981617, 0.05928558028244879, 0.03457929487922229, 0.035458621132420376, 0.030574439660995267, 0.03344589065818582, 0.010219288160442375, 0.038307291906676255, 0.029355285842029843, 0.04385058957268484, 0.06578409622306935, 0.011953246630582726, 0.025396300916327164, 0.03492978525173385, 0.04515815729973838, 0.054137068073032424, 0.06757233815733343, 0.020384427371027414, 0.02080528633086942, 0.01580508120241575, 0.04493258151342161, 0.02102725899021607, 0.028849380469182506, 0.010982206695189234, 0.057381470542168245, 0.05174926729523577, 0.03578086165362038, 0.07621113749337383, 0.06383016239851713, 0.035325305434525944, 0.033813650807132944, 0.016443450658698566, 0.02740497740887804, 0.03968674405768979, 0.024268019369628746, 0.0438749876775546, 0.03838664233626332, 0.007567940538137918, 0.04190002138784621, 0.02734550911554834, 0.030140298113110475, 0.05510433511517476, 0.03805191889114212, 0.03057902242289856, 0.02452641292620683, 0.04565174116578419, 0.028849551163148135, 0.08585424817283638, 0.02260821907839272, 0.0035695264659807435, 0.07908253654022701, 0.04321086569689214, 0.0273869265220128, 0.024779926861810964, 0.054037861482356675, 0.02177676320570754, 0.08438688120804727, 0.05703970782633405, 0.023944860440678895, 0.005552463189815171, 0.023476752649003174, 0.03966235708503518, 0.024371331892325543, 0.038147125305840746, 0.04033233461086638, 0.0500622765684966, 0.039253752838703804, 0.020072962834092323, 0.07126061915187165, 0.07075762114254758, 0.02244700419396395, 0.023358482139883563, 0.08630432363133878, 0.0038995286922727246, 0.03627279795182403, 0.020530511719698552, 0.023587299256178085, 0.02472711006703321, 0.019698406467796303, 0.03279695301898755, 0.08290705358376727, 0.06577861175173894, 0.07485204987460747, 0.015734373082523234, 0.02494217889761785, 0.03426366689382121, 0.03857850606436841, 0.027433934155851603, 0.025456401890551206, 0.021545534109463915, 0.08634834041004069, 0.051627621869556606, 0.03874234258546494, 0.08649422437883914, 0.03563118902093265, 0.04336842735938262, 0.022858590018586256, 0.04129131186346058, 0.0574047851114301, 0.004331524041845114, 0.024437466527160723, 0.06149642707896419, 0.033504598250146955, 0.038631239367532544, 0.06274957311688922, 0.04242315386363771, 0.06982689374126494, 0.017546740382385906, 0.026316805233363993, 0.02959701818326721, 0.03607350903621409, 0.02096821928716963, 0.01689421074843267, 0.02692747217224678, 0.03779825652600266, 0.07166038441937417, 0.07111913611879572, 0.0052843952744296985, 0.04714811497251503, 0.03420350098167546, 0.06420749996323138, 0.048212814872385934, 0.06621266424190253, 0.04370744041807484, 0.05211509414948523, 0.04834793398913462, 0.06252913299249485, 0.03294445858045947, 0.06501359850517474, 0.05563962768064812, 0.010223884837614605, 0.0053891452444077, 0.0560686372773489, 0.025226219222531654, 0.03577987459721044, 0.06509568003821187, 0.03264315404521767, 0.035624721203930676, 0.05321488279150799, 0.0439333056419855, 0.05712019745260477, 0.03659973255707882, 0.02683909722691169, 0.01731384330923902, 0.035722206011996605, 0.04600911866873503, 0.052461955419857986, 0.004434188576851739, 0.010586923071969068, 0.05763030152593274, 0.07797037629643455, 0.03359109556186013, 0.083768308541039, 0.052104830247117206, 0.01804861403797986, 0.011245067053096136, 0.026061630742333364, 0.08726991713047028, 0.03416724706767127, 0.04008405281638261, 0.04437237876118161, 0.07101263050572015, 0.015221215999190463, 0.02910223203798523, 0.02518727687856881, 0.06011348312313203, 0.02823100076057017, 0.05725893825001549, 0.033777615826693363, 0.014453678522841074, 0.009702684728836175, 0.032565228539169766, 0.05007654064684175, 0.029306203905434813, 0.034937010059366, 0.0713741900108289, 0.07086276862537488, 0.03447525319643319, 0.03135172060865443, 0.03285766069893725, 0.026419505484227557, 0.044785628851968795, 0.038790040416643023, 0.11090470085036941, 0.05215331104409415, 0.18719170067925006, 0.1374370072153397, 0.11961688374867663, 0.20113085192861035, 0.14061035646591336, 0.10437727454700507, 0.19147871673339978, 0.1659773351275362, 0.20768354093888775, 0.06469713931437582, 0.10014741128543392, 0.11427986231865361, 0.11276863442617469, 0.11230006464757025, 0.14072954538278282, 0.15833284298423678, 0.14730587921803817, 0.10830947721842676, 0.13445118383970112, 0.12668493494857103, 0.16943880094913766, 0.08535220011253841, 0.15489334473386407, 0.08413927105721086, 0.18217822595033795, 0.06886771981953643, 0.1757423806702718, 0.15080892015248537, 0.17561976303113624, 0.14397319086128846, 0.10242103264317848, 0.17148390761576593, 0.14722973486641422, 0.1828603190369904, 0.22655165113974363, 0.11997448760666884, 0.11079892996349372, 0.13082191842840984, 0.10894465915043838, 0.16016787732951343, 0.09861100974376313, 0.2843029116047546, 0.10046717303339392, 0.12246109792613424, 0.11684354467433877, 0.14636255014920607, 0.14715385768795386, 0.19323117972817272, 0.14262987388065085, 0.06543947252794169, 0.09370667525217868, 0.11030609195586294, 0.19315092387842014, 0.0692371757759247, 0.10763976315502077, 0.21715558657888323, 0.11396629008231685, 0.2210577842197381, 0.05613202782114968, 0.2075856813462451, 0.11718296591425315, 0.11261139559792355, 0.11473960053990595, 0.14501774887321517, 0.06364708940964192, 0.11521798893227242, 0.13689963292563334, 0.2656685630790889, 0.14087891002418473, 0.06507155281724408, 0.08673676566104405, 0.21694885392207652, 0.2946503204293549, 0.29920437606051564, 0.14393298130016774, 0.0832032373000402, 0.08803592485492118, 0.14091546821873635, 0.10800350457429886, 0.15215164341498166, 0.09827259040321223, 0.1759968779515475, 0.12081989028956741, 0.16818748059449717, 0.2345326924114488, 0.20028483326314017, 0.12287537960219197, 0.15007704379968345, 0.12434525502612814, 0.14108956122072414, 0.15799237531609833, 0.1542691985378042, 0.14313799270894378, 0.23251252190675586, 0.12508844170952216, 0.11976355439401232, 0.08538803842384368, 0.11732709099305794, 0.08180469711078331, 0.24774289136985317, 0.19497945701004937, 0.24797049321932718, 0.09603347149095498, 0.08252618339611217, 0.1358327956404537, 0.21006071416195482, 0.19921070808777586, 0.10983190411934629, 0.0995049266202841, 0.1816060152486898, 0.1257241505663842, 0.10548060323344544, 0.12031155623844825, 0.12050775781972334, 0.10028271222836338, 0.17196994012920186, 0.18064782838337123, 0.13718835805775598, 0.16642250498989597, 0.13011632894631475, 0.1620200849720277, 0.14291601633885875, 0.14724781358381733, 0.13656452356372029, 0.12145183645770885, 0.128518306883052, 0.13059246120974422, 0.1598301259218715, 0.12574565800605342, 0.14481232239631936, 0.09123775031184778, 0.1608144660713151, 0.06777841030270793, 0.20346131437690929, 0.14595705550163984, 0.19291075004730374, 0.1758405816508457, 0.2093868440715596, 0.12395308935083449, 0.14551440894138068, 0.1238100478076376, 0.16033769556088373, 0.16893593652639538, 0.18911139923147857, 0.15713451197370887, 0.09832346462644637, 0.08900721062673256, 0.10527416743570939, 0.24608331557828933, 0.1623139309231192, 0.11530153249623254, 0.1296244334662333, 0.28917018324136734, 0.0864298727537971, 0.1814534593722783, 0.14707369089592248, 0.23059507948346436, 0.19241178932134062, 0.13535856327507645, 0.10195105278398842, 0.16950283345067874, 0.08127774999593385, 0.11354456466506235, 0.0914687363547273, 0.11844929991639219, 0.11840998835396022, 0.16408974188379943, 0.21515961008844897, 0.14532654167851433, 0.11354466856573708, 0.11003793915733695, 0.13784232374746352, 0.130305502389092, 0.09729874422191642, 0.13840347644872963, 0.15538642765022814], [0.04281806177459657, 0.030162156217556912, 0.07106474411557429, 0.01865423437266145, 0.0510141477570869, 0.036883552093058825, 0.031130208080867305, 0.011846523011627141, 0.04579259708407335, 0.06674036834738217, 0.08672463896800764, 0.015969474334269762, 0.022879416537762154, 0.023248395664268173, 0.019848682095471304, 0.038874203673913144, 0.008932223190640798, 0.01211514058013563, 0.04766402635141276, 0.054661143076373264, 0.013191351190471323, 0.058295492199249566, 0.047985480196075514, 0.064886060426943, 0.05222180385317188, 0.017694021444185637, 0.0564794939418789, 0.07547182482085191, 0.06988702254602686, 0.015999074894352816, 0.04328991184593178, 0.04210099497868214, 0.028576784061442595, 0.099083379318472, 0.006522593530462473, 0.03467834190814756, 0.08416478609433398, 0.05054348141129594, 0.06937058424227871, 0.03695865743793547, 0.0330833737825742, 0.04684082501626108, 0.008179344058589777, 0.012939379066665424, 0.025440172976232134, 0.026614514063112438, 0.04263981645635795, 0.021540671186812688, 0.05010716165998019, 0.11741358088329434, 0.01600716987013584, 0.03000789711222751, 0.016256531489489134, 0.03272916525020264, 0.023274192717508413, 0.10075626181787811, 0.03653647188912146, 0.02102957820170559, 0.05517525103641674, 0.010190744233113946, 0.021671706635970622, 0.0359763693268178, 0.054336542525561526, 0.0365578865603311, 0.03816977194219362, 0.039071807914297096, 0.04900922467641067, 0.028742910108121578, 0.005763224780821474, 0.018007217040576506, 0.01806213411327917, 0.05344652563508134, 0.04626968671800569, 0.031757493561599404, 0.026996653323294595, 0.005806429835502058, 0.061769693274982274, 0.04609594994690269, 0.022482117055915296, 0.008003031107364222, 0.0688120439008344, 0.05077453424746636, 0.06388726324075833, 0.007260207148647169, 0.037807351545779966, 0.02942980489024194, 0.07007088221143931, 0.01541380424896488, 0.03317527021863498, 0.04136492178076878, 0.031052265876496676, 0.03306660866655875, 0.014592510233342182, 0.03268527092586737, 0.04342235180956777, 0.1498467702185735, 0.0347171079920372, 0.05004095837648492, 0.0693186858552508, 0.050051645303028636, 0.016356498781533446, 0.03461813888861798, 0.03606772399507463, 0.02471591105859261, 0.053486853939830326, 0.025685779328341596, 0.07355589637882076, 0.02972430764202727, 0.054640715461573564, 0.021951878516119905, 0.04868423449806869, 0.024524900800315663, 0.02706285104068229, 0.002708168071876571, 0.0880052889988292, 0.04441825090907514, 0.06926223810296506, 0.024869173830666114, 0.07258487035869621, 0.05943423617281951, 0.03176041762344539, 0.11221359702176414, 0.10856094653718174, 0.029989966824359726, 0.037890045350650325, 0.04500695955357514, 0.04311806755140424, 0.034307383102714084, 0.046897569627617486, 0.03666664088086691, 0.027642587119771633, 0.0032449943319079466, 0.03318717055663001, 0.03274197471910156, 0.026222752858302556, 0.03951261023757979, 0.048087236064020544, 0.027249786908214446, 0.024661489369464107, 0.02103099013766041, 0.035691737139131874, 0.040588190022390336, 0.09962977812392637, 0.0335573723714333, 0.016339377434633207, 0.0760609787539579, 0.0388789719727356, 0.033492549482616596, 0.04088701207365375, 0.058210824281559326, 0.04420926212333143, 0.0050960047974513145, 0.011502309353090823, 0.03200180486601312, 0.11108044884167612, 0.013463015275192447, 0.0073818103646772215, 0.053185820288490504, 0.03467472764896229, 0.03182246116921306, 0.06235896595171653, 0.047389650644618087, 0.0457467509113485, 0.06186776437971275, 0.05086855322588235, 0.0421000079222722, 0.010674495570128784, 0.04947209847159684, 0.046414587341132574, 0.035589020189945586, 0.023236866400111467, 0.007045756619845633, 0.03789188958762679, 0.04931697476422414, 0.02508565830794396, 0.054479780737892725, 0.03908644306648057, 0.02858436324459035, 0.00909495669475291, 0.014099697273195488, 0.03621156334702391, 0.04646785127988551, 0.011711349161487306, 0.12386536007397808, 0.026023851714853663, 0.030812054937996436, 0.04182126467640046, 0.08573389408411458, 0.09683589640189894, 0.017350640846416354, 0.006549618374265265, 0.055384288061759435, 0.019604088774940465, 0.024144002782122698, 0.012309903322602622, 0.017124660589615814, 0.02992474132042844, 0.015612440074619371, 0.1201606034010183, 0.01740879553835839, 0.06638818958890624, 0.0207821851290646, 0.0434497222158825, 0.08297162043163553, 0.013979257837490877, 0.050713759774225764, 0.05373092775698751, 0.09766940987901762, 0.04040393701870926, 0.051692010601982474, 0.03301643948361743, 0.03375737745955121, 0.017755732878868002, 0.019802650385827292, 0.013044735278526787, 0.017320700753771234, 0.012812762179237325, 0.03007349368999712, 0.004349278997324291, 0.038702745296177454, 0.06507408354082145, 0.010599654615361942, 0.07145506926462986, 0.035047708806814626, 0.06500081130070612, 0.031115289057197515, 0.02284139445691835, 0.033967542549362406, 0.0266320510127116, 0.054851207096362486, 0.09641152893891558, 0.023341841333603952, 0.028753582191711757, 0.06117670243838802, 0.04059842052811291, 0.0076852671281812945, 0.06703240345814265, 0.08872960286680609, 0.05515538374311291, 0.03829508357739542, 0.023178808187367395, 0.015247891569742933, 0.022756203325116076, 0.0457287575409282, 0.018706342416408006, 0.024789290910121053, 0.020778715588676278, 0.018371342521277256, 0.025316891114925966, 0.03736773294804152, 0.03377172688487917, 0.02450539901474258, 0.026313940543332137, 0.040776357855065726, 0.05835520540131256, 0.011790161534008803, 0.04147110084886663, 0.025970595197577495, 0.025068761460715905, 0.049709470695233904, 0.02736363236181205, 0.03005263006343739, 0.06741593053448014, 0.04668841385864653, 0.043494354977156036, 0.041952450410462916, 0.07254098716657609, 0.03419503307668492, 0.05806469911476597, 0.07528404661570676, 0.029599708468595054, 0.03840748184302356, 0.053173931082710624, 0.09132816616329364, 0.02831522153428523, 0.055954461568035185, 0.03901338975992985, 0.03302736018667929, 0.019102046280750073, 0.050555084890220314, 0.10521616859477945, 0.00651651441330614, 0.03465230365691241, 0.021351538562157657, 0.026733070299087558, 0.06004896822560113, 0.06466049948357977, 0.033527378473081626, 0.011799595158663578, 0.05315321031957865, 0.02849073203833541, 0.04895610545645468, 0.032880307335290127, 0.0448969064746052, 0.05913124325161334, 0.048384332621935755, 0.02802052582410397, 0.002919458443102485, 0.029249448161863256, 0.09535404271446168, 0.028694596294371877, 0.03966218268033117, 0.032548485687584616, 0.05674836291291285, 0.04514106192800682, 0.04600598680553958, 0.018193557334598154, 0.022720778761140537, 0.03116102576314006, 0.01918383095471654, 0.011319864406686975, 0.027882148679054808, 0.04535875981673598, 0.029152933711884543, 0.08779281211900525, 0.004137465411986341, 0.018051547376671806, 0.032638408010825515, 0.028480742730607744, 0.038293955512926914, 0.04919163715385366, 0.02625451121275546, 0.07338855692069046, 0.008990285114123253, 0.025253164749301504, 0.010250906434521312, 0.007257596180352266, 0.02311520427610958, 0.01602341919351602, 0.02771370898699388, 0.028010757305310108, 0.07217398029752076, 0.045452611811924726, 0.058388182733324356, 0.044856066087959334, 0.03460108804574702, 0.02449115905619692, 0.0333405242417939, 0.06995832809479907, 0.023232697385537904, 0.03159936786687467, 0.03719503518368583, 0.023183272205642425, 0.035197719116695225, 0.0417212639877107, 0.026425329488120042, 0.0745512277353555, 0.011235963684157468, 0.02095519274007529, 0.04378628989798017, 0.061580575493280776, 0.008443038404948311, 0.1468491170089692, 0.11100831208750606, 0.11359850395820104, 0.04203682517982088, 0.1460487107397057, 0.17369448352837935, 0.11329374101478606, 0.1708195815444924, 0.10589171593892388, 0.12995186902116984, 0.13709630205994472, 0.21338696067687124, 0.2485733843059279, 0.12513665162259713, 0.08974610769655555, 0.12483480531955138, 0.1259969046805054, 0.11074911701143719, 0.07416802720399573, 0.1491097582038492, 0.18891502695623785, 0.13076331844786182, 0.259646539343521, 0.09473070545936935, 0.2003316776244901, 0.12186216248665005, 0.09797377948416397, 0.21186005120398477, 0.15896283730398864, 0.36313763761427253, 0.2170895948074758, 0.21907751157414168, 0.17638815304962918, 0.2876646624645218, 0.12018631881801412, 0.11180711531778798, 0.1287097216118127, 0.1098376112349797, 0.08992484654299915, 0.13877826102543622, 0.06442320518544875, 0.12331923586316407, 0.09209202165948227, 0.16397502069594339, 0.08127954599331133, 0.19783972384175286, 0.1157853459881153, 0.10378498132922687, 0.13160270231310278, 0.18060516973491758, 0.07189682524767704, 0.107503645849647, 0.06811138227931224, 0.1656468864530325, 0.24065928475465626, 0.14754770061699674, 0.10843879645108245, 0.17853497847681865, 0.22194506629602984, 0.10758727847132832, 0.1587575295707211, 0.14297154382802546, 0.12250020168721676, 0.0740281175239943, 0.15746674180263653, 0.13294894335558638, 0.15283581451512873, 0.19252239901106805, 0.13581599341705441, 0.09889062872389331, 0.09191577642923221, 0.13789452641503885, 0.14832386834314093, 0.07611095497850329, 0.1162872975692153, 0.10553992309723981, 0.07918337956652977, 0.09677847643615678, 0.1844752620672807, 0.07512868542107753, 0.18310838931938633, 0.08705841246410273, 0.13738909416133538, 0.12282546274946071, 0.11304426807328127, 0.08372525655431673, 0.20535267773084342, 0.1661527788382955, 0.2492723538307473, 0.15425530553329736, 0.09984006566810422, 0.09002493257867172, 0.15085052495123819, 0.14169604430207983, 0.20438641629880294, 0.22377039334969595, 0.11512830038554966, 0.15060987614560872, 0.28442248643841594, 0.21729022701038048, 0.1332130143418908, 0.10769145374069922, 0.1247993900324218, 0.15962876641424373, 0.15934467228362337, 0.052285090496297926, 0.16084606671938673, 0.11304906976874918, 0.12182471371488646, 0.16949756420217454, 0.13004497886868194, 0.12101668558898382, 0.07142700866097584, 0.2320489616249688, 0.15684543061070144, 0.18117337283911183, 0.1307673705741763, 0.08765796388615854, 0.24565111845731735, 0.17163205513497815, 0.15822113491594791, 0.14250351581722498, 0.16587355319643393, 0.15641713718650863, 0.13206345727667212, 0.1239801332121715, 0.14455907192314044, 0.10519743678742088, 0.1375065464526415, 0.17231701291166246, 0.10594008170301095, 0.07408817953546531, 0.142101509263739, 0.09969599253963679, 0.12875756045104936, 0.1443767559248954, 0.12703824177151546, 0.07881819838075899, 0.19529470650013536, 0.14060021872865036, 0.2603885979624465, 0.15759738947963342, 0.1415173351415433, 0.1318832192919217, 0.14743112405994907, 0.1413334606331773, 0.11916362447664142, 0.10805970741785131, 0.17080384801374748, 0.17179935006424785, 0.19360689941095188, 0.09985406257328577, 0.07979107234859839, 0.10992030132911168, 0.1837650267407298, 0.28211903816554695, 0.11058669799240306, 0.13437734014587477, 0.08991398150101304, 0.13009252084884793, 0.15393592970212922, 0.09969261576770805, 0.24695802567293867, 0.19784244010224938, 0.2974041039124131, 0.16864891833392903, 0.198434243502561, 0.11368061517714523, 0.2262871793936938, 0.15943123638862744, 0.16085097973700613, 0.11533926328411326, 0.17994734487729147, 0.12703797459835187, 0.15905242937151343, 0.11181003937963396], [0.014247408780647675, 0.028872891707578674, 0.025748988045961596, 0.02319291827006964, 0.02318416092748521, 0.0428306708636228, 0.01978927874006331, 0.02040359890088439, 0.027496471229824238, 0.025862850197881926, 0.0989494810346514, 0.037660380330635235, 0.06961191582377069, 0.05553445793339051, 0.04428433036082424, 0.04085826869413722, 0.08241725838161074, 0.060157741099828854, 0.02854802027286496, 0.03164074631058611, 0.015352429563790793, 0.002962372204819985, 0.026343593053752556, 0.020667647622758523, 0.03481491563434247, 0.015340825157181825, 0.05612717788608279, 0.029938372717879247, 0.018572950648376718, 0.011750282228604192, 0.020285148420953192, 0.030718674206582364, 0.024447969772154465, 0.009081073894776637, 0.025477506715105847, 0.052206422842573375, 0.06175550341140479, 0.06960019731195644, 0.026079698327521328, 0.08951788986450993, 0.07008065629634075, 0.014873621857987018, 0.029070278869767208, 0.07422140988637693, 0.06598003805265762, 0.02453894223435782, 0.04682976701587904, 0.02886089489038568, 0.03056838188058464, 0.009410516959178494, 0.008639355019113282, 0.06776563794119284, 0.01706827591988258, 0.04604156536515802, 0.0163619758313871, 0.08728322383831255, 0.03238861223508138, 0.03902009135344997, 0.0028882856895506848, 0.04292453028028831, 0.03173568926285952, 0.04842451620788779, 0.01325042429016321, 0.0424047411797801, 0.045091434512869455, 0.07455499784555286, 0.04018160812847782, 0.03477082835161127, 0.029056643761578016, 0.05472212164022494, 0.03907368554791901, 0.07615373979206197, 0.01799293255317025, 0.02835562776454026, 0.03994520811829716, 0.06834022351540625, 0.01320669138294761, 0.03312147564429324, 0.07174612474045716, 0.012760396239173133, 0.03168970579281449, 0.03848423104500398, 0.013171825285098748, 0.03155554775730707, 0.047484014721703716, 0.01310199197178008, 0.023812340696167666, 0.06610954282223247, 0.0631482177414, 0.045687980236834846, 0.01260263605217915, 0.03355176915647462, 0.03724504480487667, 0.027571897553571034, 0.056414099599351175, 0.006050367746865959, 0.05950475504505448, 0.047018591649248265, 0.0339621211605845, 0.030649622931377962, 0.04447377839824185, 0.06693737144814804, 0.019288529438199475, 0.05358688060368877, 0.11841706844279543, 0.06690590438665822, 0.05357657959393691, 0.007766543894831557, 0.02639228907355573, 0.00976918116066372, 0.037404873728519306, 0.05264646817522589, 0.07648004728253, 0.025324371963506564, 0.006206195103004575, 0.014300892580649815, 0.035769555033766665, 0.05554480347200297, 0.03310491090815049, 0.016383292168029584, 0.021077175842947327, 0.011382823577150702, 0.0595326152688358, 0.05670675811416004, 0.012785823146259645, 0.08662533960887231, 0.033559224029886536, 0.011351501234457828, 0.03740657324669883, 0.05828471992572304, 0.02276910556247458, 0.0287576231858111, 0.010775390546768904, 0.07083677119226195, 0.10019798864959739, 0.10269743812386878, 0.025645085515861865, 0.02056396217085421, 0.053367115833680145, 0.08054140591411851, 0.03916834277333692, 0.02561600074841408, 0.025103968946496025, 0.03859840675431769, 0.0064302972623409005, 0.07181498120189644, 0.04486340221774299, 0.02925873799540568, 0.03209791670087725, 0.0594929103681352, 0.018743611217360012, 0.014026778480911162, 0.11130065147881396, 0.030003681713424157, 0.03523653715092223, 0.06587963289348409, 0.05196967402298469, 0.05915671004913747, 0.04977692078682594, 0.04171227657934651, 0.016722082582418807, 0.03755588593776338, 0.029416485194815323, 0.052387889081728645, 0.02786021079373313, 0.019956076430389658, 0.03664943047624547, 0.0547694929264253, 0.09213462093612179, 0.02531479454773944, 0.049111700427602045, 0.03784655549679883, 0.011567885521799326, 0.038786886289017275, 0.012254047433089, 0.03522232873365283, 0.008651586540509015, 0.041822040220722556, 0.06299670087173581, 0.034735246081254445, 0.06013462691043969, 0.03551333225914277, 0.014618095774494577, 0.025238255002477672, 0.040651157542015426, 0.03442531407927163, 0.09948663268005475, 0.01182986921776319, 0.03214463860786054, 0.03488427675620187, 0.020768336653418373, 0.03769690141780302, 0.016904938493098598, 0.05641143528919201, 0.013958997205918422, 0.023512269981438294, 0.02536272986617405, 0.014597669087379472, 0.027018489163310733, 0.041567379666958004, 0.009436721265956294, 0.02189462182286661, 0.02088186112814583, 0.07834132396965288, 0.014098856790951686, 0.08351254960871302, 0.016820268720039167, 0.02533371931349393, 0.01806479471269995, 0.031032806764415, 0.02406341296591563, 0.0538793906889623, 0.047840817060205154, 0.016145971894729882, 0.0512263055134099, 0.02569004296674393, 0.08008229851839133, 0.04304712565499358, 0.014303682128229411, 0.1153563846310135, 0.050402688575559296, 0.0221292889182223, 0.015480034435313428, 0.036439614195842296, 0.031915953222778626, 0.01730352931190282, 0.025500400115561206, 0.023663508545723744, 0.01102411206375109, 0.04470526168006472, 0.09003988685435615, 0.08408423338551074, 0.06853641025372781, 0.04724558493762743, 0.036861807166133076, 0.09360219570226036, 0.036870976400678046, 0.01982205198146403, 0.043298439122736454, 0.049748192250262946, 0.06348301540128887, 0.008929508785513462, 0.03933001593395602, 0.06856287523987703, 0.009835159016802208, 0.05898826850170735, 0.0451541237271158, 0.016402033252234105, 0.011696622168528847, 0.013891190883441595, 0.06359219274600036, 0.06833840525359847, 0.04161010139796417, 0.04665917695092503, 0.024628554710943718, 0.019909616130462382, 0.05455733145936392, 0.08066905531450175, 0.037195461918599904, 0.07547307905042544, 0.02802599916321924, 0.0634915723640006, 0.04880618420429528, 0.007809565267962171, 0.07461863700882532, 0.037694533966714516, 0.02058271438727388, 0.038631770003121346, 0.00974891960140667, 0.04679904210206587, 0.0061309506054385565, 0.02634216256410582, 0.06376214456395246, 0.023958898163982667, 0.07718805616605096, 0.019357185519766062, 0.030640947225037962, 0.03576437484298367, 0.05087418241600972, 0.040637579950271174, 0.057676730284583755, 0.030448706856986973, 0.0639429540024139, 0.05523341314983554, 0.0077744807003909955, 0.054833462345413864, 0.016543460624234285, 0.004636718358597136, 0.09088586099096574, 0.041319023657706566, 0.017277624647249468, 0.03399918401555624, 0.016671714874973986, 0.033421960106352344, 0.07687227232963778, 0.0322882850014139, 0.05529926762392279, 0.07954982982482761, 0.013146135843271622, 0.015188347206276376, 0.009773435522220097, 0.03516252647386864, 0.03954968422476668, 0.08208721046685241, 0.02511352409783285, 0.058621885036700405, 0.05853627088072244, 0.0999457920261193, 0.005772956192231504, 0.04333908284024801, 0.030665382437291555, 0.017688074985926505, 0.013551003376051085, 0.007540468550359947, 0.036117752169957384, 0.060223476830287836, 0.03662897688627709, 0.05737818653869908, 0.028491453776950948, 0.008012723556021228, 0.03385668795090169, 0.027430939589976333, 0.018746286659734324, 0.015685187245253474, 0.029744833591394126, 0.012769474560627714, 0.0030413207150559174, 0.025828676152741536, 0.016794755538285244, 0.03684797353344038, 0.039017642266117036, 0.02645328433573013, 0.02190731440350646, 0.03712225276103709, 0.08163319420418702, 0.06657690290012397, 0.02900515541114146, 0.10367990806116723, 0.056238199467770755, 0.016218143900914583, 0.033393272387911566, 0.03764090266486164, 0.02434671299852198, 0.006645646717515774, 0.07524035638198256, 0.059366708155721426, 0.030240597516240086, 0.05250608723144978, 0.01442063625290757, 0.05942927491560113, 0.03195763594703749, 0.09758600732311606, 0.15385237871669233, 0.1537478546379134, 0.11676328140310943, 0.1017435260291677, 0.10764771897811443, 0.16999389772536233, 0.10404808010207489, 0.08777242532232776, 0.1089229884382803, 0.11194951119250618, 0.19873876153724268, 0.09848766479990445, 0.08736397692700848, 0.10885030991630629, 0.11274891556240618, 0.14067170239286497, 0.19934285490307957, 0.10650386902852915, 0.1726035264437087, 0.051982416698592715, 0.12620871362742037, 0.09954608613043092, 0.16600458679022267, 0.08618362073320895, 0.08840172944474034, 0.07394329746603034, 0.1433888979954645, 0.20012438093544915, 0.08638613799121231, 0.11674089822918177, 0.11560133047169074, 0.13495435996446759, 0.07785871275700629, 0.14449728070758283, 0.16343029914423823, 0.14837819355307147, 0.14883697440382093, 0.11845221655676141, 0.18093015620252118, 0.21316749276593328, 0.22392907936591655, 0.08199794494430535, 0.10884774208534509, 0.20703815447632223, 0.13910162961110473, 0.0776746156043373, 0.11564815999008715, 0.09289626483223401, 0.1023382980201859, 0.10965341018163599, 0.15094357542693615, 0.2191217287327163, 0.15317971090553328, 0.20977860898710787, 0.12963926157681271, 0.18627793877385557, 0.12576627486851066, 0.13159692840417847, 0.13348602078622207, 0.1533317324356176, 0.10844857053598389, 0.11443612893344834, 0.07917745722807012, 0.1454444244154729, 0.11527868176926859, 0.160273143555969, 0.16595723776845261, 0.15075175993843004, 0.09405108372448012, 0.22782525076763704, 0.09777669474715367, 0.30120541399810463, 0.09230576019035652, 0.08310338133014739, 0.15711534972069785, 0.19513181992806494, 0.08801933785434812, 0.15764877578476444, 0.15301919920602813, 0.11263261359999888, 0.20353238243842497, 0.18409695971058682, 0.13512201112462208, 0.17914843774633482, 0.15601370570948347, 0.16534352616872638, 0.14633650076575577, 0.13306701905094087, 0.14495707087917253, 0.28436596447136253, 0.050636687738006, 0.14182891842210665, 0.09777701387065463, 0.14900720823789015, 0.11506962619023398, 0.09607838626834564, 0.1821211993228644, 0.10054427475552075, 0.12496341951191425, 0.1436482192366384, 0.1456621111719869, 0.16876911657163873, 0.11107429643743671, 0.12083528243238106, 0.15823495370568708, 0.20797683770069852, 0.15881087514571846, 0.14552413107594475, 0.11890933499671519, 0.12049347889842466, 0.08660537583637051, 0.20938261382980272, 0.13622108730487525, 0.15268539602402598, 0.07545943837612867, 0.10678611521143466, 0.08316950668813661, 0.24470936274155974, 0.19659045181469992, 0.09108009588089772, 0.08361424610484391, 0.134192218829412, 0.11896641357452609, 0.08448931243037805, 0.11720617287210189, 0.15201925911242142, 0.16993028082652017, 0.09099505317863077, 0.1691698021022603, 0.19528360397089273, 0.13277798221679404, 0.19148572260746732, 0.20377105713123456, 0.22872872650623322, 0.15185456170001999, 0.19491065992042422, 0.08152049165801145, 0.15191805985523388, 0.09589790337486193, 0.15782476868480444, 0.10061669352580793, 0.17876473255455494, 0.07675674220081419, 0.08505898498697206, 0.1213233039015904, 0.20343746175058186, 0.08493752509821206, 0.12033572056679986, 0.09607509113266133, 0.17318247584626079, 0.0976155670650769, 0.1230317352747079, 0.2624780702171847, 0.14185599196935073, 0.11439888054155745, 0.2697864139918238, 0.12150392780313268, 0.14736621582414955, 0.1892165615572594, 0.157596068456769, 0.06745049977325834, 0.24712990707485005, 0.1708504994167015, 0.1206515340891201, 0.16025472345063463, 0.13341495272470638, 0.1943619456142187, 0.13003550906432793, 0.1012191541667562, 0.1567056990461424, 0.11786096976720728, 0.15354602015577257, 0.11011980546754785, 0.2467319229617715, 0.14205546642187983, 0.2430611863383092], [0.018358399465796538, 0.0411676552175777, 0.06337737067951821, 0.062375649431487545, 0.007093026324582752, 0.0920585730636958, 0.01097750890039606, 0.057874479243764654, 0.023731789842713624, 0.051722754069487564, 0.010658566297934158, 0.028301013117015827, 0.021725592123402748, 0.0827782835403923, 0.03425561459152959, 0.020462725806282833, 0.08591022837208584, 0.04771532359882258, 0.06807499477872625, 0.06061117848730646, 0.034940501864184625, 0.022561769910680596, 0.06026507791830227, 0.008909380812838208, 0.058248992936569266, 0.018396805608063005, 0.01742697444569785, 0.049073888003476895, 0.057382732193218544, 0.0705595790350344, 0.029114735370967537, 0.03939711350540165, 0.03178725739417132, 0.01640851034608204, 0.06784486220567487, 0.01185186833026819, 0.0658520769502502, 0.06044544206815772, 0.04093771560292225, 0.0029674204324692255, 0.011367562237865059, 0.08424261512118392, 0.0663647822511848, 0.057544505543773994, 0.06773432673071511, 0.023358554499282036, 0.03769887924136128, 0.08100032035144977, 0.06057343656721059, 0.058825270607485436, 0.067350628960412, 0.058503133986960165, 0.033293089873041026, 0.02921267288911622, 0.06155397692054976, 0.06096005097788293, 0.025370067851326894, 0.05073900021670852, 0.03108777764282422, 0.012681498519668821, 0.05952471881755628, 0.035836596944136545, 0.03784163134696428, 0.04021636661491357, 0.023108877467166167, 0.037777661927975714, 0.09653168264776468, 0.10210769789409824, 0.035100690729450434, 0.05024164252972696, 0.06618483370402828, 0.06014535465510562, 0.046206429760786705, 0.020454888726817444, 0.03997989610070363, 0.053685211460106075, 0.041491858719382435, 0.015720073752163444, 0.055377794269588776, 0.04032066062791273, 0.024060676296357997, 0.06466909355367534, 0.017289083407376893, 0.06352841999614611, 0.06915850812220015, 0.018465153698343784, 0.057183536046068184, 0.03328807666548528, 0.09441629459615797, 0.021480716786754783, 0.04892210396064911, 0.049244956753682345, 0.06014669794240035, 0.030134446278680116, 0.03640518225438427, 0.02914293327194173, 0.02474468226864701, 0.05359391987440176, 0.011368016803317005, 0.03296417373348959, 0.05506461166078225, 0.04569433302094694, 0.06734262118698098, 0.02178660965000745, 0.044877814725623466, 0.018326676363358274, 0.10186137165874243, 0.0263524580077501, 0.02871798693377059, 0.03277756070019677, 0.03489941285806708, 0.006450971177400788, 0.015467813118448248, 0.022995659128355328, 0.05723931586544495, 0.05025663391279522, 0.020818869488721248, 0.031207384017761797, 0.009983333438867703, 0.03545689192833379, 0.03365402597410139, 0.05136775886057876, 0.035872045627911575, 0.07083050746587105, 0.0400396798067959, 0.036481968563748524, 0.01603208191227168, 0.0432652094605146, 0.05237411482085008, 0.04332004304160364, 0.02609604041936109, 0.019391658279346302, 0.06636815160163678, 0.06120672231190838, 0.05175876307475846, 0.03998279418738093, 0.054746018795412965, 0.06502992575406097, 0.024679989255673718, 0.05008419590012636, 0.013065803923382191, 0.03682481481519062, 0.057984372760984115, 0.04857233718212228, 0.026846932451007888, 0.055798413886805065, 0.0695594162971247, 0.026116271365026478, 0.03918871472706087, 0.016365411975129973, 0.012433598003553925, 0.04174950270680711, 0.05288966254738625, 0.09336680872365832, 0.02030618274147855, 0.03160018794005737, 0.02919893573562149, 0.028884003513667267, 0.017136034002760425, 0.033472270297352225, 0.0539128541277023, 0.03735581034561619, 0.06277427921304479, 0.05814986056066118, 0.0056719526764936745, 0.039653570056543685, 0.03837749536614865, 0.07353168010013178, 0.08806228594039567, 0.0361141861503711, 0.04875925078522414, 0.011513834906509146, 0.04476635527680628, 0.06878620974021032, 0.03745545480342116, 0.03376352986379061, 0.011941041084355675, 0.024431790952803567, 0.034277812228538096, 0.053743555399705656, 0.07359890383668244, 0.05166735645616427, 0.02952344722871203, 0.05634982589981519, 0.02890267965995008, 0.03156825332553126, 0.028448336852306966, 0.01499434238212416, 0.02486843539372785, 0.04140362849284429, 0.04747806640807539, 0.052204322564648464, 0.06957342062378302, 0.005425732197181787, 0.0743046343268361, 0.024554807496315334, 0.10598406137432903, 0.04089465619472321, 0.04118383032619022, 0.0458414304011967, 0.0715068711724598, 0.04926823792629875, 0.03790612026932649, 0.06720249628415331, 0.011357892053638352, 0.03373583662323654, 0.02618755093863001, 0.010313321981811896, 0.0656634898041375, 0.07322874284000136, 0.02970351266412763, 0.012583331863424974, 0.033786213607527316, 0.0603611452243058, 0.030530608419212513, 0.043945398938376456, 0.0692034674284514, 0.02179398845328251, 0.04367178393295035, 0.01688802680291701, 0.051627080101752654, 0.01992525689274771, 0.014717379362991778, 0.035706888083950616, 0.05129762219439726, 0.03758469239983242, 0.028687146987067536, 0.04132976995606441, 0.02088123215798987, 0.05019925476517528, 0.011662721790344222, 0.053308920323615894, 0.054510283007402904, 0.008337570870935451, 0.02721430668316316, 0.041204951849067584, 0.052891525338054635, 0.020125753653701395, 0.03891283617122099, 0.06638194812694564, 0.03453935249126516, 0.03523236628097948, 0.026804526132764295, 0.07898333366028965, 0.023091687471605837, 0.07496919046388939, 0.030520570871885866, 0.06264420298975892, 0.028528781949717086, 0.03739352629054338, 0.013823498666170053, 0.022202472100616433, 0.09506279428023845, 0.037421798406285234, 0.016683477915648837, 0.04252811209880747, 0.05274918512441218, 0.040946176086436026, 0.035922778843087144, 0.10797455339343287, 0.026508116061449982, 0.038573826823267154, 0.013075390615995275, 0.04299605847336352, 0.03122989335679449, 0.01809168457839405, 0.05828537672641687, 0.03279691591160372, 0.026810196141013876, 0.05252363160252571, 0.04467405437026173, 0.04903051318251528, 0.04023390356451273, 0.08028340569580905, 0.08523047305061482, 0.008963148484326666, 0.016619495509075932, 0.06761690412531607, 0.047889223642414436, 0.027101669074909296, 0.01752928877976956, 0.023168893094407395, 0.015436912872246467, 0.04736890390631743, 0.02720507993217325, 0.04663160245399922, 0.03902253673004452, 0.027887033866136335, 0.03175229852786288, 0.03996100844233297, 0.08433118302491494, 0.05255457173916511, 0.012449721161829075, 0.028153822968306486, 0.0401296466588974, 0.05345886012946721, 0.05312619614414871, 0.03701954323332757, 0.040401064907200634, 0.04278313630493358, 0.07847482149372809, 0.022007064617355354, 0.023973013812792487, 0.05455209931824356, 0.024318852774740662, 0.015533326204604236, 0.018110768905899022, 0.014394043246284127, 0.030135114211589098, 0.02944000571005745, 0.017499530513305217, 0.03449016294325702, 0.0494871121190954, 0.011867843986692606, 0.05126069292600732, 0.03539701545378193, 0.03516222961479798, 0.0040370505121245515, 0.012586745742737548, 0.03396060717932414, 0.04766282036143821, 0.037896001085755415, 0.07498568098526448, 0.03454052879533265, 0.017999092378886417, 0.03864604892442003, 0.024045605132414494, 0.02087633027258562, 0.028969745690119453, 0.018532392277847975, 0.024265230749733746, 0.044736743584508076, 0.07210331299575046, 0.025310877863375936, 0.08201751537853852, 0.05696586784324609, 0.05339270137483254, 0.02652529121405678, 0.03128106443909928, 0.050075479375664145, 0.00809283190392307, 0.021549163211602718, 0.06818230933276936, 0.022262663987930864, 0.033701809152262285, 0.0610722006240394, 0.017367025611747522, 0.01703613164863782, 0.04147204708715435, 0.13161793118342757, 0.02745759567915229, 0.041826352098723873, 0.06592607649508864, 0.12216011993587017, 0.1294634467922151, 0.20584384590620175, 0.1410881956689991, 0.175135838217102, 0.07641359537956305, 0.15319971920689568, 0.09192249286570586, 0.14353217702591792, 0.18623979238327593, 0.10000727896112949, 0.14110620017163455, 0.21911534626269713, 0.1245514236507006, 0.10863703151699156, 0.17676614370429888, 0.10004983370890841, 0.2013089376850985, 0.12861920928116888, 0.15532007964793593, 0.12624933879124, 0.1327846318599768, 0.17844560905359685, 0.284906099550426, 0.11607597101829015, 0.07213096541818231, 0.19558641506591812, 0.09285629275836982, 0.14644437935203314, 0.15807610441697761, 0.14419369777897373, 0.14056676271138713, 0.15869057300733402, 0.11411143932491541, 0.08398908263188787, 0.15470681333681569, 0.15499684464884922, 0.1155061722965911, 0.12096426769858226, 0.15216173662338406, 0.0989235875022132, 0.10758504460682161, 0.18034691718639806, 0.12792009132681414, 0.1254689259803854, 0.14481606282060966, 0.25312234880402684, 0.13714507600525394, 0.14178042649291456, 0.11792638266342692, 0.15110987587831914, 0.11497735496959649, 0.1586707279784605, 0.17191408609505743, 0.1447570027085021, 0.15655421186238527, 0.1546392185264267, 0.12190414578071795, 0.07784104222082533, 0.1448062070994638, 0.12418259109836072, 0.13916667143348604, 0.23792475258233026, 0.11104671080829576, 0.1137660289532505, 0.15895761258434504, 0.12652814883040264, 0.1494567419285886, 0.1179818285163492, 0.1375018709222786, 0.1364174298942089, 0.13892817485611886, 0.10680703635443933, 0.12349334370810539, 0.10886874486459419, 0.2227097752620466, 0.1017981703625992, 0.09822018735576421, 0.10790605316287838, 0.14081861794693395, 0.14195239695254713, 0.08245057339081541, 0.327674763975665, 0.23141752753872424, 0.1497574453242123, 0.1694582006894052, 0.18728509254287928, 0.19513636187184602, 0.0869157568376977, 0.18653823964996263, 0.24236088094767183, 0.1388494626735337, 0.20669789460953325, 0.20450832147616893, 0.22885723679792136, 0.09127623809035867, 0.12834314518840984, 0.12152155381045304, 0.17374031856888905, 0.07318622519960627, 0.10280153175699525, 0.2003930977662094, 0.16613444779068232, 0.12002959949313663, 0.10979818092891946, 0.12699393555521965, 0.08251128107076511, 0.18916841101599857, 0.10353914491133764, 0.12533725413959473, 0.08447851418168284, 0.07585222745547071, 0.14199590164935216, 0.21018552855821326, 0.20288180094212294, 0.11835820128908381, 0.12223407495184802, 0.14098071784246713, 0.14151297131320462, 0.2350667567225173, 0.1849345921073109, 0.10585673109744675, 0.1655857780133374, 0.14672293706098571, 0.13255985017167404, 0.12063804184435867, 0.2033850661246106, 0.11881808793987148, 0.1273765868972987, 0.12464404368074611, 0.10979227343341336, 0.11604658197029494, 0.1295490757911466, 0.12598084460478276, 0.15384225582238287, 0.18260335782542825, 0.11411522427806631, 0.0751708987809252, 0.16530134249478579, 0.16816435527289286, 0.0778469794022385, 0.1550541236065328, 0.1622970841708593, 0.08855562860844657, 0.21167964994674549, 0.13962957862531766, 0.16288164420984685, 0.1460939520620741, 0.07496720150811598, 0.10074242818518542, 0.11618002012255602, 0.14017389941727743, 0.13579266029410064, 0.19805971125606447, 0.16000233386876062, 0.172388689534273, 0.12927887466503307, 0.26000363111961633, 0.08414364230702631, 0.1737126216175966, 0.159531545068603, 0.14882743038469926, 0.11294025607639924, 0.08754938025958836, 0.13552217715186998, 0.12676912418100983, 0.18903112853877246, 0.23227260040584952, 0.14195296098478138, 0.17910281050717458, 0.08829653001157567, 0.12493876536609605, 0.2727664931444451, 0.1065741726779379, 0.22018829884473234], [0.011713010644598398, 0.055483323958469555, 0.03347382880747318, 0.04321782704209909, 0.04747489743749611, 0.03781784180318937, 0.0535125990427332, 0.03626572899520397, 0.04044576075102668, 0.032268521608784795, 0.025668357411632314, 0.026417286462674383, 0.02625633504067082, 0.0189539117491222, 0.015656111754651647, 0.01219613672219566, 0.011422076695453143, 0.036605380300898105, 0.04206273355521262, 0.028389106046233792, 0.008502669043082278, 0.03969431025325321, 0.031280815819627605, 0.0427704492904013, 0.05003928854421247, 0.07986879005329683, 0.013630791672767373, 0.03628988219134044, 0.034555419988464564, 0.04477398826566059, 0.030122312164166942, 0.06133699520432856, 0.06955227683647536, 0.028031524452671874, 0.04321777138102334, 0.037513520437642, 0.021620721090584993, 0.0626228514011018, 0.004133383599764784, 0.0264385953778401, 0.07266295171575621, 0.01956947315193247, 0.061549601959995925, 0.03417156636714935, 0.054711074772058055, 0.05746016788179986, 0.015195024679997005, 0.01772760177118471, 0.050650380362640135, 0.03922718024114147, 0.06613464967813343, 0.044451224530348554, 0.05843766914040316, 0.017399654134351294, 0.07049451494822279, 0.018550211243564263, 0.05349574115825817, 0.032393918590969406, 0.041248181951232255, 0.07577235010103323, 0.07214030163595453, 0.012877655572083313, 0.02647895522386534, 0.026162388421653304, 0.020615971880033612, 0.041394830332137644, 0.02421437508019153, 0.028022746701026335, 0.10565737538854592, 0.036926370303262956, 0.05587703701166902, 0.0301982116070576, 0.011716999688360374, 0.08079444858594798, 0.0350374671688769, 0.024603136153018568, 0.029079694868414663, 0.015780872345203534, 0.0287965970710502, 0.04609431722201407, 0.00371438511137967, 0.06613738820306025, 0.07074488588841632, 0.03588581246731337, 0.03147766306938138, 0.081559721584199, 0.025257849556510337, 0.02193601510953158, 0.026771921729960013, 0.02273436934046913, 0.06499461436760612, 0.06379678059602156, 0.052003141172463074, 0.02344648786674952, 0.03594749236071948, 0.030294488569779787, 0.02968409808090655, 0.020322584205132443, 0.04378238991193939, 0.016652309568598866, 0.00873234705068171, 0.01572687368025072, 0.018598595561343245, 0.04354532196884975, 0.010647406252246583, 0.03960235073463991, 0.017594616329006385, 0.04365478132967837, 0.035359941466595046, 0.06048441595339682, 0.04750207488541491, 0.014051308316993527, 0.06838985093054362, 0.049692705579218455, 0.03302694458398037, 0.0461645132600097, 0.007133372255339054, 0.06569120901986025, 0.077395731350407, 0.017349835616187192, 0.05065422097686678, 0.02081554281176068, 0.03970286350522656, 0.04482466210902203, 0.02818151806422975, 0.024443780348519795, 0.03581030265195295, 0.008871456138876965, 0.04898576909909025, 0.019566422924981453, 0.032557261583860964, 0.0651021144585684, 0.022389636178559158, 0.03684588438773062, 0.025048207680811174, 0.027828404199681245, 0.09499212697846815, 0.021808387973578647, 0.05947760357230436, 0.12828519829781726, 0.056367425931966864, 0.02451762033160776, 0.013821972625009948, 0.024503732893208507, 0.04846725278184749, 0.024066993828455452, 0.04533702973276377, 0.05137349566211924, 0.01666228774411138, 0.04948014335241169, 0.05001134668418672, 0.10106798610650003, 0.011369166204531211, 0.07169951044488698, 0.036121310768066905, 0.02101166275679134, 0.047514813850284554, 0.14636835374403745, 0.043004351973650046, 0.02359717538638506, 0.07496573947719298, 0.0455745207000291, 0.042783407188835554, 0.03998654574388638, 0.029737831428064965, 0.05931667998083867, 0.025018783380801324, 0.005326281161615043, 0.02175941179302754, 0.08944473636802286, 0.0328254477790324, 0.05803279047540855, 0.0438594285515137, 0.04053630276757758, 0.019601047824835405, 0.04767745551362168, 0.0024821423585308366, 0.027861624585057143, 0.018267085615661927, 0.09279602294554934, 0.05675070067809429, 0.02549705488490872, 0.019779586291406304, 0.054244044949882664, 0.01680427358223824, 0.0422475394589128, 0.05737276514992118, 0.0732865413010586, 0.021352410585677717, 0.001374713306177, 0.057546056632418185, 0.02471467167197261, 0.09106430297833867, 0.018751312854874413, 0.028326060601102654, 0.06434827053453773, 0.06052446966350544, 0.04713959511718713, 0.05984639159578364, 0.03495574557746295, 0.07737478052149527, 0.07556403666967526, 0.05663323354383465, 0.021561967114394065, 0.0319101384957321, 0.01139224143116735, 0.011572364383027889, 0.03723843226907775, 0.06188537925481796, 0.024578107222623657, 0.01617888057808159, 0.09017857199069113, 0.07053049426758662, 0.09835796707193367, 0.05775251840532292, 0.048030866237240843, 0.027055462960561272, 0.045026552252238616, 0.05676978500559926, 0.02794953754346352, 0.0811267971585039, 0.09666061596362852, 0.01739495633955812, 0.022151152588776313, 0.07148733784561045, 0.04622410771844443, 0.034631976232049055, 0.01867866587417666, 0.07436556465108879, 0.06667705572908744, 0.05931914391112514, 0.04944735897879582, 0.07536295175668783, 0.05450980432215147, 0.023416239782818593, 0.07292903392226435, 0.05377580913773272, 0.011135327531519579, 0.009487975839874707, 0.05223487678449601, 0.03123859132756479, 0.047002917490317486, 0.0126141115106293, 0.07919821509858593, 0.07862651647883467, 0.03719038562849164, 0.04719899661722593, 0.0338307239144342, 0.012422187483025482, 0.04384805513836909, 0.03399594825168606, 0.003389698981663969, 0.015251234945026226, 0.08789225990767591, 0.037541388082900085, 0.026869432513194624, 0.02235421346995281, 0.017714710666041356, 0.013479687622748315, 0.08751828427193686, 0.024460957356495783, 0.021391610825958196, 0.05158220243174583, 0.045907314561191015, 0.03811179536569398, 0.0241055150036118, 0.10704568136134185, 0.05331283144187182, 0.0408131906442577, 0.031221403187373653, 0.014245529291656567, 0.032245181064354256, 0.009000608388305409, 0.04803382369573228, 0.03109918259724509, 0.04468553910555784, 0.0062700165563001065, 0.017684536796878092, 0.05151140154339373, 0.02119340544595616, 0.02457169692206662, 0.015515651957684895, 0.012053400387230795, 0.0288951060429099, 0.02467149908625288, 0.018284492689417675, 0.04628498980309814, 0.011943210010940675, 0.13787172763841227, 0.033048344412236474, 0.033734352327883244, 0.018943556933663785, 0.05558199620281812, 0.05916634312598035, 0.05256286895019002, 0.028151943479315378, 0.058379113688715734, 0.004173237857685308, 0.04258923167071771, 0.03543353654094972, 0.023901049607957248, 0.04576926396111958, 0.030658484174637124, 0.04778901144163683, 0.020784934786206577, 0.011333701750118053, 0.025257376437366474, 0.019391628593439236, 0.017491164653620217, 0.05300979770254344, 0.03751045907847583, 0.03864027501549572, 0.06748301326297224, 0.06161311124742497, 0.02065153188596014, 0.09679893002612516, 0.09039277807460167, 0.017659203585935757, 0.09346114311483689, 0.036227333985152654, 0.009343151286884677, 0.03881304328388069, 0.028560341779666487, 0.02144130688975565, 0.010904772861977108, 0.02009008047025418, 0.04869044256338384, 0.12080360014806502, 0.01972353373275837, 0.05333061701094266, 0.02370934915234102, 0.03127336465695407, 0.02861361685063457, 0.0962832264485769, 0.03887999242579099, 0.056009417603490874, 0.07108245918061584, 0.010632560515659861, 0.0720535742584616, 0.02734751848038286, 0.09847830631770194, 0.030391975233214907, 0.025455984432483092, 0.0076076250297774095, 0.05213693555560894, 0.018966749048558995, 0.021517544009839185, 0.04140880126215052, 0.024695010324649047, 0.11010504415025935, 0.012886096574220574, 0.04985138417396229, 0.07175194317824207, 0.08211904860218056, 0.11268578848103061, 0.2171512969653122, 0.10821703530382365, 0.09242417727364227, 0.08415343123488128, 0.10658861487172544, 0.09971893974579871, 0.0993658704101108, 0.13500303000910208, 0.09889152672258206, 0.09496581042185426, 0.12322588852839544, 0.1127282615925651, 0.11675841291435063, 0.3999536839546636, 0.11151308382977732, 0.12133515599998645, 0.1516887659090571, 0.2024603946483694, 0.11631357701844536, 0.12068689742591232, 0.13673883921001107, 0.14578989415895194, 0.1891169059672393, 0.12607337557710707, 0.2066020536585711, 0.14527102903230116, 0.10938601437374018, 0.11005239619407803, 0.0730339513393119, 0.19117232848657295, 0.07324697740841657, 0.16375610197428614, 0.24569086788687855, 0.1272297158720903, 0.15844164183363318, 0.11512863435200416, 0.10369743758928962, 0.17740673589287326, 0.16000086441636086, 0.1745481908437796, 0.11562452258658595, 0.1289186510257423, 0.19877494865795597, 0.1272670755861327, 0.1244286353175994, 0.1778634387301281, 0.1294957599020563, 0.1345996727468446, 0.09395468616276048, 0.14636069478001446, 0.15147674916079268, 0.13964621757622808, 0.07617272392963059, 0.20553171343635768, 0.1565804987330921, 0.10242411997751333, 0.16549205960473046, 0.18041709467070177, 0.08764182217419147, 0.1184947119327262, 0.14648007665527984, 0.14025074138771743, 0.13451429607812315, 0.09382129253936, 0.1980228116735816, 0.3034068614942953, 0.12791973509592935, 0.09697701578261331, 0.15785347495693713, 0.16059758083429188, 0.16260461532510817, 0.1412504439940676, 0.1175640439032577, 0.10357453051256016, 0.19319747138069943, 0.09853213428868912, 0.12206816041725688, 0.07194157675257884, 0.2181679056957364, 0.14032492646947503, 0.1388245858834125, 0.17633267008932307, 0.1654999708989635, 0.11475797611637972, 0.11025825311662629, 0.1705687801586464, 0.20683016016846523, 0.2523331786505878, 0.1274081875453703, 0.2030389878200367, 0.08057521074078977, 0.15706583362771198, 0.10212481181952171, 0.13548949296819046, 0.12398483100696467, 0.13000589737202972, 0.1613182804430835, 0.13241093081887811, 0.10201056560617872, 0.1250240084482357, 0.0889124754758086, 0.1586624456103891, 0.16100844863103703, 0.06208267550391611, 0.11447550728917122, 0.1299514385755174, 0.11475618011900224, 0.15513077261857688, 0.10981803337926976, 0.21791658480651677, 0.1473546531633474, 0.1540315628517419, 0.11554625569260679, 0.12074018362909555, 0.14195631549227983, 0.2464078419143334, 0.1011598194600083, 0.17588012327905744, 0.05823904444696382, 0.14514709037030116, 0.12051806625095196, 0.16280290234135464, 0.10772925132187083, 0.20434451464097947, 0.0790110083471518, 0.17745360994013026, 0.07188182644313201, 0.12918876309413463, 0.12964689085492864, 0.135640490334481, 0.14270652289269492, 0.10344990165322088, 0.19832698832033202, 0.2062344382284209, 0.15063274913700297, 0.11075660528149456, 0.224903667694889, 0.1968548641889356, 0.11659923708066344, 0.13250846386654302, 0.15617448458215222, 0.08959660946857184, 0.11141006631078199, 0.11503665999043733, 0.11614509465289302, 0.17954069247934967, 0.2333340051700361, 0.14495704119326547, 0.19162080832757056, 0.10688102847780101, 0.1200419562519528, 0.13205550145357847, 0.10178618467762135, 0.10407457477413118, 0.23342518543358892, 0.1577787406858988, 0.14921551424777135, 0.3091627510730177, 0.08745676765101962, 0.13299486745381728, 0.15718151960754767, 0.2302080494700931, 0.28274012671317905, 0.07160355817177333, 0.21051182120572776, 0.17376721400069073, 0.1406672940356657, 0.11535050682141446, 0.09323759339167736, 0.1953825174132362, 0.1802203810075298, 0.11326406995067373, 0.10947648959700018], [0.02905873847339535, 0.015083977123140357, 0.07870067929616198, 0.01600047940883087, 0.016342544549843296, 0.048999053542502224, 0.042979553109034896, 0.022060530791350175, 0.04128400170884561, 0.024334463851118926, 0.027240296694799326, 0.045745311144855805, 0.01709021751594264, 0.02601578085887013, 0.08061403248575516, 0.029939003543404397, 0.051898082747356966, 0.06340157953673042, 0.04372275092464406, 0.017401997465640306, 0.010296435339114396, 0.037045106510049663, 0.004070860904903384, 0.0198552779329475, 0.11059731070417911, 0.03436414997850079, 0.01950111021869816, 0.037307593011064455, 0.11532112519489601, 0.06763466371921822, 0.022288585350906942, 0.031918799359118566, 0.07066146848956123, 0.04325545764004346, 0.03336110028612893, 0.029715479795413557, 0.015556008092971751, 0.021487353442353196, 0.04393203656945843, 0.0654068922449369, 0.0020770939272551914, 0.034456328430678695, 0.032811714336276054, 0.06393384042894468, 0.018419595107843634, 0.03269769447797444, 0.05650486426020507, 0.0031016058346722275, 0.07449600452673621, 0.074160486983601, 0.008854973038978642, 0.020362185205158312, 0.034325372762396, 0.046090202013147064, 0.03247551401727833, 0.03150921547785401, 0.014106795915722614, 0.03370352351339534, 0.03127540556306485, 0.06382890074746683, 0.04255503350577783, 0.0584856415662216, 0.01449708210202516, 0.040105612206389196, 0.09509178998996504, 0.04539593028312083, 0.04604959911375772, 0.0474931802455103, 0.05707290409191046, 0.013546771278925007, 0.05714314465876669, 0.02250733337859856, 0.04156736482400447, 0.05619778952677734, 0.02427885843644617, 0.06478525450802408, 0.10317549254978076, 0.024617480012238957, 0.10043589150882326, 0.0538305017107632, 0.020160660569672473, 0.06180502321512904, 0.03384406772966031, 0.03825701882306021, 0.04321734835684765, 0.06857342857983895, 0.03764302149647847, 0.014209288365236716, 0.021711057161155622, 0.024557848446420394, 0.03667965444037691, 0.041443466980126686, 0.03575041133444756, 0.03329916806251276, 0.0728194261319004, 0.03193864809873048, 0.039320416253758594, 0.010508337982173543, 0.02056337587418966, 0.08191216751583852, 0.02100962370604975, 0.01822750873543555, 0.0660813857393805, 0.04456514048797544, 0.027940132677031215, 0.04277574451407418, 0.036379388911882415, 0.017600996943656355, 0.04137050644203555, 0.04884435285930522, 0.012529977939266246, 0.08517012902302667, 0.02981775516673224, 0.03028889092092868, 0.030856570811010897, 0.05534938856726512, 0.031243047924363054, 0.03278734962805174, 0.03326766389363911, 0.02668737812200561, 0.06261243164772168, 0.004294897198633407, 0.042983360326616094, 0.03376924811163917, 0.049356946838088334, 0.036533818711177446, 0.02732905570155708, 0.0231829901895253, 0.01308030734435306, 0.03262261139752809, 0.058057622736669146, 0.00877197217050707, 0.07463560992619023, 0.04700440178567078, 0.01837672865804052, 0.10385384521214291, 0.05400720707257278, 0.012897582237201277, 0.014254380330385175, 0.09747067757416517, 0.06412175222067162, 0.024574628405389376, 0.02052053725492442, 0.042707036482170224, 0.061229105485836044, 0.0389632947917562, 0.033232011119253, 0.020054652195540257, 0.07414646781398915, 0.026569985202513635, 0.017721627482387703, 0.03466428563115187, 0.07160050794482231, 0.0034655135414141114, 0.06705231528030708, 0.056080660069710575, 0.06029834097716957, 0.03544590072124265, 0.030117371316009667, 0.0015941635911076446, 0.03577166273316834, 0.05711728081223555, 0.03345662211359013, 0.06690385605907068, 0.04340547908213921, 0.04686763510107994, 0.007391509770968696, 0.056115192201104946, 0.036214620995451696, 0.04053970922541339, 0.042731916983029805, 0.02365894990361994, 0.013428237307380186, 0.01830051936849486, 0.05549236331717111, 0.023873126301623415, 0.0796691226423718, 0.01695702798315324, 0.10046370720374398, 0.02917712030466646, 0.014838338302070042, 0.015529816773778293, 0.06903082903590985, 0.003634820154729823, 0.05775886747869663, 0.04681446764152497, 0.012746686916216277, 0.053160724564804696, 0.01738412283884827, 0.05590204738837201, 0.027473724403535016, 0.09753317383001558, 0.06365094857756048, 0.04716647570603527, 0.032842699001776055, 0.014339329336507944, 0.06713853057590313, 0.03377421679033432, 0.04970501038769726, 0.036392276306287386, 0.022319490235531703, 0.04900079016806558, 0.021199784205236938, 0.034206751588499174, 0.05088539997814223, 0.032880155195016414, 0.023089691094355658, 0.07048005791148171, 0.057032330878428183, 0.1126886457495857, 0.01275569844437996, 0.03627562182373367, 0.04012767254607752, 0.028273423777136486, 0.039590558008058, 0.09470827033510432, 0.03132183803245425, 0.022861376783112064, 0.004141704930589185, 0.009561703573126579, 0.019283423462184146, 0.03266198604251258, 0.07181336331996135, 0.03969635858084075, 0.06266459720791318, 0.030545254703611135, 0.038200934723136015, 0.0720682019891683, 0.023839299210521858, 0.01182860292828991, 0.06564676179550588, 0.020076714390597772, 0.04060819461301435, 0.0495188278000569, 0.04902236811176408, 0.015743737130833324, 0.013198045362514677, 0.05654162654536776, 0.06102053972426802, 0.012733030471281381, 0.08248074911534786, 0.08213022534619085, 0.020816030773858074, 0.009090804378502071, 0.021254959174257237, 0.028358023046166636, 0.005795846809633076, 0.010992413081112318, 0.030425657605519518, 0.015853766090003774, 0.03677133565361146, 0.04708686923549976, 0.009513349868939258, 0.030301529695861973, 0.07756248451187275, 0.02133285870513646, 0.07688799843890592, 0.07948233891511336, 0.1535050684469752, 0.03556287061655894, 0.04806513119547162, 0.013530774285754887, 0.007259136136781308, 0.004821372122023604, 0.005557013018915313, 0.02656961041793693, 0.017737693124217913, 0.0714805546158459, 0.037630315928254277, 0.0347889256227063, 0.03097254622844048, 0.027065942085755523, 0.05122308459249325, 0.021589035095530562, 0.028603169266716577, 0.036040906488779, 0.03187116832123138, 0.029018367495154962, 0.13300795893883333, 0.022469765863206703, 0.027358953120710794, 0.03691819183586631, 0.10310525569366291, 0.02599230116175022, 0.0562626012833789, 0.029373383113124873, 0.044644316512858495, 0.06177958239277359, 0.03270015098678414, 0.03909014267264865, 0.06664104672381654, 0.0036041337398273754, 0.020651353770517744, 0.053583822955260985, 0.035543196281651035, 0.08933018587413244, 0.01950887864950346, 0.02342118063097587, 0.023676167729718145, 0.003984158111052238, 0.0729112297995016, 0.035652470105560496, 0.05162170695257373, 0.06982181745115668, 0.0289378871457302, 0.05183671826671343, 0.06111419505032245, 0.020315826950536575, 0.07076865687849931, 0.06687267843517475, 0.06263643270358443, 0.03835835166682955, 0.038262399393715896, 0.0797821739979554, 0.0010296782988916675, 0.05193565768422559, 0.09059424148290418, 0.039234980213223025, 0.03702944719407242, 0.019391969981370494, 0.01656962132983608, 0.02396962034254102, 0.044985006825299934, 0.02895936675486155, 0.07296536205103621, 0.06092270981753245, 0.024535999618819915, 0.015144682947720867, 0.022851964495202992, 0.07871279856772162, 0.06726410938426852, 0.053398950258269906, 0.023587991308886558, 0.06416019547032192, 0.09548682777676731, 0.02196027406171197, 0.05581655197602231, 0.07705573123530485, 0.06809774160501547, 0.033845188372652046, 0.08261781636974774, 0.047998323061619885, 0.03352146355609875, 0.012589366451720707, 0.050899701163871214, 0.05354725362849422, 0.03172849043039605, 0.053472886720555834, 0.05666491953888908, 0.013985990972287254, 0.006334093586701783, 0.027907381700060796, 0.11972528925980441, 0.09396924710017629, 0.23818444489734247, 0.09055607282789424, 0.13046047766692936, 0.14288496488006786, 0.16837530332850292, 0.0945142432465218, 0.16572452994296327, 0.18081800284562632, 0.14147060952382162, 0.10978891892591491, 0.09670364568592049, 0.12689102935837582, 0.2490257826866582, 0.16950026561971754, 0.11405156285036355, 0.2156038596876897, 0.10254296750645153, 0.07457931802491657, 0.13558815408032387, 0.11708679841831326, 0.06764015561202541, 0.15641566773410887, 0.17060851474525407, 0.17467993689933792, 0.11824761386378668, 0.10053504985990003, 0.26117019820958376, 0.1554205219144933, 0.14659896871307865, 0.09211709882947616, 0.25024860457051545, 0.18739151651971042, 0.07085128760081716, 0.1062953329528682, 0.15269526658812538, 0.13870309630874544, 0.11573459050850943, 0.11282273699180223, 0.12739374535158277, 0.08450984765659086, 0.1639444738975726, 0.2106912131421268, 0.09448043841985054, 0.15202742273686454, 0.22758673934731632, 0.09222048742230982, 0.1937564866966568, 0.18491382681531832, 0.1002013283141423, 0.17293333687121049, 0.13847506401361898, 0.1716794486856088, 0.22465396468760446, 0.09501974971499294, 0.0836109287047293, 0.10075261045130901, 0.12266462450497784, 0.19205094227800146, 0.10308460172382183, 0.10904245937126689, 0.11718642432242632, 0.09187422358081676, 0.17046824883436784, 0.21050883777206764, 0.09939768628100865, 0.10113765893038362, 0.07686467273742892, 0.10292230886989273, 0.05969083002128173, 0.1466084088315256, 0.08078273007413372, 0.08380891144042835, 0.129656286444515, 0.16092074161861092, 0.17459328373661265, 0.13013795512961224, 0.2866787341190502, 0.2357045584358275, 0.17770233331248164, 0.16624520590994507, 0.25151313515380025, 0.2617754938546568, 0.11272064715740271, 0.17679483513347805, 0.07996196669409983, 0.07155039813369513, 0.09961977397324517, 0.18501898914109915, 0.128202834748663, 0.2062274917261675, 0.17396002396708354, 0.13737686356762424, 0.21968344546621665, 0.1143187508569099, 0.13574881420936435, 0.1598408870631829, 0.13129414699506015, 0.1957681670319289, 0.13677665905561298, 0.08131566632073373, 0.1512008483405225, 0.1333918867749162, 0.11789260010118596, 0.1257288854685612, 0.24693994695553556, 0.10992553347023204, 0.10008677039877512, 0.14739366044523194, 0.14712032745592296, 0.16352787672076374, 0.07034575886791572, 0.16128697665408254, 0.12560221570311114, 0.1054039690643549, 0.12363712739897892, 0.0980556161084678, 0.12767743872245774, 0.16028997546527535, 0.14034784398972988, 0.12359019397990778, 0.15033860632684082, 0.050984406188945286, 0.14400572661543265, 0.1363653311273083, 0.060011860841768794, 0.1322922614053823, 0.1370985433459282, 0.1617912808433175, 0.1946149140712805, 0.12353056241408922, 0.1830845812219195, 0.19498120847856626, 0.10903149785008281, 0.184762473218143, 0.2060964729753323, 0.1554719527484849, 0.20426136441528797, 0.20344800024759024, 0.17825990886194631, 0.11414732216508128, 0.18009056453593075, 0.09747257005074061, 0.14951832534279674, 0.1959660681313835, 0.10331241879612207, 0.11532583041116595, 0.17437751172110438, 0.1459866523509845, 0.10604120674543083, 0.15832910255994648, 0.13096295617287979, 0.1803494553314522, 0.22580024146009237, 0.16524060512892902, 0.12878729088697582, 0.12307656841585413, 0.1623471049242653, 0.19694178452482447, 0.1615705809672363, 0.20612746506230906, 0.14586764154955745, 0.14015236229170114, 0.1583329023560509, 0.23542457580333576, 0.11900513141881675, 0.16892149433260784, 0.08365861169295385, 0.13209072378231212, 0.13538691331632435, 0.17232869431609288, 0.1245896887849085, 0.09545852968585677, 0.09757562467711978, 0.09732111255289055], [0.037518333265325055, 0.0385028181335656, 0.009714111020002747, 0.018865219535655342, 0.08046661969274282, 0.03370261809322983, 0.012471146965253865, 0.09919860516674817, 0.02165287278330652, 0.0698583311168477, 0.015114179750526091, 0.03571603505406529, 0.026021682788268663, 0.05042438155214768, 0.005735346003348241, 0.02383207069215132, 0.028043038873875048, 0.013490103665390052, 0.04460258554900065, 0.034613352036103606, 0.03975497340434231, 0.028170046316517983, 0.032483967079315335, 0.03510538852424361, 0.0341951035807142, 0.07147765281843022, 0.0623501418158412, 0.022207442634680774, 0.027969692418992054, 0.015535086022282485, 0.03228369481803384, 0.028744960291078314, 0.053434525107149966, 0.03355778055265546, 0.04077440229593776, 0.024051009822869673, 0.056709864002186805, 0.030391663531190716, 0.005757224516855786, 0.032467728888150305, 0.01759427865181351, 0.043825991087942384, 0.03322930970171001, 0.04113750175747555, 0.037614556422340684, 0.03275317372754216, 0.03816639888100326, 0.11017525132047012, 0.044040119246346876, 0.08526689023710787, 0.06537612280226313, 0.01461542589822784, 0.06060871084628161, 0.027087360467703547, 0.04123361730307806, 0.019411367866268847, 0.06013030761096161, 0.03761225576454308, 0.02779949012619909, 0.048903795177466236, 0.0226453394498094, 0.03513330811983906, 0.03287678955530282, 0.011658611219900195, 0.07318534204387106, 0.0722752908768598, 0.02244802650238853, 0.027217896822548937, 0.04127453932596836, 0.030323051978484727, 0.04287888077669777, 0.050117722421418875, 0.010224534216831671, 0.058742183464346454, 0.007725989235041197, 0.040792421641526744, 0.07080918556312099, 0.08530470266123302, 0.03934000895242207, 0.018455008539604023, 0.02632331943459576, 0.03459844971075654, 0.01907135661895154, 0.018736553392955102, 0.026016623196483124, 0.03293760113592725, 0.0440672261902364, 0.05039088100602385, 0.037287888990249485, 0.013801700861222344, 0.05308668791258242, 0.05848297725606244, 0.054323629155987874, 0.025927283459168393, 0.025422706530662253, 0.04659961959987413, 0.03494924065307714, 0.06957143908948638, 0.05080705515865702, 0.036897864411002956, 0.015432925683853682, 0.044051741278963163, 0.02199210663093254, 0.08054530961089768, 0.027188825042685494, 0.01766617235261947, 0.06988702254602686, 0.03271117930125911, 0.026671978557715192, 0.030984982768131886, 0.058327267252025194, 0.10422300430946052, 0.03944440686609596, 0.027982247702311724, 0.028836431847594213, 0.03523104154737666, 0.030435077314905357, 0.01681087313045282, 0.02321618088899413, 0.048591803715680726, 0.041362743577337824, 0.050780938981915824, 0.023836989275878295, 0.07772417622618377, 0.036043537402292714, 0.017675623603281565, 0.004676319822465302, 0.03076524953939952, 0.02109060686052544, 0.0037839308424736373, 0.03514895259286277, 0.040154464077204466, 0.01568227802636102, 0.028822410822613165, 0.013101029035169631, 0.027880961242772173, 0.02585829897725489, 0.011627029125520494, 0.009674968296167208, 0.012579519079736201, 0.039867935702204704, 0.01700489465292776, 0.01704485188383842, 0.09304246050305665, 0.03171552139974665, 0.03405978037335444, 0.012224631482240511, 0.024180690852517728, 0.04378546240332071, 0.029457585333148018, 0.007430661307807895, 0.01880889609310543, 0.11105441430117935, 0.07506114256102592, 0.03125799477857072, 0.04067510293680243, 0.04212547843053471, 0.019132593079120852, 0.028703797070193104, 0.007704370937062777, 0.025462268567935098, 0.0021651342103723437, 0.08670184761285782, 0.03315277201181743, 0.06441950186854228, 0.08178998774383217, 0.033965108304983005, 0.03338464863190893, 0.03360135204275139, 0.04103691106138285, 0.031605613039573655, 0.07561715217889287, 0.023308539311983623, 0.042224377029924653, 0.05978028479148634, 0.04798366193426773, 0.029678583923669066, 0.06754291200195439, 0.062464952061418444, 0.043609822023427114, 0.03307549959572498, 0.028906158477184363, 0.03775865181523841, 0.015788548007549252, 0.09630112705053762, 0.028664971614489332, 0.03765518529689871, 0.036343836327432655, 0.06816676876042038, 0.031246999860741198, 0.05093555060739163, 0.07956177098094486, 0.026399469352327287, 0.044652086799032986, 0.04550051373371389, 0.02692872269108193, 0.04053527118230704, 0.03489431430352852, 0.039044070144882426, 0.03157812388963066, 0.051609442962217145, 0.06361741092405282, 0.034763900403049774, 0.02770645820419304, 0.04794140033482108, 0.11250313109485433, 0.049256660422543064, 0.04886826114670839, 0.019967169682786334, 0.06849709869129583, 0.018151442309317645, 0.054819932993268594, 0.019489274818624835, 0.04746311213239096, 0.04350523857283406, 0.03319461058708839, 0.0211023680458311, 0.029611549434775952, 0.0737542798742652, 0.03433216341363732, 0.10627035226207227, 0.032798196116345935, 0.0366371850395808, 0.040543308641645126, 0.016121126645884942, 0.0678155325294938, 0.04179940100584645, 0.03728997442522086, 0.06500984323793091, 0.01560978689667536, 0.009739797678776085, 0.0037831733880011598, 0.056509599162382074, 0.032938257936621085, 0.03605800557124894, 0.02913265081588179, 0.036377622600411996, 0.04401553931529634, 0.03375689877429977, 0.04097528682905249, 0.05410337456851266, 0.031431111856363714, 0.05174880716367625, 0.04948461850290187, 0.008865688723744825, 0.019712221546797082, 0.035894169050152414, 0.044199632757226937, 0.026060762429551687, 0.07548996291006915, 0.021883424669795204, 0.10698630954721011, 0.014688782557641389, 0.03707591677084565, 0.023743840465613175, 0.03425433438678738, 0.054454751807497814, 0.04250303492881358, 0.02912534251663601, 0.06399059988325462, 0.008862927006703103, 0.04080131999216974, 0.016470589143864345, 0.035166931120329536, 0.03452151868259534, 0.03418021609832067, 0.02982175905344775, 0.06190063038957305, 0.0395408489566762, 0.091343536041677, 0.043068443847005256, 0.03429476288147271, 0.04137915988394525, 0.04868159245233983, 0.06298321604845114, 0.06932805918040685, 0.053605237626470625, 0.014082247525948333, 0.02820773072016891, 0.06180365766340401, 0.10175090297707357, 0.06047250448318664, 0.051671976325451396, 0.09949658488039859, 0.0407481228467077, 0.05620447998808231, 0.05948665777395945, 0.047215620725182816, 0.03303851466625929, 0.03122579299088102, 0.01060779968611314, 0.02892511292884592, 0.010787215742311673, 0.012818779141525738, 0.015642244725313503, 0.01433261753845727, 0.03332631953526288, 0.02098362812830601, 0.002111930571118137, 0.05391992308432236, 0.021655954551533796, 0.05120156973134726, 0.015350649337051436, 0.0434391874296125, 0.036444100478547625, 0.09283748673624359, 0.03610777399444487, 0.05461134867800865, 0.005776914622401819, 0.03983287293522153, 0.05691337202733848, 0.10160824735066853, 0.02427480631013168, 0.03059062404645374, 0.008042511508392636, 0.04445961822057143, 0.02409563330729725, 0.020846685183641966, 0.030265157038229518, 0.037128434851183556, 0.038338276572176255, 0.04387011176731903, 0.02079775724268984, 0.0862438311742153, 0.027938247621932533, 0.05148401629412547, 0.04632370393665042, 0.06443065634812228, 0.020529713910946157, 0.06494358429335989, 0.04317870472732466, 0.042585702758515254, 0.035450817449600436, 0.016802479440229945, 0.010358723793615354, 0.04910403775284067, 0.0043632670895021874, 0.044690344511764124, 0.02547963296819944, 0.032113746710820124, 0.05090413549623918, 0.01532980240881443, 0.024377866502618417, 0.021035927275079302, 0.03058790221984964, 0.05382937735703308, 0.03936573921237141, 0.00914550344532472, 0.053371212488855235, 0.039121773006627336, 0.041155847648042254, 0.009713556264614454, 0.11291615854133852, 0.13435764354653656, 0.1409374357899651, 0.08405134140048176, 0.19525559531757608, 0.24702412134502083, 0.10057164516183548, 0.14464152453001589, 0.27033343620132655, 0.14431116491323337, 0.15802022069692612, 0.12337224005023018, 0.08943316628574394, 0.11781222550780512, 0.16615913162240759, 0.19655350770335644, 0.11656491275061853, 0.07324337057070807, 0.14473592571448535, 0.13776346313534304, 0.14952295634429902, 0.16832072578836232, 0.19229638535762206, 0.24912012449931353, 0.16425400885054842, 0.2039693293045275, 0.19362120801815763, 0.2802497165976092, 0.12578779715113342, 0.204528181347996, 0.09987653480493464, 0.1150648616021499, 0.19812387734418735, 0.12037696913466789, 0.11305753767373972, 0.09855709271505475, 0.14492484682705253, 0.13979032781207934, 0.12043047056067735, 0.10712205577874556, 0.15509250748436898, 0.09811584881390445, 0.150562452909071, 0.0692580227041617, 0.1451381845981814, 0.07707336466410197, 0.128146045608446, 0.18746651796391234, 0.3634565236279741, 0.15604857180733234, 0.198788485431578, 0.1158015248074662, 0.19120995537377894, 0.07152953636250459, 0.1622219491400756, 0.09964200129616074, 0.16074097860837355, 0.07858755372581072, 0.13853176409611478, 0.23734593676635996, 0.09147137840045616, 0.12903390655992553, 0.14146057568723336, 0.136046786501538, 0.09498230094322935, 0.16479325335239992, 0.1111777444020845, 0.10056436469312757, 0.07339470932492986, 0.09145195639575832, 0.171013193030376, 0.06573996070073918, 0.16181342652998865, 0.1672223026980646, 0.12785050756065175, 0.21158559015020728, 0.10716772012528963, 0.23454524955013767, 0.06559493020176888, 0.13704120501643047, 0.1036522927461192, 0.11599520308664069, 0.07857426928239875, 0.08887721603969112, 0.11371707689249888, 0.09917401781422086, 0.2741851529572159, 0.09763494454091415, 0.13177370798075572, 0.12160881553427316, 0.22036442533135414, 0.08534256703569554, 0.09846128144999966, 0.18216507509350777, 0.08971472227131017, 0.21117282245540991, 0.12213896872708574, 0.13415555673418567, 0.12029508056002669, 0.1813379069790244, 0.08828453690512106, 0.28149619814939797, 0.11157931308844127, 0.127442296652589, 0.17801078472984955, 0.13471945538185537, 0.11469341668998823, 0.1566712188650854, 0.07394595435471274, 0.13756097556324676, 0.08245268851169385, 0.12873560772277415, 0.13036105956416577, 0.14475701755145565, 0.14463793253526092, 0.16711573029169813, 0.1112234013271518, 0.16565111669478938, 0.08448514898191206, 0.0954119599191472, 0.11326061154250056, 0.1044916023965925, 0.08693156458321027, 0.18182138650445268, 0.14189449459081516, 0.17654458293691278, 0.08664476903504692, 0.22620067466050386, 0.14098132640356198, 0.27664216642733663, 0.17392386653227732, 0.10071885757497512, 0.10047408984974027, 0.1287247278378345, 0.1837118889670819, 0.19114270195132121, 0.07427920834743418, 0.08583191694924608, 0.1639082867768593, 0.14345963951200247, 0.16814915608847514, 0.05800006918434519, 0.1348519732709974, 0.1782148753409274, 0.1568841261905618, 0.07873737107729539, 0.08326908806338906, 0.1966096882824786, 0.0872877064102795, 0.11352350993547589, 0.18134442303562537, 0.08872105332557112, 0.23784811841323972, 0.1489173193112947, 0.20701090281363577, 0.15109294006833807, 0.1928059884812683, 0.133870646241121, 0.09701229748316109, 0.1380503477412276, 0.12961935717612505, 0.15290318668121472, 0.12465775856981054, 0.09335847440524958, 0.18141264125006273, 0.12634381419047713, 0.12942789791850373, 0.10523528631892987, 0.11827548150904477, 0.08640858795843087, 0.1294653318473138, 0.18567644292488694, 0.10996574303135276, 0.12661288725212216, 0.26121968461666256, 0.14865462871966884], [0.06262066206545569, 0.06774778186809272, 0.08554451283998787, 0.019556622864911333, 0.052479065634543076, 0.044541632960317656, 0.008830775313981576, 0.01576265447511105, 0.011108612070529489, 0.015641192730981857, 0.06250159189221449, 0.023517461304436438, 0.05167054398043547, 0.05421600289992057, 0.044462653604568914, 0.08034665894228965, 0.05464166541059967, 0.041045794569072314, 0.022170604279381223, 0.051542022556532174, 0.01849353899160633, 0.03489848146273289, 0.03268271051638294, 0.03837084201222751, 0.031671920223743655, 0.030095832335064188, 0.04502542047703173, 0.041854984156088904, 0.056131693854695186, 0.058649552302085795, 0.028046510269632563, 0.016065690069808625, 0.08392899093450978, 0.04593468125676736, 0.05297724710544571, 0.0781669192656409, 0.03816508156887721, 0.03143238092889078, 0.04200786286673974, 0.005551439026021399, 0.03284150414401665, 0.03734022153366823, 0.03857877694827039, 0.03688434990181122, 0.0593491415202152, 0.06605813425267115, 0.039107219490688294, 0.031404409382957965, 0.05548166525841225, 0.0712774955900386, 0.016756165714468807, 0.03940326590964105, 0.009334170372312656, 0.06562919515999965, 0.028233327393536456, 0.037268953092279844, 0.04187534126685932, 0.06278599030338228, 0.04402884231240023, 0.020585597630997654, 0.058746729118865915, 0.0884554089861922, 0.019873813071171753, 0.02882926641177619, 0.021501085029740352, 0.012158537665527547, 0.03554176393663511, 0.04464521822228562, 0.0241644303969224, 0.03921366202121135, 0.03969436220359057, 0.044299793007667176, 0.006734705366397975, 0.019901391278835945, 0.03394172694243025, 0.044074592005927116, 0.08494978537783027, 0.008414354397245916, 0.0400285253272159, 0.031711202100268565, 0.03435203070694115, 0.023311676741286647, 0.027498510280565824, 0.013608971603389364, 0.02447511382342782, 0.12606341595528647, 0.04134126582357567, 0.023128984103095718, 0.004774244816871942, 0.0711657949432265, 0.095799798873486, 0.07850221416447312, 0.038097078577266075, 0.036538935819407925, 0.013939821037638467, 0.013360597968130605, 0.013998584290675353, 0.021341309911804274, 0.021430169108498376, 0.044876285901409574, 0.03392979320778977, 0.025621294116717763, 0.05027237857575528, 0.05915291767450981, 0.03552385220245924, 0.04179625058895908, 0.005156340012035798, 0.06293458311120048, 0.02623783515446121, 0.018327225552638993, 0.030866812448948622, 0.016205269494093955, 0.01858197145338636, 0.02594769623101456, 0.03638752656115685, 0.03104972216533497, 0.02191057243180694, 0.04599216430506203, 0.03328792081447318, 0.017243190850422252, 0.07223956388770603, 0.023123544160625897, 0.014009347287355922, 0.05695248692063615, 0.010612365749693708, 0.050287941412534565, 0.016217448137467727, 0.058581341509125195, 0.028332348447293043, 0.01767401314282324, 0.038955179406912066, 0.008702600844117114, 0.0342199358419748, 0.018653863298823126, 0.02284683068864979, 0.047288225032389164, 0.06497709226096049, 0.055711118766339496, 0.016196938886423595, 0.0184180087671848, 0.023268283366633113, 0.01785182616004022, 0.014569765262422152, 0.016930377460084856, 0.055524991839774884, 0.059465859085321426, 0.02843299851519987, 0.04092011186003219, 0.010153573766729096, 0.05000642624509055, 0.10012223763624206, 0.0246226935996674, 0.007047530352792819, 0.03365333206602372, 0.010402551324659726, 0.06336691381875426, 0.054984919843263924, 0.031503604841418564, 0.029078897059662268, 0.0382821850507753, 0.018515430492698215, 0.01259480361113674, 0.01596111960679991, 0.02625458171678474, 0.06016437218931969, 0.017565872949489858, 0.03677453059935942, 0.08819490030873567, 0.048324073941330425, 0.05504002430825494, 0.0501255075505469, 0.04166978120338172, 0.029459785801009275, 0.023413738745148294, 0.025605480805097613, 0.0650959175254684, 0.024433937614958268, 0.05454229183669668, 0.049088233718066476, 0.036966590996598825, 0.018217614051536657, 0.024103193936753087, 0.008860587386152474, 0.03031759348232299, 0.050674537269514985, 0.026697092835092917, 0.06458436997490935, 0.021439128686324693, 0.05426076182629913, 0.058047214115504175, 0.03123712187516503, 0.011446947919466766, 0.012541349497041665, 0.042360126972198486, 0.028170820005470887, 0.018681768051465042, 0.06233010382857174, 0.018959368389914744, 0.017847210001491476, 0.03141116663755383, 0.023342301465163473, 0.03719202577485703, 0.07180544460425153, 0.049975237488979474, 0.016364128059649374, 0.05515074903087225, 0.02875525016861502, 0.027347225332050584, 0.06291120545938611, 0.019827454816550016, 0.038496320630656555, 0.020663608484028373, 0.0466626576235285, 0.05030505904869642, 0.02636659406562103, 0.036045674787601456, 0.022113917184469756, 0.00880580946613918, 0.06706348460284062, 0.04974170216883067, 0.029624431263073348, 0.0491238827817142, 0.03134876686090138, 0.017169553102576174, 0.004689857523771934, 0.043908733132411726, 0.04715118004241958, 0.028805643851228524, 0.03196337274857797, 0.0485860335174948, 0.012128019625379238, 0.01689852448180318, 0.03696937033964787, 0.03171536183799617, 0.036790278973057866, 0.03321458920254372, 0.08176342627848499, 0.07464824127964675, 0.02967555781651754, 0.014327099670481402, 0.03367752236954402, 0.02627493697218597, 0.06382141247740947, 0.040305324146174826, 0.012847803609474795, 0.036817222644458525, 0.039626277575735, 0.040814452295308, 0.030665671874885447, 0.045618158983415924, 0.060113549916422926, 0.04008103227533866, 0.09322442027041689, 0.013055044637440005, 0.025844146221061237, 0.023023873727652244, 0.032791884150356054, 0.06913950914167799, 0.049924092381843366, 0.029409063718048856, 0.06617155668209307, 0.08653597760712728, 0.028576117983902805, 0.02120857679983601, 0.05581927936873399, 0.02794180250930367, 0.058271071829949506, 0.014419774433918064, 0.020120027984376065, 0.03707749012392014, 0.015716492889623623, 0.04455410846276209, 0.037378419874585234, 0.06009035038005095, 0.05487100759637542, 0.022832228933111764, 0.06559065543115139, 0.049706969657563604, 0.019990790387964807, 0.05596557151875459, 0.03245574320317246, 0.025965949353121687, 0.03538551587553229, 0.06696959550026804, 0.09920998971210793, 0.022277293574006762, 0.023528007222921588, 0.07919341340311803, 0.059946370020043105, 0.06659659949946217, 0.07262110942974687, 0.037138717307243496, 0.02516728713089833, 0.01709604523057351, 0.04748358427605126, 0.06348878188873641, 0.051298564721946605, 0.050922147420351394, 0.030241430577007122, 0.007581514419143787, 0.014961807555664564, 0.048886017029872164, 0.01259819429833442, 0.023132422102207784, 0.03544230872648768, 0.00981269049589173, 0.0281306252873037, 0.020996009006921668, 0.02353239331569057, 0.008996010783448583, 0.04158027448283974, 0.08284132156404667, 0.027836590088554658, 0.052922647300874814, 0.06606931099668145, 0.007848125405871542, 0.046377936378121376, 0.0043730662218877114, 0.006412137372535653, 0.05887421895749867, 0.02186221408919664, 0.06613104284042493, 0.0222071494863485, 0.09068699509953149, 0.02364659871091135, 0.046357931787497364, 0.10692963915062137, 0.017325830849586055, 0.009221147774951532, 0.00631323506240733, 0.02756365414825268, 0.08981452629086562, 0.08764399666688405, 0.015865620043769013, 0.019372449642105494, 0.049633868111413904, 0.046936988801462576, 0.08840987080475315, 0.02966945179650793, 0.11048642641981132, 0.004927553509332938, 0.07125903095584363, 0.024486526199325453, 0.03820924677711446, 0.03670639402116649, 0.04222712668706663, 0.03611220461607445, 0.02649559231940657, 0.017133655419456773, 0.05191484415263403, 0.04922746433294378, 0.05624871941108722, 0.11316980977426283, 0.09508487317361869, 0.21856151113752276, 0.14250103704398498, 0.11740404428564943, 0.08105658256681636, 0.05520525977772195, 0.13282341649755836, 0.13214933860581368, 0.0811034714570269, 0.1362936693476513, 0.10128328314749524, 0.1527516994974576, 0.11659481388051063, 0.09683814510935917, 0.15488283592276275, 0.15732797503005713, 0.12217856972711161, 0.11963880679104477, 0.13128268823493272, 0.15986224607331678, 0.0668619321368169, 0.11814021025202237, 0.13839929073583335, 0.29533799446653575, 0.18355648324359208, 0.25618317362386733, 0.09936247879522853, 0.16192262613913044, 0.2075074886670336, 0.18955976032884791, 0.1021239509282168, 0.13848346512531862, 0.16355682048015296, 0.20405507704708725, 0.10092573123984039, 0.1209379437204916, 0.20577114511979744, 0.23496730893384665, 0.09733651953865774, 0.09502792818238959, 0.13115276786265895, 0.2530181215843186, 0.15215176215860993, 0.17921578022651374, 0.1265247943229042, 0.12117382051656023, 0.12127927970141172, 0.1642275438643992, 0.17215881671290845, 0.09273491450585425, 0.10526030411710963, 0.16118865692988038, 0.18529551336541772, 0.13014792959438637, 0.0988103802956175, 0.13215799204772338, 0.1490841095801443, 0.09313301736256108, 0.1579486479749903, 0.24856168805854395, 0.2588783868122846, 0.16951589524978772, 0.11408889287849888, 0.1753058345639147, 0.14620137051679194, 0.13915117538999766, 0.1004569981887471, 0.15026667737402022, 0.09361217758851126, 0.1163878437364474, 0.13664347323356196, 0.1004445375292562, 0.14495463663479313, 0.1469048226135783, 0.10576487547950819, 0.18420854903524742, 0.08848063458572142, 0.10352166733355261, 0.12461052829166874, 0.09319955090177245, 0.14516334340441972, 0.1609348869533278, 0.09339066877146251, 0.10223704681266099, 0.27242507552728057, 0.15502963273320347, 0.12321460788371041, 0.11341790974256583, 0.10871722799493, 0.17047017841832712, 0.2177653054241091, 0.1468110003042966, 0.2192985379952006, 0.09319784396211617, 0.23997938842512667, 0.12470868474338204, 0.11628052176092751, 0.12036986678140238, 0.06811636209022254, 0.15747913566883653, 0.06804815129726194, 0.13705008110264316, 0.1955149759305641, 0.1407064645900391, 0.14591361017664894, 0.14530114538501948, 0.15834873978747055, 0.14301145653007552, 0.1272549043642357, 0.09207697832607664, 0.18211918068118393, 0.231295280973427, 0.1494237460428849, 0.20333960215793923, 0.18637983564985916, 0.1484707838972099, 0.12126105997595005, 0.10834137472556904, 0.1848962824442424, 0.1864364615175873, 0.19496091816108674, 0.14851008803816512, 0.12359966378426179, 0.05730611657781992, 0.0957268086494878, 0.07528104091761634, 0.06377936239005066, 0.15749418642371893, 0.07748857402475551, 0.1186558544577565, 0.0880472277640365, 0.250671599060297, 0.10416634133434854, 0.11934030015254393, 0.18644670315552503, 0.1423639920540154, 0.12438449979526922, 0.13531259464798495, 0.091432771878317, 0.0833646024693735, 0.13563698739744723, 0.1465053393621929, 0.15194486622931436, 0.13188829558202997, 0.1715758300269954, 0.11132578802062199, 0.10704121363232844, 0.1233141373086255, 0.14541022625053301, 0.3020911227213219, 0.15017848054412752, 0.17930273024830967, 0.10054579615825787, 0.1793843219638802, 0.16530365799553692, 0.12789932603482157, 0.12378212079056539, 0.07835516502382234, 0.1798755643540062, 0.21927652589511126, 0.12216122573590837, 0.1291526947170496, 0.13784597511403263, 0.09148883371381089, 0.20462037093238905, 0.21114295843290165, 0.16021678486140445, 0.07564614046714269, 0.131210477265995, 0.12153863804996945, 0.11085588237619959, 0.10086088979733177, 0.09287082400987856, 0.22106970311142504, 0.13243793015135452], [0.03484742541331798, 0.02544315269915387, 0.0374557999020908, 0.03959215362556279, 0.014786551237193635, 0.08116755590890534, 0.05001306846679654, 0.019490516060614027, 0.038700978984707035, 0.03462979060714133, 0.02328737326024566, 0.047771789904800244, 0.0494833271659445, 0.02082966031593969, 0.040154567977879196, 0.025172984969685785, 0.03462625427346211, 0.03613875865994487, 0.062273307266877964, 0.002903114495893533, 0.04377896118967328, 0.02665798536327202, 0.036451755731832236, 0.061719386794720776, 0.07229767405078746, 0.07519878869061358, 0.035495951160555705, 0.02046381119725993, 0.01970847926713759, 0.009803270786505891, 0.02327198482817039, 0.04888390933047049, 0.06106204804382287, 0.043712828410207294, 0.052959164677304216, 0.02260599077999359, 0.002435599494674534, 0.09478454827331007, 0.1063371826603543, 0.06380578284733929, 0.03205832312232815, 0.009268348367186263, 0.06314510814263485, 0.07594199021696113, 0.06348862603772432, 0.006170589640532853, 0.0005770751317868417, 0.08110917857266031, 0.03661083879705984, 0.0535565304744523, 0.05121847214468289, 0.050490328794694506, 0.05740276275901124, 0.005182728000363568, 0.05379483409342356, 0.05193353514187038, 0.03361814313393552, 0.06773267174139619, 0.011417536607041257, 0.09053905538166873, 0.023658055615669582, 0.037293169370968826, 0.03264386279624887, 0.04319567764468957, 0.022618471848545596, 0.01806338277674513, 0.02662121936737094, 0.036678433607448824, 0.006438008640543558, 0.05188140297832433, 0.017874467230285518, 0.040843718888936564, 0.023252529426827095, 0.052182095241732895, 0.03522124890878331, 0.04756879025080707, 0.028177632921142504, 0.08509795516147278, 0.009774532973096939, 0.044213963628862984, 0.06454177069826983, 0.004033547575090779, 0.030801826287643053, 0.015195439355011331, 0.06503869793959893, 0.058753293415065855, 0.041990147801698186, 0.08262891889899038, 0.039837125441408716, 0.01886690235551214, 0.03808093686529901, 0.06111782415246125, 0.093071240989957, 0.0369365414371714, 0.02123700291122077, 0.00629633728749468, 0.02775291293801274, 0.07097256937413476, 0.03690541576361284, 0.010211684857495129, 0.02009668001846876, 0.004931434013997205, 0.03397504195163492, 0.06080323888454586, 0.057760021518333815, 0.025406698405276984, 0.0473965748824412, 0.05497744270542171, 0.04093491028470453, 0.05602602686849423, 0.005970211623207433, 0.010156420830753632, 0.05009388463804498, 0.01779917634848971, 0.04292624093068298, 0.03481567262497265, 0.05958438378002029, 0.04222169787681196, 0.02485528268152848, 0.07370699022430927, 0.05681717113475315, 0.05510796050657518, 0.05870613735169172, 0.05183226538065355, 0.044093791366321966, 0.013718236150452867, 0.06637533559114672, 0.035937376887886785, 0.012030726848024642, 0.009827456451603211, 0.07764070687699132, 0.02664971412741579, 0.03428226140385959, 0.012947443428856786, 0.024819863683660515, 0.02728145249420777, 0.042053297147504054, 0.008402598778047832, 0.0278107967460528, 0.035183154468541034, 0.05450030854262877, 0.016447519483335782, 0.02648838606546633, 0.016796928175608627, 0.028442531402106397, 0.08482252931571566, 0.01834281993069453, 0.021981876125209965, 0.09410979502717964, 0.04340511542977765, 0.053758632129756734, 0.05899245050386526, 0.054010249878047034, 0.03760570260055829, 0.02368185443629045, 0.058468486822675914, 0.046563220967072994, 0.03973464226874057, 0.02830442514095921, 0.033909462072188035, 0.023391891772917006, 0.09016912445076741, 0.07164445793023333, 0.04833362538192887, 0.0434338105696952, 0.009299197590735275, 0.05657660396536812, 0.04887390889052767, 0.025397412282472942, 0.03553785652911756, 0.0126323924632743, 0.06443736536311917, 0.0461005957913585, 0.04302381850720849, 0.04256584288668819, 0.022042292512196582, 0.06355406861985102, 0.03352482177433558, 0.07630694875842892, 0.03705819799506571, 0.057535143350833096, 0.0779100545332767, 0.030594370036851615, 0.016763874773459975, 0.020821940124733374, 0.016461421764688566, 0.030909710440027993, 0.01664033316046698, 0.013501159810402896, 0.05348114311345853, 0.013373360125115141, 0.03849874374282081, 0.02768538863165304, 0.02827354437613394, 0.013820543990732403, 0.008784321507846471, 0.034769982303259894, 0.028357113915262744, 0.04945104745274875, 0.05554746778216213, 0.008313775761052966, 0.060444106202339754, 0.037136639293748885, 0.06495603010989726, 0.06489639112260193, 0.04755909409141168, 0.03328023216454312, 0.006666461640634225, 0.012317626296862727, 0.01971565212443238, 0.16895260516321287, 0.041340000461786985, 0.03333902881422546, 0.04031317977933213, 0.08850355210597627, 0.03436346349189989, 0.021647455105267, 0.05214137359871529, 0.057400966761633754, 0.028766998366336338, 0.06742132594808936, 0.014962451368774055, 0.02138369767635595, 0.06596673134481534, 0.046555098160752095, 0.029852383777324576, 0.006332867651508423, 0.02044339842541376, 0.006476864709838992, 0.05383991214330308, 0.04954853226081468, 0.06795928653446026, 0.023718286465737037, 0.0800597298075445, 0.061873389859101735, 0.014757190947420895, 0.04144037593505345, 0.028111134633945767, 0.024952320345619228, 0.01674557897786144, 0.020845653598371428, 0.03613862136262469, 0.025113704068644438, 0.023172312539827544, 0.05228831883869134, 0.02275954670039937, 0.04846514137170743, 0.0468550074583618, 0.09661467702244408, 0.07312338755582459, 0.03624199140176643, 0.01601821117219515, 0.01750482573697809, 0.056500971695641056, 0.007588548123749206, 0.04921192004985642, 0.024440626220894046, 0.04301693137676921, 0.038513787076226436, 0.024171189506887458, 0.009202377004839946, 0.08564059869968332, 0.02144132915418595, 0.10080979292979464, 0.03208632806490641, 0.02289654716150835, 0.021906470210524276, 0.008383542281080736, 0.06391534610884264, 0.02498700276191812, 0.03323193690448534, 0.028123064657847863, 0.01692708789050812, 0.028523559085442685, 0.04827505137654953, 0.018465858738636598, 0.05441086119390093, 0.05471539407153614, 0.028337090770946816, 0.010649998203007272, 0.025384849577676505, 0.021018317966081668, 0.03464140521828085, 0.051962037323391996, 0.0331669655861333, 0.09298290315200575, 0.04841668654989917, 0.04285716924641747, 0.017830819670052733, 0.03357048612087965, 0.016182912295334972, 0.024924864592321683, 0.05325426856870763, 0.04103261773707345, 0.01451915450161323, 0.06805014767451212, 0.02857840750948526, 0.026888973261520732, 0.011036657142540207, 0.02670758309250232, 0.018085420852003153, 0.03583670826628804, 0.03127945768937934, 0.06952525523956865, 0.04429337343026418, 0.015532740835624281, 0.032005946050048806, 0.027440409394330345, 0.046346398812602274, 0.028803922068618704, 0.040824244933901355, 0.014649636123067467, 0.04263552313204855, 0.04595789192535449, 0.027866025520779658, 0.030417692505579907, 0.024034921916609164, 0.02233825172879733, 0.020245091000106186, 0.038743552286177874, 0.04314064368372783, 0.02465932415361749, 0.05150706369022373, 0.03918018002877943, 0.09581657141097821, 0.04625810179277323, 0.02801048271066975, 0.04398125209263526, 0.04740496115118731, 0.058113510167459026, 0.01675325278483797, 0.01949210240127286, 0.03899732226273045, 0.08167429434251972, 0.025142616286757402, 0.017044226624420844, 0.04772708663949743, 0.016881191622815095, 0.027059268322773278, 0.0017577397807144735, 0.04358134952781256, 0.021747817590949126, 0.057829416036838666, 0.034106097809853964, 0.06253397179534659, 0.029448928180499934, 0.061493013199651614, 0.026320872202632017, 0.07313899492146447, 0.05619500647298992, 0.03713008241902571, 0.03574786947865505, 0.11236837191972882, 0.11589685367653146, 0.11600309211644344, 0.12950836156960577, 0.24287107778945938, 0.1300847134552896, 0.1458555890712887, 0.15187572775175795, 0.10737551405327395, 0.1442481714184396, 0.13242360670119524, 0.09597645970643498, 0.0816106254933402, 0.10198821211815812, 0.11563399981241673, 0.14129896560916677, 0.12790784589014947, 0.12389653769787401, 0.1736130253993906, 0.07685517324716784, 0.1337574390345253, 0.17766014963854104, 0.15423237317008898, 0.1670683070551604, 0.21555095940129831, 0.1907478497014381, 0.13584490749053657, 0.13282666710438207, 0.10319302949937992, 0.19701212528161705, 0.14354814804391935, 0.0559879880893277, 0.06834931482444517, 0.17168740450870246, 0.23301592067582533, 0.12000036629615352, 0.11366411723429337, 0.14117055921815336, 0.23282462469069287, 0.11659026451525278, 0.10648252486134879, 0.148745512124151, 0.25182495592162013, 0.17834858066635206, 0.17483173578511924, 0.10652628188836388, 0.09934115689247847, 0.2944312384352088, 0.11572846779017709, 0.11788857766077854, 0.11633289512246847, 0.175844544719439, 0.17716197558911517, 0.08392089410335757, 0.1427714608144015, 0.18811451678629965, 0.126092953432817, 0.21248213422950357, 0.17303011292824522, 0.11414862834499218, 0.11870843562064692, 0.13680345058673993, 0.07378771362709813, 0.10448937595356256, 0.11397760041290894, 0.082661313645076, 0.13157095323549584, 0.18415397149510682, 0.14943572430638596, 0.17307560658082366, 0.20352835999801755, 0.1766641132417135, 0.12806773418560624, 0.15286538167856634, 0.0916460576991085, 0.2161708753556013, 0.06529692080221139, 0.1728733564959839, 0.03880339536408428, 0.06768175298930146, 0.22499746031826362, 0.14193074108334258, 0.11069851738284342, 0.08685734239406884, 0.22969549259869382, 0.2124624524731189, 0.16960529435891658, 0.15182591479970142, 0.12441839367966168, 0.10083412053063512, 0.08033344871364534, 0.20711158256744966, 0.15621876111254096, 0.1909931591944769, 0.11462456022854894, 0.1505848509259522, 0.11122772062662989, 0.18049910198897123, 0.22735898906830698, 0.09897607960738242, 0.14580387622117996, 0.10637213781592436, 0.09639973621233366, 0.11702310730470344, 0.06211964559042826, 0.07486397618777119, 0.11277080891886726, 0.19592507189372554, 0.0733067499822937, 0.14649900142103434, 0.14390757016371936, 0.13016658718697727, 0.0851481688732747, 0.1576872932491824, 0.15427111327880993, 0.08360569656360894, 0.19393641297938302, 0.13998006528709084, 0.07307923719054088, 0.2764630119781941, 0.11310686080832966, 0.13212958263466135, 0.1611673424486071, 0.09795368212508038, 0.09781895263586193, 0.14045040879864246, 0.12909749377286062, 0.14802184392465279, 0.13188998767873272, 0.070392306370195, 0.1366090078954585, 0.1369741148664616, 0.15648971922928467, 0.10143269973923452, 0.1193861648789607, 0.07305396706215106, 0.1805967537802644, 0.09366410566144623, 0.12588682933710515, 0.13543478184146807, 0.09857655182713643, 0.10033064012532122, 0.11525620953761972, 0.10071593351312913, 0.12277340108994395, 0.16470314178150147, 0.11682776661473326, 0.09306136300438084, 0.13421690266113728, 0.14691561344079673, 0.1276284718187526, 0.13434483407763764, 0.14501359284622595, 0.1160145434550941, 0.08576884923968464, 0.14296306850155815, 0.09975194305297919, 0.16529654822079465, 0.07650645289686508, 0.10693090080167167, 0.08668192094773985, 0.14032290782779455, 0.10643043351592496, 0.13368053769227117, 0.08647294700494967, 0.12051266341586597, 0.07578866250696592, 0.14840632095001638, 0.10817353802849539, 0.05551019341510255, 0.08664165943628177, 0.11850639333715662, 0.24297350901179016, 0.21953620336716995, 0.14514357259031385, 0.13432451407425106], [0.09639404393965378, 0.023622239568794612, 0.042287448450224474, 0.05072826876130421, 0.06850264253444038, 0.04301362881960813, 0.0849360111169517, 0.0039367548197333235, 0.08163427773979492, 0.04989430999557953, 0.05175586869881954, 0.049171113059856, 0.031770841087563895, 0.02378912817221135, 0.044160016914247535, 0.06047722083167173, 0.05574355061980896, 0.025576245752745308, 0.032186447497224435, 0.053739503273391165, 0.060381647053873166, 0.029947228395030834, 0.03684733899717685, 0.08760766111663543, 0.024999231500260066, 0.005364946127883741, 0.022359851936926134, 0.07229312468552962, 0.0873932323884219, 0.020087930097361095, 0.055348483147099614, 0.0454926766542485, 0.03415979219425935, 0.06635942394495942, 0.0397664841148071, 0.0408907191012986, 0.036971904773963615, 0.03279046664829366, 0.045958737973705865, 0.08007319978787564, 0.039935252207214944, 0.015281269661500119, 0.008483067995257443, 0.11278085759840906, 0.07552424271125346, 0.022435946193581913, 0.07154886188800447, 0.051274533980176784, 0.005317101722539519, 0.015241244709613966, 0.056859403048292734, 0.016241874072875362, 0.10479875505552627, 0.015084414062584983, 0.06899370680912398, 0.033587499856366776, 0.037594911773339845, 0.04371103612356819, 0.02601221298391465, 0.07924456964246929, 0.027333992838975973, 0.05892924178624526, 0.05909523053560406, 0.01665022598899668, 0.018188314061262645, 0.035119385429425165, 0.04603277091518976, 0.008745306804485153, 0.016670935619913507, 0.03547288150002714, 0.041104171905317344, 0.014686470767628634, 0.06092529249144718, 0.01315204333877773, 0.04845479583309498, 0.022382804709195625, 0.04308494921133388, 0.002893548212341557, 0.022830291927675717, 0.02775195742287906, 0.02056325156445382, 0.022061805429984815, 0.03620668372604996, 0.04839861525397282, 0.060838988138129935, 0.044939379586139694, 0.018248346386826597, 0.008708307032065932, 0.0064755065795907285, 0.08129572481266223, 0.023396776959998533, 0.020055513086845167, 0.032198440603679046, 0.04525739357632119, 0.004745860451293993, 0.0890627306944225, 0.09503894907538779, 0.09589883105945773, 0.06137976517493371, 0.02774587737803813, 0.011629506971075898, 0.025196449823852163, 0.020843731435888913, 0.07731218036497012, 0.012346874336799374, 0.023657155761611648, 0.058722720641526394, 0.030689149716636166, 0.0347983100800775, 0.027024446753785014, 0.05891858825634699, 0.06752370522008277, 0.008612536585133057, 0.0038330125471475185, 0.01871046690212097, 0.047450517886318266, 0.010290462905686582, 0.02322301977983443, 0.02369319074205123, 0.04377580335130915, 0.022541307043866254, 0.05250896305369679, 0.01649541769438656, 0.012866809083789121, 0.024203211323765572, 0.06197239978064317, 0.05168204355868511, 0.022695415864291135, 0.014034464347787434, 0.07712656923104078, 0.0279840678194887, 0.03495606470096391, 0.08777284092502668, 0.07255429387441836, 0.027241558345849626, 0.02814916970237391, 0.07582408521557227, 0.014301452902145684, 0.011476315630716272, 0.035226844702265225, 0.022859924029035028, 0.04046128648042213, 0.04165717582509387, 0.025472109446127433, 0.04144146318139974, 0.027426739034126513, 0.013303840369189857, 0.09449304750887677, 0.06934902485227212, 0.03128372132778168, 0.04031212592963129, 0.046050441451370716, 0.020992587706132326, 0.04346574889495969, 0.019343197891430464, 0.04876936996879522, 0.03398574372113217, 0.04083241969055962, 0.029097786573402118, 0.028885884858027566, 0.04035611302242614, 0.010430937545606866, 0.07209126793895848, 0.04058780781633686, 0.014472612565441523, 0.0067778691391140455, 0.027984038133581635, 0.007925184454506962, 0.06500860385131091, 0.0240187579402118, 0.04602163870004006, 0.07358910006587394, 0.009989113841584185, 0.07606105296872556, 0.048342238005716354, 0.05549292363866698, 0.046293461418827064, 0.019388068139960524, 0.10756179312011227, 0.011365752325218637, 0.05617493879981339, 0.02345954409975093, 0.16467774548800662, 0.04933140582579654, 0.030395561661862303, 0.0500306722096866, 0.031204901533783413, 0.09220180756528862, 0.021274397877277806, 0.01995073111174861, 0.05449465708807111, 0.04769433195178863, 0.04571033743559383, 0.0472609511052724, 0.03447306386078708, 0.013569620150519768, 0.01347269937468809, 0.06913714169058949, 0.1023357079247944, 0.03963837087212596, 0.09637970564654097, 0.016982934503175784, 0.03894865221809596, 0.03569216016330756, 0.008152830832841573, 0.054343151350622065, 0.08167459120159037, 0.050265035024494864, 0.024802779444144107, 0.023810127240722068, 0.010588450040813768, 0.03254644478147384, 0.07261417777044699, 0.0456326828134479, 0.04867417097557336, 0.05328946863301098, 0.029402506843325682, 0.03277388335845899, 0.07551855043857358, 0.021398108328867238, 0.06795496723498218, 0.023932043550303206, 0.050214301809319295, 0.0089456124624121, 0.03536947064276319, 0.0756036450911779, 0.04721021046862006, 0.020220086189510766, 0.0708264479180798, 0.030768641154281795, 0.016114232093968894, 0.06253340034163557, 0.054537987380172126, 0.016683316498529166, 0.010635317594278604, 0.05319849988154601, 0.06274140949244611, 0.01919824531796621, 0.009148593562713359, 0.05197653517825529, 0.05028391155065037, 0.009957730271707987, 0.026454375292814802, 0.025141955775325187, 0.033975713595282286, 0.0551122055912856, 0.01554069109261036, 0.0390698375122156, 0.046656887425342575, 0.05837257165694609, 0.005108794784973725, 0.022745212118024938, 0.028898781529278494, 0.020935863503837027, 0.04334303848736454, 0.05172521428903565, 0.015564794193778653, 0.09512491204077378, 0.019644988533400465, 0.03171690179442521, 0.04522336239460856, 0.04287806812499184, 0.03179525774612557, 0.0335641889978433, 0.034293430726393126, 0.01149954114225693, 0.030876235869072843, 0.04720773911685683, 0.052226390325813554, 0.01953941802639747, 0.018325819182791747, 0.04513624538958538, 0.09159709079540335, 0.09502933084149845, 0.08568230739911087, 0.06351846779580228, 0.021820410765940323, 0.05176641090656631, 0.021464090823428705, 0.03785608096222859, 0.0334038220171351, 0.04710248402261641, 0.07498113162000664, 0.04489185615966562, 0.0628162402426824, 0.022157687199069187, 0.03810423288086895, 0.052900052614859305, 0.025243056697945576, 0.016075326857389882, 0.049831850847112946, 0.044400031183613464, 0.04184555888059549, 0.004286676521587651, 0.0477615297131706, 0.04214924942061771, 0.03320098934636917, 0.05964892465271987, 0.04636738674889784, 0.061227075711940415, 0.03515733886160888, 0.003438956018726458, 0.0410190846741898, 0.021006137467338704, 0.010890345511143096, 0.053531883750110865, 0.017046456778189167, 0.06586735777091235, 0.11717464643879794, 0.045604722399730235, 0.01647830747970147, 0.056408637392451055, 0.0065228319454035955, 0.05546163098188117, 0.061874952079961076, 0.05860191013198346, 0.028156997504993342, 0.03731139651790727, 0.04743264325952623, 0.003538704377206159, 0.045454827122739516, 0.009327351890533464, 0.035312933832756244, 0.06480561904027127, 0.05210882671235595, 0.03248246051953174, 0.004907765069219749, 0.021591519434878137, 0.03354999913426582, 0.06550692633027211, 0.06505829805973917, 0.06368479051161557, 0.03606947175285313, 0.08342744753463194, 0.025970815986511298, 0.027298969034745824, 0.08609491924289614, 0.027297239830659237, 0.09276264856453054, 0.02991490971908206, 0.01753872333210893, 0.01155088291852735, 0.03857019401038997, 0.0038882874741830165, 0.027348668809281662, 0.022641101786575746, 0.016500514393555932, 0.006936564896022901, 0.004983345852451748, 0.0435582353384234, 0.021652685391018167, 0.012432618368620751, 0.3133933193748817, 0.10620582252158783, 0.19530902995029464, 0.09951879736036062, 0.2960464486386627, 0.1126997557003051, 0.13465968280797824, 0.10175902207265608, 0.14332790829939768, 0.15159449831116945, 0.09505611495114863, 0.13478237466188148, 0.10640980181051418, 0.11451835147454403, 0.10764722916064784, 0.1515563519205898, 0.12235779096954502, 0.15249960677465424, 0.19996737217297778, 0.17548641393659636, 0.134500031999778, 0.19688554457388818, 0.20614995213691145, 0.1979997308808379, 0.1964285151916556, 0.08642062559374608, 0.11140841874293983, 0.09110229351790622, 0.1948061803705059, 0.11064814039855264, 0.1719370629871264, 0.15857723221415654, 0.1012312808597926, 0.10245543860946782, 0.0917326366470661, 0.10292327366187237, 0.14395385049283504, 0.13149599632015452, 0.1256485702469945, 0.18226115353172645, 0.1627483544871211, 0.13447324046865106, 0.19074416864896193, 0.2546276617795229, 0.24682880291948095, 0.10157541473745368, 0.14896077947923914, 0.14968309696996585, 0.08999081604997627, 0.18748125701677054, 0.2849405352026224, 0.09029201668454334, 0.22100368165411055, 0.0805879979452584, 0.21410530025605112, 0.15760251029860228, 0.15124769270187244, 0.10602853828459047, 0.15077402436872944, 0.1370701487758197, 0.14052840851945803, 0.1120567812176887, 0.09725140262162313, 0.11883081577252597, 0.12121607840526849, 0.11986802652245387, 0.13288195710629225, 0.12111707590520382, 0.1559944692417048, 0.112600894208299, 0.15898590325377882, 0.14781989069888368, 0.11354826056049205, 0.11112848806078546, 0.15033943753223866, 0.17344623513054103, 0.144593121658545, 0.11006739499862306, 0.0989385046705138, 0.12112199634429999, 0.08106583714834414, 0.11640735479886644, 0.1673768475302495, 0.06578722066478804, 0.1137087277311366, 0.20759952982189134, 0.17447587597416714, 0.16213094699196517, 0.07403453710139729, 0.14973933692090213, 0.10815342582645826, 0.12047803480527364, 0.11934775131521747, 0.16476748598506674, 0.0989359591039829, 0.12598727160366252, 0.18250171327963471, 0.20627200574381277, 0.10408029673271812, 0.12200674769701436, 0.057743163633858785, 0.1381645939545706, 0.1251887800754048, 0.1042447195504792, 0.10288144621881656, 0.13966598839033395, 0.20446162554435432, 0.13122615142492577, 0.15556144091533497, 0.09562805105815642, 0.2118303207680583, 0.13931373541709036, 0.14787828287808225, 0.1259220071369782, 0.09822204272495583, 0.1755090494407341, 0.1479059798293747, 0.14587642857804894, 0.09346880207885988, 0.11216290833544917, 0.1143090806726832, 0.2076786130783148, 0.10904887152719311, 0.13213416910730302, 0.13727193872909993, 0.1076972795999609, 0.12993407231988385, 0.0967518259130884, 0.13456225366098806, 0.21286862989654765, 0.08463494406896643, 0.17850328877102584, 0.20177671336568892, 0.13203990150941536, 0.1331160156405531, 0.17808968987083063, 0.14999040547991171, 0.3351838141679764, 0.16476761957164854, 0.1545100551447831, 0.22635483357589692, 0.22218460188014433, 0.12184531573439017, 0.11265131572145037, 0.15188037359621376, 0.08762352823396213, 0.18563647085102275, 0.16262552904663607, 0.22222193190827966, 0.18751270923530683, 0.10427626824821346, 0.15306841843994334, 0.10610932105919346, 0.18726020090980455, 0.11159184796269983, 0.22637611837126315, 0.12138406353187747, 0.16242802870692685, 0.11476297077024356, 0.09044437960255891, 0.15356724557932466, 0.07484096218831837, 0.1784162496915087, 0.15029093076009303, 0.12377328923321329, 0.15727574267657474, 0.12247154736542143, 0.10059756838018075, 0.16624921350739896, 0.07732233294518664, 0.129167300183326, 0.14642098685726523, 0.1360435358947143, 0.19700149772688746, 0.09899850731017068, 0.17300605250056833], [0.035184705557185225, 0.04700708836026024, 0.04796802859345917, 0.03887480481353123, 0.00898123833394493, 0.07366499208728783, 0.006051717064110562, 0.04108600041945465, 0.028353950510791037, 0.06453685025917366, 0.03768221431528218, 0.030319684483401943, 0.03313746150524821, 0.013000431845284766, 0.024742452114878688, 0.01938233875989681, 0.030560058694391046, 0.060587507687159814, 0.04326256370404735, 0.021820904294145294, 0.0032832866008902784, 0.02835095780028496, 0.030577796023862902, 0.04192539541691076, 0.017540038788865786, 0.011512483270053053, 0.011125595192424953, 0.016985782494884916, 0.06371235387632623, 0.0822747808706481, 0.04273410631867591, 0.0395928364014253, 0.026903218786173966, 0.04144515907682944, 0.04391334929096047, 0.02166797548852628, 0.06451558030676097, 0.04775893219630234, 0.07272319184266962, 0.03327792037453037, 0.028594547366083134, 0.04298564243072178, 0.07816415847628377, 0.057105777523247525, 0.028779844942619093, 0.02707553248910699, 0.039175638084998354, 0.08229396538808942, 0.024358518712688237, 0.05920440045883879, 0.04189367973594926, 0.02233000090200221, 0.03713277641509194, 0.09793401521164924, 0.041821053164312616, 0.027060342581535224, 0.047017916294862516, 0.03398112014110666, 0.03182445012498647, 0.0741581417969428, 0.1345199512434192, 0.03403963848541025, 0.07990344092831947, 0.0385800794174429, 0.05090067337732762, 0.01852391695138067, 0.03149190488329623, 0.06447905921959318, 0.06514639098895714, 0.017240207416762132, 0.07668618622119538, 0.038975603310973383, 0.015179838483163621, 0.05826958382385783, 0.045667174126720056, 0.060435638297349215, 0.02651698472618591, 0.032255678743240424, 0.04800959999556653, 0.05191466974793002, 0.04519473033724353, 0.03156060178298503, 0.02744782716035843, 0.025514781082165428, 0.014699030689371284, 0.03671774145914242, 0.027559023146750405, 0.05338077506166883, 0.02705893621168798, 0.026725723037088756, 0.025125459687842522, 0.03871281252941117, 0.037707948285969906, 0.056164374327636324, 0.009803966549952747, 0.03384724412171636, 0.08076808007899672, 0.05481215899635572, 0.022649510319752153, 0.026901771598204505, 0.021216018685663585, 0.06809540383983403, 0.03881852033373434, 0.044813789645559154, 0.0645538380194921, 0.06244466174393892, 0.043695822096196935, 0.03926442492229398, 0.052537784358719364, 0.01944170315255178, 0.042018894891953096, 0.024298232201545034, 0.02227687611593865, 0.02863529498426942, 0.055519210509373806, 0.050009127662633546, 0.04927683941787109, 0.01575502334162593, 0.04270466903108172, 0.017189752506965306, 0.026752056292025372, 0.03177062586473767, 0.05173036850464996, 0.011495567869133083, 0.020944086500094272, 0.04191298670775723, 0.023478886323573533, 0.045620203600265086, 0.013730543741985457, 0.021698451782867778, 0.03092119331995491, 0.02122014317137655, 0.042140685036429204, 0.10831712876097299, 0.03571885892597493, 0.030677969261887483, 0.013587528173957253, 0.04837282562220935, 0.009273748419218464, 0.01845798826252576, 0.021490279359568376, 0.021111299793119542, 0.02833055430528475, 0.022584125254070386, 0.0374124881636817, 0.008600780965934973, 0.03051923129532952, 0.029438912897603586, 0.023107198358047754, 0.04769664374180138, 0.042369915900053456, 0.030530667791026644, 0.02767518410109915, 0.03582704179279972, 0.08076778321992606, 0.05768491988419555, 0.09426678152522072, 0.062050841079326347, 0.0670456062653102, 0.05229706504906062, 0.05211447074543685, 0.010700679467845475, 0.036089557979721576, 0.04114186929655261, 0.037517899108934216, 0.019143094468745403, 0.011337322503095493, 0.056294131427421235, 0.03328564242110588, 0.054625579359708354, 0.01703987392829731, 0.08258309870143421, 0.036669000910478644, 0.05198582686716691, 0.08299108696519397, 0.04601979446306359, 0.07359626921243034, 0.028903828133479692, 0.051599928629002534, 0.051661267134477384, 0.00810652731161099, 0.03266333675128408, 0.05602327721135225, 0.0807883555535227, 0.018079145993397105, 0.07867073363740928, 0.050510225773905404, 0.0155546471796697, 0.043752663186751306, 0.05266480664431583, 0.01932433991896687, 0.006232861396711087, 0.021490309045475442, 0.02311584808921907, 0.07374541120952927, 0.03176537516992539, 0.0009975195325750974, 0.016790029912954196, 0.053238909822539426, 0.012746331613016082, 0.039223469502758235, 0.05073761240055319, 0.018418140498397406, 0.03480300416413229, 0.02884325775085017, 0.04869459487963468, 0.047313324466813356, 0.057230840538977645, 0.014171183720463887, 0.05501534047652967, 0.01778095291228965, 0.022193451295606792, 0.01672527752816677, 0.014944296581234084, 0.04341310836025514, 0.05281744786771014, 0.02013628472923301, 0.031595720211043954, 0.05952674488071352, 0.030526602677127812, 0.009380970204801997, 0.0471535215183394, 0.03205201486707665, 0.03543058279319666, 0.032835745078045875, 0.04431423520145472, 0.021192186468397267, 0.04004520509624854, 0.03981847898103297, 0.04914819553960115, 0.04475791705772281, 0.010150262860406656, 0.05366417157347314, 0.04954952673870139, 0.024337638387805782, 0.016430169926024973, 0.06335487618343905, 0.0058396024451212725, 0.03905772195139434, 0.016866569458215963, 0.019168756080034655, 0.04246587930538226, 0.04197704518446699, 0.0833939692529384, 0.03676347259897739, 0.004716681523859734, 0.03540465215337463, 0.055694557740935124, 0.049248307550442405, 0.03588797953852918, 0.04753460692882072, 0.04810983446077444, 0.030503026500809938, 0.0366785931691993, 0.013763095266767778, 0.043821653234772384, 0.04973830684321001, 0.025086804926104378, 0.02506065535271773, 0.036338259087642655, 0.0532676643342711, 0.005046821743235341, 0.06568529410287738, 0.07145980416680686, 0.02008192241191864, 0.01977653977519367, 0.01896000849228585, 0.013663263416674454, 0.040473398330505006, 0.06856834486825392, 0.033734044336597435, 0.04137813572015148, 0.03857118106679991, 0.014562466240022331, 0.04581840526952874, 0.03558064876415301, 0.014915873252903111, 0.06409184366930276, 0.03892374945280608, 0.022360471630236134, 0.009470555778534617, 0.03699898203194607, 0.01791217760910513, 0.07613432520884089, 0.09669630584539846, 0.08274528765468858, 0.03974205261329189, 0.04261816429789178, 0.04361980390967801, 0.05244066320301499, 0.0751227630826179, 0.012911221983813448, 0.07253007017425261, 0.01745846377161797, 0.03933845415303949, 0.016939522574830335, 0.042021084227599204, 0.017888575457618572, 0.036455562949413434, 0.036916395838488825, 0.01694960279564839, 0.03659234076621942, 0.05854163289768621, 0.020616495094145648, 0.07425380463246256, 0.018732299031398725, 0.01961232290341286, 0.07914658388472162, 0.08571503611165099, 0.09118070884142071, 0.04880866668827366, 0.045198389125289395, 0.042338322673458606, 0.043277050426695496, 0.03138148444122635, 0.01454841738450341, 0.02861111210222589, 0.008770273580012145, 0.030118731301627122, 0.018143820452678483, 0.08113823365420103, 0.029189551278250292, 0.016661751542415004, 0.0192039357352769, 0.01235575227838126, 0.07707796597969718, 0.04688014028943144, 0.03170854150084779, 0.017391254878020845, 0.04449501866474748, 0.06766074278857559, 0.07647410267964005, 0.04901453103229869, 0.06593186524696648, 0.008804473600321217, 0.0828933683806099, 0.09264150037779473, 0.03415880513784941, 0.059029654366895556, 0.05223014559305739, 0.01129617319747922, 0.013032428614678793, 0.01828285625379067, 0.043431135127320886, 0.028875724856334273, 0.04107213710085489, 0.055711552922730334, 0.06886501840199344, 0.03800331563979853, 0.029280032067617867, 0.042994425748474896, 0.12477240554289892, 0.17218783468706533, 0.2072751964442432, 0.12614854029379785, 0.10205065642367117, 0.17812112724641338, 0.1815606700256467, 0.10512133696465753, 0.16036316606914625, 0.10118846636032686, 0.24818190140649676, 0.12933892925502732, 0.11027523345546797, 0.1666074778768234, 0.08339198029716499, 0.16066838172264397, 0.12971607386134565, 0.1043785065121483, 0.15177972352830693, 0.14472733164438978, 0.1379551153513603, 0.16952619625953957, 0.11202054214663804, 0.15508912329096347, 0.09959375427570194, 0.13397990522207692, 0.17256913532037288, 0.10570350728812627, 0.22237025754293427, 0.13865782530047, 0.1471849685185589, 0.2821960434084758, 0.12797037925338373, 0.19890592287993059, 0.09946056845365092, 0.2498195244697854, 0.06076206082070712, 0.16058419249020517, 0.09263160754926503, 0.22206945024663582, 0.1606688863830641, 0.14041678950889036, 0.12548770231660455, 0.10276552275172435, 0.13084833888569847, 0.10767375351861119, 0.11569282985874452, 0.09303955870564096, 0.22473796096164733, 0.07408476565615274, 0.143749670824036, 0.18126296490663663, 0.1938866445561871, 0.21703840146074072, 0.1810669043334201, 0.13405279896687716, 0.1493145464337431, 0.20483269938267767, 0.16242960206000134, 0.12832153384806588, 0.11040300159947947, 0.2321728557581082, 0.1077686964708846, 0.16363535454729572, 0.10465699000633322, 0.08663633823744021, 0.08492639288306236, 0.18446965143084526, 0.1712719353963621, 0.23163196368841454, 0.09069543331861496, 0.15917133627226576, 0.12226771650603041, 0.17509534663986415, 0.15177044668234885, 0.14296559180365875, 0.11582142178667709, 0.14719892089487985, 0.0931904224853497, 0.18301290459930897, 0.20708300988189876, 0.166017129085958, 0.112273473496316, 0.11308590255794115, 0.22037704184185714, 0.10364778790972196, 0.12406767695210874, 0.20062337134731933, 0.2266130267526023, 0.1343176863156259, 0.129366269975435, 0.07590685694594868, 0.09886480198474601, 0.10867376782698557, 0.2198281791061163, 0.21389708330389112, 0.07241349361720495, 0.1155907845532056, 0.15931488247588277, 0.24268778215628117, 0.14310403203126043, 0.12575022963574156, 0.18192896823165938, 0.19185244746040553, 0.15552624827250838, 0.1762178895296529, 0.10528784521738999, 0.13373861816944554, 0.14949355245335028, 0.1886571157956496, 0.21357543650083244, 0.09407808305695653, 0.11616134768701158, 0.19214667932828888, 0.10348479001550004, 0.21706085884943604, 0.09503560198936611, 0.16325403907103464, 0.08926316993893124, 0.13756643777014688, 0.09563738727592863, 0.14005656586959958, 0.17371371999615803, 0.10344636160880327, 0.10694330208934844, 0.1416594861075282, 0.15968834602972493, 0.19740666582947597, 0.09997313274652697, 0.19148410472553223, 0.09559190846630372, 0.14329099387396127, 0.12929447460919619, 0.1697132916888222, 0.1229967875406146, 0.1434345549205318, 0.17549592826981097, 0.10236207643174566, 0.09454124257899821, 0.08195187241653912, 0.11418632944696583, 0.17148313578218222, 0.17857388185802847, 0.08031856865272857, 0.07077015601680614, 0.16985182097414508, 0.10354671481763944, 0.06787058504414745, 0.16999315557768568, 0.07776446742354892, 0.13188645505579188, 0.15317188866902143, 0.1625180512201041, 0.1159065164392814, 0.12275915185455233, 0.15233744750730693, 0.17445239442167804, 0.17841544817201793, 0.15022240084363148, 0.11880861813551746, 0.12816341186407954, 0.21173799759708345, 0.0856353814015165, 0.1551031053531915, 0.17200489528477192, 0.1083366695092991, 0.11488571457448415, 0.10177425094298087, 0.17598832841031253, 0.13768633914878592, 0.14713058393681422, 0.1840304335928522, 0.17109123728005216, 0.1433580691809766, 0.28950147796422243, 0.1915551579440944, 0.24722951813600957], [0.030901641439413652, 0.1049440675706137, 0.018616173329064623, 0.028843181680713315, 0.026062066754093394, 0.030876259988872334, 0.03460471343714744, 0.06635231417021714, 0.009520837211312028, 0.010857395081984578, 0.04088349058292806, 0.023178290539362933, 0.0539699994988041, 0.034445140554453246, 0.060271571710472926, 0.03509346592181828, 0.04667850247642491, 0.04984507220797241, 0.07012774556642398, 0.04781844501849264, 0.04037695252918638, 0.04691208232543431, 0.05526205262867734, 0.028455676692829, 0.013257994196465006, 0.028806265399907716, 0.054257232914096676, 0.04147868188738357, 0.03300346674222965, 0.009375661993544782, 0.043040683813160285, 0.010019634664786281, 0.03611971143982373, 0.044757100695278496, 0.03129491662548389, 0.01716854007099755, 0.04902055727143306, 0.08634251455077901, 0.003334908769829781, 0.045210003736428916, 0.03614495930378325, 0.03571284010831732, 0.034931837290059775, 0.03126095594780054, 0.0342781647486845, 0.02247350443212781, 0.014303050375019666, 0.047979205337469466, 0.03404291877814103, 0.03621460244175978, 0.05363666386983823, 0.13216636347351596, 0.02480881681549363, 0.07509605318773538, 0.014154353666526731, 0.06092330353567377, 0.012630551937036216, 0.07110936945537105, 0.05531173570489045, 0.03865578219119925, 0.019958703633164987, 0.08207785940612666, 0.03842758291284554, 0.05854566647030879, 0.07728950775344856, 0.04949228859914001, 0.026548720816208515, 0.014905665939295432, 0.08132341434247792, 0.038915003242436796, 0.01302912049141014, 0.010133613704965683, 0.04923752414470073, 0.04529394434939604, 0.006991036680119578, 0.026110241415153723, 0.012301616316108266, 0.05091879291285295, 0.021250884783512447, 0.015324853211495792, 0.026778773608384654, 0.07445716051734053, 0.04139201759244315, 0.023249698133440688, 0.017918918165378273, 0.06960839804378338, 0.07927214785013348, 0.023228357676998712, 0.0242213531237212, 0.007146049065340776, 0.07111561833880842, 0.03004152011271799, 0.01938856723427307, 0.01517012933618389, 0.03931491322873626, 0.0289574074849952, 0.06471475790021941, 0.048819056755746715, 0.04862043206230737, 0.005747845625592163, 0.029146773886168376, 0.03006348582857754, 0.03724480360688176, 0.053707175320596434, 0.013915970266680233, 0.0777278647001367, 0.033133082833955996, 0.02642233121150639, 0.11245966350543313, 0.04345544417446945, 0.032491804158780724, 0.018592133310448844, 0.030677811555506196, 0.033529545544297434, 0.09157613996649161, 0.010756290448625805, 0.021709571010433137, 0.04346049448940903, 0.09443413582630455, 0.017029209266183898, 0.054844238329678774, 0.029685309636988677, 0.052864603931084275, 0.01676723113632761, 0.030506514594890177, 0.029596680506074335, 0.05723854774259962, 0.04914622142678127, 0.06134998278866988, 0.0857272295979783, 0.0073175598572561285, 0.020866914273938164, 0.05471101540024392, 0.022430747449107002, 0.021884730849706102, 0.03708936448674649, 0.07170470547862351, 0.014059656550671207, 0.048858579830266535, 0.043031306777265854, 0.04157908333581872, 0.00914639123948291, 0.0438613321603043, 0.06534714935696684, 0.005208015754760709, 0.04890897536824923, 0.026235746008751448, 0.024613622699689586, 0.00898685546417255, 0.014172371156746522, 0.02398597171122674, 0.03566380270058289, 0.03927395409846213, 0.04115202187676914, 0.07469031363143586, 0.04405720348586328, 0.06852133723441511, 0.02169252202293137, 0.040656493583810516, 0.04280366782040801, 0.006081586652726401, 0.028304410298005678, 0.03359555215865839, 0.044174993454362266, 0.025259858921344858, 0.01485520546339103, 0.015854682642384432, 0.039546329717268236, 0.04173386194452178, 0.017671135465207044, 0.03232016766560264, 0.01546493544083205, 0.0022299670717984554, 0.03195970282831695, 0.053935189062030986, 0.03668455632578116, 0.02987824205774814, 0.10709367605159059, 0.10981766972690821, 0.008609999367763521, 0.07630305990460329, 0.012085858215868939, 0.017295348989136983, 0.06376257500960492, 0.03349466460349504, 0.024183223431464285, 0.025710797126521356, 0.020662007300416008, 0.0629513556486927, 0.023571508208988234, 0.031597018969478086, 0.04216867884679232, 0.01080289453966543, 0.0178903399137198, 0.02301614425959997, 0.04468457802431658, 0.02015921152633382, 0.01082596048945561, 0.03631101113569457, 0.031216445640893653, 0.03139328087854665, 0.0528989468148211, 0.009936631013260921, 0.06677779485471547, 0.02572733588749543, 0.006499086930489284, 0.019821994465019088, 0.010067961466120323, 0.038962545222602785, 0.04753877037728671, 0.03043136286578374, 0.02909418715717038, 0.05972311715595424, 0.08034067723201588, 0.014909454603184713, 0.041448628617217764, 0.053361605387181044, 0.0712218790431507, 0.004753394641738851, 0.04547382610326167, 0.08456042502075434, 0.04195705914753489, 0.04190539082628675, 0.014370099706866313, 0.02778443380520912, 0.039059020709828474, 0.10303476650733501, 0.08800662486464716, 0.07079084709403105, 0.056815189600456506, 0.009712959763419349, 0.03730869138962589, 0.06410183297703043, 0.07652462809346616, 0.047390682229888625, 0.03401334419322666, 0.01885317818960175, 0.02230451184004778, 0.04227432356856298, 0.07553590185125358, 0.055347484958474524, 0.02658905097632669, 0.027581179965636693, 0.027538653048395645, 0.04911420888674911, 0.043020337834605016, 0.06815297965658829, 0.011294410596747184, 0.006982939385125064, 0.018174725337303244, 0.0400657737191068, 0.04785486220498569, 0.014491703386738664, 0.03242969381972216, 0.03616208807216026, 0.0596354620938655, 0.0177654271828942, 0.03798526660830248, 0.04291158722480759, 0.022140404435049277, 0.03339594783028588, 0.07924002027721144, 0.07136091298889369, 0.04674191528465599, 0.013323580569704063, 0.028331734320090618, 0.04912778276775498, 0.04642519634217024, 0.047449367557419464, 0.024719337925489526, 0.049916722855414264, 0.04826929602131713, 0.05497573205502704, 0.03269870750955306, 0.06827812059782445, 0.013087200040899916, 0.05606078906566836, 0.04333932032750454, 0.02043461696302984, 0.03704412687511649, 0.014210977678885683, 0.06088879737944808, 0.049109084357041866, 0.02271378216391895, 0.012144346874265466, 0.06974966585403308, 0.006855867004560423, 0.0673618057044223, 0.0788497990288306, 0.060323933939798735, 0.10059093357995152, 0.06970671776798554, 0.06954841024708003, 0.03774685537791811, 0.038692774542141706, 0.0512337418331299, 0.04584444723150227, 0.04773869753989857, 0.04915809207886923, 0.07521335704950616, 0.029589186669909395, 0.05383885458286386, 0.0329445624811342, 0.00959746859734878, 0.03633614025602583, 0.07114871812518686, 0.02199908467446221, 0.03757662154384889, 0.07411633661831729, 0.03723979782080278, 0.06650865499977954, 0.029589045661850832, 0.021653282819897868, 0.01665239306021249, 0.07238759266328998, 0.0477480300469324, 0.042182642355328426, 0.030238981489674188, 0.007914242414699402, 0.023894915757409763, 0.02671810674655717, 0.023928694608912338, 0.033527883133501746, 0.021612778255075682, 0.02111376372340601, 0.03369100348209031, 0.01604960772965569, 0.027448890286905225, 0.010340894623368513, 0.03217019446310587, 0.019352491435711272, 0.051393448302405886, 0.08886229887139052, 0.011896697760676034, 0.02577477953309426, 0.04049863877298776, 0.027347750401531812, 0.07039284813799895, 0.01614551176317036, 0.01816974181565456, 0.039832750480854884, 0.013621689231513301, 0.00932717563046026, 0.026447252530488186, 0.025182714525726624, 0.06196000591444317, 0.013529325242416235, 0.05570926339714788, 0.047187114832922816, 0.008254239746747771, 0.0047882004400889855, 0.027771602071879897, 0.1429679073044099, 0.17258136591408402, 0.18942433322081342, 0.14923403825378045, 0.12645216775126755, 0.1042460479948204, 0.09536268131341785, 0.20808655681321397, 0.18226251908345148, 0.2336561121046543, 0.10885390191106126, 0.11826980407931842, 0.11734670595615171, 0.21724173508118838, 0.1345656526973471, 0.15299053746275604, 0.1689935865579173, 0.1499353678082116, 0.13799127278616652, 0.1168038546165917, 0.17708087369101122, 0.07456710969563574, 0.1599041180452332, 0.1469835199532099, 0.17826807248638943, 0.10328449177904986, 0.14799511176533997, 0.14735766628291458, 0.09867331304121763, 0.13136459165252745, 0.14578725211322308, 0.10262852971209213, 0.18273234309162945, 0.13372938585234806, 0.16109055984998122, 0.14059693843591958, 0.11738542380044237, 0.19096874253591523, 0.17040329606970772, 0.14054819417651743, 0.10005824966356158, 0.19227812852477655, 0.14128219307167456, 0.14570687751984224, 0.13800516579067335, 0.11194445716682822, 0.08825865079415962, 0.09009206725750118, 0.11206878916709684, 0.11272299976553768, 0.24005131737794727, 0.23378843703540042, 0.10506666294531897, 0.19078896468272433, 0.10333396334317513, 0.11783141744672321, 0.14204320614226162, 0.27668432041537017, 0.24518951744539663, 0.06835267675342038, 0.12382240456645377, 0.16615502012427896, 0.11587678600335494, 0.12785856728442013, 0.19831717712804675, 0.07818392186891288, 0.09219020037562586, 0.09292020651628263, 0.15669787680963054, 0.12529720785096288, 0.14200022094883025, 0.10942438340862282, 0.15058718126965687, 0.10416214819997549, 0.11471865713247098, 0.15455853223102167, 0.06492891945526935, 0.18628869991516694, 0.09668858750956133, 0.13379071693634614, 0.10421298531582579, 0.10157752985833213, 0.18897132627898827, 0.11385734280338511, 0.1259070009109564, 0.14689713396364823, 0.1376366597833112, 0.08791317362920381, 0.11385947276721708, 0.12229698681039736, 0.33060425834264606, 0.173521488904953, 0.08969242073362693, 0.12603980081621557, 0.18011407577432692, 0.1380970436730422, 0.15765067568281665, 0.16547876031836495, 0.20002517063403502, 0.09958690425264649, 0.14827899809461087, 0.09357066184747964, 0.114748751220759, 0.1265125785721466, 0.1180599766667001, 0.1774354124790989, 0.1571892379433848, 0.11010836155037396, 0.1846009967266582, 0.09074866014998406, 0.09086007135920227, 0.09409164209500886, 0.2438706616521813, 0.24639123264933005, 0.21529543795622885, 0.17128737206803635, 0.12638136686291546, 0.18390830577118322, 0.3130548109766096, 0.1388183666858822, 0.14498605916742235, 0.07950163475470617, 0.08818186077405699, 0.0988414317544084, 0.10239042647299357, 0.19215503591112792, 0.2027345885289833, 0.16234915325185284, 0.09273521878640167, 0.0966537807835266, 0.06345456145936623, 0.22050590836443007, 0.10022342205047607, 0.1317458032281138, 0.18824373953975737, 0.10072892109747045, 0.20322404976468533, 0.10302586073521525, 0.11497534374939278, 0.13436485722195357, 0.15870789473410696, 0.10908459851634689, 0.08782228280324489, 0.1713485101936385, 0.16027253499487415, 0.1392342959297821, 0.14165052096359432, 0.2170138809015043, 0.13225371425505728, 0.09493674791883677, 0.07752015982987359, 0.12121888372348621, 0.10749527442385443, 0.1094819518039003, 0.19455189089057967, 0.15335911768488586, 0.1547368851606734, 0.12966891779797152, 0.14768026303499937, 0.20394480874529108, 0.09388324702740647, 0.1617068689665757, 0.12952994322404265, 0.14476529991952702, 0.13975558045785874, 0.08675742705236189, 0.09435887463041581, 0.12217088849865831, 0.11603020277107134, 0.10683762768167071, 0.09807820708374493, 0.15626419539330527, 0.1896072577801533, 0.15930320107145235, 0.1585180830443278, 0.07592567038955167], [0.016237834934145212, 0.038535773201147094, 0.06462306555476971, 0.07202582535683177, 0.05487566457304638, 0.02298762723512482, 0.08907546594855376, 0.03695352548675146, 0.023603769368492067, 0.0007869940372984274, 0.048639082233421504, 0.026875328876485582, 0.04823239643883426, 0.027410363545641303, 0.06323153123958036, 0.025379057115060277, 0.024246281864179764, 0.0031202659783957643, 0.01656768061366165, 0.04596936923917383, 0.061144118444644846, 0.027073428500443697, 0.02256069750728784, 0.03307971128378995, 0.06713073060382158, 0.019182513642590493, 0.0655244335939642, 0.02376083193667, 0.016421896834799554, 0.028558169142343104, 0.07711916259722784, 0.07483923298423178, 0.0494107785198139, 0.03305296057078522, 0.053366221545729786, 0.09432141843717545, 0.026357083443144802, 0.05030234649893828, 0.023807000943634193, 0.0417275499785319, 0.04940926824929193, 0.0331906252540648, 0.030581391729356255, 0.022125873183540534, 0.02991540324728703, 0.04576629165967461, 0.007788213679305045, 0.06627490816754289, 0.006653128957623267, 0.034040491955238394, 0.01636838242120575, 0.0262130492774304, 0.03446913789957762, 0.06337880302453414, 0.02450500011036638, 0.08604469068814069, 0.041325298516312614, 0.017248836738872342, 0.053489963538595475, 0.026656523332349025, 0.02967723507026676, 0.05355074543331284, 0.04794845815922599, 0.03341988580359612, 0.02662759812665172, 0.03926325975044165, 0.0320841832581209, 0.03181812331604306, 0.01068456651410088, 0.033401246764697134, 0.04751517379190773, 0.0414998998894589, 0.07034796304651536, 0.060141057620057836, 0.018193497962784022, 0.027968983667960856, 0.11230581629206426, 0.02984302529512206, 0.03803302752203308, 0.054947589815128595, 0.05067570986284409, 0.004790145330844098, 0.04065092376549728, 0.0022092444532972877, 0.021811714650539216, 0.02814126211887924, 0.044845843003713526, 0.054146248439792544, 0.04942593688610941, 0.06656020457739942, 0.024592712688900065, 0.02402634640020551, 0.010473900474607944, 0.014091593020566506, 0.016630894897389226, 0.03834428425761871, 0.061895309190731496, 0.027434602088760585, 0.00733240559384285, 0.06887940864544362, 0.044581074398593046, 0.02520359670597827, 0.03560477227438241, 0.04178450981271453, 0.022862697805976495, 0.03834487055428326, 0.05413766921265051, 0.020895217930956278, 0.045948088154545985, 0.0036558969168254407, 0.042983868697774597, 0.05196338432142511, 0.04271116653399076, 0.011914876668015495, 0.039446317896363325, 0.012048246171616483, 0.0027259392618361744, 0.015805468974576797, 0.033626677832216956, 0.028488190182542894, 0.04595724996761419, 0.015829768744879402, 0.05202670807193499, 0.03711178476805799, 0.02047343870799523, 0.0118522644515906, 0.02478337599313818, 0.005107635643071262, 0.02890182804549113, 0.030240174492064398, 0.032609616391710006, 0.03847323983791284, 0.08224398916354403, 0.018674298335099593, 0.08715458738151938, 0.03470977186225355, 0.03293564928753767, 0.015474582432943862, 0.025872798687487375, 0.02530499448766932, 0.013130941297276877, 0.02723867139138747, 0.01879555969935609, 0.061534317428595386, 0.028512029821285978, 0.037221641177893616, 0.03595563000999391, 0.028142998744442593, 0.05148300697328523, 0.008986676421045559, 0.025345432259200606, 0.047023192964843474, 0.08464209837256931, 0.039346821868093684, 0.09150151701760478, 0.023063741900841706, 0.04094886637176387, 0.03251477362937294, 0.05448732466902584, 0.015947195061016828, 0.008264601983682951, 0.008051303175307112, 0.027686596476996783, 0.04819570094696246, 0.040075006036204286, 0.012735627060465049, 0.04451395456271712, 0.012433146221155766, 0.04357719350082334, 0.035068203214905225, 0.03572743444237858, 0.008711159662198042, 0.09355218237033114, 0.038483741227537394, 0.05806305896840058, 0.021285042130330112, 0.018636753084138036, 0.03131488410872407, 0.02312229549715994, 0.10589901125058532, 0.042814462358364835, 0.0075166252008784795, 0.04175296111498028, 0.0375061954400735, 0.018811662448570132, 0.02181117844884284, 0.00747979102015961, 0.04284768830984831, 0.014491387046291493, 0.034322556311963126, 0.024728366151975933, 0.016331787119270302, 0.03650055565231014, 0.02745518369920319, 0.04095340089406818, 0.08695037802681327, 0.07861494639655575, 0.02971620524476748, 0.019255190309195314, 0.03101624573901063, 0.02356590128329117, 0.05183056215173565, 0.03953222891141195, 0.03677519111079164, 0.02744247998634819, 0.008510214829584584, 0.014519533924612915, 0.013474823772412492, 0.029000986396567896, 0.022150085751491133, 0.02545519218983827, 0.04910920681140851, 0.03099897781794425, 0.014164908861857839, 0.01735943715175381, 0.03480620282061864, 0.06902430555783212, 0.01661348967900267, 0.07753069832688197, 0.04949950969603378, 0.04378226003609598, 0.0766819114505779, 0.019958529228460975, 0.015508624746871646, 0.04007610441476572, 0.061130140093155205, 0.006172108724058489, 0.039369924925267696, 0.07629070314578712, 0.061426984320860356, 0.024197888269554824, 0.06163013611512724, 0.012552169082482578, 0.0334651271259645, 0.06195224304974545, 0.015915405165287666, 0.09748388038133271, 0.021657685610989574, 0.055823969742050394, 0.033528914718772285, 0.04769507781020366, 0.015115143614821136, 0.019815990490315016, 0.02961609323392622, 0.025789832143345848, 0.036816580686718225, 0.09556169563438743, 0.03704252012539655, 0.08194827300030738, 0.027229695115238428, 0.03944718249840662, 0.09569020592607558, 0.07318871139432304, 0.03322093085444067, 0.06036655919160694, 0.014299878621386597, 0.035575936126406305, 0.009195975053444272, 0.018542745237937197, 0.042425179926794954, 0.08798085007583722, 0.008993720330181532, 0.039046099918778054, 0.12130365925258957, 0.0211165987275308, 0.01901814463053597, 0.022052602798794396, 0.029736779433733318, 0.010888168235396734, 0.026757971209008247, 0.013118317365297116, 0.051017123769270256, 0.06293477606959641, 0.03567693871445954, 0.01999992808123352, 0.016149120456248056, 0.04859308392042294, 0.06376251563779078, 0.024687351360626053, 0.04372237985080574, 0.03791871822613757, 0.053365843050414696, 0.014194155046425294, 0.031013317966426257, 0.014753807681699982, 0.02335383258468937, 0.07780502579407766, 0.029597424509120174, 0.0075424932219902985, 0.029599535919260234, 0.03537370830599684, 0.04498958216572646, 0.061114647760405205, 0.11129872931633145, 0.04233942847349681, 0.012448809247871395, 0.045639618183486164, 0.03734360201633535, 0.06857174390461296, 0.020770865521626547, 0.06271783888223581, 0.036379652374307625, 0.046644757021567784, 0.03221237442630809, 0.04544965806417167, 0.03824224266281817, 0.03674972802400589, 0.0490118296147557, 0.035191692877560854, 0.02530361780372914, 0.07681946852244437, 0.054643839903292246, 0.043756151280831546, 0.025742195539351087, 0.034766104581649415, 0.03833249524177518, 0.015908291679807007, 0.03175894446030725, 0.01761720730428351, 0.03322913158626761, 0.03783233594731428, 0.03862422236124985, 0.042066310707014054, 0.11112696665804833, 0.037730487310909666, 0.047853418727754615, 0.05021164120989852, 0.14399204141227528, 0.047392207343364134, 0.006414336448870017, 0.04967410735844169, 0.043938122180406936, 0.046072828336036764, 0.03520546713843942, 0.06599855463718995, 0.045063559446134605, 0.025930001575034112, 0.05071967840194702, 0.0205702945459052, 0.027126733257318847, 0.08012745820451528, 0.010373209588578902, 0.029903142967668828, 0.09805741952732205, 0.041493877361062914, 0.007828248835721752, 0.023576206003781408, 0.005941355993854813, 0.06155798451800365, 0.02628864072903525, 0.058105339121539146, 0.03912433712685015, 0.10585919502773322, 0.10892762686125934, 0.18932038801722229, 0.3215556079521775, 0.19005443144124, 0.10230021842289716, 0.22849187749670818, 0.07934297842439264, 0.109114848455647, 0.19326558569446206, 0.12534952926216647, 0.11440731876064092, 0.10754577757325023, 0.20454149547731504, 0.16273615357931703, 0.1486135582672432, 0.19297371385619044, 0.0840251732734032, 0.17378385295160115, 0.20779532322194427, 0.15977456874679774, 0.07374099543085322, 0.10235406865831465, 0.12672225013375282, 0.11503742440254427, 0.1780092262197286, 0.11409241065848619, 0.13581559265730903, 0.16259639232885092, 0.1317552285036072, 0.21589855168713257, 0.12291578212170862, 0.19859989086398855, 0.0665843540627975, 0.1380400318885222, 0.14303904958069324, 0.12977510428754613, 0.25730331195518374, 0.11215556849492714, 0.14476644282694906, 0.13473214610712603, 0.09088768667425029, 0.2755397208966315, 0.12362580222543329, 0.19808565673884004, 0.12626378098502755, 0.09100053764996119, 0.11426334953284822, 0.18272996821906418, 0.1486437933635898, 0.069409250136232, 0.18426360154990107, 0.19557224004529417, 0.1701599161606282, 0.09281401260523126, 0.2146835668827407, 0.11488295378512703, 0.12419482169207186, 0.20995316212065518, 0.11698736547259614, 0.11033673523343168, 0.17188586964039132, 0.14270217390730977, 0.09957233589375392, 0.15540769760264084, 0.17532841069623828, 0.23080071376170963, 0.1339820574503392, 0.10380064064520411, 0.1327189221046865, 0.19385272840736434, 0.10974453849485144, 0.15830416639801115, 0.17399578064214438, 0.16024207725422457, 0.18501281447242945, 0.15951291716191918, 0.10464974664500915, 0.130739732994698, 0.1619804246001877, 0.2007435992709361, 0.10878621804295108, 0.12110581752494909, 0.16318859648890793, 0.12549816659884527, 0.09202181448927149, 0.0905727043573279, 0.2754218381596729, 0.186973761592526, 0.13387585611781105, 0.2181396447122097, 0.07580024743219838, 0.1151976540859323, 0.11446574804722331, 0.1278987026307732, 0.10525703866733238, 0.14741224382305518, 0.13361635676119477, 0.08702638879185542, 0.11453625949798152, 0.14882088464219123, 0.27185558108612895, 0.09550063914502971, 0.11249363160459325, 0.1687788832350634, 0.18048127560177818, 0.16587555699516088, 0.07745202325168066, 0.19023953791474923, 0.13785626128083095, 0.11970041989115998, 0.09294359901105054, 0.16620796493953094, 0.13048526539932936, 0.07422692404361442, 0.15829586918698624, 0.18975570215843618, 0.16965022397926077, 0.11422149240388535, 0.09205790513078682, 0.19215985987102613, 0.1213448855560273, 0.17764892836567014, 0.16144342138431966, 0.13886109954910353, 0.11488617470604368, 0.18143014109227806, 0.09814614328206517, 0.10898385939071886, 0.1671004420495592, 0.15338791301473975, 0.08931512769777328, 0.20073689025593922, 0.1859819405945018, 0.2666909754043445, 0.14331598940771073, 0.1214873259596061, 0.12510303233284503, 0.09200202883221209, 0.19025775021873415, 0.10430237700347789, 0.13903866580221802, 0.11946880302275531, 0.1557886865339242, 0.08438569377176464, 0.13903182320063934, 0.1093305685208179, 0.1651950372615829, 0.14962654531700537, 0.11080595810199156, 0.15495900996029377, 0.1404077056213282, 0.164383840165101, 0.07812511408701539, 0.16421972162788734, 0.05646830606565345, 0.24196154612582177, 0.09654143446823582, 0.13607326633064076, 0.1792953978292644, 0.12587390112457797, 0.1469983035349287, 0.09063618766958825, 0.19259149295976385, 0.19084520463366061, 0.09799558378290385, 0.13774495397228748, 0.17575952428160235, 0.15617586497683078, 0.10591125668724999, 0.12610013742232695, 0.07744728834950365, 0.10138926925719716, 0.09588275614078157, 0.16413143574027345, 0.10328334145015106], [0.05713183061743621, 0.04282903813873418, 0.04330107745772693, 0.03714477694302332, 0.08205722770071588, 0.03237140925193671, 0.04548521064862143, 0.05088831661851145, 0.090433603618294, 0.04459902695089113, 0.00863047151142382, 0.00856851795106195, 0.022667544508294668, 0.051124468009220436, 0.051894628049922176, 0.03776675606786739, 0.03486100671580061, 0.02846702598617412, 0.01148962604929693, 0.0328441276360536, 0.12066339360899292, 0.07055990558001213, 0.05470285177580081, 0.01633762596611632, 0.06613755147554912, 0.03376125889190007, 0.06325529480818659, 0.058145997682004236, 0.05700772497220896, 0.01778472858859459, 0.03300144810054917, 0.03838312084553763, 0.02754841414571274, 0.06739736199961044, 0.05320566531736404, 0.011359580439602723, 0.037386913754744455, 0.04236662818584591, 0.01074428713764064, 0.051008217997150496, 0.03444876223511528, 0.028207611976540647, 0.10427675064420328, 0.008854498992150184, 0.035161053310730495, 0.05071098043117672, 0.011785758742917096, 0.012179012592241634, 0.050044554081978276, 0.04498423499171622, 0.028926641753059812, 0.11050195957068354, 0.04503279000346083, 0.017016924866766203, 0.0693632815091405, 0.021793103442178108, 0.06230196901015006, 0.046920954700908624, 0.02300047937751515, 0.017152248074125964, 0.05301121520460583, 0.0683035614201799, 0.007706454516664962, 0.027768004511017352, 0.1431799092097208, 0.01813448794564465, 0.041046002370421775, 0.05269751309242565, 0.019382205173315015, 0.034332504801568575, 0.05697379769117106, 0.03039055587578332, 0.019393749280425254, 0.08456118943286128, 0.033712355070747435, 0.05568735890847165, 0.05673394669429399, 0.0322665066778427, 0.06115731754107401, 0.09082691962248646, 0.025010061290231533, 0.005400540921982611, 0.032620128913549706, 0.03971157260821201, 0.047834482829784974, 0.024933646054705605, 0.011238870119996136, 0.042126053594984114, 0.060423864124459215, 0.06391872288077138, 0.04467432896490209, 0.044375391880748793, 0.06125574858742766, 0.029116926561982837, 0.011710555063473294, 0.02872546963772038, 0.06679582162178122, 0.04205133416689932, 0.060960470291320235, 0.016235855255217757, 0.04887935625447426, 0.017556646198499948, 0.0345861968526151, 0.044689943752018735, 0.007403270956274355, 0.07388548416201957, 0.04734319962153677, 0.040655699485796504, 0.022677331580780447, 0.058347821031929925, 0.025902180314005818, 0.0016275231291729142, 0.10713079827837646, 0.014781885911361314, 0.03995950559328776, 0.01710493987047812, 0.0157003196363803, 0.04083123596501537, 0.05414644881966524, 0.03148579329717904, 0.021601156222459394, 0.03201614315912593, 0.027187014202354476, 0.03231450878956821, 0.004444205715117278, 0.02335854707780527, 0.025873026897897944, 0.06482169395894744, 0.02174927962187212, 0.03603370023483876, 0.020188620983390138, 0.07026695762760937, 0.05092117891763337, 0.036274248850531876, 0.02610976829600986, 0.01824229231715435, 0.04673552539316006, 0.08446076943073422, 0.043402191367931664, 0.11487870127893984, 0.05500450512045063, 0.05934694105235394, 0.03697944870509673, 0.08310688426718116, 0.018895877656177618, 0.06557590153533965, 0.031611398080713116, 0.05201718631724361, 0.015844693334656768, 0.04784625329193659, 0.0511976437701378, 0.03467231566901319, 0.06358164682751521, 0.045849430753150955, 0.01053954900271492, 0.014232992562028812, 0.06310806755209342, 0.022826937420177273, 0.07921883938251995, 0.013744752159254858, 0.03258403085055761, 0.01714702335448237, 0.06308623356744647, 0.057644829066703096, 0.055081098471418954, 0.027958196551480796, 0.018759016347758006, 0.060560241181519814, 0.04834866129385773, 0.041080300725298, 0.06139416655059904, 0.030898407530912664, 0.021871836033824366, 0.031049315839482006, 0.01567590112244943, 0.01958700639079325, 0.03317480266559869, 0.026087793303304352, 0.0502575690188678, 0.01874869307357585, 0.024831302034726832, 0.048752935108495876, 0.03537470649462193, 0.011335997769492678, 0.02621494360937504, 0.03180808576871641, 0.04996401250537019, 0.012043210699630436, 0.006702527698507765, 0.057480001778458245, 0.009384337699884782, 0.08520355535438284, 0.04067368543474004, 0.04230250291584525, 0.04053474054671824, 0.038424024314736016, 0.07400528163998388, 0.012548761696962174, 0.03397994383703917, 0.05169077863683924, 0.04613244876964018, 0.04535861509793904, 0.05140311477589421, 0.031363212765427306, 0.030838013408356346, 0.010690969393181149, 0.0552814041293459, 0.10075136364321224, 0.023810123529983684, 0.032088869920698926, 0.08359041574294679, 0.009546552628307836, 0.031950125412549824, 0.01893768469017232, 0.061454261958715506, 0.05526449058379512, 0.01821306097554043, 0.02068938141746912, 0.03448376191954594, 0.021887601105845533, 0.010133650812349515, 0.047011971691972576, 0.029130726798030082, 0.01758830992912408, 0.046229221115936525, 0.08999710204079747, 0.01917973244417226, 0.07885270082624629, 0.03458533225057181, 0.03629616447142325, 0.050162856132374145, 0.04153256923018489, 0.055117341253207996, 0.056567954234196804, 0.01764017120876815, 0.03948538826080039, 0.019523472983564716, 0.03960924528655596, 0.02478458198311273, 0.04353955177066382, 0.0720965965592768, 0.06809638347476721, 0.021944247382634785, 0.02330191378860036, 0.03678488727018703, 0.02185041579650715, 0.02098638520692475, 0.07340597512666136, 0.048747276232461445, 0.04291028846637346, 0.01282753833947936, 0.08149085027980618, 0.03664289957669098, 0.0341847246454563, 0.16345067851943895, 0.016516524374310393, 0.040849054930731654, 0.03968031334807165, 0.028124821692472324, 0.03925385302864015, 0.056240240373881534, 0.04461267504666466, 0.025627886243455578, 0.02022895114350831, 0.011235031361138681, 0.02368273573665647, 0.020554438560793642, 0.0783207367931027, 0.024335577072633896, 0.06283468261244707, 0.06114346906542778, 0.04076281365996692, 0.08620390362921171, 0.049639812714303844, 0.042213627020828426, 0.060972441133344546, 0.024538693614886142, 0.03655780863482505, 0.02229459489171859, 0.03680953028379008, 0.022158926585689187, 0.032082865945994854, 0.0877973169554025, 0.033811632165452465, 0.023890969387139194, 0.04609728952345904, 0.03530574613250792, 0.08014452760107815, 0.034864405752159655, 0.01266256262169918, 0.03431799581449013, 0.040990805136971176, 0.03288939864432905, 0.0467924184340518, 0.06765842728782445, 0.014639451073890086, 0.044301993475528434, 0.016450463954242878, 0.01815482279198477, 0.05547074084461201, 0.020439331456145737, 0.005934217924732366, 0.025868737284326926, 0.030462453287327662, 0.0036348769754113164, 0.05153789621545002, 0.0667279670597054, 0.0383315824001329, 0.043732717967941426, 0.049301909166388214, 0.008682737261551665, 0.039239581528818235, 0.09066000318853185, 0.015572024567518383, 0.02115325340128038, 0.03205306129530072, 0.07756423598038964, 0.042116747063118964, 0.016753067247918807, 0.06990514579229057, 0.0711880593735259, 0.10011232254328206, 0.05730179727834184, 0.01915672401082702, 0.041032461886061355, 0.03558579926902894, 0.017035803248290904, 0.010649584455677541, 0.06827092918683775, 0.018496808152121957, 0.0353584460390266, 0.028708431782433763, 0.028423246694728732, 0.08527169193257578, 0.07283098879270256, 0.027977661229670048, 0.056126977506210096, 0.006515519007734838, 0.05141631016158499, 0.048173028335440904, 0.04172197644948028, 0.042246400262229145, 0.024731466473895125, 0.05155220853339415, 0.06474529727711342, 0.01690276214503683, 0.006730197283104644, 0.027370784810045734, 0.0399871839908883, 0.02247963086119853, 0.018487601810193155, 0.022075102860981133, 0.1349753627437167, 0.14186287909979, 0.18357031687628478, 0.1851601159432903, 0.18142315006116405, 0.10070557313156314, 0.11305108098895289, 0.08190441207261756, 0.12523212149972096, 0.10304483002983034, 0.1434102124767378, 0.06629243027418852, 0.11291853341390379, 0.12436051358236, 0.10594163279165514, 0.09459369015530683, 0.21065205743070692, 0.17218654335010797, 0.10168062901357189, 0.1117704606440384, 0.2364025334827602, 0.08271907499874942, 0.1727217505685985, 0.1190091464377474, 0.12760809244355187, 0.20490943745244294, 0.19212585466448218, 0.13170013146009296, 0.12174658782896586, 0.18031334242550656, 0.15874903940130025, 0.17783921502996236, 0.10478018652065657, 0.1759439628222026, 0.10843714146176353, 0.1331827644025907, 0.09202250468661077, 0.16417419828940183, 0.17061537218978629, 0.16182316350750625, 0.1795843752915971, 0.08746882012928836, 0.2446612122002989, 0.1830848483950831, 0.17731542204273865, 0.20281331555452198, 0.05690478537871968, 0.08769954642048106, 0.13941756187705323, 0.24122839327901602, 0.11058882795623504, 0.20025342557346448, 0.10150573449209332, 0.10910313736530952, 0.1582616413361393, 0.13836161931976676, 0.15580309904180467, 0.11672309410641901, 0.06573484730324708, 0.10562386742094532, 0.1321029246901162, 0.15747080877190456, 0.08664461318403482, 0.14712328120367602, 0.1999394377344288, 0.13769505196250975, 0.13950451189884916, 0.20486557652475312, 0.17273451550863683, 0.11810289506684057, 0.12766685569658875, 0.14497041469439864, 0.10333601167076267, 0.1820469697122462, 0.16605790267931297, 0.24510751012712717, 0.15728467813460156, 0.11404213757487014, 0.3062618739204481, 0.18551646557170898, 0.19015534868231043, 0.13844260247424245, 0.1538215350592509, 0.13924404775025323, 0.14371084165759385, 0.12996567296795547, 0.1516437769168988, 0.1259950641542673, 0.12290848681004718, 0.12048282165778801, 0.11599756311625242, 0.16488179157022387, 0.1632432927726768, 0.17682311095995829, 0.14754013071069494, 0.0843225815333426, 0.23410698166117072, 0.11540739986230619, 0.2542104263557121, 0.15904751635389403, 0.1408036710927263, 0.2130793998367153, 0.1564473722828552, 0.17868545633973554, 0.09587058491888456, 0.13072316825855523, 0.16684023023117334, 0.08805656398180872, 0.06622042710660025, 0.17939489014679566, 0.10391542120487429, 0.12410830211592838, 0.1894304930465296, 0.06422895545256324, 0.12596380489412695, 0.06842591930762865, 0.06886678471346386, 0.13633839116664603, 0.13588672009063885, 0.16284535318845883, 0.12362428082269616, 0.13299905316671357, 0.09578767960192636, 0.19733877416001633, 0.11016809701686725, 0.09926240018103272, 0.10667177994037047, 0.12353216545307077, 0.12947508366778493, 0.09168205186142586, 0.1476456641103141, 0.1327696701628156, 0.11667572282021865, 0.12580032460391521, 0.12298739195102826, 0.18361500900937244, 0.17053857474820688, 0.18677764164749533, 0.12712035299045965, 0.20280951575841755, 0.19242069509346038, 0.14298387832241133, 0.10504055419005454, 0.1450788276270032, 0.13715277949813753, 0.3871689731022343, 0.16424434608779848, 0.14043417060747743, 0.16117274528369308, 0.12727163237286732, 0.11853023854200728, 0.21051363204605877, 0.2227592171402648, 0.13491958292433992, 0.10538761955103837, 0.10234296612907201, 0.23072158597642556, 0.16980911779683083, 0.2535889815771952, 0.1170691278821323, 0.10636511709890328, 0.13059740391327068, 0.1667477289447561, 0.13656348455697298, 0.10978477032040246, 0.1584449369693175, 0.10430140479002148, 0.14574745815480128, 0.29456114396452904, 0.07018808217253536, 0.19738688017241657, 0.12238212599186227, 0.22859917720779777, 0.1520199270453304, 0.05005766412068624, 0.10380755746155046], [0.012146664230385795, 0.043040947275585495, 0.0108331556111807, 0.09959114191588014, 0.06362860993249342, 0.034236441206303425, 0.07202080101706088, 0.026075941204908304, 0.06330890755634755, 0.054986092436593026, 0.06770666688680649, 0.02307536022271961, 0.041674000312923454, 0.06766842401702888, 0.10950069103273563, 0.007898288095020689, 0.017203760544362012, 0.0320433057640912, 0.025791438893065788, 0.04821550886845216, 0.016952090845734347, 0.017906691282405518, 0.028933473222423345, 0.018065664880850818, 0.05687664684955962, 0.05735523933253717, 0.0655505052418448, 0.011863271429319866, 0.022268172579060774, 0.09741200337884948, 0.02353458636207506, 0.03973708764533512, 0.029019003886787686, 0.056123122049029917, 0.05030178617744241, 0.006099714073570794, 0.0238421008180012, 0.013669957588717807, 0.0279704345666687, 0.010059546439151745, 0.08415746851824224, 0.02941106380603742, 0.03913653803465422, 0.016668993048369884, 0.05328138293407392, 0.033103875612141564, 0.02821290534484433, 0.033459041515016, 0.012906181873404421, 0.016382340363634285, 0.03256433425121941, 0.04734512549475767, 0.08132236791425385, 0.01608384114661021, 0.044494925896287896, 0.027036013125325553, 0.022538267949130386, 0.021864054615434725, 0.037316921807359904, 0.02355403619731078, 0.033712217773427255, 0.06581234236364253, 0.0117968019003456, 0.027672710893966723, 0.01605426470632665, 0.013192387414164841, 0.04110562651476357, 0.03604975288908463, 0.011785753176809521, 0.009424294003110845, 0.033821695687947795, 0.045412227846099995, 0.020968703538528644, 0.024316687558894046, 0.08605249808169901, 0.017538407919346355, 0.03382394810614642, 0.059467350802151486, 0.03222926570742857, 0.018608506943564862, 0.04534318213700317, 0.015679968091717456, 0.08371265488676727, 0.016070818310254253, 0.03251145993999671, 0.0629795275744982, 0.023771222004143056, 0.07658546935999766, 0.039822367834858596, 0.06507020952994935, 0.065326487965649, 0.04204638033115771, 0.0714916868309956, 0.014510937999148155, 0.05394547893956769, 0.0780902776750736, 0.08034803933696821, 0.06003734619298484, 0.04719664029835258, 0.034899910097010434, 0.018659702145669144, 0.00199769595383259, 0.06342131324345246, 0.03127696407318581, 0.04786646939464845, 0.016961542096396443, 0.02975156116008293, 0.07725339484750293, 0.014214646671462106, 0.030169251149345655, 0.0742599941440858, 0.027633796380541753, 0.031795068498468027, 0.03691284466185607, 0.004939959899274982, 0.02983098580443766, 0.04123346516280435, 0.013846621204720577, 0.07662946387426928, 0.03515247408358846, 0.0558807811466977, 0.12149307760410011, 0.012881506390840514, 0.03843541257083416, 0.027342616594978608, 0.035729093142435886, 0.017209204197570216, 0.032105772334034555, 0.04324040317442268, 0.044751627356163226, 0.04701485493569635, 0.01144944802945247, 0.04606710637744982, 0.07508229376981035, 0.06542810282553546, 0.01660164871282177, 0.02725542537518777, 0.03220691593014635, 0.05227616988122463, 0.03917908907169476, 0.044298527645878494, 0.02493459229299333, 0.07458513646270148, 0.022369468315446284, 0.0362565820250893, 0.0557947105698986, 0.017935100695467554, 0.00659176076624135, 0.006221498651939328, 0.021938477184448857, 0.03691927166073583, 0.00786069460446015, 0.005139057711858186, 0.06708981600240804, 0.06920438027009368, 0.03253405091527384, 0.03600587340770289, 0.008116031440295046, 0.03246185107855126, 0.058508009897195734, 0.05780137769761495, 0.04565449824440293, 0.12597035063663498, 0.026017890413641, 0.01836734234530013, 0.018107310497725848, 0.03667223296361044, 0.03230792222893797, 0.028723111463477835, 0.027136381177115254, 0.07073967601172626, 0.07487039576517418, 0.021118834447406698, 0.041575676877982914, 0.018148698218283243, 0.04832438564335462, 0.025240405375370756, 0.06026442482834682, 0.0495608333585551, 0.018692855737754144, 0.029262174139148556, 0.004637835754692787, 0.050366538562229834, 0.06429738888982683, 0.10411422772449441, 0.019824460250674747, 0.04845961979299318, 0.048880120666581206, 0.0821807433385402, 0.10631666227709502, 0.04394079020130448, 0.011281393326498801, 0.025960258935810998, 0.0724561300012283, 0.06897013619891368, 0.028708823265333194, 0.0206650408290443, 0.044446003521443345, 0.030822712178633083, 0.023440567383659072, 0.039581834062119015, 0.026682433563109953, 0.03811349859461188, 0.034248122610733844, 0.052342799899633974, 0.03697705156810116, 0.015323867082770448, 0.025716374366311356, 0.01634742417081725, 0.018332504077989142, 0.025361820735270157, 0.022645207718596794, 0.06862920839921571, 0.017773247564036865, 0.0387364202470053, 0.04957449629728217, 0.056365566852036864, 0.062463185749948025, 0.06313258068985306, 0.027696021752490196, 0.03802560604526661, 0.06447908890550025, 0.0694589369231835, 0.06462408971856348, 0.06711655558319762, 0.014190168785717105, 0.035015161920455284, 0.01850400512921624, 0.02644988715474028, 0.03590127882489469, 0.06918615312315524, 0.009510991694696713, 0.05228208108746912, 0.07335933856666088, 0.05414948049292434, 0.06220554176252335, 0.019364671934454236, 0.047586894943378866, 0.007580109904665733, 0.04000649096269626, 0.0496743708208669, 0.024019795091589913, 0.020024960722366814, 0.01690720204351237, 0.03376340369868558, 0.029249403633002657, 0.06625110007007606, 0.03153629644657485, 0.004604241976267076, 0.03862090867187362, 0.03216731493012048, 0.0999028142541647, 0.038565908107557334, 0.09324421334895305, 0.017335436095891055, 0.022157388484629337, 0.030190070247044787, 0.01792467537597986, 0.058704727271106094, 0.027077625345555134, 0.05285623992676847, 0.08015688435989432, 0.034045976426568814, 0.047878551558824256, 0.04524881805991754, 0.09559946352965198, 0.09787747098016553, 0.04096405813470483, 0.027964749715465587, 0.02372928323893575, 0.05246851600531954, 0.010141706825379515, 0.05233042829786427, 0.049312766786897555, 0.024990286765387282, 0.04637843361706473, 0.030996385867183562, 0.008130130390782142, 0.023221002993523143, 0.023383683619613294, 0.009171486035484122, 0.016261591081274673, 0.03042876905965386, 0.005856691323060659, 0.03707678879436571, 0.03718001040397212, 0.024573227601649705, 0.056094957544701174, 0.04221781273372471, 0.031065175535331946, 0.007332900977417012, 0.014398869989236118, 0.03329061852127779, 0.0412192901421804, 0.056065490571199916, 0.03532794748025481, 0.039886619269964285, 0.056970914447447285, 0.04896744547295384, 0.0818890867230948, 0.023151794011937454, 0.020168354785710108, 0.011549569317139685, 0.016366037234547548, 0.0581750861601904, 0.04899042978649959, 0.07455555445631035, 0.01712130608211737, 0.006609912306885235, 0.08474923481117003, 0.02456681730109267, 0.0427793031121837, 0.010945716221613111, 0.06987989792833105, 0.027415102158556692, 0.04396463911689352, 0.010983604715875117, 0.021999511409376282, 0.053158932278165594, 0.026826102221093606, 0.04090870876098052, 0.031158643469098024, 0.026636954753485043, 0.07965456912643276, 0.042421049874974415, 0.06588718053535558, 0.03876615810440853, 0.048230017855530605, 0.012405409379425691, 0.012954191406606697, 0.0332129787420854, 0.04765203324495815, 0.04696710886491928, 0.024880831115297042, 0.04929481052386109, 0.07302416241145693, 0.03407652322493959, 0.09213465062202886, 0.04571422628941946, 0.010743538496171823, 0.030383345911104698, 0.03001908684382215, 0.03444998677878175, 0.025317405052192044, 0.041496426638332196, 0.042106831970158964, 0.04621139101800509, 0.004828255077882204, 0.02187418307585176, 0.03685519091959577, 0.0633567463955842, 0.02757354697678238, 0.09951437416020781, 0.17519391869427636, 0.12978255545021966, 0.14983583096181974, 0.12665922695305198, 0.18328139878576621, 0.20212712581269443, 0.1357505508349277, 0.16007304569939151, 0.12935675564222038, 0.11173835533554666, 0.18104502581991255, 0.2558703732211143, 0.1671070174779743, 0.23028517345665023, 0.15528565883869305, 0.1721714183804579, 0.2845226170029491, 0.11909635621123016, 0.07974246167577803, 0.14275773108238354, 0.11865566149936058, 0.11644017256912775, 0.13541772728785872, 0.14401757129235193, 0.13541808351874352, 0.10171323156100698, 0.11606339161517099, 0.17848733259597793, 0.1569947655661963, 0.14549814106430858, 0.1347185648046434, 0.07413097177050076, 0.15342316502938047, 0.1705578705877997, 0.0934828286699485, 0.16929051984334365, 0.07040311946184374, 0.10300953348632902, 0.1254223339492455, 0.15001666266471148, 0.09772631776286289, 0.20890139043331146, 0.08857394481310621, 0.11205987597350031, 0.10658420651452616, 0.14342553040478379, 0.11937337767449208, 0.14184334577294067, 0.07412863400531933, 0.12605854746652767, 0.21284820599248633, 0.12374656449537724, 0.09781952408957295, 0.24699847272131592, 0.07351927139097825, 0.0878514937357977, 0.1608345634303987, 0.14718292019097134, 0.17869777599116787, 0.08506922662490979, 0.10162380276597105, 0.0674571271520108, 0.11423960080719553, 0.11644623591564596, 0.11838973514386453, 0.07788422037265263, 0.17910423543071374, 0.08968469497631304, 0.12084737201803364, 0.22683055023662746, 0.10326207149773836, 0.15955139009747654, 0.10584531686617993, 0.21343172702472657, 0.22519861202454194, 0.12408354406943545, 0.18019188253674656, 0.13896023563575, 0.11856244775117375, 0.2733316534431651, 0.08954445132985711, 0.2086503367172554, 0.1487709826324135, 0.09310733163147233, 0.11040372148272581, 0.12504263635491952, 0.18746120418654755, 0.10113510594237596, 0.17136736074462533, 0.18137390114134178, 0.09757907566381618, 0.14921921014320105, 0.12397824815707281, 0.11846366789541207, 0.16671139339450747, 0.14490890549495816, 0.11013335708412342, 0.09164013536064886, 0.15665119572076946, 0.07773492994601838, 0.07565724299638532, 0.15073906921315938, 0.07325465863686986, 0.08054818914388306, 0.13342071179067716, 0.1383927301503718, 0.24639844632474706, 0.14046767115360126, 0.1888310455251485, 0.17988748324569315, 0.18771421717246994, 0.15130109764868394, 0.13165410346118733, 0.18026562232989818, 0.06608499999856576, 0.16276919399388134, 0.08517193244188093, 0.27677679201588035, 0.17581059888470918, 0.16818323550978675, 0.18379610788542777, 0.11732769955415279, 0.2292978498735465, 0.14565813326044008, 0.12279075250262395, 0.09050339518580586, 0.1074939979298506, 0.18411920929793268, 0.12254196233698167, 0.15724101016530767, 0.07870221554185264, 0.17378769727656618, 0.12583636329509318, 0.1518961664987728, 0.15967308747349307, 0.09495706792222336, 0.24534928699722514, 0.14863727730698884, 0.19321780622703955, 0.15289618080714718, 0.06577867854502983, 0.1410399709129706, 0.13434910884825513, 0.09959313087165356, 0.15507848089328036, 0.14834357978543267, 0.11635186441708356, 0.1715245030936785, 0.15505445015151054, 0.177329997823108, 0.18038286681985483, 0.15029909438453615, 0.10420042075566016, 0.1403360438416712, 0.11091638225479983, 0.20282636251067743, 0.1056849981250707, 0.10815537025337107, 0.12143411397119053, 0.15167987497989088, 0.21530363126657903, 0.21204248594585806, 0.09090526073123328, 0.14383136644028127, 0.14861556206597015, 0.12392711418215185, 0.14700427040224895, 0.14430328330490738, 0.12563424679683521, 0.15215370658552274, 0.13720719376578927, 0.11762111505959183, 0.12296777698793449, 0.13263345637824386, 0.1094001745514106], [0.04007090195955243, 0.04333247401518747, 0.03131145909719635, 0.049167747420142405, 0.06312702200375497, 0.04306451046431903, 0.06259862027945928, 0.05268924927804619, 0.024923089004005305, 0.03467110596830025, 0.11308722358080558, 0.07008220738498494, 0.006632589556829771, 0.048017670851550065, 0.034863500331994146, 0.009246118261216907, 0.023894826699688565, 0.024573029077146202, 0.014082894122111611, 0.004631645779227256, 0.10174780079978518, 0.026981439295923337, 0.05907098086026963, 0.028268497771932743, 0.035627474571811035, 0.018036062465398572, 0.026428363016748335, 0.042147984058829024, 0.08219086623284966, 0.053162550248089246, 0.013262071370263584, 0.05149704098585062, 0.04161259872489609, 0.029397113285085652, 0.03423982168897055, 0.012322491074883146, 0.008833938718453282, 0.00931066098928568, 0.013979214236314874, 0.008852741957525723, 0.045250317198224366, 0.01882669279439142, 0.040968715111375786, 0.02761718897090759, 0.04425711951625999, 0.02864602458430454, 0.06935943718417548, 0.035073724793619476, 0.049753906787373126, 0.06416247386368923, 0.061689730573561974, 0.01689127184363315, 0.04092053488420788, 0.04237577515596058, 0.0030645594461020664, 0.047805884169065394, 0.025109386624535546, 0.04956357188348193, 0.02137738385499688, 0.062807609065203, 0.03864168138534296, 0.0504904846457066, 0.024218766739068087, 0.04312134413339663, 0.040081867191474885, 0.06767062819562852, 0.02721408960496774, 0.030848112182866316, 0.00823996917461045, 0.05009145039366558, 0.02877232513128547, 0.04133988171815872, 0.006019182701493264, 0.06137492637208197, 0.015335015068558278, 0.06543001014506444, 0.009809652328840457, 0.04313525940233376, 0.11120639872387983, 0.06541087015648372, 0.056620123505126685, 0.04598113227984868, 0.02415903869405156, 0.03365236727404408, 0.020822105252591427, 0.012308824425417697, 0.039163715482573025, 0.07324417951167561, 0.043284438506816514, 0.06462007469963282, 0.06202599026437383, 0.0333721286006039, 0.053526076444541104, 0.0432520845788531, 0.018212541472166777, 0.019761798866966274, 0.011755698978959117, 0.04449777574336622, 0.03787054542044643, 0.033070527206291445, 0.040621594089316204, 0.021829665347468108, 0.04543539398582652, 0.030084178761171643, 0.018627086610649712, 0.008319246317114448, 0.047536525380564854, 0.07942053285660222, 0.03533720206178259, 0.05977740525850095, 0.008153224171110196, 0.02338950947887497, 0.00651913929686998, 0.09495852253166959, 0.004656225710277795, 0.047437960747629404, 0.007950659601192456, 0.04973428440280259, 0.025398712896276265, 0.08622531458968297, 0.028748565273417626, 0.08254223605035804, 0.019984465434390586, 0.019890776711690705, 0.029290988022694364, 0.08632045792182907, 0.034780138594214804, 0.016995059340843, 0.02712401885219151, 0.01759196129569318, 0.027611834375420585, 0.014215233895811252, 0.020836985313508194, 0.017282212975260336, 0.04503299038333353, 0.06990274123381823, 0.014670807740913006, 0.02805706546496367, 0.02359295256610494, 0.060503782297018915, 0.0412551655608695, 0.052538244490278885, 0.021637155950884335, 0.02214182935858844, 0.12960954598383978, 0.024237377947429195, 0.034122361976187676, 0.042497142276261, 0.025235243738279678, 0.04262101785570849, 0.06012370991811622, 0.039746075053699315, 0.019439011011854745, 0.06859184868517332, 0.03714809805387631, 0.023238233807205688, 0.05111309830681421, 0.06310595985269174, 0.03829368462902494, 0.03612062799220439, 0.032317592413164675, 0.020602342337951995, 0.03502035324345343, 0.0217360489841667, 0.07576194519060664, 0.045435661158990115, 0.04185669109574519, 0.022158581487019546, 0.039231996779562905, 0.06665968205197714, 0.04102945989870932, 0.021889482450205833, 0.08737114607356489, 0.019305339083075523, 0.012856914399890229, 0.03469485469395295, 0.003518698163134104, 0.04387132517877035, 0.012986409892619122, 0.037997927647666074, 0.03585128775739577, 0.019048309222853277, 0.030334351176861674, 0.013139628135832027, 0.08730181463761255, 0.04332000964495819, 0.052681920569739304, 0.06876499915961176, 0.02315204263140913, 0.052491422393359244, 0.044154680872452445, 0.035863336524926126, 0.05239634214376565, 0.026644007011782378, 0.004313054769227165, 0.029731289396295324, 0.0367233892029617, 0.03183463239111006, 0.004240059906805982, 0.008211553267756244, 0.015239714957715478, 0.035406726456130855, 0.011342895104462514, 0.046546318553737365, 0.028870804417238105, 0.013240918306109961, 0.025611438395571895, 0.006806561495977803, 0.005279206270643044, 0.12231177039211616, 0.03571222041500732, 0.05238569974608254, 0.06302269830484875, 0.025872004589473363, 0.01715762493404327, 0.040573065052740276, 0.04909588154987432, 0.03869712723826524, 0.045405630153254606, 0.018475450997357257, 0.038609449911746196, 0.012237837072461843, 0.03992446880147327, 0.04556746287562419, 0.028173206010251306, 0.06552992548677139, 0.022640261304331943, 0.03525137639371678, 0.018467482186679263, 0.05683166156813968, 0.0932660918624606, 0.023524413372797426, 0.013902516056987224, 0.06490506682894193, 0.02730464646447217, 0.04786501107446384, 0.0408976693142904, 0.03424282738706097, 0.016964618298516143, 0.011655461730697425, 0.04369302791019436, 0.01616109315364156, 0.06942485750187188, 0.024747296483838, 0.021560994900937658, 0.0409862854576204, 0.029563690186478198, 0.04995796029106714, 0.04153241708991118, 0.0396666689630365, 0.029142736602807418, 0.06510686420369893, 0.019947844157286454, 0.01828483222197974, 0.013425921806629049, 0.038174436340341344, 0.0010688083830245887, 0.020605119825631846, 0.04443522011570167, 0.09885707622743212, 0.018190607297583483, 0.05042254844738636, 0.06204726763826329, 0.04865227761911228, 0.022367664896592032, 0.055847540352260694, 0.020078729321539868, 0.045634167108801194, 0.03237352066207677, 0.03090954716753913, 0.07966714852955192, 0.08840048263664357, 0.022992985541350208, 0.076124120678287, 0.04830981728446204, 0.018747960202745162, 0.03432134290051181, 0.02442130626150174, 0.05420261084509548, 0.0023454004895029357, 0.04338091028330382, 0.017339775804430246, 0.056249880872201174, 0.06948549096705392, 0.0545636656897841, 0.0603561208845349, 0.02502326595276827, 0.036137856950517744, 0.028873246083094273, 0.031889992897049524, 0.07624047459103167, 0.09988711040932685, 0.01879006224044133, 0.013027303157286951, 0.004976719865226187, 0.07724313836661167, 0.015744154588901438, 0.018637626963027287, 0.09377703827340156, 0.0594538474251749, 0.021161151707929093, 0.03288471940322779, 0.024226338500739075, 0.020069227975909598, 0.056843569327611476, 0.035980684915557504, 0.030735853069927543, 0.017125167105405126, 0.01927284785779193, 0.009911946253851056, 0.0021795678230773774, 0.053966529958415776, 0.040435975533910096, 0.024518221471225843, 0.04617351180058904, 0.06322670727968216, 0.01664404018811183, 0.08521423485944979, 0.058282615937059745, 0.06953807212994434, 0.037988517215126194, 0.02470001611072803, 0.027969696129730437, 0.021356024844862986, 0.03137256753689144, 0.011337734395056032, 0.0290178275827202, 0.007312307307074661, 0.07199118932476267, 0.06290260396781377, 0.033332750244881026, 0.015388280862680404, 0.056231416238006204, 0.026222339110972825, 0.025587778727640398, 0.025383458050782792, 0.037688403826905414, 0.04481302894419059, 0.033039119516615756, 0.04017635372292716, 0.028479813190642744, 0.07772699638735503, 0.009542312182020396, 0.03675206949992571, 0.04279846165445633, 0.055921205930644646, 0.04202276890282519, 0.08477905430481769, 0.09040742806973867, 0.019449738756520674, 0.07099005437339656, 0.047326326894108206, 0.057855443155858666, 0.13328233093488961, 0.06186328180774581, 0.11302471248200163, 0.15478766290470958, 0.12514077796367928, 0.17204780626343563, 0.13429071666905656, 0.2295289991889149, 0.14028623088961467, 0.23709178087301552, 0.23059353581629694, 0.05252374663541559, 0.14640828128904104, 0.10877980588702485, 0.15055553609272465, 0.12416153636877425, 0.12047742624417879, 0.13069161213934422, 0.09702397146611474, 0.171188295353204, 0.092480053572217, 0.11387776670744643, 0.16318987298291177, 0.1003614318324253, 0.1286266159149818, 0.12874118867330253, 0.15849795599933714, 0.15049801964778453, 0.15659225435229018, 0.10416671982966363, 0.15577918704366311, 0.08622578214271925, 0.20779278507689014, 0.11238394217798486, 0.139482811500784, 0.14998908445704728, 0.15097329101990908, 0.12053011130774394, 0.11817050472018309, 0.156165371008683, 0.19803536881227046, 0.1390691235428676, 0.12288820391404442, 0.19089564098976552, 0.07723030663328245, 0.14513119356706738, 0.15604610787704587, 0.16388296469813213, 0.23893843725090846, 0.10297083790646866, 0.09046351959113963, 0.17644375475356355, 0.19425331003731117, 0.1568372966721654, 0.21920864906860515, 0.1301913007046096, 0.0923725609027315, 0.1225236090249382, 0.12698333768639714, 0.08540942711988464, 0.22180175757966936, 0.09512038493994623, 0.0943159191228915, 0.14645183051470667, 0.09594829520210624, 0.20938622066751122, 0.08666301844641566, 0.10186664832872339, 0.10252387204673141, 0.104277077189181, 0.06882290152134374, 0.22435281600337476, 0.19933581934310496, 0.13547503593144938, 0.19190934050129727, 0.1125402087927796, 0.09154000479611568, 0.12949619034770876, 0.1861759676830843, 0.15050980495288968, 0.11492549368995242, 0.10243914104648866, 0.18907613237388432, 0.12982159241801128, 0.15544688299996778, 0.15348557964898646, 0.20232826267601922, 0.08183134763385169, 0.14265498815802857, 0.14550015970598906, 0.15474942745640874, 0.17058093653758988, 0.1164433044323232, 0.24283883889438584, 0.1633146428503096, 0.10822367752552964, 0.15021576604340225, 0.12142267005401663, 0.062457953608827665, 0.10593398124910891, 0.11146392396767624, 0.15447710378794, 0.16445150919025764, 0.10622255053021945, 0.09563773608533666, 0.13338168966583908, 0.16302599193295464, 0.18062366405501962, 0.17956264520762488, 0.06539192312629893, 0.09186039736960083, 0.07509721835958771, 0.16130515927216038, 0.23177809256594628, 0.16461893770610914, 0.08934000448789448, 0.11192590347491205, 0.2239346009446308, 0.15712133143097162, 0.15061781712574884, 0.15878803184023127, 0.18222472892375663, 0.17950308043509722, 0.07274346731719561, 0.1815059588989243, 0.10758083662949502, 0.13659330405062065, 0.10153521259780973, 0.11867915789480321, 0.11021826619980857, 0.13536504964577034, 0.13849254901288077, 0.08069034753134474, 0.08540920447558165, 0.1554578816285357, 0.09165200230199844, 0.09514823774225079, 0.12113650533137843, 0.19328353082528338, 0.1050182971812319, 0.1685947267105803, 0.13395032321568578, 0.14520300377625972, 0.16012318519642577, 0.11384619574528188, 0.11867604829603806, 0.12880122842034325, 0.11243250090046786, 0.07412265971652232, 0.1272290330962278, 0.1345774528454058, 0.21246770687866956, 0.149231351679191, 0.09946368547389284, 0.09049264146597125, 0.14870935468934476, 0.09283278151997365, 0.09804705914575607, 0.11820284009445459, 0.12519124400569126, 0.14140628016320989, 0.20231840695487335, 0.10884394971071742, 0.22271228372119367, 0.15619709040038288, 0.11994782224064693, 0.08981048900750466, 0.1625429280102253, 0.17106239742133766, 0.18299289629794657, 0.2551427122671157, 0.2875983144622296, 0.11646038125036284, 0.1469095129868947, 0.12228995125042275], [0.05145560317032505, 0.04016548497020267, 0.009428571556782117, 0.07777873150189407, 0.040130719062290154, 0.045353987807175145, 0.024818557503749616, 0.057507728415657766, 0.062003213752177544, 0.02490088951162761, 0.0817615412233863, 0.03175518177158665, 0.07447086798492819, 0.03673072162200697, 0.03277402065577917, 0.0648254863335751, 0.030620707002526615, 0.006704407651341171, 0.026927936014544684, 0.017777138273231685, 0.024826862136251293, 0.07243303436553106, 0.020504950298345648, 0.044574235507752746, 0.0434083808795549, 0.03692723490530625, 0.1010998390847817, 0.038517026550835, 0.01575371530634584, 0.03781072831770871, 0.024583990598330274, 0.05841018370119855, 0.021913400014454965, 0.04097469682164956, 0.08468555111903697, 0.0027426946371633676, 0.04751047970785294, 0.04110018657229375, 0.062301056168507785, 0.06791970779886469, 0.06537981127621606, 0.02841678258846514, 0.025412793293071445, 0.03016697275597835, 0.04021422551886644, 0.019083512997895014, 0.03447822178713977, 0.04834042345464695, 0.006747148863723851, 0.047023515799082816, 0.022263712271524128, 0.06683793108095415, 0.027189839929633308, 0.03060434821236413, 0.06812816223828122, 0.03910431398253422, 0.04442740530066658, 0.027581185531744268, 0.03174573794240132, 0.060560482379514724, 0.05095719905511942, 0.019555032813514117, 0.02715493301366223, 0.04692202710430138, 0.01379222270770697, 0.0659942724450957, 0.0560307469277177, 0.08721121324924752, 0.002225936746071966, 0.058519142112345435, 0.009213394187099766, 0.08151748595992103, 0.030084731661190744, 0.03357996705744881, 0.012900963647552999, 0.06396822413080372, 0.039604258054168895, 0.031119480336201377, 0.05058354254288133, 0.02934588468633592, 0.08540601324057207, 0.05150970944669098, 0.04341147192462813, 0.04700872850662563, 0.04964476283930708, 0.053958128846716136, 0.033635654108366, 0.010539429331402062, 0.1030190552410204, 0.025413283110538032, 0.010429390167701058, 0.06018941225192975, 0.0474665556976106, 0.051979099298478104, 0.026023386017186567, 0.02529123692511348, 0.026926065802399535, 0.015813547252037097, 0.032832475917530246, 0.04307017305109184, 0.04730834094516467, 0.04951670896844007, 0.09112068393733352, 0.023940439095895272, 0.07880809775087982, 0.0160479898477206, 0.016060183334047906, 0.020008939609397203, 0.04437591880559921, 0.0749416345206555, 0.04618542327079922, 0.03515393611451145, 0.02182693609938724, 0.017166558536700904, 0.023810722814232577, 0.06322004279354587, 0.04108400775294285, 0.05268341599730775, 0.03195435194356833, 0.045393752079689875, 0.00872051536134677, 0.03453860292211175, 0.02248881122795865, 0.0006772098129204096, 0.04841221139940899, 0.04885155911324546, 0.026801516723935492, 0.021315746635082178, 0.03248085005907342, 0.006549646204803139, 0.01637511555600213, 0.05817076686071232, 0.05279786259052344, 0.037083082206663676, 0.04231379098200705, 0.01069584252036293, 0.05643435652018525, 0.026583683393255342, 0.07997200053068809, 0.0403410511353286, 0.04711772402515635, 0.09452358688577078, 0.017721679432725068, 0.04610652555129491, 0.05740257722209208, 0.05470082942338195, 0.022230679278436583, 0.041928753635147586, 0.013631829751830082, 0.053713717352366075, 0.012634944523597369, 0.04238516332407016, 0.020628883394238073, 0.05344888566469308, 0.02481755003827857, 0.04297387939004693, 0.060889127635164186, 0.0031863802041698364, 0.03633894557424355, 0.027103953034384176, 0.025279501714976504, 0.024078862625174224, 0.055603555592824705, 0.041494233591947705, 0.027219017465540674, 0.010934237052424578, 0.0324951067159418, 0.03368829464307055, 0.019637361110653728, 0.026288791013939772, 0.051727392492466606, 0.03649073332780972, 0.01136882574428455, 0.06068768649129197, 0.03882952638377901, 0.017160014649562072, 0.05137104286404792, 0.031719922335469164, 0.03624985816713888, 0.047870332273305394, 0.042462580458959565, 0.03031088075658772, 0.04045224341098219, 0.06795415087253787, 0.039140363805927336, 0.04651815033867024, 0.03058881135075353, 0.07177124643931165, 0.09240544546628371, 0.02480246032064315, 0.06645821122219786, 0.028000907150271814, 0.04641694366000593, 0.040781025963951834, 0.021620014194922987, 0.025964123669837136, 0.031545020392513834, 0.03749407987925224, 0.034558655752334744, 0.06343840490444563, 0.04106790314835962, 0.10091712232679129, 0.035802870042971335, 0.06030850097886287, 0.09899720855173655, 0.054771103386883624, 0.06588863514480181, 0.013978481365484186, 0.056156251521315426, 0.04461279007955454, 0.0016592969063822238, 0.055898102873470634, 0.02796825265249936, 0.05957145927823149, 0.0962804137088824, 0.05541686463402584, 0.01773130879882956, 0.015477272718271706, 0.020630976250686217, 0.030471731988654938, 0.010146630975214066, 0.02699199820199283, 0.010627703159116209, 0.02459987812471809, 0.03564022837963421, 0.0264972677177866, 0.04711988367489539, 0.030696148169226944, 0.01507720409790636, 0.06294800856267102, 0.03176920836267527, 0.05398233399318997, 0.012760163390339585, 0.023156549323175568, 0.03689797573315445, 0.035464576867525466, 0.025984586536651477, 0.038660813952446915, 0.026979856666002888, 0.05918357950577047, 0.020535287439997774, 0.06808692851336673, 0.04330137431679759, 0.05054631641542073, 0.057006489296327345, 0.06881358756800182, 0.02898716204072116, 0.0454145507683279, 0.0625296970247291, 0.044473062225733884, 0.04486009966058191, 0.018446256763127167, 0.0876730220625177, 0.07671586470678449, 0.043771068449132144, 0.050077282794518396, 0.08295849183923565, 0.03188205933838617, 0.08497556016664021, 0.031244368947227485, 0.030482593319902662, 0.06762675984646194, 0.011944560719712172, 0.040061450708890334, 0.042959997517755255, 0.018080190566251986, 0.0419926005997695, 0.049951518449233845, 0.01463543791032862, 0.02781655395665439, 0.06122304956079461, 0.036058309851796366, 0.04039084924443159, 0.051974063826492056, 0.0675474019953981, 0.008619111085863551, 0.04710405366495252, 0.03486755616904702, 0.06582263595191762, 0.0032220028288065805, 0.03068043133680476, 0.046234397595981136, 0.030435325934377033, 0.06993428993155248, 0.0223864839063026, 0.023096639451978263, 0.03515287855407223, 0.022025484722689725, 0.013611461508844513, 0.030687782309541944, 0.13170416874345392, 0.012748479202855378, 0.021783618794870563, 0.032720092494855635, 0.021937111632723827, 0.05512557538168039, 0.03491543582640588, 0.02597483471618034, 0.05239287260337733, 0.053189620084594935, 0.028589198336703703, 0.019444836871116422, 0.0532280262268614, 0.007583254755445523, 0.04150573688093573, 0.027176475705346093, 0.05907996826863382, 0.058135819126619026, 0.05842175378347747, 0.022383914219972212, 0.018900877876149025, 0.041991387188318186, 0.08147213331540115, 0.04700239056546707, 0.09401308576343581, 0.054652767939842306, 0.033837084120023064, 0.04845240240683779, 0.01823854818212567, 0.029744876264885534, 0.034276031074114144, 0.021934938995400444, 0.027026892130379565, 0.01936482407472795, 0.032443100717500784, 0.08499966512317769, 0.023779975635989103, 0.03867092942527961, 0.08589240198489279, 0.03155323225655593, 0.02515551110263914, 0.03180210776918102, 0.08198192197596654, 0.08311533732921816, 0.04808852740097791, 0.06226866884389892, 0.012505745889939135, 0.01399101809511194, 0.06956158336834051, 0.04784566699527204, 0.03456918311712798, 0.023810329475963954, 0.03967409043980297, 0.05182122593396343, 0.03376108819793444, 0.0731454516062513, 0.007661720637770486, 0.05138162217917852, 0.04001511842943728, 0.05113178187457379, 0.025724402548803482, 0.04494204018556047, 0.09112536688917316, 0.10856433815206401, 0.13184566661948338, 0.20339757873443887, 0.11803576780948788, 0.1753757003461942, 0.10919263295363635, 0.1952717889798805, 0.15990043699275702, 0.16343607305316254, 0.17090053501306102, 0.14341276546474546, 0.14865703327814117, 0.1036759078851901, 0.137204373604618, 0.15142696589464322, 0.09011522226501256, 0.10780577416880988, 0.06853896324173547, 0.09025050094351172, 0.1437337146489881, 0.12258687711437233, 0.10693375807022676, 0.1188739642384462, 0.12404746084939688, 0.16066125710494816, 0.1784664040314965, 0.14133307471638545, 0.12313491606619209, 0.10241426425636746, 0.08816319575998932, 0.18276005488587543, 0.09521840780507773, 0.12921752873808146, 0.15388129279017448, 0.15590499591780826, 0.12482536520110443, 0.22265240724664181, 0.17923565494129434, 0.18059795605950058, 0.14089198666624725, 0.1338056637905538, 0.20644256612285972, 0.13075350725557655, 0.1692356009152718, 0.09321360717876814, 0.11920914039365016, 0.11862809813464992, 0.08299289038404822, 0.1557745411992073, 0.10014957835664973, 0.09619629869121127, 0.13176217500586063, 0.19829716882668436, 0.16776399628724903, 0.1428105274681002, 0.15896797296591103, 0.10862820738111623, 0.1481608927133493, 0.14062416041269898, 0.1360373612260446, 0.1632357673952356, 0.144287787261419, 0.17258981155464426, 0.07263273888383992, 0.24342661985429004, 0.14717885322170332, 0.22476323851151392, 0.1943377367570065, 0.1486881441087462, 0.09013981703901663, 0.13547444221330807, 0.1580974634271115, 0.1053370867157355, 0.1786628653644584, 0.0994515216734726, 0.08064322115387768, 0.18326018820516765, 0.13490053941495717, 0.14069313561776653, 0.1359186027548276, 0.09848392437561415, 0.14951148274121806, 0.1733527987380512, 0.1078569600940682, 0.1544263557298109, 0.11784696544054896, 0.15877446538070217, 0.22205622517503798, 0.15136009838897735, 0.09859595156740397, 0.11301043356070295, 0.13947334169643, 0.1746276451740414, 0.13090196647681296, 0.15100229415111244, 0.1291306529310532, 0.174733831663616, 0.12447853732737713, 0.11138105575810187, 0.16421161737525836, 0.1056481727573555, 0.1848497794708237, 0.0690025754738599, 0.1287370326463133, 0.11709387108567171, 0.07602888086694293, 0.10659988067345694, 0.09956394962500781, 0.1559536362765357, 0.1481246462208219, 0.07526659872382879, 0.11820986081147566, 0.11337356641888618, 0.297166527598165, 0.23434041679138318, 0.14684464927995577, 0.12981949956156313, 0.15854396915528923, 0.20091749931452796, 0.09439368877792731, 0.1597790513187647, 0.08697196710272692, 0.15223541704472154, 0.09041259341756813, 0.1299444623873569, 0.10767787985969335, 0.15765509888296947, 0.1213185244705528, 0.1199750071100425, 0.19663593062432483, 0.19389604014577344, 0.16662732290569693, 0.12790012755431235, 0.1384467288153246, 0.11356665840139613, 0.16277568036457524, 0.09994272695621476, 0.25686399021651596, 0.15718334529083222, 0.10278769812430255, 0.18428303097607568, 0.09854914431343786, 0.1316346146631986, 0.11731994411093183, 0.1568073287489824, 0.16659092798363417, 0.14208844746463, 0.17069196183001623, 0.19609584007412195, 0.11570246293558739, 0.09353219633339904, 0.24781804124359041, 0.18207929766504094, 0.13263980916235596, 0.13537762162741274, 0.21169327577808872, 0.1644992589717731, 0.10049536722362973, 0.14423626736970618, 0.08777130467933603, 0.1815710452501662, 0.10992293595336378, 0.10753282709629275, 0.10510945518035442, 0.13379837590036914, 0.10674931952962652, 0.12302074406761676, 0.1352857140591368, 0.09958320093574002, 0.23122480663005263, 0.12526669073849916, 0.16517909592948854, 0.19180122442776337, 0.11092174056102522, 0.18575803464045748], [0.003032074714610644, 0.012444133717508521, 0.04891353215498384, 0.05344800250895787, 0.012028551427647471, 0.06200853124028072, 0.029590600461233407, 0.02216178570961347, 0.02854172129445942, 0.019070187736360822, 0.03772103234950919, 0.00835378494230099, 0.006957792638786486, 0.09072785032913089, 0.12023872186546214, 0.11497606363263912, 0.012684736138908193, 0.00961982394073857, 0.021851645906281192, 0.02522956630855333, 0.07716758773312904, 0.04865951726969797, 0.019085088206338696, 0.025238336638722103, 0.031952340723364614, 0.021355911667342298, 0.007857500586396782, 0.05844452287419699, 0.06605366652365774, 0.03007252889801748, 0.06788582875742577, 0.08533415108104236, 0.0063218388731911546, 0.03289574771770276, 0.02814368152030511, 0.03094899788266048, 0.07721499612671323, 0.009230048908648314, 0.02230019625130808, 0.03499863429169636, 0.10939968473394401, 0.05361955365515314, 0.052895978224114515, 0.032293973563355394, 0.05107721175590996, 0.044857765606138855, 0.018113789446942974, 0.06523956020828336, 0.040977446478791535, 0.01198680005472852, 0.02927703935711179, 0.04326871239754837, 0.011024211326002842, 0.047118455040617846, 0.03600657102651894, 0.07046339669614099, 0.016416265789302997, 0.036535644394462, 0.051338904158910736, 0.018050582584692165, 0.04765504636452533, 0.05481056708958931, 0.05299386379192583, 0.027728245804610197, 0.014567668695235625, 0.04182992553978693, 0.028079277944925707, 0.022424832532124128, 0.0559056579368189, 0.04264940129360184, 0.046786919119767845, 0.014461333776125684, 0.01516028753030696, 0.008863209950504825, 0.11606671643676236, 0.016267242535832338, 0.05457664214191027, 0.06096313831221778, 0.022701850284647662, 0.031353665035567246, 0.021526887649088167, 0.01773246840457432, 0.05311935725330841, 0.05762188557127956, 0.026852159026020672, 0.05280950317683164, 0.024535760276194196, 0.07866717875003815, 0.03563993894204032, 0.013434465781756444, 0.11994365137070417, 0.03780709179409314, 0.019462503696558997, 0.028053683126927353, 0.05145297596754972, 0.045675894361920655, 0.039448395909857936, 0.012977791702724062, 0.04403824161272496, 0.03946819269913249, 0.06268634213483892, 0.011714354859577725, 0.07746507762931287, 0.052553736823028885, 0.01745453781040851, 0.03281076809798833, 0.08493531349813566, 0.054804440660518594, 0.04651500734325964, 0.07725011455477215, 0.03808635825407691, 0.08037478633923456, 0.010714389718486927, 0.04727312974864617, 0.03399076435016468, 0.011618095522862859, 0.06259392248466611, 0.050323917021160014, 0.06479807881987654, 0.022118483248050325, 0.04531596387096215, 0.002660208633642469, 0.019637372242868878, 0.020593460685631726, 0.024580810495535843, 0.07416033855406567, 0.027652973476506304, 0.04000282846391201, 0.04497717716731131, 0.023589894917677157, 0.04340349754784256, 0.042097837140318006, 0.08816568195470609, 0.026230150215269532, 0.06642776832450181, 0.019328180533193517, 0.019806268355750944, 0.019771741790464148, 0.09261378858354874, 0.03852317153359763, 0.025365114015585277, 0.02312385771801928, 0.041072819876717404, 0.023913328441267367, 0.02591042000858579, 0.011953539778915001, 0.03609707593568601, 0.00803551676654024, 0.03080325863265898, 0.03017329585418338, 0.021631233612424694, 0.04927399699226953, 0.027662239190249238, 0.04342237036325969, 0.08114102412946522, 0.06652545722317882, 0.03398738015675917, 0.048997747362591326, 0.04039377330627758, 0.03998289808805566, 0.06826860626460984, 0.013676401285920292, 0.0029560484108515084, 0.057527684766682796, 0.014430614428420085, 0.050079071370419115, 0.07761382628814317, 0.05464962494443171, 0.020462616339500528, 0.036084244202356786, 0.02672170059668133, 0.009082656524697086, 0.025734961454872973, 0.036059044577996247, 0.033313710446236655, 0.05624127195915207, 0.045400383169180714, 0.08434210743871517, 0.04128881082579028, 0.025290624653280247, 0.04880684100498911, 0.051724305158131756, 0.03183872904628515, 0.02738055703957798, 0.05596826180408243, 0.019131726621708367, 0.03215798242308665, 0.03154867546982132, 0.014311131435533753, 0.04494796994549688, 0.0539525590284029, 0.05307722181896679, 0.013726130746363197, 0.013805709386360832, 0.10297099375748076, 0.025770343345357105, 0.016297811598633416, 0.05106670665554702, 0.0364909151539905, 0.031815908005228266, 0.020563965881592594, 0.006521559625980444, 0.021492229352588765, 0.06431755304220133, 0.03803704254096374, 0.04126608255319297, 0.024841274644131772, 0.05654099571984261, 0.01983926609682385, 0.005448221590995672, 0.022477120546682272, 0.002418276376374706, 0.02331132607650943, 0.027161170764884446, 0.01508815726992907, 0.02337658868782455, 0.11114361303043552, 0.03763375949347392, 0.10107096211868338, 0.0379635958961444, 0.05734240388846956, 0.04318792591220699, 0.03511826478643343, 0.017742424315656535, 0.02789654077787418, 0.037167427290114574, 0.027723037783289328, 0.06460054137278348, 0.021186110134294722, 0.044094685654272325, 0.013103194251016248, 0.03257284297433216, 0.018442482942191418, 0.04748050436319318, 0.06374106014845893, 0.015071714060468366, 0.05358719972718973, 0.06275998544879258, 0.03859370153804775, 0.06397875520633534, 0.012904719842481427, 0.02406870262348093, 0.0540302210720256, 0.015657072835892905, 0.015639838311471976, 0.07249038753798231, 0.023676626005908474, 0.05344318225979805, 0.024065967809292488, 0.023667837122047786, 0.05524566600797698, 0.047794009806239046, 0.029434307871269993, 0.050284419921808876, 0.026795529447554145, 0.015805795519554522, 0.016014832544897217, 0.02468007089191815, 0.02074630043352954, 0.01938969344337238, 0.06122850063547958, 0.058643069642130286, 0.12627523974515498, 0.013566434481617762, 0.040023122492129914, 0.029629639284394216, 0.028653349581873044, 0.025084732478717342, 0.014419840299524367, 0.01990698707231786, 0.026343155186623335, 0.02497646797564812, 0.08274204446934164, 0.01027632963086944, 0.04200932860840112, 0.07272862436366268, 0.01910009072162211, 0.02621637595439097, 0.05015725291741546, 0.011192554538865807, 0.0008978921209745749, 0.06538294313941151, 0.05284740465867799, 0.04783079064509366, 0.027096952726424206, 0.08302152244141325, 0.11054773523937911, 0.0354936950316187, 0.03837289405055344, 0.10180419660173357, 0.028779403364751488, 0.04222497074806597, 0.046607070762547664, 0.004902472628600663, 0.012239655334269628, 0.07235227385535836, 0.05226447363384068, 0.03040919305931311, 0.017901086212077644, 0.023163406767707784, 0.017585643763595726, 0.05423228933068458, 0.05241235026915092, 0.03460193780483678, 0.021750786181655712, 0.009670071049185935, 0.06069132301490754, 0.044189450491103344, 0.07185719456174411, 0.027092637137684505, 0.07513818491133861, 0.0061509941588155925, 0.013775862989859888, 0.06133890252385754, 0.05343604650988709, 0.043872972746612504, 0.02453914818033809, 0.03875461399729829, 0.02833818729413906, 0.04335076053394005, 0.052496680509648286, 0.06451223322073929, 0.011489621410873951, 0.027130330818181392, 0.07051923588733189, 0.0232018017777591, 0.010147623597731581, 0.035162682324880734, 0.02742692086030729, 0.06021073044394143, 0.15449758706381544, 0.023872829442552757, 0.03218729354557581, 0.012230554748384748, 0.04121996178582776, 0.011780222321249312, 0.007874733255448518, 0.03408837903407402, 0.07575773721328005, 0.023275216881302185, 0.03819991798081901, 0.03433189995121211, 0.035740522216656245, 0.026709646263043396, 0.04809492842468899, 0.01921772854984738, 0.03775891527766362, 0.05813997515360825, 0.06808962250943296, 0.0228036042972235, 0.054131962097017094, 0.027855496300617233, 0.13662309385836124, 0.15681348857469857, 0.15292779629817232, 0.15031522867502645, 0.21833619510289282, 0.1820705403224565, 0.15867268724832684, 0.1918385099270381, 0.21663044288288802, 0.27308947581332177, 0.11559588310774416, 0.11265226567047648, 0.1948065366013907, 0.16778939258074388, 0.26081185962539166, 0.19612151838373393, 0.11489973374409601, 0.07630262203747407, 0.1371672365348786, 0.08753663758398034, 0.14019090944202617, 0.19684244063682854, 0.0886103545781225, 0.09329234904726036, 0.15635656309314072, 0.07229314694995992, 0.08176058385288343, 0.16105564922327176, 0.11065989601775073, 0.15076685522217304, 0.13162030605599284, 0.24872757290722802, 0.12160913465777412, 0.11770330049330369, 0.0994972899206914, 0.08331178381922655, 0.12377885534078814, 0.09064100420800969, 0.09196199738653377, 0.15912196860881522, 0.2927942090900615, 0.17152068845462054, 0.15745372453238815, 0.15898921323241666, 0.12094005884137005, 0.14929743250831962, 0.14847951155388728, 0.09732664897455834, 0.12987710506422445, 0.2340528048807755, 0.10921281937044114, 0.16016044100979343, 0.08621086497441866, 0.163314598321449, 0.10650005438947119, 0.20065488293766975, 0.10807105485582724, 0.11359955780790187, 0.16722902655601501, 0.07433668768499047, 0.12677473481744528, 0.1801417430397123, 0.19884992041625082, 0.2737622772110626, 0.08881282730726525, 0.10146242275368422, 0.14403668901650235, 0.10478605690877885, 0.16977279708953574, 0.22953848383622244, 0.13668917468748987, 0.11634396796580404, 0.15060552716022357, 0.10656889600795694, 0.226500888238661, 0.1066334183269646, 0.2720833313651383, 0.20017057220684364, 0.182352660340257, 0.18121132627129555, 0.15313114476157352, 0.09515071651549079, 0.14616928005125374, 0.15637247473932803, 0.13488764088833705, 0.1960297444020398, 0.243247227917891, 0.18104026123182848, 0.12753417453495786, 0.1635541784344241, 0.16620802431134507, 0.12177742406493053, 0.0877981555822771, 0.12232927765580826, 0.10590636593406089, 0.09296511387219653, 0.13330541172763333, 0.1288106685387902, 0.12614900042535737, 0.13097892719088122, 0.06871748686535284, 0.09980738890590146, 0.13817051629303023, 0.14423922111745924, 0.10378086240962148, 0.14800109347561374, 0.1263885508524254, 0.11365843980456702, 0.07672855543205515, 0.1543900795513764, 0.18323914089705795, 0.12143213985837065, 0.10475586634129286, 0.13664206315297633, 0.12829692423110828, 0.2707129705231637, 0.23654165648622438, 0.10923828987870365, 0.15130776213482022, 0.144287564617116, 0.1079783754539676, 0.09141212532995269, 0.13813550176564604, 0.07260458922246471, 0.12400307299685664, 0.25742261961568147, 0.11475290724774823, 0.17923357692779973, 0.062096984111121856, 0.11691778912791051, 0.17213150567840785, 0.13965007674414665, 0.18681894958717749, 0.12219597309012897, 0.12624159076949582, 0.07610312532051466, 0.10193213543971069, 0.180740789801348, 0.12909258075524122, 0.13680598873179406, 0.1366331276949495, 0.12400817897287197, 0.1495599895133637, 0.09837306977715343, 0.1488566561602056, 0.0964295408630278, 0.09734256062074564, 0.07499656087020412, 0.12724962027277797, 0.05886486418603454, 0.08310671357321553, 0.15192255727015436, 0.1484888477716595, 0.17038977413903922, 0.31453943287488073, 0.1999231698573567, 0.0948937181965448, 0.2423398187966086, 0.10094893819768913, 0.1486147753894329, 0.1655111476429738, 0.08071737654972821, 0.1373521945788525, 0.13300095306476578, 0.1461307329009287, 0.09508027185802348, 0.14076485676923767, 0.10386765658040531, 0.10438445111503825, 0.17970104090636596, 0.10641593195032328, 0.20936220476869494, 0.15656259813113138, 0.16475482494570315, 0.24489463248755783, 0.1561500976094976], [0.014949332980904728, 0.02136160765076056, 0.0718825166404713, 0.03904142438841518, 0.1140174017928075, 0.04420354758622125, 0.019507694923959207, 0.06933703174581751, 0.007243505579026532, 0.06885879920446314, 0.02763921034784289, 0.07341606091358699, 0.09186367024085484, 0.08715540374396369, 0.06675475116935559, 0.05446952796773985, 0.011136989942315267, 0.020047906073159538, 0.04973538649210241, 0.005981986723782029, 0.05477574552060105, 0.03547406151483301, 0.048965979731292464, 0.04349785049271304, 0.056152670658775605, 0.05965326250588987, 0.008788586073933402, 0.13765191833954304, 0.05122271351865493, 0.09185412622173317, 0.06214985842234455, 0.051481890041031875, 0.04305146721890196, 0.02246106232632883, 0.01361056165478658, 0.025488473802397493, 0.02689306620595744, 0.008510993156960467, 0.04972549737431109, 0.048986670808517374, 0.004615141342583229, 0.03821670907200314, 0.009155185689451173, 0.042623207191354595, 0.03532547241775319, 0.009265004064218374, 0.08706918844836764, 0.03359264665050432, 0.002073697442028788, 0.011907783591595944, 0.04174210720520932, 0.01641138987906743, 0.08513240565662272, 0.05798699254228268, 0.08641573484055698, 0.02438412280753255, 0.06759754149243236, 0.02790099366393406, 0.0408405684720492, 0.008233410444518086, 0.05424630478955805, 0.03419061358727049, 0.056382517504971474, 0.027003720424545463, 0.0072967750838870415, 0.07446644478477538, 0.020506137734628282, 0.07892250723671168, 0.07465806731488556, 0.06077123005525209, 0.027731264490284957, 0.012846261797676561, 0.10757591619039886, 0.02791504251945298, 0.013463359446177492, 0.015146502137213247, 0.06543836672790349, 0.03341958152304869, 0.06677216937532648, 0.12239697636687197, 0.04224128686473705, 0.03364300508110318, 0.026520973769947886, 0.02857816816685954, 0.058491289310040884, 0.013820122821925906, 0.025736020870681386, 0.026465774681128096, 0.011214813403057633, 0.02797547374939313, 0.09228413400705904, 0.04067341455083806, 0.10162648191908374, 0.017632784984016325, 0.06868332580779679, 0.029269996375660412, 0.0419134357071016, 0.05258465469523799, 0.02601292173494585, 0.07246123597724363, 0.01255513674550457, 0.02912735002610134, 0.00507542318700871, 0.09150263023911975, 0.050830354884965345, 0.026247594396409113, 0.14316266169771552, 0.025863779737846926, 0.005962834675301565, 0.013634425413329154, 0.04164826634223573, 0.06230310449609533, 0.028808536371798255, 0.043616686889436096, 0.047629768814658746, 0.07236241901409812, 0.038065704284235835, 0.0646630821574945, 0.09173712664050981, 0.07532238596468233, 0.019068261863139924, 0.057062306223087944, 0.057011617536772974, 0.005525231472347514, 0.011261405434197513, 0.01455090265153558, 0.08306372095830739, 0.024276670956169255, 0.0532207457581535, 0.03572407251340337, 0.021237019609543495, 0.01704166250419803, 0.023970971051312517, 0.01052750487360754, 0.023688136716373265, 0.003910007353624678, 0.059709832712542266, 0.042730239729280584, 0.008914968257158762, 0.09136174092418514, 0.037097427921253256, 0.011757308511732845, 0.02194367778429296, 0.04320690262829885, 0.03217989062250126, 0.02875584759749472, 0.01853255926107522, 0.04560572429909371, 0.01067249548214022, 0.02706683451833669, 0.01961800404387759, 0.09793474251637235, 0.0240912397930515, 0.07102533607394435, 0.022874928399687633, 0.031773872760822996, 0.03519482103001792, 0.009803748544072732, 0.05377609486458823, 0.033028699763235636, 0.103650964301778, 0.031540200143354014, 0.0542315100756241, 0.032301814353559166, 0.0051889560108975274, 0.035542290861485526, 0.06802427640650421, 0.025780915239010938, 0.01066839882696513, 0.03224796411814168, 0.04083155879925471, 0.017882300599012524, 0.020268192201911006, 0.05792434785689693, 0.11268175861914642, 0.008320273263962008, 0.01618566566321533, 0.09076585571165197, 0.007145816216507228, 0.0033275756550210644, 0.044309845397947356, 0.06821313814725727, 0.03859871103486512, 0.009599177392374258, 0.022698286120430566, 0.0072445459773007315, 0.04017673963971902, 0.05174534504476469, 0.023983969767868984, 0.047688454142189585, 0.06563099115737714, 0.04753686676849611, 0.05245180655037984, 0.06822518320404924, 0.019682812089740764, 0.06293673533946276, 0.0037224100469757104, 0.06231734631001018, 0.029843292468285654, 0.03239963683881797, 0.025993147210101597, 0.07568500674096867, 0.029406202738755383, 0.10346018039854243, 0.015139079732762184, 0.05045789323048666, 0.023599861960974522, 0.028593756978807505, 0.033806663486757316, 0.025634261291997973, 0.0838901469251141, 0.03233433897548821, 0.07397796318400651, 0.03414904589590151, 0.03885996928147506, 0.015280217667168472, 0.01646129003347596, 0.018646647768036928, 0.01712482942821225, 0.02426889510388719, 0.028955366578884423, 0.0377082377235638, 0.08830499049508944, 0.0419568142388016, 0.05006042119930498, 0.030546525631507393, 0.13853473268682137, 0.02320643834536895, 0.05229923212027643, 0.039619613089598715, 0.07481457141693681, 0.061423529623425566, 0.03759114537388086, 0.009704300755402073, 0.06347643997287378, 0.02649549212947022, 0.034615496842889115, 0.017478618647146504, 0.053174769709585235, 0.004968976945747272, 0.03603963370551355, 0.03896341353538446, 0.042658333040890284, 0.07259069621795788, 0.011758408745663473, 0.043460123415570706, 0.020529598878056277, 0.06921663312823512, 0.04394169562146999, 0.058550252942950465, 0.014232015710149426, 0.06512097243103199, 0.0014146428225103591, 0.031732568531879224, 0.02668419616384199, 0.05127373617142439, 0.028679469469352625, 0.007022685567790177, 0.054575131871388294, 0.04566668430925347, 0.04441078119270969, 0.03561312514648307, 0.024142522197507787, 0.059145937775610946, 0.004734705971713993, 0.05610739593976177, 0.08014537364942953, 0.05319289666658733, 0.06440745681175031, 0.010631495533743873, 0.05426772688224446, 0.021756478454335593, 0.021698770906368736, 0.030652200039185118, 0.05971332822809927, 0.01788882778782863, 0.04592445446178317, 0.024193737808673177, 0.05115357504109852, 0.10170934270718135, 0.03404395407414995, 0.037182003070483916, 0.09628270694520324, 0.03750957963347901, 0.02268852502311347, 0.08919311861973256, 0.06847801065305248, 0.014207111089490354, 0.03626077887020074, 0.009015463401738089, 0.05495639539731201, 0.04090463808097411, 0.028011499452986754, 0.0235247733144206, 0.03530553833115846, 0.07321896875509992, 0.010318102340534097, 0.03494387863611337, 0.045527101174229756, 0.03942128525523003, 0.05018336538341828, 0.015306251279980643, 0.08242725511081517, 0.027326888630341273, 0.06721004392602481, 0.056639898029970936, 0.007511562362196855, 0.00893644786629011, 0.03192955678969156, 0.06062900116376113, 0.043202238230151124, 0.043608526975731365, 0.026878852222580463, 0.03676129810628481, 0.05969695273961406, 0.09203363690176047, 0.052547699451679364, 0.029175482013670262, 0.033626251097302884, 0.04793337400769815, 0.06639005237957463, 0.08116270968457684, 0.02440660431602737, 0.0433902984514134, 0.004048391920150607, 0.033955824037548155, 0.02657312263181666, 0.0992234745353926, 0.043563393264776096, 0.016629651800030842, 0.09749341697897762, 0.025895018588926177, 0.04992401445633732, 0.015989202474884223, 0.050611603146535344, 0.05070311366580427, 0.054364094758057036, 0.08674651006003842, 0.043029644366470166, 0.02315438410732895, 0.031448040244868025, 0.025884357637551147, 0.03002409819600871, 0.05908766805077903, 0.020157426661171485, 0.012444816493371036, 0.052018106580362655, 0.05468808303703554, 0.045739778433926404, 0.04519096022704616, 0.04122940190427471, 0.018497813762223814, 0.16369484510505572, 0.11784830872784369, 0.16523840837180614, 0.12954753212397918, 0.24517231446225196, 0.13488326221704483, 0.1297933462774381, 0.14820089447312057, 0.07958730828249827, 0.13151493592886254, 0.13365294464165345, 0.1588597529917024, 0.12814796034945175, 0.11535224344697781, 0.17119711206760257, 0.11863638792419806, 0.18286223377799615, 0.147934507986065, 0.11910134344361722, 0.11748690507374704, 0.14857144880807027, 0.15808692493010312, 0.17669056338490918, 0.06566750482306816, 0.10123534782906063, 0.12096109872800298, 0.13246028363937512, 0.28415644133929163, 0.11279770435066894, 0.2347274764906615, 0.16071343008661643, 0.11515525518916547, 0.14691010670503601, 0.12297760302317329, 0.15086088533280417, 0.1878128485986963, 0.20726805698359385, 0.11532479140441865, 0.13730350969126448, 0.12481846322771162, 0.19776786910369992, 0.1093716909235809, 0.1121233295998536, 0.12383466484607197, 0.12163938459707424, 0.16140883730258793, 0.25169255677610636, 0.15231776575092226, 0.176243849855382, 0.14974442805396393, 0.28392961132340133, 0.14526709564961493, 0.18408977572107688, 0.11355270602507517, 0.37150294810999185, 0.1699995232047513, 0.236684801930096, 0.06970534479478374, 0.10688453883631155, 0.08011973986867815, 0.10225058358628303, 0.11914115966646932, 0.09734151419252157, 0.12061323184752837, 0.06035843267454766, 0.16133254452142864, 0.12057289612130262, 0.2528915705624968, 0.13399271469097584, 0.1767181564355269, 0.0965658733912278, 0.1038729926222004, 0.19010848947800696, 0.13240025873528793, 0.18795096228132024, 0.137643784401007, 0.14005374570842832, 0.05612333356111776, 0.222714465635363, 0.2983412583125755, 0.14953153557144105, 0.17900953738717362, 0.11264485903666355, 0.08270660691778176, 0.22291692352155223, 0.10664400135283358, 0.07295509814866818, 0.125188646488823, 0.07502856227802113, 0.14419473678572103, 0.22542953869560733, 0.12717533129034564, 0.19446008722297847, 0.12858554546255618, 0.21972062706481665, 0.16963403031695634, 0.1935987061006017, 0.13091666100081056, 0.11667927770758979, 0.11248507464188151, 0.09554668940836564, 0.17100528173614293, 0.07891033601481467, 0.3733834018930793, 0.16828566673211753, 0.10138447498320602, 0.20410478609846905, 0.14315035688923672, 0.10499487500055693, 0.12028790399199352, 0.20378587039886042, 0.17294930788921192, 0.10709744616178796, 0.1335215993458405, 0.1422404541517608, 0.19230008125305176, 0.13968829734949395, 0.3148845909163356, 0.1262330709141679, 0.2134938002564013, 0.1022923516575247, 0.1439794249017723, 0.15624096617102623, 0.1414849329739809, 0.14202011050656438, 0.17191882099723443, 0.16599372174823657, 0.08024508118978702, 0.1857127933180891, 0.18488270114175975, 0.15179189475020394, 0.12039425375405699, 0.17747649777447805, 0.15759961592266336, 0.07472059325664304, 0.12940267974045128, 0.11768490265239961, 0.11937958945054561, 0.11849443733808585, 0.28714112180750817, 0.18283199868164957, 0.1302869783830829, 0.10932913617580198, 0.10167936736252159, 0.1290919870370999, 0.15612496848916635, 0.08437062817392871, 0.15627716813469306, 0.09575422358466312, 0.09228413400705904, 0.1046897261403501, 0.2096094290027395, 0.16977662657154724, 0.22725474700564519, 0.1706651851418428, 0.10870427751797251, 0.13734181935433298, 0.09470691962633282, 0.15356826974311844, 0.13452458224492148, 0.14131658419501036, 0.19809819903457537, 0.19411950081121176, 0.12261078169103712, 0.10191561523242854, 0.12346485265879892, 0.19061081955442205, 0.2078811006504111, 0.12365299451630563, 0.20930550468619913, 0.22804152744356543, 0.219105817086529, 0.11542558248038404, 0.11511329415952787, 0.22776777885155752, 0.17944140796316788], [0.038991752444417216, 0.01381262805807637, 0.04889436990197282, 0.008655060719320318, 0.05276036557916086, 0.03498671168927103, 0.03293153036793228, 0.052291161264292896, 0.02181370360631263, 0.07245972941746004, 0.10725880390964448, 0.00536913137693773, 0.012111297182855196, 0.11203895483049564, 0.022365841068676673, 0.011807052815129282, 0.0646979408338666, 0.017013245669659227, 0.03422595465963241, 0.049439239883213304, 0.009554942607792327, 0.05218952413997613, 0.04098366938706022, 0.08347012844751589, 0.05475061640026979, 0.08402106919675134, 0.04040440828248393, 0.03956355867558159, 0.02078926521789981, 0.03243181265133899, 0.04678534947743174, 0.04893324730801396, 0.01846082326665055, 0.043361499410821125, 0.013878268237021985, 0.04525590185949113, 0.04180154952337034, 0.008655426227051066, 0.012895230556750903, 0.03956778520660009, 0.08252551546320319, 0.02915793393185595, 0.009781725311768241, 0.09467250623856671, 0.05735071965318639, 0.025254218599002343, 0.061255915570654906, 0.051318268742761575, 0.0023323720870394027, 0.03356552857439965, 0.02484492229996249, 0.014630878340540221, 0.060726779120159335, 0.054994159581838176, 0.043884631886612624, 0.022027123013685923, 0.04995885828975588, 0.005031983891967684, 0.03214937351003755, 0.00689522495122219, 0.04433029898791574, 0.011795235968747875, 0.021025522364652716, 0.02879162839235505, 0.036319794453447685, 0.08290761019452475, 0.02908253914938541, 0.060051784676034003, 0.03939791873563081, 0.04616045000148006, 0.04111025751626585, 0.009651199161453405, 0.06253458035644144, 0.06122356164269149, 0.06655310222413391, 0.043613347224891186, 0.029491789064195473, 0.018578097442514263, 0.06083768566895742, 0.08379107763175853, 0.0069976853956177365, 0.06214889734110329, 0.00824040333100129, 0.042369489165139385, 0.027491393084346782, 0.017198242676386144, 0.05057703390775714, 0.02604018824058585, 0.03910390209057368, 0.025800546900427435, 0.02921942086686613, 0.01594568107975647, 0.08048565578064881, 0.05471926066093147, 0.021291606426530052, 0.03287796957010869, 0.026829189555428457, 0.08516770220012404, 0.08023334783501923, 0.0472646470007021, 0.0521950642723823, 0.028616212512133643, 0.03943891126255039, 0.06659226535703056, 0.02825211857270915, 0.035905060067307204, 0.013484271312336205, 0.02717596733418759, 0.06991946182097308, 0.04104658124560956, 0.056248927212436683, 0.06709471417707391, 0.051932199276052415, 0.05843452243425418, 0.03542763275618199, 0.0479778917360818, 0.060187096751178615, 0.04000981578428764, 0.050108772120438516, 0.02456981372233713, 0.04419110919116065, 0.08750719658564776, 0.053018963226350024, 0.018694384561968036, 0.014915830579411704, 0.027958185419265646, 0.027114510085084476, 0.016733220363676082, 0.07880714038037695, 0.053094532413524576, 0.030134138287394308, 0.031346558971563354, 0.0430233732186025, 0.03055481913179392, 0.018733104261627886, 0.07041524615488015, 0.025824967269727495, 0.006187221169966506, 0.026703289768192917, 0.025758593292266596, 0.014979968836996704, 0.08732098431210034, 0.01991190751141403, 0.0228563227574341, 0.06005970710248221, 0.06394044554326683, 0.04531449070782401, 0.08033669189899229, 0.07909564286819659, 0.03827804386673961, 0.034240630629938096, 0.009098982845898718, 0.057471381733193994, 0.04683233113610186, 0.06492897882708348, 0.008010100991668878, 0.002587926001069718, 0.002218189420091221, 0.04062638836330734, 0.01613924618141027, 0.014512107809423469, 0.06916397032910027, 0.03297653420304414, 0.025226258185284678, 0.05147908472281415, 0.016843496086949017, 0.017568861949257553, 0.11955568625126034, 0.09704193886136636, 0.05333697721653152, 0.047502238157903776, 0.03163434157613665, 0.03281395933299791, 0.05815943797642831, 0.045820995364920236, 0.05873078778677154, 0.06039618943759706, 0.053064178573549725, 0.02005968395678792, 0.025470883047091775, 0.03308863932034001, 0.0185723791946657, 0.07123525254428387, 0.01798431621864438, 0.03939174406696111, 0.08670863084262237, 0.08459532822598703, 0.021034539458923973, 0.057231564132962376, 0.12138393736677244, 0.044593950660782866, 0.02829611494234996, 0.025080899285967462, 0.11625426457612775, 0.029345105431275442, 0.0479660507699009, 0.05437586522020865, 0.0488548690918833, 0.011795439131674357, 0.05945141689153388, 0.06714969989843667, 0.04207482314086519, 0.01712136359856231, 0.038836495150462724, 0.04484502293053083, 0.043165999159100465, 0.018869722516683396, 0.08691286988323554, 0.041355192224727944, 0.021919977298239246, 0.04174943962425459, 0.027466015344543848, 0.026514682213019114, 0.013032516744715394, 0.030604236890212633, 0.032246420450974256, 0.01598819872015156, 0.07646811354788952, 0.028771158104063943, 0.03665496318717487, 0.010857656689040596, 0.035144288194715045, 0.08950259420089424, 0.05071845756901894, 0.013263692035252461, 0.05389168065448757, 0.06913703778991476, 0.06554996347404085, 0.034864520785049535, 0.028868214321846608, 0.003101690253970446, 0.06854684485006146, 0.029191759167588316, 0.01954777275386732, 0.029999820690136403, 0.06424956489354372, 0.037078091263538226, 0.023587289979332127, 0.024277518859889824, 0.02934530766651733, 0.040628544302308, 0.03748149305465631, 0.01814838466088986, 0.05819372890982777, 0.010503685643925564, 0.019663818675326183, 0.02559719101554947, 0.0472993275616318, 0.052780648475163616, 0.012198558906675316, 0.03262215126596857, 0.0401711661106674, 0.03621213480073493, 0.0975017438759096, 0.029101523286954034, 0.07346352125750855, 0.04804677788342815, 0.01232153184901108, 0.031703914210083894, 0.04871101489698049, 0.08849567791912705, 0.07454971375409514, 0.049397148977732286, 0.04328043090936262, 0.035494804542395286, 0.05463268171297386, 0.03011612265254371, 0.04644476677640341, 0.04517075154581107, 0.02506972996343393, 0.06463363373768516, 0.016065196541603655, 0.0934852629143279, 0.06286917021498084, 0.05608310915704351, 0.0386873531533638, 0.011350028071319684, 0.046929552481742576, 0.02170435371226631, 0.08070147974649444, 0.05892611363378819, 0.04146565348492004, 0.08021641202503815, 0.0703355840232689, 0.0282540333137149, 0.027840924230986275, 0.026480528576939832, 0.027924872265430167, 0.03499240396195091, 0.021042101943749003, 0.042772668311954476, 0.01784444921213435, 0.030584245287172962, 0.06302460562437773, 0.05344894503650721, 0.02919069789641071, 0.009138794430327835, 0.06491012827609666, 0.03996150197053794, 0.059084666063426994, 0.056619091919856146, 0.014012676747370278, 0.06927730370080099, 0.048428675945615396, 0.039448210372938775, 0.013092267981846817, 0.014952244055166375, 0.023416078365698922, 0.05726716495701112, 0.03377312583324965, 0.052888311838614754, 0.0452731716359267, 0.022396332205971703, 0.0462209498800803, 0.04616446502041072, 0.028486921110015828, 0.0077881867764517665, 0.008271345323009882, 0.04687950946390629, 0.08440784687991254, 0.016802058271423448, 0.10066837669000961, 0.04166856037045363, 0.058721518362290226, 0.005768574737885501, 0.020805022868444212, 0.01675965937465662, 0.019115358554699924, 0.05955436761723831, 0.044723351529682986, 0.03419111453695223, 0.0733052656869404, 0.03588779400161002, 0.03776254066906404, 0.008624081619927892, 0.03335379013151396, 0.012578365040099015, 0.07306228653760627, 0.030337520147440955, 0.035507324573700316, 0.01087497377739055, 0.04826805663469713, 0.013539012124965666, 0.10528979706577957, 0.03593509107304271, 0.04373489988211077, 0.020115541701670736, 0.019128915737383068, 0.01243729297129903, 0.10984196022036485, 0.03676410713524092, 0.0866245900397189, 0.09129275829764083, 0.15390657034004107, 0.12349971875664778, 0.09167558775516227, 0.13798701285850257, 0.149605869082734, 0.15576915320707485, 0.11544737193617038, 0.11875280120875686, 0.14419194631045684, 0.2069467812543735, 0.15763513511046767, 0.1704433126724325, 0.22344696539221331, 0.1549488870659843, 0.16325576085364446, 0.21957901044515893, 0.19385660241823643, 0.21356881654355675, 0.1306755669065751, 0.23179912503110245, 0.12868886726209894, 0.13762839225819334, 0.34256521495990455, 0.22438196756411344, 0.12076896411599591, 0.08051502256421372, 0.08604831979027949, 0.11617966389167123, 0.18152993026887998, 0.13807310198899359, 0.21875990205444396, 0.13550883333664387, 0.16555015492485836, 0.155377343762666, 0.14148684771498665, 0.32436448847875, 0.09100605922867544, 0.14562069933163002, 0.21683138678781688, 0.24451434117509052, 0.20633189706131816, 0.13565304747316986, 0.15691868058638647, 0.14592919527785853, 0.07638379072886892, 0.1468720642151311, 0.17322342755505815, 0.0849697862577159, 0.11959119801758789, 0.1787747663911432, 0.12032817292492837, 0.2576221089111641, 0.17908827925566584, 0.09353928384371102, 0.12538121896795928, 0.1616299824672751, 0.07695157823036425, 0.1230514096096158, 0.11623848651652224, 0.14186736167175695, 0.15749068348668516, 0.15465115226106718, 0.14425493980525061, 0.10039067245088518, 0.09817950282013044, 0.22104884876171127, 0.2150330739095807, 0.1870279829017818, 0.2581798774190247, 0.09326137180323713, 0.06835934866103344, 0.1088300344417803, 0.10176853640587069, 0.13910097652114928, 0.0800187855202239, 0.1168612894252874, 0.12049673692672513, 0.21316986763849854, 0.10915088714682497, 0.07606338331243023, 0.10648345996742137, 0.07861144345952198, 0.11117044909042306, 0.13884135842090473, 0.1319759283796884, 0.11915271490579471, 0.10310164885595441, 0.17436505848309025, 0.16268880455754697, 0.16841767996083945, 0.10436045748065226, 0.16007022553822026, 0.12521430995548144, 0.1617783377878368, 0.12615064799319953, 0.1813223960925825, 0.1616464284597896, 0.24651950545376167, 0.10834367538336664, 0.17846184724476188, 0.1365520406397991, 0.14005435426952317, 0.1454640319570899, 0.09100384762859903, 0.10634263744577765, 0.10129696092917584, 0.13500819535693154, 0.1263015266158618, 0.09682496456662193, 0.10202126737567596, 0.11285050073638558, 0.17138809635071084, 0.12488780950661749, 0.08315899045555852, 0.11341126009938307, 0.17421751952497289, 0.20005982893053442, 0.1903422363102436, 0.0822760647861287, 0.08970050272182561, 0.14948886208003387, 0.10697264660848305, 0.15050383808556944, 0.1714241350418888, 0.14118693099590018, 0.16313767031533644, 0.08037470470299013, 0.17138279741629958, 0.15435491659445688, 0.20332599116954952, 0.12200074372231029, 0.14286774705396965, 0.15805931703653187, 0.14729783433722332, 0.13145942328264937, 0.09747421761858277, 0.17397534189512953, 0.18859419651562348, 0.12313443367020227, 0.09590928049874492, 0.12039610170177184, 0.12826036603655666, 0.1605583360651508, 0.15654961054679006, 0.18933635903522372, 0.14577846508473158, 0.1766364459763281, 0.18571778055047616, 0.15034856594866142, 0.10337912302929908, 0.1216431324428413, 0.13795076636597514, 0.10254583961796016, 0.13310752547113225, 0.12158557889051735, 0.1076324530004058, 0.16266622842522338, 0.1873168713063933, 0.16870655352249742, 0.11932542751310393, 0.16093347687274218, 0.1223127574485261, 0.0939005242253188, 0.09548858666676097, 0.1267102570272982, 0.15376517636468634, 0.14096396014792845, 0.15123837132705376, 0.1693332675495185, 0.08904570582672022, 0.12898344051791355, 0.10369647279730998, 0.19586148468079045, 0.11672880864352919, 0.2150691719725728], [0.018936141023004893, 0.038375777294277214, 0.01830418001190992, 0.04060392726387363, 0.04959437472280115, 0.008358500363101484, 0.014781400732317707, 0.08626323091448285, 0.02013381523283897, 0.01455423582228832, 0.014075631279411027, 0.026059328229166567, 0.07834971023839898, 0.05063636490376666, 0.035451700605335645, 0.02155436381144682, 0.021917982776358258, 0.031434855991392396, 0.021810786965943407, 0.01851524124504067, 0.04293267164030112, 0.020152881006652024, 0.026775181613629684, 0.05281066463794559, 0.02598154744191561, 0.011515366513776826, 0.03276131879829336, 0.04143134399782866, 0.031792014560778625, 0.025291680358350277, 0.027894587074115407, 0.03578392672352493, 0.04007153649581596, 0.020516546355793253, 0.028924329963047057, 0.019887067828676663, 0.049529588941368274, 0.06504645338281989, 0.025352156117151026, 0.05525527310965117, 0.029779567958030384, 0.10908564494457096, 0.026524860768404324, 0.024902555633161683, 0.0203471381610143, 0.07171374483732507, 0.0647486888919957, 0.03669794095912948, 0.037702404442825355, 0.014446350742218783, 0.06652020281762816, 0.013959140997030772, 0.04539796747849323, 0.045522473883465864, 0.043180240973015316, 0.03629337028542068, 0.0267944329243619, 0.012099784617021214, 0.04875367354543414, 0.05608004779787734, 0.04145948252698872, 0.06941028914297931, 0.021324932567949872, 0.019877570193784777, 0.06341592525132, 0.051774533712887205, 0.02553543876274489, 0.04103897423192393, 0.035505224295775406, 0.07561428006738424, 0.07070650201058015, 0.046955108336987905, 0.06072254887840245, 0.06750323678716086, 0.06001041365379933, 0.019119820717605762, 0.05521038801816758, 0.025927086790034082, 0.06735335264238529, 0.024341965108760633, 0.011381069325580029, 0.0467887002741918, 0.007732884714641841, 0.04644778360670898, 0.04987871005141642, 0.013798670115647838, 0.026837831865123007, 0.04803855117643252, 0.01651679525821237, 0.10710457077948377, 0.007768547693558503, 0.014045111383893527, 0.05940563009062316, 0.039049944243743084, 0.0030844153752696, 0.07281981204869226, 0.021857928186364006, 0.0058517977868177695, 0.030098238748905715, 0.010384210072515998, 0.034076734737027436, 0.035369073593756184, 0.03904919096385129, 0.06315164646366611, 0.015323982115660328, 0.07496591759263538, 0.0700935696659144, 0.049679521325742826, 0.03726406976056751, 0.014918392844265327, 0.024071021834970452, 0.037076206208439544, 0.044915627149748616, 0.08021496483706869, 0.09395819652127102, 0.12977402075193822, 0.0441563729691552, 0.04528747282165568, 0.017808917036745697, 0.012695482437266037, 0.07852564376662485, 0.0499717122875154, 0.009866450745903421, 0.04449193504115101, 0.03625318298873026, 0.033038303154171444, 0.045821336752851494, 0.05493276541528758, 0.04858180327573791, 0.017226091767952312, 0.03583232588425744, 0.04858366235566791, 0.028813009666919243, 0.033540596123202704, 0.13247436960227787, 0.023921672036522068, 0.006681908980681328, 0.10820967319887131, 0.037432771059684455, 0.028522562752186786, 0.04776828325702809, 0.07055612062686123, 0.02822018024744466, 0.04595760990923736, 0.0076639456892735325, 0.047403603020939045, 0.05776381760369986, 0.020573845722537953, 0.04706974417786114, 0.009867963799479185, 0.05800366117910016, 0.032196269821724854, 0.06979912999668159, 0.03659831505501643, 0.0176340299367439, 0.03448795876465738, 0.010767086841951823, 0.02463163276843261, 0.047112072570598684, 0.04590161857777275, 0.06525403950945474, 0.027817583686555736, 0.027396900986786932, 0.043175914252060466, 0.05586992723692674, 0.015482872222492006, 0.07684897631406784, 0.026632249537215102, 0.0471202807239024, 0.05685171810910106, 0.027725375548470765, 0.006702241507809958, 0.02266023620904889, 0.05134414372150786, 0.03513754578307271, 0.030287909430626314, 0.08495218251482584, 0.01594655681401491, 0.034488229648559354, 0.025596313425921835, 0.04611612152075395, 0.06383452622685581, 0.01972973252122756, 0.011005165961250896, 0.049851610529003665, 0.04423062113346532, 0.026911913046205882, 0.01296544236538466, 0.08546142198611051, 0.048106242466019467, 0.017879515689855907, 0.022755609606974758, 0.011333105248922948, 0.01471931544074323, 0.024565961975895334, 0.008436875796178356, 0.06670440387097187, 0.056523911480326205, 0.05145256778632756, 0.05877186566067394, 0.06764892037608661, 0.014341162441269262, 0.058057244241354056, 0.009847309829638107, 0.09413168838364072, 0.05945966586295981, 0.08197387709515169, 0.01776868706656387, 0.1035171328112483, 0.005695266781913233, 0.013566517973231385, 0.02562919798947405, 0.056855388029362075, 0.02814577066601487, 0.06531919265398756, 0.0270543720034766, 0.11253285410930403, 0.019401599347474985, 0.03305089740024414, 0.056502726874896325, 0.05494644690770656, 0.054363946328521706, 0.04097735742107034, 0.032345849685953, 0.10518204464460723, 0.08340210319147445, 0.010145424985239515, 0.04139123091590591, 0.03910788000212051, 0.03444294008659199, 0.03287226987595204, 0.007498903178202454, 0.08456673327600583, 0.03178685663442593, 0.06095970958995167, 0.03141078072076198, 0.018691538425628096, 0.018981540051754564, 0.03140148903185036, 0.05438692322059069, 0.03680789755890146, 0.02246332402137341, 0.013504013368219603, 0.03370066624484025, 0.03143187997920904, 0.0927778180630412, 0.04924436674627941, 0.017929983587237075, 0.0051180192167521454, 0.14488874876406044, 0.07165038026869297, 0.06960866521694697, 0.06936649500858039, 0.03586938873922918, 0.09468530828598887, 0.08942130676587112, 0.038822576170787215, 0.04935952580126468, 0.023172681758296676, 0.03454340090684127, 0.020188444723316934, 0.018756201752694324, 0.06520793729578145, 0.021578676569333766, 0.034420523516018875, 0.03862766221573111, 0.030177720909705386, 0.08222939111874439, 0.07658144691959023, 0.02466424830345204, 0.06953181582503021, 0.02949338282633107, 0.04410367306263652, 0.03140230168355629, 0.027742691709136125, 0.048561138173681684, 0.01660123682086123, 0.027814874847535975, 0.018267740560986567, 0.011058344553021016, 0.0316529657720821, 0.05705914838472381, 0.03513450297759846, 0.031401114247273654, 0.03984017937909812, 0.03617090478655882, 0.05994046623527538, 0.04183927288977429, 0.047276165132643655, 0.04309255622501951, 0.04204451754048932, 0.05706987241865136, 0.030605442880187184, 0.06277410851907916, 0.02969080895127263, 0.021676079741155263, 0.019334466524014715, 0.1079547157860361, 0.09101522475248203, 0.07786093177855946, 0.036823375048697926, 0.04970610134478193, 0.0326601455162745, 0.03447455928835552, 0.046322783673531376, 0.06928745628101751, 0.0952329761639703, 0.03709903838171158, 0.008295226707559777, 0.07931934102089144, 0.03987037365732249, 0.03326430938614067, 0.033324749892926775, 0.019807190474239178, 0.04695789139077533, 0.03121389636362437, 0.020561450000968762, 0.0397409431025153, 0.00369809381027153, 0.021445336751639843, 0.024092247258522548, 0.048239543320960365, 0.04264384631824214, 0.017883378568512853, 0.011055305458285147, 0.03180828243785072, 0.005326668469933793, 0.06697458273265511, 0.07926595091703348, 0.022158709507493768, 0.04327777030994184, 0.013030269892624347, 0.07431307996739633, 0.06049027149856556, 0.016298405316774733, 0.05814566742628813, 0.10576901666354388, 0.07369329759967513, 0.038672851587762125, 0.0445789592777146, 0.06949017391889356, 0.04593605794070754, 0.06453220441471785, 0.02441225205984665, 0.06455627968534827, 0.04178016082732938, 0.036683806756627746, 0.03309161533252336, 0.038305718553601764, 0.04359199192549568, 0.032434024251415394, 0.06186462880577892, 0.1406173623399809, 0.18217846343759447, 0.1353566930629313, 0.14357470208778977, 0.19333953328896314, 0.22013783280272037, 0.09660922223702073, 0.11860664264531806, 0.08042911897064187, 0.11712460342096165, 0.10670629722881131, 0.17980465956497937, 0.15271288517396897, 0.13295073935296386, 0.1085946845705621, 0.16601623850874603, 0.1332483851001598, 0.13000126637052745, 0.07876249277614988, 0.0694874428154435, 0.18276162823894992, 0.1687216042773798, 0.22818042780272663, 0.13769846584182233, 0.1853103266330436, 0.061979539241292514, 0.12322009235504083, 0.11980462484643795, 0.14930727338651195, 0.10320128218154423, 0.1663954759715125, 0.15100284334039316, 0.16629625082714483, 0.12618135806405917, 0.21242204995360225, 0.07048245504847728, 0.15948421088978648, 0.13409140548901632, 0.17393885791534558, 0.11387805614504032, 0.1512603388982825, 0.1614420409896411, 0.10708200206863694, 0.08658304461278021, 0.16420833708252758, 0.2192886674311012, 0.1716174348257482, 0.13510544638847932, 0.1707605956471525, 0.19514174986397848, 0.0948376786254812, 0.07391264676698484, 0.13788642216240987, 0.13946584600489587, 0.1136505433532875, 0.12206256462377496, 0.18366042844718322, 0.12013971936539747, 0.14159865968395025, 0.1682908766088076, 0.16463936161017045, 0.13052045804215595, 0.09904905498842709, 0.13368901301873848, 0.19468222686555237, 0.19369622430531308, 0.07113909246982075, 0.1408677629660815, 0.15291322051780298, 0.1432375592412427, 0.1280843879794702, 0.11822910470073111, 0.08849346631905064, 0.20160474290605634, 0.17465313052525744, 0.1948795936186798, 0.10957483158563264, 0.11334115682984702, 0.1643329139915295, 0.16050135396653786, 0.11124614073196426, 0.1510473870439455, 0.10618915388477035, 0.08720186218852177, 0.2508863469120115, 0.12132796458899975, 0.13548128481488675, 0.1576289307558909, 0.14709696464706212, 0.1140098986797966, 0.06412952250684611, 0.17367487598676234, 0.17767260287655517, 0.11752988284570165, 0.23895439342595637, 0.17160520423203707, 0.15074312133947387, 0.14807514497078955, 0.11391445848857984, 0.08939616280258633, 0.16460599465062842, 0.09958478913176805, 0.11155953485285863, 0.1667308376636356, 0.07831442111637443, 0.11829124472569674, 0.22075296932598576, 0.1289731840370223, 0.11902456826646812, 0.17954573908355087, 0.12126929781516083, 0.1780717002111487, 0.11168181852553971, 0.18959461158374324, 0.18279040872585028, 0.23434650240233168, 0.196610089042224, 0.16646220989059657, 0.16538443334866315, 0.10592873426503502, 0.16254782618489116, 0.2217856381321326, 0.1339332092902623, 0.20059019734617323, 0.09483502915827557, 0.14146504341624677, 0.11292847077129409, 0.14136884623439983, 0.21051550225820392, 0.16371618927223608, 0.19121918769087642, 0.10385196015704423, 0.14071974903345108, 0.09399116272106767, 0.2320290869101882, 0.15789043391123414, 0.11624590799328871, 0.23321356944506988, 0.12600257468875498, 0.13048542867181823, 0.09911036380799487, 0.22295732604106888, 0.11098643357399851, 0.13658894022228196, 0.094169782823883, 0.13169021636713296, 0.11370958862244152, 0.08292623810120858, 0.11552396157640032, 0.11144243137096055, 0.13307322340551764, 0.20291528664529324, 0.31917393731418997, 0.19132665067445487, 0.10609988094074652, 0.13559553102822974, 0.13731959945289418, 0.16548760671867058, 0.18541630532126874, 0.2094020284130238, 0.22663750278297812, 0.17302349297096953, 0.1732993937912397, 0.057950323025579564, 0.21371899754740298, 0.20872382418019697, 0.22673108760500327, 0.06984207066125236, 0.12937476014485583, 0.1248576189391315, 0.09782073379028589, 0.07572528309538029, 0.22721029235981405, 0.20112346013775095, 0.15254996891599149, 0.2191111902357079], [0.045891651534475386, 0.002597483471618034, 0.02011774959100876, 0.0655591141548939, 0.011500967921165284, 0.0164551506168209, 0.06849312820122577, 0.07061394877382554, 0.020605856407200918, 0.029463641258189455, 0.04685501859057695, 0.0451232726481976, 0.04894706238701474, 0.061580723922816105, 0.038245140749495476, 0.014893894549459219, 0.06385888351360336, 0.0754036585567519, 0.007743797532384633, 0.012262685104360571, 0.05181625725526828, 0.04296137791243382, 0.02709928492549807, 0.04994275739591103, 0.019155492045683786, 0.03183647662808653, 0.04787092228070833, 0.031523917423328385, 0.05814187134092208, 0.06189425534103066, 0.06700550060486421, 0.024686813303560484, 0.03834075163467787, 0.013511721499526175, 0.07989751116838306, 0.025022419904416893, 0.037425527698360384, 0.03552633097569924, 0.043913805711781606, 0.04719392774859443, 0.04650422764825635, 0.04418721662659664, 0.0480943718139315, 0.04418748008902185, 0.048480615150765516, 0.06757701368769631, 0.022267528765951283, 0.06256437016418204, 0.04361850515124388, 0.04757661990879569, 0.03375683940248564, 0.013653420683112927, 0.037616886766045354, 0.027146162683493458, 0.04193814551399555, 0.022868375235702842, 0.055688075080979615, 0.012141368079028325, 0.009654102814238286, 0.005156220340722939, 0.054172850723261945, 0.013351306279218988, 0.07925615456770174, 0.007434904073306825, 0.04407241380249616, 0.06894485864904709, 0.02955191972432658, 0.03190106574038509, 0.07136765168979764, 0.015395398058899445, 0.06522419032990001, 0.024141876529029105, 0.05678967085259501, 0.10147768130991608, 0.02774276777927298, 0.01674764400377171, 0.03977847722126171, 0.01601368778210599, 0.023168711268226616, 0.024589718123024795, 0.013249537423689617, 0.06002667410939466, 0.0635449105175212, 0.05298085023241583, 0.010102685628226027, 0.058529331799945794, 0.008104863973130705, 0.03052282514545368, 0.03740027983440086, 0.03718120155099314, 0.03157329992973246, 0.07713616520049982, 0.050372186306049116, 0.01323656282693264, 0.03364349860930815, 0.049441213996033184, 0.04405087667691987, 0.03664607967948541, 0.03186832218489144, 0.036758270143764094, 0.04129853296035435, 0.056679832996451296, 0.03724159010744188, 0.01022110178382718, 0.018973745645780582, 0.00543063825716672, 0.02586336970125558, 0.08439638069830835, 0.01193575699289795, 0.08746801860979758, 0.008469995063933311, 0.06203315941093024, 0.008958301332313567, 0.04092917348316405, 0.016494471456098836, 0.08801682939520106, 0.05074264787253924, 0.026361239470134024, 0.008982073250081157, 0.06696836353512481, 0.015501598463742994, 0.02272043737320928, 0.03260486664657947, 0.025013710801431444, 0.05884305988729466, 0.04616188605723437, 0.06756274960935116, 0.004050693969475105, 0.043753613135777414, 0.03813443458057009, 0.056633022031746805, 0.04481892530748155, 0.011659129795589251, 0.04608139643096365, 0.06986799387959763, 0.016409677373303566, 0.08509391045663506, 0.023911601092549972, 0.0404840444389265, 0.02665612628334202, 0.07589064101921394, 0.03705815346620511, 0.0813042075606063, 0.050315493645030074, 0.025249472564610187, 0.06585163908312097, 0.03817361997789703, 0.08449080414720811, 0.05151124940312002, 0.02639919846842531, 0.014252321798267076, 0.02380096171691548, 0.03288237792730797, 0.007878226915636333, 0.06880596571136266, 0.061497273127315566, 0.030709491984453052, 0.01651904767641099, 0.047665595993748866, 0.0518975224258611, 0.02486511799361324, 0.037624445540132, 0.011431078019086272, 0.00842884111989406, 0.022123926901258528, 0.011237177095608786, 0.046914230842958204, 0.018129146337741986, 0.013499816523108166, 0.08393017837079242, 0.0011404911515455751, 0.04656009281461593, 0.011472672613308532, 0.04336008190875873, 0.04649143673304934, 0.041674356543808244, 0.09265152679290622, 0.04401270802190993, 0.03657553483208176, 0.030154779269651044, 0.042791967862285674, 0.09084575533051975, 0.010875910738832317, 0.031872882682364434, 0.04583390873449389, 0.03646752636996098, 0.04698123564594425, 0.035732395699596964, 0.008116055560094537, 0.05294651477015577, 0.022352103915181942, 0.037545785307884216, 0.10438613579026423, 0.07960350936627947, 0.041601451666792855, 0.02909144121076679, 0.042994058385374956, 0.004143033374930383, 0.026704553274612408, 0.011345188340783352, 0.028121578507125378, 0.027602483314694837, 0.06095457021729089, 0.03238490149669815, 0.06137350144854281, 0.02958640361612197, 0.08152349735610187, 0.03731169337697793, 0.029629366545123048, 0.02123732574546011, 0.04479005576285999, 0.04676816504797898, 0.039320245559792966, 0.03169701594742946, 0.07929515442810953, 0.05203025182709098, 0.030125252924335655, 0.06515859931823798, 0.009215762565872865, 0.06448679239838384, 0.023238985231728293, 0.052759037134819664, 0.06863602131488733, 0.0814329256536439, 0.06405404608813114, 0.024219360457209405, 0.07046453960356303, 0.07588185399072245, 0.010128247049578931, 0.04063929431140423, 0.023283688497031108, 0.08269085854408331, 0.026434225983393844, 0.0464874402678106, 0.022608063227380626, 0.04885889895376749, 0.01864995403593639, 0.02210442140494706, 0.03810913105553482, 0.02778452842903789, 0.02486595476511866, 0.027866472664754838, 0.034827053459594026, 0.004741812035717885, 0.02880614480091026, 0.01606295525562018, 0.02345702079765033, 0.016326950171787757, 0.06068545262678526, 0.07745308452285826, 0.020312362976255827, 0.05243404695647769, 0.024135978310368955, 0.04677707824157551, 0.030548340182576794, 0.010215351067017764, 0.007173659278123523, 0.038044163447921164, 0.0538876693462953, 0.016590705745329615, 0.04503194766584784, 0.03125458832073491, 0.05239462036115583, 0.01784728236088995, 0.04363145191746298, 0.048778605996631086, 0.028860605452791788, 0.02695613948162645, 0.038355820943252183, 0.038469903884106316, 0.023536521512141917, 0.010251545609207824, 0.053194911597529426, 0.019656272888823878, 0.03483778491499834, 0.036197692606947385, 0.09564696098095737, 0.08780401112744585, 0.02541055015171878, 0.006770116942789173, 0.0922311595059, 0.04358205827884376, 0.031749244590173475, 0.03834042508970015, 0.008415376705670496, 0.06899180691107176, 0.0094133927814255, 0.021592089033219963, 0.040012164681684226, 0.013988943792355713, 0.08528194099199027, 0.0655259624181781, 0.03718736508744769, 0.014333622220874531, 0.02400558667432051, 0.04116564028663561, 0.02339919450605521, 0.038911318479222246, 0.016132687451317906, 0.054635494452668354, 0.015938400611048564, 0.01211122111271834, 0.10274299114826135, 0.054151265358086675, 0.030448397010331973, 0.028190852426632773, 0.02671185415238142, 0.018300938681932166, 0.002993591110680427, 0.033386444629286416, 0.059160877208341844, 0.038984026687103324, 0.06131475303845946, 0.03996713858214207, 0.014129879491520114, 0.1167903326859232, 0.014238020612538094, 0.17484065640019253, 0.038547502845176496, 0.08963841464719735, 0.03389006604265887, 0.01098759654269088, 0.06211724103195593, 0.017478459085396025, 0.022568595813936554, 0.031131180294323713, 0.03192888143530581, 0.030634722461400088, 0.031452778857783414, 0.0463769344787579, 0.0473353143024724, 0.03173421609972138, 0.0489243415358942, 0.031212749745463952, 0.02043252781732008, 0.021904106470174156, 0.03132344478217419, 0.027508434650371782, 0.07016785122686997, 0.04887960116320755, 0.031729711263324134, 0.09916027323924936, 0.031441843311768025, 0.09690617036540061, 0.023952124211064074, 0.09916950555634685, 0.04563882408547215, 0.028154652318335138, 0.06263102986849844, 0.029949065210530534, 0.028974256092624273, 0.12699564249487594, 0.23712194175459445, 0.12875932676251978, 0.07856407959479839, 0.14054801606107503, 0.12761891295667738, 0.20121787616517395, 0.11828800896182656, 0.09541156658087857, 0.09187236079014838, 0.10225145932054147, 0.1521773068816401, 0.18937262037070468, 0.09227140617440455, 0.16874915279913694, 0.13307165005244315, 0.08649308889289387, 0.13227045710664243, 0.2894496463704854, 0.10153666720725596, 0.17984636826440692, 0.10502424920559861, 0.12103938788641244, 0.12148053530836478, 0.1455971138784662, 0.09004289997392334, 0.11706183999194764, 0.13441891525872052, 0.07932261389214545, 0.1276039215736091, 0.12139800848672166, 0.17759341571945697, 0.06932058575330302, 0.13435097906040028, 0.12019689442240633, 0.19122331403195858, 0.10844383563380688, 0.11429289443185553, 0.14101577689871192, 0.09944838238880038, 0.12846064200857654, 0.13315082236658782, 0.24957143934443593, 0.12029594887280837, 0.2181869195192121, 0.14476869895588607, 0.1605296297930181, 0.14398950326722115, 0.17437234637327492, 0.12891305523226038, 0.23003811249509454, 0.13741147733526304, 0.2236554049886763, 0.11583760802750476, 0.14185790671035647, 0.10866814234759659, 0.10572609084192663, 0.11456978973001242, 0.1448812976013869, 0.09212259072228335, 0.14626653108280152, 0.08677893449203111, 0.06493661552667618, 0.1829165589879267, 0.11988643178483471, 0.10392834941740148, 0.10702478248276748, 0.17094840353820473, 0.09023234058986418, 0.1335347502026707, 0.23236366192577407, 0.16310963197611272, 0.08090650546364486, 0.22725275804987177, 0.20950291596818715, 0.1393889743485488, 0.18652920029126108, 0.09362146185594611, 0.12457223347155377, 0.06771581756765954, 0.1393408386502415, 0.08922242603148334, 0.1869097290909849, 0.09008084598463029, 0.13796203216770664, 0.10674850316718221, 0.21721955970861018, 0.09410054786712863, 0.1359077970846556, 0.09163153386907652, 0.1392969480366446, 0.14180258702253923, 0.19295076665002853, 0.1522938092239201, 0.13345943705644459, 0.1432541833491996, 0.14501872850814834, 0.2097650128416717, 0.15237305575283244, 0.10898627879214473, 0.0823650779784657, 0.11996048328001052, 0.17709562758682296, 0.09866592867183499, 0.10891983431065455, 0.1702734944410622, 0.06590885124751367, 0.06440735291107558, 0.20077206805581227, 0.05866268831596244, 0.12698896316578612, 0.13160623493604362, 0.19446529709966853, 0.0710516377876047, 0.16886810422874987, 0.11775496881455183, 0.11214259575353935, 0.13906945008784533, 0.1229893957497552, 0.10195091919740662, 0.18983932735864073, 0.14529458479955792, 0.14830197498667985, 0.10127169080078602, 0.1329080361756496, 0.11557189689483494, 0.12269244762137532, 0.17657468444667757, 0.1371060241945088, 0.11281160477665253, 0.14246189617551863, 0.14406557340407744, 0.14333921862998977, 0.11074680893216282, 0.09302502003265545, 0.13415401306701824, 0.10186172788962722, 0.20699773711385205, 0.10538321861531585, 0.10304933486622758, 0.21212127234321088, 0.1411601691506803, 0.3084880794631317, 0.19645747379399836, 0.21860062232008204, 0.10691538249375299, 0.13120201678248122, 0.1977864673244767, 0.1410474072326906, 0.15926503983791918, 0.08309343655128032, 0.13138436246663332, 0.07080684779793955, 0.1617034847731702, 0.13729107129620388, 0.26754705759231, 0.13727018726058304, 0.17955651506781578, 0.12216570088639855, 0.1312305746250786, 0.10440161699079908, 0.12394724122714251, 0.11426013603340834, 0.1578710786998272, 0.0742100179195404, 0.17990376596571878, 0.1126687487703748, 0.09384449207573198, 0.19060457067098469, 0.1986537707853131, 0.2903545321896672, 0.2264917004504241, 0.1807170410756953, 0.13806205883156508, 0.16392795369029045, 0.15336036449298263, 0.2303838197258301], [0.05276446965581272, 0.03384758179890923, 0.018449121453159023, 0.02784828633593861, 0.0439004618965555, 0.023357797508651856, 0.050719132923404686, 0.023881941160652786, 0.01866485079517588, 0.024184991598303895, 0.07171556309913285, 0.08283885021228343, 0.032485035771969706, 0.044330510500003584, 0.012094388275727397, 0.016313072010234464, 0.04054483746585902, 0.04136383082368411, 0.04679103432863485, 0.024046378821367398, 0.06885087306727655, 0.019726454083865974, 0.05401377136877272, 0.04237653956806753, 0.021370609902078286, 0.025970882779802196, 0.014280576288001612, 0.06419295386876911, 0.026509769195399713, 0.04130359440750908, 0.025412815557501744, 0.033642537528066896, 0.054373445818782784, 0.04114060022402555, 0.044146476429887116, 0.030617346928920597, 0.12861224793596193, 0.025380077568115667, 0.03643609270511661, 0.04243666466209106, 0.04551032492599916, 0.04424183498485945, 0.08597091378760524, 0.027245363708061632, 0.008487725899612997, 0.03014637444721302, 0.06812690058723092, 0.05474480909470003, 0.026602459729474504, 0.022273913091339637, 0.03277697069279384, 0.04674920688557904, 0.05957154091447592, 0.06677821045741439, 0.04033417142636608, 0.014840972926322138, 0.07140179048292339, 0.09471704994211905, 0.029972121883474756, 0.044689301794278435, 0.011669757350318832, 0.017704083111311775, 0.04883094225078821, 0.049843955275719054, 0.02271409386594314, 0.035070017765974626, 0.019430198008194566, 0.07151161349611357, 0.04134956303460058, 0.033697334001772106, 0.057944608488469385, 0.053214567378745414, 0.013690815649169963, 0.024315114205819555, 0.10276901084580459, 0.05904111312702298, 0.013873531479475787, 0.05196414131205529, 0.010655959504219936, 0.059530155049287714, 0.021052933589089662, 0.03445304071647115, 0.05206482848734595, 0.12399625265970826, 0.02428711854008725, 0.014826334063400282, 0.04410094195918646, 0.05180632731935475, 0.05104940719320439, 0.02131708064553095, 0.08223218159400858, 0.03158064719173126, 0.01206432572871563, 0.03190976000041701, 0.012362829584162682, 0.037337946851039305, 0.06384223714121617, 0.03092709153861506, 0.03216939665435348, 0.06303016431047581, 0.018072561288136058, 0.019476194465823937, 0.08397881872951984, 0.00933943683776306, 0.04734358182759024, 0.008522671778337099, 0.04278083193639759, 0.02362401515711099, 0.0015385582923954644, 0.05869859713129699, 0.055759384340490215, 0.07301218414795585, 0.054803052844363265, 0.05690661106200423, 0.06490761981694959, 0.03364342439454049, 0.020825201863772236, 0.02382578470133012, 0.08414790223469026, 0.05075403612863738, 0.04583259884384461, 0.023563339018437546, 0.02388899156358093, 0.020265436978661455, 0.023456479029846378, 0.02571166172856465, 0.04038760234834626, 0.026549646645435132, 0.03166912603774108, 0.043360330528230406, 0.03176709695253521, 0.08262597999419086, 0.013031452690484002, 0.03202017302101012, 0.01826171988795977, 0.034644336701603606, 0.025433606824663002, 0.06775727393687703, 0.08160038385540247, 0.02300952430232428, 0.03249996778322384, 0.04021996232040692, 0.0133349261523108, 0.02881788557715481, 0.024917508053476922, 0.027027537798858248, 0.022336806396197062, 0.02882552598748589, 0.00960266734182369, 0.04461781441932544, 0.022000361168466043, 0.04463960758585017, 0.023529539757873863, 0.010545604927756358, 0.04919155551760923, 0.07567990076495335, 0.11651418695691973, 0.06874946600873955, 0.030081917066127062, 0.04739579562738072, 0.009960088445950532, 0.023523129457316827, 0.044752714602509513, 0.08647009715787135, 0.029856986948288977, 0.017252775687666144, 0.04416619529365562, 0.04530835314653814, 0.044296004343777895, 0.024748161085881293, 0.033077469997806475, 0.021152331282792147, 0.042450665278011, 0.024445223825750872, 0.028995279280934483, 0.03814263160165865, 0.05256265743810218, 0.036255851009627804, 0.016370512385037728, 0.01255932616913924, 0.017732214218995068, 0.03534115770889912, 0.050931973455590196, 0.03784228072618134, 0.07122086230083369, 0.036913263975293376, 0.03697983833262697, 0.06496978952782229, 0.03065440607315395, 0.024609511201560963, 0.019344073625688907, 0.05930274615820963, 0.0166863407503115, 0.05341536656487733, 0.030887108332535718, 0.03868747560773045, 0.0343595449521672, 0.022457865525211673, 0.02910963310569059, 0.05269235887681134, 0.0658816663781181, 0.026939391063933726, 0.031899715031613596, 0.05073180509498343, 0.05458599320263602, 0.02978742359118769, 0.0188891537982272, 0.03383435672731139, 0.06131354333774652, 0.02674847171874717, 0.051787832999252714, 0.009964800156012643, 0.02312026572326431, 0.05028190033044666, 0.06151582310849335, 0.06630806732573546, 0.04730449662019964, 0.06634798002778552, 0.01751666855852818, 0.015486987431359012, 0.0678596828947775, 0.02442240649543237, 0.044485882826847956, 0.007361770985880867, 0.10254461507429369, 0.03319932693557348, 0.01910074381157756, 0.06308571406407282, 0.03978288557846099, 0.03491702773317229, 0.0534017629979644, 0.030161070826579817, 0.02764454453426879, 0.028406223682395648, 0.08774832778726704, 0.046376812024391256, 0.026977190500474535, 0.06342399981804192, 0.021710029286623467, 0.05454634767374955, 0.04432004250702448, 0.028148681740276515, 0.0075600672789732926, 0.05838152195792645, 0.030184389106580056, 0.06762514196452685, 0.0392686477425741, 0.05446614006359596, 0.009661992771725636, 0.04873377285548486, 0.05082987619971391, 0.011961746076849522, 0.04472775988688227, 0.029360482731135562, 0.049065360726672225, 0.03170679745380767, 0.05193867451453116, 0.023174164198280778, 0.013650898308696924, 0.05254477910057176, 0.056890881241997704, 0.022721582136000507, 0.041004390150192194, 0.015986417565727606, 0.03026809779839823, 0.010100829331349814, 0.02461320338625228, 0.008726939577172743, 0.020375165368022863, 0.014114102359599201, 0.05224648026342038, 0.04522656847257167, 0.05584960352280177, 0.08072670534602366, 0.04098499412066303, 0.044993593473918736, 0.0649172232078854, 0.04323166809626855, 0.02667351294803666, 0.030646960476587992, 0.006830861730122706, 0.039327589111053385, 0.032352833295590244, 0.010879332967306254, 0.03993254707893357, 0.06034665850165766, 0.025781028416531626, 0.06461086464696564, 0.01205666583700804, 0.014478121156571433, 0.014711895819345955, 0.03017383391124895, 0.00408319818234304, 0.02658726054505678, 0.05861587735125795, 0.05299849850416649, 0.00928923054743791, 0.056715968166827224, 0.03400804154807702, 0.002968580038213986, 0.0662299340183381, 0.06969848735025153, 0.025846602729870938, 0.022786542322137393, 0.028183568247186486, 0.05830073918332346, 0.02885173678805586, 0.0381172353081638, 0.023747022423776798, 0.03499087513773702, 0.038960559977567755, 0.03296717201010324, 0.045028077365714125, 0.0556762823543977, 0.05890677326533478, 0.013810821856168332, 0.023579495573358145, 0.03596753034798894, 0.04539312867564149, 0.03147996743791737, 0.0497541554068448, 0.04781272305990569, 0.061219891722430475, 0.022894114772498142, 0.013992763997521251, 0.046389020353672095, 0.061387895402731374, 0.0394876221253071, 0.04846587609790731, 0.08216214511776343, 0.02396836796833668, 0.0586387948715128, 0.04098091601917986, 0.05139593078638427, 0.014067881402297644, 0.07039905991405249, 0.04122793616261333, 0.015846823298488744, 0.019249062024755403, 0.014932591057004174, 0.042346905611339025, 0.02947258784843143, 0.04405060208227951, 0.0647485998342745, 0.04009385287645273, 0.040035126730799675, 0.03579572316084523, 0.03205655681085773, 0.05617168819298968, 0.022518404366564937, 0.06560319772688672, 0.036592400138033554, 0.1829611323773861, 0.14033463376108557, 0.07718029330135323, 0.10777723116916604, 0.13207423326093704, 0.12014697756967507, 0.18859498319216073, 0.20003919722512364, 0.1437100549810566, 0.25213110668119043, 0.1454729525721632, 0.16585241683060303, 0.18766992579912767, 0.11846652516396716, 0.14696509984787554, 0.13265088200569153, 0.10037187385023572, 0.10355786929721944, 0.10640675158356316, 0.07842290826374665, 0.17332673451164737, 0.09142519455053844, 0.16367341188015416, 0.14438500860705972, 0.09688113030279055, 0.11668658786220476, 0.10844817719771527, 0.1660184352658689, 0.14772470283787698, 0.12735347641864792, 0.17507055890746415, 0.1518538047093898, 0.13734676205785945, 0.14049796562176198, 0.08886218754923902, 0.09221538144629449, 0.160865347716026, 0.114871673140442, 0.21257487300317734, 0.17263653717236593, 0.14937421510694548, 0.1692132919561118, 0.14183690393110737, 0.15189880854450166, 0.11838651422294788, 0.1215282034536358, 0.19306268251966685, 0.11668591250781901, 0.2105310428305529, 0.15948707557981834, 0.11057238938519731, 0.12873691390268505, 0.10639611660735682, 0.14642895752331242, 0.17693692672764882, 0.07890949738794006, 0.1656429233844392, 0.1589981041615829, 0.1258825694094412, 0.091298918123357, 0.1290891520329751, 0.14154926233459264, 0.1522196686710231, 0.09459066961426288, 0.09757656720466912, 0.13650534470798448, 0.16202309809159487, 0.26962999894749373, 0.10928942385362461, 0.213068223092705, 0.10781589706311934, 0.10519499512156472, 0.10202266261330806, 0.16505794774275273, 0.15077114483574405, 0.15544045600108802, 0.12488972424762323, 0.13083413417916745, 0.10244766832329333, 0.13943486876087263, 0.1122893851425033, 0.12924812006531283, 0.1541550413821824, 0.24376310961088166, 0.1355257394607179, 0.1217015172005631, 0.13718135218368843, 0.12886923883343115, 0.09941549782524817, 0.10421308179502375, 0.1306827657390386, 0.08338501895195805, 0.10303441769792698, 0.08520746647263877, 0.10529820559895597, 0.13114501984091476, 0.14438248530495912, 0.10225733713014051, 0.13356600946281105, 0.15095399518031627, 0.1418497134000063, 0.20440599415451288, 0.26063686120323837, 0.11777124411310069, 0.21221315022557974, 0.05891825057915412, 0.25126196269411594, 0.07706417687586509, 0.22531483235070482, 0.15119375340873376, 0.19877241051290184, 0.2444770556758158, 0.1601333377766423, 0.12155495045590214, 0.12365432296064682, 0.11356414994224906, 0.05326838421751745, 0.08901889945263974, 0.1583219927852042, 0.15319235710194334, 0.25172325200401247, 0.13161016831872985, 0.10408524685772136, 0.10740875484771095, 0.11891413669218309, 0.22604302765103057, 0.06523553034639917, 0.12424608183209784, 0.17068240296794102, 0.11295612319372594, 0.11168749595526606, 0.13973196531878784, 0.11746846270398237, 0.13725347409490496, 0.07735030449111946, 0.13807693147100508, 0.1871603078325279, 0.1776749183773063, 0.24402496899710968, 0.10268527432344854, 0.12221877186675556, 0.11198913445696235, 0.10021104302722961, 0.08821690498734824, 0.12151258124504238, 0.1850062984158285, 0.14480025507509708, 0.08556452114135027, 0.14365684299264103, 0.13432343053864315, 0.11991795821813866, 0.13105829246342182, 0.059267178730806336, 0.0918169372016564, 0.1798492032685317, 0.13652170164277777, 0.18262813071487471, 0.2171144270687364, 0.08395865457714535, 0.1273808319820091, 0.2510758023709059, 0.12301508148084395, 0.19213639316149056, 0.13440419104881585, 0.09672357977251522, 0.13853151176590472, 0.16087990865344182, 0.18025164026767015, 0.15618640347383916, 0.14651785197202116, 0.16706097463611513, 0.147153917059768, 0.12858429865445942, 0.13923471153248101, 0.1804970091325231, 0.07471191012882628], [0.029203420162957627, 0.046747533342568204, 0.020118193024245556, 0.020549391956592444, 0.056079261121340096, 0.07966734890942462, 0.008098000034806319, 0.043749460819526576, 0.028368255407258403, 0.04677089615142904, 0.04793824249645695, 0.019443666133156512, 0.022848366934340447, 0.007281589814738254, 0.034385946855763905, 0.049790145858423784, 0.01270574448426487, 0.09211073120241053, 0.060613787136389874, 0.027687858128047083, 0.03697613130498212, 0.08415131611400284, 0.035040855073020793, 0.015395635546155972, 0.04627111164154485, 0.02220076887169853, 0.1772555010393262, 0.04621155429049395, 0.021238912086118944, 0.025155095499940217, 0.04397837627038825, 0.029439849859045353, 0.024901993456296623, 0.09951700136298314, 0.027088709321105853, 0.013184217295929557, 0.08284555922728032, 0.013567032838182058, 0.022409214034269098, 0.06841364418505691, 0.0742942516808398, 0.029182350590417627, 0.012705947647191351, 0.0217596641232376, 0.04860615685174707, 0.022864955790282693, 0.026135500411328394, 0.05761410415288992, 0.015894999814918265, 0.009689403996162582, 0.024654476073919795, 0.0243716732802568, 0.03773306627408601, 0.01900568026030669, 0.06921391686773859, 0.02423470807116246, 0.021637627214659005, 0.02286847542563919, 0.05851562804309651, 0.012792624002031516, 0.06823365853051655, 0.059994672701577656, 0.03334916284075007, 0.01591397653101012, 0.04172294124145992, 0.033449297116021626, 0.07471688251825981, 0.013091581495245919, 0.0868984054250177, 0.04573472440824844, 0.047518602514173836, 0.03535453121003229, 0.10465482293511741, 0.009904557246045442, 0.03645803801191505, 0.038631870193057694, 0.07251426242874004, 0.04248001721862238, 0.042907379247481, 0.021574375823547598, 0.010750292967713904, 0.05061355870566331, 0.06887331561301835, 0.02222475322923856, 0.031907002921798266, 0.01312407086516032, 0.05911057443881873, 0.008120360944303684, 0.025694855794426985, 0.02581649379862938, 0.03811956936260685, 0.015604283871653024, 0.038029635907150805, 0.04848768781812396, 0.04476297108340077, 0.03787464949709829, 0.0696982721274253, 0.04003514157375321, 0.05057675931311678, 0.01120203083701199, 0.030998508409538772, 0.05180052372452337, 0.0419276218599407, 0.028340395183477085, 0.036281659195083193, 0.0729671580484137, 0.042233204876538366, 0.031906887888908386, 0.028657160510192625, 0.015637315009371378, 0.02907235873863101, 0.04075696553627495, 0.030785901653871406, 0.064317404612666, 0.060069551691412926, 0.03807429093285464, 0.055542447153129615, 0.05474130615766626, 0.061037208361085504, 0.04623260902008042, 0.024495044199284166, 0.0526082438591402, 0.07580020290333778, 0.018056172812066507, 0.04506436838710215, 0.023904457921162248, 0.025824486729106866, 0.03587245009839535, 0.015674721107643563, 0.03635311317339074, 0.059126957348780707, 0.02718692885537166, 0.06959567021112889, 0.06356876314384863, 0.04061359373736195, 0.017316374032816384, 0.03642559873696882, 0.027242074138484895, 0.01826843261369504, 0.11195643543032929, 0.059859419998247176, 0.04890330535999965, 0.05464304951601662, 0.04448501451406628, 0.06321241351542994, 0.11361196651705541, 0.03535703966917936, 0.10773514397442341, 0.033123564790003, 0.051351079091546126, 0.033339897127007134, 0.02897242669860134, 0.02326536301552551, 0.07049942054436542, 0.02879051517084008, 0.04362499152193777, 0.030053965929255355, 0.006827905199315865, 0.026388173864688724, 0.06594935024622828, 0.0325632952444721, 0.04068518872372806, 0.0687884287617635, 0.14305911725386977, 0.030734958781977184, 0.03403564573090989, 0.003037662854694645, 0.13090183289023116, 0.05533182935323566, 0.0702759153500665, 0.02018090079218382, 0.052290036910562776, 0.07790869640302844, 0.037724197609350085, 0.041197975660907105, 0.03478189748420846, 0.0555993290618062, 0.031573745218338445, 0.050613139392226, 0.023838952256483026, 0.059199999523116276, 0.017957420786842704, 0.03827083761279937, 0.03147152179735713, 0.026869328612519894, 0.06502479751361534, 0.034449567465344444, 0.04578022919304203, 0.01521733920526458, 0.08099859856883995, 0.02341281662666006, 0.03871616332617123, 0.03973899867560249, 0.07052798580843955, 0.02505085343727842, 0.0679169841168914, 0.024225639026553836, 0.01729247873299755, 0.022673715466225985, 0.03758637707505841, 0.0031885447242530063, 0.05705298484826926, 0.08319855434820056, 0.057353528682142496, 0.02851836590707535, 0.053397870433400385, 0.025983887062466238, 0.030955204092606436, 0.07326631035539322, 0.10210251028183848, 0.005819555644848151, 0.015709561230323743, 0.024982657487271354, 0.027899665219592862, 0.011169915323989699, 0.12148569323471747, 0.12100063293473795, 0.07161198896938004, 0.012520281779870857, 0.056008293249760754, 0.016503319711773656, 0.026513088450883515, 0.030274561904661823, 0.03616566893470008, 0.032884207321330905, 0.015728374673926737, 0.022436144718085416, 0.03836669711745344, 0.05225410212005954, 0.03523746854625642, 0.04359771017334424, 0.031685586873209104, 0.02990754204802215, 0.11819527018815279, 0.03426121409574989, 0.04433725291164592, 0.020099544708500616, 0.0461849408748094, 0.01648946010391228, 0.04721156488812994, 0.0431782520172419, 0.023375512573693413, 0.07699445210164413, 0.06673134383163415, 0.10908896976616234, 0.041351429536007345, 0.07020069868303835, 0.024470935532008298, 0.039864974532974884, 0.0073100553527183365, 0.032074386908789165, 0.05827343185956124, 0.012910893583466532, 0.040220563460025005, 0.01346946175544872, 0.058432763544260524, 0.02340537845157087, 0.012696129961113911, 0.05855538489413448, 0.05750677104515489, 0.020019500370835885, 0.018621268172864802, 0.06433213624404743, 0.06449302643886767, 0.041732047393452376, 0.03269677792559378, 0.008009651992324507, 0.03697116633702535, 0.013747276389040053, 0.048800933509483, 0.08315018116263673, 0.029923177244199906, 0.06322314497083426, 0.05862677578988951, 0.04505580029217526, 0.03464957255346235, 0.01845444450736977, 0.0470891402073903, 0.05008791405998636, 0.03631750863860361, 0.10467049709404819, 0.045264751970535144, 0.02036640431470005, 0.059937890982837416, 0.045731369900749996, 0.06023887268383987, 0.02044126289547421, 0.047274602911784314, 0.03422970250539947, 0.06430331864976324, 0.010562243878666777, 0.09284517538617365, 0.02614982757222606, 0.04388518849737011, 0.05751066732045729, 0.011549522932909895, 0.016350199803127907, 0.03157913692120928, 0.07802162901498377, 0.0428373984323116, 0.029859727328584995, 0.030718282723682933, 0.026423874878673814, 0.022925271987332962, 0.027462798134365585, 0.035703374014701694, 0.027606374023889657, 0.042195563146378845, 0.03734210287802853, 0.03325263169244863, 0.012652825644181576, 0.04907112721411977, 0.0743380755011458, 0.037496528966585174, 0.023260997331817634, 0.028455671126721427, 0.04932689727866091, 0.018339034977543633, 0.05442685818707105, 0.011484074784675613, 0.061027122574159876, 0.06648478753049858, 0.00497383754918701, 0.04141029297898058, 0.04172708242549561, 0.021219347217993345, 0.04642802392481826, 0.024887562394724227, 0.07140230998629704, 0.024624237266834825, 0.04046762813231908, 0.014063642811379395, 0.0345973735966254, 0.04434523099916987, 0.05104841271531768, 0.044355413265293464, 0.05418271757662296, 0.0239055525889853, 0.044125417989562266, 0.025863673981803004, 0.031265186189557426, 0.04020160900836345, 0.032725714263506234, 0.0532263452623738, 0.008522998323314823, 0.05761192223872058, 0.035125088834320195, 0.029369503536145203, 0.07116088934708387, 0.03924397875380237, 0.02068999925540993, 0.03197805242962204, 0.14105199370533228, 0.20380605681566522, 0.12657613609917462, 0.1445079973200336, 0.15595559554640204, 0.12991915515158325, 0.1687069097533822, 0.15497676213271916, 0.12856068351538852, 0.11166854892508127, 0.08833213083562441, 0.08067557879257947, 0.06203326331160497, 0.11949062958592549, 0.06269017161685042, 0.13378044561250135, 0.12146122462581843, 0.2582995709963143, 0.20797127159312367, 0.12804309488274157, 0.13399822142673656, 0.14412028453079984, 0.20701062079751864, 0.08696899851202033, 0.18500018311897293, 0.13302566658239812, 0.26863002916797996, 0.1438946122652851, 0.12435871758498251, 0.15546984504908323, 0.12753873132169247, 0.11661470343824476, 0.08893664722563699, 0.17417003691662103, 0.11046730127418414, 0.12524132413091138, 0.16620667360257357, 0.1091893897682894, 0.16958031366812065, 0.27258244052063674, 0.2081067135441117, 0.1332052960060537, 0.08296674452139996, 0.12994493736186996, 0.14364171802299097, 0.10826908954186365, 0.11476890053017996, 0.1692124459077604, 0.09049400701769628, 0.10519631614442915, 0.08542542782379314, 0.07856768643250689, 0.14531514229020104, 0.24368319514906034, 0.16001441603293642, 0.10772938490845263, 0.18294544337550178, 0.25377831829246134, 0.1055638054094743, 0.11157458560774103, 0.16960360226221383, 0.20647535420721397, 0.14063937444007024, 0.13433223241008818, 0.1872767211170867, 0.149409823352471, 0.14992840646300465, 0.17648587905569002, 0.14143045933451504, 0.1578198408242315, 0.1373284903820604, 0.08172033718437888, 0.17980955773964524, 0.15329269546782598, 0.12202798054204322, 0.18909122765762731, 0.10812653039465658, 0.15685202088207006, 0.11487890165881254, 0.13283720560139045, 0.12344474045676179, 0.15481449896469712, 0.17118980933446437, 0.10744056329713203, 0.1205414735886734, 0.07470685610314831, 0.12604863237356767, 0.146625938359648, 0.16438340971944854, 0.16623140196315944, 0.08905409209546633, 0.17789797828299925, 0.14011109888087958, 0.12264703560504131, 0.16912411549128592, 0.0825213297503069, 0.1481349769164808, 0.18682187364902347, 0.18718194885877892, 0.11688178012263961, 0.06985535510466434, 0.12927853327710181, 0.08370205701794475, 0.11061659912229516, 0.1414762350032106, 0.232990539225284, 0.09450032055610791, 0.11138151588966139, 0.122795962379314, 0.1648756762733683, 0.06758963761967607, 0.1265854574739933, 0.13651938614202663, 0.24017242103582248, 0.14215530012734234, 0.214471654035151, 0.10608462238451466, 0.15544079738901928, 0.21003657951951027, 0.12145550266723149, 0.11740589965484105, 0.10611660894937813, 0.16606023302301764, 0.12422403262462467, 0.12177434415207244, 0.10187969528487884, 0.09951566549716517, 0.11053482186980546, 0.18680238485103473, 0.14994126046076417, 0.1485087670153007, 0.1961398939602077, 0.12836763606173918, 0.14288986305473372, 0.08562319533666596, 0.11365705940988846, 0.13861687359167263, 0.12375541089568287, 0.12547563499538228, 0.22367717960150912, 0.12400277613778599, 0.17656502168392763, 0.2733887097565457, 0.08799403804005124, 0.11865298234624788, 0.20278811221942306, 0.1255643364856951, 0.18513690156396478, 0.207567157340236, 0.17660162440733984, 0.17057330725947395, 0.16028072830522433, 0.26103779906407, 0.17615973483771086, 0.12695630866801366, 0.11907437379704788, 0.09903496160404757, 0.11813043616712093, 0.11280393839115277, 0.168801236723084, 0.13931502675404772, 0.12959538580616936, 0.17831938457675278, 0.22183902823599055, 0.1063472090754658, 0.23662884399527684, 0.10870967293158174, 0.2534638257930055, 0.12762752186972648, 0.18724682740867138, 0.14422376960283145, 0.11310964386211708, 0.18253562942845747, 0.27588467113673687, 0.19511374121066183, 0.1279280026210472], [0.05358579335734248, 0.056839873432181776, 0.051684013960766606, 0.003800364079324936, 0.12417800462571904, 0.06581994195585139, 0.013296802953846054, 0.020442795430426486, 0.03723659545357805, 0.10228949438896962, 0.030666749844385777, 0.04506101759034209, 0.04109187822905369, 0.053775950145791285, 0.02551042281993432, 0.0677510621608235, 0.08631949312984943, 0.03994682971097063, 0.05839110308443196, 0.02161090618756134, 0.030846616755297873, 0.034770397905958816, 0.04249102697940543, 0.020105049588892143, 0.03521882950735744, 0.024260041282104794, 0.03477522186585702, 0.017614997559576295, 0.043950482649961486, 0.047708455022075213, 0.054049728423706256, 0.028275238328205887, 0.08923938410589471, 0.025425001622352283, 0.03277896707004402, 0.03368226098245941, 0.027196172304684296, 0.03562033140042331, 0.04470261592359748, 0.06469314655987546, 0.024973447434604168, 0.04228898098517675, 0.054486137232743204, 0.025162090241792612, 0.014350584006024292, 0.03061301278648898, 0.025342001681565307, 0.024136952379194554, 0.025379144317412283, 0.0004557871255883583, 0.03629026439739391, 0.03312313805508893, 0.08638711762614548, 0.08343952969880775, 0.07506146168452688, 0.056980829540407285, 0.010237739807053003, 0.04071258881594986, 0.017209020516020246, 0.03734672274731565, 0.045853675837861374, 0.03435585276747588, 0.04392481547256466, 0.03602224518544972, 0.047671162101323716, 0.026987231758539565, 0.00732161847736279, 0.012730078578897519, 0.07256610144395381, 0.06648788970778696, 0.06650504816207103, 0.032901421436690725, 0.049614683593972586, 0.12423029635101557, 0.03829025961749721, 0.03503152256598696, 0.012593676474352833, 0.025743191872606985, 0.04811368620721623, 0.04346456145867705, 0.11681767340633087, 0.07780154512147419, 0.032285219931509346, 0.072009928553598, 0.03230815229471773, 0.05813532188767567, 0.048603507384541444, 0.0400224619806977, 0.027033102051063906, 0.05033711240685079, 0.056629418904776685, 0.05969987309072167, 0.044516373964142986, 0.013881781378586311, 0.07619973810506053, 0.05469547111715656, 0.018069961915898602, 0.020899242226732895, 0.04963676990882959, 0.02569090200267965, 0.0545276789489435, 0.0625919780577533, 0.05114013845741283, 0.029466754567692988, 0.02115044251695508, 0.029256489287945442, 0.026295121533621568, 0.040128162363544106, 0.011375953145034146, 0.026694840416894294, 0.018226428910566028, 0.08235616478486918, 0.03159593543387018, 0.04656207063817419, 0.04695894524047617, 0.07011903275270015, 0.0511996141722193, 0.00948350903854589, 0.017118832874984946, 0.021859533080714755, 0.033695096426527016, 0.08298100859974511, 0.04291583602025639, 0.022560762445209548, 0.0651341381308157, 0.056966713891597465, 0.06263413204578683, 0.07930784515338019, 0.014908444354659878, 0.07933767948998138, 0.02675600080692675, 0.0353925291710766, 0.009796327067306265, 0.06059273240680341, 0.03890093583322596, 0.04081905361090321, 0.06229471822734922, 0.01765285080182366, 0.03919207665603608, 0.00996988665065146, 0.06255629559746012, 0.021375604555942118, 0.013737476328969933, 0.04327447517425753, 0.08298055588966236, 0.005680296735590673, 0.025225781355402432, 0.07469839561963454, 0.02062798354018014, 0.05868455198651645, 0.01275609456570237, 0.01254853255886701, 0.10712588526075706, 0.04264732328010723, 0.0394628343929071, 0.07019617158221081, 0.0224417034041835, 0.05940639450273011, 0.15440345305250958, 0.03765217959880829, 0.03396720116143115, 0.030861584018566646, 0.020296087677706964, 0.06832050465163775, 0.03542401849699672, 0.04415523748320993, 0.07000849727774039, 0.08762532423133962, 0.07494510035030544, 0.027298056193103548, 0.02625740373332519, 0.052926272692275234, 0.028292127753957175, 0.05318927127518691, 0.0322026114736218, 0.04273007274605334, 0.0051302196607139194, 0.03958820911066141, 0.05057007627328858, 0.04089847454451956, 0.14857023168588057, 0.05669516576745082, 0.03976475491072051, 0.029797783972753678, 0.07085217075655237, 0.03950927799451165, 0.07469544929335825, 0.029500420241674874, 0.04736757917271461, 0.011167796492372872, 0.053164706187089905, 0.09736059480928816, 0.0481435057008639, 0.014052970727789216, 0.054389272117987275, 0.034368458145763725, 0.020001635020889807, 0.04194402332359459, 0.04322113330999855, 0.011746323798433878, 0.02729457923123846, 0.00635936232356471, 0.043204223475186154, 0.06702243641484529, 0.023605624737683684, 0.05299735930748284, 0.05852631868037861, 0.0377819366985932, 0.053023404980194755, 0.03282986355770845, 0.07098596513969824, 0.014716272635268979, 0.017808532975323033, 0.0213889539372758, 0.037968182368786074, 0.04598355539201293, 0.06772346911020577, 0.07750359509373084, 0.014029939102329081, 0.06374235890689306, 0.02872209472116083, 0.05770718060375657, 0.031869669182924554, 0.05875189817743376, 0.04939013939292636, 0.016492361901327968, 0.034588159833219834, 0.006943958078409196, 0.07610843909787945, 0.012337343305262038, 0.07992160128196701, 0.019693541689775884, 0.027375608769943938, 0.039604395351489075, 0.03796956276346464, 0.061952272735652514, 0.019182547039235942, 0.03200682549504563, 0.06340209904010408, 0.028544029373733792, 0.02609319613839034, 0.06879412103444338, 0.02824990326189436, 0.02253668902994832, 0.03169045907270629, 0.07557598524726927, 0.00392009917050018, 0.039028748506098054, 0.017821787732827943, 0.03992090649262536, 0.03967418320826255, 0.026055552552861627, 0.04986126958101522, 0.0156373539721244, 0.07069763334584422, 0.05754447956860531, 0.024898529482015874, 0.038673757007927634, 0.04797364665137138, 0.02939933601737721, 0.09373765991767868, 0.03531465932610445, 0.062359663570532575, 0.047293538809753954, 0.04155641814577393, 0.04753133776830509, 0.051597553756437264, 0.015156216850300552, 0.049349362088833004, 0.030608287161157932, 0.04452340581337921, 0.02149623880541185, 0.021577387087745592, 0.051577393314801157, 0.06821373186539859, 0.10244002420222387, 0.06438718133722432, 0.038301807435345836, 0.016831376815389376, 0.06620270462008193, 0.016121688822750002, 0.1212828049028758, 0.09367780570755713, 0.030444908916251734, 0.028374270514177624, 0.08866545162163675, 0.042737538751680404, 0.10952712633297779, 0.01704633246845333, 0.05666561715770513, 0.08177620606147684, 0.03387858872883953, 0.01469204893510323, 0.027942279339185916, 0.01203811492814566, 0.07891351982834749, 0.00700947209224978, 0.024472583099850453, 0.0472384417662397, 0.03154010737489443, 0.055543077978654765, 0.017146457466878928, 0.030522903070959728, 0.040887717113946564, 0.01164617839094717, 0.038062802486820146, 0.022011816217855085, 0.018399030195723753, 0.0341870920965448, 0.030508382951666135, 0.014550053820130415, 0.04123198086745106, 0.030637774543720298, 0.014447647645283723, 0.0388249473326141, 0.023123252867662814, 0.10622473244438879, 0.023946626752149314, 0.04349167211330496, 0.06294725157204084, 0.05689200930646621, 0.05090749000373762, 0.03405134215427097, 0.03289896863861941, 0.021066256995254662, 0.030456985514319967, 0.04724921775050461, 0.03330546147481073, 0.09833841148065403, 0.04184514698863495, 0.021665481872332748, 0.0104844009365479, 0.006384002554113977, 0.06385759959812276, 0.05358469868951943, 0.04187181606539525, 0.05662479161401279, 0.03207716996257659, 0.06148063417640515, 0.05432982979982626, 0.08480562319164164, 0.06848871242254972, 0.06520098337205127, 0.07012904432485811, 0.061825903540011495, 0.021745800804637838, 0.01368023076793179, 0.007582039024782716, 0.06479230491095223, 0.04497361485846341, 0.028424100164556876, 0.06147842628706712, 0.15277751139365137, 0.1604300781036727, 0.16339142544893548, 0.07075983274262398, 0.3030509571544826, 0.15021253027953207, 0.10328117437893525, 0.12998771475395188, 0.16814985370729119, 0.16992450691759586, 0.1959675969555974, 0.24880438519176096, 0.18409580196021125, 0.13592632109066471, 0.12433856085408479, 0.14156918157823384, 0.16924278490478173, 0.1031640634755604, 0.30513665929902345, 0.10685619621654041, 0.10250102131976746, 0.19666943117044866, 0.10261786504997872, 0.11336492039845325, 0.16468426154460758, 0.12133845855714753, 0.20042943331645802, 0.1759061578195542, 0.12009935395326465, 0.13373708934523165, 0.12990129907848313, 0.13816190737998113, 0.15031886519864202, 0.1718123079626821, 0.20315308560384437, 0.09477979110670276, 0.10754288319731131, 0.1251859005424194, 0.07825162057997659, 0.16929394856560975, 0.1675691973650828, 0.11410040358896367, 0.1066223083762452, 0.13830499345203862, 0.07527339679654688, 0.19334910699399188, 0.17741001618560404, 0.13585412496468052, 0.09927140243235044, 0.08517634079908021, 0.09970256796805188, 0.19167784979799762, 0.2133561170194298, 0.10604525887174532, 0.1870364136993885, 0.15025924105430022, 0.16635246109217405, 0.17507416574517265, 0.24394465377554297, 0.12072347788489424, 0.17782428301870823, 0.10054753278382123, 0.1307988227927126, 0.08347544222488068, 0.13028568704612553, 0.1659438494243659, 0.04964578700310085, 0.12012319915811531, 0.24115428241202608, 0.1941072999034077, 0.1436793597531505, 0.17069729045033455, 0.1817128696711734, 0.30247018206864595, 0.15044762782054022, 0.15608033572789282, 0.17422994307707995, 0.15374580631032586, 0.2638266119174659, 0.20790948037756607, 0.1515966356964782, 0.18765109009109437, 0.14281281328294426, 0.10549909755354747, 0.17376947012962773, 0.11584633568418212, 0.16160636732820421, 0.13049331028014421, 0.12460910336812958, 0.1346254104282707, 0.17647504369961098, 0.11706130564562045, 0.27140512713231146, 0.09479162094066851, 0.1452728547155857, 0.1988733425969258, 0.07106863296939991, 0.11360826320014894, 0.1795662075164728, 0.1524317596340552, 0.13393156172242016, 0.17316461977316067, 0.12735041877022013, 0.09550262067932636, 0.09810299481614493, 0.13569270784500986, 0.12199085089378059, 0.12378367930068634, 0.13277176301926374, 0.15820758329937235, 0.11356094386428595, 0.21045319153927267, 0.10145860811462626, 0.1541346768499352, 0.1633043566835113, 0.1611722554662265, 0.19408240827033296, 0.10646537382854149, 0.11349294829415157, 0.1747016966692172, 0.11506818642374128, 0.18604466691613197, 0.08759382006246597, 0.10562871364527382, 0.13330802408745512, 0.10775173839647323, 0.10654521407559514, 0.1517630845773965, 0.09762712972587906, 0.1297648181207478, 0.10887558746617287, 0.12393089171382599, 0.1318359890137799, 0.0859908627171535, 0.22215699398657307, 0.091779577487614, 0.1015562895918265, 0.0591221556533128, 0.08838124616886489, 0.13370716595090926, 0.23315168917179108, 0.1788221302558668, 0.09768787451321259, 0.11632888752501458, 0.24674605345353484, 0.14955875754822046, 0.12689837662037462, 0.1387002761475742, 0.09761503271874972, 0.20972677739337087, 0.10752143512945622, 0.04329538518504705, 0.3047614294337109, 0.1907598873367533, 0.13585281878476962, 0.11223986904951744, 0.12061169560183771, 0.24408512748777866, 0.19251732272095978, 0.11090047803008929, 0.1435860272613354, 0.0920076691545546, 0.13970297703053802, 0.15679505362641066, 0.13538771483581513, 0.18935184023575857, 0.18222121114376932, 0.1704490272095427, 0.16622564289718866, 0.09389861690578982, 0.14331091311760247, 0.11513886114698835, 0.09672883417806588, 0.11933879359276034, 0.17004054912831634, 0.10446360858622938], [0.03445840273343492, 0.03947365861677099, 0.03341253112012055, 0.05155844999535475, 0.01895181332656648, 0.018433130026096478, 0.040455390117131174, 0.004634210363292368, 0.018089498953486327, 0.04371996416011825, 0.009266821398341563, 0.03396021013031714, 0.015034866428322857, 0.08210828746086918, 0.018576112197479233, 0.049749465033528395, 0.01417506700818194, 0.03553885471774265, 0.029121598381607328, 0.030847665038891137, 0.06776115536922589, 0.022874228925502393, 0.08075014979112893, 0.030374080197361764, 0.047670093408669345, 0.023324502908508293, 0.014570191997336224, 0.04680512771301437, 0.021602844608423766, 0.03188394439348485, 0.05958424648270011, 0.061593243954121135, 0.014985596171754878, 0.019301828724564984, 0.059895922531723045, 0.02165773756132694, 0.009429821147932671, 0.04669051784730982, 0.08414629177423194, 0.014322887982416432, 0.016679262516845483, 0.04964816187566612, 0.03772460579057224, 0.0762493209913373, 0.043357977920095436, 0.07180316621088423, 0.011098769336967962, 0.01609602535609156, 0.059633781129377894, 0.03124610557279084, 0.08142601625877433, 0.023495961286243983, 0.04049633440445177, 0.056968298376887105, 0.03049614308110904, 0.04303475405322388, 0.036393044429132715, 0.006814697753725341, 0.07779344829032198, 0.01312715819949517, 0.04034620906168129, 0.0701592794212047, 0.036142873868811876, 0.0576130465924507, 0.07167138304794207, 0.008666653993714135, 0.05574526498094201, 0.01651482300076168, 0.012166164160589688, 0.03796172568399925, 0.018261400764458813, 0.03148910698655527, 0.08172335772542283, 0.0942923039838206, 0.021893905650358647, 0.05325201615050901, 0.04263157490640879, 0.07051782580674626, 0.07375419823802076, 0.05830400092236232, 0.039954269741429016, 0.056627010635565966, 0.0387946714181453, 0.030680589043186046, 0.03439738335146103, 0.04803420961252414, 0.062125041004037485, 0.027228659819229506, 0.0543356630805647, 0.03824872903351206, 0.01335559960352839, 0.05103266805235762, 0.06721603305777535, 0.025875783976516686, 0.010198816016782075, 0.02894040859246161, 0.024674406449776143, 0.056942501323646866, 0.07190841759438626, 0.038018952691345476, 0.08101647690637037, 0.02926232999016065, 0.02514059578970773, 0.047727702622069046, 0.06750532222213224, 0.06231586943613365, 0.02687759984837612, 0.07567768916487694, 0.013609847337647807, 0.05897411945625208, 0.02727858223806834, 0.05492073520144913, 0.011038798238587333, 0.03218254008970689, 0.011053706130041974, 0.033174383352161385, 0.02975350373162655, 0.02380622725468129, 0.060904779529664665, 0.02634713124280097, 0.03385705531400163, 0.05799451420898549, 0.04705313862359617, 0.02466008114424767, 0.07112867271644063, 0.10815966728841886, 0.02980961751745781, 0.01380513422191143, 0.017524880422570277, 0.027666103924275376, 0.050933543097926304, 0.03976986088673584, 0.018178753343818244, 0.03517559569445439, 0.02298553808941506, 0.019618252663349267, 0.030920017015887424, 0.04364558611996472, 0.040006631970754825, 0.02903760952904122, 0.020785784545296337, 0.05372418534534518, 0.03105858155322494, 0.02316481313755503, 0.03391746984561905, 0.019106348881905433, 0.06409841909771785, 0.05513991738553159, 0.015944562292133924, 0.052702682150993496, 0.04419070843141526, 0.024449999546050094, 0.04684473613451701, 0.13561377301812172, 0.06670286762528121, 0.056323290409636684, 0.008705292057129554, 0.017597887344891205, 0.06868213095003739, 0.02804959389322903, 0.023189409766928293, 0.021914941826253198, 0.07782909364323132, 0.02769064489257289, 0.008931440224841936, 0.02507805314962752, 0.1031254421104677, 0.027716191470972262, 0.042521714785834774, 0.0330455724906642, 0.11981537114479579, 0.012329785458859988, 0.02503955980500905, 0.054427303475677036, 0.016403638146584854, 0.17097480915253982, 0.02183486594731221, 0.038305866983137093, 0.018549077612988185, 0.12753859773511067, 0.06574404251296073, 0.016226559855567757, 0.02932707495347131, 0.005751390308432747, 0.05965521064354107, 0.010595873372949427, 0.05390315425756853, 0.038769557140767574, 0.012846253448515199, 0.06339208746794611, 0.046016885244171135, 0.03244009873014875, 0.018852855355362408, 0.060288600288913585, 0.0831832512631081, 0.07196846476290375, 0.051732969732256606, 0.06650343028013594, 0.022895061010785867, 0.06271665144595318, 0.03322372504044324, 0.01997044812014792, 0.0632114709878806, 0.025817783280217554, 0.03696676540130284, 0.01842499608756043, 0.07361319760093465, 0.03657857763755601, 0.025772055851120967, 0.019897387392120436, 0.10420597202028148, 0.04610142328601796, 0.044990495007368736, 0.015284486871678382, 0.056581598619231954, 0.019899359649571124, 0.02609983093861956, 0.05635266090393998, 0.12412114869221114, 0.05933107764576562, 0.03595322174078319, 0.019142740093229804, 0.04593880017637275, 0.014863211381452857, 0.06294941864325665, 0.042400440433993936, 0.051549299314501695, 0.009365421283291653, 0.03338175796670839, 0.01996615479583852, 0.03923562959244009, 0.036717452021548524, 0.01221121530761593, 0.015772367332829162, 0.06631364085478708, 0.028743719049089123, 0.040345340748899616, 0.07089017613907345, 0.03185236972058192, 0.004803990095751942, 0.05137968146300409, 0.07252659692312591, 0.024891842731449287, 0.010389143499196507, 0.04028656636364758, 0.025803725147852674, 0.04321904787502717, 0.019394728915358428, 0.041921384108718485, 0.05881761906493921, 0.0694033871695865, 0.033930487115867436, 0.047681385185569525, 0.017223592585651204, 0.06481689226347953, 0.04791949955688324, 0.012294947191549, 0.05924638004216831, 0.04113455172046088, 0.010595657222438604, 0.02668884571903618, 0.017610507566132583, 0.020190635914332233, 0.02562501969805453, 0.04116099815291818, 0.022779773935326375, 0.027369825584173668, 0.07434992759954184, 0.05925775345531292, 0.07497621118091047, 0.026788380710058846, 0.04703572041762527, 0.03276135590567719, 0.03688791963213589, 0.05158062165719457, 0.0324615764839109, 0.06018468106049113, 0.007050405711197527, 0.02238162654975895, 0.07001513949944638, 0.005320182563082199, 0.04201086485409178, 0.04591065793647431, 0.03500187747704331, 0.013758940167463152, 0.04156334980507381, 0.0533434450335335, 0.015434516662935494, 0.035784828432952054, 0.022112956103228498, 0.03753557706659194, 0.02918767735536676, 0.026051875211123843, 0.007787395461491542, 0.016445690089312848, 0.02114230301231146, 0.048833023975021206, 0.02756861169473268, 0.004143602973272209, 0.027799417766800616, 0.040016947823460214, 0.05284139697323553, 0.04502895681071095, 0.04211509949527681, 0.046898393411538564, 0.042012764752143994, 0.014907765289535746, 0.021396603624452837, 0.04180583171546459, 0.016803182625153568, 0.0554822738195071, 0.04264319322828669, 0.06089794806030113, 0.009064303212653613, 0.005830930449519656, 0.028244361274119, 0.024683885530976113, 0.03722459492564667, 0.05677526947692968, 0.012632332163775573, 0.00694316490807978, 0.07736309911706485, 0.07750466378638521, 0.0325826615880942, 0.06532346742460504, 0.04384139807370957, 0.0687225186266005, 0.036799745066673495, 0.037152027725824155, 0.08109136702842079, 0.08166886182152666, 0.03840256140392739, 0.08350065298145637, 0.07137666136259213, 0.0434553662489634, 0.04185775607766118, 0.05693339146091603, 0.025860039313556626, 0.038896375335752964, 0.007850657984818099, 0.038288163050310686, 0.01171893947685021, 0.060643443357548676, 0.05461131899210159, 0.05001714285754133, 0.030664169025840238, 0.051806735500576906, 0.030126392121019308, 0.018479063401173335, 0.03416561063204426, 0.030090169748291373, 0.03608766550314613, 0.20536882686428726, 0.1468400628073141, 0.2043646268430166, 0.21867372386623174, 0.11692725893226452, 0.11750254212529399, 0.09724894611281343, 0.09381439798744395, 0.12118793616537005, 0.11077406801632605, 0.10969810231472366, 0.17963087826501578, 0.11649063861113973, 0.23352642921963707, 0.10066135597298853, 0.12939585198182613, 0.10766565668745898, 0.10922860485152341, 0.16454340191558003, 0.12566258199512959, 0.10288640376529656, 0.1404317660490051, 0.16453106742119417, 0.11875787007738836, 0.20102791604585946, 0.07504374661948532, 0.08267794517450966, 0.15288760158000514, 0.11516205326188356, 0.15683713339967653, 0.1507694972679019, 0.10532423271797597, 0.12723329302389175, 0.07143331691622734, 0.1993181265424937, 0.1547346290317364, 0.13498624262865633, 0.18242353544337675, 0.18018489150563255, 0.13408487458946183, 0.09747059593792073, 0.12596235028468072, 0.20503634470514953, 0.10704266824177466, 0.13440902985166758, 0.16309205791912973, 0.1149309633183293, 0.0903668548562564, 0.15327984147006646, 0.19659122364828363, 0.09614938011509366, 0.08479531476041302, 0.14778241224121302, 0.14761532511329278, 0.06391085611539893, 0.14487723063211888, 0.12671132571995258, 0.12588046171003953, 0.19799974572379142, 0.08940269370214082, 0.13150223036063835, 0.12179937679320574, 0.07792335381964222, 0.11305735955829732, 0.16718253842554986, 0.10966515837935731, 0.16436393576441333, 0.12430412520188838, 0.12956920283613726, 0.10806370759382844, 0.15004012937424704, 0.14136118727037683, 0.24010636989260092, 0.17630506219575182, 0.09632561792386696, 0.19952880742494017, 0.1878786028828472, 0.10218503710348159, 0.15875396726187319, 0.11337714357068762, 0.0803425326012075, 0.16292345680994913, 0.10757740048575215, 0.09740165041876025, 0.18177390389610082, 0.14106544142123312, 0.18289257277501747, 0.08843715215334669, 0.1526098750764504, 0.14068788121221587, 0.12102094551664777, 0.10718139048549347, 0.14380358043126762, 0.1736566933686845, 0.07391103630652651, 0.0973664948833175, 0.14786876854486763, 0.1342078929883428, 0.22179869993124157, 0.1132043196412269, 0.1764111002557911, 0.12409721442963928, 0.15975982969393954, 0.20168784860288724, 0.17350407812045887, 0.21119576966157183, 0.10492351007997058, 0.14068117219721898, 0.0715338927693665, 0.14987997390562668, 0.19788456440437585, 0.12411620598868467, 0.11765993680455722, 0.12206732179038227, 0.12648051779251546, 0.09369420717121102, 0.12059275599312969, 0.07481863838620484, 0.1266272403881885, 0.10072341436170973, 0.24488183786161244, 0.09190698197926395, 0.11382870332454331, 0.07844777763239108, 0.21345503046177328, 0.2963287616148591, 0.1529634787584655, 0.10495674345293082, 0.14620380476117134, 0.17081483179936185, 0.13462935865391046, 0.17363169783493504, 0.13301612256327644, 0.12989809300052002, 0.1255111541831866, 0.13231750926934183, 0.1262916115229018, 0.13217599655035883, 0.08195858885301277, 0.11981164556345902, 0.1418059563729912, 0.14633296814281493, 0.12097224578610621, 0.1450745528563857, 0.14624149102019146, 0.20103432820178568, 0.32343056984245777, 0.11712349762092344, 0.14559985982486978, 0.11400765739381313, 0.15091008972376585, 0.15373828093288466, 0.19351565977558494, 0.2664719527820125, 0.18868356593884528, 0.09356214199215174, 0.2007918240269646, 0.13885789347114041, 0.15430547471623868, 0.12248247177922167, 0.18789252557326108, 0.1315861227340065, 0.14861266769003123, 0.11003047315170988, 0.1277510152431205, 0.14675873826490715, 0.17330786911770701, 0.1454318079049699, 0.11565646462258883, 0.088007901358651, 0.3278095676796511, 0.13493910140823573, 0.09479081942117773, 0.18030221021035686, 0.1766949420562014, 0.28533642645925283], [0.029185501007304993, 0.031876589710009284, 0.016135082732944284, 0.04912612035695929, 0.009882606373139424, 0.02806949087243993, 0.02414154812868219, 0.02643201809405582, 0.15644847066141665, 0.03526785578287672, 0.022582383062399458, 0.015344842959166272, 0.03249065011914354, 0.021308295472408645, 0.021621572705043945, 0.021164953359402716, 0.01797479075321462, 0.04027647686598357, 0.03906835692760069, 0.025919171785062645, 0.027963024222117383, 0.09481611181399785, 0.011153000850754324, 0.02993753965711221, 0.039555981347803026, 0.013507333551388001, 0.08030803757719696, 0.028014905910822563, 0.016847262486408, 0.05590619228314608, 0.012573774856718956, 0.09366004611365497, 0.08140054575051181, 0.12737008568365127, 0.006443225011025788, 0.0443062942213146, 0.04100844598724507, 0.05003483565815259, 0.024764046756899916, 0.023552158563688863, 0.05804341803013813, 0.05193327167944517, 0.02220626818598248, 0.0366762479825411, 0.06482874436187558, 0.05855743322172202, 0.03829808185400907, 0.02069460057100514, 0.09490034557529725, 0.0548735568736447, 0.026045301638077945, 0.09724907969939522, 0.038117446820251644, 0.02789258327538846, 0.04201289462798741, 0.03811738373769913, 0.0421513979381416, 0.05344775017874781, 0.07546190972789191, 0.043940003524767235, 0.06066499903681688, 0.058246109692845494, 0.0720571365673095, 0.01600104344106512, 0.10489867781870998, 0.02872863860829966, 0.026565437692624982, 0.05812272764160298, 0.09089049941394478, 0.029733161463809665, 0.026307546941097826, 0.040889130905270576, 0.021775223249278497, 0.07457848681951873, 0.0505246345710475, 0.009243874192179646, 0.04376989214506466, 0.014790260120207677, 0.023960191356309224, 0.033462629799032584, 0.04803695555892773, 0.005654175456584198, 0.048006286306190304, 0.013651736007886939, 0.04148005486058537, 0.05348231199604925, 0.007939043134683743, 0.024582198311691172, 0.020238723373040557, 0.03642834097263403, 0.01823701193643501, 0.050948887001140974, 0.07296509487787262, 0.10343835383537225, 0.016640672693029046, 0.04160174481512513, 0.07974321124493144, 0.054363222734536976, 0.0670431942853611, 0.03903888624336105, 0.03139896201901138, 0.027032961043005344, 0.058566606167005375, 0.07379492730251513, 0.019106582658423577, 0.029427404042507987, 0.041144971473841, 0.07917279654066078, 0.04993183298211079, 0.04936203797115013, 0.030203998503566254, 0.05768024806457106, 0.010734086317825131, 0.058905715704895556, 0.03831285430351272, 0.021388966924860142, 0.05059850052930415, 0.054476626610266976, 0.05826861161040142, 0.07047438048175536, 0.020183858250675257, 0.02849345200957032, 0.023037429054966196, 0.05922463140450418, 0.02208089346822817, 0.03867926003294997, 0.08628517622128129, 0.008870064611983253, 0.0358029665221693, 0.02278400232171407, 0.03986685958807357, 0.03523554638377391, 0.011698099042405374, 0.008489567353535676, 0.04958419616741594, 0.019547572373994626, 0.08158231255947612, 0.011457496621005703, 0.025144417850242462, 0.06489517400041223, 0.05285275554342661, 0.09578698940458708, 0.01310501065745484, 0.06962551196920685, 0.040288165691890754, 0.039857849915279076, 0.05930803767114412, 0.04461561766220257, 0.07771826873067766, 0.050174377975054085, 0.036764114556717686, 0.015671696855861228, 0.04269158867828082, 0.04415869218064472, 0.041791730909608305, 0.04472483582503628, 0.011430196718720254, 0.04010515578556806, 0.01726751659589354, 0.07358683651546016, 0.05942697054706514, 0.04641212712158449, 0.0053024341013951926, 0.019733664048544597, 0.03341726973303594, 0.006699129125991021, 0.07189427968114614, 0.028495142250903882, 0.05784523120382801, 0.026674757900764234, 0.01730585594486911, 0.007007887606960139, 0.07804948181728832, 0.049854675598908216, 0.01819245153455995, 0.06270176396355964, 0.030576534372812603, 0.07589186556288041, 0.047172861886792816, 0.034628592038643546, 0.031926762603688985, 0.016885275290405843, 0.02521105529012857, 0.012092217493773205, 0.07660370392841287, 0.03963731331168674, 0.057963533254223876, 0.03966258715081494, 0.030993990585557185, 0.0546652731281938, 0.034702862467383966, 0.014899763082212303, 0.056778661091811955, 0.022493867109005805, 0.051072918431600556, 0.044204048535902984, 0.04479457173147239, 0.05035968111769762, 0.07666772158700041, 0.023291445795621257, 0.015435624318342889, 0.02676327570952708, 0.03928871912648901, 0.0087004792294465, 0.037633996980730444, 0.04019481835712213, 0.03941668022889644, 0.035326029028510675, 0.04652511910535395, 0.055757881491445005, 0.01643953026359668, 0.02426064427709207, 0.04866461211349815, 0.040536376982345246, 0.018887825353886, 0.009658718045102432, 0.076461011194624, 0.04994777060346678, 0.03532909038767684, 0.021849564182048198, 0.05149726363015361, 0.03119012908427976, 0.09322281723143533, 0.053797305445186794, 0.04134959643124603, 0.01016711981719709, 0.00873713854161906, 0.06320128872175701, 0.01060783957655076, 0.07476823913748376, 0.024441316418233328, 0.013384445956035051, 0.040942951454780996, 0.095993143186206, 0.017190041944559198, 0.0498260620952351, 0.05119653054862283, 0.008404562686337158, 0.06620495332754217, 0.045871086622355506, 0.09921302509610541, 0.05574971415626351, 0.018245225655846298, 0.031735622469568625, 0.021744498335465323, 0.05278125332552008, 0.04574946346110664, 0.029000401955272537, 0.07112421240890399, 0.05155053127964493, 0.031001176430436317, 0.01802494138246402, 0.046735302748857066, 0.010110646089742659, 0.04106576576305088, 0.05154631217010319, 0.018853679139283486, 0.0757222254469525, 0.10193658832577057, 0.026383182921563275, 0.0033710657407937106, 0.036955481045879424, 0.037518184835789725, 0.08373302684049122, 0.009640799817134393, 0.02121798723237589, 0.05518594538443722, 0.04025975627882872, 0.03136934661597479, 0.03572209840058349, 0.028184013535792474, 0.04623386324965395, 0.05586879917245824, 0.025578310778655577, 0.07022802456049249, 0.057192122694686987, 0.0041599599080655025, 0.04902627923002001, 0.04731622255349066, 0.019993771966255736, 0.02616523084725486, 0.0754929611866828, 0.011263290489296196, 0.019072278737439774, 0.03004994163347874, 0.046648968709632754, 0.02381433150731027, 0.06424815481295809, 0.06276440864894539, 0.15156264533288777, 0.06579709122888744, 0.051768693010671996, 0.017202135240950156, 0.06428125459933653, 0.01904222917801235, 0.039483670188928954, 0.01601131105417153, 0.03182497704983689, 0.06533446605317295, 0.033717219848767854, 0.018621281160449143, 0.02635007014760049, 0.028813325079681817, 0.02467649188474752, 0.10143385006813332, 0.023656087068957277, 0.022954755659156945, 0.06579886496183462, 0.008488826133543625, 0.014308556183095789, 0.048237958835670725, 0.04206050711218268, 0.12489033280871809, 0.007350154519372154, 0.04437107258127071, 0.0548388095194241, 0.04074942160514183, 0.043525246874196455, 0.03250167101214174, 0.03598584655264858, 0.02513333016395336, 0.04270402707334142, 0.13170611317036673, 0.07395677486783825, 0.02822646809363505, 0.016855737812875304, 0.05210680435993709, 0.04548570046608802, 0.03642008457973134, 0.06270663245231844, 0.009756595263752388, 0.014142810487101087, 0.021744316509284545, 0.06190728003275581, 0.03358016372658312, 0.0351795550523093, 0.08143573097186163, 0.039033052962622605, 0.03687489494041074, 0.05262135018710978, 0.01394191853250959, 0.01970755900401855, 0.020448842078621965, 0.027784242702182382, 0.042568778080749325, 0.01588161518156994, 0.0788955450116191, 0.005121806952956831, 0.044176748633617535, 0.03133546757453587, 0.029587442622869276, 0.03739171545021236, 0.14302003575721756, 0.16912684659473598, 0.09312342139310203, 0.14479256642516702, 0.13344456441700459, 0.1151614447007887, 0.11108128004707396, 0.167663257161621, 0.3034289478091523, 0.14944176538847387, 0.2029164889245294, 0.12979110499145463, 0.1132887315179687, 0.10541276351432316, 0.1292395853670314, 0.09954597480827942, 0.10135878183064051, 0.12129153998102993, 0.1183088707330171, 0.12048165648593567, 0.10223294273600914, 0.2834293444175273, 0.15581075800582767, 0.14116290025413036, 0.12000753544270992, 0.10759736425825395, 0.18853820889489725, 0.06422569742426276, 0.09693437939858995, 0.15996273286873475, 0.12298003726755269, 0.1631306199124083, 0.16841073345858604, 0.25669997557997704, 0.12257360751391388, 0.12095207421225496, 0.1725480583263561, 0.10840971910511144, 0.06043599081749562, 0.10661550288205035, 0.11485248862300068, 0.12612551887286827, 0.11875459720613435, 0.1100670758751221, 0.15950839006109163, 0.15691372303990647, 0.22435339487856254, 0.20492432493483648, 0.20392950566019863, 0.13104312296491116, 0.0840831572713796, 0.19124170445138589, 0.08113106450764462, 0.12255870518856682, 0.09668607905041426, 0.11200321299838834, 0.14031051396159455, 0.1647346979007125, 0.1582182850688696, 0.09562053310219198, 0.2262423833599314, 0.13843627937603742, 0.21737633098382503, 0.10676045174477622, 0.3916063631186262, 0.09112081752391532, 0.13091134722344577, 0.09005622894619592, 0.14507312793284655, 0.11465549294371158, 0.10509470128454268, 0.11811817588750273, 0.1604963667341508, 0.24814886099193245, 0.13763306778855622, 0.06625441747019067, 0.14916917454684153, 0.08135447322274558, 0.16553482215385884, 0.20173991768388078, 0.14458288002060726, 0.185465776885394, 0.19171403691871092, 0.25233288179151714, 0.10621908470056951, 0.13547983020544052, 0.08996546428534202, 0.13770130084594712, 0.1163864484988153, 0.11935733244172297, 0.11929948203032836, 0.11682850134093314, 0.1464441863936372, 0.20182541309623048, 0.12432014817022718, 0.27766226325184107, 0.15023322135675699, 0.16732416988816112, 0.25552607607096434, 0.2091099339304492, 0.11850129478261806, 0.09086647609365173, 0.11914020229596645, 0.19902484462363645, 0.10416021861601621, 0.16536518203793094, 0.10732851384091191, 0.20398626511450857, 0.12101703439839184, 0.1833257346879691, 0.06436727693653665, 0.13016099139349535, 0.15226206014631316, 0.25316251383628696, 0.12106624621083029, 0.1753782681771554, 0.11991502673481591, 0.13962735218228772, 0.15051142283482477, 0.18343239615205675, 0.13359525008127093, 0.1353260868927464, 0.1378237403696403, 0.10214557711151429, 0.12983883993001655, 0.10469141081557609, 0.2090690119075589, 0.10873669452848844, 0.23447643761755899, 0.09516043865005486, 0.12480740522732958, 0.10450159912579693, 0.14441742561757565, 0.1525039557600394, 0.1484329195227474, 0.18037295172689483, 0.1440836224355735, 0.1264277214067988, 0.15617130819009617, 0.10271654100506566, 0.22507252113427967, 0.15732680243672803, 0.13604527252027765, 0.1665374042931944, 0.10663642402505502, 0.10842505187611096, 0.1737743683042936, 0.16982108121737838, 0.2132177064777352, 0.08626807713881135, 0.1608270380529575, 0.1057908358052373, 0.1621104488731362, 0.22368569945683703, 0.15329100337112322, 0.1540391772869043, 0.0808503694133833, 0.13406504440354183, 0.12677173654083163, 0.14337717206217349, 0.2086534388945438, 0.11355295835528523, 0.12030615340336226, 0.20312678389018402, 0.10309042016160674, 0.10234975678031333, 0.13027419860009104, 0.08891850171494298, 0.15637360280379653, 0.11224189511267468, 0.10006053547840565, 0.13350916095077991, 0.1145098835695535, 0.14515129092615098, 0.12127583613619208, 0.12467254215152934], [0.028481236258812714, 0.040870287775760517, 0.021495624678209424, 0.007535241047662566, 0.04321143343986478, 0.014907353397575207, 0.0516428062110208, 0.04202590076602064, 0.016175615128304344, 0.01259235359611921, 0.04431229448528029, 0.037627859419444576, 0.026071364009112585, 0.03229826317692641, 0.012654534439207055, 0.03988386961282231, 0.03716283339599613, 0.07947510297526605, 0.0976701223407872, 0.04792237166839186, 0.02432840978144668, 0.043831442162627354, 0.04640237159037497, 0.04525838063273113, 0.032908386492636055, 0.011628627526079072, 0.024058674353000242, 0.03349259772221558, 0.042124528481508605, 0.07601849822094664, 0.005009206915929099, 0.0625422912708018, 0.07123340459656902, 0.03562481397239026, 0.0574209416663507, 0.0899152951024007, 0.026355252193752676, 0.03240849437133875, 0.04826942960789893, 0.05142156827787403, 0.07757105631753802, 0.048428375375806354, 0.04352053794718813, 0.03334112909215037, 0.07601184857776389, 0.0359132274024887, 0.09209295676555485, 0.05250900016108062, 0.040946346780401655, 0.03250822417612653, 0.0622335949447006, 0.014712555403093575, 0.014881431106914533, 0.07424779323628172, 0.0104882294908748, 0.020516121476248372, 0.014758953548152931, 0.03783902640861925, 0.0357385852112202, 0.03295242553576827, 0.051051800619461574, 0.021373142481024843, 0.05318813207850326, 0.011918785003217636, 0.011955233730986947, 0.0305440895317588, 0.03559044882422313, 0.017080250472645275, 0.021922650885244366, 0.05700840774807148, 0.061396741803037, 0.04483911914576311, 0.02710894768824801, 0.027084514331363607, 0.030984509648988023, 0.06801764902775176, 0.026973461208399385, 0.013661883021995891, 0.007408818973999587, 0.08389471855480224, 0.032416869507869706, 0.035079921726719476, 0.02274795620905934, 0.01292209723033011, 0.008217753911594627, 0.06113079689384904, 0.014764209809072781, 0.08399453741731122, 0.04038842613226734, 0.043688983205356635, 0.014309270500234561, 0.023380596285278443, 0.0898495630826801, 0.009583427163306624, 0.025699100879137404, 0.02635910022945609, 0.017216603409906384, 0.027003974610124715, 0.022102853617980145, 0.007998871369636618, 0.024600375363661442, 0.017809820601542015, 0.021599529063678347, 0.025701544400362764, 0.0878121450659819, 0.04209099082800094, 0.009265283297281712, 0.03823142214969266, 0.006988843633735087, 0.050809663807740435, 0.024770418094703928, 0.08517377296811901, 0.008006372627278324, 0.06323112305835821, 0.05965778589597903, 0.0838527426822111, 0.027597843036346603, 0.022627119724347722, 0.015458982488780748, 0.062122436065692455, 0.02845719067408936, 0.026149384138989262, 0.0481613877491327, 0.06316950253676623, 0.017168271042464767, 0.017243159309145994, 0.01868345458206022, 0.04162563825957477, 0.05672643987054471, 0.04114713483431842, 0.049784546354203485, 0.07538182457210496, 0.0074872667664749315, 0.018197505560237914, 0.04685428757511545, 0.04177854294539429, 0.011248983737459639, 0.023889585281722248, 0.04774308363266755, 0.0493023544549942, 0.048841963143786415, 0.02150101267034188, 0.06730176595738158, 0.06682859486318193, 0.057656818462419324, 0.01974546605197247, 0.06513448694022372, 0.05120278685353696, 0.01988651121791918, 0.023032978024275508, 0.03181974490871653, 0.013848103644704679, 0.02616168338136049, 0.015739913214929402, 0.04141481636906974, 0.021916841724305414, 0.07223387903650291, 0.0731922811246477, 0.03620400828367565, 0.038582573033636436, 0.04903718137938995, 0.059492643194971606, 0.020214722317177802, 0.027358016159269027, 0.03846765888738446, 0.018258383934153244, 0.026636589245754294, 0.02855185161024565, 0.024885905550036114, 0.051679375537787564, 0.03679803812701721, 0.06681454600766301, 0.07700346177443862, 0.0732175586745143, 0.06680524689727463, 0.009040255772561068, 0.014286921650636941, 0.036005472647957504, 0.04894092111499049, 0.02682747148355702, 0.010243517426715698, 0.04860029017436318, 0.09725925454404205, 0.036942022197763436, 0.031119591658352874, 0.0164632511587115, 0.037875951966270804, 0.0680518100853078, 0.016109528733068146, 0.01593083441548515, 0.017109283289755695, 0.05820595950353891, 0.05905428253754508, 0.058620333948056214, 0.037474130949703977, 0.005367697640394908, 0.031746914246468805, 0.05306162187480368, 0.03031033898878377, 0.08328914089361206, 0.02759055143542355, 0.00835797251056647, 0.08526504228939302, 0.031427887224708684, 0.02426680781354662, 0.04042969325382728, 0.026238887148792855, 0.01757589194312459, 0.0870159913029056, 0.04106779182620812, 0.03083030620473437, 0.03799414640525356, 0.014952747787901899, 0.027246087302046362, 0.013386121354415081, 0.01777908455551369, 0.08123397070448846, 0.03256426003645174, 0.08946389862103388, 0.042307174735469744, 0.16713303717551753, 0.03038424390979344, 0.03948439749365207, 0.042323127199779265, 0.06353020857204683, 0.03693024060339667, 0.052227952546672896, 0.027779585725511424, 0.03683041060867254, 0.03676823718706146, 0.06364938264596276, 0.03321424410387408, 0.018854788650060073, 0.03956455686420668, 0.03449259718763642, 0.04048669390613213, 0.03740595355338883, 0.02625464665470645, 0.030918148659111466, 0.026793189827003516, 0.029524449128075503, 0.07965373792103492, 0.0414020996686304, 0.04522873925452586, 0.026798913640959654, 0.044226094032637775, 0.05086873876280151, 0.042979230274795555, 0.024954053260444198, 0.06002587630064227, 0.032179400805034675, 0.030526723276125267, 0.11453438928583637, 0.021139371528988704, 0.006383871750585968, 0.09856949400273152, 0.021467536244017538, 0.01820604953536531, 0.05587816136539914, 0.006962479765206808, 0.024356360918318387, 0.020817440854443703, 0.016747523404774256, 0.0146659179154085, 0.03879771051288117, 0.025881830624712165, 0.04198655209620483, 0.03971019592427183, 0.02852332345355535, 0.05631920117593836, 0.01652781429584138, 0.01580643562192563, 0.010504370275157271, 0.01061808863596525, 0.026856591503019445, 0.043074766945210285, 0.07832831412088126, 0.04398376426252071, 0.053013656870462, 0.04318843057262711, 0.05024594698625151, 0.03692391750519164, 0.03296153910923749, 0.019942107355745975, 0.006591766796191223, 0.025114702257269528, 0.03655918531876523, 0.032782210255390964, 0.0644063510117121, 0.05518529600522015, 0.08983132109278813, 0.007788165439706063, 0.03787161040236242, 0.06514926310046576, 0.024777576109045185, 0.02875720016163541, 0.0501495420030551, 0.02846405182935996, 0.01633232517633587, 0.07707512355409563, 0.07403240713756531, 0.010097503582073841, 0.012726365985145094, 0.033186810615006834, 0.06204725279530976, 0.016266828788502607, 0.036750707658939064, 0.06520007795188576, 0.023215438741317485, 0.036985274564358406, 0.023993588001758326, 0.10866016426007263, 0.011424344884289894, 0.06021272682119161, 0.027366651047486812, 0.040606858747196384, 0.025687844354251865, 0.05359222035622224, 0.012479117631301051, 0.0922733209154103, 0.06815083484980278, 0.017907535475387704, 0.03848443884635344, 0.0760187282867264, 0.034283790228073485, 0.008672105068399105, 0.053850818003411405, 0.022125711766420864, 0.022407054384530056, 0.05383613832236733, 0.012046492847730406, 0.04069741189596243, 0.03422303059778642, 0.059996646814397536, 0.12288671961869113, 0.058060776864294894, 0.02260290344565874, 0.04465269164938945, 0.048518679905100726, 0.09021811361890286, 0.046622414665762335, 0.06920273270225152, 0.008996509877761127, 0.012668856033997145, 0.03039946164790308, 0.025604128240956925, 0.09990862527047284, 0.008468511696264613, 0.01384706092721899, 0.034355477982899174, 0.06742865836713463, 0.052403934314497747, 0.07331656117457896, 0.15532051009358838, 0.2132423160946928, 0.062332226370926946, 0.11808538038167171, 0.11510636992170475, 0.19322825566632673, 0.1693625230109319, 0.08482571312924847, 0.16400200518546626, 0.15588106907671317, 0.17180919094244018, 0.11645698963548057, 0.12102046312065795, 0.10187496038270183, 0.15511079400312155, 0.07987171411514282, 0.1633507409133017, 0.0990558011108078, 0.17326684319414198, 0.15463157440535724, 0.13033392664510757, 0.1763454350293614, 0.20128138916334137, 0.07886677194619551, 0.12641701963730156, 0.10062133194878697, 0.12267113314010203, 0.0839298518258147, 0.21515422209631652, 0.14155313634546474, 0.15657034615287557, 0.21805029013194144, 0.1422163046663627, 0.15095159062184393, 0.15735884837340564, 0.10168186097871512, 0.21811320941196755, 0.10863830801099539, 0.100669794192072, 0.1883906699367799, 0.11079078118200414, 0.12092681892681867, 0.11443273731856607, 0.32158986548893154, 0.17704829340800643, 0.3052210563328117, 0.16365318093448877, 0.12321975096710958, 0.07141757596400566, 0.17225167423021048, 0.11729218778782524, 0.0819128131843172, 0.08695892756804824, 0.13824020395986736, 0.11636309311143123, 0.1739427912980318, 0.13305907807080075, 0.12440451551810838, 0.10664907022146508, 0.11428856771090068, 0.11396787827834487, 0.16129686206113547, 0.07854755196603946, 0.11548351452802308, 0.13778977969195694, 0.07461345681804232, 0.13923220307333395, 0.20668585697421804, 0.10666012822184712, 0.19928156834794208, 0.12758147902786732, 0.1115820293489378, 0.09515400422969833, 0.1231853969511576, 0.21779353672172874, 0.2760841604322195, 0.05105892523715738, 0.1762003154726699, 0.1635280845221132, 0.07711803453275934, 0.09403082309290767, 0.19698756019352004, 0.07891818051575683, 0.06751096996595152, 0.12837232643505558, 0.14319040317786857, 0.12129777402151376, 0.13970380823593587, 0.18834400369087234, 0.11637648145551793, 0.1196614645596128, 0.1868805626872927, 0.14455616270424798, 0.0858571648132056, 0.12288350611925125, 0.06328983436105773, 0.10359876905567944, 0.12305096432100981, 0.20792827155673876, 0.18738161626970395, 0.17144926416222006, 0.1601047205622308, 0.05530210633878596, 0.160557979834266, 0.16855242429301143, 0.1445380988297984, 0.11573484283871949, 0.1345922364271246, 0.11790118674980476, 0.08952861389843747, 0.13985045661684126, 0.16852646396728233, 0.14867567602777854, 0.1335038768593222, 0.14692723547341302, 0.14388163952389732, 0.1672021162812598, 0.12964635650860146, 0.1806697217398323, 0.10736421114415862, 0.12345222130534239, 0.13712610671063885, 0.24380759394261986, 0.140385307604447, 0.07463013287633657, 0.10095251534949057, 0.1372999176965095, 0.17313386517344043, 0.11877985249157064, 0.18368260381976143, 0.17679277196293697, 0.1599183227517642, 0.08842621289659292, 0.08346840666490607, 0.20353177387733012, 0.041716221094247885, 0.13054543873295188, 0.10949391522444785, 0.10732701470260508, 0.15320638369303197, 0.09644656573073007, 0.11485106369946152, 0.15033407922601327, 0.12829601881094277, 0.14623764669522643, 0.184089612448588, 0.258953373413533, 0.07883352373028174, 0.13054402865236625, 0.11302779239485972, 0.09089254032005556, 0.19229222933063284, 0.10605691059026867, 0.1570640376303345, 0.20353247149614617, 0.16852054162882268, 0.14445983193581924, 0.13179031724575907, 0.11605574749410152, 0.16407017887104303, 0.11229158189962618, 0.15230718272505328, 0.14960125292418525, 0.15480093250516802, 0.19022411608602852, 0.11977847898378968, 0.09860279416898265, 0.11957502661971375, 0.07758793275570497, 0.1778500058571808, 0.13208698335802183, 0.14440135069889948, 0.20694954204373062, 0.11594418043387122, 0.12127542053349316], [0.015214305676636286, 0.030977269998402335, 0.041821535560302436, 0.030231426426325925, 0.024092831699817907, 0.015797926898812875, 0.04109298773983028, 0.04178607945505064, 0.06863908638479188, 0.035482570237945765, 0.08059443978709169, 0.03297656759968959, 0.03473382857919205, 0.02371395046793623, 0.014228321670088917, 0.012649976724787848, 0.04216147630359046, 0.07290793466381729, 0.06796215122449212, 0.052303406700957566, 0.05465505746542476, 0.04233654522977304, 0.04140979202929884, 0.03601112410251517, 0.025161208941426594, 0.025931918171409052, 0.019748317754419986, 0.016961818546405993, 0.03376225336978678, 0.01922456744068768, 0.03714851365657523, 0.024322118224517908, 0.05764064706454519, 0.06412675429601222, 0.0660787288506981, 0.06006686140608508, 0.04528674922767095, 0.031069687793205958, 0.04729227344796527, 0.031806486440473236, 0.1393224927596748, 0.06354519253363833, 0.010471001460246043, 0.05910202118684538, 0.01816201791370986, 0.05590548724285327, 0.07202942477306351, 0.011838210029964102, 0.012186067633592756, 0.046122793428367004, 0.028522425454866607, 0.09285829655709676, 0.01664027749939123, 0.0932299937994685, 0.027749666041927412, 0.03751337200810667, 0.03507368397549726, 0.02699225238757208, 0.009463226142543135, 0.015181833932729205, 0.050043451992678456, 0.047266491237678565, 0.013081279557809466, 0.05348114682419691, 0.05923396391153801, 0.05379673770221416, 0.05532329836569261, 0.03630104038165882, 0.0374758304678835, 0.046488538646372035, 0.038964667764957994, 0.03952654034947045, 0.02834204089595005, 0.05066256271675229, 0.040152720030164346, 0.04417918658873532, 0.06133908435003832, 0.05154616374056786, 0.04310971839004196, 0.04170901112956926, 0.02295913433044916, 0.045452507911249995, 0.06112316761573311, 0.04554141349217389, 0.07492031261790544, 0.1061985049454961, 0.05174272526346613, 0.04223425501550082, 0.055478733775089495, 0.09610222405171953, 0.11095976078649983, 0.025675335455161985, 0.07298180062207393, 0.06518931681057438, 0.0565730231028283, 0.04342458567407448, 0.04894384888757486, 0.06957159494049847, 0.03615445508330595, 0.06761628814274445, 0.043929342573392205, 0.01970596338651376, 0.026957866830343846, 0.01273277164727915, 0.04256043263012543, 0.024463092886435334, 0.04047451526275836, 0.03211078183085192, 0.06799300230341032, 0.06072150245017838, 0.011579491783777485, 0.022294029004115146, 0.045243248241604306, 0.08791459855274297, 0.037897700603934936, 0.03497082972899079, 0.014094956804910908, 0.018542045763751958, 0.08972475610789843, 0.06759403855539858, 0.05110078607685864, 0.02524448533222312, 0.027591787111305166, 0.04710035405878443, 0.03288953594164923, 0.02624249584187055, 0.03955969579692464, 0.019934181218559388, 0.03606913778639864, 0.10070423726574518, 0.04006599265267141, 0.020486526482272893, 0.021298931424098555, 0.07166592826251872, 0.059783906472148374, 0.04932469681079965, 0.03195131655957084, 0.029921481436758768, 0.008137072254612576, 0.04697289019532036, 0.08985490654595196, 0.04724120626633521, 0.03679560017189942, 0.08587622316554189, 0.015708911851106677, 0.03604324425396044, 0.046556315282941796, 0.05687839460733812, 0.049434067113907076, 0.03301659533462953, 0.047444135416299105, 0.0068328441921039484, 0.04188452163361944, 0.05365107637771871, 0.030493026060867123, 0.035118157175020315, 0.029777480667689815, 0.05668427103955764, 0.047465286625083536, 0.0611211118666688, 0.03958093235269189, 0.04686336404120084, 0.032561324842390604, 0.015721268609922845, 0.06812333827838302, 0.06827864010119811, 0.09543562700855546, 0.0057297548482893035, 0.03444277310336474, 0.07248399764648639, 0.05808050686027855, 0.029498789372155443, 0.046072691038716584, 0.007373155067398329, 0.04089802554517519, 0.040168175255530514, 0.07330198539420962, 0.08593554302933626, 0.07184079309809022, 0.03926464014512021, 0.03722407542227302, 0.023987862332432996, 0.014151655032037525, 0.024781813772278838, 0.04433264046383556, 0.02784588919894304, 0.030070215252635535, 0.014030074544280069, 0.06358363578328863, 0.019009485622518696, 0.04075476877915207, 0.029763903075945564, 0.006939228742339765, 0.028485731818364002, 0.049023900646716356, 0.02622329833684489, 0.08938370214309543, 0.02449473991873674, 0.05665894153935369, 0.019356703123776242, 0.047759674343978986, 0.04272131540346891, 0.04902571519778576, 0.058298612930229865, 0.02620887284138007, 0.04457861417904496, 0.0015941279912112805, 0.057493612766847946, 0.021285123766574543, 0.08337220948305912, 0.04585933842463419, 0.025606432609492913, 0.08673599382746033, 0.033670791090116836, 0.03967224249208812, 0.02523359431506833, 0.0293916139708017, 0.04552955397230107, 0.02230176960438257, 0.10376047561294399, 0.02753480501269223, 0.06419396318960935, 0.018960915767820552, 0.013161029819457326, 0.03502472449326888, 0.03573178342776373, 0.02833258778991876, 0.1285281329182908, 0.03348182544868905, 0.09842582163400948, 0.02104641382175032, 0.005250529684417415, 0.029426392866298556, 0.04711533802037593, 0.01734137513267342, 0.03836087496893015, 0.04696311611041892, 0.05885366888833232, 0.03438175001065247, 0.014105019399721641, 0.10318968241335824, 0.012751762278639944, 0.04170025378698483, 0.014255123405746417, 0.05989078686980065, 0.00397254952986259, 0.01858724997873651, 0.016942377988016233, 0.023046370079100598, 0.052383677393663675, 0.08936502228607424, 0.025834136504272465, 0.048351065852330066, 0.04953610499796923, 0.013584519692813046, 0.0220815947977826, 0.016075764724519104, 0.026147111311729532, 0.02800035053951433, 0.026346353843109682, 0.03935691507649608, 0.05151462246431038, 0.024714254213904496, 0.018957765350933187, 0.05012043497117702, 0.05998847205773927, 0.054041119510657154, 0.02490417165972758, 0.061355374491540715, 0.02597576425614534, 0.027268442645436153, 0.07241672195959836, 0.05882078803551849, 0.03105774292635033, 0.051074810908176005, 0.030304123501991853, 0.02935567361419089, 0.031096616621653084, 0.012970643892913358, 0.007136754129533074, 0.025262551062041894, 0.06048916569852736, 0.048580474831396714, 0.007391504204861121, 0.026151063248107675, 0.09346778533654287, 0.02690346369490726, 0.04416223964653909, 0.03075744585657958, 0.03776664103497751, 0.042440638862899505, 0.01835746250435477, 0.054615081680822186, 0.08914107180316932, 0.06551193582708947, 0.034556948812678456, 0.03265100225689821, 0.01936151038535172, 0.07268359084264375, 0.05523679734324105, 0.016793009635875933, 0.024588757041783538, 0.057228821897297166, 0.01709210071567213, 0.03584984799090307, 0.04498212358157616, 0.03348742124217097, 0.030782986868871376, 0.013950350257800892, 0.04296914819860831, 0.013952381887065712, 0.010431389328005025, 0.011326782150717918, 0.024212464049924165, 0.03286399492935743, 0.03228091918572318, 0.03247140994062647, 0.05833733448525891, 0.032760784451966174, 0.0663936666387599, 0.03552354050043505, 0.028681651383521967, 0.031001024290162604, 0.019480205774016213, 0.03207655769074336, 0.06812813255237415, 0.05808088906633202, 0.022285021186689846, 0.009410981729160994, 0.03514962794724852, 0.029876587068429217, 0.03330046311020851, 0.022045361292839516, 0.06474559413618408, 0.04287865442165639, 0.029130040311429184, 0.02500257673091255, 0.010453397717355983, 0.023306314724322874, 0.0917212817876134, 0.043300390971126035, 0.007359964783972828, 0.12955694255651906, 0.031214875998557545, 0.022860838726046495, 0.05324769685103092, 0.04518539411947131, 0.03647628371254541, 0.03420975728658959, 0.01897067872050684, 0.013716118246520637, 0.019666954249260016, 0.2517355716554448, 0.22628842620179057, 0.13651056942762807, 0.1395120521192439, 0.10319396460545249, 0.12063439789926633, 0.09309191722422838, 0.11854275115183555, 0.15345803112722933, 0.18243995174998417, 0.13307398039614782, 0.09846331493463367, 0.15396680304547772, 0.1277842783019878, 0.07225428067613393, 0.09020904457429424, 0.09525386762106791, 0.10892094753216952, 0.21461094031110406, 0.14052223385078833, 0.18291553482413292, 0.14268412487581372, 0.16519226162927225, 0.12891436141217127, 0.07979646034073085, 0.2406404193607159, 0.16946930321864784, 0.11294158452074043, 0.12609163240995258, 0.12062494293786585, 0.1980956460465677, 0.13614623429020867, 0.1266717692487873, 0.14547866710927337, 0.15526324597885832, 0.15395136637380347, 0.18459557904861867, 0.18495945405447856, 0.06903157860506326, 0.09780868131201714, 0.2853073045844212, 0.13824217807268724, 0.10007002754718997, 0.2222586830612272, 0.12749316345434636, 0.14608933590352535, 0.10723060971940868, 0.17519008921226487, 0.11447037904872559, 0.14881867304211482, 0.11040652680094354, 0.12419417602359317, 0.25383656204212457, 0.17630310292588547, 0.14318255125544965, 0.07991980528458953, 0.06291982179391198, 0.22863806574605405, 0.10108951581059955, 0.137135190598201, 0.09303794824518263, 0.12194055554573424, 0.10880589979933575, 0.2014648777549155, 0.1759136386681348, 0.14846083911834285, 0.16169337672181427, 0.14489032211713493, 0.2459072633064352, 0.11413486150559038, 0.095839236601023, 0.13891781447455287, 0.12263606666238047, 0.17216191889019683, 0.12870632257545367, 0.13722579198656604, 0.09675610068370588, 0.07300701137864962, 0.11145138909341767, 0.13325801817700267, 0.1755750857410021, 0.17725792044075206, 0.18218863086076453, 0.1502046041423455, 0.17390785098541528, 0.22597028233576566, 0.1282878255005926, 0.1459435632568784, 0.15710632520494983, 0.16341852868208662, 0.17319341510301456, 0.08964166525402106, 0.14182424289174378, 0.18838890362530947, 0.1540393108734861, 0.16478327888762578, 0.17957330244826153, 0.1293402651208453, 0.11938430208829232, 0.19109265151200816, 0.09659585615736432, 0.16741284169256687, 0.13905002066167071, 0.056380554524366744, 0.07584451654111035, 0.08185485887224786, 0.133387062815018, 0.1319204899482429, 0.16082193207694218, 0.18767457164358348, 0.13488631986547261, 0.1296469650696963, 0.1311808655736968, 0.21783671487355605, 0.2913801505928859, 0.08496328504406847, 0.20888837316306308, 0.15338994649937376, 0.1376907475059852, 0.12155900258221664, 0.13694469613255933, 0.06793879583710805, 0.12108088136301376, 0.17523380171041936, 0.1268883130978793, 0.11240699328482151, 0.17272957280511037, 0.12183073995402083, 0.10970690418616869, 0.14495520066702738, 0.1518220704747364, 0.10917509600403719, 0.15964883408742025, 0.16909527563257143, 0.1243706290551927, 0.08607114825281315, 0.0942008788115345, 0.09289497349527664, 0.08516404341207817, 0.11013073730282485, 0.13231535704107955, 0.12163074599811807, 0.12617545056855306, 0.2246471369289793, 0.11119223112473264, 0.11275151307927445, 0.1480408280622214, 0.1223955737077631, 0.1269334356766194, 0.16163409396540374, 0.16698021412594244, 0.158542737190146, 0.13918384473072365, 0.20890759478788823, 0.10834595377673395, 0.1335198775632307, 0.08726370535441674, 0.1355831223190762, 0.18566599348559976, 0.08696364020579495, 0.09755644758115523, 0.06523673262563534, 0.12126783578423783, 0.17672087269602343, 0.13359612581552938, 0.16814703354611993, 0.2363493066513911, 0.14340852038003504, 0.10492805944522843, 0.18706691596889868, 0.22954183834372088, 0.10252658830722794, 0.14387092291144654, 0.07495234371162951, 0.1068778446642682, 0.09815545723540708], [0.04842050118895713, 0.03708928656124044, 0.050318135690758936, 0.0009183185181882436, 0.04223261115839705, 0.012573942767630797, 0.03726532399014104, 0.055187433390528895, 0.006624608222409734, 0.03014127960341284, 0.06469653075328097, 0.02285795177158434, 0.025731879686645698, 0.015954764967318624, 0.03923499876691494, 0.0160083740047412, 0.031882938783383, 0.020271565263101365, 0.06311738150543533, 0.06937265483429655, 0.06319142557913437, 0.05382810457376763, 0.13582890678662807, 0.1393507537432015, 0.0443533909128746, 0.03673607992823236, 0.03291002292826306, 0.04248404708050657, 0.0822378441807814, 0.08644596993690357, 0.016727656111470424, 0.07363940283539705, 0.0377787046454614, 0.016092001060314942, 0.031248235536622815, 0.033126436901511624, 0.01704760710708797, 0.03621344098064583, 0.04561389905575197, 0.033304771277471446, 0.07017303141765296, 0.025162231249851175, 0.03802456703851931, 0.008610677505203057, 0.08854416984831914, 0.10166264677536674, 0.05805076900287531, 0.046563796131522395, 0.043345457888790406, 0.02488103520590812, 0.027517986090970226, 0.06718350472510792, 0.05028256826335564, 0.0421402879874222, 0.009196677310683299, 0.061101025639800355, 0.038561822584597394, 0.04915058525511995, 0.014340017678478034, 0.04486523903324269, 0.04147054052737076, 0.03136773986625485, 0.05653460953908507, 0.04876763705397025, 0.012899567482236307, 0.052803588259848766, 0.09143689079792239, 0.04607845010468736, 0.025390070586581714, 0.022657134031760506, 0.068040967307752, 0.03717701583809685, 0.05952051084022969, 0.03838650503894314, 0.06279747132794, 0.026681962299335282, 0.03491612973448355, 0.02994587954162853, 0.020360465277917683, 0.021990460918459576, 0.02322270993317943, 0.039660420079599135, 0.02912583604484098, 0.04878045765508432, 0.06524026524857618, 0.06538195608300157, 0.0403329728578683, 0.03486052431981079, 0.021507191049749963, 0.043878883952856995, 0.053287750561139546, 0.025594072139938362, 0.041535318887326866, 0.05443369707791135, 0.03624501565354876, 0.012590868373081321, 0.016101092369353864, 0.02779083853965858, 0.053710069696535356, 0.006661846873612376, 0.049525102658662945, 0.10745441919425502, 0.03246322405175306, 0.055406437459168956, 0.009325181108579272, 0.024068431739578955, 0.026699820227804594, 0.030582367653551046, 0.08859306253725663, 0.0020782699994015275, 0.03399914319743402, 0.0696649645396974, 0.008155359701049747, 0.07775182122713886, 0.018154600147681776, 0.011256103716732468, 0.06270638754358515, 0.05038414601585828, 0.08090024915873073, 0.034988734041689895, 0.060434146580519155, 0.04607446106092539, 0.008873277183738537, 0.047279104037443176, 0.09236228215740994, 0.04749446045025252, 0.05131581965542864, 0.05442980080260895, 0.0710974282992538, 0.017922521292348392, 0.04004983238701243, 0.06832632308942266, 0.012957163708051667, 0.07567473541712388, 0.029350159456953406, 0.040181660078815185, 0.01137612476668437, 0.01611300012882566, 0.07810526163666509, 0.03492812655167654, 0.028342298792267684, 0.02563992573413998, 0.05540754325920716, 0.0832393576274626, 0.06521420844364911, 0.041892165754688904, 0.009567571178195067, 0.011368618870619684, 0.036641174083342776, 0.012205808761791559, 0.018215159398096148, 0.02855548071238445, 0.04765651210618671, 0.03570408276573289, 0.05469429110235069, 0.08439029508735985, 0.06891451223054901, 0.1350416662171483, 0.038186039819265716, 0.035463567546685226, 0.007851219233998563, 0.030962041128077544, 0.03873830530210398, 0.07864670289563946, 0.03805888023634907, 0.014110389765846776, 0.036151571839582175, 0.06884130678372458, 0.01240014662471367, 0.03206217115803156, 0.04075239019584842, 0.020943264571542386, 0.04666027904022485, 0.042420545214554295, 0.02876901886338601, 0.04833302795304917, 0.03608609586081002, 0.014932918529666495, 0.0287813923205249, 0.0341802309412742, 0.02040140770986909, 0.02992194342368748, 0.0021455069554576767, 0.07416087290039286, 0.011824023877125, 0.0038438523097283905, 0.013957913670310518, 0.004703159593191231, 0.05738117739383597, 0.032327908265870064, 0.0376028675964335, 0.023471088206861168, 0.021090339687361848, 0.025656332763901446, 0.014564295634045266, 0.04552234029688407, 0.03564421000191942, 0.0060865205432492075, 0.0962360184348654, 0.039524970707134344, 0.06188166109495796, 0.05494979028298985, 0.0065431412804173306, 0.05243137893558014, 0.0415916144993389, 0.08935439473134466, 0.05529475907678716, 0.05072711472166702, 0.020770251394424122, 0.06597389306989498, 0.007658373551748809, 0.014533050289173843, 0.0429862361488631, 0.025767267143237405, 0.025424853192816954, 0.031214441842166707, 0.015576961704937275, 0.026700495582190342, 0.03151407654513605, 0.06523767515318468, 0.0699138363415841, 0.039860889010014944, 0.0673121189174708, 0.01219647532707313, 0.035463233580230735, 0.0462543465255294, 0.05672398707247339, 0.03895992173056584, 0.018283221761521418, 0.034252312034368515, 0.017806009673222434, 0.020077096596651245, 0.044127874498371966, 0.045036615774733946, 0.06789367325836793, 0.062326244660653174, 0.025426315223739948, 0.005590510781985358, 0.03368023863004055, 0.032596465534879826, 0.017409272368240636, 0.027573576662689447, 0.06484087105491199, 0.04260571477061603, 0.029953519951959606, 0.02528440731111914, 0.028033812122885138, 0.04326863076130394, 0.04355584933364298, 0.039388100121868774, 0.050401690386934206, 0.018741735439107288, 0.014140691655484261, 0.028790958604076877, 0.015321617447625613, 0.050965893315151334, 0.03571128901967313, 0.01952235234057298, 0.011933228124689776, 0.034853366305469535, 0.05518085054063704, 0.028001365426462144, 0.03330677507619839, 0.01702635570836719, 0.020797770230274182, 0.03608962106227409, 0.05236535747826565, 0.06222921256267, 0.029395981509878766, 0.016366794225177728, 0.029086684044159483, 0.020990255507058464, 0.03704599708726164, 0.0544546219316544, 0.03506104891130235, 0.01770724466041429, 0.06312177501968108, 0.044331453027552925, 0.02850524844689062, 0.03317196395073552, 0.03344759388710372, 0.04781207739142701, 0.07385936798527837, 0.020308219936850946, 0.0596193500678055, 0.05681940499925986, 0.04289055104891304, 0.059817451547132805, 0.0432383622683119, 0.01436608097719727, 0.028453285121941008, 0.04283133879653178, 0.04372970484837424, 0.03187541711668018, 0.04557911088340916, 0.03016456263139844, 0.06332346849376336, 0.022889192478032783, 0.024477126899000723, 0.04429860186064616, 0.08078291561105289, 0.026431313053763006, 0.09050151755218394, 0.020368894220155198, 0.08216846821596846, 0.03630065817560535, 0.012055383776896633, 0.01456150144804269, 0.0027716316708392696, 0.07271690585184842, 0.0318953103851527, 0.05175154568860307, 0.009463233564019902, 0.025838598667178303, 0.03966945572756231, 0.12403354558045976, 0.01553531052195467, 0.05729859491111711, 0.014469144880422391, 0.02022914410190424, 0.06192382992594503, 0.024400463044003118, 0.07543273590272292, 0.033339667061227374, 0.030773450271226466, 0.05467095797939692, 0.033236660674447194, 0.03163366251101252, 0.013526917900890112, 0.03447399154538289, 0.062460246845148504, 0.03851334549835883, 0.023964527354110032, 0.0068824442405457376, 0.02922660485637607, 0.04839131252083462, 0.034258497835253365, 0.0035983092720925924, 0.03952941617171746, 0.0587808604905149, 0.037251386456773616, 0.03904782912286464, 0.026306767686037347, 0.0531847367528826, 0.03359266520419624, 0.10127049594302662, 0.014078418043936836, 0.046755337025388144, 0.015904068859526888, 0.04216782166622579, 0.0030886212653058465, 0.05126279320393223, 0.1999666151823476, 0.11509281088365242, 0.130399695772212, 0.08218309594667517, 0.1247632919694297, 0.14896204113028944, 0.1272756399703212, 0.1797310236725025, 0.08746222243644297, 0.19274269812740386, 0.10222247103229165, 0.0978509392007254, 0.15161130053456873, 0.10263458563713357, 0.13071412889985368, 0.1208042012876831, 0.13215077837230638, 0.1259135318105109, 0.09899209515424445, 0.20607251644833013, 0.1797227413044311, 0.14664453658042476, 0.1363210249110125, 0.18971102486830205, 0.1343844796065241, 0.2028643901576288, 0.20896451751468703, 0.20365410950034857, 0.1006068749120459, 0.3127423964906484, 0.1387257911846973, 0.1317701456719078, 0.11299650344881229, 0.11236440885113552, 0.12376465805573389, 0.11841527986689471, 0.08956425925134681, 0.12484866863815114, 0.12868612131569535, 0.2504381787730381, 0.15231605881126598, 0.06961104008951224, 0.10761204393929802, 0.14264596364228055, 0.20778741192771122, 0.24714041588595137, 0.2649607026251033, 0.14254292385885492, 0.14056970161618665, 0.0638298803824, 0.17191107297549024, 0.1398536330088973, 0.13000215694773942, 0.18275708629516885, 0.18086183408740908, 0.17155736539280042, 0.11972913358476944, 0.15131159161683172, 0.14266902959207073, 0.143395206250716, 0.13253751152660698, 0.08080438594333827, 0.12096269434550777, 0.11834872406325303, 0.07931860629469156, 0.2079118404071778, 0.27610048768110573, 0.13192037120461464, 0.1041963834722992, 0.08652344273286872, 0.13629251159727573, 0.07953602587804198, 0.17837161693023518, 0.11170795696671121, 0.14057077030884102, 0.08030029697692953, 0.11082598124630749, 0.11364724079612643, 0.10036261926870793, 0.09522780339466408, 0.0732283791876398, 0.0847514315682929, 0.06685014683171175, 0.14752743998542428, 0.13089408486848697, 0.14378535328432918, 0.16977644845610484, 0.07522872692788951, 0.16137805301696062, 0.10993004572810605, 0.10948329509119503, 0.057259528257418424, 0.09234653378371149, 0.12088023431715555, 0.12448276756913401, 0.10599040673696436, 0.17006760783260688, 0.11982126379734837, 0.12520826887339354, 0.11623318758211099, 0.10850920400116593, 0.12223873563925736, 0.09542030908050947, 0.15083344071172178, 0.1030671464104671, 0.20697375090094283, 0.26569061970803887, 0.0892113902955316, 0.13979007548186928, 0.1046516391215846, 0.18405324721243232, 0.15543410321697593, 0.08998188059194945, 0.17997260758420452, 0.11715270855347626, 0.10735551317338832, 0.1543121540453285, 0.11928684325539507, 0.1492716057691723, 0.08371933421585709, 0.1356673560803756, 0.10915054575889371, 0.1423648529453203, 0.11306389787932858, 0.22561375459190458, 0.12936021405039355, 0.20321652438724414, 0.13878134835977107, 0.11139305628603324, 0.07414097592118196, 0.08606489194789901, 0.14140458806650713, 0.08325479429913685, 0.19757502945140004, 0.0828152424946893, 0.15163356496486813, 0.0600382850097958, 0.09480391090619378, 0.18688036972889677, 0.23242819908773527, 0.08212006534449756, 0.12726326094707474, 0.1220450944674667, 0.11486152798170224, 0.1814050565008074, 0.18334676715312526, 0.13155918277334422, 0.10385804576799273, 0.10123510292032734, 0.15401931741507724, 0.11452871185611002, 0.06897804007166997, 0.09323855076218024, 0.14318017638288438, 0.12524699413916096, 0.17330688948277384, 0.1418479174026288, 0.2106072910828516, 0.1355312907253392, 0.0687957314949017, 0.104273581673624, 0.15657987532904372, 0.07800755047355779, 0.24041416822001338, 0.14479528268566355, 0.0996437824505847, 0.08081637904979289, 0.1928850865806453, 0.1625184965087101, 0.18538170639658347, 0.06385155109455809, 0.11380989730241708, 0.11332371635944583, 0.10027833355707116, 0.12450023030396551, 0.15057581156725064], [0.06380987208103761, 0.0327103406743845, 0.05051962136349175, 0.05139489920111373, 0.03298006682598498, 0.03991484314610716, 0.009192678062390769, 0.024100813498080242, 0.020106853007746395, 0.04258671950083226, 0.04896384234598372, 0.04454681315110065, 0.055360613550874405, 0.06916123180417344, 0.033312953455606475, 0.07925550147774629, 0.009405351611349033, 0.03266410858486779, 0.020037807298649568, 0.06557620581588708, 0.03724255489942152, 0.03929105689167045, 0.016064875562733505, 0.009277500903408509, 0.017623534113226924, 0.009015886425913777, 0.05382805262343027, 0.05303347221342847, 0.04871500023000408, 0.04710730798251461, 0.023957794219313655, 0.04413046459376346, 0.013374419540923554, 0.05268304121273104, 0.007671458542972687, 0.06556217180332169, 0.0350865119980881, 0.010038290402007988, 0.0883201599936001, 0.04646200315619353, 0.024365847420995124, 0.04269393015420064, 0.05739286250900477, 0.013366866332944483, 0.018565369609859772, 0.07708563978667371, 0.040705137653276324, 0.014146996199997375, 0.08368570750462823, 0.03353930478624534, 0.027512362466950435, 0.03286813240265474, 0.024110626545734704, 0.00943808310694294, 0.018122752735507675, 0.00799276906036539, 0.011860260165121872, 0.019221576585550793, 0.0391120211861562, 0.026737471234810073, 0.015731617859273683, 0.04515270993579179, 0.030807260664005298, 0.03998802632850129, 0.04714938775578048, 0.012608234628714854, 0.05211834104557056, 0.04406946376548149, 0.01970454217371298, 0.046866091433912516, 0.06179722324304748, 0.08028995143831708, 0.1294274377869442, 0.02137947485607583, 0.009175593822874362, 0.07330360327614471, 0.012542188123916276, 0.018543646947364323, 0.019061790335399564, 0.03769885697693098, 0.010392745698482031, 0.052505801504594274, 0.042440950564923696, 0.030548694558092393, 0.04527346478425898, 0.03524097519402858, 0.028531501920951996, 0.034639883815543726, 0.025388634530827403, 0.11666582999168895, 0.07191641794634052, 0.042823264229809865, 0.028881660182378255, 0.05164173380762804, 0.08734650677070022, 0.0503021201438969, 0.033188439629157074, 0.0697885469708126, 0.012071368710167008, 0.041176572121912614, 0.0204116085296846, 0.044876816536998376, 0.016083291957329493, 0.04032252341858111, 0.04525581651250832, 0.025222354488505516, 0.09358876282931305, 0.009605739833205007, 0.04455027898075059, 0.023253323524841107, 0.018924049581983127, 0.04145622820942663, 0.018438484621583484, 0.038278659849311225, 0.05948080593952909, 0.06627596201724373, 0.03505210603179876, 0.05150731230969541, 0.02476677043887321, 0.03142842528177425, 0.030064086968195625, 0.03550397748767864, 0.04361339917522855, 0.04456742259208113, 0.03252079615776893, 0.060124978990643285, 0.03486878442345187, 0.023283224654733203, 0.03663370807771571, 0.08448358305031434, 0.07291419096873142, 0.03922268282622099, 0.036354382245917805, 0.022204117813089397, 0.025381005252711475, 0.01554042763018515, 0.027557164066820405, 0.01327610167209059, 0.011008353485522093, 0.05339077179087326, 0.031882857147138566, 0.026905567683570553, 0.039230412294273265, 0.07846060194424354, 0.04322057298850268, 0.08484264893922955, 0.03438086685491726, 0.04358205456810538, 0.03889950348821003, 0.04173568020632956, 0.06570626719621941, 0.01946768388734199, 0.0517083823797293, 0.014315038843051298, 0.06545718759298325, 0.02415078786725644, 0.042929484116029926, 0.050928151395055465, 0.08543279735022224, 0.06078850354242604, 0.024081560331978835, 0.05722861780668609, 0.028829431539634243, 0.004583149675454479, 0.06341052241623402, 0.04203469150525052, 0.02705101007450139, 0.03250892179494258, 0.005504338623723015, 0.04409462999319658, 0.02142707435268676, 0.036041233033756725, 0.03389800331206061, 0.04311852026148699, 0.04761230979056563, 0.04014789607026614, 0.05804131033073645, 0.03667477110866457, 0.053033720832900144, 0.01983154590561753, 0.02949585974420188, 0.0080543598960503, 0.09914807975292206, 0.0468077994446503, 0.038070580194471404, 0.01400248242134694, 0.06533641048008576, 0.048750719797681086, 0.08619982923846692, 0.04973933471774217, 0.03543670922226738, 0.011087113907706225, 0.02368740941165015, 0.0023843314693294815, 0.03700356108311098, 0.03488215421384666, 0.041848308537737466, 0.03924021977582015, 0.01882204509456642, 0.04644621396437287, 0.03678625282191206, 0.06389279224094935, 0.038032663869671524, 0.08645674592116848, 0.01793310988432495, 0.07443354537826963, 0.02101692087308038, 0.055250790537684225, 0.01984100086701801, 0.04044993162096944, 0.02157317354431143, 0.04014388476207387, 0.022824905790912453, 0.05927472266193945, 0.04584038026223425, 0.06098552519688383, 0.0335822491615545, 0.017492864171799738, 0.03364640040672384, 0.02141958051652182, 0.04541091053397395, 0.031081595552677754, 0.006501546222352772, 0.02852121204341529, 0.07366614241618663, 0.04296168961445801, 0.02654263334989082, 0.10359245337895118, 0.04190963962173555, 0.06076599420339335, 0.0373803976981435, 0.001372791607536783, 0.042562488379189745, 0.022650122591585387, 0.10017227323260158, 0.015535052625637036, 0.024954099644673988, 0.04768329621583689, 0.05449415613838937, 0.039042693460942246, 0.024267733642773237, 0.01554389995362726, 0.005393475212258636, 0.051980453717987984, 0.061231907093315385, 0.04312356686568819, 0.10880710950004868, 0.013906662807130488, 0.014856912403047318, 0.010125123535544844, 0.009802738295547897, 0.05185297872230876, 0.04339124840043951, 0.02647062276082579, 0.01690023513219785, 0.06965016611502506, 0.023128880202420987, 0.027488457890285645, 0.01142105253165937, 0.021404694889497478, 0.01739003033435438, 0.026991981503670104, 0.048900351612246595, 0.030266500325524248, 0.0144902125975932, 0.047649446860305034, 0.033399673411622643, 0.07142789923818782, 0.03444289926846977, 0.02045721350441454, 0.01748179132846417, 0.02055551467492478, 0.050036219763569534, 0.08724386774701998, 0.07105456927092746, 0.05075668930658139, 0.006597652027267031, 0.06225185548828449, 0.03569590800907463, 0.024506079935235903, 0.04445451595529448, 0.013248832383396802, 0.026919711162918247, 0.04261615678842645, 0.015045262061903486, 0.02749299612332834, 0.011559592949197395, 0.01883613662357675, 0.14515512040816247, 0.06297511921729892, 0.008795913854555693, 0.0285617333065602, 0.004374159498183872, 0.035624468873720616, 0.01067383691406576, 0.04959012221661396, 0.008911244531191187, 0.009267016212106682, 0.057884947236743756, 0.04002843255875632, 0.023618103950866498, 0.02083286082779523, 0.031793561938684434, 0.04652318581065629, 0.02779922851914307, 0.14946351031539962, 0.03052056530577829, 0.04019655869342387, 0.043246444256510586, 0.02742849235801259, 0.026499247396714054, 0.017779477893782314, 0.023187517290352844, 0.0733536240295507, 0.029931769458926283, 0.04573170757794287, 0.03161234802973922, 0.056016419766820036, 0.02109678152919514, 0.059821525937877595, 0.040623108070576563, 0.03947239696572069, 0.014396318856597645, 0.02271987519634422, 0.041028239065781236, 0.0349761620600475, 0.06632265052758157, 0.011158392553625163, 0.006883539836053387, 0.03671468009997625, 0.015265461915987544, 0.01037220305079245, 0.10581198701402172, 0.015204686515062349, 0.09316595387645066, 0.024887202453101054, 0.04191189203993417, 0.010424631145724561, 0.04212386797007639, 0.05385788324929308, 0.02405022500170162, 0.03223898784199264, 0.037481392864719965, 0.03338088594318833, 0.0374266965809511, 0.025169997825287282, 0.009986862351070158, 0.009047013027156936, 0.0690696136734914, 0.04954702570103109, 0.013107405939081218, 0.03833001646853518, 0.1749172163545154, 0.1386566527071409, 0.24899398908019066, 0.14783302671276033, 0.1964611845323816, 0.12063303976901807, 0.1123515103245154, 0.08702399907633662, 0.12918407272081822, 0.1003761931497138, 0.2267378114629537, 0.2101310103898868, 0.1398735967813991, 0.17031927010975778, 0.09523270156932995, 0.1477791171055287, 0.10049347474705428, 0.09304618608439341, 0.11911572626559064, 0.16105086979223415, 0.18231283669592813, 0.1550708813010715, 0.09948677368811332, 0.20454385550692677, 0.1385970730916597, 0.0910519684839528, 0.2630091807805002, 0.14788422005949542, 0.10064087269711308, 0.1518020176445134, 0.09408258047187701, 0.15677905292250216, 0.14696838014060631, 0.08245677032391541, 0.16634101717500016, 0.15040922909975052, 0.0963476300239563, 0.15954647707985714, 0.1602371345506981, 0.1388688327278942, 0.11766320967581123, 0.10382635606219992, 0.09862883613095619, 0.1036611688323319, 0.11158612600411288, 0.10811361702508293, 0.1831658760784194, 0.05762028995377477, 0.1915077495505102, 0.1341231248807162, 0.11375911213690415, 0.19882574124494568, 0.1341823927941732, 0.07599411124829203, 0.10025065887020901, 0.09594675153493881, 0.1348819411941804, 0.10453564886120148, 0.20651853235904127, 0.09112851359532215, 0.06855043684481643, 0.20057663088664412, 0.1786840017302893, 0.18479995167581365, 0.16011260217055678, 0.21247916563879699, 0.1372036462998949, 0.14887163270032033, 0.16696744918590412, 0.13157037436030805, 0.14427350834012032, 0.15664416016079485, 0.22149768483359367, 0.10318920743884519, 0.10065661364933476, 0.260045399190858, 0.11603467050008476, 0.1481147311278619, 0.08908771880669519, 0.1449575458536856, 0.10444194529554807, 0.17812547623179853, 0.18397165549686179, 0.09429937665117905, 0.08531488492735662, 0.10812737644300796, 0.15592775016557425, 0.11079270334448665, 0.05565839288465213, 0.1585093405446969, 0.13638715026900172, 0.2509789966279641, 0.14806828752625734, 0.12396666323184036, 0.21600841922918335, 0.24248648202046752, 0.14034876425284892, 0.20420555491000414, 0.19697066891239956, 0.1400352513883263, 0.06737099349265918, 0.09137653192738071, 0.09441606453037821, 0.10447730121086352, 0.14416013786103576, 0.12854934349888936, 0.15548900730209425, 0.07558844590676017, 0.09113632841035724, 0.1796800529700704, 0.16578179405769333, 0.2150840000831522, 0.2329249630565755, 0.2271183699485846, 0.08744288948946632, 0.15868237969698384, 0.09609095082851127, 0.17005286877974868, 0.11668834675219841, 0.06267637509154156, 0.10820375828188844, 0.10810329375090078, 0.0934691954171285, 0.11471498350147158, 0.09954778564861044, 0.1268776410142891, 0.14178994082612917, 0.1348968138336204, 0.08886750132660381, 0.15489157842239365, 0.1659816544270143, 0.09096966430661269, 0.17234565981198102, 0.09736783817061223, 0.1245761223253794, 0.12793171335943043, 0.1037988520693034, 0.17144803219707683, 0.07586148945847526, 0.19661350292153656, 0.20142037858022377, 0.1799164863768965, 0.09863565646810457, 0.1852849600254558, 0.1342668937286362, 0.16949475888395682, 0.1820620204671286, 0.10106948524480686, 0.1326336048077792, 0.14624383620684966, 0.17618355777813122, 0.07060086471028626, 0.1829673070460558, 0.1163464986893814, 0.11371131040505134, 0.1232302152493503, 0.1839069402194582, 0.13143362622940913, 0.18496378819691017, 0.1365573247312568, 0.1660207804525271, 0.12977376842172816, 0.09229663919541053, 0.12111084186471999, 0.12989328388357535, 0.1311679818900302, 0.10374683493864723, 0.12600909074535593, 0.08243871387094259, 0.12114281358662993, 0.10111884548678063, 0.09565868691424839, 0.16267752391286194, 0.1285250307410024, 0.14019312104210258, 0.1895426315604709], [0.054514680232387036, 0.039016425143927336, 0.03512186049192678, 0.02739135714364238, 0.05145323942997493, 0.022356718218361493, 0.02818577613652451, 0.023111374794098083, 0.03680919631733559, 0.007919582167232875, 0.06329106632620096, 0.07101016657543369, 0.099935060570715, 0.09270820461097173, 0.014345711806527106, 0.045562664890894666, 0.030193304155545775, 0.0054056779754318995, 0.026796112033480313, 0.040694131603231654, 0.019773329986492172, 0.0195498136599781, 0.04079231774085201, 0.03938392183044925, 0.0219353694410529, 0.07364689110545442, 0.027260479400865734, 0.12694517645286396, 0.0036090996354687377, 0.05343765325960703, 0.055306344002019614, 0.016300911920552608, 0.04869895870797336, 0.005021141114411876, 0.020519429599517025, 0.052659381544799544, 0.05996019623125903, 0.04235048276314046, 0.07125597330741584, 0.03985672927228734, 0.006545623764395714, 0.009455893723497866, 0.009395464348926907, 0.02703433587157633, 0.047380559335579164, 0.056537555865361355, 0.026979775029758457, 0.0068334972820593975, 0.03357989655341953, 0.050648257820284925, 0.040312838391400874, 0.05347892038116697, 0.07664081873372197, 0.06347445843857713, 0.03740118154382799, 0.05057709327957127, 0.010619183303788304, 0.09922544864821248, 0.0279549867627793, 0.03144010297546629, 0.019416089780861512, 0.06096401404647622, 0.0385815191839356, 0.06340288571664132, 0.058748569645104, 0.10371319338446483, 0.0263109830848407, 0.025406149215996265, 0.01124344824347645, 0.003611731708588195, 0.07375030938419513, 0.05238803380052559, 0.01594470886630006, 0.028088385952287354, 0.025189935622620396, 0.08385305438423529, 0.016387754330935422, 0.020214974647387862, 0.010985033350152662, 0.05306801547703799, 0.02649246045621112, 0.03417662039282732, 0.02202613410190679, 0.016987847520795185, 0.012938157306052744, 0.006288766453508288, 0.11456488413386978, 0.055616042227484286, 0.05856623138242867, 0.05392391212808434, 0.0157142182069947, 0.016757471894379705, 0.03995444785687141, 0.009999454741773661, 0.024215135781560093, 0.0473148198943818, 0.039470678893849254, 0.05407437143730931, 0.05042706441599876, 0.014879348454996943, 0.01548011792692705, 0.05397254877607338, 0.018554283778939862, 0.021447711624205112, 0.0451919695478864, 0.004033468258057837, 0.020851319895882625, 0.012425114327925257, 0.06012001402268652, 0.02601946376671549, 0.042723987135104835, 0.02709677275561262, 0.02592494012787938, 0.04282212132238783, 0.040337856189580634, 0.012796811570296995, 0.023961684928508475, 0.03299734031315893, 0.041465968897682615, 0.02231045644293772, 0.08607492578448728, 0.011366167927917559, 0.05670434613421094, 0.08116187105770223, 0.02379761092015542, 0.007089690834618523, 0.012409724968165392, 0.00958280839768122, 0.021888224509893917, 0.05978108260023873, 0.03709103060828056, 0.020695528255600948, 0.07874545306549408, 0.03614767927501816, 0.054094012375571765, 0.02641049024532549, 0.0037252763604556094, 0.009113438027270604, 0.034451393148628995, 0.04681925078330096, 0.07359784256550483, 0.0337433694221545, 0.02708303745748708, 0.04233870859025046, 0.06246055112569593, 0.04116375894227531, 0.05670470236509573, 0.015731860912637785, 0.019626423709269147, 0.04588243777106982, 0.02168334165617125, 0.07098425077856518, 0.0758848745317664, 0.011773968799388967, 0.06069124137866311, 0.004037770859213197, 0.016668189673509914, 0.11382752330973744, 0.04512941392022185, 0.023090069589670748, 0.042828381338040344, 0.018420454143779352, 0.04953793068125378, 0.02935578864708077, 0.06848559540230781, 0.022134699174785055, 0.017436036068829708, 0.03345998775330372, 0.01401676876412239, 0.014207906115188962, 0.04876490966125857, 0.03757102575036697, 0.0034646953236006084, 0.014257632792578079, 0.06948856345843524, 0.08232659762143157, 0.022846095962449908, 0.007990876583789941, 0.02080734022456454, 0.028609800356207415, 0.028268156384001486, 0.03842938633169979, 0.07610213084262796, 0.02895489345974056, 0.02161185799195664, 0.01458464068491594, 0.025161004850815516, 0.03311117834527977, 0.05856320713064633, 0.0428529575583525, 0.03981042296800297, 0.08077757214778103, 0.030000278966326732, 0.07582410748000257, 0.017965285696845967, 0.05484380788402632, 0.17043933476088569, 0.013804162008455023, 0.048778420459711924, 0.01478447415138362, 0.007950051967782201, 0.025861072754196357, 0.03856090974295512, 0.06955747187021188, 0.03588088831747882, 0.017049989401130006, 0.12301842856686562, 0.006479320754806395, 0.03932739244191907, 0.004720781889773207, 0.05032282977481373, 0.04356769029982388, 0.03186123838531785, 0.034911584079964086, 0.032458696950925514, 0.12083756082574837, 0.03564408754755277, 0.02417616189632099, 0.04120632853300776, 0.028791441000066698, 0.03408290198422037, 0.04852552250667941, 0.0178016569770989, 0.013506560790119693, 0.004209241760690929, 0.05982521441183053, 0.07235230354126543, 0.08544235621229745, 0.009683319312898675, 0.031542678916594014, 0.07275292227859609, 0.028391506893967744, 0.06513322528917342, 0.11732343220501207, 0.034814670725609176, 0.056420307664666325, 0.18307387945242226, 0.05307841667672619, 0.048182082537095994, 0.019480597256915644, 0.05331693922926206, 0.0515926333173411, 0.015248984382196795, 0.030689845480083022, 0.08373264834517613, 0.04502618859987706, 0.017959374490601476, 0.0430036988836946, 0.015353876751760254, 0.03777864156290889, 0.015247107676259475, 0.0287442775152158, 0.00249669332333724, 0.0336417619837448, 0.017913185074576177, 0.12243708944879472, 0.05835264499182813, 0.0270352283041575, 0.03766563473618589, 0.06369243463268504, 0.039821091340854764, 0.037686418581870385, 0.010012104648922104, 0.051625725682242773, 0.011644594833342126, 0.03358503592608031, 0.03821283877186943, 0.03147169991279952, 0.05183305576792918, 0.07738341169897467, 0.05197132530156523, 0.0921443133847788, 0.048874242856982164, 0.04330216099333484, 0.05231321047176607, 0.05362916075682733, 0.021746385245933197, 0.01051228249707492, 0.03386557516932953, 0.06580734028830193, 0.016676566665410064, 0.028571342263603583, 0.046588628392782994, 0.032609052359475754, 0.02519756118999794, 0.008397849960601889, 0.0197298568309634, 0.04325227753724903, 0.0506838066939963, 0.016791349080449436, 0.036271688441047445, 0.04984288658306468, 0.03773753029236104, 0.02507954486645758, 0.026966050863848068, 0.041167094896081835, 0.04643148604372982, 0.057109588451567106, 0.025427150139876176, 0.0957503347308375, 0.02652070288604591, 0.019705928134499118, 0.04374208387162071, 0.055977045121835545, 0.05326162696292158, 0.03897222653904464, 0.04752722255943809, 0.0485283129819436, 0.06354657292831689, 0.06814621126977727, 0.021998999327479396, 0.02558398449764354, 0.04419182536366861, 0.045000157770118676, 0.021547749420278706, 0.03706098475959152, 0.05254347292066086, 0.04765013334690593, 0.05481350970512722, 0.02851875738997478, 0.06829579855548218, 0.0031839689199841814, 0.054970655764918774, 0.04902562614006456, 0.06444200378609821, 0.05324860227119643, 0.02748659509961726, 0.026022155907412525, 0.04973737173713744, 0.10001329035731032, 0.009069596580957295, 0.026668355021683965, 0.05530571688723285, 0.09096443958696909, 0.0033465635033280705, 0.024485923204338178, 0.02170186195144197, 0.006139944043752621, 0.011327207030262798, 0.016157729369297158, 0.10765695129521191, 0.04901552922092378, 0.017659901204751804, 0.04960120619216468, 0.004090065831405809, 0.03440320921072271, 0.03968580895161722, 0.03976944528403692, 0.06780982541386038, 0.04483812095713802, 0.04451648528629448, 0.01876193669886561, 0.12687289126915857, 0.14678235340397805, 0.13189184304792434, 0.12401333689922467, 0.08986355998786166, 0.16213103604968637, 0.13453377003315836, 0.055381085694534704, 0.13803476264001802, 0.1391471381066367, 0.08246797675383277, 0.1857255434151739, 0.21780385257443413, 0.24323643709067255, 0.14530666696373373, 0.14587178273359314, 0.10873275372432545, 0.16403728688601404, 0.07409392375848256, 0.1399096948443912, 0.17757226451067254, 0.07162876150687225, 0.09549852402415127, 0.15570151386782527, 0.14787703606998548, 0.1727365341503173, 0.15725828736322, 0.31697525060735643, 0.18119113985449076, 0.12198860960779712, 0.24371547857299447, 0.09902655307087116, 0.18903069809312, 0.057437506402493455, 0.14238780015148222, 0.07692788887652569, 0.13604246720205992, 0.12737161450786516, 0.12559369584778324, 0.2534219092922285, 0.09151553618721664, 0.11350346452672966, 0.11138788351672702, 0.10080309875775129, 0.12431700888555497, 0.15550260344753042, 0.11715834887581877, 0.1276494745980017, 0.07253047835547477, 0.1433229655958712, 0.1091685651044827, 0.12072476180037484, 0.11523719571414404, 0.15755462693050504, 0.2027967805042863, 0.11898067023139447, 0.11261546998866834, 0.234453683369793, 0.11401769865187816, 0.16992950899293646, 0.2899704856099561, 0.18085487274220213, 0.1386263730819337, 0.15348216576967388, 0.17560889798915014, 0.218009976670146, 0.15228613541694358, 0.16597721638390794, 0.18308257742319256, 0.14493093243800104, 0.1220524194650352, 0.2943285251967609, 0.11487148760352284, 0.1893646497046575, 0.10057074716314673, 0.18767139525152743, 0.09782608467503451, 0.20248776505468413, 0.1590111808036454, 0.19415454502450302, 0.16482684295624495, 0.1347197819268331, 0.11207364281290211, 0.15783518843818456, 0.10680072809918784, 0.08280880065285601, 0.20573475019773468, 0.16496042953804135, 0.15963789483066648, 0.12804544006939977, 0.0847960272221826, 0.1539722504094243, 0.15609762776875868, 0.20676562300650403, 0.1533282591844909, 0.3137153817806393, 0.12781823897967115, 0.16538799565751106, 0.1960084299207665, 0.11897373857209459, 0.07647923834156245, 0.149518221442122, 0.10710140180890448, 0.12529661413282156, 0.12337842956185341, 0.15500861511100084, 0.13074580376269296, 0.1559336725040339, 0.11126334371510893, 0.11773416641517542, 0.14601528440834954, 0.17767637298675254, 0.1146842363232281, 0.19371575763216242, 0.1183917983144056, 0.16901694936677814, 0.18146537826396525, 0.11850903538288549, 0.1172179655986838, 0.11329569286317565, 0.1591189851751551, 0.13782492780592293, 0.10515346453757957, 0.24108175974106416, 0.12459023797418922, 0.1399169975775294, 0.1664184231776744, 0.1390600693412125, 0.1686143342521973, 0.17260210152016953, 0.24771422962658107, 0.13214881910244003, 0.10253164975438267, 0.19023950822884217, 0.18685819435631856, 0.1494854927295819, 0.10160487057873979, 0.14422881620703265, 0.08621856846730225, 0.1366595778381452, 0.16355002240743488, 0.14831834676442668, 0.12086634131264873, 0.16635379695799202, 0.2123574385768734, 0.0943542510503903, 0.15686996601289138, 0.0975103082600981, 0.1870912584126927, 0.13949048530776054, 0.10377778991824016, 0.16303405165672302, 0.19952088128775358, 0.10001229587942362, 0.12353094833088107, 0.19751438114326447, 0.12312955033848993, 0.2077449462376535, 0.13851521420292556, 0.08297739434055984, 0.16478056262712926, 0.10781547403894365, 0.10139650519704446, 0.1028849788417574, 0.23178414849098772, 0.09888242799206637, 0.047395743677043356, 0.10651501608663239, 0.1692089726566337, 0.09887105828966014, 0.2095361048122868, 0.17676305636996403, 0.11921290308237076, 0.11300520884105936, 0.11918250471353531, 0.1955549480044283]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.013787069419777254, 0.06360204846714623, 0.06607607938349247, 0.036756882327608764, 0.008285207713925047, 0.004199627237539971, 0.03866061357257422, 0.023553410937893204, 0.04898433304333594, 0.035553753332351334, 0.02034601380728418, 0.008945870358729735, 0.01985732997127343, 0.04772946522280108, 0.01041657977111754, 0.037917805384495296, 0.02080095960991457, 0.029956735306768678, 0.03573639587557409, 0.05294127520755865, 0.032311224786099046, 0.01379346858811914, 0.02998924694111338, 0.03597973125579301, 0.06693396499031223, 0.10363572800997645, 0.03971088241087273, 0.0655742762319278, 0.017834357859101146, 0.03807120359851979, 0.04488109130761586, 0.023221374067361467, 0.09954487642971799, 0.03161458189424593, 0.047474051389144734, 0.04440906683157664, 0.01053132507877308, 0.045954504021210596, 0.0036914882321070763, 0.006821288488936261, 0.07964128468302079, 0.0222145858060685, 0.07544666601461358, 0.023021684392006136, 0.08653902041260153, 0.02552167934481986, 0.03181267595209647, 0.018308844410057645, 0.013650553210027283, 0.035269225045340136, 0.061489194849855267, 0.09901546538458206, 0.01749656006722944, 0.016118258245114703, 0.00633515439403709, 0.056196438818005845, 0.013760317779087927, 0.030637106610811315, 0.03382458264240995, 0.012029075569444103, 0.03575549504603259, 0.03649610647698864, 0.05490846750035416, 0.07735921026323922, 0.06726868101395667, 0.028263933563721366, 0.03198913640517276, 0.02804350086080376, 0.08245489269029349, 0.03971439276938327, 0.018418864092382137, 0.0629659165861085, 0.019805422307399567, 0.03254382128943689, 0.08637379607534967, 0.04948957976012025, 0.03451096163189504, 0.0629894649318885, 0.06301083136349916, 0.062371448875637725, 0.045497344763134606, 0.07436696731019765, 0.034739687835099176, 0.005330144504114287, 0.0182606066664448, 0.04219039037707262, 0.03573364250769373, 0.0671150119160302, 0.027776370370702352, 0.05121755559230223, 0.038410999623010866, 0.08825034616165794, 0.028582673003256787, 0.025669068018032704, 0.02066047105472535, 0.015816176310181618, 0.027876640087924898, 0.047499711145064794, 0.022871278888487723, 0.11072061854065396, 0.014607765078835655, 0.017780704292817973, 0.03289827101980336, 0.012339990917098476, 0.07532014467869885, 0.06257541332161054, 0.020739305691677146, 0.09054177906364202, 0.030182184927980416, 0.05423943621281069, 0.012328797474765452, 0.06252242397749797, 0.02792205210425891, 0.05543425686482806, 0.03242239479732234, 0.03190120303770527, 0.06510603299830109, 0.09337388139101677, 0.023263156981556676, 0.015089379958226345, 0.02582862234703498, 0.030342325553647242, 0.03182600121363066, 0.03698704829730559, 0.05971225582470652, 0.079472371871816, 0.03738076506124344, 0.01858848008851055, 0.027441222046036273, 0.05472046665090602, 0.07972821986186318, 0.016846819053171203, 0.004069603428433766, 0.060733836944564246, 0.049517540173837915, 0.017262425462831743, 0.09267736837500706, 0.04351872339611873, 0.03668247089080978, 0.0589313123782631, 0.017290131690970156, 0.0271117826923728, 0.046937504594097845, 0.10856968903681263, 0.11966114543611184, 0.05078421556390822, 0.033506512991152704, 0.021991858011460863, 0.01852559420512989, 0.1296861207811162, 0.0421066909621004, 0.028171276426292025, 0.05396637410740368, 0.04801182272785809, 0.07260460406541824, 0.035240730285295285, 0.016005405414034612, 0.020583029800036456, 0.023419098906742875, 0.04175668669631705, 0.05500582614331506, 0.03624311575549655, 0.07021082899882458, 0.0382373667525826, 0.02704511000047205, 0.04902866523480043, 0.045449617246049456, 0.02050466642685933, 0.0108937306322332, 0.039037550377543084, 0.01820856356061995, 0.04579248205118347, 0.028360676224110648, 0.04540386755252257, 0.022666299555567093, 0.07958890390000306, 0.03955378459068015, 0.02038370192167349, 0.030560784143744968, 0.03179928760800976, 0.031001464012661017, 0.026076920839841478, 0.017950743313122075, 0.025504424411337823, 0.012651798697334016, 0.04997402036678977, 0.06561685324413702, 0.04081471204699483, 0.03319800962344743, 0.07044340323773213, 0.013582725550804753, 0.09864473293418996, 0.03092199855018407, 0.01636478857108159, 0.04135912189667579, 0.043719199748011306, 0.014580108945665415, 0.021225616510491818, 0.030481721296382602, 0.06255424726987258, 0.07737693274975754, 0.03796074233832769, 0.039171300231828354, 0.05760380685387645, 0.05636745932861231, 0.030355871604115237, 0.03545809791830834, 0.05155514372745529, 0.06404412357369438, 0.029849652673874516, 0.03648045829322655, 0.03223357016395312, 0.05042893091740552, 0.05488463713845704, 0.03104969804553548, 0.029424474414554425, 0.019241447589593008, 0.02148726624000119, 0.060488553426694125, 0.030517583727487363, 0.07412847073283046, 0.05865288825589232, 0.06493031469290145, 0.09087246522540227, 0.01939070461958181, 0.028209420961502474, 0.06538348490721546, 0.011175869203725597, 0.016267261089524254, 0.04713998845545575, 0.020254056144040078, 0.03737567392818164, 0.09931203501764685, 0.019269443255325314, 0.028950182677363046, 0.01744683617289411, 0.06423015031032264, 0.06930985429789871, 0.052440507352002896, 0.018292993991053663, 0.08429602006799541, 0.026812133146449924, 0.009377959868288599, 0.05080308095784858, 0.01824801798647968, 0.03164391528116539, 0.044600756154977717, 0.01495834265369922, 0.06375477503752336, 0.06722097576130182, 0.05742164299590513, 0.0687203960842453, 0.02174114197259769, 0.021228505320323166, 0.01296151176575222, 0.05887692408578005, 0.04325121997680981, 0.06442468948080204, 0.04743163022794761, 0.0250825283001177, 0.031440225429832935, 0.040658089201315306, 0.08080802988843061, 0.05921314295846969, 0.06833680221461691, 0.08867857279255986, 0.066685078345472, 0.04249329424055759, 0.046858150453772396, 0.015359953085862799, 0.015931079324218445, 0.04190854124317411, 0.012629995326278731, 0.05936030713201035, 0.014774988576391479, 0.09109585167607293, 0.03907043123035692, 0.04012135315861087, 0.027920660577365197, 0.050058933193213306, 0.03823462080617901, 0.026785668160300702, 0.027352194010745734, 0.017852236196631566, 0.05291875102557242, 0.03020209860551404, 0.03746072776266374, 0.04433533445990179, 0.023475444613723084, 0.028597293312486727, 0.022331713407766074, 0.039069555496098474, 0.031188503780867904, 0.021616822959913407, 0.025510543418931775, 0.02273235069878865, 0.008064929934334941, 0.021275865474308375, 0.0148552564860438, 0.015792533340572845, 0.04547785967588425, 0.06667200170340948, 0.024631135529489256, 0.06056790014554281, 0.04979557095794007, 0.013072121455479646, 0.0312711901642615, 0.06382815859979019, 0.026926755999738816, 0.1502969569992274, 0.04371748538687825, 0.022606821985391434, 0.05435265826235991, 0.023632629636267666, 0.06583657348528504, 0.016170444214367308, 0.010740772140707122, 0.022350968429236673, 0.07321108714677393, 0.048274487344315276, 0.008434169740212383, 0.031052863305376377, 0.02636152148625115, 0.010541529609326972, 0.056685707095311955, 0.07459117754478939, 0.03507065230223816, 0.03666816228360403, 0.04409963577927556, 0.08173270878614858, 0.011880676647706423, 0.06881800334667787, 0.029543470373027958, 0.029425027314573526, 0.017556985731062014, 0.02155312442482682, 0.038263030219241045, 0.017345807609672192, 0.03016754792042775, 0.05168526819034014, 0.01424360527380486, 0.013605717285827268, 0.022797034434915986, 0.06599286978598684, 0.057507361052557826, 0.031036356085678563, 0.05824017251143232, 0.03624716046033427, 0.08403099913266487, 0.03850845474516973, 0.023741328295727726, 0.06175829759740736, 0.11071763510699384, 0.11098845963715576, 0.16288470185827464, 0.146102917206008, 0.09834411859628744, 0.10170840017963201, 0.10502738106879406, 0.08292899889056571, 0.11027496628230438, 0.11890998808667064, 0.11942455617827363, 0.15639543678844348, 0.17147486825706437, 0.2141270600259304, 0.09624332858948037, 0.20000459830043837, 0.0893242858001031, 0.1247496364521794, 0.201024561538361, 0.18799059296725318, 0.19166511454386637, 0.1729283347958699, 0.21737220464274287, 0.15664770762668923, 0.2204394861473702, 0.19026569119887426, 0.15632568974979222, 0.19271785102318972, 0.14234684844268486, 0.11971524800173938, 0.18607632693601772, 0.10803819255670533, 0.18433177523547783, 0.18934790685307235, 0.13158285728422925, 0.17038889840478078, 0.15830962860491127, 0.2136628466541879, 0.09350922686280683, 0.07499837171053514, 0.15131632651900873, 0.09723450391902588, 0.19429868494626135, 0.14188290224410594, 0.1685136099695228, 0.096407320961589, 0.08920820648199879, 0.16710631985915825, 0.16207504842896014, 0.17213370243553072, 0.2903151389909908, 0.23848608339903876, 0.07031038810964674, 0.09819380400585942, 0.09136808628682047, 0.1458063253085129, 0.15904667030554265, 0.21463789511471987, 0.14222676894860342, 0.1613203139277175, 0.16431373689556494, 0.1783952914411202, 0.1823531650006771, 0.13324341271072626, 0.20909228565869853, 0.10293332234141417, 0.05985868898278568, 0.1878700384986587, 0.11889964996953495, 0.07420004345476627, 0.11947638035053387, 0.13304574909852818, 0.1875244648545049, 0.16153439384652302, 0.2018620158196427, 0.14364928792929277, 0.09549755923217162, 0.14454964664764702, 0.14911329082679003, 0.10324116519768722, 0.1158733424381353, 0.16937603009864688, 0.2741264342330396, 0.13783375936327502, 0.14677246799692512, 0.16694683232344687, 0.15226850198814645, 0.14430975483264774, 0.15675577917136252, 0.23755044298013672, 0.17119546449976042, 0.14267026155721396, 0.12040196466841735, 0.08872441525454633, 0.11307624721666798, 0.10798744449857622, 0.10304577997885644, 0.17791286576539278, 0.12520961958216503, 0.18274482601555064, 0.15406028396682814, 0.11324790597427636, 0.1944687555078417, 0.1294089137809351, 0.14852050779154524, 0.13805437018163502, 0.09915753471432254, 0.28481727931648493, 0.13486010720953345, 0.08313215439557098, 0.12815281399525702, 0.15402197430375963, 0.10116321107489057, 0.09464200396905653, 0.14161656028591096, 0.2048666897462681, 0.13864201755495742, 0.12825426558265463, 0.1442739981575869, 0.09667224541772157, 0.08877356027369387, 0.14292983512859792, 0.12806362268747762, 0.18116534280125052, 0.29339080676436424, 0.2029448834946379, 0.1661748651531525, 0.11136209388496354, 0.09010121793835424, 0.08592251091613434, 0.15968656487530097, 0.1543741679051891, 0.09003521132399328, 0.277177284588106, 0.14336256659589708, 0.09638099698349833, 0.24211846583057195, 0.11489174823509529, 0.234461119689513, 0.09249180176993832, 0.10523838107474148, 0.11812284399638884, 0.19353681098436937, 0.17451550666010007, 0.18440343701513484, 0.1620345123228617, 0.15011090057669207, 0.11776552957599051, 0.09380745148519054, 0.16996582970023155, 0.14547375409165397, 0.10865024174563587, 0.13682252378202975, 0.13098502764478326, 0.2275824942626059, 0.10934475838439539, 0.18587832193588838, 0.1520389853976667, 0.14031659957254305, 0.08645971451187506, 0.15611871960572898, 0.15752192790387198, 0.0900285245734267, 0.13406243204372004, 0.06880787303089164, 0.07852580703911372, 0.18314047978492454, 0.10930822245427407, 0.14668271265691146, 0.08617360173957422, 0.06874638609588146, 0.1198856822156813, 0.1551657129311934, 0.1576865214155987, 0.13341728306841105, 0.13908841938246042], [0.01610764182260027, 0.027679919003276154, 0.019001648543053307, 0.05126837044372223, 0.004371936765892315, 0.01630430168006569, 0.05746204922616016, 0.0352159388421569, 0.04861676956352312, 0.04641327745048329, 0.04401404017698951, 0.02246730749902781, 0.028821644555137027, 0.03101949634583434, 0.019008726776519325, 0.04072309020557441, 0.03932927378627937, 0.049196861873497255, 0.03499502745398786, 0.04233703875797801, 0.006555381150974426, 0.01536152180051431, 0.050536531198304147, 0.019715737471415196, 0.02750556439423235, 0.0494913609145442, 0.05880803051695693, 0.021717255949624814, 0.005159255260878126, 0.02603663335321471, 0.07324452832108364, 0.041451934885117225, 0.042427016742294654, 0.033196154254255816, 0.043111673949169926, 0.01630100654438138, 0.0631222128868103, 0.026088075319421478, 0.09927726539899595, 0.020147741633991245, 0.028902182421006728, 0.043375373861636035, 0.021640280392603017, 0.0503745352034457, 0.08660455205244943, 0.02332232841581572, 0.03207095076504629, 0.043810064598801546, 0.03211477829609066, 0.1002621473162435, 0.03330313484184444, 0.037822339218109846, 0.03277563853771426, 0.03252171642088797, 0.026694695698097348, 0.06755576599971391, 0.01746222460496938, 0.059807354627992027, 0.03884719320922159, 0.031706623049103655, 0.03653448664408643, 0.07564657833427191, 0.07969903119374067, 0.0547013266623253, 0.04918839025776833, 0.054053698913776316, 0.03506083368847612, 0.026303633967472706, 0.015155274322751211, 0.04582512912747916, 0.02125914117641514, 0.03659824455098715, 0.04081293831404764, 0.007624120653417776, 0.07815207631210797, 0.042957002951879986, 0.05934323402470909, 0.048153450479730964, 0.00773088648202247, 0.033827673687483184, 0.05707425851142034, 0.025219610397471115, 0.029350465592870023, 0.026808678449015133, 0.06097053752455395, 0.026196989201707765, 0.11658152943709865, 0.014729307531524682, 0.07369531624135561, 0.030640203221992124, 0.01757060414092848, 0.03370340105902869, 0.041754126286832616, 0.03530940863129217, 0.04485671917791478, 0.016551024964428507, 0.03852921261568554, 0.055658099736319855, 0.04372358955151867, 0.0937038402480539, 0.050970197771675885, 0.05580978358921129, 0.035289077495690435, 0.02754127654043259, 0.05853747687069699, 0.040636971389176324, 0.02003487024921924, 0.04835209372686222, 0.07416121428832412, 0.03901070318534039, 0.008183471327356528, 0.03898522896633949, 0.01947085100255208, 0.05607989936834201, 0.016079061715572607, 0.043866445557796396, 0.012104164215998026, 0.0664677181339357, 0.031714196666143835, 0.059867750605917536, 0.036715066016768105, 0.057976776879513636, 0.04403212631586939, 0.026475411468709353, 0.03507208835799247, 0.04348230249888729, 0.044425360683817416, 0.04870356002356857, 0.02572707428043941, 0.034836552949855104, 0.0765490744379349, 0.08160816156305373, 0.02493087413313333, 0.0354049230372766, 0.04117702483199537, 0.07851503847632557, 0.04065135792188812, 0.052699145817314275, 0.061262628296390176, 0.010221431111858692, 0.07058395858621225, 0.0681017417809926, 0.02613061893498525, 0.050296398185309954, 0.05944175412878394, 0.057513005085638724, 0.03786629662499763, 0.01521843480077223, 0.0318492304359097, 0.027557069442991633, 0.00897905827514478, 0.006446877305279486, 0.054088468532427214, 0.0526776717742905, 0.06316133149084635, 0.01592549651832087, 0.044702738377964124, 0.032877609628485516, 0.03012344579474302, 0.047245043169823475, 0.025539908347127493, 0.08564773816033266, 0.03510736263706349, 0.030563088512280956, 0.029470470872183796, 0.020177175210847054, 0.019404018748900853, 0.07358357106568292, 0.04245465803251136, 0.033137695281766355, 0.02484371445461875, 0.02746759982983349, 0.09868506123893894, 0.09239729668479413, 0.04033347009681165, 0.04735295144200791, 0.07295840812730603, 0.030889414556440897, 0.06418501288862899, 0.03580299991881475, 0.02036026675341418, 0.03053318552701967, 0.03548154607415199, 0.05689429883204866, 0.07217008402221836, 0.05376800545491278, 0.01072981061952305, 0.03757898528419901, 0.10121261584572494, 0.06052996155631263, 0.035637916589621454, 0.03029824569239281, 0.08067433940595947, 0.12259722265298478, 0.02088336768792942, 0.034631883463589475, 0.01610361196071608, 0.02621221250592498, 0.01127421397541184, 0.05284611332172062, 0.029961757791170385, 0.04461559539777227, 0.05167779476323631, 0.03255996300140396, 0.04045529734867159, 0.0434740238415543, 0.00963067970587872, 0.027981292187178042, 0.02906638073909562, 0.03483963286271319, 0.061103816115064546, 0.02074255815387005, 0.04838036955334246, 0.09137423869105987, 0.07014863702352159, 0.03647367877420038, 0.04922698935843073, 0.0631408036861103, 0.01910519669763744, 0.08169773136614822, 0.020926718389091548, 0.012283051491976948, 0.02155291847884655, 0.028447565018723253, 0.057234580963267945, 0.04260441230144352, 0.06920385334524326, 0.06765737343812361, 0.023323944442381617, 0.0163005371359759, 0.012830554242100334, 0.0030055262368477997, 0.020145993876212742, 0.029119589016772807, 0.058982194022974, 0.007345816202359856, 0.041624231889727525, 0.02215276675997302, 0.049206732437596656, 0.009605446684872732, 0.020984253387723584, 0.0281885666117887, 0.022918768918316346, 0.07801632265909575, 0.0360990908666281, 0.09744253533426672, 0.033924472008948214, 0.020518683741101995, 0.054768902919022366, 0.018009959276241716, 0.05446547955216374, 0.06236382701899856, 0.02146469381841598, 0.09487768780672923, 0.03253204340580851, 0.0882818280661013, 0.027257861474936362, 0.048420319362776354, 0.010983048105117632, 0.013069408905721502, 0.026030406734207645, 0.01630743168789195, 0.04829918972973246, 0.03933905900339596, 0.037861962482566014, 0.04878377134446055, 0.011286387052678037, 0.0317273512337124, 0.09674807806732133, 0.060099296970292926, 0.030339574041136075, 0.046557012901757844, 0.012735960099234944, 0.051763286464847624, 0.05953841515292879, 0.019876074766216334, 0.03135356855636928, 0.00708747830685752, 0.013853993514203466, 0.05213930671743583, 0.018092766258632764, 0.027336517996445764, 0.05748826188209932, 0.04403281651320867, 0.0272964290343225, 0.028110466701036785, 0.05269931280054152, 0.00852940862387186, 0.04808936602785252, 0.022992215563135687, 0.025880821303871926, 0.017713782981445547, 0.025125598840531893, 0.02797317680233391, 0.055717957657179795, 0.02194242726545781, 0.04298849598853849, 0.03289370681159198, 0.015921418416837696, 0.041893683446687646, 0.002306879546267737, 0.03728013354702853, 0.04681886115577072, 0.05313650086463895, 0.09407230914803222, 0.027045160095440224, 0.0863886835577432, 0.09958142720279284, 0.018963181173603516, 0.06480485462816432, 0.11257748687057756, 0.053979576914571226, 0.026905235572485253, 0.016480571030115243, 0.02458234488585731, 0.07012235757429153, 0.04582125511660706, 0.03195617762685288, 0.017507901939097792, 0.11318539487547241, 0.06315421429462731, 0.03097936285485048, 0.010609715354803484, 0.01931947328557726, 0.022142586349218618, 0.03791255468968302, 0.045425653297570534, 0.029923140136816073, 0.058834302544710226, 0.011018697168765357, 0.07078017501044087, 0.019812901300610974, 0.034376569819869474, 0.06680139515083283, 0.020947418743162416, 0.019791750091826543, 0.042500704585108906, 0.03300294352811761, 0.034713694112724625, 0.018425068446958903, 0.05184597284824122, 0.020455222693271935, 0.047044021339388564, 0.012175682204542682, 0.027695342687366065, 0.025051419324881863, 0.028964799275854602, 0.03990192977653351, 0.0304851518740179, 0.14443833933910355, 0.04879958651144989, 0.034336683092988096, 0.17176466208184138, 0.12456176918931305, 0.16586516692768782, 0.18808440043358132, 0.17832229379564524, 0.08797801507171243, 0.14068982563912868, 0.18419415137032047, 0.16592283180216327, 0.11529673080076464, 0.08772014843998477, 0.07541806364315562, 0.23150608059950173, 0.1015639262914192, 0.1673019796726294, 0.11653751265839674, 0.1815907418495044, 0.2055993230897002, 0.13840835978044197, 0.17790298035833985, 0.08387718160520308, 0.16345404786989093, 0.09583194128936157, 0.11149110141559504, 0.10200420540058985, 0.13296185672516003, 0.20327880542026833, 0.1097856460546609, 0.13730037782806903, 0.24072486092336476, 0.15265490859746933, 0.13615969684906304, 0.09638279298087582, 0.0971272487367969, 0.1006239814159926, 0.1685308723244816, 0.14417481754207984, 0.2030071645276621, 0.17052388022420928, 0.1359817892080173, 0.11264641012530774, 0.12926876661367714, 0.09106275188969448, 0.15662707592127845, 0.20465589012019336, 0.11115398083347827, 0.12585659424075857, 0.11700658709742129, 0.1593810968915932, 0.16587120800977573, 0.1249601985909976, 0.08507434002240188, 0.09647965809563175, 0.18560227268608287, 0.11330598645145074, 0.15120582072995603, 0.14507363259326667, 0.15759780508233234, 0.14487004664260894, 0.09418661473318934, 0.15011787676485255, 0.1394170572166331, 0.2284755650907755, 0.10652615572325885, 0.16037564899306744, 0.16320951021043584, 0.17018172045936808, 0.19353433221112937, 0.12070168842910789, 0.11737859604181722, 0.09391343017341569, 0.173016041808296, 0.10927051393082365, 0.1107589653111063, 0.183453235658817, 0.09992172417696565, 0.1718033428187482, 0.16906751930946484, 0.09193891659379005, 0.18239186058053747, 0.19151468120981008, 0.09023860431625508, 0.11182947622728534, 0.039721034991089255, 0.12904622621135786, 0.14633978105848655, 0.20550492190523073, 0.1659840886713937, 0.1918290846515447, 0.19589198695030063, 0.19395924144191667, 0.12622809852473438, 0.17244724498596042, 0.1320930986548774, 0.09708282377687283, 0.09612534195184708, 0.1296668843133375, 0.15051094786031172, 0.21640610648319125, 0.19188832287909463, 0.11055266309995204, 0.09722426970256492, 0.13930539367720485, 0.17091640213038772, 0.13017384539125487, 0.1184825184463989, 0.19830681674648076, 0.16032135346904397, 0.11928671709029004, 0.14614909363444895, 0.10285530777764507, 0.15115302434423938, 0.09555960277793929, 0.08531967177987099, 0.07261261926032603, 0.10211663335212506, 0.10199852054938674, 0.17546052782563493, 0.1312504493398592, 0.10134873315109871, 0.12454251787858084, 0.20229997200658545, 0.09426295204320922, 0.21892367920372635, 0.09355713991681114, 0.16273112181806937, 0.08967470566858537, 0.17044246662408113, 0.14958130399463698, 0.08449422544799745, 0.17405675549525768, 0.2567475027171895, 0.1309496717294678, 0.13753078499576077, 0.2431829134002328, 0.13588856061687693, 0.17914006632054225, 0.13975725771160796, 0.08807904363493435, 0.13504751434084028, 0.12009975471301004, 0.17633731593377888, 0.17107486550230533, 0.1522929483326152, 0.2453006911673583, 0.13359734293771908, 0.13188126002205536, 0.1366927963681519, 0.10477981544681825, 0.11670909720123746, 0.13960934767965227, 0.07554644776973873, 0.18365551542956382, 0.11281739352853037, 0.14342704438604414, 0.15961533354129642, 0.12185541636426933, 0.14575753652025014, 0.22844351915409788, 0.1429672393715009, 0.22880887845531106, 0.2550882089417428, 0.1199538484797813, 0.16649441909976304, 0.11538515027496032, 0.0951784654171206, 0.19412754569202662, 0.1506983846775256, 0.11834310600534081, 0.14798834337852895, 0.10500850825337693, 0.20345267577795312, 0.2386975212721154, 0.19916350749554113, 0.10284830190357752, 0.13869214220903814], [0.006535420161526417, 0.017716903712425847, 0.01856006510934094, 0.00822025866000331, 0.03447437375143636, 0.04075827913766261, 0.02275985840242356, 0.034876673453254625, 0.012279427028261125, 0.05474547702760901, 0.0039930031198309734, 0.06679594778688625, 0.05730898497859016, 0.016797438402136322, 0.056323075186810456, 0.038469959545182064, 0.019174080989614595, 0.06527464152895845, 0.04134985989367124, 0.024686781762284227, 0.0010451445405124105, 0.015898740239208564, 0.008424191564699868, 0.05911670457862783, 0.0360786855162587, 0.02512058006686857, 0.014887323759467108, 0.05181547057873104, 0.06968431975110434, 0.012574329612107249, 0.017699112577247433, 0.020706886825792026, 0.02885525085730478, 0.026825321110663936, 0.10956776633975096, 0.01329958600763348, 0.04665096137614455, 0.07831676630303264, 0.062117938650771976, 0.02646491750056157, 0.025693583011161536, 0.019676526098919567, 0.03184839180903509, 0.031769453271408565, 0.033620722097111866, 0.03490484908979852, 0.0609593273838982, 0.016745786779210903, 0.023420534962497186, 0.0076327425540512195, 0.06544536518049426, 0.027184973296243697, 0.0461308939702576, 0.03912608117389027, 0.039366585260722786, 0.017722250886436086, 0.01486414463215624, 0.01697745559795294, 0.06623104723985307, 0.027967143141722772, 0.03127841126115527, 0.019294876656203996, 0.06230520477402024, 0.03488985028525349, 0.02623261600092519, 0.04281280365830753, 0.016891563136596233, 0.05533941039175261, 0.04835058716707863, 0.02494353146175854, 0.062023607970331796, 0.056639953691046685, 0.05595230191829614, 0.021036433790868614, 0.04903463210212067, 0.03477406040474307, 0.11807401810074225, 0.042263235882273875, 0.022506650602736045, 0.07216920086648315, 0.007019914110060199, 0.042522301082499325, 0.054479309474118054, 0.03789443144341931, 0.01745371031574905, 0.02431473199976608, 0.012500569409894524, 0.03168339011608623, 0.04106457832676824, 0.09081970594706945, 0.060074197535868734, 0.014509151278616628, 0.06841070528025739, 0.015034872922115028, 0.0718961944221519, 0.038140753968036734, 0.03200248393113725, 0.03128852302324958, 0.09036736693815328, 0.040129984336090274, 0.011760162069549551, 0.012983405122213298, 0.04481493255298119, 0.01857119546912145, 0.016166724199138116, 0.06323090041405521, 0.04157662311627064, 0.08793287022854201, 0.045131243314244784, 0.03153645229758695, 0.01956296451680828, 0.09335880837170407, 0.022549858440470416, 0.03383137700438965, 0.07454982507624663, 0.029725118438364007, 0.020163243243587203, 0.05438420696009416, 0.04683654653490521, 0.019760208815569058, 0.02964701852761209, 0.021437121176859364, 0.049948145388043486, 0.08111655552056618, 0.02923426938650664, 0.02034220473433379, 0.021305080117599573, 0.0293937606329564, 0.017820960238168482, 0.05576261639362201, 0.005759149926234386, 0.03197001868102234, 0.06623521068831906, 0.047762635513208807, 0.014533967769239098, 0.05132431353558786, 0.061023426678730175, 0.029050723278487567, 0.02184060460422188, 0.02853321813745424, 0.02778241701889783, 0.028124409800511785, 0.026194588353973813, 0.021055430916021578, 0.016972845005511772, 0.028373125751386397, 0.032113987908815034, 0.10149242036277428, 0.04397912212880328, 0.0537021584023023, 0.04948585788952187, 0.0054201489274419146, 0.051273914286866784, 0.018347024197282735, 0.028164483919681516, 0.03538068078341894, 0.0863443996058777, 0.0330032774945721, 0.013223564110376174, 0.03656022061477415, 0.058134097344009206, 0.050124516783398576, 0.07704977178946137, 0.03255345807701815, 0.048572281521046534, 0.06759652475011535, 0.022278699943854008, 0.037423531321110204, 0.071752136136638, 0.01453728053093073, 0.046772599380346946, 0.008429342997260392, 0.0382008939050138, 0.02308140687091509, 0.053230289777275175, 0.045126326585887, 0.06374773947754875, 0.03625451885454822, 0.02969269215100212, 0.03731378623342607, 0.04694367184129078, 0.020894490626233164, 0.03559811149898451, 0.033760713413357735, 0.07389975566184148, 0.016005088145902846, 0.04934699092700612, 0.01952970887941774, 0.04024560723337345, 0.056091551086865366, 0.06628391041886061, 0.0354502942354884, 0.045159589644754305, 0.028503020148491487, 0.01145507814726443, 0.03218278870917857, 0.02062164930975996, 0.060632756431004964, 0.048929684999166057, 0.04943598927638959, 0.08450719818938524, 0.011226810220250627, 0.061279590081539936, 0.024544799634895753, 0.048697574602556415, 0.06408734625438228, 0.09135924730799161, 0.01702512559859315, 0.028098705515731126, 0.026173143996857107, 0.022614384470216464, 0.04239981702994555, 0.13009878457523882, 0.05550886497076135, 0.04361383704235777, 0.044047473929822445, 0.05464114590722602, 0.03357694651640486, 0.05264375933620613, 0.07706564632826485, 0.019637324003269896, 0.03989640077634249, 0.06572358150151558, 0.03288037783931941, 0.03644284253823571, 0.06983875326113775, 0.0807563318812754, 0.0236883946126909, 0.040680832316866145, 0.016706471506040543, 0.06527089368319139, 0.043915928254136816, 0.04016863167635165, 0.033085778341046534, 0.05237908349954523, 0.08037528357817791, 0.0766831508371979, 0.012434702875907533, 0.018118715452146716, 0.022704438524669968, 0.05606881910352968, 0.052993396238889545, 0.036348174180602655, 0.03864355901896488, 0.06288036922342144, 0.07057036986225285, 0.0181180326762842, 0.03686035626742523, 0.03857327021250967, 0.055985665167099796, 0.06196658876433503, 0.04803626907232683, 0.014739625239599263, 0.029966533511469606, 0.06340582462144084, 0.046875590924173594, 0.027943988134211395, 0.04216373614326585, 0.03361914132256061, 0.005939400434726849, 0.015906913140497636, 0.012185184477857547, 0.024717235792195424, 0.03575282702513505, 0.07129938152502291, 0.05118024411785882, 0.02057700912700966, 0.003659777421489707, 0.030440448608715087, 0.11450338977738284, 0.08743232872802764, 0.0664331043662969, 0.01394994114889414, 0.035617867470136844, 0.01547634688904509, 0.12290484286495484, 0.09325798018835485, 0.10704242333304137, 0.0627888846793212, 0.038299696025205776, 0.06792218657210469, 0.01646990822337102, 0.07893119036452845, 0.027444366896816064, 0.03376018277776893, 0.03501527324260678, 0.11103073236881755, 0.05926526398980059, 0.02114838862325996, 0.04478095332160592, 0.018400421722617466, 0.010959549854305806, 0.04271857687854208, 0.033411666518077254, 0.10188546177232638, 0.061336119470070116, 0.08211846972699277, 0.004052895828863257, 0.04695541261753533, 0.040283712805830874, 0.025056875965674408, 0.01514384339316166, 0.06134699193353299, 0.013879698726668721, 0.06366831483319402, 0.07293065180419944, 0.007140366069506854, 0.02665797423105687, 0.018827985986717977, 0.05367632053093985, 0.027352249671821482, 0.06426226304029115, 0.007920094249129761, 0.050065542018273845, 0.0121305290122109, 0.025177161405736115, 0.034523990034358576, 0.06476268579717726, 0.05513324176718015, 0.05607996616163291, 0.06240882343263365, 0.02956845662993146, 0.01288156019654707, 0.04761312986374833, 0.05103638621221762, 0.011910870925930794, 0.023889893273008056, 0.03866357474180404, 0.09540603015921079, 0.020519626268651336, 0.05194949502765667, 0.012611038091563387, 0.05652834952343255, 0.022566668085346464, 0.04265310832124669, 0.029969606002850924, 0.046403789092437364, 0.05988825985696167, 0.049095428839791566, 0.05289718792482745, 0.019725409511011094, 0.06691722956020385, 0.03768663009395823, 0.03641823663201649, 0.05914099507208448, 0.04680234094848856, 0.03047402893571416, 0.041862914004013874, 0.006585298051504651, 0.020793001931451727, 0.06864424431114458, 0.011418827943998622, 0.09540222294162959, 0.10238690869300626, 0.16183181694941595, 0.17910059890709817, 0.18265550112118945, 0.1388336400850676, 0.09812516276724637, 0.09227050075423904, 0.1854834845289588, 0.13743969378992915, 0.14490751025732607, 0.1847854649531655, 0.14398935483768582, 0.10718459656345658, 0.17055090924259275, 0.17708977946313098, 0.11427831123000942, 0.08814337299554609, 0.106509435136104, 0.1518891309387982, 0.14213236776413396, 0.14983876986661926, 0.07596103372634389, 0.14870081999106333, 0.14240844669984654, 0.16460238781291991, 0.1181988324970007, 0.11019397570635192, 0.26191748154815286, 0.147629173588939, 0.10767593543278053, 0.09563625178998336, 0.12171340640634298, 0.1390746154356748, 0.177319414797239, 0.2260705761727877, 0.22519041871419176, 0.1745148832560517, 0.10196961389738135, 0.10598953842418268, 0.1531080639688298, 0.11805126385297626, 0.11778518906794488, 0.17492241138825193, 0.1445012289332226, 0.09437601824174635, 0.16399934829678386, 0.0862946460256353, 0.09040270058903843, 0.21683629980543628, 0.19194019900169224, 0.061434431772795506, 0.18396659404970706, 0.06846851858426817, 0.13517639570636675, 0.12216933741001412, 0.08382730928133242, 0.0722680104081519, 0.23519655835116282, 0.11579134996281937, 0.24078092275885865, 0.1118708509602584, 0.15536282735411078, 0.08067054703133181, 0.11179805369465612, 0.12873428669990972, 0.12941099179442972, 0.1580565414042212, 0.13402330601820722, 0.16755126707721502, 0.1947529980679974, 0.14502879203064367, 0.22137843654491007, 0.1292632005061023, 0.16628164536086842, 0.10962019907310605, 0.1410602463874966, 0.11993096806691028, 0.16613423998933285, 0.09671462947153486, 0.0866131015936844, 0.13975658977869898, 0.13113556487951428, 0.0928877895057667, 0.11426990269683301, 0.12735096795950085, 0.16790441062767059, 0.13475644402205944, 0.16632004408165812, 0.13157513894839212, 0.16037199762649834, 0.09627722247387283, 0.13815047830576077, 0.210383489029482, 0.1500062132254243, 0.18846510734874755, 0.07149096694774926, 0.12966087291715667, 0.22293014859315008, 0.19259100314229727, 0.21634302393067628, 0.16202131693717092, 0.17953033209778368, 0.09646105245337822, 0.11447368902736343, 0.1670081782503985, 0.13883122068364173, 0.15540698514087126, 0.10368242394179106, 0.22205870394827798, 0.2158033341402188, 0.1696347279357724, 0.07893535381299444, 0.14759138342924416, 0.11334128299495205, 0.06521806019009091, 0.14853560307528824, 0.13143497693818063, 0.15531004581134766, 0.1401886681560427, 0.12500802258728072, 0.09089619168662466, 0.15740781527711079, 0.12564362754346803, 0.15426438942085952, 0.1103867485653609, 0.13622481288621202, 0.14086734736338258, 0.22638490539975464, 0.15358756558271125, 0.11339469536324032, 0.08396381992497481, 0.17015206423820928, 0.12921171030029655, 0.09505187728791498, 0.12218861098517664, 0.1577745846589096, 0.13680815580300987, 0.14602852432290092, 0.12677624879870564, 0.11572444534976967, 0.14846309524727985, 0.12405795481754467, 0.20184315042570233, 0.11463176648248918, 0.1123404226382263, 0.11305330001050606, 0.13460238900734112, 0.14303890115115792, 0.13984943245304748, 0.096018947660923, 0.10422988401842304, 0.18810797104379162, 0.14058681554161012, 0.1552852729219012, 0.09095772315049544, 0.15048210800159723, 0.12624561320990324, 0.10499456329853274, 0.12157866949564777, 0.28609674191102386, 0.15344158513471484, 0.21903354674577713, 0.15982788463588804, 0.1359949103789404, 0.1993863595998846, 0.0991650007199496, 0.09478396197664551, 0.16513983631739393, 0.12921775138238445, 0.09962526586605236, 0.12565477460157126, 0.12556890811538324, 0.11406901816371828, 0.22366736840922385, 0.10083148590638302], [0.07364793753367849, 0.03594252739276271, 0.03372113096702378, 0.030624100472778082, 0.05969094876490999, 0.02206700788519811, 0.007716386307947687, 0.009215227291861083, 0.04166897968389094, 0.06278719258261845, 0.019312354233989026, 0.04122465215914417, 0.0486777703918051, 0.09284884159569629, 0.035105614879284985, 0.06701885926304385, 0.0054990021180856274, 0.1138738778536208, 0.013046934818703448, 0.05945096418145113, 0.04715623035735916, 0.10686683861422352, 0.048013793129939586, 0.0467364233918488, 0.018015319437836297, 0.02914467731898185, 0.028263790700293612, 0.011481165565783158, 0.029518610281229485, 0.06274092709645629, 0.08499674848280847, 0.04257927575963549, 0.0825573164911475, 0.09446814845432527, 0.014172100272844546, 0.01374888592181378, 0.029262274329084903, 0.03193576856574509, 0.04881182452663779, 0.08104002525215037, 0.03507670451654121, 0.03629361519415397, 0.09848895613686182, 0.029327987795113586, 0.035841038697981276, 0.06817246845457703, 0.020787827306776308, 0.04555617480946239, 0.050313578904024325, 0.033830085667432286, 0.03924769320292398, 0.04225700926326681, 0.023369592090602964, 0.02208291582064703, 0.07897355215391144, 0.04239604691974819, 0.05378003937948961, 0.040707056105020456, 0.02150545442418661, 0.0016807766314741457, 0.019524818126228638, 0.03522650702507235, 0.006834109090050333, 0.023330223011726048, 0.06772942855604924, 0.06784551529563032, 0.06956101933610626, 0.06187650687934365, 0.04038657818455249, 0.05622910444799345, 0.06845069961855188, 0.024924113167799078, 0.098490729869809, 0.009653728029661579, 0.02725811194977723, 0.06126980486442335, 0.06181439654028509, 0.05125521587615367, 0.011878379700647201, 0.017644917243160307, 0.0369203403533902, 0.041942639218177646, 0.06020205844833981, 0.050336140193394385, 0.01918465659400681, 0.014624418872699607, 0.032344101928174496, 0.03593209279642906, 0.013890831869503018, 0.05307339604769368, 0.05887860505026765, 0.06392318318830803, 0.009783178993529873, 0.02146877748600673, 0.012836793848691741, 0.01123766320233699, 0.047051056899363175, 0.06110966423875652, 0.013495447128661908, 0.026957145091728307, 0.05245517590083182, 0.04284434122382663, 0.03939046015148051, 0.06900241220137104, 0.016528025807929225, 0.033322523449896835, 0.0950053743144963, 0.07453654063283466, 0.044957729187444784, 0.02266391911689425, 0.04816490923985839, 0.03382166600204073, 0.026075837304233573, 0.03090781425271416, 0.0835848347924184, 0.058647867626859806, 0.04963053957908414, 0.031229095548042096, 0.06050661359040532, 0.04133425623876974, 0.013753238617937313, 0.0641338863351848, 0.06777013535611331, 0.03859239906887524, 0.03366430843016133, 0.041870123968692496, 0.029061473287583794, 0.03695123967190739, 0.061550473983515985, 0.037351487335399725, 0.0010341168058403127, 0.03367819401319139, 0.014446773766394472, 0.04524412397586275, 0.05611646127363201, 0.03182077649398707, 0.006346589498207322, 0.11089616615208797, 0.01429694992111763, 0.0511773052130593, 0.02228363893664209, 0.03908668797521386, 0.018383513743174262, 0.051331694194232114, 0.03576725066523068, 0.05259170509816613, 0.049077409494202584, 0.02475984991178848, 0.036576918937498704, 0.011569260350370314, 0.010250103059661342, 0.09993074127123691, 0.022408271506719757, 0.01516518756034202, 0.020156821810815018, 0.03138419328024611, 0.0478875500994036, 0.04452586974366568, 0.053553354082396254, 0.03803817060543224, 0.022185846137290355, 0.014145436762191821, 0.043449792719911784, 0.10097868347656913, 0.03253849266911857, 0.08845123069477268, 0.01910048220452154, 0.0058497694044490345, 0.03152997334836982, 0.05235651107796002, 0.08064531401032582, 0.02424424652417656, 0.01682140791672282, 0.03569791922927834, 0.0639765955565963, 0.04995251292712055, 0.03055472821870353, 0.05342631695384625, 0.014957730381865986, 0.04862415022216737, 0.014164470994728617, 0.026946712350763846, 0.01261449649973656, 0.02937185428891098, 0.028771987454092596, 0.031054275241331197, 0.0127442471057293, 0.009096761968976352, 0.01925695476529654, 0.03773133335926104, 0.030339264194481075, 0.09132919032708742, 0.006155035616757232, 0.03626268618972972, 0.03438400242885109, 0.04005694587249309, 0.017673556722002104, 0.09623093472328037, 0.01758465114107821, 0.11310513160424307, 0.027747198400902562, 0.059509660641197115, 0.03749419120140374, 0.016512396177859046, 0.015613829746143892, 0.07717940272414126, 0.01399645803758176, 0.018341112991038244, 0.042667491143220104, 0.01615428765944671, 0.05318171621183865, 0.013215361523180036, 0.04161576769547537, 0.011671245356410509, 0.09547685331199318, 0.05459021973365452, 0.03953043291403446, 0.04997717078367714, 0.04001101806352381, 0.03142918227240443, 0.02235323754575802, 0.00673448736051796, 0.0399170027958462, 0.05601969634881243, 0.10239825613098219, 0.09509501833235845, 0.02742146793025313, 0.02612924039567588, 0.03101604164839955, 0.05180855376238469, 0.062131386366672814, 0.007462437752110418, 0.059381280225352384, 0.019701343517226633, 0.02725072201428702, 0.04586174669384491, 0.0458968057500897, 0.03764901062822901, 0.028249278002476785, 0.011888293865922606, 0.02719022213568678, 0.04706043022451922, 0.02784825108392397, 0.039859675598563626, 0.06633876255364157, 0.025123086670646444, 0.012215656133776065, 0.07631158718140796, 0.08664348511956632, 0.018206387212558184, 0.040040934036369435, 0.08155861578416079, 0.06408102315617725, 0.032933793918346055, 0.026154874176427256, 0.030055173774599098, 0.04050728850415908, 0.0325954970321618, 0.024988453660625964, 0.06702125640003942, 0.04600993874191772, 0.02467890200932743, 0.028080031224817503, 0.05129820106958505, 0.029646550974575803, 0.019777691959461663, 0.03172034164890647, 0.03905827856215183, 0.06316857485217042, 0.026418633460707497, 0.026964874559780583, 0.06467007318860851, 0.10224070560070686, 0.032695638728910126, 0.03769687173189595, 0.018663090049813036, 0.02320964813407045, 0.00853345425639418, 0.021010824129916728, 0.05249239089607727, 0.0287166121051996, 0.03777682701183949, 0.047449207995668985, 0.07589803281007335, 0.03448628151090816, 0.0792255780834239, 0.02161878779588733, 0.014652266108896583, 0.04838343462324701, 0.035819705663016066, 0.05879681295482442, 0.03192580152244773, 0.12910818069940433, 0.07244268970680423, 0.036862289562122896, 0.010971394531225087, 0.039031342312227935, 0.041603459176258184, 0.07119045651052147, 0.04035421683511231, 0.01017223878079676, 0.05226279638009146, 0.03541087506164331, 0.02617909231048543, 0.003568405822989007, 0.044983882471569814, 0.03372444836713839, 0.060263641862547956, 0.053055432363180444, 0.016144738074217457, 0.02622816125949612, 0.0344705368479481, 0.016475912198075093, 0.03753877943381667, 0.048067417010315694, 0.0365683545533102, 0.05226829569437541, 0.03450738076935522, 0.04411175876157358, 0.06725520361214876, 0.009723098428366939, 0.04328806018747855, 0.06184407502587419, 0.0330908991600154, 0.038005857495591044, 0.023273888436960988, 0.13143494725227356, 0.0650042251800187, 0.015521266304858727, 0.024616604277980514, 0.01702659505099291, 0.036152121028862894, 0.013176087068131892, 0.0234447660841397, 0.01669827448495198, 0.05728725860535633, 0.04372045397758484, 0.023121742597140837, 0.06598722946364433, 0.05112004480906762, 0.07737643551081419, 0.0927591827348806, 0.05507997782842722, 0.04495692024647724, 0.013323517487151548, 0.024792242802504916, 0.054275133516057394, 0.10508575840503909, 0.00728434179109172, 0.05203317217819858, 0.03545103267242666, 0.05190728908928577, 0.18254075024742633, 0.1002697840158362, 0.07858363518607803, 0.14612323720939457, 0.13500334171112627, 0.08167441308614798, 0.10169950925046578, 0.14463203988270834, 0.13511200697394088, 0.11540347390109673, 0.1212134215165861, 0.0920685104210861, 0.11293556570308283, 0.22791240859078243, 0.07344791389186867, 0.1776209642412141, 0.08428654284216464, 0.21989555127220228, 0.08960350402048789, 0.17672839807346463, 0.0997079188528005, 0.3093979525147006, 0.1305541515466757, 0.27054886682890356, 0.146994607639499, 0.0853067213029135, 0.12538227281766012, 0.09016964395414107, 0.07300844372366555, 0.2891238435404375, 0.10277163804857992, 0.12588641373440623, 0.23638846236281097, 0.1545892868307419, 0.15672875015297905, 0.07857503369450569, 0.15383619989734143, 0.12432719857315533, 0.16096126288175583, 0.16999787563690916, 0.0954429000557866, 0.14779626071685925, 0.17119015072239563, 0.09323284364654683, 0.13556835358031094, 0.14238983363611624, 0.15396582341054454, 0.17305274843238294, 0.19760887138545513, 0.11618328557233326, 0.10088366630952805, 0.09502726767095737, 0.07850503432564437, 0.14092005469137803, 0.2228740867576562, 0.1160653583065141, 0.14186730229994282, 0.13792048674076796, 0.15075861738296226, 0.1808310201158747, 0.16710403404431418, 0.13689212239114568, 0.04371943352452945, 0.156009430938866, 0.12645635346416384, 0.2322137332521379, 0.1537503334111534, 0.1585400803014636, 0.11137551933643408, 0.14512246591039002, 0.13957495655631647, 0.18201593309640884, 0.17636818927712739, 0.11196916326298378, 0.15128080733120441, 0.19935407617595047, 0.22846217674668878, 0.10117914498550817, 0.10576181040960364, 0.09620073673431762, 0.08150989378918894, 0.11270809744019061, 0.1661512500140816, 0.15145767596550286, 0.1406200192286633, 0.12889497651485726, 0.13523833535145968, 0.37942531518638134, 0.1091101580823306, 0.1614916609833017, 0.07830494389054365, 0.13582722953287885, 0.2620920940535143, 0.12796654977137223, 0.09088527469430119, 0.21049562754342332, 0.12030254656565376, 0.09772712670383044, 0.117428750381805, 0.09277366203605197, 0.1719234519987367, 0.12589583900989965, 0.11079106319812126, 0.3302033798536286, 0.1799606590066105, 0.15439254348166287, 0.16824910853756592, 0.146283199719619, 0.13149992970284075, 0.23197265400085598, 0.13720223621930927, 0.14345802163006738, 0.12489963934058324, 0.12412772412062623, 0.12862943607615307, 0.14996999641880393, 0.15561312407953665, 0.09208217335981317, 0.15362609789008275, 0.21256650157738477, 0.10162305319681764, 0.1937118687783368, 0.15356219897512347, 0.2192203453159891, 0.13189429213525727, 0.1608561450848356, 0.11742386705009267, 0.1150143139238935, 0.13845030596712604, 0.12507996638305485, 0.1023422388243489, 0.11647233724943362, 0.1986905516241677, 0.13939139374997467, 0.09917447794578038, 0.18267843348439783, 0.12550671614008024, 0.1362314328434877, 0.11733045292203315, 0.17315096425591037, 0.1306637073867023, 0.1538918016012758, 0.12473152804886922, 0.2042180229909718, 0.06645492350799032, 0.11225655995076522, 0.10807599013787694, 0.1566936614108272, 0.14331076468806714, 0.04056642283103429, 0.3174051915993914, 0.16952042235061526, 0.12583247444126755, 0.08919377913116477, 0.14133504882920533, 0.15937184973154217, 0.11491384197142906, 0.10424209976918064, 0.13352149544516578, 0.13402881275396794, 0.08218649498303421, 0.11107297541457228, 0.16834782902151346, 0.2784615266136825, 0.13994733657455072, 0.20228397130267695, 0.09381761148688383, 0.10862017734325491, 0.10102929052663967, 0.16729898139601573, 0.1761407803860493, 0.18439315084833652, 0.15600604674546048, 0.13354180060559884, 0.1455332149635069, 0.10083664383273572], [0.02897402417147532, 0.00866656215293915, 0.024691338549018838, 0.02109306151396595, 0.04231245882692747, 0.04156791030254681, 0.09479645974352024, 0.017991804488701746, 0.02419945791189093, 0.019696482449944597, 0.06232115352759138, 0.06445237901061773, 0.09868923953035846, 0.03618779235694092, 0.04678628458350431, 0.018164457724196836, 0.0445827219664352, 0.026883067621383816, 0.0649058460840024, 0.07378545749816112, 0.03911768006219063, 0.04654045929783024, 0.01701803437754279, 0.028590265173988882, 0.08252810555859469, 0.03802035906119272, 0.08747130632400513, 0.020608066151908133, 0.02981173078296706, 0.010766427258204203, 0.08197548013413325, 0.09230976036633365, 0.017826884431997314, 0.044174993454362266, 0.019085418462054804, 0.03185232148098294, 0.020577419163601007, 0.05539296005736105, 0.06792873231461272, 0.08501108677592129, 0.011638926680461736, 0.050691807045950554, 0.013153096260793973, 0.06430023131542839, 0.022448525596701074, 0.06993418603087775, 0.024913437373470515, 0.020695194289146457, 0.029098985141899902, 0.027590338067966513, 0.12056951192789711, 0.021367863955674693, 0.035983646084787324, 0.0249650741534424, 0.08145893792971037, 0.05354813678422943, 0.0484526213404024, 0.05208539711020421, 0.017962129713851027, 0.06570796671439894, 0.018423691763018724, 0.03044170469365781, 0.03795464930590242, 0.020522021550277714, 0.015671336914238054, 0.028106817189836875, 0.0250239450178924, 0.04058298385643866, 0.06443412959924899, 0.028686002224276308, 0.017801016874727793, 0.034573869779706, 0.008624317251815228, 0.004739545702250325, 0.08447208718280308, 0.028142080336692743, 0.030808269984845538, 0.019568998177419417, 0.003969770650655846, 0.04638173988496419, 0.0770811943220906, 0.0439902951620752, 0.061886047187726945, 0.03135839993774425, 0.01987743660720298, 0.02973232840304263, 0.0708300547557883, 0.01614125183550641, 0.08883066853741184, 0.021011249009461608, 0.044626471571973525, 0.08119406542391516, 0.04692393071309198, 0.009821593484957702, 0.032657952469890006, 0.05710937322874088, 0.038229622441576794, 0.056580003001727164, 0.030422152813116554, 0.02216519587818766, 0.012194056853331858, 0.059690841153496876, 0.025487501588941086, 0.030925100727472454, 0.06359614097164012, 0.05117387649079319, 0.04226079421641771, 0.05987899785395712, 0.0573192674346501, 0.04027802053315099, 0.049366936145816, 0.0139381094595592, 0.042087588080903515, 0.058672195227700286, 0.01618753587536048, 0.033481231730547734, 0.04581329187203664, 0.017261380889976863, 0.04493846674449742, 0.045063926809234545, 0.03766074027225841, 0.05405472678830847, 0.03032059732504422, 0.038897340127732605, 0.024580884710303508, 0.03662007482489571, 0.07106538978405297, 0.026417854205647018, 0.04046459274832159, 0.04225304248393513, 0.023200888936116826, 0.007471118560715695, 0.05932312924414873, 0.043191061486140825, 0.019770049693761393, 0.06124907667981461, 0.012687152757280273, 0.02453093260555761, 0.025651968935562763, 0.05167387251276523, 0.09871825750451535, 0.02974151062517194, 0.03481155741610564, 0.05937493115197867, 0.05192964257730637, 0.014202801066858228, 0.040610944270156324, 0.052282381657278165, 0.04696289717685431, 0.05787251626315992, 0.040509878599550575, 0.04309074909542687, 0.021399462748377118, 0.037187546913628466, 0.019915633092750795, 0.10355065562180243, 0.03657544948509894, 0.02048412377916975, 0.014033040351932868, 0.04929409806209151, 0.04998529730073642, 0.056340426599490456, 0.038899039645912126, 0.060680313254124485, 0.022844932645966765, 0.041547378787072375, 0.034189607977168635, 0.02049288112175418, 0.03573972440790385, 0.02554618320573354, 0.048421696046716534, 0.03160780979669653, 0.020145856578892563, 0.06341679356410168, 0.02956807813461637, 0.04457450639165472, 0.03156892867991701, 0.05180584863410331, 0.07665589175303467, 0.04056286794366315, 0.03325050915009342, 0.03548511209373828, 0.048988117996486835, 0.02093680788675556, 0.055539578752359375, 0.049430530780227855, 0.078060487867333, 0.05630279971228447, 0.03751113443286158, 0.08520742194377817, 0.04724093909317162, 0.0444550206157146, 0.07382482843240723, 0.03635758090240415, 0.012399468487274135, 0.009454550436203135, 0.09093030079384334, 0.024003295293368865, 0.07549585556262173, 0.02254433129564859, 0.03528715162246954, 0.04442989891686011, 0.03803509069257416, 0.042450784021639265, 0.05453977966681123, 0.01919341393659124, 0.03302956436527893, 0.08000239147804677, 0.022432150108215865, 0.03453559351328295, 0.07877123527578078, 0.016296407084155362, 0.039659455287619494, 0.09642905846703798, 0.08935606456361711, 0.0687833821575623, 0.0028230147290742025, 0.038741099488106556, 0.010363071851315908, 0.051980821081087925, 0.031027903023641557, 0.08423019899055362, 0.007211095062302775, 0.015314606935135089, 0.07083838165272027, 0.028062978526577353, 0.05368952333810739, 0.06152127047243994, 0.07924205376184545, 0.017009935691021383, 0.04312174489314202, 0.03903894932591356, 0.05730403485358693, 0.010646956325217616, 0.11755472252843902, 0.08420836500590667, 0.026345990190748125, 0.00974152502749348, 0.0050248550996911945, 0.016681860033713747, 0.05426850613730494, 0.02677719839994097, 0.047200299086398445, 0.04197493748506531, 0.052746851069969125, 0.07020190096227452, 0.09416523345862515, 0.04037772807350848, 0.03577981893613469, 0.01686702402366791, 0.10939486819552258, 0.007404678253806196, 0.04044647321279626, 0.009765025133674499, 0.02222059905761853, 0.043268994413665496, 0.06562166236108169, 0.02015231326367939, 0.054165919063962065, 0.0754102785140276, 0.020440674743440468, 0.039657573943259194, 0.022030672334949486, 0.042434052302269265, 0.06312759345746599, 0.03563038007996511, 0.011466557316452963, 0.11911283931112848, 0.013347299609449692, 0.00924231753742788, 0.0685689905367326, 0.06012045931129251, 0.05034574729506858, 0.04184129895293154, 0.07383345218840986, 0.03212121271644719, 0.04456349663087167, 0.06884294693008997, 0.057129003034788184, 0.06040626409230754, 0.018997101033164654, 0.016593498075962998, 0.06725939674652182, 0.03486802743282169, 0.01833937636547489, 0.02478576570865698, 0.04506021236011293, 0.028201871464261785, 0.028383586322888732, 0.023690841844654642, 0.0392805777664762, 0.0464934590854682, 0.05430073018942494, 0.026755017461255193, 0.03577654606488068, 0.07912927700090222, 0.032822100693010725, 0.05579290344030596, 0.01577974428073503, 0.023736519178783055, 0.05719761087675579, 0.020656767737818882, 0.024141498033714015, 0.01708512081677327, 0.058745478600030765, 0.10432441136799753, 0.040087169836624525, 0.016792677524790633, 0.06831677907030098, 0.03905949568434153, 0.05241488841420505, 0.02807086013490334, 0.037409107681014575, 0.02310754902282497, 0.02156876704248134, 0.08846300857840106, 0.01885057510662591, 0.014317438763100654, 0.05607913124549668, 0.03174575278535485, 0.02409780408925144, 0.020480127313931007, 0.04872765755862929, 0.0368263250857126, 0.04663140207412653, 0.051755197055172175, 0.006557421129400609, 0.04325533518567681, 0.008384806715184823, 0.03957820124924183, 0.04349169437773526, 0.05633532433421351, 0.019391008900129236, 0.02667768938408699, 0.03637317713582888, 0.010134958847629605, 0.013190237041271757, 0.012605957163032144, 0.03932315477868542, 0.0441667741688434, 0.048488496759091504, 0.018757031102722976, 0.03437177925661672, 0.015971121902111918, 0.04400888967211358, 0.036942163205822, 0.038019446219550446, 0.019536004147084896, 0.06656754441792145, 0.05678138477378525, 0.019772751111304387, 0.04971381596988067, 0.1143362358561717, 0.1019690498651471, 0.13946204620879143, 0.15035119315143675, 0.10771478686365299, 0.1801692321896553, 0.17683584621408954, 0.10639369720593095, 0.2266410502488725, 0.12100720094167627, 0.2075632833293639, 0.10370992051321082, 0.22378391528036445, 0.14759727608179674, 0.11753334867535159, 0.14819431904470548, 0.14265559671912342, 0.16590510931564495, 0.3421725594671443, 0.18196580844232813, 0.12127570997108705, 0.1631025964161381, 0.11435127176810056, 0.1891280827112496, 0.13749002624535933, 0.10404114844277501, 0.2347647471469827, 0.09372370754135773, 0.13264629553304985, 0.15932608890580013, 0.14330653444631025, 0.1567060998058878, 0.13464383053360507, 0.18152420088881627, 0.1332034554798156, 0.10102773943799548, 0.1693704936769791, 0.1973631462897174, 0.21805196738569066, 0.23839984583901241, 0.159224845119752, 0.11771549397963099, 0.13642197183798999, 0.14382713619852439, 0.17631413124036044, 0.1903358389972709, 0.16132739401655272, 0.06962996485526673, 0.1491836315835826, 0.1356774938176386, 0.16726993373595178, 0.14137298741843551, 0.20557921088766307, 0.1657523901667446, 0.1520539025659673, 0.11498616426251829, 0.1442773378221318, 0.13442324940115213, 0.19810881174635142, 0.1975924550788477, 0.12460064288461581, 0.1329815830104053, 0.07780723739415407, 0.0928977713920176, 0.1939337412477471, 0.1692002746858634, 0.09099241855437867, 0.15850080584641546, 0.1515391786233522, 0.22669332713121548, 0.15717052097897977, 0.14768571039894596, 0.12560666858917102, 0.1064138465153519, 0.2907318400684744, 0.10585440075374208, 0.22480718849692494, 0.07206127032986842, 0.1425023580668494, 0.13643006124766544, 0.2073729076073505, 0.1306364408810623, 0.1720139940152876, 0.16772822476923466, 0.09157070002402179, 0.12349951095529832, 0.17194176820339635, 0.09986797042074613, 0.2143729929230176, 0.12171207054052502, 0.05311470027663745, 0.21571461780695245, 0.10218690731562674, 0.09565873886458576, 0.14367248746566474, 0.17197850451339036, 0.18394260783679783, 0.13511423341697082, 0.17085376486647874, 0.1188718639605213, 0.12669674993958324, 0.12671941512962803, 0.20842684636591002, 0.17561205953825265, 0.1671364510548301, 0.15294810145860538, 0.16166870773304254, 0.18501195358112454, 0.08298310145619325, 0.11753039492759854, 0.13626316707814112, 0.10544106902671047, 0.23606711241882294, 0.11923620651941746, 0.149241489416454, 0.1003875480091665, 0.1617622480262071, 0.1703392041963525, 0.11617589378147386, 0.23644303990295157, 0.15264264831785113, 0.16653290687827393, 0.23187363665783778, 0.14075704937567934, 0.20153006800683215, 0.1405179442372173, 0.20096446241950616, 0.07564509403891861, 0.12018916866509244, 0.1839453834691085, 0.12346755407634191, 0.06065708403184544, 0.17022129177348688, 0.18315045424969867, 0.10852558320038952, 0.147979571192991, 0.11779549007769674, 0.06579117631190456, 0.1487335783895105, 0.1465463059139438, 0.1573687931522727, 0.12941833905642852, 0.18008646788075566, 0.10289188823662698, 0.11058989664888941, 0.17628187750233337, 0.14508759981254116, 0.1347612086101435, 0.1736496578087099, 0.14117248880211264, 0.11624451275565661, 0.08891955556464382, 0.1647564279846847, 0.08680577797349542, 0.10548906371695921, 0.1590942419716157, 0.05873703667020891, 0.10639504049322568, 0.16320447844918817, 0.18074591062031686, 0.10773629430332221, 0.2002908001304604, 0.16509034991031513, 0.30333706992678344, 0.16350868478184566, 0.08801226518698968, 0.14182759739924222, 0.15152089210459962, 0.11659253548714332, 0.0643246405525133, 0.17620727681787685, 0.0876993386191316, 0.2280966838588938, 0.1517980545759201, 0.10862289360375144, 0.10822316544363275], [0.023953114978212398, 0.032147670281119645, 0.06107726207119413, 0.07025654529570602, 0.009712489427329274, 0.01949326015164843, 0.041785604480537586, 0.06476404392742552, 0.011400384646549355, 0.010120283805008512, 0.0808616129506845, 0.009292244594689691, 0.024961417220765725, 0.07096526664099656, 0.04227801946399268, 0.038629506452707574, 0.09357858056318946, 0.021360360842663795, 0.032223042799159884, 0.021943653664493468, 0.042338493367424235, 0.040969034234876744, 0.05503958644112572, 0.030301407241495326, 0.015216917108773487, 0.023820348469598684, 0.025721411693666596, 0.03889487619744614, 0.05417450942331925, 0.03970058140112087, 0.03914354390872177, 0.03389260047697462, 0.053907495821476914, 0.09954736262443475, 0.039425534050678834, 0.016278831171803176, 0.024328652834810782, 0.11053782014641911, 0.06188424376887269, 0.009872600367089035, 0.09015856368932873, 0.0354626435728278, 0.03875708163832314, 0.06524084412376396, 0.02362639002967626, 0.008692547526152339, 0.04786387558851857, 0.047535081903333776, 0.031070982840901706, 0.024001916754059494, 0.029426125693134964, 0.0034528188734839205, 0.05212039679463487, 0.059291999859851785, 0.01499752712334157, 0.013081900178804062, 0.04306416536564939, 0.06118583456554916, 0.03759424012969248, 0.04665667220251635, 0.06476494934759103, 0.015016878624010133, 0.030797642430115957, 0.028060251133865677, 0.024223850450653117, 0.04074890952324495, 0.010363282435719157, 0.03295673741376959, 0.03150167525745928, 0.013478222808771534, 0.015822336135897785, 0.034819179272744805, 0.0459338537621079, 0.012090854725101963, 0.07470524564268999, 0.04631758863979485, 0.026483743931748904, 0.02586237336799968, 0.016995871992548928, 0.04970237205270678, 0.06649667673627846, 0.022659681453660596, 0.03125825824099593, 0.02771412273432361, 0.08324401089339517, 0.035443896922515705, 0.02944115418358706, 0.05903244484215975, 0.0374026843928732, 0.038231678190641105, 0.03369023535924498, 0.021966727035760414, 0.07174351238063537, 0.03211607334378641, 0.022631301726505626, 0.032131168627529405, 0.02448436654958641, 0.026662902091629803, 0.05202172826102469, 0.07354130575549789, 0.019154330584569834, 0.03056599773117341, 0.06921871114172973, 0.028781477667507716, 0.09129076934186742, 0.06401823004125617, 0.09408772355527617, 0.06252447230508551, 0.027567665456444956, 0.04674422707466874, 0.027812806110887323, 0.04459554256754927, 0.05529184243641794, 0.07072489985148422, 0.03616972848249134, 0.04919777471513953, 0.08348787319846451, 0.0347996162599884, 0.10704110231017694, 0.03369019083038438, 0.04933473806886468, 0.005833407367390464, 0.006978023120609578, 0.010317678388673812, 0.02457105310895713, 0.026441213303769473, 0.007156729961934616, 0.0619949907559203, 0.037514329378609546, 0.10051242177723907, 0.025376806552230846, 0.03795376615016721, 0.026180877175647765, 0.020332742351456545, 0.027102951135020703, 0.08559151305234991, 0.07376316338195466, 0.01404167802320444, 0.0019774508609771146, 0.03540696394338738, 0.04540457630355377, 0.007512546635553008, 0.036985768092563376, 0.049327145898132585, 0.09032249668962322, 0.05713973077945411, 0.059241622875561006, 0.026443120623298455, 0.04065236724272836, 0.01084775180061115, 0.015654386261303443, 0.062399999296758324, 0.020243228209437802, 0.05371055580326356, 0.06506896272185259, 0.03480128609226085, 0.05382548479246907, 0.015469900408788817, 0.01138830619311193, 0.009556306304148166, 0.018926225930044893, 0.05348151418729685, 0.05530370195629075, 0.03619944036472589, 0.05809141272038687, 0.0696546264225617, 0.07118185501894914, 0.033140849409392104, 0.03173466138832737, 0.04689853813033551, 0.023104229767341167, 0.1007020405086223, 0.057754110312089324, 0.05956172972219065, 0.022330416504701134, 0.04707553664047737, 0.03727108305611182, 0.02637849625898525, 0.03980516114097554, 0.06150840534246527, 0.04648835310945287, 0.03210634007700719, 0.04291886398277711, 0.07579421377158724, 0.027653177567117382, 0.02964736177091254, 0.055956550713744946, 0.01164344079370494, 0.05082799856609199, 0.01073036166417296, 0.04237642824591603, 0.06652438853052445, 0.04991023648472037, 0.05845742140081711, 0.008410582431679359, 0.073117940191878, 0.10367264985688962, 0.004195952215013676, 0.02267820917040808, 0.06486177735496312, 0.026449228498677257, 0.04373082920210436, 0.03227745706681162, 0.045828487345715985, 0.043585653984337114, 0.00585204547860485, 0.03512202747515403, 0.04590725518937688, 0.02515498603315791, 0.03515574324410409, 0.021381808910518885, 0.01594787412614096, 0.03958686582336668, 0.0606692886503879, 0.04494463028095197, 0.06854598395875655, 0.058722653848235495, 0.020983117901778314, 0.05127060059749056, 0.02420191256533144, 0.032666375846019946, 0.10744009574409574, 0.023119813013181556, 0.05154447535460349, 0.07270966249052435, 0.056369756275671534, 0.029288624282344244, 0.06143776401586365, 0.1091942805214785, 0.05336981725122314, 0.06757206356269307, 0.0415080672246404, 0.020499909260252025, 0.059389005982666276, 0.06167285413539503, 0.028511992713902146, 0.05343692595488392, 0.05276514129946008, 0.044928284478373826, 0.07167948730057105, 0.048462989143445157, 0.026166392308368813, 0.017684826234471984, 0.004310482299842988, 0.03461628351942636, 0.0059100211274198955, 0.008589800891058985, 0.025495611407677643, 0.05869727239769418, 0.01682655100012198, 0.011417010609875433, 0.07816905665094964, 0.09041713536134921, 0.04332115626311861, 0.04011256241938099, 0.03988903867139015, 0.019079152880294714, 0.010729206696851179, 0.028090371197322384, 0.014936603292881045, 0.0773488350387197, 0.026333505411457736, 0.02862575653125532, 0.03589201682189014, 0.008465482806059299, 0.01126322091295151, 0.031337148539023474, 0.03505431392113678, 0.06410860136384144, 0.019100133395113517, 0.02531715828808956, 0.019444118843239266, 0.03880733987898566, 0.037153634475544095, 0.03587195657019038, 0.0453997449221788, 0.025669771202956326, 0.04406229832966346, 0.08961372339399531, 0.07430185869452544, 0.023577812753501348, 0.04080100457940716, 0.08895180930267088, 0.003336321401548048, 0.05529218753508758, 0.004048647497256752, 0.03595066133129876, 0.024235413111455273, 0.050719808277790435, 0.011768422173190629, 0.029345511757128406, 0.022855007300677244, 0.04994376300601289, 0.03498364661936648, 0.05988941018586047, 0.026235985351377167, 0.023667059722356498, 0.07271263108123094, 0.020836903677263763, 0.03783914144150913, 0.0516328911180608, 0.10350781143642962, 0.057101231868728064, 0.03995359809778165, 0.013742933897447074, 0.03609073057305068, 0.08789975559921004, 0.08195173882995732, 0.04937495134072378, 0.06477148024714552, 0.04122642960282974, 0.04814203624846414, 0.04395018950162921, 0.03789696958847344, 0.09914314447087236, 0.0453036034014076, 0.0301092856170726, 0.030886772510712035, 0.02440961186948698, 0.04815745436644647, 0.0724511724547483, 0.05898172275919933, 0.03705019393237308, 0.020282662226236425, 0.01390440482282429, 0.05798066944407765, 0.04624852066626772, 0.021072804593131877, 0.05609955143881962, 0.07839089943445288, 0.082184372440679, 0.046671667296322994, 0.08708639143151231, 0.05203956949117128, 0.026205230751656927, 0.006328110948743415, 0.044251891085878015, 0.056152956385631114, 0.05840947495016735, 0.07723516027908772, 0.04079298938449938, 0.050128888033214025, 0.04710674395028036, 0.011175097370141884, 0.04487612262892071, 0.01088781478756573, 0.012594401923706755, 0.08538283596863039, 0.08319769345689565, 0.05595472874119878, 0.04867687981459312, 0.046143417712301016, 0.0885791695327498, 0.06582593108760193, 0.18187934823799878, 0.1637665365706198, 0.18685387505684048, 0.1300703306333162, 0.15261263586580753, 0.13034658768447116, 0.1326168025843799, 0.17377614945871755, 0.17143609846243635, 0.15752016159240156, 0.13277689868118614, 0.12069880147464573, 0.12785447062924504, 0.17324581072898582, 0.20425504131708294, 0.16416704398579895, 0.138265733839944, 0.11965144556597807, 0.1780873298412189, 0.10051546458271332, 0.21573792124399915, 0.1110354375850875, 0.10560168462689035, 0.05835221825691406, 0.13655496470164508, 0.13227084302343428, 0.13916212948970497, 0.1272370186052285, 0.18716894643148407, 0.12678239378146827, 0.16912177030462772, 0.19439422903815284, 0.10233549270196818, 0.10547460668021813, 0.13444538024486974, 0.15237038402119651, 0.11635274757281877, 0.16920940310228616, 0.17940148041816428, 0.11247256203205325, 0.18588189908768982, 0.20339161186711863, 0.11863686289871112, 0.20111600897507742, 0.16503789491252974, 0.09369075618451461, 0.09272392329876311, 0.12009988087811507, 0.058983188500860706, 0.2090798324206844, 0.14786823419854045, 0.13600167876575142, 0.10103883454576135, 0.11901688703801483, 0.11426106371800415, 0.17801933427108452, 0.10807521088281646, 0.15605358872562647, 0.20679336448665708, 0.1216818873945158, 0.06595181417651474, 0.18435257021337748, 0.11444315707194619, 0.08998440389405005, 0.09247404217603616, 0.1731798189575784, 0.12747959699481726, 0.08923532455810346, 0.12609198864083737, 0.13144388271030039, 0.15272967255441472, 0.08106430090265349, 0.1852092461194843, 0.2809864317532629, 0.15061461104778573, 0.1012660282140132, 0.09409334903466515, 0.19300319196190685, 0.15419618604937568, 0.09581811507814564, 0.11826241970993578, 0.1865787905990146, 0.24215466779423878, 0.17999122064793482, 0.1280533365206793, 0.11265173874562606, 0.1664884077035822, 0.08364920868189074, 0.09305287283496, 0.17849681724328548, 0.16063925984781235, 0.08353531127795577, 0.24089472368359566, 0.12822805292671546, 0.1443076619761996, 0.06731239351211116, 0.14582912408513948, 0.14899570494890213, 0.09816584730288014, 0.16441646497696638, 0.15956433315295726, 0.25285072275437415, 0.13760044297669083, 0.19688823114847764, 0.1440071515389718, 0.12506409926572815, 0.1924175038584508, 0.3161299740895629, 0.11159339905134402, 0.12484368140576407, 0.16575903980992734, 0.140690196712967, 0.23194547655293718, 0.19757565285544842, 0.2845672349212691, 0.16539169155294076, 0.20892981468932703, 0.1252925323206, 0.11532850214280188, 0.20726390095660463, 0.1060187716211658, 0.17814995226217434, 0.13668052124558017, 0.1519053097581491, 0.14222074270946905, 0.16560183808906004, 0.16084508708445355, 0.1181983649439644, 0.16398955194745213, 0.13719928247155622, 0.12539034738438204, 0.15778118977323174, 0.14750747621292248, 0.09601332218153402, 0.1531353304744698, 0.10692258874769323, 0.2008770967950113, 0.14016678964253515, 0.28140577487647533, 0.17036728706443682, 0.22936827968806028, 0.07985048869159073, 0.22823475301265717, 0.10921835579210892, 0.21898642036831006, 0.09791979566216469, 0.126244603889063, 0.07529655180405825, 0.08116430530208163, 0.12483332102419809, 0.17316542129265144, 0.23754596040816978, 0.2461839359602891, 0.14351871446706355, 0.21029143303167075, 0.14326357893878594, 0.15040235681226477, 0.20000355929369107, 0.12305011827265844, 0.1845178910298273, 0.11730789163266309, 0.12908183445688337, 0.18001474672928452, 0.12085497903171927, 0.13437201152555645, 0.16711326636141166, 0.1829037643619813, 0.08108396781608462, 0.08302679911139421, 0.21060154685983434, 0.28981006296817213, 0.15063414437463507, 0.11341765741235577, 0.14376222796272486], [0.04789349841303192, 0.047006105014588684, 0.11403680895455182, 0.022198950609890744, 0.03588835803384427, 0.09710063532111235, 0.05457341379951686, 0.021764113298559096, 0.016033740612328984, 0.0571196148666786, 0.07953068241477013, 0.025963205262087286, 0.0087940974481171, 0.044964913176954724, 0.04576074039505329, 0.018969058983202558, 0.006130933443273534, 0.025695707408885937, 0.03950502919906285, 0.04924757653498091, 0.010703726911742706, 0.02024495741352439, 0.01524011293440708, 0.008522962143615587, 0.04214337532175705, 0.01939877176482696, 0.02478602917108219, 0.038877361512277275, 0.030244347217376344, 0.057932478084694594, 0.03720233420608565, 0.0540822085167747, 0.00992314433460706, 0.0150774388021091, 0.047048923224792816, 0.03673745290143415, 0.016380503548134584, 0.07262942148372531, 0.051469084282871336, 0.02990668115671724, 0.021394384602899663, 0.025782245538721327, 0.04745032492792234, 0.02363935906032566, 0.02785960223263828, 0.020081055954506155, 0.015617943099641707, 0.01542277866974473, 0.05664421732944902, 0.023184031051641796, 0.08510299434419721, 0.122776354837697, 0.06035551232344005, 0.028429261801647954, 0.05965695840131957, 0.05444136717414949, 0.029703965374210384, 0.04223460753564723, 0.08588665776187554, 0.017759892616595607, 0.05197865029913373, 0.049920270321308635, 0.055563724527019076, 0.0562705237098271, 0.04400712707138155, 0.027503087476361543, 0.02577567196567543, 0.026614566013449803, 0.04081856008269824, 0.0303061495651491, 0.022041572628950235, 0.06071464500564616, 0.038866997419972904, 0.00846399108922924, 0.009744383223733166, 0.029675455771212, 0.015660757599107455, 0.041057821072172374, 0.02764128465059912, 0.05096390435937792, 0.040152007568394765, 0.017225627925654408, 0.06213449967617635, 0.04247970922733657, 0.07332835390116088, 0.10353263627621345, 0.0329370816325536, 0.05315143287589308, 0.03386594253242947, 0.049682560420478694, 0.08719268182176165, 0.03775793193199206, 0.0557445376762189, 0.05132122620125301, 0.02145907019439619, 0.06306640338152647, 0.04533436171186622, 0.0323358010064112, 0.026605422754073516, 0.08732170419534668, 0.11272509262198582, 0.0528530227165902, 0.053602150292135775, 0.00556792027055053, 0.07124275565729477, 0.04697040771134198, 0.04122257785638794, 0.037666966891265474, 0.008153178714565001, 0.05537483681109734, 0.04956724922521971, 0.00783848305218271, 0.02455560716043692, 0.04402311293233652, 0.08739982265979052, 0.04653616968425922, 0.027697468940459657, 0.009182725862046937, 0.03333395994559396, 0.020441064370970707, 0.026812411451828666, 0.019246054471295793, 0.07167750576627441, 0.030034983647055924, 0.05218100799538661, 0.0489521609415533, 0.04926876485114917, 0.030900954952812754, 0.061820968257961795, 0.056997490755748004, 0.06822753581218421, 0.009150559326371877, 0.019398233707761392, 0.02223789480922278, 0.06360850515193306, 0.07990788639290258, 0.032095467613544315, 0.021957986391498707, 0.0464724785706494, 0.04031686454254668, 0.032893892348511145, 0.05084506425191648, 0.047678138289484195, 0.06767240192857571, 0.03632618063420523, 0.05350370811356697, 0.030633963615400717, 0.030157280307321344, 0.016250954249699134, 0.014232719822757645, 0.02231110953289317, 0.029753277376585174, 0.09080824718694203, 0.04817698398255743, 0.010378791466791881, 0.0367846497829305, 0.0390190003963653, 0.015500405461352784, 0.02673723931366112, 0.006178342300700024, 0.07896659823018126, 0.0506504545774078, 0.026546635381237138, 0.024902917430154048, 0.10057709994725883, 0.028639463998842984, 0.028737360698869452, 0.048894325373112224, 0.04640419727365952, 0.06641452840995044, 0.024369994171138387, 0.029785889200866222, 0.03276940078649204, 0.041265050967922434, 0.02536259256885387, 0.06896077771671116, 0.015289054790628143, 0.02020092579186894, 0.07547986970166676, 0.10642234410624951, 0.005501454916156945, 0.04519375441304874, 0.08352265023859218, 0.01878509356174618, 0.05948499165242538, 0.09175209575914778, 0.056822533151716925, 0.03497176854580175, 0.022269478758971673, 0.061964666601852514, 0.05992416125081945, 0.05366465025872458, 0.03918784641427919, 0.017359394478262402, 0.03983400471042842, 0.02367619741562521, 0.05406914671766572, 0.029926708011771552, 0.04906134199700318, 0.02679240315046627, 0.06437992313294671, 0.08467677151202224, 0.047981064417399466, 0.027188079184270464, 0.03148371528368443, 0.08577956585213542, 0.00665883607325668, 0.018651247228262946, 0.026797995233209804, 0.017240476445294917, 0.03689554148877505, 0.04396583768539131, 0.02800968304654816, 0.06655921752098948, 0.03737256432941649, 0.07222131447633728, 0.05985320080071688, 0.02010732798225945, 0.03590865948353894, 0.06128536770120263, 0.07455191793269478, 0.029104773893777747, 0.040953508505481295, 0.029139780999685172, 0.04674120282288641, 0.022684959003527183, 0.10067819530377164, 0.012458537876227638, 0.04743574172607623, 0.058288044747314416, 0.049884662075783126, 0.017888902002596296, 0.03646686214779038, 0.04557076172204688, 0.058072128013009205, 0.05996771047648508, 0.0606673405127367, 0.02861946682969574, 0.020569752778101247, 0.05048669598181732, 0.06926129557541572, 0.040790221173665486, 0.03974402672611177, 0.03921959920262452, 0.04760822426760569, 0.06179720468935557, 0.024217189675255213, 0.03636454595834948, 0.025446781801292673, 0.04383495994261466, 0.0338623282732442, 0.02758802813332295, 0.015416116038977634, 0.040691641697776504, 0.04190642983303405, 0.009133469520747894, 0.00853107289003674, 0.03635523942648433, 0.06913747565704398, 0.012965151072421577, 0.03998855325335171, 0.04756120179081336, 0.037268162705004215, 0.016494720075570513, 0.04603030327416491, 0.040377401528530754, 0.016106990588014014, 0.011804843998106662, 0.05456379185488913, 0.043786642418126576, 0.03515539443469606, 0.04849343946261797, 0.045904824655735865, 0.09912450172123499, 0.04454122106835712, 0.10893708182265982, 0.04424161605129484, 0.02505908199964324, 0.03264985192799941, 0.031799911012058146, 0.051571010844781995, 0.06536821150803007, 0.08479302152409218, 0.03017670416738838, 0.03131997895252425, 0.03200089944584761, 0.05036488357291091, 0.07142862654291093, 0.0017126939678746567, 0.026896309391304385, 0.06940244464203715, 0.10053200705442578, 0.06626674454309978, 0.013333002134459093, 0.013483533803082537, 0.027949682262260467, 0.019858046143781394, 0.028217378639965318, 0.06192346627358347, 0.038139881944516674, 0.03177377628162503, 0.0390686426544562, 0.06044960180588532, 0.045914212823845446, 0.009275306001654826, 0.012042548332829028, 0.037278511954355054, 0.011253855009272229, 0.012354735536064254, 0.01344190302916104, 0.034396964038023725, 0.05563881131820381, 0.055969356471905485, 0.019191515893908218, 0.018598998176457826, 0.041586167135392316, 0.04710786830401048, 0.07555360949481837, 0.07554933472420089, 0.0410537429706892, 0.019794748368440196, 0.004393658964545466, 0.03611221203755122, 0.04828804638236761, 0.0193944914281019, 0.014244724989112001, 0.05458415638713632, 0.017180412578454707, 0.04110565620067064, 0.05333499197149649, 0.019797559252765495, 0.050001416748273186, 0.04013616642623674, 0.019517513537721243, 0.05728130658098962, 0.04728067739051767, 0.04220237606205046, 0.03663635012344457, 0.01270505614229478, 0.030263592962000985, 0.032286184723488986, 0.02558216994657414, 0.033852082924568094, 0.028500491280283313, 0.01776056054950459, 0.044251501458347775, 0.04185900659649633, 0.02661951984919142, 0.13242814864497632, 0.046194655587896705, 0.028037220436090138, 0.03448556533840019, 0.14778302080230787, 0.08316518738865852, 0.16670705925207585, 0.1905317511409521, 0.08948661576141603, 0.17627022578381002, 0.1108974203816615, 0.0828449877735693, 0.1220038830069825, 0.16824898979393765, 0.22422112931963056, 0.13414755638223141, 0.15097137627890334, 0.10060470041935332, 0.18636742694070563, 0.10087182163260877, 0.10063913607154973, 0.06267869801376946, 0.10788841973408125, 0.08155244853696786, 0.10403380860225298, 0.0668359718110878, 0.11325022889650427, 0.1361866813385859, 0.13750859478022903, 0.12138378151576035, 0.13680215924978256, 0.131953663949389, 0.1576678638230078, 0.16700666426913813, 0.08474775051581673, 0.11593264745897613, 0.09575200456310995, 0.1322786949458532, 0.08324446360347793, 0.14458786725299433, 0.1461186507367529, 0.1714761447510682, 0.1566213316982612, 0.13577701582107693, 0.20407873671501875, 0.16989762632874772, 0.1507692746235989, 0.1561662318999879, 0.11022017351933755, 0.11775180726544932, 0.12325444637099281, 0.053221224443404935, 0.3555226977914572, 0.0900186094804667, 0.14750695670954883, 0.15618361299857497, 0.13625791267259046, 0.10994344149366952, 0.19422739424044266, 0.08159019416780211, 0.18260577722685412, 0.16511326743056998, 0.29800966673064977, 0.22278876946074888, 0.11765683462726884, 0.14520435448503122, 0.11523563720402308, 0.11397609385312535, 0.14526859478792176, 0.1786422633449547, 0.12548633676487952, 0.13836567144608125, 0.17932745860889554, 0.11510530865052715, 0.14082388719543815, 0.19294082187116146, 0.12155982636613771, 0.13672720233444124, 0.08863549854140729, 0.0791262935672421, 0.11562669707927853, 0.08968614958575927, 0.1254770005471073, 0.10176713374676183, 0.12214225644129328, 0.12456640019081533, 0.14354607003042474, 0.08956316829426214, 0.2577404072508216, 0.20652558276196942, 0.19081434613326564, 0.20445942878723145, 0.13148137601092458, 0.18738333805231377, 0.14770562964258716, 0.07577331489301287, 0.11690253799315542, 0.23905724025098607, 0.15792228688951582, 0.20174178789602593, 0.12628594151465222, 0.19453502929536626, 0.2297132447711192, 0.2433142438530922, 0.20922153809806332, 0.16442591993836686, 0.08129923517117277, 0.12384293237118982, 0.22181925742188469, 0.10428750436403789, 0.12950640229973942, 0.10927219860604964, 0.09599528057151474, 0.10416101271403022, 0.18699244887102395, 0.12646058370592073, 0.1096839272940997, 0.16053765983087942, 0.24249060836154968, 0.22949585487367585, 0.16231679561315104, 0.11733181847375818, 0.10573741601547226, 0.060992957805865444, 0.16325945674907416, 0.11552739029866643, 0.15687866398366168, 0.10637043829774484, 0.09517803497146815, 0.11254907003603876, 0.09662254378781654, 0.16819968150230125, 0.12634310172870755, 0.10305454474291764, 0.19983345904620364, 0.11108325415989384, 0.19181081297574565, 0.07105973461875692, 0.16918455599807203, 0.12418009006069042, 0.11281449915259145, 0.09234473778633401, 0.08923431523726322, 0.09023102698847651, 0.10752672664239071, 0.20378480170620605, 0.16129991970956326, 0.2607381495181471, 0.12099126703105867, 0.14473237824859098, 0.1028517603117507, 0.16457028250442818, 0.134358519280795, 0.15555358899291605, 0.11430349972215481, 0.19064553722273558, 0.1161643756495323, 0.1429538955562748, 0.18326378019992262, 0.10376800099038519, 0.1171551353763789, 0.08626371331047267, 0.17314477474428713, 0.12507388077210635, 0.15955352748278528, 0.2059859671862796, 0.20012239197967574, 0.12735073047224432, 0.16002781921997666, 0.05426917407021392, 0.0839256661129184, 0.08340572487213649, 0.18548315798398107, 0.09113247666391544, 0.09826559195062146, 0.12946594040840864, 0.16964336653472856, 0.10392714713816531, 0.11331164161674678, 0.18935687199700624], [0.016517023468622938, 0.04412006339407526, 0.03901240270351991, 0.013469022032950306, 0.06399589139618911, 0.028883003469672985, 0.04979949691914953, 0.0730670808115974, 0.04453946959984023, 0.03323241930047516, 0.06211764921317808, 0.06748748099198565, 0.02815111784002511, 0.05402661052357871, 0.043821734871016815, 0.1339740422554314, 0.02066507422568975, 0.09435299682081677, 0.04518937203101814, 0.06615510326810181, 0.016358658431272488, 0.01601675285201054, 0.040288636955665424, 0.055262438545469195, 0.022123168055259157, 0.00809798426416819, 0.0443398021889152, 0.022501062230730895, 0.01071395092367311, 0.04912112941383384, 0.046128407775540836, 0.03111330937827006, 0.02698980701097753, 0.11305770094622858, 0.009302176385972416, 0.024430410558125004, 0.021370793583628256, 0.03118514927336946, 0.0897979541332461, 0.03230520596844144, 0.04080259277543519, 0.023538052191725, 0.05556480806262698, 0.02169024919567164, 0.1465767339686863, 0.04710739704023581, 0.022533794654009398, 0.023175041787908413, 0.02826494845066918, 0.06357562058838084, 0.0608879068022361, 0.05715718609280884, 0.041894759560818784, 0.02302230779605452, 0.013765281819360098, 0.01314701064984547, 0.0244327130712918, 0.03561231991625391, 0.0256638896826189, 0.0888607997330837, 0.024241266801254824, 0.01948708919371711, 0.02665213538421085, 0.015287586265912978, 0.08478543677483685, 0.03908986065653153, 0.07066091187880374, 0.03933344836696051, 0.049462925526313484, 0.035107314397464506, 0.05937712048762478, 0.023976962038432248, 0.032498438959009945, 0.038614392615272664, 0.09898236559820361, 0.024804590284475125, 0.029679869694518857, 0.10458489035954699, 0.04134967064601369, 0.033435697259847075, 0.024005211889743805, 0.024622615674161352, 0.022324763194774278, 0.0044991227878199425, 0.03532729810103774, 0.06947898233192973, 0.04711331566795707, 0.026582230639178306, 0.03234666233765893, 0.015235330720315687, 0.10296045526047237, 0.03300549280538689, 0.07544547857833095, 0.019768270394706633, 0.08575137908337638, 0.03842375343083404, 0.031858893198659644, 0.058449439602554776, 0.045434937565005384, 0.05387265198805835, 0.06417106051230803, 0.043129771220264956, 0.022928479920665268, 0.02277844734635437, 0.05149158991116565, 0.037562435391009785, 0.04559039152809419, 0.031065826769918203, 0.07273524432093836, 0.10843580559594557, 0.04064548382302746, 0.04234572559653316, 0.05155244973138906, 0.04329083953052759, 0.05879358090169262, 0.01511732923972886, 0.007667484342164244, 0.11413880230975337, 0.03803928382694721, 0.004502859501371859, 0.019237048509239685, 0.03890723666700069, 0.012472475409595063, 0.038576535662286915, 0.09560794627759606, 0.016340774527634494, 0.026133134815609083, 0.04243253089953214, 0.050429791808710434, 0.07900924945715815, 0.04980321136827115, 0.05637304398987908, 0.04846612471737899, 0.02511586371838348, 0.022666264303552452, 0.02064423286356032, 0.009770446522452403, 0.029387602662609424, 0.039203398118843324, 0.02973492220917251, 0.025694327014207374, 0.022755637437512632, 0.027947190501436125, 0.028900729666929692, 0.07833457042579539, 0.04896510028629564, 0.05995764324325137, 0.03693999984534457, 0.022271076231845655, 0.02505916178051848, 0.02151237495127134, 0.05533871277293656, 0.016089639175334014, 0.048885363939916715, 0.021702990015910473, 0.04408789500303101, 0.04474006098462269, 0.03796663128014188, 0.02010848758800421, 0.02318611463124398, 0.08170166474883445, 0.029035583465883974, 0.05346995523723308, 0.05087240497232415, 0.00904051181350951, 0.02458268998452695, 0.04296344850445166, 0.037039818707853556, 0.046266929639386944, 0.019019333922187798, 0.021762491705885623, 0.03973304665123578, 0.02216501219663769, 0.039678435714449733, 0.04071705654496327, 0.05508959606231656, 0.02103694401739631, 0.07772612807457335, 0.031965907182893716, 0.027848197278217413, 0.026887338681262918, 0.026861803235078696, 0.037170848590903915, 0.07698489323956892, 0.01865527894551633, 0.025800188814173453, 0.05296116476529278, 0.02470010887918761, 0.06414525603759103, 0.033842765260487795, 0.045385191406239755, 0.07180922213592567, 0.04151402667048387, 0.016851882355695125, 0.062063657969702035, 0.07104943360900506, 0.02795521868392825, 0.05156378603714984, 0.010853175044758245, 0.07061729585984722, 0.014611104743380565, 0.022100627174950205, 0.07944849698105827, 0.03217486999346875, 0.01747442365740426, 0.005905087236897089, 0.010348955274821492, 0.006936750432942063, 0.03956700224080123, 0.05710580720915459, 0.03451155535003636, 0.03930731734726578, 0.07310953908017837, 0.03095821350143524, 0.06525786156998947, 0.030724722710147034, 0.059262024515192024, 0.018331448372919112, 0.049793337093433365, 0.04008852796687279, 0.034016372155747376, 0.007149668426791322, 0.016668868738634046, 0.04181952805083711, 0.030335902265505865, 0.0729843536100816, 0.019328059934196062, 0.06743430611095391, 0.0029038037655482185, 0.05311618457199074, 0.05232708863331936, 0.03946024058677722, 0.04296406448702328, 0.015682791963627096, 0.044325968556222506, 0.016918900146265514, 0.029093114753777627, 0.0078017866326263174, 0.03304232559457887, 0.04128568267333321, 0.0983707542764023, 0.04654104930523317, 0.04381856961117592, 0.06499477764009498, 0.015819089239812456, 0.044902728623128496, 0.05111810038215481, 0.04955293690727558, 0.06636807738686912, 0.012056487721565645, 0.04181210657407064, 0.02100507805153029, 0.08156448617228307, 0.007341307655224227, 0.0066024347052007215, 0.016983312998490874, 0.023505742792622186, 0.026042709687317256, 0.022336234942486044, 0.03711183300765697, 0.05298851661791559, 0.08705254207598045, 0.010723629457061179, 0.014308284371509217, 0.057578985724831, 0.018173716016463004, 0.09668532948126085, 0.036169105078442954, 0.05594059453869704, 0.028876736032543704, 0.005755319052695995, 0.04719815799035132, 0.022542132683156524, 0.05412117869127542, 0.04196481088001747, 0.034333651419728994, 0.066818932100432, 0.03358414534886833, 0.10969433962600306, 0.04930741590214893, 0.07155747822253034, 0.06867492469609715, 0.013677485749212792, 0.02793764648231445, 0.007495160434700665, 0.029559415415860713, 0.02525790892832447, 0.010756093779491493, 0.10881671289098449, 0.03605572346714325, 0.026908367435680702, 0.03861624798446428, 0.06919049468706362, 0.024951431623776443, 0.03576732116925996, 0.05570947490923572, 0.030580935308535118, 0.02505913951608818, 0.019589746771089267, 0.02532780810724944, 0.02601502201287076, 0.023287332442123443, 0.026831414143089205, 0.02985685336170718, 0.027038610642193817, 0.03710510914970655, 0.09914128168020397, 0.047196740488288924, 0.05374614549509715, 0.019456670415820554, 0.003713285573212488, 0.04448630214028526, 0.04494293076277245, 0.012786744337063283, 0.06534557600389235, 0.014718524125783006, 0.007918180435808608, 0.008628620780655183, 0.05008262254705187, 0.029748920969723258, 0.052304553319117986, 0.03431289725995157, 0.0247739655605983, 0.02941682658274658, 0.08037644875003025, 0.025122873303189408, 0.029281980205269065, 0.07757381710689515, 0.08637488703243434, 0.05814696989546064, 0.03477064281469211, 0.012611890633706935, 0.01092563185011386, 0.03224727763154078, 0.05313529858540278, 0.029476756863004994, 0.05537902994547039, 0.006776292539143469, 0.0645404496754054, 0.006262353881538729, 0.03821001861069817, 0.03206009685527533, 0.03540650010108948, 0.02411008477793075, 0.05171871307538822, 0.014557211834471673, 0.04021252228994854, 0.01257430734767695, 0.016882089621503837, 0.033274072338826954, 0.013069014639768284, 0.07255227523273788, 0.1317123620538041, 0.15070919034769759, 0.20574972673784941, 0.11840569131891243, 0.2680449793115258, 0.1300974190235138, 0.10289486424881034, 0.2179436435108073, 0.08301761132315733, 0.07861664591473527, 0.20666148484451696, 0.16189810557989404, 0.2713784691877663, 0.13543111563194543, 0.16148116701515391, 0.2167066911351867, 0.12084993242751807, 0.13711829931708053, 0.14628443168476224, 0.17673774913419038, 0.09108046695473604, 0.23979091260116547, 0.11550776049261913, 0.130417492473498, 0.15630487992893904, 0.14444360858760774, 0.15465655509615317, 0.09874791372567415, 0.10929195457720198, 0.178714964131359, 0.13042991602560505, 0.1449796321685426, 0.13558340433519334, 0.21935954253422096, 0.06347234331769869, 0.12885996198747307, 0.1168672191852238, 0.1084298461501021, 0.22208356589544564, 0.12432838600943796, 0.1874034947832115, 0.08592223632149398, 0.2037701813969761, 0.14470502268522978, 0.25281489186454564, 0.12719222257146612, 0.09138577166595496, 0.1737541373586282, 0.11042893966077827, 0.1445116932154633, 0.1305597770260647, 0.14778428245335817, 0.06517495625303127, 0.16181911138119176, 0.09365457648527808, 0.14172813476761803, 0.07956229048431851, 0.10379441402619705, 0.11132726489449851, 0.15527420007856563, 0.15483939059777185, 0.08288658515084535, 0.15334243420511484, 0.1283292967127636, 0.3055509855039418, 0.1362704994971864, 0.17801528214477003, 0.24795299337711185, 0.14873571577481925, 0.1123639932484366, 0.10406729430542327, 0.11069620930356905, 0.2392664665239863, 0.2295552266878076, 0.1613643381278962, 0.08007537428056821, 0.1378275253227912, 0.17702641489449888, 0.13288934889715165, 0.14757363125681877, 0.08935377132729627, 0.07091195817338303, 0.1605087606003508, 0.1231715187896043, 0.13683810888323933, 0.2606649143854156, 0.08487296567182057, 0.06848670862382278, 0.0963155840872787, 0.15604000742314383, 0.24044474470429122, 0.15786904521519318, 0.11639724674751051, 0.13512983336113393, 0.1997756160562858, 0.12364477152004838, 0.05284357146592811, 0.1199454176821746, 0.17165225639473647, 0.10778880125144497, 0.15407583938213065, 0.13077307026833296, 0.21255121333524585, 0.18434013181831688, 0.29372946359217167, 0.13436102773994207, 0.14935640356270596, 0.11838306323625147, 0.15590159688144922, 0.22894642810570076, 0.07575551077025011, 0.14513478556182235, 0.23738144111121073, 0.09666319121606648, 0.13641560421092436, 0.09679363851319067, 0.19831659825285897, 0.18679043627344072, 0.15864528715610504, 0.13740882044658065, 0.14134785829810426, 0.07215717807412148, 0.08389998780330643, 0.09115062217460945, 0.22323582437820733, 0.0803126537357457, 0.06868036463856697, 0.11604321261984296, 0.11029940520529635, 0.17365878622513264, 0.15010309318313375, 0.17480632464867085, 0.14415369601920247, 0.09400982773513533, 0.10492420027730986, 0.13271377159981057, 0.1180597985512577, 0.07647572798305191, 0.24673820153111592, 0.17211229889653623, 0.13378117291722447, 0.20845571591053158, 0.1154047207091935, 0.17023061314830557, 0.20974430692149326, 0.15163552423473448, 0.10777515315567143, 0.19106911058770493, 0.13285709515912458, 0.10949830131721683, 0.10644818568835035, 0.1887814700603485, 0.14694231591420248, 0.14829774474492297, 0.1577185673522763, 0.18032929860055447, 0.08414241034188308, 0.11120325201773085, 0.09037160460138693, 0.1412412413628772, 0.15644029219402, 0.0836767943110317, 0.1604306569788605, 0.12650742806727067, 0.1813347009010613, 0.14405169524252415, 0.12944170186528936, 0.1102107111364603, 0.0835167353216093, 0.0806112568534445, 0.13599293626612052, 0.1386190703487955, 0.11754563864087686, 0.11021652957424521, 0.08539247646695003, 0.16797880351077765], [0.016910847843973897, 0.013955440463178093, 0.013570499595516594, 0.038194737790036015, 0.01902314485050738, 0.02985553419421194, 0.07136974454624578, 0.029658857638423797, 0.10383604108938016, 0.031867431607679464, 0.048499042677576654, 0.0421898189233616, 0.047029642228153534, 0.008262393166660331, 0.017264243724639527, 0.031093429097381886, 0.07598888652864844, 0.02697712556255283, 0.02184918939747149, 0.034820648725144565, 0.014512363850371912, 0.04690607463999186, 0.04169236104644369, 0.05807556415675208, 0.02966768548503751, 0.06179274067108054, 0.009059061794687295, 0.05719570355722681, 0.07677295070607215, 0.055611140342080034, 0.046593667575507425, 0.05400060937972739, 0.05976859225484077, 0.02756487127044238, 0.05084666729089804, 0.05405331670772284, 0.03513549374474678, 0.06255733460420743, 0.025854836858343333, 0.009139878893620335, 0.04106451895495411, 0.043327060047886334, 0.020810032365261577, 0.03236521974031348, 0.003678392804431496, 0.02042221381998388, 0.007115808402886614, 0.06851960060885176, 0.01503004339610925, 0.017068134911824018, 0.07584542938275263, 0.019787495730270166, 0.04509172766120173, 0.05715494851756375, 0.03961116373830009, 0.022000466924509965, 0.07097188659827225, 0.021022045402787626, 0.06722096833982505, 0.10493923618923873, 0.056590010863146745, 0.02664691437530564, 0.009088503720704466, 0.049782857968239114, 0.002429464948363602, 0.0673195107083302, 0.03964577008446213, 0.07173693695222028, 0.027531259402167052, 0.029069837291899603, 0.04400898986204993, 0.028610854205908254, 0.06937007216038182, 0.02097296903230017, 0.06855873405584134, 0.019882206761394627, 0.029560619550466072, 0.019089863926637918, 0.011532805128808832, 0.03292509223683737, 0.030701497198606376, 0.03922270509065129, 0.020905550481984392, 0.04353105046902783, 0.00928423774894327, 0.04324685985920951, 0.07278158402186818, 0.00982602688964107, 0.038828312972327694, 0.05648561294947285, 0.056483230655430816, 0.019312075928610284, 0.03458306127868127, 0.023934141972858924, 0.02975793249788694, 0.017078204000426922, 0.02090178408252541, 0.027223605793551542, 0.05769848634372465, 0.019795071202679537, 0.0486448375886539, 0.08469278705888428, 0.04453656409168616, 0.05507706489879638, 0.03386318916454911, 0.01521385760497651, 0.052380671695573255, 0.04986830514098983, 0.025027928495546803, 0.04267332442395855, 0.03303785415482707, 0.02539305030950345, 0.05702821566956118, 0.030957655035308562, 0.051882416009902954, 0.05420294852228835, 0.05895899077586364, 0.0200030970518128, 0.009031758181663463, 0.07172760815592483, 0.04573131423967425, 0.025435386123717763, 0.024956712004495785, 0.05892375731491484, 0.037836050396435894, 0.03036928963410901, 0.036156803980702534, 0.054816088668303564, 0.04287453179131262, 0.022956178727326915, 0.021685892788809724, 0.012477736308937892, 0.07458675434463657, 0.08524520468199626, 0.024109116275212727, 0.04098710182006471, 0.03700770597788505, 0.06940200677490793, 0.044726828491548076, 0.0230946170995594, 0.03847875399515033, 0.02775858109089313, 0.009173878534056712, 0.04616877318767365, 0.03009400850714883, 0.03588996107282583, 0.033470125490566716, 0.01258868645891198, 0.06792531101382338, 0.10355239966884255, 0.09299093318986706, 0.006409228617485496, 0.026867497363127768, 0.04730336855573114, 0.025294778824900277, 0.057706349398358725, 0.02512448376364773, 0.051894683710997924, 0.058167074676021, 0.05555636984354351, 0.05019273128709756, 0.016875178371265065, 0.02373299954342656, 0.02749455648881849, 0.03600838557758834, 0.04792140316567384, 0.011962933513132157, 0.02908805701736128, 0.05999141467327718, 0.06176206770760473, 0.0677732375334017, 0.06197052585775964, 0.01281425946217496, 0.06326165501377545, 0.013849379211023916, 0.00057534644952284, 0.04419806682562921, 0.04299585438275244, 0.030836633013677783, 0.06515282540931366, 0.0484408249030821, 0.014528913743561134, 0.05089551174023654, 0.0609431930934079, 0.043848771310877055, 0.019026421432499774, 0.027310448203934357, 0.022531469876412302, 0.08093186464975588, 0.02486302884790348, 0.037111988858669065, 0.03734864862053655, 0.032062085811048746, 0.016395823331549764, 0.05233289222815074, 0.034463338015484624, 0.03263168786361348, 0.026198631203442346, 0.030905571111361496, 0.08043617679504678, 0.06292991500231437, 0.03949231620936189, 0.061253158492036164, 0.043270831229165196, 0.052617702531279065, 0.03717148683790583, 0.01893307224236196, 0.03763143657124601, 0.02829328179359436, 0.04203580472676549, 0.02770882194454316, 0.014020566704857629, 0.04182577693427447, 0.04647416695661377, 0.04328925504523795, 0.059334320831112564, 0.027101624546048697, 0.01805010575480992, 0.14219411445083097, 0.03220031452656258, 0.07706597287324257, 0.05971704267722089, 0.016588792859693058, 0.052266314160078764, 0.05218919388426002, 0.006826888456998859, 0.03687938122311607, 0.055429766871384345, 0.020261876525182743, 0.03189180373738054, 0.018094948172802106, 0.013080088410788449, 0.036292127188062295, 0.149166680930648, 0.032001482031773776, 0.0836507449275814, 0.036005583970109, 0.07420065943733789, 0.06665833876468241, 0.0343291354511166, 0.03892466971592512, 0.04765968107676599, 0.046137391473166645, 0.06381596511346288, 0.03404640687222127, 0.04457634320715442, 0.017234555962204468, 0.017418092793377582, 0.09633401161408983, 0.02298846771736862, 0.02762239884759765, 0.08159467673976906, 0.051761152790277265, 0.024646514684718568, 0.0254159900941886, 0.025406538843526505, 0.06710694477078505, 0.033727272239048034, 0.007727578358753817, 0.027326775452820584, 0.07079800881911069, 0.023455890877812635, 0.06501244817627594, 0.0034063309749399195, 0.027575159292609897, 0.008308205942739733, 0.07971273123985156, 0.026538119236647617, 0.05784577668237034, 0.03348459365952294, 0.020008909923490137, 0.04770354200445581, 0.021627858695865143, 0.021748875151388347, 0.011318484012008412, 0.05386734563217033, 0.02159725067031104, 0.022216519100766163, 0.029758559612673707, 0.01361161272143363, 0.033274762536166236, 0.04827388249395881, 0.0027186379202248645, 0.03758576109248679, 0.03448200674029067, 0.038918042337172665, 0.06460022967075929, 0.024177878112823237, 0.0406491055036895, 0.06570050070877187, 0.02144070760550676, 0.005586619145105942, 0.04760753407026641, 0.020974182443751488, 0.012690400581050199, 0.031219440206768923, 0.05185232563235331, 0.02392164049524581, 0.02891580454161158, 0.038970924069872126, 0.019060491576965433, 0.030582365798181854, 0.029472237183654215, 0.006612714842049172, 0.028872609691461548, 0.039343207608908415, 0.056031567000900395, 0.021589523057627957, 0.027770162305387203, 0.01899008588225115, 0.02265858307509916, 0.04461889053345658, 0.05069844926765654, 0.041990915924543515, 0.06775058718631044, 0.03993828016973566, 0.04698959593952168, 0.018267035520693753, 0.04645030690880958, 0.0724389567039907, 0.051986179387313314, 0.02156720667699119, 0.011376375241525238, 0.019689409782586154, 0.10833701831870712, 0.03768847804167308, 0.11718673602445051, 0.035146822629030794, 0.008074502711679088, 0.03833937495073769, 0.03745211142813787, 0.008966738623712445, 0.04179041730822064, 0.08297478940221481, 0.10351642777095549, 0.030242914872360416, 0.07313814145163633, 0.033656927771517076, 0.019342932573636062, 0.06416557604097761, 0.03902169810316991, 0.0331180988723645, 0.025410908237972762, 0.04263600923877675, 0.024380742324865423, 0.055717749855830334, 0.02837182328221388, 0.06689073488814756, 0.03772286916500889, 0.02966856864077272, 0.027812856205855496, 0.05346378056856338, 0.17244829883566126, 0.12540968775283545, 0.11040525772841647, 0.24771080090431497, 0.13727216137340292, 0.13815123529639095, 0.17159876239020377, 0.16321638249792159, 0.15999221097445115, 0.15449521219125018, 0.07684122087084688, 0.1066991058178246, 0.1222843628784176, 0.12974019366083667, 0.10574771702522412, 0.0846656912472099, 0.2319802832789719, 0.1414821424987167, 0.14622066635638475, 0.13434208813123405, 0.11524752640980296, 0.18888666207203642, 0.07999881432624534, 0.1501516593270935, 0.14180741098243743, 0.10421446218970232, 0.10926096249022521, 0.1271789678139612, 0.11264425789704546, 0.12499570293584839, 0.18339319591177627, 0.1812586752930656, 0.17014799726894125, 0.09246198227629066, 0.12157120349002071, 0.07771037227939814, 0.15002380212536082, 0.09836736266152002, 0.15370372653706, 0.11920376724447124, 0.1308314921334386, 0.16025420394726098, 0.229346297273878, 0.1536089542787522, 0.12920991430291906, 0.09607296116882935, 0.14330420410260558, 0.10032421312644146, 0.12803917634300888, 0.1554634774220176, 0.10670247516827658, 0.16225831437623128, 0.18605133140226826, 0.09426380551303737, 0.11755271872971207, 0.09195152568281628, 0.14751756942132488, 0.2288829447934404, 0.19878949475241825, 0.21368503686971962, 0.12920391774969175, 0.13644346443470567, 0.10464200604474172, 0.1421515003312379, 0.10393254255177453, 0.1022405200637877, 0.1315281164715998, 0.18712765333475545, 0.0864013445971068, 0.10987829577061348, 0.10486420505912974, 0.12264528413652442, 0.19754730281420052, 0.1354556658770889, 0.20985346200177446, 0.12985259934794158, 0.12155690972576849, 0.14797621668549255, 0.1007916325761471, 0.0735840831475798, 0.14667567709693685, 0.15641764184692875, 0.11777528139646165, 0.14740983926458284, 0.13299747981363907, 0.10226783851976506, 0.18634054635185748, 0.1186785419122316, 0.22397659166017547, 0.08701762402779423, 0.16191501170396805, 0.12449390720576048, 0.19187088240869343, 0.1639977452578023, 0.10834435815922916, 0.11318624834530056, 0.1713053320418112, 0.1577681428170763, 0.16389810451073572, 0.16786234569735825, 0.1319427098496817, 0.18102519563399255, 0.12051878613419831, 0.15807237883564085, 0.0967070521437563, 0.09993258921895176, 0.17016876256093383, 0.09656507187173702, 0.13211249839514494, 0.16507414140505716, 0.16784278268460184, 0.08898237836547196, 0.12592527258675545, 0.16308301856042817, 0.10419593818369322, 0.11616329953540117, 0.11857608100399375, 0.19475470500765368, 0.1075964662595652, 0.11338833515765145, 0.14948537398595363, 0.12615015817573294, 0.07232994263176806, 0.21985001309076324, 0.1595269437530078, 0.12526685401098803, 0.07370497900410555, 0.08015886589419097, 0.13307023997185752, 0.10341519140638411, 0.1751656280248426, 0.13858415972208604, 0.16688774252543226, 0.1580059714615345, 0.09528180948109366, 0.2108210592996329, 0.1731555804144591, 0.10411805720650591, 0.16463968815514818, 0.06297718980931677, 0.10356311628129333, 0.12012008955935016, 0.1335250577540137, 0.2474564965814352, 0.15237546031130478, 0.1516173713025637, 0.13998046604683623, 0.07739350490737706, 0.18299803195986897, 0.12901285925181583, 0.22989345306996256, 0.06635932746576145, 0.08804076365777291, 0.18294416688149795, 0.15066866908455268, 0.23273181170225143, 0.18195391923654824, 0.10109044349519536, 0.11147906378027983, 0.15587483503622934, 0.14561097719706595, 0.06875163307995535, 0.09141155387624167, 0.1511099500930868, 0.08886972776963376, 0.2667692571412772, 0.0760758513933979, 0.13345235696760938, 0.14478968689218163, 0.12044336908729747, 0.15128509694477543, 0.1861312607070431, 0.11030189882148989, 0.1897984795505181, 0.10736672702478245, 0.19941662438213825], [0.04931247734930366, 0.039085782555048354, 0.05818071535031777, 0.04449730447959155, 0.05770662770373747, 0.008340801996382652, 0.1017026040062774, 0.024006371495488565, 0.06272429556702264, 0.0200976448104484, 0.14983839879278094, 0.029550923391070683, 0.06729084154358134, 0.06488156301202253, 0.022957180626690388, 0.053724537865491584, 0.08143204991938546, 0.008745516461203806, 0.0249515299583436, 0.0429825625178637, 0.05996948792017065, 0.03949382276914548, 0.06492726446595043, 0.02166485290217679, 0.020475256969803013, 0.021331752905098256, 0.07371967352810316, 0.03130404504190665, 0.018897753434430342, 0.06159494718303904, 0.06212073283677455, 0.06536242275615223, 0.10153243696549907, 0.047447441684198566, 0.02266481711558299, 0.04786812438396737, 0.044356652651913464, 0.07249608723213896, 0.044008537151967175, 0.03828626315225847, 0.047578148733009584, 0.10546629462623969, 0.045325782484724186, 0.05327671482518781, 0.03165591951983515, 0.065132921008626, 0.04993675713194534, 0.04839566521695815, 0.01523511085906648, 0.06629225958022289, 0.03911220672307536, 0.02975014922412811, 0.011452417547843652, 0.007464146083293599, 0.10249683560687117, 0.07523433756432496, 0.01069110854587052, 0.04615182624547742, 0.01851414101111004, 0.04248837380146142, 0.04076616445672698, 0.06730463064741343, 0.019203449628548697, 0.019804203329840675, 0.028621650599234272, 0.08268250196124427, 0.0313474569702521, 0.042527176992734894, 0.04447849474672694, 0.02639953057951061, 0.009876219264697284, 0.015398808227473637, 0.018027036094281357, 0.02823529594024876, 0.05426338902907446, 0.01123688858569949, 0.06213163498614449, 0.05028315084928181, 0.024231143906945363, 0.0413401303376304, 0.06472717403084971, 0.042806005585589446, 0.030694912493345328, 0.050684337329585105, 0.049546183363418095, 0.08756897295825183, 0.017737557682266925, 0.03465375455562025, 0.02532085603888845, 0.057961329075624235, 0.07835529118892737, 0.05204571076319553, 0.023961445585882757, 0.02231469039543299, 0.06078727157728281, 0.05766331225458998, 0.013926604315201985, 0.03888413732056506, 0.04952974479238037, 0.02441948243358638, 0.05610022308246698, 0.06493451524875127, 0.011723185489245225, 0.031209254229906946, 0.020293274938012473, 0.07315742244827561, 0.04072858580911998, 0.029207674524514005, 0.03589049170841463, 0.023389409288938623, 0.055040094812284224, 0.11365381622454152, 0.046099671817501076, 0.043673078980646096, 0.026369881779828575, 0.057242087787017226, 0.03072826460993383, 0.058542152401059866, 0.03093123643338913, 0.04916990706988145, 0.03635457149357535, 0.01467630891056615, 0.09879832781734876, 0.05465552501846105, 0.02751647767581744, 0.07548982190201059, 0.02150300904759206, 0.02445499791065231, 0.07636295122210868, 0.01693542035354767, 0.0144719093805179, 0.036056944300071336, 0.06417672309908085, 0.01569110587297473, 0.11962938893702812, 0.02060801791230915, 0.045493671132135205, 0.011059646094508935, 0.0849376289988868, 0.01810818623198429, 0.007863996233936632, 0.04016640152258333, 0.03149207928800024, 0.051690678446902893, 0.042578303546179086, 0.07201834450825118, 0.014374436632351717, 0.04446883569471538, 0.0345527779427357, 0.06826190467108972, 0.03530818779836409, 0.0186520765782916, 0.01000425087113399, 0.05169084914086852, 0.0349860771530075, 0.021051640396763105, 0.014502792000712361, 0.03605607969802804, 0.05278192496916745, 0.04333707533078268, 0.031068928947206587, 0.04896596117760055, 0.06954472919460386, 0.0358308527211193, 0.04646235567633994, 0.024826580120134167, 0.03689282151754014, 0.03258631666540168, 0.053838242311030626, 0.06780702751711942, 0.05419291468570009, 0.05150609889824409, 0.05475910656969063, 0.006717444402966066, 0.08553351421141997, 0.015682801240473054, 0.030766577983740717, 0.007799931263434701, 0.018362310584052466, 0.009143894840235589, 0.0270082271163119, 0.05735300917876884, 0.029794887741445564, 0.04812880746612791, 0.040528079771320336, 0.02430554792226758, 0.046589307457907125, 0.016228632302954793, 0.007077877235133201, 0.049403713273932226, 0.0034139507442887407, 0.12131800496717915, 0.02803987361403415, 0.08247988080256619, 0.009416355806024512, 0.06363356005749665, 0.06375953220413066, 0.05526801949599758, 0.02493166823114734, 0.0556514055642765, 0.018598666065372527, 0.04081464525370393, 0.050526074337540194, 0.04397817589051556, 0.01712128010694869, 0.012393227025313536, 0.02177167021727655, 0.03316953712783288, 0.058147808522335254, 0.046011274607735686, 0.024739858308748808, 0.046899554872652516, 0.005621089121632394, 0.03742801389307715, 0.05593665373453405, 0.035176545643480495, 0.0781207947875373, 0.01729567924485309, 0.02129773100023158, 0.06082349209464155, 0.007832499486539746, 0.05164793816220481, 0.059741414806921966, 0.02235974432551302, 0.04621651183697395, 0.05443681038741488, 0.027555891283554956, 0.01438818213500781, 0.009306486408604542, 0.030887221510056406, 0.048309268095181324, 0.06148532083898317, 0.08916854611015879, 0.026434803003212437, 0.028813228600483853, 0.061308300064411014, 0.05516685363545548, 0.05773916716862004, 0.049004575121216476, 0.03785077831707895, 0.04317599959904328, 0.06451575842220336, 0.039995098995859735, 0.0038810012074463884, 0.033301602306892164, 0.06262664377572946, 0.0072845992235670565, 0.025528512669552583, 0.08120550934108905, 0.03357867572049145, 0.022275067130976822, 0.04446425664355047, 0.07043454199447297, 0.03954776948376093, 0.025217556503775995, 0.061130128960940056, 0.04763524957525078, 0.02682920439838199, 0.04755247042339761, 0.022475842197309248, 0.02855061407899484, 0.02016166617977433, 0.009612343092157971, 0.05104692099848762, 0.005840209614689229, 0.03674433632113505, 0.07099323818692937, 0.07903704288764857, 0.02231239715911215, 0.035072886166744865, 0.07425394564052112, 0.013842610824212898, 0.03168945717334282, 0.027581398899201304, 0.01592808846908156, 0.03559664204658475, 0.007688038585911272, 0.09483052432187833, 0.031767271357239224, 0.020822617334488314, 0.03050024159165332, 0.0315525977202924, 0.024893529262044467, 0.03447156472248025, 0.03310730433440767, 0.03746119160496164, 0.01893862721772166, 0.053918535268167034, 0.07212972603156231, 0.08406354230828583, 0.054938524481258355, 0.06804634787840769, 0.04262089169060346, 0.04113482260436285, 0.03866702943923883, 0.04889000607363414, 0.06788046302972361, 0.02672153917956166, 0.034597054473124444, 0.10189132473897189, 0.04309359152102843, 0.03320771320431959, 0.08257419292931445, 0.040351181451114826, 0.045306479223654605, 0.035120201791869476, 0.027393878590373788, 0.04492645508435089, 0.008089700040727621, 0.04901388536382001, 0.01567049272125587, 0.06918068349477835, 0.023778784488968085, 0.003961568527302006, 0.008267972261819523, 0.022510830749524757, 0.07897209754446521, 0.044302809837972745, 0.024978460642159916, 0.03560751451004762, 0.010871894792217063, 0.14153673488181084, 0.05372456755139865, 0.05383103976782877, 0.06535434076795354, 0.06589043856365606, 0.01219485558976885, 0.05224729662586469, 0.027528942046046723, 0.0607379632856464, 0.038849749907967634, 0.05901101903873496, 0.0250162879092386, 0.07135496096452698, 0.030432528037636075, 0.028989230777369812, 0.05733926831453573, 0.030213755890144967, 0.035313679691171274, 0.027963625361735467, 0.06814490508986637, 0.03054761287785368, 0.014695552799821598, 0.02722873403399717, 0.03408332500839606, 0.023913810837257188, 0.03484200773527846, 0.018377982887614053, 0.02670528800081229, 0.0167920207240968, 0.08861918613547459, 0.01097468502848642, 0.12442336606909521, 0.14010165876243263, 0.07848666617064737, 0.09162912188912742, 0.13696673791855574, 0.1138376907329075, 0.1699210930382833, 0.15457410248927772, 0.1627438867581077, 0.1141351657861378, 0.1459015131695196, 0.16154315118910745, 0.1354893742245622, 0.1321092329453677, 0.20364431315101683, 0.14193460025126114, 0.1021538965869695, 0.12653041980229318, 0.07111791899660602, 0.1476257448666729, 0.2278293771087192, 0.16703370813047513, 0.15125466889003292, 0.17668544256594032, 0.0756825650751125, 0.16508270578924567, 0.15224907256197184, 0.12163657927885652, 0.08059441752266139, 0.14746159664355218, 0.14280635659815744, 0.12295308246393688, 0.3053150122286752, 0.1263662418932654, 0.1307153163361363, 0.08853446997818537, 0.16950880031799898, 0.16919773654080927, 0.21599468949716538, 0.06365031033055857, 0.15529028984019533, 0.17607461049919948, 0.10444936677231453, 0.10732029084465466, 0.08644763234769925, 0.12139640544774011, 0.18185882043326274, 0.22852220165077597, 0.09222286229487509, 0.16574786306591704, 0.1203677368175704, 0.08715476549696177, 0.08092069532722235, 0.11140903472551145, 0.15110301843378693, 0.2658630651421845, 0.14873878826620057, 0.11723147268639877, 0.08803259261185303, 0.170315989817027, 0.15312642470235005, 0.19660746183944866, 0.12906313233543187, 0.10558188412687741, 0.10480956072569825, 0.17609420319786295, 0.13356364943319932, 0.08791209009359591, 0.13933738024206832, 0.15027196146547794, 0.15083244623383507, 0.12815211637644097, 0.19909821334294975, 0.14627343305619434, 0.1078695098112803, 0.18484087369870394, 0.16428335336968303, 0.15945692954119295, 0.07329694621148519, 0.12635837512789294, 0.1455028759664856, 0.1343637440004386, 0.18883817014284432, 0.10807446131366305, 0.20806852262467146, 0.18937737011583522, 0.06986086926190183, 0.19258040527347475, 0.16212557384278625, 0.22414976439904422, 0.1480097766034305, 0.1268515916308388, 0.11748047807486728, 0.10029537326772697, 0.26805216330103576, 0.1244535343721509, 0.08890497236279771, 0.08926308088121004, 0.13971799809951335, 0.12413538308464922, 0.17410452011972666, 0.21514895284781232, 0.17019365419400856, 0.14470042136963457, 0.13715784094529226, 0.17609659291338176, 0.09568602021317929, 0.0973268790403381, 0.09312808950198814, 0.1056604330369737, 0.12070476834196597, 0.17151068430393934, 0.14683648565551266, 0.16898463625693694, 0.08703881976543926, 0.1155879718135111, 0.12114400102291256, 0.10660319065209478, 0.13813722354825586, 0.08475710157654248, 0.11268077898421325, 0.13885614200262353, 0.12002759569440968, 0.14272460161009803, 0.10050494835013524, 0.163766180339735, 0.11399104070733301, 0.1190141039842274, 0.28728628589306027, 0.1541382836876437, 0.11161417918629013, 0.11129312610137276, 0.1282469480065629, 0.11001349281286821, 0.2703200181713328, 0.1216654414020013, 0.13177217915654182, 0.10340963272028603, 0.12779358483385295, 0.11519933133968152, 0.23083998821675777, 0.16567213431699201, 0.14260228083003312, 0.08647740731248632, 0.1308569181128405, 0.27596939471550286, 0.129147469997406, 0.12442945168004371, 0.15916655684122816, 0.16645619849441573, 0.18419125699438155, 0.1138871994044166, 0.1048908630036749, 0.20173883414827287, 0.14194966584909707, 0.1404699421254918, 0.11525429479661398, 0.13450691913021728, 0.2033137605758384, 0.15498667722567916, 0.20913455839036033, 0.11619217650149949, 0.14882505551213399, 0.0973455143684987, 0.15926860214676708, 0.07228067144751549, 0.10396969446446747, 0.11859587408252992, 0.1888138722279109, 0.13345053128432482, 0.20670861122198403, 0.0722678322927095, 0.07287392945727333, 0.12893371662357822, 0.22654418513411656, 0.11377907590940595], [0.06786717116483487, 0.018877613401855342, 0.059119072029716335, 0.021519173023989424, 0.02048425179964397, 0.05944160569924861, 0.06265736126806587, 0.08620224863989279, 0.06975133568630554, 0.03662146264105104, 0.02042263684415957, 0.039202904590638354, 0.006859827290099929, 0.027527192432899028, 0.03350171500642318, 0.0358085882908199, 0.01280148246223689, 0.0390449829865247, 0.15452439343789592, 0.027142954750161152, 0.05186150599911343, 0.034718937386060134, 0.06552196966367774, 0.03395649197045714, 0.013898289525968721, 0.02231595204648329, 0.056024958175839856, 0.032072149333544075, 0.037284549325704575, 0.03890467625751626, 0.023945947687025182, 0.03447600647632498, 0.04565276904031634, 0.05648664082400501, 0.02322850425116485, 0.024926781188696623, 0.03899340743373614, 0.02587803639471531, 0.06611409218749031, 0.004161671949987067, 0.04156036266067531, 0.03884833240590524, 0.03718175816175062, 0.032943055921350606, 0.0259069207822904, 0.059821833929163404, 0.011159509485878516, 0.04426461520779412, 0.052177171091898344, 0.09338528820080683, 0.0642565856105648, 0.047908248598105274, 0.011915226405108115, 0.0462034648808185, 0.02004888199735433, 0.027293781422486063, 0.016684004840499256, 0.06035727492417209, 0.06300499808276072, 0.018486497865524143, 0.01121204519222374, 0.04454048634215724, 0.043718980814446695, 0.023500360366597306, 0.05186783651879523, 0.036761209048563614, 0.032040107107604854, 0.11307983178994618, 0.013425978395389393, 0.040821294896886684, 0.016485552696394734, 0.07219987382995896, 0.018265981670992915, 0.006949670296307886, 0.01776975390384905, 0.064168455573963, 0.037476791549124755, 0.03415199964365456, 0.11668721868772991, 0.05448586634884123, 0.07120446825865656, 0.06651824354776181, 0.0859192677307874, 0.04975648575054947, 0.06694914933177643, 0.05114743747981265, 0.0496383172867354, 0.040567061078036204, 0.022461002954514697, 0.034539768093964085, 0.04320661319070496, 0.018420159140077885, 0.04064687906065956, 0.043916098948102444, 0.028971582505619153, 0.024810108152450994, 0.00909293805307243, 0.020176635298412293, 0.03364858974236995, 0.04838324537558947, 0.038922725289012305, 0.08505566016538069, 0.02061383635009406, 0.02687310985493241, 0.022341493058775086, 0.020520555808616336, 0.007704245235800045, 0.06686154622002505, 0.047553602198604494, 0.034466918878024444, 0.02826318028382957, 0.033927169715752825, 0.03975680279836524, 0.027320339177094866, 0.015993610832083505, 0.04188138234894723, 0.041778431623242795, 0.03234872921893839, 0.07175086706411093, 0.008360698047908954, 0.0941238587256521, 0.023892531607998535, 0.01871025910077151, 0.04027064729598351, 0.04314002399041783, 0.0370630701945629, 0.02482343898009276, 0.027816906476800796, 0.04501119350607041, 0.05319585783581715, 0.052749559908988886, 0.08729883120395243, 0.044002559152431786, 0.038987492516753264, 0.07144142116885632, 0.051911437694798224, 0.022091192622610833, 0.034693841662374325, 0.003647800317594374, 0.03218706347979605, 0.03631408362707589, 0.025747795043571386, 0.12016452936222777, 0.028266579320188612, 0.04815690888790414, 0.013291969717101892, 0.05476125137647614, 0.03301588287285995, 0.04223799543979112, 0.01562110279337503, 0.02234846368082799, 0.04037313789012842, 0.04216643013933208, 0.1002621250518132, 0.0756173674017191, 0.017997001377807464, 0.0170030930894427, 0.02983480786497239, 0.07499495783122256, 0.058242313607479446, 0.07751515775453299, 0.05453473306261003, 0.026317126212234143, 0.01185897903269506, 0.03132318874122575, 0.04198395829007495, 0.05098928580991924, 0.07546916051069275, 0.013983712578919949, 0.014302488198154606, 0.008963762611529091, 0.15450349455932155, 0.06591947880224325, 0.040630592629895546, 0.01632036546652671, 0.045810701776645146, 0.07453362399246544, 0.04880634376604576, 0.039984219110920094, 0.03159495950967539, 0.007261348200700013, 0.055336516015813686, 0.046413451855187304, 0.034331105853198096, 0.016287692415062338, 0.03820412966888398, 0.012689462691923836, 0.024179640713555273, 0.017731524021655787, 0.0191165812429972, 0.044112070463597775, 0.04670080772484653, 0.034242500842083246, 0.03631379047874361, 0.0672836130252108, 0.03329011386085767, 0.02718800682487199, 0.021749663683294784, 0.06614456477109343, 0.05675923537637573, 0.06728486725478433, 0.06449606182286516, 0.021939280559308827, 0.03460010470007546, 0.02902892269048607, 0.015156280860537663, 0.05790832859929651, 0.053507381744566374, 0.0258166886123945, 0.0518076668959111, 0.0384909326385241, 0.015861866631894372, 0.10653138044290245, 0.057754663212108426, 0.014301914889074396, 0.01592009368323488, 0.049676582420943305, 0.030239356274250895, 0.02973765516799176, 0.004857388084928971, 0.040646244524396025, 0.024514199030818418, 0.029052352292637806, 0.026458247448317707, 0.05572808797296602, 0.01505872183770407, 0.05698880762793124, 0.038721280434401706, 0.019369490328244865, 0.04726955259684473, 0.03092024151555961, 0.06539752634125762, 0.03588672530895565, 0.0195210201854934, 0.08256056709797122, 0.03987601769040339, 0.13175138417864218, 0.04408179454912897, 0.02154346351744607, 0.03488870366709307, 0.06141254954854958, 0.055712907342240214, 0.06410497968317941, 0.045249638133100234, 0.025779729658097494, 0.01359449601295637, 0.09119554437347688, 0.06084628344979137, 0.05360859584470745, 0.03616261499701068, 0.06354010140057653, 0.08942374843172729, 0.03740953812666703, 0.039010135442367755, 0.04548188953776844, 0.013711727515328676, 0.04321466549299657, 0.07901140168542042, 0.08784841382293962, 0.07083576929289848, 0.025674738026282284, 0.030860932783980388, 0.048717393656261265, 0.04094953430467285, 0.025431762587686535, 0.030501024557452183, 0.026793174984049983, 0.03675963569548912, 0.07778561863233335, 0.012861263385275379, 0.04542321905319113, 0.026657692214939743, 0.06069130446121562, 0.08569332829210907, 0.06290710138273425, 0.024212725656980183, 0.0630356339388527, 0.008688256984896725, 0.02438825471472228, 0.005581913001151406, 0.04435360613570083, 0.05168648531252984, 0.0859043282980565, 0.018090584344463423, 0.10470430192071944, 0.031984702072804794, 0.012942278081027325, 0.08064232315518893, 0.02899912175053032, 0.0584832741151331, 0.041472384764347225, 0.1382229564478621, 0.044381889383657835, 0.01798354624042986, 0.018575037938717287, 0.029169227564125322, 0.03143190224363934, 0.06835266933194362, 0.014528911888191942, 0.05131360063387547, 0.03152178745949641, 0.05277709358779248, 0.026280707170371898, 0.03258362638007384, 0.012513543078966904, 0.010992510487994878, 0.04001862878794782, 0.030443020150414668, 0.02623995955218561, 0.040038351362454705, 0.07960109738633037, 0.06450982866226695, 0.03827715328952763, 0.04778935282956809, 0.02255717230582377, 0.020007644561701454, 0.010744805713329697, 0.014710270515934099, 0.05702700596884824, 0.05629879953630734, 0.05610707310552243, 0.03157830942654982, 0.06535188425914384, 0.047054982860572636, 0.020143229376117233, 0.0088519061137049, 0.06380380131304264, 0.045907759849797, 0.016135162513819523, 0.10677029262296855, 0.055680304794805124, 0.05009930973756127, 0.011712325085682096, 0.05848717781191226, 0.014202596048562555, 0.03233231291233096, 0.022537258628290147, 0.012625905164895812, 0.03351198261952959, 0.009919493895722553, 0.07935134985018522, 0.020181832187518012, 0.035664437236846425, 0.04377529869088903, 0.0051625554988277145, 0.06325995549559593, 0.011972795728070196, 0.1037265223567374, 0.06946710054762661, 0.030402747506741434, 0.057275721919722855, 0.04314125224482268, 0.16518248012289405, 0.1518849452259019, 0.134376315982081, 0.10617791776894592, 0.10428976049297489, 0.1580094892415218, 0.2233844468719326, 0.15774152940139174, 0.15358458214905113, 0.16079962311778218, 0.10083712622872554, 0.15195801708614454, 0.1779642965993844, 0.09993057057727128, 0.18267920531798154, 0.14816317852819338, 0.0881617188861128, 0.14832826185738668, 0.24156506115105003, 0.17292264994466677, 0.13547543669119477, 0.11844693988678046, 0.10814261273480952, 0.16072736761998385, 0.12500799290137365, 0.1867503157700412, 0.14232675108360127, 0.09342042889329605, 0.20297443581512198, 0.19159751973347738, 0.15017304802313447, 0.1846470989403315, 0.13546100934036076, 0.1477945686201565, 0.13586212531663477, 0.081428346602479, 0.23142815509345382, 0.2085506811272353, 0.1602108625229448, 0.10923169218585826, 0.13132047839462757, 0.10987151996232569, 0.1017187828256283, 0.1753428380470723, 0.1376426118076779, 0.1154220498574432, 0.10788260129629634, 0.1460727711673826, 0.11180718953255564, 0.20192667172523215, 0.17488137062173337, 0.1603409758536145, 0.07557211123639718, 0.18678861059015617, 0.1351744364365004, 0.16886362165678293, 0.19965583342127502, 0.14706861460581422, 0.14613607636420056, 0.07004037994192913, 0.14350424258736894, 0.1968218237743713, 0.09207880400936119, 0.10394000113592483, 0.11365109254256822, 0.09489344360190444, 0.19785714946920052, 0.17372373898979276, 0.17738340276991948, 0.1122264658624772, 0.21415885363239795, 0.14138995291432366, 0.09856590942945331, 0.0957238623232115, 0.11250077848671935, 0.1549854304175824, 0.17916071286890656, 0.18756550562102348, 0.19724602054338902, 0.12329886390944012, 0.12153756193583831, 0.13763078197371215, 0.1915509722311981, 0.19062411884078756, 0.20155565725872293, 0.21064583823317662, 0.1410201407270506, 0.12039552282658406, 0.06589719210751355, 0.17960052442504093, 0.09862393795629032, 0.14062007860047743, 0.18193922471255064, 0.07734200728009455, 0.10417865356430411, 0.1577100029680878, 0.1557496198802255, 0.16768176632467657, 0.16403029585490003, 0.0746564197470434, 0.149285216757562, 0.08339368723682128, 0.12069098665961064, 0.12020890237181447, 0.0937222974607721, 0.11048094936995767, 0.147148291580379, 0.16067081596702337, 0.22170912270667031, 0.10078094564960338, 0.10600999201415107, 0.23644145170692354, 0.1503323277574964, 0.1191222868510522, 0.07512861120630987, 0.1902383950073272, 0.15084996091900393, 0.13291125709656626, 0.24746133538428694, 0.09292327158618718, 0.10820382507517934, 0.19614565302617848, 0.14358774904394522, 0.1221601347788237, 0.10117323749000207, 0.08383423351915553, 0.12134021002566442, 0.15051565307658166, 0.2051750075770542, 0.1254006038652733, 0.18462657113559544, 0.14793461188673973, 0.11002896659192629, 0.15301848674425855, 0.12915450555738062, 0.09087018683203496, 0.10071668308228254, 0.12612342601642013, 0.08758316282182932, 0.12527543323813006, 0.11947581631829962, 0.134324261744041, 0.2360902080545202, 0.10907754069194198, 0.1553593689459376, 0.12939312087837607, 0.1171972745214589, 0.15076780517119914, 0.12640131579246372, 0.13855656667146832, 0.1695648324675858, 0.11178323300555348, 0.14733399177202955, 0.18042766285361722, 0.2245994910481386, 0.09161492460407317, 0.1486303159617819, 0.1977173882187344, 0.10944887428195216, 0.19852227705996484, 0.12370636977721006, 0.17250675038667396, 0.0861423573223874, 0.1148617803119123, 0.2710238116560504, 0.13321353384526446, 0.10493490946828388, 0.19126732338918373, 0.07075982532114722, 0.13475172396283597, 0.10020370318670757, 0.2823357156012207, 0.13600592385046184, 0.098586385283852, 0.10407455250970088, 0.1228346950665582], [0.044626872331718914, 0.037092537168064155, 0.02760158160526771, 0.008381880797969643, 0.03795404074480757, 0.03987760217569303, 0.040203683311119676, 0.03030958385352278, 0.0631645301473327, 0.009958121754607419, 0.026005129184341058, 0.03482273416011594, 0.03640917129814625, 0.09649273473769426, 0.005287098547341884, 0.061403640065691434, 0.03359403075592127, 0.01611104642506689, 0.03481006569927558, 0.018476547520549502, 0.06323644425719976, 0.008495174279232742, 0.02549901786551345, 0.015195045089058112, 0.03810486741713248, 0.05135816289111972, 0.030082781668170355, 0.07110172533430159, 0.06829815116361715, 0.05992142643663101, 0.0978497666073963, 0.09157711217994802, 0.00968945316344616, 0.053884351946180686, 0.008038788710109657, 0.038420684650191106, 0.039398289809469134, 0.05700473040633369, 0.057917583180824295, 0.08940996674937196, 0.015928604261716828, 0.027145507738168817, 0.07742876434349455, 0.06324451882392168, 0.026932515065709595, 0.028574531643243972, 0.030842525666230358, 0.029535021021729335, 0.10261393908876926, 0.032477402783115394, 0.04053833254147321, 0.02855912836821517, 0.0687538149941247, 0.02816693486238364, 0.09273459538235329, 0.021729948530264664, 0.027331677338224836, 0.03649316757218912, 0.022594220317841973, 0.02106895284669008, 0.02852998979506083, 0.06713894617860205, 0.046666297857882455, 0.04005822978797369, 0.07122860290110111, 0.021783756092190742, 0.03809236965025775, 0.004805723938261508, 0.01275210181120201, 0.0597699800709961, 0.027234417029831093, 0.05251599119219463, 0.03099107951129554, 0.05390844577050302, 0.02383893370279111, 0.041541697646607645, 0.056124071998056024, 0.06985335872741416, 0.042615885904524475, 0.05414460087195039, 0.013271039297251264, 0.04804955351573881, 0.014221549572539516, 0.024717412052268628, 0.01542604319183738, 0.07801879401085898, 0.052523026752169244, 0.10911827717791311, 0.06327965209493414, 0.049376387396478094, 0.03720992637681775, 0.0236611281070509, 0.021161383629078045, 0.01005749161777203, 0.015781252695887815, 0.03029752024303889, 0.05042121629230678, 0.039093645609682426, 0.03681590904307086, 0.012217764760862337, 0.0380917165603023, 0.038632411960861646, 0.045297573451534845, 0.030117898240860086, 0.012959415198565694, 0.08865889103617519, 0.032028726272983477, 0.0269419867254328, 0.04257883789250627, 0.03211877847206779, 0.02992274679854745, 0.04341744992416352, 0.09636145623517223, 0.01498777344750124, 0.04428936212207191, 0.07629692234331742, 0.031249541716533713, 0.07464380323654041, 0.015233855701808352, 0.02811164486047346, 0.05067346115538385, 0.0002628142925686916, 0.02361880528042093, 0.05815128177346196, 0.0034028509980998933, 0.03263943588535767, 0.0358575663267402, 0.012455606392904883, 0.02284317004523473, 0.03795763273956254, 0.033728248163242824, 0.04902777465758845, 0.01593911863892572, 0.02765737441222882, 0.029685526715184096, 0.07370519422693178, 0.01628489637369057, 0.029502728320949245, 0.017764421572792344, 0.043204947069170885, 0.007777724813422537, 0.0060008080527040875, 0.07854574112570845, 0.08390631832298823, 0.03528872497554403, 0.019389867848076392, 0.05841672573296819, 0.031472059854422696, 0.06916803729836829, 0.0036422499806576525, 0.0702834407275077, 0.021025418463977985, 0.03914172564691398, 0.02666839398443699, 0.02053908166999463, 0.04351362484158017, 0.04258188811945729, 0.018356685104663484, 0.09809158800635487, 0.02080892285448499, 0.033978407591348514, 0.04057175887282938, 0.011780635140894447, 0.087362975027645, 0.03269151609856635, 0.0295948733764817, 0.03325483216030989, 0.04509317484917119, 0.05388498648244422, 0.03073892556130886, 0.026033091453427915, 0.08369833143660799, 0.020793918483832385, 0.0317898066714406, 0.023110758811526466, 0.07320185482967645, 0.05734201426093932, 0.06427307613193989, 0.03452548546192702, 0.023604355665156618, 0.04527992889052257, 0.00910267410290544, 0.015010386687208666, 0.02975300834805239, 0.02677569184015738, 0.0016735650433474802, 0.007486921203962993, 0.04893640143563971, 0.08417420394835062, 0.062406552460743114, 0.022271191264735535, 0.004441544651854201, 0.07645776800927706, 0.04888802082859911, 0.013221558456280036, 0.013088290997984586, 0.05954236337856855, 0.06521994524518959, 0.03624413249781355, 0.07157669984735548, 0.024936312220233958, 0.020894390436296817, 0.04379240519483574, 0.047953155954019167, 0.012006452125206124, 0.04571011108055245, 0.08795788060524501, 0.03593655310396571, 0.0326669398782542, 0.023128071261453442, 0.04090540991455782, 0.11221623164601624, 0.012201200952404179, 0.03523798433889169, 0.05889510670385789, 0.05471226220834069, 0.033715739264152944, 0.02793226405628957, 0.04962359307683073, 0.015191566271823831, 0.04571332086925395, 0.011354254602338187, 0.0022754333576813224, 0.06188545346958563, 0.027150140595040284, 0.02766998906736262, 0.02811318110616412, 0.007335736909226398, 0.08272656326880679, 0.02823460574290948, 0.05041515294578858, 0.03401936301088426, 0.025025312424986623, 0.005743139017795329, 0.05824764593853615, 0.035918084759032354, 0.06293611193541437, 0.07704962335992604, 0.04213238040392753, 0.03441222259425558, 0.035998117964481935, 0.06322635847027414, 0.02328850132471416, 0.007071872332744533, 0.01991223220102256, 0.021767545731563587, 0.04112724156584591, 0.05659374757669866, 0.021470801693794783, 0.0388280903280247, 0.0305000467778882, 0.021791791696159635, 0.04766365156683605, 0.0331256019853754, 0.010736063213698799, 0.020515722571872175, 0.009894486302073346, 0.03985323375673033, 0.05252429953543469, 0.014499172175419517, 0.05439052634756081, 0.04578412546834443, 0.05602701392490417, 0.03456496029684786, 0.08275236774352379, 0.01659452223975677, 0.038262926318566315, 0.04201010044198483, 0.03248033426643815, 0.07319749842281453, 0.019215943684685044, 0.04097723125596531, 0.04550538593321107, 0.05992420577968005, 0.06424428822356276, 0.025525889177515637, 0.011593281815294176, 0.028227885595697444, 0.021966806816635653, 0.013447277106024558, 0.004282658719603205, 0.04306359391193837, 0.0814048873144202, 0.055438568742829375, 0.028933601242897566, 0.007782318243698683, 0.03167223563650623, 0.027616817897069268, 0.041408660254091956, 0.0279260819661431, 0.020944149582646787, 0.08601032925071195, 0.037482313127839006, 0.048365077600465156, 0.043376475950935856, 0.045122259616618976, 0.01707255625660764, 0.04610780946677551, 0.039769634531694464, 0.04254261737514753, 0.019112007757939864, 0.026756099141493905, 0.0284504538285546, 0.0024693038994882954, 0.035596797897596844, 0.027097132697235793, 0.021046809015388135, 0.11036668831366114, 0.06545554744661786, 0.010009573925344739, 0.06797424081014469, 0.008622469304100377, 0.0335451566206757, 0.04964485931850504, 0.05923648350290023, 0.0028737920092680724, 0.0036439694440559833, 0.047816901351325214, 0.11969455692451447, 0.048190368615905754, 0.036770504448213615, 0.04686599124397617, 0.07600475364597514, 0.05643706906994339, 0.08773948880843818, 0.03900542651535943, 0.10561554052401334, 0.09151733960607089, 0.05461497035867069, 0.02815435731463367, 0.03238316116039641, 0.024979379049909767, 0.0395940312591847, 0.020117539934290107, 0.02464457953465171, 0.008750371962378267, 0.05795116907393094, 0.01758497026457917, 0.01860938824393088, 0.048387167626060545, 0.041748411749722436, 0.009628519128455082, 0.030349155167641584, 0.028291695452935528, 0.022216851211851463, 0.06927466165507212, 0.027203259814996272, 0.09405557371792383, 0.03824657680524979, 0.0034513280843384564, 0.0238532775620115, 0.015360232318926137, 0.1218553792568855, 0.22496339573990554, 0.17103242949815467, 0.05901586155232508, 0.09719079884234816, 0.06920904837897979, 0.07160139852203429, 0.16447908739792183, 0.10550647450145334, 0.08723223829292692, 0.09596449628588744, 0.2041055727750063, 0.18021738273091614, 0.16690185817424208, 0.06495665351394564, 0.08238395079388283, 0.20782014064025134, 0.11423636504332535, 0.1408458547666669, 0.1654484510072507, 0.15104974707355723, 0.12696237943600863, 0.1777316036168486, 0.11061213881475851, 0.12174662493634969, 0.13240800675703213, 0.21777032234240323, 0.14927046286175027, 0.22282265592366457, 0.1511822352767922, 0.2680224773939699, 0.14384442823939025, 0.1673704502172768, 0.1386003236984834, 0.1424056859104894, 0.21034002886153758, 0.16304279415635392, 0.14784325350774452, 0.1696104893926531, 0.17677824071142823, 0.07685003016376868, 0.11342991769197397, 0.09793531397008337, 0.13376463786698878, 0.13460313115501776, 0.1232311429339461, 0.11994016327662393, 0.1412603590870276, 0.2521381719270721, 0.06774371489882469, 0.15398525283671916, 0.11391371634090319, 0.10348942843847908, 0.10803098630276509, 0.14093733188929036, 0.09866638880339451, 0.1519384392304346, 0.1101874076994136, 0.18432709970511496, 0.10024852148490027, 0.14645877701696008, 0.25607392948586494, 0.10115872850292362, 0.12237427406944335, 0.14395255915587768, 0.1798933165264316, 0.15082784491823986, 0.12195273418910801, 0.0881328790273983, 0.18265771272126585, 0.09893848982756026, 0.11916812931303866, 0.10551325773121789, 0.14062919217394665, 0.1967560694902204, 0.15827302588149905, 0.09401100032846443, 0.23909589130198583, 0.11228980074520223, 0.11586727909161709, 0.08541984687326476, 0.12176662581623532, 0.15257505350746214, 0.23367821326246485, 0.10798951509059407, 0.18707988871028647, 0.1501476368866861, 0.2410471162875183, 0.1586069181212224, 0.14361149776959792, 0.1305003309971653, 0.10899559274548665, 0.15266154339769855, 0.17384362552547827, 0.1804695645114407, 0.23502498865127563, 0.19247742486186326, 0.17382422578521073, 0.17395839124219492, 0.17432112334063277, 0.11844729611766525, 0.13177700311644003, 0.09851373644778505, 0.1595849054865539, 0.08305211376864463, 0.24258741410449147, 0.1479062024736777, 0.09621548320865259, 0.09905917046125978, 0.10403391992440447, 0.07334877038374543, 0.19386157480766997, 0.1080639153951779, 0.0678675645031035, 0.12392457603709772, 0.16128378541907296, 0.11547938818694092, 0.16619013855233788, 0.12294744214159437, 0.24860269913915545, 0.15355465875472873, 0.10492792585864663, 0.10914288679487072, 0.13091867964249104, 0.10702328334446065, 0.09535669218166731, 0.15598925936501473, 0.10287423254339956, 0.11183667505974881, 0.14518842799589038, 0.14623301569372416, 0.19146241917042062, 0.19561129185603932, 0.09632687957491726, 0.15031365532195196, 0.13584933069068938, 0.0985887527349405, 0.09522400359855965, 0.08328214244102128, 0.15850962256081402, 0.11424924872699194, 0.16965105518465862, 0.1860005091293715, 0.16264399368083104, 0.06477811504737474, 0.06298523469013162, 0.12405732399201952, 0.10208773412159644, 0.165885531459935, 0.08539238740922883, 0.14430380280828103, 0.21235441061435267, 0.1802511652931571, 0.08887887102901004, 0.09142123890342191, 0.12202333469758742, 0.2103044354589656, 0.0772597773175221, 0.10694777723983862, 0.1450162348919548, 0.17892295843921602, 0.16752538096625358, 0.14597906760172918, 0.13282482657814398, 0.12035509062116034, 0.17378995340550318, 0.13350558379897848, 0.1719014102127403, 0.1159648344037123, 0.121323348430451, 0.17311571224126965, 0.23916826554341242, 0.08104609602014534, 0.1090791956812609, 0.09944562902092002, 0.16074580256827176], [0.019829785160254687, 0.005491544925462222, 0.044149586028652266, 0.018446507237968035, 0.03361760878760833, 0.009369028121000156, 0.033763641185942106, 0.060811881194240414, 0.028219796186021995, 0.06490188301540911, 0.020883838951704092, 0.06961125531233847, 0.03585486861993559, 0.023271546961041167, 0.02838094613252906, 0.01879699389974121, 0.06235482476768084, 0.062408125813817605, 0.03649262209364679, 0.060877294090460055, 0.044450994464568794, 0.012613848975888686, 0.009910691096592927, 0.048320986606995575, 0.019456095251371153, 0.035658767228596844, 0.028319069569988642, 0.015003728694864549, 0.03784507491218392, 0.07633892048033886, 0.026635557660483755, 0.055098394223023206, 0.0643818972457666, 0.0739004607021343, 0.037287454833858646, 0.03068824800720904, 0.013395716396189528, 0.035320841416250914, 0.06607233895920217, 0.0162893826563959, 0.004934352509735618, 0.031418821890838444, 0.06714221904985607, 0.06857672371552326, 0.02788101319310954, 0.0227050285320729, 0.06498854359961115, 0.07539008467574604, 0.023633262317162007, 0.050880101043730974, 0.020583632795023732, 0.04474997607758269, 0.011303784849587828, 0.00923771622183267, 0.05412087069998961, 0.06969618669245392, 0.047754624029039405, 0.05157666601007804, 0.035281685704831034, 0.07910745043773204, 0.053800337118445896, 0.013359278800635366, 0.017245730850845575, 0.09683588898042217, 0.10528426064411178, 0.031939950567903, 0.04427939507877454, 0.022176639795361552, 0.06452883506426588, 0.023460225020244252, 0.052933779516024515, 0.02539994671678869, 0.03997356187028345, 0.027154172312293667, 0.025242375777452253, 0.01843857367930468, 0.0620339201122988, 0.07923858051071875, 0.04194597146124579, 0.03418036823859438, 0.04765923949889839, 0.03618625982198864, 0.03700336441397667, 0.011356217582942918, 0.0377379162091529, 0.06525680029881187, 0.03839850556687452, 0.0367022528371308, 0.01788918030797504, 0.07190161210019141, 0.07566029322333634, 0.03659684931335505, 0.02353924519411521, 0.02187697169574676, 0.02107425178110134, 0.07654754561372101, 0.008110989474516828, 0.05739894440921489, 0.06282466361881234, 0.031236565264407545, 0.017907116161950398, 0.044581107795238495, 0.021783182783110533, 0.0021265156283334363, 0.12394315199344419, 0.01000622498395387, 0.05183977591514122, 0.03628033446148038, 0.02238990335172275, 0.05698134904378094, 0.03305448197352234, 0.050543024990474805, 0.005828622370245284, 0.10149639085284434, 0.04423827638674993, 0.018839897456928156, 0.02386869011388626, 0.02673215560207609, 0.03781650222663302, 0.022635107088717632, 0.028030266512359958, 0.029103245069563854, 0.025654228775238153, 0.07336687136557885, 0.050846637604990974, 0.04877708088315558, 0.017164482378575485, 0.027588159864535555, 0.01650449601584114, 0.0376585732010426, 0.041257169359596446, 0.041161551052937284, 0.019966974869021215, 0.04874992941040546, 0.03640524533693679, 0.020850874607276637, 0.06793240594561212, 0.049629073837422766, 0.02937480061518727, 0.02640772388986079, 0.018822913407348096, 0.03387530472537037, 0.05164692513062619, 0.03678865738038439, 0.02223072195192799, 0.005742904777434887, 0.016163855798367877, 0.0036844962733084685, 0.0146911258889304, 0.05285146791720763, 0.008767033177718986, 0.0339287467795657, 0.07273064300534315, 0.005101812103021075, 0.03988598102296237, 0.056183833439718, 0.033806949213612825, 0.04598931074724533, 0.06140849000075832, 0.043991827697027475, 0.01590936222783057, 0.008758286039665109, 0.017876606470963452, 0.02636230259668082, 0.07545998756540939, 0.008369085244339658, 0.004567597507048049, 0.019140719596180134, 0.010004208197642583, 0.04164148682320956, 0.05918394686887041, 0.03457647100731265, 0.03110936300799949, 0.025965407585317735, 0.016858231429068837, 0.031832661989028566, 0.016014097818697337, 0.016155096600414254, 0.08208487270167097, 0.0037950855539747863, 0.03607841092161834, 0.03483382555714343, 0.017534101607452612, 0.029837509282515384, 0.01699283289781306, 0.04614460514858365, 0.032963182966341265, 0.08500898649799637, 0.024592085574113298, 0.04215678964101244, 0.028000576894555707, 0.04416187228343915, 0.028117504116380587, 0.041879152195178904, 0.06646171415923163, 0.09128606412559748, 0.02552720092353411, 0.04346277659351472, 0.055768817037460394, 0.043950905674137175, 0.0519550425815396, 0.025234666718461085, 0.061349303723545745, 0.04021838525659405, 0.1251632353523746, 0.056032335123745725, 0.02271689361805329, 0.04205802091746591, 0.07785576643073, 0.030723520430910867, 0.08571512516937219, 0.048309431367670186, 0.023605468886671588, 0.013590624785138061, 0.03454473306192085, 0.02959513683890691, 0.021874184931220952, 0.04878856932919007, 0.07606768776895478, 0.01731521071633324, 0.03565878578228876, 0.06222609925316647, 0.05041294505645055, 0.021805664291605353, 0.02751961881585885, 0.032916969430516474, 0.03565542014257517, 0.027758916912716813, 0.01321444868153776, 0.04481846888666041, 0.0499195912561845, 0.030995203997008502, 0.042961993895005435, 0.009559511454426683, 0.04540812748018652, 0.049115073488792405, 0.03446488539339043, 0.013295561711856863, 0.02769132210232783, 0.009077104332391173, 0.025745186394487973, 0.06850211560958996, 0.045118289126548916, 0.03893954235536512, 0.0362976153701311, 0.04188476283161435, 0.056503691666875966, 0.04888562369160354, 0.04036101861856878, 0.07502364926040173, 0.028055312141077593, 0.04356814672064502, 0.014731264946021838, 0.059133874165127054, 0.03199476188456174, 0.021577335137408227, 0.047772765828995034, 0.024178371641028207, 0.039081377908587456, 0.05437564257590566, 0.002571078321125242, 0.010727574899647152, 0.04633554119209293, 0.03692585822136607, 0.06861313348053955, 0.03806847620580811, 0.07203019660664722, 0.045219425301183946, 0.032603452855255455, 0.010757759901025565, 0.035287953141960315, 0.05308380466885865, 0.022504559601657093, 0.03127532392682042, 0.02748237042396795, 0.047134084670688026, 0.03090385489485925, 0.02295584105013404, 0.10188415559241548, 0.05237921708612703, 0.07292318579857238, 0.027733733986679, 0.03335020555823576, 0.056731070872046985, 0.025739599877852015, 0.024470464268233627, 0.04312220131396316, 0.014577487308997661, 0.011591877300816122, 0.04882446701230947, 0.02725036392803304, 0.018869809719035402, 0.05730515920731705, 0.06612080862396397, 0.011744063031073892, 0.0506647743168287, 0.006654183271166403, 0.03620334777224343, 0.020814425879507326, 0.02827860582328867, 0.09188314419589005, 0.018820605328073725, 0.028108492588216905, 0.05829431589518208, 0.046937229999457486, 0.023992335627553985, 0.06264880430535413, 0.07545711545390077, 0.025537548317515757, 0.029572568128060084, 0.026431383557792287, 0.03510190043016337, 0.03667960991151631, 0.017268783813051414, 0.017649459186941385, 0.11155116342706606, 0.022220860664674547, 0.0485376306460239, 0.034386106417514384, 0.011940796175622381, 0.1328060353989713, 0.025153177048196085, 0.07623114579473622, 0.07220356972538866, 0.030961477095843293, 0.02737238784902729, 0.023726557701593265, 0.04522882831224706, 0.046827280821162276, 0.041201523126801476, 0.027253139560343698, 0.06890930235385895, 0.06225266071851365, 0.03235075157135725, 0.0704197509912774, 0.023984776853467338, 0.010331718895031372, 0.005509901948244078, 0.021572628065769095, 0.06227667661732994, 0.03142877038044389, 0.018275772454217076, 0.015300473660317948, 0.07152750287787057, 0.017745064506016206, 0.013957062983536161, 0.013041134934610454, 0.05177277482289355, 0.005852957856404828, 0.06374366508680396, 0.01425025584467221, 0.04169453553913627, 0.0623786699725315, 0.1403556959121488, 0.20551330817397684, 0.09612382797058672, 0.08811654435703531, 0.14657471532700583, 0.13028577610384673, 0.10369334093411453, 0.05110555066494271, 0.1267962422571145, 0.12002094605122693, 0.1843714207643643, 0.0895063865755219, 0.09927814855473116, 0.09530700539471582, 0.11205259550479241, 0.1587196355103515, 0.13627628824906424, 0.17182145122205839, 0.21182827244047076, 0.15021904633613303, 0.04745684469526168, 0.13583669933723286, 0.08643384324386716, 0.1230140721600037, 0.13045264058746397, 0.15354259143350646, 0.10945245885523036, 0.2711579919559881, 0.11071505985455588, 0.13427088648313656, 0.11590196707402356, 0.19521005713613704, 0.143209298257716, 0.1387492727371864, 0.12098540406441316, 0.07369099694187753, 0.06731460511218756, 0.13024553685681894, 0.08377384496270679, 0.09996204506023787, 0.17926284723216668, 0.19862656365148723, 0.17336480668745935, 0.14419852173887193, 0.13325148727744818, 0.21454769448610023, 0.11279756334261037, 0.16383907408453524, 0.1738774377736263, 0.15180847432930022, 0.18278954783454537, 0.07454775448422879, 0.1514450297690928, 0.17638200806686655, 0.20828804990742356, 0.13071920518996194, 0.12404673354467377, 0.18882221396779642, 0.26634207693859935, 0.1188517220725771, 0.22607415332458913, 0.13632123271236196, 0.16058720560977235, 0.14952303055906668, 0.10411255047074519, 0.1496720389695838, 0.11817207065178081, 0.1730186986969784, 0.09329665350378491, 0.1850720081711188, 0.17092219088226557, 0.13535424397559837, 0.21483208547579125, 0.11814353507361375, 0.14720316597959027, 0.11910596702364273, 0.18386569165159017, 0.17187298595672473, 0.09417089604539797, 0.11435552427428775, 0.0934743533434812, 0.20046413614181802, 0.08214539484470151, 0.0817729628761299, 0.20011779066408053, 0.12477990123443305, 0.11752015328966081, 0.18349323741858825, 0.24697076092706993, 0.191249868075829, 0.18602982396259904, 0.12441153623512946, 0.09691449726233259, 0.07563510473119095, 0.15048265719087794, 0.11109221188235097, 0.0951094827905763, 0.20178600505460054, 0.10565977994701825, 0.1763568344176747, 0.16317195753799751, 0.2157710655592382, 0.10160975391045213, 0.1666378168738447, 0.11117472386104055, 0.09623031131923199, 0.1726378730381839, 0.11585232481593266, 0.1625431506545283, 0.11690428204019554, 0.14387159084435552, 0.13489792705513537, 0.17081604892155156, 0.11902573343832046, 0.06511493134894408, 0.28516386228147894, 0.11800874621258117, 0.11717443863744847, 0.12976732657989487, 0.1104263644083403, 0.083032335533062, 0.08641091830213554, 0.2211550500942394, 0.2548597165150568, 0.1945989578962326, 0.08062020715442486, 0.16112135897856206, 0.15903702238574624, 0.1085137014160864, 0.16593206411926076, 0.11581898754229769, 0.1380574278300628, 0.1302028782083653, 0.08366148380446248, 0.10291056809364818, 0.14785655279411003, 0.15258712082868442, 0.07044737372780219, 0.23669902147958055, 0.20733499870402738, 0.11896221301867627, 0.12458563665859401, 0.17383433383656666, 0.2531830861698836, 0.10494577451026998, 0.15541584638413042, 0.18451648094924167, 0.15684615791542456, 0.13157650450011715, 0.15025759348645806, 0.14851725718472153, 0.16790202091215178, 0.1594212619238533, 0.10118425838300027, 0.22287140018306673, 0.20786147826584056, 0.21221049333689734, 0.22338195325573906, 0.13728598016314209, 0.15246392431436107, 0.11664636345813051, 0.170988405297976, 0.16712825774447992, 0.1620544760953635, 0.05598281532002147, 0.1363222420332022, 0.11553405478480272, 0.12586113618453965, 0.1640689914347604, 0.14435904828133062, 0.10401843130239286, 0.1458615410956554, 0.09968903119442984, 0.10058077357825823, 0.20169997529592365], [0.033320215370622464, 0.030009231122676283, 0.030820673127891496, 0.03831493231700733, 0.054391338999266736, 0.02946580461866688, 0.0642157971742563, 0.04891135395155288, 0.02066319288132945, 0.003071329224439978, 0.012236883412697352, 0.03661407085019164, 0.04010766053397674, 0.03344171607750468, 0.042611982207745314, 0.02343310694413958, 0.067965142079629, 0.014427022433665115, 0.034526079180068336, 0.06146831452497281, 0.04358142745331861, 0.05563407270528842, 0.031896249201963656, 0.03916483241482638, 0.0453153775742976, 0.051244399073766544, 0.06456190516473725, 0.055017741324263625, 0.02313999200850958, 0.03450047137448564, 0.01640851220145123, 0.07225783556350507, 0.04752207576530054, 0.02207160920079332, 0.03340078292239923, 0.050721600564429536, 0.03701988091052044, 0.03438190215092618, 0.024144115959643386, 0.040167878396459855, 0.03468690258159768, 0.021831084704899695, 0.05208764581766445, 0.0013249861649455852, 0.05814041673147585, 0.02259268963825889, 0.05165665097592864, 0.004986731901226449, 0.05700075991626363, 0.05939839415077586, 0.050250529748154804, 0.05909188344958238, 0.04885390429990366, 0.03404177587071899, 0.042475950249354355, 0.0564360708813183, 0.03475356599665247, 0.04307721603254322, 0.03974260551331099, 0.015577108279103413, 0.017173848282254767, 0.03378021334356163, 0.05741605462389998, 0.022132981102913618, 0.04410993307828903, 0.020878276554867625, 0.042367333226138726, 0.0692001277639065, 0.019750058090721723, 0.026043537181976717, 0.03884164194460027, 0.03200569000910036, 0.01778352259862004, 0.011132185463793576, 0.010697756333684083, 0.01098142836781335, 0.024949134676717222, 0.026221869702567346, 0.009692294661363121, 0.05490975141583476, 0.02565237711678492, 0.03753492026589811, 0.021089673609822057, 0.027984151311102323, 0.05739095890021417, 0.02985746192280203, 0.018877101319958456, 0.04694046205258928, 0.054577406554017216, 0.01989578435313888, 0.017565947164257523, 0.037744944347650744, 0.02628868711326504, 0.05847949658345897, 0.030800293752690777, 0.0715152129123453, 0.05604287733149249, 0.03465491972747259, 0.055248623466468416, 0.09772872974281199, 0.012801024186046561, 0.03087255852733506, 0.059050516138086095, 0.10206681297859177, 0.020304709578340407, 0.04017245373688638, 0.0175844099430833, 0.034427614737069234, 0.03679388952150475, 0.05031456224969588, 0.04329257986682933, 0.03480921222944744, 0.005785984130852739, 0.048681280750315636, 0.026497852159081958, 0.0483336402248824, 0.03297351737273857, 0.014809750773565611, 0.04742157041619066, 0.03889865372912027, 0.07423946633934975, 0.04876305058132857, 0.006434127672036993, 0.016355018196918536, 0.014744066993443994, 0.055831454301369376, 0.01081637750758091, 0.04244250165356789, 0.04854476639593486, 0.07270180314662866, 0.039263359940377995, 0.05832734517753124, 0.022569308275706135, 0.01969657707377337, 0.0056621438034198945, 0.01209405338158831, 0.06082689855247736, 0.04665443462727126, 0.05822601975523867, 0.018691742516239174, 0.02608610306197079, 0.00990690150501905, 0.03487269925244618, 0.048028721430455334, 0.02162845241400646, 0.014669188003608724, 0.01888487531687133, 0.04283784372091759, 0.0632918975315988, 0.024071012558124494, 0.07050554326269776, 0.028471560508478433, 0.02840154444129439, 0.0390388751111459, 0.07150046643801033, 0.08041979017434642, 0.025878309133986477, 0.021971762507746462, 0.03233386029023677, 0.03884029865730554, 0.02705480615986744, 0.02210874627053272, 0.05501671344973147, 0.0021969092631479725, 0.04229455080348998, 0.056941339862532914, 0.07886933977715671, 0.060106169257778674, 0.002357599310016667, 0.049265577326877974, 0.034136878384742886, 0.0212672509951517, 0.055319873354164883, 0.05148979020304978, 0.038260239743976854, 0.005595819457084872, 0.03692227735882625, 0.016768938075983897, 0.05184777626709547, 0.02618374001031043, 0.0333802291424945, 0.029706156565225683, 0.06389349728124216, 0.017142737451649737, 0.034490949619794264, 0.02361023533012485, 0.048668230083421804, 0.019685107181430794, 0.046672253592987545, 0.08891318793757819, 0.058636219619074836, 0.04905049550870899, 0.10264914657454938, 0.02168794297176646, 0.04761578304169234, 0.05331588166882284, 0.10570093945716508, 0.06411586698959582, 0.019716323768079747, 0.019567254130379297, 0.014615475065511419, 0.038767631267546676, 0.15473118546651676, 0.07809263028320856, 0.05908171602641232, 0.03851174988085404, 0.023853763668739703, 0.03934691092581488, 0.10537680645938963, 0.04010665863461327, 0.07393202424282208, 0.019482697534840554, 0.021123879196238704, 0.026465336813998874, 0.048569242426310666, 0.06267634540563449, 0.02004603771638358, 0.03677149521536194, 0.07069145125569776, 0.046514220666722395, 0.012327158256084658, 0.03651791819720529, 0.03546989435562864, 0.05215193064941559, 0.020217869023326784, 0.01770842653058935, 0.08289479330414906, 0.022102627262938768, 0.030460586785920896, 0.01698710537311854, 0.012254841531103011, 0.11334707916830666, 0.12705931876553223, 0.04141081248235423, 0.04033446457469836, 0.014640458539361134, 0.013261560216051294, 0.013514015663531609, 0.06729647444444709, 0.029476048111973796, 0.05508522852323949, 0.046411926741711795, 0.010340435419493588, 0.03640647359134164, 0.05294798051181715, 0.04677457349316683, 0.04332490781962406, 0.031238546798704192, 0.03230580339732114, 0.04215411048789974, 0.0808122823946178, 0.028979219205211848, 0.01913420910568675, 0.0228268205319182, 0.010039751505246386, 0.027815939829451963, 0.028357789269648492, 0.024594883470854256, 0.03802336104854476, 0.03474144672509283, 0.07306931467610411, 0.01862097873527091, 0.026652658598322887, 0.049523139678058214, 0.022535859679919668, 0.019080737365584355, 0.03289995940576773, 0.0541540484118741, 0.02577561630459968, 0.052978831590735354, 0.014060685352887958, 0.07061357769998722, 0.11940516385948285, 0.0626636843662709, 0.07499560349970125, 0.10571706632617861, 0.05262505350401625, 0.033823142875917256, 0.03148707721265964, 0.07346971076913178, 0.10019444118370302, 0.07903722100309096, 0.019330230716150254, 0.0290541464346461, 0.0281936132159899, 0.037882857650402, 0.07778821614920162, 0.06794319677283056, 0.016872643936949316, 0.022349812534230296, 0.005275877738313284, 0.020093542589165736, 0.060510713956318796, 0.02871790715289535, 0.0874982240202371, 0.08078387298155576, 0.008049319785641273, 0.017396807998011354, 0.024597200826974586, 0.01184032422315795, 0.08619846368674189, 0.029570916849479545, 0.032804151851451024, 0.007826259879948338, 0.06413908879039809, 0.02889529900130583, 0.02842864952981472, 0.05472627766721416, 0.0201784925229731, 0.06959944032132626, 0.060556144526344724, 0.11929399755899794, 0.03363328294653911, 0.11785446855355985, 0.06346488473354839, 0.055802213682909496, 0.04834493942325935, 0.0645539716060739, 0.08106311346637085, 0.043950423278147355, 0.019193131920474116, 0.012971184733032715, 0.044571582329808734, 0.03293790541647468, 0.042441154655534774, 0.028008306362607982, 0.02089836649247445, 0.04567518932162784, 0.04469052262720652, 0.01106757037632633, 0.06132128764875233, 0.047222081120708026, 0.07090907864039764, 0.05113561135658529, 0.024551985479774885, 0.013848717771907104, 0.030718642665306106, 0.029097293045197148, 0.024759361949691083, 0.011957808983424911, 0.028243864035175648, 0.05623366865620483, 0.06849987432360649, 0.004198835922579747, 0.0051944701681350125, 0.04602946835802868, 0.017445709963794798, 0.04835062427446246, 0.032955998976831324, 0.025297940374002792, 0.010209694046352524, 0.06350764728267677, 0.16613152372883633, 0.07849428060580976, 0.24726416158955544, 0.1634826502413489, 0.1583478195243515, 0.07305000399355777, 0.2211740193888545, 0.1598514849320054, 0.25618038314860314, 0.09467729309108108, 0.09121749710175209, 0.06557308879564516, 0.09534055046970025, 0.18095782346790656, 0.2152120799291879, 0.15258112427545711, 0.23680980928475037, 0.10739874327555299, 0.19994258444057778, 0.16046777920564637, 0.2464714291272685, 0.14850290404865518, 0.17509341705590487, 0.06644253706326708, 0.20363984542200342, 0.12421340506989509, 0.20398669556016102, 0.1335547585040331, 0.13113667810102925, 0.13224605529103428, 0.2304180624196306, 0.14066499337786809, 0.1562866973108612, 0.14200001314748079, 0.20358911220682785, 0.1211411808617413, 0.10873224164242856, 0.10239737297524698, 0.11872367191244848, 0.12709335365798324, 0.18559914082288742, 0.10431958740809932, 0.21821187052410096, 0.07300744924577884, 0.14320508285891265, 0.10137573990505189, 0.14828817103989422, 0.09637882991228253, 0.23950462171342224, 0.1373620651429519, 0.31975738413166255, 0.13848175818566233, 0.11005991415004246, 0.12995100812986493, 0.08614647624199279, 0.20754048455273733, 0.20240363519405946, 0.11130636601592414, 0.09741451183799654, 0.1118644981761463, 0.13216023333370686, 0.2505167870549485, 0.1548350416123867, 0.13722886447794735, 0.11851802279124968, 0.1873910118592903, 0.12927020638016984, 0.17292603413807228, 0.1224628568161279, 0.1155532467237208, 0.17635676020290703, 0.134886497980915, 0.11761013127397746, 0.08887018790119328, 0.161850088625215, 0.19397271884372458, 0.0639516297087539, 0.20291420310968533, 0.12861468218034133, 0.1938642465393059, 0.1101279171416536, 0.10446496671647765, 0.1513557048747316, 0.15852393116801977, 0.21623287437250838, 0.21703613048885018, 0.18831405061064288, 0.14673543482786044, 0.2181541165919043, 0.0744125054916367, 0.21880704327486455, 0.13412201165920123, 0.09136132532148622, 0.18517604243243113, 0.1476907718461007, 0.16047674434958026, 0.19766787212574854, 0.11131284496514127, 0.14275517809437588, 0.3649679815862328, 0.10640857726684771, 0.11597561780945398, 0.15365781728178263, 0.23195957735879347, 0.1923322310904041, 0.11596650423598476, 0.13787901552859694, 0.10838479036465287, 0.08410380381974392, 0.1401945756515488, 0.1402527600293979, 0.18592129228636622, 0.12356155450106598, 0.20470852323342115, 0.15343628620030358, 0.13090247113723308, 0.23025324626360089, 0.19863361405441537, 0.2173746982589364, 0.1621721510309726, 0.14682637760415673, 0.1393904586439021, 0.12748753797495738, 0.07155333703849465, 0.15913379844278097, 0.17840358865214512, 0.07251199887832627, 0.08479938172968104, 0.18527250678744167, 0.1527654440724291, 0.14540213684085757, 0.15143694035941735, 0.05272965550830122, 0.10642068169545382, 0.1396501064300537, 0.20788868539966643, 0.20741624903166667, 0.224142461665906, 0.16206111089559272, 0.12251255102455616, 0.1177546422695741, 0.1458572514820844, 0.2113707532407716, 0.15588290960295126, 0.10867799064726569, 0.1762303279247135, 0.16121035732794553, 0.12947374780196697, 0.1437302413978614, 0.11870551155880094, 0.20304437581216916, 0.16916224703891203, 0.12616899388376623, 0.21281972236465663, 0.1828604971524328, 0.1468275353545323, 0.15153834741795436, 0.08752028807066381, 0.12436833581887186, 0.11095871435827576, 0.18913519248599187, 0.09768561096279882, 0.12762596335960552, 0.11950804779189639, 0.13098015915602446, 0.24939477851148695, 0.14443302556173876, 0.0849337327235844, 0.1255487959133461, 0.21293766447342932, 0.1315994665492326, 0.11455402651336044, 0.24481572734657675, 0.12052871607011184, 0.11355211230693385, 0.15886439883615822], [0.020819854689761996, 0.023170147323980927, 0.020593516346707474, 0.01629658891033614, 0.04300348737160675, 0.04676050979469437, 0.04942108324030414, 0.03706267314555589, 0.03251820606237743, 0.00765714065892098, 0.0656185601837933, 0.01459935376260546, 0.06399157209671102, 0.015093981273821555, 0.046726144646527246, 0.04788006182934623, 0.024772985925665125, 0.013809809752274305, 0.048525863894610666, 0.034215475534438156, 0.016566161066293716, 0.06346954542095773, 0.015900265352684073, 0.0371944451762829, 0.050206223531858996, 0.04569938333588652, 0.06717181589920074, 0.09516012694803067, 0.038454686145996675, 0.061119939273339696, 0.011486771563795628, 0.039533798553748056, 0.0336553507077042, 0.04773281230882276, 0.0058569538578012725, 0.040556229432695545, 0.011370182946848217, 0.05051660453318618, 0.03478468053799588, 0.04713855611043982, 0.08140896170516498, 0.03138984844554216, 0.02458475315506803, 0.049836415055324323, 0.10532256288570352, 0.020864715661446098, 0.050877381072496064, 0.07018888369202614, 0.0853773218113929, 0.017099516626331024, 0.10771756249596365, 0.07638064402271993, 0.006275116038523265, 0.070480302820215, 0.039212671254063025, 0.076305071124807, 0.05708467826480046, 0.0453822821873473, 0.07358745249803178, 0.044143800987512805, 0.07519918945035897, 0.09244895016308874, 0.044549251106218435, 0.021258441702229902, 0.12495657691033557, 0.05744748828874435, 0.04732482033432461, 0.04941569895891007, 0.058740016393130645, 0.028540483763208613, 0.021621110718115233, 0.017077107477234676, 0.03969842546212021, 0.018167522794101387, 0.06944479158846661, 0.030597720833611675, 0.05561563033552375, 0.07700953254243359, 0.06416156844352372, 0.035036543195019476, 0.045945334786665626, 0.04669996167649515, 0.040908567752921954, 0.08322034380398691, 0.040297416562680155, 0.022054207693145145, 0.01514280995252193, 0.01947534656210337, 0.04140513876336627, 0.038597939201281406, 0.042508771730354056, 0.07012217203737237, 0.030834762801532634, 0.02142671812180197, 0.06855758372694254, 0.13543427718104795, 0.048752289440017194, 0.03502354447846301, 0.028464036986406427, 0.038943531399127096, 0.07784873829223216, 0.045419263406074606, 0.011402522031858098, 0.0542780983960256, 0.07850070760468952, 0.07437786203809083, 0.01626845965802204, 0.061384533473756164, 0.04608216455380898, 0.06376638222718611, 0.02142716526577715, 0.05283796082949266, 0.02563782731158426, 0.028842127831012476, 0.048090278869494796, 0.05639285191136878, 0.07831928218365647, 0.02575248170614941, 0.07087948179105297, 0.043649667932186276, 0.08031631252379157, 0.05140959743584972, 0.09676314366515726, 0.02975829986098688, 0.021898365957895294, 0.03793770978518296, 0.053518847926170565, 0.09439247165573761, 0.04179431729426142, 0.05264164421532769, 0.09197719657095149, 0.03177789520123042, 0.020122081878071185, 0.016621107824903447, 0.028150331163487863, 0.03866725950501859, 0.004361836599855451, 0.09082307529752143, 0.03397101580048911, 0.05847731095855124, 0.036235931765986606, 0.013599670637631789, 0.04272197591490112, 0.015740584858576767, 0.008712993694643956, 0.021449357336678077, 0.017060524187400006, 0.028591419213626068, 0.02922353978647152, 0.003590602764234063, 0.03714468046382535, 0.020903971562802326, 0.06505922574433498, 0.0342380627989769, 0.03366499120602384, 0.05080660244857427, 0.029857383997295983, 0.023897119936009403, 0.03537773074640427, 0.05369881502701901, 0.01893900756840594, 0.038780529794166796, 0.05848364518897142, 0.061913324825582094, 0.028093150540371425, 0.021181857628107537, 0.055644191888859496, 0.025939393453882076, 0.05315850554325152, 0.04650200491596479, 0.04679503079387359, 0.030460436501016375, 0.05028429004596546, 0.027089881914434955, 0.019250728146289475, 0.04548294709820766, 0.04755986221425701, 0.02802903083647834, 0.06446388229960576, 0.048261655610986054, 0.058156795930699445, 0.019845125352730975, 0.01610649149370147, 0.065013939893106, 0.04078700396348722, 0.018395197002973873, 0.06663759573712014, 0.017699068048386835, 0.07461697459802963, 0.013044870720477775, 0.03604299192375038, 0.027386060064600315, 0.02311056770849973, 0.017464122647652403, 0.014524264188366942, 0.03916016059520189, 0.018095588275173213, 0.06675495897070505, 0.04568675569316838, 0.015738221118226647, 0.04842307273065671, 0.09361479736980982, 0.007035145299596479, 0.036386353967827745, 0.04573980811983347, 0.06308359152171761, 0.03200417231710162, 0.07038124836981297, 0.030081907789281104, 0.023005273651506286, 0.015684738245909102, 0.0813785262289457, 0.05161399232747499, 0.06647459784289822, 0.11409536440623924, 0.01940993552125292, 0.023443372701876797, 0.06509676357381977, 0.019832143334497232, 0.04516943794442341, 0.048483516948181204, 0.04691625319537707, 0.05445967224659398, 0.04716037896287162, 0.019429672938713338, 0.036651066911872476, 0.05757221733801998, 0.12838178139645606, 0.047979491064324975, 0.04523475807218347, 0.017303935637755785, 0.023764060279063415, 0.0069640183301089564, 0.026086535362992436, 0.059624359564622864, 0.010210608743363991, 0.017400735814590007, 0.024970551203296054, 0.037257271687849425, 0.013841314848832553, 0.10414215474156663, 0.03296942071756348, 0.0252152317261789, 0.036509134879452176, 0.02053521322523011, 0.03608657825679984, 0.037269183158059604, 0.025155963812721893, 0.025445089704589918, 0.013005294767935993, 0.037157857295824215, 0.0027911202369068633, 0.02272282523335889, 0.020421916960913222, 0.01796108885173453, 0.04995523289835546, 0.03567025938536972, 0.02799775673338445, 0.07112328472430818, 0.016754134085203987, 0.027062906701758038, 0.01987199666473316, 0.07446770643582568, 0.05382947012549266, 0.04414667680975981, 0.008442386242677458, 0.022185604939295445, 0.012036710413667606, 0.0016331417668880022, 0.020760889201483224, 0.04027493319881614, 0.04122828126128297, 0.0316554890741827, 0.02870887521567056, 0.0316262744308915, 0.03634736523963511, 0.032123595010489225, 0.01612021751498105, 0.028178209940961096, 0.016079633169283625, 0.03871027067361865, 0.0414515860757092, 0.030551679847121704, 0.052423749657464214, 0.019996929804619867, 0.025378506070410367, 0.017696978902677074, 0.03717334591783583, 0.07569007560960017, 0.024778576153039467, 0.001822331444145675, 0.02643218878802145, 0.023675479387748055, 0.08355101512279361, 0.03671236088848673, 0.05090099250082858, 0.023574679034936707, 0.028067017665307503, 0.028671088766714092, 0.013475418418238405, 0.030067968400544487, 0.07891733446740545, 0.03343028329254594, 0.010046507832157658, 0.04843705479288474, 0.009896621832012897, 0.06123302402556874, 0.03514649608405307, 0.04540265414107125, 0.03400705449166708, 0.004065558723596041, 0.023077779624145478, 0.027579562083701603, 0.03793548334215302, 0.06877099571283907, 0.055957834629225545, 0.023896964084997308, 0.03565489692846313, 0.014614583560614847, 0.02817641394358361, 0.04045487803523429, 0.02598171071440447, 0.02227076267445227, 0.016979604115476832, 0.013185364841774572, 0.04137236552196555, 0.06035201309714466, 0.061159369579399936, 0.06268013778026216, 0.03520135935104918, 0.07968324571265839, 0.03213065654563252, 0.05343003511370625, 0.05336932372301817, 0.02144350735761691, 0.03762111329706386, 0.06979321507969871, 0.036114412505412474, 0.04311181866796687, 0.030404730896407273, 0.027223106699238997, 0.04165394006122369, 0.017571335156389978, 0.06090095004765317, 0.04220755254209507, 0.016702560387784615, 0.02013516965234885, 0.05767605864093639, 0.04714633381809108, 0.01407681686032447, 0.049808988987933844, 0.08598751563113183, 0.1126116924569942, 0.12819339463021606, 0.17769801401300356, 0.2143316256115213, 0.1617718959460035, 0.1312733074882999, 0.1274702904629521, 0.15927912580082193, 0.1317604086943902, 0.13130658539012074, 0.29467534564901143, 0.0942130500334315, 0.14046194177353755, 0.10410519578726962, 0.0929707838804461, 0.12998734368011355, 0.06354856930556707, 0.11048221102100797, 0.1051919448946137, 0.11018447621609084, 0.11416768669732846, 0.1814908190863207, 0.16576006397372112, 0.0743690601666458, 0.1884280890226364, 0.17384518403559923, 0.12744974781526253, 0.13984870514832437, 0.21801911992952228, 0.15099030104465783, 0.11982455151155591, 0.14302445895737037, 0.13838122686138377, 0.1264616969274357, 0.0963997733197175, 0.17298398102866486, 0.12433024137862958, 0.20033363689435646, 0.19313306780532002, 0.08143910774379037, 0.18662844027858227, 0.14723727508680895, 0.08319419794133864, 0.15741685463581234, 0.2618289878591895, 0.13664636760950089, 0.12250620566192083, 0.16153613047208637, 0.21246185875497758, 0.21167653292650357, 0.2699948981171474, 0.20181423635222018, 0.13531160017009825, 0.15049132547574118, 0.11172286671353504, 0.1591789655503817, 0.1439616282004863, 0.15840920998016372, 0.20356787194032222, 0.13654264505021274, 0.1803381450008601, 0.22506935958517715, 0.11294268289930187, 0.12529547122539952, 0.19959282508352771, 0.1693460176466033, 0.09097743459278718, 0.16484636144014075, 0.2362940166494809, 0.11084803787525743, 0.1261395454639569, 0.12210515647893772, 0.13436858280329034, 0.0850068120053038, 0.101107742957538, 0.09428290097275749, 0.1542721374426037, 0.22115592582849786, 0.14760733960429206, 0.14213327318429947, 0.1576014861348085, 0.18007302016485482, 0.08705719534191303, 0.1738975351327099, 0.1254963260726072, 0.12068979922332801, 0.20643369003664702, 0.1557897255406715, 0.15998780261725187, 0.10566454453510232, 0.12744597770506516, 0.21758756105555221, 0.12111273434129544, 0.08843883682857268, 0.16048324556322768, 0.22575752343982458, 0.1113907185208518, 0.07054786052322015, 0.09819293569307774, 0.06852449136204086, 0.20544507511658594, 0.08226089528761804, 0.11560434359125793, 0.10377298080129549, 0.18370243400568143, 0.10503550016437657, 0.07352721237111837, 0.19668685679789633, 0.13296638382598758, 0.10520859126700088, 0.09524499895633198, 0.09553214331390336, 0.08963294501882046, 0.09235596648068167, 0.13070284825516865, 0.18259817763464525, 0.2543929946841672, 0.17717472568619996, 0.11508394221891649, 0.14853747328743339, 0.18048871192149818, 0.14821922552073374, 0.16174393182154745, 0.09682339121354744, 0.10228849248960614, 0.1517623127438128, 0.09383428754517809, 0.2649152831872925, 0.1325730307144113, 0.1425882097100839, 0.15342893893830478, 0.14618654240621254, 0.14518721087370068, 0.13981603580759838, 0.11383498931536451, 0.15998845570720732, 0.14442995307035744, 0.20919992675771937, 0.14346268231747672, 0.26227923401165754, 0.12080333297490142, 0.09397057554451749, 0.1473815634381026, 0.07479232925106771, 0.07446463394444436, 0.1149412791710347, 0.13853724114596844, 0.10049463991890661, 0.09567278029862791, 0.05967733777652029, 0.09444525319850072, 0.18850748398108408, 0.18898529349826276, 0.19977058429503813, 0.15738044487079605, 0.11291330127278343, 0.253635291592218, 0.2262264271848835, 0.10929143507382832, 0.2087448863312602, 0.1618855187552981, 0.18380924389930442, 0.18115928687620908, 0.11124548022053204, 0.15712536871433258, 0.13035023905104026, 0.11928774125408381, 0.12653392273932695, 0.14562982774805278, 0.15451845625648275, 0.13308011053595692, 0.0990115171589423, 0.10625258524669334, 0.1291689180652611, 0.07669979720958509, 0.166909264808055], [0.006566791207660572, 0.02511498983949423, 0.02090691232297104, 0.039717031104373746, 0.013535303241951624, 0.07131180507712997, 0.026165605631831568, 0.034043787090922706, 0.068297297693789, 0.046692818505107425, 0.02178057413402712, 0.022327310616674367, 0.026787057831825223, 0.07931957850814797, 0.01284422367461957, 0.04142249388678465, 0.02692918282264145, 0.029584266230813228, 0.03336275527544785, 0.022619581359322183, 0.018675008941499982, 0.041072478488786146, 0.08525985467713326, 0.01606475496373605, 0.062202584304031916, 0.02061777158814948, 0.025778085800993722, 0.05242236555204727, 0.09407586403540336, 0.075530231843004, 0.019385648738534655, 0.039182065083878115, 0.029516569375118706, 0.026526135407038964, 0.04549472869257443, 0.008516312500432832, 0.037030348903499544, 0.054826842388138175, 0.05585532548138872, 0.03895303460012656, 0.06728186897817068, 0.04981296318874229, 0.05982351489365101, 0.03552000787749421, 0.027530474580998998, 0.009994472147809574, 0.050967603965546004, 0.050148361988249235, 0.04090881266165525, 0.012530962212622399, 0.029467749045579694, 0.026589932276692707, 0.008544288684788626, 0.016096455801744014, 0.02266436811623862, 0.0580884181545116, 0.06889881580718793, 0.02226845645054709, 0.05033031433413271, 0.10090750409290195, 0.02638246674905531, 0.02595560381450923, 0.024487103219144046, 0.0022334245522870333, 0.04121320082049351, 0.013866284407413332, 0.01680666329775704, 0.01694819457043195, 0.03188803733792156, 0.033979624713538215, 0.05053045300883241, 0.036903749642078765, 0.042673135176301, 0.1079636141366791, 0.02291810840688413, 0.010895505292864982, 0.042343406385043636, 0.025361783627886325, 0.04923185413645115, 0.059525049073272385, 0.1434381617582403, 0.06909987103426829, 0.023557730237371288, 0.030984641380200628, 0.04201276846288238, 0.04055778423207812, 0.021154717287572566, 0.07537949422840029, 0.028443106566555798, 0.06395569667802192, 0.007474225376427057, 0.10628617485053837, 0.03069623537157895, 0.08897996638552286, 0.056180293395300396, 0.03837587748421356, 0.03050858333153883, 0.05652972249663435, 0.05709962140826974, 0.06790241575799882, 0.022768869930587243, 0.022239071113290265, 0.06029394004144706, 0.02333994514629012, 0.06380777922458947, 0.041897319970303215, 0.01889902621769579, 0.018035849097941536, 0.04612687152985018, 0.03770131719647907, 0.013274492139316862, 0.06081955129047856, 0.026201484761259053, 0.04444805555976927, 0.03240797857870348, 0.05746076531067956, 0.05675582149706315, 0.04532366365310736, 0.021935827717243228, 0.053692670044256374, 0.014913992836227408, 0.036643226121668704, 0.03230102396628354, 0.040218370413640514, 0.032965847276500426, 0.018498596728022676, 0.03758794300665613, 0.006758056579201366, 0.061086015703040175, 0.029200356948422268, 0.0362790245708311, 0.09982596486224793, 0.044892802397953346, 0.08853115257807076, 0.012748189765261486, 0.03417135485506151, 0.02294959773280425, 0.09199044390697964, 0.014548533345077885, 0.07501591608161107, 0.012435310509317787, 0.02667145905434154, 0.04733902504085563, 0.01375225898300414, 0.07349714054726064, 0.016649136887281202, 0.02040718904027017, 0.05641766561893746, 0.050375856226310134, 0.01148683093560976, 0.0382379864458926, 0.029323969065444544, 0.060206310954527, 0.07215847683255561, 0.009349556949018734, 0.03711513556481805, 0.03592471213778481, 0.0060527950336108916, 0.03874169691698626, 0.029140654878574423, 0.0644174832268618, 0.02206933822890278, 0.037276274379109964, 0.06749762615072541, 0.054980581990093924, 0.029894875442550983, 0.03740474014193751, 0.024494216704624705, 0.008583645703765796, 0.02234871786640724, 0.03125077368167695, 0.024314932379638776, 0.052673820027848706, 0.015907566230453085, 0.06757532901247032, 0.01967601216165349, 0.03562122939911205, 0.05062923286459409, 0.013885493972338736, 0.03413483747863211, 0.04631590396456886, 0.05614250694634393, 0.015151982897805283, 0.03940933667763602, 0.046254673070507124, 0.030675581401737873, 0.06556291395099834, 0.0317879475915106, 0.047783590052858926, 0.03881801196257584, 0.04293185156711843, 0.0377235742053017, 0.0326867923286045, 0.0316150308935903, 0.005615300833596848, 0.02975239051011158, 0.04158748073677998, 0.04108199282200076, 0.04230829537846148, 0.018644315568963066, 0.04922609507048037, 0.02573483157902956, 0.0311675455304794, 0.0578987029439304, 0.02468275746650761, 0.034286981463083066, 0.04936643519613426, 0.03771063486055937, 0.02489243273885222, 0.03109594683337491, 0.013553099015553016, 0.061766194048686884, 0.009356798454973614, 0.10586595599306747, 0.02390715562796686, 0.02546270643506432, 0.03584283469535876, 0.012558122962218476, 0.021503899624804035, 0.05762094304373022, 0.079141455644276, 0.006743337471561972, 0.011097621791122947, 0.04906731999653857, 0.030992910760687664, 0.02243845650809817, 0.041606019585742615, 0.08106427863822319, 0.06699836856569164, 0.02372510494751623, 0.07974973472300917, 0.03492597803415265, 0.01989738182601286, 0.012883930430689361, 0.0952642502670642, 0.08193188637960702, 0.05766772803326603, 0.04458204290131107, 0.05182084372790996, 0.03214286858565174, 0.015710368315922096, 0.02380163892667042, 0.032699056318961084, 0.01990068438317394, 0.04806188429938629, 0.0520537074044114, 0.012040061210427666, 0.021918969832768198, 0.011975338511547307, 0.11963304030359723, 0.015498417433263967, 0.017927788685483392, 0.04066531400894746, 0.034592464289744385, 0.032255738115054555, 0.023283419468498323, 0.08226742618717253, 0.048628673612256534, 0.030670571904920507, 0.05742655601352453, 0.10826328594703227, 0.012803224653907819, 0.08982352112070657, 0.019246425545134116, 0.03341280942549929, 0.01293714241910493, 0.060575425522984006, 0.08756670940783806, 0.036581327294697985, 0.07503308937884867, 0.04289485550543759, 0.019036351368413307, 0.059142423706362024, 0.03514101903419942, 0.08301698791910894, 0.06010759047057945, 0.0641438236925751, 0.038773460837546736, 0.031013559164421167, 0.012528896259027533, 0.10379326369729824, 0.032397132090409286, 0.0372427812544629, 0.04108774446649477, 0.007707854392720037, 0.036788041397812776, 0.04277110238035675, 0.04296984952816274, 0.02745257876085816, 0.05105059462948702, 0.012835659290431067, 0.02025379268161487, 0.026849155183299445, 0.04139009542996064, 0.06744006517692469, 0.06170729349832982, 0.02917204958066577, 0.025100458587985486, 0.04357224337582011, 0.04997026138880756, 0.06384440421243198, 0.04969397465174552, 0.03453842851740774, 0.027055286700488068, 0.08414549025474116, 0.019752553562284447, 0.06384359527146444, 0.04125695413677022, 0.05812182222143747, 0.010459236564202001, 0.06140575889730826, 0.03366179626027588, 0.04537973291007802, 0.03108581466221949, 0.05818716832436621, 0.07118389592505991, 0.05088558551506139, 0.04139291930187028, 0.06964770960621536, 0.0204035525166546, 0.04816821921849623, 0.027403905005485285, 0.025586915980966296, 0.06510014776722528, 0.034199315268779173, 0.057681379839777946, 0.03970360194216482, 0.008138907214743085, 0.08294660263345577, 0.017929890818777494, 0.06108266119554173, 0.027816882357001305, 0.014512875004584203, 0.04519417001574766, 0.06125635343778413, 0.017274991878366563, 0.011247716520301765, 0.0215386098716408, 0.01445924091967754, 0.0222092961485032, 0.08438119635684416, 0.09454375845962204, 0.039455234800698236, 0.04582818677590694, 0.11204498106963001, 0.011410642982809804, 0.014402890574274352, 0.036378275690367445, 0.03417410822294187, 0.013227838880993659, 0.0933392824663315, 0.01821494231990073, 0.09735879881191067, 0.14035878324648365, 0.07657847090740688, 0.113220587518299, 0.06720673394738697, 0.11001501421560533, 0.1077171097858809, 0.1265658054035157, 0.17026409885147586, 0.11114339780760929, 0.09285701264161617, 0.07598329073516652, 0.1134670918690972, 0.1882795407436788, 0.17205055220983922, 0.15451229643076658, 0.08064797832048498, 0.11679962437483482, 0.1348153705475852, 0.09704959782538936, 0.13218847947428003, 0.16272926644887775, 0.12875003507360816, 0.08938914208556525, 0.18610785336932167, 0.1342535499134101, 0.1360134343849495, 0.11493783560581505, 0.12692942807916552, 0.15866183704929426, 0.14605797274271026, 0.10899625325691886, 0.16304700955515727, 0.21877648163354024, 0.11395358451409265, 0.1329689219710417, 0.19238030741689727, 0.19523033261066303, 0.15691358945332468, 0.16017083107726648, 0.20193531032418832, 0.10365782916778699, 0.12095021884306334, 0.17153397289803252, 0.21540238143643364, 0.08809416118310764, 0.15797589963767678, 0.12053814134560525, 0.14783014717977494, 0.12679094332270324, 0.14555121946614236, 0.10817514106747694, 0.16966183116892353, 0.10072218981804326, 0.18495022173738107, 0.1092848225380294, 0.10232950357021764, 0.06623354827752337, 0.19877920858561993, 0.2917237946530804, 0.1491537972469814, 0.08825476194033399, 0.18923063267720863, 0.10863635616260581, 0.13448590150801465, 0.12983848369913176, 0.0652186168008484, 0.07679807240492664, 0.16827851242851466, 0.08995803538709879, 0.21448112383950502, 0.1327984209638089, 0.11221831708098762, 0.23034954734612256, 0.1539849559776485, 0.12505557941040024, 0.19828211807180196, 0.1256064756307751, 0.10933004159596749, 0.1277369589661248, 0.2709955506725237, 0.1701033051358536, 0.17511099111288786, 0.10825933029991575, 0.20159218576736748, 0.12774206494214013, 0.18011002364801243, 0.08332322031492367, 0.09530179551802576, 0.1388884402695112, 0.11662403965601698, 0.27917060418985784, 0.1300868359976448, 0.3781635157065466, 0.09872243579593487, 0.1952625863486901, 0.13229698146460578, 0.1930367964087054, 0.20265359053155407, 0.18133143545128405, 0.10387003145297058, 0.1100507634691894, 0.20244127692421898, 0.09861820857622661, 0.2747753681614995, 0.08876029067323543, 0.1512106743757613, 0.11126709898235276, 0.10754393704701215, 0.14147234614938498, 0.15811248449608684, 0.13126555946655571, 0.19111920555587858, 0.1845980281359516, 0.10025405048509128, 0.18693191930651665, 0.19995649228803813, 0.1147018326446414, 0.18697916442761198, 0.1000291871605441, 0.1091275762883015, 0.12807604623958468, 0.0940356396313291, 0.11348630607244559, 0.18999977968633175, 0.13658329989993945, 0.08533249609172344, 0.07620915595907718, 0.20125118375290185, 0.14855130692012608, 0.09479706088313833, 0.09116715722484514, 0.1788649521768093, 0.14278248912887648, 0.1792396031669341, 0.12003492069197819, 0.14102466782787815, 0.1815254328539595, 0.16193785500945523, 0.15815097227459773, 0.10893796497839503, 0.11652544533717446, 0.1112510685925372, 0.14584396703867242, 0.21853040030691773, 0.07257522986037657, 0.1522151118842885, 0.12729688023682684, 0.13516619859728962, 0.0985525878786575, 0.15280546067515388, 0.12618261971510947, 0.1893739859224297, 0.20842415979132056, 0.15715290239313617, 0.10840691378689371, 0.08765654638409615, 0.07975570901180618, 0.20099536544876173, 0.10202013188973069, 0.16415297286584973, 0.07744990070932545, 0.0932735504466109, 0.18462502746842802, 0.14686252019600943, 0.29560813622083515, 0.15989062580047175, 0.14075258164666593, 0.2036694868002087, 0.08899805252440274, 0.1549793893354945, 0.14930194476619363, 0.23142342019127682, 0.09746636569616385, 0.1373680171673186, 0.07239549653604627], [0.013723209467570996, 0.024231396237155423, 0.011225358393858187, 0.012014586991426768, 0.06288220232818276, 0.04730757653305773, 0.025471166918578092, 0.008915767921280349, 0.03685874580696691, 0.03684644841996487, 0.02086235377646517, 0.06691415706882253, 0.010226829308521701, 0.05762149223301094, 0.0323799550824333, 0.030583592197217513, 0.04206467798212543, 0.0056858902098611, 0.005932981321166153, 0.07114712992915884, 0.030783664078626316, 0.06418980716262013, 0.024707231641514227, 0.019466043740976602, 0.08619132422609255, 0.040146764295059256, 0.04105893058294896, 0.0005388836325437296, 0.011953078719670884, 0.022405052441172302, 0.03330351704789791, 0.10099298466229811, 0.014442575065913843, 0.09093009299249388, 0.0029674774850718677, 0.007956432582432171, 0.03303639212390408, 0.029427906847558916, 0.03817801349214278, 0.043665308694471605, 0.04471145861316472, 0.028528956354421098, 0.01086131176634808, 0.014143315147521207, 0.03095304073212901, 0.027348407202225644, 0.04352294621639885, 0.0366866491822293, 0.016213165945373476, 0.029376884194789454, 0.07636211259523407, 0.047503707610303536, 0.059309406933607534, 0.04096569828107022, 0.07509301038226113, 0.04242760674969759, 0.039558653079438955, 0.023004253198450897, 0.012682390952249989, 0.06943217507796362, 0.016996705053315964, 0.04109704357688315, 0.017883257969515398, 0.04009773059806321, 0.042760998039739206, 0.013443192510749213, 0.010872397597267991, 0.10729380359407514, 0.054481261322507635, 0.042238563182763755, 0.008619369909865782, 0.02873280391213484, 0.08113902775221504, 0.05979508321615867, 0.02154995916498592, 0.024004319457162637, 0.04134390786930453, 0.05501036066561937, 0.04958425553923007, 0.03918574613635428, 0.02847987627319526, 0.04312392309657298, 0.009915562368405517, 0.042942082072841004, 0.008240259539888939, 0.04400556113978382, 0.04221638781018555, 0.021601516164082568, 0.04641545194317587, 0.026617128278303426, 0.041212699870811775, 0.009426150299987057, 0.016868623351911083, 0.029258188806124963, 0.013623500999528915, 0.029658544081030414, 0.011156329383084085, 0.025464456048212014, 0.029921169734734576, 0.051912083363276906, 0.02931796138000209, 0.03871429682476446, 0.050679713749559596, 0.053055617900099605, 0.021741416567238048, 0.01759839571604971, 0.057782122676144354, 0.014353759470395744, 0.008973695330496412, 0.04199781047645956, 0.05531019574846141, 0.024615368602098897, 0.025382649109815247, 0.036104085520491935, 0.020600583447958343, 0.04480214534851257, 0.008481695022055646, 0.031029196215968113, 0.03192311123711988, 0.04783568139828276, 0.037325909215724096, 0.03102925929852063, 0.05461772372655105, 0.0446007376012858, 0.05083537551399786, 0.019006095863005612, 0.09619576434488408, 0.08537589688785374, 0.003391272102817311, 0.015762489347252995, 0.05074832901300397, 0.0332259477727348, 0.01946619031514274, 0.008781354772509076, 0.008158965611073654, 0.0179988085074001, 0.02047410664090421, 0.049467092685517855, 0.06066765963623766, 0.009700644750409992, 0.1347748641273938, 0.04241061156790238, 0.025039737920451444, 0.016640559515508357, 0.04541701840935275, 0.01290867177885957, 0.016615003660263028, 0.0316913644928718, 0.030154641972330865, 0.05729177457396872, 0.014656183720944682, 0.0402735045645386, 0.036407642473932356, 0.027062550470873248, 0.006551131891683326, 0.057520994305377826, 0.007289959849003935, 0.019521048016031273, 0.01911705436214106, 0.05136042644153349, 0.0006052813819223957, 0.0554282714438159, 0.012092339020455256, 0.042221601397613995, 0.05588904125033878, 0.05034376576077193, 0.03865967104502488, 0.04264652918209322, 0.020387650147313252, 0.05275171213725116, 0.052253805260988884, 0.01285179729165975, 0.053373027039924636, 0.03392095422896091, 0.053232193386065774, 0.07440523986588232, 0.009078611819859361, 0.03273834190622438, 0.05942142670392059, 0.04352614858362358, 0.01214541278386605, 0.03771906565816607, 0.027163395352545194, 0.01580541331350105, 0.0245365784940077, 0.07275209849467501, 0.04708786742412485, 0.08973891628556885, 0.04863267749897204, 0.05392565988586284, 0.02778845253487816, 0.024593182097305544, 0.030078811178100295, 0.024819060308800545, 0.023909558331070002, 0.04665908418246545, 0.04701505160483066, 0.0745870363607537, 0.04619945728336461, 0.02257349027786404, 0.07591591856908053, 0.06713389215292409, 0.06980425823712721, 0.051066009036730975, 0.1059095942764543, 0.025150121255137492, 0.045262640560395084, 0.0560791943280492, 0.030315016374515835, 0.05042812197643798, 0.042420051686349325, 0.023610229764017276, 0.015534842968918383, 0.07985220305272378, 0.0414168609859189, 0.01366801594485878, 0.037484847562154755, 0.05418790518888272, 0.006954863474675221, 0.040979902987601236, 0.01201166292958078, 0.06447016086895019, 0.020583553014148492, 0.0830745860002935, 0.06226335506653413, 0.02883297343942104, 0.08242185969720595, 0.04510357233812101, 0.02901685165852541, 0.03477008991467301, 0.03510479109536391, 0.04515801258094143, 0.06085859196900856, 0.07564473780803382, 0.046217183480621316, 0.010219110972684575, 0.021870919481443707, 0.018723909051914234, 0.06997168675297871, 0.027259095295448788, 0.12644859059946612, 0.044196267117513344, 0.026922586985165253, 0.0915171837550588, 0.09278326542698778, 0.017695823007670697, 0.027458955664769746, 0.04116668671485968, 0.0014951439288779511, 0.12510024185758084, 0.01163028993687476, 0.017413600944564678, 0.02196968449425185, 0.04030404394143261, 0.04182235192274675, 0.06285224182647653, 0.09064831436262466, 0.08587847187300213, 0.05695283201930579, 0.05037939998146612, 0.05226211731496733, 0.023594459125888534, 0.0808977555425372, 0.017341035600111354, 0.06659492966718972, 0.06750419415766373, 0.05252670780464541, 0.048041987320175394, 0.033833124762168154, 0.008638577619421994, 0.035316377397975884, 0.083703860436799, 0.01724446177831851, 0.039951627695700154, 0.03446023212745786, 0.024854265939211473, 0.05647354562825058, 0.04771707877807785, 0.07601947785587981, 0.03847500243864488, 0.03886552054609638, 0.014734122214576928, 0.03166206821333617, 0.03891281390679069, 0.029697748032049276, 0.02134882230166113, 0.015392681798402919, 0.03259441720729228, 0.0536409200867638, 0.028538732294691727, 0.017194355677929707, 0.016105164904729463, 0.022623535151069518, 0.05848353015608154, 0.045130545695428737, 0.08147627449943684, 0.04310375152272172, 0.010451227863086388, 0.04931828094413504, 0.039482248976128176, 0.03094933184911497, 0.016995480509649497, 0.09149793244432658, 0.05930633073148783, 0.06242549206945114, 0.07041475633741356, 0.015544584584858967, 0.020905287019559182, 0.019832351135846693, 0.029951794458611403, 0.02430799329886213, 0.014857763089821674, 0.01845871185651049, 0.020290465909056365, 0.012248036036908161, 0.021540773232118227, 0.03276163050031755, 0.04097985103726387, 0.036728298509842716, 0.05905840516788885, 0.023935878598422278, 0.05462970570079051, 0.05522580242541153, 0.0544051355245756, 0.009897977179207373, 0.03866491431836039, 0.03991352212324273, 0.05459722931846045, 0.04248436620400753, 0.008272804570879089, 0.0019372105703041598, 0.018138564191758633, 0.021485255019797478, 0.034770119600580074, 0.01680882109212689, 0.03852031426504254, 0.021117949436302297, 0.027168712840648368, 0.03202860381861683, 0.05175511170818936, 0.014770475390832871, 0.007865872012189357, 0.029812424691044725, 0.027742424535972532, 0.031104286717891227, 0.0021955488136882195, 0.08521112526068464, 0.026607374602463096, 0.0521733082132414, 0.009535471435810905, 0.04477229616895784, 0.020696480059996247, 0.18784051586408168, 0.052628207631642, 0.1713539575575851, 0.08717626551515423, 0.09204172631143592, 0.13549179362598807, 0.14953735400922596, 0.1197219941241201, 0.13755245570791885, 0.08090102099231444, 0.12035366569762118, 0.1693545375019312, 0.09169501718133688, 0.11996960427495651, 0.1336093360441737, 0.12317825006903149, 0.10488822095794603, 0.09517698854324408, 0.12670699157752097, 0.20236256474163383, 0.08054467878537253, 0.18218241166323423, 0.09078348171897233, 0.1466536204679869, 0.2650860958965495, 0.1802274165675044, 0.09070341882761568, 0.18207343469839543, 0.18903359246905893, 0.1768351485952735, 0.14734784024767578, 0.25432249065488577, 0.09795342979487032, 0.14523043355438858, 0.21659137622918934, 0.11949670035392046, 0.06574073995579965, 0.13947432133136317, 0.15389805048471317, 0.1523932273266837, 0.08895631413906813, 0.143598243012093, 0.11864471482113004, 0.09020763449370861, 0.1022406981792301, 0.1353158600977622, 0.13029741297941655, 0.16885449324036017, 0.09134148029261269, 0.10909496631938964, 0.18660242058103904, 0.15241163258906454, 0.10263707183185034, 0.11823823311715387, 0.1316575618693605, 0.08311823170515709, 0.11245124012930319, 0.16956729639787227, 0.05532436705834698, 0.17049653950380161, 0.16380793356802315, 0.1118927146308124, 0.07426762342220172, 0.12965155154233798, 0.3153401508461684, 0.15184003044851124, 0.08177959767635912, 0.11077677685534582, 0.18270375556312501, 0.16610905149718747, 0.09905511833494529, 0.14358451328007504, 0.2834429405629635, 0.29606152907945216, 0.1331624889280647, 0.15833296172786504, 0.11282102263066918, 0.07737441686913371, 0.1075977947039064, 0.11961977070313878, 0.25656226265709847, 0.18374746752670035, 0.15489242447074503, 0.19081728503806517, 0.12948416755534708, 0.11915995826711878, 0.13858273479854688, 0.177736293990165, 0.14317128545371816, 0.18785721418680623, 0.10166696607484482, 0.16494558658450842, 0.08424806990660727, 0.24965482705738395, 0.060930784384254366, 0.15871398034505546, 0.17032266914611682, 0.18569064763141796, 0.14781594247324392, 0.14711982279550284, 0.18089137156493962, 0.10478489915840328, 0.16376759042032063, 0.1432555785868317, 0.20908882725052536, 0.1453925037640147, 0.14060265297302976, 0.12620396388228983, 0.10981945088133216, 0.1487137927324511, 0.14718888705829158, 0.18837060226360336, 0.18126826384104788, 0.10185153078055009, 0.10227178674540482, 0.14434402721235529, 0.17888084898004308, 0.13317016273504123, 0.10473107860889286, 0.12108730836189352, 0.12098330378648825, 0.15198555076494813, 0.13952642009826377, 0.12335482184425928, 0.1862353691831231, 0.1012872981664259, 0.14955730293877423, 0.11563635984202847, 0.08218432049034163, 0.17653478658758104, 0.1500034672790207, 0.13385400729021057, 0.10432956929435022, 0.11349898937623948, 0.06585710871149786, 0.09170392295345664, 0.10484121332410723, 0.20189205795759335, 0.1497625364572741, 0.07766274866298772, 0.27573003724683076, 0.20774030039319769, 0.06673311756458133, 0.13192146958317608, 0.08009187964489684, 0.17408644140232354, 0.13596589240478352, 0.1726670394418761, 0.13882077124435455, 0.17322771716862917, 0.11951721331570297, 0.27137677709106356, 0.09072148270206526, 0.11144873220473528, 0.05515297918464057, 0.19586811948101968, 0.08913293044315651, 0.1880515381344594, 0.12767162028467283, 0.11712343082763255, 0.14246844191802666, 0.13692391599761322, 0.16273472865577787, 0.1475553447380662, 0.11269280177657492, 0.13706232653930783, 0.0626336941786576, 0.1477303431602195, 0.1795284025138244, 0.17684121936326846, 0.3083631017943844, 0.15124809346161783, 0.11516206068336032, 0.12228844469063915, 0.15015180775662884, 0.1329110938240774], [0.025115756106970366, 0.050076484985766, 0.025109108319156803, 0.02723015710216714, 0.016463614811073057, 0.06387035711668432, 0.013544838911911938, 0.012849436334363418, 0.10156750344322063, 0.029047613679722417, 0.026071234133269172, 0.026001717160397675, 0.007812485619069776, 0.07492994569474831, 0.024513625721738208, 0.0054489071499119746, 0.04323843648307957, 0.01505383943367633, 0.01711888482532231, 0.016257505558314733, 0.030666321254102513, 0.03720817119756248, 0.03968243960116524, 0.03886625898303464, 0.007810449351381976, 0.04522057934082113, 0.08008176417206414, 0.01810203568311408, 0.06954978322028182, 0.003138320807920536, 0.042571267986204475, 0.04345090965216514, 0.0964281233609654, 0.06475913833128288, 0.0691689872473944, 0.0437516687088646, 0.07618273550178856, 0.05119955851114355, 0.02838085336406948, 0.020990459597669542, 0.008212389111577068, 0.001510479598891834, 0.08899509135517292, 0.056902644282672554, 0.02052622767223511, 0.06163293030112982, 0.05506737987161614, 0.09290166024584323, 0.06269303630688228, 0.017665907034825068, 0.06310416385531425, 0.0811371130112093, 0.027061962318839505, 0.033204737192136236, 0.02952497234218754, 0.03733803219802212, 0.04281713037926238, 0.0816563492116984, 0.03695733641507104, 0.05484540350153111, 0.010644056383171119, 0.05929643419221975, 0.030951871849538293, 0.04297887033317238, 0.01797698194422992, 0.04744409830891527, 0.024495513607689645, 0.017564915578986984, 0.010201963650615653, 0.008316350085806334, 0.04773598127940204, 0.03720375541888643, 0.025517339636280667, 0.05030229454860091, 0.07144511706428602, 0.03790502560150344, 0.0809978786855936, 0.029399632876447868, 0.008841278558975318, 0.028263427047932055, 0.015982571385393385, 0.04742347402498126, 0.050612052145879716, 0.01692145313427318, 0.05252447022940032, 0.026615794267854653, 0.07451297744410113, 0.007323850950342603, 0.023479320479964372, 0.027245068704360165, 0.04711967587354593, 0.07891262182965875, 0.08934014549595304, 0.09052465771674179, 0.024472952318319585, 0.041170998592861, 0.020606917678378522, 0.009358236366097117, 0.06051864009350538, 0.11252280542976223, 0.03695440864248667, 0.02132216435711598, 0.017682976431387942, 0.006381700968631776, 0.04837184227653779, 0.07818093843525276, 0.0366117108205799, 0.0152596731641097, 0.051976783797726966, 0.030984411314420868, 0.031261891053873114, 0.015272906584868906, 0.03197146957973018, 0.011403436728869565, 0.016416733342339285, 0.060013378533767536, 0.02327033540495904, 0.03719536915014032, 0.041728203068487346, 0.039638938615098596, 0.02496683860954363, 0.07769705072860233, 0.04627939772035461, 0.03614373847085517, 0.07415846092044376, 0.023156155984906945, 0.03935722306778189, 0.021638751568389125, 0.06601459244848229, 0.01368201656077872, 0.01834315204177983, 0.025073900833376683, 0.05034076748415828, 0.020481476167333312, 0.0639663464971818, 0.11163725997903384, 0.02274732723890338, 0.018493752359063365, 0.050120887681259774, 0.060381999574019574, 0.019742345320992172, 0.05103289811813738, 0.05495448065630626, 0.04169648738752585, 0.006781347492506029, 0.04090579583134968, 0.06198800343554467, 0.021880691710975952, 0.014523702011501882, 0.023214518478198443, 0.033743235835572705, 0.06250677950447425, 0.027171464353159536, 0.04106004009372555, 0.059250331978546456, 0.010640926375344861, 0.03929292339307722, 0.041459026106167585, 0.05572926427703351, 0.02988489726703847, 0.049727430669008754, 0.025086649075092282, 0.0343351987976348, 0.0211417185710161, 0.01445363956008805, 0.04608041679603048, 0.038991752444417216, 0.056383994378848, 0.013224296981206862, 0.04339160834206268, 0.012758463872160064, 0.03414558006625157, 0.02147537517885212, 0.024293011192639824, 0.07003810897003859, 0.022769632487324998, 0.011599793233472155, 0.029397528887784574, 0.01811839818401495, 0.05488522343512159, 0.02716959785175277, 0.03528753382852301, 0.01200216158395051, 0.0263320303929504, 0.10176812080317177, 0.10645163667504676, 0.02540046065405477, 0.058861108918790706, 0.012474105351429898, 0.0531916647014441, 0.028062507262802683, 0.02351820901822066, 0.08987053617602214, 0.02671834979992127, 0.05458834952150937, 0.04758825678436551, 0.029079880405333824, 0.016743152154958807, 0.01238673045008909, 0.03902730873960536, 0.06006596711813472, 0.027142223734699655, 0.009638287647248944, 0.033969653959502466, 0.040865489791030996, 0.01951984944753349, 0.039356566267088056, 0.03434682454098947, 0.026594275695970282, 0.024828674831951503, 0.033751351220416836, 0.09121113689616323, 0.013327286669664318, 0.01742752177960938, 0.04607385249983054, 0.0661319779464975, 0.049290480092167854, 0.01782550403731875, 0.07082344221998937, 0.02216103985119844, 0.05726715382479597, 0.09054040609044023, 0.04605762915161904, 0.03237711265683174, 0.02716274597332813, 0.07218288606964052, 0.03619054943555966, 0.033732942247297615, 0.027076916594523937, 0.05946864956058562, 0.013486941188602941, 0.02177610083890613, 0.07805484754499048, 0.024754109399509616, 0.023176008435257245, 0.034149535713368095, 0.059676424934878014, 0.07403304538456723, 0.023192875596578233, 0.018636612076079473, 0.010871302001760341, 0.03553659116732888, 0.0009325496637302422, 0.030047490690776613, 0.090204317093594, 0.03700619941810146, 0.05248871355433948, 0.007795674118824536, 0.08292369995615445, 0.019265712107880972, 0.07032724970486015, 0.0296394690303714, 0.014263638622651342, 0.023869705000834074, 0.041590104228816926, 0.08947370239184238, 0.060260895916144364, 0.042481319687794894, 0.026851750844798516, 0.013579666047007777, 0.01853563175245654, 0.027721887454390526, 0.035131055701640435, 0.04122266691410914, 0.022224849708436523, 0.07689349775318988, 0.034916022123070434, 0.0825239866389893, 0.08298183980514295, 0.03028289065696299, 0.04032030439702794, 0.039029230902087875, 0.026217828708468005, 0.04030800329928752, 0.0259285877837101, 0.02842786841938505, 0.00707251707353862, 0.00604630634370551, 0.01639981423068093, 0.033420227191527374, 0.09646310078096576, 0.04352503536210861, 0.04868310643360019, 0.040950465700007044, 0.0606592844997067, 0.0363168481271714, 0.0170566965607577, 0.06599202373763546, 0.0272809367015725, 0.03597784248995595, 0.12853228894528002, 0.04218594120175112, 0.01990688131627394, 0.052617175606428646, 0.04164453705016058, 0.07855370437027887, 0.02677956214029109, 0.09866238120594062, 0.03638894406321924, 0.045269401525729336, 0.02138168831152143, 0.021572674449998885, 0.05135092324053403, 0.02073907933663577, 0.026742514128272887, 0.04418143529619556, 0.0160551831140765, 0.061133687559049577, 0.16867701604496688, 0.032799791733850725, 0.01511576701886952, 0.04425894519954454, 0.030389561397896614, 0.00581607450840238, 0.0473018285993021, 0.025530650054861326, 0.04450454784091562, 0.05801406237878837, 0.119526015187148, 0.06757506183930673, 0.04281621382688172, 0.03533035946020391, 0.13084620150038972, 0.026736970285128336, 0.01653232284297701, 0.03888394065143075, 0.010946269121632213, 0.06535752458148636, 0.05197405640501529, 0.09126101664151065, 0.04182051510724705, 0.033980823282036, 0.03920507166185416, 0.018135745885956567, 0.06962601662962697, 0.03876764611050021, 0.05233352676441427, 0.03914019311196171, 0.0662472409021575, 0.030731886290595867, 0.0074959039739042055, 0.017345933774777222, 0.042814002226805314, 0.06340186897432432, 0.052987358867540024, 0.04161221280810423, 0.014732424551766599, 0.005815977565362118, 0.03376407163159456, 0.018030570572591387, 0.0042724848026409745, 0.06941446001292206, 0.08537668356439099, 0.21242656221147627, 0.1173494741669856, 0.17825750430347398, 0.10485272403457202, 0.1337695657275617, 0.1010184403276071, 0.08463026853860356, 0.17843339330283925, 0.22238069213926792, 0.16529632557649165, 0.16188734443858266, 0.11108433769550174, 0.20493903430178761, 0.10237629598123021, 0.11479098684503697, 0.1773081489955075, 0.11145450611365959, 0.16647724580252543, 0.12326652853516862, 0.13629426306579262, 0.11144121424877085, 0.09285684194765054, 0.06449810272897594, 0.13409985112957656, 0.14647228410467505, 0.1974539109505713, 0.09120606060605496, 0.17577218532096595, 0.1192424405599013, 0.16055334883276373, 0.1284447600482963, 0.11480965185910463, 0.2581338048912585, 0.13176886917790398, 0.17363984661642462, 0.1515412121079862, 0.11030208435840905, 0.09955171903129667, 0.12301848051720299, 0.11081943550379947, 0.2234379854053259, 0.20392595819430426, 0.20957765023922548, 0.13854332675691694, 0.2184125324129127, 0.11070041728089564, 0.13385184021899477, 0.10120962499058805, 0.15277602709829807, 0.12564341974211857, 0.18244085717014968, 0.09602578284102492, 0.18337228219024837, 0.11314741175738163, 0.06992334325332195, 0.2075931621948257, 0.13952745910501108, 0.1419613917823881, 0.1523128675762564, 0.1513906748732552, 0.1382100282353349, 0.130258850986138, 0.10644929890986532, 0.09343104902654886, 0.11050936620449647, 0.09018767072120681, 0.06257720931898803, 0.12799351941794157, 0.0849611328158062, 0.1424862237763591, 0.09943782904883847, 0.08838267851388082, 0.13913236936787143, 0.19815911451587453, 0.15267074602888897, 0.20186415320495144, 0.16036885092034936, 0.11789671902079135, 0.19377187883947045, 0.17113594425609335, 0.15039676101878285, 0.1474345230963081, 0.11042558515327983, 0.11969913597567938, 0.10650285228621215, 0.14325137803098187, 0.09205181209836155, 0.23433994181687012, 0.13521659042453393, 0.08556337081245147, 0.26641433243639767, 0.16992882621707395, 0.1575106621021405, 0.10923149922746234, 0.13637175812618807, 0.12466742133256048, 0.20817497628740966, 0.1475475521874614, 0.1892489191959612, 0.0946445124282036, 0.13032919174293056, 0.0799504634051118, 0.18297878064913675, 0.0964750642015133, 0.1856731774751097, 0.09515859070234, 0.12570016435347497, 0.12964729161467403, 0.11528672665008344, 0.12753962189890444, 0.12537768634501845, 0.11834645309136249, 0.10074610181618482, 0.18935368076199666, 0.14365098002599552, 0.09590145826223306, 0.13117773371050134, 0.1662996201775968, 0.11581090555409901, 0.06958001831662841, 0.18107993644662201, 0.17376448289724067, 0.1732424265355803, 0.17664601968135685, 0.14274756365921348, 0.11426279292209074, 0.050974643236259, 0.16629418765660375, 0.13919384888140485, 0.06450507891713642, 0.15723266842542216, 0.32460476621054113, 0.08961217230535112, 0.12674988771323115, 0.15000659914221615, 0.08347334936843254, 0.09409593913005665, 0.10493228226550855, 0.18513679766329005, 0.12284544878639281, 0.17981484183110297, 0.130429886339698, 0.13619057019241154, 0.0736236989905592, 0.08755366987315938, 0.24123182200128213, 0.11336458643199876, 0.06644706416409463, 0.20450266631087288, 0.1308040029834956, 0.14100240339757875, 0.07104814969352446, 0.1898499103845097, 0.14485806837910786, 0.13706906524021178, 0.11569538284675218, 0.12107860296964645, 0.14180822734488174, 0.10364924994064495, 0.10697342586354353, 0.16510891844518483, 0.1223708750330843, 0.17106039362261072, 0.06438328506192192, 0.10294959763996303, 0.12027673466945998, 0.15310960763599724, 0.1320849944022484, 0.12072011595591903, 0.06496636080555618, 0.0868415272270795, 0.18557142902864143, 0.07107828088919632, 0.10137929479242302, 0.12199192700791173], [0.05398664958192967, 0.090453656448517, 0.03337168331199791, 0.051251215700176544, 0.056137660722015426, 0.032041773229138926, 0.039393150436808355, 0.02290042302774964, 0.006845120242360281, 0.01852798948675627, 0.03771026007598266, 0.005584105583693599, 0.03846221894491464, 0.02837686060956912, 0.055071424576453865, 0.06303418675088324, 0.02279769309097901, 0.04587984767567832, 0.04958789577358402, 0.02107742260704981, 0.07684836775297299, 0.005337995962690911, 0.024783290646155365, 0.060880244127474725, 0.044088763315812685, 0.09619606862543151, 0.07291334492038004, 0.05879145835933741, 0.04671251881518401, 0.02681849891814636, 0.039099141213227995, 0.0606773891922785, 0.029206665203673765, 0.03542366226611193, 0.049845710454974324, 0.026569571455183905, 0.021123743754287716, 0.029310087193152867, 0.016688387222529855, 0.020579196607286576, 0.0260326962597901, 0.02049950107902987, 0.02342602314456599, 0.046118125319480896, 0.02706827799556777, 0.02948809131339658, 0.05750064090534579, 0.06408903092960827, 0.019630268034234177, 0.05495496676303446, 0.016359413566533476, 0.03640562754299026, 0.011257700261921855, 0.0652382466068957, 0.026979264803230762, 0.0866963186126668, 0.030019363293831702, 0.009871623515209649, 0.027079413921455853, 0.05008093787182588, 0.02346486900933087, 0.024493309429090004, 0.0802132356329821, 0.032400241689174436, 0.03236098949855659, 0.017190440848935395, 0.07638900060555898, 0.022173578436195385, 0.047636629969929345, 0.012424368469510227, 0.0971422326983884, 0.031444310952792875, 0.02397198222752195, 0.04006484603451099, 0.03721466870047152, 0.054139205458341166, 0.03695078325108625, 0.10971156487357803, 0.022094662162999157, 0.035663220114656724, 0.035825327431666665, 0.010550986426096642, 0.05865445047675166, 0.016801080491859466, 0.0485003154608421, 0.015238429186865687, 0.05142639594851062, 0.005897184291825397, 0.048667358059901744, 0.01636837871046737, 0.010229030704067554, 0.022429131422541104, 0.03125505958450958, 0.07728627941105515, 0.03318257295177318, 0.012655708887905348, 0.04677680735767353, 0.02223365900135832, 0.03058004102058476, 0.04547880220343359, 0.05042671560659073, 0.023692958820902277, 0.018246791587444022, 0.10699779057176784, 0.037709785101469606, 0.041223728185286745, 0.061720154917566106, 0.028890304347441997, 0.04064265624037944, 0.05033260757045355, 0.042748808264150284, 0.006461255024987622, 0.037312068161554635, 0.06503570708446205, 0.030045562962186523, 0.015164044652919983, 0.060551843780558556, 0.03429652548220474, 0.01296383561566472, 0.026991591876139864, 0.026940177740470972, 0.04954801275744103, 0.0066630157562030945, 0.049183870578417554, 0.026147204080189113, 0.0471332274901215, 0.11349908585543744, 0.08106306151603349, 0.04555220060865395, 0.0652169543900527, 0.010249328443023842, 0.01944851792359259, 0.03297234849014785, 0.03705019022163469, 0.026054762165586, 0.03203581378329545, 0.022983870112511795, 0.0554612042469671, 0.017624797619646415, 0.056729178395471536, 0.053401150726131164, 0.026786638518387917, 0.032874062162591144, 0.014134100456431042, 0.03738476152648218, 0.011788013944169506, 0.011867746579810046, 0.05121578185935505, 0.01990347485843813, 0.019385765626793727, 0.10774817608762532, 0.026161126770603005, 0.022660599861410446, 0.025249652535421774, 0.055120380347943865, 0.022530466121679638, 0.02514193536626408, 0.014267769602156477, 0.032805621303850785, 0.04556203406536952, 0.02543010574299842, 0.03186614398146048, 0.034796309992088936, 0.041012698493432254, 0.06397834702511318, 0.05922172960708849, 0.005512152511073509, 0.1192363772133831, 0.07390973754809238, 0.054396927371271886, 0.023513247761002276, 0.028850369380961638, 0.054970600103843026, 0.08672371128341183, 0.017726560909068212, 0.04921978681522887, 0.03207342582754791, 0.06518480455270037, 0.05065759032731876, 0.06828341211075895, 0.08256323882960714, 0.06015342922182754, 0.09349877000204287, 0.013258180661068764, 0.03382812639756594, 0.005892754134038114, 0.009034641425387235, 0.014239658903534291, 0.028380959120113403, 0.009223185898008524, 0.03250378984375857, 0.03911411033186596, 0.019800589070655406, 0.08327690287842415, 0.032175500818993896, 0.023725962128082756, 0.054501974664162844, 0.012998294459976023, 0.05955449378234334, 0.07751736193313263, 0.029226910992292687, 0.058737630388350226, 0.018668003067432437, 0.023203057862701826, 0.04379921068903059, 0.016237358104262967, 0.05335106317943428, 0.034087210151483305, 0.05262157654215116, 0.030650645239802543, 0.02397839809418656, 0.020855058464803733, 0.019774920037889387, 0.012885412870673463, 0.028181386333017144, 0.026930681960948277, 0.07435079591232352, 0.014849483504804084, 0.026119230678887106, 0.023973008246684913, 0.09999665882787667, 0.02073773790471023, 0.03367194512975402, 0.02042133994109463, 0.04260991161572747, 0.037671226818929426, 0.01074068401067052, 0.050029692574753426, 0.0156937683277647, 0.0922543961496558, 0.03598550145397894, 0.05740171633078717, 0.012194373193779029, 0.06268783385166898, 0.03880667565681506, 0.032429181737825274, 0.018556016693764832, 0.03214046031644102, 0.06330292584607378, 0.028039432036166545, 0.008892723308235873, 0.014842534219496883, 0.0180328471105895, 0.026096572910319082, 0.011198423999303486, 0.03370462931343354, 0.04909811912511941, 0.015192118244158337, 0.044818439200753346, 0.055833472943049856, 0.027952396667387802, 0.07793463446432725, 0.03638305141066667, 0.057790100763668306, 0.029909083859820385, 0.016742792213335633, 0.026830102397070732, 0.10192484012804925, 0.05288337284582667, 0.0066758289358404, 0.03364947660884354, 0.10104858636623248, 0.023479034753108863, 0.028774512611562386, 0.0313497576280497, 0.009507861686870456, 0.04252403028658591, 0.06999271179665811, 0.031047074553498533, 0.029586791388283018, 0.05207639856962487, 0.013113762433931697, 0.036780683003598824, 0.06427183674531989, 0.008596946845500497, 0.04648335845558904, 0.018283852587046567, 0.04235635686200112, 0.07026893916190602, 0.05383007868658751, 0.04382264771265909, 0.018470127943146508, 0.008976686185633298, 0.0051938555770902894, 0.09011256537633017, 0.0772953632986173, 0.058985871364711784, 0.008873213173501426, 0.02940249200037215, 0.056267807449330576, 0.05678255365637597, 0.02278302825288847, 0.02554471375333378, 0.021898837221669964, 0.027417970559326932, 0.04794115913682617, 0.03027841550647281, 0.012948627154401038, 0.019539850327419117, 0.08717935284948908, 0.004441730188773363, 0.011979107694060076, 0.03537933749612421, 0.02322489926882554, 0.01403472873789724, 0.018226805550511926, 0.030470891506411135, 0.023042048924253322, 0.012815402369596995, 0.009049832260643598, 0.0222352787386626, 0.03608834827900864, 0.039183545668493025, 0.02970891735458281, 0.01838402582507115, 0.025615982194722164, 0.02532148500904441, 0.05706138224923052, 0.01850171003752621, 0.02670190566277597, 0.04038062987092417, 0.06620925036258996, 0.03892373089911416, 0.04081707578734495, 0.03621245763497427, 0.04785659511981066, 0.023144543229136616, 0.05921441945247352, 0.027380839055695105, 0.047736686319694854, 0.018788611341733485, 0.04842323971388396, 0.01987872052268358, 0.01052368281307281, 0.06059345971152652, 0.015944378610583954, 0.05493850592756644, 0.010225053720205324, 0.029760119978163857, 0.0252363012987189, 0.026503720691835042, 0.021436102579173166, 0.005998215174258803, 0.01947998498508241, 0.04621323896571994, 0.028392208223522175, 0.015139169718167977, 0.021400184486992657, 0.040378136254730634, 0.09078665811102837, 0.02070862530672457, 0.10637254599714652, 0.10308425291441381, 0.18220075755380094, 0.15328232024330646, 0.12282461670110933, 0.16367274394724518, 0.18647857097676024, 0.11867244145832956, 0.11445851952885278, 0.10826381287188269, 0.19680196390254423, 0.16684998205164447, 0.08453444243059494, 0.1451860976521857, 0.10398361715488136, 0.10859334870474413, 0.2688543061958626, 0.0710119328869041, 0.18279189302120358, 0.11410971012082882, 0.1157668442465365, 0.15052001690492034, 0.11111839485238306, 0.1590388035401702, 0.22458254039520398, 0.09129721860517748, 0.19795450440142304, 0.2175078247091733, 0.13610973546747118, 0.17046882770955563, 0.16210336878430098, 0.1116472715511918, 0.17060760932508856, 0.1295168517390266, 0.13666943355929106, 0.09498202634858899, 0.1308759319363162, 0.08257941764895804, 0.17874598590424284, 0.15709881467046216, 0.0789675852865912, 0.10911276302067563, 0.13983464887132868, 0.13212055811891332, 0.1294599735410884, 0.19666766485897824, 0.10361557127907872, 0.1509193071979098, 0.162010986241512, 0.08357030354090966, 0.12341664274572395, 0.0935298808326479, 0.14428272581426427, 0.06271547885262407, 0.24867712170816958, 0.19762944371905178, 0.17773149971617386, 0.09742770722368732, 0.12457296077627689, 0.1120057214575354, 0.16537141607841477, 0.13570590323070064, 0.16256220900686458, 0.14326295553473756, 0.10303347517037764, 0.08164089027559385, 0.08599678505561315, 0.19277664396213368, 0.14326736389193684, 0.11138898931676522, 0.16608393721980974, 0.21936919045401737, 0.1144860680506099, 0.12990070536034182, 0.09798295242944732, 0.13458965375320986, 0.11859098332934082, 0.1273319689789787, 0.19276864361017942, 0.14063005306525156, 0.26447064767125994, 0.14175201707985252, 0.16767119814176112, 0.10616153856972232, 0.13704331271583214, 0.1635545791941695, 0.22187910421052948, 0.18166503083193675, 0.10584928735624999, 0.13133872038451955, 0.09633384834160097, 0.09642755932873115, 0.10685339089832269, 0.16991373093333095, 0.15459031099453568, 0.14823760109720752, 0.06946517096366733, 0.18526547122746706, 0.11534389428561553, 0.09049017753568478, 0.14786373678361997, 0.13191455276682973, 0.15374598442576826, 0.12569211947266012, 0.1820374553790316, 0.06815641580033116, 0.08278554916614667, 0.13782516529317945, 0.07141175752622075, 0.20086013129912317, 0.14748446963494644, 0.09328965505119413, 0.09344906095066108, 0.21405798092018813, 0.18589549523312598, 0.13076023111352697, 0.08350254545803182, 0.12296425920794718, 0.1307235987042077, 0.13364825426833704, 0.11835487646749243, 0.04965211010130588, 0.15024144435301423, 0.09546537970891222, 0.17655066854786128, 0.09019734832691029, 0.08113747666357085, 0.2217575255781412, 0.11604301966144703, 0.11136355591588654, 0.18774409603793174, 0.08899849781300873, 0.12420933810062706, 0.10900572306127287, 0.11638501615379937, 0.09475484752329066, 0.13869232032448053, 0.12498008814873174, 0.15802743437234312, 0.14060928777325898, 0.11417469999287277, 0.13093891058815643, 0.09301244062953629, 0.14363928377861157, 0.08262287039542571, 0.1230107102310285, 0.11329118060530163, 0.12297669018153101, 0.11622344318311661, 0.09870316964224912, 0.11788784293457866, 0.19572213903302327, 0.1929085681331344, 0.1536664113518782, 0.1075210640556179, 0.11069047250202857, 0.1772614085348323, 0.1906619090004824, 0.07302807352971286, 0.20190277457004413, 0.18051489489153028, 0.16195165895624086, 0.11702753050485626, 0.12444374544429593, 0.19670296140247956, 0.1411067196750082, 0.28851109673269093, 0.1184205045865383, 0.2938404295127839, 0.16583411546889693, 0.1477532458375208, 0.11617025345913135, 0.10338247011532076, 0.13196329702623188, 0.22926234552869573, 0.08294457657029852, 0.1940551120787859], [0.019153974353685044, 0.04304254660382867, 0.021359811653383076, 0.043012281821575016, 0.08471408669720404, 0.0647706861491315, 0.03737917315447703, 0.050479530545999296, 0.0215886065052473, 0.022577735362574458, 0.02356495133426506, 0.038658450212096795, 0.04334390308940783, 0.07598903495818377, 0.08288619923405349, 0.033181118342326954, 0.03520155602018349, 0.026214652316411957, 0.0768094346858561, 0.023951754992594942, 0.028489594697020948, 0.03249362613132689, 0.08287039891001768, 0.03792299670749344, 0.006521997029267368, 0.05468684736115392, 0.008742007958062459, 0.01656565826124279, 0.05432851619843859, 0.037773004951304756, 0.03200293293048162, 0.03303792836959474, 0.055404244412784465, 0.020130507109570317, 0.04429214517585933, 0.007345786052610492, 0.04934620053973049, 0.031588788551744074, 0.0343205488024978, 0.03753627839614637, 0.011630671215243638, 0.03165224588883575, 0.022769035058445297, 0.06828623969340697, 0.014493097696686164, 0.08261144874268211, 0.0807403979706578, 0.0219693635153817, 0.020305214238760527, 0.05447054099931847, 0.013747781977144768, 0.05016625887947157, 0.004032067918160465, 0.02053504253126448, 0.037883206459810026, 0.07936959184007719, 0.03786071567446925, 0.04812364211829845, 0.09034247530507855, 0.058582328565535136, 0.03678270906675607, 0.0637435463431757, 0.032276451456709765, 0.049075483620981686, 0.02442177566990722, 0.024238465193775482, 0.052658383356174454, 0.026956067122227978, 0.022845481835247483, 0.06211437634192407, 0.023527259509137366, 0.09015799965709448, 0.03627323210821487, 0.06471953733125702, 0.05864010476216208, 0.04822129019885324, 0.044759223237633705, 0.011955037061852636, 0.026478044237592258, 0.058386390446685255, 0.052189509297022596, 0.07058174698613584, 0.07360259973211214, 0.011086163030995522, 0.07825073000276461, 0.002834766637533903, 0.029649090974999126, 0.011925166545552202, 0.05361811759939883, 0.008776753456913866, 0.022727856994606555, 0.05650665654684417, 0.04002414665592369, 0.026651426633179653, 0.018848914551199414, 0.021747555983893108, 0.019016372752957977, 0.03186134228599258, 0.024890991116990335, 0.05707420285034459, 0.05114471750857774, 0.05797998295747675, 0.06391984352376312, 0.10647811650414951, 0.07223917797091417, 0.04514683212619275, 0.009233497112290934, 0.011556569625099655, 0.025009742166730575, 0.025500995689071715, 0.01415278031345224, 0.055633553201914765, 0.022283663056441583, 0.0447632085706573, 0.02682115024072118, 0.046655763071612455, 0.028728954021062236, 0.02203330510383239, 0.010786947641463485, 0.02299307830980979, 0.07389357357169501, 0.015128958693821914, 0.02682481088413624, 0.014201575595507165, 0.0038175621921254788, 0.013185967836761847, 0.04509946455073077, 0.019516795509844087, 0.07724292314378545, 0.005717611456930172, 0.04068618320161477, 0.04513597450568341, 0.024623769713798538, 0.03796469798544422, 0.03983724789577536, 0.03722259854839649, 0.047575911157764494, 0.015501182861044072, 0.06307335730525665, 0.08661074898554944, 0.009976142955565592, 0.05770545882114675, 0.027303019305691123, 0.02867567709472496, 0.026722691363829654, 0.010119015660166042, 0.05136324660270475, 0.03423876783926971, 0.012048190510540735, 0.026704148804128636, 0.036968850836274214, 0.0503703086724272, 0.027447571119409986, 0.07253048577695154, 0.07467227202141657, 0.03185957597452216, 0.027460282253741752, 0.020721796572615858, 0.017246211391466204, 0.018916713452199474, 0.021329101582523435, 0.09726994889206253, 0.04865129056270234, 0.04362915125966538, 0.038081322782090865, 0.04071142364409752, 0.030118206232145894, 0.06341925749438815, 0.039006636216072366, 0.049200453868252225, 0.032646649560774677, 0.042786702324519865, 0.03002666973770829, 0.06377162178978324, 0.01578896917635575, 0.1003825904626865, 0.037712275006924756, 0.0409708153893007, 0.03162489032547455, 0.02995992839714745, 0.09661252479418181, 0.05893276698770933, 0.036353454561321996, 0.03568818596249912, 0.0024525724120394443, 0.04074786680575926, 0.052082406255067326, 0.010209820211457554, 0.04480506198888179, 0.05734214042604435, 0.04892841221590061, 0.006858424167148769, 0.015020510509202722, 0.062263852305477485, 0.07936777357826941, 0.02628774644108489, 0.057512522689648904, 0.04023827852506656, 0.063867061981, 0.08778763192822225, 0.029308359844435472, 0.07885519444243982, 0.0407102547615068, 0.025410644775547553, 0.02507470049749827, 0.022342964366544038, 0.03591569133277517, 0.03424469388846774, 0.020584105914167594, 0.023317758641496766, 0.025326602117274888, 0.04480686540773604, 0.03420550478040241, 0.01967528856766876, 0.05107288503495511, 0.020484461456362624, 0.014739516700501554, 0.06368194066453725, 0.03007977968081832, 0.01829605349485064, 0.06379647631547414, 0.12462991318898275, 0.025179775620927103, 0.033546600097906776, 0.03544745923136361, 0.07003830192843452, 0.05371648556319997, 0.03584612983104307, 0.03151420642097946, 0.030246555106714368, 0.050418555692886, 0.045507957474910654, 0.039287446343223564, 0.0728914441424422, 0.04988705179130193, 0.03530172740283888, 0.042417721342644654, 0.05409388249972835, 0.01826169762352947, 0.05948850201093592, 0.008693337913427968, 0.03036051002709428, 0.05706790943804663, 0.027845560798596125, 0.027913406083825976, 0.054527170577785, 0.02855764963896945, 0.0175153809323092, 0.03839858720311895, 0.07140834364690818, 0.04340747545938939, 0.061663362066610716, 0.017436741109122522, 0.08027143485378474, 0.023044212284730747, 0.048468221284565516, 0.029058745894872118, 0.00760436050768476, 0.0316608659341, 0.028421921961125918, 0.03485227163764648, 0.025150215878966264, 0.05457352141092997, 0.0015797915534676576, 0.05376903332944494, 0.05002392608730588, 0.022291132772807032, 0.01244253160621156, 0.05950192375166807, 0.015728840371593833, 0.046483191472361796, 0.06001423200359568, 0.07815032484359108, 0.020467867034312803, 0.004737797480629524, 0.06496809000964276, 0.025603643989597913, 0.03251870701205917, 0.04751375257910695, 0.033385112474206835, 0.08894695565686561, 0.05694202263839543, 0.03163964422128629, 0.0430245680763619, 0.013443424431898165, 0.03235007250623312, 0.021185605473874602, 0.013462729548336938, 0.04789632970641833, 0.09443177579669282, 0.0633665056375321, 0.03173265387886204, 0.13541538210120052, 0.06542671500938013, 0.11197636951692402, 0.0498844245885266, 0.007695546801187447, 0.0671908148797229, 0.020350301565486006, 0.054541349309147336, 0.020133202961005736, 0.09737560845678672, 0.035903765019611456, 0.019096804862783756, 0.05570845074544195, 0.06895412065205164, 0.045370044172159396, 0.024868752661859617, 0.019635912067315076, 0.030960657022660598, 0.04770177569298539, 0.015019688580650836, 0.02088469613227062, 0.043441358211566694, 0.03332795597088989, 0.02942408849776257, 0.06566372729139403, 0.060826297412859276, 0.006617605595238274, 0.02707160838326672, 0.012380140178720467, 0.04588497962686233, 0.07081469229888171, 0.05154695412784349, 0.02098352422763128, 0.05568629021581728, 0.03916658759408165, 0.06637853424763307, 0.037462861437234096, 0.0653484629583545, 0.0898016054998152, 0.029008402307226788, 0.06749564461642876, 0.028033754606440198, 0.004472531636565691, 0.012503159505286021, 0.05580992088653147, 0.04653985444747377, 0.04535617343208287, 0.03802189901762176, 0.04518483008723706, 0.0467017205664888, 0.03815407180809416, 0.03582828117941972, 0.07178660889621824, 0.04181891577900387, 0.05110759528179187, 0.050750080481520854, 0.06385285727446899, 0.06495637149782851, 0.04356229859695304, 0.07696746019064449, 0.08457005067612045, 0.09685794560937211, 0.16430530609795824, 0.14511520770611241, 0.1742043686681427, 0.21259358996758237, 0.09313140690210275, 0.08769256281084381, 0.10619450476951897, 0.16963922535069287, 0.07637090704520233, 0.06646998910582624, 0.1752937672426924, 0.21904297202127054, 0.1765127744874917, 0.12559249356854707, 0.0996098737232387, 0.24279736768221483, 0.2412405051290989, 0.1749727438436821, 0.15988814702723175, 0.12409450559061952, 0.22185284702572972, 0.2035008856910281, 0.14685456437291577, 0.13144566386472434, 0.25261083093937486, 0.13048738794168457, 0.2390173720777966, 0.1352182825212367, 0.15558333427179605, 0.09285174339311197, 0.07975600587087683, 0.1058538664074149, 0.23136027826694772, 0.0926390067616012, 0.15138708287850022, 0.17260860273381695, 0.19706351158674806, 0.10931194803561084, 0.09901090117637068, 0.15361245721578598, 0.1072049314097967, 0.2069056811160408, 0.11704182426910847, 0.18104287359165028, 0.20085869153263047, 0.0953275257779751, 0.13041458325460553, 0.16188232752028853, 0.25976946868468076, 0.12435687705874443, 0.14758131990674883, 0.10486744082299992, 0.1275045331567526, 0.12965085392352194, 0.134136097622104, 0.1745194845716469, 0.19770085316849872, 0.11921093639102764, 0.12491943984059617, 0.1817784458398819, 0.10633246260113083, 0.14388915005838498, 0.0630370069120545, 0.10016325613833033, 0.09764701928361319, 0.09420982911251485, 0.09749008473590948, 0.1509689271915704, 0.0928296496567782, 0.19679840159369633, 0.09873120798147283, 0.1535443725879304, 0.19880185893271118, 0.15184308809693903, 0.17924053827300668, 0.12435921482392587, 0.1371343742357567, 0.1276664252509363, 0.1098799507599324, 0.11858083074912429, 0.18092254176735878, 0.08083719629212283, 0.1891373298713006, 0.11614110931986943, 0.17997964314417914, 0.08544797427020967, 0.16610100661637262, 0.09988115096348338, 0.09120431655901484, 0.15652176516596228, 0.1856775561464019, 0.09366430604131892, 0.0922248512506485, 0.14215475093806162, 0.2452983014518395, 0.08972720519523136, 0.07446370625984855, 0.1772875024471432, 0.1835519858286716, 0.14219684555428103, 0.14369101147167385, 0.2154605955001898, 0.16556841175770387, 0.09572274168021977, 0.07669440921745263, 0.10046620081993751, 0.07436411004164256, 0.17548190167872235, 0.12263296448509209, 0.13685885933227837, 0.10485118778888136, 0.22859787102788687, 0.13639605604112148, 0.13523287314455956, 0.11095349706010893, 0.17466899764258415, 0.15113585104700178, 0.12135009543271735, 0.13540534826461226, 0.15123471996048465, 0.08626375783933327, 0.15893539268290624, 0.07855109201045707, 0.1450478652259335, 0.13827955262968317, 0.07432842758134939, 0.22338168608257547, 0.12893450330011547, 0.10847374418517575, 0.11792143253842369, 0.14903984789270908, 0.19274415273685008, 0.157142452953849, 0.11867245630128309, 0.1316178124397993, 0.13721801427891478, 0.1725755474762991, 0.1058639150869567, 0.11830645133159123, 0.14238104660762474, 0.17209401237778366, 0.08766341125010513, 0.15693995053879917, 0.18058765504974872, 0.12954820005688816, 0.15398543095216155, 0.11556602650671266, 0.13847555383108556, 0.13573627191362903, 0.16659690969390795, 0.07671936022234149, 0.14426981244469061, 0.12618448992725462, 0.11563846011995338, 0.1704684121068567, 0.12033489678287879, 0.08873488695826381, 0.15561414824333042, 0.22908135055331513, 0.17398319381754845, 0.1390454193460755, 0.19018910155864432, 0.15122560638701543, 0.15660288190701976, 0.08405917105847038, 0.1890065337647684, 0.15098448260687292, 0.14769814879400656, 0.1655322840088047, 0.14628857286879793, 0.14191273658070713, 0.127194196684286, 0.11527278169523925, 0.1702453225152567], [0.0683283491525799, 0.05421159825345967, 0.037232769682304934, 0.019394448754610494, 0.06854205057607032, 0.030680969393870328, 0.05976259941235185, 0.024805516113701742, 0.017361542995786294, 0.02298764022270916, 0.03459226762061007, 0.08533854459528811, 0.04628079666872509, 0.1306352682877332, 0.04963570863765199, 0.006655198158114217, 0.051338499688426964, 0.024316064154845662, 0.046608907578047365, 0.007454219394276151, 0.03168750903569162, 0.07057116396026686, 0.01474519876865088, 0.0778432612423785, 0.02682623209693702, 0.06477953254943714, 0.024974198859126773, 0.025855102176137734, 0.020914274427923374, 0.0380199211940635, 0.07297216754523106, 0.09786042384803295, 0.03469121817033738, 0.023605749047419522, 0.03696751125971787, 0.0715327869693283, 0.012071642377122771, 0.02450009636959294, 0.023352999523922335, 0.06728573556756601, 0.04561853376799263, 0.0180406378058251, 0.03011288688867353, 0.0736348979989998, 0.021604301073239185, 0.028205042290210258, 0.05471573174872901, 0.06394289463059977, 0.03596299953642301, 0.07247798625030555, 0.007730173092568293, 0.05256147371255793, 0.010994020758516854, 0.020261075005691964, 0.03515032185532618, 0.02805266823997954, 0.02602239153929986, 0.03270703811722342, 0.036755576147697866, 0.008934458910516696, 0.0725552809308283, 0.05230387796473224, 0.013901641250413377, 0.03733590965566691, 0.04495248962484766, 0.017773269828467164, 0.020808507251786068, 0.05896894297620747, 0.038185097291716374, 0.03788797475863248, 0.03289080872491468, 0.03348961799929384, 0.06278944129007868, 0.04147819578065537, 0.04814287858607713, 0.04991477100702468, 0.07152569203753956, 0.03070763104915386, 0.03307453480374534, 0.054128088086145, 0.057430151719017886, 0.026422581686347257, 0.09148379453108646, 0.038200853086891584, 0.026491076350794174, 0.028984481032239273, 0.02716637322009774, 0.04994843853637576, 0.15744575386634097, 0.05396909407863859, 0.05102358045405708, 0.005211008001424489, 0.06855080049717799, 0.004749162080770475, 0.020781648927368224, 0.0597958290745737, 0.020709137388621457, 0.07981375238159671, 0.02490290815330809, 0.022848641528980806, 0.012689863451669225, 0.025458086565777194, 0.009945529363903916, 0.050677097678999417, 0.01961508740350837, 0.04245300304319244, 0.029967691261845175, 0.03168551265844144, 0.017462389732827432, 0.05084953940240666, 0.04558938591799233, 0.004552163618427585, 0.02156541624572128, 0.08560801099520177, 0.04462626005988568, 0.014994834982644534, 0.06171396540594287, 0.051985975296702236, 0.07965281765791588, 0.0027503164938025293, 0.042527466430328786, 0.01934390664246166, 0.008538586207578192, 0.017946225489140488, 0.021884790221520234, 0.02003377001528861, 0.033332575840177014, 0.03254929462855216, 0.030879072728566825, 0.03015294987562811, 0.05993511535052676, 0.11590019334107637, 0.09783805551705882, 0.06361579304211773, 0.06076508136175107, 0.057911341718863696, 0.04516235043411143, 0.024696399996173568, 0.046619086133432575, 0.021153900925128255, 0.028603581158677116, 0.037995255916030146, 0.01908226990053663, 0.04026091402920429, 0.028239990024303552, 0.03392947037355043, 0.012864136424468597, 0.08026620271266438, 0.03537164884619415, 0.03000597866048338, 0.09333764231996611, 0.05125179457536433, 0.016211154725169763, 0.037285157886799425, 0.07156568637583405, 0.08876340027200058, 0.05450011929497123, 0.07210455980384722, 0.0632497806509491, 0.01579190622578608, 0.008410028603975661, 0.05830054622492753, 0.014519969936372945, 0.09023196209454909, 0.016144495020853356, 0.03522542720020283, 0.06913143457495607, 0.05427322248579003, 0.03240737372834701, 0.00596640997173381, 0.046653514364152215, 0.031125090972636826, 0.020884453078906517, 0.028859110025223345, 0.011837061556434492, 0.034490341058699414, 0.010725546053436119, 0.08467234831186943, 0.02581246393674519, 0.03763640524994116, 0.09309395813033916, 0.0735918756981846, 0.04925719847960863, 0.03691938298288733, 0.01090562447643606, 0.05051871223258786, 0.0271589016483631, 0.03910435480065644, 0.010756501033029053, 0.01694685128313722, 0.09556180695653893, 0.013324320862011518, 0.09728816119604744, 0.04906790629320312, 0.024293896203744225, 0.006498134662251687, 0.013118040915287565, 0.029969424176670145, 0.025592300262360368, 0.03624336066422984, 0.0371577942132717, 0.028532817377708852, 0.028778308696928434, 0.01862490469648037, 0.01974192044144729, 0.03885634017933626, 0.02426074632239761, 0.02797665561956819, 0.021192963868088555, 0.012090338932466693, 0.01656798860494746, 0.06701263264403678, 0.03354101543664001, 0.02451785225275671, 0.022111182370281313, 0.04346665802586358, 0.04654537973692641, 0.01650957787205698, 0.06413537805201486, 0.04595303085807245, 0.009107823680096772, 0.047498876228928566, 0.014127076028671581, 0.014890322963765357, 0.06601848872378469, 0.11246517766267061, 0.04236564112943597, 0.016542965240660124, 0.08457901582005434, 0.034427729769959114, 0.028629480257222895, 0.02194794884417206, 0.00779906387833762, 0.032215929313679226, 0.01650028247240698, 0.007619929838256212, 0.01985810922633391, 0.09278428959078155, 0.04788049598573707, 0.030950684413255658, 0.021367476183513645, 0.03922092764696572, 0.03834140101389494, 0.07633345085196197, 0.02792915631289361, 0.05795463490358088, 0.09324147482402623, 0.012122291173000121, 0.0838009333529044, 0.044958842408959754, 0.046663648390676826, 0.0267162625095807, 0.06108527726610191, 0.03666821794467978, 0.013638762338814558, 0.03131953737465665, 0.02515557047445327, 0.07903868303401396, 0.05727375151764136, 0.018763858861348126, 0.05384057636547368, 0.05507715766725596, 0.06094410222431179, 0.032755897409515455, 0.12089486204786226, 0.06197025868459605, 0.04353681695647538, 0.04771661122504156, 0.016788779394119047, 0.03823123290203512, 0.05444741196697578, 0.032585745211690664, 0.07023641825071536, 0.02527475568058435, 0.024867659849405754, 0.03683467053633649, 0.04672964016208425, 0.04171481843513902, 0.039891038759378716, 0.025387927635165397, 0.03719895001268014, 0.032329722816939466, 0.02042943120613927, 0.023119293509807903, 0.016418191662523896, 0.04409107510582544, 0.03203093045158312, 0.03644535470812116, 0.027798805494967382, 0.06493911656434648, 0.07356276124482974, 0.047482511872658506, 0.009900536661007209, 0.03262250749685336, 0.023218615133373532, 0.02244647912448272, 0.042398466321174055, 0.03732063254574314, 0.028983161864744034, 0.009561967035551788, 0.037204252657829784, 0.05606816601357423, 0.02562613477493869, 0.03657347166154068, 0.036163631739327684, 0.04949653739458881, 0.015687677150708623, 0.07129174482543021, 0.10696731056668796, 0.08095875266008079, 0.07287579224794172, 0.039711706194793805, 0.025773708985070698, 0.010793919191200985, 0.03782790161494631, 0.006260165937419515, 0.006940719067642931, 0.05544473599002231, 0.037855019691050984, 0.03038013426703401, 0.05288056381687056, 0.05642665673804004, 0.016024812575778924, 0.10740076191723347, 0.03604937439376954, 0.025218832997779828, 0.015669052954763174, 0.02336919875233434, 0.07818157668225467, 0.053159392409725115, 0.017340493832307402, 0.028314876435615588, 0.018804163046297617, 0.06266998520004563, 0.052044853582629, 0.03680950801935978, 0.055176382811623625, 0.029975147990626283, 0.03514239942887798, 0.05712353711714968, 0.03478922990325373, 0.04042849839606788, 0.061759195596096106, 0.004408658696775092, 0.024709606514079496, 0.023631342010048684, 0.01828302880312549, 0.06485926147433929, 0.04114443341677543, 0.031043797971506137, 0.04388258726976346, 0.04836468797293492, 0.09989339640014805, 0.2009200374595821, 0.13072983274469152, 0.0797908051754348, 0.21081390499603003, 0.17660379147855565, 0.20048886450240389, 0.13556753721786663, 0.09529944290989079, 0.10273787032929249, 0.1704317203257233, 0.2767161437077448, 0.12069279749994166, 0.310046233353205, 0.3347420284990221, 0.12121723615564406, 0.1789672943414189, 0.08551331295166165, 0.10581315218587406, 0.08046969218412414, 0.1282466808333993, 0.13765407056780532, 0.14141741237835959, 0.13574927434092388, 0.11998216883512214, 0.10445122214150615, 0.1158100001339335, 0.14578017202438787, 0.15191452723229304, 0.07084164710249752, 0.12640064785955474, 0.21256564068607986, 0.09879810517304577, 0.13442842959193513, 0.12835779518354684, 0.14652401179773733, 0.14344280760269612, 0.12692668213276193, 0.10377831684309058, 0.1372146003996022, 0.11095167879830115, 0.10953541612252593, 0.14782866288442165, 0.25176415918394923, 0.10328714124625549, 0.13429377431748435, 0.13050025678239763, 0.19774101820075884, 0.13032237882725894, 0.16977509774733335, 0.10896219610003754, 0.05243136780336499, 0.1254480122588575, 0.11228915507672355, 0.13764906849246472, 0.09091579922824167, 0.10003604460507631, 0.14266258775023744, 0.0991314704879187, 0.09241307474439964, 0.09869028595858254, 0.1599779023672454, 0.1176632393617183, 0.12106639464036562, 0.0874460807244759, 0.12395573139656335, 0.13557944126660004, 0.14759093814063817, 0.11910060129594058, 0.09752916623256169, 0.18908609199570492, 0.0771643000189215, 0.1647258663433604, 0.12219044408993796, 0.16359008353902027, 0.1673316358937882, 0.12284709635423496, 0.13885447959182784, 0.11267032954492606, 0.1708950282773003, 0.15791134763276204, 0.20548927743220702, 0.17719672294333577, 0.1183760647836607, 0.16124019166454673, 0.17225562245585024, 0.129140256321989, 0.13175582222174853, 0.28123573400080204, 0.13938199816038832, 0.1261520283878781, 0.1534548102063127, 0.11864242900628597, 0.11096272195572965, 0.14626157353632152, 0.10740676589193754, 0.09168437478365377, 0.1292070496128872, 0.06831236329162493, 0.11397531459806487, 0.18198388715973124, 0.14237697963835672, 0.1001183784683235, 0.14283173804869875, 0.1449108647648245, 0.09250159811927006, 0.10134824333363213, 0.14351755671668798, 0.1291563015547581, 0.15759394591441378, 0.13540806452510878, 0.10851958664716221, 0.21997625241056085, 0.11489791548228823, 0.20798957295482978, 0.14553550077835098, 0.1375568937510252, 0.10542444491875358, 0.13649559288751334, 0.06868524054880254, 0.18548194086179137, 0.15672122477553785, 0.11575685493880883, 0.07043115037959069, 0.1375611239927821, 0.11180804300238378, 0.18101479072356597, 0.12182979000499472, 0.07466916242265143, 0.11262945205089636, 0.11839200611575507, 0.17135489266365767, 0.2614716289099306, 0.1509950211038813, 0.18643953400896862, 0.10285236145136878, 0.21062352927401662, 0.11117189627839252, 0.11060689183068462, 0.12539242539787665, 0.07029388274531811, 0.13880095590138808, 0.1242923918471206, 0.11214396872674115, 0.1254179107490927, 0.14316799031803384, 0.09626217171899043, 0.24296908581163734, 0.14142988045932725, 0.11022588805644773, 0.15946077386615798, 0.14599337620893493, 0.1151306381507311, 0.20675760781159624, 0.10529882158152759, 0.15182825998635963, 0.14344539027661085, 0.19094782881438732, 0.07906588274636306, 0.07553797244327143, 0.08955980636528693, 0.10580092901363969, 0.0860121994628571, 0.13266734284115955, 0.09642928111134097, 0.1001022441778332, 0.15084081765962765, 0.1514712127391249, 0.08884884373401292, 0.1002585850073956, 0.11681296076858416, 0.20442153472686186, 0.11783965528593399, 0.10948633789666928, 0.17763053794624284, 0.13610100781079382], [0.06621998181799427, 0.08370687355636619, 0.029010949729126878, 0.03921956209524069, 0.036897207610309124, 0.026559819634712767, 0.06267808945267461, 0.01680443499935791, 0.013554805955209304, 0.045421753311529756, 0.023857977212173864, 0.03737812672625296, 0.057011194512597285, 0.029719780541199725, 0.06181658958666958, 0.06860436129500158, 0.02040626135567436, 0.04453584420843981, 0.042478852046770044, 0.05467657232657075, 0.036630041868193075, 0.028841023886343464, 0.0150862916962069, 0.06027946074027568, 0.02123197671608068, 0.06131568443379365, 0.0593737734016031, 0.03669775542221032, 0.05050876374298241, 0.017527092022646684, 0.01048225612976239, 0.03516164702887181, 0.010055460916191805, 0.044207607134012505, 0.0021972478680254426, 0.007645139203305007, 0.012179546010884224, 0.05125551273522433, 0.0631868168420624, 0.019928585425077472, 0.056574266200186685, 0.09588324595824815, 0.04229619094985537, 0.04657736630178988, 0.06835286229033954, 0.02393553535512183, 0.14021428709384054, 0.040759648400126025, 0.13046493055298924, 0.020744367138831876, 0.0575313583976822, 0.09489437128650025, 0.07707336466410197, 0.019657269222079776, 0.02754812470811885, 0.03276766787166707, 0.0519476730551105, 0.0845618054154329, 0.05321788848959841, 0.05361274816095829, 0.030050646673771553, 0.0715785106876865, 0.023769657927914523, 0.08487001192406751, 0.025066917223739438, 0.026508069677220192, 0.024465367569064256, 0.02353097210288979, 0.07432657221215777, 0.058757171136676334, 0.052832461515208706, 0.011495130929688457, 0.015372432299045613, 0.038143978599691764, 0.06458456293330528, 0.05506881221663207, 0.05877441122720484, 0.010637061641318724, 0.05431523917650338, 0.009156901905953418, 0.001994582412407908, 0.047656359965913, 0.011269845508650178, 0.01102260272091371, 0.1279951966716908, 0.0023619360035809223, 0.05056352682004217, 0.029965294124849606, 0.0159751981482259, 0.004249963403708534, 0.06262591647100635, 0.029938049883639906, 0.047405543737113476, 0.03207295827451162, 0.07487498965929262, 0.08070046300417744, 0.12711508374195546, 0.0353673221252393, 0.06890299409860745, 0.016340377478627488, 0.006117851698945742, 0.05420624736871105, 0.04735325201181695, 0.013590987509815022, 0.04476960588362999, 0.021912678275839426, 0.09064725309144706, 0.02329782826564042, 0.0581157737178728, 0.01335061979261809, 0.012736608550767414, 0.048819643052411266, 0.07847765649785288, 0.022177938553795684, 0.05723467002098914, 0.06597372979740612, 0.030008487119630445, 0.028094401059206575, 0.01915129520057235, 0.03637927758973092, 0.01299952364206547, 0.031534396548522636, 0.027569331577979028, 0.05790970157249831, 0.06963918232941069, 0.022152907768031582, 0.0482871409622021, 0.04764093813719228, 0.033516554249217734, 0.05360932686016895, 0.03847595980914775, 0.07098339730873704, 0.08152052876539528, 0.03651769184216391, 0.032017857520258985, 0.03937433699320536, 0.04341124928032514, 0.03530932699504774, 0.046820749921607785, 0.023033356519590598, 0.01278544372325996, 0.01771459934388986, 0.016653007187414914, 0.024923153941927012, 0.0578561222209828, 0.038443153171101585, 0.049757198212319054, 0.05631739033560734, 0.07324290301767178, 0.020471863499551546, 0.017362407597829588, 0.06016179693688173, 0.01634351305256132, 0.024971675557026174, 0.012156995853729313, 0.051823534013237804, 0.042350794465164654, 0.059347449423512444, 0.01102752037695609, 0.0654215645045042, 0.06198938383022323, 0.10345087386667728, 0.012144216070737457, 0.03027366390597308, 0.05388635203416925, 0.05033578767324798, 0.03307373699499294, 0.02049526898190379, 0.04252200422342867, 0.020709740383608732, 0.044181071643834, 0.009611454370315187, 0.025808691971178632, 0.06498384580481797, 0.05762334760220256, 0.05412415470345877, 0.005980341475151363, 0.05646314071782399, 0.01878348681202624, 0.021915375982644036, 0.011536544625414535, 0.0875552580691874, 0.04558376043860335, 0.06733836125931703, 0.061478979187086225, 0.06065262743504718, 0.04162038385402411, 0.04180539013759699, 0.009943933746399125, 0.03975496598286554, 0.02803451345243957, 0.015003794560470851, 0.02190079278079793, 0.028556864817801397, 0.028320923083811067, 0.008742676818656037, 0.037963410359225236, 0.03920343522622716, 0.026550501970632467, 0.028096499481762294, 0.03900216477632057, 0.040870825832826085, 0.10607780204736628, 0.0211860043782508, 0.023369901937257964, 0.0578144469182007, 0.12832295877160504, 0.03657121182186529, 0.025143959574052133, 0.04373454736196436, 0.05191709286009427, 0.04833657541894354, 0.020072599181730766, 0.021043942469987087, 0.08449216227745637, 0.06431842877645977, 0.033552704262547195, 0.04465141515538562, 0.03079744947172003, 0.04317195860494394, 0.036409501553862356, 0.029717691395489965, 0.08181863464415073, 0.07680151597014628, 0.11911526613403112, 0.04789954320585821, 0.06036089289409574, 0.03772796400880907, 0.08803468546830118, 0.08198784431442618, 0.06983563624089584, 0.051262188353575766, 0.0603958480496658, 0.07978678273502737, 0.03876650320307817, 0.04271597936167382, 0.044071263473597355, 0.027414382275310345, 0.020403363268997055, 0.04253165956470184, 0.010690361759770894, 0.0284470900442102, 0.026995300759153906, 0.02021461656113388, 0.03937631110602524, 0.0366804522491293, 0.025264857285947073, 0.06638504288275726, 0.07367455094936304, 0.035891070583602414, 0.10300868743797764, 0.012276067882339703, 0.0458689195511397, 0.03373004416062031, 0.02190851853811182, 0.0370350726734614, 0.03275476563430857, 0.02584516110800905, 0.025106427310674917, 0.03413820682908408, 0.07195168480393477, 0.04441889286681544, 0.07852849361370318, 0.015376156952697784, 0.028080068332201336, 0.049991579580819234, 0.03331818188598845, 0.0038627740605079453, 0.057772151922108606, 0.019058200196013786, 0.01752643151121447, 0.026575206211418845, 0.04224958778650034, 0.04666802706196904, 0.02783504271064885, 0.027477396179165225, 0.01499001566116931, 0.029357798011915293, 0.027965502995357383, 0.018224556843051687, 0.04504598538915161, 0.01607078120287042, 0.05337917202268727, 0.016722231011954136, 0.023229018188430928, 0.012247321719769388, 0.03762402251595631, 0.03176223217451479, 0.034939848774229176, 0.03249732202675659, 0.01025091571136727, 0.035317446090630256, 0.025413220027985517, 0.03009873784321826, 0.08234133667428978, 0.07649250052054413, 0.026826573484868277, 0.01878432358353166, 0.008006611969904043, 0.03733295961865224, 0.083665439451579, 0.03626971803896595, 0.0488022174249636, 0.022057567766751163, 0.061613660436705686, 0.022993278689682484, 0.006762920429537189, 0.07067904996802099, 0.052946355208405294, 0.05988135046209209, 0.02273135065479437, 0.022009233543940354, 0.04251617836416699, 0.05452568628243171, 0.0434665875218343, 0.02674182764167199, 0.10766035033157095, 0.007196844899226562, 0.015519037078775, 0.02422720495815156, 0.05789019793155603, 0.04976244148565456, 0.028919290780322626, 0.07362224438111298, 0.016409989075327758, 0.061223806551424786, 0.08690893650054932, 0.043546030719880946, 0.029251442683744244, 0.03874399757478386, 0.023686574495513923, 0.05160968044947367, 0.033386340728611685, 0.03372350212885067, 0.01515309890237404, 0.05290843888360541, 0.02125914117641514, 0.03751362062757835, 0.03615363129938487, 0.01911792638566112, 0.04886843184067402, 0.05696062456991058, 0.019118837371934205, 0.046463728649541736, 0.03949004894820973, 0.08976845376309939, 0.0165193111388362, 0.0041086844612436835, 0.08831059371004812, 0.10027700511272997, 0.03806977125350386, 0.025152928428724408, 0.10619561799103394, 0.15700143005233258, 0.2086367257288657, 0.103954836667981, 0.1211499010969419, 0.1647841397789307, 0.1887420323328115, 0.14415400772122666, 0.13401440024608746, 0.17846276750788093, 0.12496255862060934, 0.1724380868836306, 0.11841101251775399, 0.12461490696296096, 0.1945330254966393, 0.14912577375071123, 0.1377542901900597, 0.12939220061525702, 0.13127404963597655, 0.1556963485199958, 0.10433598145027645, 0.11100330259068869, 0.10184217971982434, 0.08027859657886438, 0.10012111699325033, 0.14669892116216943, 0.1389220595592633, 0.08579188550356776, 0.17950075009139255, 0.14441230479860678, 0.2565551974112168, 0.11048656000639312, 0.16376612096792087, 0.17772035265807062, 0.13840504980180413, 0.11877260913024656, 0.13481088797561824, 0.11834566641482525, 0.1799683624994941, 0.08744658538489603, 0.15825472451979294, 0.15036490804050118, 0.10931346943834797, 0.21893288183491677, 0.15400223317556083, 0.11116529858554713, 0.183331107837148, 0.22626406891504303, 0.2544043050147593, 0.13172773935366422, 0.10401942578027956, 0.13467461481923237, 0.18316820642212406, 0.10203231053310446, 0.12617329834029078, 0.07717808912275359, 0.16565663827350363, 0.18117084953701124, 0.25107034016400576, 0.11201969609828666, 0.15698171861004084, 0.1280999433947727, 0.16484144842252135, 0.17288839240791276, 0.09793155870283954, 0.15352154412539676, 0.13925204810220748, 0.10213545421720482, 0.21276762359775603, 0.24424028088105842, 0.09092146181501448, 0.1557837735163048, 0.07521009902120568, 0.1565196574665606, 0.26875693642068654, 0.10685863788239658, 0.11813487421022728, 0.06322936416836455, 0.19413619913393632, 0.14206086925696582, 0.11451787650003098, 0.14437164994888008, 0.11925714992685243, 0.11387550315703265, 0.224467848893255, 0.07949957900564186, 0.1527207370963879, 0.07433128484990448, 0.09484854366746731, 0.1502406131476164, 0.14250838430598378, 0.330842636176385, 0.21988720953231677, 0.16311975487042218, 0.14761112455744296, 0.1880829903529957, 0.21131537418114021, 0.11794096586527303, 0.13373063266044483, 0.0863765568647068, 0.15038481244118884, 0.1378554300754331, 0.11061228724429384, 0.06575599109055474, 0.1969069184269756, 0.12819047056837007, 0.182411705609411, 0.15733777137938887, 0.1846172646037303, 0.11053194975829683, 0.12616026622708887, 0.1023642806103453, 0.1543406822020188, 0.13398150826105848, 0.1310492234188132, 0.12391264230245724, 0.11660587188089266, 0.1354441774310544, 0.13219606422353536, 0.16354648978449404, 0.12411216870532371, 0.1548259874107316, 0.050639982873690315, 0.1603879834874533, 0.20063784322701395, 0.08209713298128918, 0.16165959415957332, 0.13181302696466446, 0.10788591127493419, 0.09822832129430026, 0.10194574642810039, 0.15047627472085878, 0.2619713911553845, 0.22532986826263368, 0.11789936106652021, 0.12936166865983978, 0.13835108082275838, 0.1094140081841033, 0.11197479616384953, 0.09797841790714301, 0.1241623230453115, 0.11157486762385815, 0.13853234297130257, 0.11940366472117603, 0.13714330969378352, 0.23559078719699755, 0.2373661973979324, 0.160439444007352, 0.0813961670792196, 0.14547900849720463, 0.13197251450037584, 0.17133136658230796, 0.16989835363347083, 0.16709633055143058, 0.13730227772612125, 0.10451819354784675, 0.0997301610186696, 0.10262806958053261, 0.15198696084553376, 0.18386310897767544, 0.1306309935171157, 0.14472302718786523, 0.11411086787120439, 0.1426132646156475, 0.11303122111712582, 0.1046921158558689, 0.10798653907841071, 0.14197660580975935, 0.1382985367672518, 0.21037197089754045, 0.10183978258282878, 0.09195919948979281, 0.1104637241223827, 0.23204254946904257, 0.0966250299825333, 0.18642534414539114], [0.040727446612436324, 0.061247366029419936, 0.032069347726064734, 0.028784954629372805, 0.07618224568432197, 0.026581978308968246, 0.031664576672483236, 0.0653759075794369, 0.03574042573745828, 0.07912729546660557, 0.03450097232416738, 0.025652495860413183, 0.021102750251884572, 0.0261033858259907, 0.01587610659044003, 0.009184846549032954, 0.09677389738499187, 0.07886525796493515, 0.016533152193005662, 0.05327533814124763, 0.040259856468765065, 0.04877113628026564, 0.06639506929786876, 0.03702386995428242, 0.03048542461328907, 0.038196515233721584, 0.027941338667005766, 0.03782629486522637, 0.028818106366088614, 0.06165896855236497, 0.058165723967249505, 0.07891486311564222, 0.09413791500264779, 0.081216411490459, 0.01650131591304671, 0.05729601965867914, 0.022800680235377513, 0.04179118543106597, 0.05445309310744051, 0.043830844733747654, 0.01963391012395732, 0.0743066900759004, 0.033595151398913004, 0.010370993350079516, 0.06766705846530385, 0.011179383272974519, 0.049499672968522646, 0.028780269822163973, 0.01893746946734609, 0.0831575358461123, 0.012622086815099465, 0.051259082465549, 0.03926182740542572, 0.024946474077296443, 0.012742982671625214, 0.024580671342846472, 0.026189714299107436, 0.012700050356215797, 0.07092311265296303, 0.014007116205903003, 0.03465481953753624, 0.03846280524157919, 0.01076826036296552, 0.04213808751956094, 0.0109476439502032, 0.031144193853833713, 0.00656916190564516, 0.037187361376709305, 0.04213057327433489, 0.010423363000882091, 0.031147745030466467, 0.046647614290122874, 0.035604627555585466, 0.07428493030602112, 0.055629055786994286, 0.09971747771487571, 0.06943337735719979, 0.038779657770646736, 0.017912313051056117, 0.08256792178144678, 0.02975966355734272, 0.021751524618593976, 0.016367029857065063, 0.04824850104341749, 0.08920061431126669, 0.005669293004757492, 0.06872525715152733, 0.03859953110804781, 0.02100597419484984, 0.05985520459944382, 0.049212283702217974, 0.012930718203278957, 0.07095599721651524, 0.05183160486922134, 0.04593994679453317, 0.0494466984673636, 0.01652833008847665, 0.07103602300048806, 0.025395473421667702, 0.03666930519102607, 0.05289864253427368, 0.022360287948686164, 0.01566150902363006, 0.07702469461946748, 0.08680528073455207, 0.015180859863903606, 0.03944989133742638, 0.01604071308975108, 0.012398029648466036, 0.0640050123911351, 0.020428436728252564, 0.06311209741397761, 0.019161182462994475, 0.046506877115461975, 0.021667960645572748, 0.032417489201179706, 0.019835520106425975, 0.01710798267595237, 0.06655967023107223, 0.0017061064795598213, 0.03322033713629935, 0.02144494341337122, 0.026789215626195073, 0.04197797657980118, 0.04030401054478716, 0.05349257589841727, 0.051244217247585766, 0.0205857200853643, 0.03344755677971989, 0.05732965379138477, 0.021740509291703347, 0.031757634569657966, 0.06112791736086365, 0.02865590256988071, 0.02830063833243912, 0.04502273761318065, 0.07909885636763647, 0.05718721338780597, 0.028222401124367025, 0.05230657567153685, 0.030153692023304757, 0.02172065869672224, 0.039845615610829554, 0.04312492128519807, 0.03831899928627536, 0.01251426574526704, 0.021437113755382597, 0.01804410549084423, 0.05391931452322751, 0.059807239595102146, 0.010841910170711344, 0.07086149955284782, 0.09470907927607186, 0.010270350703649456, 0.06768476610886864, 0.03076852241065353, 0.07411923099425621, 0.08711159476661123, 0.09256188277504407, 0.051800353030557744, 0.05474123936437536, 0.05216672165261116, 0.047892641232465394, 0.056242225618916564, 0.03961060712754261, 0.03671022721391637, 0.013906929052609485, 0.04476677830098197, 0.046767790263402276, 0.055840519635239616, 0.06146729407191742, 0.04225340613629669, 0.018489251233404502, 0.018072971324727405, 0.0064660075531719485, 0.041819687612587586, 0.024829891954141203, 0.05654168962792028, 0.05589942760707345, 0.03998605963715818, 0.04479365517909173, 0.026245577610097826, 0.018793008566717617, 0.12200328186736442, 0.010638706426107092, 0.032282143729389645, 0.02712356985284714, 0.11333922724588774, 0.03102410693827551, 0.03322989970911294, 0.067821373231709, 0.11087592036346905, 0.05709167671739124, 0.032880912185646594, 0.01233942131875665, 0.02466408688633237, 0.06428869091905653, 0.04847885626077186, 0.056967366981552914, 0.039827792934374884, 0.015320628535846481, 0.018370960315223783, 0.015320743568736361, 0.020828274355153553, 0.09779358602827415, 0.031505018632742576, 0.05031097767641768, 0.049629600762273185, 0.035949655721196905, 0.04525288502918556, 0.020915582463203464, 0.03553936679963954, 0.0652146759966854, 0.054642448376398534, 0.014131422231002944, 0.026618714618962258, 0.07660225674044341, 0.049195210594916716, 0.02955840423965128, 0.029886763768445235, 0.029017532579018734, 0.005397831619120552, 0.04292484940378927, 0.03960371628636494, 0.027712851806427352, 0.0539298307558056, 0.02730020285525825, 0.030426535195147153, 0.05172403798496816, 0.07357614216743968, 0.032314505078829825, 0.008329923966812203, 0.033836386501207016, 0.0261941263670451, 0.0673182045284193, 0.04984371036698576, 0.024602629637229256, 0.041845989326247945, 0.05040717856900301, 0.06474319699918851, 0.045326402178034186, 0.06217000031028874, 0.08642821776447818, 0.04576692248519976, 0.02541114572522929, 0.04027184586448129, 0.008506666436005617, 0.03959250243497081, 0.03263040765887126, 0.058431743091205135, 0.041582679041312076, 0.011459782435849775, 0.0306438378902385, 0.0379127365158638, 0.006104750473241438, 0.04410993307828903, 0.0384723863680847, 0.04545245967165101, 0.05413773229520302, 0.030689505947520956, 0.028629712178371847, 0.027862246133736335, 0.01713306912279222, 0.013943871308583766, 0.08120458165649325, 0.053312375021050684, 0.03188852715538815, 0.04584449176036287, 0.0344456823222572, 0.06801876224926673, 0.007184755313573987, 0.09132415114436299, 0.01316651336310315, 0.026425205178384203, 0.03970161669712979, 0.03316604903375264, 0.03418440552195534, 0.014095105234446237, 0.04913237295113504, 0.019920432932849508, 0.03892982022080105, 0.04158454183198046, 0.03157131839543581, 0.06463774523581378, 0.05043820776336361, 0.03584326143027283, 0.045652631742996164, 0.06951735878828913, 0.08359713217942044, 0.03959670299082063, 0.048946999304462224, 0.03410946716030594, 0.03483963286271319, 0.011063722340622917, 0.02597509817860555, 0.0317364462534897, 0.029471020061464515, 0.10771816363558173, 0.014411962401936762, 0.01749898317939369, 0.012373286444926634, 0.05694341416528914, 0.025618290273996536, 0.1375337684294209, 0.011453535407781601, 0.030654205693281256, 0.028635506496357266, 0.05909953128139023, 0.019512912222126033, 0.04171648826741148, 0.02231732873042347, 0.05446923110866919, 0.026553576317382976, 0.041734273836482316, 0.048977089682011865, 0.0437261944898637, 0.013530979304050561, 0.03545233514159918, 0.01161103306003497, 0.019332976662553847, 0.03675301202747505, 0.024002399150049314, 0.024188045535993297, 0.05469306655868422, 0.06039176252670586, 0.07780406842357479, 0.034123026198358275, 0.0856738691800274, 0.0930576967948582, 0.033424750581616536, 0.007504427076128195, 0.022897133458172902, 0.010727463577495655, 0.04102599777979776, 0.027968924296146724, 0.045944830126245506, 0.05792447773274034, 0.03897247515851632, 0.049803515648818575, 0.020022517201141454, 0.04894513651379384, 0.043384268501540646, 0.032231844670604914, 0.029447801971400622, 0.0670726501266472, 0.06338980165310204, 0.05669472047884483, 0.01391276418871712, 0.013891370854253182, 0.022048713944968767, 0.07581258192658424, 0.05002048994356301, 0.1388568989932537, 0.1479750292492099, 0.1037440741492901, 0.06642864405876026, 0.13573772652307525, 0.07082590615027584, 0.11899986959178932, 0.21876380575122312, 0.08753827030886896, 0.17658644006587565, 0.08842882525641471, 0.1487267654738389, 0.10861533854040317, 0.1040676431148313, 0.22448807983892038, 0.16885101998923346, 0.18013075925409794, 0.19077432953054085, 0.08240525043220259, 0.09127257188083604, 0.12506892322562635, 0.10018396205850877, 0.1302206452237442, 0.12109885617974214, 0.1307269383687526, 0.12439496407750994, 0.1628784678177908, 0.1032917425618507, 0.20889390958473086, 0.1292147976346314, 0.11296549651888199, 0.2127868600655347, 0.13343279395485297, 0.1268355463980697, 0.16962043417152017, 0.12693138734903187, 0.13239248102763668, 0.1473155865096487, 0.1898143911967054, 0.09230271738488227, 0.14906656520906836, 0.12337201740592718, 0.09178121021250263, 0.1389596567605622, 0.14880145521601662, 0.08729425215278752, 0.10689332586480305, 0.12093671917682514, 0.09092295353184454, 0.1535018178401515, 0.12977218022570014, 0.23847958218539134, 0.09429923564312048, 0.1832892803940922, 0.08071141710388474, 0.1142940967110917, 0.13839644088875502, 0.19911357579985633, 0.14225811726646498, 0.15207771066343412, 0.08184281381545588, 0.1634645863668993, 0.10471003130078316, 0.11714894586475566, 0.1301609171787277, 0.1314085119520314, 0.20155993202934042, 0.1809351285919547, 0.1803280963213183, 0.10049234668258578, 0.12067091898643412, 0.19866564514813945, 0.12725444423267618, 0.17747428617440164, 0.14492362970486283, 0.11983612159383483, 0.14252797700464725, 0.11833443029900081, 0.11804376073996536, 0.16614443709840998, 0.1081852639617864, 0.16690021060639992, 0.09509279931080528, 0.13859440136002377, 0.15352880232967436, 0.18390272482065484, 0.1310320501215756, 0.1420876311021857, 0.13783490227069706, 0.1217200412065722, 0.09232061056536622, 0.1238820658181794, 0.12883716321084648, 0.10074155245092697, 0.11002050610841252, 0.22570917994016781, 0.08066802372923121, 0.1494717481546104, 0.07036333292489871, 0.08123759238515049, 0.20256583899026737, 0.042718387630884536, 0.1295468196622096, 0.11783446025219746, 0.21241154114250094, 0.07931429441669025, 0.07865212057367899, 0.17700367548968643, 0.07411910482915118, 0.1301707432139665, 0.14863010816043243, 0.15956345741869882, 0.1362704994971864, 0.11686207610182464, 0.0922420690767467, 0.1276885115657933, 0.17298270453466102, 0.21355520555516705, 0.13573354081017897, 0.12755298055708408, 0.10292697697877884, 0.2547922998201102, 0.18196819815784693, 0.1527267336496152, 0.1817235120688565, 0.2096164645627141, 0.14136114274151623, 0.2040203000069596, 0.16108382114907727, 0.13835955614922568, 0.1829505048226565, 0.13742036826442927, 0.13880108948796988, 0.09942199161741883, 0.17012135416734964, 0.22279136697761714, 0.1282926939893514, 0.13145994278602302, 0.13439776404993609, 0.1434653837350197, 0.10418212681543082, 0.10298188848537393, 0.13405913690803573, 0.12411974603310227, 0.08832311374135315, 0.056041504358290695, 0.10921707187662832, 0.17367987806210294, 0.1114741581841372, 0.12606553849764168, 0.15698056085966527, 0.16787346306955442, 0.14760098682017997, 0.11782797388150357, 0.12847308040363714, 0.11728451398084871, 0.13490022771293297, 0.15269810159225017, 0.18833993672160432, 0.15203108894638717, 0.19821661611786112, 0.13963146368041635, 0.19366300577530637, 0.0787556279101409, 0.1261690235696733, 0.16958938271272928, 0.0970431930909399, 0.14468814624706283, 0.14942344918381423, 0.1370040827896446, 0.1501969451783225, 0.12765287363436073, 0.0944784123566933, 0.2261609400738962, 0.09253172189346515, 0.1022689146338962], [0.04596082340867724, 0.04566971227177419, 0.07712013481068425, 0.03133177538984455, 0.02805102809361415, 0.022214526434254367, 0.008135305015457561, 0.1177451502007898, 0.07692518003750592, 0.0365851753304014, 0.026629256826709025, 0.01861784501670627, 0.024638991162646562, 0.06255400978261605, 0.04791001862031408, 0.02817413926095469, 0.009457513460802147, 0.08329584990860894, 0.05464959154778626, 0.05579927848884836, 0.029477714233507868, 0.0380168672563741, 0.09184585127513856, 0.019239219291193876, 0.04327495757024735, 0.03275416820542887, 0.012171013167971978, 0.010793074998218799, 0.054036644360166974, 0.051645351777551696, 0.004744814486912219, 0.011181238642166136, 0.1021560191293247, 0.020584612429956906, 0.04073405172675848, 0.0052570169827959035, 0.009560112594044767, 0.022111418002168648, 0.020909559934807476, 0.06214871180418413, 0.06322391680441797, 0.026190389653493185, 0.1174038067983929, 0.018757053367153276, 0.032860866776900366, 0.009271663911931682, 0.04497260924836155, 0.032356506926589645, 0.055385560845024884, 0.0351751726702787, 0.021166159349377267, 0.0452794576267479, 0.040415870753349736, 0.06866689465823583, 0.012456267832021695, 0.009589836536179064, 0.03515234049700666, 0.035083959010080434, 0.05294447757478338, 0.08950059782364406, 0.02721792279771762, 0.0877725292230025, 0.0651230281800963, 0.012936506955156801, 0.014796235336689278, 0.021661682076228317, 0.0408330876234686, 0.029882036287744995, 0.0916768865135964, 0.006614899075430003, 0.04617233178578317, 0.05066347184765618, 0.04818351117137354, 0.029601157511933707, 0.03508740999677684, 0.04511075261689257, 0.06979535246500745, 0.05332973385520745, 0.03736830811249092, 0.031203339312924072, 0.053104688704479486, 0.05188932169403415, 0.047048622654983774, 0.043278093144181184, 0.036699091288028285, 0.03318471404782031, 0.061423310689860955, 0.05872545916645322, 0.009971237359422958, 0.049180393616552465, 0.039223183775902726, 0.02531685029680375, 0.03718601437867619, 0.047171633632387966, 0.04070453280291986, 0.029130834409443196, 0.02938017376436619, 0.061100498714949936, 0.05491788535437081, 0.06692426512017846, 0.04906843321805354, 0.04420147328346502, 0.04184590026852675, 0.01445328982299543, 0.027160662393725943, 0.02849324791895924, 0.06090232673159335, 0.008722141592443222, 0.0048193697148235515, 0.021720053846365772, 0.028029433451592922, 0.019500097187119536, 0.02951211092295125, 0.021891048381803557, 0.038185063895070925, 0.026445911098562647, 0.06755691632861272, 0.01219362269694102, 0.06824404117651284, 0.021747418686572928, 0.05179251224035397, 0.08237211353844032, 0.03859097785607446, 0.00866116859469912, 0.01198068939629593, 0.03267986809078138, 0.03950449114199728, 0.048584033429506235, 0.02993237616465194, 0.03333895088871941, 0.05098915222333744, 0.028023193845001515, 0.04263942682882771, 0.08750352295464836, 0.009896862102323212, 0.09395192537340336, 0.045850855676690117, 0.103963512374321, 0.027935000725847203, 0.05825386513606645, 0.051356366893742234, 0.006673682737527997, 0.08977059114840813, 0.01681183977780165, 0.03048296995984856, 0.046155614909366705, 0.02051040322839981, 0.024418051943939645, 0.014779768007429084, 0.0050148862010246376, 0.020485986569838133, 0.029710585331486072, 0.03985122253652662, 0.03798876583459787, 0.07187973358668387, 0.027572504259296693, 0.013817909366480308, 0.0329742409667233, 0.05093298648716882, 0.029916852290625684, 0.034585269168019295, 0.03469693641818594, 0.04985829727957025, 0.035264965117676184, 0.0710540942964144, 0.019185530472896062, 0.027455005583760794, 0.017637607088545337, 0.03329596198454965, 0.016886447883734945, 0.09558398232911713, 0.059116307529620826, 0.03959085857786704, 0.03737795974302571, 0.10623532289173454, 0.021783103002235293, 0.05518245729035698, 0.0431882561679231, 0.015161348801484564, 0.01810610636312049, 0.04924043707433157, 0.0032270710016746307, 0.05137451982591301, 0.04621909451088868, 0.017122081626439467, 0.050778712538885884, 0.14097320730797946, 0.0629857690364588, 0.07939961913507432, 0.018231301110063214, 0.035339168753125705, 0.04336708036134951, 0.010607032490952406, 0.03734024379809853, 0.06543590279761702, 0.06699421996017918, 0.08205736128729768, 0.07001463483902626, 0.01883403634565184, 0.027821784242405556, 0.06484145735157654, 0.02276783277920913, 0.04754471498017665, 0.01844141796027543, 0.060968344478169456, 0.015629184781573713, 0.03799294041527901, 0.027868136930919718, 0.021161212935112417, 0.008774250563874375, 0.02359083930059569, 0.046297443041112274, 0.05072595697129145, 0.03734235520823859, 0.015350459161709296, 0.013187942877266323, 0.05258538942143787, 0.07896224924479611, 0.07253670497448184, 0.08353843571967445, 0.046958585298852995, 0.011466190881037619, 0.05153403333679307, 0.05152578807610553, 0.020349268124846276, 0.009874238658085233, 0.025633877230575308, 0.042473300782148726, 0.006656500163444434, 0.031909960380289704, 0.03990398552559782, 0.04506742974626832, 0.09096383844735101, 0.03754451252461877, 0.02919134913099697, 0.07487703798688017, 0.01726043836242752, 0.03982666486990638, 0.045655477879336104, 0.016314253880409524, 0.0256360257480992, 0.06505208628368564, 0.04568950163957197, 0.016152627104020212, 0.04485150559048634, 0.03862546174786985, 0.03723602771060541, 0.04121463316550944, 0.043127704338985495, 0.03966676915297285, 0.00796163596533006, 0.0068769249810429756, 0.04878287705651019, 0.019869003954227082, 0.040057012665783986, 0.037604630197165534, 0.06374511969625019, 0.05784068926004693, 0.06303009751718491, 0.04451767272257712, 0.03552634581865277, 0.010617520892992616, 0.026075265850522555, 0.08984161468106322, 0.04615427533281036, 0.038713532412657514, 0.0228200039055082, 0.04587019233440515, 0.06041800486855209, 0.029484232145478018, 0.038000384156475775, 0.028934094771102536, 0.027888970871572383, 0.03803785890340805, 0.039591415188624524, 0.08393557378440164, 0.039309929707087576, 0.06755411101039499, 0.02046906931354897, 0.04660488884837832, 0.02485808428900782, 0.030503130401484668, 0.029799938056385145, 0.026410061655042227, 0.05417678039520979, 0.03302247314422857, 0.05691782120265998, 0.0625498834415339, 0.04653723466617521, 0.008360356659977697, 0.012364825033728266, 0.12410327777615748, 0.03306528022221755, 0.03900644696841482, 0.03769699047552422, 0.05174333382456098, 0.04566138166410383, 0.05095580010674894, 0.04438259813468903, 0.0445337216660846, 0.06400714235496707, 0.055280431915889494, 0.0645401825022418, 0.09645470709074289, 0.022103241390141193, 0.007270067044373718, 0.012001630020677112, 0.0042233346812281525, 0.026254963922838215, 0.0188262103984016, 0.015514383812842425, 0.02948192777694203, 0.02928462596173631, 0.015782649788889103, 0.037301247648429126, 0.02543304279242875, 0.09511820302577689, 0.02248414126370335, 0.03418719599721953, 0.019272684585303068, 0.01823677259380929, 0.036956319672754034, 0.00784953363108798, 0.005457757260955987, 0.04117606375075411, 0.007487015363949467, 0.03897041569871362, 0.020823018094233703, 0.03276840259786695, 0.04941251143463887, 0.034814166065189056, 0.03507236666337121, 0.05858371267095208, 0.026618883457558695, 0.06218688788067084, 0.06261260976316407, 0.021796144392283168, 0.016332549676008057, 0.02688651304197265, 0.0314081201213412, 0.07833781361114234, 0.02674015224329196, 0.04820081434445456, 0.050812636109185405, 0.06568783224793151, 0.03992109945102129, 0.021152297886146698, 0.0424668440973619, 0.022211622781469487, 0.010142974970221985, 0.0942117215890903, 0.0637270558218006, 0.1200754419551231, 0.09080132294911891, 0.193342620623298, 0.1424480476998724, 0.13886245025787503, 0.1291890599532053, 0.1334872082225047, 0.22450661868788302, 0.1535865117330104, 0.1703348700539209, 0.20576005743350834, 0.12167811728431843, 0.1564374126610346, 0.10841199007700197, 0.13066633458947763, 0.10560123933828436, 0.07041608478175476, 0.181385493488051, 0.12814101384719834, 0.1639851287472993, 0.16432871343567967, 0.13746299722697586, 0.18697895662626252, 0.04707525462436024, 0.20098463399335742, 0.08424237763392739, 0.1906017356668599, 0.10334119928302243, 0.18988859112141654, 0.1316288110683672, 0.103699300379958, 0.10854335021576844, 0.16347641620086506, 0.11403935452108271, 0.1653279410675168, 0.22020290431100875, 0.1814689554157667, 0.09430260499357246, 0.0967220361053478, 0.10998843048582785, 0.15901932958513498, 0.2098632583511062, 0.20118492480833083, 0.21851523080840707, 0.08046463073696941, 0.11932870038435794, 0.1356581979780458, 0.15688648622017354, 0.12557635927805677, 0.06018936401233077, 0.13106969185173512, 0.11309037028695457, 0.10941311760689132, 0.14736444951267913, 0.08828951671603136, 0.135670012969058, 0.20792114693904296, 0.11812162687419914, 0.10595796004054137, 0.194693329394795, 0.12499062664574012, 0.2320156985661015, 0.16722083324566483, 0.14344693394377828, 0.13732228602748364, 0.22655264561763033, 0.11612403992330655, 0.15803677059011534, 0.12888218188891187, 0.06297948304563761, 0.12811276770662516, 0.11009622743586078, 0.13638945092679933, 0.12453818373614922, 0.07507879083277658, 0.14136145444354042, 0.1189300706028007, 0.10145473410375416, 0.12173550014267676, 0.09251300492906012, 0.17344178224448115, 0.2933308115461841, 0.17681286932202056, 0.16596415458479896, 0.10079736937768757, 0.167128064786084, 0.21973793394863605, 0.15779402892803773, 0.12167393899289891, 0.1557975626201369, 0.1910710401716642, 0.0999027474608738, 0.14981966698542237, 0.10160905629163608, 0.12089979732991196, 0.08360850930330344, 0.09421466049388982, 0.11266723478911445, 0.20432508521480486, 0.22287709987722337, 0.12296388813410886, 0.24513599375495687, 0.07893248912296258, 0.10847033772733994, 0.17749742633895949, 0.16120775981107727, 0.09386393634486012, 0.06960934799280949, 0.19316621212055907, 0.1406312405015342, 0.1885806448990479, 0.11408014295739122, 0.08666537105455063, 0.09776536215213127, 0.09566613807692192, 0.24919534858781844, 0.09148855911917053, 0.14120351057499647, 0.14964637550292537, 0.10666036570910364, 0.1970930490642786, 0.1669756870251149, 0.16435198718681931, 0.10219952382612973, 0.1747499214252457, 0.13844191969837993, 0.1435871107969433, 0.1774109512916766, 0.12572851439472288, 0.15598670637700707, 0.1988882152363658, 0.0776773838151712, 0.1516733440803364, 0.166845707281027, 0.0987719593103975, 0.1642965042265132, 0.1392635068623349, 0.1404706694302149, 0.12244008772540838, 0.11769860269851051, 0.17288770963205025, 0.09562807332258672, 0.16116139042424038, 0.1380023456295021, 0.16793946968391538, 0.19068139779847115, 0.13015066069783643, 0.14095931430347264, 0.12023225033772178, 0.0703700419398956, 0.18920097645604983, 0.11397447597119026, 0.1466638917918317, 0.11152259816299193, 0.13103819510433823, 0.12493474292568862, 0.1048359960259404, 0.0893550032924395, 0.14549475687090307, 0.1294539324590005, 0.12309849145822227, 0.08596070925705135, 0.1039883669000119, 0.08532306339475326, 0.12589154939632863, 0.14603422401705757, 0.122514621616574, 0.19292449462227523, 0.1604528768802993, 0.12386705217068084, 0.15708190854638815, 0.1756935176672414, 0.13809416414005682, 0.13863461092114449, 0.2837997948518023, 0.2147410684847273], [0.02246852276584832, 0.024104796975734644, 0.027317860403854866, 0.10625965791405179, 0.02009849456953816, 0.043466398274176754, 0.04016531056549866, 0.060282139893388376, 0.017687043400655966, 0.060871156529174186, 0.0357179572165478, 0.0746056271600537, 0.09311816698755138, 0.04118922573979944, 0.055264319889829494, 0.10157865792280063, 0.013850046216248302, 0.07066411795676686, 0.03378944194992073, 0.019805316551355645, 0.02099531138810562, 0.07237273486680351, 0.03465855996182654, 0.04957023265887983, 0.014461854207183933, 0.039744479436194524, 0.09024472703458741, 0.0038924161344766617, 0.03566142411727924, 0.03211907904187683, 0.06049551106116269, 0.039203995547723025, 0.0594936191191664, 0.05103382580273319, 0.024255430689663626, 0.02618838771013543, 0.06327599330688827, 0.07266332278959453, 0.023761581505823415, 0.024400069705734495, 0.042649854003684595, 0.030993530453997664, 0.06107761088060215, 0.0929770921356976, 0.010957958875223994, 0.03367977107700426, 0.06378376332577318, 0.015245097383740358, 0.046387183538172394, 0.02343090091017075, 0.08613711775979027, 0.03304016965557821, 0.0247314720400027, 0.016768978894106112, 0.07155698098358698, 0.011087363454862498, 0.024650815430504736, 0.04500035443925299, 0.01195357966935262, 0.09826981477090158, 0.01215038795635337, 0.1261679400340654, 0.05312994398991577, 0.036560751250362955, 0.039694410443189554, 0.03338930560857989, 0.05072141873824876, 0.024765872440184467, 0.017616773147892673, 0.033141183375846595, 0.009261243230866967, 0.09967424761271104, 0.029665583351743408, 0.004893282984994585, 0.026046631937788334, 0.043344537625671364, 0.05758655934187118, 0.007840375528758159, 0.017048184126906563, 0.03555917843186762, 0.01008633147648652, 0.03752665645151865, 0.04882225541223306, 0.0751909516111482, 0.022422350048145745, 0.017343482832075097, 0.010492967176105594, 0.048998444981407374, 0.02821522270096466, 0.03509489826683421, 0.0327102738810936, 0.05397898319642991, 0.07054822417558171, 0.07208933093352243, 0.028910247710882686, 0.017973543945117854, 0.020307058475736994, 0.05565619241679087, 0.006091941004342516, 0.06067729271308053, 0.014480007139354711, 0.0525532692699926, 0.07589346860186197, 0.0725777457410004, 0.008980927559605334, 0.04008557792985812, 0.03781584542593919, 0.0438395315723028, 0.07793502780259587, 0.06508050311822444, 0.058396398308104835, 0.044566339056473225, 0.03713692873134278, 0.054791185903013684, 0.02578057385107968, 0.0554326315614162, 0.073842187266564, 0.005529588343051728, 0.05990334400848951, 0.005944620979789761, 0.05878296447917819, 0.06676587596302852, 0.049651427325443365, 0.037420904118334875, 0.042407691216794774, 0.04010009804915171, 0.02769267466646852, 0.0231036694458453, 0.04432230234669987, 0.02645032316650031, 0.05088343328679912, 0.05214310651354026, 0.08097297963104211, 0.03780922917940188, 0.07356755551882088, 0.023294644452107605, 0.015331325666920748, 0.016912578903429676, 0.04848304939514492, 0.009458324257138884, 0.10991083894623443, 0.023646569025004283, 0.016788144857855514, 0.04930588336719666, 0.0040669896770850755, 0.05205215260502882, 0.022077961984905414, 0.03750143827346619, 0.01750985193211818, 0.03347573241626378, 0.062301160069182515, 0.026571519592835102, 0.019780437905865256, 0.01856164959463058, 0.05229316506301984, 0.028026179134030826, 0.04694668125011958, 0.038546812647837214, 0.011577815457712859, 0.04073269359651022, 0.018226169158879202, 0.01525158839285723, 0.01753841348545393, 0.027761386409110855, 0.04861651352257468, 0.04686291875259485, 0.052371053461683914, 0.04883852328930516, 0.0957489394932054, 0.015044961492094444, 0.0628372875507921, 0.022489505136036314, 0.028809490031562746, 0.019291767057438847, 0.047726656193844974, 0.016931479549384676, 0.02267548919917317, 0.03653297266282607, 0.025050283838936593, 0.03671735554235056, 0.017524845170555636, 0.06084995337005239, 0.03212551717297174, 0.07540811144281179, 0.035467237466946244, 0.013566570851253346, 0.03718489002494607, 0.014839244649920147, 0.09518998354906216, 0.04190600309811998, 0.040843915558070876, 0.09667260164860636, 0.014176715503708692, 0.039426728908438236, 0.056747494600131176, 0.031560698262182996, 0.016032855601224583, 0.06026746763382107, 0.012607452590600587, 0.11251700183493085, 0.027862153365276754, 0.0442525367543567, 0.06423782411729917, 0.04357207639259286, 0.04567064366710838, 0.04259410015947651, 0.0754284908180125, 0.08565853640902787, 0.055627159599680454, 0.04894773031992372, 0.009116210876527475, 0.03488994676445145, 0.04345318804553244, 0.018365648393228184, 0.06467906801844947, 0.026699193113017827, 0.037788404515595175, 0.05098806868772954, 0.04254375657183118, 0.022263641767494846, 0.040142274301615544, 0.030870077898725867, 0.02815605312207481, 0.08782469478319399, 0.08973872332717292, 0.012435487697075587, 0.08524461096385494, 0.030728683923371136, 0.023384553787764162, 0.05482359920279123, 0.03304971738543827, 0.008244421132985735, 0.019737647526198998, 0.05432005200418644, 0.03335091059852857, 0.021912908341619186, 0.04124468643567525, 0.1401156556676142, 0.01902520245494088, 0.038155745351105, 0.041107789875240996, 0.024595514296379406, 0.0829517531383317, 0.044185287042637356, 0.038926643828745, 0.017163946176879108, 0.05051276020822115, 0.009019673234433867, 0.033350821540807374, 0.03029514537047362, 0.034250875978614204, 0.02313707907887874, 0.05018669391574804, 0.015815486112842336, 0.019668408858706243, 0.03547563115716912, 0.028008794324705377, 0.04835265775909647, 0.03369554913660977, 0.05372862709918991, 0.030129076840239577, 0.038962040562182665, 0.04821178699785378, 0.050788583102985285, 0.03101963364315452, 0.03275793460488785, 0.06434390670619905, 0.06633511860854924, 0.03236752039811108, 0.03124649520032108, 0.03726306043972727, 0.0747714823228307, 0.01992571516893804, 0.05908419108891394, 0.034248731171828695, 0.04007305789855309, 0.0410351299069589, 0.06053681529010646, 0.08500907555571757, 0.040232820028904825, 0.008779053187026875, 0.034862350003095344, 0.022507774956466164, 0.021048690359748434, 0.09934348723618314, 0.016926327189139556, 0.03636670560808852, 0.03511222741508391, 0.007485885907954071, 0.04751265048980713, 0.024030914319155272, 0.07501757849240676, 0.04763677468872629, 0.03684360228362493, 0.05602372621069662, 0.016360858899133746, 0.044959220904274844, 0.06180839998705778, 0.05222322135523427, 0.03273306523624342, 0.008570307454647264, 0.029308652992767747, 0.04606431961292401, 0.06866429714136757, 0.04053913777170237, 0.020863331556029152, 0.04578017724270467, 0.0594296348572243, 0.01618622784008039, 0.06683600891847163, 0.020277626754250377, 0.05266557105642278, 0.024262039514724165, 0.011954435922234552, 0.07192790639237501, 0.021124697414052207, 0.07823454376193695, 0.057580585053074174, 0.04351219620730262, 0.03540864861861337, 0.00505684769450454, 0.04943759231537115, 0.058996602820116095, 0.05118517568917014, 0.04035996476886794, 0.07682003997615539, 0.044979177255299874, 0.06163994730741251, 0.023644364846404642, 0.04251164384186268, 0.0652256968896836, 0.035589075851021335, 0.04755490837851539, 0.04251844933605753, 0.007641294878339977, 0.010885688534472138, 0.03269226937845815, 0.019488840662233997, 0.0409638651763089, 0.014935739618522348, 0.0704604058410041, 0.03214913602278102, 0.027151908761879895, 0.04102113671251573, 0.031171838854788803, 0.04280339693650603, 0.0270097540851566, 0.014167619556246791, 0.025266410229960456, 0.03671784907055553, 0.025549207457515877, 0.021949132569716312, 0.07811447168933228, 0.09884345781756565, 0.07766594731947407, 0.17394860973581672, 0.09329152526333928, 0.13246780901681632, 0.21161186217796057, 0.19685357285197824, 0.0885781305260025, 0.12768552813213319, 0.08375477918889374, 0.12845626333728433, 0.21453084773384035, 0.12077309787855484, 0.12191959729534574, 0.2375943781225942, 0.07436949803377502, 0.17783799790777266, 0.1383938582148403, 0.2002510507008992, 0.16690383228706196, 0.18394196958979592, 0.1538530911784619, 0.17609245172934607, 0.06971888898988254, 0.12986070360057056, 0.1946375792613253, 0.12460037571145222, 0.23794977780198678, 0.1108282596396748, 0.18629211379447952, 0.3593672899296507, 0.09091381769394502, 0.13878351543098688, 0.08498442140989937, 0.09761737048393115, 0.19058067351579666, 0.12405003610183485, 0.08876144100213423, 0.1267307551461272, 0.17018486716551706, 0.14377978717675433, 0.13361233432078734, 0.19131851673591882, 0.10239875336992554, 0.11600605328567326, 0.12822046817746013, 0.13995189336128533, 0.14873440959490836, 0.11314277333440259, 0.138173796585761, 0.18587769853184, 0.12485073180869222, 0.11386569938622415, 0.25512843334581703, 0.10318096959963441, 0.1606671794434078, 0.11259963997872546, 0.1231199321046006, 0.18537765427026898, 0.1477700035320595, 0.210592373914551, 0.09452886355575174, 0.13188657379942015, 0.11062979450798593, 0.10982168474583887, 0.15668076288420707, 0.15875006356509402, 0.15383657097117975, 0.12060047432896681, 0.14513342001009732, 0.1987814498716034, 0.13649182277731597, 0.10287426965078339, 0.10024526345659979, 0.1725303803686984, 0.15677773189963773, 0.11024153995094821, 0.12162626342615113, 0.12302439543418586, 0.15489058394450694, 0.1492789975600317, 0.16096427600132301, 0.17266337323235348, 0.10388570561190136, 0.11824607019661926, 0.09963890654034913, 0.0731418447685428, 0.21804755902849138, 0.17034871852956712, 0.2001373388338834, 0.10015334104537033, 0.2206842612940818, 0.1394806889584288, 0.17788350640330464, 0.1392967253923416, 0.08819454407785088, 0.16794237890280783, 0.20827354834182188, 0.20935030071996152, 0.23447345418389887, 0.2070915445801802, 0.20138423598837107, 0.14447537250816822, 0.10299999688868411, 0.15165102027822286, 0.10098226804984733, 0.10913766949670389, 0.1987729745451361, 0.16815069975564256, 0.15922894177492708, 0.10790122920298018, 0.11217927269171923, 0.1992610702291131, 0.09936644186382182, 0.22039936564397067, 0.1938566766330041, 0.09478698993916623, 0.23664557200390846, 0.09436636290047318, 0.13713265245314687, 0.11645485225017183, 0.11715014814399183, 0.21583396999631077, 0.12655632075620815, 0.13714777742279693, 0.10037233398179524, 0.15022057516034693, 0.14601096510887146, 0.13256917154649273, 0.12515145004726946, 0.19283174100564793, 0.1462770695798099, 0.1300578031805344, 0.1405025669373572, 0.18428916111588478, 0.20796999509911984, 0.1047566307533998, 0.14779881370486692, 0.10398762475233525, 0.3078115376411006, 0.09331190463854, 0.14507027808576822, 0.086309496400645, 0.11041832694900222, 0.184466831269674, 0.17045779939508066, 0.18001688411459327, 0.045871773108956404, 0.17606399778742343, 0.13382524164626375, 0.13704381737625226, 0.10231733234832063, 0.1251067133853212, 0.15219903696561232, 0.07466033086529933, 0.11252656069700606, 0.11663101584417745, 0.09246031986549497, 0.1177463450585492, 0.08779292344115674, 0.06541868497151881, 0.11472512866021134, 0.11252742900978774, 0.2133272771607153, 0.06079895669245161, 0.1541650455328636, 0.15644287486793473, 0.17952878843061626, 0.22134214552352205, 0.16406654234742746, 0.11124771408503875, 0.15200466848909855, 0.18698502739425749, 0.11550001247087494, 0.13854690390871838], [0.0366656909318408, 0.04494495311519131, 0.03670695805340074, 0.05641122748784255, 0.08004606686881743, 0.11713696017977782, 0.051548679621191695, 0.03800669241172727, 0.04796264060132671, 0.039894790315884165, 0.025647998445492703, 0.014583338215743424, 0.06646698340773582, 0.06829815858509392, 0.05033514571550768, 0.01363988390949089, 0.0022981113033893052, 0.04301055261748843, 0.03906436788383871, 0.04785353004990611, 0.02792330262309406, 0.03874979374813847, 0.07881678087869659, 0.08800985320704058, 0.009427296918147476, 0.0485499799833633, 0.04312845761887729, 0.042347354610683396, 0.0449123988073552, 0.034140548305003904, 0.06271374964853749, 0.035953982442151755, 0.041467575647402555, 0.04728925290692132, 0.0587379680655431, 0.06718134507536888, 0.032977012888295576, 0.05394025793066248, 0.0550154666416347, 0.08874912877217866, 0.02794331834593322, 0.0422833703487413, 0.05612464345176704, 0.04323833629314322, 0.049899798177648336, 0.01861310454842169, 0.016015634064387996, 0.0583896113676019, 0.034039779493468814, 0.02742731976468349, 0.0704037280229386, 0.018402852256258484, 0.023079360398696736, 0.02658367968251696, 0.018218131699541118, 0.06013046717271209, 0.06297669999185018, 0.06734597569447942, 0.046508161030942574, 0.005218962432991248, 0.03324298748339061, 0.036482187497313134, 0.006866606809126097, 0.04417130498040933, 0.04084273925400339, 0.012103473090974148, 0.022056205925764516, 0.03528028304572217, 0.04718319258245174, 0.010178981192439096, 0.01029376546284766, 0.04456421280337963, 0.07972295803483576, 0.03650963582913391, 0.03052975494938437, 0.07047110761050135, 0.0573968181561213, 0.03345358301885426, 0.025379973667440936, 0.016638292254356202, 0.020012049208162352, 0.02542893500503851, 0.010401380586699815, 0.023997857206268236, 0.026368250910309143, 0.05230967413808685, 0.04517834742728155, 0.06004504226439167, 0.02455329908116255, 0.035131204131175764, 0.04500141571043059, 0.0514690471754875, 0.05740879270888399, 0.04072287498274818, 0.010941020282189129, 0.06342262684484012, 0.04791155857674312, 0.022278250944509637, 0.015432207655976526, 0.06551408805535175, 0.039947026380104944, 0.06607208662899211, 0.057075746517512016, 0.015111434731807094, 0.058497809077380225, 0.006901571705384413, 0.028050413966411725, 0.025012835067173, 0.06228576792636886, 0.040684724881430157, 0.02926440614828607, 0.015946629173413385, 0.027070812429883517, 0.09864710038527846, 0.033202911508851685, 0.08150864698109217, 0.0235325417452259, 0.02695360319194151, 0.09317017669673078, 0.027867981079907622, 0.030208833595679607, 0.0387284087628359, 0.010533100667089457, 0.029442939048749395, 0.02569447173300432, 0.05295807743095793, 0.04860657616518438, 0.020582525139616337, 0.061367894522845745, 0.086646832205588, 0.04520808899542317, 0.005603521094599273, 0.03630163781053852, 0.054194781187106855, 0.019197605215595104, 0.0526783359964611, 0.025414546616957523, 0.05334861038136296, 0.015488416993321152, 0.03221672341169324, 0.03329557606775779, 0.0335673319932539, 0.023952088959049433, 0.0465870550397085, 0.04243928815412801, 0.034691971450229175, 0.048125920511665754, 0.014242414126783842, 0.07030575710814446, 0.03481840372842271, 0.0020347840882095625, 0.04199742084892932, 0.02963251325127203, 0.07876823699916713, 0.018633547006174922, 0.005148397176526487, 0.021749311163148377, 0.04011429533420596, 0.03380617738002911, 0.011464509916550014, 0.026301257239538245, 0.028696065746771637, 0.022526490065502003, 0.041840720077743754, 0.03413558704778552, 0.06579168839380145, 0.033292963707935996, 0.08097542871837504, 0.028665184981946368, 0.055439006609958597, 0.011891767117049312, 0.013731961244047852, 0.03888177358021494, 0.022033494351489935, 0.011327710762998322, 0.020673649742093403, 0.012429969829099718, 0.01608408048923593, 0.029153213872632477, 0.06309792981483042, 0.012055501592840301, 0.09496408121776767, 0.03694122438901104, 0.06086544941354077, 0.01953085549757816, 0.032085678685689345, 0.02697840205655666, 0.03138673142530024, 0.03681647307530511, 0.027575190833886154, 0.009810321189434035, 0.05243212479399517, 0.028488778334576637, 0.035701310844160616, 0.04891827076789923, 0.04368019617686514, 0.019825076233246364, 0.04804610995051917, 0.09434036546736024, 0.030962534656282514, 0.019781172632065136, 0.046060022577876225, 0.07326980587095022, 0.02738070546911331, 0.022642177900706884, 0.02296597507665865, 0.022088797340984456, 0.023294494167203084, 0.036263918154872954, 0.032048074062913656, 0.058913300454150885, 0.0846186390845105, 0.03921695715689566, 0.05822447237733286, 0.028583294551935978, 0.07164513328461908, 0.04285635288397316, 0.043213003082200885, 0.03436547842284199, 0.041407409735256806, 0.0546648760791868, 0.014892859253450297, 0.03573950547433924, 0.05402842507464811, 0.042893898134934716, 0.058002458899863996, 0.03916936693713069, 0.018731415875663515, 0.039635621214983985, 0.019898133250535466, 0.0339082078426145, 0.020236413438396994, 0.0378277940035332, 0.01866029586381046, 0.07252903858898208, 0.04786472905834671, 0.030274315140559338, 0.050376316357869655, 0.03126736068225, 0.006348688848447637, 0.006693265695503214, 0.06401059334166348, 0.06797784022637643, 0.05218161655648146, 0.07937319125630893, 0.042915435260511, 0.03759055536647793, 0.07013463269686326, 0.04579440792440437, 0.00808498183687334, 0.07336388793191873, 0.07132192054996267, 0.0516297926515108, 0.04128270666114986, 0.04936501769407187, 0.04797376168426126, 0.07620437652803957, 0.024171102304535452, 0.020829369022976607, 0.01823321399569977, 0.014433810301852645, 0.08193301444407552, 0.057591464938013814, 0.016137472448463086, 0.06316513870842755, 0.05364182921766769, 0.02978293730848236, 0.042036071899929084, 0.07660716975806281, 0.04945967120875139, 0.03547580556187313, 0.024407715682173148, 0.03714348189532757, 0.01980902728973888, 0.0355016397224972, 0.03978477805503644, 0.061130184622015804, 0.03315107991511468, 0.025183553152601235, 0.043511465191841125, 0.050739824000629596, 0.05048137478297576, 0.005517824374692282, 0.05829496156366076, 0.02721136963373283, 0.020618140806618612, 0.023124082217691466, 0.030412872256420087, 0.0589517177286325, 0.035369110701140016, 0.017168816521007102, 0.059561781672528014, 0.024241895771410782, 0.04102793478523381, 0.029682038621103857, 0.050999230588786304, 0.07175578008173034, 0.058840840865741484, 0.026610354325384833, 0.01750518011249369, 0.024664070188009646, 0.04282668181986082, 0.020319225986895617, 0.05235608434304595, 0.07741090827039443, 0.05588044718024321, 0.012686110039794585, 0.08275271655293182, 0.06729763961629942, 0.026559656362223905, 0.013252883582026698, 0.06206778431078419, 0.03282828278315719, 0.04368482346762903, 0.04477519425563514, 0.0489900735556148, 0.03177989899995737, 0.02131966331944568, 0.08504813478793949, 0.027487680490594357, 0.014758423840248724, 0.022632071704720147, 0.0020721222335851053, 0.03915477260306943, 0.09017405973281711, 0.022527465989696793, 0.016898947505978867, 0.033408902017981745, 0.05665455544658471, 0.02801046230160864, 0.01735034955345327, 0.02663081348146079, 0.04041727712319698, 0.10735295276390389, 0.017433121283829678, 0.04751165230118204, 0.027328326541464776, 0.009580144087522058, 0.030887761422491167, 0.029631012257596012, 0.04326057474827394, 0.029584461044578347, 0.05747892937506549, 0.005561007164942566, 0.026965484976244625, 0.021781108480354305, 0.019967568587162532, 0.05216626523179002, 0.01556508919748012, 0.012694544548139675, 0.03918492606317159, 0.034506223018979654, 0.09471712415688671, 0.1378035984816961, 0.10352661003707908, 0.1334104998386465, 0.12346922390861437, 0.19880432286299765, 0.09128955964115448, 0.12023026138194837, 0.14072118879994377, 0.11216720537049696, 0.08549187972676009, 0.10556290741078556, 0.20478995167650282, 0.12131668394431472, 0.15974420006386936, 0.1751369662815705, 0.10666271089576185, 0.1336215963237919, 0.17954784678295255, 0.35314631124492735, 0.1169070576725062, 0.12557333131553605, 0.19543843081919476, 0.18538639676989987, 0.09964001234038733, 0.11583492887439206, 0.13743053568759933, 0.15995669178664684, 0.09165753872366622, 0.12884351599495858, 0.07847869550460018, 0.20412207813933492, 0.12491412606323138, 0.1609867185470648, 0.22271171968895942, 0.1695763654424809, 0.12964243796886876, 0.12353319703834131, 0.1326068874914199, 0.2115266042528674, 0.14770490233786404, 0.12450299109332263, 0.11352095694746822, 0.15563901019049808, 0.11559621707419865, 0.09282494444050826, 0.13616680662380531, 0.1804027266916819, 0.14761254948098212, 0.17339419573545456, 0.16860338015249, 0.26757122192066163, 0.08675264019984752, 0.06481220931163989, 0.09387322061229497, 0.18576685135485604, 0.1510194971342571, 0.14669610100099817, 0.15907789987977594, 0.09923053978127427, 0.13548024580813944, 0.18080673704389483, 0.07960443705087528, 0.14484856888884678, 0.14025332406163216, 0.13336211181012914, 0.13832479395205155, 0.17897358775371686, 0.17085679282899946, 0.13151830527931452, 0.13630315399495885, 0.20413920690771192, 0.20998519321437925, 0.12914352177176625, 0.08024887356441468, 0.20243674982339144, 0.11066988532547839, 0.05956664645054843, 0.1564082462573424, 0.11415961955208331, 0.12322873837547377, 0.07618128089234233, 0.14657661522505805, 0.1205043587833643, 0.24410224141320214, 0.17842876230133697, 0.156034218671266, 0.10562813477008604, 0.2875189937185496, 0.12961385044036433, 0.07904819736722857, 0.1049104260164313, 0.14768134657060727, 0.12953984347404912, 0.13608362671220675, 0.17106843850342557, 0.15528723219176754, 0.07809243732481264, 0.1813309159479104, 0.21487054356839508, 0.2311094175092876, 0.20417695253854617, 0.09359118223073892, 0.1640654291259125, 0.09666686484706588, 0.1989549639984034, 0.11404731776565313, 0.09334147922345437, 0.1947613843367435, 0.1574344583787024, 0.06325315742287785, 0.09059954041731544, 0.1768636322231032, 0.2108610759023577, 0.11295460179098882, 0.1392938310164027, 0.08848248995491304, 0.09243286040145904, 0.19489396159769967, 0.07246191875310615, 0.21906663168920204, 0.17822446388890967, 0.08029527263715863, 0.10860462934942916, 0.06398274053935893, 0.11516774553456344, 0.0914203112188261, 0.09045796090504155, 0.14868541300529614, 0.3046439029276371, 0.14099363121204078, 0.18475730787031353, 0.11646807732176967, 0.19476945890346542, 0.07797187543474138, 0.21481577306985855, 0.2734731661621481, 0.09131908227573149, 0.13717366353375837, 0.1451729764812626, 0.20406919269589707, 0.10813505767146125, 0.15332818496972322, 0.09390131832333282, 0.13647527288412675, 0.0987162537057884, 0.12887369171949103, 0.10341136192437261, 0.1935785196837969, 0.14265800127759576, 0.12134817327023484, 0.16180717764655128, 0.10912194338743575, 0.1982842554571107, 0.13866745837731287, 0.14137116173515096, 0.1356555410893634, 0.15433697146363556, 0.11652956425677985, 0.11416721914429218, 0.1720654100063257, 0.11272908537648618, 0.09376255897223018, 0.08387580121052451, 0.11882406965014525, 0.2182563696987927, 0.1460208059870638, 0.17474564665462822, 0.14663619484053925, 0.11183289752807468, 0.09614100126782432, 0.1395129575394094, 0.14232499961508438, 0.09341925629996695, 0.13083404512144625, 0.08924898749683052], [0.019173943692294415, 0.07120434209355153, 0.02101629932440119, 0.07235225159092806, 0.05748900402977597, 0.023163052392192185, 0.03077020708587952, 0.054044425778556615, 0.05554189425311051, 0.10303834365913644, 0.0063040083114174195, 0.043390291029936634, 0.05283345599309541, 0.07522851912654005, 0.06432060326915234, 0.05778515806014184, 0.01787631888873875, 0.05031727851019241, 0.051794352766592056, 0.01937000055477256, 0.03712279452884104, 0.03886670427164063, 0.08964266715338454, 0.04470258623769041, 0.048369174255640246, 0.0334323724382557, 0.02024755307502346, 0.01753508680849336, 0.030932941517676227, 0.07277862285263836, 0.05125018040416762, 0.07000231518759392, 0.0640620019112248, 0.04418503100168891, 0.04660013168177102, 0.012125430457672337, 0.0213877813439467, 0.00830972270705388, 0.05399367029895075, 0.036292424047132954, 0.048113619413925335, 0.04160088392382022, 0.05038660623540636, 0.0118062522233231, 0.03470421317615546, 0.05733931284339633, 0.0593447591381846, 0.03023956964170793, 0.09585610561771318, 0.05418223518063314, 0.03451981916441582, 0.02387497981544584, 0.01857967636169633, 0.00850104652272421, 0.024376222645514645, 0.009995660511776805, 0.02875681981095113, 0.02816427240759367, 0.01988016585528385, 0.03792697832977865, 0.02539183318731375, 0.031393451572512276, 0.05615389520244207, 0.02660990347067127, 0.05199459534196649, 0.01662212271185126, 0.01845377842982998, 0.033029649712261744, 0.05306474631652236, 0.02820393092406448, 0.004823749313800363, 0.04056874204252381, 0.07835540251107886, 0.05077922462078277, 0.04771079278725665, 0.005345713370843441, 0.04831532030948438, 0.04442428456968628, 0.05803373300295789, 0.036410625907592475, 0.03401431269594468, 0.017014332916005515, 0.061709631263511255, 0.05818135730805807, 0.07091421430232003, 0.05537826553336345, 0.021851306373719126, 0.06940556166227907, 0.012332935875747353, 0.011715060827555135, 0.042599269218044356, 0.03736802238563541, 0.02246789008495398, 0.047005325759528205, 0.032408019396825694, 0.02517203687602887, 0.055702027457300574, 0.055570860276930034, 0.07718729175394401, 0.052889632861479186, 0.053903952066320926, 0.005472260681926855, 0.0039419883523805765, 0.07882150093792006, 0.07538614387158304, 0.03417671687202528, 0.01648006265895674, 0.006163840271256049, 0.07498243779991753, 0.048672144912416115, 0.03043649110622937, 0.06758249073754996, 0.014772985705349129, 0.0282394482564996, 0.060772050128434785, 0.005625345802400261, 0.026619000345817767, 0.05384361917094793, 0.0765965050959494, 0.005251138245512266, 0.06425579893402755, 0.0274251044538687, 0.01095643283406389, 0.03868137515382841, 0.036037756071891636, 0.011533731885720044, 0.05481589199916925, 0.03497884863463696, 0.026034585025627166, 0.07056378701236099, 0.026049101434182376, 0.04024972615297884, 0.03475641213299241, 0.021221551396592986, 0.006776168229407631, 0.03129437114694156, 0.018300189112778753, 0.03570232758647762, 0.057936908706324175, 0.02647070254170103, 0.04219022339384537, 0.00808732331279316, 0.027356750797480345, 0.007583260321553098, 0.021571065844909754, 0.0074853251226159045, 0.02400643272267189, 0.0383552198036341, 0.026886876694334205, 0.018850671585823875, 0.05308503663400188, 0.025183981742884498, 0.013980767180328257, 0.04372378622065298, 0.04025018999527674, 0.07533596726716496, 0.044056895494577475, 0.012576157150760991, 0.07920633419416845, 0.05244777297775727, 0.019599622901296243, 0.09293950977735221, 0.06886562696308829, 0.03105765386862913, 0.0047103983160923235, 0.03520512946124654, 0.06686524211545475, 0.035300105810165405, 0.0826132224756293, 0.02774180113192415, 0.06367737645632587, 0.010205611306446372, 0.09265594999305904, 0.05584240840107668, 0.032005842149374075, 0.04518239584285766, 0.028524089721031487, 0.09363574819872156, 0.015188155175565043, 0.04600335218128748, 0.03214846066839527, 0.023381594473903533, 0.012893527327832999, 0.06343560700770468, 0.007727383544988697, 0.0502767795114778, 0.03587030900234822, 0.006342545257211896, 0.024443769216304645, 0.023519251735706348, 0.09715737993246876, 0.04621785512426868, 0.045495459708035924, 0.034134444140363485, 0.08609457043348812, 0.0377329809271032, 0.037219655932858586, 0.025234182467102073, 0.02661305759829702, 0.0324975854891818, 0.03358895817655139, 0.03922430070815608, 0.037626928024110384, 0.03850851411698386, 0.00416101839618932, 0.042388551228214055, 0.036489612684817985, 0.024306269660883117, 0.035366550291655585, 0.010825897406903096, 0.009487411807640456, 0.050649816330405883, 0.034574263117974624, 0.05055035369878169, 0.0492145361204166, 0.04811950464500114, 0.03564611361071002, 0.01970155874005286, 0.0202250585789443, 0.0382683736825129, 0.056709162672632374, 0.0275019241598784, 0.0643768283771351, 0.02473755394021282, 0.06086321183829568, 0.08413932300754823, 0.11442737901234068, 0.016379624103137758, 0.11764007693273015, 0.0248855326208286, 0.05826740562042687, 0.013825230653310427, 0.05640934243274387, 0.03280723176430911, 0.05879699107026681, 0.05558309087064117, 0.0434907110320637, 0.023331863158091437, 0.035293597175041214, 0.05031315959058702, 0.02791323910059873, 0.004023692317787209, 0.0220010124030523, 0.07706934222369455, 0.1012722919404041, 0.07530269678682089, 0.04450498199730646, 0.02339039263461018, 0.08836932727717794, 0.03696267245686613, 0.03435825361520983, 0.1002621027873829, 0.02446835471346276, 0.042433525377418846, 0.014434169315791223, 0.03201304098183755, 0.09728275836096145, 0.03918823233107105, 0.05588091102254111, 0.02753366581600858, 0.09913542613503523, 0.03692208068969194, 0.03060183418710949, 0.0392216846375959, 0.03561758545401972, 0.020588321312970947, 0.03408717304409947, 0.0064383676544821355, 0.07853297618567012, 0.00593002293499012, 0.05728957781684585, 0.06429908840800636, 0.015058005665196106, 0.019417674266151153, 0.03753489057999104, 0.017904206943057943, 0.039272369613172486, 0.15873183641815558, 0.031749968184158206, 0.020001961565867532, 0.04415727838932071, 0.05257112534309272, 0.007313965543289669, 0.0722180341836065, 0.0028843404788858606, 0.02219167014118284, 0.08495210830005817, 0.05051258209277876, 0.0413604911591392, 0.01544598841064726, 0.04099880919966381, 0.03698561595228966, 0.01950500092789298, 0.010092378124682, 0.11531000040122308, 0.013026540600549197, 0.05696370448276866, 0.022010636203049216, 0.04001806475571357, 0.01547877463963232, 0.008572137776354793, 0.008109786267596064, 0.05184799891139846, 0.0823469324677717, 0.02176173100451706, 0.0692719899234362, 0.014368798165378394, 0.04821703398192767, 0.025551996077410877, 0.013499967735697282, 0.0922981086478103, 0.02455956651829183, 0.04751507360197138, 0.07740171306068078, 0.037465740970219485, 0.019890535513695795, 0.037250959721859545, 0.012482768070185557, 0.05541181060834788, 0.034566299873404205, 0.0277857659602887, 0.05728506555897184, 0.05583950289292261, 0.012960859603481367, 0.037818951313965954, 0.024841090962581802, 0.03059435333852889, 0.010509684052522061, 0.046917180879972875, 0.07106777949957177, 0.04353660173364915, 0.030018444886081852, 0.06994215669692494, 0.02652113889780594, 0.07478769082808867, 0.01977286985493265, 0.012582360577653162, 0.02504132982721785, 0.04446893959539011, 0.03986021736636758, 0.014090546592342434, 0.06047512055374682, 0.07626207108842209, 0.05400377092882991, 0.10958093203953467, 0.05747239105403423, 0.051221047397120856, 0.04619367595296353, 0.04137769414228387, 0.03881790806190111, 0.03446885217272211, 0.018264731152157765, 0.18635126296430826, 0.19088989676674828, 0.08608101139543578, 0.1329470137716271, 0.21937895711744204, 0.11561442195670679, 0.07656342757400125, 0.11252230076934211, 0.12287471166928299, 0.21369308175053447, 0.06798257512855344, 0.0909928118926473, 0.14980831212596968, 0.1207868721394334, 0.1805757955298759, 0.17116632778197527, 0.16502159734955058, 0.11345143255311996, 0.14026565855601802, 0.12566142424475402, 0.11082337630796246, 0.12287529054447077, 0.18063126364722848, 0.17510628589661792, 0.1586886731092818, 0.1452872226946056, 0.13656057533808053, 0.10809087019879371, 0.18476469966117293, 0.12925650633405894, 0.19560922868549824, 0.21534609695663676, 0.1475143336574547, 0.11573359603062272, 0.18893013708293438, 0.16804216807940975, 0.15634265524568036, 0.15027384652057663, 0.17032860632753, 0.10273681647959165, 0.14266689220676199, 0.12269145314348862, 0.1338694291189313, 0.10786172468215227, 0.14835172856692225, 0.13565502158598974, 0.11701354102115147, 0.14836254908004776, 0.23111490940209478, 0.17105890932725742, 0.26700404298026115, 0.1277155999559909, 0.28437819506507367, 0.09582992264768109, 0.10279880807502195, 0.09833107906160876, 0.09739282628288493, 0.08207980383303948, 0.12253570603206754, 0.1410194134223275, 0.13017049088375643, 0.15269179333699867, 0.12097444254322909, 0.14173779753036797, 0.1754362299107015, 0.22481557476567104, 0.109550318447873, 0.18985016271471977, 0.20648423029342666, 0.16731358686229214, 0.18989516654983163, 0.191125929413829, 0.14957508479710668, 0.11611107460339554, 0.10181823061429895, 0.2177970841876231, 0.14337007713038474, 0.10488994274055585, 0.10936802471405827, 0.12440011458238587, 0.2426013071089983, 0.12372670462355018, 0.20250076748197898, 0.16229993401793763, 0.15939498989610001, 0.1951032769284211, 0.18568659550510347, 0.17855670856079087, 0.2038969995919615, 0.1172973308712244, 0.13178601278923452, 0.13250307587441057, 0.15553717268630862, 0.10129975140444003, 0.10204405130934902, 0.2185748697957024, 0.12007773519144394, 0.12273604879737832, 0.245369057811331, 0.12518187810201198, 0.13093036104692146, 0.24026367551414296, 0.12349945900496095, 0.13742523675318807, 0.2039698784938082, 0.14481673075351864, 0.10350791533710435, 0.17309683200437576, 0.1352363167097792, 0.10536410089116544, 0.14557159884134308, 0.1774456986458972, 0.12458416720619425, 0.1796664419816807, 0.15782616392243654, 0.1405798245104961, 0.1216062180174049, 0.13329892535693944, 0.19603458320489153, 0.10166381936869584, 0.15206396608846262, 0.16066481941379607, 0.0782361245364882, 0.1086863991804421, 0.09524130306090228, 0.08620256034191698, 0.19122519908705726, 0.17446686630137265, 0.1312305746250786, 0.13086269202176481, 0.12958590115886182, 0.14079976739594713, 0.15548298106295988, 0.1170359538809862, 0.15463050571270287, 0.11903966355021112, 0.15500471141422167, 0.14920565852662548, 0.11960146934143268, 0.0973132457875181, 0.10771750312414952, 0.25128752226009965, 0.12009249650873244, 0.1074763570795767, 0.14637384563684464, 0.19602723594289273, 0.12486570834880695, 0.12926021707244217, 0.06732143287081271, 0.16383858426706865, 0.09715922788018361, 0.11441140799433924, 0.11316766496747732, 0.22221725637791678, 0.22920938587049022, 0.19498557230690494, 0.08440865582088009, 0.08586010371800512, 0.17651627742452547, 0.1647440341184847, 0.1555082289269194, 0.13604432257125154, 0.14681160886539146, 0.1811238715890795, 0.14399348117876798, 0.1295255942386575, 0.16795929986983538, 0.13114181376295164, 0.2157237462233752, 0.14296324661700055, 0.14580634015146643, 0.1447633109637536, 0.24898815579945222, 0.13069769775029272, 0.17803530528908595, 0.10760661883978173], [0.02372546303377021, 0.045554939133580774, 0.09185477931168862, 0.009961983705579769, 0.026902263271040283, 0.059103108433191665, 0.0538894616329344, 0.04833622289879713, 0.03418938533286564, 0.013270381568872835, 0.009903888385451864, 0.028251272524357773, 0.06750544838723727, 0.01308983280978282, 0.034418033610563725, 0.04663994048314635, 0.05395698965003248, 0.07008812972344458, 0.02023077497142367, 0.03360466202138923, 0.020509469977696426, 0.01709493386442773, 0.07184979534940794, 0.027182385056221392, 0.02910889652412152, 0.017883417531265877, 0.03347918711369857, 0.060143855516798794, 0.03338548725878354, 0.04788217323948629, 0.05355649707780685, 0.055374443472828716, 0.02133856211003149, 0.0468442722922191, 0.01870245541795157, 0.07987052667886019, 0.016794104303698987, 0.02994973870954709, 0.09089539016713388, 0.013246751586848404, 0.06749941472662613, 0.058382338320370764, 0.03412000194657594, 0.04797811809112318, 0.016630586906103417, 0.03101467424130533, 0.024301146986545064, 0.014603087693103589, 0.031678517916589044, 0.11427758392528631, 0.029354070575209334, 0.05261942802462727, 0.03825490741292015, 0.0547943251876859, 0.054596327609033324, 0.018855836933653336, 0.01242801983607933, 0.010851670340343844, 0.02696690247830702, 0.054792736991657875, 0.02745313166087726, 0.04763507517054677, 0.09416529283043928, 0.01375041752908146, 0.02315030971658416, 0.034189377911388874, 0.026288809567631688, 0.0037911431263637496, 0.05276298164972104, 0.03315315050713252, 0.07542327351984568, 0.01765117354807444, 0.032294652628479525, 0.040804206946631894, 0.01919597249070648, 0.03727838949998841, 0.012549488074000692, 0.05168473755475134, 0.01839807468059007, 0.07350298867095262, 0.019272975878266152, 0.04426759493071586, 0.0533712867036229, 0.05154534737812355, 0.03955901673180051, 0.028690918952634092, 0.012233123507030541, 0.01497828323408612, 0.042846537980949506, 0.0619279970851494, 0.014931964869902004, 0.04370049020508304, 0.025089220616791863, 0.04243256429617759, 0.0471858123637503, 0.006530441278300714, 0.041634284280007705, 0.03216934470401611, 0.03778854552365374, 0.04557993095659185, 0.013817351828038227, 0.02005597692914307, 0.02503805881133303, 0.05725100098061375, 0.04019474043161608, 0.01821971618483076, 0.03616617730585858, 0.035014475433854386, 0.05494855089636985, 0.027990682210656814, 0.05154220438271295, 0.03460300278675277, 0.055709820007905364, 0.044422766877687536, 0.08208331419155002, 0.09898104457533918, 0.03888726176228374, 0.05059932802396361, 0.06157121330033988, 0.03635857538029086, 0.03202922722266521, 0.020364623160276096, 0.05310386863129679, 0.03457883474766277, 0.027913142621400766, 0.014915989213477587, 0.007369473551079864, 0.014493818507617107, 0.03561778583389241, 0.0805307635164354, 0.07209082265035249, 0.01582563312695129, 0.013871391311113257, 0.010468785221746657, 0.032161878698389046, 0.028017275217280257, 0.029106239635439124, 0.03516483826388139, 0.014030107940925518, 0.04993316142645199, 0.11636366456514224, 0.04603620334819425, 0.0049034991116059246, 0.03592324268538505, 0.028109377599321306, 0.03020304298843257, 0.03089227368036518, 0.016684095753589645, 0.04073875323229004, 0.02466984595230315, 0.052972211633459665, 0.027312101337884087, 0.020355077285785228, 0.029195284369052388, 0.09343933139462024, 0.05208499263972044, 0.0857667563832365, 0.06225518030987587, 0.022515944147016853, 0.07046979400911368, 0.013595907021226594, 0.006807235458836658, 0.03969615077949129, 0.03643348776677158, 0.11266566885751672, 0.003978480681325891, 0.06554316540132277, 0.07345601814449765, 0.05898902549233753, 0.02202781877713278, 0.01720888878480764, 0.011938864736293908, 0.051268923343741335, 0.06022735084115993, 0.019451657208264805, 0.01400695293341414, 0.06505259836558253, 0.07009198146988638, 0.04050309165904764, 0.041204814551747404, 0.018136732942366507, 0.03925907403754536, 0.053513259554165415, 0.04873400292126462, 0.018055794316751417, 0.02224055726401275, 0.019014801255252678, 0.06131326503236778, 0.05518274672795087, 0.03080919024796458, 0.02286673137859907, 0.04214102271362208, 0.047659903721068986, 0.05743426692788489, 0.038382445491151884, 0.00831660334370099, 0.04731650456960779, 0.030309114445117302, 0.02685701267182594, 0.011686563284456497, 0.013602882281702477, 0.02700613797060214, 0.027071656622865703, 0.03647908532002475, 0.044107272478868254, 0.030569892151106615, 0.009313669470429886, 0.02736368616751861, 0.0297712429164676, 0.013091356067889137, 0.019137910567224026, 0.05636160749418195, 0.023421727964887396, 0.05575485723966267, 0.02976722604216775, 0.04064630018547177, 0.09627110717701726, 0.0286761335155461, 0.030313016286527272, 0.07492232383810915, 0.061144289138610475, 0.009755091487022582, 0.03042292835743865, 0.031176455013337545, 0.010700498569349293, 0.09782264110981487, 0.08792915949015878, 0.043040683813160285, 0.024887419531296473, 0.03912920190487057, 0.05189521063584834, 0.043352363572921604, 0.007416313737849123, 0.014173205145198153, 0.02502317503967788, 0.05322401862940751, 0.03836322757706512, 0.03477396763628349, 0.03879204421536997, 0.0060826572007499635, 0.019402907382755075, 0.029972531920066103, 0.02200366187025793, 0.030126609199214727, 0.05480372077727225, 0.02796462540572975, 0.0533775281655835, 0.05074539010820445, 0.052600351118599065, 0.03305929109046701, 0.010038819182227599, 0.01695415030553704, 0.02102693801134592, 0.041775032586883754, 0.08662988155265339, 0.024446079150948208, 0.022828477376606315, 0.09151918755378574, 0.034953686117660254, 0.05424369242973626, 0.017907023393490817, 0.023671659182582516, 0.01617004345462192, 0.07808256676071323, 0.03298209288914222, 0.04759672468935605, 0.10714589356211945, 0.014751580310985446, 0.11192271223990247, 0.036222869966877624, 0.022085023520048708, 0.02683160339074675, 0.06563793023815379, 0.04412774091179017, 0.04002973131719045, 0.038990628090687096, 0.04346940397226717, 0.04365462176792789, 0.024150286917574704, 0.05128642689669505, 0.008803315849945648, 0.026488278454053216, 0.012757941585732624, 0.040989862609421834, 0.02360897182370536, 0.04111565664061345, 0.011574048130569281, 0.04881043671048246, 0.02084786148770945, 0.01508096214820398, 0.032263608591165394, 0.04375821445137262, 0.0628285450511612, 0.010609825749270385, 0.02324696888535982, 0.0324206989898812, 0.040951857226900756, 0.013807822651870083, 0.032825291928020306, 0.03023711313289823, 0.027603156813711394, 0.03631833242252469, 0.03350608625623863, 0.03250779373047408, 0.045994565152795985, 0.027612326048256364, 0.0688997286488302, 0.022790776274632663, 0.01729464765958255, 0.008279918056359747, 0.03369287369423546, 0.012515303824329749, 0.014953501995478291, 0.03023573459358886, 0.06662759158643894, 0.05801147228339687, 0.028038355922035407, 0.048365489492425695, 0.02829279939760454, 0.029640302091138437, 0.05649125698255375, 0.0025814616628849762, 0.08435274983639829, 0.011239834911975777, 0.035291704698465765, 0.009799843919608975, 0.011641129931376781, 0.06319083186099306, 0.0240249771377421, 0.021669125817425083, 0.04449648069567047, 0.021016800274082925, 0.05734178419515956, 0.014758129764231853, 0.05427395721198991, 0.035532947222236544, 0.025317484833067283, 0.04773847489559557, 0.0253057069494389, 0.07527567518991418, 0.101442154700635, 0.034224622504552826, 0.01248889357157168, 0.03410926306969486, 0.0511741176887881, 0.029482590143743437, 0.059568423894234, 0.041922508462448604, 0.01069276167982025, 0.06690105074085295, 0.0550453009782359, 0.05522673382074572, 0.14035850123036653, 0.1765023695770651, 0.17243197158677503, 0.2155070539447479, 0.1276492074248381, 0.11758207809180021, 0.24662321317009628, 0.1537110292701982, 0.11145767508423887, 0.09231309260940179, 0.0986777213984169, 0.1467653879080899, 0.13089090847643092, 0.06224086057045497, 0.13890202157199383, 0.16227798128966242, 0.11637965042609721, 0.16931331861997023, 0.09399790142197162, 0.0928767240839079, 0.12178668606793508, 0.11034429771825671, 0.1454102707793936, 0.0845926787587814, 0.09271526243537664, 0.12297548790229484, 0.08837580622639507, 0.10750369779998437, 0.1392368192318827, 0.13627900450956076, 0.22288809850579128, 0.18509087356505916, 0.13012922747293487, 0.1313830414437689, 0.1206056545197498, 0.20806021057069302, 0.06246254008146934, 0.1071329579281155, 0.14229434891603887, 0.17327957844827324, 0.19266475777840242, 0.2287525197607465, 0.1556053463718854, 0.16267718252493069, 0.07100647810148075, 0.13398403156315908, 0.12537305534351617, 0.11074851587181911, 0.14545395359164104, 0.2123904789914377, 0.15272453689249232, 0.1059345155954361, 0.133543670817744, 0.15857493155635893, 0.16727748879930004, 0.1193925399275031, 0.07923368975752965, 0.14940309949452057, 0.0800785655155778, 0.18263133679283783, 0.10542779200477526, 0.08626790644484572, 0.10752118279924616, 0.07598466370836832, 0.08835950124193914, 0.16147987567819655, 0.16681358712958172, 0.10983557775034569, 0.17730791150825098, 0.08819280003081076, 0.14150131959468126, 0.10806794525706209, 0.10759319338831119, 0.14948163356166333, 0.1450365548953414, 0.13965472258860245, 0.12689932656940073, 0.1447981473756954, 0.09708320227218792, 0.17197479377500713, 0.1127298572100699, 0.17614477314054966, 0.09885714302072302, 0.22579614480491728, 0.13078202056931332, 0.10961676292936318, 0.1184577084495686, 0.1343330933013931, 0.1557513713487424, 0.1610532298218459, 0.1894738938426599, 0.12152235532994382, 0.13781876798020676, 0.1645322103286162, 0.113701692171162, 0.0860010449832771, 0.23050569521728903, 0.117564066167688, 0.1315095479367301, 0.08080156578216702, 0.10049034288385883, 0.08651258511235937, 0.11100679068476893, 0.10313554274034686, 0.10565595788648352, 0.08581193833379075, 0.10774231312097982, 0.16492053167894483, 0.146137397387065, 0.12818260380299762, 0.1891786971827969, 0.1626672229031101, 0.11198477062862366, 0.11386601850972511, 0.12472472997615114, 0.16889827995328233, 0.12848321814090014, 0.08713886127225123, 0.11300111218588427, 0.10020946225267835, 0.1109234252362512, 0.0941237696679309, 0.11419387708883733, 0.12088642382877879, 0.12118942788220011, 0.06491190943052061, 0.18681412562727928, 0.0874798781296704, 0.20459775027120486, 0.26755581493489444, 0.2082375987083651, 0.09329529537353665, 0.08839361777063459, 0.1283315973705612, 0.12226819148054346, 0.1344678524765186, 0.11922035424504429, 0.119372553890571, 0.16674547281581908, 0.15151137777138501, 0.15912510047201067, 0.1639530828106217, 0.0974867599143181, 0.13414274726528674, 0.17805433395551518, 0.16165123757673427, 0.20012145687360317, 0.05155891754839104, 0.07317441020859405, 0.09107105652219616, 0.13401999603956938, 0.07744991555227898, 0.1916354731656611, 0.1541871318477206, 0.1746925534098409, 0.12393106982926838, 0.2717016002861783, 0.10671686541172676, 0.13443988835206255, 0.1171685237204656, 0.12126748697482981, 0.18223047314677387, 0.12174695890280418, 0.13366700091864914, 0.2126177097670734, 0.14833203196758404, 0.11163905597641133, 0.12799248041119426, 0.11709419020917267, 0.1645841309800744, 0.1765515294391662, 0.1257877377793193, 0.16198064724449068, 0.119709444406908, 0.1602912222733721, 0.10364479705458507], [0.058433405502000824, 0.03357508743647486, 0.05358425711165182, 0.022658785310341045, 0.0419969829818001, 0.015454679887625389, 0.06482917480752803, 0.031231058528646827, 0.06108741836214904, 0.07788682531099766, 0.09089081853744574, 0.01644521140406141, 0.0691849656868726, 0.06501788069726899, 0.04932305666443426, 0.07996152140549384, 0.02794211050058948, 0.04591264689224772, 0.04287545205443166, 0.042557920460239984, 0.015218991411529714, 0.034537404353613965, 0.06725329629261978, 0.10017795066232793, 0.020019797229906544, 0.0451355329278158, 0.02743363358604256, 0.054775018215877935, 0.06284809322096407, 0.09493486286373809, 0.0051665348019014345, 0.05704540009901393, 0.00969718819760601, 0.043746087758336216, 0.06485632999101654, 0.036503969531622715, 0.02407076579402201, 0.07655723064090125, 0.030879321348038502, 0.04559686676657293, 0.042139801880693994, 0.0069072329006303335, 0.06885023482027464, 0.020995131417294033, 0.05018100535380654, 0.0590745728550246, 0.027744068393076304, 0.01297652634093538, 0.0170620307471836, 0.021680523350369185, 0.026742658847069833, 0.09650066829635762, 0.013203710732341278, 0.02047994734311942, 0.03577228984795511, 0.06550669626449235, 0.06214712360815611, 0.06802856602007523, 0.009473787831666414, 0.05282170037389733, 0.05653638698277064, 0.03360915943630971, 0.03216440571122803, 0.06175511378387455, 0.04929642098431941, 0.030559884289687034, 0.017697735893307254, 0.028131929611845408, 0.02760330153250834, 0.024298334246850573, 0.003149679378111614, 0.053768283760291524, 0.017668534237600397, 0.0058138703298027394, 0.02405475952400593, 0.04209822305710986, 0.0029793193789373618, 0.05303193596773781, 0.053551944001810625, 0.0851701883948408, 0.03437932318774983, 0.027362315049686003, 0.028952268112334423, 0.02198723072069697, 0.01831225828937022, 0.08264755422715098, 0.022202529617061373, 0.01858344276115531, 0.012165246680524433, 0.01619177910470171, 0.0292927060945658, 0.040754961737548, 0.05481884574692231, 0.019163624128850643, 0.02996618284669239, 0.05384011623391416, 0.02551493507780833, 0.0576012724195607, 0.09708236364531331, 0.024512735144526232, 0.052704541230923496, 0.06223495307494886, 0.04219639435177669, 0.023057856669765897, 0.05264188912406098, 0.004156623490416678, 0.014227257615857525, 0.02786591419862816, 0.09813331154873595, 0.05265768944809679, 0.06646737674600445, 0.02021866683207918, 0.011978770016867202, 0.015761053291498683, 0.02912353909778176, 0.03700503795698751, 0.01940651607583277, 0.03903103803168051, 0.008111000606731977, 0.025795587498578243, 0.033646459778537974, 0.029157481221773196, 0.026777090788527858, 0.019665612817334477, 0.00462752825114876, 0.02587903643870959, 0.01834378101193579, 0.038063121610321105, 0.0295229666880914, 0.010377524249634007, 0.016987769595289137, 0.04602104869263712, 0.0417014115373604, 0.021664363084710203, 0.1143125761882402, 0.02837603125954047, 0.02316201338544488, 0.03665762378659565, 0.015046229636936914, 0.021633526848745532, 0.04124575512832962, 0.0025945853849407285, 0.030593865376431495, 0.017846464143076446, 0.0382629300293047, 0.04371244249341544, 0.03312324195576366, 0.07200532723800279, 0.03158453604555689, 0.05758418818004429, 0.041038016861421056, 0.07440165529260412, 0.038880745705682784, 0.006623337294513476, 0.07816530138370581, 0.03205670524039306, 0.018801530277414713, 0.08271039187093265, 0.02452097298373701, 0.015806418923602905, 0.03211937590094749, 0.048659658277756535, 0.019241560767113697, 0.0822623424755875, 0.06357349062454887, 0.011110218820249429, 0.01503074472566368, 0.08059309649979696, 0.026734213206509594, 0.03073983098147437, 0.053907358524156734, 0.03360927075846121, 0.07456177365384065, 0.0804800377227366, 0.027930011638090946, 0.06383482308592647, 0.041742051544133574, 0.012306272365094628, 0.03651312021247577, 0.01174350363726262, 0.019698258038260974, 0.022991855621512514, 0.029496668685169425, 0.04257698994479142, 0.041238567428081296, 0.06946197230718099, 0.019154449328198098, 0.02718015490245307, 0.009779372703633271, 0.05119386994920205, 0.028977772017242387, 0.023950200193212368, 0.036323468084447086, 0.10704179250751622, 0.00939931238463032, 0.05582494937698357, 0.02856365175830433, 0.02426801380352117, 0.04402447106258478, 0.09610024251742288, 0.022470845688076224, 0.023579207991133444, 0.021910908253630623, 0.03351742256199941, 0.10616522704367526, 0.008627588267700048, 0.032998023089021444, 0.06993690971285105, 0.009992683571908856, 0.048799790602060966, 0.00816077459603548, 0.016463345782540273, 0.017871240743261296, 0.02391259742580587, 0.03465976224106271, 0.03583537240047008, 0.05624218851153273, 0.036435079673537984, 0.05601323595328722, 0.024777403559710365, 0.02606198140711058, 0.08150221256073564, 0.006455156890297076, 0.013593624917120906, 0.029021547597949393, 0.010514200948819052, 0.047907550979289226, 0.0832468830049038, 0.044126130451331846, 0.02507693992811255, 0.05756715589086525, 0.034998315168195404, 0.07005842897342518, 0.0330714437586721, 0.04276150641089771, 0.0654800828488078, 0.032155451699509285, 0.0451801285817055, 0.048392767130280845, 0.022685318945150357, 0.049108130697277375, 0.014351762165460968, 0.030115523368294816, 0.037550935812760144, 0.019214600397390313, 0.03419743763515726, 0.0352307669527363, 0.029723140614805743, 0.047554726552334614, 0.040093459538184106, 0.006202830854817876, 0.049176571556017734, 0.06755910566425882, 0.015695870461058803, 0.00941339741984848, 0.02997472125571221, 0.06083986387238838, 0.04615412690327503, 0.005284352600938291, 0.013672375134774484, 0.06324673784547485, 0.047705864926683716, 0.030323137325467542, 0.009578387052897597, 0.05541079015529249, 0.05641127943817992, 0.006712046670145355, 0.048358639469370246, 0.03900600167980883, 0.0504272091347957, 0.02659233497979585, 0.022205282984941732, 0.03317122180305887, 0.06119326346379239, 0.06400400307029486, 0.029478512042260263, 0.01343371621260303, 0.06238378337002359, 0.0196403334120987, 0.044225863966858014, 0.054076798260211945, 0.04514789710810874, 0.014189555586199276, 0.021327242502593435, 0.050760867598000914, 0.06966387358261272, 0.07001047139056027, 0.051011498289881274, 0.04593189078150317, 0.035050324877374806, 0.003092540500801988, 0.008146204381773714, 0.06807474244851619, 0.02893018736358499, 0.05321368051227182, 0.03506726068735588, 0.029927075374871492, 0.03989812626969069, 0.010181164961977629, 0.04216207002173178, 0.027922308145207353, 0.0523777402122505, 0.045490561533370055, 0.026076438443851657, 0.038007935509085655, 0.040164149104384705, 0.012173055929451948, 0.04901659791357815, 0.019687508029164746, 0.019744657111004926, 0.09555007360177115, 0.021815245418110862, 0.040968299508676864, 0.008671980758663267, 0.029129492977517657, 0.03359507718414534, 0.028523076689452864, 0.02423745401756605, 0.05847659478604328, 0.04352279778686352, 0.010441639315104112, 0.029829983905074187, 0.057770704734139144, 0.02624062377435621, 0.01263860702238162, 0.010942863591481, 0.033968908101087436, 0.05085523909656331, 0.028030411231156904, 0.031387128474307247, 0.015142789543460822, 0.0291102732080617, 0.06169790904095862, 0.011619305223575793, 0.02081252412608592, 0.03594205241824966, 0.006591772826141096, 0.016287837133859284, 0.06129813635197934, 0.06290561708738096, 0.019229235549573787, 0.0142215310188476, 0.0389539771276759, 0.03997690524556674, 0.016638488923490513, 0.014143647258606507, 0.020967235941498075, 0.01757141679263441, 0.032755886277300306, 0.06726463630911894, 0.04581631612381898, 0.06617854029173031, 0.12823073950130492, 0.08085988374659792, 0.20263335958588868, 0.13696670823264867, 0.12766333791660145, 0.18791397364111617, 0.17693603615043685, 0.248921585152857, 0.17721763666486368, 0.17129495681729168, 0.1131340085703414, 0.0782199679815676, 0.12079301712219603, 0.09109312799409963, 0.1812465486000292, 0.1613879087381065, 0.11077991614001803, 0.23549019650090486, 0.1564175824751146, 0.1945226057432592, 0.07574355477117933, 0.11987075020442717, 0.21288265648763627, 0.422917632968165, 0.16494205396156758, 0.1713997925980948, 0.13285238994285464, 0.09539766615489498, 0.17961866251425818, 0.12075800259481184, 0.057688400556799024, 0.11319179960992187, 0.14857748989015818, 0.1216249201388564, 0.11711217244737782, 0.25398600089829415, 0.17244485527044162, 0.14559741073753685, 0.15629946225089952, 0.105861458578147, 0.15886287001194432, 0.2118988209986128, 0.1468624162953347, 0.1069670805009082, 0.17357082688249648, 0.1582813379354775, 0.13153538951883093, 0.08850758196786046, 0.10758114833151922, 0.1284978978219442, 0.10756246105302125, 0.12968019844265655, 0.2969099523033947, 0.07541947372374125, 0.12774050643201917, 0.11929632790270261, 0.15547435730695724, 0.10021695052273571, 0.09273124829633161, 0.13547151815146208, 0.15541172004304826, 0.10363134191720746, 0.12500150653067976, 0.13840524276020005, 0.12191103291115724, 0.1519200933398679, 0.18078267661621794, 0.1193489387515001, 0.07465922506526113, 0.10860528243938461, 0.1015994454792235, 0.11732632658095099, 0.13614191499073058, 0.12271510538994335, 0.060858955621370114, 0.1675037993118167, 0.18577299633761868, 0.13229300355305895, 0.12078765881597064, 0.1329494480160065, 0.1457394429598935, 0.11156428459798917, 0.09402203606441617, 0.12268025413504802, 0.11339468052028678, 0.17450278624892235, 0.18671697849640623, 0.10425886488519609, 0.08492455235682428, 0.13460581772960722, 0.08624304449767806, 0.1245155927608721, 0.11574199714232236, 0.1461146876681596, 0.12285403543501161, 0.14661434601293877, 0.16082363901659846, 0.14155819779261947, 0.252783959149383, 0.0753020288539119, 0.1477594205061905, 0.11420730254030786, 0.09905882165185176, 0.10154058574698865, 0.1397287443978712, 0.15671997796744108, 0.15282285661669448, 0.13505741459084675, 0.1822901121340692, 0.13686948688700795, 0.12319185363594443, 0.1832116220612079, 0.06791778563638218, 0.19013385608559474, 0.11886882115504704, 0.13008548528887331, 0.1261618544231169, 0.13473137427354231, 0.1368722625193186, 0.1253952900879085, 0.11514419718878344, 0.09422879840712994, 0.07675574772292748, 0.17232836777111515, 0.08110310038318858, 0.1124346605502069, 0.08332409604918212, 0.14542121003614739, 0.2469789542374201, 0.1432486023986712, 0.09498101702774875, 0.16113406454678625, 0.17730906925862655, 0.20796471100766212, 0.2074336598161608, 0.13610841444460675, 0.08623695888672955, 0.13258569175377488, 0.12134173142840154, 0.09346492806798778, 0.09052550376509316, 0.08584905313909985, 0.10856076100026257, 0.07312687564990483, 0.18999036925379187, 0.12354370584944263, 0.13260623440146446, 0.17420865828171372, 0.08915757716749795, 0.13069887034362182, 0.15299929480534047, 0.17485824530012906, 0.11072643697843887, 0.08309555909363553, 0.12512673652963713, 0.1639646157855168, 0.24312380875926465, 0.13268980022985488, 0.091841546818614, 0.11683696182444692, 0.15364966850029305, 0.07653245032997802, 0.087845319067128, 0.20482639112742618, 0.15440655522979796, 0.0866180368757341, 0.1038879988482222, 0.14122442429652438, 0.09199480031384155, 0.1045287617307622, 0.13636994728585705, 0.0937384094868321, 0.11937860981561244, 0.16000163624994457, 0.1383463162346743, 0.1764421962434426], [0.04004270776931662, 0.023171718821686227, 0.04503595155256335, 0.07677835354115814, 0.11061921890359372, 0.02209039666922763, 0.04397619435621891, 0.046006740085431375, 0.020074309832125437, 0.018776720280584414, 0.04718744879937731, 0.033734664029907435, 0.044876219108118676, 0.009215211521222955, 0.058240131693310104, 0.0358848105679499, 0.036026568195666187, 0.027276836335659027, 0.05722535235690884, 0.021288175848894753, 0.059087801637360826, 0.03205148794222623, 0.023270049678103533, 0.031236275826813653, 0.03455781341472175, 0.0302807198750088, 0.05274768227536697, 0.050548717263154685, 0.007869667169870809, 0.035675799517775886, 0.01747247366438387, 0.008099685637716902, 0.02619919894641498, 0.04057321719301399, 0.02406221810815623, 0.023008604039205238, 0.06347394635668024, 0.02985173439810751, 0.04374482610728592, 0.020495445241976995, 0.029005049655097537, 0.047072345405467786, 0.011428994439484086, 0.03979752815212123, 0.06358909056871198, 0.03603421602747403, 0.010819547405844787, 0.05738129613746423, 0.04342480831837747, 0.07184080794104375, 0.05508763679245021, 0.04756032234581653, 0.03034450190170901, 0.03142596877296455, 0.016016634108382277, 0.027064815876656212, 0.03915647954272572, 0.02523657589335926, 0.020602895237971097, 0.020551369780150708, 0.08890684257494286, 0.021317247628758196, 0.02658236237039091, 0.02552997655584477, 0.009303652332164347, 0.0066145720666099805, 0.010781954842968844, 0.05097660992760211, 0.020783027466677595, 0.05934380547842011, 0.04636068144463934, 0.034896125143859535, 0.07183062567492016, 0.018821525591192767, 0.026605112907418516, 0.028722608658426907, 0.025738792792253662, 0.005820166988996789, 0.010566655018919846, 0.07425168209010735, 0.0661594670964405, 0.07023422149359249, 0.010709602865972556, 0.03355116059537977, 0.032069188164314255, 0.049019685247913, 0.06370790841174312, 0.07218088227091357, 0.04290578362997621, 0.012831956901209196, 0.04182100863545202, 0.06117362623626832, 0.057048101516556926, 0.029136751181795262, 0.026697194880398456, 0.02020174029894406, 0.058342818956589326, 0.06274333907640539, 0.05370783583202865, 0.03862453035253566, 0.030857214624120388, 0.043661820600391366, 0.05138288383022882, 0.05153776262886822, 0.03522076651279349, 0.020484528249653522, 0.020858552124991547, 0.0326810147089418, 0.04743072851852048, 0.035600482660811394, 0.14150275936117396, 0.020197569429001305, 0.04291225144697819, 0.04960459038557019, 0.021736321723437868, 0.027214588699280284, 0.02758647704467876, 0.01309222530835541, 0.028508742107078433, 0.10123543688678183, 0.04821313028514851, 0.07261027407366782, 0.04167516548477579, 0.017790919955587015, 0.03437662177020684, 0.07807136775227264, 0.017778333130991086, 0.011118058682768606, 0.0709776308212895, 0.013047319807810709, 0.03195843746652827, 0.046311985424836166, 0.02998704647325212, 0.02129425403836649, 0.028091150452382863, 0.05122309201397002, 0.021114320334163494, 0.05505347944563255, 0.0395928586658556, 0.08140542166074738, 0.05553971233894117, 0.05190943389607128, 0.023988413377082907, 0.06407429929822683, 0.011535154026205419, 0.0345826345437672, 0.02397300639131572, 0.04602808054187335, 0.027290189427731093, 0.021291758566803765, 0.027732607777579688, 0.012565338493004674, 0.02926294597273227, 0.024104763579089195, 0.04376492717710789, 0.011909479399037082, 0.021543867987929843, 0.006696715290672728, 0.03587397521187086, 0.03482490865280852, 0.013800521774101071, 0.0024862967620720156, 0.059803495460073464, 0.06373907119268551, 0.024868862128641922, 0.03668524652312044, 0.031533799119642936, 0.06955595046747476, 0.023831775688449852, 0.07347702092374675, 0.02721058852330316, 0.03531815484166145, 0.0520330571453087, 0.10143998762941919, 0.08668467431562021, 0.06616849161218852, 0.06984005201957189, 0.017107502135331742, 0.04419269367645029, 0.019388333457754925, 0.04185401936410926, 0.02362593360885512, 0.019709490443347022, 0.011919677435798803, 0.015185692172963172, 0.11572205563425086, 0.03015590918948874, 0.01191881283375551, 0.028036066396452952, 0.01832484882470453, 0.05703278358851094, 0.007869293312978698, 0.02212444454926299, 0.04837262153159827, 0.04146089260757435, 0.02600498261017492, 0.01455304931369028, 0.017618910533201415, 0.03106282663793536, 0.050290178987779655, 0.03807794601016212, 0.05254892028460745, 0.03774703720409889, 0.07140279980376363, 0.014060324483580189, 0.12126431800425053, 0.016025753247959074, 0.04754821420647204, 0.04894971556495875, 0.09201785884215496, 0.031469098685192876, 0.006788613582102698, 0.04239897469233256, 0.025498160684946924, 0.06301797824562527, 0.04543547562207095, 0.052000606738147326, 0.029124806314939633, 0.005655127724821796, 0.04975202915375121, 0.07773361634463072, 0.04440229844476562, 0.028070804473827593, 0.033670687189442106, 0.030622655140177812, 0.05258697761746589, 0.035916537381126545, 0.047076876217033714, 0.04579091240884736, 0.046604476956417784, 0.03330501989694312, 0.004893802952210535, 0.04432701498444658, 0.05314651985827368, 0.09172297388431616, 0.01734774275973905, 0.07833037729142234, 0.04676653603382874, 0.07058228133246303, 0.06958164362004027, 0.04397208656882867, 0.034424523691996, 0.010243540618830593, 0.012316190241108416, 0.023157610594353173, 0.02575915917987004, 0.04114166149520315, 0.12163270526798442, 0.03487908543320373, 0.026160987617913634, 0.022307593608275056, 0.041239747442887165, 0.0683968048542738, 0.023023595422273502, 0.044035458558937535, 0.041440824934397824, 0.01723322751786327, 0.048606045529595576, 0.06117225326306652, 0.014468666195170954, 0.03917786823876668, 0.04414906281454023, 0.023449946274922695, 0.016616484244877938, 0.02971163918118691, 0.028946661186637357, 0.049758163004298694, 0.018206203531008214, 0.011103498673037393, 0.050218661926919594, 0.03186345369613264, 0.02761139094218379, 0.08777055511018261, 0.050889500344055705, 0.05794194046757184, 0.019374896874069236, 0.014508888743876014, 0.05146990435605403, 0.029752173431916162, 0.02195260582084302, 0.04429457199876197, 0.12555868132039905, 0.002332446997570514, 0.015937712269078474, 0.022141814515634906, 0.026475667509657796, 0.09874920506263152, 0.01171816486021271, 0.03960220601584297, 0.11713597312336788, 0.029151326962164603, 0.018292274107807316, 0.10831080566276796, 0.028221757311257534, 0.020635494074667804, 0.04521923234278802, 0.08260696617071517, 0.06254869600525126, 0.059225841105217114, 0.07218584723887034, 0.0469038073788397, 0.08083472494035959, 0.02313591761776479, 0.03679229390399996, 0.05401866583270021, 0.03709841868840158, 0.12736548436805606, 0.0309907121481956, 0.03252087779401336, 0.010946370239253156, 0.031185598272713833, 0.04369427100755274, 0.07227480105939321, 0.06586306073586456, 0.032154820873984136, 0.11698681628331542, 0.03108500015514437, 0.0319560403295327, 0.03377488101250492, 0.023182266595540568, 0.026950528845191002, 0.03282839781604707, 0.03374456056917552, 0.06404934829333797, 0.04799862734216731, 0.05398039327701554, 0.03214036383724306, 0.03471442141744774, 0.0034011268962785834, 0.015310560374928173, 0.004565923964037211, 0.0538052501360653, 0.028138273119111545, 0.0253230138332583, 0.023323009336309042, 0.03161361710226629, 0.02788140467600897, 0.09895801573293284, 0.01079572168237064, 0.022011751279933378, 0.030002254934515804, 0.026333277201047167, 0.044108812435297295, 0.04019370142486878, 0.10867183824302629, 0.04658169302274473, 0.025505645244265907, 0.010147611537831835, 0.039989120996324345, 0.04717323296063114, 0.03062412273720838, 0.013327745873539243, 0.14355273451656103, 0.07374647990218364, 0.09072929751710035, 0.15200625668512657, 0.17950300622032955, 0.1224190997891128, 0.1474822877207771, 0.1491753343725577, 0.15405354526592419, 0.18695595004828647, 0.12179229670437053, 0.14792046655202284, 0.18981623172294348, 0.11790540214860812, 0.21151976165128872, 0.07560196783742867, 0.12850346392951906, 0.10230719461105764, 0.09473874291870743, 0.20088839228264987, 0.11190875986358151, 0.06308440046268515, 0.137033783539664, 0.08898368454538286, 0.20073853782378137, 0.17530207929667085, 0.13019784644711763, 0.16405217436840758, 0.049451830418547615, 0.21802523522637784, 0.09364345911308192, 0.12139997517806478, 0.14592772582545877, 0.1297053275629878, 0.09357247268781066, 0.13410204788669944, 0.20655419997638091, 0.08510493134963326, 0.14416638674447313, 0.06807880199630745, 0.13115831912728027, 0.15305562381399795, 0.12700999563094229, 0.1262890882208012, 0.22415055107558146, 0.11558757105376571, 0.14866095181787387, 0.09452080383198336, 0.16993492667097598, 0.12789448723196983, 0.1228741773229558, 0.1456007652450353, 0.13290990638779476, 0.1931679339031689, 0.1249357670894824, 0.11657703944365494, 0.10926069531706162, 0.1334685506299138, 0.19463141943560913, 0.08309812692459673, 0.14689841045765206, 0.1311255755717866, 0.07759250438539311, 0.21304426656570286, 0.16844684636453167, 0.23065563873387873, 0.1367118101916276, 0.15052200586069375, 0.1048136202734895, 0.15763013303512707, 0.15557931183138862, 0.22448760486440733, 0.1826935139251873, 0.1829092117259279, 0.1399193872930482, 0.13952213048469275, 0.13848594389855862, 0.08346768678165972, 0.10005056843510829, 0.2229811341385357, 0.16963548492640257, 0.1429011585423723, 0.19276141509180889, 0.11890238107298501, 0.1926646984065883, 0.12761592952301726, 0.1606973700108938, 0.12851437350036576, 0.22167299495777115, 0.12876887078164145, 0.13288771617226303, 0.11015536176273599, 0.16759230784373358, 0.12582385068526492, 0.12395730474963784, 0.06980135643971153, 0.3027374146040529, 0.18655747611774132, 0.1146882884495426, 0.1583577791461721, 0.19455189089057967, 0.10630755612510256, 0.15422938973642886, 0.13542293716454878, 0.22104179835878313, 0.13500170898623765, 0.13878844329155982, 0.10481836259714328, 0.1969284555525519, 0.1706360187381506, 0.16702719207387418, 0.19328424328705296, 0.1567646997864358, 0.1909836448612623, 0.12035057094180956, 0.0940941579756327, 0.18549881729995832, 0.13887508161133155, 0.15484658943023533, 0.19337612116942182, 0.18025164026767015, 0.23058224032865837, 0.10081297674332745, 0.10765506624011323, 0.14527945982990786, 0.1879008673131466, 0.09750325785716996, 0.08516637375578284, 0.23692202201345935, 0.14628029050072655, 0.20077889581443742, 0.10594707273412496, 0.23170972592197359, 0.09947334823664278, 0.13522953348001465, 0.14160651160636917, 0.14690742013044655, 0.10518970360863023, 0.16686516639310867, 0.2596107975114137, 0.11632594862021506, 0.16428362054284662, 0.10861081143957563, 0.189765082905069, 0.1170669830753468, 0.1419098422047682, 0.08202591649023816, 0.1287110277917236, 0.10726791006163694, 0.09910533946822397, 0.1024525442335289, 0.20374146028188989, 0.1091374468524009, 0.10738806377048604, 0.11067843486671336, 0.13189478195272386, 0.08208572617149912, 0.10639132233336568, 0.1132985798176378, 0.07939319213619456, 0.13639721379149705, 0.1201672010938637, 0.14061757014133036, 0.203325976326596, 0.16677805309882388, 0.15165226708631963, 0.09647188038798049, 0.1789707675925456, 0.22356150846462697, 0.1543041388504207, 0.16896980814635754, 0.11830549396108836, 0.16612937150057405, 0.14865661767544225, 0.17254158679861575, 0.1257505116518587], [0.06777752714697272, 0.031551759093417786, 0.033247919054701924, 0.02581465512776049, 0.005067933061582153, 0.057221359602408484, 0.023751929875288624, 0.013600769943877822, 0.06888489311677404, 0.07140659959986806, 0.030846883928461466, 0.04967263048456516, 0.03962796225096099, 0.016228391104959883, 0.04455550370039418, 0.0534573795448523, 0.04884966663667001, 0.0164462763859774, 0.013277508041937836, 0.042632903350749984, 0.04020314525405411, 0.022326870894175954, 0.053006272501079366, 0.025290116282121744, 0.060052831104258075, 0.04247009099344723, 0.052720274761668406, 0.0121504918570281, 0.057652621617307886, 0.04600231317454018, 0.020878369323327206, 0.03628371865488589, 0.042859677705564536, 0.017549744225107133, 0.015431555493705673, 0.018169858703913633, 0.0384394535649335, 0.06634033590671606, 0.04024971502076369, 0.0670233640994411, 0.06183943660289515, 0.07718413762631826, 0.018945414158224594, 0.024187815470213536, 0.028731130369124003, 0.027054572383349296, 0.025447618572798092, 0.03265630119130947, 0.033225669467356056, 0.032955186325125396, 0.041959805093938485, 0.048961207721731625, 0.03956460139306728, 0.03478891449049115, 0.022815142838226166, 0.06347055474179797, 0.053486623874050565, 0.031210400848067366, 0.03684556155349128, 0.015763611845613923, 0.07288614520803094, 0.05551716218178626, 0.010823535521922167, 0.05234828437096439, 0.14134226250462234, 0.06392034076270647, 0.04287465424567927, 0.034659368902794085, 0.015067214790178696, 0.026325447543058544, 0.07657564332475886, 0.11136147790239193, 0.03009084324730793, 0.04052155629324261, 0.025030548276845366, 0.05022937853937037, 0.023316521110245958, 0.05445259215775877, 0.027105914159619715, 0.04954537813318893, 0.04992541711544618, 0.04506628683884628, 0.03218547899450641, 0.03294305221061222, 0.009273407031287206, 0.032042196253314614, 0.03821889098617248, 0.03173125493049156, 0.008812518481136067, 0.04528668985585682, 0.08038364016101696, 0.06115063821198419, 0.012804760899598477, 0.032227488263743, 0.013710989078390412, 0.10279829599312507, 0.07232279574964195, 0.04228772304486483, 0.04017294726509135, 0.03991501755081117, 0.038391878188122064, 0.02025638648774475, 0.08000231726327911, 0.023608780720678624, 0.07629135623574257, 0.04711707464593928, 0.04845197567192372, 0.01229772004080587, 0.013232530181994662, 0.04146231382037513, 0.026284677660441957, 0.0576627333794022, 0.03286676685092971, 0.04649306945793796, 0.02298019277077401, 0.050858159447670914, 0.022189686751517, 0.039132938618422486, 0.024856928394001443, 0.020116343221161515, 0.09684158125310205, 0.030038575641810894, 0.032591990384389646, 0.10244530829368159, 0.03706903335114475, 0.0375512994651217, 0.020517475895758253, 0.0026745179366116645, 0.03902432901668362, 0.06704647457809187, 0.02911394869443029, 0.05316174872859847, 0.023608905030414462, 0.03565560567949433, 0.07003631297266111, 0.06077181635191664, 0.0762095938262064, 0.004514061292866245, 0.03206335488357581, 0.0547578300756868, 0.05256760385236703, 0.06704894592985511, 0.05724436246964615, 0.04090441172593273, 0.04038960985781159, 0.03895663772709668, 0.037114812730578706, 0.08143748986185528, 0.00453714162176766, 0.023485380115744192, 0.07067266007652506, 0.019880527652276214, 0.046834832173772156, 0.008046502407523803, 0.030359337433765177, 0.045985522083356045, 0.07554606185294688, 0.004658345469579217, 0.044670766656054184, 0.051558995473897085, 0.03378645109478384, 0.04019130428787321, 0.06200962219736539, 0.028218536390340887, 0.04762865188240539, 0.011289505928289145, 0.05143536109244451, 0.03112050449999515, 0.049839606290333904, 0.05540111997106578, 0.023797364156052936, 0.04393963245092891, 0.12015324871754274, 0.07051782580674626, 0.028347311999823432, 0.025904863177856896, 0.02184800752729643, 0.030034903866180684, 0.009053374160430394, 0.08025446193641983, 0.025866841097013094, 0.04860208988247905, 0.04042957451019902, 0.04523974159383215, 0.04495695735386107, 0.055113816051743925, 0.05718985543353483, 0.014425264471356058, 0.05381130977184512, 0.020223010251356754, 0.08415493779466487, 0.024775809797574766, 0.06842042741482146, 0.041472740995232016, 0.026038555515697226, 0.029860194881621283, 0.04181305652309675, 0.011527491351444041, 0.03426828305236995, 0.05705292918719351, 0.06315743521554396, 0.04552782476821449, 0.02544350707466947, 0.018772541989164893, 0.02746567395661259, 0.033839978495961986, 0.034793864615494385, 0.03970317149651237, 0.06381929735653102, 0.022236913318920415, 0.03907813472324051, 0.033433908683946356, 0.02869212308723945, 0.032448588899569586, 0.023315986763918772, 0.04137639167311136, 0.07744249407551251, 0.023708388071099762, 0.041972187827923335, 0.11256604295340367, 0.02651878628967097, 0.020595171336026397, 0.08942151456722058, 0.016387129071517847, 0.021079105426906608, 0.031911121841403656, 0.017737579946697224, 0.017107424209825695, 0.021892057702643797, 0.02501372935512336, 0.00845813276100671, 0.014052341757633258, 0.07603476609801874, 0.0672957174538169, 0.04845400544581935, 0.053255214806995355, 0.03820193662249949, 0.09377418842632324, 0.049104735371656716, 0.09600344419595785, 0.07680108552449383, 0.048293571671820246, 0.03683109338453505, 0.01728789968183264, 0.06559152374393307, 0.020011923043057323, 0.04423209058586508, 0.05366774130379781, 0.04381420207209885, 0.013689282186533092, 0.04660710044845473, 0.05742634821217507, 0.006841711929155281, 0.07335268150200136, 0.011232958913751645, 0.01573555124195991, 0.03052664720598841, 0.040340587293030694, 0.07051174761727452, 0.08965043001808226, 0.06169177890114952, 0.033534480826347135, 0.06853505954495631, 0.03032662541954778, 0.03851664063404314, 0.018595114888739772, 0.04944715488818474, 0.048424278720631264, 0.024940666771726683, 0.033387787916581146, 0.022594253714487422, 0.08051147509831935, 0.028702110539597925, 0.012287423669476993, 0.013395372225204483, 0.012264071992831305, 0.016526945983059704, 0.049523633206263185, 0.02222415765572805, 0.0321195948345121, 0.0047392242595378775, 0.055548265590914525, 0.009736137035361025, 0.03624504905019421, 0.08459530596155673, 0.02193290551076643, 0.021967931170365773, 0.02101312107697595, 0.01665695170231629, 0.059583496913546696, 0.04550831741653383, 0.016832545697980095, 0.09670544910477474, 0.017976365961658303, 0.024857811549736653, 0.03216810160665773, 0.09483806454227306, 0.039549368812004104, 0.011330029974487843, 0.04994976698071696, 0.07473899109754711, 0.018038914167846087, 0.021555356433964334, 0.023458206378563773, 0.039047120371833444, 0.05741317138017621, 0.03821377758868039, 0.005536461094379774, 0.046440855658147484, 0.04984590341337025, 0.056764441542327404, 0.024481911896145903, 0.01223857922013849, 0.03883578639943153, 0.04817450149857905, 0.0462345386040397, 0.04885512884357013, 0.025237397821911145, 0.05129563694936223, 0.08775073976721615, 0.06546128424815834, 0.035024457320105284, 0.030700656716362573, 0.08133873969200067, 0.049345655061188154, 0.018100063425663393, 0.05980911351798568, 0.021047510344942566, 0.011893632690771483, 0.02709826632781187, 0.03465498652076349, 0.07221985244541429, 0.06860439098090865, 0.03485516230284702, 0.0276395183391287, 0.02809316909406334, 0.011892435049958294, 0.025578121530998033, 0.10063147710752673, 0.08482117118546739, 0.04176006346824579, 0.05639156799588818, 0.02082515919028083, 0.06233601874555461, 0.02501763305190252, 0.06871382807730697, 0.013087053466733778, 0.008809184382698731, 0.05733111953304615, 0.01989902197237825, 0.03657807297713589, 0.04618043974915054, 0.19652070477604866, 0.13350769149838015, 0.09387535057612695, 0.1614492546650581, 0.08864306102623232, 0.2119917527306825, 0.16514892020495608, 0.12098450606572442, 0.12075716396793723, 0.17278446204727516, 0.100010663154535, 0.16207595384912565, 0.19059974671108648, 0.07243872663821094, 0.1419807766797021, 0.09935202193446457, 0.13488496915670112, 0.1340774234267883, 0.13398830633377656, 0.1523165189428255, 0.08391255978494883, 0.15398767223814502, 0.20370202255435288, 0.15989904175512493, 0.17223154718521982, 0.14060354355024174, 0.0888110016239807, 0.10845418117241934, 0.16498484619660303, 0.12321951347985305, 0.11783422276494093, 0.16643574490444735, 0.10940950334770605, 0.21325883630197495, 0.14002368872752413, 0.11771051416872069, 0.07708352466579527, 0.1700299364165403, 0.06615504389628768, 0.18539905780926347, 0.21190086932620034, 0.1295888697495684, 0.09520889347186312, 0.17262963519897312, 0.11074410009314306, 0.12549711274914443, 0.21743280842201784, 0.08217189693823457, 0.15881037048529834, 0.16195142146898434, 0.1449826156022027, 0.12285255113965832, 0.14058583590667695, 0.0680161573109217, 0.11142490926431492, 0.08110124501399696, 0.20862917066551745, 0.15425931313075125, 0.12415794437401928, 0.13852881034836173, 0.1675725815584883, 0.20267803687602282, 0.18765313841868192, 0.14817349438089877, 0.23483260913053527, 0.15315355762140825, 0.160694312362466, 0.15348652959801257, 0.35499737598001957, 0.17595519893802702, 0.19963868980994448, 0.25730616180226207, 0.15150158142205328, 0.0751746169407852, 0.09633845707867295, 0.13768616103334352, 0.10768190230010077, 0.24359593342524022, 0.12442440507584251, 0.25030696706380695, 0.17882891348563135, 0.160141991218552, 0.1971009752014652, 0.1856519965804182, 0.15343293169280514, 0.14866568672005087, 0.1480143630760722, 0.14835821493761614, 0.17281123873544857, 0.07349928535404615, 0.1422590672154911, 0.1899570765090175, 0.12098221282940358, 0.13351771049201488, 0.09004798368550837, 0.18581261218059808, 0.13676787202712148, 0.1348834254895337, 0.11402074145735241, 0.12385719644953497, 0.09946027901605703, 0.11477204723632894, 0.17378174525219947, 0.16311230370774865, 0.15709498518845066, 0.1570115381036885, 0.09611596120521426, 0.11761316665797494, 0.17712927656248212, 0.10641682252753526, 0.10359400446759537, 0.10610126133542508, 0.07947413076180965, 0.0983495288528502, 0.14502462116070092, 0.1045893803529907, 0.20304301026044413, 0.07928713923320174, 0.13560393213992938, 0.11956813948927447, 0.21852805512025952, 0.17563937057275325, 0.16247001942247152, 0.17165495781227946, 0.17424917954485863, 0.1382676188950427, 0.06329179363092408, 0.10169672619667836, 0.11473485821625218, 0.1537018860108219, 0.06605094284168445, 0.13786847703158855, 0.12119183244067244, 0.1448678647284396, 0.12696508085355163, 0.14680019463412464, 0.18458271020790562, 0.11800027088611387, 0.19921642262488604, 0.142478060151916, 0.24213657423388213, 0.12091285912902094, 0.18447438633302227, 0.17395885137375444, 0.12533574015833437, 0.1620186897343956, 0.16826074541313574, 0.17844458488980308, 0.16308897058479488, 0.09107887875870802, 0.1270481271785684, 0.16007298632757738, 0.17097779258619994, 0.11652698158286512, 0.20592036133166403, 0.1692255077068694, 0.1669318409403786, 0.09846679560723715, 0.10735052594100125, 0.06768195336917415, 0.14615013264119625, 0.1265735534252599, 0.23322440480114892, 0.15739404101623222, 0.09769831653102301, 0.1474402376334183, 0.06483443663455546, 0.15524118934990838, 0.10653146207914688, 0.1311384147265926, 0.12245848556631245, 0.13403912860667333, 0.300086522474885, 0.1976476560230367, 0.1272570269065909, 0.11482128873467445], [0.013657632371177897, 0.051302342253620736, 0.055904403707245365, 0.04681734717451036, 0.026574825860734563, 0.04979300683771726, 0.017770071171980817, 0.03604325538617559, 0.042446286606718786, 0.038758473165216856, 0.028219345331308432, 0.027048360607295763, 0.050058276392519474, 0.010452265014464501, 0.05524651947780512, 0.03321025877085049, 0.05421178007964045, 0.06504302466055378, 0.04070878530910704, 0.05318646595696919, 0.023392350049107336, 0.05498432983586099, 0.03367633493326139, 0.04417041811393574, 0.061852401922806166, 0.015064519866427872, 0.011051833134843037, 0.015577470076095778, 0.03270316410635132, 0.04277296888176352, 0.054624191543553025, 0.028909121501783375, 0.015526652441621991, 0.0362044832581887, 0.10123197847860865, 0.035271162050776184, 0.006282143713178812, 0.06102853636548389, 0.03553800124791451, 0.0528935476904735, 0.020846878142037895, 0.013410031497187447, 0.06888039570185356, 0.021411413181340322, 0.03619765549956355, 0.04514101739914622, 0.04504224496486131, 0.0430264271562919, 0.051000792809645645, 0.03907238678948488, 0.03720499480550643, 0.011953276316489791, 0.04552034391963389, 0.028520861378638074, 0.004116666259506019, 0.005645733062920044, 0.07139166016713716, 0.025442391997785307, 0.022752564946131315, 0.025573108323442284, 0.01166670805105241, 0.04656148063077126, 0.07110397404176183, 0.051684897116501816, 0.01785166845365893, 0.028057494055246934, 0.04676911870774347, 0.046776120871072635, 0.11012842922355048, 0.03028356786671793, 0.06420082063414156, 0.028047686573700048, 0.015288204103853786, 0.03561035693564918, 0.019450994841463398, 0.014571037118003005, 0.006550148546011769, 0.03109608413069509, 0.01871487525932025, 0.010362974444433348, 0.062129412253852934, 0.06579997076187283, 0.07843154686270282, 0.04765208148455713, 0.044760518285329454, 0.01808722983696498, 0.033737636331352405, 0.008131742706609657, 0.05480618099682033, 0.028914837894262746, 0.07207865884993225, 0.062233980861492455, 0.025306352617917582, 0.030794853810220957, 0.021708279673475772, 0.07706944612436928, 0.04422622761921957, 0.06711562789860182, 0.03939866459404584, 0.08085592067800462, 0.029659061729034875, 0.02338879701710539, 0.021133931586518884, 0.055637660989305004, 0.03650374317658134, 0.0577550008893013, 0.02071514321869472, 0.015713361026428174, 0.07999552661203779, 0.02520531848858809, 0.02070453978376463, 0.004514781176112592, 0.05159834043297451, 0.038580346590606496, 0.034156816182076, 0.040779385817586444, 0.04788973572431132, 0.06429331449908204, 0.011911251276615076, 0.019735691967071034, 0.00790272521044244, 0.07493580866139382, 0.017570106901985127, 0.01355666132440092, 0.019058667749050073, 0.01729092764435336, 0.08248710932093672, 0.045342373196035624, 0.059843627095688134, 0.02508658784790896, 0.02309839092049515, 0.033938290798687376, 0.03808724883128889, 0.026277571596438065, 0.03878245195664931, 0.10026527917943895, 0.017775655833247583, 0.015470223243028158, 0.02455154390190728, 0.039812348841223866, 0.03121823421679437, 0.043356426831451245, 0.026147849748667795, 0.03758508202736266, 0.0366452410526108, 0.04327499838836957, 0.028070750668121036, 0.03028153623745311, 0.03627430080086924, 0.03336642148497049, 0.009134676438407041, 0.035892150408471934, 0.060024187914677896, 0.048216443974524736, 0.05814219417516142, 0.010869775960600236, 0.04438401934748981, 0.029720133061346132, 0.01103131182389916, 0.07431320613250136, 0.05559980032558087, 0.03627110585512128, 0.05384648386097979, 0.04959265665092971, 0.04126063889998477, 0.020726234615722205, 0.07654707806068473, 0.013600474940176355, 0.04278899927157909, 0.02655646141647594, 0.02001331828068942, 0.04844285467697773, 0.040440999873680994, 0.011777693453041138, 0.031354856182588264, 0.03691931990033481, 0.04615669102349784, 0.015317578308895463, 0.05839050194481388, 0.0333053353097057, 0.05779777085990645, 0.026686530218285043, 0.022885457619850058, 0.04283335372747388, 0.04978108423529193, 0.04260654968675226, 0.03955650085117668, 0.030044896884646732, 0.03638342248450499, 0.021717647432524245, 0.009493185716564767, 0.011423178784752963, 0.032474972249474376, 0.04756667141919024, 0.03449715397437103, 0.04322084758314304, 0.019897764032066334, 0.035878828857676126, 0.014238080912036821, 0.013741761304117972, 0.04611031792592257, 0.05017011062591337, 0.019431917935435195, 0.053601612235070206, 0.03191760079062078, 0.039621987962163985, 0.025255745567847043, 0.019012958873645402, 0.08321871107909828, 0.04267902040737681, 0.04799412992724683, 0.042679747712099925, 0.03579248739697505, 0.008200828306144103, 0.04062178333697375, 0.038016277248971164, 0.025596597297408152, 0.06264435141929425, 0.063138525292743, 0.03372804036189336, 0.059215009459876455, 0.025381483937962912, 0.020637217712646816, 0.060703598137479275, 0.08017011685296893, 0.05994389866827987, 0.044990906899329275, 0.020118834981985856, 0.060062675693188794, 0.02656505548657151, 0.027831584302475676, 0.06578946195077151, 0.07787763752276078, 0.0274714701299672, 0.08107287270831876, 0.053322223320719786, 0.036436571390368044, 0.05504804321390111, 0.025705346051836386, 0.035575880465330556, 0.04986964471754618, 0.031822828532313, 0.04578293432132341, 0.010928274823527317, 0.07706044387305155, 0.05858397242263891, 0.03701927977090236, 0.03632460728113074, 0.04179278475930914, 0.05385137090343051, 0.02900528343161568, 0.08902708534151316, 0.007004340141065768, 0.028777919069398195, 0.016266576458292548, 0.05787322130345274, 0.013421359453786863, 0.0574741462332895, 0.025902145061991177, 0.022257096024986822, 0.060789746639784425, 0.02080124719213927, 0.03403347123821732, 0.02448326446028659, 0.034064845531247556, 0.015572636839351617, 0.0899190800555516, 0.024462977853545453, 0.041618495088187046, 0.023301329347305, 0.03372111983480863, 0.051011865652981214, 0.02097401360515505, 0.060494119534268975, 0.019830423407256603, 0.042246081138728186, 0.037196508346823975, 0.017468762926000636, 0.02302594431967009, 0.03420869972615037, 0.022506711829919368, 0.041933158281608485, 0.045416302236844786, 0.03599853727791924, 0.04070347895321902, 0.05001322802854702, 0.0537419523607241, 0.023304368442040868, 0.04319603758631274, 0.04804586133104749, 0.09174545353744179, 0.026724576418928336, 0.0179600554110948, 0.03852116773487069, 0.02387294818618102, 0.031630630837753415, 0.038138175004860386, 0.020813459232158493, 0.03382402232091408, 0.03282598212535959, 0.025773328634386417, 0.021704901046177838, 0.04271970865374897, 0.01302312486586743, 0.016279872033919673, 0.030054375965846702, 0.02836319210473448, 0.024913767629186623, 0.029872720479033887, 0.028342827572487295, 0.04630322437151335, 0.03800038786721416, 0.016957102197920904, 0.0134842945044511, 0.0400334828736959, 0.0730972491146531, 0.018870709573093336, 0.02762497966614319, 0.037253690825309604, 0.07088705911883153, 0.015149691516853636, 0.03968811332015321, 0.034924412102554925, 0.00883422908373177, 0.036039796978002414, 0.014970442443882348, 0.09064527897862718, 0.02444369500153698, 0.02164538822398754, 0.040618725688545965, 0.041491962620057166, 0.019351430164533667, 0.04237033521349076, 0.05235952419752721, 0.030858207246637903, 0.063885875424603, 0.03801050334004685, 0.08411625705775805, 0.023275333769561257, 0.03373886087501887, 0.018788093693729024, 0.03156576342007611, 0.030252510841819458, 0.03378713387064636, 0.01840485605498543, 0.04239265159412753, 0.033680876877042465, 0.010516903294046642, 0.008128196168399882, 0.04231151629937813, 0.04232882318319753, 0.056804491541697644, 0.1201188204868231, 0.15048616012791172, 0.23037307342747226, 0.086817867559148, 0.1518698944710195, 0.08484971418511122, 0.1969876344082877, 0.10390224808361381, 0.2144899999257177, 0.14348190394230187, 0.13044131541391835, 0.1175516277726274, 0.1747584858094342, 0.08702794730197638, 0.0764491071458906, 0.14637501823017374, 0.13319404504727572, 0.1885690080234781, 0.1500904469867237, 0.18419248895952478, 0.11950205123866908, 0.12317118482314982, 0.16385431779781356, 0.12372768425848335, 0.21195219625951722, 0.09927371793310158, 0.08330554235726595, 0.20897217647871003, 0.11331702960887924, 0.12481335725169629, 0.10678996695787646, 0.05382036768423859, 0.18297775648534298, 0.2127372400718741, 0.1770336730987765, 0.12371005825116299, 0.11912127753021196, 0.11627818399574608, 0.13285550696309656, 0.11450464400695637, 0.120147393172374, 0.09159974026260898, 0.12863644195022061, 0.20382152317324653, 0.15789781085914, 0.09651924425270408, 0.10880255271331407, 0.13936072820797563, 0.20746652211528271, 0.08687712805112824, 0.14602128096157685, 0.12476873933337629, 0.0977893261006102, 0.10857924047741108, 0.1128947178949602, 0.1780803536530584, 0.21769637474790215, 0.21814405306940898, 0.17792196449590847, 0.10853094150661491, 0.10999722493579611, 0.20058762951521203, 0.1498085941420868, 0.14487478154478595, 0.17747925856383517, 0.07286995154572651, 0.2739270339952782, 0.09425702970474958, 0.2426479139830917, 0.15706685779150575, 0.17428777122404426, 0.10243398312013596, 0.12297254157601856, 0.15715806774096563, 0.08575347193982452, 0.12760650424752384, 0.1778864156221971, 0.27493911562487483, 0.09833387695834972, 0.09025311330333352, 0.1362382754450664, 0.1637252137879841, 0.1962367887608707, 0.09863875864539295, 0.1245474160532467, 0.08840008187689818, 0.14959075895603746, 0.09608890992240049, 0.09989052428863943, 0.16166588757187128, 0.18616335117258132, 0.12904460832942277, 0.10262890820740722, 0.10070163232740015, 0.14440111321164295, 0.1608226148528047, 0.10815712914336473, 0.15682482859119773, 0.1814496298902668, 0.16214120347285643, 0.093424911465263, 0.10618181404424831, 0.135928473318927, 0.24445062037557364, 0.1888480703928508, 0.15727857768069953, 0.10005405652918853, 0.21086861612275243, 0.1800263687619008, 0.14247921790229157, 0.18436917947838083, 0.21281555149471387, 0.11535572411958128, 0.15631282090907916, 0.16056831052992493, 0.11081864882726222, 0.16094395599793643, 0.12823853205190971, 0.10491222201380879, 0.098259981314186, 0.08966731387772597, 0.13340282603166997, 0.1077526735025458, 0.09578787998179905, 0.08642533081001602, 0.11161796413944103, 0.1635708470712416, 0.13125303201377392, 0.11439776732004248, 0.08575612882850692, 0.16522038902621716, 0.11961720287217759, 0.15900076105026528, 0.1640121132368222, 0.11746080373995937, 0.13602232531411573, 0.1058922428637743, 0.15113200672203675, 0.11267074514762498, 0.11687360907671973, 0.09768649411853403, 0.10551638217293657, 0.10755547002190724, 0.1909883797634393, 0.08993577837827615, 0.14821503980783746, 0.1195844222093001, 0.1176991815736983, 0.08376923622563481, 0.12939887994434685, 0.23329703137278557, 0.06517549802083522, 0.23831927828723565, 0.13389797211857513, 0.11222881847061217, 0.12728905800031498, 0.12565643701236695, 0.1429801675840281, 0.08395279161049984, 0.14293810265371576, 0.13184759620344266, 0.16120694344863296, 0.17653619666816667, 0.0902676816622261, 0.09961802992620505, 0.09186885043163784, 0.14635216008173302, 0.09085201905691065, 0.13499580149073154, 0.13153837295249104, 0.07626351085491478, 0.09992029925342649, 0.11949028819799423, 0.13766153657343239, 0.15403076133225113, 0.18664439645363018], [0.06011159064655658, 0.017463619842601474, 0.013821649790770607, 0.02657131179148564, 0.02737064194661798, 0.020454510231502354, 0.03337311565701384, 0.06261063565034419, 0.004688846347562503, 0.05370026221498847, 0.1039202006359119, 0.04990567969798576, 0.0734332342108246, 0.03262514583184384, 0.05543761879380327, 0.053088094282429665, 0.008792813532636501, 0.009796911508601625, 0.05564752413192764, 0.049934731068788096, 0.01487828903918853, 0.04399455508973915, 0.09289390480262227, 0.02048921862296993, 0.004427749518072233, 0.03898179282259662, 0.028743860057147685, 0.0498849106952548, 0.08364268520381302, 0.029361759225139394, 0.020350687482277863, 0.019697469506354537, 0.020380228670546785, 0.03515557626087684, 0.0657899295038078, 0.03606442885939032, 0.08708872177521698, 0.015480820184166078, 0.05312907196639571, 0.0478621204092633, 0.033893190484377556, 0.014942307625460671, 0.06743763835402206, 0.009060547017725185, 0.018230911482532974, 0.038438945193775, 0.03785994013014715, 0.025009675373439677, 0.08453324757283553, 0.05129518795001786, 0.04365636581496801, 0.018302833013876807, 0.038367595116142184, 0.039610844614799134, 0.03478740050923079, 0.01441134549168055, 0.015939101940602995, 0.04671889386372641, 0.049610839269007556, 0.038462823795271106, 0.020949021782143973, 0.03996626284788363, 0.026214132813038304, 0.04146544939430896, 0.015720044066256378, 0.029379119914665353, 0.04953111776558217, 0.052199606216163374, 0.033573065084056, 0.022628008446190506, 0.016920245288929436, 0.07264999381732196, 0.03310321881144773, 0.033250627893721685, 0.027403940257499926, 0.02823264461767394, 0.0344450403645169, 0.020057327637914568, 0.06684409090667032, 0.013794911137665622, 0.037851290398975834, 0.0673143750464078, 0.030201783192751464, 0.0504873193858657, 0.1135827333200723, 0.04454731410078239, 0.02569308391684899, 0.03534284609486349, 0.059459558251546696, 0.06934334742254578, 0.04566099203657359, 0.029701547828153707, 0.01870672462246148, 0.04133183683734387, 0.041080271039390936, 0.06168289539346006, 0.0179801286503789, 0.08809381979517639, 0.08330818440299481, 0.03348391459439881, 0.022235317701415624, 0.02199422917328775, 0.06475485613918863, 0.04575362319883425, 0.036269543634261936, 0.01838824864535127, 0.14559623814420775, 0.03811556176515296, 0.0150666164336144, 0.06938402453670278, 0.025919873114617076, 0.05152231482497882, 0.034039987294818275, 0.05777908729214687, 0.03512530405714642, 0.05062111005827319, 0.04419882010552101, 0.06050973432138562, 0.013227695089881308, 0.008244719847425586, 0.04248258133884519, 0.0072360827107331716, 0.010754272734629922, 0.00799420326075051, 0.0346439619170269, 0.07509600123739801, 0.003836795413008076, 0.02102901788020972, 0.01815077252103947, 0.040583666632301174, 0.05266385298455134, 0.044680488790618256, 0.024848302782629617, 0.01410518545526429, 0.037421134184114635, 0.025352078191644978, 0.02420148583041737, 0.031786645122338086, 0.01784515054168878, 0.040133784132194705, 0.01987975396332331, 0.09544095562887378, 0.02703813195694238, 0.05180370753805619, 0.03481148320133798, 0.03917111098417081, 0.012868002086179331, 0.049054150586016476, 0.023784306067682337, 0.05987695694784634, 0.006530140244649374, 0.013546239715651609, 0.015988055856723804, 0.02168381106457673, 0.023717735421087127, 0.03144025140500162, 0.05037612339947373, 0.05050994375778828, 0.014594915719499113, 0.04916268968372606, 0.05047526690759696, 0.05519971964531578, 0.03562281017366331, 0.03810157228144817, 0.050695410172920674, 0.05036321374063846, 0.03670518060971517, 0.026592110480123665, 0.03303289660834707, 0.07117866378393956, 0.05925338962697424, 0.031242903205566108, 0.00939908695727354, 0.09172482183203101, 0.04372236871859059, 0.08861310052452609, 0.030390730280487332, 0.02809490015351912, 0.005616441421807394, 0.0033029769383574603, 0.03553276910679415, 0.02352355804760009, 0.026161662972299382, 0.019568894276744686, 0.015857200378377456, 0.02343173953704536, 0.03547515989339445, 0.004492815460253041, 0.045979154456290416, 0.045577626588055864, 0.07929221552331, 0.05455255202832632, 0.013602387825812912, 0.03954214771511033, 0.06275816718698479, 0.022288557520369068, 0.004214460914226947, 0.0720010747318156, 0.060619742871494964, 0.024803580963634886, 0.027938190105487593, 0.03256586678617168, 0.03772074662265368, 0.026703243383963127, 0.06739712451235391, 0.022003003214194905, 0.020039354676555376, 0.0395117233711062, 0.16152725438587368, 0.03471790209005121, 0.037278834788594395, 0.07718047883827239, 0.11040341720217839, 0.050604166826815344, 0.06002328620525077, 0.03107402750174515, 0.06131054135039449, 0.035980796237709, 0.04770428415213246, 0.024794010969344527, 0.03546052845194936, 0.04665700987970922, 0.08503477612975985, 0.05860260032932274, 0.13274476368678734, 0.020652502244047355, 0.0387041071371641, 0.03225977539841551, 0.021603627574222628, 0.023160916862252634, 0.012414251141308341, 0.014488964861811837, 0.02573904326709453, 0.002250109655506094, 0.01761114766850369, 0.04479326926229987, 0.02159405757993227, 0.035652399601531215, 0.07845246800570749, 0.09953437504009344, 0.009620947366784094, 0.0014553046298715344, 0.03660702415800188, 0.026739571512734983, 0.06281894166022539, 0.020201319130137563, 0.019354137148184236, 0.03216407174477354, 0.059126037085661665, 0.06890161370392889, 0.006797703035772429, 0.014799344935454428, 0.0681402518239338, 0.037082989438204095, 0.05613318928226363, 0.01671318052103743, 0.041639906048658304, 0.013858829534001416, 0.022625186429650057, 0.03274153314123396, 0.050981741878786124, 0.03520465448673349, 0.07770797514240257, 0.06189321633428335, 0.04694534909504, 0.04340101506386418, 0.03093659288424533, 0.06355921912472695, 0.02206222474342212, 0.020822455917368643, 0.02918452322774101, 0.029503053010557778, 0.019876238038705196, 0.0299091692068032, 0.038015705795260146, 0.07175666323746555, 0.033045865638996474, 0.08067140792263672, 0.005111048594699241, 0.044055080943508074, 0.027308268145134207, 0.018439768537064083, 0.01541449259093497, 0.0030203081951185595, 0.014557381600752706, 0.013743470099143451, 0.04032496508443728, 0.03224421256163623, 0.040817361514200456, 0.06822028502938338, 0.014828118000878021, 0.02605491245049052, 0.03674162748211529, 0.05102294591779355, 0.003763414169952739, 0.0361965163028799, 0.05268171276838984, 0.0557792182371486, 0.015458200450666482, 0.019807533717539627, 0.034271155163878575, 0.018590576655697078, 0.024317947354575153, 0.01807409196771914, 0.05875756076420657, 0.021314549921953585, 0.04582757450407371, 0.06990677851717919, 0.007436049763782648, 0.04695731622632593, 0.03514016185363289, 0.10670347706764005, 0.016665423318045214, 0.007970109436428174, 0.034986036334885284, 0.054238055818132125, 0.04275777711882256, 0.08574734180001542, 0.013054907340119826, 0.028510881347756367, 0.0585898836288834, 0.013302191873663105, 0.025635218662500847, 0.11148825156851672, 0.054997900006128475, 0.03572068460925948, 0.005621070567940478, 0.029989692229719367, 0.08850271347910166, 0.012296469521970721, 0.055921217062859796, 0.027587044787651394, 0.14436123019549996, 0.042026238443213515, 0.005935686913289828, 0.025441067264182493, 0.04463757410121616, 0.06538434579852037, 0.02843296326318523, 0.0500342790473951, 0.08067919305176474, 0.01869457195425639, 0.05600005169981159, 0.02610572915727971, 0.04282663358026184, 0.020094501815037802, 0.011084873549407348, 0.011029616016458021, 0.06663600754109211, 0.04978132543328684, 0.018550832792243455, 0.02326514593733009, 0.13894218660425395, 0.12681630993029103, 0.09067184044397436, 0.08739025637623854, 0.10203785437624902, 0.1362623952445574, 0.18911169609054923, 0.14928199583664536, 0.11817889841040596, 0.15651168680051342, 0.13033591560088098, 0.09770640594069846, 0.2730437001446262, 0.08787668964941986, 0.17640345613472164, 0.1558456983184442, 0.09903082042001188, 0.27978700236417353, 0.1945726413396187, 0.13092604174744338, 0.07901469682110474, 0.07808962458511814, 0.10222302764304914, 0.16178529913304374, 0.07502627646317706, 0.15987885533832014, 0.08614581573056057, 0.10809510786202736, 0.18531911366153508, 0.10130116890650243, 0.07809548755176365, 0.15381841803900898, 0.23971864226041362, 0.16945000737905502, 0.15592138253850862, 0.17938798817340285, 0.19225305877625942, 0.13097380637191236, 0.1671615504892543, 0.13088578765746206, 0.11118244219687767, 0.08370847659534775, 0.16209731285925955, 0.15063467872096226, 0.0732435857935343, 0.1120960408297833, 0.13672030036104843, 0.19025203568162397, 0.23657098616240546, 0.11587147964746691, 0.18845335172954947, 0.11813119315775111, 0.10099637627718039, 0.10986860332195647, 0.16674783284543082, 0.14666197705082595, 0.08412273600697517, 0.13192374055506662, 0.1860934853903018, 0.08560283080441877, 0.14242386852856725, 0.1871823496185243, 0.14438601792789996, 0.17851915588835254, 0.16188856156077236, 0.1338757819030434, 0.1802671659970656, 0.09830692215473391, 0.1557278452673927, 0.09466476563829929, 0.11193939571967348, 0.09210177347995341, 0.08493712433846667, 0.18547398503869772, 0.09932737521012314, 0.13236389349913225, 0.10576526881777681, 0.19516287138685584, 0.20741434913361445, 0.10056020124466158, 0.08120912360027432, 0.1842153916368261, 0.11786235016188584, 0.20110496581764892, 0.1542090845759958, 0.14151653362205252, 0.12160739803221077, 0.20829763845540583, 0.1083505031419918, 0.16532255307538435, 0.14193500101100653, 0.12801685254089534, 0.07408657649648376, 0.14823553792666644, 0.11179616863955744, 0.15035457734484226, 0.1304041189723648, 0.31454062031116337, 0.2026987131102942, 0.1403448308701627, 0.11566419037990272, 0.10522982411202975, 0.10925958951702341, 0.1971300970762968, 0.18966513045597821, 0.11658929972327314, 0.16562698205234483, 0.1398353316471912, 0.09135589280049317, 0.10518491675611585, 0.15241056389641017, 0.14128496870398521, 0.10042071458883584, 0.17453429783927277, 0.1924043381586671, 0.21553976781433448, 0.14004783821292222, 0.12010880891466513, 0.11971696236287244, 0.1587461301824078, 0.1270370840211399, 0.09428831865079701, 0.2093261809204705, 0.07677923669689335, 0.11602728613070212, 0.18671567231649533, 0.12321435555350035, 0.14473935443675146, 0.246968311839737, 0.14999604580225423, 0.11797235871199518, 0.15179581328993663, 0.08283905059215613, 0.10403647291241214, 0.17688009305857122, 0.16924222087254748, 0.18496582168154418, 0.08493889807141386, 0.18098874134011567, 0.18920680973678827, 0.15095215465407819, 0.17596351099200547, 0.1113687435281463, 0.10351288030506112, 0.13033607887336984, 0.19600235915277153, 0.15830726857529953, 0.24852639151504263, 0.12760629644617438, 0.17869906732812524, 0.09541852050460875, 0.10778555806609802, 0.1779938192339614, 0.11175945459399372, 0.2290291478857398, 0.10362085537053645, 0.24582733400166035, 0.1776071306085214, 0.11324211722239852, 0.11260272731306031, 0.16651352198095992, 0.1343642783467658, 0.06850498029962182, 0.14543692872393876, 0.2712490386329591, 0.1515812732395716, 0.16050460457336158, 0.18115916813258082, 0.1719818144920282, 0.16341876616934314, 0.2984680171357468, 0.19603958528023213, 0.1108693152491469, 0.11356014234479517, 0.20651378261391073, 0.1380351188709028], [0.030452391620201524, 0.012342680274741724, 0.058227496629115194, 0.0763730815378949, 0.042343406385043636, 0.0178447033977136, 0.013256109141366323, 0.006426323989217053, 0.027712464034266304, 0.01714090434688842, 0.02880570693378104, 0.04305736358219292, 0.04969115449057426, 0.008415752417931799, 0.06391322356648743, 0.11109813422081061, 0.06073355492844712, 0.02993604608491296, 0.027540684677660465, 0.06139406264992431, 0.043047856670455076, 0.009753223130246624, 0.030864096188452095, 0.015043407620396465, 0.02439111198327737, 0.01165939140264527, 0.026187185430899262, 0.05072066545835696, 0.09820236096857116, 0.06948187670786865, 0.04639155478798784, 0.025126407781499438, 0.062295868556248024, 0.056820455138222314, 0.04767565209476743, 0.03121955152892042, 0.0485220047266921, 0.04533526713203173, 0.011682533422572305, 0.0610813847015379, 0.04245987904141657, 0.07018697637249716, 0.08784013145486824, 0.03023757326445775, 0.023726639337837696, 0.03736724684131332, 0.047647027458879165, 0.06865764007670805, 0.027813551969302353, 0.023259023218997754, 0.04705502367869485, 0.07956332949106582, 0.04314970530685969, 0.011564893738977844, 0.025559727400832344, 0.05876734598132316, 0.016327523480867967, 0.011759329936467111, 0.0635075730679091, 0.034613945754244924, 0.058737021827255376, 0.011208312189410208, 0.022819575315224938, 0.017805651586968452, 0.010966751469823066, 0.048194569171755575, 0.03391691323486157, 0.04369649002910592, 0.035759524907916784, 0.07796681398758665, 0.02420844346488593, 0.07383615360595286, 0.036440475087147206, 0.029872640698158648, 0.04199077120574657, 0.12466240441426635, 0.009718973942653975, 0.026993016799679026, 0.03618525792262517, 0.023468789404432755, 0.04453606314200442, 0.029079915657348465, 0.06589619762962684, 0.02536565763875842, 0.02466603687935276, 0.003542334407029557, 0.06046701630111784, 0.08446270643617027, 0.0617462933587376, 0.026504833913350012, 0.05364276061300188, 0.026974607826559804, 0.029974160934216343, 0.016935908315645065, 0.01716322443826357, 0.04465250240173191, 0.012034147221129388, 0.04258579923771322, 0.035234006427344866, 0.04369469032099005, 0.036598585938918404, 0.0624627701472491, 0.06441733479732648, 0.0417292309430195, 0.04920696992485318, 0.020866513514192775, 0.029882173585065175, 0.07647327889571898, 0.0322796092950739, 0.05615091919025872, 0.024873385518731084, 0.02166962676710682, 0.054258676391327754, 0.0627145882754121, 0.013853815398761071, 0.010355452777730534, 0.02544200608099345, 0.01589461389812641, 0.030514166137436405, 0.03784937936870847, 0.019804630064754747, 0.0026762837842397857, 0.018496539123589173, 0.0754755875095725, 0.02855649003322469, 0.031276626395992935, 0.015644929444533773, 0.04967539869539905, 0.04921160463709384, 0.04687700842623599, 0.03162103115755599, 0.05123267685121391, 0.08626573195215315, 0.006684202680844464, 0.03835956878901925, 0.032205394527409226, 0.06158107644296251, 0.034470028476789594, 0.031726097004138865, 0.0408486244850792, 0.013117390608385904, 0.031950299817253835, 0.06762736840755679, 0.08025927847484127, 0.011684040910040494, 0.01860686308646109, 0.03469552633760031, 0.019395422823436093, 0.08335546663147397, 0.021584515416179784, 0.04603133485943545, 0.02236623997305287, 0.002352786482333613, 0.014666459683212452, 0.036371666865306906, 0.016403365407313686, 0.04601150838425383, 0.05688636527338531, 0.030552911812264938, 0.061065543559379876, 0.009868220768112224, 0.018955203086079564, 0.05907610910071526, 0.014700145766255446, 0.02270378543471452, 0.07070014180499129, 0.05921651973039843, 0.025854181913018692, 0.029646576949744485, 0.011460950390755897, 0.008423324179602787, 0.017688622319838032, 0.0746926513966173, 0.05614664070890285, 0.022407054384530056, 0.046216114787966944, 0.10661102773156017, 0.044628905816352926, 0.004211404657326057, 0.02680104360479163, 0.04430609384144191, 0.03961804715800099, 0.0310566426924197, 0.03647628371254541, 0.007535023505624849, 0.07409942307276651, 0.03930717633920722, 0.019447274826234207, 0.010769265045382781, 0.01617365029233042, 0.037122694338904694, 0.03791576447838452, 0.07118056368199177, 0.024483845190843567, 0.09011666945298202, 0.03129517637717072, 0.01996267968934262, 0.023410354551742785, 0.04482799064135179, 0.027087521884823218, 0.041348835729877464, 0.04372033894469496, 0.06761003925930709, 0.03116670690360479, 0.06059234277927317, 0.09350959051516838, 0.015333975134126376, 0.021846348827239126, 0.1064960022631567, 0.025299105545855127, 0.07633978879312053, 0.06884716975037009, 0.029727845831075683, 0.06604917653021403, 0.030472086364170536, 0.02767064215731807, 0.04348697802925017, 0.03921915762475692, 0.039366663186228834, 0.022903296994627453, 0.011984393640886992, 0.022266853411565535, 0.016250540502369404, 0.030421913470490836, 0.050487504922784865, 0.021165871767152566, 0.0008300779711589712, 0.017910426140588243, 0.02782657295028912, 0.06436729177949019, 0.023733485650154762, 0.014698995437356643, 0.025436608812015038, 0.027733429706131574, 0.03893351611623075, 0.03478777900454588, 0.01858364685176639, 0.010988097492372617, 0.026446117044542916, 0.014661956702184398, 0.020504657150013372, 0.0528892098373035, 0.011173642760695657, 0.0645009228901472, 0.03893510060152039, 0.026866757070820313, 0.060865382620249875, 0.042831286846194416, 0.04872016557783354, 0.03468906223133672, 0.037398402200778946, 0.07137857610359788, 0.040528755125706084, 0.059254784864606336, 0.016421705731772818, 0.024239960621343926, 0.01872574215667555, 0.041151498662657104, 0.047581169274053536, 0.040384711683145724, 0.07506126130465418, 0.01762656949722441, 0.014612574195780326, 0.045566542612505145, 0.024175130311050452, 0.05514297132322099, 0.02681815196410753, 0.04536136104434263, 0.009593144659447717, 0.0521410173678305, 0.04608786053722724, 0.07562662940472364, 0.036694133741548285, 0.028741368296323344, 0.004968177745467983, 0.05553628732741345, 0.05693428574886639, 0.03784269261814188, 0.03630174913269002, 0.02305358004377922, 0.011189458855369594, 0.06646817084401846, 0.012961244592588628, 0.02487049114279216, 0.02613462467706995, 0.006427689077099785, 0.05418416847533081, 0.041689700447022915, 0.013903518884035293, 0.042880160981439985, 0.0058829039789998205, 0.03271189176302869, 0.017671571476967074, 0.007389186384898494, 0.012686002428381471, 0.07833333846065216, 0.04447233492101077, 0.05894770642044023, 0.03486868052277714, 0.030101808479230385, 0.0502009765477851, 0.027442120044725016, 0.0363266741624102, 0.0361785674613202, 0.05040173120505642, 0.029847012483514845, 0.003394080436009972, 0.01574955185787985, 0.03560660908988211, 0.03877628470945638, 0.06555268715601414, 0.08279343077447265, 0.008258517300419044, 0.10093151257024147, 0.019043334978050552, 0.0761920420336537, 0.013272008727653883, 0.03460538879153319, 0.09885799649055116, 0.03179349143465515, 0.048734492738731205, 0.04666507702495437, 0.06488921455456875, 0.02667256299901055, 0.005608529199889745, 0.036066399261471815, 0.026814892080437858, 0.07895952556282282, 0.005823158771818271, 0.008588616237830138, 0.03955951026000548, 0.013529969983210322, 0.011127023826702498, 0.014909463880030671, 0.07020386765361764, 0.010178653719776776, 0.0448244468861958, 0.02332051572011551, 0.01619192753423704, 0.05212320582359098, 0.03684121256810613, 0.04804292613698635, 0.0559922591492068, 0.053183148556854576, 0.02948507077235263, 0.04149288288317621, 0.0516898361092899, 0.012167656805104343, 0.03492259384074714, 0.030305448235594667, 0.06067072470614221, 0.08173132839147002, 0.1955942966742441, 0.16271359228994697, 0.12306809308938682, 0.16353814804460853, 0.19594846438849345, 0.11763936447096057, 0.14982100285124034, 0.10874193409108557, 0.06460275297285989, 0.10784831407363527, 0.13871347153326496, 0.16811206354759634, 0.11404247154132463, 0.10210651787929237, 0.17880923172924668, 0.17054653057130054, 0.33789796696510166, 0.1305165543453768, 0.21702400379581377, 0.14889886952005327, 0.13564227148890495, 0.06122237420640886, 0.13660884462296963, 0.12173317722044885, 0.09520861887722276, 0.1528108338243328, 0.18500365637009963, 0.10913284553680569, 0.15278598672011867, 0.281070324126631, 0.1574825940770097, 0.2651062823133543, 0.19240071647800505, 0.15165943623287603, 0.20748734677908942, 0.10978472579154186, 0.11664929494145326, 0.11737645123503171, 0.14057246240554377, 0.130042975069955, 0.1040502917021513, 0.1444411595002748, 0.10636941413395107, 0.08526421108399518, 0.08438364544417709, 0.11831788040581159, 0.1060544021311216, 0.15873582917265594, 0.15517518273554742, 0.10512985681998543, 0.12364942478598095, 0.11685309611493722, 0.07743135443888605, 0.2263421576935798, 0.12835193221690133, 0.13533147488487884, 0.13648744410602376, 0.15093898895429447, 0.11697488254867494, 0.17338200967060402, 0.17134122230345383, 0.13939039927208796, 0.16448165522888303, 0.1333997238543816, 0.1250134254223667, 0.1837327581597492, 0.22062978765461594, 0.11862111452501267, 0.2547010453417897, 0.3106171527178958, 0.18898064765380695, 0.12767205073032528, 0.20560537901474163, 0.11097824026364833, 0.09999727481044829, 0.13414040207862854, 0.07401942697470076, 0.20442131208255887, 0.13751224614679813, 0.15456519671715796, 0.12221137265441939, 0.09600067598512396, 0.11732098311767913, 0.11285473839961924, 0.11644936035736464, 0.09253849770175293, 0.10353238394600339, 0.19307066802866757, 0.17886841058498248, 0.16034149535698816, 0.16141250351211056, 0.1729109833831899, 0.11024804116459563, 0.0771866312425118, 0.21769290149677545, 0.10966380024910904, 0.1570593917858787, 0.08986468805233017, 0.13212572346674278, 0.15184111398411915, 0.23962063423823565, 0.22060675139073282, 0.18503006198443472, 0.15328422014135867, 0.10136753175174817, 0.20072091923793778, 0.18474731856258586, 0.2167838893365115, 0.12326036128797568, 0.13376889779465273, 0.15517939813435078, 0.19008022849448025, 0.1442091492936015, 0.11756101594073698, 0.11817670165328309, 0.11344372906023636, 0.09483527406700887, 0.11082294586231001, 0.07061558892019093, 0.13502388435881585, 0.09463343958486803, 0.135254024353344, 0.14325836906209588, 0.10733665520092472, 0.2552637120243162, 0.11302122438792139, 0.07442732618073933, 0.15642457350622863, 0.15161072165938094, 0.1211053945007734, 0.10870716447243467, 0.16858375776791945, 0.05898387127672322, 0.09451726378756575, 0.14104390429565683, 0.13739314628764987, 0.16300565708661452, 0.1595344246015884, 0.16343662224244326, 0.1315893733408302, 0.07550587455625646, 0.059697472242987715, 0.22583660669624805, 0.20220145932398736, 0.07433082471834496, 0.12033926061121747, 0.1813320440123789, 0.09495224396232516, 0.12993845099117607, 0.1549110672203824, 0.06984463849221356, 0.18641339556779712, 0.07864091414376162, 0.04182304212008603, 0.10446380896610208, 0.0885542927426286, 0.2352430167957209, 0.12687608250416815, 0.21835884544998407, 0.09970365892513655, 0.11696070010657422, 0.08849815669236705, 0.1841185413650237, 0.0766881751769688, 0.1658229238819331, 0.18204224965302274, 0.13171102618798614, 0.1513274884200655, 0.12034052226226777, 0.08596867992309853, 0.08515961279044859, 0.24264528678031638, 0.19838886859361082, 0.15672846813686192, 0.14442676183534786, 0.13855808065272868], [0.02173050514102215, 0.03958998655434698, 0.0022299327474684105, 0.029889897487009875, 0.03740606116480194, 0.049522037588758394, 0.04470486463105772, 0.034578155682538636, 0.0170954941859236, 0.024968380421341863, 0.0348372839653166, 0.014425494537135819, 0.05384109586884733, 0.05400713285780512, 0.052358017637743615, 0.03683526054373942, 0.03317817572678905, 0.061788343446096405, 0.0545377944217762, 0.06853546772617847, 0.07057692302623764, 0.03455631427641492, 0.043146580865141004, 0.026928564984700643, 0.05634353990899399, 0.013421961521089543, 0.05753364792326465, 0.03256121723097749, 0.03262618854932953, 0.003343826369928138, 0.01616664998437045, 0.05418531138275284, 0.029528011436923407, 0.07666381789022125, 0.024462128094455693, 0.059963376334053464, 0.03622825795901008, 0.035898922506021336, 0.03661862763692625, 0.037035458590253256, 0.032627505861455575, 0.018003229852183722, 0.09471642653807066, 0.07414919149596244, 0.09681804032879882, 0.05032945715356618, 0.02195118460804224, 0.032367628009524196, 0.04149777363636531, 0.024570392597524915, 0.0659487268421799, 0.038796823646407574, 0.08813152089715004, 0.013048296659690095, 0.053951735244481824, 0.10198221556493081, 0.052606355093303137, 0.022547630142071284, 0.03791409093537368, 0.02760293602477759, 0.036487764737103134, 0.03748739312868565, 0.018679864442674443, 0.05299519223626703, 0.04460787335119676, 0.07262381826876663, 0.025282195711042732, 0.07811654228135012, 0.029052257668809034, 0.024688787416380364, 0.05093030362331774, 0.05684784038749058, 0.025752878755156416, 0.016799080403870903, 0.012199678621982457, 0.07155373037676327, 0.0028011605672872975, 0.027549317710509058, 0.020038402872160077, 0.048517759641981684, 0.043046524515375495, 0.062461233901558444, 0.049410541032557376, 0.036932830698788166, 0.0373554763791617, 0.04204766053589992, 0.04158438227022998, 0.04154340458626393, 0.037342180803534575, 0.023803930307622068, 0.008572106235078536, 0.019648890374810435, 0.03920892340829596, 0.03166376773151569, 0.059226471930742264, 0.04782855678058695, 0.04949502712406684, 0.03615413595980499, 0.01717321003525285, 0.07553821735200472, 0.009228136023011757, 0.06118465455074329, 0.030341997153300326, 0.017280455940635875, 0.021140807584743015, 0.0506770568608772, 0.09779751941096038, 0.04751669148390647, 0.06342028165818192, 0.06919030172866769, 0.049148882026202045, 0.057782363874139264, 0.03625014018325601, 0.035024939716095105, 0.018436944665154442, 0.02882957811380038, 0.06155822571599856, 0.03812697970715817, 0.03402133712370414, 0.05069891682069283, 0.057930125476559624, 0.07768861993099563, 0.05753988938522525, 0.020017763745272532, 0.05434892897028476, 0.030285469620139338, 0.0514010367623996, 0.017067522639990784, 0.02341382780286949, 0.0368893111590296, 0.012997052290302236, 0.054935633816057816, 0.014728655369253829, 0.042526605539023876, 0.005286518744469504, 0.0392019435093971, 0.028803656750824302, 0.061313075784710236, 0.059600744425551966, 0.07182272922364064, 0.058589249092619866, 0.040188695638789795, 0.03208560447092168, 0.03711899473273661, 0.07174335652962327, 0.015827417992113624, 0.02951397927972721, 0.014667622999695595, 0.062075914538581856, 0.035099232409265824, 0.041897279152181, 0.01507113332991139, 0.06135252464446239, 0.011876235821546288, 0.03521129670843948, 0.02262141260871431, 0.03200747858500108, 0.014532073437294457, 0.0025077348573177005, 0.01703625966911204, 0.06877546344185248, 0.025732081921887584, 0.012938740819663508, 0.03824838393484242, 0.05949255413725041, 0.04731165092380252, 0.020148704570601694, 0.019285336347820703, 0.04789311620697845, 0.038052345626056194, 0.04440188655280508, 0.02474465814884752, 0.02764078184554819, 0.06626482980209403, 0.005713035652661347, 0.07056370537611656, 0.052125658621662296, 0.05878457122889813, 0.00901830489965505, 0.03392380036530085, 0.023790078121237457, 0.09417286273674108, 0.06596823790459894, 0.08441018464509398, 0.02921503662946634, 0.022205091881914996, 0.019755542562052142, 0.08328615745995194, 0.03166685135511216, 0.06474432506365702, 0.04679093042796012, 0.050827957747969776, 0.05782854030258022, 0.043260456004645675, 0.022358924252330326, 0.03267712214437779, 0.1087409544561524, 0.03428345997235738, 0.022697128370054998, 0.030979748771642335, 0.12529692583484575, 0.028194409169373102, 0.02891977874242002, 0.036805941999773495, 0.07205332192825153, 0.028050566106685437, 0.03080025107919937, 0.010000523434428032, 0.03805531421676278, 0.0547999469563365, 0.04748923201987054, 0.07852279391954653, 0.031027847362565808, 0.03936006920412183, 0.02124259128322592, 0.03599681549530942, 0.030223116227716673, 0.03948131015931722, 0.007082437732606195, 0.04881019180174917, 0.012782923204213148, 0.03398718348762486, 0.006460379290729179, 0.09120035349042155, 0.049632320733508095, 0.06108327717811335, 0.014276193905971013, 0.06127531531092245, 0.044128241861471906, 0.03380868954991456, 0.03908564896846656, 0.04820880727493204, 0.032429508282803, 0.011416324123274535, 0.03348595921124797, 0.03585119869967457, 0.044810898980358616, 0.022544052990269847, 0.044407341338228434, 0.023449936998076737, 0.02163742683478631, 0.043300539400661364, 0.022690181867801584, 0.0790480786236003, 0.026076392059621867, 0.0374818938144017, 0.04657650541048497, 0.028096122841816396, 0.05237009609118104, 0.07970907987328246, 0.062018535390961915, 0.03914441964298021, 0.012962351320311427, 0.02719268606597325, 0.006205395438882988, 0.031320580092142336, 0.04497599715250544, 0.038782010378781706, 0.023590779928781558, 0.051909133326262236, 0.08306369869387709, 0.03123626098386012, 0.05486688496603165, 0.02634207165101543, 0.029202008227002807, 0.022777291451347992, 0.021370275935623795, 0.02625101198646007, 0.055719575539114885, 0.04617246908310335, 0.08300047513330355, 0.05531146111025009, 0.06599259519134648, 0.03540160192642361, 0.04921114450553432, 0.06376704273861833, 0.03967564152844716, 0.019515886378940195, 0.0064016698433988495, 0.043144068695255555, 0.01632536754186731, 0.04007373696367722, 0.040382956503890455, 0.10663493230822496, 0.046474330229102634, 0.10607245116261765, 0.025058638566406444, 0.026571395283099264, 0.04383142731967382, 0.021996609611960594, 0.023559990077046677, 0.012704038472293178, 0.01973652688320726, 0.0677992646524217, 0.041388496101717465, 0.036434678913792595, 0.024965033335320186, 0.011029594679712318, 0.08564678821130656, 0.04010749726148788, 0.05603938552667387, 0.015652389884053264, 0.1004158535215538, 0.07172205689130351, 0.06477806309703737, 0.09441908507142216, 0.025400963459105697, 0.09960556926671416, 0.030013561554369517, 0.02745497775322292, 0.0649880686250981, 0.03144097499898635, 0.08594797400292009, 0.03384078743692953, 0.029513294648495503, 0.022789644499425776, 0.03308807157736737, 0.03993735619587824, 0.039623045522603206, 0.0070905058055359405, 0.08237182410084642, 0.034792153965099715, 0.0496700552321272, 0.0030688979950355133, 0.03530923051584978, 0.02422039946395671, 0.03165765985613689, 0.04925813729641959, 0.025456858311372343, 0.055063609761418775, 0.05735214086598717, 0.036169899176456966, 0.01732851185806794, 0.06951634204597212, 0.07619132215040736, 0.020143919573456515, 0.07689208025112748, 0.01287457751459442, 0.044126256616436876, 0.09729326717206277, 0.007781228678140906, 0.03191463591065258, 0.01603600972885033, 0.04159448290010914, 0.015329104789998382, 0.01022416035993956, 0.05407250493590254, 0.03838940683635883, 0.0330864499846939, 0.03700489323819056, 0.06423869243008085, 0.08146110500092618, 0.15397985000163317, 0.17796071944758296, 0.11189829558134079, 0.11645775404758751, 0.07896937386249192, 0.19235010200645775, 0.11713933505234309, 0.22341177274938673, 0.07890763459727168, 0.16106124501675367, 0.13200565881561488, 0.25259720510803163, 0.09427823286387138, 0.17000405030557886, 0.19317661703098565, 0.11811728531029075, 0.1364868800737895, 0.10850973092601635, 0.153981126495637, 0.09145847987383604, 0.18816373602021486, 0.12980784784303978, 0.08815026754746214, 0.11337928095599636, 0.27670703013427556, 0.07351404667133465, 0.16919853806030005, 0.11898506374564022, 0.14970228890888393, 0.061812210915377364, 0.1318882658961229, 0.07700661590206437, 0.11234155812417157, 0.1623490938800387, 0.15090580011019483, 0.15852572716539726, 0.19062082370510325, 0.11678553841193207, 0.10946068927296437, 0.17696272378088906, 0.08067780523560941, 0.14385299262357876, 0.18306160432985052, 0.2045343560166657, 0.19090754503849894, 0.1906010677339509, 0.1748715594294481, 0.20164202840533108, 0.1441040908684954, 0.20832350972341374, 0.1245453825686127, 0.10981107945553958, 0.13589757028967142, 0.20202867250191048, 0.07528410598752089, 0.21768208098364994, 0.0976840227667708, 0.11809829375124536, 0.13747205142863095, 0.10344406095100567, 0.2546925551723689, 0.11852419745991938, 0.14959507825551555, 0.1346848564571701, 0.10518727678572759, 0.12272214094991796, 0.17807739990530536, 0.1791909331222996, 0.13225583679741248, 0.12208996471599676, 0.12475370342144743, 0.1201956624572631, 0.10622235015034676, 0.16405944741563872, 0.1370824981131591, 0.1501535443821922, 0.07667864600080065, 0.1324088973342441, 0.11502293025841936, 0.07706250704359263, 0.16748368710977957, 0.09870250170934014, 0.16839275864185765, 0.10658276674803346, 0.19817020220216364, 0.13182266004150733, 0.24952830572146922, 0.08773677996941842, 0.20188741211313754, 0.182218138652388, 0.1098996918881312, 0.12117232879973017, 0.1473957978305407, 0.19274161459179595, 0.20836979005252942, 0.23815544176613912, 0.16933829931076616, 0.14565470453817397, 0.17503140319604427, 0.1791228336514905, 0.11863485909998417, 0.09255203447537497, 0.08165289080352522, 0.09630809581722133, 0.1522803318221122, 0.1596519659506157, 0.2351389973773621, 0.1812961240648292, 0.12667583621805534, 0.29235076101031154, 0.14542484655976295, 0.08094981720205396, 0.15207748801913112, 0.15902360435575247, 0.1329318294301629, 0.10997078221407719, 0.21633702737744898, 0.10655740756192245, 0.15235273574944586, 0.10307255666702986, 0.11982376483501866, 0.1447934124735184, 0.2637420961400494, 0.1429195934906602, 0.14709904266055673, 0.11335022587445565, 0.22687331278575584, 0.14092456694925204, 0.09966891899239272, 0.20477688987739384, 0.12593977415235713, 0.23001184046734124, 0.13312603463418782, 0.08313973172334954, 0.1522013227804564, 0.08406691165873781, 0.1657500004512258, 0.1558402954833582, 0.17720126488711685, 0.14169412956107408, 0.17748433485394344, 0.10244599849102087, 0.1836352696409449, 0.14350502926390618, 0.25388144713360816, 0.13412147731287405, 0.2414586371742189, 0.13994168140925467, 0.17386223858920857, 0.09425190146430396, 0.07748567964881659, 0.15789637109264731, 0.13483812479535118, 0.09393142725457437, 0.09864303341601044, 0.0983244962117169, 0.10347103059757501, 0.13025288411881775, 0.10732619834016077, 0.07746388277155347, 0.291568121756427, 0.08818813934340142, 0.10647200120729394, 0.20276476425351575, 0.19446722668362781, 0.15503554022870958, 0.0799702713266015, 0.10834563465323299, 0.15781320602400228, 0.10360103260609321, 0.2012147443019785, 0.0856006340472959, 0.09758647487615235, 0.09812275078729726, 0.12001504597719759, 0.22109750396339223], [0.018017544025497045, 0.0434720089106122, 0.03169214374793228, 0.04851595251238905, 0.05444965325295925, 0.06236086584976874, 0.02805911935865879, 0.011762483136408264, 0.09038079238962382, 0.03429451797273941, 0.05014763097278774, 0.0323929018486524, 0.005519811938938801, 0.01474437312936061, 0.04131661909923423, 0.042399304948048666, 0.01253461821761448, 0.017623077692405786, 0.022691423109790776, 0.03555745293851942, 0.0196443614186137, 0.03261959456722252, 0.05861169163836166, 0.038215978056541644, 0.027181848854525015, 0.015186582750175148, 0.03872863140713889, 0.023295770661206916, 0.033891079074237496, 0.02198250323999673, 0.021631500785588287, 0.04725253143988084, 0.03176771293510683, 0.0166414797786274, 0.0545984798372956, 0.03581326382118277, 0.01752216416207375, 0.08425973646808416, 0.021277691157592926, 0.05485309215146117, 0.023480300114897545, 0.021998010415700264, 0.04243918425345328, 0.031219492157106288, 0.04022496439574752, 0.007322698302232311, 0.07534852440585382, 0.014275564008130459, 0.02619001672428567, 0.03040659739781404, 0.029029688957962207, 0.024752480385359377, 0.006606382466998184, 0.087426629033871, 0.049508782831253484, 0.05327615450369194, 0.04280130779079627, 0.007879884688009042, 0.0338368763186736, 0.040923176929936744, 0.038829864060971886, 0.03296462644357234, 0.004242989998601843, 0.07482459783204831, 0.06457613213569857, 0.06677450714050792, 0.03919236238289159, 0.021200311130087357, 0.04567077354295179, 0.04074591866810806, 0.05648644786560908, 0.06458859279518947, 0.06770595442503691, 0.018332849176658783, 0.06984233783441596, 0.02278207459312398, 0.043215400219196454, 0.033540276999701746, 0.07192882665549405, 0.03906823447323404, 0.018342183539061807, 0.04000800494395662, 0.03674457380839158, 0.032614021038170904, 0.019175999441358726, 0.025664993627287913, 0.047873237781459466, 0.07168789583374746, 0.06626327129197307, 0.021288671232468914, 0.03080834048887482, 0.008716893680684734, 0.019047264649998397, 0.03716444756719284, 0.00988917623544694, 0.0427941089583328, 0.10838783317012712, 0.049708702572388574, 0.06677337907603942, 0.04371272079879418, 0.040849722863640636, 0.019595170015236363, 0.018405538830847945, 0.05472868593642488, 0.11205767179490067, 0.014540712036250625, 0.06058736296836287, 0.0362194672197802, 0.04938331163430121, 0.032539591047680005, 0.061565380019601434, 0.03809509704296943, 0.13728223973885179, 0.008837114182824735, 0.037918239540886134, 0.013940456501586596, 0.05500631596078165, 0.01855141166743124, 0.01911546802148223, 0.018177732890762854, 0.025133406234090216, 0.05113369661557954, 0.08774646499659866, 0.08071702774032019, 0.042292213038308546, 0.0017613991485632141, 0.03025908998097293, 0.008328641906700796, 0.036612482654163614, 0.026864063074754085, 0.03949586367525626, 0.016812990106700454, 0.011140272090415237, 0.027002690694644116, 0.001956631763277983, 0.017344189727737103, 0.09903535494231619, 0.020890627747576218, 0.0841317605227232, 0.02284505324496422, 0.06637923186644912, 0.03608789927966427, 0.06161884433822706, 0.016879330687515903, 0.03786569919611793, 0.045379795992630534, 0.046717973600607365, 0.03347307923831977, 0.06566113719600253, 0.0189783228415763, 0.018206036547780968, 0.017412866218364798, 0.0366271808888996, 0.053514131577685475, 0.03316482820082456, 0.03838024873402901, 0.017241187051695306, 0.02896377696743002, 0.02663211966137169, 0.14379500120412558, 0.00958108847044059, 0.05535963391594123, 0.05000315337383654, 0.07489689785870723, 0.04061970903421752, 0.04208054509945214, 0.04594212870870251, 0.05346086763893254, 0.04652606163290329, 0.07339839037740603, 0.021711062727263197, 0.03053753636777401, 0.05068442267656792, 0.038541866233572364, 0.03353939755470492, 0.010367915292590624, 0.039809821828384884, 0.028220187668921426, 0.053744208489661105, 0.0254836034582695, 0.02822968344844412, 0.03681837668409571, 0.021751303829660174, 0.021615021396428347, 0.03219611397071276, 0.0631408036861103, 0.038196882596821524, 0.02895581001212122, 0.06339887069771066, 0.047579195161233656, 0.031096538696147036, 0.012910122677567415, 0.017229069635504857, 0.02139218784577679, 0.06487562583060935, 0.035695087935891934, 0.04339317798439879, 0.011164539391756989, 0.08040488784899935, 0.03598472962039523, 0.0818334256473463, 0.039653729618294165, 0.060255767675698735, 0.037600912037305534, 0.06414276242139749, 0.0190644602116663, 0.03684790674014948, 0.013626130057673436, 0.03208600894140545, 0.05629905928799417, 0.02123532565747155, 0.04052662516187411, 0.016394485610362608, 0.023546304873889312, 0.03475697245448828, 0.021604761204798706, 0.031657106956117786, 0.023038737090246286, 0.04269646458851639, 0.06631291355006397, 0.06962874031160027, 0.017414914545952342, 0.030715603570570238, 0.02032062864600448, 0.02023843950155424, 0.045758165142615326, 0.034940661425935104, 0.030455631094810087, 0.009066185484698508, 0.09622671932447702, 0.05175816193514038, 0.09180778652080335, 0.016187931068998296, 0.05621928212349303, 0.03317493996291887, 0.09114202810451388, 0.03274973758379929, 0.022439771964855026, 0.02408381460554665, 0.06490794636192732, 0.04709832057415042, 0.07741120512946509, 0.010552651619946118, 0.08099609753116965, 0.025932081443897914, 0.047179723042063415, 0.02012785949773388, 0.015437029760505538, 0.03510526235913858, 0.03637972658907529, 0.013874733758711955, 0.061032918747514486, 0.061022955414955504, 0.03234791285649408, 0.038663637824356556, 0.058431030629435554, 0.032786559240776114, 0.05966771212115418, 0.015237289062497439, 0.009990343951358227, 0.04209610051475465, 0.019086002903350163, 0.011254814235144295, 0.03943156400055159, 0.13207874551881105, 0.016715907913749106, 0.02706327777559636, 0.03859301876218524, 0.051976460963487625, 0.019765142242249567, 0.053010632618679665, 0.046494631678797305, 0.06563556278706528, 0.026442994458193425, 0.049726985380402766, 0.03676594024000224, 0.07558431956567802, 0.029677940110559575, 0.05108413228299469, 0.11677222428261302, 0.05515724282304291, 0.008599348620919045, 0.023536794251413085, 0.053672231297241524, 0.0754557573236525, 0.006942973805053043, 0.05337978800525889, 0.029550511499110144, 0.10063647176139057, 0.03895385096257087, 0.03727075280039571, 0.05984366791381035, 0.06586224437342025, 0.007208153838291764, 0.027002230563084595, 0.0724215607624501, 0.04707206710008904, 0.026799943370861, 0.031235541100613773, 0.026704558840719983, 0.05859254793904256, 0.045391870735329576, 0.023775489353283774, 0.024423235845461022, 0.03245290819904767, 0.022517439574585296, 0.017314674514636863, 0.019371191701793578, 0.09055798756889999, 0.015010499864729354, 0.06642879990977235, 0.0192054404396913, 0.07383043906884268, 0.012302092218305916, 0.019692695641424507, 0.08510943618603051, 0.0416816704091616, 0.0448834513372276, 0.03140245382383, 0.03798142970481422, 0.030336931995407213, 0.03079176090977853, 0.05009209235140588, 0.032351237678085454, 0.0638112673186697, 0.0021491390725714155, 0.06907068236614577, 0.018213905168522615, 0.06649678805842996, 0.05355709079594817, 0.02770777551631909, 0.07512996191508137, 0.02691230081836693, 0.042931836724164896, 0.005814990972794476, 0.016924156407185365, 0.016369018812838476, 0.07010068686213344, 0.05278408461890649, 0.02096588708809577, 0.030473368424281944, 0.0689406952005811, 0.020837224656133913, 0.03939371075830422, 0.020754684846906457, 0.06997554592089728, 0.04407922300742939, 0.05980182562780101, 0.052043985269847326, 0.01775740456650965, 0.029300626665644813, 0.05716695275623351, 0.1091434879344888, 0.08904235874069855, 0.23359537473879755, 0.1321931995335035, 0.138166582910344, 0.11480395216494799, 0.12512817629612982, 0.08885308139724657, 0.23008178046438843, 0.12920164677780122, 0.10724321138695814, 0.11876964796101674, 0.11168636789079756, 0.10990433031111024, 0.1762171770678833, 0.07232517062220722, 0.11022849299479276, 0.1659040109370835, 0.1471757362014614, 0.16438891645520926, 0.1059825399715919, 0.13442891940940171, 0.19470790517516434, 0.15102059551281855, 0.12860573187936097, 0.11023382903658785, 0.13769341923762113, 0.06384036692907102, 0.11959830779233016, 0.09933170193107799, 0.11356944145518355, 0.09975559441954829, 0.1703483919845894, 0.0971642299555242, 0.13714989996515214, 0.11078774579800665, 0.10577369219390675, 0.16476690710987896, 0.13915549468947574, 0.13637242605909705, 0.15248045936459675, 0.09463566602789797, 0.1497197145363316, 0.12417997873853892, 0.10901094778091647, 0.14884267409797758, 0.18434287776472047, 0.12726573972031474, 0.17198660876601934, 0.05728165910113603, 0.10057946739834733, 0.0918257242301479, 0.10433823757921346, 0.17749108839780092, 0.09428417004528455, 0.17306046676822007, 0.1149829507630784, 0.1373771604266949, 0.10363615103415214, 0.3323418041691184, 0.09123714917222969, 0.145812010159716, 0.1370606492855586, 0.15864006243646145, 0.08200670228688978, 0.15122214797884226, 0.11713137922924943, 0.13167724362574518, 0.11749647135729901, 0.12085132766515017, 0.10858188252313994, 0.1392157273949124, 0.18796197575284168, 0.1534803697722964, 0.1424372717156075, 0.13804675574647263, 0.13986681355163455, 0.08220241405069828, 0.20543725288007408, 0.18920707690995187, 0.14373908779816702, 0.16319785849191248, 0.10298360284650698, 0.1380098264780827, 0.10635421494953334, 0.12157754885265604, 0.14291217201389372, 0.2183551643975079, 0.21847276511834934, 0.09458263957640156, 0.12860668182838708, 0.08054770674789324, 0.13379229028942063, 0.12155291697126813, 0.08511178879416548, 0.12365321716060862, 0.16819282405776903, 0.1142942080332432, 0.1445666715153493, 0.13847233291016892, 0.15183345502009615, 0.11610981295234524, 0.1002259379310999, 0.14132731565041468, 0.16575426037888974, 0.1240937337570358, 0.14930739213014022, 0.09374045781441964, 0.16885317221749574, 0.06475801768829115, 0.13083480211207643, 0.12137991492636502, 0.3751702856970951, 0.14635441621067002, 0.15629506873665377, 0.2176254551159218, 0.13192433427320793, 0.06549035417265259, 0.11320369623717852, 0.14599276764784008, 0.14694896555738524, 0.15936209791107103, 0.19211577629903331, 0.20055721630342305, 0.2048822451615706, 0.09557955912896432, 0.09245492445188574, 0.10475506482180208, 0.17883692868053913, 0.11093444612924941, 0.11334772483678535, 0.08751860339543782, 0.11501332686748356, 0.09391946383402683, 0.14955273130908608, 0.10528564846026711, 0.15065174811752513, 0.2062784624285996, 0.18982972396770492, 0.20471993746468797, 0.13446354801999405, 0.16136377409566194, 0.21939017839031294, 0.11634622409474105, 0.10854744687094353, 0.09891675232211128, 0.12432989256922156, 0.08774140354944393, 0.11647365085082129, 0.1155087401275523, 0.24812465213472024, 0.11218229323276319, 0.14132157142739743, 0.13230845506768674, 0.14721343730343506, 0.1450521993683651, 0.2249667650903575, 0.1114592410158366, 0.14626304298872128, 0.20101831265492365, 0.15659376833355054, 0.13942752149887383, 0.11230882199015468, 0.23512280371505767, 0.0819761332240887, 0.13921835459768772, 0.11453222221462056, 0.15624519641278312, 0.14015853696037084, 0.22360287577612326, 0.1183534218580462, 0.17744949844200164, 0.20503180276136845, 0.13847252586856484, 0.20335794804850593, 0.17043790983734652], [0.05342718897736631, 0.026993933352059685, 0.050824677455239, 0.027322528512740973, 0.09012865513795987, 0.04653043288271874, 0.03634762870206032, 0.059002465786761604, 0.033369735174346715, 0.014085484217503108, 0.055488144207629375, 0.07000649347901344, 0.004973476216036943, 0.033646964438958094, 0.0328303830610821, 0.10112544317962602, 0.02058101486909436, 0.01850596810982097, 0.010957379072351614, 0.02052744479442481, 0.07858390978071839, 0.022902838718437124, 0.07707399548962712, 0.03500484235701151, 0.009569867197569693, 0.031826453923713416, 0.02382825048698578, 0.015586932458973024, 0.03887855265929829, 0.03135089311399497, 0.024419684668828268, 0.04213353444356471, 0.05361424358852673, 0.019472773165034596, 0.0518056742293993, 0.05085476041131187, 0.08588716984377243, 0.01836727184127085, 0.0257844645602745, 0.016896737761271652, 0.016915259911911562, 0.01963636292202864, 0.03583360608899966, 0.04138990989304148, 0.05897191527765244, 0.0276775849488331, 0.014268309514591238, 0.005184777255635709, 0.07528653281042352, 0.03526877975673415, 0.02244215054815868, 0.018061124792438932, 0.02722906614508247, 0.10700328988605179, 0.01174133471067762, 0.07169754375354387, 0.01597845803189557, 0.08293799372040667, 0.07787852067849599, 0.02106071315211011, 0.039269953922485, 0.03688030890771188, 0.018906516343122348, 0.028940865013282746, 0.027501875920279417, 0.04278600470570382, 0.025638714178057853, 0.09402755022165366, 0.03766657355299685, 0.06487677615950815, 0.04092961877177004, 0.0588607118697837, 0.05682234390405938, 0.01875404024758609, 0.0011544356425474689, 0.02929437963757664, 0.07826267858035862, 0.03688345561386086, 0.05297770352626685, 0.0619204939721385, 0.027545317534531932, 0.016470602131448686, 0.037742187269032, 0.05969228091998957, 0.05298517695337068, 0.04238043213263154, 0.01804434483346995, 0.05662293995555956, 0.026748200834845193, 0.014252532382670324, 0.029106584734108765, 0.009468817297602072, 0.06548987177666277, 0.05669665006280411, 0.0595010331744561, 0.03366395591001492, 0.03244250328862108, 0.051750766433542594, 0.02923966480011586, 0.07706761301960796, 0.008740784342080588, 0.04457378279766999, 0.03599987685447559, 0.057682904953253455, 0.04424434344400652, 0.02558112351835007, 0.019220097856305074, 0.08949895767727867, 0.057078614918282256, 0.016999014987959526, 0.06399834790499881, 0.02479933958966285, 0.07450209013768472, 0.0617196242819773, 0.028805577057937626, 0.048925035443971865, 0.033621857583057135, 0.03205986678949557, 0.02521453410736285, 0.024916992260841653, 0.0319032328116009, 0.044071033407817595, 0.028875131138192955, 0.038866251561557874, 0.02516645963623887, 0.027071369040641002, 0.05347642676497344, 0.03254087125242222, 0.03482493091723882, 0.02127392104739556, 0.01048704112690757, 0.02957465356303146, 0.02350979677430587, 0.049997134556178935, 0.05064198667241726, 0.0674347736639902, 0.05854684277437627, 0.02684799001144711, 0.010506541057111463, 0.010167099408135982, 0.03184354558470659, 0.03773081014514901, 0.03136209212243557, 0.032712359316064976, 0.026219082938041538, 0.020696752799267415, 0.060784904126194306, 0.038051232404541224, 0.03820935067778919, 0.023257726315932814, 0.05057565722381696, 0.010661505202733679, 0.031217020805343054, 0.006675328913843259, 0.056661231064936146, 0.06868276177556254, 0.03322733929962851, 0.047657402683398686, 0.017595853860257193, 0.044315248233033344, 0.06804697870393284, 0.06558615059475414, 0.006753811494490947, 0.0524137269530911, 0.03327095902932342, 0.00508676134813868, 0.01152057546278229, 0.016840449570736382, 0.0690547187696211, 0.028310963461990468, 0.03866849518090021, 0.04066989306011237, 0.07280770019860938, 0.05478670704178512, 0.03040996118215844, 0.0499941103043966, 0.08640803134767339, 0.04861935223743785, 0.05205030465731397, 0.01572747110913042, 0.031688136150478385, 0.03156604914693162, 0.019883718887285795, 0.039038789764163084, 0.04923493404930923, 0.030215845035854727, 0.02224664101959206, 0.018228905828436837, 0.0363384483353002, 0.07907607985544018, 0.023102003324311227, 0.056756949561531655, 0.02921815736044664, 0.02796355856844457, 0.03055051653063856, 0.037197116907918826, 0.05217105208430439, 0.052399329288164154, 0.0695939632714726, 0.02484763113898225, 0.01258666132343933, 0.030068486048548948, 0.02784853681077948, 0.02088265522615984, 0.08501934687956236, 0.006745155269527459, 0.033846349833766, 0.007668686157558113, 0.07653719265363179, 0.05363376207242254, 0.025676424556877464, 0.0049652277084533125, 0.022997770538495388, 0.040694684503250755, 0.017108882530010305, 0.05917692615184933, 0.06998180222581141, 0.010029004279203946, 0.07030513370409608, 0.03181857231538743, 0.033209728135261685, 0.018144660934922285, 0.035358713212190196, 0.03706952316861134, 0.10115055003552698, 0.038394635266740806, 0.03693725389894098, 0.07469232485163957, 0.08269655823823996, 0.07116025852155872, 0.11360217758920044, 0.0375371133122826, 0.02180268642405281, 0.04410413319419604, 0.05644666132866405, 0.035078519067610614, 0.01591717518749647, 0.023044750341796316, 0.023613174234924372, 0.03253950198995881, 0.07817158737452701, 0.027013750550395343, 0.03824810562946368, 0.0839892755902838, 0.020716330654977355, 0.03016789301909739, 0.07031286688288674, 0.04374901553092059, 0.032068338405224495, 0.013298618432600051, 0.04734874346468132, 0.0677877984708175, 0.020077258013770916, 0.036954898459953256, 0.13395162939559668, 0.016545304861210752, 0.050805188657250255, 0.01719729829346761, 0.008830228907754645, 0.10360603468143381, 0.030238402614486404, 0.07956678789923899, 0.02180996503739152, 0.04183835262665525, 0.017621342922211625, 0.043247256908216514, 0.07542688777903095, 0.029773807036690414, 0.02672083970537642, 0.05172045712242834, 0.07253283096360974, 0.044278938657953404, 0.08006302494322881, 0.02082249673549086, 0.07464581445674412, 0.08164302766090259, 0.035863577722921036, 0.01772606367012486, 0.010098163165821461, 0.02372274120716611, 0.06206720914633479, 0.05880563709069975, 0.03509117268549744, 0.026188163210463244, 0.04866559916990809, 0.03809521578659769, 0.048550065330346115, 0.04561530542559922, 0.04597733619448263, 0.013368012023420306, 0.01279449978028424, 0.04016882463474758, 0.03354756117914803, 0.038392119386116974, 0.028425246782717295, 0.0629217439563945, 0.022424919734476134, 0.061453631133190356, 0.020424436552275438, 0.06930889692739584, 0.01999649564822903, 0.024346054342458956, 0.0606946515472373, 0.02541740017477423, 0.029074073099764064, 0.019210713398933876, 0.026021124322141986, 0.04930632494506426, 0.030297182565846015, 0.07397718392894603, 0.05384457283071242, 0.018606697958603036, 0.03667002136353403, 0.016065452582552098, 0.023867929412517697, 0.008644287518109195, 0.01345660961305839, 0.03161722022923641, 0.025215062887582462, 0.05344997291103937, 0.0355983564077178, 0.04264761271770112, 0.014659684802609263, 0.05612625762296375, 0.037208868816378526, 0.025686963053885847, 0.04678454053646419, 0.018513719842303544, 0.013436205190373585, 0.057397374766878784, 0.07639447023393586, 0.04870478827797342, 0.016458380814583506, 0.03909938983269967, 0.02818403394485358, 0.010528058701311238, 0.05966000862827059, 0.05098838410049211, 0.026115030123037286, 0.052113973506493494, 0.01575250189489452, 0.018272694396728184, 0.04045251429488417, 0.01461955595004838, 0.012339386994426604, 0.008045301055972232, 0.009524310462438734, 0.033228077736566775, 0.06729398082825355, 0.05550789646804333, 0.051796338011627086, 0.0027522994196260697, 0.15855861915042624, 0.10605466188280843, 0.1508466064115055, 0.20001332595711574, 0.13609217625344172, 0.11033940696506761, 0.14433549251407385, 0.16042892035329714, 0.11696838133502752, 0.18720201653195545, 0.1516846989397891, 0.15368965541711077, 0.1006860175402835, 0.1692707638721913, 0.13017679913900793, 0.16730822855606675, 0.09712334504001774, 0.13715108740143478, 0.13041433092439547, 0.11877075376105495, 0.12722334824502468, 0.09620605793315917, 0.15501286019571126, 0.28445264731999487, 0.1252661712351255, 0.09483717396506108, 0.12105112124118023, 0.082798091461882, 0.11666803417028859, 0.10067996161524206, 0.10926851013209671, 0.10025268493336625, 0.19606556044891477, 0.11016279066097923, 0.072105583967641, 0.1319879511720501, 0.21137326169991866, 0.11775052334996872, 0.1246914075454697, 0.1204829552443698, 0.21230008540442213, 0.1308152687852271, 0.15433631837368011, 0.12494961556512862, 0.16343561292160302, 0.149585370963905, 0.09872058042674325, 0.2264386072056368, 0.3233440947951749, 0.09990926351747476, 0.1020743309345562, 0.12480629200581461, 0.16768877219874412, 0.20713734993478283, 0.21152577304746956, 0.1596832845825702, 0.13875127653591335, 0.2134110062615946, 0.1530474898754619, 0.16405374772148207, 0.22021124605089426, 0.10793910842039622, 0.060127045871922746, 0.08768616549787112, 0.07994149083970115, 0.08327539631864056, 0.1378167196526192, 0.11937673960346729, 0.10343623871449381, 0.13664985570358112, 0.19488299265503883, 0.12659366562729701, 0.13902389706345275, 0.12935200589708984, 0.1086378627223894, 0.12603159266291186, 0.16318441077601165, 0.18129141884855926, 0.20576494076522067, 0.16334668878698722, 0.0868862342031207, 0.0967527981265448, 0.12016090768156573, 0.16705054003978148, 0.18934728344902396, 0.1442619159934111, 0.142274578101933, 0.13486083451425657, 0.180489988415502, 0.13403900986304507, 0.18110745528247207, 0.08844567943015136, 0.21810792532050982, 0.16487247019540519, 0.19825439143460244, 0.17972189525607973, 0.20677535998402163, 0.18736318132141605, 0.15845399117097259, 0.15779790293890983, 0.08755211136303842, 0.13037070748396218, 0.09586673317244276, 0.12412082956871018, 0.154149237787351, 0.18266200233483687, 0.16244536527665332, 0.18248937878524885, 0.14487349020782858, 0.14129287999821827, 0.1505076527246274, 0.12933836522279307, 0.18692749610636383, 0.1430180319584906, 0.11425077755120583, 0.18076235661283135, 0.13598919584183022, 0.12784704915247858, 0.15772092738188803, 0.1461907132761553, 0.08637510225526057, 0.10940241583739407, 0.1101127105357591, 0.13728333811741322, 0.09920843862346373, 0.1209753702278249, 0.23740208765957505, 0.1854087205720134, 0.1630936609581113, 0.16401154920458794, 0.1277917146217078, 0.1894490615813993, 0.14405881986021996, 0.16053000086685643, 0.1452927739592269, 0.11035937815904617, 0.14670405682409182, 0.17021143605234101, 0.08145392843289301, 0.04603579516697209, 0.10281855662469752, 0.12329186545684934, 0.09581749167409725, 0.14320117916213349, 0.11323229118715972, 0.1281374812242575, 0.13816634542308748, 0.16696862177923322, 0.12671929638599977, 0.09959085989976302, 0.16126431146403775, 0.15624286606907845, 0.08574998384574428, 0.125263009686023, 0.15920023550279438, 0.16644831688608974, 0.14544058009050786, 0.17992800450883806, 0.18167214060667902, 0.16395864891819656, 0.2753081708215177, 0.13179221714381129, 0.1566646879655309, 0.12419983861036599, 0.17339229583740234, 0.09914085865602829, 0.1494259576429613, 0.14028870966285467, 0.1260507697588764, 0.10763210419099778, 0.1768397944397293, 0.1403808398754336, 0.15738699061330408, 0.11130581682664342, 0.13317838573129848, 0.12783379439497367], [0.055515240019303747, 0.12788074265699834, 0.03953087449190207, 0.0253977981992648, 0.030641372104582842, 0.02470570838340791, 0.06194884030264802, 0.02113107060722541, 0.004719857452073484, 0.0803036663273815, 0.04375750198960304, 0.09562534221913666, 0.04747837068862282, 0.03131733319605701, 0.06266916883760132, 0.010776948129205266, 0.02152634217054583, 0.020898359070997685, 0.044473923117038794, 0.06515163797303103, 0.042767491831909865, 0.03447405091719702, 0.046873089886503294, 0.01982173100259388, 0.04069654729391914, 0.025581281224731356, 0.022658256530121434, 0.02545309191191336, 0.006316353010333842, 0.04620105661160778, 0.07279310215380974, 0.03103756764176069, 0.00864965324581135, 0.02267424795718398, 0.01687271815171698, 0.033782172613427974, 0.08568335382733494, 0.020193370728520676, 0.04925509820168372, 0.025123734194494318, 0.04999570963263977, 0.029019252506259363, 0.06013869016896933, 0.049100512551376596, 0.018064803989545908, 0.026849465029954445, 0.026824634624063037, 0.08684239553986117, 0.013854256976628676, 0.07753403799142689, 0.02414072248939192, 0.039460121843148954, 0.02630435199534986, 0.012520463606051635, 0.02808024644764373, 0.06512604872114025, 0.04181617725407705, 0.02153625540813664, 0.04461604439711664, 0.02896368419897044, 0.01625159064133186, 0.03078310746786883, 0.02097389671689598, 0.037476056822924875, 0.03155670179694425, 0.006099971969888429, 0.07612636938574724, 0.039829228990129195, 0.028314527626207564, 0.06454073169152252, 0.029328000782697927, 0.08326861308887601, 0.044121343598817475, 0.06621020773309283, 0.05225708184298128, 0.03819794386799913, 0.0755860932986252, 0.05294333466736134, 0.01780788545147516, 0.031901893235044554, 0.052473280593403615, 0.14239277254091576, 0.2469616028247401, 0.17970825458178297, 0.07527564550400712, 0.06948344263946638, 0.03574412905436475, 0.0184075185097754, 0.14114685502136126, 0.06623302135267295, 0.03601261953008361, 0.0630060445109848, 0.05743238558352459, 0.06041785643901676, 0.016604719348833896, 0.014212011119525414, 0.0479134213674115, 0.02870299926144071, 0.06633925237110816, 0.055224292154889554, 0.02880110747355502, 0.034944242288474925, 0.012593613391800318, 0.07584493956528604, 0.058546523650875315, 0.010547766432864591, 0.013920077126385877, 0.04718274729384575, 0.030470535275526345, 0.0465245996019803, 0.014966604612709489, 0.07583480182802305, 0.04133518392336555, 0.014823526889813365, 0.02317465030500898, 0.06657661346253008, 0.06546360717038624, 0.024897288240026683, 0.018759482045425102, 0.10303930102963932, 0.018997167826455552, 0.0128799822050496, 0.02586464619525941, 0.03854820417473093, 0.02166868609492667, 0.042741431316244416, 0.08958005215390585, 0.04102435763343237, 0.002428478587717109, 0.025299973858636804, 0.03554057650035247, 0.018135196696675848, 0.05080338894913439, 0.042874398204730824, 0.013860067065252224, 0.06318615633063018, 0.09131531958701089, 0.0384531090821838, 0.008069191717368085, 0.024969668047560845, 0.0755179715633858, 0.10315912077203393, 0.03126775030978024, 0.01866740934929112, 0.05016334223910235, 0.03171299438690767, 0.05478125596710015, 0.03661283517431002, 0.008390630719077308, 0.06147022926597856, 0.027961235646216664, 0.031588903584633954, 0.03764784174563829, 0.010817144702741643, 0.0910482280596625, 0.022761504114896525, 0.023655944205529522, 0.014513909372908529, 0.013854745866410667, 0.011349789656378562, 0.0434623387263855, 0.03505810258502606, 0.021407583699328825, 0.021598172788799275, 0.03452881399425678, 0.02622652296849992, 0.06164943195472006, 0.011921152454306139, 0.03739190098713152, 0.028490281183621846, 0.0323483507236233, 0.022740466083632782, 0.08927537084673531, 0.04292601086490322, 0.020488237132667564, 0.03322176205983851, 0.061901550652692094, 0.03618269009166397, 0.0155300366350275, 0.052331244660308585, 0.08345412032213062, 0.04382398728921544, 0.026747351075755432, 0.013450518436002312, 0.07033820380456746, 0.04274665974662639, 0.027322046116751153, 0.045763720117975026, 0.01862133311078651, 0.03387964257854037, 0.01780073856934905, 0.025924611727532465, 0.049315371725242585, 0.03902135671523865, 0.031068708158272784, 0.018938447246910073, 0.04275438921467867, 0.013690215437236475, 0.014070656106923707, 0.05790194612927735, 0.06285233088419773, 0.044892101068398915, 0.0277779975294834, 0.042638962986529805, 0.01924029169458663, 0.055086538413888775, 0.04340328603575472, 0.04669222478696611, 0.018420947671984322, 0.002981928723784222, 0.016919143199629616, 0.014973699544498231, 0.03950570826418698, 0.02405506937066093, 0.004395737905724673, 0.0118451379785256, 0.008940698517108103, 0.037250399400363676, 0.05173718513105996, 0.060013148467987776, 0.06305110029643402, 0.069954802893335, 0.03763735148822889, 0.053416850860230625, 0.028425990785763133, 0.06793202002882026, 0.0321810557943536, 0.03256441588746384, 0.01683607461018255, 0.008557607452530647, 0.05666530174494255, 0.0420069871324813, 0.04919456863717642, 0.012010815953544807, 0.027859149522555526, 0.05006939005397726, 0.03262804762925953, 0.04066291687195189, 0.012688025708484929, 0.029067364084767178, 0.01190618426335277, 0.017751925661286805, 0.040968370012706146, 0.008935093446780229, 0.042362579770269804, 0.06593020283617079, 0.059754977555712685, 0.04064450789883267, 0.020526880762190558, 0.06414530798792839, 0.02208543912274763, 0.051895006545237266, 0.022328498052957002, 0.065532003500266, 0.052626285469159484, 0.0033891256725837593, 0.046780562624917366, 0.13221530069131404, 0.06314740880043246, 0.16047110402723774, 0.09957871094229631, 0.03258629440097138, 0.016383670663344674, 0.013169208286853973, 0.02410051107290201, 0.021200962364673615, 0.019249095421400853, 0.026639079151209444, 0.049715678760549054, 0.04192267915641423, 0.050697499318630435, 0.010111573774338467, 0.05670205660862848, 0.05270662666589487, 0.03133558260742575, 0.06212277745362371, 0.0355879997368902, 0.0318921451253118, 0.02861141267203493, 0.04925127243041061, 0.03618758084485307, 0.09846751549048349, 0.06151555593532976, 0.020706389586848672, 0.021280791479512118, 0.016783556529844645, 0.02189529903262155, 0.017064988205675036, 0.026932672772090882, 0.09886211541015655, 0.06383198808180168, 0.011603945549722994, 0.04464322926651221, 0.10867810196941718, 0.044270793587202206, 0.09064874480827712, 0.06503525437437929, 0.0064829048642423, 0.021411684065242298, 0.06046981790859718, 0.0172221324100974, 0.09373363747727126, 0.05001419653126504, 0.096956369234249, 0.04010807613667566, 0.05787230846181046, 0.0041460455668129725, 0.030388160594156943, 0.08704890555236489, 0.04972685179382097, 0.044059741630917415, 0.030586449465772603, 0.022460644868260715, 0.030015340853424277, 0.0211221314384602, 0.03738065002835356, 0.0254048578790389, 0.057848029100568965, 0.02572442481323378, 0.03971920188632794, 0.01495660510045127, 0.09409773512743413, 0.03199581944500096, 0.025971214890887495, 0.04837649183173198, 0.00901312378118746, 0.04209834922221489, 0.02127246458258014, 0.061854465093347244, 0.010550678434810834, 0.05678231245838106, 0.00741538698093791, 0.02640734353917651, 0.03004506572324317, 0.025391515919181984, 0.014768439123145072, 0.03511617564072367, 0.070209893892752, 0.026103619602508843, 0.04823242612474132, 0.014125108409643872, 0.0421031286532525, 0.12496705603552982, 0.038331964606186375, 0.10632072182488628, 0.03560888748324942, 0.023206800142361317, 0.01649789646762656, 0.079671690473333, 0.04334421479143202, 0.05865664723387454, 0.10313239603419788, 0.2789346606004983, 0.1917554932879284, 0.1192572241416201, 0.11972096253884956, 0.15777762746438384, 0.15978052077116445, 0.15717258414952084, 0.1857551105786115, 0.13112361630192026, 0.2271715522510931, 0.12888227094663307, 0.2360030057025142, 0.06569755438249558, 0.08135801326716319, 0.12861923896707594, 0.08414286305196583, 0.11548502108780667, 0.08466074854368344, 0.17547599418321624, 0.10656796832336113, 0.1429040529183112, 0.07613347173901275, 0.20368263765703887, 0.10211385029833764, 0.20010705920867622, 0.13024771877098829, 0.0846409257792402, 0.12090042815543711, 0.07624437086633407, 0.1888170634629205, 0.18142818182241172, 0.11672258202452213, 0.1350245374487713, 0.10678206308512017, 0.10472250680322759, 0.16790895257145166, 0.16782124555902556, 0.07614581365487538, 0.06580535133252852, 0.12902638118248433, 0.13358952070120722, 0.12470813555410132, 0.1546357898041606, 0.315842495765537, 0.12884639552794397, 0.20958201406756416, 0.14350599405588582, 0.11760812005377375, 0.21388307155575603, 0.2202850006869994, 0.18078984576277435, 0.11240660736802965, 0.1397407375043258, 0.17150479165138677, 0.17939710174687207, 0.1331299086450599, 0.15365376515546814, 0.08754400711040944, 0.16253133566351607, 0.15330339723732322, 0.09487319039180875, 0.10094507902977057, 0.11314085859339684, 0.1035691202559974, 0.0859040611248929, 0.09929855761583894, 0.2926703594857827, 0.07196373728220351, 0.12089265044778585, 0.18885656056227162, 0.22305194986984134, 0.21035497571574524, 0.1103100179170724, 0.2262233546935022, 0.19313100463477895, 0.1376373870880343, 0.177451012423262, 0.19245584320742637, 0.17483655974501744, 0.08147342465235852, 0.18765600310871378, 0.36401755758561194, 0.3165754704969004, 0.5053057323675603, 0.21448790706926957, 0.12580456968862563, 0.08191365923266858, 0.13246574584627524, 0.22753973171347752, 0.16437980288174003, 0.08286026117275469, 0.17770288250176236, 0.16609242738923058, 0.17900756327435374, 0.11785483220592141, 0.11323339698719792, 0.29745094827376306, 0.15904420637525618, 0.16444591339677572, 0.1277706227847375, 0.12514116388047114, 0.1388984444201924, 0.12981004460016266, 0.21343586820876226, 0.13628494169097394, 0.15746778080938384, 0.1616788751562126, 0.13831259304424748, 0.11756268577300943, 0.1159599659149535, 0.13439359317999333, 0.13187282922444865, 0.10820303097716533, 0.17670166591415182, 0.14794124668696895, 0.20835764851653948, 0.09562489693053067, 0.16778431629063562, 0.1116286807518918, 0.19533778075128794, 0.2316647072439082, 0.13704868586501107, 0.10651706441421993, 0.12866744888015091, 0.0741743874095846, 0.15400273783598095, 0.17162607342470437, 0.19801363872829825, 0.09106123790843412, 0.14052224869374186, 0.20433750876691192, 0.09685205295681953, 0.1822094406816177, 0.18807292683050036, 0.17142333352239802, 0.10595331419608556, 0.13966131285997108, 0.15473737497814, 0.18561500794021413, 0.13000546692637727, 0.221207371505443, 0.20942602946888655, 0.1070438111491967, 0.1891814431292005, 0.24284326209453866, 0.1907362276688218, 0.1284819416468963, 0.10418706951895729, 0.14984705223469064, 0.13922200596425682, 0.12028538811136968, 0.13531879900256172, 0.1208138937363401, 0.15515027625951916, 0.13439299946185201, 0.15621623781044036, 0.13579358055721968, 0.1274335541529581, 0.11955964189837687, 0.09492214245256037, 0.1044557047134731, 0.14309763471828774, 0.06954724507522769, 0.13954219815786928, 0.13234893180197105, 0.119935458060354, 0.16551827226066962, 0.07346752885496244, 0.2397413965081796, 0.163893043063581, 0.07854376701288857, 0.19316058664117008, 0.14741335704457015, 0.11031872330931947, 0.11384799916413613, 0.24177139304811135], [0.04033217133837752, 0.06596331746550277, 0.04485457808186766, 0.08587723248638213, 0.04277511739928741, 0.018517677344789263, 0.04080724233062938, 0.04547041593468748, 0.07633897985215299, 0.010719632991822436, 0.07811190385837108, 0.04270707730029244, 0.007054182315187063, 0.039920472336234525, 0.060375516914064065, 0.03354524938913528, 0.05377526736992877, 0.03598887822590768, 0.02843889673386002, 0.02923524716607062, 0.0671593849256169, 0.00676722488606174, 0.047110547457123175, 0.06429026427213103, 0.030631494119006675, 0.009216684684361098, 0.05654606829921249, 0.04463829398446251, 0.016657628912071232, 0.06927826849278063, 0.024268063898489345, 0.08314958744449541, 0.029253030879772268, 0.006512580566777615, 0.02932265731942607, 0.09014195442432538, 0.031313785730162635, 0.004663577146857278, 0.0842322398966644, 0.030305166219477542, 0.07725030751316808, 0.017522650268801954, 0.03735188067366835, 0.05031869230151642, 0.0537066521064844, 0.010172373295063153, 0.006916972661201726, 0.0880945916287601, 0.024783381559245754, 0.032693857574486174, 0.007977531840879237, 0.013088972846162505, 0.02892944150516996, 0.04214739405142609, 0.019357925812073518, 0.008397159763262607, 0.06199031151481904, 0.013092023073113523, 0.024485630056005903, 0.03198634221917018, 0.07340330339502543, 0.05764188274042681, 0.01782172836101381, 0.039531293805339374, 0.0221922768469085, 0.10910205382970162, 0.022970468780840747, 0.031156661934801377, 0.03266665415139869, 0.022191894640855026, 0.043983738287352026, 0.13561454485170543, 0.1684782688971609, 0.18137056147679687, 0.9542996145319194, 0.8060381608083844, 2.1100600250065327, 1.4727474167011678, 2.409080467186868, 2.1626572776585817, 4.00472148321569, 5.234847525134683, 5.266092298552394, 6.153539903461933, 4.762466372922063, 7.4739510007202625, 4.549292111769319, 8.829065635800362, 11.567984316498041, 6.797942100092769, 4.974023820832372, 4.905140167102218, 6.163543341681361, 9.12008536979556, 7.158028353005648, 2.6844379166141152, 2.0812597079202533, 2.505564414896071, 1.295156821142882, 0.7333174848463386, 0.41488649672828615, 0.1475364199723117, 0.03813179995631799, 0.05246284599706996, 0.15558369050268084, 0.07983606134075671, 0.009889775519695831, 0.022778445490985177, 0.0636987057805527, 0.03911573192453943, 0.04463564822799526, 0.048320526475436054, 0.03464026973233558, 0.026860066609515343, 0.028678493545157835, 0.056413973434246145, 0.06505091369035654, 0.03990666096797213, 0.0427743233012734, 0.04918215250654612, 0.08671174786286429, 0.051885848442907445, 0.035319338567205705, 0.057382160739507526, 0.01968206252058735, 0.04394184405100532, 0.03660928028693888, 0.033472671057097614, 0.012783267375198193, 0.04359918704722077, 0.051911244736402296, 0.016055131163739134, 0.010874631461774698, 0.11690653816913255, 0.10981965126120485, 0.03015482008777326, 0.027485541249916423, 0.04595316815539263, 0.007198308785518748, 0.023876833329268266, 0.045870522590121254, 0.040572397119831294, 0.030683607728860807, 0.03796141769271344, 0.020456760794331785, 0.02450370135193225, 0.03224187850719318, 0.053889662012807094, 0.022865059690957423, 0.02708049931243295, 0.05549172878090758, 0.04864927563176025, 0.006798756885473267, 0.0022743769568478456, 0.05293733069265727, 0.04227484307193663, 0.027519225477590226, 0.017128378749475814, 0.023781801319273654, 0.03739610896445811, 0.04586287104757503, 0.01643704035814153, 0.03028107796126278, 0.02297190669196425, 0.0531922843947541, 0.04646096414944623, 0.02989167121995706, 0.04368204412457999, 0.04544678595266305, 0.01149411233200226, 0.06670915361610241, 0.08777396156801842, 0.034436980640748516, 0.027309106772008818, 0.05007305626349989, 0.028758274420397356, 0.049726239521987736, 0.00826920329927816, 0.00364206908216147, 0.03584002195566427, 0.03377617606020067, 0.015862146792642307, 0.044499608848127536, 0.010595467974781059, 0.041524587431922555, 0.04498883259657305, 0.018558601223048754, 0.016813819456729107, 0.0031073233867573435, 0.018967231444548815, 0.08867017910233699, 0.03146248243865557, 0.05832696297147777, 0.028997539120609872, 0.07624530597240664, 0.03065430402784841, 0.0407772039034171, 0.03292958594101947, 0.03415464911086019, 0.044033369413227774, 0.07160901295719668, 0.010875378247874323, 0.05395643675001338, 0.042105718748643994, 0.08461783756501973, 0.02340383107366506, 0.03386441741895396, 0.04529842692136299, 0.04866555093030911, 0.03142310037219431, 0.02213436149759218, 0.03450504671491217, 0.03770905408600811, 0.06503534343210049, 0.04250569181749597, 0.02409946650004713, 0.03848254265903961, 0.018158869352191687, 0.06695424046483822, 0.03401715883228462, 0.04006888331787195, 0.14563944598194212, 0.02408320789982099, 0.03651250422990415, 0.03749762363440823, 0.05507136149390135, 0.05869781045475975, 0.06055959180230275, 0.0035462381038087187, 0.052886842386214994, 0.005763434901382425, 0.06636334990616888, 0.08291269390610978, 0.022901680968061555, 0.06413640221580863, 0.012643498703255318, 0.013645413837366505, 0.048325784591725096, 0.025282659553340636, 0.02075536391203059, 0.027040102359023876, 0.05342262847989332, 0.06757433453458361, 0.12867111508967355, 0.048847102516447194, 0.10128005480510183, 0.07153257174650207, 0.05955100197752472, 0.09903455342282541, 0.15003466716734692, 0.9131206898018718, 0.8976490481290966, 2.2359123593196273, 1.5902171633206308, 2.013307004235685, 2.390355784446001, 4.241226492449641, 5.068975975736976, 6.4828364085406065, 6.741591123864055, 5.3373607993125916, 7.877165414392948, 4.636528780683875, 9.498733151704073, 13.584317620843649, 7.780468678101897, 5.853970628231764, 5.327919255942106, 6.871143747121096, 8.635390028357506, 7.159377280622721, 3.9729998353868723, 3.0553649878129363, 3.0765602504834533, 1.5388777619227767, 0.7549249660223722, 0.3025450499262661, 0.12757071788655594, 0.07514769182307646, 0.05563775746850297, 0.10094591023516841, 0.0546784648031462, 0.004406807038321858, 0.09217235172400251, 0.017499207679065876, 0.02511262609914411, 0.005330426984073711, 0.047946383856469765, 0.03811009955825284, 0.08124572632368654, 0.020339570110081695, 0.10309552613762207, 0.057127774780383334, 0.031955543090589345, 0.015085455852386076, 0.016256024973699823, 0.05525622676941566, 0.009837767665885622, 0.02849384163710056, 0.009690339102235157, 0.04449401305464562, 0.023713610935374163, 0.06891791868838482, 0.029933272307971492, 0.05724666312744375, 0.023506303114118055, 0.06468514620792121, 0.051882590414606966, 0.019809697078017052, 0.07247710309457034, 0.06625174573855475, 0.024731384837650694, 0.04600119253154844, 0.039207290683407336, 0.0331763500435045, 0.046826316029182635, 0.05003213795134798, 0.08359067549463362, 0.02649027854204178, 0.06252310675336048, 0.023873675490904134, 0.06698818629956804, 0.06315118633210659, 0.0653288554167375, 0.03688016047817655, 0.04426959130796604, 0.06712768779834732, 0.022128711898403708, 0.03854949180094991, 0.031275524306693114, 0.054494712749146856, 0.055218395791598596, 0.02642961910169106, 0.00997298975562444, 0.04339616512879729, 0.09218020364642143, 0.06830665617599152, 0.018187117348134052, 0.008996413398563163, 0.02827536634868011, 0.027293440034554806, 0.04662623301555868, 0.03737630475370679, 0.029245958212413825, 0.08756975221331231, 0.04564502844004892, 0.019969778331869747, 0.05966694399830885, 0.05404036623076536, 0.06748670915840194, 0.04091244176379405, 0.01504497355199419, 0.1687592311645858, 0.13938196847448125, 0.13991067447932437, 0.12859445123467594, 0.1281735792872496, 0.11177076492458582, 0.11112229112768546, 0.13152391591574997, 0.13377186638535932, 0.18255866569234058, 0.1841628921101801, 0.08436135132797062, 0.13341737212613225, 0.08490691892802715, 0.18513047456508502, 0.1142565811460372, 0.17995677015278488, 0.11517146369442344, 0.15786475560162216, 0.13658451702212915, 0.19859214284224436, 0.0953312884666957, 0.13356014649616554, 0.1577647586236708, 0.1196739029546734, 0.08129500492941588, 0.15797864558408037, 0.23300605011172593, 0.15956185437971726, 0.3251033113338053, 0.15955924201989546, 0.15249951771693304, 0.12530169042292982, 0.06656271303654648, 0.06615455407882109, 0.2698687626980245, 0.1940133291645907, 0.13577453704783693, 0.15619425539625809, 0.0935636337089818, 0.13579181424574926, 0.11438170724431984, 0.17965069360798225, 0.11683918826747686, 0.13231103774160147, 0.20763617707416415, 0.07998575994861312, 0.15517678577452898, 0.16327959863701835, 0.1695133571047336, 0.09959167626220733, 0.1302370466873981, 0.08610217002569698, 0.13671246328158304, 0.11322383812512271, 0.1896299229701981, 0.16346198885003105, 0.17081386700738221, 0.11797721235780045, 0.11105134180979803, 0.20351560990093276, 0.12567882018629462, 0.10202213568845764, 0.16716877900762483, 0.16830166743602604, 0.19864205969497561, 0.12243922683410347, 0.2165782847441733, 0.1935757588944398, 0.308395370375365, 0.1836658312822692, 0.35211644775699824, 0.2973832347197458, 0.8002578990999609, 1.9366971775889397, 2.285685888491571, 3.68409326300025, 2.8563748905435205, 3.7661555595695972, 4.274343140423298, 7.230771649628878, 8.450213614851236, 10.771550852805376, 10.913509335368872, 8.569594658911228, 10.960642006248236, 8.208976909518242, 14.369362145662308, 22.621271051466465, 15.778317041695118, 11.610354892909527, 8.599565550684929, 11.13455867394805, 14.411025010049343, 11.194375064224005, 6.973363012075424, 5.022365301847458, 4.347946140915155, 2.375663397833705, 1.5088389487937093, 0.49191477592103183, 0.3113861661404371, 0.1744648625026457, 0.1706443604780361, 0.3147955035092309, 0.1505110814468935, 0.12228221065015532, 0.11348407962941565, 0.1594026043312624, 0.139919743523933, 0.19077096018008888, 0.20305622048908845, 0.17310769704636186, 0.23117491946322843, 0.13637365802424029, 0.16095118451630697, 0.16097405750770122, 0.18621271883603185, 0.10409489477751777, 0.17270082200411707, 0.19257090578321368, 0.11992963962256908, 0.06382382445735857, 0.1363782593398355, 0.16659906192217022, 0.1925508677959442, 0.1836427504895255, 0.15099824202479795, 0.1343664899468422, 0.12594992673257366, 0.11905666615348309, 0.10610327997710556, 0.07983227638760582, 0.23925530462292954, 0.21756072499556467, 0.09950077059329487, 0.09934411806170829, 0.1346422274946235, 0.1498201271169819, 0.11522930668434128, 0.16704457317246124, 0.1324881290202029, 0.10654815298039466, 0.1539368202793412, 0.1063907879870385, 0.15654141723643988, 0.1272731166682206, 0.15299789956770837, 0.1331987205776386, 0.09519715269561857, 0.13289444003021345, 0.09365618694573641, 0.21513436222448945, 0.18111073557520285, 0.2483982522971928, 0.1395083562238142, 0.10130830836715177, 0.05036730297433678, 0.10554425723967142, 0.21471417305292562, 0.15224110189592466, 0.07586987572722137, 0.1201733534981031, 0.09506689093541354, 0.17263371701119468, 0.07979162153787911, 0.15686819970142096, 0.11410460414481349, 0.14923003065632656, 0.12883772724308074, 0.17423490062355995, 0.16441109182778746, 0.19107921863906085, 0.2287210081703961, 0.11676086200168356, 0.1231855082733091], [0.027953992284892593, 0.03919998795026913, 0.033226196392206475, 0.017419578944100067, 0.028011017056996934, 0.035330849277670495, 0.0698790221940726, 0.04466679245524574, 0.02469219016347779, 0.06193482484377455, 0.03356254143000115, 0.019437428381934296, 0.0028187244197397376, 0.06534965039463714, 0.04908250804874115, 0.025206071768479887, 0.041120387832052074, 0.0683918473077938, 0.022770038813177962, 0.029194853923399933, 0.061802585260011256, 0.06403791179764085, 0.09518019462120719, 0.0654663605382666, 0.02558382308052387, 0.005993364775349619, 0.03554189381247852, 0.03353442887600977, 0.04517615809163544, 0.057377707853447646, 0.053776937202201225, 0.045749615601380356, 0.002169422664337617, 0.02159598716389155, 0.07394849249976687, 0.057293945355922915, 0.028157320339232683, 0.032549769603065215, 0.02470482708304189, 0.037230810412438586, 0.05737604915339034, 0.07806773865013383, 0.04232515326293651, 0.05179833067813888, 0.10319450637325644, 0.06757287250366062, 0.1073175597412046, 0.0278290776986978, 0.02248504853923805, 0.010148452020075638, 0.018638241090229712, 0.02395153420366114, 0.03314142828457989, 0.03425785958825145, 0.029128661772119813, 0.08062932072789408, 0.03560249388101511, 0.09083964003366418, 0.06140574776509311, 0.037681346002500504, 0.06178587209433317, 0.019119547978334595, 0.015960713280946948, 0.08118049896438606, 0.03855806360661518, 0.07091836290783249, 0.11740665664547123, 0.534877764293924, 0.5218921392224729, 1.3828440033830702, 2.3058155458420515, 10.202072560787201, 17.603729590773582, 21.32132090628147, 25.33208169043064, 22.36377976834774, 28.787772059440613, 31.359360069036484, 38.897722363471985, 45.76898865401745, 49.53993670642376, 54.23235431313515, 61.7831115424633, 56.73123702406883, 59.593517035245895, 59.42927084863186, 54.92191471159458, 62.159899324178696, 69.14272382855415, 63.044035881757736, 49.05672803521156, 39.52474571764469, 42.89096988737583, 49.45053890347481, 51.98288641870022, 43.01962338387966, 38.97063285112381, 40.76885215938091, 28.411746136844158, 20.84505256265402, 11.254031863063574, 4.182473570108414, 0.6431141251232475, 0.11588545428821817, 0.0764713047828991, 0.039744687237543985, 0.05944123833614867, 0.053289654169930145, 0.029951651595183648, 0.09770310338353738, 0.09167454874841496, 0.08370362294954248, 0.024704535790078808, 0.024091748164210003, 0.013197337539168075, 0.05970880854874849, 0.05563351238379255, 0.02211850180174224, 0.08209883992094547, 0.022494614822790027, 0.024937432863225695, 0.07944804427097552, 0.042701299680629745, 0.022553131311724428, 0.013838350896548945, 0.028283162610023282, 0.018692833473323844, 0.11440380840213038, 0.02050325263553532, 0.022888711937412154, 0.029041704328847118, 0.012828509625251172, 0.032029078793129884, 0.09909459316986613, 0.03797679499257356, 0.05393712977820542, 0.05961014001513831, 0.08090718081803061, 0.0337168561964063, 0.008762731504248222, 0.07155918516218662, 0.10891714031458832, 0.08676363882841542, 0.07170192984631285, 0.04216097906464711, 0.02626046509249136, 0.01986040431802394, 0.05457397783175111, 0.03858272517391015, 0.048904897266766056, 0.010582351442280924, 0.051975922906422056, 0.0477460819092812, 0.04503137621213682, 0.08685173917911015, 0.016818669391795993, 0.0460987589758588, 0.026451163648744114, 0.008595990402682219, 0.07461962406523526, 0.047228849507519044, 0.06632117365370505, 0.006818790698162047, 0.06156903509690892, 0.09686247271019965, 0.047306826963904314, 0.03740227621165104, 0.07479508261894807, 0.038892278680577874, 0.04155682632699609, 0.048900696710916236, 0.017459107584727462, 0.029223072233435232, 0.018534707778599113, 0.026946771722577978, 0.041360275936312973, 0.020665046395151876, 0.05429749071481638, 0.022203908156370744, 0.05507202571607195, 0.09769950396730565, 0.04366656292404514, 0.021575500177277718, 0.04038189894345123, 0.055538981323479675, 0.12364972906652838, 0.035425569585640915, 0.006439853341362323, 0.02973412996652769, 0.06769464409444481, 0.06256748718442395, 0.022887472550792154, 0.015085134873515926, 0.035903512689401396, 0.03883425015374087, 0.09080392788746394, 0.05965311036561616, 0.05815937118313741, 0.0744494199170731, 0.02315300556801958, 0.014591303315683035, 0.07823481835657731, 0.06056969614292029, 0.07132908969651908, 0.06620008483878337, 0.04316184684284963, 0.03156476523145102, 0.07882941223215312, 0.021746368547610473, 0.020306321894167922, 0.010610450081003364, 0.025185939157381654, 0.005048706798334024, 0.006896796912769787, 0.020731791446451098, 0.03614300745539367, 0.023095054966688622, 0.03203898646461312, 0.05045884689025115, 0.038781962139182724, 0.03965382980823051, 0.09878167402348481, 0.07322813427890651, 0.07993244405952282, 0.00688750754306966, 0.04173595109023154, 0.03038617349375272, 0.07923479555756785, 0.05765007605077699, 0.02631638963066507, 0.05175673701160122, 0.05930358107434586, 0.04665074615331832, 0.021403271821327507, 0.04127642809180543, 0.015536455284745898, 0.036155071065877564, 0.045407363068079576, 0.06397001270670444, 0.14771224959986284, 0.04881295630184468, 0.06561973277712241, 0.06080872335587628, 0.5038022599183023, 0.6718585139606148, 1.12589739728719, 2.5459127873182297, 10.521011296659708, 16.303844042122364, 22.75993701070547, 25.63844595104456, 24.71419494599104, 31.38297200202942, 35.11746101081371, 43.97830434143543, 50.78205205500126, 57.606200873851776, 62.008333057165146, 69.69190075993538, 62.56715007126331, 65.42354419827461, 65.45360058546066, 59.69005465507507, 69.4996690750122, 77.30519503355026, 67.92846098542213, 53.01064006984234, 43.95039103925228, 49.786820858716965, 56.02003678679466, 60.30261978507042, 53.58701594173908, 47.07782082259655, 50.88786117732525, 36.49890348315239, 27.69397035241127, 17.06781204789877, 6.406565476208925, 0.5261243996210396, 0.09492212018813007, 0.055126933511928655, 0.0572554167592898, 0.07326004662900232, 0.06905655187438242, 0.0556447447888786, 0.036704416197608225, 0.0538385131949326, 0.0497032960265642, 0.019560149921744596, 0.046352425051736645, 0.020340456976555288, 0.06933842698344961, 0.01611085161130177, 0.0907148107944522, 0.02911232895712601, 0.034992381697520614, 0.01949243451235816, 0.04588263815094251, 0.005497032643688726, 0.017508961354906205, 0.03783849206229206, 0.053676190655096434, 0.040626599875395186, 0.03970203972130548, 0.03118177250144072, 0.026819493396033067, 0.03355411063239444, 0.05883996142074466, 0.016259388758044224, 0.01543541373393964, 0.026463067697477527, 0.0265158585170866, 0.03842175334284548, 0.0368007395445602, 0.024894631351344287, 0.01850027583714109, 0.024869999469956383, 0.12338256332441233, 0.05617964772682171, 0.0623154167260509, 0.01229952624271391, 0.031908160672173835, 0.04514602689596359, 0.07466351467883214, 0.0031500792101724073, 0.04365496315585915, 0.03702776622958481, 0.01788327095709974, 0.04991503075871151, 0.037942132985335775, 0.04393247072584927, 0.01751927164150402, 0.08260343354777433, 0.019356051889189985, 0.03269416556577198, 0.021672567527275532, 0.06396099561243318, 0.04749708023155108, 0.054122507135616615, 0.052118738094577566, 0.022088394725869875, 0.021821147347509395, 0.03280193282989785, 0.05810222581203561, 0.04700870624219533, 0.03463667402684223, 0.04482660653593484, 0.046272402978502214, 0.06377035271725617, 0.03118063701549545, 0.017115725131588988, 0.06448422456742264, 0.08495758534991182, 0.09495025500655174, 0.19674251787364483, 0.19200362294213846, 0.21219026239123195, 0.1842842629412189, 0.11152345163282007, 0.16268555395072326, 0.14969586191000417, 0.22684849536744878, 0.1251168511225842, 0.2021869132295251, 0.11333536065649241, 0.2807582064997405, 0.165352372569032, 0.193713768676389, 0.09589152832631953, 0.19408482767175883, 0.09550146292895079, 0.24366576952161267, 0.12767139764036983, 0.22687187301926315, 0.2151496207807213, 0.16686951537849382, 0.12366207840386778, 0.22139045933727175, 0.16194471245398745, 0.2162523483275436, 0.22510979179060087, 0.14052950689801946, 0.1631381452898495, 0.10691418021451682, 0.11780145694501698, 0.09673574357293546, 0.2081391602405347, 0.164710815588478, 0.10892916310695, 0.09012687398353592, 0.1906099883490242, 0.12093550205463544, 0.083747461612802, 0.13445360324112698, 0.11092172571807168, 0.09949205035809427, 0.1099024155701045, 0.25046985363587737, 0.14521081116981804, 0.19412886671489105, 0.09288465764257126, 0.10512225722777657, 0.17981632612645626, 0.16505754698300734, 0.21790353785036132, 0.14073457714403048, 0.10967300288029946, 0.1447126519633457, 0.15706096513895318, 0.15913226961856708, 0.12774856615578756, 0.14233405381673947, 0.14127699803793803, 0.11684695855365135, 0.12579609436215833, 0.23736996750812978, 0.13172301929444075, 0.20418899017386138, 0.34493875165935606, 0.7717961200978607, 1.4887040667235851, 3.2655782578513026, 5.94155402854085, 16.068482771515846, 26.268497742712498, 34.520148262381554, 37.18537084758282, 36.450877860188484, 44.179651737213135, 48.0303081125021, 55.837825164198875, 65.66659435629845, 71.53671696782112, 75.51348477602005, 84.86822560429573, 77.36723810434341, 80.36231338977814, 79.12725806236267, 76.137023717165, 86.25444442033768, 92.96455755829811, 85.92969104647636, 67.47098833322525, 58.63895885646343, 62.471410408616066, 71.44894167780876, 73.09325784444809, 66.31455838680267, 60.752470046281815, 60.253317430615425, 48.02670210599899, 36.561482325196266, 23.03360402584076, 8.861080817878246, 1.3034847867675126, 0.3584739816142246, 0.11540755571331829, 0.14252999564632773, 0.20210343645885587, 0.14114057645201683, 0.15777881490066648, 0.17619638208998367, 0.2347200401709415, 0.18552065128460526, 0.1413315607351251, 0.11792838646215387, 0.11535320823895745, 0.1788600836880505, 0.12038529603159986, 0.16390392294852063, 0.25107224006205797, 0.10589367520879023, 0.10078049293952063, 0.27892281592357904, 0.12065380506101064, 0.09517043537925929, 0.14291128143668175, 0.13243374443845823, 0.10582767601590604, 0.24116301006870344, 0.1688715923228301, 0.11567655456019565, 0.1668319181771949, 0.17261685541598126, 0.09228839393472299, 0.12968282564543188, 0.1268063354655169, 0.11367476705345325, 0.1015574399207253, 0.16862044954905286, 0.15245957532897592, 0.12271372499526478, 0.16220330639043823, 0.21367224224377424, 0.1254391807015054, 0.1595450224704109, 0.1127467855985742, 0.049373370566172525, 0.17234197875950485, 0.19308527349494398, 0.09374282526550815, 0.16914774547331035, 0.1210533179983031, 0.1926749845733866, 0.2386108977952972, 0.11351769891916774, 0.15638523967936635, 0.12942406843649223, 0.16417689970694482, 0.1739867709693499, 0.13221782399341464, 0.1258192938985303, 0.17570985975908116, 0.20460960979107767, 0.09966242520022206, 0.18664414412342012, 0.1338700673659332, 0.20951152488123626, 0.14099820284172893, 0.23698679666267708, 0.18498283170629293, 0.18408984993584454, 0.15535865648416802, 0.0914118358923588, 0.1754377142060548, 0.0947834127873648, 0.11316477801301517, 0.15241587767377496], [0.03717467436217703, 0.060916301372344606, 0.018534433183958754, 0.004000868493676535, 0.06134372277301736, 0.08118124853353947, 0.032782462585601024, 0.08290133904665709, 0.059059614868601784, 0.03881584860209841, 0.08011743178940378, 0.025774178393476177, 0.05643377764499746, 0.014146179837553063, 0.026486295064387377, 0.07063805373036303, 0.04154377194936387, 0.06796796966227703, 0.04020153479359578, 0.026698183792177588, 0.034395412949379534, 0.0525643124274211, 0.07459145956090651, 0.013468565612129169, 0.05156736689968966, 0.0065219358020840446, 0.09273003859561868, 0.0556979716202477, 0.01788992616639007, 0.02859004438505508, 0.02168261620681733, 0.03189499126165174, 0.07105858428985812, 0.05157349332876038, 0.016808791406219825, 0.050924867391586304, 0.01237123811733909, 0.04060462488268968, 0.05748199073423166, 0.02703695008676732, 0.030841236184642185, 0.05050727202615235, 0.04076327008078806, 0.083850108057959, 0.026227471062156837, 0.018681497167563066, 0.010592118105705595, 0.04825410054763779, 0.029412410804070532, 0.04973042894562241, 0.04131553927436471, 0.038723584802937694, 0.021827288619533647, 0.03617495691287331, 0.05724255162931513, 0.009430769241589587, 0.03012850724189775, 0.01874285237136064, 0.01975636820134241, 0.09445336487260647, 0.06110576054197736, 0.025238683592760935, 0.04108704313694034, 0.027238198272243608, 0.45394955843221396, 3.222980643622577, 8.0351865850389, 17.227160297334194, 18.404198437929153, 27.055224627256393, 38.22874926030636, 45.852447375655174, 59.85092282295227, 67.56830871105194, 71.40619397163391, 76.91689386963844, 73.85301187634468, 76.79113581776619, 88.78687933087349, 83.07227477431297, 75.84643051028252, 89.4747868180275, 79.70140725374222, 84.23384964466095, 83.27082931995392, 89.65868934988976, 80.88743761181831, 85.97724169492722, 82.43710845708847, 76.36670619249344, 81.31663978099823, 72.58858412504196, 78.50786849856377, 84.04974952340126, 82.52025559544563, 81.03117629885674, 70.59830412268639, 73.93384113907814, 75.7301415503025, 81.72593861818314, 74.944738894701, 48.940689861774445, 22.007079608738422, 5.134038934484124, 0.8264506061095744, 0.227881342289038, 0.084359941247385, 0.031717421297798865, 0.03792248091485817, 0.05710349912988022, 0.031147900881478563, 0.00917836945518502, 0.061448053893400356, 0.08611379947979003, 0.015268358147295658, 0.08017338230274618, 0.03184395747666713, 0.020019348230562173, 0.07251040326082148, 0.09571341288392432, 0.0778472465754021, 0.023796249079168774, 0.02337249203264946, 0.06716470612445846, 0.017123558500315994, 0.022779098580940627, 0.026003255261457525, 0.036549619035213254, 0.03640182032540906, 0.027866044074471574, 0.04412254216731526, 0.03101553698797943, 0.07900236232671887, 0.02231387588835787, 0.062470792763633654, 0.06562202601344325, 0.014706048623338575, 0.015490873502130853, 0.03807360444625374, 0.03657791712612379, 0.011520844491315074, 0.009004326548165409, 0.02274302278237883, 0.01827009502449073, 0.10483405159902759, 0.04501258132222574, 0.04428539534274023, 0.04008098032500129, 0.0025903393725457136, 0.04214294116536621, 0.07703368944930844, 0.05128509474161547, 0.020875445261481218, 0.040824393363436684, 0.04613985169271473, 0.07099633294274099, 0.013922936250310158, 0.0365987863187911, 0.0414424687915016, 0.016667981872160453, 0.01640992228203686, 0.05302918259985745, 0.05154601160029415, 0.11977191097685136, 0.029772445195703767, 0.06491331951110624, 0.07606333878356963, 0.025951668576453812, 0.03108848824922461, 0.045216174694360234, 0.09930691419867799, 0.021972766262479126, 0.07859737233957276, 0.0629118065990042, 0.057854511760524474, 0.03603515855502337, 0.039308779378188774, 0.021110522393428255, 0.017375029674440157, 0.061793037530151196, 0.018549708438513335, 0.06751692199031822, 0.012444520561984973, 0.027756098606914748, 0.07175790262408555, 0.06771973610739224, 0.011031394387828186, 0.022687599193886854, 0.048323394876206294, 0.04901259773760103, 0.05292389410897158, 0.05184373898373451, 0.03957298024033662, 0.07928796301712282, 0.030007106724951882, 0.05212982949160505, 0.030183231356204487, 0.040153592053684406, 0.05005231323593762, 0.024298037387779914, 0.010917458021140192, 0.040090038237394765, 0.02164672223443631, 0.047475706378463656, 0.016063680704974104, 0.02417513773252722, 0.039669255347689614, 0.046658527571707964, 0.019591822929214686, 0.043617269475362264, 0.008737921507417923, 0.12650138698518276, 0.007662697489649872, 0.06556594191351905, 0.0385695446311729, 0.05100441449030768, 0.05746987146267202, 0.05364692406146787, 0.01736859525408363, 0.051913756906287745, 0.1002808049088344, 0.02595064441266004, 0.006730784043611493, 0.015989217317837756, 0.059189761595916934, 0.05605891143204644, 0.05902814409637358, 0.02493409876478836, 0.0953274812491145, 0.03285832121036947, 0.03239156969357282, 0.020252928079571575, 0.03570341483282391, 0.04480965588300023, 0.05842344216944184, 0.020290658867452294, 0.10381275249528699, 0.031089723925106227, 0.0793432975478936, 0.33776010561268777, 0.5385838716756552, 4.005489517003298, 10.299143102020025, 19.51578129082918, 20.161385647952557, 28.150559552013874, 39.71717119216919, 50.934446677565575, 68.34848284721375, 74.84831526875496, 79.95551481842995, 83.82615432143211, 84.91206765174866, 89.5637096464634, 100.95204055309296, 96.39986202120781, 89.38266456127167, 98.63193824887276, 90.67645713686943, 100.37669062614441, 97.41838216781616, 100.67867562174797, 91.81088626384735, 96.0300962626934, 91.68937638401985, 89.94482919573784, 91.81052148342133, 81.66761934757233, 89.77911248803139, 96.30378797650337, 91.80656209588051, 91.53230041265488, 84.8472811281681, 87.50014677643776, 91.5421798825264, 98.05205136537552, 90.19941553473473, 60.26441663503647, 29.89888373762369, 7.911562118679285, 0.8761697506997734, 0.19841457658912987, 0.04113842202059459, 0.08670653056469746, 0.06078715654439293, 0.10221099000773393, 0.07244375097798184, 0.03436690705711953, 0.024326511738763656, 0.0856711009691935, 0.03970890087657608, 0.03775207638682332, 0.06575087769306265, 0.05071502142527606, 0.06290909033850767, 0.034281459884368815, 0.021940607148280833, 0.04677071061450988, 0.08974426717031747, 0.021945186199445743, 0.061209516497910954, 0.00966642061030143, 0.021527828321268316, 0.023012387136986945, 0.032989911414915696, 0.021187319835007656, 0.019913211835955735, 0.013922341604484245, 0.012685340061580064, 0.010163081606151536, 0.06963199833990075, 0.03313909051939845, 0.03829521716397721, 0.011352203491696855, 0.05605675920378417, 0.03771544768824242, 0.06245830241823569, 0.013256542370072566, 0.05047026483225636, 0.037501211918424815, 0.019735786590899806, 0.049967092418228276, 0.05780981220596004, 0.06148684595245868, 0.02183942087867763, 0.04064928361913189, 0.07210257826955058, 0.03125524141069036, 0.03977926018706057, 0.021553029800998047, 0.008972007872216636, 0.050827048617065884, 0.06488060564151965, 0.07762304376228712, 0.05025287493481301, 0.050331687307334505, 0.0031592373125022277, 0.09419603258720599, 0.05262187340122182, 0.03948479083192069, 0.022490828014269937, 0.05349524391931482, 0.030530610274581704, 0.006721467307215789, 0.011517165294208098, 0.04510391743679065, 0.03758625090995338, 0.04986373722204007, 0.06358537240885198, 0.08014708801056258, 0.0451696828531567, 0.05949410151515622, 0.12567850848427042, 0.11206841809325852, 0.08003186216228642, 0.19816999440081418, 0.13285575929330662, 0.16317642526701093, 0.11608231638092548, 0.11141751747345552, 0.1651870962814428, 0.12433522861101665, 0.176218394190073, 0.15199230430880561, 0.12282514362595975, 0.14954603713704273, 0.12352130041108467, 0.1190217629482504, 0.09743772621732205, 0.21333702898118645, 0.1217361309682019, 0.22280606150161475, 0.0787133551784791, 0.1205922216468025, 0.14446389890508726, 0.1553905985201709, 0.20540491008432582, 0.08839715039357543, 0.12831976753659546, 0.15220399451209232, 0.08877146741724573, 0.09742516165715642, 0.10781850942294113, 0.1635491763590835, 0.17819470376707613, 0.16350457328371704, 0.10520311421714723, 0.15821812179638073, 0.22115491650765762, 0.21832853613886982, 0.19141131488140672, 0.20699749962659553, 0.08394290620344691, 0.1552491748589091, 0.11002278450177982, 0.2650613972218707, 0.20634365268051624, 0.10541351308347657, 0.07547679721028544, 0.11268348040175624, 0.0927826420229394, 0.18522576632676646, 0.1553612540010363, 0.12356750652543269, 0.18174580618506297, 0.08824656120850705, 0.2029104033135809, 0.09444169088965282, 0.1381027582101524, 0.16377277061110362, 0.11937898088945076, 0.24672775209182873, 0.12966551876161247, 0.13880629936465994, 0.25900271139107645, 0.5513379466719925, 1.4790166052989662, 6.475376458838582, 16.56836684793234, 29.10291764885187, 31.103263311088085, 42.09298610687256, 53.630641400814056, 66.2489815056324, 83.43836233019829, 89.36189487576485, 93.81101533770561, 100.90429991483688, 99.49008420109749, 104.70481798052788, 114.66271564364433, 109.08000960946083, 102.74204090237617, 112.38166004419327, 104.08415168523788, 111.50449991226196, 109.62507516145706, 110.40379017591476, 102.85820826888084, 108.93284350633621, 103.28529015183449, 100.06872475147247, 104.27427068352699, 99.74130392074585, 105.61056017875671, 109.75154757499695, 105.09717732667923, 105.70437714457512, 97.00969129800797, 101.76847994327545, 106.34394362568855, 110.92591255903244, 103.15472915768623, 71.30454182624817, 35.45021675527096, 11.427729092538357, 1.5898894309066236, 0.43748020310886204, 0.238217129081022, 0.15087669307831675, 0.15333130198996514, 0.1411072540213354, 0.1739267905941233, 0.13166853081202134, 0.14510783075820655, 0.1463007292477414, 0.11435607346356846, 0.20008592284284532, 0.17371891502989456, 0.22631474275840446, 0.17294589400989935, 0.13750374113442376, 0.17640480684349313, 0.1171563970274292, 0.10788229701574892, 0.14296940644271672, 0.07581928352010436, 0.14773757167859003, 0.12719412246951833, 0.11715906133758835, 0.10491386958165094, 0.16165797627763823, 0.10491561362869106, 0.12462223938200623, 0.1124939952569548, 0.07961322407936677, 0.1472166582243517, 0.1706800577812828, 0.15682809404097497, 0.1323014046647586, 0.13570032228017226, 0.2350371005013585, 0.10176225783652626, 0.15467182849533856, 0.16111928096506745, 0.11060574150178581, 0.1736765235546045, 0.1309430814580992, 0.09683020412921906, 0.11329646469675936, 0.1218191698717419, 0.10751919384347275, 0.17857207101769745, 0.17829364689532667, 0.12962581386091188, 0.1057954148564022, 0.1367835610290058, 0.1378226123051718, 0.096238541736966, 0.23321334680076689, 0.10897500556893647, 0.11862701459904201, 0.0961445264692884, 0.1915872484096326, 0.39508121728431433, 0.2537126827519387, 0.1737831998616457, 0.18287404876900837, 0.16810137662105262, 0.10818155322340317, 0.09139841786236502, 0.10851669227122329, 0.16124795452924445, 0.17006403068080544, 0.12738341465592384, 0.1642135321162641, 0.19642762461444363, 0.1434800188872032], [0.050542635362944566, 0.019100623212580103, 0.011791663455369417, 0.03834753486444242, 0.05087160345283337, 0.056728707131696865, 0.027381391955714207, 0.05305873492034152, 0.005888355981369386, 0.06661564300884493, 0.026781176311487798, 0.06518498266814277, 0.05656947934767231, 0.033251785644097254, 0.004182693282928085, 0.030708699741808232, 0.03800080346991308, 0.056465326342731714, 0.02329959828784922, 0.036364390107337385, 0.07168223324697465, 0.03788388552493416, 0.06574289218406193, 0.07916761634987779, 0.04189326413325034, 0.022141701338114217, 0.07195473503088579, 0.03972585895098746, 0.034983041769010015, 0.06508920851047151, 0.01793104485841468, 0.05262805920210667, 0.020348329308035318, 0.014716674322698964, 0.02365651380387135, 0.022303968216874637, 0.010277869587298483, 0.023087976733222604, 0.044313196194707416, 0.0325862461613724, 0.05779737010016106, 0.025123567211267073, 0.054549576016142964, 0.06945314817130566, 0.02914722659625113, 0.045659426104975864, 0.02205764569225721, 0.058954326377715915, 0.04043907028972171, 0.05935360924922861, 0.009611901514290366, 0.03212767682271078, 0.020550675872073043, 0.015491910653508967, 0.05825582811667118, 0.07200186882982962, 0.04333259646955412, 0.07761848697555251, 0.010595800085866358, 0.05615317902993411, 0.16168592555914074, 0.567103597568348, 6.3661422953009605, 19.3027039244771, 32.230565920472145, 39.85147878527641, 45.38661137223244, 54.060633927583694, 57.56537586450577, 61.86459816992283, 69.02935311198235, 79.41608056426048, 67.32667207717896, 76.44229933619499, 78.3576549589634, 71.54988706111908, 69.0920801460743, 65.94063565135002, 56.23818688094616, 89.15324047207832, 57.8603046387434, 44.59066428244114, 46.55741214752197, 42.55183808505535, 59.40884694457054, 66.25759184360504, 59.2716933041811, 57.061074525117874, 50.712648779153824, 48.958089128136635, 57.5957590341568, 60.88350221514702, 74.87773329019547, 64.82556268572807, 61.072291284799576, 60.67855641245842, 50.6527715921402, 69.64985221624374, 61.30095161497593, 67.4346774816513, 69.34595972299576, 83.0531769990921, 74.36442643404007, 58.80628287792206, 22.729766629636288, 7.920977063477039, 1.4212333434261382, 0.7739359396509826, 0.1493932437733747, 0.09159997032838874, 0.0500405205093557, 0.028184384609630797, 0.08438506294623949, 0.05513396536116488, 0.02814250336086843, 0.016454786964459345, 0.048210829627350904, 0.022550789835804608, 0.02519893787393812, 0.013622337683045771, 0.005650762504956219, 0.024755864578764886, 0.1004775779438205, 0.028998539164604153, 0.025171185261569917, 0.02544471120927483, 0.062154099796316586, 0.04006830073194578, 0.048512160137761384, 0.04578370615490712, 0.047365723803523, 0.05507851208676584, 0.015623464678355958, 0.027290421348880045, 0.029808713952661492, 0.020895407178613823, 0.0027320046956447186, 0.03589897074562032, 0.13537284219637513, 0.046971472693257965, 0.05488901209901087, 0.0455439330835361, 0.03091150829277467, 0.033572590109542944, 0.0926212100603152, 0.0113006260835391, 0.030569994196412154, 0.04953080977429636, 0.03879148018313572, 0.05476087659189943, 0.053560252345050685, 0.048289415644831024, 0.04276470877812244, 0.031871357568888925, 0.01696018396614818, 0.03485725144855678, 0.033012884596246295, 0.031056061961862724, 0.06691009009955451, 0.0521032160759205, 0.014872600477247033, 0.01463913380575832, 0.05506565808900632, 0.05910397674597334, 0.01451168478524778, 0.02406959691143129, 0.055414675298379734, 0.024761065178608987, 0.021912976990279276, 0.025555426655046176, 0.006881128319946583, 0.01818208744225558, 0.023102934719645418, 0.017828778763941955, 0.07111351806088351, 0.01870319199952064, 0.015243949837895343, 0.048539623312535696, 0.049362698482582346, 0.02376436455961084, 0.019621219398686662, 0.030233667712309398, 0.035957756263087504, 0.019748289923882112, 0.0544006418203935, 0.02005089321755804, 0.020757805577886757, 0.02900452458561631, 0.02415119048237102, 0.018875008463510312, 0.005788164653495187, 0.02728223174926825, 0.047849745096755214, 0.03263362486904953, 0.05686883203452453, 0.054803327439003624, 0.037799202764290385, 0.018927810415334534, 0.04927468347887043, 0.05068256359663792, 0.03876190559822135, 0.09990340055082925, 0.06151057612441946, 0.029959269741084427, 0.03887848957674578, 0.02230390142358374, 0.055030710354913026, 0.05422172114776913, 0.057921093539334834, 0.056905412493506446, 0.009612536978238495, 0.0250163101736689, 0.008587674637965392, 0.04135148519708309, 0.0875923728744965, 0.03691340869409032, 0.07322472039959393, 0.035741739338845946, 0.016193573246710002, 0.03084462779952446, 0.007118362318578875, 0.0678003704524599, 0.014949390497349668, 0.024391084152739495, 0.07918671180959791, 0.04868633106525522, 0.013293611718836473, 0.05530173897568602, 0.016899936417758, 0.024204899709729943, 0.030459933695965447, 0.03924336648196913, 0.02431543147395132, 0.08383378823054954, 0.04294172584195621, 0.045493177603930235, 0.21216795343207195, 1.3758291047997773, 9.207071252167225, 21.892618350684643, 34.99736465513706, 45.43788202106953, 52.63633735477924, 61.46679371595383, 65.61313882470131, 69.76510003209114, 80.09939789772034, 86.95993736386299, 78.37894141674042, 88.77383083105087, 90.67685231566429, 81.03312939405441, 78.87930616736412, 76.76354169845581, 69.68841254711151, 93.8234406709671, 66.69478118419647, 58.31775449216366, 60.435608848929405, 54.63563807308674, 72.61061534285545, 80.22419840097427, 71.04650527238846, 69.39553186297417, 61.454915553331375, 61.24785326421261, 69.72420662641525, 73.97107154130936, 87.27332934737206, 76.95382788777351, 73.36579442024231, 73.42634797096252, 58.21895219385624, 78.25187623500824, 68.6199326813221, 77.57909953594208, 80.23128882050514, 94.2630010843277, 86.62507653236389, 70.98654448986053, 30.806178152561188, 11.129388101398945, 2.4075275380164385, 0.844453921308741, 0.22443811845732853, 0.07258105571963824, 0.07865029489039443, 0.04437419331225101, 0.08211313368519768, 0.02301508855452994, 0.034385497856419533, 0.02552394103986444, 0.08470823857351206, 0.0357712731056381, 0.07556039272458293, 0.013417432564892806, 0.07740134940831922, 0.02080512491374975, 0.07166223978856578, 0.008266779259429313, 0.03253418079111725, 0.08487528859404847, 0.04218698762997519, 0.010961964617308695, 0.06764384408597834, 0.03360531511134468, 0.024139642664522398, 0.01665986277657794, 0.03494439442874864, 0.060473335688584484, 0.022238883721001912, 0.020040762901771814, 0.024614147769170813, 0.04478310926060658, 0.07189424257376231, 0.03695366649481002, 0.08397268116823398, 0.026504707748244982, 0.04591961936966982, 0.023044585213938262, 0.04927807880449109, 0.024242871695605572, 0.02627762169140624, 0.05774027667939663, 0.012949270039825933, 0.013581479670392582, 0.05238477577222511, 0.0124128438437765, 0.04684078048740048, 0.040668256624485366, 0.04626212423318066, 0.06842344795586541, 0.015017979785625357, 0.04833369217521977, 0.05846828644280322, 0.005633728360407986, 0.04442939425643999, 0.01583238296007039, 0.03750405434402637, 0.1132823119405657, 0.0979417483904399, 0.027727357082767412, 0.09003150058561005, 0.03140896245895419, 0.02931017068476649, 0.0761094261542894, 0.04315641061111819, 0.013377469767874572, 0.06652672629570588, 0.04802146693691611, 0.010005837211792823, 0.042201151518383995, 0.10587924043647945, 0.09438307606615126, 0.21242386079393327, 0.1768758925027214, 0.20765654160641134, 0.1330449030501768, 0.12147636443842202, 0.17278401675866917, 0.11087361228419468, 0.09173621379886754, 0.13308656722074375, 0.10470854700542986, 0.12826789141399786, 0.09930450964020565, 0.12101817730581388, 0.1755858468823135, 0.18998143379576504, 0.1541660845396109, 0.12762174796080217, 0.13982431817566976, 0.16748037713114172, 0.16934310842771083, 0.1493794991984032, 0.19229493074817583, 0.21386680367868394, 0.1139854449138511, 0.24610023654531687, 0.12545837264042348, 0.20228981942636892, 0.12197375923278742, 0.09926911661750637, 0.1612114705494605, 0.12379032152239233, 0.16857342707226053, 0.11415313318138942, 0.10946270049316809, 0.10095302743138745, 0.14291818341007456, 0.2630394900916144, 0.08403065032325685, 0.13883059727959335, 0.07958149726619013, 0.19303834007587284, 0.10544822333031334, 0.09821819097851403, 0.17560776992468163, 0.09354416717542335, 0.1126417717023287, 0.1488249219255522, 0.19367352942936122, 0.0927319162292406, 0.10121410014107823, 0.23588215437484905, 0.13006062334170565, 0.12341163324890658, 0.15928310371236876, 0.10816649504704401, 0.14621190901380032, 0.1082810974912718, 0.1380238085403107, 0.36345812666695565, 2.5562023976817727, 13.360254094004631, 31.76813643425703, 49.03490200638771, 60.739915519952774, 68.38553845882416, 78.21176558732986, 81.86224490404129, 88.06465208530426, 96.63437783718109, 99.2977537214756, 93.15442577004433, 99.37811180949211, 101.91705957055092, 91.39132797718048, 92.6269380748272, 88.65533038973808, 80.41984990239143, 108.73720720410347, 79.79722291231155, 66.41203075647354, 71.157938092947, 65.56944876909256, 82.11072117090225, 88.44299778342247, 81.87235236167908, 80.5267533659935, 70.72872072458267, 69.61377695202827, 80.02074971795082, 85.08537635207176, 96.91038742661476, 89.19345751404762, 85.79650819301605, 82.4835267663002, 72.5092139840126, 90.45773327350616, 84.53585743904114, 90.98829880356789, 93.65935787558556, 106.84084296226501, 100.87830170989037, 82.73593962192535, 37.95221909880638, 15.576899349689484, 3.9790175249800086, 1.6086017643101513, 0.39523306069895625, 0.2515948307700455, 0.25629838462918997, 0.1375801526592113, 0.11848969501443207, 0.24689639772986993, 0.15251866512699053, 0.15098817850230262, 0.1271021258435212, 0.13180222129449248, 0.12924478040076792, 0.1315414602868259, 0.17221936112036929, 0.12539214338175952, 0.24490116338711232, 0.1501145667862147, 0.157672687782906, 0.1919364437344484, 0.200586263963487, 0.16140428051585332, 0.1496018614852801, 0.18634293606737629, 0.08532354579074308, 0.30589727160986513, 0.14517858711769804, 0.10605512943584472, 0.1074864502879791, 0.11847198737086728, 0.10972003277856857, 0.15079453733051196, 0.22903380857314914, 0.2036413297173567, 0.14819479401921853, 0.07909009160357527, 0.17207617114763707, 0.09972027561161667, 0.17368808621540666, 0.1505788543727249, 0.11186999006895348, 0.14856463589239866, 0.1207209620042704, 0.11810910684289411, 0.0941859616432339, 0.20052534848218784, 0.21712406014557928, 0.09296126212575473, 0.14607605146011338, 0.1691538459272124, 0.11567043926334009, 0.12310466612689197, 0.136218489788007, 0.20902154414216056, 0.10499761352548376, 0.1886806418769993, 0.15447793499333784, 0.22438368934672326, 0.2363683353178203, 0.11165306772454642, 0.14424049761146307, 0.09642744800657965, 0.11290584268863313, 0.1451024872949347, 0.11844152220874093, 0.12340845685685053, 0.1559771623578854, 0.11330832421663217, 0.1140214316546917, 0.10326129224267788], [0.0451523759693373, 0.026073063527292106, 0.10041201661806554, 0.049269091396126896, 0.11531542550073937, 0.04202968942990992, 0.045315945317270234, 0.008984496362245409, 0.059679111509467475, 0.05172441276954487, 0.013916093648731476, 0.015605558510287665, 0.023302136432903353, 0.03675310108519625, 0.03420050270506181, 0.03116288484307006, 0.023787380414432846, 0.08725786465220153, 0.028771813049388584, 0.05484486173372716, 0.09378978837048635, 0.016446664158138447, 0.03415644881897606, 0.06577719424967654, 0.04496494657360017, 0.03919832182873506, 0.049967712111538276, 0.03231641239835881, 0.04505331780819688, 0.05354780652851332, 0.02225210137112299, 0.09880284749669954, 0.033854127541417256, 0.05389562888012733, 0.06353069838951342, 0.0870113899873104, 0.019351955234014895, 0.046189226777642034, 0.010396370162197854, 0.04293526915716939, 0.015696994814788923, 0.10976480654790066, 0.018960496454383247, 0.07239854676299728, 0.026272957293258514, 0.02451043634209782, 0.017925803440448362, 0.051859902960131876, 0.07563724953797646, 0.01008087854643236, 0.02857834071619436, 0.04873548721661791, 0.06903334491653368, 0.03512975323246792, 0.01603160137165105, 0.0626884498342406, 0.03286053652118426, 0.06585121605894528, 0.24484075256623328, 6.350761195644736, 19.31307166814804, 36.385620161890984, 57.45108559727669, 68.91326934099197, 78.45379739999771, 76.53704345226288, 82.8866395354271, 61.21253415942192, 63.57337787747383, 71.33396744728088, 66.21615886688232, 58.75394828617573, 60.28298243880272, 54.06248822808266, 46.366487592458725, 41.13619364798069, 39.87272344529629, 28.867478482425213, 43.1031809002161, 75.68960532546043, 43.28293785452843, 21.769850738346577, 23.839916959404945, 27.28002056479454, 24.45273667573929, 28.961496837437153, 27.103537134826183, 23.475915491580963, 23.240459226071835, 27.614833898842335, 30.058228187263012, 31.042690761387348, 30.398418232798576, 50.08502505719662, 42.66135960817337, 38.50187860429287, 52.40557573735714, 43.07944357395172, 51.39610290527344, 56.2401931732893, 47.2068352997303, 59.12031702697277, 71.77575454115868, 73.87750536203384, 71.74828961491585, 55.05149535834789, 34.02163401246071, 22.30530470609665, 10.084656961262226, 2.214302681386471, 0.8336868428159505, 0.2097805534140207, 0.08592369835241698, 0.3102584579028189, 0.03850415399938356, 0.08643069653771818, 0.010093505261465907, 0.10881174050155096, 0.024440806191705633, 0.044471169749158435, 0.035827668907586485, 0.019012179618584923, 0.025914637262758333, 0.06775627203751355, 0.04682680213591084, 0.05122897353430744, 0.010541373758314876, 0.11754024322726764, 0.04964680003467947, 0.07830012735212222, 0.023110964757506736, 0.03461794593022205, 0.03975583429564722, 0.011675014538923278, 0.02728851031861268, 0.011484894857858308, 0.029406833564280532, 0.07136338434065692, 0.05615425885480363, 0.042278750479454175, 0.010674048426153604, 0.01568717805639608, 0.046700013626832515, 0.060303094433038495, 0.056343706892221235, 0.014818458948866464, 0.023992081441974733, 0.08824600459774956, 0.04025273556180764, 0.018324429511267226, 0.009095229434024077, 0.059543951574596576, 0.015159649283305043, 0.04228871752275154, 0.05440484237624332, 0.04281990601157304, 0.02624166834721109, 0.030416458685067482, 0.005115644344186876, 0.04806882709090132, 0.03270123452239204, 0.02865592483431101, 0.003495135902085167, 0.020448487703106366, 0.05516801880730782, 0.058584380603861064, 0.0341692991059972, 0.008814130796963582, 0.03325467630929779, 0.038398705946747214, 0.06086305969802197, 0.01785634955012938, 0.01885277742985636, 0.029344591494009364, 0.048837487993296236, 0.04235222681018058, 0.03381013673788402, 0.05207732625422068, 0.023061810461513232, 0.09611152316210791, 0.04851232712098863, 0.05253239636658691, 0.03164792658935767, 0.038056030389270745, 0.010123770971404156, 0.050352411781204864, 0.03606232115998864, 0.0420813058008207, 0.02987072781252209, 0.054741313579143025, 0.05710020399419591, 0.007293164535440155, 0.07135266772820614, 0.019054342883464415, 0.060612158122239634, 0.05961602153547574, 0.029858324669476133, 0.038993014095467515, 0.012865392509411322, 0.06562789640156552, 0.015022293518995866, 0.02392884674918605, 0.07635210844455287, 0.13318084966158494, 0.05850826964888256, 0.020428648240340408, 0.035288272265461273, 0.042577717249514535, 0.0752851004654076, 0.043557838289416395, 0.0422485562012298, 0.06039147679985035, 0.011192572164873127, 0.034121248754672706, 0.046347753232112154, 0.054550815402762964, 0.0380355025845347, 0.06744762024027295, 0.02990905417391332, 0.013040906724199886, 0.01246984913450433, 0.05964970761851873, 0.019007789815077558, 0.037949580437270924, 0.14243403595173731, 0.027295714717183728, 0.006717937931171036, 0.03480414336081594, 0.08383090127608739, 0.03915067223715596, 0.04775011919264216, 0.06228404614375904, 0.01338147829301306, 0.0668978966132272, 0.4926619998877868, 7.907705325633287, 24.19785775244236, 44.2858712375164, 63.47529374063015, 77.2596886754036, 87.51864418387413, 85.65032243728638, 89.19154241681099, 69.61086630821228, 75.94281613826752, 81.87153920531273, 75.8440974354744, 69.07300516963005, 71.27563297748566, 67.89860978722572, 57.42684289813042, 52.60764129459858, 52.917184084653854, 43.457671478390694, 50.8225616812706, 84.34892266988754, 59.092441722750664, 29.085142202675343, 36.30965083837509, 36.917865201830864, 39.30795215070248, 48.25171083211899, 40.60927972197533, 36.630957797169685, 39.1516475379467, 44.92924891412258, 48.447951301932335, 45.96159651875496, 47.05586180090904, 62.50534638762474, 54.11274053156376, 52.35163003206253, 59.70411770045757, 57.475111708045006, 63.78665283322334, 68.59717190265656, 56.9846036285162, 72.46542513370514, 81.12332135438919, 85.44156163930893, 83.29719990491867, 67.99535259604454, 44.66505669057369, 28.84274560958147, 13.666479662060738, 3.0830507772043347, 0.9604830702301115, 0.20403650851221755, 0.12150605776696466, 0.22188211733009666, 0.03887278988258913, 0.01904594733787235, 0.03272818561526947, 0.06464645804953761, 0.07176078215707093, 0.03379707493877504, 0.05430797355074901, 0.03963561379350722, 0.04398834331368562, 0.0272971155209234, 0.04056906858750153, 0.019202219518774655, 0.02261059395095799, 0.021627606365655083, 0.018799489371303935, 0.004157692646913347, 0.032923051330726594, 0.012669214120251127, 0.05146348848938942, 0.024304970902448986, 0.06632507735048421, 0.02909352107963059, 0.026581130405247677, 0.031018583504192065, 0.02210034701420227, 0.04118333679798525, 0.009599263667041669, 0.015901790466159582, 0.02971571171656251, 0.03006546921824338, 0.02280219050589949, 0.05115014260809403, 0.03373131694388576, 0.09010821639094502, 0.04228645768307615, 0.039905462399474345, 0.021830396362929605, 0.038055525728850625, 0.02007485345529858, 0.03803852312557865, 0.11548323251190595, 0.08747537329327315, 0.010322648922738153, 0.04009550786577165, 0.06816341425292194, 0.014112738663243363, 0.025655688950791955, 0.04044356770464219, 0.03067190591536928, 0.04674637930293102, 0.02321444797416916, 0.012065097562299343, 0.03900027229974512, 0.05583909842243884, 0.06528872007038444, 0.030164571908244397, 0.028912975103594363, 0.06500940537080169, 0.07477737497538328, 0.04548558543319814, 0.04239429174049292, 0.033419963729102165, 0.14995589561294764, 0.13114395114826038, 0.20482692547375336, 0.14625338022597134, 0.1733553220401518, 0.16279746982036158, 0.09607437124941498, 0.12483732862165198, 0.18072499689878896, 0.13597668323200196, 0.0756751287553925, 0.22967196651734412, 0.12016266657155938, 0.10682724503567442, 0.1548300395370461, 0.09695938235381618, 0.1545534559409134, 0.1511982359807007, 0.17932573682628572, 0.21654733718605712, 0.1398943769163452, 0.16786483931355178, 0.1114961109124124, 0.14441738108871505, 0.09842815197771415, 0.1775009441189468, 0.19015612051589414, 0.24000539327971637, 0.20349144557258114, 0.2176314516691491, 0.08907851617550477, 0.2089553594123572, 0.17672652786131948, 0.1924198935739696, 0.18735267251031473, 0.15285371511708945, 0.10535713212448172, 0.1342536389711313, 0.13633732247399166, 0.10000482987379655, 0.1387875378713943, 0.23822815739549696, 0.12073659163434058, 0.15989308973075822, 0.09210112038999796, 0.12581881892401725, 0.13686451449757442, 0.09561868515447713, 0.23833190964069217, 0.12925273622386158, 0.12756942654959857, 0.157224029826466, 0.19739146664505824, 0.1116290815116372, 0.16829774889629334, 0.18970557750435546, 0.12886873417301103, 0.18738787999609485, 0.9589643392246217, 12.05726221203804, 32.41296373307705, 56.45281836390495, 78.6771722137928, 93.47797080874443, 101.23871237039566, 98.56596618890762, 101.78511545062065, 84.71203118562698, 86.16126582026482, 91.81819707155228, 89.21539753675461, 81.48132294416428, 83.38217854499817, 76.46959707140923, 67.88868471980095, 61.66064791381359, 61.04455277323723, 48.18978555500507, 61.121924221515656, 90.97905769944191, 61.851758658885956, 38.14196951687336, 41.08874939382076, 45.218656584620476, 38.55610549449921, 44.948365688323975, 45.36576189100742, 39.118919894099236, 39.48953300714493, 44.53981541097164, 50.20781546831131, 52.494506165385246, 48.43033544719219, 68.25756892561913, 61.401585415005684, 59.22964856028557, 74.76331382989883, 63.27621102333069, 73.93150806427002, 76.08973145484924, 70.53886011242867, 83.52280139923096, 95.60022532939911, 98.64788219332695, 97.9090042412281, 78.85383993387222, 55.814277827739716, 38.19051191210747, 20.262486822903156, 4.871748508885503, 1.1308300076052547, 0.3425928228534758, 0.25241846626158804, 0.39878919487819076, 0.13615466508781537, 0.19035703473491594, 0.14933160098735243, 0.15663568483432755, 0.2309098985278979, 0.18193915049778298, 0.11651332606561482, 0.09487828894634731, 0.0750963574682828, 0.1143460618914105, 0.12728524336125702, 0.1238349245977588, 0.09093959248275496, 0.1569942757487297, 0.1400693308096379, 0.19020339532289654, 0.1588834126596339, 0.1322065878775902, 0.09299771641963162, 0.17580121813807636, 0.14812967798206955, 0.10421701517770998, 0.12447930173948407, 0.20362170733278617, 0.17170113424072042, 0.1060198328923434, 0.07953658248879947, 0.08369357427000068, 0.1797436995548196, 0.11915122318896465, 0.10222026685369201, 0.1849768648389727, 0.09992582825361751, 0.19458258611848578, 0.15594937634887174, 0.17713393724989146, 0.09074130546650849, 0.17043053288944066, 0.0967093750659842, 0.10078696446726099, 0.21492669446161017, 0.12485656508943066, 0.08955947239883244, 0.13744606141699478, 0.2327963785501197, 0.14712736301589757, 0.11563171399757266, 0.12852373940404505, 0.18407494761049747, 0.1117639297444839, 0.1174859625461977, 0.17665945255430415, 0.10437020187964663, 0.14866086276015267, 0.13200248242355883, 0.09633498382754624, 0.20422057597897947, 0.1034006527333986, 0.14964932925067842, 0.17668211774434894, 0.16546899365494028, 0.15180563932517543], [0.07122986455215141, 0.006683822330160183, 0.03310864391096402, 0.030576430472137872, 0.011224664485780522, 0.03303013581898995, 0.03578149618988391, 0.05094635627756361, 0.03740651758562308, 0.07504945373511873, 0.03064396405534353, 0.03638553018390667, 0.027926946568186395, 0.055543170747114345, 0.02129184391378658, 0.07105827258783393, 0.03418433501792606, 0.08399092315812595, 0.01334856589892297, 0.08290836718515493, 0.03705396033183206, 0.031541027638013475, 0.06548066914547235, 0.009345979797217296, 0.050347799333394505, 0.10949232702841982, 0.05641012539854273, 0.02809881498251343, 0.01052562167387805, 0.04283116810256615, 0.05924491801124532, 0.040677333090570755, 0.020942860101058614, 0.08849906953400932, 0.016925512682064436, 0.04430933702678885, 0.08538428315659985, 0.057410195367992856, 0.029487668289220892, 0.01907976700749714, 0.02894384288083529, 0.033862951677292585, 0.023139363038353622, 0.046792062203167006, 0.047552778414683416, 0.006946963776499615, 0.016332191589754075, 0.00468544313662278, 0.01585873291332973, 0.013393235767580336, 0.05122799761011265, 0.12337922365986742, 0.019666377229441423, 0.05045498772233259, 0.09191012126393616, 0.026324369573558215, 0.46559801150579005, 4.864163640886545, 18.729493282735348, 50.85123114287853, 80.10629072785378, 75.3323332965374, 73.41992631554604, 72.28729829192162, 67.84841448068619, 57.92508356273174, 56.1896026879549, 46.239901185035706, 32.84932851791382, 53.08118708431721, 49.129851311445236, 49.701283648610115, 31.742438413202763, 25.501744486391544, 24.070758372545242, 18.873347863554955, 18.526285886764526, 12.199765015393496, 23.5267548635602, 26.580994874238968, 19.124825969338417, 25.431976430118084, 23.832480758428574, 17.946104519069195, 22.693833857774734, 24.269449710845947, 24.594016894698143, 20.49846936017275, 14.496202189475298, 12.028591800481081, 14.14658010005951, 11.890957485884428, 13.991141840815544, 22.464404068887234, 18.75458713620901, 23.70446752756834, 20.507613569498062, 11.308384146541357, 19.8105675727129, 31.64473805576563, 31.93437561392784, 34.56662356853485, 54.23442520201206, 58.01470935344696, 66.91967591643333, 63.42399649322033, 69.48511585593224, 60.33806048333645, 48.36070418357849, 32.09313489496708, 18.332745172083378, 8.498350381851196, 4.5301230903714895, 0.8574210223741829, 0.3397064027376473, 0.06714785937219858, 0.03977302985731512, 0.03924499549611937, 0.007825735738151707, 0.10863873845664784, 0.03785245557082817, 0.01552223944599973, 0.02197761248680763, 0.028020850513712503, 0.023246065320563503, 0.09950532738002948, 0.03640842543973122, 0.028620273915294092, 0.04793570435140282, 0.04297854749893304, 0.02926787012256682, 0.013223046462371713, 0.03150767552142497, 0.003930265202143346, 0.06235813474631868, 0.0502667085675057, 0.008524925124220317, 0.03371636266820133, 0.018449281014909502, 0.07530933900852688, 0.008391829287575092, 0.02348342826735461, 0.022815771808382124, 0.06644512715865858, 0.028468384116422385, 0.005942876932749641, 0.024738229294598568, 0.035854107918567024, 0.02672711827472085, 0.04188948660157621, 0.06192766682943329, 0.06455281385569833, 0.056536750635132194, 0.06421092126402073, 0.027318745414959267, 0.04089235924766399, 0.06823729505413212, 0.05722462505218573, 0.024892250912671443, 0.037398984786705114, 0.05169763237063307, 0.054902385600144044, 0.06252100647543557, 0.038005950264050625, 0.028132836887380108, 0.0070023187163315015, 0.0022321891083265655, 0.04955141179380007, 0.016767566958151292, 0.04297986852179747, 0.018653056213224772, 0.09003420200315304, 0.017885890738398302, 0.03173834615154192, 0.09623777732485905, 0.05191550837480463, 0.15843034634599462, 0.04005236682132818, 0.012098486786271678, 0.07035588176222518, 0.03092285758611979, 0.04263353046553675, 0.07639345349161886, 0.016989892137644347, 0.04891833013971336, 0.08511827516485937, 0.11038900469429791, 0.09584636864019558, 0.052159233382553793, 0.07651024527149275, 0.025980879509006627, 0.056838849268388, 0.02455771857057698, 0.004729467336801463, 0.02394815001025563, 0.05533787785680033, 0.04584808004437946, 0.05404419942351524, 0.08060784297413193, 0.06102781648223754, 0.010894749229919398, 0.051385941478656605, 0.020410042598086875, 0.06092326271755155, 0.037351142236730084, 0.021940677652310114, 0.06029925752955023, 0.04834072031371761, 0.01868636936706025, 0.06782517302781343, 0.021470365682034753, 0.01976185081730364, 0.06531778257340193, 0.09987353652832098, 0.023623792512807995, 0.07808393231243826, 0.0496531008684542, 0.05629878840409219, 0.04618948281859048, 0.03208541151252575, 0.06244601245271042, 0.008043289835768519, 0.026521324434725102, 0.02859289052139502, 0.032376084782299586, 0.05243965017143637, 0.04529950674623251, 0.09996806387789547, 0.03335601286380552, 0.052174944648868404, 0.05517845340364147, 0.06058047954866197, 0.45563533203676343, 8.123794980347157, 25.11435717344284, 60.589002817869186, 90.05312338471413, 84.80723887681961, 83.97563830018044, 83.3206370472908, 77.41369441151619, 71.22838631272316, 66.55719816684723, 58.12996096909046, 45.85052087903023, 61.956503838300705, 56.20721094310284, 62.48372174799442, 40.55387869477272, 35.521200746297836, 38.03846687078476, 28.219419457018375, 29.37986008822918, 25.88578797876835, 34.859230667352676, 36.07019528746605, 32.8611458837986, 34.32080715894699, 38.45434695482254, 30.18314838409424, 28.19532684981823, 26.351118609309196, 32.3797383159399, 29.60023306310177, 25.518190003931522, 23.13480779528618, 26.20285626500845, 25.582393258810043, 22.482542395591736, 37.52808965742588, 39.67363692820072, 41.62908039987087, 42.99266763031483, 24.930602833628654, 38.80893252789974, 46.24918408691883, 44.7408664226532, 43.15179169178009, 67.7907107770443, 68.85140866041183, 75.70010036230087, 70.96279576420784, 80.50827875733376, 71.9940148293972, 56.962450817227364, 38.2408782094717, 24.6046145260334, 11.079822611063719, 5.124404551461339, 0.9731216670479625, 0.28118544607423246, 0.07631876374944113, 0.02417452917143237, 0.034905535576399416, 0.0330746980762342, 0.06819308531703427, 0.09090399908018298, 0.03243166793254204, 0.08029683856875636, 0.033111278535216115, 0.04575060636852868, 0.08080698346020654, 0.025547795521561056, 0.020466560854401905, 0.017872751013783272, 0.02962450176710263, 0.0333250319090439, 0.1036253156780731, 0.07628979772562161, 0.0635820253228303, 0.08883726623025723, 0.03286872241005767, 0.0505699167115381, 0.02427649469609605, 0.04347945636254735, 0.03247666434617713, 0.04232180246617645, 0.06236141503904946, 0.030262730215326883, 0.02926435976405628, 0.03961952403187752, 0.0421750353416428, 0.05067986960057169, 0.023597615108883474, 0.03668932091386523, 0.0673020034446381, 0.06760997988749295, 0.0798241795564536, 0.040193630920839496, 0.04060082879732363, 0.021865548187633976, 0.03648516722023487, 0.10597184562357143, 0.13200565881561488, 0.06598767475225031, 0.05064772718469612, 0.05040162730438169, 0.06568554643308744, 0.029258467111503705, 0.039247303575393744, 0.06220585717528593, 0.06789863822632469, 0.04873359102930408, 0.02393745195149677, 0.01262915020561195, 0.03687159980472643, 0.005129235851200065, 0.09067115766811185, 0.04376121643872466, 0.041042250813916326, 0.06527105695568025, 0.06215343928488437, 0.2462008420843631, 0.162259086209815, 0.11361628581653349, 0.15981071133865044, 0.2016783194267191, 0.10763453101390041, 0.12965049769263715, 0.17356144613586366, 0.07698134577367455, 0.1719568931730464, 0.13797651889035478, 0.17405049176886678, 0.15270348958438262, 0.2271145404665731, 0.13378173694945872, 0.19239452696638182, 0.0909828300063964, 0.09633602283429354, 0.11980256167589687, 0.1613190077478066, 0.17608926049433649, 0.11375842193956487, 0.1851165815605782, 0.10137007731827907, 0.12993070296943188, 0.20504333573626354, 0.23684071231400594, 0.16107816598378122, 0.17125272861449048, 0.11813933451776393, 0.26258909550961107, 0.1425068109529093, 0.18360662274062634, 0.2428475220222026, 0.06308892014203593, 0.1701659127138555, 0.18131994700524956, 0.24230226612417027, 0.11310481990221888, 0.13819561572745442, 0.12342892528977245, 0.16535789414774626, 0.1095466893457342, 0.07871287278248928, 0.18849673768272623, 0.052531487235683016, 0.10387092203018256, 0.1246148327481933, 0.09355549977044575, 0.11474209415609948, 0.07384569020359777, 0.17189474572660401, 0.1771543314680457, 0.08182970006600954, 0.14919149834895507, 0.14521415083436295, 0.8897683897521347, 11.472106911242008, 37.14000128209591, 74.39529597759247, 106.41898959875107, 96.44534558057785, 94.16997447609901, 93.0563834309578, 88.48098054528236, 79.23229962587357, 74.70459938049316, 64.53639060258865, 50.58321252465248, 74.52337950468063, 68.99174273014069, 72.57526963949203, 48.88670615851879, 44.92590129375458, 39.3481881916523, 34.647186845541, 32.022196501493454, 22.740293964743614, 35.09752728044987, 42.494491562247276, 32.2891815751791, 40.31168729066849, 37.459184154868126, 34.0184535831213, 38.789743557572365, 38.12916800379753, 40.59037193655968, 33.41506116092205, 24.32844154536724, 22.815539427101612, 27.375416345894337, 25.395249500870705, 24.617127254605293, 36.69883355498314, 33.65187205374241, 40.25567069649696, 37.84048229455948, 23.95014714449644, 36.39198862016201, 48.04283984005451, 47.31171727180481, 52.95541003346443, 77.84262299537659, 79.44967836141586, 87.25524991750717, 82.8603221476078, 90.42906001210213, 81.94555163383484, 68.86922970414162, 48.551051169633865, 32.174416333436966, 16.15294273942709, 9.115885645151138, 3.003782518208027, 0.8246602490544319, 0.33424024761188775, 0.13063442223938182, 0.2163090929389, 0.06818507012212649, 0.15436122484970838, 0.20404939219588414, 0.12377230217680335, 0.13304376014275476, 0.1344589318614453, 0.15151584550039843, 0.23011510289506987, 0.16455382166896015, 0.17741093644872308, 0.18560700758825988, 0.12146595210651867, 0.17519385932246223, 0.17609214002732188, 0.1275473550776951, 0.14194709801813588, 0.1972502507851459, 0.11918370699277148, 0.18834023358067498, 0.2104937276453711, 0.18052605679258704, 0.11745045077987015, 0.15979141549905762, 0.1571733262971975, 0.10249550716252998, 0.1439749274868518, 0.103896585496841, 0.10324060858692974, 0.1144019010826014, 0.17927969398442656, 0.09039847776875831, 0.10264833763358183, 0.22410274192225188, 0.13410783663857728, 0.16312555846525356, 0.1336967313545756, 0.10554087304626592, 0.08166514366166666, 0.14980613021180034, 0.2817867341218516, 0.1303045524400659, 0.1956406215322204, 0.10346947208745405, 0.1442489432520233, 0.1320720513467677, 0.18581630807602778, 0.19335994235007092, 0.13918344397097826, 0.1489356652018614, 0.1693839265499264, 0.09789638090296648, 0.16036263172281906, 0.13073646754492074, 0.17411214939784259, 0.09389415659825318, 0.12435621654731221, 0.13685596495633945, 0.2114362848806195], [0.025978202211263124, 0.0586741619190434, 0.06757830502465367, 0.007664081595066818, 0.017673580841801595, 0.009684930701041594, 0.0076427726799011, 0.0373759707872523, 0.0024274987208627863, 0.07050061540212482, 0.052043836840312, 0.05554363830015063, 0.11097175389295444, 0.02215898595750332, 0.10590195015538484, 0.08016833569854498, 0.02001630356971873, 0.05935615852649789, 0.05153074562258553, 0.01567480830999557, 0.009823273521760711, 0.08577761400374584, 0.034449211234459653, 0.016928130607993808, 0.0856575122452341, 0.04010415759694297, 0.03577374816813972, 0.03923496165953111, 0.0357632616214687, 0.013270986419229303, 0.04558889981126413, 0.028026162435708102, 0.05445245486043859, 0.05393246166931931, 0.035848163315677084, 0.017070745416276623, 0.05769814866653178, 0.013429334758257028, 0.007938907692732755, 0.013075290426058928, 0.034656133138923906, 0.00876047444762662, 0.060157132538734004, 0.047410363986273296, 0.037728030802099966, 0.05579627279075794, 0.01777650002622977, 0.012935950344399316, 0.02307486854988383, 0.057335706005687825, 0.04162969780736603, 0.06062238120648544, 0.15289462229702622, 0.21323715074686334, 1.8290369608439505, 7.847007857635617, 27.04410832375288, 56.740557923913, 75.20852833986282, 74.45173814892769, 64.2462457716465, 65.66936060786247, 55.380398109555244, 43.93238380551338, 41.84723049402237, 31.39604900032282, 30.99263794720173, 17.151329666376114, 19.44926206022501, 21.883867420256138, 35.82322373986244, 22.220331765711308, 23.718091696500778, 38.16473789513111, 13.296931441873312, 16.572932302951813, 20.185977928340435, 29.560937471687794, 33.9195790886879, 33.216840997338295, 34.881182089447975, 39.05847653746605, 43.86377088725567, 46.37350581586361, 44.64614510536194, 55.48295460641384, 36.3106843829155, 38.60601581633091, 60.503780990839005, 50.17511822283268, 38.003390952944756, 29.591370038688183, 35.81553295254707, 19.39110618084669, 14.970668479800224, 17.104183696210384, 11.26961862668395, 17.90388498455286, 12.094206679612398, 13.977320082485676, 14.980770237743855, 30.69486692547798, 22.61733066290617, 25.381745025515556, 38.7417521327734, 48.66109326481819, 53.05307239294052, 63.320284858345985, 66.68585926294327, 71.50644779205322, 62.02787160873413, 50.02814210951328, 38.551576137542725, 23.028164617717266, 11.232691258192062, 4.315537679940462, 1.1844627046957612, 0.2593176194932312, 0.1705055491765961, 0.05553320741455536, 0.04652643641748, 0.04028787625429686, 0.038737552022212185, 0.05956661676464137, 0.027806850375782233, 0.03175695921527222, 0.018943419636343606, 0.07333047644351609, 0.062097533300402574, 0.05932715539529454, 0.01922220370033756, 0.01967679512745235, 0.0249297738992027, 0.025677168559923302, 0.052030121951247565, 0.03783308551646769, 0.04212124076730106, 0.025574395949661266, 0.029397840589808766, 0.027627328563539777, 0.055766902296454646, 0.05331078682502266, 0.012149816502642352, 0.059133506802027114, 0.02662880226125708, 0.015879702295933384, 0.014058873584872345, 0.012295345168240601, 0.02972537633468164, 0.018756224017124623, 0.024973927975224797, 0.03803795167186763, 0.0530614845774835, 0.04923267049889546, 0.03754854609724134, 0.01595042340341024, 0.014036569264135323, 0.04179302224656567, 0.016186285356525332, 0.01862872490164591, 0.048888818637351505, 0.037195027762209065, 0.04998809519747738, 0.07220224128104746, 0.060128237018943764, 0.011478768428787589, 0.018514469411456957, 0.020761863270308822, 0.011978221755271079, 0.0324622852349421, 0.025125747270067222, 0.028960268464288674, 0.0816785691131372, 0.05990360376017634, 0.03699072934978176, 0.03693306447530631, 0.06263218761887401, 0.01013274446449941, 0.07367147103650495, 0.03785736487770919, 0.025717919888847973, 0.04171454755123705, 0.04434041817148682, 0.028381378433550708, 0.019481215094856452, 0.0555343280575471, 0.03045459950953955, 0.018234748386021238, 0.053841385306441225, 0.004163328330832883, 0.07296014475286938, 0.03369168996869121, 0.015240240954881301, 0.036147430655546486, 0.020250096786185168, 0.03261590609326959, 0.00417069229115441, 0.024941321717051324, 0.03600865646149032, 0.04606745147611946, 0.052043617906747386, 0.055795155858504586, 0.006484936957349419, 0.029161817219574004, 0.02617101217765594, 0.07478924933820963, 0.05530016933334991, 0.03920994386135135, 0.1459942222572863, 0.021787244186270982, 0.04106132029846776, 0.06543529423652217, 0.024187435119529255, 0.014711140684084967, 0.053252713769325055, 0.07035390022792853, 0.026785914924403187, 0.03154551020998042, 0.05707195414288435, 0.028053864953108132, 0.061945467241457663, 0.04586350929457694, 0.04277372958313208, 0.034304525834158994, 0.03979974346293602, 0.03237360971979797, 0.0053642596412828425, 0.03885779849952087, 0.15361879515694454, 0.31398243620060384, 2.382983467541635, 10.993289854377508, 34.33682709932327, 69.60989356040955, 84.71154481172562, 83.02705720067024, 74.80412364006042, 77.84545764327049, 64.90320011973381, 56.92181959748268, 54.2842785269022, 39.08931188285351, 42.98578999936581, 29.881102591753006, 26.874658316373825, 40.427562072873116, 47.63823375105858, 29.503889232873917, 31.50390051305294, 40.543866232037544, 18.991405628621578, 20.635824389755726, 31.83642826974392, 30.79142354428768, 26.635675840079784, 37.92962931096554, 31.516958512365818, 35.19393190741539, 38.62389385700226, 37.140331864356995, 39.39411632716656, 39.23588141798973, 37.241820618510246, 34.82146829366684, 35.65191373229027, 37.24281996488571, 29.344784170389175, 25.987377427518368, 32.858835607767105, 25.40543295443058, 14.148209262639284, 19.57500871270895, 18.78859531134367, 24.01541244238615, 24.90251664072275, 25.948256626725197, 31.837197728455067, 42.21532814204693, 36.96978181600571, 35.506639927625656, 48.87076981365681, 59.42196384072304, 63.50254587829113, 73.16078022122383, 77.74915561079979, 82.35007032752037, 73.3305399119854, 58.3017535507679, 46.89706452190876, 26.837667301297188, 14.896971434354782, 4.865748155862093, 1.1793163558468223, 0.23808738682419062, 0.180108479980845, 0.0429403565794928, 0.0137827213620767, 0.09627375664422289, 0.05273299146210775, 0.027420627448009327, 0.03224374129786156, 0.05635333254758734, 0.014205740899342345, 0.040713468260946684, 0.06395407879608683, 0.04864516784437001, 0.009786989921849454, 0.10766574574518017, 0.028760738350683823, 0.04159578908002004, 0.02648947516718181, 0.052040530572412536, 0.01921698454680154, 0.03562879188393708, 0.049159279515151866, 0.027915697464777622, 0.06789741368265823, 0.021148917403479572, 0.04709302163973916, 0.03858882933855057, 0.07366998674115166, 0.036871811316814274, 0.03284448757767677, 0.057115221352432854, 0.023559576329716947, 0.036926425964338705, 0.032511797617189586, 0.06782909156754613, 0.05480424399138428, 0.037019012597738765, 0.0755154259968549, 0.027806683392554987, 0.03458987790509127, 0.045345267571974546, 0.05532644507184159, 0.03344202406879049, 0.05785822249890771, 0.04746823295135982, 0.01660981975874165, 0.045786166374455206, 0.0469770425115712, 0.028348508712952025, 0.010422742379887495, 0.019846585528284777, 0.07799932005582377, 0.05978960616630502, 0.006697586386508192, 0.15177613153355196, 0.05912572167289909, 0.05425057213869877, 0.04864753158472013, 0.04022353947220836, 0.132073535642121, 0.18500818347092718, 0.11301059683319181, 0.09781302287592553, 0.21033719385741279, 0.09296903241192922, 0.1092813492869027, 0.08493848246871494, 0.09361691249068826, 0.21042889362433925, 0.13128535996656865, 0.22824422281701118, 0.32408247236162424, 0.19694154703756794, 0.16183710104087368, 0.13131926127243787, 0.14331768150441349, 0.23734939517453313, 0.16947206400800496, 0.09714848158182576, 0.11024013729183935, 0.1264317290042527, 0.0971159829350654, 0.14047050615772605, 0.15620909834979102, 0.11207073359400965, 0.1308380378759466, 0.16633942897897214, 0.13976135436678305, 0.1468461484182626, 0.15695768786827102, 0.17003125743940473, 0.19055379292694852, 0.2921433455776423, 0.1361491731950082, 0.10916280603851192, 0.09089777988265269, 0.11761657311581075, 0.10792566070449539, 0.12581249582581222, 0.0953053504053969, 0.11958710878388956, 0.21026666014222428, 0.08160407975083217, 0.19214659027056769, 0.14995968056609854, 0.09716377724544145, 0.12063600093824789, 0.06258880908717401, 0.09537790276226588, 0.11763213595259003, 0.1955011422978714, 0.3292100894032046, 0.5453082639724016, 3.194719897583127, 15.081974007189274, 45.98803550004959, 81.87659293413162, 97.93349772691727, 92.53999873995781, 83.06590631604195, 86.40360921621323, 77.47982606291771, 62.84048080444336, 61.93563535809517, 48.37315611541271, 49.10482585430145, 32.23075211048126, 34.25276800990105, 39.22945596277714, 53.2621143758297, 37.889845445752144, 41.62123382091522, 54.45065259933472, 24.76851873099804, 32.07831189036369, 35.6605164706707, 44.95078235864639, 46.278172731399536, 46.66714645922184, 52.671728655695915, 55.124531239271164, 60.23162439465523, 65.75133740901947, 65.52338764071465, 76.84411257505417, 55.569559559226036, 58.41952063143253, 79.28437203168869, 69.5445066690445, 54.036847203969955, 44.44091431796551, 54.323112443089485, 31.28860406577587, 22.89156574755907, 27.56124347448349, 18.494130112230778, 27.70630069077015, 24.356461241841316, 27.525935769081116, 26.662587895989418, 48.703517988324165, 39.74679820239544, 44.558160826563835, 58.835324719548225, 68.20681884884834, 74.63412836194038, 85.95983102917671, 87.97294020652771, 93.25091779232025, 88.64158272743225, 70.6923870742321, 55.9952013194561, 36.64101205766201, 20.863555669784546, 8.230204470455647, 2.4460534332320094, 0.4116296855499968, 0.3217885532649234, 0.2552656119223684, 0.17675328970653936, 0.12118337195715867, 0.1404930229182355, 0.12430791757651605, 0.08043933092267253, 0.0876643018273171, 0.09086105099413544, 0.1372519601136446, 0.20117938838666305, 0.1224852770974394, 0.08544274212908931, 0.17805369570851326, 0.12889898411231115, 0.13957139424746856, 0.13107481267070398, 0.1037092600017786, 0.16043551062466577, 0.12590504164109007, 0.10008103359723464, 0.1636576486635022, 0.17032379721058533, 0.25518599431961775, 0.11793980811489746, 0.1459718242404051, 0.18294339504791424, 0.10806761871208437, 0.11528611808898859, 0.2514928299933672, 0.1397607012768276, 0.10852600622456521, 0.10730242735007778, 0.2344117223401554, 0.14398837520275265, 0.10370198695454746, 0.21331734722480178, 0.0880039382900577, 0.17193456937093288, 0.1353031100006774, 0.10417745128506795, 0.07967057725181803, 0.14669148484244943, 0.13895076583139598, 0.11440097339800559, 0.21434208989376202, 0.29928423115052283, 0.14955326565541327, 0.11684377474011853, 0.06594912018044852, 0.11612899004830979, 0.23769283143337816, 0.13309471600223333, 0.2636203245492652, 0.13286721805343404, 0.20896705565974116, 0.11970998617471196, 0.11720287031494081], [0.011828883089037845, 0.006107636500018998, 0.06709485518513247, 0.03793779884290416, 0.061589893157361075, 0.0350865119980881, 0.02949831625301158, 0.07666180667001754, 0.01668132568738656, 0.010453454306116328, 0.0658928653865587, 0.036237686945241876, 0.04332593198341783, 0.09097089627175592, 0.04931084833515342, 0.019388608052395284, 0.007689792373639648, 0.10307283126167022, 0.03759639606869314, 0.0029965896192152286, 0.056004229991231114, 0.01769222173606977, 0.04874662685324438, 0.08251582301454619, 0.048014572385000065, 0.022962559341976885, 0.03035773439478362, 0.04148288244323339, 0.040078241800074466, 0.02462130392814288, 0.037645515112672, 0.09125964366830885, 0.01164523586339783, 0.04794697757461108, 0.028664435412792955, 0.04752077329612803, 0.019704768528754357, 0.09325299295596778, 0.07202405162388459, 0.10799844312714413, 0.09973398307920434, 0.07042641547741368, 0.03458152132225223, 0.10987293746438809, 0.012743243350996636, 0.03841760473733302, 0.0643108737131115, 0.05253678988083266, 0.07466298033250496, 0.035291211170260794, 0.5596567690372467, 3.625677335076034, 6.683797650039196, 12.20777403563261, 38.841546177864075, 56.087680757045746, 76.13039687275887, 72.96301603317261, 64.0136830508709, 56.38062223792076, 38.98388274013996, 39.066353514790535, 33.98703686892986, 27.08698332309723, 21.47855456918478, 18.97658832371235, 19.236275888979435, 22.411459609866142, 29.56816278398037, 18.970419354736805, 19.366720989346504, 26.888985447585583, 34.4144531339407, 43.744768872857094, 51.42147794365883, 39.129973500967026, 49.91963133215904, 73.28178852796555, 78.3615231513977, 48.34400787949562, 70.00917613506317, 62.217823415994644, 65.49766302108765, 55.880280286073685, 42.70044431090355, 33.56778636574745, 40.38472697138786, 54.999403953552246, 75.19241720438004, 65.86535409092903, 69.53544795513153, 69.69051763415337, 58.91673535108566, 69.17162507772446, 85.48804074525833, 59.80617642402649, 64.6343569457531, 48.63401971757412, 55.34532979130745, 38.906803876161575, 15.202851220965385, 18.24534986168146, 15.816039517521858, 29.84583668410778, 24.33383535593748, 27.091740667819977, 32.69695669412613, 40.479733273386955, 56.76654472947121, 58.15947778522968, 61.470608711242676, 63.382848501205444, 68.14633369445801, 71.35301202535629, 56.36488348245621, 38.61667804419994, 20.92605471611023, 11.69801713898778, 5.704512298107147, 0.6242413097061217, 0.11617858777754009, 0.17144191690022126, 0.13838018785463646, 0.10808382721734233, 0.032857078113011084, 0.023767422208038624, 0.05461319291498512, 0.018608659083838575, 0.025501040217932314, 0.023805256896594074, 0.022800513252150267, 0.08472334127873182, 0.01658250501350267, 0.04323953115090262, 0.10540706382016651, 0.05353655928047374, 0.05671253573382273, 0.03508545814838726, 0.03403642127523199, 0.03678053086332511, 0.03238976998545695, 0.044220505660632625, 0.025134050047199707, 0.04066819354193285, 0.07311642621061765, 0.03480915656837169, 0.03637917368905619, 0.02409242166322656, 0.03039848572370829, 0.05016031427658163, 0.04849302757065743, 0.056293856832780875, 0.006327825685730204, 0.05799894854135346, 0.15632316644769162, 0.06813501968281344, 0.03956795590056572, 0.018173946082242765, 0.07205980087746866, 0.05560466139286291, 0.026031601591967046, 0.05472509023093153, 0.06741425328073092, 0.006131639875093242, 0.011106620331702288, 0.05201251078688074, 0.009938152415998047, 0.05105624979478307, 0.04130755376536399, 0.04303257213905454, 0.027646344242384657, 0.0170855790929636, 0.019808320394076873, 0.026316623407183215, 0.09011968257254921, 0.06212476269865874, 0.020478598489717115, 0.054660363821312785, 0.036108664571656846, 0.06391596951289102, 0.02618229467771016, 0.036768025674973615, 0.03961485592299141, 0.07105268421582878, 0.004029057581647066, 0.04171576467342675, 0.0651475264749024, 0.03361592782312073, 0.03644566641014535, 0.01932097613462247, 0.02281630615470931, 0.058572573034325615, 0.027074862700828817, 0.05185999943932984, 0.03489997689030133, 0.056812387992977165, 0.045668320744880475, 0.003036635444004787, 0.04461901669856161, 0.06925938825588673, 0.02248835109639913, 0.02044527791440487, 0.016924423580348957, 0.020940060348948464, 0.03474454519164283, 0.026927544531645253, 0.07670976425288245, 0.037657051798305474, 0.04703453669208102, 0.09037351934239268, 0.0412676484847907, 0.04615325859049335, 0.04143075399042573, 0.03466071961156558, 0.06271765334531665, 0.027984312728221994, 0.04357951271231286, 0.07476809070794843, 0.04539614550594706, 0.0351658550061984, 0.0609339867514791, 0.04307495248212945, 0.029623473892570473, 0.04166466780588962, 0.06849453086033463, 0.0070516335017600795, 0.5079352506436408, 3.5460504703223705, 8.375976048409939, 15.983143150806427, 46.51757128536701, 65.96749261021614, 88.33062261343002, 81.71092942357063, 73.64202439785004, 64.55955415964127, 50.67740947008133, 50.811865255236626, 47.39700749516487, 38.557218834757805, 35.20866371691227, 30.668954215943813, 30.384944155812263, 28.454414047300816, 31.60308089107275, 21.682259738445282, 29.0159897133708, 29.781794920563698, 35.61864651739597, 42.39052154123783, 36.97502553462982, 34.97354753315449, 36.57085262238979, 42.43434838950634, 61.2182604521513, 48.312488570809364, 46.70949138700962, 50.48553876578808, 42.81020142138004, 46.87710419297218, 31.58077798783779, 31.075384207069874, 28.196233101189137, 36.82509697973728, 58.74249190092087, 50.29874078929424, 53.84862810373306, 49.121370166540146, 45.74090056121349, 46.0175409168005, 50.20922139286995, 38.91972318291664, 38.67834873497486, 34.52897518873215, 37.770695239305496, 39.92554821074009, 22.884304337203503, 30.938990525901318, 26.57670870423317, 36.37083515524864, 34.42087098956108, 34.67146374285221, 43.066463470458984, 52.06323690712452, 65.49560353159904, 66.17430791258812, 69.83445391058922, 73.98759305477142, 78.14153775572777, 80.60142695903778, 66.00249633193016, 43.07843282818794, 24.369990415871143, 13.238629270344973, 6.646995199844241, 0.5489424720872194, 0.10614424652885646, 0.03554229828296229, 0.18217003263998777, 0.0468597868893994, 0.040557446554885246, 0.033450465998612344, 0.049358716860297136, 0.021595272846752778, 0.01440507527149748, 0.031297465902753174, 0.03597282186092343, 0.061853559673181735, 0.06387364483089186, 0.030423909847741015, 0.05784292683529202, 0.030099958676146343, 0.042435692448634654, 0.05752366232627537, 0.035345551223144867, 0.07091851875884458, 0.046520855466951616, 0.06126739288447425, 0.03765429471968673, 0.03581919729185756, 0.03014792368048802, 0.038238183115026914, 0.023977735727385152, 0.032032603994593956, 0.08211708191083744, 0.005234473783275462, 0.014951834018575028, 0.016034577383834403, 0.035265243423054926, 0.04144850616285112, 0.05155879138328601, 0.02483563617715845, 0.017227969401574228, 0.04865027753112372, 0.06280087036429904, 0.03171199990902096, 0.04068613867275417, 0.059680109698092565, 0.017057999029930215, 0.02434647180052707, 0.08305067400215194, 0.049940549506573007, 0.030922711011953652, 0.03333350352477282, 0.003077226283494383, 0.07829902897356078, 0.035946464486187324, 0.0598456271836767, 0.017888382499222644, 0.01444854471628787, 0.0766448634385597, 0.027296456864860374, 0.18301493808394298, 0.16151539486600086, 0.10782817960716784, 0.17654201510595158, 0.15099603042472154, 0.12006653618300334, 0.1874026338919066, 0.2698882663389668, 0.09404389231349342, 0.1621514154248871, 0.17732480278937146, 0.1138960977550596, 0.11705566532327794, 0.15532264747889712, 0.15234016376780346, 0.12533804081613198, 0.1644167469930835, 0.22715711005730554, 0.13330527814105153, 0.12036483502015471, 0.16218077478697523, 0.07911950291600078, 0.09110641243751161, 0.12278229201911017, 0.14443145220866427, 0.1109396263200324, 0.11995514723821543, 0.10799352268804796, 0.13206396193709224, 0.08094292265013792, 0.17342806735541672, 0.18944876472232863, 0.16174424352357164, 0.16687557130353525, 0.08882254202035256, 0.13152060593711212, 0.10033325248514302, 0.21371883427491412, 0.12168721601483412, 0.17449340550228953, 0.32412735745310783, 0.1762320497073233, 0.08885909279342741, 0.1679164482629858, 0.14912501676008105, 0.16791312344139442, 0.2515687368577346, 0.12710067123407498, 0.14439853053772822, 0.17573237651959062, 1.0250910627655685, 5.113620730116963, 11.00393783301115, 20.7418766990304, 55.14675244688988, 78.31306055188179, 100.25666266679764, 91.30389466881752, 83.89512822031975, 74.3442115187645, 56.49356357753277, 56.51617996394634, 52.14346960186958, 42.01600223779678, 38.167158365249634, 34.02541860938072, 33.280024006962776, 35.81783942878246, 44.21802967786789, 32.75242231786251, 36.54831223189831, 45.77853374183178, 52.59467639029026, 65.47460585832596, 72.85254076123238, 57.0461755245924, 65.87070420384407, 93.25356245040894, 95.70902109146118, 65.16731634736061, 94.3797080218792, 82.25930839776993, 84.42343667149544, 70.78857511281967, 53.36505085229874, 44.6135238558054, 53.216828405857086, 71.28666758537292, 92.36311823129654, 83.55275139212608, 90.41919574141502, 90.13623252511024, 79.85656052827835, 89.34677168726921, 112.21058562397957, 79.12535816431046, 85.61493873596191, 67.24288657307625, 73.76559376716614, 52.302274480462074, 24.382457546889782, 30.96656944602728, 25.671253390610218, 44.89278607070446, 40.261640176177025, 43.03992189466953, 50.97384676337242, 60.582406371831894, 75.35795912146568, 78.7329152226448, 79.8620018362999, 82.79492765665054, 92.74453416466713, 92.85070806741714, 78.99211451411247, 53.7177175283432, 34.195630475878716, 20.435081161558628, 9.419514052569866, 1.184702329337597, 0.3844794596079737, 0.16447795933345333, 0.374747499008663, 0.19448589911917225, 0.10267467645462602, 0.13890595495468006, 0.14388255978701636, 0.20449628384085372, 0.16503078513778746, 0.191083344980143, 0.09726850912556984, 0.15154131600866094, 0.12986995076062158, 0.14719544764375314, 0.16109189571579918, 0.1799715537345037, 0.13135743734892458, 0.16440276493085548, 0.11797424376709387, 0.18365999800153077, 0.13402968848822638, 0.16764655883889645, 0.10458656761329621, 0.09538993297610432, 0.21418539283331484, 0.12306050091865472, 0.1596051809610799, 0.10313198043149896, 0.20746830326970667, 0.1845564678660594, 0.10761389930848964, 0.15063414437463507, 0.12797855772078037, 0.12034469313221052, 0.1671081010135822, 0.11601633945247158, 0.08400515755056404, 0.18127335497410968, 0.24198340979637578, 0.14450376707827672, 0.15198753972072154, 0.2133040182525292, 0.10750587971415371, 0.08984411571873352, 0.18768561480101198, 0.11490404562209733, 0.09222474734997377, 0.08962120424257591, 0.15394305431982502, 0.20301831158576533, 0.12493642017943785, 0.1203195343259722, 0.06932396994670853, 0.12986926798475906, 0.12019342117127962, 0.10911560544627719], [0.03325276898976881, 0.01774443924659863, 0.021520022783079185, 0.006844735717095318, 0.01051240866217995, 0.057275399085483514, 0.009674038756202208, 0.016321000002790242, 0.03764372653677128, 0.02144571153621655, 0.012149104040872771, 0.0470772769767791, 0.03372834835317917, 0.09657008879003115, 0.1253804619773291, 0.12147873188951053, 0.030391329564736225, 0.07258700032252818, 0.02618186979816528, 0.01702130353805842, 0.0377546924573835, 0.051584276734502055, 0.03323194803670049, 0.025778534800338093, 0.07794408942572773, 0.11287643137620762, 0.015128788927540882, 0.026699350819399115, 0.05534072028240189, 0.059024099391535856, 0.00979393364104908, 0.017074658389901742, 0.09618305877665989, 0.04484724566282239, 0.04152175984927453, 0.03405145718716085, 0.03521498147165403, 0.04505834214796778, 0.043983036957797594, 0.019141487719025463, 0.05396337583079003, 0.025238852431357373, 0.03193974647729192, 0.0415141305711586, 0.07757815867080353, 0.06422580874641426, 0.06193378954776563, 0.005524411863007117, 0.40204170159995556, 5.216372441500425, 8.864443637430668, 29.258116520941257, 46.13811984658241, 69.02516573667526, 74.87457185983658, 72.12548777461052, 73.24888229370117, 57.974435314536095, 41.35036915540695, 43.99590499699116, 25.025039166212082, 19.652826637029648, 14.775491952896118, 20.31874470412731, 20.05008202046156, 21.321246810257435, 27.178811095654964, 33.54513198137283, 54.03706379234791, 48.55611249804497, 46.704323664307594, 32.616165429353714, 53.64265255630016, 51.4602130651474, 55.591218397021294, 49.302073270082474, 71.02040827274323, 57.409014254808426, 25.2298291772604, 30.94042494893074, 21.47714674472809, 17.653349228203297, 18.650425225496292, 11.088744532316923, 16.750244088470936, 11.274134684354067, 13.223745469003916, 12.076525278389454, 11.925751268863678, 24.31909404695034, 23.382037729024887, 27.539096362888813, 37.546837851405144, 51.6839374601841, 49.91950213909149, 53.76548856496811, 74.11120802164078, 86.0502889752388, 95.93775361776352, 64.37836468219757, 56.14511087536812, 32.79960818588734, 33.87134447693825, 25.21389853209257, 23.275084868073463, 26.94292165338993, 21.474553383886814, 23.967101834714413, 37.90196679532528, 37.46811367571354, 48.3150040358305, 45.645305290818214, 54.42425921559334, 61.88053831458092, 75.06507083773613, 65.05203813314438, 62.00113624334335, 44.40502144396305, 32.91359446942806, 25.38309395313263, 9.947588816285133, 2.293781591579318, 0.11723944335244596, 0.0508388858725084, 0.046596825413871557, 0.04934615230013151, 0.04553632978058886, 0.0700946977303829, 0.012997368630749406, 0.02598602444777498, 0.035415116435615346, 0.023288135816983413, 0.023378189871436916, 0.02392398197116563, 0.0755179715633858, 0.03936425120627973, 0.052106043658568524, 0.045545506436610594, 0.03996711260697339, 0.11831658906885423, 0.07848387569538318, 0.07224819506518543, 0.04693787566793617, 0.03453016841376666, 0.06673227151622996, 0.10591548692900687, 0.02523049584851833, 0.04820482565264683, 0.017633896350162104, 0.07879456839873455, 0.05004588994779624, 0.02387004453339614, 0.04161060605838429, 0.015098312633199384, 0.03824645064014476, 0.1040687266504392, 0.052730393945239484, 0.023727151419734582, 0.05772818338300567, 0.016773047718743328, 0.037176229161559604, 0.04591506629367359, 0.021927272609900683, 0.056879637704696506, 0.021467740334628616, 0.0506386581400875, 0.034264642818016, 0.0213139487823355, 0.03261480771470815, 0.026495876190892886, 0.03861387311189901, 0.05053243454312906, 0.04588575888192281, 0.050418500031810254, 0.011357079401932424, 0.037669861267204396, 0.05039273266447708, 0.023317920058616437, 0.04407368287502322, 0.03957614550017752, 0.016920228590606712, 0.05013567868445534, 0.01433049314073287, 0.03222320978238713, 0.023394016170641407, 0.019957132135459688, 0.009391683106514392, 0.034304800428799354, 0.07418709297780879, 0.06863805479952134, 0.041152277917717583, 0.07832579824025743, 0.0859845989907626, 0.021467048281920142, 0.007646431467946968, 0.082677425671136, 0.04585670008964371, 0.0510637232218869, 0.031323585790232755, 0.034524724760558456, 0.03151884113322012, 0.10491444845683873, 0.07073995802784339, 0.08771043372689746, 0.03933948573831003, 0.0945886509725824, 0.04078553451108746, 0.03413622529478744, 0.025876767322188243, 0.0796296181215439, 0.021208020189078525, 0.017888553193188272, 0.05792671530798543, 0.07193379162345082, 0.05974618310574442, 0.03797904741077218, 0.018746290370472707, 0.03732164557732176, 0.051198886867496185, 0.06908692797878757, 0.09454172497498803, 0.056531392328906804, 0.06758318835636601, 0.061310170276556164, 0.42978822835721076, 5.2856170758605, 10.855492148548365, 37.29196272790432, 58.04052136838436, 79.96521189808846, 86.4042703807354, 79.35819447040558, 80.32965794205666, 66.83966740965843, 52.99778155982494, 53.21952246129513, 32.43004381656647, 31.279647946357727, 25.19521303474903, 27.260385118424892, 28.077939748764038, 25.805958062410355, 30.23758426308632, 31.362103521823883, 49.67954881489277, 43.01570579409599, 42.35855005681515, 38.57543125748634, 50.49408070743084, 52.67284199595451, 52.86703057587147, 44.13206689059734, 48.88343073427677, 45.89385375380516, 32.68136993050575, 28.130131848156452, 21.239285208284855, 17.228695414960384, 15.075938031077385, 10.01109765842557, 11.151085887104273, 7.439645016565919, 9.794264193624258, 10.131973922252655, 12.426204364746809, 18.0873429402709, 21.521150283515453, 24.231493547558784, 28.65288309752941, 44.882336631417274, 51.978957429528236, 53.282325491309166, 61.582334116101265, 69.23189744353294, 74.28020775318146, 48.673925176262856, 31.703283414244652, 33.7248395383358, 32.99872510135174, 42.57491044700146, 36.87250703573227, 33.356882482767105, 34.36056062579155, 35.114607363939285, 46.10506922006607, 46.317994594573975, 59.03553977608681, 55.475241020321846, 63.419208750128746, 70.98397582769394, 84.83367025852203, 76.20849028229713, 72.8469854593277, 51.75847806036472, 39.240026995539665, 31.344225481152534, 12.207346558570862, 2.664302559569478, 0.06958323923754506, 0.0033724417289704434, 0.043424626492196694, 0.042590719676809385, 0.07354160261456855, 0.009575025123922387, 0.12238950293976814, 0.029505290585802868, 0.0433853186405031, 0.03383760362339672, 0.0240887832842418, 0.06977017139433883, 0.023858422500779852, 0.00371594315765833, 0.043272148541291244, 0.05530995083972812, 0.010524827575864037, 0.07654745655599982, 0.042895653314189985, 0.07509560047765262, 0.016104493261082098, 0.02412558638752671, 0.011352917808835628, 0.12315151048824191, 0.055051928356988356, 0.09038720454555005, 0.04091846800292842, 0.042635819991119206, 0.04519701986282598, 0.047286733315559104, 0.020630213693948463, 0.04071009148901794, 0.026165830131503753, 0.0047698030630272115, 0.053620922917616554, 0.03020479631231865, 0.02644346943270648, 0.025752099500095937, 0.03612309563322924, 0.08292679471196607, 0.022452074917964637, 0.046983554857433774, 0.01282864506720216, 0.021353304873628076, 0.04289406140742358, 0.06680578124360181, 0.004371121331132599, 0.041865452149068005, 0.037593683518934995, 0.027057047445850912, 0.03649792844953481, 0.060324141741148196, 0.035091784957330674, 0.09102682452066801, 0.15309135080315173, 0.11874103816808201, 0.13520173262804747, 0.09098685986828059, 0.13937717420049012, 0.10416959194117226, 0.07487127149943262, 0.07393160121864639, 0.1732696485123597, 0.10711439681472257, 0.11247867732890882, 0.22044157900381833, 0.21743104211054742, 0.1833526449627243, 0.25471520551946014, 0.23367482906905934, 0.16946548857958987, 0.24074604181805626, 0.19473977299639955, 0.17246441828319803, 0.2005097336950712, 0.168432122154627, 0.09775569938938133, 0.0882298628857825, 0.11237370054004714, 0.2192418379127048, 0.14762982667889446, 0.21185832942137495, 0.13837007980328053, 0.26288473745808005, 0.165291293815244, 0.20059675793163478, 0.2069687339826487, 0.19478924456052482, 0.11190624398295768, 0.14335343817947432, 0.17670291272224858, 0.20576406503096223, 0.1657317584613338, 0.07934352761367336, 0.18648201454197988, 0.11994016327662393, 0.11608191562118009, 0.21200972754741088, 0.2169432581285946, 0.20119909982895479, 0.18586279620649293, 0.1131537496985402, 0.9938836935907602, 6.583740469068289, 16.1308716237545, 45.73639780282974, 66.41130119562149, 93.77114027738571, 95.67695081233978, 88.57391595840454, 89.51048210263252, 77.42310270667076, 60.5634605884552, 61.44293859601021, 38.473045751452446, 32.5302292406559, 26.063263155519962, 32.12902016937733, 31.51001438498497, 34.61233891546726, 41.217988058924675, 47.93022148311138, 69.98922720551491, 67.01756626367569, 66.865194439888, 50.98997309803963, 71.43950298428535, 73.22261810302734, 71.56201601028442, 68.30828100442886, 93.5008379817009, 72.31933057308197, 37.57734261453152, 42.717007622122765, 30.50368968397379, 24.198659509420395, 24.67770740389824, 14.601422343403101, 20.92203263193369, 14.249391183257103, 17.39141408354044, 16.687517054378986, 16.884291395545006, 30.957938209176064, 29.964707605540752, 34.985361099243164, 46.68286241590977, 66.04234099388123, 63.876540809869766, 71.73331081867218, 95.83253726363182, 105.74480697512627, 119.04815152287483, 82.37409263849258, 74.7144028544426, 46.21136851608753, 47.53383055329323, 40.40383234620094, 38.89030896127224, 40.450372248888016, 34.521474391222, 37.782664597034454, 53.54967914521694, 57.10219591856003, 68.47498565912247, 64.55224335193634, 74.80263411998749, 81.67842596769333, 95.63045650720596, 84.79832455515862, 84.65831726789474, 64.9326941370964, 50.60076758265495, 41.001088097691536, 17.919754832983017, 4.669709075242281, 0.39627076126635075, 0.12353430283837952, 0.1339295579236932, 0.1087865000590682, 0.12551939202239737, 0.15607810928486288, 0.17992111737839878, 0.13880444399546832, 0.11586500069824979, 0.125657579919789, 0.1117096861707978, 0.149268310633488, 0.1656568460748531, 0.12952547549502924, 0.17093826580094174, 0.14437921985518187, 0.16247953375568613, 0.17793159757275134, 0.194961482193321, 0.2512739261146635, 0.10229326449916698, 0.15505510324146599, 0.16362414811737835, 0.20638542075175792, 0.27541492134332657, 0.1708027347922325, 0.13498959713615477, 0.15999693103367463, 0.14843468583421782, 0.1323380519170314, 0.10665192749002017, 0.14976520818891004, 0.14495644747512415, 0.22258168057305738, 0.15658812801120803, 0.084983352717245, 0.1795550307724625, 0.17713223031023517, 0.12213560679811053, 0.1520512456772849, 0.10488355284905992, 0.17469650163548067, 0.11226816714042798, 0.14828358456725255, 0.21026780304964632, 0.1236339435854461, 0.17025782028213143, 0.11692645741277374, 0.10919225445832126, 0.08704178835614584, 0.09078756353119388, 0.15636903117410839, 0.1242749736411497, 0.12736579607008025], [0.02104117054841481, 0.06575732695637271, 0.07965985321789049, 0.03482148364128079, 0.052578891918528825, 0.055092379116103984, 0.03545799772837199, 0.04853936727158725, 0.011586714736040449, 0.03147364062897395, 0.047570460083079524, 0.021894111596338917, 0.042780609292094596, 0.04211220511933789, 0.056283058584085666, 0.021844721668458078, 0.03171456031850539, 0.03803411476837937, 0.0802198110613972, 0.05950856597337406, 0.09124980279011652, 0.024633085522509646, 0.028343341509753373, 0.01857788778579561, 0.05069686107162852, 0.022491225063276943, 0.024815058277454227, 0.027641074993880466, 0.02565229919127887, 0.10394441691460088, 0.041397483510081656, 0.04861030916799791, 0.08817748952424154, 0.033998182116192766, 0.04114790295716375, 0.01803448911232408, 0.011346626251906855, 0.057661319588078186, 0.03607973565522116, 0.03008589868841227, 0.0018733797242020955, 0.027493389461596962, 0.030587614637624938, 0.02387341944995569, 0.014844096440356225, 0.06366973233525641, 0.3235740715172142, 4.821447758004069, 13.344284500926733, 23.545793741941452, 43.632040321826935, 71.42705485224724, 71.86589330434799, 70.86862161755562, 54.037379175424576, 65.02388164401054, 46.64088986814022, 24.79070194065571, 21.34164221584797, 15.147817824035883, 26.95840772241354, 31.55183494091034, 28.89240324497223, 33.54336507618427, 50.9173209965229, 58.50007250905037, 49.60014447569847, 51.26140013337135, 56.266172379255295, 48.53134162724018, 50.227920189499855, 50.28911590576172, 43.30970361828804, 25.287886261940002, 27.089185304939747, 19.289484433829784, 7.617000974714756, 4.0303924307227135, 2.1996057825163007, 1.20399211300537, 0.3248465579235926, 0.8962514356244355, 0.6567728484515101, 1.3385856407694519, 0.421723784529604, 0.6665624293964356, 0.36263986432459205, 0.6337275600526482, 1.6149718849919736, 1.6816826490685344, 1.548098917119205, 2.5061892438679934, 3.5466439509764314, 4.536542845889926, 5.807935623452067, 17.501798160374165, 19.42183133214712, 25.453080497682095, 28.887881487607956, 52.2641359269619, 75.09340211749077, 68.31329673528671, 80.60600951313972, 42.892858386039734, 35.00209920108318, 38.23363959789276, 23.092312775552273, 27.380973547697067, 29.85895738005638, 17.71420106291771, 22.650176100432873, 34.10241387784481, 37.58516639471054, 46.185526102781296, 46.03591673076153, 57.52088405191898, 74.07456278800964, 68.47241699695587, 73.17959681153297, 65.5802933871746, 51.3812381029129, 31.035915724933147, 12.468517944216728, 4.0176493395119905, 0.6993480201344937, 0.07207250644569285, 0.02550754328694893, 0.015967481667757966, 0.021811287915625144, 0.042987445849576034, 0.026520927385718096, 0.10117176061612554, 0.045638219235115685, 0.04504968870605808, 0.03519687306834385, 0.04267009237082675, 0.05304603306285571, 0.04341131236287765, 0.015521729219472036, 0.040293401543749496, 0.04285358096240088, 0.037609565479215235, 0.01587828664924018, 0.03129835276922677, 0.038684729661326855, 0.047691530344309285, 0.0011410614456508483, 0.06823024465120398, 0.022141307999845594, 0.07727653501206078, 0.08903061054297723, 0.031204259576043114, 0.005643962576868944, 0.03770353621803224, 0.06053802870155778, 0.027656923557515256, 0.019598641410993878, 0.019517869768606033, 0.08128080022288486, 0.07938643859233707, 0.04132513153308537, 0.024601549812359735, 0.04274183578672819, 0.028309557092143223, 0.01952885912032798, 0.008761594162933761, 0.05675520180375315, 0.07411572063574567, 0.05988862722006161, 0.030977995447756257, 0.05206758556596469, 0.037298687238944694, 0.01930735586938681, 0.086251467873808, 0.013831537053192733, 0.007441337102136458, 0.022887517079652753, 0.06832788902102038, 0.02775921006104909, 0.02465997724357294, 0.06685448097414337, 0.015205430518108187, 0.05254065647022799, 0.06308749521849677, 0.03228768386179581, 0.05029726278735325, 0.03675578765978571, 0.07763052461086772, 0.02287632549268892, 0.02733880937739741, 0.09942309741745703, 0.008029013697523624, 0.02802271701511927, 0.01633202646189602, 0.0803954254661221, 0.048108442933880724, 0.04203681033686735, 0.02729939948039828, 0.03673790561151691, 0.006844020008429652, 0.057158484851242974, 0.024083181924652308, 0.05289486871333793, 0.03374745494511444, 0.07953432635986246, 0.016644466923025902, 0.06432954614865594, 0.024443667170999106, 0.021420205775939394, 0.03790011258388404, 0.09627053572330624, 0.025353692362841684, 0.055240359652088955, 0.11933858579141088, 0.046325388611876406, 0.055385664745699614, 0.08519516908563673, 0.04263003123924136, 0.0520946071628714, 0.0289732096644002, 0.06488373008323833, 0.014003718097228557, 0.3492691833525896, 4.878085143864155, 16.49580404162407, 32.13038809597492, 59.97956492006779, 85.72668313980103, 81.26744762063026, 79.38051447272301, 66.23962640762329, 74.3392413854599, 61.330343037843704, 36.95246234536171, 34.17698107659817, 31.609833128750324, 35.99337100982666, 35.46104997396469, 31.582544893026352, 31.497146375477314, 46.59975327551365, 47.544333189725876, 40.69478653371334, 44.29216369986534, 50.480116456747055, 45.25157801806927, 47.84301996231079, 42.51479387283325, 38.891205713152885, 33.27768713235855, 25.619904845952988, 18.389907404780388, 10.887646973133087, 5.113321021199226, 2.7940311608836055, 1.5883845929056406, 0.5379365407861769, 0.7060104282572865, 0.5301072390284389, 0.8153681445401162, 0.3972576989326626, 0.5712384288199246, 0.24352870968868956, 0.38328691734932363, 1.0987279051914811, 1.19293506257236, 0.9427051898092031, 1.8908440880477428, 3.4734057309105992, 4.156527137383819, 4.649811442941427, 11.541502587497234, 16.121320836246014, 24.465564787387848, 29.984597638249397, 42.80196726322174, 55.80418936908245, 50.2639726549387, 57.91880249977112, 34.5887915790081, 36.999579817056656, 41.44142746925354, 22.96865601092577, 32.48655438423157, 38.893588185310364, 28.044864423573017, 30.86507309228182, 42.404254004359245, 50.677945241332054, 58.475860208272934, 58.84835422039032, 65.28079345822334, 84.7158233821392, 76.42225921154022, 81.20877116918564, 77.69867911934853, 59.597221836447716, 34.97344113886356, 15.005638003349304, 4.696826795116067, 0.7529301918111742, 0.00937465081733535, 0.03694781094964128, 0.013737942954321625, 0.062101767252897844, 0.05438900494482368, 0.009191139961330919, 0.05869179163710214, 0.014487827520497376, 0.07299981254618615, 0.017125410158769228, 0.012220274147693999, 0.05685873140464537, 0.06004264883813448, 0.036849802927463315, 0.14256440161261708, 0.0635712270741351, 0.050224907099618576, 0.0581213064288022, 0.012626864390767878, 0.029362262030190323, 0.057891463293344714, 0.034740170231088996, 0.014972232875152258, 0.002474317107044044, 0.02112561953254044, 0.06184191908687353, 0.06149307999294251, 0.0248839611231233, 0.05585457962297369, 0.017471891078457702, 0.06504780409159139, 0.08305494877276942, 0.03773397911572829, 0.047231339412974194, 0.047296191987697966, 0.038011835495126434, 0.013199230015743524, 0.03368478428456001, 0.022885292491992004, 0.017488834309915546, 0.06305624337983318, 0.03251517438911833, 0.033902337454492226, 0.09358714494737796, 0.04641552244720515, 0.01703681999060791, 0.12195540592074394, 0.036806951320613734, 0.060017464056727476, 0.04958748759236187, 0.03645835713541601, 0.05863938858965412, 0.24223572516348213, 0.23140737495850772, 0.1277105533517897, 0.16133350931340829, 0.10477675779839046, 0.2512876410037279, 0.1579534719348885, 0.08236780908191577, 0.16512051079189405, 0.1364911993732676, 0.1307327568065375, 0.12129868686315604, 0.1125041775230784, 0.1494754885789007, 0.10194841815973632, 0.08894383121514693, 0.09224649969837628, 0.15929153450997546, 0.12869652622612193, 0.2144038217375055, 0.14640774694271386, 0.17872931726742536, 0.10940395208308473, 0.1879922702210024, 0.12171981114079244, 0.09312650130596012, 0.058698994180304, 0.11720174967194907, 0.24132607475621626, 0.08991435999632813, 0.1483035780256614, 0.19844246649881825, 0.07077632326399907, 0.16397007799241692, 0.14455081924097613, 0.1846660385490395, 0.18512170237954706, 0.15113663772353902, 0.1527536439243704, 0.16504616243764758, 0.13517238810891286, 0.13678614370292053, 0.09942555392626673, 0.14748969435459003, 0.22729363554390147, 0.9207586955744773, 8.344254400581121, 22.16705482453108, 41.98169007897377, 73.91668885946274, 99.39661681652069, 91.3636502623558, 89.81044560670853, 72.44010329246521, 83.74145686626434, 65.63721433281898, 41.53106465935707, 34.506677985191345, 28.0680450797081, 41.31240539252758, 43.72791297733784, 40.46342074871063, 49.543003141880035, 65.89031115174294, 77.0490051805973, 67.77068585157394, 66.01973220705986, 74.44453373551369, 67.96619296073914, 67.980996966362, 69.21492755413055, 57.96850763261318, 39.52625423669815, 37.7153892070055, 26.920139975845814, 12.768875677138567, 6.47071173414588, 3.3625324303284287, 2.50575867947191, 1.1783320899121463, 1.7951381485909224, 1.445659501478076, 2.2741739312186837, 0.6895846815314144, 1.4461535937152803, 0.7858267484698445, 1.2260686908848584, 2.700024680234492, 3.2797617092728615, 2.024955991655588, 3.979201577603817, 5.44216345064342, 6.1748885829001665, 8.449691142886877, 22.779614254832268, 25.849838107824326, 35.25659814476967, 37.68860824406147, 72.24274948239326, 96.67806789278984, 84.85570907592773, 100.16854539513588, 55.83681061863899, 49.865609630942345, 56.49373456835747, 33.31976607441902, 41.326567232608795, 46.1732641607523, 32.71289303898811, 38.529324531555176, 52.07095809280872, 58.29842492938042, 65.66577360033989, 66.31524994969368, 79.24403339624405, 95.94749629497528, 89.5265856385231, 94.47965025901794, 88.63106489181519, 72.90599629282951, 45.20265944302082, 22.465428113937378, 6.834260076284409, 1.5197947109118104, 0.17501296824775636, 0.06927080248715356, 0.16718547733034939, 0.15157089801505208, 0.24653955828398466, 0.10472501526237465, 0.13154744199709967, 0.07363944736425765, 0.1228047271433752, 0.11815068195573986, 0.15899697609711438, 0.19189283513696864, 0.13559407641878352, 0.19144745747325942, 0.2391135841025971, 0.18204207153758034, 0.13568680034950376, 0.23108338296879083, 0.106277892482467, 0.11293538016616367, 0.09069990104762837, 0.1650376574252732, 0.14993012824561447, 0.12890027544926852, 0.13335681287571788, 0.12991004157811403, 0.12785953207639977, 0.15463880292372778, 0.16550417145481333, 0.14502919279038906, 0.16823813959490508, 0.15463115880265832, 0.12979362829355523, 0.13728353107580915, 0.21398971817689016, 0.23946257162606344, 0.08837123459670693, 0.1352901224163361, 0.08737032228964381, 0.12272523570572957, 0.1482233073329553, 0.148016752791591, 0.21467293932801113, 0.12913127633510157, 0.2094045517151244, 0.08980252576293424, 0.27127596375066787, 0.08742575329961255, 0.25475554866716266, 0.1073199494567234, 0.08785712663666345], [0.030020934791537, 0.052461539817159064, 0.024679963280505035, 0.06938836610061117, 0.016664371323713567, 0.014885331092955312, 0.08164894999936223, 0.040716143703320995, 0.04471823442145251, 0.028294172370806336, 0.015316910375986481, 0.02704719914618181, 0.019289266019768547, 0.013588784258899977, 0.03165570800774731, 0.026436261323397048, 0.06036492275597993, 0.06667945286608301, 0.03038359081983799, 0.07381856470601633, 0.022859758901176974, 0.026763570713228546, 0.025083645232371055, 0.0404846863966668, 0.022701716698065866, 0.0500282824941678, 0.05883670710318256, 0.050759194054990076, 0.01787380300811492, 0.013264508397696773, 0.056515751566621475, 0.04157049668719992, 0.10490957996807992, 0.06969058347749524, 0.015838249637454282, 0.056830852627172135, 0.044884067319799215, 0.11175561769050546, 0.03019955303898314, 0.013937873827671865, 0.014062419195397524, 0.0637866131728515, 0.03068218837142922, 0.14272900996729732, 0.12875468091806397, 1.4354575239121914, 12.536950372159481, 28.43166846781969, 53.2439399510622, 62.030748054385185, 66.67095646262169, 55.954687893390656, 65.74769720435143, 46.16713508963585, 33.20557080209255, 29.251366183161736, 16.740011237561703, 16.07386138290167, 17.234172821044922, 18.354272916913033, 31.961460560560226, 46.12782999873161, 56.61428689956665, 50.898910984396935, 62.00678654015064, 69.10004451870918, 89.16554421186447, 60.50261065363884, 46.14958383142948, 44.285958632826805, 32.022755071520805, 22.87106204777956, 11.77946386858821, 5.2209834940731525, 2.2577994223684072, 0.8729762001894414, 0.1725414235261269, 0.09358776835142635, 0.0753146008355543, 0.11090484185842797, 0.1733545056777075, 0.07897560790297575, 0.04858591848460492, 0.008601511053711874, 0.027561294118640944, 0.015092028497747378, 0.07671343788388185, 0.04765717632835731, 0.04879314838035498, 0.05785156914498657, 0.19352229457581416, 0.09104030192247592, 0.10109376089530997, 0.18177599675254896, 0.8823099243454635, 1.38289256952703, 2.254732749424875, 4.513613451272249, 8.72620990499854, 10.777520332485437, 19.641336053609848, 37.719173803925514, 44.946591183543205, 74.31268081068993, 72.73278638720512, 50.5088809132576, 46.559574231505394, 43.187673166394234, 23.44303585588932, 14.37240768224001, 18.94031547009945, 26.560757160186768, 14.740305840969086, 17.055582404136658, 23.406099937856197, 42.20806673169136, 48.57805632054806, 53.06052379310131, 51.21583677828312, 62.845055758953094, 66.75552472472191, 66.67965039610863, 54.0633849799633, 32.016709595918655, 12.024258133023977, 3.039078349247575, 0.17007958609610796, 0.06690403417451307, 0.029447046836139634, 0.03551443063770421, 0.07434940809616819, 0.010425013351778034, 0.05489704213687219, 0.06980549020227045, 0.0028382034770402242, 0.052355561128933914, 0.008605392486060737, 0.019748006052395795, 0.05600721713562962, 0.03012365174072329, 0.03591596963815391, 0.049362342251697555, 0.04501488940150011, 0.03307629369373899, 0.02400659413979156, 0.022947712677705567, 0.02056818313576514, 0.09032089365064166, 0.0371466174692614, 0.017002790664264467, 0.003010372229255154, 0.026164418195548933, 0.06398567944415845, 0.018438874249113724, 0.009467891468375456, 0.005466638449433958, 0.01563893660204485, 0.01883740012999624, 0.024915958820201922, 0.02850372333341511, 0.023189537787402514, 0.12237730203196406, 0.09034532515215687, 0.01963355389307253, 0.027727691049221903, 0.03923449410649482, 0.023148522996052634, 0.048081454733619466, 0.02980703484354308, 0.05358791218895931, 0.05131158199219499, 0.02211629947851179, 0.05605052887403872, 0.04477585847780574, 0.03320732357678935, 0.04295902530429885, 0.026576423333608545, 0.028704225660476368, 0.04901635671558324, 0.004883498695562594, 0.025087560061365366, 0.0469136779429391, 0.0723134446889162, 0.008685810680617578, 0.018954965598823037, 0.04337891390605364, 0.027751703237299807, 0.012778628024534555, 0.046705316271982156, 0.06990055189817213, 0.035983119159936905, 0.03134836981189437, 0.008925382444431307, 0.04004218826594297, 0.0020682769809354795, 0.018680363536986988, 0.024682525545358658, 0.026549154972599354, 0.015756496504764073, 0.029594214720418677, 0.03204537264537066, 0.08281103451736271, 0.10475013696122915, 0.04774757362611126, 0.038308509028865956, 0.06557849905220792, 0.0313224911224097, 0.04692770824476611, 0.07819852733518928, 0.03690312623803038, 0.08337468083482236, 0.07969880854943767, 0.03533828930812888, 0.08132907692925073, 0.04902109161776025, 0.04181164644251112, 0.03352031322719995, 0.05014133384975139, 0.036538189960992895, 0.04335323188570328, 0.09086251302505843, 1.8323481269180775, 15.004869494587183, 35.921790450811386, 66.33769914507866, 76.97609469294548, 74.4732753932476, 61.325163915753365, 74.54819217324257, 59.426952973008156, 41.925346702337265, 40.83615034818649, 28.409194573760033, 22.988107167184353, 24.000469744205475, 18.694985434412956, 38.990076407790184, 42.217984199523926, 46.79677650332451, 49.47164297103882, 51.76423855125904, 66.28483638167381, 66.78039819002151, 51.767646968364716, 42.233814150094986, 39.87734779715538, 28.92315499484539, 22.434898652136326, 12.04123942181468, 4.818238355219364, 2.438415843062103, 0.9952136815991253, 0.17377254262100905, 0.09881521167699248, 0.02519313056836836, 0.15511187753872946, 0.14699003600981086, 0.06374592863721773, 0.047638455653213896, 0.016632835613563657, 0.09875491217826493, 0.04639723221771419, 0.11804284047684632, 0.057647845897008665, 0.09966762765543535, 0.024061314543359913, 0.07494421719457023, 0.053890066483290866, 0.03240400066715665, 0.10261272938805632, 0.5099492019508034, 1.0338139696978033, 1.795795988291502, 3.603380131535232, 6.795238545164466, 11.209778487682343, 16.942724660038948, 29.38966356217861, 35.96704602241516, 48.51513929665089, 50.56943066418171, 45.96074536442757, 34.292787462472916, 37.73374602198601, 34.97558042407036, 24.402759857475758, 27.567921616137028, 38.41539144515991, 26.983125396072865, 27.624608874320984, 30.326907970011234, 50.867878049612045, 60.757443979382515, 69.13981318473816, 64.2947767674923, 71.36523216962814, 74.6200843155384, 74.59664717316628, 61.099045649170876, 37.39504739642143, 14.31810099631548, 3.0948631558567286, 0.09266284454497509, 0.030320960977405775, 0.036269027841626666, 0.05637741895043291, 0.027733544739021454, 0.03056901456147898, 0.02936629745818209, 0.06584736431250349, 0.02265893930598395, 0.031058687309268862, 0.05789165625174064, 0.12907637224998325, 0.08570078687625937, 0.02260624496557284, 0.08169828055542894, 0.05476506230479572, 0.021405505685834214, 0.014251934026106028, 0.019336581644893158, 0.03387647360796109, 0.035192969371564686, 0.05358370050089434, 0.025494407273072284, 0.02637313424202148, 0.046578954497817904, 0.01295900423428975, 0.024071194384305272, 0.07801396262948401, 0.025932769785868004, 0.01226173608301906, 0.09190307086100802, 0.030325185653055087, 0.02287960764078889, 0.031016956345411018, 0.054619864822598174, 0.05870745095307939, 0.10530071405810304, 0.04114503455639351, 0.024367352125409525, 0.034237955187563784, 0.04088274472451303, 0.02881044925743481, 0.019848646843456663, 0.042136978008784354, 0.043943677155766636, 0.010154496812901925, 0.07712130740401335, 0.03133289603283629, 0.05751514247094747, 0.05321854157955386, 0.15809437609277666, 0.16811230103485286, 0.12062781504937448, 0.21668092376785353, 0.16776712815044448, 0.12254784014658071, 0.1774854035465978, 0.10212216977379285, 0.130109234014526, 0.1138167547469493, 0.10344428359530866, 0.07977613291586749, 0.09138367138803005, 0.16744858352467418, 0.12033863720716909, 0.1579472527373582, 0.10516884925891645, 0.17057185265002772, 0.1251870731357485, 0.11572342860745266, 0.06699669131194241, 0.09129861384280957, 0.16830120730446652, 0.14531193621223792, 0.14716163539560512, 0.1107329604565166, 0.1729908533161506, 0.12432519477442838, 0.14636565232649446, 0.14888065721606836, 0.08360352949239314, 0.15744020260171965, 0.15663712460082024, 0.21356963290600106, 0.14248156308894977, 0.11770219469326548, 0.172592394228559, 0.1563607042771764, 0.19900970481103286, 0.09614742826670408, 0.11424428375903517, 0.13803807261865586, 0.14761066442588344, 0.4266175063094124, 0.2987265813862905, 3.236497943289578, 19.796774312853813, 44.4700663536787, 77.50633344054222, 88.8468325138092, 87.85978987812996, 71.88561424612999, 82.57479026913643, 66.08083292841911, 49.20083910226822, 44.32003900408745, 29.472191333770752, 27.15189713984728, 30.25584988296032, 29.34613309800625, 46.112695410847664, 62.64840871095657, 76.0559132695198, 68.6647018790245, 78.22615161538124, 85.54278060793877, 103.47414761781693, 77.74434506893158, 61.465239599347115, 58.16842630505562, 43.3992800116539, 30.81009954214096, 16.540459245443344, 8.114304039627314, 3.55891278013587, 1.7965004942379892, 0.5461104365531355, 0.3757933038286865, 0.292212602798827, 0.39122335554566234, 0.4967884300276637, 0.19497823988785967, 0.30108928272966295, 0.17295468103839085, 0.5089972936548293, 0.22606348124099895, 0.3939878853270784, 0.2413892760523595, 0.17633158655371517, 0.2644813642837107, 0.4519318073289469, 0.345058148377575, 0.20484792825300246, 0.695816109655425, 1.680205122102052, 2.168243215419352, 3.7747060507535934, 6.307168509811163, 11.886625718325377, 15.592358820140362, 25.632035695016384, 48.875793144106865, 58.532070592045784, 91.86125636100769, 89.79167461395264, 69.78352904319763, 67.4086032807827, 61.102750450372696, 38.79657179117203, 27.434240989387035, 32.304612547159195, 40.5009551346302, 25.91767016798258, 29.326328560709953, 37.5704687833786, 62.107325345277786, 69.5330160856247, 74.38822835683823, 69.83817011117935, 82.86277681589127, 83.18235486745834, 87.03733161091805, 73.46334278583527, 47.786881774663925, 19.09698486328125, 5.004430264234543, 0.44741426536347717, 0.18462327599991113, 0.1252497549285181, 0.10170168374315836, 0.1530661474680528, 0.2121546393027529, 0.11201546585652977, 0.15346021304139867, 0.09595172392437235, 0.11666610458632931, 0.22030046704458073, 0.42162121972069144, 0.16691808152245358, 0.118327305681305, 0.18700369982980192, 0.18908330152044073, 0.14158234727801755, 0.10683006519684568, 0.07586945270304568, 0.1418708942946978, 0.12953846307937056, 0.1830583982518874, 0.09458373053348623, 0.1074923577834852, 0.09846203844062984, 0.09189283664454706, 0.1892856406630017, 0.2101350625162013, 0.081900330260396, 0.17434450099244714, 0.18372404534602538, 0.10898932159761898, 0.0700403650989756, 0.15001161606051028, 0.15635512332664803, 0.21114741131896153, 0.15809608303243294, 0.13292841555085033, 0.12461106263799593, 0.12748568260576576, 0.18431198957841843, 0.2338696873630397, 0.13792125857435167, 0.31644259637687355, 0.1420115609653294, 0.12916924461023882, 0.10983505082549527, 0.1597835190477781, 0.1540545842726715, 0.10057646912173368], [0.03194645920302719, 0.034542885114206, 0.036396981522557326, 0.023119987417885568, 0.02306287358806003, 0.012950938016729197, 0.07300120036234148, 0.005916308509767987, 0.021011978169553913, 0.05328042556357104, 0.027826042314700317, 0.04139371339988429, 0.07186967006418854, 0.04735123337013647, 0.02567399958934402, 0.04773953987751156, 0.013449407069856534, 0.04288008676667232, 0.016921744427236263, 0.04658217541873455, 0.032987499434966594, 0.038917619312996976, 0.03250020898121875, 0.033460900594946, 0.04293689074984286, 0.05745040863985196, 0.023448228203051258, 0.03301455442851875, 0.028768013253284153, 0.03684480827359948, 0.052787468812312, 0.03862250428937841, 0.06311998644378036, 0.007428272983815987, 0.014143762291496387, 0.039254661969607696, 0.05974631669232622, 0.04791721003130078, 0.06301627872744575, 0.06497796799521893, 0.058613884684746154, 0.06841960363090038, 0.14619342953665182, 1.429141431581229, 8.383759930729866, 28.992822356522083, 47.958111986517906, 66.99615061283112, 70.31806156039238, 60.39653554558754, 55.81890977919102, 57.03281544148922, 90.94231367111206, 35.56620933115482, 20.762222707271576, 15.600233897566795, 18.65624461323023, 29.204191714525223, 39.13199879229069, 60.62896907329559, 50.16120716929436, 57.75702238082886, 59.020994156599045, 60.03767900168896, 56.308027133345604, 41.263916194438934, 42.39097371697426, 34.25059452652931, 16.769685745239258, 9.168530870229006, 3.596574696712196, 1.3706245715729892, 0.22398864413844422, 0.04439317373908125, 0.04892587778158486, 0.01759402632160345, 0.028604317740246188, 0.051699688119697385, 0.004446163593456731, 0.06881036664708517, 0.05842169812240172, 0.11975896049989387, 0.045752851365250535, 0.059249159385217354, 0.029362573732214514, 0.05888053092348855, 0.03180165134835988, 0.04164036989095621, 0.11030648529413156, 0.09139003159361891, 0.05434909966425039, 0.047880225101835094, 0.09681942072347738, 0.04037208404042758, 0.04485239245695993, 0.031742747087264434, 0.017650616937316954, 0.0672278406273108, 0.03938450070563704, 0.4524434736231342, 1.7996283201500773, 2.242179410532117, 5.5906841810792685, 10.242159459739923, 25.125346183776855, 28.928543105721474, 39.523829966783524, 52.90059417486191, 50.04992634057999, 35.66667214035988, 29.791723787784576, 28.124388456344604, 32.35475845634937, 25.758992582559586, 32.65923231840134, 42.374505400657654, 48.68329547345638, 51.04358062148094, 54.18929882347584, 56.48718751966953, 54.857329577207565, 61.46158039569855, 66.19146779179573, 68.35139349102974, 49.6204923838377, 26.785598695278168, 7.910484401509166, 1.8785992451012135, 0.17222189926542342, 0.09991336759412661, 0.06289280761848204, 0.08994929288746789, 0.02447622890031198, 0.051107814215356484, 0.01697997890005354, 0.059976081902277656, 0.0988429160497617, 0.010129294405487599, 0.028124144482717384, 0.04982884885976091, 0.05137867956364062, 0.024817893281579018, 0.0497988846473163, 0.015317593151848996, 0.037379510831669904, 0.05917226546443999, 0.04971861024387181, 0.027352897195669357, 0.09529700866551138, 0.10165322892135009, 0.045799799627275206, 0.04155901937338058, 0.010900167835643515, 0.054669577584718354, 0.04017351871880237, 0.06166322476929054, 0.01748702346958453, 0.06633960118051618, 0.07697067369008437, 0.03751740186999086, 0.026110245125892106, 0.022179957195476163, 0.01750390547385905, 0.03586198581615463, 0.01717358667519875, 0.030661295058962423, 0.07720580833847634, 0.04138490781770088, 0.07691085658734664, 0.01915193901368184, 0.0642316197627224, 0.017908361114677973, 0.04795693719643168, 0.0649545829219278, 0.03743771376321092, 0.03253192095144186, 0.02283046633237973, 0.08972333118435927, 0.012050241621182067, 0.08170763903763145, 0.026944740093313158, 0.061462533194571733, 0.05886548759008292, 0.04406451364047825, 0.07386106008198112, 0.03587214210710954, 0.04679387675423641, 0.060681760442093946, 0.03430544980801642, 0.031334614104707725, 0.02963427028589649, 0.0305816032414441, 0.033100628716056235, 0.06565739677171223, 0.051982346194563434, 0.03456851889495738, 0.032394538284279406, 0.05326586091541685, 0.036355495467432775, 0.07127910605049692, 0.04809270198165905, 0.010332386827940354, 0.02903730153775541, 0.035962658148491755, 0.00819381779365358, 0.048357225678046234, 0.013172778017178643, 0.060698618326568976, 0.1250756619265303, 0.03844950595521368, 0.00552042745766812, 0.031693505588918924, 0.07032204724964686, 0.020027357859362382, 0.08567602140828967, 0.1865230404655449, 0.0376311731088208, 0.07436315267113969, 0.3102315030992031, 1.6566386679187417, 11.318563800305128, 39.36594843864441, 59.25737947225571, 78.54880750179291, 78.39022681117058, 66.94258868694305, 66.83285057544708, 65.75960576534271, 92.32845649123192, 40.054490491747856, 25.985354036092758, 23.11718624085188, 25.796519368886948, 35.528849735856056, 39.24411557614803, 52.43712544441223, 43.01483564078808, 49.69461500644684, 51.02290213108063, 48.94066706299782, 45.38173623383045, 36.07583798468113, 39.71331059932709, 28.37857961654663, 17.750215530395508, 11.164057441055775, 5.043889246881008, 1.7299901694059372, 0.22848104214062914, 0.13245679554529488, 0.0537109231663635, 0.0637013181403745, 0.06010231751133688, 0.031816538830753416, 0.04088339781446848, 0.22689020406687632, 0.184565982199274, 0.08501722433720715, 0.24059050250798464, 0.21609007031656802, 0.10056196013465524, 0.11022158359992318, 0.17868934519356117, 0.10356147613492794, 0.03819039251538925, 0.05632845946820453, 0.07655084074940532, 0.26020068617071956, 0.10336393126635812, 0.045263709253049456, 0.0668895994022023, 0.030070872053329367, 0.016532831214135513, 0.05591647844994441, 0.06630883173784241, 0.202316447685007, 1.376497393939644, 1.6418929654173553, 4.620194882154465, 9.114072192460299, 19.301771074533463, 24.253080189228058, 34.2908875644207, 46.39549523591995, 42.114078775048256, 31.62150990217924, 28.613568507134914, 29.72274038940668, 25.482527017593384, 22.338514924049377, 32.39346697926521, 49.60903599858284, 56.70803926885128, 52.16417849063873, 56.44477799534798, 62.83404394984245, 64.34321656823158, 72.00441867113113, 76.186253875494, 78.91806408762932, 59.18861836194992, 32.832518219947815, 8.864076007157564, 2.2122621908783913, 0.24759653984801844, 0.07400388640235178, 0.04727401661511976, 0.04198608825390693, 0.06397171964636073, 0.05425993062090129, 0.049527384762768634, 0.05510071343451273, 0.06776645430363715, 0.06985148851526901, 0.0340824975137366, 0.04134339207666926, 0.012961860575160244, 0.07844301304430701, 0.04763770608406048, 0.041374072461621836, 0.04083266459929291, 0.0687176056089811, 0.06375455981469713, 0.027119560400024056, 0.04091099457582459, 0.058767409063875675, 0.053687081672251225, 0.04083520645508543, 0.08557998007745482, 0.059202340999036096, 0.05918452203331981, 0.04278754466213286, 0.040669106383575127, 0.02759347920800792, 0.034286844165762886, 0.04602409520884976, 0.04340428793511819, 0.05515753597137518, 0.013590672097052447, 0.028000749443890527, 0.056858657189877704, 0.017975874288822524, 0.005244767371550552, 0.04545999247056898, 0.04124886472709477, 0.003927214975192328, 0.048002842740970664, 0.02565391521784477, 0.04112531940336339, 0.06409749883459881, 0.03437642510107253, 0.04306951996113639, 0.16405817092163488, 0.1607986880117096, 0.10244016521028243, 0.145445374364499, 0.1566284117870964, 0.18806448118994012, 0.15942835685564205, 0.12142010222305544, 0.16212359972996637, 0.14655524137197062, 0.14550240099197254, 0.15601946477545425, 0.10971673764288425, 0.11788697462179698, 0.11704085947712883, 0.1614516889094375, 0.15719639224698767, 0.1696829526918009, 0.200350780505687, 0.1932260292232968, 0.11425640303059481, 0.18919275345979258, 0.14327088167192414, 0.14146847213851288, 0.1843217562418431, 0.07262608924065717, 0.20584501849953085, 0.1599227311089635, 0.047747154312673956, 0.23369985428871587, 0.09881844744086266, 0.16580627008806914, 0.16500785277457908, 0.1580340988584794, 0.1689265706227161, 0.18348538549616933, 0.10236940885079093, 0.14507876825518906, 0.19331680872710422, 0.27176711708307266, 0.18715031852480024, 0.1743164923391305, 0.5895904346834868, 3.191137877292931, 15.751190297305584, 49.67315375804901, 70.88591068983078, 87.61332750320435, 88.05031165480614, 76.69606491923332, 76.5784840285778, 76.00381046533585, 101.83638229966164, 48.067443519830704, 32.56359525024891, 25.60089446604252, 30.791613534092903, 43.14104586839676, 56.2548603862524, 79.06581535935402, 65.66231578588486, 75.27269169688225, 75.33191531896591, 76.08262583613396, 74.82739359140396, 55.52091456949711, 52.94781804084778, 45.410542488098145, 24.085277393460274, 14.097981657832861, 6.1157086584717035, 2.521200575865805, 0.6484167405869812, 0.4907151684165001, 0.15515514474827796, 0.18624598189489916, 0.190070194657892, 0.21626986301271245, 0.2282606391236186, 0.2152127627050504, 0.21303904184605926, 0.36260002583730966, 0.5672729853540659, 0.5541541893035173, 0.39660169975832105, 0.5818613525480032, 0.46817985421512276, 0.4470328608294949, 0.6881272816099226, 0.21697288466384634, 0.1333228818839416, 0.2789943589596078, 0.4177695623366162, 0.147321805707179, 0.12309855825151317, 0.20762036932865158, 0.13775323634035885, 0.16797933785710484, 0.33334432693663985, 1.086325014475733, 2.892578160390258, 3.345728782005608, 8.143628016114235, 14.3666329421103, 32.86332696676254, 38.58426958322525, 53.994992449879646, 68.2486318051815, 65.89506849646568, 49.97493736445904, 43.594019562006, 40.73169395327568, 43.03638428449631, 38.33131715655327, 46.311006769537926, 59.39962863922119, 62.62136556208134, 66.43267124891281, 72.37769544124603, 73.81798535585403, 74.50231343507767, 80.82035601139069, 84.92500975728035, 90.30767932534218, 69.75649729371071, 39.697058871388435, 12.61484144255519, 3.55104838963598, 0.5591019394341856, 0.2514903957489878, 0.20094761566724628, 0.17244911519810557, 0.28506494883913547, 0.17107100633438677, 0.13903008657507598, 0.16066918324213475, 0.2375661171390675, 0.15428681712364778, 0.09556361037539318, 0.29858076421078295, 0.14872060564812273, 0.16452910815132782, 0.17845849273726344, 0.11695093344314955, 0.180353655887302, 0.18115542770829052, 0.13221521163359284, 0.08290925034089014, 0.193042689061258, 0.22073953645303845, 0.15988075523637235, 0.18120993103366345, 0.1715615511056967, 0.13937925221398473, 0.19428381230682135, 0.22641974181169644, 0.18081447022268549, 0.1982171504641883, 0.12445855129044503, 0.08271769460407086, 0.10303369039320387, 0.11901972946361639, 0.17839840846136212, 0.09334396541817114, 0.08089127659332007, 0.10394027573056519, 0.11127596764708869, 0.12142456253059208, 0.23231398256029934, 0.08051895594689995, 0.13341695652343333, 0.12610476842382923, 0.11550945258932188, 0.12598773173522204, 0.11885832718689926, 0.13048012973740697], [0.019217758235754445, 0.03130913988570683, 0.012242054326634388, 0.027697342775354628, 0.043962319905404, 0.027155832867720164, 0.022404737028409727, 0.06817620887886733, 0.02671177251613699, 0.014704660807183245, 0.02180600567953661, 0.037233218681649305, 0.040053888224065304, 0.04777545611432288, 0.02219357560534263, 0.057338804472237825, 0.03138248262985144, 0.04142079436860513, 0.04987457999959588, 0.024044517886068206, 0.03084784129896434, 0.0485109838336939, 0.06094123382354155, 0.02549908465880435, 0.03826763895631302, 0.04456017180928029, 0.019023534478037618, 0.04654540571209509, 0.05223809028393589, 0.026210251380689442, 0.028722627212118823, 0.08484511286951602, 0.008217697322834283, 0.04232697894622106, 0.012895448562630918, 0.04212799060042016, 0.05532133909582626, 0.01028550999762956, 0.043521781044546515, 0.03336304100230336, 0.5540343176107854, 0.9926604561042041, 7.3908694088459015, 31.19841020554304, 56.81026138365269, 67.98059418797493, 67.17195957899094, 59.18136075139046, 54.43016789853573, 50.429780557751656, 30.08842896670103, 20.059904493391514, 60.953566655516624, 78.97145122289658, 26.27997312694788, 26.434776820242405, 37.86195494234562, 48.22793550789356, 53.56307342648506, 43.6018281430006, 56.7446731030941, 54.342020228505135, 38.59909638762474, 33.63948851823807, 21.469169072806835, 12.243281230330467, 5.705779530107975, 3.938017962500453, 1.7578994343057275, 0.6914410600438714, 0.1389936768100597, 0.015237289062497439, 0.036315111501608044, 0.004539283181657083, 0.03143710840959102, 0.03022080629307311, 0.11371090222382918, 0.0602539382816758, 0.04470862360903993, 0.03126185394648928, 0.04715781113191042, 0.0323527331056539, 0.09448423821595497, 0.0792513380292803, 0.060330717169563286, 0.07553578310762532, 0.07051104257698171, 0.042348122733528726, 0.07630467036506161, 0.028416539535101037, 0.14910411788150668, 0.08593333885073662, 0.04492879656027071, 0.03039904604520416, 0.08126648419420235, 0.09097794667468406, 0.23998878401471302, 0.14565414050593972, 0.012635914881684585, 0.02176214475184679, 0.04252654245647136, 0.12785752827767283, 0.23876098974142224, 0.5221929762046784, 0.8824037318117917, 3.656376600265503, 7.6813847199082375, 12.382728047668934, 45.75483061373234, 59.50171396136284, 61.0608197003603, 53.85278508067131, 50.163502246141434, 30.892817303538322, 27.508680894970894, 24.369067065417767, 32.807264775037766, 76.77960723638535, 81.09714835882187, 54.131294935941696, 35.63501983880997, 47.57820837199688, 59.450610503554344, 69.00946497917175, 67.65679076313972, 61.72543443739414, 43.670156076550484, 21.21832363307476, 5.86305926553905, 2.5281575275585055, 0.5564886296633631, 0.009398211223015096, 0.027389754104660824, 0.05801232204248663, 0.016190821734198835, 0.04001315544883255, 0.008429342069575796, 0.038745377969462425, 0.023430676410498563, 0.08621703222161159, 0.018863900368160103, 0.02995558868860826, 0.020046924582857173, 0.02548331773141399, 0.04826799355214462, 0.023228593308886047, 0.08685798064107075, 0.04577519743179437, 0.0365423496987205, 0.035640087371575646, 0.05644238284730818, 0.03207764122635126, 0.0017510183579361183, 0.07332208275329322, 0.04914272591122426, 0.01310644949626294, 0.050619818721315823, 0.05473086785059422, 0.023328926108661108, 0.05533141375053674, 0.06967430075746961, 0.02113038226525532, 0.027399335231166333, 0.044244410237297416, 0.08278657332994044, 0.08552563260309398, 0.06297192056081258, 0.02675734409422148, 0.03172989308950491, 0.011570576734811766, 0.05333757464541122, 0.007926494345156243, 0.06658360449364409, 0.021781761570309754, 0.0721178887761198, 0.011053291455027647, 0.06418345437850803, 0.0535077528184047, 0.015058070603117812, 0.08513171545928344, 0.050030334532493725, 0.034252256373292767, 0.03476356643659528, 0.06200859061209485, 0.028840474697062746, 0.04515969725616742, 0.021722629098803736, 0.0418818313482916, 0.0760597838961985, 0.04612670454662293, 0.0677038318826817, 0.042980952057405375, 0.049884569307323545, 0.015654709095542785, 0.03108989832981024, 0.023821092472644523, 0.035898933638236485, 0.029967791451781522, 0.03033891538507305, 0.033703634835546836, 0.005250430422165664, 0.04241398462909274, 0.046542533600586466, 0.022975778847467154, 0.06119656602095347, 0.015730415580037516, 0.08088079746812582, 0.0355499758006772, 0.0744120602030307, 0.05901825497858226, 0.02586838476418052, 0.020386227079143282, 0.0814121900475584, 0.021506265220523346, 0.025845868003671058, 0.03249842411605641, 0.5288375727832317, 1.0894781327806413, 10.01369196921587, 39.903292804956436, 67.90946960449219, 78.26791897416115, 77.39459663629532, 67.36076384782791, 63.77664417028427, 63.13424304127693, 39.49854992330074, 34.98397417366505, 75.57665258646011, 74.67540174722672, 25.552868843078613, 21.770743690431118, 33.51066783070564, 42.22983956336975, 47.06048995256424, 42.407521829009056, 47.40716055035591, 44.49988715350628, 33.439452052116394, 29.615996517241, 21.423919200897217, 12.966319732367992, 6.195777961984277, 4.521185019984841, 1.630994318984449, 0.7918744802009314, 0.15526758012128994, 0.04130673740291968, 0.05970971025817562, 0.019145818150718696, 0.08246957979281433, 0.09904737773467787, 0.09522270484012552, 0.03730297685251571, 0.3175978531362489, 0.691271434770897, 0.2663318649865687, 0.06065041212423239, 0.07055874782963656, 0.03613973829487804, 0.07432151076500304, 0.09054808731889352, 0.16600158851360902, 0.010326833707949845, 0.016615745807939675, 0.0758562127884943, 0.7629190245643258, 0.3399007860571146, 0.17101825447753072, 0.10024025395978242, 0.11076819020672701, 0.12899207911686972, 0.2916850842302665, 0.05677343637216836, 0.04695063689723611, 0.03571309243852738, 0.06727383894030936, 0.07599302029120736, 0.058278255819459446, 0.1242107036523521, 0.6707502203062177, 2.6419428968802094, 7.146773356944323, 12.111038826406002, 32.75684528052807, 42.1719116717577, 47.54816338419914, 43.42478044331074, 41.59361690282822, 35.161743834614754, 34.007293581962585, 38.477924689650536, 39.87624205648899, 78.51231426000595, 91.34198382496834, 67.24342614412308, 45.417450517416, 57.00186990201473, 67.2367613017559, 78.3394767343998, 78.90911936759949, 71.27361908555031, 51.7439666390419, 26.245241090655327, 6.936032390221953, 2.8846166376024485, 0.5148824653588235, 0.055980499819270335, 0.03379750909516588, 0.0604199715598952, 0.09313253496657126, 0.03388766148418654, 0.0016390686278100475, 0.030226530107029248, 0.029981756815686822, 0.06652536816545762, 0.08581763060647063, 0.027329382246534806, 0.013948679497843841, 0.06549407975398935, 0.022885090256750118, 0.05364674965676386, 0.0483653336414136, 0.01580954522069078, 0.03814410847553518, 0.012532210876088357, 0.024582790174463298, 0.011754390943679027, 0.03446339367656037, 0.020851425651926547, 0.053050901551614515, 0.03799538950261194, 0.04112326365429908, 0.03554681796231307, 0.08176005692803301, 0.038466241385322064, 0.07407637196592987, 0.019358795980224386, 0.017586454559932463, 0.03548370943462942, 0.03835567622445524, 0.012201605422887951, 0.016877178459253628, 0.059980924415867776, 0.05594927024503704, 0.026652337619452737, 0.06319993801298551, 0.03750781332200859, 0.03867541570798494, 0.014701520594826434, 0.06597557774512097, 0.06513256477774121, 0.20210671675158665, 0.09795279896934517, 0.06932002914254554, 0.19893327844329178, 0.09380889125168324, 0.08652524615172297, 0.15237264015013352, 0.2598346589365974, 0.11602951257373206, 0.07101686074747704, 0.14471236994722858, 0.10160009114770219, 0.14686504349811003, 0.15011306764790788, 0.1674118620576337, 0.13928737433161587, 0.14189305482432246, 0.1081829410395585, 0.12120457511628047, 0.12537602393422276, 0.07350891843088903, 0.16918087494559586, 0.09398939640959725, 0.09237615289748646, 0.0938855847925879, 0.12449196277884766, 0.192781749938149, 0.1707412998075597, 0.09056196548044682, 0.11584790161577985, 0.13444969954434782, 0.24273575458209962, 0.1943912307615392, 0.0976789538981393, 0.10058178289909847, 0.0936591778008733, 0.20728221716126427, 0.07944592915009707, 0.19865573005517945, 0.1384272548602894, 0.7475218351464719, 2.2237736731767654, 14.612022824585438, 51.44058331847191, 79.9145682156086, 89.34467419981956, 87.49849006533623, 76.65830254554749, 74.74262773990631, 71.81009709835052, 46.98735527694225, 33.84917266666889, 71.34129345417023, 88.64932671189308, 37.803202494978905, 39.2710979282856, 52.26200424134731, 62.33574628829956, 69.21227529644966, 60.15223905444145, 74.53496128320694, 67.70514696836472, 49.681182727217674, 44.30821403861046, 28.889855481684208, 17.605268508195877, 8.70715582743287, 5.872967708855867, 3.0615520058199763, 1.5168328885920346, 0.3568927914602682, 0.2773199253715575, 0.31264475954230875, 0.13917360309278592, 0.265554569195956, 0.3149668505648151, 0.36308031412772834, 0.24160495901014656, 0.15898581419605762, 0.587854937184602, 0.37970804376527667, 0.19607538648415357, 0.217504306929186, 0.2154077248997055, 0.5483197211287916, 0.2362343479762785, 0.3590628015808761, 0.2511075366055593, 0.17880448198411614, 0.2407842772663571, 0.7079306314699352, 0.43316556431818753, 0.3676238312618807, 0.27338226791471243, 0.2099892304977402, 0.43173779093194753, 0.6327963131479919, 0.31920115929096937, 0.236922541516833, 0.12753445655107498, 0.23794827866367996, 0.33148061600513756, 0.39613987610209733, 1.1091478960588574, 1.20962934801355, 5.1707568392157555, 10.489532835781574, 18.361530527472496, 59.36084412038326, 74.73876714706421, 79.31733906269073, 72.50630334019661, 65.9009201824665, 44.47042353451252, 41.40331171452999, 34.56706054508686, 41.60644121468067, 80.66242888569832, 87.8475621342659, 71.26278966665268, 53.33763912320137, 66.41934156417847, 78.96893575787544, 88.56298014521599, 88.87464702129364, 83.05028915405273, 62.06270433962345, 34.09525886178017, 10.934717897325754, 4.705464681610465, 0.756366157438606, 0.20109070173930377, 0.1742508271127008, 0.16569122235523537, 0.15245426155161113, 0.20417315274244174, 0.1325487031135708, 0.14198603108525276, 0.10609721663058735, 0.15629753266694024, 0.22420615277951583, 0.12440379563486204, 0.16782761318609118, 0.14721256156917661, 0.17387866973876953, 0.1450675172964111, 0.1785058862878941, 0.13657748146215454, 0.1356191313243471, 0.13956912327557802, 0.15530933334957808, 0.09704367548692971, 0.18383891496341676, 0.15627458546077833, 0.12100351246772334, 0.1383774567511864, 0.16926313459407538, 0.1589446546859108, 0.19200911483494565, 0.12468251661630347, 0.18521926511311904, 0.17022411193465814, 0.1211476227035746, 0.10043773945653811, 0.16172330011613667, 0.18215412099380046, 0.15249453048454598, 0.19635661592474207, 0.18615440087160096, 0.1035269143176265, 0.19617861922597513, 0.149575233226642, 0.14914520317688584, 0.0919209343555849, 0.148236918321345, 0.135489507811144], [0.05603217927273363, 0.06487342165200971, 0.04892063450824935, 0.02822597642079927, 0.021461016476678196, 0.016049247788032517, 0.027985266387986485, 0.04996841344109271, 0.011853993655677186, 0.07833946860046126, 0.06423357161111198, 0.0630590709624812, 0.031993125448934734, 0.06562897993717343, 0.030216253217076883, 0.06672671283013187, 0.026371397616458125, 0.07030750115518458, 0.03436803883232642, 0.07814278462319635, 0.06632706630625762, 0.05262175094685517, 0.011616473930189386, 0.04423489961482119, 0.01742362364893779, 0.02309515515662497, 0.02117586107488023, 0.030255466444941703, 0.011315008905512514, 0.04340844396210741, 0.04095668489753734, 0.004575933216983685, 0.023086082401277963, 0.047369634921778925, 0.019882642773154657, 0.03161405125865713, 0.015258673120115418, 0.02507197867089417, 0.0828523572999984, 0.2933296834817156, 3.262270772829652, 20.485620349645615, 51.74412243068218, 66.1045740544796, 71.37369811534882, 66.79012566804886, 60.326987877488136, 50.15334539115429, 42.60910861194134, 27.356668151915073, 19.801911637187004, 13.194737825542688, 18.89683060348034, 38.346869722008705, 40.729254484176636, 41.15252137184143, 69.25807043910027, 60.51242932677269, 48.97880561649799, 34.114071652293205, 20.444132275879383, 11.244670115411282, 6.838725786656141, 3.586919652298093, 1.1617078632116318, 0.266037707333453, 0.256538602989167, 0.0043427147011243505, 0.07119128029444255, 0.03209039132343605, 0.014773579423490446, 0.02681384936295217, 0.05367093996028416, 0.05665619930368848, 0.014718243037350476, 0.06483768724137917, 0.1252234383719042, 0.2630743116606027, 0.27348818723112345, 0.5427759373560548, 0.637839058181271, 0.2875629882328212, 0.1458078986615874, 0.03931152903533075, 0.016147432070283685, 0.14911704609403387, 0.3186431829817593, 0.14421272644540295, 0.09234110126271844, 0.05597845520242117, 0.2705826790770516, 0.4737109027337283, 0.1524183267611079, 0.009121475486608688, 0.07339000410865992, 0.04474620596738532, 0.043624442332657054, 0.11202998968656175, 0.06029098258295562, 0.09746006486238912, 0.1099569931102451, 0.08002683040103875, 0.03243533785280306, 0.07222983433166519, 0.01991761277167825, 0.0637705679400824, 0.06138495278719347, 0.8283836930058897, 2.1551298815757036, 10.513187516480684, 14.729183837771416, 26.586367785930634, 35.548802465200424, 41.200649589300156, 30.86157537996769, 31.70304972678423, 39.76809985935688, 20.347167178988457, 16.88566692173481, 18.131348378956318, 22.938941605389118, 33.5501629114151, 42.29074269533157, 43.050162345170975, 55.95743514597416, 60.72677582502365, 67.11188480257988, 55.81574834883213, 42.804706916213036, 34.22924727201462, 10.538415312767029, 3.0379448225721717, 0.2308154825004749, 0.07003539270954207, 0.028241637592145707, 0.07169730626628734, 0.04545336138107814, 0.01032496906191227, 0.009714268726384034, 0.1070773636456579, 0.03457057835476007, 0.03352990919665899, 0.09845019376371056, 0.023472182874684222, 0.01807115120755043, 0.032130675099324435, 0.0741852969804313, 0.018007918370130938, 0.08141979706124403, 0.029848183221474756, 0.0012996182817914814, 0.10666164962458424, 0.08592392841819674, 0.02729061245190678, 0.008334773901879089, 0.04284301649022382, 0.0800250937754754, 0.0153157108798041, 0.017796990723581985, 0.030728396341146436, 0.006069700693842606, 0.023928637092467397, 0.03639727096015122, 0.10485415637958795, 0.02163526718504727, 0.06702641432639211, 0.012290194663364673, 0.03434134378039744, 0.022231278562685475, 0.00855749149195617, 0.048218507145065814, 0.019412032088439446, 0.012740401853079675, 0.0144396853283979, 0.06679165075183846, 0.03201759034709539, 0.044972672330914065, 0.014759890509594698, 0.14071770070586354, 0.006567121927218977, 0.03064308089960832, 0.039204455679282546, 0.0847094037453644, 0.09915527858538553, 0.04851736259297468, 0.05372688676288817, 0.02583582860097522, 0.04494086759223137, 0.062157495121937245, 0.08526941353920847, 0.00796725773398066, 0.06451995897805318, 0.025526918907416984, 0.09178695443551987, 0.021343248772609513, 0.03427840594667941, 0.015030179765744833, 0.02931509483460104, 0.04729621054138988, 0.05294073715049308, 0.010574348307272885, 0.043248830261291005, 0.01504525464042672, 0.05028624931583181, 0.11318780685542151, 0.05457990388094913, 0.0337756825319957, 0.02806131054967409, 0.035288847429910675, 0.08722475744434632, 0.07594334092573263, 0.06868863216368482, 0.07428878205246292, 0.048402144166175276, 0.14476895128609613, 0.42536493914667517, 4.878749633207917, 26.316268779337406, 61.37633576989174, 78.03838849067688, 80.27319297194481, 74.66607704758644, 68.82367014884949, 61.05749107897282, 54.25871729850769, 37.2517304867506, 34.81590919196606, 23.19115687161684, 32.08245746791363, 54.54943969845772, 42.46485315263271, 37.52808965742588, 54.81807008385658, 47.85567328333855, 39.775349870324135, 26.810645051300526, 17.882879711687565, 11.580757331103086, 6.440440183505416, 3.8656544080004096, 1.0949602886103094, 0.2861451596254483, 0.25727288390044123, 0.017062758051906712, 0.05044096484198235, 0.00944388855714351, 0.07927397353341803, 0.027732353592000436, 0.03317401969979983, 0.1185704703675583, 0.11970655003096908, 0.14907508506439626, 0.7845041225664318, 1.061440862249583, 0.2377978601725772, 0.7576938299462199, 1.0171766811981797, 0.042039630498038605, 0.15294041280867532, 0.11558525555301458, 0.04083179999724962, 0.15390504151582718, 0.7135641854256392, 0.25115191703662276, 0.20538641576422378, 0.1241844316245988, 0.668144510127604, 0.8750957739539444, 0.4881558276247233, 0.4793940024683252, 0.32535472128074616, 0.1633228806895204, 0.21198182279476896, 0.21711459034122527, 0.10946430353214964, 0.11314315925119445, 0.11891731308423914, 0.040584735324955545, 0.021356243778427597, 0.0623153944616206, 0.074218738154741, 0.08403243889915757, 0.03642101968580391, 0.6456417613662779, 2.328701480291784, 8.829181529581547, 15.020996779203415, 24.165000915527344, 30.88346790522337, 36.3226917386055, 33.67584876716137, 25.268930979073048, 41.85690477490425, 34.536844566464424, 31.609154865145683, 31.530375592410564, 37.86086820065975, 46.7778155207634, 49.37195152044296, 51.787394508719444, 63.221892938017845, 70.47718182206154, 75.59400245547295, 65.21783083677292, 51.41277641057968, 39.66371566057205, 14.819912519305944, 3.895921208895743, 0.12861339084338397, 0.053076865588082, 0.02724406680499669, 0.0458613496448379, 0.027121048406115733, 0.0387765667255735, 0.02482979733031243, 0.024055742869677488, 0.03294973153970204, 0.03201918596460018, 0.04512759936915245, 0.05640895651595201, 0.026113115382031538, 0.05693004066415597, 0.1315590788726695, 0.04819338173547294, 0.022661553521174937, 0.10436545955599286, 0.07016309406026267, 0.02397285796178039, 0.040602728695375845, 0.057032802142202854, 0.045045785009278916, 0.035586734375101514, 0.045897169402451254, 0.033394934798707254, 0.04679788806242868, 0.01408868194630486, 0.02153367273422191, 0.03842022822936997, 0.03637500281911343, 0.008035841456148773, 0.06467219573096372, 0.04804795047675725, 0.029452106427925173, 0.024498855127603747, 0.01784664040314965, 0.005460781048896024, 0.029995013428560924, 0.02249419365398353, 0.034907498557004146, 0.03174508114170749, 0.03522862956742756, 0.05860834826307837, 0.23671978677157313, 0.1580212448607199, 0.28376488422509283, 0.06807474986999296, 0.14487081847619265, 0.10154419258469716, 0.16414237499702722, 0.17177327099489048, 0.1336213291506283, 0.14822507364442572, 0.11636375362286344, 0.23262982576852664, 0.12905643816338852, 0.2656590932747349, 0.1130260483478196, 0.10469588596606627, 0.17907359957462177, 0.17697146628051996, 0.15967808954883367, 0.1285324225318618, 0.29375166865065694, 0.08531605752068572, 0.19461245014099404, 0.12398832652252167, 0.07579134166007861, 0.08331763936439529, 0.12271892002900131, 0.12442900639143772, 0.29611825884785503, 0.15275466808816418, 0.09128939636866562, 0.20393691229401156, 0.22175868332851678, 0.1413188551669009, 0.1856003876309842, 0.23106197942979634, 0.13809625699650496, 0.20320067211287096, 0.3038962633581832, 0.9231000230647624, 7.414983864873648, 34.26448658108711, 72.45495289564133, 90.15257924795151, 89.53795462846756, 85.92276021838188, 79.90509912371635, 71.27305671572685, 61.1153619736433, 41.77826799452305, 33.89922738075256, 23.118630163371563, 29.601895473897457, 50.43764613568783, 52.97223933041096, 57.651065066456795, 85.46144977211952, 75.78015446662903, 62.46452897787094, 43.11436749994755, 26.868362054228783, 15.295803733170033, 9.36501832678914, 5.5946421436965466, 2.3115824488922954, 0.762930839555338, 0.7118556427303702, 0.20311701722675934, 0.32255406375043094, 0.1537694808212109, 0.14908681099768728, 0.28464575414545834, 0.17798666493035853, 0.25138257653452456, 0.24929987266659737, 0.27076204132754356, 0.6397470308002084, 0.8066858479287475, 0.6992374104447663, 0.6179651152342558, 1.3254758692346513, 1.1579461838118732, 0.29518796189222485, 0.33557991322595626, 0.23216231726109982, 0.3296244749799371, 0.8579548343550414, 0.7253417128231376, 0.581525070592761, 0.20692184509243816, 1.3661029329523444, 1.8610988091677427, 0.9408396680373698, 0.711591913131997, 0.3462217468768358, 0.24262369028292596, 0.11790541699156165, 0.17447246209485456, 0.2615199872525409, 0.32414386281743646, 0.3266750316834077, 0.26639061339665204, 0.09742376641952433, 0.14421416621189564, 0.3204639977775514, 0.27908596966881305, 0.25382919993717223, 1.4864088711328804, 3.725682506337762, 14.311552047729492, 21.470548398792744, 36.999724209308624, 48.090975657105446, 55.23753337562084, 45.03427907824516, 45.17509192228317, 53.56183469295502, 32.64944784343243, 27.505344673991203, 29.479680731892586, 36.27074092626572, 49.81965869665146, 61.54821954667568, 63.00732985138893, 75.41338294744492, 78.64615827798843, 88.1090185046196, 76.01282358169556, 59.94807980954647, 47.48025342822075, 20.319890342652798, 6.028488138690591, 0.5335911770816892, 0.1626491590286605, 0.1052201836137101, 0.13406323356321082, 0.09808760267333128, 0.1687834845506586, 0.0983046882902272, 0.14521073695505038, 0.08642222121125087, 0.08576252614147961, 0.21410760091384873, 0.12565032171551138, 0.2301636541960761, 0.10629300260916352, 0.26356175425462425, 0.09908766151056625, 0.1563561029615812, 0.19423776946496218, 0.19050599861657247, 0.13357357936911285, 0.1530395043664612, 0.10588112549157813, 0.166230526228901, 0.1307209863443859, 0.1088610636361409, 0.07609087246237323, 0.07755026133963838, 0.08979356804047711, 0.10577852357528172, 0.14676681283162907, 0.15506828378420323, 0.17572737444425002, 0.13063498627161607, 0.09128941863309592, 0.09685926663223654, 0.16092241887236014, 0.1650962870917283, 0.09060443117050454, 0.21659085672581568, 0.12558415182866156, 0.10387379414169118, 0.18007434118771926, 0.15471784165129066, 0.17161461466457695], [0.011884991308761528, 0.06939025857718661, 0.009584573781467043, 0.04639316153770778, 0.04737454422865994, 0.018865713063860312, 0.01834474765928462, 0.05685956261004321, 0.015785254727234133, 0.02321077248780057, 0.02792480547213927, 0.05486629124789033, 0.03605746751418337, 0.05505877095856704, 0.04189801758911926, 0.011435072628955822, 0.037343112198868766, 0.022997653650236316, 0.021294320831657387, 0.04540487687336281, 0.0798442769155372, 0.08242053867434151, 0.05296318340697326, 0.02931131730292691, 0.0077941805466252845, 0.03575846363673918, 0.0671895309642423, 0.046851103761582635, 0.05122036462125834, 0.02916036817623535, 0.03643840078439098, 0.012552525313367369, 0.05732400233682711, 0.038257256310316734, 0.06601557950489223, 0.0225169738769182, 0.0878092655329965, 0.4261894355295226, 5.074448632076383, 18.884815648198128, 37.89481557905674, 59.6006378531456, 67.81116887927055, 69.06434163451195, 66.4027288556099, 55.80391578376293, 48.382393419742584, 26.178201287984848, 15.075050778687, 18.4837718680501, 15.195183232426643, 19.52848970890045, 35.50687551498413, 33.6053017526865, 34.66199465095997, 31.1379611492157, 27.223282009363174, 15.917516872286797, 5.627925032749772, 2.309810556471348, 1.247513077687472, 0.2785790234338492, 0.05200698178668972, 0.05850776127772406, 0.015114015550352633, 0.09314609400462359, 0.022226081673579756, 0.06296434323303401, 0.0889001261384692, 0.05872219000593759, 0.11083167351898737, 0.0206809320661705, 0.0037692648447773536, 0.07723055154201575, 0.04038906809000764, 0.1480497041484341, 0.3825275815324858, 0.2467508625704795, 1.6160040046088398, 1.1667279875837266, 0.48856484005227685, 0.11855235454277135, 0.06870472192531452, 0.03671885468065739, 0.10296105640009046, 0.07376066976576112, 0.25947774527594447, 0.029817656832165085, 0.03304588419268839, 0.018282796881976537, 1.197675308212638, 0.4283966717775911, 0.43661827279720455, 0.3078794589964673, 0.1506115385564044, 0.08731668727705255, 0.5999316985253245, 0.24358448950806633, 0.1167729144799523, 0.056160578242270276, 0.06637231505010277, 0.055355644872179255, 0.027802217518910766, 0.03917214256944135, 0.02265348823129898, 0.08502192213200033, 0.062384577468037605, 0.05789593844383489, 0.07353998473263346, 0.3116715664509684, 0.9669616632163525, 5.27890901081264, 12.034429237246513, 28.315573297441006, 46.37510173022747, 75.64511731266975, 62.42794834077358, 42.89073809981346, 35.91353729367256, 23.63783810287714, 13.154913112521172, 22.302694246172905, 28.891242407262325, 56.73133961856365, 63.31646606326103, 56.29400208592415, 60.12713760137558, 59.12742644548416, 70.38018822669983, 67.87199601531029, 55.774129182100296, 25.89112289249897, 5.495057562366128, 0.8477782679256052, 0.0660152084310539, 0.024517961719539016, 0.04168521787505597, 0.03257600823417306, 0.05839253542944789, 0.01639259313378716, 0.041528361252858303, 0.012530451986094704, 0.030892718968971167, 0.06110761591116898, 0.05302234741975553, 0.05333798653737176, 0.045422350740409456, 0.002302410889569728, 0.005443721393021406, 0.09862955601420254, 0.03214512100385036, 0.0394620365841547, 0.031247819933923893, 0.04114985480555333, 0.042683603169280104, 0.07928060091217048, 0.011659055580821587, 0.01818198539695004, 0.057846444615279324, 0.054432249889941886, 0.0430233954830328, 0.04479316536162514, 0.03885942751367111, 0.0048933854941424215, 0.035493082759785466, 0.05783244771009777, 0.041004828017321415, 0.04676812422985677, 0.02550895522290375, 0.02075461805361556, 0.02379687619395554, 0.05667627068760339, 0.05324153331457637, 0.03784311193157919, 0.04874087891948875, 0.01131113675000961, 0.046336773157236166, 0.05306703213136643, 0.011693306623783428, 0.024641957897983957, 0.022520872007589787, 0.03585011145332828, 0.0288777991590905, 0.054893034539418295, 0.04290597658837214, 0.025827702083915938, 0.03255312782130204, 0.029061682944302447, 0.004120336643609335, 0.059816661159857176, 0.050792334659490734, 0.026190701355517376, 0.031458114899578504, 0.05227960973570589, 0.027562778413994238, 0.07984194657183252, 0.06822579918662086, 0.05824534899147693, 0.09867953223874792, 0.041827984823612496, 0.04273845530406106, 0.03184289249475114, 0.059917533872067, 0.04422144447744358, 0.0673093061777763, 0.0045354045323620085, 0.04037499697005842, 0.006087470028433017, 0.017913827032316476, 0.025076440833800007, 0.08291601130622439, 0.018299031362403184, 0.03474855278909672, 0.4989794280845672, 5.317104086279869, 22.660179063677788, 45.84231711924076, 68.18478003144264, 77.23856180906296, 75.21949455142021, 74.91520687937737, 67.57157653570175, 59.818529561161995, 36.073425114154816, 31.173719130456448, 32.62877695262432, 23.3369018509984, 22.27815516293049, 30.547567829489708, 36.47964231669903, 43.08735094964504, 34.56414230167866, 24.84024938195944, 13.881491124629974, 5.671155788004398, 2.8515443997457623, 1.2220938666723669, 0.30186859716195613, 0.05084547243313864, 0.09286438958952203, 0.07184140908066183, 0.0890848615381401, 0.07808623297023587, 0.05285302642732859, 0.22926822333829477, 0.1809755014255643, 0.06255867047002539, 0.29342803289182484, 0.17397449584677815, 0.3601071221055463, 0.6136614305432886, 0.6496128451544791, 1.7467017914168537, 2.0356049202382565, 2.7858801232650876, 1.567651480436325, 1.0169073706492782, 0.5536734557244927, 0.09960458963178098, 0.030404639983316883, 0.04580347325827461, 0.05936753936111927, 0.3550576383713633, 0.2673790353583172, 0.311030528973788, 0.48118441889528185, 1.695586577989161, 0.99821284878999, 0.6360149779357016, 1.2547012232244015, 0.8907759294379503, 0.2811743732308969, 1.6774078784510493, 1.6277663921937346, 0.26259310310706496, 0.7989131868816912, 0.4388890665723011, 0.04140724275202956, 0.22973619197728112, 0.1498731758329086, 0.0743119370599743, 0.06469310945249163, 0.07633203334989958, 0.07708558041485958, 0.07821404564310797, 0.21829131001140922, 0.4923005145974457, 3.7967391684651375, 10.281741935759783, 25.893150083720684, 37.513327449560165, 63.76244053244591, 60.86041085422039, 38.4149506688118, 30.290439426898956, 19.24743589013815, 20.018634907901287, 30.933972895145416, 38.55153813958168, 62.66219437122345, 69.78222951292992, 64.46417927742004, 69.84277546405792, 68.59714150428772, 81.80086299777031, 80.42317852377892, 67.55950078368187, 34.03553746640682, 7.790189981460571, 0.9285920346155763, 0.07150964680477045, 0.05951417660980951, 0.051572283628047444, 0.0573198648635298, 0.02387407253991114, 0.011913628932234133, 0.04842231945076492, 0.022424446615332272, 0.04825733631150797, 0.015197197317320388, 0.08622514389571734, 0.03206459055945743, 0.03415720580960624, 0.02785416043479927, 0.008858125311235199, 0.08076564583461732, 0.06289389115408994, 0.036952371447114274, 0.03283652804384474, 0.025790193940338213, 0.042427844236954115, 0.04887802781013306, 0.01476203902711859, 0.028283830542932265, 0.03328694117954001, 0.045815577686880715, 0.06591549346921965, 0.055274305486818776, 0.01351597400571336, 0.03316284295578953, 0.01483281672335579, 0.02231982049124781, 0.0796219814219512, 0.03151749784592539, 0.1436026068404317, 0.04199199946015142, 0.07751235985779203, 0.05545631720451638, 0.04291985846066382, 0.07302959493244998, 0.046446744599961676, 0.03804367363045458, 0.13722067116759717, 0.20865775819402188, 0.09858794379397295, 0.14265577483456582, 0.17238310858374462, 0.14650171768153086, 0.07744949994958006, 0.2420893291127868, 0.14973601209931076, 0.12863610056228936, 0.09822741587413475, 0.14286549092503265, 0.1211217291711364, 0.1265002292348072, 0.18655937601579353, 0.10180713550653309, 0.11455041967565194, 0.06607502553379163, 0.09847557521425188, 0.23122491053072736, 0.21192669606534764, 0.23579033586429432, 0.17286166024859995, 0.1578681546379812, 0.08562597096897662, 0.12293682200834155, 0.2033150222268887, 0.16325169388437644, 0.20714422222226858, 0.20745647343574092, 0.21062539948616177, 0.13737816974753514, 0.10967003428959288, 0.15517329768044874, 0.1746312074828893, 0.17436450929380953, 0.2234081065398641, 1.1240634019486606, 8.449429906904697, 31.731403805315495, 58.533161133527756, 80.95641911029816, 86.37904733419418, 85.8079531788826, 82.80033856630325, 75.84931835532188, 66.33995622396469, 40.81925265491009, 28.532834239304066, 32.116952016949654, 25.405273362994194, 32.036449536681175, 48.52769382297993, 49.3271329253912, 50.7004514336586, 41.90524198114872, 35.14277145266533, 21.33762963116169, 8.473371472209692, 3.8042817637324333, 2.278647478669882, 1.003567473962903, 0.15897668577963486, 0.2998844801913947, 0.22347700753016397, 0.2010968021932058, 0.15430516301421449, 0.40412004163954407, 0.340544554637745, 0.19726496015209705, 0.20028504106448963, 0.15966150996973738, 0.16951218451140448, 0.29958254483062774, 0.5526234058197588, 0.465371745522134, 1.3494775188155472, 1.4872145466506481, 2.5749377673491836, 3.136650463566184, 1.972810321021825, 1.1216355697251856, 0.34435717505402863, 0.13037700089626014, 0.4578993277391419, 0.188971430179663, 0.5965543922502548, 0.3901657951064408, 0.2050218134536408, 0.6096065137535334, 3.780214567668736, 2.9245085595175624, 1.5228189923800528, 2.8497147979214787, 1.5873264684341848, 0.5007782753091305, 2.478679195046425, 1.5926552074961364, 0.30632736103143543, 0.2418474483420141, 0.21159029536647722, 0.3808652894804254, 0.2940190496155992, 0.2761540707433596, 0.16431854601250961, 0.25954281678423285, 0.23523645621025935, 0.22137347899843007, 0.36723073048051447, 0.8106969483196735, 1.374243046157062, 6.964816320687532, 16.37918259948492, 39.63379226624966, 61.018790155649185, 93.49285081028938, 75.5759610235691, 57.61537358164787, 51.46586336195469, 34.41271282732487, 20.690036080777645, 33.46094749867916, 43.38029623031616, 73.76680210232735, 80.39977937936783, 78.04218828678131, 79.58693459630013, 81.27275973558426, 91.80977672338486, 92.00475186109543, 77.38793939352036, 42.369782254099846, 12.294729519635439, 1.6509365988895297, 0.1270662504248321, 0.14150238828733563, 0.1962783045019023, 0.19170563580701128, 0.25491932581644505, 0.11873844807269052, 0.14270361367380247, 0.15789818193297833, 0.16636016458505765, 0.1344190488453023, 0.1545985636767, 0.1458549508242868, 0.12130418617743999, 0.10678417078452185, 0.06040380758349784, 0.22998561296844855, 0.17587381502380595, 0.27028020936995745, 0.15142757445573807, 0.10650674114003778, 0.14576672430848703, 0.11617190844845027, 0.12545534467790276, 0.1721966068726033, 0.12655510363401845, 0.10999407080817036, 0.19139420095598325, 0.1685468284995295, 0.13929193111835048, 0.07316879215068184, 0.18518496304750443, 0.18092607439029962, 0.10892137797782198, 0.09223610963090323, 0.19691064400831237, 0.1540686108637601, 0.10380749066825956, 0.15546116192126647, 0.17669909808319062, 0.19137454888550565, 0.08557107430533506, 0.12083693742169999], [0.019688942229549866, 0.00989660142295179, 0.02531670001189923, 0.08594297192757949, 0.02770800743746804, 0.03000203229021281, 0.044258410853217356, 0.050273632805328816, 0.055792907151044346, 0.06007571522786748, 0.015299859533115523, 0.029339442844502628, 0.029498932235583197, 0.009156039159279317, 0.07685331787797622, 0.04967661952832714, 0.06995673989877105, 0.019766416880884208, 0.022461678308900446, 0.035565527505241334, 0.016327510493283626, 0.005238397425273433, 0.02585186084615998, 0.011667801791190868, 0.014694720666739158, 0.05539243313251063, 0.022612861212110147, 0.09265578672057018, 0.03843863720248919, 0.023239825713972095, 0.008836238448566291, 0.0345938112877775, 0.039454028810723685, 0.030800993226876017, 0.02664901279786136, 0.04446718441613484, 1.2614647415466607, 7.146089393645525, 25.31875390559435, 56.59719921648502, 62.20281422138214, 62.40067720413208, 56.6763299703598, 60.635177940130234, 57.379531636834145, 37.340280935168266, 24.027978368103504, 21.856354996562004, 19.50191393494606, 16.547283679246902, 28.52916743606329, 63.020066767930984, 61.33911296725273, 42.922504395246506, 27.23022423684597, 13.27765317633748, 4.9420651607215405, 0.785493494477123, 0.3145582240540534, 0.08895574268535711, 0.09170716613880359, 0.01689822762273252, 0.061396619348670356, 0.03760230727493763, 0.049404136298107915, 0.12312859296798706, 0.09341800949187018, 0.04652810996049084, 0.01984905688004801, 0.05667787372658495, 0.18186282803071663, 0.27903238660655916, 0.07737124047707766, 0.32115609501488507, 0.24146871553966776, 0.6030169548466802, 2.1973627153784037, 2.666744878515601, 0.48433133284561336, 1.5064044669270515, 1.3264585915021598, 0.11085200836532749, 0.100693565182155, 0.08595563296694309, 0.025437453004997224, 0.08893455436918885, 0.041918849674402736, 0.13152517756680027, 0.04512571802479215, 0.2727821673033759, 0.2504480938659981, 0.8652708667796105, 0.4503545060288161, 1.6960622649639845, 1.540224077180028, 0.6570926250424236, 2.109913732856512, 1.4645643183030188, 0.20071947947144508, 0.8907654799986631, 0.3631619206862524, 0.11317239986965433, 0.08149327710270882, 0.03549193985236343, 0.08115520657156594, 0.006675890626866021, 0.0863320057396777, 0.08747344370931387, 0.03611093925428577, 0.15659033961128443, 0.06197747236001305, 0.06941713174455799, 0.15122088632779196, 1.2367203505709767, 4.282009229063988, 9.337068926542997, 24.798742309212685, 46.83325834572315, 59.89299036562443, 51.28778971731663, 56.16543598473072, 20.401249676942825, 15.85132347419858, 29.207607731223106, 36.31202191114426, 35.712588876485825, 46.09697945415974, 49.55028735101223, 50.2411662787199, 63.71490888297558, 67.3309126496315, 73.62008437514305, 49.614279717206955, 19.189350306987762, 3.816911573521793, 0.11253483564360067, 0.06783351476769894, 0.027165362043888308, 0.013616354117402807, 0.019838679800159298, 0.01977466956304852, 0.05326225407770835, 0.04312510311137885, 0.030676987771585118, 0.022353326603479218, 0.07471373581211083, 0.08018733467906713, 0.05901288182940334, 0.07160153210861608, 0.01904939090309199, 0.04774295004608575, 0.025803665776038542, 0.027282914525130764, 0.07214620170998387, 0.014489702371065505, 0.00815941368273343, 0.0332805030484451, 0.03599919407861307, 0.019090849127678666, 0.024682358562131412, 0.04066975576279219, 0.03091946040512994, 0.02684163166122744, 0.036260897613829, 0.0467822584323585, 0.10809335639351048, 0.046375524398172274, 0.04840617773879785, 0.03180728053848725, 0.0404091283417074, 0.05037726630689576, 0.0433009958214825, 0.034193292740383185, 0.010750228957476793, 0.021900935644225683, 0.08183434591046534, 0.0347295909159584, 0.07371627449174412, 0.022642016483587213, 0.027654329751385376, 0.012330483077676035, 0.01249106249815668, 0.05119311666931026, 0.08752232155529782, 0.07876014016801491, 0.010471283476363169, 0.02623316519020591, 0.0559371064446168, 0.01903123611555202, 0.048923888825811446, 0.04102808692550752, 0.04648112088034395, 0.05308130363118835, 0.011442014492786257, 0.053555420963675715, 0.017507298944110516, 0.09313303220551461, 0.009269438396586338, 0.01934700510901166, 0.056174426717916504, 0.02451548851240659, 0.016376503372157458, 0.00883100445207674, 0.0335511754383333, 0.012651335782720707, 0.024786650719761383, 0.0620217043615412, 0.03612858381529804, 0.033142445026896894, 0.03834915274637751, 0.014116513411863707, 0.007629936771991197, 1.0270354896783829, 8.400842864066362, 29.62364360690117, 67.1618065237999, 72.09470942616463, 71.48976668715477, 65.59049963951111, 69.48116406798363, 67.80604675412178, 50.04550717771053, 37.459662929177284, 31.866575852036476, 24.628697633743286, 18.634188696742058, 27.438967935740948, 49.376746863126755, 47.68100045621395, 44.019330739974976, 24.12778191268444, 10.4625210352242, 3.804675517603755, 0.6990195158869028, 0.28655651723966, 0.07061545533360913, 0.03131240162474569, 0.11286536595434882, 0.056015236041275784, 0.10725896718213335, 0.14391715871170163, 0.2661938255187124, 0.502051681978628, 0.4283494414994493, 0.5682812968734652, 0.41402032133191824, 1.1335389059968293, 1.1840158724226058, 0.6864597054664046, 1.0248232958838344, 1.6621108492836356, 1.7123847641050816, 5.988037884235382, 4.019377771764994, 5.998111618682742, 3.130679321475327, 0.8456180838402361, 0.3345023444853723, 0.20908376580337062, 0.07821913677616976, 0.1480929713579826, 0.1320639470941387, 1.3639046321623027, 1.1094068759121, 0.3139830002328381, 1.9698088383302093, 1.0969034093432128, 2.3080049408599734, 2.011576434597373, 3.72893750667572, 2.6704427925869823, 2.9698223154991865, 6.724737603217363, 4.5831074472516775, 1.3371126260608435, 2.34597725328058, 3.0929706199094653, 0.517709394916892, 0.7215166243258864, 0.43285947293043137, 0.5082849506288767, 0.07797256563208066, 0.23027022660244256, 0.030915554852981586, 0.035849539999617264, 0.09912375215208158, 0.20134389284066856, 0.044076050326111726, 0.12546282552648336, 0.7403820182662457, 4.376430362462997, 10.107520334422588, 22.42324847728014, 40.735729336738586, 43.262947127223015, 39.84362840652466, 39.00307551026344, 31.389226466417313, 28.56487412005663, 47.58170038461685, 50.65149866044521, 47.29775682091713, 53.44209551811218, 60.68572282791138, 59.9077183753252, 71.18926361203194, 75.48151329159737, 84.21942561864853, 63.51295731961727, 28.46800021827221, 5.7904252130538225, 0.05192657750740182, 0.1967406625044532, 0.056429180040140636, 0.02353646770643536, 0.035580904805101454, 0.06869837656267919, 0.0217707518095267, 0.034484466959838755, 0.05798963458801154, 0.03041504489374347, 0.016268981016764883, 0.03983511793194339, 0.00746245491427544, 0.02152195607777685, 0.12116087003960274, 0.034207649587187916, 0.033663881695247255, 0.007081911271598074, 0.04292377328965813, 0.033900062771863304, 0.040528146564611234, 0.0253304946818389, 0.030073692214500625, 0.0972155346244108, 0.004255800859027659, 0.023164280646597035, 0.05530615475436207, 0.0488121325179236, 0.036647805172833614, 0.06824184441938996, 0.03802519044256769, 0.039894274523248896, 0.0447730346058961, 0.04296103652450256, 0.08653666780446656, 0.023658589961996768, 0.053003240827820264, 0.11028309279936366, 0.04732128028990701, 0.06375329074217007, 0.025509992374281865, 0.09495071513811126, 0.2611497149337083, 0.12109483373933472, 0.15364321181550622, 0.1268471239018254, 0.20351615909021348, 0.1591009509866126, 0.13437570742098615, 0.12289709484321065, 0.20888944185571745, 0.11169050165335648, 0.1803802396170795, 0.0760124868247658, 0.12787544372258708, 0.24673483218066394, 0.14622112648794428, 0.19041331921471283, 0.09655530520831235, 0.08879539425834082, 0.15376845665741712, 0.119174029387068, 0.09789534189621918, 0.0926514228922315, 0.13386600039666519, 0.14396697166375816, 0.1194480451522395, 0.12529642117442563, 0.23715257761068642, 0.11736422064132057, 0.13221341563621536, 0.15214062994346023, 0.09124297503149137, 0.10102251471835189, 0.11488377014757134, 0.0751372572267428, 0.1836186900618486, 2.004967164248228, 12.062058504670858, 38.78353849053383, 78.59831884503365, 82.15799063444138, 79.1795888543129, 76.2772285938263, 80.34854292869568, 72.819634526968, 53.25758121907711, 37.84842386841774, 33.503072038292885, 26.39323554933071, 26.58541213721037, 43.021599277853966, 81.52489900588989, 77.86410704255104, 58.32014836370945, 36.359758749604225, 19.289246946573257, 7.285093059763312, 1.8022622913122177, 0.6513630668632686, 0.5557251675054431, 0.23033084522467107, 0.25797587586566806, 0.2735409390879795, 0.2838824107311666, 0.22192753676790744, 0.426088206586428, 1.0572074144147336, 0.6682412268128246, 0.425028211902827, 0.2638104627840221, 0.7626817154232413, 1.3956851768307388, 0.4012251313542947, 0.9317525150254369, 1.1184663022868335, 1.4320919732563198, 6.301123984158039, 9.770532567054033, 4.525960413739085, 4.812547210603952, 3.5509101720526814, 0.7341055269353092, 0.4571149667026475, 0.22047594044124708, 0.282173600862734, 0.2895056933630258, 1.6176132182590663, 0.7545984804164618, 1.151861879043281, 3.0359905399382114, 4.038485996425152, 3.48437312990427, 3.5985517781227827, 6.19857651181519, 5.818223571404815, 2.203205139376223, 4.975412646308541, 2.245769980363548, 0.7937021227553487, 1.3646609103307128, 1.2651403318159282, 0.328021792229265, 0.41408180084545165, 0.2576764934929088, 0.4049315949669108, 0.17671803769189864, 0.3322386456420645, 0.29293990752194077, 0.19237787317251787, 0.4740131349535659, 0.344671459752135, 0.20028671831823885, 0.5590520077385008, 1.7242499836720526, 6.052347058430314, 12.787009254097939, 33.791609555482864, 61.55797362327576, 77.14379489421844, 70.43094590306282, 75.59672310948372, 30.421980768442154, 24.70580119639635, 41.33561834692955, 51.32839813828468, 53.154519349336624, 65.98725154995918, 70.53355559706688, 69.65999767184258, 85.09582579135895, 86.66220813989639, 93.9565247297287, 72.90439277887344, 35.1509790122509, 6.958046508952975, 0.2683041075943038, 0.3619159141089767, 0.17610054113902152, 0.15685549413319677, 0.10516490845475346, 0.17984029749641195, 0.12352213903795928, 0.14565586228854954, 0.11470388097222894, 0.12256706919288263, 0.17440844443626702, 0.15782828646479174, 0.15389151958515868, 0.10398601429187693, 0.12919652595883235, 0.1694710843730718, 0.0844255396805238, 0.13873224786948413, 0.21512743056518957, 0.06690282447380014, 0.1582887742551975, 0.1133963132451754, 0.06293431593803689, 0.1364130066940561, 0.12663461733609438, 0.1587023286265321, 0.19097920681815594, 0.1260227314196527, 0.09339441661722958, 0.12718747282633558, 0.18526487750932574, 0.1612727125757374, 0.08341352484421805, 0.10141465070773847, 0.1474113532458432, 0.10663994922651909, 0.11045781662687659, 0.22772178053855896, 0.1420083994162269, 0.1386021196958609, 0.1566218215157278], [0.035921873422921635, 0.05201927175221499, 0.04505544035055209, 0.07713478480582125, 0.0065262690168310655, 0.02139045678632101, 0.02666153468453558, 0.0465579962474294, 0.06248401041375473, 0.040955081858555786, 0.0352778636442963, 0.025764578713278752, 0.06667896304861642, 0.06840364745585248, 0.0047605508007109165, 0.047524695546599105, 0.05739901120250579, 0.0387897138716653, 0.040193204185925424, 0.04700794925156515, 0.13566272507887334, 0.03839088742097374, 0.06821159448008984, 0.035292714019306004, 0.041237509867642075, 0.039714333397569135, 0.024202103668358177, 0.05267551583528984, 0.1343808727688156, 0.0326514475455042, 0.07668272781302221, 0.000998043906292878, 0.01986777384445304, 0.09439128421945497, 0.04588066403812263, 0.6851515069138259, 9.853793699294329, 37.67724685370922, 57.79345102608204, 61.70956268906593, 70.79822659492493, 54.15356554090977, 57.1906665712595, 34.87107843160629, 18.040554150938988, 20.091547295451164, 15.028964951634407, 21.916277781128883, 37.11724050343037, 41.42717443406582, 44.10161912441254, 62.95394651591778, 37.33704350888729, 12.773728966712952, 4.883437631651759, 1.192940406035632, 0.08600550529081374, 0.11659666182822548, 0.044700088910758495, 0.04512535437243059, 0.040364272936130874, 0.051059159013675526, 0.2017622414859943, 0.006705311679979786, 0.05613464760244824, 0.15658106276532635, 0.30498288630042225, 0.17473570187576115, 0.6696995173115283, 0.7014512666501105, 1.001934630330652, 2.5490697054192424, 0.9244099433999509, 1.3138210633769631, 0.9975887322798371, 1.6942343255504966, 3.8661761675029993, 3.9169936906546354, 4.481710363179445, 1.3544781692326069, 1.0349156730808318, 0.09483784931944683, 0.053599797684000805, 0.05372026680561248, 0.04064713139086962, 0.23831031314330176, 0.2760918193962425, 0.26136591739486903, 0.9803067846223712, 1.3026314950548112, 0.9164993616286665, 1.0906891990453005, 0.20537523902021348, 0.8554679865483195, 0.6626589701045305, 0.20985614857636392, 1.7697555106133223, 1.4920103643089533, 0.5880404741037637, 10.348667744547129, 8.048738557845354, 0.41603489604312927, 0.5547706468496472, 0.30211757286451757, 0.20456019759876654, 0.07385752745904028, 0.029813380206178408, 0.04737006536743138, 0.06549194979015738, 0.022697297208651435, 0.06043954570486676, 0.07189161537098698, 0.07329336905968376, 0.16899700043722987, 0.26069237384945154, 1.016460657119751, 2.9690813552588224, 11.563983131200075, 33.121792897582054, 39.36092130839825, 54.02475245296955, 40.04712648689747, 23.216199427843094, 15.513002928346395, 16.44914824515581, 23.869663663208485, 28.876322507858276, 27.40739542990923, 41.04833096265793, 51.359571665525436, 57.76166953146458, 68.40309351682663, 76.24443635344505, 67.60460436344147, 35.92761553823948, 6.1518513690680265, 0.28844305663369596, 0.1422497458406724, 0.10853416242753156, 0.0339691159024369, 0.026048552244901657, 0.01603816566785099, 0.05551939604629297, 0.02042551823251415, 0.02044668985035969, 0.01489075804784079, 0.05100261107145343, 0.027057199586124625, 0.02957246237201616, 0.03405053692404181, 0.009441108286409872, 0.08178034724551253, 0.046446032138192095, 0.0733225057774689, 0.045492361241485924, 0.02674912666407181, 0.054387769268942066, 0.013888542343920562, 0.10709288195357658, 0.030598663361161016, 0.05149600197910331, 0.033237614334211685, 0.04315969090384897, 0.04803003874258138, 0.07877224459662102, 0.042202450276818126, 0.02942250586784212, 0.0043006525538658025, 0.05521177583432291, 0.049066748542827554, 0.043826380715472624, 0.07459496991941705, 0.03322755823319312, 0.021842849600943737, 0.06733712187269703, 0.0038563285079362686, 0.011212660247110762, 0.054809561479487456, 0.03412258090975229, 0.0660450650320854, 0.036165561323286965, 0.02045909484877484, 0.04236557433614507, 0.04713640017143916, 0.027733971473935526, 0.040591425786260515, 0.03717647778103128, 0.041725746559677646, 0.08137011027429253, 0.07297247182577848, 0.02174115496018203, 0.021418047981569543, 0.07509137023589574, 0.023421737241733354, 0.03358270558237564, 0.03685366209538188, 0.024308206666319165, 0.06382511579431593, 0.03118991015071515, 0.04588954383507371, 0.0045298268287297105, 0.0955048025934957, 0.0506628484436078, 0.03466217051027343, 0.08024643932003528, 0.021115157105668914, 0.08344782690983266, 0.04273648861271795, 0.059118749195476994, 0.05627010810712818, 0.0335586117580533, 0.5915218591690063, 11.633580196648836, 45.312750935554504, 67.53796353936195, 71.39799401164055, 80.36001071333885, 63.908139914274216, 65.83341300487518, 46.767008900642395, 30.200435556471348, 31.195626854896545, 27.690408043563366, 31.21619515120983, 36.456554755568504, 37.58348688483238, 39.28385764360428, 63.1295008957386, 37.46210999786854, 11.724450420588255, 3.548958501778543, 0.7265653065405786, 0.06675988683127798, 0.09696048815385439, 0.027253041225776542, 0.10935872560366988, 0.19067038432694972, 0.2031508888467215, 0.37602295400574803, 0.19493636791594326, 0.6235569901764393, 0.9528751659672707, 1.2460381630808115, 1.1892554350197315, 2.095101890154183, 2.2718325443565845, 2.895533926784992, 6.0862018167972565, 2.7179423812776804, 3.4306311886757612, 4.739976329728961, 5.868683913722634, 8.229687698185444, 8.474577907472849, 8.810987155884504, 5.758898304775357, 2.384653240442276, 0.649117921711877, 0.13910775975091383, 0.050489686836954206, 0.11094496978330426, 0.48687033879105, 0.6490986852440983, 0.9101906907744706, 1.1188152898102999, 1.5454369224607944, 1.8810236337594688, 2.4950826773419976, 3.9171874802559614, 4.610916255041957, 4.945939052850008, 4.975781701505184, 8.689982648938894, 8.25575714930892, 3.9637406822293997, 11.050265897065401, 7.844871422275901, 1.7600830108858645, 2.0060558058321476, 0.8789556543342769, 0.6801053776871413, 0.3466202801791951, 0.5249006871599704, 0.28504505928140134, 0.2174496403313242, 0.13629369903355837, 0.12655543017899618, 0.013491776280716294, 0.08270314850960858, 0.10602799651678652, 0.07945763281895779, 0.526066868333146, 2.7434259513393044, 9.691400863230228, 28.76232672482729, 39.310342222452164, 51.32135331630707, 26.247403174638748, 18.810639828443527, 20.895967930555344, 27.621692530810833, 35.870622396469116, 45.56636072695255, 40.61710350215435, 48.407244086265564, 63.44543494284153, 66.87093213200569, 77.46708154678345, 82.56843701004982, 77.7686333656311, 46.9356856495142, 10.317805800586939, 0.5980089423246682, 0.0888620391197037, 0.08473347901599482, 0.09709032688988373, 0.014458398582064547, 0.0500788747012848, 0.026797780010383576, 0.02119275050063152, 0.035679666107171215, 0.030603068007621914, 0.07601698423968628, 0.03246999614930246, 0.05681119684595615, 0.0025693869201859343, 0.022849548804515507, 0.02286219685629476, 0.04712747955636587, 0.05145071983861271, 0.0880214232893195, 0.033117026468971744, 0.0954697212728206, 0.034637690769159235, 0.03525974039803259, 0.03365757343999576, 0.015924871258903295, 0.011767838659579866, 0.027394759890739806, 0.03906289472070057, 0.04623139931936748, 0.016255290247499943, 0.05101271170133259, 0.04106581771338824, 0.04502306415815838, 0.02928741272626212, 0.05036109119828325, 0.010266444223816507, 0.030816309299552813, 0.019674939758260734, 0.014800656681472901, 0.03445084024860989, 0.11370031177648343, 0.16760639380663633, 0.11491295139421709, 0.20716914354125038, 0.1320090430090204, 0.12181436075479724, 0.08926055015763268, 0.10211448112386279, 0.24705260497285053, 0.2076850549201481, 0.2007707321899943, 0.21969625493511558, 0.16879308794159442, 0.25433617585804313, 0.11116189954918809, 0.14633816317655146, 0.21286637376761064, 0.13813397294143215, 0.10380184292444028, 0.09502851447905414, 0.18512829265091568, 0.2157825094764121, 0.1809115579817444, 0.17098784126574174, 0.09419104535481893, 0.18288031249539927, 0.12632471130928025, 0.10517750270082615, 0.29742120299488306, 0.1052463888481725, 0.11312565940897912, 0.1371901243692264, 0.09121827635681257, 0.1365155418170616, 0.13973864464787766, 1.1129201436415315, 17.215825505554676, 55.05260869860649, 78.56028288602829, 82.02700406312943, 89.4097039103508, 72.19008430838585, 74.15340095758438, 50.43555244803429, 31.40133261680603, 30.09949777275324, 25.266624502837658, 33.75163570046425, 48.71760003268719, 59.00545299053192, 59.76763129234314, 79.31555315852165, 47.589429169893265, 18.01793586462736, 6.863911310210824, 2.024863609112799, 0.2141493689850904, 0.36012629920151085, 0.1538523638737388, 0.21427816129289567, 0.2349187873187475, 0.23851407720940188, 0.2372943129739724, 0.19910600589355454, 0.3555940923979506, 0.8481649565510452, 0.8504251821432263, 0.9003810421563685, 1.5897139278240502, 2.23858789075166, 2.7309243846684694, 6.045394856482744, 2.675296082161367, 3.8610321935266256, 4.467439753934741, 7.0270460564643145, 11.393404584378004, 10.351892821490765, 15.394834969192743, 7.693202560767531, 5.364454295486212, 1.312475223094225, 0.2503248379798606, 0.18406570045044646, 0.4082473326707259, 0.7235584803856909, 1.3855103915557265, 1.1878021317534149, 3.2486463664099574, 5.814711609855294, 2.6669792784377933, 2.959391875192523, 2.7000871393829584, 3.675638004206121, 4.420693712309003, 4.480176195502281, 5.510947359725833, 8.928045574575663, 4.1144253965467215, 24.832720085978508, 15.845498386770487, 2.2108080564066768, 1.4995131804607809, 0.5078046326525509, 0.5493922135792673, 0.4852221178589389, 0.4215593246044591, 0.15687210339820012, 0.199336516961921, 0.35615607630461454, 0.39003152574878186, 0.30723842151928693, 0.2764050354016945, 0.38042228668928146, 0.6559230003040284, 1.8788754427805543, 4.606790626421571, 16.67780477553606, 42.795059233903885, 53.654333129525185, 70.97263723611832, 50.96973158419132, 35.19307315349579, 23.742898665368557, 26.894953027367592, 38.042965829372406, 46.65500231087208, 43.99109445512295, 60.44312484562397, 71.61929413676262, 78.43412205576897, 86.48540362715721, 94.70576852560043, 91.31381213665009, 57.82742880284786, 13.038054183125496, 1.0046677524223924, 0.21392120310338214, 0.23803531774319708, 0.15667549363570288, 0.09233687102096155, 0.10959380088024773, 0.13044239894952625, 0.10985508881276473, 0.10351705859648064, 0.12678377417614684, 0.12705258006462827, 0.21065018721856177, 0.15596582234138623, 0.09855940079432912, 0.1447759720031172, 0.13947219878900796, 0.2304746734444052, 0.1486886339262128, 0.1892358425538987, 0.13814304198604077, 0.1385927537921816, 0.1172008813591674, 0.14529905252857134, 0.11334681941661984, 0.21763707714853808, 0.15715888410340995, 0.19227275537559763, 0.14731200935784727, 0.19847653107717633, 0.10771994479000568, 0.10624415444908664, 0.12904310919111595, 0.1087123817706015, 0.10493366266018711, 0.18409504496958107, 0.1119252726493869, 0.13231598044512793, 0.15991090127499774, 0.1709259461495094, 0.06656922909314744], [0.07373859087238088, 0.024419885048700962, 0.047234508383553475, 0.10848457954125479, 0.08707505883648992, 0.031277327725547366, 0.04162289602390956, 0.04023266417789273, 0.038633810909232125, 0.017140164054580964, 0.0995185153442435, 0.06696423719404265, 0.03856498784443829, 0.018095937084581237, 0.06490551211754791, 0.03623815820901655, 0.0028378055003486224, 0.02492257877747761, 0.050946556657436304, 0.010013163137045922, 0.023897257233329583, 0.0527416337718023, 0.06960508806514554, 0.07873424663557671, 0.008256967139459448, 0.06380623555742204, 0.07301089281099848, 0.006323358884401387, 0.03132091776933521, 0.11844999011373147, 0.011302768107270822, 0.03604830570111517, 0.045797617713105865, 0.06927299924427643, 1.3884831382893026, 17.75514006614685, 49.441977962851524, 60.72239086031914, 64.5169660449028, 55.648424327373505, 47.231723964214325, 49.409436509013176, 40.222365483641624, 20.912451446056366, 15.17041901126504, 15.973945744335651, 16.42561800777912, 45.29090590775013, 54.66306880116463, 34.41761456429958, 48.44650357961655, 27.26370994001627, 6.110318172723055, 1.2871935172006488, 0.048118554695975035, 0.044526493147714064, 0.12957603059476241, 0.041981850590673275, 0.0875280806212686, 0.06557682921993546, 0.17714682093355805, 0.1260645588627085, 0.29591235739644617, 0.13282574684126303, 0.5182077025528997, 0.5879585410002619, 0.2411670028232038, 0.7390090450644493, 2.917720698751509, 2.735260189510882, 3.1558258971199393, 2.7005464397370815, 4.259691601619124, 1.9991043163463473, 3.8312954641878605, 1.9436092441901565, 7.187787881121039, 3.8987513445317745, 10.171161219477654, 3.3714289404451847, 0.08269198660855182, 0.048960357962641865, 0.05932967127591837, 0.06138604374427814, 0.1569667865987867, 0.34699153213296086, 0.721164015121758, 3.168636434711516, 2.7732757246121764, 2.2375795198604465, 1.1048664757981896, 2.259568702429533, 3.059105174615979, 4.214090248569846, 2.1187513461336493, 6.851481702178717, 12.957671396434307, 12.961677331477404, 4.788860706612468, 2.287623784504831, 7.689549056813121, 1.700195730663836, 2.0356747414916754, 2.128955698572099, 0.9883132518734783, 0.5010190280154347, 1.2876885593868792, 0.12354326798231341, 0.06061806561774574, 0.1146648291614838, 0.09687767189461738, 0.05384109215810895, 0.16389945521950722, 0.26608149404637516, 0.0171794848938589, 0.028682708943961188, 0.03334498454933055, 0.08441160956863314, 0.7440177700482309, 11.461471281945705, 32.0370689034462, 83.35129380226135, 72.16825067996979, 47.35486015677452, 26.394612975418568, 16.117834523320198, 8.867409378290176, 24.200699999928474, 26.89212217926979, 30.390203073620796, 49.593836814165115, 63.900122344493866, 60.050978288054466, 69.26245540380478, 71.72444209456444, 53.42658095061779, 15.77277883887291, 0.8556772721931338, 0.011259455441177124, 0.06280462563154288, 0.009183862275676802, 0.04965706764778588, 0.026246945017192047, 0.011875262680405285, 0.057745033846003935, 0.05393602026742883, 0.02130038417817559, 0.03269316366640851, 0.03882383040036075, 0.07170545504777692, 0.029388385628408287, 0.021206231613177806, 0.0238492272910662, 0.08395248732995242, 0.03300382668385282, 0.010183435006183572, 0.05620862859359477, 0.01704437134321779, 0.05527123670617584, 0.056873529829317704, 0.003683607087623386, 0.028829561415477656, 0.020357331559353042, 0.033835603535408154, 0.05498026657733135, 0.03952492246753536, 0.028350790817057714, 0.043186794137000106, 0.009289065419579856, 0.06648129943641834, 0.01565795228088973, 0.028721252383547835, 0.038385566222132184, 0.05354319408070296, 0.014232607572921552, 0.029810855048708618, 0.049165465316036716, 0.07761206739814952, 0.0952731263532769, 0.026282473481842317, 0.04595546881319024, 0.030305041909741703, 0.02653565716173034, 0.05436648818431422, 0.024137106374837458, 0.026344049474573694, 0.005885162890990614, 0.027992062605335377, 0.053426777085405774, 0.07881362675107084, 0.039179415616672486, 0.04909178489469923, 0.027309609577059746, 0.0821048735815566, 0.09383484415593557, 0.013053990787739167, 0.01551805651615723, 0.057499420072417706, 0.039950020945980214, 0.018462289008311927, 0.014831977168796584, 0.035613392319646664, 0.034206410200567916, 0.05419869230536278, 0.017188687525049318, 0.04023237845103722, 0.04152202331169974, 0.021307282440830022, 0.07529845170211047, 0.0022774575654693763, 1.4026949694380164, 21.15711461752653, 59.22179438173771, 71.56612738966942, 74.44090873003006, 64.58937495946884, 56.69756323099136, 56.574237048625946, 49.34221051633358, 33.16495478153229, 24.697487242519855, 24.155271537601948, 20.056706964969635, 41.94200120866299, 44.31640639901161, 37.23262131214142, 47.0426195114851, 24.404110684990883, 6.539512267336249, 1.112902807071805, 0.06401903156074695, 0.03821898375463206, 0.13920263590989634, 0.12359334068605676, 0.1221763135981746, 0.5503102799411863, 0.37028520251624286, 0.44893130427226424, 0.9890930412802845, 0.9179280849639326, 1.2429357483051717, 1.8148051807656884, 1.9268179452046752, 3.4202375588938594, 6.6099395882338285, 6.5053449757397175, 9.49390646070242, 9.001526981592178, 6.481653722003102, 7.171447807922959, 6.885644244030118, 9.624657444655895, 8.136500548571348, 5.998632190749049, 9.378079175949097, 6.850154623389244, 2.7957933163270354, 0.8345660800114274, 0.04578030711854808, 0.16828667605295777, 0.18103266163961962, 0.3781250130850822, 1.19192099198699, 2.4298843508586287, 1.3552040490321815, 1.0247138142585754, 1.335644123610109, 3.9028418250381947, 3.6336590442806482, 6.013136962428689, 4.767275964841247, 8.895962946116924, 9.509254787117243, 11.343434415757656, 3.9647298166528344, 5.311254300177097, 9.438824616372585, 4.475667262449861, 3.4903556713834405, 3.7962257210165262, 3.0090300366282463, 2.854187870398164, 2.652792977169156, 0.8171791629865766, 0.6362833979073912, 0.20656776643591002, 0.36525005707517266, 0.15291896474082023, 0.31532391265500337, 0.0823221447353717, 0.03294534544693306, 0.05340862044249661, 0.03273314687248785, 0.19507443706970662, 1.2738435273058712, 11.21745502576232, 28.264903016388416, 60.2111054956913, 58.2779136300087, 38.09076726436615, 27.936395443975925, 26.632772795856, 19.954422153532505, 35.84740564227104, 37.739875093102455, 38.56677532196045, 56.054424941539764, 73.68545606732368, 68.16770374774933, 76.18798658251762, 82.74432957172394, 66.48926541209221, 24.680361561477184, 2.1606714092195034, 0.060486968941404484, 0.06001954207022209, 0.04440229102328885, 0.02034193013969343, 0.024160046159522608, 0.005888240484637208, 0.03157275074045174, 0.08257492765551433, 0.03434886544710025, 0.031054998835315928, 0.02389374316408066, 0.015187953868007753, 0.07474282057955861, 0.06617354563786648, 0.0343074461852666, 0.06204773890203796, 0.029273291511344723, 0.11394464905606583, 0.03391510610526893, 0.033014662039931864, 0.01523943108622916, 0.03843302656605374, 0.022995356703177094, 0.031209276494337246, 0.02803437801048858, 0.02891882508265553, 0.011813728433480719, 0.014883867206663126, 0.048892536797211505, 0.013419879796856549, 0.038329957096721046, 0.08217398979468271, 0.024343323239008896, 0.015579440478177276, 0.023502117401221767, 0.050870300983660854, 0.07437336462317035, 0.07999496257980354, 0.1636283189873211, 0.13718276226427406, 0.21717589173931628, 0.2596248686313629, 0.20096409134566784, 0.16531398869119585, 0.13146396522643045, 0.128766184207052, 0.14749889698578045, 0.11676786787575111, 0.2248147435602732, 0.14540816307999194, 0.278592441463843, 0.2552751114126295, 0.30273094307631254, 0.1780898086144589, 0.11813955716206692, 0.22873221460031345, 0.25295091269072145, 0.07736124374787323, 0.1281810601358302, 0.12588090699864551, 0.11922246936592273, 0.18577804294181988, 0.126133281737566, 0.1993892836617306, 0.10463192767929286, 0.11517932303831913, 0.09279889505705796, 0.14085912436712533, 0.13350668217753991, 0.11590625668759458, 0.1442666508955881, 0.14665317517938092, 2.6507845474407077, 30.934115387499332, 71.603844165802, 82.05915033817291, 83.26796427369118, 74.65974658727646, 65.08494436740875, 65.20805776119232, 56.07013709843159, 31.87707468867302, 25.567515157163143, 23.963587023317814, 25.452898107469082, 56.57204456627369, 69.43924471735954, 50.23351728916168, 65.68443819880486, 37.51849137246609, 9.14824090898037, 2.352213431149721, 0.1317591470433399, 0.12910622142953798, 0.44465119019150734, 0.29229159699752927, 0.4052734578726813, 0.5042430956382304, 0.3393886151025072, 0.3842170658754185, 0.5252550181467086, 0.8448904822580516, 1.0793732875026762, 1.0550678917206824, 0.9171840373892337, 3.186511625535786, 8.762178774923086, 10.280043426901102, 14.872219562530518, 10.54598830640316, 14.032943397760391, 11.48166624829173, 14.492974262684584, 13.95111383870244, 20.511799044907093, 14.12895854562521, 18.184606321156025, 10.31101556494832, 2.458036565221846, 0.7337076170369983, 0.15733468404505402, 0.23175771319074556, 0.2771877933992073, 0.9032506600487977, 3.9272982627153397, 6.076990161091089, 2.0275868754833937, 3.1586006982252, 4.509731009602547, 6.756332432851195, 8.668014127761126, 9.36346611008048, 4.242777759209275, 15.292525459080935, 21.417586840689182, 25.87565202265978, 13.961051255464554, 10.25286728516221, 18.677660264074802, 9.715224634855986, 9.50598981231451, 7.063931152224541, 4.268352286890149, 5.19353186711669, 4.026503814384341, 1.0374599928036332, 0.6366129708476365, 0.5995838984381407, 0.500006441725418, 0.3632040449883789, 0.34828144416678697, 0.4357414401602, 0.2030878805089742, 0.2604417357360944, 0.18998656945768744, 0.368639801745303, 1.8454233440570533, 16.331364065408707, 45.187863036990166, 107.61084884405136, 89.76322174072266, 62.90538512170315, 37.51178093254566, 26.372840143740177, 18.921926356852055, 36.89779847860336, 43.43324638903141, 46.6826306283474, 67.61172518134117, 83.22186514735222, 78.09315115213394, 87.00131714344025, 92.45597004890442, 77.29762583971024, 29.463909678161144, 3.043425315991044, 0.18846331135137007, 0.17480875889305025, 0.16879482456715778, 0.10866352618904784, 0.06752849949407391, 0.18323724099900573, 0.23580385779496282, 0.1535480239544995, 0.12841234303778037, 0.15537427127128467, 0.16914936335524544, 0.10947696457151324, 0.1670617761556059, 0.14623945753555745, 0.14966366754379123, 0.27766490529756993, 0.1085719748516567, 0.13495219289325178, 0.14083619200391695, 0.08328561569214799, 0.10324226357624866, 0.17492276761913672, 0.09045860657352023, 0.09595225827069953, 0.20955939340637997, 0.14531937253195792, 0.12877635163022205, 0.2097126914304681, 0.09319424454588443, 0.13953485089587048, 0.13326224841875955, 0.1354191522113979, 0.11916753559489734, 0.0918219838058576, 0.09096363064600155, 0.16297264635795727, 0.20009126630611718, 0.2052322420058772], [0.09402669675182551, 0.13241199951153249, 0.05198800878133625, 0.05632930180581752, 0.07286055595614016, 0.07603489226312377, 0.013476405474648345, 0.049055697963922285, 0.04266111609467771, 0.05526951121282764, 0.02444340741931228, 0.014159669299260713, 0.04275359140592627, 0.08533581349183805, 0.019895721270586364, 0.08685570224770345, 0.06795909357606433, 0.05005036138754804, 0.03935643268050626, 0.09249957947758958, 0.13473886996507645, 0.04406329280755017, 0.0407463973533595, 0.08187246261513792, 0.026400233764434233, 0.0170826791509171, 0.09000895413919352, 0.08522287345840596, 0.15899189980700612, 0.18677338171983138, 0.24584962811786681, 0.04591872508171946, 0.1511607872089371, 2.7640569442883134, 23.025113381445408, 57.02059529721737, 60.88026858866215, 62.7213229984045, 48.265899270772934, 56.030440628528595, 38.092974945902824, 33.5101168602705, 30.419248715043068, 17.099509947001934, 21.438793502748013, 26.34998057037592, 51.43633134663105, 54.026564955711365, 55.39223447442055, 42.676216810941696, 21.860135793685913, 6.815234972164035, 0.12449763278709725, 0.0717111250560265, 0.13245844311313704, 0.12981442327145487, 0.05725356510083657, 0.12046375588397495, 0.2306676169973798, 0.17323211068287492, 0.5528251512441784, 0.4484846501145512, 1.70759417116642, 1.1347472411580384, 2.732700314372778, 3.2034178683534265, 3.468686146661639, 3.4702402632683516, 7.232802640646696, 4.3985432758927345, 4.2950430046767, 11.082417871803045, 3.1281754933297634, 4.928099010139704, 6.255319816991687, 6.654733959585428, 4.901380268856883, 6.464549889788032, 7.602294813841581, 4.125956352800131, 1.63678877055645, 0.32648931664880365, 0.0485214295622427, 0.09028920394484885, 0.27387045265641063, 7.047218224033713, 25.013035610318184, 28.57242051512003, 33.0239063501358, 24.189790785312653, 7.503522438928485, 2.949637323617935, 7.608202546834946, 6.30610266700387, 7.157043730840087, 5.707670403644443, 13.96521583199501, 8.23945127427578, 2.5078238686546683, 4.14909758605063, 2.0688073011115193, 2.3973127361387014, 2.5360364047810435, 2.200369304046035, 0.40727627696469426, 1.3247935683466494, 0.6220449681859463, 1.7022737441584468, 1.4474116824567318, 0.16922700684517622, 0.2398901674314402, 0.20567678846418858, 0.35749651375226676, 0.19158150418661535, 0.1717374104191549, 0.12741158658172935, 0.16879360744496807, 0.09918950643623248, 0.07456138031557202, 0.09236783342203125, 4.5428310334682465, 14.250590018928051, 40.0109676271677, 47.79491074383259, 43.26219476759434, 35.04417434334755, 35.00532902777195, 31.00499678403139, 34.15692575275898, 36.068314388394356, 34.189980179071426, 42.132686376571655, 50.578352585434914, 59.665986746549606, 73.13248693943024, 72.91877120733261, 63.173570930957794, 34.70044478774071, 4.701479645445943, 0.4979242425179109, 0.13021421822486445, 0.12376526661682874, 0.05653819040162489, 0.04439266907866113, 0.008629726580693386, 0.16177434503333643, 0.21385032800026238, 0.1846959619433619, 0.26297216245438904, 0.22721493820426986, 0.16599050082731992, 0.15348995832027867, 0.09003479572129436, 0.025875596584228333, 0.03257318436226342, 0.050210858244099654, 0.03903162432834506, 0.08118406127323397, 0.02938852663646685, 0.06341246684314683, 0.054500379046658054, 0.019216850960219745, 0.03381466383871157, 0.0391783506347565, 0.041839655095827766, 0.008606672690802952, 0.002921981745203084, 0.06489884763141163, 0.023685439009568654, 0.04689763271017, 0.043608823834802024, 0.04706339139374904, 0.06328955976641737, 0.05265887317364104, 0.01228850442203111, 0.028481444060162175, 0.05373775180487428, 0.05188858696783427, 0.028924168545927387, 0.00812798836705042, 0.059781646632472984, 0.07348385610384867, 0.05289548098517116, 0.036666110245278105, 0.005279726701701293, 0.012687037724390393, 0.01790570793673396, 0.028349746244202834, 0.02459384446410695, 0.04936450561217498, 0.052085619754507206, 0.04128011285501998, 0.061504546174546704, 0.015417246886499925, 0.043059686504420824, 0.058359157337690704, 0.04405116240377538, 0.012475130442908267, 0.0206867746237549, 0.06478820825577714, 0.03721060915268026, 0.045547135450760834, 0.013717216625082074, 0.03243669598305132, 0.036569107833202, 0.201912185002584, 0.1468754929373972, 0.028566136097651906, 0.2703532960731536, 3.257849710062146, 26.256800070405006, 67.57919892668724, 72.08798378705978, 72.25599557161331, 58.272415325045586, 63.07272054255009, 47.73504875600338, 41.926186457276344, 36.500442400574684, 25.310878828167915, 24.583100080490112, 21.65823932737112, 35.07435992360115, 46.896923929452896, 53.523270562291145, 40.38953371345997, 23.36778849363327, 5.60052945278585, 0.33245220605749637, 0.04732387780677527, 0.1650041717221029, 0.15904300409602, 0.08434486080659553, 0.19169552775565535, 0.4405928298365325, 0.4209682485088706, 0.7083319255616516, 1.6322231967933476, 3.6446314305067062, 2.9444596264511347, 6.064030481502414, 5.092156631872058, 7.5139794778078794, 7.0963790360838175, 12.844679709523916, 9.846163708716631, 6.980388835072517, 9.055597130209208, 11.231075394898653, 9.592840801924467, 8.730634767562151, 8.591001760214567, 5.0062247179448605, 7.237642630934715, 7.990832515060902, 6.429383251816034, 3.999550435692072, 1.0553317400626838, 0.5607677344232798, 0.2064612682443112, 0.3282751911319792, 5.121767492964864, 22.001473009586334, 26.107283793389797, 30.763352550566196, 20.452921204268932, 5.988886663690209, 2.0018928917124867, 4.018672909587622, 9.505602233111858, 7.845947239547968, 7.488197861239314, 9.421126116067171, 3.583636390976608, 2.6662475802004337, 7.975880317389965, 5.869758781045675, 2.6501998538151383, 2.3690163670107722, 2.7609396865591407, 1.9178723939694464, 2.0198849262669683, 2.797270962037146, 0.8967835851944983, 1.824677288532257, 0.9805452218279243, 0.9273679065518081, 1.0301260300911963, 0.5764750228263438, 0.201863277470693, 0.254996360745281, 0.03407313903153408, 0.08501884964061901, 0.0725146260811016, 0.06315393227851018, 0.09337293144199066, 4.642682075500488, 16.052755415439606, 38.917367309331894, 40.42327210307121, 31.530753672122955, 31.196878887712955, 30.073187984526157, 29.480598382651806, 39.356015771627426, 47.41036757826805, 50.61522580683231, 55.66707752645016, 59.12429541349411, 69.96850311756134, 80.60569792985916, 81.70984268188477, 77.97962844371796, 49.072789773344994, 9.009875133633614, 0.40582258778158575, 0.14083004702115431, 0.09435352374566719, 0.07152471240260638, 0.05659343958541285, 0.01670263460255228, 0.07353047039941885, 0.14275422814534977, 0.12139288024627604, 0.06417601063731126, 0.07577347816550173, 0.10385928515461273, 0.0755230849608779, 0.06902888460899703, 0.06550769816385582, 0.040269370801979676, 0.059479685296537355, 0.024415799525741022, 0.023581306413689163, 0.05058242561062798, 0.013741338279942283, 0.11319501310936175, 0.008838729281706037, 0.12709025148069486, 0.025005610259540845, 0.016900025475479197, 0.04828016106330324, 0.05921053802012466, 0.04515131098742131, 0.05108504512463696, 0.030719893184141256, 0.023272840153367724, 0.033179422534885816, 0.0825500582868699, 0.04562279369565658, 0.0024252694947790587, 0.05541059348615818, 0.15316215169150382, 0.17379888886353, 0.15876590099651366, 0.16443298518424854, 0.19891484349500388, 0.15509679709794, 0.19184947886969894, 0.14313135790871456, 0.23564113449538127, 0.14692397002363577, 0.07772133380058222, 0.10831634950591251, 0.15067812404595315, 0.13307490065926686, 0.13970892905490473, 0.15708674734923989, 0.1262405072338879, 0.11902387806912884, 0.1669300746289082, 0.13881823309930041, 0.31828463659621775, 0.08581423899158835, 0.15415766858495772, 0.2219087307457812, 0.12736929900711402, 0.12535095418570563, 0.15754119405755773, 0.2059680368984118, 0.1766976434737444, 0.3053538117092103, 0.3350469621364027, 0.12162716142483987, 0.3813701280159876, 6.088633686304092, 37.18970261514187, 77.85773858428001, 79.38727051019669, 81.87252715229988, 68.45982447266579, 75.38980901241302, 55.29022514820099, 47.15998001396656, 40.526159182190895, 24.05730899423361, 31.072306372225285, 37.61105440557003, 66.94486856460571, 66.47232592105865, 71.03883728384972, 57.96199478209019, 30.969514288008213, 9.621807597577572, 0.40865987772122025, 0.19815960433334112, 0.42274126899428666, 0.42439231008756906, 0.22718304069712758, 0.309231384890154, 0.49075188988354057, 0.23811043793102726, 1.2524258578196168, 1.0276794363744557, 3.6066517559811473, 4.742639986798167, 9.064449705183506, 10.421675126999617, 13.622853253036737, 15.754365026950836, 13.811794314533472, 13.139638882130384, 18.085750825703144, 24.596876241266727, 11.487437188625336, 15.980587787926197, 16.748811565339565, 17.42705427110195, 14.994168318808079, 17.678779363632202, 19.39850628376007, 12.579316198825836, 5.039182724431157, 0.40357245539780706, 0.31808859086595476, 0.3828239062568173, 0.9483347064815462, 7.547303689643741, 19.656375646591187, 18.52907493710518, 21.831198446452618, 13.441545981913805, 2.925518830306828, 10.36409491673112, 15.831415392458439, 17.88530968129635, 17.0968234911561, 15.038393195718527, 27.69202295690775, 19.644066207110882, 6.583250295370817, 16.161319389939308, 13.78588730469346, 7.46599517762661, 12.35024644061923, 8.15051419660449, 5.897544790059328, 4.495810456573963, 5.082288086414337, 4.804875897243619, 4.917749315500259, 1.4979075291194022, 1.5802621725015342, 1.0160976578481495, 0.9270917682442814, 0.35521910001989454, 0.36786826502066106, 0.23393795010633767, 0.4648670554161072, 0.18898190930485725, 0.21850957564311102, 0.5052191088907421, 7.456718925386667, 19.59683284163475, 55.1111863553524, 64.30894240736961, 57.61761926114559, 49.32036928832531, 47.43269518017769, 42.55176208913326, 47.47269943356514, 47.54348963499069, 51.94526083767414, 60.997978672385216, 70.02303779125214, 80.62402814626694, 91.35183289647102, 94.83107820153236, 92.01376497745514, 56.80755212903023, 10.561721362173557, 0.9063387068454176, 0.23380612983601168, 0.2678225131239742, 0.22671768441796303, 0.19864017463987693, 0.11959070077864453, 0.23307002324145287, 0.24687494966201484, 0.32656976545695215, 0.2622712781885639, 0.22341578034684062, 0.2071611283463426, 0.21370207658037543, 0.15566694462904707, 0.14372921723406762, 0.1392959980876185, 0.17250734410481527, 0.11189972792635672, 0.14052572194486856, 0.14872323285089806, 0.13293147319927812, 0.19198483176296577, 0.11294106501736678, 0.2540365856839344, 0.10005516232922673, 0.1229892844276037, 0.22233255644096062, 0.22994776343693957, 0.14252070395741612, 0.15613843104802072, 0.13256139383884147, 0.18904120690422133, 0.1990953041240573, 0.1460941747063771, 0.12396712336339988, 0.14961360226152465, 0.15767957491334528], [0.0702993969025556, 0.12944155343575403, 0.06909781528520398, 0.02929328868049197, 0.04580708009598311, 0.03400378533115145, 0.01734853685775306, 0.0270311112399213, 0.030773841754125897, 0.04884042689809576, 0.08458594005787745, 0.03813618604908697, 0.17524258873891085, 0.035529091765056364, 0.01858393443399109, 0.005518857351489714, 0.06500408417196013, 0.03851974652206991, 0.12169005101895891, 0.025546144242980517, 0.048927421448752284, 0.05602601944701746, 0.09287702094297856, 0.19924986379919574, 0.004642002913897159, 0.24812763556838036, 0.23077503545209765, 0.11686990575981326, 0.6059426791034639, 0.31308215169701725, 0.43330253509338945, 0.33332648570649326, 0.7488698721863329, 17.82454714179039, 47.118539437651634, 59.33886229991913, 60.09317122399807, 52.25788526237011, 49.05048877000809, 34.894678965210915, 19.64587491005659, 20.48805981874466, 29.838149696588516, 25.647386871278286, 38.50620277225971, 41.455589309334755, 53.787865564227104, 54.32435877621174, 30.885717384517193, 17.814485281705856, 2.5580680975690484, 0.03040082534425892, 0.11751235331757925, 0.07171046454459429, 0.13403170712990686, 0.16863927041413262, 0.13487843825714663, 0.4193770245183259, 0.5594626232050359, 2.397697940468788, 1.8066197074949741, 1.9344588601961732, 4.4820300210267305, 3.0585572915151715, 3.3727156464010477, 3.3535817731171846, 4.923899285495281, 6.620853077620268, 12.213353086262941, 9.431476760655642, 8.6712078563869, 6.855627754703164, 10.39820758625865, 4.98798094689846, 3.4682061849161983, 8.793975468724966, 5.918182907626033, 4.115861244499683, 5.3818488121032715, 4.68194916844368, 5.92931536026299, 4.20949961990118, 1.3691225834190845, 0.18531068286392838, 8.87656593695283, 47.98529572784901, 76.1949934065342, 65.48643842339516, 72.09935277700424, 63.398165479302406, 57.2532644122839, 25.358281284570694, 4.348428240045905, 9.941792227327824, 7.360315723344684, 4.987464649602771, 4.91743678227067, 3.379300693050027, 1.731805403251201, 4.856346985325217, 4.107398148626089, 3.0964365089312196, 2.721318262629211, 1.8555927858687937, 2.6162548502907157, 0.5661311466246843, 0.9570573165547103, 1.0359094385057688, 0.474891125340946, 0.49270320392679423, 0.6682322616688907, 0.7665084663312882, 0.09776525825145654, 0.5080696090590209, 0.27119542588479817, 0.19111429253825918, 0.002855300008377526, 0.13242218177765608, 0.16035518056014553, 0.09258960941224359, 0.07529156457167119, 0.6779676955193281, 12.48825028538704, 42.75072701275349, 57.16776140034199, 53.78144770860672, 36.49157367646694, 98.45647126436234, 55.674175545573235, 18.979339376091957, 18.309562616050243, 23.79141066223383, 23.232194669544697, 45.57370573282242, 63.10826003551483, 58.83554130792618, 67.7526368200779, 73.89740109443665, 50.25639206171036, 7.096127299591899, 0.3493992966832593, 0.2313100200262852, 0.015823415960767306, 0.04481135540117975, 0.15619383979355916, 0.35052287857979536, 0.45556539203971624, 0.3705429652472958, 0.47908684238791466, 0.6905475736130029, 0.45565507316496223, 0.4080314270686358, 0.06075755227357149, 0.05741809553001076, 0.0700502801919356, 0.03919104136002716, 0.09087136684684083, 0.054853144101798534, 0.04781375093443785, 0.1896434449008666, 0.039296374379773624, 0.023300718930840958, 0.012150303537055152, 0.03003225996508263, 0.041993097838712856, 0.04281686691683717, 0.09032244473928586, 0.0694178367848508, 0.0733090951689519, 0.01368124194414122, 0.016186797438422218, 0.04360737664683256, 0.06999730569077656, 0.05766364993178286, 0.0698753708275035, 0.017911782415467314, 0.1932317140744999, 0.08860651025315747, 0.04891711301752366, 0.07839210171368904, 0.06847910161013715, 0.02030632003879873, 0.050874134176410735, 0.03708232892677188, 0.03271562105510384, 0.04883033368969336, 0.04285743641958106, 0.1299161568749696, 0.07958407994010486, 0.07432920683640987, 0.06395173360942863, 0.08600978006143123, 0.029404974484350532, 0.010856472963496344, 0.05461233573441859, 0.05359107002732344, 0.03682774258777499, 0.05420916771981865, 0.05311616972903721, 0.1276722882175818, 0.07857797259930521, 0.08164414088241756, 0.04713357258879114, 0.14968603587476537, 0.5700010608416051, 0.26126866636332124, 0.18915444379672408, 0.251228180131875, 1.1015966325066984, 21.244390234351158, 57.91208066046238, 70.25236308574677, 69.562608897686, 60.695085525512695, 57.63487793505192, 47.3653057962656, 29.094575196504593, 24.60352398455143, 42.49927170574665, 27.765549011528492, 26.68498009443283, 40.109173357486725, 47.593802735209465, 45.541331470012665, 31.302361227571964, 18.406584709882736, 1.5708145732060075, 0.04031905387819279, 0.011598248638620134, 0.07903069752501324, 0.2614148991415277, 0.41351542342454195, 0.47171277401503175, 0.9377797634806484, 1.6849412117153406, 2.573999692685902, 3.399848327971995, 4.963813768699765, 7.9903024435043335, 5.941818589344621, 7.99773009493947, 6.439155377447605, 9.017526023089886, 9.17488032951951, 19.935871548950672, 13.407821841537952, 7.573501383885741, 7.6168375834822655, 8.372708223760128, 8.129779659211636, 8.417853601276875, 5.623145839199424, 4.4124681036919355, 5.745842205360532, 6.721509201452136, 5.616826778277755, 2.673107637092471, 2.7782270964235067, 0.4015647084452212, 0.5684734834358096, 9.677882138639688, 49.647413939237595, 82.50551998615265, 78.54606404900551, 82.05075278878212, 73.08056652545929, 61.01859636604786, 28.580819964408875, 6.341750454157591, 3.570828465744853, 3.812511647120118, 3.349620485678315, 3.3475799951702356, 4.577136067673564, 3.1402894807979465, 5.378632759675384, 3.515678937546909, 3.0304138641804457, 1.3080555852502584, 1.3855758192948997, 1.5219467016868293, 1.5378524106927216, 1.6303095244802535, 2.728867270052433, 1.493789500091225, 1.3276571896858513, 1.8718353705480695, 1.752074584364891, 0.9883178828749806, 1.8826769012957811, 0.5425345315597951, 0.34831139724701643, 0.15864127955865115, 0.2397456712787971, 0.0809596803446766, 0.06761845521396026, 0.03680164125398733, 0.18465642031515017, 10.280428156256676, 34.93430323898792, 47.86142237484455, 43.12800116837025, 32.916083335876465, 71.27725169062614, 56.582767590880394, 27.63706460595131, 28.49028032273054, 35.993579998612404, 34.417667761445045, 57.04180955886841, 74.08352270722389, 68.96346464753151, 76.07453227043152, 84.33880001306534, 64.366045743227, 10.98266277462244, 0.39068966230843216, 0.20969084260286763, 0.03912370259058662, 0.07879622338805348, 0.25731218804139644, 0.20903343334794044, 0.19340971077326685, 0.2347750629996881, 0.3695340600097552, 0.5486729834228754, 0.3323117026593536, 0.27810113970190287, 0.06876747793285176, 0.06346895912429318, 0.03478817976429127, 0.0812372138898354, 0.031649589000153355, 0.047410775878233835, 0.020592896653397474, 0.09810655712499283, 0.05237762146862224, 0.040285939248860814, 0.01909100126795238, 0.03328508209961001, 0.07852597031160258, 0.03237284530769102, 0.039299725176533684, 0.06833410821855068, 0.10666962029063143, 0.07443888142006472, 0.05771744450612459, 0.1150450536806602, 0.03234378651541192, 0.05718756961869076, 0.02794678232021397, 0.02330377286853036, 0.3166302409954369, 0.30973616405390203, 0.10803828161442652, 0.12620838708244264, 0.14372431905940175, 0.10123781918082386, 0.12474393675802276, 0.11043162623536773, 0.12725402862997726, 0.18118517298717052, 0.17018201731843874, 0.23053683573380113, 0.30655294423922896, 0.2818465215386823, 0.10122826774022542, 0.20284935424569994, 0.17169881873996928, 0.16284003941109404, 0.20418490836163983, 0.10613834645482711, 0.10936153834336437, 0.14114171935943887, 0.26241872808896005, 0.29464767838362604, 0.18051458318950608, 0.3005064890021458, 0.36835508421063423, 0.3904089523712173, 0.7844842330086976, 0.44832158542703837, 0.5450786731671542, 0.3515519999200478, 3.0122069036588073, 29.085717871785164, 66.90399795770645, 76.65321841835976, 76.38764306902885, 69.94910895824432, 67.3010690510273, 49.9743065983057, 34.73479114472866, 35.13496667146683, 42.36980505287647, 36.64309434592724, 51.0559793561697, 56.84283323585987, 69.51495945453644, 67.84425750374794, 44.0275003015995, 24.704526364803314, 3.9448267221450806, 0.18255906645208597, 0.11799443760537542, 0.28904318693093956, 0.5308441026136279, 0.5237333779223263, 0.667625303613022, 0.7431217306293547, 1.444174968637526, 4.469244657084346, 5.076543744653463, 7.491223448887467, 12.144475132226944, 9.717546310275793, 12.083199620246887, 16.572094447910786, 20.703601352870464, 17.501929253339767, 21.079290993511677, 24.216328561306, 16.894235461950302, 19.685178101062775, 20.67636251449585, 15.33328017219901, 11.96783971041441, 16.84437833726406, 12.469978015869856, 13.376139141619205, 16.01173471659422, 13.413892015814781, 11.909757927060127, 12.214806508272886, 6.298221414908767, 1.8734113359823823, 10.494965594261885, 47.096751406788826, 71.25838950276375, 70.36754250526428, 70.7626225054264, 59.03937757015228, 47.608329355716705, 25.097235292196274, 11.017069928348064, 18.549109362065792, 17.297572419047356, 12.168723531067371, 14.077514056116343, 10.038572084158659, 7.900122832506895, 12.358682937920094, 15.921385064721107, 12.097600847482681, 6.3459245301783085, 8.549011163413525, 8.866354934871197, 5.909560220316052, 4.41189338453114, 4.973316108807921, 4.535048101097345, 4.3356257770210505, 4.42758796736598, 5.054915780201554, 1.551571455784142, 1.383891322184354, 0.34824276342988014, 0.245904695475474, 0.24407110089669004, 0.4395681613823399, 0.1462202804395929, 0.24609388376120478, 0.17406030296115205, 1.3587364344857633, 17.246157377958298, 56.95571757853031, 74.32829797267914, 70.20512402057648, 50.83006247878075, 112.09954038262367, 69.02441337704659, 32.024255990982056, 29.925022535026073, 41.44488528370857, 38.34759548306465, 60.5657746642828, 82.87736043334007, 79.4801527261734, 87.42171138525009, 97.6597148180008, 73.26847404241562, 12.854512631893158, 0.6646240584086627, 0.3183763660490513, 0.2083122736075893, 0.10891202691709623, 0.42583513422869146, 0.5608679540455341, 0.7897148898337036, 0.47851630894001573, 0.6621705775614828, 0.9669527574442327, 0.4901598044671118, 0.517246532253921, 0.2912316023139283, 0.23578132619149983, 0.14882257673889399, 0.16122376051498577, 0.17573976831045002, 0.26022600824944675, 0.24765439768088982, 0.27221184165682644, 0.21596899634459987, 0.12367136267130263, 0.10416829318273813, 0.08899182590539567, 0.182416663155891, 0.1273089920869097, 0.20047008816618472, 0.1273432793095708, 0.2325117203872651, 0.17047473520506173, 0.11121709307190031, 0.16110697615658864, 0.167477794457227, 0.15943999373121187, 0.13381047290749848, 0.09661084754043259], [0.07752631223411299, 0.12104249006370082, 0.014472887160081882, 0.06314821031992324, 0.08055306505411863, 0.05624323122901842, 0.10151737136766315, 0.04128630236664321, 0.08846248165355064, 0.08248731712228619, 0.07323487297981046, 0.007441384877893142, 0.021861310524400324, 0.13006584806134924, 0.024248012923635542, 0.05194487515836954, 0.04155660739343148, 0.020998465515731368, 0.026652268970792647, 0.028939210023963824, 0.042896696031675674, 0.059406676518847235, 0.13933724665548652, 0.12413117510732263, 0.29076024948153645, 0.1606830910895951, 0.1971369842067361, 0.40180949843488634, 0.27901202207431197, 0.3778248291928321, 0.38465006451588124, 0.46405909408349544, 12.338913548737764, 46.878658309578896, 63.492689207196236, 60.14896363019943, 44.16263625025749, 42.12452821433544, 30.991100929677486, 28.993356227874756, 35.085717514157295, 22.05780118703842, 15.077948123216629, 44.836948066949844, 40.50716020166874, 31.427543610334396, 42.564001232385635, 24.22527138143778, 7.715852670371532, 0.4735634825192392, 0.035194928641431034, 0.07871434965636581, 0.05419086264737416, 0.11783880181610584, 0.19220646674511954, 0.10156624179217033, 0.5636109318584204, 1.0260736662894487, 1.5663815173320472, 3.446421716362238, 1.3745784969069064, 5.375727340579033, 5.463288417086005, 2.30498552788049, 7.2091698087751865, 3.891578991897404, 7.010145988315344, 7.145156068727374, 26.335881426930428, 15.18537500873208, 4.382284423336387, 4.878266584128141, 16.87883108854294, 8.946190550923347, 9.28193673491478, 8.246972020715475, 3.639935594983399, 7.34600474126637, 3.9603807125240564, 5.515319975093007, 2.7148999320343137, 3.0600522737950087, 2.4244922026991844, 3.691580998711288, 27.661343403160572, 63.97950768470764, 52.93081395328045, 54.7574557363987, 57.186376601457596, 60.54217033088207, 60.091605708003044, 57.847180142998695, 23.937167041003704, 9.754643719643354, 6.741116624325514, 7.250114036723971, 3.436248949728906, 2.0735594211146235, 2.147167883813381, 4.511456117033958, 3.522163527086377, 1.6238594893366098, 0.32178041932638735, 0.9563444391824305, 1.3212629640474916, 0.4709270177409053, 0.5378602480050176, 0.11460448513389565, 1.04333815863356, 0.4435651015955955, 0.30925578670576215, 0.4753478430211544, 0.8160220657009631, 0.6309830385725945, 1.3629878126084805, 0.11082313882070594, 0.1962176413508132, 0.04281777233700268, 0.052249296713853255, 0.06387982692103833, 0.05070054954558145, 0.056025140002020635, 0.07967621015268378, 5.467540863901377, 21.15363210439682, 46.74847349524498, 49.176421612501144, 99.90717262029648, 98.28890785574913, 50.74031889438629, 20.801582895219326, 60.071592181921005, 54.65619497001171, 29.187301620841026, 47.21413470804691, 47.7988625317812, 61.65829963982105, 61.08048364520073, 69.38895061612129, 50.3841982036829, 8.170723412185907, 0.528558287769556, 0.018289476211066358, 0.16835342481499538, 0.22149452328449115, 0.14195042283972725, 0.2233732255990617, 0.420492502162233, 0.2872593607753515, 0.5408455221913755, 0.4300696210702881, 0.2806965191848576, 0.018400833614578005, 0.224593598395586, 0.05437501546111889, 0.06600135995540768, 0.08982959931017831, 0.04061068822920788, 0.08263628100394271, 0.09456477608182468, 0.038227499899221584, 0.04549168217636179, 0.05605434351309668, 0.013880160713597434, 0.06427099811844528, 0.03258152981288731, 0.026700117086875252, 0.1167992755654268, 0.017647229033173062, 0.06354122946504503, 0.03148628682538401, 0.00986462506261887, 0.0465102353336988, 0.02343584917980479, 0.050948831340065226, 0.020130512675677892, 0.06118698860518634, 0.10089964474900626, 0.03694248975079972, 0.030542421554855537, 0.02712371828238247, 0.04506885838054586, 0.008551742630515946, 0.029507314793590922, 0.010538633378018858, 0.08846967306453735, 0.09510533418506384, 0.07700826346990652, 0.044599939792533405, 0.07604446596815251, 0.028751628487952985, 0.010919900614680955, 0.08324001813889481, 0.05977933855319861, 0.02053954180155415, 0.006495760253528715, 0.08987382389022969, 0.045707394820055924, 0.1667774296947755, 0.052267097125877626, 0.1502487767720595, 0.0816423819924239, 0.11413696178351529, 0.35177488171029836, 0.23072925978340209, 0.2111688890727237, 0.3564900130731985, 0.5458497349172831, 15.121082458645105, 56.4628916233778, 73.78667503595352, 68.55891555547714, 53.64343911409378, 51.50732673704624, 45.54211042821407, 37.719139605760574, 38.99404339492321, 30.696225352585316, 22.46012929826975, 36.952663734555244, 34.94556583464146, 28.96742071956396, 35.41702173650265, 24.227612055838108, 5.871210303157568, 0.5686461960431188, 0.047136136709013954, 0.13223183574154973, 0.22506708861328661, 0.41296540293842554, 1.336463454645127, 1.8317044177092612, 1.8471047538332641, 2.680925717577338, 2.8344256058335304, 6.671334793791175, 5.097492970526218, 7.839731248095632, 6.490815030410886, 7.197876814752817, 6.431162506341934, 6.145290546119213, 8.292355835437775, 8.695898931473494, 17.44439084082842, 8.43576394021511, 4.41886268556118, 3.9939134381711483, 5.5814069788903, 3.6585956811904907, 3.0214081099256873, 5.474009541794658, 3.9813280384987593, 3.2409437047317624, 2.8203354869037867, 2.2622589580714703, 2.2735681012272835, 3.9197948528453708, 3.9897023141384125, 5.060757016763091, 33.23522061109543, 76.02018758654594, 66.65957987308502, 61.57870151102543, 66.27327740192413, 71.07690364122391, 71.71953275799751, 67.71703273057938, 24.82123900204897, 6.516527300700545, 2.7384206699207425, 2.031484991312027, 1.650669425725937, 1.6577712446451187, 1.4883301430381835, 1.1242475733160973, 2.177861211821437, 0.8580608724150807, 0.3151094022905454, 1.4823809685185552, 0.5375884438399225, 1.3617841084487736, 1.3110202574171126, 1.0837039863690734, 1.6261230991221964, 1.8653349881060421, 1.3967487635090947, 1.6965991049073637, 2.8246520552784204, 2.495047766715288, 2.9616788774728775, 1.3802983774803579, 0.7891659974120557, 0.09042993740877137, 0.22256081138039008, 0.11914881120901555, 0.10858042049221694, 0.04811050239368342, 0.09321236037067138, 3.7248935736715794, 18.47045548260212, 37.0512418448925, 40.38644067943096, 92.99362599849701, 82.71105095744133, 38.92515689134598, 25.132413804531097, 69.55696240067482, 56.77321717143059, 33.27280819416046, 60.268007442355156, 58.58077637851238, 71.38292402029037, 67.17309951782227, 78.80628928542137, 62.713332027196884, 11.201755218207836, 0.43475675862282515, 0.08292274258565158, 0.09043703234056011, 0.10855078653548844, 0.10108346730703488, 0.19039519596844912, 0.2977872599149123, 0.25548899837303907, 0.4635910363867879, 0.338989220908843, 0.23253543942701072, 0.06346175287035294, 0.1479528538766317, 0.041509566362947226, 0.056353117324761115, 0.04648599679057952, 0.04402624108479358, 0.012109415838494897, 0.12503867328632623, 0.054843655743752606, 0.02054694286925951, 0.0363819381891517, 0.018136005637643393, 0.010290119662386132, 0.03853905349387787, 0.07423637158353813, 0.09938941133441404, 0.019635591088444926, 0.038133937341626734, 0.09345435246359557, 0.06439733391744085, 0.03449916148383636, 0.027305767107463907, 0.06579079039511271, 0.07279604105860926, 0.240044207603205, 0.22660164220724255, 0.10668451519450173, 0.1201410626526922, 0.16710756666725501, 0.18004480371018872, 0.19269613578217104, 0.13347528933081776, 0.21767770231235772, 0.2499012794578448, 0.26243918167892843, 0.15174110216321424, 0.17104056343669072, 0.1854896591976285, 0.12531133834272623, 0.10759061813587323, 0.17187981371534988, 0.14755371201317757, 0.10181975201703608, 0.09403254487551749, 0.1545982074458152, 0.208194954902865, 0.34838843217585236, 0.3065523208351806, 0.5783596623223275, 0.24653497181134298, 0.2147820350364782, 0.9579033649060875, 0.517082012956962, 0.7087852293625474, 0.707304080715403, 1.2474978785030544, 23.002928271889687, 69.97525915503502, 82.07492709159851, 78.04421737790108, 61.922176480293274, 59.262676388025284, 45.80331601202488, 42.10067309439182, 50.28646744787693, 36.73896700143814, 22.417689375579357, 62.98986218869686, 56.39825329184532, 43.740399107337, 55.42734459042549, 33.33768591284752, 11.456876378506422, 1.3086684211157262, 0.20872847002465278, 0.3355618641944602, 0.3247316140914336, 0.381564570707269, 0.9062707261182368, 1.4497770555317402, 1.4638628996908665, 3.0674694757908583, 6.295146429911256, 9.492246899753809, 7.466461602598429, 13.097269255667925, 14.023554101586342, 10.952012669295073, 20.31652182340622, 12.296229489147663, 19.935206584632397, 18.611350022256374, 40.505887269973755, 28.050497621297836, 15.057592615485191, 16.506834849715233, 26.303081586956978, 22.230287231504917, 18.412920869886875, 17.433812208473682, 9.51958928257227, 17.33223605901003, 13.20527845993638, 12.177710998803377, 8.042030967772007, 9.7339091822505, 7.611410524696112, 5.2243757620453835, 37.966468334198, 71.37793868780136, 66.62133872509003, 65.39630725979805, 67.68182381987572, 69.89867806434631, 69.98307153582573, 63.69557172060013, 30.559911467134953, 16.1824918538332, 14.04430003836751, 14.726217146962881, 9.656589031219482, 6.024247091263533, 6.4329279866069555, 14.942908119410276, 13.717943150550127, 4.707679012790322, 2.101584579795599, 4.5257077272981405, 4.043692192062736, 4.914284851402044, 2.7405338315293193, 2.196640041656792, 3.1218723440542817, 4.5288188103586435, 2.769689904525876, 3.773925192654133, 4.671285515651107, 3.6092256428673863, 3.888403787277639, 1.0670012701302767, 0.5256122583523393, 0.14977239217841998, 0.2125022909604013, 0.18911968159954995, 0.19526077550835907, 0.18487535387976095, 0.486957318498753, 7.616719789803028, 30.9514519572258, 60.69487273693085, 61.825551465153694, 102.0663383603096, 102.25944399833679, 69.02486935257912, 32.17641122639179, 73.93463149666786, 66.28131777048111, 45.44899262487888, 67.44368299841881, 68.13691020011902, 81.35406017303467, 78.5343986749649, 89.35201540589333, 71.4657823741436, 12.485307343304157, 0.919370879419148, 0.2003777798381634, 0.3406331967562437, 0.35002558026462793, 0.40845382784027606, 0.5514182173646986, 0.6569270370528102, 0.674789403565228, 0.9330499079078436, 0.8713036961853504, 0.5851678282488137, 0.35641440306790173, 0.4815778462216258, 0.13809459458570927, 0.22920623916434124, 0.2175122924381867, 0.22545486077433452, 0.10800693329656497, 0.29916792176663876, 0.19566581002436578, 0.11422224939451553, 0.1488542219158262, 0.10126632507308386, 0.1848191287717782, 0.14926544594345614, 0.21987206971971318, 0.21886779548367485, 0.09709255333291367, 0.1084112330863718, 0.16764418396633118, 0.11803098837845027, 0.15706351812696084, 0.08702925348188728, 0.1900372581440024, 0.2619550045346841], [0.05731017983634956, 0.007503503566113068, 0.02290261421876494, 0.04166112776147202, 0.022894621288287453, 0.03179855288180988, 0.028748379736498464, 0.039417400112142786, 0.05002774814784061, 0.03136237042781431, 0.02886216767365113, 0.03046663900022395, 0.058521186729194596, 0.05812502829940058, 0.05096733679238241, 0.03560395220119972, 0.050744250911520794, 0.03859847354760859, 0.01966102448932361, 0.022156045197334606, 0.07437901236698963, 0.034499925895943306, 0.04070133414643351, 0.07655892273760401, 0.13985260884510353, 0.014889862832205836, 0.06573611637577415, 0.1836248202016577, 0.07434678831486963, 0.24766419403022155, 0.8323476521763951, 10.764660872519016, 35.75228154659271, 61.86664626002312, 61.828108727931976, 54.93352688848972, 41.314844861626625, 22.91824411600828, 18.112273402512074, 17.4823185056448, 21.18798416107893, 25.283412002027035, 48.87487359344959, 45.34129500389099, 39.50128197669983, 57.996884509921074, 17.573828995227814, 0.8496400492731482, 0.057509977123118006, 0.1612981830839999, 0.04520538386714179, 0.1648490925435908, 0.08831862374790944, 0.16856631729751825, 0.484066178323701, 0.49636160605587065, 1.4491227781400084, 2.12557150516659, 1.9814469013363123, 3.671319060958922, 4.393174163997173, 4.8797922022640705, 5.749971158802509, 3.176827132701874, 4.949047761037946, 2.989147840999067, 5.443873358890414, 4.7223984729498625, 19.53472327440977, 6.852295808494091, 5.688518481329083, 4.554788991808891, 1.8260465213097632, 5.7073345966637135, 5.445247935131192, 4.183424944058061, 4.217966040596366, 9.926540795713663, 11.10027501359582, 15.628890059888363, 15.264360420405865, 18.88676304370165, 15.225890334695578, 27.491798400878906, 36.921326816082, 47.77961276471615, 38.75865742564201, 56.17398552596569, 49.516890943050385, 54.372418597340584, 45.62899276614189, 53.71927164494991, 46.184093579649925, 15.65167173743248, 9.257536344230175, 10.310694482177496, 10.973948892205954, 9.277912750840187, 5.418126415461302, 6.158827794715762, 6.253907717764378, 4.509536270052195, 10.509631857275963, 7.391984174028039, 5.4017673432827, 4.420992471277714, 3.190812519751489, 2.186888577416539, 0.7178291003219783, 0.48461637692525983, 1.889413227327168, 0.7914265198633075, 1.3078707014210522, 3.8542172592133284, 1.5206358907744288, 1.764358850196004, 0.5486029246822, 1.1810451443307102, 0.3841529740020633, 0.1001888453902211, 0.12023859570035711, 0.046650026270071976, 0.05896162911085412, 0.10951844320516102, 1.6069873259402812, 13.395254965871572, 32.62089617550373, 56.93757355213165, 63.541885167360306, 44.36539337038994, 34.882812201976776, 24.9641702324152, 41.25480428338051, 26.456969529390335, 24.353066124022007, 31.583396047353745, 43.71506966650486, 56.38127960264683, 65.0575478374958, 69.10816848278046, 35.237120389938354, 4.171437062323093, 0.07366514051682316, 0.11520169879077002, 0.12898415297968313, 0.14878270856570452, 0.2579676825553179, 0.23726651212200522, 0.16261740995105356, 0.338730983203277, 0.2569278742885217, 0.011072324759879848, 0.051725451776292175, 0.11167671254952438, 0.10910868862993084, 0.04514525877311826, 0.046917949002818204, 0.04961579310474917, 0.015554537712887395, 0.08634375393739901, 0.03881922908476554, 0.0060198882056283765, 0.055638429112150334, 0.049607911496423185, 0.016508219741808716, 0.07916373491752893, 0.08517739464878105, 0.06029822594427969, 0.1005965590593405, 0.00592081612921902, 0.03369964579178486, 0.051374479007790796, 0.06162375364510808, 0.041722933819983155, 0.010958822549582692, 0.057562098154448904, 0.07564568775705993, 0.006493648379546357, 0.034440617164364085, 0.08422339349635877, 0.04730528700747527, 0.025853562219708692, 0.011628650718193967, 0.04342185457062442, 0.01933966897922801, 0.06038342820829712, 0.03455836631474085, 0.06686622917186469, 0.04452648943697568, 0.046230883526732214, 0.05671239101502579, 0.05417041276814416, 0.07599328746437095, 0.009900202694552718, 0.04340302257332951, 0.06292088306508958, 0.032401837306679226, 0.03731561933818739, 0.04583117020956706, 0.04412406728079077, 0.06472420544014312, 0.0412186927133007, 0.08685962078743614, 0.08962879641330801, 0.04097021424968261, 0.06958259356906638, 1.1475928081199527, 13.85282451286912, 44.84935060143471, 73.83411169052124, 71.48728162050247, 64.83260750770569, 50.98115377128124, 33.69189530611038, 24.396505393087864, 25.99704410880804, 33.24883908033371, 34.09395173192024, 34.615770131349564, 43.88685084879398, 34.9552933126688, 35.81004224717617, 15.22101804614067, 1.141734947450459, 0.08261743787443265, 0.157890819828026, 0.1506966628949158, 0.3151131427148357, 0.21885783586185426, 1.1588481604121625, 1.4994554710574448, 2.5347793847322464, 3.8828679593279958, 4.436690378934145, 5.4505472257733345, 7.417311714962125, 6.3856361992657185, 5.050349375233054, 6.444118386134505, 6.968640340492129, 8.365306220948696, 3.428957615979016, 6.149100316688418, 6.802669996395707, 8.659073207527399, 5.6908544059842825, 4.091178243979812, 3.50388057064265, 3.309161919169128, 4.506396688520908, 2.4322138633579016, 3.2336350344121456, 5.324037289246917, 9.680476449429989, 11.783551499247551, 13.72238701209426, 17.083277218043804, 22.508411407470703, 18.39846644550562, 30.713425129652023, 46.214697137475014, 54.90140341222286, 47.06514470279217, 62.32269398868084, 56.17737874388695, 62.17672102153301, 56.85857579112053, 62.14505352079868, 51.94403350353241, 19.762992225587368, 12.296975199133158, 10.648627448827028, 9.793636277318, 9.025732632726431, 4.91479592397809, 6.730262031778693, 6.239456618204713, 6.045638993382454, 12.195669785141945, 10.104903224855661, 6.887482395395637, 5.733325676992536, 4.8207357712090015, 2.6666752947494388, 1.511125594843179, 1.9808540144003928, 2.4957333924248815, 1.1212989315390587, 1.7430780921131372, 2.5899284379556775, 3.309982675127685, 2.383073950186372, 1.7388832359574735, 1.749093763064593, 1.0654038120992482, 0.44237051100935787, 0.09222519263857976, 0.020478194019233342, 0.018933048122562468, 0.15690370404627174, 0.8418545045424253, 11.707878559827805, 28.569905050098896, 59.87773038446903, 67.83605754375458, 50.35337045788765, 26.13147709518671, 26.138102039694786, 52.299789413809776, 36.965655237436295, 41.24044485390186, 40.62223702669144, 51.694231107831, 68.19581463932991, 71.77884757518768, 76.99210703372955, 47.97700457274914, 6.371005084365606, 0.1370432978728786, 0.09086168181966059, 0.04692652822996024, 0.12918214313685894, 0.16951053694356233, 0.1073671574704349, 0.14017207373399287, 0.1360458365525119, 0.1120836469635833, 0.07504497858462855, 0.0717113477003295, 0.03247829336032737, 0.059866878582397476, 0.06532431347295642, 0.0075664534597308375, 0.03724631758814212, 0.08092166754067875, 0.09058676805580035, 0.018255736322316807, 0.022921479612705298, 0.06552012171596289, 0.08112691590213217, 0.02271242774440907, 0.003585124322853517, 0.052673864556709304, 0.025047999879461713, 0.12768805143423378, 0.004978331717211404, 0.012669763309531845, 0.040472949331160635, 0.020394060447870288, 0.054550036147702485, 0.028489496362453792, 0.07807240675901994, 0.18594481836771592, 0.2591398009099066, 0.08250611572293565, 0.2037170881521888, 0.15512703219428658, 0.13255616911919788, 0.18903093558037654, 0.11215508609893732, 0.07512654803576879, 0.3034350334201008, 0.12387583177769557, 0.17028404778102413, 0.22642885538516566, 0.20677028369391337, 0.17882153653772548, 0.12600333167938516, 0.2943505224538967, 0.19660885707708076, 0.10413862211862579, 0.30118113092612475, 0.13558168255258352, 0.11913394599105231, 0.11800839740317315, 0.18535399460233748, 0.5103352968581021, 0.149476527585648, 0.19592109398217872, 0.2675869851373136, 0.4231185471871868, 0.3792928863549605, 1.4399414020590484, 19.48106825351715, 57.33443945646286, 81.42991930246353, 79.75428521633148, 72.84816339612007, 58.75244736671448, 38.82945142686367, 28.207866176962852, 26.76665861159563, 31.306347213685513, 36.6649279743433, 65.29425993561745, 62.48221702873707, 53.359218165278435, 75.2448619902134, 24.911267571151257, 2.180225159972906, 0.14862141018966213, 0.1946151367155835, 0.19117357529466972, 0.2524828549940139, 0.24303785321535543, 0.7864071079529822, 1.2326840171590447, 2.783646793104708, 5.265695694833994, 5.703268339857459, 9.144203625619411, 11.496501602232456, 11.65642837062478, 11.841279901564121, 16.697079241275787, 13.849089313298464, 15.947246477007866, 13.24625451117754, 10.721861869096756, 17.219287119805813, 37.98297464847565, 16.4964310079813, 13.900366611778736, 9.593030791729689, 8.457010500133038, 11.02569641545415, 10.244126804172993, 8.660932257771492, 8.340517301112413, 14.380474649369717, 16.627187691628933, 19.741768464446068, 20.023162364959717, 27.382679656147957, 20.33933959901333, 33.71524125337601, 52.38775469362736, 59.72655549645424, 54.7878997027874, 66.25954493880272, 61.08153998851776, 67.90298715233803, 62.67450951039791, 67.82262906432152, 56.4329644292593, 21.40947427600622, 14.967335108667612, 15.092816725373268, 16.901595667004585, 17.22568027675152, 10.029698610305786, 12.420327980071306, 10.18763618543744, 6.897857263684273, 13.940166626125574, 10.224297568202019, 8.669107519090176, 7.682658126577735, 6.855884240940213, 5.548133114352822, 4.159115748479962, 4.434922998771071, 5.143340835347772, 2.9621246410533786, 3.7376706255599856, 9.988581966608763, 7.065874747931957, 5.114119928330183, 1.2237879820168018, 2.00690696015954, 0.5932505882810801, 0.29153042065445334, 0.22244879161007702, 0.18176254903664812, 0.12336964995483868, 0.5050170666072518, 2.5449614133685827, 18.784311041235924, 43.73548977077007, 65.93494355678558, 70.61976537108421, 60.84426172077656, 51.719317361712456, 32.896480187773705, 51.91488526761532, 39.47297349572182, 37.65515483915806, 45.64331419765949, 61.939028576016426, 79.14224445819855, 82.0319589972496, 85.50857484340668, 55.796817764639854, 7.089052554219961, 0.2887837024172768, 0.22838560194941238, 0.3646310465410352, 0.2606572851072997, 0.4304420010885224, 0.4831896722316742, 0.3714733215747401, 0.6290497141890228, 0.5123667628504336, 0.2081969438586384, 0.16120391548611224, 0.26936315232887864, 0.21060191793367267, 0.22439728549215943, 0.1942235796013847, 0.11406483987229876, 0.17447578691644594, 0.1552030281163752, 0.1272699996479787, 0.12412335287081078, 0.1923746374086477, 0.22856111987493932, 0.19168438069755211, 0.139832986460533, 0.17453297681640834, 0.2292722012498416, 0.23947919573402032, 0.11878573772264645, 0.14553170098224655, 0.17482618452049792, 0.1411463355179876, 0.13014371419558302, 0.10656283266143873, 0.1294824160868302], [0.10439257763209753, 0.01806508043955546, 0.04053517470310908, 0.03361137103638612, 0.02840568562533008, 0.012412731593940407, 0.03573309331841301, 0.07671751969610341, 0.044099988299421966, 0.09186116178170778, 0.08623843576060608, 0.04442940167791676, 0.04899562110949773, 0.03855168113659602, 0.03496725628792774, 0.032333303679479286, 0.07205063535366207, 0.013965155176265398, 0.09114993197727017, 0.04602834400429856, 0.0955990405054763, 0.046794540976407006, 0.05232162642641924, 0.04432991307112388, 0.11424844720750116, 0.03128614443994593, 0.07719646469922736, 0.01932799870701274, 0.09315836170571856, 0.04888995041255839, 5.510384514927864, 41.12036369740963, 62.95857846736908, 62.84489616751671, 60.940540954470634, 35.61981685459614, 34.694741293787956, 30.58324221521616, 23.014485351741314, 21.77614890038967, 22.203367576003075, 39.23741273581982, 47.052742168307304, 43.772587180137634, 32.793106734752655, 10.922998376190662, 0.2411834042868577, 0.3378593159141019, 0.07375773828243837, 0.04414595692651346, 0.039487789108534344, 0.1333059460739605, 0.34869692812208086, 1.469078476075083, 2.1185931796208024, 5.035789981484413, 4.12507432512939, 2.3649161495268345, 1.9367227074690163, 5.487328777089715, 3.980990331619978, 6.01387744769454, 4.050372708588839, 7.533664796501398, 3.40649725869298, 5.5014958418905735, 4.633251931518316, 8.613088075071573, 9.478072710335255, 6.46828081458807, 2.763768872246146, 3.7013305630534887, 4.6541940327733755, 4.5082923118025064, 5.156793538480997, 9.116615206003189, 17.526025660336018, 22.247832790017128, 33.97432655096054, 40.264444425702095, 39.19560357928276, 38.213781863451004, 48.82467828691006, 51.104544550180435, 33.14910963177681, 44.34145085513592, 42.052301689982414, 50.18291540443897, 43.05379115045071, 49.79401007294655, 44.36366826295853, 47.30625696480274, 38.568101450800896, 42.35798768699169, 26.285577826201916, 26.02940507233143, 35.595091581344604, 28.255057744681835, 27.860992290079594, 28.17129123955965, 31.097785905003548, 32.01704777777195, 44.11445863544941, 39.95801366865635, 33.552404791116714, 37.540089413523674, 25.490041114389896, 25.691696293652058, 19.242097176611423, 12.540898360311985, 3.506280854344368, 0.3039944643387571, 0.6444581842515618, 1.1844591423869133, 2.377882953733206, 1.4304996212013066, 2.3812445858493447, 1.7704279557801783, 1.1410364974290133, 0.936524405842647, 0.07721689602476545, 0.034218355067423545, 0.0579534140706528, 0.04556290979962796, 0.05898655785131268, 0.10998884608852677, 6.124622980132699, 19.836468882858753, 37.25350119173527, 29.66833870857954, 63.4689024835825, 45.757391676306725, 17.46977347880602, 15.803030915558338, 14.861299898475409, 21.483163721859455, 40.605453327298164, 47.83717967569828, 51.78000010550022, 62.087292820215225, 68.49820241332054, 19.87176138907671, 0.26001265563536435, 0.07963978554471396, 0.030364576996362302, 0.04746851496747695, 0.21183223550906405, 0.15299499034881592, 0.1297783845802769, 0.12226280348841101, 0.05468119590659626, 0.1273951554321684, 0.016398875413869973, 0.05683269315341022, 0.04373630254121963, 0.01846804065280594, 0.07542569292127155, 0.0436258709669346, 0.06918227169080637, 0.03217013509129174, 0.033981379892793484, 0.025740779892657883, 0.057044197819777764, 0.011444560059317155, 0.06514665816212073, 0.1256890024524182, 0.08247275618487038, 0.06907996663358063, 0.0860580790322274, 0.12032688900944777, 0.053471176070161164, 0.00665717830088397, 0.040033668410615064, 0.04727363811980467, 0.0601009408273967, 0.01538961394544458, 0.05262210717773996, 0.0493736191856442, 0.0534258419793332, 0.023072298863553442, 0.07176623694249429, 0.028326001229288522, 0.04846344185352791, 0.0234091337188147, 0.08673211981658824, 0.09865150132100098, 0.010987754249072168, 0.06316237791907042, 0.0751723385474179, 0.1265627477550879, 0.043906825812882744, 0.028968838414584752, 0.0521355291857617, 0.04805805110663641, 0.12299981550313532, 0.061017597108730115, 0.04807833771337755, 0.053763018222525716, 0.050860192932304926, 0.037821110963704996, 0.03365455660969019, 0.03960289992392063, 0.047602832564734854, 0.07614450747496448, 0.05988679040456191, 0.13737640343606472, 8.680669348686934, 50.75019836425781, 72.54671037197113, 73.52535545825958, 66.45730152726173, 47.38742060959339, 41.61493755877018, 36.45860284566879, 28.421167731285095, 25.26130858808756, 26.512389555573463, 34.2026486992836, 43.94804656505585, 38.294193148612976, 31.011568531394005, 11.121224239468575, 0.33097470877692103, 0.1297367352526635, 0.1725706344586797, 0.2499675384024158, 0.38795440283138305, 1.3027800433337688, 1.3962245103903115, 2.5610093772411346, 4.258957291021943, 7.738425834104419, 4.354263776913285, 5.287613393738866, 6.321968715637922, 6.92000437527895, 6.519345799461007, 6.546244081109762, 5.672942642122507, 5.903725633397698, 3.9749505557119846, 3.4940044255927205, 3.450396303087473, 7.846213225275278, 9.205688126385212, 8.044573031365871, 4.57449758425355, 4.179565301164985, 5.746207935735583, 5.0089220982044935, 6.3628725707530975, 9.758778847754002, 18.184264339506626, 26.69495265930891, 35.81768363714218, 43.09212729334831, 41.78562819957733, 41.544926315546036, 52.97635830938816, 54.15405571460724, 40.34158028662205, 49.83211822807789, 47.19587668776512, 56.74317218363285, 49.85539197921753, 57.09986284375191, 52.13112026453018, 52.05678105354309, 45.990414172410965, 45.50585277378559, 30.19301265478134, 30.168011896312237, 39.460468366742134, 31.371057741343975, 31.055518873035908, 31.106168255209923, 33.795325756073, 36.192704513669014, 48.04019138216972, 42.10872866213322, 38.548771888017654, 40.89295729994774, 30.313675180077553, 30.370339639484882, 22.95279946178198, 14.813054837286472, 4.9940544459968805, 0.8043440454639494, 0.19537806452717632, 1.0977627569809556, 1.4321102597750723, 2.081623775884509, 3.1227384600788355, 3.466657530516386, 3.3050609892234206, 1.3617813773453236, 0.8330770942848176, 0.055893067401484586, 0.11682463475153781, 0.0650099545600824, 0.10842339688679203, 0.09754276237799786, 3.076499216258526, 23.152659237384796, 39.76732090115547, 30.427133291959763, 51.25675678253174, 35.012666434049606, 24.241289421916008, 19.778109714388847, 20.560523830354214, 28.630213513970375, 52.16848365962505, 58.77342224121094, 59.70929682254791, 69.69068482518196, 79.96791735291481, 27.91491899639368, 0.5045140685979277, 0.11531218973686919, 0.07988810073584318, 0.044613135178224184, 0.21587106253718957, 0.05557373609917704, 0.1177931077836547, 0.04775594134116545, 0.07124668903998099, 0.06567566844751127, 0.0527472778048832, 0.03399111687031109, 0.017141540738521144, 0.07820629762136377, 0.06841459413408302, 0.007504432178393472, 0.0380800982384244, 0.02078062476357445, 0.03927141224266961, 0.009595990795787657, 0.05878521318663843, 0.04940455190080684, 0.07566870917798951, 0.04539069443126209, 0.049693462569848634, 0.03757764941838104, 0.03998429703642614, 0.0562320804601768, 0.0225904965918744, 0.048222707700915635, 0.014048788725631312, 0.03637070949480403, 0.08620721360784955, 0.05010559943912085, 0.22042157070245594, 0.16182351973839104, 0.11747195079806261, 0.19584606285206974, 0.19322987354826182, 0.135905496426858, 0.15966882754582912, 0.14590379898436368, 0.19556291867047548, 0.18348850251641124, 0.18105056224158034, 0.10231922482489608, 0.13967039674753323, 0.2285995482816361, 0.13988376420456916, 0.14328342396765947, 0.12174673625850119, 0.1422959371120669, 0.21663369348971173, 0.25898626539856195, 0.1680397635209374, 0.12275711836991832, 0.21071882103569806, 0.1576963474508375, 0.22720275213941932, 0.2010607041302137, 0.29011297796387225, 0.2978769113542512, 0.13316369120730087, 0.2893802704056725, 12.986867129802704, 62.17142790555954, 81.82699799537659, 84.12487909197807, 78.59929159283638, 51.263167038559914, 47.17480681836605, 40.22477075457573, 32.403734028339386, 31.626299545168877, 32.88433603942394, 52.85391367971897, 60.85165612399578, 58.342388570308685, 45.442073196172714, 15.196911189705133, 0.7535537739749998, 0.5457381752785295, 0.4044809628976509, 0.4012854828033596, 0.402726941392757, 1.4086076896637678, 1.3432706706225872, 2.9865278815850616, 6.029564430937171, 13.416486326605082, 10.885910466313362, 9.355962462723255, 11.947763487696648, 15.006990730762482, 12.518620155751705, 16.863075233995914, 12.312152534723282, 17.036938704550266, 10.094769168645144, 14.20101122930646, 10.14412946999073, 17.38997396081686, 21.851639449596405, 12.572617158293724, 6.9047030713409185, 8.051026035100222, 9.02891306206584, 7.56077871657908, 8.702619820833206, 11.257704365998507, 21.360306814312935, 26.81645303964615, 37.16723442077637, 44.317154958844185, 46.61101587116718, 48.80955509841442, 56.71046733856201, 61.5129080414772, 47.52667933702469, 55.23509010672569, 52.679472640156746, 61.301172003149986, 54.46230657398701, 63.812286257743835, 57.02164404094219, 58.354513719677925, 49.25079122185707, 50.4558851569891, 34.138382747769356, 33.52436229586601, 41.683713868260384, 35.28025187551975, 35.08531093597412, 31.634290516376495, 34.29340682923794, 36.052716225385666, 48.86412017047405, 45.36895751953125, 39.09047842025757, 43.897896856069565, 30.423063710331917, 32.66400866210461, 25.29212113469839, 16.267856173217297, 8.163053523749113, 4.400336304679513, 6.152928611263633, 6.516580497846007, 7.727885199710727, 7.01781777665019, 8.963841553777456, 4.09387799911201, 3.733243625611067, 1.7548560351133347, 0.7416691398248076, 0.11412631196435541, 0.18576919654151425, 0.17810652178013697, 0.23441409721272066, 0.4245172580704093, 8.855326976627111, 29.53087728470564, 48.80892053246498, 43.308198899030685, 88.18673953413963, 61.163539588451385, 30.070740915834904, 24.120435006916523, 25.105950124561787, 35.788144022226334, 57.34370715916157, 66.16780266165733, 72.18058481812477, 78.82598742842674, 92.00348272919655, 34.457105845212936, 0.8430566056631505, 0.21769119455711916, 0.1975460263201967, 0.1905540155712515, 0.527516728034243, 0.3168505401117727, 0.2552615152671933, 0.2584903623210266, 0.2469938268768601, 0.2707991190254688, 0.20747419592225924, 0.17197602574015036, 0.25347712507937104, 0.1773422581027262, 0.20434773556189612, 0.16814155649626628, 0.10314370636478998, 0.12965527712367475, 0.12151382063166238, 0.07675543602090329, 0.1331494122860022, 0.11503472298500128, 0.24772243777988479, 0.26050858839880675, 0.19803392904577777, 0.20923574280459434, 0.2425228027277626, 0.17798690241761506, 0.1334974350174889, 0.17492281214799732, 0.11822562402812764, 0.1508371069212444, 0.2309652479016222, 0.15387545950943604], [0.08713866089237854, 0.0842877005925402, 0.05653074294968974, 0.05776841891929507, 0.030072766385274008, 0.018722751301538665, 0.026364397308498155, 0.015359429871750763, 0.10836175410076976, 0.064432667568326, 0.05635029716358986, 0.03169262985466048, 0.05778987811936531, 0.02324213564861566, 0.04576930477924179, 0.013904208153689979, 0.05611741122265812, 0.02534881088649854, 0.07428668177453801, 0.04496615627431311, 0.07314701011637226, 0.04209428225294687, 0.1056106794567313, 0.021533965882554185, 0.1053170116210822, 0.007344099522015313, 0.011287260003882693, 0.01209614716572105, 0.09786118083866313, 2.802849537692964, 47.175574377179146, 62.26196564733982, 66.45447447896004, 54.75418031215668, 50.187828540802, 26.47275198251009, 65.54981902241707, 61.25872068107128, 20.08362092077732, 27.58943796157837, 33.199776113033295, 43.75369839370251, 36.68589144945145, 36.112031042575836, 4.543735384941101, 0.17668005457380787, 0.19155952177243307, 0.10402229789178818, 0.016762357081461232, 0.11033685397705995, 0.2692611515522003, 1.0195495351217687, 1.7717196489684284, 3.7428124621510506, 3.828017902560532, 4.3684987630695105, 2.886195690371096, 5.009166710078716, 5.204119523987174, 4.8862870037555695, 5.7622231263667345, 4.1096751764416695, 3.544070301577449, 7.015898879617453, 9.768582321703434, 3.660572050139308, 12.355649750679731, 18.16870417445898, 18.72116792947054, 17.648848369717598, 11.130771227180958, 10.878171231597662, 12.907296549528837, 19.62035547941923, 15.635333564132452, 24.9406760931015, 38.483799174427986, 48.88755351305008, 54.58879038691521, 61.43112502992153, 46.65262743830681, 45.2853088080883, 63.89180839061737, 49.504458010196686, 36.58502206206322, 42.00215198099613, 47.01741926372051, 47.22610026597977, 40.46101927757263, 45.190177112817764, 45.257167518138885, 37.429427951574326, 45.14785498380661, 51.43374748528004, 33.05492788553238, 53.47352363169193, 57.80752167105675, 57.87203460931778, 56.564999744296074, 58.50038789212704, 59.02118794620037, 59.19641174376011, 60.4360344260931, 59.36136469244957, 60.66521532833576, 56.1251125484705, 53.75855773687363, 57.063031420111656, 51.024425849318504, 41.90285570919514, 32.724307626485825, 19.990978091955185, 8.926302418112755, 2.07730483263731, 1.8494643084704876, 2.2485889540985227, 3.546451823785901, 2.9030045634135604, 3.427105452865362, 0.6478114449419081, 0.9527005534619093, 0.27673781441990286, 0.04901994871033821, 0.04196988345938735, 0.07239853934152052, 0.04478296825254802, 0.12299417518079281, 1.1695654853247106, 19.257115870714188, 57.508641108870506, 27.337621673941612, 39.51585419476032, 49.81169432401657, 45.84564954042435, 39.90685321390629, 21.644797548651695, 17.801938354969025, 28.486879505217075, 52.73266218602657, 48.66023451089859, 64.58708748221397, 51.87882520258427, 8.411297053098679, 0.10673859549569897, 0.07190682197688147, 0.028958040165889543, 0.12212748028105125, 0.07383649499388412, 0.03739302534086164, 0.10061676031909883, 0.10049572345451452, 0.030601427861256525, 0.026574725670798216, 0.032871835719561204, 0.09982693707570434, 0.07432716593029909, 0.018884272321884055, 0.05477260994666722, 0.04174321671598591, 0.03170739859342575, 0.05074834014521912, 0.06131386988272425, 0.03500873863231391, 0.043178782652830705, 0.03358444220793899, 0.019904204018530436, 0.03901447700627614, 0.02595656675111968, 0.020869174113613553, 0.010079442490678048, 0.023551197482447606, 0.012076675066055031, 0.06593760946998373, 0.01005117965178215, 0.0350883488135878, 0.019582744607760105, 0.024681616414454766, 0.05452029829029925, 0.05906035330554005, 0.08287498538265936, 0.023742656740068924, 0.0770671825739555, 0.04289789831091184, 0.018888337435782887, 0.08246011740993708, 0.01964949336979771, 0.09609795670257881, 0.0019011884614883456, 0.054304763762047514, 0.04649433110898826, 0.04430932218383532, 0.01886107464088127, 0.030842245505482424, 0.031218419753713533, 0.004040377652927418, 0.12080794913345017, 0.031870233215158805, 0.06831948048784398, 0.09413332110852934, 0.04086492204805836, 0.08547524077584967, 0.05008314205042552, 0.03624564647907391, 0.024783648732409347, 0.12270103426999412, 4.7750303987413645, 55.33566690981388, 70.88958129286766, 74.14017766714096, 64.71749648451805, 58.534662052989006, 33.827806413173676, 67.59637400507927, 50.86485341191292, 16.252656988799572, 26.223802641034126, 29.439539685845375, 41.083809658885, 33.07647652924061, 28.929018080234528, 4.160216264426708, 0.17929725319845602, 0.045174955812399276, 0.21012391545809805, 0.08102119696559384, 0.5246491287834942, 1.6609400371089578, 2.4575026938691735, 3.5550633491948247, 3.9303397620096803, 5.864176405593753, 6.000747727230191, 5.401764018461108, 5.468422891572118, 7.991303689777851, 4.666317757219076, 5.545772016048431, 3.9783207373693585, 2.9169975500553846, 4.706483976915479, 7.52814369276166, 7.260666070505977, 13.522210903465748, 17.112075872719288, 16.825523748993874, 14.186972882598639, 11.032490450888872, 11.716088019311428, 12.559800446033478, 20.02341505140066, 18.399836272001266, 26.546384431421757, 37.68422327935696, 49.44699369370937, 56.56936950981617, 63.71460109949112, 50.01138120889664, 49.74512189626694, 66.52404874563217, 52.46132634580135, 40.38796439766884, 47.31052793562412, 53.382423520088196, 52.657441422343254, 47.6859325915575, 52.09501840174198, 54.05965358018875, 43.845030292868614, 48.92867490649223, 55.28478763997555, 37.69683860242367, 56.96525126695633, 58.21947656571865, 60.49341894686222, 58.44948582351208, 61.021423414349556, 60.09914830327034, 60.840100944042206, 63.624059557914734, 58.96266728639603, 58.15654054284096, 57.88584686815739, 53.983311876654625, 58.383437767624855, 52.85964377224445, 44.77373085916042, 35.96181370317936, 24.171065390110016, 10.14523046091199, 3.5912813432514668, 2.0806415285915136, 1.1878951080143452, 4.122067736461759, 3.1810439564287663, 3.0068434914574027, 1.0847380058839917, 1.7427477473393083, 0.9414064313750714, 0.13293154741404578, 0.1944321082555689, 0.09611637680791318, 0.07043431935016997, 0.08320384586113505, 1.3104758178815246, 17.870059199631214, 46.012924164533615, 33.853360041975975, 51.006950587034225, 48.4733871370554, 41.75942100584507, 33.048844411969185, 29.570482559502125, 33.73431243002415, 35.951451659202576, 59.77543227374554, 56.44864238798618, 70.91517671942711, 65.67909568548203, 15.30548656359315, 0.15004413697170094, 0.09712810220662504, 0.05155955208465457, 0.026241184095852077, 0.16948049480561167, 0.0701703671074938, 0.03710681608936284, 0.09674136163084768, 0.05100185779156163, 0.031317229295382276, 0.030444717813224997, 0.08757459843764082, 0.0831525782996323, 0.03408329532248899, 0.08353764904313721, 0.03228601402952336, 0.022205884124559816, 0.0622043803014094, 0.08647416412713937, 0.0034049751639031456, 0.037586844628094696, 0.0828971533337608, 0.02224232543085236, 0.07281448342837393, 0.03361016133567318, 0.021775082241219934, 0.01891779884317657, 0.03966569303884171, 0.045148375793360174, 0.053649039182346314, 0.010442332295497181, 0.016573816319578327, 0.037714716672780924, 0.16767477529356256, 0.20665805612225085, 0.17910104419570416, 0.1889429020229727, 0.0979913906485308, 0.16340880654752254, 0.12578295834828168, 0.13689359184354544, 0.2690752880880609, 0.2474578027613461, 0.13127117010299116, 0.2199457649840042, 0.16166989516932517, 0.1357223789091222, 0.12723413907224312, 0.11099581432063133, 0.17668032174697146, 0.25162134028505534, 0.10393492484581657, 0.24112881190376356, 0.1368029013974592, 0.27625868387985975, 0.32846218266058713, 0.12036358079058118, 0.1587946666404605, 0.12731068418361247, 0.10020935835200362, 0.11419073038268834, 0.3264050680445507, 7.204146953299642, 68.07739779353142, 81.40248477458954, 83.83854165673256, 76.635252982378, 70.91310203075409, 39.88947294652462, 77.55771428346634, 67.62044951319695, 30.21390773355961, 39.25013445317745, 45.280087888240814, 58.315144032239914, 48.342442363500595, 47.63274684548378, 6.757837627083063, 0.868618784006685, 0.6742411048617214, 0.4075095191365108, 0.15699221257818863, 0.4338061565067619, 1.4550825208425522, 2.92530604172498, 4.425127124413848, 10.80442763864994, 11.336766723543406, 12.097030878067017, 10.93335947021842, 13.520794529467821, 13.300665691494942, 10.743625201284885, 13.047917503863573, 9.166860859841108, 11.124638356268406, 13.742748219519854, 15.131854880601168, 7.464304743334651, 18.47195640206337, 23.2526071742177, 26.687275171279907, 22.03036665916443, 14.858263861387968, 14.445632603019476, 16.284313090145588, 26.42493534833193, 21.045007333159447, 29.27674502134323, 42.68181391060352, 50.90681076049805, 56.95391647517681, 63.13797824084759, 56.376218274235725, 54.03327539563179, 69.12211373448372, 54.567530527710915, 45.09780026972294, 52.352492585778236, 58.52224051952362, 58.21272432804108, 51.73235446214676, 57.89843559265137, 59.85186517238617, 49.51871104538441, 53.77598360180855, 60.209824964404106, 39.81943130493164, 56.69950492680073, 59.65631626546383, 65.2474844455719, 58.409815952181816, 62.69143380224705, 60.155552476644516, 62.358868047595024, 63.99783790111542, 64.47327598929405, 64.34433370828629, 56.51070445775986, 57.06781156361103, 62.36826114356518, 57.20931597054005, 50.558236464858055, 41.878818199038506, 28.467525243759155, 12.554829362779856, 6.136883022263646, 7.088489234447479, 6.811232836917043, 9.892601016908884, 8.33958350121975, 9.789353907108307, 3.128736913204193, 2.729956624098122, 0.6102469575125724, 0.2389595884596929, 0.19048450601985678, 0.27453737624455243, 0.2211448084563017, 0.4397833248367533, 2.236572573892772, 29.318352788686752, 72.15915396809578, 41.76820993423462, 57.83574655652046, 66.44421502947807, 68.03780391812325, 56.97032019495964, 34.12333935499191, 29.700834564864635, 42.88214676082134, 69.2743107676506, 66.562320291996, 78.46851781010628, 75.31507462263107, 18.156694918870926, 0.6195509363897145, 0.18428739480441436, 0.2189433015882969, 0.20991277444409207, 0.28600343910511583, 0.19444785662926733, 0.2052808229927905, 0.20029969105962664, 0.13692189735593274, 0.17198227462358773, 0.20490372291533276, 0.15592657757224515, 0.17977486975723878, 0.13141479052137583, 0.15345185645855963, 0.15750006423331797, 0.12871383310994133, 0.13472718856064603, 0.1664598350180313, 0.1796761789591983, 0.1783536866423674, 0.17788125027436763, 0.1616590894991532, 0.14141386491246521, 0.1690983332809992, 0.094851668109186, 0.1511747989570722, 0.14361133449710906, 0.08261162685812451, 0.186497169197537, 0.11316595802782103, 0.14378480409504846, 0.20913864020258188], [0.019336533405294176, 0.05378013585868757, 0.012330995159572922, 0.07529777634772472, 0.03242223152483348, 0.04261730340658687, 0.02963370810903143, 0.05986258154734969, 0.13553699041949585, 0.08736773219425231, 0.018759992271952797, 0.01013422504911432, 0.04788170939718839, 0.02787239500321448, 0.025356711048516445, 0.05404144976637326, 0.016757653720560484, 0.027840130132972263, 0.039445720467483625, 0.03515652992064133, 0.0028958493339814595, 0.048479086326551624, 0.022252277631196193, 0.031672079785494134, 0.1431585056707263, 0.07043284247629344, 0.01453384345950326, 0.056036765745375305, 3.8078647339716554, 29.973089955747128, 63.32227975130081, 67.20507860183716, 54.44013096392155, 37.9453756660223, 32.64123648405075, 22.603888884186745, 59.66400325298309, 65.46240091323853, 33.90769712626934, 30.502196364104748, 43.617034927010536, 42.95590840280056, 35.527759194374084, 5.58507283218205, 0.16131911164848134, 0.07339542920817621, 0.03742434397281613, 0.18438332481309772, 0.14946788898669183, 0.5525183770805597, 1.4229648630134761, 1.8208850920200348, 3.182785212993622, 2.517681964673102, 5.519216191023588, 5.0891742669045925, 1.854722632560879, 2.793877269141376, 2.3934459686279297, 2.743315282277763, 5.974096432328224, 5.944119365885854, 12.016927376389503, 15.118900425732136, 24.62158441543579, 30.518161207437515, 32.721761763095856, 42.72850200533867, 39.240988343954086, 33.19598391652107, 27.09936685860157, 31.962934881448746, 36.69156454503536, 41.15304194390774, 40.29538616538048, 49.19496841728687, 59.041805639863014, 64.82822254300117, 63.61596219241619, 60.89535377919674, 61.569376811385155, 63.203619718551636, 62.52419337630272, 66.3283060491085, 54.62714932858944, 29.510987251996994, 44.134057983756065, 40.48089601099491, 37.997790053486824, 41.4046074450016, 37.619410157203674, 52.03393667936325, 64.94455710053444, 58.94109584391117, 61.39541074633598, 65.33481895923615, 59.966759607195854, 62.879618704319, 61.17284148931503, 62.287181094288826, 64.79650184512138, 62.77296982705593, 58.15096244215965, 59.09105099737644, 63.021362498402596, 58.767521157860756, 54.03699919581413, 57.83621773123741, 58.59998054802418, 59.571204632520676, 51.28505766391754, 47.310520336031914, 41.53591699898243, 30.39331130683422, 12.758816666901112, 4.641526462510228, 2.934238649904728, 3.2197467796504498, 2.2539877519011497, 1.4350385963916779, 1.2638536258600652, 0.5810467118863016, 0.4386396158952266, 0.08123799314489588, 0.026237243291689083, 0.013171570171834901, 0.07135412233765237, 0.03545091763953678, 0.9824008285067976, 14.564524423331022, 33.86953957378864, 33.440447598695755, 36.909881830215454, 39.22149159014225, 40.146551951766014, 34.72388572990894, 26.711705960333347, 39.21161592006683, 37.897460237145424, 49.843358024954796, 53.59094113111496, 66.61124646663666, 45.748465955257416, 2.757583041675389, 0.22586314589716494, 0.0575405424751807, 0.04889018789981492, 0.04378279067168478, 0.11062828794820234, 0.038290857046376914, 0.01464621389459353, 0.013633578437293181, 0.036811426471103914, 0.02386140407907078, 0.07856010910472833, 0.021210166851233225, 0.025947473586711567, 0.05960118600341957, 0.04147536448726896, 0.06341953208902851, 0.07052100962027907, 0.06936010511708446, 0.0334292739717057, 0.037589920830214396, 0.03284540041931905, 0.01654508221690776, 0.06663072344963439, 0.04689113891799934, 0.04797974710527342, 0.0022678080222249264, 0.03504847321892157, 0.07858432538341731, 0.007461436316589243, 0.0069039066875120625, 0.009792504079086939, 0.05653366330079734, 0.007919294585008174, 0.02852312863979023, 0.019673507413244806, 0.035253432142781094, 0.05149555297975894, 0.02933324776677182, 0.018111837598553393, 0.06634694102103822, 0.14998561120592058, 0.054945259471423924, 0.059520629583857954, 0.034208473371108994, 0.04721709759905934, 0.04300837441405747, 0.05639780203637201, 0.04091253453225363, 0.03186140165780671, 0.004298132962503587, 0.043247750436421484, 0.11113428423414007, 0.05835588075569831, 0.022337001209962182, 0.055148704414023086, 0.0447642475774046, 0.05710637124138884, 0.07612626548507251, 0.04999788783607073, 0.12654774152906612, 5.377832427620888, 39.126644879579544, 73.88245269656181, 74.94857668876648, 63.58388051390648, 48.055816143751144, 49.123239666223526, 26.56635995954275, 61.64038360118866, 68.82267460227013, 29.53212171792984, 27.156852073967457, 35.65851777791977, 42.08831235766411, 29.782144501805305, 4.8468137718737125, 0.08711070418939926, 0.14199766796082258, 0.11419375834520906, 0.4139790282351896, 1.3361322786659002, 2.487490684725344, 2.198677444830537, 4.717135280370712, 4.7072415612638, 4.3671422358602285, 6.525700008496642, 6.407551048323512, 4.452881310135126, 4.632014622911811, 4.7813143115490675, 4.022578150033951, 5.120337819680572, 7.286183126270771, 12.662364542484283, 17.327136732637882, 25.886794924736023, 31.955586075782776, 33.312291875481606, 41.34289115667343, 37.26748064160347, 32.5987433642149, 27.5414864346385, 33.76078560948372, 36.35637313127518, 41.38733357191086, 42.49735660851002, 49.92766410112381, 59.18112136423588, 66.09607011079788, 64.29257288575172, 60.4416087269783, 63.67061845958233, 64.51969429850578, 64.13282945752144, 67.34266921877861, 56.33188605308533, 36.57593674957752, 49.94227811694145, 47.18423031270504, 43.77327114343643, 47.70314186811447, 43.14009211957455, 54.943242967128754, 65.20994246006012, 60.2737071365118, 64.09371435642242, 66.96974962949753, 61.098806262016296, 63.64399328827858, 60.38427360355854, 63.57810862362385, 64.03851091861725, 64.8284125328064, 60.4025050252676, 61.52814142405987, 64.62814807891846, 59.7889519482851, 56.380162462592125, 62.4999962747097, 64.03025776147842, 65.57481408119202, 59.16091404855251, 52.514854073524475, 45.10638780891895, 34.16238985955715, 15.525181274861097, 5.786641566082835, 2.7980242716148496, 0.9454787441063672, 2.253497103229165, 3.437655824236572, 2.932946481741965, 1.9708261149935424, 1.8012342089787126, 0.5276574986055493, 0.328739745891653, 0.058788456371985376, 0.13758644607150927, 0.04658160025428515, 0.8379151253029704, 14.812738504260778, 32.199969962239265, 33.54731686413288, 34.102288484573364, 33.299566358327866, 32.773435190320015, 35.83085373044014, 27.278481647372246, 47.190716564655304, 48.07913549244404, 58.10063034296036, 60.96894443035126, 71.8984803557396, 64.53485548496246, 7.0188152231276035, 0.46038899570703506, 0.11196992767509073, 0.07086996003636159, 0.019613282129284926, 0.040773463479126804, 0.03688569318910595, 0.1020271006564144, 0.07279730270965956, 0.0343440748838475, 0.05880731805518735, 0.048138900674530305, 0.025497643036942463, 0.09603662561858073, 0.0224122679719585, 0.05889300642593298, 0.038978690645308234, 0.07735185557976365, 0.02283800840814365, 0.04687705295509659, 0.09199137159157544, 0.018140801767003722, 0.056960609726957045, 0.013633586786454543, 0.06626305606914684, 0.027085978217655793, 0.08640956759336405, 0.09407940407982096, 0.05243258492555469, 0.04999454446078744, 0.09156323401839472, 0.019730702879314777, 0.05832322625792585, 0.10841363022336736, 0.19182331074262038, 0.15195347514236346, 0.10734455907368101, 0.1237059393315576, 0.1874304495868273, 0.11459675937658176, 0.19627094239694998, 0.30612772330641747, 0.16280138836009428, 0.15593757620081306, 0.12016527893138118, 0.1527543118572794, 0.1754496034118347, 0.1639277904178016, 0.16620027628960088, 0.12091194628737867, 0.14090196113102138, 0.16280386713333428, 0.13664161786437035, 0.14780055033043027, 0.18754376069409773, 0.11273413940216415, 0.17914300522534177, 0.20231894130120054, 0.16431614145403728, 0.16451897041406482, 0.2034337806981057, 7.245607003569603, 53.97652544081211, 83.2793940603733, 82.65253409743309, 73.80643397569656, 55.82634598016739, 49.87518511712551, 36.24386116862297, 67.04567715525627, 72.27567091584206, 44.10873994231224, 40.78644901514053, 59.0475395321846, 55.83376698195934, 47.04953894019127, 8.201216775923967, 0.4636760865105316, 0.2763725887052715, 0.14256665774155408, 0.6544043880421668, 1.5687080612406135, 2.953779101371765, 2.4106630822643638, 6.662286529317498, 11.461064703762531, 7.439366681501269, 13.361129947006702, 12.602356262505054, 9.5453623495996, 9.766176100820303, 9.844568744301796, 10.735900215804577, 13.157344032078981, 12.430893313139677, 19.712618328630924, 19.92787677794695, 30.366270057857037, 37.470537945628166, 40.05297437310219, 45.18644951283932, 41.31974279880524, 37.329766899347305, 30.842036828398705, 37.36883260309696, 40.488461405038834, 45.249450132250786, 45.526402071118355, 52.05357402563095, 61.942338198423386, 70.13211473822594, 67.44738399982452, 64.6081231534481, 66.60050064325333, 66.50994390249252, 67.81607821583748, 65.49862816929817, 59.89614799618721, 38.49962532520294, 54.29966390132904, 51.90993793308735, 49.03155438601971, 51.893959790468216, 51.04413539171219, 57.170588448643684, 66.62886992096901, 63.68915006518364, 65.23933008313179, 65.75091943144798, 61.45032919943333, 63.01176801323891, 63.76728147268295, 64.57447975873947, 64.36511099338531, 66.47635370492935, 62.29524806141853, 64.11228775978088, 66.05928048491478, 64.97322276234627, 58.642108887434006, 63.03574092686176, 64.34369534254074, 68.65402445197105, 64.43299815058708, 57.411286532878876, 52.21868276596069, 37.391019612550735, 16.898730620741844, 8.207640331238508, 9.857556447386742, 11.738853547722101, 11.234523709863424, 5.3916142880916595, 4.507413608953357, 2.829302530735731, 1.8538305116817355, 0.3984830738045275, 0.2197246643481776, 0.14601019327528775, 0.36691119137685746, 0.24111775390338153, 1.7743561137467623, 21.041895300149918, 47.25196547806263, 45.50647594034672, 52.18160815536976, 54.72602382302284, 58.017878383398056, 46.52728736400604, 35.96945509314537, 52.77029536664486, 55.06803587079048, 69.24634426832199, 72.70833849906921, 81.42121016979218, 75.43459340929985, 10.464761015027761, 0.978041571797803, 0.19057234661886469, 0.21805598982609808, 0.1560797420097515, 0.24814195901853964, 0.12272660867893137, 0.1822998936404474, 0.1683909774874337, 0.14730718539794907, 0.16410219512181357, 0.16166216199053451, 0.18844383739633486, 0.13432258449029177, 0.18514208175474778, 0.22361537354299799, 0.17610931332455948, 0.15501775837037712, 0.15478467947104946, 0.14987028145696968, 0.15498482185648754, 0.10491826309589669, 0.12958135921508074, 0.18774387339362875, 0.17314171709585935, 0.1380229031201452, 0.09757602543686517, 0.2949367300607264, 0.20672597747761756, 0.14472411072347313, 0.232440919498913, 0.0907471906975843, 0.13681792246643454], [0.0262710573952063, 0.014116354777797824, 0.04083118030393962, 0.04014855658169836, 0.09599116907338612, 0.06570388490217738, 0.0363874709000811, 0.04682908795075491, 0.050524400794529356, 0.08372501164558344, 0.11898839598870836, 0.021821648297191132, 0.07959953887620941, 0.10570505837677047, 0.1231037087563891, 0.08722811937332153, 0.024484119785483927, 0.04454866852029227, 0.012232798817422008, 0.03746328817214817, 0.056739071224001236, 0.02072807514196029, 0.043478105653775856, 0.036690025954158045, 0.054599485447397456, 0.04172108958300669, 0.08640018684673123, 1.0274084634147584, 31.68790563941002, 65.63629478216171, 69.10252958536148, 61.003252789378166, 46.819814667105675, 34.31473508477211, 19.222649820148945, 32.50651851296425, 32.453564554452896, 20.884401351213455, 24.83769401907921, 34.01415601372719, 42.39900268614292, 25.915508083999157, 3.400395973585546, 0.060133803126518615, 0.017472952349635307, 0.06355878125759773, 0.19401325494982302, 0.2486328748636879, 0.5669608677271754, 0.6068727385718375, 2.182568684220314, 4.8476283531636, 3.2685708347707987, 3.0433025350794196, 2.506764200516045, 2.5196863571181893, 3.7092562252655625, 6.1042950209230185, 8.768809419125319, 8.4975391253829, 13.752900324761868, 21.734014861285686, 26.75549291074276, 36.43094792962074, 43.339798003435135, 53.63345704972744, 53.74743953347206, 53.20687673985958, 56.35102942585945, 53.450398072600365, 55.79117126762867, 57.239748537540436, 56.055998057127, 61.06260560452938, 62.53355607390404, 66.09709605574608, 69.36747416853905, 65.14472275972366, 62.763299345970154, 60.09051516652107, 66.2117587029934, 68.07379558682442, 62.45233163237572, 60.33448487520218, 66.08954206109047, 40.49946941435337, 28.73885728418827, 42.08735480904579, 42.89800710976124, 35.519509837031364, 46.530581787228584, 67.53857150673866, 63.154655545949936, 65.51687479019165, 64.69997182488441, 62.55483493208885, 59.805032685399055, 61.02766267955303, 60.34776136279106, 63.84478971362114, 61.42422080039978, 60.076429322361946, 60.185111090540886, 60.185848250985146, 55.99567249417305, 58.072432056069374, 63.77159044146538, 68.3860932290554, 64.81954380869865, 61.46087743341923, 59.18897934257984, 57.21593901515007, 50.89548736810684, 48.8686229288578, 39.85057823359966, 28.80290474742651, 19.20222781598568, 8.3753851801157, 2.4092360213398933, 0.6536547595169395, 2.304752552881837, 2.911659311503172, 1.0283681494183838, 0.6381074187811464, 0.2025136214797385, 0.06524197218823247, 0.029961405271023978, 0.05038158560637385, 0.11090504965977743, 0.3246235573897138, 10.681057758629322, 42.446579933166504, 49.246455654501915, 45.452887415885925, 45.19436448812485, 53.406449630856514, 45.744153186678886, 9.80138786137104, 23.57950933277607, 44.51792098581791, 48.54771874845028, 55.95748074352741, 62.13881425559521, 28.08475848287344, 1.3677938422188163, 0.29915643332060426, 0.04520065638644155, 0.024284290957439225, 0.021294435864547268, 0.02903868935391074, 0.01941476690262789, 0.027148960580234416, 0.03665583521069493, 0.023209755745483562, 0.04299040330806747, 0.04190983629086986, 0.024362737822229974, 0.06220257688255515, 0.015817575258552097, 0.08328716678079218, 0.04018174913653638, 0.017321891900792252, 0.022179014667926822, 0.025555050015100278, 0.026260335216647945, 0.034723483040579595, 0.023887605602794793, 0.021760589952464215, 0.037258785669109784, 0.07756832521408796, 0.04539298024610616, 0.055743973643984646, 0.05875103728612885, 0.042617526050889865, 0.10565200966084376, 0.049861217630677857, 0.0057277311043435475, 0.031518752075498924, 0.031372908924822696, 0.050738376812660135, 0.06731424145982601, 0.06878082916955464, 0.03746855742065236, 0.03492712465231307, 0.04030729454825632, 0.09849503432633355, 0.01547156838569208, 0.0469844120380003, 0.04252758146321867, 0.029211440923972987, 0.05062122509116307, 0.07430627447320148, 0.03554071008693427, 0.04587935414747335, 0.036285492387833074, 0.05080527771497145, 0.047867107641650364, 0.03224440552003216, 0.01679327124293195, 0.030526034934155177, 0.03867687031743117, 0.06031545119185466, 0.058649563434300944, 1.5675425925292075, 40.07679529488087, 76.02774158120155, 79.94817361235619, 69.06732827425003, 57.890604212880135, 40.975336879491806, 31.356075145304203, 39.37383681535721, 43.47051098942757, 37.44275763630867, 33.89832302927971, 41.040643975138664, 43.068256974220276, 23.291446790099144, 2.844300800934434, 0.035115919599775225, 0.08501525022438727, 0.2904892765218392, 1.0270394082181156, 1.488009060267359, 1.505436587613076, 3.162065874785185, 6.879084846004844, 7.35172058455646, 5.308522246778011, 6.3204198237508535, 4.822799535468221, 4.721956746652722, 3.812592630274594, 6.035513961687684, 7.213503951206803, 10.174285601824522, 15.723498333245516, 21.78225327283144, 27.723490968346596, 35.77428236603737, 44.978448674082756, 57.85914570093155, 60.35406142473221, 55.94311371445656, 55.94255514442921, 54.984653145074844, 56.32190018892288, 57.68006891012192, 57.437980100512505, 62.427427768707275, 63.19188594818115, 67.3345984518528, 69.31982472538948, 66.41054883599281, 65.580635368824, 62.614658921957016, 67.54908174276352, 67.93402388691902, 63.995976001024246, 60.66071256995201, 66.60582795739174, 43.27010214328766, 35.34827582538128, 48.0435997992754, 47.8350517898798, 43.64294193685055, 52.990288361907005, 66.58008053898811, 63.24760615825653, 66.96075931191444, 66.06829360127449, 62.91526839137077, 61.55829660594463, 61.15365631878376, 61.12519584596157, 64.2107404768467, 62.91733168065548, 60.10127618908882, 59.83958423137665, 60.65379314124584, 58.5795072466135, 60.21371975541115, 65.47085165977478, 71.95149511098862, 69.41934138536453, 65.94388827681541, 66.04407370090485, 64.3921123445034, 56.42616279423237, 53.34656864404678, 46.51116482913494, 34.37229439616203, 21.753010042011738, 10.556290503591299, 3.3318690257146955, 1.881419406272471, 1.3396423403173685, 3.2453870913013816, 3.109940509311855, 2.112188385799527, 1.1007528402842581, 0.3452006704173982, 0.09485329341259785, 0.07669379323488101, 0.07849940884625539, 0.265842106891796, 11.050342842936516, 32.190022096037865, 39.60165739059448, 37.89493717253208, 40.157031789422035, 40.918628722429276, 39.33428093791008, 19.215071126818657, 39.76881042122841, 54.78620879352093, 56.091351360082626, 62.35577881336212, 70.25255307555199, 46.12398460507393, 4.008676595985889, 0.1511810626834631, 0.0695628672838211, 0.03126655916275922, 0.04432227637153119, 0.0763783062575385, 0.023267667384061497, 0.0322644917469006, 0.06367474925355054, 0.07120352573110722, 0.047503878304269165, 0.01059548745615757, 0.09205199021380395, 0.06791768173570745, 0.027114174263260793, 0.11497960367705673, 0.007423965744237648, 0.037859313015360385, 0.02173417877202155, 0.06170037668198347, 0.04300017739296891, 0.016736905126890633, 0.011832017735287081, 0.08264710893854499, 0.1146794568921905, 0.0377769346232526, 0.03697360058140475, 0.021388545756053645, 0.06024775990226772, 0.03679863926663529, 0.038977955919108354, 0.0496811429184163, 0.1301736375899054, 0.10665403518942185, 0.13596853445051238, 0.11429929916630499, 0.21319032122846693, 0.18861144402762875, 0.15373148286016658, 0.11754677412682213, 0.07869492765166797, 0.2561622450593859, 0.26527201873250306, 0.12623985414393246, 0.09177706902846694, 0.14340586349135265, 0.21169193991227075, 0.1737050517112948, 0.1607589385821484, 0.109525530715473, 0.12625085277250037, 0.20306022808654234, 0.20363435352919623, 0.11652116314508021, 0.17732688080286607, 0.15875607496127486, 0.14219726115697995, 0.31350701639894396, 0.18694259139010683, 2.043306394480169, 50.32988391816616, 86.799585968256, 86.49329200387001, 81.04776620864868, 66.97918832302094, 48.04141491651535, 30.898176915943623, 47.59178504347801, 42.92086288332939, 31.579195372760296, 36.290830448269844, 46.90184846520424, 54.98897731304169, 34.48616288602352, 5.464851558208466, 0.15823467168956995, 0.26588016422465444, 0.302802367368713, 0.7741000433452427, 1.4429055992513895, 3.7771383952349424, 3.2261131005361676, 8.268831297755241, 11.620745435357094, 11.360413804650307, 12.642404213547707, 7.922651348635554, 8.783068154007196, 9.144774544984102, 11.81777911260724, 14.992543905973434, 13.412293251603842, 19.615153558552265, 26.833757311105728, 32.05800577998161, 42.690124064683914, 51.38644382357597, 59.74059574306011, 61.200344413518906, 61.3835059851408, 59.02842655777931, 55.917427092790604, 58.107659965753555, 59.729485139250755, 61.036618798971176, 64.77994233369827, 66.4256340265274, 70.65463989973068, 71.78659915924072, 68.59724029898643, 66.51440486311913, 64.93804425001144, 70.05616441369057, 68.98030534386635, 66.28343045711517, 61.98166988790035, 69.72319588065147, 48.83870713412762, 40.646624118089676, 52.11615666747093, 52.219370529055595, 47.69242264330387, 56.33429132401943, 65.59149518609047, 64.72678318619728, 66.57930538058281, 63.364514485001564, 63.94600108265877, 62.096476927399635, 63.62494111061096, 62.41967238485813, 66.21574848890305, 63.476737663149834, 60.3958135843277, 61.79229944944382, 60.11308595538139, 60.08019872009754, 59.33694340288639, 63.81167829036713, 73.75165611505508, 70.48271432518959, 69.04443070292473, 69.06409084796906, 66.23350113630295, 58.79739135503769, 55.03071807324886, 47.162617072463036, 35.982142612338066, 26.87561396509409, 14.849490132182837, 7.58430752903223, 6.6938842087984085, 6.2660076934844255, 8.516726195812225, 4.158948082476854, 2.102031293325126, 0.8662515704054385, 0.2669284032890573, 0.1768307847669348, 0.334081724868156, 0.21597790211671963, 0.7223279401659966, 16.646545752882957, 55.83616845309734, 66.55016094446182, 59.79211337864399, 55.71079798042774, 72.89620041847229, 60.27570202946663, 20.13930883258581, 39.97428439557552, 61.447505950927734, 68.60254481434822, 72.62657448649406, 79.54392850399017, 57.84564882516861, 5.843558711931109, 0.4752084973733872, 0.16667164396494627, 0.1544219473726116, 0.16316064720740542, 0.14897600834956393, 0.17455124849220738, 0.15597735531628132, 0.1371271605603397, 0.11636928262305446, 0.11243744360399432, 0.10002568422351032, 0.15694538305979222, 0.20874035923043266, 0.10049338568933308, 0.22167911025462672, 0.13777357118669897, 0.20001901080831885, 0.12103014814783819, 0.1603739568963647, 0.07690131256822497, 0.09825951376114972, 0.1418962312163785, 0.10637490602675825, 0.209045396768488, 0.12309847661526874, 0.1585761783644557, 0.20177090977085754, 0.141173557494767, 0.12062011897796765, 0.2390283261775039, 0.2115361631149426], [0.05338336886779871, 0.01611729159776587, 0.0327429617755115, 0.06332773584290408, 0.08549454403691925, 0.0655330647714436, 0.028800894106097985, 0.05517923636944033, 0.06979468453209847, 0.04059080238221213, 0.024137523832905572, 0.03815557836787775, 0.040368670161115006, 0.04637701240426395, 0.080855304695433, 0.01899402112030657, 0.03052539483178407, 0.022565352628589608, 0.05693099432392046, 0.022430483986681793, 0.054299932380672544, 0.02499064114090288, 0.06636790669290349, 0.043543997235246934, 0.045884682767791674, 0.06876929619465955, 0.15354484756244346, 14.141540620476007, 64.48139995336533, 69.4337198138237, 68.25618579983711, 55.25915801525116, 40.66992066800594, 28.86716689914465, 23.399759978055954, 16.869950965046883, 22.561173476278782, 28.565736673772335, 26.40427965670824, 39.6293693035841, 34.48397420346737, 5.618497738614678, 0.044451432331698015, 0.07241439161589369, 0.06451855631894432, 0.10192103291046806, 0.4943857714533806, 0.15074085036758333, 0.6069188704714179, 2.3887821938842535, 2.1285821311175823, 6.9909038208425045, 3.037001760676503, 3.5056289518252015, 3.8259308645501733, 9.789905827492476, 13.909810055047274, 16.59694891422987, 20.687429420650005, 25.361625105142593, 32.96896509826183, 40.20000748336315, 42.42998622357845, 53.3204298466444, 55.50200678408146, 57.59331576526165, 62.21815399825573, 60.94837233424187, 57.58350469172001, 61.87643073499203, 58.63012433052063, 61.314881667494774, 64.30334150791168, 61.3458614051342, 61.66465289890766, 62.9062856733799, 63.20561841130257, 68.13018456101418, 64.39291030168533, 64.96966615319252, 64.95117634534836, 64.10933911800385, 62.579404413700104, 66.14871248602867, 60.24690717458725, 58.82956802845001, 34.3776711076498, 34.26988989114761, 33.001859933137894, 33.85179452598095, 62.232015654444695, 57.99921378493309, 59.32343512773514, 60.6696192920208, 59.92671735584736, 59.265438839793205, 61.475882828235626, 57.62192063033581, 61.844888627529144, 61.43785446882248, 60.38625329732895, 58.500258699059486, 59.40918132662773, 57.30893522500992, 60.55465646088123, 63.67296293377876, 70.4355588555336, 64.4316378235817, 67.80956536531448, 63.6788260191679, 64.47110250592232, 63.97479593753815, 70.37096232175827, 68.49835440516472, 59.63413305580616, 54.95539091527462, 39.42291118204594, 27.516269087791443, 17.173404581844807, 8.759164586663246, 3.633276214823127, 2.6770349638536572, 2.8187143988907337, 1.7444126517511904, 0.6518880324438214, 0.3742419776972383, 0.040328412360395305, 0.05406494987255428, 0.10647569710272364, 0.11659974916256033, 0.24917109520174563, 6.035141106694937, 24.860185012221336, 43.64110663533211, 42.538987174630165, 64.24518942832947, 47.128692492842674, 30.44170930981636, 17.95378390699625, 27.337256893515587, 47.865035980939865, 49.19116102159023, 52.45256021618843, 59.00456763803959, 26.349668987095356, 1.0169085580855608, 0.09396910609211773, 0.035162786225555465, 0.02248139717266895, 0.022879225434735417, 0.0552255872025853, 0.045253898060764186, 0.051971559078083374, 0.021726874183514155, 0.04813295978237875, 0.03454434343439061, 0.10347562449169345, 0.05129862780449912, 0.03494595664960798, 0.001257480760159524, 0.07252536495798267, 0.055792825514799915, 0.03830273140920326, 0.03446065886237193, 0.062432008126052096, 0.0587664294289425, 0.030714382737642154, 0.01788263085472863, 0.11689761013258249, 0.01666828800807707, 0.023058107144606765, 0.007240554614327266, 0.03627309481089469, 0.04657314348150976, 0.031082467576197814, 0.035967582298326306, 0.04037738668557722, 0.04698528035078198, 0.03598873721784912, 0.014818938561802497, 0.08211911539547145, 0.065408064838266, 0.0661665026564151, 0.052096829895162955, 0.013981756092107389, 0.01578213028551545, 0.06327626048005186, 0.03512973096803762, 0.009973445248760981, 0.0887663614412304, 0.04104080733668525, 0.01368317431115429, 0.01798439599951962, 0.033157213765662163, 0.05942442126979586, 0.013373277561186114, 0.049412871376262046, 0.08440312682068907, 0.04827535565709695, 0.05691304919309914, 0.10839825292350724, 0.05381068265705835, 0.08422056591371074, 20.510583110153675, 74.1236637532711, 78.24236914515495, 72.4531289935112, 63.95980954170227, 53.857033252716064, 38.33517774939537, 25.66887851804495, 26.65325939655304, 31.972639560699463, 30.9892675280571, 33.347439989447594, 34.003896564245224, 26.96623720228672, 4.3774354085326195, 0.01320659212069586, 0.07947172620333731, 0.3433509118622169, 0.8154488308355212, 1.926088621839881, 2.6217842660844326, 3.391579259186983, 5.396581571549177, 7.44370604865253, 7.803690657019615, 3.3083406882360578, 4.186802012845874, 3.709668265655637, 7.98665938898921, 13.869826700538397, 17.170754224061966, 20.76016891747713, 27.51972310245037, 33.897753059864044, 40.63321843743324, 47.19682663679123, 56.698080003261566, 60.39946898818016, 62.9855228215456, 67.18235582113266, 65.77883273363113, 61.70602887868881, 63.944747149944305, 59.857511669397354, 63.26877102255821, 67.70755603909492, 64.16814476251602, 64.21986758708954, 63.97673383355141, 63.908816277980804, 67.88574367761612, 64.99981373548508, 65.44808328151703, 66.85504898428917, 64.70235049724579, 64.51495215296745, 67.6777732372284, 62.7323804050684, 62.10800550878048, 38.3637598156929, 41.141213178634644, 38.866301849484444, 39.619839414954185, 60.772544369101524, 59.39421772956848, 63.09904173016548, 62.84376382827759, 60.58276355266571, 58.62241454422474, 60.926778092980385, 58.928852900862694, 60.28756499290466, 61.59384369850159, 59.89806689321995, 60.271985828876495, 60.1070024818182, 57.76911713182926, 60.47638826072216, 63.881761729717255, 70.46048551797867, 68.72160762548447, 69.03167098760605, 66.94917753338814, 66.41999512910843, 66.73381268978119, 72.13111147284508, 72.50203236937523, 61.2967262417078, 57.54550293087959, 43.435891047120094, 30.95675267279148, 18.824408389627934, 7.398846130818129, 2.933033164590597, 0.6936907768249512, 2.6612128503620625, 1.6834183246828616, 2.5374622782692313, 1.4011269598267972, 0.36590543284546584, 0.15077570162247866, 0.06715614174026996, 0.05909242892812472, 0.29246852500364184, 5.548593839630485, 23.617613688111305, 51.24467343091965, 51.55103199183941, 63.50686624646187, 36.14540085196495, 25.979511849582195, 24.197114892303944, 36.360461711883545, 56.24121151864529, 56.566569060087204, 59.789632111787796, 72.34496399760246, 44.590823873877525, 1.6574177448637784, 0.0408404571498977, 0.020405875438882504, 0.07977818124345504, 0.06038547653588466, 0.015245397025864804, 0.09543679218040779, 0.04131263376621064, 0.030034126466489397, 0.03829230794508476, 0.055104680213844404, 0.026198248997388873, 0.0021008987778259325, 0.04077601646713447, 0.022528488298121374, 0.013032801543886308, 0.026819424747372977, 0.03609089755627792, 0.04234769228787627, 0.029519079689634964, 0.058227659901604056, 0.014354826307680923, 0.019604949666245375, 0.07537498939200304, 0.053132778994040564, 0.011431157799961511, 0.013882565272069769, 0.05010160297388211, 0.03966996409872081, 0.0207710974427755, 0.031588365527568385, 0.15541442146059126, 0.14028100616997108, 0.12493768183048815, 0.13837350852554664, 0.23560947447549552, 0.2125340697239153, 0.1487551600439474, 0.11129913007607684, 0.12305339856538922, 0.08141362239257433, 0.10172992988373153, 0.15251493954565376, 0.14636312902439386, 0.1626990907243453, 0.13240005093393847, 0.12550649349577725, 0.0884094848879613, 0.13454570376779884, 0.10421582031995058, 0.05683749113813974, 0.12997141719097272, 0.1696914280182682, 0.16485893342178315, 0.17174974491354078, 0.2311379011371173, 0.15323072613682598, 0.23414909112034366, 29.94629379361868, 86.15270867943764, 86.78730502724648, 83.92547339200974, 71.81587278842926, 60.191019773483276, 41.6137520223856, 32.82910220324993, 25.69050505757332, 30.33638846129179, 41.04346342384815, 35.89982382953167, 51.92015178501606, 44.92448776960373, 7.863758783787489, 0.18642638315213844, 0.21686570369638503, 0.310678543173708, 0.9389100247062743, 1.7778845806606114, 3.7055082013830543, 4.7955037001520395, 8.862950317561626, 7.550659384578466, 15.102737993001938, 9.013308249413967, 8.887600544840097, 11.566580291837454, 15.996123254299164, 24.15075547993183, 23.42098943889141, 27.076735273003578, 34.052142575383186, 42.07251280546188, 47.90148742496967, 51.19921267032623, 59.81938451528549, 63.76696228981018, 65.67708179354668, 68.45261245965958, 65.73161646723747, 61.269124522805214, 64.80350106954575, 61.96003384888172, 64.98624846339226, 68.62716749310493, 66.16589516401291, 67.40630820393562, 67.85062596201897, 66.59663245081902, 70.90443089604378, 66.86361372470856, 66.84903010725975, 66.98525279760361, 66.64717733860016, 66.72629669308662, 68.36177453398705, 64.59721773862839, 63.19943234324455, 43.59587386250496, 46.3192143291235, 44.480435997247696, 45.0214471668005, 62.7810025960207, 61.78324073553085, 62.308737337589264, 61.945115849375725, 61.13074354827404, 59.367679953575134, 61.324092373251915, 59.45315256714821, 62.394000962376595, 63.69337163865566, 62.60449826717377, 60.810052156448364, 60.934522077441216, 58.61551411449909, 59.41688351333141, 64.96744707226753, 72.63083785772324, 71.74269631505013, 73.44297587871552, 70.71662977337837, 70.80096244812012, 70.83115562796593, 76.9229507446289, 74.40167963504791, 61.04739502072334, 59.060071259737015, 47.23438002169132, 35.9246326982975, 23.132799603044987, 13.498307336121798, 9.806028362363577, 7.781583443284035, 7.663685269653797, 5.5835633631795645, 3.7061294680461287, 0.714300989639014, 0.21651342103723437, 0.17410938860848546, 0.20307366095948964, 0.2893887012032792, 0.5314394237939268, 9.842669796198606, 33.30215781927109, 56.42280377447605, 53.48556138575077, 73.88534814119339, 64.07732963562012, 45.05192153155804, 30.543921925127506, 42.47671231627464, 61.906038746237755, 68.37341710925102, 70.11873185634613, 82.3740242421627, 55.21496258676052, 3.1826994800940156, 0.20480273145949468, 0.09946465768734924, 0.14864990866044536, 0.1453695268719457, 0.1587944439961575, 0.18943616305477917, 0.15723577060271055, 0.21945223677903414, 0.16123754961881787, 0.12554205721244216, 0.14809565793257207, 0.19113743270281702, 0.09615048591513187, 0.16259177617030218, 0.10510891341255046, 0.1896247873082757, 0.13667235762113705, 0.117967883561505, 0.18164913402870297, 0.13214098202297464, 0.10055134000140242, 0.09245011533494107, 0.15193958213785663, 0.13651033194037154, 0.1734494263655506, 0.11617319236393087, 0.15838402148801833, 0.1259703654795885, 0.16945578128797933, 0.10779579228255898], [0.026562443126749713, 0.12937134626554325, 0.047656541792093776, 0.047403443459188566, 0.05964434560155496, 0.03953624393034261, 0.05354337590688374, 0.05081831353891175, 0.05260943129542284, 0.02398817774519557, 0.09094926266698167, 0.029202043479017448, 0.04812504106666893, 0.010629935168253724, 0.046847693593008444, 0.08390277085709386, 0.015141461099119624, 0.03324839773995336, 0.035066678101429716, 0.03523779509123415, 0.09751240853802301, 0.052876433765050024, 0.04495415574638173, 0.05198384162213188, 0.019622349318524357, 0.10238994407700375, 5.785065600648522, 52.52993546426296, 70.30411630868912, 65.37183657288551, 59.387241303920746, 56.41099400818348, 32.681088745594025, 23.76781962811947, 35.564735010266304, 29.35463324189186, 36.55262120068073, 41.66248820722103, 40.92110238969326, 51.8161703646183, 9.201962426304817, 0.06156407012895215, 0.038301198874250986, 0.04648539194022305, 0.018809116882039234, 0.5132401816081256, 1.9671766483224928, 2.387824645265937, 1.173166148364544, 5.296879671514034, 14.539499916136265, 5.64788868650794, 2.376985726878047, 9.069022759795189, 21.1312760040164, 30.147791281342506, 40.46584501862526, 43.96492525935173, 46.09752282500267, 53.657137379050255, 54.26358863711357, 52.235132083296776, 59.7649410367012, 61.541414111852646, 64.98542010784149, 65.25276616215706, 62.799891382455826, 61.17013983428478, 62.118257358670235, 62.14685082435608, 63.32373887300491, 60.799701511859894, 58.25457528233528, 57.664219960570335, 59.09143477678299, 56.974473372101784, 58.72746750712395, 61.18543401360512, 64.15699616074562, 63.448782563209534, 58.186843916773796, 57.116882130503654, 63.499069064855576, 66.18322983384132, 60.58158181607723, 58.35221864283085, 47.944820299744606, 29.52762085944414, 23.498573675751686, 44.69291679561138, 57.29679487645626, 54.96741347014904, 59.29672256112099, 58.5577268153429, 60.61608776450157, 56.46956026554108, 58.75301733613014, 57.544723972678185, 55.573100969195366, 58.0378083139658, 60.047239288687706, 57.99723409116268, 57.65024431049824, 55.20745798945427, 60.541752353310585, 64.96683150529861, 63.25073719024658, 62.57213920354843, 57.915789261460304, 54.78002652525902, 54.8633598536253, 57.35515974462032, 59.98790927231312, 67.87292316555977, 63.9301635324955, 61.29258446395397, 60.05704276263714, 46.48853324353695, 37.0075061917305, 24.13174320012331, 8.512478973716497, 3.2627238985151052, 2.245942633599043, 2.9410284105688334, 2.1935408329591155, 1.1965460563078523, 0.3135096584446728, 0.06672919160337187, 0.022813062969362363, 0.049817779727163725, 0.02630326103826519, 0.17658963130088523, 2.5379004422575235, 12.26613700389862, 26.02563377469778, 41.41737475991249, 52.20528848469257, 40.1168717443943, 25.57903043925762, 20.839884839951992, 27.42591943591833, 46.08629062771797, 55.83984665572643, 49.77196365594864, 56.72129675745964, 17.698447108268738, 0.15935386007186025, 0.07402645511319861, 0.07065889323712327, 0.026081919204443693, 0.058792805357370526, 0.075808077090187, 0.043947061349172145, 0.011179363791598007, 0.03781529994739685, 0.06053675962903071, 0.04791299463249743, 0.059380786697147414, 0.05522665218450129, 0.0316020841273712, 0.022133322490844876, 0.03223445703042671, 0.05953164305537939, 0.035008712657145225, 0.018635337437444832, 0.07416504377033561, 0.10558006586506963, 0.018445048917783424, 0.03362554605701007, 0.060642215103143826, 0.07031403947621584, 0.05472807737533003, 0.022252518829191104, 0.021912628180871252, 0.04056180296174716, 0.052739206948899664, 0.04560014705930371, 0.05929097569605801, 0.10187883439357392, 0.06599001251743175, 0.029309040764928795, 0.05029433130403049, 0.03661814895167481, 0.054909202226554044, 0.04259348788764328, 0.045418814406730235, 0.022310679087240715, 0.02329035854927497, 0.024930011386459228, 0.016145801200764254, 0.003659512103695306, 0.010921306056843605, 0.014389328753168229, 0.07190797230578028, 0.016465470180264674, 0.02412445090158144, 0.051511086130631156, 0.0205247025587596, 0.029155423617339693, 0.004212953426758759, 0.09422706178156659, 0.1422755280509591, 8.510322589427233, 61.76448114216328, 80.44429019093513, 74.13719862699509, 70.30686736106873, 64.67566832900047, 40.49704894423485, 30.095234401524067, 34.18265797197819, 27.077968306839466, 30.887003615498543, 38.81794564425945, 34.72893185913563, 40.106369107961655, 8.176246415823698, 0.04479395203816239, 0.0894099593278952, 0.23880704742623493, 0.7890467788092792, 1.7051200289279222, 2.839392414316535, 1.3892772956751287, 3.8682534685358405, 5.8588766399770975, 6.883435137569904, 5.43214718811214, 4.567818492650986, 8.500139135867357, 19.77543655782938, 30.297203063964844, 40.30701354146004, 41.71143718063831, 44.46441985666752, 51.46780885756016, 54.84548181295395, 54.35307763516903, 62.31575556099415, 65.17763659358025, 66.58741414546967, 68.40111762285233, 65.23817494511604, 63.975882679224014, 62.97821581363678, 65.06738170981407, 66.06893196702003, 64.15815889835358, 61.25252701342106, 60.21849989891052, 60.988406985998154, 58.75335931777954, 60.393051132559776, 63.949952870607376, 66.63662910461426, 63.66916313767433, 61.82265602052212, 58.14558193087578, 63.84865030646324, 68.63124087452888, 63.59210707247257, 63.39153103530407, 51.03294499218464, 33.91871653497219, 29.251210391521454, 45.76887086033821, 59.3878872692585, 55.52018120884895, 60.52936501801014, 58.6571104824543, 60.56350618600845, 57.423924654722214, 59.304481744766235, 56.74178525805473, 57.82275125384331, 60.096674636006355, 60.987054258584976, 59.60393987596035, 58.32144409418106, 55.33214829862118, 61.29263386130333, 66.89214259386063, 65.86128070950508, 64.39748525619507, 60.594653114676476, 56.261654421687126, 59.71767537295818, 58.866562843322754, 62.076581194996834, 69.94487598538399, 64.5107039809227, 60.89061163365841, 61.379128620028496, 49.20552425086498, 42.40461118519306, 28.225582726299763, 11.559813804924488, 3.7123513966798782, 1.2493685656227171, 3.1110823480412364, 5.393494237214327, 2.92758924420923, 1.2990875914692879, 0.22615532943746075, 0.09602248770534061, 0.043834013704326935, 0.047976381465559825, 0.12935871491208673, 2.722993497736752, 12.511078510433435, 29.100039303302765, 47.37656459212303, 50.48277251422405, 33.769855722784996, 24.569004736840725, 35.3382633626461, 39.55419793725014, 56.00014865398407, 64.10266667604446, 53.307122960686684, 69.05716001987457, 30.454866103827953, 0.5131449492182583, 0.026331297522119712, 0.02021898966631852, 0.028539337145048194, 0.041771960095502436, 0.08588876546127722, 0.09947402359102853, 0.03284911857917905, 0.07454495658748783, 0.07013084774371237, 0.02615793182485504, 0.04855475199292414, 0.019229166900913697, 0.03115108840574976, 0.05866576451808214, 0.08564303294406272, 0.02055948702036403, 0.026019812576123513, 0.013412287626124453, 0.06548955265316181, 0.029761791665805504, 0.03740023901627865, 0.04996055409719702, 0.04306087765144184, 0.13400398049270734, 0.009171641886496218, 0.013177568580431398, 0.06520116148749366, 0.03806348526268266, 0.06716723684803583, 0.07783036271575838, 0.18509063607780263, 0.155307715467643, 0.16527468455024064, 0.1239227651967667, 0.14078982261708006, 0.12601955502759665, 0.175039166060742, 0.11789609561674297, 0.10530320767429657, 0.1958438364090398, 0.11159552159369923, 0.19592887168982998, 0.16503762773936614, 0.14308516663732007, 0.18349077348830178, 0.17760529008228332, 0.16607844532700256, 0.14036519540240988, 0.11221796085010283, 0.18973171594552696, 0.10357933220802806, 0.22443565452704206, 0.25526766024995595, 0.21564396534813568, 0.3202814294490963, 12.402883116155863, 79.33238625526428, 87.65010952949524, 81.8291562795639, 78.22631880640984, 75.57776212692261, 46.93343997001648, 35.950953885912895, 48.708560317754745, 40.3580030053854, 48.752113580703735, 54.827668368816376, 53.41165155172348, 66.25852659344673, 12.42366325110197, 0.12179966623079963, 0.22815492760855705, 0.2881362527841702, 0.7377715583425015, 2.005508397705853, 6.032374855130911, 6.26741599291563, 5.990192843601108, 12.813927959650755, 26.02402836084366, 12.411160971969366, 5.79340330325067, 14.035639353096485, 26.377681083977222, 35.31093902885914, 44.4872984290123, 46.44177295267582, 51.58059820532799, 58.540319949388504, 60.26578076183796, 56.246808618307114, 65.88233157992363, 66.57596156001091, 70.51948115229607, 69.99229744076729, 67.64402344822884, 66.32902041077614, 63.02406795322895, 62.02653408050537, 66.27407535910606, 65.94892680644989, 62.52857454121113, 62.700443118810654, 65.24775043129921, 60.754537135362625, 62.59434141218662, 63.812354654073715, 70.59451192617416, 66.79895639419556, 63.055241480469704, 59.4365968555212, 65.398670732975, 70.11332854628563, 65.37680670619011, 65.49310326576233, 53.72190870344639, 39.11635123193264, 34.96062062680721, 49.59409140050411, 65.27200073003769, 59.0266178548336, 59.411088824272156, 59.65385779738426, 61.40968658030033, 59.25924517214298, 59.53535735607147, 57.52576678991318, 56.96819610893726, 60.8843419700861, 61.43810525536537, 60.07572256028652, 59.6334832906723, 54.423776641488075, 62.814296409487724, 69.12586033344269, 68.3091701567173, 66.98322370648384, 63.248312920331955, 59.16396528482437, 61.352039873600006, 62.4927918612957, 67.24385932087898, 74.00469973683357, 66.02641984820366, 60.94455733895302, 61.36675648391247, 51.98987424373627, 45.49455597996712, 34.49187017977238, 13.346268944442272, 7.2937228716909885, 9.651021379977465, 10.875697564333677, 10.552008133381605, 3.5117537481710315, 0.837329066125676, 0.1922333028051071, 0.20166289759799838, 0.15531673998339102, 0.34200189518742263, 0.42028283060062677, 4.679411379620433, 17.596886157989502, 41.892915442585945, 53.63381043076515, 63.63712325692177, 55.04863031208515, 39.10984218120575, 34.36220973730087, 40.824078395962715, 62.36923009157181, 74.21030670404434, 64.87150222063065, 77.00881853699684, 36.280335411429405, 1.3623479031957686, 0.17053284536814317, 0.19056686956901103, 0.12559062335640192, 0.18003842124016955, 0.22002762387273833, 0.27505886857397854, 0.12406546535203233, 0.14348689117468894, 0.11989151549641974, 0.1624561264179647, 0.15059657685924321, 0.10421279977890663, 0.11936853145016357, 0.07978448949870653, 0.18768172594718635, 0.09780683336430229, 0.09327419611508958, 0.12625071918591857, 0.24106431927066296, 0.1781232943176292, 0.08475324983010069, 0.12330747282248922, 0.14423512446228415, 0.26254919765051454, 0.13480832014465705, 0.11260478306212462, 0.1262499621952884, 0.16746142267948017, 0.1885290804784745], [0.017405997641617432, 0.021769838967884425, 0.03797011937422212, 0.0067267193935549585, 0.004762271655636141, 0.09440251291380264, 0.07473500576452352, 0.035528635344235227, 0.04798569170816336, 0.029752002737950534, 0.037327204263419844, 0.007401644725177903, 0.06007262047205586, 0.035623400181066245, 0.0326303111796733, 0.019273315410828218, 0.052672179881483316, 0.009093756270885933, 0.11777806445024908, 0.037067738303449005, 0.024943321805039886, 0.024595872382633388, 0.021853783291589934, 0.018154104764107615, 0.07228114642202854, 0.6200876575894654, 28.091596215963364, 69.00531560182571, 65.8611211180687, 62.31876119971275, 46.45829066634178, 39.867198541760445, 36.15122973918915, 24.654106870293617, 43.79751764237881, 42.85517580807209, 44.43636976182461, 45.35861827433109, 46.274714916944504, 7.85003487020731, 0.08962579813669436, 0.03798016063228715, 0.017660511621215846, 0.060223153996048495, 0.5059398233424872, 1.4597692131064832, 2.8379057440906763, 1.4741683029569685, 4.8695161286741495, 5.370297431945801, 6.260079061612487, 5.219486374408007, 18.828584365546703, 34.330827221274376, 44.56053949892521, 57.617064490914345, 60.380838587880135, 58.58357682824135, 61.67801298201084, 59.86636519432068, 60.65355755388737, 60.44147193431854, 64.64641749858856, 61.389760449528694, 58.025303184986115, 57.270507887005806, 62.50019006431103, 64.38116893172264, 63.842745423316956, 62.47745968401432, 62.55288943648338, 58.91790948808193, 60.43411932885647, 54.29966390132904, 54.68610696494579, 55.95873847603798, 57.5967013835907, 62.08320043981075, 64.52724829316139, 60.23556478321552, 58.50964039564133, 56.26186341047287, 65.03645896911621, 58.3810742944479, 59.83653299510479, 60.52883304655552, 65.06372630596161, 38.40015046298504, 24.64798539876938, 48.083934634923935, 49.57908980548382, 60.61320371925831, 58.25983799993992, 62.74597987532616, 61.52789443731308, 55.51319718360901, 58.91409449279308, 59.07164543867111, 57.082144394516945, 57.821284532547, 58.1642085313797, 58.62936817109585, 54.67224530875683, 61.22080251574516, 64.71545979380608, 63.45532961189747, 60.37170767784119, 54.425653740763664, 48.8332886248827, 51.06726095080376, 52.90296904742718, 61.1933071911335, 64.5912292599678, 65.18923357129097, 59.68818135559559, 61.44524127244949, 60.550902262330055, 62.95515485107899, 54.11541938781738, 42.244343385100365, 37.682798355817795, 21.450722962617874, 5.5673914309591055, 0.3523420903366059, 4.239508034661412, 6.054028943181038, 2.3378034168854356, 0.7806136063300073, 0.18619518930790946, 0.015039775735203875, 0.020608006780094, 0.060993510705884546, 0.04275783277989831, 2.792495093308389, 15.309815481305122, 32.1591791510582, 36.3190933316946, 51.208020597696304, 44.91002194583416, 14.81914971023798, 25.30958689749241, 38.1058144569397, 49.3369098007679, 50.654698088765144, 58.27435702085495, 51.15198500454426, 18.153214305639267, 0.3189417935209349, 0.17252055433345959, 0.05723291484173387, 0.02286076265590964, 0.04175712456344627, 0.03517338780511636, 0.010262866144330474, 0.0797809346113354, 0.06717451731674373, 0.06745254067936912, 0.05072192710940726, 0.05775868565251585, 0.04221909293846693, 0.05900613570702262, 0.061685392720391974, 0.03791231720242649, 0.03545384170138277, 0.035151965712429956, 0.04639486847736407, 0.056219515900011174, 0.04404309896926861, 0.04349713803094346, 0.024713875718589406, 0.008044096921366872, 0.014601537532143993, 0.02277300740388455, 0.0411163319949992, 0.016952354308159556, 0.10480354932951741, 0.04442758341610897, 0.02229312915005721, 0.02670437330380082, 0.030432926942012273, 0.025983656996686477, 0.05404117146099452, 0.09101666451897472, 0.04970550762664061, 0.05868790278327651, 0.044530181621667, 0.0688924927089829, 0.028435917010938283, 0.08736233678064309, 0.029000546674069483, 0.09902434889227152, 0.015425932797370479, 0.06285723648034036, 0.023205946672533173, 0.015037729262985522, 0.020067203768121544, 0.03700578752614092, 0.028724007606797386, 0.03797362602199428, 0.02678541211935226, 0.12104929555789568, 0.8868452778551728, 37.675525546073914, 78.83104115724564, 74.44915428757668, 69.20849069952965, 55.857891887426376, 51.18506222963333, 49.450861886143684, 35.38549862802029, 52.76608519256115, 33.49876306951046, 41.649774089455605, 40.306986942887306, 34.18617658317089, 7.475896496325731, 0.06293626778642647, 0.06370015296852216, 0.030973679859016556, 0.8384905569255352, 1.782983432058245, 3.3957735216245055, 4.096481334418058, 3.165276227518916, 4.112003976479173, 5.441767796874046, 7.433114117011428, 7.367921965196729, 14.414458125829697, 33.667090237140656, 46.82756245136261, 58.84059503674507, 60.00038780272007, 58.06684635579586, 60.3569682687521, 58.74655768275261, 61.88922084867954, 61.380697935819626, 66.13224416971207, 63.6798557639122, 61.46648213267326, 59.298109486699104, 65.19978940486908, 64.59379032254219, 63.14290277659893, 64.8925606906414, 64.78278458118439, 61.176907271146774, 62.50476881861687, 57.2437459230423, 57.353438436985016, 58.81108582019806, 58.67532290518284, 63.32787685096264, 65.61800256371498, 63.276233822107315, 61.07495874166489, 58.630796894431114, 66.17984041571617, 60.17716571688652, 61.376905739307404, 61.8892702460289, 68.07208567857742, 40.18163926899433, 29.190970323979855, 50.0288450717926, 53.860593661665916, 61.67531132698059, 61.38549707829952, 63.280314803123474, 62.12754786014557, 56.85276210308075, 59.40090537071228, 59.40708003938198, 56.85944974422455, 56.33647620677948, 58.110627606511116, 58.097609505057335, 55.35431630909443, 60.56195966899395, 65.82720413804054, 66.04269817471504, 62.41411708295345, 57.79582589864731, 51.510640159249306, 51.63681238889694, 55.14461316168308, 61.91876046359539, 66.65362939238548, 66.83225780725479, 59.96265962719917, 61.13948307931423, 60.51197715103626, 61.47058591246605, 57.05643877387047, 45.83546608686447, 43.34481753408909, 23.49526595324278, 7.839506585150957, 1.3153386069461703, 1.4172712247818708, 3.4637535363435745, 4.4857766199857, 2.4542947160080075, 0.43019640957936645, 0.22191107593243942, 0.1235161350632552, 0.0948413967853412, 0.04531955586571712, 2.2061193455010653, 12.380296178162098, 35.05487076938152, 43.245745450258255, 49.554090946912766, 37.71038107573986, 18.28794177621603, 33.05085830390453, 48.12005929648876, 57.11831085383892, 60.93460947275162, 64.09337997436523, 66.0898308455944, 32.37688846886158, 0.9216296800877899, 0.24342964781681076, 0.03474893128441181, 0.06510095670819283, 0.04952784118358977, 0.07722744936472736, 0.02513703719159821, 0.08112883806461468, 0.07570243236841634, 0.059325463298591785, 0.06586627423530445, 0.06659268095972948, 0.035518271251930855, 0.0531499671342317, 0.018846255807147827, 0.09737381245940924, 0.06220626906724647, 0.0009025987287714088, 0.07412840393953957, 0.013047705724602565, 0.044421928250812925, 0.03867339706630446, 0.04711686684458982, 0.05868928688869346, 0.03161945038300473, 0.023803074982424732, 0.035321164250490256, 0.09157231790595688, 0.052300742390798405, 0.14949542266549543, 0.12165632782853208, 0.12232155931997113, 0.18953633814817294, 0.05293449939927086, 0.28847211913671345, 0.24846246291417629, 0.14164958585752174, 0.12671329983277246, 0.08753439629799686, 0.11017453885870054, 0.15074193390319124, 0.17313825868768618, 0.11974617329542525, 0.19626316468929872, 0.10900937442784198, 0.12172651273431256, 0.14335992455016822, 0.11222219851333648, 0.28439639252610505, 0.13660042866831645, 0.1417404247331433, 0.12118869315600023, 0.1549960282864049, 0.171717164630536, 2.2465225774794817, 50.97071573138237, 88.147092461586, 83.64660635590553, 81.83308526873589, 64.65688213706017, 54.79938268661499, 52.64593183994293, 37.94015854597092, 58.01295764744282, 55.95765933394432, 56.974199786782265, 58.98772694170475, 61.082049161195755, 10.308197066187859, 0.24182818218832836, 0.22805948741734028, 0.14517217496177182, 0.7650109310634434, 2.5922914361581206, 3.916299515403807, 7.2931320033967495, 5.902776159346104, 11.968302335590124, 13.73147802427411, 14.268594402819872, 8.926451560109854, 22.57265456020832, 37.903061136603355, 49.003819674253464, 62.103457152843475, 62.20187187194824, 60.1618867367506, 61.16928867995739, 60.931444242596626, 62.79887303709984, 63.22697326540947, 70.06315603852272, 66.63625672459602, 63.94873693585396, 62.6917377859354, 67.79968589544296, 67.55872562527657, 66.59253627061844, 66.49570226669312, 66.79932877421379, 63.719210252165794, 66.18215069174767, 60.1267272233963, 60.0943111628294, 62.475217804312706, 61.54877811670303, 66.91845998167992, 66.96044772863388, 64.36238273978233, 62.36297942698002, 60.72403237223625, 68.60967323184013, 63.60838159918785, 63.67323271930218, 67.20602095127106, 69.85746547579765, 43.7863652408123, 34.21757809817791, 51.50236040353775, 54.29658606648445, 61.98111891746521, 61.902257949113846, 65.0367021560669, 64.58499759435654, 58.759879767894745, 62.576026394963264, 60.0301668047905, 58.12713772058487, 56.17144726216793, 59.12912875413895, 59.13695253431797, 55.56968875229359, 61.17172434926033, 69.38067466020584, 68.61243948340416, 67.41555690765381, 60.182949006557465, 54.5941860973835, 55.67118510603905, 59.22680251300335, 66.91671207547188, 69.16641935706139, 69.6623383462429, 60.45109681785107, 62.619948238134384, 61.26967169344425, 64.59458068013191, 59.80246402323246, 49.63465042412281, 47.57966369390488, 27.259015291929245, 8.831325564533472, 5.407758671790361, 10.683837309479713, 15.447885822504759, 6.5872890036553144, 1.482139325235039, 0.27191584347747266, 0.3674864745698869, 0.17257286090170965, 0.13647527288412675, 0.17998414055909961, 4.074527062475681, 20.084755159914494, 46.54329210519791, 48.287972286343575, 63.46355237066746, 60.84974482655525, 25.26844460517168, 36.59304343163967, 52.024661377072334, 66.40468195080757, 70.3484371304512, 74.8420000076294, 76.37187391519547, 41.191541478037834, 1.3461607717908919, 0.42745610349811614, 0.21950142632704228, 0.1372604354401119, 0.1899168372619897, 0.1991777864168398, 0.07864996092393994, 0.17237297084648162, 0.19268956035375595, 0.19056502904277295, 0.2830453572096303, 0.17338200967060402, 0.1091360961436294, 0.11850639333715662, 0.1848463952774182, 0.1424659779877402, 0.14283056545536965, 0.11872996532474644, 0.1314269023714587, 0.12708646652754396, 0.17073752969736233, 0.14041873393580317, 0.18567443912616, 0.09266154578654096, 0.1072520281013567, 0.10808750084834173, 0.13437092798994854, 0.2166341239353642, 0.29331730445846915], [0.0680544224451296, 0.02762137653917307, 0.05032315260905307, 0.027278094275970943, 0.032519426895305514, 0.04144504033320118, 0.02010345211601816, 0.017852902274171356, 0.04909792616672348, 0.01959839093615301, 0.03381986629392486, 0.0341865391965257, 0.02885410052840598, 0.11359092663042247, 0.028476898405642714, 0.04864805479883216, 0.012561048879433656, 0.05774756828031968, 0.004323021348682232, 0.04488593382120598, 0.01662822687649168, 0.06143642072856892, 0.04133316899242345, 0.05769097580923699, 0.12335796855040826, 10.145283658057451, 60.797653421759605, 67.82941550016403, 62.55995325744152, 48.281926810741425, 48.047988563776016, 27.578733935952187, 16.273086592555046, 22.073059268295765, 32.12275430560112, 64.90870982408524, 42.601072043180466, 31.847143694758415, 7.041593575850129, 0.38939051795750856, 0.14799263299209997, 0.04193976339593064, 0.09325413586338982, 0.30355077877175063, 0.9894093149341643, 1.9200461148284376, 1.1961663141846657, 1.0908104362897575, 1.8958968669176102, 3.392767170444131, 7.343437978997827, 26.876510716974735, 42.60738730430603, 54.58294630050659, 63.81773516535759, 65.86756557226181, 63.07405047118664, 66.21520131826401, 58.8094937056303, 60.459866747260094, 60.58478504419327, 61.770697608590126, 61.386082246899605, 56.46293722093105, 56.27597585320473, 59.14570726454258, 63.27137768268585, 60.86478441953659, 61.976304575800896, 60.228029787540436, 60.39176680147648, 55.30453898012638, 51.927040815353394, 51.04427978396416, 56.42270117998123, 55.909743905067444, 61.22294180095196, 60.596959590911865, 59.752234518527985, 57.94982023537159, 58.62206116318703, 56.96132607758045, 61.588045209646225, 58.16431872546673, 55.787162482738495, 54.29560951888561, 66.7534652352333, 42.20843531191349, 23.392086289823055, 65.0172472000122, 59.43812437355518, 63.96588921546936, 59.06289450824261, 61.20659127831459, 58.835100531578064, 61.13301582634449, 60.16416661441326, 64.45613130927086, 59.03544098138809, 56.30069352686405, 53.52395452558994, 58.8521958142519, 53.55996899306774, 61.88480168581009, 61.17326706647873, 57.528981417417526, 52.26996101438999, 48.614386171102524, 45.09727209806442, 49.430077001452446, 56.28619730472565, 60.86567737162113, 62.85636015236378, 59.60484802722931, 59.574077278375626, 59.26364913582802, 61.2023963034153, 57.74327091872692, 63.38953994214535, 60.644996613264084, 48.031831830739975, 40.969196408987045, 29.441519379615784, 10.819541327655315, 4.077269090339541, 2.076684753410518, 3.3443810418248177, 2.005804069340229, 1.21361248428002, 0.17692315246677026, 0.01959684170287801, 0.1472020972869359, 0.056448802424711175, 0.02679131404875079, 0.16460357524920255, 10.922948028892279, 28.42643614858389, 56.782416477799416, 62.97879338264465, 50.28724640607834, 22.77055364102125, 23.98967832326889, 36.85732305049896, 43.008983954787254, 43.98089200258255, 47.61298410594463, 52.057780399918556, 12.884149141609669, 0.32045823871158063, 0.06623199718887918, 0.04574110316752922, 0.019871167314704508, 0.010516269685467705, 0.029037475942459423, 0.03151626959152054, 0.03250057634431869, 0.11576368269743398, 0.05905917700147256, 0.0426447406061925, 0.028602475358638912, 0.06563089467817917, 0.044535261622513644, 0.035123619381920435, 0.0457652749173576, 0.056751004958641715, 0.08607127441791818, 0.011800539541582111, 0.022918193753866944, 0.035865514728357084, 0.022187566064530984, 0.038086658823885955, 0.027444966181064956, 0.04442385783477221, 0.021713702917622868, 0.06831959180999547, 0.06038968451321125, 0.05175826583581511, 0.03854322807455901, 0.05491466443345416, 0.034484559728298336, 0.07810531358700246, 0.016117916857183445, 0.03532698639901355, 0.03277918971434701, 0.032873041709535755, 0.03569973006960936, 0.02580778469564393, 0.012996866753383074, 0.03220138321921695, 0.08680804894538596, 0.033775196425267495, 0.0404035288374871, 0.06563879855093546, 0.027289078061585315, 0.04570851175230928, 0.022809153706475627, 0.0463132173899794, 0.06229039150639437, 0.06701013902784325, 0.06585240349522792, 0.07075145389535464, 14.607692006975412, 72.61098772287369, 76.12548753619194, 69.04377713799477, 58.24308089911938, 57.62649558484554, 39.30960886180401, 26.772791482508183, 23.16463429480791, 38.27289529144764, 59.87706921994686, 43.01611237227917, 28.497017361223698, 6.805286156013608, 0.3406171960523352, 0.052968044474255294, 0.02026172624027822, 0.5944035889115185, 1.4938456658273935, 2.3758911481127143, 3.7376290652900934, 3.2196330232545733, 3.975465903058648, 4.23807836137712, 3.924214728176594, 8.798373732715845, 23.726185262203217, 42.49569609761238, 57.00003080070019, 65.20273044705391, 67.4319340288639, 67.07549035549164, 65.20089894533157, 58.93103018403053, 61.94863826036453, 61.14047482609749, 63.861311227083206, 62.42315299808979, 58.33069659769535, 59.09509778022766, 61.61721624433994, 65.48039674758911, 62.33108773827553, 62.24203571677208, 63.341267332434654, 63.75448375940323, 57.223815992474556, 54.713773280382156, 53.92539158463478, 56.87265783548355, 59.645293056964874, 62.818225398659706, 62.66244895756245, 62.093767672777176, 59.540384486317635, 60.27913324534893, 59.586065635085106, 63.71751934289932, 60.29454901814461, 57.75788113474846, 57.49516703188419, 70.14753431081772, 44.425099566578865, 26.569819673895836, 64.4590799510479, 60.50619386136532, 66.53265908360481, 60.253617614507675, 64.43396329879761, 62.47407786548138, 62.89553605020046, 61.632096245884895, 64.722770601511, 59.687706381082535, 59.18700344860554, 54.58030924201012, 57.45067521929741, 52.98180341720581, 63.11004213988781, 62.6541768014431, 61.75671435892582, 55.18693529069424, 50.45942276716232, 47.54335664212704, 52.05466836690903, 58.391113355755806, 63.348513543605804, 64.70308005809784, 61.230571791529655, 59.04939383268356, 59.31715786457062, 60.691844299435616, 60.29911257326603, 65.35413712263107, 65.57187303900719, 54.0136494487524, 46.57060503959656, 31.829795725643635, 11.14942917600274, 1.9307345850393176, 0.9464444860350341, 3.5108577087521553, 2.988895629532635, 2.891322090290487, 0.6602760823443532, 0.11270820876234211, 0.034287853486603126, 0.026395035019959323, 0.009517507751297671, 0.23563495982671157, 11.082518566399813, 33.1680516153574, 63.64511042833328, 65.71856796741486, 35.24178273975849, 30.5308810248971, 40.067094415426254, 48.64430196583271, 48.2626086473465, 54.42370444536209, 55.142831057310104, 67.8058947622776, 23.561034724116325, 0.5786831793375313, 0.13146748300641775, 0.05943642550846562, 0.042328533745603636, 0.032319633319275454, 0.05344873723515775, 0.010896411640715087, 0.03760703846637625, 0.08141130689182319, 0.007218171440399601, 0.03537836157192942, 0.03352704821736552, 0.031016405300761107, 0.026325265716877766, 0.03087573863012949, 0.01757924459525384, 0.15262896311469376, 0.03040765310288407, 0.03780446088057943, 0.04209123202599585, 0.06044769448635634, 0.01868908562755678, 0.0377547592506744, 0.015001886313257273, 0.03387626951735001, 0.019609220726124477, 0.0428480000118725, 0.014255169789976208, 0.14369685959536582, 0.1272887017694302, 0.25804068020079285, 0.10869824385736138, 0.28859507816378027, 0.10360719243180938, 0.14889751881128177, 0.10615427294396795, 0.15572747419355437, 0.11980484006926417, 0.13563915446866304, 0.10669487557606772, 0.1465900629409589, 0.20582368917530403, 0.10300088004441932, 0.12611251644557342, 0.19645471300464123, 0.09807817739783786, 0.13975034089526162, 0.13953773042885587, 0.08353496246854775, 0.17872648226330057, 0.2020454895682633, 0.23123770515667275, 0.21464861172717065, 20.683603025972843, 87.81825050711632, 83.5706028342247, 81.5685586631298, 65.57191863656044, 64.29514154791832, 40.768536776304245, 25.93068826943636, 30.4393857344985, 41.06823429465294, 79.20393794775009, 56.96664959192276, 43.08509387075901, 10.054766815155745, 0.7110861840192229, 0.24166232702555135, 0.145076482440345, 0.4043924395227805, 1.0010222042910755, 4.210958266630769, 6.355304326862097, 5.887707592919469, 5.344866346567869, 7.061498332768679, 8.354373257607222, 13.818968329578638, 33.42807166278362, 46.60603053867817, 58.567169308662415, 68.50625798106194, 70.42346030473709, 66.15484535694122, 68.15375849604607, 59.23668958246708, 63.78741279244423, 61.650111079216, 64.4823195040226, 65.65517976880074, 60.47453016042709, 61.22467830777168, 65.90487957000732, 66.49284482002258, 63.66992309689522, 63.75834435224533, 64.63678881525993, 65.20129412412643, 59.44397985935211, 56.13152280449867, 56.79605774581432, 61.06643579900265, 62.07128807902336, 65.57948783040047, 64.56105127930641, 63.88406440615654, 59.69489559531212, 60.98912514746189, 62.508325427770615, 64.8535443842411, 63.41063641011715, 60.16627550125122, 59.56354044377804, 71.84668153524399, 48.482810631394386, 29.99230932444334, 64.53773573040962, 61.78178921341896, 67.67958953976631, 62.667962461709976, 67.1341136097908, 64.40551042556763, 67.49635577201843, 65.88559180498123, 68.17640528082848, 62.45235063135624, 60.36658175289631, 54.57568868994713, 58.12253996729851, 52.420733124017715, 65.23266524076462, 68.15703392028809, 63.68338957428932, 57.89636090397835, 53.56984466314316, 49.661305993795395, 53.6192724108696, 62.13037870824337, 66.87274843454361, 65.41861206293106, 61.090632900595665, 59.490648955106735, 61.083747670054436, 61.839983090758324, 59.96948026120663, 68.40496301651001, 67.33181700110435, 58.035695627331734, 50.200523659586906, 36.41177795827389, 14.99065350741148, 8.15124660730362, 11.968917902559042, 12.510546538978815, 6.36828538030386, 1.9304934167303145, 0.29386616719421, 0.10699180886149406, 0.2615046693244949, 0.17538815358420834, 0.13592516334028915, 0.6671695655677468, 15.496617257595062, 43.42010289430618, 66.2977708876133, 73.51423725485802, 66.35451704263687, 35.542544201016426, 37.20506899058819, 51.12070508301258, 60.08215941488743, 64.65430587530136, 62.36245505511761, 79.02487635612488, 30.88093724101782, 1.1990965506993234, 0.2620892145205289, 0.19931103161070496, 0.1456064055673778, 0.13523526286007836, 0.18688605458009988, 0.08561545473639853, 0.15758716268464923, 0.21293552708812058, 0.14696434285724536, 0.12112970725866035, 0.08502106124069542, 0.15022674982901663, 0.150054527039174, 0.12270281542441808, 0.1469056835048832, 0.2024758016341366, 0.1567249948857352, 0.14701454172609374, 0.09281031670980155, 0.12483153986977413, 0.13692348555196077, 0.09659650924731977, 0.12699461833108217, 0.13605359941720963, 0.08357157261343673, 0.14491603011265397, 0.14357373729581013], [0.047679893468739465, 0.05417415319243446, 0.024009879998629913, 0.04809787846170366, 0.025291940110037103, 0.021202660027483944, 0.024545551059418358, 0.02857465409761062, 0.015056241209094878, 0.0571637466782704, 0.039103145099943504, 0.056611310501466505, 0.04768463950313162, 0.049350568078807555, 0.01592401593370596, 0.08648038332466967, 0.06487842372735031, 0.07464000344043598, 0.060128066324978136, 0.04373442119685933, 0.077318889379967, 0.0035666900703290594, 0.037070035250508226, 0.14140540442895144, 0.3946065396303311, 35.10245181620121, 68.89409556984901, 59.11722779273987, 54.66777674853802, 38.9827997982502, 22.26458229124546, 16.59867972135544, 27.545048743486404, 47.92559713125229, 35.402776300907135, 38.8568327575922, 31.532170996069908, 8.571712095290422, 0.19656879594549537, 0.025064353103516623, 0.03603352954087313, 0.08652336109662428, 0.16118824132718146, 1.3399272062815726, 0.9224303090013564, 3.81710940040648, 3.0459557427093387, 2.3311323998495936, 3.324208161793649, 9.063579551875591, 31.051606982946396, 49.01320897042751, 56.60856440663338, 63.83424147963524, 61.23318985104561, 61.04699984192848, 65.12289673089981, 61.36801041662693, 59.2308758944273, 59.56838138401508, 61.19976684451103, 62.551878690719604, 60.799298733472824, 53.26356589794159, 49.545807391405106, 58.049819469451904, 58.05415503680706, 58.709346279501915, 60.0179922580719, 61.65275573730469, 59.73654896020889, 52.11568929255009, 50.886185467243195, 51.8178840726614, 54.64680567383766, 57.45772384107113, 60.00971630215645, 57.633829191327095, 61.03747375309467, 58.98778773844242, 56.984721422195435, 53.302236422896385, 61.061803847551346, 55.979048386216164, 52.763372138142586, 53.04291933774948, 67.10560753941536, 43.06393280625343, 35.272751078009605, 68.34585338830948, 53.2357931882143, 63.290220871567726, 54.24698732793331, 60.081118270754814, 54.359351098537445, 57.4781059473753, 54.51579250395298, 60.039461106061935, 57.73801580071449, 62.89695717394352, 56.333196982741356, 53.49740535020828, 53.02977964282036, 62.81631030142307, 60.335852801799774, 57.14203678071499, 48.69348652660847, 46.29783667623997, 45.62743864953518, 51.44121028482914, 57.451279386878014, 63.01153622567654, 63.57196435332298, 56.748362705111504, 58.330658599734306, 57.33399488031864, 64.19706121087074, 67.14134082198143, 63.76662790775299, 62.79891483485699, 66.29368990659714, 54.60040256381035, 46.35326810181141, 31.779784709215164, 11.165794897824526, 1.9687033351510763, 3.551442618481815, 5.577032463625073, 2.0188706181943417, 0.40941431536339223, 0.08738544725929387, 0.03153593650495168, 0.04357143072411418, 0.12131034600315616, 0.08095182100078091, 0.3690555231878534, 14.976853597909212, 25.083181746304035, 36.49493649601936, 63.39531183242798, 29.81511153280735, 12.824024967849255, 17.994493022561073, 37.794987335801125, 39.37230549752712, 48.89009937644005, 48.7628898024559, 52.537029683589935, 9.657154250890017, 0.11062953475629911, 0.22047105710953474, 0.00800201343736262, 0.06583285532542504, 0.022667585326416884, 0.07310845554457046, 0.11259903141763061, 0.06247954268474132, 0.07113898114766926, 0.031694399876869284, 0.07897131086792797, 0.04941751350997947, 0.03703605972987134, 0.015671693145122845, 0.08962298539699987, 0.0629920995561406, 0.005872046822332777, 0.06131169167929329, 0.06450513828895055, 0.07624705744092353, 0.029465787920344155, 0.03005985858180793, 0.1291045144898817, 0.11790488264523447, 0.06764277539332397, 0.10456174277351238, 0.04899253377516288, 0.05188033057493158, 0.056510909053031355, 0.012509305415733252, 0.02095403498969972, 0.026291631584172137, 0.014079287284403108, 0.022019516000000294, 0.046310263642226346, 0.011176539919688366, 0.04575888502586167, 0.0790469505591318, 0.021239787820377387, 0.07234068893012591, 0.05500312843651045, 0.01746872025250923, 0.06619964697165415, 0.02186825888202293, 0.035954394334112294, 0.10234342626063153, 0.07002517333603464, 0.018674747334443964, 0.010507963197596837, 0.05185378024179954, 0.14260995463700965, 1.3025374501012266, 45.05224451422691, 79.50631812214851, 67.7694471180439, 63.232353776693344, 46.826965883374214, 34.77382645010948, 27.478478215634823, 29.499443471431732, 42.502045556902885, 28.44590250402689, 50.13486698269844, 31.069880202412605, 6.372211994603276, 0.29134785232599825, 0.03253019916883204, 0.18777027900796384, 0.4876023338874802, 1.5494078281335533, 2.7190160611644387, 4.300342770293355, 5.2779419627040625, 3.95071426872164, 3.0988709907978773, 4.247443908825517, 9.82132539153099, 27.268453985452652, 46.746626794338226, 59.70315255224705, 65.54183185100555, 64.36068043112755, 63.20328913629055, 66.8771941959858, 62.60943420231342, 58.677625581622124, 58.816785514354706, 60.57879276573658, 63.961990624666214, 62.82573759555817, 54.817515313625336, 52.627480030059814, 61.07779338955879, 61.82673320174217, 59.89995539188385, 62.28727228939533, 63.12078796327114, 61.95857472717762, 55.82822307944298, 52.17793755233288, 52.46681705117226, 57.12768875062466, 60.40247082710266, 62.51107648015022, 60.102419927716255, 62.74545170366764, 60.0568413734436, 58.97011108696461, 55.672572031617165, 62.911958768963814, 60.22299885749817, 55.72871781885624, 54.698456302285194, 70.28876513242722, 45.09688451886177, 37.50123269855976, 69.98950839042664, 57.34844170510769, 65.20991206169128, 57.853901982307434, 62.86207504570484, 57.06809274852276, 58.51093992590904, 57.55051866173744, 62.6847879588604, 60.90298756957054, 63.50777439773083, 56.6385143995285, 53.65926906466484, 53.69288966059685, 64.06224444508553, 63.003533855080605, 58.888540863990784, 51.21932119131088, 49.25285071134567, 47.32818938791752, 53.71597722172737, 60.4119361191988, 66.2854215502739, 63.13341088593006, 57.057130336761475, 58.066010400652885, 56.91667087376118, 66.37162372469902, 69.21653106808662, 67.3453138768673, 66.8578152358532, 67.97690078616142, 60.8402681350708, 52.71720461547375, 35.22150322794914, 13.482915312051773, 1.6481228498741984, 2.835720148868859, 5.355223640799522, 5.72305197827518, 2.810210455209017, 0.3392890782561153, 0.09497458260739222, 0.044878456683363765, 0.05181960805202834, 0.09843386651482433, 0.2927731617819518, 14.920259434729815, 31.306504905223846, 40.160299614071846, 55.22097386419773, 25.867645852267742, 22.35091555863619, 32.822596952319145, 51.67050518095493, 47.50743716955185, 60.037694200873375, 55.88005989789963, 65.6855097413063, 15.160113014280796, 0.2409252111101523, 0.029905707087891642, 0.012532563396234764, 0.037696415311074816, 0.058535346906865016, 0.012945907183166128, 0.019042251442442648, 0.036730580613948405, 0.05404972100222949, 0.052400227286852896, 0.06085488865210209, 0.016290041312458925, 0.019413559057284147, 0.03046719190024305, 0.032632222209940664, 0.011551158440852305, 0.06727959800628014, 0.06555460189701989, 0.033787979918997735, 0.050460134516470134, 0.009923542311298661, 0.04147016574279405, 0.05336098940460943, 0.04272515230695717, 0.031430113667738624, 0.049017759374692105, 0.026307604457542766, 0.2158974384656176, 0.2157618777710013, 0.06921323409187607, 0.1629024837166071, 0.13163289288058877, 0.066820965585066, 0.11847112647956237, 0.07925802477984689, 0.14142107858788222, 0.12505626218626276, 0.14758209174033254, 0.16749633330618963, 0.158217795251403, 0.1345802136347629, 0.13254327059257776, 0.33655785606242716, 0.16477863304316998, 0.15431654755957425, 0.18873303750297055, 0.10431125308969058, 0.13751810911344364, 0.1109473743417766, 0.21089626854518428, 0.25739507109392434, 2.3938556341454387, 56.9040821492672, 87.64439463615417, 76.4278145134449, 71.70029059052467, 53.95898938179016, 33.84700298309326, 26.985211484134197, 39.69266630709171, 66.21530011296272, 46.932064443826675, 52.33542010188103, 40.28615266084671, 12.212204597890377, 0.6753892370034009, 0.12794392911018804, 0.21814041654579341, 0.47353836824186146, 1.045450964011252, 4.973887503147125, 7.071442399173975, 11.112758293747902, 9.98378187417984, 8.551297690719366, 8.568075690418482, 14.18062437325716, 36.21462933719158, 53.60241271555424, 61.98225885629654, 68.13830092549324, 65.22521004080772, 66.00632652640343, 68.51309761404991, 64.78933542966843, 58.992309495806694, 59.52199347317219, 60.92980653047562, 67.47538849711418, 65.633794516325, 56.3871730864048, 54.100645780563354, 64.88828212022781, 62.83919267356396, 64.03530389070511, 63.46731036901474, 67.58486822247505, 64.15547624230385, 58.30634370446205, 54.73394259810448, 55.699516385793686, 58.92745077610016, 61.98120251297951, 64.30370628833771, 61.55469439923763, 62.9495045542717, 60.61323791742325, 61.087916046381, 59.39636081457138, 66.29945799708366, 62.66144581139088, 58.43263752758503, 58.84152218699455, 72.10667878389359, 48.88425149023533, 41.764391139149666, 70.56755617260933, 60.30868425965309, 68.16600903868675, 60.441612526774406, 65.62036603689194, 59.479253366589546, 61.500011533498764, 59.99884508550167, 63.479192331433296, 63.11340495944023, 65.61288803815842, 57.461158856749535, 52.12406404316425, 54.71229135990143, 65.56877240538597, 68.08428302407265, 62.158903777599335, 54.00900989770889, 51.34683474898338, 50.129836052656174, 57.91508249938488, 63.87540087103844, 68.80980849266052, 66.77351295948029, 57.85244286060333, 58.866023272275925, 58.31767089664936, 71.1855474114418, 74.18736353516579, 70.59738457202911, 67.73181393742561, 73.6038364470005, 64.24936920404434, 57.40535885095596, 37.616305723786354, 17.503177486360073, 4.358710963279009, 12.272857893258333, 19.392198622226715, 9.705974031239748, 1.847272776067257, 0.19285590533399954, 0.170766903902404, 0.10805710990098305, 0.33033613523002714, 0.27275378757622093, 0.7717180461622775, 21.600577421486378, 39.534199610352516, 46.80374152958393, 78.83273586630821, 40.47199688851833, 22.658691443502903, 30.119767785072327, 53.172879964113235, 54.76326562464237, 72.31093302369118, 65.21801322698593, 76.08462452888489, 19.684545435011387, 0.47842342173680663, 0.36794568586628884, 0.07975744563736953, 0.14468170440522954, 0.21624966175295413, 0.22033187473425642, 0.19830274977721274, 0.21377198689151555, 0.1650327889365144, 0.11663978060823865, 0.20502317900536582, 0.07934881912660785, 0.15202538925223053, 0.16017743619158864, 0.14149288879707456, 0.13564233086071908, 0.19687551073729992, 0.17446892947191373, 0.16739111160859466, 0.17976961535168812, 0.12915696948766708, 0.18138338578864932, 0.22347222809912637, 0.18707221490330994, 0.2171242085751146, 0.2804535400355235, 0.12703179992968217], [0.013479284079949139, 0.013847355930920457, 0.05546371641685255, 0.01652236136578722, 0.07835932847228833, 0.06108100249548443, 0.06893940386362374, 0.02133606107236119, 0.04666211214498617, 0.05766633650637232, 0.07122082519344985, 0.025915121514117345, 0.07530303817475215, 0.030437667410296854, 0.040511288680136204, 0.01733487948513357, 0.10860886701266281, 0.016610296588623896, 0.12455960211809725, 0.04481631294765975, 0.027160666104464326, 0.07744887654553168, 0.0367853362695314, 0.05580727141932584, 7.34233888797462, 54.777271673083305, 65.28759509325027, 59.10477966070175, 43.733966052532196, 43.05967703461647, 27.691684775054455, 21.09671115875244, 36.392266005277634, 28.50247196853161, 43.574329018592834, 33.77941220998764, 7.46638560667634, 0.28260122635401785, 0.03008851290360326, 0.14848872902803123, 0.06054899393348023, 0.29482335958164185, 2.277125185355544, 1.9365583662874997, 1.1502567026764154, 2.3505374835804105, 1.890681884251535, 3.733473513275385, 12.40144869312644, 25.933471620082855, 51.44209943711758, 60.99341131746769, 65.90509995818138, 60.759784653782845, 59.85954076051712, 59.08521071076393, 63.739337772130966, 62.26917766034603, 59.107929691672325, 57.410952150821686, 60.90092808008194, 58.96921433508396, 59.159390330314636, 50.68827688694, 47.929761707782745, 57.53294080495834, 60.696784034371376, 59.96518649160862, 60.7740680873394, 56.59313343465328, 55.020044445991516, 49.64426390826702, 50.19896574318409, 50.27903124690056, 58.04425656795502, 58.56121502816677, 62.55565568804741, 57.02672816812992, 57.55595616996288, 56.020382568240166, 55.065843388438225, 50.60344643890858, 59.39369335770607, 53.28359842300415, 48.39333303272724, 51.85572624206543, 67.6556508243084, 40.25334522128105, 39.85274791717529, 68.08014884591103, 55.232954621315, 58.45600627362728, 51.66509427130222, 55.506273955106735, 53.988646790385246, 54.19378638267517, 50.91178089380264, 54.972759783267975, 55.63303895294666, 61.42236270010471, 57.7130663394928, 53.46888788044453, 53.51581156253815, 61.53672896325588, 57.18523286283016, 52.72896498441696, 43.68268400430679, 45.58831974864006, 44.14766505360603, 51.357675567269325, 57.21117787063122, 60.108894780278206, 57.00633846223354, 55.364191979169846, 57.25899450480938, 61.85837410390377, 64.67553153634071, 59.5813462883234, 61.875169202685356, 60.66266566514969, 60.608218386769295, 65.26289641857147, 63.330179527401924, 52.93706461787224, 34.09267120063305, 14.584697540849447, 2.3285295395180583, 2.6243541156873107, 4.759597526863217, 3.610668615438044, 0.7289705774746835, 0.019210973150620703, 0.12394554913043976, 0.06984125429880805, 0.03748272130906116, 0.24001774261705577, 1.074271823745221, 27.500963509082794, 37.278633043169975, 49.626378268003464, 58.23628306388855, 33.918625339865685, 11.867262907326221, 14.295546356588602, 31.77885565906763, 41.36158615350723, 47.84066788852215, 50.44579669833183, 40.87927423417568, 3.182212393730879, 0.16477190918521956, 0.09121921888436191, 0.01910931747261202, 0.028134039166616276, 0.059205714060226455, 0.04796398388862144, 0.019775641776504926, 0.04829261059057899, 0.04505533644987736, 0.01762101452186471, 0.03404146045795642, 0.013844423519913107, 0.04224969910865184, 0.043703982009901665, 0.006655862380284816, 0.0244299467158271, 0.08104859705781564, 0.018631324273883365, 0.02114462407917017, 0.03656002394563984, 0.02218764213466784, 0.019120176948490553, 0.08059812826104462, 0.0605484039260773, 0.004677526740124449, 0.05598270770860836, 0.048878454545047134, 0.012724567204713821, 0.019949374836869538, 0.01106413979869103, 0.042669168396969326, 0.06048853487300221, 0.028422799550753552, 0.042339870051364414, 0.07134819999919273, 0.023252761347976048, 0.035369325923966244, 0.05253726485534571, 0.024385796350543387, 0.036632806368288584, 0.05863496167876292, 0.02850679768016562, 0.05552610877202824, 0.023191901527752634, 0.056267555119120516, 0.09215365702402778, 0.04063669308379758, 0.037449009250849485, 0.017114209294959437, 0.1820437191054225, 11.994250193238258, 68.43161478638649, 74.12130028009415, 66.20843008160591, 54.07731883227825, 48.38649719953537, 35.52681304514408, 21.682073548436165, 35.2270433306694, 32.15682327747345, 42.363204807043076, 31.255893521010876, 5.9347666427493095, 0.41372191859409213, 0.018231486646982376, 0.12128831906011328, 0.26766443566884845, 1.2795207789167762, 3.7882499489933252, 4.6850222535431385, 4.470214080065489, 3.5908106435090303, 1.965126064606011, 3.157306155189872, 11.645984631031752, 25.518089309334755, 49.763573706150055, 63.03844638168812, 65.98316296935081, 62.52900391817093, 61.786945536732674, 62.42009036242962, 65.72201058268547, 63.7763249874115, 59.676610976457596, 58.284035101532936, 60.4671623557806, 60.30420809984207, 63.23859304189682, 51.794298738241196, 49.781744331121445, 60.551905408501625, 63.2323993742466, 61.32183149456978, 62.856550142169, 58.86475794017315, 56.70439526438713, 52.690465450286865, 51.84169739484787, 52.579750791192055, 59.48306456208229, 60.42166359722614, 62.798998430371284, 58.125272020697594, 59.84170451760292, 57.43122786283493, 57.116977125406265, 55.556043684482574, 62.70359694957733, 55.350273326039314, 51.14757344126701, 54.48595270514488, 69.3163289129734, 43.83182220160961, 41.74927935004234, 68.66879045963287, 57.153078988194466, 61.462401151657104, 55.0974652916193, 58.77719163894653, 55.73849469423294, 56.41234293580055, 52.40640789270401, 57.52203159034252, 58.5965683311224, 64.00671422481537, 58.259526416659355, 53.874740302562714, 52.9077909886837, 62.78678968548775, 60.330639481544495, 56.44254371523857, 46.48089565336704, 47.20900118350983, 46.095322743058205, 54.58758965134621, 59.622175097465515, 62.881955578923225, 58.45629125833511, 56.2680646777153, 56.904123947024345, 63.459965363144875, 66.78412199020386, 63.39240498840809, 64.95141953229904, 64.53678578138351, 63.36736433207989, 66.5765543282032, 65.18943876028061, 58.31735551357269, 38.73328998684883, 16.7378643527627, 2.5984846288338304, 3.5261053405702114, 6.359471753239632, 5.910770930349827, 3.1414296571165323, 0.6779269664548337, 0.11313846145640127, 0.20604237040970474, 0.06527384000946768, 0.1221107151650358, 1.062833012547344, 24.825897552073002, 36.335816234350204, 53.55726733803749, 48.04627865552902, 19.868884943425655, 20.18944714218378, 28.64725559949875, 44.65394988656044, 47.5729950517416, 54.68961797654629, 58.96645188331604, 51.4687018096447, 5.006853109225631, 0.18794523290125653, 0.07575112467748113, 0.0228600409172941, 0.02864341779059032, 0.04742214186990168, 0.023069029703037813, 0.054840568409417756, 0.04186793463304639, 0.05740956825320609, 0.05478472921822686, 0.012955913189216517, 0.028894228453282267, 0.13058475771686062, 0.024498324492014945, 0.0909527507610619, 0.06905169080710039, 0.06886211660457775, 0.00711078545464261, 0.011542154334165389, 0.06010227298247628, 0.0208637638570508, 0.032498784057679586, 0.03951260652684141, 0.04043262844788842, 0.040224682379630394, 0.07430605925037526, 0.1586787134874612, 0.10533773238421418, 0.17919486650498584, 0.11085351492511109, 0.21977796539431438, 0.1251749909715727, 0.0990793494565878, 0.08665112181915902, 0.13903467304771766, 0.19030670227948576, 0.1734947567456402, 0.11193916565389372, 0.14809216983849183, 0.12323068280238658, 0.17651180969551206, 0.13166489428840578, 0.18447993759764358, 0.09730236590257846, 0.2112827345263213, 0.22310995613224804, 0.10974145858199336, 0.2355011209147051, 0.09431790065718815, 0.26219869614578784, 17.951217144727707, 80.74189022183418, 83.79157617688179, 77.2053211927414, 61.12129345536232, 56.61908224225044, 40.21502807736397, 31.68031744658947, 49.45818409323692, 40.15414014458656, 56.8908778578043, 45.00329554080963, 11.615950092673302, 0.6285162584390491, 0.1827885236707516, 0.509778211126104, 0.21420333796413615, 1.141053952742368, 5.359212951734662, 7.786213019862771, 7.0628895331174135, 6.9070560950785875, 6.243045525625348, 9.688973743468523, 21.000405326485634, 31.081874258816242, 55.3778712451458, 67.48402923345566, 71.81304574012756, 65.51527127623558, 65.53362429141998, 63.95901918411255, 68.7748047709465, 65.52699744701385, 58.73714178800583, 58.60772453248501, 60.09304963052273, 61.89162231981754, 65.03158003091812, 53.63965071737766, 52.48660258948803, 62.285619378089905, 66.60897418856621, 63.90525966882706, 65.33390700817108, 60.43887287378311, 59.91252891719341, 54.86269488930702, 54.195093512535095, 55.68685166537762, 62.90024019777775, 62.30383180081844, 65.29096931219101, 59.85306590795517, 60.2095627784729, 57.9012094438076, 58.36527094244957, 58.870833814144135, 64.44504350423813, 59.15247470140457, 52.967820167541504, 57.63020038604736, 72.0355997979641, 47.303798496723175, 44.141904562711716, 70.65282359719276, 61.83488756418228, 63.10769386589527, 57.85435415804386, 61.1060144752264, 58.641003146767616, 59.550993517041206, 56.94539353251457, 60.06082735955715, 62.532378137111664, 66.76538899540901, 60.29422603547573, 54.01279829442501, 53.53552870452404, 65.9226094186306, 63.26708011329174, 58.74446019530296, 49.17453311383724, 49.618945866823196, 49.46487933397293, 57.12228924036026, 64.48637008666992, 65.48892349004745, 60.21860249340534, 57.379128858447075, 58.12761649489403, 64.93102222681046, 69.86722335219383, 66.62343621253967, 68.9719457924366, 67.89075180888176, 66.92102864384651, 69.72113639116287, 71.06710776686668, 61.01693965494633, 41.48625746369362, 20.047872439026833, 5.661677196621895, 9.676060136407614, 22.42473989725113, 13.810880463570356, 2.027178159914911, 0.3678228158969432, 0.2534428972285241, 0.3627079934813082, 0.1903587268316187, 0.3562142013106495, 1.8047415395267308, 38.56016747653484, 53.47377061843872, 61.51163510978222, 76.90868631005287, 49.025516510009766, 21.419794522225857, 23.711029775440693, 45.22209160029888, 56.29709132015705, 64.86650928854942, 67.460827678442, 65.0300221145153, 6.099787037819624, 0.45941835560370237, 0.16210259695071727, 0.08237209127401002, 0.19628367765108123, 0.11941651129745878, 0.06162097430205904, 0.3281878848792985, 0.11384731638827361, 0.11658258328679949, 0.12581093731569126, 0.22994838684098795, 0.1922193355858326, 0.17670515400823206, 0.19174804212525487, 0.12981667940039188, 0.14337809232529253, 0.1799780549481511, 0.1666850916808471, 0.1361836533760652, 0.10889533601584844, 0.07987728022271767, 0.09666194440796971, 0.22066655365051702, 0.13017614604905248, 0.18436779908370227, 0.17855400714324787], [0.04692700691521168, 0.02626830402732594, 0.022157709463499486, 0.0417449013912119, 0.021989095366734546, 0.024290213295898866, 0.05780557454272639, 0.025750212589628063, 0.09438479784876108, 0.025687406487122644, 0.023367389767372515, 0.012044404629705241, 0.060722292837454006, 0.020684826486103702, 0.030559140286641195, 0.04759399358590599, 0.06343055298202671, 0.03981813759310171, 0.023380527636618353, 0.06471101005445234, 0.007141893038351554, 0.035326325887581334, 0.043990428748656996, 0.9073295630514622, 29.866146594285965, 69.29723873734474, 59.853035509586334, 48.89951527118683, 34.02762249112129, 32.58671320974827, 20.459320060908794, 39.80746574699879, 41.38476110994816, 31.57740756869316, 44.888921678066254, 15.40454724803567, 0.6681611342355609, 0.05037616421759594, 0.07306071318453178, 0.026247139830957167, 0.34826395916752517, 0.9141792298760265, 3.8521382957696915, 1.7841369076631963, 2.810334423556924, 2.3723552003502846, 3.9679508563131094, 13.564245197921991, 33.89900699257851, 50.93790449202061, 65.28706312179565, 61.73364959657192, 60.0573543459177, 54.7320768982172, 56.54016047716141, 58.041596710681915, 57.77524620294571, 59.43168371915817, 61.21804006397724, 56.88992030918598, 56.256893277168274, 59.11763057112694, 58.77162113785744, 53.330491706728935, 44.317291751503944, 48.312309980392456, 56.79009206593037, 54.577375799417496, 57.04375125467777, 55.00769130885601, 49.445621967315674, 45.72052605450153, 51.32672622799873, 54.09384794533253, 57.65057489275932, 56.66291669011116, 59.15333725512028, 56.75705283880234, 57.82278545200825, 54.53727275133133, 55.22473186254501, 54.04191993176937, 60.54283529520035, 45.96412718296051, 49.26546983420849, 53.35058882832527, 67.14552819728851, 38.296473026275635, 41.14937134087086, 65.01669242978096, 53.02635222673416, 53.69285926222801, 50.669293105602264, 55.715391933918, 52.23088011145592, 53.53217348456383, 46.088802292943, 49.30357798933983, 51.405404806137085, 58.69430668652058, 61.71334728598595, 56.745474860072136, 52.81403101980686, 59.23374854028225, 59.93663102388382, 55.34928537905216, 43.33295077085495, 45.017062202095985, 44.55301970243454, 53.49542185664177, 57.986150085926056, 60.21830230951309, 57.15864188969135, 55.3704122453928, 56.32519081234932, 61.596799939870834, 59.61462490260601, 63.66649188101292, 56.262269988656044, 58.72943580150604, 58.27895097434521, 58.39708283543587, 60.20844183862209, 64.50030013918877, 60.24730235338211, 38.97909499704838, 16.803184747695923, 1.0358256055042148, 5.301926750689745, 5.606619575992227, 3.511092821136117, 0.5987992999143898, 0.07001482037594542, 0.13823192159179598, 0.06181976597872563, 0.056918515110737644, 0.22855576156871393, 3.501786170527339, 31.06272328644991, 33.399630188941956, 60.70686109364033, 50.73259010910988, 30.78722856938839, 14.85601058229804, 22.903594002127647, 40.013046115636826, 53.116764575242996, 51.495376378297806, 55.95591142773628, 17.177700251340866, 0.37844012898858637, 0.05835328694956843, 0.03946606273530051, 0.025980139216699172, 0.10083326706080697, 0.0224060933032888, 0.05637663598463405, 0.025806973899307195, 0.02457872877130285, 0.0713628351513762, 0.11524234621901996, 0.04202289135719184, 0.043651033483911306, 0.047256416582968086, 0.007535115810242132, 0.024388648052990902, 0.02669510016858112, 0.01760699349688366, 0.06174424874188844, 0.03763475768209901, 0.04162187186011579, 0.03449405550782103, 0.010582325467112241, 0.07370198814896867, 0.05317247276252601, 0.13318775163497776, 0.05386152719438542, 0.015432609343406511, 0.04966109379893169, 0.01916759090818232, 0.02305063000676455, 0.0921331366407685, 0.05463935362058692, 0.013418007729342207, 0.05754053876444232, 0.00927955665247282, 0.08396494056796655, 0.04914044380711857, 0.03156920327455737, 0.020441407614271156, 0.060374908352969214, 0.05618545132165309, 0.021356779980123974, 0.017586469402885996, 0.020531803056655917, 0.033694717931211926, 0.058653697196859866, 0.06067925940442365, 0.011788731972046662, 1.1692721885628998, 37.01811522245407, 79.75506037473679, 69.23420011997223, 55.463765636086464, 45.83742298185825, 40.45607574284077, 27.090931311249733, 37.834562212228775, 40.983027666807175, 30.735954120755196, 41.06826089322567, 13.950180988758802, 0.6367330206558108, 0.0643509571091272, 0.048901279296842404, 0.25529316044412553, 1.260298560373485, 2.5299664679914713, 5.88414765894413, 4.737553959712386, 3.271936741657555, 2.482788199558854, 2.544921515509486, 14.433765839785337, 32.288345620036125, 51.904986798763275, 65.74350222945213, 62.76055969297886, 61.73552289605141, 58.20902332663536, 59.76855844259262, 60.325536355376244, 59.21365901827812, 61.83752082288265, 61.96163736283779, 56.54218576848507, 54.91582743823528, 58.523308262228966, 62.74494633078575, 56.29648715257645, 47.807959243655205, 50.03695383667946, 58.22350434958935, 57.10206292569637, 58.96553993225098, 57.68703393638134, 51.7032366245985, 49.286167323589325, 53.188341334462166, 55.441289842128754, 59.94736544787884, 57.86338247358799, 59.136808142066, 56.77733235061169, 59.60949897766113, 54.92463916540146, 55.518167316913605, 57.3040296882391, 63.217184990644455, 48.607998713850975, 51.468234434723854, 55.929749831557274, 69.91385444998741, 41.09316095709801, 43.553981110453606, 67.69833773374557, 56.27884849905968, 56.82435862720013, 52.54777170717716, 56.923666298389435, 53.982377126812935, 57.287880554795265, 49.75857697427273, 51.25867947936058, 55.35981461405754, 60.01508541405201, 62.43026241660118, 55.453604981303215, 52.68971689045429, 61.614354997873306, 63.21565367281437, 56.905457675457, 45.756156742572784, 45.26034414768219, 46.36771872639656, 55.9903983771801, 59.784357994794846, 63.95498380064964, 58.51868011057377, 55.75250454246998, 57.04453021287918, 63.93223822116852, 62.50036485493183, 65.77058717608452, 58.05182956159115, 60.85892133414745, 63.195773139595985, 62.4913327395916, 61.97115585207939, 69.73240658640862, 64.65136483311653, 44.38147030770779, 18.674685023725033, 2.836541379801929, 5.137959849089384, 6.70766131952405, 7.288919929414988, 3.83925698697567, 0.9087467682547867, 0.31435083830729127, 0.17218814638908952, 0.08919071406126022, 0.20005101221613586, 4.360895371064544, 31.417464651167393, 40.18972523510456, 63.52960042655468, 48.9177580922842, 25.78804202377796, 19.82790794223547, 37.46038869023323, 47.519885301589966, 59.09675069153309, 59.46301683783531, 70.47832936048508, 24.329970963299274, 0.533746553119272, 0.054379186331061646, 0.03899677307344973, 0.03451675409451127, 0.02151670167222619, 0.02827327720297035, 0.010230145780951716, 0.02358342710067518, 0.0729001643776428, 0.0794834150292445, 0.021241635768092237, 0.011801007094618399, 0.02297555620316416, 0.013084521815471817, 0.06306609910097905, 0.04127532600250561, 0.007198434950623778, 0.01329191034528776, 0.007280216841536458, 0.00478726997243939, 0.06405694046407007, 0.019891479896614328, 0.0395929699880071, 0.08226483609178104, 0.03546178268152289, 0.05637363399728201, 0.13871315983124077, 0.0725406754645519, 0.15484921663301066, 0.15639424935216084, 0.1395156589569524, 0.18276186572620645, 0.13507963449228555, 0.2220459093223326, 0.154258526454214, 0.156407845497597, 0.11192067875526845, 0.10536352943745442, 0.13035558251431212, 0.07017853815341368, 0.16962074587354437, 0.17390090448316187, 0.12057933796313591, 0.1452139875618741, 0.10424961772514507, 0.2146569237811491, 0.11715460103005171, 0.14771165588172153, 0.08563797891838476, 1.769022981170565, 47.37004794180393, 90.79489678144455, 76.8154089152813, 67.41441696882248, 51.24568797647953, 46.41235113143921, 29.150399900972843, 53.13616253435612, 54.79366019368172, 41.610552594065666, 60.05588382482529, 20.646129436790943, 1.1996320844627917, 0.20259996294043958, 0.2696011442458257, 0.3007101046387106, 0.9981350717134774, 4.839729527011514, 13.662811908870935, 7.7657002955675125, 8.153831418603659, 8.070761226117611, 8.223132099956274, 19.303163699805737, 40.4150303453207, 57.62475907802582, 70.15427514910698, 65.29514148831367, 63.94978567957878, 60.425892770290375, 61.14385664463043, 63.552475199103355, 63.11683617532253, 63.34374859929085, 63.71172845363617, 56.539335921406746, 55.46451419591904, 59.914246425032616, 66.19861140847206, 58.63363914191723, 49.38915319740772, 53.033917620778084, 60.287925973534584, 59.28709767758846, 62.765366435050964, 61.48181810975075, 53.5548734664917, 50.34115791320801, 55.47756649553776, 59.377688616514206, 62.30828516185284, 59.83524486422539, 60.15847451984882, 57.64939695596695, 59.84824776649475, 56.35160319507122, 61.01166933774948, 58.51379357278347, 67.52910241484642, 49.92014430463314, 54.4628119468689, 59.84593369066715, 72.8636285662651, 44.89369422197342, 47.08306834101677, 69.75903555750847, 59.013842940330505, 58.252606987953186, 56.31268948316574, 60.28265565633774, 57.093566581606865, 59.36685919761658, 51.64618268609047, 53.10480661690235, 56.63831681013107, 63.09760540723801, 64.35690343379974, 56.151779517531395, 53.09233948588371, 63.180706948041916, 67.15664640069008, 59.50638011097908, 47.55808465182781, 47.91757196187973, 49.478604197502136, 59.4240765273571, 63.14549423754215, 65.92402294278145, 60.408664494752884, 55.841374173760414, 57.0480640232563, 66.41847521066666, 65.31451284885406, 69.44515720009804, 61.956777423620224, 64.16347101330757, 66.21582448482513, 63.61892603337765, 64.97532024979591, 72.15413823723793, 66.79013326764107, 44.69594523310661, 21.836985535919666, 6.195507226511836, 13.387969806790352, 16.080435030162334, 11.990961469709873, 3.7400899082422256, 0.5210610525682569, 0.3695814684033394, 0.22525054751895368, 0.2117233327589929, 0.34713114495389163, 6.236616270616651, 45.14840595424175, 47.5301181524992, 71.1175386607647, 67.09795475006104, 41.44143506884575, 21.60439621657133, 35.34110181033611, 53.30728255212307, 72.1451023221016, 67.54973530769348, 80.1340900361538, 31.798521503806114, 0.6255368620622903, 0.25845904368907213, 0.11294875366729684, 0.11593688512220979, 0.24346200545551255, 0.26554129959549755, 0.12690582778304815, 0.11674419336486608, 0.12936646293383092, 0.21648618421750143, 0.3339453774970025, 0.08938587663578801, 0.08666491092299111, 0.10964467510348186, 0.1152656867634505, 0.16271317668724805, 0.14255022659199312, 0.10178886383073404, 0.12401508836774155, 0.14233530062483624, 0.11174366911291145, 0.11711799830663949, 0.14045888412510976, 0.15669061860535294, 0.15495368133997545, 0.166089236154221], [0.024627033308206592, 0.11121500763692893, 0.0434529097401537, 0.042327075425419025, 0.03883747849613428, 0.03322890894196462, 0.020839530880039092, 0.11740468253265135, 0.0326960431993939, 0.03689200144435745, 0.016249683321802877, 0.010972570835292572, 0.043438823777250946, 0.023234821783262305, 0.02630622035212582, 0.010996034761774354, 0.04539839050266892, 0.04140217017265968, 0.03221053761080839, 0.12671067262999713, 0.009801540654734708, 0.01652952494623605, 0.028289086803852115, 3.1008715834468603, 43.04079584777355, 64.74607855081558, 60.93620918691158, 40.08105866611004, 21.19732405990362, 37.11044266819954, 33.58606718480587, 28.764631301164627, 27.17192966490984, 46.78747460246086, 22.808399610221386, 0.49161791685037315, 0.09133270068559796, 0.06841949230874889, 0.03314365843834821, 0.18528994725784287, 0.7198382425121963, 3.662531557492912, 3.8727757008746266, 3.6076993122696877, 3.8961667707189918, 6.834138007834554, 19.447571150958538, 41.32635824382305, 58.54780934751034, 64.97109487652779, 62.215448543429375, 58.870936408638954, 55.695519000291824, 53.56464274227619, 56.445427760481834, 56.10231377184391, 56.4361372590065, 60.40780574083328, 60.67626893520355, 57.743479907512665, 56.64490185678005, 57.011965960264206, 61.32457494735718, 56.07935540378094, 50.12709639966488, 44.79508951306343, 46.878768503665924, 49.123908430337906, 47.93516881763935, 48.01742680370808, 46.958492025732994, 44.58952434360981, 50.69330021739006, 54.788154289126396, 59.13197100162506, 56.82764545083046, 60.07215075194836, 54.04272548854351, 55.464126616716385, 51.29876732826233, 53.65223564207554, 57.82319203019142, 54.33122880756855, 43.192358314991, 51.42245449125767, 51.94890484213829, 64.69725117087364, 35.246167704463005, 40.11350132524967, 65.73660179972649, 54.268634766340256, 51.49458982050419, 47.904740050435066, 56.054348945617676, 52.63100244104862, 54.49143201112747, 44.88819971680641, 43.72095935046673, 48.65228533744812, 59.30881351232529, 57.499840781092644, 58.92772056162357, 50.146927535533905, 59.23402972519398, 54.54195410013199, 54.12714175879955, 43.40212605893612, 41.75943620502949, 43.95579054951668, 53.26716810464859, 58.12738090753555, 58.520416617393494, 51.577885150909424, 52.11660884320736, 52.12707348167896, 60.05444750189781, 58.86228047311306, 56.72834537923336, 55.53117781877518, 52.27927051484585, 53.762441128492355, 58.38482849299908, 61.39423280954361, 60.86129240691662, 62.543792724609375, 62.02716484665871, 43.612627163529396, 16.729791685938835, 3.1177699891850352, 3.489287691190839, 7.869573421776295, 2.764162151142955, 0.23067303467541933, 0.16947535914368927, 0.03847073880024254, 0.015655239731131587, 0.08237591333454475, 0.03723360459844116, 10.654244497418404, 34.77753505110741, 48.36244449019432, 68.84952396154404, 52.9738200455904, 37.13734522461891, 16.59863982349634, 27.286362424492836, 37.60145992040634, 41.49741746485233, 48.88853006064892, 45.43117918074131, 4.051798582077026, 0.16262901714071631, 0.08726100393687375, 0.05670282473147381, 0.01822329704737058, 0.05740606160543393, 0.03429221731494181, 0.08848807832691818, 0.0516484057152411, 0.08533095242455602, 0.05627041980915237, 0.025657826336100698, 0.039709743214189075, 0.013599638168670936, 0.04328613431425765, 0.02995952578203287, 0.07777082020766102, 0.012864554810221307, 0.06296268082223833, 0.08615223530796356, 0.03625142409873661, 0.02990226166730281, 0.06302876907284372, 0.05604872545518447, 0.10832258354639634, 0.007616983975822222, 0.022078813599364366, 0.07424860959872603, 0.04218583359033801, 0.06304695169092156, 0.01217863502461114, 0.04200359922833741, 0.02730685064307181, 0.02657243614521576, 0.006808523548897938, 0.04982751670468133, 0.010073457997350488, 0.022520179954881314, 0.06260691749048419, 0.03317492883070372, 0.05861199591890909, 0.036188901867717505, 0.030513457386405207, 0.013531135155062657, 0.049356468152836896, 0.0828116579214111, 0.013384663961915066, 0.02509723952243803, 0.11954968227655627, 4.87032026052475, 52.95106686651707, 75.29620483517647, 68.05983513593674, 51.640270203351974, 32.93309882283211, 43.364185094833374, 26.042084991931915, 33.26170898973942, 28.694133684039116, 41.5913712233305, 22.293004766106606, 0.3900256776250899, 0.06547031618538313, 0.09301254453021102, 0.13147303427103907, 0.93979413039051, 1.8646726361475885, 1.4675760129466653, 3.1058671278879046, 5.335113694891334, 2.155654728412628, 6.598601471632719, 18.12172159552574, 42.46359542012215, 59.373554438352585, 67.82590448856354, 63.67787607014179, 60.08157044649124, 56.6146706789732, 56.13863602280617, 59.14268642663956, 58.557084649801254, 58.86922650039196, 61.99099458754063, 60.97924567759037, 57.8685387969017, 55.33657506108284, 56.66227072477341, 62.648264318704605, 58.377863466739655, 52.20554307103157, 46.71081751585007, 48.83382819592953, 51.50307096540928, 50.86489140987396, 50.89349627494812, 48.61670024693012, 48.67102973163128, 53.63194093108177, 57.221482917666435, 61.10834375023842, 58.5580687969923, 60.757546573877335, 56.468469724059105, 56.72856576740742, 52.08014219999313, 57.108803763985634, 59.33769956231117, 58.14504615962505, 44.298725947737694, 53.76789763569832, 54.307590276002884, 68.59543159604073, 38.353925943374634, 42.62140095233917, 67.72662341594696, 55.217512249946594, 55.07103390991688, 51.96728065609932, 58.066705763339996, 55.013782382011414, 57.43569262325764, 48.53060446679592, 45.57752072811127, 51.904428228735924, 61.19189366698265, 61.278798803687096, 59.1651052236557, 51.24805524945259, 59.97011102735996, 58.79847049713135, 57.15073451399803, 45.78358747065067, 44.59550142288208, 45.87593011558056, 55.999810472130775, 60.8304038643837, 59.91324707865715, 53.05977143347263, 50.48459641635418, 54.130960553884506, 61.15246318280697, 61.92599147558212, 58.44528324902058, 57.456504106521606, 55.58344781398773, 56.67639076709747, 59.420770704746246, 65.32291039824486, 63.80657136440277, 65.34345209598541, 65.7373009622097, 47.62499526143074, 17.672222815454006, 4.408951867371798, 4.175790203735232, 5.26560639962554, 6.858757836744189, 3.8584903674200177, 1.0356555646285415, 0.2891927445307374, 0.07738491825875826, 0.09670060288044624, 0.07361153519013897, 10.991006176918745, 34.3285321444273, 53.99954840540886, 78.99732023477554, 39.32948559522629, 23.600881285965443, 22.59682696312666, 38.447131142020226, 47.268167808651924, 48.289097025990486, 55.63043609261513, 56.5824294090271, 5.625942489132285, 0.15966820414178073, 0.032819117259350605, 0.03704568538523745, 0.02660196063516196, 0.06743430611095391, 0.01820701247197576, 0.02427817937132204, 0.032820401174831204, 0.0709230755455792, 0.011188764019607333, 0.05092839630378876, 0.04886541129963007, 0.06942005580640398, 0.07317518946365453, 0.03522223967593163, 0.03963666393246967, 0.038885899921297096, 0.0037774994370920467, 0.0451522646471858, 0.0178254929051036, 0.0732307466387283, 0.02183175820391625, 0.04238642126438208, 0.015663473859603982, 0.03297184382972773, 0.2002178766997531, 0.16025306103983894, 0.18677390122320503, 0.1188877756067086, 0.059542504386627115, 0.1462739970884286, 0.14966408314649016, 0.19710514607140794, 0.12855807115556672, 0.1845321847940795, 0.13502853020327166, 0.10470049470313825, 0.13323250313987955, 0.10436803480843082, 0.2017628648900427, 0.16089899669168517, 0.23416007490595803, 0.17017423961078748, 0.21034399193013087, 0.27179923723451793, 0.17193339677760378, 0.10552532505244017, 0.18779821344651282, 8.206359799951315, 67.01314330101013, 84.20262292027473, 78.37845504283905, 57.14836344122887, 34.42554473876953, 51.40234217047691, 42.60973557829857, 41.65836542844772, 35.594388619065285, 61.04302905499935, 32.67935983836651, 0.7333653979003429, 0.16048964287620038, 0.22606771148275584, 0.16232593887252733, 1.1776404082775116, 2.3819565726444125, 8.169839959591627, 10.457518603652716, 12.332069166004658, 11.22434500604868, 9.672955702990294, 23.081293366849422, 46.589794009923935, 64.12444710731506, 69.7003211081028, 66.34361162781715, 63.472519889473915, 61.474115923047066, 59.79454904794693, 60.16931913793087, 61.068784072995186, 61.322059482336044, 64.08533200621605, 62.70340695977211, 59.04105328023434, 56.49678960442543, 56.413828656077385, 66.84536710381508, 61.76656723022461, 54.11258853971958, 49.438702538609505, 51.84672832489014, 54.22221265733242, 52.32726573944092, 52.00990676879883, 50.563271194696426, 50.13324446976185, 56.36940523982048, 59.82166439294815, 62.89920665323734, 60.72961427271366, 62.678218111395836, 56.65090933442116, 56.88528075814247, 55.8579982817173, 58.40887740254402, 62.27580450475216, 61.607914343476295, 45.924282521009445, 57.05277197062969, 56.32728450000286, 69.52138870954514, 40.82776799798012, 45.979216173291206, 69.60897400975227, 59.319027364254, 57.44505152106285, 53.82749363780022, 61.80418521165848, 57.907809689641, 60.79786621034145, 50.80127142369747, 48.0285108089447, 53.667529821395874, 64.34463769197464, 61.226935386657715, 59.52152989804745, 50.76484277844429, 61.254856288433075, 60.67569136619568, 59.51554901897907, 47.778742611408234, 46.641767621040344, 48.26401077210903, 58.98550786077976, 65.41191682219505, 63.10951016843319, 53.26722890138626, 52.54816688597202, 54.33959595859051, 63.55657897889614, 64.4198128581047, 60.48725567758083, 61.84032127261162, 59.665530771017075, 58.986017033457756, 64.65979278087616, 69.25551697611809, 67.74905741214752, 66.7553423345089, 68.64438816905022, 50.120283365249634, 19.878152646124363, 8.472479470074177, 12.170467637479305, 18.963473327457905, 11.690123062580824, 3.157744794152677, 0.5482319695875049, 0.18336402950808406, 0.13794852507999167, 0.32877456746064126, 0.09047568339155987, 15.871701780706644, 50.04626713693142, 60.18187366425991, 77.03874573111534, 70.04053965210915, 53.11247460544109, 25.941272601485252, 39.42335195839405, 52.43534334003925, 59.79877442121506, 65.24069041013718, 67.54577592015266, 7.146127866581082, 0.38607089139986783, 0.22315674112178385, 0.11473082093289122, 0.07268098590429872, 0.187456899730023, 0.17352196387946606, 0.18400598724838346, 0.14778036391362548, 0.196936619176995, 0.11761899251723662, 0.11882382474141195, 0.15590535214869305, 0.09829089176491834, 0.14713056909386069, 0.16430428193416446, 0.1650375238386914, 0.10353534511523321, 0.16657373984344304, 0.11474606464616954, 0.08181482000509277, 0.105137434147764, 0.16372821206459776, 0.15003689361037686, 0.2278633526293561, 0.11228784889681265], [0.05410736732301302, 0.016560787917114794, 0.03547520813299343, 0.05966679556877352, 0.024395548171014525, 0.034081287813023664, 0.017954194299818482, 0.004544268558674958, 0.07747060662950389, 0.020934689055138733, 0.027858474168169778, 0.031224000704241917, 0.10311039877706207, 0.030601795224356465, 0.017284610112255905, 0.06823747316957451, 0.12008324192720465, 0.06944736684090458, 0.029119898863427807, 0.04677058073866647, 0.06807780751842074, 0.09054484413354658, 0.27262305084150285, 33.714648485183716, 74.61751565337181, 66.69242531061172, 51.988122537732124, 36.24712519347668, 23.298607505857944, 38.16463530063629, 53.160059452056885, 28.742772974073887, 43.88880014419556, 33.269449174404144, 2.0081722922623158, 0.12184363105916418, 0.11539136947249062, 0.06335865371511318, 0.12141007580794394, 0.890494150808081, 2.1768286172300577, 1.0097930836491287, 1.9155352818779647, 3.363150372169912, 9.507302641868591, 30.75293730944395, 42.08458475768566, 59.822310358285904, 60.189294666051865, 60.510461032390594, 58.50520983338356, 57.62944042682648, 56.72635428607464, 57.41344481706619, 57.1435908973217, 54.264739975333214, 57.521803602576256, 59.56566073000431, 61.61104917526245, 55.37213735282421, 54.094763696193695, 55.40744885802269, 57.63269305229187, 56.45585440099239, 51.904454827308655, 51.327980160713196, 50.2986153960228, 49.601956978440285, 48.15554179251194, 44.002737030386925, 46.24865211546421, 46.83399170637131, 51.769113689661026, 54.00245904922485, 57.825604900717735, 58.50452207028866, 58.79882387816906, 53.382921293377876, 56.43332161009312, 49.48117285966873, 58.45986306667328, 54.8384939879179, 50.59689939022064, 40.70996671915054, 53.59600245952606, 52.68817037343979, 65.62592133879662, 34.52563136816025, 43.2038526982069, 64.60338860750198, 53.21076013147831, 50.451587587594986, 47.323899418115616, 55.32012194395065, 54.242222383618355, 55.062594562768936, 48.98342616856098, 43.94145391881466, 44.84236657619476, 59.38195578753948, 59.026978835463524, 56.792542934417725, 50.958723574876785, 56.1059045791626, 57.78566524386406, 56.71922206878662, 46.906450018286705, 41.026478335261345, 46.56133733689785, 55.61690501868725, 58.530022501945496, 61.49854861199856, 54.35392498970032, 53.62005516886711, 53.66929292678833, 57.929837107658386, 57.30173081159592, 59.789434522390366, 57.53202125430107, 52.31602594256401, 49.75748263299465, 53.08682218194008, 56.01172663271427, 60.9399101883173, 60.84741935133934, 62.455158680677414, 60.06689563393593, 43.891121819615364, 13.749433010816574, 2.744895522482693, 6.155634541064501, 5.902345832437277, 4.042452983558178, 0.8279499819036573, 0.30872975243255496, 0.04096978751476854, 0.08863662660587579, 0.09296234566136263, 0.30390255677048117, 21.88038870692253, 24.509157948195934, 23.373767472803593, 54.884042143821716, 79.69202175736427, 39.95298273861408, 21.311739720404148, 31.376407854259014, 44.988240748643875, 53.63407641649246, 64.07366663217545, 21.127301417291164, 0.14659323933301494, 0.19266716233687475, 0.07600591139635071, 0.040077358644339256, 0.043688040677807294, 0.05935804729233496, 0.0741579859459307, 0.03684063740365673, 0.04977616379619576, 0.098713819461409, 0.026257010395056568, 0.05802776613563765, 0.020052891450177412, 0.04090314636414405, 0.028417604517017026, 0.03796859055000823, 0.055481476010754704, 0.03607074453611858, 0.03535902491421439, 0.025401319689990487, 0.01429456391633721, 0.018719766012509353, 0.07134332408895716, 0.049997468522633426, 0.050160536920884624, 0.011756392887036782, 0.0174723122472642, 0.04137358264415525, 0.011110710493085207, 0.0316100733471103, 0.02701586938201217, 0.05115145249874331, 0.014109402709436836, 0.019607179820013698, 0.014904698364262003, 0.041884996608132496, 0.07857751988922246, 0.09170491743134335, 0.062253569849417545, 0.02578198393166531, 0.018311681269551627, 0.06625406123930588, 0.01092360207621823, 0.029511012544389814, 0.01796089218260022, 0.03383657203812618, 0.016364736620744225, 0.2273934247205034, 41.379175409674644, 85.10909467935562, 73.59770357608795, 61.927982568740845, 44.30110462009907, 26.098859645426273, 45.78119359910488, 45.486150830984116, 24.514739848673344, 38.16327877342701, 30.398821011185646, 2.919884445145726, 0.07370357634499669, 0.1505359137081541, 0.2807582064997405, 0.5802228685934097, 1.7965365923009813, 5.018758345395327, 2.469675103202462, 2.829830702394247, 4.13196288049221, 10.21170599386096, 29.049950391054153, 45.44178061187267, 61.134315356612206, 64.28609043359756, 62.18060061335564, 60.96120424568653, 59.524117559194565, 59.03955236077309, 59.39618982374668, 59.384684041142464, 56.99752293527126, 59.066416919231415, 61.077109426259995, 61.84782586991787, 55.59430383145809, 54.8639640212059, 55.36300644278526, 59.980119690299034, 58.593752682209015, 54.012406915426254, 53.218868896365166, 51.815737187862396, 51.61513455212116, 50.846576392650604, 46.46965965628624, 48.49272049963474, 49.05863173305988, 55.4005142301321, 56.58255860209465, 59.253442883491516, 58.840161859989166, 60.150456950068474, 54.110532850027084, 58.071052730083466, 53.92490901052952, 60.727421790361404, 56.84067875146866, 53.791999742388725, 41.78006149828434, 55.46437360346317, 56.033339872956276, 68.75895202159882, 36.89256615936756, 45.49129195511341, 66.366456001997, 55.74452117085457, 52.95295536518097, 49.08409796655178, 59.126039519906044, 56.160758435726166, 58.10178928077221, 50.7817442715168, 45.39449594914913, 46.120595186948776, 59.949018359184265, 61.18249677121639, 57.51350864768028, 51.90043464303017, 55.86302161216736, 60.11545702815056, 59.80830430984497, 47.580245062708855, 43.60321506857872, 49.103602319955826, 57.352982461452484, 59.39278520643711, 62.330966144800186, 54.54217828810215, 55.49178533256054, 53.17797169089317, 59.508450999855995, 61.02939918637276, 62.877684608101845, 59.610315933823586, 53.305914625525475, 52.73678116500378, 56.21990606188774, 58.88988219201565, 62.36792676150799, 65.11305525898933, 64.73081856966019, 64.49144661426544, 47.97556445002556, 15.941687375307083, 3.7027699733152986, 3.2240574108436704, 4.912794856354594, 6.4387003518640995, 4.814558252692223, 0.7277083920780569, 0.26418014138471335, 0.014084140930208378, 0.061593073260155506, 0.5127371242269874, 22.342381216585636, 29.681180119514465, 23.499702215194702, 46.93983502686024, 63.801069259643555, 31.993580237030983, 26.57289180904627, 40.03995627164841, 53.15123252570629, 60.268881395459175, 71.98573127388954, 25.860025361180305, 0.2949629130307585, 0.1534456669469364, 0.07456108345650136, 0.03621475087129511, 0.03198682461516, 0.059697116012102924, 0.08384083863347769, 0.05688978286343627, 0.11035148170776665, 0.025396119090146385, 0.045797168713761494, 0.06166312829009257, 0.017684046979411505, 0.05413346865680069, 0.017325231565337162, 0.06750138883944601, 0.028508953619166277, 0.03913728018233087, 0.10623781650792807, 0.009658700419095112, 0.007189830675997655, 0.04469429644814227, 0.00930297233935562, 0.025940458435798064, 0.03315868692880031, 0.13511545053916052, 0.10238198083243333, 0.11593030227231793, 0.10700265906052664, 0.08034035068703815, 0.18308342347154394, 0.06483078526798636, 0.1516281918156892, 0.10262838870403357, 0.12899763038149104, 0.07660824587219395, 0.16174029529793188, 0.1495310160680674, 0.22698237880831584, 0.09392138599650934, 0.17041307757608593, 0.20497358869761229, 0.18456396355759352, 0.07568654298665933, 0.16585355973802507, 0.1291121734539047, 0.12191094385343604, 0.50049590296112, 49.797840267419815, 96.6786378622055, 80.99027529358864, 70.60658767819405, 51.166097447276115, 32.693438082933426, 48.02262872457504, 68.0435948073864, 40.74644096195698, 57.75196485221386, 45.04046514630318, 3.7424175208434463, 0.35908928140997887, 0.3267013927688822, 0.2398789461585693, 0.5213915754575282, 2.5667767552658916, 9.522216841578484, 5.923331156373024, 6.38423977419734, 8.51264901459217, 13.921667318791151, 34.763616397976875, 47.69739277660847, 64.50254201889038, 65.85361272096634, 65.69161221385002, 63.830532878637314, 61.871498599648476, 61.312370002269745, 61.737665981054306, 62.063445299863815, 59.247541800141335, 60.20461544394493, 64.51388821005821, 65.244140625, 55.36822356283665, 54.333960860967636, 55.43806381523609, 61.39301307499409, 60.95726765692234, 55.76283618807793, 56.73045426607132, 55.015781074762344, 53.99729132652283, 54.47487249970436, 48.70043255388737, 49.7177367657423, 52.27300465106964, 57.53437712788582, 59.06026504933834, 61.859920620918274, 60.79928733408451, 60.757212191820145, 54.713651686906815, 60.69700062274933, 58.41675437986851, 63.64811606705189, 60.558019280433655, 56.07693873345852, 44.645738527178764, 57.988969534635544, 57.80485801398754, 70.26494041085243, 41.336385905742645, 48.737054988741875, 68.84681850671768, 58.698782846331596, 55.489079877734184, 51.09872326254845, 60.4564393311739, 59.42376494407654, 59.67412211000919, 54.138693138957024, 48.354894295334816, 48.64248566329479, 63.46523568034172, 64.14897099137306, 58.54471631348133, 50.86658991873264, 56.32289573550224, 63.18691201508045, 62.37911716103554, 51.28935903310776, 45.588999912142754, 53.89856122434139, 61.06436111032963, 62.084727957844734, 63.275694251060486, 55.92932045459747, 55.218473598361015, 55.29022514820099, 62.24631808698177, 64.11643713712692, 66.39763712882996, 63.33220861852169, 57.12637782096863, 56.369424238801, 59.23595242202282, 61.56597599387169, 65.21770164370537, 68.59540119767189, 67.47748598456383, 66.11899048089981, 50.04674211144447, 19.47842549532652, 11.177719607949257, 17.36670020967722, 16.15047287195921, 15.729978885501623, 4.624425005167723, 0.6126962229609489, 0.20459981344174594, 0.19633748335763812, 0.28170877892989665, 0.7702744798734784, 31.328422129154205, 38.57022933661938, 33.340512961149216, 66.36574923992157, 92.48949944972992, 53.97494472563267, 34.34595800936222, 45.13768672943115, 60.81143908202648, 69.4169095158577, 80.31268805265427, 31.369551122188568, 0.4521320090861991, 0.3376273502362892, 0.12903518305392936, 0.1156709216593299, 0.15993497654562816, 0.1431509357644245, 0.2625347999855876, 0.17736986599629745, 0.1972278972971253, 0.2629439905285835, 0.0985935544304084, 0.20328054204583168, 0.16769729205407202, 0.13562361389631405, 0.10285105527145788, 0.1803626210312359, 0.231217993714381, 0.11458556036814116, 0.23573183978442103, 0.07453442551195621, 0.16016397363273427, 0.12090269912732765, 0.1403926993953064, 0.17136790993390605, 0.1797309791436419], [0.04986587089661043, 0.03045843270228943, 0.048531199936405756, 0.016931811660469975, 0.04420647535880562, 0.059008607058785856, 0.03248153654567432, 0.01137137316618464, 0.07188803821918555, 0.03503050953440834, 0.06343993372865953, 0.04038112339912914, 0.04345030109107029, 0.049482262184028514, 0.07683736912440509, 0.04397829463414382, 0.08322197652887553, 0.06049447947589215, 0.08153848873917013, 0.026251104754919652, 0.05242390921921469, 0.046210459622670896, 3.528938088566065, 54.17896717786789, 67.27702394127846, 59.02825176715851, 44.049455523490906, 32.26425491273403, 29.34058539569378, 29.694559201598167, 61.4086302369833, 50.47493353486061, 45.95630720257759, 8.031531181186438, 0.19774982007220387, 0.02569038621004438, 0.03054595974390395, 0.061860446803621016, 0.2569593413500115, 1.2540933745913208, 1.0690143308602273, 0.24765174079220742, 1.7846125946380198, 16.099405512213707, 32.717851772904396, 49.749845042824745, 55.62461860477924, 61.55240312218666, 61.304713413119316, 58.55834998190403, 59.58415433764458, 59.20769713819027, 60.67804343998432, 61.24359369277954, 61.020830646157265, 60.68737953901291, 56.53588570654392, 60.03154993057251, 60.19187472760677, 55.28741329908371, 55.33051438629627, 55.038291066884995, 55.79943962395191, 57.55203478038311, 55.35378433763981, 56.138746216893196, 57.32039920985699, 55.79940922558308, 57.403952926397324, 51.82934045791626, 47.35553652048111, 46.357330083847046, 49.4808042794466, 52.61356137692928, 57.33244076371193, 59.62581530213356, 57.52078525722027, 54.46464344859123, 53.77519704401493, 52.900814563035965, 58.34568679332733, 47.11611516773701, 45.461968928575516, 42.31339707970619, 54.46911200881004, 51.71679049730301, 65.62725886702538, 33.429952561855316, 43.835865184664726, 62.977414056658745, 54.20033723115921, 49.21194210648537, 45.488183721899986, 53.32932896912098, 56.2883859872818, 53.44544693827629, 47.42420643568039, 41.9426965713501, 43.3227901160717, 55.21790362894535, 58.65838721394539, 57.17226795852184, 50.97306400537491, 52.591997534036636, 56.72802999615669, 55.34213416278362, 46.697696819901466, 40.65861627459526, 46.93125128746033, 56.31077818572521, 56.43093153834343, 55.860677137970924, 54.64450679719448, 51.37325093150139, 54.25449952483177, 55.51957704126835, 56.1220309138298, 56.2784381210804, 56.41937255859375, 53.654941096901894, 46.14392593502998, 50.40016494691372, 53.51151779294014, 55.81467680633068, 57.67140917479992, 61.52901157736778, 62.756003737449646, 59.62597109377384, 46.16422064602375, 9.921283777803183, 0.5705300043337047, 6.109780026599765, 6.721638394519687, 3.3144505228847265, 0.500823991606012, 0.0781434154487215, 0.08959602317190729, 0.09804354136576876, 0.14603860268834978, 3.5006989538669586, 39.38048265874386, 59.86997880041599, 79.62126195430756, 81.05690091848373, 70.34782156348228, 28.280071802437305, 24.409924373030663, 37.762187495827675, 49.23925504088402, 56.153272837400436, 34.15135145187378, 1.7666066670790315, 0.047518773208139464, 0.028574834068422206, 0.04690527683123946, 0.03060908868064871, 0.06791550724301487, 0.041852657523122616, 0.06783369288314134, 0.034002942993538454, 0.023552685488539282, 0.013484590435837163, 0.040257207001559436, 0.01879402345366543, 0.06831789971329272, 0.037954422950861044, 0.021623201719194185, 0.04823850431421306, 0.029751106594630983, 0.03457719460129738, 0.05994389495754149, 0.08255803637439385, 0.05418777531303931, 0.04939861471939366, 0.07343840698013082, 0.030024864463484846, 0.04008174844784662, 0.011445893142081331, 0.035824399747070856, 0.030342995341925416, 0.038225377356866375, 0.04271592741133645, 0.002691185413823405, 0.02603596542030573, 0.060328984254738316, 0.042161008750554174, 0.02418110831058584, 0.01688570944679668, 0.03505696338834241, 0.017844935318862554, 0.03104498169705039, 0.09593377137207426, 0.01948495366377756, 0.06015460181515664, 0.07688454003073275, 0.06895353435538709, 0.042808825746760704, 0.03700195062265266, 3.927159095183015, 64.67655748128891, 75.56775346398354, 67.29495137929916, 51.108127757906914, 40.8615367859602, 32.51688435673714, 37.879547998309135, 58.916712552309036, 38.43631312251091, 45.0277092307806, 8.898784294724464, 0.1973558435565792, 0.050991185707971454, 0.06143802747828886, 0.6218551564961672, 2.1814912045374513, 4.180024601519108, 6.601512590423226, 2.2027667379006743, 2.1905378066003323, 13.766720183193684, 34.758403077721596, 51.98225185275078, 60.73060221970081, 65.27539774775505, 65.1109729707241, 60.39193779230118, 61.57366678118706, 60.956731885671616, 62.31021165847778, 62.23173446953297, 63.48686031997204, 62.41221718490124, 59.463936388492584, 60.267277881503105, 61.55496038496494, 56.812187880277634, 55.525816306471825, 54.54449996352196, 58.335400745272636, 61.04491375386715, 56.49889849126339, 56.85986392199993, 60.20329311490059, 58.89967426657677, 59.47848200798035, 52.654165998101234, 48.39785858988762, 49.37866196036339, 51.14539235830307, 54.27447125315666, 59.14500430226326, 61.52074322104454, 58.676006868481636, 54.93777506053448, 54.63468812406063, 56.25937834382057, 58.54574605822563, 51.128384470939636, 46.658729910850525, 45.07937125861645, 57.884585335850716, 54.702959060668945, 66.12269148230553, 34.79343719780445, 45.889673978090286, 65.80651044845581, 56.09572872519493, 51.154409274458885, 48.597252890467644, 55.60649737715721, 56.636492908000946, 55.6839220225811, 49.29831147193909, 44.494077265262604, 45.36757439374924, 58.800928965210915, 60.03073297441006, 57.68663115799427, 50.794173404574394, 53.15068915486336, 58.33498656749725, 57.49693013727665, 49.315091371536255, 42.948289811611176, 49.1726940125227, 59.22693930566311, 58.84058363735676, 59.10056568682194, 53.28324884176254, 52.03448764979839, 54.741204008460045, 57.36120142042637, 59.144905507564545, 59.47161577641964, 59.03500780463219, 56.34651906788349, 48.1601357460022, 52.992731630802155, 55.903158858418465, 57.740033492445946, 60.3065487742424, 63.25540333986282, 63.88708144426346, 63.532708659768105, 48.49925234913826, 12.537084314972162, 2.2126502450555563, 4.3873058538883924, 7.278565485030413, 4.1941493935883045, 2.8386535914614797, 0.5847139901015908, 0.24696549167856574, 0.07569704437628388, 0.16556866408791393, 3.976190951652825, 37.318610697984695, 49.783484637737274, 79.66188177466393, 77.09728538990021, 69.71846133470535, 37.13429018855095, 31.70235436409712, 42.32521064579487, 54.502067640423775, 63.56136292219162, 42.02944591641426, 2.2306505916640162, 0.04068849499162752, 0.06169384949316736, 0.0830038741696626, 0.06922032902366482, 0.04276238214515615, 0.028786431503249332, 0.033316397020826116, 0.015692901870352216, 0.03021290984179359, 0.036194571875967085, 0.05966177865047939, 0.06190165826410521, 0.024296946430695243, 0.06383379150065593, 0.05648543483403046, 0.04502697898715269, 0.05818425168399699, 0.01802567425329471, 0.0673766115505714, 0.08524248842149973, 0.024982052636914887, 0.038718549330951646, 0.0259174110396998, 0.051016296274610795, 0.1467085542390123, 0.11930079563171603, 0.14730853610672057, 0.11515765232616104, 0.12299872454605065, 0.28214661637321115, 0.11743723312974907, 0.10279341266141273, 0.20492499286774546, 0.11823884909972548, 0.2223999731359072, 0.10370206116931513, 0.21912831900408491, 0.14493433147436008, 0.13333932787645608, 0.12896874599391595, 0.1439482843852602, 0.12219972093589604, 0.18239757511764765, 0.13879202044336125, 0.21921874227700755, 0.13558745646150783, 5.21988820284605, 74.31835010647774, 84.67330366373062, 76.48525983095169, 60.98946712911129, 45.89229963719845, 41.06663458049297, 38.01653824746609, 69.15089339017868, 62.94445842504501, 60.810747519135475, 11.653254590928555, 0.40827502962201834, 0.13979776413179934, 0.2586629264988005, 0.5125873885117471, 1.882169866003096, 5.904359249398112, 7.446636166423559, 3.5313333850353956, 4.732575276866555, 20.308517552912235, 37.383078038692474, 54.11739528179169, 59.97660867869854, 66.31266608834267, 67.74150341749191, 63.088858276605606, 65.42898550629616, 62.56232813000679, 63.77551183104515, 63.3092350512743, 65.52013501524925, 64.19807195663452, 60.07220774888992, 63.39677095413208, 63.86771768331528, 57.46468126773834, 54.907904863357544, 53.48230116069317, 56.54595896601677, 63.2827390730381, 58.02939936518669, 60.78968524932861, 61.552182734012604, 61.48939870297909, 61.814927235245705, 55.76336055994034, 51.31223000586033, 50.48599474132061, 52.94185236096382, 57.112242579460144, 62.50801384449005, 63.31167072057724, 60.74507184326649, 57.06805095076561, 58.92942287027836, 59.22348149120808, 62.36641064286232, 53.269143998622894, 49.67909283936024, 47.44399957358837, 61.007865741848946, 56.47334486246109, 68.76797273755074, 38.48341539502144, 48.4492090344429, 67.44484573602676, 60.70061042904854, 53.3551561832428, 51.75544202327728, 58.01561750471592, 60.02551585435867, 57.07527816295624, 51.7069186270237, 46.49296760559082, 48.06527003645897, 60.90605400502682, 62.62760862708092, 59.569677114486694, 51.069309040904045, 53.23809206485748, 60.71811988949776, 59.724176824092865, 52.19564460217953, 45.57985760271549, 51.89635366201401, 61.52686469256878, 60.86307071149349, 58.98337237536907, 54.889787435531616, 52.204604521393776, 55.25883123278618, 58.23755219578743, 61.924038380384445, 62.91172698140144, 61.676728650927544, 59.605908170342445, 51.292341873049736, 54.83030542731285, 60.27697116136551, 60.20969197154045, 64.21582460403442, 66.88042402267456, 69.8014260828495, 66.10626876354218, 52.33575828373432, 13.997383955866098, 6.913548046723008, 16.027995944023132, 16.89329881221056, 9.286107011139393, 2.728207055479288, 0.42473898211028427, 0.28151475184131414, 0.3758306190138683, 0.27044276939705014, 5.713021941483021, 54.78860266506672, 67.62013792991638, 82.18895137310028, 84.54461216926575, 78.26842054724693, 38.33712324500084, 37.51778461039066, 52.55146510899067, 63.66724044084549, 71.83359503746033, 49.243712201714516, 3.119856077246368, 0.1461574947461486, 0.07481442298740149, 0.2236732907476835, 0.12353828817140311, 0.12625521660083905, 0.10628987816744484, 0.1108963591104839, 0.06772314256522804, 0.08761888238950633, 0.16809705732157454, 0.139215103990864, 0.1515738369198516, 0.10324401504476555, 0.20150244527030736, 0.11004460364347324, 0.12777019233908504, 0.16742323176003993, 0.1478343625785783, 0.2001883540651761, 0.15705701691331342, 0.1736963537405245, 0.09217464496032335, 0.21963320206850767, 0.1282984233694151], [0.03959058769396506, 0.11906686326256022, 0.02744407560385298, 0.03337782087328378, 0.11066374776419252, 0.06558887427672744, 0.07223131120554172, 0.044712653470924124, 0.06648105452768505, 0.09533001197269186, 0.10696777811972424, 0.062440980691462755, 0.027571268583415076, 0.05897720307984855, 0.05258032055280637, 0.04278650936612394, 0.05520521895959973, 0.01559606273076497, 0.07333905567065813, 0.09420373608008958, 0.1517052119015716, 0.03822562226559967, 14.442630764096975, 65.52030980587006, 62.68774040043354, 54.59549322724342, 48.17326404154301, 22.161068245768547, 21.623588986694813, 28.387682028114796, 54.726206213235855, 61.38229764997959, 21.663536243140697, 0.3738410398364067, 0.05378854439186398, 0.14874724874971434, 0.22041122516384348, 0.5900688527617604, 1.5866719535551965, 2.390461703762412, 5.052072107791901, 2.6778576197102666, 11.316386517137289, 34.252182841300964, 48.21153558790684, 60.41189432144165, 62.50002287328243, 62.965425699949265, 61.17585852742195, 59.86747473478317, 60.42680472135544, 62.87966430187225, 63.70045825839043, 60.45523099601269, 59.5940338075161, 61.09215281903744, 62.02401101589203, 58.40078003704548, 57.31770135462284, 52.96159990131855, 55.32288059592247, 53.194667994976044, 53.62261243164539, 57.2522384673357, 56.738338842988014, 56.9515909999609, 58.008625879883766, 57.95537933707237, 58.130333349108696, 55.96136413514614, 52.93176770210266, 48.511115312576294, 51.42556272447109, 52.25984215736389, 56.851291581988335, 54.92867834866047, 54.391482174396515, 51.8478948622942, 52.24657326936722, 57.30920501053333, 54.65440906584263, 44.14629712700844, 42.554387748241425, 44.33120660483837, 55.83882451057434, 53.66819478571415, 64.96370807290077, 34.974634274840355, 41.20467737317085, 62.63415947556496, 53.17612498998642, 49.5206793397665, 41.99410021305084, 54.88930106163025, 54.0416045486927, 56.45396590232849, 49.14836011826992, 44.562705382704735, 42.532744109630585, 54.2550352960825, 56.68204106390476, 57.67940394580364, 51.72230400145054, 52.50812463462353, 58.756406754255295, 56.930517330765724, 47.73790620267391, 39.80049692094326, 49.28725406527519, 58.763611167669296, 57.795419320464134, 54.67969670891762, 52.36565887928009, 53.911837711930275, 55.739296451210976, 57.23291650414467, 57.38385580480099, 60.41988529264927, 58.03399331867695, 55.319711565971375, 47.69642382860184, 47.20674030482769, 47.945530861616135, 52.66213417053223, 52.148994505405426, 57.45833940804005, 61.63121469318867, 62.65009582042694, 58.27589213848114, 35.38921482861042, 9.397909361869097, 2.4725104635581374, 6.947294510900974, 6.706237820908427, 2.493724962696433, 0.8873796241823584, 0.1216521866444964, 0.08322248118929565, 0.01459177365177311, 0.006630497164223925, 12.256747707724571, 44.61871437728405, 78.0140545964241, 72.87538513541222, 57.6256900280714, 23.346370942890644, 30.00168912112713, 43.72434876859188, 45.289325192570686, 59.82265613973141, 47.69732058048248, 5.765155144035816, 0.27247856953181326, 0.04165969912719447, 0.05831418318848591, 0.06836052125436254, 0.08812890111585148, 0.06515869579743594, 0.0503976642357884, 0.02598719518573489, 0.04174273803073447, 0.04789517195604276, 0.02670627691259142, 0.06767427956219763, 0.01029680641295272, 0.03370854785316624, 0.027626217197394, 0.03341895811900031, 0.03190512528817635, 0.021538233231694903, 0.006317547868093243, 0.03345479643030558, 0.014968904342822498, 0.0412136015802389, 0.012068143150827382, 0.012655862883548252, 0.05499631923157722, 0.052927801516489126, 0.02564052316301968, 0.02247685522888787, 0.08306473770062439, 0.05637499954900704, 0.060508532042149454, 0.03492533978715073, 0.031295261724153534, 0.050691981450654566, 0.07150033285142854, 0.07722098525846377, 0.027132867107866332, 0.019385782325116452, 0.09633359601139091, 0.01151065387603012, 0.02943535801023245, 0.057731422857614234, 0.09952726526535116, 0.05672382379998453, 0.08285287680337206, 0.12033200982841663, 19.044319689273834, 77.83451423048973, 70.41136935353279, 62.45783373713493, 55.358720272779465, 28.926493115723133, 25.20695060491562, 26.625401191413403, 56.96632280945778, 64.89857956767082, 21.017428413033485, 0.6879444164223969, 0.07477327832020819, 0.25711988273542374, 0.6452868960332125, 1.7564956471323967, 3.9169343188405037, 7.940259128808975, 7.730928361415863, 2.0768521819263697, 12.646117564290762, 36.77736014127731, 51.11992612481117, 63.98174196481705, 65.03881484270096, 63.86099964380264, 64.63434174656868, 62.877992391586304, 62.81023822724819, 64.36798363924026, 64.14682030677795, 63.17134045064449, 62.00159601867199, 60.97586005926132, 62.7599935233593, 59.40230369567871, 59.87910971045494, 55.70804312825203, 55.672461837530136, 53.30970302224159, 55.33340223133564, 59.65052917599678, 58.373543098568916, 58.73474031686783, 59.726380705833435, 58.7058162689209, 58.98651860654354, 58.07273603975773, 54.15723994374275, 51.36514216661453, 52.183337062597275, 55.27523495256901, 59.50617112219334, 56.852655708789825, 56.1436365544796, 52.28267893195152, 54.15188983082771, 59.43138733506203, 56.94709964096546, 46.959187388420105, 44.076339080929756, 46.3114133477211, 56.586274802684784, 57.35446818172932, 65.55086776614189, 35.28447724878788, 43.15589927136898, 63.74859407544136, 56.08773395419121, 51.24507240951061, 44.01888616383076, 54.51635107398033, 56.28524735569954, 58.46650891005993, 51.85557805001736, 48.0631497502327, 42.909976467490196, 55.869124084711075, 57.62880966067314, 59.32129964232445, 53.13056543469429, 53.63868936896324, 59.72682528197765, 59.20052692294121, 50.35375043749809, 41.71441622078419, 51.82544946670532, 60.69630526006222, 59.62409779429436, 56.176588386297226, 54.68440845608711, 54.21712853014469, 57.33594037592411, 58.498936370015144, 60.14932461082935, 63.734998404979706, 61.904830411076546, 57.63824835419655, 50.10782763361931, 49.76015008985996, 51.621655002236366, 53.93757373094559, 54.48525734245777, 61.37233838438988, 63.16317468881607, 65.27568653225899, 62.88449764251709, 40.321296975016594, 10.764297042042017, 2.764443098567426, 4.148418847471476, 10.036491695791483, 6.139599876478314, 3.21021665353328, 0.7113671314436942, 0.15065811574459076, 0.06250875361729413, 0.06309305390459485, 14.620833601802588, 49.72507417201996, 83.44057381153107, 82.08492055535316, 55.02461180090904, 24.793196506798267, 36.06053240597248, 49.79224696755409, 51.71379245817661, 65.4589506983757, 58.59670512378216, 7.0791403111070395, 0.322811440564692, 0.046189698041416705, 0.08072602999163792, 0.0412842688820092, 0.005836298960275599, 0.06780758412787691, 0.06332983612082899, 0.009021132482303074, 0.06815425615059212, 0.040430316657875665, 0.026299641212972347, 0.042781826414284296, 0.012522280012490228, 0.05274372291751206, 0.047858305770205334, 0.041000145065481775, 0.03663759693154134, 0.05918546456086915, 0.03353362364578061, 0.059330316944397055, 0.06302890265942551, 0.045236936275614426, 0.029941792163299397, 0.040530591941205785, 0.2842098759720102, 0.18829681794159114, 0.23050934658385813, 0.14874959393637255, 0.23239872098201886, 0.13226342154666781, 0.252412588451989, 0.2419940521940589, 0.12409189323079772, 0.21309618721716106, 0.23972799332113937, 0.15259837178746238, 0.14711753698065877, 0.1293972769053653, 0.20754208759171888, 0.11206362381926738, 0.10660255240509287, 0.1064165479328949, 0.19777153531322256, 0.19499973248457536, 0.301349806250073, 0.20300872303778306, 23.464677594602108, 89.41065385937691, 79.72508758306503, 70.93273177742958, 63.027537167072296, 34.26940731704235, 31.798040829598904, 39.22239974141121, 67.58954957127571, 73.65496650338173, 30.630266591906548, 0.8753527945373207, 0.14474664232693613, 0.6569281651172787, 0.7705233071465045, 1.631155216600746, 5.893513206392527, 10.139024443924427, 11.141853332519531, 7.267101025208831, 15.538669601082802, 37.333703488111496, 49.83235001564026, 63.05164307355881, 62.89427071809769, 65.96116974949837, 67.36876621842384, 64.33449223637581, 64.17878419160843, 66.17711216211319, 66.16433724761009, 64.117531478405, 62.407482638955116, 64.30465623736382, 64.80708047747612, 61.0842302441597, 60.78938506543636, 55.54822750389576, 54.542216286063194, 52.85417206585407, 56.16512060165405, 61.79150149226189, 60.594162940979004, 60.64631134271622, 61.15850865840912, 61.11472740769386, 61.90081402659416, 61.06738954782486, 56.60051263868809, 54.350793957710266, 56.1213393509388, 58.11635009944439, 61.66314817965031, 57.999278381466866, 55.904051810503006, 54.47191625833511, 55.49332045018673, 61.4578527957201, 59.869861006736755, 49.886850491166115, 46.83439068496227, 50.78627362847328, 60.886295065283775, 60.398245453834534, 66.94369062781334, 38.805812895298004, 46.604818403720856, 65.48225864768028, 59.29633118212223, 53.140448704361916, 46.766708716750145, 58.067792505025864, 59.32337053120136, 60.725510492920876, 53.47546152770519, 50.28130732476711, 47.63557389378548, 58.604669496417046, 61.59038208425045, 61.0870610922575, 54.262323305010796, 52.52689182758331, 62.81364284455776, 61.83922313153744, 53.25325705111027, 44.26328904926777, 54.00032736361027, 63.268524035811424, 61.58130817115307, 57.32679806649685, 54.73731301724911, 53.897767066955566, 59.7884351760149, 62.77549669146538, 61.380568742752075, 67.03553929924965, 64.09359276294708, 61.326767429709435, 53.72301824390888, 52.4704572558403, 54.10750441253185, 57.60106734931469, 57.207324877381325, 65.15319630503654, 67.70979031920433, 66.85261711478233, 63.463628366589546, 42.8206242620945, 15.584318451583385, 7.513968553394079, 13.752632439136505, 23.153723180294037, 12.62341283261776, 1.9375068903900683, 0.2782362699508667, 0.17092438763938844, 0.28961164236534387, 0.13870085502276197, 20.756466016173363, 59.15062040090561, 82.42317080497742, 79.52968686819077, 63.378364741802216, 35.14863073825836, 43.33596020936966, 56.57015986740589, 60.36386489868164, 72.34136939048767, 66.9934755563736, 8.816920537501574, 0.40134746697731316, 0.17476604087278247, 0.2138308688881807, 0.14891322265611961, 0.27736101066693664, 0.1256744415150024, 0.16454141295980662, 0.12525812635431066, 0.1158410070638638, 0.13979651732370257, 0.08311184923513792, 0.18815972842276096, 0.08936125217587687, 0.10795849331771024, 0.14730739319929853, 0.11758382213884033, 0.11088317114626989, 0.1215753669384867, 0.15004194021457806, 0.1917979886638932, 0.11498409367050044, 0.1728831825312227, 0.05541935453948099, 0.07906531871412881], [0.04227204517519567, 0.019127041814499535, 0.03843929029244464, 0.0269679247867316, 0.039231410482898355, 0.025694822397781536, 0.05540179532545153, 0.14987143920734525, 0.05246868298854679, 0.04707036758190952, 0.06531819075462408, 0.0488035681337351, 0.016593561158515513, 0.06730471228365786, 0.07327437750063837, 0.017641583144722972, 0.034769099147524685, 0.030957347044022754, 0.006834332198195625, 0.026747044939838815, 0.028560981882037595, 0.04019565327325836, 32.25238434970379, 72.94153198599815, 55.27973011136055, 55.53063064813614, 32.34491318464279, 28.987772427499294, 26.290080584585667, 52.0808831602335, 49.21142153441906, 35.70276640355587, 6.206533284857869, 0.03706986826728098, 0.18061104754451662, 0.06432841066271067, 0.2019729817402549, 1.4980838634073734, 3.811019752174616, 5.399456592276692, 7.585358172655106, 5.8067291881889105, 27.500682324171066, 51.37187920510769, 62.88548178970814, 60.39677493274212, 61.720513701438904, 60.6129415333271, 61.37721352279186, 59.75549474358559, 63.909074664115906, 59.47670750319958, 61.1712683737278, 56.330358535051346, 58.264397755265236, 54.47110690176487, 56.52950964868069, 55.968082174658775, 56.12044259905815, 56.461850479245186, 57.27964259684086, 53.10247354209423, 58.01951229572296, 55.862512439489365, 56.07837125658989, 54.28335517644882, 55.481328293681145, 51.301028206944466, 58.05364966392517, 54.94461089372635, 55.70659160614014, 50.85271306335926, 51.25879347324371, 52.72398345172405, 57.563282176852226, 54.62418168783188, 56.73122942447662, 49.63349908590317, 56.35036066174507, 53.63992050290108, 49.721357971429825, 39.50032062828541, 41.74555554986, 44.59771670401096, 54.15215961635113, 52.33749099075794, 62.066428139805794, 35.91454043984413, 43.078273236751556, 60.295962542295456, 55.04000097513199, 51.69494166970253, 42.05643206834793, 52.11913950741291, 52.36531689763069, 55.14461696147919, 49.97866876423359, 43.30373413860798, 39.68155950307846, 46.48089565336704, 55.78540697693825, 57.809467166662216, 55.98813369870186, 53.14871706068516, 54.61718626320362, 58.25153924524784, 47.87985138595104, 39.36119869351387, 47.82418817281723, 56.58912844955921, 56.56886413693428, 53.03045220673084, 52.040430530905724, 52.119975462555885, 56.71176306903362, 56.15080676972866, 57.58847862482071, 56.653272807598114, 56.567640602588654, 55.43043002486229, 45.838745310902596, 46.058913096785545, 46.71920746564865, 46.69751822948456, 49.190777242183685, 52.46664986014366, 54.317066967487335, 57.58271053433418, 63.24842311441898, 53.765613958239555, 25.25981906801462, 7.098609991371632, 3.312836322002113, 2.3953983513638377, 5.4430298041552305, 2.1527376724407077, 0.594183022622019, 0.027007657517970074, 0.06015569648297969, 0.038380575279006734, 1.2767901504412293, 20.52053477615118, 30.597607344388962, 35.07418893277645, 70.55332213640213, 56.47829979658127, 21.793998442590237, 24.014669582247734, 42.369763255119324, 52.5297112762928, 55.53686611354351, 17.1905929595232, 0.5566077295225114, 0.1025653284159489, 0.04618335638951976, 0.02945809370430652, 0.016599160662735812, 0.01326546298514586, 0.05061529533122666, 0.050914863240905106, 0.054636540880892426, 0.0452342422795482, 0.023710403002041858, 0.06839235196821392, 0.04310433039790951, 0.022166117996675894, 0.021680694044334814, 0.026218515195068903, 0.043114230647915974, 0.017601911640667822, 0.0515579082275508, 0.03641387651441619, 0.04142981517361477, 0.04856172818108462, 0.028460675057431217, 0.057328818875248544, 0.05483440858370159, 0.05237376601144206, 0.028048738568031695, 0.0401916159898974, 0.034392670713714324, 0.019697642055689357, 0.05564353137742728, 0.14406061585759744, 0.09241510080755688, 0.003460358398115204, 0.03994290374976117, 0.046552159255952574, 0.017966124323720578, 0.033982162858592346, 0.06498711125459522, 0.07159521643188782, 0.047797060033190064, 0.019308832743263338, 0.06955874094273895, 0.03240495061618276, 0.03930281622160692, 0.06089444883400574, 40.296130925416946, 82.06869542598724, 64.0707179903984, 60.769276544451714, 41.93828880786896, 37.12656520307064, 30.16227040439844, 37.47170448303223, 49.93359938263893, 41.2868707627058, 5.693867169320583, 0.06410377740394324, 0.04303665766201448, 0.047193115096888505, 0.9453211119398475, 3.2513427967205644, 6.161779761314392, 6.299093943089247, 4.36874907463789, 9.174598194658756, 31.194460317492485, 52.567830830812454, 62.569844126701355, 62.33494073152542, 62.987061738967896, 63.34733560681343, 63.37996445596218, 62.252477556467056, 64.19152870774269, 60.01575417816639, 61.23907953500748, 58.3976224064827, 58.633756935596466, 57.16756761074066, 58.73578526079655, 57.74448685348034, 58.73796634376049, 56.68298341333866, 56.704072281718254, 54.45515915751457, 57.411123141646385, 56.7998081445694, 57.52166301012039, 55.45495390892029, 56.96964383125305, 53.54436703026295, 59.302988424897194, 57.46593900024891, 57.23449341952801, 51.827106177806854, 53.11553344130516, 55.04825793206692, 57.89621651172638, 56.38242334127426, 56.51724010705948, 50.40550746023655, 59.30155590176582, 56.98248714208603, 52.620594799518585, 41.92084014415741, 44.08963456749916, 47.8592374920845, 56.464654728770256, 55.389069244265556, 64.30419266223907, 38.94015088677406, 45.97597874701023, 61.745615154504776, 56.706895530223846, 54.137408807873726, 44.042809680104256, 53.07755447924137, 54.70282606780529, 57.1602264046669, 51.389833241701126, 45.17190009355545, 41.30605213344097, 48.413487151265144, 57.31134429574013, 59.71259884536266, 57.60164871811867, 54.16021138429642, 55.91611236333847, 59.925205036997795, 49.69929255545139, 42.366624623537064, 51.57767616212368, 59.54616017639637, 58.24437662959099, 53.70170138776302, 50.25463655591011, 53.878532499074936, 60.30794329941273, 57.7117820084095, 60.021127089858055, 59.53401602804661, 58.681330382823944, 58.78555119037628, 47.75343976914883, 48.64839434623718, 49.47371006011963, 49.82378527522087, 51.51670843362808, 55.928070321679115, 58.22064310312271, 61.36811301112175, 64.03488591313362, 57.621814236044884, 28.310511969029903, 7.544450042769313, 2.4945953534916043, 2.6454365719109774, 9.895805194973946, 6.485775550827384, 1.7191760684363544, 0.6417066568974406, 0.09340000498923473, 0.035488537105266005, 1.5809828275814652, 24.470388628542423, 43.243104591965675, 47.68719032406807, 67.62259259819984, 43.043106123805046, 24.944777972996235, 28.727541491389275, 48.13538387417793, 58.79214383661747, 64.58508878946304, 21.217924654483795, 0.7187218149192631, 0.07003756720223464, 0.08363149361684918, 0.04148287873249501, 0.02202720093919197, 0.04712415102403611, 0.02285245616803877, 0.045123417366994545, 0.01690827073616674, 0.015619228870491497, 0.020812028742511757, 0.022713958423992153, 0.05314258647558745, 0.009366667163703823, 0.07453904167050496, 0.08503594130161218, 0.0515261034888681, 0.033053795486921445, 0.04556517335004173, 0.0022365081758835004, 0.03610493899032008, 0.07674606269574724, 0.017695466776785906, 0.023107899687602185, 0.1294812880223617, 0.11852275027194992, 0.08434788876911625, 0.1352293256786652, 0.1323732890887186, 0.1970128229004331, 0.21505706012248993, 0.35902468487620354, 0.16672169440425932, 0.14629422803409398, 0.19391980371437967, 0.11485460374387912, 0.0972983063547872, 0.12700625520665199, 0.11324135281029157, 0.18924218049505726, 0.08556373446481302, 0.0960725975164678, 0.13788961339741945, 0.13439383066724986, 0.136832780262921, 0.3271173220127821, 49.629182517528534, 94.06427934765816, 71.08869820833206, 72.04981863498688, 45.82001991569996, 43.6285825073719, 38.84613633155823, 67.69430994987488, 60.77295854687691, 47.67364405095577, 9.193353988230228, 0.08817429828923196, 0.36703043966554105, 0.12584878684720024, 1.014155368320644, 6.535060331225395, 11.09282361343503, 11.256923507899046, 16.590770445764065, 9.816037975251675, 30.35976480692625, 51.64600409567356, 64.04291868209839, 61.34408690035343, 63.589280024170876, 62.66287453472614, 64.73939850926399, 61.68549098074436, 66.3128712773323, 62.60923281311989, 61.84008948504925, 58.75532001256943, 60.93935541808605, 57.79360681772232, 60.74172422289848, 59.72124718129635, 60.568138137459755, 57.204760015010834, 58.26262705028057, 54.343315958976746, 57.1252416819334, 56.633365675807, 58.59123721718788, 54.126689583063126, 59.14802514016628, 53.08952383697033, 61.2545333057642, 58.27307268977165, 61.05118341743946, 55.744946748018265, 57.093771770596504, 56.62683382630348, 60.20574018359184, 58.23884032666683, 58.53856064379215, 52.184040024876595, 60.82434318959713, 59.46741320192814, 54.60366278886795, 44.38624665141106, 47.363440096378326, 51.566386967897415, 59.32560481131077, 58.82538445293903, 66.6111932694912, 42.233316376805305, 48.47906403243542, 65.20425796508789, 58.92805874347687, 56.341453939676285, 46.13988295197487, 57.026902958750725, 56.20835468173027, 59.893947914242744, 54.57226127386093, 47.902285382151604, 43.79469819366932, 52.165105640888214, 60.51274850964546, 62.627726420760155, 60.763284265995026, 55.11936351656914, 56.61678336560726, 63.24917547404766, 52.03505001962185, 45.14399819076061, 52.846302688121796, 61.759609803557396, 59.348430186510086, 53.75257305800915, 52.325821816921234, 53.293918669223785, 62.397173792123795, 59.56190653145313, 61.8657723069191, 62.466675862669945, 62.23688319325447, 61.850599721074104, 51.03612922132015, 50.54863817989826, 50.93051388859749, 51.011529341340065, 54.42506097257137, 58.30513156950474, 62.14577928185463, 63.956047743558884, 65.90035021305084, 60.09390838444233, 33.701022416353226, 13.759271632879972, 7.466073073446751, 10.88217906653881, 15.226240865886211, 9.618227239698172, 1.4139300165697932, 0.3604073356837034, 0.21037182246800512, 0.22909948864253238, 2.2917289892211556, 31.476384289562702, 42.853534296154976, 44.72238041460514, 80.0644625723362, 67.27326214313507, 32.38756209611893, 34.322988241910934, 57.52807706594467, 67.12336018681526, 72.67071291804314, 25.629370138049126, 0.8548423263709992, 0.3065081185195595, 0.13907319051213562, 0.11097408423665911, 0.14289551822002977, 0.11339482894982211, 0.1725743303541094, 0.13934388145571575, 0.11345568505930714, 0.14066361298318952, 0.08491860775393434, 0.18010237952694297, 0.11889114495716058, 0.08222926495363936, 0.11342062600306235, 0.10308633834938519, 0.10196581410127692, 0.15191452723229304, 0.16381943685701117, 0.055192528234329075, 0.12291313265450299, 0.15671748435124755, 0.10772621593787335, 0.15840282751014456], [0.07295490519027226, 0.051896969525841996, 0.00432181350333849, 0.04024797468446195, 0.04913984266750049, 0.009181517089018598, 0.05874763082829304, 0.007495822337659774, 0.025536179055052344, 0.03664467702037655, 0.005714300086765434, 0.055500011148978956, 0.04245034244377166, 0.06979947880608961, 0.042453663554624654, 0.013495875718945172, 0.07569408320705406, 0.09299306315369904, 0.04373318181023933, 0.0023802876921763527, 0.0207342034264002, 4.964128201827407, 43.79982031881809, 59.4637767970562, 62.95174263417721, 51.012961864471436, 35.33075116574764, 18.102566823363304, 43.57782483100891, 60.44388100504875, 42.59862117469311, 23.98131687194109, 0.0877499976195395, 0.021941289924143348, 0.06763868615962565, 0.22566448780708015, 0.5871332134120166, 2.7498789550736547, 3.761328631080687, 6.134972674772143, 8.266441226005554, 21.938170306384563, 53.39447267353535, 63.7160450220108, 63.640455678105354, 63.29404726624489, 58.690472692251205, 58.7557265907526, 58.80080737173557, 61.049549505114555, 59.867930710315704, 61.47601202130318, 59.64641399681568, 59.048170298337936, 59.45056110620499, 55.74066437780857, 55.97298391163349, 56.46725378930569, 54.9562306702137, 54.00899089872837, 54.85360957682133, 54.42803621292114, 54.32553291320801, 53.31602208316326, 56.99559643864632, 56.06656149029732, 55.3772708773613, 53.25278587639332, 52.406411692500114, 55.08179493248463, 58.08021783828735, 51.95887930691242, 51.556902676820755, 52.0317517966032, 56.423529535532, 54.951621517539024, 55.36705322563648, 55.259883776307106, 55.638332068920135, 52.949341759085655, 44.045192152261734, 38.13335157930851, 43.61564800143242, 46.802046820521355, 55.13824850320816, 52.613416984677315, 61.37477785348892, 35.057967603206635, 43.04545059800148, 60.759355276823044, 52.83940605819225, 54.651620015501976, 41.94869264960289, 48.970875442028046, 52.34346427023411, 56.450040712952614, 50.12081913650036, 43.84203605353832, 39.68879051506519, 43.17436248064041, 51.4489808678627, 55.39066895842552, 54.723770543932915, 54.85407315194607, 53.940754160284996, 57.36975476145744, 46.04427248239517, 39.385547786951065, 46.1532886326313, 57.74392828345299, 57.31360137462616, 52.6980422437191, 49.11460652947426, 55.99441096186638, 57.332505360245705, 53.9977853000164, 52.90293484926224, 55.3657802939415, 54.699280858039856, 50.40141128003597, 44.99573774635792, 45.11340983211994, 44.52908858656883, 51.43347389996052, 52.987647503614426, 54.14471961557865, 57.08673074841499, 58.77108916640282, 59.25163798034191, 63.20752590894699, 48.64882372319698, 21.547743156552315, 4.51049049384892, 3.5668973391875625, 6.776770111173391, 8.85935666039586, 2.8130973502993584, 0.40765913610812277, 0.04063222535478417, 0.134306242398452, 0.053540466687991284, 6.511004772037268, 30.90084247291088, 27.562759593129158, 32.30970427393913, 44.510104805231094, 24.27084993571043, 27.21914403140545, 39.64682176709175, 47.862558513879776, 58.45380239188671, 32.34504237771034, 1.4381905272603035, 0.09636535251047462, 0.07021743411314674, 0.11146129676490091, 0.015281021969713038, 0.05501945568539668, 0.028062212259101216, 0.03818568729911931, 0.032470931255375035, 0.05097304761875421, 0.03530578323989175, 0.016089201308204792, 0.09522851585643366, 0.09226607013260946, 0.049387690305593424, 0.028192301469971426, 0.05615374306216836, 0.06262044684262946, 0.05672398707247339, 0.020046957979502622, 0.03435205668210983, 0.03135419567115605, 0.025545157186570577, 0.04090889429789968, 0.029782161764160264, 0.0766448411741294, 0.039534418247058056, 0.009747924195835367, 0.042662960331654176, 0.07327653715037741, 0.05211716845224146, 0.07071176383760758, 0.10618475294904783, 0.030346333151101135, 0.11021262587746605, 0.04828880337299779, 0.05566774765611626, 0.046200025026337244, 0.018913010135293007, 0.003602900615078397, 0.024013529509829823, 0.054506954475073144, 0.014587164914701134, 0.033758383069653064, 0.013860815706721041, 6.140969702973962, 54.65339072048664, 67.46506065130234, 68.59411686658859, 57.94360376894474, 39.467201605439186, 22.099564746022224, 39.03791964054108, 59.54892262816429, 47.884749323129654, 24.94361713528633, 0.283473813906312, 0.08131602255161852, 0.09604072969523259, 0.6315576389897615, 3.1250622728839517, 6.34410965256393, 6.928247557953, 4.109420590102673, 7.080352921038866, 24.870294369757175, 53.405583277344704, 66.62469014525414, 64.72137987613678, 62.80353158712387, 58.69062848389149, 59.58935625851154, 59.88392025232315, 61.01329185068607, 60.69175310432911, 61.469784155488014, 61.49341508746147, 61.20975650846958, 61.180783063173294, 57.50970505177975, 58.21919158101082, 57.09834672510624, 56.3421531021595, 56.44981652498245, 56.271488294005394, 54.05600197613239, 53.21599245071411, 53.73779185116291, 55.850729271769524, 55.5284533649683, 55.91927759349346, 51.91111586987972, 52.63726070523262, 56.89600758254528, 60.02706237137318, 54.886698201298714, 52.88222596049309, 54.516035690903664, 58.90915095806122, 56.79272912442684, 55.621403977274895, 56.042470782995224, 58.84552337229252, 54.648952558636665, 46.42851926386356, 40.079873129725456, 46.08556106686592, 49.27017018198967, 58.041528314352036, 55.09511701762676, 62.67650060355663, 38.13013315200806, 44.92916911840439, 62.44334131479263, 55.90697765350342, 56.48416668176651, 43.33106607198715, 52.15640030801296, 54.20356705784798, 60.11588640511036, 52.01386235654354, 45.61813294887543, 41.79233863949776, 45.221939608454704, 54.021617621183395, 59.25235994160175, 56.852784901857376, 54.94150646030903, 55.86422614753246, 59.377095848321915, 46.84975326061249, 42.550177574157715, 47.93753229081631, 60.70623032748699, 58.09044688940048, 53.75691622495651, 49.62258227169514, 58.04104574024677, 59.59676966071129, 57.233839854598045, 55.87347485125065, 57.891873344779015, 56.48703932762146, 54.50938984751701, 47.66347199678421, 48.153212517499924, 47.11507022380829, 53.07411186397076, 53.33315536379814, 57.05660216510296, 58.45949448645115, 59.95675474405289, 62.44620256125927, 64.95151072740555, 50.87659478187561, 22.48983610421419, 4.418418109416962, 1.266883488278836, 4.899363527074456, 6.532601863145828, 6.264037024229765, 2.17594635207206, 0.08930878233513795, 0.0865562456601765, 0.085418154776562, 8.205886725336313, 29.4971426948905, 26.907769739627838, 41.16679720580578, 42.60436646640301, 27.63188548386097, 32.27777078747749, 45.58417797088623, 52.56559655070305, 63.321785777807236, 38.93336825072765, 1.877222650218755, 0.11200109787750989, 0.08405895583564416, 0.042007154115708545, 0.02423759131488623, 0.06479428644524887, 0.05739570864534471, 0.050079702195944265, 0.02197274585341802, 0.09719712194055319, 0.0023897976188891334, 0.04279905537259765, 0.049206513504032046, 0.06272852580877952, 0.010780788743431913, 0.01841873050580034, 0.049489665107103065, 0.029401842621155083, 0.07744151444057934, 0.09564290143316612, 0.038661340877297334, 0.04465613892534748, 0.037384961906354874, 0.049762534254114144, 0.166790283692535, 0.23470770567655563, 0.2242755881161429, 0.22222405445063487, 0.12723816151265055, 0.10142804647330195, 0.19193843269022182, 0.27119943348225206, 0.17681435361737385, 0.11711499260854907, 0.20742448687087744, 0.08278258057544008, 0.12187906861072406, 0.187667150166817, 0.10252715976093896, 0.06566265117726289, 0.16951162047917023, 0.13065429695416242, 0.09283234365284443, 0.16899504116736352, 0.08132420101901516, 7.7989608608186245, 67.85390138626099, 75.61372339725494, 81.02030888199806, 65.68991750478745, 49.78920713067055, 25.831752978265285, 56.522373631596565, 72.13349014520645, 55.56253753602505, 34.17648330330849, 0.4340119689004496, 0.2468467628932558, 0.3124995360849425, 0.5906820448581129, 3.1909096520394087, 9.158509857952595, 10.508047342300415, 14.141672663390636, 13.051614705473185, 25.88896080851555, 56.159591898322105, 65.67296281456947, 64.7242221236229, 64.19281303882599, 58.85006792843342, 60.44785939157009, 60.99938839673996, 63.522194623947144, 61.73070855438709, 62.50529699027538, 63.288754150271416, 62.12224714457989, 64.38522711396217, 59.83892686665058, 59.50612172484398, 58.87187495827675, 59.216201081871986, 56.87985084950924, 55.74115455150604, 56.29481144249439, 53.04541200399399, 55.59960454702377, 58.904294818639755, 59.08806435763836, 56.15621767938137, 53.31666424870491, 52.40063980221748, 58.41114208102226, 63.40058594942093, 56.1860840767622, 56.13303132355213, 58.09950180351734, 60.68201802670956, 59.33372117578983, 56.454843655228615, 58.93753543496132, 61.43058925867081, 58.713058680295944, 49.632089361548424, 42.69835442304611, 47.74585157632828, 52.668118849396706, 62.74237006902695, 59.017118364572525, 63.36161904036999, 41.44021913409233, 48.476499170064926, 65.833261013031, 59.083740189671516, 58.301251977682114, 46.10668033361435, 54.49349530041218, 56.191764771938324, 61.60469211637974, 54.2746726423502, 48.87754485011101, 42.860282734036446, 47.968770414590836, 56.26245237886906, 61.555374562740326, 58.6307018995285, 57.5489417463541, 57.31415614485741, 61.86678685247898, 49.9081901460886, 44.56496246159077, 49.86184403300285, 64.4503404200077, 60.31058795750141, 54.618151411414146, 49.42385673522949, 60.70191375911236, 62.169079631567, 59.58963744342327, 59.27042797207832, 60.75950346887112, 58.90514217317104, 56.121825724840164, 49.78663466870785, 50.79472057521343, 48.815380185842514, 56.14362135529518, 57.75895647704601, 59.60147000849247, 62.42515169084072, 62.00429007411003, 64.82657343149185, 67.77469843626022, 52.91136659681797, 28.36225189268589, 8.16741093993187, 8.323652856051922, 18.367234021425247, 19.166407138109207, 9.383884314447641, 1.0063784918747842, 0.14973105455283076, 0.26135128224268556, 0.16099770233267918, 11.005398854613304, 48.55603650212288, 40.58341071009636, 43.99530462920666, 51.54165789484978, 34.29089896380901, 41.66558124125004, 55.40752485394478, 61.138989105820656, 69.29603800177574, 47.09742397069931, 2.5871341628953815, 0.34839992062188685, 0.20330524072051048, 0.19358827150426805, 0.17660860059550032, 0.14682704553706571, 0.1015808769443538, 0.12865452066762373, 0.11567982743144967, 0.10807221260620281, 0.10025197989307344, 0.1277875734376721, 0.16546820697840303, 0.1840518816607073, 0.16086402669316158, 0.09862901424639858, 0.13226058654254302, 0.13272907468490303, 0.15358314238255844, 0.16327971738064662, 0.11704315271344967, 0.19726389145944268, 0.1000454550376162, 0.12164281331934035], [0.04229254700476304, 0.022387613826140296, 0.040938750898931175, 0.07609934778884053, 0.052030912338523194, 0.040791367791825905, 0.05468930758070201, 0.08820410293992609, 0.03235118943848647, 0.05346060046576895, 0.057561686262488365, 0.013619548135466175, 0.04252585596987046, 0.040546358868596144, 0.03527209715684876, 0.051021287217736244, 0.027772735702455975, 0.04856847430346534, 0.09294354706071317, 0.05278307158732787, 0.12929968448588625, 15.237095933407545, 71.54637604951859, 59.429464638233185, 55.852051600813866, 42.572087198495865, 37.98144333064556, 32.90768578648567, 56.00253112614155, 29.31767452508211, 44.77847300469875, 5.434467913582921, 0.08832503590383567, 0.07049261505017057, 0.10126396504347213, 0.23808835161617026, 1.387301639188081, 3.633799636736512, 6.765896994620562, 5.967897539958358, 22.083915285766125, 55.57831808924675, 64.67185333371162, 64.93901699781418, 62.74080075323582, 63.14542964100838, 63.394407480955124, 57.23882898688316, 60.588307455182076, 58.235705494880676, 59.402847066521645, 58.76856990158558, 60.06101354956627, 58.12051087617874, 57.62366093695164, 57.44364559650421, 59.592282101511955, 57.62255139648914, 56.598795130848885, 56.936084032058716, 53.92525479197502, 53.27334277331829, 55.74376121163368, 56.161639988422394, 57.05907583236694, 56.25291109085083, 56.993039175868034, 54.43315073847771, 52.335161715745926, 53.359810933470726, 58.00357975065708, 56.00517578423023, 53.163361474871635, 50.62461130321026, 56.36252000927925, 55.432793498039246, 53.68568144738674, 52.954281494021416, 56.48476704955101, 50.23190997540951, 40.76587311923504, 38.53882782161236, 45.55124893784523, 44.03414994478226, 53.407676964998245, 52.59749963879585, 62.295042872428894, 33.44083897769451, 42.44184158742428, 59.498932510614395, 53.157889768481255, 57.30998016893864, 43.41820299625397, 46.225974932312965, 49.67561222612858, 51.247964054346085, 48.39453376829624, 42.81817339360714, 40.281038135290146, 41.38156548142433, 48.13161447644234, 55.66554240882397, 56.9743137806654, 51.767757162451744, 53.71186584234238, 55.618960708379745, 42.69892439246178, 40.46910144388676, 48.131124302744865, 56.857371255755424, 54.351531118154526, 50.88710501790047, 51.20539873838425, 57.530284747481346, 54.32322643697262, 53.91781099140644, 49.13124583661556, 48.463583663105965, 50.637496411800385, 47.045951932668686, 44.57651764154434, 46.99945002794266, 49.80383634567261, 52.496151477098465, 53.76133918762207, 58.671865090727806, 59.319015964865685, 60.6481846421957, 60.73395363986492, 57.74125322699547, 57.334203869104385, 44.878092259168625, 16.77061479538679, 1.4615755411796272, 5.311369244009256, 5.510752620175481, 2.9794538486748934, 6.0873303562402725, 0.1300984135014005, 0.11983627002337016, 0.12704227905487642, 0.16469989117467776, 22.510744482278824, 43.42064246535301, 33.40086132287979, 31.79145198315382, 16.10567517578602, 18.556570261716843, 39.63365167379379, 45.384449288249016, 50.98134756088257, 50.02643600106239, 7.1906002052128315, 0.22465720045147464, 0.025107802139245905, 0.07115772037650459, 0.047086000922718085, 0.01924686712300172, 0.08810251034446992, 0.08419430130743422, 0.035411316639510915, 0.042531596482149325, 0.07713035418419167, 0.025508573016850278, 0.027482917757879477, 0.027706521286745556, 0.04949804024363402, 0.008151578458637232, 0.03339045222674031, 0.008386164845433086, 0.026670523948268965, 0.05818154284497723, 0.022685864423692692, 0.10345829534344375, 0.027060309184889775, 0.03021143111254787, 0.02435916438116692, 0.0692930149671156, 0.04437077201146167, 0.04154711161390878, 0.08742841018829495, 0.10576879401924089, 0.03908559330739081, 0.05942853276792448, 0.03608739090850577, 0.01828055002988549, 0.042261272901669145, 0.04454254209122155, 0.0848891148052644, 0.029136511839169543, 0.05681815448042471, 0.09043298021424562, 0.026617634794092737, 0.02918022062658565, 0.02084461273625493, 0.06711490801535547, 0.15646969608496875, 19.960971102118492, 79.35549661517143, 66.42085388302803, 64.1508024930954, 48.734577521681786, 45.85162281990051, 32.98748530447483, 56.51419647037983, 36.38560876250267, 47.25488372147083, 5.841289758682251, 0.07608543994138017, 0.022872729787195567, 0.22800863545853645, 0.5819060595240444, 5.455312170088291, 4.908187128603458, 4.478395991027355, 3.558093449100852, 23.49317416548729, 54.69250202178955, 67.51343205571175, 66.84536710381508, 64.27416667342186, 65.18405824899673, 65.15550658106804, 56.44724786281586, 62.340553030371666, 59.08653303980827, 61.14235572516918, 59.56080079078674, 62.20619224011898, 59.33976285159588, 61.533438339829445, 58.456678837537766, 61.19241423904896, 57.59620741009712, 57.8251489251852, 57.162844464182854, 56.265408620238304, 53.97201508283615, 55.95303878188133, 57.601090148091316, 58.698190078139305, 58.16168546676636, 58.48686821758747, 54.33810643851757, 53.396152183413506, 53.5129427164793, 58.85196402668953, 57.434001713991165, 55.87812960147858, 52.78115138411522, 57.88091093301773, 56.06048181653023, 55.88764429092407, 56.01502485573292, 59.577626287937164, 51.14488698542118, 43.53756599128246, 40.53175628185272, 47.79307924211025, 47.084668055176735, 56.801563650369644, 53.15549209713936, 63.698322772979736, 35.88044486939907, 43.06044839322567, 60.96377290785313, 54.12363074719906, 58.24834741652012, 45.00552982091904, 49.286665096879005, 52.49534972012043, 54.09114249050617, 51.960699409246445, 46.32901020348072, 42.301678508520126, 42.82519541680813, 49.674160704016685, 56.89760349690914, 58.43160778284073, 53.33918184041977, 55.64517170190811, 57.0240493118763, 44.05616596341133, 42.41504542529583, 49.6457040309906, 56.50803700089455, 56.20518945157528, 51.029673367738724, 50.650316923856735, 59.26944002509117, 56.89903222024441, 56.78301304578781, 50.55909901857376, 49.73697513341904, 54.07410800457001, 49.49005298316479, 47.31183506548405, 49.5649279654026, 53.0656611174345, 54.75521765649319, 56.70272335410118, 61.20046980679035, 61.44381634891033, 62.23790913820267, 62.71890252828598, 59.33477371931076, 60.48280991613865, 44.868839755654335, 20.544429793953896, 2.4413849087432027, 1.9987001130357385, 6.234195800498128, 6.319435676559806, 4.251888245344162, 1.0415422799997032, 0.03290732151072007, 0.1774945022771135, 0.42961064726114273, 22.088057063519955, 40.99708691239357, 35.712056905031204, 40.55010549724102, 21.58912293612957, 24.315051063895226, 43.93003553152084, 51.361121982336044, 56.867619305849075, 59.057741984725, 9.961206335574389, 0.11833178825327195, 0.011327139309287304, 0.053506431795540266, 0.039692473437753506, 0.010296234031557105, 0.07409427256789058, 0.018750407434708904, 0.04263240611180663, 0.015320802012865897, 0.1219171927368734, 0.020418490094016306, 0.015973253721313085, 0.014672985944343964, 0.024675612439750694, 0.018864174962800462, 0.018371802652836777, 0.016861713957041502, 0.0324667344102636, 0.07935510511742905, 0.015964540907589253, 0.06692109614959918, 0.054531938876607455, 0.05982126989692915, 0.21841300738742575, 0.15558256243821234, 0.14473850838840008, 0.14716729056090117, 0.12229473068146035, 0.2495995518984273, 0.15721331321401522, 0.1483730727341026, 0.16237232310231775, 0.17589388269698247, 0.2642675070092082, 0.0923213007627055, 0.1488778815837577, 0.12684538727626204, 0.17178907874040306, 0.1863792270887643, 0.11324685954605229, 0.08392349162022583, 0.19596226833527908, 0.1766969310119748, 0.3044436714844778, 26.604924090206623, 89.97637510299683, 75.02504378557205, 74.46876883506775, 56.21199108660221, 50.939078629016876, 44.742963910102844, 69.78042840957642, 38.071897476911545, 60.67022725939751, 8.539468925446272, 0.20166769187198952, 0.14486761239822954, 0.2603076444938779, 0.7796270842663944, 6.08074008487165, 10.026445034891367, 14.941913522779942, 9.837774708867073, 24.773832745850086, 60.22346243262291, 70.510164052248, 69.31310668587685, 68.15066546201706, 67.5036133825779, 66.00305110216141, 57.66687981784344, 63.339048251509666, 58.02385166287422, 60.337414517998695, 61.48682624101639, 63.68413433432579, 62.096074149012566, 62.874340787529945, 60.68264119327068, 63.6705956608057, 59.76170361042023, 60.80156721174717, 60.3642600774765, 57.61253513395786, 55.4525600373745, 57.084906846284866, 59.76086005568504, 59.278730526566505, 62.41231217980385, 60.93284256756306, 56.84636704623699, 53.78502331674099, 54.096572399139404, 61.17621570825577, 59.330464750528336, 58.81555438041687, 54.292550683021545, 59.875872284173965, 58.7980031222105, 57.24701754748821, 60.238927602767944, 62.129508554935455, 54.64836739003658, 45.28503902256489, 42.791225239634514, 50.5707947909832, 49.87867712974548, 59.16463024914265, 58.23453135788441, 66.9281342625618, 40.205190405249596, 45.01314841210842, 62.245136350393295, 57.263105884194374, 61.16189047694206, 47.63032637536526, 51.459050327539444, 55.279604718089104, 56.39617100358009, 52.94428803026676, 48.71763043105602, 44.21796128153801, 44.935195595026016, 52.85621255636215, 60.63009761273861, 60.031055957078934, 57.50221945345402, 57.81393192708492, 59.63694490492344, 45.97005866467953, 45.01393876969814, 52.78941594064236, 59.723603054881096, 58.22799190878868, 51.78927540779114, 51.137207597494125, 63.403694182634354, 59.104696065187454, 58.28564241528511, 53.95580895245075, 53.04635055363178, 58.18313151597977, 53.58123265206814, 48.49985271692276, 51.36265330016613, 54.18857306241989, 57.6639349758625, 58.31755310297012, 63.713860139250755, 63.9555461704731, 63.82796421647072, 64.42287549376488, 60.96494324505329, 60.436551198363304, 47.18882046639919, 21.399621404707432, 4.3981466721743345, 13.261653184890747, 14.126387033611536, 10.37402093410492, 12.400452196598053, 0.6202204129658639, 0.21152379893464968, 0.3592399077024311, 0.7084552408196032, 32.456649988889694, 59.16332691907883, 48.301925137639046, 42.89587922394276, 23.716396987438202, 31.00863888859749, 53.17783109843731, 58.257767111063, 64.18894484639168, 65.97658172249794, 12.767706289887428, 0.275285312673077, 0.13689072715351358, 0.17224037874257192, 0.14799497817875817, 0.11790204021963291, 0.1166603084129747, 0.1427906972821802, 0.142041128128767, 0.07687697754590772, 0.26421024289447814, 0.08314395454362966, 0.19290819705929607, 0.15645878651412204, 0.11192605190444738, 0.17628119472647086, 0.10496873655938543, 0.17981086391955614, 0.09246306581189856, 0.18809330620570108, 0.07126230382709764, 0.14466565917246044, 0.0969166865979787, 0.12556626606965438], [0.01668429798883153, 0.04104364605154842, 0.03318984599900432, 0.019130312830384355, 0.043828792695421726, 0.022906412159500178, 0.0429452695971122, 0.013806450606352882, 0.06811092956922948, 0.03819586585450452, 0.00149973875068099, 0.09482132911216468, 0.06704875297145918, 0.013911052610637853, 0.07337539864238352, 0.05907070626562927, 0.019446976111794356, 0.015994519962987397, 0.02405854447715683, 0.03453809826169163, 1.0708550945855677, 34.39540475606918, 66.58954963088036, 52.35099546611309, 52.0074786990881, 31.1380922421813, 17.1568051725626, 17.67383012920618, 21.469984129071236, 43.4479895979166, 24.139817766845226, 0.34746226156130433, 0.015222398797050118, 0.055116305957199074, 0.07182118555647321, 1.0627925209701061, 5.8746348693966866, 4.749302454292774, 4.443687703460455, 12.790266629308462, 49.21758100390434, 61.90293051302433, 61.72508105635643, 60.40475830435753, 58.71821880340576, 58.93320746719837, 63.24161008000374, 60.36149002611637, 54.25973184406757, 56.881648153066635, 61.34969539940357, 60.744125694036484, 57.7922160923481, 56.32633455097675, 54.19585347175598, 54.3908666074276, 55.95649279654026, 57.070627212524414, 56.56936950981617, 57.357492819428444, 53.33712995052338, 54.826741218566895, 55.849281549453735, 53.470328003168106, 55.292227640748024, 53.61131563782692, 56.85170955955982, 54.088247045874596, 54.864043816924095, 51.4583245664835, 57.21636459231377, 54.288914278149605, 55.24926334619522, 55.17056196928024, 57.39985294640064, 52.043569162487984, 51.15220919251442, 54.598616659641266, 54.13021959364414, 44.6726942807436, 39.54163201153278, 38.101011514663696, 44.9141713231802, 46.30011275410652, 53.87683779001236, 52.98175401985645, 62.48719856142998, 31.39623139053583, 39.30760636925697, 60.26163138449192, 51.36849358677864, 55.16178444027901, 44.32661645114422, 45.959742218256, 48.9691237360239, 52.01623722910881, 49.46541890501976, 45.868767499923706, 40.37167087197304, 40.543087273836136, 42.70784251391888, 53.72733861207962, 54.77019265294075, 54.93828423321247, 56.71922206878662, 50.15032835304737, 41.927774772048, 41.881785839796066, 45.398443937301636, 56.588368490338326, 55.65709546208382, 52.75819681584835, 52.62076959013939, 57.068313136696815, 53.82468178868294, 51.06308497488499, 45.844019427895546, 46.47500976920128, 45.831225514411926, 43.73957075178623, 43.50047618150711, 48.930160626769066, 50.3951758146286, 54.842844754457474, 59.13375310599804, 60.35252630710602, 61.375184431672096, 60.37921607494354, 58.07203307747841, 59.4259612262249, 60.60833238065243, 57.75169126689434, 48.183071315288544, 18.833620995283127, 3.8074695551767945, 3.0845500342547894, 6.6949590761214495, 4.469738630577922, 1.2966580968350172, 0.047921974619384855, 0.03998130989202764, 0.022709878467139788, 2.3181513464078307, 28.97789865732193, 34.80851858854294, 17.952752262353897, 13.847461100667715, 26.353293992578983, 34.258950278162956, 44.21761929988861, 51.78861044347286, 55.79729653894901, 17.129068560898304, 0.1288147206651047, 0.09860246020252816, 0.02074593121506041, 0.04279641332686879, 0.022966520555200987, 0.058199565901304595, 0.027451858877611812, 0.012720410250040004, 0.06714872026350349, 0.04051787895150483, 0.022788323476561345, 0.051339442215976305, 0.06867757416330278, 0.12316974505665712, 0.04218955546093639, 0.019406419596634805, 0.059179423478781246, 0.024113519066304434, 0.08813816311885603, 0.04541662507108413, 0.03565696380974259, 0.03090154681558488, 0.03200622806616593, 0.04761364194564521, 0.027391227267798968, 0.07384085140074603, 0.08341821521753445, 0.11461251517175697, 0.010011432077590143, 0.02985790906677721, 0.03589635467506014, 0.02680687503016088, 0.06798834903747775, 0.04385726148029789, 0.04696286006947048, 0.011766779243771452, 0.044936911945114844, 0.046083730485406704, 0.06398812853149138, 0.028664160818152595, 0.10884237635764293, 0.07788272123434581, 0.015336466894950718, 0.8433176635298878, 43.44161354005337, 75.45166969299316, 60.54943174123764, 58.303953632712364, 40.456056743860245, 24.091761745512486, 26.184450052678585, 28.6283915117383, 41.64946250617504, 29.533463045954704, 0.5135028425138444, 0.0735014227393549, 0.07235992539790459, 0.7630760036408901, 3.6845903238281608, 6.612480226904154, 4.21374399214983, 3.3553318167105317, 15.023388750851154, 51.50718614459038, 63.78719240427017, 65.14342322945595, 62.66915179789066, 60.67398525774479, 61.738471537828445, 66.06295868754387, 60.55423468351364, 57.08469785749912, 57.607382610440254, 62.58601985871792, 62.61999003589153, 59.96587425470352, 58.82652439177036, 56.67202100157738, 57.62856267392635, 57.28603385388851, 58.5843063890934, 59.13386330008507, 57.049378752708435, 55.523217245936394, 56.19321249425411, 59.133946895599365, 56.29039607942104, 57.18690477311611, 55.90658627450466, 58.588246777653694, 56.15387320518494, 55.24355985224247, 52.916279733181, 59.09230872988701, 55.83133511245251, 57.78800591826439, 56.921257227659225, 59.700295105576515, 52.50000827014446, 54.05550420284271, 56.08939066529274, 56.980819031596184, 46.46145969629288, 41.42183572053909, 40.88742859661579, 46.068739369511604, 48.86014558374882, 54.78954881429672, 54.121586456894875, 64.60386738181114, 34.15004812180996, 40.659212842583656, 60.39317272603512, 54.145958349108696, 57.53257602453232, 46.6807497292757, 47.749073803424835, 51.34914502501488, 53.702465146780014, 52.6178627461195, 47.52762548625469, 43.84113550186157, 42.75440901517868, 44.94190223515034, 54.351804703474045, 56.72235690057278, 57.6438644528389, 57.88814574480057, 52.24251128733158, 43.09215009212494, 42.94471800327301, 48.21137599647045, 58.719130754470825, 57.59433031082153, 52.668460831046104, 52.665493190288544, 58.557650819420815, 55.7738745957613, 54.087688475847244, 48.26176129281521, 48.43161217868328, 48.50868724286556, 46.61055229604244, 46.85509957373142, 51.24574117362499, 53.49281519651413, 57.58458003401756, 60.480731427669525, 62.454926893115044, 62.797660902142525, 62.16730132699013, 59.46361340582371, 62.02448979020119, 62.76290416717529, 59.72272150218487, 49.7203054279089, 20.556750632822514, 3.9082242362201214, 3.048797990195453, 4.967032196000218, 7.864719657227397, 6.04633673094213, 0.33286466205026954, 0.07706273710937239, 0.056092467639246024, 2.954170717857778, 31.643142141401768, 36.84220366179943, 25.093085914850235, 15.162306446582079, 30.154520720243454, 43.23590397834778, 50.95042861998081, 56.513497307896614, 66.3120125234127, 21.69129755347967, 0.2835800003958866, 0.05964391886664089, 0.05033681183704175, 0.03443074660026468, 0.0408281300769886, 0.03604816098231822, 0.030190983088687062, 0.03641185045125894, 0.03993882935901638, 0.04033457960758824, 0.07923827623017132, 0.011886528482136782, 0.0373003682034323, 0.037232417162158526, 0.0632725571631454, 0.043192081939196214, 0.0708150930586271, 0.061568341188831255, 0.01839496508182492, 0.011314438379486091, 0.02124581405951176, 0.022464888097601943, 0.037244796185404994, 0.1727614999981597, 0.2212687916471623, 0.11835910670924932, 0.0925952274701558, 0.2200371233629994, 0.12155647185863927, 0.1294047577539459, 0.14279758441261947, 0.1953079761005938, 0.13995655404869467, 0.10368027913500555, 0.24733283993555233, 0.1556952204555273, 0.09262556646717712, 0.16599642316577956, 0.1427012833300978, 0.13121622148901224, 0.18355299514951184, 0.1763575171935372, 0.1430755335604772, 1.5733926161192358, 51.77738584578037, 86.405820697546, 67.06872671842575, 65.7557375729084, 43.35802182555199, 27.543222941458225, 27.156979367136955, 32.749648466706276, 60.91974467039108, 34.579653069376945, 0.798682764871046, 0.16423408960690722, 0.3578235040185973, 0.5478249164298177, 5.748946638777852, 13.55412919074297, 12.720601167529821, 11.210064422339201, 16.985392570495605, 53.368067890405655, 66.45857065916061, 68.37715610861778, 66.38467222452164, 63.03636409342289, 63.85348364710808, 67.71089226007462, 63.03332805633545, 56.272689029574394, 60.063437819480896, 65.14345362782478, 64.62144523859024, 62.77977526187897, 60.70774644613266, 59.8305407166481, 59.51364532113075, 59.90690901875496, 60.186722204089165, 61.30734667181969, 60.04495561122894, 57.13857516646385, 57.30113424360752, 60.4998330026865, 58.13429273664951, 60.17935439944267, 58.64446856081486, 61.007265374064445, 58.95227864384651, 57.46199481189251, 53.864040076732635, 60.59714958071709, 58.54304060339928, 60.2715640515089, 60.607591420412064, 61.554052233695984, 54.67308886349201, 56.28710925579071, 58.12292754650116, 57.88642443716526, 48.86875592172146, 43.134286031126976, 44.11246754229069, 48.07466693222523, 50.716475173830986, 57.85484813153744, 59.65205289423466, 67.34604343771935, 38.390894159674644, 42.17533528804779, 62.81816080212593, 56.99039451777935, 58.63638639450073, 50.008831545710564, 49.701325446367264, 54.85851131379604, 56.29585258662701, 55.698118060827255, 49.81058858335018, 46.31575271487236, 45.16487047076225, 46.73949457705021, 57.72864930331707, 59.41539779305458, 60.17956718802452, 60.68570002913475, 54.47667360305786, 45.991546511650085, 46.86074987053871, 51.487203016877174, 62.67991662025452, 59.7139135748148, 53.32744427025318, 54.15895365178585, 60.79459458589554, 58.59225936233997, 56.37484274804592, 49.82237935066223, 50.47678783535957, 51.17425560951233, 49.38816525042057, 49.2397528141737, 52.62414760887623, 56.368071511387825, 59.35253396630287, 63.263542503118515, 64.41690981388092, 65.67775055766106, 65.13872668147087, 61.36586353182793, 62.820075899362564, 65.97604975104332, 61.583998426795006, 53.163825049996376, 21.928891204297543, 6.037349263206124, 12.427576091140509, 14.947250336408615, 14.278584066778421, 5.553236240521073, 0.1774258239311166, 0.1845076642348431, 0.08934271332691424, 4.364025453105569, 41.204061806201935, 48.18084083497524, 27.034158557653427, 20.563806854188442, 38.88586699962616, 49.429442435503006, 58.7157641351223, 64.34095948934555, 74.50436532497406, 27.15285088866949, 0.5407609173562378, 0.2357814449351281, 0.15735213935840875, 0.14696952304802835, 0.08131165872327983, 0.20837409450905398, 0.09904304359224625, 0.11866930217365734, 0.1282946829451248, 0.12640925677260384, 0.272860627155751, 0.12763633858412504, 0.1525291145662777, 0.1549229267402552, 0.15254279976943508, 0.14965185255277902, 0.24776380509138107, 0.11358130097505637, 0.17869795410661027, 0.11819713297882117, 0.13343087921384722, 0.1552466070279479, 0.11987869860604405], [0.06718984266626649, 0.011240448111493606, 0.04809717713214923, 0.011818239763670135, 0.034706016595009714, 0.06494754736195318, 0.03170891628542449, 0.025055246951524168, 0.05307641658873763, 0.08680813800310716, 0.07803123240591958, 0.012619976332644, 0.061587792879436165, 0.032525315837119706, 0.03150310760247521, 0.04878104024101049, 0.07414269028231502, 0.054969980410533026, 0.09002615712233819, 0.0879731762688607, 2.725748112425208, 49.945789128541946, 58.18815104663372, 54.917354956269264, 45.707150772213936, 27.409287728369236, 19.428009800612926, 33.39491084218025, 41.418913677334785, 42.517187744379044, 10.128306169062853, 0.03908640595909674, 0.023262203321792185, 0.026611571447574534, 0.28019358054734766, 1.3954485207796097, 6.033443072810769, 1.6216294839978218, 6.986214397475123, 38.55963550508022, 66.02707341313362, 65.85242718458176, 60.97520649433136, 59.670238718390465, 55.207883566617966, 57.955725118517876, 60.9393136203289, 61.17103658616543, 58.049390092492104, 56.041391640901566, 58.05510498583317, 55.65995670855045, 54.66503709554672, 50.46824209392071, 51.22292719781399, 50.45515939593315, 51.58560253679752, 54.12990041077137, 56.58602021634579, 55.06879962980747, 53.40432174503803, 56.73104703426361, 56.132734939455986, 51.178625375032425, 51.104837134480476, 49.99281920492649, 51.52679689228535, 52.815182358026505, 56.96004934608936, 52.76643857359886, 55.556549057364464, 56.056784614920616, 55.01180648803711, 55.0268042832613, 54.495121613144875, 50.895103588700294, 52.295149862766266, 54.66814912855625, 53.451367020606995, 39.825712367892265, 41.3082218170166, 40.13472318649292, 46.19664050638676, 45.008546859025955, 53.24857950210571, 49.98733229935169, 63.489523977041245, 31.75574529916048, 38.878282606601715, 60.394191071391106, 51.504499688744545, 56.443953439593315, 45.44303074479103, 43.08737374842167, 45.23861691355705, 49.22884739935398, 50.4142127931118, 45.84764063358307, 39.87500712275505, 40.35736843943596, 41.91919483244419, 46.82431362569332, 51.94835007190704, 54.595732614398, 49.19410966336727, 44.67484496533871, 39.81264486908913, 40.4789999127388, 44.68977816402912, 56.08021415770054, 53.96509565412998, 53.41515116393566, 48.8380953669548, 55.64279302954674, 54.23256330192089, 53.574583008885384, 46.07192359864712, 42.85736829042435, 43.160044848918915, 42.42234103381634, 44.777291268110275, 48.89229565858841, 56.349232122302055, 57.379033863544464, 60.35824500024319, 56.58444330096245, 58.21050524711609, 60.10930895805359, 59.68936309218407, 57.94583044946194, 58.56983296573162, 58.39995928108692, 61.52111940085888, 46.71471610665321, 23.443894609808922, 2.433549016714096, 4.50128311291337, 3.7965995259582996, 3.554102713242173, 0.8242385904304683, 0.10322336107492447, 0.09701100614620373, 0.1330140742356889, 13.994450513273478, 35.510154739022255, 25.95455288887024, 21.77415780723095, 14.703141935169697, 23.393691703677177, 38.99375461041927, 49.944330006837845, 58.04435156285763, 38.134958893060684, 1.460008837748319, 0.2552688180003315, 0.009147850487352116, 0.0292211315172608, 0.06086105218855664, 0.044302453607087955, 0.04413812355778646, 0.041961022216128185, 0.02416367526166141, 0.10194567221333273, 0.034500085457693785, 0.06388655077898875, 0.056976732885232195, 0.08543897944036871, 0.027170262073923368, 0.010860563124879263, 0.05734773621952627, 0.02203036619903287, 0.04670239592087455, 0.13218631240306422, 0.026357204042142257, 0.027903466871066485, 0.009398597139806952, 0.03369108511833474, 0.026445862858963665, 0.016815194285300095, 0.02091002563247457, 0.08480197182507254, 0.029795394257234875, 0.048206413848674856, 0.007477734343410702, 0.04223664844175801, 0.02390021469182102, 0.0875849810836371, 0.028413127511157654, 0.04894188590697013, 0.030273550728452392, 0.044746484272764064, 0.04159572228672914, 0.04608170813298784, 0.02236437903775368, 0.1012611597252544, 0.26944271055981517, 5.011059483513236, 60.72447694838047, 67.39481762051582, 59.938435927033424, 51.896479055285454, 34.95427496731281, 27.952818162739277, 26.381290890276432, 37.586173340678215, 49.25128519535065, 11.439513210207224, 0.03162467139190994, 0.08542553172446787, 0.18535895214881748, 1.0519207105971873, 4.390403162688017, 4.2997034545987844, 3.2066764310002327, 7.817156659439206, 41.0166634619236, 66.86186581850052, 67.61173278093338, 63.162714913487434, 62.4723831564188, 58.230636566877365, 60.77308773994446, 63.01573880016804, 64.26108777523041, 56.798759400844574, 58.083991035819054, 60.14038369059563, 57.89214313030243, 56.161263808608055, 53.152976632118225, 53.68780553340912, 52.33757458627224, 53.84401135146618, 56.62903010845184, 57.94309079647064, 57.595721036195755, 54.53902445733547, 58.416742980480194, 57.77569837868214, 53.0244979262352, 52.56157636642456, 53.41127537190914, 53.76461461186409, 55.2328672260046, 57.40595921874046, 53.799409344792366, 56.131234019994736, 57.883794978260994, 57.55602836608887, 57.7739542722702, 55.84904596209526, 51.88311517238617, 52.524440959095955, 56.507117450237274, 54.8025631159544, 42.37727925181389, 43.02258722484112, 42.22416266798973, 47.14309372007847, 46.282382905483246, 52.867756336927414, 52.78555154800415, 65.39847314357758, 33.78359958529472, 40.673473477363586, 61.606120839715004, 54.15307156741619, 58.5535204410553, 47.989213317632675, 45.33507853746414, 49.46043737232685, 51.31362073123455, 50.89054763317108, 48.092852756381035, 42.00425706803799, 42.696838304400444, 43.010374680161476, 47.488157004117966, 55.20720340311527, 55.71791119873524, 51.945564821362495, 45.66718451678753, 43.22903394699097, 42.47507080435753, 47.686156779527664, 56.547387689352036, 56.51457644999027, 52.53885358572006, 50.40131628513336, 56.92130282521248, 56.090127825737, 55.76825089752674, 47.497014328837395, 44.79878291487694, 45.19489265978336, 44.98178489506245, 46.4182598143816, 50.572162717580795, 57.10684306919575, 61.01840637624264, 61.71703688800335, 57.82541871070862, 59.705782011151314, 61.70153371989727, 62.28253774344921, 60.63067138195038, 62.52144992351532, 61.35987885296345, 62.79001571238041, 50.782470032572746, 25.226916633546352, 5.251505356281996, 4.920469019562006, 10.696922857314348, 8.275653831660748, 4.134232783690095, 0.28420886665116996, 0.037897860165685415, 0.2263669899548404, 15.115317218005657, 37.39591754972935, 32.24212110042572, 24.023363515734673, 19.431549310684204, 33.54151077568531, 44.84832465648651, 57.144400253891945, 62.96444535255432, 50.71368992328644, 2.876935349777341, 0.16309510072460398, 0.003793275409407215, 0.03343767879414372, 0.084970958851045, 0.03484047520032618, 0.0116407495806925, 0.024113554318319075, 0.04731645261927042, 0.06067059854103718, 0.020860951117356308, 0.07277886033989489, 0.020962725538993254, 0.014880717717460357, 0.06335170721285976, 0.019109556815237738, 0.03364193638844881, 0.02164130641176598, 0.03441165856202133, 0.06765315803932026, 0.028432913168217055, 0.028922524688823614, 0.05669162201229483, 0.15734633576357737, 0.15082036406965926, 0.11513382938574068, 0.07608611529576592, 0.25911706150509417, 0.12301210546866059, 0.09527567934128456, 0.12628297292394564, 0.19180557341314852, 0.16113177873194218, 0.1523854793049395, 0.1480894981068559, 0.1444009054102935, 0.18595727160573006, 0.1779838596121408, 0.193763566785492, 0.1938456334755756, 0.13314533047378063, 0.20416924904566258, 0.3161202074261382, 6.83317475952208, 72.41755530238152, 73.98810982704163, 71.07194110751152, 60.951423570513725, 41.701747700572014, 29.42465778440237, 43.7884247303009, 55.73371835052967, 59.17766734957695, 16.001338474452496, 0.1800840039504692, 0.18813268456142396, 0.30185580253601074, 1.357295005582273, 5.699795801192522, 13.692673556506634, 7.614621352404356, 10.673829596489668, 42.794614657759666, 68.85812669992447, 69.4831171631813, 65.03879964351654, 65.4332260787487, 60.29126599431038, 63.327702060341835, 66.27625644207001, 64.30230796337128, 57.53917247056961, 56.59651145339012, 61.99643589556217, 62.212678492069244, 59.996474012732506, 54.55180697143078, 54.78667236864567, 53.786117658019066, 55.10110929608345, 58.82660798728466, 59.838877469301224, 60.952160730957985, 56.246200650930405, 62.28004887700081, 62.08997927606106, 54.64924894273281, 55.74722662568092, 54.7886748611927, 56.714981496334076, 57.414227575063705, 61.65392607450485, 55.25849685072899, 56.29748649895191, 60.30888184905052, 59.608910009264946, 59.346765875816345, 56.602207347750664, 53.394522070884705, 55.10658100247383, 57.83628232777119, 58.80499854683876, 43.62076632678509, 46.97991147637367, 46.30500689148903, 51.08408644795418, 49.49413016438484, 55.95842309296131, 54.89301346242428, 68.81805405020714, 37.054521068930626, 43.03564712405205, 63.27027954161167, 55.4573667794466, 59.54002730548382, 50.02073630690575, 45.752683728933334, 51.3857788592577, 53.4211016446352, 55.51466390490532, 50.124759525060654, 44.153934717178345, 44.32073436677456, 46.22784823179245, 50.1839679479599, 57.28419095277786, 59.370579198002815, 53.66543233394623, 48.61373260617256, 45.484779104590416, 45.02476818859577, 49.90730479359627, 59.51828107237816, 59.44494120776653, 54.79638084769249, 50.745665207505226, 59.63584676384926, 59.32499684393406, 59.1766832023859, 50.740098506212234, 48.0039869248867, 47.86773383617401, 46.529837027192116, 49.392166435718536, 53.00093159079552, 62.03943818807602, 62.60398909449577, 66.16394206881523, 60.39227217435837, 61.234147399663925, 63.970730155706406, 63.984553813934326, 64.2963194847107, 66.1936716735363, 63.76250892877579, 65.16939103603363, 53.78992885351181, 28.417215943336487, 7.42058951407671, 12.032365947961807, 15.98893404006958, 9.603631272912025, 2.952023595571518, 0.39170328760519624, 0.2369508915580809, 0.3169459803029895, 19.915516041219234, 50.73824420571327, 36.62046276032925, 31.275933645665646, 22.844712361693382, 35.790032520890236, 54.617988020181656, 63.450146690011024, 71.1864897608757, 56.827007085084915, 4.387352876365185, 0.41551637230440974, 0.13194011233281344, 0.11033352915546857, 0.09353581801406108, 0.13281801366247237, 0.1191168840159662, 0.25109147652983665, 0.1262952183606103, 0.16714327881345525, 0.12264684264664538, 0.1954087449121289, 0.11324973907903768, 0.1686524657998234, 0.08821447816444561, 0.17202040617121384, 0.2572958904784173, 0.09970495768357068, 0.1205920657957904, 0.2494373481022194, 0.11604558749240823, 0.14108028437476605, 0.1258623829926364], [0.0239214215616812, 0.023085041539161466, 0.12944468529894948, 0.04247198347002268, 0.07554960931884125, 0.04573597863782197, 0.05054261680925265, 0.03662614559289068, 0.03607316764828283, 0.03333457963890396, 0.05281039004330523, 0.055459682844229974, 0.03612194901506882, 0.09359919742564671, 0.01979132335691247, 0.038452689768746495, 0.04525509662926197, 0.061257462948560715, 0.05487504487973638, 0.041819468679022975, 13.140805419534445, 60.31338460743427, 54.9970480799675, 58.03937003016472, 40.66215768456459, 22.51189962029457, 24.09815300256014, 46.9045577198267, 41.86931870877743, 29.51009999960661, 2.359460829757154, 0.1190749897796195, 0.07426469193887897, 0.25907244358677417, 1.210322454571724, 3.5004685912281275, 2.9165363498032093, 3.890035324729979, 25.38404580205679, 56.13613195717335, 64.48351263999939, 60.03687344491482, 60.43952263891697, 53.80960039794445, 50.124371945858, 54.18923042714596, 60.77659495174885, 60.4787403345108, 61.19462192058563, 56.79271012544632, 60.07533498108387, 55.647557973861694, 53.70214596390724, 46.57153598964214, 45.946765914559364, 47.41676263511181, 50.30960060656071, 50.912768840789795, 54.290791377425194, 54.93943177163601, 55.92567265033722, 56.625686287879944, 53.92640992999077, 48.33111137151718, 43.467987924814224, 45.8522117882967, 51.69526845216751, 51.22194305062294, 54.66974124312401, 53.15755158662796, 55.50239056348801, 54.93986114859581, 55.456606820225716, 56.43762677907944, 53.283765614032745, 50.365260019898415, 54.34634819626808, 54.79177549481392, 47.85376198589802, 39.287353456020355, 40.63191890716553, 40.861449390649796, 47.4799532443285, 43.0666496604681, 52.153246477246284, 51.11638851463795, 62.21814639866352, 31.952569037675858, 39.836705178022385, 60.11178642511368, 50.21913506090641, 57.780816704034805, 47.97234982252121, 41.4253581315279, 43.2045366615057, 49.491705894470215, 47.590227127075195, 44.738753736019135, 40.50205707550049, 41.21238715946674, 39.20787312090397, 42.78330646455288, 44.11404065787792, 43.137052282691, 43.09560410678387, 42.54923142492771, 40.25096274912357, 39.64869886636734, 43.84909987449646, 53.69765840470791, 57.12320879101753, 53.62421974539757, 48.28359492123127, 54.6247136592865, 56.06879197061062, 53.74786131083965, 47.02851086854935, 42.736918553709984, 43.12124893069267, 43.7654397636652, 42.611369490623474, 50.13403482735157, 52.620287016034126, 57.243324145674706, 59.24186110496521, 54.14073742926121, 57.934723645448685, 59.41657952964306, 55.42870111763477, 59.066907092928886, 57.50608764588833, 56.94065138697624, 57.42649331688881, 58.81657272577286, 42.582977414131165, 17.187560722231865, 2.667757999151945, 8.771953750401735, 11.062953416258097, 2.99579962156713, 0.2665766252903268, 0.05184872621612158, 0.08049517753534019, 1.6440184763632715, 32.11097493767738, 29.778698086738586, 19.390919990837574, 15.535932797938585, 26.76163338124752, 39.82508160173893, 46.54736548662186, 55.18687069416046, 57.33088284730911, 15.353646129369736, 0.2551361219957471, 0.1080504157289397, 0.07623347613844089, 0.08720160985831171, 0.06555698419106193, 0.03546412415744271, 0.013946312046755338, 0.023228728750837035, 0.02120187520631589, 0.04459019910427742, 0.04796273336978629, 0.0548296922352165, 0.027213410539843608, 0.06404174127965234, 0.08469318781862967, 0.008203297802538145, 0.053159277376835234, 0.06712075613904744, 0.029078208717692178, 0.09654929381213151, 0.011815677498816513, 0.07992060680408031, 0.03243671453674324, 0.005108759069116786, 0.06050290656276047, 0.1255402760580182, 0.10878668559598736, 0.05507948430022225, 0.0334440798178548, 0.04674106923630461, 0.009585560837876983, 0.06973846684559248, 0.027231312997173518, 0.04783969641721342, 0.09600023069651797, 0.058333360284450464, 0.04183168442978058, 0.03153190664306749, 0.044149378227302805, 0.09016182913910598, 0.07737580468528904, 0.04716950737929437, 18.708149828016758, 72.58275523781776, 62.26643040776253, 67.88566768169403, 46.85457520186901, 27.304059974849224, 25.493854209780693, 47.55380228161812, 43.43303360044956, 32.846854850649834, 3.18492426071316, 0.10533856358961202, 0.27458416123408824, 0.47359509801026434, 3.098997096531093, 7.303147315979004, 4.323760438710451, 3.9703810634091496, 27.345751337707043, 58.71657349169254, 65.97806364297867, 62.028517574071884, 62.60042868554592, 56.66469119489193, 53.98832380771637, 56.6407410800457, 61.71637572348118, 62.73307576775551, 60.34158669412136, 57.611360996961594, 61.48368000984192, 57.26589493453503, 54.49156120419502, 48.55773501098156, 47.12161727249622, 49.8170330375433, 53.30075070261955, 53.23188699781895, 55.76168105006218, 57.33746029436588, 59.283807054162025, 58.84874179959297, 56.67704053223133, 51.05811484158039, 46.10626995563507, 49.408209174871445, 53.486963510513306, 53.430521339178085, 56.20514005422592, 55.47987297177315, 56.914740577340126, 57.316367626190186, 56.262220591306686, 56.46133370697498, 54.68941658735275, 52.516784369945526, 57.20089562237263, 56.54895320534706, 51.113755255937576, 41.838669553399086, 42.43912473320961, 42.06179738044739, 49.28499698638916, 46.229755729436874, 54.20671708881855, 53.64506922662258, 63.67441825568676, 33.11680756509304, 40.760192424058914, 60.85735581815243, 53.359373956918716, 59.4924196600914, 50.08366473019123, 43.578694984316826, 47.25035436451435, 50.47261945903301, 50.01148760318756, 48.04479293525219, 43.49131867289543, 42.20388315618038, 40.83947516977787, 44.87251415848732, 46.154500767588615, 46.494704112410545, 44.676019102334976, 44.60173688828945, 42.69999973475933, 41.25494107604027, 44.64317746460438, 54.267209842801094, 59.05164331197739, 56.33825071156025, 47.84382551908493, 57.00483374297619, 57.97656700015068, 56.37707322835922, 49.58212584257126, 43.08710016310215, 44.89351183176041, 45.11985808610916, 45.82850106060505, 50.65912485122681, 54.85595025122166, 60.1328980922699, 60.85313804447651, 56.253617852926254, 58.95314119756222, 61.81263215839863, 57.92238190770149, 60.6972324103117, 59.58679899573326, 59.676789566874504, 59.73220579326153, 61.64657346904278, 46.08725197613239, 16.91419579088688, 2.96918204985559, 8.054346106946468, 12.825935315340757, 7.008580947294831, 1.759549139533192, 0.2008683542953804, 0.12396218808135018, 2.280165022239089, 33.48368547856808, 31.140900291502476, 20.177430287003517, 20.136344991624355, 35.208686515688896, 44.606182649731636, 52.535923942923546, 61.27170078456402, 65.88679254055023, 20.895996429026127, 0.2576065534958616, 0.10089332907227799, 0.03344796125020366, 0.04950357666530181, 0.024733164136705454, 0.036128183055552654, 0.029439762656693347, 0.03805675027251709, 0.06705480889650062, 0.06077812460716814, 0.030707473342772573, 0.053743681564810686, 0.023778174072504044, 0.0686308262811508, 0.08193705914891325, 0.034573988523334265, 0.03820228543190751, 0.04743111443531234, 0.05937562877079472, 0.037386464755400084, 0.024924961071519647, 0.05991207166516688, 0.2013437740970403, 0.10553803804214112, 0.22969212324824184, 0.1953181583667174, 0.2945371874375269, 0.14842350909020752, 0.1256851284415461, 0.08751204280997626, 0.09087523343623616, 0.15858156635658816, 0.13198446307796985, 0.0936293879931327, 0.13655830436619, 0.1381638369639404, 0.17585776979103684, 0.1954174428828992, 0.1607401028741151, 0.2632755524246022, 0.1302114871214144, 0.11875574011355639, 24.894227385520935, 83.88487637042999, 69.9699318408966, 75.99808797240257, 53.28767940402031, 33.22354383766651, 33.05234782397747, 62.320322915911674, 56.56993567943573, 42.11914390325546, 3.7686430010944605, 0.2646584704052657, 0.3787219076184556, 0.5413390800822526, 4.524862747639418, 13.440205603837967, 10.713408272713423, 9.208452478051186, 30.197834596037865, 59.212177097797394, 68.00194144248962, 64.24913361668587, 64.98428776860237, 59.664390832185745, 56.30482390522957, 58.06863605976105, 63.95338788628578, 65.95688357949257, 60.60261368751526, 58.540544137358665, 63.45360070466995, 59.42981421947479, 57.18482628464699, 51.03345416486263, 50.10437361896038, 51.68220095336437, 55.05119137465954, 55.994365364313126, 58.37521880865097, 58.80170412361622, 61.60906568169594, 62.66587637364864, 61.07481434941292, 52.77431175112724, 47.45770923793316, 51.62493422627449, 55.201784893870354, 57.40742973983288, 58.354943096637726, 57.70319066941738, 57.25248545408249, 57.66382098197937, 58.48179928958416, 59.25873979926109, 56.55242241919041, 53.645612597465515, 60.18321119248867, 58.02285611629486, 54.823834374547005, 43.88047859072685, 45.30526153743267, 44.93693210184574, 51.350136771798134, 48.09289835393429, 55.86141809821129, 56.1469803750515, 67.59933024644852, 36.20029650628567, 43.712535202503204, 64.3460664153099, 55.81301249563694, 62.699466571211815, 53.036216497421265, 46.41342647373676, 49.37655687332153, 53.08421552181244, 52.59243831038475, 48.43761965632439, 46.20494306087494, 44.74046744406223, 43.39020989835262, 46.65165849030018, 47.55200497806072, 46.835283637046814, 47.11821265518665, 46.481370627880096, 44.34044010937214, 43.8180061429739, 48.20563070476055, 58.639004454016685, 62.690943628549576, 57.10413761436939, 48.534354865550995, 58.22236821055412, 60.847415551543236, 59.84406419098377, 52.618322521448135, 46.40297323465347, 47.65067808330059, 47.07054801285267, 48.07057835161686, 54.372752979397774, 56.65278643369675, 61.356052458286285, 64.02784869074821, 58.794317319989204, 62.579902186989784, 64.95372980833054, 58.88515904545784, 66.16076543927193, 61.97166882455349, 62.89070650935173, 62.39818453788757, 62.800096571445465, 47.894423604011536, 21.346743442118168, 7.253773240372539, 20.479650869965553, 22.973065674304962, 7.897260161116719, 1.032820560503751, 0.26303954946342856, 0.215247287414968, 2.91062006726861, 46.99411131441593, 43.37597966194153, 29.385664276778698, 22.964174151420593, 40.26493079960346, 51.203134059906006, 59.53505337238312, 68.76258462667465, 74.05177161097527, 25.343454480171204, 0.3479388984851539, 0.2633867261465639, 0.1264545277808793, 0.15633039496606216, 0.21175782778300345, 0.1240903718280606, 0.1409429870545864, 0.1445887133013457, 0.16651402664138004, 0.1539703505113721, 0.17259318090509623, 0.1672084690653719, 0.1655577842029743, 0.2067910341429524, 0.16025000339141116, 0.0995245786907617, 0.13240043685073033, 0.1919704192550853, 0.1206887379521504, 0.2642547420691699, 0.08748634965741076, 0.19616962439613417], [0.03975825740781147, 0.06247758341487497, 0.052085757051827386, 0.060299376273178495, 0.06580932924407534, 0.017518189961265307, 0.030162098701111972, 0.0260007820543251, 0.03713802339916583, 0.02261407091282308, 0.044868667755508795, 0.028259571590751875, 0.0696870285901241, 0.03697359687066637, 0.028030938156007323, 0.07876411065808497, 0.01714479505608324, 0.04941526109178085, 0.0988587163737975, 0.28494599740952253, 29.34915203601122, 60.57814300060272, 62.4841283261776, 46.887610629200935, 37.46986158192158, 24.2476711794734, 41.09770551323891, 41.64233788847923, 39.691347777843475, 20.84651168435812, 0.059338432329241186, 0.16010190040105954, 0.05107702250825241, 0.08449812914477661, 1.1351263895630836, 4.029556475579739, 1.7378304549492896, 17.333083413541317, 47.79241807758808, 68.06314095854759, 61.32886491715908, 62.4821600317955, 56.18118993937969, 54.358047768473625, 46.88753843307495, 53.27745795249939, 57.25364439189434, 59.488308280706406, 57.2633870691061, 58.29322300851345, 58.503807708621025, 54.35597687959671, 49.277644380927086, 44.92587469518185, 44.016157910227776, 43.632845878601074, 45.91150380671024, 48.782751336693764, 51.90176457166672, 54.81545202434063, 56.95920579135418, 54.270082488656044, 51.13431975245476, 42.715609297156334, 40.340558141469955, 42.24366322159767, 45.37762485444546, 50.778069868683815, 53.60739424824715, 53.83023329079151, 53.200895860791206, 51.15483485162258, 51.84250295162201, 49.771017506718636, 52.72322729229927, 49.74214285612106, 54.87225517630577, 52.0051684230566, 42.73769751191139, 39.64715614914894, 41.64803758263588, 41.8574633449316, 47.090876922011375, 41.40908360481262, 50.67312330007553, 51.15606978535652, 61.31952881813049, 31.47369023412466, 38.30211192369461, 58.497857227921486, 50.13625010848045, 53.93442749977112, 48.31134483218193, 41.721043065190315, 41.669050455093384, 47.97881327569485, 44.837411642074585, 45.7585734128952, 40.44902712106705, 40.11306054890156, 38.943582102656364, 41.6152985394001, 41.25527165830135, 40.69306902587414, 39.598408564925194, 41.49859540164471, 39.98665653169155, 39.57605056464672, 40.37029914557934, 46.85450680553913, 54.783161357045174, 55.500726252794266, 51.816652938723564, 51.474177315831184, 55.02023823559284, 54.097199365496635, 48.01644645631313, 41.72016151249409, 42.38197959959507, 43.405287489295006, 40.98928213119507, 46.50213271379471, 53.13228294253349, 58.03871646523476, 57.767832800745964, 57.29989930987358, 56.518258452415466, 55.597993433475494, 54.88615483045578, 53.31240467727184, 53.82380783557892, 54.8186856508255, 55.03947280347347, 59.95201259851456, 53.40282462537289, 24.212870746850967, 8.650377374142408, 4.882422611117363, 10.58882625773549, 8.232134766876698, 1.3655142020434141, 0.1470206124940887, 0.14481713151326403, 0.028995052925893106, 12.541200444102287, 40.15724457800388, 42.48367354273796, 16.552635692059994, 27.99580715596676, 43.70838202536106, 41.039675027132034, 47.41003319621086, 54.22193147242069, 34.39371384680271, 1.378822869155556, 0.06836007596575655, 0.020127831667196006, 0.02637387082359055, 0.016542310295335483, 0.039700551715213805, 0.051776611726381816, 0.026220938307233155, 0.03930999278964009, 0.03589154926885385, 0.005893873385502957, 0.07004311104537919, 0.04587968440318946, 0.040618785060360096, 0.005849447497894289, 0.08527464568032883, 0.036353406321723014, 0.09315108123701066, 0.05003972641134169, 0.06079026614315808, 0.032391725544584915, 0.0273119658959331, 0.013550408730225172, 0.052126059381407686, 0.04600085856509395, 0.007162074352891068, 0.013841351956216386, 0.015981810684024822, 0.07016883086180314, 0.028425408199836966, 0.019654022325994447, 0.0253106422314886, 0.04956120072165504, 0.029503219993785024, 0.029838026930519845, 0.08767743041971698, 0.052489967783913016, 0.03304436650068965, 0.03068767469812883, 0.023318075909628533, 0.15061539772432297, 0.3160003654193133, 34.88219663500786, 69.01966363191605, 66.33958384394646, 53.287838995456696, 41.78642235696316, 27.757362350821495, 33.64550739526749, 39.08996544778347, 43.22681866586208, 23.45663722604513, 0.0906120975560043, 0.2222914414596744, 0.0888544914778322, 1.3990241289138794, 4.517621761187911, 5.64243265427649, 1.224753011483699, 14.88586938008666, 52.09225594997406, 70.76335206627846, 64.12126287817955, 64.940065741539, 59.00617115199566, 55.30144974589348, 50.26329629123211, 55.40938675403595, 58.795791640877724, 61.49966575205326, 58.474625274538994, 58.84103961288929, 59.712625443935394, 56.602370738983154, 52.05667465925217, 45.48706658184528, 46.9458083063364, 45.912218168377876, 47.98693723976612, 52.56827540695667, 54.36848200857639, 56.92004129290581, 60.47019079327583, 57.59543985128403, 53.93584482371807, 44.118433222174644, 41.73047415912151, 43.6751414090395, 48.62258233129978, 53.49960923194885, 55.18385745584965, 55.056298300623894, 54.87884022295475, 51.02964676916599, 53.182227462530136, 51.576737612485886, 53.827611431479454, 52.21965931355953, 57.13840797543526, 55.26229664683342, 44.89357642829418, 40.73007524013519, 42.93521471321583, 43.5338269919157, 48.66278037428856, 42.97516576945782, 52.886952906847, 53.2602296769619, 63.887362629175186, 33.274955078959465, 39.11397635936737, 58.575042486190796, 54.57990266382694, 56.885128766298294, 49.863071367144585, 43.28560151159763, 41.80253729224205, 50.43185904622078, 48.75783607363701, 46.73730209469795, 42.31081321835518, 44.15122166275978, 40.88110573589802, 43.21921907365322, 42.22376748919487, 42.839315459132195, 41.36917434632778, 43.107866048812866, 39.80032593011856, 41.79789014160633, 42.95810468494892, 49.8228657245636, 56.76021806895733, 58.79453390836716, 52.54855066537857, 52.06014007329941, 58.2390721142292, 55.22785909473896, 51.1818628013134, 43.91801297664642, 44.852949008345604, 44.86059419810772, 44.2763527482748, 48.080264031887054, 56.78470775485039, 58.928476721048355, 60.681904032826424, 59.810785576701164, 59.2823251336813, 57.10424400866032, 60.00419519841671, 56.681664884090424, 56.92217297852039, 56.57047525048256, 59.452198818325996, 61.00157707929611, 57.606003284454346, 26.321172416210175, 8.115121945738792, 4.954992542043328, 8.201032485812902, 8.892792016267776, 6.109277028590441, 0.10886481148190796, 0.11721107846824452, 0.13233578094514087, 15.947090685367584, 37.32195071876049, 36.98055423796177, 18.617963567376137, 33.51941876113415, 50.22041939198971, 47.677770629525185, 53.80931921303272, 59.550811126828194, 46.87273442745209, 0.7829042302910239, 0.08279058092739433, 0.048749239213066176, 0.04235166277794633, 0.021762513970315922, 0.0388075291266432, 0.061315506318351254, 0.014165195516397944, 0.06336727004963905, 0.05813554824271705, 0.015865412242419552, 0.04566346338833682, 0.04586849652696401, 0.051768923076451756, 0.019131149601889774, 0.03060335002373904, 0.01157569940914982, 0.09154334446066059, 0.05186171751120128, 0.047189074102789164, 0.04555479812552221, 0.020219164071022533, 0.11499144835397601, 0.14354299753904343, 0.18166871188441291, 0.1394051976967603, 0.09873301140032709, 0.08353822049684823, 0.15823468653252348, 0.20690354373073205, 0.11969918792601675, 0.091319987695897, 0.15845801361138, 0.08804678247543052, 0.16465003369376063, 0.16517814598046243, 0.1368321420159191, 0.20860338845523074, 0.09289474342949688, 0.2002888557035476, 0.24544212967157364, 0.6881793506909162, 41.84393607079983, 76.81150272488594, 77.46989339590073, 62.726376727223396, 50.00981569290161, 35.09382627904415, 54.90761607885361, 53.37469473481178, 54.20314148068428, 27.443791776895523, 0.365360637078993, 0.462355301133357, 0.2222826989600435, 1.1065712780691683, 7.160396575927734, 12.208495046943426, 8.007077593356371, 22.707433328032494, 51.838159784674644, 73.20451587438583, 64.22972425818443, 67.96343430876732, 62.488387897610664, 59.208894073963165, 52.5032988935709, 59.02505233883858, 61.17844618856907, 64.43967819213867, 57.985325530171394, 58.95088031888008, 61.79812453687191, 59.16906461119652, 53.59564907848835, 48.46879318356514, 50.24523586034775, 49.12675827741623, 50.9099417924881, 55.49078978598118, 56.95748828351498, 59.4758715480566, 62.28584736585617, 59.33040015399456, 56.05109252035618, 47.24744372069836, 44.705053344368935, 46.29986956715584, 51.04807198047638, 56.263641715049744, 57.27560721337795, 56.767737865448, 55.46524755656719, 53.13121899962425, 52.65789359807968, 51.97603918612003, 55.18515318632126, 55.64571887254715, 59.80427272617817, 59.06759485602379, 47.1085649728775, 43.776789754629135, 46.40100494027138, 46.70958258211613, 52.11790457367897, 46.487165316939354, 53.5833453387022, 56.901893466711044, 65.17333522439003, 36.377268210053444, 41.81493982672691, 60.236054956912994, 56.96639120578766, 58.608777076005936, 51.74904316663742, 46.04080706834793, 44.71394866704941, 54.08082224428654, 50.516062527894974, 50.95603711903095, 44.81486365199089, 45.81728786230087, 43.68796192109585, 45.919582173228264, 45.05192153155804, 46.28160774707794, 44.38606806099415, 46.86294995248318, 42.307313606143, 43.08106608688831, 45.143287628889084, 51.44827790558338, 59.56437639892101, 61.02481663227081, 53.46405453979969, 53.70325170457363, 61.140056848526, 57.621111273765564, 52.43101917207241, 48.062161803245544, 47.612041756510735, 47.42443822324276, 45.58277204632759, 49.5019805431366, 58.70936527848244, 62.12494499981403, 63.735503777861595, 61.88468389213085, 61.13474853336811, 61.502534598112106, 61.248176246881485, 58.931942135095596, 61.22901767492294, 61.59569039940834, 61.7829367518425, 64.45816799998283, 58.81352908909321, 28.58902372419834, 12.905690185725689, 12.416448388248682, 18.042239360511303, 17.553847767412663, 4.527653697878122, 0.19079822668572888, 0.4199050477473065, 0.10759072203654796, 21.084608808159828, 59.30086053907871, 54.109685495495796, 23.797522634267807, 35.46855077147484, 53.57380785048008, 55.84689907729626, 60.57622790336609, 67.27700114250183, 55.35585142672062, 2.7147921128198504, 0.2369674711371772, 0.18370384408626705, 0.11576450648135506, 0.12780335149727762, 0.09615409275284037, 0.14312485669506714, 0.08596675033913925, 0.15892388939391822, 0.19504534488078207, 0.07310704546398483, 0.24442020716378465, 0.1075532435788773, 0.08597733336500823, 0.16540328389964998, 0.1926546497270465, 0.12156007869634777, 0.24337443202966824, 0.1282799438922666, 0.13853863638360053, 0.13683613477041945, 0.2318463849951513], [0.04782699455972761, 0.030673826222482603, 0.05279653785692062, 0.02818148652295349, 0.015695709043939132, 0.039934335654834285, 0.07457160711055622, 0.05283931895974092, 0.024337111462955363, 0.02340619481401518, 0.04034278405015357, 0.02734252753725741, 0.12774292583344504, 0.03366955541423522, 0.015728805119579192, 0.0282747039818787, 0.036968784042983316, 0.013264617864479078, 0.05319399504514877, 1.0503171966411173, 35.50985835492611, 62.16295816004276, 61.23955450952053, 47.32149034738541, 31.114940084517002, 20.970666222274303, 32.86429211497307, 52.02747322618961, 37.58599855005741, 4.890670068562031, 0.09426317468751222, 0.02702782538108295, 0.027641050874080975, 1.0143198282457888, 3.1554406927898526, 6.4841587375849485, 3.6007884331047535, 25.653747729957104, 61.285076066851616, 62.48606242239475, 59.94800381362438, 56.56294025480747, 54.76596347987652, 50.259819477796555, 44.169472083449364, 50.073884055018425, 57.58134260773659, 60.253610014915466, 59.20649640262127, 57.83763125538826, 57.46604159474373, 57.45412923395634, 49.28780123591423, 41.651780381798744, 42.102671787142754, 41.815069019794464, 43.633833825588226, 44.96342808008194, 48.549660444259644, 50.325574949383736, 55.21936655044556, 52.56345346570015, 46.728798151016235, 38.206398859620094, 39.86571662127972, 38.29863891005516, 44.01067480444908, 49.538234397768974, 52.994369342923164, 53.56548249721527, 55.643169209361076, 54.25182066857815, 51.390680596232414, 49.48358952999115, 51.69719114899635, 51.86134234070778, 54.945971220731735, 45.32718636095524, 40.57861156761646, 39.823652878403664, 40.431840643286705, 40.43435990810394, 43.35424482822418, 43.81888769567013, 50.78203305602074, 50.09735159575939, 63.97172570228577, 34.683824479579926, 37.67437040805817, 57.31221064925194, 49.06076341867447, 54.46867123246193, 46.87941826879978, 43.5270481556654, 40.109576135873795, 43.850767984986305, 44.04925033450127, 42.91180416941643, 41.003633961081505, 42.1754302829504, 39.31546434760094, 40.26243433356285, 41.412875801324844, 41.479429230093956, 40.51438741385937, 41.30631431937218, 39.801161885261536, 39.32967558503151, 41.62113502621651, 46.67197220027447, 51.84471823275089, 57.127035185694695, 52.61413894593716, 50.448114573955536, 55.74494294822216, 52.746178060770035, 50.14146342873573, 44.79739598929882, 43.81247363984585, 40.52434287965298, 42.90695562958717, 40.7913963496685, 45.21076820790768, 52.33406737446785, 56.71910807490349, 54.87311013042927, 55.43826520442963, 51.52004085481167, 51.013330444693565, 47.57077977061272, 50.740869864821434, 50.48567935824394, 57.943968549370766, 55.09782247245312, 61.40028588473797, 38.287281319499016, 13.067807536572218, 4.648806871846318, 8.166823871433735, 9.23455422744155, 5.341142071411014, 0.3704391833161935, 0.08759715972701088, 0.02478422760759713, 2.4008717201650143, 24.15250338613987, 43.572581112384796, 38.71745623648167, 21.025618873536587, 19.67631507664919, 29.05138861387968, 43.54407124221325, 49.12633650004864, 54.4864808768034, 11.148743312805891, 0.18980297696543857, 0.1057471901003737, 0.06932927630259655, 0.008321051591337891, 0.08040955595788546, 0.03200616127287503, 0.03321631840663031, 0.024977917018986773, 0.02171362499211682, 0.16612715990049765, 0.0903049077896867, 0.038540971945622005, 0.013774268300039694, 0.04862722642428707, 0.00701074905009591, 0.022801711820648052, 0.02436689941532677, 0.015920512996672187, 0.045296931493794546, 0.030429041798925027, 0.08448210617643781, 0.05939960014075041, 0.011787282001023414, 0.05346208105038386, 0.052954722923459485, 0.026621581164363306, 0.05271992595226038, 0.06326846792944707, 0.04343091248301789, 0.016249015388893895, 0.03616520138166379, 0.040386745167779736, 0.0585910784866428, 0.10734960567788221, 0.035335725187906064, 0.024059238385234494, 0.03950984944822267, 0.03151940516545437, 0.04181696021987591, 0.020865765800408553, 1.4488380309194326, 46.29826605319977, 70.29134139418602, 66.5597516298294, 55.793097764253616, 39.66071382164955, 29.559161067008972, 36.72003261744976, 49.33970645070076, 41.12982898950577, 6.148025449365377, 0.09066084181540646, 0.0637138010642957, 0.39822655788157135, 2.909467304125428, 5.846186745911837, 6.062491089105606, 4.064938277006149, 29.377333223819733, 62.66171559691429, 64.98377099633217, 62.668346241116524, 60.51084861159325, 57.20767445862293, 52.5399175286293, 46.10640674829483, 52.80718758702278, 59.621411338448524, 61.80815979838371, 58.616057485342026, 59.71333980560303, 60.23155219852924, 59.719373881816864, 51.89571909606457, 43.6450470238924, 44.46944318711758, 43.613938093185425, 46.350220665335655, 47.02727973461151, 51.78664594888687, 53.481389209628105, 55.846313908696175, 54.304770827293396, 49.287797436118126, 40.49551002681255, 42.625022158026695, 40.808446034789085, 47.39597015082836, 51.20583191514015, 54.87428806722164, 55.18766485154629, 57.52770848572254, 53.654606714844704, 52.81295947730541, 49.539872109889984, 52.99313820898533, 55.16179583966732, 57.17422105371952, 47.254507541656494, 43.09315703809261, 41.79397635161877, 43.30338075757027, 43.63486737012863, 46.161188408732414, 45.9818684309721, 54.20175075531006, 53.3169986307621, 64.02647316455841, 36.48761808872223, 38.27818840742111, 57.5556293874979, 52.88593836128712, 57.173092514276505, 50.58987736701965, 45.53429424762726, 40.9596399217844, 47.094186544418335, 46.61787450313568, 45.38140185177326, 44.13878493010998, 44.42502737045288, 42.37972252070904, 42.43984669446945, 44.356361255049706, 44.31791111826897, 41.85735695064068, 44.88414913415909, 42.3917830735445, 41.64326123893261, 41.77355244755745, 48.525060564279556, 55.51376335322857, 58.04326482117176, 54.877267107367516, 52.03756168484688, 56.57769866287708, 55.6901840865612, 52.4051121622324, 47.10063859820366, 45.46927593648434, 40.027485340833664, 44.252197444438934, 43.35410803556442, 47.10394062101841, 54.917157366871834, 59.642086029052734, 57.1063718944788, 58.57035733759403, 54.75904405117035, 52.83411294221878, 50.7290069013834, 53.59859012067318, 53.70080083608627, 60.05313657224178, 57.755209878087044, 62.49257527291775, 40.04365727305412, 15.553676895797253, 5.858191251754761, 7.254505651071668, 7.123511955142021, 9.389981087297201, 1.0421796957962215, 0.24463802750688046, 0.04795489257958252, 3.054041708819568, 29.541140533983707, 38.83873052895069, 26.90030314028263, 17.395413368940353, 30.66142112016678, 34.67218570411205, 51.75669215619564, 53.37912529706955, 64.33918878436089, 18.467314951121807, 0.29847309342585504, 0.10454468821990304, 0.046742486738367006, 0.056567438441561535, 0.07576482472359203, 0.0658508152991999, 0.03728054914972745, 0.030649925356556196, 0.02859208529116586, 0.08030590019188821, 0.09582477214280516, 0.015094594473339384, 0.029710930430155713, 0.088766183325788, 0.03553368565917481, 0.049703284894349054, 0.006173081401357194, 0.008646506539662369, 0.037615855180774815, 0.03106769512669416, 0.034852368116844445, 0.1674194764927961, 0.06633015364059247, 0.1180609266157262, 0.14475686912192032, 0.1741004828363657, 0.20684996066847816, 0.23566991498228163, 0.15022318752016872, 0.13723543990636244, 0.1234082861628849, 0.14945411472581327, 0.2120932933758013, 0.2316389250336215, 0.21265487652271986, 0.11369514642865397, 0.12067556483088993, 0.19793995830696076, 0.17309677263256162, 0.1621524544316344, 2.5944376084953547, 56.590169593691826, 80.38078039884567, 75.0851109623909, 65.05638509988785, 45.13871647417545, 31.66459769010544, 43.88492435216904, 67.12934106588364, 54.03964385390282, 8.039825186133385, 0.16403295274358243, 0.14176414377288893, 0.6968774402048439, 4.718088079243898, 11.247658655047417, 17.569643519818783, 9.083462934941053, 29.669370353221893, 65.20600587129593, 66.94261908531189, 64.46372330188751, 62.6843623816967, 58.80535952746868, 55.85305094718933, 48.272203132510185, 56.534757167100906, 60.8724220097065, 65.50934359431267, 59.974476993083954, 59.79000449180603, 62.22205638885498, 61.99450179934502, 55.34560337662697, 46.35536178946495, 47.52100624144077, 48.044447153806686, 48.52521635591984, 48.8467551022768, 54.445078298449516, 54.123490154743195, 58.31330493092537, 58.383369371294975, 49.43212129175663, 42.664707228541374, 45.152806118130684, 42.456166818737984, 49.9047589302063, 54.98088374733925, 56.715916246175766, 57.220616564154625, 61.3880505412817, 55.92926725745201, 54.4576708227396, 52.531523779034615, 57.53954105079174, 57.860247641801834, 58.10045935213566, 49.93766896426678, 44.36284750699997, 44.98960867524147, 45.18404804170132, 45.484057143330574, 49.062568321824074, 49.255236983299255, 55.99645145237446, 55.58548830449581, 66.7814089357853, 39.879460483789444, 40.504412949085236, 59.0289319306612, 55.16304597258568, 56.948646157979965, 53.014230877161026, 48.57451491057873, 43.9649822562933, 49.74552847445011, 48.64277444779873, 47.85403557121754, 44.79695901274681, 47.66588106751442, 44.261913523077965, 45.02746224403381, 46.35015606880188, 46.02884151041508, 44.095991626381874, 46.9529215246439, 45.095094814896584, 43.02990183234215, 44.40043888986111, 51.92050516605377, 57.767293229699135, 62.839903235435486, 56.10870122909546, 51.54727019369602, 59.01155166327953, 58.15095864236355, 54.89978849887848, 49.264850467443466, 49.82462503015995, 42.171121314167976, 47.05735892057419, 45.15347868204117, 50.29771104454994, 57.610050067305565, 62.721881568431854, 59.408079385757446, 61.42189532518387, 55.833022221922874, 55.61263024806976, 53.3753103017807, 57.04961434006691, 56.75581410527229, 64.11477282643318, 59.06268931925297, 63.71264800429344, 44.241409823298454, 17.318976670503616, 13.925607707351446, 17.22903359681368, 17.86021012812853, 9.020305573940277, 0.5408886855002493, 0.2986354456515983, 0.3583295299904421, 3.7841421319171786, 39.77767914533615, 57.53949545323849, 51.8231163918972, 29.792479947209358, 32.98220358788967, 39.98284913599491, 59.845283925533295, 60.28072915971279, 74.03548568487167, 24.11872699856758, 0.5082202353514731, 0.184677526995074, 0.16538024763576686, 0.1156379035091959, 0.13779423257801682, 0.09190318218315952, 0.1462213194463402, 0.09285717591410503, 0.15226260933559388, 0.2442537434399128, 0.2056829334469512, 0.1826930686365813, 0.14813671354204416, 0.25148036191239953, 0.07972395251272246, 0.1629394871997647, 0.08441052603302523, 0.11185237148310989, 0.09896275805658661, 0.14121945190709084, 0.13184584473492578], [0.04329226816480514, 0.10008577592088841, 0.012363968780846335, 0.05016878218157217, 0.11209579592105001, 0.05187527283851523, 0.027999736412311904, 0.05472830373037141, 0.029218018207757268, 0.012010754726361483, 0.042694252988439985, 0.031039001842145808, 0.05066180572612211, 0.046016862979740836, 0.024271438815048896, 0.038308690855046734, 0.03656723019958008, 0.054926327284192666, 0.04898251478152815, 7.109182449057698, 51.996330097317696, 55.05529895424843, 56.467424780130386, 35.162868574261665, 22.0835505053401, 23.022083044052124, 40.5987960845232, 44.6751793473959, 21.127240620553493, 1.0340795991942286, 0.054454373312182724, 0.05562710764934309, 0.208023474260699, 2.312597706913948, 3.759022867307067, 4.8217313177883625, 7.757769646123052, 43.81542228162289, 65.85469186306, 61.920531168580055, 58.92412215471268, 56.59631386399269, 53.125397711992264, 50.60690425336361, 45.29855489730835, 46.7924789339304, 57.521332427859306, 58.04160811007023, 58.25337454676628, 55.722436755895615, 57.28125751018524, 53.988361805677414, 46.408437341451645, 39.531402960419655, 41.85469329357147, 41.170087829232216, 41.55945673584938, 42.480899691581726, 46.88889876008034, 48.135136887431145, 49.959259405732155, 46.91043980419636, 44.19388957321644, 38.676790818572044, 38.47759410738945, 38.086716681718826, 44.06040273606777, 46.85633830726147, 52.85383768379688, 49.745042100548744, 54.972588792443275, 53.53105254471302, 52.45735935866833, 51.64444997906685, 52.29662798345089, 52.28738687932491, 49.53066520392895, 40.119900181889534, 40.61915159225464, 38.97738888859749, 41.95538029074669, 40.65315596759319, 45.39670743048191, 43.844619914889336, 48.75484183430672, 50.60417219996452, 60.6166235357523, 36.582404002547264, 36.806629970669746, 54.88226003944874, 52.213564440608025, 52.905685901641846, 48.733129799366, 45.31032666563988, 40.05715414881706, 40.19298546016216, 40.990916043519974, 42.60352671146393, 39.646757170557976, 41.7501837015152, 40.90400330722332, 41.08801983296871, 42.140198573470116, 42.54111886024475, 42.40803860127926, 43.194018825888634, 40.84205903112888, 42.27118134498596, 40.33590719103813, 45.144549161195755, 51.347461715340614, 53.577311262488365, 53.6212445050478, 47.16279946267605, 54.653025940060616, 55.765655636787415, 50.828869342803955, 47.43945501744747, 46.839091032743454, 42.4905663728714, 39.131189435720444, 40.89523337781429, 41.608132123947144, 42.143166214227676, 46.14732675254345, 49.58079591393471, 48.931676745414734, 45.963469818234444, 45.74160732328892, 46.29484623670578, 50.876701176166534, 54.22864951193333, 58.15954618155956, 57.39631153643131, 58.64512972533703, 48.6474671959877, 27.61688768863678, 8.60068079084158, 4.514050427824259, 6.405768468976021, 13.700944762676954, 0.5815298797097057, 0.07213076503830962, 0.055359307370963506, 0.04068879927217495, 11.096233930438757, 28.948729522526264, 32.77104511857033, 21.900096349418163, 13.816815745085478, 26.128159873187542, 41.370447278022766, 46.28450699150562, 49.020911157131195, 34.99489478766918, 2.1545019652694464, 0.06537121720612049, 0.01681294001173228, 0.02109617296810029, 0.014390509695658693, 0.03671892889542505, 0.08181092372979037, 0.01992498971958412, 0.08197556177037768, 0.04840674919250887, 0.045145073236199096, 0.07160526511142962, 0.050156406869064085, 0.05040017269493546, 0.09541748891933821, 0.04797824796696659, 0.0210738398891408, 0.051219978704466484, 0.02652755290910136, 0.021586836483038496, 0.07868027765653096, 0.050062180089298636, 0.019389227745705284, 0.011547276080818847, 0.03724097041413188, 0.0745125618414022, 0.07647454054676928, 0.03968363816966303, 0.03514353862556163, 0.026598556032695342, 0.029904792390880175, 0.03192887030309066, 0.03435612736211624, 0.03771185198274907, 0.0563388235605089, 0.09259500482585281, 0.03947059354686644, 0.034076582596753724, 0.03208409048966132, 0.028648965344473254, 10.226431153714657, 63.71587023139, 61.19302600622177, 64.3494862318039, 42.7014284580946, 29.2026299983263, 23.273574449121952, 34.06723156571388, 45.15331149101257, 26.457526199519634, 0.9292545053176582, 0.0695631344569847, 0.05038230920035858, 1.0054520540870726, 5.315130092203617, 6.614292254671454, 4.815766112878919, 8.160319570451975, 46.827900633215904, 66.38357788324356, 64.82543349266052, 60.85438817739487, 59.76470544934273, 55.00731512904167, 53.766180127859116, 47.756730392575264, 50.315995663404465, 59.79660473763943, 60.000957772135735, 59.088995307683945, 56.15003161132336, 60.030542984604836, 56.573302298784256, 48.374212458729744, 41.25856988132, 44.79276403784752, 44.17236752808094, 43.84718477725983, 44.682904332876205, 47.449558675289154, 50.1552414894104, 53.475077748298645, 49.1320513933897, 45.905538126826286, 40.254728347063065, 40.26776164770126, 39.955999776721, 46.117053776979446, 50.75271762907505, 53.33701215684414, 51.983551383018494, 56.85003384947777, 56.02912589907646, 52.43226170539856, 52.855323404073715, 55.39091594517231, 54.46300953626633, 50.99054306745529, 42.58552327752113, 41.76878750324249, 40.83447463810444, 43.62139329314232, 41.541582494974136, 47.85505771636963, 46.38767525553703, 50.90500965714455, 52.5289399176836, 62.73607760667801, 38.317816480994225, 38.01476374268532, 55.37677690386772, 54.41585026681423, 55.39718560874462, 50.10452181100845, 45.84694527089596, 42.67609141767025, 42.56330206990242, 43.308001309633255, 45.06892181932926, 41.53152443468571, 44.18037369847298, 43.2880599796772, 42.00853183865547, 44.45733703672886, 43.85409660637379, 43.83530281484127, 45.60184322297573, 44.422698095440865, 44.617175459861755, 42.62469157576561, 47.05791749060154, 54.078667759895325, 56.44705027341843, 55.27822159230709, 47.953130453825, 56.82797223329544, 57.631385922431946, 53.909162655472755, 51.001581475138664, 47.86154016852379, 43.90666298568249, 41.80762521922588, 43.12114633619785, 43.96521784365177, 44.736242070794106, 49.54907901585102, 52.676539197564125, 50.19603610038757, 46.98601774871349, 49.878635331988335, 49.09251071512699, 54.077733010053635, 55.2384415268898, 60.93129605054855, 58.966945856809616, 61.073970794677734, 50.90987339615822, 29.720977284014225, 8.954280316829681, 3.6160011542961, 8.373828213661909, 11.774660926312208, 4.41781441681087, 0.26300799334421754, 0.1828976342221722, 0.03578216412279289, 13.123579993844032, 34.4703671336174, 40.58126002550125, 23.961831517517567, 17.061584182083607, 34.211536422371864, 49.44880239665508, 52.87069357931614, 55.8006289601326, 42.416584342718124, 3.007276668213308, 0.07177762148785405, 0.04230461061524693, 0.016132975033542607, 0.037741604683105834, 0.07454155012965202, 0.10769863030873239, 0.03432998521020636, 0.0363675071275793, 0.03633143503975589, 0.026603118385537528, 0.10023413124145009, 0.041034009263967164, 0.009499976367806084, 0.046039468797971494, 0.054660534515278414, 0.05829086861922406, 0.022236477307160385, 0.0346947322395863, 0.017822709851316176, 0.07202454144135118, 0.2017707613413222, 0.1381662712083198, 0.08896795101463795, 0.20303152181440964, 0.2307736995862797, 0.15859508828725666, 0.12055642786435783, 0.09815611032536253, 0.09745790521265008, 0.05366797136957757, 0.18741830805083737, 0.13876273529604077, 0.20083715440705419, 0.22427109070122242, 0.17719897907227278, 0.11014843752491288, 0.20602448465069756, 0.18006073019932956, 0.12866735982242972, 14.901739228516817, 75.45682221651077, 69.23750594258308, 75.719243735075, 50.088608264923096, 34.25269961357117, 32.43582710623741, 53.43566246330738, 60.350010842084885, 31.14325236529112, 1.745900153182447, 0.2388585970038548, 0.47922660363838077, 0.900219907052815, 8.667401410639286, 14.297537449747324, 14.434523899108171, 12.239513732492924, 48.79665479063988, 70.06383240222931, 68.22365954518318, 63.47074158489704, 61.54109872877598, 57.721372693777084, 55.33890053629875, 49.437125623226166, 52.20563426613808, 62.326205000281334, 63.07983376085758, 59.431265741586685, 56.899860575795174, 62.64775134623051, 59.93748217821121, 50.8800183981657, 43.03283527493477, 47.410534769296646, 47.417264208197594, 46.53175212442875, 46.40322022140026, 51.43136881291866, 54.04638089239597, 55.197669714689255, 51.97404809296131, 47.67598092556, 43.46820071339607, 42.42859169840813, 43.2870302349329, 48.035802617669106, 52.38152302801609, 56.934393122792244, 56.50413081049919, 59.31562654674053, 58.034111112356186, 52.389365807175636, 55.12365348637104, 58.61245907843113, 56.158398762345314, 53.26324671506882, 43.390168100595474, 44.76889371871948, 43.51809583604336, 46.15573950111866, 44.48436118662357, 49.80213783681393, 48.23386698961258, 53.598244339227676, 55.71209751069546, 63.983892649412155, 41.52914576232433, 39.62828256189823, 56.53115876019001, 58.16210724413395, 57.846313789486885, 54.58771124482155, 48.731746673583984, 43.67172159254551, 43.911051750183105, 46.494472324848175, 48.304026424884796, 45.19119165837765, 45.959818214178085, 45.70217303931713, 44.6782685816288, 47.20644772052765, 46.926224157214165, 46.66479058563709, 47.688087075948715, 46.290563866496086, 47.654728665947914, 44.33442883193493, 49.64679837226868, 57.84772351384163, 59.22089762985706, 56.37615367770195, 47.996098548173904, 59.019082859158516, 60.28761439025402, 55.395551696419716, 52.547114342451096, 50.5359772592783, 46.47676147520542, 43.51982854306698, 46.018403470516205, 46.72552652657032, 48.011696711182594, 50.66573649644852, 56.22274070978165, 52.891364470124245, 50.26952415704727, 51.71413443982601, 51.58531375229359, 58.33568572998047, 57.522643357515335, 63.940878957509995, 61.07521332800388, 64.17509838938713, 51.8485826253891, 32.295823618769646, 13.376956097781658, 10.097772907465696, 15.403071977198124, 27.935092113912106, 2.8108723321929574, 0.2808896853821352, 0.3654748684493825, 0.11657757378998213, 17.35248327255249, 44.194976314902306, 44.5078781247139, 30.24835478514433, 24.83402531594038, 37.464758455753326, 58.54380436241627, 61.079237312078476, 62.82472684979439, 48.703183606266975, 3.3322630170732737, 0.14344242168590426, 0.1625568061717786, 0.11296833894448355, 0.08786808073637076, 0.17804039642214775, 0.15252529992721975, 0.13151921069948003, 0.12259688868653029, 0.15401765500428155, 0.1249317594920285, 0.23205158882774413, 0.1480137396720238, 0.1596046020858921, 0.24167742230929434, 0.15812014346010983, 0.13526724942494184, 0.13827729650074616, 0.10256434878101572, 0.0954465959512163, 0.19130434171529487], [0.0219796775127179, 0.05286424027872272, 0.016066777316154912, 0.03276400166214444, 0.040602190638310276, 0.012165737425675616, 0.018535205017542467, 0.011589161040319595, 0.03685298674099613, 0.09651826461777091, 0.06725768980686553, 0.030804091693426017, 0.02445272508339258, 0.07858986180508509, 0.020096930493309628, 0.028505406153271906, 0.027837725574499927, 0.006878778958707699, 0.5438832216896117, 24.001712277531624, 59.61432471871376, 54.73543591797352, 55.38089968264103, 42.30850674211979, 24.342276602983475, 33.69149632751942, 49.32740271091461, 38.47023770213127, 9.57510905340314, 0.0648872775491327, 0.10477128074853681, 0.05164070593309589, 0.40953448391519487, 2.3157472629100084, 4.911756087094545, 2.9410464596003294, 16.452976539731026, 61.56326673924923, 63.01612637937069, 57.59751833975315, 57.03313082456589, 51.47009253501892, 48.98992761969566, 47.00224667787552, 46.46726958453655, 44.75508525967598, 55.16539044678211, 58.622676730155945, 56.96001514792442, 54.674669578671455, 57.91941426694393, 54.618185609579086, 44.71401706337929, 38.79377894103527, 41.35310880839825, 39.61288958787918, 41.99765682220459, 40.122867822647095, 41.17408141493797, 42.99688160419464, 43.86214457452297, 42.52493552863598, 41.38610623776913, 39.32060547173023, 38.74930612742901, 38.093301728367805, 44.78774070739746, 47.5375809520483, 48.94477464258671, 49.76726710796356, 53.283336237072945, 52.3126707226038, 54.12793971598148, 47.30576679110527, 54.97661657631397, 51.47408992052078, 43.65224003791809, 38.340516462922096, 40.45470021665096, 38.33733603358269, 41.781524419784546, 42.63725370168686, 45.56265972554684, 43.90193223953247, 51.49001106619835, 49.775938242673874, 61.21770188212395, 35.70027753710747, 37.33699791133404, 55.802152678370476, 49.71274383366108, 52.45429292321205, 44.9639942497015, 41.75562120974064, 41.32992245256901, 39.81965929269791, 39.17481489479542, 41.58834658563137, 40.911021530628204, 43.16452480852604, 43.24506148695946, 41.985664665699005, 43.22472117841244, 44.93152119219303, 44.68686752021313, 46.0868263989687, 43.384912982583046, 40.340463146567345, 42.82700791954994, 49.515914395451546, 53.68811711668968, 54.68822345137596, 53.488532826304436, 51.95674002170563, 53.50223109126091, 55.09498782455921, 53.570707216858864, 52.19149902462959, 52.35672175884247, 47.85045236349106, 41.252064630389214, 40.06943888962269, 43.18374417722225, 39.918222203850746, 42.92357973754406, 42.056762650609016, 43.27211603522301, 42.069058790802956, 42.61500969529152, 43.56380358338356, 52.27709323167801, 57.19210669398308, 58.02413284778595, 55.527959391474724, 57.590473517775536, 54.31547865271568, 44.2816686630249, 20.515897125005722, 5.671281656250358, 4.457841468974948, 12.347128707915545, 3.693386851809919, 1.0298061347566545, 0.07277625540154986, 0.06044254027074203, 2.093657017685473, 20.943434983491898, 26.740740202367306, 25.59296429157257, 19.252037443220615, 18.814403526484966, 37.78120547533035, 44.7375226020813, 46.70895181596279, 34.65896621346474, 9.517416749149561, 0.416345737176016, 0.02854547099559568, 0.12024110415950418, 0.09127393743256107, 0.060512721465784125, 0.07115763874026015, 0.06205550547747407, 0.031546374812023714, 0.005056466879977961, 0.021397551718109753, 0.060851782764075324, 0.026827087422134355, 0.03877199880662374, 0.03448147610470187, 0.04281622124835849, 0.032938855365500785, 0.021444665107992478, 0.020374100386106875, 0.0354018690995872, 0.07169103511841968, 0.03722374887729529, 0.028948989674972836, 0.013062930884188972, 0.035538491065381095, 0.08612814519437961, 0.014230170545488363, 0.036183435950079, 0.053549235162790865, 0.08930755779147148, 0.05067167629022151, 0.02452769869705662, 0.018529342050896958, 0.0327016427036142, 0.05094714666483924, 0.04118193784961477, 0.042057085811393335, 0.06372882955474779, 0.04085827982635237, 0.8203101949766278, 30.618198439478874, 69.80182886123657, 62.090233862400055, 62.251584604382515, 48.362851068377495, 27.20166116952896, 32.340353429317474, 44.65463005006313, 46.46997503936291, 11.38009674847126, 0.07091108243912458, 0.10295629181200638, 0.049698765214998275, 2.6102100871503353, 5.395957455039024, 4.03182115405798, 1.9737727381289005, 19.8498859629035, 62.07132987678051, 64.59289357066154, 60.07710188627243, 57.680581882596016, 53.9419586956501, 52.479059994220734, 48.01213748753071, 47.8988503664732, 46.68914347887039, 58.020724430680275, 60.924103036522865, 57.965456396341324, 55.96480295062065, 60.98500616848469, 56.87984324991703, 47.07132697105408, 41.73529990017414, 43.20675954222679, 41.689117178320885, 46.57942056655884, 43.72557230293751, 44.10961389541626, 45.37554256618023, 45.458530113101006, 43.87706257402897, 43.47343683242798, 42.17975825071335, 41.13304741680622, 40.91250345110893, 45.755727365612984, 49.73736271262169, 51.83139234781265, 51.5246994048357, 54.11094702780247, 54.3802347779274, 54.70335803925991, 49.93299521505833, 58.856633976101875, 53.4887608140707, 47.690230160951614, 40.26529937982559, 41.62280693650246, 39.57608476281166, 44.40325453877449, 44.58926595747471, 48.4074492752552, 45.69238096475601, 54.233194068074226, 50.629847422242165, 62.655442133545876, 37.40137405693531, 38.332616686820984, 59.20357055962086, 52.30352841317654, 55.35373494029045, 47.62544743716717, 44.429309740662575, 42.20313839614391, 43.969732001423836, 40.63829876482487, 44.32028979063034, 42.34501138329506, 45.43205313384533, 46.02946847677231, 44.742424339056015, 46.38751186430454, 47.486116513609886, 45.47148361802101, 48.3973304182291, 44.88735996186733, 43.02789933979511, 44.91214223206043, 52.831673473119736, 54.75284278392792, 56.887351647019386, 55.3180168569088, 52.80014656484127, 54.404979050159454, 57.64621652662754, 55.25794208049774, 54.457484632730484, 53.97738419473171, 50.45750007033348, 42.920969277620316, 42.45694577693939, 44.34317596256733, 42.685845494270325, 44.03591684997082, 43.636406287550926, 43.706147745251656, 45.08120276033878, 44.83281768858433, 46.22639290988445, 54.98508632183075, 60.168190598487854, 61.06409132480621, 59.38770487904549, 58.70735138654709, 55.334743559360504, 43.95830601453781, 19.962736107409, 5.771810486912727, 4.594803219661117, 6.46575347520411, 10.636985823512077, 2.9871861962601542, 0.4160963458707556, 0.049777867025113665, 2.4732839595526457, 25.500690042972565, 28.091149739921093, 26.69883795082569, 21.046831235289574, 26.1537628993392, 44.42705646157265, 50.9581384062767, 54.91893567144871, 46.804174706339836, 12.101731225848198, 0.29170556750614196, 0.06763520548702218, 0.02953267397970194, 0.09858527948381379, 0.11269191862083972, 0.061696513803326525, 0.055792743878555484, 0.016913267245399766, 0.010167583659494994, 0.029887808341300115, 0.029403508742689155, 0.04624533685273491, 0.019623221342044417, 0.020920129973092116, 0.029568868521892, 0.03610193329222966, 0.064461173460586, 0.09342218036181293, 0.07377698217169382, 0.040639175567775965, 0.08641512627946213, 0.1459759208955802, 0.06457015784690157, 0.14000905357534066, 0.23852221114793792, 0.1550258180941455, 0.13205336406826973, 0.14705641369801015, 0.14826973609160632, 0.23352582065854222, 0.16503351624123752, 0.15786457748617977, 0.18165183544624597, 0.08870020639733411, 0.18093849794240668, 0.1485632554977201, 0.20237059477949515, 0.11209116491954774, 1.119495453312993, 39.66476060450077, 80.36820307374, 71.36795282363892, 70.41338324546814, 57.0174490660429, 36.9656590372324, 46.44890137016773, 64.47174847126007, 54.004218354821205, 14.49717778712511, 0.22704115690430626, 0.2807776804547757, 0.15190925798378885, 2.3477819189429283, 10.923157967627048, 14.890917409211397, 7.550522116944194, 21.554938070476055, 63.60493518412113, 66.14961683750153, 62.383334934711456, 61.9307754188776, 56.531401947140694, 54.707837998867035, 49.7027313709259, 51.49181216955185, 47.48584292829037, 59.53661888837814, 62.90157772600651, 57.7676086127758, 55.54468609392643, 63.00808221101761, 58.96490536630154, 49.20702517032623, 43.77889484167099, 46.618322879076004, 44.157365933060646, 48.672629445791245, 46.21012978255749, 45.73390133678913, 47.922583892941475, 47.72218644618988, 46.56511053442955, 45.860499143600464, 44.09053511917591, 43.326840698719025, 42.989707589149475, 48.856053203344345, 51.88850708305836, 52.385626807808876, 55.49828298389912, 56.646258383989334, 56.57662332057953, 57.13390901684761, 51.997067257761955, 61.01118676364422, 57.94539347290993, 48.98442551493645, 42.308024168014526, 44.64478097856045, 41.04174591600895, 47.21521385014057, 46.874679923057556, 50.75514569878578, 47.73244969546795, 57.87167362868786, 54.102997854352, 65.55932611227036, 40.786563009023666, 39.529499262571335, 60.02983242273331, 54.25275921821594, 57.5852108001709, 50.04594035446644, 45.95355615019798, 44.89554092288017, 45.990087389945984, 43.886330276727676, 46.011183857917786, 47.215388640761375, 48.894830122590065, 48.852743580937386, 46.45215779542923, 48.440929278731346, 51.16481311619282, 48.919388204813, 51.184944435954094, 47.66986705362797, 44.886900186538696, 46.85673348605633, 55.539769157767296, 58.13824452459812, 59.72319267690182, 56.15199610590935, 53.84159468114376, 56.32189258933067, 60.33365651965141, 58.98593343794346, 56.74483649432659, 58.73521909117699, 52.74457074701786, 46.378107368946075, 44.39362585544586, 46.541791185736656, 43.842750415205956, 46.18527911603451, 44.32885453104973, 46.239695996046066, 46.572326347231865, 47.82072275876999, 49.53424081206322, 57.9763238132, 62.83407814800739, 63.09689104557037, 60.667198821902275, 60.84743835031986, 57.84113846719265, 46.48487403988838, 24.183158241212368, 10.794625114649534, 11.830528378486633, 23.940957337617874, 10.511369314044714, 1.6966950497590005, 0.29072379518765956, 0.17061458551324904, 3.3802204811945558, 33.83718051016331, 39.19221796095371, 36.26508302986622, 27.245081439614296, 30.009951777756214, 53.76244492828846, 58.62916678190231, 61.743521466851234, 55.29882788658142, 14.082217253744602, 0.6402197491843253, 0.1337790206889622, 0.2354331105016172, 0.1789361983537674, 0.177386119030416, 0.21848573785973713, 0.10006768978200853, 0.12078168452717364, 0.09331015317002311, 0.1386207327595912, 0.21422811085358262, 0.07973311803652905, 0.13355046889046207, 0.10088241207995452, 0.11106441103038378, 0.10097498758113943, 0.10674627672415227, 0.19188455276889727, 0.2210835664300248, 0.17479063564678654], [0.08726766100153327, 0.0475285027641803, 0.020795983509742655, 0.03022917215275811, 0.05366037177736871, 0.016723455555620603, 0.06611409218749031, 0.05378863344958518, 0.03302923039882444, 0.08000444722711109, 0.007804009364917874, 0.03506074834149331, 0.03990981509559788, 0.038928094727452844, 0.05124828792759217, 0.05922699885559268, 0.03569753702322487, 0.04928889189613983, 1.025869189761579, 31.09587650746107, 64.17333528399467, 52.79550701379776, 51.17314986884594, 26.745638139545918, 15.430409610271454, 28.109757341444492, 34.630889520049095, 27.633124217391014, 3.0129568884149194, 0.1384988275822252, 0.08872081583831459, 0.285788988112472, 1.5145964710973203, 4.489366477355361, 3.622008631937206, 9.92994636297226, 40.86712248623371, 65.0652614235878, 61.07868254184723, 59.35858704149723, 57.234440222382545, 53.23640115559101, 50.673024505376816, 44.732529670000076, 43.74838627874851, 41.949642598629, 51.62985496222973, 57.645722553133965, 57.1403306722641, 55.60878865420818, 55.76570123434067, 52.35553242266178, 43.02444912493229, 39.68791276216507, 41.58720664680004, 40.29904916882515, 42.78522536158562, 43.987807631492615, 42.65979029238224, 41.55771262943745, 42.18487657606602, 41.57184787094593, 41.088399812579155, 38.52870136499405, 38.884799256920815, 39.14816312491894, 43.871571868658066, 44.308829605579376, 46.41204334795475, 46.57207556068897, 49.339805245399475, 52.595785930752754, 52.870587185025215, 53.17280016839504, 53.22269909083843, 47.097085788846016, 40.48471860587597, 38.2246682792902, 40.42635753750801, 38.67991805076599, 47.11852803826332, 45.51080770790577, 50.51710747182369, 48.46152417361736, 53.348791524767876, 49.914797991514206, 59.5405288785696, 35.04394255578518, 36.232013404369354, 59.561427757143974, 50.53888790309429, 50.53747057914734, 41.92171409726143, 44.0499646961689, 39.210278391838074, 39.3588238209486, 38.06472346186638, 39.261233657598495, 39.285157173871994, 40.28149411082268, 42.154759392142296, 43.370032981038094, 43.74916523694992, 44.91872347891331, 45.51397293806076, 45.96100375056267, 44.6316184848547, 43.76771964132786, 47.89706826210022, 51.82497829198837, 54.34974901378155, 54.816914945840836, 53.022487834095955, 50.187634751200676, 47.40567483007908, 54.1439900547266, 54.640410616993904, 55.000217109918594, 53.15510831773281, 51.29117913544178, 42.16666795313358, 40.23908078670502, 41.52808181941509, 40.901031866669655, 41.03819690644741, 43.24371635913849, 43.69084216654301, 42.6308586448431, 42.44344890117645, 41.31873965263367, 48.96461717784405, 56.31124556064606, 57.59523846209049, 58.97081024944782, 58.74780401587486, 59.27103213965893, 56.20550863444805, 41.68044224381447, 13.379086833447218, 6.43352597951889, 6.351285092532635, 10.325772073119879, 3.590220012702048, 0.12601563648786396, 0.16075297171482816, 0.1558748647221364, 9.610732141882181, 43.70893679559231, 37.93720990419388, 14.711699075996876, 18.16239271312952, 28.198136799037457, 36.27531208097935, 46.65019556879997, 51.54533989727497, 15.068163648247719, 0.20115820749197155, 0.06363454711390659, 0.06207012578670401, 0.04198352042294573, 0.011084431971539743, 0.01399913811837905, 0.028315679810475558, 0.025100044840655755, 0.039775430705049075, 0.022187857357494067, 0.027651314776449, 0.039661396003793925, 0.04242142465955112, 0.02021451266045915, 0.03412174599361606, 0.02693663955142256, 0.042610445962054655, 0.0841614390083123, 0.0676986071630381, 0.05124690753291361, 0.04931095594656654, 0.030126008059596643, 0.03999971515440848, 0.01633783191209659, 0.02821356956701493, 0.025069852417800575, 0.04493214364629239, 0.05227793248195667, 0.10999788544722833, 0.13145814678864554, 0.02719299591262825, 0.05072717409348115, 0.02629542024806142, 0.04681566992076114, 0.01748942246194929, 0.03147441617329605, 0.0874920493515674, 0.10880023721256293, 1.64276584982872, 41.62329711019993, 74.41020637750626, 60.20339950919151, 58.02794024348259, 35.9955482929945, 23.366017788648605, 28.723836690187454, 40.94203166663647, 33.293828666210175, 3.9104706281796098, 0.10405228065792471, 0.02431706048810156, 1.2118751462548971, 5.916909975931048, 5.306331189349294, 2.1781459590420127, 10.71061447262764, 42.98999637365341, 65.52947491407394, 63.732707127928734, 60.523444935679436, 58.2850344479084, 56.300241351127625, 51.642971858382225, 46.4566795527935, 47.42154657840729, 43.642288371920586, 53.3794254809618, 59.787504225969315, 59.12800021469593, 58.72788168489933, 58.30959253013134, 55.53321070969105, 44.798429533839226, 41.9827426224947, 43.44497635960579, 43.90477068722248, 44.54077675938606, 46.009724736213684, 44.52644772827625, 43.27338136732578, 42.983388528227806, 41.95928268134594, 43.40572066605091, 40.56439273059368, 40.56525528430939, 42.3083471506834, 46.71885788440704, 46.846930012106895, 49.316763281822205, 50.2391941845417, 52.11800716817379, 55.78806683421135, 55.69517321884632, 55.1052700728178, 58.07474613189697, 50.55612377822399, 43.427900075912476, 40.46649098396301, 43.112118020653725, 39.74531248211861, 48.30912575125694, 47.13879615068436, 51.74759924411774, 50.75460612773895, 54.65102344751358, 51.06161445379257, 61.72676436603069, 36.03310167789459, 37.78628580272198, 60.38688026368618, 53.127096220850945, 54.16756018996239, 44.332745522260666, 46.25159315764904, 41.322835832834244, 43.48222196102142, 40.02627320587635, 41.058875396847725, 41.70540310442448, 42.41871602833271, 44.24579478800297, 45.670775324106216, 45.957089960575104, 47.79319703578949, 47.18802250921726, 49.7198798507452, 46.403490006923676, 46.7223346978426, 50.250369384884834, 53.44927713274956, 57.64704868197441, 55.622331127524376, 54.4159946590662, 50.85383020341396, 49.70000311732292, 55.61587907373905, 56.903550177812576, 56.415671557188034, 54.09886747598648, 53.86011488735676, 44.08876061439514, 42.82486863434315, 42.852238565683365, 44.05789487063885, 43.87607842683792, 44.83256310224533, 46.418727189302444, 44.52684670686722, 44.04093258082867, 44.01981331408024, 51.849840357899666, 59.710258170962334, 58.948858827352524, 60.99596478044987, 60.03021240234375, 60.15520289540291, 57.04107999801636, 42.46191591024399, 13.792552147060633, 1.9587722118012607, 3.1038943212479353, 9.025209210813046, 7.560039656236768, 1.4159585139714181, 0.18763976491754875, 0.11454402236267924, 12.004125863313675, 40.93482345342636, 38.358455300331116, 18.997027426958084, 23.308399580419064, 37.29178413748741, 43.20309653878212, 51.54500551521778, 59.34939153492451, 22.8016796708107, 0.20814206945942715, 0.049259736624662764, 0.05264522507786751, 0.03530854402924888, 0.03452842807746492, 0.060100317423348315, 0.045976879773661494, 0.04293158810469322, 0.056696987739996985, 0.10334905862691812, 0.012639513370231725, 0.040427459389320575, 0.008680302089487668, 0.025671895600680728, 0.06223553937161341, 0.017448563521611504, 0.050979125808225945, 0.02053799071290996, 0.0389030286896741, 0.05901667791476939, 0.14978969906223938, 0.15873631899012253, 0.13969505089335144, 0.1670335597009398, 0.14785650826524943, 0.13473501079715788, 0.10240681309369393, 0.1769689578213729, 0.20453912060474977, 0.2707165922038257, 0.11584571228013374, 0.12599994748597965, 0.10814144014148042, 0.15335402655182406, 0.1368301679030992, 0.18024144315859303, 0.11383087781723589, 0.11266578017966822, 2.8874204121530056, 54.350759759545326, 83.75465735793114, 68.53586599230766, 65.32735615968704, 39.53091658651829, 25.43459638953209, 39.085656479001045, 49.01473268866539, 41.717535853385925, 4.899810003116727, 0.4096451529767364, 0.4640658030984923, 1.0443689720705152, 7.188754929229617, 13.426679279655218, 9.540790244936943, 14.433220569044352, 46.22993811964989, 67.20675811171532, 65.66988497972488, 63.71148906648159, 61.790813729166985, 58.703376799821854, 56.185438111424446, 49.302400052547455, 49.408775344491005, 45.67353777587414, 55.8914402872324, 62.61148229241371, 61.82922966778278, 58.83750580251217, 60.4558389633894, 57.38637126982212, 47.13206671178341, 44.37781870365143, 46.10036127269268, 45.60273617506027, 46.718181520700455, 47.05406069755554, 47.65668176114559, 46.253097876906395, 46.13664552569389, 44.830157831311226, 46.74123868346214, 43.7289085239172, 44.009272679686546, 45.59543676674366, 48.48988585174084, 50.42752727866173, 50.99292553961277, 53.44844497740269, 56.281709745526314, 57.232046350836754, 59.33058634400368, 56.96686998009682, 60.48171937465668, 52.22305253148079, 45.86923107504845, 41.750696673989296, 45.048292726278305, 42.65360042452812, 52.00089365243912, 49.24585908651352, 55.866544023156166, 53.39934781193733, 56.855167374014854, 53.68647560477257, 62.90261507034302, 40.34159168601036, 40.32160855829716, 62.99162529408932, 55.72359949350357, 56.123395040631294, 46.011852622032166, 49.38782326877117, 43.44473697245121, 46.12953990697861, 42.05912992358208, 42.77607925236225, 45.25774508714676, 43.871511071920395, 47.39883899688721, 48.36000882089138, 48.16938444972038, 49.25821602344513, 48.97496022284031, 53.343319818377495, 48.6760188639164, 48.50253917276859, 52.37105458974838, 56.39400511980057, 61.34666696190834, 57.23185256123543, 55.81527337431908, 52.27170132100582, 51.56147763133049, 58.349969163537025, 57.574369981884956, 59.650532975792885, 58.0826573073864, 56.92218817770481, 46.48115023970604, 45.12022666633129, 45.3301578015089, 46.09246149659157, 46.330188140273094, 47.1355777233839, 49.44258593022823, 47.48998090624809, 45.21923415362835, 47.28305160999298, 54.8856570571661, 61.38854071497917, 62.52113074064255, 64.91301119327545, 64.4452790915966, 62.514971271157265, 57.65147924423218, 45.07185146212578, 16.796899884939194, 12.84446407109499, 14.058057200163603, 21.069236733019352, 5.041756136342883, 0.6686239968985319, 0.2228490318520926, 0.20389251701999456, 17.04313427209854, 65.66302254796028, 52.56070241332054, 22.28392705321312, 27.272400073707104, 42.596139907836914, 50.56249223649502, 57.519128546118736, 69.93328660726547, 30.3221620246768, 0.6073323357850313, 0.15105488273547962, 0.13436809298582375, 0.20179111103061587, 0.20256858493667096, 0.18165952409617603, 0.14812093548243865, 0.14135520556010306, 0.2097157490788959, 0.27629757241811603, 0.06387319954228587, 0.2039020907250233, 0.08866876160027459, 0.10312016544048674, 0.20888457336695865, 0.0994441521470435, 0.11857585835969076, 0.2773645136039704, 0.15881042985711247, 0.15213761682389304], [0.017853932004072703, 0.07018192234681919, 0.026200840948149562, 0.022358684909704607, 0.033922672300832346, 0.045763259986415505, 0.014034842843102524, 0.029233738750917837, 0.06839739857241511, 0.018830106673703995, 0.08907311334041879, 0.0672118621878326, 0.0195256233564578, 0.032076509451144375, 0.038932020688662305, 0.08499616218614392, 0.037316164816729724, 0.012351400509942323, 11.266717482358217, 52.16460406780243, 58.23377899825573, 55.86695820093155, 38.91409568488598, 18.737432956695557, 20.37262011319399, 37.19228267669678, 40.238659009337425, 24.682153165340424, 0.19929639645852149, 0.08933201897889376, 0.06940107909031212, 1.6547126462683082, 4.8173340037465096, 2.924559856764972, 2.2684086905792356, 28.801183439791203, 59.37242969870567, 63.87546166777611, 62.134277299046516, 57.9648332297802, 57.70244970917702, 57.76409760117531, 53.78112092614174, 45.97747966647148, 45.10900966823101, 43.744803071022034, 44.05987076461315, 54.85565006732941, 57.610479444265366, 57.913216799497604, 54.59899663925171, 47.16646246612072, 42.79586859047413, 41.24718189239502, 40.4246324300766, 41.65565997362137, 44.85599644482136, 45.800181180238724, 43.7073028832674, 43.14724713563919, 41.60242862999439, 41.36110357940197, 39.7615110129118, 37.33029507100582, 38.570373728871346, 37.83082701265812, 40.760511606931686, 41.84516340494156, 45.24226471781731, 44.467083513736725, 50.50807535648346, 50.751349702477455, 55.29710277915001, 53.41631390154362, 53.32228794693947, 42.78201073408127, 38.724014684557915, 39.44532997906208, 39.13581758737564, 42.76596799492836, 49.300891533493996, 50.43260760605335, 57.39525519311428, 52.82319612801075, 57.791630923748016, 50.22735022008419, 59.52244944870472, 30.191572532057762, 36.95603035390377, 58.705341294407845, 47.197145819664, 51.483163833618164, 42.09544077515602, 45.7646606862545, 40.79544313251972, 40.5139884352684, 38.86456914246082, 40.50862692296505, 38.912119790911674, 42.00901061296463, 41.20227210223675, 42.13296756148338, 44.453484043478966, 48.080985993146896, 47.14468203485012, 47.92104497551918, 47.61335648596287, 47.980192601680756, 51.16637483239174, 54.83520716428757, 52.67724595963955, 51.91825948655605, 51.534134298563, 48.875253573060036, 54.7108094394207, 55.69939099252224, 52.2857491672039, 54.18247438967228, 53.70194457471371, 52.67504967749119, 43.04976336658001, 42.44317911565304, 39.764725640416145, 40.77249996364117, 43.380471020936966, 48.399724289774895, 49.15639668703079, 48.97976316511631, 44.32144112884998, 40.22057577967644, 44.39349286258221, 54.06930886209011, 55.71630388498306, 57.03098773956299, 56.93416893482208, 57.89015203714371, 59.68260705471039, 54.41032536327839, 37.33645834028721, 7.010695058852434, 1.9427357660606503, 13.420535959303379, 9.020247627049685, 3.7390055414289236, 0.05609368847217411, 0.0537716085818829, 2.31874767690897, 23.452867828309536, 31.47324375808239, 19.518921822309494, 17.045005671679974, 21.819420978426933, 39.17644500732422, 41.46606534719467, 50.71483366191387, 37.327031046152115, 1.7353189084678888, 0.06398965735570528, 0.054636744971503504, 0.03278127514931839, 0.06107605979195796, 0.04364954918855801, 0.030123072865535505, 0.02674428415048169, 0.005040125251980498, 0.1442170754307881, 0.05328677092620637, 0.022795967597630806, 0.06068063237762544, 0.010896423700614832, 0.036763068128493614, 0.0589299839339219, 0.02956209827971179, 0.07183318608440459, 0.04488925864279736, 0.029081409229547717, 0.012583528532559285, 0.11171151185408235, 0.06005729141179472, 0.10123496933374554, 0.00906869487153017, 0.024431234342046082, 0.033300374052487314, 0.046615219544037245, 0.019629551861726213, 0.030925950486562215, 0.03793498610320967, 0.009078840957954526, 0.03136785118840635, 0.02724542864598334, 0.13044618390267715, 0.02849933909601532, 0.030721256880497094, 0.030627249034296256, 14.664992932230234, 62.32818849384785, 65.77944070100784, 62.95409470796585, 46.53947710990906, 25.34845881164074, 20.83476461470127, 34.559525549411774, 42.03114442527294, 27.70882375538349, 0.26716042833868414, 0.09302618520450778, 0.0631832990620751, 1.652719178237021, 4.950201949104667, 3.735440382733941, 3.4019109047949314, 29.631264097988605, 59.25646372139454, 64.65182840824127, 65.26385396718979, 60.036998838186264, 59.77355897426605, 59.505175575613976, 55.410481095314026, 47.57708363234997, 47.65312135219574, 45.891311690211296, 48.228623270988464, 56.56660705804825, 59.72584493458271, 59.71215806901455, 58.38502608239651, 49.90795835852623, 45.46715945005417, 43.212216049432755, 42.593088671565056, 44.60156589746475, 46.469253078103065, 48.168305307626724, 46.47295027971268, 44.98514011502266, 43.01766648888588, 42.762962356209755, 41.147182658314705, 39.96710658073425, 40.589342191815376, 40.167055651545525, 43.46001215279102, 45.12659892439842, 47.14830324053764, 46.19352087378502, 52.686753049492836, 52.92309656739235, 56.74079731106758, 54.71736788749695, 53.89164179563522, 45.21906316280365, 42.12182275950909, 40.59623122215271, 42.350745275616646, 44.10391040146351, 50.88288724422455, 51.27339228987694, 58.75068046152592, 54.704057201743126, 59.70437988638878, 53.06999288499355, 61.16875670850277, 32.2749437391758, 37.42476940155029, 61.19007736444473, 50.30465327203274, 51.82698838412762, 44.43710312247276, 47.56485588848591, 43.01975637674332, 42.82785527408123, 40.79249449074268, 42.998625710606575, 40.880733355879784, 44.24096144735813, 43.40757496654987, 43.35547976195812, 46.603420078754425, 49.748971089720726, 50.426041558384895, 49.94868457317352, 48.83369520306587, 50.02833589911461, 53.1204541772604, 56.89761109650135, 54.77668270468712, 53.34105893969536, 51.8569877743721, 52.089577093720436, 55.08806839585304, 56.558851674199104, 54.609343484044075, 56.5031960606575, 56.646182388067245, 53.89790765941143, 45.08612349629402, 44.33750666677952, 42.8051894903183, 41.796066239476204, 44.91849169135094, 50.30039370059967, 51.62535600364208, 50.80509401857853, 45.64321160316467, 42.75646470487118, 46.4218620210886, 56.270374953746796, 58.021795973181725, 58.34467984735966, 59.31106299161911, 59.74952906370163, 62.01297640800476, 57.94844850897789, 38.31514522433281, 7.04378510825336, 1.5569089818745852, 7.0193785429000854, 16.03121057152748, 4.198077907785773, 0.09243390682968311, 0.16590521321631968, 2.947942614555359, 27.645106874406338, 34.959036111831665, 23.215036690235138, 21.14775761961937, 29.32894852012396, 45.95415271818638, 47.43246339261532, 54.60796795785427, 49.039818942546844, 3.1590046640485525, 0.04755257432407234, 0.02290523214469431, 0.041861860154313035, 0.010979726994264638, 0.013366713264986174, 0.07066725724143907, 0.014242980942071881, 0.02783849740808364, 0.12550054147141054, 0.027680573948600795, 0.01122882144045434, 0.004943672956869705, 0.04456900336663239, 0.016841750184539706, 0.07736568179097958, 0.04581688757753, 0.0424774902057834, 0.045553414020105265, 0.05858321914274711, 0.12727569934213534, 0.15463363757589832, 0.1449556607985869, 0.16939229797571898, 0.07725870862486772, 0.12897662760224193, 0.0675837449671235, 0.07784489396726713, 0.12777902389643714, 0.1489799565752037, 0.17512433492811397, 0.1608010777272284, 0.10135743854334578, 0.14907836535712704, 0.18548566644312814, 0.14656245504738763, 0.0934395837248303, 0.10996271506883204, 19.91808470338583, 72.09364548325539, 72.74484694004059, 72.92873427271843, 52.014329731464386, 29.283960834145546, 29.17211953550577, 51.16899289190769, 55.62839560210705, 35.11250987648964, 0.42235840985085815, 0.13658460607985035, 0.2271547500276938, 2.3198263440281153, 15.955978408455849, 11.349085662513971, 6.040275581181049, 31.555442847311497, 62.11062356829643, 65.15823483467102, 68.20328503847122, 62.071067690849304, 60.94188988208771, 64.23855498433113, 58.371115028858185, 49.21475015580654, 51.0003275424242, 47.5977773219347, 49.41791005432606, 58.81966196000576, 62.614392936229706, 61.77157536149025, 60.02767413854599, 52.426622807979584, 47.29733124375343, 45.97340628504753, 45.12662932276726, 45.763266161084175, 49.78182032704353, 50.47648765146732, 49.10005711019039, 48.4516067057848, 45.75147159397602, 46.05127550661564, 43.108971789479256, 40.89470520615578, 43.33727493882179, 42.889514565467834, 44.300451055169106, 47.68256597220898, 50.72089433670044, 49.49933968484402, 56.40313223004341, 55.11168412864208, 59.31207373738289, 56.81864373385906, 59.18763041496277, 47.480112835764885, 44.28022854030132, 43.08751434087753, 44.36850920319557, 47.755077481269836, 53.53191129863262, 53.94023738801479, 61.75496645271778, 57.04989172518253, 60.878953859210014, 55.228558257222176, 61.03884547948837, 34.010371416807175, 41.233878806233406, 63.01454186439514, 52.29709915816784, 55.138647481799126, 46.72297306358814, 49.27727200090885, 45.92299059033394, 44.692662209272385, 43.264482244849205, 46.63160316646099, 43.525486439466476, 46.39432109892368, 45.27108617126942, 46.13713949918747, 50.055489242076874, 52.71389119327068, 52.048835679888725, 52.93713301420212, 52.51059830188751, 52.48832389712334, 56.42153464257717, 58.63292098045349, 57.32440419495106, 54.2765649408102, 54.36714068055153, 54.8214291036129, 58.911085054278374, 60.1972970366478, 55.02273850142956, 59.1745363175869, 59.275018125772476, 57.26888157427311, 47.75777153670788, 47.804493829607964, 44.33888219296932, 44.92873974144459, 47.81921423971653, 52.18978151679039, 53.37602086365223, 53.54402884840965, 47.472137063741684, 43.203100338578224, 48.89692381024361, 59.53318387269974, 61.18419528007507, 62.345595359802246, 61.90895318984985, 64.32537272572517, 63.27614262700081, 60.22837556898594, 40.70980712771416, 10.805047955363989, 8.536189701408148, 24.47510227560997, 17.16766308993101, 7.082769116386771, 0.2253293339163065, 0.25777306174859405, 4.007511958479881, 36.00747965276241, 43.06911952793598, 29.458056092262268, 25.653749629855156, 33.142159804701805, 53.02088052034378, 53.44624109566212, 62.5473303347826, 56.80394612252712, 5.607169596478343, 0.2950640529161319, 0.214107719657477, 0.22798165096901357, 0.12298201138037257, 0.12739233527099714, 0.10013990817242302, 0.08097008525510319, 0.18502023594919592, 0.357324899523519, 0.17195723456097767, 0.1468094566371292, 0.11925572500331327, 0.16213333670748398, 0.09512609205557965, 0.15418261958984658, 0.3056113369530067, 0.1192904426716268, 0.18921739276265725, 0.18727519229287282], [0.02741437670920277, 0.014134620887489291, 0.008458692154817982, 0.03495818353258073, 0.004106337419216288, 0.01438221526768757, 0.04914730125165079, 0.0772399026027415, 0.11293074916466139, 0.03647658428235445, 0.01825710744014941, 0.09676466506789438, 0.0615264358202694, 0.05443159679998644, 0.13135078770574182, 0.032748483354225755, 0.11728231722372584, 0.08294166735140607, 21.80051889270544, 56.013907715678215, 53.803980499506, 47.40003973245621, 32.41065725684166, 21.483765989542007, 32.04784132540226, 37.305558398365974, 40.284887328743935, 12.354321721941233, 0.018142859371437225, 0.10817471062182449, 0.09050500564626418, 1.7643583752214909, 4.731954960152507, 2.5905770156532526, 11.42614172771573, 48.98643560707569, 59.08068895339966, 62.43750102818012, 59.96536888182163, 63.365639224648476, 58.57835590839386, 58.79600442945957, 55.66165141761303, 51.97509303689003, 44.62311074137688, 44.95420977473259, 41.97163201868534, 45.71301765739918, 50.19255928695202, 51.41432672739029, 46.55533745884895, 42.14990705251694, 42.54839546978474, 42.02585890889168, 40.37120349705219, 43.454061672091484, 44.10411939024925, 46.2472727894783, 46.91602170467377, 46.0471261292696, 41.984771713614464, 39.71616804599762, 40.0432088971138, 39.23624239861965, 40.8050262182951, 38.44203561544418, 39.57837224006653, 40.813583359122276, 40.23180037736893, 42.72710748016834, 44.85639542341232, 49.96602304279804, 51.71299070119858, 48.10754656791687, 43.19976791739464, 38.949483186006546, 40.38462437689304, 39.47567895054817, 41.69597961008549, 45.612444654107094, 51.74826800823212, 52.375310361385345, 54.729120656847954, 51.69334955513477, 57.78857208788395, 48.46732646226883, 59.042235016822815, 30.567528158426285, 35.945371985435486, 60.772966146469116, 47.95067958533764, 51.401092037558556, 46.46332159638405, 50.40935665369034, 45.426843613386154, 42.64389954507351, 37.88233324885368, 38.861586302518845, 37.91399694979191, 39.372814670205116, 38.40516239404678, 41.557446643710136, 41.98466531932354, 47.678382396698, 46.94714963436127, 47.57031999528408, 47.60921470820904, 53.182368054986, 54.1826643794775, 52.350296303629875, 50.31726099550724, 51.53809368610382, 52.57682114839554, 53.14324915409088, 53.81251484155655, 50.08698955178261, 52.48114988207817, 53.381066992878914, 53.50194610655308, 48.384350314736366, 42.22412087023258, 43.119691014289856, 39.830351918935776, 43.47432218492031, 52.07446150481701, 57.05841846764088, 55.32519467175007, 53.97834174335003, 50.40187865495682, 44.03063893318176, 40.62347196042538, 44.595934599637985, 49.648512080311775, 53.5501579195261, 55.74292525649071, 56.04213260114193, 56.29725471138954, 58.983862549066544, 58.622779324650764, 24.052665643393993, 2.8828188590705395, 4.675261052325368, 15.061387661844492, 12.121423669159412, 0.46990258677396923, 0.1015588128939271, 0.15747043769806623, 12.312051840126514, 30.90972639620304, 31.65216665714979, 18.644442446529865, 19.475248865783215, 30.879143737256527, 47.07860358059406, 45.447655096650124, 48.28415349125862, 11.908078417181969, 0.23541944014141336, 0.06352305426844396, 0.017519303182780277, 0.05865831706614699, 0.0450692257436458, 0.02342638123081997, 0.04768374521518126, 0.03598813978896942, 0.05898438335862011, 0.05908236911636777, 0.04096549419045914, 0.03233209026802797, 0.03653862782812212, 0.02221779930550838, 0.03342745570989791, 0.03903403259755578, 0.040887557552196085, 0.06553190702106804, 0.015111815082491376, 0.06291812227573246, 0.03364637443155516, 0.025373029020556714, 0.06194143366883509, 0.04065477551193908, 0.07528538248152472, 0.009177095744234975, 0.056366086355410516, 0.04990004679712001, 0.058208275004290044, 0.050518144489615224, 0.11427648554672487, 0.02274381316965446, 0.06022832676535472, 0.06986078020418063, 0.060841351878480054, 0.07149373515858315, 0.10815112516866066, 26.72506034374237, 65.26655942201614, 62.39601485431194, 55.05376763641834, 36.718767285346985, 24.35205537825823, 32.19221457839012, 38.01683843135834, 41.60443872213364, 13.603091463446617, 0.07987349526956677, 0.13379352225456387, 0.20086160075152293, 4.0547961462289095, 7.29676223360002, 3.2687100023031235, 13.993751350790262, 50.693467408418655, 60.070296451449394, 62.755084186792374, 61.326588839292526, 64.3793374300003, 59.91501398384571, 61.661886647343636, 58.19719076156616, 53.85978430509567, 46.63740925490856, 46.57452642917633, 44.404291883111, 48.82343575358391, 53.78933608531952, 53.08372534811497, 47.63700261712074, 43.258831948041916, 45.179826468229294, 42.75857359170914, 42.601816803216934, 45.17330601811409, 47.90008910000324, 46.81538790464401, 48.30021142959595, 48.51345218718052, 44.013387858867645, 41.97052247822285, 42.14514970779419, 39.929093420505524, 42.51631759107113, 40.66378779709339, 41.198213919997215, 43.159813061356544, 43.030380606651306, 44.85502369701862, 47.47990004718304, 52.01045773923397, 53.13182696700096, 49.68693181872368, 47.47551888227463, 40.63970848917961, 42.19629496335983, 40.87653458118439, 43.58892023563385, 47.809828743338585, 53.69920112192631, 55.14107935130596, 57.758914679288864, 53.1533832103014, 57.98099376261234, 50.33106565475464, 60.81441432237625, 31.68930396437645, 37.9331137239933, 63.46322558820248, 49.88479100167751, 53.18498231470585, 48.25542703270912, 51.588228195905685, 46.88873536884785, 45.550713166594505, 40.8814363181591, 41.48342661559582, 40.26299670338631, 42.35338993370533, 41.39477737247944, 42.75707647204399, 44.191640093922615, 51.4595253020525, 49.68334101140499, 50.453669875860214, 49.846177473664284, 54.688405841588974, 56.99118107557297, 55.20197868347168, 50.528978034853935, 53.471099361777306, 54.58620272576809, 55.02710446715355, 55.616764426231384, 53.13399285078049, 55.37576615810394, 55.79360693693161, 55.68343944847584, 50.513448268175125, 45.31482182443142, 44.50378954410553, 41.289504021406174, 46.33490368723869, 54.946047216653824, 59.11937087774277, 57.23459601402283, 56.9453327357769, 51.01489596068859, 45.68134255707264, 42.394366934895515, 46.940108612179756, 51.59138582646847, 56.731214225292206, 57.441289722919464, 59.578048065304756, 58.66531044244766, 62.442520558834076, 59.12249431014061, 26.317469514906406, 2.223575608804822, 3.5842928057536483, 11.55739238485694, 8.284862637519836, 0.9130603680387139, 0.04051171170431189, 0.2498095203191042, 13.339169025421143, 33.115815818309784, 27.92216330766678, 19.78588979691267, 29.884778894484043, 38.134050741791725, 53.52295897901058, 50.523206144571304, 55.69543540477753, 17.68525991588831, 0.25588762073311955, 0.09187942603603005, 0.03588896659493912, 0.07343695979216136, 0.04191624102531932, 0.038064030741225, 0.09066286045708694, 0.01578445877385093, 0.024170965007215273, 0.027093438657175284, 0.04666027904022485, 0.04079405807715375, 0.08930397321819328, 0.025080882587644737, 0.030044759587326553, 0.02079847898130538, 0.14703765220474452, 0.029359989202930592, 0.02428727995720692, 0.16637914872262627, 0.1352948127896525, 0.1132180864806287, 0.22151408629724756, 0.06613245292101055, 0.16686209390172735, 0.12814485817216337, 0.16357721469830722, 0.23371508315904066, 0.16005642159143463, 0.20038303424371406, 0.19546623167116195, 0.11671682295855135, 0.2086255489848554, 0.22682066482957453, 0.30075861141085625, 0.18214190524304286, 0.4357372841332108, 33.57542775571346, 74.77893859148026, 69.59785580635071, 63.337425738573074, 46.721054166555405, 31.554422602057457, 44.38835173845291, 52.02451318502426, 54.96339328587055, 16.77455898374319, 0.11773575461120345, 0.2947308582952246, 0.611386540113017, 7.835478326305747, 13.193623535335064, 7.366630034521222, 14.611829984933138, 52.84405320882797, 60.79544574022293, 63.5790091753006, 61.99890956282616, 67.65850827097893, 64.32838216423988, 64.2080046236515, 60.195442736148834, 55.53571097552776, 49.16116163134575, 49.36678759753704, 47.06482172012329, 51.00837171077728, 54.980898946523666, 55.87939113378525, 50.91344140470028, 45.21547615528107, 47.28207506239414, 46.01713053882122, 43.65102410316467, 47.2614573687315, 48.99902433156967, 49.69537116587162, 51.14511877298355, 50.38493916392326, 46.405203714966774, 43.2040236890316, 45.275748521089554, 42.70022392272949, 45.6821671128273, 43.009455129504204, 43.95599193871021, 46.42218500375748, 44.17981132864952, 47.95026920735836, 47.918381318449974, 54.23582352697849, 55.452575236558914, 51.76939107477665, 48.86481933295727, 43.79385083913803, 44.39304068684578, 42.89808690547943, 46.2199180573225, 50.31247705221176, 56.137279495596886, 56.75955690443516, 57.86256551742554, 55.41940301656723, 59.198038056492805, 50.42371988296509, 60.123102217912674, 33.44158373773098, 40.033865198493004, 65.30979350209236, 51.92471534013748, 55.984941869974136, 52.03355669975281, 54.130443781614304, 50.011354610323906, 46.90682239830494, 42.9427383095026, 43.49191144108772, 43.330306112766266, 43.65646541118622, 42.70498126745224, 45.125443786382675, 47.386660650372505, 53.77535283565521, 51.65983535349369, 52.434093207120895, 53.40572386980057, 57.97350816428661, 58.94913621246815, 55.28883822262287, 52.12046943604946, 55.25930620729923, 56.787439808249474, 57.24490866065025, 57.96724610030651, 56.0726335644722, 58.206659853458405, 58.6602833122015, 57.780577316880226, 53.15723240375519, 47.50174127519131, 46.69328525662422, 44.19106252491474, 49.00592856109142, 57.7522574365139, 61.90863020718098, 59.15373243391514, 60.04379667341709, 54.66268502175808, 47.119610980153084, 45.18936775624752, 48.81478741765022, 55.291585475206375, 60.07975034415722, 60.60458958148956, 61.382772624492645, 60.89211255311966, 65.44779449701309, 61.47016033530235, 27.818236984312534, 5.841766158118844, 11.159883365035057, 28.500144593417645, 21.092168502509594, 1.0325903166085482, 0.19957566662924364, 0.36246323317755014, 19.19912338256836, 46.05408735573292, 43.702416345477104, 26.678567938506603, 30.16933612525463, 42.029594108462334, 62.529000118374825, 57.761616334319115, 62.9254974424839, 21.6690706461668, 0.43032877903897315, 0.16093791491584852, 0.09965055825887248, 0.24560532794566825, 0.14064105169381946, 0.11427177290897816, 0.21170296822674572, 0.13749528065091, 0.1733438335941173, 0.2114685534616001, 0.15700539312092587, 0.11122886353405192, 0.3204974241089076, 0.09885910229058936, 0.11921963436179794, 0.1102641606121324, 0.24208150687627494, 0.20735444297315553, 0.14524325786624104], [0.10446043219417334, 0.03498506783216726, 0.056015855734585784, 0.06765009296941571, 0.039189846502267756, 0.027542328534764238, 0.02100553818308981, 0.032103731427923776, 0.03409443495911546, 0.0290562708323705, 0.0424911234586034, 0.05558310200285632, 0.012373523004498566, 0.0392160183400847, 0.03727309427631553, 0.015279375329555478, 0.1349604901042767, 1.3111670245416462, 35.408016219735146, 61.347168534994125, 52.1776981651783, 42.948734387755394, 21.664915569126606, 14.932785462588072, 29.973853714764118, 38.409228175878525, 39.75388862192631, 4.897409006953239, 0.24910222389735281, 0.11973668122664094, 0.4387428337940946, 0.9383375023026019, 1.767193260602653, 2.8153017070144415, 32.74539269506931, 58.706868812441826, 64.92637127637863, 61.817404702305794, 59.58351217210293, 59.50817361474037, 63.539415299892426, 58.771499544382095, 57.49019309878349, 54.29406300187111, 48.810261860489845, 43.64179439842701, 44.08228576183319, 41.33777663111687, 43.14722053706646, 41.04293145239353, 42.27796018123627, 40.906305983662605, 41.727544516325, 43.00214432179928, 47.09326699376106, 46.36288918554783, 47.808601409196854, 49.47698548436165, 47.277883887290955, 47.328580766916275, 42.8142786026001, 39.784868359565735, 41.21121682226658, 39.01319816708565, 39.679959788918495, 39.664205834269524, 39.33716498315334, 38.59819583594799, 39.836275801062584, 39.681700095534325, 41.121670827269554, 39.680533558130264, 41.698593869805336, 39.22611974179745, 38.869672268629074, 38.797392547130585, 39.715590476989746, 38.58098275959492, 41.33691407740116, 45.14520272612572, 54.94687557220459, 52.55687601864338, 55.398903116583824, 49.304835721850395, 54.51667405664921, 45.83458833396435, 54.55512419342995, 28.058456294238567, 31.733282804489136, 60.81539086997509, 49.9936855584383, 53.90805311501026, 49.22892339527607, 52.84927412867546, 48.484106361866, 49.4261784106493, 43.077004104852676, 38.478369265794754, 37.71420367062092, 41.47474028170109, 40.801310017704964, 38.8283646851778, 39.74142149090767, 47.140304669737816, 46.822482123970985, 48.83372940123081, 49.957253113389015, 52.83826991915703, 52.8351578861475, 52.514253705739975, 54.13994327187538, 53.37803475558758, 54.87154081463814, 52.61118270456791, 50.78702598810196, 52.848745957016945, 52.97689788043499, 51.6693614423275, 46.08721397817135, 41.73822954297066, 41.2638857960701, 40.57657867670059, 40.02231001853943, 43.81344638764858, 54.58197735249996, 53.36803749203682, 56.82211294770241, 54.88062232732773, 52.66195558011532, 46.364751085639, 43.20387549698353, 40.52652396261692, 43.09038698673248, 43.394781053066254, 48.64158131182194, 49.97345544397831, 58.22241760790348, 56.27138949930668, 59.687166810035706, 54.25929106771946, 15.864181984215975, 4.063114849850535, 15.141013339161873, 5.831566555425525, 3.4146072110161185, 0.18529993656557053, 0.09169263488729484, 6.2286841962486506, 30.18448781222105, 46.531106159090996, 29.45074338465929, 15.541868079453707, 31.501295752823353, 44.12999600172043, 44.66381035745144, 50.97910188138485, 22.97093778848648, 1.0562793142162263, 0.03206819368642755, 0.04386064196296502, 0.031721736886538565, 0.030853340613248292, 0.03669503174023703, 0.051282385902595706, 0.039458767423639074, 0.007157905338317505, 0.04630156196071766, 0.03926142664568033, 0.033182105398736894, 0.014760051926714368, 0.09596036994480528, 0.03526784093992319, 0.09610585315385833, 0.021577988227363676, 0.02613744854897959, 0.08475546143017709, 0.04335094607085921, 0.025247140365536325, 0.0039361207473120885, 0.04572092788293958, 0.06371993862558156, 0.06329047260805964, 0.05403274808486458, 0.03119727596640587, 0.05013054673327133, 0.09911349567119032, 0.03894944631610997, 0.0069353176240838366, 0.01776798759237863, 0.03404378338018432, 0.017287660339206923, 0.040589774507679977, 0.10411213486804627, 1.5376792824827135, 44.41783435642719, 69.92729052901268, 57.97405153512955, 48.821391463279724, 28.700065165758133, 18.24792042374611, 29.909365475177765, 38.41224521398544, 45.9131795167923, 6.120931003242731, 0.34375668852590024, 0.13948180217994377, 1.12411268055439, 5.707293748855591, 4.562750514596701, 4.723931215703487, 35.91105982661247, 61.07965908944607, 66.32405787706375, 63.360475301742554, 59.71970446407795, 62.06476382911205, 64.93358328938484, 60.54900236427784, 61.47227682173252, 57.680855467915535, 50.8874735981226, 45.909455716609955, 45.831267312169075, 43.4917214512825, 44.63519409298897, 44.5575300604105, 44.53514166176319, 42.97956973314285, 43.880163207650185, 44.79190528392792, 48.23685362935066, 48.99058498442173, 50.78566946089268, 51.59419387578964, 49.742762222886086, 48.76448571681976, 43.8565930724144, 41.609291061758995, 42.21586391329765, 40.951755344867706, 41.03642240166664, 40.16042120754719, 40.9557793289423, 42.033059522509575, 41.41562305390835, 42.06603415310383, 42.107113748788834, 42.76149943470955, 44.978095293045044, 43.8656859844923, 40.54632090032101, 39.685997664928436, 42.52765238285065, 40.61535179615021, 44.65478204190731, 47.49972738325596, 56.68984964489937, 54.74373087286949, 58.90790842473507, 51.76250584423542, 56.41033664345741, 47.38186150789261, 54.581661969423294, 29.14506308734417, 31.14392302930355, 63.83612617850304, 51.64206750690937, 56.67312674224377, 50.377119183540344, 53.97023677825928, 51.829868629574776, 53.034981563687325, 44.646065309643745, 39.708359465003014, 40.02403512597084, 42.34465800225735, 44.02291014790535, 40.59427052736282, 40.744860246777534, 49.519250616431236, 49.27993945777416, 52.668495029211044, 52.96316921710968, 55.41472166776657, 52.79180981218815, 53.53125773370266, 55.17951808869839, 53.8416288793087, 56.358948200941086, 54.35583248734474, 54.08060945570469, 55.72271794080734, 55.65275229513645, 52.75093540549278, 49.11260023713112, 43.0609879642725, 42.467949986457825, 42.397212982177734, 43.27629581093788, 46.92483343183994, 57.17370048165321, 56.17473788559437, 58.420045003294945, 56.833094358444214, 54.173491671681404, 48.42324502766132, 44.11232315003872, 42.24467396736145, 44.95107874274254, 47.06441514194012, 49.5280547440052, 53.00860337913036, 59.13769729435444, 58.3206195384264, 61.811575815081596, 58.018889129161835, 17.97498106956482, 1.9483186164870858, 6.8549699150025845, 14.81464410200715, 7.9768188670277596, 0.6299159489572048, 0.08953298514825292, 5.753767630085349, 32.679656222462654, 38.70989464223385, 25.096300542354584, 17.394529916346073, 35.919723361730576, 49.564810171723366, 49.43755120038986, 57.03603006899357, 30.68490006029606, 2.0851839473471045, 0.0733674353978131, 0.09563395855366252, 0.08938108978327364, 0.04329520706960466, 0.03441004439082462, 0.008850937610986875, 0.029507938197639305, 0.02768331247352762, 0.022166201488289516, 0.05045168516517151, 0.02908679351094179, 0.011181479840161046, 0.018470445211278275, 0.002861108937395329, 0.01647408280405216, 0.03167645103530958, 0.03105043277173536, 0.028153090097475797, 0.18216158699942753, 0.18394652637653053, 0.10123967455001548, 0.11396137706469744, 0.16560022020712495, 0.1524975139182061, 0.0978435251454357, 0.08808035723632202, 0.16077395965112373, 0.16870426770765334, 0.17078698641853407, 0.09854770454694517, 0.1088598019850906, 0.13422408665064722, 0.10812168417032808, 0.18309163162484765, 0.26371855521574616, 2.4338285392150283, 54.75978881120682, 79.33209747076035, 66.92692592740059, 57.82090075314045, 33.83126422762871, 24.422739185392857, 39.930225759744644, 51.57736077904701, 53.91496114432812, 7.485916083678603, 0.5095507577061653, 0.45528515707701445, 0.9403855924028903, 6.4235420152544975, 8.569735251367092, 6.262769317254424, 39.64349314570427, 61.33532457053661, 67.41551890969276, 63.574897795915604, 61.84760548174381, 62.71330922842026, 67.36905500292778, 63.97162690758705, 62.950435504317284, 59.00504261255264, 52.50980034470558, 47.22483493387699, 47.77520500123501, 46.05757936835289, 46.46986484527588, 45.69311812520027, 46.69675827026367, 44.13100674748421, 45.7331033796072, 46.73404946923256, 50.78285001218319, 50.594011545181274, 53.23548540472984, 54.93231475353241, 51.34850285947323, 52.23508268594742, 47.425008192658424, 44.86759342253208, 43.805706202983856, 42.73683875799179, 43.681794852018356, 42.6888245344162, 42.887713462114334, 44.014049023389816, 43.38411882519722, 43.291829377412796, 44.11855861544609, 43.697776794433594, 45.70816531777382, 44.888005927205086, 42.50909797847271, 43.60272869467735, 43.84995102882385, 43.15662883222103, 46.7793620377779, 49.05088394880295, 59.505148977041245, 57.686308175325394, 60.522551983594894, 53.332532197237015, 58.395562916994095, 49.625804498791695, 54.75437790155411, 31.20872475206852, 35.39137311279774, 64.28128749132156, 54.67044800519943, 58.724275678396225, 53.94703522324562, 57.34275721013546, 54.13629926741123, 54.22230005264282, 47.52748489379883, 42.36014977097511, 41.94279156625271, 45.280106887221336, 45.7192949205637, 42.86231182515621, 42.85711370408535, 51.71800643205643, 51.58125177025795, 53.905260264873505, 54.82145570218563, 58.129896372556686, 54.186851754784584, 55.402178540825844, 58.10123831033707, 57.54891514778137, 59.217006638646126, 57.36210577189922, 56.70597977936268, 56.44553795456886, 58.78010228276253, 55.29821991920471, 51.84058405458927, 44.719279780983925, 46.14152446389198, 45.26350177824497, 46.05633303523064, 48.093753308057785, 59.6668417006731, 58.851926028728485, 62.18283109366894, 58.61677564680576, 58.222953379154205, 50.76308727264404, 47.98332363367081, 45.46523675322533, 46.98034085333347, 48.59976075589657, 52.77865491807461, 55.62880218029022, 63.42332012951374, 60.93190401792526, 64.43786188960075, 58.04405137896538, 20.22343821823597, 8.340067025274038, 25.021919533610344, 16.509946882724762, 6.7123127449303865, 0.5823180405423045, 0.20368054480059072, 8.720011487603188, 44.02188040316105, 60.3581728041172, 41.82748295366764, 23.45081213861704, 42.24161133170128, 57.094999104738235, 58.086160719394684, 65.54914265871048, 39.24310103058815, 3.1759783532470465, 0.22737438121112064, 0.15220169385429472, 0.1702449217555113, 0.11719969392288476, 0.11730953177902848, 0.091358408681117, 0.14982901804614812, 0.12017253713565879, 0.12113497650716454, 0.20261062018107623, 0.1976864703465253, 0.09589859357220121, 0.19125791295664385, 0.1338125063921325, 0.16306287667248398, 0.08013072365429252, 0.14803549944190308, 0.18321481329621747], [0.021396922747953795, 0.034392166053294204, 0.026080523966811597, 0.020105296352994628, 0.041188761897501536, 0.16317529720254242, 0.023244918702403083, 0.025499817529635038, 0.09579067045706324, 0.03121660149190575, 0.04869649106694851, 0.014490130961348768, 0.052355308798723854, 0.047247855909517966, 0.0683670595753938, 0.05011449036828708, 0.07648327562492341, 3.6566383112221956, 51.18259996175766, 53.135277181863785, 44.87848363816738, 34.90197457373142, 19.608690105378628, 21.44080739468336, 42.20050133764744, 40.176171362400055, 27.337562777101994, 0.3482936747604981, 0.02991023604408838, 0.08141613827319816, 0.5446935875806957, 3.19037483073771, 5.526903178542852, 5.9941574558615685, 42.180674001574516, 62.27098636329174, 63.58124725520611, 59.83912065625191, 64.94808331131935, 55.24045541882515, 60.12645363807678, 56.214909330010414, 56.35559678077698, 56.780717968940735, 54.71973516047001, 48.086199313402176, 41.26713842153549, 41.786737740039825, 41.044838950037956, 41.84788405895233, 41.39347404241562, 39.649766609072685, 42.34935835003853, 45.80322101712227, 48.982126638293266, 53.42128403484821, 52.59894356131554, 52.74361699819565, 50.267099887132645, 49.538021609187126, 48.50050628185272, 39.494905918836594, 40.588491037487984, 38.495836928486824, 39.96814392507076, 38.10171067714691, 39.46139931678772, 36.572714522480965, 40.95985651016235, 38.08486618101597, 39.767529889941216, 40.351243168115616, 41.17742523550987, 39.213948994874954, 41.93505518138409, 38.1029038131237, 42.19881422817707, 40.90234659612179, 41.99517175555229, 42.19145022332668, 51.89718581736088, 50.58354690670967, 56.91196292638779, 51.76706939935684, 55.22701933979988, 49.373764023184776, 56.909466460347176, 27.0430538803339, 27.142908722162247, 55.073492377996445, 49.94383603334427, 54.27746929228306, 51.63788013160229, 53.81647042930126, 51.29755899310112, 51.743997037410736, 46.57592095434666, 41.42922252416611, 38.61529491841793, 39.95614796876907, 39.099024161696434, 41.84216536581516, 39.12486657500267, 42.76456966996193, 45.235189497470856, 49.26140785217285, 52.11294203996658, 53.64818885922432, 53.93876686692238, 53.11936743557453, 52.562473118305206, 50.22071957588196, 49.22785945236683, 48.827668726444244, 50.677208080887794, 49.901069328188896, 47.448958307504654, 42.58494570851326, 39.709981977939606, 39.5898400247097, 39.10910502076149, 41.02385647594929, 39.99185085296631, 43.95475700497627, 54.65461425483227, 56.315641924738884, 55.08953511714935, 53.47247488796711, 54.01662848889828, 52.12471380829811, 47.906712144613266, 42.276364266872406, 43.127871975302696, 47.769824489951134, 45.55618867278099, 45.93559831380844, 47.73492716252804, 55.97852401435375, 56.83992639183998, 61.96470759809017, 43.776223585009575, 9.396820720285177, 6.895585460588336, 4.675182206556201, 1.3387905922718346, 2.0772409485653043, 0.06885511815198697, 1.0158450901508331, 24.04890764504671, 35.730881094932556, 29.26618918776512, 26.03935293853283, 27.9013879224658, 38.458492532372475, 47.54659406840801, 45.884209871292114, 45.36401018500328, 7.266024732962251, 0.07816968747647479, 0.1074713104753755, 0.08639563005999662, 0.04901555148535408, 0.033368725853506476, 0.08591085919761099, 0.07736446466878988, 0.04270249824912753, 0.02590364976640558, 0.03605564925237559, 0.08213039604015648, 0.021714331887778826, 0.040639186699991114, 0.046413474119617604, 0.032400976415374316, 0.05645705510687549, 0.021204656404734123, 0.018227870532427914, 0.008838998310238821, 0.04334903875133023, 0.011369984422344714, 0.07735538820270449, 0.04914098186418414, 0.06753813257091679, 0.08750510372919962, 0.08658112987177446, 0.051663378544617444, 0.04762605807627551, 0.017444375953346025, 0.018238841330457944, 0.013357888201426249, 0.052967769879614934, 0.00925593316424056, 0.0952184152265545, 0.14412145712412894, 5.6329607125371695, 59.058072566986084, 59.79038067162037, 51.27871200442314, 41.24421805143356, 26.58070418983698, 24.035836346447468, 37.588172033429146, 42.23764814436436, 33.794945776462555, 0.30935170187149197, 0.06517019908642396, 0.07403262978186831, 3.821149058640003, 8.974160850048065, 5.579030681401491, 8.734948486089706, 42.16441847383976, 63.2006710767746, 65.39476454257965, 61.87119461596012, 65.3011603653431, 57.20168977975845, 61.5558647364378, 57.222527861595154, 56.89417988061905, 58.25309716165066, 56.917810812592506, 48.78796465694904, 43.77260237932205, 43.67946557700634, 43.40561047196388, 43.36018770933151, 42.412066385149956, 42.53571555018425, 43.9614712446928, 47.576901242136955, 51.174741983413696, 54.13108974695206, 54.22877110540867, 54.954057186841965, 52.669490575790405, 51.13816134631634, 50.250798761844635, 41.74605332314968, 42.85667672753334, 40.541149377822876, 42.03084424138069, 41.273898258805275, 41.58592231571674, 40.23122660815716, 42.804938703775406, 39.51187580823898, 42.494103983044624, 40.52369311451912, 43.11777971684933, 39.844525158405304, 42.20608703792095, 39.70248498022556, 42.51968041062355, 42.93985426425934, 43.22290487587452, 45.228980630636215, 54.26975570619106, 53.1306566298008, 58.26951988041401, 53.18645283579826, 56.77574023604393, 51.959095895290375, 56.98144219815731, 28.07719498872757, 28.684947676956654, 57.82202169299126, 51.856835782527924, 57.22695842385292, 52.71660424768925, 55.99713921546936, 53.68046812713146, 53.54314349591732, 49.24179330468178, 42.249712496995926, 39.684128165245056, 41.71629711985588, 41.3841113448143, 44.71455663442612, 40.25678403675556, 44.60312761366367, 48.941856399178505, 50.37192106246948, 53.87892007827759, 55.78453302383423, 56.22884318232536, 55.582866445183754, 54.688630029559135, 52.17674821615219, 51.644069999456406, 52.38328613340855, 53.86267215013504, 52.33151011168957, 52.18310907483101, 44.1779912263155, 41.89355380833149, 41.12963140010834, 42.180373817682266, 41.861760914325714, 41.19263581931591, 45.683037266135216, 56.1109659075737, 57.09453172981739, 57.49841205775738, 55.12286312878132, 57.72587165236473, 52.98476725816727, 50.679016783833504, 44.05326671898365, 45.81438861787319, 49.639635756611824, 49.49903950095177, 47.567880526185036, 51.964301615953445, 58.66452768445015, 59.69311349093914, 62.278141379356384, 49.374208599328995, 7.441871697083116, 4.655800396576524, 5.497795315459371, 3.0806882539764047, 2.565461313351989, 0.1209776708856225, 1.2291240831837058, 26.672761850059032, 41.98751896619797, 31.07957348227501, 29.42334495484829, 35.77815055847168, 45.85185080766678, 53.345018327236176, 53.07773306965828, 53.66612009704113, 11.601652409881353, 0.14535376365529373, 0.05698182401829399, 0.08787576196482405, 0.008649758074170677, 0.028266043118492234, 0.05040807656769175, 0.10133418705663644, 0.050613851853995584, 0.025113538940786384, 0.010795671587402467, 0.06481077696662396, 0.03065540611714823, 0.06357599908369593, 0.06902435008669272, 0.0549566848349059, 0.03524546518747229, 0.068298982369015, 0.00407053204071417, 0.08993476163595915, 0.1168773569224868, 0.089085150975734, 0.10713180017773993, 0.06248329795198515, 0.3483612695708871, 0.17287271824898198, 0.17869173490907997, 0.26175127015449107, 0.12430874136043712, 0.13851733674528077, 0.10079612999106757, 0.13206710864324123, 0.14683381392387673, 0.10987587636918761, 0.14379440748598427, 0.22869222768349573, 7.916525602340698, 68.35887148976326, 68.22158485651016, 60.21720036864281, 48.72921600937843, 31.24173928052187, 31.560424380004406, 55.92028073966503, 53.77431929111481, 37.572281286120415, 0.5891653324943036, 0.18835758499335498, 0.1795299313380383, 4.189206808805466, 14.151990059763193, 14.177483841776848, 12.432835958898067, 47.04403683543205, 66.82817682623863, 67.16408640146255, 64.31151106953621, 68.69867205619812, 59.65192750096321, 64.32838216423988, 59.95800867676735, 59.11767236888409, 60.89372746646404, 59.309068098664284, 52.40885116159916, 44.82492931187153, 45.04680700600147, 45.111544132232666, 44.228821098804474, 45.55955529212952, 44.15441729128361, 46.279612854123116, 49.9325430393219, 52.52785697579384, 56.22607313096523, 56.934119537472725, 58.17905053496361, 54.23757903277874, 52.889597564935684, 53.06843876838684, 43.766765892505646, 46.20243139564991, 41.621089428663254, 43.91428917646408, 42.34377644956112, 44.23270829021931, 41.443771943449974, 44.86517295241356, 41.231074556708336, 44.30251434445381, 44.353633001446724, 45.15347108244896, 41.62273094058037, 45.94406045973301, 42.33943708240986, 45.03214739263058, 45.009310618042946, 45.235333889722824, 47.834801003336906, 55.92267841100693, 55.54497107863426, 61.55199274420738, 56.64001151919365, 59.59230490028858, 55.111566334962845, 57.33067385852337, 30.727343782782555, 31.45769689232111, 56.626647636294365, 54.17501159012318, 57.70444080233574, 54.7850726544857, 56.40793897211552, 55.428522527217865, 55.27843438088894, 51.742743104696274, 46.093726828694344, 41.438395231962204, 43.75155910849571, 42.85025127232075, 47.33524940907955, 42.44936138391495, 47.55958177149296, 50.872061625123024, 55.11438958346844, 56.320076286792755, 57.370982095599174, 58.14461678266525, 57.337471693754196, 57.773733884096146, 53.8442887365818, 55.65580353140831, 53.858860954642296, 56.09289787709713, 54.5605693012476, 52.545450031757355, 46.918882951140404, 44.18207220733166, 43.88601869344711, 43.67938958108425, 45.5913519859314, 44.68352369964123, 48.87150317430496, 59.92804728448391, 61.56872324645519, 58.65635432302952, 57.46351093053818, 60.063308626413345, 57.19252847135067, 55.108967274427414, 46.682672426104546, 48.379813358187675, 51.083945855498314, 51.21662333607674, 49.38247315585613, 54.2311991751194, 61.31268158555031, 61.96633391082287, 66.27019956707954, 50.45016646385193, 11.462964601814747, 15.08505279198289, 9.258186109364033, 4.704548455774784, 3.137461245059967, 0.2158180286642164, 1.5293975081294775, 34.41133730113506, 50.96136063337326, 42.63173259794712, 35.55217668414116, 38.533010333776474, 51.30390465259552, 59.83832649886608, 59.76795807480812, 63.48045766353607, 15.72170102968812, 0.47992353967856616, 0.22498309233924374, 0.1639511383837089, 0.0935402189497836, 0.10088099457789212, 0.1766250465880148, 0.22710000921506435, 0.0837216126092244, 0.15320678445277736, 0.14796483214013278, 0.1486474002012983, 0.15625946049112827, 0.19354064046638086, 0.14316997927380726, 0.1301004469860345, 0.12341406749328598, 0.14743876818101853, 0.19020740292035043], [0.09904605671181343, 0.04088294139364734, 0.01924342355778208, 0.04938395359204151, 0.030438105277426075, 0.07227836336824112, 0.024024917765927967, 0.0485686821048148, 0.008067370672506513, 0.02229377110779751, 0.03032006112334784, 0.04598005616571754, 0.020699116539617535, 0.03240236052079126, 0.02337619720492512, 0.009562230497976998, 0.13845331908669323, 10.52386874333024, 47.903220131993294, 54.56944182515144, 51.462181359529495, 38.52080538868904, 16.84567216783762, 23.688075207173824, 38.151225820183754, 40.58722950518131, 18.49466398358345, 0.15478383342269808, 0.08958029706263915, 0.20841679768636823, 2.5063379108905792, 5.8659181371331215, 2.0135922264307737, 9.698773417621851, 50.95962032675743, 61.72094687819481, 60.270682498812675, 57.60971188545227, 62.05649547278881, 60.62429912388325, 55.30926212668419, 53.008861765265465, 57.64577195048332, 56.621666103601456, 59.17834371328354, 49.31012503802776, 41.507931500673294, 40.72741538286209, 41.81023567914963, 43.4153987467289, 40.842522606253624, 40.272222608327866, 46.39431729912758, 49.36633542180061, 56.22840240597725, 54.551092609763145, 55.461227372288704, 53.45748469233513, 54.71927918493748, 51.88057690858841, 47.28609524667263, 39.28071901202202, 40.9676156938076, 39.1734279692173, 40.123046413064, 37.46495984494686, 40.94866991043091, 38.598936796188354, 40.31045235693455, 38.5971736907959, 40.705688148736954, 38.5967443138361, 40.66445276141167, 37.98257187008858, 39.51901562511921, 38.974238857626915, 40.78344717621803, 38.56534279882908, 44.01834279298782, 37.56516806781292, 43.150731548666954, 43.437296971678734, 52.17487871646881, 49.225822761654854, 54.14885759353638, 47.975560650229454, 60.56222565472126, 30.239218175411224, 26.643370427191257, 51.65966436266899, 45.381508246064186, 51.35344639420509, 47.88963206112385, 49.936441630125046, 51.16489291191101, 54.19701240956783, 50.53802154958248, 42.784476801753044, 38.458047956228256, 42.093670070171356, 39.80382174253464, 39.71712939441204, 39.245396107435226, 39.91460479795933, 41.07784017920494, 50.04167318344116, 49.02152672410011, 54.10107135772705, 56.627840772271156, 52.21391402184963, 51.82139128446579, 46.63373485207558, 44.32141453027725, 46.594262570142746, 45.811907351017, 45.171140134334564, 43.145674020051956, 38.753128722310066, 40.04165858030319, 41.09869346022606, 41.94304995238781, 38.12020428478718, 40.6942355632782, 40.807347893714905, 49.812667071819305, 52.99111291766167, 53.39209780097008, 53.859932497143745, 56.55347116291523, 56.096933260560036, 53.56511011719704, 48.64692762494087, 50.62040492892265, 54.94759373366833, 55.118272975087166, 53.366730362176895, 50.80436825752258, 50.469621419906616, 57.02046610414982, 59.85370047390461, 61.32071815431118, 20.314452834427357, 4.436331773176789, 10.65918043255806, 4.927146211266518, 9.810638464987278, 0.9280695032794029, 0.1336968649411574, 8.968024179339409, 32.925662621855736, 30.672778710722923, 15.383978001773357, 16.593371406197548, 32.40439139306545, 45.08575111627579, 43.464712500572205, 51.407205909490585, 25.37003595381975, 0.20676422776887193, 0.04153922258410603, 0.04866430412221234, 0.039824627674533986, 0.028049786851624958, 0.06292284233495593, 0.043184415553696454, 0.057842370224534534, 0.049589884729357436, 0.032999503673636355, 0.03965500982303638, 0.01915898385050241, 0.041128020820906386, 0.037120252673048526, 0.0430958328070119, 0.028513439901871607, 0.045237600497785024, 0.08250279832282104, 0.03627552905527409, 0.05936978064710274, 0.01963921091373777, 0.015964013982738834, 0.09201444496284239, 0.036436630762182176, 0.047549208684358746, 0.07819670165190473, 0.028211691933393013, 0.03899433882907033, 0.004655631064451882, 0.020641370028897654, 0.03786946559557691, 0.02071909144433448, 0.04240481910528615, 0.03823590472165961, 0.12515446316683665, 14.682206958532333, 59.73851725459099, 61.670778170228004, 57.65888884663582, 45.46846278011799, 21.513222008943558, 27.891926430165768, 38.55213090777397, 44.30394306778908, 20.485686846077442, 0.1006971942842938, 0.17289956915192306, 0.514786698622629, 4.735051319003105, 9.692915081977844, 5.5583669152110815, 11.096207331866026, 53.4360234439373, 65.31395807862282, 62.63332352042198, 59.04918484389782, 64.53475669026375, 61.109643280506134, 57.75454491376877, 54.47179466485977, 59.727307856082916, 59.9758031219244, 61.983531787991524, 51.574765518307686, 43.301347866654396, 43.40162068605423, 44.73797857761383, 44.73875753581524, 43.29102382063866, 42.81411521136761, 48.68397943675518, 52.005077227950096, 57.23732806742191, 56.726316288113594, 56.565885096788406, 56.1900282651186, 56.22433662414551, 54.127624332904816, 48.76346357166767, 41.05876140296459, 42.917135283350945, 41.60813972353935, 43.07829223573208, 40.33192500472069, 42.864793092012405, 40.13477638363838, 40.9531232714653, 41.45737521350384, 42.31898657977581, 40.537820756435394, 42.351353242993355, 40.10774463415146, 42.146673426032066, 40.87703995406628, 43.28473135828972, 41.03958003222942, 44.65052247047424, 40.40642000734806, 45.191412046551704, 46.04019150137901, 52.83898428082466, 50.319426879286766, 57.2476901113987, 49.827440679073334, 63.42202439904213, 32.85356529057026, 27.83168636262417, 51.78413428366184, 46.26466065645218, 54.237335845828056, 50.46315036714077, 53.37161310017109, 51.54426835477352, 56.785357519984245, 53.54837201535702, 44.23415221273899, 41.1018168926239, 42.8662484139204, 41.217490285634995, 42.18122497200966, 42.14432895183563, 41.99542634189129, 43.576867282390594, 52.21468158066273, 51.24750807881355, 54.89773280918598, 56.44272990524769, 54.72692057490349, 53.520207926630974, 48.14821198582649, 46.233494728803635, 47.87601739168167, 47.518752962350845, 46.735178008675575, 44.878065660595894, 41.72593720257282, 41.01585790514946, 41.968694776296616, 43.65460731089115, 41.358724907040596, 42.22731649875641, 43.343263417482376, 53.80256697535515, 54.505445659160614, 54.34405691921711, 55.330286398530006, 57.90170721709728, 58.04322302341461, 54.18645277619362, 51.64513774216175, 52.966414242982864, 56.479865312576294, 57.863564863801, 55.3254758566618, 53.71493987739086, 51.56693033874035, 58.89039136469364, 58.62462982535362, 64.36553657054901, 24.200648702681065, 2.1458367677405477, 5.395198445767164, 7.090417630970478, 5.889001423493028, 0.9372411423828453, 0.2982313313987106, 11.680062152445316, 38.77346523106098, 26.374373361468315, 16.91146183758974, 23.72658994048834, 38.87011684477329, 50.36620236933231, 50.375739857554436, 58.671169728040695, 33.419138342142105, 0.7584964181296527, 0.04965393207385205, 0.09215894853696227, 0.03364461925229989, 0.08414193536737002, 0.020342102689028252, 0.05168306772247888, 0.02702906476770295, 0.013235624937806278, 0.047715193722979166, 0.012741169048240408, 0.026832471703528427, 0.036259535772842355, 0.03331421139591839, 0.04581345885526389, 0.03864687641907949, 0.09342209130409174, 0.020475054734561127, 0.2042644369066693, 0.14925918221706524, 0.10232617874862626, 0.15680397424148396, 0.1605198928155005, 0.19231905054766685, 0.06771990680135787, 0.19024023553356528, 0.0711572973523289, 0.10082999418955296, 0.12246351732756011, 0.16848803556058556, 0.15198860841337591, 0.12419350809068419, 0.10373507189797238, 0.11176847168826498, 0.2695320057682693, 19.00335978716612, 67.92137056589127, 71.10824435949326, 66.60930097103119, 52.67655439674854, 25.646682009100914, 33.54408323764801, 52.402459904551506, 55.32380014657974, 24.525405876338482, 0.24629858293337747, 0.233006302441936, 0.42651805852074176, 6.88498972915113, 14.412058554589748, 7.161059165373445, 14.271573442965746, 57.7031222730875, 65.50368189811707, 65.01761958003044, 59.94770362973213, 66.12854316830635, 63.21425914764404, 60.98149515688419, 55.494224801659584, 60.75712859630585, 61.948391273617744, 65.29976963996887, 53.57061982154846, 46.76772706210613, 44.61333006620407, 46.67117804288864, 48.47565561532974, 43.786752820014954, 45.916409343481064, 50.38862116634846, 53.588243275880814, 58.35199825465679, 58.11266429722309, 58.23322042822838, 57.419243305921555, 59.19981636106968, 55.511487275362015, 51.16798594594002, 43.481108620762825, 45.185453966259956, 43.991569429636, 44.30356688797474, 41.56037628650665, 44.91097949445248, 42.579135820269585, 44.133602008223534, 42.2532045096159, 44.981659501791, 42.23443731665611, 45.57384632527828, 42.82849743962288, 43.62140849232674, 44.290073812007904, 45.30707024037838, 43.301013484597206, 47.09257923066616, 41.23417519032955, 47.030292972922325, 48.150640055537224, 55.86040735244751, 54.415937662124634, 59.75561633706093, 52.42349557578564, 65.45704320073128, 34.71086002886295, 29.869304224848747, 50.794044211506844, 48.23075495660305, 55.04511930048466, 51.165941655635834, 53.747880309820175, 54.142998307943344, 57.863952443003654, 55.336502864956856, 46.54201917350292, 43.66691865026951, 46.870648339390755, 43.46902906894684, 43.03730383515358, 43.95145118236542, 45.62858238816261, 45.38145884871483, 55.4441586881876, 55.047064796090126, 58.00535045564175, 60.48859320580959, 57.14875862002373, 56.792440339922905, 49.53090079128742, 48.94044667482376, 50.8782134950161, 50.48244573175907, 48.544165939092636, 48.633278757333755, 43.50831136107445, 43.74848507344723, 44.32200349867344, 47.52927839756012, 44.11537438631058, 45.01901529729366, 44.6855603903532, 56.31452478468418, 58.06125685572624, 56.534430384635925, 57.70422041416168, 60.55209919810295, 59.73737731575966, 57.63710841536522, 52.75859199464321, 56.10370449721813, 59.206131622195244, 60.0750157982111, 59.65724341571331, 56.03685088455677, 55.35339295864105, 62.401539757847786, 62.957278937101364, 65.51687479019165, 25.17784606665373, 8.086057305335999, 23.99105954915285, 11.331761442124844, 15.744213871657848, 1.9064421323128045, 0.2919886523159221, 13.327860832214355, 45.818910375237465, 41.84042125940323, 22.809264063835144, 26.96188073605299, 44.61683347821236, 59.46979567408562, 57.07414202392101, 65.25735631585121, 39.879076704382896, 1.9605446979403496, 0.28305663785431534, 0.17289973242441192, 0.10775219852803275, 0.1640181543189101, 0.21251934551401064, 0.16970299067907035, 0.1617916816030629, 0.11289961606962606, 0.13071769120870158, 0.10767258092528209, 0.21004229405662045, 0.13180041045416147, 0.12636790430406108, 0.10136448894627392, 0.15772729500895366, 0.24911487009376287, 0.2689970360370353], [0.022110883655841462, 0.01894076274766121, 0.07534109550761059, 0.05221238599915523, 0.0824829755583778, 0.01952985916432226, 0.03856174094835296, 0.053207591190584935, 0.022069278857088648, 0.017218406828760635, 0.07496717182220891, 0.03805845721217338, 0.10937826635199599, 0.022076973073126283, 0.03218035075406078, 0.03643045980425086, 0.35326190816704184, 19.50798410922289, 52.38438047468662, 49.45998139679432, 42.486747577786446, 26.40003528445959, 20.84769532084465, 36.25817500054836, 36.41340807080269, 39.882564917206764, 12.05497283488512, 0.23992335627553985, 0.09451611345866695, 0.08931273056077771, 2.940202667377889, 7.212814763188362, 4.470401694998145, 15.069584771990776, 58.100071772933006, 61.19826592504978, 57.57979989051819, 56.441715359687805, 57.592514008283615, 60.165739730000496, 62.23909467458725, 57.11239077150822, 58.00120867788792, 56.820669025182724, 57.788173109292984, 47.63839714229107, 39.73783828318119, 39.890567287802696, 40.603420436382294, 40.86098961532116, 41.39542333781719, 43.13751965761185, 48.96394841372967, 53.55114966630936, 53.62995743751526, 51.610616594552994, 52.47418865561485, 52.52194069325924, 55.07579505443573, 54.16464574635029, 45.05187973380089, 39.43557970225811, 41.75913602113724, 39.80617381632328, 42.29417771100998, 38.75771127641201, 40.665060728788376, 40.22910252213478, 41.1314857006073, 37.30116583406925, 40.517343655228615, 38.62280331552029, 40.14088645577431, 38.60205642879009, 40.471955090761185, 37.052548974752426, 42.82418467104435, 42.052130699157715, 45.843065679073334, 45.39919249713421, 43.24777454137802, 39.907278791069984, 44.34042111039162, 39.964150339365005, 51.37561060488224, 48.237678185105324, 59.81881454586983, 29.317380040884018, 22.89985690265894, 56.17134466767311, 45.75953096151352, 54.92833636701107, 50.80916740000248, 50.11241398751736, 49.181885719299316, 52.38745830953121, 53.39780129492283, 47.84073248505592, 39.4000706076622, 40.832901522517204, 38.5379234701395, 42.20871649682522, 39.077749103307724, 40.56805953383446, 37.223023027181625, 43.99861805140972, 46.85700327157974, 53.54970954358578, 49.14598144590855, 47.78289958834648, 44.398052617907524, 40.683162957429886, 39.8474358022213, 39.21893052756786, 39.45386052131653, 39.79459583759308, 37.77590475976467, 40.92011444270611, 39.3589948117733, 39.76637855172157, 39.67615619301796, 41.586522683501244, 40.88147811591625, 46.22439041733742, 52.78470799326897, 55.474906638264656, 53.85647088289261, 49.52830173075199, 51.41912966966629, 53.602788895368576, 55.54480388760567, 54.07202571630478, 53.66392381489277, 56.305857449769974, 58.606436401605606, 54.57355700433254, 52.932447865605354, 49.24379959702492, 57.2369746863842, 52.08187110722065, 61.46224915981293, 41.39717124402523, 7.360713751986623, 5.062953773885965, 0.6601425551343709, 2.346184104681015, 1.84580854838714, 0.1680819026660174, 1.5274590183980763, 33.7942998111248, 45.30881054699421, 36.65244944393635, 22.63020247220993, 25.678832083940506, 45.54080709815025, 43.866563737392426, 47.789454236626625, 40.32805301249027, 4.34990493580699, 0.12809596548322588, 0.04530483165581245, 0.012346011590125272, 0.04764131663250737, 0.05609437124803662, 0.09399194197612815, 0.06763808502000757, 0.033795980270951986, 0.009375090539833764, 0.10310224999557249, 0.038084317347966135, 0.01242419313712162, 0.03977355678216554, 0.054570497159147635, 0.007058499759295955, 0.04609920426446479, 0.00842215715238126, 0.033476437456556596, 0.06414310380932875, 0.08423568346188404, 0.05768333168816753, 0.07531963259680197, 0.043943480486632325, 0.03229725385608617, 0.04751421271066647, 0.050683053414104506, 0.055664044339209795, 0.043102790441480465, 0.05665578741172794, 0.0396208561869571, 0.05015855538658798, 0.06316325365332887, 0.036455321751418523, 0.4615282517625019, 26.391489543020725, 62.35040210187435, 56.954725831747055, 49.18902933597565, 30.955170057713985, 21.48078504949808, 29.74697358906269, 37.06773675978184, 45.94470642507076, 11.962500046938658, 0.3110020898748189, 0.04383247374789789, 0.8484625874552876, 7.756461091339588, 5.730086825788021, 3.3308753790333867, 16.435869857668877, 61.01141095161438, 62.303858399391174, 61.21375389397144, 58.3448888361454, 61.005969643592834, 61.893210634589195, 64.3124458193779, 58.99304285645485, 60.502804443240166, 59.94542375206947, 59.39724616706371, 48.571433275938034, 41.42515294253826, 42.056264877319336, 43.218082934617996, 42.75529816746712, 43.59860211610794, 45.252622961997986, 50.85106775164604, 54.439443200826645, 58.347430899739265, 52.78680928051472, 53.54103460907936, 54.03846591711044, 56.23666696250439, 55.6582847982645, 48.315224424004555, 41.18315152823925, 44.40047308802605, 40.23401565849781, 42.617775946855545, 41.345938593149185, 41.94931961596012, 40.72709619998932, 41.75339072942734, 41.19111590087414, 40.56393675506115, 40.5159567296505, 40.52115485072136, 40.17978876829147, 41.46597035229206, 40.42228415608406, 42.9118649661541, 42.66949117183685, 46.88477598130703, 45.8773398399353, 44.90382827818394, 41.67684763669968, 44.988977909088135, 42.01295480132103, 52.82567359507084, 50.604191198945045, 62.91793964803219, 31.226610392332077, 25.011717081069946, 55.29429852962494, 47.30178460478783, 56.77996940910816, 49.994168132543564, 52.639297395944595, 48.41669037938118, 53.96805189549923, 54.67270888388157, 49.14112150669098, 40.76084218919277, 42.46379680931568, 41.02729149162769, 43.847294971346855, 41.232351288199425, 42.54997618496418, 39.87115032970905, 44.913251772522926, 48.49477618932724, 54.422002136707306, 52.55171209573746, 51.95952147245407, 45.90886674821377, 43.297589868307114, 41.04288965463638, 41.46267592906952, 41.50393411517143, 42.16637156903744, 40.79624488949776, 41.96184754371643, 40.81350356340408, 42.14233785867691, 41.123772114515305, 44.233023673295975, 43.27743574976921, 49.240117594599724, 53.344759941101074, 56.96041792631149, 54.76977847516537, 52.372916489839554, 53.4225569665432, 57.16664046049118, 58.714798986911774, 56.63238912820816, 55.31136341392994, 58.239186108112335, 59.79185879230499, 56.797456070780754, 54.22080673277378, 52.545020654797554, 57.456013932824135, 56.26238778233528, 61.48295044898987, 47.9160026460886, 6.132053006440401, 1.904121763072908, 6.745901992544532, 6.527767572551966, 3.6006274167448282, 0.12673275894485414, 1.634319021832198, 37.47513189911842, 41.36466398835182, 28.209180906414986, 28.225086852908134, 32.987249717116356, 50.624326318502426, 50.24346515536308, 52.79152102768421, 50.47966048121452, 7.080316348001361, 0.1573220972204581, 0.06354136305162683, 0.04888477393251378, 0.03316764465125743, 0.011570437582122395, 0.10545326993451454, 0.057073761272476986, 0.02197705030994257, 0.012871878880105214, 0.04088297107955441, 0.05838731442054268, 0.016941711910476442, 0.011653450510493712, 0.06619310122914612, 0.06778710085200146, 0.053752687526866794, 0.03571055429347325, 0.10755581883131526, 0.11579144644201733, 0.16709702817024663, 0.1620978323626332, 0.1425861762254499, 0.13555872050346807, 0.20056570647284389, 0.2541985223069787, 0.13092243490973487, 0.12915398605400696, 0.17332720948616043, 0.15025545610114932, 0.1356670295353979, 0.2804658893728629, 0.15345809049904346, 0.10057721126941033, 0.7510657387319952, 32.021512538194656, 71.54168710112572, 64.92517054080963, 57.378794476389885, 36.17999419569969, 31.371278129518032, 46.71706438064575, 49.69832360744476, 54.47439752519131, 15.102701894938946, 0.43917871196754277, 0.22851169283967465, 1.0721452441066504, 9.691572804003954, 14.681439399719238, 10.834383331239223, 19.798602014780045, 61.472007036209106, 65.65802201628685, 62.754673808813095, 61.78821086883545, 62.667977660894394, 65.02683788537979, 66.21849954128265, 60.98637789487839, 61.165245696902275, 61.10974207520485, 61.13276124000549, 51.46228775382042, 42.91534177958965, 44.38180088996887, 45.09268194437027, 44.60901349782944, 45.27743183076382, 48.67547549307346, 54.091951847076416, 58.79299879074097, 58.105258494615555, 54.17513318359852, 54.24202099442482, 55.55254027247429, 59.069091975688934, 58.607952520251274, 49.8277522623539, 45.58078095316887, 46.468721106648445, 43.681905046105385, 45.15991933643818, 43.20958659052849, 44.673427641391754, 43.52105587720871, 43.909756019711494, 42.80565306544304, 44.073181450366974, 42.18908675014973, 43.61973658204079, 43.463564962148666, 44.78050969541073, 41.73637144267559, 47.1113046258688, 46.54003947973251, 49.59020420908928, 49.82114441692829, 47.21310496330261, 46.54676511883736, 47.82133832573891, 44.55467261373997, 55.3232491761446, 54.181304052472115, 64.27700892090797, 34.5699217915535, 26.15304473787546, 56.60612873733044, 50.99270135164261, 58.60123448073864, 53.743730932474136, 52.38809287548065, 50.71666516363621, 56.13348729908466, 58.44149485230446, 53.16745005548, 42.313408479094505, 44.65354710817337, 43.3862467110157, 46.19160197675228, 43.583581522107124, 44.76798556745052, 41.95416435599327, 48.55540573596954, 50.34313000738621, 59.45335775613785, 55.103446170687675, 53.38515557348728, 48.54920446872711, 45.63322953879833, 44.11046124994755, 43.917173221707344, 42.98120744526386, 43.455330803990364, 41.685583367943764, 45.24384543299675, 43.366613164544106, 43.55595700442791, 43.872377425432205, 46.338232308626175, 45.96338242292404, 51.46734908223152, 59.823332503437996, 59.9066012352705, 57.50487931072712, 52.406214103102684, 56.612884774804115, 60.314509347081184, 61.31512485444546, 59.44593295454979, 57.63630285859108, 62.2699224203825, 63.05840291082859, 59.34977151453495, 57.614818811416626, 55.04050634801388, 62.701609656214714, 58.385280668735504, 64.83503937721252, 47.917944341897964, 10.06518205627799, 12.806350216269493, 6.5805647894740105, 3.481129528954625, 2.838727687485516, 0.2505624439800158, 2.035449603572488, 47.49440386891365, 59.87945169210434, 49.54770348966122, 32.127587646245956, 36.11903786659241, 57.24356733262539, 58.25502745807171, 61.29001960158348, 58.29842872917652, 10.654563680291176, 0.27802288765087724, 0.19573763507651165, 0.1158795393712353, 0.09324019090854563, 0.10414378746645525, 0.22500314516946673, 0.15318325837142766, 0.10168097782297991, 0.17178167210659012, 0.21209118567639962, 0.1268788581364788, 0.08291470512631349, 0.08816697329166345, 0.18603340111440048, 0.09839810241828673, 0.18713986908551306, 0.11702727075316943], [0.05189491748751607, 0.05320150186889805, 0.10053939884528518, 0.04439046490006149, 0.016684782240190543, 0.05790107410575729, 0.07049676365568303, 0.06171713066578377, 0.07873201277107, 0.023267561628017575, 0.0529491642373614, 0.013016536449868, 0.017084655119106174, 0.009240663475793554, 0.02844497863407014, 0.08736110481549986, 1.8808994279243052, 32.46650665998459, 55.91105483472347, 49.354031682014465, 45.33653765916824, 28.02479960024357, 25.266645401716232, 49.162882938981056, 35.91070644557476, 39.987028911709785, 2.8635097201913595, 0.20445781090529636, 0.12109022500226274, 1.7456291802227497, 5.643629115074873, 8.142366483807564, 3.7272280734032393, 24.011044576764107, 64.05409768223763, 61.21245056390762, 56.60895198583603, 53.49271260201931, 56.602560728788376, 55.729253590106964, 56.58873327076435, 56.17514446377754, 56.667028069496155, 55.90470917522907, 50.82080617547035, 42.95516364276409, 41.12348712980747, 40.985102355480194, 40.17681732773781, 40.441856905817986, 42.251965776085854, 48.87262411415577, 52.95223720371723, 53.216277435421944, 50.33053368330002, 51.98425054550171, 50.834272652864456, 54.779543951153755, 52.77990885078907, 50.21593563258648, 41.39462538063526, 39.652871042490005, 41.94934621453285, 38.46078000962734, 40.583433508872986, 37.29524955153465, 41.56422547996044, 40.88532730937004, 39.8861975222826, 38.4014043956995, 40.66528491675854, 39.34275068342686, 40.061254128813744, 38.502919748425484, 39.11291241645813, 39.56558972597122, 47.71818146109581, 49.622426480054855, 53.7031377106905, 48.559539914131165, 53.3335467427969, 49.34660688042641, 50.45825622975826, 45.38680896162987, 53.93954202532768, 45.633438527584076, 60.33245578408241, 29.154108501970768, 26.081796661019325, 56.71843931078911, 49.126515090465546, 54.865989312529564, 49.7019562125206, 54.97983880341053, 50.51640070974827, 54.283237382769585, 51.41106270253658, 44.42304387688637, 37.55955196917057, 41.01333864033222, 38.95756535232067, 39.70118924975395, 39.16131801903248, 39.67273257672787, 39.42407391965389, 40.946344435214996, 37.93946698307991, 42.383982092142105, 40.740520879626274, 40.50363779067993, 38.26339580118656, 40.082855969667435, 37.85841353237629, 40.46134226024151, 38.05501498281956, 38.88164162635803, 37.54033260047436, 40.5250458419323, 38.59280772507191, 39.65502932667732, 41.10711760818958, 42.8228547424078, 44.88546386361122, 52.86169186234474, 53.160884007811546, 52.67065331339836, 51.29688262939453, 46.35799124836922, 48.590154871344566, 54.972999170422554, 53.861646205186844, 56.314296796917915, 55.144898146390915, 56.567230224609375, 55.30780680477619, 54.02504503726959, 49.43797677755356, 52.82086305320263, 48.09504523873329, 57.75673359632492, 55.196495577692986, 60.50964407622814, 16.010790467262268, 1.490459453780204, 8.886122424155474, 1.8602455174550414, 2.6876230956986547, 0.07434422048390843, 0.5031072534620762, 18.476559855043888, 36.28589451313019, 30.804118663072586, 10.653787571936846, 29.758397676050663, 37.11686052381992, 35.34693829715252, 48.520694598555565, 46.46148629486561, 19.146186523139477, 0.26850419060792774, 0.06510688646812923, 0.08375943987630308, 0.05032335298892576, 0.005885469026907231, 0.020538731005217414, 0.02726157592405798, 0.02227020049758721, 0.05271639704005793, 0.0233283305351506, 0.039012866545817815, 0.022104185773059726, 0.05527494002308231, 0.029683083193958737, 0.02710067645239178, 0.034779852867359295, 0.031882189214229584, 0.010382559721620055, 0.025418734185223002, 0.10271888619172387, 0.016828551088110544, 0.034547868635854684, 0.02646849836310139, 0.04562106078083161, 0.04673401883337647, 0.04743820936710108, 0.054093414946692064, 0.07510743031161837, 0.037327148602344096, 0.014370948538271477, 0.02742978926107753, 0.005495423110914999, 0.02115764691552613, 2.893496286123991, 42.06276252865791, 64.32089656591415, 56.7366099357605, 50.82669585943222, 33.979045897722244, 27.818229384720325, 46.973987594246864, 37.40589581429958, 46.80950202047825, 2.454015430994332, 0.07718055305304006, 0.2598776441300288, 2.93369694147259, 14.73348330706358, 9.354884270578623, 3.5684160701930523, 24.811169542372227, 67.86641031503677, 63.52749913930893, 59.42044012248516, 55.632628574967384, 57.577311024069786, 57.038830518722534, 59.832721799612045, 57.473842576146126, 59.77448992431164, 58.1246792525053, 53.59223686158657, 44.414346143603325, 43.44210371375084, 42.260937094688416, 43.29489581286907, 41.68307550251484, 44.817063733935356, 49.517757296562195, 55.22507004439831, 55.96156932413578, 52.82017529010773, 51.78682453930378, 52.355980798602104, 56.79129660129547, 55.64801774919033, 52.112995237112045, 43.08144986629486, 41.0333863645792, 43.5170166939497, 41.282079219818115, 41.28123566508293, 39.57150600850582, 42.85614475607872, 41.382272243499756, 41.31849646568298, 40.99807105958462, 43.004439398646355, 40.82843296229839, 41.9059981405735, 40.5427110940218, 40.77215798199177, 39.822847321629524, 50.66730961203575, 54.47810612618923, 57.15494468808174, 51.10401637852192, 55.7847686111927, 51.35409235954285, 52.08172291517258, 46.0772243142128, 55.888993218541145, 47.94509768486023, 62.06140100955963, 30.593976639211178, 26.985817551612854, 56.21838614344597, 52.654355987906456, 56.66067101061344, 52.69130900502205, 55.49648568034172, 53.216870203614235, 55.06495423614979, 54.71276253461838, 45.56879259645939, 40.54457299411297, 42.10367493331432, 40.11546581983566, 40.56639522314072, 42.03079104423523, 41.951303109526634, 41.525896936655045, 41.76384396851063, 40.93076907098293, 44.68512341380119, 42.2810760140419, 43.51097881793976, 38.590850830078125, 42.04555705189705, 40.04030205309391, 42.19799347221851, 40.44900432229042, 41.890643164515495, 39.1066275537014, 41.97118744254112, 40.761822536587715, 40.99980756640434, 42.95172482728958, 44.5344614982605, 46.761856377124786, 55.15982374548912, 56.174555495381355, 56.48760549724102, 51.86934471130371, 48.34286414086819, 51.39120876789093, 54.608974903821945, 54.780942276120186, 59.13703612983227, 57.612956911325455, 58.20100195705891, 57.42256432771683, 56.72850117087364, 51.650818437337875, 52.52423197031021, 50.523293539881706, 60.4255735874176, 56.763884872198105, 63.810355961322784, 20.560404136776924, 0.5944532237481326, 5.318194627761841, 3.485107203014195, 3.281285190023482, 0.11062911173212342, 0.21562737092608586, 21.839856281876564, 41.58068999648094, 31.408512331545353, 15.905558913946152, 34.09756153821945, 44.89554852247238, 40.01920938491821, 53.29021766781807, 53.00684027373791, 26.405440494418144, 0.3402873262530193, 0.051252043194836006, 0.06903999455971643, 0.012540397692646366, 0.06958443409530446, 0.0072603629996592645, 0.04280730434402358, 0.0066941316890734015, 0.021210682643868495, 0.0345391892187763, 0.0405052475980483, 0.031565529643557966, 0.12726912391372025, 0.03150525240926072, 0.027061494765803218, 0.04390757538203616, 0.039144323163782246, 0.0821312791958917, 0.13111855485476553, 0.281464671716094, 0.0762892040074803, 0.08551811464712955, 0.11762895956053399, 0.19635214819572866, 0.19489474827423692, 0.2813590789446607, 0.12826708989450708, 0.15827127441298217, 0.0835156295215711, 0.09478648527874611, 0.10475113143911585, 0.06640996420173906, 0.1744800023152493, 3.8623792212456465, 52.46381901204586, 72.0267690718174, 65.90642228722572, 59.921424239873886, 39.58141207695007, 36.46171487867832, 63.503378033638, 48.67774777114391, 53.44840317964554, 3.4680418437346816, 0.2728558180388063, 0.4379670519847423, 2.838627230376005, 10.324832573533058, 17.31869738548994, 10.941339042037725, 27.700593397021294, 70.15341639518738, 66.23667016625404, 61.162536442279816, 58.34658354520798, 60.21509148180485, 61.02832764387131, 63.84740397334099, 61.37661315500736, 62.090439051389694, 59.780592396855354, 55.77806197106838, 46.922055780887604, 46.39109507203102, 44.62010510265827, 45.142713859677315, 44.55000266432762, 47.91259802877903, 52.07699216902256, 56.828713193535805, 57.76647247374058, 53.39000791311264, 53.40155929327011, 53.575175777077675, 60.06336562335491, 57.77521960437298, 55.195070654153824, 45.439937710762024, 43.03402081131935, 45.41981019079685, 42.49049037694931, 43.861054033041, 41.609454452991486, 46.028161346912384, 43.70953716337681, 43.686647191643715, 41.94322094321251, 45.19158683717251, 43.81417594850063, 44.31506127119064, 42.51691795885563, 43.70877340435982, 42.46592849493027, 53.32112900912762, 56.29717871546745, 59.10286836326122, 52.72123999893665, 57.23093681037426, 54.441373497247696, 54.61971312761307, 50.53733378648758, 57.716166973114014, 49.83379013836384, 63.7724643945694, 32.57020689547062, 29.832383506000042, 57.7778946608305, 54.90314371883869, 59.747963547706604, 55.758797004818916, 58.221213072538376, 55.00667676329613, 57.753264382481575, 57.93330252170563, 46.78550250828266, 41.04692883789539, 44.78742152452469, 41.91189922392368, 43.57665069401264, 44.37732473015785, 44.16168250143528, 43.72289724647999, 45.5142655223608, 42.56616711616516, 46.94547772407532, 44.33045044541359, 45.92282719910145, 40.45612893998623, 45.55958949029446, 41.83601729571819, 44.42006103694439, 41.63859508931637, 43.67938198149204, 41.40895061194897, 44.34482127428055, 42.561094388365746, 43.464670702815056, 46.189333498477936, 46.71886548399925, 49.35643695294857, 57.672313526272774, 58.05601693689823, 58.75985696911812, 52.242325097322464, 48.918419256806374, 51.88685417175293, 54.60981845855713, 56.31954811513424, 60.994300469756126, 58.66277977824211, 62.29742534458637, 59.331209510564804, 59.50069181621075, 54.2264798283577, 59.253074303269386, 52.573902904987335, 62.348802387714386, 60.345207899808884, 66.61756172776222, 20.125557370483875, 3.420824627391994, 20.956158600747585, 2.0558568835258484, 5.515611134469509, 0.2037683260277845, 1.0546268778853118, 25.454374328255653, 53.91832396388054, 43.362900763750076, 17.553420290350914, 38.91109384596348, 48.042695447802544, 48.51826652884483, 61.465942561626434, 59.70154903829098, 32.37800560891628, 0.6708271661773324, 0.14351023914059624, 0.12170812973636203, 0.07918247414636426, 0.149270344118122, 0.13773178827250376, 0.1368957886006683, 0.09113501480896957, 0.1163317819009535, 0.05998600441671442, 0.18594806897453964, 0.0864263104449492, 0.16853648296091706, 0.12644584465306252, 0.18038868525763974, 0.23931299918331206, 0.11992314583039843], [0.04990456647647079, 0.034460666283848695, 0.05485533343744464, 0.03768974340346176, 0.06813718675402924, 0.042111937946174294, 0.0457480125623988, 0.09915205766446888, 0.03705656527017709, 0.13854613207513466, 0.04091436021553818, 0.029828892947989516, 0.08266221164376475, 0.030789551165071316, 0.011637443312793039, 0.11967216632911004, 5.693085361272097, 40.391999781131744, 55.18319249153137, 42.31002666056156, 26.90011505037546, 13.466521091759205, 33.24112169444561, 33.54336887598038, 37.09529668092728, 32.74833753705025, 0.2969688788289204, 0.09458014596020803, 0.07503757937229238, 3.330026837065816, 15.581795386970043, 3.3985979575663805, 1.3570153643377125, 29.41639132797718, 67.91634723544121, 57.26497918367386, 58.139722645282745, 51.42672546207905, 52.06203617155552, 50.41099816560745, 53.68451490998268, 47.23374165594578, 47.02854506671429, 43.06221529841423, 41.70072175562382, 40.40975242853165, 40.10453000664711, 40.622708201408386, 41.53609558939934, 40.17284654080868, 41.80418260395527, 47.120975106954575, 52.6934976875782, 53.753633201122284, 55.54556384682655, 49.11683700978756, 52.44254395365715, 53.25050599873066, 51.91284477710724, 47.734778970479965, 41.534119695425034, 39.771835058927536, 41.042266488075256, 38.265782073140144, 39.06105279922485, 40.002019107341766, 40.06797216832638, 38.91270875930786, 39.333152398467064, 39.391095489263535, 39.9659438431263, 38.08800481259823, 41.211110427975655, 38.14149834215641, 40.46779051423073, 49.578649029135704, 53.422477170825005, 53.72222788631916, 54.4280020147562, 52.50105321407318, 53.49591203033924, 49.58326958119869, 54.90573137998581, 50.366350561380386, 55.900586396455765, 47.2723475843668, 59.51820507645607, 26.71672359108925, 30.40866818279028, 59.65081036090851, 48.46046023070812, 55.66975638270378, 48.82354214787483, 53.14039930701256, 50.62189444899559, 51.796134039759636, 46.190112456679344, 41.353595182299614, 38.63072209060192, 39.8360326141119, 38.716004714369774, 40.20350709557533, 39.57804545760155, 40.134050622582436, 37.43359252810478, 38.895073905587196, 37.155751436948776, 39.933827966451645, 39.010975286364555, 39.63161498308182, 38.22703555226326, 38.55655387043953, 37.95419879257679, 39.57576937973499, 38.98848429322243, 40.13107918202877, 40.04195496439934, 38.352280631661415, 37.96285092830658, 39.724041223526, 38.751335218548775, 42.41650454699993, 49.947461038827896, 55.38603700697422, 52.841055169701576, 50.76747223734856, 51.901718974113464, 55.45442573726177, 53.77121485769749, 54.06862869858742, 52.96540729701519, 50.818750485777855, 52.8824919462204, 56.54193118214607, 53.85176673531532, 47.83002845942974, 45.70052772760391, 47.09213845431805, 50.998606234788895, 55.10332837700844, 52.91830122470856, 60.05970261991024, 37.99187757074833, 5.273440629243851, 8.345810417085886, 4.656843915581703, 7.068982981145382, 0.2718449238454923, 0.06617118560825475, 5.530379042029381, 34.98634144663811, 36.11369155347347, 26.49292889982462, 30.53763896226883, 35.54426930844784, 42.408129796385765, 49.52726438641548, 45.252330377697945, 35.708112716674805, 1.8258042843081057, 0.03213217423763126, 0.05208139693422709, 0.13424416916677728, 0.01529405501059955, 0.04761625430546701, 0.03156551480060443, 0.10895086350501515, 0.06866895040730014, 0.044789473176933825, 0.031922435882734135, 0.09810081290197559, 0.04732049361336976, 0.013829635299771326, 0.07765054033370689, 0.03995432169176638, 0.06109090645622928, 0.034834786638384685, 0.037943305578664877, 0.055715571652399376, 0.055946361026144587, 0.07587496686028317, 0.012323458649916574, 0.02829775879945373, 0.02272205525514437, 0.05007590239983983, 0.01410928211043938, 0.07941864780150354, 0.04543769464362413, 0.0800831000378821, 0.017725451398291625, 0.04256082967913244, 0.04051384166814387, 7.949344916269183, 48.87920156121254, 62.02682666480541, 49.65214088559151, 36.35729268193245, 23.25736451894045, 31.511220820248127, 35.31985715031624, 42.06701450049877, 37.715856581926346, 0.23146367428125814, 0.1475311952526681, 0.11890591369592585, 5.865898663178086, 11.163698360323906, 8.198186438530684, 3.76722757704556, 32.629312723875046, 68.98087531328201, 59.685700088739395, 61.57362498342991, 52.97979332506657, 53.40708799660206, 52.453859746456146, 54.14226494729519, 50.51647290587425, 50.17857603728771, 46.21821574866772, 43.273107782006264, 42.68340602517128, 40.87736293673515, 41.82123228907585, 43.381576761603355, 41.97369530797005, 43.64474684000015, 48.65829661488533, 54.323522821068764, 54.850288555026054, 57.790711373090744, 49.46570008993149, 51.071649715304375, 55.2004511654377, 52.56630331277847, 48.944865837693214, 43.90562184154987, 41.30497679114342, 42.124608010053635, 40.79306825995445, 41.718314811587334, 40.76843038201332, 41.788470447063446, 41.66770152747631, 41.36711485683918, 41.389533653855324, 41.84007927775383, 40.16870096325874, 43.35294149816036, 40.794580578804016, 42.49633066356182, 51.72324255108833, 56.598931923508644, 55.66175401210785, 57.02297396957874, 55.80241106450558, 56.43069215118885, 53.280266001820564, 56.62407137453556, 52.19240717589855, 57.62576602399349, 50.07036544382572, 60.707552656531334, 28.60704615712166, 31.502393893897533, 62.582562044262886, 50.75386516749859, 57.270808070898056, 51.866320073604584, 54.49547879397869, 53.72845575213432, 53.05617682635784, 48.229953199625015, 43.878928273916245, 40.658327490091324, 41.052221953868866, 40.11229678988457, 42.158300802111626, 41.175909116864204, 41.31526663899422, 40.43402552604675, 41.18000529706478, 39.56412300467491, 41.18470184504986, 39.2617542296648, 42.056846246123314, 40.81332877278328, 41.35492891073227, 40.22110395133495, 40.875580832362175, 41.074131578207016, 42.925308644771576, 42.22599416971207, 40.27123466134071, 39.60991054773331, 42.12559595704079, 40.363102331757545, 43.01764748990536, 51.39059320092201, 58.20607088506222, 54.101287946105, 52.64099970459938, 51.664949879050255, 56.46861411631107, 57.037287801504135, 56.54213257133961, 55.615632086992264, 51.814141273498535, 55.382328405976295, 59.398636892437935, 57.00289584696293, 52.48818330466747, 47.6530871540308, 49.01287078857422, 54.27710831165314, 58.35675559937954, 54.47076112031937, 62.35626898705959, 40.39763867855072, 6.045926827937365, 3.473037388175726, 9.14340091869235, 11.555436439812183, 0.8463253802619874, 0.08143338578520343, 5.835904497653246, 38.90146516263485, 36.82038903236389, 25.68747092038393, 34.610856994986534, 38.549877628684044, 44.51793238520622, 56.288982555270195, 50.390369072556496, 43.093107640743256, 3.3336867531761527, 0.06181744305649772, 0.05851566143974196, 0.06881991808768362, 0.04097109740541782, 0.02024199809966376, 0.07728964876150712, 0.06726264735334553, 0.02914048047387041, 0.022517703037010506, 0.012746972643071786, 0.017914342824951746, 0.07256947079440579, 0.04017840947199147, 0.06703963939798996, 0.04682494305598084, 0.05898300667467993, 0.16425500332843512, 0.10967627575155348, 0.2179496845928952, 0.1728083740454167, 0.1424895040690899, 0.12735095311654732, 0.10851831015315838, 0.21805664291605353, 0.2510784147307277, 0.2040296362247318, 0.13887410197639838, 0.13855828845407814, 0.19265331386122853, 0.11276423349045217, 0.12325159652391449, 0.2003816538490355, 12.033137306571007, 59.72375884652138, 70.03031820058823, 58.11423361301422, 39.18889693915844, 23.089358434081078, 43.43184806406498, 45.0006090849638, 51.38988643884659, 43.14027450978756, 0.37208497000392526, 0.24778313061688095, 0.21475223038578406, 8.799237236380577, 29.65217437595129, 12.346959616988897, 4.452292816713452, 34.21528682112694, 71.96654230356216, 62.250976637005806, 64.04081359505653, 56.246664226055145, 55.09792126715183, 54.97879005968571, 57.89816960692406, 52.192711159586906, 51.01441338658333, 48.44206161797047, 44.90675792098045, 44.28769513964653, 43.18546548485756, 44.61359605193138, 46.636117324233055, 44.68366429209709, 47.14644514024258, 50.76011583209038, 55.07746696472168, 56.56985588371754, 57.42660351097584, 50.444288179278374, 52.034267261624336, 56.92334711551666, 54.986815229058266, 51.92017078399658, 45.3870065510273, 43.560360968112946, 44.459168538451195, 42.04924285411835, 43.328007236123085, 43.26758287847042, 43.68742994964123, 44.36807602643967, 43.60204093158245, 43.987876027822495, 43.871074095368385, 42.86254741251469, 45.49078658223152, 42.445295602083206, 45.34955956041813, 54.29447717964649, 58.4552501142025, 57.93203718960285, 60.19877515733242, 57.17498101294041, 60.331813618540764, 54.771628975868225, 58.95134009420872, 54.88897427916527, 59.942775294184685, 52.555337101221085, 61.42267048358917, 30.53981054574251, 34.634799510240555, 63.571607172489166, 53.109233379364014, 59.74704399704933, 54.58431042730808, 56.58738054335117, 56.34007841348648, 56.19386985898018, 50.12170068919659, 46.08011215925217, 42.91908837854862, 44.10169892013073, 42.25888900458813, 42.52858333289623, 43.24682839214802, 43.75640004873276, 43.12806956470013, 43.30520085990429, 41.43295392394066, 43.9529825001955, 44.09322917461395, 43.870078548789024, 43.60511876642704, 44.12509426474571, 42.4812188744545, 43.895263597369194, 42.20359057188034, 43.500035405159, 44.43101964890957, 41.63666099309921, 41.39309786260128, 43.86004328727722, 43.559194430708885, 45.95791071653366, 55.30676186084747, 60.28983727097511, 57.1882688999176, 53.357082679867744, 52.60789208114147, 59.47771064937115, 58.97558279335499, 57.76512734591961, 57.16183751821518, 51.82087071239948, 55.98972201347351, 61.24370388686657, 59.90031637251377, 53.976263254880905, 51.12817548215389, 51.04376681149006, 56.59610107541084, 61.72863766551018, 58.09302695095539, 63.73752146959305, 44.736781641840935, 6.951176952570677, 18.651905246078968, 18.94726149737835, 13.272909130901098, 0.84238481358625, 0.22552312351763248, 7.438172120600939, 51.19885928928852, 47.080093100667, 38.42169910669327, 39.614401906728745, 46.77454389631748, 55.47942079603672, 63.45409467816353, 57.25141391158104, 49.66684229671955, 4.656873838976026, 0.17410085391020402, 0.10263873424264602, 0.14660680579254404, 0.15849633811740205, 0.10739922567154281, 0.15185661002760753, 0.23457046772819012, 0.1406095252605155, 0.13911445392295718, 0.28252897085621953, 0.16630410274956375, 0.1157021512335632, 0.10991762217599899, 0.14246235630707815, 0.19973258633399382, 0.2054964762646705], [0.02352666764636524, 0.03536003794579301, 0.038573722922592424, 0.053843782443436794, 0.06058741120796185, 0.05650664541462902, 0.05833745322888717, 0.05335440655471757, 0.11758647902752273, 0.015994210116332397, 0.07256262077135034, 0.030005065818841103, 0.010045709095720667, 0.08170743865775876, 0.052913971594534814, 0.04931298943120055, 11.593894176185131, 52.565782740712166, 57.34607443213463, 42.575389221310616, 23.43228243291378, 18.634222894906998, 39.77170206606388, 40.94920568168163, 41.03996001183987, 20.620682202279568, 0.20082833769265562, 0.37462480715475976, 0.772831505164504, 4.081539586186409, 18.7463890761137, 6.235818788409233, 2.291287975385785, 42.72333048284054, 65.09762808680534, 58.7409757822752, 53.64752009510994, 45.42132630944252, 45.645673871040344, 43.44015821814537, 41.75722472369671, 40.41786879301071, 40.23153819143772, 40.90377911925316, 46.18331842124462, 43.500555977225304, 43.055504858493805, 41.59499242901802, 41.23338483273983, 39.60245154798031, 39.75447379052639, 43.77969279885292, 49.37789060175419, 52.949470952153206, 55.22606939077377, 55.00531263649464, 51.79414674639702, 53.36025170981884, 54.79646064341068, 49.920011311769485, 43.908384293317795, 40.15735477209091, 39.86509345471859, 41.02274313569069, 39.03646431863308, 41.127366721630096, 41.40410967171192, 40.248485282063484, 39.82437863945961, 39.8482945561409, 39.83836568892002, 37.562831193208694, 40.866723507642746, 37.95868635177612, 46.003071293234825, 50.711999014019966, 55.43831840157509, 47.072311118245125, 50.91726779937744, 49.41808104515076, 51.85987561941147, 50.75264163315296, 55.12882500886917, 49.41707029938698, 55.25746710598469, 47.40930363535881, 58.264595344662666, 22.74650853127241, 34.15604040026665, 58.38590383529663, 47.24755011498928, 51.941833421587944, 45.373566672205925, 48.746128901839256, 44.65610817074776, 43.328280821442604, 39.512897953391075, 39.454422891139984, 38.3310017734766, 40.60930632054806, 38.334786370396614, 39.57443565130234, 40.17674893140793, 39.932353645563126, 39.83265459537506, 39.62794438004494, 39.114485532045364, 39.25581134855747, 40.51605552434921, 39.54805746674538, 38.90515856444836, 37.4055690318346, 39.8127094656229, 38.92165347933769, 39.770280942320824, 40.62531106173992, 39.59863655269146, 41.03393733501434, 40.52932821214199, 40.34206286072731, 41.04848675429821, 42.4376580119133, 49.28875878453255, 52.23170846700668, 55.661073848605156, 51.57866790890694, 55.61929889023304, 53.8154710829258, 53.84441412985325, 52.02984429895878, 54.45479817688465, 52.91340708732605, 55.23776516318321, 54.21975798904896, 47.12253302335739, 43.84602963924408, 46.54955416917801, 47.37838089466095, 53.064395785331726, 55.949474573135376, 58.19384694099426, 57.75503508746624, 51.05439104139805, 13.180025964975357, 4.860321097075939, 9.635201878845692, 2.1466748602688313, 1.5613295696675777, 0.07319755779462866, 2.6018063630908728, 25.10265190154314, 36.1232328414917, 31.689473055303097, 12.86096753552556, 26.120541281998158, 39.54879082739353, 45.325769037008286, 47.52799026668072, 47.50135749578476, 6.112392386421561, 0.0859859942283947, 0.09181272180285305, 0.031165411855909042, 0.033725724861142226, 0.037983860238455236, 0.029151722155802418, 0.047366696016979404, 0.02575417936895974, 0.07733281949185766, 0.061164497819845565, 0.053856662416365, 0.0986231883871369, 0.07518268408603035, 0.007870889858168084, 0.08724702187464572, 0.02140764678188134, 0.03686677955556661, 0.03477781196124852, 0.03763691733183805, 0.014411617303267121, 0.033550730149727315, 0.06153357899165712, 0.0668854804825969, 0.021831683989148587, 0.016746330402384046, 0.0073833837177517125, 0.030892624345142394, 0.08728686036192812, 0.041775437057367526, 0.03938014429877512, 0.10676673773559742, 0.09462434085435234, 17.12129607796669, 61.296600848436356, 62.58196547627449, 50.56897848844528, 27.462899051606655, 17.828240543603897, 39.60337109863758, 39.0868154168129, 47.85560108721256, 22.6972783729434, 0.06349356874125078, 0.18661856971448287, 0.8473595778923482, 6.265174113214016, 13.10115359723568, 7.0510887913405895, 3.973475997336209, 44.68404807150364, 64.80096280574799, 60.46465829014778, 54.7060102969408, 48.45878832042217, 46.172207817435265, 44.629042223095894, 43.8222923129797, 41.5560445189476, 42.54439428448677, 43.392440378665924, 45.591804161667824, 45.5717184394598, 45.0520621240139, 42.89719395339489, 41.966703683137894, 39.76898521184921, 42.1131744235754, 45.76683036983013, 51.59409508109093, 53.09763640165329, 57.01162777841091, 54.60400477051735, 51.27601034939289, 55.58077655732632, 54.663976952433586, 51.718348413705826, 44.52561937272549, 43.545275777578354, 41.39599710702896, 41.48363180458546, 40.19792139530182, 42.50482700765133, 41.76624543964863, 42.917101085186005, 41.850597113370895, 40.85675664246082, 41.7819157987833, 40.2350378036499, 42.732632383704185, 39.19329330325127, 48.763201385736465, 53.084272518754005, 55.93072637915611, 48.70327480137348, 51.611809730529785, 49.16520841419697, 53.427785485982895, 50.821425542235374, 56.46892949938774, 51.62850223481655, 57.32013702392578, 49.94664028286934, 57.45880678296089, 22.43923991918564, 35.30313044786453, 61.93841680884361, 50.07848180830479, 55.366593450307846, 46.894590854644775, 50.80118402838707, 46.64188161492348, 46.564950942993164, 43.0357763171196, 41.296579241752625, 40.34097231924534, 41.63705617189407, 39.277397990226746, 42.250491455197334, 41.71699248254299, 42.03429825603962, 40.83472162485123, 40.94766676425934, 40.42754307389259, 41.69841147959232, 42.699574157595634, 39.77408453822136, 39.76157180964947, 41.96269869804382, 41.95192627608776, 41.50723613798618, 41.800158619880676, 42.016397416591644, 41.82179845869541, 42.028575763106346, 42.011218294501305, 42.193448916077614, 41.57926507294178, 44.50878627598286, 51.561910808086395, 54.68166120350361, 55.79432509839535, 52.994859516620636, 54.79802615940571, 56.3660804182291, 55.30622608959675, 54.67586651444435, 56.4420535415411, 53.87891627848148, 56.34060278534889, 56.93190425634384, 50.14968238770962, 44.92177851498127, 49.93020996451378, 50.399028807878494, 56.01739972829819, 58.72934080660343, 61.77243031561375, 58.960907980799675, 51.13586246967316, 17.118360735476017, 4.627877119928598, 6.048352047801018, 7.333308197557926, 3.0866769701242447, 0.04973349772626534, 2.3461817298084497, 29.669446349143982, 41.127879694104195, 31.287944801151752, 19.254617504775524, 34.52185817062855, 46.88926354050636, 51.88638299703598, 53.68664659559727, 55.962834656238556, 9.465834517031908, 0.037304665238480084, 0.07755757149425335, 0.04509524173045065, 0.04182235563348513, 0.060858796059619635, 0.05149854754563421, 0.011080568165198201, 0.055702947720419616, 0.062412014667643234, 0.00996130185740185, 0.058427980402484536, 0.026241924388159532, 0.04770975006977096, 0.03411811689147726, 0.054235862771747634, 0.04245959331456106, 0.1445992072694935, 0.10236888934741728, 0.15876845398452133, 0.07670496255741455, 0.13153009058441967, 0.24025983118917793, 0.20608302525943145, 0.11597058604820631, 0.17442377720726654, 0.09132421793765388, 0.15845005778828636, 0.1381058752303943, 0.07761952598229982, 0.13289433612953871, 0.19924052758142352, 0.14124333421932533, 24.098107405006886, 69.24486234784126, 70.42152240872383, 57.154845893383026, 35.289018005132675, 28.91191329807043, 52.095937952399254, 51.74900136888027, 55.317944660782814, 26.122916154563427, 0.343206282122992, 0.6746122380718589, 1.25937509117648, 13.676224239170551, 34.939064383506775, 15.224055983126163, 6.66967143304646, 47.334994822740555, 67.51584112644196, 63.670812249183655, 56.941836923360825, 50.78476510941982, 49.98875342309475, 46.34367361664772, 45.070407539606094, 44.62889403104782, 45.76448209583759, 45.08535973727703, 50.21122768521309, 47.641121596097946, 47.870412692427635, 46.499453857541084, 45.370454639196396, 42.00242176651955, 43.843932151794434, 48.816383332014084, 53.31162191927433, 57.0407722145319, 60.421545803546906, 57.94883228838444, 52.14376978576183, 56.786299869418144, 57.96019367873669, 54.40704233944416, 46.615579426288605, 44.550580233335495, 42.95921042561531, 44.29562531411648, 41.97773829102516, 46.218067556619644, 42.558468729257584, 44.685245007276535, 43.138025030493736, 43.0278005450964, 42.301978692412376, 41.8494875729084, 44.12304997444153, 42.55075894296169, 50.47234587371349, 54.58124779164791, 58.996504470705986, 51.08749486505985, 52.52075515687466, 52.49544471502304, 54.44299601018429, 52.396414428949356, 58.44637759029865, 53.64451825618744, 59.161636009812355, 52.1855903416872, 58.35979923605919, 25.53573366254568, 37.89446599781513, 61.97165362536907, 53.63446779549122, 57.633665800094604, 49.29855465888977, 54.73333463072777, 48.72144542634487, 47.262490913271904, 44.68105763196945, 42.58201986551285, 41.89710281789303, 43.52107487618923, 40.41291765868664, 43.94366540014744, 42.32989959418774, 44.1190829873085, 43.47379021346569, 43.2548725605011, 44.33844901621342, 42.98118844628334, 44.26763601601124, 43.09182710945606, 43.06300565600395, 42.7284450083971, 44.537227749824524, 42.60982297360897, 43.35035003721714, 44.28665019571781, 43.34429696202278, 44.63661141693592, 44.17558595538139, 43.60059700906277, 43.66563431918621, 46.51780307292938, 54.00763817131519, 57.9007762670517, 59.26132746040821, 52.4860630184412, 58.026374727487564, 57.74633355438709, 58.964491188526154, 57.15212903916836, 57.86471240222454, 55.21512597799301, 58.95051933825016, 59.977076053619385, 51.56941540539265, 47.761738523840904, 51.77282229065895, 52.76186741888523, 60.378429517149925, 61.98410555720329, 64.57701802253723, 59.57046367228031, 55.17718881368637, 19.898502454161644, 9.621615707874298, 16.64434377104044, 6.421887679025531, 2.626167805865407, 0.311997250537388, 3.2218901021406054, 35.366271659731865, 51.91458888351917, 42.41130642592907, 22.480021230876446, 37.500267550349236, 52.482430413365364, 59.520500153303146, 60.92229053378105, 64.24198240041733, 12.48166048899293, 0.28397796966601163, 0.2077157946769148, 0.1987380045466125, 0.15353132563177496, 0.21709667489631101, 0.07349756357143633, 0.1393706284579821, 0.11764405484427698, 0.21306460141204298, 0.12639154912903905, 0.1001714717131108, 0.2189354199799709, 0.1605098886648193, 0.09214630234055221, 0.22061224328354, 0.10902317095315084], [0.04944667249219492, 0.01670656056376174, 0.020085542237211484, 0.09215162353939377, 0.012493869671743596, 0.039429333846783265, 0.042405832136864774, 0.04402470854984131, 0.03200943785486743, 0.056575746784801595, 0.04828294782782905, 0.13038323493674397, 0.02677774758922169, 0.03154792961140629, 0.0833980881725438, 1.1235653911717236, 29.669060669839382, 57.05991178750992, 48.92658121883869, 40.43025232851505, 40.661063343286514, 28.41145735234022, 38.68936814367771, 37.628525868058205, 39.08520810306072, 7.608935432508588, 0.2728779043536633, 0.07124793584807776, 0.6684440409298986, 4.761672215536237, 6.311887381598353, 5.544690024107695, 4.839743301272392, 49.038439616560936, 61.72340154647827, 54.4662469625473, 50.51312528550625, 49.47247512638569, 47.38330543041229, 45.97553417086601, 45.202131271362305, 46.21852733194828, 48.25481906533241, 51.37341432273388, 51.91920943558216, 52.639658376574516, 51.875169798731804, 48.6284264177084, 43.230515867471695, 39.32561740279198, 40.775319412350655, 40.379703640937805, 43.10899458825588, 47.38651245832443, 51.50661617517471, 54.09023813903332, 52.10707135498524, 52.01098591089249, 53.69950890541077, 51.05508640408516, 49.393006190657616, 45.947734862565994, 46.05493851006031, 42.17915028333664, 40.215522050857544, 38.46053682267666, 38.7859171628952, 38.52770961821079, 39.81722742319107, 40.3950510174036, 39.76841524243355, 37.88461692631245, 37.72700898349285, 38.16402733325958, 49.75802980363369, 53.18160429596901, 48.3618289232254, 45.628643184900284, 50.427679270505905, 50.988323986530304, 51.329386085271835, 48.57281640172005, 49.506825283169746, 48.03174443542957, 51.350136771798134, 46.114659905433655, 54.5425620675087, 23.19264069199562, 38.53275574743748, 57.13483616709709, 48.722767755389214, 51.23274967074394, 39.003504887223244, 41.11287049949169, 38.52011002600193, 38.25563281774521, 39.05628025531769, 41.4540009945631, 38.32810252904892, 37.060376554727554, 37.510720789432526, 40.60038439929485, 39.86106187105179, 40.75128570199013, 39.122822284698486, 39.42768752574921, 39.627119824290276, 38.923310190439224, 40.29705427587032, 40.27030371129513, 37.462064400315285, 38.58154512941837, 39.160447865724564, 38.346672132611275, 38.873164281249046, 43.14817048609257, 46.087939739227295, 47.43736892938614, 44.56281177699566, 42.98408389091492, 42.239190861582756, 42.92585201561451, 50.177884474396706, 55.827877297997475, 51.104020178318024, 48.76388914883137, 54.527355283498764, 50.86404025554657, 50.85864074528217, 49.59542892873287, 54.27934259176254, 55.49409560859203, 55.93256168067455, 48.22733514010906, 40.94529569149017, 45.29413193464279, 53.782051876187325, 57.15253181755543, 59.673438146710396, 55.98485827445984, 58.03618960082531, 53.72301444411278, 61.27255953848362, 27.97879356890917, 7.103152647614479, 5.904603861272335, 4.867795296013355, 4.304353930056095, 0.2782825502799824, 0.1070673149661161, 19.547475390136242, 38.68938334286213, 33.304753080010414, 20.744726546108723, 14.944919161498547, 30.077514052391052, 38.04389677941799, 47.74171359837055, 48.29937167465687, 19.136402048170567, 0.4324472841108218, 0.06249493482755497, 0.09325227307272144, 0.041089265869231895, 0.05562860307691153, 0.042767777558765374, 0.08694688251125626, 0.06090143615438137, 0.07768072347971611, 0.07056076647131704, 0.07835978118237108, 0.1303413332789205, 0.025424728883081116, 0.02402613674348686, 0.05502759704540949, 0.023930553688842338, 0.05372730978706386, 0.05855494331626687, 0.029851246436010115, 0.02671459638804663, 0.03633062980952673, 0.040581521825515665, 0.008648015882499749, 0.020851559238508344, 0.019473183201625943, 0.0449645198386861, 0.030285250686574727, 0.08936602418543771, 0.0437821227387758, 0.03377137807547115, 0.13425635523162782, 1.370353123638779, 39.368422105908394, 63.76850500702858, 53.2097227871418, 45.44970318675041, 45.17129212617874, 24.07330233603716, 40.11267676949501, 39.02650885283947, 46.95675551891327, 8.548332899808884, 0.4363047599326819, 0.22552003618329763, 2.0617306558415294, 6.865762760862708, 8.96173456683755, 7.718349611386657, 6.007965439930558, 50.76969891786575, 63.13156798481941, 57.83065862953663, 51.205543130636215, 49.786881655454636, 49.204437509179115, 48.04019138216972, 48.11721324920654, 47.460167706012726, 47.86887377500534, 52.84136675298214, 54.61677968502045, 55.53300552070141, 53.68651360273361, 50.91264724731445, 44.511932507157326, 42.25948937237263, 41.434983015060425, 42.07025192677975, 45.663817897439, 49.9225115776062, 53.02220664918423, 57.03018598258495, 53.55711914598942, 51.71452961862087, 55.14405079185963, 53.2978780567646, 51.45385980606079, 46.87811113893986, 47.47130870819092, 43.73719207942486, 43.05227503180504, 40.21847449243069, 40.802168771624565, 40.535943657159805, 41.0637429356575, 41.107763573527336, 41.22485049068928, 39.286650493741035, 40.22288605570793, 40.97316339612007, 51.374884843826294, 53.798489794135094, 51.454566568136215, 48.427318409085274, 51.887218952178955, 50.831681191921234, 52.57580280303955, 48.97679552435875, 49.51449327170849, 49.44784864783287, 53.72962228953838, 46.34130634367466, 56.58357314765453, 23.64186018705368, 39.77453291416168, 60.000110417604446, 48.785452991724014, 52.21687786281109, 42.705688029527664, 43.30711595714092, 39.94847238063812, 40.49964040517807, 41.5324629843235, 43.18133130669594, 41.07211008667946, 40.06766818463802, 39.46789316833019, 42.26403772830963, 41.387219578027725, 42.61433333158493, 40.25601647794247, 41.74247771501541, 42.37697906792164, 40.87376832962036, 42.02398180961609, 41.85962922871113, 40.299261957407, 40.765588134527206, 40.30511364340782, 38.85381191968918, 41.36653728783131, 44.107216224074364, 48.06371212005615, 48.86054836213589, 47.14158520102501, 45.1420982927084, 44.13105994462967, 44.19777676463127, 51.16480931639671, 57.39322230219841, 52.537698447704315, 49.72122497856617, 56.58601641654968, 54.6392934769392, 52.57438167929649, 52.48994641005993, 56.59293204545975, 56.694511994719505, 58.572116643190384, 49.921915009617805, 42.726860493421555, 47.395373582839966, 56.97417698800564, 60.860973224043846, 60.126164853572845, 59.327360317111015, 59.68239426612854, 56.122494488954544, 61.91608540713787, 32.03034706413746, 7.952586617320776, 3.7991202156990767, 3.81689399946481, 4.3975558038800955, 0.14560299168806523, 0.2618636313127354, 22.154095619916916, 41.45084336400032, 25.385172441601753, 24.536660872399807, 24.608226232230663, 37.35609948635101, 46.2918633967638, 53.846538215875626, 56.705865785479546, 26.33644189685583, 0.988495642086491, 0.010065195110655623, 0.07702375209191814, 0.03184223569405731, 0.0014875253191348747, 0.03173891389451455, 0.023754855792503804, 0.022866944746056106, 0.05024448495532852, 0.053529037613770925, 0.01581676446221536, 0.019077169490628876, 0.01991250679566292, 0.037492810806725174, 0.03235281845263671, 0.0392705068225041, 0.18194392992882058, 0.16601646115304902, 0.11031755071599036, 0.15003247041022405, 0.11684016790241003, 0.10455356430611573, 0.12309969373745844, 0.10509766987524927, 0.11888131892192177, 0.21351670293370262, 0.1463381334906444, 0.19873945915605873, 0.14598951704101637, 0.12225688114995137, 0.2455336067941971, 1.980421906337142, 50.378312319517136, 71.84242576360703, 62.70145386457443, 51.388871893286705, 50.88583968579769, 39.86581541597843, 52.33100473880768, 47.96261094510555, 52.84945271909237, 9.251247681677341, 0.49088221101555973, 0.2833294216543436, 2.2287065209820867, 12.366363275796175, 12.597767058759928, 12.957601100206375, 9.44616487249732, 52.66460403800011, 65.65707206726074, 58.79375874996185, 55.279391929507256, 52.32374332845211, 51.84873081743717, 49.907791167497635, 50.04595935344696, 50.90778350830078, 50.63945330679417, 55.98576262593269, 56.91105857491493, 58.30579653382301, 55.08154794573784, 53.514960408210754, 45.8741670101881, 43.55488546192646, 44.12097528576851, 43.32044944167137, 47.39885799586773, 51.92675203084946, 57.049849927425385, 59.257668256759644, 56.04550302028656, 53.53615187108517, 57.73638188838959, 56.87061354517937, 53.54206435382366, 50.08309856057167, 49.67376932501793, 45.881842598319054, 45.45936606824398, 41.19677759706974, 43.085158467292786, 41.58215671777725, 42.43807598948479, 43.31119693815708, 42.43854716420174, 42.09210455417633, 41.62094123661518, 42.806078642606735, 53.602557107806206, 57.00134553015232, 55.309661105275154, 49.85827602446079, 53.34230527281761, 53.71432811021805, 54.01459939777851, 51.00800313055515, 50.80012388527393, 50.710342302918434, 54.15048010647297, 48.85000392794609, 56.28725364804268, 26.33880916982889, 42.474801018834114, 60.50459414720535, 51.68707229197025, 55.68317346274853, 43.333934918046, 45.27181953191757, 41.30862079560757, 41.313670724630356, 44.620580077171326, 46.25499777495861, 42.55939967930317, 41.48496173322201, 41.260101199150085, 44.32836815714836, 43.96437048912048, 44.37980979681015, 42.07738034427166, 44.337590262293816, 44.60419535636902, 43.719705417752266, 44.112148359417915, 45.512441620230675, 42.345110177993774, 43.57094720005989, 41.90595254302025, 40.6082309782505, 43.291407600045204, 46.683306992053986, 50.515762344002724, 51.53699554502964, 48.44858206808567, 47.10683226585388, 47.63868972659111, 46.49830251932144, 53.381952345371246, 59.994577914476395, 54.79490652680397, 49.51119124889374, 60.076805502176285, 54.73806917667389, 56.48417428135872, 54.18736472725868, 58.98898847401142, 60.14120824635029, 60.53314581513405, 51.91505245864391, 45.4512345045805, 49.450432509183884, 59.70931962132454, 62.40904055535793, 62.21962831914425, 61.59743070602417, 62.84113436937332, 57.762988060712814, 62.96020857989788, 35.414525270462036, 14.124235399067402, 21.47703655064106, 11.758236307650805, 6.780114881694317, 0.2892941515892744, 0.40568941680248827, 26.270998008549213, 53.892337158322334, 46.107706278562546, 31.675341613590717, 23.94451394677162, 43.04662473499775, 53.824636191129684, 61.382438242435455, 63.66197392344475, 32.51024231314659, 1.4359656278975308, 0.1559188443934545, 0.1831625067279674, 0.2136516699101776, 0.12647392752114683, 0.06530210099299438, 0.2260182992904447, 0.11346300263539888, 0.21903716842643917, 0.14881705516017973, 0.10548754231422208, 0.18213727424154058, 0.16518163407454267, 0.12142097053583711, 0.09674207409261726, 0.12823070981539786], [0.04700501034676563, 0.03533543575031217, 0.07610224216477945, 0.062487491086358204, 0.06973480063606985, 0.06520366994664073, 0.007643718918188824, 0.025047003546205815, 0.017721731383062433, 0.04525153803115245, 0.04422550031449646, 0.025537075198371895, 0.06993887640419416, 0.02887699578423053, 0.05032226203184109, 2.2834544582292438, 35.975812152028084, 57.13863216340542, 48.903611451387405, 34.38295662403107, 35.35070389509201, 28.033835515379906, 38.604005724191666, 42.38348051905632, 38.402418941259384, 2.130304151214659, 0.17419636831618845, 4.0330627374351025, 3.6541351955384016, 2.7274071983993053, 7.579400567337871, 4.3319774977862835, 2.969848201610148, 46.94807678461075, 61.17919094860554, 55.44556841254234, 56.50261469185352, 55.940469056367874, 56.162396147847176, 54.20669429004192, 54.9285339564085, 54.67679746448994, 51.978072077035904, 57.885390892624855, 59.09469120204449, 54.63898569345474, 55.44108845293522, 52.44353950023651, 45.73139727115631, 39.39398713409901, 39.46063935756683, 39.55408774316311, 41.60734176635742, 41.818842217326164, 47.06764496862888, 51.56885303556919, 54.079302325844765, 49.684321358799934, 51.524764001369476, 53.3103109896183, 50.512376725673676, 51.85860648751259, 51.973219737410545, 51.12767390906811, 46.507798209786415, 37.73566111922264, 39.07929942011833, 40.3046690672636, 40.06313122808933, 38.933387249708176, 38.10476951301098, 37.574108988046646, 38.50157082080841, 39.36910226941109, 49.20093409717083, 51.88295178115368, 51.519436687231064, 53.26043486595154, 52.28356048464775, 53.49883407354355, 54.2977412045002, 52.927063554525375, 55.165443643927574, 51.79639242589474, 55.15744887292385, 49.71077173948288, 55.84014303982258, 26.200109012424946, 39.94286388158798, 55.4445044696331, 48.61611507833004, 49.4735998660326, 40.137170255184174, 42.496805638074875, 41.612171307206154, 46.84562288224697, 47.543200850486755, 47.73670166730881, 47.92990989983082, 45.1578788459301, 37.73553192615509, 38.710122630000114, 39.69404563307762, 39.76869262754917, 37.886425629258156, 39.761552810668945, 39.41601075232029, 39.19315651059151, 38.819001987576485, 38.45253445208073, 39.01394672691822, 38.10484550893307, 38.18066284060478, 39.59201730787754, 44.45267468690872, 50.39190039038658, 52.945826947689056, 52.314623817801476, 50.87329275906086, 47.48266629874706, 43.035335540771484, 46.34973809123039, 48.99315744638443, 54.02644336223602, 49.29233059287071, 49.39021334052086, 54.37805749475956, 50.64074903726578, 48.03285777568817, 43.40942166745663, 51.562040001153946, 52.284259647130966, 50.974716916680336, 42.060345858335495, 46.15565210580826, 50.77444866299629, 56.33002795279026, 54.4084482640028, 47.37004414200783, 59.29152823984623, 60.6803423166275, 57.97437831759453, 60.58985777199268, 53.097769394516945, 11.229381635785103, 3.4362190263345838, 4.154715109616518, 14.980735089629889, 2.4095240933820605, 0.23936494952067733, 10.496614705771208, 35.845657736063, 48.67230646312237, 31.104232259094715, 19.419502057135105, 30.23862160742283, 40.249515026807785, 46.12021520733833, 46.80273458361626, 40.367920473217964, 2.078263806179166, 0.11901409656275064, 0.05163044574146625, 0.07295930612599477, 0.0774218475271482, 0.043031547975260764, 0.07036350361886434, 0.042116197873838246, 0.061020569410175085, 0.08737141324672848, 0.03014598481968278, 0.036313289529061876, 0.03039724633708829, 0.04916749880067073, 0.11895356699824333, 0.013214054415584542, 0.011258755039307289, 0.06079593986214604, 0.06382054416462779, 0.053463294461835176, 0.041581988843972795, 0.030983340766397305, 0.023335655532719102, 0.06530935177579522, 0.006326077927951701, 0.04553835955448449, 0.04512567349593155, 0.01100423085517832, 0.030870949922245927, 0.028728903926094063, 0.01782271541742375, 3.118596919812262, 44.691419675946236, 65.80506652593613, 54.86317366361618, 40.809688568115234, 41.06617860496044, 34.39298428595066, 41.95709399878979, 47.09824472665787, 44.33583475649357, 2.5553391315042973, 0.28102089709136635, 6.217118566855788, 6.8016331270337105, 5.129879107698798, 10.28524249792099, 8.098028562963009, 4.975004643201828, 47.38163352012634, 64.17520478367805, 57.95605570077896, 58.52080039680004, 58.24436143040657, 57.15169586241245, 55.648553520441055, 56.02228246629238, 55.38546323776245, 55.1685556769371, 57.922324910759926, 62.65817038714886, 57.322713285684586, 56.75068058073521, 53.32655891776085, 48.177960589528084, 41.80817238986492, 40.940933525562286, 39.931795075535774, 43.6197479814291, 43.31857994198799, 49.42166805267334, 54.09593403339386, 56.59151092171669, 51.01414740085602, 53.26050326228142, 55.23225925862789, 52.70348735153675, 52.19320513308048, 53.05092550814152, 52.99344219267368, 48.101770877838135, 39.3606249243021, 41.19838871061802, 41.76669001579285, 41.83970309793949, 41.127784699201584, 40.70616692304611, 40.21443530917168, 41.286084204912186, 42.42104150354862, 49.97414320707321, 53.703753277659416, 52.51643858850002, 53.05611602962017, 55.52592650055885, 54.36132699251175, 57.011312395334244, 53.97398337721825, 57.31458552181721, 53.33632439374924, 56.299975365400314, 49.7439743578434, 58.43923777341843, 26.376347355544567, 42.596398293972015, 57.799792885780334, 49.31053161621094, 49.7372031211853, 41.96277089416981, 43.79625231027603, 42.295682430267334, 47.82156251370907, 48.99978809058666, 51.12150304019451, 49.19235035777092, 47.12112709879875, 40.11443227529526, 40.54861217737198, 42.075773030519485, 40.7322259247303, 40.237963646650314, 41.7020782828331, 42.12910316884518, 40.9825336933136, 40.31961366534233, 39.8663017898798, 40.840379521250725, 40.32350465655327, 41.051423996686935, 41.341523230075836, 46.43234185874462, 54.31745454668999, 55.55192470550537, 53.54556016623974, 52.50074543058872, 49.355866983532906, 47.488001212477684, 47.551947981119156, 50.05818709731102, 54.865347146987915, 50.80702431499958, 49.558593705296516, 55.53244315087795, 54.48368042707443, 48.96986469626427, 46.18978947401047, 54.008162543177605, 54.23966132104397, 52.69945576786995, 43.79072740674019, 46.413255482912064, 53.92834022641182, 57.40950062870979, 54.60373878479004, 48.957883939146996, 59.378193989396095, 62.184894382953644, 59.48171563446522, 60.42320631444454, 54.920664578676224, 15.911246258765459, 1.1940066050738096, 3.420451059937477, 19.90344598889351, 3.3845959464088082, 0.35571007523685694, 11.663919668644667, 43.88046719133854, 43.29359628260136, 29.34357013553381, 20.657169744372368, 33.3784045279026, 44.36497539281845, 51.58563293516636, 53.39891463518143, 49.1780099272728, 3.0328352842479944, 0.1049513480393216, 0.06744046593667008, 0.0857743485539686, 0.031514440197497606, 0.029310311692825053, 0.010601243739074562, 0.03376048705831636, 0.07520128972828388, 0.12844287499319762, 0.04434209542523604, 0.04281204666767735, 0.05347620040993206, 0.05470863310620189, 0.1482704930822365, 0.060578431221074425, 0.13012565032113343, 0.17529093223856762, 0.16356569656636566, 0.14693829347379506, 0.10214438225375488, 0.16886810422874987, 0.1441815117141232, 0.11966104895691387, 0.16611633938737214, 0.17194040265167132, 0.15007106208940968, 0.14105595677392557, 0.11811263204435818, 0.057701484620338306, 0.12395451427437365, 4.4544776994735, 54.84134383499622, 72.76669576764107, 63.75487133860588, 46.78935170173645, 46.56331703066826, 38.18606615066528, 46.83109626173973, 54.71031926572323, 48.92357937991619, 2.5389883713796735, 0.35605472861789167, 6.942426972091198, 6.914419149979949, 12.686464749276638, 22.08847314119339, 13.437531497329473, 6.089814947918057, 51.890786960721016, 65.51938265562057, 60.37631303071976, 60.55185221135616, 60.69255106151104, 59.81196731328964, 59.363230392336845, 59.91641990840435, 58.97347390651703, 58.65555256605148, 58.65773744881153, 62.290730103850365, 59.38539080321789, 58.90764243900776, 57.3829248547554, 50.98982870578766, 43.13179336488247, 43.28414998948574, 41.2697184830904, 46.828595995903015, 45.99727660417557, 52.50601954758167, 56.437341794371605, 59.13781888782978, 51.27105921506882, 54.00537729263306, 58.57699558138847, 54.74911518394947, 56.026564836502075, 56.49431213736534, 55.53006447851658, 50.51676169037819, 41.73408776521683, 42.74851933121681, 44.59392070770264, 44.45930913090706, 43.236922323703766, 42.473121508955956, 40.83052285015583, 42.844555377960205, 44.290871769189835, 53.379851058125496, 56.58522225916386, 55.02103999257088, 55.799622014164925, 56.54834523797035, 56.93527087569237, 57.52369210124016, 57.28124611079693, 58.07584427297115, 54.66807313263416, 56.75949990749359, 53.73484320938587, 58.03666837513447, 30.02828199416399, 44.70900513231754, 59.44997973740101, 52.843464240431786, 52.84149594604969, 44.6660066395998, 46.07343591749668, 46.693931221961975, 50.17861783504486, 51.44252881407738, 53.4789003431797, 51.75872124731541, 49.00601215660572, 41.5805684030056, 41.93925775587559, 43.901575058698654, 43.21102671325207, 42.7930149435997, 43.36681455373764, 45.41115425527096, 43.442160710692406, 42.20387175679207, 41.94503344595432, 43.554144501686096, 41.23674385249615, 43.35847020149231, 44.238605573773384, 49.33215245604515, 57.701332569122314, 59.48412090539932, 57.53942705690861, 53.90613801777363, 51.11644171178341, 48.955585062503815, 51.39202572405338, 53.24204005300999, 58.72595518827438, 52.56454020738602, 50.6799591332674, 59.02268506586552, 56.96077510714531, 52.14797616004944, 47.573128044605255, 55.31680852174759, 56.170113533735275, 55.900810584425926, 47.68055588006973, 50.80104723572731, 56.64174422621727, 59.966417625546455, 58.25305916368961, 53.867649883031845, 61.452479884028435, 64.80572015047073, 61.43351890146732, 66.28520876169205, 55.61230346560478, 19.170034043490887, 8.60586466267705, 14.499520361423492, 24.629157409071922, 2.814604681916535, 0.28796722122933716, 12.38375874236226, 54.50936324894428, 63.55378232896328, 44.22876410186291, 28.10312669724226, 41.20355263352394, 51.872065365314484, 59.723413065075874, 59.72796902060509, 59.042732790112495, 4.332818202674389, 0.23378868936561048, 0.13899783283704892, 0.2491998311597854, 0.09567401968524791, 0.09370647487230599, 0.12639965338166803, 0.1216072570241522, 0.18786384898703545, 0.25969510548748076, 0.18249292625114322, 0.1207520579919219, 0.1281089530675672, 0.15999014780391008, 0.2364440046949312, 0.1381234938162379], [0.035358690947759897, 0.026812836331373546, 0.02917394020187203, 0.11295558142592199, 0.037532586211455055, 0.09775888320291415, 0.11830782430479303, 0.08301505833514966, 0.04118778968404513, 0.046259300361271016, 0.031011445898911916, 0.06544929856318049, 0.04883421141130384, 0.04385321677546017, 0.059420962861622684, 5.27560081332922, 39.73376490175724, 51.49542577564716, 43.96158903837204, 30.676777996122837, 11.516629122197628, 17.682630456984043, 21.28826268017292, 43.77019330859184, 28.078116439282894, 0.8137346478179097, 0.44342919951304793, 12.241795510053635, 13.841234184801579, 2.8904151264578104, 8.063598610460758, 5.835467046126723, 4.845000319182873, 37.086720541119576, 66.3124381005764, 55.384163707494736, 59.08774517476559, 51.911093071103096, 56.45754151046276, 55.228558257222176, 58.074423149228096, 54.71684351563454, 58.819905146956444, 57.39097662270069, 52.96560488641262, 54.11497101187706, 54.39562775194645, 50.31680881977081, 43.63880775868893, 40.6769122928381, 40.05289077758789, 44.143979251384735, 50.192889869213104, 47.43826948106289, 49.05809596180916, 48.44369173049927, 53.88735182583332, 50.93737632036209, 49.85516399145126, 51.8094789236784, 54.45588871836662, 52.49198690056801, 55.855798199772835, 52.41057246923447, 53.26995335519314, 44.687988460063934, 39.273453801870346, 39.95601497590542, 39.957599490880966, 38.67041476070881, 37.979953810572624, 38.126812130212784, 38.92332158982754, 38.29268082976341, 46.74319177865982, 48.587631806731224, 50.510617420077324, 47.173138707876205, 49.42582122981548, 47.88031496107578, 51.44468329846859, 50.77104024589062, 52.98872284591198, 50.52041709423065, 52.53591254353523, 50.17397828400135, 57.80590295791626, 28.234683237969875, 42.30186469852924, 55.23165889084339, 48.338608369231224, 47.32532434165478, 41.37886382639408, 46.368220299482346, 48.76815252006054, 51.6775082051754, 51.869348511099815, 53.14852327108383, 51.83711864054203, 51.27754166722298, 47.69928887486458, 40.662024691700935, 37.87543281912804, 39.92256157100201, 38.62471841275692, 40.5053286999464, 38.43477800488472, 40.517199262976646, 38.240357637405396, 40.360727459192276, 39.56063859164715, 40.353393852710724, 40.24248160421848, 45.58068595826626, 52.5284231454134, 51.716125532984734, 53.08257021009922, 51.19664400815964, 52.521997690200806, 49.05643545091152, 49.88599553704262, 50.55769309401512, 50.62897726893425, 53.028704300522804, 50.39612576365471, 47.098628506064415, 53.6505751311779, 53.123383820056915, 51.52969993650913, 43.62005576491356, 40.917557179927826, 38.59135240316391, 41.034993678331375, 41.40526480972767, 46.669585928320885, 52.92411111295223, 54.25982303917408, 34.98253785073757, 34.421946331858635, 63.14946122467518, 56.37436397373676, 60.28837434947491, 50.11235699057579, 65.85547462105751, 33.55674795806408, 2.9112085606902838, 1.2581384950317442, 10.14317287132144, 2.14144729077816, 0.4864980181446299, 3.7284067226573825, 33.13626632094383, 31.856360100209713, 33.72700922191143, 25.146397054195404, 26.56406868249178, 35.161838829517365, 44.11318190395832, 50.018669217824936, 39.36708077788353, 3.817304139956832, 0.10065976035548374, 0.10969220224069431, 0.02530652145651402, 0.019159494077030104, 0.02305454298038967, 0.11951638211030513, 0.013379038482526084, 0.054134336969582364, 0.06871405072160996, 0.040244468036689796, 0.06918466882780194, 0.1072630267299246, 0.04130817345867399, 0.10475686081917956, 0.00987362824162119, 0.014181735205056611, 0.03108158070972422, 0.03833141912764404, 0.05048105194873642, 0.042662247869884595, 0.06406903747119941, 0.08081841995590366, 0.11137023524497636, 0.029821456628269516, 0.03927606921934057, 0.031523950819973834, 0.021808143064845353, 0.020914296692353673, 0.037637611239915714, 0.04037468526803423, 7.233216343447566, 52.142930030822754, 57.21636839210987, 51.63187265396118, 34.387774765491486, 22.553250901401043, 28.665922097861767, 26.061448752880096, 48.38546745479107, 31.20478056371212, 0.5220421124249697, 0.44839859066996723, 12.817969042807817, 16.93751133978367, 5.830602357164025, 8.56062714010477, 7.392451548948884, 3.4453316498547792, 39.708241671323776, 68.39187651872635, 56.44311748445034, 61.44115649163723, 54.37155604362488, 58.314304277300835, 58.288245275616646, 58.65634672343731, 55.18756225705147, 60.65362975001335, 57.7507147192955, 56.98874160647392, 57.31546327471733, 56.281162574887276, 51.53243198990822, 47.1053047478199, 40.67135699093342, 41.60517208278179, 45.76753333210945, 51.70705921947956, 49.102906957268715, 50.046263337135315, 50.54196573793888, 54.21060048043728, 51.74067601561546, 49.60988335311413, 54.8059943318367, 57.80948996543884, 54.722132831811905, 56.63857899606228, 52.87447437644005, 55.70426233112812, 44.66025374829769, 40.09409576654434, 41.232985854148865, 42.61518068611622, 41.28836028277874, 40.130174830555916, 39.19058404862881, 40.24586722254753, 41.12251058220863, 48.037979900836945, 51.05799324810505, 54.728444293141365, 49.911229982972145, 52.82608777284622, 50.82160413265228, 53.24888728559017, 54.87752169370651, 54.04169574379921, 51.84336170554161, 55.67834012210369, 52.451902851462364, 59.312601909041405, 29.80720605701208, 45.12405306100845, 57.357124239206314, 51.75594739615917, 49.36921566724777, 43.70469622313976, 48.30446720123291, 51.75188161432743, 54.40485365688801, 55.105452463030815, 54.581715166568756, 54.35649365186691, 52.910040467977524, 48.746410086750984, 42.95429728925228, 39.856308326125145, 41.06317296624184, 39.98871602118015, 41.4581997692585, 39.925981387495995, 41.353956162929535, 40.99319972097874, 40.68889304995537, 40.3203584253788, 42.33137011528015, 42.51816809177399, 47.02422849833965, 54.82287682592869, 54.878399446606636, 54.30021867156029, 53.43221224844456, 54.383259415626526, 51.989194080233574, 52.263087183237076, 52.237677946686745, 52.47841402888298, 54.66280661523342, 50.16521595418453, 49.92614038288593, 54.96422924101353, 53.96511845290661, 53.416089713573456, 44.763125628232956, 41.88141725957394, 41.64474695920944, 42.68184430897236, 42.69194036722183, 48.1607399135828, 57.66069374978542, 58.45625326037407, 37.30364330112934, 38.094312474131584, 63.7585723400116, 58.18510740995407, 61.18817366659641, 52.86666579544544, 66.75576031208038, 35.84845058619976, 4.293040037155151, 0.7023071707226336, 13.763589151203632, 3.182779513299465, 0.5124644888564944, 3.1995271146297455, 37.15490408241749, 37.3785562813282, 34.256822392344475, 26.92464653402567, 32.750298231840134, 41.925681084394455, 49.71855752170086, 55.752287954092026, 49.097100868821144, 5.834916550666094, 0.16810581466415897, 0.058973377308575436, 0.05944791766523849, 0.039811291280784644, 0.0196507791406475, 0.05057635484263301, 0.0014751408457414072, 0.05323289842635859, 0.07095661319908686, 0.050072199082933366, 0.05494514814927243, 0.015413150231324835, 0.09652338543673977, 0.022687207710987423, 0.01716087368549779, 0.1661240280373022, 0.15499262925004587, 0.14748087764019147, 0.244905527215451, 0.1397940979222767, 0.19764422730077058, 0.22631100233411416, 0.19051163893891498, 0.15490576828597113, 0.11038843324058689, 0.19550657481886446, 0.17384754406521097, 0.12628537748241797, 0.35367555159609765, 0.14125920133665204, 11.15006659179926, 62.463092654943466, 64.1323734819889, 58.93506556749344, 40.99014848470688, 20.5107332020998, 25.537048391997814, 32.633059322834015, 56.114408522844315, 38.43405984342098, 1.2195356539450586, 0.601889721583575, 17.251934967935085, 20.494899451732635, 10.092641282826662, 15.982014611363411, 15.919964890927076, 8.20961907505989, 42.38854184746742, 70.87473168969154, 60.015218406915665, 63.35583575069904, 56.07096165418625, 60.06058417260647, 60.88981367647648, 61.47893786430359, 55.95953643321991, 60.09282544255257, 59.2765836417675, 59.36522528529167, 57.37610042095184, 58.63137826323509, 54.22737658023834, 48.99539552628994, 44.142444133758545, 43.939314633607864, 48.21457922458649, 55.48138149082661, 51.55701667070389, 53.70381407439709, 52.70868927240372, 57.66810715198517, 52.647022381424904, 50.50229586660862, 56.714947298169136, 59.00158479809761, 57.687140330672264, 59.06075522303581, 56.62552669644356, 57.76882454752922, 47.76724822819233, 42.9973603785038, 43.42899441719055, 45.052575096488, 42.91291370987892, 41.97399169206619, 42.30158731341362, 42.974014431238174, 43.094471767544746, 50.176425352692604, 52.752797305583954, 56.052274256944656, 50.97351998090744, 54.86185133457184, 53.05021874606609, 56.13310731947422, 54.98623386025429, 56.61787010729313, 55.18457181751728, 56.635634154081345, 54.121860042214394, 59.72239851951599, 33.252076506614685, 47.00759299099445, 60.10268971323967, 53.63370403647423, 52.02988229691982, 46.379950270056725, 50.47084495425224, 53.70886780321598, 56.16813383996487, 55.91361589729786, 57.53066472709179, 56.14892207086086, 55.3668974339962, 50.64737968146801, 45.212079137563705, 42.12367706000805, 42.63341970741749, 41.20808959007263, 44.33730907738209, 41.189056411385536, 44.19699780642986, 43.12750719487667, 44.594323486089706, 43.28484155237675, 45.22036649286747, 44.96267192065716, 49.261426851153374, 58.72168801724911, 56.31689205765724, 56.630128249526024, 55.05835399031639, 56.07424847781658, 54.835761934518814, 54.74479861557484, 54.52680051326752, 54.40926522016525, 57.44204968214035, 51.85557425022125, 49.45982940495014, 56.864051297307014, 56.958457231521606, 56.17992460727692, 48.68954613804817, 44.90256294608116, 43.392998948693275, 44.362809509038925, 46.045294627547264, 51.36649489402771, 59.423058182001114, 61.160978525877, 38.97812604904175, 41.40084184706211, 66.0703606903553, 61.24371528625488, 66.0297104716301, 54.0243648737669, 69.76630836725235, 38.55409160256386, 7.532147727906704, 4.690463561564684, 16.1478928104043, 4.231706578284502, 0.6654838810209185, 4.409846719354391, 44.52855281531811, 47.49676734209061, 46.752972453832626, 35.03139182925224, 37.35589809715748, 48.739798441529274, 57.02394671738148, 60.802627354860306, 58.35008315742016, 9.08001746982336, 0.3192040091380477, 0.16934033279540017, 0.11238728926400654, 0.15934407856548205, 0.15033090283395723, 0.18046625453280285, 0.10284856907674111, 0.12771889509167522, 0.18329296144656837, 0.13601209851913154, 0.1776987561606802, 0.165950647497084, 0.20338994945632294, 0.1819588619400747, 0.09621711593354121], [0.04187335602182429, 0.05577266878390219, 0.02397021591605153, 0.03266893996624276, 0.05814943011500873, 0.033221606208826415, 0.09050648994161747, 0.08649754920043051, 0.036720620992127806, 0.021269458884489723, 0.041754560443223454, 0.06394213763996959, 0.010823591182997916, 0.041424393784836866, 0.19535933271981776, 12.839581333100796, 47.51590311527252, 54.81605239212513, 42.17453733086586, 31.850880794227123, 13.303338848054409, 32.32098586857319, 36.38796463608742, 49.70110885798931, 16.41720335930586, 0.247343051887583, 0.23547792137833312, 4.521904606372118, 6.638425709679723, 3.507304424419999, 4.8126360308378935, 5.266489377245307, 3.9424340380355716, 28.75982455909252, 65.15866801142693, 53.25763441622257, 57.838227823376656, 53.23265455663204, 60.61999395489693, 49.527002200484276, 54.70661446452141, 49.89141024649143, 54.713951870799065, 47.2770631313324, 54.179305359721184, 52.54627838730812, 50.34798614680767, 42.25175678730011, 42.717737182974815, 37.30387508869171, 44.141748771071434, 50.25183230638504, 55.01624844968319, 51.95309981703758, 51.775330156087875, 49.23164024949074, 54.8946625739336, 49.433694407343864, 48.91686134040356, 45.801271721720695, 48.84381785988808, 49.1072691231966, 50.49967020750046, 51.6125962883234, 53.02918687462807, 48.25947381556034, 39.86474387347698, 38.589684292674065, 38.072034269571304, 40.93310594558716, 38.74236389994621, 36.760648638010025, 38.30708205699921, 39.00070063769817, 41.87528058886528, 44.58936855196953, 45.044888108968735, 44.58635151386261, 45.374132841825485, 45.025189965963364, 47.49125003814697, 46.76214516162872, 48.306135311722755, 47.63028457760811, 53.94169270992279, 49.93625544011593, 58.96629989147186, 31.48796606808901, 44.97379772365093, 53.19429561495781, 48.98828610777855, 49.0170543640852, 47.54094377160072, 50.99279634654522, 51.46598495543003, 50.67679390311241, 50.02994701266289, 48.49537655711174, 48.37570197880268, 53.47000502049923, 54.9069245159626, 46.64745591580868, 39.11356598138809, 38.102759420871735, 38.80550891160965, 37.88992524147034, 39.05943028628826, 38.78669232130051, 39.55651581287384, 39.63550977408886, 38.715354949235916, 39.383575692772865, 47.461942210793495, 50.76138496398926, 51.32536970078945, 52.0661361515522, 47.27122664451599, 50.25278985500336, 54.180129915475845, 55.81878438591957, 52.67318017780781, 50.96728451550007, 54.67277728021145, 49.32945840060711, 49.51717592775822, 50.79605810344219, 52.981267645955086, 53.97416576743126, 49.616491198539734, 38.65156017243862, 38.76126028597355, 38.465294167399406, 39.9169796705246, 42.30026878416538, 46.880372017621994, 55.554671958088875, 54.77335408329964, 48.83858174085617, 58.06013211607933, 56.839561611413956, 52.28248134255409, 54.900575056672096, 52.82864883542061, 61.58378943800926, 53.270002752542496, 9.99900670722127, 1.3789183390326798, 9.791557788848877, 5.206739958375692, 0.6190943077672273, 1.0781371663324535, 26.33595172315836, 40.16712784767151, 30.057929903268814, 34.741216599941254, 20.706861577928066, 33.62460471689701, 45.134988874197006, 48.10936667025089, 48.58099356293678, 9.284886326640844, 0.29253000451717526, 0.10327039839467034, 0.09121762326685712, 0.04511537619691808, 0.02831482262990903, 0.0790137097646948, 0.05214747776335571, 0.0628704392875079, 0.10172748821787536, 0.04955456592142582, 0.04206568359222729, 0.03690802812343463, 0.023885750233603176, 0.05952674488071352, 0.07821968596545048, 0.0727500204811804, 0.04025692498544231, 0.06567131204064935, 0.05100513437355403, 0.06148958076664712, 0.011566467092052335, 0.03813824921962805, 0.04294839774956927, 0.036854415375273675, 0.05843527200340759, 0.049883856845553964, 0.007804309934726916, 0.06204865174368024, 0.016197515906242188, 0.19386734871659428, 18.993220031261444, 58.01526792347431, 58.789309188723564, 49.032960310578346, 35.1350312680006, 12.558300476521254, 31.24477531760931, 34.88473869860172, 54.63827893137932, 18.377472572028637, 0.04293738798878621, 0.14552565990015864, 9.17328916490078, 12.374969813972712, 4.412043001502752, 9.057517927139997, 6.411015512421727, 4.2867841478437185, 32.10639998316765, 65.7785439491272, 55.09154140949249, 58.86352680623531, 54.37412090599537, 59.852366745471954, 51.304645612835884, 54.44217525422573, 51.603191792964935, 55.77360101044178, 50.15211045742035, 56.680019572377205, 53.58002811670303, 51.94274537265301, 44.315756633877754, 43.744400292634964, 39.693756848573685, 45.66498063504696, 52.760765478014946, 54.829081892967224, 53.33531364798546, 53.961744233965874, 52.67439231276512, 56.87189407646656, 50.54411642253399, 48.031489849090576, 47.516017109155655, 50.61299912631512, 49.97162014245987, 52.469970881938934, 52.926873564720154, 55.256984531879425, 50.102378726005554, 39.84753079712391, 39.49623964726925, 40.35289987921715, 42.1578524261713, 41.49023965001106, 38.810874223709106, 41.15951679646969, 40.51043942570686, 44.061322286725044, 46.416200324893, 46.53031200170517, 46.0099071264267, 48.35004575550556, 47.40084528923035, 49.679066240787506, 47.47014597058296, 51.48339182138443, 49.188204780220985, 53.7187472730875, 52.86187045276165, 61.4119740575552, 33.832445964217186, 45.781034007668495, 56.891003251075745, 52.379683926701546, 51.134395748376846, 49.08091373741627, 50.994867235422134, 53.86148281395435, 52.228262051939964, 49.414615631103516, 49.47123259305954, 51.739023104310036, 56.763045117259026, 55.175315514206886, 48.026413321495056, 40.78048713505268, 40.167219042778015, 40.61932638287544, 39.28834520280361, 40.89426063001156, 40.16014762222767, 41.81866742670536, 41.29820175468922, 42.00576938688755, 41.289051845669746, 48.4234844148159, 51.553156077861786, 52.229086607694626, 53.33698555827141, 48.78881201148033, 51.856330409646034, 56.65134251117706, 57.014504224061966, 54.28689658641815, 54.170474633574486, 56.255719140172005, 50.51286309957504, 48.73219504952431, 51.736355647444725, 54.676444083452225, 56.04957640171051, 52.19994597136974, 41.593795493245125, 40.606388077139854, 40.23466542363167, 42.66872361302376, 44.82480011880398, 48.71918834745884, 57.84382112324238, 56.027396991848946, 53.927435874938965, 61.30576215684414, 58.07205967605114, 53.93440470099449, 57.38880693912506, 55.619663670659065, 62.70073190331459, 57.1293568611145, 12.966043297201395, 0.9131394512951374, 8.561810776591301, 5.093653751537204, 0.5642455571796745, 0.7972317771054804, 28.914753645658493, 46.707659885287285, 30.81276699900627, 29.7778507322073, 27.312771007418633, 40.10747104883194, 52.25325331091881, 51.96171015501022, 57.80735068023205, 13.395233117043972, 0.19947804452385753, 0.06982986233197153, 0.06189348721818533, 0.0638351718953345, 0.011202546629647259, 0.015720385454187635, 0.0388323836523341, 0.03213187366782222, 0.035459849386825226, 0.025619394218665548, 0.06654566590441391, 0.05115321138873696, 0.07017382551566698, 0.02156279831979191, 0.036712034343509004, 0.18691195553401485, 0.13045281870290637, 0.118667120259488, 0.15816985251149163, 0.11655529451672919, 0.2696771698538214, 0.11570851886062883, 0.16965665097814053, 0.09920728829456493, 0.16441288782516494, 0.14213492075214162, 0.18345259741181508, 0.140886465087533, 0.11634715177933685, 0.2811201073927805, 27.355820797383785, 67.10420161485672, 66.55092090368271, 55.93092396855354, 42.169354408979416, 20.675524659454823, 44.47321638464928, 48.32278981804848, 63.60987491905689, 21.674644947052002, 0.34703448764048517, 0.4313540115254, 8.736351560801268, 13.36230218410492, 9.217771477997303, 14.050305616110563, 15.937254913151264, 7.4844564869999886, 33.32329608500004, 68.58593970537186, 55.53730309009552, 61.67496554553509, 53.40312860906124, 61.19575046002865, 51.42940431833267, 55.85141323506832, 51.16792514920235, 58.96138675510883, 54.02347192168236, 58.81171278655529, 55.658816769719124, 54.991891756653786, 45.966969430446625, 46.64900243282318, 39.511723816394806, 48.00503946840763, 54.28078271448612, 59.33484971523285, 55.616251453757286, 56.383806467056274, 54.33115281164646, 58.3672696352005, 51.9790980219841, 48.89063514769077, 47.463169544935226, 50.50398297607899, 51.176687479019165, 51.1520230025053, 53.93847428262234, 57.41136632859707, 51.5710873156786, 42.84733682870865, 41.902604922652245, 41.74201413989067, 45.111775919795036, 44.22535568475723, 41.27942696213722, 41.1785651743412, 42.40360803902149, 45.81905856728554, 48.268566727638245, 48.22435989975929, 48.19688357412815, 49.96854230761528, 48.451621904969215, 52.31113940477371, 49.87074315547943, 54.299006536602974, 52.41370730102062, 57.98068977892399, 53.73309150338173, 63.44577692449093, 36.76912218332291, 48.255430832505226, 58.35426293313503, 53.67808185517788, 54.2620687186718, 51.20257928967476, 55.052175521850586, 56.03417582809925, 52.319631949067116, 51.84142380952835, 49.84179250895977, 52.86472029983997, 58.30468699336052, 57.432398200035095, 51.50605000555515, 44.057351499795914, 42.42910847067833, 43.0575605481863, 41.03567764163017, 42.7346158772707, 43.11096288263798, 44.285434260964394, 42.73346073925495, 43.71277078986168, 43.95128779113293, 53.86626295745373, 54.69570145010948, 54.71374288201332, 55.68784341216087, 49.91901196539402, 53.07208277285099, 58.42957869172096, 59.38886381685734, 58.39304365217686, 57.216782569885254, 58.58107656240463, 51.07808277010918, 50.688531473279, 52.81428560614586, 57.612056359648705, 60.107564851641655, 55.39209008216858, 43.12842294573784, 42.63047866523266, 41.371287032961845, 45.15524938702583, 46.79777964949608, 50.884540155529976, 59.87126313149929, 57.274189889431, 55.12181058526039, 60.96516743302345, 62.891071289777756, 59.01613041758537, 59.25691209733486, 59.33112591505051, 67.27545842528343, 58.59015807509422, 16.117488741874695, 4.26858882419765, 14.858416803181171, 6.886160541325808, 0.5802424612920731, 0.8795317390467972, 33.55115085840225, 57.96856462955475, 42.624190002679825, 45.03647156059742, 32.05519013106823, 43.99009890854359, 59.659280106425285, 59.262026622891426, 67.3280856013298, 17.75114458054304, 0.48383035347796977, 0.23493029060773551, 0.11807907954789698, 0.14219383243471384, 0.09736803855048493, 0.20413828664459288, 0.21101204358274117, 0.11613665643380955, 0.15983245626557618, 0.1676377866533585, 0.13168845005566254, 0.2038599961088039, 0.13777670304989442, 0.15622647944837809, 0.19386291067348793], [0.023475552225136198, 0.010742141403170535, 0.06986909225815907, 0.085380179079948, 0.05673277410096489, 0.027410343136580195, 0.027140097481606063, 0.04685824693297036, 0.03700173168908805, 0.02246492891572416, 0.05647564961691387, 0.06213961307366844, 0.08999130586744286, 0.07907465493190102, 0.7128228095825762, 22.857437878847122, 55.352108627557755, 46.71289600431919, 40.25046497583389, 26.55525505542755, 33.00831958651543, 45.734144523739815, 32.13959500193596, 49.658304154872894, 11.84184892103076, 0.10285970871336758, 0.04192607077129651, 0.7152993266936392, 3.1084671383723617, 6.792263304814696, 5.40369288995862, 5.146359298378229, 4.32760963216424, 29.055433496832848, 56.79205276072025, 51.80609330534935, 57.61192336678505, 58.10706339776516, 57.24857546389103, 57.25876271724701, 57.22424916923046, 53.83016489446163, 52.16806188225746, 56.01272597908974, 53.57021704316139, 46.826012134552, 40.8782634884119, 40.14659374952316, 41.084155440330505, 40.06994046270847, 47.50753216445446, 50.09125292301178, 53.273278176784515, 50.61491422355175, 52.83743776381016, 50.7428989559412, 49.446575716137886, 47.37762473523617, 53.26088324189186, 51.745976731181145, 50.931266248226166, 47.71047927439213, 49.31189574301243, 45.57676076889038, 51.270766630768776, 50.593300983309746, 38.380896896123886, 36.20661176741123, 39.3122573196888, 39.94345284998417, 38.228411078453064, 39.96915087103844, 37.560216933488846, 38.46795402467251, 41.82974003255367, 40.25130853056908, 42.73702494800091, 41.51868112385273, 44.50912445783615, 42.11503632366657, 45.946621522307396, 44.40468706190586, 47.39833742380142, 45.3235537558794, 49.89405110478401, 49.70531143248081, 54.466163367033005, 35.80983325839043, 46.00353106856346, 54.23607811331749, 49.434458166360855, 50.17125383019447, 50.28137572109699, 52.247223034501076, 49.41518560051918, 51.2618675082922, 45.9500527381897, 47.91156068444252, 47.548003792762756, 49.7254541516304, 52.2567643225193, 53.43167647719383, 46.47752903401852, 39.479968920350075, 38.352288231253624, 39.386858716607094, 39.32378590106964, 39.150545597076416, 38.047183603048325, 38.96051399409771, 39.096915274858475, 46.48527301847935, 50.083060562610626, 51.334162428975105, 51.81422106921673, 47.39624373614788, 45.74346162378788, 48.61148312687874, 46.523396372795105, 51.846804320812225, 56.028502732515335, 51.04411259293556, 47.01765485107899, 48.45137491822243, 53.56420956552029, 53.3694776147604, 52.690260261297226, 49.50501278042793, 42.77831353247166, 38.66658076643944, 40.88601887226105, 45.72306051850319, 44.30148459970951, 41.20624288916588, 43.06206330657005, 51.26892752945423, 53.410876393318176, 60.35234771668911, 54.4356320053339, 50.45851841568947, 44.72670458257198, 50.31899370253086, 53.46043333411217, 55.108720287680626, 59.31097559630871, 29.955947175621986, 1.0476524708792567, 4.691505655646324, 2.6205588318407536, 0.11286172943073325, 0.12142721199779771, 14.039558842778206, 35.11652246117592, 42.31660030782223, 86.78459957242012, 32.248375564813614, 24.633264988660812, 40.866620913147926, 51.44892767071724, 48.26357759535313, 21.181155927479267, 0.6912271433975548, 0.033897264875122346, 0.07155960818636231, 0.02858276948245475, 0.10610820041620173, 0.05780940402473789, 0.15023696178104728, 0.07130774552933872, 0.022328065751935355, 0.020030196574225556, 0.05685438241926022, 0.008691810016898671, 0.10393222342827357, 0.04040488325699698, 0.0562637961411383, 0.09235860110493377, 0.03662397481093649, 0.05243354971753433, 0.05888581130420789, 0.019320694118505344, 0.06171374647237826, 0.026961835465044715, 0.017137525719590485, 0.019913703508791514, 0.05422476395324338, 0.029057747706247028, 0.007230261026052176, 0.044500180301838554, 0.04716882831417024, 0.4908011684892699, 30.876278690993786, 63.08858849108219, 53.28074857592583, 43.22926953434944, 32.276228070259094, 34.80328626930714, 41.437411084771156, 36.860419884324074, 55.381864830851555, 12.542491424828768, 0.11732913932064548, 0.05054089502664283, 1.2551592173986137, 5.737198619171977, 7.4445676524192095, 10.282468646764755, 5.556234754621983, 6.106549724936485, 29.958546236157417, 57.48975612223148, 51.05420485138893, 58.92738617956638, 58.58483836054802, 59.23777632415295, 57.71281935274601, 58.241287395358086, 54.91423912346363, 54.60926368832588, 58.273684456944466, 55.54130047559738, 47.674658596515656, 42.56859518587589, 40.154656916856766, 43.22268828749657, 42.60201059281826, 50.24215802550316, 52.17416435480118, 55.87715685367584, 52.34072841703892, 54.14792664349079, 51.3588573038578, 49.31807801127434, 48.626195937395096, 53.981100395321846, 52.304436564445496, 52.257873862981796, 48.01665164530277, 49.22763906419277, 45.1651668548584, 54.254408329725266, 53.09729062020779, 40.14848604798317, 38.299003690481186, 40.26773504912853, 41.747292056679726, 39.17290359735489, 40.285624489188194, 39.63739827275276, 40.26545137166977, 43.3183291554451, 42.79209919273853, 44.72983181476593, 45.48863209784031, 45.50975516438484, 44.152897372841835, 46.7468623816967, 46.00849740207195, 49.355642795562744, 47.28854991495609, 52.46482215821743, 50.896707102656364, 56.0868714004755, 36.54107362031937, 47.03852713108063, 55.396699234843254, 51.15082606673241, 51.25628940761089, 52.16588839888573, 54.290966168046, 52.078762874007225, 52.38827906548977, 47.264216020703316, 49.99017834663391, 49.16829764842987, 50.00754341483116, 53.73253673315048, 55.5371169000864, 47.16928951442242, 41.22259721159935, 41.0201782733202, 40.47115333378315, 40.47622226178646, 40.964857041835785, 39.64284338057041, 40.9945372492075, 41.10969766974449, 49.23630639910698, 52.612972408533096, 53.89262214303017, 53.254267796874046, 48.88151563704014, 45.85079446434975, 48.8488981872797, 49.20832470059395, 52.63419806957245, 56.963738948106766, 51.36164255440235, 47.92554773390293, 49.73967678844929, 53.958993181586266, 54.23238471150398, 53.17409589886665, 52.7799316495657, 45.417644307017326, 40.58138161897659, 43.9064159989357, 46.754720360040665, 45.666709542274475, 44.66956704854965, 46.07974357903004, 55.00215880572796, 54.78847347199917, 62.61277802288532, 56.21518671512604, 52.90805697441101, 45.654276609420776, 50.79365283250809, 55.090549662709236, 57.92869336903095, 58.194002732634544, 34.06886927783489, 0.3917660436127335, 6.7076237965375185, 7.681933315470815, 0.13950075663160533, 0.14621597598306835, 14.886724334210157, 44.619687125086784, 39.725314155220985, 75.27509316802025, 37.4467284232378, 30.90256378054619, 46.84756837785244, 59.925607815384865, 54.472079649567604, 29.600666239857674, 0.9355356870219111, 0.03623854041507002, 0.036982851452194154, 0.014689058079966344, 0.016910836711758748, 0.020760430925292894, 0.06589061667909846, 0.04379607882583514, 0.08441230718744919, 0.03317026072181761, 0.08020879016839899, 0.07767002913169563, 0.041091217717621475, 0.07262492406880483, 0.048152556191780604, 0.13662711629876867, 0.11033085742383264, 0.20330374158220366, 0.20269112836103886, 0.11399757902836427, 0.18095822422765195, 0.11478340209578164, 0.11269890965195373, 0.17231269361218438, 0.15057368902489543, 0.10683252170565538, 0.09175306055112742, 0.18836858362192288, 0.2220990025671199, 1.2445475743152201, 40.149151012301445, 71.37279376387596, 59.16593737900257, 52.58157089352608, 37.40442909300327, 46.40476293861866, 60.300583094358444, 43.23513641953468, 63.408987298607826, 15.174438245594501, 0.24684953852556646, 0.1867959281662479, 1.6741392225958407, 6.145005561411381, 15.504029709845781, 12.99229133874178, 13.067975677549839, 7.86601728759706, 30.533407889306545, 56.1932010948658, 52.515720427036285, 59.82568457722664, 60.044279247522354, 62.003066539764404, 60.14461666345596, 60.63994288444519, 58.50316934287548, 57.801723182201385, 59.719461277127266, 58.600561916828156, 50.903542935848236, 43.938406482338905, 44.40434128046036, 45.38901664316654, 45.50029747188091, 52.40386962890625, 54.7746954113245, 58.106459230184555, 54.476943388581276, 56.349893286824226, 52.32710614800453, 50.46723514795303, 48.96228790283203, 56.09625309705734, 55.08276768028736, 54.07595470547676, 48.735941648483276, 50.31737878918648, 47.061394304037094, 56.62369519472122, 53.57369765639305, 42.4749606102705, 39.32462565600872, 43.00169214606285, 43.57995271682739, 41.40642374753952, 44.26797799766064, 41.64147533476353, 41.879331171512604, 45.73249541223049, 46.280676797032356, 48.033271953463554, 48.53737570345402, 50.11654436588287, 46.345854699611664, 49.85944636166096, 48.662407994270325, 52.16519683599472, 49.91912215948105, 54.47220504283905, 54.14378486573696, 57.4117387086153, 39.66584734618664, 50.60588210821152, 56.90098911523819, 53.949687480926514, 53.890957832336426, 56.31000682711601, 55.453597381711006, 52.55061775445938, 54.87841084599495, 49.52729478478432, 50.616726726293564, 48.32239083945751, 53.57452221214771, 57.74167500436306, 57.459711134433746, 49.78754661977291, 44.15034390985966, 43.34211967885494, 43.61955039203167, 43.098347559571266, 43.66996608674526, 42.57106125354767, 43.68281699717045, 43.12826335430145, 52.05371841788292, 55.269436463713646, 56.31842717528343, 55.32720856368542, 49.761765003204346, 46.152536273002625, 50.067428201437, 48.67080174386501, 54.20815721154213, 57.328226789832115, 52.276618257164955, 48.67521710693836, 51.497261077165604, 55.60277357697487, 57.45587334036827, 57.36444644629955, 53.76757465302944, 47.154633700847626, 44.06547546386719, 46.46641083061695, 49.77420173585415, 48.39941270649433, 47.435795813798904, 48.228528276085854, 56.53755001723766, 57.76980869472027, 65.90988770127296, 59.727642238140106, 54.11074563860893, 48.965498730540276, 54.16231267154217, 59.00837503373623, 59.357853680849075, 61.181185841560364, 36.737694069743156, 4.390259720385075, 9.64013496413827, 5.288160089403391, 0.23157927120337263, 0.15884781925706193, 19.187275618314743, 51.12799309194088, 53.70272733271122, 97.07642331719398, 44.73747320473194, 37.476986199617386, 54.798710122704506, 66.00849241018295, 62.855148017406464, 37.739179730415344, 1.3435366563498974, 0.1354844166780822, 0.1752702856902033, 0.10555257671512663, 0.15057425305712968, 0.1370767835760489, 0.3060962859308347, 0.20629467093385756, 0.1382247227593325, 0.12103848246624693, 0.1559169148094952, 0.13152960076695308, 0.183060921553988, 0.1775807249941863, 0.14776197349419817], [0.07760812659398653, 0.03888564016961027, 0.01408120109772426, 0.0722566332842689, 0.0988665979821235, 0.015608144894940779, 0.023402784645440988, 0.039996397754293866, 0.027242716096225195, 0.029107035588822328, 0.0793964130571112, 0.014569897921319352, 0.04640084647689946, 0.03902538286638446, 0.8510135568212718, 31.345093734562397, 52.01157487928867, 44.95599567890167, 39.99819651246071, 20.864929296076298, 10.456500258296728, 31.388947181403637, 35.007905289530754, 54.714810624718666, 6.300919270142913, 0.09585031686583534, 0.0503560557262972, 3.202092214487493, 4.516789130866528, 3.212414598092437, 7.903371658176184, 3.9758689189329743, 10.770763345062733, 39.690918400883675, 55.33947050571442, 56.36698476970196, 60.18908187747002, 51.485626101493835, 55.83212547004223, 55.0039941072464, 56.58870667219162, 55.3199927508831, 54.630257561802864, 50.29713727533817, 45.898128524422646, 40.0378929823637, 40.048760399222374, 42.03792326152325, 42.337324395775795, 45.85266396403313, 50.98460778594017, 53.356250524520874, 51.916469782590866, 47.34093390405178, 49.93439733982086, 47.338692024350166, 48.23434576392174, 54.01267670094967, 51.3820094615221, 48.806625455617905, 52.43220090866089, 54.283564165234566, 51.087016090750694, 46.64094306528568, 52.32578381896019, 47.799067720770836, 38.45694601535797, 37.1903295814991, 39.39177945256233, 39.03089001774788, 39.73435387015343, 36.64339832961559, 37.977274954319, 39.16257955133915, 38.8723511248827, 39.23908084630966, 41.73439174890518, 41.688680201768875, 43.47187511622906, 43.2407221198082, 45.91820664703846, 42.807545363903046, 48.12542840838432, 45.565505772829056, 51.06847308576107, 50.41791759431362, 59.43580649793148, 33.86533699929714, 40.34542568027973, 56.354821622371674, 50.58456905186176, 51.249035596847534, 49.559733644127846, 50.69540150463581, 46.10742889344692, 45.40353946387768, 46.41715407371521, 48.026892095804214, 44.935640171170235, 47.890794798731804, 52.26170405745506, 50.10502338409424, 53.50060477852821, 45.24326026439667, 37.066558822989464, 38.694988042116165, 39.639271572232246, 38.62524278461933, 39.577323496341705, 38.585979491472244, 42.131124660372734, 51.67113594710827, 51.649781093001366, 52.685521915555, 45.97812183201313, 50.7684525847435, 50.01695550978184, 48.82675297558308, 48.62162098288536, 43.49258400499821, 48.96885775029659, 47.213792726397514, 51.52586594223976, 53.86012628674507, 52.54663176834583, 50.629102662205696, 48.231032341718674, 43.9872832596302, 41.477894112467766, 46.680263355374336, 53.47510054707527, 52.83065892755985, 50.55518142879009, 45.32864548265934, 39.55799773335457, 42.02258348464966, 46.196853294968605, 45.26572845876217, 44.70017060637474, 43.76829341053963, 49.529540464282036, 56.237643510103226, 58.88741992413998, 58.12023349106312, 61.40342451632023, 42.885065004229546, 1.0429542604833841, 1.6273202723823488, 6.863779267296195, 1.814927130471915, 0.19576935446821153, 5.827659890055656, 40.69637484848499, 54.08592537045479, 59.66708108782768, 22.333109714090824, 27.03905649483204, 37.66660362482071, 49.17087011039257, 48.078850507736206, 31.874943003058434, 2.3111706459894776, 0.09180500346701592, 0.020661100024881307, 0.10010277852416039, 0.06272860002354719, 0.08588903263444081, 0.06109130350523628, 0.034006765054073185, 0.05697800937923603, 0.00484128069729195, 0.07997420470928773, 0.04363669148006011, 0.09518274018773809, 0.048131787189049646, 0.06845274052466266, 0.028306772182986606, 0.08274140622233972, 0.050808710147975944, 0.00541102932402282, 0.047955404661479406, 0.03216009012248833, 0.02941207683761604, 0.066403292294126, 0.10486898449016735, 0.054980927088763565, 0.0321622200863203, 0.010636603365128394, 0.010365332618675893, 0.09055048445588909, 1.1002279934473336, 40.18046893179417, 61.830483600497246, 51.22609622776508, 50.059486627578735, 28.424015678465366, 17.362271547317505, 36.593313217163086, 36.72232009470463, 59.187619015574455, 6.168751437216997, 0.16671161603881046, 0.14519443939207122, 5.12353059835732, 6.441920204088092, 7.199195818975568, 8.045096453279257, 6.869303695857525, 12.413798030465841, 40.58304972946644, 55.60930922627449, 57.30876803398132, 60.87282478809357, 52.485056072473526, 58.875731751322746, 55.55659465491772, 58.94804947078228, 57.284312546253204, 58.318282663822174, 53.65317799150944, 50.17975777387619, 41.97275295853615, 42.5567702203989, 43.36228899657726, 42.93310962617397, 48.06576780974865, 53.10996674001217, 56.176159009337425, 54.51936811208725, 48.16564165055752, 49.780877977609634, 48.96364443004131, 50.09299322962761, 55.33819757401943, 54.48727883398533, 51.71688549220562, 54.93351548910141, 55.88531121611595, 52.092362344264984, 47.47616484761238, 55.645346492528915, 50.8691281825304, 39.40686084330082, 38.855772614479065, 42.313750460743904, 39.728486984968185, 40.21485708653927, 38.54792073369026, 39.51855204999447, 40.25164291262627, 41.699528619647026, 41.24957576394081, 43.775931000709534, 44.442806616425514, 44.47311379015446, 45.00614158809185, 48.45484033226967, 45.404694601893425, 50.69970287382603, 48.85125786066055, 52.776774019002914, 51.45951770246029, 60.330510288476944, 36.16889499127865, 40.60866795480251, 59.25960995256901, 51.77414081990719, 54.66100551187992, 52.96821914613247, 51.52957834303379, 48.96272487938404, 46.32281273603439, 47.07989551126957, 48.22737693786621, 47.82256565988064, 49.343741834163666, 53.297855257987976, 51.39552913606167, 56.22470140457153, 47.87503324449062, 39.695652946829796, 41.043748408555984, 40.732374116778374, 41.508353278040886, 42.4830237776041, 41.59839704632759, 45.254424065351486, 54.20011684298515, 55.40379725396633, 55.00756971538067, 47.1470645070076, 49.93437074124813, 48.888389468193054, 52.00229957699776, 48.35886888206005, 44.63636063039303, 47.66102112829685, 47.33053386211395, 50.16816459596157, 57.26266510784626, 54.62503284215927, 53.633658438920975, 51.1346123367548, 46.73186458647251, 42.982734963297844, 48.28642576932907, 55.695013627409935, 55.32534286379814, 52.20194086432457, 46.07363350689411, 41.231340542435646, 44.0606003254652, 47.71127723157406, 48.54997202754021, 46.568689942359924, 47.00242526829243, 49.948969557881355, 58.427154421806335, 59.70682695508003, 62.031150832772255, 61.275838762521744, 47.71078325808048, 2.3252125550061464, 0.4242650169180706, 14.206178952008486, 3.7572523998096585, 0.129479625611566, 5.7486858777701855, 44.92253467440605, 51.75044149160385, 62.301749512553215, 26.064150407910347, 32.47345648705959, 42.29814849793911, 54.6114257723093, 55.92648580670357, 39.438756331801414, 2.9590456187725067, 0.19830407080007717, 0.06905671514687128, 0.05800819941214286, 0.020541955636872444, 0.03149756375933066, 0.027956543417531066, 0.029710312592214905, 0.04537056738627143, 0.056926203760667704, 0.08128326415317133, 0.07730429875664413, 0.034438071597833186, 0.05681455135345459, 0.058841690624831244, 0.1521513020270504, 0.15611270820954815, 0.0954873398586642, 0.11239499275689013, 0.1927025182521902, 0.14444948639720678, 0.13287928537465632, 0.15079254837473854, 0.21788182260934263, 0.11971117361099459, 0.13239886349765584, 0.07811569623299874, 0.07361477095400915, 0.1127621480554808, 2.1234858920797706, 50.540878996253014, 70.00721544027328, 59.223952665925026, 54.38857913017273, 28.633129857480526, 18.473084941506386, 43.159478679299355, 45.236097648739815, 66.47152036428452, 7.044327529147267, 0.7822864665649831, 0.19583720160881057, 10.951665937900543, 12.134849298745394, 9.714946299791336, 17.674153111875057, 13.93810523673892, 14.47555884718895, 45.28851583600044, 56.419505551457405, 59.4613753259182, 62.409735918045044, 56.00781284272671, 60.06620407104492, 59.7158894687891, 61.24291732907295, 58.401334807276726, 58.60562704503536, 55.44855125248432, 51.72668896615505, 44.211570024490356, 44.78206381201744, 46.082794815301895, 45.037831887602806, 49.34541754424572, 53.799656331539154, 58.83922331035137, 55.55981308221817, 48.88390190899372, 51.14088200032711, 48.273711651563644, 51.09115406870842, 58.52872297167778, 55.95467269420624, 55.26008516550064, 56.151984706521034, 59.687371999025345, 54.01760123670101, 48.93780581653118, 58.40695470571518, 53.315972685813904, 40.822877660393715, 41.73795975744724, 43.174031898379326, 42.92611040174961, 41.87239274382591, 40.35682126879692, 42.313047498464584, 43.159539476037025, 43.1090933829546, 43.82399082183838, 45.732582807540894, 46.69345244765282, 46.74251161515713, 46.97045758366585, 50.69945588707924, 46.56305484473705, 52.70861327648163, 49.78735662996769, 55.89001156389713, 54.38230946660042, 63.1614837795496, 39.191628992557526, 44.765644893050194, 61.21617816388607, 54.7011199593544, 57.29421481490135, 53.790574818849564, 53.783191815018654, 49.69044663012028, 48.56082804501057, 47.79077656567097, 49.15259309113026, 50.41757941246033, 49.977498427033424, 54.056758135557175, 54.09441411495209, 58.27681168913841, 49.66253712773323, 41.43446624279022, 42.96764597296715, 43.55613939464092, 43.21762315928936, 44.5079655200243, 43.60061600804329, 46.67742870748043, 55.46157315373421, 56.79716348648071, 55.68851597607136, 47.00315102934837, 50.506563037633896, 51.36030122637749, 52.70911484956741, 50.70412963628769, 45.176243260502815, 49.31612491607666, 47.60317303240299, 53.40127810835838, 60.32418742775917, 58.423723205924034, 55.05096718668938, 53.08174945414066, 47.05792509019375, 45.45657321810722, 51.25456050038338, 58.32230284810066, 58.50039169192314, 54.905469194054604, 48.8177702575922, 43.642930537462234, 46.0837409645319, 50.722665041685104, 51.020918637514114, 49.68834154307842, 48.67472693324089, 52.52639785408974, 60.118952840566635, 63.88552352786064, 64.95673164725304, 64.66753676533699, 47.5561847537756, 3.406158839352429, 3.9025433035567403, 11.979374941438437, 3.037159452214837, 0.3367483802139759, 7.715680729597807, 54.96384546160698, 66.00617453455925, 68.11651289463043, 31.72417089343071, 36.97359301149845, 49.5775280892849, 63.62253583967686, 63.22925694286823, 47.01581954956055, 4.70572211779654, 0.32793353602755815, 0.12238719486049376, 0.2343169946107082, 0.1077848975546658, 0.15024871740024537, 0.07817636680556461, 0.13750409736530855, 0.20724398171296343, 0.2121576969511807, 0.12513585010310635, 0.18131904158508405, 0.231156247027684, 0.16053673956776038, 0.13909475732361898], [0.03519284691719804, 0.03699565721035469, 0.05700283421901986, 0.005741585609939648, 0.028245706416782923, 0.0555671272741165, 0.05019997464842163, 0.10690034658182412, 0.03218783160264138, 0.03251348600315396, 0.02521503876778297, 0.03583514233469032, 0.032339122117264196, 0.06807548459619284, 2.6571684423834085, 39.79683771729469, 50.37079632282257, 43.9934541285038, 28.57343316078186, 18.47430657595396, 24.178968966007233, 33.49182464182377, 42.42668800055981, 47.660964131355286, 2.680834997445345, 0.13117231603246182, 0.12765581253916025, 1.0173808014951646, 5.894519677385688, 7.290208535268903, 8.946195300668478, 6.102119637653232, 25.531061813235283, 44.34166744351387, 52.97688648104668, 54.51264247298241, 56.734797433018684, 51.498856991529465, 49.4790867716074, 48.4600954502821, 49.89601559937, 49.25448462367058, 47.883609384298325, 45.11120215058327, 40.47619566321373, 39.840668365359306, 44.503527358174324, 47.428386211395264, 50.314996317029, 48.33457298576832, 53.26761268079281, 51.11290030181408, 48.63310396671295, 47.200056463479996, 53.81132930517197, 50.784107744693756, 53.72108414769173, 51.33624091744423, 51.41824811697006, 46.770010739564896, 47.7961190789938, 49.394104331731796, 54.18195761740208, 49.64403212070465, 52.18480758368969, 44.35127712786198, 37.464036494493484, 36.85488738119602, 40.82710303366184, 37.63468913733959, 37.66274303197861, 35.955730229616165, 38.307424038648605, 37.90954738855362, 36.990969479084015, 38.88665735721588, 39.73404608666897, 39.61783692240715, 42.969530671834946, 40.73812700808048, 44.5920854061842, 43.55580501258373, 47.69580066204071, 44.91976082324982, 51.12005531787872, 49.45406511425972, 58.03894065320492, 30.74244037270546, 34.081066623330116, 52.34116159379482, 47.74665713310242, 51.04063957929611, 46.57408185303211, 45.29447391629219, 46.93176046013832, 46.83207280933857, 43.960977271199226, 46.40446275472641, 46.5837637335062, 47.00910151004791, 52.494984939694405, 54.142150953412056, 49.888761788606644, 52.12364986538887, 40.16042500734329, 36.19636371731758, 38.84082041680813, 39.59231749176979, 38.64496372640133, 37.73745462298393, 45.41395090520382, 53.13540257513523, 53.123923391103745, 44.620511680841446, 52.96024717390537, 52.3330832272768, 52.27496914565563, 53.40787075459957, 51.00199185311794, 47.222798243165016, 44.38129171729088, 49.88283030688763, 52.51866526901722, 51.09066769480705, 50.61038486659527, 46.70029208064079, 40.87442569434643, 42.10021331906319, 49.65602807700634, 53.14998999238014, 53.42180460691452, 54.00106072425842, 54.05524201691151, 49.08865012228489, 41.08384385704994, 40.48891358077526, 42.26441390812397, 44.522359147667885, 47.72602044045925, 54.79532450437546, 55.61567008495331, 59.29328754544258, 57.241333052515984, 54.865639731287956, 58.4499341994524, 44.37162883579731, 2.3529287427663803, 0.8638971217442304, 15.263971891254187, 3.531213216483593, 0.10660771033144556, 1.2520792451687157, 36.97473295032978, 47.0706620067358, 44.77290250360966, 24.96566355228424, 24.69730105251074, 32.436302080750465, 48.26899990439415, 47.1129347383976, 32.66276992857456, 4.068125830963254, 0.1764483709121123, 0.10811386935529299, 0.05632453721773345, 0.09959993636584841, 0.036874442230327986, 0.04766391502926126, 0.025406507302250247, 0.019408805601415224, 0.11339441334712319, 0.02952402053779224, 0.06468242252594791, 0.06425940577173606, 0.042232800406054594, 0.051146981058991514, 0.05927609192440286, 0.04291741679480765, 0.01763151776685845, 0.028681371222774033, 0.017462324794905726, 0.10829534672666341, 0.00567514066460717, 0.12495665112510324, 0.029697158024646342, 0.05736954422900453, 0.030287430745374877, 0.03658738321973942, 0.01640216498344671, 0.09968391779693775, 3.781540459021926, 51.80828958749771, 56.58668138086796, 49.09579373896122, 35.50923898816109, 23.344024568796158, 24.685694575309753, 34.80015903711319, 47.338194251060486, 51.608910486102104, 2.5347974337637424, 0.1045173178135883, 0.4573869192972779, 3.2949908170849085, 5.362200541421771, 8.823731672018766, 5.042588766664267, 6.1860457342118025, 24.730135090649128, 47.40785211324692, 54.05264675617218, 56.132981926202774, 57.6002161949873, 54.68783587217331, 51.00981183350086, 48.69323194026947, 52.86709137260914, 50.99247716367245, 51.35014057159424, 45.59426262974739, 42.09137499332428, 41.746896877884865, 45.353902727365494, 49.636120945215225, 52.94827401638031, 50.53425595164299, 54.532131627202034, 54.59972620010376, 47.62741573154926, 48.54644201695919, 53.58636237680912, 53.31405758857727, 54.42048601806164, 52.38612838089466, 54.07364822924137, 47.779677361249924, 49.7841078042984, 51.068777069449425, 55.62799282371998, 52.48614281415939, 53.55051510035992, 46.76526479423046, 40.21579183638096, 39.02781218290329, 42.755142375826836, 39.768274649977684, 39.805869832634926, 38.608645275235176, 41.13378457725048, 39.58456590771675, 39.16740149259567, 41.60100370645523, 42.8133400529623, 41.40247195959091, 45.04984684288502, 42.31977313756943, 48.12570579349995, 46.70051246881485, 51.3525116443634, 47.10769861936569, 52.51917824149132, 50.379410460591316, 58.91214519739151, 31.213419400155544, 36.19728326797485, 53.44101257622242, 49.7509203851223, 51.72628238797188, 47.65939101576805, 45.823291540145874, 47.852344661951065, 46.50259628891945, 45.534058660268784, 47.790757566690445, 47.53930225968361, 49.57299493253231, 54.077071845531464, 54.21828746795654, 52.178750708699226, 53.858002200722694, 42.004899233579636, 38.73803213238716, 40.681061670184135, 41.41906566917896, 39.07608859241009, 38.78736488521099, 47.72935286164284, 55.899188071489334, 53.515328988432884, 46.2450385093689, 54.96168337762356, 53.968648463487625, 55.26528708636761, 54.330400452017784, 52.567249462008476, 47.760469391942024, 45.91742768883705, 50.975693464279175, 56.277594566345215, 52.719929069280624, 51.72823168337345, 48.810691237449646, 43.5105836391449, 43.8714312762022, 52.54683315753937, 54.846652150154114, 56.081274300813675, 55.794537886977196, 55.93315824866295, 51.25559024512768, 42.84064918756485, 42.42387995123863, 44.30513620376587, 46.00360706448555, 48.90087179839611, 54.85944226384163, 58.05005885660648, 60.38318686187267, 59.981825798749924, 56.81136332452297, 59.417263492941856, 45.383453741669655, 3.5316430684179068, 1.4993792376480997, 13.752351254224777, 6.9461246486753225, 0.13614083145512268, 1.5999088995158672, 39.4640401750803, 51.47160105407238, 49.396615996956825, 27.93070524930954, 31.15381769835949, 38.12078185379505, 53.17851886153221, 55.419038236141205, 41.87629893422127, 5.367601001635194, 0.11548123613465577, 0.05206721820286475, 0.02662062008312205, 0.04975599964382127, 0.0051529646316339495, 0.02146146733139176, 0.04434693051734939, 0.05042019583925139, 0.06969272828428075, 0.048646058421581984, 0.10444512910908088, 0.073666194366524, 0.022723413385392632, 0.005607505963780568, 0.2205855111242272, 0.11308288943837397, 0.10319459543097764, 0.13778293709037825, 0.13141505769453943, 0.1874763736850582, 0.10479344869963825, 0.36046201712451875, 0.1059109227207955, 0.21619788953103125, 0.13777205720543861, 0.11416577937779948, 0.0676963065052405, 0.17692445864668116, 6.088461270555854, 63.55863846838474, 64.96306970715523, 57.19765439629555, 38.8420819491148, 28.15331630408764, 34.53306756913662, 49.13938879966736, 53.80708113312721, 57.594383507966995, 3.1142836762592196, 0.2215054476982914, 0.4313034861115739, 5.5444240383803844, 16.49719286710024, 19.499852545559406, 18.568832203745842, 12.025761902332306, 31.097516119480133, 49.40288566052914, 55.68888835608959, 57.44795836508274, 61.03350296616554, 55.509173199534416, 53.679286390542984, 51.867889389395714, 55.26284001767635, 53.01083765923977, 52.77371898293495, 48.32973964512348, 44.59648557007313, 44.86147195100784, 49.36395674943924, 50.74345372617245, 55.62529496848583, 51.95433095097542, 57.35184632241726, 55.45261323451996, 48.59555438160896, 48.15205737948418, 57.06970766186714, 55.68782061338425, 57.12853230535984, 54.588266015052795, 57.81653858721256, 50.87537884712219, 52.21941612660885, 53.82210932672024, 58.37029427289963, 52.28807084262371, 55.38565322756767, 48.2570381462574, 42.251255214214325, 40.24633079767227, 45.07191605865955, 41.55774302780628, 41.553175672888756, 41.10327981412411, 42.59662248194218, 42.828322649002075, 41.29174590110779, 42.44335390627384, 45.24968571960926, 44.65927340090275, 48.22291597723961, 45.85773289203644, 51.24075964093208, 48.816048949956894, 53.91376420855522, 50.66245727241039, 57.18235641717911, 53.2603170722723, 59.97790440917015, 35.400443226099014, 37.3371385037899, 53.30269619822502, 51.556275710463524, 52.52189889550209, 50.11380851268768, 47.74414926767349, 49.63402345776558, 46.75487235188484, 46.10621675848961, 48.820019736886024, 48.260883539915085, 50.65515786409378, 54.91266220808029, 52.631055638194084, 53.61276336014271, 57.82722361385822, 44.97790530323982, 40.59301279485226, 43.12486253678799, 42.653456032276154, 42.24746681749821, 40.71744091808796, 50.59628002345562, 58.46007965505123, 58.5352548211813, 47.974044531583786, 55.91212257742882, 57.20257133245468, 58.50716292858124, 58.20309564471245, 55.813685059547424, 49.5160473883152, 46.17466628551483, 51.10832154750824, 57.324077412486076, 57.1133179217577, 53.55674296617508, 51.85152366757393, 44.9916909635067, 45.71074537932873, 56.14431291818619, 58.671469911932945, 57.51623310148716, 58.16509008407593, 59.33564007282257, 53.745368644595146, 46.46767236292362, 44.87997315824032, 46.82970553636551, 49.064437821507454, 51.5691190212965, 59.43321883678436, 60.4098804295063, 63.61467406153679, 61.34367652237415, 58.90401363372803, 60.410560593008995, 49.316934272646904, 3.7260306626558304, 2.9732124460861087, 25.337787084281445, 6.221465058624744, 0.13069501117570326, 1.7576619470492005, 48.19668598473072, 58.81058044731617, 58.674144968390465, 35.63224978744984, 35.886357352137566, 44.56461288034916, 60.615362003445625, 62.17695660889149, 52.45174705982208, 8.259636741131544, 0.3316733072279021, 0.1616283942712471, 0.15627887507434934, 0.14096119935857132, 0.061534246924566105, 0.07904813799541444, 0.25512320862617344, 0.1045809940842446, 0.23428705637343228, 0.21633567666867748, 0.1284905505599454, 0.17516338673885912, 0.1212938480603043, 0.08358784791198559], [0.050112627577618696, 0.041327799553982913, 0.03162737652019132, 0.03298566633020528, 0.020721035871247295, 0.017930133872141596, 0.013245377685962012, 0.047138767622527666, 0.06504349963506684, 0.00987155022812658, 0.010748945041996194, 0.02988355769048212, 0.027200816293770913, 0.097646484937286, 3.9757473254576325, 43.66041719913483, 49.00315470993519, 46.2898875027895, 32.286552116274834, 15.474224109202623, 32.42739915847778, 36.293524503707886, 44.9946928024292, 39.69897396862507, 0.3800208738539368, 0.036754759785253555, 0.48080224252771586, 3.5080722207203507, 4.72517897374928, 5.512535674497485, 3.2177996216341853, 10.975351966917515, 33.81254643201828, 49.92904722690582, 59.77155648171902, 56.41119919717312, 57.84486226737499, 53.34910690784454, 52.28328689932823, 46.13291412591934, 44.27187658846378, 41.25414311885834, 39.63602654635906, 38.96734222769737, 42.721020206809044, 46.86508163809776, 51.72151364386082, 51.92928649485111, 53.19354705512524, 53.44636648893356, 54.08599756658077, 53.47520314157009, 48.58760140836239, 49.93569687008858, 53.05872268974781, 52.73993119597435, 51.15690194070339, 48.25321555137634, 49.31793361902237, 42.52317622303963, 47.01441362500191, 48.893819376826286, 52.33962647616863, 51.007429361343384, 50.14712132513523, 39.02431637048721, 37.14965656399727, 37.443396002054214, 38.67399036884308, 37.863786444067955, 39.20485608279705, 37.02952980995178, 39.39632400870323, 37.015383169054985, 37.08139322698116, 37.81795330345631, 37.73642107844353, 39.90057975053787, 40.48666790127754, 41.1078167706728, 42.74755418300629, 41.60710237920284, 46.64819307625294, 45.68444699048996, 51.56918741762638, 48.64581048488617, 57.7970190346241, 34.6450437605381, 32.46226988732815, 50.08448928594589, 42.246915847063065, 47.66398496925831, 46.52465030550957, 55.135372057557106, 48.05948294699192, 51.66639760136604, 51.992720291018486, 52.40445099771023, 51.36582612991333, 52.127829641103745, 44.86969850957394, 54.53984521329403, 54.655735194683075, 50.20187258720398, 47.480774000287056, 37.43673115968704, 39.39585663378239, 39.273092821240425, 36.58939562737942, 37.93635115027428, 47.59307697415352, 49.795697182416916, 42.707215547561646, 51.338509395718575, 52.96425595879555, 49.20420952141285, 48.397847190499306, 49.606406539678574, 51.932299733161926, 49.089307487010956, 45.18081821501255, 52.06559278070927, 51.20323285460472, 50.87416671216488, 48.11853937804699, 44.43976677954197, 43.31190750002861, 48.338566571474075, 52.0589355379343, 51.86622127890587, 51.867881789803505, 52.590606808662415, 54.85321819782257, 49.61893826723099, 46.752584874629974, 43.757916167378426, 46.00372865796089, 50.856687650084496, 54.63301241397858, 57.58864961564541, 56.17491267621517, 59.895175248384476, 55.59389725327492, 52.477004304528236, 40.625915229320526, 46.53614088892937, 6.152993682771921, 0.19211147184250876, 15.476084109395742, 19.489486701786518, 1.6983607853762805, 0.13688464154256508, 30.119030624628067, 45.67694999277592, 41.27441503107548, 30.324610993266106, 17.749254181981087, 31.75751980394125, 44.02623496949673, 50.34785695374012, 43.71764972805977, 6.63436752744019, 0.2770529006375, 0.07395952823571861, 0.014131450989225414, 0.04051596792123746, 0.05454196158098057, 0.040815350293996744, 0.09238318103598431, 0.06406616535969079, 0.04428151391039137, 0.1245527298306115, 0.05092020299343858, 0.04893844234175049, 0.10045092742075212, 0.0629041031061206, 0.007461240111297229, 0.004915155004709959, 0.017456261448387522, 0.039595593480044045, 0.09437891261768527, 0.025444802122365218, 0.06227764883078635, 0.034049683454213664, 0.0265192445658613, 0.010747617525339592, 0.06467080791480839, 0.010079235617013182, 0.018669914097699802, 0.14220137265510857, 6.706970231607556, 53.95699828863144, 56.678484454751015, 52.20764435827732, 39.09828320145607, 21.44500806927681, 29.612337313592434, 36.08346037566662, 51.83013081550598, 42.24151253700256, 0.42798792652320117, 0.1967064940254204, 0.6414776598103344, 5.040184445679188, 9.868906438350677, 9.65022437274456, 5.85532620549202, 11.531426478177309, 31.222352720797062, 51.3343296200037, 58.90481539070606, 57.60154612362385, 58.177291229367256, 56.12291246652603, 53.00956852734089, 47.65528343617916, 46.82250492274761, 43.36754411458969, 42.44184158742428, 40.8743155002594, 43.4587050229311, 49.08836133778095, 54.205314964056015, 53.88987109065056, 54.44169268012047, 54.71831403672695, 54.08830024302006, 54.011472165584564, 48.766974583268166, 51.797779351472855, 54.44019936025143, 52.45241202414036, 51.573743373155594, 52.20593065023422, 50.37021115422249, 44.269733503460884, 48.13862890005112, 50.232723131775856, 54.61723946034908, 53.82343925535679, 52.8902967274189, 40.96851624548435, 40.24090848863125, 40.104096829891205, 40.44207349419594, 40.36827005445957, 40.18148347735405, 39.02338922023773, 39.42325696349144, 38.77889133989811, 39.48392830789089, 39.13750469684601, 39.678295478224754, 42.154330015182495, 42.60076805949211, 42.63732209801674, 46.500544399023056, 44.712592139840126, 48.60884986817837, 47.546708062291145, 53.23837324976921, 48.822147622704506, 58.7472340464592, 36.2147319316864, 34.43269595503807, 50.00087857246399, 42.85856142640114, 48.032002821564674, 48.12431886792183, 54.482988864183426, 49.26577381789684, 52.86136507987976, 53.19282129406929, 52.8134610503912, 52.8695422410965, 52.1695514023304, 48.50521042943001, 57.2927974909544, 53.709110990166664, 53.66052679717541, 48.65624852478504, 39.548467844724655, 39.037395268678665, 41.35948866605759, 38.69842305779457, 40.0336068123579, 48.464081436395645, 52.123482674360275, 46.704384461045265, 52.59780362248421, 54.49604116380215, 52.29360714554787, 49.29140344262123, 49.18606549501419, 53.89858402311802, 51.19092531502247, 46.31382241845131, 52.93810576200485, 51.96453720331192, 52.27235488593578, 50.76412081718445, 45.28708331286907, 44.1954854875803, 49.10239778459072, 54.32100735604763, 54.4912876188755, 53.36798049509525, 53.3211138099432, 55.10366275906563, 51.08032464981079, 48.318268060684204, 46.88289128243923, 48.11472438275814, 53.11977781355381, 58.83885093033314, 59.5186610519886, 58.687976226210594, 61.53756871819496, 54.619933515787125, 52.81790301203728, 39.59671765565872, 49.71506930887699, 5.69889334961772, 1.319666812196374, 7.279499284923077, 16.490383632481098, 2.9052098700776696, 0.17157789319753647, 34.09538805484772, 52.543648928403854, 47.71820046007633, 30.52358351647854, 18.866162449121475, 35.613794177770615, 50.04010006785393, 54.67052400112152, 52.77132511138916, 11.174852661788464, 0.24835513351717964, 0.07598398835398257, 0.03051581370527856, 0.026299585551896598, 0.0833693819004111, 0.049191240104846656, 0.0368335832899902, 0.05612144850601908, 0.05742310873756651, 0.011979928694927366, 0.08723234961507842, 0.08547901088604704, 0.064636943716323, 0.05076883084257133, 0.08622576729976572, 0.06875738472444937, 0.18319078255444765, 0.13352458277950063, 0.1625927706481889, 0.088845504069468, 0.12485476909205317, 0.0926387395884376, 0.20093732950044796, 0.11260861996561289, 0.11429112812038511, 0.14497347234282643, 0.1395124231930822, 0.23550006706500426, 9.897868484258652, 64.71927478909492, 62.646865993738174, 58.27676609158516, 43.57745625078678, 25.710509084165096, 42.13973119854927, 48.140042424201965, 55.819601342082024, 47.22727060317993, 0.5899319413583726, 0.2745473210234195, 1.0828833491541445, 11.617979183793068, 9.206604827195406, 11.98920976370573, 11.167891435325146, 16.859106346964836, 35.430336222052574, 50.68483047187328, 60.17197899520397, 57.93088585138321, 60.85712783038616, 58.94547700881958, 55.178256556391716, 49.96609143912792, 49.81003001332283, 45.36070056259632, 43.72105814516544, 42.44790606200695, 45.734152123332024, 52.27836616337299, 56.1688482016325, 56.384399235248566, 57.45129078626633, 58.49739745259285, 56.88053481280804, 53.4549730271101, 48.131492882966995, 53.195758536458015, 57.4318016320467, 57.126393020153046, 54.61884297430515, 54.21058528125286, 53.80334593355656, 45.528366565704346, 51.81011348962784, 53.69443237781525, 56.941905319690704, 55.798884853720665, 55.66854804754257, 43.498412892222404, 41.79367236793041, 40.00193931162357, 42.88345389068127, 42.17385336756706, 42.266150414943695, 40.594897493720055, 42.26619981229305, 41.86555691063404, 40.977814346551895, 43.682205229997635, 41.311774626374245, 46.28387622535229, 45.311987176537514, 45.96491374075413, 48.76025274395943, 46.497474163770676, 51.66643939912319, 48.73456232249737, 54.88890588283539, 53.35832521319389, 61.16150289773941, 39.621013551950455, 37.57756680250168, 50.26931516826153, 43.56172889471054, 48.67620885372162, 48.39555971324444, 55.76042711734772, 50.70846900343895, 54.26233850419521, 55.74898973107338, 55.91414786875248, 55.245357155799866, 54.07823458313942, 51.58447399735451, 58.126050978899, 53.88052359223366, 57.060276567935944, 51.25964842736721, 43.30096408724785, 41.80566072463989, 44.04496796429157, 42.00368709862232, 41.45844675600529, 50.43554864823818, 54.022423177957535, 48.76847170293331, 54.03188847005367, 58.62967595458031, 55.144297778606415, 51.55559554696083, 53.60859118402004, 57.27211520075798, 52.741435915231705, 47.380056604743004, 53.80908362567425, 54.12140406668186, 56.9628231972456, 53.69706563651562, 47.881561294198036, 46.99027732014656, 52.772993221879005, 56.802635192871094, 55.60202121734619, 55.7059570401907, 54.509021267294884, 58.746493086218834, 53.5766576975584, 49.80574004352093, 48.60678277909756, 51.23361982405186, 55.440279096364975, 58.89102213084698, 62.14541830122471, 62.508986592292786, 63.69206830859184, 55.73675438761711, 54.41054955124855, 40.721947476267815, 54.74161818623543, 7.786969654262066, 2.55318702198565, 24.411676079034805, 26.008124314248562, 3.198292418383062, 0.17673696245765314, 40.148113667964935, 59.04869467020035, 55.999312698841095, 39.73234377801418, 29.058045856654644, 44.45048600435257, 58.665895611047745, 63.41838039457798, 61.362424716353416, 14.79327879846096, 0.3843985655112192, 0.1798560013412498, 0.17691675515379757, 0.11827819034806453, 0.146395189804025, 0.17355856660287827, 0.19404978345846757, 0.13904587947763503, 0.10884348215768114, 0.17724086588714272, 0.13952171488199383, 0.1195917249424383, 0.13930071814684197, 0.11289548972854391], [0.03992659134382848, 0.0113307034735044, 0.037246863066684455, 0.06854550156276673, 0.04417170202941634, 0.006649643182754517, 0.05228836336755194, 0.009536531779303914, 0.00604313041549176, 0.11441300361184403, 0.04599251311447006, 0.07848412060411647, 0.056641170813236386, 0.07182555680628866, 9.647786803543568, 48.6746509373188, 50.85269406437874, 44.26272287964821, 24.94464498013258, 12.408510614186525, 34.62759889662266, 32.2375613451004, 51.40401408076286, 28.28638706356287, 0.09072275177459233, 0.05012941866880283, 0.7689094624947757, 3.476725327782333, 3.306349120102823, 8.794319350272417, 1.1853064969182014, 16.80908203125, 56.32715530693531, 62.88204677402973, 57.05171562731266, 55.85741691291332, 58.240892216563225, 55.38388632237911, 53.64185079932213, 52.505943551659584, 44.40715692937374, 44.75517265498638, 42.140240371227264, 39.513764306902885, 42.272701263427734, 49.70151923596859, 52.737423330545425, 54.20029543340206, 52.94931896030903, 52.29868747293949, 49.48901183903217, 52.05002881586552, 48.09390909969807, 52.60959059000015, 48.936384692788124, 48.18182498216629, 44.68560218811035, 41.22037433087826, 44.16104793548584, 41.413381174206734, 40.68255499005318, 44.21229958534241, 46.82151697576046, 46.78495913743973, 39.98468063771725, 36.61888964474201, 37.662819027900696, 37.02952601015568, 40.870135724544525, 40.42080603539944, 39.390529319643974, 37.03208327293396, 36.44145056605339, 37.1411108225584, 39.67990659177303, 37.15024933218956, 40.87583541870117, 37.76290185749531, 38.75447764992714, 37.56933644413948, 37.82106913626194, 38.050424829125404, 45.05984030663967, 42.02375762164593, 47.959080934524536, 46.05602905154228, 56.41925096511841, 33.976610228419304, 31.479488722980022, 48.37403766810894, 45.061576813459396, 53.67816165089607, 49.642793387174606, 52.53134898841381, 49.38317611813545, 50.09000279009342, 51.14000804722309, 52.2547048330307, 48.03292237222195, 51.65348969399929, 52.16565661132336, 43.85861836373806, 54.38039056956768, 54.37713794410229, 50.9444135427475, 39.81959469616413, 38.103564977645874, 37.926369085907936, 37.28996403515339, 36.314875558018684, 46.77711635828018, 52.80143469572067, 50.30995398759842, 54.1629434376955, 49.32700373232365, 46.877423375844955, 43.00535514950752, 47.15702377259731, 53.49295198917389, 52.60377690196037, 48.244274631142616, 53.02239663898945, 52.76957340538502, 48.37877221405506, 43.31197589635849, 43.51274572312832, 48.66394691169262, 52.65717923641205, 53.72619867324829, 51.57678700983524, 45.82028970122337, 51.27822943031788, 53.45040567219257, 50.672956109046936, 46.8438483774662, 50.16233570873737, 54.4854511320591, 54.90420766174793, 52.792337983846664, 52.425114288926125, 57.85786136984825, 54.189150631427765, 53.44420060515404, 53.782146871089935, 30.428989492356777, 24.111739173531532, 6.7143565602600574, 2.5089759193360806, 7.833044081926346, 21.052261143922806, 4.346168311312795, 0.08822194417007267, 17.459821812808514, 43.974884524941444, 42.0155044645071, 31.217739768326283, 25.960079692304134, 35.517176762223244, 44.53495927155018, 45.05230911076069, 49.748978689312935, 14.033310078084469, 0.15311931492760777, 0.06074479846574832, 0.027187808300368488, 0.02952870163426269, 0.11921178986085579, 0.061751002285745926, 0.061059046056470834, 0.03007477575010853, 0.11973138229222968, 0.023453571666323114, 0.00358908298494498, 0.036234966974006966, 0.03461455060460139, 0.042913520519505255, 0.03655187145341188, 0.010359150528529426, 0.05299036456563044, 0.03146072354866192, 0.02769510705547873, 0.016396949540649075, 0.05382287985412404, 0.03308642400952522, 0.03402970854949672, 0.09370308325742371, 0.0713222693593707, 0.059254773732391186, 0.14866055105812848, 0.07508189301006496, 14.203913323581219, 59.0315879881382, 57.673901841044426, 49.310307428240776, 30.187143869698048, 15.575876254588366, 29.88191954791546, 37.16671384871006, 53.60044822096825, 31.905101984739304, 0.024776310747256503, 0.05116032116347924, 0.8260982343927026, 4.550894200801849, 6.980244917795062, 13.129209391772747, 4.649484660476446, 16.568843722343445, 57.313168197870255, 64.17024984955788, 58.54398675262928, 59.00250434875488, 59.20467250049114, 56.24528490006924, 55.84458880126476, 55.64349979162216, 46.96239821612835, 44.74319949746132, 43.50017599761486, 42.42922246456146, 45.334094390273094, 50.9212613850832, 55.15426844358444, 55.49944192171097, 54.357044622302055, 53.04847463965416, 50.486093536019325, 54.481385350227356, 48.48466493189335, 53.837566897273064, 49.85327169299126, 50.53827613592148, 46.23788729310036, 44.51646186411381, 46.22733525931835, 42.13618218898773, 42.42950364947319, 46.728661358356476, 50.68259999155998, 48.80054958164692, 42.1945508569479, 37.83408723771572, 39.51923221349716, 38.341227024793625, 42.596569284796715, 40.927014872431755, 42.61075772345066, 39.620439782738686, 39.24638785421848, 37.6491017639637, 41.16590045392513, 38.9546737074852, 43.446610271930695, 39.82632793486118, 40.91310381889343, 39.2998281866312, 41.98499210178852, 39.176160022616386, 46.4130312949419, 43.99951100349426, 50.44656045734882, 49.01016153395176, 57.91835032403469, 37.610123455524445, 31.581680439412594, 48.61032038927078, 44.9707692861557, 55.25992177426815, 52.73163244128227, 54.482156708836555, 51.94144584238529, 51.725963205099106, 51.90724387764931, 53.60400103032589, 50.16142375767231, 54.84947919845581, 51.50759272277355, 48.993222042918205, 55.19202321767807, 55.83910949528217, 51.646220684051514, 42.16593459248543, 38.98212343454361, 39.89407069981098, 38.51137429475784, 39.602569341659546, 48.93208332359791, 54.26401041448116, 51.48670144379139, 56.4839006960392, 51.54572747647762, 48.44051890075207, 45.29766574501991, 49.75523315370083, 54.014010429382324, 53.71045231819153, 49.39048312604427, 52.72996813058853, 55.86302161216736, 50.73668248951435, 45.04089072346687, 45.4484948515892, 49.05246086418629, 56.84940688312054, 54.38607506453991, 53.72902952134609, 46.184625551104546, 52.3752723634243, 53.97450774908066, 51.727179139852524, 48.380911499261856, 53.26133921742439, 55.8925574272871, 56.015211045742035, 53.14613699913025, 55.23749157786369, 58.255745619535446, 55.12052245438099, 52.08410918712616, 56.755677312612534, 28.56653843075037, 25.156531110405922, 6.872079446911812, 2.8246931405737996, 9.022813439369202, 22.412789538502693, 7.501427326351404, 0.07480370637495071, 20.11572539806366, 48.19590322673321, 45.46106077730656, 32.7837136387825, 33.68859328329563, 42.15291269123554, 51.916313990950584, 49.80230122804642, 58.432162553071976, 17.009760662913322, 0.19470230938168243, 0.046647948256577365, 0.09098072230699472, 0.028637673567573074, 0.008315774921356933, 0.06979829136980698, 0.08549849226255901, 0.05241265826043673, 0.027471830071590375, 0.03579472497222014, 0.046580368289141916, 0.032367546373279765, 0.10611549572786316, 0.06430115157854743, 0.1743644499219954, 0.08906601840863004, 0.1919913329766132, 0.1884047410567291, 0.093019186751917, 0.0859303554170765, 0.19211917533539236, 0.22051666950574145, 0.12941948196385056, 0.269624714856036, 0.1985260026413016, 0.22362257237546146, 0.24684403178980574, 0.17936474410817027, 20.62884796410799, 68.4746664762497, 64.18764531612396, 59.6897354722023, 34.890297800302505, 19.253304675221443, 47.174407839775085, 46.29585698246956, 60.566595420241356, 35.095467790961266, 0.27649341034702957, 0.11859110207296908, 3.014225782826543, 7.003939496353269, 9.674533568322659, 22.663389891386032, 4.176375372335315, 18.650795705616474, 58.86619046330452, 66.55131608247757, 60.393503308296204, 61.91684536635876, 61.57262183725834, 59.38168600201607, 57.0067298412323, 56.883080676198006, 48.248765990138054, 48.0815065652132, 46.30181506276131, 43.647399097681046, 45.39739519357681, 54.09423552453518, 57.30129763484001, 58.86858053505421, 56.270785331726074, 54.88269701600075, 50.523627921938896, 56.10311932861805, 48.230492770671844, 55.86282782256603, 52.52840794622898, 53.59973385930061, 48.86842153966427, 45.64381577074528, 48.95826391875744, 43.88144373893738, 44.500381126999855, 48.89419935643673, 51.54268763959408, 52.10193023085594, 44.726560190320015, 39.64597821235657, 40.59333957731724, 40.32664328813553, 44.24418367445469, 44.44626443088055, 44.37922082841396, 42.155770137906075, 41.55713886022568, 39.43469054996967, 43.68138447403908, 41.02602995932102, 46.02513670921326, 42.74080574512482, 43.135152384638786, 41.71843260526657, 44.18046109378338, 43.25355403125286, 49.40985828638077, 46.938014924526215, 51.99512176215649, 51.232373490929604, 58.79722036421299, 39.569169133901596, 33.92608813941479, 48.945492804050446, 46.93501688539982, 57.467728704214096, 54.09613162279129, 58.26515011489391, 52.78283089399338, 53.35063062608242, 54.17564235627651, 56.645418629050255, 51.87043905258179, 56.407783180475235, 53.13093401491642, 52.33177989721298, 57.65574261546135, 58.78861002624035, 55.50186239182949, 43.932824581861496, 42.32863426208496, 40.887261405587196, 41.35137230157852, 41.118334606289864, 50.69536350667477, 56.247830763459206, 53.13719987869263, 56.913718432188034, 56.00816622376442, 51.52171276509762, 47.98111595213413, 51.490265652537346, 56.61305956542492, 54.6153661608696, 50.66744640469551, 54.6196523308754, 58.66694055497646, 53.11869107186794, 48.37466463446617, 48.59310731291771, 52.795947790145874, 59.20783773064613, 57.7724951505661, 55.80281004309654, 47.12387815117836, 53.89519080519676, 56.74054652452469, 53.755023926496506, 53.028240725398064, 55.90342104434967, 60.2690713852644, 59.611258283257484, 56.53795659542084, 55.51129728555679, 59.761221036314964, 55.722660943865776, 53.29559437930584, 59.35071386396885, 31.643020547926426, 27.77042794972658, 11.583388689905405, 5.207640985026956, 15.285775121301413, 24.4195169582963, 5.401693722233176, 0.07933472574222833, 22.20376655459404, 56.40168450772762, 53.63363564014435, 42.48399272561073, 37.95042559504509, 44.959255903959274, 59.81036759912968, 56.008565202355385, 67.25035697221756, 21.670712158083916, 0.4365356866037473, 0.1299000671133399, 0.19190153310773894, 0.18486621062038466, 0.19727220351342112, 0.14706831774674356, 0.2021245431387797, 0.19755776709644124, 0.27395974786486477, 0.14753545518033206, 0.1587456848938018, 0.1253495886339806, 0.18348854704527184, 0.12674245139351115], [0.029164320112613495, 0.09235454897861928, 0.06723324346239679, 0.052371535857673734, 0.03271307548857294, 0.04197651825961657, 0.04376998491352424, 0.039013063214952126, 0.032836743266670965, 0.05264971136057284, 0.05230980401393026, 0.006266198206503759, 0.004504667558649089, 0.13627051434013993, 15.794417727738619, 49.00560177862644, 47.002330273389816, 38.91046687960625, 20.605148635804653, 18.261696584522724, 30.641753375530243, 31.770925484597683, 56.858974769711494, 19.200139828026295, 0.11464142924523912, 0.04692992726631928, 0.6276104820426553, 4.7097779251635075, 12.227335385978222, 9.948681257665157, 9.312558341771364, 43.74774791300297, 58.48069354891777, 55.325551852583885, 56.39710195362568, 54.39282350242138, 56.170440316200256, 55.79529784619808, 55.993909388780594, 53.84037494659424, 46.66215732693672, 40.6222066283226, 38.07926908135414, 37.55630314350128, 40.08311055600643, 50.626298412680626, 53.119439631700516, 54.34668257832527, 53.161526173353195, 53.69946330785751, 50.70324428379536, 48.304668590426445, 48.138868287205696, 51.5082348883152, 50.494247898459435, 47.804820612072945, 46.28801420331001, 40.908680856227875, 38.79437930881977, 38.21275971829891, 40.56470811367035, 40.19649267196655, 40.29776483774185, 38.699566796422005, 39.2551501840353, 38.01823675632477, 38.0370457470417, 36.66365884244442, 40.05224101245403, 38.18746827542782, 39.8399768024683, 38.01048897206783, 37.36782565712929, 37.827684581279755, 38.14652547240257, 39.3427012860775, 41.085500568151474, 37.79846414923668, 40.52477225661278, 37.565000876784325, 41.28417290747166, 38.58309164643288, 43.14294956624508, 40.3595495223999, 47.665569484233856, 46.82176016271114, 57.54784360527992, 36.419271156191826, 32.868661880493164, 54.559254571795464, 49.01037812232971, 53.76639671623707, 49.375846311450005, 53.11023652553558, 49.69825521111488, 49.641702845692635, 49.06985253095627, 48.57752814888954, 49.80644680559635, 50.26459962129593, 55.22775650024414, 48.236925825476646, 46.70295573771, 52.91748046875, 49.00071904063225, 43.286828845739365, 36.42080247402191, 38.14626708626747, 36.86885163187981, 37.46026709675789, 40.10862998664379, 53.43589045107365, 51.910963878035545, 53.30860488116741, 47.533484771847725, 41.148546785116196, 42.24708303809166, 48.875656351447105, 52.672397419810295, 51.50788150727749, 48.47170002758503, 51.134239956736565, 49.76412087678909, 47.910500541329384, 43.64198058843613, 48.611376732587814, 49.39723156392574, 53.74440349638462, 51.632647812366486, 50.69979406893253, 47.56918765604496, 50.862611532211304, 52.983615919947624, 55.4936396330595, 50.48046983778477, 52.36170329153538, 52.63101004064083, 55.98399192094803, 56.173449754714966, 52.17096492648125, 48.81021246314049, 56.75124295055866, 56.17234021425247, 53.11113327741623, 34.96325768530369, 32.2306153178215, 8.347539324313402, 1.356779420748353, 5.722138127312064, 3.8873628806322813, 2.2351405257359147, 0.1431166782276705, 11.038264241069555, 39.08797435462475, 39.336256831884384, 36.503805220127106, 12.837128564715385, 21.489689871668816, 37.65739291906357, 46.49847351014614, 53.488308638334274, 15.224064532667398, 0.36910364404320717, 0.08488238352583721, 0.05747144481574651, 0.05297283503750805, 0.07774295256240293, 0.04483829536184203, 0.013498693097062642, 0.034904867643490434, 0.03939293892472051, 0.04128952328755986, 0.05929716891841963, 0.020483097760006785, 0.06408999572158791, 0.07999472509254701, 0.04166509454080369, 0.024143837654264644, 0.05490391071361955, 0.03944615091313608, 0.07166603216319345, 0.03549644097802229, 0.04221223178319633, 0.03072137747949455, 0.03636019697296433, 0.043248154906905256, 0.08612669058493339, 0.006027710442140233, 0.04139006574405357, 0.2198071763268672, 22.534800991415977, 59.523973166942596, 51.168274730443954, 46.84156849980354, 27.316236421465874, 20.92572793364525, 35.85051387548447, 36.75262726843357, 58.054485619068146, 22.863517552614212, 0.21504209842532873, 0.05535650205274578, 1.7740470240823925, 6.299809729680419, 10.191019903868437, 12.61504378169775, 7.475888421759009, 40.41703283786774, 63.8004232943058, 55.56526958942413, 58.51708799600601, 56.2248419970274, 58.15650254487991, 57.731020376086235, 59.10300515592098, 55.67589685320854, 48.74414920806885, 44.37587320804596, 41.38514868915081, 40.15660621225834, 42.55718819797039, 51.82692378759384, 55.382165014743805, 56.42298236489296, 54.57602687180042, 55.9526702016592, 53.05993102490902, 50.790024027228355, 48.47902223467827, 52.78574913740158, 50.62642760574818, 49.55870009958744, 48.08512017130852, 42.29823209345341, 40.310596749186516, 40.35216651856899, 41.720853075385094, 42.57791988551617, 43.16225253045559, 41.43012307584286, 41.203332245349884, 39.11887429654598, 40.58606296777725, 37.93977476656437, 40.62213443219662, 40.86687549948692, 41.74277789890766, 39.50930334627628, 39.77510668337345, 39.55135568976402, 40.99986836314201, 41.27438083291054, 42.470222264528275, 40.86444742977619, 42.41500362753868, 38.52380342781544, 42.04363435506821, 40.99307432770729, 45.41886784136295, 44.01441000401974, 49.58041973412037, 48.562815338373184, 58.97443525493145, 38.52052800357342, 33.52332875132561, 55.50010308623314, 48.862357065081596, 55.065003633499146, 50.38761802017689, 54.94368754327297, 51.72879785299301, 51.406347155570984, 51.294921934604645, 52.0306346565485, 51.43406666815281, 52.171751484274864, 55.60876965522766, 50.043888464570045, 49.1741569340229, 54.65055227279663, 51.083877459168434, 44.526896104216576, 38.05872358381748, 39.320350885391235, 39.88934375345707, 38.87267030775547, 41.740775406360626, 55.03242038190365, 55.75307831168175, 53.772670179605484, 49.062097147107124, 43.13946135342121, 43.9233972877264, 50.987339839339256, 53.44823598861694, 53.14061589539051, 48.722117990255356, 53.19315567612648, 52.169232219457626, 50.12263923883438, 46.017632111907005, 49.97031681239605, 51.8978925794363, 54.69282880425453, 53.278381302952766, 50.59852950274944, 47.19706602394581, 51.036003828048706, 54.253671169281006, 56.5212906897068, 53.691172152757645, 54.22433294355869, 55.04038855433464, 58.524482399225235, 56.28889136016369, 53.75832974910736, 48.50513443350792, 57.071219980716705, 55.98921284079552, 57.40780591964722, 40.71060888469219, 34.798243939876556, 10.85388958454132, 0.10514246590901166, 4.845554139465094, 1.3240013108588755, 2.308920929208398, 0.18744832050288096, 12.107474617660046, 44.126013815402985, 48.00746373832226, 45.56235194206238, 18.746206685900688, 26.40483632683754, 45.28261475265026, 52.65553392469883, 59.49496552348137, 20.34151118248701, 0.32872511073946953, 0.07043398538371548, 0.03527867258526385, 0.015363245438493323, 0.09388635662617162, 0.019926579770981334, 0.061302492758841254, 0.10232631975668482, 0.03888688326696865, 0.04764225544931833, 0.027267090081295464, 0.02179063765652245, 0.038085590131231584, 0.050608159581315704, 0.15800717374077067, 0.14541749929776415, 0.24438789405394346, 0.20346607896499336, 0.1711622014408931, 0.11850666793179698, 0.1551400197786279, 0.11600666184676811, 0.1176951294473838, 0.10878658169531263, 0.19777505309320986, 0.095191037398763, 0.11910113564226776, 0.3888687287690118, 31.00091390311718, 69.7775861620903, 57.862949296832085, 53.70738208293915, 28.74547652900219, 28.221142664551735, 44.07868355512619, 43.82104977965355, 66.26310914754868, 24.582349620759487, 0.3277155227260664, 0.24451346544083208, 4.346507443115115, 14.52873034402728, 22.934721931815147, 19.9019792675972, 13.860010877251625, 47.9948940128088, 63.928780406713486, 58.908273205161095, 60.134121626615524, 59.02724862098694, 61.02094084024429, 60.89742846786976, 60.18036134541035, 59.53671008348465, 52.12493039667606, 46.196921691298485, 41.84513680636883, 41.770600005984306, 43.65239582955837, 56.12541273236275, 56.50125816464424, 58.22790451347828, 57.539381459355354, 58.87525677680969, 54.10928271710873, 52.70257540047169, 48.952678218483925, 54.49860602617264, 54.41104352474213, 53.31488594412804, 51.257243156433105, 45.13514846563339, 42.54918582737446, 42.56261430680752, 43.77580940723419, 44.568142890930176, 43.59845392405987, 44.787676110863686, 44.436289966106415, 43.370325565338135, 42.56109058856964, 39.393899738788605, 43.408863097429276, 43.71589042246342, 43.58523063361645, 43.14925342798233, 41.211308017373085, 42.33413256704807, 42.94588454067707, 44.195747673511505, 45.16323275864124, 42.96166509389877, 46.112817004323006, 41.801032572984695, 44.38829854130745, 43.94023038446903, 48.14527854323387, 44.7822879999876, 53.32019425928593, 51.0552041977644, 59.22280132770538, 42.204133942723274, 35.07641561329365, 55.28789207339287, 51.32461354136467, 58.64754259586334, 52.82731130719185, 57.849144637584686, 54.45705905556679, 52.51124806702137, 54.13280725479126, 54.67953331768513, 53.89566197991371, 55.20844593644142, 59.20132867991924, 51.34448267519474, 52.542011216282845, 56.481237038969994, 54.74299371242523, 47.43422269821167, 40.63595049083233, 40.80866642296314, 40.576985254883766, 41.6731808334589, 44.939337372779846, 60.46511046588421, 57.40049131214619, 59.48703154921532, 51.86856955289841, 45.174803137779236, 46.265591606497765, 53.15442435443401, 56.59594148397446, 54.505308866500854, 52.05560691654682, 54.144430831074715, 55.263596177101135, 52.878209576010704, 47.789522632956505, 53.40850532054901, 54.2225356400013, 58.42534951865673, 54.69909846782684, 50.77298954129219, 49.48771230876446, 51.49929016828537, 57.9422814399004, 58.48145350813866, 55.26436373591423, 56.45572140812874, 56.642101407051086, 61.28359414637089, 60.30145324766636, 54.39373165369034, 48.87312188744545, 58.89034956693649, 59.38477523624897, 58.84484700858593, 42.20399335026741, 33.879179656505585, 13.321197889745235, 3.3088403614237905, 10.787842478603125, 5.526163168251514, 4.0382979065179825, 0.30764241702854633, 14.044831059873104, 49.91242691874504, 54.27136681973934, 45.91634474694729, 21.08086410909891, 31.847658567130566, 51.49428963661194, 60.41482776403427, 67.46625378727913, 28.345542289316654, 0.5832223920151591, 0.12703355139819905, 0.11268841568380594, 0.27610517805442214, 0.25727573374751955, 0.11882547973073088, 0.1608174791908823, 0.2143850305583328, 0.17947827785974368, 0.10191217908868566, 0.11770917088142596, 0.07661283976631239, 0.2085612789960578, 0.15393205569125712], [0.033885190132423304, 0.10815257235663012, 0.01678666983934818, 0.025516783025523182, 0.027037480722356122, 0.044684058520942926, 0.024762143148109317, 0.017939241879503243, 0.06825363714597188, 0.012883136332675349, 0.005616768894469715, 0.08658201302750967, 0.045569169815280475, 0.4651649238076061, 27.11187768727541, 54.74010206758976, 45.364006385207176, 29.244701340794563, 16.960847787559032, 16.61417528986931, 21.761504486203194, 36.51859022676945, 51.743259876966476, 10.024177506566048, 0.2831341477576643, 0.18440167070366442, 0.8208173490129411, 3.022047900594771, 6.022949460893869, 13.692189082503319, 23.115962706506252, 55.015773475170135, 58.0350686609745, 54.357044622302055, 50.76782561838627, 48.57257321476936, 53.252447694540024, 52.87497974932194, 52.853324711322784, 45.800173580646515, 42.29361534118652, 37.750936299562454, 37.273856699466705, 37.60909751057625, 37.41528891026974, 40.954867377877235, 44.81588959693909, 47.46921882033348, 50.517692640423775, 50.83135060966015, 52.095588371157646, 53.85889895260334, 48.542836010456085, 47.855380699038506, 51.66800111532211, 50.37580445408821, 51.53621278703213, 47.224314361810684, 44.51326243579388, 37.72163987159729, 37.998751401901245, 38.02352987229824, 39.572041779756546, 38.037288933992386, 38.35204504430294, 38.02843160927296, 38.16896326839924, 37.606487050652504, 38.34070265293121, 37.75409013032913, 39.747455567121506, 38.43695908784866, 36.905097886919975, 38.65646950900555, 40.89153237640858, 41.35930247604847, 41.37667894363403, 40.587282702326775, 39.84988287091255, 37.723615765571594, 39.80170525610447, 40.081982016563416, 45.892295837402344, 47.62965381145477, 49.92841646075249, 47.959996685385704, 56.120324805378914, 37.30320632457733, 30.688532665371895, 57.54168413579464, 46.87327779829502, 50.380728989839554, 47.53787353634834, 47.852344661951065, 45.686688870191574, 49.98635195195675, 44.08026047050953, 47.86804161965847, 48.02807003259659, 51.56753450632095, 51.198296919465065, 48.541806265711784, 45.74815437197685, 52.60609857738018, 50.69801576435566, 41.77251510322094, 36.41817681491375, 38.93208771944046, 38.31263355910778, 41.31197601556778, 38.28202620148659, 43.96493285894394, 45.74968948960304, 45.37372626364231, 38.13585564494133, 39.587012976408005, 47.64369785785675, 51.35964386165142, 53.952586725354195, 47.24219240248203, 49.9360616505146, 53.64664614200592, 49.664839804172516, 45.66134802997112, 47.17653952538967, 51.904557421803474, 50.471859499812126, 52.77708940207958, 51.15767329931259, 53.917085230350494, 51.73914469778538, 54.183378741145134, 52.02013202011585, 56.26505143940449, 53.74906964600086, 55.276758670806885, 54.29978929460049, 56.85264430940151, 51.53379611670971, 53.17613258957863, 55.68247430026531, 58.778323978185654, 55.97755506634712, 65.20061776041985, 52.40924634039402, 58.00567343831062, 22.893490344285965, 1.0690851020626724, 2.9775641625747085, 7.060927888378501, 1.843427144922316, 0.21936332748737186, 4.6911294758319855, 44.833243265748024, 36.12174332141876, 32.40381382405758, 36.64335273206234, 17.93522570282221, 36.278192326426506, 43.21360297501087, 51.6889987885952, 22.914980091154575, 0.5921345169190317, 0.01308995433646487, 0.0597501721495064, 0.028232062031747773, 0.028158530039945617, 0.018535538983996958, 0.0593746157392161, 0.021641484527208377, 0.04337158148700837, 0.10347796225687489, 0.06947891553863883, 0.04251018923241645, 0.12062392619554885, 0.045858392186346464, 0.00928077377466252, 0.04291258541343268, 0.03294461072073318, 0.05891696666367352, 0.04549435390799772, 0.005580048355113831, 0.05203005886869505, 0.02809781493851915, 0.0799220020417124, 0.015563860015390674, 0.019713177061930764, 0.051968301049782895, 0.03655315907963086, 0.9116252325475216, 36.82375185191631, 63.408789709210396, 52.153839245438576, 39.266139194369316, 22.10137154906988, 18.4904196113348, 27.59051900357008, 41.04626007378101, 58.74840438365936, 10.928670521825552, 0.29748523549642414, 1.032802511472255, 3.939340291544795, 10.323444698005915, 8.77455186098814, 5.756845464929938, 17.683823592960835, 58.1816191971302, 60.75066514313221, 57.77239255607128, 52.08348602056503, 51.90224714577198, 54.02439907193184, 55.11366382241249, 54.355114325881004, 50.29185175895691, 43.36902603507042, 40.315380692481995, 39.979319125413895, 39.50290448963642, 40.67175596952438, 43.66454757750034, 47.579903081059456, 49.19923558831215, 52.4136047065258, 52.10127666592598, 54.845580607652664, 53.72784398496151, 50.75758896768093, 49.5828478038311, 53.84672060608864, 53.644943833351135, 51.937813237309456, 48.30082319676876, 45.43630510568619, 39.59841996431351, 39.719629660248756, 39.78568151593208, 40.00674985349178, 39.50606971979141, 41.036855578422546, 39.31709825992584, 39.77553226053715, 38.54770414531231, 40.764326602220535, 38.76271180808544, 42.171189710497856, 39.28837560117245, 38.84466961026192, 41.563841700553894, 43.56813535094261, 43.23503002524376, 43.075974360108376, 42.00913980603218, 41.96789301931858, 39.31015603244305, 41.715263575315475, 42.557191997766495, 48.06116245687008, 49.38123822212219, 53.11981961131096, 49.80152986943722, 57.27448247373104, 39.12640929222107, 32.80673660337925, 57.818126901984215, 48.75299133360386, 53.521762043237686, 49.5268502086401, 51.38044394552708, 48.96632708609104, 51.67749680578709, 46.82698108255863, 50.223615020513535, 50.83700850605965, 53.122456669807434, 53.47320444881916, 49.44149538874626, 47.18002773821354, 53.32702249288559, 52.45326317846775, 41.091511845588684, 39.050215780735016, 40.73511376976967, 40.258657336235046, 42.4457211792469, 42.76710033416748, 44.879224598407745, 48.21331389248371, 47.43977800011635, 41.97771169245243, 41.05107821524143, 48.7470256537199, 53.412221521139145, 54.30667832493782, 46.4739116281271, 50.97214825451374, 54.42075960338116, 50.39513781666756, 48.30335006117821, 49.90533269941807, 54.60793375968933, 51.85617461800575, 53.404162153601646, 53.87208804488182, 54.84872683882713, 54.737867787480354, 53.790525421500206, 52.769930586218834, 55.482289642095566, 56.45297035574913, 57.20885619521141, 57.19339482486248, 57.57159233093262, 51.988817900419235, 52.13285677134991, 57.781922444701195, 59.02050778269768, 59.58111830055714, 63.96373853087425, 56.19540497660637, 59.1195722669363, 25.727091394364834, 0.8983694657217711, 7.620436465367675, 5.925697004422545, 1.4191629295237362, 0.21020173706347123, 5.086279772222042, 48.600889295339584, 42.50837981700897, 27.152242921292782, 30.46486906707287, 25.567857138812542, 40.520945861935616, 50.029456838965416, 59.92291755974293, 30.76850887387991, 0.6900591216981411, 0.02364319039770635, 0.07463288624421693, 0.04298566469515208, 0.05588845495367423, 0.028083714132662863, 0.009558714573358884, 0.02591851127363043, 0.011438835317676421, 0.03337712325446773, 0.05755484366090968, 0.02921728719229577, 0.039733198791509494, 0.06283953625825234, 0.13338357472093776, 0.18490662798285484, 0.1359890028834343, 0.14078593376325443, 0.08795937232207507, 0.15364468126790598, 0.14083034388022497, 0.13387349608819932, 0.20577098184730858, 0.1273510867031291, 0.2075764787150547, 0.18737851409241557, 0.1632418530061841, 1.7210625484585762, 47.221905291080475, 69.86433550715446, 59.98546980321407, 43.59979525208473, 27.774459533393383, 23.09067316353321, 30.898995772004128, 48.31306613981724, 62.64818832278252, 12.70517684519291, 0.37021425319835544, 0.5305235541891307, 2.772571574896574, 10.27580950409174, 14.211638309061527, 24.30676180869341, 27.448271736502647, 60.39482183754444, 61.233744621276855, 59.24224108457565, 53.631686344742775, 54.05890882015228, 57.66129411756992, 57.38122634589672, 57.44400277733803, 51.402171179652214, 45.32324597239494, 42.58241504430771, 41.56926400959492, 40.79447418451309, 40.650104731321335, 45.07151708006859, 47.48176574707031, 51.93763464689255, 54.775067791342735, 55.43818920850754, 56.30453132092953, 54.24681253731251, 49.67662677168846, 49.270945340394974, 55.27764022350311, 55.96291825175285, 54.87469844520092, 50.94439074397087, 49.694406017661095, 42.85380408167839, 41.25050291419029, 40.44043578207493, 43.65946725010872, 42.81821899116039, 42.23403833806515, 42.8971141576767, 41.91784210503101, 40.41680485010147, 41.469918340444565, 40.99984936416149, 43.68015334010124, 42.997329980134964, 39.39007334411144, 42.649880424141884, 45.221666023135185, 45.18587954342365, 45.73381394147873, 45.302461087703705, 45.397345796227455, 41.608622297644615, 44.84681993722916, 45.393340811133385, 50.68138025701046, 51.13211967051029, 55.09402647614479, 53.529487028717995, 58.17848816514015, 43.97237665951252, 35.86852490901947, 60.68744033575058, 50.58033227920532, 54.87417787313461, 51.68233014643192, 52.61770695447922, 49.90742638707161, 53.76740746200085, 48.76396894454956, 52.51068949699402, 53.1328871101141, 54.73166272044182, 54.1938965767622, 51.24380707740784, 51.02197878062725, 57.58232295513153, 53.921097815036774, 44.20861758291721, 40.710593685507774, 43.60752023756504, 43.349943459033966, 45.78882358968258, 44.99959073960781, 47.6318234950304, 49.57240216434002, 51.251908242702484, 42.97991931438446, 43.23500722646713, 50.67071042954922, 56.37234628200531, 56.99365474283695, 50.47731600701809, 52.433663830161095, 56.942395493388176, 53.54893438518047, 50.597321167588234, 51.30355127155781, 57.042140141129494, 54.911362677812576, 54.32603448629379, 55.32279700040817, 58.7180782109499, 56.93779394030571, 57.2742734849453, 53.98016944527626, 59.49761398136616, 59.02649626135826, 61.4912074059248, 58.79974722862244, 60.71831367909908, 52.30534091591835, 54.49952557682991, 60.37617243826389, 62.85625755786896, 60.22996008396149, 66.71029955148697, 58.868690729141235, 60.94355419278145, 26.185804679989815, 2.698642029426992, 10.680688228458166, 15.208778902888298, 3.805867228657007, 0.24225070170359686, 5.714752748608589, 56.66553854942322, 49.2045933008194, 45.22216759622097, 52.67122708261013, 27.364218346774578, 47.879357412457466, 59.833964332938194, 68.21862861514091, 38.19350615143776, 1.071757071185857, 0.15225505427224562, 0.2218696937779896, 0.10114404882187955, 0.23750361346174031, 0.1326666452223435, 0.09928527317242697, 0.13738210313022137, 0.07549297602963634, 0.17228933080332354, 0.10597817614325322, 0.13785761198960245, 0.17563337401952595, 0.11187762676854618], [0.011290477214060957, 0.09062626515515149, 0.10622858419083059, 0.022717060601280537, 0.01837078591051977, 0.006649853303315467, 0.044867083270219155, 0.02255362855066778, 0.025999522258643992, 0.05436229876067955, 0.055313516859314404, 0.033574348999536596, 0.046388285627472214, 2.531755934469402, 37.854104563593864, 44.19012017548084, 44.84974578022957, 31.322823129594326, 22.003154419362545, 32.86472529172897, 31.00611202418804, 37.257863357663155, 49.76680353283882, 4.951688619330525, 0.04200343224511016, 0.13372263230849057, 3.80185108166188, 6.087821954861283, 7.039353596046567, 10.324376598000526, 42.797958478331566, 61.777533441782, 54.21006850898266, 52.77037136256695, 48.188098445534706, 42.101524248719215, 43.768437802791595, 42.74076774716377, 41.92392937839031, 38.12138982117176, 40.63957929611206, 43.081024289131165, 43.068272173404694, 41.62243075668812, 40.30505284667015, 39.78328004479408, 39.509147554636, 39.55015115439892, 42.80403435230255, 47.413415014743805, 49.95464265346527, 50.0501961261034, 51.55906096100807, 49.64049071073532, 48.690089508891106, 50.85852675139904, 51.50008052587509, 49.43680264055729, 48.318089470267296, 42.655789107084274, 38.683866038918495, 39.0511467307806, 39.98878061771393, 38.10894928872585, 38.72046947479248, 40.53616784512997, 40.00478535890579, 36.790971010923386, 40.101360976696014, 37.93972156941891, 40.2419800311327, 38.238830119371414, 36.62646263837814, 40.54538995027542, 41.85838669538498, 41.83133974671364, 43.27327877283096, 39.749427661299706, 41.41816511750221, 39.00858521461487, 44.402513578534126, 49.316231310367584, 52.96419896185398, 51.693273559212685, 55.33924251794815, 48.44127506017685, 57.863720655441284, 37.601513117551804, 29.664561711251736, 54.57684002816677, 46.734585240483284, 50.51173076033592, 44.24188859760761, 47.425464168190956, 47.19616927206516, 47.768220975995064, 47.581404000520706, 50.3466410189867, 49.94982831180096, 53.31990547478199, 49.66225974261761, 48.17536532878876, 44.067287966609, 48.46357226371765, 48.151362016797066, 40.33971458673477, 37.378069907426834, 38.06576080620289, 38.27421002089977, 40.597564950585365, 37.64980852603912, 40.749002024531364, 37.25949726998806, 39.92738351225853, 37.24456787109375, 42.8814247995615, 49.31651629507542, 54.11451503634453, 49.67802509665489, 46.9614140689373, 52.905917689204216, 53.01507443189621, 46.347348019480705, 46.037235260009766, 49.02607887983322, 51.52722246944904, 50.02334676682949, 51.85666099190712, 53.167959228158, 50.87006293237209, 50.60819238424301, 56.11921526491642, 50.02356335520744, 51.47291578352451, 55.57056650519371, 54.24112804234028, 52.1761554479599, 51.807837411761284, 50.08457288146019, 58.149412125349045, 55.10331317782402, 55.97769945859909, 52.90589489042759, 59.51708413660526, 56.47320047020912, 62.03922539949417, 29.250839911401272, 0.9696958540007472, 0.6727593624964356, 0.5919762910343707, 0.17004326538881287, 0.06206555786775425, 1.5543240518309176, 37.62793689966202, 44.65480104088783, 74.37793090939522, 68.99016201496124, 17.787943705916405, 32.63685151934624, 41.0974395275116, 56.51557579636574, 32.34501197934151, 0.6714364397339523, 0.0720808852929622, 0.011697311438183533, 0.1335223563364707, 0.10224053490674123, 0.2001263402053155, 0.02718873969570268, 0.04256190579326358, 0.089697185321711, 0.06871581703308038, 0.035930352460127324, 0.054845488848513924, 0.033387153380317613, 0.04683124388975557, 0.005284912458591862, 0.05007329375075642, 0.05819282348966226, 0.03730865428224206, 0.046510079482686706, 0.019979083008365706, 0.02705968578084139, 0.036413390407687984, 0.03319142677355558, 0.025414552183065098, 0.008973806652647909, 0.02511001188395312, 0.036789347577723674, 4.205110855400562, 49.3454859405756, 51.044260784983635, 52.77010157704353, 37.21577301621437, 27.506651803851128, 26.556330397725105, 26.592105478048325, 41.60195745527744, 53.02088052034378, 5.351661331951618, 0.1240308812703006, 1.2844954244792461, 6.727115800604224, 10.815286505967379, 8.081008326262236, 8.652585055679083, 40.36874882876873, 63.89728009700775, 56.55358515679836, 55.62517337501049, 48.19412112236023, 44.63778555393219, 45.75603514909744, 46.57000847160816, 42.77880370616913, 40.87104007601738, 42.22321271896362, 45.769250839948654, 45.19302695989609, 42.915087193250656, 39.63340848684311, 41.27962835133076, 41.09582841396332, 41.51400737464428, 45.1257249712944, 49.05426576733589, 51.92613646388054, 52.540981471538544, 52.65383921563625, 49.90901090204716, 49.13268595933914, 52.136971950531006, 52.30414777994156, 52.02680446207523, 50.716019198298454, 44.118425622582436, 40.14262676239014, 39.74625863134861, 41.58729404211044, 41.175274550914764, 40.084999054670334, 41.380839720368385, 41.84682011604309, 40.50987705588341, 41.22527986764908, 41.236014291644096, 42.2757600992918, 40.15929266810417, 40.09462773799896, 43.45323331654072, 44.54079955816269, 42.66431964933872, 44.39841739833355, 44.12951722741127, 41.822246834635735, 40.76436460018158, 47.66460433602333, 51.70152671635151, 53.770656287670135, 54.43170301616192, 55.48013895750046, 50.09363539516926, 59.95527662336826, 39.82798844575882, 31.92622885107994, 55.877381041646004, 49.09610532224178, 51.6862553358078, 46.90594084560871, 50.48963114619255, 48.74819979071617, 49.817143231630325, 49.29814048111439, 52.53836341202259, 51.908159628510475, 55.604441687464714, 52.92819209396839, 50.096059665083885, 46.0435239225626, 50.224352180957794, 50.420509055256844, 41.994833573699, 37.828885316848755, 40.14076106250286, 40.082787573337555, 42.44653433561325, 39.907947555184364, 43.159683868288994, 40.062720850110054, 41.51132471859455, 39.66048963367939, 43.966334983706474, 50.91585047543049, 55.60997799038887, 50.55551201105118, 46.7461784183979, 54.26334545016289, 53.724769949913025, 48.12440626323223, 47.651274651288986, 52.46345043182373, 54.275322407484055, 51.85221903026104, 52.341070398688316, 56.289814710617065, 52.83977463841438, 52.97070801258087, 56.29123583436012, 53.40032055974007, 52.83606983721256, 55.94893500208855, 53.9303807169199, 53.26464124023914, 52.20045894384384, 52.19584599137306, 58.55094417929649, 57.842001020908356, 57.46180102229118, 56.11684039235115, 59.65184770524502, 58.77202391624451, 63.82521316409111, 33.213272988796234, 1.0004662466235459, 3.7175160320475698, 3.605384286493063, 1.2830168288201094, 0.14517480216454715, 0.9678859636187553, 42.617517560720444, 45.20104452967644, 63.079089000821114, 67.82096475362778, 23.455398492515087, 35.94010166823864, 49.57525201141834, 62.875651717185974, 41.98955565690994, 1.381002408452332, 0.13963422446977347, 0.10051501187263057, 0.06913339384482242, 0.09061834643944167, 0.015246021357597783, 0.0225724364281632, 0.023394185009237844, 0.07145922529161908, 0.061024862734484486, 0.039402148977387697, 0.04413122158439364, 0.04991655587218702, 0.02432964916806668, 0.19908479531295598, 0.145128536678385, 0.3321756224613637, 0.09072699685930274, 0.08812591768219136, 0.10028457501903176, 0.12738152960082516, 0.13477709057042375, 0.07521872277720831, 0.1363685223623179, 0.11380168914911337, 0.24293840542668477, 0.14695816818857566, 5.775889093056321, 58.427952378988266, 61.028377041220665, 59.0273018181324, 42.49569609761238, 33.6838511377573, 44.00388456881046, 41.86150632798672, 49.30426575243473, 58.57063852250576, 6.406763540580869, 0.2784428541781381, 0.6636804027948529, 7.11444279178977, 13.692755252122879, 13.193650133907795, 15.214696135371923, 45.003135949373245, 65.21900117397308, 58.85130286216736, 57.89149336516857, 51.29173010587692, 45.33040098845959, 47.18538925051689, 47.776865512132645, 45.03966338932514, 42.69143499433994, 45.24948813021183, 46.833577528595924, 47.36291952431202, 45.558069571852684, 42.97004744410515, 43.35161916911602, 44.07309025526047, 43.06155413389206, 46.72332264482975, 51.922222673892975, 54.323747009038925, 54.42830219864845, 55.33912472426891, 52.13656157255173, 49.36323098838329, 53.3491525053978, 56.115970239043236, 53.07138741016388, 53.443854823708534, 46.6985859721899, 42.36470952630043, 43.34135591983795, 44.664604514837265, 42.29679577052593, 42.8201112896204, 45.24119697511196, 43.6878327280283, 41.66964702308178, 43.277002573013306, 44.19611245393753, 45.14255806803703, 42.51951701939106, 41.69978700578213, 44.94561083614826, 45.11393420398235, 44.20796401798725, 47.374345511198044, 45.074876099824905, 44.92565430700779, 43.67753528058529, 49.65895392000675, 55.492108315229416, 55.115046948194504, 56.550670713186264, 58.57441172003746, 52.80993863940239, 60.90536244213581, 42.17224985361099, 33.36084187030792, 56.689177080988884, 51.12398810684681, 55.30423879623413, 48.60319197177887, 50.878665670752525, 52.05384001135826, 52.08415478467941, 52.73363873362541, 54.53975021839142, 54.177318066358566, 57.6403534412384, 54.39639151096344, 50.5746515840292, 47.183857932686806, 54.78048250079155, 52.34351746737957, 43.03584851324558, 39.603006318211555, 39.97553452849388, 41.8426251411438, 44.645138159394264, 41.32780596613884, 45.568359419703484, 41.39486476778984, 43.33092547953129, 41.98119230568409, 45.72277173399925, 54.388978108763695, 58.41398052871227, 52.787493243813515, 47.814244106411934, 56.39303997159004, 56.631131395697594, 50.78313119709492, 50.63291385769844, 54.05316352844238, 55.10085090994835, 52.62556493282318, 55.34304231405258, 59.10748511552811, 55.47383889555931, 52.529414892196655, 60.6105400621891, 53.99207040667534, 54.44452352821827, 57.22725860774517, 56.64283096790314, 53.93168784677982, 52.029274329543114, 51.68874800205231, 62.16479726135731, 60.31326301395893, 59.85325209796429, 59.297174736857414, 65.70621103048325, 61.41933426260948, 66.46305441856384, 34.17204134166241, 2.444755802862346, 3.1976464530453086, 2.234157803468406, 2.6440282724797726, 0.40225077944342047, 1.8847645330242813, 46.9194795191288, 59.09124098718166, 88.39382842183113, 72.94737607240677, 28.036115393042564, 44.85965184867382, 59.18641448020935, 68.31406429409981, 51.99958272278309, 2.2221606597304344, 0.2734958758810535, 0.1774605712853372, 0.14426363777602091, 0.2274737844709307, 0.28914189257193357, 0.2558099030284211, 0.17741111456416547, 0.21142251061974093, 0.21635050477925688, 0.10250819788780063, 0.1117702157353051, 0.18437853053910658, 0.11715242653735913], [0.046130986738717183, 0.05659587754053064, 0.08376446421607397, 0.04211026069242507, 0.061141958794905804, 0.033204265928361565, 0.04561829999147449, 0.03725305628904607, 0.00948356191656785, 0.024101492563204374, 0.03441017055592965, 0.05232124050962739, 0.06264427720452659, 7.079825699329376, 46.711364686489105, 49.39571164548397, 36.772097423672676, 22.440488152205944, 12.739322762936354, 24.243316613137722, 32.40603290498257, 43.89918118715286, 40.9731861948967, 1.6837870236486197, 0.20627682970371097, 5.828773230314255, 5.1850345730781555, 10.437860358506441, 9.498759750276804, 16.960834488272667, 52.56541036069393, 56.799181178212166, 57.68270596861839, 52.47327670454979, 47.18612641096115, 43.47315564751625, 40.45079402625561, 39.3631935864687, 40.303890109062195, 41.61260448396206, 50.38007542490959, 51.19428053498268, 52.41881802678108, 49.8849505931139, 48.45100253820419, 44.57237586379051, 43.86513501405716, 41.96514196693897, 42.855703979730606, 45.67711718380451, 49.511901810765266, 50.121286511421204, 50.67710928618908, 49.21731501817703, 49.450417309999466, 46.15608908236027, 48.63630339503288, 50.16529954969883, 48.23871552944183, 47.12235063314438, 39.03307490050793, 37.901602014899254, 37.74418406188488, 37.44748838245869, 37.25689820945263, 39.40073937177658, 39.37642067670822, 36.23954460024834, 39.60069604218006, 38.97241495549679, 42.06286132335663, 37.84376531839371, 38.718793764710426, 43.02752695977688, 45.001961812376976, 43.42753529548645, 46.343601420521736, 40.35257689654827, 40.09831354022026, 39.781087562441826, 48.63596901297569, 52.82517582178116, 52.17360198497772, 49.312055334448814, 51.94689854979515, 47.76923932135105, 52.923795729875565, 34.25448551774025, 30.295375362038612, 56.15449637174606, 48.77512514591217, 48.73541347682476, 45.65814100205898, 48.74892555177212, 48.08368004858494, 51.54983505606651, 50.544310212135315, 49.52396996319294, 50.373680368065834, 51.2989991158247, 45.00351972877979, 44.567652717232704, 43.82172994315624, 48.57199564576149, 47.58449703454971, 39.051355719566345, 37.67032742500305, 38.15844543278217, 38.692176192998886, 39.43282105028629, 39.15080018341541, 39.472046345472336, 39.311235174536705, 40.17748989164829, 39.23556603491306, 44.79792796075344, 50.315197706222534, 53.11934843659401, 43.85191172361374, 50.58908320963383, 51.63802072405815, 50.49088887870312, 45.69535620510578, 47.08617277443409, 53.0313565582037, 51.69846408069134, 50.73496498167515, 51.36223152279854, 52.629212737083435, 49.619432240724564, 46.56730301678181, 51.74913056194782, 54.84513983130455, 50.67387565970421, 48.39189291000366, 45.26976764202118, 48.896194249391556, 51.47859267890453, 54.97215561568737, 56.0323329269886, 54.16010499000549, 51.740087047219276, 53.14354553818703, 57.16889753937721, 53.29834163188934, 60.968059077858925, 42.13951461017132, 3.582962164655328, 4.343085726723075, 1.8762749573215842, 1.0076315933838487, 0.03812653441855218, 0.3262052818899974, 28.184220045804977, 49.01687577366829, 49.299998581409454, 45.97628653049469, 18.93939021974802, 25.342493131756783, 46.60647891461849, 49.37852516770363, 37.97812230885029, 1.1524462164379656, 0.11130039172712713, 0.054528187320102006, 0.03340174771437887, 0.01293007810090785, 0.04823821858735755, 0.03279858945461456, 0.06561597750987858, 0.04688171735324431, 0.020655762127717026, 0.028393013453751337, 0.05342791999282781, 0.031482683698413894, 0.07280624558916315, 0.012157438359281514, 0.022138588028610684, 0.08833835745463148, 0.04325098991103005, 0.05373356238123961, 0.06144865132228006, 0.03591225147829391, 0.06562563285115175, 0.036963169695809484, 0.02890281510190107, 0.015241747514664894, 0.010889137665799353, 0.012100504500267562, 10.127417016774416, 56.27241164445877, 55.734356716275215, 43.626887798309326, 27.52694271504879, 18.754729628562927, 24.070830568671227, 33.900747299194336, 48.76336857676506, 45.643625780940056, 2.244047960266471, 0.07068319857353345, 2.747597652487457, 7.165910555049777, 15.091492496430874, 8.361160643398762, 13.65110283717513, 53.68183985352516, 59.39101070165634, 57.849745005369186, 54.35147412121296, 49.325920790433884, 43.930096328258514, 42.61288180947304, 41.257201954722404, 40.88268645107746, 43.82342465221882, 50.59889428317547, 52.80673161149025, 54.940655305981636, 52.03316152095795, 49.60890680551529, 45.39676822721958, 46.55549705028534, 42.36977845430374, 44.61353525519371, 48.23418237268925, 52.046289816498756, 51.34358212351799, 52.16768950223923, 50.48576295375824, 50.231803581118584, 46.80927403271198, 48.923153802752495, 51.29508912563324, 51.611851528286934, 48.653155490756035, 41.96897976100445, 40.17863743007183, 40.05458928644657, 38.48327100276947, 40.13062700629234, 40.03802217543125, 40.38739062845707, 38.16223382949829, 40.325833931565285, 40.5021558701992, 42.55152650177479, 39.106494560837746, 39.97274927794933, 44.391083791852, 46.57377406954765, 44.92109835147858, 46.480880454182625, 43.13493199646473, 42.41161420941353, 42.882766127586365, 53.87556105852127, 55.138921067118645, 53.94815616309643, 51.15499444305897, 53.24554726481438, 49.12995770573616, 53.59998844563961, 35.71920432150364, 32.379122748970985, 58.413699343800545, 49.9921428412199, 50.940826535224915, 46.57178297638893, 50.5346093326807, 50.13522416353226, 52.73340694606304, 52.44338370859623, 51.45063377916813, 51.48960828781128, 52.01122149825096, 46.359541565179825, 46.321699395775795, 46.49848110973835, 49.03276652097702, 48.6349468678236, 40.81313498318195, 38.62988233566284, 40.17151281237602, 39.30542528629303, 40.4603923112154, 40.33770829439163, 40.098480731248856, 40.753341391682625, 40.36599017679691, 40.55473744869232, 46.89245916903019, 53.066968247294426, 55.110065415501595, 44.70704063773155, 50.968850031495094, 54.06608663499355, 53.14075268805027, 48.042353466153145, 48.829260841012, 53.68223123252392, 53.27602542936802, 51.6287150233984, 54.02872323989868, 53.40366058051586, 52.367000207304955, 49.6297524869442, 54.37513925135136, 55.887492299079895, 52.321946024894714, 49.81395900249481, 47.5619300454855, 48.80526512861252, 54.11936357617378, 56.386971697211266, 56.655871868133545, 56.658109948039055, 54.396490305662155, 56.53516374528408, 58.901482969522476, 58.22793871164322, 61.73225127160549, 45.27869716286659, 5.476356390863657, 6.117475088685751, 9.286067113280296, 2.834624145179987, 0.20061026501934975, 0.38004554284270853, 32.610446736216545, 56.106888726353645, 57.34329678118229, 47.99605295062065, 20.201868675649166, 34.98970426619053, 54.23437960445881, 55.508375242352486, 47.84778490662575, 2.781833577901125, 0.05475297642988153, 0.025798398382903542, 0.06475032903836109, 0.045586038831970654, 0.11748870849260129, 0.016523867925570812, 0.01994047277548816, 0.057960512713179924, 0.12675296020461246, 0.06063745422579814, 0.05668168465490453, 0.05775152392743621, 0.07371799627435394, 0.1374974922509864, 0.2464205920114182, 0.12968849565368146, 0.2169957576552406, 0.1517277880338952, 0.15550870390143245, 0.1637584768468514, 0.13680120930075645, 0.08073367411270738, 0.08648849499877542, 0.17618925747228786, 0.16810364759294316, 0.16334045474650338, 13.617462292313576, 63.58876705169678, 61.873983666300774, 50.659527629613876, 33.43018054962158, 20.739583522081375, 35.13496667146683, 45.23910328745842, 55.77958568930626, 49.54101584851742, 2.3456768319010735, 0.2675402595195919, 10.011130906641483, 18.60631339251995, 23.309471122920513, 18.282224982976913, 19.854202531278133, 56.67298994958401, 59.405788108706474, 61.421515345573425, 56.228691190481186, 51.989247277379036, 47.37479008734226, 45.197818502783775, 43.39761570096016, 43.927789852023125, 45.5109217017889, 53.781041130423546, 54.8368638753891, 57.026705369353294, 55.131796449422836, 54.29723583161831, 49.471057802438736, 49.16037127375603, 45.52273906767368, 46.512745544314384, 50.14309734106064, 54.35490533709526, 54.294549375772476, 53.47285486757755, 51.558266803622246, 51.78166061639786, 47.62337274849415, 50.04477761685848, 54.11795385181904, 53.14631558954716, 50.636466667056084, 43.465183675289154, 42.190105095505714, 41.107812970876694, 41.2642277777195, 41.11214853823185, 42.50106900930405, 42.39480771124363, 40.001555532217026, 41.693122163414955, 42.61900708079338, 45.84438040852547, 41.96385383605957, 42.073166370391846, 47.11313612759113, 49.21168752014637, 46.603385880589485, 51.18304833769798, 45.37940315902233, 43.57730805873871, 45.98648518323898, 54.8212581127882, 56.911309361457825, 55.095892176032066, 50.77853724360466, 55.85815407335758, 50.38250729441643, 54.27267774939537, 37.281144708395004, 35.719493106007576, 60.22839456796646, 53.777112141251564, 52.82251596450806, 49.071239456534386, 52.560003250837326, 52.777435183525085, 55.507816672325134, 54.31659959256649, 51.3955557346344, 53.68139147758484, 53.09726022183895, 47.740182280540466, 46.59067176282406, 48.13959784805775, 54.197692573070526, 50.55705852806568, 42.38549821078777, 41.66097968816757, 41.68722487986088, 41.85972802340984, 42.34792202711105, 41.69920563697815, 43.5054425150156, 43.78767617046833, 42.34703667461872, 43.62192906439304, 49.47486899793148, 55.54321937263012, 55.41879124939442, 44.622312784194946, 52.24635288119316, 55.849479138851166, 55.64060814678669, 50.240980088710785, 51.46693870425224, 58.609358444809914, 53.80863144993782, 53.27700577676296, 56.96895606815815, 57.933283522725105, 54.316500797867775, 53.45096044242382, 56.74497328698635, 59.75031562149525, 53.892774134874344, 54.15288917720318, 49.248435348272324, 47.67565034329891, 54.9383108317852, 59.613693952560425, 59.445868358016014, 59.851185008883476, 57.31039434671402, 58.92889849841595, 61.39114357531071, 59.29444268345833, 64.56433430314064, 48.077847361564636, 6.524449400603771, 10.987609159201384, 7.639528540894389, 4.010435426607728, 0.21196231915382668, 0.5812613409943879, 37.57833056151867, 64.73103895783424, 59.265036061406136, 52.48123347759247, 29.658130556344986, 38.3105094730854, 62.356922551989555, 64.41499471664429, 59.13967318832874, 5.175634827464819, 0.19261157547589391, 0.105574714980321, 0.20757322810823098, 0.12743160972604528, 0.2853778382996097, 0.1540495376684703, 0.09962470183381811, 0.1521077231154777, 0.18522958096582443, 0.09927932114806026, 0.21767678204923868, 0.09890930115943775, 0.13753820647252724], [0.07484094734536484, 0.023673585055803414, 0.01672917936957674, 0.01786479519068962, 0.06497258742456324, 0.020284111269575078, 0.046096688383840956, 0.06538186702528037, 0.015802745292603504, 0.04215601038595196, 0.030826062975393143, 0.0630589151114691, 0.1486221226514317, 13.081257864832878, 51.884407103061676, 46.292509362101555, 43.54658290743828, 25.37441521883011, 21.36639028787613, 26.392758674919605, 26.71299409121275, 45.66953279078007, 35.93041218817234, 0.4896422603633255, 0.032947393774520606, 1.7980170878581703, 4.863681066781282, 8.867363780736923, 10.618517864495516, 30.818027816712856, 60.504115372896194, 56.08741857111454, 52.50387266278267, 49.706196784973145, 44.493332505226135, 41.68451942503452, 40.676095336675644, 41.881896033883095, 40.33009350299835, 42.318124026060104, 48.4786194562912, 52.88847662508488, 53.25406260788441, 51.81479103863239, 48.78443084657192, 50.0224120169878, 48.564479649066925, 47.31837831437588, 47.798809334635735, 48.691461235284805, 47.34667919576168, 48.214963003993034, 51.50940142571926, 50.750646740198135, 50.639563500881195, 47.938174456357956, 44.371222257614136, 49.59031820297241, 50.70056922733784, 46.882328912615776, 40.174628645181656, 37.25250944495201, 38.76050032675266, 38.0540232360363, 38.30035641789436, 38.60927224159241, 39.37119595706463, 38.002053424715996, 38.061812818050385, 39.49413076043129, 40.60363322496414, 36.58695235848427, 40.37286400794983, 41.497212275862694, 46.1632326990366, 46.86825446784496, 45.66749610006809, 43.26213777065277, 43.120127990841866, 45.4827956110239, 53.08623321354389, 49.441711977124214, 49.66466881334782, 44.301986172795296, 49.995266273617744, 50.40871448814869, 54.113895669579506, 39.278211146593094, 33.01037907600403, 53.717953115701675, 49.502322524785995, 48.679111897945404, 47.43518024682999, 50.84027633070946, 48.82971301674843, 51.953821778297424, 48.25932562351227, 48.41864347457886, 48.59561137855053, 48.11825819313526, 47.3472073674202, 45.06231017410755, 45.800405368208885, 52.62372203171253, 44.04455378651619, 39.180446192622185, 37.744890823960304, 38.53760048747063, 38.84964354336262, 39.492215663194656, 40.3321073949337, 38.70373137295246, 38.33960451185703, 38.77389460802078, 37.32506275177002, 45.370032861828804, 51.71934776008129, 51.401897594332695, 43.466205820441246, 49.252159148454666, 51.92350700497627, 48.90827380120754, 47.7802587300539, 50.16003303229809, 51.489596888422966, 55.134969279170036, 51.25295698642731, 50.36590218544006, 45.80229386687279, 42.48807370662689, 45.45601464807987, 48.578972071409225, 53.80701273679733, 50.72507031261921, 44.705482721328735, 52.81776621937752, 54.37662877142429, 54.74884159862995, 55.029638931155205, 54.87552300095558, 50.24743974208832, 45.90790160000324, 48.065125644207, 55.204950124025345, 55.64401276409626, 59.460318982601166, 51.81420587003231, 7.579994760453701, 3.6659323750063777, 12.31931610032916, 1.9235267280600965, 0.14593446452636272, 0.05984939729387406, 20.285055711865425, 48.25256958603859, 33.34491692483425, 51.91148065030575, 25.074848793447018, 31.780024096369743, 46.289860904216766, 50.185199081897736, 44.05318692326546, 4.618363855406642, 0.11276133169303648, 0.02711902419832768, 0.032794507642393, 0.02808735065627843, 0.02812149130477337, 0.11880590187502094, 0.0507929617742775, 0.07352552027441561, 0.03982080190326087, 0.022916473826626316, 0.020265665189072024, 0.014343930652103154, 0.0780514781945385, 0.0776252627838403, 0.03319216521049384, 0.0369899241195526, 0.10964265646180138, 0.1004456210648641, 0.031128130067372695, 0.06336884340271354, 0.08098034173599444, 0.047190680852509104, 0.014486499076156178, 0.00802960092187277, 0.022666566728730686, 0.0796558678848669, 16.781275123357773, 61.2897764146328, 53.004283010959625, 50.17805926501751, 30.445435009896755, 23.99850904941559, 25.76351623982191, 29.776585400104523, 50.80478623509407, 39.309958443045616, 0.5455590505152941, 0.02372678034589626, 2.4874871224164963, 7.797515038400888, 11.901733707636595, 4.810166163370013, 31.50092527270317, 63.377600982785225, 57.788800075650215, 57.28948026895523, 51.476476192474365, 46.981868371367455, 44.006073251366615, 42.41302013397217, 43.40167388319969, 41.569408401846886, 44.096394404768944, 52.3828149586916, 54.498594626784325, 55.910800248384476, 51.47318936884403, 51.47233821451664, 51.896178871393204, 51.23906493186951, 48.58330003917217, 49.354605451226234, 49.42088149487972, 51.1180604249239, 50.31047835946083, 52.77397736907005, 51.99551694095135, 51.25632360577583, 46.4630214124918, 45.223774909973145, 51.80337265133858, 53.73733587563038, 49.13671374320984, 42.86886267364025, 39.283812046051025, 39.65724840760231, 40.503751784563065, 39.83590342104435, 39.002494141459465, 41.14135757088661, 40.62610521912575, 39.199011996388435, 40.15398435294628, 41.95606045424938, 38.08537535369396, 42.14047595858574, 44.00320440530777, 47.82640725374222, 45.994829535484314, 47.97640800476074, 44.70557391643524, 43.853237852454185, 45.20618565380573, 54.38882611691952, 50.153280794620514, 49.782979264855385, 48.02059583365917, 52.468120381236076, 50.34723378717899, 56.23405650258064, 41.54016897082329, 34.389807656407356, 55.82647517323494, 50.369257405400276, 49.789256528019905, 49.59736682474613, 52.61116370558739, 49.875891879200935, 54.27425466477871, 49.3265325576067, 50.31254164874554, 48.20135213434696, 48.05536776781082, 48.45792576670647, 47.587457075715065, 48.2039549946785, 53.49050872027874, 46.489703580737114, 40.578520372509956, 39.530468210577965, 39.494871720671654, 40.275935009121895, 40.96337512135506, 42.16152682900429, 40.489259362220764, 40.96459485590458, 40.065122321248055, 39.845657497644424, 48.4002410620451, 53.57806362211704, 52.11708381772041, 45.71199171245098, 50.91798976063728, 53.815539479255676, 50.785460472106934, 49.916538298130035, 53.007497638463974, 55.001889020204544, 56.021659299731255, 54.24000330269337, 51.883650943636894, 46.87510550022125, 44.550314247608185, 47.64536216855049, 51.40358850359917, 56.259150356054306, 53.33280958235264, 47.77054265141487, 54.66369956731796, 54.432804957032204, 57.19134673476219, 56.25289589166641, 57.70322106778622, 53.16846080124378, 48.921345099806786, 48.59782285988331, 56.932850405573845, 57.38482855260372, 62.041801661252975, 52.451416477561, 8.434310518205166, 4.651896581053734, 17.414638437330723, 4.582626298069954, 0.5109258089214563, 0.09854521093075164, 23.805583901703358, 54.485390335321426, 38.41500386595726, 54.48505215346813, 28.79303477704525, 37.36394986510277, 51.6520381718874, 54.854988902807236, 53.48855562508106, 7.195703806355596, 0.13620342419017106, 0.04136134833970573, 0.02121791672834661, 0.07448404852766544, 0.004040895764774177, 0.021326717433112208, 0.022807452332926914, 0.05367229809053242, 0.1144069254223723, 0.011294409669062588, 0.012098104580218205, 0.06397519289748743, 0.05309255087922793, 0.16326984681654721, 0.1437046966748312, 0.1269637153018266, 0.2081622410332784, 0.13587055611424148, 0.2421796484850347, 0.17743946460541338, 0.2944496733834967, 0.14277819951530546, 0.16634097264613956, 0.11993705367785878, 0.17843180510681123, 0.17537188570713624, 21.04597818106413, 68.65322649478912, 59.728782176971436, 57.24423989653587, 36.44027642905712, 32.664479836821556, 37.213683128356934, 39.83681537210941, 55.47950059175491, 45.07014915347099, 0.6712146266363561, 0.24479839077685028, 5.327458055689931, 13.668117374181747, 17.343055978417397, 17.43071347475052, 35.52203670144081, 64.25330579280853, 61.16056054830551, 58.27993132174015, 54.02360491454601, 47.50899128615856, 46.30018875002861, 44.218326061964035, 45.82608059048653, 43.84974204003811, 47.32445038855076, 54.296399876475334, 55.465901121497154, 56.713453978300095, 53.68049472570419, 53.26808385550976, 54.348863661289215, 53.97597447037697, 50.98680406808853, 51.142044737935066, 54.202066138386726, 52.91545897722244, 53.09365041553974, 56.78919531404972, 53.565615490078926, 52.96516411006451, 47.81869366765022, 44.984904527664185, 53.18996384739876, 55.281466618180275, 51.06391713023186, 44.06255342066288, 41.77107498049736, 42.11553029716015, 42.784545198082924, 41.922303065657616, 43.11798870563507, 43.44456598162651, 42.73514784872532, 39.645290449261665, 42.86852829158306, 42.2656374424696, 38.960783779621124, 44.275197610259056, 46.29835344851017, 48.50033529102802, 49.63117741048336, 51.65079563856125, 47.44396157562733, 46.310414001345634, 48.00726234912872, 55.71179732680321, 53.90738435089588, 52.93254666030407, 50.435123071074486, 54.15733493864536, 54.737430810928345, 57.76933752000332, 42.047920525074005, 37.53015294671059, 56.44622951745987, 53.02300460636616, 51.95273503661156, 51.71335928142071, 54.43199560046196, 51.35084353387356, 54.643541648983955, 51.188751831650734, 51.23194791376591, 51.87687210738659, 49.080594554543495, 50.390711054205894, 48.17777439951897, 49.02535691857338, 56.248301938176155, 48.90220172703266, 42.04844109714031, 41.20289146900177, 42.292338609695435, 43.521557450294495, 42.38036848604679, 44.933907464146614, 42.928986847400665, 41.965058371424675, 42.719906866550446, 41.30506418645382, 50.3886553645134, 55.91790206730366, 54.00317341089249, 45.55573269724846, 51.79712578654289, 54.89820018410683, 52.45686538517475, 53.78066875040531, 56.18405498564243, 56.13712750375271, 58.87719467282295, 55.45074753463268, 53.60669508576393, 50.19769661128521, 45.46943932771683, 50.28014458715916, 54.35747779905796, 58.32043334841728, 54.95466135442257, 49.77226763963699, 56.06224112212658, 58.511251509189606, 58.77130575478077, 59.204828292131424, 60.715296640992165, 55.916819125413895, 51.522104144096375, 53.64669553935528, 60.50355680286884, 61.43425606191158, 63.825456351041794, 56.38153038918972, 10.06699550896883, 10.865630954504013, 21.64602678269148, 4.191797794774175, 0.6225475505925715, 0.18227608554298058, 27.90065076202154, 62.006695345044136, 46.82392604649067, 65.41275277733803, 36.12315684556961, 43.46519887447357, 61.65929518640041, 62.315975949168205, 64.20205414295197, 11.54275557026267, 0.23085687949787825, 0.14744247891940176, 0.20456564496271312, 0.19482032570522279, 0.1036958271288313, 0.16428868199000135, 0.15891213377472013, 0.12468229397200048, 0.1908310889848508, 0.11893338800291531, 0.10218496288871393, 0.14464027772191912, 0.13405977515503764], [0.012850727671320783, 0.06387749657733366, 0.016166065543075092, 0.07567331791506149, 0.0489825704426039, 0.05407803022535518, 0.03642071540525649, 0.09915559770888649, 0.0830716396740172, 0.08876231673639268, 0.044460360368248075, 0.06425139799830504, 0.05366778212192003, 14.844177067279816, 50.06817676126957, 49.22181777656078, 46.03935554623604, 24.063360169529915, 13.927978780120611, 24.593566618859768, 39.35910500586033, 45.00154763460159, 31.891160532832146, 0.21765235054772347, 0.25209263374563307, 3.6206920025870204, 3.328477470204234, 14.058993849903345, 10.817837119102478, 48.12748409807682, 57.78734475374222, 51.16031035780907, 50.52077807486057, 44.95693422853947, 43.02990183234215, 44.40339893102646, 44.31898646056652, 41.67516052722931, 40.05248419940472, 42.21534714102745, 49.34295527637005, 51.92851133644581, 51.408809423446655, 51.77261710166931, 51.89021699130535, 49.796510338783264, 50.7096279412508, 50.826106891036034, 49.39996361732483, 50.20469583570957, 49.04543124139309, 48.827395141124725, 49.01297718286514, 51.83551512658596, 47.694227546453476, 45.49914613366127, 46.91599890589714, 47.688497453927994, 50.07371686398983, 47.37917885184288, 40.84215022623539, 36.64770729839802, 37.56294518709183, 37.13117055594921, 38.666603565216064, 35.861008912324905, 36.97216808795929, 36.83918662369251, 37.81588241457939, 38.862479254603386, 38.380475118756294, 38.1843676418066, 39.159102737903595, 43.47041979432106, 48.40345188975334, 45.1337843388319, 45.78642591834068, 42.53304049372673, 39.84999306499958, 42.40940272808075, 52.27233588695526, 48.798710480332375, 50.58130122721195, 48.60178604722023, 54.62336853146553, 50.622361823916435, 55.9738464653492, 43.308533281087875, 35.00905282795429, 54.32020179927349, 50.6513162702322, 48.887181133031845, 49.14001576602459, 50.619420781731606, 51.96544535458088, 50.3661073744297, 49.23034831881523, 50.020109340548515, 49.82902519404888, 52.362429052591324, 51.286330595612526, 51.4362895488739, 52.475681975483894, 47.83543176949024, 42.0305934548378, 37.52697251737118, 37.966662123799324, 37.00892351567745, 39.5641154050827, 40.014847218990326, 37.57495254278183, 38.27978812158108, 38.8443998247385, 38.447172939777374, 37.78783991932869, 46.46258823573589, 50.87237700819969, 50.67931316792965, 48.405298590660095, 47.937144711613655, 52.47128181159496, 49.12460759282112, 49.765279814600945, 49.59265887737274, 53.72643806040287, 52.53377325832844, 51.529418751597404, 46.29776827991009, 41.33710026741028, 39.25618752837181, 40.723680183291435, 46.32100783288479, 50.658592879772186, 51.04232668876648, 54.93845522403717, 54.18199181556702, 57.02614299952984, 54.82398636639118, 54.00623984634876, 48.39399039745331, 43.76141957938671, 43.62456992268562, 50.52338473498821, 57.50686660408974, 57.21970081329346, 58.70879530906677, 58.43825362622738, 17.574678249657154, 6.9759131502360106, 20.07086880505085, 6.77975295111537, 1.1037112190388143, 0.11896980518940836, 13.403385579586029, 49.54807586967945, 39.46959927678108, 46.7268792539835, 19.52052153646946, 21.720981560647488, 41.38558566570282, 50.427542477846146, 46.61295756697655, 5.4275575093925, 0.1164829202753026, 0.07462521985871717, 0.06645790694165044, 0.042830804450204596, 0.07858886732719839, 0.021493040148925502, 0.14659518375992775, 0.0039766100053384434, 0.04643629516067449, 0.061104146370780654, 0.07368355320068076, 0.04420437879161909, 0.02343135176488431, 0.0649108036304824, 0.04167839011643082, 0.04143301383010112, 0.00492869734443957, 0.06207104604982305, 0.05074332693766337, 0.015547540187981213, 0.056056848261505365, 0.040593351659481414, 0.034871508105425164, 0.025070193805731833, 0.04147506020672154, 0.18234920193208382, 18.962187096476555, 58.42157632112503, 54.94686797261238, 51.7154985666275, 29.537397734820843, 13.719542864710093, 24.24616266041994, 43.70191477239132, 51.774026826024055, 33.88450317084789, 0.13404193392489105, 0.38571151380892843, 3.345080679282546, 5.023500490933657, 6.428628517314792, 9.969249553978443, 48.71748223900795, 60.764424204826355, 54.805922135710716, 51.838965341448784, 47.13431999087334, 45.21852359175682, 47.0035158097744, 45.279821902513504, 41.59673273563385, 41.57614164054394, 43.724884539842606, 52.2779443860054, 53.67680512368679, 52.93864153325558, 53.28125774860382, 56.1738221347332, 52.340272441506386, 52.19383969902992, 51.869758889079094, 51.62432245910168, 50.428484827280045, 51.9125521928072, 51.36096239089966, 50.8460558205843, 52.012433633208275, 48.76552306115627, 47.25375898182392, 47.265416756272316, 48.285236433148384, 52.29223921895027, 50.994293466210365, 43.28657045960426, 37.552431151270866, 39.450813084840775, 38.636915758252144, 39.72265049815178, 38.352786004543304, 39.87716540694237, 38.999526500701904, 39.47413623332977, 40.81356056034565, 40.5954522639513, 40.16331285238266, 40.855962485075, 45.08442118763924, 50.97253583371639, 47.20981813967228, 48.19956623017788, 43.73653091490269, 40.779366195201874, 43.53990666568279, 53.28014820814133, 49.214864149689674, 51.30475200712681, 52.18616411089897, 54.47715997695923, 50.299899727106094, 57.204323038458824, 46.01109266281128, 37.19537191092968, 55.55655665695667, 53.708297833800316, 50.78204445540905, 50.815836042165756, 52.31298230588436, 52.83175706863403, 52.023882418870926, 50.0672610104084, 52.376176714897156, 51.49215415120125, 53.07632714509964, 53.50978508591652, 54.25434373319149, 54.165664091706276, 52.01754815876484, 45.29108829796314, 39.44537937641144, 38.53135742247105, 39.20099928975105, 41.49307429790497, 42.31857620179653, 39.880155846476555, 39.421151876449585, 39.9966461956501, 39.574861228466034, 40.320088639855385, 49.45794850587845, 53.77691835165024, 52.23281420767307, 47.737058848142624, 49.29370991885662, 54.68476563692093, 52.03249275684357, 50.60210891067982, 53.03119696676731, 53.59651543200016, 53.71880806982517, 53.259978890419006, 48.479542806744576, 43.44868116080761, 42.90130153298378, 42.02812738716602, 48.03360253572464, 52.3071002215147, 53.42714712023735, 55.365305319428444, 55.615187510848045, 58.153280317783356, 56.60319909453392, 54.932481944561005, 52.93185509741306, 46.61412790417671, 45.64104571938515, 52.43918113410473, 59.43354941904545, 59.47443522512913, 57.81066410243511, 59.83099669218063, 19.860232807695866, 2.52748710103333, 12.949612028896809, 6.286052567884326, 0.7282638153992593, 0.03499399586871732, 15.131255462765694, 56.174152716994286, 44.30582016706467, 51.85223422944546, 25.098935700953007, 27.869146652519703, 47.89987251162529, 58.819631561636925, 55.75764946639538, 10.149338990449905, 0.17785220261430368, 0.05588743821135722, 0.07780800922773778, 0.012201487606944283, 0.05491023381182458, 0.14811621542321518, 0.06660424362053163, 0.03934933403797913, 0.06222246644028928, 0.0563765357946977, 0.030094038193055894, 0.026523493361310102, 0.0456358926021494, 0.08168932283297181, 0.22304831334622577, 0.1733836275525391, 0.11411395520553924, 0.14239361858926713, 0.1239784708013758, 0.08205183228710666, 0.1401719549903646, 0.24337039474630728, 0.30605344916693866, 0.163753341184929, 0.13133714703144506, 0.25041915010660887, 24.72430430352688, 68.21229815483093, 61.58352345228195, 57.52356290817261, 36.07063986361027, 22.95286025851965, 35.76605960726738, 54.160690158605576, 57.166473269462585, 39.01868887245655, 0.3015205595875159, 0.4707653186051175, 5.624301452189684, 5.983574548736215, 22.574328370392323, 13.824834264814854, 53.10095362365246, 60.0879693031311, 54.42723825573921, 53.69092136621475, 50.21751634776592, 47.70112797617912, 48.33667807281017, 47.78379254043102, 44.52703669667244, 43.65032494068146, 46.2585885822773, 54.55132059752941, 54.84145402908325, 54.70867395401001, 55.24395503103733, 56.21668383479118, 55.365795493125916, 53.49876947700977, 55.59160217642784, 54.460152089595795, 53.75455655157566, 52.49434657394886, 53.75860333442688, 52.6678566634655, 55.18235273659229, 48.720685467123985, 48.680468425154686, 48.6315156519413, 49.61617961525917, 53.65169607102871, 53.57906676828861, 45.08815638720989, 40.99142141640186, 41.17474637925625, 41.34038709104061, 41.10648684203625, 38.77334363758564, 41.489848271012306, 40.964161679148674, 40.97636662423611, 41.781326830387115, 41.98937326669693, 42.433349043130875, 43.355019986629486, 48.02297070622444, 51.93994112312794, 49.0784552693367, 50.31803995370865, 46.76321290433407, 42.47801944613457, 45.41279956698418, 56.48478604853153, 50.93741811811924, 53.66312965750694, 52.47222416102886, 58.674247562885284, 54.63804714381695, 60.67336209118366, 47.343004792928696, 41.10479213297367, 59.113245606422424, 56.3751695305109, 53.05014654994011, 53.92310790717602, 54.9533998221159, 55.23024536669254, 54.085940569639206, 51.565444618463516, 54.17240872979164, 54.00004617869854, 56.7082292586565, 54.707195833325386, 56.556203216314316, 55.924665704369545, 53.82264129817486, 46.285289749503136, 41.479436829686165, 39.90418955683708, 41.089361160993576, 42.92066529393196, 43.93516145646572, 41.423785015940666, 42.3755769431591, 42.80669420957565, 42.74922229349613, 41.72015391290188, 50.87372973561287, 55.4623407125473, 54.89896014332771, 49.721494764089584, 49.54844444990158, 56.74066051840782, 55.088121592998505, 53.13372686505318, 55.20514391362667, 56.87262363731861, 57.42774344980717, 56.84236966073513, 52.33168490231037, 45.89536227285862, 43.76010864973068, 44.76167790591717, 51.375177428126335, 54.67749282717705, 54.22834932804108, 56.85076341032982, 58.337509632110596, 60.46249620616436, 60.0802481174469, 58.240284249186516, 55.590200051665306, 48.59519720077515, 49.673233553767204, 55.353282764554024, 62.95574001967907, 61.93854600191116, 61.9552993029356, 61.31399251520634, 23.47086176276207, 12.506257519125938, 32.76772029697895, 13.588754832744598, 1.9467983418144286, 0.16463617037516087, 17.31358475983143, 62.963377609848976, 52.967375591397285, 58.13270442187786, 28.516350723803043, 32.06414245069027, 56.47656328976154, 65.74362382292747, 65.50954878330231, 16.07593797147274, 0.396104579558596, 0.21487676276592538, 0.1547562997438945, 0.12119769540731795, 0.1434011582750827, 0.1648182192002423, 0.21736346214311197, 0.08935751917306334, 0.25349285861011595, 0.23361985076917335, 0.16150904208188877, 0.13856383971869946, 0.12511506996816024], [0.0638832853292115, 0.026645094258128665, 0.015785122996021528, 0.07018460892140865, 0.01870810316177085, 0.03173547775077168, 0.047391142361448146, 0.003935166159863002, 0.04768234626681078, 0.023036852035147604, 0.04418524251377676, 0.025371763658768032, 0.1585282207815908, 21.507199332118034, 50.53147450089455, 40.79111136496067, 36.884301602840424, 18.991574719548225, 30.04614483565092, 43.8296715170145, 35.77622786164284, 41.04131653904915, 27.4445878341794, 0.13088252220768481, 0.8159999793861061, 1.7164948373101652, 10.368770565837622, 11.296041458845139, 21.159286201000214, 57.59066730737686, 58.2031374424696, 52.9534987360239, 45.7824931293726, 43.4345269203186, 48.79703477025032, 48.746402487158775, 49.71723899245262, 46.04264236986637, 41.66716195642948, 41.447271555662155, 47.43043810129166, 53.24260242283344, 51.14100739359856, 51.88449829816818, 51.44806891679764, 50.18632382154465, 50.02962023019791, 49.575366005301476, 51.79652161896229, 50.396517142653465, 51.17587052285671, 51.979975774884224, 51.67645186185837, 50.82538492977619, 49.892888367176056, 43.505951687693596, 44.82659362256527, 47.605164125561714, 49.647638127207756, 48.85208621621132, 41.06368973851204, 36.80560402572155, 38.702371045947075, 37.38245867192745, 39.586336612701416, 37.963892072439194, 35.81079080700874, 38.21062043309212, 36.9436202198267, 38.099176213145256, 36.04040868580341, 37.80769765377045, 38.42560529708862, 46.10953398048878, 49.08148750662804, 47.90157862007618, 47.408870458602905, 44.57749418914318, 39.119056686758995, 43.42901721596718, 45.97322389483452, 48.19345995783806, 52.63654634356499, 50.26925057172775, 49.784609377384186, 47.372400015592575, 52.81589671969414, 49.37902674078941, 38.0168042331934, 51.57655522227287, 49.43291924893856, 47.08136223256588, 50.1437509059906, 51.51607766747475, 47.42119699716568, 47.36575037240982, 53.11870627105236, 48.76081511378288, 49.944972172379494, 50.64053624868393, 48.33431079983711, 50.63169412314892, 46.77674397826195, 42.73285277187824, 38.773393034935, 38.23417916893959, 38.93201932311058, 39.31964412331581, 37.961285412311554, 39.33814153075218, 39.20267499983311, 38.12487043440342, 39.91186134517193, 38.50328832864761, 37.39491060376167, 42.92055509984493, 50.771690011024475, 47.85161130130291, 50.78984923660755, 49.32066947221756, 50.7766867429018, 50.785745456814766, 48.89164589345455, 47.8850457072258, 49.55349437892437, 47.086769342422485, 45.221058055758476, 40.832593739032745, 41.67737580835819, 42.36052595078945, 43.35614092648029, 41.9439847022295, 46.76266573369503, 50.806686133146286, 54.04125116765499, 55.67282661795616, 51.699877604842186, 47.12954364717007, 43.079359978437424, 41.9599324464798, 43.6470191180706, 42.916063740849495, 51.515253111720085, 55.276621878147125, 59.74052734673023, 55.66376410424709, 63.29831823706627, 27.178187929093838, 3.545513986609876, 4.788975650444627, 1.0865369718521833, 0.750046621542424, 0.13465748605085537, 8.650784902274609, 47.41705521941185, 34.82823193073273, 43.04348610341549, 28.140159510076046, 20.66349260509014, 44.35441575944424, 44.58096720278263, 48.41381773352623, 13.560133818536997, 0.0850488398282323, 0.11270457223872654, 0.07742464542388916, 0.061198169059935026, 0.007218379241749062, 0.05674629603163339, 0.09771213532076217, 0.10433108327561058, 0.020986088347854093, 0.02020128202275373, 0.02893922857765574, 0.034729761609924026, 0.0926090833672788, 0.015305336582969176, 0.040407766500720754, 0.041588690437492914, 0.005299163085510372, 0.06241540628252551, 0.012194555947644403, 0.08754699796554632, 0.031198222204693593, 0.03315104651846923, 0.025591046032786835, 0.04406065076182131, 0.06844712246675044, 0.18556604103650898, 28.327706046402454, 57.966022565960884, 50.00848576426506, 43.606315702199936, 30.314604230225086, 27.86880847066641, 44.07743722200394, 44.55628752708435, 46.64695434272289, 30.626423098146915, 0.11157843735418282, 0.9340930706821382, 10.849563516676426, 8.602972067892551, 3.8461215561255813, 24.771720059216022, 59.72612611949444, 60.742377787828445, 54.1354975104332, 47.40969121456146, 45.72396866977215, 50.45041345059872, 50.16328565776348, 52.67104469239712, 46.58121407032013, 43.65786753594875, 42.404254004359245, 49.32068847119808, 53.92927497625351, 52.152475118637085, 52.0600488781929, 52.27738581597805, 50.52044369280338, 52.800021171569824, 51.38601444661617, 54.34023052453995, 51.90564416348934, 54.66186806559563, 52.3791329562664, 54.45597231388092, 52.05339543521404, 49.539571925997734, 44.60890710353851, 46.457127928733826, 48.21143299341202, 52.477038502693176, 49.724720790982246, 41.93580374121666, 38.237329199910164, 39.545937180519104, 39.37183052301407, 41.62392407655716, 39.29011590778828, 38.98984842002392, 38.44336934387684, 38.71892295777798, 39.87035237252712, 38.91750030219555, 39.39144127070904, 41.21242135763168, 47.608766332268715, 50.11851646006107, 50.3450945019722, 48.384734094142914, 45.91148100793362, 41.164023354649544, 44.82440114021301, 47.30539061129093, 49.80227842926979, 54.59825187921524, 51.89438156783581, 53.059763833880424, 50.876598581671715, 54.488243982195854, 50.15008896589279, 39.430894553661346, 54.87183719873428, 52.03367829322815, 49.368987679481506, 51.34292855858803, 52.6211229711771, 50.025862231850624, 48.30605171620846, 55.00224620103836, 51.247397884726524, 52.80162088572979, 52.38884523510933, 50.79424940049648, 52.654287591576576, 49.87173110246658, 44.90078464150429, 41.00906386971474, 40.16226030886173, 41.04445897042751, 40.560760125517845, 39.63090442121029, 41.28881625831127, 39.8088488727808, 41.23620048165321, 41.69817589223385, 39.2777855694294, 40.05028411746025, 45.18723987042904, 51.05944097042084, 50.92777043581009, 50.77810786664486, 50.07538117468357, 52.05605149269104, 54.39188115298748, 49.03783544898033, 50.39976216852665, 51.29201129078865, 50.943786576390266, 46.8852623552084, 42.450748309493065, 43.06007981300354, 43.956269323825836, 44.855506271123886, 44.713963866233826, 49.24927890300751, 54.923537224531174, 55.48010095953941, 57.021252661943436, 52.56911136209965, 51.07001580297947, 45.107881128787994, 44.20234031975269, 45.700485929846764, 46.311280354857445, 52.98002131283283, 58.01968328654766, 61.145608350634575, 59.600892439484596, 61.370047107338905, 32.8625176101923, 2.1328060794621706, 2.382639111019671, 5.677674813196063, 1.1852737236768007, 0.1230627644690685, 9.928502440452576, 50.90166963636875, 42.48335435986519, 48.48549708724022, 30.642482936382294, 26.503959707915783, 50.3348084539175, 52.803030610084534, 59.8133010417223, 19.905589073896408, 0.08939913139329292, 0.059504484161152504, 0.06436614887206815, 0.003961338461522246, 0.036663137943833135, 0.024289695647894405, 0.014666461538581643, 0.03583540579711553, 0.02423357444058638, 0.04636521225620527, 0.08368373339180835, 0.11793465018854477, 0.08767659179284237, 0.22396102140191942, 0.1347079817787744, 0.2298383560264483, 0.23779584153089672, 0.18935526895802468, 0.13900023739552125, 0.11968447855906561, 0.09105057324632071, 0.11428755839006044, 0.12352231715340167, 0.16645453608362004, 0.1483222801471129, 0.6902139040175825, 35.042266845703125, 64.96692270040512, 55.93819297850132, 50.12978285551071, 30.36118783056736, 41.98791794478893, 57.318305522203445, 49.39087450504303, 50.60753881931305, 34.77932095527649, 0.13601285550976172, 1.2575539201498032, 15.423105452209711, 20.928940661251545, 17.55951516330242, 24.136738032102585, 62.66336850821972, 62.70069770514965, 57.59931184351444, 49.52012076973915, 48.39358001947403, 53.439747244119644, 53.63458938896656, 55.749654695391655, 49.006015956401825, 45.05833938717842, 44.752079620957375, 52.11071535944939, 57.54198431968689, 54.70838896930218, 53.665257543325424, 52.40405961871147, 51.512756645679474, 52.68830716609955, 51.77721485495567, 55.38969241082668, 54.67884175479412, 55.379831939935684, 56.42571821808815, 55.19748352468014, 53.59599865972996, 50.586867928504944, 44.42813940346241, 46.936806589365005, 52.25850462913513, 55.650654807686806, 54.00169529020786, 45.31247355043888, 40.846656784415245, 42.818667367100716, 40.14844425022602, 44.21267956495285, 40.90888224542141, 40.2055399864912, 40.49067668616772, 39.83393892645836, 42.30837754905224, 40.46614520251751, 42.11910970509052, 42.99903988838196, 50.179332196712494, 53.048634231090546, 52.35208600759506, 50.69063276052475, 49.229622557759285, 44.01674687862396, 46.96859568357468, 48.82508106529713, 51.41534127295017, 56.42015911638737, 54.07983809709549, 53.728182166814804, 53.851717337965965, 58.250805884599686, 53.14073748886585, 40.339528396725655, 55.43321907520294, 53.976339250802994, 50.90483866631985, 53.65553766489029, 53.36535483598709, 51.265089735388756, 49.739357605576515, 57.64174796640873, 52.68619067966938, 55.310356467962265, 54.29620988667011, 53.18626284599304, 55.29695078730583, 51.47596322000027, 44.77880738675594, 43.6462477594614, 41.696937158703804, 44.37626078724861, 44.83254790306091, 41.21101163327694, 44.403421729803085, 42.2764440625906, 42.841450944542885, 43.714419901371, 41.729258224368095, 42.2059578448534, 46.99553243815899, 53.436627611517906, 53.2821810990572, 52.94447802007198, 51.838684156537056, 54.062442630529404, 56.14825330674648, 51.89372420310974, 52.73232400417328, 54.63161788880825, 51.927470192313194, 49.027264416217804, 45.42359858751297, 46.32305972278118, 47.465612813830376, 46.61916643381119, 47.29540854692459, 51.95452094078064, 55.85555501282215, 58.762220442295074, 61.187782287597656, 56.03534236550331, 53.36974740028381, 46.440595015883446, 47.181825041770935, 46.73835463821888, 49.78300966322422, 55.54168425500393, 62.11630046367645, 63.675159215927124, 61.61688566207886, 61.62473604083061, 36.4414581656456, 7.90393877774477, 13.359467536211014, 7.120342925190926, 1.6499004419893026, 0.17024943401338533, 11.542967408895493, 60.36242477595806, 48.430844619870186, 57.73571692407131, 37.16867834329605, 33.44034880399704, 58.333614841103554, 60.30152164399624, 69.1866646707058, 27.134991846978664, 0.22101775277405977, 0.284782160888426, 0.1895409543067217, 0.18672928330488503, 0.0668112063431181, 0.14299140369985253, 0.24235372664406896, 0.16901261522434652, 0.18367947195656598, 0.1702898513758555, 0.15265171736245975, 0.20493409159826115, 0.23343665903666988], [0.08148688721121289, 0.060063915079808794, 0.02127392104739556, 0.042029737669508904, 0.08199240852263756, 0.05665409531502519, 0.0751335613313131, 0.06765972604625858, 0.023921816755319014, 0.03320697105664294, 0.03926748628146015, 0.027577923792705406, 0.8747013669926673, 28.67503970861435, 49.8112041503191, 39.48585860431194, 24.698478989303112, 10.336451400071383, 29.379375614225864, 54.81726452708244, 38.44330094754696, 43.40738117694855, 23.830879144370556, 0.18778124795062467, 0.6515072809997946, 1.1059792223386467, 3.9712058566510677, 2.4213131982833147, 18.34085203707218, 58.90194654464722, 53.77442568540573, 49.52638283371925, 48.84689189493656, 50.07671870291233, 50.43118268251419, 54.30851362645626, 53.49806651473045, 50.375747457146645, 44.70032639801502, 41.55732125043869, 47.655553221702576, 52.56925195455551, 52.51586861908436, 48.37708130478859, 49.510579481720924, 43.399344608187675, 50.9828294813633, 48.110552206635475, 47.96555958688259, 48.686494901776314, 48.439660146832466, 46.16149619221687, 47.256601229310036, 44.93496000766754, 45.749271512031555, 46.292311772704124, 48.95416013896465, 48.406001552939415, 48.905746936798096, 43.92406225204468, 38.57847109436989, 36.68678820133209, 36.37636385858059, 38.16608302295208, 38.3840811252594, 38.0865228921175, 38.22022631764412, 35.742645263671875, 37.08057627081871, 37.11466424167156, 36.21328420937061, 37.47143089771271, 40.77892541885376, 49.439405500888824, 50.64877040684223, 47.01454661786556, 48.34523141384125, 43.60289208590984, 38.29859331250191, 40.361669808626175, 43.15298102796078, 46.84630684554577, 47.13001102209091, 46.358204036951065, 44.06186565756798, 44.67390641570091, 53.70138980448246, 49.19226296246052, 38.51841911673546, 53.79866078495979, 50.06321802735329, 50.38644768297672, 50.26364207267761, 50.85631147027016, 47.520690858364105, 51.65896140038967, 49.774102941155434, 48.82559783756733, 49.035969749093056, 43.81354138255119, 42.730538696050644, 40.30307695269585, 38.133423775434494, 35.5844521522522, 37.75388494133949, 38.20670664310455, 36.97786018252373, 37.596653178334236, 37.600065395236015, 38.68261970579624, 39.57719810307026, 37.82020278275013, 37.68489584326744, 37.62509845197201, 39.89094726741314, 39.706809148192406, 47.798664942383766, 50.11045329272747, 49.45214621722698, 48.55420120060444, 49.80233162641525, 51.507174745202065, 50.31931668519974, 46.164258643984795, 44.209518134593964, 42.80582405626774, 42.85906679928303, 44.19129431247711, 44.52845402061939, 43.983221277594566, 42.26706236600876, 40.367346704006195, 42.10294917225838, 46.30957044661045, 49.86360713839531, 47.94276840984821, 43.59701760113239, 42.385148629546165, 39.89740312099457, 42.31912337243557, 41.11817881464958, 41.75333373248577, 47.551681995391846, 55.68848177790642, 56.733323112130165, 57.57853455841541, 59.52064074575901, 48.41650418937206, 4.855276392772794, 1.0552636999636889, 2.5339230056852102, 0.4389612330123782, 0.08633011326310225, 5.42796028777957, 50.10315768420696, 38.712087124586105, 40.637079030275345, 45.635418221354485, 23.994562961161137, 35.905823707580566, 45.30150353908539, 52.16077387332916, 17.914545312523842, 0.11458006847533397, 0.0449756743182661, 0.08014767430722713, 0.032229584830929525, 0.0693449578830041, 0.07083410688210279, 0.03683880429889541, 0.05130098041263409, 0.18504901643609628, 0.04236873588524759, 0.025409846966795158, 0.04887265837169252, 0.06428000779123977, 0.05759422943810932, 0.06653248536167666, 0.050792015535989776, 0.06920682193594985, 0.1060173541191034, 0.010856034168682527, 0.060338335315464064, 0.03764623870665673, 0.04124709470488597, 0.08878245862433687, 0.014138100632408168, 0.0340818110271357, 1.4921079715713859, 37.835067585110664, 57.97662019729614, 45.152661725878716, 28.678923100233078, 17.33970645815134, 31.235165633261204, 59.65845935046673, 43.88992488384247, 48.66205081343651, 26.15221068263054, 0.13001115177758038, 0.6604311021510512, 5.767218433320522, 14.070215597748756, 5.825712019577622, 18.939992487430573, 57.36460603773594, 57.75407373905182, 52.290373519062996, 50.19881755113602, 52.54459507763386, 51.75036169588566, 55.59900037944317, 55.83681061863899, 54.42477598786354, 46.27359017729759, 43.603682443499565, 48.85817728936672, 53.90001654624939, 53.85201372206211, 50.504564344882965, 49.43905971944332, 44.12485867738724, 51.05489641427994, 48.97550359368324, 48.712762892246246, 49.552529230713844, 49.40768480300903, 46.81856833398342, 47.50882409512997, 46.758485957980156, 45.39468973875046, 46.580165326595306, 49.000681042671204, 50.96376970410347, 50.70653110742569, 46.411268189549446, 40.64829982817173, 38.20055477321148, 39.41757246851921, 39.916086718440056, 40.768365785479546, 39.54331152141094, 39.59229089319706, 38.19014713168144, 38.231515511870384, 38.35976243019104, 37.47143089771271, 38.3919733017683, 42.02691525220871, 50.899074375629425, 52.51055270433426, 50.6899905949831, 49.07967500388622, 46.00539296865463, 41.203358843922615, 42.62087658047676, 46.26614257693291, 49.00758147239685, 49.672230407595634, 48.01974467933178, 47.11858883500099, 48.07258464396, 56.33619122207165, 50.23512080311775, 41.4418226480484, 54.86674167215824, 53.068176582455635, 52.29443550109863, 52.47465223073959, 50.56219205260277, 49.17583264410496, 52.012775614857674, 51.40055626630783, 52.07864128053188, 51.947373524308205, 47.04637371003628, 44.65684153139591, 43.69738921523094, 40.76683446764946, 37.10426039993763, 39.8484655469656, 41.372100189328194, 40.40774613618851, 41.4256127178669, 38.51602904498577, 39.29455026984215, 41.2800919264555, 38.95785413682461, 39.75236490368843, 41.020809039473534, 41.56055107712746, 43.250248208642006, 48.96582171320915, 51.77452079951763, 50.540973991155624, 49.70403470098972, 51.05118781328201, 53.143252953886986, 53.18111792206764, 48.580754175782204, 46.53751641511917, 45.70690378546715, 45.42849272489548, 45.855844393372536, 45.513615757226944, 47.23253712058067, 45.015698075294495, 42.50663571059704, 42.520987540483475, 48.46213974058628, 51.073458418250084, 49.97844837605953, 45.88466964662075, 43.83068606257439, 42.32742592692375, 44.37216080725193, 44.22402195632458, 44.17318448424339, 49.905545487999916, 57.671929746866226, 58.80518853664398, 59.93235245347023, 62.64167547225952, 49.59850676357746, 6.209966400638223, 0.6748094118665904, 3.1703358935192227, 1.3176111225038767, 0.08266310222097673, 5.860205618664622, 54.385007321834564, 45.83842612802982, 50.31162589788437, 46.266989931464195, 27.34515856951475, 42.80760236084461, 50.10217733681202, 62.84577392041683, 24.508044607937336, 0.03461659522145055, 0.046993002397357486, 0.047737580607645214, 0.07985449628904462, 0.06816581881139427, 0.07768852345179766, 0.029189156084612478, 0.018033333217317704, 0.025342125991301145, 0.042129656721954234, 0.01906648070871597, 0.05186856382351834, 0.05835775467858184, 0.220674435258843, 0.23204523604363203, 0.15977326256688684, 0.2627803914947435, 0.2502889180323109, 0.15978749695932493, 0.21009633725043386, 0.12121068299165927, 0.08434328745352104, 0.15730602230178192, 0.1669442793354392, 0.12187648593680933, 2.059216140769422, 46.822858303785324, 65.16964942216873, 53.86273294687271, 35.460590198636055, 18.95349506288767, 37.571844309568405, 65.82775130867958, 48.78457523882389, 56.57436244189739, 28.59728828072548, 0.21933021285803989, 0.9264817228540778, 3.4217969002202153, 10.918120387941599, 6.50426915846765, 20.828861631453037, 60.92201694846153, 58.191217482089996, 54.035939052700996, 53.394487872719765, 53.8717270642519, 55.07072612643242, 59.61694277822971, 58.880173712968826, 56.28355644643307, 49.139616787433624, 45.58790177106857, 51.89656265079975, 56.3761954754591, 55.70925146341324, 49.73053827881813, 52.576114386320114, 46.79560996592045, 50.98340705037117, 49.9608439207077, 48.65884378552437, 49.39474269747734, 49.40264627337456, 46.80879905819893, 47.66791395843029, 46.593069434165955, 47.103499844670296, 46.87593385577202, 51.03559345006943, 51.666048020124435, 53.14320355653763, 49.086108058691025, 43.337567523121834, 40.64835302531719, 41.632032841444016, 42.05518573522568, 42.913920655846596, 41.56211279332638, 41.66042871773243, 41.120755076408386, 40.40832370519638, 40.43589122593403, 39.193840473890305, 40.575689524412155, 45.386668369174004, 53.61497484147549, 54.98565249145031, 53.77477526664734, 52.54704974591732, 47.60054737329483, 43.28570790588856, 45.416743755340576, 47.5199992954731, 51.46433584392071, 51.1938663572073, 51.54405176639557, 48.052213937044144, 49.58458811044693, 58.74058440327644, 52.91154898703098, 43.828463181853294, 58.51564407348633, 53.0147248506546, 55.843836441636086, 55.14323763549328, 52.93668083846569, 50.38281887769699, 53.872228637337685, 51.936912685632706, 54.637735560536385, 54.43624757230282, 49.63310770690441, 47.57911652326584, 46.40964947640896, 41.65896199643612, 37.89182133972645, 41.78795367479324, 43.74935902655125, 41.76172748208046, 43.055907636880875, 41.5390632301569, 41.322117671370506, 42.78288468718529, 41.73895910382271, 43.794318214058876, 42.42626242339611, 44.84086565673351, 44.43717911839485, 52.57325693964958, 53.858363181352615, 53.02893228828907, 48.98425452411175, 52.28888399899006, 54.61630471050739, 55.471407026052475, 50.09332001209259, 48.14579151570797, 49.09273870289326, 47.58490741252899, 48.64033117890358, 48.16018134355545, 49.899507611989975, 48.682945892214775, 44.92405079305172, 46.66886016726494, 51.25696197152138, 53.33811029791832, 52.64802172780037, 49.31519016623497, 46.01820968091488, 44.600403159856796, 46.988111436367035, 45.78457161784172, 46.98194056749344, 52.879368513822556, 63.060610592365265, 61.65022127330303, 62.314235642552376, 64.4250413775444, 51.98643922805786, 8.27943367883563, 3.814347186125815, 8.623278178274632, 1.2620862456969917, 0.12567551020765677, 6.13010086119175, 62.93191149830818, 52.58066654205322, 57.49599538743496, 53.749544620513916, 34.219272807240486, 49.75351944565773, 61.0265189409256, 73.00784602761269, 35.26232823729515, 0.2624583290889859, 0.10533497159485705, 0.21626400004606694, 0.1492140447953716, 0.18460810650140047, 0.18302077136468142, 0.1329829782480374, 0.2746230794582516, 0.2325144366477616, 0.15777933440404013, 0.08018507112865336, 0.18016871268628165, 0.13696854875888675], [0.02369167861616006, 0.017898815240187105, 0.021177308262849692, 0.016715067431505304, 0.01668776381848147, 0.06967446402995847, 0.027042466099373996, 0.059800111266667955, 0.059243778814561665, 0.04141759571211878, 0.05861242636456154, 0.06565532617969438, 1.3006532262079418, 32.99019455909729, 46.959392577409744, 45.59181176126003, 26.61521203815937, 21.294492445886135, 49.50898736715317, 65.70073932409286, 36.61608159542084, 45.08890114724636, 21.083561964333057, 0.17327683250186965, 0.6820049195084721, 13.40812012553215, 9.754121247678995, 1.0826344625093043, 21.673267520964146, 56.95477902889252, 57.19744920730591, 51.69358514249325, 51.72562502324581, 51.31044030189514, 54.95892092585564, 50.30364632606506, 49.81425918638706, 52.03482583165169, 48.008873462677, 39.89873304963112, 46.817078813910484, 47.734744772315025, 54.10196051001549, 46.71638421714306, 42.92624719440937, 43.86996455490589, 47.333919480443, 49.585921838879585, 47.95886054635048, 50.197753608226776, 49.6376446634531, 49.49763737618923, 48.74637968838215, 46.46886169910431, 47.47582286596298, 48.586130887269974, 50.68894185125828, 48.04184049367905, 46.45712032914162, 40.5940767377615, 35.686727464199066, 35.64711458981037, 36.67827665805817, 36.94459296762943, 37.63434715569019, 38.81450682878494, 35.17642244696617, 35.39614945650101, 37.53440111875534, 37.1967626363039, 37.653608322143555, 37.423458471894264, 42.40504816174507, 52.23822131752968, 50.004021003842354, 49.98867742717266, 47.27529242634773, 42.47747227549553, 40.23939996957779, 39.10466305911541, 43.170634880661964, 40.12830153107643, 44.23216111958027, 41.104803532361984, 42.076973766088486, 48.27902376651764, 53.880702182650566, 48.16315658390522, 35.90217590332031, 52.78268650174141, 49.618782475590706, 48.720461279153824, 49.877461194992065, 52.39530868828297, 51.179723516106606, 49.14064273238182, 44.89388421177864, 52.187144458293915, 50.460410714149475, 48.72936800122261, 45.63035309314728, 44.97552663087845, 42.37104378640652, 39.887033477425575, 36.46403655409813, 37.39920437335968, 37.49857284128666, 37.23171316087246, 37.62005612254143, 37.713523507118225, 39.05784957110882, 37.45942734181881, 37.885422483086586, 37.24471606314182, 37.680233493447304, 37.44111232459545, 40.97776114940643, 48.941856399178505, 48.742800280451775, 50.60684345662594, 47.73419000208378, 50.40702357888222, 50.656388998031616, 49.5933922380209, 46.72273747622967, 50.382051318883896, 49.15518835186958, 50.03966689109802, 46.74143627285957, 46.691727340221405, 44.603310003876686, 39.914749190211296, 38.3274831622839, 41.51576288044453, 40.29204234480858, 40.008999332785606, 39.62652325630188, 42.90677323937416, 42.5735767185688, 45.18948175013065, 44.222741425037384, 44.35092754662037, 43.60127717256546, 51.4519789069891, 55.804227367043495, 59.6303104609251, 57.30192460119724, 58.05143818259239, 18.827769309282303, 0.5460871034301817, 4.16483111679554, 1.2070573610253632, 0.1577968045603484, 2.856514770537615, 43.919035121798515, 49.59582410752773, 37.44968846440315, 51.458681747317314, 27.007341496646404, 33.85442018508911, 45.996064469218254, 47.06708639860153, 20.74272595345974, 0.9344460361171514, 0.03221689039492048, 0.06528535814140923, 0.003676956748677185, 0.1355361146852374, 0.08202038006857038, 0.012416521185514284, 0.09073634049855173, 0.1192371713113971, 0.038236071704886854, 0.03533174727635924, 0.04567836942442227, 0.1411849568830803, 0.03379580957698636, 0.05009240034269169, 0.020290041029511485, 0.04726297716842964, 0.029877011947974097, 0.08506835089065135, 0.02271702906000428, 0.061669774222536944, 0.05140121116710361, 0.0018062328695123142, 0.07312462694244459, 0.059194626373937353, 2.666453244164586, 42.19963498413563, 56.42814628779888, 51.42335124313831, 32.833711355924606, 20.059915892779827, 48.197263553738594, 71.90384566783905, 42.60632336139679, 49.06781584024429, 22.774931006133556, 0.2518925507320091, 1.0670030512847006, 5.523066809400916, 8.52670731022954, 4.066528966650367, 22.231898345053196, 59.267908707261086, 58.67831714451313, 53.239843770861626, 52.88888320326805, 54.761415123939514, 56.43233746290207, 53.87060232460499, 50.83727449178696, 54.022430777549744, 49.2361544072628, 41.804969161748886, 48.50651375949383, 50.531345307826996, 54.96742106974125, 48.30140456557274, 46.862057000398636, 47.819408029317856, 48.49642910063267, 49.16814565658569, 47.298927158117294, 49.866673573851585, 50.32539635896683, 50.19220970571041, 48.39789278805256, 48.27613212168217, 48.032724782824516, 50.58997616171837, 52.60068006813526, 50.58509722352028, 48.51442493498325, 43.80733631551266, 37.166786044836044, 37.378670275211334, 37.81761512160301, 38.78258474171162, 39.4251112639904, 38.29115331172943, 37.36279472708702, 37.78152845799923, 40.023370161652565, 38.60074169933796, 38.269186690449715, 39.05653104186058, 42.910823822021484, 53.28919552266598, 52.122221142053604, 50.4703775793314, 48.61337162554264, 46.059384271502495, 41.943106949329376, 42.91625753045082, 45.320924296975136, 43.64866442978382, 45.81503838300705, 44.057986065745354, 44.22125190496445, 50.998374447226524, 55.306085497140884, 50.049854144454, 39.62938830256462, 54.24137882888317, 52.3987703025341, 50.39712890982628, 51.7194389551878, 54.33090582489967, 52.06279993057251, 51.38015516102314, 47.32730783522129, 53.888351172208786, 51.721665635704994, 49.84300084412098, 47.36520320177078, 47.46438927948475, 44.60261084139347, 42.361042723059654, 37.952694073319435, 38.412674590945244, 38.522215113043785, 38.84000726044178, 38.78562457859516, 39.352120980620384, 41.55934654176235, 40.02919524908066, 38.94888661801815, 39.829956740140915, 39.52765256166458, 40.79627148807049, 43.08510147035122, 49.82337489724159, 51.1298967897892, 51.16585426032543, 49.705759808421135, 51.76116831600666, 54.666830599308014, 52.65598610043526, 49.01852868497372, 51.49987913668156, 51.935556158423424, 52.098810598254204, 49.604863822460175, 49.08500611782074, 46.888689771294594, 41.28299497067928, 39.91976112127304, 44.32167671620846, 42.87958949804306, 43.22182573378086, 43.53177510201931, 44.06663440167904, 45.23717299103737, 46.554060727357864, 46.760104671120644, 45.462310910224915, 44.690082147717476, 54.04823139309883, 59.08633545041084, 62.72770285606384, 59.25790764391422, 57.997579872608185, 21.194916889071465, 0.4431174084311351, 4.183390270918608, 1.4843239705078304, 0.07398123605526052, 2.753760921768844, 46.78020939230919, 51.8945449590683, 45.2188503742218, 51.669650226831436, 30.15465371310711, 39.459355026483536, 52.26686418056488, 54.969115778803825, 31.486668437719345, 0.5383680551312864, 0.052529568783938885, 0.07906484373961575, 0.05413747625425458, 0.06988288878346793, 0.023275717830983922, 0.04758108021633234, 0.0280250343712396, 0.03469812756520696, 0.0765779810899403, 0.016627918885205872, 0.1101785761420615, 0.0534995854832232, 0.08744027712964453, 0.08121026650769636, 0.1236860200879164, 0.07212108001112938, 0.1023869235359598, 0.2858006546739489, 0.17091514047933742, 0.15786885225679725, 0.186380666855257, 0.15792194550158456, 0.18122539739124477, 0.14258592389523983, 3.9891660679131746, 50.08578881621361, 63.75779718160629, 60.62044233083725, 37.989833280444145, 34.057587683200836, 59.049583822488785, 74.12883907556534, 45.79266518354416, 57.74254895746708, 26.24259263277054, 0.23630836978554726, 1.650646983180195, 24.343340545892715, 19.083809070289135, 2.884530429728329, 24.113688468933105, 62.20538668334484, 61.644297391176224, 55.60171343386173, 55.68758502602577, 56.60428203642368, 57.709642723202705, 55.60805909335613, 52.909793481230736, 56.08252823352814, 51.33823201060295, 43.80773529410362, 49.78328324854374, 52.41083845496178, 56.7284631729126, 49.252132549881935, 48.62635552883148, 47.98127934336662, 49.693695455789566, 49.20766733586788, 48.417594730854034, 53.23829725384712, 52.981233447790146, 53.13575975596905, 50.67307390272617, 47.91577845811844, 49.71411556005478, 52.299204245209694, 55.40867619216442, 51.257277354598045, 50.49770951271057, 45.31721569597721, 39.548673033714294, 40.76583132147789, 38.92141029238701, 40.95658868551254, 42.03892640769482, 41.72821708023548, 37.23353326320648, 38.266374841332436, 42.19865083694458, 39.17455270886421, 40.544759184122086, 41.25356175005436, 45.70081651210785, 56.67416408658028, 55.06729871034622, 53.34657624363899, 50.065798088908195, 47.59458929300308, 44.97383572161198, 43.7983687967062, 48.10283102095127, 45.75513079762459, 49.648238494992256, 46.788789331912994, 47.45634891092777, 52.66068644821644, 56.86542682349682, 51.4590997248888, 42.022701278328896, 56.01667396724224, 53.85141335427761, 52.396661415696144, 55.12780286371708, 54.75376233458519, 54.38745059072971, 51.33453480899334, 48.32885429263115, 57.11726970970631, 54.63237404823303, 51.75787389278412, 51.579317674040794, 48.470795676112175, 47.41367720067501, 44.191613495349884, 40.55747330188751, 40.191761925816536, 40.92672608792782, 41.11143037676811, 40.3823558986187, 40.286388248205185, 43.37875731289387, 41.442932188510895, 43.49942743778229, 41.37829005718231, 42.656784653663635, 42.997090592980385, 46.66007503867149, 53.48471403121948, 54.04401741921902, 53.43796893954277, 51.13545209169388, 52.205907851457596, 56.444048434495926, 54.28221143782139, 51.36804901063442, 56.28054700791836, 55.1663213968277, 54.89818878471851, 51.35402396321297, 50.902342200279236, 48.529004752635956, 43.80029909312725, 41.933235079050064, 46.8968441337347, 45.63490904867649, 45.58425396680832, 44.8649525642395, 46.827566251158714, 48.2345699518919, 48.78680571913719, 49.6346390247345, 48.73138569295406, 46.71819671988487, 55.24796761572361, 62.76630878448486, 64.17067542672157, 60.991709008812904, 59.95457366108894, 26.58409170806408, 1.7724588280543685, 15.831375494599342, 7.532825516536832, 0.27530535066034645, 3.690494019538164, 53.73170077800751, 61.599809378385544, 53.65724757313728, 61.67799398303032, 35.79657956957817, 48.73734377324581, 59.70174662768841, 65.77966868877411, 42.25916638970375, 1.3517040805891156, 0.2738898672396317, 0.1364477095194161, 0.18310657847905532, 0.21864503243705258, 0.22149605210870504, 0.06701183854602277, 0.20076161861652508, 0.20514906209427863, 0.16393818048527464, 0.100241189065855, 0.19524827774148434, 0.23400107718771324], [0.049027180939447135, 0.016809778462629765, 0.044669148774119094, 0.03264795202994719, 0.024654108710819855, 0.050974112600670196, 0.055152878994704224, 0.03118809559964575, 0.006145629358798033, 0.06207363985595293, 0.04332065531343687, 0.027333397265465464, 2.659463994204998, 33.39185580611229, 49.97503995895386, 39.81957569718361, 16.762344539165497, 26.830692775547504, 54.81625758111477, 60.19200772047043, 32.21471317112446, 45.034495666623116, 17.294486984610558, 0.6117129069752991, 4.050196493044496, 13.19979915395379, 11.196654941886663, 9.827120080590248, 18.914037980139256, 56.10411487519741, 55.35102568566799, 54.083751887083054, 56.086787804961205, 53.70567597448826, 53.17039109766483, 44.4662019610405, 51.32248565554619, 54.04625169932842, 46.49718917906284, 40.76578952372074, 45.359982401132584, 49.194755628705025, 51.87695950269699, 50.13144336640835, 44.89476576447487, 47.13942691683769, 46.44671268761158, 51.30933076143265, 50.75377397239208, 49.91531856358051, 50.493940114974976, 53.243848755955696, 50.49248859286308, 52.075460851192474, 52.62869216501713, 49.432261884212494, 50.14158882200718, 46.7947968095541, 39.95069146156311, 37.36108861863613, 37.020759880542755, 36.77209362387657, 38.08805041015148, 38.14840257167816, 38.335515931248665, 38.64400237798691, 37.39022545516491, 36.56460955739021, 38.44801649451256, 34.89930711686611, 36.02414555847645, 37.53953844308853, 47.80583515763283, 51.35622784495354, 49.68184009194374, 49.46504272520542, 49.18831117451191, 45.42273983359337, 41.60534307360649, 42.18647629022598, 42.47354708611965, 41.05864740908146, 44.02977257966995, 43.89677211642265, 46.02492772042751, 49.73941460251808, 52.152604311704636, 46.62908010184765, 30.745662599802017, 50.191347151994705, 50.570832788944244, 49.15547713637352, 49.34696026146412, 50.784176141023636, 49.5801043510437, 44.45870116353035, 46.8899817019701, 50.992800146341324, 50.22003561258316, 51.661142483353615, 50.19337244331837, 49.64669577777386, 49.95390549302101, 47.16848015785217, 40.129008293151855, 36.19927056133747, 37.45570354163647, 38.07499811053276, 37.38666504621506, 39.78875175118446, 36.25281348824501, 38.43102380633354, 39.99995581805706, 38.50837625563145, 37.31365196406841, 38.19203183054924, 36.6037018597126, 43.723425418138504, 49.0820574760437, 50.33314794301987, 52.3019552975893, 49.36464451253414, 51.386763006448746, 50.39006508886814, 51.21731109917164, 49.76242616772652, 50.48116900026798, 51.613242253661156, 50.185465067625046, 47.85472333431244, 47.43737272918224, 43.754443153738976, 42.2775612026453, 40.37329338490963, 39.58447851240635, 38.884601667523384, 41.44903086125851, 45.148417353630066, 47.64848180115223, 46.418582797050476, 47.760469391942024, 47.8061543405056, 46.87039375305176, 47.48800881206989, 54.50266420841217, 57.45534896850586, 57.819019854068756, 61.39554373919964, 47.080533877015114, 1.4868450164794922, 1.7398570524528623, 1.3542142021469772, 0.04690322108217515, 1.4615044137462974, 40.947362780570984, 53.95963154733181, 37.85249724984169, 45.42821153998375, 29.770444929599762, 35.260470137000084, 39.75860796868801, 49.44729007780552, 27.67158765345812, 1.0350633901543915, 0.067749711452052, 0.021435814996948466, 0.016352789898519404, 0.018786271721182857, 0.05163572612218559, 0.026694358020904474, 0.01946620330272708, 0.03468243856332265, 0.05810753216792364, 0.04036154925415758, 0.010259205500915414, 0.025791249645408243, 0.01843388887209585, 0.015042577342683217, 0.0323279453732539, 0.04542842892988119, 0.03948745143134147, 0.04255748259311076, 0.029842826770618558, 0.00917052588192746, 0.04482005337195005, 0.047506149276159704, 0.09929753345204517, 0.05907823906454723, 3.669150327332318, 41.77652768790722, 57.89425201714039, 46.171607449650764, 21.744705587625504, 30.60501504689455, 61.28837428987026, 68.00924465060234, 36.55109368264675, 49.71150889992714, 20.022277012467384, 0.6882291636429727, 3.936915071681142, 13.456880059093237, 8.345083706080914, 6.519938092678785, 20.681110359728336, 57.05751791596413, 57.099251076579094, 55.65801881253719, 57.28874310851097, 56.957701072096825, 55.044526532292366, 46.393910720944405, 52.04405173659325, 55.38213461637497, 48.642025887966156, 42.005309611558914, 47.115659192204475, 52.45081230998039, 54.27833564579487, 52.32926823198795, 45.55580109357834, 49.72938314080238, 47.160926163196564, 54.12921264767647, 51.96961373090744, 52.503165900707245, 52.84138575196266, 53.74216541647911, 53.79102319478989, 55.15977434813976, 53.61459866166115, 51.055116802453995, 51.4330293238163, 49.089204892516136, 42.97569774091244, 39.368885681033134, 38.92388395965099, 37.85812094807625, 39.069267958402634, 38.43328468501568, 40.70386804640293, 40.682399198412895, 38.300546407699585, 38.341929987072945, 39.334896504879, 38.18126320838928, 37.947275564074516, 38.53938639163971, 48.76360036432743, 53.83927680552006, 52.38277696073055, 51.578477919101715, 51.02817244827747, 46.275034099817276, 43.10316950082779, 41.54016517102718, 43.67830663919449, 43.00074979662895, 45.81007204949856, 45.89454151690006, 48.54787074029446, 49.53316166996956, 53.756540045142174, 49.00937877595425, 33.334338292479515, 51.9453102350235, 52.882944121956825, 50.129896849393845, 51.12203121185303, 52.55774237215519, 51.85984142124653, 46.79000906646252, 49.37716104090214, 52.20346078276634, 50.921918749809265, 53.5796557366848, 52.31477200984955, 51.92238986492157, 51.14577993750572, 49.90204967558384, 40.77128782868385, 38.4531956166029, 40.11924281716347, 38.9883778989315, 39.00461442768574, 40.025505647063255, 39.36458431184292, 39.850673228502274, 42.569438740611076, 40.31451053917408, 39.785160943865776, 39.59077477455139, 39.53458718955517, 46.14683657884598, 50.57976990938187, 52.71907791495323, 53.1490096449852, 49.328409656882286, 52.38248057663441, 51.888480484485626, 52.4199503660202, 51.27330869436264, 53.795772939920425, 53.97064335644245, 51.9547451287508, 50.03070317208767, 49.19008567929268, 45.61961866915226, 43.3522879332304, 42.98900082707405, 41.43131621181965, 41.695736423134804, 42.42207124829292, 46.007479056715965, 49.368497505784035, 48.66843067109585, 49.32532802224159, 49.1438839584589, 47.961189821362495, 50.428511425852776, 56.47039622068405, 59.17593464255333, 60.10294809937477, 64.27956998348236, 45.99451795220375, 2.315356833860278, 1.3936778157949448, 1.0697202617302537, 0.0743626405892428, 1.3673730148002505, 45.25827705860138, 57.66784496605396, 42.35709473490715, 51.285240054130554, 37.46624417603016, 40.7499747723341, 47.07894176244736, 57.560375332832336, 37.44058035314083, 2.148446752689779, 0.047690417122794315, 0.04682785598561168, 0.03385019415873103, 0.03288285661255941, 0.10800176052725874, 0.03861415141727775, 0.03225676227884833, 0.0814542623993475, 0.04770388339238707, 0.04706562525825575, 0.025460828801442403, 0.046833533415338024, 0.13025649095652625, 0.11614178467425518, 0.14026611868757755, 0.12474812247091904, 0.14501890662359074, 0.13163066643755883, 0.12712914001895115, 0.06233448992134072, 0.13312410505022854, 0.2665845811134204, 0.1890529625234194, 0.13781615562038496, 5.716749541461468, 51.28295257687569, 66.42007872462273, 55.590884014964104, 26.267815679311752, 37.912921607494354, 60.81010155379772, 64.09847930073738, 43.6441844701767, 57.02240779995918, 23.37476871907711, 0.5395760340616107, 5.811600526794791, 26.318860240280628, 17.50596273690462, 16.759086214005947, 22.74354849010706, 56.88631430268288, 58.946278765797615, 57.9726380109787, 61.23217150568962, 58.43031205236912, 56.694485396146774, 48.736876398324966, 54.52032946050167, 57.76394560933113, 50.829161927103996, 44.3619279563427, 48.54392655193806, 54.24602597951889, 57.50012956559658, 53.88336963951588, 46.232715770602226, 49.429951608181, 49.4336412101984, 54.603890776634216, 54.77282211184502, 54.371879026293755, 55.561291202902794, 56.68899469077587, 55.830286368727684, 56.186414659023285, 55.50508461892605, 53.12707722187042, 54.20411802828312, 49.936388432979584, 45.62930814921856, 41.22167766094208, 43.40721778571606, 39.06336307525635, 41.02675572037697, 41.770710200071335, 42.46916592121124, 41.757042333483696, 40.85691623389721, 40.32379724085331, 40.042543932795525, 39.223167300224304, 38.56045626103878, 40.953666642308235, 53.022377640008926, 56.48154862225056, 55.321854650974274, 54.2217642813921, 52.54648357629776, 50.708970576524734, 44.80168215930462, 46.27442993223667, 48.00065070390701, 43.7465737760067, 48.766484409570694, 50.3999787569046, 49.61668498814106, 52.555131912231445, 56.17243520915508, 50.56058093905449, 35.09511820971966, 54.25295300781727, 54.32856895029545, 52.83021055161953, 54.27851803600788, 54.91975262761116, 54.147459268569946, 46.61442808806896, 50.81571064889431, 54.05574358999729, 54.09525386989117, 57.07711346447468, 54.04918894171715, 52.87236548960209, 53.89813184738159, 51.36085979640484, 44.765568897128105, 39.68094393610954, 42.723326683044434, 40.47307223081589, 42.54444368183613, 43.05665619671345, 40.40286719799042, 41.75846345722675, 45.121207013726234, 41.572083458304405, 41.81938178837299, 41.33576653897762, 41.342362985014915, 47.61366426944733, 54.13219928741455, 56.101838797330856, 57.71338552236557, 49.37976390123367, 54.33750607073307, 55.128931403160095, 54.702985659241676, 53.07759627699852, 57.555948570370674, 56.331259086728096, 55.7520067691803, 51.31455548107624, 51.82023614645004, 47.17069163918495, 46.29438266158104, 46.45414128899574, 43.85820418596268, 43.30320596694946, 47.14685931801796, 50.06941929459572, 53.01784448325634, 49.31645169854164, 52.584451138973236, 52.08015359938145, 50.83836883306503, 51.26098595559597, 59.47577655315399, 62.363636791706085, 62.80923508107662, 64.31483969092369, 50.507395192980766, 3.6751160072162747, 5.656149443238974, 4.3876673094928265, 0.1258910447359085, 1.4009774615988135, 49.67123106122017, 64.31563004851341, 50.50962947309017, 57.48041622340679, 39.93504390120506, 47.631986886262894, 57.0160773396492, 65.99420517683029, 46.266252771019936, 3.660579174757004, 0.19213075283914804, 0.09783180663362145, 0.10491842636838555, 0.09309832938015461, 0.1961680658860132, 0.11968601480475627, 0.09665196252171881, 0.14976339734857902, 0.1132018186035566, 0.10621615321724676, 0.11045862556784414, 0.1227799839398358], [0.029416613215289544, 0.07981868766364641, 0.09134764011832885, 0.03351656538143288, 0.03902915668732021, 0.022964088166190777, 0.03583088982850313, 0.03145554706861731, 0.05517218596651219, 0.015693749774072785, 0.12102683074772358, 0.023225121913128532, 4.774762038141489, 38.90497237443924, 50.346728414297104, 41.724060103297234, 38.62233214080334, 29.57649953663349, 44.54298064112663, 43.55699434876442, 29.214063584804535, 52.76960000395775, 15.650530848652124, 0.8945323247462511, 10.362924579530954, 46.00815922021866, 5.904587712138891, 7.7463113609701395, 23.40714108198881, 47.06595405936241, 50.44689483940601, 58.497667238116264, 53.46658520400524, 53.410842195153236, 50.02735175192356, 55.84668628871441, 50.915880873799324, 53.765021190047264, 45.300720781087875, 40.405508056283, 44.55321729183197, 48.96615989506245, 50.81814631819725, 49.6796590089798, 49.104100093245506, 44.95912291109562, 48.92661161720753, 50.66662184894085, 47.01021485030651, 47.953316643834114, 46.83068208396435, 49.20968882739544, 46.73664093017578, 49.404641166329384, 49.44489240646362, 46.5906223654747, 44.0308403223753, 40.79305686056614, 35.037114322185516, 35.445155426859856, 36.505218744277954, 36.85197673738003, 36.033455058932304, 36.94767840206623, 37.23923675715923, 37.8454752266407, 37.4550461769104, 35.84455959498882, 38.27969312667847, 38.070757538080215, 36.32046885788441, 39.998219311237335, 51.88101388514042, 50.07329888641834, 51.05885960161686, 50.64123161137104, 48.81764866411686, 46.980599239468575, 43.569039702415466, 44.52575236558914, 44.43746030330658, 42.83724457025528, 45.33482775092125, 44.94390092790127, 46.3811282068491, 51.34095646440983, 51.69428050518036, 49.04902204871178, 32.54399970173836, 50.03199130296707, 48.948597237467766, 46.68492190539837, 47.67033442854881, 51.22828111052513, 50.24945743381977, 40.29589533805847, 45.66729851067066, 51.073348224163055, 52.18134216964245, 51.23382121324539, 51.193281188607216, 47.99073703587055, 49.49753098189831, 49.742693826556206, 48.19034032523632, 38.43452341854572, 37.528275847435, 36.64764270186424, 36.34646326303482, 38.93845617771149, 38.34104463458061, 37.91541427373886, 40.86362287402153, 40.02661518752575, 38.234946727752686, 36.411253586411476, 36.48663014173508, 40.39811745285988, 47.53870569169521, 47.43010371923447, 52.08082236349583, 49.643435552716255, 49.400089010596275, 51.21082104742527, 52.15512357652187, 51.97746030986309, 53.66106256842613, 50.549128353595734, 54.05194379389286, 53.22065480053425, 51.31860986351967, 48.819711953401566, 46.38068363070488, 42.48737834393978, 40.98049320280552, 38.78161199390888, 42.2745555639267, 46.84792935848236, 51.38954445719719, 50.647470876574516, 50.55148042738438, 48.15889701247215, 49.492382258176804, 45.0837030261755, 52.682010903954506, 54.591283053159714, 57.8151098638773, 56.21872432529926, 60.273289158940315, 10.997590273618698, 0.33497996104415506, 0.3368481545476243, 0.07036703624180518, 0.47416720481123775, 31.19920816272497, 55.31952917575836, 42.60093905031681, 33.01800146698952, 22.734687365591526, 25.8078845590353, 39.33063693344593, 46.133499294519424, 30.49377031624317, 2.1666898112744093, 0.12123381573474035, 0.07797907426720485, 0.10581503724097274, 0.01835174796724459, 0.13209893193561584, 0.005353477163225762, 0.06586958421394229, 0.0055609913943044376, 0.06759149298886769, 0.048663754932931624, 0.0431995219696546, 0.026208509189018514, 0.01751088537275791, 0.014066031599213602, 0.06130454479716718, 0.03468161477940157, 0.012487743242672877, 0.026563445026113186, 0.026615202405082528, 0.0758660165593028, 0.04775564819283318, 0.008728634456929285, 0.16787358181318268, 0.035490314548951574, 7.035086425021291, 48.032173812389374, 56.30371056497097, 47.539925426244736, 38.495589941740036, 28.66001721471548, 49.83245261013508, 49.40061338245869, 31.517006009817123, 57.262832298874855, 16.905002184212208, 1.0310211195610464, 11.998509764671326, 51.28203682601452, 3.162558185867965, 5.953100183978677, 24.820294752717018, 51.197791546583176, 52.9569261521101, 59.34727504849434, 53.525406047701836, 52.556207254529, 49.615138471126556, 55.07286161184311, 52.50071503221989, 56.43112912774086, 45.86013436317444, 40.79123295843601, 44.54275645315647, 49.87673923373222, 51.782971546053886, 52.451731860637665, 48.98425452411175, 43.92017126083374, 50.41333124041557, 51.72858126461506, 48.7345053255558, 49.87888611853123, 49.35383789241314, 50.1015617698431, 48.08474399149418, 51.6679023206234, 51.88403472304344, 48.24866719543934, 46.489019617438316, 42.46225029230118, 38.30674387514591, 37.829478085041046, 38.40897358953953, 38.08253690600395, 37.092492431402206, 38.9686493575573, 38.65268871188164, 39.25276391208172, 38.942639753222466, 37.99484521150589, 39.66888338327408, 39.0742114931345, 36.808051094412804, 42.27991707623005, 52.996941804885864, 52.84615829586983, 51.233806014060974, 51.72800749540329, 50.900970473885536, 49.05776537954807, 45.02356365323067, 45.033621713519096, 45.26853270828724, 44.68575797975063, 45.79010032117367, 44.59959000349045, 48.37158299982548, 53.81734058260918, 52.78911575675011, 50.74157662689686, 33.99079866707325, 51.67994387447834, 49.78047139942646, 48.26894290745258, 48.573766350746155, 52.59211152791977, 51.43300652503967, 42.726655304431915, 46.87247984111309, 52.520591765642166, 54.60150830447674, 53.52489687502384, 52.18049481511116, 50.420125275850296, 52.17280022799969, 51.212549954652786, 49.03301350772381, 40.07789343595505, 38.81812423467636, 36.64828486740589, 38.019091710448265, 40.57714104652405, 39.8711047321558, 40.09907729923725, 42.26828970015049, 40.24444229900837, 39.99299459159374, 39.120762795209885, 37.38817356526852, 41.695797219872475, 50.30508644878864, 49.511138051748276, 54.786600172519684, 51.4318285882473, 50.684849470853806, 52.5498615950346, 53.58143024146557, 53.51040065288544, 55.77557310461998, 53.33742633461952, 54.99268211424351, 54.4890533387661, 53.90991121530533, 51.781941801309586, 47.49695733189583, 45.45039854943752, 42.54273757338524, 41.2812090665102, 44.047088250517845, 48.05570974946022, 52.53864459693432, 52.02031061053276, 54.021393433213234, 50.81933185458183, 51.48068256676197, 47.48774662613869, 54.0848196297884, 57.09635563194752, 60.08208341896534, 58.85047070682049, 62.63939179480076, 12.610076498240232, 0.38676634314469993, 1.0170876234769821, 0.14242285920772702, 0.5028156784828752, 34.84517142176628, 58.3768755197525, 46.503819823265076, 37.721993252635, 25.192258693277836, 31.600394435226917, 44.96177896857262, 54.27612416446209, 40.148987621068954, 3.7442126870155334, 0.17686369159491733, 0.0937173621787224, 0.07316821327549405, 0.10267228673910722, 0.0315055010287324, 0.047311899543274194, 0.03754770747036673, 0.03211438495782204, 0.053577785583911464, 0.04773452295921743, 0.016923594230320305, 0.04751009379106108, 0.16245609673205763, 0.19206762575777248, 0.2616152196424082, 0.12935264414409176, 0.18591042724438012, 0.1079670873878058, 0.13801399734802544, 0.09688303762231953, 0.1849105762084946, 0.18154207180486992, 0.26985914446413517, 0.07227411086205393, 9.386230688542128, 58.370841443538666, 63.719981610774994, 55.25680214166641, 48.927329778671265, 41.14713706076145, 49.013467356562614, 52.39346198737621, 39.87603686749935, 63.5013223439455, 20.34783784300089, 1.1516278353519738, 11.057760994881392, 54.991496577858925, 10.515193808823824, 13.543776646256447, 28.066378869116306, 53.954224437475204, 56.65777936577797, 60.409196466207504, 55.44162042438984, 54.37485046684742, 51.938394606113434, 57.23281390964985, 53.701617792248726, 59.65535871684551, 48.76983962953091, 43.647646084427834, 47.42531977593899, 52.973523661494255, 54.68804486095905, 54.34037871658802, 49.52867031097412, 45.58756738901138, 51.49697229266167, 54.28482569754124, 51.27023085951805, 52.68170692026615, 52.83286660909653, 54.58064362406731, 50.012733936309814, 53.05242642760277, 53.17111685872078, 49.959593787789345, 48.51677320897579, 45.45926347374916, 38.898896500468254, 39.502015337347984, 40.666166469454765, 40.52152343094349, 38.86654503643513, 40.22077716886997, 40.963424518704414, 41.982689425349236, 40.83788305521011, 39.43870693445206, 41.6085235029459, 42.158171609044075, 39.705737605690956, 44.7063110768795, 55.89657761156559, 54.95279185473919, 54.46360610425472, 54.11331050097942, 52.381382435560226, 51.43391087651253, 48.23104754090309, 47.54616469144821, 48.254093304276466, 47.28361018002033, 48.18060904741287, 48.91199380159378, 50.12375257909298, 56.88623070716858, 55.89165307581425, 52.74904690682888, 37.56663478910923, 53.92013266682625, 51.34010910987854, 50.67966274917126, 51.582885682582855, 54.01134677231312, 52.39684760570526, 43.68352375924587, 48.09220299124718, 55.415135845541954, 56.43831454217434, 55.272985473275185, 55.482700020074844, 52.25927598774433, 54.33586075901985, 53.88180032372475, 51.72806069254875, 41.568971425294876, 41.56683973968029, 38.30696426331997, 39.261799827218056, 43.43913607299328, 41.321783289313316, 42.822379767894745, 43.86357329785824, 42.135524824261665, 42.23892107605934, 39.948046803474426, 40.2046774327755, 44.06062692403793, 51.751209050416946, 52.452590614557266, 57.91061773896217, 53.82289208471775, 52.70194463431835, 54.61515337228775, 54.39660809934139, 54.266472682356834, 58.03788051009178, 54.95894372463226, 57.76956170797348, 56.57028906047344, 55.888700634241104, 54.33096282184124, 49.86258119344711, 47.03810915350914, 46.04687534272671, 42.653045654296875, 46.36997580528259, 51.474348306655884, 55.67128770053387, 55.293857753276825, 55.64228765666485, 53.742864578962326, 55.8236975222826, 49.504997581243515, 57.46802128851414, 59.7875764220953, 61.90605394542217, 60.49189902842045, 65.58375120162964, 15.7479452714324, 1.8279886920936406, 2.4137884145602584, 0.5032195849344134, 0.38074420066550374, 39.022963643074036, 66.11943885684013, 54.58070062100887, 43.19450519979, 33.70022065937519, 37.21000112593174, 52.31998533010483, 62.75314249098301, 51.853594556450844, 6.445431690663099, 0.20799122052267194, 0.14066365751205012, 0.21262327587464824, 0.12006810211460106, 0.24656219378812239, 0.17256814084248617, 0.12241635384270921, 0.12454423966119066, 0.1328923471737653, 0.18652369355550036, 0.10166527397814207, 0.07567901760921814], [0.015518947093369206, 0.06920797968632542, 0.05981567039270885, 0.07038715586531907, 0.04495420398598071, 0.08200170763302594, 0.032795602310216054, 0.04851159239478875, 0.06843189359642565, 0.055896785561344586, 0.09358029492432252, 0.02757130940153729, 7.345138862729073, 48.002869784832, 51.328287944197655, 44.56125386059284, 31.246365532279015, 26.182990930974483, 33.59357938170433, 30.877540223300457, 35.387109741568565, 56.088813096284866, 9.528629947453737, 0.24285875813802704, 0.7920669042505324, 22.009044103324413, 8.475930634886026, 3.588021118193865, 21.558112800121307, 18.518490605056286, 28.43726746737957, 47.83577375113964, 51.58963792026043, 55.08978210389614, 57.156859785318375, 56.525675654411316, 52.40793541073799, 48.189169988036156, 40.58492302894592, 40.44785678386688, 43.963933512568474, 48.444520086050034, 51.170300021767616, 52.65120595693588, 50.18087111413479, 47.019968926906586, 47.50457972288132, 49.70463886857033, 48.763911947607994, 48.4630972892046, 41.264337971806526, 41.071437522768974, 40.768597573041916, 42.19178840517998, 41.291734501719475, 40.192096307873726, 37.59617440402508, 37.99486801028252, 37.24968999624252, 37.33536779880524, 37.20676749944687, 36.451539024710655, 37.428166419267654, 37.53194645047188, 36.723448634147644, 35.58226726949215, 35.28241015970707, 36.938764080405235, 37.458112612366676, 36.695626527071, 34.07124035060406, 41.34128004312515, 50.49728773534298, 50.735417157411575, 53.26737329363823, 48.30955892801285, 49.93989944458008, 47.04677268862724, 45.38892924785614, 45.412335991859436, 45.591503977775574, 43.75937908887863, 43.28513413667679, 43.26116122305393, 45.783443078398705, 51.005252078175545, 52.03235596418381, 51.87550038099289, 36.93458430469036, 51.166500225663185, 51.710543632507324, 47.108017802238464, 45.903417840600014, 50.185628458857536, 50.00456057488918, 44.99694988131523, 44.91785332560539, 45.416021794080734, 45.48477530479431, 45.05724124610424, 46.46205626428127, 44.95422877371311, 48.41971501708031, 48.67560088634491, 48.88469606637955, 40.509025901556015, 34.648984149098396, 35.891278088092804, 37.1599730104208, 38.22977140545845, 39.65682663023472, 38.950467333197594, 38.7240032851696, 38.21270652115345, 39.73574839532375, 38.14415819942951, 36.463234797120094, 37.01857879757881, 41.69226720929146, 45.12111581861973, 50.16494236886501, 51.461717784404755, 49.84540231525898, 49.489965587854385, 45.85389129817486, 47.340329736471176, 48.75654794275761, 49.501353576779366, 50.65685257315636, 52.54174143075943, 49.04301457107067, 50.776834934949875, 50.51561035215855, 47.263923436403275, 43.2554767280817, 42.033899277448654, 42.11461454629898, 44.81130704283714, 54.610510021448135, 54.4110207259655, 53.11677597463131, 48.8959776610136, 52.844767570495605, 50.945861265063286, 54.87658314406872, 55.58243706822395, 60.19902594387531, 60.50028137862682, 61.57555527985096, 33.698989525437355, 1.71865668380633, 0.3830613341415301, 0.05426438350696117, 0.16075135383289307, 23.74471876770258, 59.672169014811516, 40.54004363715649, 42.834273129701614, 36.16338908672333, 33.9325287938118, 43.45322571694851, 49.62030239403248, 36.79337628185749, 4.755763057619333, 0.14474303548922762, 0.017363572769681923, 0.10747986743808724, 0.11443839248386212, 0.04028756826301105, 0.028839357764809392, 0.03481876367004588, 0.03942957875551656, 0.058407793985679746, 0.08502121709170751, 0.044676481193164364, 0.01856133789260639, 0.05030816493672319, 0.085290497954702, 0.028404117838363163, 0.06218181901203934, 0.05629578641674016, 0.030730986436537933, 0.045393844848149456, 0.13467568351188675, 0.029842032672604546, 0.05964707299426664, 0.09614070440875366, 0.07630663705640472, 9.061093535274267, 54.467690885066986, 56.58999100327492, 49.68323841691017, 38.585971891880035, 33.71621020138264, 37.276573553681374, 37.606471851468086, 40.24612940847874, 60.8997805416584, 11.550132874399424, 0.4404765204526484, 1.2812963523902, 28.349720165133476, 8.70887903496623, 3.60265270806849, 21.8124882504344, 20.58842573314905, 29.77527257055044, 50.14710612595081, 50.6156399846077, 57.06878051161766, 57.14185819029808, 55.492150112986565, 53.30214902758598, 50.85019379854202, 42.907495200634, 42.89867207407951, 45.40241092443466, 50.544541999697685, 54.22607704997063, 53.386477902531624, 51.61819338798523, 48.40861961245537, 48.557028248906136, 50.3758804500103, 49.57318112254143, 50.68954221904278, 43.33112306892872, 43.54037784039974, 44.49699550867081, 44.94380213320255, 42.59507596492767, 42.32293076813221, 39.449646547436714, 41.52066841721535, 37.83190995454788, 39.57650274038315, 38.60258460044861, 37.98117354512215, 39.01719555258751, 38.840242847800255, 37.80408784747124, 38.08290548622608, 37.84525103867054, 38.882621973752975, 39.188266173005104, 39.11420054733753, 36.393056362867355, 43.2607888430357, 53.36558282375336, 50.83751767873764, 53.246831595897675, 50.15702739357948, 52.636253759264946, 48.976852521300316, 48.217828050255775, 49.10276256501675, 47.09200546145439, 46.5618085116148, 45.40440961718559, 45.63946880400181, 48.15455764532089, 53.50166492164135, 53.6380548030138, 52.98509784042835, 39.565034955739975, 54.13055017590523, 52.459954619407654, 49.11578446626663, 49.30864691734314, 52.58120231330395, 52.48827449977398, 45.669753178954124, 46.22186355292797, 48.104704320430756, 47.126009836792946, 46.73558458685875, 46.02490492165089, 45.12792885303497, 49.32646036148071, 50.81957884132862, 51.73824414610863, 43.38653549551964, 37.842606380581856, 36.97778798639774, 38.915824592113495, 41.16829812526703, 41.39245569705963, 40.81891447305679, 38.732959404587746, 40.213850140571594, 41.28863766789436, 39.339129477739334, 38.6237608641386, 38.22865046560764, 44.284921288490295, 47.84600280225277, 52.17863291501999, 52.72453062236309, 50.20765207707882, 49.933534786105156, 48.72581519186497, 47.92220391333103, 50.358709171414375, 49.54104624688625, 53.64305153489113, 55.53380727767944, 52.34284110367298, 53.614518865942955, 52.80243404209614, 49.25967514514923, 43.708461821079254, 43.738054633140564, 43.66735562682152, 47.58442863821983, 56.08839891850948, 54.70955550670624, 55.47893822193146, 52.32418790459633, 55.33853195607662, 53.74523565173149, 57.73695185780525, 57.34083831310272, 62.92445629835129, 63.14306616783142, 66.56996548175812, 36.767397075891495, 3.135222690179944, 0.4743085987865925, 0.0939702638424933, 0.06828462181147188, 27.361404597759247, 64.51234549283981, 46.675855591893196, 43.10138359665871, 41.537645906209946, 45.30209630727768, 52.71252326667309, 59.08299542963505, 45.23209646344185, 7.028853809460998, 0.13433144573355094, 0.019134027279505972, 0.02005820151680382, 0.04720863711554557, 0.031948681935318746, 0.09998816123697907, 0.11612506408710033, 0.0878380385984201, 0.05841528967721388, 0.05492414908076171, 0.030034169139980804, 0.04773182525241282, 0.14875217661028728, 0.12595074309501797, 0.11169986755703576, 0.19233246857766062, 0.12925615010317415, 0.1801866281311959, 0.21097833523526788, 0.2126298809889704, 0.1751873581088148, 0.27250849292613566, 0.2277814195258543, 0.12247399645275436, 12.78281332924962, 65.36699563264847, 64.85128730535507, 55.711641535162926, 43.08290518820286, 37.83134378492832, 40.37683479487896, 42.18504756689072, 47.83781424164772, 67.71558880805969, 13.418200984597206, 0.753114897524938, 1.6007149312645197, 26.35597664862871, 10.570224355906248, 7.138917278498411, 25.147005021572113, 21.677538491785526, 31.937537044286728, 53.282340690493584, 51.791726276278496, 57.78661899268627, 58.74652348458767, 58.18540379405022, 57.764652371406555, 52.779251486063, 43.5530349612236, 44.29723642766476, 47.11958058178425, 52.680673375725746, 55.29019854962826, 55.614226162433624, 52.86376655101776, 48.71009923517704, 50.66895492374897, 52.804968506097794, 52.58857011795044, 53.89620155096054, 45.5166631937027, 47.677702233195305, 45.467113852500916, 47.014155238866806, 44.743454083800316, 43.90142686665058, 42.30781137943268, 43.13519798219204, 40.44356681406498, 41.45326763391495, 40.83304591476917, 39.27471533417702, 42.39408954977989, 41.00104250013828, 39.09260630607605, 40.16219951212406, 39.86791670322418, 40.18133148550987, 41.24693110585213, 40.35602331161499, 37.62981779873371, 44.97739613056183, 55.52096776664257, 53.65244463086128, 55.70249542593956, 50.50657443702221, 55.96065737307072, 52.52416357398033, 51.24396286904812, 51.04647986590862, 50.31353339552879, 48.572470620274544, 46.86741851270199, 47.089368402957916, 48.798737078905106, 54.594208896160126, 55.703126192092896, 55.65936394035816, 42.573914900422096, 56.3485823571682, 54.630610942840576, 51.54042296111584, 50.61765767633915, 54.40490685403347, 55.00049449503422, 48.01649585366249, 46.72591410577297, 48.48574787378311, 48.302301317453384, 47.49987177550793, 47.678971365094185, 46.53029300272465, 51.04659005999565, 52.526310458779335, 53.486123755574226, 45.095379799604416, 39.36487689614296, 39.237317740917206, 40.003064051270485, 41.535115242004395, 43.70471902191639, 43.110016733407974, 40.98451718688011, 42.020839378237724, 45.07755495607853, 42.44896620512009, 41.055231392383575, 41.13707900047302, 46.51624895632267, 49.21952269971371, 53.9544790238142, 56.57065004110336, 51.513091027736664, 51.2833933532238, 48.700523748993874, 49.271367117762566, 52.072888389229774, 51.198065131902695, 53.289081528782845, 57.144305258989334, 53.06832477450371, 56.12867675721645, 56.30620703101158, 51.90551497042179, 45.54011173546314, 46.10235616564751, 45.45767515897751, 50.03577210009098, 59.01446230709553, 59.846682250499725, 57.67243131995201, 55.58531351387501, 58.59874561429024, 56.07013709843159, 60.476262867450714, 59.50506538152695, 65.10061472654343, 64.11660432815552, 65.54848149418831, 41.5765406191349, 4.174047997221351, 1.6418056888505816, 0.4872111033182591, 0.2003729113494046, 30.80671962350607, 71.28916785120964, 52.87773460149765, 55.73665179312229, 46.86132363975048, 45.615910068154335, 59.58011135458946, 65.55624827742577, 57.72615283727646, 10.221127588301897, 0.24938136048149318, 0.14805031270952895, 0.1986497631878592, 0.21870066382689402, 0.18471816700184718, 0.18048405123408884, 0.16556502756429836, 0.21462464035721496, 0.18020783871179447, 0.18120139633538201, 0.16344067436875775, 0.126450787356589], [0.06500281509943306, 0.038186462843441404, 0.026949304301524535, 0.004224721569698886, 0.07581979560200125, 0.028327873296802863, 0.04071975425176788, 0.050866516030509956, 0.11941017335630022, 0.011140387123305118, 0.06733273577992804, 0.1319542428245768, 9.517244808375835, 50.22223189473152, 45.81170216202736, 41.58810719847679, 18.902418203651905, 13.035498820245266, 25.208844803273678, 34.51193690299988, 42.3051743209362, 54.13306184113026, 6.388939647004008, 0.3374955151230097, 0.5585034121759236, 1.4552069641649723, 1.9454249530099332, 2.6751763885840774, 25.71181431412697, 23.61464224755764, 28.26404806226492, 51.49634152650833, 53.946301862597466, 55.613154619932175, 54.62812967598438, 52.670520320534706, 48.604860082268715, 40.197275429964066, 40.20247735083103, 41.59315712749958, 44.33797784149647, 45.992010086774826, 50.27053490281105, 50.889951065182686, 52.001182436943054, 48.651115000247955, 50.23102082312107, 49.56617809832096, 47.47959606349468, 46.17350734770298, 40.93507423996925, 37.84329414367676, 36.78244426846504, 36.72608569264412, 35.75967215001583, 35.797122940421104, 37.506647408008575, 37.725983038544655, 38.14955770969391, 37.28177547454834, 39.31201413273811, 35.16837827861309, 36.20644837617874, 35.25513522326946, 35.11671245098114, 36.19314908981323, 36.75955429673195, 36.83563381433487, 36.03652149438858, 35.93698963522911, 35.120721235871315, 42.30323642492294, 52.607132121920586, 50.66159091889858, 47.137671411037445, 49.30481292307377, 51.508880853652954, 47.302734553813934, 47.362881526350975, 48.60263720154762, 47.49750830233097, 44.52718488872051, 46.14519506692886, 43.381686955690384, 43.30151505768299, 50.015796571969986, 50.75689360499382, 51.8400064855814, 41.15734711289406, 50.90661317110062, 50.75967885553837, 44.253527373075485, 45.532679334282875, 50.09858652949333, 49.948395788669586, 43.827452436089516, 44.95458595454693, 45.80239646136761, 44.641167372465134, 49.43092815577984, 49.95483264327049, 48.6064749956131, 48.941263630986214, 47.361080422997475, 47.958351373672485, 42.93533630669117, 36.75231948494911, 35.125539377331734, 37.37381033599377, 38.654786199331284, 36.65055334568024, 38.499591127038, 40.18104650080204, 37.073018476367, 36.909840032458305, 36.24047555029392, 36.684124544262886, 37.27468505501747, 38.92100751399994, 41.31768710911274, 45.45456312596798, 50.90813688933849, 51.81207798421383, 51.303429678082466, 50.05867727100849, 48.578679487109184, 48.47234219312668, 48.27729485929012, 47.70249970257282, 51.99800580739975, 53.55923183262348, 51.8270605802536, 50.08531004190445, 47.62880265712738, 46.009519547224045, 43.510025069117546, 40.59401974081993, 44.36823181807995, 55.248906165361404, 54.585864543914795, 57.63092614710331, 52.79552981257439, 56.69811800122261, 56.470339223742485, 57.94803813099861, 57.718458250164986, 60.81130988895893, 59.04652118682861, 62.20016576349735, 39.418450221419334, 8.96310344338417, 0.169557039916981, 0.046420361250056885, 0.03906459423888009, 18.49397052079439, 60.55127464234829, 44.48273107409477, 34.3896746635437, 12.343240566551685, 15.506877657026052, 38.572972789406776, 48.705961257219315, 42.66381807625294, 8.244203869253397, 0.23132284433813766, 0.03303410630906001, 0.08670856404933147, 0.016371367710235063, 0.07317815805436112, 0.015304617627407424, 0.04585323797073215, 0.08181895376765169, 0.07251224378705956, 0.040989703047671355, 0.03455394311458804, 0.0872740508930292, 0.024401769223914016, 0.007033585397948627, 0.03135228835162707, 0.08906711678719148, 0.006937142379683792, 0.05850658126291819, 0.012993872187507804, 0.07130298094125465, 0.07090634753694758, 0.0296529037586879, 0.06603175832424313, 0.03384340350748971, 11.201279293745756, 59.087281599640846, 53.307423144578934, 48.589630499482155, 24.90801114588976, 18.98187004029751, 26.02756977081299, 39.376268684864044, 44.67943511903286, 61.160666942596436, 7.061290768906474, 0.22179026913363487, 0.4336434183642268, 4.551784303039312, 5.789763573557138, 2.429769169539213, 27.73640837520361, 23.158600218594074, 30.180745013058186, 54.19946327805519, 56.28752343356609, 57.36809425055981, 56.401300728321075, 54.54084075987339, 51.07460595667362, 42.23252981901169, 42.125850543379784, 43.26536379754543, 45.38802109658718, 46.69534094631672, 51.32900230586529, 50.932569578289986, 54.61747884750366, 49.60945777595043, 51.760632544755936, 51.23447857797146, 48.09461586177349, 46.27327099442482, 42.13517524302006, 39.69917915761471, 38.54750655591488, 36.9575996696949, 38.004899471998215, 37.136961445212364, 38.39709922671318, 38.59743967652321, 39.47671249508858, 38.09766009449959, 40.1436223089695, 37.18676537275314, 38.389188051223755, 36.47279888391495, 37.12604843080044, 38.87719586491585, 38.932452499866486, 39.89877484738827, 37.64521837234497, 38.287725895643234, 37.21015691757202, 42.66746208071709, 55.06402708590031, 50.28294123709202, 47.5994074344635, 51.04782119393349, 53.12814496457577, 49.99159187078476, 50.15887409448624, 50.85252307355404, 50.007015243172646, 46.128912940621376, 47.57145993411541, 45.04901848733425, 47.05946400761604, 53.40396076440811, 53.020139560103416, 52.16246858239174, 43.53452615439892, 50.76257809996605, 52.837984934449196, 47.200459241867065, 48.16438011825085, 51.47585302591324, 51.47694356739521, 44.382344260811806, 44.88909266889095, 46.51098243892193, 45.4293666779995, 49.050066992640495, 50.774235874414444, 50.46273998916149, 51.40972137451172, 49.418799206614494, 49.80249501764774, 43.35967093706131, 38.19585062563419, 37.83294349908829, 39.294599667191505, 40.527770295739174, 39.548426046967506, 41.38841651380062, 42.25861921906471, 40.05563423037529, 38.67978885769844, 37.36448563635349, 39.05745059251785, 38.55732522904873, 39.64550703763962, 42.842822670936584, 49.033602476119995, 52.730853483080864, 53.103153705596924, 53.16393904387951, 51.0552079975605, 48.85378472507, 50.00751681625843, 48.85149344801903, 48.949471190571785, 51.301240995526314, 54.535407051444054, 54.14872460067272, 52.59358584880829, 51.38428553938866, 47.74204798042774, 45.12107402086258, 43.259044736623764, 46.31914593279362, 58.0162862688303, 57.44690582156181, 57.36735329031944, 55.29919646680355, 58.86419177055359, 59.40174512565136, 60.265134796500206, 59.657786786556244, 62.498567551374435, 60.98469838500023, 63.36753152310848, 42.85448044538498, 11.37161560356617, 0.20913843240123242, 0.12463852210203186, 0.1896857176325284, 21.186145059764385, 64.9031013250351, 50.57676427066326, 41.85905545949936, 17.41647943854332, 18.08610040694475, 43.41306947171688, 57.392694130539894, 52.24951051175594, 12.100891470909119, 0.1928440309711732, 0.05265773397695739, 0.11738830333342776, 0.03172636417730246, 0.04099207049875986, 0.01950478199432837, 0.053270729404175654, 0.05833193165017292, 0.06714276823913679, 0.044627881652559154, 0.015263887635228457, 0.050575304703670554, 0.16167902358574793, 0.182622623979114, 0.08963207670603879, 0.17730170715367422, 0.15730615588836372, 0.18927872384665534, 0.11865187654620968, 0.19217443565139547, 0.2780332480324432, 0.11054558301111683, 0.14393275865586475, 0.1334701685118489, 13.651694655418396, 65.3282681107521, 60.279771611094475, 55.14664605259895, 27.901228331029415, 23.856280781328678, 33.297567665576935, 49.76475924253464, 52.113322019577026, 66.07055827975273, 8.1448420509696, 0.36053688498213887, 1.853643727954477, 4.81818943284452, 6.765581611543894, 3.5348215978592634, 29.91482388228178, 26.4253818243742, 33.220572397112846, 56.7523904889822, 59.763930290937424, 60.830084681510925, 58.37496802210808, 56.910279616713524, 52.43172973394394, 43.46199184656143, 45.49191892147064, 46.69068239629269, 48.11985030770302, 48.91633316874504, 53.62712658941746, 53.76574695110321, 55.01516550779343, 51.73302322626114, 51.74189195036888, 52.47896499931812, 50.46590901911259, 48.68165396153927, 44.529297575354576, 40.991884991526604, 41.505830213427544, 40.20945757627487, 40.74350371956825, 39.35528241097927, 40.54833099246025, 41.37618117034435, 42.016192227602005, 40.36115303635597, 42.51073569059372, 39.76865462958813, 40.16672506928444, 37.828284949064255, 38.58824796974659, 40.55770888924599, 41.61884754896164, 41.42148993909359, 40.5404844135046, 39.93461452424526, 38.791271075606346, 43.48830163478851, 56.77388593554497, 52.90707662701607, 49.473801255226135, 53.08713376522064, 55.53528539836407, 50.27737073600292, 52.86242142319679, 52.811796739697456, 52.50136099755764, 47.46215879917145, 49.99648600816727, 48.56078624725342, 48.243176490068436, 55.43434001505375, 55.93850456178188, 54.74810443818569, 46.80837728083134, 53.76543916761875, 55.193752124905586, 47.937171310186386, 50.683143362402916, 52.65271447598934, 52.52297803759575, 45.08932292461395, 44.53218162059784, 48.49517896771431, 47.53361776471138, 51.964145824313164, 52.37246431410313, 51.848571226000786, 54.39023204147816, 51.71338967978954, 50.333299934864044, 47.376583591103554, 39.83001373708248, 39.28583733737469, 39.298543855547905, 43.38818080723286, 40.654717683792114, 42.46555991470814, 43.93130846321583, 40.97950905561447, 39.87415976822376, 39.228133633732796, 40.90676575899124, 41.03229962289333, 43.43516908586025, 46.327813267707825, 52.2465580701828, 56.73407167196274, 56.39063850045204, 54.779509752988815, 54.438398256897926, 51.53465487062931, 50.97116030752659, 49.64998260140419, 49.2067401856184, 53.17908123135567, 54.99120019376278, 55.270302817225456, 54.819795191287994, 53.056112229824066, 49.51506704092026, 49.205904230475426, 45.75810223817825, 48.32311660051346, 60.95265470445156, 60.04803724586964, 61.66685678064823, 58.72417688369751, 62.544685676693916, 61.951624900102615, 63.950560837984085, 61.29350781440735, 64.4693773984909, 64.21008691191673, 63.01043048501015, 46.55020773410797, 14.745470713824034, 0.7887417264282703, 0.6501608469989151, 0.3098740254063159, 23.689156249165535, 71.74062922596931, 55.65173774957657, 47.32036180794239, 21.66187383234501, 25.50933837890625, 53.52445229887962, 63.92020806670189, 65.2251872420311, 17.429923117160797, 0.32414083485491574, 0.152537812537048, 0.1780161281931214, 0.12583594769239426, 0.14437176869250834, 0.16390226053772494, 0.10125375309144147, 0.16672116005793214, 0.24024774902500212, 0.09124917938606814, 0.1027624354173895, 0.1970345084555447], [0.0528165721334517, 0.0009769742177923035, 0.029362497662077658, 0.03161725733662024, 0.06051535237929784, 0.018320293893339112, 0.07289906599908136, 0.030587382716475986, 0.06334617821266875, 0.07688353813136928, 0.050309664075030014, 0.025840192429313902, 9.85957508906722, 43.69485855102539, 46.56707122921944, 40.47339901328087, 29.484757259488106, 21.118677780032158, 25.027649626135826, 39.40473295748234, 41.719500347971916, 54.48522314429283, 4.985559526830912, 0.24306905310368165, 0.11248234353843145, 10.055969450622797, 10.879866890609264, 2.2613821551203728, 25.3272008523345, 47.3938612639904, 50.27570262551308, 54.42286089062691, 53.80514703691006, 50.075863748788834, 48.70658062398434, 43.376207649707794, 43.76906096935272, 48.36421899497509, 48.848275020718575, 49.56237830221653, 49.24235187470913, 47.02583961188793, 47.74856463074684, 51.20445638895035, 48.76714937388897, 47.84769371151924, 48.2608113437891, 49.105452820658684, 49.63964715600014, 45.141410529613495, 42.315346375107765, 40.029347240924835, 38.02245453000069, 37.43385851383209, 35.47894321382046, 35.92007294297218, 35.48538386821747, 35.10781332850456, 37.622883170843124, 38.25332634150982, 38.043102622032166, 37.66648583114147, 36.92060485482216, 36.11653760075569, 37.8188044577837, 34.812519773840904, 35.77504612505436, 37.383815199136734, 36.98006026446819, 36.586880162358284, 34.38800275325775, 39.92776729166508, 53.70143160223961, 46.452385783195496, 39.49365198612213, 50.68924963474274, 50.86018726229668, 49.94768522679806, 51.25620201230049, 49.44862760603428, 52.064262852072716, 50.38067199289799, 51.27666771411896, 48.5531410574913, 46.299018412828445, 46.564000993967056, 51.32983826100826, 50.98997309803963, 41.00231543183327, 48.536934927105904, 51.097435131669044, 46.20331294834614, 47.17068023979664, 49.66908037662506, 52.90306404232979, 44.93068143725395, 45.6547249853611, 48.35541486740112, 49.817074835300446, 50.90133145451546, 52.088041976094246, 49.73022289574146, 48.901776149868965, 46.07221998274326, 44.918567687273026, 41.19436472654343, 37.06572286784649, 36.64909802377224, 35.9633032232523, 36.86160922050476, 37.23617032170296, 34.91528145968914, 36.389720141887665, 38.78890000283718, 38.808438554406166, 38.64427976310253, 39.00697410106659, 37.3380808532238, 39.440591633319855, 38.45596566796303, 39.74567726254463, 45.15619933605194, 46.50696225464344, 49.39511887729168, 51.17321066558361, 50.53272843360901, 50.877662524580956, 49.38734449446201, 48.21935936808586, 47.40779131650925, 50.36584138870239, 51.50972440838814, 53.23368430137634, 49.30454693734646, 49.732472375035286, 45.14975868165493, 42.28151299059391, 43.56449894607067, 53.69332663714886, 54.59987819194794, 58.20047378540039, 53.7774845212698, 61.244110465049744, 56.32828004658222, 61.32268264889717, 57.66550429165363, 61.05168119072914, 51.43046826124191, 63.77840727567673, 43.41230571269989, 8.0754036270082, 0.55801507900469, 0.14279053400969133, 0.05483440116222482, 13.938465267419815, 59.709452614188194, 48.586887046694756, 34.356612637639046, 32.27664224803448, 42.870238199830055, 42.86918185651302, 46.686821803450584, 50.727528780698776, 11.801830418407917, 0.3865610057255253, 0.013584384250862058, 0.04984984050679486, 0.05246503162197769, 0.11387871665647253, 0.007421682248605066, 0.05507597394171171, 0.07602454672451131, 0.054716273516532965, 0.06649675095104612, 0.03826068503258284, 0.023731424334982876, 0.04405913678056095, 0.08192211971618235, 0.03582037730666343, 0.02026034770096885, 0.018437501275911927, 0.007982385486684507, 0.07300583136384375, 0.022781679399486165, 0.0896529236342758, 0.09291436581406742, 0.023780103656463325, 0.030264589295256883, 11.59344770014286, 51.623839884996414, 52.5225068628788, 46.09928213059902, 32.842165902256966, 22.260531708598137, 26.43488511443138, 41.673750802874565, 46.52419053018093, 59.5431849360466, 5.803632354363799, 0.27866484539117664, 0.35035156121011823, 5.0173828192055225, 7.381337620317936, 3.234945251606405, 29.02313143014908, 50.80979436635971, 53.92932817339897, 56.381670981645584, 56.592871248722076, 52.027697414159775, 49.363979548215866, 45.09115822613239, 43.70805524289608, 48.05137038230896, 49.67301316559315, 50.06569929420948, 51.11515358090401, 48.92211265861988, 50.03726541996002, 52.24538393318653, 51.64561651647091, 48.86790096759796, 47.944254130125046, 50.4058912396431, 50.95069460570812, 47.8796461969614, 44.03214365243912, 41.63531206548214, 40.073132291436195, 39.580462127923965, 37.1190720051527, 37.66283802688122, 37.889545261859894, 35.92030853033066, 38.272633105516434, 38.79083029925823, 39.50716786086559, 38.43427263200283, 38.31867903470993, 36.87351018190384, 37.5748423486948, 37.54898853600025, 38.45930568873882, 39.25314389169216, 39.36518467962742, 38.3099927008152, 36.48285314440727, 42.02732563018799, 55.26190906763077, 49.28227253258228, 40.28175629675388, 51.887158155441284, 52.522571459412575, 51.400294080376625, 52.31320269405842, 51.723500937223434, 52.30045437812805, 52.32289977371693, 53.39905522763729, 50.016294345259666, 48.93134616315365, 49.298524260520935, 52.773190811276436, 53.181771486997604, 41.94410629570484, 50.4320452362299, 51.69863507151604, 48.10912728309631, 49.9111919850111, 50.73507137596607, 53.81413355469704, 45.83792455494404, 47.9890613257885, 52.26901486515999, 51.98249503970146, 53.30031372606754, 53.2272132486105, 52.08626367151737, 49.66663330793381, 49.844007790088654, 47.694425135850906, 43.792129531502724, 38.80249947309494, 37.83968433737755, 37.85734198987484, 38.63734893500805, 38.32757815718651, 37.61276811361313, 39.02819596230984, 40.430742502212524, 40.62013953924179, 42.383940294384956, 40.72837293148041, 40.269357562065125, 40.27506485581398, 40.83218336105347, 42.63962857425213, 46.76854021847248, 49.98475223779678, 51.702947840094566, 52.16169722378254, 51.57317340373993, 51.45613208413124, 50.31366638839245, 49.35493603348732, 48.80934230983257, 52.225647792220116, 54.57050956785679, 55.50455264747143, 53.598525524139404, 51.78703352808952, 47.317998334765434, 44.37650017440319, 46.278583109378815, 55.969351306557655, 56.28276988863945, 59.65147912502289, 55.39973147213459, 62.73594081401825, 59.20100949704647, 62.248438373208046, 59.09429222345352, 60.78878469765186, 52.71268665790558, 61.98364198207855, 44.17716667056084, 11.240214854478836, 0.39434625359717757, 0.09448460186831653, 0.08564783463953063, 15.30308224260807, 65.4447090625763, 51.77651569247246, 39.87639404833317, 26.902123242616653, 45.12085363268852, 49.76973697543144, 52.86904066801071, 59.880717024207115, 15.964738838374615, 0.3480902669252828, 0.022513619369419757, 0.08240401846705936, 0.07225097811897285, 0.08302158923470415, 0.006061794501874829, 0.016609606391284615, 0.06579655688256025, 0.023821734430384822, 0.05535541109566111, 0.1344173270626925, 0.030067860789131373, 0.09928455328918062, 0.08403568208450451, 0.24475827027345076, 0.1555194947286509, 0.14439425576711074, 0.18664001778233796, 0.16434554534498602, 0.13770746067166328, 0.16236861236393452, 0.20164576882962137, 0.10479510368895717, 0.10414611038868316, 13.237258493900299, 60.39338931441307, 60.46314217150211, 54.535426050424576, 41.20571091771126, 30.784376822412014, 33.8871668279171, 53.07316951453686, 52.23018854856491, 67.24196702241898, 6.702986620366573, 0.5414176289923489, 0.5643128254450858, 19.143306277692318, 19.22616273164749, 4.123936761170626, 29.02620356529951, 51.21694631874561, 55.43979272246361, 57.38221809267998, 59.99650441110134, 55.09458124637604, 51.97050668299198, 47.58900359272957, 46.809190437197685, 51.115708351135254, 52.40805700421333, 52.29206062853336, 54.206781685352325, 52.0749668776989, 52.64262981712818, 56.69780261814594, 51.970179900527, 49.958351254463196, 49.191977977752686, 50.89574955403805, 53.767593652009964, 48.927930146455765, 47.05926641821861, 44.89840216934681, 43.157696574926376, 42.121837958693504, 38.82549203932285, 39.010450914502144, 39.89993758499622, 37.86136977374554, 40.25091715157032, 42.281182408332825, 40.95580592751503, 42.36883230507374, 40.307165533304214, 38.20989467203617, 41.736409440636635, 38.76374535262585, 38.810281455516815, 41.47394612431526, 40.947716161608696, 40.63064217567444, 39.42413471639156, 44.57049876451492, 56.79338648915291, 53.10843542218208, 42.3523335903883, 52.25068084895611, 53.112740591168404, 53.2186409085989, 56.188918724656105, 53.27537566423416, 55.372517332434654, 53.998917639255524, 56.37158252298832, 53.81105192005634, 52.397588565945625, 50.152380242943764, 55.37990793585777, 53.02459292113781, 44.71237935125828, 52.47250534594059, 54.36126619577408, 50.2034343034029, 51.42405420541763, 52.88689970970154, 55.213499665260315, 48.61395299434662, 48.22606600821018, 50.082099214196205, 55.10366655886173, 55.47643035650253, 56.196130737662315, 55.18191196024418, 51.77995450794697, 52.6947820186615, 49.037949442863464, 46.11529067158699, 41.931255385279655, 39.5658291131258, 39.710487350821495, 40.90302675962448, 40.545762330293655, 37.88014456629753, 40.835739970207214, 43.606596887111664, 42.61358477175236, 43.811588287353516, 42.93945148587227, 41.24541498720646, 43.686236813664436, 42.58176147937775, 43.39703433215618, 48.94467584788799, 52.47512720525265, 55.16275718808174, 56.25193454325199, 53.17574121057987, 52.08062097430229, 53.35221894085407, 50.35988710820675, 50.09867012500763, 53.47964510321617, 55.82702614367008, 57.53044433891773, 54.20276150107384, 53.71550604701042, 49.81679365038872, 46.158745139837265, 48.71364824473858, 58.69356572628021, 57.410625368356705, 62.19959199428558, 57.669406682252884, 64.90858063101768, 61.5206254273653, 64.45699766278267, 60.508762523531914, 62.37075001001358, 53.06075178086758, 62.92766332626343, 45.21623611450195, 14.771819449961185, 1.1026685312390327, 0.33022018207702786, 0.12629272474441677, 16.77761022001505, 71.16155549883842, 61.98000177741051, 45.61345919966698, 43.002775087952614, 56.838231682777405, 56.79421864449978, 62.01645702123642, 68.06021511554718, 22.11876131594181, 0.5562270968221128, 0.10417570723802783, 0.1456619775854051, 0.15366414037998766, 0.13038893463090062, 0.0936290317622479, 0.17570518422871828, 0.16557569964788854, 0.10222491269814782, 0.15046926884679124, 0.3076253179460764, 0.14540316100465134], [0.038897625854588114, 0.057240043170168065, 0.13977834954857826, 0.010914429130934877, 0.021152696790522896, 0.024039447162067518, 0.019961880025221035, 0.08247432953794487, 0.05155671708052978, 0.03216915916709695, 0.08880785491783172, 0.05963388874079101, 8.6799549870193, 44.239703714847565, 49.107177928090096, 46.79632432758808, 37.22693681716919, 19.35000568628311, 22.026110887527466, 34.95550990104675, 41.0740327835083, 50.61528280377388, 2.8733165189623833, 0.11248635855736211, 0.10022293965448625, 2.7541608503088355, 4.636525930836797, 2.653884468600154, 25.545569434762, 52.01817512512207, 55.483927354216576, 53.68481129407883, 49.656700640916824, 47.19827055931091, 46.25173754990101, 47.83045023679733, 51.38889089226723, 52.358587458729744, 52.83616863191128, 53.805960193276405, 51.30690649151802, 48.346489146351814, 49.128452986478806, 49.5783906430006, 51.94366492331028, 46.86728172004223, 46.86712972819805, 47.1403768658638, 48.33633229136467, 46.648835241794586, 42.057549208402634, 38.13357576727867, 36.54782585799694, 36.97251006960869, 37.02143244445324, 37.38750860095024, 37.8011430054903, 35.67101530730724, 37.16422118246555, 37.57236488163471, 37.37248420715332, 36.58936142921448, 36.721476539969444, 37.73850716650486, 36.77478767931461, 37.0312587171793, 34.88616742193699, 36.01102486252785, 35.65448239445686, 35.903053656220436, 36.18106573820114, 37.08086125552654, 48.31330172717571, 47.92124256491661, 41.89564749598503, 45.064954832196236, 47.6700684428215, 49.969971030950546, 53.41797821223736, 52.727707251906395, 49.84717682003975, 51.641505137085915, 52.49172851443291, 52.256053760647774, 47.760761976242065, 45.7433096319437, 48.16585063934326, 52.538074627518654, 44.55181136727333, 49.16016228497028, 49.442141354084015, 48.60818110406399, 48.94440606236458, 50.40993042290211, 51.903710067272186, 42.21854276955128, 37.291461154818535, 50.61219736933708, 49.0057347714901, 48.54157827794552, 48.03559362888336, 47.61191636323929, 44.00816693902016, 45.183531269431114, 43.05711217224598, 39.36682239174843, 37.065187096595764, 36.50967210531235, 37.171220406889915, 38.23396638035774, 37.4347248673439, 38.10355357825756, 36.130980625748634, 38.79751034080982, 40.16878455877304, 38.57576943933964, 38.83307263255119, 37.34300918877125, 39.3299263715744, 37.80261732637882, 36.76994673907757, 38.48471112549305, 42.63902060687542, 46.505567729473114, 47.479075491428375, 49.56069119274616, 50.92652790248394, 50.693201422691345, 51.55122198164463, 49.578580632805824, 48.64661984145641, 50.56123070418835, 52.13564582169056, 52.31804743409157, 52.251072227954865, 48.397983983159065, 45.04107691347599, 41.726529970765114, 51.338106617331505, 54.48529154062271, 57.15367555618286, 55.252242386341095, 54.351675510406494, 53.91816437244415, 59.48934942483902, 58.43179777264595, 60.76271049678326, 57.52543620765209, 58.243989050388336, 39.71347779035568, 15.960116386413574, 0.09401945339050144, 0.036604278211598285, 0.0819974031765014, 8.159552961587906, 54.09428112208843, 49.79329951107502, 42.23856769502163, 37.749264389276505, 28.921614177525043, 34.24136482179165, 50.37576265633106, 50.45970395207405, 15.195844396948814, 0.17735247005475685, 0.06220315204700455, 0.06524717464344576, 0.02434414331219159, 0.08058937091846019, 0.015745290074846707, 0.059486835889401846, 0.01637423240026692, 0.011046152922062902, 0.05612846180156339, 0.07616104994667694, 0.04023934721772093, 0.01196697636260069, 0.04952627525199205, 0.08468384417938069, 0.01612550717254635, 0.06564537397935055, 0.013211032946855994, 0.012310983147472143, 0.05258566772681661, 0.04371778966742568, 0.021852920544915833, 0.058533383926260285, 0.0512070950207999, 10.911532491445541, 50.29263451695442, 56.47696986794472, 50.60189612209797, 41.07057496905327, 20.54080478847027, 24.834464192390442, 41.475519239902496, 46.17579862475395, 55.29836431145668, 3.665118981152773, 0.1104561764805112, 0.34705197263974696, 5.088581023737788, 6.338626071810722, 2.638907809741795, 25.942872315645218, 53.90262320637703, 54.7273575514555, 56.172344014048576, 53.05210344493389, 49.52438034117222, 47.865370362997055, 48.3992113173008, 53.082395419478416, 54.58834581077099, 56.053585186600685, 54.75286938250065, 54.02607858181, 50.37589944899082, 50.59472970664501, 50.46229161322117, 53.233764097094536, 47.7772530913353, 46.72240689396858, 49.87148031592369, 48.70185747742653, 48.960019424557686, 43.2435567677021, 40.57891935110092, 38.74888814985752, 37.28001996874809, 38.23533050715923, 39.642588794231415, 39.81255367398262, 38.348070457577705, 38.97335730493069, 39.237925708293915, 39.1150289028883, 37.52937398850918, 38.785738572478294, 38.0518801510334, 39.16887201368809, 38.29825893044472, 38.2991024851799, 38.17207530140877, 36.70288413763046, 38.346953317523, 37.12922126054764, 38.66240859031677, 50.272503197193146, 52.32529744505882, 42.833433374762535, 45.83247944712639, 48.17777059972286, 51.834044605493546, 55.0057116150856, 53.91637846827507, 52.827041521668434, 53.39817747473717, 53.028772696852684, 55.81140898168087, 49.96316559612751, 47.774513438344, 50.074621215462685, 55.00945441424847, 46.23791389167309, 50.95229052007198, 52.37770803272724, 49.53904375433922, 51.20909973978996, 51.85533866286278, 54.25092771649361, 44.1855376213789, 38.86543169617653, 52.71232187747955, 51.71465881168842, 51.210995838046074, 51.35153129696846, 51.42048619687557, 46.909881234169006, 47.73359343409538, 44.765644893050194, 40.28716720640659, 39.475116580724716, 38.01326282322407, 37.89001263678074, 40.92141017317772, 39.7318422049284, 39.55178126692772, 37.50586465001106, 39.18513134121895, 41.128787845373154, 41.154995039105415, 40.97290500998497, 39.87678922712803, 41.18830405175686, 39.24327962100506, 39.601307809352875, 39.888378605246544, 43.742325603961945, 48.79434831440449, 50.27785710990429, 51.07575349509716, 52.339337691664696, 53.49703297019005, 52.51690596342087, 52.06894800066948, 50.05871146917343, 52.84557692706585, 54.105790704488754, 54.695146679878235, 53.8813329488039, 50.75637303292751, 48.00939783453941, 45.20952567458153, 55.256676748394966, 56.25413462519646, 58.03419470787048, 57.32500076293945, 58.541110306978226, 56.11901767551899, 61.40360310673714, 60.06196729838848, 62.21556253731251, 58.29072654247284, 58.49299728870392, 44.93788585066795, 18.996318764984608, 0.09583448685589246, 0.013000297331018373, 0.03144423302728683, 8.937134686857462, 58.61810177564621, 54.58833821117878, 45.42142130434513, 44.21750150620937, 37.76305764913559, 40.22641986608505, 58.19862328469753, 59.679320231080055, 21.78665153682232, 0.05833437331602909, 0.024638050490466412, 0.05315506197803188, 0.02830614692356903, 0.09513240773230791, 0.04425861865456682, 0.035354145293240435, 0.03104437313595554, 0.028026179134030826, 0.05590660417510662, 0.021281938097672537, 0.018299528601346537, 0.08121537248371169, 0.10871140213566832, 0.22859276505187154, 0.10429652887978591, 0.11804298890638165, 0.07794450502842665, 0.14280105766374618, 0.17127717495895922, 0.1412809462635778, 0.218068576650694, 0.20336945133749396, 0.0995109009090811, 12.65986617654562, 61.16545848548412, 63.29476162791252, 58.67432735860348, 48.80150333046913, 29.65009778738022, 31.179610714316368, 48.42894472181797, 51.068271696567535, 59.99529227614403, 3.9559076400473714, 0.25765179481823, 0.7399337610695511, 10.01166382804513, 11.445695478469133, 4.821932706981897, 29.80889316648245, 53.15056376159191, 56.051183715462685, 57.178803607821465, 56.35669872164726, 51.333432868123055, 49.9760203063488, 49.60273213684559, 56.829484552145004, 56.30175366997719, 58.55699345469475, 57.01413184404373, 56.56114675104618, 52.54939801990986, 53.000517413020134, 52.12460741400719, 54.32280085980892, 48.44562582671642, 48.102200254797935, 50.47637365758419, 51.62241876125336, 53.374208360910416, 44.780308306217194, 42.29950122535229, 40.45620873570442, 38.33098277449608, 40.61201177537441, 42.40708865225315, 42.1966103464365, 39.45781230926514, 40.60396760702133, 41.045207530260086, 42.034860625863075, 39.45242419838905, 39.89730052649975, 41.48183070123196, 39.788470566272736, 39.37163293361664, 38.31518702208996, 40.974538922309875, 38.36422339081764, 39.957006722688675, 39.52471151947975, 41.696990355849266, 52.51566722989082, 53.67688491940498, 46.68049514293671, 46.74678258597851, 49.397721737623215, 52.161454036831856, 58.72402869164944, 57.019056379795074, 53.80182981491089, 55.70003695785999, 55.810599625110626, 57.82345041632652, 51.292015090584755, 50.089345425367355, 50.89333288371563, 56.62576608359814, 51.345558017492294, 53.14148984849453, 54.142998307943344, 54.089535176754, 53.40693600475788, 53.81229065358639, 53.48646953701973, 46.455102637410164, 43.57176035642624, 55.01990765333176, 53.54078382253647, 52.83487290143967, 53.50562050938606, 51.99583612382412, 48.75283174216747, 50.40559485554695, 46.87168948352337, 43.04399527609348, 42.65710763633251, 40.96745990216732, 40.623152777552605, 41.830093413591385, 41.522511318325996, 42.96097733080387, 40.07337547838688, 42.10179403424263, 43.68557184934616, 42.86159746348858, 42.06102982163429, 41.81591257452965, 44.61054861545563, 41.99669547379017, 40.71934461593628, 41.88865587115288, 46.79581515491009, 51.24589316546917, 52.41219878196716, 53.257182240486145, 54.07495155930519, 54.13520112633705, 54.956219270825386, 53.495752438902855, 52.22590617835522, 54.253583773970604, 55.62208794057369, 57.26609632372856, 55.201819092035294, 52.58506290614605, 50.15649542212486, 47.91172407567501, 55.88522382080555, 58.21211256086826, 61.5966821461916, 59.39611002802849, 60.811157897114754, 56.085689663887024, 62.90601588785648, 60.75829513370991, 64.23575833439827, 60.051886439323425, 61.307430267333984, 44.29959610104561, 20.8733344450593, 0.14428821770707145, 0.7365088979713619, 0.2667554235085845, 10.439871400594711, 64.335518181324, 62.1108515560627, 54.493613094091415, 46.08333058655262, 38.551241755485535, 47.27734811604023, 66.21432736515999, 69.58171427249908, 30.393115617334843, 0.3171439853031188, 0.13669524545548484, 0.17454568238463253, 0.18685034243389964, 0.16079096967587247, 0.13232233322924003, 0.20473849115660414, 0.21184706361964345, 0.08564751551602967, 0.1237789295555558, 0.1335187049699016, 0.18065461161313578], [0.040355196470045485, 0.0662756132078357, 0.02653428789926693, 0.006685770931653678, 0.04245865078701172, 0.050651274650590494, 0.040781556599540636, 0.04487935839279089, 0.02018536295508966, 0.024134462473739404, 0.012293769032112323, 0.07156227991799824, 4.670610101893544, 40.95168314874172, 51.89338982105255, 42.79178760945797, 28.952080942690372, 21.64969738572836, 23.166404999792576, 33.1609345972538, 42.57947780191898, 49.12771962583065, 3.0369889363646507, 0.17732312553562224, 0.22703268157783896, 2.1000145515426993, 4.043219592422247, 2.8327541705220938, 19.88955583423376, 51.587985008955, 54.37857046723366, 52.24835157394409, 50.53176328539848, 51.486739441752434, 53.64693492650986, 53.91112335026264, 52.837521359324455, 52.1193028986454, 50.264991000294685, 49.81664165854454, 50.82130014896393, 51.46505780518055, 49.87549290060997, 51.28144405782223, 44.08347889780998, 45.724052265286446, 46.911587342619896, 47.09059193730354, 51.19503289461136, 47.803524881601334, 42.95644797384739, 40.69437615573406, 37.19153791666031, 37.098579704761505, 36.320491656661034, 35.992535054683685, 36.29628695547581, 36.27253443002701, 35.9899739921093, 37.206729501485825, 35.97628712654114, 36.14280939102173, 36.50537833571434, 36.98907718062401, 36.56247407197952, 37.19572529196739, 37.01608993113041, 35.59721186757088, 37.6896607875824, 34.32247146964073, 34.53963741660118, 34.51893612742424, 41.521557569503784, 50.294283628463745, 51.23985528945923, 47.220833748579025, 44.94630239903927, 48.54591004550457, 47.5314062833786, 48.023289889097214, 46.369352638721466, 48.445584028959274, 51.1535619199276, 52.38544441759586, 51.30523078143597, 48.350725919008255, 50.55782608687878, 50.772153586149216, 42.38853804767132, 47.41496533155441, 52.75256931781769, 52.208822295069695, 51.89381539821625, 50.13726465404034, 49.26968760788441, 45.655279755592346, 44.231085777282715, 49.499123096466064, 47.81098008155823, 46.69902674853802, 43.18684481084347, 42.92342394590378, 42.84492775797844, 37.96607695519924, 36.127800196409225, 35.919867753982544, 36.93179905414581, 36.96384273469448, 35.606411173939705, 36.46481931209564, 35.729155987501144, 36.11348636448383, 36.149151250720024, 38.76303859055042, 37.52940818667412, 37.602284476161, 38.155257403850555, 37.35781319439411, 38.46101179718971, 37.96800725162029, 39.21224668622017, 40.14608457684517, 39.224128648638725, 41.742857694625854, 43.585853800177574, 45.52497334778309, 47.52924419939518, 50.76361924409866, 50.19159033894539, 52.334466353058815, 52.50532038509846, 54.18178282678127, 50.170733258128166, 52.34018884599209, 52.5834745913744, 50.860897824168205, 50.79244829714298, 43.007141053676605, 47.735918909311295, 51.83234229683876, 54.868227392435074, 56.074552461504936, 58.55018422007561, 56.329028606414795, 58.609822019934654, 58.004233315587044, 59.455310851335526, 59.819867089390755, 66.84793576598167, 65.23818254470825, 25.915086306631565, 0.13287668785778806, 0.04588749921822455, 0.05585909559158608, 5.187266478314996, 50.04846341907978, 52.594011425971985, 39.8321758210659, 28.714960366487503, 29.2978547886014, 42.13601119816303, 50.31295582652092, 50.96488304436207, 9.94458032771945, 0.13475623622070998, 0.04810529622773174, 0.09178626423818059, 0.08182674631825648, 0.05656162371451501, 0.08875948915374465, 0.018038099660770968, 0.017858670616988093, 0.020753417629748583, 0.0223189595999429, 0.027601852489169687, 0.01585262503795093, 0.03287251107394695, 0.029227564082248136, 0.014172878600220429, 0.020669517834903672, 0.012867648638348328, 0.045892694251961075, 0.021200366791163106, 0.07235772121930495, 0.051631317764986306, 0.03519885089190211, 0.05038388626417145, 0.03891823158483021, 6.289128502830863, 46.56549051403999, 56.636603102087975, 50.486393719911575, 31.73507820814848, 25.65761972218752, 28.406403623521328, 34.08529579639435, 47.24376551806927, 52.77071334421635, 3.674758351407945, 0.27498806768562645, 0.0871079285570886, 2.87039827555418, 3.419558582827449, 3.3527394058182836, 23.87738484889269, 50.54932974278927, 56.81252986192703, 52.7767588198185, 52.377917021512985, 54.53555904328823, 54.80819821357727, 54.57465514540672, 55.300401002168655, 53.2367317378521, 51.38461232185364, 51.566086784005165, 51.379550993442535, 51.0648974776268, 52.26470969617367, 51.098335683345795, 46.92289933562279, 46.36264979839325, 46.33504427969456, 48.458875715732574, 52.3582074791193, 49.964301735162735, 45.798706859350204, 41.858607083559036, 38.45630764961243, 38.40460002422333, 38.157427087426186, 36.54613494873047, 38.05095300078392, 38.379532769322395, 35.90177312493324, 39.919137954711914, 38.16149286925793, 37.61357747018337, 37.869592532515526, 37.80993193387985, 37.977183759212494, 38.664357885718346, 38.23506832122803, 37.25687921047211, 38.111772537231445, 37.17634633183479, 36.95885360240936, 37.1394769102335, 43.78631204366684, 52.27192170917988, 53.10376167297363, 47.322227507829666, 46.27146229147911, 48.93492557108402, 48.549576848745346, 49.855217188596725, 47.83608913421631, 50.10167956352234, 52.6662303507328, 53.76748725771904, 51.91519685089588, 49.9981465190649, 49.43088635802269, 53.89608755707741, 43.47572050988674, 48.885509222745895, 55.957929119467735, 51.96102999150753, 53.1438647210598, 51.70291364192963, 51.19147248566151, 47.50043794512749, 44.49247755110264, 51.10265605151653, 50.89207135140896, 50.78242063522339, 45.194774866104126, 44.797236397862434, 44.538018107414246, 40.281836092472076, 39.59265947341919, 37.254261150956154, 38.14886994659901, 38.580990359187126, 37.16212369501591, 37.92681746184826, 37.46720552444458, 37.48816519975662, 38.21152098476887, 38.56921099126339, 39.540191888809204, 39.35589037835598, 39.262700378894806, 39.81367841362953, 40.14853924512863, 39.670912474393845, 41.17977350950241, 40.79339884221554, 41.629023402929306, 43.604427203536034, 46.484011486172676, 46.791164204478264, 49.38271254301071, 51.70533791184425, 52.421238496899605, 54.20603312551975, 54.74040985107422, 55.17473794519901, 52.59295888245106, 52.292755991220474, 54.689477384090424, 53.62217925488949, 52.1477709710598, 47.238628193736076, 49.74300540983677, 53.483593091368675, 58.68684008717537, 58.25988359749317, 60.214179530739784, 58.335484340786934, 60.60979910194874, 58.82049411535263, 61.196339428424835, 62.314011454582214, 66.21211588382721, 68.1270383298397, 28.957735039293766, 0.09660586030804552, 0.08795887508313172, 0.10470416091266088, 6.153317140415311, 56.038750782608986, 58.37400287389755, 43.846831396222115, 35.42950786650181, 31.718782782554626, 47.44940288364887, 58.09301935136318, 60.05906045436859, 16.807928793132305, 0.04425739040016197, 0.021362379484344274, 0.04871122640906833, 0.16850467451149598, 0.10586992648313753, 0.043005762054235674, 0.01749138729792321, 0.03264371436671354, 0.009457086725888075, 0.028283175597607624, 0.022364306678355206, 0.05237102748651523, 0.16227061918471009, 0.19886624766513705, 0.111043779324973, 0.10844120100955479, 0.1017273472098168, 0.1628179827821441, 0.13688011444173753, 0.176221095607616, 0.10784822501591407, 0.09237850550562143, 0.21788066485896707, 0.14636667649028823, 7.675010561943054, 56.565885096788406, 64.49270814657211, 56.004355028271675, 39.443927854299545, 30.443143732845783, 31.995324343442917, 45.07635422050953, 54.45478677749634, 57.80077323317528, 3.949308106675744, 0.41106179414782673, 0.9057508071418852, 5.689880708232522, 12.374836821109056, 4.773320015519857, 22.650639675557613, 53.73703949153423, 58.337072655558586, 55.903519839048386, 54.296494871377945, 55.94379387795925, 57.9238486289978, 57.25380018353462, 56.92759908735752, 55.00454127788544, 51.42480656504631, 51.54906369745731, 53.97426836192608, 53.463081791996956, 53.54375906288624, 54.285365268588066, 47.21513785421848, 47.53412313759327, 47.56773233413696, 49.33257423341274, 54.55623373389244, 52.02647008001804, 48.238981515169144, 43.64122822880745, 40.508630722761154, 40.29810681939125, 39.14055593311787, 38.20423297584057, 40.2279207855463, 39.908574521541595, 39.03645671904087, 41.4329007267952, 40.68812929093838, 39.8897959291935, 40.35286568105221, 40.02386033535004, 38.67623224854469, 41.71491779386997, 39.659714475274086, 38.773237243294716, 41.233559623360634, 38.960871174931526, 38.90628330409527, 39.6212225407362, 45.01066714525223, 54.09740835428238, 56.05509750545025, 50.09194068610668, 46.70266315340996, 50.04307150840759, 49.38309632241726, 51.347625106573105, 48.61727021634579, 49.90571267902851, 54.83767703175545, 55.64817734062672, 54.4716502726078, 52.98980578780174, 53.54774884879589, 55.47831505537033, 46.529476046562195, 51.86465196311474, 56.97704963386059, 55.89672200381756, 56.33929185569286, 55.11048339307308, 52.17389076948166, 48.80675844848156, 46.32231876254082, 54.015982523560524, 54.012836292386055, 52.26049952208996, 47.45229072868824, 46.641691625118256, 46.72027140855789, 42.763691917061806, 41.26195929944515, 39.14462171494961, 40.21269120275974, 40.73268949985504, 39.03774105012417, 40.27833268046379, 39.89400990307331, 40.274589881300926, 40.53821973502636, 41.40156380832195, 40.48387885093689, 41.13724619150162, 42.406260296702385, 41.23086176812649, 42.92531244456768, 41.600783318281174, 43.93421910703182, 42.537854835391045, 44.32198829948902, 45.9444822371006, 49.04521845281124, 47.7583909034729, 52.58725918829441, 53.917176425457, 54.8885753005743, 56.86342433094978, 59.50302869081497, 57.54343964159489, 54.958594143390656, 54.647649228572845, 57.34995402395725, 54.84143503010273, 55.814517214894295, 49.34495396912098, 51.62146881222725, 55.55094815790653, 60.08157804608345, 60.09725600481033, 62.71832875907421, 60.813620164990425, 65.34908339381218, 61.8818112462759, 64.7827997803688, 62.8767042607069, 70.4576888680458, 62.53425903618336, 28.446081094443798, 0.16977742809103802, 0.287808965658769, 0.1978175633121282, 6.680797236040235, 60.45245334506035, 66.14422112703323, 50.091146528720856, 39.321122244000435, 41.30421683192253, 55.494619980454445, 64.18332114815712, 67.78373435139656, 25.790508091449738, 0.37030078761745244, 0.1320424841833301, 0.19979313074145466, 0.1899235462769866, 0.1435772402328439, 0.1776918541872874, 0.13310519512742758, 0.11472830505226739, 0.11651190114207566, 0.15238684485666454, 0.13600298494566232, 0.08828845544485375], [0.04992334281268995, 0.01588496412296081, 0.05522646664758213, 0.17630525515414774, 0.033686788083286956, 0.04549408673483413, 0.039096595646697097, 0.048922775604296476, 0.09287164779379964, 0.038550233948626556, 0.09568310357281007, 0.03508964757202193, 4.945724839344621, 36.76748067140579, 52.42787294089794, 33.862217366695404, 39.22319009900093, 17.826916314661503, 16.930071339011192, 33.92778664827347, 38.25866125524044, 51.81401968002319, 2.134229578077793, 0.18388488359050825, 0.3409997880226001, 4.593761125579476, 3.26044924557209, 2.5444018933922052, 19.8273778706789, 48.28620158135891, 54.823439195752144, 53.961805030703545, 52.627343237400055, 52.381390035152435, 51.8577591329813, 51.8146238476038, 51.744468212127686, 50.81221103668213, 49.05856333673, 49.29517664015293, 47.185237258672714, 46.31466217339039, 45.73076270520687, 45.91140501201153, 46.48219898343086, 50.19917093217373, 48.31305854022503, 48.77911873161793, 48.19213002920151, 45.924643501639366, 42.320354506373405, 37.271728813648224, 35.44412948191166, 35.09044446051121, 35.66036067903042, 34.76727560162544, 34.35115613043308, 35.14889672398567, 35.30599929392338, 36.493283584713936, 34.40460026264191, 35.47834284603596, 36.579386964440346, 36.32001668214798, 35.706064626574516, 36.91062659025192, 35.98647817969322, 35.51127187907696, 37.36810304224491, 36.39823168516159, 34.106266871094704, 34.47086110711098, 36.9707165658474, 45.97563676536083, 48.93038481473923, 51.47389233112335, 50.486059337854385, 50.81545606255531, 50.766244903206825, 50.45851081609726, 51.038998067379, 46.91925913095474, 45.37345267832279, 50.49402751028538, 52.67224162817001, 47.58547358214855, 48.06942321360111, 50.3631017357111, 43.40439833700657, 47.60989107191563, 51.43866442143917, 46.60403944551945, 50.553870499134064, 50.311090126633644, 48.14155854284763, 50.83282873034477, 50.218306705355644, 48.700352758169174, 46.95048965513706, 44.20582853257656, 42.55821794271469, 41.09044790267944, 36.95827603340149, 35.897992327809334, 36.41352966427803, 37.24994458258152, 37.0438664406538, 36.53655186295509, 36.6823386400938, 37.53038853406906, 37.79198169708252, 36.46825052797794, 36.52813531458378, 38.33593770861626, 36.54154859483242, 38.70312720537186, 38.624209240078926, 39.26812268793583, 38.96391861140728, 38.621283397078514, 38.38589742779732, 40.18799252808094, 36.54679611325264, 37.15003654360771, 36.345756500959396, 40.312713235616684, 43.92624333500862, 46.85954913496971, 49.177090376615524, 50.59822551906109, 49.80915226042271, 49.8643708974123, 50.712709575891495, 50.95119997859001, 50.008557960391045, 53.158927112817764, 49.61915485560894, 41.295173317193985, 43.52530024945736, 48.71205233037472, 54.652425572276115, 55.70571765303612, 56.820087656378746, 55.122414752840996, 54.533427357673645, 56.33511207997799, 57.53552846610546, 55.9434898942709, 64.22435894608498, 62.12478160858154, 20.06447184830904, 0.11281314844381995, 0.026327074701839592, 0.07152350270189345, 3.3510254602879286, 49.96467411518097, 51.823667362332344, 43.987002074718475, 33.67078743875027, 26.416220515966415, 33.664464578032494, 46.57808303833008, 51.37926980853081, 14.238347075879574, 0.20999504893552512, 0.061998660676181316, 0.08085755340289325, 0.04812826569832396, 0.040885717025958, 0.03241026810428593, 0.0422853630152531, 0.06246733435546048, 0.03399290915695019, 0.03998745116405189, 0.022580106524401344, 0.04980853998858947, 0.07799839237122796, 0.008855666947056307, 0.07554705633083358, 0.07443918570061214, 0.06916818572790362, 0.002742067986218899, 0.01578380382852629, 0.04075499142345507, 0.03190891024132725, 0.08380643266718835, 0.06751197928679176, 0.034046173095703125, 6.181403808295727, 43.463948741555214, 58.735895454883575, 41.3972282409668, 40.907077342271805, 20.788863077759743, 21.528989262878895, 44.3970000743866, 45.207697972655296, 55.76747193932533, 2.9652383364737034, 0.09515353667666204, 0.5219080508686602, 4.810983119532466, 4.607961438596249, 5.582852326333523, 23.826023004949093, 49.67327915132046, 58.73472511768341, 55.66617697477341, 55.594873800873756, 54.744076654314995, 53.4005181491375, 53.191685155034065, 52.42858350276947, 50.80608956515789, 47.898968160152435, 47.752915397286415, 48.090512081980705, 46.57994493842125, 46.350365057587624, 46.391809433698654, 48.18294212222099, 49.11587946116924, 50.20647034049034, 50.319141894578934, 50.52933521568775, 49.237434938549995, 43.38240511715412, 39.161716997623444, 37.16199070215225, 37.041905745863914, 36.87548987567425, 36.80718474090099, 35.8334793895483, 36.68178386986256, 36.67099244892597, 36.79712288081646, 38.18948596715927, 36.92206397652626, 38.0656012147665, 37.724352926015854, 36.9612854719162, 37.50810652971268, 37.565601244568825, 38.311668410897255, 37.314563915133476, 38.023875653743744, 35.939736887812614, 35.843180269002914, 38.06170642375946, 46.72147214412689, 50.8088406175375, 53.19504417479038, 50.69282524287701, 49.73396189510822, 51.51420056819916, 52.684161588549614, 50.640300661325455, 46.78790397942066, 48.27509097754955, 52.018821090459824, 53.76458801329136, 50.471369326114655, 50.608728155493736, 51.44751034677029, 45.42351879179478, 49.41527299582958, 52.079671025276184, 48.82000833749771, 53.32750126719475, 51.54876731336117, 48.605718836188316, 51.68506219983101, 51.37450486421585, 51.659797355532646, 48.08573953807354, 45.20923689007759, 44.85672600567341, 42.40857437252998, 38.72697472572327, 39.250780418515205, 38.245073184370995, 39.710719138383865, 39.409490302205086, 39.213067442178726, 37.94102109968662, 38.71563993394375, 40.1334198564291, 36.67081765830517, 38.6439947783947, 38.937339037656784, 37.93164700269699, 40.33293575048447, 40.174070075154305, 40.51978312432766, 39.44627232849598, 39.89070788025856, 41.58152975142002, 41.54477432370186, 38.76304239034653, 39.627788588404655, 39.52737137675285, 43.25632028281689, 46.213127821683884, 50.49912303686142, 52.433819621801376, 52.4584499001503, 53.47927652299404, 52.681307941675186, 51.860137805342674, 53.28756920993328, 53.83008509874344, 55.919296592473984, 52.28736028075218, 44.29229289293289, 46.58054530620575, 51.47163525223732, 56.73517741262913, 59.03925597667694, 59.149484261870384, 56.73666313290596, 57.59313337504864, 59.71587806940079, 58.882145807147026, 59.25438143312931, 67.5763338804245, 62.12665490806103, 22.28332668542862, 0.1629652248811908, 0.05723225804104004, 0.09109027814702131, 3.559820456430316, 53.09500694274902, 57.498024478554726, 45.19034430384636, 36.19866639375687, 30.58705911040306, 40.898220017552376, 53.00496697425842, 59.506710693240166, 20.10600931942463, 0.42436301009729505, 0.05517836434592027, 0.06608881463762373, 0.038295046470011584, 0.06840289788669907, 0.033606914439587854, 0.06705593696096912, 0.03175203506543767, 0.009405785767739872, 0.06845617666840553, 0.04153902220423333, 0.01667517513851635, 0.27747521235141903, 0.12444150415831245, 0.11121213552542031, 0.30402049887925386, 0.18999936408363283, 0.10979452956235036, 0.07880849851062521, 0.18107563199009746, 0.16406731418101117, 0.13994401175295934, 0.22074281674576923, 0.09953974818927236, 7.958236914128065, 52.519432827830315, 66.38097122311592, 47.3268024623394, 51.42370842397213, 25.43745193630457, 24.694211818277836, 48.02342668175697, 48.69812987744808, 60.015252605080605, 3.9774940442293882, 0.3356252139201388, 0.8956946467515081, 14.529862683266401, 6.978744473308325, 5.454770224168897, 22.411366514861584, 51.42284967005253, 57.40288898348808, 58.823628947138786, 57.30776108801365, 56.29793867468834, 55.21061562001705, 53.68500508368015, 53.14466267824173, 50.92987932264805, 48.8750521838665, 47.98816457390785, 48.46537336707115, 44.871617406606674, 45.63796028494835, 47.17395566403866, 48.76980163156986, 50.311143323779106, 52.02250689268112, 50.74645556509495, 50.87421610951424, 51.20104417204857, 46.50871016085148, 42.61394575238228, 39.24991026520729, 38.71288888156414, 39.70252297818661, 38.598458021879196, 37.01956294476986, 39.04594860970974, 38.987830728292465, 38.660816475749016, 39.36866529285908, 38.85565482079983, 40.34388296306133, 39.56655107438564, 38.852504789829254, 40.623487159609795, 38.49991410970688, 39.55492749810219, 39.902973622083664, 40.59187665581703, 37.31821931898594, 37.3133859783411, 40.357630625367165, 50.210110545158386, 51.33137717843056, 55.97618333995342, 53.81362818181515, 53.07247415184975, 54.01337966322899, 53.356653302907944, 54.090390130877495, 48.37261654436588, 47.0138930529356, 52.35291436314583, 56.02688021957874, 53.24214644730091, 52.77662202715874, 53.068013191223145, 49.98700551688671, 51.17106758058071, 55.777207016944885, 50.501828491687775, 55.94379387795925, 53.869887962937355, 51.17318406701088, 54.623311534523964, 54.210091307759285, 52.91255213320255, 52.324013113975525, 46.58761292695999, 48.94951678812504, 44.75114867091179, 40.632963851094246, 39.70297895371914, 40.63134893774986, 40.30613958835602, 41.43793545663357, 41.50700055062771, 40.025881826877594, 40.916622430086136, 42.41329371929169, 38.854195699095726, 40.60416519641876, 40.89682549238205, 40.36555700004101, 41.42394840717316, 43.45772087574005, 42.85258434712887, 41.851094886660576, 41.0136616230011, 43.45403507351875, 42.8662446141243, 41.14455699920654, 41.23677425086498, 39.373327642679214, 44.95220348238945, 48.283864706754684, 52.030535861849785, 55.25698833167553, 54.44427654147148, 56.871658489108086, 54.7080659866333, 54.44691359996796, 55.8846690505743, 52.919919937849045, 56.71557806432247, 53.355300575494766, 45.67970484495163, 48.46365585923195, 53.26740749180317, 59.28692288696766, 60.654841884970665, 61.907197684049606, 59.28493559360504, 59.67951022088528, 61.88030272722244, 61.5321160107851, 61.728326082229614, 70.53659543395042, 61.525994539260864, 25.40076870471239, 0.35629114718176425, 0.14642722089774907, 0.2466026705224067, 4.272776199504733, 58.852389603853226, 64.90290373563766, 56.66018083691597, 46.56693063676357, 38.42148631811142, 49.483730122447014, 62.7170330286026, 70.12555629014969, 30.55651444941759, 1.213003566954285, 0.18029789091087878, 0.17476863838965073, 0.19635070842923597, 0.15542911598458886, 0.11195106228115037, 0.14947908057365566, 0.12385217953124084, 0.16869602986844257, 0.1403078719158657, 0.1581061168690212, 0.10560298338532448], [0.0847724566119723, 0.0650757533730939, 0.03562380465155002, 0.09835497621679679, 0.057987504624179564, 0.06602533132536337, 0.07911174747277983, 0.04508711521339137, 0.07188241273979656, 0.02630977895023534, 0.07055758265778422, 0.08757050920394249, 2.5600570533424616, 36.84420995414257, 50.518859177827835, 42.942354530096054, 28.35280939936638, 32.526752427220345, 26.831654123961926, 28.243749551475048, 38.02852660417557, 48.16801272332668, 3.675954812206328, 0.10212680077529512, 0.1482187060173601, 2.253588060848415, 2.5387570587918162, 5.362016251310706, 20.398572720587254, 42.72395744919777, 55.81466160714626, 51.77652709186077, 53.824294209480286, 51.93626292049885, 54.501235485076904, 52.34661430120468, 54.131868705153465, 53.054687306284904, 54.52186077833176, 54.184898659586906, 52.63982556760311, 51.784719452261925, 48.026694506406784, 47.78307817876339, 51.42364002764225, 50.3620757907629, 49.608260840177536, 48.79453830420971, 46.26203119754791, 42.45837830007076, 39.31162655353546, 37.77641773223877, 35.476564541459084, 35.1918838173151, 34.175966531038284, 35.23008316755295, 35.431863740086555, 36.096448078751564, 36.45182780921459, 35.80490492284298, 36.016013994812965, 35.75162038207054, 35.681434348225594, 36.51835843920708, 35.14752499759197, 35.68173833191395, 35.67856930196285, 36.96722835302353, 35.45113630592823, 35.31027406454086, 34.881018698215485, 35.524183586239815, 33.65208484232426, 38.745950907468796, 43.4691658616066, 46.42318055033684, 49.03905138373375, 47.72103130817413, 46.439660266041756, 47.23135158419609, 50.26885159313679, 47.94327758252621, 47.93997175991535, 50.658771470189095, 48.61960709095001, 49.619629830121994, 48.07916969060898, 52.325377240777016, 44.030616134405136, 47.834618613123894, 52.358055487275124, 52.72388845682144, 49.50411222875118, 48.54634702205658, 51.29364900290966, 49.45052370429039, 50.01799285411835, 48.67209367454052, 49.182964861392975, 48.92503850162029, 47.31481410562992, 45.66755309700966, 41.67453356087208, 37.77624674141407, 36.06583312153816, 37.847990691661835, 36.55716195702553, 36.00368745625019, 35.966027677059174, 38.97307612001896, 36.446496695280075, 36.03682927787304, 36.9196131080389, 35.87409920990467, 38.31257276237011, 38.07110331952572, 38.43542777001858, 36.941534131765366, 38.779358714818954, 39.05408017337322, 39.39107649028301, 38.042304664850235, 38.68491478264332, 38.81908178329468, 37.488271594047546, 39.20807830989361, 38.97353209555149, 41.24127320945263, 44.960483238101006, 46.05036735534668, 48.206337466835976, 51.02042846381664, 51.38550907373428, 52.016541212797165, 53.49290259182453, 54.339318573474884, 47.93687492609024, 47.286327034235, 41.88821129500866, 48.63195642828941, 54.16035197675228, 56.34110815823078, 57.219723612070084, 55.87792061269283, 54.29373621940613, 53.76037023961544, 55.04320800304413, 60.70112720131874, 60.31316041946411, 59.50131878256798, 16.242866814136505, 0.11056343908421695, 0.12741136393742636, 0.03649730504548643, 2.182062123902142, 47.486424297094345, 51.885607838630676, 49.12118777632713, 29.12212561815977, 25.061857290565968, 42.00933359563351, 48.87293569743633, 52.22315892577171, 23.20888862013817, 0.538521115668118, 0.02038282618741505, 0.021318603903637268, 0.03859495947835967, 0.04373510768346023, 0.03396991371118929, 0.09348378604045138, 0.0623253540834412, 0.07282013859366998, 0.03491106828732882, 0.07643090968485922, 0.036733827510033734, 0.017104232974816114, 0.11166326483362354, 0.04364711494417861, 0.027981809835182503, 0.03891701446264051, 0.099521899537649, 0.01335885299340589, 0.03490643728582654, 0.059577986467047594, 0.061674331009271555, 0.07595278846565634, 0.029014191059104633, 3.8504067761823535, 44.73144292831421, 57.7591996639967, 47.26286709308624, 36.967688128352165, 40.46308256685734, 28.977816961705685, 34.17707607150078, 42.34357126057148, 54.13572169840336, 3.485164912417531, 0.06488655766588636, 0.10223330638837069, 4.812542935833335, 4.508068598806858, 7.763005765154958, 23.572827391326427, 44.8853612691164, 55.73274940252304, 53.32598514854908, 53.5223738104105, 54.36076462268829, 56.57460182905197, 54.391542971134186, 54.52701710164547, 55.14246627688408, 56.12236149609089, 54.619055762887, 54.15589861571789, 52.52395838499069, 47.17877380549908, 48.64833354949951, 50.844965279102325, 50.71603059768677, 50.801856592297554, 50.06459355354309, 47.637397795915604, 45.102367624640465, 40.08066348731518, 38.54061372578144, 36.83949060738087, 37.011248990893364, 35.98019331693649, 38.042912632226944, 37.160398587584496, 38.34737129509449, 37.79021859169006, 36.87718078494072, 36.973877996206284, 36.23786889016628, 37.18440189957619, 38.134890496730804, 37.91359797120094, 37.4483547359705, 37.29047320783138, 38.48976485431194, 37.05716572701931, 37.68578499555588, 36.076195165514946, 37.18607380986214, 35.04212625324726, 40.88987186551094, 46.95620454847813, 49.99334737658501, 50.462724789977074, 50.49837067723274, 50.163863226771355, 50.39821185171604, 51.01393461227417, 48.38018573820591, 50.43231502175331, 51.79642662405968, 51.276192739605904, 51.20703265070915, 49.6662837266922, 53.05773474276066, 45.80163270235062, 49.707063138484955, 53.234706446528435, 52.56209313869476, 50.981636345386505, 50.18209844827652, 52.50142179429531, 50.32063141465187, 52.41227477788925, 51.878935396671295, 49.37912933528423, 51.00880488753319, 48.28203320503235, 47.474633529782295, 43.503823801875114, 39.675388634204865, 38.43162417411804, 39.51907642185688, 38.64734619855881, 37.5786155462265, 37.52424046397209, 40.21319277584553, 38.63451048731804, 37.830378636717796, 36.67316973209381, 38.225101456046104, 40.690306574106216, 38.73821832239628, 39.739684984087944, 39.11001697182655, 40.15238083899021, 40.08682295680046, 41.00853189826012, 40.35370923578739, 40.18948584794998, 40.010070875287056, 40.16383722424507, 39.88135278224945, 41.03867568075657, 42.83867709338665, 45.63198320567608, 47.51724064350128, 50.062496066093445, 53.70839282870293, 54.19884771108627, 55.43527476489544, 55.50196498632431, 53.63242730498314, 51.18174880743027, 48.3098629117012, 43.89915078878403, 51.76048435270786, 55.20806595683098, 58.243723064661026, 59.09424662590027, 58.9262842386961, 56.326380148530006, 55.70322498679161, 58.0804306268692, 63.49118448793888, 62.321284264326096, 61.99897415935993, 16.709458976984024, 0.4115535115124658, 0.2894459059461951, 0.0712401581404265, 2.5536114117130637, 50.05327396094799, 56.73300012946129, 50.97103491425514, 34.664118736982346, 31.001269184052944, 50.90896524488926, 55.569608956575394, 58.65567795932293, 27.80027724802494, 0.7305197662208229, 0.0257776701982948, 0.04689126137236599, 0.029910369630670175, 0.07921261276351288, 0.0669140531681478, 0.08607712996308692, 0.10871139471419156, 0.05631344210996758, 0.04996430565370247, 0.04660415041144006, 0.0113923406934191, 0.23368591675534844, 0.13894307718146592, 0.14002541051013395, 0.21075781347462907, 0.14945779577828944, 0.15982617769623175, 0.13783657952444628, 0.09316539726569317, 0.227154616441112, 0.2643970859935507, 0.18327388825127855, 0.15515133010922, 5.778062576428056, 53.4457965195179, 62.436687871813774, 54.163699597120285, 39.908677116036415, 43.46844010055065, 34.831788539886475, 39.55175466835499, 48.085040375590324, 61.12791270017624, 4.285551588982344, 0.24172226287191734, 0.539138107560575, 7.1933764312416315, 11.350901015102863, 9.588732272386551, 23.295107893645763, 45.335048139095306, 57.73685686290264, 52.992089465260506, 54.97331075370312, 54.17377665638924, 57.80646912753582, 57.30624496936798, 58.03313836455345, 59.314110428094864, 59.623410031199455, 58.08664329349995, 55.65856218338013, 55.39658144116402, 49.109518602490425, 51.3726619631052, 54.15686376392841, 54.33436743915081, 53.45370389521122, 52.07622081041336, 49.76689092814922, 47.0925260335207, 43.13667610287666, 41.98971524834633, 38.700733333826065, 40.231971368193626, 37.334569841623306, 40.51626831293106, 39.65353600680828, 40.06784677505493, 41.22628301382065, 40.25448516011238, 39.43372920155525, 39.16780807077885, 39.833729937672615, 40.09477213025093, 38.305957317352295, 39.37465377151966, 39.08044695854187, 40.45287251472473, 38.61268825829029, 39.56055499613285, 40.27720794081688, 38.62724147737026, 36.3872654736042, 43.71315836906433, 49.63384486734867, 50.4906190931797, 53.843160197138786, 51.25111788511276, 54.17145498096943, 52.595177963376045, 55.02904996275902, 51.04227349162102, 52.827060520648956, 55.35752333700657, 51.84019647538662, 53.49993981420994, 51.54419995844364, 56.388582810759544, 49.79592137038708, 52.23413273692131, 54.47175286710262, 54.843300729990005, 52.90476255118847, 51.45611688494682, 54.72720555961132, 53.1964311003685, 54.248697236180305, 53.76898057758808, 51.714385226368904, 54.667252376675606, 50.66255986690521, 50.16162894666195, 45.63672915101051, 42.4373996257782, 39.357927069067955, 41.496999487280846, 41.206592470407486, 39.4569231569767, 39.62255246937275, 42.61478170752525, 40.2096513658762, 40.53981564939022, 39.92348492145538, 39.69999611377716, 42.53242492675781, 41.202690079808235, 42.57595159113407, 40.91949887573719, 42.792752757668495, 43.70701029896736, 42.97559514641762, 41.63398593664169, 42.54860445857048, 42.66348369419575, 41.976275369524956, 43.466247618198395, 42.22000189125538, 44.895362332463264, 49.114587530493736, 49.67486746609211, 52.97405183315277, 54.973557740449905, 56.67422108352184, 56.14076770842075, 57.784228920936584, 57.12002836167812, 53.204821050167084, 51.01202331483364, 45.28563179075718, 52.06740528345108, 58.25560502707958, 61.190423145890236, 61.76821634173393, 59.630595445632935, 60.06050057709217, 58.5101305693388, 60.201875790953636, 67.3211319744587, 65.6410825252533, 66.17938444018364, 17.57530901581049, 0.5687548464629799, 0.8821360243018717, 0.25275130465161055, 2.860249732621014, 54.89587850868702, 65.81254452466965, 59.489140436053276, 40.60093156993389, 37.561930641531944, 53.66770461201668, 63.249297067523, 68.53202819824219, 38.054927587509155, 1.7846457241103053, 0.12262696793186478, 0.16226379142608494, 0.1224032772006467, 0.20624169643269852, 0.17869177943794057, 0.12755637959344313, 0.30377974617294967, 0.14783477818127722, 0.2851615467807278, 0.22388400131603703, 0.10620545886922628], [0.019798605680989567, 0.0268833589143469, 0.01906988531118259, 0.01129160064010648, 0.03487943053187337, 0.08371542309760116, 0.0839431511121802, 0.0585060914454516, 0.04090182534127962, 0.08675161603605375, 0.1347742704092525, 0.08070395109825768, 1.850773694459349, 36.20339713990688, 50.23995414376259, 46.568860933184624, 18.52017391473055, 11.30138112232089, 40.038797333836555, 41.5739681571722, 38.54217544198036, 42.06323370337486, 4.131260393187404, 0.07813019037712365, 0.16363324684789404, 2.9620930552482605, 4.032175010070205, 7.500200467184186, 22.442519143223763, 42.02846936881542, 56.56932391226292, 54.05994236469269, 55.65032422542572, 52.50051364302635, 49.163867086172104, 50.27793310582638, 50.174077078700066, 46.04011930525303, 50.285794883966446, 48.09821806848049, 51.83621808886528, 50.66770099103451, 53.21999363601208, 51.21660053730011, 51.430494859814644, 47.69178807735443, 44.32021379470825, 42.0939626544714, 39.222319945693016, 38.10854271054268, 35.33935770392418, 35.67221984267235, 36.15624167025089, 35.2843252569437, 35.20897530019283, 34.4928353279829, 34.53872166574001, 36.15653045475483, 35.432874485850334, 33.767830431461334, 35.64685620367527, 35.726154148578644, 36.578091233968735, 33.80705572664738, 35.89882828295231, 35.64674600958824, 35.74758879840374, 36.397524923086166, 35.78865699470043, 35.461315959692, 37.43581160902977, 35.04725977778435, 35.05886435508728, 35.92292279005051, 36.54018446803093, 39.42697696387768, 43.009379133582115, 43.25581111013889, 46.54085263609886, 48.291103318333626, 49.6485310792923, 49.99244682490826, 48.895388692617416, 48.687817230820656, 51.3212963193655, 50.04803404211998, 47.75259241461754, 53.37277963757515, 45.805592089891434, 48.20248827338219, 51.07579909265041, 50.38809299468994, 52.568302005529404, 52.260024547576904, 49.604434445500374, 50.615715980529785, 48.833809196949005, 50.15277922153473, 51.59601017832756, 50.72644963860512, 48.65171916782856, 50.019877552986145, 48.362706676125526, 43.666409477591515, 36.699593514204025, 35.86973324418068, 37.89369463920593, 36.8292273581028, 35.155424773693085, 40.584581047296524, 37.8994969278574, 36.74530886113644, 35.59834040701389, 36.996688172221184, 36.17109887301922, 38.45983766019344, 36.73519380390644, 37.83238112926483, 37.848119884729385, 36.90938785672188, 37.79400318861008, 37.09939286112785, 37.134818360209465, 38.547495156526566, 38.175536915659904, 39.11696679890156, 37.68671974539757, 37.90090665221214, 39.31933254003525, 38.95792633295059, 39.78838697075844, 42.94052682816982, 44.25153627991676, 48.55995409190655, 51.46673731505871, 50.450823828577995, 49.550044164061546, 42.330249175429344, 38.80183830857277, 47.14172579348087, 56.07621677219868, 56.957229897379875, 57.303281128406525, 54.35739800333977, 52.61680260300636, 51.48141972720623, 57.85329021513462, 58.25113266706467, 60.53074054419994, 53.64395588636398, 11.169954724609852, 0.25574367376975715, 0.08246756115113385, 0.04956565360771492, 1.9605585909448564, 45.06590098142624, 55.86294561624527, 47.14250095188618, 33.84650520980358, 18.607105650007725, 25.265585258603096, 48.86617586016655, 52.71527051925659, 27.920721285045147, 0.628011419903487, 0.018301604759471957, 0.061982522674952634, 0.036850741744274274, 0.020125846422160976, 0.031984783709049225, 0.02275773586006835, 0.016262685749097727, 0.04655922079109587, 0.06319020103546791, 0.014168546313158004, 0.06761699318303727, 0.05207000496739056, 0.05929776263656095, 0.06396416458301246, 0.011111257826996734, 0.043621173172141425, 0.0203697792312596, 0.04299398045986891, 0.0735607129172422, 0.06055853053112514, 0.12093948738765903, 0.10325264622224495, 0.07252153547597118, 2.6231011329218745, 45.87023042142391, 58.0776833742857, 53.54894958436489, 23.123045526444912, 16.702598445117474, 29.928068071603775, 36.1968918889761, 45.684348195791245, 48.875587955117226, 4.979412881657481, 0.17101929348427802, 0.2505333221051842, 5.446150861680508, 7.254573572427034, 8.371070511639118, 20.18195204436779, 45.4402606934309, 56.92725330591202, 57.72466331720352, 56.10586658120155, 55.44734671711922, 51.14143677055836, 52.51908704638481, 53.37368778884411, 48.56757268309593, 51.875428184866905, 50.454828813672066, 53.797539845108986, 53.79911296069622, 51.49221494793892, 50.90490706264973, 53.540403842926025, 48.84643591940403, 46.23078927397728, 43.285354524850845, 41.33049622178078, 37.75478549301624, 37.756176218390465, 37.04100899398327, 36.96209862828255, 37.726807594299316, 38.37577097117901, 36.411929950118065, 36.77927903831005, 37.66536869108677, 36.72322444617748, 36.37226767838001, 36.518715620040894, 38.111411556601524, 37.40887105464935, 35.50152160227299, 38.62284891307354, 38.350247740745544, 37.39326909184456, 38.48797135055065, 37.75050312280655, 36.43685661256313, 37.66104452311993, 37.706782668828964, 35.56871339678764, 37.423914447426796, 39.31796081364155, 41.97054907679558, 44.391228184103966, 45.88084325194359, 48.882480785250664, 50.96190020442009, 51.46222695708275, 50.86598575115204, 49.79742608964443, 51.82364836335182, 52.74302802979946, 52.1836144477129, 49.25346627831459, 54.43198040127754, 48.775170743465424, 49.07280497252941, 53.193828240036964, 50.48947535455227, 53.954346030950546, 52.678879871964455, 49.9942821264267, 52.227722480893135, 50.93733452260494, 51.06159545481205, 53.458484038710594, 51.602454632520676, 51.82026654481888, 52.52175070345402, 51.33319728076458, 46.528241112828255, 39.32579219341278, 37.51700185239315, 38.610461577773094, 37.805706560611725, 37.65006311237812, 41.29929229617119, 39.85902138054371, 38.55731002986431, 38.26873451471329, 38.60439330339432, 37.553768679499626, 40.515344962477684, 37.573489621281624, 38.376891911029816, 40.752501636743546, 38.365313932299614, 40.30634477734566, 39.647536128759384, 37.326704263687134, 40.52755370736122, 40.62046632170677, 40.02936244010925, 40.21073430776596, 38.94483983516693, 40.76561093330383, 41.024008467793465, 43.866476342082024, 43.87042433023453, 47.67244711518288, 51.10070675611496, 54.10937011241913, 52.91958935558796, 50.34951366484165, 43.44698265194893, 42.17120870947838, 48.61734241247177, 58.68933655321598, 59.74867790937424, 59.39568065106869, 58.7590666115284, 54.53948423266411, 55.14054737985134, 59.59113076329231, 60.47234147787094, 61.92749619483948, 54.97564762830734, 12.802971247583628, 0.450628031976521, 0.8282159676309675, 0.05630315965390764, 2.1634419355541468, 47.955976501107216, 60.35227172076702, 48.582452684640884, 36.947587206959724, 23.299044482409954, 34.52410385012627, 53.70190657675266, 60.71183502674103, 34.80871617794037, 1.0385495843365788, 0.06572537749889307, 0.05901567230466753, 0.029416084435069934, 0.08329425429110415, 0.08712869384908117, 0.014545764206559397, 0.02513076975446893, 0.02341824543691473, 0.08356703809113242, 0.05761591870395932, 0.027280678805254865, 0.18319100519875064, 0.14702801912790164, 0.1342656766064465, 0.11441992784966715, 0.14322611532406881, 0.15554308018181473, 0.22469546558568254, 0.08034825455979444, 0.19347883440786973, 0.22782456799177453, 0.20246815751306713, 0.17945635481737554, 4.505037311464548, 55.543591752648354, 62.47683271765709, 60.67179657518864, 27.895939014852047, 19.031550474464893, 49.27175849676132, 53.84850651025772, 51.598989218473434, 56.10488623380661, 5.525971753522754, 0.3369141760049388, 0.6614014157094061, 10.425188038498163, 10.57526383548975, 12.452906481921673, 26.52254831045866, 46.499978229403496, 58.012801855802536, 58.96132975816727, 60.3238682448864, 58.7425222992897, 52.86638841032982, 55.76380893588066, 54.74981054663658, 50.14551021158695, 54.26124796271324, 52.904819548130035, 56.20342634618282, 56.58955402672291, 56.0991295427084, 53.843433782458305, 55.63153803348541, 51.98763616383076, 49.589189663529396, 44.81126144528389, 44.064495116472244, 41.92672222852707, 39.256620705127716, 39.12010543048382, 38.97819824516773, 37.932045981287956, 39.32939060032368, 39.68741878867149, 38.47757890820503, 40.53733438253403, 39.71749797463417, 38.49708326160908, 39.04583461582661, 40.737545639276505, 40.61051465570927, 37.30076305568218, 40.460962280631065, 40.398733019828796, 38.62274631857872, 41.10160410404205, 40.322763696312904, 39.07630518078804, 40.06797596812248, 39.14368696510792, 37.22804255783558, 39.41742807626724, 41.042042300105095, 43.33349034190178, 46.71382315456867, 47.457002475857735, 51.29092834889889, 53.202609568834305, 53.18794995546341, 53.961292058229446, 52.256388142704964, 52.34127938747406, 56.61694295704365, 54.9064077436924, 51.48563750088215, 58.90327647328377, 51.677846387028694, 50.493047162890434, 54.72687117755413, 54.88546706736088, 56.793435886502266, 53.68791572749615, 51.32590927183628, 54.776971489191055, 53.07249315083027, 52.551727294921875, 56.4312469214201, 52.91699789464474, 53.317929580807686, 55.48990823328495, 53.13055783510208, 48.83242227137089, 41.25279039144516, 39.55794833600521, 42.22844883799553, 39.39249761402607, 39.16894420981407, 44.676060900092125, 40.97616903483868, 40.89816302061081, 39.05982166528702, 41.1470914632082, 39.68250185251236, 42.19270035624504, 40.5134716629982, 41.12886764109135, 42.46465176343918, 40.289146900177, 42.095657363533974, 40.92812821269035, 39.787930995225906, 42.52841234207153, 42.33868472278118, 43.301245272159576, 41.476822569966316, 40.914597138762474, 44.73316803574562, 43.436081036925316, 45.57565122842789, 46.55170105397701, 48.66051569581032, 53.68932165205479, 56.81072875857353, 56.901730075478554, 53.35448741912842, 46.35050944983959, 44.27132561802864, 51.374379470944405, 60.6091683357954, 61.92419797182083, 61.10418677330017, 59.90327641367912, 56.06900475919247, 56.130873039364815, 62.79579520225525, 63.64321053028107, 64.9799408018589, 56.40910170972347, 15.304937493056059, 1.506517748348415, 1.6310122492723167, 0.2274093363666907, 2.831619931384921, 52.59958192706108, 68.5124896466732, 59.856208339333534, 46.38279251754284, 28.17267246544361, 38.889765590429306, 62.71835155785084, 70.7640740275383, 44.307465478777885, 1.8530865828506649, 0.1342976334854029, 0.12593069026479498, 0.09181384244584478, 0.12321255955612287, 0.24102765717543662, 0.17861314147012308, 0.05197805287025403, 0.10747512511443347, 0.14402396860532463, 0.19711181055754423, 0.15259289473760873], [0.03561056102626026, 0.012107104976166738, 0.017746843805070966, 0.050579987655510195, 0.05899219075217843, 0.045103976808604784, 0.03835994728433434, 0.07889429078204557, 0.02982710622745799, 0.047044904495123774, 0.03164749614370521, 0.15080084558576345, 2.4602437717840075, 34.06846269965172, 52.217527627944946, 45.48804312944412, 35.49701884388924, 39.452021420001984, 56.24321021139622, 46.86460666358471, 35.47560319304466, 45.40420442819595, 6.819237107411027, 0.3566799435066059, 0.0653723230061587, 3.1553855957463384, 2.738308575935662, 6.3339912705123425, 21.136160641908646, 48.540263548493385, 58.88908423483372, 50.610700249671936, 53.691130355000496, 50.358203798532486, 49.3243932723999, 43.26007068157196, 41.287600323557854, 40.17802566289902, 41.481545716524124, 43.273107782006264, 46.7773063480854, 45.998602733016014, 47.87296615540981, 44.988016560673714, 44.75628599524498, 39.59200590848923, 37.52332091331482, 37.19124533236027, 37.02321834862232, 36.63984552025795, 34.460328072309494, 36.60519897937775, 37.542988657951355, 37.02267877757549, 35.5009326338768, 36.13713629543781, 33.74256558716297, 35.89368715882301, 33.803905695676804, 33.58645856380463, 34.62496183812618, 35.993933379650116, 35.77522471547127, 35.503448098897934, 35.61006277799606, 36.49006135761738, 36.301713064312935, 34.136555045843124, 35.082407891750336, 35.76249159872532, 36.779127046465874, 35.61390057206154, 35.917861461639404, 38.03036190569401, 36.25937573611736, 36.64046868681908, 36.312390491366386, 40.46165384352207, 46.04436747729778, 47.395244389772415, 50.65407112240791, 50.91320961713791, 51.664486303925514, 50.65141126513481, 50.92213533818722, 53.83855104446411, 48.452222272753716, 52.37130917608738, 44.512764662504196, 44.10758100450039, 51.9574885815382, 48.837943375110626, 51.761445701122284, 49.90487292408943, 50.739232152700424, 50.12406036257744, 50.245851427316666, 48.86508531868458, 47.350148409605026, 47.44862012565136, 47.289769649505615, 48.68421882390976, 50.84077030420303, 49.234501495957375, 40.98023861646652, 37.99589395523071, 35.55810436606407, 37.151951640844345, 35.76383672654629, 37.857843562960625, 36.063572242856026, 37.669233083724976, 36.41717366874218, 36.729760095477104, 37.96627074480057, 36.48443765938282, 37.523309513926506, 37.70122356712818, 37.191055342555046, 38.059909120202065, 35.32263860106468, 38.00053350627422, 36.08461171388626, 39.19382527470589, 38.58119174838066, 39.424932673573494, 37.679933309555054, 38.72282914817333, 39.574963822960854, 37.14418865740299, 38.59610974788666, 39.721377566456795, 39.08133611083031, 40.12796334922314, 40.40883667767048, 41.6386216878891, 40.907643511891365, 41.90989293158054, 41.63083590567112, 47.33545459806919, 55.86293041706085, 55.116179287433624, 55.8956428617239, 56.41391225159168, 50.8551449328661, 52.35661156475544, 56.206093803048134, 54.64256130158901, 59.00495141744614, 54.881541877985, 11.544645968824625, 0.5558367865160108, 0.18999988358700648, 0.06237735637114383, 1.324872295372188, 42.04116448760033, 56.232540383934975, 48.92721198499203, 41.656849309802055, 31.035098768770695, 32.3115623742342, 47.26236931979656, 52.319536954164505, 23.78028865903616, 0.7878053141757846, 0.043680262970156036, 0.06475480418885127, 0.10076661477796733, 0.07521588777308352, 0.08333899837452918, 0.03394888495677151, 0.03106473210209515, 0.020011303349747322, 0.010803262830449967, 0.04362952975498047, 0.048435229109600186, 0.028519098777906038, 0.04550907811790239, 0.03307619350380264, 0.04838736800593324, 0.07774583951686509, 0.030612619448220357, 0.0465560926386388, 0.038794942302047275, 0.023380930251732934, 0.023396596989186946, 0.04016378545202315, 0.055207308105309494, 3.634739611297846, 43.802138194441795, 57.65081807971001, 50.523567125201225, 37.38538071513176, 25.474148467183113, 45.76862007379532, 47.81296357512474, 41.2649991363287, 48.6931711435318, 6.7524471413344145, 0.30955151771195233, 0.19490242208121344, 4.063876708969474, 7.169840969145298, 5.906575005501509, 18.71043350547552, 49.32249717414379, 59.05149132013321, 54.05496083199978, 55.07384195923805, 51.65985815227032, 52.769049033522606, 46.05539828538895, 43.51498380303383, 42.98645876348019, 44.720241129398346, 45.108644887804985, 48.09735931456089, 49.382784739136696, 49.38892520964146, 47.32606530189514, 46.04504004120827, 42.18644209206104, 40.758246928453445, 39.53012242913246, 38.55950631201267, 37.967669069767, 37.47312180697918, 38.20574149489403, 39.7837246209383, 37.63364039361477, 38.13530087471008, 38.158369436860085, 37.019353955984116, 37.316646203398705, 36.185389906167984, 35.188182815909386, 36.06088198721409, 38.179807886481285, 37.99869820475578, 37.51736283302307, 35.46116016805172, 37.28756256401539, 37.81180143356323, 36.83669775724411, 36.61215640604496, 36.15646965801716, 38.49157355725765, 37.12915286421776, 37.3966509103775, 38.373460695147514, 37.87979878485203, 37.191621512174606, 39.364968091249466, 42.27445676922798, 47.78112508356571, 49.70639057457447, 52.165603414177895, 51.11949674785137, 52.31066823005676, 53.36761951446533, 52.61887349188328, 55.47317013144493, 50.8072105050087, 54.29771080613136, 45.28874762356281, 45.93914732336998, 53.66770841181278, 51.56082406640053, 53.69796998798847, 52.14471593499184, 52.078538686037064, 50.565661266446114, 50.67247733473778, 49.77296680212021, 47.84704014658928, 49.4401540607214, 48.51006656885147, 52.040088549256325, 54.60642524063587, 50.75945846736431, 41.99794180691242, 37.49270595610142, 37.81631179153919, 39.08388577401638, 37.84846946597099, 38.78251254558563, 37.53431372344494, 38.79790551960468, 37.566862776875496, 38.595087602734566, 39.17722776532173, 39.79665532708168, 39.143975749611855, 39.040507301688194, 38.50925400853157, 39.04900744557381, 38.316820934414864, 39.4961104542017, 38.5487224906683, 40.76272688806057, 40.49346573650837, 41.11850179731846, 38.942373767495155, 39.823474287986755, 40.32875217497349, 40.05802810192108, 40.76977550983429, 41.92090094089508, 40.89774504303932, 42.10949622094631, 43.250958770513535, 45.34750007092953, 43.040301874279976, 44.260405004024506, 42.859389781951904, 49.68082934617996, 57.586160749197006, 57.22936749458313, 58.98776113986969, 58.86774078011513, 54.165664091706276, 53.481389209628105, 59.61123928427696, 57.74292133748531, 61.134178563952446, 56.12203851342201, 13.12720499932766, 0.08465052174869925, 0.5070631974376738, 0.06896481500007212, 1.0938777029514313, 46.940192207694054, 61.11740246415138, 55.55152952671051, 42.74310082197189, 30.819766223430634, 36.07836864888668, 52.94618412852287, 61.72876685857773, 31.504375487565994, 1.8013014178723097, 0.014495816740236478, 0.03126444775261916, 0.002263558299091528, 0.03385599033208564, 0.016674631515343208, 0.005182760005482123, 0.04549179349851329, 0.03829996690910775, 0.021436143397295382, 0.08404118139878847, 0.13469744328176603, 0.07900882643298246, 0.11571593291591853, 0.1077355002053082, 0.17778851150069386, 0.18703904090216383, 0.10152591348742135, 0.1019294785510283, 0.09553780590067618, 0.14990713651059195, 0.11696383196976967, 0.20669550489401445, 0.20043712196638808, 5.130708888173103, 56.81203208863735, 64.08995255827904, 58.77492696046829, 45.31184658408165, 54.13587749004364, 65.31755268573761, 56.257759630680084, 46.01149924099445, 55.234645530581474, 8.565159346908331, 0.44728225213475525, 0.5855530919507146, 10.938378050923347, 9.184363670647144, 12.555440180003643, 23.88637136667967, 52.97768823802471, 64.55424964427948, 56.28305107355118, 57.7814968675375, 54.62448187172413, 53.94688323140144, 46.89959138631821, 45.53376987576485, 45.01035936176777, 45.19022271037102, 47.28858791291714, 50.70359766483307, 52.90841415524483, 51.725959405303, 48.344878032803535, 49.4633100181818, 43.482514545321465, 41.24907799065113, 41.500316709280014, 40.58175019919872, 40.38669526576996, 38.099115416407585, 41.411059498786926, 41.173876225948334, 41.02651633322239, 39.57521080970764, 39.334174543619156, 38.305964916944504, 40.3369103372097, 38.07715259492397, 37.779020592570305, 37.68388129770756, 40.157795548439026, 39.29230839014053, 38.66422489285469, 37.768867537379265, 39.269414618611336, 39.70329813659191, 38.62422823905945, 37.89184033870697, 37.85986885428429, 41.58804640173912, 39.987405091524124, 39.11098212003708, 40.74613697826862, 39.99877788126469, 41.1747045814991, 40.618349835276604, 43.885634914040565, 50.226358473300934, 53.423233330249786, 55.493293851614, 53.338912054896355, 55.59898138046265, 55.14911971986294, 54.70450557768345, 58.71813900768757, 54.336765110492706, 57.03046716749668, 47.295549139380455, 46.56940810382366, 55.077523961663246, 55.19570142030716, 55.365426912903786, 55.0838316231966, 54.231693148612976, 52.74768278002739, 52.09575556218624, 50.22146053612232, 48.9223026484251, 50.93589060008526, 49.00878220796585, 53.14722754061222, 56.92027308046818, 54.40394930541515, 44.40624497830868, 41.79366856813431, 39.368353709578514, 40.40399953722954, 38.7165442854166, 41.526736691594124, 40.219732224941254, 40.56067653000355, 39.713736176490784, 41.57194286584854, 42.526064068078995, 41.78021349012852, 41.124133095145226, 41.408433839678764, 41.15289755165577, 40.80001808702946, 39.33656841516495, 41.894021183252335, 40.23035645484924, 43.20362851023674, 41.01619228720665, 42.25340969860554, 41.783306524157524, 42.353617921471596, 43.414118215441704, 42.346835285425186, 43.20911541581154, 45.052160918712616, 42.11850553750992, 44.40204240381718, 44.58887077867985, 47.13436558842659, 44.97363053262234, 46.23471826314926, 45.119937881827354, 52.31667950749397, 59.3643931299448, 59.65087115764618, 60.20975276827812, 60.525759011507034, 56.6707556694746, 56.353434696793556, 61.75042189657688, 59.68958728015423, 61.55129738152027, 59.82551358640194, 15.088775642216206, 1.2009751936420798, 1.2096287542954087, 0.20317496411735192, 2.131624105386436, 50.029054060578346, 68.8759933412075, 65.00834807753563, 54.12897706031799, 43.647159710526466, 44.534655287861824, 60.65024793148041, 69.19891521334648, 42.016853392124176, 3.2361272256821394, 0.08317550324136391, 0.09677462468971498, 0.18963707727380097, 0.12303989147767425, 0.1404413694399409, 0.07725355069851503, 0.11224444067920558, 0.15551545744528994, 0.09950034014764242, 0.15337534103309736, 0.24097711691865698], [0.05731034681957681, 0.0750024089938961, 0.036094834649702534, 0.04328722156060394, 0.059209684550296515, 0.08904961694497615, 0.06807154379202984, 0.061570337566081434, 0.04762580203532707, 0.13281277409987524, 0.03724440284713637, 0.04609677744156215, 2.962845889851451, 39.54922400414944, 56.20899684727192, 42.12485499680042, 26.320249065756798, 42.20563106238842, 76.43826395273209, 60.56682340800762, 33.946033269166946, 51.73116892576218, 7.940262453630567, 0.2192326501244679, 0.029975814068166073, 4.79858011007309, 6.412013433873653, 7.142358468845487, 27.5053408741951, 56.974465772509575, 51.97670415043831, 50.96077926456928, 51.923020631074905, 48.85350354015827, 47.59290598332882, 46.24668762087822, 43.77470746636391, 39.78263407945633, 38.60830329358578, 36.66655048727989, 37.20775164663792, 38.44381012022495, 38.2571717351675, 37.560950294137, 36.949312314391136, 35.56530877947807, 35.45005336403847, 35.53598195314407, 35.45089691877365, 36.056660413742065, 37.27749690413475, 39.62102875113487, 39.98191438615322, 40.88595427572727, 34.902818128466606, 35.752695724368095, 36.514900624752045, 36.38118959963322, 34.97003652155399, 35.29785633087158, 34.94548223912716, 35.749272108078, 36.89828485250473, 36.04346752166748, 35.023830235004425, 34.591546431183815, 37.50771515071392, 38.54960784316063, 35.195060446858406, 35.6518529355526, 35.89961864054203, 35.541712045669556, 36.736208349466324, 37.39412024617195, 34.151321053504944, 36.35343208909035, 39.11586485803127, 42.603386119008064, 45.537824258208275, 49.20439951121807, 47.03934408724308, 51.4791626483202, 49.324351474642754, 49.56659987568855, 49.790130481123924, 51.00951924920082, 49.28604193031788, 49.91956293582916, 43.09822976589203, 41.729600206017494, 45.86692839860916, 46.189246103167534, 45.91566078364849, 47.987609803676605, 47.27122664451599, 46.82259991765022, 46.93523347377777, 45.66632196307182, 43.95908497273922, 46.235793605446815, 46.22109219431877, 46.89221978187561, 48.205866292119026, 46.82018704712391, 42.21288487315178, 38.728129863739014, 36.3846892118454, 37.231640964746475, 35.78722067177296, 37.23570294678211, 35.531171411275864, 36.3787729293108, 37.638002559542656, 38.022237941622734, 37.05504544079304, 37.54559151828289, 35.89563265442848, 36.67299874126911, 37.43332274258137, 39.408597350120544, 38.96965630352497, 37.75836870074272, 37.98778139054775, 38.036654368042946, 39.026246666908264, 39.825849160552025, 41.28011092543602, 39.0364833176136, 37.76781879365444, 38.80291365087032, 38.306496888399124, 40.842154026031494, 40.40531426668167, 39.42507706582546, 38.18770006299019, 40.816626995801926, 41.22070491313934, 41.710985004901886, 40.608462765812874, 42.09211215376854, 52.28666491806507, 56.94868415594101, 55.256726145744324, 53.34584288299084, 50.47791637480259, 51.884106919169426, 55.13228662312031, 58.38903106749058, 61.85844250023365, 60.33779449760914, 13.195542432367802, 0.5461393506266177, 0.6941394496243447, 0.1023037065169774, 0.8244839741382748, 39.18755181133747, 62.02498376369476, 37.728152722120285, 44.97684895992279, 28.731626272201538, 24.588693380355835, 46.361015886068344, 52.145323902368546, 31.394631676375866, 2.0280753867700696, 0.0321642572816927, 0.028723651375912596, 0.07103252748493105, 0.01145080244896235, 0.028513977958937176, 0.07553729708888568, 0.07569846929982305, 0.04009778996987734, 0.03323715049191378, 0.021815017207700294, 0.03762058637221344, 0.043845617183251306, 0.03827823311439715, 0.051104474550811574, 0.013244494530226802, 0.021265271316224243, 0.09025061226566322, 0.06319795647868887, 0.028545010864036158, 0.07143172129872255, 0.08760772048844956, 0.06449396896641701, 0.06212402797245886, 4.065004773437977, 48.71285408735275, 61.18925280869007, 47.788158506155014, 31.807956397533417, 54.38746578991413, 78.65789204835892, 66.33183985948563, 39.34401601552963, 56.19194336235523, 8.574126865714788, 0.2602969575673342, 0.0676977240073029, 2.0657612895593047, 7.218243246898055, 4.28332538343966, 28.055262565612793, 55.27347184717655, 55.1219017803669, 52.725776955485344, 54.4368327409029, 50.62734715640545, 50.39108343422413, 47.66882210969925, 45.300994366407394, 43.05765174329281, 40.43013833463192, 37.569974809885025, 39.245943278074265, 40.15784114599228, 40.380201414227486, 39.818766340613365, 38.36418159306049, 39.60588276386261, 37.06997103989124, 37.7953977137804, 37.39611893892288, 36.398965045809746, 38.786897510290146, 40.751779675483704, 41.62462703883648, 41.29863493144512, 37.97214522957802, 37.639203295111656, 37.78682917356491, 37.266420498490334, 36.670205891132355, 35.65105877816677, 37.179066985845566, 37.66387157142162, 38.398003578186035, 37.82953128218651, 35.63166841864586, 36.15972988307476, 40.41577510535717, 38.37248794734478, 36.993036568164825, 38.03014911711216, 37.46644176542759, 36.2747573107481, 38.64201508462429, 38.1555499881506, 36.588004902005196, 39.35571178793907, 40.032991245388985, 44.25204545259476, 46.700269281864166, 50.828664153814316, 49.748283326625824, 53.18257324397564, 49.97513875365257, 51.126317381858826, 52.96619765460491, 53.42492803931236, 50.48373766243458, 51.17493197321892, 46.27416394650936, 42.68883213400841, 47.397550866007805, 47.020493298769, 46.78462475538254, 47.720218151807785, 49.42983001470566, 48.096196576952934, 50.29774144291878, 47.66039416193962, 44.53740254044533, 47.96579137444496, 47.81562343239784, 46.37914851307869, 48.86642664670944, 49.36791613698006, 44.2832075804472, 40.57331845164299, 37.471643686294556, 39.66501139104366, 37.74899460375309, 38.28286975622177, 37.845186442136765, 37.64473959803581, 38.905439749360085, 38.43020685017109, 39.29972559213638, 37.73127995431423, 37.80186876654625, 38.12489703297615, 39.57985796034336, 41.21343590319157, 40.546799674630165, 37.859602868556976, 39.23178143799305, 40.639609694480896, 41.088699996471405, 42.07847088575363, 42.198894023895264, 40.41431598365307, 39.72590692341328, 39.68377098441124, 40.94344899058342, 43.28863374888897, 41.95802114903927, 41.066258400678635, 39.93746057152748, 42.15410202741623, 42.99732618033886, 43.128343150019646, 43.32290790975094, 44.68208357691765, 55.94234995543957, 59.26339074969292, 57.86748245358467, 55.86183987557888, 52.91176937520504, 54.51226249337196, 58.75223457813263, 60.214198529720306, 62.76215560734272, 60.995216220617294, 14.410066511482, 1.0599122755229473, 0.5388611974194646, 0.0970564255840145, 0.9931205282919109, 41.98578625917435, 67.56406053900719, 44.08440224826336, 48.069047033786774, 41.135118305683136, 32.51637138426304, 53.97990345954895, 59.759541526436806, 37.47232384979725, 2.5704169599339366, 0.013622719889099244, 0.041913431996363215, 0.056761101877782494, 0.037367128097685054, 0.03111139463726431, 0.08490086300298572, 0.0152102080937766, 0.0481348745233845, 0.07632910928805359, 0.06371491428581066, 0.05336901202099398, 0.12125197608838789, 0.1487137036747299, 0.11839042534120381, 0.10235015011858195, 0.1702044004923664, 0.17410437169019133, 0.14750873786397278, 0.1340762508334592, 0.12409823859343305, 0.1412324098055251, 0.16063240240328014, 0.13295725540956482, 5.313276741653681, 60.43798752129078, 68.2678359746933, 54.93566617369652, 35.4395355284214, 54.47539307177067, 77.90478765964508, 69.09454241394997, 45.50254315137863, 64.89768281579018, 8.975720666348934, 0.26355115638580173, 1.0434567835181952, 7.846002811565995, 15.404630843549967, 9.51864218339324, 32.17465192079544, 59.91135098040104, 55.96791498363018, 55.85050128400326, 56.51200398802757, 53.141949623823166, 53.66703204810619, 49.00188557803631, 47.36301451921463, 45.874862372875214, 42.93735399842262, 40.09689621627331, 42.78670348227024, 42.5114044547081, 42.56562374532223, 41.30666010081768, 40.03721281886101, 40.7723555713892, 39.36173066496849, 38.18263493478298, 39.32679533958435, 40.26726387441158, 41.68479301035404, 42.83909127116203, 43.340056389570236, 43.900674507021904, 38.99384580552578, 38.89416955411434, 39.87987466156483, 39.026600047945976, 39.25918936729431, 38.39160092175007, 38.59096102416515, 39.29232358932495, 41.025809571146965, 39.61132027208805, 37.863794043660164, 36.61076568067074, 41.09019711613655, 41.654387041926384, 38.10507729649544, 38.78024786710739, 39.60696570575237, 37.970298528671265, 41.49628892540932, 41.538915038108826, 38.451212123036385, 40.42625114321709, 42.938239350914955, 47.26945973932743, 49.284693002700806, 53.18719759583473, 50.91120332479477, 55.3636372089386, 51.14896796643734, 52.98517003655434, 55.34365028142929, 53.67366649210453, 53.50374720990658, 52.23036713898182, 48.81124220788479, 43.22639688849449, 46.03999391198158, 47.85215467214584, 48.42280425131321, 50.614386051893234, 51.967911422252655, 49.959662184119225, 50.760902389883995, 48.310774862766266, 47.38418698310852, 50.89729227125645, 50.61266474425793, 49.72032442688942, 51.52513638138771, 53.12169291079044, 46.53457537293434, 43.707663863897324, 39.751141369342804, 41.6567999124527, 38.88183921575546, 40.21564744412899, 39.5642825961113, 38.49753923714161, 40.75841411948204, 40.65363094210625, 40.268080830574036, 40.10264910757542, 39.497729167342186, 41.953704580664635, 41.690952479839325, 43.284282982349396, 43.37577447295189, 39.23279978334904, 42.04373314976692, 42.51963101327419, 43.25928412377834, 43.46311278641224, 43.81916128098965, 42.38539561629295, 40.9221663326025, 42.348051220178604, 41.88467748463154, 47.414349764585495, 46.19173876941204, 43.87977942824364, 41.70913830399513, 44.4216987490654, 46.40302263200283, 46.075411811470985, 44.897068440914154, 45.942384749650955, 56.70157201588154, 62.10516706109047, 62.151383981108665, 59.31252971291542, 55.70294760167599, 55.260902121663094, 61.21978797018528, 64.20377165079117, 65.35583943128586, 62.998491525650024, 17.452484406530857, 2.2892781207337976, 2.86056250333786, 0.49049011955503374, 1.2538313074037433, 45.20566888153553, 72.93913051486015, 48.64974707365036, 57.70214192569256, 40.936157181859016, 37.184914872050285, 61.915899217128754, 67.75779694318771, 48.317128121852875, 4.166216142475605, 0.34593272488564253, 0.1257230225019157, 0.1660279495990835, 0.18524378567235544, 0.11893870920175686, 0.2737468108534813, 0.1680727445636876, 0.1712505763862282, 0.18654624000191689, 0.11842460124171339, 0.16830772336106747], [0.01974996346689295, 0.05894548368814867, 0.04390493704704568, 0.04195504792733118, 0.037824643586645834, 0.05655374210618902, 0.056240618869196624, 0.04157817049417645, 0.031029392885102425, 0.02938613877631724, 0.03730391195858829, 0.02647580851771636, 2.3684877203777432, 40.415341928601265, 52.2743421792984, 42.58007436990738, 22.425467558205128, 20.509982742369175, 33.15688021481037, 28.598656207323074, 39.91084299981594, 56.38027645647526, 9.168284833431244, 0.25436357595026493, 0.11905054343515076, 1.8132383585907519, 6.5424832329154015, 5.368780363351107, 41.9159422069788, 55.357682928442955, 53.3082515001297, 52.7651846408844, 52.93743319809437, 51.536991745233536, 53.06410700082779, 50.008652955293655, 49.840416982769966, 47.625272646546364, 46.282261312007904, 42.80863210558891, 39.509056359529495, 36.93163946270943, 36.0777834802866, 35.34797564148903, 36.68496049940586, 35.302929058671, 33.83593797683716, 35.375782549381256, 35.390411764383316, 36.0502615571022, 40.327935218811035, 44.04504396021366, 43.399781584739685, 43.985501155257225, 40.23733668029308, 39.754067212343216, 35.733795538544655, 37.150218933820724, 36.808472871780396, 34.183915704488754, 35.169316828250885, 34.34678636491299, 36.24666541814804, 36.06525935232639, 35.06890721619129, 35.469268932938576, 38.86203847825527, 36.8888233602047, 36.554768085479736, 35.34598454833031, 35.23275062441826, 35.1734434068203, 35.461688339710236, 36.111540868878365, 36.53001241385937, 37.582776322960854, 42.49512232840061, 47.18060530722141, 44.170433431863785, 46.95945717394352, 48.91501843929291, 49.06631492078304, 47.713264524936676, 48.95990163087845, 47.544230595231056, 50.460847690701485, 46.6031388938427, 46.7415426671505, 38.48700240254402, 40.84715835750103, 43.39592479169369, 43.40230084955692, 47.990148067474365, 47.83798523247242, 49.76619176566601, 48.49108658730984, 47.854685336351395, 46.39806769788265, 50.177713483572006, 48.54707658290863, 50.1376636326313, 46.67801387608051, 49.58542786538601, 46.97676904499531, 42.97076180577278, 38.58584649860859, 36.67714811861515, 35.743021443486214, 35.74980027973652, 36.63404703140259, 36.215351298451424, 35.14052577316761, 36.25201553106308, 35.83526909351349, 36.60214774310589, 36.086287423968315, 35.614668130874634, 36.071316227316856, 36.68658301234245, 38.2651437073946, 38.519247472286224, 38.321984857320786, 37.692651227116585, 37.103295251727104, 36.56218908727169, 39.10065807402134, 37.64263071119785, 38.13315398991108, 42.41653494536877, 37.72857829928398, 38.14044959843159, 38.904934376478195, 39.27236706018448, 40.9570636600256, 40.79654507339001, 39.32287015020847, 39.57670032978058, 41.67194589972496, 40.53349658846855, 40.396038964390755, 41.20127655565739, 43.90162445604801, 46.109685972332954, 50.66288284957409, 49.05056096613407, 50.826836451888084, 56.49480991065502, 59.29016791284084, 58.868964314460754, 61.782488375902176, 20.55190209299326, 0.36598534730728716, 0.5792873469181359, 0.022051983105484396, 0.4090745304711163, 38.431069403886795, 57.879850789904594, 48.690021112561226, 48.34557719528675, 18.605629429221153, 29.768982008099556, 49.56474557518959, 53.65300700068474, 32.98606038093567, 1.7203740729019046, 0.11710446153301746, 0.06353818665957078, 0.09950397667125799, 0.016359020228264853, 0.10920385422650725, 0.08008335236809216, 0.03756208287086338, 0.023668241592531558, 0.0405522329674568, 0.034338783370913006, 0.04705117935372982, 0.03896326510584913, 0.07526969347964041, 0.054844089900143445, 0.021137581097718794, 0.032491677993675694, 0.0006793988586650812, 0.028504300353233702, 0.0533503061888041, 0.07349094361416064, 0.01960707963007735, 0.0794634067278821, 0.009608001528249588, 3.333051949739456, 46.75760820508003, 60.18448792397976, 49.46490593254566, 26.279762238264084, 27.32114765793085, 54.60401237010956, 44.434910640120506, 42.46387280523777, 60.1714888215065, 9.926085770130157, 0.20805924577871338, 0.17450918356189504, 3.4457959374412894, 3.616306562907994, 5.587683292105794, 44.06447611749172, 57.792204692959785, 53.77107806503773, 54.60185408592224, 52.95808508992195, 52.522077485919, 54.74951036274433, 51.06923684477806, 50.60807839035988, 48.70376877486706, 46.42807088792324, 43.4189173579216, 40.06978087127209, 39.13122743368149, 37.622943967580795, 37.754667699337006, 37.549566105008125, 37.574758753180504, 37.86933034658432, 36.48110143840313, 35.890867710113525, 37.54287846386433, 41.182779148221016, 45.33652625977993, 46.28699205815792, 47.453768849372864, 41.76114231348038, 40.837214291095734, 37.62560762465, 38.51068653166294, 37.60947369039059, 36.01489305496216, 37.527766674757004, 37.12385214865208, 38.30175094306469, 38.162074238061905, 35.775737687945366, 39.29076947271824, 38.768966272473335, 38.32915507256985, 37.671049386262894, 36.29637815058231, 37.197647988796234, 37.09656201303005, 37.361495196819305, 36.80895924568176, 38.60710255801678, 38.28129664063454, 43.45747008919716, 47.95211970806122, 47.501156106591225, 49.627278819680214, 52.09307670593262, 50.822215899825096, 48.98265101015568, 50.303878113627434, 49.832011833786964, 51.30157917737961, 49.587798938155174, 49.409349113702774, 41.30784563720226, 41.323162615299225, 43.00848998129368, 44.382386058568954, 50.337175726890564, 50.88788777589798, 52.423313185572624, 51.12892024219036, 49.39165726304054, 47.79742240905762, 51.47272579371929, 50.75891129672527, 52.519603818655014, 49.476810693740845, 50.96262976527214, 50.10743625462055, 45.36376319825649, 40.70749685168266, 38.849065974354744, 38.74916933476925, 37.68466405570507, 38.83263185620308, 38.965586721897125, 36.85273289680481, 37.90818326175213, 37.803004905581474, 37.87835106253624, 38.495133966207504, 36.58518545329571, 38.14471676945686, 38.427828177809715, 40.52224539220333, 38.52135255932808, 40.328938364982605, 38.22324715554714, 38.58482055366039, 39.58101689815521, 40.70254571735859, 38.39605048298836, 39.97524954378605, 44.21402469277382, 39.93621423840523, 39.73315313458443, 42.50630132853985, 41.52390584349632, 42.77736358344555, 41.84999294579029, 42.277830988168716, 41.99834458529949, 43.080682307481766, 42.322831973433495, 41.73351779580116, 44.59582440555096, 48.58462996780872, 49.33347478508949, 50.339843183755875, 50.959821715950966, 53.114765882492065, 58.83958429098129, 61.19773015379906, 61.87642313539982, 63.681204691529274, 23.56287382543087, 0.41564648563507944, 0.5679922155104578, 0.0713346632255707, 0.6397183542139828, 39.473817050457, 65.63551962375641, 48.82721275091171, 51.86302185058594, 23.322101645171642, 31.611548736691475, 57.14331351220608, 62.46458597481251, 41.17381922900677, 2.561062811873853, 0.08070683063124306, 0.04638980703020934, 0.02076944616419496, 0.03952539002057165, 0.06427487955079414, 0.0338834423746448, 0.13146262936061248, 0.05229878683167044, 0.016558322131459136, 0.0385288675170159, 0.04666085049393587, 0.2018271348788403, 0.2135342769906856, 0.1125154210603796, 0.15370768960565329, 0.12653744051931426, 0.12147670582635328, 0.1312924548983574, 0.23169001447968185, 0.13152666186215356, 0.1371030110749416, 0.12840125535149127, 0.11751764483051375, 4.148372299969196, 58.01899932324886, 64.43872064352036, 56.781447529792786, 30.787971429526806, 29.686076156795025, 42.849004939198494, 38.63360233604908, 50.639365911483765, 67.69954606890678, 10.937821380794048, 0.30463968752883375, 0.5629639571998268, 8.522868566215038, 16.94510903209448, 7.781724035739899, 46.17783911526203, 58.8499653339386, 58.4050852060318, 56.11468590795994, 57.98790939152241, 55.383168160915375, 57.43668057024479, 53.68810571730137, 54.84602138400078, 51.46462082862854, 50.332631170749664, 48.12259376049042, 43.608861565589905, 41.58178433775902, 40.2913735806942, 39.09412622451782, 40.43752133846283, 39.189603701233864, 39.199475571513176, 39.112950414419174, 39.272690042853355, 38.455490693449974, 44.74984914064407, 49.283560663461685, 47.97591783106327, 49.09625731408596, 44.32548031210899, 45.14181710779667, 40.46396031975746, 40.61009667813778, 40.600547790527344, 37.855031713843346, 40.083456337451935, 39.368824884295464, 39.937171787023544, 40.046651512384415, 37.40718014538288, 41.11242212355137, 41.68185196816921, 39.89183261990547, 40.305888801813126, 38.60050231218338, 40.45366287231445, 37.258026748895645, 38.95193785429001, 39.03332568705082, 40.921372175216675, 39.24166090786457, 45.93712583184242, 50.92851899564266, 48.58077697455883, 51.829070672392845, 53.67605656385422, 52.41856724023819, 50.52691474556923, 52.408341988921165, 52.092457339167595, 53.0177266895771, 51.03121988475323, 48.34779627621174, 42.766427770256996, 42.986903339624405, 43.58473286032677, 44.90454263985157, 49.65972147881985, 51.07634626328945, 52.843627631664276, 52.00240597128868, 51.35764516890049, 49.27316442131996, 53.46018634736538, 52.237738743424416, 54.29329924285412, 51.816945523023605, 54.45194073021412, 51.57698839902878, 46.5445726364851, 44.33471001684666, 41.559167951345444, 40.437844321131706, 38.74913513660431, 40.871712639927864, 40.188596695661545, 38.661948814988136, 39.773909747600555, 39.51488144695759, 39.36450071632862, 40.41218429803848, 39.792619943618774, 39.558088928461075, 40.26854820549488, 42.72695168852806, 40.77865183353424, 41.64073057472706, 40.29558755457401, 42.52170950174332, 40.46492546796799, 43.38520936667919, 41.2669712305069, 42.173435389995575, 47.0356734842062, 41.73659183084965, 40.623076781630516, 43.91708962619305, 43.88582110404968, 46.27842731773853, 44.35754679143429, 44.98901590704918, 44.76498372852802, 47.157437950372696, 44.433614909648895, 45.36749079823494, 45.89202605187893, 49.77103270590305, 50.85121214389801, 52.77075134217739, 53.44293527305126, 55.42436175048351, 61.58928394317627, 64.09898847341537, 63.01065847277641, 67.08256557583809, 24.31197512894869, 1.8376968149095774, 2.105256370268762, 0.1946818854776211, 0.6771930714603513, 45.369056314229965, 69.57602977752686, 62.43236370384693, 60.229040533304214, 29.42137286067009, 42.0500598102808, 65.03846526145935, 70.83661213517189, 50.99480643868446, 3.8252630503848195, 0.2907318400684744, 0.18976570630911738, 0.1635039201937616, 0.15107849787455052, 0.21173038316192105, 0.17809032811783254, 0.20416595390997827, 0.10087829316034913, 0.2050804134341888, 0.14055128151085228, 0.17297923128353432], [0.04633162265236024, 0.08318264270201325, 0.018273427267558873, 0.06608850293559954, 0.007316471219382947, 0.04688652647018898, 0.0378142498084344, 0.03371296734258067, 0.06801229072152637, 0.016968202871794347, 0.06329073235974647, 0.05185860791243613, 1.9963672757148743, 38.11355844140053, 50.743974298238754, 42.1215795725584, 26.237571202218533, 29.602398946881294, 19.764878824353218, 34.72655698657036, 41.89594008028507, 55.23326240479946, 9.84692556783557, 0.3459129243856296, 0.08033324833377264, 0.1503128686454147, 2.91382092051208, 12.788615617901087, 48.656936287879944, 54.974336698651314, 56.33304879069328, 52.07283519208431, 53.63270469009876, 51.96432821452618, 54.788891449570656, 52.093734070658684, 51.459513902664185, 49.91634450852871, 49.38988655805588, 45.62712326645851, 43.30647759139538, 37.90480524301529, 36.16971954703331, 36.0686107724905, 37.792551666498184, 36.13955296576023, 37.146498933434486, 34.18522283434868, 34.533192962408066, 36.66198693215847, 41.122263595461845, 44.939876943826675, 46.63835160434246, 47.63984486460686, 47.3364083468914, 44.22818273305893, 41.510264575481415, 36.324789226055145, 35.793376341462135, 38.29067453742027, 35.012734830379486, 36.28555253148079, 36.492322236299515, 35.70076011121273, 35.79072028398514, 37.322057113051414, 36.98279991745949, 36.61684535443783, 34.58263210952282, 35.79586140811443, 35.42002737522125, 34.55772824585438, 34.620573073625565, 34.95688542723656, 35.1394048333168, 40.62834709882736, 47.546510472893715, 46.25007703900337, 51.25211723148823, 50.38746602833271, 49.90569368004799, 49.291319847106934, 48.35381895303726, 49.66904617846012, 51.045024544000626, 52.522674053907394, 49.90183688700199, 50.75091652572155, 45.083022862672806, 39.72588412463665, 47.29838378727436, 49.14529748260975, 50.523342937231064, 50.22052958607674, 51.670600175857544, 47.16405339539051, 49.650347381830215, 49.12590712308884, 49.76980537176132, 46.55403412878513, 48.839083313941956, 47.699672654271126, 45.45716978609562, 43.994624465703964, 39.987739473581314, 35.48192225396633, 36.37279585003853, 36.33450150489807, 36.3161750882864, 35.51630660891533, 36.25266149640083, 35.704176127910614, 38.082521706819534, 35.78287370502949, 35.777348801493645, 37.002460062503815, 37.12864749133587, 35.3235087543726, 36.63436621427536, 36.73622354865074, 36.79961174726486, 36.608618795871735, 37.66100652515888, 43.09620447456837, 46.98325149714947, 44.031216502189636, 40.872039422392845, 33.938528671860695, 38.160497322678566, 41.923803985118866, 39.60692010819912, 40.38189232349396, 43.39882403612137, 44.05801646411419, 42.22391568124294, 42.17125430703163, 41.23702123761177, 39.13105644285679, 42.96447694301605, 46.27389036118984, 45.853572115302086, 42.87423558533192, 41.039504036307335, 42.522256672382355, 43.97018417716026, 48.32937106490135, 55.05768142640591, 59.091465175151825, 60.79502396285534, 60.579602122306824, 21.734288446605206, 0.19132990128127858, 0.21041785046691075, 0.12074871090590023, 0.6385302648413926, 35.73729895055294, 62.20765136182308, 48.6648740619421, 39.00043085217476, 29.29824996739626, 36.47008962929249, 46.08024515211582, 50.68400211632252, 26.35385636240244, 1.4140017377212644, 0.05069955877843313, 0.017466041099396534, 0.1122100643988233, 0.14761651254957542, 0.06948825917788781, 0.004107440900043002, 0.05889058702450711, 0.03453878474829253, 0.01267816349354689, 0.020796844401047565, 0.02851454384654062, 0.08981481572845951, 0.06474518595496193, 0.010060358163173078, 0.06614876532694325, 0.008769888590904884, 0.04976795564289205, 0.06371387527906336, 0.0721353960398119, 0.051402098033577204, 0.029790802218485624, 0.09358473296742886, 0.11621641504461877, 2.3742182878777385, 43.955307975411415, 56.65140710771084, 50.082699581980705, 30.12053344398737, 28.83267804980278, 24.984763227403164, 38.41979540884495, 47.83726327121258, 61.06614701449871, 11.273373775184155, 0.3429801942547783, 0.07541430837591179, 1.8143044388853014, 2.3991136020049453, 13.820258360356092, 50.129718258976936, 55.42793355882168, 58.272312730550766, 53.88031080365181, 56.42139784991741, 53.27820651233196, 57.769033536314964, 53.20633716881275, 54.03191886842251, 52.24279247224331, 51.04355402290821, 47.23060682415962, 44.42276269197464, 40.46335235238075, 37.791635915637016, 37.17586375772953, 38.69068667292595, 37.46117144823074, 39.58405673503876, 38.25748331844807, 36.26508682966232, 38.051792755723, 42.58920527994633, 47.24123105406761, 49.95531141757965, 48.53156961500645, 47.20362827181816, 46.684876307845116, 42.37507916986942, 38.030506297945976, 38.13055872917175, 39.62338462471962, 36.75515413284302, 39.13229517638683, 38.860925137996674, 38.09110924601555, 37.39358067512512, 39.85205635428429, 37.70674467086792, 38.185382187366486, 37.63211667537689, 38.23482133448124, 36.34835176169872, 37.16419838368893, 35.67510388791561, 36.95419505238533, 37.62983299791813, 41.314415484666824, 50.33824726939201, 49.28301729261875, 52.90117174386978, 52.73615039885044, 49.814973548054695, 50.531352907419205, 49.16846863925457, 52.392040863633156, 54.26577731966972, 53.02859030663967, 51.1870913207531, 50.69473274052143, 46.15009680390358, 41.55710846185684, 46.88752703368664, 49.74462412297726, 51.93032003939152, 51.04922711849213, 51.68965995311737, 50.19568271934986, 50.41810758411884, 51.22423812747002, 51.17644049227238, 47.76116855442524, 50.02621941268444, 48.023324087262154, 48.317720890045166, 46.75744481384754, 42.41746969521046, 38.609724417328835, 37.701835334300995, 38.59153479337692, 38.510416746139526, 38.576795384287834, 37.20414184033871, 39.02332462370396, 39.35264155268669, 38.10884669423103, 37.54700884222984, 38.144743368029594, 40.02865567803383, 37.10575371980667, 39.72220592200756, 38.334786370396614, 38.99962529540062, 37.889374271035194, 38.655086383223534, 45.15130899846554, 47.9470431804657, 45.49381121993065, 43.303825333714485, 36.838932037353516, 40.34776635468006, 43.15765857696533, 41.59800186753273, 41.698369681835175, 45.40522277355194, 45.17732620239258, 44.362148344516754, 42.72279091179371, 41.377632692456245, 41.43652193248272, 45.06789207458496, 48.005446046590805, 47.32656307518482, 45.1982668787241, 43.18433694541454, 44.69703957438469, 46.343935802578926, 51.11706107854843, 58.19505147635937, 62.47959516942501, 61.717367470264435, 63.79088580608368, 23.43541156500578, 0.8129264193121344, 0.5344944004900753, 0.07168913522036746, 0.5012274824548513, 39.07128565013409, 67.41877153515816, 53.19263130426407, 45.366388857364655, 30.00959649682045, 42.2165060788393, 51.93918876349926, 58.7301691621542, 33.11469487845898, 2.185535612516105, 0.056682103968341835, 0.021270622200972866, 0.11575129625271074, 0.08369343326194212, 0.03652019287983421, 0.05147642041265499, 0.03218646234017797, 0.06857316882815212, 0.03241803096898366, 0.04398321507323999, 0.0286614594006096, 0.18232897098641843, 0.20350094506284222, 0.08937561273341998, 0.18956375308334827, 0.1339645724510774, 0.1066419604467228, 0.1315699884435162, 0.12791369401384145, 0.14494202012429014, 0.1320780033711344, 0.1568368513835594, 0.23152521316660568, 3.815459101460874, 52.92506106197834, 64.6076899766922, 55.3695572912693, 37.61041983962059, 41.735398694872856, 27.59515095502138, 45.21525576710701, 53.439002484083176, 66.10939979553223, 12.846383918076754, 0.6121906719636172, 0.25668492482509464, 3.9104542415589094, 7.62340173125267, 15.29674893245101, 52.109248638153076, 58.254886865615845, 59.864852875471115, 56.544024869799614, 57.633228823542595, 54.41537149250507, 61.48585729300976, 54.77131359279156, 54.812309592962265, 54.86648328602314, 52.40478537976742, 50.56494690477848, 46.63680508732796, 41.762700229883194, 39.776577204465866, 39.48061868548393, 42.09133319556713, 38.189352974295616, 40.52066847681999, 39.51795168220997, 38.356046229600906, 40.41431598365307, 44.439155012369156, 48.86617586016655, 51.079256907105446, 51.96819260716438, 51.80627189576626, 47.86619111895561, 45.98595321178436, 42.13333614170551, 39.836629182100296, 41.13304361701012, 38.893375396728516, 42.073713541030884, 39.93274502456188, 39.33630242943764, 39.822813123464584, 42.505484372377396, 39.83608201146126, 40.460635498166084, 38.94476383924484, 40.26862420141697, 39.6472929418087, 37.26085379719734, 37.692685425281525, 39.48958620429039, 38.954867497086525, 42.894625291228294, 53.66654947400093, 51.10265985131264, 56.40268765389919, 54.41954366862774, 52.14415356516838, 52.655195742845535, 50.62471389770508, 52.657931596040726, 55.04966385662556, 55.23138150572777, 52.77824454009533, 52.75899097323418, 49.09910336136818, 44.07610349357128, 47.91939206421375, 52.195754796266556, 53.20352531969547, 52.741428315639496, 55.087916404008865, 50.80409847199917, 51.97324253618717, 53.37005138397217, 53.84699039161205, 50.157551765441895, 52.31574475765228, 52.19594858586788, 49.65176470577717, 48.105707466602325, 44.439702183008194, 40.5122709274292, 39.75136935710907, 41.74905516207218, 40.59858709573746, 42.34917975962162, 39.968565702438354, 40.756616815924644, 42.14873671531677, 39.34575632214546, 39.21982727944851, 40.0404654443264, 42.378878965973854, 39.31019403040409, 41.786205768585205, 40.75609244406223, 40.77705591917038, 39.22488860785961, 41.66656158864498, 47.51678466796875, 50.77749989926815, 47.80459642410278, 46.06991730630398, 37.643147483468056, 42.56762623786926, 45.07877469062805, 44.23430800437927, 43.641448616981506, 49.38162960112095, 47.634388357400894, 47.24554002285004, 45.433911234140396, 44.043349251151085, 43.88576030731201, 48.54385435581207, 51.46435484290123, 52.100904285907745, 47.66078554093838, 45.34171298146248, 47.04015724360943, 48.023377284407616, 52.763619124889374, 60.975176095962524, 65.66265016794205, 64.61608752608299, 64.55035865306854, 26.505109146237373, 1.3209480559453368, 1.02914793882519, 0.44158113305456936, 0.7517152070067823, 42.43533253669739, 73.50184231996536, 60.95684587955475, 50.195659920573235, 42.59591571986675, 49.722592905163765, 61.43690072000027, 67.53001436591148, 42.451291680336, 3.3078659512102604, 0.1610582318971865, 0.10617955049383454, 0.2983547654002905, 0.1978224763297476, 0.15070519759319723, 0.14269383216742426, 0.1131422612525057, 0.1283331707236357, 0.08516601010342129, 0.14096747792791575, 0.1541632050066255], [0.043539718753891066, 0.016731468895159196, 0.06461275712354109, 0.04558184198685922, 0.040615193065605126, 0.0401575105934171, 0.046072724435362034, 0.021556404717557598, 0.04151839792029932, 0.03282323246821761, 0.020063498595845886, 0.038365186846931465, 1.2705625221133232, 29.54328741878271, 48.033040165901184, 45.18719807267189, 37.34294459223747, 24.73794747143984, 32.11525350809097, 42.57538162171841, 36.742622405290604, 57.189051657915115, 13.107275068759918, 0.23746726306853816, 0.010305987707397435, 1.1887064832262695, 1.3574193301610649, 18.84701907634735, 45.930567383766174, 54.63381417095661, 55.81777364015579, 52.17131830751896, 51.50627039372921, 51.206246092915535, 51.63296699523926, 51.52553156018257, 50.94985485076904, 50.42442664504051, 49.12688747048378, 47.952579483389854, 43.17729212343693, 40.02347655594349, 39.08266223967075, 37.81179763376713, 39.750970378518105, 36.06098838150501, 35.6080374866724, 35.29758654534817, 35.785119384527206, 37.66173228621483, 41.65169298648834, 45.557188019156456, 47.37846449017525, 47.715844586491585, 48.1660558283329, 46.7326245456934, 46.87443673610687, 42.739244028925896, 37.25149869918823, 36.264934837818146, 36.78784377872944, 35.36873012781143, 36.40401877462864, 36.42684794962406, 36.10444284975529, 37.6954098790884, 37.20357187092304, 36.521101891994476, 36.26319833099842, 35.96326522529125, 35.54597541689873, 34.406811743974686, 35.62967732548714, 34.98557388782501, 37.278066873550415, 48.84789504110813, 46.25288508832455, 51.52780383825302, 45.41141264140606, 44.1067336499691, 50.22883594036102, 49.76975217461586, 52.8777763992548, 49.435503110289574, 51.53180882334709, 51.491302996873856, 50.0212986767292, 50.09944148361683, 48.70601825416088, 41.55510976910591, 50.54816700518131, 48.69323194026947, 49.086168855428696, 46.6184938699007, 50.94933047890663, 48.68621751666069, 48.822018429636955, 47.45050482451916, 49.00892660021782, 47.95756861567497, 46.70782707631588, 45.127879455685616, 42.400917783379555, 38.85195381939411, 36.64073847234249, 34.46993015706539, 35.36232367157936, 36.80423989892006, 35.171820893883705, 37.76068277657032, 36.3458476960659, 33.70699189603329, 37.158057913184166, 37.47224785387516, 36.62754938006401, 37.40279138088226, 36.62686921656132, 34.70068037509918, 37.387425005435944, 36.47506356239319, 37.73379161953926, 37.49614477157593, 40.739209949970245, 47.000863552093506, 51.303273886442184, 51.63568764925003, 49.43994887173176, 41.020691245794296, 36.87156468629837, 37.707280442118645, 39.081016927957535, 40.71295715868473, 44.01824399828911, 44.3801099807024, 46.33623741567135, 43.74234460294247, 40.2374354749918, 41.59196779131889, 52.310318648815155, 56.41061022877693, 53.75624366104603, 52.46114395558834, 52.367095202207565, 49.74772855639458, 46.40604726970196, 48.9205015450716, 52.884179055690765, 60.12289322912693, 59.223686680197716, 61.91513925790787, 18.73542096465826, 0.26503595639951527, 0.24001726764254272, 0.10845769895240664, 0.29517552349716425, 30.921572260558605, 60.1077738404274, 47.2638588398695, 43.89277093112469, 27.74153620004654, 37.043338268995285, 53.47328424453735, 47.800310254096985, 26.306140422821045, 0.7379394618328661, 0.03929596619855147, 0.010185283881583018, 0.04797307148692198, 0.05093453757581301, 0.031076997947820928, 0.06288899297942407, 0.03004344784130808, 0.0219396850297926, 0.022886225742695387, 0.034123887089663185, 0.05916052839893382, 0.045667470985790715, 0.023971392220119014, 0.03619076465838589, 0.02646816810738528, 0.0555577650811756, 0.04801634240720887, 0.019069258196395822, 0.030995181732578203, 0.09931559732649475, 0.00970320608757902, 0.04023577748739626, 0.016149185394169763, 1.6831051977351308, 35.10900266468525, 55.04561327397823, 51.2580107152462, 39.48011711239815, 29.31535094976425, 30.75997833162546, 44.660162553191185, 44.38050515949726, 60.6110530346632, 14.552225433290005, 0.2112330254749395, 0.11228614195715636, 1.3823241437785327, 1.2167973071336746, 19.757131040096283, 46.62739299237728, 56.17123447358608, 59.53334726393223, 54.4121340662241, 51.55999571084976, 52.494977340102196, 54.21755410730839, 53.303068578243256, 53.10218095779419, 51.808825358748436, 51.68785884976387, 49.23870787024498, 46.88059240579605, 42.83835791051388, 40.06570748984814, 39.14654441177845, 41.29480093717575, 37.08968438208103, 36.75083376467228, 36.64202660322189, 36.153346225619316, 39.387109503149986, 44.2393883317709, 47.16371141374111, 49.98453564941883, 51.254199519753456, 49.242716655135155, 48.85461688041687, 48.460669219493866, 43.769585341215134, 38.72359290719032, 37.42272891104221, 38.40442903339863, 36.816026866436005, 37.983480021357536, 37.38420657813549, 38.172690868377686, 37.635840475559235, 37.25590266287327, 38.69588479399681, 36.938634887337685, 37.468615248799324, 37.70096518099308, 36.62681221961975, 36.62399657070637, 36.46725878119469, 39.800029546022415, 49.782910868525505, 49.52982924878597, 53.288481160998344, 48.10573406517506, 47.08258576691151, 51.963230073451996, 50.0696586817503, 52.954684272408485, 51.9311635941267, 52.30896212160587, 53.43103051185608, 52.17537268996239, 53.17399710416794, 51.61502815783024, 43.43208745121956, 50.85920311510563, 50.019953548908234, 51.58906415104866, 51.04547671973705, 51.70457035303116, 50.569468662142754, 51.78570739924908, 48.694436475634575, 51.012464091181755, 48.40177997946739, 48.834607154130936, 47.04279810190201, 44.331373795866966, 42.28864900767803, 39.03858840465546, 37.56321497261524, 37.06356078386307, 38.95416833460331, 38.181042820215225, 39.302358850836754, 38.77231769263744, 36.23320274055004, 38.33345264196396, 38.907248452305794, 37.591610848903656, 38.71833398938179, 37.90081925690174, 37.59322576224804, 39.42088209092617, 38.71691666543484, 39.53479617834091, 39.070753678679466, 41.73619665205479, 49.86310176551342, 53.53948809206486, 54.335074201226234, 51.45704783499241, 42.920034527778625, 38.52024681866169, 39.54668574035168, 41.14312447607517, 42.54635497927666, 45.85274375975132, 46.56061537563801, 47.48416341841221, 45.780030861496925, 42.72030584514141, 42.98393949866295, 52.41897761821747, 57.79503174126148, 55.349133387207985, 54.793777987360954, 53.27887147665024, 49.941046983003616, 48.3460483700037, 50.991952791810036, 56.33842550218105, 59.91797022521496, 60.85620068013668, 65.41671216487885, 21.44506696611643, 0.45302163634914905, 0.6509146909229457, 0.300757602090016, 0.2680746652185917, 34.12712015211582, 65.10382935404778, 51.39061599969864, 46.37485474348068, 32.81119756400585, 43.680043146014214, 57.371487468481064, 55.18122799694538, 31.73396486788988, 1.752963736653328, 0.05289451619319152, 0.055883619861560874, 0.026283319530193694, 0.0991302311012987, 0.04811924489331432, 0.03575560636818409, 0.06201196367328521, 0.021112138419994153, 0.06099257188907359, 0.02344395157706458, 0.089730871404754, 0.13518923486117274, 0.09223139699315652, 0.09161182242678478, 0.17572149663465098, 0.09419160938705318, 0.09314535185694695, 0.16715509380446747, 0.08641076245112345, 0.1831419492373243, 0.1644675395800732, 0.1965910752187483, 0.1949387724744156, 1.7670086142607033, 40.06204828619957, 65.0149293243885, 59.796182960271835, 46.962318420410156, 35.755868554115295, 42.86817871034145, 53.75230707228184, 49.1322223842144, 65.64930528402328, 16.56132012605667, 0.38463830889668316, 0.3484481602208689, 4.322322690859437, 5.119437268003821, 21.36165004223585, 49.46240946650505, 57.78187684714794, 59.33169208467007, 55.52470676600933, 54.33030165731907, 55.401631370186806, 56.77651919424534, 55.60780070722103, 56.81667543947697, 54.34510566294193, 54.648420587182045, 52.4830611795187, 49.615685641765594, 44.54928070306778, 43.797095865011215, 41.79435633122921, 44.07472036778927, 39.08105872571468, 38.337814807891846, 39.09789562225342, 39.7380206733942, 41.70121192932129, 46.462204456329346, 50.160819590091705, 50.50631985068321, 52.89665378630161, 51.45899713039398, 50.81858329474926, 51.13368518650532, 47.6788117736578, 41.335622146725655, 40.01069404184818, 40.82856975495815, 39.84919510781765, 40.09462393820286, 40.16234390437603, 39.67116326093674, 40.26442922651768, 39.098921567201614, 40.768004804849625, 39.13383789360523, 39.42974701523781, 40.35319626331329, 37.99397125840187, 38.95638361573219, 38.516101241111755, 42.821676805615425, 53.990987464785576, 51.87466822564602, 54.835993722081184, 48.693357333540916, 46.60992532968521, 54.57368619740009, 51.906977891922, 56.747420355677605, 53.155788481235504, 55.768220499157906, 55.60721933841705, 56.05490751564503, 53.504507169127464, 54.54619847238064, 45.28002329170704, 53.83147582411766, 52.63517461717129, 53.29818584024906, 52.54326894879341, 53.05856689810753, 50.96295654773712, 54.470263347029686, 51.67898632586002, 54.77007105946541, 52.32055529952049, 51.547342389822006, 49.20963183045387, 45.781125202775, 44.565980806946754, 41.45166791975498, 39.375265538692474, 39.40914072096348, 40.366985723376274, 38.36977109313011, 41.83404520153999, 39.560824781656265, 36.930043548345566, 39.96281661093235, 40.963048338890076, 40.24696536362171, 39.85171437263489, 41.13236345350742, 38.68610791862011, 42.2224185615778, 40.426532328128815, 42.908353954553604, 41.53001971542835, 43.952074348926544, 51.98021896183491, 55.04134990274906, 55.359225645661354, 55.044275745749474, 44.53148625791073, 41.0123772919178, 40.764953568577766, 42.89968281984329, 45.354829877614975, 47.97925025224686, 49.35386449098587, 51.726810559630394, 47.51947872340679, 45.220191702246666, 45.66848024725914, 55.91453164815903, 59.93182808160782, 58.230431377887726, 58.40379327535629, 57.69681841135025, 53.80267336964607, 52.400768995285034, 53.56933929026127, 58.954064548015594, 62.387279123067856, 64.34671238064766, 67.67531096935272, 23.745085448026657, 1.4171642367728055, 1.7841553129255772, 0.5100501340348274, 0.35555594600737095, 36.07845984399319, 71.36812761425972, 59.64871287345886, 54.96990613639355, 40.56558586657047, 48.28952260315418, 66.82908117771149, 65.13726755976677, 40.68527564406395, 3.119565392844379, 0.31079167616553605, 0.10873187056859024, 0.1328178503899835, 0.23646579415071756, 0.10515895643038675, 0.12029032339341938, 0.17905178043292835, 0.1730001301621087, 0.11204720009118319, 0.1407734359963797, 0.2568043809151277], [0.02205678294558311, 0.03577528812456876, 0.029388888433459215, 0.027011839520127978, 0.043924177225562744, 0.010617092302709352, 0.05381984075938817, 0.07720592708210461, 0.04009409407444764, 0.04920453568047378, 0.05621297757897992, 0.06304759735940024, 0.2689599880250171, 18.472250886261463, 46.565182730555534, 49.728140607476234, 37.2603028267622, 22.073292955756187, 25.936758443713188, 37.93078064918518, 41.91621959209442, 55.93489095568657, 16.401842683553696, 0.08460875367745757, 0.036109043066971935, 0.7095972576644272, 0.7116082403808832, 10.415882337838411, 50.17884202301502, 56.05927728116512, 54.50836770236492, 51.620693653821945, 46.7925663292408, 44.026086777448654, 44.56178583204746, 42.72421583533287, 44.11591395735741, 42.71011099219322, 43.86764667928219, 41.34796008467674, 40.254488959908485, 38.21253553032875, 36.413164883852005, 35.719793289899826, 36.18586488068104, 36.85222752392292, 37.896894067525864, 38.31588618457317, 36.4242222905159, 37.934223264455795, 40.679655745625496, 44.17079821228981, 46.98529198765755, 46.52438051998615, 47.887074798345566, 47.68674574792385, 45.39609186351299, 48.60409252345562, 39.24111373722553, 32.76179261505604, 35.74114814400673, 35.656473487615585, 36.40532590448856, 35.627788826823235, 35.362137481570244, 35.286411345005035, 36.2888203561306, 35.63468165695667, 36.630836203694344, 37.27481044828892, 35.65986290574074, 36.6160473972559, 36.24010317027569, 34.5056938380003, 40.767727419734, 48.91459286212921, 50.96078686416149, 49.28553655743599, 44.796757623553276, 42.761351242661476, 46.13264814019203, 49.262312203645706, 52.787766829133034, 49.474580213427544, 47.1865139901638, 48.008858263492584, 49.41213056445122, 49.12608191370964, 50.46193443238735, 45.41750371456146, 49.79932598769665, 50.642375349998474, 48.962736278772354, 51.575476080179214, 50.300766080617905, 49.966429620981216, 46.772712394595146, 48.40087182819843, 48.275717943906784, 47.509078681468964, 44.831160977482796, 41.48264765739441, 39.19677771627903, 38.01727540791035, 36.273716166615486, 36.66583992540836, 36.69280707836151, 34.89045739173889, 38.1902801245451, 35.791199058294296, 35.784629210829735, 35.639803782105446, 36.82320088148117, 36.492649018764496, 37.14386187493801, 36.189619079232216, 35.627325251698494, 35.22960439324379, 34.88250061869621, 35.6713192909956, 38.706170842051506, 35.91987535357475, 43.09088855981827, 47.985550314188, 50.29256232082844, 52.064726427197456, 48.20879213511944, 49.03267912566662, 38.83173130452633, 36.57438263297081, 38.74611049890518, 38.5689602047205, 42.51195542514324, 47.32145234942436, 46.80634059011936, 46.44910275936127, 41.33184514939785, 43.88181231915951, 53.1151382625103, 57.08607338368893, 58.97079885005951, 55.7538078725338, 55.37288971245289, 58.841499388217926, 53.883472234010696, 56.032644510269165, 53.60481418669224, 57.16406039893627, 61.88020013272762, 57.617965042591095, 15.213431753218174, 0.1277792316977866, 0.5020947859156877, 0.0913262514222879, 0.2134192144148983, 30.599640235304832, 59.663285091519356, 44.789948388934135, 43.21854270994663, 23.795858323574066, 29.72653068602085, 48.09483624994755, 48.732381239533424, 26.91614829003811, 1.0359430429525673, 0.048032005433924496, 0.024227299581980333, 0.06695752817904577, 0.03662243856524583, 0.0907817376719322, 0.055490337254013866, 0.05785878653114196, 0.04505351447733119, 0.054224537598202005, 0.0883960297505837, 0.06817889545345679, 0.0543666254816344, 0.018282210585311987, 0.03683269642351661, 0.040549561235820875, 0.023967677770997398, 0.02792718220007373, 0.030655975715490058, 0.05123499606270343, 0.041062344462261535, 0.009823870950640412, 0.010792925640998874, 0.09622117548133247, 0.28089253522921354, 22.751349471509457, 54.350706562399864, 56.11007295548916, 41.24014846980572, 25.238889791071415, 27.01441291719675, 40.882219076156616, 46.6711438447237, 60.22296845912933, 17.343363761901855, 0.11532924429047853, 0.052467462155618705, 1.3495377218350768, 2.1516542555764318, 12.2489695250988, 50.41531093418598, 56.57015226781368, 55.64342759549618, 53.204847648739815, 51.00063532590866, 46.58317096531391, 47.38212749361992, 45.93606188893318, 46.82332567870617, 45.998123958706856, 46.004674807190895, 43.10650572180748, 43.97430695593357, 40.27575641870499, 38.475986793637276, 37.63701841235161, 37.83539056777954, 37.61563315987587, 38.97001348435879, 38.21001246571541, 38.01882952451706, 39.70784269273281, 43.73882219195366, 45.98078928887844, 47.441746294498444, 48.499453738331795, 50.81878088414669, 49.225419983267784, 47.55337290465832, 49.102435782551765, 41.828094720840454, 34.90473322570324, 37.86697827279568, 36.918552964925766, 37.58403405547142, 37.0240581035614, 36.28923453390598, 38.65305729210377, 36.94469556212425, 37.41094954311848, 38.96470136940479, 39.58545506000519, 36.64644956588745, 37.529525980353355, 37.17810183763504, 35.16794890165329, 41.14662408828735, 51.37447066605091, 52.7323430031538, 50.88652744889259, 45.38954481482506, 42.63985276222229, 46.72724403440952, 49.722250923514366, 54.42204013466835, 49.91799362003803, 48.4120774269104, 49.82115961611271, 50.40086790919304, 51.725636422634125, 51.09263978898525, 45.97212195396423, 50.451819375157356, 52.17131070792675, 50.310816541314125, 54.00222726166248, 52.224808037281036, 51.935445964336395, 49.39543806016445, 50.334637463092804, 48.393637016415596, 48.26034016907215, 45.78104540705681, 44.015926122665405, 41.11700467765331, 40.224656760692596, 38.32548826932907, 37.99925297498703, 38.217642456293106, 37.10480377078056, 37.912853211164474, 38.274229019880295, 37.79422737658024, 37.98688463866711, 38.09495843946934, 38.43309089541435, 38.339030742645264, 38.39775659143925, 37.60767638683319, 38.555657118558884, 37.374657690525055, 38.16188044846058, 40.886436849832535, 38.93030561506748, 43.85627008974552, 49.66635972261429, 53.439276069402695, 54.22842152416706, 49.49500411748886, 49.68750178813934, 40.776683539152145, 39.259371757507324, 42.07442790269852, 40.16073279082775, 43.87853689491749, 49.71506550908089, 48.368098586797714, 49.08054135739803, 44.6638635545969, 45.032189190387726, 54.377916902303696, 60.47550290822983, 59.294902458786964, 58.57436992228031, 58.252143412828445, 61.52341067790985, 56.49544067680836, 58.21907378733158, 56.17495447397232, 60.18832191824913, 62.198041677474976, 61.044643968343735, 16.128798834979534, 0.21735393296694383, 0.8902094035875052, 0.06892422694363631, 0.1896595791913569, 32.87343442440033, 63.81544008851051, 50.235132202506065, 49.314981177449226, 26.95282582193613, 39.2344830930233, 56.830282509326935, 57.952825874090195, 33.735254779458046, 1.1934495787136257, 0.1009327890642453, 0.01950833131559193, 0.03409201184695121, 0.04490089551836718, 0.13700765994144604, 0.028624120095628314, 0.05804498396173585, 0.10003163624787703, 0.041825012522167526, 0.04945455781125929, 0.045727191609330475, 0.12169104549684562, 0.12563328200485557, 0.1800353339058347, 0.17859317769762129, 0.07674388820305467, 0.11956894100876525, 0.15887530840700492, 0.1461090028169565, 0.3065190132474527, 0.1466481137322262, 0.1579697843408212, 0.14654759725090116, 0.6075601454358548, 27.490194886922836, 63.43295261263847, 62.670002952218056, 48.13959024846554, 32.80537247657776, 36.391297057271004, 50.08569002151489, 52.32115186750889, 65.26147529482841, 20.792645774781704, 0.14663555659353733, 0.3843593504279852, 4.271208308637142, 3.20319059304893, 13.098779674619436, 53.55236180126667, 58.707913756370544, 57.82621666789055, 56.54776766896248, 51.90944775938988, 48.187505677342415, 48.87484319508076, 47.17019006609917, 49.345774725079536, 48.424677550792694, 48.58955830335617, 45.31493581831455, 46.10116682946682, 42.266879975795746, 40.04885919392109, 38.54267321527004, 40.33782608807087, 40.65686456859112, 40.37788353860378, 41.292027086019516, 40.755640268325806, 41.39487236738205, 44.92293745279312, 48.56427066028118, 49.22636613249779, 51.626746729016304, 52.683580219745636, 50.91098293662071, 48.556906655430794, 53.117801919579506, 43.268863409757614, 35.70993661880493, 39.426528587937355, 40.04532918334007, 39.86191302537918, 39.198438227176666, 37.253843173384666, 40.17411187291145, 40.09158030152321, 38.25135424733162, 39.885403364896774, 41.05712749063969, 39.61227402091026, 40.3474547713995, 40.294706001877785, 38.75416226685047, 44.57574248313904, 51.835192143917084, 54.071687534451485, 54.23633649945259, 47.591272071003914, 42.7593107521534, 46.468215733766556, 50.37892408668995, 56.52181886136532, 54.10079777240753, 50.4341047257185, 51.337069272994995, 52.22727030515671, 52.44956597685814, 54.352739453315735, 48.86728160083294, 53.06752681732178, 53.70616614818573, 52.44900360703468, 55.865343287587166, 53.75808656215668, 54.3564822524786, 51.27260573208332, 51.72554522752762, 52.295260056853294, 51.77712365984917, 48.5584569722414, 45.026356503367424, 43.721255734562874, 42.11168110370636, 39.843248426914215, 40.374995693564415, 40.613163113594055, 37.90737010538578, 41.20303586125374, 39.057196006178856, 38.47760550677776, 40.33027969300747, 39.18412819504738, 39.9180968105793, 41.567447707057, 40.69456994533539, 39.83845308423042, 40.70561595261097, 39.981762394309044, 40.320552214980125, 43.36421549320221, 40.41997008025646, 46.22027523815632, 53.425349816679955, 54.76355820894241, 55.708510503172874, 50.15105031430721, 53.40329200029373, 44.73977968096733, 40.540317222476006, 43.986846283078194, 41.83999568223953, 48.08083400130272, 52.38030329346657, 49.07804109156132, 51.12497225403786, 46.44125238060951, 47.46180921792984, 57.204349637031555, 62.876810654997826, 63.78876551985741, 61.6802092641592, 60.573685839772224, 64.09483909606934, 59.776955991983414, 61.540623754262924, 59.0126384049654, 62.34752185642719, 66.68054714798927, 62.144266963005066, 19.34100966900587, 1.0276337200775743, 1.6003723558969796, 0.2055260434281081, 0.4917199176270515, 35.83949066698551, 71.76217406988144, 57.301069647073746, 56.94762401282787, 33.37005637586117, 46.680897921323776, 59.91070121526718, 68.20845276117325, 43.1542843580246, 2.7315819868817925, 0.19620503968326375, 0.19961275917012244, 0.13490647659637034, 0.08000752713996917, 0.2633412176510319, 0.0971247699635569, 0.1729448401601985, 0.08830213322653435, 0.1574528933269903, 0.15655507275369018, 0.13530039374018088], [0.03669748082756996, 0.011980872150161304, 0.02918608359323116, 0.01912236442876747, 0.026843542691494804, 0.06777636197512038, 0.02940242335171206, 0.012354915506875841, 0.058674284373410046, 0.05262494960334152, 0.04873078942182474, 0.03777406251174398, 0.18249871500302106, 11.14826263859868, 43.80466885864735, 50.7101409137249, 41.92603446543217, 31.196400113403797, 24.10511802881956, 33.02302099764347, 41.02066084742546, 56.08285881578922, 23.39504063129425, 0.09263160012778826, 0.008407710320170736, 0.30427238380070776, 0.5565245496109128, 9.217552989721298, 45.23724518716335, 57.86319628357887, 54.155252650380135, 48.56973096728325, 41.456463262438774, 39.20952223241329, 37.949392050504684, 37.68643096089363, 36.73715449869633, 36.27527788281441, 37.066524624824524, 38.58003281056881, 38.09529282152653, 37.060437351465225, 34.01320606470108, 38.83097514510155, 42.844050005078316, 46.50573492050171, 42.97740764915943, 43.81238244473934, 42.584143951535225, 39.97964210808277, 40.44482834637165, 41.37522742152214, 44.76320922374725, 45.03068447113037, 46.909056678414345, 46.56582489609718, 45.83836913108826, 48.96004602313042, 43.15947487950325, 34.852961003780365, 36.19325548410416, 36.00305289030075, 35.54225541651249, 35.91671012341976, 34.9751016497612, 36.357589066028595, 35.91598816215992, 35.818800777196884, 35.78955374658108, 38.48613224923611, 35.89006595313549, 34.79232005774975, 35.03707632422447, 36.44033342599869, 39.908407330513, 51.032941192388535, 48.73950205743313, 48.273574858903885, 52.3889896273613, 52.23856329917908, 47.974283918738365, 49.276287853717804, 48.92715498805046, 47.595113664865494, 47.96158120036125, 46.621358916163445, 46.36238381266594, 50.30884064733982, 49.84987847507, 46.75991468131542, 48.70330139994621, 48.48889410495758, 51.45887553691864, 50.207047909498215, 47.398793399333954, 50.708328410983086, 46.830834075808525, 48.111315965652466, 47.028697058558464, 46.87743857502937, 47.23151117563248, 40.6543605029583, 38.50269556045532, 35.72875700891018, 35.21082200109959, 36.69222570955753, 37.07855477929115, 36.53214789927006, 37.088700234889984, 35.78924596309662, 35.31786225736141, 35.36751039326191, 33.77703353762627, 35.88524781167507, 37.84795269370079, 36.28622129559517, 35.831355303525925, 34.907009303569794, 35.35637319087982, 36.11627161502838, 38.64693962037563, 36.636110320687294, 42.88084343075752, 47.85770997405052, 48.85775551199913, 46.652274057269096, 46.65393836796284, 50.86782865226269, 41.572813019156456, 37.06165328621864, 37.47065953910351, 37.51633308827877, 39.36118729412556, 44.4065223634243, 46.1459094285965, 46.66378743946552, 44.535377249121666, 41.19664080440998, 46.91882595419884, 54.26187112927437, 57.166610062122345, 59.39724616706371, 56.541152223944664, 59.707446321845055, 56.92844644188881, 56.95911839604378, 56.98913298547268, 58.5458030551672, 59.67979520559311, 48.54434832930565, 10.160274803638458, 0.05542722872633021, 0.5418594146613032, 0.017344994957966264, 0.4658220213605091, 34.183041751384735, 61.176968067884445, 45.629878118634224, 45.73719196021557, 31.242721527814865, 28.246969878673553, 48.22712995111942, 52.44560658931732, 28.666522465646267, 1.1393501004204154, 0.17273141333134845, 0.0065535025896679144, 0.011464129565865733, 0.062273010407807305, 0.04955882213835139, 0.03085665615799371, 0.022186237620189786, 0.009378285485581728, 0.07829036068869755, 0.006649906181337428, 0.04497950751101598, 0.05360301489417907, 0.036622238185373135, 0.09712026512715966, 0.06125148123828694, 0.0574662460712716, 0.058107932927669026, 0.025998939672717825, 0.046715895587112755, 0.05634914312395267, 0.017010674127959646, 0.04819875488465186, 0.13134151085978374, 0.1291196543024853, 13.900899533182383, 51.7808398604393, 56.23619578778744, 47.039313688874245, 32.839696034789085, 26.52861088514328, 39.67380411922932, 45.31786926090717, 61.147804632782936, 24.72709145396948, 0.05732115248974878, 0.047614139184588566, 0.43253343261312693, 1.3780452171340585, 8.157706260681152, 47.937239706516266, 59.0842417627573, 55.278232991695404, 49.90471713244915, 43.61241057515144, 40.85190050303936, 39.8767664283514, 39.264106303453445, 39.85466681420803, 37.795553505420685, 39.1290957480669, 39.86935682594776, 39.73280355334282, 39.448001235723495, 36.15135133266449, 39.20831769704819, 45.760458111763, 46.24310061335564, 45.78697308897972, 45.179526284337044, 43.469310253858566, 40.40421612560749, 41.881896033883095, 42.76087246835232, 46.362619400024414, 47.97600902616978, 49.0987765789032, 47.83772684633732, 47.77058444917202, 51.621772795915604, 44.030794724822044, 36.440424621105194, 38.555744513869286, 37.08797827363014, 37.25236125290394, 36.20386831462383, 37.170886024832726, 37.271447628736496, 37.409688010811806, 38.120485469698906, 37.608158960938454, 39.49077554047108, 37.33892820775509, 35.23223005235195, 37.14137680828571, 37.60680243372917, 42.82773748040199, 53.378984704613686, 52.151513770222664, 49.586051031947136, 52.841070368885994, 52.717014625668526, 48.40876780450344, 49.74375016987324, 51.64937451481819, 50.70313788950443, 49.65851694345474, 47.808757200837135, 49.32823486626148, 53.590713143348694, 51.09726794064045, 47.13117375969887, 50.69575108587742, 49.954483062028885, 52.74796396493912, 50.68660497665405, 49.18429099023342, 51.52692228555679, 47.43791610002518, 47.665979862213135, 48.275307565927505, 49.54730071127415, 48.27297829091549, 43.35615232586861, 40.61401806771755, 37.422926500439644, 38.05913396179676, 38.51103611290455, 39.35826525092125, 38.315836787223816, 38.16550925374031, 38.50299574434757, 36.92602716386318, 37.617035284638405, 36.262430772185326, 36.82995691895485, 38.4536287933588, 38.40056464076042, 37.21462927758694, 36.857497841119766, 37.63484872877598, 39.788409769535065, 40.274973660707474, 40.15856310725212, 45.31302832067013, 49.85771745443344, 51.53672195971012, 49.782819673419, 49.79540839791298, 53.4701532125473, 43.44086118042469, 38.54270741343498, 37.70013302564621, 39.55856390297413, 42.30161011219025, 46.799877136945724, 48.39339002966881, 48.21628913283348, 46.3387680798769, 42.054798156023026, 50.00887334346771, 56.226966083049774, 58.1786173582077, 60.382898077368736, 58.27768564224243, 60.992164984345436, 59.57625836133957, 59.949318543076515, 58.757539093494415, 60.20363889634609, 62.5336092710495, 50.80573618412018, 11.588041540235281, 0.4303993424400687, 0.48363718728069216, 0.10504651363589801, 0.38545431511010975, 36.44110098481178, 66.20170444250107, 50.93940541148186, 49.53341245651245, 31.45656455308199, 31.597688980400562, 53.648382648825645, 59.7904908657074, 36.1470727622509, 1.7612839839421213, 0.05460960834170692, 0.02415525188553147, 0.065565244294703, 0.03014431869814871, 0.04220656177494675, 0.05426269883173518, 0.021058080383227207, 0.019002739500137977, 0.07444413582561538, 0.11854980897624046, 0.029868679484934546, 0.14345046656671911, 0.1425006362842396, 0.2937174111139029, 0.16027033823775128, 0.10562266514170915, 0.1345201738877222, 0.1655844718334265, 0.1475021624355577, 0.13948116393294185, 0.10319846944184974, 0.11891312737134285, 0.23281157773453742, 0.2947984531056136, 15.468278378248215, 62.06382907927036, 64.94347035884857, 54.51362282037735, 42.02125355601311, 35.15561856329441, 43.817075192928314, 51.87466822564602, 66.456837952137, 29.458008594810963, 0.13604807783849537, 0.12317706263274886, 1.8535439833067358, 3.3052588161081076, 11.510315760970116, 48.7384457141161, 61.88513606786728, 59.395756646990776, 53.163593262434006, 45.98574802279472, 42.847188636660576, 42.2271379083395, 41.93962253630161, 42.08483174443245, 40.53060494363308, 42.33393117785454, 41.937145069241524, 40.119444206357, 40.53970545530319, 37.75265000760555, 41.557686030864716, 48.991120755672455, 48.775797709822655, 46.06195293366909, 48.297859355807304, 45.09644374251366, 42.50292330980301, 44.77659210562706, 45.86429513990879, 48.75734210014343, 49.32091265916824, 50.2152668684721, 48.95940765738487, 48.656628504395485, 53.96940842270851, 47.629080042243004, 38.496034517884254, 41.383643969893456, 39.01059530675411, 39.387056306004524, 38.8188423961401, 38.84684309363365, 38.58222149312496, 40.15701279044151, 40.529932379722595, 39.41211976110935, 41.49287290871143, 39.262673780322075, 37.96021766960621, 38.81677530705929, 40.44963888823986, 44.811367839574814, 55.528723150491714, 54.957256615161896, 51.018973141908646, 55.076931193470955, 56.01553402841091, 49.67239759862423, 51.37871503829956, 53.725396916270256, 51.11081041395664, 52.04379715025425, 51.06296718120575, 51.68039225041866, 53.266727328300476, 55.01121371984482, 49.50163096189499, 52.64960244297981, 50.76435640454292, 54.977030754089355, 53.61183241009712, 52.101238667964935, 54.410443156957626, 49.183633625507355, 51.601991057395935, 48.50019849836826, 52.160097509622574, 51.40508942306042, 44.915102273225784, 41.58676967024803, 39.61337596178055, 39.9381635338068, 40.918472930788994, 42.510602697730064, 39.779696837067604, 40.89964494109154, 40.8172045648098, 39.243739396333694, 39.00276392698288, 37.44452454149723, 38.42400938272476, 41.92971646785736, 40.47204248607159, 40.48281490802765, 38.68516556918621, 39.7648586332798, 41.38313479721546, 42.54681475460529, 42.987340316176414, 46.26260116696358, 52.0717978477478, 54.043698236346245, 52.16912962496281, 50.61910919845104, 56.70107044279575, 43.82367543876171, 40.50101213157177, 39.684401750564575, 40.964100882411, 44.27067205309868, 48.880732879042625, 51.4139049500227, 51.15483105182648, 48.74759942293167, 45.21749384701252, 50.25218188762665, 59.576083570718765, 62.49765560030937, 62.48817130923271, 59.87482354044914, 62.177701368927956, 61.86855375766754, 63.042010590434074, 62.32016712427139, 62.59322427213192, 65.40367126464844, 51.487997174263, 13.660073205828667, 0.7410542853176594, 1.4740480156615376, 0.4276580864097923, 0.6018555234186351, 40.13932853937149, 73.24021875858307, 58.021066412329674, 60.41801959276199, 43.12837354838848, 40.20744368433952, 64.1130781173706, 67.22310483455658, 45.83606265485287, 2.850650972686708, 0.2700516872573644, 0.036385964340297505, 0.13045033992966637, 0.13289525639265776, 0.12681311869528145, 0.10203819576418027, 0.13318757351953536, 0.12793854111805558, 0.20802359300432727, 0.18388874275842682, 0.13546032656449825], [0.04409830362419598, 0.04279557469999418, 0.09634896588977426, 0.03079462931054877, 0.03458800398220774, 0.04388996050693095, 0.03293396832305007, 0.024292840498674195, 0.010293817413185025, 0.055092071124818176, 0.07792932810843922, 0.132120187045075, 0.05738930020015687, 6.479222327470779, 40.215582847595215, 48.19325476884842, 40.26565656065941, 30.506968908011913, 18.110305108129978, 32.47292071580887, 40.72738118469715, 55.03359831869602, 29.18368611484766, 0.1826596719911322, 0.01764494321832899, 0.6994052545633167, 0.9150487300939858, 3.692339533008635, 40.70720046758652, 55.55574730038643, 51.81452505290508, 47.87800848484039, 47.31198325753212, 46.4816290140152, 48.166568800807, 47.570399791002274, 43.893652483820915, 41.232453882694244, 37.67468959093094, 37.72967644035816, 36.886250898242, 36.365811824798584, 40.98003722727299, 45.66932000219822, 48.72218258678913, 46.84009797871113, 45.07105350494385, 43.88474956154823, 40.66431976854801, 43.57597053050995, 44.40868824720383, 44.96557496488094, 44.397418051958084, 46.749104261398315, 48.60097289085388, 44.468877017498016, 46.05117671191692, 46.79295010864735, 42.41495043039322, 34.97581601142883, 36.18742659687996, 37.11382448673248, 35.46206831932068, 34.858337715268135, 36.338259503245354, 37.11689472198486, 34.97556522488594, 35.06209038197994, 36.83239258825779, 35.93530252575874, 36.936936378479004, 34.85472030937672, 35.239324271678925, 35.60052528977394, 37.58999593555927, 43.12755659222603, 49.12727504968643, 49.27550129592419, 48.95954445004463, 49.55195166170597, 52.985109239816666, 52.243252247571945, 50.907718911767006, 51.49649351835251, 48.51817533373833, 43.43008495867252, 44.36898797750473, 48.92073713243008, 50.529886186122894, 45.65763182938099, 48.22211802005768, 50.42601875960827, 49.28341247141361, 52.96978086233139, 51.561508029699326, 46.356007754802704, 47.39427164196968, 46.49293340742588, 49.63759146630764, 47.64167256653309, 43.9847943931818, 41.64294585585594, 36.60265691578388, 34.47386294603348, 36.2775881588459, 35.85499383509159, 36.10866442322731, 36.28986909985542, 36.35538898408413, 37.26245731115341, 36.7984414100647, 37.07203432917595, 36.93102769553661, 36.901332288980484, 36.39457248151302, 36.653904765844345, 35.32749854028225, 34.93425004184246, 36.137470677495, 35.63999377191067, 36.57939836382866, 39.17701497673988, 43.53756599128246, 46.65048435330391, 47.216528579592705, 46.093958616256714, 46.602082550525665, 50.63012480735779, 47.96223096549511, 41.46609574556351, 35.785556361079216, 36.84224545955658, 37.39520698785782, 41.11631691455841, 45.099529176950455, 47.31955245137215, 47.55791746079922, 43.84207025170326, 37.917150780558586, 47.55788326263428, 52.937395200133324, 58.21712449193001, 52.74841994047165, 55.408774986863136, 58.60185004770756, 60.48814482986927, 58.889167830348015, 60.45441783964634, 59.9943233281374, 38.40092562139034, 4.854837991297245, 0.15075762290507555, 0.32329273817595094, 0.0823330543062184, 0.5147712619509548, 33.6171343177557, 62.41332292556763, 48.8308035582304, 46.1177833378315, 26.036869771778584, 23.47125504165888, 44.89168033003807, 50.94498731195927, 24.43982306867838, 1.0194196295924485, 0.08689152571605518, 0.03592306456994265, 0.0585519932792522, 0.04079294485563878, 0.02626137422339525, 0.05821365186420735, 0.04348432114056777, 0.04832417413126677, 0.02672621099918615, 0.039532696464448236, 0.0709821653435938, 0.037265053106239066, 0.024832476483425125, 0.03420456596359145, 0.10122819352545775, 0.04065761051606387, 0.029611629215651192, 0.012515921662270557, 0.028440466376196127, 0.03825833242444787, 0.040700343379285187, 0.06093672156566754, 0.11648509476799518, 0.015258627663570223, 8.04492736235261, 47.02634118497372, 54.574442356824875, 47.254226356744766, 35.845589339733124, 23.67581706494093, 37.617472261190414, 46.2100575864315, 59.97038081288338, 32.61813372373581, 0.17113653797423467, 0.06588590404135175, 1.3282440206967294, 1.5883873240090907, 5.235265027731657, 41.397741213440895, 57.721304297447205, 53.28327924013138, 50.22927291691303, 48.37291292846203, 48.7057788670063, 48.25961820781231, 48.24980713427067, 44.43643055856228, 42.21540793776512, 38.71460258960724, 40.66556230187416, 38.08999590575695, 37.456216514110565, 42.164087891578674, 47.303403317928314, 48.77520114183426, 47.25517250597477, 46.45637556910515, 46.93643420934677, 43.00458759069443, 45.15475161373615, 45.405766144394875, 46.21821954846382, 45.91096803545952, 48.804850950837135, 49.39790792763233, 46.87329679727554, 45.97090221941471, 50.05747653543949, 45.21873638033867, 35.67099630832672, 37.25574687123299, 37.450703009963036, 36.91378802061081, 37.51510575413704, 37.579998672008514, 39.74035754799843, 36.26577079296112, 37.520246878266335, 37.96212516725063, 37.025194242596626, 38.95342357456684, 36.64279796183109, 36.95143260061741, 37.84443788230419, 39.83898885548115, 44.961554780602455, 50.97771495580673, 52.146935015916824, 50.89005745947361, 53.62128630280495, 54.400024116039276, 51.32410816848278, 51.656658723950386, 52.29541964828968, 50.925528556108475, 45.92049412429333, 47.322938069701195, 51.34500704705715, 53.506247475743294, 47.56671778857708, 49.68176409602165, 51.74194514751434, 48.65499459207058, 52.653162851929665, 50.78137569129467, 46.313708424568176, 47.76208810508251, 47.794899344444275, 51.37636676430702, 49.30268123745918, 46.2881737947464, 43.44724103808403, 38.552776873111725, 36.94488175213337, 37.99843601882458, 38.69199380278587, 38.03282417356968, 38.58455076813698, 37.65902683138847, 38.1157661229372, 37.438448667526245, 37.834193632006645, 37.16669104993343, 39.380513057112694, 39.0833880007267, 39.705068841576576, 38.02285350859165, 38.16789172589779, 37.38420657813549, 37.8338136523962, 39.729326739907265, 41.45143613219261, 46.49294100701809, 49.25153598189354, 49.54579599201679, 48.30941453576088, 48.79112608730793, 53.73106621205807, 49.78861816227436, 43.63543353974819, 36.956710517406464, 39.23827148973942, 39.98263254761696, 44.528670608997345, 47.0694574713707, 49.57904040813446, 48.24390985071659, 46.01699374616146, 40.90653397142887, 51.48414418101311, 55.7751627266407, 61.23970650136471, 56.58617600798607, 56.18904411792755, 59.32430908083916, 62.79896043241024, 62.07796432077885, 63.74217242002487, 62.89323717355728, 40.229303911328316, 6.376440217718482, 0.5602730484679341, 1.4645411632955074, 0.08963370943092741, 0.38239690416958183, 37.04767383635044, 69.20507848262787, 52.68966369330883, 51.34844206273556, 31.99894554913044, 30.137833915650845, 51.43490642309189, 59.425725638866425, 31.7940928414464, 1.3292852835729718, 0.09590931760612875, 0.07664911594474688, 0.04115775125683285, 0.01527647353213979, 0.09803041277336888, 0.04749941799673252, 0.049817894760053605, 0.018814430659404024, 0.02793581152218394, 0.0375214873929508, 0.07908113388111815, 0.21174044668441638, 0.1588592483312823, 0.18867969192797318, 0.16409300733357668, 0.16645818745018914, 0.11920729244593531, 0.09233629956725053, 0.09031450375914574, 0.09410583938006312, 0.17514468461740762, 0.18178720318246633, 0.3613113606115803, 0.14195267896866426, 8.937147986143827, 52.70051211118698, 61.461568996310234, 53.70458543300629, 42.651708126068115, 27.501322589814663, 43.30295518040657, 51.02832444012165, 64.09476310014725, 37.08711192011833, 0.39197509177029133, 0.19781686569331214, 3.4488597605377436, 3.8452981878072023, 5.379417417570949, 44.76776137948036, 60.34366898238659, 57.245303839445114, 51.559836119413376, 51.78053967654705, 50.7578169554472, 52.23019614815712, 51.72090567648411, 47.98075117170811, 45.16969621181488, 40.30175842344761, 41.378662437200546, 41.200383603572845, 40.75235724449158, 45.0675804913044, 50.5285220593214, 51.59988597035408, 49.59790259599686, 47.884433940052986, 47.643796652555466, 45.221141651272774, 47.65020690858364, 48.646999821066856, 48.64804096519947, 47.86147557199001, 49.37782600522041, 50.33637776970863, 46.394906267523766, 47.85644844174385, 52.57943540811539, 47.531007304787636, 37.85641483962536, 39.16585497558117, 39.0508883446455, 38.670581951737404, 38.25480446219444, 39.49171029031277, 41.92567728459835, 38.508684039115906, 39.24982286989689, 39.54879082739353, 39.303954765200615, 42.49621666967869, 38.50777968764305, 38.18234235048294, 40.245475843548775, 40.733232870697975, 45.86862310767174, 52.19891242682934, 54.518763944506645, 53.65883968770504, 54.69626381993294, 55.67292921245098, 53.91439117491245, 53.37837293744087, 55.138313099741936, 52.52255246043205, 49.05817195773125, 50.72184808552265, 51.78084746003151, 55.878308191895485, 49.607523679733276, 50.42300932109356, 56.16694450378418, 51.87862001359463, 54.26952391862869, 51.61085978150368, 47.23031423985958, 48.147657215595245, 49.31252270936966, 55.46031542122364, 53.15062835812569, 47.879133224487305, 45.37720687687397, 40.20386427640915, 38.1783601641655, 40.98631829023361, 40.569370463490486, 40.70242032408714, 39.8840506374836, 39.177497550845146, 39.06841680407524, 39.39310938119888, 41.39470137655735, 39.45345014333725, 40.56210905313492, 40.602683275938034, 41.223338171839714, 39.19309191405773, 39.80977602303028, 40.39289653301239, 39.58451271057129, 41.54754817485809, 43.46614882349968, 47.80993513762951, 52.170106172561646, 53.95840801298618, 51.7419071495533, 49.031930565834045, 54.657380506396294, 53.18000838160515, 46.47274889051914, 39.40459996461868, 39.351049438118935, 42.67877787351608, 46.36402152478695, 49.33832712471485, 52.55453534424305, 51.33163556456566, 49.26734313368797, 42.578691244125366, 52.67957903444767, 57.00922630727291, 64.02669355273247, 58.7693602591753, 59.34111937880516, 60.80098584294319, 63.77062529325485, 63.333454951643944, 65.25332853198051, 64.51514974236488, 43.954912796616554, 7.513931505382061, 1.6493740514852107, 2.4741078028455377, 0.28694023727439344, 0.7262259966228157, 39.57185558974743, 75.50453245639801, 60.47859974205494, 61.9517806917429, 38.045538291335106, 36.635578349232674, 60.216136425733566, 69.29307416081429, 42.87051558494568, 2.295992122963071, 0.2230622063507326, 0.10095316843944602, 0.21543110255151987, 0.053351360038504936, 0.17231916513992473, 0.1259123146883212, 0.25779933377634734, 0.14244263002183288, 0.1219891884829849, 0.18147557537304237, 0.1701857874286361], [0.0590875641501043, 0.011945644255320076, 0.07498965147533454, 0.10703405932872556, 0.04076728509971872, 0.010895988616539398, 0.03871173641528003, 0.0008047558344514982, 0.08402061648666859, 0.03079964251810452, 0.033269882915192284, 0.10447221007780172, 0.01143803008744726, 1.8255926831625402, 31.985802054405212, 49.33334179222584, 44.552225545048714, 34.3700335174799, 24.366760589182377, 32.94226013123989, 44.754412695765495, 50.71104146540165, 43.55928182601929, 1.2356641259975731, 0.1308120330213569, 0.10419420155812986, 1.1767856916412711, 2.8139306930825114, 25.083985403180122, 56.8168768286705, 52.64706797897816, 51.76500990986824, 50.36642275750637, 52.446913719177246, 50.417552813887596, 49.63120020925999, 49.51048068702221, 45.97007766366005, 38.26751857995987, 34.72581222653389, 35.34678630530834, 41.557515040040016, 44.769573882222176, 47.14747488498688, 45.44638976454735, 46.82286590337753, 44.24053966999054, 45.290567725896835, 42.84133315086365, 40.606878250837326, 45.94472922384739, 47.50467091798782, 50.06212368607521, 47.75530926883221, 44.5512717962265, 43.5131599009037, 46.31814278662205, 46.53055138885975, 41.17836378514767, 35.55936209857464, 35.90037859976292, 35.074261128902435, 36.29748769104481, 34.848655834794044, 36.34966269135475, 36.79184876382351, 36.526991575956345, 36.28208711743355, 37.42494039237499, 35.882625952363014, 36.74497447907925, 33.739293962717056, 36.74568124115467, 37.11622595787048, 36.55837029218674, 37.25491851568222, 42.445010617375374, 44.29176852107048, 47.11735390126705, 45.334181785583496, 49.671554043889046, 51.461410000920296, 50.49333594739437, 51.395213752985, 48.21332909166813, 42.37141236662865, 43.86486142873764, 52.299838811159134, 50.84898926317692, 48.452488258481026, 48.771880120038986, 52.372635304927826, 56.615586429834366, 47.672952488064766, 43.598400726914406, 45.31185418367386, 46.46446913480759, 46.62391997873783, 50.27518965303898, 48.316896334290504, 44.02780048549175, 37.71795406937599, 36.343301832675934, 38.20617087185383, 34.01390142738819, 35.90291306376457, 37.72960804402828, 36.0801887512207, 35.92517226934433, 35.44396609067917, 37.16747760772705, 36.33712716400623, 36.71443171799183, 38.05367365479469, 37.406815364956856, 36.98702909052372, 35.537011697888374, 35.269107073545456, 35.01927427947521, 35.483005195856094, 35.68998768925667, 42.092647925019264, 43.67769867181778, 47.20725707709789, 43.09446796774864, 42.93766938149929, 45.78066162765026, 50.66235087811947, 49.555162489414215, 46.37381359934807, 39.83602501451969, 37.557207494974136, 36.89109183847904, 38.63835588097572, 43.24611783027649, 48.40811423957348, 45.09824864566326, 46.75747521221638, 42.01206564903259, 40.71808308362961, 44.5560747385025, 53.15802276134491, 54.88870069384575, 54.49020467698574, 54.85604524612427, 57.94000916182995, 61.32614806294441, 60.58388829231262, 53.87749135494232, 24.987626373767853, 2.5071947649121284, 0.7467562356032431, 0.14796679140999913, 0.153799953404814, 0.7248970773071051, 31.763529181480408, 61.23106196522713, 47.8244199603796, 37.97499507665634, 26.35907918214798, 30.06848953664303, 48.249700739979744, 48.228022903203964, 25.894233025610447, 1.4103881316259503, 0.10064056099508889, 0.012508238578448072, 0.04050773008202668, 0.09318006210378371, 0.023156142997322604, 0.036945061292499304, 0.019103204031125642, 0.020465002344280947, 0.024249552880064584, 0.0409458050125977, 0.05735393315262627, 0.05538836616324261, 0.08540396491298452, 0.08754265640163794, 0.03385898489796091, 0.0071088108779804315, 0.03941366710932925, 0.05083670766907744, 0.06083952248445712, 0.03545415340340696, 0.042604193367878906, 0.04717948555480689, 0.08945790206780657, 0.04704281163867563, 2.7495538350194693, 38.19455489516258, 55.52075117826462, 48.98986682295799, 37.928116992115974, 24.70658205449581, 38.82632799446583, 51.23593010008335, 55.69843344390392, 45.911925584077835, 1.448332064319402, 0.11247623566305265, 0.5373834923375398, 1.5920747886411846, 4.6988501865416765, 26.83547481894493, 59.59891274571419, 54.55653391778469, 53.88929732143879, 51.82923786342144, 55.27357064187527, 52.56463520228863, 52.53960594534874, 50.23431904613972, 49.525869861245155, 40.31613305211067, 37.47884050011635, 37.20495119690895, 43.04459564387798, 45.75305610895157, 49.593578428030014, 45.83041995763779, 47.58793964982033, 46.10109083354473, 47.07158535718918, 44.05083104968071, 43.62245723605156, 47.747204303741455, 48.205642104148865, 51.16978704929352, 49.29676495492458, 47.344916090369225, 44.33685690164566, 48.52568753063679, 49.5839649438858, 43.64437825977802, 35.97719147801399, 37.87508703768253, 38.0477611720562, 38.38436610996723, 37.8885193169117, 39.12027262151241, 38.898296132683754, 39.143838956952095, 38.828991651535034, 38.363797813653946, 37.087184116244316, 36.77035331726074, 36.19114279747009, 37.81628519296646, 39.66251492500305, 36.25365324318409, 39.610921293497086, 44.62109684944153, 45.810284838080406, 48.523935824632645, 47.70026542246342, 52.98829726874828, 53.23936499655247, 53.43972064554691, 52.43295706808567, 51.07019059360027, 44.922211691737175, 45.6875666230917, 54.31785732507706, 51.36994890868664, 47.95929752290249, 49.87722560763359, 51.63560025393963, 56.353571489453316, 51.63650460541248, 44.59786109626293, 46.56727261841297, 47.751612067222595, 46.90613463521004, 50.13772822916508, 50.171633809804916, 46.482115387916565, 41.194714307785034, 37.53117889165878, 38.285275027155876, 36.66455939412117, 37.46676094830036, 38.90593372285366, 38.0728854238987, 36.6998291015625, 38.30938473343849, 38.01327422261238, 38.37022326886654, 38.12192939221859, 39.86705034971237, 39.097815826535225, 39.451037272810936, 37.60903291404247, 37.327589616179466, 37.38064996898174, 36.46729677915573, 37.72395774722099, 43.65165486931801, 46.70809306204319, 48.324298337101936, 45.967159420251846, 45.43701946735382, 46.31819598376751, 52.00591318309307, 51.807461231946945, 48.73917147517204, 41.30986712872982, 39.07569341361523, 38.22157524526119, 41.0485627502203, 45.36100074648857, 50.6233611702919, 47.747143507003784, 47.67293728888035, 43.395373821258545, 42.83028334379196, 48.087802827358246, 55.641634091734886, 57.708517983555794, 56.60998933017254, 56.32810905575752, 59.19324271380901, 61.11382685601711, 62.41843365132809, 55.4421865940094, 27.862337417900562, 3.574436609633267, 1.6722342185676098, 0.398195298621431, 0.14805543352849782, 0.748126715188846, 33.578361198306084, 67.27272257208824, 51.94348253309727, 45.55521212518215, 27.49476984143257, 29.642794579267502, 54.076053500175476, 55.873832032084465, 32.73464307188988, 2.0690286392346025, 0.15562832326395437, 0.003328648290334968, 0.061095184937585145, 0.01567277668073075, 0.11012610630132258, 0.09455157327465713, 0.025085324341489468, 0.032033936149673536, 0.011294323394395178, 0.017648279172135517, 0.033450158007326536, 0.2022576695890166, 0.1613023242680356, 0.14367293275427073, 0.13454503583488986, 0.0980568332306575, 0.09166487856418826, 0.2052845188882202, 0.18551155255408958, 0.2953486517071724, 0.11581342143472284, 0.13791076460620388, 0.19438887073192745, 0.18393436999758705, 3.045945530757308, 43.761628568172455, 61.83082938194275, 54.95028018951416, 45.05644328892231, 33.48148539662361, 43.23610916733742, 57.69355818629265, 60.245204865932465, 51.78293354809284, 1.9503935426473618, 0.2681019762530923, 1.7018025694414973, 4.7477103397250175, 6.183039145544171, 25.98613679409027, 63.1656863540411, 56.86513043940067, 56.416237726807594, 54.64432440698147, 57.49089606106281, 54.628551453351974, 54.40763510763645, 52.48705476522446, 51.38212725520134, 41.990406811237335, 39.290294498205185, 38.636881560087204, 45.64818553626537, 48.28386090695858, 52.16218359768391, 46.697541028261185, 49.18852396309376, 46.32846303284168, 48.474637269973755, 45.79116806387901, 46.03638790547848, 51.37720271945, 50.542569905519485, 53.61190840601921, 50.369736179709435, 46.20675936341286, 43.99757690727711, 49.55868110060692, 51.333132684230804, 44.72771912813187, 38.25808368623257, 40.22344462573528, 39.69798982143402, 40.218121111392975, 38.411261066794395, 40.90137004852295, 41.03399433195591, 40.66247686743736, 40.06677143275738, 41.06905125081539, 40.67699208855629, 39.86924283206463, 38.41458208858967, 40.36463364958763, 42.930461168289185, 38.62270072102547, 42.919373363256454, 45.33694803714752, 48.33064779639244, 49.66899678111076, 48.6154805123806, 54.21832166612148, 54.24644015729427, 54.29588310420513, 55.95751114189625, 52.17828333377838, 46.351763382554054, 48.77328984439373, 55.64777076244354, 55.123915672302246, 51.175847724080086, 51.31785370409489, 53.89075644314289, 53.6667812615633, 50.4785243421793, 45.874520391225815, 47.43231140077114, 49.64967481791973, 49.841119945049286, 52.303801998496056, 51.65029786527157, 48.498974964022636, 42.26442150771618, 39.98574458062649, 41.95973105728626, 37.2239425778389, 39.09218072891235, 41.71748265624046, 40.393561497330666, 37.95967049896717, 40.57060919702053, 40.17001189291477, 41.019893288612366, 39.20242041349411, 43.081890642642975, 41.64315864443779, 41.760222762823105, 39.333642572164536, 39.02054317295551, 38.82884345948696, 40.54278329014778, 38.824773877859116, 47.0363612473011, 48.62847201526165, 52.21484117209911, 47.28965565562248, 46.599544286727905, 48.31247337162495, 51.758523657917976, 56.50744803249836, 51.76083393394947, 43.77213500440121, 42.080515176057816, 40.515405759215355, 42.504944801330566, 47.48855218291283, 53.22152115404606, 50.09830914437771, 50.75678341090679, 46.653679981827736, 45.94300791621208, 49.53146696090698, 58.17323684692383, 60.836164355278015, 59.25727307796478, 60.90710274875164, 60.341263711452484, 63.43272842466831, 64.36438143253326, 57.56384834647179, 29.71009086817503, 3.7166907638311386, 4.864333206787705, 1.285625270102173, 0.27716069016605616, 0.7581158448010683, 37.76046998798847, 70.30391111969948, 60.10419063270092, 51.50618299841881, 38.76855589449406, 41.278632804751396, 62.7184921503067, 63.24823312461376, 42.20652021467686, 2.744726431556046, 0.23920783685753122, 0.10199729600572027, 0.15812925703357905, 0.11983255928498693, 0.18859579955460504, 0.20688951713964343, 0.12068867858033627, 0.0956435248372145, 0.15166102442890406, 0.1685794087825343, 0.21942154155112803], [0.06490770145319402, 0.028409604165062774, 0.01448904185963329, 0.09299554192693904, 0.04790394414158072, 0.040404129977105185, 0.026806212663359474, 0.032370644839829765, 0.07531293100328185, 0.03550133544194978, 0.03038768747501308, 0.03520021273288876, 0.10867731529287994, 0.4047970287501812, 22.86716155707836, 49.00145620107651, 43.56296382844448, 33.45269054174423, 22.63058055192232, 23.746362179517746, 42.03622095286846, 47.826825231313705, 47.80684970319271, 3.4844954358413815, 0.1916120361420326, 0.5771960935089737, 2.0320972334593534, 3.9506508596241474, 11.38330852612853, 49.89964820444584, 53.07237535715103, 54.08668152987957, 55.023935437202454, 52.84017361700535, 50.836389139294624, 51.68463662266731, 51.090420708060265, 48.67307782173157, 37.362129762768745, 36.65493831038475, 44.172139540314674, 50.75076073408127, 46.92761488258839, 47.786942571401596, 45.73596842586994, 45.04799634218216, 47.0784667879343, 46.038633584976196, 46.67698033154011, 43.189998641610146, 44.37098667025566, 49.53711345791817, 43.52772831916809, 44.46018308401108, 43.88598829507828, 46.665246561169624, 47.668521925807, 46.744225323200226, 40.30188761651516, 34.30508740246296, 34.40240018069744, 34.60258483886719, 35.30964329838753, 35.150321647524834, 36.002456322312355, 37.07333765923977, 36.68485790491104, 36.20902843773365, 36.517997458577156, 37.28878989815712, 37.457246258854866, 36.24389536678791, 35.92172585427761, 35.253577306866646, 35.73605261743069, 39.44993533194065, 41.127735301852226, 39.003831669688225, 39.59020100533962, 39.647760316729546, 43.558654859662056, 46.00850120186806, 48.131321892142296, 49.700082913041115, 46.794956400990486, 41.73486292362213, 47.10911214351654, 50.46953782439232, 52.25035786628723, 46.682543233036995, 54.94141146540642, 56.26364931464195, 40.3835566341877, 40.04810303449631, 45.63830606639385, 48.38363215327263, 49.379414319992065, 48.89104172587395, 48.92774395644665, 46.46916948258877, 41.76286742091179, 38.62186096608639, 36.744176521897316, 37.497292309999466, 36.361024081707, 36.54104322195053, 35.6042604893446, 35.336754843592644, 37.410622760653496, 36.69403821229935, 35.973524674773216, 37.38528572022915, 37.622051015496254, 35.23363217711449, 37.11844123899937, 39.48666416108608, 37.80897058546543, 35.166117399930954, 36.773237362504005, 34.088362231850624, 36.845106706023216, 42.68622547388077, 45.854050889611244, 46.074511259794235, 48.09862844645977, 46.32145620882511, 43.10529738664627, 48.38814251124859, 52.30492293834686, 51.31265178322792, 49.365985840559006, 43.63856457173824, 38.3785106241703, 38.66124205291271, 38.51378336548805, 42.547681108117104, 46.006715297698975, 45.02756103873253, 41.792209446430206, 39.769467785954475, 40.01724489033222, 45.944683626294136, 51.75403989851475, 55.07546827197075, 57.790266796946526, 56.90481171011925, 54.770101457834244, 56.94822818040848, 49.25900638103485, 18.498030602931976, 1.1435767798684537, 0.64815663266927, 0.8195845526643097, 0.11208548748982139, 0.6131161598023027, 33.238682225346565, 64.18257638812065, 48.73417094349861, 45.95970042049885, 26.99851457029581, 26.562349274754524, 44.785506427288055, 48.848309218883514, 20.437043756246567, 0.4581911105196923, 0.03320697105664294, 0.04455893984413706, 0.022250257134146523, 0.06353845383273438, 0.044889896889799275, 0.03912292704626452, 0.04014530226413626, 0.020335816698207054, 0.013739520945819095, 0.011408005575503921, 0.0157266566020553, 0.02364703843340976, 0.01700837161479285, 0.05217209480179008, 0.09638131610699929, 0.07198832463473082, 0.040010316733969375, 0.014311333670775639, 0.04669527130317874, 0.0033954339278352563, 0.02371941453020554, 0.06717016090988182, 0.0337136241432745, 0.03184056586178485, 0.5743871536105871, 27.168213464319706, 56.961079090833664, 49.25641871988773, 38.50777588784695, 24.54767268151045, 29.430954046547413, 49.041551649570465, 52.03909680247307, 53.96839767694473, 3.7363216979429126, 0.13571428949944675, 0.21132944530108944, 4.9529848247766495, 4.484158381819725, 12.896316088736057, 51.732821837067604, 53.938447684049606, 55.72880141437054, 55.91279894113541, 56.54550299048424, 51.797779351472855, 52.8726314753294, 53.36359553039074, 51.391839534044266, 38.71391862630844, 36.95273973047733, 45.38086608052254, 52.04487629234791, 48.951511681079865, 48.797980919480324, 45.75757026672363, 46.63071781396866, 46.52525447309017, 45.62415562570095, 48.06284576654434, 46.56210869550705, 45.87604030966759, 51.33505158126354, 44.92790758609772, 46.215631887316704, 44.25672300159931, 49.00698870420456, 48.58683004975319, 48.53016749024391, 42.98952519893646, 36.0750400274992, 36.50043100118637, 37.00308322906494, 36.122792065143585, 38.412161618471146, 37.343427166342735, 39.51339192688465, 37.70481437444687, 38.98533046245575, 37.70822659134865, 37.69298940896988, 39.05604846775532, 37.96326890587807, 37.26931594312191, 36.57990753650665, 38.18212956190109, 41.69243060052395, 42.76160202920437, 42.25266873836517, 40.73499597609043, 41.579998433589935, 45.85620917379856, 48.727004528045654, 52.30003260076046, 51.39417260885239, 47.44849853217602, 44.62632916867733, 48.93149435520172, 52.67647460103035, 52.68134593963623, 49.24363620579243, 52.89975821971893, 59.90472413599491, 45.732332020998, 42.992914617061615, 46.402984634041786, 49.62623007595539, 51.0708973556757, 49.48387831449509, 50.03935530781746, 50.15376336872578, 43.23017008602619, 40.583509504795074, 38.114850372076035, 39.681187123060226, 38.14472436904907, 39.3883216381073, 38.37042085826397, 38.45192648470402, 37.57250167429447, 37.72608183324337, 37.7242199331522, 38.93347844481468, 38.27103339135647, 37.781327068805695, 39.44659911096096, 40.63217729330063, 39.62077796459198, 38.069017231464386, 38.82881686091423, 37.97613121569157, 39.73255276679993, 43.68806071579456, 47.58185617625713, 48.63963961601257, 50.6376788020134, 45.71800298988819, 45.13574503362179, 48.12781848013401, 54.23885956406593, 54.20956313610077, 52.037310898303986, 45.62106639146805, 39.22396905720234, 38.54287460446358, 40.87090328335762, 44.62320193648338, 48.46441201865673, 45.97113020718098, 44.91907685995102, 43.323736265301704, 42.25265733897686, 47.22804196178913, 54.623243138194084, 56.53180852532387, 59.135318621993065, 59.13472965359688, 57.05531403422356, 56.793040707707405, 52.19877943396568, 19.074814952909946, 2.789465943351388, 2.3060877062380314, 0.5683887004852295, 0.21827639284310862, 0.5538545991294086, 35.309126526117325, 67.71204739809036, 52.79692433774471, 49.436103478074074, 32.2545350342989, 33.068508356809616, 53.029631450772285, 55.45807734131813, 27.467209920287132, 0.6758494873065501, 0.07621156793902628, 0.03234721894841641, 0.03761772168218158, 0.052662023590528406, 0.058150083204964176, 0.017066583823179826, 0.03004734040587209, 0.04431715184182394, 0.039031308915582485, 0.047971999083529226, 0.02621377101604594, 0.12968108901986852, 0.12851008388679475, 0.14863227523164824, 0.18392295576632023, 0.2033580222632736, 0.12572594656376168, 0.10320040644728579, 0.16800853394670412, 0.13551802112488076, 0.16556118323933333, 0.10000128240790218, 0.13240708649391308, 0.16193746909266338, 0.8919858082663268, 30.993878580629826, 61.30982033908367, 55.29080651700497, 45.88483303785324, 31.044748350977898, 31.261082142591476, 53.126324862241745, 55.603594332933426, 59.57156181335449, 4.588830415159464, 0.24155288992915303, 1.9095796952024102, 5.062949024140835, 6.6962282080203295, 13.533111568540335, 56.1578705906868, 54.97913584113121, 58.70265103876591, 57.06883370876312, 56.45205460488796, 53.57145957648754, 55.8599703758955, 54.78377312421799, 54.31120008230209, 40.8264646679163, 39.69412922859192, 49.140920117497444, 54.69445511698723, 52.000247687101364, 51.51983946561813, 48.82587142288685, 47.358739748597145, 47.80325889587402, 47.00549550354481, 48.96165333688259, 45.809965655207634, 47.22362659871578, 52.004374265670776, 44.44839611649513, 46.30218364298344, 44.782428592443466, 50.74622757732868, 52.17638723552227, 52.96231426298618, 44.80211153626442, 38.51254843175411, 38.56843203306198, 37.88925267755985, 39.00111101567745, 40.8200354129076, 40.64992994070053, 41.6014064848423, 39.42854627966881, 40.09977646172047, 39.19644333422184, 40.39662413299084, 42.6466353982687, 39.835728630423546, 38.60808290541172, 38.037657514214516, 39.30276162922382, 43.16075541079044, 45.48395834863186, 43.778131082654, 43.34136351943016, 43.247607350349426, 48.91310714185238, 51.31094567477703, 54.22787435352802, 54.84119564294815, 50.714115500450134, 47.184963673353195, 52.36407816410065, 55.58874852955341, 56.49409554898739, 51.42766021192074, 54.83503237366676, 55.794142708182335, 45.70645160973072, 45.90698204934597, 49.050496369600296, 52.39929847419262, 52.38146223127842, 51.066462993621826, 51.87040485441685, 52.7314842492342, 45.743294432759285, 41.98898948729038, 40.038341358304024, 42.04279080033302, 39.68588747084141, 41.33930794894695, 39.83784891664982, 39.81926791369915, 39.92894522845745, 40.22869594395161, 39.89661656320095, 40.331066250801086, 41.515838876366615, 39.86946702003479, 40.41932411491871, 41.963291466236115, 42.410907447338104, 39.279275089502335, 40.67894138395786, 37.878750041127205, 40.829531103372574, 46.176683977246284, 48.7536296993494, 51.09123386442661, 52.88183458149433, 46.95826783776283, 46.748074516654015, 47.92991749942303, 54.762110486626625, 55.74221469461918, 54.53868627548218, 47.68331453204155, 42.57610358297825, 41.44221022725105, 42.427672147750854, 46.53937071561813, 50.609077736735344, 50.109529942274094, 47.808301225304604, 44.069127067923546, 43.62818732857704, 49.261882826685905, 56.70319452881813, 60.34330800175667, 61.29461355507374, 63.24679680168629, 60.450804233551025, 57.87655256688595, 53.35564635694027, 22.055701799690723, 3.6267153918743134, 2.7670706575736403, 2.749739312566817, 0.5928491160739213, 0.6932204333133996, 38.8782712072134, 75.45439034700394, 61.25014454126358, 58.598228842020035, 41.20468117296696, 39.06714387238026, 59.98053006827831, 64.28274661302567, 35.8181282132864, 1.0881607909686863, 0.18543239508289844, 0.09993280444177799, 0.08932370692491531, 0.21674090414308012, 0.17134438385255635, 0.13410935061983764, 0.13751125166891143, 0.20181779866106808, 0.08868972727213986, 0.07140912290196866, 0.12521941593149677], [0.04350555769633502, 0.02740136314969277, 0.01977927087864373, 0.04785160046594683, 0.0740340250195004, 0.056649293619557284, 0.12070410783053376, 0.04933679381792899, 0.024209630901168566, 0.0725295655138325, 0.03828667875495739, 0.005877400953977485, 0.15362862119218335, 0.08606987175880931, 7.330107819288969, 42.46634267270565, 45.421254113316536, 35.63088946044445, 24.095715433359146, 31.854690089821815, 42.75945134460926, 44.86732743680477, 51.79845951497555, 7.856419002637267, 0.0453580028261058, 0.1711192014045082, 3.3818180579692125, 3.221459062770009, 2.4372958531603217, 33.78721699118614, 52.569160759449005, 57.06275023519993, 42.99576826393604, 44.03142549097538, 47.844471484422684, 52.745714485645294, 49.736579954624176, 42.21918113529682, 35.26344537734985, 43.54690968990326, 51.10233686864376, 47.76292786002159, 47.199988067150116, 43.852029517292976, 47.258873507380486, 48.46821181476116, 47.0928680151701, 47.39919997751713, 46.42968200147152, 47.376044020056725, 44.52126860618591, 46.489790976047516, 46.15679584443569, 45.7075497508049, 46.621993482112885, 49.063700661063194, 44.23228271305561, 43.046955317258835, 35.086994245648384, 35.68111516535282, 36.753334030508995, 35.87910354137421, 35.062333568930626, 36.25011183321476, 35.316296741366386, 35.8369106054306, 36.66550174355507, 35.39887771010399, 36.47174634039402, 37.40176923573017, 36.75284005701542, 35.74831835925579, 36.217179000377655, 36.394428089261055, 36.52185805141926, 42.62940712273121, 43.97736579179764, 47.538055926561356, 46.76694430410862, 40.79958111047745, 37.03003138303757, 38.888496458530426, 39.002098962664604, 40.53950786590576, 38.72304953634739, 45.434853583574295, 51.24674052000046, 52.25460983812809, 50.483916252851486, 47.36077643930912, 57.58473202586174, 37.70913474261761, 44.06889148056507, 49.11922328174114, 48.18323850631714, 48.34325931966305, 47.307263910770416, 48.93560953438282, 48.350193947553635, 43.86634334921837, 38.469287753105164, 35.64374417066574, 36.755271926522255, 36.03523716330528, 35.32381273806095, 34.78454947471619, 36.784401163458824, 36.586264595389366, 36.596193462610245, 36.519574373960495, 36.130980625748634, 37.34916865825653, 37.488450184464455, 37.0279148966074, 36.53732322156429, 37.51122236251831, 36.46702699363232, 35.678956881165504, 36.49306319653988, 35.27213931083679, 37.3152706772089, 44.68662053346634, 49.0146528929472, 48.067527115345, 44.51853275299072, 49.48973760008812, 44.68730829656124, 45.12950576841831, 46.6984947770834, 48.28145183622837, 49.95557740330696, 50.30228979885578, 45.77192969620228, 41.38954125344753, 37.90084965527058, 38.924013152718544, 39.596231281757355, 40.625364258885384, 42.034457847476006, 40.573512241244316, 41.31703734397888, 39.603219106793404, 40.96183620393276, 45.296981781721115, 53.62981304526329, 55.496060103178024, 56.95235475897789, 61.13678142428398, 49.083364605903625, 12.188253533095121, 1.2094591883942485, 1.0107024223543704, 0.5542288790456951, 0.1482881116680801, 0.6959853786975145, 32.91500799357891, 62.031622007489204, 47.38411858677864, 47.750806510448456, 26.368723064661026, 36.437304988503456, 45.2153355628252, 51.820950508117676, 22.098527401685715, 0.43013629561755806, 0.017833871752372943, 0.0872849159350153, 0.04560500070510898, 0.014038926510693273, 0.021189375584071968, 0.08203890407457948, 0.010553816791798454, 0.05711612306185998, 0.04932363182888366, 0.06621523207286373, 0.012074008900526678, 0.0563858089299174, 0.04072101590281818, 0.026662850141292438, 0.008582844184275018, 0.055905390763655305, 0.03501139181025792, 0.06977981931413524, 0.10817636561114341, 0.0024186272730730707, 0.0636986835161224, 0.09557605619193055, 0.03397654108994175, 0.03077907946135383, 0.10650888594682328, 11.364397890865803, 50.933416932821274, 50.528104081749916, 41.848720014095306, 23.553248941898346, 31.27889558672905, 44.546841233968735, 48.5592283308506, 56.42191082239151, 8.668750338256359, 0.13187400181777775, 0.23159046279033646, 2.8633470414206386, 4.25108696334064, 5.060081128031015, 36.763452887535095, 54.78060029447079, 58.102214857935905, 45.756061747670174, 43.94588068127632, 49.77417513728142, 54.46017488837242, 51.40485383570194, 45.49252308905125, 37.93143421411514, 44.43457245826721, 53.496679589152336, 48.30990470945835, 47.695967853069305, 45.19943721592426, 47.9876895993948, 48.26437935233116, 47.70214632153511, 48.069229423999786, 46.337924525141716, 47.660405561327934, 45.30775040388107, 46.64014510810375, 45.176938623189926, 45.3936979919672, 49.12211872637272, 50.45014746487141, 46.344783157110214, 45.205304101109505, 37.54501394927502, 36.285822317004204, 38.42433616518974, 37.54530653357506, 37.231580168008804, 37.442248463630676, 37.62031450867653, 37.0611023157835, 38.36708463728428, 36.96201503276825, 38.28266076743603, 38.959841430187225, 38.85050609707832, 36.676946729421616, 39.23741653561592, 38.273636251688, 39.236348792910576, 42.49818496406078, 45.25620996952057, 46.22282110154629, 47.35416479408741, 43.66483636200428, 39.52093072235584, 41.633305773139, 42.53472380340099, 42.87346042692661, 40.55477924644947, 47.40201562643051, 53.698684349656105, 53.5145728290081, 53.198741376399994, 47.81862527132034, 59.559995234012604, 44.921653121709824, 43.67878161370754, 50.73650389909744, 47.84608639776707, 52.53421023488045, 49.969104677438736, 50.52589260041714, 49.686852023005486, 45.91993175446987, 41.86470955610275, 37.382530868053436, 37.89111837744713, 37.80051223933697, 38.37053865194321, 36.50093637406826, 38.604636490345, 38.62219914793968, 38.80335062742233, 39.11713019013405, 38.270851001143456, 38.64695481956005, 38.898983895778656, 38.189626559615135, 38.22760932147503, 38.93464498221874, 37.25697420537472, 37.09242783486843, 36.91847696900368, 37.02596940100193, 39.66994732618332, 47.55876861512661, 50.823819413781166, 47.80679650604725, 46.03801041841507, 50.116639360785484, 44.63419854640961, 46.8889519572258, 46.91989749670029, 50.858823135495186, 52.338771522045135, 52.59883716702461, 46.135205402970314, 41.27311550080776, 39.923477321863174, 41.23680844902992, 42.672648802399635, 43.36529463529587, 43.97545449435711, 43.15252125263214, 43.892615139484406, 42.41700991988182, 43.54743406176567, 49.04622919857502, 56.34371481835842, 57.26048022508621, 58.96218851208687, 63.17545562982559, 48.51186007261276, 14.23908518627286, 2.2924640122801065, 3.5243571968749166, 0.5965872248634696, 0.2230734276236035, 0.6117192597594112, 36.45512603223324, 69.32006031274796, 52.875397726893425, 51.78098805248737, 29.82529118657112, 37.1261852234602, 53.120742961764336, 59.1407485306263, 28.23304932564497, 0.5579410423524678, 0.06410329500795342, 0.046844951357343234, 0.016241452904068865, 0.09744828697876073, 0.027795144851552323, 0.02290609489136841, 0.03538917466357816, 0.05349370767362416, 0.04367080800875556, 0.06989836256252602, 0.013960536234662868, 0.13097266346449032, 0.11071298184106126, 0.09134798892773688, 0.11633481728495099, 0.16638747561955824, 0.12671637232415378, 0.35624085925519466, 0.20623210788471624, 0.16377177613321692, 0.18088393524521962, 0.17203786148456857, 0.1162089267745614, 0.272972394595854, 0.15588519541779533, 13.558369763195515, 58.47554862499237, 58.865628093481064, 48.97594057023525, 34.87124942243099, 43.308609277009964, 56.52659520506859, 54.10336263477802, 63.149776607751846, 10.172361955046654, 0.12791706336429343, 1.0191442631185055, 7.877338780090213, 5.708081731572747, 3.3467863127589226, 37.712793946266174, 55.05575492978096, 59.16627176105976, 45.6860239058733, 46.50877095758915, 51.3636564463377, 57.788594886660576, 54.790529161691666, 45.94411365687847, 39.29078847169876, 47.740189880132675, 56.39752373099327, 49.12526495754719, 48.931532353162766, 45.68372882902622, 49.171713665127754, 50.77183060348034, 50.82052119076252, 50.28868652880192, 48.485649079084396, 49.58674639463425, 45.500377267599106, 48.881538435816765, 44.843415319919586, 47.26432241499424, 50.72875991463661, 54.43167641758919, 49.6392709761858, 47.37325116991997, 39.06574174761772, 39.011883437633514, 40.32053701579571, 40.57173773646355, 38.45083214342594, 39.494126960635185, 37.98294425010681, 38.77192631363869, 40.94676621258259, 37.93535180389881, 38.099791780114174, 41.52532696723938, 41.74494758248329, 38.035761415958405, 41.55316427350044, 40.99533520638943, 39.88909676671028, 45.14053277671337, 48.450884744524956, 49.89020951092243, 48.744730576872826, 46.94096356630325, 41.986504420638084, 42.3606513440609, 43.60782042145729, 45.08871115744114, 41.95852652192116, 50.113937705755234, 56.86150923371315, 56.95214197039604, 55.0930081307888, 51.99371583759785, 56.73540540039539, 47.11615316569805, 49.160994440317154, 50.493434742093086, 51.17987930774689, 53.04771088063717, 51.49118900299072, 53.76432962715626, 52.83355437219143, 48.79426471889019, 43.57291929423809, 39.95593897998333, 40.793455839157104, 40.4042237251997, 39.04843367636204, 37.4757132679224, 41.675346717238426, 41.2751217931509, 39.70881924033165, 41.23503774404526, 39.61557984352112, 41.62608616054058, 41.43705390393734, 40.28276324272156, 40.22627167403698, 40.68414330482483, 39.128009006381035, 38.886155784130096, 40.274966061115265, 39.85807903110981, 40.36044627428055, 49.591796323657036, 53.417727425694466, 51.11766144633293, 48.16573664546013, 51.27713888883591, 45.98171643912792, 47.21083268523216, 48.36429499089718, 50.49626179039478, 53.47123235464096, 54.71127301454544, 49.339634254574776, 44.16953667998314, 42.78202973306179, 43.17323014140129, 44.13041017949581, 45.084170401096344, 46.37037478387356, 45.17943888902664, 47.03471213579178, 45.87753742933273, 45.27606390416622, 49.796863719820976, 57.927667424082756, 61.476988568902016, 61.86381161212921, 66.2013928592205, 52.23572105169296, 15.523611009120941, 4.078570995479822, 5.511209070682526, 1.078497909475118, 0.5105523602105677, 0.7626935897860676, 39.10301014780998, 74.05751690268517, 58.265332505106926, 59.811891317367554, 39.65099014341831, 51.99078619480133, 61.18748590350151, 68.33862617611885, 36.353242099285126, 1.3551969244144857, 0.14093057834543288, 0.27406741864979267, 0.1861221916624345, 0.16253798530669883, 0.11741351409000345, 0.24645930243423209, 0.11875791460624896, 0.1680467842379585, 0.16402170178480446, 0.22308628162136301, 0.1060333993518725], [0.06180011019750964, 0.026937932743749116, 0.061611170531250536, 0.06011638120980933, 0.02479384398611728, 0.10220767260761932, 0.041518308862578124, 0.040823833041940816, 0.03346001743921079, 0.0729247739946004, 0.024101193848764524, 0.11169942226842977, 0.025974771633627824, 0.06505368190119043, 5.971365328878164, 44.90967236459255, 49.21200290322304, 45.853853300213814, 26.05787504464388, 21.359896436333656, 39.37998868525028, 45.60006871819496, 50.6351937353611, 12.084283512085676, 0.20313803484896198, 0.13755362830124795, 5.156643921509385, 3.0150619754567742, 1.075741513632238, 11.809091828763485, 41.40660613775253, 54.39622052013874, 50.9957791864872, 49.43966768682003, 49.03648652136326, 49.135904386639595, 39.471043199300766, 34.72155265510082, 39.80896666646004, 51.58253610134125, 49.59445998072624, 46.26127503812313, 47.413844391703606, 48.190644308924675, 48.395609110593796, 51.61875955760479, 48.61266486346722, 50.16160994768143, 48.369857892394066, 47.86054462194443, 41.563207134604454, 47.565144672989845, 45.13837829232216, 48.49823780357838, 49.783477038145065, 46.13568417727947, 44.684447050094604, 35.16631878912449, 34.712319150567055, 36.87518209218979, 35.77389858663082, 35.1570700854063, 34.88417252898216, 35.80491252243519, 36.692723482847214, 36.24101132154465, 35.57715654373169, 37.58768565952778, 39.20334756374359, 37.48052380979061, 34.442028254270554, 35.41758790612221, 36.62716940045357, 38.30036781728268, 37.891277968883514, 45.64050234854221, 46.98977954685688, 51.13434635102749, 52.95300476253033, 57.42246173322201, 46.792022958397865, 40.85590548813343, 36.88618630170822, 39.122305512428284, 39.931418895721436, 50.51991552114487, 50.249598026275635, 50.34447133541107, 43.17239038646221, 51.15229658782482, 45.885779187083244, 40.55191420018673, 51.60792633891106, 47.03755058348179, 51.08999893069267, 48.03329475224018, 48.98907646536827, 46.53724282979965, 45.05819119513035, 40.72075434029102, 36.66280768811703, 34.666425213217735, 36.884825974702835, 36.44714266061783, 36.41723446547985, 36.38223834335804, 36.391528844833374, 37.198806926608086, 38.42156991362572, 36.32304511964321, 36.252209320664406, 35.75131639838219, 37.66818434000015, 35.909965485334396, 36.15158312022686, 37.99739867448807, 36.78258866071701, 36.8551229685545, 36.33502967655659, 35.38930982351303, 36.7162062227726, 44.750802889466286, 47.581882774829865, 50.033496022224426, 47.91935786604881, 49.800807908177376, 49.25472021102905, 51.038139313459396, 50.207055509090424, 48.36924232542515, 47.08912521600723, 49.725131168961525, 50.43778672814369, 46.65717959403992, 42.83131308853626, 41.566338166594505, 41.94580480456352, 38.288018479943275, 37.518415376544, 40.727719366550446, 41.35151669383049, 41.11616112291813, 40.382618084549904, 41.152395978569984, 47.25628204643726, 52.181133180856705, 54.357371404767036, 56.82159997522831, 46.651818081736565, 8.045157250016928, 1.093812631443143, 1.9513787585310638, 0.1689899351913482, 0.18230949703138322, 0.31321793503593653, 32.801751270890236, 61.552672907710075, 46.092047318816185, 50.208780616521835, 33.3205222338438, 36.54531039297581, 52.44131661951542, 56.34625308215618, 22.599722407758236, 0.06086857756599784, 0.04061731931869872, 0.023278957305592485, 0.03316889517009258, 0.07259282618178986, 0.05735566977818962, 0.04254497369402088, 0.009823738291743211, 0.07005111881881021, 0.027726431253540795, 0.04442879682756029, 0.04192600397800561, 0.06233000734937377, 0.013197591724747326, 0.01909862312459154, 0.04154957554419525, 0.027549646110855974, 0.04985453088011127, 0.01912299525429262, 0.037557385076070204, 0.022845726743980777, 0.03744310175534338, 0.08348873408976942, 0.04988475484424271, 0.10303511531674303, 0.030083930141699966, 7.658086745068431, 48.446879759430885, 56.09323985874653, 49.72525276243687, 29.020363278687, 31.55709955841303, 49.62532952427864, 49.63572196662426, 57.68858805298805, 11.937010064721107, 0.1824452803703025, 0.10977173078572378, 8.01122697070241, 5.64423518255353, 3.0712697468698025, 15.062123872339725, 43.32917757332325, 54.72661279141903, 50.36476604640484, 51.64538852870464, 51.09369233250618, 51.118641793727875, 42.509838938713074, 36.42942801117897, 41.66631460189819, 53.68746355175972, 51.51540130376816, 47.61695109307766, 48.152072578668594, 49.44775365293026, 50.94304941594601, 53.7114554643631, 48.82047951221466, 51.071349531412125, 49.59741622209549, 46.680947318673134, 43.28872114419937, 47.65938341617584, 45.8351469039917, 48.54632042348385, 50.16914874315262, 48.53632315993309, 47.877522110939026, 37.94281840324402, 36.192096546292305, 37.74824604392052, 36.90054193139076, 38.782497346401215, 35.595916137099266, 37.56997101008892, 38.106927797198296, 37.109196335077286, 38.16667579114437, 38.500400483608246, 40.380748584866524, 38.94312992691994, 35.986953154206276, 37.72880248725414, 37.271147444844246, 39.814727157354355, 40.031045749783516, 45.96587888896465, 49.064456820487976, 53.39823067188263, 54.04925733804703, 55.39758458733559, 48.46940495073795, 43.333247154951096, 38.41462008655071, 39.79181058704853, 42.84537613391876, 52.22909800708294, 50.7640790194273, 51.933378875255585, 45.3412152081728, 52.14327961206436, 49.02419798076153, 42.362004071474075, 52.959221228957176, 49.88318748772144, 52.10289157927036, 49.095687344670296, 49.68242526054382, 47.670079842209816, 47.6867039501667, 43.75168450176716, 38.27110558748245, 36.88471578061581, 37.867293655872345, 37.728487104177475, 37.75327317416668, 37.3421086370945, 37.76176191866398, 38.65413263440132, 39.33386296033859, 39.0473697334528, 37.06254243850708, 37.65694074332714, 39.38980735838413, 38.78612235188484, 38.03085967898369, 40.008835941553116, 36.8384874612093, 37.17702269554138, 37.9631283134222, 37.73920252919197, 39.78476956486702, 47.30874203145504, 49.56187292933464, 53.585492223501205, 50.43481528759003, 50.15212945640087, 50.733118280768394, 52.57118605077267, 50.444417372345924, 48.72970998287201, 47.50307120382786, 51.90293870866299, 53.315657302737236, 48.7628024071455, 43.34447555243969, 44.010017439723015, 42.36601285636425, 38.571513667702675, 38.45010258257389, 42.73766331374645, 42.281619384884834, 43.659832030534744, 43.11114527285099, 43.742857575416565, 49.98661793768406, 55.08926913142204, 57.14515641331673, 58.07515271008015, 47.691335901618004, 9.486873038113117, 2.8780536772683263, 4.196654409170151, 0.0781484397884924, 0.1767362203099765, 0.48753809358458966, 36.14228121936321, 66.55534386634827, 54.48892414569855, 57.55222097039223, 41.17250829935074, 43.57905216515064, 57.3195518553257, 64.10620048642159, 29.37728952616453, 0.21449624880915508, 0.03367390811035875, 0.04454761467059143, 0.017207896162290126, 0.02096206502756104, 0.051881235995097086, 0.033434517245041206, 0.012553383421618491, 0.05218843318289146, 0.014864316253806464, 0.05990533667500131, 0.04649883965612389, 0.2209315448999405, 0.14107010210864246, 0.17681846511550248, 0.19828124233754352, 0.14758425881154835, 0.21967464359477162, 0.10454030954861082, 0.1919326587812975, 0.08375207034987397, 0.1621396152768284, 0.1453052123542875, 0.10089019720908254, 0.17741258401656523, 0.2699116291478276, 9.090468809008598, 57.36245535314083, 60.62790893018246, 57.41166651248932, 35.63171401619911, 33.31383839249611, 50.917115807533264, 57.204786613583565, 61.365339159965515, 15.348940081894398, 0.45666100981179625, 0.3023511712672189, 11.544641219079494, 6.546175684779882, 3.373467531055212, 15.43574072420597, 43.21524068713188, 54.65386189520359, 54.47281301021576, 53.86251635849476, 53.98056082427502, 53.89451824128628, 42.95629218220711, 38.50377470254898, 43.806975334882736, 54.58320468664169, 53.56332801282406, 48.67177069187164, 51.063305363059044, 51.10131472349167, 52.36443534493446, 56.265898793935776, 51.31651237607002, 52.7960579842329, 50.94888590276241, 47.707150653004646, 43.33034411072731, 50.17371229827404, 47.86519177258015, 51.114165633916855, 52.3045239597559, 51.10866352915764, 49.83405612409115, 39.35347370803356, 38.230041190981865, 39.74114790558815, 38.0221239477396, 40.16573712229729, 38.221199065446854, 37.853074818849564, 39.565034955739975, 40.72453893721104, 40.70249632000923, 40.794956758618355, 42.74072974920273, 40.83789825439453, 38.185845762491226, 39.68713380396366, 40.07195435464382, 41.311903819441795, 43.04436385631561, 50.05048871040344, 52.62521915137768, 56.17420591413975, 56.714362129569054, 57.33304113149643, 51.40625216066837, 45.614545941352844, 40.69817595183849, 42.35810928046703, 44.70324844121933, 53.89759987592697, 53.631344363093376, 52.25739508867264, 46.75230748951435, 51.027032509446144, 48.881299048662186, 47.26170055568218, 53.548516407608986, 52.38130263984203, 55.26261202991009, 51.074780747294426, 52.29410871863365, 50.195264741778374, 47.95269347727299, 46.586647778749466, 39.31047521531582, 40.339323207736015, 40.466483384370804, 38.51422034204006, 40.31633444130421, 39.907305389642715, 39.50465239584446, 41.40450865030289, 41.615800112485886, 40.27284577488899, 39.87901970744133, 40.77738270163536, 41.04475535452366, 39.368783086538315, 40.51791362464428, 42.61208385229111, 38.86192448437214, 39.730193093419075, 40.741242840886116, 39.259371757507324, 41.666265204548836, 48.085598945617676, 53.15813675522804, 56.22801102697849, 52.064031064510345, 52.4317829310894, 54.31367754936218, 54.49049726128578, 52.13906183838844, 50.031238943338394, 48.99103716015816, 53.57612192630768, 54.659443795681, 51.162350848317146, 47.70113557577133, 46.70403108000755, 45.893086194992065, 41.06429010629654, 40.960878655314445, 44.15873385965824, 45.701439678668976, 46.521568670868874, 47.06170208752155, 44.96522158384323, 52.390847727656364, 56.792877316474915, 60.046175345778465, 58.517167791724205, 52.606231570243835, 9.296413958072662, 4.207140421494842, 7.702162954956293, 2.765650483779609, 0.43516648351214826, 0.3805278497748077, 39.11832332611084, 72.01383456587791, 59.83787812292576, 61.20113097131252, 47.04767324030399, 48.29311341047287, 67.28305041790009, 70.92984393239021, 35.79019971191883, 0.44770581065677106, 0.08621272034361027, 0.20671971375122666, 0.11182056303368881, 0.12748743407428265, 0.1388612628215924, 0.11905506311450154, 0.1154244173085317, 0.18176620040321723, 0.11720555688953027, 0.25168480875436217, 0.16280170006211847], [0.01997494367969921, 0.04390868118207436, 0.09631056716898456, 0.05497744270542171, 0.014927379324944923, 0.05385242846386973, 0.01734841996949399, 0.04483218377572484, 0.01127009969422943, 0.061817650857847184, 0.08054847116000019, 0.050898406116175465, 0.13483965361956507, 0.02679554614587687, 3.7210493674501777, 41.361912935972214, 50.7247207313776, 42.766674757003784, 25.156533010303974, 18.988865464925766, 33.24209824204445, 44.42596212029457, 53.85631889104843, 21.40154030174017, 0.03786586246860679, 0.06874729151604697, 1.4794299518689513, 4.919480122625828, 2.1234300825744867, 2.929562763310969, 32.53833420574665, 55.23537129163742, 51.45623467862606, 50.77481344342232, 46.33150666952133, 41.39700025320053, 36.02284602820873, 41.93565554916859, 49.24994766712189, 49.88580174744129, 46.75676845014095, 50.301632434129715, 49.120082035660744, 50.40715277194977, 46.53907053172588, 47.124345526099205, 46.89633496105671, 48.1164874881506, 47.84553922712803, 51.648956537246704, 46.8083430826664, 45.64502030611038, 47.70597271621227, 51.33468680083752, 44.99449901282787, 44.40438687801361, 39.30533789098263, 35.21627090871334, 34.89464856684208, 35.16287997364998, 35.99054776132107, 35.56795343756676, 36.12948730587959, 35.54857447743416, 36.9918130338192, 36.94672465324402, 36.01536802947521, 37.75583043694496, 37.53989562392235, 38.12447525560856, 36.03589452803135, 36.036456897854805, 34.49233375489712, 37.724208533763885, 36.873696371912956, 43.814932107925415, 48.65371786057949, 51.66925884783268, 46.72892354428768, 52.057582810521126, 58.55408661067486, 50.74565760791302, 45.86618363857269, 41.14167295396328, 39.94507156312466, 49.66876119375229, 50.1456356048584, 52.71314263343811, 49.02801297605038, 45.74191130697727, 43.38574893772602, 43.58969919383526, 49.47489559650421, 51.32096193730831, 50.015462189912796, 47.33632855117321, 45.36571629345417, 44.60857652127743, 43.487712666392326, 41.29690982401371, 34.770775213837624, 34.326126873493195, 35.862422436475754, 36.92370928823948, 36.80076688528061, 36.34285345673561, 36.50572411715984, 36.83306895196438, 37.30778507888317, 36.68014995753765, 36.331632658839226, 36.83305375277996, 37.296879664063454, 37.5485135614872, 36.02198347449303, 36.91694565117359, 35.31520240008831, 36.93442091345787, 36.56313143670559, 36.48686192929745, 34.22723338007927, 40.33898502588272, 46.76996514201164, 47.98748821020126, 49.29491065442562, 49.346287697553635, 48.16760994493961, 48.126192167401314, 50.81129148602486, 50.48612393438816, 51.273939460515976, 51.27870440483093, 50.78296020627022, 51.11619472503662, 48.434025049209595, 48.62313710153103, 47.70065300166607, 44.6353080868721, 35.0967863202095, 37.392049357295036, 36.68941766023636, 41.278572008013725, 41.77048221230507, 43.95264811813831, 44.12051171064377, 54.96353767812252, 52.895996421575546, 60.94990365207195, 41.160405948758125, 5.9620425291359425, 1.897390780504793, 1.422682253178209, 0.31456143013201654, 0.08471364140859805, 0.4299480572808534, 29.496686719357967, 60.06323643028736, 47.423404678702354, 40.157700553536415, 22.321191653609276, 31.863138936460018, 48.54105770587921, 51.74442641437054, 15.316450875252485, 0.08119922335026786, 0.0585749219317222, 0.041735086488188244, 0.06788587328628637, 0.04229512967867777, 0.04794016094820108, 0.09341744545963593, 0.039154995247372426, 0.05819660844281316, 0.025709568872116506, 0.04464550765987951, 0.05568751847022213, 0.03761152474908158, 0.05443798298074398, 0.028959429837414064, 0.10520626834477298, 0.02414345359284198, 0.0628025624610018, 0.12356079008895904, 0.03797941106313374, 0.01804812236514408, 0.05529543814191129, 0.05469029834785033, 0.02601932646939531, 0.13038709410466254, 0.03840588622551877, 5.648955954238772, 47.92753882706165, 57.52096384763718, 46.52060352265835, 27.75928884744644, 18.16022302955389, 40.165151953697205, 51.70631065964699, 59.11736078560352, 22.18989159911871, 0.03455531979852822, 0.0678761066228617, 3.052048715762794, 6.757478546351194, 3.5442241933196783, 4.056500354781747, 36.074367463588715, 54.78256098926067, 55.230469554662704, 52.59252950549126, 49.475112184882164, 44.01046961545944, 37.14997574687004, 43.37798975408077, 51.61112956702709, 52.29774512350559, 46.744688898324966, 50.85447236895561, 51.194462925195694, 50.50692021846771, 49.003914669156075, 50.33337593078613, 48.637181147933006, 49.58908326923847, 49.69752185046673, 51.6424360871315, 48.92908528447151, 46.82314708828926, 48.9621739089489, 52.02012822031975, 48.41846488416195, 46.918043196201324, 41.69252559542656, 36.82732746005058, 36.09910033643246, 38.15116502344608, 37.765257731080055, 37.570172399282455, 36.61226660013199, 36.868395656347275, 39.40112695097923, 38.89098532497883, 37.95461297035217, 38.290720134973526, 39.305121302604675, 38.890080973505974, 37.25630924105644, 37.76303485035896, 38.50109204649925, 38.468018621206284, 39.09612111747265, 46.974758952856064, 50.08834607899189, 53.583732917904854, 50.87656818330288, 53.40010777115822, 58.23614627122879, 52.37256310880184, 47.8865884244442, 42.44195558130741, 42.90926970541477, 50.89196115732193, 52.3552892357111, 54.46500822901726, 48.44534084200859, 49.22377087175846, 44.91612821817398, 46.86590239405632, 48.665280640125275, 50.69250226020813, 52.14750498533249, 50.76232351362705, 48.49554754793644, 45.55106654763222, 46.11184045672417, 44.257942736148834, 36.676148772239685, 37.43961900472641, 36.765022203326225, 39.41091902554035, 37.920904979109764, 38.475891798734665, 37.9063555598259, 38.699695989489555, 38.91148902475834, 37.88638763129711, 37.10624389350414, 37.39662431180477, 39.2487171292305, 39.17505048215389, 37.86323167383671, 39.348416179418564, 36.22880257666111, 39.17661979794502, 38.32649901509285, 38.79279859364033, 36.25166974961758, 42.78845898807049, 48.285563215613365, 49.84603688120842, 51.64657026529312, 53.35401624441147, 51.69875666499138, 49.83608141541481, 52.068978399038315, 51.34168602526188, 51.286106407642365, 50.760533809661865, 52.11812876164913, 53.53597328066826, 50.11927641928196, 50.21877408027649, 49.74873170256615, 46.44529536366463, 37.680750265717506, 39.86515425145626, 39.98878441751003, 44.1633316129446, 44.05451685190201, 44.52785365283489, 47.377313151955605, 55.610008388757706, 55.668586045503616, 61.44915506243706, 45.52966609597206, 5.867638969793916, 2.955094068311155, 6.009575603529811, 1.0931036132387817, 0.14973785262554884, 0.3905207198113203, 32.53415822982788, 65.14374241232872, 53.626807406544685, 46.563149839639664, 27.269160747528076, 37.890696600079536, 54.90063965320587, 61.305123791098595, 19.446043632924557, 0.11633291738689877, 0.04276982588635292, 0.04753390188852791, 0.10570108046522364, 0.015720717565272935, 0.032482876122230664, 0.0266533636386157, 0.05693424493074417, 0.0023552919265057426, 0.029878796813136432, 0.05357995265512727, 0.035004901728825644, 0.13311990449437872, 0.16780610574642196, 0.23972829018021002, 0.21072662842925638, 0.1350700607872568, 0.16395517566706985, 0.18532180023612455, 0.15178094065049663, 0.0792179636482615, 0.17233098013093695, 0.155451706959866, 0.16557284980081022, 0.2545704273506999, 0.09669982362538576, 6.014916691929102, 54.481719732284546, 63.48339110612869, 55.1610054820776, 34.98848453164101, 26.591049134731293, 45.91147720813751, 55.340625643730164, 63.542785719037056, 26.218954101204872, 0.300794561044313, 0.24104984739096835, 3.1740345200523734, 12.639151588082314, 5.428471360355616, 4.209748981520534, 37.29692526161671, 55.569156780838966, 56.24623104929924, 56.175634637475014, 50.69124452769756, 45.060607865452766, 40.83869241178036, 46.43751718103886, 53.83620657026768, 53.82701486349106, 47.378403693437576, 51.399727910757065, 52.77404956519604, 53.24781954288483, 51.15833826363087, 52.17536889016628, 49.68858852982521, 53.119439631700516, 51.243693083524704, 53.11375893652439, 49.07636918127537, 48.47471326589584, 51.08458802103996, 52.358021289110184, 50.41222929954529, 48.94295834004879, 42.5531680136919, 38.7227987498045, 38.435188382864, 40.05256399512291, 41.0727446526289, 39.89545002579689, 38.84392485022545, 39.765831381082535, 41.36607751250267, 40.58578558266163, 39.331909865140915, 40.62033712863922, 40.2536416053772, 40.82365281879902, 39.976902455091476, 41.026915311813354, 38.33555392920971, 42.019775435328484, 41.11367605626583, 48.69344852864742, 51.32262624800205, 54.24034908413887, 52.10319556295872, 55.46770602464676, 57.713476717472076, 54.38745819032192, 50.13110138475895, 45.05759842693806, 44.878597632050514, 52.8581390529871, 53.70949096977711, 54.54533591866493, 52.95408010482788, 49.2918936163187, 47.26327747106552, 47.87895083427429, 52.2511026263237, 53.64546060562134, 54.605843871831894, 53.2356183975935, 50.62064811587334, 49.35611017048359, 48.7645199149847, 47.72574305534363, 37.48943813145161, 38.67739878594875, 38.32147188484669, 40.81714756786823, 39.87626485526562, 40.54351665079594, 40.299885123968124, 39.69361625611782, 40.782755613327026, 39.18219789862633, 38.19040171802044, 40.032124891877174, 40.59057332575321, 40.12079693377018, 39.03247073292732, 42.46250867843628, 37.76938430964947, 41.1241102963686, 40.91154210269451, 39.600646644830704, 38.20719301700592, 44.07548412680626, 50.23442544043064, 52.78076760470867, 53.453513905406, 54.82772536575794, 54.22658622264862, 51.93052522838116, 56.25666528940201, 53.98188315331936, 53.22707265615463, 52.976301312446594, 56.315668523311615, 56.85585133731365, 53.040882647037506, 52.77603305876255, 51.64349623024464, 48.35974283516407, 40.42641073465347, 42.21931032836437, 41.65346369147301, 46.86943240463734, 46.51304192841053, 49.15546953678131, 49.29667375981808, 58.92963565886021, 59.73979018628597, 64.22824993729591, 47.929032146930695, 8.389296233654022, 6.668989844620228, 10.002312529832125, 2.1879121474921703, 0.2718603308312595, 0.50352000631392, 35.98411850631237, 70.27870327234268, 61.1634635925293, 52.55428455770016, 33.06251607835293, 46.6103471070528, 63.70562978088856, 69.40145194530487, 25.592172034084797, 0.36310762516222894, 0.17891206371132284, 0.28763696551322937, 0.16823423589812592, 0.1849292783299461, 0.2316203564987518, 0.16942499700235203, 0.24444423790555447, 0.08966441208031029, 0.1376598296337761, 0.12991444993531331, 0.14818596246186644], [0.02726364094996825, 0.023466470192943234, 0.016682761743140873, 0.021459732561197598, 0.0833397924725432, 0.024287181622639764, 0.10816681417054497, 0.006444525160986814, 0.01045957980750245, 0.05542109858652111, 0.035017173140659, 0.05462270353746135, 0.07447590716765262, 0.04134857968892902, 0.7077581563498825, 28.614554554224014, 51.28795690834522, 46.53372421860695, 32.954723462462425, 31.589371226727962, 37.88015216588974, 42.835964038968086, 47.758668288588524, 31.35757226496935, 1.0738542024046183, 0.04847236989007797, 5.1389943435788155, 6.48065485060215, 0.836871131323278, 2.2908244002610445, 26.438916698098183, 56.43001198768616, 47.920250818133354, 47.24967420101166, 39.16729509830475, 37.24308595061302, 42.20721557736397, 47.87063308060169, 50.35004183650017, 49.80713076889515, 50.4340211302042, 51.202575489878654, 46.510876044631004, 46.70693792402744, 45.71615248918533, 46.25572353601456, 45.629897117614746, 48.29233445227146, 47.38289885222912, 47.921580746769905, 48.592563942074776, 48.75809445977211, 52.06828683614731, 46.94389320909977, 43.89905199408531, 40.13417601585388, 33.80843125283718, 35.31672231853008, 36.939296051859856, 35.78697368502617, 36.33768193423748, 35.051519349217415, 35.46528674662113, 36.95732228457928, 37.053020149469376, 36.11513167619705, 35.88521361351013, 37.21774511039257, 36.84694200754166, 36.91155754029751, 36.883283257484436, 36.15091435611248, 34.57358479499817, 37.13783539831638, 38.50838765501976, 40.713698118925095, 45.640855729579926, 51.2911981344223, 50.37471391260624, 42.489954605698586, 52.10760332643986, 50.41323244571686, 49.93573106825352, 44.879087805747986, 41.0890381783247, 44.003329798579216, 49.20393593609333, 52.812978476285934, 50.56381456553936, 43.568773716688156, 44.46271754801273, 44.63602624833584, 50.77399268746376, 47.14383848011494, 49.73683074116707, 46.660762801766396, 44.00810994207859, 43.71093928813934, 40.34747377038002, 35.24906314909458, 36.26395829021931, 33.33982139825821, 34.901754185557365, 36.57218635082245, 35.314237251877785, 35.298965871334076, 36.1811189353466, 37.663616985082626, 37.758524492383, 37.02000752091408, 36.89589098095894, 36.16332828998566, 38.76325137913227, 35.58372639119625, 35.942514538764954, 37.65395030379295, 36.82602033019066, 36.316281482577324, 35.93163952231407, 34.86998029053211, 35.739848613739014, 35.88584437966347, 40.77819965779781, 45.94474822282791, 46.256631687283516, 47.18297258019447, 46.53052859008312, 45.58298483490944, 44.05198998749256, 45.734418109059334, 47.26962313055992, 50.65051071345806, 51.93667709827423, 50.14622837305069, 51.04863815009594, 52.09581635892391, 55.91523841023445, 51.63086570799351, 44.20990951359272, 39.71721678972244, 39.39459130167961, 38.87596853077412, 38.91366630792618, 44.00063954293728, 47.108481377363205, 52.14867912232876, 53.04296873509884, 60.63146933913231, 42.81067259609699, 3.161663571372628, 3.272786708548665, 2.9400578001514077, 0.363754837308079, 0.1446216052863747, 0.3883141960250214, 30.949610956013203, 60.3090376406908, 46.57943196594715, 46.69622629880905, 33.71545024216175, 37.551545798778534, 45.49345403909683, 52.161727622151375, 13.122027777135372, 0.0830381984997075, 0.050621529371710494, 0.05683238145138603, 0.035985093272756785, 0.056355492197326384, 0.04397524811793119, 0.023993038812477607, 0.01709233820292866, 0.14791712688747793, 0.022917711357877124, 0.04448431689525023, 0.05901421398448292, 0.03856241630273871, 0.08536476467270404, 0.04112101494683884, 0.004972856986569241, 0.017702084878692403, 0.045271616836544126, 0.024549369409214705, 0.054392656311392784, 0.016085368115454912, 0.0719978241249919, 0.07333807603572495, 0.0474566851335112, 0.021366819382819813, 0.09382517397170886, 1.270511937327683, 35.44547840952873, 57.06655763089657, 52.9510972648859, 35.046708807349205, 26.8604888767004, 40.433675944805145, 46.516355350613594, 53.89948457479477, 34.192184060812, 0.7550374756101519, 0.04712531990662683, 3.9377320278435946, 6.581858145073056, 3.2413213094696403, 3.2203830080106854, 28.901281468570232, 58.167453557252884, 50.37379056215286, 48.769091069698334, 42.93722100555897, 37.76458136737347, 43.50946269929409, 48.34488183259964, 53.49594242870808, 49.171535074710846, 51.56226418912411, 53.04812505841255, 47.95753441751003, 49.21099215745926, 48.54363776743412, 48.47221300005913, 47.784282714128494, 49.168670028448105, 49.24866333603859, 49.802985191345215, 48.39897193014622, 50.44163592159748, 53.198304399847984, 48.955406472086906, 46.78856514394283, 43.19189473986626, 37.859276086091995, 36.250913590192795, 38.372826129198074, 38.19000653922558, 38.335508331656456, 37.09270142018795, 36.69601410627365, 38.69744271039963, 39.99667279422283, 37.09880389273167, 38.18744547665119, 39.38552498817444, 38.49247790873051, 38.765622451901436, 37.9169075936079, 36.050478145480156, 37.56464749574661, 38.001065477728844, 39.85543817281723, 42.877689599990845, 47.73757942020893, 52.558243945240974, 50.86108021438122, 46.63079760968685, 53.92628833651543, 52.300765961408615, 52.467185631394386, 47.75949664413929, 41.64580710232258, 45.63300535082817, 50.50283923745155, 55.655070170760155, 53.284331783652306, 46.12732082605362, 45.452321246266365, 47.272294387221336, 51.94010831415653, 49.293755516409874, 50.62216803431511, 49.1077820956707, 46.66689187288284, 44.1202799230814, 42.48703256249428, 37.962022572755814, 38.00842948257923, 35.31079463660717, 36.717737540602684, 38.556352481245995, 37.135126143693924, 36.427433118224144, 37.595133259892464, 38.69302734732628, 38.87653850018978, 39.21365641057491, 38.24478060007095, 38.87040562927723, 40.712387189269066, 37.29250989854336, 37.68933780491352, 38.77806678414345, 38.560828641057014, 38.88150483369827, 38.75165060162544, 36.32447384297848, 37.512229308485985, 38.90251770615578, 43.63546013832092, 48.00236441195011, 48.66884484887123, 49.18047979474068, 47.54913233220577, 47.6236767321825, 45.97939856350422, 48.7820103764534, 49.901806488633156, 53.29190857708454, 52.13315315544605, 51.096792966127396, 52.95334294438362, 54.11621354520321, 56.748845279216766, 54.60560828447342, 46.06655828654766, 40.185423865914345, 42.032565549016, 41.63932844996452, 41.18778347969055, 45.402524918317795, 48.78897160291672, 53.612786158919334, 57.47384637594223, 61.23569771647453, 47.221494913101196, 2.5969046261161566, 4.305446846410632, 6.512272953987122, 0.48920480883680284, 0.18775733595248312, 0.4543829133035615, 33.422121182084084, 64.74151879549026, 52.17593885958195, 44.718576818704605, 33.12254525721073, 42.84449078142643, 50.60437738895416, 60.24518586695194, 18.05422581732273, 0.03863607817038428, 0.04836363783397246, 0.035466424815240316, 0.0540220537368441, 0.055290269083343446, 0.026647517370292917, 0.03107922624622006, 0.09624746977351606, 0.06659717095317319, 0.015455113116331631, 0.06409351350157522, 0.07998296947334893, 0.19585531001212075, 0.0997959153028205, 0.136096584610641, 0.1328661196748726, 0.23150441818870604, 0.15041858016047627, 0.24560504592955112, 0.15370546316262335, 0.13788142008706927, 0.12831901054596528, 0.11875216296175495, 0.11723927265848033, 0.14233648806111887, 0.21217381639871746, 1.7464822344481945, 42.07671158015728, 67.05922722816467, 60.29467061161995, 43.918829932808876, 41.6303875297308, 51.30727507174015, 53.499955013394356, 58.537010326981544, 39.36124429106712, 1.2390312203206122, 0.15167291363468394, 11.191087290644646, 14.45731982588768, 4.6070699114352465, 4.387634061276913, 31.177480928599834, 61.056256145238876, 53.09515133500099, 51.62524960935116, 44.90956597030163, 41.57693199813366, 47.2871819883585, 50.7295236736536, 54.83009643852711, 51.61193132400513, 53.375743478536606, 56.13162159919739, 51.54465973377228, 51.73406817018986, 51.64472356438637, 50.28432056307793, 51.51448555290699, 50.65635100007057, 51.47679157555103, 51.46900959312916, 51.67829476296902, 53.19854758679867, 56.22560575604439, 53.68055932223797, 48.3307009935379, 43.990646079182625, 38.14535893499851, 38.200113996863365, 41.02528139948845, 40.103428065776825, 40.181050300598145, 38.91637936234474, 39.29571680724621, 41.164308339357376, 41.76491171121597, 40.7822198420763, 39.80468429625034, 40.45789584517479, 39.470914006233215, 41.1421213299036, 39.87737059593201, 39.58651140332222, 38.11643488705158, 39.73374590277672, 43.325263783335686, 44.667135179042816, 50.50787016749382, 55.497922003269196, 53.05059492588043, 48.595349192619324, 55.650696605443954, 52.816546484827995, 55.67552827298641, 48.35644841194153, 45.191917419433594, 47.21565082669258, 53.864047676324844, 56.86006151139736, 55.205919072031975, 47.74711690843105, 49.187972992658615, 48.37970316410065, 53.651418685913086, 52.194751650094986, 54.34554263949394, 51.73605926334858, 48.45412217080593, 47.14343570172787, 44.4741777330637, 40.0931192189455, 40.304722264409065, 36.19455121457577, 37.95509934425354, 39.68719840049744, 38.39408218860626, 39.044675678014755, 39.435644298791885, 41.3148258626461, 41.40110023319721, 41.99468918144703, 39.91772823035717, 39.863083362579346, 43.40694800019264, 38.46775263547897, 40.5038695782423, 42.02018201351166, 39.61097829043865, 40.535772666335106, 41.28749392926693, 37.959647700190544, 39.80199784040451, 41.156564354896545, 46.1061255633831, 50.055078864097595, 50.41632167994976, 53.25395241379738, 51.5445951372385, 51.18715971708298, 49.22682970762253, 51.66737034916878, 51.370667070150375, 56.71656221151352, 54.542448073625565, 52.862630411982536, 54.085074216127396, 56.40068896114826, 60.36357991397381, 55.78607574105263, 49.67481806874275, 43.80592659115791, 43.94252926111221, 42.484817281365395, 42.383054941892624, 49.422462210059166, 51.8922308832407, 56.31168253719807, 58.94914761185646, 64.04652088880539, 49.25151318311691, 4.018948869779706, 6.939683994278312, 11.247537061572075, 1.9986146176233888, 0.3372103226138279, 0.572123306337744, 36.01185321807861, 72.4277463555336, 59.55666281282902, 58.75718951225281, 47.91186086833477, 51.65541619062424, 58.5765890032053, 68.57428953051567, 24.9129755795002, 0.19947549153584987, 0.09546053348458372, 0.10949965202598833, 0.15603157662553713, 0.08830196253256872, 0.11703475160175003, 0.12557388050481677, 0.16631599195534363, 0.2089641019119881, 0.19427352614002302, 0.14137629739707336, 0.18560875905677676], [0.05907394202949945, 0.048421837054775096, 0.06819194240961224, 0.03305373240436893, 0.015374494541902095, 0.021559428969339933, 0.05892767585464753, 0.021493272070074454, 0.05723798742110375, 0.0724513060413301, 0.046979046310298145, 0.012674428635364166, 0.0500801586167654, 0.09418739398824982, 0.06447218693210743, 20.99096093326807, 53.380922600626945, 44.913859739899635, 27.95407399535179, 18.734102435410023, 30.565077289938927, 44.418548718094826, 47.65824347734451, 42.22103923559189, 3.00187383312732, 0.11565331049496308, 0.9493078698869795, 3.6353879515081644, 4.910646071657538, 2.190388427115977, 33.0615471303463, 52.83628262579441, 50.37840351462364, 43.70456323027611, 40.12202426791191, 44.99414183199406, 49.0270022302866, 52.28121221065521, 50.51629051566124, 51.12997278571129, 53.11277858912945, 48.11386562883854, 47.355061545968056, 45.219830721616745, 45.90764321386814, 43.64096224308014, 47.51526854932308, 43.01089145243168, 46.21435895562172, 48.0422318726778, 49.34996969997883, 47.71853104233742, 46.13385647535324, 42.49199889600277, 40.782102048397064, 35.672269240021706, 35.12260973453522, 34.209461733698845, 35.309590101242065, 35.892934799194336, 36.50710344314575, 35.473574101924896, 34.81862224638462, 35.73116607964039, 35.80909609794617, 36.671148240566254, 36.50852456688881, 35.304152593016624, 38.8917338848114, 35.59119679033756, 36.92951537668705, 35.472578555345535, 36.12504154443741, 38.45605306327343, 38.40341828763485, 37.14108042418957, 42.71585628390312, 48.15699711441994, 51.463845670223236, 48.69750291109085, 39.56023961305618, 48.413616344332695, 52.8341319411993, 50.53433954715729, 44.37927782535553, 40.397471487522125, 44.8166723549366, 51.609735041856766, 52.0332907140255, 42.29258939623833, 47.04513117671013, 47.95056939125061, 52.010590732097626, 49.76279474794865, 49.59392420947552, 45.945154801011086, 44.75226581096649, 42.95245818793774, 40.45552097260952, 35.34674070775509, 35.97924716770649, 34.19772036373615, 36.67443506419659, 36.62819914519787, 37.003094628453255, 35.435268357396126, 36.34280785918236, 37.26835839450359, 38.39518032968044, 36.121180951595306, 35.3653559088707, 36.51651173830032, 37.51928552985191, 35.70858009159565, 35.54797410964966, 35.793068557977676, 36.3033127784729, 35.21150976419449, 36.14017613232136, 35.61979025602341, 37.375524044036865, 36.58675476908684, 33.89601655304432, 36.261230036616325, 37.9278814047575, 39.6087060123682, 40.02064190804958, 40.80558858811855, 43.01483944058418, 44.5185973495245, 47.23854459822178, 46.651286110281944, 49.15796980261803, 51.739220693707466, 51.39196112751961, 46.57808303833008, 50.26504419744015, 54.39122758805752, 48.75410847365856, 45.59934675693512, 47.12385915219784, 46.4009365439415, 42.28555217385292, 39.21062417328358, 47.063563987612724, 52.7188765257597, 53.530645966529846, 58.86511892080307, 39.93350878357887, 0.8220944367349148, 2.6587603194639087, 4.883728791028261, 0.5990381527226418, 0.10382035208749585, 0.45369648607447743, 34.91264820098877, 59.2381639033556, 41.65289372205734, 40.77607177197933, 28.123145923018456, 35.6349628418684, 42.41719990968704, 45.49632288515568, 9.437111858278513, 0.08073963355855085, 0.020046889330842532, 0.021576713588729035, 0.014443729105551029, 0.08898168816813268, 0.025745288439793512, 0.015277894744940568, 0.09909029613481835, 0.016712751930754166, 0.04900969965092372, 0.05946196281001903, 0.0744294561445713, 0.03933941152354237, 0.06531339648063295, 0.03385894036910031, 0.04366567976830993, 0.10915063481661491, 0.050809756576200016, 0.03932547399017494, 0.033312986852251925, 0.020304537029005587, 0.03601838972826954, 0.10440472658956423, 0.050791061876225285, 0.008689447204233147, 0.1176805462455377, 0.08247121251770295, 26.95973765105009, 58.466968685388565, 50.401396080851555, 32.933182418346405, 21.366059705615044, 38.604750484228134, 50.176090970635414, 52.71766059100628, 44.80138577520847, 2.471314240247011, 0.14110737276496366, 1.1215359438210726, 3.7938776845112443, 4.020642153918743, 3.518824693746865, 33.87613222002983, 57.94907167553902, 52.77509070932865, 44.8447148501873, 41.246946305036545, 47.4982188642025, 51.253633350133896, 56.49713538587093, 51.797247380018234, 53.050211146473885, 54.5534560829401, 49.44729007780552, 50.12723699212074, 47.51349024474621, 46.109788566827774, 45.33060997724533, 48.75841364264488, 45.813260078430176, 48.89582946896553, 50.28774797916412, 53.19484278559685, 49.59618888795376, 48.76255542039871, 45.89516468346119, 43.905150666832924, 37.219215631484985, 36.03845179080963, 37.05479845404625, 36.798885986208916, 36.54868461191654, 37.64593653380871, 36.84966266155243, 36.882827281951904, 37.976009622216225, 38.55971910059452, 38.41964341700077, 37.37390153110027, 38.31065386533737, 40.254667550325394, 38.75773787498474, 38.41582462191582, 36.262867748737335, 38.4026925265789, 39.05528470873833, 40.50648383796215, 38.17112535238266, 45.23098312318325, 49.36560586094856, 55.28880022466183, 48.83846394717693, 41.06611780822277, 50.46366713941097, 53.38442601263523, 52.846876457333565, 46.76157519221306, 42.909212708473206, 47.07970172166824, 51.69763572514057, 53.969146236777306, 45.526462867856026, 48.41307297348976, 49.54779468476772, 52.20117710530758, 50.70000685751438, 51.90261572599411, 49.44591835141182, 47.44405657052994, 45.32589063048363, 42.46288105845451, 38.870778009295464, 37.57491834461689, 37.479558661580086, 37.42041863501072, 37.87766329944134, 38.27539935708046, 37.43262737989426, 38.16739395260811, 40.021466463804245, 39.65282924473286, 38.83474074304104, 38.45381498336792, 39.17619042098522, 38.36702384054661, 37.01310709118843, 37.969166189432144, 36.735892966389656, 38.96177552640438, 37.59447209537029, 40.13767562806606, 37.553441897034645, 39.171151891350746, 38.47923941910267, 36.9505662471056, 36.23348772525787, 41.420190408825874, 42.910911217331886, 43.527002558112144, 44.56231780350208, 44.77803982794285, 47.207705453038216, 49.652224481105804, 49.64488707482815, 53.17553222179413, 53.52533385157585, 52.48670898377895, 48.86498652398586, 52.68350802361965, 57.15154767036438, 49.93699640035629, 47.171645388007164, 48.5604252666235, 46.5458607673645, 42.899633422493935, 42.13805168867111, 48.04496392607689, 54.95311103761196, 56.72555632889271, 61.59507103264332, 42.24453717470169, 1.0662837023846805, 3.3086786326020956, 7.131881006062031, 1.3497519353404641, 0.08439856261247769, 0.5422678927425295, 36.96186684072018, 64.46940019726753, 47.28918448090553, 50.971851870417595, 33.748082891106606, 39.175962433218956, 49.63321790099144, 54.99765604734421, 14.194308388978243, 0.07272187081980519, 0.056914808083092794, 0.009710772283142433, 0.041800350954872556, 0.06472997192759067, 0.01416094022715697, 0.016837998628034256, 0.07472539495211095, 0.035471849914756604, 0.029436983313644305, 0.025255346663470846, 0.06648960406892002, 0.17089709144784138, 0.10579143694485538, 0.14215742266969755, 0.1061648188624531, 0.14947712130378932, 0.13626589818159118, 0.08989021793240681, 0.07742774017970078, 0.18293447443284094, 0.20201424515107647, 0.2111445169430226, 0.16229606000706553, 0.10141609789570794, 0.22894145571626723, 0.18953731778310612, 30.134624987840652, 67.58440464735031, 58.24971914291382, 39.44461941719055, 28.69611717760563, 43.71096968650818, 55.03327913582325, 58.44648018479347, 52.77155689895153, 2.925316491164267, 0.3275229799328372, 3.3644995372742414, 12.80320493504405, 10.859594978392124, 4.128390597179532, 38.15876081585884, 58.148313984274864, 55.811747163534164, 47.204327434301376, 45.54571643471718, 49.587593749165535, 53.376522436738014, 56.33302219212055, 53.53221908211708, 54.629512801766396, 58.06974560022354, 51.749141961336136, 52.740193381905556, 50.192418694496155, 49.74755756556988, 46.60424083471298, 51.39009542763233, 47.81469628214836, 51.04369081556797, 53.08693617582321, 53.219074085354805, 50.95078960061073, 53.50951910018921, 46.74867868423462, 46.81525871157646, 40.30224859714508, 38.66224139928818, 38.82700055837631, 38.56483742594719, 38.90724465250969, 40.18891967833042, 38.950493931770325, 39.677231535315514, 40.20607575774193, 41.09185382723808, 40.67846640944481, 39.9435668438673, 39.105191230773926, 42.79478944838047, 40.13545274734497, 41.16028435528278, 39.15787920355797, 41.18287034332752, 41.78241737186909, 42.99107551574707, 41.620918437838554, 47.43257358670235, 52.06438824534416, 57.18759633600712, 49.66273471713066, 43.47698584198952, 52.8451931476593, 54.71259154379368, 54.9879589676857, 48.02354447543621, 45.75239114463329, 47.39925317466259, 54.77636732161045, 55.27838498353958, 47.486390098929405, 50.95341145992279, 51.246018558740616, 55.46220771968365, 54.01361145079136, 53.625067099928856, 50.65103128552437, 49.58517327904701, 48.64346981048584, 44.959016516804695, 39.83023792505264, 40.06255365908146, 38.661363646388054, 40.164019614458084, 39.623107239603996, 40.612536147236824, 38.968295976519585, 40.107706636190414, 41.790374144911766, 42.05784559249878, 41.40116482973099, 40.149793177843094, 39.413461089134216, 41.20249629020691, 39.10494044423103, 39.1355250030756, 38.22127886116505, 41.74460560083389, 38.37469942867756, 41.790655329823494, 39.99540366232395, 41.43767327070236, 41.0519065707922, 38.115545734763145, 38.85192722082138, 43.117528930306435, 43.9192783087492, 45.138154104352, 45.730063542723656, 47.47021056711674, 49.01068590581417, 52.48200483620167, 51.40107303857803, 55.46875476837158, 55.333276838064194, 54.39824961125851, 49.17382255196571, 53.61151322722435, 59.0140101313591, 53.51046144962311, 50.275109857320786, 52.83203065395355, 50.283727794885635, 47.44425415992737, 42.88058124482632, 51.95391297340393, 58.78173619508743, 59.60147000849247, 63.08925345540047, 43.22159394621849, 1.864186618477106, 6.083242250606418, 11.958314571529627, 3.0517884297296405, 0.3540127241285518, 0.565909689757973, 41.20928272604942, 70.07152318954468, 54.83950853347778, 55.711778327822685, 42.71929129958153, 50.76957732439041, 59.573245123028755, 64.0581026673317, 20.4678563028574, 0.1917033054633066, 0.1680511629092507, 0.16673536476446316, 0.10277207591570914, 0.20786747481906787, 0.08854885280015878, 0.06046756920113694, 0.23175608046585694, 0.18192950257798657, 0.13893372612074018, 0.15826066170120612, 0.2547702728770673], [0.044061314983991906, 0.05170168078620918, 0.03194462609826587, 0.040329399416805245, 0.07633108340087347, 0.03290036758698989, 0.05388028497691266, 0.05344302269804757, 0.037007880382589065, 0.0320384150109021, 0.07707228112849407, 0.014118321469140938, 0.02733798373810714, 0.07713774597505108, 0.07401958282571286, 10.642402432858944, 49.17787313461304, 47.615712359547615, 34.118452817201614, 22.16763999313116, 25.424827113747597, 38.98675158619881, 46.944626569747925, 45.321498066186905, 6.6843395959585905, 0.10221357268164866, 0.6398505752440542, 1.9516025902703404, 3.3520008204504848, 3.8055131351575255, 28.08339435607195, 52.4049411714077, 49.34271588921547, 45.11306785047054, 46.63398563861847, 50.664919540286064, 49.98024567961693, 42.69914098083973, 51.6871976852417, 48.8065342605114, 49.21958349645138, 45.97977474331856, 44.45538014173508, 41.615712717175484, 42.16798648238182, 42.38854564726353, 43.94662544131279, 43.64490643143654, 46.85587093234062, 45.45987904071808, 46.73409886658192, 43.955805748701096, 40.85092015564442, 36.84052795171738, 35.34130699932575, 34.60920788347721, 37.193627804517746, 34.87688452005386, 35.957231149077415, 37.070658802986145, 36.95779725909233, 35.21822780370712, 35.5119938403368, 35.491520538926125, 36.62506051361561, 34.959328696131706, 34.43759769201279, 35.33707782626152, 35.55981047451496, 37.40169703960419, 36.7425312101841, 35.03377050161362, 34.235117956995964, 37.17812843620777, 36.22216813266277, 34.24879342317581, 37.162568271160126, 46.5710724145174, 48.3514478802681, 57.415994480252266, 39.84139032661915, 37.81581401824951, 48.31022769212723, 51.27993933856487, 45.98625339567661, 41.23340763151646, 45.00747911632061, 51.24203637242317, 51.494346633553505, 42.31414183974266, 45.01961186528206, 48.53560119867325, 51.128931641578674, 49.758238792419434, 46.08713798224926, 43.039040341973305, 40.189565643668175, 39.88140217959881, 39.23261359333992, 34.96797323226929, 34.71576176583767, 34.52125400304794, 36.77542604506016, 37.63242445886135, 37.47317120432854, 37.863186076283455, 37.583042308688164, 38.44677396118641, 38.10801833868027, 35.03782868385315, 37.36155219376087, 36.85878977179527, 37.10631988942623, 35.26774674654007, 37.01765164732933, 37.42264151573181, 34.9917371571064, 35.27927152812481, 37.71843284368515, 35.515504851937294, 37.0226863771677, 37.265177965164185, 37.50848650932312, 35.44507563114166, 34.24487963318825, 34.91699896752834, 35.72186417877674, 36.8601007014513, 38.298015743494034, 38.94634835422039, 44.87588457763195, 46.994962468743324, 46.44529536366463, 48.26057955622673, 53.29549938440323, 47.648854181170464, 43.15177649259567, 56.84633284807205, 52.33104653656483, 51.06347635388374, 49.466555044054985, 53.49881127476692, 48.52735184133053, 43.29702749848366, 45.21422602236271, 52.83232323825359, 53.594212755560875, 59.98759388923645, 35.115507915616035, 0.12237221089890227, 3.1333178048953414, 3.217616993933916, 0.3486382984556258, 0.15879037702688947, 0.37525156571064144, 34.82208766043186, 58.54327619075775, 45.16704395413399, 30.737814120948315, 29.2306686937809, 37.27903202176094, 48.436099737882614, 47.94109269976616, 5.709386011585593, 0.028588283639692236, 0.041767173242988065, 0.017691904467938002, 0.08122819679556414, 0.05659625974658411, 0.039362993265967816, 0.04348485548689496, 0.01222207107275608, 0.049234076868742704, 0.014944224221835611, 0.03255875701142941, 0.02481056457327213, 0.02043931290245382, 0.048086044916999526, 0.032187560718739405, 0.04091685012099333, 0.04345394132542424, 0.06068673283152748, 0.06919574909261428, 0.06532153784064576, 0.05430370249086991, 0.04552634047286119, 0.03684364310174715, 0.05163918081962038, 0.08499384668539278, 0.05272172566037625, 0.06760505202692002, 14.66974837705493, 55.94662092626095, 54.23630990087986, 37.47600205242634, 26.05702769011259, 34.05140541493893, 48.24883818626404, 51.81015148758888, 50.20853742957115, 7.1800685953348875, 0.2065871810191311, 0.14993756456533447, 3.513215482234955, 3.4558404609560966, 4.216911122202873, 30.971661172807217, 54.6958914399147, 52.88889080286026, 46.90206125378609, 48.2524061948061, 52.452073842287064, 51.82138368487358, 45.32147906720638, 52.46978469192982, 51.66923604905605, 51.54538929462433, 47.97795072197914, 47.49927140772343, 45.2249376475811, 44.951177537441254, 45.000229105353355, 45.737746730446815, 46.7873378098011, 50.62949784100056, 47.694261744618416, 48.0962535738945, 46.433056220412254, 43.188501521945, 39.00632053613663, 37.297267243266106, 35.62430061399937, 37.878176271915436, 35.89978963136673, 37.64897257089615, 37.757540345191956, 37.59554363787174, 37.013984844088554, 38.258767649531364, 36.5579105168581, 39.57158200442791, 37.055121436715126, 36.291518211364746, 39.20531965792179, 37.15077370405197, 37.95618608593941, 37.75959603488445, 36.47634029388428, 36.53428338468075, 38.43325808644295, 37.1462519466877, 35.635559409856796, 39.46979686617851, 48.42795677483082, 50.89181296527386, 55.751353204250336, 42.27996647357941, 40.63719682395458, 51.02277673780918, 52.56457440555096, 48.31949919462204, 42.99887649714947, 47.85430155694485, 52.54629738628864, 52.14110992848873, 44.612938687205315, 46.11389994621277, 51.15218639373779, 51.820186749100685, 49.111095517873764, 47.62426570057869, 43.739426359534264, 43.2637032866478, 42.59825639426708, 40.973303988575935, 37.58187957108021, 37.992515936493874, 36.375356912612915, 38.73392075300217, 38.509421199560165, 39.28797662258148, 39.8128804564476, 39.96430233120918, 39.626492857933044, 39.027037024497986, 37.647433653473854, 38.350350335240364, 39.401085153222084, 38.980687111616135, 37.991546988487244, 37.80164837837219, 39.95615176856518, 36.55871607363224, 38.99629287421703, 39.36039313673973, 36.65475592017174, 39.72693666815758, 39.28302928805351, 40.19103616476059, 37.38044857978821, 37.18227781355381, 36.206239387393, 37.37283378839493, 39.1200066357851, 40.09859852492809, 42.691017016768456, 45.816603899002075, 48.29151749610901, 49.24979567527771, 50.63852235674858, 55.458252131938934, 47.89630450308323, 44.90450084209442, 58.95540967583656, 53.7216617166996, 53.53459395468235, 51.76003597676754, 55.430992394685745, 51.03232942521572, 45.64269483089447, 46.6189194470644, 55.004111900925636, 55.93894533813, 63.32508400082588, 35.328634679317474, 0.1751383615192026, 5.471668867394328, 8.381219767034054, 2.013871273957193, 0.089466659410391, 0.3348479775013402, 37.4077121168375, 65.47573819756508, 51.17784641683102, 40.266990289092064, 34.72756393253803, 46.34007140994072, 54.63514029979706, 56.587638929486275, 9.302222896367311, 0.12100552368792705, 0.04938100726576522, 0.029641363362316042, 0.07172675468609668, 0.02048388443654403, 0.023130253175622784, 0.024453201913274825, 0.029859855349059217, 0.022192252727109008, 0.049230703807552345, 0.08271099301055074, 0.005004122276659473, 0.14321030757855624, 0.11486824441817589, 0.09598908363841474, 0.12117054022382945, 0.19270542747108266, 0.21941079525277019, 0.1709090400254354, 0.1613327968516387, 0.18141531298169866, 0.16279749950626865, 0.2847166737774387, 0.13415620982414111, 0.1340228458866477, 0.19328014663187787, 0.14122399385087192, 16.45193539559841, 63.140695095062256, 60.838470831513405, 45.90559132397175, 34.47510167956352, 34.895948097109795, 51.223508566617966, 54.21397089958191, 58.336141705513, 8.425516840070486, 0.21946152846794575, 2.0910135470330715, 5.620351089164615, 9.377671647816896, 5.944634713232517, 31.25396892428398, 58.33879016339779, 55.550237596035004, 49.80533726513386, 52.022347301244736, 54.64600391685963, 52.71547190845013, 44.349510222673416, 54.975735023617744, 52.67275460064411, 52.81461238861084, 49.17913466691971, 48.761039301753044, 47.58350148797035, 47.15688318014145, 45.48102870583534, 48.25013391673565, 48.51596385240555, 52.601565420627594, 49.88315708935261, 50.92938534915447, 48.85317675769329, 45.25117143988609, 40.14960318803787, 38.62290970981121, 38.124190270900726, 41.217824667692184, 37.53328397870064, 39.867867305874825, 40.62520086765289, 40.438786670565605, 38.64557169377804, 39.564366191625595, 38.901332169771194, 41.5943768620491, 39.84887592494488, 38.0138897895813, 39.754568785429, 38.679431676864624, 40.754808112978935, 39.326206371188164, 38.55088837444782, 36.35947376489639, 40.02739414572716, 39.43894252181053, 38.08330826461315, 41.41680099070072, 51.52187615633011, 53.302878588438034, 56.79811343550682, 45.72801925241947, 42.42138348519802, 52.784920781850815, 55.17587788403034, 50.452890917658806, 45.1266673207283, 48.92884969711304, 54.7814666479826, 53.76507818698883, 45.731442868709564, 48.06215040385723, 53.66568312048912, 53.98325867950916, 51.69996500015259, 52.0438427478075, 46.12403780221939, 44.438330456614494, 45.296810790896416, 43.88509154319763, 37.95447237789631, 40.004762560129166, 37.94619642198086, 40.82899533212185, 41.56598478555679, 40.98063759505749, 42.015496864914894, 41.41777753829956, 42.79314033687115, 41.26559190452099, 39.58844929933548, 40.984802171587944, 41.02113962173462, 41.77433140575886, 40.01732848584652, 41.000392735004425, 42.5238411873579, 38.19859027862549, 40.44557310640812, 42.20939666032791, 38.55230189859867, 41.943346336483955, 42.138329073786736, 42.47455783188343, 38.60150545835495, 37.94384814798832, 38.802469074726105, 39.219625890254974, 41.29906430840492, 43.32423783838749, 43.0236853659153, 49.57176759839058, 52.01369136571884, 52.16478645801544, 51.87377907335758, 57.67178915441036, 48.37075084447861, 45.28177499771118, 60.056962966918945, 56.78434677422047, 56.13713890314102, 53.40381637215614, 57.74567998945713, 53.477452620863914, 48.967315033078194, 50.12225925922394, 56.154420375823975, 58.08064341545105, 64.05000150203705, 39.11206126213074, 0.4737277643289417, 9.50715159997344, 11.76234483718872, 2.8115762444213033, 0.3510213049594313, 0.4485621303319931, 41.01622648537159, 71.38269603252411, 57.03634925186634, 45.71301005780697, 40.85125453770161, 53.4178414195776, 62.084693759679794, 66.2149429321289, 13.808772526681423, 0.20031776977702975, 0.10675807687221095, 0.1728890900267288, 0.1779416314093396, 0.15721317962743342, 0.14573311986168846, 0.0993596734770108, 0.08128221772494726, 0.1213286844722461, 0.1438237668480724, 0.23860493092797697, 0.08230888255639002], [0.011686156958603533, 0.07737612380879, 0.030845624132780358, 0.052370949561009184, 0.03751568008738104, 0.09391623549163342, 0.06561599977430888, 0.013262927623145515, 0.027200931326660793, 0.04155438466113992, 0.09848649220657535, 0.12114221986848861, 0.0287885855868808, 0.10702584375394508, 0.015456077908311272, 7.600650927051902, 42.60955698788166, 47.70397402346134, 35.82958459854126, 16.11757043749094, 28.13215333968401, 45.20351059734821, 43.379175290465355, 51.98522709310055, 10.67057317122817, 0.1436844954150729, 0.23300517437746748, 1.3477450492791831, 1.01938602514565, 2.2833877243101597, 24.315241053700447, 49.687364995479584, 52.16872304677963, 50.34270063042641, 51.067063361406326, 51.56993217766285, 50.71989119052887, 51.53903603553772, 52.22833424806595, 49.267453327775, 47.18919284641743, 44.69007454812527, 41.463907063007355, 39.6451460570097, 40.69200128316879, 42.37602151930332, 45.230679139494896, 44.286034628748894, 43.9922533929348, 41.15237317979336, 40.09931668639183, 37.230679616332054, 35.29481269419193, 35.22525742650032, 35.80761797726154, 34.8551344871521, 35.98848067224026, 34.71223175525665, 36.282546892762184, 35.03876343369484, 38.19966182112694, 35.993914380669594, 34.03667360544205, 35.159266367554665, 36.68339118361473, 35.50111882388592, 35.168955847620964, 35.5546959489584, 39.034583419561386, 37.26575553417206, 36.727351024746895, 36.29864662885666, 36.545059606432915, 36.199050173163414, 39.9722059071064, 34.668431505560875, 36.98302410542965, 45.25992996990681, 53.26833464205265, 46.07278615236282, 42.41876922547817, 51.671056151390076, 53.278054520487785, 53.42121183872223, 48.252497389912605, 45.81636071205139, 45.12729048728943, 52.17621624469757, 52.205976247787476, 40.852204486727715, 45.62542475759983, 48.26966866850853, 48.45296323299408, 49.76702392101288, 46.147683933377266, 42.256707921624184, 39.55650441348553, 40.89572735130787, 36.3920684158802, 34.21160861849785, 35.32149866223335, 34.748987182974815, 36.578288823366165, 37.825146317481995, 37.18592941761017, 35.86091011762619, 36.235083639621735, 37.6837445050478, 36.150154396891594, 35.947575867176056, 35.22536002099514, 35.78727766871452, 36.69930852949619, 35.605073645710945, 37.35039599239826, 37.67608031630516, 36.20139464735985, 35.243390053510666, 34.67720523476601, 35.6921573728323, 36.33553884923458, 37.67706446349621, 36.24158129096031, 36.98646292090416, 34.877477288246155, 37.070563808083534, 36.740205734968185, 36.231105253100395, 35.844707787036896, 36.95604555308819, 37.9423738270998, 43.20530042052269, 45.04773035645485, 47.05064468085766, 47.32640728354454, 57.27803148329258, 48.509975373744965, 51.623927280306816, 50.71579121053219, 52.797209322452545, 49.28184315562248, 54.19500231742859, 52.74622365832329, 44.106068685650826, 43.5107584297657, 55.703004598617554, 54.430756866931915, 62.00007610023022, 25.524685755372047, 0.20097433298360556, 3.143446398898959, 7.62111852876842, 1.110109956935048, 0.03489095237455331, 1.2228237837553024, 35.54931163787842, 59.80810672044754, 46.16950996220112, 39.31247390806675, 23.715789020061493, 31.83000661432743, 48.46172176301479, 41.48493513464928, 4.418761990964413, 0.09659725139499642, 0.0689408733160235, 0.004658293519241852, 0.026071237844007555, 0.04196932684862986, 0.04515591230301652, 0.035720105734071694, 0.02531862959585851, 0.011056992916564923, 0.04272927122656256, 0.016342527851520572, 0.10828327940544114, 0.02418314736132743, 0.07183124907896854, 0.015846782480366528, 0.03012357195984805, 0.03542918755556457, 0.11912285830476321, 0.027165608807990793, 0.011791083652497036, 0.037510462789214216, 0.038158335446496494, 0.10530447674682364, 0.0073479591537761735, 0.05591927263594698, 0.09189257689286023, 0.023001702065812424, 8.775685150176287, 51.451291143894196, 54.147295877337456, 42.31127679347992, 20.764014311134815, 28.974704928696156, 49.55915227532387, 51.845105811953545, 56.32163040339947, 11.6023563221097, 0.08263113049906678, 0.29026491043623537, 2.313228235580027, 2.6310030464082956, 3.325469931587577, 25.62601301819086, 51.765921860933304, 53.770595490932465, 51.612607687711716, 51.85480289161205, 53.68958003818989, 50.770789459347725, 50.30111946165562, 55.505168214440346, 49.570255279541016, 49.76818285882473, 46.760465651750565, 44.445200487971306, 41.27988673746586, 42.33011618256569, 44.33921277523041, 46.27996623516083, 46.25334106385708, 45.60791529715061, 43.83074305951595, 43.774293288588524, 39.468941912055016, 37.993716672062874, 37.28606544435024, 37.04746104776859, 36.275163888931274, 37.38302864134312, 35.81695407629013, 38.211277797818184, 36.80381812155247, 41.53069227933884, 38.23698341846466, 36.78256966173649, 37.54266947507858, 37.062717229127884, 38.26333500444889, 38.01773898303509, 39.05280724167824, 38.766333013772964, 38.11864256858826, 38.32510069012642, 38.211536183953285, 37.73989789187908, 37.45511457324028, 40.69659523665905, 37.24487945437431, 37.513901218771935, 45.72602055966854, 58.075468093156815, 48.07743698358536, 43.51689890027046, 54.00649443268776, 54.687395095825195, 54.72312077879906, 50.53729198873043, 46.02139391005039, 48.031524047255516, 53.04946258664131, 54.19293902814388, 44.81525503098965, 45.26001736521721, 49.685411900281906, 50.55039368569851, 51.97674594819546, 47.006574645638466, 45.4364874958992, 42.79244877398014, 41.8982807546854, 38.4074080735445, 37.602664455771446, 36.215317100286484, 37.00430676341057, 38.59404265880585, 39.072372391819954, 39.472361728549004, 38.16660359501839, 38.2136944681406, 38.97298872470856, 38.63573022186756, 37.965495586395264, 37.128001525998116, 37.499135211110115, 39.346736669540405, 37.63555929064751, 38.18385846912861, 38.42579148709774, 37.81590901315212, 37.8404974937439, 37.44431555271149, 37.85957247018814, 39.03405524790287, 38.66487465798855, 39.971062168478966, 38.16956743597984, 37.766466066241264, 38.7353228777647, 37.828277349472046, 37.41612486541271, 37.11981676518917, 39.13617856800556, 39.46204148232937, 45.519695430994034, 48.945158421993256, 49.11586806178093, 51.38941906392574, 57.419338300824165, 50.33286675810814, 52.03724630177021, 54.66323979198933, 54.87201198935509, 52.45749235153198, 55.907935202121735, 53.99714693427086, 47.73018501698971, 45.33618427813053, 56.27637483179569, 57.033051028847694, 64.31344136595726, 27.791532017290592, 0.3669450926827267, 5.5346861109137535, 5.965724056586623, 1.5240320772863925, 0.06444106125854887, 1.056409457232803, 38.53092044591904, 65.11426359415054, 52.568997368216515, 44.683614894747734, 28.541672565042973, 36.71529047191143, 55.46958312392235, 49.23758313059807, 5.5732345674186945, 0.06097358404076658, 0.05295149087032769, 0.02193453452491667, 0.045214764613774605, 0.04218901369313244, 0.03947570323362015, 0.03594349960621912, 0.025935812591342255, 0.010148556848434964, 0.05390522856032476, 0.0049288782429357525, 0.0627593620447442, 0.07848714114516042, 0.2302093111211434, 0.08223943237680942, 0.1399786997353658, 0.20665438991272822, 0.20381191978231072, 0.17121156910434365, 0.08655784127768129, 0.11111691797850654, 0.14374428283190355, 0.15008632064564154, 0.2464575509657152, 0.11321485813823529, 0.2925780660007149, 0.13608485867734998, 10.125105790793896, 57.30608157813549, 60.972774624824524, 47.25190468132496, 25.124648921191692, 37.72092550992966, 57.4358294159174, 54.846644550561905, 62.62522995471954, 13.12285803258419, 0.28477726271376014, 0.7834012911189348, 6.500730598345399, 6.242227144539356, 3.74321595299989, 28.146668560802937, 52.5460883975029, 55.318898409605026, 54.82295282185078, 54.5452219247818, 54.35397058725357, 52.58380137383938, 54.829146489501, 55.43079100549221, 53.021226301789284, 51.42667606472969, 48.5688342154026, 45.06858743727207, 44.992348328232765, 44.928086176514626, 46.25680647790432, 49.231115877628326, 48.494548201560974, 48.32165747880936, 45.70790693163872, 44.906184151768684, 41.12131364643574, 39.814677760005, 39.42500486969948, 39.96650241315365, 38.210711628198624, 40.2687381953001, 38.12045507133007, 39.619014859199524, 38.66026170551777, 44.38105992972851, 40.262248143553734, 38.65191735327244, 39.75023701786995, 39.441321194171906, 41.21082164347172, 39.94670167565346, 40.98144695162773, 43.59337739646435, 41.71260751783848, 40.446675047278404, 39.859488755464554, 39.33125250041485, 38.821943029761314, 42.488848865032196, 37.761948108673096, 40.444592759013176, 48.42297904193401, 57.1807225048542, 49.61506627500057, 45.91754928231239, 51.96799501776695, 54.638628512620926, 58.68064261972904, 52.462812066078186, 49.37462277710438, 50.77922120690346, 55.56656911969185, 55.71690805256367, 46.33270360529423, 48.8265135884285, 50.35483717918396, 52.603659108281136, 55.16111567616463, 50.26863880455494, 47.29717545211315, 44.403148144483566, 44.09090369939804, 40.77275075018406, 38.750358670949936, 39.606958106160164, 38.747125044465065, 40.57030901312828, 40.752209052443504, 41.814905628561974, 39.77348417043686, 41.03088229894638, 41.240908429026604, 40.735007375478745, 40.4117701202631, 40.221130549907684, 39.673040360212326, 41.25384673476219, 41.006635800004005, 41.36085659265518, 41.57529428601265, 40.5137300491333, 39.94364283978939, 38.821145072579384, 40.08667856454849, 40.926878079771996, 40.77597297728062, 41.119561940431595, 41.34816527366638, 39.21823516488075, 40.88150091469288, 40.67256532609463, 40.413001254200935, 39.368372708559036, 40.362897142767906, 42.04931505024433, 47.79184430837631, 52.425577864050865, 51.72692835330963, 53.64418767392635, 59.94071580469608, 50.69311022758484, 53.71663078665733, 55.221509635448456, 59.32330973446369, 54.31170925498009, 60.43481849133968, 57.8387787938118, 50.111623629927635, 48.31132963299751, 59.87766958773136, 58.98093670606613, 66.06944873929024, 29.136509746313095, 0.6123720528557897, 7.79652614146471, 16.423068344593048, 3.4282033564522862, 0.11308984336210415, 1.2883583921939135, 41.92736059427261, 71.30397945642471, 58.626244738698006, 52.2895185649395, 35.17946608364582, 45.65679207444191, 62.91359268128872, 56.21856093406677, 9.429582562297583, 0.22677606175420806, 0.15405112586449832, 0.21516001084819436, 0.11871343027451076, 0.16097126703243703, 0.054810040164738894, 0.13394557347055525, 0.0977606866217684, 0.14495292969513685, 0.16842772864038125, 0.1317337655927986, 0.20831757254200056], [0.015138114940782543, 0.04485336467041634, 0.022691764497722033, 0.06681685408693738, 0.04368025554867927, 0.028676576948782895, 0.01088242586774868, 0.05376253953727428, 0.05732595789595507, 0.04884128778940067, 0.06586335759493522, 0.03492657175229397, 0.01239773650013376, 0.07545405038399622, 0.011295257572783157, 3.5597432730719447, 37.455752938985825, 52.00009949505329, 42.142307460308075, 32.17614904046059, 29.863085858523846, 40.45350328087807, 43.052769005298615, 51.06439970433712, 18.57791181653738, 0.03351288061821833, 0.14792938716709614, 1.7008135537616909, 2.330570030026138, 1.1200581793673337, 11.868657432496548, 37.384278774261475, 55.306188091635704, 51.075962483882904, 53.288370966911316, 50.28751999139786, 55.020891800522804, 50.76646149158478, 49.31916855275631, 46.8122910708189, 47.619629949331284, 42.47027926146984, 39.37324024736881, 39.172660410404205, 39.90915589034557, 39.12080079317093, 40.742014199495316, 39.499347880482674, 39.55952525138855, 36.107022911310196, 36.82953514158726, 33.94810035824776, 36.30058452486992, 34.19278062880039, 35.5973144620657, 35.155348777770996, 33.9793498814106, 34.899892285466194, 32.75548495352268, 33.61600957810879, 33.8880255818367, 34.41774755716324, 35.77165670692921, 33.42750169336796, 34.83040161430836, 35.21646089851856, 35.92081770300865, 36.30778893828392, 37.42373585700989, 36.330173537135124, 37.87765569984913, 34.995179772377014, 36.32230415940285, 35.13529725372791, 36.39685615897179, 34.525688365101814, 38.7881438434124, 47.67494358122349, 51.967938020825386, 45.43416202068329, 43.66006761789322, 50.296650901436806, 53.09678144752979, 50.44286325573921, 49.467831775546074, 44.381204321980476, 44.364610612392426, 51.51257425546646, 54.20132517814636, 43.91097955405712, 46.39783591032028, 47.591530457139015, 49.89088587462902, 47.391273602843285, 43.901601657271385, 41.97275295853615, 40.08040130138397, 37.88853071630001, 36.06927193701267, 35.13583682477474, 34.010208025574684, 36.68018415570259, 37.255898863077164, 37.243097350001335, 36.71372875571251, 35.809403881430626, 35.8765234798193, 38.06897163391113, 37.39301070570946, 36.756145879626274, 37.95435078442097, 38.78181718289852, 35.82818627357483, 36.81386478245258, 35.58628745377064, 37.24822707474232, 36.66783481836319, 36.04657955467701, 36.35394126176834, 36.77045591175556, 37.305748388171196, 37.215913608670235, 36.17260739207268, 33.559480011463165, 35.171649903059006, 34.120261520147324, 34.73614387214184, 34.63330619037151, 35.191690027713776, 37.08874583244324, 37.36965335905552, 37.86491498351097, 42.971802949905396, 46.72941371798515, 45.889852568507195, 50.502702444791794, 50.353837832808495, 45.18190875649452, 50.15649542212486, 53.0212377011776, 51.978775039315224, 52.95772410929203, 53.42955619096756, 50.39915420114994, 45.01059874892235, 54.579860866069794, 53.925266191363335, 60.04255034029484, 19.840175583958626, 0.543155976338312, 4.190601333975792, 5.796287823468447, 1.912547335959971, 0.09189795004203916, 1.718865791335702, 39.22516219317913, 58.658049032092094, 47.68476985394955, 31.169187873601913, 27.993816062808037, 40.39193518459797, 47.45338886976242, 39.05975326895714, 3.1605910789221525, 0.06505676181404851, 0.12287134974030778, 0.05377220230002422, 0.0774677716253791, 0.03593665700464044, 0.043130676640430465, 0.015339406727434834, 0.02872932509490056, 0.01512010672740871, 0.025151054505840875, 0.06412083937902935, 0.03626655277912505, 0.02164018205803586, 0.025730376837600488, 0.007826975124771707, 0.018888311460614204, 0.03214694297639653, 0.014959747168177273, 0.026769730538944714, 0.07433696970110759, 0.03774523749598302, 0.05416745902039111, 0.03205181819794234, 0.05551391157496255, 0.07858177981688641, 0.04845461771765258, 0.03972147656895686, 4.924955628812313, 44.72763933241367, 56.94051079452038, 45.95609821379185, 29.57484282553196, 32.802727818489075, 47.03701101243496, 47.68172241747379, 58.01675744354725, 19.01977490633726, 0.049308165471302345, 0.20584261394105852, 1.7924335249699652, 2.130381572060287, 1.7850437527522445, 14.541434962302446, 41.919267028570175, 57.441753298044205, 51.31990559399128, 54.42167915403843, 51.6728800535202, 55.70179246366024, 54.22840632498264, 50.49138285219669, 49.17336657643318, 49.584789499640465, 44.48753021657467, 40.877260342240334, 41.251525059342384, 40.62105529010296, 41.81414186954498, 42.61028274893761, 41.4653167873621, 41.57353118062019, 37.03087493777275, 37.96656332910061, 35.34508779644966, 37.85899490118027, 36.72592610120773, 37.58111201226711, 36.5044891834259, 35.26037514209747, 35.77628865838051, 35.781619772315025, 35.890164747834206, 35.562584325671196, 36.53449237346649, 37.14803025126457, 36.35835662484169, 37.15126007795334, 38.19218002259731, 37.77305491268635, 39.323926493525505, 39.5695149153471, 37.45917655527592, 40.25765798985958, 37.14298792183399, 37.475527077913284, 38.06847766041756, 38.248812183737755, 37.9092738032341, 40.64730808138847, 48.61773379147053, 53.26722510159016, 47.79447756707668, 43.37488152086735, 50.61256594955921, 54.40608099102974, 51.411621272563934, 49.45974200963974, 46.46758496761322, 47.38366261124611, 52.832007855176926, 56.22374005615711, 46.89858824014664, 46.589554622769356, 49.593578428030014, 51.47149845957756, 48.79301078617573, 45.06954878568649, 42.85585597157478, 42.48776212334633, 40.296248719096184, 38.660987466573715, 37.433748319745064, 35.26355177164078, 38.77257227897644, 38.18570896983147, 38.39457616209984, 38.58016200363636, 38.11810679733753, 37.73898974061012, 40.23756846785545, 39.04399931430817, 37.682498171925545, 40.30537202954292, 40.66501133143902, 37.896810472011566, 38.78417685627937, 37.988427355885506, 39.737378507852554, 39.50257010757923, 38.501608818769455, 38.53651374578476, 38.84913817048073, 39.03372086584568, 39.03473541140556, 37.73019701242447, 38.0544488132, 36.84873931109905, 36.59346900880337, 36.037718430161476, 37.466076985001564, 37.13379241526127, 39.023073837161064, 39.325324818491936, 39.391566663980484, 45.074442923069, 49.1903630644083, 49.422203823924065, 53.04243676364422, 51.44308738410473, 47.944801300764084, 50.83148740231991, 55.464153215289116, 53.89605335891247, 55.770260989665985, 54.761502519249916, 52.59282968938351, 45.60756951570511, 57.00313523411751, 56.79829962551594, 62.24312245845795, 20.810301527380943, 0.48028796387370676, 5.374887110665441, 6.640105219557881, 1.1141700390726328, 0.024042298864515033, 1.5485493117012084, 43.872411623597145, 64.25085872411728, 52.58620284497738, 36.116541400551796, 28.06689754128456, 44.83823239803314, 53.82879696786404, 47.394446432590485, 4.976388718932867, 0.10027249285485595, 0.07120154419681057, 0.07162644600612111, 0.04337853541073855, 0.024846846317814197, 0.03805302840191871, 0.02129340613464592, 0.08264014759333804, 0.041423521761316806, 0.021287155395839363, 0.031327879114542156, 0.019345875189173967, 0.16298043890856206, 0.13107620790833607, 0.11163576084072702, 0.16699818894267082, 0.11307684835628606, 0.12883665855042636, 0.1144937492790632, 0.15130062267417088, 0.15360843477537856, 0.14162037492496893, 0.1915015748818405, 0.1499661075649783, 0.13418156158877537, 0.11009496578481048, 0.10542511285166256, 5.246555171906948, 50.571493953466415, 64.63125631213188, 54.121586456894875, 41.30382925271988, 42.332589849829674, 52.144928723573685, 53.004127219319344, 62.480241134762764, 23.040152974426746, 0.1358821484609507, 0.683569663669914, 6.477937996387482, 5.968724470585585, 1.7626959644258022, 14.377749245613813, 42.4960532784462, 59.50306288897991, 53.318742737174034, 56.51227377355099, 52.55782976746559, 59.01408612728119, 55.32345436513424, 54.60485212504864, 51.50972060859203, 51.08492620289326, 47.39032745361328, 42.9465115070343, 43.14031630754471, 43.88201750814915, 42.76114225387573, 45.32171465456486, 43.68396833539009, 44.36105780303478, 39.85302910208702, 40.745263025164604, 37.96817824244499, 41.27121560275555, 38.47573980689049, 39.42924164235592, 39.01413291692734, 37.9689572006464, 37.98845775425434, 37.54643127322197, 38.32595184445381, 37.377298548817635, 39.04279097914696, 39.874847531318665, 38.6137256026268, 39.56057399511337, 40.40832370519638, 40.2400117367506, 40.72212606668472, 40.932999551296234, 39.29395370185375, 42.005704790353775, 38.77520173788071, 38.08393143117428, 39.43171910941601, 40.01895859837532, 40.06106033921242, 43.69221769273281, 50.49325235188007, 53.46081331372261, 50.000069215893745, 45.26032514870167, 51.56589679419994, 56.48602858185768, 53.746527582407, 52.24629208445549, 48.35594303905964, 48.910052105784416, 55.104840695858, 57.308521047234535, 48.84726047515869, 49.89290736615658, 50.67808963358402, 53.77300836145878, 51.57103031873703, 47.76561051607132, 44.265686720609665, 45.86162768304348, 42.356737554073334, 40.94836972653866, 39.50873717665672, 36.462687626481056, 41.29169650375843, 39.67733412981033, 41.189664378762245, 39.4289680570364, 38.98670218884945, 39.88883838057518, 41.84321030974388, 41.527192667126656, 40.94295121729374, 43.31626206636429, 43.661101162433624, 40.547673627734184, 41.05962015688419, 41.29434876143932, 42.110237181186676, 41.74716666340828, 39.73411828279495, 40.86216375231743, 42.6025577634573, 42.377731427550316, 40.598663091659546, 39.53459858894348, 39.56424459815025, 37.60307863354683, 38.08312967419624, 37.34248861670494, 39.25333008170128, 39.26814928650856, 41.791924461722374, 42.3911789059639, 41.27832502126694, 47.396186739206314, 52.75524437427521, 52.10836708545685, 54.95731361210346, 53.80400709807873, 50.055884420871735, 55.69516181945801, 58.414926677942276, 56.52155667543411, 57.79965989291668, 57.42903918027878, 54.90890420973301, 49.07171443104744, 59.89640258252621, 58.88157583773136, 64.59596380591393, 22.778658606112003, 1.3843660592101514, 12.21312889829278, 15.093110259622335, 4.423759672790766, 0.18950012134155259, 2.1732812700793147, 47.71565839648247, 71.47131487727165, 60.32004565000534, 46.50500915944576, 38.71191993355751, 52.82230317592621, 61.15313574671745, 55.62491498887539, 6.847518514841795, 0.11585890766582452, 0.264920448535122, 0.12736512813717127, 0.12844320153817534, 0.15750325546832755, 0.08414048817940056, 0.07638408758793958, 0.24216939200414345, 0.18946383032016456, 0.10406690096715465, 0.14880770409945399, 0.14690497104311362], [0.012410224062477937, 0.011824176017398713, 0.039861694240244105, 0.04873674515692983, 0.036372457252582535, 0.00976556690147845, 0.02049773291219026, 0.03238647484977264, 0.03569970780517906, 0.07179785243351944, 0.03419517779548187, 0.04459209900232963, 0.03436825776589103, 0.08428252040175721, 0.07163181173382327, 1.1207807343453169, 30.71651816368103, 46.0911999642849, 45.337062031030655, 29.118500612676144, 20.936205871403217, 36.236842945218086, 39.27987925708294, 51.497922241687775, 24.157317727804184, 0.10827526421053335, 0.03820162120973691, 0.20691489859018475, 0.9729643317405134, 0.9241196152288467, 4.082349892705679, 19.18716162443161, 42.50869520008564, 50.85671044886112, 52.855965569615364, 52.208761498332024, 52.97074221074581, 47.91168987751007, 48.42141352593899, 44.86627869307995, 40.98618909716606, 38.06603819131851, 37.32750982046127, 35.64676880836487, 36.82632811367512, 35.508482828736305, 36.34598068892956, 36.49214364588261, 35.80953307449818, 34.085121005773544, 34.498721212148666, 35.656944662332535, 35.76331615447998, 37.31683239340782, 35.10190464556217, 34.43362310528755, 36.26743510365486, 34.62520122528076, 35.22210739552975, 35.24126976728439, 35.46489916741848, 34.62216138839722, 34.79880630970001, 36.77111707627773, 36.39131985604763, 35.75737327337265, 36.11192084848881, 36.79171197116375, 37.80308470129967, 35.93348242342472, 36.12170912325382, 35.69034107029438, 35.57486526668072, 36.6891098767519, 35.070050954818726, 34.59458626806736, 38.77932071685791, 47.65880964696407, 51.435290202498436, 47.36321970820427, 45.957545936107635, 47.9939516633749, 51.76466032862663, 51.49698369204998, 47.32333704829216, 46.11812151968479, 45.997728779911995, 52.465897500514984, 54.22543488442898, 40.32066620886326, 44.58972193300724, 49.377689212560654, 48.71261090040207, 45.15235394239426, 44.150400906801224, 42.342864498496056, 39.627864584326744, 36.88240550458431, 36.486611142754555, 36.3705425709486, 35.06935939192772, 35.69968856871128, 37.2566132247448, 37.934420853853226, 38.84186536073685, 36.881018579006195, 35.7051070779562, 36.58976800739765, 36.78377039730549, 37.783599346876144, 37.464036494493484, 37.80011706054211, 35.63845105469227, 37.837339863181114, 35.741110146045685, 37.57746420800686, 37.85478472709656, 39.58103209733963, 37.496570348739624, 37.776877507567406, 39.38897520303726, 41.320092380046844, 38.95694598555565, 36.493864953517914, 36.180735155940056, 33.32478180527687, 34.138014167547226, 34.95440796017647, 35.38402050733566, 34.12318356335163, 35.94065643846989, 37.964408844709396, 38.30598011612892, 42.605711594223976, 45.87983250617981, 48.049333691596985, 51.91951721906662, 50.96655495464802, 52.10433930158615, 53.41781482100487, 54.40889663994312, 52.60841645300388, 53.523973524570465, 50.525334030389786, 47.43976280093193, 55.119488909840584, 55.424148961901665, 54.16889771819115, 15.067360941320658, 0.3334330581128597, 3.54228890966624, 3.531938740052283, 0.8341295784339309, 0.02696457398997154, 2.019374091178179, 41.309133768081665, 56.198942586779594, 46.66930854320526, 33.50929230451584, 24.839396327733994, 35.78364506363869, 51.62031747400761, 32.111560106277466, 1.465002957265824, 0.061311250101425685, 0.029513431945815682, 0.045011905967839994, 0.057442946344963275, 0.013490362489392282, 0.019349383692315314, 0.015917312484816648, 0.0636306063097436, 0.014319796937343199, 0.00782189512392506, 0.037111209603608586, 0.06734217589837499, 0.014733650023117661, 0.061504891273216344, 0.037629866928909905, 0.04549415723886341, 0.007531789597123861, 0.03249299159506336, 0.02172639735363191, 0.05568939239310566, 0.09013148272060789, 0.051406569473329, 0.03314765119284857, 0.04811244682059623, 0.027140776546730194, 0.05105086922412738, 0.01756554269377375, 1.8258173461072147, 37.53231503069401, 55.072865411639214, 52.71443076431751, 35.4569385945797, 26.080054454505444, 45.094992220401764, 45.14967888593674, 56.53675585985184, 25.64554776996374, 0.03290821208793204, 0.1564242469612509, 0.5852006608620286, 2.951166029088199, 2.1714343316853046, 6.269740993157029, 22.83162396401167, 46.20186522603035, 51.542075872421265, 53.57495918869972, 54.55316349864006, 52.793394327163696, 51.83918192982674, 51.00239843130112, 48.234471157193184, 43.39445427060127, 39.76995036005974, 38.991733118891716, 38.26632924377918, 38.13666880130768, 39.37628388404846, 38.11209172010422, 37.64203034341335, 37.51969210803509, 35.59941954910755, 36.9735512137413, 37.03376658260822, 36.48341551423073, 37.738510966300964, 36.801287457346916, 35.413256138563156, 38.281980603933334, 36.89484603703022, 38.982119634747505, 36.67900241911411, 38.689884915947914, 37.65015430748463, 37.074363604187965, 37.56682097911835, 38.77878874540329, 37.877720296382904, 37.91770935058594, 38.10275562107563, 40.5373951792717, 37.541761323809624, 38.60839828848839, 38.212615326046944, 38.17143693566322, 38.69377590715885, 37.8116038441658, 37.56087429821491, 40.97966864705086, 48.34212318062782, 52.85156920552254, 50.694265365600586, 45.43180614709854, 50.58620296418667, 51.591211035847664, 52.53619372844696, 49.76242996752262, 46.7495222389698, 47.05011650919914, 52.5193340331316, 53.76786723732948, 42.41166740655899, 46.15874134004116, 52.77880311012268, 48.98385934531689, 47.336298152804375, 46.10642574727535, 43.37766297161579, 41.87406465411186, 40.88362120091915, 38.313032537698746, 37.93494142591953, 37.58155658841133, 38.785491585731506, 40.11140003800392, 38.32866869866848, 39.95521321892738, 38.14463697373867, 39.058746322989464, 39.50286649167538, 38.798087909817696, 40.65379053354263, 39.064518213272095, 40.06542630493641, 38.76527287065983, 38.38790751993656, 38.00608120858669, 39.178002923727036, 39.6214809268713, 40.83669371902943, 40.030813962221146, 40.33238857984543, 41.216642931103706, 41.40644654631615, 41.85686677694321, 37.23693788051605, 37.44366958737373, 35.48115089535713, 36.31390281021595, 36.78574629127979, 36.37664124369621, 36.942769065499306, 38.624954000115395, 39.422181621193886, 41.26612767577171, 46.168100237846375, 48.75084064900875, 51.860874965786934, 55.33906392753124, 51.475283056497574, 52.79516123235226, 54.36140298843384, 56.34280666708946, 54.497196301817894, 53.69319744408131, 51.59619256854057, 48.96398641169071, 56.15700803697109, 58.52319426834583, 58.145870715379715, 17.07056500017643, 1.403934652917087, 6.10484124161303, 4.107159236446023, 1.64278294891119, 0.038613279393757693, 1.9980795588344336, 45.09920999407768, 60.49388252198696, 52.41220258176327, 41.96361444890499, 29.998622685670853, 41.292859241366386, 58.06040570139885, 42.06062324345112, 2.4843549029901624, 0.05477281774801668, 0.012587507371790707, 0.03708178715896793, 0.05757435843406711, 0.03240740712499246, 0.020239433979440946, 0.0031625349993191776, 0.024793574957584497, 0.009881564583338331, 0.05375466906116344, 0.07165003888076171, 0.01712316516204737, 0.1037366155651398, 0.17097387404646724, 0.11887990884133615, 0.15736551285954192, 0.11458803171990439, 0.09946458347258158, 0.06748140280251391, 0.14458516583545133, 0.2106827823445201, 0.17487936682300642, 0.10905909090070054, 0.14248033112380654, 0.1538026102934964, 0.2046276885084808, 0.19889612653059885, 2.1409260062500834, 43.41893635690212, 62.130108922719955, 59.24102135002613, 40.34379556775093, 30.337406806647778, 50.08307956159115, 49.7526340931654, 62.338356748223305, 29.41526658833027, 0.1660384880960919, 0.6349678372498602, 3.06174389552325, 6.03679639287293, 3.2694825483486056, 6.383101735264063, 22.252599634230137, 44.97127465903759, 52.54364512860775, 55.86476571857929, 57.68080987036228, 56.48010849952698, 54.21758450567722, 54.44697819650173, 49.81993988156319, 44.561839029192924, 41.853914335370064, 40.46735353767872, 39.443388283252716, 39.7875852137804, 40.66312663257122, 40.1465405523777, 40.10794222354889, 39.72235411405563, 37.762882858514786, 38.60809810459614, 39.09306228160858, 38.35779793560505, 40.70061922073364, 38.29321660101414, 38.015155121684074, 40.90938001871109, 39.33436453342438, 40.49866005778313, 39.55592684447765, 40.09092673659325, 39.19324770569801, 39.55449052155018, 40.43896906077862, 41.69921323657036, 39.80879947543144, 41.247185692191124, 40.514273419976234, 42.16181941330433, 39.74340498447418, 40.46904444694519, 39.60063524544239, 39.45352993905544, 41.18387348949909, 39.50822040438652, 40.61239555478096, 43.61729711294174, 51.10636845231056, 54.31380674242973, 50.215023681521416, 47.89346985518932, 53.162305131554604, 54.32503893971443, 55.35398952662945, 50.55971458554268, 48.874987587332726, 48.854559883475304, 56.077596098184586, 56.20946802198887, 43.77772070467472, 47.44127131998539, 55.601405650377274, 51.137986555695534, 49.66387465596199, 47.32608810067177, 45.68886995315552, 44.911382272839546, 42.210874781012535, 41.613037660717964, 41.168628707528114, 40.78626662492752, 41.957983151078224, 42.36379757523537, 41.0676035284996, 42.76496484875679, 40.17784707248211, 39.92634616792202, 41.24529719352722, 41.21881641447544, 41.433045119047165, 41.090527698397636, 43.07483062148094, 40.56671820580959, 42.54641957581043, 39.80212703347206, 42.15744964778423, 42.438862547278404, 44.54850934445858, 42.071733847260475, 42.26502567529678, 44.623426124453545, 45.60630418360233, 44.48228269815445, 40.371746867895126, 39.78790059685707, 37.542293295264244, 38.51484730839729, 38.889712393283844, 39.76359710097313, 38.4294430911541, 39.888971373438835, 42.10852347314358, 43.38287629187107, 48.44485826790333, 50.55351711809635, 53.450766652822495, 58.865517899394035, 54.31565724313259, 55.756205543875694, 57.500330954790115, 59.29060488939285, 56.75900213420391, 56.91122576594353, 54.87750269472599, 51.527651846408844, 61.458027586340904, 59.368546307086945, 60.37205345928669, 18.01843173801899, 1.6772042331285775, 10.063105467706919, 10.382148697972298, 2.123360736295581, 0.24181379936635494, 2.279745382256806, 47.809802144765854, 66.8710233271122, 58.741906732320786, 45.94220995903015, 35.61183728277683, 51.07747100293636, 65.06282955408096, 47.75400213897228, 3.93607959151268, 0.17256929859286174, 0.227831766824238, 0.12041469992254861, 0.15654961054679006, 0.15781598165631294, 0.09939522235072218, 0.15382371697342023, 0.20102416077861562, 0.18768800451653078, 0.12379414358292706, 0.2125805281684734, 0.15694664471084252], [0.025237316185666714, 0.01762622439855477, 0.031572665393468924, 0.02003391844482394, 0.032210856734309345, 0.03562315156159457, 0.12124782748287544, 0.06081176245061215, 0.03276563067629468, 0.032210062636295334, 0.011303837727609789, 0.04643971646146383, 0.031474961651838385, 0.045707613753620535, 0.04995920338842552, 0.34552305936813354, 17.188280783593655, 46.5399444848299, 43.58549661934376, 29.521966762840748, 26.940358690917492, 31.160769425332546, 37.31736056506634, 51.224443316459656, 34.829953238368034, 0.889926734380424, 0.05962645242107101, 0.2510881517082453, 1.3266674615442753, 1.2015906418673694, 0.5719052336644381, 6.909270901232958, 24.83451548963785, 50.049975737929344, 53.56183469295502, 49.09808501601219, 47.57415018975735, 46.1388798058033, 42.9845854640007, 40.31916908919811, 36.970268189907074, 37.54063278436661, 36.37595348060131, 35.986584573984146, 34.52849641442299, 35.18332287669182, 33.88557091355324, 34.86370302736759, 34.3435413390398, 36.45095765590668, 35.556014478206635, 34.39809501171112, 34.2805141210556, 35.913077518343925, 34.60578426718712, 36.088088527321815, 33.55849586427212, 35.72456203401089, 36.016192585229874, 35.72484701871872, 35.062272772192955, 36.28723204135895, 36.48303933441639, 36.12224109470844, 35.56015245616436, 35.35904824733734, 40.846029818058014, 39.33612763881683, 37.577726393938065, 37.212535589933395, 37.72651880979538, 35.04114590585232, 37.72794373333454, 37.34715096652508, 35.086325481534004, 36.24344699084759, 39.548912420868874, 48.02830561995506, 48.98929305374622, 48.0243082344532, 45.90790919959545, 50.15516549348831, 49.76951278746128, 50.69578528404236, 48.33122916519642, 44.50304478406906, 47.424966394901276, 51.305975541472435, 51.58171534538269, 42.18584552407265, 43.63263688981533, 46.17660418152809, 53.07511880993843, 45.983392149209976, 42.58612744510174, 40.791913121938705, 39.11918208003044, 37.93134681880474, 38.77899773418903, 36.3205486536026, 35.48900127410889, 37.82804936170578, 35.395754277706146, 36.84855692088604, 38.757236301898956, 37.02856086194515, 36.915912106633186, 36.13980755209923, 37.102345302700996, 36.77198342978954, 39.14535507559776, 38.646460846066475, 37.45003804564476, 36.14735774695873, 35.411360040307045, 37.07846738398075, 38.5114236921072, 39.834022521972656, 39.67323414981365, 39.37087297439575, 37.63574928045273, 40.872981771826744, 37.84610599279404, 40.99470444023609, 36.75220549106598, 36.48984856903553, 35.15237353742123, 33.96875225007534, 34.250339940190315, 33.30115847289562, 35.39165049791336, 37.022526785731316, 37.81517945230007, 38.480060175061226, 43.73168237507343, 46.18999846279621, 52.130873277783394, 52.510343715548515, 51.50509625673294, 52.4893194437027, 53.17083187401295, 53.485941365361214, 52.445747181773186, 52.903592213988304, 53.856090903282166, 54.167070016264915, 56.46066874265671, 46.11350476741791, 10.470583252608776, 0.9813118900638074, 3.4861806454136968, 3.5815009055659175, 1.441104852128774, 0.0766114667931106, 1.8562349514104426, 41.80436119437218, 52.080202996730804, 38.888211473822594, 24.08922728151083, 22.89888985455036, 38.38523626327515, 53.58836866915226, 26.654363237321377, 0.7429724105168134, 0.06828352343291044, 0.016282846190733835, 0.021597848099190742, 0.0135121807034011, 0.024080126131593715, 0.07353203633101657, 0.045625584170920774, 0.04262822782038711, 0.004097676555829821, 0.06433498609112576, 0.029938517436676193, 0.023121095073292963, 0.0521905928326305, 0.07473438236047514, 0.04420103912707418, 0.04377306111564394, 0.04513513958954718, 0.04107680892047938, 0.12727158784400672, 0.029026002339378465, 0.0611723682959564, 0.013145853827154497, 0.04650225724617485, 0.017386564504704438, 0.062043542056926526, 0.019151028027408756, 0.016305266472045332, 0.6251087319105864, 23.359269350767136, 51.762965619564056, 48.418700471520424, 31.93401463329792, 27.210034020245075, 38.39629366993904, 43.90337996184826, 56.469602063298225, 37.401206865906715, 0.6085209001321346, 0.11781849665567279, 0.6202765787020326, 2.4391570407897234, 1.880601025186479, 2.5523192435503006, 9.089605305343866, 29.47714626789093, 52.760404497385025, 55.64720079302788, 51.18935979902744, 50.272776782512665, 48.83134312927723, 44.93088662624359, 42.704582288861275, 39.13774028420448, 38.33107016980648, 38.3276579529047, 37.127769738435745, 37.85157769918442, 36.33764773607254, 35.52623547613621, 35.633895099163055, 36.81016758084297, 37.28263422846794, 36.47818699479103, 36.40759438276291, 37.43062108755112, 36.68941766023636, 36.06264889240265, 37.16429337859154, 34.960202649235725, 35.43100118637085, 38.22442889213562, 38.001152873039246, 37.937901467084885, 37.93580777943134, 37.55102902650833, 37.317907735705376, 37.49066926538944, 36.85415022075176, 42.557533979415894, 40.011518597602844, 40.043315291404724, 38.11159394681454, 37.591781839728355, 36.581332460045815, 40.05721874535084, 37.86524176597595, 37.17741407454014, 37.33676992356777, 41.59147761762142, 49.078698456287384, 50.11537402868271, 52.03047886490822, 47.41794057190418, 50.029156655073166, 52.328223288059235, 51.812108382582664, 50.56636042892933, 46.5498923510313, 48.22041191160679, 51.91048130393028, 53.193725645542145, 43.614443466067314, 45.558791533112526, 50.49638718366623, 53.01092505455017, 48.26958887279034, 43.06263707578182, 41.37189120054245, 41.897623389959335, 40.64272552728653, 40.613607689738274, 38.58335003256798, 38.46905596554279, 38.93060579895973, 38.47591079771519, 40.34386396408081, 40.372430831193924, 38.91872763633728, 37.722776010632515, 39.29394990205765, 39.429826810956, 39.7301284968853, 41.07706502079964, 41.252547204494476, 38.667196333408356, 39.42516066133976, 38.49868677556515, 39.12930853664875, 40.58766268193722, 40.69782257080078, 40.594836696982384, 42.78173714876175, 40.31558208167553, 41.405526995658875, 40.82375921308994, 43.03555212914944, 37.787167355418205, 38.90843778848648, 37.29395002126694, 37.80398905277252, 36.16517499089241, 35.46825058758259, 38.01687642931938, 38.02225314080715, 39.33088771998882, 41.187323704361916, 47.312348037958145, 47.550960034132004, 53.88368122279644, 54.89093877375126, 52.19384349882603, 53.939629420638084, 55.14675624668598, 54.324457570910454, 53.957089483737946, 55.46247370541096, 55.47877863049507, 57.03182369470596, 60.27414791285992, 49.40217509865761, 11.935123465955257, 1.285279132425785, 6.99555809609592, 6.374573092907667, 0.816818360472098, 0.02001251676119864, 1.732482835650444, 46.494875103235245, 57.93329492211342, 50.11912822723389, 30.45149188488722, 26.20565291494131, 43.32057103514671, 59.989562183618546, 33.064279183745384, 1.1390639282763004, 0.08950319534051232, 0.025972927396651357, 0.0394013956974959, 0.010163347851630533, 0.023855513281887397, 0.06215063767740503, 0.0363465488771908, 0.03558215161319822, 0.006054206505723414, 0.05372438201447949, 0.06269013450946659, 0.0159578022066853, 0.09102061274461448, 0.1545265901950188, 0.18880938965594396, 0.18663177994312719, 0.10491563589312136, 0.09351059241453186, 0.27556513203307986, 0.20683427166659385, 0.13212242833105847, 0.1127472754160408, 0.19925330736441538, 0.13348106323974207, 0.3134406387107447, 0.08744412887608632, 0.14720116218086332, 0.6697455304674804, 25.08097216486931, 62.84559153020382, 54.92203630506992, 43.10020945966244, 36.585413441061974, 43.78588646650314, 50.13529255986214, 60.60086578130722, 42.08467215299606, 1.1953739379532635, 0.27838529320433736, 2.09595138207078, 6.892960276454687, 4.854091806337237, 2.031877557747066, 8.991930596530437, 29.33193325996399, 54.22357298433781, 58.231100142002106, 52.63028047978878, 51.31501905620098, 50.14728091657162, 47.08634376525879, 44.017769023776054, 41.50494486093521, 40.45542597770691, 40.05192182958126, 39.55333538353443, 38.24452981352806, 38.269486874341965, 37.887136191129684, 37.86861978471279, 39.157575219869614, 40.4132292419672, 38.389815017580986, 38.25209140777588, 40.06416097283363, 39.504922181367874, 38.22181083261967, 38.81484501063824, 35.48443391919136, 38.70536528527737, 40.745589807629585, 40.60025900602341, 39.23223361372948, 39.4755307585001, 39.80950623750687, 38.92507329583168, 38.96536633372307, 40.18999122083187, 44.81278516352177, 41.06987580657005, 42.89207182824612, 40.678728595376015, 41.126165986061096, 37.16803997755051, 41.855449452996254, 39.85718987882137, 38.73408414423466, 40.989966094493866, 44.27286833524704, 51.54950827360153, 52.42075972259045, 51.21806725859642, 47.71438926458359, 52.977407053112984, 54.173244684934616, 53.48942197859287, 53.41755263507366, 48.296248242259026, 50.41283346712589, 54.82255384325981, 54.71893720328808, 46.14379294216633, 48.454433754086494, 50.88385619223118, 56.81297443807125, 51.05830483138561, 46.04428008198738, 43.38738664984703, 43.74009512364864, 41.37134402990341, 43.595596477389336, 40.31819634139538, 40.736816078424454, 41.478065103292465, 39.90946747362614, 41.23217269778252, 41.73845373094082, 39.84835535287857, 40.00320464372635, 41.07344761490822, 41.09181582927704, 41.02030746638775, 43.15251745283604, 42.78990291059017, 41.707424595952034, 40.86326949298382, 39.83904965221882, 41.04620687663555, 42.49541871249676, 44.74685110151768, 43.42478804290295, 45.28844363987446, 41.83357022702694, 45.08414760231972, 42.091602981090546, 45.95016673207283, 39.81115534901619, 42.02035300433636, 40.76962731778622, 38.95511448383331, 39.439261704683304, 37.13240168988705, 40.42828023433685, 40.03220468759537, 41.99774041771889, 43.399773985147476, 49.34299327433109, 51.37803107500076, 55.50797626376152, 57.6384649425745, 54.53345015645027, 55.23761697113514, 55.58113373816013, 56.403082832694054, 56.51265375316143, 58.681014999747276, 60.36107584834099, 60.97170688211918, 61.56749211251736, 51.45885653793812, 13.897388521581888, 3.8277747156098485, 9.20349944382906, 10.842387601733208, 4.739724593237042, 0.17521915171528235, 2.173134027980268, 50.93119405210018, 64.29774820804596, 52.078101709485054, 35.092370957136154, 35.53136520087719, 51.10096514225006, 68.02700489759445, 42.417777478694916, 2.136801090091467, 0.16794126568129286, 0.1631846631062217, 0.12986165354959667, 0.13790417433483526, 0.1534086634637788, 0.14087891002418473, 0.15847517206566408, 0.11089358347817324, 0.07243843720061705, 0.13975316105643287, 0.09009857589262538, 0.10592403647024184], [0.03334755980176851, 0.0687052340072114, 0.0793889767373912, 0.027647010319924448, 0.026095832618011627, 0.035690924487425946, 0.0443844646360958, 0.021289552532834932, 0.046717168370378204, 0.045115635948604904, 0.011951889428019058, 0.08338587984326296, 0.010697118086682167, 0.05559236400586087, 0.05299926291627344, 0.08533121959771961, 10.627826415002346, 40.73378004133701, 47.2522808611393, 28.27943343669176, 19.89724852144718, 37.274764850735664, 41.341899409890175, 52.61133469641209, 42.201048508286476, 4.174403753131628, 0.07036585622699931, 0.10298334309482016, 1.2225899775512516, 0.8759582682978362, 1.924566684756428, 1.7949740448966622, 11.872294787317514, 45.77783837914467, 53.001083582639694, 51.15915521979332, 46.073910892009735, 44.11226235330105, 39.55576725304127, 38.031353652477264, 36.48778147995472, 36.71127788722515, 36.235957592725754, 35.53144879639149, 35.340281054377556, 35.91789945960045, 35.83800494670868, 36.086219027638435, 35.50828903913498, 35.80710120499134, 36.15356281399727, 34.96690168976784, 34.71452683210373, 35.277896001935005, 33.689813017845154, 34.92196910083294, 35.91222256422043, 35.41067607700825, 35.16780070960522, 35.044546723365784, 37.283717170357704, 35.994130969047546, 35.24842098355293, 37.98118494451046, 36.83855205774307, 36.216673627495766, 37.50756315886974, 39.11201186478138, 36.66327886283398, 37.931050434708595, 34.94376093149185, 36.17968641221523, 35.44076286256313, 35.693886280059814, 35.98981820046902, 36.87228284776211, 38.32254722714424, 46.226677894592285, 46.43103092908859, 48.862440660595894, 47.52404227852821, 50.6037238240242, 50.770884454250336, 49.257843643426895, 48.888013288378716, 47.288173735141754, 47.7394413203001, 50.73707766830921, 52.30873793363571, 37.859876453876495, 45.028245002031326, 45.247451439499855, 50.06430096924305, 46.10315792262554, 42.92092368006706, 40.78855790197849, 38.83956268429756, 38.97788666188717, 38.804235979914665, 38.00651058554649, 36.314062401652336, 36.59017838537693, 37.08345651626587, 37.02853426337242, 36.43344059586525, 35.815696343779564, 36.07443206012249, 36.083790957927704, 37.522572353482246, 37.90865443646908, 38.620375245809555, 38.859845995903015, 36.80039070546627, 36.04915201663971, 34.400903061032295, 35.973498076200485, 36.808541268110275, 38.39397959411144, 40.05156844854355, 38.007361739873886, 39.04299236834049, 40.530095770955086, 39.31015983223915, 40.259599685668945, 39.1326941549778, 38.26665982604027, 36.79496079683304, 36.675472408533096, 36.746258810162544, 34.51016999781132, 35.06740249693394, 35.31552538275719, 37.16073676943779, 38.55021581053734, 43.13484460115433, 45.75482681393623, 48.93375903367996, 53.10928277671337, 51.7421655356884, 50.38487836718559, 54.069913029670715, 54.17373105883598, 52.1233306825161, 40.39231516420841, 51.162134259939194, 55.088721960783005, 57.642789110541344, 36.339255049824715, 6.924760770052671, 1.1568206129595637, 6.429424099624157, 1.564812082797289, 1.253218709025532, 0.09480334687395953, 3.354883440770209, 49.89100366830826, 51.011555939912796, 53.36207941174507, 38.94464984536171, 26.981898061931133, 38.22020351886749, 52.43491396307945, 23.82725603878498, 0.40522091381717473, 0.022856845971546136, 0.04243328789016232, 0.0809606748225633, 0.0696051177510526, 0.025941421372408513, 0.04531506587227341, 0.03284658043412492, 0.047841600026004016, 0.031115665697143413, 0.04094267686014064, 0.03472393946140073, 0.038169445397215895, 0.03955428554036189, 0.036950512367184274, 0.043948482561972924, 0.09114995424170047, 0.021200192386459094, 0.029789757645630743, 0.030846312474750448, 0.0751347784535028, 0.021506226257770322, 0.05765936031821184, 0.06152202746307012, 0.05114944498927798, 0.016199495585169643, 0.05127114236529451, 0.044267487319302745, 0.04411743248056155, 13.710805233567953, 49.54136162996292, 52.00921140611172, 37.08660274744034, 23.183306492865086, 39.336215034127235, 48.258406072854996, 55.27924753725529, 45.914551243186, 4.916605101898313, 0.06601770204724744, 0.07421982169034891, 2.219486553221941, 3.0026394920423627, 4.107330227270722, 3.703361079096794, 13.43679053708911, 49.31515596807003, 52.815303951501846, 53.51760886609554, 48.160382732748985, 46.60807102918625, 42.43386581540108, 40.332118794322014, 39.92540381848812, 37.97801971435547, 38.2358168810606, 36.97747640311718, 37.63820394873619, 37.3360213637352, 38.267051205039024, 36.48197919130325, 36.67669594287872, 37.53653280436993, 37.762119099497795, 36.51745788753033, 35.544181913137436, 36.43682241439819, 36.50987349450588, 37.20490179955959, 36.71333737671375, 38.87635610997677, 36.768958792090416, 37.974896281957626, 37.79230087995529, 36.58818729221821, 38.044269159436226, 39.345843717455864, 39.302617236971855, 39.49197627604008, 40.835595577955246, 40.098419934511185, 39.26442928612232, 38.97727109491825, 36.16658851504326, 37.84233659505844, 38.66810828447342, 37.671949937939644, 38.47636677324772, 37.46001251041889, 40.966718941926956, 47.250494956970215, 48.9518004655838, 52.75218553841114, 50.63366241753101, 52.88499981164932, 51.976837143301964, 51.4443489164114, 51.25144846737385, 49.9465224891901, 49.495118111371994, 51.81311912834644, 53.19771163165569, 43.27611342072487, 47.27518603205681, 48.080625012516975, 51.60537667572498, 47.764345183968544, 44.92496654391289, 42.28122040629387, 40.94793654978275, 40.85265286266804, 39.01080809533596, 39.05599907040596, 38.05559255182743, 37.74261474609375, 38.24973173439503, 38.3676166087389, 37.97754853963852, 38.38645979762077, 38.505845591425896, 38.644788935780525, 40.2827138453722, 40.72393476963043, 39.82155159115791, 40.07395684719086, 40.708013623952866, 38.71223911643028, 35.757635459303856, 37.762461081147194, 39.64822769165039, 40.4812303930521, 42.41225257515907, 40.87159484624863, 43.28650586307049, 41.99041061103344, 41.75107665359974, 42.1540754288435, 40.9340862929821, 40.67369386553764, 38.992770463228226, 38.00789371132851, 38.52322965860367, 36.686377823352814, 38.02434302866459, 37.63209007680416, 38.327635154128075, 41.16213105618954, 44.9007922410965, 47.375838831067085, 52.69345588982105, 56.16244934499264, 52.22299933433533, 51.538724452257156, 54.60277743637562, 54.879375994205475, 53.61401729285717, 43.79366844892502, 53.097959384322166, 58.06966960430145, 58.55453498661518, 39.53669987618923, 8.128908555954695, 1.3980507873930037, 5.1951781287789345, 4.727557646110654, 2.9059453681111336, 0.04255828040186316, 3.6179055646061897, 53.000715002417564, 56.478254199028015, 54.472714215517044, 37.95604169368744, 30.528783537447453, 43.21066953241825, 58.05260851979256, 30.21873727440834, 0.6230119569227099, 0.02663778966962127, 0.06158922151371371, 0.11669683692161925, 0.014270995161496103, 0.032862243460840546, 0.03530261426931247, 0.006446028937716619, 0.02692549620405771, 0.03841781253868248, 0.026823801563296, 0.008433212369709508, 0.01441331960450043, 0.19820147630525753, 0.11654906047624536, 0.16776099801063538, 0.18249926419230178, 0.17554946680320427, 0.1643262495053932, 0.11543210595846176, 0.1983732686494477, 0.10171296438784339, 0.1138154708314687, 0.178467086807359, 0.3060108202043921, 0.16214571573073044, 0.1706074460525997, 0.14735345088411123, 0.36437536182347685, 17.134566865861416, 54.9573440104723, 58.64275485277176, 41.960342824459076, 29.55229863524437, 49.87152971327305, 52.5798761844635, 60.166184306144714, 50.6103240698576, 6.492341598495841, 0.22751699230866507, 0.8652705105487257, 5.432777004316449, 5.359681276604533, 7.189327273517847, 3.0947076017037034, 15.16373137012124, 51.91101707518101, 56.6132153570652, 58.06492365896702, 51.68500520288944, 49.39935564994812, 43.77174362540245, 42.21206791698933, 41.410595923662186, 38.94008249044418, 39.55603703856468, 40.50548069179058, 39.42728474736214, 39.05446395277977, 40.32003164291382, 39.51851785182953, 39.22178037464619, 39.344730377197266, 40.065114721655846, 38.006134405732155, 38.51962745189667, 39.36071611940861, 37.54582330584526, 39.587913528084755, 38.60135346651077, 40.87145425379276, 37.907537296414375, 40.34545607864857, 41.008075922727585, 40.00645346939564, 39.24612566828728, 40.6589050590992, 41.30841560661793, 42.242439687252045, 41.36828899383545, 42.08167031407356, 41.74909695982933, 40.476089268922806, 37.546058893203735, 39.73243497312069, 38.85195381939411, 40.28001978993416, 40.407590344548225, 41.19004815816879, 42.248055785894394, 49.30812634527683, 50.26296950876713, 52.05444797873497, 48.32148648798466, 58.36982309818268, 52.63846904039383, 53.03735263645649, 53.874466717243195, 52.59331986308098, 53.78660023212433, 54.79337900876999, 56.92443385720253, 46.26694813370705, 48.31210479140282, 49.038386419415474, 54.82672221958637, 49.893762320280075, 48.248097226023674, 45.12266993522644, 42.1273248642683, 44.36374045908451, 42.341629564762115, 41.938133016228676, 39.363577365875244, 40.29181055724621, 40.662590861320496, 40.82240268588066, 40.12641303241253, 39.77736756205559, 39.76718410849571, 41.07007719576359, 43.42196099460125, 42.139829993247986, 43.36657516658306, 42.86721736192703, 42.98021949827671, 40.5212764441967, 36.604279428720474, 40.35837158560753, 41.83213010430336, 43.20086985826492, 45.16583561897278, 42.99060434103012, 44.69914086163044, 45.19387051463127, 43.540096655488014, 45.32752454280853, 43.64981956779957, 43.13205935060978, 41.19486629962921, 40.66764459013939, 42.96647183597088, 38.83003659546375, 39.64073069393635, 39.78848196566105, 40.7258764654398, 42.09398925304413, 47.25200727581978, 49.38401207327843, 53.47300685942173, 57.86554075777531, 56.212500259280205, 54.15527544915676, 57.698718309402466, 55.88307313621044, 54.619564935564995, 44.09143187105656, 55.266305431723595, 61.11139118671417, 60.93993678689003, 38.81843201816082, 9.631235841661692, 5.04458793438971, 15.859025660902262, 8.063423819839954, 3.2236817060038447, 0.2314294019015506, 3.6416436033323407, 58.64320322871208, 60.244399309158325, 66.1094605922699, 50.63803978264332, 39.382006376981735, 53.24341557919979, 66.91820919513702, 38.446625769138336, 1.1275484086945653, 0.11319045632262714, 0.1200592631357722, 0.19112221867544577, 0.12780164455762133, 0.15339202451286837, 0.15398166084196419, 0.09226794776623137, 0.23067506816005334, 0.14995451521826908, 0.13996971974847838, 0.11374268840881996, 0.1442310871789232], [0.02377441694989102, 0.0262235395348398, 0.03720373315445613, 0.022925294251763262, 0.032891573137021624, 0.028461220535973553, 0.049117645030491985, 0.045282964274520054, 0.03855714705423452, 0.03361557159223594, 0.022987864722381346, 0.06713071576086804, 0.009811661693674978, 0.037618081623804756, 0.0037774178008476156, 0.0444507495558355, 5.111517067998648, 38.62806223332882, 49.94229331612587, 29.61471028625965, 27.086591944098473, 22.917516455054283, 33.96694354712963, 47.02678196132183, 44.31127667427063, 9.742405526340008, 0.05749446623667609, 0.3224946325644851, 0.9155581996310502, 1.1606193403713405, 1.6276373178698123, 0.9740412177052349, 4.879178535193205, 38.36836516857147, 53.59607845544815, 48.60615961253643, 48.57135348021984, 45.91940738260746, 41.979980170726776, 38.441283255815506, 38.11582691967487, 37.3294173181057, 38.71408201754093, 39.837039560079575, 40.41846536099911, 42.359139025211334, 40.94678521156311, 38.0053136497736, 39.23658438026905, 39.7145189344883, 38.56280833482742, 36.225352361798286, 35.51853708922863, 36.94145813584328, 36.25795841217041, 36.53577670454979, 36.91604509949684, 36.409049704670906, 35.85187040269375, 35.150580033659935, 36.05259843170643, 35.72243794798851, 34.780928269028664, 36.38985313475132, 34.7282250970602, 35.305661112070084, 36.28738783299923, 37.45020143687725, 36.857839822769165, 37.56247401237488, 36.90688759088516, 35.64677640795708, 35.63003450632095, 36.33759453892708, 37.60891892015934, 36.75990767776966, 39.703275337815285, 48.29807214438915, 46.7769605666399, 42.11847513914108, 51.19713798165321, 49.507946223020554, 49.956679344177246, 52.282998114824295, 50.89653991162777, 46.7337416857481, 46.27092272043228, 50.30467227101326, 55.1019224524498, 37.34618201851845, 44.073534831404686, 47.961892783641815, 47.81959421932697, 46.64569281041622, 40.73627270758152, 38.63639898598194, 40.302525982260704, 41.262046694755554, 39.36334937810898, 37.26115018129349, 35.859800577163696, 35.46806439757347, 35.50891600549221, 36.79833881556988, 36.411990746855736, 37.23656930029392, 35.38778990507126, 37.35906332731247, 36.98280371725559, 37.60474294424057, 40.002988055348396, 37.546727657318115, 36.49614863097668, 36.40743479132652, 37.28612244129181, 35.910942032933235, 36.185317710042, 36.20600380003452, 36.445588544011116, 35.541377663612366, 37.077065259218216, 38.58801618218422, 38.49555194377899, 38.13125029206276, 40.582943335175514, 37.07373283803463, 37.85265304148197, 36.505150347948074, 36.5959844738245, 34.16237846016884, 34.9792206287384, 37.32359983026981, 37.431434243917465, 38.88486385345459, 41.208461970090866, 45.05264349281788, 50.30398070812225, 51.09929323196411, 52.06501141190529, 50.16477897763252, 53.131796568632126, 52.25063145160675, 53.81304681301117, 46.78967088460922, 54.90192398428917, 51.53243198990822, 51.201161965727806, 28.579199351370335, 4.079329529777169, 0.5816610914189368, 3.5868310695514083, 5.774928219616413, 2.726091993972659, 0.044428422042983584, 2.4290455458685756, 42.52977266907692, 48.803247436881065, 43.64955358207226, 29.52260322868824, 29.090581610798836, 41.983031406998634, 49.154511988162994, 16.178863048553467, 0.15147970290854573, 0.033034985754056834, 0.1291101102833636, 0.0950398544955533, 0.008125123677018564, 0.053545517002930865, 0.02529737448639935, 0.09159748413367197, 0.06261301794438623, 0.013829521194566041, 0.015488814042328158, 0.09969245991669595, 0.05509239395905752, 0.013876675402570982, 0.10116921504959464, 0.02293885700055398, 0.05434265411167871, 0.040391494912910275, 0.024916945876611862, 0.01842212768679019, 0.0371286240988411, 0.030896884272806346, 0.026646949627320282, 0.0204196645427146, 0.02029126371780876, 0.05420438086730428, 0.044351568940328434, 0.0465134005935397, 0.06482026903540827, 7.6369408797472715, 44.54330362379551, 54.5161534845829, 34.79114972054958, 28.259543403983116, 36.28992609679699, 44.584615007042885, 52.87378281354904, 48.57625901699066, 9.749905373901129, 0.02580621134256944, 0.05732721954700537, 1.087832939811051, 2.8928593453019857, 5.151721760630608, 2.867874735966325, 7.536625787615776, 42.13845066726208, 54.1651701182127, 50.503029227256775, 49.067713245749474, 46.9885978102684, 43.360077515244484, 40.326939672231674, 39.74632702767849, 40.54530255496502, 40.1746666431427, 41.782371774315834, 41.64933331310749, 44.339269772171974, 42.03430965542793, 40.099483877420425, 40.71167662739754, 41.03739134967327, 39.137067720294, 38.91820326447487, 38.99142153561115, 36.74847789108753, 37.768027782440186, 37.8070592880249, 37.49023608863354, 36.894842237234116, 37.73321405053139, 37.311296090483665, 37.34217703342438, 38.18345569074154, 37.31079451739788, 38.56876641511917, 36.91419839859009, 38.53966377675533, 36.60188555717468, 40.446211472153664, 39.04779531061649, 39.4243361055851, 37.37945303320885, 37.63085514307022, 36.359621956944466, 40.258132964372635, 39.01870787143707, 37.69526928663254, 40.135593339800835, 50.18342837691307, 46.19704328477383, 47.606057077646255, 54.94255520403385, 50.537554174661636, 51.96806341409683, 53.588399067521095, 51.996269300580025, 48.98828610777855, 49.51723672449589, 51.74971953034401, 55.66982477903366, 41.88544124364853, 46.41913756728172, 49.673499539494514, 49.48900803923607, 47.28782795369625, 44.035529270768166, 42.134495079517365, 41.37786068022251, 42.807674556970596, 41.380642130970955, 39.49632704257965, 38.33218730986118, 37.51813419163227, 36.806303188204765, 37.827992364764214, 38.058229610323906, 37.64828860759735, 36.83088406920433, 39.11142289638519, 41.16221085190773, 40.59366635978222, 42.5595136731863, 39.41916078329086, 38.200474977493286, 40.291103795170784, 38.46523717045784, 37.11499102413654, 37.76844955980778, 39.28590953350067, 39.221316799521446, 37.82315142452717, 39.332707822322845, 40.73194473981857, 40.97179166972637, 39.84173230826855, 42.18475878238678, 39.67449568212032, 41.03661619126797, 39.50533255934715, 37.83345267176628, 37.00638525187969, 37.03664682805538, 39.25705388188362, 38.324659913778305, 40.74269816279411, 42.865940630435944, 47.69201226532459, 50.55999577045441, 54.769322499632835, 54.39834080636501, 52.11600087583065, 54.201910346746445, 55.00577241182327, 55.129307582974434, 47.94448971748352, 55.62676928937435, 54.62587259709835, 53.80369171500206, 31.260607168078423, 5.301882103085518, 1.3068031962029636, 4.929074132815003, 4.11183868534863, 1.413551343139261, 0.0850599052500911, 3.387738852761686, 48.86839494109154, 54.103347435593605, 49.920011311769485, 34.95198369026184, 34.3500541895628, 48.84755305945873, 57.594083324074745, 21.398447267711163, 0.23479893046896905, 0.0218875417340314, 0.04213513748254627, 0.016359719702450093, 0.02927982983237598, 0.024994205305119976, 0.07482468688976951, 0.041283296668552794, 0.08804332406725734, 0.021744913938164245, 0.06448125597671606, 0.035542598852771334, 0.019303941990074236, 0.0751188668073155, 0.15134099550778046, 0.17384816746925935, 0.20991397672332823, 0.11607867985730991, 0.14054467639653012, 0.07436974294250831, 0.092874178517377, 0.12448399953427725, 0.12527871353086084, 0.12510249798651785, 0.12730320333503187, 0.1719209286966361, 0.13848082307958975, 0.10163489045226015, 0.1732138093211688, 8.444191887974739, 51.950280368328094, 62.55957707762718, 42.117490991950035, 37.38231807947159, 35.59562735259533, 46.000343039631844, 57.456675097346306, 53.94584968686104, 12.60865157470107, 0.11583409766899422, 0.8668860176112503, 4.270575642585754, 5.298649426549673, 6.194703094661236, 3.7047852901741862, 8.613978177309036, 44.90736208856106, 57.124721109867096, 54.028305262327194, 53.71523626148701, 49.92240138351917, 45.77050097286701, 41.59517861902714, 41.80541753768921, 41.462835520505905, 43.25818978250027, 44.32973228394985, 42.78733804821968, 48.11981610953808, 43.9604377001524, 42.02374242246151, 42.04446651041508, 44.44963864982128, 42.173059210181236, 40.856270268559456, 40.78823111951351, 40.083163753151894, 39.9991312623024, 39.76020008325577, 40.855282321572304, 38.7229735404253, 40.152323842048645, 39.52767536044121, 38.385973423719406, 39.811786115169525, 38.389761820435524, 41.15826666355133, 39.46421876549721, 40.61416245996952, 38.33232790231705, 42.270162999629974, 40.54303027689457, 41.28385752439499, 40.27224160730839, 38.69190640747547, 38.78031246364117, 43.01444426178932, 41.75439387559891, 41.3013631850481, 42.3725713044405, 53.17488245666027, 48.19526106119156, 49.979968294501305, 49.95374210178852, 49.47022944688797, 56.60933576524258, 55.65197333693504, 56.035387963056564, 50.04937916994095, 51.79842531681061, 54.055583998560905, 59.63705129921436, 45.59726446866989, 49.30833913385868, 51.029494777321815, 51.73497632145882, 49.36818592250347, 45.85558220744133, 41.909858733415604, 42.99709439277649, 47.46472366154194, 43.59750397503376, 41.031820848584175, 39.735338017344475, 39.06531237065792, 39.05264005064964, 40.09443014860153, 40.96024788916111, 39.87860932946205, 38.74220430850983, 41.40547379851341, 41.98013976216316, 42.36660182476044, 45.34574456512928, 42.34689228236675, 39.714336544275284, 41.88367813825607, 40.599012672901154, 38.99990268051624, 40.21844409406185, 40.74514903128147, 41.62323631346226, 39.95824545621872, 40.519710928201675, 42.56041422486305, 42.59123057126999, 41.52416042983532, 46.342605873942375, 41.472817584872246, 43.89394886791706, 42.16717712581158, 41.213975474238396, 39.73888702690601, 39.35080245137215, 43.7928780913353, 39.88979212939739, 43.573481664061546, 45.43390363454819, 48.876093327999115, 54.62435647845268, 57.492491975426674, 55.34840002655983, 53.853130862116814, 56.32857263088226, 56.89830265939236, 56.36200703680515, 47.592165023088455, 56.19825102388859, 54.95059557259083, 53.932641595602036, 33.82872596383095, 6.677408767864108, 3.8084641518071294, 12.808490451425314, 15.981847420334816, 5.752605842426419, 0.1957949882489629, 3.3675077883526683, 53.09851035475731, 64.08101543784142, 58.466565907001495, 39.89646077156067, 41.249518766999245, 55.22153623402119, 66.10912621021271, 27.550339959561825, 0.7964625558815897, 0.13172794715501368, 0.25417777185793966, 0.17460213013691828, 0.09130196835030802, 0.1310765789821744, 0.19928213238017634, 0.2489195071393624, 0.1579493604367599, 0.06759791256627068, 0.0559934762713965, 0.19878385443007573, 0.2434589181211777], [0.07100484537659213, 0.028994067724852357, 0.030878132056386676, 0.071159486687975, 0.07185147260315716, 0.025377014353580307, 0.08629474250483327, 0.03627285361289978, 0.033388359370292164, 0.06325304610072635, 0.047931785811670125, 0.023277387663256377, 0.0993064911745023, 0.01552247415020247, 0.011618725420703413, 0.14432538446271792, 2.029538545757532, 28.69203619658947, 45.715278536081314, 47.706557884812355, 28.54000825434923, 22.35920861363411, 45.08337624371052, 51.01899594068527, 49.83181804418564, 22.493784092366695, 0.5921655090060085, 0.20188269205391407, 0.557010032935068, 2.5624326383695006, 4.839011840522289, 1.6691528214141726, 2.6327963126823306, 33.082810789346695, 52.95908063650131, 50.736652091145515, 48.30757923424244, 45.736204013228416, 43.387648835778236, 41.69000253081322, 42.467771396040916, 43.61557960510254, 44.07813258469105, 46.63300909101963, 45.19462667405605, 45.423226207494736, 44.02066066861153, 42.581598088145256, 42.29495286941528, 41.347671300172806, 39.72204253077507, 37.24636897444725, 37.6032230257988, 38.728886023163795, 35.27108296751976, 35.910634249448776, 34.35764238238335, 35.06235636770725, 35.255522802472115, 36.57744526863098, 34.90579716861248, 37.727860137820244, 36.41786143183708, 35.10341316461563, 37.202321738004684, 35.422174260020256, 36.42892263829708, 37.36817143857479, 36.5032010525465, 36.88082478940487, 35.80424755811691, 37.10078738629818, 36.62777736783028, 34.68810684978962, 35.83137430250645, 35.1362320035696, 40.46394892036915, 45.443239733576775, 53.82681727409363, 37.68830046057701, 38.33767421543598, 54.44554567337036, 51.2277377396822, 51.895802691578865, 49.76964198052883, 48.35527427494526, 47.395810559391975, 49.69388544559479, 51.372167989611626, 43.69449757039547, 47.1443210542202, 49.185168743133545, 48.73874209821224, 45.707751139998436, 42.21023641526699, 37.93513901531696, 38.966513872146606, 39.02385659515858, 41.853640750050545, 38.57667379081249, 37.066216841340065, 35.82321614027023, 37.30542540550232, 37.94452451169491, 35.85343211889267, 35.95230281352997, 36.690151020884514, 36.1387550085783, 35.29191344976425, 37.38375820219517, 36.85501277446747, 36.422390788793564, 37.460692673921585, 36.99114426970482, 36.861605420708656, 36.71076871454716, 37.22014658153057, 35.2993306517601, 37.31833331286907, 36.24686300754547, 35.83140090107918, 35.62949113547802, 35.18088720738888, 38.294166550040245, 35.09699150919914, 37.52055086195469, 38.31902861595154, 37.218847051262856, 36.4482332020998, 36.14172264933586, 36.604401022195816, 34.96617212891579, 36.17374733090401, 38.804528564214706, 41.364417001605034, 43.46184745430946, 48.29472832381725, 48.69288235902786, 53.117877915501595, 52.084800750017166, 49.326410964131355, 52.21865996718407, 53.407137393951416, 52.370834201574326, 52.038348242640495, 51.204368993639946, 46.26115344464779, 21.599123999476433, 2.872155918739736, 1.1567036504857242, 2.2270132368430495, 1.7571942158974707, 1.7282837047241628, 0.06069546790968161, 5.456178048625588, 41.76818333566189, 45.76909124851227, 38.83766658604145, 24.98252894729376, 31.542253755033016, 39.960213750600815, 43.996452167630196, 12.232741545885801, 0.08664088760269806, 0.06113664130680263, 0.011345253278705059, 0.012831893818656681, 0.052462070452747867, 0.022062306379666552, 0.05108482619107235, 0.05866948267794214, 0.017761243325367104, 0.047255232857423835, 0.1011113052663859, 0.005677178787664161, 0.03176992824592162, 0.009627102554077283, 0.01986482566280756, 0.05494962701050099, 0.027866159107361455, 0.08774549278314225, 0.03869808089802973, 0.05493374505022075, 0.05597887822659686, 0.05402115573815536, 0.024440932356810663, 0.04253757077094633, 0.02786809240205912, 0.08005503201275133, 0.03860578370222356, 0.05142147922015283, 0.013153956224414287, 2.8632491966709495, 35.9903159737587, 53.89859162271023, 50.17169080674648, 30.89796982705593, 24.62332282215357, 47.99205556511879, 54.95697163045406, 52.940321043133736, 21.841188110411167, 0.3032150905346498, 0.158969308831729, 1.333511013071984, 4.081336772069335, 6.697789449244738, 3.0883403308689594, 4.496402749791741, 35.680757984519005, 55.05414001643658, 54.09879148006439, 49.11738038063049, 47.40153685212135, 44.535555839538574, 43.807119727134705, 42.985060438513756, 45.335184931755066, 45.76118007302284, 47.737222239375114, 46.427098140120506, 46.988016441464424, 45.17562389373779, 44.34713914990425, 45.02865917980671, 42.82947778701782, 42.168032079935074, 38.615872487425804, 39.96993362903595, 39.82059024274349, 37.32951991260052, 38.791073486208916, 36.32874481379986, 35.84314987063408, 36.65263183414936, 37.729885429143906, 37.360286861658096, 38.48686181008816, 36.53212130069733, 38.04190568625927, 38.63379992544651, 37.152251824736595, 38.650636821985245, 39.308225736021996, 39.362976998090744, 38.03405150771141, 38.65041643381119, 39.02106374502182, 37.59710535407066, 36.51448264718056, 38.03206041455269, 36.73788405954838, 41.75272576510906, 46.712128445506096, 53.69633227586746, 38.11428040266037, 48.29616464674473, 57.79326103627682, 51.62938378751278, 54.04126636683941, 52.33797736465931, 48.535297214984894, 49.880178049206734, 51.994494795799255, 53.15198488533497, 45.02536855638027, 49.595140144228935, 50.825305134058, 52.10045590996742, 46.986378729343414, 43.02706338465214, 41.641380339860916, 42.15040482580662, 41.36502876877785, 44.28774453699589, 39.652802646160126, 39.97425019741058, 37.54761300981045, 38.08154135942459, 38.67008037865162, 37.735303938388824, 37.72743456065655, 39.86831188201904, 37.62042470276356, 36.96885086596012, 40.834299847483635, 40.64090542495251, 39.511955603957176, 39.30412195622921, 37.78667338192463, 39.069199562072754, 38.20891812443733, 39.320392683148384, 37.166493460536, 38.66003751754761, 37.44559608399868, 37.950319200754166, 37.03017957508564, 37.921170964837074, 40.42443484067917, 39.183714017271996, 40.093275010585785, 39.79268454015255, 39.219728484749794, 38.54777634143829, 38.501950800418854, 38.25795069336891, 37.04545095562935, 37.96274073421955, 40.11847525835037, 43.10666151344776, 45.334721356630325, 51.3548219203949, 51.345079243183136, 54.77501079440117, 53.671295419335365, 52.15451180934906, 52.91099801659584, 53.48563738167286, 54.00276683270931, 53.17044049501419, 51.54051795601845, 47.786205410957336, 24.70353651791811, 3.247717791236937, 3.0150268273428082, 2.7374823577702045, 4.269932052120566, 2.416798803023994, 0.08801293311989866, 4.77191124111414, 45.258512645959854, 53.0525404214859, 48.396243676543236, 29.089789353311062, 35.83046235144138, 44.724922478199005, 52.51973681151867, 16.398772448301315, 0.05703071670723148, 0.07042959186946973, 0.08609667071141303, 0.03346406214404851, 0.07072573105688207, 0.06166157720144838, 0.030069966633163858, 0.013440314833133016, 0.027458308140921872, 0.0072929599809867796, 0.0602050047746161, 0.0327883552381536, 0.053053747687954456, 0.09680608432972804, 0.15594600699841976, 0.12221540993778035, 0.20697786239907146, 0.14557091606548056, 0.1422700213151984, 0.19255652296124026, 0.0846401316812262, 0.11085957827162929, 0.159333243209403, 0.09641447526519187, 0.1580662783817388, 0.27508347819093615, 0.10306011085049249, 0.12672955286689103, 0.1647500752005726, 3.195869573391974, 40.59824891388416, 60.5856703966856, 57.8950347751379, 39.72666308283806, 31.71571634709835, 55.291456282138824, 59.37364183366299, 59.420082941651344, 28.40387675911188, 0.993448676308617, 0.5023631465155631, 4.262797459959984, 11.926428582519293, 14.708208963274956, 5.249344697222114, 4.357789512723684, 39.376793056726456, 56.53693825006485, 55.97722068428993, 51.62301152944565, 50.284191370010376, 46.573268696665764, 47.20143958926201, 46.02998524904251, 50.076464116573334, 47.81662277877331, 51.37827806174755, 47.84132145345211, 50.74845805764198, 47.3239716142416, 47.567743733525276, 46.594912335276604, 44.71194617450237, 43.43276381492615, 40.757851749658585, 42.33225166797638, 42.48112767934799, 39.55685779452324, 40.39714850485325, 38.71597811579704, 38.73362436890602, 37.643223479390144, 41.58034801483154, 38.90068240463734, 40.752980411052704, 38.67695800960064, 39.08111572265625, 41.12852565944195, 39.92359131574631, 40.459058582782745, 40.42996734380722, 40.23371547460556, 40.16134075820446, 39.856445118784904, 41.41542546451092, 39.53790061175823, 39.108474254608154, 39.90556128323078, 38.89517270028591, 43.87759454548359, 49.94348645210266, 58.44724774360657, 39.36698958277702, 49.04299937188625, 51.00205644965172, 53.444660380482674, 58.52176934480667, 54.61072281002998, 50.42636074125767, 51.12544722855091, 55.624576807022095, 56.177865117788315, 47.965475991368294, 52.499024122953415, 53.10046724975109, 54.5418781042099, 49.97433319687843, 45.507665276527405, 41.93668149411678, 44.090246334671974, 43.650013357400894, 48.592058569192886, 42.687319815158844, 42.32902184128761, 38.92845131456852, 40.02250760793686, 41.631405875086784, 39.51208099722862, 40.99355690181255, 40.28064675629139, 39.30081233382225, 40.27178183197975, 42.57441647350788, 42.08751440048218, 40.3767815977335, 42.13201001286507, 41.28950782120228, 40.21733075380325, 40.4592789709568, 40.092366859316826, 38.739134073257446, 39.99259941279888, 40.61431065201759, 39.23536464571953, 39.01836208999157, 39.292190596461296, 42.30007119476795, 39.59926351904869, 41.602808609604836, 43.22162054479122, 42.27658845484257, 41.610431000590324, 41.055170595645905, 41.97221338748932, 40.67188896238804, 41.15137383341789, 42.661690190434456, 46.54264993965626, 47.906256169080734, 53.08723635971546, 51.636926382780075, 57.635725289583206, 58.66290517151356, 56.361399069428444, 55.31780406832695, 55.765982419252396, 54.702727273106575, 55.60692675411701, 52.470837235450745, 50.4275880753994, 25.985010154545307, 4.556341208517551, 4.411845412105322, 6.534732123836875, 7.151468005031347, 3.834039866924286, 0.3361297555966303, 5.86100785061717, 54.7464819252491, 60.09998805820942, 52.869181260466576, 35.724284648895264, 44.81396310031414, 54.285654053092, 63.00183154642582, 21.755715496838093, 0.17423374287318438, 0.11125923963845707, 0.14452876261202618, 0.12358812338788994, 0.21207911835517734, 0.163523705850821, 0.1651463523739949, 0.12933385296491906, 0.14189394540153444, 0.13693550834432244, 0.20243872393621132, 0.08334403755725361, 0.15560690488200635], [0.009291338246839587, 0.05666650031344034, 0.13054051087237895, 0.04726983832370024, 0.025020358589245006, 0.03684183597215451, 0.01626269873668207, 0.04673995601478964, 0.01868071049102582, 0.14208678505383432, 0.038886449110577814, 0.09494747937424108, 0.06932958058314398, 0.017053067458618898, 0.02105819727148628, 0.037033310072729364, 0.7882390252780169, 15.801154766231775, 46.933394372463226, 47.00961448252201, 32.270072400569916, 33.86498361825943, 44.93354648351669, 48.33510495722294, 50.20835883915424, 36.59247346222401, 1.2874060682952404, 0.050670117780100554, 0.8530896704178303, 2.294555325061083, 2.879482638090849, 1.4818647899664938, 2.7755347033962607, 24.04707994312048, 54.421504363417625, 51.254841685295105, 50.16521215438843, 47.019771337509155, 46.137880459427834, 44.736713245511055, 46.32452644407749, 46.48942619562149, 49.309646263718605, 47.5930617749691, 49.815102741122246, 46.47601671516895, 45.35043351352215, 42.91004866361618, 44.84799787402153, 41.070529371500015, 42.14342080056667, 41.54785975813866, 42.860529720783234, 37.71975137293339, 36.97480894625187, 36.55829809606075, 36.59101814031601, 35.57523764669895, 36.69061839580536, 35.570267513394356, 36.18380919098854, 36.41458980739117, 35.560414642095566, 34.96038883924484, 35.86396135389805, 34.17977012693882, 35.0118912756443, 35.945653170347214, 37.715298011898994, 35.823679715394974, 36.24584846198559, 36.69580511748791, 37.22795516252518, 37.039933651685715, 35.22470265626907, 34.26659166812897, 43.23166720569134, 47.665352895855904, 47.06069514155388, 52.27714642882347, 34.687707871198654, 38.07041935622692, 54.6016450971365, 56.642846167087555, 48.71567353606224, 47.92810879647732, 49.3278206884861, 50.20064525306225, 48.15004728734493, 42.53785103559494, 49.8357280343771, 49.301028326153755, 47.53887668251991, 42.80234344303608, 41.404584646224976, 39.447161480784416, 39.2437431961298, 40.10153956711292, 40.73837399482727, 41.493492275476456, 37.06773675978184, 36.28500536084175, 35.81468939781189, 36.00193955004215, 37.05575220286846, 36.22334606945515, 37.935963571071625, 38.18315930664539, 37.29501776397228, 36.66643649339676, 37.42033503949642, 38.596869707107544, 37.11751028895378, 36.7225556820631, 36.42641097307205, 38.60791951417923, 35.41768670082092, 37.05704793334007, 37.150306329131126, 37.05898962914944, 37.09348037838936, 35.85381589829922, 35.26140868663788, 37.00103513896465, 37.312660217285156, 36.12491615116596, 33.996642753481865, 35.33392019569874, 35.25543160736561, 35.37671349942684, 36.193700060248375, 35.397999957203865, 39.23418290913105, 38.678747713565826, 40.81796072423458, 43.89180578291416, 44.67591270804405, 50.73692947626114, 51.65113382041454, 52.811846137046814, 52.44940258562565, 51.75634257495403, 52.30990447103977, 52.03027747571468, 51.47708036005497, 52.840428203344345, 41.746235713362694, 14.57107812166214, 1.784408474341035, 1.297786042559892, 1.6981241293251514, 3.3991581900045276, 1.2094141845591366, 0.1091760459530633, 5.611754525452852, 48.29968325793743, 45.52865535020828, 44.443209394812584, 22.29738973081112, 33.80250357091427, 45.639054626226425, 34.88851949572563, 7.343268888071179, 0.1036682711855974, 0.05053890236013103, 0.0899600911361631, 0.06112388007750269, 0.05564104147197213, 0.02222239134425763, 0.04045720837893896, 0.01984151665965328, 0.0683632300933823, 0.008549386311642593, 0.020301479380577803, 0.0378884794190526, 0.03181670210324228, 0.015213520855468232, 0.01729134139168309, 0.09114420259720646, 0.02261634188471362, 0.03726529801497236, 0.007336477201533853, 0.06628335380810313, 0.043961978517472744, 0.02772728472336894, 0.02239185520011233, 0.04126684696529992, 0.05746957831433974, 0.06728557229507715, 0.033654712460702285, 0.03461883279669564, 0.10559386981185526, 1.1316718999296427, 21.676373854279518, 53.397900089621544, 52.35104866325855, 35.55313043296337, 31.90275751054287, 49.12005923688412, 54.52445603907108, 55.4188634455204, 37.99093522131443, 1.3242463977076113, 0.10744545405032113, 0.9333775809500366, 6.247846568003297, 5.33267280086875, 3.7186046736314893, 4.467692915350199, 28.97722039371729, 54.176098331809044, 52.77616985142231, 51.39218531548977, 49.34703625738621, 46.08395375311375, 46.62456214427948, 47.71395228803158, 48.35938185453415, 49.68040756881237, 50.311390310525894, 50.38623109459877, 48.63653138279915, 45.591735765337944, 45.00445827841759, 46.09346084296703, 43.91820676624775, 42.52434276044369, 43.070666044950485, 42.75643810629845, 40.946420431137085, 38.602641597390175, 38.303521648049355, 36.867453306913376, 37.53435172140598, 37.696523219347, 37.48279228806496, 37.510830983519554, 37.18722514808178, 38.38422551751137, 37.907039523124695, 38.2254396378994, 36.249739453196526, 37.254177555441856, 37.94003315269947, 39.53568533062935, 37.854997515678406, 37.90882542729378, 39.006062150001526, 38.88191521167755, 36.849419474601746, 36.796587109565735, 35.674617514014244, 45.7498262822628, 46.893321722745895, 50.913566797971725, 51.84673972427845, 35.90365022420883, 46.99967421591282, 59.46679763495922, 55.29048353433609, 49.77447532117367, 50.11815927922726, 50.367053523659706, 50.94324320554733, 50.36182500422001, 46.09921753406525, 51.0223663598299, 48.89424115419388, 48.97854723036289, 46.44822880625725, 43.13907377421856, 40.38627728819847, 41.32569707930088, 42.045142874121666, 42.521758899092674, 43.331943824887276, 38.03446188569069, 38.32788974046707, 37.67670348286629, 38.2703722268343, 37.424351423978806, 37.74195738136768, 40.357459634542465, 39.17522147297859, 38.08273069560528, 38.48970405757427, 39.140441939234734, 39.27106373012066, 37.84773610532284, 37.62750372290611, 39.06617872416973, 38.980155140161514, 39.447442665696144, 38.98617401719093, 37.80695289373398, 38.09762589633465, 39.88204054534435, 37.35210970044136, 38.09332832694054, 38.52418340742588, 38.260895535349846, 37.87281475961208, 37.23118498921394, 37.51415580511093, 36.67123183608055, 37.32893854379654, 38.68278309702873, 38.72909501194954, 39.6338264644146, 41.39184772968292, 42.73038670420647, 46.03419542312622, 49.982145577669144, 53.808000683784485, 55.56100621819496, 54.8537577688694, 53.11083309352398, 54.364864602684975, 53.284141793847084, 51.70531891286373, 51.858560889959335, 52.79464825987816, 42.478034645318985, 17.053942792117596, 1.8859683559276164, 2.467263895086944, 3.811262701638043, 2.9680411610752344, 1.2746923067606986, 0.05238500212726649, 5.896681286394596, 51.80460758507252, 49.2887169867754, 48.575909435749054, 25.66328141838312, 40.96696972846985, 53.115263655781746, 45.0326793640852, 10.362794436514378, 0.021411394627648406, 0.10538240967434831, 0.1289626455400139, 0.04263441362127196, 0.011899742421519477, 0.016985196198220365, 0.0719505938468501, 0.01269336824407219, 0.010855936761799967, 0.02702530207898235, 0.030152380277286284, 0.06215940615220461, 0.038105409184936434, 0.10112384756212123, 0.14720076142111793, 0.3114277560962364, 0.17959792690817267, 0.1207969876122661, 0.0698939170979429, 0.19024183857254684, 0.17139229690656066, 0.10650590251316316, 0.21274127735523507, 0.0690265468438156, 0.18471059709554538, 0.15439013892319053, 0.07971192229888402, 0.16120231244713068, 0.13536243728594854, 1.147974687628448, 25.491937212646008, 64.00967046618462, 59.38151881098747, 44.12732474505901, 42.875656709074974, 57.8884307295084, 60.90668477118015, 58.27689528465271, 43.33930782973766, 1.7106495634652674, 0.25620805041398853, 2.654963848181069, 5.5377525463700294, 12.562193367630243, 7.656134124845266, 6.070046508684754, 29.962049648165703, 58.42474155128002, 55.98052270710468, 55.27935393154621, 51.45442597568035, 49.294853657484055, 48.338745161890984, 51.374603658914566, 49.63681250810623, 54.03700299561024, 53.0148084461689, 53.93788531422615, 49.59525793790817, 47.79609628021717, 46.672887951135635, 48.55745002627373, 45.50400987267494, 47.45332047343254, 45.070475935935974, 47.36119821667671, 42.838775888085365, 40.39871022105217, 41.049398705363274, 38.977787867188454, 39.830891489982605, 42.07181364297867, 39.839011654257774, 39.31747443974018, 39.12398502230644, 38.30861337482929, 37.58990854024887, 40.3986494243145, 37.48809680342674, 38.052225932478905, 39.391198083758354, 41.617008447647095, 39.54180300235748, 39.45808969438076, 40.43314777314663, 41.345835998654366, 38.515029698610306, 38.42202968895435, 36.82572394609451, 49.658304154872894, 50.170763656497, 52.31963574886322, 54.14717048406601, 40.01838482916355, 48.88010211288929, 55.0454156845808, 56.73093684017658, 54.36473160982132, 53.9115185290575, 53.373444601893425, 52.84775801002979, 50.83192437887192, 49.38945338129997, 55.052156522870064, 53.49239341914654, 51.03506147861481, 48.45224887132645, 45.2164489030838, 44.38338540494442, 44.2005468159914, 44.4097787886858, 45.297650545835495, 46.78786218166351, 40.43489947915077, 39.82690930366516, 39.84707482159138, 40.49194201827049, 39.07421909272671, 40.490296706557274, 43.711190074682236, 42.86663219332695, 41.02686211466789, 42.030479460954666, 42.48483628034592, 42.17640683054924, 40.34754976630211, 40.108504593372345, 40.70406183600426, 40.67555196583271, 39.62106674909592, 42.40877576172352, 39.85012985765934, 40.07121339440346, 42.31916517019272, 38.42491373419762, 38.87341506779194, 40.40489248931408, 39.560156017541885, 40.022196024656296, 37.82752878963947, 39.37051199376583, 38.729520589113235, 39.01784911751747, 40.614200457930565, 40.44696383178234, 43.67621295154095, 43.61104644834995, 44.808426797389984, 48.65611933171749, 50.78007236123085, 56.23612739145756, 57.02942602336407, 55.82084767520428, 55.449231415987015, 55.42864792048931, 55.96172131597996, 54.20078560709953, 52.29065090417862, 54.3807515501976, 45.21546855568886, 18.88212349265814, 2.990567539818585, 5.627073403447866, 6.8461752869188786, 9.90268662571907, 4.852968016639352, 0.12007329714833759, 6.4285477716475725, 57.038093358278275, 56.24389037489891, 58.14163014292717, 33.19041721522808, 46.91205471754074, 58.565265610814095, 53.3748809248209, 13.386571481823921, 0.17676097835646942, 0.2566177456174046, 0.27060975262429565, 0.19902808038750663, 0.21590545366052538, 0.11139313050080091, 0.15048978180857375, 0.0962184443778824, 0.09093105036299676, 0.08279113753815182, 0.18856931972550228, 0.17931988870259374, 0.1797093084314838], [0.019744655255635735, 0.03386383112228941, 0.021749184998043347, 0.03244893028750084, 0.0320929925510427, 0.046638997955597006, 0.09924262194545008, 0.08887219912139699, 0.0010443692281114636, 0.027843002244480886, 0.07010018220171332, 0.024609739411971532, 0.053341170350904576, 0.012996625555388164, 0.015920663281576708, 0.09997964880312793, 0.07807164976838976, 8.990967348217964, 45.3557076305151, 45.443600714206696, 31.69677436351776, 27.075437642633915, 46.877784356474876, 49.81142833828926, 51.235067546367645, 41.648778542876244, 6.571684665977955, 0.0884178934211377, 0.5128013645298779, 3.112143441103399, 3.9439226081594825, 2.5912065943703055, 2.483598981052637, 20.151574574410915, 50.25746740400791, 51.55251771211624, 51.626465544104576, 48.96988369524479, 49.71388757228851, 46.77732154726982, 46.67764909565449, 48.6863961070776, 50.54230771958828, 49.08271484076977, 50.5131670832634, 48.122042790055275, 48.33632089197636, 47.25087113678455, 44.55550856888294, 44.63474951684475, 46.59264765679836, 43.28996367752552, 41.36266529560089, 41.902050152421, 40.290195643901825, 38.51875349879265, 37.229000106453896, 36.810254976153374, 37.19635985791683, 35.08173532783985, 35.92633880674839, 35.604712665081024, 36.64026729762554, 36.196238324046135, 36.16877719759941, 36.619964987039566, 36.27259522676468, 37.97532945871353, 37.932387962937355, 35.362927839159966, 36.24961405992508, 37.125934436917305, 38.101311698555946, 34.986964613199234, 35.11806897819042, 38.02684709429741, 45.54663598537445, 49.538963958621025, 48.02402704954147, 46.96627780795097, 48.39929111301899, 34.273492097854614, 34.77716267108917, 47.97804191708565, 56.773977130651474, 50.18065832555294, 49.03404325246811, 52.351326048374176, 51.32408156991005, 42.319548949599266, 48.05362746119499, 48.761434480547905, 48.78901720046997, 43.86538580060005, 40.23737087845802, 37.46908262372017, 39.375558122992516, 40.54766222834587, 40.86521878838539, 40.9871656447649, 37.734961956739426, 36.38346567749977, 35.68362683057785, 35.02087019383907, 36.69887535274029, 37.1777256578207, 37.65461526811123, 35.0141179561615, 36.406279653310776, 36.90266601741314, 34.33365046977997, 37.08590738475323, 36.77416831254959, 37.064852714538574, 36.12362802028656, 37.85392977297306, 37.64725886285305, 37.0328888297081, 37.00155571103096, 37.41904690861702, 36.532805263996124, 36.79923936724663, 33.95521357655525, 35.38054749369621, 37.08412528038025, 36.31655506789684, 34.65669393539429, 34.707045033574104, 34.649994894862175, 34.79475572705269, 34.38939347863197, 36.46320819854736, 37.929747104644775, 42.06391766667366, 43.137029483914375, 43.69086496531963, 47.727293372154236, 49.18224290013313, 49.932797625660896, 51.044165790081024, 53.12036678195, 50.805990770459175, 52.500867024064064, 54.95531491935253, 52.91555777192116, 49.54127423465252, 36.72762081027031, 10.65758641809225, 0.7503642013762146, 1.9217680161818862, 1.4192359568551183, 1.4027739339508116, 0.8387851598672569, 0.1348179383785464, 8.02569754421711, 47.19119153916836, 42.40528754889965, 40.6293236464262, 32.2052288800478, 37.37072870135307, 43.23707811534405, 32.804202139377594, 3.9515117509290576, 0.1513590000104159, 0.013653313071699813, 0.05646381978294812, 0.0375141178665217, 0.04496617111726664, 0.05989169228996616, 0.012254132780071814, 0.060006168569088914, 0.020646854500228073, 0.07107716024620458, 0.07070950770867057, 0.02021097818214912, 0.0489490179461427, 0.03490105671517085, 0.030112827516859397, 0.043191714576096274, 0.0738644294324331, 0.05717439649743028, 0.06264355732128024, 0.04676082149671856, 0.03931197432393674, 0.006760812266293215, 0.08339109714142978, 0.01827431970014004, 0.06837613604147919, 0.04495607419812586, 0.06205979880178347, 0.01524742308902205, 0.05997428219416179, 0.14495726383756846, 11.722704414278269, 56.52760975062847, 51.65857382118702, 40.315483286976814, 31.637134663760662, 52.19649575650692, 54.79865312576294, 54.749282374978065, 45.699338391423225, 5.946412067860365, 0.04261388210579753, 0.6368349026888609, 4.163339696824551, 5.187348648905754, 2.6974132703617215, 3.741393950767815, 22.529789060354233, 53.604897782206535, 52.169479206204414, 53.006289303302765, 50.39555199444294, 51.10319562256336, 47.551150023937225, 49.458947852253914, 49.30571347475052, 52.01406754553318, 50.01846022903919, 52.086883038282394, 50.38628429174423, 49.23490047454834, 48.42357560992241, 46.50107257068157, 45.37840761244297, 47.44972966611385, 44.56530064344406, 44.47230823338032, 44.195876866579056, 42.1457576751709, 40.026318803429604, 38.76828990876675, 39.11713019013405, 38.14378201961517, 37.421425580978394, 37.51544773578644, 37.45436601340771, 38.06119345128536, 38.922865614295006, 37.95378841459751, 38.96370582282543, 37.79631346464157, 39.916189312934875, 39.852261543273926, 37.321278154850006, 37.84931682050228, 39.49028916656971, 39.59067218005657, 38.53078745305538, 35.66507242619991, 37.09598824381828, 48.139837235212326, 52.79690533876419, 49.95076306164265, 49.7865054756403, 50.60962490737438, 35.222130194306374, 41.54991924762726, 55.33204950392246, 58.238927721977234, 50.15064373612404, 50.955926924943924, 51.73561468720436, 52.09824062883854, 44.89973209798336, 50.4208130389452, 51.57578006386757, 51.057225689291954, 43.66498835384846, 42.34801322221756, 40.5843036621809, 41.02306231856346, 42.80254863202572, 43.36733512580395, 43.84935446083546, 40.04379026591778, 36.898125261068344, 38.45134511590004, 37.92010322213173, 37.82308682799339, 39.41625773906708, 38.264505341649055, 36.518905609846115, 38.96624408662319, 38.22189062833786, 36.826875284314156, 39.05086934566498, 37.85578027367592, 38.634111508727074, 37.94446751475334, 38.281912207603455, 38.83197449147701, 39.5753476023674, 37.85197287797928, 38.36894653737545, 37.55470722913742, 38.72285954654217, 36.73895940184593, 36.451668217778206, 38.58936510980129, 39.39044192433357, 36.882314309477806, 36.932357624173164, 35.954556092619896, 36.345961689949036, 36.11140787601471, 39.333308190107346, 40.712687373161316, 43.142945766448975, 44.42844718694687, 46.45125724375248, 49.01387773454189, 51.218466237187386, 52.32283517718315, 52.72408604621887, 53.903322368860245, 54.31976482272148, 53.48402626812458, 54.31063391268253, 53.68522547185421, 48.8185416162014, 40.19158713519573, 13.034749310463667, 1.6366453282535076, 3.64503872115165, 3.293670625425875, 4.17983366176486, 1.0224163625389338, 0.009662597622082103, 8.000073619186878, 51.57268323004246, 49.27770137786865, 44.15698975324631, 28.599837943911552, 40.44468015432358, 47.83358506858349, 41.45945370197296, 5.287650916725397, 0.02860497454094002, 0.016617385954305064, 0.08723059072508477, 0.07740437737083994, 0.007691811479162425, 0.005455665332192439, 0.04590403055772185, 0.04609089592122473, 0.031032825318106916, 0.041729223521542735, 0.02713263704208657, 0.012068626474501798, 0.05491375159181189, 0.11966609556111507, 0.08669812945299782, 0.22227253153687343, 0.2686820091912523, 0.13814268575515598, 0.19973836024291813, 0.15840560314245522, 0.17995157511904836, 0.11683458695188165, 0.1825962183647789, 0.11185670562554151, 0.08996429911348969, 0.1466028278809972, 0.14486652886262164, 0.1296645391266793, 0.22365402459399775, 0.20115440769586712, 14.588220901787281, 63.044263869524, 56.61417290568352, 43.62796314060688, 36.95208616554737, 59.95094485580921, 61.069316044449806, 60.61646394431591, 50.08956201374531, 8.368009775876999, 0.1262845314340666, 2.652048454619944, 12.503413371741772, 10.572564080357552, 7.861911607906222, 3.9427945436909795, 25.58755148202181, 53.30275319516659, 54.16263185441494, 56.88917174935341, 53.344752341508865, 54.21281956136227, 50.35979971289635, 52.102807983756065, 52.29560203850269, 53.53177070617676, 53.107664063572884, 53.69248688220978, 51.744407415390015, 52.18290388584137, 50.247952714562416, 48.36136154830456, 47.59209282696247, 50.510651618242264, 47.25263424217701, 45.601083263754845, 47.11023688316345, 45.42318820953369, 41.92072995007038, 41.47999919950962, 41.36709585785866, 40.29078461229801, 39.02272045612335, 39.513566717505455, 38.18018026649952, 39.36280220746994, 39.89824287593365, 40.08540563285351, 41.36940233409405, 40.16439579427242, 42.66569897532463, 42.809019684791565, 38.3986609429121, 39.88377705216408, 40.53441993892193, 42.83732816576958, 38.642277270555496, 37.89850898087025, 40.30944161117077, 50.17606437206268, 54.28872808814049, 51.715639159083366, 51.18964858353138, 52.27119594812393, 38.80979888141155, 44.5894293487072, 51.17052800953388, 54.979439824819565, 53.39042969048023, 55.43728865683079, 56.008428409695625, 55.12955076992512, 45.530783236026764, 51.6165366768837, 52.19246797263622, 53.83577719330788, 47.06798695027828, 45.90353563427925, 42.02767141163349, 42.85446524620056, 46.321931183338165, 46.307944133877754, 45.68706505000591, 41.64007321000099, 39.580222740769386, 41.35837912559509, 37.609017714858055, 39.726180508732796, 41.732636243104935, 42.45610602200031, 38.346740528941154, 41.97475165128708, 41.529841125011444, 37.81952641904354, 41.833558827638626, 40.325157567858696, 41.111578568816185, 38.80913771688938, 42.47645393013954, 40.29768504202366, 41.71474300324917, 40.35764202475548, 41.39766521751881, 39.45399731397629, 40.33958539366722, 37.79204249382019, 38.94568718969822, 40.27257598936558, 42.07208342850208, 38.931517750024796, 38.3683917671442, 38.625022396445274, 39.84850734472275, 37.701227366924286, 42.21455678343773, 44.46206018328667, 45.30754141509533, 47.48086519539356, 48.04614946246147, 51.0946536809206, 52.92440749704838, 52.424650713801384, 55.40075361728668, 57.987024039030075, 55.58800756931305, 56.42313055694103, 56.98449723422527, 55.213834047317505, 50.148789435625076, 42.96767637133598, 14.379886630922556, 2.3162526357918978, 6.831478625535965, 6.772847771644592, 7.182384096086025, 5.198061699047685, 0.26651351305190474, 9.563835058361292, 57.98586130142212, 55.50585977733135, 54.65726651251316, 41.28456048667431, 51.440400928258896, 53.936259001493454, 51.6288860142231, 7.093387171626091, 0.3124796168413013, 0.06709430599585176, 0.20772391377249733, 0.14801433339016512, 0.10879406254389323, 0.13870689610484987, 0.1668527873698622, 0.1219617215974722, 0.16484846913954243, 0.1990588498301804, 0.21178959170356393, 0.08517864145687781, 0.10061228516860865], [0.019226029471610673, 0.0472173721936997, 0.03873277630191296, 0.04034265788504854, 0.006504111270260182, 0.051841746317222714, 0.012428676636773162, 0.06556851716595702, 0.04528541707259137, 0.053917711484245956, 0.058629377017496154, 0.0242301178877824, 0.04851031590078492, 0.06892404140671715, 0.04212062849546783, 0.17984841659199446, 0.14732651092344895, 5.8538613840937614, 31.630648411810398, 46.40318222343922, 31.98482170701027, 28.7013665959239, 40.59226043522358, 44.51304964721203, 49.063727259635925, 46.46504670381546, 10.52287319675088, 0.04314337478717789, 0.13210118806455284, 6.305330358445644, 3.629614873789251, 1.885389480739832, 2.668590391986072, 16.039952002465725, 49.12688747048378, 48.28460946679115, 51.93282030522823, 48.52849557995796, 48.568328842520714, 46.83188281953335, 50.11594399809837, 47.79839515686035, 51.25402852892876, 51.63417533040047, 51.51537850499153, 48.12126763164997, 48.85092347860336, 47.37650379538536, 46.48266635835171, 45.15341028571129, 46.702241376042366, 44.765929877758026, 46.21156990528107, 42.8183101862669, 43.529198840260506, 40.761548951268196, 40.502345860004425, 40.38622409105301, 38.730892315506935, 35.326054617762566, 37.7556062489748, 38.50751370191574, 37.59387172758579, 35.95827989280224, 36.19405344128609, 37.50739976763725, 35.56948475539684, 35.79554222524166, 37.00051836669445, 37.564537301659584, 36.66160695254803, 36.41720026731491, 38.166010826826096, 36.881094574928284, 34.61388923227787, 40.612596943974495, 51.647508814930916, 48.92319180071354, 51.468329429626465, 46.80622659623623, 48.61041158437729, 49.219237715005875, 41.224641501903534, 32.706368789076805, 43.24582904577255, 54.20892097055912, 51.92161850631237, 49.854651018977165, 51.35572627186775, 42.54421949386597, 46.93074211478233, 48.671189323067665, 50.23891679942608, 42.589452266693115, 39.1877494007349, 39.15097497403622, 39.81615208089352, 41.881861835718155, 43.68628241121769, 42.31365166604519, 42.99668401479721, 36.58512085676193, 34.64241050183773, 34.940162524580956, 35.853857696056366, 37.78882026672363, 35.988803654909134, 35.38827247917652, 38.1835962831974, 36.464959904551506, 38.06770250201225, 37.49838285148144, 36.571179404854774, 37.19954028725624, 37.31606863439083, 38.05277690291405, 36.87472231686115, 36.69155314564705, 36.928508430719376, 36.89997956156731, 36.921999379992485, 35.71403279900551, 37.131637930870056, 37.07085259258747, 36.71760454773903, 35.28926499187946, 35.52916891872883, 34.13263365626335, 33.53440895676613, 34.53174144029617, 37.059495002031326, 37.36459583044052, 38.82552623748779, 41.9535031914711, 44.72918584942818, 47.07105338573456, 48.037877306342125, 50.4337627440691, 51.21260695159435, 51.21848903596401, 51.15774169564247, 50.17319552600384, 50.55456966161728, 51.25111408531666, 52.297995910048485, 48.81266713142395, 27.118153050541878, 3.758371202275157, 1.3016234803944826, 1.3651696080341935, 1.9433006295002997, 1.6557371662929654, 0.17282888700719923, 0.035667557967826724, 11.705467589199543, 53.6894166469574, 41.380102559924126, 34.64780241250992, 25.461413450539112, 39.283675253391266, 50.87530665099621, 28.917687088251114, 0.8019464928656816, 0.07828469810192473, 0.017781876886147074, 0.009656252259446774, 0.08126554908812977, 0.08526156903826632, 0.0068315171392896445, 0.02376287098741159, 0.024479377461830154, 0.0352816263330169, 0.012118963568354957, 0.022747113871446345, 0.06267719145398587, 0.038526845164597034, 0.08026392431929708, 0.0650769704952836, 0.0676577519334387, 0.04770963503688108, 0.019996137561975047, 0.06919723338796757, 0.024813310519675724, 0.04211247229250148, 0.053198318055365235, 0.05275177150906529, 0.018470959148544353, 0.024382119008805603, 0.057125333114527166, 0.024647082427691203, 0.04495071589190047, 0.07648302329471335, 0.07792373973643407, 7.0735793095082045, 41.604849100112915, 51.838984340429306, 36.3150579482317, 30.753474980592728, 46.63010984659195, 51.20783820748329, 54.82937067747116, 51.924700140953064, 12.064650915563107, 0.1046673058590386, 0.4302157647907734, 4.3169602286070585, 8.519908525049686, 3.7397491140291095, 3.8602520478889346, 20.343194492161274, 49.786649867892265, 51.691525653004646, 53.552726581692696, 51.18201859295368, 51.64940111339092, 49.3087001144886, 49.81770560145378, 49.72657509148121, 52.774703130126, 53.109484165906906, 53.56316842138767, 51.51074655354023, 50.145084634423256, 48.18177558481693, 49.201701655983925, 47.838976979255676, 46.817842572927475, 45.44491544365883, 47.643059492111206, 45.463770031929016, 44.954650551080704, 43.638043999671936, 41.914635077118874, 42.11199648678303, 41.653874069452286, 37.741888985037804, 40.197685807943344, 38.38843949139118, 39.140624329447746, 37.23052762448788, 37.48057700693607, 38.717034459114075, 37.89073459804058, 38.38650919497013, 39.34881895780563, 38.381546661257744, 37.65532203018665, 37.72247202694416, 38.7745975703001, 38.589118123054504, 37.45766423642635, 42.12676629424095, 52.23828211426735, 50.36902941763401, 53.21090832352638, 47.078880965709686, 49.838957861065865, 50.26382826268673, 39.904767125844955, 35.23482911288738, 50.51824741065502, 57.712044194340706, 52.529981061816216, 50.755388885736465, 54.47769574820995, 43.912852853536606, 49.44051884114742, 51.296130269765854, 51.36350065469742, 44.2635702341795, 41.05346828699112, 41.241193413734436, 42.39808313548565, 42.18692846596241, 45.92351496219635, 44.03047554194927, 45.56670270860195, 38.63513745367527, 37.1548280864954, 38.559893891215324, 36.88521735370159, 38.85716333985329, 38.934766575694084, 37.11886681616306, 38.211270198225975, 38.06004971265793, 39.606547728180885, 38.66367392241955, 38.26404556632042, 38.67599666118622, 38.71942453086376, 38.4509689360857, 38.70145529508591, 37.38216608762741, 38.31676013767719, 39.46389578282833, 38.47569800913334, 39.05957467854023, 39.07375171780586, 38.547932133078575, 39.81347322463989, 38.383784741163254, 36.237777695059776, 36.11823230981827, 36.508649960160255, 35.63936300575733, 38.94743509590626, 39.14014555513859, 42.09959015250206, 44.70570310950279, 46.007950231432915, 49.789761900901794, 51.5818939357996, 51.12304575741291, 53.01481984555721, 53.63277688622475, 51.747238263487816, 52.22248636186123, 53.635501340031624, 51.6207430511713, 53.059824630618095, 49.9669273942709, 29.5464925467968, 6.012768857181072, 2.2254199348390102, 3.6524530733004212, 3.703954084776342, 3.230235166847706, 0.8748971752356738, 0.07937054921058007, 12.302586548030376, 57.69159749150276, 47.01374866068363, 44.11894239485264, 31.14202693104744, 43.803612515330315, 55.62524177134037, 35.754633620381355, 1.4616517745889723, 0.09038839940330945, 0.0538459717790829, 0.06272738290135749, 0.0676663608464878, 0.04311010430683382, 0.008513380089425482, 0.0030340300418174593, 0.021611004522128496, 0.033218266544281505, 0.036282015425967984, 0.03084233085246524, 0.04679280064010527, 0.0365435445564799, 0.09932163840858266, 0.12400509163853712, 0.12494964525103569, 0.13179683330236003, 0.10655977501301095, 0.18047567980829626, 0.11038459633709863, 0.13140659721102566, 0.10573875188129023, 0.1064064101956319, 0.1636846479959786, 0.1397721006651409, 0.13468015124090016, 0.1349452612339519, 0.23751247470499948, 0.40430949709843844, 0.28220411797519773, 8.940863236784935, 49.456762969493866, 59.68932509422302, 42.82032407820225, 37.834630608558655, 52.37058341503143, 56.222189739346504, 58.57023574411869, 56.731461212038994, 14.940190315246582, 0.153056321432814, 1.267392779700458, 15.540370009839535, 11.267933417111635, 6.773743573576212, 4.554394762963057, 22.169327102601528, 54.880200549960136, 51.86911292374134, 52.82918460667133, 53.312233686447144, 53.50385740399361, 49.64984580874443, 53.839265406131744, 51.579173281788826, 54.75230321288109, 54.79315482079983, 53.492879793047905, 52.756999880075455, 52.49110534787178, 49.65943269431591, 51.776093915104866, 49.446609914302826, 50.12912929058075, 47.58958116173744, 49.58741895854473, 46.47036261856556, 49.3704392015934, 45.58779537677765, 44.56623159348965, 44.395035579800606, 44.36893478035927, 38.939303532242775, 42.78310887515545, 42.463500425219536, 40.26395425200462, 38.96185152232647, 39.03310149908066, 41.340767070651054, 39.30631063878536, 40.36269195377827, 41.18527941405773, 40.601714327931404, 40.43971002101898, 38.98904286324978, 42.365990057587624, 41.690583899617195, 38.89689400792122, 44.32379700243473, 55.383897721767426, 52.66404926776886, 55.57746693491936, 50.03144793212414, 51.34696774184704, 51.95407256484032, 42.34105199575424, 38.31369750201702, 48.2168211042881, 54.17806662619114, 52.530228048563, 55.518904477357864, 55.287238508462906, 47.0937267690897, 50.62316358089447, 52.08581529557705, 54.07577611505985, 46.86112605035305, 43.46760034561157, 42.841321751475334, 44.105912894010544, 44.16542150080204, 47.59174324572086, 46.65398396551609, 47.48594552278519, 41.23596869409084, 37.567402347922325, 40.23882620036602, 39.87833954393864, 40.68992659449577, 40.570818185806274, 39.63373526930809, 42.598396986722946, 41.51468373835087, 42.74528570473194, 41.337294057011604, 40.28586767613888, 42.04385854303837, 41.496741101145744, 40.81012934446335, 39.554881900548935, 40.556181371212006, 41.88972361385822, 40.8437879383564, 40.892919301986694, 39.900332763791084, 40.788542702794075, 40.12923628091812, 41.52025043964386, 41.88536524772644, 38.96372102200985, 37.01560355722904, 38.00777591764927, 38.482169061899185, 41.76628343760967, 42.741911485791206, 43.47709983587265, 46.480169892311096, 48.34599517285824, 52.762718573212624, 54.19562168419361, 53.50244767963886, 54.69425372779369, 53.93473148345947, 53.87675419449806, 50.68071909248829, 52.53938555717468, 50.48953615128994, 54.894529581069946, 50.233357697725296, 30.708399899303913, 5.925975339487195, 2.883501397445798, 5.242288950830698, 10.232123248279095, 6.874327501282096, 2.065817336551845, 0.1839164100238122, 14.04528133571148, 64.33051005005836, 51.975731402635574, 49.43245567381382, 36.88537694513798, 54.09083090722561, 62.652611285448074, 44.354088976979256, 2.8069369308650494, 0.21668130968464538, 0.18354291678406298, 0.1181739334424492, 0.14869457110762596, 0.2034596964949742, 0.15336275420850143, 0.1170046797778923, 0.12919694156153128, 0.12747846893034875, 0.15241995948599651, 0.15717506292276084, 0.11441255832323804, 0.08825972690829076], [0.05004060214560013, 0.020040519848407712, 0.028684072640317027, 0.048903242277447134, 0.025136903605016414, 0.06112238464993425, 0.03178340193699114, 0.08715550764463842, 0.05188015988096595, 0.017278869599977043, 0.024688993362360634, 0.08418895784416236, 0.05052874235843774, 0.036086422405787744, 0.07305776685825549, 0.0294681906234473, 0.048844660850591026, 2.278145905584097, 27.936524637043476, 51.960338428616524, 36.78337901830673, 32.664590030908585, 41.76195926964283, 39.88844320178032, 46.323162317276, 48.99866335093975, 20.14593567699194, 0.14984421723056585, 0.2470819346490316, 1.2329457281157374, 5.852127727121115, 3.1154252775013447, 1.516324665863067, 12.528398931026459, 49.26394231617451, 47.62780711054802, 51.971008256077766, 51.47192783653736, 50.58572418987751, 48.99026960134506, 50.87560683488846, 49.10763390362263, 49.83926184475422, 51.19450472295284, 50.4879592359066, 48.80944110453129, 47.034639939665794, 49.04881685972214, 47.326547876000404, 47.598784267902374, 46.38378046452999, 46.94394260644913, 47.73473337292671, 45.836207047104836, 44.9189742654562, 42.86855109035969, 43.33216421306133, 43.862163573503494, 43.33063669502735, 38.39130833745003, 36.88797600567341, 38.24768364429474, 37.136456072330475, 37.789747416973114, 35.13510346412659, 35.624608397483826, 36.14097788929939, 36.96742594242096, 37.953328639268875, 35.17590947449207, 35.3757331520319, 36.76360867917538, 36.68258182704449, 36.444053426384926, 34.719926342368126, 39.92585979402065, 50.52261337637901, 50.68005032837391, 50.18966764211655, 50.695139318704605, 52.75873638689518, 48.529080748558044, 51.02436125278473, 46.4045425504446, 38.25534023344517, 43.5748115926981, 52.868056520819664, 52.04037353396416, 49.73853684961796, 42.19722591340542, 48.667279332876205, 49.653983786702156, 47.86100819706917, 43.397277519106865, 40.74087806046009, 40.78605003654957, 41.53842866420746, 43.745696023106575, 44.26483556628227, 44.616301506757736, 44.02690373361111, 36.795591562986374, 35.788539201021194, 36.411800757050514, 37.69615463912487, 36.9852089881897, 36.52573384344578, 36.38098441064358, 35.122214555740356, 35.767058953642845, 37.456490099430084, 38.09455566108227, 35.531471595168114, 35.42606145143509, 37.67003484070301, 37.48566873371601, 37.83806562423706, 35.84381103515625, 36.74252361059189, 36.77538804709911, 36.3088870793581, 37.39097401499748, 38.86499471962452, 37.28223145008087, 38.41559283435345, 37.49345451593399, 34.01080459356308, 34.84772488474846, 34.72657598555088, 33.16292569041252, 35.45436233282089, 39.519448801875114, 42.55449794232845, 46.59188769757748, 47.57766880095005, 48.43776024878025, 48.56820724904537, 49.694637805223465, 49.400928765535355, 50.19704684615135, 50.83092503249645, 53.113394156098366, 52.791540026664734, 51.89455255866051, 52.4137756973505, 43.143751323223114, 22.025335729122162, 2.3993786377832294, 0.9004094218835235, 2.2674188436940312, 2.088169399648905, 2.457866524346173, 0.7068785035517067, 0.1574533386155963, 14.96569074690342, 53.43797653913498, 45.44719912111759, 30.203587487339973, 25.183655954897404, 39.55950245261192, 48.26299622654915, 23.330086916685104, 0.5754481279291213, 0.07825220687664114, 0.04577671512379311, 0.03998625630629249, 0.050935357648995705, 0.05172673198103439, 0.06140775527455844, 0.020461417771002743, 0.10246524238027632, 0.020793630901607685, 0.017741869560268242, 0.022707427524437662, 0.05994454804749694, 0.06825588585343212, 0.03391923615708947, 0.006363554994095466, 0.07095967826899141, 0.1051152587751858, 0.02397619577095611, 0.034101785931852646, 0.012405519773892593, 0.05307890649419278, 0.05598625517450273, 0.07143066002754495, 0.030201287809177302, 0.07519535254687071, 0.024694110470591113, 0.1102543345768936, 0.009465784696658375, 0.03937870824302081, 0.0925468913919758, 3.65213792771101, 32.970431819558144, 57.75992542505264, 40.51925115287304, 34.249515384435654, 44.32725101709366, 46.6718278080225, 52.44393087923527, 55.07839031517506, 19.66859769076109, 0.18271034583449364, 0.2579046000028029, 2.048099124804139, 5.750410510227084, 5.096078021451831, 2.0685467775911093, 14.253656454384327, 50.383635833859444, 49.92883063852787, 54.34347555041313, 53.29654812812805, 52.91045844554901, 50.1894586533308, 51.96358725428581, 49.96321879327297, 51.31055809557438, 52.15685248374939, 52.01526828110218, 50.59850290417671, 48.79572004079819, 50.52301235496998, 48.02697189152241, 49.326874539256096, 49.15826238691807, 47.86725126206875, 49.21458676457405, 48.514588326215744, 47.142284363508224, 44.23464238643646, 46.513304114341736, 44.6720939129591, 43.44408340752125, 40.44142372906208, 38.60231101512909, 40.34274682402611, 40.045648366212845, 39.36632841825485, 36.02775156497955, 37.80351407825947, 38.171668723225594, 38.368007987737656, 39.04547743499279, 36.61014251410961, 36.3587062060833, 38.9202855527401, 38.312002792954445, 38.9692497253418, 35.587605983018875, 40.72084553539753, 52.713541612029076, 50.82520633935928, 51.49094581604004, 52.464225590229034, 55.70781894028187, 48.117676824331284, 52.834390327334404, 45.582905039191246, 38.111582547426224, 50.641167014837265, 56.30995362997055, 52.71465115249157, 50.808529034256935, 43.49785432219505, 49.995798245072365, 50.970119163393974, 48.25871005654335, 46.718952879309654, 43.34017038345337, 42.744784131646156, 44.32615287601948, 44.89749401807785, 46.4860063791275, 46.37876473367214, 47.609108313918114, 39.322820752859116, 37.44428515434265, 37.53824271261692, 38.2781808078289, 38.966916650533676, 37.47203506529331, 37.26483978331089, 38.05992051959038, 37.52172499895096, 40.226112082600594, 39.960403740406036, 36.94806218147278, 36.42009571194649, 39.464412555098534, 39.032679721713066, 38.895374089479446, 36.320484057068825, 38.20427097380161, 38.7055666744709, 37.09606043994427, 39.5544259250164, 40.19913353025913, 40.29273010790348, 39.18948970735073, 39.03163477778435, 37.60549530386925, 35.72790205478668, 36.59972347319126, 35.92518746852875, 38.533842489123344, 41.45921051502228, 44.888906478881836, 48.81094962358475, 50.73156416416168, 50.73730185627937, 50.90739592909813, 52.65327304601669, 50.77169381082058, 51.60120069980621, 51.7803230881691, 51.17880396544933, 53.48487362265587, 52.537930235266685, 53.46400894224644, 44.64670367538929, 24.810107499361038, 2.8879034612327814, 2.9986207326874137, 5.2931012492626905, 5.070069842040539, 4.432899607345462, 1.0171640943735838, 0.05068729107733816, 16.108260937035084, 57.215711027383804, 50.888913720846176, 36.95972375571728, 29.846820831298828, 44.659486189484596, 54.725864231586456, 27.414096370339394, 0.8495645283255726, 0.0271693251124816, 0.0054800184443593025, 0.049292235271423124, 0.013212029280111892, 0.027366300382709596, 0.04493937216466293, 0.004633451053450699, 0.07566337313619442, 0.030925982027838472, 0.08511126186931506, 0.0868436275050044, 0.012378814517433057, 0.021823761562700383, 0.1244225942355115, 0.11512958430103026, 0.19506389857269824, 0.2032577432692051, 0.08737023323192261, 0.19715423171874136, 0.12810828513465822, 0.23546435491880402, 0.09334116009995341, 0.11986938465270214, 0.1928301082807593, 0.11732625978766009, 0.16565484227612615, 0.16791103058494627, 0.2019414256210439, 0.1047878603276331, 0.1771868226933293, 4.390802616253495, 40.812724605202675, 65.36227628588676, 48.7034609913826, 43.50994527339935, 52.28642553091049, 51.86141453683376, 58.03236700594425, 59.33546528220177, 24.177274256944656, 0.3725703642703593, 0.6027393322438002, 4.843769185245037, 14.098964855074883, 6.498164311051369, 3.3056373707950115, 17.47709758579731, 51.50809429585934, 52.43096597492695, 54.399473145604134, 55.00102646648884, 54.666351824998856, 52.42382615804672, 53.7720812112093, 52.911336198449135, 52.57107585668564, 54.40054848790169, 52.89231821894646, 52.3123287409544, 50.175517201423645, 53.293447494506836, 50.6811560690403, 50.780779123306274, 51.1737160384655, 50.26960775256157, 51.299192905426025, 50.75971305370331, 48.97661693394184, 45.78890338540077, 48.72169241309166, 47.776257544755936, 46.46946966648102, 41.59287974238396, 40.793892815709114, 43.34989406168461, 40.22307224571705, 40.413799211382866, 38.81202556192875, 40.447731390595436, 39.95254956185818, 39.499914050102234, 41.99000023305416, 39.44023825228214, 38.78602355718613, 40.24053990840912, 40.193262845277786, 41.17000803351402, 37.921607941389084, 42.38492824137211, 54.304512441158295, 53.174354285001755, 52.672507613897324, 54.91162486374378, 57.076304107904434, 50.39092764258385, 55.87030582129955, 46.91000282764435, 41.578539311885834, 52.12038964033127, 52.82387249171734, 53.399420008063316, 53.81421335041523, 46.531277149915695, 54.97657097876072, 53.26574698090553, 52.04250141978264, 48.81679370999336, 46.04492224752903, 44.291335344314575, 45.67250423133373, 46.709392592310905, 47.576395869255066, 48.62693689763546, 48.39211329817772, 40.93107685446739, 38.80099095404148, 38.77257227897644, 42.13678255677223, 40.61398766934872, 38.7113955616951, 39.35896061360836, 40.8856350928545, 39.34415280818939, 42.40002483129501, 43.06671425700188, 38.550143614411354, 38.35601583123207, 40.8908636122942, 41.197716146707535, 41.89795397222042, 38.082643300294876, 40.050132125616074, 40.449574291706085, 39.70903962850571, 41.85855768620968, 41.72398790717125, 41.692016422748566, 40.627123564481735, 41.95729158818722, 38.96627828478813, 38.241755962371826, 38.22893925011158, 37.432969361543655, 39.64036591351032, 44.291779920458794, 46.47217512130737, 51.83313645422459, 52.189777716994286, 53.38974192738533, 52.751186192035675, 54.9973064661026, 52.66279153525829, 53.55705074965954, 54.10631887614727, 54.654234275221825, 54.67322565615177, 53.14744032919407, 53.70813064277172, 46.04267276823521, 27.269244343042374, 3.850636901333928, 3.3293754095211625, 7.006280645728111, 9.210978392511606, 8.214439116418362, 2.9414471006020904, 0.2541413175640628, 18.852082304656506, 64.1459159553051, 57.32590891420841, 41.9488750398159, 37.46506243944168, 52.11160451173782, 59.677123948931694, 32.167333513498306, 1.2769134063273668, 0.1475698166177608, 0.09097972040763125, 0.16107681527500972, 0.11400430288631469, 0.22169206815306097, 0.18314319604542106, 0.10156026008189656, 0.2544023754308, 0.10203476704191417, 0.22592964232899249, 0.11790780670708045, 0.14165806118398905, 0.15294740383978933], [0.0931621392373927, 0.06550657009938732, 0.011341226199874654, 0.04076307712239213, 0.029193523623689543, 0.09259985105018131, 0.03594859816075768, 0.017620381840970367, 0.012334345028648386, 0.03897943279298488, 0.07694106941926293, 0.04584147121931892, 0.0023062241371007985, 0.004443821653694613, 0.04998270349460654, 0.040386251639574766, 0.023539081921626348, 0.7690469082444906, 18.89354567974806, 47.540841177105904, 45.111517533659935, 33.335170447826385, 26.192906498908997, 39.44023825228214, 45.18735006451607, 48.57214763760567, 28.132288232445717, 1.1284902831539512, 0.15069213579408824, 1.5138793783262372, 5.049423649907112, 4.236886650323868, 2.0090488577261567, 14.2508246563375, 44.115191996097565, 48.34078185260296, 48.765105083584785, 52.02904634177685, 49.732384979724884, 49.26350153982639, 49.356748536229134, 49.99696858227253, 48.58499474823475, 49.848502948880196, 51.177417039871216, 49.52765956521034, 48.27556595206261, 47.95182712376118, 47.149891555309296, 48.91908802092075, 45.60911223292351, 49.005879163742065, 48.786011561751366, 47.16330483555794, 47.10112117230892, 47.26436421275139, 46.44268870353699, 45.11170752346516, 43.15584607422352, 43.83002869784832, 40.238153636455536, 37.73583970963955, 37.83975653350353, 36.06634609401226, 35.24361804127693, 36.470051631331444, 36.259231343865395, 37.274035289883614, 38.63414950668812, 35.82282856106758, 34.86363083124161, 38.12216877937317, 37.08406828343868, 36.902586221694946, 34.65662553906441, 36.917884200811386, 47.32008822262287, 52.21668787300587, 50.350235626101494, 46.44444040954113, 48.455934673547745, 52.48229742050171, 50.81204004585743, 46.81006819009781, 50.813381373882294, 39.10408169031143, 43.17514143884182, 56.21843174099922, 52.03379228711128, 42.642223834991455, 49.71166089177132, 50.621632263064384, 47.67095759510994, 43.21994483470917, 41.27698749303818, 41.95112831890583, 43.517415672540665, 43.808681443333626, 47.82123193144798, 44.12232421338558, 43.17047528922558, 37.72161707282066, 37.08739310503006, 36.10314331948757, 35.237857550382614, 34.73929390311241, 36.62595346570015, 34.9211635440588, 36.95878140628338, 36.76001027226448, 35.84081679582596, 36.430495753884315, 37.469869181513786, 36.29836544394493, 37.348640486598015, 37.124562710523605, 34.75416250526905, 37.007563188672066, 36.7423602193594, 40.87161764502525, 43.73711608350277, 42.03127361834049, 44.89334084093571, 44.625022038817406, 43.789610266685486, 41.445504650473595, 34.6627926081419, 33.93807269632816, 34.96147558093071, 35.35662017762661, 34.668423905968666, 37.57226228713989, 44.77635271847248, 48.581913113594055, 48.99598449468613, 50.36101944744587, 53.00664268434048, 49.92211639881134, 50.18519148230553, 53.07240195572376, 48.97524520754814, 53.324309438467026, 55.17162211239338, 50.47365680336952, 51.726536974310875, 39.05374959111214, 15.554615445435047, 1.1049794009886682, 3.161223982460797, 3.506427383981645, 3.0820383690297604, 2.030350989662111, 0.29537955473642796, 0.1504602443310432, 14.28211122751236, 47.04839900135994, 40.24220421910286, 32.699430361390114, 25.73277398943901, 40.322516709566116, 43.76219093799591, 14.203843977302313, 0.08277785309473984, 0.10928081494057551, 0.0773042171203997, 0.029154724143154453, 0.02138679428753676, 0.0864150446432177, 0.08278036897536367, 0.02948794288386125, 0.02555949176894501, 0.024761900094745215, 0.01870097483333666, 0.03500532104226295, 0.015518601994699566, 0.05957157802185975, 0.03915297660569195, 0.04681110571254976, 0.047594594725524075, 0.016529645545233507, 0.05641838921292219, 0.12253043678356335, 0.07508052003686316, 0.043671390594681725, 0.019381514975975733, 0.04661307102651335, 0.023711421599728055, 0.007300560500880238, 0.0494274879747536, 0.01429609552360489, 0.04604984031175263, 0.0376970832439838, 0.007512387073802529, 1.2528704339638352, 25.976439714431763, 56.23167023062706, 47.23248012363911, 39.442924708127975, 34.63057793676853, 48.356778994202614, 51.41567185521126, 54.68763068318367, 30.210725404322147, 1.065369970165193, 0.25884686037898064, 1.2843010411597788, 6.007305700331926, 4.5093591045588255, 1.6711975866928697, 15.59741634875536, 47.53039173781872, 50.25209069252014, 50.493183955550194, 53.44792440533638, 51.90864220261574, 52.69155219197273, 52.14463233947754, 51.28391772508621, 50.86978554725647, 52.33986206352711, 51.41126409173012, 51.55372604727745, 50.516328513622284, 50.076395720243454, 48.445386439561844, 52.079139053821564, 47.3274028301239, 49.996296018362045, 51.21054366230965, 50.10702207684517, 49.407042637467384, 48.10124650597572, 48.4707310795784, 46.887454837560654, 44.94793251156807, 46.46717458963394, 40.58564119040966, 40.26142738759518, 38.64011138677597, 38.67674142122269, 36.61675035953522, 37.65646576881409, 36.687475964426994, 40.239422768354416, 37.853557392954826, 38.093465119600296, 37.23656550049782, 38.97979415953159, 37.01619632542133, 38.35872508585453, 35.68448178470135, 40.60318484902382, 49.261016473174095, 53.162658512592316, 50.81268601119518, 46.73886001110077, 51.053805872797966, 54.00436274707317, 51.209111139178276, 49.06287990510464, 51.098069697618484, 40.53630843758583, 50.862398743629456, 57.18555964529514, 51.83974429965019, 44.14220854640007, 50.79294987022877, 51.780836060643196, 49.28501598536968, 44.87675093114376, 42.364234551787376, 42.69202396273613, 44.45897474884987, 46.72955051064491, 49.725834131240845, 45.99633425474167, 44.346071407198906, 40.8839213848114, 37.91522428393364, 37.828189954161644, 36.70054346323013, 39.06499698758125, 38.95530827343464, 36.08059152960777, 38.1884828209877, 39.57534000277519, 38.169594034552574, 38.3293716609478, 39.041407853364944, 39.241132736206055, 39.963093996047974, 37.3986230045557, 37.795108929276466, 39.963325783610344, 37.026873752474785, 41.76353998482227, 44.0172104537487, 45.239844247698784, 46.55042052268982, 45.80577068030834, 44.143105298280716, 41.73582807183266, 36.540214866399765, 35.328463688492775, 38.260131776332855, 35.930605977773666, 36.85141056776047, 39.845513105392456, 47.16314144432545, 51.35495111346245, 52.29182504117489, 52.49694183468819, 54.1183490306139, 51.2580943107605, 53.151570707559586, 52.85430885851383, 50.810193344950676, 53.06089237332344, 55.58171130716801, 51.583022475242615, 52.03810505568981, 41.97268836200237, 18.222828470170498, 1.7647854960523546, 3.5100132040679455, 5.180077739059925, 6.011927677318454, 2.980211195535958, 1.7201649653725326, 0.08153318980475888, 16.437646262347698, 54.02116924524307, 46.881443560123444, 35.950456112623215, 29.733873791992664, 47.65630938112736, 50.35544514656067, 18.428861014544964, 0.12609241908648983, 0.08717513002920896, 0.003749112984223757, 0.036419335010577925, 0.10009166857344098, 0.05037480979808606, 0.030188725104380865, 0.02298383114975877, 0.02258417720440775, 0.03453006451309193, 0.015348056458606152, 0.07410555321257561, 0.033132978933281265, 0.07253646748722531, 0.1393541824654676, 0.12064423877745867, 0.18591085769003257, 0.1489266406861134, 0.18093901744578034, 0.21963836741633713, 0.16225533094257116, 0.13880548300221562, 0.12676409241976216, 0.1577820655074902, 0.1581128704128787, 0.10323025562684052, 0.10293954896042123, 0.10304905285011046, 0.15522202709689736, 0.11992726475000381, 0.13902870618039742, 1.3778247102163732, 31.289601512253284, 63.97435516119003, 53.70088443160057, 46.23427368700504, 37.093142196536064, 52.61530168354511, 54.783446341753006, 59.95157562196255, 35.27664206922054, 1.8036900646984577, 0.6528472434729338, 6.799823949113488, 13.442255593836308, 9.586418196558952, 4.596163546666503, 18.53218127042055, 49.41205836832523, 53.034620583057404, 51.607873141765594, 55.86598165333271, 54.31082770228386, 53.2436815649271, 53.41217592358589, 53.5817988216877, 51.93100020289421, 54.45282608270645, 53.14666137099266, 52.38808527588844, 52.84791760146618, 50.584056079387665, 51.22265741229057, 51.922788843512535, 48.242420330643654, 51.892656460404396, 52.63083145022392, 50.76602831482887, 51.89862973988056, 50.17311193048954, 52.409789711236954, 49.334766715765, 47.43044950067997, 48.334527388215065, 44.02128383517265, 42.73471087217331, 40.36164700984955, 39.60417665541172, 38.96674185991287, 39.72700886428356, 39.01211142539978, 41.73069454729557, 40.444007590413094, 38.70456352829933, 37.47594125568867, 42.01487369835377, 39.01473708450794, 40.52811987698078, 37.790640369057655, 42.76816047728062, 51.412985399365425, 56.75728462636471, 53.99235159158707, 49.276778027415276, 53.27161006629467, 56.146771386265755, 52.46167212724686, 53.81703659892082, 50.31785376369953, 41.02536499500275, 51.61592870950699, 53.129961267113686, 53.1673588603735, 49.4848320633173, 54.880268946290016, 55.20446754992008, 49.84172411262989, 47.708434984087944, 46.08360797166824, 45.41158743202686, 47.039142698049545, 48.74945752322674, 52.75668069720268, 48.55597950518131, 46.9970865547657, 42.10623599588871, 40.84403492510319, 40.40610082447529, 37.72245682775974, 39.54778388142586, 39.64674957096577, 38.230934143066406, 40.43103888630867, 41.44453950226307, 40.235349386930466, 40.29938355088234, 40.316752418875694, 41.16914927959442, 42.15327367186546, 40.72605885565281, 38.466209918260574, 42.02569551765919, 39.56360623240471, 46.12566411495209, 48.265694081783295, 48.1114299595356, 49.48164023458958, 49.35375429689884, 46.672792956233025, 43.92517179250717, 39.753029868006706, 37.45073340833187, 39.61561784148216, 37.02435448765755, 37.923367246985435, 41.30180776119232, 48.87628331780434, 53.1598162651062, 53.421363830566406, 54.66664060950279, 56.80236540734768, 54.571493715047836, 53.724933341145515, 54.85057353973389, 52.645513862371445, 55.29929906129837, 57.947217375040054, 53.45682352781296, 54.75661978125572, 43.476305678486824, 20.960549265146255, 2.2054360946640372, 7.764019360765815, 8.837599027901888, 9.104660097509623, 10.254712086170912, 2.8208883572369814, 0.2599392127012834, 18.00527684390545, 58.29107992351055, 54.32837516069412, 45.05870036780834, 37.44303502142429, 53.325551971793175, 59.077797308564186, 22.453967928886414, 0.3249878331553191, 0.25537230307236314, 0.11862760089570656, 0.15611346520017833, 0.36694423179142177, 0.13823542452882975, 0.12477328127715737, 0.1623157417634502, 0.1499871103442274, 0.09276963959564455, 0.07558652374427766, 0.21522552764508873, 0.12063197849784046, 0.16071478079538792], [0.013302339375513839, 0.05185641115531325, 0.04296311453799717, 0.049618249613558874, 0.04958611090842169, 0.030704912933288142, 0.0465587272628909, 0.05734688646043651, 0.08936709287809208, 0.019282059765828308, 0.02516579541406827, 0.03233343726606108, 0.0527596048777923, 0.028259998325665947, 0.07159753193263896, 0.06803935684729367, 0.030362011020770296, 0.45334613299928606, 14.325184766203165, 45.67849650979042, 50.55186800658703, 30.867489762604237, 29.357842169702053, 35.343590676784515, 38.64684842526913, 46.56169451773167, 39.790606051683426, 3.4373639523983, 0.10044252630905248, 0.7748889760114253, 2.878900319337845, 4.523842977359891, 0.3482253081165254, 7.460424201563001, 37.820867747068405, 48.86421136558056, 46.705079823732376, 49.75389562547207, 49.33397255837917, 48.06953340768814, 49.5851618796587, 50.73854438960552, 51.53540723025799, 50.663969591259956, 49.944561794400215, 50.493400543928146, 48.69020730257034, 48.49542215466499, 49.37676586210728, 46.95917218923569, 48.93368303775787, 48.69554981589317, 48.73730197548866, 50.17553240060806, 48.64775598049164, 47.727027386426926, 45.99340841174126, 48.454038575291634, 46.9943393021822, 43.92138719558716, 41.525828540325165, 39.94672067463398, 36.753258034586906, 37.13079817593098, 35.842572301626205, 36.42474666237831, 35.42870230972767, 39.545089825987816, 37.83719927072525, 35.501563400030136, 34.14664350450039, 38.0331015586853, 37.76929311454296, 36.682418435812, 36.063382253050804, 36.78685583174229, 40.54003983736038, 45.718116983771324, 44.16888691484928, 47.39593215286732, 46.945819705724716, 47.70006403326988, 53.12876433134079, 47.60010279715061, 44.50009994208813, 53.63124176859856, 34.61207672953606, 52.78626970946789, 56.438268944621086, 43.69214549660683, 49.6139757335186, 50.64237155020237, 47.2989347577095, 42.2502900660038, 41.03748254477978, 42.151388972997665, 43.087738528847694, 45.107846930623055, 49.670053124427795, 47.641592770814896, 43.80303114652634, 38.50597098469734, 34.366644099354744, 37.17526338994503, 35.03408208489418, 36.23127244412899, 35.249313935637474, 36.48508362472057, 34.56411950290203, 37.522321566939354, 37.05014370381832, 36.92515321075916, 36.29581198096275, 36.875109896063805, 37.54086837172508, 34.97292056679726, 35.48314578831196, 36.38916917145252, 41.215780377388, 46.63871258497238, 49.65106554329395, 48.2939987629652, 47.52769008278847, 50.18487609922886, 48.35096150636673, 48.739122077822685, 42.746463641524315, 37.96057865023613, 34.349864199757576, 35.47866962850094, 34.43956598639488, 34.94653478264809, 40.922983288764954, 50.50646424293518, 50.76975591480732, 49.43641126155853, 47.68760070204735, 53.88851456344128, 49.569286331534386, 52.07003854215145, 51.866019889712334, 49.461554512381554, 52.74252645671368, 52.86429092288017, 53.24663020670414, 38.9208859205246, 11.044034231454134, 1.0422324179671705, 1.8165663862600923, 5.256713451817632, 3.5058377031236887, 2.0269879326224327, 1.0165342781692743, 0.06522194904391654, 15.627220999449492, 48.285760805010796, 39.73162181675434, 30.032932944595814, 31.318926438689232, 45.022412315011024, 37.648436799645424, 6.624855687841773, 0.10751166846603155, 0.021427640240290202, 0.06410816349671222, 0.03389169134607073, 0.0469230846647406, 0.035365069707040675, 0.08101944549707696, 0.04662458173697814, 0.029872880040784366, 0.010417738449177705, 0.1392467343248427, 0.04534562751359772, 0.09035035691340454, 0.03546189400367439, 0.01971115285414271, 0.01092899563445826, 0.03818241071712691, 0.04258570646925364, 0.008449099896097323, 0.05901000229641795, 0.015391050001198892, 0.025747325635165907, 0.03832442809653003, 0.022823406652605627, 0.04036947910208255, 0.017524763534311205, 0.06344443114358, 0.02282110413943883, 0.031102002758416347, 0.07924701872980222, 0.01917016059451271, 0.5775206198450178, 19.112869910895824, 52.263729348778725, 55.554937943816185, 35.089600905776024, 33.63490216434002, 42.77225285768509, 45.83711139857769, 51.5992172062397, 42.60697692632675, 3.579202266409993, 0.2870815125061199, 1.1794242938049138, 5.031766472384334, 4.0447138622403145, 2.2457540687173605, 10.175941362977028, 41.04730881750584, 51.15557201206684, 48.58688324689865, 49.26990419626236, 51.231362745165825, 50.07946975529194, 50.62863148748875, 51.226183623075485, 52.04569324851036, 52.409671917557716, 50.69791316986084, 51.897311210632324, 50.19416280090809, 51.47443950176239, 50.06634905934334, 48.79675358533859, 48.15649934113026, 50.03135293722153, 51.4365441352129, 51.158182471990585, 49.14949245750904, 49.46619026362896, 48.35167206823826, 49.15407121181488, 47.12092570960522, 44.81618978083134, 44.05482843518257, 40.561060309410095, 37.30174720287323, 38.37077423930168, 36.28937132656574, 38.40012386441231, 37.37767092883587, 40.56079052388668, 38.81651312112808, 36.211878284811974, 37.40746513009071, 39.197503477334976, 41.37333892285824, 37.21215181052685, 37.46100805699825, 37.68262356519699, 43.52471888065338, 45.83105832338333, 47.35300965607166, 48.18962976336479, 50.56893669068813, 50.09716160595417, 53.630641400814056, 49.02599148452282, 49.8677147179842, 50.898815989494324, 39.883028492331505, 58.12918201088905, 55.6011738628149, 46.36716775596142, 49.703932106494904, 53.44712644815445, 48.27875778079033, 44.79827754199505, 42.948358207941055, 43.64879362285137, 43.928245827555656, 47.55985155701637, 50.60371622443199, 49.6216931194067, 46.55159465968609, 39.96703818440437, 36.81656263768673, 37.680286690592766, 37.20043323934078, 37.209731340408325, 36.97013899683952, 39.48551282286644, 37.44748458266258, 40.34571446478367, 38.54935705661774, 38.887808695435524, 37.86007784307003, 38.88286896049976, 39.34873916208744, 38.02371606230736, 37.85620965063572, 38.87519717216492, 42.66542539000511, 48.85299816727638, 50.71018651127815, 51.189488992094994, 49.92768310010433, 50.65108448266983, 51.982609033584595, 50.429453775286674, 43.36710713803768, 39.780924171209335, 36.813017427921295, 37.2768547385931, 36.78806036710739, 37.975280061364174, 45.2652382850647, 53.68539646267891, 52.63459324836731, 50.18166147172451, 50.071284994482994, 53.32931376993656, 52.54055209457874, 53.60968552529812, 55.41876085102558, 52.42004536092281, 54.738357961177826, 54.02127183973789, 54.49126482009888, 40.15482410788536, 13.627071026712656, 1.6090071550570428, 3.384153745137155, 4.8801626823842525, 9.497233182191849, 4.283243687823415, 1.375499947462231, 0.13306286302395165, 17.226696722209454, 53.338938653469086, 47.904884442687035, 34.67725843191147, 35.297677740454674, 49.93542708456516, 46.959118992090225, 8.847596291452646, 0.013511181587091414, 0.07456774794263765, 0.05736997467465699, 0.05170029297005385, 0.05184841822483577, 0.10009957986767404, 0.08283012255560607, 0.022443992929765955, 0.021108561268192716, 0.029654286008735653, 0.16899959795409814, 0.027821854746434838, 0.016466915512864944, 0.07188171512098052, 0.18093014135956764, 0.12894818850327283, 0.07679773843847215, 0.140299218473956, 0.09273061747080646, 0.13715013745240867, 0.13122137199388817, 0.14251498942030594, 0.19585446396376938, 0.08605845010606572, 0.1074158497794997, 0.147066937352065, 0.09856732693151571, 0.07701615992118604, 0.1519619207829237, 0.1671903012902476, 0.15891317278146744, 0.7550243544392288, 22.325099743902683, 61.64449878036976, 60.840948298573494, 41.37431167066097, 38.26354779303074, 47.120864912867546, 51.13064534962177, 57.65822008252144, 48.00592102110386, 4.419939452782273, 0.5447268357966095, 3.4264827612787485, 10.779994949698448, 11.971863694489002, 1.5381059283390641, 10.50366522744298, 42.036274150013924, 51.79175667464733, 50.15587605535984, 51.47682577371597, 52.957195937633514, 51.567656099796295, 53.79082180559635, 53.18754717707634, 54.9330785125494, 54.15677256882191, 53.66236589848995, 54.27409887313843, 52.24769040942192, 53.84575165808201, 52.082699462771416, 49.681372717022896, 52.47502461075783, 50.14147862792015, 54.0756431221962, 54.537534937262535, 52.10627719759941, 50.529878586530685, 49.22188997268677, 52.16210380196571, 51.69175364077091, 46.0248289257288, 45.76518125832081, 42.97010064125061, 39.370549991726875, 41.060144528746605, 40.19374921917915, 40.649496763944626, 38.772918060421944, 43.2160272449255, 41.94865845143795, 37.093932554125786, 39.66788783669472, 40.892721712589264, 41.108766719698906, 39.438627138733864, 39.41204756498337, 39.485919401049614, 45.12635953724384, 48.11030521988869, 49.71683621406555, 50.35880796611309, 52.80553087592125, 51.47416591644287, 57.969563975930214, 50.381792932748795, 51.566694751381874, 55.53961716592312, 40.8601650595665, 57.23956234753132, 52.45708577334881, 50.74378430843353, 52.5299658626318, 55.13689957559109, 50.20662613213062, 47.84282237291336, 45.08883275091648, 46.6799745708704, 47.308069467544556, 49.878832921385765, 52.788735777139664, 50.158581510186195, 47.637382596731186, 42.155040577054024, 38.80566470324993, 38.750339671969414, 40.251658111810684, 39.31803300976753, 38.45344640314579, 41.602645218372345, 38.182954117655754, 41.309038773179054, 41.88808590173721, 41.275372579693794, 39.84943829476833, 41.39417700469494, 41.29599027335644, 39.32096645236015, 38.756780326366425, 40.53802974522114, 46.2092824280262, 51.7922430485487, 52.675167471170425, 52.48330436646938, 51.88573323190212, 53.88017401099205, 54.19730119407177, 53.86281654238701, 47.07441620528698, 41.424195393919945, 39.064210429787636, 38.11142675578594, 38.2439636439085, 38.61112654209137, 44.905712977051735, 55.56950256228447, 55.286501348018646, 51.3210379332304, 50.63082776963711, 56.7630261182785, 55.152881518006325, 55.64101092517376, 57.118443846702576, 53.80704313516617, 56.546897515654564, 56.94101616740227, 55.30192092061043, 43.00184413790703, 15.769496764987707, 2.1557760844007134, 5.250012511387467, 13.153084460645914, 12.212632074952126, 9.034850243479013, 3.5713492752984166, 0.23554737155791372, 18.899581655859947, 60.62526427209377, 49.78672966361046, 41.82691678404808, 43.33620719611645, 58.08773763477802, 55.76309837400913, 11.979642827063799, 0.14651736215455458, 0.16949805401964113, 0.2668974408879876, 0.14259862946346402, 0.38494125357829034, 0.2145957262837328, 0.283860947820358, 0.12477078766096383, 0.16487799177411944, 0.10695075325202197, 0.3728004597360268, 0.10467040803632699, 0.28269464790355414, 0.22889553161803633], [0.037531153866439126, 0.025787108461372554, 0.021313310535333585, 0.030377605398825835, 0.016250206535914913, 0.0368615585466614, 0.03298628602351528, 0.023741534241707996, 0.06474652182077989, 0.03404968716495205, 0.01700263295788318, 0.039881813863758, 0.006047579126970959, 0.07200171297881752, 0.025785316174733452, 0.008943413849920034, 0.05664099269779399, 0.08000894464203157, 7.097221165895462, 39.42795351147652, 49.98173899948597, 31.16444382816553, 21.43461372703314, 29.696185514330864, 43.958249017596245, 50.77697552740574, 41.977620497345924, 5.311580132693052, 0.27435341267846525, 0.43767909868620336, 3.4169808961451054, 2.1017455961555243, 1.4322041859850287, 5.004238374531269, 33.819488659501076, 48.254579678177834, 46.708362847566605, 49.02270846068859, 50.06137512624264, 50.1285707205534, 48.456740230321884, 50.371248498559, 50.511605367064476, 49.43164251744747, 50.324742794036865, 49.77030694484711, 49.57489863038063, 46.85286149382591, 49.07387271523476, 48.79616841673851, 46.98730207979679, 49.89610679447651, 48.75783607363701, 49.73873823881149, 47.3031335324049, 50.69200448691845, 49.29095886647701, 50.68974360823631, 46.96294158697128, 46.92759968340397, 41.50310955941677, 38.362494483590126, 36.963109374046326, 36.53101935982704, 35.113672614097595, 36.798517405986786, 36.381744369864464, 36.87265142798424, 36.19109719991684, 36.21969826519489, 34.8941545933485, 37.55423225462437, 37.634126767516136, 35.985064655542374, 36.19361266493797, 37.46814027428627, 36.94982148706913, 38.502243384718895, 38.26950587332249, 39.55455131828785, 41.40163220465183, 49.09952133893967, 46.50671146810055, 52.14861072599888, 43.26839983463287, 49.291080459952354, 45.55399999022484, 36.756282672286034, 59.375123754143715, 39.76178079843521, 50.04978574812412, 49.32450346648693, 48.40635113418102, 42.03332170844078, 42.131246253848076, 40.367278307676315, 45.555523708462715, 45.33337622880936, 49.18644927442074, 48.74415300786495, 46.91866636276245, 40.30882224440575, 33.74874785542488, 37.540381997823715, 35.48667199909687, 36.66722685098648, 36.650207564234734, 36.90333478152752, 35.955901220440865, 36.151408329606056, 35.56942395865917, 37.18662478029728, 34.780293703079224, 36.83402270078659, 35.896210223436356, 38.18360388278961, 35.63725411891937, 37.53549166023731, 45.323340967297554, 48.12846824526787, 49.43744860589504, 45.88769808411598, 47.03183189034462, 47.14828044176102, 51.44965723156929, 50.13995110988617, 47.673963233828545, 47.12154507637024, 39.84069116413593, 35.72458863258362, 34.40944120287895, 34.944536089897156, 37.572874054312706, 47.568883672356606, 50.57681746780872, 50.027929320931435, 51.14709846675396, 51.03031173348427, 50.93806408345699, 51.41889788210392, 50.79825438559055, 47.10781641304493, 48.37815664708614, 51.404340863227844, 53.822800889611244, 38.4008002281189, 9.042056556791067, 0.7523094001226127, 2.159248860552907, 2.4370244052261114, 6.969577940180898, 0.9297093527857214, 0.838641420705244, 0.0502642075298354, 20.902104601264, 48.48567187786102, 35.43581932783127, 27.568483985960484, 27.62294266372919, 46.31452918052673, 32.73748151957989, 2.326972335577011, 0.08404562686337158, 0.09634611604269594, 0.016708070834283717, 0.01400008342898218, 0.011819566352642141, 0.022444133937824517, 0.05779571882158052, 0.05718648979382124, 0.046493518457282335, 0.011847865371237276, 0.019860059219354298, 0.020864125654043164, 0.023771585656504612, 0.02823463913955493, 0.030833849959890358, 0.01898224880278576, 0.02479238566593267, 0.05902952449105214, 0.05358538888685871, 0.05222607862378936, 0.04031185504572932, 0.08009619152289815, 0.062491899443557486, 0.005089225742267445, 0.021346707180782687, 0.008937241964304121, 0.10214997062576003, 0.049884213076438755, 0.07269118301337585, 0.029191217399784364, 0.055413068548659794, 0.12242849537869915, 9.959444180130959, 46.19963854551315, 55.312020778656006, 39.09578673541546, 29.29433047771454, 37.40944862365723, 50.58766968548298, 54.216334372758865, 46.94457717239857, 5.411749882623553, 0.2131719159660861, 0.5369265074841678, 7.0104252733290195, 5.662564923986793, 2.1226019645109773, 5.037041064351797, 36.457918882369995, 51.501285061240196, 48.095315024256706, 50.134297013282776, 52.527640387415886, 51.080457642674446, 50.28755038976669, 51.802289709448814, 51.87386266887188, 50.11999078094959, 52.099730148911476, 50.81370435655117, 51.685214191675186, 48.092389181256294, 50.004074200987816, 49.94736984372139, 48.84286791086197, 51.04298785328865, 51.25833749771118, 50.95457419753075, 50.78409634530544, 51.952005475759506, 50.42746268212795, 50.57891495525837, 48.75634275376797, 49.69742305576801, 43.213675171136856, 37.956767454743385, 37.91077472269535, 39.25654090940952, 36.5084295719862, 38.342127576470375, 38.05586613714695, 39.21869874000549, 37.35005781054497, 37.58319430053234, 37.1662312746048, 39.710924327373505, 40.47399938106537, 38.29855531454086, 38.475633412599564, 37.90495723485947, 39.32050667703152, 39.57770727574825, 40.581408217549324, 42.15299628674984, 42.700045332312584, 50.948011949658394, 48.86175289750099, 52.55898870527744, 46.26789428293705, 52.882780730724335, 44.719743356108665, 42.84537233412266, 59.31202434003353, 44.82972465455532, 51.16574786603451, 51.4078176766634, 49.465080723166466, 43.97423096001148, 43.29727828502655, 43.69086496531963, 46.53828017413616, 47.026846557855606, 52.156692892313, 50.88465794920921, 47.621252462267876, 41.172892078757286, 35.737336948513985, 37.66443774104118, 36.77345775067806, 37.99529358744621, 37.71241016685963, 39.141103103756905, 36.551637053489685, 39.0108422935009, 38.75562898814678, 38.584968745708466, 37.59579822421074, 38.378639817237854, 37.09909647703171, 39.90200087428093, 38.75474363565445, 37.85940147936344, 46.57162718474865, 50.68129666149616, 50.466182604432106, 48.13786894083023, 49.015792831778526, 50.19154094159603, 52.36024796962738, 51.767749562859535, 50.005985498428345, 48.44964601099491, 41.507562920451164, 37.88437753915787, 36.04222498834133, 36.98498860001564, 40.463036969304085, 50.27142025530338, 54.28216964006424, 51.84814564883709, 52.12714187800884, 53.610616475343704, 53.933181166648865, 53.32902118563652, 52.044462114572525, 48.56517881155014, 52.06675551831722, 53.80008190870285, 55.299561247229576, 40.26309169828892, 10.186183713376522, 1.4122919482178986, 4.617358334362507, 5.831665825098753, 7.749842796474695, 3.6998165817931294, 0.5496850947383791, 0.13754727551713586, 20.657758712768555, 56.37462995946407, 42.40264289081097, 30.686902552843094, 33.762396723032, 53.135440573096275, 41.20931692421436, 3.462282777763903, 0.037969974655425176, 0.025987937333411537, 0.07112856139428914, 0.045989262507646345, 0.030463577641057782, 0.024045517930062488, 0.024123996336129494, 0.05472913493576925, 0.04129628054215573, 0.017562267967150547, 0.028224160014360677, 0.030270671195467003, 0.0019975486839030054, 0.09078388247871771, 0.17974904301809147, 0.104750522878021, 0.14830859494395554, 0.14862804498989135, 0.11721025468432344, 0.19893695949576795, 0.11035517760319635, 0.19316579651786014, 0.1419413834810257, 0.11268976639257744, 0.05985693380353041, 0.09746907453518361, 0.14178122801240534, 0.16561378666665405, 0.20928310666931793, 0.09206174945575185, 0.2061284743831493, 0.28757889987900853, 11.281701028347015, 53.61843645572662, 62.23380535840988, 43.35834860801697, 31.25624120235443, 39.35567758977413, 55.829541608691216, 60.93900963664055, 51.65768086910248, 7.146646538749337, 0.35729874623939395, 2.0942184375599027, 11.849455162882805, 10.382134448736906, 3.810554277151823, 6.562379440292716, 37.88460172712803, 50.567789152264595, 50.39137601852417, 50.500380769371986, 54.39261831343174, 52.40100838243961, 50.80156780779362, 53.45612436532974, 53.32500100135803, 51.80711545050144, 55.128133445978165, 52.94572815299034, 52.65828877687454, 50.403531566262245, 51.57191947102547, 51.41319818794727, 50.860324054956436, 55.20020417869091, 52.61562466621399, 52.760035917162895, 51.493514478206635, 55.87554194033146, 51.4908280223608, 54.82973925769329, 50.378612503409386, 51.288336887955666, 45.00657856464386, 41.65636293590069, 39.874649941921234, 40.43577343225479, 38.97691011428833, 40.32755523920059, 39.2426298558712, 41.70115873217583, 39.68267284333706, 39.66545596718788, 38.05028423666954, 40.77753849327564, 41.1974273622036, 40.70291809737682, 40.21521806716919, 40.12154549360275, 40.47477833926678, 42.7634297311306, 41.91095307469368, 43.17141763865948, 44.200052842497826, 55.23401476442814, 51.19569405913353, 54.86118637025356, 47.79931850731373, 55.17948389053345, 47.503565177321434, 45.318093448877335, 55.74416019022465, 43.47907193005085, 54.56444129347801, 54.37847927212715, 52.95276157557964, 46.55697897076607, 45.4490040242672, 44.282424822449684, 49.02665264904499, 48.9550568908453, 53.315657302737236, 50.857895985245705, 51.25172205269337, 43.163825646042824, 37.83788703382015, 38.90034042298794, 37.87109725177288, 40.40383614599705, 40.25717921555042, 40.49715153872967, 38.66959020495415, 40.010473653674126, 40.86528718471527, 40.76328545808792, 39.60014507174492, 41.254903078079224, 40.66686563193798, 42.73469567298889, 39.62195210158825, 40.456630513072014, 49.92504984140396, 51.773392260074615, 53.31013239920139, 50.35825699567795, 48.52434620261192, 50.37641242146492, 54.619032964110374, 53.99420589208603, 52.295784428715706, 51.219906359910965, 45.25145262479782, 39.74044494330883, 37.107060849666595, 38.728354051709175, 40.90954340994358, 51.40389248728752, 55.479732379317284, 55.140080004930496, 55.32040312886238, 53.10871280729771, 54.523069113492966, 56.37631706893444, 54.253302589058876, 51.9544867426157, 53.62497590482235, 55.988585874438286, 58.07343140244484, 43.542300537228584, 11.388673838227987, 2.4884874187409878, 7.423864463344216, 9.347064290195704, 17.3770584538579, 5.865836916491389, 2.228429135866463, 0.2466152870329097, 23.77129264175892, 59.417442083358765, 47.15076930820942, 39.293930903077126, 38.776649460196495, 59.91546995937824, 48.038580268621445, 4.759659748524427, 0.16633286839351058, 0.2421708614565432, 0.22269888053415343, 0.10194451446295716, 0.17334813805064186, 0.14827355073066428, 0.1449334408971481, 0.13672399625647813, 0.10078159131808206, 0.15045245178043842, 0.15054055955260992, 0.1862833564518951, 0.07923321478301659, 0.15515452134422958], [0.03864375568809919, 0.027247384205111302, 0.051886720466427505, 0.03794936892518308, 0.06262979790335521, 0.06143239086668473, 0.028998160669289064, 0.05490065639605746, 0.017293551136390306, 0.07229341412312351, 0.01471261848564609, 0.04965616222762037, 0.038214118976611644, 0.010693549284042092, 0.009205055230268044, 0.030226916023821104, 0.12554792017908767, 0.016532432309759315, 2.5218664901331067, 33.169256150722504, 47.87547022104263, 36.350342854857445, 25.906441770493984, 33.814085349440575, 41.97851724922657, 44.73604828119278, 44.503527358174324, 10.974895041435957, 0.04551533071207814, 0.5532001436222345, 4.996349047869444, 2.3884197883307934, 2.70869676489383, 2.2750987065955997, 29.447859339416027, 50.52716553211212, 51.98137030005455, 47.666451036930084, 49.795909970998764, 48.11979331076145, 46.86343252658844, 47.292942479252815, 47.718253657221794, 48.05258631706238, 49.31610971689224, 47.004617750644684, 46.505662724375725, 45.039374604821205, 49.22334149479866, 51.53240539133549, 49.4390445202589, 52.06161819398403, 47.650005519390106, 49.92476485669613, 48.136664405465126, 49.65467914938927, 48.56906220316887, 48.42760719358921, 47.468990832567215, 48.115567937493324, 44.44309540092945, 38.16839709877968, 38.2107800245285, 36.531030759215355, 36.04432627558708, 35.685165748000145, 36.50597870349884, 37.212562188506126, 36.98976494371891, 35.62185354530811, 35.96641145646572, 37.4087380617857, 36.30282260477543, 35.26840791106224, 36.182973235845566, 36.482127383351326, 36.60114459693432, 37.38376960158348, 36.40759818255901, 35.58873072266579, 39.52768296003342, 39.15269248187542, 47.67776682972908, 46.554482504725456, 53.34904991090298, 44.01016183197498, 46.42090447247028, 35.056785866618156, 51.91258639097214, 46.99681676924229, 48.23515512049198, 49.874698743224144, 48.03615219891071, 41.9686833769083, 42.70429350435734, 44.243210926651955, 45.615575686097145, 47.3068193346262, 46.22477039694786, 51.976555958390236, 47.512509897351265, 44.108622148633, 34.701231345534325, 36.87252603471279, 35.51306538283825, 36.4556086063385, 35.60471646487713, 37.49461345374584, 36.46237224340439, 36.02902449667454, 36.96174144744873, 38.08053441345692, 35.64440153539181, 36.64198100566864, 36.509660705924034, 36.719633638858795, 35.52002280950546, 37.86542795598507, 49.247185215353966, 48.12090665102005, 47.08568640053272, 44.63276222348213, 48.12630616128445, 43.82366023957729, 47.0512792468071, 49.920455887913704, 50.47227367758751, 49.55661401152611, 47.23962374031544, 41.525520756840706, 36.90518148243427, 33.14105026423931, 34.97491545975208, 40.00126674771309, 47.686859741806984, 47.77812324464321, 50.605638921260834, 48.72492603957653, 48.95721897482872, 46.72177232801914, 46.0228568315506, 44.40413609147072, 50.623201578855515, 51.298790127038956, 53.04511182010174, 37.09042154252529, 9.771901443600655, 1.3134377589449286, 3.6965915048494935, 2.897235522978008, 7.953687133267522, 4.596599573269486, 0.6872715556528419, 0.3797277552075684, 27.035623379051685, 45.271238163113594, 39.4550384581089, 31.21280573308468, 33.4878234565258, 44.48599509894848, 25.407420247793198, 0.9302558109629899, 0.004738286834253813, 0.043314977883710526, 0.03576990755391307, 0.00573010087464354, 0.02124371749232523, 0.06728094871505164, 0.033743811000022106, 0.09477391329710372, 0.07307573425350711, 0.029173821458243765, 0.01597018308530096, 0.06479867995949462, 0.07853325820178725, 0.015972027322277427, 0.07621872966410592, 0.1280678529292345, 0.024756220809649676, 0.043521736515685916, 0.0702449084201362, 0.040795360546326265, 0.021053158088761847, 0.06948103808099404, 0.05925343415583484, 0.13733473926549777, 0.12536974536487833, 0.03766173103940673, 0.018517252465244383, 0.04848244454478845, 0.017341703533020336, 0.037838035641470924, 0.011625576371443458, 0.05349040511646308, 3.7808633828535676, 38.86246785521507, 55.603259950876236, 39.254766404628754, 26.13851621747017, 36.167014092206955, 45.93717522919178, 50.217732936143875, 47.7022223174572, 10.788822825998068, 0.05422954709501937, 0.7266355433966964, 5.267046997323632, 3.097236128523946, 2.7505230205133557, 3.856711112894118, 30.53378026932478, 52.69157499074936, 51.13954447209835, 48.23061816394329, 50.572257712483406, 48.998598754405975, 49.043447747826576, 48.43386925756931, 48.264698535203934, 49.21682484447956, 50.95375344157219, 47.74563878774643, 47.09514029324055, 46.94296605885029, 50.78589364886284, 50.33741511404514, 50.205778777599335, 51.738491132855415, 52.08953909575939, 51.039047464728355, 50.24180464446545, 50.372069254517555, 49.42799091339111, 51.36543095111847, 49.22622933983803, 49.493970572948456, 45.10738715529442, 39.634544625878334, 38.887877091765404, 38.22442129254341, 37.324226796627045, 37.328341975808144, 38.35274040699005, 37.36265033483505, 38.37036766111851, 37.238982170820236, 38.2653982937336, 38.94807726144791, 37.71745249629021, 36.30199804902077, 37.24605739116669, 37.98049338161945, 39.17261861264706, 39.230018332600594, 39.1874074190855, 38.808788135647774, 40.03828056156635, 43.65180306136608, 48.001106679439545, 46.48052707314491, 53.52722615003586, 47.00753219425678, 48.091842010617256, 40.77299013733864, 53.25151674449444, 46.78155831992626, 49.068074226379395, 53.41887876391411, 49.25289250910282, 43.979223892092705, 44.02327872812748, 44.738255962729454, 47.97811031341553, 47.90212959051132, 50.34089952707291, 54.335932955145836, 50.70453621447086, 45.02034902572632, 37.11917079985142, 38.04986245930195, 36.883024871349335, 37.44287542998791, 37.42147497832775, 38.65648090839386, 37.868289202451706, 38.606483191251755, 38.17233368754387, 38.832764849066734, 37.90243037045002, 38.65996532142162, 37.1247299015522, 39.56144414842129, 37.41606406867504, 39.691039994359016, 50.948509722948074, 50.149131417274475, 51.052783727645874, 45.104263722896576, 49.75036561489105, 46.115131080150604, 48.61004680395126, 52.07658179104328, 53.41766282916069, 50.85905112326145, 49.299630001187325, 43.57897236943245, 38.75485002994537, 35.116750448942184, 37.26028002798557, 41.54980905354023, 49.38775487244129, 52.15286649763584, 52.867741137742996, 51.54106892645359, 51.64185471832752, 48.05367685854435, 49.5218762755394, 45.97477041184902, 53.453460708260536, 52.62827418744564, 54.65632416307926, 39.18373681604862, 11.67627090588212, 1.5684025338850915, 4.986402131617069, 7.507714563980699, 7.490736125037074, 3.3056043600663543, 0.9482645883690566, 0.399337790440768, 27.381091341376305, 49.26973320543766, 42.823048532009125, 34.22077372670174, 35.15262812376022, 49.51277956366539, 32.941997945308685, 1.4310793275944889, 0.08619072308647446, 0.032419415074400604, 0.040782358119031414, 0.07134932806366123, 0.03162993321893737, 0.05398603359935805, 0.027250280436419416, 0.03309454310510773, 0.022151879893499427, 0.03277815441833809, 0.07322020814171992, 0.07246315071824938, 0.03596281399950385, 0.028035635950800497, 0.18683349568163976, 0.28850943432189524, 0.1362090793554671, 0.10778002164443024, 0.13646869745571166, 0.1869881444144994, 0.1315888241515495, 0.2232487525907345, 0.13146792829502374, 0.23263898387085646, 0.19468403770588338, 0.14604768657591194, 0.09684754069894552, 0.1329680610797368, 0.17762041505193338, 0.13620818877825513, 0.1455761110992171, 0.2242544072214514, 4.122470989823341, 44.49811264872551, 62.75059662759304, 47.500992715358734, 35.07785193622112, 44.83912155032158, 53.00293788313866, 53.47027100622654, 54.36483420431614, 13.628655541688204, 0.1880951170460321, 1.892740186303854, 11.11579243093729, 10.681496635079384, 7.039101859554648, 3.6380556458607316, 32.87193350493908, 52.28962115943432, 54.90008868277073, 50.588224455714226, 50.567146986722946, 49.99084711074829, 50.70346847176552, 49.161416217684746, 49.55764755606651, 51.724762469530106, 53.47104236483574, 48.9930472522974, 48.68447721004486, 47.76335723698139, 52.99652382731438, 54.34228241443634, 52.65692085027695, 55.064882040023804, 53.620005771517754, 54.55826662480831, 51.05967275798321, 54.6248010545969, 51.2886256724596, 52.54305616021156, 51.39893755316734, 53.116977363824844, 47.54565551877022, 42.66465023159981, 42.14055195450783, 41.24178618192673, 39.62964668869972, 38.289819583296776, 40.24837128818035, 40.87349474430084, 39.672781974077225, 38.89446213841438, 39.59020860493183, 40.288755521178246, 39.45396311581135, 39.33767035603523, 39.75760482251644, 39.52064573764801, 39.96239863336086, 43.02631862461567, 40.38378842175007, 39.672181606292725, 41.56141363084316, 43.849301263689995, 50.997595489025116, 49.925988391041756, 55.10387174785137, 49.091982543468475, 47.87663295865059, 42.725256979465485, 53.169106766581535, 47.06668742001057, 54.97718654572964, 54.342886582016945, 53.347700983285904, 44.655317813158035, 47.15241461992264, 47.05789089202881, 51.38925567269325, 50.294025242328644, 52.024722173810005, 56.00569635629654, 51.5191251039505, 49.25949275493622, 40.73328606784344, 40.08890524506569, 38.14315505325794, 38.557724207639694, 39.42720115184784, 40.58484323322773, 40.50373278558254, 41.22777633368969, 40.762088522315025, 41.75321973860264, 39.05284903943539, 40.52113205194473, 40.15570566058159, 38.923165798187256, 39.60248954594135, 41.672018095850945, 53.51669691503048, 52.23271921277046, 52.76589900255203, 48.45153070986271, 50.03322623670101, 48.108975291252136, 48.7822649627924, 52.906594052910805, 54.52331230044365, 54.17908877134323, 51.41020394861698, 44.36486899852753, 40.29368005692959, 35.5986025929451, 38.84905457496643, 42.67114408314228, 52.63558879494667, 54.48336884379387, 55.85275836288929, 53.34144651889801, 54.20260950922966, 50.619850158691406, 52.082897052168846, 47.64945834875107, 54.72359575331211, 55.509378388524055, 55.35973481833935, 40.57829238474369, 13.760069590061903, 2.8436417737975717, 9.540025535970926, 11.127943228930235, 19.39362544566393, 13.932202253490686, 2.1400921884924173, 0.409297471633181, 32.49169550836086, 55.562244951725006, 51.33181415498257, 40.55147722363472, 46.06104098260403, 58.738175332546234, 39.165140613913536, 2.3855404928326607, 0.15179893031017855, 0.15520800050580874, 0.08781592259765603, 0.18275794718647376, 0.15397998358821496, 0.12531056650914252, 0.19392772985156626, 0.16980512504233047, 0.1380600847187452, 0.14080278051551431, 0.10512702181586064, 0.22644783952273428, 0.14231863198801875, 0.17790018988307565], [0.024740806402405724, 0.03965484655054752, 0.015759483649162576, 0.024801252475299407, 0.02695306327950675, 0.04908958071609959, 0.09461596942855977, 0.05644666132866405, 0.04336567399150226, 0.030693478292960208, 0.04889387266302947, 0.016329749923897907, 0.020562418503686786, 0.03971935773734003, 0.037049459206173196, 0.045161367088439874, 0.09637416180339642, 0.016641843430988956, 0.8132368745282292, 18.75880490988493, 46.036000326275826, 34.52639892697334, 20.26206124573946, 26.913950107991695, 40.399838760495186, 47.634954527020454, 49.349384531378746, 20.67361906170845, 0.2747180743608624, 0.3118367091519758, 3.693423899821937, 2.850016881711781, 1.2813744856975973, 2.4497798457741737, 25.641166605055332, 48.60860288143158, 49.71510350704193, 51.85416452586651, 48.408034443855286, 48.612269684672356, 48.44519264996052, 47.18576543033123, 48.95329758524895, 47.07993730902672, 48.75762328505516, 46.76319010555744, 49.457842111587524, 51.15437887609005, 51.21156580746174, 48.690800070762634, 49.88026924431324, 50.832349956035614, 47.80340328812599, 48.973284512758255, 47.85186968743801, 48.63216541707516, 49.724960178136826, 47.768977135419846, 49.82767626643181, 46.488168463110924, 43.730466440320015, 36.55081249773502, 38.02326388657093, 37.293357253074646, 37.26954773068428, 35.37066042423248, 37.41925589740276, 37.914783507585526, 38.04781436920166, 35.62513656914234, 37.487420439720154, 37.55646273493767, 37.421649768948555, 35.31312771141529, 37.12784193456173, 38.88214699923992, 37.38606087863445, 36.295435801148415, 38.881584629416466, 38.07268023490906, 37.507692351937294, 38.021322190761566, 42.15231232345104, 44.441906064748764, 48.78773286938667, 50.991394221782684, 47.27362051606178, 40.15114210546017, 49.80403013527393, 44.01268109679222, 46.19045063853264, 51.12662136554718, 46.529544442892075, 45.408133417367935, 43.65711897611618, 45.45788794755936, 47.73756422102451, 50.12447074055672, 44.27582077682018, 47.89566993713379, 48.656731098890305, 44.895499125123024, 34.35335621237755, 35.38154684007168, 36.03125497698784, 35.50171539187431, 35.398429334163666, 36.916185691952705, 36.343928799033165, 35.98357893526554, 34.91937004029751, 36.96833789348602, 36.25861957669258, 36.734262853860855, 37.372522205114365, 35.687293633818626, 34.91398572921753, 36.390947476029396, 49.129592925310135, 48.2104716449976, 47.77231715619564, 49.7236492484808, 48.07602345943451, 49.572200775146484, 48.835370913147926, 47.82373979687691, 49.40941371023655, 49.0987765789032, 46.78088575601578, 48.397056832909584, 41.996383890509605, 36.72817178070545, 35.68649187684059, 34.70204830169678, 40.56859150528908, 43.57477739453316, 45.82504704594612, 46.97891592979431, 46.07089765369892, 44.53548364341259, 41.58789440989494, 46.45935840904713, 50.58606617152691, 49.01673898100853, 53.45298193395138, 35.871701538562775, 8.845009580254555, 0.3366787370759994, 3.452206193469465, 6.466064108535647, 3.9360292442142963, 1.4222054975107312, 0.5465453350916505, 0.7320949004497379, 29.49134800583124, 46.30624182522297, 30.42944546788931, 23.93881805241108, 37.17050224542618, 47.196925431489944, 17.19008568674326, 0.3538709442364052, 0.015365735343948472, 0.022843925180495717, 0.0935178209329024, 0.017415923866792582, 0.004235626502122614, 0.048858464797376655, 0.03584392194170505, 0.03573182053514756, 0.045302553262445144, 0.0405504406808177, 0.08213480439735577, 0.010286015585734276, 0.011226339884160552, 0.003872545130434446, 0.0918592544621788, 0.05244008803856559, 0.042610791060724296, 0.05571159374085255, 0.09579979145200923, 0.033210154870175757, 0.020198472993797623, 0.04457318165805191, 0.06110115551564377, 0.00906155262782704, 0.008033839512791019, 0.06564811992575414, 0.03654165950138122, 0.06612362878513522, 0.006535024504046305, 0.010924142916337587, 0.08415179108851589, 0.04995194518414792, 1.3177796197123826, 25.01048594713211, 53.580757677555084, 42.2393162548542, 26.647519804537296, 34.282497614622116, 49.72050681710243, 51.147068068385124, 53.082745000720024, 21.628184840083122, 0.251121370238252, 0.30756639142055064, 5.160415219143033, 5.484510753303766, 1.884343943092972, 2.972723222337663, 27.26983331143856, 50.80784127116203, 51.85747794806957, 50.80828204751015, 50.73560334742069, 51.445648446679115, 48.896106854081154, 48.3938954025507, 48.57469730079174, 48.14773701131344, 49.17705237865448, 46.59316062927246, 50.32660089433193, 51.77208133041859, 52.01766215264797, 49.4584234803915, 51.932941898703575, 52.301495522260666, 50.73930434882641, 51.11261151731014, 50.55961959064007, 49.454490691423416, 51.64386101067066, 47.87142723798752, 51.75651356577873, 49.91297408938408, 43.83761689066887, 39.05188009142876, 38.83245326578617, 38.407883048057556, 38.92776735126972, 38.698768839240074, 39.48693014681339, 38.01240786910057, 39.27603006362915, 36.896042972803116, 38.833236023783684, 39.46074575185776, 38.52794520556927, 36.56175211071968, 39.05456654727459, 39.6477185189724, 38.16859848797321, 37.23197154700756, 40.08770450949669, 39.58752974867821, 39.70590099692345, 40.96103444695473, 43.58379051089287, 46.62602126598358, 50.44858194887638, 52.175121903419495, 47.99079403281212, 44.29999887943268, 46.957659870386124, 45.64369797706604, 50.0684617459774, 51.17420621216297, 49.452499598264694, 45.88926739990711, 44.046282693743706, 47.40161284804344, 49.18845176696777, 50.240345522761345, 48.280220702290535, 50.22116795182228, 51.78983397781849, 45.25738410651684, 36.10808685421944, 36.75198510289192, 37.90293574333191, 38.35750535130501, 37.68805347383022, 38.476955741643906, 37.5377981364727, 37.13222309947014, 39.18734662234783, 39.05699461698532, 36.578554809093475, 39.58270400762558, 38.456186056137085, 37.67940133810043, 37.79716081917286, 38.12643975019455, 50.667852982878685, 50.24777412414551, 50.7630530744791, 51.984683722257614, 49.20441471040249, 51.30659870803356, 51.16560347378254, 49.486663565039635, 51.16542488336563, 51.03607602417469, 50.33601298928261, 49.803809747099876, 43.58722932636738, 39.16016288101673, 37.8468469530344, 37.01081581413746, 42.89152845740318, 45.83460733294487, 47.48961232602596, 49.552331641316414, 47.88258723914623, 46.31042540073395, 42.95648597180843, 47.22292363643646, 52.36158549785614, 51.22796952724457, 55.44379010796547, 36.61739632487297, 10.582481548190117, 0.7081963203381747, 5.4757393989712, 9.81109444051981, 6.535956608131528, 2.966771316714585, 0.843822977039963, 0.7112415006849915, 30.967867076396942, 52.49149292707443, 35.748888328671455, 28.995909690856934, 41.7994936555624, 55.239011496305466, 24.29239857941866, 0.4353568295482546, 0.060772784854634665, 0.046392749645747244, 0.06221747549716383, 0.020010832085972652, 0.09446575873880647, 0.014424012097151717, 0.0026594987230055267, 0.01624157164769713, 0.08823485011816956, 0.10860215057618916, 0.03370576479937881, 0.026917217546724714, 0.027198680763831362, 0.03586663166061044, 0.20201954408548772, 0.20017259084852412, 0.0751426155329682, 0.17008616152452305, 0.19179594033630565, 0.15733952284790576, 0.24522435385733843, 0.1418485408066772, 0.12731144117424265, 0.13065426726825535, 0.15609354595653713, 0.19106870982795954, 0.10942175620584749, 0.10619541018968448, 0.20025701756821945, 0.1535725296707824, 0.164298893942032, 0.17616026918403804, 1.8185712536796927, 27.73465856909752, 61.89584769308567, 46.71128489077091, 30.629766918718815, 39.62574049830437, 50.64457543194294, 57.05337233841419, 59.06252212822437, 26.414599902927876, 0.3699007403338328, 1.5236114873550832, 10.38806403055787, 10.812640897929668, 5.208128783851862, 4.084887206554413, 29.25769094377756, 50.56865930557251, 52.95288696885109, 53.051145896315575, 52.10094228386879, 51.683557480573654, 49.45960521697998, 49.97834578156471, 50.28662323951721, 48.157175704836845, 50.672097355127335, 47.23278410732746, 51.78649015724659, 54.576551243662834, 53.28543372452259, 51.33785583078861, 55.07273621857166, 53.756559044122696, 52.62600190937519, 51.806663274765015, 51.83106556534767, 52.12225154042244, 53.731218203902245, 52.27115415036678, 54.36954975128174, 51.900750026106834, 47.480549812316895, 39.64784771203995, 41.33768543601036, 40.65347895026207, 41.22565224766731, 40.33775769174099, 41.92831054329872, 40.902369394898415, 42.141802087426186, 40.63418358564377, 40.771941393613815, 40.704704001545906, 40.157373771071434, 38.63197982311249, 39.608124643564224, 43.283948600292206, 39.92139883339405, 40.03584489226341, 42.98292875289917, 41.50376312434673, 40.42711369693279, 42.272674664855, 45.299143865704536, 48.66842307150364, 52.18942433595657, 53.98169316351414, 51.03449910879135, 43.59835132956505, 54.34991240501404, 45.84163315594196, 51.17895595729351, 53.634156212210655, 50.693072229623795, 48.34860943257809, 48.10591645538807, 50.633844807744026, 52.72624433040619, 52.221411019563675, 50.13118498027325, 51.29671163856983, 52.467288225889206, 47.829663679003716, 38.10001976788044, 38.90078879892826, 39.13675993680954, 39.58555765450001, 39.58248741924763, 40.65394252538681, 40.827714800834656, 39.68572787940502, 39.13316912949085, 42.03901380300522, 39.41995494067669, 41.246243342757225, 40.04819042980671, 39.44115400314331, 39.61276799440384, 41.688174828886986, 52.56504938006401, 53.44572812318802, 52.26068191230297, 54.545586705207825, 52.56617791950703, 54.28975023329258, 51.587038859725, 50.05189083516598, 52.05610848963261, 51.517354398965836, 52.34562635421753, 52.64456011354923, 46.17562383413315, 42.119231298565865, 40.33524602651596, 38.49360264837742, 45.73099069297314, 46.96942023932934, 50.78787334263325, 51.36010743677616, 50.20656533539295, 49.4068868458271, 44.71660852432251, 50.07720127701759, 54.411822482943535, 54.68837544322014, 56.74849949777126, 39.90254804491997, 12.317186314612627, 1.9830089737661183, 12.064754460006952, 14.469283483922482, 11.26700721681118, 6.918318215757608, 1.3338888552971184, 1.0415230435319245, 34.31122787296772, 57.15436331927776, 41.88645958900452, 36.21598966419697, 48.18505860865116, 62.73489207029343, 28.95305559039116, 0.5616193043533713, 0.09886296887998469, 0.14532150991726667, 0.14210048509994522, 0.08568359873606823, 0.15941096091410145, 0.1998825595364906, 0.17940294987056404, 0.12577258312376216, 0.20601298136170954, 0.18850605905754492, 0.21195834124227986, 0.2142903918866068, 0.09666224868851714, 0.10430245121824555], [0.09322931844508275, 0.03516812968882732, 0.05071351115475409, 0.06434558395994827, 0.02318975115485955, 0.07490719886845909, 0.056376183274551295, 0.02088870001898613, 0.026177422478212975, 0.0700587332539726, 0.025511576859571505, 0.04221877381496597, 0.07126674929168075, 0.03548819571733475, 0.11384186902432702, 0.04248326411470771, 0.027273817649984267, 0.045024696883047, 0.06951541436137632, 10.173984467983246, 41.16949886083603, 35.63567340373993, 21.587249636650085, 20.065864473581314, 32.051173746585846, 46.049804985523224, 52.29357294738293, 33.440421000123024, 2.204239396378398, 0.2230099739972502, 3.293816205114126, 1.9948941422626376, 1.115462207235396, 1.6385638690553606, 21.854039020836353, 48.81238594651222, 49.87714201211929, 46.574906408786774, 53.95360507071018, 44.990247040987015, 44.824480935931206, 44.88325238227844, 48.08569014072418, 48.85278917849064, 48.3196359872818, 51.938421204686165, 51.189310401678085, 49.47040803730488, 49.721623957157135, 48.774752765893936, 45.53449563682079, 46.995760425925255, 46.87229745090008, 47.57334843277931, 49.67475347220898, 48.4083042293787, 49.2400112003088, 50.37069372832775, 49.17054332792759, 47.41363160312176, 38.99488314986229, 37.08104744553566, 37.281935065984726, 35.182703509926796, 37.03152470290661, 35.882093980908394, 37.915330678224564, 37.38380379974842, 35.70196084678173, 34.376781955361366, 36.91871255636215, 37.10654407739639, 37.04091019928455, 34.98601846396923, 36.383948251605034, 36.192955300211906, 35.73929764330387, 38.50038908421993, 39.323960691690445, 39.71790075302124, 40.4325246065855, 37.76296645402908, 39.91777002811432, 39.04546983540058, 47.44609326124191, 47.509439662098885, 54.04491417109966, 42.1400161832571, 46.73210397362709, 40.926509499549866, 48.467056676745415, 52.318826392292976, 47.28921487927437, 46.68853171169758, 43.43322739005089, 44.76390838623047, 46.514238864183426, 52.510909885168076, 46.140848100185394, 47.002413868904114, 47.9620523750782, 47.67510697245598, 36.17289237678051, 34.85789313912392, 35.66488243639469, 35.78868359327316, 34.81639936566353, 35.27707904577255, 36.78357660770416, 36.496395617723465, 35.82538582384586, 36.66657328605652, 35.27059659361839, 35.97485840320587, 35.48002615571022, 37.18359254300594, 36.20288036763668, 35.47471024096012, 41.31154663860798, 49.035145193338394, 46.88966631889343, 45.118756145238876, 46.619079038500786, 47.99419865012169, 49.24903951585293, 49.325708001852036, 47.75488369166851, 48.985246270895004, 50.879874005913734, 47.65235759317875, 46.19611993432045, 39.13527421653271, 36.06379263103008, 35.75044244527817, 36.38485640287399, 37.85769157111645, 39.84404258430004, 40.45015946030617, 42.769744992256165, 41.40442505478859, 43.524654284119606, 47.72430673241615, 52.20458172261715, 52.007623091340065, 52.08618767559528, 32.85939417779446, 9.654744230210781, 0.6829662679228932, 3.0996155133470893, 10.573788564652205, 4.827886512503028, 1.4389914530329406, 0.5881103547289968, 1.154531235806644, 31.331078186631203, 40.901693031191826, 35.32478168606758, 29.86045639961958, 39.425757229328156, 39.27775897085667, 8.89049218967557, 0.2368966702488251, 0.026081735522893723, 0.11003186096786521, 0.034167035555583425, 0.03810923495620955, 0.02770793693343876, 0.06139224809885491, 0.012962148157384945, 0.02313223470991943, 0.05381414848670829, 0.03758309678232763, 0.054937871391302906, 0.04802932257007342, 0.0237103714607656, 0.0009434719322598539, 0.04880460342974402, 0.04714018512459006, 0.02606431175081525, 0.013619910860143136, 0.031685256617492996, 0.09400206487043761, 0.05438327556475997, 0.03708065167302266, 0.11634352267719805, 0.037169379138504155, 0.012641597877518507, 0.04226998942613136, 0.03344566801388282, 0.05782657361123711, 0.056213274438050576, 0.02406359479209641, 0.02351354090933455, 0.10887894197367132, 0.26587277243379503, 13.899710197001696, 48.40850941836834, 41.13179348409176, 24.7453323751688, 25.131049677729607, 44.219568595290184, 51.42346903681755, 55.42149290442467, 36.20815068483353, 1.8965596938505769, 0.1152212024317123, 2.8327584452927113, 3.8348292745649815, 2.05668143928051, 2.0065293554216623, 23.39952629059553, 49.47015345096588, 52.254047468304634, 49.149127677083015, 53.0569139868021, 45.833737179636955, 46.309179067611694, 44.40485805273056, 48.51770795881748, 49.37665566802025, 49.879904463887215, 51.49920277297497, 53.206891939044, 51.81372709572315, 51.12059108912945, 50.92276610434055, 48.58462616801262, 47.94184125959873, 49.30798575282097, 49.41570997238159, 50.60154274106026, 50.61638854444027, 49.49736379086971, 50.93453787267208, 50.97339078783989, 49.965810254216194, 41.28102287650108, 38.96326884627342, 39.02961328625679, 36.893519908189774, 38.098925426602364, 38.00726294517517, 38.49671468138695, 39.30107071995735, 37.403539940714836, 36.46541588008404, 39.14723977446556, 39.48953680694103, 39.51739311218262, 36.74850448966026, 37.56341256201267, 39.156496077775955, 37.332468554377556, 39.20986421406269, 40.90428069233894, 40.82186311483383, 40.80833964049816, 40.553479716181755, 41.99087418615818, 41.94568321108818, 48.208214566111565, 49.6270090341568, 54.63585086166859, 46.26878343522549, 45.66696032881737, 43.30687277019024, 51.34355932474136, 54.20132897794247, 48.49001504480839, 46.4775176346302, 45.8084799349308, 47.666143253445625, 49.983904883265495, 54.14077542722225, 49.18722063302994, 51.125451028347015, 52.12964974343777, 48.289043828845024, 39.39241781830788, 36.45756170153618, 36.27797573804855, 38.203184232115746, 37.32776440680027, 35.98300136625767, 38.779024332761765, 36.7382488399744, 38.654383420944214, 38.22472907602787, 36.29103943705559, 37.602611258625984, 36.73534579575062, 38.66070628166199, 37.25626744329929, 37.06923387944698, 45.02238571643829, 49.43495213985443, 50.61064325273037, 48.13334338366985, 50.0793519616127, 49.386033564805984, 51.37706592679024, 50.24844668805599, 47.94938005506992, 49.02399279177189, 52.324621081352234, 49.58838790655136, 48.93500916659832, 40.840987488627434, 37.996471524238586, 37.37338475883007, 38.705638870596886, 40.75188606977463, 41.953894570469856, 42.86567464470863, 44.609990045428276, 43.72831955552101, 44.50357675552368, 49.002919122576714, 53.910971358418465, 54.7469113022089, 52.8323308378458, 34.047476425766945, 9.473950881510973, 1.0689644585363567, 7.637690864503384, 11.548968236893415, 6.500026686117053, 2.2456355625763535, 0.2274885680526495, 1.1072792275808752, 32.97282189130783, 48.33702765405178, 38.68002824485302, 32.45546065270901, 44.07752841711044, 45.04493370652199, 12.551099862903357, 0.16856230970006436, 0.02699510037928121, 0.09421959577593952, 0.02674916006071726, 0.08611664932686836, 0.05795716562715825, 0.1614895384409465, 0.042396985736559145, 0.01711115906800842, 0.05849089597177226, 0.05429323449789081, 0.14042582886759192, 0.006639513794652885, 0.04927996385958977, 0.035843458099407144, 0.14838959294138476, 0.1448006261489354, 0.1322105509461835, 0.14167599147185683, 0.09442578666494228, 0.19440564326941967, 0.18920584494480863, 0.12535194866359234, 0.17059842153685167, 0.1407040303456597, 0.09300772057031281, 0.12097519953385927, 0.19913263415219262, 0.21364102751249447, 0.1914838672382757, 0.17919130419613793, 0.11673809291096404, 0.16521768760867417, 0.35058637673500925, 15.062833484262228, 57.226586043834686, 47.35301725566387, 34.032075852155685, 30.302948355674744, 44.160109385848045, 55.21465100347996, 59.89955261349678, 41.99099577963352, 2.982846829108894, 0.7476347009651363, 8.788554109632969, 6.747772917151451, 4.824917921796441, 2.9680601600557566, 25.702577009797096, 50.547825023531914, 53.02556946873665, 49.89002712070942, 55.099638774991035, 47.38779678940773, 46.09125316143036, 45.976077541708946, 49.2122270911932, 49.36831131577492, 49.88861359655857, 53.159329891204834, 55.31465403735638, 53.59359338879585, 53.75949248671532, 52.69852861762047, 49.66183416545391, 50.97120590507984, 50.99334351718426, 51.531390845775604, 51.936190724372864, 52.06936217844486, 52.15428002178669, 52.43563212454319, 53.84040914475918, 52.440568059682846, 41.73830173909664, 40.65070889890194, 40.55481344461441, 38.36142674088478, 41.280639097094536, 40.61889320611954, 41.875489577651024, 41.655975356698036, 39.41506080329418, 38.79837289452553, 40.45715108513832, 40.71943201124668, 41.20961710810661, 38.00929583609104, 39.65982846915722, 40.33568300306797, 38.25548842549324, 42.05437257885933, 43.68524506688118, 42.911990359425545, 43.39700013399124, 40.999021008610725, 45.12548178434372, 42.15659849345684, 50.93098886311054, 50.817188769578934, 58.906567096710205, 45.843350663781166, 53.72144132852554, 47.3698465526104, 52.689124122262, 57.36077204346657, 51.122046411037445, 50.6352773308754, 46.98472201824188, 48.47068928182125, 51.47622920572758, 56.961208283901215, 51.27705529332161, 52.528746128082275, 53.34545910358429, 51.06182724237442, 41.708762124180794, 39.703643918037415, 37.96059384942055, 40.11950880289078, 37.3211869597435, 38.68648789823055, 41.41503028571606, 38.78997914493084, 40.34286841750145, 40.51403023302555, 38.437612652778625, 39.496802017092705, 38.22884425520897, 39.90472912788391, 40.130190029740334, 39.14499029517174, 44.29440937936306, 51.59836605191231, 51.415968239307404, 50.94678081572056, 51.49210475385189, 51.03778973221779, 52.47479662299156, 51.6580456495285, 49.974659979343414, 49.80231262743473, 53.85122336447239, 51.674707755446434, 50.47256626188755, 43.69680404663086, 40.30634477734566, 39.13247376680374, 40.82947790622711, 43.53697322309017, 44.263775423169136, 46.0259460657835, 46.76970675587654, 46.775421649217606, 47.42980353534222, 52.61548027396202, 56.55191324651241, 58.139791041612625, 53.722949847579, 36.139435172080994, 11.204997394233942, 2.7120009250938892, 9.78654870763421, 19.409898072481155, 10.701665952801704, 5.936762960627675, 1.3526072446256876, 1.5762932854704559, 36.65007457137108, 53.19451980292797, 47.64631971716881, 42.26013533771038, 52.54106506705284, 50.71995958685875, 18.071773275732994, 0.3614230686798692, 0.11489614174934104, 0.14984052133513615, 0.10601725763990544, 0.22052855871152133, 0.12187419270048849, 0.31777540454640985, 0.11758625638321973, 0.08493279761751182, 0.29081608867272735, 0.24257127981400117, 0.2546580304624513, 0.19767873716773465, 0.07139288471080363, 0.11829331531771459], [0.0431193811527919, 0.04246589414833579, 0.007736077805020614, 0.02817450847942382, 0.037318817994673736, 0.014100871721893782, 0.052508361914078705, 0.05148332980752457, 0.023183157172752544, 0.04719900774944108, 0.07403976182104088, 0.057789607235463336, 0.0729890217189677, 0.05003005622711498, 0.036651660630013794, 0.06978900710237212, 0.04190877501969226, 0.04879616521066055, 0.07111598941264674, 4.796803230419755, 27.93734349310398, 38.73593084514141, 31.582824178040028, 31.8924942612648, 42.666344940662384, 46.56128413975239, 45.28817005455494, 46.22629791498184, 5.936232414096594, 0.18581479409476742, 1.7405720078386366, 3.4062595339491963, 0.302919982932508, 0.8756748866289854, 20.78954704105854, 41.72387391328812, 55.822861567139626, 45.06966657936573, 47.81186543405056, 49.951070845127106, 46.03244751691818, 46.18086755275726, 48.05046223104, 51.594684049487114, 52.13592320680618, 51.5351602435112, 49.21952269971371, 49.290214106440544, 46.77734434604645, 45.58879852294922, 45.45551307499409, 46.10896021127701, 46.49066112935543, 45.761936232447624, 47.19960808753967, 48.70803974568844, 48.45404617488384, 49.34390142560005, 48.400795832276344, 41.997086852788925, 35.91321811079979, 36.78030118346214, 36.016253381967545, 35.64871430397034, 35.94571016728878, 36.428892239928246, 37.43586480617523, 36.57974414527416, 36.3505632430315, 37.83780723810196, 35.75958475470543, 37.821863293647766, 35.6064073741436, 37.936624735593796, 36.58077768981457, 37.9855053126812, 37.84830987453461, 40.919726863503456, 44.74417224526405, 44.12433810532093, 46.79951995611191, 44.87022668123245, 38.44618499279022, 41.65089502930641, 43.253231048583984, 47.79206469655037, 48.98078911006451, 48.87819081544876, 39.920870661735535, 38.746817260980606, 48.55431519448757, 51.98803514242172, 49.25627052783966, 47.18074969947338, 44.56535004079342, 46.3136400282383, 47.9257795214653, 54.77270431816578, 44.80062581598759, 46.87301181256771, 46.93662039935589, 48.00923444330692, 37.83337667584419, 33.56420315802097, 35.5276034027338, 34.784101098775864, 35.28532840311527, 36.6485508531332, 36.311831921339035, 36.46970584988594, 35.19279956817627, 37.35973209142685, 35.2186343818903, 35.08598729968071, 36.23126484453678, 35.51097169518471, 35.252049788832664, 34.83980990946293, 36.604279428720474, 41.578292325139046, 43.79792422056198, 42.62509435415268, 43.59664902091026, 44.29506294429302, 46.213249415159225, 49.427572935819626, 50.699710473418236, 48.799044862389565, 45.525794103741646, 50.27123786509037, 48.91545161604881, 48.22796210646629, 39.453978314995766, 36.92962557077408, 37.35533572733402, 36.06218911707401, 37.91180446743965, 40.03678724169731, 39.493792578577995, 41.983153000473976, 46.87674701213837, 51.61967910826206, 50.84154166281223, 52.19574339687824, 48.46012584865093, 33.1356393545866, 6.9180636294186115, 0.13313241710420698, 4.479810940101743, 10.500473398715258, 3.9810523157939315, 2.5950783491134644, 0.22520132828503847, 2.9060016525909305, 33.52175563573837, 39.60060104727745, 29.849467389285564, 26.052407138049603, 38.2545118778944, 43.663871213793755, 5.920919235795736, 0.011910512839676812, 0.049082816040026955, 0.008076952726696618, 0.05328389139322098, 0.016943598820944317, 0.034288506576558575, 0.07621785392984748, 0.02955288451630622, 0.022606385973631404, 0.09503224748186767, 0.08637724706204608, 0.06254748630453832, 0.045183034089859575, 0.04156533133937046, 0.00560881121600687, 0.03538275137543678, 0.03877993978676386, 0.014090314671193482, 0.03481445921352133, 0.02533857481466839, 0.054670323443133384, 0.03252174239605665, 0.03991189681983087, 0.032488705692230724, 0.04428441199706867, 0.043245260530966334, 0.05771807162091136, 0.06453014124417678, 0.03717202118423302, 0.01469136523155612, 0.036385426283231936, 0.036402914993232116, 0.032881246152101085, 0.0213034362604958, 6.879220688715577, 36.66872397065163, 45.53570777177811, 37.110267877578735, 33.83195959031582, 39.99849669635296, 52.515393644571304, 50.97253583371639, 47.71914280951023, 5.726056667044759, 0.13981763884657994, 4.287755470722914, 8.476377110928297, 2.354544843547046, 1.5070068533532321, 22.052367478609085, 44.18541982769966, 53.87557625770569, 46.64234139025211, 49.68126632273197, 50.296795293688774, 47.114219069480896, 46.35598115622997, 47.91768975555897, 51.220833510160446, 53.706770315766335, 52.85047106444836, 51.3935836404562, 49.518597051501274, 48.60766813158989, 47.92476497590542, 46.8803758174181, 48.615381717681885, 48.270067647099495, 46.35581396520138, 49.38974216580391, 50.31197167932987, 51.11542336642742, 51.116171926259995, 49.655594900250435, 44.45533074438572, 37.88211666047573, 37.71057866513729, 38.861183524131775, 37.330564856529236, 37.152084633708, 38.0589097738266, 38.45865972340107, 37.41066075861454, 38.44748072326183, 38.37102882564068, 36.37772798538208, 40.21250881254673, 38.587678000330925, 38.252190202474594, 36.9354772567749, 39.20231781899929, 38.51237364113331, 42.976408302783966, 46.873976960778236, 46.26223638653755, 48.12621496617794, 45.10421432554722, 40.705277770757675, 43.2986918091774, 45.39932928979397, 47.91040174663067, 50.02967342734337, 51.28739073872566, 41.36622950434685, 41.71518757939339, 51.39028921723366, 54.241777807474136, 51.4300274848938, 48.305303156375885, 46.2397263944149, 48.40518459677696, 49.286672696471214, 54.0157051384449, 47.17994034290314, 48.660306707024574, 48.69295835494995, 48.34486283361912, 38.63463968038559, 35.21800361573696, 37.36029826104641, 37.964492440223694, 36.99586361646652, 36.80346854031086, 37.59951822459698, 37.19974547624588, 37.12033733725548, 38.98047432303429, 36.689638048410416, 38.52209351956844, 37.69945286214352, 37.54076957702637, 37.71448105573654, 36.69613569974899, 39.48361672461033, 44.07392621040344, 48.93371723592281, 46.20951421558857, 45.12583516538143, 47.14340530335903, 48.33554953336716, 50.683956518769264, 53.38492378592491, 47.458674386143684, 47.64712147414684, 52.54519164562225, 49.55930046737194, 49.61863048374653, 40.75760096311569, 38.26730579137802, 38.6550597846508, 37.31639921665192, 40.6870349496603, 40.14770328998566, 42.4003554135561, 44.271929785609245, 48.05753745138645, 53.326152339577675, 53.85459378361702, 54.00660082697868, 50.89375466108322, 34.53658618032932, 7.769289677962661, 1.4288096618838608, 6.096356771886349, 8.946922961622477, 8.307047747075558, 3.1324692629277706, 0.11008475383277982, 2.697856421582401, 38.02388325333595, 46.30545526742935, 36.220891401171684, 34.82266902923584, 45.758516415953636, 50.30658356845379, 9.492210801690817, 0.04550061763438862, 0.0426174963649828, 0.036544294125633314, 0.01964652106835274, 0.04060203478729818, 0.018633240870258305, 0.09086569683859125, 0.09145043499302119, 0.035259079886600375, 0.05903302371734753, 0.09207372771925293, 0.05088718855404295, 0.025657214064267464, 0.008077386883087456, 0.011089404360973276, 0.11931577959330752, 0.11937800867599435, 0.0838662646128796, 0.15723292075563222, 0.12386904112645425, 0.12807105900719762, 0.12288060432183556, 0.10249196711811237, 0.11742668721126392, 0.2175633967272006, 0.08207580365706235, 0.1745717169251293, 0.21955469768727198, 0.14460679201874882, 0.2534639148507267, 0.17979869269765913, 0.13664077181601897, 0.16608046396868303, 0.23911451920866966, 7.460429426282644, 40.68039670586586, 53.44793580472469, 43.656712397933006, 43.944949731230736, 52.86648340523243, 58.047676384449005, 54.766662642359734, 56.93050213158131, 6.832289407029748, 0.36097994714509696, 9.195639565587044, 13.070190008729696, 4.136482262983918, 1.6979708313010633, 25.21888006478548, 44.86416980624199, 55.78726887702942, 47.76879854500294, 50.144594460725784, 52.80489630997181, 46.07356511056423, 45.95313057303429, 48.63801710307598, 52.90030159056187, 55.950090140104294, 54.190146178007126, 53.468792885541916, 51.8395809084177, 51.227916330099106, 49.54409748315811, 48.00884686410427, 51.41158327460289, 51.387378573417664, 49.04984660446644, 51.48855194449425, 53.09612788259983, 53.3517287671566, 53.71556684374809, 52.313457280397415, 45.395947471261024, 38.67609925568104, 39.12522755563259, 39.971970319747925, 37.38309323787689, 39.57116022706032, 40.30898563563824, 41.741622760891914, 40.010713040828705, 39.68342140316963, 40.40254421532154, 38.95651660859585, 41.014858558773994, 39.610784500837326, 40.36913640797138, 39.07725133001804, 42.31028124690056, 42.35449567437172, 44.966999888420105, 49.356569945812225, 48.30838859081268, 50.88554710149765, 47.67211273312569, 44.04749482870102, 46.38270132243633, 47.44602106511593, 49.6036858856678, 52.73070149123669, 51.583220064640045, 49.370701387524605, 45.014155358076096, 52.431528344750404, 55.601998418569565, 52.43127375841141, 50.82468956708908, 49.42160725593567, 49.08201947808266, 51.65111482143402, 57.06168249249458, 46.69838838279247, 50.37062153220177, 49.47672329843044, 50.95075540244579, 41.80886775255203, 37.594817876815796, 40.06467014551163, 39.090296030044556, 39.066429510712624, 40.42331390082836, 41.10851593315601, 39.72098618745804, 38.31765688955784, 41.55746564269066, 38.432270139455795, 39.360328540205956, 39.95189219713211, 39.53045681118965, 39.31220032274723, 38.538318648934364, 42.61031694710255, 45.285928174853325, 49.955110028386116, 48.13948005437851, 46.76614634692669, 49.37368042767048, 49.910922199487686, 53.74188043177128, 55.58009259402752, 49.748268127441406, 47.746630534529686, 53.75657804310322, 53.092795461416245, 53.58932241797447, 44.00719039142132, 40.38483336567879, 40.571958124637604, 38.9498707652092, 43.482043370604515, 43.48593816161156, 42.78876677155495, 45.97812183201313, 50.034179985523224, 55.670489743351936, 56.38477921485901, 53.928807601332664, 51.24314971268177, 33.87488208711147, 8.69541920721531, 1.430957259144634, 10.359581708908081, 22.249307110905647, 14.41287076100707, 9.067681431770325, 0.4077864589635283, 3.701156722381711, 41.349419206380844, 50.378817692399025, 43.13451401889324, 37.318945080041885, 51.635889038443565, 58.76855090260506, 12.659028321504593, 0.10520091003854759, 0.10162938371649943, 0.11891309768543579, 0.12467318039853126, 0.1728521756012924, 0.10897972562815994, 0.2652375237084925, 0.19061640050495043, 0.06574461396667175, 0.1405950533808209, 0.25274652522057295, 0.15794803941389546, 0.11682880562148057, 0.09322303245426156, 0.08023072805372067], [0.019800577938440256, 0.11518013197928667, 0.06320351516478695, 0.10220335330814123, 0.08587675751186907, 0.06636661535594612, 0.05171949975192547, 0.07579232871648856, 0.035778642632067204, 0.025662722655397374, 0.03985502975410782, 0.07061677635647357, 0.04892362165264785, 0.028586112857738044, 0.037800282589159906, 0.02389963025052566, 0.039617924703634344, 0.025757973598956596, 0.05230037131696008, 2.365969168022275, 21.489482782781124, 41.06896385550499, 32.01808512210846, 24.436929523944855, 24.975881204009056, 38.08329686522484, 46.81148551404476, 50.43339416384697, 8.073190245777369, 0.17353386792819947, 1.653187503106892, 2.970954654738307, 1.3613288453780115, 0.9000460070092231, 18.16005013883114, 41.30217634141445, 50.95545955002308, 50.20876921713352, 44.590960666537285, 51.491097807884216, 46.38692669570446, 44.53979641199112, 49.983878284692764, 50.9358374029398, 52.92972721159458, 48.465418964624405, 48.10146689414978, 45.63838206231594, 43.33370693027973, 43.864591643214226, 43.24527807533741, 43.4069138020277, 44.08635154366493, 44.94473308324814, 44.61020663380623, 47.46207520365715, 45.794796869158745, 46.68232284486294, 40.82529053092003, 36.59791857004166, 36.994013115763664, 37.75469429790974, 36.94537952542305, 35.68628668785095, 35.17918489873409, 37.206421718001366, 35.34510679543018, 36.990437507629395, 40.92880077660084, 38.218987584114075, 37.842887565493584, 36.62740118801594, 36.16787664592266, 36.73234015703201, 36.50608889758587, 35.53548417985439, 35.91183118522167, 42.944284826517105, 47.84303516149521, 48.31208199262619, 47.52435006201267, 45.166732370853424, 42.760560885071754, 40.497193336486816, 42.24967069923878, 44.74554777145386, 49.67999339103699, 49.53329086303711, 39.579698368906975, 36.78227707743645, 48.752774745225906, 51.91016972064972, 48.94369550049305, 46.69327385723591, 45.87105117738247, 47.46763050556183, 49.19166259467602, 52.60343112051487, 43.2734839618206, 44.93425704538822, 45.42452573776245, 49.43463675677776, 38.408730402588844, 33.93714174628258, 35.81406623125076, 34.73098374903202, 36.362194418907166, 37.258961498737335, 37.40173123776913, 36.3974679261446, 34.558480605483055, 35.05505695939064, 37.16676324605942, 35.81450700759888, 35.87248429656029, 36.89039267599583, 35.75220175087452, 36.04256696999073, 34.40211899578571, 36.31198011338711, 38.09839725494385, 38.59992854297161, 40.39899900555611, 42.99562767148018, 44.680468663573265, 47.79709182679653, 47.8227898478508, 48.895764872431755, 47.90627896785736, 48.7220723927021, 51.42238609492779, 46.79394945502281, 45.81621252000332, 43.01412507891655, 40.93969479203224, 41.87961995601654, 40.95476858317852, 42.28172957897186, 42.88191877305508, 45.48163667321205, 48.60720455646515, 49.734186083078384, 53.26132781803608, 52.314365431666374, 44.83823619782925, 26.557496935129166, 4.860221827402711, 5.070988917723298, 7.902834936976433, 8.786805253475904, 5.0419888738542795, 1.2668060674332082, 0.07208412105683237, 3.8154593389481306, 27.868821769952774, 32.14827373623848, 33.86904940009117, 23.486988097429276, 40.25984667241573, 34.12096068263054, 2.236074088141322, 0.01685676383203827, 0.025454837814322673, 0.09066512400750071, 0.04351838200818747, 0.0023644279963264125, 0.07829138485249132, 0.028772640544048045, 0.05622255128400866, 0.02701596215047175, 0.04260076835635118, 0.017797166983655188, 0.0185612247150857, 0.034849681542254984, 0.03148765979858581, 0.054702180132153444, 0.06209924024005886, 0.041795794168137945, 0.006828948844486149, 0.08178799136658199, 0.039924706288729794, 0.045731058198725805, 0.10195876369834878, 0.1271338007063605, 0.049962717457674444, 0.030570268791052513, 0.020694127451861277, 0.04441215787664987, 0.07518098456785083, 0.0687933417793829, 0.03467066439043265, 0.046959824685472995, 0.06295926694292575, 0.07131814301828854, 0.024899605596147012, 3.530203183181584, 27.06301800906658, 48.50182481110096, 36.8099357932806, 27.935616485774517, 33.16184274852276, 48.56620475649834, 51.09864726662636, 57.361368611454964, 9.245933666825294, 0.04691496927989647, 2.303697159513831, 5.71877340786159, 2.0095385564491153, 0.9620298841036856, 20.956954658031464, 42.52827174961567, 49.675308242440224, 49.605156406760216, 46.58767752349377, 52.407870814204216, 47.99308530986309, 44.99763384461403, 50.41808478534222, 52.29289658367634, 54.00712139904499, 50.13490878045559, 49.76822465658188, 47.67681308090687, 46.174282506108284, 45.998234152793884, 44.87605556845665, 45.10748594999313, 46.31185032427311, 46.06217712163925, 46.532990857958794, 49.430555775761604, 47.51964971423149, 48.160827308893204, 44.88515228033066, 37.626751363277435, 38.15770447254181, 40.92916555702686, 38.74426759779453, 37.494427263736725, 37.588711604475975, 38.632629588246346, 38.52680146694183, 38.95438112318516, 42.11711101233959, 40.29013104736805, 39.14893448352814, 39.99866768717766, 37.376519590616226, 37.99701489508152, 38.45138691365719, 37.81859166920185, 37.6420721411705, 44.74507659673691, 49.397877529263496, 50.855296924710274, 49.19233895838261, 45.23122251033783, 42.5504207611084, 43.234855234622955, 44.59588140249252, 46.10642574727535, 50.9868648648262, 52.319065779447556, 40.347067192196846, 39.465237110853195, 51.180418878793716, 54.34005953371525, 50.070908814668655, 48.100801929831505, 48.0967703461647, 50.10340467095375, 51.02507181465626, 52.5793632119894, 46.57649092376232, 47.56838969886303, 48.672416657209396, 50.36306373775005, 39.55651581287384, 35.02468898892403, 37.73775480687618, 36.815548092126846, 38.256016597151756, 38.27544875442982, 39.58494208753109, 38.2236385345459, 36.85874417424202, 38.00783671438694, 38.356490805745125, 37.43654876947403, 36.32089823484421, 37.75669679045677, 37.150006145238876, 37.545295134186745, 36.715826243162155, 37.40661017596722, 39.384278655052185, 39.99694637954235, 42.698244228959084, 45.09985215961933, 47.64269471168518, 50.09508691728115, 49.43386159837246, 49.89117465913296, 48.32971304655075, 50.43044172227383, 52.42643281817436, 48.80322843790054, 47.55056865513325, 44.32653285562992, 42.0266492664814, 43.14964860677719, 42.69221395254135, 45.29374435544014, 44.22198906540871, 47.566413804888725, 49.99253802001476, 52.92263299226761, 54.346393793821335, 53.30976001918316, 45.861433893442154, 30.558209158480167, 5.046882536262274, 5.268412549048662, 13.405304476618767, 8.265115097165108, 7.186822257936001, 2.9044135753065348, 0.07696830623899586, 4.0111711621284485, 33.1150558590889, 38.326897993683815, 37.701063975691795, 27.315035685896873, 45.10684758424759, 43.83584998548031, 3.9665000466629863, 0.06351553631247953, 0.07894497204688378, 0.03195886420144234, 0.02263186761410907, 0.04610786141711287, 0.013098309063934721, 0.028528956354421098, 0.022770936811866704, 0.011813372202595929, 0.027364873603801243, 0.040312459896085784, 0.006857442676846404, 0.05174535988771822, 0.014184414358169306, 0.06650396462646313, 0.14355531719047576, 0.21320005820598453, 0.1140882917388808, 0.20936883956892416, 0.14684323919937015, 0.1449724184931256, 0.23273624974535778, 0.164579440606758, 0.18234105315059423, 0.07277690849150531, 0.15763817791594192, 0.16191999893635511, 0.2179806915228255, 0.09928071638569236, 0.12193534566904418, 0.16979146952508017, 0.16774812916992232, 0.1360505269258283, 0.13508733798516914, 4.16969153098762, 32.299228236079216, 54.71862941980362, 44.947886914014816, 36.381812766194344, 34.92321543395519, 49.41003307700157, 55.88366970419884, 60.59179186820984, 10.564131382852793, 0.2294146639178507, 5.10573330335319, 10.89670853689313, 6.31255092099309, 2.1508919214829803, 24.338889084756374, 44.962816312909126, 51.50982320308685, 50.8053258061409, 48.267502784729004, 51.96359105408192, 50.11877864599228, 45.57167284190655, 50.50334081053734, 53.79599332809448, 54.665546268224716, 52.736549377441406, 52.87386640906334, 49.99681659042835, 48.58216010034084, 46.42536163330078, 46.95560798048973, 48.49996671080589, 47.32849717140198, 48.209947273135185, 47.90391929447651, 51.048239171504974, 49.26143065094948, 51.410815715789795, 46.15111134946346, 39.425825625658035, 39.9806072562933, 42.649796828627586, 39.85582575201988, 38.80327083170414, 40.259094312787056, 41.174734979867935, 40.066786631941795, 41.0392190515995, 43.227445632219315, 42.32713334262371, 42.226343750953674, 40.96008449792862, 39.794987216591835, 40.554646253585815, 41.24486021697521, 40.28707221150398, 39.43773038685322, 46.648535057902336, 51.579978838562965, 53.97625185549259, 52.21017502248287, 47.21372053027153, 45.86729697883129, 44.989072903990746, 46.0612727701664, 49.32143323123455, 53.23499143123627, 53.02161008119583, 45.62464199960232, 41.49304389953613, 51.81729890406132, 57.028745859861374, 51.29827715456486, 50.42508400976658, 49.83914025127888, 50.892135947942734, 52.77544409036636, 55.79803749918938, 46.639597937464714, 48.282929956912994, 48.96605730056763, 53.15315522253513, 42.66403466463089, 36.66311927139759, 39.036126136779785, 37.91127249598503, 40.367388501763344, 41.331111788749695, 42.338927909731865, 39.9160373210907, 38.02411124110222, 39.719964042305946, 41.07362620532513, 39.754340797662735, 38.66798669099808, 39.37221810221672, 39.40030999481678, 40.80906540155411, 37.3040384799242, 38.917283713817596, 41.78466685116291, 41.64739541709423, 44.57808695733547, 46.812963634729385, 48.15668933093548, 52.86565124988556, 51.364826783537865, 51.9619457423687, 49.229356572031975, 52.07961782813072, 55.143731608986855, 50.60435079038143, 50.27142025530338, 47.332973331213, 44.66615863144398, 46.45285315811634, 45.24652048945427, 47.424913197755814, 46.996831968426704, 49.96332138776779, 53.08897286653519, 55.2397296577692, 56.22309789061546, 54.665827453136444, 45.76893165707588, 30.481894053518772, 6.5188375767320395, 10.433691032230854, 22.375059463083744, 17.96698059886694, 17.021021358668804, 4.71624992787838, 0.19502549985190853, 4.637679643929005, 36.128810942173004, 44.87165920436382, 44.68964137136936, 34.94382932782173, 52.49516353011131, 49.76846784353256, 4.901442490518093, 0.17763086449122056, 0.13145489618182182, 0.15629980363883078, 0.11950979183893651, 0.14172760042129084, 0.2785425988258794, 0.18452819203957915, 0.1695376104908064, 0.05131503668962978, 0.14060437475563958, 0.14713558601215482, 0.15031841991003603, 0.12642976973438635, 0.10338849635445513, 0.11205479968339205], [0.030419711147260386, 0.05807456596812699, 0.01968694956303807, 0.03715937869856134, 0.019919089645554777, 0.0889859777817037, 0.04623316192009952, 0.04259400368027855, 0.09184532435028814, 0.07008487911662087, 0.102945530670695, 0.04841892412514426, 0.050992725664400496, 0.05616736889351159, 0.029629084529005922, 0.11073689383920282, 0.07687939694733359, 0.05259861449303571, 0.08540068462025374, 0.8172875759191811, 14.215591046959162, 38.7596719712019, 43.74824948608875, 34.275764375925064, 30.843579545617104, 32.666432932019234, 31.8827173858881, 41.00261941552162, 12.520148623734713, 0.012596280485013267, 2.52808200661093, 8.526177238672972, 2.8299313969910145, 4.564858926460147, 14.824970047920942, 38.546294420957565, 48.96281987428665, 50.51259711384773, 47.25973226130009, 44.57891911268234, 47.07958772778511, 45.49121215939522, 52.53503479063511, 49.898671656847, 49.13234397768974, 48.0725010484457, 45.882074385881424, 43.717277348041534, 42.957937493920326, 42.20558546483517, 42.99299821257591, 42.283310294151306, 43.81870150566101, 41.505761817097664, 43.54886278510094, 41.91329374909401, 41.27724587917328, 38.24820801615715, 36.30692258477211, 35.55640585720539, 36.87992803752422, 40.00778719782829, 36.66030742228031, 33.452299162745476, 35.153657868504524, 37.22905330359936, 36.368334889411926, 37.875569611787796, 40.28653644025326, 36.54326990246773, 36.768658608198166, 36.43844872713089, 37.77619354426861, 35.71883574128151, 36.91810078918934, 36.24361418187618, 35.19919082522392, 43.65468330681324, 50.267229080200195, 48.959187269210815, 51.01489216089249, 48.522461503744125, 45.629304349422455, 42.70112067461014, 42.14176028966904, 43.116096407175064, 46.27486690878868, 49.122304916381836, 47.156974375247955, 41.697237342596054, 47.408938854932785, 51.734375953674316, 49.99781973659992, 49.368033930659294, 48.83932650089264, 49.41643953323364, 49.351930394768715, 50.00529773533344, 46.23360492289066, 44.80052702128887, 45.82043029367924, 48.876393511891365, 40.174130871891975, 33.202150985598564, 35.29042772948742, 35.32478168606758, 36.77734114229679, 36.174511089921, 38.85138384997845, 37.448069751262665, 35.74823476374149, 35.33142752945423, 35.72762846946716, 37.31872469186783, 35.775300711393356, 35.83975665271282, 35.43134696781635, 35.41459746658802, 36.12555831670761, 34.32401418685913, 35.70731855928898, 33.85641507804394, 33.92064303159714, 39.28575374186039, 40.826643258333206, 44.89921152591705, 46.95039086043835, 49.54792007803917, 47.570057809352875, 48.830199390649796, 49.20405752956867, 49.295093044638634, 47.87075847387314, 48.090109303593636, 46.44203893840313, 47.46318094432354, 47.04240672290325, 48.221137672662735, 47.57074177265167, 48.72197739779949, 47.501292899250984, 52.85997435450554, 51.05686850845814, 47.80687630176544, 46.143979132175446, 18.091254830360413, 0.7643168151844293, 9.739525280892849, 3.6177735216915607, 6.7269334103912115, 8.215816542506218, 1.7697723722085357, 0.11587300105020404, 5.048198215663433, 33.11083048582077, 33.16475719213486, 27.568459287285805, 27.857325486838818, 50.04969075322151, 27.369488663971424, 1.5888026892207563, 0.06281260371906683, 0.03477184509392828, 0.058447109258850105, 0.041288105785497464, 0.09014697134261951, 0.10110963543411344, 0.0870967963419389, 0.0751165438850876, 0.05723495574784465, 0.03457593666098546, 0.040735194634180516, 0.013739401274506235, 0.03900960109604057, 0.04915179866657127, 0.05234253272647038, 0.038182124990271404, 0.05712331818358507, 0.010271264472976327, 0.06962152663618326, 0.03689851007948164, 0.03358488007506821, 0.04206522346066777, 0.03252498929214198, 0.033409751777071506, 0.020388986013131216, 0.028421222486940678, 0.024363277734664734, 0.04351264149590861, 0.10352295124903321, 0.0350084529054584, 0.01849368927651085, 0.004503725031099748, 0.005334915122148232, 0.08281208836706355, 1.6169623844325542, 19.483669213950634, 48.19366134703159, 46.55953623354435, 34.14394564926624, 29.328644536435604, 37.607087418437004, 42.19264715909958, 48.743993416428566, 13.81996102631092, 0.015832883909752127, 1.2653001607395709, 8.315754979848862, 4.7011414635926485, 4.041516333818436, 18.021625466644764, 41.020090878009796, 50.47386959195137, 49.43810597062111, 46.18731200695038, 45.87301567196846, 48.02339628338814, 47.88239344954491, 54.653531312942505, 51.90480060875416, 51.738122552633286, 49.721794947981834, 47.96593576669693, 45.74524752795696, 44.398113414645195, 43.94072435796261, 45.19170083105564, 44.16393578052521, 45.410835072398186, 45.01783736050129, 45.586522445082664, 44.809156358242035, 43.63473057746887, 40.694463551044464, 38.80305424332619, 36.447062864899635, 39.4413173943758, 40.99298693239689, 39.32480424642563, 35.036616548895836, 35.73344595730305, 38.637766912579536, 37.561752051115036, 38.7215980142355, 42.14850872755051, 37.780297324061394, 38.65358546376228, 38.332548290491104, 38.74186232686043, 38.30929733812809, 38.920532539486885, 38.0616570264101, 37.10747502744198, 45.721985176205635, 51.62138141691685, 50.58924280107021, 51.42967030405998, 51.3543925434351, 47.029761001467705, 44.86687146127224, 44.42809380590916, 44.660626128315926, 48.634813874959946, 50.43901406228542, 48.335564732551575, 43.73074382543564, 50.21465130150318, 53.03553253412247, 50.10712467133999, 51.46113261580467, 49.549724981188774, 51.65603555738926, 53.1289467215538, 51.87387406826019, 48.77615489065647, 46.276637613773346, 49.849247708916664, 51.3417924195528, 41.38185426592827, 34.84482564032078, 37.53939785063267, 37.226264253258705, 38.00217881798744, 37.22347140312195, 40.055630430579185, 39.42308597266674, 36.90050773322582, 37.28480011224747, 38.30711245536804, 37.985528111457825, 37.620344907045364, 36.21102713048458, 36.520550921559334, 36.548703610897064, 36.915019154548645, 36.848731711506844, 37.678348794579506, 36.86882883310318, 36.92926459014416, 41.05604834854603, 44.14593234658241, 47.05970719456673, 49.80637460947037, 50.49578681588173, 48.34159880876541, 48.65037404000759, 51.403364315629005, 49.927702099084854, 50.225389525294304, 50.13885296881199, 49.77102130651474, 48.62184897065163, 48.54676879942417, 49.59295526146889, 50.75845532119274, 51.20960131287575, 51.697688922286034, 55.5367711186409, 52.05823257565498, 48.46057042479515, 46.80533744394779, 19.80575703084469, 4.013222577050328, 14.836838711053133, 6.502960603684187, 12.526092454791069, 5.491083925589919, 1.9187927758321166, 0.10641936067258939, 5.089173316955566, 35.276934653520584, 36.20868645608425, 32.90708161890507, 30.888194851577282, 54.42810460925102, 32.3620692640543, 1.989137213677168, 0.055813609360484406, 0.03087168835918419, 0.024412153725279495, 0.028618546566576697, 0.02319825616723392, 0.018454847122484352, 0.05818463760078885, 0.08500431838911027, 0.06802174568292685, 0.020010655825899448, 0.020379022680572234, 0.0983146701764781, 0.02060973969491897, 0.016100483808259014, 0.026576939126243815, 0.1288588932948187, 0.18825031496817246, 0.11838770165923052, 0.10967438327497803, 0.11438996734796092, 0.12975898484000936, 0.15258063445799053, 0.1442988304188475, 0.16562880773562938, 0.1624365188763477, 0.1725410672952421, 0.11783215959439985, 0.0939130739425309, 0.18920967442682013, 0.15671482746256515, 0.14467832021182403, 0.20776308432687074, 0.10492357687326148, 0.25604468886740506, 2.210016273893416, 23.12547169625759, 54.04032401740551, 54.907167702913284, 45.10666899383068, 40.00331103801727, 45.48788733780384, 40.58822125196457, 52.34035983681679, 16.64141032844782, 0.12052723177475855, 5.9711819887161255, 18.694924637675285, 7.350006401538849, 6.269986554980278, 21.938242502510548, 44.58204634487629, 51.60495489835739, 51.07708342373371, 47.22246006131172, 45.79692095518112, 48.61331082880497, 48.5252695530653, 56.24194487929344, 54.160568565130234, 52.946366518735886, 52.537166476249695, 49.937623366713524, 49.21204090118408, 46.739388182759285, 47.38469995558262, 47.99280032515526, 46.731936782598495, 48.72357711195946, 46.15125574171543, 49.63484041392803, 46.50262288749218, 45.7587406039238, 42.586142644286156, 41.117289662361145, 38.60377013683319, 40.537239387631416, 43.980132043361664, 40.90130165219307, 36.108531430363655, 37.895077764987946, 41.49117060005665, 39.756510481238365, 40.99158860743046, 42.60340131819248, 38.96242909133434, 39.92945060133934, 40.37088431417942, 40.896255522966385, 39.75041560828686, 41.97817146778107, 39.94104377925396, 39.70742851495743, 47.13141694664955, 54.802414923906326, 52.11379699409008, 53.83771508932114, 52.221840396523476, 47.90557220578194, 47.66083113849163, 46.200634092092514, 47.681312039494514, 50.938683450222015, 52.120344042778015, 51.619834899902344, 47.80336908996105, 50.85205189883709, 55.00309735536575, 52.99580566585064, 54.651886001229286, 51.009994223713875, 53.31384479999542, 55.068647637963295, 53.599965646862984, 48.09254877269268, 48.094619661569595, 48.995399326086044, 53.114507496356964, 42.60177880525589, 37.04165495932102, 39.27865192294121, 39.87638644874096, 39.81534272432327, 39.47556495666504, 42.220195680856705, 40.75926907360554, 38.21028225123882, 39.11204606294632, 39.613938331604004, 40.709195360541344, 38.85090507566929, 38.56448404490948, 39.56441178917885, 38.502467572689056, 38.864382952451706, 39.15168933570385, 39.60040345788002, 37.62188762426376, 36.372845247387886, 43.42787727713585, 47.02294036746025, 49.52354818582535, 51.25853508710861, 53.069350719451904, 50.08338734507561, 49.998043924570084, 52.68079876899719, 52.47144900262356, 52.854859828948975, 53.02902728319168, 52.08956189453602, 51.679271310567856, 50.964468866586685, 52.15097799897194, 52.838551104068756, 53.38530756533146, 53.05844530463219, 55.96104875206947, 51.97606958448887, 49.67738293111324, 48.994852155447006, 22.367820851504803, 5.110808880999684, 23.221492543816566, 11.529452484101057, 14.279304128140211, 16.805707812309265, 6.152104530483484, 0.28804384055547416, 6.124236350879073, 42.36582666635513, 44.4085780531168, 38.275232166051865, 38.65798182785511, 62.802327051758766, 39.51895862817764, 2.7601414918899536, 0.09876890908344649, 0.1499871103442274, 0.13788921263767406, 0.21382220060331747, 0.1781435846351087, 0.2571535762399435, 0.28356281225569546, 0.18038212467217818, 0.2166299382224679, 0.04576413572067395, 0.1283948728814721, 0.2613279491197318, 0.19627116504125297, 0.16305312485201284, 0.18244229693664238], [0.040189315332099795, 0.025905770453391597, 0.07608527666889131, 0.029699788938160054, 0.03227288543712348, 0.003312559688311012, 0.043277714648866095, 0.03615406545577571, 0.06192306551383808, 0.06426026666304097, 0.09047464438481256, 0.07115970191080123, 0.08209947074647062, 0.07189273601397872, 0.035283477991470136, 0.03882702534610871, 0.036917854158673435, 0.07079692528350279, 0.016553377572563477, 0.11405237921280786, 8.12138020992279, 37.948115319013596, 44.55263592302799, 47.517928406596184, 63.67661453783512, 48.46871338784695, 31.69273518025875, 45.74269026517868, 26.406375244259834, 1.1347275297157466, 0.7970365032088012, 8.613357860594988, 29.58396803587675, 13.540481273084879, 16.443705037236214, 38.55012461543083, 48.69787149131298, 49.460543766617775, 52.8374757617712, 52.537656649947166, 49.22589875757694, 49.51402969658375, 50.75388416647911, 51.65873721241951, 48.35658900439739, 45.493636429309845, 42.68148332834244, 43.02603363990784, 40.1163549721241, 40.09195648133755, 40.77162221074104, 40.19863575696945, 40.28370559215546, 38.61825875937939, 37.04272650182247, 37.8165777772665, 36.92177139222622, 36.056386828422546, 37.74722009897232, 37.04983972012997, 36.736200749874115, 39.04636278748512, 38.109876438975334, 39.246140867471695, 37.83919416368008, 34.62328612804413, 34.523503482341766, 35.217270255088806, 36.4162503182888, 35.74791558086872, 38.381463065743446, 36.17766112089157, 37.7798755466938, 37.31325298547745, 37.37419031560421, 36.832149401307106, 36.08723357319832, 44.91314917802811, 47.87367671728134, 48.47120225429535, 49.161123633384705, 48.20093035697937, 48.34256395697594, 44.52067583799362, 44.19469512999058, 42.19162881374359, 49.84789118170738, 48.54281321167946, 52.65977829694748, 41.46342448890209, 44.65810306370258, 51.59108564257622, 51.031208485364914, 49.30656082928181, 49.858534410595894, 48.17895233631134, 49.74386416375637, 47.31872409582138, 49.325768798589706, 45.96639946103096, 45.70715457201004, 48.201165944337845, 40.73069080710411, 34.903692081570625, 35.734224915504456, 33.878244906663895, 36.48216538131237, 34.590516686439514, 37.12153047323227, 36.928276643157005, 34.31796491146088, 35.282235369086266, 35.30213490128517, 37.02635318040848, 36.084117740392685, 37.40266978740692, 36.3688250631094, 35.25210298597813, 34.96580354869366, 34.02601517736912, 33.60617570579052, 35.72113461792469, 34.62864004075527, 35.68037420511246, 38.23733679950237, 43.06753121316433, 45.42704880237579, 49.89665776491165, 49.243275225162506, 45.81202894449234, 46.495665460824966, 51.1919816583395, 51.890855357050896, 46.52985602617264, 49.01976741850376, 49.47184436023235, 51.46294131875038, 48.52227531373501, 49.10661555826664, 50.841553062200546, 51.76462613046169, 50.0498503446579, 53.593373000621796, 46.40672743320465, 37.164711356163025, 15.79779289662838, 5.2727685403078794, 4.233727119863033, 4.061821969226003, 13.902039472013712, 2.385468534193933, 1.2859107297845185, 0.13993684260640293, 7.6023755595088005, 33.97468753159046, 36.555186063051224, 37.685560807585716, 33.88053618371487, 42.868129312992096, 18.471308536827564, 0.4182855924591422, 0.0839854015794117, 0.02539765162509866, 0.09286718006478623, 0.05394035812059883, 0.01343903926681378, 0.04995041264919564, 0.035363292263355106, 0.0463540280907182, 0.061209768828121014, 0.04458087401872035, 0.03412194266275037, 0.012419726335792802, 0.07857878154027276, 0.04145997605519369, 0.047177381566143595, 0.05887025217816699, 0.020417636624188162, 0.03235911928641144, 0.05788032736745663, 0.009434623771085171, 0.04610866293660365, 0.06270002733799629, 0.04782103140314575, 0.030797516265010927, 0.03952683349780273, 0.04718861026049126, 0.015793555648997426, 0.05572053290961776, 0.059999422446708195, 0.08078310114797205, 0.05625841185974423, 0.025938521430362016, 0.019407202562433667, 0.05083186144474894, 0.24477268278133124, 11.806028243154287, 43.65042753517628, 51.52957834303379, 51.2332284450531, 54.55895058810711, 44.860590398311615, 32.77644082903862, 48.01511272788048, 26.43165908753872, 0.9347885521128774, 0.34761600487399846, 8.9192452467978, 30.25371629744768, 16.367654018104076, 19.826342426240444, 43.519509360194206, 50.077752247452736, 50.679643750190735, 51.68937876820564, 50.89865259826183, 49.700656682252884, 50.36698892712593, 52.60607197880745, 53.15285503864288, 49.82558637857437, 46.95365488529205, 46.67915381491184, 44.73024219274521, 42.85989135503769, 43.41181553900242, 43.18356178700924, 41.26786798238754, 43.48838523030281, 41.44022673368454, 39.92122404277325, 40.48129498958588, 38.75138461589813, 37.423177286982536, 38.22273798286915, 37.36541658639908, 38.4712028503418, 39.00670811533928, 39.120952785015106, 39.20623920857906, 39.174940288066864, 37.503679767251015, 37.26247251033783, 38.141707330942154, 39.26891304552555, 37.62609779834747, 40.66916450858116, 37.49161921441555, 38.703005611896515, 39.33587685227394, 38.463432267308235, 38.80333922803402, 36.30547106266022, 45.992188677191734, 50.19092537462711, 50.11595159769058, 51.80130556225777, 51.1002279818058, 49.631337001919746, 46.12231269478798, 46.0736259073019, 43.70677091181278, 50.44884033501148, 50.33548481762409, 53.82973171770573, 43.54497179389, 47.03701101243496, 53.659633845090866, 51.957097202539444, 50.003378838300705, 51.60978443920612, 50.623501762747765, 51.83241829276085, 50.32010704278946, 47.46850065886974, 48.24591614305973, 47.89935953915119, 52.469902485609055, 43.081145882606506, 36.34295605123043, 36.496395617723465, 36.150188595056534, 37.17310890555382, 37.43937961757183, 38.28918121755123, 39.60430584847927, 36.82882837951183, 38.36952030658722, 37.577684596180916, 39.94851417839527, 38.146502673625946, 37.78838708996773, 36.37284144759178, 37.36685670912266, 36.725318133831024, 36.176327392458916, 35.36368399858475, 37.03489512205124, 36.537007838487625, 38.584144189953804, 40.59300139546394, 45.447168722748756, 47.61727787554264, 50.80435685813427, 49.71030816435814, 46.88365884125233, 46.76562957465649, 52.14355319738388, 52.244563177227974, 49.18734222650528, 50.423263907432556, 52.2554761916399, 52.48841509222984, 50.13021223247051, 51.26897692680359, 52.13751532137394, 53.34947168827057, 51.25717855989933, 51.548524126410484, 46.61801889538765, 40.69678142666817, 19.3992168456316, 6.3579190615564585, 8.6317840218544, 1.2817566026933491, 14.366153217852116, 5.9658855479210615, 1.0935411835089326, 0.09085964833502658, 7.613417766988277, 39.9391932785511, 39.98251095414162, 39.87486273050308, 37.841569036245346, 47.38504573702812, 23.55348262935877, 0.6102038535755128, 0.028702405543299392, 0.022428090560424607, 0.046728415618417785, 0.03352031693793833, 0.038423230216722004, 0.01132226896515931, 0.04712978392490186, 0.05470206138852518, 0.06990367633989081, 0.02274745154863922, 0.023110231886676047, 0.0357601186260581, 0.03472190597676672, 0.05605386853858363, 0.03072976560360985, 0.12114042387111112, 0.1024473640427459, 0.14771766727790236, 0.19232675404055044, 0.10916883969912305, 0.15727701917057857, 0.16658424865454435, 0.20095151936402544, 0.142458229965996, 0.10764331804239191, 0.22977577813435346, 0.17110226559452713, 0.15455869550351053, 0.2868784312158823, 0.1928273178054951, 0.14116095582721755, 0.2036012092139572, 0.11178036089404486, 0.13655189221026376, 0.5232844082638621, 13.676768559962511, 52.60147042572498, 59.04455669224262, 58.91934581100941, 65.98432570695877, 56.72694705426693, 41.18236497044563, 56.573283299803734, 32.984726652503014, 2.094434075988829, 0.957929725991562, 20.21622810512781, 43.349848464131355, 18.133299574255943, 23.55465106666088, 46.25679507851601, 50.83806864917278, 51.191958859562874, 53.78420636057854, 54.46533881127834, 50.84813430905342, 51.064977273344994, 53.64279694855213, 54.799815863370895, 52.4691691249609, 49.11628603935242, 48.641691505908966, 48.31971198320389, 45.73277659714222, 44.56181243062019, 44.62248757481575, 43.841694071888924, 46.26399949193001, 41.49955295026302, 40.839908346533775, 42.05662585794926, 40.880691558122635, 39.31936673820019, 40.99194958806038, 39.62710082530975, 41.27367027103901, 42.74367459118366, 41.601300090551376, 41.352592036128044, 41.50657877326012, 38.610358983278275, 39.13349591195583, 38.76476749777794, 40.875288248062134, 39.348537772893906, 41.88443809747696, 38.71011883020401, 41.42364822328091, 40.85771419107914, 41.07123613357544, 41.176399290561676, 37.45322987437248, 47.45305448770523, 52.7605526894331, 51.70364700257778, 54.317872524261475, 52.11636945605278, 52.96723119914532, 48.165554255247116, 47.34202444553375, 45.65303407609463, 53.8646974414587, 53.621791675686836, 55.50498202443123, 46.03501617908478, 49.0998899191618, 53.38915675878525, 54.58624452352524, 51.99349544942379, 53.442741483449936, 53.043804690241814, 52.48953603208065, 51.18144102394581, 47.34171666204929, 51.939663738012314, 49.55070152878761, 55.293052196502686, 44.94781091809273, 37.76317544281483, 38.470317497849464, 38.13156187534332, 38.87670949101448, 38.60299877822399, 38.650492429733276, 41.001920253038406, 38.89617584645748, 41.43467903137207, 39.66226413846016, 41.220252737402916, 41.40964977443218, 39.86279457807541, 38.042468056082726, 38.82222421467304, 39.17915806174278, 37.774175852537155, 37.02506884932518, 38.49040701985359, 38.33532974123955, 40.54801180958748, 41.8728943169117, 47.15151786804199, 49.90925028920174, 53.35679769515991, 51.44284039735794, 47.87670135498047, 46.280247420072556, 53.207043930888176, 55.57753153145313, 52.000452876091, 53.9094552397728, 54.14753906428814, 56.107523292303085, 54.372369199991226, 54.54566270112991, 56.743673756718636, 54.842175990343094, 53.03900554776192, 52.43621349334717, 49.33040454983711, 43.770007118582726, 28.0619141086936, 9.822722766548395, 9.759911186993122, 12.013812493532896, 26.670766957104206, 9.755902402102947, 4.628939162939787, 0.1777407617191784, 9.165127202868462, 44.82042655348778, 47.9448164999485, 49.5428017526865, 45.14720521867275, 56.65167309343815, 28.096148371696472, 1.1862228414975107, 0.1781628211028874, 0.12707870366284624, 0.1932346381363459, 0.0844949230668135, 0.11726288037607446, 0.20295868744142354, 0.06869118515169248, 0.1323582828626968, 0.13794356753351167, 0.13777271029539406, 0.09501080683548935, 0.12355729457340203, 0.18076581502100453, 0.2347140881465748, 0.14913226012140512], [0.03483297579805367, 0.013821136781189125, 0.04148829641053453, 0.03826749052677769, 0.06569266362930648, 0.0694998589460738, 0.09289607929531485, 0.039538466662634164, 0.0509050817345269, 0.10319033550331369, 0.04224317191983573, 0.06422414633561857, 0.06232216284843162, 0.04394449722894933, 0.026756199331430253, 0.06299409593339078, 0.0471481446584221, 0.04107988883333746, 0.0264371352022863, 0.07210021081846207, 3.8147815503180027, 32.223517298698425, 47.1164533495903, 41.94005571305752, 63.13630253076553, 71.87697350978851, 51.07041098177433, 43.5965958237648, 35.15250653028488, 0.8919401513412595, 0.6037653365638107, 9.968726132065058, 24.45063728839159, 11.770892478525639, 17.757742926478386, 27.103145755827427, 52.151908949017525, 47.0872101187706, 47.172580137848854, 53.323682472109795, 43.119706213474274, 49.815349727869034, 51.466684117913246, 49.0089076012373, 46.38829082250595, 43.42662714421749, 42.909307703375816, 40.09807415306568, 38.38266380131245, 38.97219456732273, 37.96817064285278, 36.76553517580032, 37.428466603159904, 34.87000308930874, 34.906325340270996, 36.52049012482166, 37.04328507184982, 36.45872823894024, 36.40148051083088, 35.7225139439106, 36.621310114860535, 38.30172814428806, 39.55686919391155, 40.129874646663666, 36.99205242097378, 37.68200419843197, 35.86393855512142, 36.49897187948227, 36.82275250554085, 36.65659122169018, 38.38987201452255, 36.3890627771616, 38.01211528480053, 35.41265957057476, 36.0771869122982, 35.49357622861862, 37.40240380167961, 43.80193680524826, 47.35291086137295, 45.5006318539381, 44.65002089738846, 47.640255242586136, 49.212223291397095, 49.11270283162594, 45.15718348324299, 46.1688107997179, 46.862288787961006, 47.53627762198448, 52.07223102450371, 43.18308301270008, 41.398075595498085, 51.33040443062782, 48.961125165224075, 49.84287545084953, 50.55334232747555, 48.34643214941025, 46.26911021769047, 47.80851401388645, 54.32696923613548, 39.111244305968285, 49.80639360845089, 48.506023585796356, 44.43572759628296, 34.21706132590771, 35.59946894645691, 34.3050342053175, 35.78950434923172, 35.2012275159359, 35.17945468425751, 36.06210172176361, 34.72799710929394, 34.277789667248726, 34.80404242873192, 36.83125264942646, 36.574781611561775, 35.90857096016407, 35.37330888211727, 34.54501032829285, 35.74968248605728, 34.29478235542774, 34.5255933701992, 35.088658556342125, 36.8992879986763, 40.4801170527935, 41.83141574263573, 41.89961448311806, 46.198183223605156, 46.16331249475479, 48.48911829292774, 47.249533608555794, 45.30208870768547, 44.99951854348183, 45.325347259640694, 49.782610684633255, 50.78423693776131, 49.422401413321495, 50.597074180841446, 53.557673916220665, 48.81297491490841, 52.17378057539463, 47.88292922079563, 51.11186295747757, 48.37789446115494, 42.017119377851486, 16.15477044135332, 9.620061591267586, 4.764129258692265, 4.129286399111152, 3.2381223561242223, 6.191082838922739, 3.334902925416827, 0.6237085664179176, 0.07914277666714042, 9.539409969002008, 36.61839187145233, 33.80240857601166, 25.13133466243744, 25.68181872367859, 45.64278602600098, 12.20368355512619, 0.13273842574562877, 0.021459543313540053, 0.02492872747097863, 0.05437782820081338, 0.00925368445678032, 0.038828910401207395, 0.03832952294033021, 0.024232349896919914, 0.02467529702698812, 0.10384139197412878, 0.045479659384000115, 0.06242290197405964, 0.016119041210913565, 0.02570257413026411, 0.038435646347352304, 0.03757501479412895, 0.055215994943864644, 0.03344015385664534, 0.039433716228813864, 0.020289853637223132, 0.014378536070580594, 0.02481906587490812, 0.10001478207414038, 0.038650806091027334, 0.021105987871123943, 0.002701197217902518, 0.01455945868656272, 0.03787148052651901, 0.04573827187414281, 0.014915299943822902, 0.007904866306489566, 0.033141057210741565, 0.026250156661262736, 0.050852192580350675, 0.08598673637607135, 0.029270508457557298, 5.434494037181139, 40.76475217938423, 50.73222532868385, 48.89282763004303, 68.89173209667206, 66.58897966146469, 48.50296474993229, 49.66316029429436, 38.496824875473976, 1.570878813508898, 0.6721945584286004, 8.354909028857946, 30.107788927853107, 16.875947043299675, 19.57215316593647, 32.09940455853939, 52.21649408340454, 49.0565000474453, 50.83484262228012, 55.08028641343117, 45.6752172857523, 50.75452633202076, 52.09582015872002, 51.50422230362892, 48.15237656235695, 45.914205461740494, 44.08528760075569, 42.595908120274544, 40.31459413468838, 39.89383511245251, 40.23316450417042, 40.35164214670658, 39.99853849411011, 37.214568480849266, 37.535879239439964, 37.74382688105106, 38.49097318947315, 37.28130429983139, 37.836139127612114, 38.020824417471886, 37.38136053085327, 39.62751120328903, 39.61021073162556, 41.69749192893505, 38.516830801963806, 38.82014952600002, 37.84296356141567, 37.76216469705105, 39.2825923115015, 38.572919592261314, 39.94610130786896, 38.42220067977905, 39.04172703623772, 36.08894348144531, 37.666436433792114, 37.24532023072243, 37.757171764969826, 46.41970753669739, 49.22197736799717, 48.9601182192564, 47.484418004751205, 50.219138860702515, 52.26514287292957, 50.36302573978901, 47.52496562898159, 46.144689694046974, 47.82068096101284, 49.95392069220543, 54.063506573438644, 44.54517312347889, 43.070658445358276, 52.546616569161415, 50.32432101666927, 53.0183232575655, 52.57807508111, 50.03290705382824, 48.49973492324352, 46.074340268969536, 54.12105828523636, 42.83407174050808, 50.42354889214039, 50.4447403550148, 44.56311956048012, 36.45416468381882, 37.07709565758705, 36.95881940424442, 37.68449306488037, 36.92786246538162, 37.732165306806564, 37.33682692050934, 37.79035538434982, 36.970287188887596, 37.40345634520054, 39.59158033132553, 38.56380768120289, 36.47306866943836, 36.9034031778574, 36.96891926229, 34.75495666265488, 36.731724590063095, 35.35680256783962, 36.16175137460232, 38.667393922805786, 41.38592004776001, 43.21823112666607, 43.478965535759926, 46.02797895669937, 48.74707505106926, 51.32684022188187, 46.964864283800125, 45.548269897699356, 45.57940162718296, 46.42029270529747, 52.09063343703747, 51.41015835106373, 51.8002188205719, 50.971259102225304, 55.08071579039097, 52.0352628082037, 54.23804260790348, 49.48619619011879, 51.83980129659176, 49.798113852739334, 46.99800230562687, 24.828394018113613, 16.415915228426456, 7.052469542250037, 3.5316974529996514, 3.3507694490253925, 3.233359311707318, 6.1521510779857635, 1.2161402986384928, 0.04180043259111699, 9.628255851566792, 41.131242513656616, 39.493663385510445, 33.45374308526516, 33.20716291666031, 50.120952129364014, 15.318561661988497, 0.2972839353606105, 0.04501716779486742, 0.019775504479184747, 0.08735597657505423, 0.018314826120331418, 0.03551828980562277, 0.10826387966517359, 0.02966980802739272, 0.014534488200297346, 0.03247965520131402, 0.06653760618064553, 0.04273956852557603, 0.05101576563902199, 0.020563049329211935, 0.029731769936915953, 0.04201011899567675, 0.09919145828462206, 0.11308628105325624, 0.14700783271109685, 0.18352265615249053, 0.09354522102512419, 0.18682081979932263, 0.2654564572731033, 0.18015514622675255, 0.207518249808345, 0.09394935754244216, 0.18555891641881317, 0.1605522949830629, 0.11346164450515062, 0.11815487509011291, 0.12727434863336384, 0.1242972826003097, 0.1629489570041187, 0.1331974143977277, 0.17384387785568833, 0.11762442503822967, 6.983209233731031, 46.89369410276413, 56.96494348347187, 54.6851722151041, 68.97535040974617, 74.22367438673973, 57.443649396300316, 55.62077321112156, 44.799896255135536, 1.9984904117882252, 1.7621351382695138, 18.20258315652609, 37.5070121884346, 23.875720538198948, 22.88637712597847, 34.080842435359955, 52.98439107835293, 48.25494445860386, 51.38721898198128, 56.47318907082081, 46.99772112071514, 51.672959849238396, 54.026488959789276, 54.10492815077305, 50.436889976263046, 47.600877955555916, 46.82820841670036, 44.7027962654829, 42.16314934194088, 42.2724998742342, 42.847154438495636, 41.931855753064156, 44.45005662739277, 39.73937340080738, 38.97379048168659, 39.05781917273998, 40.54346725344658, 40.790188014507294, 40.514155626297, 38.90856698155403, 40.02997800707817, 42.29757472872734, 43.07577297091484, 43.83501023054123, 39.93212565779686, 40.917093604803085, 40.740357488393784, 40.85779018700123, 39.649071246385574, 40.2935166656971, 42.18845598399639, 39.68848653137684, 41.79702378809452, 38.87092240154743, 38.89575406908989, 38.86023737490177, 40.215978026390076, 48.56526240706444, 51.302073150873184, 49.76779907941818, 46.68342098593712, 50.80988556146622, 53.84845331311226, 53.078261241316795, 49.15178753435612, 50.74328273534775, 49.16718050837517, 51.609229668974876, 56.06129117310047, 45.98642438650131, 43.65960404276848, 52.393154203891754, 53.31998907029629, 53.22923094034195, 56.23923562467098, 50.47305643558502, 51.05876840651035, 46.53827637434006, 54.35876592993736, 47.99968935549259, 52.84151114523411, 53.43617923557758, 47.090971916913986, 39.50066260993481, 37.374889478087425, 39.052556455135345, 39.539815708994865, 38.897680565714836, 39.60328750312328, 39.05890591442585, 39.69075880944729, 39.99566204845905, 38.13706398010254, 42.83072791993618, 40.22103175520897, 38.594776019454, 38.12749229371548, 38.35139907896519, 37.656085789203644, 38.8301657885313, 37.6193455606699, 37.66241244971752, 42.1132618188858, 44.40057948231697, 46.672963947057724, 45.56899018585682, 49.672994166612625, 51.8051053583622, 51.89515672624111, 49.13968898355961, 45.06936639547348, 47.799873277544975, 47.7366940677166, 53.02410654723644, 52.60687753558159, 52.90621407330036, 53.70946817100048, 56.622513458132744, 53.07130381464958, 54.53080549836159, 48.09450946748257, 50.12858211994171, 50.7904078066349, 49.95474524796009, 28.47766499966383, 16.58238049596548, 7.176687251776457, 9.577884804457426, 12.816905099898577, 11.700771041214466, 13.499339930713177, 2.52936277538538, 0.1432088974979706, 11.560891047120094, 48.139312863349915, 43.91121134161949, 36.791100203990936, 35.95107547938824, 58.795244470238686, 18.320813812315464, 0.39644103962928057, 0.2537608629791066, 0.15055896481499076, 0.1985952747054398, 0.13360693148570135, 0.17593965836567804, 0.16240948985796422, 0.08306036645080894, 0.1042710583715234, 0.18631330953212455, 0.18772025825455785, 0.20654443331295624, 0.15508541255258024, 0.09557627883623354, 0.07677750749280676, 0.13062962796539068], [0.0513130403123796, 0.010174450380873168, 0.02032533571764361, 0.07430438199662603, 0.05123531889694277, 0.03513738251058385, 0.05796102108433843, 0.04667249108024407, 0.04017030893010087, 0.00934778507144074, 0.04719531556474976, 0.04902717351797037, 0.0405653578491183, 0.1349232639768161, 0.033562849421286955, 0.00822308067654376, 0.0713502854341641, 0.01892135744128609, 0.021571145625784993, 0.0432371451461222, 1.6948155756108463, 18.697823882102966, 46.195652559399605, 36.22273430228233, 36.27198725938797, 54.412723034620285, 45.97666271030903, 45.13639859855175, 32.441910579800606, 0.3326029807794839, 0.03998384803708177, 3.609065101481974, 18.53171579539776, 4.820396164432168, 12.847801242023706, 32.900724560022354, 47.12282560765743, 55.68494416773319, 39.556040838360786, 44.39532056450844, 42.85781666636467, 51.81800186634064, 52.002614960074425, 49.347154051065445, 49.50345866382122, 46.8115197122097, 44.113383293151855, 42.691822573542595, 42.17137210071087, 37.58284091949463, 38.40159818530083, 35.287524685263634, 35.73175884783268, 35.76173543930054, 34.098747074604034, 35.71829617023468, 35.99980406463146, 34.363695457577705, 36.222392320632935, 36.440519616007805, 36.77953362464905, 39.3075455725193, 37.29852117598057, 35.66937759518623, 36.01516284048557, 35.865192487835884, 36.1935518682003, 35.75052984058857, 36.4924780279398, 37.151275277137756, 37.85832613706589, 37.943209782242775, 35.94561517238617, 35.749864876270294, 35.36318242549896, 36.04356251657009, 38.20199489593506, 42.108211889863014, 50.73178455233574, 50.68066969513893, 51.41139708459377, 48.69813747704029, 50.677705854177475, 50.21919205784798, 47.57397539913654, 46.54682971537113, 46.08646921813488, 49.007543474435806, 49.19885940849781, 43.463177382946014, 40.83603635430336, 46.30942605435848, 45.093578696250916, 48.43409724533558, 45.15486940741539, 46.9868803024292, 46.768912598490715, 52.74201728403568, 36.79455041885376, 43.63335505127907, 49.29813288152218, 46.370568573474884, 43.323367685079575, 35.63385710120201, 35.69977976381779, 34.624285474419594, 35.362703651189804, 36.11357755959034, 36.02085493505001, 36.06751263141632, 34.805968925356865, 33.83268915116787, 33.683459758758545, 36.32781766355038, 34.75081108510494, 34.78042669594288, 35.88823825120926, 34.87869702279568, 33.77862945199013, 35.39216347038746, 35.29033653438091, 38.78338269889355, 40.62957063317299, 42.51264698803425, 43.22514295578003, 45.032496973872185, 46.68991103768349, 50.31640604138374, 46.683219596743584, 43.089463636279106, 42.4792505800724, 43.354282826185226, 46.27397395670414, 47.35848516225815, 46.528377905488014, 49.54715631902218, 47.44545869529247, 48.598016649484634, 50.11234559118748, 48.91050048172474, 47.276512160897255, 47.0159525424242, 44.25486110150814, 30.872957669198513, 6.277430830523372, 2.6006939727813005, 0.908106027636677, 0.794014596613124, 1.8442006409168243, 2.954352395609021, 4.611456301063299, 1.6294714319519699, 0.035618271940620616, 11.267767176032066, 37.63091593980789, 35.12005627155304, 35.948347225785255, 35.640453547239304, 35.960943549871445, 6.139550004154444, 0.022036409136489965, 0.028286209126235917, 0.015510753783019027, 0.02737418941251235, 0.01844533093390055, 0.05523283798538614, 0.053542303503490984, 0.06786406898754649, 0.0685270072426647, 0.09331371547887102, 0.05244700856565032, 0.06532898158184253, 0.06022262336045969, 0.048679028332117014, 0.02305151501786895, 0.0421073997131316, 0.031704270440968685, 0.05640943149046507, 0.07958796137245372, 0.04417988791828975, 0.07442187139531597, 0.08739782628254034, 0.11446188145782799, 0.012871255476056831, 0.0039196891339088324, 0.04681165490183048, 0.05730553770263214, 0.021943559040664695, 0.00553198037778202, 0.007855492149246857, 0.023474663503293414, 0.05087512865429744, 0.044378160091582686, 0.0889695095247589, 0.10289995538187213, 0.026411193430249114, 2.229007654823363, 26.80944051593542, 54.97459888458252, 41.09801709651947, 48.107516169548035, 67.0394378900528, 51.50604620575905, 48.095022439956665, 35.90891674160957, 0.5743513524066657, 0.04485826655582059, 5.952578661963344, 24.085174798965454, 8.69592647999525, 16.48342240601778, 33.518362417817116, 49.78649787604809, 53.36457587778568, 42.55670942366123, 48.11847858130932, 44.35497812926769, 49.75359924137592, 52.475108206272125, 52.17337779700756, 50.61109162867069, 48.09510603547096, 45.93432538211346, 43.79404842853546, 43.65901507437229, 39.983495101332664, 39.89812508225441, 36.59411117434502, 38.09134103357792, 37.866480499506, 36.23286455869675, 37.01643191277981, 37.84846946597099, 36.65629863739014, 37.4017920345068, 38.16729515790939, 39.001320004463196, 41.233954802155495, 39.506210312247276, 37.16232888400555, 37.3988775908947, 38.19639019668102, 38.95213924348354, 37.99167238175869, 38.32600124180317, 39.71369817852974, 38.72062906622887, 39.80852968990803, 36.452606767416, 38.51523868739605, 37.84233659505844, 37.98741661012173, 40.03390319645405, 44.94637459516525, 51.659333780407906, 53.13635632395744, 50.33391930162907, 49.328649044036865, 51.60301700234413, 51.50391452014446, 49.51290115714073, 48.50971318781376, 48.61883573234081, 50.29777564108372, 51.513410210609436, 46.25845938920975, 42.14589826762676, 48.42427097260952, 46.175346449017525, 50.780573934316635, 46.06431260704994, 47.46078707277775, 45.983604937791824, 52.76152163743973, 41.009139865636826, 43.31957928836346, 51.690625101327896, 48.472133204340935, 44.445911049842834, 35.9161439538002, 36.69237770140171, 36.87881089746952, 36.73479102551937, 36.72750681638718, 37.985623106360435, 37.25847512483597, 38.035263642668724, 37.174203246831894, 35.845650136470795, 37.43897303938866, 36.69300086796284, 36.29551939666271, 37.962873727083206, 36.2419992685318, 36.10931038856506, 37.295944914221764, 37.177805453538895, 39.265117049217224, 42.981431633234024, 43.81971225142479, 44.82820853590965, 45.97692869603634, 48.39292265474796, 52.16381751000881, 47.694235146045685, 45.20498491823673, 43.08835409581661, 44.33316729962826, 47.11235336959362, 47.40728974342346, 47.32799179852009, 51.144248619675636, 49.25505839288235, 50.09476773440838, 49.41289432346821, 47.922154515981674, 48.12698632478714, 47.88618944585323, 45.386216193437576, 36.595517098903656, 9.928600285202265, 4.0966499503701925, 1.8808117951266468, 1.8038868228904903, 1.8494417471811175, 1.2446866231039166, 1.7440181854180992, 2.0512546179816127, 0.06933974800631404, 13.201210778206587, 43.83956998586655, 40.299782529473305, 36.21019497513771, 35.49969010055065, 44.32440496981144, 8.62846489995718, 0.042851770122069865, 0.05701937297999393, 0.015526595852861647, 0.009305362982559018, 0.04050298775837291, 0.02740221290878253, 0.10275337379425764, 0.0350827938382281, 0.042837699002120644, 0.058866927356575616, 0.07432018232066184, 0.05903951379877981, 0.07400377508020028, 0.04809568912605755, 0.03991569290519692, 0.04061613930389285, 0.10584096045931801, 0.1070732892549131, 0.11169902893016115, 0.11570788061362691, 0.17002643347950652, 0.23061933286953717, 0.18346424913033843, 0.08112678231555037, 0.22945291420910507, 0.14563009492121637, 0.13808102812618017, 0.15955827722791582, 0.1995194860501215, 0.14109349460341036, 0.18766213324852288, 0.07689304504310712, 0.14417851343750954, 0.2576303615933284, 0.16347573342500255, 0.14957996812881902, 2.4735841434448957, 30.908915139734745, 63.191726356744766, 45.90168133378029, 46.33667819201946, 63.069331124424934, 52.80387796461582, 56.56705543398857, 38.17410819232464, 0.9786114224698395, 0.3606500179739669, 7.136173825711012, 24.900014474987984, 8.916697483509779, 18.108756691217422, 42.50902958214283, 52.63988256454468, 55.30191332101822, 44.07894194126129, 47.03093133866787, 47.27539882063866, 51.83269947767258, 54.471935257315636, 53.803353533148766, 53.83818246424198, 48.88665296137333, 47.78687797486782, 47.21641458570957, 45.827159732580185, 42.52599187195301, 42.90409058332443, 38.555622920393944, 41.056268736720085, 39.67229939997196, 38.173435628414154, 40.00497914850712, 41.0537950694561, 37.602835446596146, 39.733092337846756, 40.46355754137039, 40.48816502094269, 43.956200927495956, 39.885274171829224, 38.96586790680885, 39.92117464542389, 40.643166303634644, 40.05332015454769, 38.563366904854774, 40.027211755514145, 41.13891430199146, 41.225276067852974, 42.26935364305973, 38.20320703089237, 38.380509316921234, 39.90545488893986, 39.853633269667625, 43.7181892991066, 45.572466999292374, 55.323423966765404, 53.90521466732025, 53.947605192661285, 51.67256847023964, 54.091514870524406, 55.09513981640339, 51.98499150574207, 50.47108434140682, 49.81899373233318, 53.107561469078064, 53.03790740668774, 49.54423047602177, 42.766762152314186, 49.04966801404953, 45.829998180270195, 49.68884691596031, 46.636159121990204, 47.41862453520298, 44.399040564894676, 50.35153515636921, 45.37773124873638, 46.828029826283455, 54.090363532304764, 50.42601116001606, 46.85364045202732, 38.979041799902916, 39.50199253857136, 38.434550017118454, 38.467137068510056, 38.49359504878521, 40.52174761891365, 40.55092625319958, 40.125064104795456, 38.25049929320812, 38.072463646531105, 40.045374780893326, 38.52290287613869, 37.82712981104851, 40.001753121614456, 37.64459900557995, 38.510903120040894, 39.521173909306526, 39.88282710313797, 43.09771679341793, 44.38433155417442, 46.274809911847115, 46.70790307223797, 48.79188224673271, 51.006023436784744, 53.92107121646404, 47.318066731095314, 46.15793198347092, 44.982993230223656, 43.82882036268711, 46.520018354058266, 48.279346749186516, 48.24158437550068, 50.64595475792885, 51.62728630006313, 50.10227993130684, 51.01787880063057, 49.20173205435276, 47.46479205787182, 49.28033843636513, 46.823477670550346, 39.9711761623621, 11.6632186062634, 4.131897334009409, 2.706556054763496, 5.389399006962776, 6.89441179856658, 7.716305321082473, 10.272810515016317, 3.7357764272019267, 0.106810606084764, 13.784963954240084, 50.8870480209589, 47.76702404022217, 45.46583712100983, 47.39793084561825, 49.62865434587002, 9.223477821797132, 0.1388202517409809, 0.14578686619643122, 0.07741663765045814, 0.15212044352665544, 0.09047798404935747, 0.16739673708798364, 0.24642100761411712, 0.15008127404144034, 0.19101189100183547, 0.1308817949029617, 0.20033053471706808, 0.1110177299415227, 0.18669273995328695, 0.171245307137724, 0.14039685542229563, 0.2125588574563153], [0.06585970622836612, 0.06267309479881078, 0.10306383643182926, 0.025246798977605067, 0.05080814240500331, 0.042071038187714294, 0.027617309569905046, 0.01825389208534034, 0.021914941826253198, 0.0592053726722952, 0.01068570385541534, 0.02664188818016555, 0.018718732571869623, 0.041851451533148065, 0.0559576008527074, 0.06564014183823019, 0.052844577076029964, 0.047506334813078865, 0.020142873145232443, 0.01974821941985283, 0.14224048383766785, 7.608396336436272, 47.25625544786453, 44.1029604524374, 27.857458479702473, 29.37951620668173, 40.857402607798576, 46.00803002715111, 34.87544819712639, 1.82376011274755, 0.201855173218064, 1.2159409280866385, 11.78960932418704, 0.2265958979842253, 1.4053716883063316, 22.292620986700058, 42.622312903404236, 51.150902062654495, 53.79059001803398, 50.37893168628216, 51.941920816898346, 48.9620067179203, 49.95623096823692, 52.9775058478117, 49.31396663188934, 48.874147832393646, 48.334117010235786, 45.70842370390892, 44.930966421961784, 39.85358007252216, 36.488780826330185, 37.32257768511772, 35.7898273319006, 35.62582053244114, 35.490190610289574, 34.42293807864189, 35.48753835260868, 35.746350064873695, 35.39393797516823, 36.364166513085365, 36.93280220031738, 36.15460775792599, 35.73865927755833, 35.83235464990139, 36.999948397278786, 37.593119367957115, 37.527698278427124, 35.69740869104862, 36.01394310593605, 37.27561600506306, 37.60509632527828, 37.128214314579964, 36.41363985836506, 35.610948130488396, 36.72826297581196, 36.992797181010246, 36.409965455532074, 40.40555365383625, 47.514250203967094, 48.7026060372591, 50.46233341097832, 49.46169510483742, 48.57979662716389, 49.34812679886818, 52.04722456634045, 48.4743332862854, 48.5426802188158, 49.03539597988129, 53.32403585314751, 44.46408547461033, 39.60912398993969, 44.79651063680649, 46.78978867828846, 48.5133495926857, 49.60421405732632, 47.44511291384697, 47.14027427136898, 38.152255564928055, 42.02142454683781, 51.71079061925411, 46.267597898840904, 49.03604194521904, 41.060178726911545, 34.27484482526779, 36.153251230716705, 36.29171960055828, 35.607646107673645, 35.627085864543915, 36.09709404408932, 35.95293737947941, 36.54129400849342, 35.84943473339081, 34.035256281495094, 35.88899441063404, 34.4838298112154, 34.84337031841278, 35.61467953026295, 36.50440938770771, 36.525654047727585, 36.94903872907162, 40.07967174053192, 43.05116169154644, 45.779723078012466, 47.08564840257168, 46.837453320622444, 48.79609242081642, 45.36482714116573, 44.633852764964104, 42.25622154772282, 45.38379192352295, 46.97917811572552, 49.18287366628647, 45.46887695789337, 47.47145690023899, 45.12274973094463, 44.73523512482643, 46.762825325131416, 49.76514682173729, 46.350247263908386, 49.726822078228, 46.420323103666306, 48.20716202259064, 37.2762543708086, 20.651612542569637, 2.7065190067514777, 0.23105190106434748, 1.2652439950034022, 2.1374138072133064, 1.1258687800727785, 0.06155890107038431, 1.3411895697936416, 1.398931983858347, 0.06955566845135763, 10.352553986012936, 32.73190721869469, 33.016945123672485, 39.6746476739645, 40.730196833610535, 34.709214717149734, 3.697507493197918, 0.025004305934999138, 0.051616901546367444, 0.12999788217712194, 0.03700710483826697, 0.08533898246241733, 0.027632089440885466, 0.059164606500416994, 0.04409686385770328, 0.0837574434990529, 0.035215311727370135, 0.07694207874010317, 0.03868602841976099, 0.09492794604739174, 0.07221010804641992, 0.060604699538089335, 0.026515337158343755, 0.0652206502854824, 0.07158746098866686, 0.002289548774569994, 0.018436503087286837, 0.02028907067142427, 0.05165557857253589, 0.053555339327431284, 0.054807917622383684, 0.07369615486823022, 0.04152488058025483, 0.06600343054742552, 0.07638349386979826, 0.01418969195583486, 0.029414626114885323, 0.025941540116036776, 0.07325918573769741, 0.060383320596884005, 0.03247777385695372, 0.028714905165543314, 0.01972489000763744, 0.32431452709715813, 10.5290013179183, 57.89979971945286, 42.295545637607574, 32.14424595236778, 42.02937752008438, 49.66426223516464, 51.288378685712814, 36.9116335362196, 1.4506483962759376, 0.12505580205470324, 0.4890977911418304, 19.950050488114357, 1.5949703520163894, 2.8605753276497126, 30.33110674470663, 44.24036867916584, 53.40365678071976, 52.02346824109554, 51.496250331401825, 49.80195164680481, 50.846944972872734, 52.81019702553749, 55.69486543536186, 50.484961196780205, 49.3929073959589, 49.579051807522774, 47.10422560572624, 45.501714795827866, 41.31265237927437, 37.72967644035816, 38.75184819102287, 37.278503850102425, 36.69513255357742, 35.636630952358246, 37.43108466267586, 36.678120866417885, 37.977544739842415, 37.90265455842018, 37.69664101302624, 38.21109540760517, 37.14821644127369, 38.10076452791691, 37.74195738136768, 39.827091693878174, 39.37291346490383, 38.39611127972603, 37.97066330909729, 37.49367870390415, 38.27797181904316, 39.717877954244614, 39.07598979771137, 37.39766925573349, 37.22646564245224, 38.028051629662514, 38.134822100400925, 36.62321001291275, 41.32128931581974, 48.92981864511967, 50.809395387768745, 51.49250753223896, 50.64399026334286, 50.08709594607353, 50.8112420886755, 54.49646294116974, 48.6596455425024, 50.27212701737881, 49.9875944852829, 53.692665472626686, 45.93181751668453, 42.101224064826965, 44.50188584625721, 46.594433560967445, 50.254701152443886, 51.73805795609951, 48.50141063332558, 48.65016125142574, 41.415414065122604, 41.69577822089195, 52.558270543813705, 48.39680604636669, 50.89233733713627, 42.596432492136955, 37.03223526477814, 36.68278321623802, 38.11332665383816, 37.451679557561874, 37.41296723484993, 37.000719755887985, 38.25985439121723, 38.15824784338474, 36.837602108716965, 36.058271527290344, 36.68820172548294, 36.622674241662025, 37.141874581575394, 35.962015092372894, 37.53595523536205, 37.05197140574455, 38.867521584033966, 41.722019612789154, 45.27453638613224, 47.197955176234245, 47.86247871816158, 48.676505237817764, 49.99056592583656, 48.50685954093933, 46.8354432284832, 44.204794988036156, 45.956250205636024, 47.49100685119629, 48.807499408721924, 46.37084595859051, 48.05512078106403, 46.121837720274925, 46.79328829050064, 47.77535319328308, 49.9874272942543, 47.30369970202446, 50.880398377776146, 47.59762533009052, 48.736686408519745, 41.77647829055786, 23.501917496323586, 3.8218648452311754, 0.5808226426597685, 3.143690535798669, 1.7739913333207369, 0.961396861821413, 0.19629203423392028, 0.3334388171788305, 0.8075853902846575, 0.0882346200523898, 12.447746358811855, 39.56320345401764, 40.602812469005585, 45.06901681423187, 45.652422308921814, 39.9888452142477, 4.984060982242227, 0.0521527915407205, 0.015741594179417007, 0.09380436415085569, 0.01237477908944129, 0.055849870695965365, 0.03759260740480386, 0.05997735097480472, 0.03931574814487249, 0.04312525525165256, 0.02016484628256876, 0.029980747494846582, 0.07120992304407991, 0.026543329113337677, 0.056502199950045906, 0.09851870141574182, 0.04546463089354802, 0.1485678122844547, 0.1501685951370746, 0.1393852339242585, 0.10185925653786398, 0.13969181512948126, 0.13793194550089538, 0.1300640669069253, 0.11415081768063828, 0.10475361763383262, 0.08184535938198678, 0.2547166304429993, 0.13608019798994064, 0.07332373032113537, 0.12609329482074827, 0.1966415561037138, 0.2669705275911838, 0.22030711668776348, 0.12455206189770252, 0.05366965975554194, 0.14372684236150235, 0.3623755706939846, 15.715984236449003, 65.3348721563816, 51.296783834695816, 38.25804188847542, 42.090599834918976, 52.23727136850357, 55.977061092853546, 42.19962738454342, 2.6330117136240005, 0.6237224000506103, 3.821472516283393, 20.896919779479504, 1.1523515777662396, 2.772916406393051, 30.680942572653294, 50.321980342268944, 52.89652839303017, 54.77524258196354, 51.514789536595345, 50.840025544166565, 50.57752422988415, 53.722163289785385, 58.45015078783035, 53.60019363462925, 52.11427576839924, 52.60072946548462, 49.04236100614071, 49.401734322309494, 43.75972867012024, 40.83631373941898, 40.904162898659706, 39.795895367860794, 39.169726967811584, 38.612733855843544, 38.413996919989586, 39.53389182686806, 40.05669057369232, 40.13047121465206, 39.67206001281738, 40.53863011300564, 39.22294691205025, 39.58208084106445, 40.12270823121071, 41.444794088602066, 42.457223162055016, 40.873950719833374, 39.19073984026909, 38.67974705994129, 40.63822276890278, 41.701242327690125, 41.35913148522377, 39.6229362487793, 39.217577800154686, 39.79362688958645, 40.0183392316103, 39.20321077108383, 45.015029311180115, 51.22768074274063, 53.54074962437153, 53.676064163446426, 52.23912946879864, 51.486028879880905, 53.07085923850536, 55.952062234282494, 51.46612174808979, 51.29570089280605, 52.72364906966686, 55.042269453406334, 49.849281907081604, 43.90663258731365, 44.75554883480072, 46.568853333592415, 52.90534391999245, 53.021853268146515, 49.61549945175648, 49.858921989798546, 44.78999398648739, 45.351330265402794, 53.068108186125755, 50.53183928132057, 53.539932668209076, 44.0657414495945, 37.533511966466904, 38.98634120821953, 40.303779914975166, 39.20688897371292, 39.16993595659733, 39.06888797879219, 40.8706296980381, 39.62254486978054, 40.20918019115925, 37.843943908810616, 39.97882515192032, 37.490353882312775, 39.146909192204475, 37.94146187603474, 39.12765942513943, 38.663130551576614, 40.82253947854042, 44.00775656104088, 46.98346808552742, 49.80961203575134, 51.76065534353256, 50.82617148756981, 52.671455070376396, 48.46071481704712, 49.47875238955021, 46.58698596060276, 48.82263019680977, 47.17894859611988, 48.88805128633976, 47.084402069449425, 48.15716810524464, 45.54662078619003, 46.62938788533211, 46.517058312892914, 52.60117784142494, 47.18448489904404, 50.14081746339798, 47.01906457543373, 49.31935474276543, 41.80108197033405, 27.655377723276615, 4.816072471439838, 1.0573286516591907, 3.4459524415433407, 5.184797085821629, 3.6029196437448263, 2.103219204582274, 6.485337149351835, 3.6464306339621544, 0.20290235843276605, 14.267104882746935, 44.06924866139889, 44.55413684248924, 49.16834704577923, 51.113933846354485, 47.215217649936676, 6.17789089679718, 0.09798807324841619, 0.14691476739244536, 0.2147917274851352, 0.13762523070909083, 0.1815250320942141, 0.09595840325346217, 0.1345382971339859, 0.1105220643512439, 0.16546495637157932, 0.13834763725753874, 0.17606552661163732, 0.1094090951664839, 0.1927325307042338, 0.18311781459487975, 0.22496974852401763, 0.19480555696645752], [0.04323178683989681, 0.013520783122658031, 0.02319811515917536, 0.02482232761394698, 0.054750712879467756, 0.054858331714058295, 0.056128547148546204, 0.07219090868602507, 0.01150879015767714, 0.024282238919113297, 0.0599038338259561, 0.015234469829010777, 0.07125539443222806, 0.08136784672387876, 0.043016801500925794, 0.11590604888624512, 0.03789070586208254, 0.02386603879131144, 0.058278749347664416, 0.0033732117071849643, 0.0562886506668292, 2.8535409551113844, 29.128055199980736, 53.93579162657261, 39.5804051309824, 23.38660318404436, 29.78352952748537, 39.10489484667778, 43.56783136725426, 4.722827849909663, 0.1444204684230499, 0.24438565276795998, 6.096069887280464, 1.5508702746592462, 0.14979352854425088, 3.395377630367875, 22.285336777567863, 45.38413390517235, 53.20192560553551, 52.6038832962513, 49.423868134617805, 49.309380277991295, 49.703821912407875, 50.5480682104826, 48.700318560004234, 50.83543919026852, 47.34405353665352, 45.35269819200039, 44.36507798731327, 42.74961367249489, 38.996714651584625, 37.22117632627487, 36.46925367414951, 35.42998284101486, 34.97876085340977, 33.643653094768524, 35.34120820462704, 36.52269780635834, 36.52907766401768, 36.898056864738464, 36.84970065951347, 37.43547722697258, 38.12241576611996, 36.32314391434193, 38.59991334378719, 38.44708174467087, 38.32005076110363, 36.58176563680172, 35.664164274930954, 35.38890704512596, 38.172588273882866, 37.79754839837551, 35.39861172437668, 37.19228647649288, 38.71312826871872, 36.47974871098995, 36.66685827076435, 38.69268536567688, 44.690750911831856, 45.39362959563732, 49.44331169128418, 48.12215678393841, 52.92594641447067, 49.66235093772411, 50.61850883066654, 48.87993112206459, 48.99079777300358, 50.02150386571884, 49.34281088411808, 42.58468732237816, 43.20716232061386, 52.3525495827198, 48.18855822086334, 49.43309783935547, 48.78199517726898, 46.933367773890495, 43.166553899645805, 47.51818299293518, 51.71705648303032, 49.883943647146225, 49.63306970894337, 45.925920233130455, 36.81181289255619, 36.02751597762108, 35.964253172278404, 35.020494014024734, 35.13851948082447, 34.961137399077415, 36.93377114832401, 35.50692491233349, 37.04907216131687, 34.88685518503189, 35.08494235575199, 34.72148805856705, 36.68895408511162, 36.376686841249466, 35.21566294133663, 35.73576383292675, 36.046704947948456, 39.14559446275234, 42.08819076418877, 44.79281723499298, 46.420098915696144, 46.40392318367958, 47.97230042517185, 45.402832701802254, 43.84780794382095, 46.59370020031929, 49.02999646961689, 48.42565029859543, 46.6635974496603, 46.04427628219128, 47.90804207324982, 45.45250363647938, 49.00635413825512, 45.487188175320625, 45.960494577884674, 47.09917567670345, 45.65405622124672, 46.8802048265934, 48.63947622478008, 44.58237312734127, 30.36656454205513, 8.150747884064913, 0.5697476025670767, 0.4419043828966096, 2.376784337684512, 0.2885190525557846, 0.3272378764813766, 0.1203195788548328, 0.35304784309118986, 0.5502332153264433, 0.08185780519852415, 10.973938442766666, 28.364776857197285, 35.09074084460735, 36.796594709157944, 31.8729842081666, 26.013649217784405, 1.480346058961004, 0.0671262777177617, 0.08705664615263231, 0.048432509138365276, 0.037575437818304636, 0.04043866581923794, 0.01845474136644043, 0.07171396748162806, 0.045729165722150356, 0.04544195828202646, 0.06819920803536661, 0.08157426767866127, 0.019417032308410853, 0.0914664134324994, 0.03672785693197511, 0.030823678825981915, 0.1328490799642168, 0.007105330669219256, 0.07555329779279418, 0.02831200803484535, 0.05270722038403619, 0.12866125936852768, 0.04138433636398986, 0.09617073912522756, 0.005702410880985553, 0.056796045901137404, 0.03407257128856145, 0.05177002145501319, 0.026519747370912228, 0.039334131142823026, 0.056421673216391355, 0.11799961037468165, 0.05057564609160181, 0.048763696249807253, 0.07885452650953084, 0.06983018145547248, 0.05081703333416954, 0.0367686045501614, 4.110297868028283, 37.27020509541035, 59.73019190132618, 37.2215411067009, 30.112238489091396, 41.10950008034706, 47.51253269612789, 45.455501675605774, 4.554936708882451, 0.07193670826382004, 1.0060323541983962, 8.291312791407108, 3.96818193141371, 0.5085846595466137, 5.702726868912578, 31.086264923214912, 46.855555549263954, 54.87751789391041, 51.248100847005844, 50.83209916949272, 49.23234321177006, 51.81758388876915, 53.097989782691, 51.81587018072605, 51.49521678686142, 49.77341137826443, 47.683740109205246, 45.81196814775467, 43.75992625951767, 40.786870792508125, 38.73935826122761, 38.82958061993122, 37.66564227640629, 36.91293306648731, 36.26398868858814, 37.41468094289303, 37.94540986418724, 38.59762206673622, 37.98754580318928, 37.80852980911732, 38.637208342552185, 40.40300399065018, 38.9980635792017, 40.96861504018307, 40.25383159518242, 39.43055637180805, 37.804076448082924, 39.228012040257454, 37.020699083805084, 39.25928816199303, 39.39107649028301, 38.51817212998867, 38.34235556423664, 39.473152086138725, 37.30284534394741, 39.160079285502434, 40.86561016738415, 46.88645549118519, 46.83727853000164, 49.904686734080315, 49.7165360301733, 52.8546242415905, 50.09100593626499, 51.095318645238876, 50.9878908097744, 50.34602165222168, 50.18143728375435, 50.979143679142, 44.44366157054901, 43.97437535226345, 52.61997543275356, 49.797745272517204, 51.565015241503716, 51.22345916926861, 49.69719506800175, 46.03060081601143, 48.43508519232273, 54.336274936795235, 51.99118137359619, 50.0758371502161, 49.27809655666351, 39.90272283554077, 36.89613416790962, 38.30619290471077, 38.198886662721634, 36.97242647409439, 36.47899255156517, 37.86540895700455, 36.86087965965271, 38.94192539155483, 36.688334718346596, 36.67773708701134, 36.19909577071667, 37.44464993476868, 37.97769293189049, 36.02314241230488, 37.53519907593727, 37.69857510924339, 41.265648901462555, 42.779856249690056, 46.87520429491997, 48.07462513446808, 47.845793813467026, 48.971149027347565, 46.89628556370735, 44.329880475997925, 47.861186787486076, 47.87236198782921, 47.01350547373295, 48.087973818182945, 46.42833687365055, 48.98240402340889, 47.1242543309927, 48.93969811499119, 45.63642896711826, 48.56399327516556, 47.56243921816349, 46.652961820364, 49.30817574262619, 47.80836582183838, 47.06794135272503, 34.321677312254906, 11.475412733852863, 1.8500438961200416, 0.693791649537161, 1.874008378945291, 1.039527200628072, 0.2185113716404885, 0.1217474635632243, 0.3870127064874396, 0.6080100650433451, 0.10418859092169441, 12.655678801238537, 34.70151633024216, 37.6448991894722, 39.0698417276144, 37.86464139819145, 32.53495618700981, 2.1849886793643236, 0.0738234406162519, 0.10271452978486195, 0.025703711471578572, 0.08575163141358644, 0.07312700923648663, 0.10324022267013788, 0.05848717410117388, 0.032975658468785696, 0.013803812271362403, 0.03131581921479665, 0.06684639156446792, 0.029901038979005534, 0.060195405094418675, 0.061154215363785625, 0.1061503024538979, 0.04016394872451201, 0.1763259165454656, 0.10159520781598985, 0.10375723242759705, 0.12611441634362563, 0.2364037506049499, 0.2375594526529312, 0.2575172286015004, 0.1735102231032215, 0.11150284961331636, 0.163974174647592, 0.25946011184714735, 0.08196644819690846, 0.22964039555517957, 0.2435973731917329, 0.14726460096426308, 0.23130142595618963, 0.11165823307237588, 0.11743814597139135, 0.1339245558483526, 0.1194021878472995, 0.17075731535442173, 4.767884407192469, 45.50575017929077, 66.17762893438339, 47.51575492322445, 34.05376508831978, 40.37501089274883, 50.7335514575243, 50.30920162796974, 6.56719378195703, 0.2746167266741395, 1.9795485469512641, 13.315299656242132, 5.3210117015987635, 0.4156866209814325, 6.231185887008905, 32.467259019613266, 50.32523676753044, 53.16705487668514, 52.62048080563545, 51.75150543451309, 51.55160956084728, 52.641706466674805, 54.82579126954079, 52.168400064110756, 54.377829506993294, 51.98594145476818, 49.608561024069786, 47.43547663092613, 45.986333191394806, 42.647429555654526, 41.52215413749218, 40.50315521657467, 40.16772821545601, 39.09749284386635, 38.87979492545128, 38.79296958446503, 40.57198092341423, 40.57108797132969, 40.42728088796139, 40.404915288090706, 40.97429573535919, 41.9723691791296, 41.21777527034283, 41.936271116137505, 41.423150449991226, 42.62743502855301, 39.8072225600481, 39.94966931641102, 37.648034021258354, 41.66822589933872, 42.05104015767574, 39.744864106178284, 40.53468972444534, 41.9782018661499, 39.06660050153732, 40.802142173051834, 42.61635482311249, 49.32870224118233, 48.66593040525913, 53.66520054638386, 52.27790638804436, 55.07604964077473, 53.514215648174286, 52.44844123721123, 52.52430036664009, 52.994627729058266, 52.65196971595287, 51.01589150726795, 45.915972366929054, 45.66329352557659, 54.49671372771263, 51.658999398350716, 52.384296879172325, 52.68302924931049, 52.11708761751652, 49.22190897166729, 49.86244060099125, 55.86456812918186, 54.6464940905571, 53.564346358180046, 51.03539206087589, 41.381113305687904, 39.23341915011406, 40.015060007572174, 39.816801846027374, 38.323432579636574, 38.56668412685394, 40.16536854207516, 39.39249001443386, 41.00124008953571, 39.51689533889294, 39.958412647247314, 37.07915514707565, 40.46018712222576, 40.02609081566334, 38.351482674479485, 40.30845366418362, 39.44892458617687, 43.57123218476772, 46.19893178343773, 49.569259732961655, 49.45305056869984, 48.85000392794609, 50.240474715828896, 48.39096195995808, 46.174582690000534, 48.858325481414795, 47.7457831799984, 46.74794912338257, 49.46102254092693, 46.35878160595894, 49.44702789187431, 46.862098798155785, 50.25529772043228, 47.03873232007027, 48.60048271715641, 49.23341475427151, 48.49702186882496, 50.429924950003624, 50.309042036533356, 50.241272673010826, 36.759337708353996, 13.492159266024828, 2.5890226615592837, 1.7291862750425935, 5.590740703046322, 5.000069998204708, 2.0111791184172034, 0.44945986184757203, 2.397492751479149, 1.7265029065310955, 0.16179539234144613, 15.657261237502098, 40.34118510782719, 44.068329110741615, 47.414908334612846, 44.900397062301636, 37.90285214781761, 2.8139031445607543, 0.16947797150351107, 0.19145737256621942, 0.19558822590624914, 0.1517365305335261, 0.19388839602470398, 0.21141872566659003, 0.15449243655893952, 0.11730196187272668, 0.19472441053949296, 0.16741462284699082, 0.24007067258935422, 0.13305230968398973, 0.33740203420165926, 0.20839092641836032, 0.1814474182901904, 0.164224530744832], [0.07767992196022533, 0.006885903112561209, 0.07873078822740354, 0.05627881721011363, 0.043630550208035856, 0.07798224323778413, 0.03840141849650536, 0.06419944766093977, 0.03430029559240211, 0.04014687561721075, 0.028897462361783255, 0.0463268729072297, 0.0391646283242153, 0.04192512824374717, 0.04538713954389095, 0.013294766686158255, 0.03793903822952416, 0.04101392303709872, 0.01222051534568891, 0.0037806278214702616, 0.08474670408759266, 0.18401128618279472, 10.685574766248465, 44.04481217265129, 45.240239426493645, 25.624417103827, 34.62388649582863, 31.334594897925854, 45.9491103887558, 10.74637245386839, 0.04874186226516031, 0.4341060435399413, 2.9174390388652682, 5.098082888871431, 0.5148539668880403, 0.1277768865111284, 5.291190901771188, 37.43432588875294, 49.08714920282364, 53.38034123182297, 53.20999637246132, 49.44766625761986, 50.00475436449051, 51.31525084376335, 49.38878081738949, 48.927698358893394, 48.210559040308, 45.24224191904068, 43.30991640686989, 41.4986751973629, 38.78992974758148, 37.22619205713272, 36.212744638323784, 35.19320994615555, 34.62545961141586, 34.732496067881584, 36.138519421219826, 36.929914355278015, 36.63968212902546, 37.19004079699516, 36.423591524362564, 36.68442092835903, 37.309392392635345, 38.246042132377625, 37.16765999794006, 35.52626207470894, 36.346862241625786, 36.62005238234997, 37.19024978578091, 35.84081679582596, 37.81735673546791, 36.59663423895836, 36.449008360505104, 37.57087916135788, 36.46921947598457, 36.51156060397625, 38.110598400235176, 38.10222364962101, 40.586340352892876, 44.2173533141613, 46.749077662825584, 48.05904597043991, 49.76758249104023, 48.67386817932129, 48.52534554898739, 49.66363146901131, 47.018297016620636, 48.43120560050011, 46.080454140901566, 39.38198737800121, 46.575259789824486, 52.49791078269482, 48.833569809794426, 46.699117943644524, 42.79296934604645, 48.457359597086906, 49.47218254208565, 48.75941298902035, 45.6584981828928, 48.45568388700485, 46.866833344101906, 40.134248211979866, 35.52113234996796, 35.78535497188568, 34.078604355454445, 36.09213151037693, 34.06391054391861, 36.381710171699524, 35.59575654566288, 34.62178900837898, 37.81672976911068, 35.67734956741333, 34.39021423459053, 33.899109587073326, 36.44226752221584, 34.30265553295612, 35.04512809216976, 35.34274332225323, 35.187289863824844, 37.236709892749786, 41.881029680371284, 46.02180428802967, 46.131656393408775, 45.721882581710815, 44.30047385394573, 46.23283736407757, 49.32455666363239, 47.11342491209507, 47.03796096146107, 44.85169127583504, 47.546407878398895, 46.81422896683216, 45.44471025466919, 47.24657356739044, 46.9667299836874, 48.07242885231972, 44.348556473851204, 43.05148467421532, 46.04886643588543, 45.172101482748985, 41.49094261229038, 38.25666256248951, 18.645291700959206, 3.475743792951107, 0.5935688805766404, 1.3532579597085714, 2.477043620310724, 0.46626633033156395, 0.20058458670973778, 0.08327833522344008, 0.176359906909056, 0.18676146282814443, 0.4373942030360922, 14.409415796399117, 29.734200574457645, 37.293801829218864, 48.50998297333717, 41.215784177184105, 16.12334992736578, 0.42476258240640163, 0.02702476402191678, 0.02093304519803496, 0.014326495747809531, 0.07697520079091191, 0.03490666364086792, 0.005362175597838359, 0.04187580881989561, 0.058276589697925374, 0.02042900818196358, 0.03862347650283482, 0.035310596067574807, 0.024251462054962758, 0.027405836444813758, 0.022278900323726702, 0.03664725227281451, 0.08159930031979457, 0.08061387663474306, 0.029179252123867627, 0.030694303932250477, 0.03906943304173183, 0.045231370168039575, 0.02311318377905991, 0.010761591238406254, 0.03816062868281733, 0.046185760947992094, 0.025743972983036656, 0.05305524682626128, 0.02149886786355637, 0.06362164858728647, 0.03281430072092917, 0.06059880317479838, 0.10321900466806255, 0.04441156044777017, 0.04711658111773431, 0.05654832813888788, 0.03372078215761576, 0.03398618158826139, 0.21732135268393904, 17.636744119226933, 53.56162950396538, 46.82276330888271, 25.39525520056486, 37.232780903577805, 39.90298502147198, 49.966444820165634, 11.145674977451563, 0.055895865298225544, 0.12466525426134467, 5.3103565983474255, 2.809356451034546, 1.2802883377298713, 0.6195440492592752, 9.783108942210674, 43.10656651854515, 47.75260001420975, 53.542170748114586, 50.89394085109234, 51.6535808891058, 52.24148914217949, 52.78620511293411, 52.39380016922951, 51.107109412550926, 48.950079157948494, 48.2780472189188, 46.147854924201965, 42.48122647404671, 39.940405413508415, 39.277071207761765, 36.233685314655304, 37.8136595338583, 37.35921151936054, 38.02912697196007, 37.92892634868622, 38.79163585603237, 37.62574061751366, 38.562861531972885, 38.259307220578194, 38.76222923398018, 38.1446635723114, 40.52781589329243, 39.265219643712044, 37.98778139054775, 38.48032236099243, 39.42440450191498, 39.12564933300018, 37.60950408875942, 38.00235740840435, 38.861723095178604, 38.21595914661884, 38.73168647289276, 37.95401260256767, 38.600464314222336, 39.00117941200733, 41.596839129924774, 42.81741723418236, 48.984106332063675, 50.20419426262379, 49.957492500543594, 51.31970040500164, 50.8838751912117, 50.460547506809235, 51.169878244400024, 49.992256835103035, 50.49055449664593, 48.19626420736313, 41.28325715661049, 46.356874108314514, 54.524448439478874, 49.650088995695114, 48.05673949420452, 45.62875717878342, 50.196818858385086, 51.51296943426132, 50.94342939555645, 47.62594521045685, 50.0817496329546, 48.72921600937843, 41.81368209421635, 36.56126953661442, 37.02659636735916, 36.85140296816826, 37.304289266467094, 35.739609226584435, 38.45790356397629, 37.87620797753334, 36.30624242126942, 39.743929356336594, 36.77827589213848, 36.59982606768608, 36.61302275955677, 37.02047109603882, 36.57425343990326, 37.06562787294388, 36.45981878042221, 37.0122255384922, 38.89051415026188, 44.41152669489384, 47.198768332600594, 48.94985496997833, 46.96300998330116, 46.26343712210655, 45.49146294593811, 48.134775906801224, 47.75683678686619, 48.26955087482929, 46.37587308883667, 48.27029563486576, 47.22353160381317, 46.975059136748314, 47.77687311172485, 49.40641187131405, 48.01382839679718, 45.65937593579292, 45.82630477845669, 48.08443620800972, 48.62111181020737, 44.33441363275051, 42.15096339583397, 23.156654722988605, 4.405034277588129, 1.0567608196288347, 1.7715160036459565, 0.8878839877434075, 1.35249562561512, 0.07570855508674867, 0.04788016573002096, 0.09343626632471569, 0.1743159579928033, 0.16519184602657333, 15.745867732912302, 33.67002747952938, 41.02830223739147, 52.282355949282646, 43.84953685104847, 20.882100574672222, 0.5266387376468629, 0.02516433894925285, 0.0683336184010841, 0.0445932567527052, 0.020933919076924212, 0.03409653523704037, 0.018722599161264952, 0.04406765292515047, 0.03504157124552876, 0.02378366596531123, 0.08709721936611459, 0.03089286183239892, 0.034277994054718874, 0.05843345003086142, 0.022482990934804548, 0.015748776313557755, 0.08722392623894848, 0.12394880715874024, 0.10756709205452353, 0.22143101028632373, 0.1362749226973392, 0.14190178248099983, 0.2155935438349843, 0.13654939859407023, 0.1154912773927208, 0.20284255617298186, 0.23571120807901025, 0.148262151342351, 0.15449537546373904, 0.17702458921121433, 0.20381711481604725, 0.1735219787224196, 0.1680239854613319, 0.0975872392882593, 0.12119563223677687, 0.17304010223597288, 0.13169686601031572, 0.25641887972597033, 0.3329675830900669, 21.499613039195538, 61.23419679701328, 56.83720953762531, 33.98090399801731, 44.6576052904129, 42.00981616973877, 55.738061517477036, 14.039517045021057, 0.14395453326869756, 1.0575927374884486, 8.589289952069521, 11.211129315197468, 3.1861786684021354, 0.43272849870845675, 11.887116841971874, 46.04329213500023, 49.594547376036644, 54.372635185718536, 52.67240881919861, 52.2528163343668, 51.93940915167332, 55.041232109069824, 54.0704981982708, 51.8887996673584, 51.63386754691601, 50.05702055990696, 46.096318289637566, 44.190705344080925, 41.38254962861538, 42.01076991856098, 39.00899559259415, 39.84917990863323, 40.21946623921394, 38.641513511538506, 39.47488859295845, 40.59545986354351, 39.2926237732172, 40.83091422915459, 40.287562385201454, 41.0651146620512, 40.50280563533306, 42.585120499134064, 39.580564722418785, 39.36544306576252, 41.68744146823883, 39.08578187227249, 40.678550004959106, 39.457158744335175, 40.83971455693245, 39.97632868587971, 40.799254328012466, 41.77783861756325, 39.25193935632706, 40.889165103435516, 41.034454107284546, 42.843784019351006, 45.40309488773346, 50.02447910606861, 51.64514534175396, 52.31300510466099, 54.19858932495117, 54.22246724367142, 51.9947873800993, 54.12351295351982, 51.176592484116554, 50.741204246878624, 47.619287967681885, 40.971168503165245, 51.1984147131443, 56.871187314391136, 52.50737987458706, 50.907631516456604, 46.99420630931854, 53.67755368351936, 53.661742731928825, 52.695541977882385, 49.030524641275406, 52.594277411699295, 52.45473749935627, 44.96805243194103, 39.23780411481857, 38.87996591627598, 38.58592249453068, 39.889066368341446, 36.9681479036808, 40.69527670741081, 39.32588718831539, 38.93442839384079, 42.33323961496353, 38.57084110379219, 38.592515140771866, 37.04480119049549, 39.532235115766525, 37.48178914189339, 39.796058759093285, 38.10261882841587, 39.02212008833885, 39.793649688363075, 46.07998676598072, 50.29301829636097, 50.64218915998936, 49.506772086024284, 48.92780855298042, 49.77379895746708, 49.51354332268238, 48.66758331656456, 48.549291864037514, 47.018236219882965, 48.35037253797054, 48.3104594796896, 47.95705184340477, 49.655663296580315, 49.81431998312473, 49.46573048830032, 47.16531492769718, 46.899427995085716, 50.237301886081696, 50.811743661761284, 43.86116422712803, 42.266853377223015, 23.322114944458008, 6.021695528179407, 3.349743979051709, 4.719550050795078, 6.760575380176306, 3.348260158672929, 0.6366121990140527, 0.4078180744545534, 0.4036350332899019, 0.34042563289403915, 0.6915878865402192, 19.04485546052456, 45.02610191702843, 45.07067732512951, 55.61588667333126, 54.86853137612343, 25.471234023571014, 0.9843503020238131, 0.13110507745295763, 0.10638568943249993, 0.1297796462313272, 0.1123799271590542, 0.1485306306858547, 0.122304148535477, 0.2060455468017608, 0.130476983031258, 0.1296293910127133, 0.18637017288710922, 0.15709722647443414, 0.17237694875802845, 0.1253146631643176, 0.09625844613765366, 0.11076095426687971, 0.21299071318935603], [0.05996634121402167, 0.06837480017566122, 0.07536390912719071, 0.086089108226588, 0.06282766189542599, 0.06953925214475021, 0.09638410658226348, 0.014482039696304128, 0.01123850832300377, 0.007818892208888428, 0.03916580833902117, 0.023404161329381168, 0.02793737188767409, 0.027800486459454987, 0.05405038522440009, 0.06511387749924324, 0.07435596126015298, 0.03988151700468734, 0.09308197244536132, 0.05333565248292871, 0.11480939952889457, 0.02000284472160274, 1.6962049948051572, 23.79107628017664, 48.0811607837677, 35.35384252667427, 31.549910344183445, 28.48800614476204, 40.209005400538445, 10.921120326966047, 0.10949601550237276, 0.32242828456219286, 4.7697121091187, 2.930291136726737, 1.0890612239018083, 1.7089947522617877, 0.8437145047355443, 18.378739804029465, 44.342127218842506, 52.600383684039116, 53.315030336380005, 51.57098852097988, 49.10782389342785, 49.53183934092522, 49.76657174527645, 47.973459362983704, 48.84987473487854, 48.09116184711456, 45.54374814033508, 42.788918763399124, 41.29603587090969, 39.384518042206764, 39.458127692341805, 38.33082318305969, 38.7011057138443, 36.49300619959831, 38.46257731318474, 37.3551419377327, 37.94865109026432, 36.81952267885208, 37.28526368737221, 37.20948055386543, 38.39010760188103, 37.20968194305897, 37.926813662052155, 38.884430676698685, 39.86790530383587, 37.9000972956419, 37.38609507679939, 37.15621121227741, 37.95138694345951, 37.06163048744202, 37.12489329278469, 37.08419747650623, 38.40656451880932, 36.6774483025074, 38.17479595541954, 38.25765050947666, 40.23120000958443, 42.4407472461462, 44.00035835802555, 45.585211515426636, 48.81946496665478, 48.03044490516186, 50.30860126018524, 48.578869476914406, 48.27430061995983, 47.39389926195145, 44.605494886636734, 40.25164671242237, 48.70563827455044, 49.314756989479065, 48.1203518807888, 45.46767622232437, 43.62826332449913, 42.916971892118454, 42.415471002459526, 42.66238175332546, 43.29621434211731, 39.86897684633732, 37.792475670576096, 35.21334886550903, 34.98912289738655, 34.24871362745762, 35.65286748111248, 36.06429040431976, 35.183714255690575, 34.28465969860554, 35.302248895168304, 34.50709216296673, 36.08519308269024, 35.33593788743019, 35.324948877096176, 36.248880699276924, 35.96225827932358, 35.43373703956604, 35.69811165332794, 33.387702628970146, 34.97054189443588, 35.92111028730869, 38.77327524125576, 40.5686940997839, 43.881637528538704, 44.93559077382088, 48.45123432576656, 48.87137018144131, 44.06354516744614, 47.22382418811321, 45.55789478123188, 45.618919506669044, 43.885129541158676, 45.13261780142784, 45.507672876119614, 45.89948885142803, 47.836643904447556, 47.13147394359112, 50.62038213014603, 47.33981296420097, 45.32169945538044, 45.52525453269482, 44.974341094493866, 30.436765775084496, 6.8324527982622385, 0.3169611201155931, 0.4805258964188397, 0.6725152849685401, 0.2304862509481609, 0.1738591809407808, 0.07771588643663563, 0.07221692096209154, 0.055258560823858716, 0.34574944409541786, 0.6290943024214357, 17.88284931331873, 32.853329703211784, 30.044596418738365, 49.63302031159401, 33.576457500457764, 5.5105384066700935, 0.012373228000797099, 0.04275243736628909, 0.05268534558126703, 0.1304018628434278, 0.04545621122815646, 0.016575790432398207, 0.04132506473979447, 0.03179136518156156, 0.14463331637671217, 0.03701252622704487, 0.006437208512579673, 0.060444210103014484, 0.05536609060072806, 0.02242813880002359, 0.07564470070064999, 0.02767969450360397, 0.14192959817592055, 0.09777144034160301, 0.06214296015969012, 0.038733032342861407, 0.02592941342300037, 0.04044849927595351, 0.05737010083976202, 0.08913402882171795, 0.028756231658917386, 0.05023543817515019, 0.010508275827305624, 0.0399970100261271, 0.04369539536128286, 0.04929406466544606, 0.005489922405104153, 0.036022939093527384, 0.05249207548331469, 0.028665539357461967, 0.03056950623431476, 0.05171554039407056, 0.13138731621438637, 0.05922156633459963, 0.020889796542178374, 3.0663454486057162, 33.62178526818752, 54.08869542181492, 36.739362180233, 32.64158606529236, 35.39354279637337, 47.98806957900524, 13.723469004034996, 0.09285117193940096, 0.2280685119330883, 5.160081787034869, 2.653991337865591, 1.031340539921075, 1.4090308919548988, 0.6809540383983403, 23.093234226107597, 45.862224251031876, 52.90908671915531, 54.284669905900955, 50.526644960045815, 50.273445546627045, 52.62571692466736, 51.818754225969315, 50.474097579717636, 50.57209052145481, 50.45299731194973, 46.658137142658234, 45.65459579229355, 43.60419541597366, 41.37080445885658, 40.027983114123344, 39.58923205733299, 39.57899920642376, 37.46942080557346, 40.21736495196819, 38.587712198495865, 39.393230974674225, 38.559445515275, 39.233544543385506, 40.24806350469589, 40.11659435927868, 38.26643943786621, 38.019049912691116, 39.82560217380524, 41.35657042264938, 39.105062037706375, 38.450645953416824, 38.11503276228905, 39.49848912656307, 38.931681141257286, 37.6109404116869, 39.0236210078001, 38.876207917928696, 38.586382269859314, 40.62453590333462, 40.441898703575134, 41.05194836854935, 45.29180645942688, 45.473991483449936, 48.43601234257221, 49.07790809869766, 50.406301617622375, 52.34864339232445, 50.8578047901392, 50.210228338837624, 48.57739895582199, 45.60587860643864, 44.04512755572796, 49.493909776210785, 52.4061419069767, 50.78810133039951, 47.97007754445076, 45.17196089029312, 44.418411925435066, 45.52289105951786, 46.06106378138065, 46.45110905170441, 42.735375836491585, 41.27088122069836, 37.27722331881523, 37.23757244646549, 35.88617496192455, 36.24982684850693, 38.206794038414955, 36.72630228102207, 36.53755120933056, 36.72637067735195, 37.970256730914116, 37.9527472704649, 37.90660634636879, 36.64016470313072, 37.11018048226833, 35.46708025038242, 36.833015754818916, 38.10768395662308, 34.787095338106155, 36.27859890460968, 38.0862645059824, 40.17832584679127, 42.92978100478649, 47.10370883345604, 48.35411533713341, 49.48728293180466, 50.334998443722725, 46.631245985627174, 49.172101244330406, 46.66588492691517, 46.81675963103771, 46.06729544699192, 45.882032588124275, 46.35462462902069, 48.1839756667614, 47.73820638656616, 49.54320453107357, 50.66710062325001, 50.08229300379753, 47.24574141204357, 45.902836471796036, 46.03695407509804, 33.93396511673927, 8.540473021566868, 1.0542170936241746, 0.8946358691900969, 1.495217748451978, 0.7203230727463961, 0.0718972334288992, 0.0860106261097826, 0.08927977178245783, 0.08386308079934679, 0.6017583911307156, 0.47606481704860926, 20.50075303763151, 38.66492785513401, 32.52434715628624, 52.01703138649464, 42.04897686839104, 8.65636870265007, 0.07226623667520471, 0.07826664907042868, 0.027907069998036604, 0.0370400524843717, 0.05182223525480367, 0.029974580247653648, 0.009885624131129589, 0.03737833452760242, 0.03446858128882013, 0.044097312857047655, 0.09142005146713927, 0.04980671430530492, 0.0386966485530138, 0.0321115610859124, 0.010985804256051779, 0.012550087358249584, 0.0764948085998185, 0.18269361782586202, 0.26453942991793156, 0.11545048153493553, 0.31748733250424266, 0.15874172182520851, 0.15984957019099966, 0.16522211080882698, 0.10938612569589168, 0.13869435380911455, 0.08913199533708394, 0.13761573121882975, 0.27719183068256825, 0.15789506491273642, 0.1846464755362831, 0.09954066103091463, 0.15418931376188993, 0.1910432244767435, 0.10100587576744147, 0.15413047629408538, 0.22935622720979154, 0.19963855622336268, 0.08189739135559648, 3.849026025272906, 43.00421521067619, 60.9608356654644, 47.3359789699316, 40.28330661356449, 38.98750014603138, 50.92450261116028, 15.461149010807276, 0.3665944130625576, 1.0460353014059365, 12.812139205634594, 9.412898607552052, 5.503182001411915, 4.676403841003776, 2.098187324590981, 24.244545847177505, 48.630972281098366, 54.99715827405453, 52.49409198760986, 50.77134422957897, 51.34643577039242, 53.61877083778381, 53.33276778459549, 52.296931967139244, 52.36955367028713, 53.02493490278721, 48.924764916300774, 47.17902459204197, 45.745669305324554, 43.31336282193661, 42.60226517915726, 42.99560867249966, 42.95466586947441, 39.39644940197468, 43.13895598053932, 41.51501812040806, 40.21317757666111, 39.83754113316536, 40.38165673613548, 41.54384717345238, 41.92329101264477, 40.77716991305351, 40.87942622601986, 41.94188341498375, 42.42606483399868, 42.02943451702595, 40.265808552503586, 41.376705542206764, 41.163742169737816, 41.22306078672409, 39.383849278092384, 40.419225320219994, 41.925004720687866, 40.614439845085144, 42.26027213037014, 43.373354002833366, 43.253618627786636, 46.65569007396698, 46.01431868970394, 50.1127065718174, 51.01162053644657, 51.556568294763565, 53.94047297537327, 51.285095661878586, 51.79114110767841, 51.680821627378464, 44.96089741587639, 45.20412236452103, 53.99107865989208, 54.279559180140495, 53.73739667236805, 50.833147913217545, 47.39559017121792, 46.465821862220764, 47.12694078683853, 46.36071190237999, 47.09299720823765, 44.3951191753149, 42.00845964252949, 37.97999180853367, 37.34055072069168, 36.06396742165089, 39.146403819322586, 41.05140499770641, 39.10253517329693, 38.28339792788029, 39.42916564643383, 40.03242887556553, 39.641319662332535, 39.98620815575123, 39.40888613462448, 40.05849167704582, 40.153919756412506, 37.88901329040527, 40.17047546803951, 36.085652858018875, 38.467745035886765, 40.08959300816059, 42.42911987006664, 45.63780449330807, 48.06905843317509, 49.83550004661083, 51.37061767280102, 51.896144673228264, 47.13762581348419, 51.51793196797371, 48.255035653710365, 46.76732048392296, 45.75603134930134, 46.714066341519356, 47.379285246133804, 47.78373174369335, 50.483931452035904, 51.74888737499714, 53.50425258278847, 50.61399847269058, 49.17285740375519, 47.47124791145325, 46.340778172016144, 35.81305168569088, 9.840616956353188, 0.7879146770574152, 0.7550966099370271, 2.7344216220080853, 2.0556797180324793, 0.7446164160501212, 0.15660200617276132, 0.34284090797882527, 0.19253863720223308, 1.389791218098253, 1.5423214458860457, 25.21122347563505, 45.17024338245392, 41.259664222598076, 58.40171858668327, 46.90305680036545, 8.862281553447247, 0.28449014062061906, 0.13680820033187047, 0.08813984037260525, 0.22880067030200735, 0.10183788268477656, 0.08483680081553757, 0.08484372505336069, 0.1600722738658078, 0.2662410557968542, 0.10655967111233622, 0.3561796766007319, 0.10390680487034842, 0.128406539442949, 0.10651644843164831, 0.17492156533990055, 0.11798810708569363, 0.3293401433620602], [0.01746035624819342, 0.034056307122227736, 0.03808954206760973, 0.05398264198447578, 0.06536375862197019, 0.03087799846980488, 0.07552663984824903, 0.017606342262297403, 0.031958355830283836, 0.06159779331937898, 0.022010543434589636, 0.029032794845988974, 0.0060339036645018496, 0.010433658444526372, 0.019089049419562798, 0.008859680110617774, 0.04286814189981669, 0.020460504929360468, 0.076269128912827, 0.014470981695922092, 0.07737164865829982, 0.011316090585751226, 0.0876098801381886, 13.16623080521822, 42.83072791993618, 31.675307415425777, 27.10134655237198, 30.511496365070343, 29.608541317284107, 14.054280202835798, 0.32291483657900244, 0.025766565813682973, 2.3754076240584254, 0.6984430155716836, 0.6361498706974089, 0.5500058212783188, 0.2700684004230425, 2.7763233985751867, 26.648040376603603, 49.25240993499756, 50.462451204657555, 52.75604613125324, 51.60128429532051, 52.26676158607006, 49.07704934477806, 50.21949224174023, 48.40509720146656, 49.48605179786682, 47.918749898672104, 45.554330572485924, 43.432744815945625, 46.47553414106369, 43.52835148572922, 44.070608988404274, 42.6261430978775, 44.38846953213215, 42.273199036717415, 39.350870847702026, 39.18604329228401, 38.68812181055546, 37.31940485537052, 36.271048709750175, 35.94759866595268, 37.51122236251831, 37.16921791434288, 38.26602146029472, 37.74202577769756, 37.857740968465805, 37.46416188776493, 38.853895515203476, 40.7356533408165, 36.91070258617401, 37.94684238731861, 37.75523006916046, 36.80081628262997, 36.47529534995556, 36.30541406571865, 36.4909353107214, 37.45953753590584, 39.63639512658119, 42.11579628288746, 44.551412388682365, 48.418358489871025, 46.878152936697006, 45.098526030778885, 48.26787896454334, 47.917233780026436, 44.14699628949165, 44.780593290925026, 42.89290018379688, 50.64939737319946, 49.21074137091637, 46.84742018580437, 43.4723424911499, 38.51208105683327, 38.33445578813553, 38.12601037323475, 36.28322325646877, 35.7253447920084, 33.93236920237541, 36.703872084617615, 35.67198425531387, 34.90652672946453, 35.480219945311546, 35.008232071995735, 36.43890090286732, 36.43428415060043, 33.776140585541725, 33.65814171731472, 36.20080567896366, 36.65692940354347, 35.71397580206394, 33.72558429837227, 34.7797617316246, 36.42005391418934, 37.38353781402111, 39.49774816632271, 36.758444756269455, 34.97556522488594, 33.60083319246769, 34.042004719376564, 36.82114899158478, 38.21860000491142, 42.06030786037445, 44.72507447004318, 44.326304867863655, 45.972114354372025, 46.46809794008732, 47.22699701786041, 44.938212633132935, 45.61410516500473, 43.8456192612648, 46.259245947003365, 45.23046255111694, 46.76457703113556, 45.64090892672539, 48.6318576335907, 44.818469658493996, 44.509196653962135, 48.50481905043125, 38.29339139163494, 13.614228665828705, 1.3748565944842994, 0.7289351325016469, 0.30130705854389817, 0.026265661981597077, 0.1272320610587485, 0.12548425875138491, 0.0816527646384202, 0.05907745609874837, 0.14983001252403483, 0.12931139557622373, 1.1654145643115044, 25.984744168817997, 28.53737309575081, 29.212057292461395, 40.60725063085556, 23.016130663454533, 1.3616800890304148, 0.10119070022483356, 0.024759601292316802, 0.020391737525642384, 0.01241151354406611, 0.04980567529855762, 0.05197339218284469, 0.01989322579902364, 0.041915576803148724, 0.028425938835425768, 0.06972867049626075, 0.04044434695970267, 0.12413176882546395, 0.03857415336824488, 0.03101739421254024, 0.021082684434077237, 0.027507275044627022, 0.04632839802070521, 0.14006876677740365, 0.033474392839707434, 0.08803074466413818, 0.029530041210819036, 0.064793106430443, 0.030358569310919847, 0.004550671437755227, 0.03728624142240733, 0.05140995366673451, 0.015790798570378684, 0.051593868993222713, 0.07819104648660868, 0.012917324293084675, 0.08290802579722367, 0.0534802636684617, 0.010586975949991029, 0.04254993124050088, 0.06691628703265451, 0.013357948500924977, 0.09433764920686372, 0.08644645975437015, 0.05835461910464801, 0.33164771797601134, 19.97565731406212, 49.75644528865814, 37.64928035438061, 32.1376571059227, 33.455737978219986, 36.5969268232584, 14.767100103199482, 0.2854024479165673, 0.05759931686043274, 1.196215117815882, 1.652841365430504, 1.0095503716729581, 1.9562549656257033, 0.15002389118308201, 4.275226593017578, 31.331912241876125, 50.310193374753, 51.864838153123856, 53.145772218704224, 51.157753095030785, 52.70333155989647, 50.97868390381336, 54.03591625392437, 49.90698181092739, 50.978626906871796, 49.821011424064636, 47.12966524064541, 45.21981932222843, 47.11299553513527, 45.75019106268883, 45.77772818505764, 43.54906417429447, 45.216718688607216, 43.570753410458565, 40.76164394617081, 41.304399222135544, 40.86730107665062, 39.433603808283806, 39.35620956122875, 38.19752633571625, 40.35120137035847, 37.99936316907406, 39.81859914958477, 38.626420721411705, 38.230736553668976, 40.35610310733318, 39.930818527936935, 42.35751271247864, 39.26426209509373, 39.30060334503651, 39.14614923298359, 39.65679243206978, 39.04852867126465, 36.75109975039959, 39.38096143305302, 39.46922309696674, 40.405120477080345, 45.85040308535099, 46.20659597218037, 49.329849779605865, 49.66669410467148, 48.31100285053253, 50.15880949795246, 51.050606444478035, 46.16851061582565, 45.614572539925575, 45.045093297958374, 52.5361443310976, 52.85019747912884, 48.704555332660675, 46.392170414328575, 40.84007553756237, 40.185982435941696, 40.232605934143066, 39.64821629226208, 37.52341590821743, 35.91016687452793, 37.946477606892586, 35.918066650629044, 36.52148947119713, 36.32443584501743, 36.94445237517357, 36.96587562561035, 37.327038645744324, 35.6443065404892, 36.455122232437134, 38.35332937538624, 38.6247868090868, 37.31220044195652, 36.69838137924671, 35.507814064621925, 37.792673259973526, 39.44007866084576, 41.0086876899004, 38.684561401605606, 36.139720156788826, 36.30396634340286, 36.605309173464775, 38.07721719145775, 41.535537019371986, 45.37252552807331, 46.286095306277275, 48.105680868029594, 46.27375736832619, 47.47058294713497, 48.75528261065483, 46.74665719270706, 45.30646227300167, 45.50845563411713, 47.95088857412338, 46.89828425645828, 49.48091447353363, 47.1137060970068, 48.98586183786392, 47.164889350533485, 47.950812578201294, 49.48323234915733, 40.16192212700844, 17.4742591381073, 2.250908254645765, 0.7611562160309404, 1.062574745155871, 0.13668843253981322, 0.2011798188323155, 0.12337779873632826, 0.07608866086229682, 0.06900699125253595, 0.0758156247320585, 0.6554696965031326, 1.607517753727734, 29.385312795639038, 36.60905957221985, 32.95253477990627, 46.44198574125767, 29.720352217555046, 1.855348648969084, 0.054347166369552724, 0.03069010523176985, 0.026499616615183186, 0.08980885628261603, 0.04600238738930784, 0.010193482758040773, 0.012895571016997565, 0.011050378525396809, 0.01117568923291401, 0.027241960960964207, 0.08973260060884058, 0.06867004136438482, 0.054185129556572065, 0.07972870967932977, 0.05472214390465524, 0.028208252078911755, 0.04725450555270072, 0.2292946437955834, 0.07651708045159467, 0.12402956024743617, 0.18794091360177845, 0.17403588630259037, 0.13495777384378016, 0.23700201069004834, 0.12867035809904337, 0.15308870875742286, 0.13053369795670733, 0.20235109113855287, 0.16138639475684613, 0.1590074849082157, 0.1285240362631157, 0.15038018143968657, 0.09613697140594013, 0.12843328644521534, 0.1932038983795792, 0.13852337782736868, 0.22490613162517548, 0.12954000674653798, 0.12142871113610454, 0.6827770499512553, 23.628169521689415, 56.94563291966915, 43.170068711042404, 36.545849964022636, 40.552381575107574, 38.904926776885986, 18.997853882610798, 0.9893573052249849, 0.09016276424517855, 6.88068313524127, 3.202492380514741, 1.5286580915562809, 6.242292216047645, 1.2204676726832986, 4.511735402047634, 33.05485188961029, 52.010400742292404, 51.140312030911446, 52.32118606567383, 51.62137761712074, 53.37012358009815, 52.85183899104595, 55.15344388782978, 53.4850750118494, 53.71294118463993, 52.604369670152664, 48.38479109108448, 46.77273899316788, 51.08988493680954, 48.096033185720444, 48.29557567834854, 46.17868646979332, 47.89073400199413, 45.4882825165987, 42.566881477832794, 42.993815168738365, 42.588559314608574, 40.97007796168327, 41.12215720117092, 39.56080198287964, 41.701268926262856, 40.68690575659275, 41.95458613336086, 39.921034052968025, 41.19950205087662, 41.76374517381191, 41.53013750910759, 44.28831070661545, 40.964959636330605, 40.46412371098995, 40.071528777480125, 41.8302758038044, 40.270729288458824, 37.96374388039112, 40.82323484122753, 41.09241619706154, 43.386679887771606, 45.312750935554504, 46.988343223929405, 52.85321071743965, 49.9469480663538, 49.78004202246666, 50.81077091395855, 52.09860920906067, 46.8411011248827, 44.75283198058605, 46.006510108709335, 54.49288733303547, 54.23011243343353, 50.515644550323486, 48.751684203743935, 41.4812683314085, 42.67996720969677, 41.600733920931816, 40.912590846419334, 40.27288377285004, 36.6433185338974, 39.952127784490585, 39.2720440775156, 38.64062435925007, 37.8421314060688, 39.43338721990585, 38.99982288479805, 39.98543679714203, 35.29811851680279, 37.678295597434044, 40.28780937194824, 40.7941360026598, 39.41838562488556, 38.09736751019955, 37.43615739047527, 40.25443196296692, 40.73260970413685, 42.994586527347565, 39.554049745202065, 38.515276685357094, 37.16527372598648, 37.748268842697144, 40.23082762956619, 43.04899200797081, 46.45636796951294, 48.7358732521534, 49.34191793203354, 48.74606050550938, 49.27315682172775, 49.77688439190388, 49.014367908239365, 47.33796626329422, 45.35629279911518, 48.03182803094387, 47.11057886481285, 49.87100154161453, 48.00628960132599, 51.21884621679783, 50.12964606285095, 49.47936415672302, 51.57675661146641, 40.77058106660843, 17.225799970328808, 2.477987869642675, 1.3905008300207555, 1.668792909476906, 0.4539362294599414, 1.0623613628558815, 0.5254285619594157, 0.2981308742891997, 0.25494334171526134, 0.405215184437111, 1.6812523221597075, 3.1080897711217403, 35.691879987716675, 40.23361288011074, 38.659057170152664, 51.42431639134884, 33.51518578827381, 2.3104151990264654, 0.29876045300625265, 0.16534909227630123, 0.10338171312469058, 0.17425869387807325, 0.15313215408241376, 0.16320293478202075, 0.115456886269385, 0.16932097758399323, 0.1110883749788627, 0.21881111024413258, 0.23913285025628284, 0.3117732109967619, 0.1562310362351127, 0.22556836484000087, 0.1533923065289855, 0.16878139169421047, 0.15464341908227652], [0.028234184574102983, 0.15138113085413352, 0.047925900580594316, 0.019333203017595224, 0.04014162492239848, 0.08820442206342705, 0.037044716882519424, 0.008058801649895031, 0.04193161461444106, 0.00934859957851586, 0.04631480929674581, 0.06624756744713522, 0.09653671440901235, 0.019304617344459984, 0.0683593338180799, 0.0773365524946712, 0.004119666855331161, 0.05336267036909703, 0.06869004224427044, 0.05686364442226477, 0.06504218603367917, 0.012820478659705259, 0.06135766030638479, 4.965448155999184, 34.99027043581009, 43.90917085111141, 25.67231733351946, 31.426164284348488, 29.75820578634739, 17.493526004254818, 0.750686174724251, 0.1442968859919347, 2.4318013479933143, 0.5789871630258858, 0.1991052192170173, 1.0626220051199198, 0.6547702371608466, 0.25948202004656196, 8.352895136922598, 36.813857182860374, 48.958286717534065, 53.16782623529434, 50.162225514650345, 51.06281898915768, 51.81066446006298, 50.7200887799263, 47.292402908205986, 47.36820124089718, 49.900913536548615, 49.72671948373318, 47.83060982823372, 50.17758049070835, 45.94560317695141, 47.04042322933674, 48.848411813378334, 50.62006674706936, 47.63887211680412, 43.56428235769272, 40.86688689887524, 40.11137343943119, 35.98209321498871, 37.96105742454529, 36.692620888352394, 34.72854807972908, 37.0623030513525, 36.12755320966244, 37.38017499446869, 37.729155868291855, 36.57520718872547, 39.88171376287937, 40.38636088371277, 37.327004447579384, 36.6691305488348, 37.228836715221405, 37.429538145661354, 35.731762647628784, 37.09013655781746, 34.39846359193325, 37.01079301536083, 38.58145393431187, 42.02611729502678, 42.73765191435814, 44.35033857822418, 46.42447628080845, 47.98379860818386, 47.865712344646454, 47.767563611269, 44.78779770433903, 44.84870083630085, 40.25903731584549, 48.22793170809746, 49.08470593392849, 47.73717664182186, 44.509892016649246, 40.81083230674267, 39.60405506193638, 35.58174669742584, 35.65857097506523, 36.65108911693096, 34.594153091311455, 34.08215716481209, 34.615918323397636, 34.71529819071293, 35.20801015198231, 34.90432284772396, 36.861252039670944, 36.48052006959915, 33.96611139178276, 34.32670444250107, 34.507019966840744, 35.54614260792732, 34.8285511136055, 36.013441532850266, 35.304821357131004, 35.574055910110474, 36.05721518397331, 34.800653010606766, 36.2558077275753, 38.700193762779236, 36.613455936312675, 33.13287690281868, 32.31399804353714, 33.10883179306984, 36.274134144186974, 38.99055138230324, 40.352143719792366, 45.03158122301102, 45.8553846180439, 47.47840292751789, 46.13521680235863, 44.829489067196846, 43.48780766129494, 43.71231481432915, 48.22674237191677, 48.281831815838814, 46.401559710502625, 43.409797847270966, 42.454548105597496, 48.405940756201744, 44.714066460728645, 27.457058764994144, 6.310555078089237, 0.28483675327152014, 0.28217063227202743, 0.5842444184236228, 0.1803289572126232, 0.10180565863265656, 0.03960687041399069, 0.07069662402500398, 0.05007865576772019, 0.21640821418259293, 0.5469761963468045, 4.906474370509386, 30.090465657413006, 27.591337859630585, 30.78609813004732, 34.109363704919815, 9.81968292966485, 0.09752957441378385, 0.023770706211507786, 0.07072855121805333, 0.10586430100374855, 0.039604636549483985, 0.06708184533636086, 0.0402442453923868, 0.026235855475533754, 0.02348322046600515, 0.060239414451643825, 0.042549864447209984, 0.04325937989051454, 0.03083721559960395, 0.04118740376725327, 0.08424050742178224, 0.027370118732505944, 0.07060703937895596, 0.039760602594469674, 0.032042552484199405, 0.05279590332065709, 0.04516610199061688, 0.04601656983140856, 0.027091514639323577, 0.10121215571416542, 0.028940026386408135, 0.033522591620567255, 0.04144717771850992, 0.043864400940947235, 0.026724893687060103, 0.012229454514454119, 0.05377013541874476, 0.06592131190700457, 0.03833459551970009, 0.05041970231104642, 0.042369511429569684, 0.03202416577551048, 0.07223896274808794, 0.020644206888391636, 0.022255559779296163, 0.02087494245643029, 0.0714287452865392, 8.159163482487202, 43.97679202258587, 45.80269664525986, 28.01210068166256, 32.359021827578545, 32.96462573111057, 17.4387576431036, 1.004255237057805, 0.1061312886304222, 0.11485852228361182, 0.8063282514922321, 0.23045540729071945, 1.0215855133719742, 0.4527241241885349, 0.28437715605832636, 10.937864128500223, 41.278906390070915, 49.63380306959152, 53.12163591384888, 49.836275205016136, 51.83088697493076, 52.64894887804985, 52.138104289770126, 51.1668536067009, 49.77796733379364, 53.309577628970146, 51.10496252775192, 48.93552213907242, 52.30313703417778, 48.22276018559933, 47.646410912275314, 49.79342110455036, 52.1297637373209, 50.07724307477474, 46.043588519096375, 42.27812737226486, 41.914783269166946, 38.17207150161266, 40.15045054256916, 38.709780648350716, 37.450281232595444, 39.420920088887215, 39.79561798274517, 39.22084182500839, 39.461463913321495, 37.85645663738251, 41.36641949415207, 41.90713427960873, 39.32024449110031, 37.94135928153992, 38.725815787911415, 38.989605233073235, 37.85110652446747, 38.713048473000526, 37.481291368603706, 37.67352305352688, 41.1067870259285, 42.54662476480007, 45.40483899414539, 46.032656505703926, 46.478456184268, 49.962474033236504, 51.13140910863876, 49.62771579623222, 44.76250246167183, 44.0413923561573, 41.765067502856255, 51.17797181010246, 52.6375836879015, 49.76556859910488, 47.082494571805, 42.93975926935673, 40.98705165088177, 36.94763280451298, 37.10965231060982, 38.54642741382122, 35.86007036268711, 35.77372759580612, 37.0421527326107, 36.448107808828354, 38.14432919025421, 37.14172638952732, 37.92066939175129, 37.28649482131004, 36.38199895620346, 37.206189930438995, 36.479535922408104, 36.99744813144207, 36.851691752672195, 38.39713342487812, 36.742838993668556, 38.089220747351646, 38.15373748540878, 38.272986486554146, 38.7397800385952, 40.76757162809372, 37.63968966901302, 35.771877095103264, 33.68438310921192, 35.458644703030586, 39.018992856144905, 41.57595545053482, 43.17862585186958, 47.1468935161829, 46.689447462558746, 48.693665117025375, 48.96807499229908, 46.46957986056805, 44.57916609942913, 45.00726632773876, 46.951333209872246, 47.9150602966547, 48.80219109356403, 47.486621886491776, 46.06053560972214, 51.36543095111847, 46.463051810860634, 29.807654432952404, 7.073629181832075, 1.0541648464277387, 3.2964387768879533, 3.4242285322397947, 0.4071721388027072, 0.16657384374411777, 0.06775668021873571, 0.03433714322454762, 0.10736800351878628, 0.4916063690325245, 1.0596819128841162, 5.7678895723074675, 37.31525927782059, 31.289582513272762, 34.24065425992012, 40.19654206931591, 13.998820278793573, 0.20470469375140965, 0.027058257146563847, 0.12387879294692539, 0.08111245144391432, 0.011135670774820028, 0.08272784718428738, 0.05977740896923933, 0.03091884256718913, 0.022697666427120566, 0.0022315826345220557, 0.037825022081960924, 0.008271139377029613, 0.0035006913412871654, 0.013380865093495231, 0.013505891929526115, 0.037883996847085655, 0.023866267001722008, 0.028973432308703195, 0.11460754278232343, 0.1828327853581868, 0.1499329780926928, 0.17423539044102654, 0.19913049676688388, 0.1527208706829697, 0.16030918224714696, 0.13222941634012386, 0.19701766170328483, 0.13458747183904052, 0.1468817566637881, 0.09067363644135185, 0.2851073700003326, 0.17754703148966655, 0.1383001694921404, 0.15127570135518909, 0.10566490818746388, 0.12627139542018995, 0.17774862848455086, 0.1429605600424111, 0.12090758988051675, 0.1060668182617519, 0.3096493030898273, 9.56742586567998, 51.40161640942097, 53.75206768512726, 35.627659633755684, 40.897319465875626, 39.182486683130264, 23.788824900984764, 1.6899973154067993, 0.3069442341802642, 5.2327486127614975, 3.2237691013142467, 0.4222151159774512, 2.563397786580026, 2.992645315825939, 1.055738318245858, 12.02524608001113, 41.49321489036083, 49.75485697388649, 55.087008252739906, 50.92405043542385, 53.093464225530624, 54.42686967551708, 54.41142350435257, 52.71607607603073, 52.710900753736496, 55.80849453806877, 53.77700574696064, 50.74251137673855, 55.00352293252945, 50.74909642338753, 49.93225425481796, 53.13973054289818, 55.618770718574524, 52.83814452588558, 48.05144637823105, 44.38032276928425, 43.83310653269291, 38.77283066511154, 42.839444652199745, 39.58602502942085, 38.630288913846016, 41.60182826220989, 40.008782744407654, 40.995908975601196, 40.77790327370167, 40.32431021332741, 42.927881106734276, 43.319123312830925, 40.92460200190544, 39.49331000447273, 40.58623395860195, 40.826780050992966, 40.28564728796482, 41.16958625614643, 39.73862484097481, 40.6934680044651, 44.34465788304806, 45.0360231846571, 46.59761779010296, 47.5508726388216, 48.86963747441769, 53.156278654932976, 52.12758265435696, 52.21360243856907, 46.48594558238983, 44.3315713852644, 44.6389102935791, 53.27157586812973, 52.95527324080467, 51.66637860238552, 49.00396026670933, 44.221559688448906, 43.50156672298908, 38.381710052490234, 39.31348465383053, 40.55773548781872, 36.49346597492695, 37.704081013798714, 39.197682067751884, 38.178272768855095, 39.10527482628822, 39.1141739487648, 39.801674857735634, 39.64358814060688, 37.806778103113174, 37.95473836362362, 37.29491516947746, 38.397540003061295, 39.24702621996403, 41.017818599939346, 39.09500777721405, 41.26574769616127, 40.46466328203678, 38.58254827558994, 39.44220654666424, 42.55317181348801, 41.15113064646721, 36.59904330968857, 36.092279702425, 37.31997862458229, 40.65332695841789, 42.46786259114742, 44.100399389863014, 50.24714335799217, 48.96044880151749, 51.80600970983505, 50.170011296868324, 47.69700139760971, 46.20069108903408, 45.33730901777744, 47.68483825027943, 48.88298615813255, 50.944470539689064, 48.94792087376118, 48.83513532578945, 52.47806444764137, 45.82720533013344, 31.258756667375565, 7.689984133467078, 0.9439734311308712, 2.9722560849040747, 3.217432228848338, 0.7994723506271839, 0.6203481811098754, 0.2380660129711032, 0.3661625424865633, 0.3660113818477839, 0.866192732937634, 3.067775359377265, 8.310287073254585, 39.575985968112946, 37.07455359399319, 41.78233377635479, 45.89796893298626, 15.566647499799728, 0.29736399825196713, 0.10130775917787105, 0.19871910946676508, 0.35348838195204735, 0.23230426042573527, 0.21440022974275053, 0.1802286336896941, 0.133385029330384, 0.1479542491142638, 0.152654314879328, 0.16107084840768948, 0.12164011932327412, 0.09894318020087667, 0.07781748645356856, 0.21966293250443414, 0.11055717535782605, 0.10316723986761644, 0.141682373941876], [0.0217215307202423, 0.059354451586841606, 0.03449961048318073, 0.006864580745968851, 0.0379226516088238, 0.020236393029335886, 0.04593199097143952, 0.060860862940899096, 0.05980106121569406, 0.03975688072387129, 0.04132823371037375, 0.02462098480464192, 0.017738915812515188, 0.0046632185967609985, 0.015242910831148038, 0.031152650626609102, 0.036030215851496905, 0.028761901667166967, 0.020787077737622894, 0.05190983836655505, 0.06830129786976613, 0.009693932024674723, 0.10905960298259743, 0.837372763780877, 17.09132708609104, 38.794253915548325, 35.221343636512756, 34.35072675347328, 33.911884501576424, 23.652761802077293, 2.043915311805904, 0.04235063861415256, 0.1976867375196889, 0.7565310329664499, 0.9383255685679615, 0.41014767601154745, 0.6243693747092038, 1.3471800670959055, 1.7677448247559369, 17.97871246933937, 41.522484719753265, 51.87445543706417, 53.821600154042244, 50.42003408074379, 50.55865444242954, 51.45066037774086, 51.673472821712494, 48.01293924450874, 49.718622118234634, 50.25425277650356, 49.00015287101269, 50.20460084080696, 48.445215448737144, 49.62256707251072, 49.96868669986725, 47.50646062195301, 48.1089448928833, 48.10833312571049, 46.17004573345184, 41.835838705301285, 39.02261786162853, 37.35816277563572, 36.02968946099281, 35.310532450675964, 37.796017080545425, 36.75156332552433, 37.01295129954815, 38.390730768442154, 39.07298795878887, 39.364067539572716, 39.832802787423134, 40.42287692427635, 39.88352246582508, 37.2325187176466, 35.7924909889698, 35.960882753133774, 35.4153536260128, 35.7453279197216, 37.661952674388885, 38.248151019215584, 42.332187071442604, 42.56071820855141, 46.626701429486275, 46.7261952906847, 47.42778204381466, 48.084174022078514, 46.075617000460625, 43.21676440536976, 44.70723442733288, 39.12267789244652, 49.33531768620014, 52.25997895002365, 48.31370070576668, 45.58375999331474, 45.153174698352814, 44.79607366025448, 41.704114973545074, 37.19344161450863, 33.69802437722683, 34.297632202506065, 35.021926537156105, 34.53832648694515, 35.7245734333992, 35.71131594479084, 35.39727799594402, 36.38367086648941, 35.886604338884354, 35.5986025929451, 34.6442724019289, 35.51866628229618, 36.12842336297035, 35.0065715610981, 35.44778488576412, 35.65920174121857, 36.18836894631386, 36.73668332397938, 35.23912288248539, 34.887957125902176, 34.74547237157822, 36.81202948093414, 35.673709362745285, 34.04245689511299, 32.97995410859585, 34.11374866962433, 36.263365522027016, 37.80689209699631, 41.38880409300327, 45.27302406728268, 44.80692207813263, 48.16360875964165, 46.510602459311485, 45.015637278556824, 44.62421268224716, 44.52616274356842, 42.65399940311909, 43.37882950901985, 43.5280779004097, 48.247591853141785, 44.24566939473152, 35.85141442716122, 13.515971638262272, 0.9669332834891975, 0.2707128814654425, 2.1234697429463267, 1.5546217421069741, 0.10020000729127787, 0.07517369667766616, 0.052491875103442, 0.10334788603358902, 0.3476626117480919, 0.14492180402157828, 1.7283399892039597, 17.908410541713238, 29.8097937181592, 25.823313631117344, 37.14292332530022, 27.390395142138004, 1.641945568844676, 0.034816667102859356, 0.037585445679724216, 0.009011994789034361, 0.031167363704298623, 0.00853105711939861, 0.032826783644850366, 0.08101024286588654, 0.03150685544824228, 0.0930158470873721, 0.013674536639882717, 0.047792057957849465, 0.01148368144640699, 0.015795333092682995, 0.10338154985220172, 0.017372684487781953, 0.027239270675636362, 0.04677049539168365, 0.054302103162626736, 0.01607613950909581, 0.026240391853207257, 0.020552950554701965, 0.04771249972691294, 0.021220208109298255, 0.01202902547447593, 0.026624091478879564, 0.10638028659741394, 0.02005806607485283, 0.04807920602615923, 0.02805430838634493, 0.01452363614589558, 0.03357633053383324, 0.010564417443674756, 0.024226839450420812, 0.009518931747152237, 0.043506886140676215, 0.02926155815657694, 0.014618348104704637, 0.02395192383119138, 0.030557726495317183, 0.029156377277104184, 0.05610310261545237, 1.754381179343909, 25.263086892664433, 47.07092419266701, 36.30769394338131, 38.475918397307396, 39.71214786171913, 25.21966092288494, 2.058942555449903, 0.053241488785715774, 0.16252763976808637, 0.437331447028555, 0.1841187640093267, 0.24618162045953795, 0.35695346945431083, 1.2538999412208796, 1.6768998932093382, 20.968376845121384, 44.15285937488079, 51.52790263295174, 52.59927034378052, 51.585834324359894, 52.34262831509113, 52.0380936563015, 52.784423008561134, 49.371841326355934, 50.493278950452805, 52.678340300917625, 50.33625617623329, 51.052749529480934, 50.86626313626766, 51.46623194217682, 51.55756004154682, 50.06531931459904, 50.13531915843487, 49.18417699635029, 46.120465993881226, 43.340200781822205, 40.709617137908936, 38.619208708405495, 37.56834849715233, 38.56211297214031, 38.86008158326149, 37.61012725532055, 38.73244263231754, 40.19562251865864, 42.36730858683586, 40.07746785879135, 40.96226178109646, 41.478992253541946, 40.97983203828335, 38.26439514756203, 37.956262081861496, 36.4625546336174, 37.82169610261917, 37.79709242284298, 39.000461250543594, 39.99943904578686, 43.25782500207424, 44.13521312177181, 46.67806327342987, 48.93943592905998, 49.227623865008354, 49.117699563503265, 47.827057018876076, 45.02546355128288, 44.86040040850639, 41.03888466954231, 50.02233222126961, 53.02289441227913, 50.15219405293465, 48.12862403690815, 46.2802854180336, 46.70506462454796, 44.0791205316782, 38.98985981941223, 36.252277716994286, 36.90035954117775, 36.12835116684437, 36.20260298252106, 37.282809019088745, 37.82100073993206, 37.97320157289505, 37.20129959285259, 37.620113119482994, 37.565859630703926, 36.76233194768429, 37.1789225935936, 38.39916631579399, 36.889309734106064, 36.89347431063652, 37.15862788259983, 38.19261319935322, 36.315939500927925, 36.71027474105358, 36.70382268726826, 36.66962452232838, 37.87723012268543, 37.681829407811165, 35.12943796813488, 35.31792305409908, 36.62142030894756, 38.51222924888134, 40.21360695362091, 41.950531750917435, 46.729801297187805, 45.34233994781971, 48.655188381671906, 48.105905055999756, 46.79294630885124, 46.358872801065445, 47.5054232776165, 45.74057757854462, 44.51746501028538, 46.26165881752968, 48.53523641824722, 47.40113787353039, 37.0962618291378, 16.026533022522926, 1.7457818845286965, 1.6945387842133641, 5.380594879388809, 4.493551002815366, 0.6035098596476018, 0.033748111745808274, 0.07179171487223357, 0.05486179012223147, 0.5114796292036772, 0.2733355126110837, 2.747114128433168, 18.9672427251935, 33.37312661111355, 27.532703205943108, 38.925335481762886, 34.202017933130264, 3.3350715413689613, 0.066305380751146, 0.026882468337134924, 0.07763825778965838, 0.01482738791310112, 0.027316862215229776, 0.04928300666506402, 0.04474737484997604, 0.014366504929057555, 0.07064223944325931, 0.014744894488103455, 0.06833444960648194, 0.051711451160372235, 0.06353466887958348, 0.1211809970845934, 0.0236301211771206, 0.03352693689521402, 0.02646337012265576, 0.0025708570683491416, 0.2147158354637213, 0.23682260391069576, 0.10585584794171154, 0.192900508409366, 0.151403202326037, 0.055509636804345064, 0.09881406134809367, 0.16292960179271176, 0.16442997206468135, 0.15851284348173067, 0.17641671089222655, 0.15615355601767078, 0.10294107778463513, 0.12007089258986525, 0.13301573664648458, 0.12773663242114708, 0.1203134264505934, 0.10731139249401167, 0.1729077030904591, 0.12891534104710445, 0.12158121506217867, 0.05947956655290909, 0.20800831960514188, 1.675285454839468, 27.46462605893612, 55.71048639714718, 44.897353425621986, 45.59731766581535, 43.61964538693428, 32.45704136788845, 3.1699478393420577, 0.18156519712647423, 0.43439666857011616, 2.7642210479825735, 1.9076048699207604, 0.8643532753922045, 4.577460950240493, 4.700064221397042, 3.7918424187228084, 22.81409740447998, 44.72927704453468, 52.101915031671524, 53.684252724051476, 53.29396806657314, 53.15309822559357, 53.38944934308529, 54.77608233690262, 51.838957741856575, 53.14565822482109, 53.65977443754673, 53.77895504236221, 53.909523636102676, 53.30914445221424, 52.685989290475845, 52.55079634487629, 51.829697638750076, 51.948771849274635, 51.104639545083046, 48.35945025086403, 45.8313775062561, 43.592055067420006, 40.881960690021515, 39.403186440467834, 39.332973808050156, 41.97759389877319, 39.72108878195286, 40.64023286104202, 43.090611174702644, 43.72761279344559, 42.96862252056599, 43.60686667263508, 43.59672501683235, 43.43916267156601, 39.82362627983093, 38.771477937698364, 38.93731243908405, 39.78099636733532, 38.99690084159374, 41.721909418702126, 41.9988651573658, 46.12967289984226, 45.49555152654648, 49.33188647031784, 51.514591947197914, 50.53434334695339, 52.35626958310604, 48.169642835855484, 44.44663681089878, 44.08827804028988, 43.659387454390526, 51.82424493134022, 55.27444079518318, 52.4441284686327, 48.64395618438721, 49.17504608631134, 49.05579708516598, 46.135832369327545, 40.86398385465145, 38.45556288957596, 37.68478564918041, 38.386683985590935, 37.63465113937855, 40.17809025943279, 39.22283671796322, 40.256761237978935, 38.73904287815094, 39.52881529927254, 39.020535573363304, 39.070955067873, 39.693046286702156, 40.611593797802925, 38.766925781965256, 40.258672535419464, 39.577718675136566, 40.604074001312256, 39.777295365929604, 38.824986666440964, 38.797495141625404, 38.09500403702259, 40.3839024156332, 40.86597874760628, 38.258167281746864, 37.448062151670456, 39.02385279536247, 40.780832916498184, 41.51706241071224, 43.93007352948189, 49.04303357005119, 46.92675992846489, 51.50592461228371, 49.9996892362833, 49.41173538565636, 47.5411831587553, 49.43152092397213, 47.97480829060078, 47.74845063686371, 47.863466665148735, 50.156145840883255, 47.02018931508064, 37.5433724373579, 15.376765988767147, 1.5976279531605542, 1.3021448836661875, 4.061290472745895, 5.297882342711091, 0.7994871935807168, 0.22887818020535633, 0.2516358270077035, 0.24534168740501627, 0.8660766610410064, 1.0080181038938463, 6.106670843437314, 27.3775727301836, 39.96841371059418, 35.75129359960556, 47.75491788983345, 38.730668127536774, 4.014355391263962, 0.11828954520751722, 0.11996016415650956, 0.13700022362172604, 0.07465195943950675, 0.13888092973502353, 0.12317186759901233, 0.13975924666738138, 0.08105457876808941, 0.20616501773474738, 0.1121099857846275, 0.13880399870686233, 0.13234143611043692, 0.1504934480180964, 0.2290665521286428, 0.1629208296071738, 0.10804833771544509, 0.14680501859402284, 0.20815527968807146], [0.07856904456275515, 0.03975828338298015, 0.06544870484503917, 0.02931141192675568, 0.026365775847807527, 0.044548675941769034, 0.01833486410760088, 0.08357626298675314, 0.09418177593033761, 0.026985806835000403, 0.0097398830257589, 0.019364796244190075, 0.028155531763331965, 0.03434692473092582, 0.057116635143756866, 0.039488193579018116, 0.07203706889413297, 0.03504262138449121, 0.010423802723380504, 0.02987819567351835, 0.059107939814566635, 0.05338719463907182, 0.013172030303394422, 0.039536024996777996, 4.273966485634446, 32.033044919371605, 37.73925192654133, 30.70879317820072, 36.28559812903404, 30.192826464772224, 2.8112492244690657, 0.11737432127119973, 0.5291700549423695, 0.039272506910492666, 0.2561434538802132, 0.300389378098771, 0.4932838602690026, 0.6612398056313396, 0.415474574547261, 2.9559768084436655, 22.521420009434223, 46.22719466686249, 51.567861288785934, 49.68530550599098, 51.15000531077385, 51.58167354762554, 52.70424731075764, 52.15283989906311, 53.70733268558979, 50.79849377274513, 52.11505852639675, 50.39239816367626, 50.11188201606274, 49.60271313786507, 49.01691757142544, 50.64331769943237, 49.12830859422684, 49.301894679665565, 46.91254109144211, 44.28473509848118, 40.45740947127342, 38.11646528542042, 37.84177042543888, 36.97530671954155, 36.77484467625618, 38.180442452430725, 38.89244444668293, 39.010477513074875, 42.48823709785938, 41.6947902739048, 41.275535970926285, 43.3902782946825, 41.708796322345734, 37.92973190546036, 37.0421489328146, 36.35901018977165, 35.8308195322752, 36.45781248807907, 36.29460744559765, 39.99276280403137, 40.418716147542, 44.86173793673515, 47.19446316361427, 48.30923594534397, 50.12570187449455, 47.503386586904526, 46.833277344703674, 42.175304889678955, 46.27871610224247, 40.6172288954258, 46.56923331320286, 52.283693477511406, 49.94117997586727, 48.90857398509979, 47.0001719892025, 47.57288105785847, 44.0028890222311, 45.629338547587395, 44.64919254183769, 41.18095524609089, 36.14418871700764, 35.69165579974651, 37.8514751046896, 36.12035259604454, 35.46494476497173, 35.78457981348038, 36.82782523334026, 35.19841946661472, 35.303373634815216, 36.38354167342186, 35.2771170437336, 38.0134642124176, 36.22958913445473, 35.895986035466194, 34.91771712899208, 33.567915558815, 34.960305243730545, 35.38849666714668, 35.40730945765972, 33.28597068786621, 33.24179045855999, 33.978764712810516, 34.884252324700356, 34.08186458051205, 33.395986184477806, 35.14895752072334, 35.041666477918625, 38.46488758921623, 41.830488592386246, 45.65552294254303, 47.371738851070404, 47.00312823057175, 44.881626069545746, 44.43303734064102, 41.850099340081215, 44.964264035224915, 48.235759288072586, 45.843331664800644, 36.09144754707813, 23.080221824347973, 4.321818742901087, 0.2889267884893343, 1.8753717932850122, 8.238634318113327, 6.805928321555257, 0.7462709897663444, 0.09953913962817751, 0.09756795829162002, 0.07319450014620088, 0.17446866229875013, 0.7023202325217426, 3.885702844709158, 26.078297048807144, 33.82572792470455, 31.72277446836233, 38.36354322731495, 9.342568181455135, 0.12031305537675507, 0.012132668252888834, 0.01791845803381875, 0.011698929320118623, 0.02511748160031857, 0.016069009325292427, 0.03289437845523935, 0.025880637622321956, 0.03183672895829659, 0.0110401999700116, 0.010669032435544068, 0.05365613782487344, 0.07570612084236927, 0.05097473971545696, 0.021790394603158347, 0.14016664121299982, 0.028675897883658763, 0.022581344055652153, 0.1343109624576755, 0.05593942565610632, 0.049610653732088394, 0.03047941136173904, 0.045537877158494666, 0.04523482115473598, 0.04121390957152471, 0.06908759591169655, 0.12824896664824337, 0.03200953433406539, 0.008567550376028521, 0.09609127737348899, 0.009788602237676969, 0.06659760882030241, 0.0037512944345508004, 0.027279357782390434, 0.0015735627312096767, 0.04989870350982528, 0.10143285559024662, 0.03195540208253078, 0.0522644699231023, 0.04271487356163561, 0.03922748081095051, 0.07597526811878197, 0.051555622412706725, 8.279190491884947, 37.957907393574715, 43.15207287669182, 32.65361241996288, 36.943103447556496, 32.856065556406975, 2.959343665279448, 0.27188853244297206, 0.7586761959828436, 0.008013884089450585, 0.10623299996950664, 0.20844989747274667, 0.70247050258331, 1.5783230890519917, 1.0150831122882664, 3.029105309396982, 26.208210177719593, 47.18418851494789, 51.96882717311382, 50.821999311447144, 51.18990316987038, 51.51676543056965, 53.52628380060196, 52.99223765730858, 54.16000239551067, 53.39572660624981, 51.94354332983494, 52.19395749270916, 51.38257943093777, 51.27828262746334, 50.18582224845886, 50.913627594709396, 49.37307246029377, 51.84488162398338, 48.14965210855007, 46.442730501294136, 42.21848577260971, 39.80278819799423, 39.15689505636692, 37.33638994395733, 39.001935571432114, 40.016416534781456, 40.372799411416054, 41.19923606514931, 42.277906984090805, 43.92122000455856, 43.64222377538681, 45.51517367362976, 43.58850605785847, 39.8071351647377, 38.435252979397774, 37.186784371733665, 37.5046107172966, 37.855597883462906, 38.02997052669525, 40.760382413864136, 42.75700807571411, 46.50457978248596, 48.94222877919674, 50.69426916539669, 52.31777384877205, 49.91494618356228, 47.586849108338356, 43.356536105275154, 44.62273456156254, 42.11706541478634, 47.24446468055248, 54.18400190770626, 52.375986725091934, 50.88072896003723, 49.8394176363945, 49.78185452520847, 46.740091145038605, 45.89050993323326, 45.74208989739418, 41.209164932370186, 37.87369251251221, 37.94659160077572, 39.24813576042652, 36.821661964058876, 36.69912613928318, 37.7017555385828, 37.67950773239136, 36.61230839788914, 37.934462651610374, 37.314734905958176, 36.13186597824097, 40.36639295518398, 38.1124223023653, 36.460825726389885, 37.168716341257095, 36.4401700347662, 36.73491641879082, 36.86595618724823, 36.67351931333542, 35.13709835708141, 35.50526060163975, 36.08229383826256, 35.72096362709999, 36.373821794986725, 35.894819498062134, 36.970336586236954, 37.81945802271366, 40.833030715584755, 43.9933667331934, 46.5889048576355, 48.92452172935009, 48.50056707859039, 46.13574877381325, 46.827019080519676, 43.74635338783264, 47.19496473670006, 49.0732229501009, 47.65841446816921, 38.55997748672962, 26.410695612430573, 5.817976109683514, 1.9638355588540435, 3.602241617627442, 5.550934514030814, 5.242479415610433, 1.6693951771594584, 0.043803593071061186, 0.03900821327988524, 0.0327388688310748, 0.5286897369660437, 0.6637721322476864, 5.374656748026609, 29.9713097512722, 37.38595828413963, 31.751485727727413, 44.38384898006916, 14.836049303412437, 0.3610145905986428, 0.024848562534316443, 0.017140178897534497, 0.05696372674719896, 0.029520445241359994, 0.07718136941548437, 0.04361096864158753, 0.06820092239649966, 0.04283030721126124, 0.017898618571052793, 0.05208894828683697, 0.0760495571012143, 0.08683359366841614, 0.03949937774450518, 0.027330480625096243, 0.057461997275822796, 0.052603141593863256, 0.051731693238252774, 0.0850366018130444, 0.18746726011158898, 0.17747216363204643, 0.17322761326795444, 0.14173214236507192, 0.13383886747760698, 0.13756769942119718, 0.1448777798213996, 0.2538219268899411, 0.1705860870424658, 0.06660528262727894, 0.17484478274127468, 0.15670997381675988, 0.19942821672884747, 0.11716267559677362, 0.14152536517940462, 0.1421374292112887, 0.13332574657397345, 0.17548360861837864, 0.16012327425414696, 0.20943071984220296, 0.11682052325340919, 0.14818606636254117, 0.15760996146127582, 0.16775788099039346, 8.92432177439332, 45.368695333600044, 48.60109828412533, 40.42613334953785, 43.49177844822407, 40.232184156775475, 4.384893458336592, 0.37172508775256574, 2.299868152476847, 0.22874907619552687, 1.349874003790319, 0.9925315598957241, 2.0441053016111255, 1.6546343942172825, 2.0370341185480356, 4.00185358710587, 26.765066497027874, 47.95162573456764, 52.36341319978237, 50.868007242679596, 52.49973468482494, 51.60887248814106, 55.38035251200199, 54.07096937298775, 56.148230507969856, 55.773475617170334, 54.71150100231171, 53.6779260635376, 52.85913459956646, 52.028339579701424, 52.34724506735802, 54.18979659676552, 49.889156967401505, 53.49334716796875, 51.35815814137459, 48.283059149980545, 44.348009303212166, 43.410063832998276, 42.367825359106064, 40.774787440896034, 42.07413151860237, 41.44896246492863, 42.058312967419624, 43.20495843887329, 46.34417898952961, 45.480945110321045, 45.752349346876144, 48.12788687646389, 45.843384861946106, 41.467851251363754, 40.85983067750931, 39.883036091923714, 39.029772877693176, 39.26412150263786, 40.50923869013786, 44.51322443783283, 44.07463297247887, 49.39746335148811, 50.66934250295162, 52.256920114159584, 53.628574311733246, 50.01108102500439, 47.185571640729904, 43.75593267381191, 43.24275121092796, 44.13896732032299, 47.94186405837536, 55.00421069562435, 56.08320079743862, 52.33328081667423, 50.78206725418568, 52.877970188856125, 48.56936998665333, 47.76005521416664, 48.33902254700661, 43.53840194642544, 40.310699343681335, 39.60434764623642, 41.30180396139622, 39.1560211032629, 37.32065498828888, 39.27207067608833, 39.27802115678787, 39.15019981563091, 40.11767350137234, 40.731097385287285, 37.81077168881893, 42.27905452251434, 39.079945385456085, 38.445090651512146, 38.640757352113724, 38.140833377838135, 38.10842491686344, 39.569340124726295, 38.65173876285553, 36.16835542023182, 38.00224721431732, 38.715259954333305, 39.00087542831898, 38.46368685364723, 36.97836555540562, 39.13769468665123, 39.92672994732857, 42.847891598939896, 46.14450350403786, 49.12900395691395, 49.65024098753929, 51.33083760738373, 48.91305774450302, 48.422758653759956, 44.48552392423153, 45.96681363880634, 51.023852080106735, 48.29652562737465, 38.598260432481766, 25.927897319197655, 5.746523318812251, 1.2171195773407817, 5.247530294582248, 14.039532244205475, 12.908190451562405, 2.4298945628106594, 0.3965271881315857, 0.2576693391893059, 0.23595957522047684, 0.9671767672989517, 1.1665887013077736, 7.651247112080455, 36.7365313321352, 44.87205058336258, 39.5205507427454, 51.300530433654785, 17.14907828718424, 0.49672985973302275, 0.19703398895217106, 0.11734724772395566, 0.09719491034047678, 0.1287378341658041, 0.2031559354509227, 0.1824072378803976, 0.16688533796695992, 0.12698572740191594, 0.0656041328329593, 0.15047692781081423, 0.191086046397686, 0.1989269256591797, 0.11778956031776033, 0.12600992195075378, 0.1459657386294566, 0.13020744983805344, 0.22577698255190626, 0.33610758022405207], [0.05725502342102118, 0.029898656684963498, 0.012652536206587683, 0.05071614577900618, 0.033286685138591565, 0.03328680759295821, 0.0334118780301651, 0.047324593979283236, 0.06769033963792026, 0.040861163070076145, 0.03349468686792534, 0.01602235235623084, 0.039908698163344525, 0.03744945453945547, 0.05321376214851625, 0.10546685865847394, 0.07148368647904135, 0.03822873186436482, 0.020360635971883312, 0.05118150576890912, 0.05003915495763067, 0.03273299473221414, 0.07115767584764399, 0.06964062951738015, 0.7037483621388674, 16.899391785264015, 41.48860193789005, 33.694710955023766, 30.723116509616375, 34.14032444357872, 8.884842842817307, 0.17981065611820668, 1.13872206537053, 0.34053285839036107, 0.06774914741981775, 0.04804785399755929, 0.26338972442317754, 1.4289444359019399, 0.9442353202030063, 0.10481834775418974, 6.208076002076268, 29.764562845230103, 48.95564205944538, 50.85178591310978, 46.943999603390694, 49.20641340315342, 49.94965732097626, 50.04432924091816, 50.084063708782196, 50.82604989409447, 51.145696341991425, 50.56997403502464, 48.587023839354515, 49.515424221754074, 50.45418284833431, 49.79831904172897, 48.30955512821674, 51.039989814162254, 48.54309059679508, 48.46345067024231, 42.06818103790283, 39.688250944018364, 35.508258640766144, 36.67895682156086, 36.63006104528904, 37.84338913857937, 37.01081581413746, 38.22637438774109, 39.24036517739296, 43.06460537016392, 45.447579100728035, 46.873547583818436, 46.00247472524643, 42.18470938503742, 37.621503844857216, 38.67686681449413, 37.00821675360203, 36.477256044745445, 37.99813583493233, 37.88012556731701, 44.206877276301384, 46.80202402174473, 50.547277852892876, 45.269053280353546, 46.459407806396484, 43.380839601159096, 43.41252990067005, 48.52971911430359, 48.4831678122282, 43.987431451678276, 46.23047009110451, 51.434165462851524, 50.384091809391975, 51.208449974656105, 49.517749696969986, 49.43499393761158, 47.30238497257233, 48.14827278256416, 46.4541070908308, 48.46337467432022, 44.31894466280937, 36.27273581922054, 33.667664006352425, 34.655329808592796, 34.43231977522373, 35.968824326992035, 34.08417485654354, 34.85286980867386, 34.69899706542492, 35.71016080677509, 35.652339309453964, 38.328896686434746, 36.8483517318964, 36.55095688998699, 35.41167162358761, 35.60576520860195, 34.05559279024601, 34.69207003712654, 34.49616014957428, 34.617563635110855, 32.848640754818916, 33.040234073996544, 33.32829661667347, 32.428113520145416, 33.63277047872543, 33.70839782059193, 35.517906323075294, 38.19031432271004, 40.497501119971275, 40.5688688904047, 43.7704136967659, 46.241136118769646, 48.37500661611557, 48.43509279191494, 44.97258558869362, 44.70392860472202, 44.81561981141567, 40.16352564096451, 24.27368838340044, 9.296464305371046, 1.501185328233987, 2.370619880966842, 2.1399922063574195, 7.482750853523612, 2.8178228717297316, 1.1584335076622665, 0.14602889539673924, 0.021932070594630204, 0.055329031456494704, 0.11641893972409889, 0.2355819259537384, 9.12165753543377, 27.071341462433338, 21.440056934952736, 35.22701293230057, 30.47318112105131, 2.566815703175962, 0.0068835287038382376, 0.03670671685540583, 0.10764213060610928, 0.03113622689852491, 0.0338735940749757, 0.036815511994063854, 0.02959698478662176, 0.04008424948551692, 0.10144294137717225, 0.0644500635098666, 0.02371456088440027, 0.0516816687741084, 0.060859875884489156, 0.04896412807283923, 0.0318401354161324, 0.021299128093232866, 0.0915454892674461, 0.019990979635622352, 0.09103920354391448, 0.04522444221947808, 0.05013471018173732, 0.08899227861547843, 0.016154946315509733, 0.02397765223577153, 0.011608615513978293, 0.03620675423007924, 0.08695766591699794, 0.026755549952213187, 0.026409955898998305, 0.03448130169999786, 0.02249482633487787, 0.021280431537888944, 0.031080400694918353, 0.05190599033085164, 0.018293888279004022, 0.009351577446068404, 0.025108076733886264, 0.02252216148917796, 0.07417814267682843, 0.0385175126575632, 0.06327420473098755, 0.03011183303897269, 0.10304515657480806, 1.500752626452595, 25.72628203779459, 47.54595570266247, 34.90050785243511, 35.20626224577427, 37.408358082175255, 8.080426957458258, 0.08000587957212701, 2.756483000703156, 0.5314511794131249, 0.05226888941251673, 0.02998401479999302, 0.08642166460049339, 0.8301192498765886, 1.2752787815406919, 0.32383275451138616, 6.853999067097902, 34.17321927845478, 50.945792868733406, 51.03533886373043, 47.861502170562744, 51.38197146356106, 51.76928848028183, 51.84341110289097, 52.07507327198982, 51.76191307604313, 50.721661895513535, 51.53552122414112, 50.29357306659222, 50.54856978356838, 53.133039101958275, 49.82755847275257, 51.44848309457302, 51.521230190992355, 50.983300656080246, 49.600387662649155, 44.878065660595894, 40.69664463400841, 37.984479367733, 38.32902207970619, 39.352652952075005, 39.8344860970974, 40.345634669065475, 39.719492867589, 41.50964140892029, 44.49665732681751, 47.89715565741062, 47.20972694456577, 47.28338219225407, 42.16010570526123, 39.94637489318848, 40.27112066745758, 38.54562945663929, 37.80356727540493, 40.557116121053696, 39.91351045668125, 45.27637168765068, 49.21756200492382, 52.79309794306755, 46.72141894698143, 47.686088383197784, 43.76324728131294, 42.86152146756649, 46.826787292957306, 48.32484170794487, 45.82129284739494, 47.21577242016792, 51.740900203585625, 50.97490310668945, 53.469898626208305, 50.67367807030678, 50.04369467496872, 49.76449705660343, 50.32179035246372, 47.85140611231327, 50.02843089401722, 45.43198473751545, 38.499070554971695, 36.28937892615795, 35.70907786488533, 36.29649214446545, 37.54512794315815, 36.25111497938633, 37.75219403207302, 37.57162392139435, 38.40948276221752, 37.652597576379776, 39.66010965406895, 38.66588920354843, 37.89061300456524, 36.51836983859539, 38.033815920352936, 36.12638667225838, 35.32520726323128, 36.91303566098213, 35.052290707826614, 35.48391714692116, 34.33702848851681, 35.06416127085686, 35.34513719379902, 34.90351349115372, 34.94724914431572, 35.8890476077795, 38.74239429831505, 41.47945202887058, 43.38392123579979, 45.80998845398426, 48.078265339136124, 48.6064749956131, 49.97971370816231, 45.612095072865486, 46.36824309825897, 46.47150255739689, 41.132150664925575, 26.6026746109128, 13.269010540097952, 3.7784300884231925, 3.0050452379509807, 6.440034555271268, 9.08164568245411, 2.755625434219837, 2.3291182704269886, 0.056707017865846865, 0.08867927783285268, 0.09852415620116517, 0.14523484191158786, 0.4335882025770843, 10.008977372199297, 34.8787160217762, 27.567275650799274, 39.548201858997345, 37.572117894887924, 3.6793235689401627, 0.025162554084090516, 0.056150867239921354, 0.021882114779145923, 0.014871832354401704, 0.04594891193846706, 0.05587580875726417, 0.028998720990784932, 0.06962355269934051, 0.07789910785504617, 0.07269081936101429, 0.01395190876792185, 0.035237023257650435, 0.029591769343824126, 0.04532581217063125, 0.024698277629795484, 0.02224739801022224, 0.03039705152332317, 0.07569805369712412, 0.08657817612402141, 0.12252373519004323, 0.127878338098526, 0.15852725598961115, 0.11127073550596833, 0.14169835980283096, 0.09228368129697628, 0.10331051889806986, 0.1299548672977835, 0.14791160530876368, 0.11020959049346857, 0.19494214182486758, 0.14271382562583312, 0.13814267091220245, 0.17710963933495805, 0.22067630547098815, 0.15194504434475675, 0.1660729237482883, 0.1584654944599606, 0.12511970096966252, 0.16700163250789046, 0.1549876865465194, 0.19604120316216722, 0.12413604359608144, 0.15910856542177498, 1.8438090244308114, 27.490740157663822, 55.99892131984234, 43.86004328727722, 41.295234113931656, 44.24525901675224, 13.718021996319294, 0.3977452008984983, 4.574195500463247, 1.1752831097692251, 0.2075722039444372, 0.12285761258681305, 0.32586674380581826, 3.7885966803878546, 2.066898853518069, 0.5087018001358956, 8.052034880965948, 34.8782904446125, 50.88974207639694, 51.84985175728798, 46.89488343894482, 51.438033655285835, 52.07716315984726, 53.02727937698364, 52.99252264201641, 54.141865968704224, 54.56389032304287, 54.17193375527859, 51.96355305612087, 51.99988670647144, 54.21324513852596, 51.487434804439545, 51.83436758816242, 53.443657234311104, 53.63629549741745, 53.610418885946274, 47.09345318377018, 43.30173924565315, 39.65999945998192, 39.6621273458004, 40.782360434532166, 42.376462295651436, 41.134749725461006, 42.63951078057289, 43.55202801525593, 47.249567806720734, 51.03729575872421, 49.64905545115471, 50.519501343369484, 43.89583736658096, 41.09135985374451, 41.69688016176224, 39.77155767381191, 39.147722348570824, 43.08955103158951, 40.800797045230865, 47.08061367273331, 50.375242084264755, 55.24378024041653, 48.35661940276623, 50.14484524726868, 44.553992450237274, 43.59077453613281, 48.243674263358116, 48.64756979048252, 46.124204993247986, 48.475264236330986, 53.60840879380703, 53.857094049453735, 54.41941827535629, 53.830921053886414, 52.78042942285538, 52.71737940609455, 52.09959335625172, 48.803125843405724, 51.55902676284313, 47.29415461421013, 40.166747868061066, 38.70138689875603, 37.23267450928688, 38.194805681705475, 40.18762394785881, 37.5711527466774, 38.71715605258942, 38.54167006909847, 40.944482535123825, 39.66437302529812, 41.626048162579536, 41.01294346153736, 39.70070667564869, 39.83177304267883, 40.57054080069065, 38.24596233665943, 36.945436522364616, 37.609257102012634, 37.296062707901, 36.55664898455143, 36.75718702375889, 36.89793147146702, 36.820571422576904, 36.88861057162285, 36.9552855938673, 38.314902037382126, 41.387295573949814, 44.72437530755997, 45.742523074150085, 46.213086023926735, 50.79945892095566, 52.06969276070595, 50.941153317689896, 45.27346484363079, 47.4253311753273, 45.43149076402187, 42.235459461808205, 25.944310538470745, 12.44271732866764, 2.9865440307185054, 4.126010974869132, 5.779670365154743, 14.090029634535313, 9.501319862902164, 4.12496080622077, 0.37941765622235835, 0.16480977355968207, 0.15901296195806935, 0.2772141247987747, 0.9619924204889685, 14.379321411252022, 40.27832508087158, 31.200568489730358, 44.69121068716049, 42.754883989691734, 5.040742540732026, 0.13443773612380028, 0.09429969577468, 0.11529086783411913, 0.15564481378532946, 0.18050731014227495, 0.15230829594656825, 0.11642383047728799, 0.22995953389909118, 0.16858637012774125, 0.17774338892195374, 0.0673775614995975, 0.14395235135452822, 0.16092666395707056, 0.1773317641345784, 0.08492024047882296, 0.09159991837805137, 0.1107573029003106, 0.17561024869792163, 0.17650579829933122], [0.057813407911453396, 0.023456530980183743, 0.05261845581117086, 0.04184408200671896, 0.011799431886174716, 0.03037523423699895, 0.013827278980897972, 0.04147978026594501, 0.04064071552420501, 0.020420132095750887, 0.016797243588371202, 0.023612443219462875, 0.032658650088706054, 0.07048028797726147, 0.04182016629783902, 0.037871636377531104, 0.02738122311711777, 0.02512447263143258, 0.00527599369888776, 0.0392663470847765, 0.03006069720868254, 0.03555222079739906, 0.07662241347134113, 0.09866657434031367, 0.08770019208895974, 5.0092127826064825, 30.33306173980236, 33.61092545092106, 25.984871461987495, 37.32070058584213, 17.079437524080276, 3.1637482345104218, 1.9561315909959376, 0.04418009200890083, 0.04506296943873167, 0.0521118917822605, 0.034623920219019055, 0.8781700464896858, 0.9194337541703135, 0.16867087106220424, 1.3405751902610064, 13.817338217049837, 30.708487294614315, 50.557594299316406, 51.803311854600906, 51.99102558195591, 50.38221091032028, 50.57427920401096, 49.63609054684639, 50.18700398504734, 49.67565022408962, 49.52984444797039, 48.28719712793827, 48.6913700401783, 49.98799346387386, 48.5313606262207, 49.814597368240356, 50.442935451865196, 50.3752800822258, 46.8147761374712, 40.9041590988636, 37.95544132590294, 36.62896670401096, 36.80786870419979, 36.478164196014404, 36.89989596605301, 37.00263485312462, 38.288729041814804, 37.80154578387737, 44.98053856194019, 48.3857486397028, 49.66418243944645, 49.07629698514938, 44.104001596570015, 38.870975598692894, 36.80235140025616, 36.392695382237434, 35.730124935507774, 36.587404534220695, 37.35529012978077, 40.38084737956524, 45.55114634335041, 50.1888582855463, 50.40564805269241, 49.31019723415375, 46.17979221045971, 49.767939671874046, 47.66385957598686, 44.545537903904915, 42.93139971792698, 43.6435005068779, 49.192475751042366, 49.66106280684471, 49.27216127514839, 49.96571905910969, 49.07721273601055, 49.01298098266125, 50.21487168967724, 50.889761075377464, 49.39475789666176, 49.33781035244465, 41.75280176103115, 34.370170310139656, 32.77757316827774, 34.71049524843693, 35.10754734277725, 35.39824694395065, 34.41655442118645, 35.29611222445965, 37.85657823085785, 40.1139535009861, 41.17527075111866, 40.55830925703049, 38.617141619324684, 36.6626138985157, 34.77622032165527, 33.810551539063454, 34.3857266753912, 34.71388466656208, 34.08047765493393, 33.521782234311104, 33.784655928611755, 34.29080776870251, 33.673933669924736, 32.18843378126621, 33.6333442479372, 33.66283446550369, 34.67507354915142, 38.12461204826832, 40.31763777136803, 42.92913883924484, 42.62126035988331, 48.6012464761734, 48.052248135209084, 46.48944519460201, 44.57555249333382, 41.91254138946533, 25.66415537148714, 11.29523305222392, 4.4599441811442375, 1.6294290404766798, 2.730769068002701, 4.5132985431700945, 3.5107712633907795, 2.109434246085584, 2.3154715402051806, 0.07844323568861, 0.06401425955118611, 0.07059178824420087, 0.2642743941396475, 0.6270727515220642, 22.988870926201344, 28.236134760081768, 27.899284735322, 38.84765625, 17.611473575234413, 0.6381034408695996, 0.03052853968256386, 0.027937297672906425, 0.01700399850960821, 0.07160091612604447, 0.014675917427666718, 0.03294428788649384, 0.017994283261941746, 0.03355840395670384, 0.019052402167289983, 0.034007340218522586, 0.013992772346682614, 0.059004220966016874, 0.03353623229486402, 0.04492365718760993, 0.058017595001729205, 0.02297538179846015, 0.0636852951720357, 0.06592155681573786, 0.05392424980527721, 0.027058149535150733, 0.04368186229839921, 0.03124560091237072, 0.04799319853191264, 0.03872879096888937, 0.018965351955557708, 0.05440804103272967, 0.044537087305798195, 0.039394493724103086, 0.011336514489812544, 0.008277280649053864, 0.01584483434271533, 0.09374137065606192, 0.026609200285747647, 0.052158969920128584, 0.020906541249132715, 0.06394391137291677, 0.01556600760522997, 0.009892240377666894, 0.018460737919667736, 0.10263634452712722, 0.057954890944529325, 0.06195608737471048, 0.0661421379481908, 0.19157705130055547, 8.381058275699615, 39.680370166897774, 37.162834256887436, 30.67002195864916, 43.86717930436134, 21.33063990622759, 2.5909220846369863, 3.4924089862033725, 0.06933113167178817, 0.18649368110345677, 0.1881394677911885, 0.048061394481919706, 0.4666160303167999, 1.0948999668471515, 0.6764665385708213, 1.7159927892498672, 16.282107308506966, 32.43028320372105, 50.94045415520668, 51.18581458926201, 50.28197608888149, 50.35899795591831, 50.04265733063221, 51.467489674687386, 51.3537959754467, 51.03644460439682, 50.200763046741486, 50.103666856884956, 49.76893521845341, 51.242492347955704, 49.7643868625164, 49.81107495725155, 51.64348483085632, 51.304698809981346, 49.33271482586861, 43.6219746619463, 40.78508488833904, 36.70186959207058, 39.26632538437843, 39.247117415070534, 38.1998024135828, 38.45526270568371, 40.096311047673225, 39.7875852137804, 46.01518124341965, 50.633088648319244, 51.187535896897316, 51.401889994740486, 45.925696045160294, 40.97466431558132, 39.64435949921608, 37.496870532631874, 38.68161655962467, 37.95216590166092, 40.320328027009964, 42.36546188592911, 47.70975351333618, 51.06694936752319, 50.61876341700554, 49.9288534373045, 46.932870000600815, 49.784111604094505, 50.25302544236183, 45.73946423828602, 43.31788457930088, 45.048000141978264, 49.7143891453743, 50.28893731534481, 50.46611800789833, 52.36939787864685, 52.04047612845898, 51.487161219120026, 51.17111697793007, 51.93282410502434, 50.95222592353821, 50.09861692786217, 43.67247395217419, 34.042304903268814, 35.375318974256516, 35.50755187869072, 37.04271510243416, 36.62306562066078, 36.39452688395977, 36.91727243363857, 38.88736791908741, 42.11692862212658, 42.81535014510155, 41.166990995407104, 39.58504468202591, 38.58532592654228, 36.736234948039055, 36.037015467882156, 36.09595790505409, 36.08840391039848, 35.49881234765053, 34.77631151676178, 35.08206591010094, 36.858816370368004, 35.57100847363472, 33.659783229231834, 34.939793944358826, 37.005454301834106, 37.053362131118774, 40.49151264131069, 40.81645980477333, 45.32444290816784, 47.01188676059246, 49.35201779007912, 48.55924353003502, 46.03827640414238, 45.637758895754814, 43.10008406639099, 28.9891916513443, 12.764117382466793, 4.886063290759921, 4.678561175242066, 5.554056046530604, 8.437935523688793, 9.67406714335084, 2.475331574678421, 2.158957701176405, 0.2438657486345619, 0.17548320785863325, 0.15142613468924537, 0.4344388225581497, 0.314873963361606, 27.55193207412958, 34.94455128908157, 27.02206000685692, 43.62148828804493, 22.83939454704523, 1.0917982645332813, 0.03902905278664548, 0.011834663491754327, 0.029076529608573765, 0.03894064073392656, 0.006530460295834928, 0.030845446017337963, 0.06168308093037922, 0.041642099095042795, 0.03340620802191552, 0.02946080068795709, 0.010962041615130147, 0.05044705787440762, 0.014562801134161418, 0.0486479137907736, 0.10388618058641441, 0.015926298037811648, 0.018268404783157166, 0.015806198134669103, 0.05589982094534207, 0.1398988298024051, 0.21261680434690788, 0.1541538242599927, 0.2082809549756348, 0.07847528904676437, 0.13107322447467595, 0.16724410699680448, 0.16972832760075107, 0.15829763549845666, 0.25172072870191187, 0.097158166609006, 0.1253682016977109, 0.158225231571123, 0.17318623111350462, 0.1490426532109268, 0.09830224662437104, 0.21103282371768728, 0.08466301951557398, 0.11402633725083433, 0.10700135288061574, 0.12748758250381798, 0.08445135899819434, 0.1480077431187965, 0.18433204240864143, 0.314319608733058, 10.318280775099993, 45.502117574214935, 44.02867063879967, 36.38338588178158, 47.952347695827484, 24.78155393153429, 6.115456447005272, 5.276763550937176, 0.2604173042345792, 0.5549011460971087, 0.3188262856565416, 0.20151866861851886, 3.357886942103505, 4.03681218624115, 1.0764615749940276, 2.5444187549874187, 17.035196498036385, 33.182110860943794, 50.77583558857441, 52.5069884955883, 52.27457396686077, 52.192847952246666, 51.17403902113438, 51.07548750936985, 53.9640849083662, 52.92758412659168, 51.849410980939865, 52.11652524769306, 51.03712856769562, 52.21455238759518, 49.42301318049431, 52.18117877840996, 53.64006109535694, 53.42888742685318, 51.96172155439854, 44.59278456866741, 43.298121839761734, 39.04121786355972, 41.63726896047592, 42.374197617173195, 40.143405720591545, 40.58288633823395, 42.30871573090553, 41.99625849723816, 48.35107170045376, 53.157194405794144, 53.24125349521637, 52.92508386075497, 48.84784944355488, 42.93465234339237, 41.36814460158348, 39.860013127326965, 39.94229771196842, 40.10962933301926, 41.69934242963791, 43.51013906300068, 51.078922525048256, 53.67538020014763, 54.00107592344284, 52.06314191222191, 49.53039541840553, 52.9000698029995, 52.84228630363941, 47.42144018411636, 46.348050981760025, 45.64462132751942, 50.978737100958824, 53.1253407150507, 50.93897223472595, 53.68066191673279, 54.60963986814022, 53.80716472864151, 53.65170747041702, 52.933048233389854, 53.599426075816154, 51.90496399998665, 45.85839785635471, 36.455920189619064, 36.3375299423933, 36.886197701096535, 38.871963545680046, 37.87030689418316, 37.5431140512228, 38.888511657714844, 42.61469051241875, 43.8353256136179, 45.96517592668533, 43.90426531434059, 42.03390307724476, 39.19654592871666, 38.18089462816715, 37.786696180701256, 38.04576247930527, 38.61608147621155, 37.30440706014633, 36.99159264564514, 37.98215389251709, 39.147106781601906, 38.59200976788998, 35.63732251524925, 37.06690840423107, 37.47336119413376, 38.74174453318119, 41.835428327322006, 43.428112864494324, 48.24277751147747, 47.87379831075668, 51.87723308801651, 50.67929416894913, 48.788447231054306, 45.638119876384735, 46.4281202852726, 27.636810019612312, 12.757744174450636, 5.804702946916223, 3.763252515345812, 5.9010296780616045, 11.347659789025784, 12.880916465073824, 3.84978408459574, 5.585349267348647, 0.449019530788064, 0.34367989108432084, 0.411583345849067, 0.789965617004782, 0.8530400355812162, 33.7569098174572, 37.69884869456291, 37.0176250487566, 50.5294606089592, 26.629666462540627, 1.2743119709193707, 0.2219981446978636, 0.133550884493161, 0.08930234049330465, 0.17413809488061816, 0.09164425428025424, 0.1446486936765723, 0.12569161481224, 0.11818508050055243, 0.12038816814310849, 0.15701637690654024, 0.13011457747779787, 0.12543826043838635, 0.13366434402996674, 0.11353153255186044, 0.19679133634781465, 0.10616570201818831, 0.15859734441619366, 0.21848814241820946, 0.17667822889052331], [0.030254202938522212, 0.070653816947015, 0.0723385218589101, 0.03417326217459049, 0.09984137926949188, 0.04587224808346946, 0.0314897637872491, 0.019539148997864686, 0.05588924163021147, 0.032001300205593, 0.05342277690942865, 0.06361410094541498, 0.029076555583742447, 0.01566283004649449, 0.023593815312779043, 0.04307425857405178, 0.028772391924576368, 0.024533634023100603, 0.027293080092931632, 0.056870008338592015, 0.035512085451046005, 0.06689628615276888, 0.1259850600035861, 0.09036029427079484, 0.04757166978379246, 0.41622815129812807, 14.273126609623432, 40.87057650089264, 30.134602189064026, 36.59717381000519, 27.597295939922333, 6.658469159156084, 0.6474824657198042, 0.10845098993740976, 0.21456074144225568, 0.07116776163456962, 0.02115172457706649, 0.058915756962960586, 0.6878680642694235, 0.20655525382608175, 0.21997261588694528, 1.979421847499907, 11.923934016376734, 34.34301316738129, 47.610928416252136, 51.62573978304863, 50.691871494054794, 47.349126264452934, 49.42847728729248, 51.0249388217926, 48.52205112576485, 48.705087304115295, 49.334094151854515, 50.159550458192825, 49.636215940117836, 47.22412057220936, 47.87013530731201, 50.54728925228119, 48.99281546473503, 47.95292906463146, 41.02243535220623, 35.56280091404915, 35.8495981246233, 37.952352091670036, 37.65762470662594, 38.33822898566723, 37.51245729625225, 38.266587629914284, 37.98615127801895, 45.52110515534878, 49.567253440618515, 51.01394221186638, 51.20017781853676, 45.86182527244091, 41.78291514515877, 37.14088663458824, 37.05436147749424, 34.972532987594604, 36.5081749856472, 36.12171292304993, 37.710890248417854, 44.820544347167015, 50.10694608092308, 49.39118228852749, 49.492040276527405, 51.08982414007187, 50.82468956708908, 49.63233634829521, 51.014660373330116, 45.90453118085861, 42.94201634824276, 47.61594034731388, 45.569491758942604, 48.45732919871807, 48.87518897652626, 50.3488676995039, 47.952279299497604, 50.509416684508324, 39.91096079349518, 43.456599935889244, 50.22739581763744, 41.76540948450565, 33.301682844758034, 34.215909987688065, 34.785499423742294, 35.407089069485664, 35.56523658335209, 35.67503549158573, 40.90086467564106, 42.30687662959099, 43.208933025598526, 42.04869948327541, 40.98174713551998, 38.836306259036064, 37.35894933342934, 36.268210262060165, 36.07588358223438, 34.97928522527218, 35.67656300961971, 34.02476504445076, 34.56680215895176, 34.967422261834145, 35.10060511529446, 31.671551316976547, 34.1885020583868, 32.94151157140732, 36.6976860165596, 34.019479528069496, 36.22251771390438, 38.53340931236744, 42.58949026465416, 43.54062482714653, 47.254936918616295, 47.89161175489426, 46.30675479769707, 41.076369658112526, 27.419862560927868, 12.729350198060274, 3.415559772402048, 0.9273467108141631, 5.046816989779472, 5.931906821206212, 11.08041062951088, 12.533403262495995, 1.1038513365201652, 0.31044221366755664, 0.0920601909456309, 0.21767834055935964, 0.055144318321254104, 0.00021391544322568734, 4.2154505755752325, 26.504662670195103, 26.981360390782356, 31.886642575263977, 32.66178198158741, 9.28715005517006, 0.12570714054163545, 0.08332900906680152, 0.053715324102086015, 0.015463153358723503, 0.02993036679981742, 0.06425393614335917, 0.1197098006377928, 0.06936575286090374, 0.02096695392538095, 0.03288725754828192, 0.04897988386801444, 0.023141821402532514, 0.08395719996769913, 0.011133613170386525, 0.07695099935517646, 0.009257027832063613, 0.057722747151274234, 0.0546466823288938, 0.046001541340956464, 0.0570236514613498, 0.03097231801802991, 0.03765029825444799, 0.0995828298619017, 0.028887469343317207, 0.028196730236231815, 0.06335621204925701, 0.04057471262058243, 0.04592774959746748, 0.04972995026037097, 0.032805083246785216, 0.019735259666049387, 0.062405313074123114, 0.026211182776023634, 0.07034097201540135, 0.022417116051656194, 0.08233427884988487, 0.08883889153366908, 0.03728455674718134, 0.04517823981586844, 0.0773204404686112, 0.013956049024272943, 0.0342523380095372, 0.07279765894054435, 0.05717493826523423, 0.050071223158738576, 1.0707792174071074, 21.59340910613537, 46.12977169454098, 32.16000370681286, 42.73128345608711, 31.441467963159084, 7.9638544376939535, 1.5246915793977678, 0.18567121820524335, 0.21801609196700156, 0.044827148303738795, 0.1414281883626245, 0.18850252643460408, 1.2432966101914644, 0.7800335437059402, 0.519602702697739, 4.316813936457038, 14.753572829067707, 37.52873942255974, 49.30024556815624, 52.16282196342945, 50.066493451595306, 48.92654702067375, 49.824587032198906, 51.927401795983315, 50.46958342194557, 51.01137734949589, 48.31604138016701, 51.539271622896194, 51.28924123942852, 48.3319017291069, 49.570384472608566, 50.04082962870598, 50.8932188898325, 48.75367529690266, 41.95549048483372, 38.09382610023022, 37.12551645934582, 40.2408666908741, 38.26778456568718, 38.86464133858681, 39.56369362771511, 39.850699827075005, 40.212178230285645, 45.8200541138649, 52.1375685185194, 53.52021932601929, 52.90622167289257, 48.32796894013882, 43.12398098409176, 38.79519246518612, 37.92745962738991, 36.720363199710846, 39.194596633315086, 37.99866780638695, 40.625520050525665, 47.15919345617294, 52.90490314364433, 51.938086822628975, 51.62395387887955, 52.278024181723595, 52.459536641836166, 51.85025453567505, 51.60060413181782, 46.79407864809036, 43.86101223528385, 47.531957253813744, 46.54403306543827, 48.48644323647022, 50.47444336116314, 50.868854597210884, 49.736785143613815, 52.70433470606804, 41.471426859498024, 45.8591578155756, 53.24937745928764, 43.6834591627121, 36.732085570693016, 36.03484958410263, 36.580466106534004, 36.80303916335106, 36.51052325963974, 36.90317139029503, 40.55089205503464, 43.784404546022415, 45.2095864713192, 43.52691896259785, 43.369793593883514, 41.95004537701607, 39.98143561184406, 37.37323276698589, 36.31151653826237, 36.73587776720524, 37.299771308898926, 35.653471648693085, 36.63095399737358, 36.468079537153244, 35.659707114100456, 34.933395087718964, 36.25778742134571, 34.651590809226036, 36.946515664458275, 36.64447747170925, 38.37966576218605, 39.28399443626404, 43.638180792331696, 44.418282732367516, 48.720814660191536, 48.797562941908836, 47.60170631110668, 41.23491995036602, 30.37293680012226, 16.03439100086689, 5.0158315524458885, 2.43694722186774, 5.180219281464815, 6.047925995662808, 8.259019274264574, 8.50196873769164, 2.804985260590911, 4.510129988193512, 0.3434822423150763, 0.3013321431353688, 0.23685423424467444, 0.11964340068516321, 4.01514669880271, 32.1632981300354, 28.288241364061832, 34.45131115615368, 39.01235841214657, 11.95301765576005, 0.13965592486783862, 0.05949274709564634, 0.11617229436524212, 0.030938273848732933, 0.0442003934585955, 0.04001089931989554, 0.09138016845099628, 0.0556880119984271, 0.051283231950947084, 0.03842566075036302, 0.04351334282546304, 0.024697932531125844, 0.029737903787463438, 0.01778284724423429, 0.01907398382172687, 0.019262251844338607, 0.029918049003754277, 0.05606448867183644, 0.04793607171450276, 0.06540899252286181, 0.11147759432788007, 0.1680603506974876, 0.19730655010789633, 0.18337529530981556, 0.14098402782110497, 0.18048816273221746, 0.09749569537234493, 0.13518458901671693, 0.1361400744644925, 0.12061493136570789, 0.11798533887485974, 0.19504717056406662, 0.08101764949969947, 0.17504679533885792, 0.12259961236850359, 0.23865889990702271, 0.13107769220368937, 0.12999990081880242, 0.10791322973091155, 0.18102351838024333, 0.16049504571128637, 0.26522437285166234, 0.18499335536034778, 0.2139688192983158, 0.16193415911402553, 1.361797763966024, 25.51586262881756, 54.95714642107487, 41.5979790687561, 45.90210311114788, 36.13580256700516, 11.696139089763165, 2.185240415856242, 0.3532934939721599, 0.5997366621159017, 0.30696035362780094, 0.2844816801371053, 0.47013054485432804, 2.8787077171728015, 0.9967156103812158, 1.108434246852994, 3.0785933788865805, 15.133622735738754, 38.99773679673672, 49.08084534108639, 52.71889932453632, 52.57432088255882, 49.043994918465614, 50.46427130699158, 53.367741107940674, 52.50872500240803, 52.76896923780441, 50.8940814435482, 52.75631591677666, 51.683052107691765, 49.32193100452423, 49.93449993431568, 51.6383209079504, 52.47255854308605, 51.663612350821495, 44.67273607850075, 39.27854172885418, 38.17095436155796, 43.0419509857893, 40.59650860726833, 41.89280904829502, 42.780027240514755, 41.38327158987522, 41.73948347568512, 49.348081201314926, 53.80743071436882, 55.470780059695244, 55.12768127024174, 49.57904040813446, 45.53953796625137, 40.229338109493256, 40.04133939743042, 38.09988297522068, 41.10299862921238, 39.47063282132149, 43.19396562874317, 49.04507406055927, 55.92237062752247, 53.95460061728954, 52.061458602547646, 53.782139271497726, 54.31461989879608, 53.93148645758629, 53.83427247405052, 48.72034728527069, 44.804072231054306, 48.070266768336296, 47.11704231798649, 49.21296805143356, 52.863333374261856, 53.000338822603226, 51.65347449481487, 52.21459038555622, 43.0080796033144, 46.86857745051384, 56.41649231314659, 44.521226808428764, 38.231386318802834, 37.78465948998928, 37.216703966259956, 37.98135593533516, 38.509865775704384, 38.95379975438118, 44.51644666492939, 46.49952605366707, 47.209650948643684, 45.517457351088524, 45.798277482390404, 43.411701545119286, 41.35690480470657, 38.999382108449936, 39.413898065686226, 37.74656653404236, 38.20207469165325, 36.99075289070606, 38.5537876188755, 37.86273010075092, 39.01887126266956, 35.99735699594021, 39.78160813450813, 36.082480028271675, 39.63668771088123, 37.46620237827301, 40.75522609055042, 43.32044564187527, 46.23009771108627, 47.10371643304825, 51.935050785541534, 49.92359831929207, 47.09623843431473, 40.97880609333515, 29.37331683933735, 14.844699539244175, 5.1248762011528015, 2.083937139250338, 8.401159197092056, 10.440699756145477, 21.325835064053535, 23.809216506779194, 5.405510142445564, 5.257017435505986, 0.6366962695028633, 0.6300338613800704, 0.3043630445608869, 0.18804235034622252, 6.689934320747852, 37.704441994428635, 37.59563483297825, 41.89560569822788, 43.029677644371986, 13.67690535262227, 0.23816437722416595, 0.17201492912136018, 0.16588403232162818, 0.14244675636291504, 0.1433683405048214, 0.1831639019655995, 0.21921106847003102, 0.15650997986085713, 0.14078919921303168, 0.18132450379198417, 0.15186999837169424, 0.15108067978871986, 0.16265160811599344, 0.12087696886737831, 0.21903512009885162, 0.07567142543848604, 0.0990153689053841, 0.1687133070663549, 0.09005153115140274, 0.25476148584857583], [0.014154667223920114, 0.046946740621933714, 0.021705928920709994, 0.016966366056294646, 0.02518259578209836, 0.026840665013878606, 0.010485335114935879, 0.02337328427529428, 0.005243118412181502, 0.03379724563274067, 0.09257872952730395, 0.05527555971639231, 0.04586221795761958, 0.059097816920257173, 0.013568218419095501, 0.058622827564249747, 0.030447558383457363, 0.06913023971719667, 0.04857244850427378, 0.011106046094937483, 0.029617957879963797, 0.01853311958257109, 0.01751454230543459, 0.06346026115352288, 0.049651004301267676, 0.05768761759100016, 3.987088054418564, 32.520296573638916, 32.95831046998501, 33.4548944234848, 39.44336548447609, 12.461291681975126, 3.124653557315469, 0.369367670500651, 0.24527943605789915, 0.16851687541930005, 0.030410458421101794, 0.11665319863823242, 0.5523073696531355, 0.2226991328643635, 1.1126942932605743, 1.1589627480134368, 2.181826299056411, 14.706619698554277, 32.59232550859451, 47.12863549590111, 50.09390518069267, 46.89626656472683, 49.253169894218445, 47.56126508116722, 51.982677429914474, 49.05202388763428, 50.635292530059814, 50.09527690708637, 47.804110050201416, 48.52545194327831, 49.29085247218609, 50.512437522411346, 49.77219544351101, 45.00753611326218, 40.22103555500507, 37.159961611032486, 36.315475925803185, 37.6846868544817, 36.210859939455986, 36.48136742413044, 38.284252882003784, 36.46621763706207, 38.18440563976765, 46.47465638816357, 51.11247472465038, 51.885588839650154, 51.529076769948006, 49.082642644643784, 43.26760947704315, 38.63926783204079, 36.80087707936764, 36.17342434823513, 36.14769972860813, 37.281007915735245, 37.47765876352787, 40.252680256962776, 47.935643792152405, 48.69007430970669, 47.51861236989498, 46.844999715685844, 48.37906859815121, 47.63183869421482, 50.87875306606293, 46.449281349778175, 43.37542489171028, 44.68062445521355, 45.93737281858921, 46.64088226854801, 47.040016651153564, 47.92239770293236, 44.83979791402817, 47.487317249178886, 47.30211898684502, 49.42842409014702, 47.25232645869255, 42.84528113901615, 36.24238684773445, 33.37336599826813, 35.466042906045914, 36.66000723838806, 35.29805392026901, 39.365583658218384, 46.195945143699646, 44.79940228164196, 45.00938281416893, 42.30137452483177, 41.09797149896622, 38.25811788439751, 36.64183661341667, 34.873464703559875, 33.664612770080566, 34.96347427368164, 34.07520733773708, 33.60116757452488, 35.757445469498634, 35.0335843116045, 35.622412115335464, 35.27734503149986, 34.81252357363701, 35.15770465135574, 36.1687657982111, 36.12009420990944, 38.76128688454628, 38.5601294785738, 44.36060182750225, 44.01985511183739, 47.28721618652344, 47.33720250427723, 46.847496181726456, 31.839033029973507, 13.338234275579453, 4.057837408035994, 1.0031445091590285, 1.5052652405574918, 4.21597589738667, 5.655246516689658, 3.9717962499707937, 5.054277889430523, 3.213248890824616, 1.6976708848960698, 0.620064502581954, 0.09695305183413438, 0.10216085051069967, 0.10052457815618254, 7.0645201206207275, 34.943677335977554, 28.40639792382717, 36.0095277428627, 22.610399834811687, 1.233212782535702, 0.01088354558305582, 0.08489426531014033, 0.06257245215238072, 0.0176811711571645, 0.04131200665142387, 0.05075171691714786, 0.07076467896695249, 0.04610110045177862, 0.035932957398472354, 0.034342008002568036, 0.017324307591479737, 0.020269852757337503, 0.010814285578817362, 0.0448083348601358, 0.026277751567249652, 0.09017771109938622, 0.018835418595699593, 0.05124326729855966, 0.04133480542805046, 0.07077085363562219, 0.02181684845709242, 0.04137569405429531, 0.03838603377516847, 0.043684322517947294, 0.017844658868853003, 0.0254237807894242, 0.015952952271618415, 0.013195694609748898, 0.03744357672985643, 0.025263892493967433, 0.0828736272524111, 0.019549785829440225, 0.043469348311191425, 0.017363485567329917, 0.026294937852071598, 0.03776698613364715, 0.009727337946969783, 0.030580508573621046, 0.056422018315060996, 0.07066718302667141, 0.10337878164136782, 0.041307891442556866, 0.036538683489197865, 0.050457737379474565, 0.02228436067525763, 0.05758121958933771, 7.47265194542706, 40.48569515347481, 36.948514357209206, 33.20677913725376, 41.5191674977541, 14.273998662829399, 3.719403105787933, 0.20393747632624581, 0.2743733022361994, 0.09541132909362204, 0.09616649404051714, 0.3822779527399689, 1.4548474084585905, 1.0134264011867344, 1.4963540062308311, 2.0983386039733887, 5.603795852512121, 18.089506924152374, 36.041328236460686, 49.312108531594276, 51.00510388612747, 47.84966200590134, 49.25530157983303, 48.056142926216125, 52.474944815039635, 50.47705762088299, 51.883472353219986, 50.94641983509064, 48.063062354922295, 49.26944442093372, 49.77976083755493, 52.10785411298275, 52.1669789403677, 46.602287739515305, 42.33000598847866, 38.52981850504875, 37.815361842513084, 39.176897183060646, 38.97177278995514, 39.603485092520714, 38.159433379769325, 38.87393184006214, 39.93487671017647, 47.720225751399994, 53.998131081461906, 51.829515248537064, 51.85395173728466, 50.18241003155708, 45.47010809183121, 40.52565760910511, 38.597188889980316, 37.59733334183693, 37.5528909265995, 39.025441110134125, 38.60477328300476, 42.733479738235474, 49.3097298592329, 50.26090621948242, 50.08274517953396, 48.257649913430214, 50.95520116388798, 49.60324130952358, 52.02881075441837, 49.59461957216263, 43.996486365795135, 45.24000383913517, 46.93014934659004, 46.72997608780861, 46.279852241277695, 49.44575496017933, 45.20585127174854, 46.40294663608074, 46.56072176992893, 50.457272082567215, 49.93065074086189, 44.03981924057007, 37.25920468568802, 35.72842262685299, 35.87330885231495, 37.12963163852692, 36.21859632432461, 40.27915343642235, 47.398193031549454, 46.52845770120621, 45.21080240607262, 44.173545464873314, 43.989422544837, 40.025950223207474, 38.49624350667, 36.399162635207176, 36.307021379470825, 36.05488210916519, 37.05618537962437, 35.56276671588421, 37.901491820812225, 36.72454297542572, 36.889902502298355, 36.24462492763996, 37.196131870150566, 36.61713793873787, 38.343351110816, 37.1461645513773, 41.10574208199978, 40.712265595793724, 45.76775372028351, 46.678599044680595, 49.488894045352936, 48.47410149872303, 46.111357882618904, 34.490513652563095, 16.318836137652397, 6.652019480243325, 1.9601382385008037, 1.987494989298284, 7.251245426014066, 5.881363833323121, 7.58565123192966, 5.804825015366077, 3.815692076459527, 6.125211948528886, 2.3041543224826455, 0.20302215591073036, 0.1824757529539056, 0.02916294899478089, 8.323600608855486, 38.86225126683712, 29.827667959034443, 38.41375753283501, 28.470705673098564, 2.333519859239459, 0.05629472514556255, 0.0260438507393701, 0.04638368802261539, 0.032184243318624794, 0.029533462511608377, 0.020655621119658463, 0.014977156097302213, 0.024632534477859735, 0.04911963769700378, 0.03066394081542967, 0.04447447972779628, 0.06162833269627299, 0.03065001070353901, 0.0256273945706198, 0.027880057677975856, 0.04219066126097459, 0.06017274361511227, 0.021005263588449452, 0.03839313612843398, 0.094668016245123, 0.08177020950824954, 0.12878420355264097, 0.18108636344550177, 0.13055156887276098, 0.14222353318473324, 0.07804059830959886, 0.1074291490658652, 0.0697105101426132, 0.16034400381613523, 0.06982740582316183, 0.20091410027816892, 0.17807520314818248, 0.12746000429615378, 0.10711896844441071, 0.15739059745101258, 0.13924683822551742, 0.12764000479364768, 0.16388320218538865, 0.1608692662557587, 0.2980433899210766, 0.16377440333599225, 0.07258169396664016, 0.10698102545575239, 0.12428796864696778, 0.14674034784547985, 0.11732102022506297, 8.183144945651293, 46.53289206326008, 44.21009950339794, 42.13704094290733, 50.488760992884636, 18.698783330619335, 6.683177808299661, 1.0190357314422727, 0.46868763165548444, 0.4677325172815472, 0.34343183564487845, 0.6658553704619408, 4.133121343329549, 1.5008573583327234, 3.1885597156360745, 3.231438989751041, 4.160179691389203, 16.714142225682735, 35.731128081679344, 50.576475486159325, 52.00661614537239, 47.877161130309105, 49.73931580781937, 48.41000273823738, 54.00952287018299, 52.20372676849365, 54.437566101551056, 52.37958513200283, 51.66593782603741, 50.14507703483105, 52.72748306393623, 53.166097328066826, 55.007953494787216, 48.28834846615791, 44.064992889761925, 40.37480190396309, 39.2044723033905, 41.924978122115135, 40.14804907143116, 40.96323452889919, 40.30628778040409, 40.17596237361431, 41.53215520083904, 49.64838668704033, 55.27874976396561, 55.550324991345406, 53.87302279472351, 53.14788110554218, 48.156985715031624, 42.545993998646736, 40.5758985131979, 39.804042130708694, 39.720176830887794, 40.301317647099495, 41.774578392505646, 44.71211716532707, 50.9134604036808, 53.32152038812637, 52.291220873594284, 50.12984745204449, 52.93030098080635, 51.84014327824116, 54.9557138979435, 51.44985482096672, 44.623118340969086, 45.32320037484169, 46.00518397986889, 48.136911392211914, 47.232358530163765, 49.47617992758751, 44.770242646336555, 48.24054703116417, 48.008276894688606, 51.64134934544563, 51.45329363644123, 45.368987917900085, 40.078638195991516, 38.0900377035141, 38.53628195822239, 39.075142443180084, 39.69612792134285, 42.63678252696991, 49.09096419811249, 48.34326311945915, 49.197928458452225, 45.85476525127888, 45.406427308917046, 42.84090377390385, 40.6427027285099, 37.85869851708412, 37.28950805962086, 37.93059065937996, 38.67500491440296, 38.63590881228447, 39.934557527303696, 38.85001212358475, 40.22588789463043, 38.513304591178894, 38.88680934906006, 37.9658717662096, 40.887200608849525, 39.07502084970474, 43.53109113872051, 42.60813966393471, 48.1708549708128, 48.570053949952126, 52.16588839888573, 50.39227657020092, 46.98615454137325, 34.479418247938156, 16.24866910278797, 5.349471224471927, 1.7487952415831387, 2.935282881371677, 9.510567616671324, 12.724422812461853, 9.442478120326996, 10.457096826285124, 7.290614163503051, 8.640287015587091, 2.073354469612241, 0.1631699240533635, 0.35858518502209336, 0.20379507303005084, 10.095906257629395, 47.26963073015213, 38.20109434425831, 46.66586592793465, 34.1980205476284, 2.3035318683832884, 0.1197962682635989, 0.2128544994047843, 0.1085957903706003, 0.15571074618492275, 0.13585549051640555, 0.0744098486029543, 0.17977948591578752, 0.17866460199002177, 0.20095545274671167, 0.11732562154065818, 0.15576072240946814, 0.1229115815658588, 0.12752798502333462, 0.15124252735404298, 0.1712631483678706, 0.16955337370745838, 0.10629637938109227, 0.17240044515347108, 0.1287220264202915, 0.17247583251446486], [0.012462554750527488, 0.06566447686054744, 0.0512757028627675, 0.04585969836625736, 0.018890239189204294, 0.030605797255702782, 0.06317125400528312, 0.0254751485408633, 0.044778099763789214, 0.09100233364733867, 0.012388362247293117, 0.048631772078806534, 0.01857825329352636, 0.0911077854107134, 0.04139857817790471, 0.03599953917728271, 0.061720166049781255, 0.019860320826410316, 0.03768881942960434, 0.004584678499668371, 0.044380316030583344, 0.04008031239209231, 0.042226388250128366, 0.06971183116547763, 0.04549319615762215, 0.03019319468876347, 0.08999503144877963, 16.09067928045988, 39.54558379948139, 29.714441634714603, 34.91791091859341, 21.325046606361866, 6.183226285502315, 0.05471792108437512, 0.10770680877612904, 0.15979615040123463, 0.07439322449499741, 0.2835041529033333, 0.7103682006709278, 1.1788139515556395, 0.14298804919235408, 0.7383230631239712, 1.3728088606148958, 2.345834760926664, 11.621331553906202, 32.302940636873245, 45.52368141710758, 50.03025099635124, 48.762361630797386, 48.06673675775528, 49.021845906972885, 49.09743145108223, 50.51667049527168, 48.22453089058399, 49.681938886642456, 51.531717628240585, 50.830548852682114, 52.20039054751396, 48.747002854943275, 42.87887133657932, 37.77685470879078, 38.397068828344345, 38.4857826679945, 37.80013985931873, 37.23612852394581, 39.37059938907623, 38.00451949238777, 38.141828924417496, 38.524882569909096, 46.1067221313715, 51.1148913949728, 52.04019874334335, 53.42082805931568, 49.5529206097126, 45.20542189478874, 39.509227350354195, 37.78326116502285, 37.30500742793083, 36.49911627173424, 36.02919928729534, 37.634939923882484, 36.397901102900505, 38.37948337197304, 39.468710124492645, 43.025543466210365, 44.90671992301941, 45.94035565853119, 47.74094983935356, 51.22513107955456, 48.4149044752121, 43.273924738168716, 45.1873804628849, 45.855088233947754, 48.74545253813267, 49.440401047468185, 50.376587212085724, 49.91132877767086, 51.49318389594555, 51.09701335430145, 47.72084891796112, 47.73115396499634, 39.604978412389755, 33.69756460189819, 36.62819154560566, 35.366142466664314, 35.47261655330658, 37.76050038635731, 47.16597989201546, 47.53788113594055, 47.58035525679588, 44.774126037955284, 42.329538613557816, 37.22561828792095, 37.72808812558651, 34.98561188578606, 35.05890615284443, 34.56562802195549, 35.14657124876976, 35.23779295384884, 35.09672552347183, 33.70968595147133, 37.43842586874962, 37.78006173670292, 38.271743953228, 38.22985500097275, 36.81283503770828, 36.0591758787632, 37.26535275578499, 39.368216916918755, 41.59243516623974, 45.31494341790676, 44.079382717609406, 44.563442543148994, 47.66645863652229, 42.17251963913441, 19.550923705101013, 5.271788667887449, 2.0758993830531836, 0.8545693941414356, 1.8595740222372115, 5.696139447391033, 1.8926994572393596, 5.581241212785244, 4.355170503258705, 1.5012597804889083, 5.5227614007890224, 1.9260477740317583, 0.2553232619538903, 0.14282902178820223, 0.30105790472589433, 16.089421547949314, 30.594103932380676, 25.10648399591446, 34.71112601459026, 12.53009743988514, 0.10547393132583238, 0.06182775890920311, 0.057080529659288004, 0.030471594691334758, 0.033052945727831684, 0.02676765994692687, 0.059759935102192685, 0.04351579933427274, 0.039801732418709435, 0.03087554381636437, 0.012656211692956276, 0.013199343193264212, 0.006519046992252697, 0.07070503997965716, 0.03138195570500102, 0.04642038722522557, 0.07457834581146017, 0.02188631162425736, 0.01790797705325531, 0.052549398969858885, 0.017132898428826593, 0.053993770488887094, 0.024875960771169048, 0.0264091822100454, 0.019988103813375346, 0.07330351421842352, 0.07365929239313118, 0.05630632120301016, 0.05699670778994914, 0.004681794089265168, 0.009798048849916086, 0.11006519082002342, 0.088959750282811, 0.030925549726816826, 0.008735208957659779, 0.06374125310685486, 0.026448683020134922, 0.06663585911155678, 0.027995090567856096, 0.03106370051682461, 0.030585547756345477, 0.031170313741313294, 0.047456058018724434, 0.0406588424812071, 0.03487183465040289, 0.03128800351987593, 0.031380460277432576, 0.45668728183954954, 23.165949024260044, 44.11314770579338, 32.31136478483677, 42.70552083849907, 24.977095238864422, 7.022744212299585, 0.18729536386672407, 0.15963094832841307, 0.42171930195763707, 0.06147346874058712, 0.6917995470575988, 1.5991522651165724, 0.6199774041306227, 0.9067233768291771, 3.005993999540806, 4.084148621186614, 4.208279410377145, 14.795694518834352, 34.7428885102272, 47.66670562326908, 49.51399929821491, 49.6653413772583, 48.407187089324, 48.90502117574215, 51.569730788469315, 52.8950122743845, 50.729603469371796, 51.19376756250858, 52.410355880856514, 53.436471819877625, 53.42831365764141, 49.57855403423309, 45.190530493855476, 38.72116483747959, 40.46255819499493, 38.82421150803566, 39.68609265983105, 38.27333606779575, 40.712987557053566, 39.79951657354832, 39.90899629890919, 40.06468914449215, 47.38698363304138, 52.3310237377882, 53.47359962761402, 54.4987428188324, 53.45175080001354, 46.392865777015686, 41.240729838609695, 38.0053174495697, 38.910789862275124, 38.54568265378475, 37.401602044701576, 39.39664699137211, 40.13029642403126, 41.168792098760605, 43.720811158418655, 46.876249238848686, 46.503124460577965, 47.936202362179756, 49.181026965379715, 53.499559834599495, 48.94697852432728, 44.4945864379406, 44.8084381967783, 44.52797144651413, 47.94945605099201, 48.655822947621346, 48.75393748283386, 49.68136131763458, 52.820996046066284, 53.22024442255497, 50.60974270105362, 49.42185044288635, 40.834592431783676, 35.052720084786415, 37.90920540690422, 36.42100386321545, 35.8076635748148, 39.60785485804081, 47.77778886258602, 49.51740391552448, 49.527537971735, 46.80730193853378, 43.81322979927063, 40.984821170568466, 39.61975581943989, 38.17259967327118, 35.748356357216835, 35.12532278895378, 36.8927713483572, 37.25947067141533, 36.294732838869095, 36.74179024994373, 38.72908741235733, 40.169259533286095, 39.353184923529625, 40.55352911353111, 37.54433758556843, 38.7348061054945, 39.09216172993183, 42.81391382217407, 42.66307331621647, 46.79144158959389, 46.14201083779335, 47.55617715418339, 47.99370467662811, 43.68011154234409, 22.725579254329205, 8.07828102260828, 2.4237431678920984, 3.52720158174634, 2.5548670068383217, 8.04173743352294, 6.173704946413636, 9.337861184030771, 6.7222363874316216, 5.626499634236097, 4.714486822485924, 3.058562516234815, 1.0727459681220353, 0.03357039335242007, 0.2306070874328725, 17.03284442424774, 37.22888611257076, 28.214453123509884, 41.4387372136116, 16.678946614265442, 0.260059826541692, 0.04323257351643406, 0.05446872273751069, 0.039245963998837397, 0.03088497836870374, 0.04788864476722665, 0.014296907247626223, 0.04439338525116909, 0.031064522445376497, 0.021822229027748108, 0.02123780628608074, 0.045001326652709395, 0.05479271101648919, 0.018811502886819653, 0.03032999848073814, 0.05007818450394552, 0.06809325903304853, 0.0768729996343609, 0.0250933729330427, 0.04507620935328305, 0.07117003260646015, 0.0803833878308069, 0.15470216749235988, 0.16649861965561286, 0.09895637558656745, 0.1140906146611087, 0.1345952643896453, 0.19584371766541153, 0.165620748011861, 0.12735890893964097, 0.23253477149410173, 0.25707639288157225, 0.177252265275456, 0.14596407621866092, 0.18030645529506728, 0.18816323135979474, 0.0908834564324934, 0.11772816986194812, 0.1476304797688499, 0.11702731528203003, 0.12695307290414348, 0.08234297682065517, 0.16043469426222146, 0.23233522282680497, 0.11073414047132246, 0.1728356850799173, 0.23997028969461098, 0.881511076586321, 27.34266210347414, 52.56793722510338, 39.59932431578636, 46.78395599126816, 29.583071283996105, 13.187353871762753, 0.41937438247259706, 0.42419098026584834, 1.2237882195040584, 0.18141580279916525, 1.080609408672899, 2.8180738957598805, 2.9031425435096025, 2.3102691443637013, 4.027214851230383, 2.4479084461927414, 2.9920095624402165, 13.789996784180403, 35.76914504170418, 48.044918328523636, 50.24472288787365, 49.41396586596966, 48.80127154290676, 50.44018819928169, 52.825806587934494, 55.07595084607601, 53.18719379603863, 53.304269313812256, 53.571934551000595, 55.54701916873455, 55.99710501730442, 51.68152078986168, 47.03907810151577, 41.85803711414337, 42.374695390462875, 41.636018827557564, 40.79776480793953, 40.14455325901508, 42.89798051118851, 41.28925323486328, 42.83470630645752, 42.24935531616211, 49.70841206610203, 55.88991276919842, 55.40420763194561, 56.19421564042568, 55.79964481294155, 49.09246511757374, 43.48384067416191, 40.30361272394657, 40.35883516073227, 40.1841851323843, 40.277033150196075, 42.80824452638626, 42.086773440241814, 42.55884870886803, 45.002809166908264, 47.99079403281212, 50.16259789466858, 48.87367285788059, 51.55648469924927, 54.537911117076874, 51.64807878434658, 46.6001370549202, 43.642527759075165, 45.7200662791729, 48.54232303798199, 50.12266583740711, 50.62907226383686, 50.782451033592224, 54.87706571817398, 55.81593453884125, 53.46100710332394, 51.98476731777191, 42.46894933283329, 36.628145948052406, 41.546993404626846, 38.640373572707176, 37.76834696531296, 41.855434253811836, 50.452769324183464, 51.439834758639336, 52.27426618337631, 49.00759667158127, 45.750240460038185, 41.03270620107651, 40.79677306115627, 40.2013336122036, 37.52117022871971, 37.806975692510605, 38.17672625184059, 38.92528988420963, 39.33534488081932, 38.128712028265, 41.204867362976074, 42.667203694581985, 42.30608247220516, 42.8424084931612, 41.157130524516106, 39.99762274324894, 40.41447177529335, 45.35516045987606, 44.98691461980343, 48.90479698777199, 48.07893790304661, 49.6350722014904, 50.07570795714855, 43.70723448693752, 22.704271897673607, 7.8315692860633135, 3.1892721774056554, 3.4077837271615863, 5.476779118180275, 10.050417948514223, 8.678372371941805, 13.770126700401306, 13.159965891391039, 8.656630888581276, 13.655884880572557, 4.746861085295677, 1.1245297081768513, 0.9145567158702761, 0.5079481343273073, 21.820828802883625, 39.306595623493195, 34.129996597766876, 47.4113555252552, 18.120070584118366, 0.39927853737026453, 0.29900494613684714, 0.1271796357468702, 0.15784513321705163, 0.09646926060668193, 0.13174734689528123, 0.12293826177483425, 0.11894138093339279, 0.1609224040294066, 0.17383287922712043, 0.10047227158793248, 0.222602920839563, 0.12833276996389031, 0.11973035812843591, 0.09238604572601616, 0.23447591811418533, 0.19999665732029825, 0.1772722290479578, 0.1462236201041378, 0.14160087128402665, 0.15473413921426982], [0.10521996096940711, 0.07640908312168904, 0.03985488503531087, 0.02290688342327485, 0.0684497199836187, 0.06151679532194976, 0.03673307794088032, 0.0559738687297795, 0.049286108842352405, 0.05005789047572762, 0.1001355517655611, 0.01654509705986129, 0.016376273306377698, 0.023466998973162845, 0.016316066576109733, 0.05302423989633098, 0.06424866689485498, 0.09717267559608445, 0.04006812261650339, 0.05763671739259735, 0.07363760683801956, 0.02454943249176722, 0.022150343647808768, 0.035212877482990734, 0.011606855696300045, 0.016840889293234795, 0.010135174070455832, 4.020145805552602, 31.206311881542206, 29.66534446924925, 28.148194178938866, 25.182793401181698, 18.071558587253094, 1.7049805051647127, 0.05762070926721208, 0.2296584891155362, 0.06045313442882616, 0.593398364726454, 0.5637460621073842, 0.35112517594825476, 0.8811069920193404, 1.9468333711847663, 5.690160943195224, 0.5372151138726622, 1.0949505516327918, 11.627723760902882, 28.425567895174026, 48.57547625899315, 50.547141060233116, 50.35027362406254, 50.29049143195152, 48.49422141909599, 47.605122327804565, 50.14961779117584, 51.525550559163094, 50.75212486088276, 51.17976151406765, 47.8333380818367, 44.41836632788181, 40.526957139372826, 41.952906623482704, 43.77166382968426, 45.121438801288605, 41.499537751078606, 35.92668078839779, 36.22651129961014, 37.05748490989208, 37.15916745364666, 40.10330267250538, 47.8094145655632, 53.54044944047928, 53.09773899614811, 52.100938484072685, 50.72510451078415, 48.52388262748718, 42.46688224375248, 36.870135962963104, 37.366932705044746, 37.11983576416969, 36.88917674124241, 35.85516482591629, 35.14227367937565, 36.962319016456604, 36.18148751556873, 36.3599943369627, 39.11860451102257, 44.99801002442837, 47.143549695611, 50.5364940315485, 46.55310697853565, 44.039207473397255, 47.15825870633125, 49.440864622592926, 50.92120058834553, 50.25296464562416, 49.67075228691101, 50.38591951131821, 48.603632748126984, 47.17220015823841, 47.99228735268116, 42.194934636354446, 33.94512511789799, 35.4983601719141, 35.995552092790604, 34.871773794293404, 34.282056838274, 41.09663397073746, 48.16923625767231, 51.09640918672085, 48.179590702056885, 46.85524396598339, 44.32441256940365, 37.42424122989178, 37.17488341033459, 37.29963831603527, 34.33753006160259, 33.68257060647011, 35.28002388775349, 34.33861680328846, 38.141065165400505, 38.11809919774532, 37.15881787240505, 38.18049944937229, 40.650712698698044, 41.413354575634, 38.32082971930504, 38.29504810273647, 36.98730267584324, 38.874741196632385, 42.81130716204643, 46.00291930139065, 45.89517988264561, 46.77472248673439, 43.31279665231705, 32.698814794421196, 8.959466088563204, 2.328434307128191, 0.8427320793271065, 2.9744922649115324, 2.2490463545545936, 7.365852501243353, 6.24436310492456, 6.887650536373258, 4.3819215428084135, 5.063605913892388, 5.868048397824168, 4.403993133455515, 2.1490407083183527, 0.05639320443151519, 1.9991829246282578, 24.626233465969563, 27.616849690675735, 36.02799475193024, 28.3028781786561, 2.6112008839845657, 0.04000803462986369, 0.06186544516822323, 0.06462945544626564, 0.02623440457682591, 0.04481872121687047, 0.030774502265558112, 0.04910014147753827, 0.05274809416732751, 0.05062703239673283, 0.06514227949082851, 0.044389704198692925, 0.05024972451792564, 0.03753872377274092, 0.10294649546267465, 0.026185630631516688, 0.00901305513252737, 0.040170357169699855, 0.03614685920183547, 0.05724652211938519, 0.027850323531311005, 0.012239031930221245, 0.07849977992009372, 0.057580540524213575, 0.024573893679189496, 0.026968676211254206, 0.03639825801656116, 0.01443654047761811, 0.03739422762009781, 0.05189348514250014, 0.06779677845770493, 0.08702195817022584, 0.04426042578415945, 0.037484227868844755, 0.06754039612133056, 0.04680527243181132, 0.024057824593910482, 0.03186047026247252, 0.04666977853048593, 0.10796501679578796, 0.04005635215435177, 0.015375289567600703, 0.053420880722114816, 0.04533442850515712, 0.03005196213052841, 0.058346017613075674, 0.06372118543367833, 0.06779866351280361, 0.01566614559123991, 7.803463619202375, 39.287285059690475, 33.92091661691666, 33.50435256958008, 30.15183426439762, 21.58419080078602, 1.21226403163746, 0.025756159047887195, 0.43280146666802466, 0.07406249380437657, 0.6235889322124422, 1.0609002225100994, 0.34897671779617667, 0.8286471257451922, 2.7351473830640316, 7.430751118808985, 1.7720987973734736, 1.8894842360168695, 14.403495714068413, 32.2746055573225, 51.76075413823128, 50.78758455812931, 50.87001733481884, 50.771758407354355, 49.48819488286972, 49.79401387274265, 50.521097257733345, 52.217672020196915, 52.74938128888607, 53.31042878329754, 50.92193774878979, 44.771348387002945, 42.26661778986454, 43.987967222929, 43.601607754826546, 45.246448293328285, 41.76577806472778, 37.31125809252262, 38.37154559791088, 39.250351041555405, 40.12778475880623, 39.91454400122166, 49.110118970274925, 53.64901341497898, 53.84593404829502, 53.925224393606186, 52.687668800354004, 49.97172653675079, 43.388488590717316, 38.263680785894394, 38.9118006080389, 39.86804209649563, 39.25233833491802, 38.10982704162598, 37.716027572751045, 37.99817003309727, 38.35141807794571, 38.873635455965996, 41.2166353315115, 46.79330348968506, 50.02306938171387, 52.80189827084541, 49.06203635036945, 44.9358681589365, 44.49231415987015, 48.386588394641876, 52.044788897037506, 52.23259761929512, 52.40154795348644, 51.56159162521362, 50.69961167871952, 48.83924290537834, 48.65738086402416, 44.809327349066734, 35.80765977501869, 36.18095554411411, 37.237222865223885, 35.937586203217506, 34.76644344627857, 40.153532177209854, 50.534286350011826, 53.020960316061974, 50.512137338519096, 48.41611661016941, 45.60054749250412, 39.15591470897198, 36.96155905723572, 38.00670437514782, 36.483404114842415, 35.70439271628857, 37.73541413247585, 37.297077253460884, 38.56228396296501, 38.91683913767338, 39.53584872186184, 40.63379220664501, 42.14067354798317, 42.61324658989906, 39.54768888652325, 40.46259619295597, 38.99753160774708, 42.50834561884403, 43.84724177420139, 47.08718731999397, 46.174206510186195, 47.989144921302795, 43.66625748574734, 34.04088377952576, 11.41977896913886, 3.9432569313794374, 3.707885923795402, 4.489592090249062, 4.07197454944253, 9.888861067593098, 5.956836333498359, 10.865621455013752, 7.86103100515902, 6.5497384686023, 4.229967221617699, 1.8982925196178257, 2.0120948692783713, 0.09864775347523391, 1.7848928296007216, 30.892990194261074, 30.66096894443035, 35.975546166300774, 34.45062719285488, 4.429360097274184, 0.055717705326969735, 0.07009658278548159, 0.057113926304737106, 0.0710965451435186, 0.04895593105175067, 0.03503971587633714, 0.03503796811855864, 0.04571283105178736, 0.023470073319913354, 0.09623023710446432, 0.06170662927615922, 0.030827372866042424, 0.012657916777243372, 0.05912061569688376, 0.048074990627355874, 0.04335648249252699, 0.059080903374706395, 0.04854342310864013, 0.06372419113176875, 0.00659574006931507, 0.0752490024024155, 0.1992229832103476, 0.20594341243850067, 0.07746944145765156, 0.16422733606304973, 0.21558717620791867, 0.17457055917475373, 0.12116217621951364, 0.1803058318910189, 0.13541336345952004, 0.3863181156339124, 0.2014647886971943, 0.08481719327392057, 0.13283457839861512, 0.12086634131264873, 0.09349488114821725, 0.14519003103487194, 0.1073100343637634, 0.19042136409552768, 0.12356524297501892, 0.11725757402018644, 0.16388722462579608, 0.1738988413126208, 0.13923057034844533, 0.13695642206585035, 0.13161169714294374, 0.1926764688687399, 0.15889556903857738, 7.980532217770815, 45.9086349606514, 40.512103736400604, 39.95181620121002, 32.336838617920876, 30.187837332487106, 3.3168120961636305, 0.14602778217522427, 0.7929224520921707, 0.22727119299815968, 2.016347791068256, 3.831956866197288, 1.4370191213674843, 2.9940258292481303, 4.974042344838381, 7.899050815030932, 1.408712777774781, 2.1230109175667167, 14.133810885250568, 31.57791294157505, 50.906723365187645, 52.99458593130112, 52.44880601763725, 50.65821290016174, 50.21810531616211, 50.321645960211754, 52.57991798222065, 53.93074929714203, 53.86149801313877, 54.16539050638676, 52.749240696430206, 46.295872181653976, 45.69029487669468, 45.678773894906044, 46.38866700232029, 49.50962573289871, 45.42736038565636, 38.28009210526943, 39.45874325931072, 41.08281031250954, 41.253215968608856, 41.68526418507099, 51.32210947573185, 57.67258711159229, 56.58619500696659, 54.84722211956978, 55.46291448175907, 51.859024465084076, 46.10763028264046, 41.40184499323368, 41.606821194291115, 42.477502673864365, 39.63936656713486, 38.75678792595863, 39.54390428960323, 39.45376172661781, 40.182946398854256, 40.34906968474388, 43.037068247795105, 49.195614382624626, 51.246463134884834, 53.68278220295906, 50.97243323922157, 46.325806975364685, 46.33957363665104, 51.423936411738396, 55.0160014629364, 53.51282112300396, 55.11698104441166, 54.997781440615654, 52.2836896777153, 52.45543286204338, 51.78664214909077, 46.48161381483078, 38.35473909974098, 38.823132365942, 39.220021069049835, 38.06881584227085, 37.3645806312561, 43.5024406760931, 52.12469860911369, 54.31397393345833, 52.67015554010868, 49.53314267098904, 49.49533849954605, 40.46715594828129, 39.81846235692501, 41.19405694305897, 36.164236441254616, 37.49075286090374, 40.3128994256258, 37.131611332297325, 41.51437595486641, 41.56454086303711, 41.790818721055984, 41.904147639870644, 45.19362732768059, 46.01320154964924, 41.20830997824669, 43.86694751679897, 41.34987898170948, 44.89065818488598, 47.04309828579426, 50.36350071430206, 49.51102785766125, 48.94825905561447, 44.92114394903183, 34.919883012771606, 10.390924327075481, 3.4811851009726524, 3.0667525017634034, 6.0625385865569115, 4.600898567587137, 16.604759395122528, 13.541292529553175, 16.684885695576668, 10.579910036176443, 11.800548937171698, 11.472628433257341, 7.165533900260925, 4.808361260220408, 0.19397271884372458, 2.795836301520467, 33.22720684111118, 38.06618258357048, 46.076886132359505, 41.20336264371872, 5.2606685645878315, 0.1395443207002245, 0.16127162904012948, 0.2081575951888226, 0.18067185912514105, 0.15088319429196417, 0.09331304754596204, 0.08235135566792451, 0.1344439701642841, 0.11545124594704248, 0.16818580334074795, 0.08858830537064932, 0.09377474503708072, 0.133701867016498, 0.19507436285493895, 0.17099514399887994, 0.09295749943703413, 0.11663275989121757, 0.10172397785936482, 0.10955799225484952, 0.13117705093463883, 0.1819642202463001], [0.08289563935250044, 0.07847929664421827, 0.022301396675175056, 0.04576026170980185, 0.046109965405776165, 0.11966671896516345, 0.03711585173732601, 0.0539983940689126, 0.020079686692042742, 0.027563210715015884, 0.050657427054829895, 0.05493994940479752, 0.05100187634525355, 0.048172386377700604, 0.0496483214374166, 0.025194154732162133, 0.026650133440853097, 0.08114407435641624, 0.06329186042421497, 0.04675993463024497, 0.0875454542983789, 0.08095261509879492, 0.023923241678858176, 0.0596031935128849, 0.10155267533264123, 0.11064422185881995, 0.03408677970583085, 0.1250532193807885, 14.484473168849945, 31.938099414110184, 32.40848757326603, 29.10270296037197, 20.752823911607265, 5.5019190441817045, 0.08281204383820295, 0.26052414381410927, 0.06257889399421401, 0.45254927419591695, 1.3348741899244487, 0.257891122600995, 0.911212598439306, 2.2535170521587133, 12.524711228907108, 1.631914700847119, 0.6483790394850075, 1.7718407674692571, 12.094029039144516, 29.327168315649033, 45.847431644797325, 47.310854718089104, 47.49557040631771, 48.679704666137695, 48.70139390230179, 49.17148567736149, 51.68878220021725, 51.824765503406525, 50.6820148229599, 49.48667876422405, 44.28196504712105, 47.16347962617874, 50.59133268892765, 51.524429619312286, 48.45194488763809, 51.300522834062576, 48.27196754515171, 38.663791716098785, 36.748189106583595, 37.222449257969856, 37.34027333557606, 47.08555340766907, 51.00070372223854, 49.97269168496132, 48.26436795294285, 50.7341518253088, 51.4382616430521, 45.13671398162842, 37.64218993484974, 36.75127074122429, 37.67618291079998, 36.428804844617844, 36.46318539977074, 37.20524378120899, 37.131105959415436, 37.83779203891754, 37.953062653541565, 40.60600429773331, 47.18663178384304, 49.09667529165745, 51.12648457288742, 48.6704445630312, 45.3755159676075, 51.375747397542, 51.7353069037199, 48.25093947350979, 47.987617403268814, 48.671428710222244, 46.07631616294384, 48.25668476521969, 47.216536179184914, 41.45352981984615, 36.93722516298294, 33.57266150414944, 36.231344640254974, 34.54196289181709, 34.49640333652496, 34.529879540205, 42.42552146315575, 48.57143707573414, 49.64403212070465, 48.63728754222393, 47.18350075185299, 46.64660096168518, 39.141224697232246, 35.287824869155884, 35.64443193376064, 34.615918323397636, 35.33970728516579, 36.76206596195698, 38.888667449355125, 37.54515454173088, 39.56257648766041, 39.69870798289776, 40.92689707875252, 40.36933399736881, 42.86602422595024, 40.54257810115814, 41.09723433852196, 39.80620801448822, 41.06310456991196, 41.895446106791496, 45.53076423704624, 46.06680527329445, 46.10130362212658, 39.2593489587307, 19.336983785033226, 4.009310211986303, 2.1070042764768004, 3.571517653763294, 5.853299964219332, 4.505297122523189, 7.206770712509751, 3.4024811116978526, 9.17813865467906, 6.625314513221383, 3.840741994790733, 1.3177417404949665, 1.3075239700265229, 1.615864837076515, 0.08457324933260679, 7.8152296878397465, 32.51617759466171, 26.11822720617056, 32.04120308160782, 17.911556772887707, 0.42972820345312357, 0.1279081279062666, 0.05807558642118238, 0.08787877508439124, 0.010619525619404158, 0.10285229465807788, 0.037122809371794574, 0.03848509935778566, 0.06696769560221583, 0.02044842462055385, 0.05887409650313202, 0.034548915064078756, 0.06272000595345162, 0.0656375072139781, 0.07408190096612088, 0.03396397652977612, 0.05140224646311253, 0.028554449127113912, 0.029009085083089303, 0.02254383776744362, 0.04621651925845072, 0.018644007577677257, 0.1149385777534917, 0.022698718421452213, 0.02734498219069792, 0.020523492858046666, 0.05744245652749669, 0.021372699047788046, 0.07202126857009716, 0.07214586774352938, 0.018363468334428035, 0.03369400175870396, 0.018896907386078965, 0.030434914042416494, 0.04884352536464576, 0.02850178261724068, 0.04199982540740166, 0.02154927082301583, 0.03640741982962936, 0.06004651542752981, 0.05511138180736452, 0.043054454363300465, 0.04452559514902532, 0.09394304928719066, 0.17504125891719013, 0.0377180414943723, 0.03019037081685383, 0.00589892091738875, 0.02590705807961058, 0.7380526838824153, 20.7442344725132, 39.12647008895874, 33.689239248633385, 28.166868276894093, 27.307240404188633, 6.647331956773996, 0.10078806284582242, 0.3705582831753418, 0.03341416384500917, 1.135350577533245, 2.1872208220884204, 0.7370021590031683, 0.7940034940838814, 6.648539341986179, 10.527264811098576, 6.713033281266689, 1.434932320844382, 2.717017368413508, 14.783513322472572, 33.67025926709175, 49.671098068356514, 49.67588201165199, 49.51089486479759, 48.98983262479305, 49.85042184591293, 51.02310352027416, 53.37778016924858, 52.6236954331398, 53.29955376684666, 50.469260439276695, 47.41528071463108, 47.10134916007519, 50.877062156796455, 52.98006311058998, 50.65033592283726, 53.96251179277897, 48.194459304213524, 40.612296760082245, 38.410189524292946, 39.138754829764366, 40.641623586416245, 48.907426446676254, 52.072158828377724, 53.2521703094244, 49.50952313840389, 51.307468861341476, 51.94424629211426, 47.24299035966396, 38.91878083348274, 38.9691661298275, 38.44526544213295, 38.59701409935951, 38.27775903046131, 39.41143959760666, 37.94753015041351, 39.09982971847057, 39.91975352168083, 41.11780643463135, 47.895734533667564, 51.194079145789146, 52.64767214655876, 49.864142909646034, 46.62608966231346, 52.018608301877975, 53.74214641749859, 50.724036768078804, 49.94351305067539, 50.54767683148384, 48.04376319050789, 48.97768087685108, 48.492268323898315, 44.298444762825966, 38.540856912732124, 35.81457160413265, 36.7005130648613, 36.17558643221855, 36.94912992417812, 36.59497372806072, 43.70302051305771, 50.03730721771717, 51.91799350082874, 50.00392600893974, 48.631743639707565, 48.730048164725304, 40.46442769467831, 36.89553000032902, 38.143740221858025, 36.18749499320984, 37.16258727014065, 37.596987560391426, 40.305330231785774, 40.161534547805786, 40.57191252708435, 41.66785731911659, 43.31353381276131, 41.6028618067503, 44.8118732124567, 42.925016060471535, 42.088308557868004, 42.31916896998882, 41.852903589606285, 44.32709142565727, 46.40049956738949, 48.57035793364048, 48.22056010365486, 41.66175864636898, 20.635645799338818, 5.92881616204977, 3.2137089036405087, 3.5144796269014478, 6.768351187929511, 4.841627050191164, 7.761589391157031, 7.590097468346357, 6.927711311727762, 8.31198463216424, 6.587811000645161, 2.487677112221718, 1.68452002806589, 1.098668770864606, 0.14994112687418237, 7.48309426009655, 36.77122727036476, 28.23593147099018, 37.76267386972904, 22.770430147647858, 0.8295286190696061, 0.10893898172071204, 0.10925190086709335, 0.037320699339034036, 0.055576140657649375, 0.10893485537962988, 0.03315728055895306, 0.0652232403808739, 0.060941385963815264, 0.010467627471371088, 0.03379338275408372, 0.01345422824670095, 0.06224238568393048, 0.01250452320164186, 0.02527791351894848, 0.09945607846020721, 0.043581546196946874, 0.021461545256897807, 0.03664881820441224, 0.031979963459889404, 0.015401059717987664, 0.00974888620476122, 0.23317135608522221, 0.169740914425347, 0.08544896874809638, 0.13516759383492172, 0.25251726096030325, 0.20100297988392413, 0.2416348972474225, 0.16910323145566508, 0.22735216130968183, 0.07197240556706674, 0.11712594670825638, 0.18196758959675208, 0.16547592531424016, 0.15017444326076657, 0.203963243693579, 0.07959577618748881, 0.1381779822986573, 0.1635328639531508, 0.15416088950587437, 0.11949212872423232, 0.16062091395724565, 0.26076638081576675, 0.28489971708040684, 0.10710338334320113, 0.2443467197008431, 0.17184433905640617, 0.145676122920122, 1.0253159631974995, 26.422414183616638, 45.73176585137844, 42.86762394011021, 37.22949028015137, 31.340556778013706, 7.6363856345415115, 0.21481181000126526, 0.4221015080111101, 0.21364398126024753, 1.215428786817938, 2.274768599309027, 0.7018158095888793, 2.385246721096337, 11.620174515992403, 27.216497473418713, 6.634998293593526, 0.7588046172168106, 2.7611023653298616, 14.782953802496195, 33.96757811307907, 49.79237996041775, 49.64354194700718, 49.42648999392986, 51.197662353515625, 50.93064688146114, 52.53989852964878, 55.57391032576561, 55.84181874990463, 53.97203028202057, 53.15353520214558, 48.04568208754063, 53.471870720386505, 53.348989114165306, 54.18689735233784, 53.04294973611832, 54.663855358958244, 52.18548774719238, 44.55862820148468, 40.22235028445721, 40.83043925464153, 41.78768388926983, 51.404496654868126, 55.867854952812195, 54.95377600193024, 52.09149219095707, 52.783541455864906, 56.20051950216293, 49.905758276581764, 41.96651749312878, 40.77497363090515, 41.0366427898407, 41.02589696645737, 39.335458874702454, 41.66416771709919, 41.78728491067886, 40.805702582001686, 40.98251849412918, 45.21230712532997, 50.030672773718834, 54.65875223278999, 55.062507167458534, 52.23523087799549, 47.11247116327286, 53.080301731824875, 55.8248146623373, 52.39690080285072, 52.83513508737087, 53.23049247264862, 48.884312286973, 51.843262910842896, 51.330225840210915, 46.546575129032135, 40.794211998581886, 37.392759919166565, 39.37581650912762, 37.68832325935364, 37.62760251760483, 37.88885369896889, 44.98919069766998, 53.8989944010973, 52.345991134643555, 52.56253391504288, 52.84874215722084, 50.07071502506733, 43.67230296134949, 38.62757585942745, 39.38949957489967, 37.7534631639719, 39.331165105104446, 39.85303670167923, 43.126876428723335, 40.79289726912975, 43.003360256552696, 43.77321794629097, 47.1933688223362, 43.60848158597946, 46.37921690940857, 43.451242223381996, 45.448076874017715, 43.893523290753365, 44.58537496626377, 45.70975363254547, 48.20153832435608, 48.98832410573959, 48.68041142821312, 42.35271356999874, 21.689114570617676, 5.248026167973876, 4.317638017237186, 6.642382247373462, 11.46269766613841, 9.545831624418497, 13.550137504935265, 10.864161383360624, 20.388624854385853, 16.316611357033253, 12.097873482853174, 6.119531253352761, 2.7780508808791637, 4.0236325934529305, 0.42073337361216545, 9.624027628451586, 43.303722739219666, 35.22939160466194, 44.65120643377304, 26.1068145185709, 0.997201984282583, 0.17446048383135349, 0.20836935960687697, 0.1859465698362328, 0.13011006521992385, 0.1403748433222063, 0.11145436510560103, 0.15442178410012275, 0.23113099916372448, 0.10428773442981765, 0.12152366893133149, 0.10953829565551132, 0.12040172718116082, 0.1413528752163984, 0.112081591214519, 0.20926127268467098, 0.18888762686401606, 0.11008024899638258, 0.15687480481574312, 0.12958581210114062, 0.14420033257920295, 0.11209529126062989], [0.007648520149814431, 0.0384450975980144, 0.051331913127796724, 0.056038899419945665, 0.020809195593756158, 0.024685714924999047, 0.025338268678751774, 0.12588751211296767, 0.08501418895320967, 0.0908997911028564, 0.024866750718501862, 0.06710076268063858, 0.0020962958387826802, 0.02931598726718221, 0.06287778654950671, 0.03890864674758632, 0.03599865231080912, 0.0063982661686168285, 0.022818170800746884, 0.015434734668815508, 0.07522724263253622, 0.04940744627674576, 0.055829261254984885, 0.06481383461505175, 0.019765188626479357, 0.06204252531460952, 0.01578416191478027, 0.01360406786261592, 6.022172402590513, 27.392726317048073, 29.59236938506365, 35.28736129403114, 26.2930254265666, 10.05913183093071, 0.6521769356913865, 0.0757509539835155, 0.12929656746564433, 0.29883995186537504, 1.939971533138305, 0.2333421984803863, 0.4152099246857688, 6.670190105214715, 5.763560179620981, 8.173091635107994, 1.7895146878436208, 0.720797631656751, 2.559909336268902, 12.888319417834282, 28.294676318764687, 43.1712656468153, 49.18687865138054, 46.930270940065384, 48.2506088912487, 48.94250996410847, 52.98521563410759, 50.678709000349045, 50.123285204172134, 49.75270628929138, 49.03388366103172, 49.02498833835125, 51.447362154722214, 52.48511306941509, 52.72564396262169, 51.39685906469822, 51.23922452330589, 42.715977877378464, 37.55192577838898, 37.610062658786774, 37.228768318891525, 45.92163786292076, 50.665041133761406, 50.26326209306717, 49.18758541345596, 52.03193798661232, 51.026751324534416, 44.82744477689266, 39.9457935243845, 35.921832248568535, 37.558184042572975, 35.88003069162369, 36.6388613730669, 35.92926844954491, 38.47306475043297, 37.34109029173851, 42.72446282207966, 43.92253093421459, 47.71962158381939, 46.316364482045174, 52.210931181907654, 46.38376906514168, 45.847629234194756, 51.43452264368534, 48.87729786336422, 47.815300449728966, 45.78044883906841, 45.124311447143555, 42.94904977083206, 44.20230232179165, 39.39384274184704, 36.018347069621086, 34.95584048330784, 34.90929678082466, 36.559825614094734, 34.596888944506645, 34.52569976449013, 35.99041476845741, 41.89436696469784, 49.04943622648716, 51.2505479156971, 49.07987259328365, 46.25499777495861, 46.966106817126274, 44.62436847388744, 35.244837775826454, 35.72008967399597, 34.16373498737812, 36.78929150104523, 39.0836463868618, 42.04806111752987, 41.384191140532494, 40.82675725221634, 43.42653214931488, 42.323569133877754, 43.500035405159, 44.005165100097656, 44.67952251434326, 42.60801047086716, 42.9282458871603, 42.03610695898533, 44.00180608034134, 46.2945194542408, 45.19075088202953, 43.44564892351627, 30.414985343813896, 9.808461181819439, 2.3369942978024483, 1.4194248779676855, 4.104808587580919, 5.257598329335451, 3.6884796526283026, 7.339073913171887, 5.363891925662756, 4.795945901423693, 6.183584416285157, 5.300021152943373, 2.3795983241871, 1.3015004619956017, 0.836536274291575, 0.3395083383657038, 15.609004776924849, 33.20091985166073, 20.65206091850996, 36.856699883937836, 6.723018670454621, 0.01791373982996447, 0.04816299449885264, 0.02433788700727746, 0.07861383317504078, 0.05233855110418517, 0.032244891626760364, 0.043252630057395436, 0.045403975163935684, 0.08976716984761879, 0.06716049072565511, 0.06897049985127524, 0.14531126827932894, 0.02888817438361002, 0.024681067225174047, 0.04550626908894628, 0.010811065585585311, 0.05888949235668406, 0.012883760664408328, 0.010471893892827211, 0.01296439129873761, 0.06978158562560566, 0.06434313487261534, 0.040014320620684884, 0.056787874855217524, 0.026969602040480822, 0.04296803868783172, 0.05379179499868769, 0.018158602179028094, 0.027492311492096633, 0.08378122933208942, 0.04943535845086444, 0.05856199000845663, 0.01454975603337516, 0.0447116849682061, 0.08708626526640728, 0.026246199158777017, 0.05497883423231542, 0.055567887975485064, 0.07033616289845668, 0.028214944395585917, 0.047891220019664615, 0.030165833559294697, 0.02305055950273527, 0.05490084193297662, 0.02013057946896879, 0.033866428639157675, 0.01698204763670219, 0.02422610286885174, 0.01142391629400663, 0.025365149267599918, 9.629292245954275, 34.794478341937065, 34.26728703081608, 40.7329972833395, 30.536801107227802, 9.92109663784504, 0.40694064809940755, 0.10668766190065071, 0.09827581132412888, 1.546850565355271, 3.2256898982450366, 1.225161252077669, 1.504363026469946, 14.775479603558779, 10.861990749835968, 6.988361282274127, 4.224956715479493, 1.447897581383586, 4.036883907392621, 15.448814872652292, 31.620846837759018, 47.148664221167564, 50.158676505088806, 47.54424959421158, 49.5445154607296, 49.24058496952057, 52.839820235967636, 52.42892548441887, 51.745144575834274, 50.99708631634712, 51.31482906639576, 50.62197044491768, 55.2863759547472, 53.64564299583435, 53.52539844810963, 52.70165964961052, 52.27839656174183, 44.279441982507706, 39.00395326316357, 40.127473175525665, 39.92749370634556, 49.0795686095953, 51.97251297533512, 52.120378240942955, 49.11728538572788, 52.74701401591301, 52.99037955701351, 46.74396313726902, 41.63748934864998, 37.82783657312393, 39.140563532710075, 37.3271070420742, 38.66915322840214, 36.94409139454365, 38.45188468694687, 38.46616432070732, 44.94481287896633, 45.064628049731255, 50.779870972037315, 47.9425024241209, 54.50008034706116, 49.00648333132267, 47.512407302856445, 52.5613521784544, 50.35734124481678, 49.301396906375885, 49.21267926692963, 47.07709886133671, 45.39994105696678, 45.55237367749214, 43.01592618227005, 38.65952454507351, 37.86287069320679, 35.605305433273315, 37.71390728652477, 36.97451636195183, 35.506047159433365, 36.08835831284523, 43.06015580892563, 50.58833085000515, 52.298923060297966, 50.0879281014204, 47.6194703578949, 48.55032920837402, 45.34517079591751, 38.415231853723526, 36.99135325849056, 35.187460854649544, 37.76638627052307, 40.185484662652016, 43.51669371128082, 43.50127033889294, 42.68075376749039, 43.63291047513485, 44.28133808076382, 44.701907113194466, 46.059144884347916, 47.176174744963646, 45.181927755475044, 44.08462643623352, 43.61646495759487, 44.44072812795639, 49.00375507771969, 47.54920452833176, 46.33898086845875, 33.332373797893524, 11.389028169214725, 3.109028795734048, 3.2057547429576516, 4.8567459639161825, 4.917631521821022, 6.027086488902569, 8.205815479159355, 8.891781270503998, 7.545278398320079, 9.642156455665827, 5.0910955388098955, 0.605369919212535, 1.1132059595547616, 0.44207602681126446, 0.3598784515634179, 18.12542449682951, 38.66691894829273, 24.88178875297308, 38.46368305385113, 9.525792449712753, 0.08177533774869516, 0.05616856746200938, 0.013716295434278436, 0.04195781242742669, 0.026120583243027795, 0.04729638865683228, 0.06044235473382287, 0.07189709242084064, 0.08055204089032486, 0.026397734582133126, 0.07742845264147036, 0.028334452435956337, 0.03309168583655264, 0.04115128343983088, 0.048132726005860604, 0.024338618022738956, 0.032074075206764974, 0.02050648097792873, 0.011900786994374357, 0.040382863735430874, 0.07776707236189395, 0.05545484404137824, 0.12691590614849702, 0.1524029643042013, 0.13429139944491908, 0.1399767107795924, 0.10099192339112051, 0.10565708595095202, 0.1197627602959983, 0.19808470678981394, 0.19945278181694448, 0.17733330780174583, 0.17561986693181098, 0.22871760913403705, 0.2381255925865844, 0.04828959376027342, 0.19495398650178686, 0.2276172416168265, 0.11564195563551039, 0.08631263568531722, 0.10606459924019873, 0.12458106502890587, 0.20359225891297683, 0.09480707245529629, 0.1366536703426391, 0.17930186935700476, 0.14422975131310523, 0.14973443874623626, 0.11741309848730452, 0.08828255537082441, 11.724025793373585, 41.32532849907875, 40.96070006489754, 47.96797625720501, 33.35098899900913, 11.721578724682331, 0.9953526710160077, 0.40477532835211605, 0.32571472227573395, 2.6257821265608072, 8.215026184916496, 0.5677408946212381, 2.110180906020105, 16.774444989860058, 17.010361030697823, 17.377981804311275, 4.650227520614862, 1.4130705501884222, 3.41986280400306, 14.455924350768328, 31.58104207366705, 47.61263832449913, 50.31470373272896, 48.8849962502718, 50.82351163029671, 50.90961121022701, 54.2205635458231, 54.01318207383156, 53.980602622032166, 53.818195536732674, 52.602344378829, 52.91959695518017, 57.53267101943493, 56.859977915883064, 56.28589332103729, 54.892359897494316, 53.554098308086395, 46.297688484191895, 41.92299082875252, 41.474257707595825, 40.84463909268379, 50.96467025578022, 53.04369829595089, 53.98165136575699, 51.62592977285385, 53.96611399948597, 55.39075255393982, 48.71706806123257, 44.955277517437935, 39.22458082437515, 42.16914542019367, 40.60192711651325, 40.2903438359499, 38.92292641103268, 42.0232180505991, 41.290294378995895, 49.515777602791786, 48.338574171066284, 52.81207412481308, 49.40420798957348, 56.24648943543434, 50.78421413898468, 50.24447590112686, 53.784377351403236, 52.00226917862892, 53.29791605472565, 50.02134047448635, 49.04891565442085, 48.04687142372131, 47.32889235019684, 44.780635088682175, 40.068329349160194, 38.10626283288002, 36.52098789811134, 40.743849501013756, 39.80161406099796, 36.76765166223049, 38.99752780795097, 45.461615547537804, 53.323655873537064, 55.158653408288956, 51.34692594408989, 49.64300997555256, 50.44123314321041, 48.24120819568634, 40.155059695243835, 38.755279406905174, 37.079713717103004, 40.81177085638046, 41.8175882846117, 45.54981641471386, 45.62494598329067, 43.90468329191208, 47.246189787983894, 46.89125843346119, 47.52939999103546, 48.252197206020355, 48.51499490439892, 47.42853820323944, 46.452617570757866, 46.362011432647705, 47.396152541041374, 50.16147695481777, 48.79208363592625, 47.168233171105385, 33.8966891169548, 12.055498156696558, 3.8569467002525926, 4.255985850468278, 8.988886009901762, 9.48226198554039, 7.384662441909313, 14.568100031465292, 13.213714007288218, 12.621159553527832, 17.12690457701683, 12.755339853465557, 6.363830594345927, 2.8179268911480904, 1.8447263189591467, 0.5854138056747615, 21.626138649880886, 43.80223698914051, 29.108366556465626, 47.984246984124184, 11.086987126618624, 0.30987165053375065, 0.1710209113662131, 0.11734760395484045, 0.2547479490749538, 0.1297709482605569, 0.15359624871052802, 0.16827837884193286, 0.1499736774712801, 0.19529083248926327, 0.1521821308415383, 0.1637874502921477, 0.17303879605606198, 0.12492331385146827, 0.15033094736281782, 0.096742972091306, 0.1445849283481948, 0.13557671016314998, 0.12289615231566131, 0.10350729935453273, 0.16380621178541332, 0.1925654138904065, 0.18191718292655423], [0.07519141174270771, 0.09500977525021881, 0.051142977172276005, 0.06178782394272275, 0.049935361894313246, 0.07257503690198064, 0.035419866180745885, 0.06241718743694946, 0.04336938844062388, 0.012031089572701603, 0.04641051295038778, 0.026931231150228996, 0.04262797549017705, 0.04065159540914465, 0.1159043716324959, 0.024863310864020605, 0.016319281930918805, 0.0067807644427375635, 0.04148938365688082, 0.018750169947452378, 0.05226048830081709, 0.02659314948687097, 0.03877247749187518, 0.029505841630452778, 0.036977081254008226, 0.04164272620982956, 0.012342593072389718, 0.10229523861198686, 0.3313290694495663, 20.612514540553093, 29.83358234167099, 23.271670751273632, 36.39745272696018, 16.30360085517168, 1.620789966545999, 0.17212222883244976, 0.08186070699593984, 1.518055354245007, 2.189834131859243, 2.415982559323311, 1.0555004747584462, 12.802429776638746, 8.131561763584614, 6.996442498639226, 4.903158573433757, 0.640853246441111, 1.145083992742002, 3.8377574924379587, 17.054317072033882, 35.69205477833748, 46.89047947525978, 48.866506442427635, 49.85979974269867, 48.81525479257107, 50.74266716837883, 54.012562707066536, 53.86499382555485, 51.481628715991974, 52.75372065603733, 52.70592302083969, 52.61728137731552, 51.10847353935242, 50.75088992714882, 51.93066582083702, 50.921352580189705, 44.05799366533756, 37.05864004790783, 37.71662034094334, 38.11157874763012, 44.39963713288307, 51.67031139135361, 52.0220585167408, 51.882784590125084, 50.4916450381279, 50.70083901286125, 49.161887392401695, 40.99893361330032, 35.89070811867714, 37.326901853084564, 36.05267062783241, 37.650906667113304, 35.2935815602541, 40.20098403096199, 42.54464887082577, 48.32154728472233, 49.068074226379395, 50.5301483720541, 49.26005892455578, 52.91658751666546, 43.119029849767685, 44.82184387743473, 52.304846942424774, 48.588688150048256, 47.36432544887066, 42.79804967343807, 40.869269371032715, 40.171053037047386, 38.04530270397663, 36.54354728758335, 35.051253363490105, 35.74974708259106, 36.22111938893795, 36.799364760518074, 34.494913816452026, 34.78907883167267, 35.08934251964092, 43.71314316987991, 46.077418103814125, 50.88653884828091, 44.436426758766174, 47.047536447644234, 47.80242674052715, 44.48874615132809, 39.68311361968517, 33.66073317825794, 35.299376249313354, 35.84950692951679, 42.65133574604988, 46.65635123848915, 44.22406755387783, 46.19585394859314, 45.01792475581169, 42.98277676105499, 45.456238836050034, 45.012696236371994, 43.57066601514816, 44.60699960589409, 44.35205988585949, 44.675399735569954, 45.57261519134045, 44.294637367129326, 46.72292746603489, 39.78484936058521, 20.7656292244792, 4.525263151153922, 1.694777577649802, 2.3242476442828774, 2.0392045145854354, 4.358255937695503, 5.412072390317917, 5.196673823520541, 8.868230134248734, 1.722771862987429, 7.41690656170249, 2.9798775259405375, 0.9692943224217743, 0.9937927953433245, 0.5655052489601076, 6.324247643351555, 41.73807755112648, 35.405519753694534, 28.030926771461964, 25.676234923303127, 0.9090435679536313, 0.09346734004793689, 0.06501298252260312, 0.10471552319359034, 0.016544896679988597, 0.05162628229300026, 0.0336949442862533, 0.056401119436486624, 0.05812239367514849, 0.010339842629036866, 0.06078570935642347, 0.07394557585939765, 0.04522504335909616, 0.06608465118915774, 0.024937559028330725, 0.023833708983147517, 0.031895581269054674, 0.05590074862993788, 0.04872352379607037, 0.0783266665530391, 0.09580241865478456, 0.016982674751488958, 0.02305947640707018, 0.02935919510491658, 0.031784325910848565, 0.026283375191269442, 0.025976721626648214, 0.03164015259244479, 0.05888755164050963, 0.08485456040943973, 0.045831047755200416, 0.0408391732344171, 0.02384973195148632, 0.013171550690458389, 0.03650545753771439, 0.041226195826311596, 0.014462745712080505, 0.021171953667362686, 0.040762001008260995, 0.06352936994517222, 0.01938628327479819, 0.03582247758458834, 0.0039933468269737205, 0.05356213740014937, 0.004175185531494208, 0.01722637749480782, 0.02170375442801742, 0.0403662804455962, 0.03145942850096617, 0.02775352892058436, 0.009102476506086532, 1.3467654143460095, 28.935646824538708, 35.39368338882923, 29.13081955164671, 38.65708887577057, 16.206020191311836, 1.3408925919793546, 0.13105290447128937, 0.17699147458188236, 0.0664866428996902, 4.287746446207166, 3.069492867216468, 6.628171484917402, 13.28852629289031, 8.694383762776852, 12.161092590540648, 5.570638356730342, 2.4446080857887864, 1.876008496619761, 5.9353299625217915, 18.80319982767105, 39.34920273721218, 48.417689725756645, 50.139913111925125, 49.40751001238823, 50.07487580180168, 51.74718126654625, 56.76472082734108, 53.63384082913399, 54.19070094823837, 53.18326860666275, 54.45793300867081, 53.44934172928333, 52.79078006744385, 50.78615963459015, 54.36818182468414, 52.3079551756382, 45.824963450431824, 38.7087395042181, 39.59124594926834, 39.472616314888, 46.268867030739784, 52.207518965005875, 53.79603512585163, 52.37974472343922, 51.62834644317627, 52.329063042998314, 50.36174140870571, 42.877328619360924, 37.0651338994503, 37.22371459007263, 37.76188351213932, 38.422056287527084, 37.539173662662506, 41.32160469889641, 43.40095192193985, 49.47578854858875, 48.763714358210564, 50.67471541464329, 51.95637904107571, 53.968682661652565, 45.564544424414635, 47.07510396838188, 53.68602342903614, 49.355771988630295, 49.13739010691643, 43.84996622800827, 43.536984622478485, 42.601577416062355, 40.43857388198376, 38.224854469299316, 38.6385914683342, 36.65230505168438, 37.19592288136482, 37.71882422268391, 36.2413989007473, 36.260268688201904, 37.24411189556122, 45.28527081012726, 48.71729984879494, 52.57299095392227, 47.29269549250603, 48.812473341822624, 49.49216187000275, 46.78003080189228, 40.16031861305237, 35.92564344406128, 36.62679702043533, 37.893413454294205, 43.29034745693207, 47.62885205447674, 46.45209699869156, 47.76264287531376, 47.180058136582375, 44.549987465143204, 47.81088888645172, 46.193919852375984, 46.68090932071209, 46.353188306093216, 45.97645752131939, 46.97352781891823, 46.76719889044762, 46.5238219499588, 47.76198171079159, 42.10594721138477, 23.270034939050674, 7.224279697984457, 3.1820929376408458, 4.053428694605827, 4.148261630907655, 5.525013729929924, 6.052732737734914, 8.907430730760098, 10.105653684586287, 7.66838894225657, 6.737292129546404, 1.6900735488161445, 0.6062340165954083, 0.31363721878733486, 0.12133160111261532, 4.407243384048343, 37.63515271246433, 31.9528616219759, 29.167840965092182, 32.12248831987381, 2.194542079232633, 0.1092921030067373, 0.08918363397242501, 0.04688441506004892, 0.059842870105057955, 0.06877744497614913, 0.033457238096161745, 0.04233441526594106, 0.01368621711662854, 0.03475370700471103, 0.08310931851156056, 0.026188322772213724, 0.04107390341232531, 0.06788964339648373, 0.05473248573252931, 0.012388570976327173, 0.02246615717012901, 0.058215266035404056, 0.06778978742659092, 0.023905315101728775, 0.03858262127323542, 0.009493876841588644, 0.02067330278805457, 0.13866637484170496, 0.1808992531732656, 0.10876641754293814, 0.15759416855871677, 0.10437529301270843, 0.10752001020591706, 0.13666981947608292, 0.19556043989723548, 0.18974326376337558, 0.14006809884449467, 0.12345736438874155, 0.10975445358781144, 0.1750052350689657, 0.19462695170659572, 0.12715903372736648, 0.08819179070997052, 0.14033595478395, 0.09247818336007185, 0.07595566057716496, 0.10519005983951502, 0.12293744541238993, 0.07534975637099706, 0.0734751507116016, 0.16953317244770005, 0.1618630316806957, 0.15252638346282765, 0.07125722753698938, 0.1611110579688102, 1.4971689437516034, 33.89011166989803, 44.253322184085846, 33.63608010113239, 47.35325284302235, 19.127077348530293, 1.8741066986694932, 0.5804171925410628, 0.47098897222895175, 4.175288155674934, 8.074794709682465, 8.885247521102428, 5.57019330561161, 19.672538079321384, 17.69209574908018, 18.690326884388924, 11.224514096975327, 1.792487553320825, 2.533494816161692, 5.425983443856239, 19.616895765066147, 38.92201825976372, 47.921322360634804, 48.48654583096504, 50.50074554979801, 49.98869262635708, 52.3538339138031, 58.10659982264042, 56.59407198429108, 56.36765733361244, 55.96182011067867, 56.78107514977455, 54.83917035162449, 53.70064124464989, 51.90889298915863, 56.431664898991585, 55.11578030884266, 46.92696891725063, 40.805751979351044, 40.53462132811546, 41.23604469001293, 46.62609726190567, 54.01602052152157, 56.18970148265362, 54.645289555191994, 52.74092674255371, 54.63762156665325, 53.50653626024723, 43.871948048472404, 40.33246077597141, 40.68321615457535, 39.558096528053284, 40.77591598033905, 40.159904435276985, 44.92843575775623, 45.85352651774883, 52.05742321908474, 53.36614519357681, 54.426254108548164, 53.16308028995991, 55.106128826737404, 44.961683973670006, 48.66895504295826, 56.87151409685612, 52.64214724302292, 51.751790419220924, 47.00259625911713, 44.75962981581688, 44.26154874265194, 42.3447871953249, 39.6911995857954, 40.039097517728806, 39.008900597691536, 38.324770107865334, 40.74778608977795, 39.57913599908352, 36.85625150799751, 38.090223893523216, 47.65537083148956, 48.94516222178936, 56.497652158141136, 47.71027408540249, 50.67586675286293, 53.33167724311352, 49.82134960591793, 43.41125696897507, 36.61822088062763, 38.094836845993996, 40.61613455414772, 45.72712630033493, 50.179248601198196, 48.983874544501305, 49.749339669942856, 50.11927641928196, 46.155066937208176, 48.7890437990427, 47.18940183520317, 49.015036672353745, 48.419654220342636, 48.75657074153423, 48.65099720656872, 48.789321184158325, 47.53517188131809, 49.78366322815418, 43.53620186448097, 23.997393809258938, 6.515400186181068, 4.019550662487745, 6.240184279158711, 6.079161269590259, 10.887412335723639, 12.420762106776237, 13.987970910966396, 18.585222624242306, 10.338866170495749, 15.431103073060513, 9.607148934155703, 1.8639342882670462, 2.4744875449687243, 0.7265074783936143, 9.115210231393576, 48.04295003414154, 40.77944979071617, 38.80996607244015, 34.476682394742966, 2.6682210993021727, 0.16352649632608518, 0.2225173363694921, 0.1425708582974039, 0.20541047619190067, 0.18631457118317485, 0.16802374797407538, 0.19955102732637897, 0.14552007894963026, 0.14226062572561204, 0.13036358286626637, 0.13456629094434902, 0.13079576514428481, 0.2066071893204935, 0.1624493283452466, 0.12959587562363595, 0.12366307288175449, 0.15266862348653376, 0.21252566861221567, 0.08482801378704607, 0.1923097885446623, 0.13074751070234925, 0.13704303069971502], [0.016517043877684046, 0.015450254832103383, 0.05604197933280375, 0.08875950399669819, 0.054718225364922546, 0.02797935147100361, 0.04318856415920891, 0.03312101551273372, 0.020422918860276695, 0.01714601217827294, 0.008721962549316231, 0.060390537983039394, 0.08363777960767038, 0.025501491072645877, 0.011658855200948892, 0.05966831697151065, 0.04050425312016159, 0.03066381650569383, 0.05767400289187208, 0.054421989698312245, 0.07717324289842509, 0.02232209331850754, 0.05752238954300992, 0.029720719358010683, 0.028667595106526278, 0.036645567597588524, 0.07306148501811549, 0.025177252318826504, 0.008591326004534494, 4.998352965340018, 28.555101044476032, 31.531775817275047, 40.819001868367195, 20.484607703983784, 6.4864319656044245, 0.12582094146637246, 0.24874042690498754, 0.3099664079491049, 2.8453583316877484, 1.850511864759028, 6.936366772279143, 4.365572445094585, 7.588479230180383, 7.720734933391213, 4.091593371704221, 2.2742147790268064, 0.8466661744751036, 2.312642829492688, 7.420811802148819, 25.907173231244087, 39.01799350976944, 50.891801565885544, 50.56737497448921, 51.420163214206696, 49.65469814836979, 48.50707992911339, 51.69248700141907, 52.192152589559555, 53.39384190738201, 54.09532226622105, 52.96565428376198, 53.781573101878166, 51.27695269882679, 51.13644003868103, 50.92364385724068, 43.27234022319317, 39.928975626826286, 40.115477219223976, 37.524320259690285, 44.88338157534599, 49.37778800725937, 51.12269997596741, 51.82686299085617, 51.812811344861984, 53.570065051317215, 51.5331007540226, 42.89139926433563, 38.51528808474541, 36.464796513319016, 36.14393413066864, 36.330466121435165, 36.764653623104095, 43.92101861536503, 47.261077389121056, 49.51197400689125, 49.189808294177055, 51.9361375272274, 47.46101126074791, 48.975488394498825, 42.25531339645386, 44.381949082016945, 51.63126088678837, 48.84417124092579, 45.9107780456543, 39.065753147006035, 37.856232449412346, 36.61055289208889, 36.70174419879913, 35.60675695538521, 33.90610121190548, 34.48094956576824, 35.93305304646492, 34.72722575068474, 35.31269833445549, 34.0167398750782, 36.063237860798836, 40.000499188899994, 46.65311001241207, 50.06017059087753, 48.65019164979458, 47.960391864180565, 46.72815218567848, 46.074081882834435, 42.47713029384613, 35.25151401758194, 33.579219952225685, 35.09659253060818, 44.00709919631481, 46.66406862437725, 48.59021946787834, 45.1736593991518, 46.42251938581467, 48.448859453201294, 45.1298363506794, 47.20024265348911, 46.369352638721466, 45.81798702478409, 46.652391850948334, 44.9558474868536, 48.27863998711109, 46.32940538227558, 43.0717945843935, 33.781627491116524, 15.302748810499907, 3.263298855163157, 1.539590461179614, 2.4303954234346747, 4.309871233999729, 2.8312271274626255, 4.396764971315861, 7.590283183380961, 6.939430832862854, 8.91391508281231, 5.393285248428583, 0.9122114698402584, 0.35279198025818914, 0.096799983875826, 0.2570585219655186, 14.455891102552414, 39.09716606140137, 35.34064203500748, 38.72706212103367, 12.613943740725517, 0.01693682115728734, 0.10166001957259141, 0.034985728343599476, 0.06059480299882125, 0.08494402631185949, 0.03398560642381199, 0.06018987609422766, 0.04490446524869185, 0.009600676530681085, 0.04735995360533707, 0.06620249681873247, 0.06080627426854335, 0.02922003870480694, 0.07494648816646077, 0.07047031351248734, 0.027140526071889326, 0.08194232839741744, 0.03736237093107775, 0.024855154661054257, 0.0535523262078641, 0.14299498085165396, 0.003756151559173304, 0.012097135149815585, 0.04610045849403832, 0.04457828021259047, 0.0678846264781896, 0.058710753510240465, 0.09564430409227498, 0.05353407308575697, 0.011308832381473621, 0.02910018742113607, 0.018364455390837975, 0.07988018202013336, 0.042764014870044775, 0.05768004397395998, 0.05395502666942775, 0.03339743954711594, 0.013940874887339305, 0.03471672949672211, 0.05580173499765806, 0.024423759059573058, 0.08130742106004618, 0.02595140325865941, 0.01788130797649501, 0.016977334998955484, 0.02780752573016798, 0.03295598042313941, 0.07880198245402426, 0.06701695194351487, 0.03606241392844822, 0.028852250725321937, 0.028158758250356186, 10.97583644092083, 34.280525520443916, 32.98609837889671, 44.41215366125107, 24.57209587097168, 5.605086833238602, 0.22401346155675128, 0.15185503667453304, 0.4217298701405525, 1.3918737438507378, 4.670699872076511, 7.4241304490715265, 7.236149786040187, 7.28427610360086, 8.515338320285082, 6.39417814090848, 3.865921343676746, 1.5908818901516497, 3.574014832265675, 9.62051946669817, 27.589681148529053, 40.26331968605518, 51.06404632329941, 50.75925327837467, 51.43769167363644, 50.27719974517822, 50.54011143743992, 53.47789719700813, 53.62037815153599, 55.01385077834129, 53.89858782291412, 52.70715415477753, 54.67789180576801, 53.289640098810196, 53.702491745352745, 52.427755147218704, 44.53860707581043, 41.26270405948162, 41.139457672834396, 38.60684797167778, 47.59020812809467, 51.99137896299362, 53.51005107164383, 52.55113072693348, 52.461079359054565, 55.05029082298279, 53.07881221175194, 45.89522548019886, 39.972433894872665, 38.7161985039711, 38.25394570827484, 38.399580493569374, 38.27896736562252, 45.02511776983738, 48.47994938492775, 51.38815373182297, 51.062723994255066, 52.96598106622696, 49.15893115103245, 50.17439626157284, 42.31798343360424, 47.87444047629833, 53.21905888617039, 50.888586938381195, 47.68403269350529, 41.28376632928848, 39.00563657283783, 39.443935453891754, 38.65817181766033, 36.604306027293205, 36.00210674107075, 36.43925428390503, 37.56503127515316, 36.87973044812679, 37.02530063688755, 35.839809849858284, 36.96179084479809, 41.013992205262184, 48.578071519732475, 51.46096162497997, 49.988175854086876, 49.27959747612476, 47.642371729016304, 49.281356781721115, 43.7359419465065, 37.13650166988373, 35.11591449379921, 37.72707737982273, 46.30151867866516, 49.08355079591274, 48.18822383880615, 46.96799911558628, 48.10776315629482, 48.65534037351608, 45.755085200071335, 49.06848080456257, 48.03272858262062, 47.36733868718147, 46.78700342774391, 46.926018968224525, 49.60127681493759, 47.796407863497734, 44.194812923669815, 36.736774519085884, 16.915480121970177, 4.798278026282787, 3.0847276747226715, 4.8309059254825115, 5.170402508229017, 5.762681951746345, 5.832446683198214, 7.3568422347307205, 9.785929340869188, 5.60537276789546, 4.44641643203795, 0.34757233690470457, 0.4247253859648481, 0.23334363824687898, 0.11504864567541517, 17.705482430756092, 51.5477641671896, 37.90564499795437, 39.8181127756834, 15.748515240848064, 0.12401962289004587, 0.0876295099442359, 0.05551929585635662, 0.08805361023405567, 0.02682205566088669, 0.04779938666615635, 0.10279429581714794, 0.044069612195016816, 0.02413472222542623, 0.050791900503099896, 0.022443560628744308, 0.03985574592661578, 0.028017273361911066, 0.017395616850990336, 0.03282956669863779, 0.047020910860737786, 0.01817543408833444, 0.034311561394133605, 0.044945669287699275, 0.024258505036414135, 0.10983700267388485, 0.058025662146974355, 0.09081415468244813, 0.11617801632382907, 0.11553516800631769, 0.2047961560310796, 0.12262591408216394, 0.211583215277642, 0.13846586138242856, 0.09770671764272265, 0.13536105689126998, 0.1538023876491934, 0.13160525530111045, 0.13346302905119956, 0.12905663112178445, 0.17957907635718584, 0.1297275474644266, 0.09066231126780622, 0.11237116981646977, 0.1558469599694945, 0.13263017608551309, 0.1398044583038427, 0.11003674429957755, 0.21558052656473592, 0.11039186938432977, 0.17793456616345793, 0.1212216741987504, 0.18193385156337172, 0.17639524798141792, 0.11898231037775986, 0.17853996570920572, 0.11071480752434582, 12.935540433973074, 43.17683234810829, 39.94727924466133, 50.09595327079296, 28.77432268112898, 7.703552255406976, 0.4236089583719149, 0.43460969463922083, 0.7769446657039225, 6.294336123391986, 11.350830718874931, 15.974838696420193, 14.27083058282733, 18.28983787447214, 16.627172492444515, 10.858111158013344, 6.99310390278697, 2.080754335038364, 3.9532534824684262, 9.162174761295319, 28.075418584048748, 41.1148501932621, 51.69743433594704, 50.7994095236063, 53.394814655184746, 51.38351798057556, 52.15716406702995, 54.00109872221947, 53.96505765616894, 55.88476404547691, 56.83970980346203, 55.15279032289982, 56.97462536394596, 54.573705196380615, 56.81192189455032, 55.52319064736366, 45.312040373682976, 45.26998043060303, 43.80653455853462, 40.2217423170805, 48.9026615023613, 53.021587282419205, 56.01262718439102, 54.217098131775856, 54.030604138970375, 58.83848614990711, 56.098244190216064, 47.083372324705124, 42.332274466753006, 40.018628016114235, 40.096045061945915, 41.11311748623848, 39.86977480351925, 48.6544132232666, 50.349601060152054, 54.059228003025055, 54.23658728599548, 54.75197643041611, 49.43210989236832, 49.75199192762375, 43.64862263202667, 47.90994957089424, 54.81848046183586, 54.88995462656021, 49.4741166383028, 42.860487923026085, 40.58609336614609, 41.16849571466446, 39.85221214592457, 38.35529386997223, 36.75645746290684, 37.77916498482227, 39.18563291430473, 39.03361067175865, 39.96373996138573, 36.81872472167015, 38.658244013786316, 43.42359110713005, 50.35218112170696, 54.02280695736408, 50.0404192507267, 49.196324944496155, 51.37236177921295, 50.782143250107765, 45.90673506259918, 39.97712664306164, 37.50119470059872, 40.447001829743385, 47.65941381454468, 49.653998985886574, 49.473208487033844, 48.661138862371445, 49.782713279128075, 51.751155853271484, 47.4612620472908, 50.28000019490719, 50.697814375162125, 49.25115220248699, 50.23572497069836, 48.84151518344879, 51.049029529094696, 49.24717381596565, 45.13948403298855, 37.460400089621544, 17.47568216174841, 4.293595757335424, 4.131987104192376, 7.038483917713165, 10.150480829179287, 9.049291368573904, 12.661753725260496, 16.32799554616213, 15.77608086168766, 14.746127128601074, 13.079568855464458, 3.1464218767359853, 1.0938212997280061, 0.36166165431495756, 0.6457730918191373, 19.93148848414421, 51.08095161616802, 42.529837265610695, 48.840052261948586, 19.196598418056965, 0.31063781410921365, 0.22465115936938673, 0.23293150879908353, 0.16220948105910793, 0.2761235536308959, 0.1308443906600587, 0.1922896911855787, 0.15004495333414525, 0.16906971606658772, 0.10467244894243777, 0.13354215683648363, 0.20848535728873685, 0.14532821893226355, 0.09585175663232803, 0.1324513481813483, 0.1261194035760127, 0.16052560735261068, 0.0780443981057033, 0.08495896574459039, 0.07146627569454722, 0.3262224997160956, 0.10008749028202146, 0.17758899251930416], [0.03690395002195146, 0.0196932949256734, 0.027725843101507053, 0.016108756899484433, 0.0017200615229739924, 0.05573340175033081, 0.039061443821992725, 0.05931827188760508, 0.09532443102216348, 0.044974564807489514, 0.03182345564709976, 0.03189002629369497, 0.03158075109240599, 0.006753016932634637, 0.03144513844745234, 0.03249497684009839, 0.03496261044347193, 0.056443351350026205, 0.055778617097530514, 0.03207113259122707, 0.01545461309433449, 0.05465293121233117, 0.052432046868489124, 0.05543686180317309, 0.02558189349656459, 0.10159064360777847, 0.06713659357046708, 0.004073958443768788, 0.05616442627797369, 1.7525647580623627, 29.707856588065624, 29.771791957318783, 27.856081053614616, 29.567311629652977, 14.502096623182297, 1.9399641710333526, 0.18517248012358323, 0.34543887013569474, 1.868130925577134, 1.479955273680389, 5.607310188934207, 6.71978646889329, 4.661644957959652, 7.914469437673688, 5.508666057139635, 2.9646327439695597, 1.403834077063948, 1.1990583152510226, 6.331851985305548, 15.312465839087963, 28.016280457377434, 46.82666949927807, 50.78969344496727, 52.29744113981724, 52.581312507390976, 51.657969653606415, 52.95700214803219, 53.70820663869381, 53.467899933457375, 53.26532520353794, 53.98904196918011, 52.06896699965, 52.5582667440176, 48.81257213652134, 46.7641818523407, 39.16352190077305, 39.721043184399605, 40.216654390096664, 38.58634427189827, 43.48040945827961, 50.95879577100277, 52.81278848648071, 53.901821449398994, 48.5202956199646, 53.02496150135994, 49.539461731910706, 47.07934074103832, 38.571152687072754, 36.80337354540825, 37.050455287098885, 37.3722980171442, 38.47565621137619, 46.670125499367714, 49.1309380531311, 52.054022401571274, 49.630349054932594, 51.10633045434952, 47.249628603458405, 48.10345038771629, 44.47327718138695, 42.91548237204552, 52.0343242585659, 49.75841738283634, 47.21184343099594, 42.196108773350716, 37.958747148513794, 36.0915919393301, 35.46372503042221, 36.432228460907936, 34.67905193567276, 35.601737424731255, 34.8381531983614, 34.629259407520294, 35.10288879275322, 35.211429968476295, 35.49170292913914, 41.56303994357586, 45.15941396355629, 51.518786922097206, 50.40531367063522, 48.25054049491882, 48.28236758708954, 45.92670299112797, 44.139947667717934, 40.5383375287056, 33.22423540055752, 35.434231013059616, 44.237062856554985, 48.52308847010136, 47.25658603012562, 48.19337256252766, 45.96588648855686, 47.49218858778477, 46.04091726243496, 45.89730016887188, 45.94951696693897, 45.61011917889118, 45.56085862219334, 46.8453036993742, 46.58675417304039, 44.26680386066437, 40.41712023317814, 26.21915739029646, 10.16005726531148, 2.5287339091300964, 1.9869349943473935, 3.9517397386953235, 2.632106887176633, 4.437975184991956, 3.120218957774341, 5.006620371714234, 9.752390440553427, 4.195968070998788, 2.078004707582295, 0.4182072513503954, 0.16721575695555657, 0.11017502867616713, 4.154734583571553, 23.17971758544445, 22.807936035096645, 28.538982309401035, 29.074880853295326, 4.161418899893761, 0.0561304730217671, 0.07959010617923923, 0.018164825087296776, 0.025647044785728212, 0.07268651490448974, 0.0319341952126706, 0.07797228361596353, 0.12570492894155905, 0.03346405843331013, 0.0450222403742373, 0.04669456626288593, 0.04827871387533378, 0.11132212181109935, 0.008003376206033863, 0.03515622564009391, 0.01319496823271038, 0.029249179133330472, 0.023050811832945328, 0.014430336123041343, 0.04694598734204192, 0.021592846023850143, 0.05234327858488541, 0.0464091585308779, 0.02555780709371902, 0.02444098801788641, 0.01964097908057738, 0.05030195687140804, 0.051232339174021035, 0.022431838406191673, 0.006749044123353087, 0.060022740726708435, 0.05948627927864436, 0.01020555193463224, 0.03446452545176726, 0.04115432624530513, 0.015136683523451211, 0.03735995895112865, 0.022689734723826405, 0.016684268302924465, 0.03397684165975079, 0.007032475423329743, 0.06658341153524816, 0.04062240303028375, 0.011825642686744686, 0.04310060481657274, 0.0288018421997549, 0.03407152486033738, 0.056040769632090814, 0.020535309704428073, 0.03014492911461275, 0.10331961020710878, 0.02945406569779152, 3.693625289015472, 33.983085080981255, 35.0212349742651, 35.894511714577675, 36.118521094322205, 15.669749267399311, 1.7961144587025046, 0.15314337535528466, 0.22785665845731273, 1.0206986172124743, 1.3570451689884067, 8.435606248676777, 8.414392936974764, 7.674313299357891, 10.614939406514168, 6.250273212790489, 6.282035233452916, 3.501491923816502, 1.33102499647066, 7.6101223938167095, 18.051303774118423, 31.72008991241455, 48.21899078786373, 52.64252722263336, 51.751224249601364, 53.81904289126396, 52.411359027028084, 53.94459195435047, 54.2569237947464, 54.269903898239136, 54.739893078804016, 55.812750309705734, 54.69421572983265, 53.721433728933334, 50.99724970757961, 49.97772641479969, 41.4470511674881, 40.42865641415119, 41.40146881341934, 40.969523191452026, 45.717782601714134, 53.901221081614494, 54.203274473547935, 55.633589923381805, 48.15686792135239, 54.04945872724056, 51.60250782966614, 48.3178348839283, 41.66835129261017, 39.53038081526756, 38.853937312960625, 38.899694457650185, 40.1878747344017, 48.596584126353264, 50.56139409542084, 52.72722847759724, 49.646239802241325, 53.155290707945824, 48.309315741062164, 47.722680419683456, 45.897357165813446, 44.29310604929924, 53.48801985383034, 51.06307737529278, 48.589657098054886, 43.41278828680515, 38.49000804126263, 38.20986047387123, 37.992903515696526, 37.56092369556427, 36.21314361691475, 37.608348950743675, 36.94368861615658, 35.87313786149025, 36.62640564143658, 38.44218000769615, 36.586838364601135, 42.7611118555069, 47.4145245552063, 52.052806466817856, 49.752444103360176, 47.912233248353004, 49.4238605350256, 48.808768540620804, 47.22882091999054, 41.1355172842741, 34.45068798959255, 38.04550029337406, 46.76558397710323, 50.19383981823921, 48.847838044166565, 48.32836411893368, 47.8718414157629, 49.30197827517986, 47.56264440715313, 46.96067310869694, 48.69554981589317, 47.020208314061165, 48.20244647562504, 48.05870398879051, 47.53992922604084, 45.17049416899681, 43.13744746148586, 29.789141826331615, 12.504635006189346, 3.094569146633148, 2.222328088246286, 3.8996568834409118, 4.396742172539234, 5.641080876812339, 5.13160421513021, 5.105268778279424, 7.845278950408101, 4.8977799620479345, 1.3731090445071459, 0.447793205967173, 0.344080621143803, 0.07142698639654554, 3.7818724662065506, 27.66380187124014, 29.784357883036137, 33.12504552304745, 37.11052246391773, 6.730785453692079, 0.07970032253069803, 0.06262140421313234, 0.03022325166966766, 0.048271229316014796, 0.02885592621169053, 0.013603549286926864, 0.0231138498565997, 0.0376760359358741, 0.039636953370063566, 0.05651662730087992, 0.04918722879665438, 0.04874745063716546, 0.006419740211640601, 0.0765356860938482, 0.04508198697294574, 0.10980475635733455, 0.034663888582144864, 0.04114642237254884, 0.05368573467421811, 0.010466129260748858, 0.03370143807842396, 0.027361298307368997, 0.03192826174199581, 0.1367101477808319, 0.20023908728035167, 0.09725307245389558, 0.1003848465916235, 0.13933003298006952, 0.14007733116159216, 0.09740466353832744, 0.1759423894691281, 0.12113656470319256, 0.15531458775512874, 0.10940344000118785, 0.09986993711208925, 0.06414567906176671, 0.11916947260033339, 0.09841710882028565, 0.08596782645327039, 0.11939084040932357, 0.10211227694526315, 0.1596978009911254, 0.19696016010129824, 0.1668465236434713, 0.1261793394223787, 0.17470666905865073, 0.16315837623551488, 0.11034405280952342, 0.19842052861349657, 0.11210690587176941, 0.16086229006759822, 0.19509897247189656, 5.426013842225075, 42.71148271858692, 41.4303282648325, 36.39974020421505, 40.19617348909378, 18.081115074455738, 2.8095635399222374, 0.34031300456263125, 0.822935082251206, 2.35786990262568, 8.720006737858057, 16.093873009085655, 16.868678033351898, 15.199173018336296, 16.65999513119459, 15.180535018444061, 8.192071616649628, 5.308662364259362, 2.547505139373243, 8.393839839845896, 17.453305162489414, 30.78420203179121, 48.80447097122669, 53.92744727432728, 53.61843645572662, 54.61123198270798, 53.30278739333153, 55.090823248028755, 56.43665783107281, 57.14454084634781, 56.39188103377819, 58.508112877607346, 56.932352632284164, 56.01914383471012, 53.1697603315115, 51.71627752482891, 43.65089111030102, 44.53013353049755, 43.45562718808651, 43.55299696326256, 46.797433868050575, 55.77022299170494, 57.84479767084122, 56.608579605817795, 50.7547315210104, 56.83338314294815, 53.51059064269066, 50.79999469220638, 43.175038844347, 41.89183250069618, 40.148311257362366, 41.66647419333458, 43.13851900398731, 51.760495752096176, 52.70158365368843, 54.47055973112583, 51.84390887618065, 55.05404122173786, 49.059756472706795, 49.239570423960686, 48.369857892394066, 47.159413844347, 53.75609166920185, 53.10158059000969, 50.733779445290565, 46.2266056984663, 41.941982209682465, 40.72340279817581, 40.11260837316513, 40.988043397665024, 38.962987661361694, 39.287326857447624, 38.24474640190601, 38.03494445979595, 38.546663001179695, 39.53920014202595, 39.54940639436245, 44.22567866742611, 50.38492776453495, 55.66086485981941, 51.86823517084122, 49.25095081329346, 50.69639325141907, 50.468033105134964, 48.12747269868851, 44.59037929773331, 36.822140738368034, 39.99470829963684, 49.3644355237484, 52.69945576786995, 50.29039263725281, 49.9122217297554, 48.6490935087204, 51.235443726181984, 48.59752647578716, 49.23953242599964, 49.65673863887787, 48.49781982600689, 49.12969931960106, 50.410109013319016, 47.2466229647398, 47.42122359573841, 44.88873928785324, 29.150031320750713, 11.329299174249172, 4.154204037040472, 4.709340948611498, 8.71786555275321, 7.310045845806599, 9.584583844989538, 7.709270948544145, 12.050133794546127, 16.054617315530777, 11.875333674252033, 5.699435295537114, 0.8575360849499702, 0.8461519551929086, 0.18468080728780478, 6.558938249945641, 29.8916869238019, 31.12808547914028, 41.39855057001114, 41.90667450428009, 7.59822903200984, 0.16282722994219512, 0.2571255824295804, 0.0626525298866909, 0.18192886433098465, 0.13890580652514473, 0.21456807386130095, 0.19397455936996266, 0.22229317808523774, 0.11930090695386752, 0.20362390408990905, 0.13636850751936436, 0.12177309734397568, 0.14444279222516343, 0.15621640108292922, 0.08679393329657614, 0.14491944399196655, 0.1189362675359007, 0.12604967138031498, 0.11487489406135865, 0.11188294796738774, 0.10613088044920005, 0.11707018173183315, 0.13030516100116074], [0.06514695502119139, 0.005764838488175883, 0.06904034336912446, 0.01474221997341374, 0.04969810470356606, 0.056569902371848, 0.06409854526282288, 0.023507637124566827, 0.07674810360185802, 0.02294028006872395, 0.019747250917134807, 0.028157299930171575, 0.061261904702405445, 0.023463993275072426, 0.05881643905013334, 0.03331659368996043, 0.04522211558651179, 0.024709177923796233, 0.05532512404897716, 0.07234898614115082, 0.04690700974606443, 0.0421005608222913, 0.0745215047209058, 0.06325393667793833, 0.04865454859100282, 0.008954330842243508, 0.022709143740939908, 0.011934753238165285, 0.06202182310516946, 0.5179594096262008, 18.441134355962276, 30.340387746691704, 27.29855976998806, 28.557204231619835, 26.460157558321953, 8.525555022060871, 0.8276534790638834, 0.28109698207117617, 0.8698363811708987, 1.624103388749063, 5.055492874234915, 4.536895751953125, 4.634294975548983, 6.540722977370024, 4.088434316217899, 4.469664059579372, 2.536532753147185, 1.23896709876135, 3.7117417668923736, 11.379582826048136, 22.73136254400015, 41.05398125946522, 52.09301210939884, 52.4435319006443, 52.939222902059555, 53.78888010978699, 53.708271235227585, 51.42769441008568, 51.543800979852676, 52.10646338760853, 48.95116209983826, 49.75331425666809, 46.125002950429916, 43.54307569563389, 40.269984528422356, 38.04436035454273, 39.06733386218548, 38.88193421065807, 38.76901566982269, 44.61689807474613, 49.99341957271099, 50.55874943733215, 54.2148220539093, 51.38296701014042, 52.491443529725075, 51.05776906013489, 48.47017630934715, 40.858018174767494, 37.011970952153206, 35.784860998392105, 37.604670748114586, 40.121271908283234, 47.155249267816544, 48.613736405968666, 51.4667297154665, 48.7285852432251, 49.071684032678604, 44.79985065758228, 48.6425768584013, 41.10475033521652, 42.37301588058472, 50.87845668196678, 48.23263965547085, 49.35878522694111, 46.0206263512373, 43.91888312995434, 37.644450813531876, 36.04561060667038, 35.82059808075428, 36.10243275761604, 35.75865760445595, 36.84846572577953, 36.40045836567879, 35.56376226246357, 34.96966794133186, 37.748466432094574, 38.70308920741081, 46.87597945332527, 47.152942791581154, 49.155971109867096, 48.40334169566631, 48.64149771630764, 47.39673390984535, 45.20354099571705, 45.23236624896526, 36.78683303296566, 34.61836539208889, 40.80684632062912, 46.41086921095848, 49.74031135439873, 47.56355635821819, 46.98425464332104, 44.73808877170086, 47.114500254392624, 45.21573454141617, 46.483787298202515, 45.84284909069538, 45.82986518740654, 47.361885979771614, 44.879961758852005, 40.77068746089935, 34.351638704538345, 20.15482909977436, 5.931569589301944, 1.672450213227421, 2.23159056622535, 2.526022754609585, 3.7379261618480086, 3.3197334269061685, 3.8021640898659825, 2.266853624023497, 5.7148349191993475, 1.957612324040383, 1.1755927931517363, 0.2633602760033682, 0.25403355772141367, 0.4523648653412238, 14.22382140532136, 33.808872029185295, 21.80325474590063, 31.93402223289013, 18.303329050540924, 0.4085190180921927, 0.019334089884068817, 0.03444130365096498, 0.10455014300532639, 0.0616235718189273, 0.025147061751340516, 0.013854272747266805, 0.03251049143727869, 0.022360733237292152, 0.011251362320763292, 0.044329204320092686, 0.04676710377680138, 0.012129865717724897, 0.019221027396270074, 0.029031316116743255, 0.06899660860653967, 0.0542606801900547, 0.02290164014993934, 0.04600572705385275, 0.04774280903802719, 0.02173977827624185, 0.035540042154025286, 0.05846803411259316, 0.028442542534321547, 0.05478031343955081, 0.031609594661858864, 0.008916957212932175, 0.026581243582768366, 0.027732043745345436, 0.07301688936422579, 0.004739555442938581, 0.06029181007761508, 0.13460324989864603, 0.032462084855069406, 0.01103013644751627, 0.031483923085033894, 0.031693219862063415, 0.005885303899049177, 0.01460380664866534, 0.02048590122285532, 0.049762467460823245, 0.017257684994547162, 0.02407497933745617, 0.10502786346478388, 0.09625326594687067, 0.03436564911680762, 0.10077573577291332, 0.0839000174892135, 0.08430776084423997, 0.011077793460572138, 0.04978134027624037, 0.02603590975922998, 0.05500242710695602, 1.2988466606475413, 25.731544755399227, 35.82238018512726, 28.937256038188934, 32.64189004898071, 29.3789766356349, 8.029760476201773, 0.8171855157706887, 0.15463893651030958, 0.41849045490380377, 0.34334948693867773, 4.631615644320846, 9.833508487790823, 4.817822277545929, 10.565821342170238, 3.814621246419847, 5.820702463388443, 2.964397631585598, 2.1706301998347044, 3.6510896589607, 12.127041667699814, 23.652216531336308, 42.923241555690765, 52.56895177066326, 54.40243698656559, 53.25120136141777, 57.027461528778076, 54.26953911781311, 54.31766353547573, 54.12608161568642, 52.93372079730034, 50.90432949364185, 51.99036821722984, 48.90352785587311, 46.77548244595528, 43.08737374842167, 40.46876326203346, 40.27642518281937, 41.46639972925186, 40.242295414209366, 47.842750176787376, 53.17119285464287, 52.08676144480705, 55.871198773384094, 51.27341128885746, 54.41380977630615, 53.01942519843578, 49.57741789519787, 43.01826685667038, 39.99494768679142, 37.585033401846886, 38.654641807079315, 41.89791597425938, 47.25852392613888, 49.69848319888115, 52.736256793141365, 50.32419182360172, 49.7922507673502, 46.42410010099411, 48.37695211172104, 42.08495333790779, 45.251551419496536, 53.036980256438255, 50.34237004816532, 51.09952121973038, 48.5788618773222, 44.32813256978989, 38.2961880415678, 37.15366914868355, 37.48352184891701, 37.01667509973049, 36.05362817645073, 37.97482408583164, 37.51455098390579, 37.61672370135784, 36.879757046699524, 38.54788273572922, 40.56739076972008, 47.46611438691616, 49.251798167824745, 51.484467163681984, 49.93953086435795, 49.76946718990803, 49.252090752124786, 47.95453637838364, 46.74841269850731, 37.86356985569, 35.73422871530056, 43.17835986614227, 48.45370039343834, 50.54754003882408, 49.08057175576687, 47.98689164221287, 46.90503649413586, 48.371434807777405, 47.07543835043907, 47.79779478907585, 47.76232369244099, 48.26104313135147, 47.178986594080925, 47.27487824857235, 41.945823803544044, 37.49537341296673, 21.814927719533443, 7.561551975086331, 2.420459194108844, 3.7796795088797808, 3.647130746394396, 5.702056679874659, 5.430693291127682, 7.136569004505873, 3.9551695296540856, 6.2858720775693655, 1.9599757972173393, 0.49705759214702994, 0.052535253635142, 0.2429846560698934, 0.3196606080746278, 14.831497147679329, 36.67153961956501, 22.186730168759823, 34.182775765657425, 23.253587521612644, 0.7277621235698462, 0.043251320166746154, 0.008616991326562129, 0.0756272824946791, 0.031622047899872996, 0.1037876530608628, 0.007615208851348143, 0.02195298431615811, 0.04744269193906803, 0.017537268722662702, 0.02934798496426083, 0.03952361999836285, 0.07603515943628736, 0.028829043767473195, 0.010993486412189668, 0.06506506644655019, 0.020639167705667205, 0.03389680845430121, 0.03568662745237816, 0.018529926492192317, 0.019683548671309836, 0.03872254950692877, 0.025449217901041266, 0.09959829621948302, 0.2212926888023503, 0.1238475188438315, 0.10848759266082197, 0.11762050649849698, 0.1134658524824772, 0.22385195537935942, 0.11335604431224056, 0.15356660733232275, 0.2095041034044698, 0.0828489508421626, 0.07896230119513348, 0.06295840605162084, 0.19196345790987834, 0.11675994916004129, 0.13717094727326185, 0.19819288223516196, 0.13586046290583909, 0.04347609072283376, 0.16538219206267968, 0.2062314547947608, 0.13273544231196865, 0.1057210739236325, 0.1685351470950991, 0.16518766031367704, 0.13867428613593802, 0.1826768898172304, 0.11165458170580678, 0.09673352455138229, 0.10838997797691263, 1.7415796662680805, 29.02981147170067, 43.57528656721115, 35.04372976720333, 37.86748364567757, 33.676152750849724, 10.676818136125803, 1.6452371422201395, 0.4369566624518484, 1.58932896098122, 6.18982320651412, 12.95465910807252, 14.730384573340416, 12.389586679637432, 14.783804956823587, 10.481064040213823, 10.588698014616966, 5.9475543815642595, 3.0342701822519302, 4.869632497429848, 13.166948966681957, 27.141550295054913, 43.69868494570255, 55.50642974674702, 56.34979069232941, 54.1169773042202, 58.652003556489944, 56.66800081729889, 55.473884493112564, 55.19908703863621, 55.96428617835045, 52.605441212654114, 54.44611184298992, 50.727175399661064, 47.26487718522549, 44.774950593709946, 42.494540959596634, 42.543558329343796, 42.8791107237339, 42.60286934673786, 48.40054124593735, 54.31993581354618, 54.45812299847603, 58.551210165023804, 52.216634675860405, 56.41023404896259, 56.914508789777756, 50.4905316978693, 45.39533570408821, 41.06762632727623, 39.37881454825401, 41.231819316744804, 44.63619723916054, 51.030136942863464, 52.74598427116871, 55.265226289629936, 51.75641097128391, 51.63507588207722, 45.6358589977026, 48.334622383117676, 43.39318513870239, 46.96251980960369, 54.03557047247887, 51.847001910209656, 53.25709104537964, 51.452104300260544, 48.53843964636326, 40.721046924591064, 39.58701677620411, 39.974842965602875, 39.28530536592007, 38.947777077555656, 41.03288099169731, 39.90364998579025, 39.626314267516136, 38.97845283150673, 41.26610107719898, 41.5034781396389, 51.00499369204044, 51.85174025595188, 52.356478571891785, 50.53865231573582, 50.08189022541046, 52.14466653764248, 50.14539621770382, 48.33956591784954, 41.70972727239132, 38.095976784825325, 44.68091703951359, 49.043128564953804, 53.10538038611412, 49.538234397768974, 48.64270605146885, 48.94911400973797, 49.61649879813194, 48.11480037868023, 50.20914539694786, 49.96064253151417, 49.757801815867424, 48.641938492655754, 47.825495302677155, 44.04514655470848, 38.18497180938721, 21.149150244891644, 7.049992075189948, 4.05034183524549, 5.96700363792479, 7.784224301576614, 9.057720266282558, 8.682414405047894, 9.855540655553341, 6.546567063778639, 14.992469809949398, 8.249567281454802, 2.337628388777375, 1.0664378316141665, 0.583980391966179, 0.8833320694975555, 19.646802060306072, 43.130125254392624, 28.365462720394135, 40.46769551932812, 28.156641125679016, 1.0573271079920232, 0.15246828814269975, 0.10950806055916473, 0.1569048617966473, 0.14365351817104965, 0.3033010312356055, 0.12300034242798574, 0.10979753526044078, 0.17299177357926965, 0.10007363438489847, 0.16227073792833835, 0.12044926916132681, 0.08728304572287016, 0.07101850089384243, 0.10857619767193682, 0.12548347207484767, 0.17431327141821384, 0.09691794082755223, 0.16961563989752904, 0.12262092684977688, 0.17902350460644811, 0.17124397127190605, 0.11371506567229517, 0.2859623241238296], [0.024665804958203807, 0.06492886750493199, 0.023770095795043744, 0.06035659585904796, 0.00504625771100109, 0.06378450547344983, 0.055803107970859855, 0.034148845516028814, 0.00977237054030411, 0.04345983026723843, 0.06267430449952371, 0.04142041958402842, 0.058036449263454415, 0.05854509872733615, 0.04320736275985837, 0.02328125796339009, 0.04731247841846198, 0.060639035000349395, 0.028810363910451997, 0.04392948358145077, 0.03986492258263752, 0.03317558563139755, 0.01793704512238037, 0.059202077536610886, 0.030412488194997422, 0.0466113566653803, 0.07693159961490892, 0.025072962016565725, 0.038141867189551704, 0.07535248747444712, 6.042492762207985, 27.467006631195545, 30.518592484295368, 35.60984618961811, 35.76237380504608, 17.64142356812954, 4.900471167638898, 0.12389965471811593, 0.4620036715641618, 0.14856652094749734, 3.0941181583330035, 8.184308633208275, 5.130773959681392, 10.406990814954042, 2.844587448053062, 5.614997176453471, 2.6762251323089004, 0.444267499842681, 1.3123121880926192, 7.874116078019142, 19.918191097676754, 37.65230879187584, 46.654356345534325, 53.970947340130806, 52.13750012218952, 53.31034138798714, 52.73179203271866, 50.28197228908539, 50.00733442604542, 48.96391421556473, 45.38729913532734, 43.660664185881615, 42.802598029375076, 40.64907118678093, 40.77788807451725, 39.33620743453503, 36.71130828559399, 37.583300694823265, 39.74173687398434, 43.08800831437111, 50.242773592472076, 52.1477709710598, 49.91696387529373, 52.571338042616844, 52.536858692765236, 50.95389403402805, 50.42469263076782, 44.56689655780792, 39.34445299208164, 35.85471644997597, 38.204324170947075, 38.117225244641304, 43.943988382816315, 47.492496371269226, 52.6473643630743, 50.247755125164986, 53.66148814558983, 50.23274213075638, 50.86838722229004, 45.28153941035271, 39.701508432626724, 51.253914535045624, 48.278617188334465, 50.71171782910824, 48.867475390434265, 46.53573431074619, 43.51973734796047, 38.03179822862148, 35.28703451156616, 35.64520329236984, 38.133792355656624, 35.987819507718086, 35.56587114930153, 35.03760449588299, 36.70528180897236, 34.96192015707493, 37.68159382045269, 42.29586102068424, 47.72509329020977, 49.25745226442814, 50.63943810760975, 48.24993632733822, 48.37252914905548, 47.13684685528278, 46.87974125146866, 42.36542008817196, 36.090634390711784, 37.968068048357964, 43.91999267041683, 46.482388973236084, 46.77554324269295, 50.044625625014305, 46.17463208734989, 43.909026458859444, 47.08237297832966, 43.74400891363621, 45.22081106901169, 44.99751225113869, 44.61396083235741, 42.370656207203865, 36.24506190419197, 27.46042348444462, 11.027334127575159, 3.857826590538025, 1.9786979863420129, 1.3972525927238166, 2.235015844926238, 3.395875641144812, 5.681294593960047, 7.0145760755985975, 3.0875029508024454, 2.6956311659887433, 2.2282267967239022, 0.21482411480974406, 0.14136872749077156, 0.06213761298567988, 4.524622410535812, 22.928003892302513, 27.955276630818844, 21.123894900083542, 27.480076029896736, 7.945127617567778, 0.0973726250231266, 0.033478248296887614, 0.05246050452115014, 0.04694161980296485, 0.05664818781951908, 0.010049477350548841, 0.05551593392738141, 0.03174514422426, 0.05696336680557579, 0.028625404011108913, 0.017778513101802673, 0.11276640798314475, 0.026888518696068786, 0.05325871032255236, 0.050554201734485105, 0.10800432835821994, 0.03309466555947438, 0.01486682471295353, 0.014624580289819278, 0.023181852848210838, 0.040271652906085365, 0.037320480405469425, 0.055849941199994646, 0.05592839734163135, 0.01605231656867545, 0.037285799844539724, 0.04996767129341606, 0.03475405210338067, 0.041309082589577883, 0.06082888750825077, 0.05507882378879003, 0.029819825758750085, 0.013854969438398257, 0.021286134942783974, 0.07284519349923357, 0.02838601500116056, 0.03943089606764261, 0.04057293146615848, 0.04688922046625521, 0.01462099664422567, 0.059456493181642145, 0.046309677345561795, 0.014089126307226252, 0.037840618315385655, 0.03890471707563847, 0.00932718026888324, 0.045478312385967, 0.057126216270262375, 0.1056965978932567, 0.05252119364740793, 0.050500600118539296, 0.011983221975242486, 0.053824456917936914, 0.19202177587430924, 10.146777927875519, 34.63609144091606, 31.866902634501457, 37.34987922012806, 39.287729635834694, 18.680284023284912, 3.781528347171843, 0.19898711383575574, 0.17170625505968928, 0.24299414071720093, 2.027015006169677, 7.249591564759612, 8.524445481598377, 9.222022499889135, 6.4039502665400505, 6.711580334231257, 2.8278586082160473, 1.7098589683882892, 2.157910382375121, 9.799524061381817, 21.780492067337036, 38.78168798983097, 50.848438292741776, 56.030999198555946, 53.67062285542488, 55.67349538207054, 55.56222975254059, 51.89207889139652, 52.84273847937584, 50.086377784609795, 46.5335950255394, 44.96058203279972, 43.2689356058836, 42.793824300169945, 42.231378480792046, 39.11135829985142, 38.27617451548576, 39.13362890481949, 41.50166563689709, 45.74974648654461, 52.999214082956314, 52.7904798835516, 53.22530955076218, 52.93403618037701, 52.318644002079964, 54.00177128612995, 52.472972720861435, 46.22511997818947, 40.6559906154871, 37.572805657982826, 40.11623717844486, 39.38199497759342, 47.09808513522148, 50.71681335568428, 52.78941594064236, 52.159155160188675, 54.11201857030392, 49.771359488368034, 50.3481837362051, 46.36735014617443, 41.83412879705429, 53.20307694375515, 50.648143440485, 52.57788509130478, 50.63599929213524, 48.74477997422218, 45.48988603055477, 39.17511887848377, 37.165019139647484, 36.579565554857254, 39.880095049738884, 36.78988806903362, 36.39715254306793, 36.518176048994064, 37.57425718009472, 38.06479185819626, 38.87274630367756, 45.31313091516495, 50.06115473806858, 50.95944933593273, 51.69746853411198, 48.55581991374493, 49.096804484725, 49.08764697611332, 48.91917921602726, 44.24046367406845, 37.20541477203369, 39.1880913823843, 46.40694782137871, 48.440344110131264, 47.240007519721985, 50.32935954630375, 47.15629421174526, 47.35717423260212, 47.49531961977482, 44.56242799758911, 46.36481188237667, 46.80770091712475, 46.34526193141937, 44.65220957994461, 39.593883007764816, 29.41528558731079, 13.96546471863985, 5.080754868686199, 2.2528758365660906, 4.058936024084687, 3.7941206339746714, 6.115728132426739, 5.041384231299162, 7.023207787424326, 4.762924248352647, 2.5595165323466063, 1.3183791562914848, 0.05377193883759901, 0.18311652325792238, 0.15907369932392612, 3.9955093525350094, 27.811161763966084, 33.181974068284035, 24.350233376026154, 32.89874106645584, 10.941764619201422, 0.10418967445730232, 0.06745952428900637, 0.06383401414495893, 0.0611763091001194, 0.04352753639977891, 0.03335174922540318, 0.038932399183977395, 0.06823834890383296, 0.029404015258478466, 0.03839312499621883, 0.02503053157852264, 0.015469620248040883, 0.032874407261260785, 0.0680137675954029, 0.031407426213263534, 0.020138136387686245, 0.05135240382514894, 0.08519381837686524, 0.05199177518079523, 0.03859604672470596, 0.003671324311653734, 0.03729631978785619, 0.03736183287401218, 0.036842800764134154, 0.10584561372525059, 0.09503335328190587, 0.09034890972543508, 0.1150837863679044, 0.1585885277017951, 0.12406196241499856, 0.16944078990491107, 0.11616788600804284, 0.10142085506231524, 0.0945702828175854, 0.11309611450997181, 0.14413120894460008, 0.12719232647214085, 0.20565614191582426, 0.1681664036004804, 0.0933171070937533, 0.20259950280888006, 0.1855543299461715, 0.15174319501966238, 0.12900972738862038, 0.1048337176325731, 0.11934421127079986, 0.16368656273698434, 0.2099977948819287, 0.26163228903897107, 0.08437943004537374, 0.12647950847167522, 0.11411584026063792, 0.14353986567584798, 0.27300694899167866, 9.887227155268192, 41.201591938734055, 39.581241086125374, 45.10900966823101, 45.916899517178535, 22.273128032684326, 5.982699645683169, 0.3746529493946582, 0.7576526852790266, 0.8144954382441938, 9.11065997555852, 20.613168105483055, 16.100241467356682, 21.872272342443466, 10.734481941908598, 13.028786480426788, 5.914969705045223, 1.655509416013956, 2.2170449467375875, 9.659414179623127, 23.170204795897007, 41.42454497516155, 52.93450355529785, 56.11373595893383, 56.85772083699703, 56.90193146467209, 57.6863119751215, 53.69894653558731, 54.6108254045248, 51.74484059214592, 48.813305497169495, 47.43490286171436, 46.46506570279598, 43.96542303264141, 43.941039741039276, 42.6655013859272, 40.30762530863285, 40.406894981861115, 43.78522150218487, 47.272875756025314, 55.1945386826992, 55.3715293854475, 53.28812018036842, 55.229903385043144, 54.51279066503048, 55.470096096396446, 55.0617890059948, 49.22342129051685, 43.72322402894497, 40.25384299457073, 41.53018310666084, 41.292532458901405, 48.61331842839718, 52.72037364542484, 56.67998157441616, 52.96183168888092, 55.33344782888889, 53.37367258965969, 50.94523809850216, 48.57478849589825, 43.89073424041271, 52.16036729514599, 51.19997262954712, 55.90763881802559, 52.90066257119179, 48.530771657824516, 48.04017998278141, 42.448346838355064, 38.7971455603838, 39.506586492061615, 41.8226458132267, 38.52344624698162, 38.02492819726467, 37.90165141224861, 40.80772407352924, 38.84677469730377, 40.52759550511837, 46.415656954050064, 51.9604904204607, 53.19105438888073, 52.10770972073078, 49.419821351766586, 49.83630180358887, 51.581453159451485, 51.378623843193054, 46.41109719872475, 40.00841036438942, 41.71002745628357, 47.864443212747574, 50.421762987971306, 49.764835238456726, 52.88169398903847, 47.68598198890686, 47.566816583275795, 47.40624099969864, 47.98595689237118, 47.30637475848198, 49.349650517106056, 46.00285090506077, 46.24867871403694, 40.54512396454811, 28.52481096982956, 12.095402665436268, 5.981904538348317, 5.518303290009499, 5.384505819529295, 5.279604373499751, 10.507778506726027, 11.952233947813511, 16.06910403817892, 10.699086841195822, 9.786588605493307, 5.119399270042777, 0.6136756797786802, 0.3649860603036359, 0.23967040266143158, 6.329058660194278, 31.437128596007824, 38.0881492048502, 30.143486112356186, 40.59371195733547, 11.607980970293283, 0.2619035291718319, 0.17999951785895973, 0.11677771617542021, 0.1063992633135058, 0.2690366073511541, 0.17286517802858725, 0.10732412032666616, 0.105786872736644, 0.17858940758742392, 0.19858804618706927, 0.09049378437339328, 0.17044850770616904, 0.15707640181062743, 0.19511552236508578, 0.20921996474498883, 0.2260381294763647, 0.11492822479340248, 0.15596300218021497, 0.13385166210355237, 0.10746282030595466, 0.11649509149719961, 0.17098006355809048, 0.07642088326974772, 0.11575011623790488], [0.020417729392647743, 0.036295132886152714, 0.06156516479677521, 0.054782877559773624, 0.032994534994941205, 0.04166260834608693, 0.026928006518573966, 0.09138479203102179, 0.022182510183483828, 0.021850386110600084, 0.062213497585617006, 0.01794357787730405, 0.04209628234093543, 0.01930408485350199, 0.03542161764926277, 0.029524898127419874, 0.02946704400528688, 0.06720682300510816, 0.031357828484033234, 0.06069904506148305, 0.01706226266833255, 0.0024822745535857393, 0.006503737413368071, 0.043156748288311064, 0.02907768364821095, 0.04666199711209629, 0.016701031563570723, 0.043346901366021484, 0.05189273557334673, 0.0040776993319013854, 1.1716363742016256, 20.471325516700745, 34.618395790457726, 25.778029561042786, 33.469930216670036, 32.017188370227814, 14.76513085886836, 3.098415252752602, 0.19660100515466183, 0.27057585131842643, 1.6130928858183324, 4.545258153229952, 4.1024574637413025, 6.359707340598106, 1.2159997061826289, 4.397020982578397, 1.4139396348036826, 2.0504488237202168, 0.32697177201043814, 6.073829680681229, 16.185763478279114, 34.042373299598694, 46.04396849870682, 53.058650493621826, 51.77362024784088, 52.61492930352688, 51.690366715192795, 50.90204581618309, 46.07420727610588, 44.43003170192242, 43.78605745732784, 43.01694072782993, 44.83539775013924, 44.29392300546169, 46.373973190784454, 47.65066668391228, 46.06614790856838, 40.88388718664646, 38.96982729434967, 43.3080393075943, 51.5455336868763, 53.37262384593487, 52.94601693749428, 46.49018995463848, 50.204209461808205, 54.36890758574009, 51.979299411177635, 48.916747346520424, 41.9858318567276, 36.924613639712334, 36.52408853173256, 38.13872829079628, 40.05823329091072, 43.12666743993759, 48.922124058008194, 47.7067706733942, 50.11985778808594, 50.72057515382767, 52.89112888276577, 44.764273166656494, 43.97765837609768, 51.26284025609493, 50.312385857105255, 50.82641467452049, 50.75892649590969, 48.30193653702736, 47.42201015353203, 42.71061256527901, 35.04761315882206, 39.03808683156967, 38.876542299985886, 35.5733073502779, 36.61721013486385, 34.650705456733704, 36.47455058991909, 35.663624703884125, 34.827673360705376, 37.399610951542854, 45.35775952041149, 48.15849803388119, 47.735481932759285, 50.60555912554264, 50.27293637394905, 48.41721095144749, 47.002569660544395, 46.92703351378441, 39.65550050139427, 33.83578218519688, 39.05704401433468, 43.85525554418564, 48.340238481760025, 46.5624962747097, 47.345087081193924, 46.18747539818287, 45.779457092285156, 47.86867618560791, 45.63984878361225, 47.49426327645779, 45.228912234306335, 38.967156037688255, 31.029471270740032, 15.199706889688969, 6.1374947894364595, 2.13365675881505, 0.9920328366570175, 3.630067049525678, 1.9868929591029882, 4.7911942563951015, 3.0012606410309672, 4.468703661113977, 2.858365271240473, 2.373834508471191, 1.0924168000929058, 0.1070078466727864, 0.2466000136337243, 1.160906224977225, 12.784308549016714, 36.194292828440666, 25.730085633695126, 26.03790521621704, 21.923964768648148, 1.6953037306666374, 0.05288533211569302, 0.029500763484975323, 0.027701291000994388, 0.040963137871585786, 0.037697079533245414, 0.06449304870329797, 0.046942703338572755, 0.027914354177482892, 0.03603179291530978, 0.07337769930018112, 0.06721949146594852, 0.018462906846252736, 0.044756421630154364, 0.022173203651618678, 0.05192016535147559, 0.008936065660236636, 0.06070156094210688, 0.025985927968577016, 0.041259889330831356, 0.02297583265317371, 0.04336471662099939, 0.043079780152766034, 0.03520168218528852, 0.02700130658922717, 0.030001234481460415, 0.01586193342518527, 0.03218758669390809, 0.06343853106955066, 0.061993840427021496, 0.025296556268585846, 0.0704954203683883, 0.12618866079719737, 0.08141693237121217, 0.038828795368317515, 0.04934982964186929, 0.04942884981574025, 0.050737011260935105, 0.04387798595416825, 0.039104844618123025, 0.09697366869659163, 0.024539272490073927, 0.022301094249996822, 0.0306367782104644, 0.020187743393762503, 0.05299689917592332, 0.07895841976278462, 0.02366754397371551, 0.01263145179109415, 0.03939166614145506, 0.05617564012936782, 0.03611151812947355, 0.06183308381878305, 0.024838604767865036, 0.07662148578674532, 2.9754455387592316, 25.54309956729412, 39.12855617702007, 33.81104551255703, 37.397775650024414, 34.52923357486725, 15.640122257173061, 2.400910430587828, 0.16071740799816325, 0.2609349670819938, 0.3810156782856211, 3.3851174684241414, 6.494316542521119, 7.688834220170975, 6.858349833637476, 6.937795020639896, 4.7632030583918095, 1.8491865671239793, 1.1455470928922296, 6.665465058758855, 16.93994890898466, 33.804867044091225, 48.981663063168526, 54.49644394218922, 54.466687738895416, 54.683397710323334, 54.10863295197487, 51.296894028782845, 48.43440502882004, 46.400883346796036, 44.229885041713715, 43.44627968966961, 45.08868455886841, 45.61469033360481, 48.150290474295616, 47.467018738389015, 46.215460896492004, 40.72903409600258, 39.89362992346287, 45.882872343063354, 54.19405996799469, 54.17240872979164, 53.86670373380184, 48.205744698643684, 53.01392689347267, 54.571235328912735, 53.945598900318146, 49.726829677820206, 44.41881850361824, 38.54044273495674, 38.81308950483799, 40.35368263721466, 43.17674495279789, 46.506924256682396, 51.01338744163513, 50.28097294270992, 53.60758423805237, 51.99351444840431, 52.8929527848959, 45.84411822259426, 45.494244396686554, 51.16665981709957, 50.36057487130165, 51.36431001126766, 52.410948649048805, 49.78275887668133, 48.1690576672554, 45.02175875008106, 36.91047079861164, 40.24874746799469, 40.05825988948345, 37.13667646050453, 37.496889531612396, 36.25749483704567, 37.78328016400337, 37.752524614334106, 37.04759024083614, 39.691708758473396, 47.113326117396355, 51.53574541211128, 50.19367262721062, 51.342841163277626, 50.54836079478264, 49.89625118672848, 48.40741887688637, 47.88534589111805, 39.97334584593773, 37.26331226527691, 41.06000013649464, 46.32225036621094, 49.28949974477291, 46.98097541928291, 48.75751689076424, 46.40919730067253, 46.489593386650085, 48.99802878499031, 46.97321243584156, 48.07772196829319, 45.82981958985329, 42.61804573237896, 34.65168200433254, 18.062049597501755, 7.866268074139953, 4.1361412312835455, 1.9505926757119596, 3.533706357702613, 4.797527566552162, 4.916421286761761, 5.714110108092427, 5.0685162004083395, 4.704064931720495, 0.964087889296934, 0.19873497658409178, 0.09401896357303485, 0.20547433057799935, 0.9453467605635524, 13.205971922725439, 38.22188302874565, 28.229819498956203, 27.82981876283884, 27.238939069211483, 2.849442637525499, 0.03411914105527103, 0.028821134328609332, 0.008577134285587817, 0.07128329176339321, 0.03000343123858329, 0.030170039681252092, 0.04350919421995059, 0.025450373796047643, 0.036812046164413914, 0.049894896292244084, 0.06164800332044251, 0.021882532237214036, 0.08393747368245386, 0.029374498190009035, 0.06517197281937115, 0.025716018135426566, 0.06560224035638385, 0.04046660025778692, 0.0585210531426128, 0.034988043844350614, 0.006733191385137616, 0.05259606521576643, 0.032826267852215096, 0.028358518429740798, 0.10405999899376184, 0.12046191535773687, 0.13856973237125203, 0.11803597561083734, 0.16730546776670963, 0.11612508635153063, 0.14646547118900344, 0.2636123390402645, 0.23434285103576258, 0.10843943469808437, 0.11771973164286464, 0.16025559918489307, 0.10708116344176233, 0.24413497012574226, 0.19109783170279115, 0.12445224303519353, 0.11234802223043516, 0.21808325633173808, 0.15243643516441807, 0.1025009693694301, 0.18029162718448788, 0.19663250190205872, 0.11193334721610881, 0.1631128232111223, 0.15707588230725378, 0.13205705996369943, 0.11006982924300246, 0.12781126279151067, 0.1747038192115724, 0.1712582353502512, 3.032489027827978, 29.97318685054779, 48.27402323484421, 37.80776225030422, 42.3519042134285, 38.93377482891083, 19.305658265948296, 3.857036945410073, 0.3673953685211018, 0.8800676884129643, 4.967242609709501, 12.70504955202341, 10.786760486662388, 18.25652126222849, 8.065413013100624, 13.507434446364641, 6.349228452891111, 4.767772788181901, 1.3911047601141036, 7.697419384494424, 18.514981493353844, 34.860609993338585, 51.12480506300926, 57.6924030482769, 56.93163827061653, 57.430536299943924, 56.813346818089485, 55.89004956185818, 49.9009857326746, 49.11925368010998, 47.56059251725674, 47.08828546106815, 47.89004623889923, 49.653250426054, 50.85085116326809, 50.569829642772675, 48.023206293582916, 43.544033244252205, 41.425190940499306, 46.996087208390236, 56.373148038983345, 57.42716208100319, 54.29206810891628, 48.407194688916206, 53.525018468499184, 55.26548467576504, 57.313023805618286, 52.787725031375885, 46.950611248612404, 40.63658885657787, 41.09653137624264, 42.77083933353424, 44.180354699492455, 48.06772090494633, 53.0890716612339, 53.324180245399475, 54.74238574504852, 55.10800212621689, 54.79939788579941, 48.163965940475464, 48.193209171295166, 52.10750833153725, 52.43685565888882, 53.77145804464817, 54.77523498237133, 53.025599867105484, 51.76685281097889, 46.613899916410446, 38.7758819013834, 43.68128187954426, 41.91731013357639, 40.38128815591335, 39.932456240057945, 38.24270211160183, 39.16457824409008, 39.28731545805931, 38.850825279951096, 42.10392192006111, 48.57584863901138, 53.40552628040314, 51.22882828116417, 53.68627421557903, 51.150335893034935, 51.43635034561157, 52.15442821383476, 50.93439348042011, 43.03683266043663, 38.01218368113041, 42.21995249390602, 48.675236105918884, 52.19891622662544, 48.78668412566185, 50.545640140771866, 47.323435842990875, 47.051602229475975, 49.939880445599556, 48.10124270617962, 48.08952413499355, 48.454133570194244, 44.18407090008259, 34.0044741332531, 16.488143652677536, 7.616177368909121, 4.6623284462839365, 3.8402302097529173, 7.988334149122238, 6.320831151679158, 11.223781686276197, 9.534409437328577, 11.716273259371519, 7.64527715742588, 5.458956649526954, 1.89204434864223, 0.36060614220332354, 0.6911161774769425, 1.9949490018188953, 17.562169320881367, 44.74627733230591, 33.24331417679787, 35.071833059191704, 30.05239550024271, 2.868145708926022, 0.10524474128033035, 0.17634969495702535, 0.14483627892332152, 0.1303418230963871, 0.10357191815273836, 0.0935674186621327, 0.15517165011260659, 0.12703427870292217, 0.15018858859548345, 0.15607990528224036, 0.22617763839662075, 0.0641050464764703, 0.17908102105138823, 0.07660465387743898, 0.18673563608899713, 0.1407735695829615, 0.10326843912480399, 0.13208971446147189, 0.1627172584994696, 0.1689513583551161, 0.12176108939456753, 0.1586717224563472, 0.09941183161572553, 0.13129549770383164], [0.06175662776513491, 0.04998143071134109, 0.0546076639147941, 0.022875687245687004, 0.0073088015869871015, 0.06631084295804612, 0.043475890342961065, 0.0383340166445123, 0.02933641488198191, 0.09509783107205294, 0.004338911194281536, 0.007818333742761752, 0.05641139818180818, 0.03745672758668661, 0.00904365017049713, 0.03323167344206013, 0.04311346994654741, 0.007057735347189009, 0.033583492258912884, 0.03467795228061732, 0.05270901267067529, 0.016658766253385693, 0.01938907560543157, 0.07594538925332017, 0.025047537892533, 0.02827569103828864, 0.0684325466863811, 0.0168007632237277, 0.012610343255801126, 0.04262270624167286, 0.09299344164901413, 8.598728645592928, 28.56870051473379, 29.530280716717243, 30.84688726812601, 35.49840196967125, 29.319673217833042, 14.624923132359982, 1.8037987151183188, 0.3743696567835286, 0.11565167034859769, 2.5006403541192412, 6.494982456788421, 4.117349339649081, 8.856472615152597, 5.430680941790342, 3.4067342709749937, 1.745174154639244, 0.9524960769340396, 3.318027793429792, 14.908212181180716, 23.58251117169857, 43.43387335538864, 49.996569603681564, 55.01532129943371, 51.20328605175018, 55.29998682439327, 51.59457005560398, 50.144020691514015, 46.97065897285938, 48.43548037111759, 46.68678380548954, 48.88028830289841, 53.45475643873215, 52.988658249378204, 52.21624709665775, 52.812575697898865, 46.69091418385506, 38.270858600735664, 41.11417002975941, 51.068305894732475, 53.146604374051094, 53.77871185541153, 50.865510776638985, 47.56953343749046, 51.33782543241978, 54.54866074025631, 50.13622730970383, 46.905085891485214, 39.952397570014, 37.72075451910496, 36.902464628219604, 38.258991837501526, 40.733825638890266, 44.517753794789314, 46.27362437546253, 51.700827553868294, 48.12471404671669, 54.13594588637352, 48.610666170716286, 40.88574528694153, 52.32874386012554, 49.69601333141327, 50.45541398227215, 50.36551460623741, 51.1787773668766, 49.647653326392174, 47.054535672068596, 40.643014311790466, 36.54886320233345, 35.954195111989975, 34.93516959249973, 35.33343382179737, 35.90268887579441, 34.627690091729164, 36.71463690698147, 34.41218465566635, 34.79659862816334, 39.632925912737846, 43.96796889603138, 46.73692971467972, 49.43940930068493, 47.79098555445671, 48.19749154150486, 49.9793641269207, 47.67545275390148, 45.09059205651283, 38.734065145254135, 38.193141371011734, 38.691009655594826, 42.69252933561802, 43.734349831938744, 46.574393436312675, 49.581924453377724, 44.50154006481171, 46.7500352114439, 43.49187724292278, 43.147577717900276, 40.054600685834885, 29.477201364934444, 19.441823959350586, 7.2569802682846785, 2.4604104878380895, 2.121977135539055, 0.8270571485627443, 1.026784465648234, 4.546824619174004, 3.2453360315412283, 3.424307140521705, 3.4126002062112093, 4.467261163517833, 0.746986954472959, 0.4500784567790106, 0.08362810942344368, 0.5931172391865402, 7.145084347575903, 24.991667456924915, 31.162758618593216, 22.282741516828537, 28.620702624320984, 8.301261607557535, 0.14037497690878808, 0.04874272315646522, 0.010983813444909174, 0.0514605941134505, 0.02821807996951975, 0.048739116318756714, 0.031461844191653654, 0.055540576940984465, 0.13208928401581943, 0.09082709031645209, 0.06610035503399558, 0.09678418355179019, 0.02962164449854754, 0.03768433685763739, 0.011286793378531002, 0.04904625042399857, 0.049418422640883364, 0.07083617005264387, 0.055207389741553925, 0.025884708302328363, 0.03170401440002024, 0.028736939530062955, 0.08413230229052715, 0.030583560655941255, 0.020751801603182685, 0.06656345518422313, 0.035362316339160316, 0.04270338511560112, 0.01093523245799588, 0.08090168892522343, 0.02364943371503614, 0.06479166666395031, 0.04396595642901957, 0.0343128898384748, 0.00208208718959213, 0.036582073153113015, 0.11209434873308055, 0.09529449278488755, 0.1071629481157288, 0.05202573585847858, 0.020707411895273253, 0.03459760366240516, 0.039671058766543865, 0.06219071365194395, 0.038849234115332365, 0.09064230296644382, 0.021234574232948944, 0.022230360154935624, 0.05936457819188945, 0.01917159665026702, 0.014358541684487136, 0.07208196140709333, 0.06888706760946661, 0.01683710805082228, 0.051895154974772595, 0.2110472065396607, 13.363615013659, 37.85868711769581, 31.601583771407604, 34.96345527470112, 42.465616911649704, 32.13837906718254, 13.587446752935648, 1.2050710176117718, 0.11353815250913613, 0.16021647315938026, 1.22794424649328, 5.243862541392446, 5.756308268755674, 7.243630634620786, 6.637661000713706, 5.695768017321825, 2.3050152137875557, 1.7306525213643909, 4.475338105112314, 14.903131853789091, 27.015214674174786, 44.09905806183815, 52.93980047106743, 55.65548814833164, 53.989991918206215, 55.19285537302494, 54.41740058362484, 50.959760919213295, 49.06483680009842, 49.00825783610344, 47.96842463314533, 49.519653394818306, 53.85206311941147, 54.40640017390251, 53.930145129561424, 53.41317526996136, 47.68788568675518, 40.13468138873577, 43.999830186367035, 52.77501471340656, 55.295126885175705, 55.473208129405975, 50.8144149184227, 47.89728485047817, 54.73638966679573, 55.659348741173744, 53.23188319802284, 48.53020928800106, 41.13810874521732, 39.31881956756115, 39.427292346954346, 40.89983493089676, 43.083760142326355, 46.561409533023834, 49.99696858227253, 52.97421522438526, 49.90840293467045, 54.73408319056034, 49.90041196346283, 41.79687939584255, 52.895935624837875, 49.859598353505135, 52.229667976498604, 51.44209563732147, 53.68201844394207, 51.41661420464516, 48.78593556582928, 42.27346122264862, 38.72413247823715, 37.704039216041565, 36.20063468813896, 36.82412423193455, 37.16279625892639, 37.27112464606762, 38.69991257786751, 36.75489954650402, 37.339027002453804, 40.72419695556164, 46.35490961372852, 48.1966707855463, 50.206911116838455, 48.40854361653328, 48.88685815036297, 50.78748196363449, 49.41298171877861, 45.95306597650051, 40.60484915971756, 39.72329646348953, 41.292498260736465, 44.399553537368774, 44.575928673148155, 47.707751020789146, 49.30495351552963, 46.48990876972675, 48.868448138237, 45.61275623738766, 45.654857978224754, 44.82305221259594, 33.63744802772999, 20.42808573693037, 9.769580718129873, 4.358858205378056, 4.492025384679437, 2.8596531646326184, 3.167281332425773, 5.475674802437425, 5.110672563314438, 7.01847561635077, 3.685459764674306, 3.4314994420856237, 0.2794951305259019, 0.3665839339373633, 0.03694979248393793, 0.6475714640691876, 7.256428822875023, 30.499707497656345, 38.56626234948635, 24.499715454876423, 31.332115530967712, 12.486784514039755, 0.20445513917366043, 0.050452802097424865, 0.1376097198226489, 0.030774184997426346, 0.043133166545885615, 0.023794169210304972, 0.04271252466423903, 0.07876323492382653, 0.05337368384061847, 0.019445291436568368, 0.0666701166483108, 0.03092538088822039, 0.02102405662299134, 0.02751722353423247, 0.06914462996064685, 0.029804904879711103, 0.011446340286056511, 0.048846278732526116, 0.0445256879174849, 0.04392418464703951, 0.04780624411068857, 0.11315639916574582, 0.0627358136989642, 0.06109846151957754, 0.07856889613321982, 0.2325977649888955, 0.08994217569124885, 0.1861816822201945, 0.0851827603764832, 0.19663858751300722, 0.15036334953038022, 0.14254731737310067, 0.10276054294081405, 0.19105593004496768, 0.18176824873080477, 0.12200385332107544, 0.15890502399997786, 0.12273779284441844, 0.20728576462715864, 0.13096464826958254, 0.12788868363713846, 0.10991877250489779, 0.1311074077966623, 0.18038491514744237, 0.16739044367568567, 0.2415757332346402, 0.1728929195087403, 0.15582643216475844, 0.15520391869358718, 0.11583042403799482, 0.15072274196427315, 0.12540888623334467, 0.1367330356151797, 0.1121373858768493, 0.11941330521949567, 0.260366274160333, 14.040989466011524, 43.38375024497509, 40.31886510550976, 40.83509020507336, 46.92039906978607, 35.876299291849136, 17.943634651601315, 2.1515839593484998, 0.4527710872935131, 1.3233825378119946, 7.790110185742378, 16.512194462120533, 10.35835912451148, 17.455320954322815, 14.38180647790432, 8.111097011715174, 3.0243249284103513, 3.080539586953819, 4.544556140899658, 17.401992715895176, 25.75262412428856, 45.46296067535877, 55.40288910269737, 59.68860313296318, 56.45673215389252, 58.592859730124474, 56.05619564652443, 54.0797621011734, 51.919513419270515, 50.84366574883461, 50.54006963968277, 52.80320540070534, 57.280060574412346, 55.78059263527393, 56.06549754738808, 55.691514015197754, 49.932402446866035, 42.952910363674164, 45.59087321162224, 56.13381788134575, 56.93996362388134, 57.538009732961655, 52.37485818564892, 48.10855731368065, 55.713989809155464, 59.415838569402695, 56.27637483179569, 51.627871468663216, 43.4628202021122, 41.09676316380501, 40.54492637515068, 42.37186074256897, 45.32804511487484, 47.652148604393005, 51.61311686038971, 55.69654494524002, 52.584485337138176, 56.10344611108303, 51.43212877213955, 44.659725576639175, 53.3351806551218, 51.660234332084656, 54.72391113638878, 53.75824615359306, 56.008572801947594, 55.89496649801731, 50.27980640530586, 43.66978369653225, 39.91718485951424, 39.624889343976974, 37.88519449532032, 39.77431632578373, 38.834033980965614, 38.41924823820591, 41.161682680249214, 37.76029519736767, 37.99426384270191, 42.71104194223881, 47.662978023290634, 50.41269287467003, 52.64398634433746, 49.51012350618839, 49.20640580356121, 52.38194100558758, 52.535030990839005, 47.84142404794693, 43.205801993608475, 41.49157717823982, 41.54246024787426, 47.26624511182308, 47.54595950245857, 49.975096955895424, 50.31460113823414, 47.013323083519936, 49.977129846811295, 47.01797403395176, 46.876891404390335, 44.22205366194248, 31.74096219241619, 20.178541727364063, 9.598492048680782, 3.756044777110219, 5.789241576567292, 3.740516435354948, 4.637895757332444, 9.091335162520409, 7.610012674704194, 11.448975652456284, 11.161125898361206, 10.254410952329636, 2.2525426419451833, 1.0417118459008634, 0.25886286108288914, 1.0025876015424728, 9.772782046347857, 32.62983329594135, 40.373658165335655, 29.660057052969933, 39.21576909720898, 12.874697148799896, 0.26996675587724894, 0.20625848381314427, 0.21602906577754766, 0.116608499083668, 0.19250106968684122, 0.19117421354167163, 0.10053110163426027, 0.18262283178046346, 0.1447633554926142, 0.17833450954640284, 0.18545385799370706, 0.1331276525161229, 0.10190485409111716, 0.1441225258167833, 0.11914385366253555, 0.13247264781966805, 0.11304359271889552, 0.27806756494101137, 0.11249011382460594, 0.17614018666790798, 0.15026871085865423, 0.1057235526968725, 0.15726800949778408, 0.14319374284241349, 0.11993438194622286], [0.04823018854949623, 0.02660760652361205, 0.035110501921735704, 0.0730266486061737, 0.060280544275883585, 0.026808507755049504, 0.01249256534720189, 0.015810524855623953, 0.016343668903573416, 0.02852190224075457, 0.03222705039661378, 0.07180286935181357, 0.03666593212983571, 0.01920011367474217, 0.022362043127941433, 0.03664274743641727, 0.019343131098139565, 0.046691683019162156, 0.11692374115227722, 0.021830270197824575, 0.02858537256543059, 0.04776008252520114, 0.04764900899317581, 0.0438738373486558, 0.021378617675509304, 0.07038306663162075, 0.024533042160328478, 0.05131034631631337, 0.01113166224968154, 0.019836047031276394, 0.006798042104492197, 1.738147975411266, 17.84084066748619, 33.28128173947334, 27.302369065582752, 28.00023391842842, 38.940675258636475, 31.539012528955936, 12.390634473413229, 0.6704320467542857, 0.13362676167162135, 0.5284292728174478, 2.4657097784802318, 5.95972940325737, 5.347025580704212, 3.3572236401960254, 6.688150316476822, 1.2788408529013395, 0.9691691666375846, 0.2351681044092402, 6.465867469087243, 17.623144648969173, 31.129681393504143, 46.81041017174721, 54.096040427684784, 52.6907542347908, 51.24178558588028, 51.45953290164471, 51.24650873243809, 52.481453865766525, 48.86111833155155, 53.24454791843891, 55.018087550997734, 53.73528778553009, 52.99518249928951, 57.162605077028275, 53.322318345308304, 51.50605760514736, 41.47499106824398, 41.393135860562325, 48.22013072669506, 52.81009063124657, 50.711698830127716, 51.443737149238586, 51.80717624723911, 49.20283019542694, 53.31387519836426, 51.4834526181221, 48.81621614098549, 40.12610524892807, 36.74485668540001, 38.17065417766571, 36.58645458519459, 39.85186256468296, 40.23730248212814, 45.21292269229889, 48.57991062104702, 51.01459197700024, 48.55344124138355, 49.7877062112093, 40.12333519756794, 44.28777493536472, 53.78712460398674, 50.53785055875778, 50.18304839730263, 51.15612678229809, 51.261289939284325, 49.57957237958908, 43.65900747478008, 36.76574036478996, 35.525923892855644, 35.14502093195915, 36.40045456588268, 34.90638613700867, 37.06359498202801, 35.565190985798836, 36.46774135529995, 36.6354301571846, 35.937559604644775, 40.663198828697205, 43.51642772555351, 47.603758201003075, 48.849141374230385, 49.90787096321583, 48.548854887485504, 47.457834631204605, 44.55852560698986, 43.94470274448395, 42.31302849948406, 42.34897077083588, 42.074469700455666, 47.0049749314785, 46.090607196092606, 47.742762342095375, 45.522131100296974, 44.45642128586769, 45.3028866648674, 40.018422827124596, 37.74305932223797, 21.55694056302309, 9.428020846098661, 4.686491349712014, 1.3813947374001145, 2.8967346623539925, 2.7663154480978847, 2.8261164017021656, 6.3890650402754545, 4.512720499187708, 5.573640670627356, 2.196506573818624, 2.4657722376286983, 0.2003411325858906, 0.05619396746624261, 1.1514784558676183, 5.304913865402341, 18.623475171625614, 26.968828663229942, 26.942076198756695, 25.22186290472746, 19.73384588956833, 1.8523757834918797, 0.09927525417879224, 0.0412217911798507, 0.041017704279511236, 0.07064479985274374, 0.013052041722403374, 0.01758221689669881, 0.018442121145199053, 0.033840067553683184, 0.04036861450003926, 0.01412270292348694, 0.06846569100162014, 0.04917961807223037, 0.07881595709477551, 0.029857708686904516, 0.027282998016744386, 0.023176490831247065, 0.046500231183017604, 0.03772951509745326, 0.1467245549429208, 0.04625734109140467, 0.03551857553247828, 0.031124753295443952, 0.012422950039763236, 0.043866167252417654, 0.10374252306064591, 0.05663674390234519, 0.047582865081494674, 0.05400763751822524, 0.05732360157708172, 0.04838278895476833, 0.011416775905672694, 0.06466947204899043, 0.03418510314077139, 0.026456822524778545, 0.03417172592889983, 0.031136115576373413, 0.03911400643119123, 0.035030082799494267, 0.05038659510319121, 0.015564016794087365, 0.06461317272624001, 0.04295923310564831, 0.05093336869322229, 0.02770652499748394, 0.028722929637297057, 0.0155560414896172, 0.1473152154358104, 0.047256379475584254, 0.09187481729895808, 0.02963301605632296, 0.03901193143974524, 0.04919406768749468, 0.024942652016761713, 0.05019566277042031, 0.04928009744617157, 0.05160973239981104, 2.8161160508170724, 25.32906085252762, 38.173086047172546, 33.28693583607674, 34.0579866617918, 46.94558411836624, 35.14828495681286, 10.994992163032293, 0.5532036465592682, 0.16978315747110173, 0.17632075119763613, 2.3164013028144836, 2.6977490773424506, 4.6806862112134695, 6.0430798307061195, 5.07937696762383, 2.6271445909515023, 1.790946142282337, 0.4743899975437671, 7.798691550269723, 19.729801006615162, 33.72236207127571, 48.21873240172863, 56.11745975911617, 53.92123080790043, 52.95537203550339, 52.8556539863348, 53.64854224026203, 53.44185993075371, 51.12213380634785, 54.25562806427479, 56.98035545647144, 55.265062898397446, 55.71644827723503, 57.727342173457146, 54.30205017328262, 52.93738380074501, 43.19624550640583, 42.61595204472542, 50.667723789811134, 54.493597894907, 52.31555476784706, 53.68778273463249, 50.98216451704502, 51.411955654621124, 54.027438908815384, 53.08712616562843, 50.637025237083435, 41.65540538728237, 39.11071613430977, 39.25497159361839, 39.164137467741966, 40.85843615233898, 44.355570897459984, 47.31499269604683, 50.07603473961353, 52.75742165744305, 50.893560871481895, 52.04171106219292, 43.41018162667751, 47.10706025362015, 53.56220327317715, 51.61296106874943, 51.55318647623062, 52.77664862573147, 52.6199222356081, 50.763235464692116, 45.36918930709362, 37.60637305676937, 37.34992861747742, 37.38681323826313, 39.855715557932854, 37.206695303320885, 38.18735808134079, 37.51393921673298, 36.9810938090086, 37.698062136769295, 37.23422482609749, 41.7084239423275, 45.830400958657265, 48.99861395359039, 50.152767822146416, 49.60204057395458, 50.2482832968235, 49.89771030843258, 46.83472886681557, 45.927884727716446, 43.03318865597248, 42.62501075863838, 44.30711209774017, 47.10315406322479, 48.33631329238415, 49.53556314110756, 46.70898601412773, 45.766199603676796, 48.025683760643005, 44.4815531373024, 39.88597333431244, 23.722991533577442, 12.303679939359426, 5.833475477993488, 2.5919043319299817, 4.136408166959882, 3.215914210304618, 3.686646013520658, 7.241231063380837, 6.532450821250677, 9.011929873377085, 2.5039893994107842, 0.814106612233445, 0.21456875663716346, 0.02868773884983966, 0.7184051256626844, 5.502224452793598, 21.36792540550232, 33.147870898246765, 27.55028296262026, 28.559307418763638, 25.04350047558546, 3.0352253559976816, 0.019017254053323995, 0.05244297499302775, 0.037852852619835176, 0.01764153490512399, 0.032692770328139886, 0.032370025146519765, 0.030238543622544967, 0.04524377887719311, 0.03525406296830624, 0.004351592642706237, 0.020016756279801484, 0.05553840244829189, 0.06733967486070469, 0.03156637569190934, 0.010148565197596326, 0.028133673658885527, 0.046064579364610836, 0.07974560096045025, 0.05777952515927609, 0.02250088597065769, 0.014418538758036448, 0.05836119824380148, 0.05998536245897412, 0.014595703323720954, 0.04782424119184725, 0.1876413234276697, 0.14929799654055387, 0.16097383486339822, 0.14614873740356416, 0.1356054312782362, 0.08676086319610476, 0.10557452202192508, 0.1135625023744069, 0.1439749274868518, 0.1422899850877002, 0.12733642186503857, 0.15683998324675485, 0.09238510319846682, 0.17757940397132188, 0.13700595300178975, 0.1128996309125796, 0.1265505765331909, 0.21826405834872276, 0.1590855440008454, 0.17173337313579395, 0.1224391303549055, 0.28411449515260756, 0.15435224486282095, 0.15230114164296538, 0.1109519533929415, 0.10749782741186209, 0.13406195706920698, 0.1265230873832479, 0.15073316171765327, 0.19679611577885225, 0.197759794536978, 3.348032170906663, 29.668950475752354, 46.21597766876221, 38.99725802242756, 39.113904163241386, 48.48075874149799, 38.6621730029583, 14.54898800700903, 1.3367520016618073, 0.42195423622615635, 1.5270328475162387, 7.4616824090480804, 12.195041868835688, 13.261339701712132, 12.364579271525145, 14.514280669391155, 4.807011382654309, 1.8028317857533693, 0.9756655711680651, 7.753020375967026, 21.004571802914143, 34.1460545361042, 50.863037109375, 57.552768141031265, 57.64784663915634, 54.353415817022324, 56.053395196795464, 55.85986778140068, 57.015001997351646, 51.44653379917145, 56.42328254878521, 59.194409251213074, 57.88507930934429, 56.90186306834221, 58.77983629703522, 56.68705679476261, 56.88961632549763, 46.07907861471176, 43.3494570851326, 51.13311141729355, 57.10213892161846, 54.36542697250843, 54.24341931939125, 52.1955344080925, 51.29414677619934, 54.12036672234535, 55.85858725011349, 53.14125046133995, 43.28778259456158, 39.86377872526646, 41.75367571413517, 41.05194456875324, 42.85014487802982, 45.47179140150547, 50.03452196717262, 51.75620198249817, 56.21508412063122, 52.84745782613754, 52.82179780304432, 45.365017130970955, 45.51676198840141, 53.01967218518257, 53.375656083226204, 52.523411214351654, 54.99151937663555, 54.07223470509052, 55.454950109124184, 47.682083398103714, 40.85897572338581, 38.90610471367836, 39.49721239507198, 40.54490737617016, 38.415832221508026, 40.70599593222141, 40.1822966337204, 39.22708868980408, 40.76578952372074, 39.536840468645096, 44.38579447567463, 47.101501151919365, 51.47858887910843, 51.19823232293129, 49.27288703620434, 51.20957471430302, 52.677215561270714, 48.92268642783165, 48.16379874944687, 46.3654350489378, 45.32135747373104, 46.069092750549316, 49.64109867811203, 49.69694048166275, 50.018513426184654, 48.81546378135681, 47.49557040631771, 48.65413583815098, 47.57818177342415, 38.19849148392677, 24.36641290783882, 11.040888000279665, 7.106068516150117, 3.626250154338777, 6.413298714905977, 6.688072420656681, 8.962405230849981, 13.385747876018286, 11.946324314922094, 14.210099391639233, 9.458760246634483, 5.77144855633378, 0.6657492730300874, 0.0916571899142582, 1.6762749454937875, 7.335649821907282, 24.945285245776176, 34.917128160595894, 34.22919027507305, 36.04458846151829, 28.8809734582901, 2.9646930657327175, 0.1663729443680495, 0.25177024479489774, 0.10339113840018399, 0.09978729154681787, 0.16596271481830627, 0.18110942939529195, 0.12146737703005783, 0.09647098238929175, 0.14104746660450473, 0.07393972773570567, 0.1262669573770836, 0.17354725627228618, 0.1680882999789901, 0.10717171287979, 0.06914337573107332, 0.11300201018457301, 0.17916700628120452, 0.2232865575933829, 0.17569797055330127, 0.12327962002018467, 0.113174730213359, 0.08779782161582261, 0.16425595327746123, 0.16288390033878386, 0.14483301347354427], [0.0930505944415927, 0.030016144228284247, 0.008849430123518687, 0.06662245592451654, 0.05877047784451861, 0.08195357193471864, 0.024500469298800454, 0.04807650089787785, 0.03410961558984127, 0.014396794758795295, 0.09475878090597689, 0.02727051694819238, 0.02574824589828495, 0.020730338692374062, 0.052665500552393496, 0.09546589179080911, 0.03191007912391797, 0.04669794303481467, 0.03339925409818534, 0.04294475009373855, 0.030941496625018772, 0.012917570129502565, 0.06752476649126038, 0.07047423205222003, 0.03593296481994912, 0.05874000155017711, 0.03982668713433668, 0.04972920440195594, 0.016054440966399852, 0.021990336608723737, 0.08311476587550715, 0.12332945523667149, 5.816562585532665, 26.593042127788067, 25.267601050436497, 19.206527285277843, 28.449430614709854, 36.17280878126621, 28.286236971616745, 8.084556385874748, 0.7877543731592596, 0.10733591305324808, 2.2179215122014284, 2.6376771507784724, 3.8175715506076813, 3.743860968388617, 3.418333623558283, 2.3979613138362765, 1.8014637404121459, 0.3569920314475894, 0.5952382972463965, 8.790005631744862, 18.61881472170353, 35.86564086377621, 44.712489545345306, 54.89288426935673, 50.415253937244415, 54.27360109984875, 54.9129243940115, 51.589573323726654, 53.87942925095558, 54.01174195110798, 54.42144736647606, 57.90098525583744, 52.772434651851654, 54.22698900103569, 55.27783401310444, 48.00666198134422, 45.510708913207054, 42.03923039138317, 51.6343729197979, 51.714856401085854, 55.62127858400345, 43.571422174572945, 48.569719567894936, 51.09444849193096, 54.24764469265938, 54.17189955711365, 50.95022723078728, 42.69187957048416, 36.75067417323589, 38.78517620265484, 38.91406148672104, 39.99497048556805, 41.74894876778126, 44.76670503616333, 49.775364473462105, 50.79277887940407, 54.87838804721832, 48.29422675073147, 38.2641975581646, 50.89549496769905, 51.09031431376934, 54.04842518270016, 52.900415584445, 52.67028473317623, 52.09295891225338, 49.534256011247635, 48.017795383930206, 38.524855971336365, 35.28480403125286, 36.21669642627239, 36.730413660407066, 36.5776314586401, 37.33570598065853, 37.2778844833374, 40.23406885564327, 40.57813659310341, 41.82361476123333, 41.36095158755779, 44.83857437968254, 47.14468963444233, 50.95095679163933, 48.36581490933895, 48.65442842245102, 48.23179230093956, 48.01371440291405, 48.78454104065895, 48.75032767653465, 45.835340693593025, 46.16487801074982, 42.930993139743805, 49.58981283009052, 47.24454067647457, 48.278712183237076, 39.93931487202644, 41.229710429906845, 38.84269371628761, 27.872370779514313, 10.500982571393251, 4.5289684273302555, 1.333648043219, 1.577729252167046, 2.963580912910402, 1.615116752218455, 3.4297047508880496, 3.666283143684268, 3.8947617961093783, 6.6406884882599115, 1.5347148478031158, 0.4500339872902259, 0.08108919253572822, 0.5203348759096116, 4.360938118770719, 16.99060209095478, 27.589779943227768, 29.295006841421127, 27.15519916266203, 22.6348078250885, 7.292061410844326, 0.1836200852994807, 0.06448508545872755, 0.06949738759431057, 0.015675802787882276, 0.06386285400367342, 0.033656400846666656, 0.03092719729465898, 0.034455972199793905, 0.03299697666079737, 0.03203611806384288, 0.02218922476458829, 0.030277819932962302, 0.07653376393136568, 0.11359698255546391, 0.06655899487668648, 0.011517723760334775, 0.046087864247965626, 0.026778580649988726, 0.03079821944993455, 0.03044622437300859, 0.018932597267848905, 0.024432635145785753, 0.013461683120112866, 0.04938275131280534, 0.011432976061769295, 0.05621714844892267, 0.014647452353528934, 0.02935133576102089, 0.023196781148726586, 0.025816295274125878, 0.03301484386611264, 0.03138552914606407, 0.058898910210700706, 0.014352973721543094, 0.017408524654456414, 0.05675875298038591, 0.035650403224281035, 0.048702461645007133, 0.057152013323502615, 0.012432865132723236, 0.016620361966488417, 0.06668730478850193, 0.037582644072244875, 0.01947139091498684, 0.04860378940065857, 0.0248325488428236, 0.04939510065014474, 0.06523779389681295, 0.04990036220988259, 0.047789293457753956, 0.0176528860538383, 0.06694670766592026, 0.04651499250030611, 0.04200243034574669, 0.05114747829793487, 0.04597591869242024, 0.0049626227701082826, 0.4021543002454564, 10.001943949609995, 33.54435682296753, 31.2912430241704, 22.973477952182293, 34.2195425927639, 44.949068650603294, 31.286607272922993, 7.141009541228414, 0.4128288774518296, 0.12875327083747834, 0.5303395609371364, 2.600890137255192, 2.1697125490754843, 6.351487431675196, 5.286184195429087, 3.7034969218075275, 2.8146018320694566, 2.046969160437584, 1.5832710172981024, 9.663592055439949, 22.243111543357372, 37.27963238954544, 49.45290617644787, 54.524482637643814, 53.11432130634785, 56.034821793437004, 56.01176083087921, 54.45579752326012, 54.696176424622536, 55.61008058488369, 56.60921037197113, 57.72938646376133, 54.202347323298454, 55.200432166457176, 54.91349816322327, 49.404530972242355, 47.0926134288311, 43.646935522556305, 51.79815553128719, 53.54648731648922, 54.86342824995518, 44.55610893666744, 47.831738367676735, 51.666184812784195, 54.16312202811241, 55.76507046818733, 52.895532846450806, 43.776694759726524, 38.53700011968613, 40.41905052959919, 40.71538522839546, 42.02376902103424, 43.5010689496994, 47.26706966757774, 51.95502631366253, 51.62749908864498, 57.6448941975832, 48.9800139516592, 42.546343579888344, 50.21392174065113, 51.10549829900265, 55.17554730176926, 52.99111671745777, 54.36441242694855, 53.57364445924759, 51.1894965916872, 48.35568465292454, 40.71648716926575, 36.60684049129486, 37.960882633924484, 40.01934617757797, 38.581127151846886, 38.43123659491539, 38.165281265974045, 40.609731897711754, 41.24352268874645, 41.992671489715576, 42.14058615267277, 47.765108942985535, 48.068036288022995, 52.23748415708542, 49.477977231144905, 49.209943413734436, 49.814973548054695, 50.074321031570435, 49.580503329634666, 49.177390560507774, 47.377655133605, 46.989809945225716, 47.15198904275894, 48.526664078235626, 49.26887445151806, 47.86160856485367, 44.14056323468685, 46.66765943169594, 42.11499832570553, 28.78340609371662, 13.71084988117218, 5.732361003756523, 3.5194096248596907, 3.4364325273782015, 3.751546056009829, 4.074550811201334, 3.920110948383808, 6.621636785566807, 5.59274367056787, 7.875945204868913, 1.2744879489764571, 0.21039156359620392, 0.12076214377884753, 0.3623942728154361, 4.38073743134737, 18.775816597044468, 32.702363803982735, 30.972369834780693, 30.087019242346287, 29.221024811267853, 10.683028902858496, 0.4735744366189465, 0.09443405419006012, 0.0916756471269764, 0.005564010543821496, 0.021457982948049903, 0.03343017197039444, 0.061325777642196044, 0.027291259975754656, 0.020199120517645497, 0.03880274227412883, 0.023037981954985298, 0.01392786689393688, 0.06718205753713846, 0.05124167168105487, 0.031569615166517906, 0.03088861303695012, 0.02912085623393068, 0.0684052133874502, 0.015127299066080013, 0.05122848742757924, 0.013692643187823705, 0.04289076627173927, 0.05976681110041682, 0.021525063821172807, 0.01815822924982058, 0.01939762514666654, 0.19796634907834232, 0.09253632320906036, 0.11487048570415936, 0.10631752316839993, 0.21982230129651725, 0.19516079337336123, 0.15023823827505112, 0.21854442689800635, 0.2446365135256201, 0.16791506786830723, 0.23221512848977, 0.07766521259327419, 0.14643740316387266, 0.10484947342774831, 0.17259479878703132, 0.24978030938655138, 0.17276895116083324, 0.14993845514254645, 0.2801431738771498, 0.1261383283417672, 0.11030511232092977, 0.1012971687305253, 0.14732358686160296, 0.1335944188758731, 0.09441915186471306, 0.1871084317099303, 0.12438729027053341, 0.1358129209256731, 0.15568068920401856, 0.1395180041436106, 0.20359078946057707, 0.5372005677781999, 10.645057540386915, 37.68642336130142, 39.83764372766018, 29.727364741265774, 37.34088510274887, 47.316854596138, 34.798114746809006, 9.43331491202116, 0.9333503886591643, 0.25866619194857776, 4.559201505035162, 7.2035465855151415, 10.427465066313744, 12.633601035922766, 10.75825346633792, 6.628721980378032, 6.729121142998338, 2.40881091915071, 1.0053299856372178, 10.49009520560503, 20.399809554219246, 37.042395919561386, 49.51273016631603, 58.09268496930599, 56.28115497529507, 57.73401841521263, 57.78180085122585, 55.68750523030758, 58.25163044035435, 57.62532904744148, 57.66579307615757, 59.382396563887596, 55.156654715538025, 56.74777373671532, 57.94127069413662, 51.2732744961977, 50.50885811448097, 45.76702035963535, 55.2332928031683, 54.67278108000755, 57.430175319314, 44.40053388476372, 50.03820016980171, 51.90460681915283, 54.58296909928322, 56.73724450170994, 54.906867519021034, 47.53222703933716, 39.851702973246574, 43.357531651854515, 42.3863759636879, 45.723296105861664, 46.42986819148064, 49.97619889676571, 53.094091191887856, 55.675608068704605, 59.442258551716805, 50.8426284044981, 43.679305985569954, 51.75092026591301, 51.32980026304722, 57.222588658332825, 56.18302144110203, 57.61369787156582, 54.91408713161945, 53.323819264769554, 51.58512756228447, 43.38042162358761, 39.059646874666214, 39.45436969399452, 41.43714129924774, 40.728593319654465, 40.74626237154007, 40.74168361723423, 44.91865888237953, 44.70157653093338, 46.10053226351738, 43.76805022358894, 51.214487850666046, 50.58663614094257, 54.80122558772564, 49.97772641479969, 48.30366164445877, 51.44172325730324, 52.778233140707016, 52.851979583501816, 52.42623522877693, 48.82975481450558, 49.784453585743904, 47.19480134546757, 51.49089261889458, 50.02831690013409, 48.714013025164604, 46.697199046611786, 49.13460485637188, 42.01852150261402, 31.377251408994198, 12.228979747742414, 6.431221403181553, 3.3701448468491435, 4.528831159695983, 7.171093951910734, 4.356675697490573, 6.6505237855017185, 9.910712745040655, 11.79813701659441, 16.07790056616068, 4.9433703906834126, 1.832763492129743, 0.43437286047264934, 0.7952636014670134, 5.578453112393618, 22.486708872020245, 36.09949171543121, 37.03114852309227, 37.109830901026726, 34.64106537401676, 11.76443187519908, 0.5313933512661606, 0.18469052942236885, 0.17492797749582678, 0.07765030284645036, 0.2007017272990197, 0.10020852714660577, 0.1256736251525581, 0.14604856231017038, 0.2125852630706504, 0.1448867449653335, 0.11210358105017804, 0.1389907527482137, 0.22430508106481284, 0.31826002697926015, 0.2025574675644748, 0.09557156619848683, 0.13544857094530016, 0.2053335154778324, 0.12594482075655833, 0.12263412965694442, 0.12545240577310324, 0.16435819154139608, 0.19729463121620938, 0.12751299364026636, 0.11317478216369636, 0.11598882803809829], [0.02782067658699816, 0.00988951484032441, 0.024816501754685305, 0.024078085225482937, 0.04386978893307969, 0.006214670893314178, 0.05955862383416388, 0.04217571440676693, 0.014523400514008244, 0.0461435104807606, 0.053359219382400624, 0.020683440525317565, 0.053934257666696794, 0.029107341724738944, 0.013104622885293793, 0.014597412118746433, 0.00532349532477383, 0.003817198539763922, 0.07650790008483455, 0.019703731377376243, 0.0935698529065121, 0.05531595481443219, 0.07177560284617357, 0.02775152141111903, 0.02497174977179384, 0.038595378791796975, 0.039507081237388775, 0.010267126071994426, 0.009054744350578403, 0.061954914781381376, 0.0022787969101045746, 0.06813309752033092, 0.3137667087139562, 10.973687656223774, 31.819435581564903, 26.522952988743782, 23.816337324678898, 34.57223206758499, 39.760025292634964, 26.443795636296272, 6.797832855954766, 0.2654498670017347, 0.06323901208816096, 1.2308640335686505, 0.7300281675998122, 4.821795914322138, 3.083311775699258, 2.6457643043249846, 2.5912533793598413, 1.7319828062318265, 1.2107796175405383, 0.9914300939999521, 7.794143194332719, 19.142375327646732, 33.71483847498894, 44.87929679453373, 54.61097739636898, 50.34834712743759, 56.514861434698105, 53.44869576394558, 57.50916168093681, 54.04148295521736, 57.558882012963295, 53.70788365602493, 57.06586606800556, 52.92542964220047, 53.3537844568491, 49.07617159187794, 46.556496396660805, 44.2338178306818, 50.91735899448395, 51.156115382909775, 57.002747654914856, 53.08197744190693, 49.38074804842472, 53.33171144127846, 55.86500510573387, 52.24671006202698, 50.4654910415411, 42.07504726946354, 38.71166154742241, 36.83696374297142, 38.612589463591576, 40.36064766347408, 40.70562735199928, 43.212953209877014, 51.07443116605282, 48.615537509322166, 54.1520494222641, 48.622593730688095, 41.7767708748579, 52.825935781002045, 52.354145497083664, 53.35826821625233, 50.41970729827881, 50.47481954097748, 50.06965108215809, 46.882944479584694, 44.739840477705, 38.18654492497444, 36.101319417357445, 36.21136151254177, 35.884651243686676, 37.371443063020706, 40.226894840598106, 42.88258373737335, 46.60101480782032, 45.92473849654198, 47.48709686100483, 46.09797120094299, 46.910789385437965, 47.71482244133949, 51.20230570435524, 51.17579072713852, 45.462113320827484, 49.460270181298256, 50.12580826878548, 48.807149827480316, 50.752010866999626, 48.56414906680584, 47.53335177898407, 47.60835975408554, 50.12418955564499, 44.48371522128582, 40.30294395983219, 41.99709065258503, 43.29831562936306, 29.993232674896717, 14.041032213717699, 7.433779081329703, 2.3740168986842036, 1.9859767332673073, 1.480964832007885, 2.7233281172811985, 2.6092209527269006, 2.2947438899427652, 6.072228541597724, 4.964113477617502, 6.2761602737009525, 1.370767776388675, 0.08447695567156188, 0.20314627268817276, 2.886761147528887, 14.631439782679081, 28.012868240475655, 27.132079303264618, 26.00092750042677, 28.851230554282665, 14.142367076128721, 1.4385038916952908, 0.04756871974677779, 0.07150114179239608, 0.06963803942198865, 0.023995402552827727, 0.047803327470319346, 0.09055501155671664, 0.046523286000592634, 0.02434610629279632, 0.07456643434124999, 0.036954059833078645, 0.026789595976879355, 0.023017261191853322, 0.02181639018090209, 0.025449735549045727, 0.07878525444539264, 0.05179691688681487, 0.016160998529812787, 0.05935051820415538, 0.061762524128425866, 0.038643369771307334, 0.0030032023869352997, 0.04970462076016702, 0.03648904494184535, 0.04328887654992286, 0.013112615815771278, 0.02907353875343688, 0.03974260180257261, 0.02362961651670048, 0.03474459343124181, 0.02998235053382814, 0.07134808867704123, 0.040462310644215904, 0.00830824397780816, 0.01303502984228544, 0.04974382471118588, 0.03401308073080145, 0.026919317824649625, 0.022039947325538378, 0.046820864954497665, 0.04558924490993377, 0.05046781574492343, 0.0310951304709306, 0.029365169393713586, 0.03914060871466063, 0.09909744301694445, 0.06345805697492324, 0.029846967954654247, 0.027791268985311035, 0.014226679668354336, 0.029070115597278345, 0.035700694861589, 0.025904575595632195, 0.01184689501315006, 0.03197781494236551, 0.047408482641913, 0.04602323802828323, 0.0673122525040526, 0.08991171795059927, 1.1755450582131743, 15.752137396484613, 36.51021167635918, 28.321252092719078, 24.596490561962128, 36.107159703969955, 45.4685577750206, 25.243210159242153, 5.934276944026351, 0.25273747101891786, 0.17892420524731278, 0.3522153018275276, 2.027368862181902, 5.62198500148952, 4.881059434264898, 4.524496542289853, 2.8823529090732336, 2.5954737653955817, 2.3714380245655775, 0.7814776443410665, 8.86859206482768, 23.06522972881794, 36.38729967176914, 50.6648663431406, 54.70921732485294, 52.84712724387646, 57.579222321510315, 55.62006264925003, 57.96617075800896, 56.03289149701595, 57.39456743001938, 55.96668004989624, 58.02548557519913, 55.012942627072334, 54.712006375193596, 50.9897755086422, 47.721092104911804, 46.2126300483942, 52.29573883116245, 53.7810867279768, 56.260985657572746, 51.59836985170841, 50.335857197642326, 52.59578973054886, 54.42481778562069, 54.302737936377525, 51.31841987371445, 43.410295620560646, 39.592963457107544, 38.938908353447914, 40.68252459168434, 43.22759382426739, 43.03498215973377, 45.624117627739906, 53.35368566215038, 52.17008717358112, 54.414094761013985, 51.281520053744316, 41.968026012182236, 53.59933488070965, 53.69277186691761, 54.563312754034996, 53.35856460034847, 51.83663226664066, 53.21854971349239, 50.89335188269615, 47.222463861107826, 40.81468529999256, 38.61440196633339, 38.632131814956665, 38.16979922354221, 38.884962648153305, 40.40827810764313, 45.03020569682121, 47.97139227390289, 48.08146856725216, 47.7643907815218, 48.47529463469982, 48.899579867720604, 49.130896255373955, 51.59214958548546, 51.85289919376373, 48.04173029959202, 48.96356463432312, 51.25100389122963, 49.83827009797096, 51.14862598478794, 49.47448521852493, 48.19430351257324, 48.087681233882904, 51.145996525883675, 46.410538628697395, 44.162742644548416, 43.412875682115555, 45.939907282590866, 32.8814709931612, 15.960568562150002, 8.57018742710352, 3.1982905184850097, 4.055678648874164, 3.2495789788663387, 3.635432361625135, 3.7710306979715824, 3.640640457160771, 5.671417498961091, 4.779646201059222, 3.9750785613432527, 0.3119965974474326, 0.03780375212954823, 0.33053173567168415, 3.4014245308935642, 15.089759789407253, 32.39190146327019, 31.596294455230236, 27.507328167557716, 32.524008974432945, 18.97646103054285, 2.6361479703336954, 0.04687385429861024, 0.06414985735318623, 0.012004227537545376, 0.01393631253449712, 0.04590161486703437, 0.05883148238353897, 0.0495099962427048, 0.03628110629506409, 0.014429218263103394, 0.03949978963646572, 0.017080803372664377, 0.06418410004698671, 0.049477879801997915, 0.02794249085127376, 0.07182600951637141, 0.03831269103102386, 0.015103554978850298, 0.039376967906719074, 0.007391271819869871, 0.017467078250774648, 0.006614318344873027, 0.024251879513030872, 0.061672264127992094, 0.036355313641251996, 0.02149445950635709, 0.06105494569055736, 0.33414231380447745, 0.06647313581197523, 0.08340015134308487, 0.20904462493490428, 0.1479229750111699, 0.12193891539936885, 0.20963887742254883, 0.25539673457387835, 0.16057981381891295, 0.14547265571309254, 0.130469324067235, 0.11907119740499184, 0.1371107145678252, 0.1282970726606436, 0.13427055993815884, 0.1423579064430669, 0.11214661819394678, 0.1994022267172113, 0.1921242367825471, 0.126526738749817, 0.24198731349315494, 0.2154414332471788, 0.13498692540451884, 0.08647178183309734, 0.10100321887875907, 0.12404835142660886, 0.11113029890111648, 0.14225802820874378, 0.11386330224922858, 0.08759770149481483, 0.1321930659469217, 0.10215669448371045, 1.2795694638043642, 16.98076631873846, 44.33371067047119, 38.9488410204649, 33.32765445113182, 43.062219098210335, 49.526941403746605, 31.53027679771185, 7.638363903388381, 0.8042723243124783, 0.2588072296930477, 4.18849197216332, 5.3045134618878365, 13.039002232253551, 8.650905545800924, 8.071262799203396, 7.411914579570293, 3.7758697383105755, 3.362841638736427, 1.473581709433347, 9.934536516666412, 21.731664687395096, 36.86103545129299, 49.34882216155529, 58.8653165102005, 56.31376102566719, 58.28929781913757, 55.92321798205376, 61.94573521614075, 57.10938513278961, 61.18313133716583, 56.526659801602364, 60.63809618353844, 56.54368668794632, 55.90778321027756, 52.56672888994217, 50.852477476000786, 48.63994739949703, 53.73156398534775, 54.88159127533436, 58.49273890256882, 51.380451545119286, 50.80224797129631, 53.717687129974365, 55.96567690372467, 56.62214107811451, 53.49835529923439, 46.8830356746912, 40.994449853897095, 41.6056052595377, 41.538744047284126, 47.06374637782574, 45.496801659464836, 48.49855698645115, 55.7779897749424, 54.40445467829704, 56.36791951954365, 53.194926381111145, 45.70134088397026, 53.47222790122032, 55.2496737241745, 56.878843903541565, 55.29414273798466, 54.05567519366741, 54.63372677564621, 51.82908207178116, 50.46894125640392, 43.62964265048504, 41.38172887265682, 40.859218910336494, 39.34334345161915, 41.26034438610077, 43.528374284505844, 47.08114944398403, 50.25132313370705, 49.86556023359299, 50.13060741126537, 50.527081936597824, 51.20890595018864, 51.52249552309513, 52.890524715185165, 51.45263247191906, 47.617608457803726, 49.23925504088402, 52.24892154335976, 52.32804089784622, 53.53207089006901, 53.18575747311115, 49.17533487081528, 50.654751285910606, 51.848734617233276, 48.891151919960976, 47.10479557514191, 46.11280180513859, 46.32270634174347, 33.92548777163029, 15.413868147879839, 9.972253292798996, 4.557211836799979, 4.862714493647218, 4.893618710339069, 6.8691773526370525, 7.713141515851021, 8.723076973110437, 12.767319660633802, 10.249453168362379, 9.612034521996975, 2.1818616846576333, 0.5553787923417985, 0.5318920151330531, 4.143237350508571, 18.74791469424963, 35.922140032052994, 35.51514767110348, 35.28589077293873, 38.52166034281254, 23.800264187157154, 2.7699608774855733, 0.1659762515919283, 0.16120057582156733, 0.15460111666470766, 0.12310002028243616, 0.11820289946626872, 0.28290286485571414, 0.22573159280000255, 0.17209013836691156, 0.09304287610575557, 0.07996307249413803, 0.11769881792133674, 0.18021680385572836, 0.23565100505948067, 0.1679951456026174, 0.11452749473392032, 0.1164606113161426, 0.08920409498387016, 0.1745836655027233, 0.13691524771275, 0.13812711549689993, 0.13564696186222136, 0.15643779857782647, 0.19772250903770328, 0.13614437892101705, 0.08207385180867277, 0.2295780848362483], [0.032306493594660424, 0.04813871142687276, 0.04789129794517066, 0.03591134234739002, 0.1023445840110071, 0.035719222578336485, 0.04100577425560914, 0.061758230804116465, 0.042950839415425435, 0.05851518646522891, 0.013072883084532805, 0.05179493535251822, 0.05231060553342104, 0.047919173011905514, 0.0215900666808011, 0.03117982436378952, 0.052427642222028226, 0.012697074344032444, 0.0604448483500164, 0.06600844746571966, 0.06412842412828468, 0.05648319725878537, 0.07528043977799825, 0.03664886644401122, 0.05469305171573069, 0.07983960138517432, 0.01736617399728857, 0.0346047876519151, 0.040460073068970814, 0.06686703069135547, 0.015445724020537455, 0.02042472598986933, 0.11613448194111697, 2.1237886883318424, 16.874710209667683, 26.799542047083378, 25.531151108443737, 22.137705199420452, 34.87182319164276, 39.16095323860645, 21.06799989938736, 6.657510185614228, 0.6679460301529616, 0.3839641122613102, 0.6771879061125219, 3.492066292092204, 5.19567352719605, 2.6105401944369078, 1.5736933937296271, 4.005086738616228, 2.0282641891390085, 0.24842050188453868, 0.9509182116016746, 4.619891373440623, 17.604314759373665, 30.059867799282074, 42.387550100684166, 50.808460637927055, 52.14630424976349, 56.676580756902695, 54.835461750626564, 52.33532890677452, 52.33903370797634, 56.52493469417095, 53.39072607457638, 53.74458208680153, 49.6348100155592, 46.66485138237476, 47.27684274315834, 48.87235052883625, 52.27231688797474, 54.89932872354984, 53.26337970793247, 50.286000072956085, 51.14922255277634, 55.37122920155525, 50.518532395362854, 53.771625235676765, 51.28546044230461, 40.22692523896694, 37.1309919655323, 37.846660763025284, 40.9268818795681, 40.048623606562614, 41.99301727116108, 45.2440620213747, 48.791293278336525, 50.476616844534874, 53.017582297325134, 51.23630627989769, 40.60237929224968, 54.54578809440136, 52.78897136449814, 51.93272531032562, 49.48711194097996, 48.74826438724995, 46.993890926241875, 45.54244101047516, 42.40270368754864, 38.45965526998043, 35.67776374518871, 36.08160227537155, 35.1141931861639, 39.104822650551796, 42.750031650066376, 46.769805550575256, 49.169912561774254, 50.801712200045586, 48.87494578957558, 48.25671896338463, 48.91525782644749, 50.583429113030434, 51.701986491680145, 46.154071390628815, 47.074712589383125, 49.92984898388386, 49.21929091215134, 48.160211741924286, 47.23640911281109, 48.5401913523674, 48.300355821847916, 49.95587758719921, 44.93163898587227, 42.98616237938404, 43.187236189842224, 47.98555411398411, 37.35371321439743, 25.994122065603733, 7.124855183064938, 2.990898359566927, 1.5124957775697112, 4.245790047571063, 3.51850978564471, 2.2713988926261663, 3.3830803027376533, 2.4906799010932446, 5.109694115817547, 4.05590046197176, 3.323312122374773, 0.5632746499031782, 0.09463335052714683, 2.6087143924087286, 10.385432671755552, 26.306609697639942, 27.68812246620655, 24.012431502342224, 29.33380275964737, 25.389901287853718, 5.2445142064243555, 0.01413727035469492, 0.03173288765538018, 0.028629478401853703, 0.02168183880712604, 0.0034710701402218547, 0.029806663769704755, 0.024640150768391322, 0.015480632791877724, 0.01627217781788204, 0.005308586969476892, 0.043028954169130884, 0.05189945200982038, 0.022906198792043142, 0.051012177355005406, 0.09091856743907556, 0.0024606237866464653, 0.06773036366212182, 0.04813731247850228, 0.07551899572717957, 0.08487151106237434, 0.055182153009809554, 0.03137120569590479, 0.02426731247396674, 0.060153496015118435, 0.01452398124456522, 0.01777227906131884, 0.01819809927837923, 0.04110010122531094, 0.050617306551430374, 0.072272678517038, 0.06952299168915488, 0.07173266960307956, 0.03447368726483546, 0.015300278846552828, 0.10089235685882159, 0.01572404053149512, 0.047048314663697965, 0.01398175794747658, 0.03976504805905279, 0.019054628610319924, 0.03373816696694121, 0.04607170027156826, 0.04731700551928952, 0.05840037621965166, 0.08949172173743136, 0.046759170218138024, 0.06710822126478888, 0.045352633387665264, 0.031077268831722904, 0.01711260625597788, 0.001733404062633781, 0.04100752201338764, 0.019335429460625164, 0.026631911860022228, 0.06824858312029392, 0.025856157881207764, 0.05077758447441738, 0.03969917874201201, 0.024550664456910454, 0.009523386488581309, 3.78668918274343, 22.137064933776855, 33.09427857398987, 27.19289503991604, 26.102950125932693, 42.853944674134254, 47.73225210607052, 22.695454470813274, 5.404048170894384, 0.439179275999777, 0.1815460794023238, 0.693852921249345, 1.3418158236891031, 5.967419715598226, 4.667345127090812, 6.063408264890313, 4.7276516910642385, 2.7741069300100207, 1.019045824650675, 1.793865691870451, 7.521783309057355, 21.41181495040655, 34.34949941933155, 45.282747745513916, 52.367695569992065, 52.859301790595055, 57.45414823293686, 55.39484493434429, 52.85327151417732, 55.609939992427826, 58.700804337859154, 57.32848137617111, 56.83063969016075, 51.149435341358185, 48.517985343933105, 47.958016991615295, 51.7515966296196, 53.1821970641613, 56.230499893426895, 53.35846960544586, 51.12356252968311, 52.39857271313667, 54.708130583167076, 54.056013375520706, 53.76901477575302, 52.418126463890076, 42.088893726468086, 39.61629420518875, 41.31245478987694, 41.26790218055248, 41.62681192159653, 44.630862325429916, 45.982867777347565, 51.1733740568161, 52.07229182124138, 55.57542264461517, 51.6262299567461, 42.60800287127495, 54.50252361595631, 54.5490825176239, 53.90707276761532, 51.53943121433258, 50.10434702038765, 48.83948989212513, 47.750103548169136, 43.73112380504608, 40.74479565024376, 39.09666828811169, 38.498428389430046, 37.88712099194527, 40.31733378767967, 44.2266134172678, 49.10068787634373, 50.095083117485046, 51.100737154483795, 50.21669179201126, 49.280661419034004, 52.35373131930828, 50.641828179359436, 52.25938618183136, 48.16444471478462, 46.38230614364147, 49.65987727046013, 49.174270927906036, 49.05836574733257, 48.599817752838135, 48.88355612754822, 48.52488957345486, 50.391680002212524, 46.58329255878925, 45.16560383141041, 43.87920565903187, 50.590462535619736, 38.805410116910934, 28.524389192461967, 10.175991710275412, 4.5545700285583735, 3.328051893040538, 4.647044241428375, 3.816010309383273, 3.636459968984127, 7.176872491836548, 7.48354216106236, 6.700967978686094, 2.9739797674119473, 1.6097807697951794, 0.168583327322267, 0.08776399452472106, 1.9985238974913955, 9.890778064727783, 27.965308092534542, 32.942005544900894, 26.884881667792797, 30.13627029955387, 30.27163803577423, 8.069873973727226, 0.1167101065220777, 0.03187194015481509, 0.04882543180428911, 0.03829587025393266, 0.07141340509406291, 0.012875593329226831, 0.008323659312736709, 0.07357527385465801, 0.05242656981863547, 0.060210908559383824, 0.025585810180928092, 0.026201443943136837, 0.01777703066181857, 0.02659741869138088, 0.05365496523154434, 0.024069110804703087, 0.05438005093310494, 0.047405647637788206, 0.009122031169681577, 0.07553051385912113, 0.12066838084137999, 0.0645488136797212, 0.01610642470041057, 0.067848862381652, 0.01952443035406759, 0.03740484775335062, 0.05299485084833577, 0.15049145906232297, 0.12140658029238693, 0.18347251665545627, 0.0912651875114534, 0.30686936632264405, 0.15423854783875868, 0.11607314343564212, 0.22772716853069142, 0.10659558363840915, 0.12026359123410657, 0.10076512306113727, 0.12000557617284358, 0.1610264234477654, 0.09501994267338887, 0.08239086018875241, 0.19293320743599907, 0.1782389951404184, 0.14346783282235265, 0.1872630210709758, 0.1442592145758681, 0.09866315303952433, 0.1088983565568924, 0.07572347225504927, 0.14687371178297326, 0.09078394927200861, 0.1437955503934063, 0.09946951875463128, 0.1378219443722628, 0.12068821102729999, 0.20220479898853227, 0.11941771357669495, 0.17252208315767348, 0.168305036786478, 3.4670111490413547, 24.537610821425915, 39.33947905898094, 36.34582109749317, 31.133492588996887, 45.096588134765625, 47.54982769489288, 24.914113618433475, 7.736733024939895, 0.7498850708361715, 0.9501552244182676, 2.2161557944491506, 10.61395050957799, 12.785125505179167, 8.681865334510803, 5.075046150013804, 11.07114102691412, 6.307682432234287, 0.749710873933509, 1.569886829238385, 6.185792572796345, 18.872724696993828, 33.44936951994896, 44.33787144720554, 53.582524582743645, 54.628551453351974, 57.27391630411148, 55.862539038062096, 52.45578244328499, 55.86419954895973, 59.25403565168381, 57.399674355983734, 57.601173743605614, 53.90196204185486, 50.41119195520878, 51.300557032227516, 54.697787538170815, 55.31889460980892, 58.857010155916214, 54.87717591226101, 49.77893628180027, 51.62818305194378, 53.82874757051468, 56.78191490471363, 56.69512756168842, 55.56762546300888, 43.77254918217659, 41.69094108045101, 42.55640164017677, 44.01030622422695, 44.477236568927765, 47.20201335847378, 49.45381812751293, 52.908018976449966, 55.34127160906792, 56.67365871369839, 52.80031755566597, 46.04586459696293, 55.7879376411438, 57.24670596420765, 57.09142729640007, 55.08008882403374, 52.16153383255005, 51.56863644719124, 49.702613577246666, 46.38842761516571, 41.580777391791344, 40.149983167648315, 39.883963242173195, 39.48178142309189, 43.23123782873154, 46.542965322732925, 52.10979960858822, 53.01063247025013, 53.816523626446724, 53.61813627183437, 50.78699938952923, 53.768330812454224, 52.32736073434353, 53.33803050220013, 47.12021514773369, 48.45300503075123, 50.53283482789993, 50.501760095357895, 50.004621371626854, 50.16034461557865, 48.82687836885452, 49.617684334516525, 51.081658378243446, 49.50984612107277, 46.542706936597824, 46.472004130482674, 47.3178805410862, 38.92780154943466, 27.930532358586788, 10.092684030532837, 4.905900601297617, 3.8058745907619596, 8.05186104029417, 8.036159332841635, 6.73087427392602, 7.928676875308156, 6.5371164958924055, 11.28752326592803, 9.054619632661343, 4.531238805502653, 1.1689014709554613, 0.211229195992928, 3.3846581680700183, 13.240150138735771, 33.17906342446804, 37.47542068362236, 33.44664126634598, 38.653380274772644, 33.298479616642, 8.041966371238232, 0.21287278592353687, 0.3397389384917915, 0.21197321388171986, 0.15855315694352612, 0.19499185087624937, 0.16553811728954315, 0.14090555312577635, 0.12390657153446227, 0.14432075346121565, 0.19293350429506972, 0.12417551100952551, 0.23416117328451946, 0.14032801380380988, 0.09891520123346709, 0.25984279287513345, 0.16185417043743655, 0.2140760447946377, 0.0874671057681553, 0.13415993540547788, 0.2363378627342172, 0.10586299482383765, 0.1106794441875536, 0.11172179802088067, 0.19236311927670613, 0.1444456123863347, 0.14158084813971072, 0.15561889798846096], [0.03253134207625408, 0.07798711172654293, 0.0285161190549843, 0.05524503889319021, 0.02674978160939645, 0.03369584599568043, 0.04871697805356234, 0.007083379796313238, 0.0185193731522304, 0.02081162983813556, 0.04786067693203222, 0.05833267750858795, 0.06505643526907079, 0.02259146138385404, 0.015116348677111091, 0.0788897043094039, 0.05669325102644507, 0.03504633954435121, 0.04203529635560699, 0.015496557425649371, 0.04892558834399097, 0.0435905484482646, 0.03619790411903523, 0.04150949214817956, 0.05401317022915464, 0.0513638774282299, 0.02844134025508538, 0.05466018570587039, 0.06910533324116841, 0.07652908840100281, 0.021095694282848854, 0.03739077292266302, 0.1401835324941203, 0.03934937485610135, 4.187006726861, 21.663027070462704, 29.259822629392147, 25.90126644819975, 18.06798677891493, 31.20911993086338, 38.15280273556709, 18.149608299136162, 6.340274233371019, 0.5805153341498226, 0.2807005267823115, 0.8270360715687275, 3.681550011970103, 3.6180613562464714, 3.827428459189832, 1.1184402974322438, 2.7833684580400586, 0.999557264149189, 0.1885640950058587, 0.7313620741479099, 1.7872143862769008, 12.169649731367826, 23.391734808683395, 37.0857135951519, 49.37064819037914, 51.167229786515236, 50.95836639404297, 55.689431726932526, 57.92756102979183, 53.19658309221268, 51.35959826409817, 48.29128950834274, 46.29172660410404, 49.39768373966217, 50.70504918694496, 53.72035838663578, 51.779601126909256, 53.87703537940979, 53.10197576880455, 53.13189536333084, 57.47894190251827, 49.41634073853493, 52.698809802532196, 52.452735006809235, 45.56856840848923, 39.358166456222534, 38.27897496521473, 39.42007273435593, 38.868026956915855, 40.86177617311478, 42.952070608735085, 46.07767269015312, 52.242944464087486, 49.14329119026661, 54.49447564780712, 49.13130663335323, 39.97684545814991, 52.275759503245354, 52.68249727785587, 51.37964978814125, 48.94548520445824, 47.91024975478649, 43.63832138478756, 44.179925322532654, 38.627705052495, 38.08472938835621, 37.02180862426758, 38.63245479762554, 36.142942383885384, 43.84758375585079, 47.27475665509701, 50.81324838101864, 48.32526348531246, 51.061652451753616, 49.083904176950455, 50.20525060594082, 47.171645388007164, 51.9377676397562, 47.19052657485008, 46.194915398955345, 51.10353000462055, 48.676205053925514, 51.43424145877361, 49.956420958042145, 48.111118376255035, 50.2342164516449, 47.97256261110306, 45.927155166864395, 44.751376658678055, 44.914125725626945, 50.53062714636326, 39.729098752141, 26.07020728290081, 14.977639205753803, 5.500382026657462, 1.3114039180800319, 1.7378594283945858, 3.1235361797735095, 1.4381856587715447, 2.5163586856797338, 5.1014419086277485, 4.991282019764185, 4.0412764716893435, 3.3274997351691127, 2.049090634100139, 0.1714439206989482, 1.6852472140453756, 8.887549247592688, 23.188529312610626, 30.055355541408062, 24.95862253010273, 23.96282136440277, 27.64716826379299, 14.42830078303814, 0.4247934854356572, 0.032831351563800126, 0.057443703335593455, 0.016692704666638747, 0.12426155561115593, 0.026830714668903966, 0.048083161673275754, 0.023269762095878832, 0.04123655991861597, 0.026425676442158874, 0.06060271800379269, 0.016126651935337577, 0.03404934577702079, 0.017922981423907913, 0.07487259252229705, 0.0494486020761542, 0.0366582546121208, 0.06560258916579187, 0.013712993804801954, 0.07686137018026784, 0.0461031413578894, 0.045922291101305746, 0.012254659704922233, 0.05390399288444314, 0.03717157589562703, 0.022329993480525445, 0.06672651245025918, 0.049855718316393904, 0.0243924107417115, 0.05234777599980589, 0.06452202214859426, 0.040325050431420095, 0.018233089685963932, 0.05892961657082196, 0.022029906067473348, 0.04099488694919273, 0.06716424599289894, 0.07930854277219623, 0.019374054536456242, 0.06241187365958467, 0.030885226988175418, 0.0168319909425918, 0.04852869518799707, 0.04154933805693872, 0.06104405467340257, 0.04239098176185507, 0.06736079638358206, 0.0596708291413961, 0.052834903181064874, 0.0196919887457625, 0.013685027824976714, 0.017200272450281773, 0.02253701186418766, 0.007589071337861242, 0.03653874657175038, 0.03277050287579186, 0.047999655216699466, 0.08985568580101244, 0.06808942212956026, 0.037446508213179186, 0.06278308850596659, 0.017110847365984228, 7.471970357000828, 26.540532745420933, 34.049148336052895, 27.552990317344666, 22.39711157977581, 37.581370398402214, 40.79735442996025, 20.84555983543396, 5.217720894142985, 0.3768973523983732, 0.2550975600024685, 0.25546326069161296, 2.3244815692305565, 5.046511581167579, 8.92380690202117, 6.173456059768796, 3.7976974295452237, 3.6105011869221926, 1.5037092240527272, 1.9961955724284053, 4.186969203874469, 16.41126047819853, 27.95237548649311, 43.09913791716099, 50.97736917436123, 52.758432403206825, 52.79970198869705, 56.965676844120026, 57.091868072748184, 54.041786938905716, 53.48004788160324, 50.68053290247917, 49.03383046388626, 51.17610991001129, 51.78550221025944, 55.80765098333359, 54.19493392109871, 54.80107359588146, 54.063301384449005, 52.728144228458405, 56.81856393814087, 54.03616324067116, 54.30123321712017, 54.01552274823189, 48.39153192937374, 40.64696989953518, 40.868763998150826, 41.12140104174614, 42.29418531060219, 42.103906720876694, 44.436597749590874, 47.16390520334244, 53.27836610376835, 52.0206031948328, 55.39190389215946, 50.90160883963108, 42.158335000276566, 53.62932287156582, 53.93519125878811, 52.12768144905567, 50.51047682762146, 49.3175308406353, 47.41767838597298, 45.15240713953972, 40.34143969416618, 40.64581096172333, 38.058795779943466, 41.02625794708729, 37.659114226698875, 45.513144582509995, 48.73907268047333, 51.13511770963669, 49.4731704890728, 53.80334593355656, 50.82552172243595, 51.56747370958328, 49.29233059287071, 51.57674141228199, 49.81511414051056, 46.37191370129585, 51.92022018134594, 49.050006195902824, 52.05162093043327, 50.69920890033245, 48.3968136459589, 50.20888701081276, 49.6722038090229, 47.25274443626404, 46.59670203924179, 46.67170241475105, 51.61299526691437, 41.42605349421501, 28.192123621702194, 16.630094535648823, 7.595910206437111, 2.42048816755414, 3.5524600138887763, 4.638715088367462, 3.3857931196689606, 3.773071188479662, 7.974830623716116, 10.379751976579428, 5.89198948815465, 1.2783188559114933, 0.39604740450158715, 0.1342685561394319, 1.685256832279265, 9.470979440957308, 27.094166837632656, 32.65782259404659, 26.59057606011629, 24.895069040358067, 32.7320022135973, 18.183310590684414, 1.060982986818999, 0.03454352336120792, 0.020217195524310227, 0.025109468260779977, 0.025122583865595516, 0.04355008284619544, 0.0204580632635043, 0.034844404872274026, 0.03318471775855869, 0.10838287562364712, 0.01601462845428614, 0.04990044384612702, 0.027884844530490227, 0.06146340521809179, 0.10806807142216712, 0.026912031789834145, 0.018675302089832257, 0.0038861630764586153, 0.022942166979191825, 0.06253798681427725, 0.08072488708421588, 0.0764661468565464, 0.010928485407930566, 0.07671921921428293, 0.04541956397588365, 0.03884229503455572, 0.0696585449622944, 0.016853728448040783, 0.07278406279510818, 0.1702391923754476, 0.09106381316087209, 0.1859979412984103, 0.05290800101647619, 0.17469316197093576, 0.1663297216873616, 0.08140460529830307, 0.12474577728426084, 0.24325631180545315, 0.11960828225710429, 0.1046402619977016, 0.13596353237517178, 0.10803796249092557, 0.0959559838520363, 0.1466492417966947, 0.11348950472893193, 0.09800422980333678, 0.14117214741418138, 0.18740391038591042, 0.13898797711590305, 0.13606217864435166, 0.16230619774432853, 0.13453298335662112, 0.1037504269334022, 0.19081151112914085, 0.11730428479495458, 0.17845932394266129, 0.14988343231379986, 0.2036625551409088, 0.18934030726086348, 0.14101703854976222, 0.1658831862732768, 0.1184813013242092, 6.919960677623749, 32.206213027238846, 42.16816507279873, 35.85784748196602, 27.10298616439104, 40.861612781882286, 44.67804819345474, 23.045115508139133, 7.554839635267854, 0.9301519102882594, 0.8995228819549084, 3.695696177892387, 10.091548841446638, 9.984615929424763, 10.473436899483204, 5.0895703956484795, 7.0941761042922735, 3.5031317733228207, 0.7614184019621462, 1.7279965826310217, 3.2004590146243572, 14.95482712984085, 28.09094075113535, 42.46102675795555, 54.37075808644295, 54.771252796053886, 53.575209975242615, 57.433804124593735, 61.08880139887333, 57.62596741318703, 54.95931230485439, 53.554930463433266, 50.42102962732315, 54.914113730192184, 55.016518235206604, 58.76384675502777, 55.67002236843109, 56.327014714479446, 55.894601717591286, 53.547957837581635, 57.964042872190475, 55.88708572089672, 56.849011704325676, 54.78834807872772, 50.70724166929722, 42.100999876856804, 41.93644590675831, 45.16500346362591, 43.42128463089466, 44.465909376740456, 47.273544520139694, 51.08117960393429, 56.79644152522087, 53.915911093354225, 56.54834903776646, 52.92807810008526, 46.097587421536446, 52.59301207959652, 56.258728578686714, 53.55064429342747, 53.75310882925987, 52.61994503438473, 48.47302235662937, 47.93953478336334, 41.34755350649357, 43.01619216799736, 40.323759242892265, 43.05449791252613, 39.63307410478592, 48.70357118546963, 49.464582949876785, 53.487031906843185, 50.00539653003216, 54.150081127882004, 52.018452510237694, 53.094759956002235, 50.226309075951576, 53.043728694319725, 48.56863662600517, 49.12089139223099, 52.11303323507309, 51.88941903412342, 54.35821495950222, 52.685518115758896, 49.772765412926674, 52.17970445752144, 51.94314815104008, 50.03319963812828, 49.21803317964077, 47.093293592333794, 50.54081439971924, 43.08691017329693, 28.852809369564056, 16.80356092751026, 6.930232476443052, 3.0010445276275277, 5.5359989404678345, 6.334175560623407, 5.600508078932762, 5.706787426024675, 9.254789091646671, 11.782177872955799, 8.547996617853642, 6.412054756656289, 3.440871639177203, 0.44924778572749346, 2.556318291462958, 11.67034037411213, 30.490652583539486, 37.799824476242065, 33.228966146707535, 33.409961834549904, 37.63251565396786, 19.329207502305508, 0.9534557035658509, 0.18476475903298706, 0.15886040608165786, 0.1550827408209443, 0.23351258074399084, 0.1451824462856166, 0.10232003376586363, 0.12643101654248312, 0.13362965604756027, 0.20173170953057706, 0.12630176410311833, 0.08241374060162343, 0.06481756019638851, 0.15991771419066936, 0.218800482689403, 0.12687170383287594, 0.16389161814004183, 0.11595181713346392, 0.1161654814495705, 0.18593950459035113, 0.23165215010521933, 0.19896437443094328, 0.11377377697499469, 0.18501879618270323, 0.21130456851096824, 0.10742903032223694, 0.08930119758588262, 0.08004556962987408], [0.12120736559154466, 0.08146518681314774, 0.0710815834463574, 0.021152635563339572, 0.033353359685861506, 0.043866868581972085, 0.02997523704834748, 0.019207139957870822, 0.010225441492366372, 0.08709239540621638, 0.0162689105127356, 0.02531325830204878, 0.05048855506174732, 0.004246600083206431, 0.012315687436057488, 0.042478176692384295, 0.050225111190229654, 0.04381002378067933, 0.02681219622900244, 0.029287152974575292, 0.07930132909677923, 0.061739936863887124, 0.09716635249787942, 0.04483157521462999, 0.013869822596461745, 0.05075231063528918, 0.09032767688040622, 0.01626730376301566, 0.07727375195827335, 0.04658443525840994, 0.009638132723921444, 0.04225713913911022, 0.0360633045056602, 0.11377514252671972, 0.030480877103400417, 7.7444689348340034, 20.314255245029926, 27.975634038448334, 26.313677318394184, 28.35611332207918, 32.935815677046776, 39.483107551932335, 21.40451744198799, 5.045735472813249, 0.5412739492021501, 0.10209614265477285, 1.2507431418634951, 3.9232141943648458, 11.300292480736971, 5.910807978361845, 1.491099363192916, 3.3045385172590613, 3.552804132923484, 0.9077926632016897, 0.9357008594088256, 0.6547949952073395, 6.197992293164134, 17.323699817061424, 35.15443302690983, 48.99126134812832, 50.41604429483414, 50.5163437128067, 54.5256719738245, 55.98622240126133, 52.773627787828445, 48.88124205172062, 49.020645171403885, 50.87596021592617, 52.87602849304676, 55.42797915637493, 56.20935782790184, 55.73113828897476, 53.957534059882164, 53.560554161667824, 52.832049652934074, 54.52248394489288, 54.598179683089256, 48.467596247792244, 42.06045985221863, 37.35441617667675, 42.279046922922134, 39.87693361938, 41.4281889796257, 41.01028360426426, 44.73073236644268, 46.7938544601202, 49.76932279765606, 50.48353627324104, 53.9743709564209, 54.01866517961025, 41.522492319345474, 55.04027836024761, 52.085914090275764, 50.84748454391956, 50.55091045796871, 47.994221448898315, 43.08095209300518, 40.60429818928242, 39.89094726741314, 38.10090512037277, 39.25313629209995, 38.97839203476906, 38.824815675616264, 46.94326624274254, 50.07418803870678, 50.87530665099621, 49.19866181910038, 48.98097909986973, 47.57580690085888, 49.34813439846039, 46.283454447984695, 46.59678943455219, 43.63990969955921, 51.10726520419121, 48.70075933635235, 49.97811779379845, 47.71337851881981, 48.257402926683426, 46.87447473406792, 47.05041669309139, 48.103769570589066, 48.371769189834595, 50.503656193614006, 47.560299932956696, 40.96903681755066, 32.194258868694305, 14.397969860583544, 6.683930167928338, 2.509350199252367, 1.7864596517756581, 2.280111350119114, 2.57341998629272, 2.9270900459960103, 4.170422041788697, 14.54333771020174, 18.879936710000038, 7.448247279971838, 0.8177737123332918, 0.22880685981363058, 1.0097164940088987, 8.969377856701612, 19.214409962296486, 34.88009534776211, 35.36635525524616, 19.107124619185925, 26.650365851819515, 18.388079702854156, 3.5523118218407035, 0.06275110936257988, 0.030627249034296256, 0.042453778587514535, 0.05413014383520931, 0.01821781072067097, 0.05133782062330283, 0.012757240256178193, 0.03768266331462655, 0.0112696191536088, 0.10844503049156629, 0.09070921500097029, 0.03072321615036344, 0.04167910628893878, 0.006832861354268971, 0.04988621316442732, 0.0477894381765509, 0.07435494451783597, 0.05899492185562849, 0.09750440818606876, 0.04686115244112443, 0.03931742539862171, 0.020663222567236517, 0.06454916248912923, 0.03065363795030862, 0.048814410911290906, 0.028002133549307473, 0.021056802033854183, 0.024843317405611742, 0.01870560212410055, 0.06534309723065235, 0.03830895060673356, 0.03574778784241062, 0.04007030453067273, 0.018752967844193336, 0.0374477438890608, 0.03067634766921401, 0.06154290407721419, 0.02825033927365439, 0.048244834833894856, 0.04455039401364047, 0.03277656993304845, 0.032594799413345754, 0.022712065947416704, 0.01698717773251701, 0.03893052155035548, 0.032763010894996114, 0.011856979872391094, 0.016989112882583868, 0.05972204475256149, 0.042980848156730644, 0.007449402392012416, 0.04144677695876453, 0.059769954095827416, 0.030368252482730895, 0.0704048115585465, 0.04112156413611956, 0.03547087399056181, 0.019857459847116843, 0.028563228734128643, 0.024802779444144107, 0.036760990114999004, 0.13587242632638663, 0.45317766547668725, 12.468593940138817, 27.671697847545147, 33.51056523621082, 25.954908169806004, 29.61883496493101, 42.2799588739872, 41.45216949284077, 20.50519309937954, 4.2719863168895245, 0.4994682362303138, 0.21993022441165522, 0.7470568350981921, 2.637481461279094, 8.710729535669088, 10.628348886966705, 9.138765167444944, 9.555343464016914, 3.8275317661464214, 3.6156199872493744, 1.548279644921422, 1.8781611998565495, 9.640077017247677, 22.059015221893787, 40.17856143414974, 51.96489818394184, 51.175813525915146, 52.97811761498451, 57.763915210962296, 56.692676693201065, 54.405742809176445, 50.82398280501366, 48.989407047629356, 51.5493980795145, 54.14704129099846, 56.3444671779871, 56.111509278416634, 57.04695828258991, 55.63704773783684, 54.720126539468765, 53.5518716275692, 55.94116061925888, 55.63911862671375, 50.218169912695885, 43.62080432474613, 40.231712982058525, 43.03695045411587, 42.176866605877876, 42.41987496614456, 43.473862409591675, 46.79999113082886, 49.63717728853226, 51.434055268764496, 52.63745829463005, 54.73054938018322, 54.65131223201752, 44.622681364417076, 55.4373836517334, 53.64908181130886, 53.652634620666504, 51.91181503236294, 49.33344438672066, 44.70468856394291, 40.72094812989235, 40.08280277252197, 39.426589384675026, 40.76493076980114, 40.18644981086254, 39.924541264772415, 46.54969476163387, 51.555675342679024, 52.544652074575424, 50.171949192881584, 49.18003901839256, 48.529297336936, 50.68159684538841, 47.35702984035015, 48.515481278300285, 44.68509681522846, 51.05329290032387, 52.20327079296112, 51.32617525756359, 49.64128486812115, 48.64085175096989, 48.73898148536682, 48.187840059399605, 50.6349391490221, 50.212458819150925, 52.212595492601395, 49.33814473450184, 43.70493561029434, 35.94168238341808, 17.889498956501484, 9.413384031504393, 4.1789373848587275, 3.0459728417918086, 4.817610438913107, 3.1047677993774414, 4.10216772928834, 5.6252499762922525, 11.714177671819925, 13.149154521524906, 4.0212795697152615, 0.7640330179128796, 0.1735138744697906, 0.702888302039355, 8.445507567375898, 21.208533458411694, 37.99579136073589, 38.5957145690918, 20.983695723116398, 30.638907328248024, 24.47423592209816, 5.811775792390108, 0.031393002573167905, 0.05691218830179423, 0.048449296518811025, 0.06383810337865725, 0.05833323783008382, 0.033383275658707134, 0.013245217196526937, 0.025536884095345158, 0.081324015482096, 0.06887554947752506, 0.04735553782666102, 0.038736038040951826, 0.05017425552068744, 0.024522817220713478, 0.051284898072481155, 0.020874246692983434, 0.0323947163997218, 0.04587877898302395, 0.06575068473466672, 0.01931682381837163, 0.020952652739651967, 0.031531721106148325, 0.04486847479711287, 0.025591962585167494, 0.05558396289416123, 0.016979902829916682, 0.03277408373833168, 0.06194557856360916, 0.23646862915484235, 0.09648667139117606, 0.18272558954777196, 0.07965127399074845, 0.15509442222537473, 0.07392507774056867, 0.09856993186986074, 0.14538717514369637, 0.16374047234421596, 0.16311350598698482, 0.21828869765158743, 0.11560792816453613, 0.17079112760256976, 0.08801102580036968, 0.09524873938062228, 0.15693165332777426, 0.22351638588588685, 0.12753276445437223, 0.0747319778020028, 0.19962402497185394, 0.15774513623910025, 0.18947076197946444, 0.16033469728427008, 0.18085172603605315, 0.12192836205940694, 0.09621880803024396, 0.13822248147334903, 0.12780030869180337, 0.1703209918923676, 0.1276088791200891, 0.1349003761424683, 0.2070839746738784, 0.0914441044733394, 0.21001394401537254, 0.3619918506592512, 12.86681542173028, 33.540572226047516, 41.40935719013214, 36.241300106048584, 36.23354472219944, 41.29838414490223, 47.42717407643795, 24.68467053025961, 6.48739093914628, 0.9458599705249071, 0.48509230138733983, 4.481717012822628, 9.112687166780233, 21.216450333595276, 14.364079479128122, 7.169393068179488, 11.682988945394754, 7.322448380291462, 3.8150451611727476, 2.0175072038546205, 1.3944707857444882, 8.174616303294897, 20.62107928097248, 40.112106800079346, 53.65475490689278, 57.172982320189476, 56.152775064110756, 58.707579374313354, 59.43763040006161, 56.364332512021065, 53.7540777772665, 53.73044304549694, 53.98893177509308, 56.9673715531826, 58.92472632229328, 59.19063985347748, 58.648332953453064, 55.56371167302132, 54.98386278748512, 56.82722747325897, 57.817165553569794, 58.21121960878372, 51.4884265512228, 45.884741842746735, 42.284321039915085, 46.06926754117012, 43.383514657616615, 45.424898117780685, 46.49239003658295, 49.93389956653118, 52.14174069464207, 53.22832278907299, 55.065869987010956, 57.8712822496891, 55.936756655573845, 47.363318502902985, 57.13040180504322, 56.45767830312252, 55.09073965251446, 54.78226080536842, 51.16745017468929, 47.97147586941719, 43.32331828773022, 41.683554276824, 39.74840551614761, 42.70036831498146, 42.52365119755268, 42.51863546669483, 49.220943823456764, 53.046574741601944, 54.53528545796871, 50.737628638744354, 51.21965937316418, 49.164752438664436, 50.74669495224953, 47.66278803348541, 47.14133061468601, 46.31095737218857, 51.45080476999283, 51.626609936356544, 53.06027680635452, 50.54075740277767, 50.59656880795956, 50.05322836339474, 50.835952162742615, 51.47000513970852, 50.160929784178734, 52.970590218901634, 49.133502915501595, 43.97826634347439, 33.86594116687775, 16.473941914737225, 9.10687917843461, 4.9086203053593636, 3.9014945598319173, 6.087442450225353, 6.313437223434448, 6.626899978145957, 11.11787661910057, 23.485616371035576, 27.283370085060596, 12.288114074617624, 2.174534252844751, 0.6211068341508508, 1.25971220433712, 11.1543033644557, 23.9431669190526, 43.01197439432144, 43.351622968912125, 25.87816558778286, 38.00310976803303, 27.816813960671425, 5.5676996894180775, 0.18638335342984647, 0.1709090400254354, 0.15727039921330288, 0.2197895577410236, 0.22449566458817571, 0.07755222060950473, 0.12209326727315784, 0.12320611771428958, 0.17503450537333265, 0.16358729306375608, 0.24195471836719662, 0.13704907178180292, 0.12586704368004575, 0.15314527525333688, 0.1390949057531543, 0.19727068953216076, 0.15232365840347484, 0.1631708740023896, 0.2200706981238909, 0.1411640431615524, 0.13820892985677347, 0.11875951764523052, 0.09224212102708407, 0.09796229103812948, 0.139819924661424, 0.1283113961108029, 0.09849230322288349, 0.20623611548217013], [0.04836856198380701, 0.0384357131406432, 0.028418187102943193, 0.011894670769834192, 0.05349004146410152, 0.05245164327789098, 0.07513189149904065, 0.06788162078009918, 0.03624729404691607, 0.08115679476759396, 0.004774595481649158, 0.0158971167911659, 0.11831937954411842, 0.04104581312276423, 0.06492913467809558, 0.040728296371526085, 0.03782504063565284, 0.03627089434303343, 0.02025494115514448, 0.03541912403306924, 0.02900678813603008, 0.033525942417327315, 0.08566980963223614, 0.0067164749725634465, 0.037395830659079365, 0.01243498025360168, 0.0517717024195008, 0.03380150184966624, 0.039022013515932485, 0.035158025348209776, 0.015261706648743711, 0.08657445054268464, 0.018235056377307046, 0.09812223870540038, 0.036563756948453374, 0.5741988855879754, 9.078293312340975, 28.730611726641655, 30.491344146430492, 19.86084647476673, 21.48053426295519, 30.194061398506165, 32.78504356741905, 18.556699454784393, 4.745102254673839, 0.3822696110000834, 0.33647696196567267, 2.4261966487392783, 9.716316126286983, 12.415166907012463, 9.784427471458912, 8.358330745249987, 2.2701280983164907, 3.963223434984684, 1.2295156996697187, 0.5548209347762167, 1.1499312263913453, 3.200253825634718, 15.592646654695272, 34.27026987075806, 43.91564570367336, 53.158414140343666, 50.951735749840736, 54.29789699614048, 55.55324703454971, 52.03753888607025, 52.27501854300499, 56.07508063316345, 53.67329031229019, 55.00601179897785, 58.60549785196781, 53.1664165109396, 51.98572486639023, 52.660264670848846, 56.36494807898998, 54.49295572936535, 49.88298989832401, 43.759930059313774, 38.274795189499855, 40.76934993267059, 40.213739946484566, 39.2317358404398, 40.644154250621796, 41.2117487937212, 42.7946450561285, 46.870572343468666, 52.41588078439236, 52.12501019239426, 53.33969101309776, 53.16789463162422, 41.209609508514404, 53.28211650252342, 53.30812230706215, 52.16023810207844, 48.434652015566826, 47.941620871424675, 44.088806211948395, 41.37189120054245, 38.638709262013435, 39.17896427214146, 38.2254396378994, 38.979178592562675, 41.530912667512894, 48.28788869082928, 50.26102401316166, 52.29628600180149, 49.19643893837929, 48.70750777423382, 51.183660104870796, 48.60079050064087, 49.243712201714516, 47.595235258340836, 49.08269964158535, 49.36980463564396, 48.83656784892082, 47.91712738573551, 47.301655411720276, 46.78927570581436, 46.28630429506302, 48.489969447255135, 48.70447173714638, 48.94589178264141, 49.87222507596016, 42.603256925940514, 32.81683266162872, 18.206732533872128, 7.668645428493619, 1.6358264721930027, 1.2623964040540159, 1.7725261556915939, 4.2382061295211315, 3.433785969391465, 2.436123378574848, 2.394028762355447, 5.95849921926856, 9.242474902421236, 3.35195807274431, 0.37448097893502563, 0.8714844833593816, 4.173902180045843, 23.10321819037199, 28.917176015675068, 29.680401161313057, 46.026550233364105, 31.495438367128372, 18.089071847498417, 5.545215345919132, 0.6260533374734223, 0.0941699164104648, 0.02497787991160294, 0.01994510934309801, 0.047966833735699765, 0.015329826528613921, 0.013205389841459692, 0.061791189582436346, 0.04071965777256992, 0.02171884600102203, 0.02819125133100897, 0.007682919622311601, 0.06168791602249257, 0.098216825426789, 0.05277996198856272, 0.0612306417315267, 0.06943135129404254, 0.015926544801914133, 0.018468871858203784, 0.06467546860221773, 0.007180103903010604, 0.035940141387982294, 0.06211348947545048, 0.028543530279421248, 0.04244625321007334, 0.034588504931889474, 0.05248420871794224, 0.020138550135015976, 0.029310994468687568, 0.023005498151178472, 0.06771558008040302, 0.06909935153089464, 0.020880671836494002, 0.013238694646133808, 0.025864685158012435, 0.042984933679690585, 0.05415448627900332, 0.012116336365579627, 0.06027665913279634, 0.0397621462616371, 0.028255738398001995, 0.01582009113917593, 0.0796817836817354, 0.10029149925685488, 0.010702153558668215, 0.017693099325697403, 0.035166526649845764, 0.02250267269118922, 0.016650392972223926, 0.038316082645906135, 0.03863128389639314, 0.01924912696267711, 0.03711910976562649, 0.00995727385088685, 0.029552533851529006, 0.06339734187349677, 0.03393909602891654, 0.09929446096066386, 0.06964118612813763, 0.0544012392492732, 0.012086718179489253, 0.03268357882916462, 0.05615776921331417, 0.0629820731410291, 1.1625655484385788, 14.070507232099771, 33.726009875535965, 37.340888902544975, 22.038460224866867, 24.037645049393177, 41.62683852016926, 43.60493257641792, 18.948194347321987, 3.983806218020618, 0.20959777728421614, 0.383812120417133, 0.8827652467880398, 1.4895488088950515, 9.955450594425201, 11.064628176391125, 12.889918182045221, 8.943926822394133, 7.045964291319251, 2.974829734303057, 1.8866155087016523, 1.734535675495863, 6.345125148072839, 20.763182155787945, 36.679682582616806, 48.85820388793945, 54.36775624752045, 53.855368942022324, 55.99945329129696, 58.50373551249504, 54.041118174791336, 56.62208788096905, 58.20935770869255, 54.952685460448265, 57.13345304131508, 58.682892099022865, 54.92976889014244, 53.40243324637413, 54.826878011226654, 57.766487672924995, 55.51450431346893, 52.493818402290344, 46.18574649095535, 41.141600757837296, 41.50720573961735, 42.55099833011627, 41.63587063550949, 42.94426582753658, 43.24122369289398, 46.56419858336449, 49.83232341706753, 54.8249439150095, 53.63695666193962, 55.52512474358082, 53.27253721654415, 43.35653230547905, 54.21231418848038, 54.47036974132061, 52.64173686504364, 50.69600187242031, 49.361688271164894, 46.46331399679184, 42.942054346203804, 40.979759842157364, 40.19740082323551, 40.83688370883465, 40.97287841141224, 43.37217226624489, 49.560178220272064, 53.68867188692093, 51.99344605207443, 51.28284618258476, 49.53354924917221, 50.42756907641888, 50.13393983244896, 50.17931319773197, 47.65052609145641, 49.152300506830215, 52.029327526688576, 50.06844274699688, 49.86036591231823, 49.4447898119688, 47.60796457529068, 49.292771369218826, 49.37448978424072, 50.938820242881775, 50.130170434713364, 51.13198287785053, 43.126344457268715, 36.835432425141335, 20.764572881162167, 10.113260876387358, 3.337554233148694, 2.7635085862129927, 3.5845839651301503, 4.745529731735587, 3.8801948027685285, 4.351363107562065, 7.091349055990577, 5.342023624107242, 3.6271998658776283, 1.3709772401489317, 0.2518614992732182, 0.8178755943663418, 4.484372595325112, 24.636946991086006, 32.40250289440155, 37.66525089740753, 48.41850288212299, 30.823499523103237, 23.650930300354958, 8.844381663948298, 1.0364604089409113, 0.05757298175012693, 0.05541775521123782, 0.022848032967885956, 0.019061606653849594, 0.01834905953728594, 0.04593797268171329, 0.015987439874152187, 0.03866307008138392, 0.03038410475710407, 0.05573470421950333, 0.016343988027074374, 0.07116890454199165, 0.08328914089361206, 0.011151334729220252, 0.07990188983967528, 0.010029791883425787, 0.04040750674903393, 0.014808317500865087, 0.06611623699427582, 0.050016230015899055, 0.040758156683295965, 0.014896864067850402, 0.007165937231548014, 0.07258023935719393, 0.038399796903831884, 0.01820832421799423, 0.01655721262068255, 0.029056975872663315, 0.15605149586917832, 0.13126484700478613, 0.15264003595802933, 0.126619343936909, 0.11920793811441399, 0.12820610019844025, 0.23237920249812305, 0.18473177799023688, 0.20545800332911313, 0.18295253830729052, 0.10248919890727848, 0.1894337436533533, 0.30285966116935015, 0.14138552971417084, 0.26833406067453325, 0.12946562870638445, 0.12267571219126694, 0.13739296817220747, 0.08941797452280298, 0.15954227652400732, 0.11820325569715351, 0.1412927167257294, 0.22780582134146243, 0.14138245722278953, 0.13721204741159454, 0.08569648241973482, 0.22866414481541142, 0.12105812711524777, 0.3527061583008617, 0.16248449130216613, 0.1285560376709327, 0.12516531336586922, 0.17440983967389911, 0.22462543653091416, 0.29180679644923657, 1.0062520299106836, 16.564074978232384, 40.074469819664955, 45.836575627326965, 29.88794982433319, 30.0082665681839, 41.138401329517365, 41.20774380862713, 23.018737323582172, 6.0047422628849745, 0.7062193576712161, 0.8899374213069677, 6.694499775767326, 17.492769844830036, 20.606339871883392, 15.240044575184584, 13.53059895336628, 7.94644994661212, 9.256440103054047, 4.242835231125355, 2.343574594706297, 2.1766816126182675, 5.382451554760337, 18.06794498115778, 36.15855194628239, 48.77260588109493, 58.32964785397053, 57.90264196693897, 59.032640531659126, 59.458354488015175, 57.55750648677349, 56.10030747950077, 61.90789304673672, 56.83293476700783, 60.06900832056999, 59.53686587512493, 54.636303037405014, 54.60261784493923, 55.505947172641754, 59.85478721559048, 56.55719876289368, 54.195120111107826, 45.98635978996754, 41.083726063370705, 43.76365005970001, 43.015534803271294, 43.79594832658768, 46.22819781303406, 46.34877294301987, 47.19013899564743, 52.30516992509365, 56.720289811491966, 55.429833456873894, 55.82171022891998, 55.78256472945213, 47.45480239391327, 54.36160817742348, 55.41382871568203, 56.68159268796444, 52.63631835579872, 53.19647669792175, 47.14825004339218, 46.36377073824406, 43.07815544307232, 42.34782323241234, 41.36162795126438, 42.10273638367653, 45.1423566788435, 51.71262972056866, 53.624945506453514, 55.03256477415562, 50.99078245460987, 50.360115095973015, 53.111634850502014, 51.53053969144821, 50.417852997779846, 49.52992044389248, 51.90250553190708, 52.36358039081097, 51.154975444078445, 51.64722003042698, 52.01515428721905, 50.011886581778526, 50.25545731186867, 51.51432976126671, 52.039651572704315, 51.56713552772999, 53.32842841744423, 42.173659577965736, 35.36952428519726, 19.645515829324722, 8.83630234748125, 2.7854820946231484, 4.065256034955382, 4.823628840968013, 8.453529886901379, 8.559588845819235, 7.475005919113755, 9.729804452508688, 12.971458956599236, 14.77354645729065, 5.771525027230382, 1.130137019790709, 1.202816313598305, 5.0367532297968864, 29.134218469262123, 35.755784958601, 37.40019991993904, 52.01642341911793, 38.944672644138336, 30.588005259633064, 9.577822107821703, 1.2979510962031782, 0.292706546606496, 0.07520707105868496, 0.10971603260259144, 0.11195152983418666, 0.13190347992349416, 0.16565720230573788, 0.1320238711195998, 0.1153624925063923, 0.07692581086303107, 0.137693359865807, 0.08103955027763732, 0.2761767210904509, 0.15092294372152537, 0.08960095845395699, 0.18263219768414274, 0.18869955179980025, 0.060572041329578497, 0.13143922202289104, 0.18839803204173222, 0.1827987504657358, 0.15880369115620852, 0.13724053103942424, 0.22331426938762888, 0.13172877836041152, 0.16006192832719535, 0.14185256324708462, 0.11772179481340572, 0.10176236173720099], [0.03541232224961277, 0.06991184738581069, 0.06486031532404013, 0.03519902900734451, 0.07596728260978125, 0.055220815193024464, 0.025101861247094348, 0.014205877268977929, 0.012489274849940557, 0.021555300772888586, 0.027779184965766035, 0.04613815217453521, 0.024368905069422908, 0.12673425808316097, 0.051496614250936545, 0.04570309407426976, 0.030891807982698083, 0.030508154741255566, 0.06695994758047163, 0.03642429626779631, 0.10419892161735334, 0.04181751311989501, 0.08267701748991385, 0.05032416564063169, 0.027028244694520254, 0.07855163377826102, 0.07308512242161669, 0.07875639232224785, 0.037801269645569846, 0.06808277248637751, 0.03328162740217522, 0.05391808626882266, 0.06301109853666276, 0.08115992663078941, 0.0304529723507585, 0.10341549568693154, 0.8185584889724851, 11.864316165447235, 26.36559773236513, 26.63213063031435, 25.57248719036579, 26.128619648516178, 37.057940885424614, 33.97685341536999, 22.530982196331024, 4.669564682990313, 1.105195158161223, 0.1769051924929954, 0.6571566278580576, 10.122902859002352, 14.302587378770113, 13.907124549150467, 6.460799966007471, 6.7904332280159, 3.087909766472876, 1.3963962136767805, 0.16035547741921619, 0.4719636793015525, 2.335602384991944, 14.786361269652843, 38.35367135703564, 44.903569892048836, 53.22279788553715, 51.7705500125885, 54.25290361046791, 58.04145231842995, 52.38297455012798, 55.86913548409939, 55.18282391130924, 53.004583194851875, 53.83471705019474, 51.600087359547615, 56.82634212076664, 56.7970684915781, 53.205189630389214, 51.06963962316513, 47.39327609539032, 42.28758506476879, 43.75446975231171, 41.13413795828819, 42.62686885893345, 40.216285809874535, 41.72367252409458, 41.76604405045509, 44.03106831014156, 47.90469825267792, 53.54796163737774, 54.0473460406065, 54.240181893110275, 53.93977761268616, 42.19985917210579, 50.51407143473625, 51.21631555259228, 52.37730145454407, 52.75707207620144, 49.109723791480064, 46.611000671982765, 41.500901877880096, 41.24336689710617, 39.154155403375626, 39.73946459591389, 38.17418798804283, 41.53219699859619, 47.97126308083534, 50.550819262862206, 52.865286469459534, 50.32498598098755, 48.677971959114075, 49.56224910914898, 50.69815255701542, 47.46001571416855, 49.068967178463936, 50.99328272044659, 49.190347865223885, 50.68831488490105, 51.412324234843254, 49.227008298039436, 50.168476179242134, 49.024194180965424, 49.29481565952301, 49.489167630672455, 49.27059955894947, 45.10248921811581, 31.370930448174477, 18.043271005153656, 5.871075410395861, 1.989752424415201, 1.3377337739802897, 2.0084988372400403, 3.5092796059325337, 3.0883868783712387, 1.3650183286517859, 5.543442266061902, 6.780759897083044, 6.0157060995697975, 3.222682122141123, 0.7343273400329053, 0.4606080777011812, 4.758767271414399, 15.7439792342484, 33.248466700315475, 22.165677398443222, 15.21517775952816, 37.05599159002304, 36.8732175976038, 12.655459363013506, 2.0250341249629855, 0.08111187256872654, 0.08043366833589971, 0.055220551730599254, 0.027224988043599296, 0.04535211388429161, 0.0687834044219926, 0.019079510966548696, 0.035903579482692294, 0.03878399933455512, 0.008221113985200645, 0.04598908810294233, 0.034877890575444326, 0.07585379338706844, 0.0387103485991247, 0.07468181604053825, 0.010397038095106836, 0.11246311449212953, 0.04300630753277801, 0.027963070606347173, 0.0636332409339957, 0.056228674002340995, 0.010901857149292482, 0.04725608632725198, 0.07113030544132926, 0.010223703939118423, 0.03707805786689278, 0.11170260608196259, 0.02221551720140269, 0.02169184295780724, 0.005311550457918202, 0.03931279439711943, 0.03348671249113977, 0.047717568595544435, 0.058227266563335434, 0.15134378598304465, 0.04114451876375824, 0.0072884430846897885, 0.04106493455765303, 0.05382971874496434, 0.04789847451320384, 0.02351301027374575, 0.0298375723650679, 0.06574863640707918, 0.02958386547106784, 0.11787478855694644, 0.04824722826015204, 0.045270915506989695, 0.017636569937167224, 0.042163283433183096, 0.021187787388043944, 0.04790296821738593, 0.06596259016077965, 0.09682876436272636, 0.028681113326456398, 0.07145595984184183, 0.06049979325325694, 0.06533177205710672, 0.013317498669493943, 0.1522266151732765, 0.08140279445797205, 0.0790557598520536, 0.05109904202981852, 0.023149014668888412, 0.11516460624989122, 0.12426029396010563, 2.3020356986671686, 18.977526873350143, 33.32877159118652, 27.633519396185875, 24.471566565334797, 25.31288892030716, 38.516838401556015, 39.6049328148365, 18.70407834649086, 4.595194598659873, 0.5187318369280547, 0.19674290379043669, 0.6161668617278337, 2.2850280487909913, 6.500495485961437, 12.699220664799213, 8.797548227012157, 10.104642938822508, 3.2135106017813087, 3.4233175311237574, 1.6849073697812855, 1.0314059676602483, 3.559945849701762, 17.667163386940956, 39.01318296790123, 49.115503281354904, 56.80645398795605, 53.90813671052456, 57.538302317261696, 58.826904371380806, 54.974553287029266, 57.65324994921684, 57.977642342448235, 54.89873595535755, 55.89336298406124, 52.23475210368633, 55.77471815049648, 58.25970880687237, 55.95650799572468, 53.001512959599495, 49.214932546019554, 44.26467217504978, 44.21522542834282, 43.1749514490366, 44.069503247737885, 42.49001920223236, 42.82990336418152, 43.57796162366867, 46.689857840538025, 49.43893812596798, 54.96498540043831, 55.58863453567028, 56.14173665642738, 55.10987542569637, 45.19302695989609, 51.19368016719818, 54.25137609243393, 53.26936438679695, 54.68154340982437, 51.69340655207634, 48.68703447282314, 44.29209530353546, 41.91994719207287, 41.21872901916504, 41.671554520726204, 39.05177749693394, 44.67212051153183, 50.562549233436584, 52.43931032717228, 53.709867149591446, 50.90013451874256, 50.111049860715866, 50.70452481508255, 51.40613816678524, 49.80276860296726, 48.63605260848999, 51.680050268769264, 50.46027012169361, 51.800822988152504, 51.1860615760088, 49.99528907239437, 50.28268665075302, 50.73073960840702, 51.07927970588207, 51.15824706852436, 49.80648100376129, 47.73877635598183, 33.86963076889515, 20.59557504951954, 8.076087590306997, 4.077817685902119, 3.289202540181577, 3.0099066020920873, 3.1231336388736963, 2.5481031322851777, 3.106569377705455, 3.885703794658184, 4.8910025507211685, 2.89116392377764, 1.0408102255314589, 0.1542674470692873, 0.10553031228482723, 4.932572795078158, 15.66344540566206, 38.89202266931534, 30.43373353779316, 19.722845479846, 42.75961093604565, 43.72911751270294, 16.857024058699608, 2.879609693773091, 0.06150879125925712, 0.15003468201030046, 0.08657656566356309, 0.032382649078499526, 0.0664173263066914, 0.03700909379404038, 0.024741622764850035, 0.052643076560343616, 0.043239879960310645, 0.024594655260443687, 0.05028915482398588, 0.011939074393012561, 0.042896295271930285, 0.040529697653255425, 0.007634885505467537, 0.03664222422230523, 0.02359578757022973, 0.029785074693791103, 0.010146823005925398, 0.04346114015788771, 0.055477297719335184, 0.05982110662444029, 0.023537057713838294, 0.023319419196923263, 0.11302494996925816, 0.058308709849370643, 0.08795710135018453, 0.04584398709994275, 0.04212596082652453, 0.08068832888966426, 0.16692087199771777, 0.09565238608047366, 0.12254985878826119, 0.15189686411758885, 0.209258348622825, 0.09603735292330384, 0.05843281549459789, 0.17348781024338678, 0.1292228722013533, 0.13359977718209848, 0.09746247684233822, 0.18448078364599496, 0.27671771706081927, 0.18101064953953028, 0.2972568024415523, 0.11206415816559456, 0.12333447215496562, 0.11574715506867506, 0.10432602924993262, 0.158860465453472, 0.1485695637529716, 0.19681435776874423, 0.24026600585784763, 0.12487667729146779, 0.2322530819219537, 0.160007914819289, 0.16648398450342938, 0.10506609149160795, 0.3279864363139495, 0.1483136267052032, 0.1846867593121715, 0.13338448014110327, 0.16168786998605356, 0.15003906068159267, 0.24836492986651137, 2.188719129189849, 20.25457564741373, 41.19716517627239, 36.73983335494995, 35.563116297125816, 34.20099578797817, 46.40901871025562, 44.318648278713226, 25.581544004380703, 6.343550607562065, 1.3735932810232043, 0.3533284936565906, 3.1312754144892097, 19.611576050519943, 22.87437926977873, 27.026026993989944, 14.30992478504777, 13.99200439453125, 7.820226419717073, 4.917323738336563, 1.3555943593382835, 1.3820548332296312, 3.743343958631158, 17.87027958780527, 41.55865877866745, 48.58417019248009, 57.575722709298134, 60.29474280774593, 60.72524830698967, 60.501482114195824, 56.490010768175125, 60.599224269390106, 58.17172072827816, 55.143765807151794, 57.5131780654192, 52.4347847700119, 56.42199441790581, 59.439378306269646, 57.68186241388321, 54.372969567775726, 50.86288131773472, 46.78194209933281, 48.164034336805344, 45.33183351159096, 46.0136841237545, 44.656115770339966, 45.16844227910042, 45.25001250207424, 48.82347375154495, 51.238437965512276, 58.66352453827858, 57.86912016570568, 58.0073681473732, 54.32827636599541, 47.9984962195158, 52.15575814247131, 54.14911597967148, 55.73100909590721, 56.80710755288601, 53.06335084140301, 50.44145353138447, 47.0299281924963, 45.77957108616829, 42.54144184291363, 44.14712928235531, 41.65610834956169, 45.75896479189396, 51.84174299240112, 54.683656096458435, 55.506608337163925, 52.54674956202507, 50.50374358892441, 51.57161548733711, 53.14444608986378, 50.14284275472164, 50.31230226159096, 54.61613371968269, 52.39557087421417, 53.37890490889549, 53.19198913872242, 51.259420439600945, 50.69276064634323, 50.83234615623951, 53.77856366336346, 53.022290244698524, 52.10543364286423, 46.52524307370186, 33.45819264650345, 19.86321184784174, 7.3517305590212345, 3.7498651212081313, 3.104015914723277, 4.576698141172528, 8.00013156607747, 8.10319533571601, 5.253764810040593, 12.180771734565496, 13.233920373022556, 11.228629276156425, 7.126931296661496, 1.7110087629407644, 0.6878476997371763, 7.00188665650785, 19.319060146808624, 41.851395070552826, 31.35602194815874, 22.376404590904713, 48.32926087081432, 46.21570408344269, 22.11993545293808, 3.0354818422347307, 0.17876983853057027, 0.3251439513405785, 0.189928236650303, 0.13884131389204413, 0.15436725108884275, 0.12959047278854996, 0.1264197804266587, 0.16240531898802146, 0.12115352277760394, 0.06468435953138396, 0.113759943342302, 0.1682520325994119, 0.138707623409573, 0.14181345206452534, 0.13498431304469705, 0.14530887856381014, 0.1467734031029977, 0.12908086966490373, 0.09050490174558945, 0.09510216521448456, 0.13651686283992603, 0.2210166840814054, 0.28736501291859895, 0.16661390487570316, 0.13719380542170256, 0.14896696899086237, 0.3062634472735226, 0.12953083380125463, 0.11177527718245983], [0.026352018285251688, 0.06398202065611258, 0.06678443707642145, 0.02412067336990731, 0.03108168275502976, 0.046568720281356946, 0.02946310876723146, 0.05786657908174675, 0.007174394004323403, 0.05065992438176181, 0.0394397276249947, 0.03457035942119546, 0.035459159189485945, 0.039770725488779135, 0.05848691434948705, 0.04136628362175543, 0.03429742719163187, 0.04488223792577628, 0.03191830954165198, 0.015189027199085103, 0.05446173170639668, 0.02283907524542883, 0.052412331715459004, 0.042462673227419145, 0.024346946775040124, 0.007005376828601584, 0.06206434445630293, 0.07138134431443177, 0.033467119792476296, 0.038490168226417154, 0.06570223733433522, 0.03890067237080075, 0.017613628297112882, 0.052198492994648404, 0.039898909235489555, 0.12411844727466814, 0.014922163882147288, 0.7639487693086267, 12.235315907746553, 32.06221595406532, 29.01542354375124, 24.291769713163376, 23.269727155566216, 27.315276972949505, 29.93080012500286, 23.378332927823067, 5.813247738406062, 0.6360026285983622, 0.10798964867717586, 1.502752744127065, 4.9889071471989155, 10.000342335551977, 11.060396153479815, 12.21176192164421, 1.4374280744232237, 3.6605435516685247, 2.4997269781306386, 0.950963927898556, 0.40464806486852467, 1.4678491232916713, 14.467213544994593, 37.519551515579224, 46.9539512693882, 52.086453661322594, 51.66045092046261, 53.233532309532166, 57.666560634970665, 59.824746027588844, 54.524509236216545, 53.26895780861378, 52.426588609814644, 54.075255542993546, 55.90379722416401, 57.12894268333912, 54.80893537402153, 54.513721615076065, 47.498173266649246, 43.73849540948868, 42.20273181796074, 42.46236048638821, 43.47796618938446, 43.8933826982975, 44.42158855497837, 42.77796395123005, 44.36633571982384, 48.065874204039574, 53.83503623306751, 53.402710631489754, 52.86005415022373, 53.54399085044861, 40.0687625259161, 49.92907002568245, 52.260985895991325, 55.199231430888176, 53.10037985444069, 51.69687956571579, 48.475176841020584, 45.335184931755066, 41.017423421144485, 39.97530274093151, 40.83017706871033, 39.39285099506378, 43.56798715889454, 50.04552997648716, 51.138750314712524, 52.811401560902596, 50.02447530627251, 52.8394440561533, 50.67917637526989, 52.0158002525568, 50.189014077186584, 51.69899225234985, 51.25116728246212, 48.175980895757675, 50.068214759230614, 49.26248699426651, 52.009268403053284, 51.41491949558258, 48.45325581729412, 52.140642553567886, 47.38210469484329, 36.74083270132542, 26.82198364287615, 17.59619079530239, 6.174129573628306, 0.9559847053606063, 1.0572836478240788, 2.66474143601954, 3.365519782528281, 1.9047493231482804, 1.732809618115425, 2.294621584005654, 1.2981832399964333, 3.7536378437653184, 0.9029752935748547, 0.40134841692633927, 0.3717714868253097, 3.882654933258891, 16.268395744264126, 28.176268972456455, 23.651899248361588, 20.67630361765623, 24.218579940497875, 24.869348220527172, 16.44542634487152, 2.0615734392777085, 0.6217749451752752, 0.05392522201873362, 0.11239681844017468, 0.009117281424551038, 0.05731458077207208, 0.051294056174810976, 0.016295824498229194, 0.08983246400021017, 0.05978020315524191, 0.01439043084246805, 0.0879286251438316, 0.059846083604497835, 0.020007854218420107, 0.07654256580281071, 0.07485958267352544, 0.028717593595501967, 0.01889305935037555, 0.013295968965394422, 0.03026673039130401, 0.029168355540605262, 0.02200974562583724, 0.06160255790746305, 0.026375141751486808, 0.03268403896072414, 0.01483674732298823, 0.0499557783768978, 0.03811175083683338, 0.0162848240142921, 0.04514233471127227, 0.0407785991410492, 0.027319405926391482, 0.09722209520987235, 0.02581160304544028, 0.02501574799680384, 0.0703368234098889, 0.042223356576869264, 0.07005540101090446, 0.036529937278828584, 0.011600784928305075, 0.028623838079511188, 0.012596172873600153, 0.0571370108082192, 0.027594605417107232, 0.0732046749908477, 0.01991191864362918, 0.010509094045119127, 0.04722133155155461, 0.04387513610708993, 0.034255328864674084, 0.011873648509208579, 0.027674397424561903, 0.0135992698778864, 0.0358964288898278, 0.04674723277275916, 0.013348614138521953, 0.02568690924817929, 0.051322113067726605, 0.06019784676027484, 0.009617802516004303, 0.008846270429785363, 0.036847702649538405, 0.0645778093894478, 0.02840925350028556, 0.04360710576293059, 0.09742809314047918, 0.01809859026252525, 0.061524676930275746, 2.0920387795194983, 18.440095111727715, 38.513426184654236, 32.04612761735916, 27.97447320073843, 24.035080187022686, 39.41656552255154, 43.315274119377136, 21.647463105618954, 5.318181803449988, 0.6829677522182465, 0.17546091374242678, 0.8049644809216261, 1.5884833876043558, 9.585446398705244, 8.453761674463749, 5.3443310502916574, 5.309490719810128, 3.1504178373143077, 3.957743179053068, 2.014198056422174, 0.7369173760525882, 2.955162702128291, 20.724764317274094, 39.447108283638954, 49.6269216388464, 54.513197243213654, 54.44056034088135, 57.00642965734005, 61.259290650486946, 59.62857775390148, 56.342928260564804, 55.28505742549896, 53.35391744971275, 53.89610655605793, 57.349365055561066, 58.99733282625675, 57.10777401924133, 56.372787058353424, 47.22412817180157, 45.044622123241425, 44.260044023394585, 44.27336610853672, 46.42935901880264, 44.313237369060516, 45.04581145942211, 46.21995225548744, 47.109108343720436, 50.3456986695528, 54.21465866267681, 56.50838278234005, 55.50743669271469, 55.017308592796326, 42.480401918292046, 48.936118707060814, 52.54527524113655, 54.54193130135536, 53.834979236125946, 53.51879820227623, 51.01615749299526, 45.97685270011425, 41.56198360025883, 42.22807265818119, 42.69010506570339, 41.27172477543354, 44.72891986370087, 52.10041791200638, 52.35086627304554, 53.76861959695816, 51.00507348775864, 52.9384059458971, 51.86549931764603, 53.93542304635048, 51.04389600455761, 51.463150307536125, 50.972862616181374, 50.24547904729843, 50.81181585788727, 51.124816462397575, 52.46334783732891, 53.39181661605835, 49.793998673558235, 52.52007499337196, 49.49078634381294, 39.423260763287544, 30.451780669391155, 20.578534863889217, 8.537811264395714, 1.5352867171168327, 2.448711865581572, 4.320713002234697, 3.5647485544905066, 3.470700513571501, 3.4884142130613327, 4.821164198219776, 3.878048392944038, 3.092897473834455, 1.4816002291627228, 0.3104529599659145, 0.24551631475333124, 3.5188814532011747, 16.401793286204338, 30.892861001193523, 30.714384578168392, 22.02957060188055, 24.003110602498055, 28.998544849455357, 24.40261546522379, 5.3456272557377815, 0.7799750624690205, 0.01673166927503189, 0.1047219056636095, 0.01342615836620098, 0.03438656283833552, 0.0582607374235522, 0.038300096784951165, 0.0789390571299009, 0.00943530561926309, 0.07624161007697694, 0.06036224731360562, 0.06497700320323929, 0.07300782031961717, 0.05893411398574244, 0.02802765229716897, 0.05662181931256782, 0.014739184589416254, 0.031891017060843296, 0.03699579079693649, 0.04102483631868381, 0.014679572504974203, 0.08512233471265063, 0.03771187053644098, 0.08741534838918597, 0.04026531125418842, 0.03617987735196948, 0.08768245475948788, 0.027667985268635675, 0.02207801393524278, 0.022730241144017782, 0.10063113571959548, 0.18813106667948887, 0.13808349205646664, 0.07827536188415252, 0.1780086918734014, 0.1407187693985179, 0.1465474339784123, 0.19125936756609008, 0.07907497405540198, 0.18118866108125076, 0.1561129605397582, 0.1508029384422116, 0.13182442635297775, 0.16002890275558457, 0.08298815548187122, 0.14291681785834953, 0.12844532408053055, 0.13671900902409106, 0.18981381232151762, 0.11987741469056346, 0.1931464413064532, 0.08640045401989482, 0.16867809958057478, 0.19083723396761343, 0.11489201540825889, 0.07398309142445214, 0.1497546845348552, 0.2189461514353752, 0.11397773399949074, 0.0704158101871144, 0.14133314893115312, 0.19625219574663788, 0.14150587638141587, 0.1127472754160408, 0.21265224931994453, 0.30982902157120407, 0.16305710276355967, 2.1286828257143497, 22.863110974431038, 45.18501318991184, 41.080462038517, 34.939801543951035, 30.90972449630499, 38.10608424246311, 39.20360594987869, 28.315159119665623, 7.405776008963585, 1.0015471698716283, 0.3129422717029229, 4.259049911051989, 13.906263895332813, 24.031778164207935, 22.524663135409355, 21.952962912619114, 7.455546213313937, 9.516702387481928, 7.4152289517223835, 3.0752908810973167, 0.9696256765164435, 2.845553308725357, 17.634542137384415, 40.43078809976578, 52.245619520545006, 57.08033949136734, 59.904556944966316, 59.182215705513954, 62.47953437268734, 60.625317469239235, 58.10944207012653, 54.091936647892, 55.03339692950249, 53.74202482402325, 57.28847712278366, 61.536747962236404, 59.807939529418945, 59.89899404346943, 49.95336592197418, 48.17883834242821, 46.21143691241741, 46.902308240532875, 48.10110591351986, 47.041810154914856, 48.73980604112148, 48.84504519402981, 49.26905684173107, 52.30676583945751, 57.25459814071655, 56.94077678024769, 56.32912740111351, 57.09175407886505, 45.72260074317455, 50.44706963002682, 52.95827507972717, 55.51223583519459, 57.19507433474064, 56.76203437149525, 53.05797412991524, 49.711007326841354, 44.88967023789883, 43.666648864746094, 44.67571511864662, 42.955836206674576, 48.25910143554211, 54.00346599519253, 54.937626868486404, 56.132168769836426, 51.74198314547539, 53.867425695061684, 54.3908666074276, 55.497732013463974, 53.360042721033096, 54.08470943570137, 53.81441853940487, 52.59378723800182, 52.350691482424736, 52.879573702812195, 54.41458873450756, 55.065904185175896, 49.45690356194973, 55.12373708188534, 49.77117709815502, 39.32995676994324, 29.398707076907158, 19.724789075553417, 7.11840882897377, 1.5303248958662152, 3.2851213216781616, 5.699339350685477, 6.62254873663187, 6.163885798305273, 5.180233055725694, 6.156131364405155, 5.403657741844654, 7.758703920990229, 3.6616818280890584, 0.97644476685673, 0.6873799685854465, 4.489322304725647, 20.30692733824253, 33.24344716966152, 32.163233533501625, 29.531893730163574, 33.7538243830204, 34.889929220080376, 25.983955711126328, 6.372330263257027, 0.8505753334611654, 0.08672797121107578, 0.3373232181183994, 0.13418586604529992, 0.1371813818695955, 0.14918383938493207, 0.07946031939354725, 0.16470570961246267, 0.13172963925171643, 0.17451427469495684, 0.09738911554450169, 0.07644904777407646, 0.19924189313314855, 0.18164119304856285, 0.2934648434165865, 0.11471974066807888, 0.13918912882218137, 0.16237989300861955, 0.12755820527672768, 0.08341410371940583, 0.11780285960412584, 0.17064777435734868, 0.21503745258087292, 0.16275788366328925, 0.06770040316041559, 0.199192748114001, 0.22101374517660588, 0.099815856810892, 0.11654305650154129, 0.14328521996503696], [0.0543475040467456, 0.040639038270455785, 0.07030940847471356, 0.060275542200542986, 0.06593793601496145, 0.027534843975445256, 0.011931641784030944, 0.10055611201096326, 0.013493403439497342, 0.05237111654423643, 0.02421023018541746, 0.06794744185754098, 0.002395642727606173, 0.04810438709682785, 0.03333086147904396, 0.05577057592745405, 0.016436405821877997, 0.03861349461658392, 0.05655016495438758, 0.010541458177613094, 0.03462540451437235, 0.04812063642020803, 0.056104219547705725, 0.051516915700631216, 0.05346619254851248, 0.03493128067930229, 0.04395695788844023, 0.08707401982974261, 0.01367025352010387, 0.012567109442898072, 0.020875456393696368, 0.0678848268580623, 0.056841732512111776, 0.02595097837911453, 0.07603075850056484, 0.0919681201048661, 0.10438128956593573, 0.11544512322871014, 1.4294729637913406, 16.9241189584136, 33.06312784552574, 25.01877900213003, 18.76389853656292, 17.681929394602776, 22.02529013156891, 37.10395261645317, 25.289643667638302, 7.675984734669328, 0.9382255270611495, 0.16595386841800064, 0.870667586568743, 7.571398671716452, 3.581502567976713, 1.7455167300067842, 3.5188011825084686, 2.5798295298591256, 3.9844766445457935, 0.6886258267331868, 0.5284463125281036, 0.2093792741652578, 2.562775807455182, 13.815160933881998, 33.91340062022209, 47.4138367921114, 51.0843600332737, 54.758200496435165, 52.98308774828911, 56.471444964408875, 54.150278717279434, 52.42258742451668, 54.27490442991257, 55.77332362532616, 56.41668990254402, 58.047668784856796, 56.07625097036362, 52.489505633711815, 50.8995645493269, 46.61507025361061, 45.83758257329464, 44.96724687516689, 43.14600460231304, 45.351227670907974, 43.15020717680454, 45.01703180372715, 42.55129091441631, 48.014903739094734, 52.5008974224329, 56.222121343016624, 53.115305453538895, 58.851789236068726, 34.82986964285374, 46.33561044931412, 47.558559626340866, 52.70604461431503, 57.22754739224911, 49.433994591236115, 50.110012516379356, 43.02616663277149, 43.86855483055115, 43.104298040270805, 41.82003155350685, 40.6486152112484, 48.414817079901695, 50.83903759717941, 51.979443803429604, 52.93985366821289, 52.44124062359333, 52.661378011107445, 51.68881259858608, 51.81530021131039, 50.61364509165287, 48.6252535879612, 49.4034556299448, 48.55133235454559, 49.71236005425453, 50.9975802898407, 48.85295256972313, 48.41112747788429, 45.683877021074295, 41.10347740352154, 30.234287939965725, 20.649657547473907, 11.408276036381721, 3.7029962986707687, 1.275832720566541, 0.18723959889030084, 2.0609645219519734, 4.705911157652736, 1.8555854237638414, 2.4163556518033147, 1.6990459361113608, 3.499717181548476, 2.4366301763802767, 1.6877711098641157, 2.0732939103618264, 0.5797281232662499, 3.700897148810327, 13.791185170412064, 28.248009122908115, 24.355634786188602, 22.282673120498657, 23.581253439188004, 26.126381568610668, 18.737113773822784, 5.380681324750185, 0.8561406098306179, 0.050168043744633906, 0.025832539031398483, 0.025380509869137313, 0.05338414070138242, 0.03190164832631126, 0.033367590367561206, 0.020065103490196634, 0.039495262535638176, 0.06501581752672791, 0.039983406459214166, 0.0438602040958358, 0.00524067767400993, 0.04592543038597796, 0.042953318188665435, 0.1010032114572823, 0.047995569693739526, 0.009291010774177266, 0.05505955021362752, 0.024769015435595065, 0.04300120897823945, 0.043907241415581666, 0.058568799213389866, 0.02092365517455619, 0.028221978100191336, 0.032407514736405574, 0.039727243056404404, 0.03099244506302057, 0.0035118110326948226, 0.01819363340473501, 0.04212174542772118, 0.061741269018966705, 0.060635179543169215, 0.04537834509392269, 0.05136299798323307, 0.06134788251074497, 0.014775129584450042, 0.027292888989904895, 0.017738418573571835, 0.05227675617788918, 0.06462681340053678, 0.053622418345185, 0.04693495902756695, 0.04121328245673794, 0.01172587762994226, 0.11161996051669121, 0.02687211352167651, 0.023851147598179523, 0.015391257802548353, 0.07139963083318435, 0.03461217573203612, 0.013309920414030785, 0.07605774299008772, 0.05314687979989685, 0.06959796344744973, 0.05924882170802448, 0.045461710542440414, 0.05399205983849242, 0.08281703107059002, 0.023580575398227666, 0.028338491574686486, 0.037757995014544576, 0.018741102758212946, 0.05938955146120861, 0.09395817425684072, 0.03131301389657892, 0.036247212410671636, 0.015373467595054535, 0.17627101246034727, 3.389653475023806, 23.888544850051403, 39.24518331885338, 27.87861194461584, 18.958759680390358, 21.09742172062397, 27.544303983449936, 47.322029918432236, 25.447268709540367, 6.34747389703989, 0.9337743034120649, 0.22990083001786843, 0.4458420997252688, 3.778102118521929, 4.36801191419363, 3.8503158185631037, 4.353731330484152, 4.113435074687004, 4.82551496475935, 3.3949126303195953, 0.9778147120960057, 0.5247389583382756, 4.46348606608808, 17.775877453386784, 37.755439057946205, 50.88740520179272, 56.78340442478657, 56.126423478126526, 55.0253451615572, 58.53828705847263, 56.6006950289011, 55.98858207464218, 55.33368721604347, 55.799519419670105, 56.05763576924801, 57.88616605103016, 57.73980550467968, 54.3780042976141, 52.40546174347401, 47.37990841269493, 47.07385763525963, 47.420387640595436, 44.76278364658356, 46.45240098237991, 45.94587296247482, 46.74201384186745, 44.21946980059147, 49.18109156191349, 53.26458424329758, 56.76549218595028, 55.47536641359329, 58.833763003349304, 39.19064864516258, 48.38687717914581, 49.477616250514984, 54.68275174498558, 57.124626114964485, 52.099144980311394, 50.626469403505325, 45.47257035970688, 44.53738734126091, 44.757558926939964, 42.51138545572758, 43.56303982436657, 48.55854816734791, 53.01277555525303, 54.15192782878876, 54.11390706896782, 52.74756878614426, 52.785589545965195, 52.87725202739239, 53.915686905384064, 52.14186988770962, 50.81694558262825, 51.14060461521149, 50.41435718536377, 51.43558278679848, 52.562685906887054, 50.202674344182014, 50.780684128403664, 48.42363640666008, 44.94385913014412, 34.40363511443138, 23.873155675828457, 13.02837135270238, 6.272353352978826, 3.58830729033798, 1.1291073937900364, 3.11729168985039, 5.623544342815876, 4.8127770982682705, 3.087334572337568, 4.391482779756188, 3.9479432674124837, 2.740933522582054, 0.7623412180691957, 0.03032992983207805, 0.3757571760797873, 2.606546371243894, 13.987959511578083, 31.26759309321642, 29.22440852969885, 22.925116047263145, 26.277370266616344, 28.87779302895069, 24.02993716299534, 9.17882926762104, 1.5500662615522742, 0.028537212747323792, 0.055174753797473386, 0.0295317091877223, 0.06244811273063533, 0.05054010092862882, 0.039401299218297936, 0.02258066499052802, 0.03282063495134935, 0.05133310056407936, 0.012617480861081276, 0.09441423142561689, 0.07614552421728149, 0.04352735457359813, 0.10260583483614028, 0.05579732664045878, 0.04598766317940317, 0.05436256593384314, 0.014533101311826613, 0.01145078667832422, 0.08095765428151935, 0.03715752704010811, 0.030310047695820685, 0.022998212116362993, 0.062184898924897425, 0.06336292848573066, 0.007446330828315695, 0.024780915773590095, 0.018344582531426568, 0.039688076212769374, 0.021712858724640682, 0.16613747575320303, 0.251205203239806, 0.13924130180384964, 0.12071227887645364, 0.15312592004192993, 0.10417100202175789, 0.1325117886881344, 0.1603733334923163, 0.10209460640908219, 0.21409445005701855, 0.2507111703744158, 0.19898770755389705, 0.1654971655807458, 0.1234072916849982, 0.2608467702521011, 0.11785308073740453, 0.13826205278746784, 0.12246846745256335, 0.2302987696020864, 0.15185830212431028, 0.08353978642844595, 0.11177582637174055, 0.11837656202260405, 0.13063362071989104, 0.18295409681741148, 0.12451222341042012, 0.2695884683635086, 0.11090252635767683, 0.14397403690963984, 0.11274889329797588, 0.10007062126533128, 0.1148245319200214, 0.11252583339228295, 0.12191396439447999, 0.2361257272423245, 0.15208957018330693, 0.25747854786459357, 0.22306501166895032, 3.829194651916623, 26.948038078844547, 47.3509805649519, 36.4129862934351, 25.49635447561741, 27.73310635238886, 30.179147198796272, 48.52882996201515, 31.073782593011856, 9.200908932834864, 1.4588500186800957, 0.462435067165643, 2.5197124807164073, 12.129845917224884, 10.377670638263226, 6.538161439821124, 8.599161822348833, 5.4414785373955965, 7.588227493688464, 3.7194674648344517, 1.2357877381145954, 0.6942429346963763, 3.6218371661379933, 15.997956655919552, 36.45429767668247, 53.100349456071854, 58.79750914871693, 60.576094910502434, 58.65679129958153, 59.620297998189926, 56.339421048760414, 56.369272246956825, 55.56285671889782, 55.176284462213516, 56.39768332242966, 58.93524795770645, 60.528829246759415, 56.448471397161484, 54.25911247730255, 50.62812611460686, 49.66812662780285, 49.7054748237133, 47.355893701314926, 50.207218900322914, 47.226750031113625, 49.476647302508354, 46.53907433152199, 51.642842665314674, 56.33008874952793, 59.58431392908096, 59.17809672653675, 61.028540432453156, 42.79390789568424, 51.02946437895298, 53.68019834160805, 55.491781532764435, 59.08553369343281, 52.66689911484718, 52.77949087321758, 47.61473201215267, 47.544067203998566, 46.991166472435, 44.882997795939445, 45.39739899337292, 52.730013728141785, 56.288819164037704, 55.47835685312748, 54.86510016024113, 53.00457179546356, 54.40895363688469, 53.727916181087494, 55.784453228116035, 54.62565220892429, 50.50228826701641, 52.53307409584522, 51.51087574660778, 52.26865768432617, 54.350201189517975, 49.93684060871601, 50.04486121237278, 48.64425256848335, 42.66465403139591, 33.19210812449455, 22.458521984517574, 11.61912577226758, 4.784676656126976, 2.3993710381910205, 1.11057412577793, 5.3342231176793575, 10.119236055761576, 7.052220180630684, 7.83576806075871, 7.158223567530513, 9.679369758814573, 9.530258160084486, 5.248791826888919, 3.034533793106675, 1.0738087235949934, 4.636535430327058, 16.920613646507263, 36.64130084216595, 32.51742772758007, 31.28110896795988, 35.09389087557793, 35.49403600394726, 26.55629049986601, 9.304703213274479, 1.6248589544557035, 0.16589871200267226, 0.17356787313474342, 0.14494381612166762, 0.23576311388751492, 0.16695505531970412, 0.10772559253382497, 0.20061130402609706, 0.12430431816028431, 0.10573319319519214, 0.12275360801140778, 0.1919140902464278, 0.11803881061496213, 0.1178639532008674, 0.16446173598524183, 0.22684576426399872, 0.1070686434104573, 0.13746611424721777, 0.13354828697629273, 0.10312590966350399, 0.1621069310931489, 0.15102145640412346, 0.09527330446871929, 0.14403275563381612, 0.1262175154988654, 0.15312053204979748, 0.16302866366459057, 0.18565665726782754, 0.13953943736851215, 0.0800227040599566, 0.13649459840962663], [0.021901236214034725, 0.012824572531826561, 0.03729113217559643, 0.0445863955974346, 0.04531410479103215, 0.04089312737050932, 0.014143786411295878, 0.02952193324745167, 0.04222584277158603, 0.028354978385323193, 0.04285783346858807, 0.008735122682992369, 0.062371849635383114, 0.040408512359135784, 0.021320963933249004, 0.03529604626237415, 0.01337380541372113, 0.0391355250030756, 0.09582767394022085, 0.021490240396815352, 0.03682262176880613, 0.020537317213893402, 0.030658233699796256, 0.005410417052189587, 0.058073790423804894, 0.014441997118410654, 0.02142926739907125, 0.033112632954725996, 0.06500741641502827, 0.04026587157568429, 0.08076795391389169, 0.03463178698439151, 0.07881293655373156, 0.04816530999960378, 0.0267442600306822, 0.05787093177787028, 0.08295239138533361, 0.04895104400929995, 0.12501859077019617, 2.253147759474814, 15.34788753837347, 34.37346093356609, 32.321909219026566, 21.936980970203876, 17.77698889374733, 15.558398142457008, 37.90178060531616, 28.623235188424587, 8.654680643230677, 1.654424099251628, 0.2252506068907678, 3.715135222300887, 3.121001240797341, 1.5156478271819651, 5.489999083802104, 2.3972866125404835, 3.158656032755971, 2.7898176619783044, 1.4144575945101678, 0.532135380199179, 0.4509263456566259, 0.874702138826251, 11.12107414752245, 31.631864346563816, 43.476864248514175, 48.464442417025566, 52.94710747897625, 51.52088060975075, 50.86790084838867, 53.59198607504368, 55.38219541311264, 58.58882054686546, 55.81009045243263, 57.26811781525612, 58.366631269454956, 56.988392025232315, 52.964407950639725, 51.44867308437824, 46.524167731404305, 48.11387322843075, 47.324173003435135, 46.895457208156586, 44.68054085969925, 47.00030118227005, 43.63102577626705, 45.86136169731617, 49.21597369015217, 56.75441578030586, 52.37890876829624, 60.2096463739872, 39.887307062745094, 39.4993706792593, 54.480613991618156, 49.396547600626945, 55.820083916187286, 51.05930037796497, 51.24611355364323, 45.412985756993294, 45.120025277137756, 44.19399596750736, 43.77952940762043, 46.570054069161415, 50.82885034382343, 53.13017785549164, 52.6242958009243, 54.56857927143574, 52.50591315329075, 52.55270004272461, 51.693900525569916, 50.738270804286, 49.19973336160183, 50.12287862598896, 49.22329589724541, 50.664851143956184, 52.44282893836498, 49.21410419046879, 46.492876410484314, 42.53108739852905, 32.63310492038727, 23.13227903097868, 15.33574528992176, 5.846927231177688, 1.248558140359819, 0.581139272544533, 1.6967964568175375, 1.1011970601975918, 2.467954745516181, 3.116819802671671, 2.6301381178200245, 1.2885323516093194, 4.259811295196414, 4.701860100030899, 1.899116006679833, 0.8419157168827951, 0.24805260443827137, 2.394796321168542, 13.882552217692137, 29.33152288198471, 26.71446841210127, 19.83380902558565, 21.798079423606396, 23.569303080439568, 15.6165312230587, 4.752211673185229, 0.6548917118925601, 0.10965136927552521, 0.04879527463344857, 0.09485810252954252, 0.03692461883474607, 0.02219325277110329, 0.022397367501980625, 0.02572736186266411, 0.04364566775620915, 0.09181894100038335, 0.021998008560331073, 0.07971029699547216, 0.04495445631619077, 0.026914208137895912, 0.04335594072472304, 0.022463099521701224, 0.05268753862765152, 0.02560291854024399, 0.05857574571564328, 0.04261530331859831, 0.08682016079546884, 0.035990017422591336, 0.04241296788677573, 0.0917377945734188, 0.08794398760073818, 0.01508687799287145, 0.04437014118593652, 0.009045087153936038, 0.044728513166774064, 0.0266584102428169, 0.029232052220322657, 0.07526113651692867, 0.009729176617838675, 0.029359232212300412, 0.022076251334510744, 0.07318523072171956, 0.02858849515178008, 0.017892343712446745, 0.02319810402696021, 0.04385761028970592, 0.04322620588936843, 0.04047575464937836, 0.012980471783521352, 0.00941841897656559, 0.015588240494253114, 0.10968323709676042, 0.029683415305044036, 0.027498003764776513, 0.07837549987016246, 0.09513329088804312, 0.07759761036140844, 0.018801556252583396, 0.01898521924886154, 0.04256282605638262, 0.0839369987079408, 0.06567913427716121, 0.011300973037577933, 0.02715109796554316, 0.07981697330251336, 0.060557042525033467, 0.02007755116210319, 0.0255972726517939, 0.02687998399778735, 0.017785099662432913, 0.025419288940611295, 0.03405287097848486, 0.03266964871727396, 0.0224949302355526, 0.08848617842886597, 0.03991727739048656, 0.05536422038858291, 4.328066082671285, 23.470439985394478, 37.871393635869026, 33.14460687339306, 19.396291002631187, 16.448319889605045, 27.326520569622517, 52.18632750213146, 28.03256068378687, 7.100520338863134, 1.8931560264900327, 0.10371503391070291, 0.5562569014728069, 1.246669760439545, 1.9083682727068663, 3.7693765992298722, 3.9491421030834317, 5.16291406005621, 3.851742404513061, 2.995479963719845, 0.6607382919173688, 0.92686039628461, 2.207333855330944, 15.927362143993378, 34.19175088405609, 46.68244443833828, 51.828128322958946, 57.29311287403107, 52.689694091677666, 52.70709715783596, 55.16422010958195, 57.42282271385193, 57.625621631741524, 56.35620474815369, 58.47810588777065, 59.901794493198395, 59.332573637366295, 56.040567085146904, 51.60105250775814, 47.644172832369804, 49.55921687185764, 48.38040232658386, 48.08599032461643, 46.72444738447666, 48.14989149570465, 45.21263390779495, 47.64769904315472, 52.03578718006611, 56.689743250608444, 53.634285405278206, 60.241560861468315, 40.70627711713314, 45.82188941538334, 54.516620859503746, 49.20080490410328, 57.17550538480282, 52.20416374504566, 53.299500569701195, 47.42866739630699, 46.29489183425903, 45.095421597361565, 45.757615864276886, 46.15554951131344, 53.09260927140713, 54.6219702064991, 53.76765064895153, 54.724268317222595, 52.66466103494167, 52.377582639455795, 52.615012899041176, 53.3319166302681, 49.67337414622307, 51.88552804291248, 51.00240223109722, 52.04457230865955, 53.30246441066265, 51.01154454052448, 47.53608003258705, 45.41156083345413, 34.004660323262215, 26.171817630529404, 17.731417939066887, 8.055247608572245, 2.2049535205587745, 1.559241700451821, 3.9632296096533537, 1.4499307097867131, 4.260137602686882, 4.193463530391455, 4.8716924618929625, 5.170028703287244, 5.875757234171033, 3.3224856667220592, 1.177132660523057, 0.3400750126456842, 0.22446464281529188, 2.139000459574163, 14.423987064510584, 30.07034383714199, 32.212000116705894, 22.57612567394972, 24.215251319110394, 27.758709378540516, 21.468646600842476, 8.559274412691593, 1.6076040803454816, 0.18147735652746633, 0.0249629274912877, 0.03333436441607773, 0.018164183129556477, 0.05279564356897026, 0.05242026527412236, 0.041922809032257646, 0.05455360958876554, 0.09073852983419783, 0.024245253989647608, 0.023142763930081856, 0.034958012838615105, 0.09393098938744515, 0.04030266354675405, 0.033600880778976716, 0.06146932384581305, 0.09195659455144778, 0.029717062425334007, 0.006694077419524547, 0.07356431233347394, 0.09039452212164178, 0.042567631462588906, 0.02272718535095919, 0.08166880244971253, 0.020317671187513042, 0.03445534879574552, 0.04496589652262628, 0.015349556524597574, 0.0267284355868469, 0.0452937105728779, 0.04256972060829867, 0.08358037448488176, 0.1527800050098449, 0.2295079073519446, 0.2478709860588424, 0.11222361601539887, 0.11081046293838881, 0.09504408473731019, 0.2675220026867464, 0.09968883081455715, 0.14918563538230956, 0.11412229694542475, 0.1366457887343131, 0.10750560511951335, 0.24559618468629196, 0.11492150093545206, 0.1529136361205019, 0.14653575257398188, 0.22113529412308708, 0.21507855271920562, 0.09722725313622504, 0.11743874711100943, 0.11819365972769447, 0.21840191970113665, 0.18143567751394585, 0.1683227889589034, 0.10174141090828925, 0.15622183360392228, 0.16737899975851178, 0.17108527041273192, 0.09521873435005546, 0.1596389338374138, 0.1571738754864782, 0.15503746981266886, 0.12426930363290012, 0.09904201942845248, 0.1672003054409288, 0.18585559737402946, 0.10758605392766185, 0.21063881751615554, 4.865089841187, 26.407526582479477, 47.49218098819256, 41.910390704870224, 30.28940588235855, 27.383878491818905, 23.496816270053387, 50.16738183796406, 32.04173505306244, 10.902751162648201, 2.3737931856885552, 0.4197030054638162, 6.062069786712527, 7.808208614587784, 7.130457507446408, 10.688217524439096, 8.84484713897109, 10.382068902254105, 7.040122579783201, 3.7503795186057687, 1.5151157369837165, 0.8605756249744445, 1.9760019122622907, 14.407872129231691, 34.14029024541378, 47.50607684254646, 52.952875569462776, 57.57561631500721, 57.60160692036152, 54.96222674846649, 54.73552331328392, 58.06425869464874, 56.019060239195824, 55.578990653157234, 59.24355961382389, 62.78500758111477, 61.83368302881718, 58.96276228129864, 55.21086260676384, 50.52559621632099, 53.359252363443375, 51.90382406115532, 50.894924998283386, 49.01111148297787, 50.153402388095856, 47.592826187610626, 49.720886796712875, 54.37326215207577, 58.633696138858795, 56.601907163858414, 62.13266618549824, 45.87480917572975, 47.65564441680908, 56.1759652197361, 53.52156825363636, 60.94431795179844, 56.10378049314022, 54.54121693968773, 50.09655363857746, 49.13118124008179, 48.20047438144684, 48.27373065054417, 51.070980951189995, 54.73775379359722, 58.16476710140705, 53.87486569583416, 55.78004166483879, 52.636964321136475, 53.183367401361465, 53.593270406126976, 54.428055211901665, 52.564015835523605, 53.069582507014275, 52.003386318683624, 53.476742058992386, 53.7614493817091, 50.485458970069885, 48.842769116163254, 42.85257674753666, 34.396924674510956, 25.022347010672092, 17.065374478697777, 7.360813971608877, 1.8618249264545739, 1.6938976873643696, 3.732380596920848, 2.594007281586528, 6.478630509227514, 8.612047880887985, 9.78277076035738, 5.487486468628049, 9.659359082579613, 9.9064427241683, 5.413306849077344, 3.1886319117620587, 0.6549392093438655, 3.562595257535577, 17.33637023717165, 35.28936758637428, 35.50666272640228, 28.716280795633793, 31.30194514989853, 33.96278657019138, 23.173683509230614, 7.243749853223562, 1.2870378443039954, 0.2154177735792473, 0.18709930329350755, 0.22039859381038696, 0.11554552838788368, 0.20414999773493037, 0.19556496699806303, 0.11834418954094872, 0.12385794601868838, 0.15469320234842598, 0.07795200071996078, 0.1458317512879148, 0.10854450796614401, 0.23426587547874078, 0.13028847752138972, 0.1277218636823818, 0.12649813637835905, 0.15435205190442502, 0.09960981435142457, 0.19742968725040555, 0.14329626312246546, 0.23819204448955134, 0.16181324841454625, 0.11857576188049279, 0.23449139931472018, 0.11247378657571971, 0.09696764987893403, 0.11936168884858489, 0.12822723656427115, 0.0670231637195684, 0.09096220572246239, 0.15812931640539318], [0.05930959989200346, 0.08819302267511375, 0.04795785374881234, 0.024377541813009884, 0.04392372822621837, 0.0391064216819359, 0.05890904052648693, 0.03815842450421769, 0.01737349713948788, 0.0852829948416911, 0.016794701732578687, 0.03142831024888437, 0.057667138025863096, 0.010346034923713887, 0.02969449556985637, 0.024130903875629883, 0.05636703259369824, 0.041496126068523154, 0.042464543439564295, 0.017608088164706714, 0.029853205705876462, 0.019977177544205915, 0.036611221003113315, 0.025985436295741238, 0.023075803655956406, 0.027011442471120972, 0.0352011329960078, 0.062272401846712455, 0.048418794249300845, 0.08970923779997975, 0.03198132530087605, 0.07937739181215875, 0.05927957630774472, 0.11081374323111959, 0.06969392314204015, 0.07027029729215428, 0.028130068676546216, 0.029306610231287777, 0.11362747740349732, 0.059694960073102266, 2.4001944065093994, 14.354118313640356, 33.427893072366714, 32.75626391172409, 18.260153867304325, 16.633970327675343, 16.523274667561054, 32.372921481728554, 26.80271677672863, 9.819423593580723, 1.455787739250809, 0.5834423645865172, 1.2658928101882339, 1.9012931711040437, 1.3859903533011675, 3.3972742035984993, 3.428940041922033, 3.399999369867146, 1.6867638076655567, 0.9390006260946393, 0.7316466432530433, 0.11963679557084106, 1.0615439317189157, 7.7654979564249516, 22.475047297775745, 38.26218746602535, 38.795884028077126, 52.23228223621845, 49.403071850538254, 47.74728409945965, 56.0560018569231, 57.648150622844696, 59.869929403066635, 56.97405159473419, 57.1035448461771, 58.8459337502718, 54.81330893933773, 55.435134172439575, 53.31697963178158, 53.111790642142296, 53.59835833311081, 53.0742334574461, 52.17791475355625, 51.42494335770607, 49.37346003949642, 48.70328240096569, 48.731165304780006, 55.3112456202507, 51.70269325375557, 62.009799778461456, 51.17055460810661, 42.29523405432701, 57.475651279091835, 54.963036105036736, 58.74287188053131, 52.11798056960106, 52.00314313173294, 47.193205431103706, 46.40538230538368, 46.3864441215992, 48.60948823392391, 50.20531140267849, 51.887690126895905, 53.20095285773277, 56.55249081552029, 55.150472447276115, 55.52634447813034, 53.38782303035259, 49.907122403383255, 52.380196899175644, 53.06245028972626, 52.19213359057903, 51.669125854969025, 52.24366642534733, 48.21054004132748, 43.93258519470692, 29.655841179192066, 22.07308016717434, 13.41030215844512, 7.137415884062648, 1.9217360741458833, 0.8761980116833001, 0.2215373155195266, 0.8649835071992129, 4.5739413890987635, 1.160610078368336, 3.022814034484327, 3.499328177422285, 4.7054841555655, 5.079399291425943, 3.631108431145549, 1.420160613488406, 0.9014084713999182, 0.23826330550946295, 2.358513968065381, 14.010573998093605, 26.897054314613342, 31.725631915032864, 22.302344664931297, 24.8431334272027, 24.455341435968876, 15.08277291432023, 2.192261964082718, 0.12040134126436897, 0.032179066838580184, 0.03247237473260611, 0.018356258369749412, 0.021128562148078345, 0.02853887515811948, 0.08073214528849348, 0.08553728432161734, 0.029996195298735984, 0.008240629686042666, 0.03949239784560632, 0.06835606836830266, 0.0416976043197792, 0.040760613192105666, 0.024665769706189167, 0.02946106600575149, 0.04401355778099969, 0.06875541803310625, 0.030791543831583112, 0.08901443172362633, 0.05335477020707913, 0.06982130536925979, 0.005418818627731525, 0.06112411014328245, 0.006381623043125728, 0.02467427842930192, 0.018622060415509623, 0.027903661684831604, 0.015109798296180088, 0.040592468503746204, 0.028428922269085888, 0.039059447444742545, 0.009969369930331595, 0.10306030380888842, 0.03831433488812763, 0.06002644033287652, 0.04010514836409129, 0.01648100333113689, 0.04567335250612814, 0.05045711397542618, 0.051207595970481634, 0.06547239419887774, 0.0784954680420924, 0.03581731965823565, 0.0201686887521646, 0.01078575371138868, 0.05053152170148678, 0.025730755332915578, 0.058919590155710466, 0.07210419615148567, 0.05100611029774882, 0.03618977760197595, 0.0806710145843681, 0.02034391352935927, 0.03175483667291701, 0.04328286515374202, 0.07261958060553297, 0.02367953522480093, 0.008570467016397743, 0.009862833703664364, 0.057274779392173514, 0.05232112176599912, 0.0960984687844757, 0.019895960613212083, 0.029321827969397418, 0.016306338875438087, 0.05210839997744188, 0.020872044369752984, 0.06665056105703115, 0.022211355608305894, 0.04535570587904658, 0.08011633341084234, 0.06118230194260832, 5.105260228738189, 21.833596117794514, 38.24368625879288, 32.01348356902599, 16.281533539295197, 14.701801557093859, 23.236376345157623, 42.51960441470146, 25.083917006850243, 8.422193918377161, 1.4206341630779207, 0.22698583721648902, 0.2368228413979523, 0.9249384119175375, 1.4003256778232753, 5.739178312942386, 4.647225681692362, 4.87928825430572, 3.2578853331506252, 2.4546480970457196, 1.5083639742806554, 0.39112969650886953, 2.4038863833993673, 11.454808339476585, 27.125532254576683, 40.01915618777275, 44.21850085258484, 56.80010832846165, 52.1181857585907, 50.1800237596035, 57.45087280869484, 58.968617767095566, 60.68161904811859, 56.60653531551361, 59.469047114253044, 60.763413459062576, 59.057403802871704, 55.35863667726517, 54.3804057687521, 53.69448937475681, 56.00682869553566, 54.87661354243755, 52.61991083621979, 52.444941624999046, 51.08581155538559, 50.4916450381279, 50.28697282075882, 56.19798883795738, 54.35714341700077, 63.51822763681412, 51.51376359164715, 42.89148285984993, 58.84120300412178, 54.22935627400875, 59.751565754413605, 53.93717095255852, 53.73781464993954, 49.85221914947033, 47.58964955806732, 48.772917464375496, 50.38552813231945, 52.50944696366787, 54.36722047626972, 54.620799869298935, 56.05467952787876, 55.745752304792404, 54.72247861325741, 55.17311543226242, 50.93962199985981, 53.66397321224213, 53.4570287168026, 53.59334260225296, 53.02383296191692, 54.88203585147858, 50.4345341026783, 46.94229729473591, 33.81031975150108, 25.774588845670223, 16.707230396568775, 9.948022942990065, 5.207770178094506, 2.2796867229044437, 0.6302533589769155, 2.72087796125561, 5.636351080611348, 2.361606527119875, 4.695285502821207, 4.404278118163347, 5.350240683183074, 4.650188097730279, 4.416464539244771, 2.118546632118523, 0.4371972073568031, 0.19187836325727403, 1.5891265030950308, 13.139027114957571, 28.680788800120354, 35.977176278829575, 25.791241452097893, 25.21180484443903, 26.501292251050472, 20.47472633421421, 5.237410012632608, 0.4838039627065882, 0.015629483496013563, 0.049338656608597375, 0.05329193998477422, 0.014138139595161192, 0.042510126149863936, 0.01618591799342539, 0.08356176142115146, 0.017779527988750488, 0.054263107012957335, 0.07201337211881764, 0.015058571552799549, 0.040037535000010394, 0.032115171634359285, 0.01142489036283223, 0.029476526797225233, 0.029531356667575892, 0.03896184018230997, 0.039513370938948356, 0.08729596651392058, 0.04152383415203076, 0.005764750821981579, 0.04130667060962878, 0.05066445148258936, 0.00902122617844725, 0.05663234296662267, 0.11507416813401505, 0.014913636605342617, 0.04183532466413453, 0.017162092663056683, 0.048152062663575634, 0.008547971592633985, 0.040855541301425546, 0.1435180168482475, 0.21583156543783844, 0.08916736609535292, 0.13053159025730565, 0.07511931951739825, 0.09278463097871281, 0.18895588960731402, 0.20332046959083527, 0.15252492885338143, 0.2894027129514143, 0.07825755776138976, 0.13783435308141634, 0.139677046390716, 0.1529044334893115, 0.117786933114985, 0.12979362829355523, 0.1563342392910272, 0.15561052656266838, 0.08401856815908104, 0.2124925539828837, 0.10335917409975082, 0.0806546353851445, 0.21980972931487486, 0.13728216552408412, 0.11652238026726991, 0.10535000750678591, 0.11670024337945506, 0.15858202648814768, 0.13004929816816002, 0.17207434546435252, 0.11346580053213984, 0.4181404580594972, 0.15625319676473737, 0.1740815580706112, 0.16957715211901814, 0.27468087791930884, 0.085353929316625, 0.18966514529893175, 0.20437267172383144, 0.21227376884780824, 5.55374588817358, 23.287219516932964, 47.70019322633743, 41.936202719807625, 26.464667916297913, 25.887566283345222, 23.871225379407406, 42.54411309957504, 31.62389427423477, 13.087063003331423, 2.546823788434267, 0.5341892887372524, 2.8843459021300077, 6.745543861761689, 7.962992833927274, 8.939603604376316, 9.686363283544779, 8.757110796868801, 4.448092142120004, 2.616165792569518, 2.9842898016795516, 0.5659874668344855, 1.7465082393027842, 9.26796868443489, 25.270730182528496, 39.66164097189903, 45.1440741866827, 56.20798610150814, 56.990466713905334, 51.23564891517162, 58.22907865047455, 56.5467569231987, 59.73795488476753, 56.13400787115097, 59.69790503382683, 64.3557558953762, 62.49113515019417, 59.014906883239746, 58.461299389600754, 56.22991092503071, 59.52053055167198, 58.247545659542084, 56.23321294784546, 55.29003515839577, 53.212264850735664, 53.526519387960434, 52.77708560228348, 58.94155561923981, 57.970251739025116, 63.49810391664505, 54.91507887840271, 45.27863636612892, 55.88924400508404, 56.07039928436279, 62.95485086739063, 55.960440784692764, 56.44896537065506, 50.17205938696861, 50.97637742757797, 51.08885519206524, 52.38663375377655, 54.14753146469593, 57.254419550299644, 56.76910199224949, 58.31955559551716, 55.98380573093891, 56.13016627728939, 54.618766978383064, 53.31122674047947, 54.669319465756416, 55.648184940218925, 56.017053946852684, 55.0090554356575, 54.58138458430767, 49.482521787285805, 46.228820979595184, 31.97513222694397, 23.89994613826275, 15.08477445691824, 7.73259362205863, 2.7189248660579324, 1.2918170378543437, 0.6901939550880343, 2.898815288208425, 8.907167594879866, 5.134613653644919, 6.558370655402541, 7.373803574591875, 9.489335305988789, 12.518857643008232, 8.364838846027851, 5.257120979949832, 2.61365816462785, 0.3319978038780391, 2.8326283022761345, 16.30677368491888, 32.48574882745743, 41.71038843691349, 31.820480525493622, 32.77221545577049, 34.54814895987511, 21.58378802239895, 4.241407457739115, 0.3904153942130506, 0.17209420533617958, 0.19416367344092578, 0.1016950118355453, 0.09140240319538862, 0.16491441638208926, 0.1867141286493279, 0.18841424054699019, 0.1260106492554769, 0.1638393709436059, 0.16800715355202556, 0.18042568874079734, 0.09968246318749152, 0.149035305948928, 0.06702741622575559, 0.10654988218448125, 0.09569513378664851, 0.24460770335281268, 0.11205539340153337, 0.17786435899324715, 0.15382530516944826, 0.135819184652064, 0.1150761941971723, 0.1300653285579756, 0.09996018226956949, 0.09786454276763834, 0.15891290560830384, 0.07098013928043656, 0.09534245036775246, 0.11418792506447062, 0.11033380375010893, 0.1349015487357974, 0.13398869225056842], [0.0929596294008661, 0.038781906478106976, 0.08500635187374428, 0.04326542839407921, 0.016049398072937038, 0.06866071256808937, 0.024974638581625186, 0.06546145494212396, 0.03739299936569296, 0.09200827029417269, 0.026826551220437977, 0.04554640814603772, 0.050400966792949475, 0.11535083336639218, 0.01942588984093163, 0.05970843747491017, 0.061392463321681134, 0.02262252768559847, 0.01227087192091858, 0.05042901626438834, 0.01877486862213118, 0.020868394858553074, 0.03507809233269654, 0.03499981059576385, 0.00658376458886778, 0.04814244071894791, 0.006523462307086447, 0.05078758862509858, 0.05194661920540966, 0.05852676025824621, 0.0040529157740820665, 0.07443482187227346, 0.04059960054291878, 0.022677940141875297, 0.042392900213599205, 0.019776901572186034, 0.036775818225578405, 0.021032027289038524, 0.01210322910992545, 0.052097987645538524, 0.1848512192373164, 1.6056349547579885, 16.947968378663063, 35.57467147707939, 35.54676577448845, 25.072179436683655, 18.75864151865244, 23.408774994313717, 19.544427953660488, 17.899710908532143, 14.196830503642559, 3.9505900628864765, 0.5700987868476659, 0.045922691861051135, 0.9716100012883544, 4.042221195995808, 2.6127758994698524, 2.9837583051994443, 3.3753633918240666, 1.7666145041584969, 0.6585243763402104, 0.13528544688597322, 0.37010821513831615, 0.8094689017161727, 5.053969630971551, 11.076614633202553, 23.052464313805103, 28.33571031689644, 47.60220028460026, 43.641585409641266, 46.34142033755779, 64.4694609940052, 56.65676862001419, 56.67476065456867, 58.38653840124607, 58.95155668258667, 57.43033871054649, 57.48792842030525, 53.90855088829994, 56.76258534193039, 57.9463966190815, 58.537371307611465, 55.79782471060753, 57.204041853547096, 55.135672241449356, 54.72814790904522, 52.50447303056717, 55.10394014418125, 53.81728358566761, 59.30077314376831, 47.31577165424824, 47.50872530043125, 60.028741881251335, 55.283963084220886, 54.920425191521645, 53.474777564406395, 52.550252974033356, 49.47906777262688, 49.718983098864555, 49.67189222574234, 51.76166228950024, 54.53551344573498, 54.3061463534832, 56.73256695270538, 55.853525921702385, 56.73323191702366, 54.39951874315739, 52.27429658174515, 53.32734167575836, 53.23363110423088, 51.72728173434734, 52.47241795063019, 50.066398456692696, 46.831829622387886, 32.79784508049488, 19.7600606828928, 11.444657184183598, 6.206121006980538, 2.7042852016165853, 1.191684810910374, 1.5642092213965952, 1.3521008030511439, 0.3230183810228482, 1.996290567331016, 3.1543180905282497, 1.893933559767902, 4.5342909917235374, 3.3121723076328635, 2.872122433036566, 5.230156201869249, 4.456308726221323, 1.8688204698264599, 0.2884511015145108, 1.830802084878087, 10.44484818354249, 23.035082146525383, 27.779669053852558, 27.00710590928793, 28.551778122782707, 27.53982212394476, 13.830697350203991, 2.9264065576717257, 0.013595501623058226, 0.049587253815843724, 0.017870185038191266, 0.11085970443673432, 0.0089577187463874, 0.05132841019076295, 0.06733145928592421, 0.04276685358490795, 0.060232104297028854, 0.028702583658741787, 0.021006803544878494, 0.03129556600470096, 0.033333021128783, 0.04848133132327348, 0.037784719752380624, 0.059687627654056996, 0.04638119069568347, 0.012374436773825437, 0.0316858540463727, 0.019745321333175525, 0.02790487509628292, 0.044438396507757716, 0.047735747502883896, 0.10446120402775705, 0.05265650943329092, 0.07141727168345824, 0.015781640468048863, 0.04459795083675999, 0.06217978923814371, 0.08515366818755865, 0.07662282165256329, 0.015025278808025178, 0.05353521970391739, 0.04316999562433921, 0.03279954682511743, 0.04644257373001892, 0.045901830089860596, 0.03267404223151971, 0.0714123438228853, 0.01458560547689558, 0.0431436827784637, 0.049333617425872944, 0.013065496859780978, 0.04227671699482016, 0.03177357961249072, 0.022393365470634308, 0.07326533814193681, 0.02454484230838716, 0.039743618544889614, 0.0842335460765753, 0.011371774853614625, 0.010247313512081746, 0.02754069209913723, 0.011804383866547141, 0.04370902861410286, 0.02124913145962637, 0.03374978528881911, 0.02148486910300562, 0.039762094311299734, 0.04430435350514017, 0.026683043979573995, 0.06869956399896182, 0.03934898522857111, 0.015306370023608906, 0.0735632584837731, 0.02633797499584034, 0.004363926209407509, 0.039114611281547695, 0.04483688157051802, 0.013683708657481475, 0.02404688533715671, 0.011795191439887276, 0.025144699866359588, 0.04025483583973255, 0.03488678892608732, 3.9236590079963207, 23.09218168258667, 38.89049135148525, 33.541643768548965, 18.759025298058987, 13.136326409876347, 29.003013409674168, 31.26196749508381, 23.270139433443546, 12.806927785277367, 2.3597147036343813, 0.4684254457242787, 0.14313195162685588, 1.059563287999481, 2.050872975960374, 3.600174766033888, 6.735590770840645, 6.373041775077581, 4.164875289425254, 3.511964874342084, 1.5663400758057833, 0.8182467869482934, 1.2285866495221853, 7.275272961705923, 16.60103939473629, 26.864056885242462, 34.06142167747021, 50.71396350860596, 45.92520207166672, 51.50947742164135, 63.058174923062325, 56.79427184164524, 56.64693474769592, 59.80338737368584, 61.51550330221653, 59.52841132879257, 59.45145785808563, 55.89633822441101, 58.84272672235966, 59.0617735683918, 60.427496284246445, 58.27306129038334, 58.47281277179718, 55.971555188298225, 56.16985894739628, 53.74906584620476, 58.3741320669651, 56.29247836768627, 59.61690478026867, 49.339144080877304, 49.46395978331566, 57.037382796406746, 55.486499816179276, 58.74299727380276, 55.81430442631245, 54.71465863287449, 50.932432785630226, 51.233437433838844, 50.683185160160065, 54.78364773094654, 56.10710151493549, 55.90384282171726, 58.52935753762722, 55.41667856276035, 56.796255335211754, 55.53603395819664, 53.03379602730274, 53.36283177137375, 53.79762344062328, 51.98809593915939, 54.979732409119606, 50.681786835193634, 48.27597253024578, 35.98486326634884, 24.107927978038788, 13.544926084578037, 9.157149530947208, 4.347398020327091, 2.489714752882719, 2.2841343842446804, 3.141628196462989, 1.8779395055025816, 3.6865861667320132, 6.708516273647547, 2.264468539506197, 5.392537163570523, 4.12080192938447, 3.7438787799328566, 1.8255265429615974, 1.0405602701939642, 0.16252001048997045, 0.16862518445122987, 1.6139229037798941, 10.952378399670124, 26.53485395014286, 29.117282778024673, 30.886266455054283, 30.00313874334097, 31.81207537651062, 19.088819101452827, 5.625732550397515, 0.14713272132212296, 0.05540016260056291, 0.026063571458507795, 0.01271073728275951, 0.028152837767265737, 0.07281337762833573, 0.07677222340134904, 0.02581113549240399, 0.020568016152537894, 0.07925527141196653, 0.03563608348486014, 0.06320982342003845, 0.014664635855297092, 0.05155971535714343, 0.016401829161623027, 0.050963162211701274, 0.05650843399052974, 0.032148794634849764, 0.07448112446581945, 0.0011196137256774819, 0.007545157995991758, 0.04238426161464304, 0.054117067193146795, 0.04161446893704124, 0.0531766584754223, 0.031177672135527246, 0.049944701822823845, 0.01580804237164557, 0.03755947051104158, 0.0360409732820699, 0.019355901604285464, 0.03669146200991236, 0.05391143662563991, 0.01831294477597112, 0.21862310939468443, 0.11533714816323482, 0.16097200918011367, 0.1404214056674391, 0.15829203970497474, 0.21379279671236873, 0.13491936028003693, 0.1917597680585459, 0.1458313356852159, 0.2495238825213164, 0.08581318514188752, 0.10982713953126222, 0.09812875476200134, 0.2730821433942765, 0.14816429174970835, 0.21743617777246982, 0.18127261282643303, 0.09920011914800853, 0.08852738988935016, 0.2048165799351409, 0.12191768997581676, 0.13822858192725107, 0.1343910550349392, 0.1460587594192475, 0.14872161496896297, 0.13361715828068554, 0.13700072828214616, 0.09483027199166827, 0.11035973438993096, 0.1342016292619519, 0.11382471057004295, 0.1704487600363791, 0.10561509523540735, 0.11345221180818044, 0.14052670157980174, 0.1542825868818909, 0.12881259812274948, 0.1391167545807548, 0.15919811296043918, 0.1736630906816572, 0.4563878697808832, 3.854678221978247, 24.456490874290466, 49.56670247018337, 46.166891902685165, 32.53999471664429, 26.947340816259384, 34.92494434118271, 31.038642078638077, 24.020821452140808, 17.20194485038519, 5.603685658425093, 0.8140283601824194, 0.7126318698283285, 3.259829878807068, 11.457056868821383, 8.565564975142479, 8.940506055951118, 10.931849051266909, 5.014002900570631, 3.7366214068606496, 1.311030825600028, 1.0644517256878316, 1.4277954725548625, 6.710877846926451, 13.893622923642397, 25.495225936174393, 33.12772057950497, 50.02133667469025, 50.796977654099464, 51.925034523010254, 63.42650055885315, 55.49682006239891, 58.62862341105938, 59.99540627002716, 63.68527427315712, 61.57613284885883, 62.10922524333, 58.77860136330128, 60.109270960092545, 63.2395201921463, 62.75957554578781, 60.97098492085934, 60.89648611843586, 59.802999794483185, 58.15943978726864, 56.608545407652855, 60.159401670098305, 59.42881107330322, 63.34146872162819, 51.6112207621336, 50.92150837182999, 57.68087446689606, 55.646288841962814, 57.59083069860935, 58.64628866314888, 56.78953729569912, 54.12103548645973, 54.597123339772224, 54.83080320060253, 56.28419481217861, 60.163551047444344, 58.04048717021942, 61.91184863448143, 55.734090730547905, 57.21418350934982, 55.138476490974426, 53.55789050459862, 53.94091755151749, 55.48481650650501, 53.240273147821426, 55.06429687142372, 51.25970162451267, 48.623099103569984, 34.00434873998165, 21.83520533144474, 13.088438529521227, 7.858060514554381, 3.7075805151835084, 2.2144655976444483, 2.6758449152112007, 2.9445059364661574, 1.5559500083327293, 5.3899922501295805, 8.986420892179012, 2.9334687162190676, 11.040773056447506, 10.147911217063665, 9.729461520910263, 13.428344540297985, 9.592689760029316, 3.682010262273252, 0.561611051671207, 2.3027711967006326, 13.246121518313885, 29.79343369603157, 33.74654017388821, 37.62330114841461, 37.50843711197376, 37.363433092832565, 19.523852057754993, 4.803581591695547, 0.19299755163956434, 0.142217566317413, 0.1414876343915239, 0.17790753714507446, 0.1629577440326102, 0.21607184316962957, 0.1891286764293909, 0.09709223420941271, 0.1298454895731993, 0.10882052753004245, 0.134735292813275, 0.20339833572506905, 0.19015131139894947, 0.12300930015044287, 0.10795806287205778, 0.11218756248126738, 0.22069181635743007, 0.0939637552073691, 0.12628037540707737, 0.12441230806871317, 0.14843171724351123, 0.09900886769173667, 0.15753494517412037, 0.23486302234232426, 0.16306421253830194, 0.14137530291918665, 0.12265594137716107, 0.083597273187479, 0.11625822022324428, 0.15494679420953616, 0.18014451867202297, 0.12168662971816957, 0.17354991316096857, 0.15347208740422502], [0.06365749432006851, 0.014447197718254756, 0.047372596091008745, 0.03730234231625218, 0.04035259895317722, 0.05786434521724004, 0.041179488762281835, 0.04318244886235334, 0.03712654237460811, 0.03472660748229828, 0.05671571954735555, 0.04182387703622226, 0.08419914753176272, 0.03704791182826739, 0.1021869592659641, 0.03626889054430649, 0.05312195477017667, 0.060459680171334185, 0.01739065002766438, 0.06245584590942599, 0.06712182483170182, 0.0895755918463692, 0.03362613235367462, 0.034877764410339296, 0.06066799360269215, 0.04267268246621825, 0.0116598274144053, 0.014045454627193976, 0.01513443296062178, 0.018052283958240878, 0.06801079900469631, 0.04346881396486424, 0.017357296055706684, 0.019567333911254536, 0.02104740087816026, 0.03298151401395444, 0.03096258846198907, 0.004673106323025422, 0.04238717825501226, 0.04176428999926429, 0.034547204413684085, 0.012935326012666337, 0.7412376848515123, 13.39844774454832, 29.330061860382557, 36.681559681892395, 27.705191150307655, 15.92010073363781, 18.966207280755043, 11.348350401967764, 16.61145083606243, 15.845486987382174, 4.984516957774758, 0.7963502837810665, 0.17689480242552236, 2.093160431832075, 2.5341657176613808, 5.737487878650427, 4.265334773808718, 3.510355898179114, 3.8135299924761057, 1.2627221178263426, 0.9930441167671233, 0.04120461788261309, 0.7361881714314222, 1.7040245002135634, 4.479310791939497, 10.06341990083456, 13.196335639804602, 32.270817160606384, 29.049616008996964, 40.2962601184845, 61.61682866513729, 57.176128551363945, 55.288488641381264, 58.82275879383087, 56.90928786993027, 60.62829650938511, 58.99200551211834, 58.56681972742081, 57.62173444032669, 58.69829647243023, 56.20490446686745, 56.712150648236275, 55.16511306166649, 58.45127172768116, 53.403861969709396, 56.47252410650253, 55.42379178106785, 64.31739315390587, 53.12991566956043, 42.05312244594097, 57.5421629101038, 59.32737551629543, 57.710687667131424, 54.15285877883434, 53.564080372452736, 51.74632631242275, 51.61847457289696, 52.85992115736008, 54.0910816937685, 54.07044120132923, 55.725499391555786, 59.33168448507786, 57.52183400094509, 56.59645825624466, 50.444170385599136, 53.600839599967, 52.56116598844528, 53.938025906682014, 52.236511409282684, 48.78307431936264, 38.392763659358025, 25.0716607645154, 13.636731058359146, 6.00843851454556, 2.46976344846189, 1.0884606186300516, 0.9682371478993446, 1.2668323097750545, 2.360138618387282, 4.298252407461405, 1.7194775585085154, 4.342704797163606, 6.575208026915789, 0.6899812852498144, 3.341359728947282, 3.2473841216415167, 3.705800548195839, 0.19407304236665368, 0.5277146142907441, 0.5379886692389846, 2.735055238008499, 10.75087996199727, 24.358435235917568, 27.237242460250854, 22.232259325683117, 24.131986387073994, 26.087997928261757, 14.1076834872365, 2.6903437497094274, 0.05222483552643098, 0.03875385700666811, 0.02617948193801567, 0.019147491693729535, 0.049230659278691746, 0.04498478789173532, 0.016563737954129465, 0.06871750912978314, 0.05722048386815004, 0.06177494396979455, 0.07437800304614939, 0.12510172615293413, 0.11013673385605216, 0.06691929273074493, 0.015175806765910238, 0.055528286975459196, 0.013074310791125754, 0.046378095939871855, 0.07166992843849584, 0.026586054555082228, 0.08335655758855864, 0.04939995429595001, 0.06007331809087191, 0.09647167258663103, 0.09944307603291236, 0.06886035029310733, 0.06743389050825499, 0.056988967189681716, 0.024653693108120933, 0.034990248022950254, 0.011730976184480824, 0.04421830890350975, 0.03372859697265085, 0.051870597308152355, 0.04318021499784663, 0.05515475662832614, 0.06126700325694401, 0.019059528640354984, 0.09919028569129296, 0.058998473032261245, 0.014454937390837586, 0.014697927672386868, 0.029339160828385502, 0.020764941327797715, 0.04262067275703885, 0.014032621966180159, 0.01086590194972814, 0.07411519371089526, 0.030934871101635508, 0.04350686016550753, 0.004294915752325323, 0.005799322379971272, 0.027113788346468937, 0.045704504154855385, 0.03326599035062827, 0.030712512525497004, 0.042647787122405134, 0.03120745823252946, 0.050193670103908516, 0.04590626071149018, 0.02939510206488194, 0.04678782825067174, 0.08342012253706343, 0.053010539850220084, 0.037097116219229065, 0.07412658567773178, 0.0895560733624734, 0.03803058214543853, 0.04888793177087791, 0.048199285520240664, 0.07189966025180183, 0.04074713579029776, 0.02400883357040584, 0.04867902091064025, 0.05445085553219542, 0.06541000926517881, 0.012863506526628044, 2.4481965182349086, 19.370192103087902, 36.57434843480587, 34.69181165099144, 25.844900272786617, 19.58750244230032, 21.441531255841255, 20.325116962194443, 29.14352986961603, 19.06147386878729, 3.1288095843046904, 0.3449863975401968, 0.03649014332040679, 0.5731339927297086, 2.140768552199006, 3.5407737409695983, 3.6827604845166206, 4.920361675322056, 7.2535433527082205, 4.47433115914464, 2.3759182216599584, 0.3872018650872633, 1.0152602777816355, 1.8418365740217268, 5.922990124672651, 12.211453188210726, 20.243062265217304, 35.219523534178734, 32.67882026731968, 48.111597150564194, 60.207567885518074, 55.94663992524147, 55.896676406264305, 59.97495576739311, 60.17750769853592, 61.67433477938175, 61.11788123846054, 61.19215585291386, 60.3879252076149, 60.84873028099537, 58.72109904885292, 59.228497222065926, 59.25700329244137, 59.93585966527462, 54.220141768455505, 57.75271721184254, 56.97948910295963, 63.29820804297924, 54.74593475461006, 45.081651136279106, 56.650031581521034, 58.184681832790375, 58.03732953965664, 55.95019273459911, 55.845113173127174, 52.464825958013535, 52.902881652116776, 55.18801063299179, 55.323682352900505, 55.42813494801521, 56.808175295591354, 58.81501480937004, 57.63055756688118, 57.59242661297321, 51.33371405303478, 53.681817054748535, 53.20644736289978, 53.0143790692091, 53.368394672870636, 49.421090483665466, 41.85801811516285, 29.08091302961111, 16.806805953383446, 8.045795615762472, 3.556568780913949, 2.086159070022404, 2.1882187435403466, 2.8241174714639783, 3.047956097871065, 4.6473653241992, 3.0963633628562093, 5.170284239575267, 2.867278642952442, 3.640150520950556, 4.165152674540877, 3.954088487662375, 1.6709560621529818, 0.4122703371103853, 0.16083625552710146, 0.20015682763187215, 2.6160199753940105, 11.971352621912956, 26.358492113649845, 28.13360296189785, 25.827217921614647, 28.788894899189472, 30.680334605276585, 19.19136229902506, 4.8347213957458735, 0.14534583751810715, 0.029129940121492837, 0.05256465381535236, 0.021843155736860353, 0.005206314845054294, 0.039724534217384644, 0.12132412768551148, 0.0147184591878613, 0.04927789697831031, 0.07884217717219144, 0.04926024499582127, 0.04893076853477396, 0.06179200594488066, 0.06651560892350972, 0.009550468384986743, 0.032579789476585574, 0.08689868744113483, 0.05314848654961679, 0.04093106967047788, 0.02393405662587611, 0.06540744885569438, 0.0348278995079454, 0.07505237037548795, 0.07758349471259862, 0.02225537238700781, 0.020160801577731036, 0.01588636492670048, 0.03755471705517266, 0.05018041163566522, 0.09770909993676469, 0.02562345747719519, 0.030997625253803562, 0.061500657320721075, 0.07767515737214126, 0.01469842305596103, 0.14371683821082115, 0.14419230254134163, 0.14863324002362788, 0.11358141971868463, 0.10473500457010232, 0.09120858390815556, 0.1330544173833914, 0.08214863803004846, 0.15289557224605232, 0.17420019779819995, 0.16050099773565307, 0.12852991407271475, 0.24095320492051542, 0.09014170209411532, 0.2708187117241323, 0.07579468874610029, 0.07124404699425213, 0.15799730317667127, 0.12305711672524922, 0.18803289538482204, 0.1293154773884453, 0.15222879708744586, 0.18212122900877148, 0.08096023695543408, 0.1906483425409533, 0.15379839489469305, 0.10366459013312124, 0.18424436508212239, 0.18087936361553147, 0.10727883447543718, 0.11030960973585024, 0.26446577918250114, 0.1623067766195163, 0.17311841365881264, 0.11094899964518845, 0.15401651209685951, 0.15427013364387676, 0.06777142669307068, 0.1928517344640568, 0.10248122081975453, 0.1369559470913373, 0.12054448670824058, 2.373367608524859, 20.138993449509144, 42.75788202881813, 46.44418202340603, 36.24451093375683, 27.569597326219082, 26.525842733681202, 20.37722736597061, 24.98576447367668, 20.230429843068123, 5.878031412139535, 0.9840403217822313, 0.46835137938614935, 5.88650400750339, 7.831918867304921, 12.412630543112755, 10.232340786606073, 11.519761104136705, 9.209646563977003, 4.4751908630132675, 2.8601511754095554, 0.2683589968364686, 1.205036819446832, 2.732830219902098, 5.804770868271589, 10.966904070228338, 17.385632693767548, 33.62253002822399, 35.21719425916672, 46.86013050377369, 58.75557079911232, 55.44491484761238, 56.188721135258675, 61.79961025714874, 62.34777644276619, 63.29246275126934, 63.66638168692589, 61.98208786547184, 62.99745798110962, 62.246276289224625, 60.56115411221981, 59.80535566806793, 61.63954384624958, 63.32023546099663, 57.7015795558691, 59.43169891834259, 59.61829550564289, 64.35837015509605, 57.8586745262146, 48.635543435812, 54.60409216582775, 58.6631103605032, 61.1541198939085, 57.140790447592735, 57.06970766186714, 54.9724406003952, 55.86030475795269, 57.34540946781635, 59.03468482196331, 56.44901856780052, 60.716789960861206, 61.55339866876602, 58.61991807818413, 57.10010603070259, 52.908763736486435, 56.315197348594666, 53.43641482293606, 55.35677097737789, 53.0576853454113, 51.245357394218445, 41.05528078973293, 27.812305502593517, 14.781253393739462, 7.869744412600994, 2.938369265757501, 1.6937397583387792, 1.9215098675340414, 3.123409361578524, 5.034825783222914, 8.544292766600847, 3.4664202807471156, 10.440550614148378, 12.816310431808233, 4.9903971422463655, 8.692877143621445, 10.41527247056365, 9.777105264365673, 3.0226454185321927, 0.9759614802896976, 0.9307462221477181, 3.760661529377103, 13.33516689017415, 30.510196834802628, 34.438247457146645, 31.106134057044983, 36.38365186750889, 37.10079878568649, 20.283505395054817, 4.683935986831784, 0.22162849578307942, 0.21542987058637664, 0.13836332625942305, 0.11359037001966499, 0.1012610038742423, 0.08128920875606127, 0.20296793460147455, 0.10109241760801524, 0.16269353945972398, 0.17454609798733145, 0.13322989078005776, 0.1508151987218298, 0.3857937437715009, 0.18845648359274492, 0.06953175645321608, 0.15418747323565185, 0.2377493682433851, 0.1793387986253947, 0.14338720589876175, 0.15971221349900588, 0.17092079564463347, 0.0922882603481412, 0.1405849601724185, 0.2584599342662841, 0.14089716685703024, 0.1556532148970291, 0.12352360849035904, 0.1676572160795331, 0.11926881648832932, 0.15618514182278886, 0.10698146332288161, 0.1498079558950849, 0.1542390524991788, 0.20303156634327024, 0.08253667736425996], [0.04482054690015502, 0.019086119791609235, 0.0463150987343397, 0.0353487313259393, 0.08977488076197915, 0.11005210675648414, 0.04128028725972399, 0.018069767102133483, 0.058718074797070585, 0.030111424857750535, 0.020672323153121397, 0.028269017275306396, 0.04911725911370013, 0.013578502730524633, 0.023536566041002516, 0.06885825743665919, 0.038728130457457155, 0.02073679908789927, 0.02148180217773188, 0.05054858367657289, 0.03569338841771241, 0.011838530081149656, 0.025953805961762555, 0.04418908683874179, 0.020282432160456665, 0.03952255872718524, 0.017902312611113302, 0.06382663719705306, 0.0273751523491228, 0.025812966741796117, 0.016241614321188536, 0.02980431672767736, 0.03395237305085175, 0.07802718770108186, 0.12432501665898599, 0.041451474753557704, 0.06531686231028289, 0.09575336269335821, 0.04823019226023462, 0.024155073770089075, 0.024115699125104584, 0.03087778139160946, 0.12865064665675163, 0.9657687053550035, 10.682013407349586, 31.39219980686903, 40.58836184442043, 25.600537285208702, 19.87753327935934, 17.423586957156658, 14.648290928453207, 11.163446623831987, 12.796052768826485, 4.689080910757184, 1.70844413805753, 0.08861586873535998, 0.9489947429392487, 3.714520367793739, 3.699635616503656, 3.423882038332522, 4.048758270218968, 7.075050305575132, 2.3032179102301598, 0.4788594483397901, 0.05457721359562129, 0.029127800880814902, 0.0802868047321681, 1.338049394544214, 2.1563569782301784, 8.82837027311325, 19.32610496878624, 18.95464640110731, 34.61570553481579, 55.07701858878136, 56.24183468520641, 59.43703003227711, 55.930779576301575, 56.64650917053223, 55.12503661215305, 59.65352341532707, 56.63110479712486, 57.574016600847244, 56.591780707240105, 57.91269242763519, 58.46229113638401, 58.61734181642532, 57.77138561010361, 59.579324796795845, 56.27772755920887, 46.560896560549736, 49.21555571258068, 52.468059584498405, 46.134992614388466, 55.042330250144005, 59.43649806082249, 56.6844767332077, 56.068822368979454, 54.42513316869736, 53.16654570400715, 55.75330629944801, 56.050317361950874, 57.64816202223301, 59.37700845301151, 59.36324179172516, 54.861247166991234, 54.58893097937107, 54.47489909827709, 51.958351135253906, 50.22354282438755, 51.285376846790314, 40.25980107486248, 30.52221368998289, 15.752195343375206, 6.931503983214498, 1.9260150007903576, 0.7470155123155564, 0.40395288029685616, 0.46280204434879124, 1.2362363515421748, 2.386291427537799, 2.018255051225424, 3.606666005216539, 3.5904256766662, 3.1683139270171523, 2.8457378363236785, 3.2671582605689764, 3.2401319732889533, 1.7547162738628685, 1.0184388072229922, 0.2733551646815613, 0.7645586365833879, 3.0279549211263657, 9.989149086177349, 14.814581405371428, 25.215095467865467, 23.27226161956787, 23.251898512244225, 26.743014380335808, 16.97298053652048, 3.2265192037448287, 0.11913024267414585, 0.08645734706078656, 0.07613105233758688, 0.030122614589345176, 0.0564138509798795, 0.06722185891703703, 0.03117834377917461, 0.04985838633729145, 0.028071563319826964, 0.023183741614047904, 0.03021487467776751, 0.05064433928055223, 0.031714003707747906, 0.06850244957604446, 0.03458608924120199, 0.05610583371890243, 0.012730820726574166, 0.040317499078810215, 0.015976296526787337, 0.026322760968469083, 0.06595033730263822, 0.04744657708215527, 0.05439631509943865, 0.02097061456879601, 0.00747378426240175, 0.03427245392231271, 0.038900898725842126, 0.04480540708755143, 0.04561322741210461, 0.09298337070504203, 0.024435772575088777, 0.047302708044298925, 0.04620005842298269, 0.07024697159067728, 0.01822313934098929, 0.00583720159738732, 0.05105404190544505, 0.03689792749355547, 0.03343698859680444, 0.02197607438574778, 0.09945887635694817, 0.0069375255134218605, 0.03038827006093925, 0.00797445471107494, 0.02858614068827592, 0.03833407230558805, 0.03305614438431803, 0.017009282601065934, 0.0429453586548334, 0.01167724933111458, 0.0290311732533155, 0.05545090323721524, 0.041854687297018245, 0.041561609468772076, 0.013472605678543914, 0.06721042984281667, 0.07395399181405082, 0.03082576055021491, 0.08221811789553612, 0.012478758617362473, 0.07278550256160088, 0.08871828511473723, 0.05166150462173391, 0.03787200745136943, 0.06089367700042203, 0.04900232270301785, 0.042500530180404894, 0.0412663645693101, 0.045874021816416644, 0.03365487944392953, 0.02244054565380793, 0.048020999383879825, 0.03904040393535979, 0.04350658928160556, 0.022423385344154667, 0.0738816472585313, 0.04615079837094527, 0.0389037597051356, 0.12044100905768573, 2.2833881992846727, 15.867665447294712, 40.049037784338, 41.47019952535629, 22.471745274960995, 19.57999214529991, 15.425508823245764, 19.699501432478428, 26.074423156678677, 19.309573955833912, 4.755576392635703, 0.7825787540059537, 0.04216389941575471, 0.3953818464651704, 1.4204096188768744, 1.8199129379354417, 6.6214406210929155, 12.723838593810797, 6.38136712834239, 3.766879183240235, 2.853106828406453, 1.1224107281304896, 0.090997747174697, 0.4464535997249186, 2.310077967122197, 2.635637135244906, 13.194445241242647, 21.071556508541107, 21.250553503632545, 40.33192880451679, 55.1164186745882, 55.024288818240166, 57.60435417294502, 54.803349673748016, 57.66492672264576, 57.22199209034443, 60.64923718571663, 57.267608642578125, 57.68834486603737, 58.05758625268936, 58.93036141991615, 62.24372282624245, 60.705512166023254, 57.91174627840519, 62.163885310292244, 58.62401805818081, 51.887184754014015, 49.653915390372276, 50.244289711117744, 46.97643086314201, 54.51026760041714, 60.531496703624725, 56.28245450556278, 56.450340896844864, 56.015872210264206, 56.29090145230293, 57.78858728706837, 58.95704358816147, 58.96326765418053, 61.478721275925636, 59.837927520275116, 56.609453558921814, 55.16439110040665, 55.05375623703003, 54.034483730793, 53.499267250299454, 53.50174851715565, 42.05763280391693, 34.02679033577442, 19.4922149553895, 9.995364602655172, 3.2795258844271302, 1.773520871065557, 1.7230380862019956, 1.406829860061407, 2.5718577951192856, 3.43170961830765, 3.9317870093509555, 4.462443022057414, 5.399925392121077, 4.273690050467849, 3.769926382228732, 4.048866564407945, 2.466804119758308, 1.5380241139791906, 0.873250913573429, 0.28814578196033835, 0.5137598630972207, 2.8883095644414425, 14.554402716457844, 21.86099074780941, 31.145693734288216, 26.419729627668858, 24.36208873987198, 30.057589821517467, 21.306114122271538, 4.936441937461495, 0.2440088940784335, 0.04331742697104346, 0.05293888178130146, 0.022655913198832422, 0.03806493987212889, 0.06310450524324551, 0.03189625291270204, 0.05341758187569212, 0.03072921641432913, 0.06291001802310348, 0.05469181603984907, 0.04416575000504963, 0.03773545227886643, 0.03918327478459105, 0.08676952405949123, 0.05561671387113165, 0.030491905417875387, 0.05752319848397747, 0.06471804561442696, 0.014284273111115908, 0.04222511546686292, 0.02638951344124507, 0.07383964912150986, 0.047994397100410424, 0.02551905399741372, 0.06166141392895952, 0.012307413417147473, 0.043112568237120286, 0.12262157251825556, 0.0364914457895793, 0.04121756093809381, 0.05301141558447853, 0.04577996201987844, 0.02181490959628718, 0.017279196144954767, 0.026802802494785283, 0.23553258797619492, 0.13566575304139405, 0.14272779284510761, 0.0761833663273137, 0.23054722580127418, 0.2154474743292667, 0.1351307684672065, 0.1614013416110538, 0.12673890392761678, 0.08878567212377675, 0.1184016911429353, 0.0941698273527436, 0.17295086639933288, 0.15802879992406815, 0.1007073097571265, 0.1446996643790044, 0.16827524697873741, 0.1077429142605979, 0.1259470175136812, 0.130106755241286, 0.11060774530051276, 0.09534049851936288, 0.2531197958160192, 0.08606840972788632, 0.24351937347091734, 0.13030998496105894, 0.17966886138310656, 0.15674255409976467, 0.09956727444659919, 0.11185635681613348, 0.11564790765987709, 0.12117276666685939, 0.12426692876033485, 0.12733689683955163, 0.2162238201708533, 0.07163134418078698, 0.11053033929783851, 0.11539431579876691, 0.15034216863568872, 0.13685672194696963, 0.2300667148665525, 0.20181944622891024, 0.26488334115128964, 2.1571010258048773, 16.744299307465553, 47.591925635933876, 50.75565107166767, 33.33409510552883, 31.39752522110939, 26.46334368735552, 22.82271534204483, 19.95713710784912, 18.139381147921085, 5.967380292713642, 2.027990841306746, 0.33785076637286693, 2.745118997991085, 8.52403985336423, 9.970746673643589, 10.493258535861969, 8.489831238985062, 13.434803243726492, 5.759495347738266, 2.222230243496597, 0.6857262854464352, 0.10253160522552207, 0.3537636296823621, 1.7486514430493116, 2.9088296508416533, 11.390026565641165, 19.818773232400417, 24.108173064887524, 39.80371154844761, 53.091226145625114, 55.5721852183342, 59.60864782333374, 56.387879848480225, 58.22782851755619, 57.03389838337898, 61.79509609937668, 57.54285827279091, 59.26362253725529, 59.148009940981865, 60.951184183359146, 63.9089834690094, 63.116349801421165, 61.2675704061985, 65.94767287373543, 58.925106301903725, 50.8895330876112, 52.808031141757965, 55.72361469268799, 48.35111349821091, 55.213294476270676, 61.34458087384701, 59.13713112473488, 60.85295185446739, 58.28079767525196, 57.850018590688705, 62.26401373744011, 61.16593345999718, 60.971197709441185, 62.331266328692436, 59.741678684949875, 55.30152574181557, 56.867163330316544, 55.954250916838646, 56.83974400162697, 54.86549533903599, 53.947149217128754, 41.18051826953888, 33.94689202308655, 16.4794098213315, 8.578949756920338, 2.593351104296744, 1.2483162595890462, 1.0534963198006153, 1.4404726610518992, 2.573528755456209, 4.914435418322682, 3.9089792082086205, 6.431127833202481, 8.120068330317736, 6.2632932141423225, 9.747909530997276, 10.887069404125214, 8.860834781080484, 6.667510773986578, 4.2994217947125435, 1.078375841025263, 1.3287772983312607, 3.7777342507615685, 14.69013238325715, 19.71079632639885, 34.10950809717178, 31.105182208120823, 32.1145923435688, 37.356760650873184, 23.612898141145706, 4.892436498776078, 0.41080495167989284, 0.1535240377415903, 0.21084204723592848, 0.08056852399022318, 0.17063622653950006, 0.21008903451729566, 0.11755300816730596, 0.07489991839975119, 0.17169090744573623, 0.16083484544651583, 0.16519549739314243, 0.20632869098335505, 0.22673527331789955, 0.12694686854956672, 0.1733453178894706, 0.1968590944306925, 0.08478777454001829, 0.15024453168734908, 0.15034895186545327, 0.08605119932326488, 0.18359292269451544, 0.1371584940352477, 0.23936920944834128, 0.26121517235878855, 0.09932284810929559, 0.13562095700763166, 0.13181314570829272, 0.09385559460497461, 0.2977851522155106, 0.1636860877624713, 0.1542320169392042, 0.11941164280869998, 0.16765157575719059, 0.1011598194600083, 0.17602114618057385, 0.1117156604595948], [0.04907579903374426, 0.021551419340539724, 0.03914192602678668, 0.04125418221519794, 0.03178830382239539, 0.013795360137009993, 0.023845123214414343, 0.05059347990027163, 0.03445854745223187, 0.03329298968310468, 0.04578946151013952, 0.05509029368113261, 0.015712077110947575, 0.09213950426783413, 0.03427754134463612, 0.06916826736414805, 0.03496512632409576, 0.010652733017195715, 0.06386338092852384, 0.020846098886977416, 0.0231376857846044, 0.013381892968027387, 0.02723694960877765, 0.08887873002095148, 0.05313739144185092, 0.04803630246897228, 0.06588765550986864, 0.02976410716655664, 0.05671649138093926, 0.03804152882366907, 0.003570952317204501, 0.027236715832259506, 0.016343607676390093, 0.03787419307627715, 0.026147929529543035, 0.0254847760515986, 0.026111382467206568, 0.07982763796462677, 0.028379780960676726, 0.052456686171353795, 0.04124426712223794, 0.02455582423863234, 0.07442755624651909, 0.054036002402426675, 0.7500989874824882, 7.483552135527134, 28.33639618009329, 36.912051513791084, 30.369091406464577, 18.851780220866203, 22.49838564544916, 17.610859908163548, 12.599699255079031, 15.461716130375862, 7.393481768667698, 2.4082658858969808, 0.5720534850843251, 0.22651608742307872, 0.6072041520383209, 5.334339486435056, 23.092434369027615, 5.049045095220208, 3.777090422809124, 3.258184092119336, 1.137445808853954, 0.37256629730109125, 0.05717073770938441, 0.09022009515319951, 0.1684824694530107, 0.7749891956336796, 4.179454632103443, 9.281842689961195, 11.501707322895527, 23.743755519390106, 36.14656738936901, 45.64595125615597, 49.98240776360035, 59.08641904592514, 57.40249380469322, 55.44069707393646, 53.643032535910606, 56.55221723020077, 56.71173647046089, 56.01916663348675, 56.06489337980747, 58.33157055079937, 54.127753525972366, 60.423544496297836, 54.07389521598816, 41.452047899365425, 59.51367951929569, 49.26681496202946, 56.539009138941765, 57.826649844646454, 59.063741862773895, 59.72782842814922, 59.808144718408585, 57.09284842014313, 57.2445210814476, 56.310865581035614, 57.746747732162476, 58.457621186971664, 56.93774834275246, 60.7521166652441, 58.952495232224464, 57.671979144215584, 50.95780782401562, 48.82455289363861, 43.42034228146076, 27.01837420463562, 16.55763052403927, 7.9145625326782465, 3.1125953793525696, 0.7764398865401745, 0.4100261419080198, 0.6136616680305451, 1.9917414989322424, 1.2735948781482875, 3.4253361728042364, 2.4073793459683657, 4.245881242677569, 3.3725194819271564, 3.0093829426914454, 4.4587458204478025, 1.2400031369179487, 2.6983100222423673, 1.0259396047331393, 1.4682526141405106, 0.32188948534894735, 1.0359984962269664, 4.644965277984738, 13.886480256915092, 20.710279494524002, 22.24737871438265, 22.22373068332672, 22.91811302304268, 27.881127409636974, 17.103997506201267, 3.3922501606866717, 0.18358734174398705, 0.1362925412831828, 0.013129918988852296, 0.07689570193178952, 0.06555728847160935, 0.06673836454865523, 0.007349506531681982, 0.04644555716367904, 0.05915463203564286, 0.04936234967317432, 0.0470103946281597, 0.03298064570117276, 0.02983241072797682, 0.09552025410812348, 0.054019177914597094, 0.04658219397242647, 0.007449390795954969, 0.051799455031869, 0.0357268333027605, 0.05506881221663207, 0.02243158050987404, 0.035120027387165464, 0.06587636002223007, 0.00903136484339484, 0.06468865656643175, 0.06924555462319404, 0.03112892787612509, 0.06517978763440624, 0.023141055135056376, 0.053285832109395415, 0.04899833365925588, 0.020520394391496666, 0.023752306515234523, 0.03279847813246306, 0.03914808214176446, 0.03021136246388778, 0.07103885058313608, 0.01666989475779701, 0.06727930114720948, 0.022024276877345983, 0.027694301825249568, 0.007099556760294945, 0.02883041674067499, 0.01506148819316877, 0.034662100006244145, 0.040189704959630035, 0.030527751150657423, 0.05267699270916637, 0.05073869964689948, 0.061402563951560296, 0.03431678982451558, 0.07199586485512555, 0.04264102615707088, 0.046265163327916525, 0.03652469771623146, 0.031630560333724134, 0.032589912370895036, 0.009543696287437342, 0.04065549168444704, 0.1885332216625102, 0.029089771378494333, 0.0345279456814751, 0.05892892637348268, 0.06304007940343581, 0.00477867172776314, 0.0649395099026151, 0.008951297313615214, 0.02409444030490704, 0.01869747560704127, 0.0655764655675739, 0.008668398040754255, 0.03781332583457697, 0.031029712008603383, 0.06197756141773425, 0.011035982715839054, 0.013479068857122911, 0.04812269216927234, 0.006261223034016439, 0.05582206984399818, 0.0424674637906719, 0.07643242366611958, 1.2474830355495214, 11.959326267242432, 36.06288067996502, 39.955361410975456, 31.02534469217062, 17.6329006254673, 16.37993685901165, 18.045279197394848, 23.956540301442146, 21.85283448547125, 8.368368856608868, 1.5175630431622267, 0.3487204690463841, 0.2528746792813763, 1.0433723567984998, 6.003276016563177, 12.109700348228216, 6.317521054297686, 3.1946579134091735, 5.892272097989917, 3.788372492417693, 1.7752405162900686, 1.8721360294148326, 0.8287311962340027, 0.9354394453112036, 1.3906233734451234, 5.970755461603403, 11.052288338541985, 14.620264582335949, 28.870807103812695, 41.87593035399914, 49.11708019673824, 53.82897175848484, 59.763588309288025, 58.445325046777725, 56.73638194799423, 55.77583909034729, 57.315672263503075, 60.005365535616875, 58.06215740740299, 56.7583941668272, 60.436543598771095, 55.865616872906685, 61.53932802379131, 55.07666140794754, 43.742154613137245, 58.298569321632385, 49.88507978618145, 57.103814631700516, 58.76553766429424, 60.02892047166824, 61.26148693263531, 61.607245579361916, 58.53903941810131, 59.82924498617649, 57.52399988472462, 58.8102612644434, 59.63198237121105, 58.279308155179024, 59.24697943031788, 58.49762924015522, 57.0433484762907, 54.33913238346577, 52.26958863437176, 47.401031479239464, 31.447163857519627, 20.29648169875145, 11.165783498436213, 5.538435559719801, 1.2882808526046574, 1.2112043634988368, 0.8597739867400378, 3.7851172545924783, 2.5104925129562616, 4.223031643778086, 5.138384001329541, 4.790762504562736, 4.179279366508126, 6.640213988721371, 6.16498963907361, 2.7464878745377064, 2.969785979948938, 0.8361886523198336, 0.21718001808039844, 0.0973317475290969, 0.9965900983661413, 4.9013669695705175, 15.860398337244987, 22.84001961350441, 19.74360566586256, 21.353024505078793, 23.625315874814987, 31.117438450455666, 22.59622659534216, 5.777235645800829, 0.24074950022622943, 0.1237481007410679, 0.038558750093216076, 0.061229966377140954, 0.010118428435816895, 0.03478438738966361, 0.08477777038933709, 0.053971083034412004, 0.08712542839930393, 0.012267467318451963, 0.04476535708818119, 0.05307538500346709, 0.05636121415591333, 0.060640860683633946, 0.06661582112428732, 0.04301864202716388, 0.0590367715631146, 0.06008220530929975, 0.042309942946303636, 0.02327934322238434, 0.013919008433731506, 0.030519938190991525, 0.01108557487896178, 0.03274098395195324, 0.03277930103649851, 0.01944237665156834, 0.06231812556507066, 0.017736694935592823, 0.02466160811309237, 0.043652925960486755, 0.03986082592746243, 0.04664962551032659, 0.052737967562279664, 0.035861740907421336, 0.06445600069127977, 0.024538652796763927, 0.03521408718370367, 0.1312475252780132, 0.12817803217330948, 0.174734054307919, 0.06896143080666661, 0.1268949033692479, 0.10014433137257583, 0.0956796451646369, 0.20004964666441083, 0.1579126389697194, 0.11039100849302486, 0.1788494412903674, 0.18447135837050155, 0.1259212353033945, 0.14733001386048272, 0.11848311216454022, 0.13080809963867068, 0.13726699602557346, 0.10198495408985764, 0.10536501373280771, 0.14478757919277996, 0.15576612524455413, 0.10837592912139371, 0.26227567170280963, 0.1498951730900444, 0.18169256451074034, 0.14156498102238402, 0.20020429539727047, 0.13171256985515356, 0.14930699137039483, 0.07149960554670542, 0.11604324230575003, 0.12327455857302994, 0.16436642938060686, 0.14004409778863192, 0.11225742084207013, 0.10005249801906757, 0.22388147801393643, 0.13636162038892508, 0.07258968689711764, 0.1430156867718324, 0.214266138500534, 0.15137128997594118, 0.11380010837456211, 0.2671918657142669, 1.430800398811698, 13.034706562757492, 41.37312613427639, 48.044488951563835, 40.622423216700554, 29.527134485542774, 31.25183153897524, 26.216047257184982, 20.028288289904594, 23.046213649213314, 9.73898096010089, 2.7496963273733854, 0.850388549733907, 1.5258036134764552, 2.196875154040754, 11.411891542375088, 40.788816288113594, 15.053418539464474, 9.039491694420576, 8.905788268893957, 3.7203445052728057, 1.7702225293032825, 0.943959834985435, 0.9035091055557132, 0.682622327003628, 1.3722112239338458, 5.515224505215883, 10.088376961648464, 15.145309958606958, 28.3275293558836, 40.09847693145275, 48.09841185808182, 52.91626833379269, 60.50291083753109, 58.46903197467327, 56.58236861228943, 56.041536033153534, 57.55482003092766, 61.120183914899826, 60.097309201955795, 60.461257472634315, 61.98240704834461, 55.797368735075, 61.0538736730814, 57.3379922658205, 42.62410260736942, 59.40747141838074, 52.494582161307335, 59.32411149144173, 59.034593626856804, 61.51320442557335, 62.50900559127331, 64.27915200591087, 59.667392671108246, 61.87189377844334, 59.17628802359104, 61.246435940265656, 61.080179661512375, 58.54711778461933, 62.1102511882782, 60.08144125342369, 57.26696267724037, 56.80795110762119, 53.01288954913616, 45.25033928453922, 29.21333782374859, 17.877535298466682, 9.400954898446798, 4.69670282676816, 1.5728368959389627, 0.8162842516321689, 2.1847253059968352, 4.799241274595261, 4.200253766030073, 7.709634304046631, 7.198298592120409, 8.891890514642, 9.34088772162795, 8.923311028629541, 13.762547057121992, 7.632087115198374, 7.096356237307191, 5.659767324104905, 4.697527382522821, 1.0207265219651163, 1.5556725044734776, 5.873740967363119, 18.438292108476162, 28.145108744502068, 27.498964816331863, 29.487422816455364, 31.90756045281887, 38.82130466401577, 23.744390085339546, 5.250466112047434, 0.2608527964912355, 0.29474777926225215, 0.1107214942749124, 0.19473949098028243, 0.1494305589585565, 0.2428343117935583, 0.17075348587241024, 0.21805155178299174, 0.18752683972707018, 0.0948020481155254, 0.11166947660967708, 0.25711658759973943, 0.15197082655504346, 0.19895628502126783, 0.18683382222661749, 0.15228471049340442, 0.19099226861726493, 0.19287916424218565, 0.13569950591772795, 0.12971191783435643, 0.0813178853422869, 0.10250473947962746, 0.17087687534512952, 0.15272236982127652, 0.1081554296251852, 0.17481371643953025, 0.16827012615976855, 0.13301900209626183, 0.14888255711412057, 0.11793527359259315, 0.15812357218237594, 0.06857608546852134, 0.17853478551842272, 0.16575237532379106, 0.15630076843081042, 0.1331891171867028, 0.20600049843778834], [0.053647009408450685, 0.04515266540693119, 0.03498460770060774, 0.03294491129054222, 0.012645803071791306, 0.02022066320932936, 0.024259722158603836, 0.039512109287898056, 0.02664133713551564, 0.0964022966218181, 0.11022884180420078, 0.03059534967178479, 0.06024558169883676, 0.0694898770598229, 0.02990090724779293, 0.05099231377243996, 0.026545980435912497, 0.06401682738214731, 0.026525801440584473, 0.04631009294826072, 0.029963468441565055, 0.08968464302597567, 0.029549110695370473, 0.07368178688921034, 0.008167593077814672, 0.05186234833672643, 0.02531054946302902, 0.04564400798699353, 0.017680915116216056, 0.05939551461779047, 0.08487407147185877, 0.054832902023917995, 0.044026612158631906, 0.012543629745778162, 0.0661282152577769, 0.022901269076101016, 0.010657510592864128, 0.05694426021364052, 0.049632814261713065, 0.0557957941055065, 0.0334026271593757, 0.019961568323196843, 0.08149052373482846, 0.014660541055491194, 0.05035280511947349, 0.17698912939522415, 6.643426716327667, 23.79604071378708, 39.207466542720795, 33.106909096241, 18.584546260535717, 22.108777351677418, 22.864720188081264, 16.14619430154562, 18.956173919141293, 12.986452002078295, 2.9190985998138785, 0.7042485696729273, 0.9409625083208084, 7.221817430108786, 10.503713674843311, 4.75828992202878, 2.0018513314425945, 3.386070029810071, 4.810184212401509, 1.56051843194291, 1.360375452786684, 0.6149427930358797, 0.4991373571101576, 0.37771781149785966, 0.08670412600622512, 1.1494804755784571, 3.934281338006258, 7.720601940527558, 12.108720950782299, 20.011251904070377, 27.264543995261192, 31.830175705254078, 36.99175603687763, 48.229079246520996, 53.76673489809036, 54.380838945508, 55.328964069485664, 57.16265447437763, 59.07556302845478, 60.804101675748825, 59.68291863799095, 62.923749536275864, 64.22802954912186, 59.95277255773544, 53.569506481289864, 41.111475974321365, 44.59665656089783, 51.775090768933296, 62.76597440242767, 61.717679053545, 62.82819226384163, 59.87132012844086, 59.30523790419102, 60.145046040415764, 61.44204944372177, 61.78151182830334, 60.11935941874981, 59.586810395121574, 57.71314613521099, 50.77200539410114, 49.69161696732044, 37.21570461988449, 18.636529371142387, 9.320248179137707, 3.0715542566031218, 0.9803802275564522, 0.41607455641496927, 0.4216740309493616, 1.2723762122914195, 1.005659499205649, 3.502902598120272, 2.4406952457502484, 2.52962329890579, 4.669742798432708, 4.229725459590554, 2.6893622148782015, 6.894703432917595, 2.6775393867865205, 1.2371879629790783, 2.435527048073709, 0.2585881476989016, 0.22049682447686791, 1.1091414839029312, 6.231656111776829, 14.371450133621693, 19.948532469570637, 20.15839710831642, 25.255405604839325, 28.42525441199541, 25.967010520398617, 17.51101266592741, 4.554794691503048, 0.3689321188721806, 0.08248092723079026, 0.13443654868751764, 0.0925966672366485, 0.010136567452718737, 0.06333338358672336, 0.028545561908686068, 0.04516860673902556, 0.018088534161506686, 0.018404700203973334, 0.06294852806604467, 0.06368297967128456, 0.06192247921717353, 0.04162672921665944, 0.07032191366306506, 0.11363351106410846, 0.04954671770974528, 0.014354042414197465, 0.057114004230243154, 0.017792626895243302, 0.03697042047861032, 0.007702903340032208, 0.031809009742573835, 0.059626849470078014, 0.06589600467123091, 0.0453971548267873, 0.007166280474848463, 0.03121014109638054, 0.06669828115263954, 0.027866916097991634, 0.0912108103511855, 0.04323333421780262, 0.025194433037540875, 0.0158081017434597, 0.03660928399767727, 0.09592666159733199, 0.05079343303805217, 0.02862216453650035, 0.028459808600018732, 0.019726192476809956, 0.06604178473935463, 0.049962743432843126, 0.0336622118629748, 0.02878646304452559, 0.05735915787226986, 0.04132242640480399, 0.02782184732495807, 0.008497050985170063, 0.02080996742733987, 0.03335376786708366, 0.06325435970211402, 0.059713985028793104, 0.015529817701462889, 0.021633699398080353, 0.04334620003646705, 0.019620495804701932, 0.008070549847616348, 0.050529495638329536, 0.017639907746342942, 0.13394198147580028, 0.07729499222477898, 0.038673415619996376, 0.005369920836528763, 0.057877477520378307, 0.10614454338792711, 0.034552425422589295, 0.013131520172464661, 0.0499493587994948, 0.033844624340417795, 0.038132586632855237, 0.00456913096968492, 0.02727524628426181, 0.01861028253188124, 0.04248827732226346, 0.007085467550496105, 0.020557666903187055, 0.04677267359511461, 0.026889748805842828, 0.10682976091629826, 0.009406679128005635, 0.0563709585549077, 0.02450414849590743, 0.030613203889515717, 0.5260337388608605, 10.520788058638573, 30.98679196089506, 43.53702262043953, 33.65594543516636, 19.09701906144619, 14.60647702217102, 14.511412773281336, 20.72639063000679, 22.531343176960945, 12.446132395416498, 2.365876310504973, 0.8187091152649373, 0.23395395081024617, 1.5924522746354342, 3.0931717716157436, 3.102807104587555, 2.865349533967674, 8.44195095822215, 10.365020167082548, 5.697037149220705, 7.987290155142546, 5.843069963157177, 2.083436041139066, 1.0836543515324593, 0.29005506075918674, 1.7073788889683783, 5.614031553268433, 9.388628359884024, 15.016359128057957, 23.29313389956951, 32.699046581983566, 37.15639740228653, 42.364610731601715, 49.96080972254276, 54.53748174011707, 56.41678869724274, 57.17263653874397, 59.3293172121048, 59.668661803007126, 60.84997661411762, 58.47962200641632, 62.7226073294878, 62.68027000129223, 65.49099057912827, 54.84085366129875, 39.7549107670784, 49.571497812867165, 55.09272314608097, 62.086487263441086, 61.84325851500034, 62.93445736169815, 60.86978115141392, 61.36064261198044, 59.56215351819992, 60.00536933541298, 61.689875945448875, 58.83523352444172, 58.92041355371475, 58.763592168688774, 52.32413470745087, 53.184062764048576, 41.53739131987095, 23.12913089990616, 12.760442979633808, 5.181039087474346, 2.715529748238623, 1.941485870629549, 1.464826266746968, 2.498385412618518, 2.7373583894222975, 5.449485182762146, 3.533258456736803, 4.69994405284524, 5.628623720258474, 6.028633480891585, 3.7429169565439224, 5.3014028538018465, 3.7662132689729333, 1.7440012050792575, 0.565137678058818, 0.27331016084644943, 0.26950994913931936, 1.473013877402991, 6.351388162001967, 17.941843047738075, 27.260157130658627, 24.415399879217148, 20.797982588410378, 27.251915372908115, 30.342394039034843, 23.991639018058777, 7.218712521716952, 0.4675807332387194, 0.1305048432550393, 0.11076832379330881, 0.05880528457055334, 0.0554464206652483, 0.09101687232032418, 0.056773647884256206, 0.10176746029173955, 0.07974566033226438, 0.027722755767172202, 0.056027492610155605, 0.0333028342720354, 0.05562846206885297, 0.04833326915104408, 0.06643920482019894, 0.08910320000723004, 0.051049633548245765, 0.03298553274362348, 0.05109385812829714, 0.06922731263330206, 0.034417677379678935, 0.046495251372107305, 0.020285335813241545, 0.048037397136795335, 0.07131660677259788, 0.0236548866450903, 0.03400284651434049, 0.012446702476154314, 0.05757695224019699, 0.019732595355890226, 0.01004070887574926, 0.07359652896411717, 0.0217890327621717, 0.03709770993737038, 0.0232204371059197, 0.034718317692750134, 0.0385288452525856, 0.02705182458157651, 0.14342645066790283, 0.0952653783315327, 0.10519644230953418, 0.10912254452705383, 0.10032919293735176, 0.20112587953917682, 0.11949783583986573, 0.10737243414041586, 0.07534070959081873, 0.16120789339765906, 0.20762390195159242, 0.1502228164463304, 0.22353627544362098, 0.1851848591468297, 0.12009068566840142, 0.11283909392659552, 0.14285570941865444, 0.14720619394211099, 0.17200425703777, 0.15654757706215605, 0.1833410674589686, 0.29672480130102485, 0.12273518048459664, 0.1270778279285878, 0.10941540342173539, 0.15893001953372732, 0.170905937848147, 0.11715118715073913, 0.10912209923844784, 0.12803347664885223, 0.21285596885718405, 0.1430427306331694, 0.20863242127234116, 0.13469701283611357, 0.17487210861872882, 0.1274015972740017, 0.10861510847462341, 0.10321435882360674, 0.09808070812141523, 0.21498361718840897, 0.20584541925927624, 0.14419034327147529, 0.11636419891146943, 0.09984733871533535, 0.16598316840827465, 0.5941492994315922, 11.460167951881886, 34.66918766498566, 53.24764475226402, 45.49990989267826, 28.868920505046844, 31.395100951194763, 31.303947642445564, 24.381475299596786, 27.008908912539482, 17.183667831122875, 4.514979952946305, 1.3813117356039584, 1.9007761613465846, 11.800869069993496, 18.8641257584095, 12.946863826364279, 7.2020485159009695, 6.682509994134307, 8.342933021485806, 3.3357797283679247, 8.62254861742258, 3.703440874814987, 1.9975193263962865, 0.9248499479144812, 0.13636248128022999, 1.8955982266925275, 4.524625735357404, 9.100424274802208, 13.886678796261549, 21.916938945651054, 31.11728075891733, 34.43944439291954, 39.978418573737144, 51.28295637667179, 60.100653022527695, 59.70121465623379, 58.61041098833084, 60.69481573998928, 61.82546027004719, 62.81841538846493, 59.995349273085594, 64.46579039096832, 61.504153311252594, 62.969138100743294, 55.85590459406376, 43.38481418788433, 49.05345641076565, 54.820919930934906, 62.52954728901386, 63.16909097135067, 64.68245476484299, 62.955075055360794, 62.6690112054348, 61.221961453557014, 61.74953654408455, 63.99152263998985, 58.41789431869984, 62.182485312223434, 60.128805711865425, 55.840268433094025, 55.84225952625275, 42.166713550686836, 21.139048486948013, 10.13644153252244, 3.624105406925082, 1.6176372044719756, 1.205433423165232, 1.3505529798567295, 3.341038883663714, 3.2352133747190237, 6.266896845772862, 5.931806601583958, 7.494909251108766, 10.733349602669477, 10.328652318567038, 8.118012640625238, 13.396422453224659, 7.694612760096788, 6.033579865470529, 6.354627963155508, 1.9847995089367032, 0.5669193074572831, 2.034058878198266, 7.6928947772830725, 19.220894314348698, 26.881889328360558, 29.426650777459145, 32.67833009362221, 36.62495031952858, 37.083589509129524, 26.8227569013834, 7.719631567597389, 0.5273256101645529, 0.2086468634661287, 0.27650967822410166, 0.1606979192001745, 0.14559494680725038, 0.15808621246833354, 0.10614808343234472, 0.17205537616973743, 0.12725484499242157, 0.07768188123009168, 0.09234660799847916, 0.17250615666853264, 0.25121627608314157, 0.14941494417143986, 0.14594999025575817, 0.17899858328746632, 0.1315821596654132, 0.12091642143786885, 0.20838570169871673, 0.11277430443442427, 0.1304984459420666, 0.1890138364979066, 0.15694110828917474, 0.10125117041752674, 0.14493701804894954, 0.13919818302383646, 0.11494876001961529, 0.1597090667928569, 0.2150843117851764, 0.06118921504821628, 0.2586230880115181, 0.17112786968937144, 0.15102378674782813, 0.08734094808460213, 0.14915155596099794, 0.1663057057885453, 0.15425842255353928, 0.12853402557084337], [0.009663791552156908, 0.04959758822224103, 0.03268409833253827, 0.041261700171162374, 0.04942768093314953, 0.025601938905310817, 0.02245860581751913, 0.015138746693992289, 0.029724626765528228, 0.06558080713148229, 0.022352907290041912, 0.050112178578274325, 0.04214777996821795, 0.06281724956352264, 0.013801036639051745, 0.04972803180862684, 0.02313936118298443, 0.016385451817768626, 0.02864029705961002, 0.03099071400356479, 0.04489944833039772, 0.03435639082454145, 0.03904597746441141, 0.10667361304513179, 0.014316332035377854, 0.023003642781986855, 0.03543225262546912, 0.04286149596737232, 0.04012433659227099, 0.0647426700743381, 0.09735035317135043, 0.06206797726918012, 0.05684398864104878, 0.09801125794183463, 0.06344200432067737, 0.013822096007061191, 0.010144825700990623, 0.06681563696474768, 0.018833320173143875, 0.03506539418594912, 0.02276152266858844, 0.07706376127316616, 0.04503063406446017, 0.015624136322003324, 0.0624751640134491, 0.025960527964343783, 0.039975762338144705, 4.451449736952782, 17.395010590553284, 34.70813177525997, 35.79477086663246, 26.439923644065857, 20.983640626072884, 14.36074610799551, 18.159299679100513, 25.15963364392519, 15.088389962911606, 6.247662277892232, 1.767411867622286, 1.2656677910126746, 1.4693219005130231, 2.5341583555564284, 1.637735276017338, 13.708822689950466, 12.790369223803282, 5.9997806791216135, 9.09119552001357, 5.95773546025157, 3.1456205947324634, 1.8358762376010418, 0.6509196187835187, 0.066965973819606, 0.11368502353434451, 0.6197235896252096, 1.2317477236501873, 2.0824193581938744, 5.369502799585462, 9.015558678656816, 14.030206594616175, 23.532760441303253, 41.098226085305214, 51.29190869629383, 58.508660048246384, 58.41437570750713, 57.5736366212368, 61.74767844378948, 59.56497296690941, 63.30304518342018, 61.09741933643818, 43.2831734418869, 42.261366471648216, 40.33669374883175, 44.40270356833935, 50.32529376447201, 62.95080408453941, 62.624716982245445, 60.69960728287697, 61.08904078602791, 60.012003779411316, 59.59982469677925, 58.43754306435585, 58.89243945479393, 57.91640482842922, 58.08551475405693, 53.78911569714546, 44.8205291479826, 25.64831592142582, 9.473911933600903, 3.643570337444544, 1.5843518218025565, 0.9966237028129399, 0.7838105410337448, 1.6381964762695134, 1.7387078516185284, 2.507179328240454, 1.8675923044793308, 5.911350399255753, 3.64457372110337, 4.651679042726755, 5.05564296618104, 2.7072917902842164, 2.30648644734174, 4.196539465337992, 2.592925289645791, 0.7421992707531899, 0.6991968594957143, 0.5854664684738964, 2.5100980466231704, 8.706673253327608, 16.895120814442635, 17.566086910665035, 16.70633364468813, 14.888540636748075, 23.810930214822292, 27.485785223543644, 18.42884201556444, 5.29029224999249, 0.19888983311830088, 0.06445188919315115, 0.060847088680020534, 0.02267342046252452, 0.052864065874018706, 0.020792816394532565, 0.08454170063487254, 0.09607898740796372, 0.09580089725204743, 0.07142346119508147, 0.055586007511010394, 0.06404876941815019, 0.008485263824695721, 0.02087676628434565, 0.021942638777545653, 0.020136290295340586, 0.051542104192776605, 0.08089474984444678, 0.030843132371956017, 0.030828834896965418, 0.02198993770434754, 0.03344603166624438, 0.004844676950597204, 0.07959333452163264, 0.014670258551632287, 0.006406149632312008, 0.0516520793462405, 0.044324647533358075, 0.03240734033170156, 0.03912899781425949, 0.03307266459160019, 0.054020832903916016, 0.06600648077437654, 0.04017502156784758, 0.023682809951424133, 0.002126119507011026, 0.024748424548306502, 0.10067772032925859, 0.04789858212461695, 0.051898082747356966, 0.031870875172899105, 0.029252364802232478, 0.08286550815682858, 0.05075778397440445, 0.038379269099095836, 0.022103172741481103, 0.017111877095885575, 0.07779548177495599, 0.09118644564296119, 0.03801614737312775, 0.013139821094227955, 0.0052879826307616895, 0.018205676606157795, 0.01943213130289223, 0.07513070406275801, 0.03864298756525386, 0.01351237087874324, 0.06264753523282707, 0.027809804123535287, 0.08362092543393373, 0.018800077523337677, 0.039250587578862906, 0.03621114032284822, 0.06607945615542121, 0.02063020070636412, 0.04694873328844551, 0.08765849823248573, 0.07328752835746855, 0.06851634258055128, 0.12307021563174203, 0.06104577645601239, 0.08270289617939852, 0.051772808219539, 0.05695677282346878, 0.06516734181786887, 0.05266736334306188, 0.044347965813358314, 0.02061856197542511, 0.0373622930055717, 0.07281758560566232, 0.07051853826851584, 0.029000340728089213, 0.06959225633181632, 0.034212295431643724, 0.08928964234655723, 0.4655724222538993, 8.361002951860428, 25.762604288756847, 41.586439087986946, 35.99812835454941, 26.695824712514877, 18.60927913337946, 15.886047910898924, 26.009714528918266, 35.23997783660889, 16.748425886034966, 6.339671965688467, 2.068328526802361, 0.38192469044588506, 0.3381545125739649, 1.2843167153187096, 1.2017953558824956, 5.17797265201807, 9.82234563678503, 7.025681454688311, 9.472930636256933, 7.720147389918566, 7.3859519977122545, 5.319974357262254, 3.409707136452198, 0.20392514183185995, 0.25332097720820457, 0.7972668064758182, 1.661186192650348, 3.4589299326762557, 7.634630128741264, 11.814751625061035, 16.870862916111946, 28.768489994108677, 44.44417454302311, 53.71092729270458, 58.75466264784336, 57.949953228235245, 58.73921647667885, 60.35660348832607, 59.54122044146061, 64.60475653409958, 62.026511281728745, 51.353541389107704, 44.08360429108143, 39.95108284056187, 49.147102385759354, 53.08936044573784, 61.93594694137573, 63.025074899196625, 62.2821007668972, 62.61214725673199, 61.091233268380165, 59.16303053498268, 57.10704065859318, 58.3720725774765, 58.5436637699604, 57.32680186629295, 57.11920000612736, 48.387633338570595, 32.128598392009735, 12.635600678622723, 5.491849584504962, 3.208110141567886, 1.9546632072888315, 1.9732697401195765, 3.7620855029672384, 2.8846104629337788, 4.448660686612129, 5.050393072888255, 5.595197388902307, 3.9983667992055416, 4.865730106830597, 5.357342027127743, 4.343494679778814, 2.2336752293631434, 3.2681732811033726, 1.87594496877864, 0.5000092915724963, 0.16585385659709573, 0.2416329676634632, 2.6571332942694426, 9.797752406448126, 20.808492824435234, 24.028973914682865, 21.01317074149847, 14.638142623007298, 23.682031631469727, 33.6937990039587, 22.66731698065996, 8.052123226225376, 0.40466121572535485, 0.07468619471183047, 0.02676627398614073, 0.059911941789323464, 0.0405237716040574, 0.02981613728479715, 0.03282523997768294, 0.05508332862518728, 0.10341228218749166, 0.04406548214319628, 0.09715607375255786, 0.004041530764880008, 0.012823465804103762, 0.008966887053247774, 0.1123975234804675, 0.09900172823108733, 0.0743835543107707, 0.04621215171937365, 0.03194701952452306, 0.06043567911547143, 0.10576020737062208, 0.04180401345365681, 0.02523252747778315, 0.049842715889099054, 0.058566272200550884, 0.03413605460082181, 0.008041722048801603, 0.022090324309829157, 0.05928371749178041, 0.08315448561916128, 0.05141484441992361, 0.08796573252766393, 0.03941420145565644, 0.024347924554604106, 0.03761922453122679, 0.0242815524325124, 0.04727304811240174, 0.06290223289397545, 0.028930315384059213, 0.08478547388222069, 0.10593977000098675, 0.14274596062023193, 0.18204738531494513, 0.1646137426723726, 0.15635838877642527, 0.11921331868506968, 0.06678851888864301, 0.17105248232837766, 0.2933503151871264, 0.15208652737783268, 0.1475292508257553, 0.1412408851319924, 0.16539406642550603, 0.1369442805298604, 0.17699472518870607, 0.07595230606966652, 0.1357097623986192, 0.17167281388537958, 0.1791323776706122, 0.16195179254282266, 0.2074374892981723, 0.0655320925579872, 0.17429335217457265, 0.17332856019493192, 0.12387825117912143, 0.1619953862973489, 0.1382584756356664, 0.1735050429124385, 0.21214231965132058, 0.2708826254820451, 0.15691373788286, 0.2610119723249227, 0.16591502440860495, 0.1399743655929342, 0.1223695465887431, 0.1775602565612644, 0.16042743605794385, 0.2214097700198181, 0.22997177933575585, 0.14124541223281994, 0.19297237799037248, 0.16296115791192278, 0.15211769758025184, 0.19290047872345895, 0.16725382913136855, 0.41358438378665596, 8.00419544801116, 27.893028371036053, 48.31730291247368, 46.14319637417793, 36.95664972066879, 30.849129147827625, 23.945591188967228, 26.80554572492838, 37.910178154706955, 19.44284040480852, 8.953111879527569, 2.7260264474898577, 2.190722096711397, 3.159466339275241, 6.679997378960252, 6.167979603633285, 27.014504112303257, 27.34465889632702, 17.087667882442474, 12.051335480064154, 10.15083136036992, 8.455697670578957, 6.253596609458327, 2.7381361601874232, 0.14120840874966234, 0.4798154829768464, 0.9239236288703978, 1.327126999385655, 2.772667994722724, 6.5486617013812065, 11.087892428040504, 16.715945228934288, 26.861212737858295, 43.02547127008438, 53.21098431944847, 59.58372116088867, 58.225164860486984, 59.748119339346886, 62.81934633851051, 59.39015194773674, 63.659013882279396, 60.53140550851822, 51.05684190988541, 44.86076898872852, 43.906970769166946, 52.502231150865555, 56.40343241393566, 61.59140802919865, 63.78020837903023, 61.81802026927471, 62.0670323073864, 60.149480402469635, 60.87836109101772, 58.094265684485435, 60.59119150042534, 59.75722745060921, 60.84104709327221, 58.622334748506546, 50.08977100253105, 29.431862197816372, 11.075364500284195, 4.769235234707594, 2.3029932472854853, 1.64180580759421, 2.114148368127644, 3.6307711992412806, 3.827212108299136, 6.449903100728989, 6.879388829693198, 11.214950010180473, 8.69475994259119, 9.539156332612038, 10.235035791993141, 7.560247695073485, 7.847807239741087, 10.900743920356035, 6.424109609797597, 2.6218559872359037, 2.007541051134467, 1.0223414353094995, 3.320911838673055, 11.65970854461193, 22.322956658899784, 25.220462679862976, 24.1112395003438, 22.79580518603325, 34.80130657553673, 38.414038717746735, 26.354245841503143, 7.914579156786203, 0.3978114598430693, 0.1795351560576819, 0.17604204505914822, 0.1157368985877838, 0.15361974510597065, 0.10994852520525455, 0.15267665352439508, 0.1883559225825593, 0.17982656776439399, 0.16561099619138986, 0.26694229629356414, 0.16764020605478436, 0.14218563912436366, 0.14513275207718834, 0.21703578910091892, 0.26083640987053514, 0.13711338629946113, 0.2548687410308048, 0.11192602964001708, 0.14531184715451673, 0.21288755466230214, 0.12388455201289617, 0.07100042959791608, 0.2463364027789794, 0.1269063918152824, 0.0936676308629103, 0.1111576915718615, 0.19023158209165558, 0.12457940261811018, 0.21369830647017807, 0.2514967485330999, 0.20326550613390282, 0.09963708085706457, 0.2049596660071984, 0.17067265114746988, 0.07222662083222531, 0.16527253232197836, 0.15398158662719652, 0.1350700607872568], [0.02100258814607514, 0.03251022055337671, 0.021996450050210115, 0.083605948893819, 0.07067586615448818, 0.11604607730987482, 0.07312114626984112, 0.044077564307372086, 0.031847809223108925, 0.007588921516799019, 0.060947642268729396, 0.07612220593728125, 0.03995562045020051, 0.008070914427662501, 0.043525120709091425, 0.00994363595964387, 0.05884209509531502, 0.031919990506139584, 0.03690098143124487, 0.016779812394815963, 0.05067194717412349, 0.03947040058847051, 0.0440330985293258, 0.06000796827720478, 0.05983539296721574, 0.05378077781642787, 0.022461674598162062, 0.019315521349199116, 0.01982633417355828, 0.012546116868179524, 0.09624044905649498, 0.0313739034027094, 0.01849988620961085, 0.03774374948989134, 0.03346783596498426, 0.046459698787657544, 0.032666717233951204, 0.03709578777488787, 0.023848191995057277, 0.04296002720366232, 0.01895851306471741, 0.05262855273031164, 0.09360042196931317, 0.025154358918371145, 0.09512081538559869, 0.029803116303810384, 0.025487865241302643, 0.09842928746365942, 1.7163637443445623, 10.031389519572258, 25.842747688293457, 33.773731514811516, 22.804455421864986, 12.673002071678638, 12.261225767433643, 13.580464627593756, 20.228833928704262, 18.357962518930435, 11.881700232625008, 4.684931058436632, 1.2593380431644619, 0.4552241525379941, 0.523913037031889, 9.56720357760787, 10.153637509793043, 10.39797579869628, 10.976452007889748, 13.16502247005701, 4.05420670285821, 2.890791306272149, 3.1039223447442055, 0.7690234563779086, 0.2764167613349855, 0.16487057029735297, 0.16953584417933598, 0.11943651217734441, 0.24749327742028981, 0.5278171494137496, 1.5065429219976068, 5.218302262946963, 16.24401245266199, 32.81780540943146, 44.94202382862568, 55.572637394070625, 55.78422524034977, 58.42203989624977, 61.07011780142784, 65.92585444450378, 53.62909108400345, 39.61759373545647, 35.47837324440479, 38.588722944259644, 46.18718281388283, 52.126663103699684, 65.70387795567513, 59.49373058974743, 65.44404789805412, 59.34214532375336, 60.57611010968685, 58.54595884680748, 59.416138753294945, 55.42686961591244, 52.866874784231186, 35.83901569247246, 22.22506821155548, 6.257657641544938, 2.1013352181762457, 0.5393557052593678, 0.41417617234401405, 0.8399454038590193, 2.1540780505165458, 2.966786278411746, 4.83069266192615, 3.6380475712940097, 2.951319208368659, 5.644010044634342, 5.322380103170872, 2.550707417540252, 2.970376373268664, 3.2198652857914567, 4.76467452943325, 0.9999786852858961, 1.0097372741438448, 1.8852887861430645, 0.4061511514009908, 1.3008467783220112, 4.9757494032382965, 14.452197700738907, 17.627544812858105, 16.86072316020727, 17.246972434222698, 16.767580658197403, 22.689144909381866, 27.875306122004986, 19.275539182126522, 4.80869279243052, 0.3749173617688939, 0.027198710449738428, 0.03593854948121589, 0.02768922182440292, 0.021335079582058825, 0.09005737927509472, 0.026517520927882288, 0.02441996111883782, 0.04834393010241911, 0.07315711074625142, 0.004499703054534621, 0.010589304438326508, 0.10150859176064841, 0.047290095244534314, 0.019319154162076302, 0.06528498706757091, 0.020510189860942774, 0.0332693930977257, 0.014633569553552661, 0.1072039146674797, 0.019956512442149688, 0.022997184241830837, 0.044967737048864365, 0.04795925269718282, 0.025829303267528303, 0.04362047555332538, 0.0625088500964921, 0.029394844168564305, 0.08397844023420475, 0.008615711121819913, 0.02180615410907194, 0.05767440736235585, 0.08380159386433661, 0.0697227481578011, 0.06576446641702205, 0.044452578949858434, 0.06331943863187917, 0.01468689008106594, 0.03451347380178049, 0.09044154459843412, 0.03532979542796966, 0.038930517839617096, 0.009439239001949318, 0.041194038567482494, 0.03162054876156617, 0.0040737051858741324, 0.04728783911559731, 0.07833613635739312, 0.05346464145986829, 0.03738400082511362, 0.014741832201252691, 0.04636076308088377, 0.04717342591902707, 0.06125757055997383, 0.008841707149258582, 0.0732571522530634, 0.009062074914254481, 0.03836661919194739, 0.029679548715648707, 0.06234646076336503, 0.031057841260917485, 0.024897748371586204, 0.0113136396430491, 0.0817790707515087, 0.0416635657165898, 0.03197689467924647, 0.020935689099133015, 0.03763479850022122, 0.010355353515478782, 0.036097131596761756, 0.03384265764907468, 0.06306952040176839, 0.07679163056309335, 0.016505933926964644, 0.038755693822167814, 0.06422300342819653, 0.0382386506680632, 0.026277159704477526, 0.0697912929172162, 0.03035358022316359, 0.04904453606286552, 0.03840780096652452, 0.013336462398001458, 0.04182795142696705, 0.06650334122241475, 0.0509286746091675, 0.08584793991758488, 0.15081886493135244, 3.6961281672120094, 17.352735958993435, 37.87458926439285, 36.46380856633186, 27.294938564300537, 12.158961854875088, 13.618352394551039, 24.64137565344572, 25.786630399525166, 19.075945392251015, 10.266684293746948, 5.390198389068246, 1.3598881289362907, 0.4135638114530593, 0.7459683122579008, 3.1430811434984207, 1.2142775673419237, 1.261560923885554, 3.4668028727173805, 10.716182123869658, 9.477763026952744, 6.778967343270779, 4.958015279844403, 4.720366057008505, 1.7352210637181997, 0.3386362554738298, 0.5683083704207093, 0.5876489169895649, 0.7058413373306394, 1.6635573841631413, 2.773019000887871, 8.160531409084797, 21.95301990956068, 35.756579115986824, 48.69903422892094, 58.853658735752106, 57.67335087060928, 60.97227685153484, 62.621954530477524, 64.16123673319817, 54.70400780439377, 49.57658194005489, 40.94084993004799, 40.21360695362091, 51.08932636678219, 56.604479625821114, 65.64753457903862, 59.1978594660759, 63.71311537921429, 61.03225663304329, 60.740884467959404, 59.223120510578156, 61.18307814002037, 59.417100101709366, 57.44433335959911, 45.12396186590195, 29.447122178971767, 10.85183484479785, 3.7042298074811697, 1.3463373435661197, 1.1273257643915713, 2.251424314454198, 2.303821127861738, 4.512890540063381, 4.335792968049645, 4.844201412051916, 4.578836001455784, 4.245717851445079, 4.949110932648182, 3.4330537961795926, 3.9440551260486245, 3.4777365485206246, 2.017131973989308, 1.4738095784559846, 0.467369191464968, 0.1596807612804696, 0.48934109683614224, 1.048470139503479, 4.312959993258119, 15.21640794351697, 25.152835808694363, 23.272138126194477, 15.769297275692225, 15.049602594226599, 21.80432628840208, 31.090389601886272, 25.732397809624672, 8.447113931179047, 0.5892517778556794, 0.016257394236163236, 0.027598247506830376, 0.010789370753627736, 0.022936498826311436, 0.036537900523399, 0.05927512342168484, 0.028728655306622386, 0.018840582088159863, 0.05221408551733475, 0.024391907936660573, 0.12386373477056623, 0.04716937379271258, 0.029001992006669752, 0.04105032538063824, 0.04495219647651538, 0.025191136046487372, 0.041186754388036206, 0.07542460196418688, 0.016860263058333658, 0.07126283075194806, 0.03543387050740421, 0.03403453993087169, 0.04775897672516294, 0.06667760491836816, 0.06813251864514314, 0.030811310934950598, 0.018396874256723095, 0.010116715002368437, 0.044776942013413645, 0.04831033307709731, 0.07778535145916976, 0.020606837897503283, 0.10051181321614422, 0.019513715596986003, 0.02873363882827107, 0.02593215751403477, 0.045148364661145024, 0.016186598913918715, 0.04993751041183714, 0.10822725467733108, 0.05593829759163782, 0.10616834406391717, 0.17436023452319205, 0.07939779345178977, 0.22136522631626576, 0.13953308458440006, 0.096172854246106, 0.1335912276408635, 0.0674457722925581, 0.16318634035997093, 0.21554092556471005, 0.10914169193711132, 0.19167100719641894, 0.14153682393953204, 0.09414509157068096, 0.25215648813173175, 0.10461235724505968, 0.13054772454779595, 0.20065973658347502, 0.11492406134493649, 0.1733996282564476, 0.0965060711314436, 0.1663411210756749, 0.20149315358139575, 0.1035086352203507, 0.09607031170162372, 0.08193767513148487, 0.10387689631897956, 0.15632790134986863, 0.16290950443362817, 0.15959781885612756, 0.12421267034369521, 0.11432347091613337, 0.17416620743460953, 0.12159694117144682, 0.1232572813751176, 0.08984764092019759, 0.0925236324837897, 0.14748004643479362, 0.1670745262526907, 0.22117538494057953, 0.16437184705864638, 0.11236425300012343, 0.20321030518971384, 0.15320332604460418, 0.17088005173718557, 0.23851483420003206, 3.6677845381200314, 17.837373353540897, 39.78919252753258, 46.01982079446316, 34.91735614836216, 21.736277639865875, 18.595314882695675, 25.03768488764763, 28.081446960568428, 24.825935550034046, 15.103456154465675, 6.09685929492116, 1.5790034900419414, 1.291451188735664, 3.2631850987672806, 18.839518278837204, 20.4875810444355, 22.223647087812424, 29.39654689282179, 23.847925029695034, 10.680021364241838, 7.223353497684002, 6.507070558145642, 3.430093517526984, 1.0495220893062651, 0.8162593748420477, 0.37114042381290346, 0.5235394102055579, 0.44956848258152604, 0.8402176829986274, 2.2914364049211144, 6.484922971576452, 19.123581536114216, 35.60158923268318, 48.03075268864632, 58.23079615831375, 58.827504739165306, 60.608947947621346, 64.42998871207237, 64.78523924946785, 57.27705493569374, 51.95850312709808, 45.38497366011143, 44.57634285092354, 53.74288357794285, 59.819737896323204, 67.86761105060577, 59.0336474776268, 65.2301649749279, 62.36144430935383, 61.1060144752264, 59.907634779810905, 61.96825660765171, 59.983721897006035, 57.96463184058666, 40.41883774101734, 26.04684043675661, 7.8144018072634935, 2.772364248521626, 0.8423896227031946, 0.823279379401356, 1.9171074475161731, 4.139203391969204, 7.326779672876, 8.92450226470828, 9.104628749191761, 6.066132243722677, 10.992682836949825, 11.231978796422482, 8.427992407232523, 8.10614112764597, 10.517123155295849, 10.905530713498592, 6.934949923306704, 5.638367822393775, 5.379156181588769, 1.3497355487197638, 1.9468983239494264, 6.813438143581152, 18.64154890179634, 24.53915163874626, 24.497709162533283, 24.331908859312534, 23.2481899112463, 31.838318668305874, 37.41555109620094, 28.54012604802847, 7.500921003520489, 0.6612766161561012, 0.11117851623566821, 0.10956339508993551, 0.07622020653798245, 0.08401455314015038, 0.14181459497194737, 0.1443027934874408, 0.13775742205325514, 0.09813963464694098, 0.23777283495292068, 0.19315938436193392, 0.2418438860331662, 0.15340263722464442, 0.14505556871881709, 0.07977865621796809, 0.1389207533793524, 0.16860192554304376, 0.133357540180441, 0.10631666969857179, 0.19309851340949535, 0.1686294295359403, 0.12553009379189461, 0.09752368176123127, 0.2590091235470027, 0.13763811439275742, 0.12339273816905916, 0.1052016818721313, 0.1798522163880989, 0.1396665524225682, 0.16040863003581762, 0.1111443032277748, 0.19893299642717466, 0.15546323993476108, 0.17090500274207443, 0.13984474207973108, 0.09505031877779402, 0.15384489786811173, 0.2078823623014614, 0.11626430583419278, 0.1614132011309266], [0.044515832196339034, 0.051120208081556484, 0.02059814734820975, 0.010802842589328066, 0.0351546782621881, 0.034148823251598515, 0.02345866279938491, 0.05893785069929436, 0.05122017166286241, 0.05328402497980278, 0.03486063935270067, 0.042386807181173936, 0.029324868919502478, 0.05905102821998298, 0.04370001894130837, 0.007197183040261734, 0.027431974885985255, 0.06095858523622155, 0.013687038117495831, 0.052499389348668046, 0.051637548094731756, 0.051891908078687266, 0.05989378143567592, 0.07378811438684352, 0.017466786957811564, 0.11509886680869386, 0.09136358145042323, 0.052309878228697926, 0.01401390685714432, 0.09642240140237845, 0.047187055461108685, 0.011942621858906932, 0.1612023272900842, 0.03529534493281972, 0.07263977444381453, 0.05972242324787658, 0.014845504665572662, 0.07695426480495371, 0.03583100115065463, 0.03580420961952768, 0.011493640140542993, 0.03252474809414707, 0.07273617200553417, 0.02197468842496164, 0.026216014157398604, 0.039780217557563446, 0.023062606414896436, 0.05576933654083405, 0.010294218172930414, 1.473848051391542, 7.212923057377338, 24.286715984344482, 33.864276856184006, 32.73902043700218, 20.650985576212406, 14.788784589618444, 18.950020149350166, 21.511897780001163, 21.037238650023937, 15.144119672477245, 8.011157624423504, 2.9241625405848026, 1.0567158157937229, 0.5703767656814307, 1.5750735509209335, 0.4692267277278006, 3.0121128587052226, 7.898449972271919, 14.251470621675253, 11.486766524612904, 6.558737810701132, 6.405424112454057, 1.2699803221039474, 0.2325011818902567, 0.616756008239463, 0.34450806851964444, 0.8501321822404861, 0.5255799600854516, 0.2116091756033711, 0.29411104624159634, 2.2470984840765595, 7.393791927024722, 16.843095906078815, 28.710537403821945, 37.33379848301411, 44.42477658390999, 46.537383422255516, 54.173810854554176, 51.943505331873894, 36.739871352910995, 30.445630699396133, 27.606943622231483, 46.35020546615124, 52.286075949668884, 67.73508936166763, 55.020971596241, 65.23348599672318, 59.955690801143646, 51.45341143012047, 32.816114500164986, 23.924958296120167, 18.97537238895893, 8.688970003277063, 2.905416009016335, 0.6525730050634593, 0.06127281427325215, 0.34281840606126934, 0.3118189569795504, 0.7636040565557778, 2.1644199080765247, 1.868181866593659, 1.6499936557374895, 3.5263668140396476, 2.9780039889737964, 4.707175539806485, 2.7062504086643457, 2.7850567549467087, 2.5972278462722898, 3.0236369278281927, 1.864642712753266, 0.8883238735143095, 0.9781453537289053, 0.49312135961372405, 0.8722132723778486, 2.440751767717302, 9.121123664081097, 18.36262296885252, 21.039106249809265, 13.753372449427843, 17.140661738812923, 24.472670406103134, 25.334948636591434, 25.081585831940174, 14.784616213291883, 4.49374764226377, 0.16618760040728375, 0.041010175191331655, 0.030889227164152544, 0.013144324075256009, 0.029386801143118646, 0.054097467073006555, 0.014306163684523199, 0.02665850301127648, 0.06254487394471653, 0.07846865424653515, 0.01581544343935093, 0.06881228880956769, 0.036629559472203255, 0.10338356107240543, 0.045587311615236104, 0.04390779431560077, 0.014569002705684397, 0.06755208494723774, 0.02849131647963077, 0.013713163571082987, 0.026316795956518035, 0.1146287978917826, 0.030177090084180236, 0.017059535275620874, 0.0786552153294906, 0.03676006985187996, 0.03536255382641684, 0.017821598485170398, 0.01970981142221717, 0.029272872197907418, 0.02640883525600657, 0.01979936823772732, 0.014997755333752139, 0.029708960028074216, 0.03502381907310337, 0.05580927892879117, 0.024910886240832042, 0.02507178571249824, 0.06302323265117593, 0.018387903546681628, 0.025844131378107704, 0.05877279705600813, 0.044650491181528196, 0.006278692726482404, 0.02512232411390869, 0.045533513330155984, 0.06312174533377402, 0.02369183632254135, 0.051572573065641336, 0.019454466237220913, 0.058117376756854355, 0.030564394692191854, 0.014754849471501075, 0.05369877791963518, 0.04534536776191089, 0.02232900085800793, 0.05552983064262662, 0.014184937572281342, 0.015813061145308893, 0.018621032540977467, 0.04065031149366405, 0.0385566423938144, 0.035999680185341276, 0.09719734458485618, 0.03742154236533679, 0.04987232758139726, 0.04452965840755496, 0.014344262763188453, 0.05304444857756607, 0.07165538234403357, 0.016636904438200872, 0.018797524535330012, 0.025649996678112075, 0.0800111265562009, 0.03226212800655048, 0.030497161678795237, 0.08413354167714715, 0.0027107412370241946, 0.08154678595019504, 0.04318480147048831, 0.008614196212874958, 0.016852602238941472, 0.052366819509188645, 0.015641888494428713, 0.03036114270798862, 0.014912071601429489, 0.014831024436716689, 0.018340676979278214, 0.04596135775500443, 0.10144766885787249, 2.6853850157931447, 11.787909865379333, 30.77067855745554, 36.84528149664402, 31.293967477977276, 20.461788028478622, 13.913238421082497, 23.13267420977354, 31.597236804664135, 28.337792605161667, 16.64078526198864, 9.403974786400795, 2.9269252298399806, 1.1244202265515924, 0.4254411725560203, 0.28078667528461665, 0.3813109640032053, 0.5532685399521142, 4.531366098672152, 7.781893126666546, 3.8435481442138553, 8.164660837501287, 5.490416586399078, 4.467221740633249, 2.676187134347856, 1.6197270923294127, 3.1848682137206197, 3.3608973305672407, 2.2999403486028314, 1.2675097421742976, 0.8073223137762398, 3.318895809352398, 10.500703286379576, 21.395694315433502, 33.505002334713936, 40.409296452999115, 48.33972550928593, 50.983950421214104, 58.62539738416672, 55.567766055464745, 44.00610364973545, 35.21699666976929, 30.49399070441723, 51.37383230030537, 56.82846620678902, 68.62247094511986, 59.105991795659065, 68.10392037034035, 62.90321163833141, 56.61011092364788, 40.344373136758804, 30.201632492244244, 24.596864841878414, 14.135948270559311, 5.504030305892229, 1.238544846419245, 0.15797196625499055, 0.957673299126327, 0.8916122408118099, 1.5234761196188629, 3.623439730145037, 4.542955476790667, 5.197405759245157, 5.4184588976204395, 5.216023810207844, 4.791873469948769, 4.508955851197243, 3.9797295117750764, 4.313167557120323, 2.6542304875329137, 2.2033827798441052, 1.2928802683018148, 0.18303479795577005, 0.2994658792158589, 0.996510658878833, 3.261015652678907, 10.838477611541748, 21.595157012343407, 30.301380939781666, 19.71689309924841, 16.7240159958601, 20.194090493023396, 24.236792363226414, 30.610634945333004, 20.97552616149187, 8.583095334470272, 0.32767998869530857, 0.09329049367806874, 0.005774525370725314, 0.017729592582327314, 0.027725165891752113, 0.021821264235768467, 0.01462845522837597, 0.02525555817555869, 0.13317566947080195, 0.03412370526348241, 0.018613972861203365, 0.03601068994612433, 0.038241812217165716, 0.10752507165307179, 0.05020655749831349, 0.03785981396504212, 0.06972302275244147, 0.048813858011271805, 0.050348430158919655, 0.07158527907449752, 0.015462447390746092, 0.06938128601177596, 0.04466929720365442, 0.04962286206136923, 0.06987347092945129, 0.07698814384639263, 0.01811697697121417, 0.03547794294718187, 0.023255837550095748, 0.010755354414868634, 0.012484308954299195, 0.10676079313270748, 0.019605638008215465, 0.01983463138458319, 0.03936884138965979, 0.03412079233385157, 0.02748909613728756, 0.043785087618744, 0.026505099231144413, 0.015357172815129161, 0.06310673168627545, 0.16062340757343918, 0.25901324988808483, 0.1384168499498628, 0.09184428534354083, 0.13955913396785036, 0.12094696081476286, 0.09603223210433498, 0.19020302424905822, 0.1499881048221141, 0.15802074020029977, 0.16698333114618436, 0.11143804527819157, 0.1278211481985636, 0.14146482077194378, 0.21733011002652347, 0.12867248064139858, 0.2069324132753536, 0.16638888570014387, 0.10870079684536904, 0.1058675887179561, 0.2108759485417977, 0.12924173759529367, 0.1507726142881438, 0.1428932324051857, 0.10204636681010015, 0.19016852922504768, 0.26930731313768774, 0.07998508459422737, 0.2816727402387187, 0.17601468949578702, 0.1506381222861819, 0.13195022038416937, 0.289129929151386, 0.07492290271329693, 0.1506146407336928, 0.19444347795797512, 0.10625209542922676, 0.17507284472230822, 0.08663230837555602, 0.10243957149214111, 0.20609334111213684, 0.2508346637478098, 0.21385053580161184, 0.2109194383956492, 0.1011991013365332, 0.16310228471411392, 0.12723302585072815, 0.148195001820568, 0.11994250846328214, 2.566289668902755, 11.904878038913012, 34.74549897015095, 48.170740976929665, 46.40315942466259, 31.418065018951893, 22.662310749292374, 28.02960254251957, 32.43945591151714, 29.405976086854935, 18.770911060273647, 11.064976807683706, 3.48761435598135, 1.739250747486949, 0.7852547010406852, 2.2496091993525624, 2.551666391082108, 11.495781540870667, 19.763501398265362, 27.357021532952785, 22.59469337761402, 13.064515963196754, 10.432109367102385, 4.1569840628653765, 1.3043063739314675, 1.4523539110086858, 2.0317011047154665, 3.080419418402016, 1.6593488724902272, 0.678149729501456, 0.5347277910914272, 2.9174342891201377, 9.010032825171947, 19.58927694708109, 31.589456722140312, 40.28454914689064, 49.27813075482845, 51.10020898282528, 57.198311761021614, 61.7937433719635, 48.087871223688126, 41.02241635322571, 35.8212174475193, 56.07677914202213, 64.18620139360428, 71.0577754676342, 60.746758952736855, 69.8562191426754, 62.56404183804989, 56.99366234242916, 35.57348974049091, 26.333523653447628, 20.07626261562109, 9.668504241853952, 3.879283801652491, 0.9807415050454438, 0.20293480512918904, 0.622004239121452, 0.7544004754163325, 1.5751313790678978, 4.583933902904391, 6.035960912704468, 7.968902941793203, 9.651173371821642, 8.419373519718647, 10.010104961693287, 8.332799915224314, 7.332074213773012, 7.856493573635817, 7.969948835670948, 6.783701414242387, 5.004200851544738, 2.5100066140294075, 1.634026556275785, 1.7733115260489285, 3.712846557609737, 11.642513517290354, 24.11180566996336, 29.817364811897278, 19.730557166039944, 25.293506160378456, 32.67916224896908, 34.27608735859394, 37.83570595085621, 22.9775133356452, 8.922330681234598, 0.400563640287146, 0.12823925935663283, 0.07266781278303824, 0.1336822149460204, 0.10667534967069514, 0.12347385491011664, 0.0904980071936734, 0.10273994092131034, 0.25304685754235834, 0.17393342539435253, 0.17145033285487443, 0.08907304654712789, 0.16581093077547848, 0.21337809943361208, 0.12337054795352742, 0.13372298853937536, 0.2129324249108322, 0.09948036153218709, 0.10821234493050724, 0.14085660106502473, 0.12674659257754683, 0.15648370783310384, 0.13086987601127476, 0.12178782155388035, 0.2007513472926803, 0.12423068226780742, 0.07743459762423299, 0.12821868702303618, 0.1654732832685113, 0.09717876120703295, 0.12789260217687115, 0.22558751225005835, 0.09007023327285424, 0.09790562064154074, 0.18602554919198155, 0.2352244037319906, 0.10772018969873898, 0.12445834348909557, 0.12258758215466514, 0.12338857472059317, 0.19342721061548218], [0.07459154119715095, 0.11059075754019432, 0.027166135732841212, 0.057490718390909024, 0.0456158620363567, 0.02968490145576652, 0.04546453070361167, 0.05705674382625148, 0.06605684291571379, 0.023545610965811647, 0.04726104387373198, 0.0842445892340038, 0.0449880236556055, 0.06579143606359139, 0.01546840127048199, 0.04307309711293783, 0.022503739528474398, 0.02372846873186063, 0.06449387990869582, 0.07343336779740639, 0.010817204074555775, 0.08211838066927157, 0.048806273262016475, 0.037439806619659066, 0.0434852451144252, 0.11487028532428667, 0.05573688613367267, 0.04350616625742987, 0.018966611751238815, 0.05024578371376265, 0.02911753883381607, 0.08748916981858201, 0.06417964716092683, 0.11135845736134797, 0.04804500043974258, 0.038361917686415836, 0.037764670632896014, 0.07095833498169668, 0.011139306370751001, 0.011650753731373698, 0.05117598419019487, 0.01278334530070424, 0.036571686796378344, 0.034167458579759113, 0.03610020408814307, 0.005875431479580584, 0.011989845643256558, 0.03188089787727222, 0.03187760645232629, 0.0038943995241425, 0.8918927132617682, 5.1611951272934675, 21.30929835140705, 30.98017081618309, 32.81386502087116, 23.4994438290596, 10.158664640039206, 13.54275070130825, 15.001695714890957, 21.316856145858765, 21.742699295282364, 14.772229827940464, 5.4777114931494, 2.006607251241803, 0.3478955867467448, 0.5482294165994972, 0.27449073968455195, 6.0138988215476274, 5.3674043621867895, 3.8754621567204595, 8.8464630022645, 10.080857165157795, 6.8543448485434055, 3.280229796655476, 1.92245839163661, 3.5997698502615094, 1.8192941648885608, 2.954051736742258, 2.24876896943897, 0.19406679348321632, 0.902270075166598, 0.49939788063056767, 1.8752967473119497, 5.897119212895632, 11.110101286321878, 17.73213990032673, 15.990771241486073, 16.331759244203568, 24.412892013788223, 34.237219244241714, 29.86311435699463, 27.95611448585987, 37.38042198121548, 39.85913537442684, 37.209028378129005, 30.816481299698353, 25.360724553465843, 21.925851367413998, 18.212080746889114, 2.3829098464921117, 0.5426215112674981, 0.27807495673187077, 0.38491768296808004, 0.041697789856698364, 0.09198433603160083, 0.22330046544084325, 1.05162990745157, 1.1517211678437889, 2.5944010354578495, 4.718550704419613, 3.0243524769321084, 4.714040346443653, 2.74623257573694, 5.121355215087533, 1.8998941336758435, 2.5111707765609026, 3.5706897731870413, 2.853502482175827, 2.3404929600656033, 1.2131670769304037, 0.5641521059442312, 0.24728651507757604, 1.8333010445348918, 5.280248913913965, 11.99822572991252, 20.49497164785862, 14.280835445970297, 14.382479041814804, 18.469064757227898, 20.89589573442936, 30.02339545637369, 24.699675925076008, 14.787767194211483, 4.397949557751417, 0.41466889902949333, 0.08074468016275205, 0.018598454553284682, 0.03251229485613294, 0.09666699101217091, 0.04666195258323569, 0.010963400673063006, 0.0593707194639137, 0.043669613150996156, 0.028639707052207086, 0.061045208713039756, 0.07338198891375214, 0.013111606494931038, 0.028842411702498794, 0.021708480053348467, 0.02129471231455682, 0.050031414357363246, 0.03349886887008324, 0.02943072329799179, 0.018591201915114652, 0.008117178986140061, 0.03672365266538691, 0.07053075401927345, 0.036460661503952, 0.03599259638576768, 0.07020363016636111, 0.03279202515841462, 0.15718591312179342, 0.052313800479169004, 0.019895220320904627, 0.07336966184084304, 0.07702813818468712, 0.025421127611480188, 0.03218566082068719, 0.07390224185655825, 0.07274918927578256, 0.00499730193951109, 0.02850325392500963, 0.03139126594760455, 0.029682758504350204, 0.06648126232903451, 0.04319237508752849, 0.06714169954648241, 0.12552492844406515, 0.040442996250931174, 0.06135604613518808, 0.09652694774558768, 0.0594233933952637, 0.022452889425039757, 0.02510262009309372, 0.03046057936444413, 0.06211214618815575, 0.0419939735729713, 0.027960567713307682, 0.06731657180353068, 0.05075152395875193, 0.010726325308496598, 0.06529427133500576, 0.012555030061776051, 0.024293313617818058, 0.049141879862872884, 0.09079770868993364, 0.040130169873009436, 0.02899767641793005, 0.01983939226192888, 0.04751772306917701, 0.06777443981263787, 0.019696552953973878, 0.08811068881186657, 0.033485306121292524, 0.07277431097463705, 0.02959065055620158, 0.061615025988430716, 0.028125697426730767, 0.04734357069537509, 0.030323727332870476, 0.09330483197118156, 0.05928704973484855, 0.02628798578371061, 0.05415251958766021, 0.025126565487880725, 0.007037698751446442, 0.01825127601478016, 0.05100537557154894, 0.0417243624542607, 0.056768953800201416, 0.04258608496456873, 0.04948857043928001, 0.029021068912697956, 0.04271017947758082, 0.07356010435614735, 0.09526384208584204, 1.8145902547985315, 9.088709503412247, 29.297763593494892, 38.11782941222191, 35.298836678266525, 25.401408970355988, 14.576581176370382, 17.734870053827763, 21.710292734205723, 26.90515737980604, 26.55497957020998, 18.662749864161015, 6.8307257909327745, 1.6938620642758906, 0.32602010120172054, 0.15650889632524922, 0.26955118286423385, 0.8014927734620869, 1.961751845665276, 2.52837672829628, 4.304723935201764, 3.8456444442272186, 5.568481022492051, 5.513779632747173, 2.0111665315926075, 10.66953107714653, 5.385798225179315, 5.734114134684205, 2.422073157504201, 2.040991368703544, 1.2696074671112, 1.290523326024413, 3.1340050930157304, 9.126168843358755, 15.474177561700344, 21.72918912023306, 20.555149018764496, 22.880954816937447, 33.7247521430254, 43.094718754291534, 36.49598143994808, 32.18738503754139, 44.08251374959946, 47.8485144674778, 45.943919867277145, 37.09277741611004, 34.25827391445637, 31.273059099912643, 29.033759459853172, 4.633277105167508, 1.339094575960189, 0.8105691208038479, 0.4820239363471046, 0.2732981677399948, 0.05988584416627418, 0.9945129160769284, 2.2208734788000584, 3.571294415742159, 3.0801334837451577, 4.412014028057456, 4.576736139133573, 4.9748331774026155, 4.419890530407429, 4.427680587396026, 5.702156899496913, 4.789269184693694, 2.929582237266004, 2.9240863071754575, 1.843458611983806, 0.46273661660961807, 0.2814647014020011, 0.4175874689826742, 2.1963246585801244, 8.454702123999596, 16.29677452147007, 23.514369428157806, 23.45979865640402, 17.67624869942665, 11.47199196740985, 17.502425126731396, 32.49132692813873, 29.832172617316246, 20.71666695177555, 7.258455064147711, 0.9298684692475945, 0.13929552311310545, 0.02973170870973263, 0.08201039076084271, 0.05222190775384661, 0.05805438326206058, 0.03081701619521482, 0.08088433009106666, 0.01657709104620153, 0.013525456797651714, 0.06603722795262001, 0.014184008032316342, 0.04685026884544641, 0.02039924991549924, 0.055173180444398895, 0.02367709170357557, 0.04510608450800646, 0.005897166665818077, 0.05400684713094961, 0.04602588749548886, 0.03739728155778721, 0.05210917181102559, 0.0678163266275078, 0.03961482252634596, 0.06400139813194983, 0.03394914841919672, 0.03781679908570368, 0.031174273099168204, 0.010248727303405758, 0.011953718822041992, 0.013516252311092103, 0.017613286909181625, 0.022359740614774637, 0.02024212426476879, 0.08817298468784429, 0.015384916150651406, 0.059799858936457895, 0.02600521082058549, 0.055436928596463986, 0.10294393505319022, 0.02725565358559834, 0.019398235563130584, 0.15666789404349402, 0.25667880952823907, 0.1669809117447585, 0.14037036075023934, 0.15984957019099966, 0.1689174718922004, 0.15016421646578237, 0.16030294820666313, 0.18443340493831784, 0.10262585055897944, 0.16408714436693117, 0.28855933633167297, 0.12625386589206755, 0.16941974259680137, 0.11009131441824138, 0.19297619262943044, 0.11958015486015938, 0.08645014080684632, 0.15983082354068756, 0.11330096211167984, 0.0813255443063099, 0.13280253246193752, 0.13467430311720818, 0.12680293642915785, 0.15061762416735291, 0.20725498034153134, 0.21696252428228036, 0.05823705920192879, 0.1468336654943414, 0.16746263980166987, 0.18250178749440238, 0.19148475781548768, 0.13891821523429826, 0.1751414785394445, 0.19562954868888482, 0.13848177302861586, 0.12073136691469699, 0.18955174513394013, 0.12617687549209222, 0.11267825568211265, 0.1295650319661945, 0.18037360481685027, 0.11498583771754056, 0.1256201311480254, 0.1281880956958048, 0.24352833861485124, 0.09923195728333667, 0.20776096178451553, 0.16440631239674985, 0.15167745557846501, 1.6251573571935296, 8.671174608170986, 30.367341600358486, 43.513273894786835, 47.67064981162548, 33.72322842478752, 17.813191451132298, 22.160160094499588, 24.964398220181465, 28.726743534207344, 29.31087289005518, 18.179630488157272, 6.908440170809627, 2.5906648859381676, 0.9821906522847712, 1.8657397851347923, 0.7665943179745227, 10.099541712552309, 12.141623385250568, 12.747844755649567, 19.301662780344486, 21.645758897066116, 17.198374941945076, 9.286928717046976, 5.975039731711149, 9.990131333470345, 5.752567844465375, 9.022616799920797, 5.498318737372756, 2.4179748399183154, 1.6817164910025895, 1.2384475953876972, 2.7373804757371545, 7.023339355364442, 12.622174099087715, 20.13256799429655, 18.734672404825687, 20.487807132303715, 33.63167233765125, 53.18503551185131, 41.684401631355286, 38.118349984288216, 45.439724922180176, 51.47887386381626, 44.56441529095173, 36.91209331154823, 29.130129888653755, 30.549853406846523, 27.058585546910763, 4.717175653204322, 0.5772828357294202, 0.716263287467882, 0.4476049973163754, 0.2480987660237588, 0.2081511533469893, 0.7867300906218588, 2.3987611709162593, 5.344008067622781, 6.0422419756650925, 10.838514659553766, 9.049869887530804, 9.711563531309366, 8.61610321328044, 10.556502342224121, 10.774021670222282, 7.927550710737705, 9.816062673926353, 8.230788689106703, 5.964957447722554, 3.0367747228592634, 1.75507654203102, 0.6697736727073789, 2.420090138912201, 7.491501308977604, 16.43036015331745, 26.58277887851, 22.932930327951908, 24.209680818021297, 23.114146403968334, 28.644930124282837, 39.79914799332619, 35.2433330565691, 22.072107419371605, 7.780167069286108, 1.0067996755242348, 0.18858815543353558, 0.15190292004263029, 0.13649216416524723, 0.19109045475488529, 0.1562871425994672, 0.1481852203141898, 0.17530721495859325, 0.12384550020215102, 0.1646837271982804, 0.13448922632960603, 0.1353475052746944, 0.1304712239652872, 0.13218399690231308, 0.23134674149332568, 0.1078172997222282, 0.05957452434813604, 0.11958803646848537, 0.166138588974718, 0.14872214931529015, 0.10597387910820544, 0.11943484234507196, 0.21862923953449354, 0.11996819419437088, 0.1331577094970271, 0.14787063875701278, 0.12189951477921568, 0.1664322568103671, 0.17583060718607157, 0.12390353615046479, 0.16315313667291775, 0.14755604235688224, 0.10469958186149597, 0.10264465658110566, 0.26088162150699645, 0.13529922114685178, 0.15863764303503558, 0.08291882404591888, 0.2214431221364066, 0.14784677128773183, 0.14110091608017683, 0.12378226922010072], [0.027800044881587382, 0.02360193626373075, 0.06570689802174456, 0.08432333852397278, 0.03701878995343577, 0.06197877853992395, 0.028480338260123972, 0.043058584415121004, 0.03929619997506961, 0.08044690082897432, 0.06804996213759296, 0.06300304623437114, 0.025099174672504887, 0.03869346845021937, 0.026906306120508816, 0.011050789489672752, 0.04622445281711407, 0.03658264089608565, 0.05275844341667835, 0.0307365710978047, 0.027299132307234686, 0.059010811237385496, 0.014980785199441016, 0.020145229464105796, 0.029732172552030534, 0.06691019400022924, 0.0636120600393042, 0.017062207007256802, 0.040904927518568, 0.10226929312921129, 0.024093520041787997, 0.04096286698768381, 0.07456537307007238, 0.04704241830040701, 0.028251150069991127, 0.05193179480556864, 0.008351148462679703, 0.013619088003906654, 0.019923505424230825, 0.03862782919895835, 0.03530633242917247, 0.031928198659443296, 0.040484745768480934, 0.014740043625351973, 0.08464851052849554, 0.029683689899684396, 0.04955124852131121, 0.04325634079577867, 0.018429461961204652, 0.03313918328785803, 0.02194609904108802, 0.11261534382356331, 2.8767933323979378, 16.796856187283993, 27.35255867242813, 32.9318904876709, 29.6800534799695, 20.10474968701601, 15.940783023834229, 15.13562522828579, 21.6080991178751, 23.150103874504566, 18.94985105842352, 11.500417292118073, 6.514500109478831, 1.1674765474162996, 0.10774524460430257, 0.5399822560139, 1.3441914087161422, 1.0543965152464807, 2.784223174676299, 1.7240799427963793, 2.2541404562070966, 9.386912751942873, 1.666009915061295, 11.020043268799782, 7.020433936268091, 6.3195202220231295, 3.149611330591142, 1.0816402221098542, 0.3303727676393464, 0.8577055914793164, 0.16287536564050242, 0.24350381805561483, 0.6621714681386948, 0.8040102571249008, 1.219864811282605, 0.7430341572035104, 3.868093639612198, 8.946079406887293, 11.047670636326075, 9.164982810616493, 11.09907427802682, 10.69825753569603, 5.092493388801813, 2.460630163550377, 0.7981738890521228, 0.27616119536105543, 0.7244796340819448, 0.2950179803883657, 0.05373714324377943, 0.062475119484588504, 0.05230481307080481, 0.495639318251051, 0.5248711199965328, 1.144401216879487, 2.624101429246366, 2.748711467720568, 1.7017165990546346, 3.846532409079373, 3.169248439371586, 2.401834730990231, 2.7771061565726995, 2.4409845052286983, 4.060971764847636, 4.2406208999454975, 1.763583216816187, 2.935594702139497, 1.5142756258137524, 0.7885185477789491, 1.6478503332473338, 4.516677986830473, 7.689702473580837, 11.860765255987644, 18.003549836575985, 20.247494727373123, 14.310723692178726, 19.96493998914957, 22.259671054780483, 28.552169501781464, 23.549021668732166, 13.318303395062685, 3.3312244853004813, 0.21136523166205734, 0.019324287968629505, 0.07932584965601563, 0.03535973737598397, 0.025705412845127285, 0.05646773090120405, 0.04373582385596819, 0.035543912454159, 0.06255426953430288, 0.009663199689384783, 0.010748814238468185, 0.04863265894528013, 0.032023204694269225, 0.04884892077825498, 0.10672372285625897, 0.030920454883016646, 0.023160920572991017, 0.03556756841135211, 0.034078775643138215, 0.03992793463112321, 0.07556543932878412, 0.08284343668492511, 0.005546292695726152, 0.02469008988555288, 0.1042934341239743, 0.034256879953318276, 0.03493109514238313, 0.09352026259875856, 0.026227816160826478, 0.06166659411974251, 0.021106197527842596, 0.02188192738685757, 0.05497915335581638, 0.00456875479358132, 0.040095144213410094, 0.07912909888545983, 0.036398781230673194, 0.011664431513054296, 0.046065692586125806, 0.011659140000119805, 0.02221527785877697, 0.016249132277152967, 0.06835026477347128, 0.01575151483848458, 0.03509672766085714, 0.09044853562954813, 0.04700777855759952, 0.17058319266652688, 0.025874516759358812, 0.0576786895544501, 0.0577283986058319, 0.008627498282294255, 0.06811874438426457, 0.04413044975080993, 0.03946061166061554, 0.020358107103675138, 0.02658790250279708, 0.04364630229247268, 0.02761984029348241, 0.008239144463004777, 0.05567627122218255, 0.06611530188820325, 0.01861463151726639, 0.007124822714104084, 0.03244964646000881, 0.09129153375397436, 0.015536627834080718, 0.0032758795032350463, 0.06713726892485283, 0.11483354159281589, 0.009875627401925158, 0.03287793246272486, 0.021944384679954965, 0.027435644806246273, 0.05275416864606086, 0.01977721698494861, 0.03345998775330372, 0.03019257499545347, 0.035348349119885825, 0.04227762241498567, 0.027884851951966994, 0.04065393688506447, 0.019338791389600374, 0.0811965145112481, 0.06721934303641319, 0.027962714375462383, 0.03242920771299396, 0.058491727177170105, 0.02153114757675212, 0.06496017129393294, 0.036243939539417624, 0.051236688159406185, 0.07301415826077573, 0.022860311801196076, 0.2092743493267335, 5.898771649226546, 23.059275448322296, 34.67713683843613, 37.9927933216095, 26.584224700927734, 19.42942712455988, 14.490916673094034, 18.1483106687665, 27.458639480173588, 32.250967025756836, 24.654334858059883, 13.794374149292707, 5.587762137874961, 0.9585853689350188, 0.24585479346569628, 0.19447999162366614, 0.11995056818705052, 0.05223106585617643, 1.4228775864467025, 2.7646026900038123, 3.4275932516902685, 2.386271716095507, 4.276886153966188, 5.671111140400171, 3.9612686773762107, 5.980826821178198, 4.809811357408762, 3.180610779672861, 2.9530785139650106, 2.256163847632706, 0.5527332436759025, 0.5717416643165052, 1.1630300735123456, 1.9875955651514232, 2.410609172657132, 1.5204703621566296, 7.871711757034063, 15.295988023281097, 15.99132601171732, 15.480902250856161, 16.992370896041393, 16.11959382891655, 8.387725967913866, 5.234627611935139, 1.8615104933269322, 0.8496073354035616, 2.905874834395945, 0.57818409986794, 0.3898989484878257, 0.1935224430053495, 0.36559865868184716, 1.060832419898361, 2.0525163877755404, 2.3612312972545624, 3.666152050718665, 2.9762237844988704, 5.782265150919557, 6.343231899663806, 3.72977108694613, 8.098811320960522, 4.611223563551903, 5.484279440715909, 2.5978533877059817, 2.0134532963857055, 0.7346597628202289, 1.0664846166037023, 0.29853736341465265, 0.2865684509743005, 1.213959096930921, 6.586229335516691, 12.192609049379826, 16.36150024831295, 21.78095754235983, 24.078711345791817, 14.709876123815775, 14.515710342675447, 19.001549184322357, 29.193276800215244, 30.52964799106121, 18.370007872581482, 6.27375072799623, 0.6290746503509581, 0.04463100980501622, 0.015443299980688607, 0.045487496463465504, 0.031740557751618326, 0.05297467556374613, 0.07029229454929009, 0.03758009108423721, 0.05964061630947981, 0.037413067038869485, 0.02602714313979959, 0.02235873314930359, 0.028346926083031576, 0.020125664595980197, 0.002636752592479752, 0.03697049840411637, 0.0180827769509051, 0.11724964788299985, 0.051478884342941456, 0.0312798658706015, 0.03559365119144786, 0.05591631888819393, 0.01667375207034638, 0.08748431617277674, 0.07886864957981743, 0.042018538661068305, 0.007146575062506599, 0.048058318279800005, 0.07128883560653776, 0.05323664256138727, 0.03880856813339051, 0.03559861987014301, 0.036461886047618464, 0.04582573768857401, 0.08026908224564977, 0.015751104801893234, 0.11980749695794657, 0.009633866302465321, 0.03366735123563558, 0.07189183059381321, 0.017913346491695847, 0.019746582984225824, 0.04584970163705293, 0.12476633477490395, 0.14164394553517923, 0.3591235092608258, 0.16463995532831177, 0.22470971482107416, 0.15684367914218456, 0.17483788076788187, 0.19565224356483668, 0.1720502701937221, 0.1578759026597254, 0.09899872995447367, 0.12696177087491378, 0.09840776518103667, 0.16082990274298936, 0.14123212778940797, 0.10607124888338149, 0.12477905518608168, 0.13699148112209514, 0.1870364136993885, 0.14006762386998162, 0.08613606391008943, 0.11063294121413492, 0.13327093154657632, 0.13877403078367934, 0.10347735369578004, 0.12976183468708768, 0.1559945137705654, 0.11919230848434381, 0.092367269389797, 0.3160762129118666, 0.16300071438308805, 0.1360209152335301, 0.1685613300651312, 0.1346684995223768, 0.09628306317608804, 0.18258992495248094, 0.1459181818063371, 0.1718398416414857, 0.14918714936356992, 0.20541298465104774, 0.16956648003542796, 0.14286752440966666, 0.1593482939642854, 0.21658995130565017, 0.13365178689127788, 0.08437154843704775, 0.09734840874443762, 0.20740412233863026, 0.09034246788360178, 0.0858633617463056, 0.12851336417952552, 0.32775417377706617, 5.612712549045682, 23.48220605403185, 40.983989015221596, 45.888841822743416, 40.50188608467579, 30.511507764458656, 23.736687898635864, 23.273414857685566, 31.55464868992567, 30.680765882134438, 24.064851589500904, 14.889965560287237, 8.010014835745096, 1.9926487002521753, 0.6977251509670168, 1.8360680085606873, 3.6013059178367257, 2.7332356106489897, 7.2305854596197605, 5.608725612983108, 11.225212309509516, 19.316658675670624, 9.513078331947327, 21.855368949472904, 16.042114086449146, 13.286343310028315, 8.584551606327295, 5.857464540749788, 2.6560403779149055, 2.500104820355773, 0.3919491759734228, 0.6262972368858755, 1.2381603545509279, 1.3049278780817986, 2.317177173681557, 1.2623354885727167, 8.014780730009079, 12.708075139671564, 14.652831684798002, 13.646418638527393, 16.24585535377264, 15.142633002251387, 6.7920623905956745, 3.898679385893047, 1.1171664157882333, 0.5316033493727446, 2.264076448045671, 0.8468603203073144, 0.2871515415608883, 0.20929676218656823, 0.20872208755463362, 1.3130749971605837, 1.670669533777982, 3.732874570414424, 6.906852331012487, 7.136266445741057, 6.480589779093862, 8.326188270002604, 9.072926100343466, 11.028078887611628, 9.09105397760868, 9.334628507494926, 9.30581085383892, 9.966845232993364, 6.509827310219407, 8.004303742200136, 3.6742848018184304, 1.342443146277219, 2.487690174020827, 6.033534267917275, 10.919627957046032, 17.072259709239006, 26.845183297991753, 29.774115532636642, 21.61086916923523, 28.909844309091568, 29.96065892279148, 38.250012919306755, 35.546967163681984, 19.37562581151724, 5.560060674324632, 0.39531662652734667, 0.1706088858190924, 0.15143870667088777, 0.08468958840239793, 0.1360858531552367, 0.11695865177898668, 0.17283731780480593, 0.11691802661516704, 0.08262652918347158, 0.09175292696454562, 0.30215845035854727, 0.13369621185120195, 0.14711630501551554, 0.1415664653177373, 0.23502681433456019, 0.090497034980217, 0.12763478007400408, 0.25233549415133893, 0.10969168273732066, 0.11705490091117099, 0.11998407615465112, 0.19558222935302183, 0.13308152061654255, 0.13864568376448005, 0.14460627251537517, 0.13954424648545682, 0.15010333067039028, 0.1654572380357422, 0.1818933748290874, 0.1491670816903934, 0.14188308035954833, 0.21411315217847005, 0.2650129795074463, 0.12392804186674766, 0.13185326621169224, 0.15773050108691677, 0.1867279622820206, 0.10829289021785371, 0.07766165028442629, 0.10000076290452853, 0.19534207036485896, 0.1079052739078179, 0.16533196350792423], [0.011598452729231212, 0.012116790931031574, 0.03624247379775625, 0.012840870094805723, 0.06299383618170395, 0.030975685513112694, 0.08691122231539339, 0.07617779279826209, 0.06523990159621462, 0.016179108788492158, 0.04052497759403195, 0.05689731195161585, 0.024786318608676083, 0.04891460826911498, 0.039016503069433384, 0.0018161018101636728, 0.0309491259031347, 0.048592260136501864, 0.04401018100907095, 0.048179477598750964, 0.07330872409511358, 0.032462519011460245, 0.05961635550193023, 0.020156209538981784, 0.004730747541543678, 0.054383119713747874, 0.019877061822626274, 0.02424508515105117, 0.03935160500986967, 0.09065792517503724, 0.04945282118569594, 0.04904296270979103, 0.022350088984239846, 0.00953124768784619, 0.00819160897663096, 0.026318851705582347, 0.06206597347045317, 0.01706985854980303, 0.04950047077727504, 0.04562862326565664, 0.037232714021229185, 0.05641716837999411, 0.042784854376805015, 0.059571307137957774, 0.016807988031359855, 0.046405076718656346, 0.053313877870095894, 0.05842372418555897, 0.031850633095018566, 0.09151136531727389, 0.02454517441947246, 0.048714881486375816, 0.10875131483771838, 2.817239365540445, 10.820170193910599, 23.878152407705784, 34.87277694046497, 32.56814740598202, 20.882727541029453, 19.92771338671446, 16.34486474096775, 18.17008350044489, 20.20693950355053, 22.252888418734074, 19.49862141162157, 12.944438606500626, 5.069351205602288, 1.1026939423754811, 0.4920416238019243, 0.37154435995034873, 0.7153348904103041, 0.8524056477472186, 3.122551557607949, 1.45307777216658, 1.3626309880055487, 6.464291028678417, 3.045333051122725, 3.3255257410928607, 1.5825842041522264, 2.171328174881637, 3.989907978102565, 2.416842025704682, 1.324813636019826, 0.3879999410128221, 0.21902121225139126, 0.09998242443543859, 0.0977356762450654, 0.050831494081649, 0.7227091072127223, 0.02521161932236282, 0.15853362361667678, 0.27805105957668275, 0.7426392752677202, 0.10063773341244087, 0.016993916433420964, 0.01124606895245961, 0.10849496960872784, 0.08716943033505231, 0.7591544359456748, 0.20051755593158305, 0.6242048554122448, 0.5504386418033391, 0.524087471421808, 0.8732520416378975, 3.7933464255183935, 2.097227876074612, 2.260024440474808, 2.318496652878821, 4.96688162907958, 3.4855090314522386, 1.6152452328242362, 5.05647512152791, 2.7952159848064184, 3.4030425315722823, 2.707835636101663, 2.4016342917457223, 0.7912145624868572, 0.707300043432042, 1.8254011496901512, 5.357446996495128, 11.622044015675783, 10.199798382818699, 11.29118911921978, 19.07758880406618, 24.025113321840763, 14.125040005892515, 17.364910505712032, 21.129138618707657, 27.35021609812975, 23.419399224221706, 9.21080170199275, 2.1200088411569595, 0.04033505087136291, 0.10965868685161695, 0.016940704445005395, 0.03736504637345206, 0.058960545575246215, 0.0577594500646228, 0.010179739110753872, 0.026570836816972587, 0.034381312143523246, 0.01221210495714331, 0.0267023194101057, 0.05111984813993331, 0.02247282536700368, 0.04163640311162453, 0.06504610457341187, 0.01269172160391463, 0.016036677661759313, 0.036231994672561996, 0.017604028616915457, 0.03662989714939613, 0.032610143316560425, 0.06393618561560288, 0.009846815373748541, 0.05145300936419517, 0.03143038826237898, 0.012761935267917579, 0.018301810705452226, 0.034636254713404924, 0.09018643875606358, 0.02635730052134022, 0.007907328381406842, 0.04690244924859144, 0.04464021614694502, 0.05301888901158236, 0.07511931209592149, 0.03603536264563445, 0.02743482473306358, 0.03065754906856455, 0.032494409097125754, 0.04953584153554402, 0.02175694415200269, 0.02071813963993918, 0.04664333209802862, 0.050280323266633786, 0.02659144069184549, 0.06280697823967785, 0.051893125200876966, 0.070075023395475, 0.03096979286056012, 0.04183766614005435, 0.07798492239089683, 0.02106125120917568, 0.046565655211452395, 0.06222665215318557, 0.03438227693550289, 0.025827616736933123, 0.044372260017553344, 0.03877366121741943, 0.1099779290962033, 0.022409245575545356, 0.016729628368921112, 0.018625023440108635, 0.07719361485214904, 0.025450342254771385, 0.024760319320193958, 0.08264921663794667, 0.04942972183926031, 0.030584809319407213, 0.012099742871214403, 0.041341777905472554, 0.0014790627483307617, 0.0423892488470301, 0.006918186536495341, 0.034662215039134026, 0.046324895083671436, 0.022450718643085565, 0.013456998312904034, 0.04021093038318213, 0.04769665116327815, 0.032463198076584376, 0.040279675522469915, 0.03425386312301271, 0.05020752229029313, 0.02200432794779772, 0.112526308366796, 0.09733568091178313, 0.019924460939364508, 0.014687519051221898, 0.05368303325667512, 0.0604578173806658, 0.021987842992530204, 0.07901698263594881, 0.02439567990222713, 0.04376202166895382, 0.045261219347594306, 0.046478404619847424, 0.13180784677388147, 5.075313085690141, 15.478470381349325, 30.015493780374527, 40.496463775634766, 35.70278540253639, 22.24781759083271, 16.987503357231617, 17.830072045326233, 19.887245558202267, 27.96213336288929, 32.962965220212936, 26.835716105997562, 14.433608148247004, 5.257752221077681, 1.096468570176512, 0.924429832957685, 0.37097813095897436, 0.46364292735233903, 0.6294009578414261, 1.1104116844944656, 0.8067524037323892, 3.0450015189126134, 3.9463449781760573, 3.932002647779882, 4.148482494056225, 9.24709165468812, 3.242299994453788, 4.046743903309107, 3.640309162437916, 2.1519755758345127, 1.73118663020432, 0.8716877130791545, 0.7930408988613635, 0.560433886712417, 0.7295302161946893, 2.5172081775963306, 0.6239476567134261, 0.7563415181357414, 0.8997814462054521, 1.4841053634881973, 0.7564965379424393, 0.28834043245296925, 0.05403465169365518, 0.482461269129999, 2.182891429401934, 2.1014280756935477, 0.7824275933671743, 1.2870645616203547, 1.1990541592240334, 1.6230850433930755, 2.993041444569826, 3.8377114199101925, 2.6621110271662474, 4.084305837750435, 5.552882859483361, 8.030702825635672, 7.812003660947084, 3.4395405231043696, 5.207491368055344, 2.585858143866062, 1.1324116727337241, 0.4825432022335008, 0.6372098950669169, 0.013780099725408945, 0.6789142009802163, 2.4050875939428806, 5.303179258480668, 11.704030316323042, 16.747508235275745, 18.19164164364338, 20.272784270346165, 22.16235637664795, 14.456043094396591, 15.113061089068651, 24.307668060064316, 30.488205514848232, 29.932331442832947, 14.944194350391626, 4.777008667588234, 0.15807868709089234, 0.01670713201747276, 0.037490287504624575, 0.043146629104739986, 0.035032561572734267, 0.042876212755800225, 0.00843415489725885, 0.037230097950669006, 0.010515450539969606, 0.017994810186792165, 0.011981778498011408, 0.013883873307349859, 0.01902981490275124, 0.040518702735425904, 0.03736992599442601, 0.021339191080187447, 0.04468596584047191, 0.008656291756778955, 0.029897870008426253, 0.009484798520134063, 0.027386631518311333, 0.02555266586568905, 0.10761347628431395, 0.028542123909574002, 0.06283778478973545, 0.024844567924446892, 0.04857142805121839, 0.03601126139983535, 0.056438738902215846, 0.05541705759242177, 0.03577942188712768, 0.029194193411967717, 0.02700123794056708, 0.0326216800021939, 0.07432774480548687, 0.03859016149363015, 0.015965240381774493, 0.07058106421027333, 0.029962974913360085, 0.0503021646727575, 0.08534838547348045, 0.025044309550139587, 0.03718383246450685, 0.041362584015587345, 0.10962608430418186, 0.12518478732090443, 0.1509055180940777, 0.156787765736226, 0.1357135473517701, 0.07391169681795873, 0.20458804297959432, 0.13199788110796362, 0.20038094138726592, 0.10203466314123943, 0.07404344287351705, 0.1518213580129668, 0.08479712560074404, 0.1364635321078822, 0.17229347198735923, 0.13438980822684243, 0.16759061574703082, 0.12866534118074924, 0.14399774110643193, 0.10465355386259034, 0.20268845662940294, 0.1550024255993776, 0.16647509357426316, 0.2699936513090506, 0.12351630575722083, 0.11207693052710965, 0.11066895021940582, 0.09658600043621846, 0.12057644358719699, 0.19527549971826375, 0.1933133354759775, 0.15885368222370744, 0.10869180943700485, 0.134316157491412, 0.06837213586550206, 0.05704477669496555, 0.15318584104534239, 0.1387608947698027, 0.10296999185811728, 0.10356319791753776, 0.1748486715951003, 0.1941343437647447, 0.143460099643562, 0.12343073613010347, 0.13509566488210112, 0.1557452857377939, 0.13408361293841153, 0.23091282258974388, 0.1395419309847057, 0.21007022849516943, 0.10505337850190699, 0.1954980252776295, 0.20109718810999766, 4.357486004009843, 15.699880700558424, 34.36021864414215, 47.712964341044426, 45.734444707632065, 31.45592998713255, 28.6172429099679, 24.99070230871439, 24.725940115749836, 29.445326775312424, 30.700357630848885, 25.52008230239153, 15.558672677725554, 7.407309226691723, 1.565809529274702, 1.154459158424288, 1.1955045559443533, 2.841802197508514, 2.357956347987056, 5.656510898843408, 4.2969015799462795, 6.878787511959672, 14.379100073128939, 8.965904843062162, 9.143836945295334, 7.879958739504218, 5.514733856543899, 10.304642356932163, 7.379260081797838, 4.097716743126512, 1.7532402905635536, 0.6354992149863392, 0.6124995241407305, 0.3305534954415634, 0.36412706889677793, 2.3571978136897087, 0.4476744920248166, 0.5735567200463265, 0.6043834565207362, 1.358003430068493, 0.644746256293729, 0.3870348818600178, 0.1618437803699635, 0.5111769516952336, 1.8861364969052374, 2.7900620363652706, 1.0561996372416615, 1.9739237800240517, 1.4217743393965065, 1.9704065937548876, 3.582704965956509, 9.63537571951747, 7.810247205197811, 5.7492059748619795, 6.248692972585559, 10.471149422228336, 11.44668247550726, 5.361456731334329, 12.761568669229746, 7.344103418290615, 9.045829754322767, 6.375596188008785, 4.234287589788437, 1.5533932205289602, 0.9756748331710696, 2.612231816165149, 7.008184343576431, 15.276441872119904, 13.831419311463833, 17.79483273625374, 29.0511055290699, 31.799720339477062, 21.083567664027214, 25.51397792994976, 32.297829911112785, 40.59620842337608, 33.69346462190151, 14.168458376079798, 3.6189630953595042, 0.1858359156176448, 0.27921234257519245, 0.22353121399646625, 0.16053311788709834, 0.16108114941744134, 0.12260791700100526, 0.06883991154609248, 0.1643013281864114, 0.16725473455153406, 0.12486165622249246, 0.11708308767993003, 0.09300272591644898, 0.20218370715156198, 0.148707662592642, 0.13072966947220266, 0.11226445640204474, 0.06901525135617703, 0.08092781252344139, 0.11396724745281972, 0.12489217333495617, 0.11323213533614762, 0.19556787621695548, 0.19170805520843714, 0.30525555135682225, 0.22313180495984852, 0.10836719404323958, 0.13772041857009754, 0.08853384657413699, 0.11607514723436907, 0.1197726753889583, 0.1237654744181782, 0.08920109670725651, 0.10542511285166256, 0.15358501259470358, 0.15584442182444036, 0.16007194732083008, 0.09079026494873688, 0.17770680104149505, 0.14927737967809662, 0.13474805775331333, 0.14320868969662115, 0.14506892737699673, 0.11535576864844188, 0.12909900775412098], [0.10086812573717907, 0.04342269319749903, 0.0073594039986346615, 0.02128908126906026, 0.03186159832694102, 0.027916103790630586, 0.029458947174134664, 0.01295685757213505, 0.06494538771221414, 0.05020581163989846, 0.08603003327152692, 0.06294231628999114, 0.03572517089196481, 0.0006083039522764011, 0.05292545261909254, 0.08611884608399123, 0.029893914361309726, 0.04496377026953269, 0.12782695179339498, 0.04978406024747528, 0.07506490524974652, 0.0698641718190629, 0.039151139790192246, 0.02172128024540143, 0.03918551607057452, 0.027061064320150763, 0.03255126874137204, 0.07931498461402953, 0.013696152618649649, 0.02819714954966912, 0.038598915125476196, 0.05630248058878351, 0.02156759444915224, 0.04522328817984089, 0.001313324473812827, 0.019287852228444535, 0.05152773992449511, 0.03571911496692337, 0.09451605408685282, 0.036008812312502414, 0.04337128091719933, 0.07017789990641177, 0.0595466678350931, 0.02125924136635149, 0.0827286412823014, 0.015470153666683473, 0.04057572936289944, 0.04225308330205735, 0.07259949066792615, 0.08290510915685445, 0.042670144321164116, 0.014524104626616463, 0.033035412488970906, 0.06801871772040613, 0.8552044944372028, 5.277348244562745, 14.87294152379036, 32.29908384382725, 35.58300822973251, 29.229321666061878, 24.31598011404276, 20.922429710626602, 17.555513978004456, 18.285338915884495, 17.058994621038437, 19.64628528803587, 20.534364134073257, 13.128062803298235, 4.886686457321048, 1.0419192910194397, 0.2700200420804322, 1.0016388399526477, 0.8885509707033634, 0.34108083054888994, 2.443830077536404, 1.0511466208845377, 1.4997712103649974, 3.5045996820554137, 8.88731935992837, 2.124066073447466, 4.017635090276599, 3.414546651765704, 2.2605694737285376, 1.0124967573210597, 1.3970035873353481, 0.6938329129479825, 0.12396718273521401, 1.5570138324983418, 1.0403008153662086, 0.5416139715816826, 0.2521132951369509, 0.11277034878730774, 0.07462194698746316, 0.3132536471821368, 0.14180390804540366, 0.10576863816822879, 0.09699308327981271, 1.487594407517463, 3.261870131827891, 0.3987560060340911, 1.478616795502603, 0.4553306655725464, 1.7633478669449687, 2.693501142784953, 2.8445105021819472, 1.6921614180319011, 4.013253450393677, 2.4165240302681923, 10.145370103418827, 6.693081026896834, 4.472485883161426, 6.271269461140037, 1.014919364824891, 1.250871503725648, 1.0876864101737738, 1.178999429102987, 2.763784546405077, 7.363278139382601, 11.12073976546526, 29.548287950456142, 25.07271520793438, 17.93671142309904, 23.124557845294476, 22.442711032927036, 18.692796751856804, 22.937189899384975, 27.933444902300835, 27.80392125248909, 19.637070782482624, 5.230892887338996, 0.38070644019171596, 0.07069309882353991, 0.05359523718652781, 0.06323665205854923, 0.04019752348540351, 0.023386774664686527, 0.06921413209056482, 0.04183071221632417, 0.059457354072947055, 0.07459454689524136, 0.02567023504525423, 0.03010768814419862, 0.015724951517768204, 0.04966262262314558, 0.025117615186900366, 0.03826353116892278, 0.053183894415269606, 0.01214368636283325, 0.011034377821488306, 0.018158514976676088, 0.03121458285022527, 0.10950348892947659, 0.04857996274949983, 0.030876660748617724, 0.024933232307375874, 0.057146298786392435, 0.03893957946274895, 0.03371462233189959, 0.0071483659576188074, 0.04758001523441635, 0.026101220610144082, 0.06903016852447763, 0.006649608858424472, 0.030779999724472873, 0.014183597068040399, 0.022097964720160235, 0.029044786097074393, 0.006455407828980242, 0.014642560672655236, 0.0073889034410967724, 0.02600467276351992, 0.05648454425681848, 0.03688827586302068, 0.04073162861459423, 0.03650310121884104, 0.04637498263036832, 0.026256203309458215, 0.024202502572734375, 0.02338035137654515, 0.010019544679380488, 0.010447382610436762, 0.015435847890330479, 0.03629272832768038, 0.055850868884590454, 0.037226309286779724, 0.0973205485206563, 0.03834141214611009, 0.06281731635681354, 0.07114321138942614, 0.043797726393677294, 0.023785680896253325, 0.08590276236645877, 0.023004145587037783, 0.03866833932988811, 0.06440157900215127, 0.015181249491433846, 0.024365875251532998, 0.03209218361007515, 0.03879690899339039, 0.03547724903910421, 0.023940604223753326, 0.02321405834663892, 0.06538863541209139, 0.0246215210063383, 0.05881777120521292, 0.030159072593960445, 0.042941176652675495, 0.04115933945286088, 0.0044116040953667834, 0.1040156556700822, 0.04178084731393028, 0.034929083922179416, 0.04657014891563449, 0.025989675814344082, 0.04452595880138688, 0.08129941328661516, 0.02981523000926245, 0.04563040813081898, 0.04914672979793977, 0.029334227401704993, 0.06844448042102158, 0.012506039965956006, 0.024176139631890692, 0.021028043811384123, 0.046050359815126285, 0.07333063229452819, 0.0314105766301509, 0.10344185677240603, 0.0677010636718478, 0.07521674124291167, 2.2795960027724504, 9.7563118301332, 22.52715390175581, 39.494666531682014, 40.49482226371765, 30.49073237925768, 20.341837964951992, 15.672251433134079, 16.062091514468193, 20.82540951669216, 24.44807432591915, 32.20756575465202, 24.668587893247604, 14.048274625092745, 5.18567911349237, 1.1292723286896944, 0.12151982460636646, 0.7110331649892032, 0.5539704335387796, 0.3145438857609406, 0.7656036992557347, 1.4378629135899246, 2.262394088320434, 1.6013880888931453, 4.023925652727485, 2.028604745864868, 3.8808448053896427, 4.520743293687701, 3.9618932688608766, 3.032189318910241, 3.3053661603480577, 1.5164773701690137, 1.6749215056188405, 2.53096011467278, 2.9508119355887175, 1.6483986913226545, 0.5947048414964229, 0.45876004092860967, 0.38082010752987117, 1.2115998985245824, 0.8672146406024694, 0.9247388632502407, 0.7065679295919836, 3.0677950708195567, 3.9092808170244098, 1.6696364642120898, 2.3955220822244883, 4.423833768814802, 4.662394467741251, 4.592862473800778, 4.554346315562725, 2.4246843298897147, 4.048532657325268, 4.669398916885257, 7.065663859248161, 2.244165991432965, 1.9745490839704871, 1.0018297797068954, 0.26337517832871526, 0.943468117620796, 0.21341775980545208, 1.2894085608422756, 2.143289716914296, 7.409001085907221, 10.193550568073988, 28.847326263785362, 31.394544281065464, 18.741532936692238, 15.6811230070889, 17.85123310983181, 18.678116239607334, 21.2284329906106, 28.70184727013111, 30.940670035779476, 26.48134522140026, 10.007177218794823, 2.2478137956932187, 0.08912510820664465, 0.06738826326909475, 0.017314088217972312, 0.04128740445594303, 0.045636141221621074, 0.02684381357539678, 0.09459044696995988, 0.022215639655769337, 0.05430306053312961, 0.020969703582522925, 0.054497384480782785, 0.029239277027954813, 0.02166894955735188, 0.014049535511730937, 0.03364917232829612, 0.029634791644639336, 0.01873650700872531, 0.08080195912043564, 0.02926370667410083, 0.03031352836842416, 0.09110375554882921, 0.07889132961281575, 0.04411404828715604, 0.03194901219103485, 0.044370723771862686, 0.0388474121427862, 0.0232606726422091, 0.022026403130439576, 0.030181177462509368, 0.01664784926106222, 0.03611245323554613, 0.022971761973167304, 0.00532490076693648, 0.011616849642450688, 0.07241900777444243, 0.03980182147643063, 0.022643283700745087, 0.01568647858221084, 0.04282145710021723, 0.036402421465027146, 0.05026575490774121, 0.058036942791659385, 0.024345926321984734, 0.028112874970247503, 0.051368371132411994, 0.19904801447410136, 0.11372870634659193, 0.06302417517872527, 0.06631433847360313, 0.15270788309862837, 0.08312725622090511, 0.09662716736784205, 0.1835264707915485, 0.1863398338900879, 0.11085810881922953, 0.16605033277301118, 0.13746825163252652, 0.14195649360772222, 0.1257386224460788, 0.1460514566861093, 0.12194364288006909, 0.09048790656379424, 0.11638359123026021, 0.22053026565117761, 0.11357969051459804, 0.1533905995893292, 0.1672015670919791, 0.10061432607471943, 0.16941788722760975, 0.11395468289265409, 0.09687298894277774, 0.14623737952206284, 0.19633681542472914, 0.1351530774263665, 0.1588386611547321, 0.10456537187565118, 0.1842415300779976, 0.13942027813754976, 0.1838979750755243, 0.13277964462758973, 0.09375754205393605, 0.1902041374705732, 0.1259569326066412, 0.19480324146570638, 0.1744343008613214, 0.2710352110443637, 0.15401471609948203, 0.20521739905234426, 0.14830991596681997, 0.21772778243757784, 0.11613644121098332, 0.08302998292492703, 0.12358032341580838, 0.16785185172921047, 0.27175886440090835, 0.22166058624861762, 0.1931782200699672, 0.15506748226471245, 0.11740463058231398, 1.6057138005271554, 9.009329862892628, 24.425290748476982, 44.91333916783333, 52.457701340317726, 41.28426030278206, 33.85317765176296, 29.3179215118289, 24.493174105882645, 26.921205818653107, 26.17879595607519, 29.52410414814949, 27.358896732330322, 17.022128999233246, 7.509489543735981, 2.179210614413023, 0.6353450263850391, 1.8166480818763375, 2.6128224469721317, 2.3302126117050648, 7.053659353405237, 3.8653497118502855, 6.261511584743857, 10.807873103767633, 18.389698415994644, 11.519773453474045, 10.279215071350336, 10.88129561394453, 8.633277341723442, 3.6462769797071815, 3.89779023360461, 2.9287194460630417, 1.3563740300014615, 3.992994362488389, 4.991936534643173, 1.5536817675456405, 0.7925293513108045, 0.6263472873251885, 0.2607586031081155, 0.9648159658536315, 0.45936313981655985, 0.7783024990931153, 1.0031543648801744, 3.4871500683948398, 6.070912862196565, 2.823604024015367, 4.068283047527075, 4.482007697224617, 6.01854027248919, 7.24145857617259, 8.210846409201622, 4.847084982320666, 9.608421865850687, 8.69662944227457, 19.892437979578972, 13.925115633755922, 11.924782320857048, 12.17305339872837, 4.4953373819589615, 3.3928540907800198, 1.9083482050336897, 1.9488745741546154, 3.829995933920145, 9.724089559167624, 14.27270008251071, 35.662081986665726, 33.72642405331135, 22.895563133060932, 31.876831501722336, 30.62719065696001, 27.09351897239685, 31.401414312422276, 36.946010291576385, 37.424754202365875, 28.444055803120136, 9.314691927284002, 1.9813356385566294, 0.20398080290760845, 0.14123220200417563, 0.1297819023602642, 0.1512015756452456, 0.15051246184157208, 0.12922999681904912, 0.19865135138388723, 0.09210412608808838, 0.16015175788197666, 0.13397281029028818, 0.10392877986305393, 0.09344367295852862, 0.12984826520550996, 0.12449399626348168, 0.12845618912251666, 0.1449670601869002, 0.13757241948042065, 0.19134325993945822, 0.14259862946346402, 0.1496008224785328, 0.21720689866924658, 0.1281655640923418, 0.10730680602137, 0.09296335498220287, 0.12903922033729032, 0.15036443306598812, 0.10180044133448973, 0.11634014590526931, 0.12710433744359761, 0.18165458139264956, 0.19545508461305872, 0.06293675760389306, 0.12295670414459892, 0.17607156769372523, 0.12588430603500456, 0.10429558635223657, 0.07326486316742375, 0.11460983601864427, 0.07494867750210688, 0.17772712104488164, 0.1781205929000862, 0.193775738007389, 0.17660003621131182, 0.09119273163378239, 0.13718605739995837], [0.020697472682513762, 0.027481941833684687, 0.023673950563534163, 0.042391879760543816, 0.050487308253650554, 0.024229837727034464, 0.09550673217745498, 0.01786020686267875, 0.023599429659952875, 0.04442715297045652, 0.031251115069608204, 0.0759197554725688, 0.042618835941539146, 0.03648890393378679, 0.018492869203328155, 0.05433323996840045, 0.0069954775062797125, 0.027716595941456035, 0.013729403617617209, 0.008117473062156932, 0.09363066448713653, 0.07564595493022352, 0.06870268101920374, 0.04596687933371868, 0.02189056784118293, 0.07033728354144841, 0.049855339821078815, 0.015386139766633278, 0.014024588217580458, 0.04297366045648232, 0.02232890808954835, 0.02942776212876197, 0.05142944246472325, 0.029316497493709903, 0.12219863740028813, 0.0075252090664434945, 0.052931141181034036, 0.042142970851273276, 0.017100869190471712, 0.061035464314045385, 0.06014831582433544, 0.032163058713194914, 0.03836979558400344, 0.015279041363100987, 0.017845373185991775, 0.016499495795869734, 0.014384583646460669, 0.04386365879327059, 0.016964839087449946, 0.09580124606145546, 0.0052233540918678045, 0.0901892886031419, 0.011427504578023218, 0.05958935245871544, 0.023823634328437038, 0.07788620190694928, 2.066446915268898, 12.686736434698105, 26.77834488451481, 35.55899731814861, 38.41655418276787, 30.31176198273897, 21.10754057765007, 22.29971520602703, 18.59915267676115, 21.042235381901264, 19.509067051112652, 22.540158703923225, 22.171665877103806, 18.94574347883463, 9.655440542846918, 4.245011089369655, 0.8782647445332259, 0.12887271208455786, 0.2653907920466736, 1.910792423877865, 2.8553040605038404, 1.526103203650564, 5.667211599647999, 1.8777393037453294, 2.0306442864239216, 2.8381888289004564, 1.7885678261518478, 3.271346348337829, 3.5577165568247437, 1.5952292131260037, 2.679006108082831, 2.8027429059147835, 2.9148216918110847, 2.083005951717496, 0.3626076551154256, 0.25683014828246087, 0.21451607899507508, 1.1591196083463728, 0.9766015678178519, 0.7409244985319674, 1.2140350928530097, 1.6045985603705049, 1.0536559112370014, 1.7351457802578807, 1.6365980682894588, 4.253221498802304, 3.333725701086223, 4.670711746439338, 0.9520858770702034, 0.9734638861846179, 2.6529563684016466, 6.205158708617091, 4.464961336925626, 2.4863452836871147, 1.0296084266155958, 1.1772155435755849, 0.6848491262644529, 2.4840490194037557, 3.6882302910089493, 12.645436450839043, 20.50659902393818, 27.271062545478344, 32.63403967022896, 55.69745309650898, 17.504087537527084, 18.800492472946644, 22.742866426706314, 25.12833282351494, 35.10676458477974, 29.669609740376472, 25.326792374253273, 11.171135511249304, 2.5699070747941732, 0.12052234102156945, 0.08644980684039183, 0.06592566089238971, 0.03739672123629134, 0.010240829924441641, 0.022685979456582572, 0.06278627974097617, 0.09248400179785676, 0.06387262808857486, 0.04276798164937645, 0.08374691242352128, 0.017052696384780575, 0.018876409267249983, 0.03177831822540611, 0.04828747492865659, 0.024065127327048685, 0.06623081717407331, 0.016798052529338747, 0.021020600070187356, 0.04415093302668538, 0.044285332260187715, 0.03530930101987906, 0.047520027437713, 0.029479204094968736, 0.07027816405752674, 0.006077393054511049, 0.14598810696043074, 0.07712275459198281, 0.06470694308518432, 0.03724682224856224, 0.046192418012651615, 0.026631195687514264, 0.052326517179608345, 0.04516612796578556, 0.04044812078063842, 0.05972805985948071, 0.018699303145695012, 0.0762628874508664, 0.007450025332218502, 0.03798151505179703, 0.03852531262964476, 0.033868436148623005, 0.05183903005672619, 0.06578448213986121, 0.03156369653879665, 0.0575466948794201, 0.04591673241520766, 0.031090017073438503, 0.03716662205988541, 0.017670309825916775, 0.003339608188070997, 0.09194865357130766, 0.0350772165984381, 0.08825007156701759, 0.048348735508625396, 0.05048743441875558, 0.04848933167522773, 0.03857613861327991, 0.0415025790425716, 0.03595609014155343, 0.04876878367213067, 0.04266383606591262, 0.006504264338218491, 0.03220797349058557, 0.032413025182904676, 0.0204912168555893, 0.031796408075024374, 0.0250956531817792, 0.029474346738425083, 0.029616050560434815, 0.002405151726634358, 0.06375867873430252, 0.025564603311067913, 0.0645947823068127, 0.05244228850642685, 0.05955089807684999, 0.06269998280913569, 0.03468578193860594, 0.040052604308584705, 0.01627927274967078, 0.05518158526683692, 0.05670546306646429, 0.018323255062568933, 0.06532408340717666, 0.07859435922000557, 0.027621775443549268, 0.11160355905303732, 0.038864474117872305, 0.029251720989122987, 0.06146910862298682, 0.01374867812046432, 0.026656616100808606, 0.02589097202871926, 0.05255367745121475, 0.05845139145094436, 0.028969988743483555, 0.033661332417977974, 0.060669800732284784, 0.13077351555693895, 0.0442196262156358, 0.06065508394385688, 0.011741681664716452, 0.3573444625362754, 4.293821370229125, 18.937629014253616, 35.05341924726963, 42.32042670249939, 39.89575020968914, 31.387510858476162, 19.44848120212555, 17.069953233003616, 17.798946015536785, 21.774180606007576, 32.21043460071087, 32.592310309410095, 29.376862049102783, 19.66599863022566, 10.580617748200893, 3.1080957083031535, 0.8943119959440082, 0.3044707450317219, 0.33576910151168704, 0.45891868241596967, 0.408307773177512, 0.5530974303837866, 0.44635997037403286, 1.2318157637491822, 2.1236725570634007, 3.1302045844495296, 2.2049183724448085, 1.9430029392242432, 3.3985010627657175, 2.4665257846936584, 1.4220827165991068, 2.4559279158711433, 2.5063469354063272, 3.7229395285248756, 1.2877243012189865, 0.7419208169449121, 1.3686173292808235, 1.9644785556010902, 1.6775515582412481, 2.519151298329234, 2.6157699013128877, 2.3545301193371415, 2.3605646705254912, 2.8941044909879565, 2.478463319130242, 4.514675019308925, 3.8501818757504225, 4.583950527012348, 3.1081633921712637, 1.7153710476122797, 1.392276759725064, 0.46950153016950935, 0.8320634986739606, 0.48410432471428066, 0.7123007532209158, 0.7438390608876944, 0.18296187452506274, 1.360613415017724, 4.326529540121555, 10.937958173453808, 20.516550689935684, 38.8947357237339, 36.91015541553497, 57.388647347688675, 22.59001962840557, 15.086830146610737, 17.772123254835606, 23.298693001270294, 31.985745057463646, 33.12692642211914, 32.13837906718254, 18.193636536598206, 5.668207621201873, 0.7473589188884944, 0.012979222192370798, 0.07277683427673765, 0.006490604182545212, 0.08786957987467758, 0.0409892280731583, 0.022083875046519097, 0.054701148546882905, 0.013883703541068826, 0.033430684052291326, 0.03605559730203822, 0.01874034947832115, 0.014710637879034039, 0.09756922736414708, 0.027573732513701543, 0.029490393826563377, 0.05992105907353107, 0.025960680104617495, 0.07855558942537755, 0.03799859929131344, 0.04719819138699677, 0.0017325940780210658, 0.020441980923351366, 0.03997998886916321, 0.11394775865483098, 0.09590524321538396, 0.0817824994737748, 0.0236093837156659, 0.016247499552264344, 0.05959670714219101, 0.028100067356717773, 0.04956651078828145, 0.01754299439198803, 0.040864962866180576, 0.0587448292208137, 0.02079872203466948, 0.024932894630183, 0.021424797814688645, 0.0074918852442351636, 0.03601079013606068, 0.020782277897524182, 0.048878064917516895, 0.05580213575740345, 0.037875321140745655, 0.012208132611704059, 0.04136570103582926, 0.028921066368639003, 0.1106883425381966, 0.09362854936625808, 0.14383198984432966, 0.13329861365491524, 0.16163931868504733, 0.11057079376769252, 0.1555630736402236, 0.062202409899327904, 0.3297475230647251, 0.16217569849686697, 0.10585320589598268, 0.19280986249214038, 0.16293941298499703, 0.11503862668178044, 0.12040571251418442, 0.11302767365123145, 0.14015019522048533, 0.10160476667806506, 0.10050100754597224, 0.10379057712270878, 0.16397551051340997, 0.1457134381053038, 0.1849531606421806, 0.22565212362678722, 0.14825682272203267, 0.14527990511851385, 0.1471223757835105, 0.10542491247178987, 0.10895821076701395, 0.10871765844058245, 0.13677622860996053, 0.10755814175354317, 0.11636701165116392, 0.18607104284456, 0.26342119148466736, 0.14909791352692991, 0.2249659487279132, 0.1637423870852217, 0.1386378169991076, 0.21814819425344467, 0.15803902671905234, 0.10399684964795597, 0.14140346000203863, 0.15555670601315796, 0.16846737416926771, 0.11352756206179038, 0.07319851516513154, 0.17344458756269887, 0.12992276198929176, 0.197908520931378, 0.08942025291617028, 0.1715720005449839, 0.22652091138297692, 0.19864338071784005, 0.17624343425268307, 0.3127809287980199, 3.7727254070341587, 17.542777061462402, 40.09456314146519, 49.98637855052948, 51.6263135522604, 42.39085212349892, 33.35316248238087, 31.30885697901249, 26.050847321748734, 30.054536685347557, 31.132006868720055, 32.70514525473118, 31.327304989099503, 24.794437140226364, 13.990838807076216, 5.809598034247756, 1.305770364124328, 0.43640545452944934, 0.8105787390377373, 3.321814527735114, 6.007067263126373, 4.45792886428535, 11.471004020422697, 6.799751278012991, 9.010685440152884, 8.49399771541357, 6.932590249925852, 10.758084375411272, 10.149060655385256, 4.64616316370666, 7.614646051079035, 8.76464769244194, 10.708192102611065, 6.149421399459243, 2.222356111742556, 0.8018459170125425, 2.4067851528525352, 3.860510434024036, 3.3636158471927047, 4.172692894935608, 4.881218075752258, 3.7044352339580655, 4.5869495160877705, 4.612739682197571, 4.7814026568084955, 10.436556078493595, 8.149229865521193, 13.692744802683592, 8.342144563794136, 5.678729256615043, 9.490690883249044, 13.750112224370241, 8.334690313786268, 4.402513587847352, 2.329469514079392, 3.0031185038387775, 1.4273456716910005, 3.9958731830120087, 5.20244998857379, 16.157715283334255, 23.74275427311659, 37.70873196423054, 36.91698744893074, 67.17135921120644, 22.907714881002903, 24.76113572716713, 32.81249709427357, 34.42038841545582, 44.9380112439394, 41.46055184304714, 36.74454130232334, 18.16784732043743, 5.2102747187018394, 0.584871384780854, 0.21464614779688418, 0.1993977144593373, 0.214828597381711, 0.23400253179715946, 0.1319751120172441, 0.2172653205343522, 0.18261232296936214, 0.1130271096189972, 0.10475611125002615, 0.1738399890018627, 0.09772721576155163, 0.14548527222359553, 0.18564761790912598, 0.1637412590207532, 0.18060408619930968, 0.1848215630161576, 0.11595777657930739, 0.11773102713050321, 0.17084151942981407, 0.16882036929018795, 0.07429122371831909, 0.1400809083133936, 0.14046173397218809, 0.17712302767904475, 0.16060053458204493, 0.20678239554399624, 0.13216051534982398, 0.14671487733721733, 0.14901050337357447, 0.1717006295803003, 0.13397058384725824, 0.07802001113304868, 0.12411759380484, 0.1516084506874904, 0.22056909481761977, 0.12745319138048217, 0.11841636340250261, 0.11394237808417529, 0.11378669776604511, 0.06128248445747886, 0.2488748001633212, 0.12110560230212286, 0.1396627229405567, 0.11104326724307612, 0.11035296600311995, 0.1727229231619276], [0.048400708110420965, 0.030022580504009966, 0.04109027147933375, 0.017101169760280754, 0.05956424560281448, 0.015858508413657546, 0.022541138205269817, 0.02692119545827154, 0.09306218678830191, 0.021452969740494154, 0.04736762370157521, 0.021412687819974963, 0.05478576451423578, 0.04352387761173304, 0.08364735331269912, 0.028929860818607267, 0.03666360178613104, 0.03767102272831835, 0.0445665876759449, 0.018841457822418306, 0.02852929217624478, 0.034532584104454145, 0.020175696481601335, 0.04271438374416903, 0.06865914663649164, 0.030739261383132543, 0.021548344993789215, 0.012314644718571799, 0.00936604839807842, 0.08862742397468537, 0.010494673188077286, 0.05705865114578046, 0.07151878264266998, 0.04786935263837222, 0.03548503045749385, 0.04692145936132874, 0.03158410559990443, 0.04727010178612545, 0.04373839168692939, 0.03376555963768624, 0.05925243596720975, 0.04017761908471584, 0.0511635161092272, 0.046303870039992034, 0.03351387880684342, 0.045672636333620176, 0.05543923667573836, 0.03624595075962134, 0.007491394962926279, 0.015115580554265762, 0.05129143639351241, 0.027199450742045883, 0.05444390160846524, 0.04769443956320174, 0.03307516934000887, 0.030620694014942273, 0.06727779458742589, 0.8075874682981521, 6.681623691692948, 19.217073619365692, 30.74136883020401, 38.17016780376434, 37.05943040549755, 31.486168764531612, 22.068744599819183, 23.072531037032604, 17.53624901175499, 21.38689398765564, 22.478444315493107, 21.949282810091972, 23.07232014834881, 20.38029570132494, 14.486632402986288, 7.296239286661148, 4.385511875152588, 1.9986010808497667, 0.8384112955536693, 0.16768642701208591, 0.16365785646485165, 0.3644839528715238, 1.1458567762747407, 2.5575952604413033, 2.165542747825384, 1.4069937262684107, 2.3312188452109694, 1.582487071864307, 1.541357603855431, 1.7129240976646543, 1.3088563922792673, 2.8669034130871296, 0.9376204095315188, 0.8935292379464954, 1.3115903455764055, 2.0178745966404676, 2.0790824247524142, 2.4799856124445796, 1.118715307675302, 2.0094449864700437, 1.4495969214476645, 1.180198264773935, 2.6686419267207384, 4.775068871676922, 4.816701337695122, 2.586384415626526, 2.747471546754241, 0.7772462151478976, 0.7336940208915621, 0.510154509684071, 0.35870755033101887, 0.7580400863662362, 1.5820145909674466, 4.1679217759519815, 10.844444241374731, 17.536440901458263, 24.084088057279587, 30.177743174135685, 25.88917549699545, 15.75432512909174, 37.6440404355526, 43.8918399810791, 18.556494265794754, 17.933265008032322, 23.217609152197838, 30.146828033030033, 31.33326306939125, 19.36013974249363, 6.41454647295177, 0.8875084016472101, 0.062478080653818324, 0.07220141749712639, 0.06892300982144661, 0.05716160929296166, 0.021730430926254485, 0.034702161137829535, 0.03669042300316505, 0.08148327295202762, 0.05715494480682537, 0.031195513365673833, 0.05757541599450633, 0.04030987351143267, 0.022892556262377184, 0.04642615371267311, 0.041894588866853155, 0.07326072198338807, 0.0196675108600175, 0.04788567988725845, 0.02021850541495951, 0.01023902186716441, 0.05290275774314068, 0.06752961271558888, 0.027926120928896125, 0.04151211935095489, 0.016633215964247938, 0.013446211196423974, 0.04939208381983917, 0.03839379292912781, 0.08955885641626082, 0.030261765423347242, 0.04934809672704432, 0.022463470595539548, 0.0323407585528912, 0.021483182572410442, 0.03205295368388761, 0.01083161101632868, 0.004772106040036306, 0.015544459347438533, 0.032066687126643956, 0.07889372674981132, 0.022959483139857184, 0.027390730028855614, 0.043398911075200886, 0.021154631940589752, 0.06478975934442133, 0.014141245483187959, 0.03022491593583254, 0.026845665233850013, 0.025269093093811534, 0.03248666849685833, 0.01529485838545952, 0.031844365657889284, 0.026869263674598187, 0.05996140593197197, 0.01980288787308382, 0.01209901092806831, 0.09243306078133173, 0.04308447052608244, 0.024039658674155362, 0.0389564559009159, 0.036191807375871576, 0.04653821059037, 0.03729617135832086, 0.05305460486852098, 0.02102164835378062, 0.009402889536431758, 0.02933872110588709, 0.014249721498345025, 0.028913674577779602, 0.03449026684393175, 0.0762131783994846, 0.13412459433311597, 0.03303370554931462, 0.08322219917317852, 0.045050145126879215, 0.004472816899578902, 0.01458499691580073, 0.06681663144263439, 0.021815579384565353, 0.049913119728444144, 0.057445837010163814, 0.029842754411220085, 0.07880669509177096, 0.07794501711032353, 0.09068151062820107, 0.04019885564048309, 0.05584015969361644, 0.0073037809579545865, 0.02113391674356535, 0.027073406236013398, 0.024187800627260003, 0.025783553574001417, 0.023466423808713444, 0.0059470918677106965, 0.049452806342742406, 0.005291922971082386, 0.04650919261621311, 0.03658850386273116, 0.02856791910744505, 0.03981834168371279, 0.012412226933520287, 0.05955391490715556, 0.04519470065133646, 0.02376932210609084, 0.05743925416027196, 2.1464148117229342, 10.812946781516075, 25.753638669848442, 38.428797125816345, 42.58035555481911, 39.79113422334194, 31.254227310419083, 16.578808687627316, 16.42832726240158, 15.928971357643604, 21.40642873942852, 29.485692009329796, 33.308689668774605, 34.5590315759182, 28.189477063715458, 19.333714060485363, 9.119592346251011, 4.882910409942269, 2.1233353251591325, 0.7935966784134507, 0.24558567587519065, 0.15356853691628203, 0.14642030408140272, 0.11341531964717433, 0.013192421738494886, 0.6470986269414425, 0.4412056360160932, 0.7142882840707898, 0.7804984843824059, 0.9670564800035208, 0.42556083644740283, 0.5432335159275681, 0.7297029881738126, 0.5564596562180668, 1.1319985636509955, 2.307065916247666, 1.3695710781030357, 1.3862372213043272, 1.3687510346062481, 2.0691060600802302, 0.14546597638400272, 0.907900482416153, 1.8143100198358297, 0.9710907947737724, 1.204157522879541, 0.42574678896926343, 0.8820682216901332, 0.14806126680923626, 0.18948625802295282, 0.333690523984842, 0.2921482140664011, 0.07249417249113321, 0.6483555282466114, 1.2375540495850146, 4.123712098225951, 10.816112011671066, 20.846627578139305, 28.384172916412354, 37.97354735434055, 40.65926603972912, 23.424698039889336, 41.02349929511547, 51.446343809366226, 15.295657441020012, 14.4197341427207, 27.180218920111656, 34.854564517736435, 38.87390524148941, 26.19818441569805, 11.346409656107426, 2.4977643834427, 0.07110905775334686, 0.05831302172737196, 0.05901908989471849, 0.06806424105889164, 0.04163611738476902, 0.05669276863045525, 0.07337113871471956, 0.06713946568197571, 0.04622523578291293, 0.01285264705074951, 0.06937593512702733, 0.04711047324235551, 0.059047105969511904, 0.03723739326233044, 0.06212157146364916, 0.028274273536226247, 0.012720092981908238, 0.03497454417811241, 0.04937142613925971, 0.015038448218547273, 0.030935051072447095, 0.029370536976784933, 0.008979395952337654, 0.015053481347422348, 0.02620034370920621, 0.03981995956564788, 0.15337483637267724, 0.06631792304688133, 0.015791442383488175, 0.0749083269329276, 0.03629623868619092, 0.0710840622195974, 0.030854709875711706, 0.0066683077329798834, 0.025682794039312284, 0.026355632544436958, 0.053829529497306794, 0.030017851167940535, 0.08488823164952919, 0.009593742088327417, 0.030446077798842452, 0.02617278219986474, 0.02113590198860038, 0.013731706130784005, 0.0781841148273088, 0.01967407515621744, 0.07524013373767957, 0.019120935794489924, 0.09450864745303988, 0.11771320816478692, 0.10268353027640842, 0.14217906369594857, 0.08836928274831735, 0.15602170606143773, 0.1303702621953562, 0.07089859209372662, 0.25779090297874063, 0.1631959734368138, 0.20323256962001324, 0.10249896557070315, 0.12771662411978468, 0.1981254803831689, 0.1487338900915347, 0.11311570720863529, 0.13449743448290974, 0.20858667528955266, 0.11541666186531074, 0.12149833943112753, 0.1737920759478584, 0.09653815417550504, 0.20104139344766736, 0.16219398501561955, 0.08143897415720858, 0.12948369258083403, 0.13101220509270206, 0.0707976748526562, 0.09807776179513894, 0.23259835870703682, 0.08638565559522249, 0.13396730355452746, 0.174109626095742, 0.10659806983312592, 0.14289799699326977, 0.11708791163982823, 0.15887789108091965, 0.10321783207473345, 0.17819366476032883, 0.1204719566158019, 0.13304288440849632, 0.13093401241349056, 0.14871361461700872, 0.1056382131355349, 0.1846946112345904, 0.09525684363325126, 0.10667328650015406, 0.17345901491353288, 0.11527732363902032, 0.10860661088372581, 0.1645064281183295, 0.15602210682118312, 0.07615103095304221, 0.11463172195362858, 0.15757024171762168, 0.11338636104483157, 0.1535465248161927, 1.5665099979378283, 9.950704649090767, 28.7398699298501, 43.635847717523575, 52.84665986895561, 50.59632562100887, 44.6236465126276, 32.24603869020939, 31.615036949515343, 24.20808870345354, 29.521199204027653, 32.48719274997711, 33.08954402804375, 34.6333821862936, 28.079778850078583, 21.94452926516533, 10.937339756637812, 6.396668432280421, 2.7793722599744797, 1.448401054367423, 0.5499023955781013, 0.5182473035529256, 0.8782414707820863, 3.5623173974454403, 5.904842773452401, 7.3194151930511, 4.703658828511834, 6.729403277859092, 6.595007814466953, 6.596660250797868, 4.756808951497078, 5.249715652316809, 8.828247729688883, 5.7922139670699835, 3.4017950110137463, 5.838605677708983, 6.703861523419619, 8.427485134452581, 8.500242680311203, 7.374035837128758, 6.928138788789511, 4.852328225970268, 4.942597132176161, 7.3596711829304695, 11.361544243991375, 11.560564264655113, 7.624611491337419, 7.630988974124193, 3.4039183845743537, 2.0664521399885416, 1.5754259820096195, 0.7068354589864612, 1.2729333573952317, 2.459378130733967, 5.612885439768434, 14.399554375559092, 22.50492699444294, 30.83063554018736, 40.19538313150406, 33.1815142929554, 22.670748196542263, 45.86399495601654, 51.933044493198395, 22.5600753352046, 25.821636021137238, 36.04819066822529, 44.08845283091068, 42.51671276986599, 27.472246550023556, 11.821619756519794, 2.262698784470558, 0.19686872750753537, 0.19211377250030637, 0.19014622026588768, 0.16991459182463586, 0.13153728941688314, 0.2209551600390114, 0.219000818033237, 0.08837362431222573, 0.15712732798419893, 0.13370471686357632, 0.1395834021968767, 0.1661865910864435, 0.23048020986607298, 0.1903439432498999, 0.22552186186658219, 0.13955962378531694, 0.07512613243306987, 0.0966513020102866, 0.1426239960710518, 0.10256708730594255, 0.12833251763368025, 0.1478337391745299, 0.1307425383129157, 0.20039250404806808, 0.16476126678753644, 0.17116753006121144, 0.3001309325918555, 0.2260163548635319, 0.21027326525654644, 0.1529222005046904, 0.14161428931402043, 0.13326975895324722, 0.1525838702218607, 0.09563409214024432, 0.15174813772318885, 0.103321510105161, 0.17426320613594726, 0.15564984554657713, 0.19817226537270471, 0.15315530908992514, 0.11396528818295337, 0.09935031499480829, 0.12535353685962036, 0.10488075495231897, 0.10708535657613538, 0.09969852326321416, 0.19454006105661392, 0.14315095060737804], [0.01857881547039142, 0.0641946608084254, 0.03860049218928907, 0.10338689331547357, 0.05534302465093788, 0.0056987789957929635, 0.03807386790867895, 0.006730122140652384, 0.024823227468004916, 0.04175047120952513, 0.030571246570616495, 0.030069790373090655, 0.04164102669165004, 0.05466385933686979, 0.05373262356442865, 0.06349454837618396, 0.06529229722218588, 0.06097767698520329, 0.030900012425263412, 0.0231098218500847, 0.07281918864464387, 0.04212640240439214, 0.04455795278772712, 0.02971339250507299, 0.04439076175913215, 0.055457356211263686, 0.06890404052683152, 0.053859757172176614, 0.10762204808997922, 0.061320649401750416, 0.06984978157561272, 0.07050149113638327, 0.01313852511884761, 0.01754638971760869, 0.01874132354714675, 0.016704612426110543, 0.017504716270195786, 0.03531195790856145, 0.05301353070535697, 0.06093505544413347, 0.03124101072899066, 0.041591777771827765, 0.02476421374012716, 0.022883850870130118, 0.061623631190741435, 0.029639715794473886, 0.03718369516718667, 0.015104707163118292, 0.08815807494102046, 0.03639099239080679, 0.08443959595751949, 0.056859325122786686, 0.02184796114306664, 0.057167861887137406, 0.02071953673294047, 0.0609399387758458, 0.012092691540601663, 0.038317344296956435, 0.3018321131821722, 3.4629864525049925, 10.300581324845552, 21.413756646215916, 30.961532816290855, 38.19839648902416, 41.08679249882698, 31.77507486194372, 29.182283990085125, 21.664157509803772, 21.64540931582451, 22.784930169582367, 22.776791006326675, 18.43158356845379, 19.370596781373024, 18.21239423006773, 17.45823159813881, 13.183127548545599, 8.30786470323801, 6.008312646299601, 3.059792462736368, 1.3282949617132545, 0.5313763709273189, 0.4658819572068751, 0.1858127606101334, 0.21789535938296467, 0.468290820135735, 0.5271370452828705, 0.7433168857824057, 0.35731649841181934, 0.25285942072514445, 0.6422797136474401, 0.6659763108473271, 0.6318576447665691, 1.245589549653232, 0.537918551126495, 0.2864931378280744, 0.7683416898362339, 1.5576144377700984, 0.1703584851929918, 0.7522150583099574, 1.4687179704196751, 0.7435916585382074, 0.3706951648928225, 0.5075824039522558, 0.9911707579158247, 0.388150418875739, 0.43033355847001076, 1.0041678417474031, 2.303085154853761, 5.274303182959557, 9.520857464522123, 17.15466968715191, 25.29218953102827, 25.880698151886463, 23.734383322298527, 19.49726488441229, 16.013266034424305, 19.020591862499714, 18.046303242444992, 25.874912962317467, 28.52234110236168, 27.1594625338912, 30.463959015905857, 26.672632656991482, 20.86701348423958, 9.360126089304686, 1.5235914196819067, 0.18759645317913964, 0.05139934837643523, 0.0552028144011274, 0.033562882817932405, 0.07916381655377336, 0.0885656476020813, 0.013540782147174468, 0.08571657977881841, 0.06169821703224443, 0.03565842955140397, 0.04681398153479677, 0.0331788510811748, 0.009149510115094017, 0.026743362031993456, 0.031240910539054312, 0.01050999204380787, 0.04170061001786962, 0.0640509587537963, 0.035608445905381814, 0.02968892946228152, 0.011275085071247304, 0.06382006919011474, 0.04539553694485221, 0.03191125171724707, 0.06191853099153377, 0.030187218544597272, 0.025903211899276357, 0.0349334700149484, 0.08475409587845206, 0.062183993504731916, 0.06592359030037187, 0.02421525823592674, 0.0221119375055423, 0.04878961204667576, 0.010654732177499682, 0.0719031854532659, 0.020921675495628733, 0.013185860225348733, 0.03159122650686186, 0.06708014581818134, 0.04095577576663345, 0.09249403563444503, 0.04417298965563532, 0.04721742414403707, 0.04784315111464821, 0.03033440312719904, 0.10395300356321968, 0.0712400245538447, 0.06733581569278613, 0.03034010838746326, 0.037611276129609905, 0.029336234911170322, 0.025555745778547134, 0.08053373210714199, 0.013574930217146175, 0.048998593410942703, 0.010413173313281732, 0.01104921428122907, 0.033701371285133064, 0.022854845883557573, 0.055948698791326024, 0.019545342220226303, 0.0571673757804092, 0.029502097495424096, 0.0485246838798048, 0.015963082587404642, 0.03314511675853282, 0.018323533367947675, 0.05315209709806368, 0.049322347913403064, 0.07228419664897956, 0.050607391458470374, 0.016363016693503596, 0.036178667651256546, 0.03983504000643734, 0.04229592377669178, 0.08286541167763062, 0.05081477720523253, 0.04280913373804651, 0.09987319514038973, 0.011180379606230417, 0.034315119992243126, 0.037172247539274395, 0.0334552788262954, 0.02466191610437818, 0.06191807085997425, 0.01836781175370561, 0.012916926316393074, 0.028400984119798522, 0.07251145711052231, 0.020306097394495737, 0.058008381238323636, 0.0784494771505706, 0.05147860603756271, 0.05251207265246194, 0.03969408389821183, 0.07460829147021286, 0.03298111696494743, 0.0811281701317057, 0.07068048973451369, 0.05526145519979764, 0.058720449669635855, 0.041827661989373155, 0.03213654548744671, 0.021288177704263944, 0.039266217208933085, 0.04805731638043653, 0.08648341128719039, 0.7053470669779927, 6.392543278634548, 16.344579756259918, 29.875834174454212, 38.86757478117943, 43.970700949430466, 41.0813207924366, 30.038668736815453, 22.2711768373847, 18.171022050082684, 17.421115189790726, 20.926271304488182, 24.994893483817577, 27.604743540287018, 29.244722239673138, 28.9582347124815, 26.931630559265614, 17.77328409254551, 10.195146482437849, 6.53506888076663, 3.2235503755509853, 1.8441767734475434, 0.6070405233185738, 0.5310926923993975, 0.21493234962690622, 0.048153027455555275, 0.14693946606712416, 0.24961353396065533, 0.29503478261176497, 0.08899665728677064, 0.10445230567711405, 0.40777918591629714, 0.33743551990482956, 0.2698161592707038, 0.4114117019344121, 0.3015590028371662, 0.2813869540113956, 0.20039101975271478, 0.19218442495912313, 0.43279235309455544, 0.22087640332756564, 0.08943175620515831, 0.24024344456847757, 0.18408220581477508, 0.3253173764096573, 0.21589541982393712, 0.14986225141910836, 0.3145637456327677, 1.175612979568541, 2.6832747040316463, 6.712488010525703, 10.983588974922895, 19.38382387161255, 30.422210656106472, 37.18762032687664, 36.3007403165102, 30.853920690715313, 24.104639254510403, 21.058247722685337, 13.104373924434185, 26.45423747599125, 33.10967154800892, 24.901686385273933, 28.2658738642931, 32.43575491011143, 28.219446055591106, 15.628631673753262, 4.9272507056593895, 0.7701204100158066, 0.17393725487636402, 0.03911063708073925, 0.08102636973490007, 0.046291075414046645, 0.038531001191586256, 0.0129070937873621, 0.02780928090942325, 0.03247430060582701, 0.028492463097791187, 0.07873135968111455, 0.07834303833078593, 0.06896025079186074, 0.016516366667929105, 0.05128846409206744, 0.04710566783614922, 0.03347032587043941, 0.08471638735500164, 0.003070957918680506, 0.039070175189408474, 0.02172264579712646, 0.06069661452784203, 0.05154388905793894, 0.04975871219357941, 0.02517732838896336, 0.06536551009048708, 0.02872363282222068, 0.022118403467175085, 0.047460006244364195, 0.07787535912939347, 0.06538660192745738, 0.025543826886860188, 0.03729012285475619, 0.051951855057268403, 0.03838699485640973, 0.005555820480367402, 0.030392786029551644, 0.04017829072836321, 0.021298096507962327, 0.05036017464590259, 0.042233145504724234, 0.032264677283819765, 0.012521608368842863, 0.04747677507111803, 0.06860813882667571, 0.034719456889433786, 0.10230177693301812, 0.08958238249761052, 0.07122130016796291, 0.044815533692599274, 0.08764673519181088, 0.17209077661391348, 0.19043852254981175, 0.22901878750417382, 0.14305384800536558, 0.10440221813041717, 0.08682451720233075, 0.10076170176034793, 0.15134694753214717, 0.18682200723560527, 0.14453136012889445, 0.20612145366612822, 0.1657062879530713, 0.15401654178276658, 0.12304587318794802, 0.2514583646552637, 0.12342642425210215, 0.30731058795936406, 0.14419506333069876, 0.12481951707741246, 0.22202664316864684, 0.12877841480076313, 0.18399941181996837, 0.17534490121761337, 0.16573358414461836, 0.1748421703814529, 0.20838074415223673, 0.1617945611360483, 0.19231498357839882, 0.30529859592206776, 0.18077138112857938, 0.143068453471642, 0.12259536728379317, 0.06523953794385307, 0.21300986059941351, 0.32668022671714425, 0.13263660308439285, 0.08286417229101062, 0.14395600272109732, 0.1444889241247438, 0.1231541673769243, 0.0733894549193792, 0.1356906001456082, 0.18988011579494923, 0.1077216443081852, 0.13020715297898278, 0.2616683574160561, 0.10065470632980578, 0.193788799806498, 0.16011984553188086, 0.16378716827603057, 0.20373816514620557, 0.10542576594161801, 0.1834968590992503, 0.1675627109943889, 0.16479260026244447, 0.1720987621229142, 0.21270209195790812, 0.4682086198590696, 5.626256922259927, 15.751052554696798, 32.20095410943031, 46.89583718776703, 53.402634635567665, 54.92100656032562, 44.842719957232475, 40.95528915524483, 31.013008654117584, 29.57070864737034, 30.89516557753086, 31.457419507205486, 28.86782616376877, 27.87755560129881, 27.96107891947031, 24.163906574249268, 17.96511109918356, 12.643458656966686, 8.0885024741292, 4.16304568760097, 2.0784742198884487, 0.9042356384452432, 0.765724639641121, 0.7915264426264912, 0.9416566835716367, 1.244900836609304, 1.8485713563859463, 1.8677243473939598, 1.4465690776705742, 1.6765917534939945, 2.606382742524147, 1.8231565388850868, 2.4479811172932386, 3.3965907152742147, 2.9739716928452253, 3.4640974178910255, 4.331494448706508, 4.605356678366661, 2.152939299121499, 2.6542361872270703, 4.236009372398257, 2.751691220328212, 2.346489275805652, 2.338855010457337, 2.72774466779083, 1.0779263963922858, 0.9198776178527623, 1.550522237084806, 3.4326719166710973, 8.09392573311925, 13.316920269280672, 22.702022418379784, 34.580758810043335, 34.13530491292477, 34.55170176923275, 26.241095513105392, 22.887524664402008, 26.74183264374733, 25.198611952364445, 34.115504175424576, 40.442130491137505, 36.143466755747795, 41.13764896988869, 39.16282273828983, 30.962701253592968, 15.689177624881268, 4.209022745490074, 0.5238766421098262, 0.1757454383186996, 0.1581768732285127, 0.1569921977352351, 0.19471479230560362, 0.135291428596247, 0.11187602372956462, 0.17430950130801648, 0.18604126787977293, 0.21450430853292346, 0.09770244287210517, 0.11490685836179182, 0.16976510843960568, 0.09374344124807976, 0.113926021149382, 0.10533860811847262, 0.10717097815359011, 0.2338906010845676, 0.12109001720091328, 0.11029185756342486, 0.0691864945110865, 0.14333451341371983, 0.18939715577289462, 0.16836442344356328, 0.19396805815631524, 0.16179275029571727, 0.1226746138127055, 0.10572495535598136, 0.19546519266441464, 0.25626403803471476, 0.17924061248777434, 0.17661829304415733, 0.10425807820865884, 0.15198759909253567, 0.17782762268325314, 0.17851893324404955, 0.08425048930803314, 0.1232338666159194, 0.13738645211560652, 0.23954512813361362, 0.19764019001740962, 0.1428432561806403, 0.1403021128498949, 0.19586038630222902, 0.2511124644661322, 0.19933193048927933, 0.19890375580871478, 0.17987793922657147, 0.18911243823822588, 0.18575914786197245], [0.0034784294621204026, 0.041056526024476625, 0.016904996009543538, 0.025609670228732284, 0.025350718206027523, 0.034632892784429714, 0.037422050736495294, 0.026991491686203517, 0.05034219611843582, 0.024490190553478897, 0.047041360739967786, 0.049375125745427795, 0.03398018503503408, 0.03668709447083529, 0.03236237731471192, 0.03125920447928365, 0.0692319733207114, 0.1181502737745177, 0.044784400597563945, 0.08044488218729384, 0.013339559936866863, 0.09618737807613797, 0.07337372881011106, 0.07662595351575874, 0.022178550825628918, 0.04161063574429136, 0.11054260699893348, 0.05205880595894996, 0.04416834010044113, 0.015471537772100419, 0.04882787347014528, 0.15831731725484133, 0.03692796592076775, 0.03249640547437593, 0.05747084738686681, 0.05068998878414277, 0.091831854369957, 0.045237381564220414, 0.09953667569789104, 0.06557757878908888, 0.016535990907868836, 0.03578341093088966, 0.03899188603099901, 0.03863482394081075, 0.04786383105965797, 0.013355439114093315, 0.06957901641726494, 0.07750329081318341, 0.030664890764455777, 0.021706919687858317, 0.051947368774563074, 0.05178864194022026, 0.011342101934133098, 0.012542896874947473, 0.01045095048539224, 0.05861335033841897, 0.016655990621075034, 0.053423081189976074, 0.04186935955658555, 0.04104000952793285, 0.6295236200094223, 3.7573739932850003, 13.014648389071226, 19.905885457992554, 31.571255698800087, 39.85632732510567, 37.89811000227928, 40.72117231786251, 33.08974161744118, 28.434354923665524, 23.93840577453375, 23.338224180042744, 27.650994658470154, 22.998928986489773, 22.34217032790184, 17.016577497124672, 24.439817368984222, 22.01670829206705, 21.019966676831245, 13.083901572972536, 9.784985091537237, 6.806777101010084, 3.9222041610628366, 3.158065639436245, 1.5045103873126209, 1.4180538640357554, 0.4675758647499606, 0.4455284681171179, 0.4579470626777038, 0.38159482064656913, 0.32662984973285347, 0.21664700761903077, 0.6063306145370007, 0.3749926155433059, 0.36008325463626534, 0.24205565045122057, 0.2834900817833841, 0.06903953442815691, 0.16640825575450435, 0.4482107382500544, 0.415420932113193, 0.7652037113439292, 1.4190869336016476, 2.506887218914926, 4.966572895646095, 9.491693079471588, 10.222218129783869, 14.639269262552261, 14.32063166052103, 20.762135311961174, 22.537810429930687, 19.807170554995537, 19.56790119409561, 19.589463137090206, 21.76158808171749, 17.140112668275833, 18.274405002593994, 20.636227168142796, 27.68879882991314, 31.22434001415968, 33.87748874723911, 29.931968562304974, 17.747831158339977, 6.087445775046945, 0.9161078045144677, 0.06699773774016649, 0.1530497460043989, 0.03742818458704278, 0.036474580483627506, 0.048113159282365814, 0.09788698531338014, 0.06288729346124455, 0.07760618216707371, 0.05209957955230493, 0.05937334666668903, 0.02931715986051131, 0.08535430039046332, 0.01710366523184348, 0.02643223702762043, 0.05968147896055598, 0.09085737736313604, 0.07944024429889396, 0.03570857646991499, 0.047357367220683955, 0.04453380701306742, 0.018643374896782916, 0.07345178790274076, 0.05015092610847205, 0.011113169784948695, 0.06698783749016002, 0.05336094487574883, 0.02934669733804185, 0.032113037959788926, 0.03278613250586204, 0.027078374914708547, 0.07497778453398496, 0.02008836981985951, 0.04015688718936872, 0.033051350110326894, 0.11118095790152438, 0.0348459596716566, 0.06766932201571763, 0.025922993845597375, 0.03854265291010961, 0.04612888646079227, 0.01176149236925994, 0.04387141794722993, 0.1065614448452834, 0.015453398755198577, 0.021972547328914516, 0.021938855679763947, 0.019038273530895822, 0.05260134559648577, 0.046410457289312035, 0.07890414650319144, 0.07021750090643764, 0.0342597743292572, 0.04787759418832138, 0.0526411543978611, 0.051783291055471636, 0.06614861689740792, 0.041622246644692495, 0.029745655519946013, 0.04517896340985317, 0.032596784658380784, 0.03709096010425128, 0.055753094638930634, 0.017904483393067494, 0.04941273407894187, 0.05786047491710633, 0.047301743252319284, 0.014647330826846883, 0.05465065281896386, 0.03324463505123276, 0.03248892833653372, 0.07255626798723824, 0.007992243063199567, 0.07999964553164318, 0.04561042209388688, 0.0058019361313199624, 0.03415708335523959, 0.0198051495681284, 0.01565595590363955, 0.07271651993505657, 0.024723365932004526, 0.012797932213288732, 0.04292960285965819, 0.038961892132647336, 0.012076642597094178, 0.05501421612279955, 0.02796050648612436, 0.015332971379393712, 0.026437496999278665, 0.06271803184063174, 0.04900756226561498, 0.050407382659614086, 0.03573545334802475, 0.02058969985228032, 0.04681225233071018, 0.1075630473496858, 0.027779164556704927, 0.049531989789102226, 0.06250624515814707, 0.002876844091588282, 0.03284082136815414, 0.014409714622161118, 0.09269449714338407, 0.03381919836101588, 0.04308414027036633, 0.011202759069419699, 0.016918465989874676, 0.03920618117263075, 0.044246451143408194, 0.05274817951431032, 0.03625451514380984, 0.1203023610287346, 1.7470860457979143, 6.80238738656044, 19.281115382909775, 26.9517694786191, 41.01840756833553, 44.11483481526375, 42.09442622959614, 37.3572052270174, 27.651433534920216, 27.03361138701439, 19.336577206850052, 15.720222909003496, 20.20913578569889, 21.94953739643097, 25.377749539911747, 27.095194682478905, 31.78756669163704, 26.874612718820572, 22.27000080049038, 18.21004405617714, 12.81104201450944, 9.040977414697409, 5.332583030685782, 4.21680330298841, 1.3259343383833766, 1.0218104138039052, 0.6349569128360599, 0.6282221304718405, 0.6082983745727688, 0.23940560437040403, 0.2287160506239161, 0.20870001608273014, 0.28081529249902815, 0.24382151663303375, 0.30527345195878297, 0.33525419945362955, 0.2484056886169128, 0.17038601887179539, 0.10800558258779347, 0.488431045669131, 0.6224041082896292, 0.8725358988158405, 1.2889152998104692, 3.677721479907632, 6.07985520735383, 11.42744505777955, 16.439901441335678, 22.108363173902035, 23.71417410671711, 29.07117985188961, 30.82241278141737, 28.314792439341545, 23.831067234277725, 19.749483950436115, 14.690072536468506, 13.36960444226861, 15.660817846655846, 19.94506135582924, 27.940202839672565, 35.59597313404083, 37.52605676651001, 36.030472218990326, 23.446795754134655, 10.150023903697729, 2.100347983650863, 0.03506974317133427, 0.06277105829212815, 0.006674147971352795, 0.08136765376548283, 0.08650703384773806, 0.07754174890578724, 0.013428628790279618, 0.043063820266979747, 0.04150254935666453, 0.017798059416236356, 0.08399874539463781, 0.02891956908570137, 0.04710200533736497, 0.027071758668171242, 0.010832220505108126, 0.07577865093480796, 0.07432007841998711, 0.04229669561027549, 0.036148369472357444, 0.009346583719889168, 0.05495105193404015, 0.009585712978150696, 0.018180499246227555, 0.03427383431699127, 0.026446771989867557, 0.03677818938740529, 0.037300869153114036, 0.04439607553649694, 0.03125970542896539, 0.05546556807530578, 0.05031603170209564, 0.03206330293323845, 0.014778600980207557, 0.08929030285798945, 0.06194251720444299, 0.03159373125527054, 0.03846503539534751, 0.040677722718100995, 0.06998402866884135, 0.10301005298970267, 0.05435406092146877, 0.030031710775801912, 0.05600264179520309, 0.015171112681855448, 0.02849756165232975, 0.04016779304947704, 0.04206986188364681, 0.024784298111626413, 0.09010480251163244, 0.018746676287264563, 0.024039638265094254, 0.13336312113096938, 0.09943813332938589, 0.2831378881819546, 0.20917818183079362, 0.1598921397817321, 0.17730534367728978, 0.12848404934629798, 0.16278133552987128, 0.1503599208081141, 0.10121661602170207, 0.1478975935606286, 0.14630823978222907, 0.10808925973833539, 0.12076692320988514, 0.19859983149217442, 0.14832860324531794, 0.1451555360108614, 0.23727924737613648, 0.21448700164910406, 0.19540553883416578, 0.0750992370012682, 0.20154547499259934, 0.1579120897804387, 0.1344378845533356, 0.14826498634647578, 0.08793642511591315, 0.22767170041333884, 0.1523953498690389, 0.12783260695869103, 0.08472829882521182, 0.170523984124884, 0.20245548163075, 0.22159267973620445, 0.10574043655651622, 0.21428495936561376, 0.1290447567589581, 0.18627577170263976, 0.12983437220100313, 0.1447528912103735, 0.29349316377192736, 0.11741426365915686, 0.14876905304845423, 0.11832576201413758, 0.22109560406534, 0.11412728417781182, 0.09456119893002324, 0.1795946911443025, 0.1508684255531989, 0.1475686885532923, 0.15723743301350623, 0.17233604157809168, 0.11293321309494786, 0.1214387895015534, 0.05430029232229572, 0.10356069687986746, 0.1816575796692632, 0.15718591312179342, 0.2745157649042085, 0.17567514209076762, 0.13985688361572102, 1.2733101309277117, 6.033192286267877, 19.309268072247505, 30.866091437637806, 45.60300976037979, 53.87859329581261, 52.057795599102974, 53.2774693518877, 43.752083480358124, 40.20361348986626, 34.02838245034218, 32.81123176217079, 38.38694617152214, 34.42465178668499, 33.070522248744965, 26.774850971996784, 36.817827969789505, 31.157057024538517, 27.522335462272167, 19.08292941749096, 14.021009188145399, 10.28621619567275, 5.90169464237988, 4.460285687819123, 2.106508403085172, 1.9579332880675793, 1.1519660172052681, 1.1172878905199468, 0.9585215442348272, 0.8942862879484892, 0.669181557605043, 0.4925277008442208, 1.1100917891599238, 0.8380948437843472, 0.9076557517983019, 0.5344498122576624, 0.8086378150619566, 0.39037508075125515, 0.6559590983670205, 0.8084764424711466, 0.884376063477248, 1.6246269294060767, 1.8983054626733065, 3.8021044805645943, 6.971577582880855, 13.265722766518593, 16.539116017520428, 22.313227280974388, 21.649383902549744, 28.44014011323452, 32.503007501363754, 27.29205831885338, 27.89574522525072, 25.910781137645245, 28.627728447318077, 26.034255512058735, 28.117047250270844, 31.518248543143272, 39.06239412724972, 43.22570152580738, 46.29685252904892, 40.20396687090397, 25.158087126910686, 9.266173280775547, 1.664444636553526, 0.18899793969467282, 0.2167170960456133, 0.1470833388157189, 0.15114229288883507, 0.2413595307734795, 0.21295014739735052, 0.22188127128174528, 0.20707759220385924, 0.07660710296477191, 0.17621656850678846, 0.13073165842797607, 0.18495529802748933, 0.16325587959727272, 0.11578954654396512, 0.16668353317072615, 0.22544264502357692, 0.22303709207335487, 0.15474227315280586, 0.27408048044890165, 0.15415478905197233, 0.14719274622621015, 0.14170392591040581, 0.09819568163948134, 0.22642325959168375, 0.20561294892104343, 0.14041542395716533, 0.13090958091197535, 0.14706805057357997, 0.08580536290537566, 0.13130505656590685, 0.2060564118437469, 0.08968248337623663, 0.09536366094835103, 0.1898449083091691, 0.22764783294405788, 0.133506043930538, 0.12828810751670972, 0.09436890846700408, 0.1656016006018035, 0.2139430370880291, 0.12246431884705089, 0.12086980714229867, 0.22207081579836085, 0.0928592390846461, 0.16842772864038125, 0.06668328976957127, 0.1356505390140228, 0.17725168640026823, 0.21538409491768107, 0.18447514332365245, 0.29100263491272926], [0.04514286534686107, 0.004450981523405062, 0.043427209166111425, 0.05359720758860931, 0.03426881739869714, 0.0920799098093994, 0.057160907963407226, 0.13221472181612626, 0.018036249857686926, 0.016198105913645122, 0.09866076332400553, 0.007972086332301842, 0.11384144600015134, 0.03724294081621338, 0.08209121064282954, 0.05810182876302861, 0.030036362186365295, 0.053626466760761105, 0.023298423839150928, 0.038849141346872784, 0.08497438015183434, 0.07378245922154747, 0.04586358722008299, 0.0089679436860024, 0.06613643083255738, 0.052191323848092, 0.00856535083585186, 0.04126557418203447, 0.011421328981668921, 0.05734202539315447, 0.08541929768398404, 0.055018546554492787, 0.05494015720614698, 0.052045313714188524, 0.012110462266718969, 0.022139896063890774, 0.03896135036484338, 0.04295437945984304, 0.04398586454044562, 0.03714029437105637, 0.01819101547880564, 0.0695743557298556, 0.016723735716368537, 0.11306834334391169, 0.05725837792851962, 0.044753794427379034, 0.029035299594397657, 0.011053551206714474, 0.03018439467268763, 0.04699975223047659, 0.01524903633253416, 0.0082048572403437, 0.02747442758845864, 0.033400259708287194, 0.058129139797529206, 0.042462190831429325, 0.02911583931563655, 0.039163014153018594, 0.0028881180105599924, 0.013300996088219108, 0.06453038615291007, 0.07926334597868845, 0.608170903287828, 2.775447783060372, 9.043498579412699, 19.955932572484016, 26.255777925252914, 28.783991262316704, 40.400944501161575, 40.890647023916245, 34.63212825357914, 29.849896766245365, 35.849715918302536, 28.423913083970547, 34.163111820816994, 25.262995697557926, 15.13386782258749, 42.94819101691246, 35.214412808418274, 23.237005211412907, 19.039056971669197, 19.76812954992056, 16.5559434145689, 17.536306008696556, 19.24394767731428, 15.44000694528222, 14.134765584021807, 11.06018241494894, 10.770819392055273, 8.097809124737978, 7.356107449159026, 6.4460429828614, 5.873576151207089, 4.769665561616421, 5.345439165830612, 4.733967427164316, 4.966667890548706, 5.732739083468914, 6.660399455577135, 8.467371594160795, 10.288075245916843, 14.849988855421543, 17.53599252551794, 18.013094924390316, 17.32264917343855, 20.481237284839153, 19.04469206929207, 18.981282971799374, 24.23425979912281, 24.229703843593597, 25.350438505411148, 23.589390702545643, 23.905440643429756, 28.555104844272137, 29.921669214963913, 34.80542175471783, 31.395378336310387, 33.9856081455946, 33.984859585762024, 27.795639596879482, 20.7712909206748, 7.474080193787813, 1.1712863179855049, 0.19532774691469967, 0.041435225430177525, 0.010830530263774563, 0.03602568875066936, 0.05146503586729523, 0.05352670355932787, 0.07496834441553801, 0.03150776828988455, 0.016743526939535514, 0.07073278888128698, 0.041670018690638244, 0.07630402469658293, 0.014013361378601985, 0.04832323160371743, 0.021959004989184905, 0.08053931305767037, 0.039089214988052845, 0.03165167443512473, 0.03473528318863828, 0.0862576425424777, 0.043305842045811005, 0.035014256500289775, 0.08503534758347087, 0.028294985022512265, 0.052689679723698646, 0.05765071058704052, 0.008031096349441214, 0.07823086270946078, 0.047385884245159104, 0.08831678322167136, 0.014789600536460057, 0.04701620935520623, 0.07191324155428447, 0.10931327647995204, 0.01954686362296343, 0.026466520539543126, 0.07460267341230065, 0.10385723682702519, 0.03294113004812971, 0.061645572786801495, 0.08890035620424896, 0.0694145193847362, 0.043397864646976814, 0.051801340086967684, 0.01462412850742112, 0.022038923161744606, 0.014860809606034309, 0.04335359553806484, 0.014514136655634502, 0.025868813354463782, 0.02650808080943534, 0.029921837667643558, 0.03622365664341487, 0.0326042395317927, 0.09112189363804646, 0.01996445713302819, 0.01398267449985724, 0.020196676996420138, 0.033748939240467735, 0.05059613678895403, 0.09943459328496829, 0.016344526084139943, 0.06030705008015502, 0.003985449448009604, 0.020476186509768013, 0.04462939192308113, 0.0173071417157189, 0.033566370912012644, 0.06923872686456889, 0.025537479668855667, 0.03816999087575823, 0.060671615283354186, 0.06525280012283474, 0.037707788724219427, 0.06420856123440899, 0.028536815698316786, 0.06570104989805259, 0.026058224284497555, 0.046454295952571556, 0.04348757916886825, 0.10267219025990926, 0.0405422956100665, 0.05597225084784441, 0.02259924465761287, 0.06108606394263916, 0.01037076235661516, 0.07438675296725705, 0.02947081782622263, 0.023243200630531646, 0.018318035909032915, 0.05798558246169705, 0.025143477178062312, 0.04203207543469034, 0.036123696772847325, 0.016582167336309794, 0.030100179465080146, 0.07802620806614868, 0.07361529787885956, 0.050309767975704744, 0.09829922608332708, 0.05302035846398212, 0.011310351928841555, 0.05527210501895752, 0.025321713219454978, 0.0074991235032939585, 0.0006856950540168327, 0.10136186916497536, 0.05805599743325729, 0.03769904622458853, 0.04962020888342522, 0.03420755310798995, 0.028973762564419303, 0.0649866956518963, 0.0382516196987126, 0.12448999608750455, 1.3926117355003953, 5.380383040755987, 13.057196605950594, 28.48000757396221, 36.37126073241234, 38.849400356411934, 45.97350887954235, 43.86593297123909, 34.531399458646774, 28.64552479237318, 31.54289972037077, 23.24313998222351, 23.509786874055862, 16.02465782314539, 21.475273445248604, 43.25356923043728, 34.866423681378365, 28.437531553208828, 29.399337843060493, 30.304511971771717, 27.583734467625618, 22.322717271745205, 22.384348064661026, 20.81594992429018, 15.847998652607203, 13.011652249842882, 12.930984478443861, 10.645416621118784, 9.008211772888899, 7.461531842127442, 6.243834933266044, 6.255751568824053, 7.3848234582692385, 5.886063706129789, 7.328244494274259, 7.766715316101909, 6.552079143002629, 9.28248105570674, 14.179364740848541, 18.60017292201519, 23.383019976317883, 24.738536439836025, 28.20809606462717, 30.602319091558456, 24.660097248852253, 21.01526252925396, 21.393425837159157, 19.196360930800438, 24.34540383517742, 18.2645483314991, 20.092569440603256, 19.416414722800255, 25.05864456295967, 30.124397836625576, 32.20687799155712, 35.172162875533104, 38.385639041662216, 32.39095911383629, 26.586979553103447, 12.543366327881813, 3.054480110295117, 0.4192891245475039, 0.025393317482667044, 0.029796494491165504, 0.025501891832391266, 0.006482980470536859, 0.07127371805836447, 0.03309334453660995, 0.0308899229275994, 0.037769561386085115, 0.05149748998519499, 0.07641240794328041, 0.020534638060780708, 0.01885289246274624, 0.018376949446974322, 0.028577162556757685, 0.01829823355365079, 0.03307424165541306, 0.006598870077141328, 0.04800178146979306, 0.030245877896959428, 0.01866439251898555, 0.016925152740441263, 0.02293747846124461, 0.07813516276655719, 0.058765516587300226, 0.08348440736881457, 0.008289604011224583, 0.026843707819352858, 0.09891672263620421, 0.03614521163399331, 0.0486231037939433, 0.04359124606708065, 0.056565453196526505, 0.0663875810278114, 0.048892525664996356, 0.027697511613951065, 0.08238372072810307, 0.07727629752480425, 0.027053370104113128, 0.0649049406638369, 0.03489132344839163, 0.05077502035419457, 0.05672747145581525, 0.009500646156084258, 0.0033079966397053795, 0.012991064086236292, 0.029782043020532, 0.03599651492550038, 0.05442103974928614, 0.009550906252115965, 0.0718489864084404, 0.0070431303447549, 0.06008600510540418, 0.13317319069756195, 0.2057692303787917, 0.11107912039733492, 0.18023909797193483, 0.14069769240450114, 0.11928828302188776, 0.21399463119450957, 0.1852346572559327, 0.10773250192869455, 0.25600336608476937, 0.2081045910017565, 0.08435303185251541, 0.1785111110075377, 0.13077249139314517, 0.13319802295882255, 0.166205738496501, 0.16262812656350434, 0.1665206762845628, 0.12363268935587257, 0.1783450777293183, 0.18997454666532576, 0.16989580064546317, 0.11255161560256965, 0.13969212683150545, 0.1897526445100084, 0.12391025258693844, 0.10564472177065909, 0.20021507138153538, 0.1667994714807719, 0.1395894878078252, 0.1348444478935562, 0.2270293715992011, 0.2008667660993524, 0.23396451899316162, 0.18549276137491688, 0.14337202155729756, 0.12369831005344167, 0.09198979823850095, 0.15846178372157738, 0.1621734572108835, 0.06979520403547212, 0.21773471409687772, 0.18301603646250442, 0.23369277419988066, 0.11786061353632249, 0.1443307427689433, 0.126430066593457, 0.14090344542637467, 0.08878773529431783, 0.20538693526759744, 0.18428748386213556, 0.15538589330390096, 0.07507538437494077, 0.19955512398155406, 0.2019693303736858, 0.07952497529913671, 0.20987897703889757, 0.16408686235081404, 0.09472096848185174, 0.1706670256680809, 0.1682522997725755, 0.16697205050149933, 1.1514063784852624, 4.171580504626036, 12.08012843504548, 27.727005779743195, 43.21496330201626, 46.41031824052334, 56.584568694233894, 54.27048146724701, 48.922648429870605, 40.765268951654434, 48.28454487025738, 37.279875576496124, 43.53486813604832, 32.19072885811329, 22.37757682800293, 52.26884767413139, 44.057317301630974, 33.422687351703644, 29.253292679786682, 31.189837865531445, 26.02562617510557, 24.468931406736374, 27.700834684073925, 21.526021622121334, 18.84033903479576, 15.917666014283895, 13.63126315176487, 11.121451277285814, 10.072013139724731, 8.678401820361614, 8.033405430614948, 6.838166266679764, 7.941366294398904, 7.013736795634031, 8.095041923224926, 8.849337548017502, 8.988461382687092, 13.031512834131718, 14.943937864154577, 21.132239252328873, 24.4451142847538, 26.7222560942173, 26.448915861546993, 29.93953585624695, 27.629147730767727, 26.34435687214136, 34.96019124984741, 29.950009994208813, 36.92027807235718, 32.11554989218712, 33.64330351352692, 37.68590658903122, 40.07437102496624, 45.46141795814037, 44.58623751997948, 45.75073063373566, 46.927348896861076, 38.10557886958122, 28.385512344539165, 12.742470894008875, 2.562865815125406, 0.36557090235874057, 0.12094644873286597, 0.08573681814596057, 0.10162092323298566, 0.12908352655358613, 0.13137355679646134, 0.12007769066258334, 0.09051580389495939, 0.12771393754519522, 0.12790388282155618, 0.10731725546065718, 0.19190233462722972, 0.16052968916483223, 0.15417935414006934, 0.1562391998595558, 0.2268367842771113, 0.15616934892022982, 0.16658317996188998, 0.1254086784319952, 0.1628921233350411, 0.07013369759079069, 0.1326316306949593, 0.12418666548910551, 0.19242085836594924, 0.2674362401012331, 0.32123179407790303, 0.1669185861828737, 0.17336943768896163, 0.1942730660084635, 0.1678105883183889, 0.11530501316883601, 0.08419296544161625, 0.13592384231742471, 0.2440939738880843, 0.13074734742986038, 0.15606060944264755, 0.19882572640199214, 0.2647964208154008, 0.15346318163210526, 0.2075336716370657, 0.13937773823272437, 0.19726580620044842, 0.11069004205637611, 0.08627555056591518, 0.1435849882545881, 0.08617523446446285, 0.09680304894573055, 0.09478883046540432, 0.16534554481040686, 0.07981013812241144, 0.24783896980807185, 0.18973005353473127, 0.1457174457027577], [0.04166801860264968, 0.015090277029230492, 0.06139695702586323, 0.05102070092107169, 0.07149194658268243, 0.018503600658732466, 0.03605903715651948, 0.028392108033585828, 0.057293039935757406, 0.018086550771840848, 0.013728363683185307, 0.022347472913679667, 0.05177434446522966, 0.01882829954411136, 0.04157395138463471, 0.03535582625772804, 0.02151927135855658, 0.034833202153095044, 0.05646956771670375, 0.024655565175635274, 0.0662846228806302, 0.03165256501233671, 0.0134769908436283, 0.030466119496850297, 0.06743322999682277, 0.027153008995810524, 0.021519853944482747, 0.05003542566555552, 0.09122532675974071, 0.053245897142915055, 0.0512539913324872, 0.03143953152175527, 0.013097364681016188, 0.038087300781626254, 0.05421956149803009, 0.07026165869319811, 0.03245582483941689, 0.043666581477737054, 0.09171845420496538, 0.022905883379280567, 0.07236431149067357, 0.04220182316203136, 0.03843581704131793, 0.04534338251687586, 0.011561688588699326, 0.06387958201230504, 0.018134135425498243, 0.049442891249782406, 0.0504292018013075, 0.061037887426209636, 0.060469146264949813, 0.04439211617864203, 0.02001628130528843, 0.04883626716036815, 0.023646719309908804, 0.06554232677444816, 0.0489925745932851, 0.04122051097510848, 0.024854189869074617, 0.03499496808217373, 0.03466249334451277, 0.09119723647017963, 0.052579971743398346, 0.12186915351776406, 0.2564133581472561, 0.8919873519334942, 5.1339325401932, 9.056739918887615, 17.54009250551462, 26.96396492421627, 34.98866692185402, 40.71082927286625, 41.83728642761707, 38.89980845153332, 35.2168332785368, 48.85759972035885, 18.568938598036766, 56.42992839217186, 57.38618887960911, 25.632174387574196, 26.021066419780254, 21.145076863467693, 17.07102857530117, 19.982246160507202, 14.904797114431858, 15.43774701654911, 16.588264480233192, 18.735390566289425, 17.24405989050865, 20.999172292649746, 20.872705578804016, 18.446921445429325, 20.24376142770052, 18.438776582479477, 21.237767189741135, 22.61340357363224, 17.70198091864586, 20.624943673610687, 34.78074587881565, 26.454655453562737, 15.571553986519575, 22.15346485376358, 21.229369640350342, 17.158832363784313, 20.732861682772636, 23.635936304926872, 29.00541678071022, 28.286907635629177, 34.130904749035835, 33.67087483406067, 33.228331580758095, 39.78409320116043, 36.399512216448784, 39.43686783313751, 38.884559869766235, 31.73361148685217, 23.714882768690586, 22.177865244448185, 15.238610152155161, 8.707814142107964, 2.42387093603611, 0.17130187363363802, 0.13880321203032508, 0.01788772384315962, 0.08725574953132309, 0.03212947653082665, 0.04771653329953551, 0.01842413705162471, 0.023797742651368026, 0.01970030636584852, 0.014551325675711269, 0.015491379090235569, 0.041279867946286686, 0.021809026220580563, 0.02642406412633136, 0.10007744902395643, 0.08862348317052238, 0.06580029730685055, 0.044422855935408734, 0.0181208880894701, 0.041741112727322616, 0.06340818465105258, 0.052862800512230024, 0.020810524038097356, 0.021741286691394635, 0.055310960160568357, 0.05013560818042606, 0.025374131109856535, 0.02241494341433281, 0.07976267777848989, 0.059229010075796396, 0.09819363331189379, 0.015054983268782962, 0.024324125733983237, 0.04385021478810813, 0.03148273935948964, 0.04375453710963484, 0.05001498691854067, 0.062258137768367305, 0.057394116738578305, 0.0321785102278227, 0.03803044855885673, 0.04654148346162401, 0.08456907846266404, 0.018599005597934593, 0.08467136125545949, 0.015446777870238293, 0.03487317051622085, 0.017093312271754257, 0.0037885933852521703, 0.048246634542010725, 0.04498333699302748, 0.04034495112136938, 0.012642578440136276, 0.024650563100294676, 0.020583098448696546, 0.05279134653392248, 0.02134384063538164, 0.06935275043360889, 0.04667625376896467, 0.035786390653811395, 0.07469316347851418, 0.01316577863690327, 0.051039076497545466, 0.04974918672814965, 0.009618922231311444, 0.023678095458308235, 0.061382674393826164, 0.05535515505471267, 0.05462973909743596, 0.02921906463598134, 0.01931334685650654, 0.027854602012666874, 0.004786574208992533, 0.028115656168665737, 0.030476563370029908, 0.017411678782082163, 0.09758646003319882, 0.02402734273346141, 0.027254054257355165, 0.02998192750965245, 0.01462163860196597, 0.06440799857955426, 0.05914664281590376, 0.061950198432896286, 0.018861885437218007, 0.06305455870460719, 0.026876866977545433, 0.021504094438569155, 0.004186468959233025, 0.011101256459369324, 0.014263498542277375, 0.03460335901763756, 0.043316710798535496, 0.023985654443094973, 0.012203030346427113, 0.031070003205968533, 0.06043592773494311, 0.041803082058322616, 0.048016902728704736, 0.12848390091676265, 0.050028612749883905, 0.054066411903477274, 0.03975203821028117, 0.01623635249416111, 0.03220026999770198, 0.072884935507318, 0.033009615435730666, 0.02533378796215402, 0.006511067977044149, 0.027126176646561362, 0.05714846214686986, 0.040586260438431054, 0.016688999494363088, 0.05246023734798655, 0.04407979817187879, 0.013438222904369468, 0.15530703269178048, 0.11229510710109025, 0.11964930075919256, 0.8669516234658659, 2.465901905670762, 9.335302971303463, 15.194943845272064, 26.575564965605736, 36.4621252566576, 43.943885788321495, 45.49885354936123, 45.36403678357601, 38.204324170947075, 35.25552660226822, 36.100985035300255, 11.338338889181614, 53.403937965631485, 53.81569147109985, 23.011834993958473, 24.047017246484756, 22.558363527059555, 21.809528209269047, 28.776513263583183, 30.537507869303226, 29.626529552042484, 33.95975053310394, 33.13118599355221, 29.051639400422573, 31.831032559275627, 30.512032136321068, 28.036151491105556, 30.171963684260845, 27.1564169973135, 27.923213951289654, 32.60956898331642, 29.653276316821575, 25.891755558550358, 35.63240557909012, 34.793585389852524, 23.50453555583954, 33.15148450434208, 30.62177784740925, 21.212952621281147, 20.06208937615156, 21.545636169612408, 22.07427330315113, 20.835927352309227, 27.303757891058922, 28.944487050175667, 31.51331450790167, 36.93140387535095, 36.05129510164261, 40.706983879208565, 42.74877771735191, 38.84483300149441, 32.4444792419672, 32.27224588394165, 22.473588176071644, 13.194244801998138, 4.912357879802585, 0.549360984005034, 0.018006317186518572, 0.03897627866535913, 0.10460446821525693, 0.04114355026104022, 0.039730022399453446, 0.06044118956197053, 0.04532391598331742, 0.01630856717383722, 0.04708498418040108, 0.05586155581113417, 0.03940453127142973, 0.03741869622899685, 0.0636937037052121, 0.04738431089208461, 0.03642225907242391, 0.06744178695953451, 0.0582526368816616, 0.04389713336422574, 0.016953118720266502, 0.031187939748633653, 0.0075258918423060095, 0.008105829692794941, 0.033600951283006, 0.06748234533006325, 0.03543334729329217, 0.01865072215878172, 0.09573852716130204, 0.03736211117939092, 0.05391797865740955, 0.031535691596218385, 0.014320559494080953, 0.028502465393103193, 0.03654196007119026, 0.02179495324526215, 0.05057547539763618, 0.035993976780446246, 0.10591621423372999, 0.0929550280852709, 0.04678641074860934, 0.06512486128485762, 0.031684510759077966, 0.05083387266495265, 0.02112425398081541, 0.055876369078760035, 0.08934193407185376, 0.019899443141184747, 0.012473554306779988, 0.031041456495586317, 0.04601416898367461, 0.02839932727511041, 0.024347904145542998, 0.024340994750673417, 0.027958242935710587, 0.03118597305729054, 0.11066256032790989, 0.1000178323010914, 0.14375826489413157, 0.16468565678223968, 0.2558381640119478, 0.19676239258842543, 0.13839305669534951, 0.18416983861243352, 0.11986949597485363, 0.14675873826490715, 0.18536143092205748, 0.20026994578074664, 0.11860658327350393, 0.14735242672031745, 0.09179901433526538, 0.13259455299703404, 0.11340072902385145, 0.079562624450773, 0.07185458220192231, 0.09840804719715379, 0.14151807728921995, 0.1486487509100698, 0.12412036943715066, 0.08042928224313073, 0.1085349713684991, 0.07829039779608138, 0.15972233639331535, 0.1448715160950087, 0.17297519400017336, 0.1857861620374024, 0.210291997063905, 0.17102061450714245, 0.07839917438104749, 0.07423951086821035, 0.09857895638560876, 0.16353336861357093, 0.12019588510156609, 0.15569412207696587, 0.1370446931105107, 0.1960573671385646, 0.1534944705781527, 0.16306434612488374, 0.10501779252081178, 0.17062197730410844, 0.16628940822556615, 0.15231087862048298, 0.14525566657539457, 0.11547420799615793, 0.1557536274776794, 0.15563304332317784, 0.20642292889533564, 0.089314214856131, 0.1186595726176165, 0.12361698551103473, 0.12967770482646301, 0.18405951093882322, 0.09521831132587977, 0.09141935384832323, 0.08766217186348513, 0.10574370200629346, 0.08463435777230188, 0.19594640121795237, 0.15265149471815675, 0.1693555765086785, 0.5873116850852966, 1.8471901305019855, 8.280283883213997, 17.420834004878998, 29.693590253591537, 43.207473903894424, 52.56647050380707, 56.86720132827759, 57.85458594560623, 54.39219653606415, 50.35330966114998, 61.53197541832924, 23.483266197144985, 70.35458520054817, 65.91503262519836, 34.1880688816309, 36.99425250291824, 30.9586563706398, 26.475233249366283, 30.324132218956947, 26.727934889495373, 24.6001535654068, 27.51315325498581, 28.462277725338936, 24.657868668437004, 30.915270298719406, 30.145344212651253, 26.411715857684612, 28.934837467968464, 26.940710172057152, 29.660579524934292, 31.87009446322918, 28.033250346779823, 29.219588488340378, 46.91161014139652, 37.57674224674702, 23.599076382815838, 33.03939811885357, 31.00622221827507, 23.850826174020767, 29.529948234558105, 31.128569953143597, 38.31320732831955, 35.95501206815243, 44.28068071603775, 46.11621402204037, 44.60145190358162, 54.039195477962494, 48.09640176594257, 52.060489654541016, 52.81629949808121, 46.611471846699715, 36.28003142774105, 33.67056705057621, 22.47143179178238, 11.363162007182837, 3.6019255220890045, 0.7140016963239759, 0.21294823265634477, 0.09507249415037222, 0.2722325624199584, 0.12743683444568887, 0.19379933830350637, 0.27002214977983385, 0.1346373590058647, 0.16226389532675967, 0.16954696155153215, 0.18465340719558299, 0.14602606039261445, 0.1280429316102527, 0.1724155552801676, 0.2006379619706422, 0.09889164546621032, 0.1380927095306106, 0.20799680147320032, 0.09679756447440013, 0.09421850481885485, 0.2260882838163525, 0.13965335703687742, 0.10045478658867069, 0.19564514863304794, 0.20073568797670305, 0.12396015459671617, 0.1267308442038484, 0.15914694929961115, 0.25317287421785295, 0.16328788100508973, 0.12308732213568874, 0.06247688579605892, 0.15241676825098693, 0.13416063302429393, 0.11003056220943108, 0.17648552282480523, 0.1538876604172401, 0.25714891555253416, 0.18069584533805028, 0.1551885562366806, 0.14159193582599983, 0.1558575133094564, 0.25582519127056, 0.14829774474492297, 0.14768841181648895, 0.1261860632803291, 0.11680544281261973, 0.17826051742304116, 0.10296120482962579, 0.13204710034187883, 0.10047956689959392, 0.10390227034804411, 0.15705504280049354, 0.05299544456647709, 0.12141964209149592], [0.04974340168701019, 0.01698610718449345, 0.0680471865052823, 0.02994247308379272, 0.027234786248300225, 0.03094553576374892, 0.03546150437614415, 0.07214358192868531, 0.031655819329898804, 0.06450732762459666, 0.07531008857768029, 0.07946435667690821, 0.05277868920529727, 0.008858509372657863, 0.016560453950660303, 0.018812868438544683, 0.05356797068088781, 0.025664698623586446, 0.032161143972189166, 0.023582903886563145, 0.09344424441223964, 0.025947883623302914, 0.062074664019746706, 0.021710673099732958, 0.042196182839688845, 0.03712818623171188, 0.024883849800971802, 0.03732764584128745, 0.026093177584698424, 0.030760657500650268, 0.05572011730691884, 0.04890687509032432, 0.11082922443165444, 0.051171104569220915, 0.01667549426201731, 0.024595467912149616, 0.03669441575766541, 0.11807640781626105, 0.12200990182464011, 0.016550863547308836, 0.08973916861577891, 0.08241439369157888, 0.026274656811438035, 0.005994207112962613, 0.011234111098019639, 0.02913371950853616, 0.05719554770621471, 0.05361472227377817, 0.025096989047597162, 0.04156211041845381, 0.04949926107656211, 0.05691824422683567, 0.04391692273202352, 0.04742614575661719, 0.07238368154503405, 0.017517991436761804, 0.012268557347852038, 0.06324350950308144, 0.04816861997824162, 0.023919972518342547, 0.03662086521217134, 0.02053963457001373, 0.019889563300239388, 0.15555600839434192, 0.04774334709509276, 0.12071204138919711, 0.06559672619914636, 0.341993048787117, 2.2668996965512633, 3.8739310763776302, 9.145177323371172, 17.146184742450714, 26.965051665902138, 38.638811856508255, 41.8316513299942, 49.8067469894886, 44.63930167257786, 43.78128111362457, 69.63777646422386, 43.67524020373821, 42.532417327165604, 34.7024092823267, 31.953097209334373, 23.676438331604004, 22.349006161093712, 21.91755261272192, 18.457591272890568, 19.807854518294334, 21.421196646988392, 23.18858250975609, 23.168796971440315, 23.938436172902584, 20.14946758747101, 22.940548919141293, 17.709740102291107, 21.335663236677647, 23.652239330112934, 28.90977021306753, 81.94630399346352, 29.527295976877213, 21.138533614575863, 27.456878274679184, 29.368056021630764, 32.05762580037117, 28.686853274703026, 32.92843647301197, 39.95228357613087, 40.39632014930248, 40.39120562374592, 41.27796024084091, 39.83146145939827, 32.60175660252571, 30.8883810415864, 22.582433335483074, 14.417495112866163, 9.544741082936525, 4.3132977001369, 2.001255238428712, 1.1060602054931223, 0.10133020172361284, 0.06249077880056575, 0.04635560515453108, 0.08911382756195962, 0.04792332161741797, 0.04625279543688521, 0.0973157690896187, 0.025505055236862972, 0.021411713751149364, 0.043285874562570825, 0.12514720496255904, 0.052133666395093314, 0.05410845456935931, 0.05046757454692852, 0.00939537529120571, 0.04147476705838926, 0.09135716187302023, 0.05519487713172566, 0.02687837724806741, 0.027528981008799747, 0.015349881214206107, 0.03496493707643822, 0.053191145198070444, 0.0747805142600555, 0.04160931472142693, 0.01362151018838631, 0.03254514231230132, 0.11146002769237384, 0.018732634853222407, 0.019645367028715555, 0.019569252362998668, 0.10521961958147585, 0.06993259041337296, 0.02890998981456505, 0.12377998340525664, 0.05333868044544943, 0.02230018511909293, 0.05206079862546176, 0.020356574568722863, 0.04065597036969848, 0.024304302969540004, 0.06465760510764085, 0.12646754505112767, 0.022625652127317153, 0.05437234744022135, 0.08337455466971733, 0.054126065733726136, 0.03344115204527043, 0.03830824185570236, 0.014486738418781897, 0.019033449570997618, 0.029972715601616073, 0.002167283191738534, 0.04425038081535604, 0.052716864593094215, 0.03053963664569892, 0.03469323681201786, 0.013759003250015667, 0.04446532162546646, 0.032558894308749586, 0.040901728862081654, 0.0396474362059962, 0.011476819363451796, 0.05713436134101357, 0.0960437131288927, 0.002515981973374437, 0.03323248980450444, 0.04549062832666095, 0.02532745187636465, 0.03295220660220366, 0.0357614025415387, 0.04151828288740944, 0.040272662226925604, 0.058709365694085136, 0.047205338269122876, 0.056979141154442914, 0.019897365127690136, 0.02018772669543978, 0.03113388542260509, 0.03546351188560948, 0.051358823402551934, 0.04976002579496708, 0.04861895889916923, 0.052755033248104155, 0.055965189312701114, 0.036536078550852835, 0.07768686104100198, 0.07580743884318508, 0.10899263899773359, 0.033844910067273304, 0.005670957270922372, 0.037958256143610924, 0.025324112211819738, 0.03149796822981443, 0.08405873319134116, 0.09095444285776466, 0.038137150841066614, 0.034997535913134925, 0.06839794776169583, 0.06623224951908924, 0.020348299622128252, 0.05964759249764029, 0.030166714859660715, 0.0729569980467204, 0.0380658007634338, 0.022344036769936793, 0.09849414374912158, 0.05315872447681613, 0.10518104274524376, 0.03268929707701318, 0.07123079965822399, 0.038889113420736976, 0.01662306152866222, 0.013350713488762267, 0.0626488117268309, 0.019913785145035945, 0.08034479615162127, 0.05485838737513404, 0.057362167281098664, 0.027854718900925945, 0.048494545262656175, 0.09195923659717664, 0.057799589121714234, 0.3034633240895346, 1.185327514540404, 3.855603472329676, 7.393421921879053, 15.157740991562605, 26.182238571345806, 37.68061347305775, 47.828265354037285, 48.89748238027096, 58.24630692601204, 39.81052838265896, 47.618026435375214, 72.54495486617088, 43.17558601498604, 35.88957957923412, 31.294406354427338, 22.78276238590479, 19.900905825197697, 17.98796497285366, 15.319693051278591, 14.868335220962763, 18.736245520412922, 18.453918769955635, 22.188533172011375, 23.769368045032024, 23.975182101130486, 25.018324926495552, 22.054037488996983, 22.928324975073338, 21.995710618793964, 22.046983167529106, 25.726012252271175, 78.36774721741676, 31.209292821586132, 16.810742542147636, 20.779610574245453, 20.499763190746307, 19.578040950000286, 21.6384119912982, 26.776697672903538, 36.99991039931774, 39.968592301011086, 43.35668809711933, 46.12753361463547, 45.60975059866905, 39.56555552780628, 39.66431602835655, 30.679698139429092, 22.03255344182253, 14.831264410167933, 8.066779989749193, 5.254795979708433, 2.228366914205253, 0.504946889122948, 0.09521014770143665, 0.018533447982918005, 0.04862547495577019, 0.08840055685141124, 0.01318676842856803, 0.0349934689438669, 0.0890950883331243, 0.08625948306871578, 0.07585901810671203, 0.07173917823820375, 0.022581958182854578, 0.07252662660903297, 0.023976312659215182, 0.04223363161145244, 0.035339168753125705, 0.04974072995537426, 0.006805115699535236, 0.046429207650362514, 0.004915136451018043, 0.06757618990377523, 0.03218936784833204, 0.014928496257198276, 0.008187182065739762, 0.06900192980538122, 0.07786256450344808, 0.01858916657511145, 0.10355955397244543, 0.036932979128323495, 0.033622121045482345, 0.0523139785946114, 0.057433925539953634, 0.16229542176006362, 0.07032904570223764, 0.03846480532956775, 0.09667566671851091, 0.051286849920870736, 0.05660310234816279, 0.01865914553491166, 0.06200296884344425, 0.012068978994648205, 0.03699201326526236, 0.04476979884202592, 0.010728877368819667, 0.0723002567247022, 0.01782023478881456, 0.08375537290703505, 0.06421274694730528, 0.028668569175351877, 0.07564245199318975, 0.04520490147115197, 0.021211806997598615, 0.0362356237747008, 0.008267250523203984, 0.015786252915859222, 0.01910825249069603, 0.021155509530217387, 0.1046747421787586, 0.08622472829301842, 0.1361758608254604, 0.12090352291124873, 0.10933115481748246, 0.17280510859563947, 0.14670438336906955, 0.17740379698807374, 0.16261132434010506, 0.13527051487471908, 0.17034871852956712, 0.12859900802141055, 0.14349986391607672, 0.17600103397853673, 0.1781045031384565, 0.11956387214013375, 0.12458441953640431, 0.20085508469492197, 0.12252107830136083, 0.0818533448909875, 0.22001073259161785, 0.10602045629639179, 0.22982409194810316, 0.141147181566339, 0.1620295993052423, 0.19652051181765273, 0.13217822299338877, 0.12533682369394228, 0.18842546181986108, 0.15088399581145495, 0.22286568564595655, 0.25389302463736385, 0.13463551847962663, 0.17109056934714317, 0.11893660892383195, 0.11485368348076008, 0.1182532987149898, 0.18088017997797579, 0.1886995814857073, 0.18730967247392982, 0.2864018833497539, 0.17219283676240593, 0.12746619380777702, 0.10179264878388494, 0.174848300521262, 0.16545168677112088, 0.1589124751626514, 0.11198505264474079, 0.08117775301798247, 0.16904008953133598, 0.15696507965913042, 0.1709444701555185, 0.12618198146810755, 0.19796870910795406, 0.15108832390978932, 0.08663892833283171, 0.1018165607820265, 0.16668660566210747, 0.12262218107935041, 0.19185425830073655, 0.21841976093128324, 0.15205384319415316, 0.11155802087159827, 0.2536278701154515, 0.20974985818611458, 0.24298738717334345, 0.3054023184813559, 0.6747235008515418, 3.0831609712913632, 6.4564411249011755, 15.593473110347986, 26.806030198931694, 43.59648942947388, 56.59457355737686, 59.14080172777176, 70.71686536073685, 55.05129016935825, 57.32571892440319, 81.72096088528633, 52.64785833656788, 55.95265880227089, 46.71989522874355, 42.083893194794655, 35.11345982551575, 31.957368180155754, 31.46123830229044, 24.467935860157013, 31.827377155423164, 27.979107052087784, 31.89904510974884, 31.53380300849676, 36.22966893017292, 28.945267908275127, 32.04277239739895, 27.48779721558094, 29.309282675385475, 35.171186327934265, 35.63608378171921, 94.74271014332771, 36.221852749586105, 27.54137624055147, 35.4357623308897, 40.23250333964825, 40.91984085738659, 37.73966230452061, 42.20648221671581, 52.39129230380058, 53.58127824962139, 55.970628038048744, 56.440309435129166, 53.52552004158497, 44.197609573602676, 42.827456295490265, 32.20045633614063, 22.268822863698006, 14.227988831698895, 7.748701432719827, 4.677379438653588, 1.6182319913059473, 0.38628302689176053, 0.17839279782492667, 0.12942295521497726, 0.18703587935306132, 0.11457045024144463, 0.1471747862524353, 0.12812254921300337, 0.21167727507418022, 0.2444683131761849, 0.2323150067240931, 0.24658046546392143, 0.2121729258215055, 0.1813741386285983, 0.1467851735651493, 0.1037675111729186, 0.09177922125672922, 0.12732812465401366, 0.12893105973489583, 0.18714401026954874, 0.1290100094047375, 0.08250162572949193, 0.10863860487006605, 0.20609807601431385, 0.13909159577451646, 0.177781134552788, 0.2510755055118352, 0.13599151134258136, 0.23272897669812664, 0.11539045663084835, 0.12402717053191736, 0.16696075501386076, 0.14152281219139695, 0.2023794114938937, 0.14621903363149613, 0.22304209414869547, 0.2077090262901038, 0.18276593269547448, 0.12004473930574022, 0.1407087652478367, 0.16207062522880733, 0.11609894791035913, 0.18213017930975184, 0.32118447474204004, 0.08645047477330081, 0.2838248200714588, 0.14592484629247338, 0.20231730857631192, 0.24383201060118154, 0.14800933131482452, 0.13152805709978566, 0.07599946213304065, 0.13331836962606758, 0.08973976975539699, 0.2229104223079048, 0.07657907946850173, 0.20782419276656583, 0.1395781774772331], [0.06715752955642529, 0.02710023858526256, 0.024490507821610663, 0.05888369989406783, 0.024269576024380513, 0.014784775648877257, 0.020835783034272026, 0.0022847909121992416, 0.051140761861461215, 0.07473305391613394, 0.050790156456059776, 0.010690927647374338, 0.06451673805713654, 0.03514457763230894, 0.024140076820913237, 0.05759860810940154, 0.06162656638480257, 0.018702011984714773, 0.034092984060407616, 0.06044882626156323, 0.05719598557334393, 0.09330748885986395, 0.12446695982362144, 0.05087723635369912, 0.042729634878924116, 0.030135240376694128, 0.017589827621122822, 0.03283138867118396, 0.04751926302560605, 0.013878166191716446, 0.03356169538164977, 0.015468562687601661, 0.028088298749935348, 0.027565748860070016, 0.02966945179650793, 0.0959000778675545, 0.04875122074736282, 0.04217778499878477, 0.033403220877517015, 0.0808193179545924, 0.016907077733776532, 0.05714796861866489, 0.028139397472841665, 0.036717233087983914, 0.033397472943761386, 0.028350403044896666, 0.06003475238685496, 0.025961045612348244, 0.06445134000387043, 0.0527279559901217, 0.036269851625547744, 0.03045251221919898, 0.016558207098569255, 0.027836033477797173, 0.029809795632900205, 0.017130757332779467, 0.06759764539310709, 0.014347343603731133, 0.048271915802615695, 0.06644411783781834, 0.06266687560128048, 0.04631758863979485, 0.05219634447712451, 0.023375375276373234, 0.053041698920424096, 0.024719775792618748, 0.02751228825218277, 0.0319993965968024, 0.060956878296565264, 0.05814472489873879, 0.05354434069886338, 0.3600800782442093, 2.3775516590103507, 4.956261673942208, 16.33855327963829, 22.471471689641476, 41.319279223680496, 47.2207273542881, 51.49175137281418, 51.64231829345226, 45.96735320985317, 46.9010429084301, 41.417317762970924, 47.89086699485779, 43.77656936645508, 44.10975828766823, 39.40092176198959, 42.85236015915871, 33.50869573652744, 37.25453473627567, 28.118952848017216, 26.77008032798767, 28.198359087109566, 28.858592659235, 23.96054718643427, 28.332507088780403, 28.04059725254774, 46.916002705693245, 80.85487335920334, 44.05182659626007, 31.67302943766117, 46.017297729849815, 46.06451779603958, 49.77808892726898, 44.30515140295029, 44.9006250500679, 38.066513165831566, 31.42085786908865, 28.547847233712673, 22.98215288668871, 14.735853429883718, 10.29217142611742, 2.5456634256988764, 1.0954642365686595, 0.42783424258232117, 0.10625723851262592, 0.0474330254655797, 0.06177391238452401, 0.019420900753175374, 0.04224146869091783, 0.06953908887226135, 0.01676405103353318, 0.03845863808237482, 0.05076046312751714, 0.08416633718297817, 0.08825788638205267, 0.1035756734199822, 0.06450075219618157, 0.007478476491087349, 0.04550975347228814, 0.07467265051673166, 0.03255233743402641, 0.15268403047230095, 0.020191370640532114, 0.039881969714770094, 0.05908979059313424, 0.02259163578855805, 0.02059212110907538, 0.03298393341538031, 0.05373787054850254, 0.03491903524263762, 0.13389055064180866, 0.052198311168467626, 0.009938893635990098, 0.02842458627128508, 0.024195144178520422, 0.033913376901182346, 0.013320641664904542, 0.05249414607533254, 0.017103336831496563, 0.03532665614329744, 0.10879133886191994, 0.022180168707564007, 0.055370357949868776, 0.07001122095971368, 0.043470932796481065, 0.02363650179177057, 0.02506175558664836, 0.005964372312519117, 0.06428160340874456, 0.09349235784611665, 0.026681893650675192, 0.03612309563322924, 0.03746967064216733, 0.04318689061619807, 0.049758129607653245, 0.030507340234180447, 0.03332374428282492, 0.059724464153987356, 0.035838960684486665, 0.017754749533196446, 0.10512934473808855, 0.013788101932732388, 0.0824076624121517, 0.019554123682610225, 0.06954466982278973, 0.03978631801146548, 0.004554689703581971, 0.06100267622969113, 0.03859510048641823, 0.05169910553377122, 0.05202076346904505, 0.035305705314385705, 0.02908289352490101, 0.0353127000562381, 0.06928160073584877, 0.07510656942031346, 0.034934534996864386, 0.0051855810943379765, 0.0808607297949493, 0.04090614093001932, 0.05259842895611655, 0.05089829850476235, 0.01055061071383534, 0.03701377303514164, 0.04150732507696375, 0.02110717716277577, 0.08344346308149397, 0.044580005705938675, 0.029750097273790743, 0.025086892128456384, 0.025584318464098033, 0.0059661479008354945, 0.05679349662386812, 0.044682084408123046, 0.04336687627073843, 0.031411478339578025, 0.045707810422754847, 0.009187547966575949, 0.09978731381124817, 0.02553524580434896, 0.06340218809782527, 0.04366576140455436, 0.030223084686440416, 0.03912800704711117, 0.05087732170068193, 0.03934577172913123, 0.07073878543451428, 0.06165506856632419, 0.009495412159594707, 0.034960458215209655, 0.020958810709998943, 0.0410592756816186, 0.03294413574622013, 0.05506854875420686, 0.07178345476859249, 0.024393078674620483, 0.06688772919005714, 0.01044896338498802, 0.05578606826020405, 0.03354291162395384, 0.029543338641815353, 0.11384001365513541, 0.03483461965515744, 0.028245799185242504, 0.1101539665251039, 0.03789794922340661, 0.04073351366969291, 0.05321632626873907, 0.04722990335721988, 0.07424991577863693, 0.06808850928791799, 0.0006367224102632463, 0.03431496785196941, 0.03781095838348847, 0.036570217343978584, 0.21195537265157327, 1.2623371509835124, 5.254440698772669, 10.226339008659124, 24.416819103062153, 31.741146482527256, 50.29128558933735, 53.46909686923027, 59.26049530506134, 58.1391716748476, 49.60247755050659, 50.09420916438103, 43.2986918091774, 45.069438591599464, 40.947621166706085, 33.79231631755829, 30.392036475241184, 32.585869655013084, 26.05139449238777, 30.183041989803314, 24.326832331717014, 26.450745463371277, 22.237875424325466, 24.274531938135624, 18.960534185171127, 21.231970600783825, 22.72811371833086, 45.629296749830246, 88.0050940811634, 37.06766836345196, 26.533723510801792, 38.46401363611221, 41.70219227671623, 48.48510570824146, 43.555892407894135, 48.36125135421753, 45.177880972623825, 41.604317128658295, 39.37393940985203, 32.52044476568699, 23.750745244324207, 15.934013687074184, 6.861292300745845, 3.9666525134816766, 1.267922732513398, 0.35700259963050485, 0.18589301645988598, 0.10902719339355826, 0.018963435359182768, 0.039360503360512666, 0.06536764747579582, 0.05488124181283638, 0.010492146175238304, 0.0647994369501248, 0.0601752149668755, 0.025413858274987433, 0.08908978939871304, 0.024430905941699166, 0.02885294277803041, 0.06139471573987976, 0.024405936383118387, 0.04163612480624579, 0.08412389375735074, 0.061325799906626344, 0.015818619831406977, 0.0753369765880052, 0.011297435776214115, 0.07222263549920171, 0.018776558863464743, 0.030154916566971224, 0.08315829283674248, 0.06494132074294612, 0.04686486689024605, 0.021945162079646252, 0.04867231931712013, 0.03378920075192582, 0.019535764804459177, 0.021837778876943048, 0.05817579120048322, 0.04686503758421168, 0.08340343905729242, 0.09045868820976466, 0.027090017356385943, 0.022952469844312873, 0.05233461401076056, 0.018563414050731808, 0.07099456663127057, 0.004879912266915198, 0.04204326331091579, 0.03579301432182547, 0.13325963605893776, 0.029033069440629333, 0.046305317227961496, 0.02808243578328984, 0.067328097356949, 0.02137463234248571, 0.02201509279984748, 0.027510134168551303, 0.02280092885484919, 0.0715847076207865, 0.039076765460777096, 0.05115511128678918, 0.0608376893796958, 0.036630327595048584, 0.040438190844724886, 0.07854705472709611, 0.12405284142005257, 0.10551511310040951, 0.12200305180158466, 0.09784306501387618, 0.10815067988005467, 0.10318808679585345, 0.16163280262844637, 0.07480365442461334, 0.10527966674999334, 0.17593584372662008, 0.13705738383578137, 0.1271864041336812, 0.1453623577253893, 0.14013334846822545, 0.192491956113372, 0.1424035633681342, 0.11378223745850846, 0.09764100046595559, 0.13841460866387933, 0.2286673805792816, 0.17837031075032428, 0.20038757618749514, 0.2368505235062912, 0.12239817122463137, 0.10027418495155871, 0.13557719998061657, 0.20109888020670041, 0.25158916076179594, 0.20775719167431816, 0.23538536072010174, 0.13856085628503934, 0.1830511845764704, 0.11907667445484549, 0.11971754865953699, 0.1200730077107437, 0.11873375027789734, 0.23135480121709406, 0.12653157755266875, 0.1215390907600522, 0.1483312452910468, 0.08227186423027888, 0.16265793121419847, 0.1664037286536768, 0.15648992703063414, 0.15320191596401855, 0.05599545780569315, 0.15535583632299677, 0.1688105135690421, 0.13972273300169036, 0.2643039613030851, 0.1196822001656983, 0.23268495249794796, 0.061288814977160655, 0.17295996512984857, 0.1428540173219517, 0.12456455966457725, 0.17193094769027084, 0.1547085351194255, 0.1036637143988628, 0.2173095228499733, 0.20016076101455837, 0.14829329185886309, 0.10613095466396771, 0.18125499424058944, 0.1310818482306786, 0.11272306655882858, 0.14137083519017324, 0.11814843324827962, 0.19136265967972577, 0.1901111612096429, 0.20871479966444895, 1.067482300568372, 4.972122022882104, 10.074154324829578, 26.087190471589565, 36.5670870244503, 57.27065607905388, 62.31398865580559, 66.73766568303108, 66.87520310282707, 60.941768288612366, 64.39078241586685, 57.431265860795975, 64.40026670694351, 56.025090515613556, 60.2903388440609, 49.54327292740345, 57.466596364974976, 41.425806507468224, 49.796476140618324, 42.02121555805206, 39.24918070435524, 39.02500033378601, 38.282751962542534, 36.31747841835022, 39.451508447527885, 37.734771966934204, 56.32359869778156, 88.4149780869484, 53.1146252900362, 43.633146062493324, 58.71584013104439, 59.096404910087585, 61.26294605433941, 56.832984164357185, 56.824905797839165, 53.88824477791786, 45.369124710559845, 41.52564994990826, 33.063371032476425, 21.554630286991596, 15.168287325650454, 5.535666458308697, 2.8387459740042686, 0.885015141684562, 0.16027645353460684, 0.26419439062010497, 0.1446883985772729, 0.08407462999457493, 0.10980478604324162, 0.15207664197077975, 0.18212338123703375, 0.07121500675566494, 0.15322337887482718, 0.16942689690040424, 0.16539798496523872, 0.3310153784696013, 0.08085728622972965, 0.13635639566928148, 0.237880015920382, 0.19205287186196074, 0.15145148645387962, 0.35717359045520425, 0.14923592330887914, 0.16199847363168374, 0.1816097111441195, 0.11294834548607469, 0.21554092556471005, 0.1704248777241446, 0.09461012130486779, 0.19891885109245777, 0.24384611140703782, 0.1813074343954213, 0.21980870515108109, 0.22019592812284827, 0.15532901510596275, 0.19099341152468696, 0.12211239984026179, 0.16522260062629357, 0.19490004720864818, 0.1550435257377103, 0.24102687049889937, 0.1958266631118022, 0.17480099602835253, 0.16852656786795706, 0.13806750619551167, 0.2063766634091735, 0.1296399740385823, 0.11816409256425686, 0.14772661757888272, 0.22403723996831104, 0.09738003165693954, 0.16048964287620038, 0.10313855585991405, 0.21373290539486334, 0.2203545399243012, 0.18509185319999233, 0.10752872301964089, 0.12781242054188624, 0.2084092129371129, 0.10617120875394903, 0.14643991162301973, 0.09197574196150526, 0.21054533659480512, 0.11932429202715866, 0.25298116263002157], [0.04755471170938108, 0.00923513354791794, 0.09214740814059041, 0.04138963529840112, 0.027796007598226424, 0.007748533362246235, 0.06914169105584733, 0.014440235445363214, 0.03458523948211223, 0.04271907040674705, 0.02065689019218553, 0.02940110418421682, 0.019247045238444116, 0.018547496838436928, 0.04191460458969232, 0.023236150227603503, 0.05092542400234379, 0.01383936578349676, 0.040507192024961114, 0.041525092092342675, 0.014661010463896673, 0.05388095662056003, 0.01926347267726669, 0.054382926755351946, 0.011158508514199639, 0.01655223280977225, 0.04931649978971109, 0.020642896997742355, 0.016590258601354435, 0.037213882023934275, 0.012929667136631906, 0.06543084135046229, 0.005922541622567223, 0.02048100304818945, 0.026682999450713396, 0.0375979323143838, 0.014134472457953962, 0.015802539346623234, 0.026960276954923756, 0.025521425159240607, 0.1338044911972247, 0.03327183847432025, 0.04463202283659484, 0.1083405880490318, 0.01253767679372686, 0.07419315632432699, 0.01776031007466372, 0.08460970362648368, 0.032848550836206414, 0.0355016842513578, 0.0401030666398583, 0.0208627452593646, 0.019589574221754447, 0.0439455213927431, 0.023111398913897574, 0.03524366176861804, 0.05694378152838908, 0.013513073135982268, 0.014682290620839922, 0.019742495605896693, 0.07389017453533597, 0.026956221117870882, 0.039185234054457396, 0.04634314820577856, 0.0092407636657299, 0.014630719706474338, 0.016257171591860242, 0.016667731397319585, 0.06229044345673174, 0.04148939849983435, 0.015223832997435238, 0.08196981012588367, 0.0728776773030404, 0.06010239172610454, 0.21563479240285233, 1.3164315233007073, 4.082528008148074, 15.958146192133427, 22.875502109527588, 30.24487417191267, 31.55627880245447, 36.69270068407059, 40.48498459160328, 42.53751665353775, 43.83127883076668, 47.5704225897789, 46.00255452096462, 46.6555380821228, 55.172157883644104, 43.03039960563183, 40.70883058011532, 45.17551749944687, 56.50435499846935, 50.05883686244488, 48.185560181736946, 46.77872747182846, 43.259166330099106, 47.0890986174345, 56.89031548798084, 49.549022018909454, 53.31416018307209, 48.803315833210945, 43.95619712769985, 30.586447343230247, 30.296405106782913, 19.03134148567915, 13.409708440303802, 5.3225890919566154, 2.3227892350405455, 0.8050227840431035, 0.05438722379039973, 0.1582795419381, 0.034604182801558636, 0.04341113795817364, 0.03839856122795027, 0.05211018484260421, 0.036169246086501516, 0.0833324006816838, 0.05840993508172687, 0.02954395276901778, 0.03139096166705713, 0.04143926271353848, 0.031636378771509044, 0.03661252347228583, 0.021707763880840503, 0.028735731684719212, 0.09901350611471571, 0.011060362267016899, 0.04211819796182681, 0.04603910885634832, 0.0356553459278075, 0.019691031375259627, 0.03306404825707432, 0.036530479046632536, 0.049559345352463424, 0.08609031050582416, 0.021484514727490023, 0.023274480299733113, 0.011727995533874491, 0.06479044954176061, 0.024170946453523356, 0.04341796571679879, 0.0473408247489715, 0.01044400583850802, 0.043963759671896696, 0.05584738821198698, 0.056295463582500815, 0.032374144066125154, 0.051692596898647025, 0.01944981668202672, 0.04615043471858371, 0.023969555404619314, 0.011192625042895088, 0.023542839044239372, 0.05029394167650025, 0.029617751933983527, 0.03704200433276128, 0.0206514298406546, 0.04479628609260544, 0.010496522991161328, 0.0659188257122878, 0.06687906090519391, 0.020841015175392386, 0.047719279245939106, 0.01559684384119464, 0.011731931699614506, 0.015024411422928097, 0.08251701045082882, 0.04740792232041713, 0.08107844623737037, 0.019796368105744477, 0.021854989281564485, 0.060427433854783885, 0.054232511974987574, 0.041115500789601356, 0.022364328942785505, 0.019839260530716274, 0.03470545998425223, 0.023192040680442005, 0.034916975782834925, 0.015724059085187037, 0.02146484039258212, 0.07568701796117239, 0.016793872382550035, 0.03113316182862036, 0.033102751258411445, 0.03641085226263385, 0.04798135385499336, 0.05302238081640098, 0.020129894837737083, 0.04750558153318707, 0.03230849368264899, 0.05828510955325328, 0.0287870586180361, 0.010684499720809981, 0.018949739023810253, 0.04465758982405532, 0.03449407406151295, 0.07140396497561596, 0.038592614291701466, 0.03512330767989624, 0.09623196630855091, 0.031009379017632455, 0.02450392956234282, 0.04781753959832713, 0.03832814625639003, 0.009468482403462986, 0.05780407911515795, 0.013341929243324557, 0.04089575457328465, 0.03542755111993756, 0.07175751670729369, 0.05527769710170105, 0.045391948660835624, 0.007852083836041857, 0.04614048251823988, 0.06346679205307737, 0.03842472564429045, 0.030055550414544996, 0.027863799077749718, 0.057672047332744114, 0.00994432430161396, 0.0206328835702152, 0.013012930539844092, 0.00929604068005574, 0.09240856248652562, 0.11024073100998066, 0.0732954619161319, 0.08289220320875756, 0.04056819656398147, 0.034497306114644744, 0.08758875119383447, 0.03029747571417829, 0.047095949412323534, 0.029617533000418916, 0.06983149505686015, 0.07651495790923946, 0.09199375388561748, 0.03618100912717637, 0.014502300327876583, 0.04896432474197354, 0.036599435698008165, 0.016978830426523928, 0.07589798828121275, 0.020254753762856126, 0.004848119588132249, 0.05096631633932702, 0.11063565747463144, 0.10950224954285659, 0.2015275595476851, 0.6373561278451234, 3.1088416557759047, 8.749155923724174, 24.58299368619919, 31.99397921562195, 40.3956513851881, 41.56878903508186, 43.94401118159294, 48.848309218883514, 50.721190720796585, 51.50372453033924, 55.70582404732704, 53.48171219229698, 53.13016265630722, 52.786224111914635, 48.36375541985035, 44.3395471572876, 46.1778999119997, 55.13913005590439, 50.49962840974331, 47.69275702536106, 46.344106793403625, 45.62364265322685, 50.87985880672932, 64.61970493197441, 56.268634647130966, 55.43398663401604, 55.98798930644989, 55.13829790055752, 42.95477606356144, 39.65727120637894, 27.11799345910549, 18.967829793691635, 10.365196857601404, 5.500233359634876, 2.384212464094162, 0.8799324987921864, 0.25555831496603787, 0.10211670014541596, 0.008247629994002637, 0.029587216267827898, 0.046030058365431614, 0.09226854148437269, 0.025100976235989947, 0.04055591401993297, 0.011649123789538862, 0.04083521016582381, 0.029967611480969936, 0.034029189046123065, 0.07725791452685371, 0.05301538978528697, 0.01706944665784249, 0.04676853241107892, 0.0512894919665996, 0.032013048403314315, 0.018844437545340043, 0.04456423506780993, 0.00907599389392999, 0.04475872599869035, 0.023184224010037724, 0.012092754623154178, 0.08569867175538093, 0.016060066445788834, 0.025560220929037314, 0.1130145376373548, 0.014278858216130175, 0.04601298525813036, 0.026855352116399445, 0.04452389192010742, 0.04004852620710153, 0.02155031168513233, 0.012213566988066304, 0.03490290095214732, 0.01607043610420078, 0.01382284186547622, 0.010073473767988617, 0.046753604110563174, 0.03683686729345936, 0.027175733557669446, 0.022009268795954995, 0.08014947030460462, 0.0170594406517921, 0.032268154245684855, 0.0658469412883278, 0.10562999756075442, 0.03398806293262169, 0.02636425258970121, 0.07640805895789526, 0.053017608806840144, 0.06854589490103535, 0.0705644252593629, 0.0054671254838467576, 0.10856301712919958, 0.08747006693738513, 0.054107805190142244, 0.04843430513574276, 0.024320485499629285, 0.07921475014882162, 0.0921812055457849, 0.012011614689981798, 0.021286068149493076, 0.02977754375024233, 0.13158584071788937, 0.10772447189083323, 0.1956800147308968, 0.16654967941576615, 0.09049323518411256, 0.1154925390437711, 0.172456061700359, 0.1719048389350064, 0.11226778122363612, 0.1431010485976003, 0.136284971376881, 0.13424691511318088, 0.14278971764724702, 0.07853380739106797, 0.15324653388233855, 0.11075716189225204, 0.20188110385788605, 0.0644747176556848, 0.127248507051263, 0.12969456642167643, 0.21257338870782405, 0.13076922594336793, 0.14227120875148103, 0.13860504375770688, 0.0890699443698395, 0.11644434343907051, 0.12222952558659017, 0.19408583699259907, 0.09969902050215751, 0.19705775252077729, 0.08659126018756069, 0.19348245608853176, 0.07021062119747512, 0.12923036789288744, 0.10800610951264389, 0.16830089560244232, 0.1041814440395683, 0.1397519142483361, 0.11200558044947684, 0.09783559158677235, 0.274020693032071, 0.10724980165832676, 0.10309216420864686, 0.17177214293042198, 0.13366021768888459, 0.16866193560417742, 0.13945803861133754, 0.18463109823642299, 0.10896644860622473, 0.17108809057390317, 0.1304476533550769, 0.19944867031881586, 0.17507706012111157, 0.1376477029407397, 0.08481119672069326, 0.22924149117898196, 0.17150856176158413, 0.090336708817631, 0.08420083220698871, 0.15950591128785163, 0.18140850006602705, 0.1518614636734128, 0.23771395295625553, 0.15901566337561235, 0.12018989596981555, 0.08337353050592355, 0.18958344968268648, 0.2286909066606313, 0.18843968136934564, 0.21117773547302932, 0.062385816854657605, 0.17165892088087276, 0.19574064819607884, 0.2562002727063373, 0.4523151711327955, 3.0182929895818233, 8.62999051809311, 23.46734505146742, 31.810036785900593, 41.82863429188728, 44.591131657361984, 50.50143711268902, 55.785619765520096, 57.4767380207777, 61.80055260658264, 65.23749858140945, 65.5239500105381, 65.18862560391426, 72.18933194875717, 61.29087455570698, 58.03169444203377, 60.015784576535225, 71.95035517215729, 67.18406572937965, 61.94460287690163, 62.662087976932526, 60.168817564845085, 60.234322249889374, 70.27217522263527, 63.42596098780632, 68.89719620347023, 64.08115223050117, 60.97150929272175, 48.0525217205286, 39.8446087539196, 25.22706862539053, 17.94978842139244, 8.974432535469532, 4.7410473972558975, 1.7415521177463233, 0.6202186911832541, 0.26640572352334857, 0.2307557247695513, 0.09092022984987125, 0.11489913260447793, 0.16124489688081667, 0.24391594750341028, 0.19500161753967404, 0.21294002450304106, 0.10761165802250616, 0.09777178915101103, 0.12570282124215737, 0.1183612589375116, 0.22605144360568374, 0.12090710748452693, 0.08654143239255063, 0.15982007724232972, 0.11615674637141638, 0.12944854446686804, 0.11863037652801722, 0.1774109958205372, 0.13080268196063116, 0.1273280059103854, 0.14892244013026357, 0.11335312025039457, 0.12162030398030765, 0.0803991881548427, 0.2100306868669577, 0.15180231450358406, 0.1303814834682271, 0.1214275236998219, 0.11747028838726692, 0.19754776294576004, 0.07166739771491848, 0.10140566329937428, 0.1777580686029978, 0.0950995009043254, 0.11957007649471052, 0.14227537962142378, 0.11829389419290237, 0.1166952116182074, 0.08484034828143194, 0.14768504246603698, 0.10107183785294183, 0.24831557704601437, 0.14024159812834114, 0.09943187702447176, 0.14662475092336535, 0.18251036672154441, 0.15336073556682095, 0.13621050427900627, 0.13347989064641297, 0.12801720877178013, 0.13753563864156604, 0.11532312157214619, 0.1303211023332551, 0.11475670704385266, 0.23438856733264402, 0.34866189875174314, 0.19763431220781058, 0.11894775598193519, 0.14640816254541278, 0.139478521887213, 0.15304927102988586, 0.18103095469996333, 0.12215137743623927], [0.05363935786590446, 0.07161198896938004, 0.08642705259262584, 0.07907885548775084, 0.047907847838359885, 0.05795072749606334, 0.010735784908320056, 0.0925742692197673, 0.06774809357011691, 0.021257616062939633, 0.0499934683466563, 0.002799391240841942, 0.08715292497072369, 0.05072897380159702, 0.03496908939268906, 0.029157824465073645, 0.06422709266189486, 0.04232031074934639, 0.028918890020577237, 0.06215216279088054, 0.02280379725561943, 0.04031649346870836, 0.04887623181275558, 0.0797138518828433, 0.02640817288920516, 0.08719911624211818, 0.03677395543491002, 0.012774831939168507, 0.02332543986995006, 0.04174643392616417, 0.042689273177529685, 0.013342098081920994, 0.06069121911423281, 0.047247956099454314, 0.010600365221762331, 0.06093528550991323, 0.012799266223737504, 0.03654481733974535, 0.06548628720338456, 0.0453370000468567, 0.046076605867710896, 0.02553726630139863, 0.011971175063081319, 0.02282811372424476, 0.03045803194254404, 0.10951214979286306, 0.016715332749299705, 0.03360341150255408, 0.034208840734208934, 0.04189069259155076, 0.018632320607139263, 0.07112308434443548, 0.03636655346781481, 0.09739552770042792, 0.034279118408448994, 0.01903845350170741, 0.04340223218605388, 0.024951849081844557, 0.0579625090904301, 0.032593170399195515, 0.023630828072782606, 0.04186819067399483, 0.056073899104376324, 0.038489240541821346, 0.029406341891444754, 0.06243945928872563, 0.01603453842108138, 0.044322547255433165, 0.053013742217444815, 0.022501932398881763, 0.01821569003368495, 0.08566546806832775, 0.024988256991491653, 0.06808983773225918, 0.034454732813173905, 0.03960125977755524, 0.024065995639830362, 0.04752780885610264, 0.9146925585810095, 2.9126244597136974, 5.254973145201802, 7.2424393985420465, 7.648851815611124, 9.548265393823385, 12.463910691440105, 19.50616590678692, 21.32740058004856, 20.59916965663433, 29.496359936892986, 23.11874035745859, 27.80373316258192, 28.36896613240242, 28.550499491393566, 35.6474831700325, 31.953101009130478, 33.847143575549126, 36.36987380683422, 39.217087626457214, 33.43275301158428, 27.720449231565, 26.85751363635063, 19.810901954770088, 9.443674106150866, 3.786498480476439, 1.3448680099099874, 0.657681830925867, 0.10591861137072556, 0.07791192474542186, 0.04895828737062402, 0.05722545254684519, 0.03454267731285654, 0.1117589499335736, 0.03610720996221062, 0.06418660850613378, 0.006485895255536889, 0.06869960110634565, 0.025155945259029977, 0.024768529328866862, 0.0568277393176686, 0.11569687456358224, 0.038396906238631345, 0.0409006119298283, 0.05006886312912684, 0.009110534374485724, 0.04498737427638844, 0.07401681461487897, 0.01217418863234343, 0.02490387108991854, 0.06749365566065535, 0.04796976150828414, 0.028593597417057026, 0.03273773705586791, 0.018650326965143904, 0.010084911191370338, 0.04914310440653935, 0.011971637977694627, 0.036603257758542895, 0.026614373055053875, 0.04735815760795958, 0.03567087165720295, 0.024141050889738835, 0.026297481563233305, 0.08544049342162907, 0.04798524270881899, 0.04322259163018316, 0.00730717303667916, 0.023412113441736437, 0.06080129816837143, 0.03533529845299199, 0.021978903823764995, 0.024645969206176233, 0.07244424079544842, 0.02546412022638833, 0.03859595024550799, 0.06469892789027654, 0.041011414577951655, 0.03791307048231829, 0.013462814895319752, 0.045388208236545324, 0.08075094388914295, 0.027428932080511004, 0.010811444080900401, 0.0339969575725263, 0.10263877135002986, 0.021872956676816102, 0.0472521418123506, 0.043922893310082145, 0.0325913150300039, 0.04976512434950564, 0.019760490831686184, 0.014146154790068977, 0.024830891998135485, 0.031879988746368326, 0.10466565829119645, 0.043918967348872684, 0.06790033774450421, 0.03309697734948713, 0.03815302909060847, 0.03620693605626002, 0.009336021103081293, 0.0392825259041274, 0.025576102889317553, 0.04359666374512017, 0.016281352618534584, 0.051175004555261694, 0.04350183211499825, 0.07242414343636483, 0.03824842475296464, 0.05869900902325753, 0.08761068165767938, 0.11729664067388512, 0.04778449176228605, 0.030891867354512215, 0.01848217856604606, 0.02563476224167971, 0.07707593991653994, 0.06281673006014898, 0.022562892409041524, 0.04269453500455711, 0.050117562859668396, 0.033121984015451744, 0.07867957261623815, 0.04258211447449867, 0.021620140360028017, 0.09148206532699987, 0.053705754107795656, 0.048627115102135576, 0.042025859947898425, 0.04644541615562048, 0.023024037000141107, 0.06365237350109965, 0.03311167187348474, 0.042973181771230884, 0.038330083261826076, 0.10058883330202661, 0.04236645749188028, 0.03666463708213996, 0.027879771951120347, 0.017940588877536356, 0.09083704993827268, 0.05373579253500793, 0.039283750447793864, 0.03115151142992545, 0.05792762814962771, 0.03628251637564972, 0.014395235320989741, 0.032110581450979225, 0.09121958253672346, 0.01215494288771879, 0.02545668390666833, 0.05744923233578447, 0.029631004836119246, 0.10835879293153994, 0.014507179021165939, 0.01221078393427888, 0.04317455241107382, 0.03111888661806006, 0.04563490554573946, 0.017728262282616924, 0.07155400497140363, 0.00887924126800499, 0.00575160645894357, 0.028307473512541037, 0.03182096203090623, 0.007407651019093464, 0.06564232375239953, 0.036371425667311996, 0.03840126264549326, 0.0645875018381048, 0.057871955941664055, 0.03200089944584761, 0.02244090002932353, 0.0826738188334275, 0.35403204965405166, 2.2579283779487014, 5.90274908579886, 9.689414519816637, 12.600413616746664, 14.857863932847977, 17.4439462646842, 20.95032211393118, 27.15565513819456, 31.264530457556248, 30.081762224435806, 41.269061118364334, 32.31476940214634, 36.75945170223713, 39.717665165662766, 40.963116735219955, 45.86372137069702, 42.41683892905712, 44.2267844080925, 46.38724207878113, 47.53055512905121, 43.621260300278664, 36.333733946084976, 36.1697955429554, 27.067868448793888, 15.980574488639832, 7.350423904135823, 3.6218165047466755, 1.2696877378039062, 0.64781678840518, 0.034461341638234444, 0.07646421727258712, 0.1131199522933457, 0.02395722647634102, 0.06263554212637246, 0.05953840402071364, 0.031619647052139044, 0.06192392640514299, 0.07996963307959959, 0.0401452280493686, 0.04678307108406443, 0.02003518195124343, 0.024134152627084404, 0.041371823754161596, 0.029657031955139246, 0.06611666001845151, 0.06330782402073964, 0.07040295618935488, 0.07820605271263048, 0.02910165687353583, 0.0371411070227623, 0.06076738573028706, 0.02945279105915688, 0.044286363845458254, 0.0311108658570447, 0.012108380542485975, 0.014144665856292704, 0.013269071678223554, 0.006526853458126425, 0.0349395110970363, 0.04711073299404234, 0.02104425602738047, 0.021698451782867778, 0.06477288290625438, 0.030684865669172723, 0.0318729123682715, 0.046608781412942335, 0.029702690735575743, 0.01783184939995408, 0.011545076540642185, 0.005700442334273248, 0.04077650257386267, 0.05326745282218326, 0.027662524917104747, 0.02077030705549987, 0.007466325678251451, 0.048366432019975036, 0.038362971536116675, 0.029060380475129932, 0.02210086095146835, 0.09703171206638217, 0.017762265633791685, 0.02034418997936882, 0.06421523314202204, 0.044944155306438915, 0.021384484352893196, 0.057748900435399264, 0.026302511469111778, 0.02629292106576031, 0.11679304152494296, 0.0255616848153295, 0.02484960339643294, 0.021853861217095982, 0.03470852505415678, 0.05558981101785321, 0.047036633259267546, 0.05673763145750854, 0.030745447184017394, 0.045866759901400656, 0.173109567258507, 0.16559788986342028, 0.18340385315241292, 0.1720679778372869, 0.09569158632075414, 0.12517340277554467, 0.1598144369199872, 0.10546031291596591, 0.20452398079214618, 0.21941753395367414, 0.1178132496715989, 0.09684024538728409, 0.20307962782680988, 0.16503234364790842, 0.09245105786249042, 0.10632387595251203, 0.14139277307549492, 0.07605417325976305, 0.17291209660470486, 0.16551426466321573, 0.151204009889625, 0.16582660493440926, 0.18943007744383067, 0.11959646726609208, 0.1022280594042968, 0.22772206255467609, 0.12248404513229616, 0.1247706392314285, 0.14134405850199983, 0.18874163157306612, 0.1600164792034775, 0.11124861950520426, 0.11167931006639265, 0.09798900835448876, 0.10852662962861359, 0.09351330867502838, 0.10848535879631527, 0.15660639968700707, 0.20543674821965396, 0.1929578764247708, 0.13875506148906425, 0.19846305367536843, 0.1376158944913186, 0.1434708756278269, 0.14107657363638282, 0.16614452615613118, 0.11078413153882138, 0.1620712931617163, 0.14142637752229348, 0.20642799034249038, 0.17410671687684953, 0.21391465736087412, 0.14093618898186833, 0.18419345375150442, 0.11671174666844308, 0.1560680754482746, 0.12101557978894562, 0.09829564893152565, 0.11938073235796764, 0.093967762804823, 0.10572421320830472, 0.08991061957203783, 0.10696046796510927, 0.10046535477158614, 0.09688635502243415, 0.10644158799550496, 0.09821104409638792, 0.11658622723189183, 0.2306937109096907, 0.1199450837157201, 0.07412033679429442, 0.23335442907409742, 0.1001221856859047, 0.1730385288828984, 0.11642583427601494, 0.18497900222428143, 0.14884501928463578, 0.23366072826320305, 1.5978237614035606, 4.1961851343512535, 7.980270031839609, 10.134466588497162, 11.984367873519659, 15.014111548662186, 18.03733952343464, 25.857992470264435, 30.87533064186573, 30.485146678984165, 39.462725445628166, 33.32555316388607, 36.95552118122578, 42.75763884186745, 41.567470505833626, 47.72146828472614, 44.949824810028076, 48.624204844236374, 49.90726299583912, 54.50178645551205, 47.90489964187145, 41.62878021597862, 37.47542828321457, 26.01581510156393, 16.714632399380207, 6.854254603385925, 2.9169011302292347, 0.8708199940156192, 0.3627481881994754, 0.2098202137858607, 0.15624764550011605, 0.21603948553092778, 0.12876559048891068, 0.18457849480910227, 0.09678252856247127, 0.09164086266537197, 0.09965419478248805, 0.10914673854131252, 0.1445046576554887, 0.07829943715478294, 0.21270031080348417, 0.20199523132760078, 0.11386514277546667, 0.14530068525345996, 0.12374436773825437, 0.1520325435558334, 0.19746456819120795, 0.1588566805003211, 0.18525708495872095, 0.08276128835859708, 0.12426914036041126, 0.11386275305994786, 0.2141001497511752, 0.15328564506489784, 0.10904179885983467, 0.09854135918430984, 0.13307693414390087, 0.1260281787835993, 0.11703490003128536, 0.10483596634003334, 0.12222313569509424, 0.11403965138015337, 0.11437505760113709, 0.22517044009873644, 0.14024039584910497, 0.14367469906574115, 0.126576982147526, 0.06752649569534697, 0.11505528789712116, 0.13790203694952652, 0.1306093079620041, 0.2510580501984805, 0.08440723089734092, 0.16239179705735296, 0.1335192986880429, 0.10192245783400722, 0.15948173211654648, 0.22210349998204038, 0.14154807489831, 0.20629055943572894, 0.1811900266329758, 0.15389625448733568, 0.109531727648573, 0.12484935141401365, 0.1807368712616153, 0.19887723145075142, 0.12500692420871928, 0.1517093085567467, 0.24370027938857675, 0.04923880063870456, 0.11124176948214881, 0.11215448495931923, 0.14185618492774665, 0.15495853498578072, 0.09632746587158181, 0.22350188432028517, 0.14097754145041108, 0.19720370328286663], [0.06242647170438431, 0.012755420139001217, 0.02046277961198939, 0.04773661581566557, 0.010593067127047107, 0.02299582240084419, 0.015593415118928533, 0.04141450466704555, 0.020161463944532443, 0.04159393742156681, 0.015347195567301242, 0.05415886495029554, 0.006410067708202405, 0.04218888752802741, 0.04826850192330312, 0.059586869974737056, 0.018460908613633364, 0.0590750144328922, 0.060141057620057836, 0.019111712754238397, 0.04467140119231772, 0.04130999543122016, 0.06446727391448803, 0.013777631156699499, 0.04251130245393142, 0.036502065922832116, 0.04529256395471748, 0.02036353591392981, 0.02071834373055026, 0.03887804057740141, 0.02427948926197132, 0.049992841231869534, 0.012379817344481125, 0.019457223315839656, 0.03001988836331293, 0.04067852052685339, 0.0510279591253493, 0.05240837977908086, 0.030011025264684577, 0.017555356716911774, 0.04335969228122849, 0.05497114187164698, 0.036466223900788464, 0.055484140320913866, 0.08017648448003456, 0.06797796639148146, 0.031603145398548804, 0.06869014614494517, 0.004969407855242025, 0.05159448126505595, 0.019617679354269058, 0.039915422021294944, 0.009732875296322163, 0.030149962731229607, 0.010274044743709965, 0.017942069462151267, 0.0372799628530629, 0.034337495744694024, 0.013621675316244364, 0.03248048640671186, 0.03449528376222588, 0.00556618967493705, 0.04986281324818265, 0.03220621460059192, 0.020894353328912985, 0.004543049581116065, 0.02148946856323164, 0.051507126772776246, 0.05214068711211439, 0.022054595465306193, 0.014151005652820459, 0.012540968218672788, 0.01280127002246445, 0.02228815676062368, 0.06131825226475485, 0.04761179028719198, 0.041068129503400996, 0.051741689967457205, 0.004528585122898221, 0.08170057379174978, 0.06556266162078828, 0.0464595318044303, 0.020041521747771185, 0.15127816528547555, 0.3186211857246235, 0.5609454936347902, 0.870975429425016, 1.3745085569098592, 1.2103054742328823, 1.6782859875820577, 1.6392984171397984, 1.7156386957503855, 1.3318812567740679, 2.2465498885139823, 2.5440584868192673, 1.9712358992546797, 2.8626566659659147, 4.249546620994806, 3.929398600012064, 2.055833372287452, 1.2739266478456557, 0.4902501980541274, 0.13568148657213897, 0.020099839712202083, 0.051402224198682234, 0.017146531681646593, 0.036858281964669004, 0.02084400417516008, 0.05646784964483231, 0.029113746459188405, 0.04703986531239934, 0.016624284216959495, 0.032569896648055874, 0.038362637569662184, 0.032979146562865935, 0.08261259165010415, 0.03342437579703983, 0.015433354274136946, 0.015943322905513924, 0.10620807865052484, 0.05001371413527522, 0.053953182432451285, 0.013781587731500622, 0.07246384091558866, 0.04086020198883489, 0.04569962453388143, 0.04503491996729281, 0.016849813619046472, 0.08296318221255206, 0.029519513846025802, 0.005070364059065469, 0.003332434171170462, 0.047499803913524374, 0.03136487888696138, 0.04205320437904447, 0.07424459457979538, 0.04921340063447133, 0.05381417817261536, 0.028440028509066906, 0.057402413949603215, 0.0031785227156433393, 0.04287888448743615, 0.05243632534984499, 0.02168718412576709, 0.013112883916619467, 0.04330191979533993, 0.03051380434044404, 0.03393431288714055, 0.03081383980315877, 0.03866521488816943, 0.03055834062251961, 0.03655626867839601, 0.04417625881615095, 0.03312952052510809, 0.03231968526961282, 0.04158455296419561, 0.03945679702155758, 0.018784147323458456, 0.03202477062586695, 0.023977485252544284, 0.039421392866643146, 0.044919308202224784, 0.0426677583163837, 0.024456487772113178, 0.06518142778077163, 0.059677367462427355, 0.02727043716731714, 0.03861712742946111, 0.032920873127295636, 0.01871302545623621, 0.028475579238147475, 0.03998089428932872, 0.015470354974240763, 0.06176382288686, 0.061358116727205925, 0.03886015110765584, 0.00681811951835698, 0.05071921455964912, 0.057409356741118245, 0.020655133157561067, 0.05775945377536118, 0.013015590211580275, 0.015501188427151646, 0.0630716874729842, 0.02287134382640943, 0.05511633564310614, 0.05172686556761619, 0.05993639184453059, 0.04313423894927837, 0.023070868373906706, 0.04277536972949747, 0.02609430935990531, 0.06366866364260204, 0.04985427483916283, 0.04294883932743687, 0.04631169969798066, 0.026999840847565793, 0.0799954375543166, 0.004854423668803065, 0.017807442018238362, 0.06875818624394014, 0.012191215355414897, 0.011632595233095344, 0.029144642066967208, 0.03728833427885547, 0.04029920142784249, 0.008206346174119972, 0.042572151141939685, 0.043765754671767354, 0.05155311766429804, 0.011980692179349717, 0.017990748783631716, 0.004206509729556274, 0.021511898121389095, 0.04647172158001922, 0.007050115345919039, 0.02618045971757965, 0.07052695422316901, 0.0696029952086974, 0.028342565965431277, 0.05740015039918944, 0.016360419176635332, 0.03416636391193606, 0.008270412072306499, 0.040612035227240995, 0.028752604412147775, 0.023360812483588234, 0.05216447294515092, 0.01814897095755441, 0.01037339141475968, 0.0517580469022505, 0.0392221707443241, 0.011383039727661526, 0.06510031103971414, 0.02079973135550972, 0.13496719911927357, 0.08322203590068966, 0.009441008096473524, 0.05336860383977182, 0.007009842702245805, 0.050830562686314806, 0.03257597483752761, 0.04257679698639549, 0.1559993822593242, 0.06567430289578624, 0.0207809680068749, 0.05977476692351047, 0.01713014135020785, 0.029647140981978737, 0.030455857449851464, 0.03896110545611009, 0.024684768686711323, 0.06876401952467859, 0.019835145321849268, 0.048709074180806056, 0.05473470846482087, 0.023958313722687308, 0.08625963149825111, 0.3127214382402599, 0.3488535212818533, 0.796848947647959, 1.7857279535382986, 2.482731440104544, 2.9858636297285557, 3.448700406588614, 3.747966173104942, 4.350074976682663, 3.827694682404399, 3.221856616437435, 5.053729768842459, 5.014564320445061, 5.006257016211748, 5.805172696709633, 7.437515230849385, 6.486597256734967, 3.8734755758196115, 2.656344836577773, 0.9292872785590589, 0.24535709439078346, 0.1936588200624101, 0.00706601029378362, 0.05768799608631525, 0.037210015434538946, 0.05227733505307697, 0.03705203445861116, 0.01980651511985343, 0.051623261751956306, 0.07077468311763369, 0.010155258441955084, 0.09293383976910263, 0.03473019205557648, 0.05739573833125178, 0.016568394930800423, 0.022748848641640507, 0.06203948621987365, 0.029311141042853706, 0.05996597756166011, 0.0164062393741915, 0.01916133831400657, 0.028683580967481248, 0.04658944846596569, 0.015010254028311465, 0.05825162385008298, 0.04692229056672659, 0.07409915589960292, 0.06788360231439583, 0.08501827818690799, 0.032496487110620365, 0.007422310291076428, 0.06522776748170145, 0.047851422350504436, 0.01613006210391177, 0.11664858990116045, 0.015394334932352649, 0.0165918152561062, 0.0310194165649591, 0.01669175471761264, 0.047298303397838026, 0.037566428145510145, 0.054777222394477576, 0.02058458459941903, 0.03972282356698997, 0.006012933354213601, 0.05906627564399969, 0.039649736863793805, 0.02682965339772636, 0.014277849822974531, 0.05723705602576956, 0.05392994949943386, 0.03847289102850482, 0.050784267514245585, 0.003968089222325943, 0.047747989228810184, 0.1091500410984736, 0.03678058281366248, 0.043633118038997054, 0.04300930580939166, 0.052554252615664154, 0.04116995958611369, 0.020130136035731994, 0.056046050012810156, 0.06378579681040719, 0.00885532092070207, 0.025263632742280606, 0.018756350182229653, 0.019402922225708608, 0.009172954560199287, 0.02119839638908161, 0.06029114956618287, 0.08574156789109111, 0.05575979252171237, 0.05627453872875776, 0.10885768686421216, 0.1595471746986732, 0.08983080901089124, 0.10583893439616077, 0.20632539584767073, 0.132625856786035, 0.18918772169854492, 0.1375918192206882, 0.09089958330150694, 0.13109476160025224, 0.11188747506821528, 0.16811423061881214, 0.13039280864177272, 0.13123753597028553, 0.09052648340002634, 0.11988895508693531, 0.15144557895837352, 0.15013729134807363, 0.12386366797727533, 0.18143454944947734, 0.12166417975095101, 0.15188626624876633, 0.1720737072173506, 0.07818395155481994, 0.19721967430086806, 0.12959701853105798, 0.12014198291581124, 0.2109442261280492, 0.13486821146216244, 0.14528413536027074, 0.13772420352324843, 0.1652070600539446, 0.1581014264957048, 0.13383106008404866, 0.0846545812964905, 0.13376625574892387, 0.15409287909278646, 0.19808645825833082, 0.142798267188482, 0.14024363161297515, 0.16300547897117212, 0.1565544048207812, 0.13613369199447334, 0.12900862901005894, 0.1369298531790264, 0.1285200731945224, 0.19304473738884553, 0.21398692770162597, 0.21431630768347532, 0.15338390541728586, 0.11680087860440835, 0.12100682986783795, 0.16687147464836016, 0.07290823894436471, 0.19074357493082061, 0.16231876972597092, 0.08452087597106583, 0.18186671688454226, 0.08355295212822966, 0.15394952584756538, 0.15684709302149713, 0.11961208947468549, 0.1704355943365954, 0.18088963493937626, 0.14453018753556535, 0.10084095571073703, 0.1229624632105697, 0.2660303155425936, 0.18691492412472144, 0.17866368172690272, 0.14934313396224752, 0.247748902766034, 0.11188885546289384, 0.15833990823011845, 0.1967769386828877, 0.11114701206679456, 0.1409757454530336, 0.15745056298328564, 0.11537481215782464, 0.09187090618070215, 0.12598921603057534, 0.13196962012443691, 0.30035515024792403, 0.289921325747855, 0.5111392505932599, 0.9699731203727424, 1.5676966030150652, 1.8947959947399795, 2.3798911459743977, 2.6402460504323244, 2.9952859366312623, 2.570432396605611, 2.2928525414317846, 3.615771741606295, 3.6043519293889403, 4.061550283804536, 4.783716732636094, 5.66397512331605, 5.689924405887723, 3.8573979260399938, 2.3091344302520156, 0.711948856478557, 0.2687878394499421, 0.28129311685916036, 0.16708824114175513, 0.14133709715679288, 0.13013835588935763, 0.1522380145615898, 0.24126257660100237, 0.14253789209760725, 0.16160494240466505, 0.10651713120751083, 0.16269897198071703, 0.1066198741318658, 0.15391841501696035, 0.22589249041629955, 0.12703882064670324, 0.12217692958074622, 0.14931975631043315, 0.24614702153485268, 0.16258102987194434, 0.1265559348394163, 0.11830305229523219, 0.19833516678772867, 0.09418497458682396, 0.12477889191359282, 0.21051755058579147, 0.13928078406024724, 0.19841606088448316, 0.16709472751244903, 0.1732032114523463, 0.09983703028410673, 0.09673893480794504, 0.15175689506577328, 0.09898635835270397, 0.17366537649650127, 0.19569616386434063, 0.09555629279930145, 0.09811739248107187, 0.10738334371126257, 0.0937319676449988, 0.1785019232193008, 0.13306737528182566, 0.11046704152249731, 0.11600664700381458, 0.14622917136875913, 0.09858518300461583, 0.10431219561723992, 0.2084091238793917, 0.19886598049197346, 0.13769704091828316, 0.20805976528208703, 0.12044946211972274, 0.08707695131306536, 0.12819691241020337, 0.1046674617100507, 0.11699171445798129, 0.20610226172721013, 0.09532944051898085, 0.09500774918706156, 0.12986756104510278, 0.123890563409077, 0.09487225528573617, 0.07977390647283755, 0.09842550993198529, 0.2103052963502705, 0.15748360339784995, 0.12883544142823666, 0.1436664315406233, 0.07473427103832364, 0.10686352863558568, 0.11927272018510848, 0.1302058616420254, 0.1859680624329485, 0.16033264895668253, 0.10271370600094087], [0.027660882915370166, 0.034610940056154504, 0.03380615511559881, 0.048178364377235994, 0.04670689704653341, 0.03372770639543887, 0.027541257986740675, 0.1047979312716052, 0.016829708838486113, 0.0399541843944462, 0.04112251408514567, 0.053755292465211824, 0.038643555308226496, 0.04310144344344735, 0.025189293664880097, 0.016075918720162008, 0.008465699884254718, 0.061622380671906285, 0.04855336788750719, 0.029934047852293588, 0.12299017500481568, 0.05520881466509309, 0.024037239272729494, 0.08317900617839769, 0.0011867041075674933, 0.04446043829375412, 0.016169132468348835, 0.012556585788843222, 0.032077656069304794, 0.007211001830000896, 0.012570083599712234, 0.029342160960368346, 0.02242502920125844, 0.02590438449260546, 0.0456030488567194, 0.07313676847843453, 0.024852490350895096, 0.01427749823051272, 0.017809891105571296, 0.030110517582215834, 0.06417785116354935, 0.03332171079819091, 0.05323854617017787, 0.014802005534875207, 0.02055621414911002, 0.0370202000340214, 0.05201678184675984, 0.04448394953215029, 0.05664091477228794, 0.07356261281529441, 0.061613875659531914, 0.015856543577683624, 0.06329996467684396, 0.0773093305178918, 0.03535053845553193, 0.027279046080366243, 0.034487732409616, 0.05605379803455435, 0.04120926001633052, 0.06857818574644625, 0.06590882898308337, 0.009630054446461145, 0.0349338893283857, 0.03503978638036642, 0.016558585593884345, 0.015828946816327516, 0.009480199059908045, 0.057875629572663456, 0.11428500540205278, 0.043612289664451964, 0.015442753574461676, 0.06648028269410133, 0.01370028638120857, 0.01362215214612661, 0.05363404408853967, 0.03257109892729204, 0.06258440072997473, 0.0304799067453132, 0.018925437398138456, 0.053123932593734935, 0.008542782125005033, 0.060954388391110115, 0.0379357096971944, 0.03467365153483115, 0.04251569596817717, 0.03529438756231684, 0.029942374749225564, 0.0796913648082409, 0.032475050174980424, 0.045295439776964486, 0.039780870647518896, 0.013467806766129797, 0.05752775527071208, 0.029732920265814755, 0.04058237900608219, 0.07437502703396603, 0.04001021654403303, 0.0021314381547199446, 0.08784224657574669, 0.04668164918257389, 0.0455775969021488, 0.028005040912830736, 0.008497457311023027, 0.033231532434001565, 0.03743217734154314, 0.019018226266780403, 0.016119625652208924, 0.05145010756677948, 0.06524186086608097, 0.024479605672240723, 0.03836118667095434, 0.024068320417427458, 0.05943008385656867, 0.03235731215681881, 0.02924990087194601, 0.04246792021149304, 0.0561813991953386, 0.021835604384250473, 0.03059737016883446, 0.09085522513487376, 0.042831249738810584, 0.007384700102193165, 0.08622860230389051, 0.010383803746663034, 0.03916841698810458, 0.015085114464454819, 0.032518714433535933, 0.03039137038285844, 0.060386934856069274, 0.030467722535831854, 0.02501608196325833, 0.021814683241245802, 0.06368455302435905, 0.020191565454297233, 0.0244984450910124, 0.02731217369728256, 0.034589310162118636, 0.020980999070161488, 0.020384431081765797, 0.029957353144709487, 0.031014253072498832, 0.026685762095439713, 0.013769401666650083, 0.05159916421689559, 0.049677372808218934, 0.007417818442263524, 0.07214715165900998, 0.04642885884095449, 0.07694258340052329, 0.021125649218447506, 0.043708123193937354, 0.034105915983673185, 0.06148573273094371, 0.023888574105512816, 0.07094988934113644, 0.02567576590081444, 0.010507881561352406, 0.040088880487019196, 0.05216833953454625, 0.06394978918251581, 0.00981441877229372, 0.02967639644339215, 0.08860009809723124, 0.0235581699598697, 0.05091346800327301, 0.04061007966811303, 0.047488582640653476, 0.009671750158304349, 0.03319083676615264, 0.04867049734457396, 0.03457801096374169, 0.06962597210076638, 0.008998407920444151, 0.007724697898083832, 0.033438944155932404, 0.0332103886466939, 0.05539732017496135, 0.04517222099821083, 0.01698978267086204, 0.009817176778597059, 0.025330385215056594, 0.0346190405980451, 0.07167762450990267, 0.0128654416766949, 0.08059567175223492, 0.04117505442991387, 0.06724665407091379, 0.10636331368004903, 0.07073517117532901, 0.047620310142519884, 0.04288428732252214, 0.029452419985318556, 0.016330263861163985, 0.05637449859932531, 0.021325418674678076, 0.06230159793631174, 0.10688067224691622, 0.023209069258882664, 0.030559323968191165, 0.0556823902297765, 0.06984250852838159, 0.009408184760104632, 0.053959791257511824, 0.01137300867412705, 0.02248201686597895, 0.03160052190651186, 0.05773791293904651, 0.048798387942952104, 0.04207037767628208, 0.08808311060420237, 0.04420487974130083, 0.07049778039800003, 0.012171033577033086, 0.04538268665783107, 0.03702886089740787, 0.021715435832447838, 0.011052620739064878, 0.044299767032498494, 0.01611166982911527, 0.09245611930964515, 0.0265272337856004, 0.11118528462247923, 0.06074636068660766, 0.02492753446858842, 0.10444618295878172, 0.03083486113609979, 0.0066721659732138505, 0.026157145148317795, 0.01891302683361573, 0.04979564146196935, 0.005002299376428709, 0.08706892869668081, 0.07516612677136436, 0.06839331676019356, 0.07098336020135321, 0.06367489768308587, 0.020814416602661368, 0.015147616286412813, 0.007887325646152021, 0.032658282725606114, 0.03345847006130498, 0.03228070025215857, 0.03255604446167126, 0.033133479882963, 0.0359603686229093, 0.0397093832725659, 0.0184747774983407, 0.07580959107144736, 0.028670400424744003, 0.038064372129156254, 0.03232033835956827, 0.04935045675665606, 0.02274888760439353, 0.04223923111567274, 0.05737345163652208, 0.02580727632448543, 0.024053789165918715, 0.01309855490035261, 0.057017024082597345, 0.0596236211276846, 0.05376367873395793, 0.025429142806387972, 0.05882033903617412, 0.08197418137569912, 0.0414894318964798, 0.019428455816523638, 0.0514946549810702, 0.03945388409192674, 0.09119331050897017, 0.042839765883400105, 0.02000905278691789, 0.057760641211643815, 0.05168875628442038, 0.1007070425839629, 0.12356718740193173, 0.053236267776810564, 0.025070750416489318, 0.007883189100539312, 0.0088932483777171, 0.10725640677264892, 0.0582451782975113, 0.024375371031055693, 0.018628797261044383, 0.018130233584088273, 0.04832384758628905, 0.019592581775214057, 0.03605576799600385, 0.02637829958985094, 0.018800821526383515, 0.04246413525834214, 0.07519096645410173, 0.04917923215543851, 0.055921079765539616, 0.03130287987005431, 0.015338642315327888, 0.10766786828753538, 0.05261763944872655, 0.04657627534470521, 0.09513394397799857, 0.04320092462876346, 0.031775249444763176, 0.037879855663049966, 0.007184315127233276, 0.011851753297378309, 0.055216718537849374, 0.016553453642700333, 0.07328953215619549, 0.03929813698050566, 0.05308262836479116, 0.025647491929703392, 0.04115987008844968, 0.024235953023890033, 0.05396662272687536, 0.03173047938616946, 0.04876647930359468, 0.038432744549936615, 0.06703829611069523, 0.042523035808699206, 0.04966339074599091, 0.0243041712383274, 0.02326272468053503, 0.059782737589557655, 0.11137103676446714, 0.09930891057592817, 0.01723146120639285, 0.004619748688128311, 0.038042797896196134, 0.04061591665958986, 0.031928413882269524, 0.02810596372000873, 0.03827012515102979, 0.04347309615695849, 0.019453263957984746, 0.003975020417783526, 0.06106708351580892, 0.03276853989518713, 0.018771291470329743, 0.03867941217322368, 0.09837524426984601, 0.06478163282736205, 0.10857765228138305, 0.02506371856725309, 0.02186206194892293, 0.021384669889812358, 0.026842002735065762, 0.01824128114094492, 0.021634870136040263, 0.024834975665726233, 0.06756303904694505, 0.04764363584399689, 0.06236839122720994, 0.029816795940860175, 0.14175283344229683, 0.15886883687926456, 0.17505789786810055, 0.14749048103112727, 0.10931687589618377, 0.11544579116161913, 0.15794140461366624, 0.17853276687674224, 0.1521307890652679, 0.1196463024825789, 0.23505415505496785, 0.2209524140926078, 0.2086372600751929, 0.14114214980509132, 0.17539843975100666, 0.09745447649038397, 0.10847510973690078, 0.32118082337547094, 0.14169068599585444, 0.14041909016668797, 0.16224149730987847, 0.20165198802715167, 0.1406544548808597, 0.22578756557777524, 0.08898136162315495, 0.11900426310603507, 0.1666826129076071, 0.10320685571059585, 0.09141257804003544, 0.10162872320506722, 0.21096364071127027, 0.13545853056712076, 0.07798071441357024, 0.17680190037935972, 0.11648338040686212, 0.20530681300442666, 0.10351653909310699, 0.10299581117578782, 0.12399749204632826, 0.09313847214798443, 0.14650967350462452, 0.14480556885246187, 0.09499243868049234, 0.1502633377094753, 0.09613462621928193, 0.23625437112059444, 0.15564646135317162, 0.18647912016604096, 0.1924366067396477, 0.15210454672342166, 0.22832906513940543, 0.09829719259869307, 0.1011173018196132, 0.13437227869872004, 0.16251405846560374, 0.1362536972737871, 0.15593287098454311, 0.16551091015571728, 0.13802360073896125, 0.1247123657958582, 0.11309212917694822, 0.13386080536292866, 0.0851234701985959, 0.1067302908631973, 0.10141732986085117, 0.10243606855510734, 0.10689112910768017, 0.14557689777575433, 0.14442784537095577, 0.15759951202198863, 0.16633470891974866, 0.20914113381877542, 0.1117155046085827, 0.11073969173594378, 0.24980904534459114, 0.10257839763653465, 0.18318248534342274, 0.10560757727944292, 0.12716011726297438, 0.0840734425582923, 0.15719700080808252, 0.1695893975556828, 0.1422129650018178, 0.13375202135648578, 0.16574177745496854, 0.09564129839418456, 0.12302450675633736, 0.19682019104948267, 0.22108231962192804, 0.12258226095582359, 0.15598413854604587, 0.09875421455944888, 0.2357829292304814, 0.15454796404810622, 0.15012155781732872, 0.15274830046109855, 0.12607192096766084, 0.2733421028824523, 0.1372675600578077, 0.16914128878852352, 0.09795826117624529, 0.09378901653690264, 0.11526078116730787, 0.19101206911727786, 0.14646615396486595, 0.09675061621237546, 0.1009550089656841, 0.19976754148956388, 0.15304824686609209, 0.14287941361544654, 0.11335962888551876, 0.08957991114584729, 0.1670642103999853, 0.17105558450566605, 0.16182019491679966, 0.09153564838925377, 0.14243648503907025, 0.11508990908623673, 0.0986331034800969, 0.21734744659624994, 0.1397364033618942, 0.11433316336479038, 0.23683924286160618, 0.17495963751571253, 0.11563484586076811, 0.05096237553516403, 0.11881632904987782, 0.12642752844840288, 0.22486078640213236, 0.133299860463012, 0.09922313314746134, 0.2203782886499539, 0.12623140850337222, 0.13288667716551572, 0.13789988472126424, 0.15483133087400347, 0.18273499998031184, 0.10669598137610592, 0.15378193405922502, 0.12390932490234263, 0.15347481850767508, 0.16460793907754123, 0.12940425309352577, 0.276804578024894, 0.12993043579626828, 0.06692393857520074, 0.2719130233163014, 0.3668389655649662, 0.1181020935473498, 0.10556604669545777, 0.1441558779333718, 0.15202518145088106, 0.13152626110240817, 0.13985257915919647, 0.193526049843058, 0.20781724626431242, 0.09776018938282505, 0.10906230440014042, 0.1018300159194041, 0.09707238918053918, 0.09773278186912648, 0.12022453942336142, 0.214598516758997, 0.16877959569683298, 0.17950183362700045, 0.07925942743895575, 0.09431421218323521, 0.1249478937825188, 0.10678152131731622, 0.10495336668100208, 0.07449880242347717, 0.1195387652842328, 0.17109573469497263, 0.0738695205654949, 0.11991717154160142, 0.09205956754158251], [0.047228163020918146, 0.02516212178306887, 0.048169057845370844, 0.02431857632473111, 0.03236094125895761, 0.057025699788937345, 0.05458491708850488, 0.020535756848403253, 0.10092358643305488, 0.01729255851387279, 0.05008805506804492, 0.10279649257427081, 0.06748199652065523, 0.03207032736099791, 0.04421437181008514, 0.05702615620975848, 0.041147346346406266, 0.09517931888694875, 0.006295249113463797, 0.04380380458314903, 0.013640717897942523, 0.05510215320100542, 0.08601351306424476, 0.08013487225980498, 0.06332701595965773, 0.024681536633579526, 0.0278852267365437, 0.014625247295043664, 0.02553216960222926, 0.018875811838370282, 0.040390244394075125, 0.009832208979787538, 0.026580551530059893, 0.07266201660968363, 0.04171957931248471, 0.05803152140288148, 0.030806531503912993, 0.06254302599700168, 0.05465434500365518, 0.071333223459078, 0.08564742645830847, 0.06790014478610829, 0.05726870120270178, 0.0054984158214210765, 0.03709243697812781, 0.011739552628569072, 0.011632927344180644, 0.061232137159095146, 0.013868503428966505, 0.036611714531318285, 0.02128926123987185, 0.009684746091807028, 0.009870975063677179, 0.09269000714994036, 0.09776973340194672, 0.032927263018791564, 0.047571758841513656, 0.03809887457464356, 0.0252530107536586, 0.01853119370935019, 0.042750967913889326, 0.02711878300033277, 0.02149406060198089, 0.002302933639839466, 0.06834125510067679, 0.04749240470118821, 0.03700664470670745, 0.027190878936380614, 0.025737410542205907, 0.04270206409273669, 0.011028881290258141, 0.020227578170306515, 0.06155274124466814, 0.048638369771651924, 0.02001871183892945, 0.03155657563183922, 0.0829799027997069, 0.0448399392189458, 0.03695034909469541, 0.05617072711174842, 0.04266761359758675, 0.05126485637447331, 0.0919806920865085, 0.008669450962770497, 0.07429872683132999, 0.07527656576712616, 0.03973717670305632, 0.02540177240007324, 0.021693039670935832, 0.05484266497660428, 0.06024792317475658, 0.017676247007329948, 0.04059282102389261, 0.024561817081121262, 0.02221523147454718, 0.010780618049466284, 0.03370896716660354, 0.050297730340389535, 0.0689196701569017, 0.04215945766190998, 0.026232851632812526, 0.04788570215168875, 0.030551154777640477, 0.012904151171824196, 0.01956484586116858, 0.06610344236833043, 0.025811428640736267, 0.05843632956384681, 0.04618987986759748, 0.02671210833796067, 0.022154449579829816, 0.030870974042045418, 0.03006687187735224, 0.03477499180007726, 0.012279138518351829, 0.01637059587665135, 0.0464599956467282, 0.04494343913393095, 0.036805392810492776, 0.022109198980615474, 0.030957937051425688, 0.12848326266976073, 0.015539358009846183, 0.034160103896283545, 0.039057128233253025, 0.05379103429731913, 0.025824442200246267, 0.03772124015085865, 0.029568836980615743, 0.059636983496602625, 0.06834985659224913, 0.020077358203707263, 0.0212680914773955, 0.07201678599813022, 0.025260955444537103, 0.023632952470507007, 0.05993235085043125, 0.05440485350845847, 0.025006252217281144, 0.05161333923751954, 0.0503634475171566, 0.09160857924143784, 0.010868473491427721, 0.03719757703947835, 0.042825052805710584, 0.01792733783076983, 0.023348843496933114, 0.06468688283348456, 0.04192318010609597, 0.07141604713979177, 0.019075976488238666, 0.07706581702223048, 0.03461685868387576, 0.03688314391183667, 0.03682029513583984, 0.02515809377655387, 0.014255106707423693, 0.033838060044217855, 0.004053202892464469, 0.0657154995133169, 0.08934721816331148, 0.03466762900643516, 0.01029864322845242, 0.05094605570775457, 0.03273104288382456, 0.06398971672751941, 0.0646667112596333, 0.033933218219317496, 0.04199117196549196, 0.040520687980460934, 0.0056438674891978735, 0.04195782355964184, 0.057744748119148426, 0.0038393706654460402, 0.0794199614028912, 0.05974045372568071, 0.058656380060710944, 0.061619775733561255, 0.01015225367154926, 0.016284499324683566, 0.060579934070119634, 0.037203083775239065, 0.03158345993142575, 0.03144443340715952, 0.05710254547011573, 0.06812321211327799, 0.036148209910606965, 0.09332748973974958, 0.04005237053206656, 0.04070243252499495, 0.018749130940705072, 0.034150545034208335, 0.03031072861631401, 0.045378764407359995, 0.03516906108416151, 0.027587566146394238, 0.024763263791101053, 0.0491115334443748, 0.049032494716811925, 0.03826605447102338, 0.030377076618606225, 0.062004007850191556, 0.022874965507071465, 0.02040458595729433, 0.039942655130289495, 0.013916681800765218, 0.06565039089764468, 0.025845237178145908, 0.06540734495501965, 0.02279542026371928, 0.025838567125902046, 0.05717227395507507, 0.03936403227271512, 0.027206614322494715, 0.030302566847240087, 0.01433598410585546, 0.035569245665101334, 0.03162150984280743, 0.1210617933247704, 0.0936132314382121, 0.029814077824994456, 0.021868717158213258, 0.058975154752261005, 0.012792444958904525, 0.11499721484142356, 0.011127451489301166, 0.07709205194259994, 0.057807760167634115, 0.0389552165142959, 0.06393621530150995, 0.018556551040092018, 0.03621427960752044, 0.02443395060254261, 0.07096267654560506, 0.05884316749870777, 0.037218082579784095, 0.058752833283506334, 0.012966652066097595, 0.0431640435999725, 0.03375365187821444, 0.04528046694758814, 0.06592533434741199, 0.028623344551306218, 0.1311376428930089, 0.046990282426122576, 0.013282828313094797, 0.09243707580026239, 0.043695180138456635, 0.0548623578652041, 0.03535532159730792, 0.04894345183856785, 0.062138466455508024, 0.06881235560285859, 0.010818841437867377, 0.08845440708682872, 0.06398317840648815, 0.01876506670669187, 0.06242596704396419, 0.0656636456551496, 0.08464744183584116, 0.053229235927574337, 0.024464874040859286, 0.04556842024612706, 0.031262911506928504, 0.05306164413923398, 0.05098528192320373, 0.004894414760201471, 0.04564175927953329, 0.02799073416099418, 0.04810254285985138, 0.04835315870877821, 0.034476514847483486, 0.012436875513230916, 0.039338157293968834, 0.0343457335839048, 0.014489857294393005, 0.012324546823947458, 0.01880431704194052, 0.09744823502842337, 0.02672756541869603, 0.06244610151043162, 0.10099965656991117, 0.004746430977320415, 0.04563530259474646, 0.05055327776062768, 0.02031509779044427, 0.01394167733451468, 0.0030889318077242933, 0.053843737914576195, 0.019187350590073038, 0.030021291022421792, 0.04224886419251561, 0.03683607319544535, 0.04137117066420615, 0.0312600356846815, 0.08249333593994379, 0.018497424134693574, 0.04965641455783043, 0.06266168056754395, 0.07076626716298051, 0.0463378715357976, 0.07013522641500458, 0.013977671496832045, 0.04257879336364567, 0.013576597266364843, 0.0555782594892662, 0.07471781762433238, 0.02440984007989755, 0.016620417627564166, 0.03596920760173816, 0.04700395649706479, 0.04172790620941669, 0.042571728117763996, 0.02344215929042548, 0.013715139539272059, 0.06387449830072, 0.0330945282621542, 0.04830416582990438, 0.06203668090165593, 0.010704797459766269, 0.0372679883003002, 0.04301930624933448, 0.018991271463164594, 0.058683761599240825, 0.07168915748479776, 0.05088433128548786, 0.032738338195485994, 0.013956698403490009, 0.04333807351940777, 0.04996350413421169, 0.023380826351058204, 0.01860234155174112, 0.04379260186397005, 0.05368613172322512, 0.029857159497623798, 0.04257866348780226, 0.01536028705231729, 0.042972758747055195, 0.0341176419169642, 0.022274289731285535, 0.04512454914220143, 0.04572800055029802, 0.05999865803460125, 0.04759269482747186, 0.031746936510899104, 0.034390800501569174, 0.024711226251383778, 0.03970473371737171, 0.024653236687299795, 0.04614327299350407, 0.07323719590203837, 0.004855574461544165, 0.14410532283363864, 0.16294763598125428, 0.10249186321743764, 0.13787310803309083, 0.10814610825036652, 0.15406295569846407, 0.1376384706236422, 0.1925005204975605, 0.24672310624737293, 0.14414603705517948, 0.13557776401285082, 0.1878298437804915, 0.12581380200572312, 0.12193398753879592, 0.06559282992384396, 0.07568385641206987, 0.22172130877152085, 0.16607506113359705, 0.1562220710911788, 0.08334170721354894, 0.11392084838007577, 0.14652338839368895, 0.1383775903377682, 0.20408736047102138, 0.11200630775419995, 0.17475443368311971, 0.12207091378513724, 0.09033480149810202, 0.18588191393064335, 0.13735136337345466, 0.1558292077970691, 0.0945182063151151, 0.18510411347961053, 0.19223453477025032, 0.08553084990126081, 0.1553828950272873, 0.14225121529307216, 0.14476022362941876, 0.1484614031505771, 0.11631115761701949, 0.16458503640023991, 0.09821798317716457, 0.23864349292125553, 0.1964998949551955, 0.13095087400870398, 0.12778616335708648, 0.08651599157019518, 0.12362249966827221, 0.16738241363782436, 0.14851866726530716, 0.2885076234815642, 0.10483573627425358, 0.11631253801169805, 0.12144837062805891, 0.17892730742460117, 0.11874729447299615, 0.1158495269191917, 0.14160588820232078, 0.12905164388939738, 0.08908722156775184, 0.24298093048855662, 0.10432001043227501, 0.1111120569112245, 0.15007870621047914, 0.1353619177825749, 0.20101758535020053, 0.1353215004201047, 0.2748573012650013, 0.10189148058998398, 0.11251966614509001, 0.18374052102444693, 0.15422150812810287, 0.16322570387274027, 0.13619282632134855, 0.1029892876977101, 0.10265294637065381, 0.21009289368521422, 0.1124815345974639, 0.17445767851313576, 0.21711515437345952, 0.18109666445525363, 0.11164008756168187, 0.2558202634099871, 0.13527685281587765, 0.21452170447446406, 0.1867857013712637, 0.20962198614142835, 0.1767224312061444, 0.14827460458036512, 0.18987196701345965, 0.18596191745018587, 0.16075350606115535, 0.17275553313083947, 0.14434910350246355, 0.11290428417851217, 0.081655154353939, 0.10085297108162194, 0.10819534974871203, 0.07578188669867814, 0.12082221321179532, 0.11841709070722573, 0.1449410998611711, 0.36576445447281003, 0.08975283897598274, 0.14032100792974234, 0.13592142291599885, 0.13817201543133706, 0.13700997544219717, 0.17952504800632596, 0.11673216315102763, 0.07553844741778448, 0.12793132744263858, 0.11796987251727842, 0.10802988050272688, 0.19379025441594422, 0.14281803800258785, 0.23599960666615516, 0.11430152560933493, 0.13645933155203238, 0.16418930841609836, 0.11165212519699708, 0.25415945565328, 0.173916281783022, 0.15272809920134023, 0.12716379831545055, 0.14131472882581875, 0.10416460470878519, 0.1489261063397862, 0.06235358538106084, 0.19517913926392794, 0.13889384310459718, 0.1140174017928075, 0.08785009107668884, 0.1661213266197592, 0.23891164571978152, 0.14294810680439696, 0.11533549317391589, 0.16248238360276446, 0.12080793429049663, 0.2102558990009129, 0.1653965748846531, 0.15404636127641425, 0.1311183618963696, 0.14715097815496847, 0.1202366512734443, 0.08454585666186176, 0.10801852564327419, 0.13580150669440627, 0.12971352087333798, 0.2527553716208786, 0.13604378822492436, 0.16471819253638387, 0.11179930792422965, 0.10759607292129658, 0.06604850859730504, 0.1651077755377628, 0.17365274514304474, 0.09909401429467835, 0.13093708490487188, 0.14576081681298092, 0.1594193620258011, 0.14877617766615003, 0.14438885293202475, 0.19449572515441105, 0.13629074528580531, 0.13916768075432628, 0.2115332687390037, 0.16445916815428063, 0.11978359238128178, 0.1286295845056884, 0.12535142916021869, 0.14230942935682833, 0.1722867481294088, 0.16545000951737165, 0.16518418706255034, 0.113670262217056], [0.06397960125468671, 0.024016260613279883, 0.030794636732025538, 0.055374235671479255, 0.06728422158630565, 0.061112065086490475, 0.04033365192299243, 0.026593947295623366, 0.0050000423198071076, 0.03983289891039021, 0.053127327919355594, 0.020308899001975078, 0.0031065974735611235, 0.04753695582621731, 0.014771256501262542, 0.03646993834991008, 0.07345573612838052, 0.060636589623754844, 0.015747820798424073, 0.007399932683256338, 0.03213915784726851, 0.0020582366505550453, 0.06735013172146864, 0.06541823968291283, 0.08153937189490534, 0.02375871867116075, 0.024878445110516623, 0.041101971437456086, 0.009714598054415546, 0.046628485433757305, 0.02650692120369058, 0.07441134774126112, 0.059226323501206934, 0.011327798893034924, 0.02849317927029915, 0.08791555592324585, 0.015127639526326675, 0.029200585158832837, 0.06815928791183978, 0.03070158440095838, 0.03792254770814907, 0.03223228624847252, 0.011238644692639355, 0.04763857810758054, 0.038997559749986976, 0.017639156321820337, 0.051408409999567084, 0.05088923317089211, 0.025735766685102135, 0.0188578370216419, 0.027246024219493847, 0.06920662897755392, 0.06789117222069763, 0.025721259553392883, 0.09134817446465604, 0.019533775848685764, 0.05422943948360626, 0.031831526503083296, 0.009527808761049528, 0.027138448058394715, 0.07505427027354017, 0.019626199209596962, 0.04658562640543096, 0.04765922094520647, 0.03040460287593305, 0.020055501954630017, 0.057213878753827885, 0.039936792163643986, 0.01094345452656853, 0.02952788712718757, 0.033231588095077313, 0.024390805847360753, 0.034059186655213125, 0.08889622986316681, 0.06112950184615329, 0.028040513716405258, 0.03399043780518696, 0.03463242523139343, 0.035369177494430915, 0.024198764003813267, 0.012962608288944466, 0.014104773563303752, 0.0282040589445387, 0.006839930310889031, 0.03489982475002762, 0.07256345939822495, 0.04885649810603354, 0.04678337536461186, 0.06329589028609917, 0.025774575442483183, 0.05941665840509813, 0.021870160635444336, 0.046609631172032095, 0.03747982322238386, 0.05652829757309519, 0.033971527882386, 0.02930405353254173, 0.020592703695001546, 0.04721886391052976, 0.029116548066667747, 0.049590214985073544, 0.07340838710661046, 0.14427724876441061, 0.04811593491467647, 0.07078995651681907, 0.028235275531187654, 0.0349941331660375, 0.038163419158081524, 0.031517917159362696, 0.03451574477367103, 0.02438736042677192, 0.0921196147101, 0.0016843268804223044, 0.02395256578893168, 0.037822120284545235, 0.0624530554341618, 0.04639577389752958, 0.018367359043622855, 0.02642305480549112, 0.013928109019616386, 0.03008066469192272, 0.04407899294164963, 0.051232509867986664, 0.05401155234721955, 0.09926653394359164, 0.05387619574321434, 0.03557090436515864, 0.06328491392196156, 0.0634593483118806, 0.024504475040885154, 0.07091511230100878, 0.018988319570780732, 0.03526669432176277, 0.02777891593723325, 0.04780460767506156, 0.09567387867718935, 0.036102512167417444, 0.020712200603156816, 0.02602877215394983, 0.03199769707862288, 0.017544894290040247, 0.05036246788222343, 0.06235389708308503, 0.05389148027461488, 0.06474006513599306, 0.006872034691696172, 0.037547217652900144, 0.027553579493542202, 0.04698052318417467, 0.05357895446650218, 0.0058066561905434355, 0.04340582789154723, 0.013785822611680487, 0.021964229708828498, 0.03294964990345761, 0.0812658533686772, 0.05092838517157361, 0.07065660000080243, 0.020777886238647625, 0.043362716533010826, 0.11057050433009863, 0.02495364322385285, 0.030931587098166347, 0.011645573540590703, 0.02091602404107107, 0.02582560366136022, 0.02010304950090358, 0.049389734922442585, 0.01803664505132474, 0.03284659898781683, 0.01109734905185178, 0.027572246362979058, 0.08265245240181684, 0.008433436869381694, 0.06273717925068922, 0.05477870668983087, 0.03422452231461648, 0.02961748105008155, 0.017945531581062824, 0.062838593730703, 0.038316197678796016, 0.06770826250431128, 0.04086700748302974, 0.026025588340417016, 0.0414274848299101, 0.042441247423994355, 0.03878423311107326, 0.01719061896437779, 0.01736187139613321, 0.018187681380368304, 0.06699283214402385, 0.012556204510474345, 0.04470396292163059, 0.026485729176783934, 0.02348334663111018, 0.0408224860439077, 0.029968826747790445, 0.03250326662964653, 0.04675573407439515, 0.07442501810146496, 0.027975050725217443, 0.03593024113797583, 0.03428425778110977, 0.06113434807048179, 0.007028447416814743, 0.014154585587675683, 0.08300045286887325, 0.04804770556802396, 0.050336277490714565, 0.013186318501539063, 0.015546860195172485, 0.05044915073085576, 0.05564435887208674, 0.0688067301234696, 0.02035178771620849, 0.028192796853545588, 0.04474058419873472, 0.07799892671755515, 0.056698364423937164, 0.0659546566021163, 0.026689587866712827, 0.014693466437165625, 0.005447200210255687, 0.05831590868183412, 0.05254436349787284, 0.0344463020155672, 0.0233837262931047, 0.03711031160491984, 0.027525298100954387, 0.02059352191281505, 0.0349134394491557, 0.0147639621172857, 0.02310283452970907, 0.17877414298709482, 0.04106052620045375, 0.024310503613378387, 0.04770540108438581, 0.03340029681567103, 0.01691797617240809, 0.03789741487707943, 0.009022492467920529, 0.010313708826288348, 0.009707000317575876, 0.03974067592935171, 0.020052550062246155, 0.005435375014712918, 0.047886885877233, 0.08528416001354344, 0.0027829626424136222, 0.010704813230404397, 0.04988450622477103, 0.03195002151187509, 0.014197589334798977, 0.0488840392063139, 0.031984728047973476, 0.034514935832703486, 0.02934668806119589, 0.05646367877488956, 0.03977774249506183, 0.020132455247221515, 0.014436571091209771, 0.037321215131669305, 0.022368548052327242, 0.04196355293970555, 0.015082235859154025, 0.02630068949656561, 0.04853367128816899, 0.08687245252076536, 0.015858977822063025, 0.04096170923730824, 0.07229837909108028, 0.05888823070563376, 0.06813362444518134, 0.039125754628912546, 0.016425178982899524, 0.0282015801712987, 0.044160016914247535, 0.031061067747941706, 0.01196991990582319, 0.007149429548007902, 0.01776268494722899, 0.04808247147593647, 0.025856777574517764, 0.05430509401776362, 0.042987241758964956, 0.06095243283198215, 0.05133259961439762, 0.023286760988412425, 0.057791707513388246, 0.05207969370530918, 0.03458542501903139, 0.04330048002884723, 0.014813148882240057, 0.03665883719804697, 0.01060516135112266, 0.030991316998552065, 0.038765783319831826, 0.04353449403424747, 0.03898715855029877, 0.036107848209212534, 0.09326878585852683, 0.046146560707711615, 0.0697203584422823, 0.08107427536742762, 0.07213795644929633, 0.020852629786531907, 0.05289287604682613, 0.027559390509850346, 0.0025848110681181424, 0.0650557896005921, 0.025991802067437675, 0.07154938881285489, 0.028334482121863402, 0.09122569041210227, 0.004772922402480617, 0.02746838094026316, 0.027504341705935076, 0.0311793419677997, 0.03006660655955784, 0.045321511424845085, 0.00664349634462269, 0.0460094563459279, 0.0387115657213144, 0.015655330644221976, 0.026999820438504685, 0.040244353003799915, 0.010527444574108813, 0.03849677334073931, 0.045279646874405444, 0.03175987585564144, 0.04679962839873042, 0.05638486640236806, 0.07326383900362998, 0.04437642346601933, 0.05346015888790134, 0.05844818537298124, 0.0701443177240435, 0.029876870939915534, 0.07149956843932159, 0.025826987766777165, 0.02297522223670967, 0.04397907017846592, 0.029265567609400023, 0.07018685020739213, 0.09133883082540706, 0.04796444402018096, 0.02710734093852807, 0.030895103118382394, 0.014746804590686224, 0.09989893282181583, 0.016614549094811082, 0.11280491060460918, 0.1909435837296769, 0.08148027467541397, 0.1493340649176389, 0.25097911537159234, 0.09334740156191401, 0.14440182567341253, 0.14708443719428033, 0.13649388594785705, 0.12834364984882995, 0.1000863325316459, 0.2601368317846209, 0.09329529537353665, 0.10140176702407189, 0.15302866901038215, 0.16043323965277523, 0.0859552767360583, 0.16676082042977214, 0.26283848681487143, 0.05080727038148325, 0.13015901728067547, 0.15895036922302097, 0.19954966177465394, 0.2693977364106104, 0.13996133347973228, 0.16066134616266936, 0.11265268869465217, 0.15182981849648058, 0.08231362488004379, 0.06674105854472145, 0.1385459242737852, 0.13189773570047691, 0.18725353642366827, 0.16466253146063536, 0.11499329630169086, 0.12944584304932505, 0.20133423007791862, 0.11029018030967563, 0.12992104020668194, 0.17331298993667588, 0.11329960398143157, 0.11005101579939947, 0.13386746984906495, 0.12192266978672706, 0.11138939749798737, 0.13254278077511117, 0.14155551121803, 0.16026630095439032, 0.11771003177273087, 0.15231736499117687, 0.11456985652330332, 0.15005546214524657, 0.11321437574224547, 0.10254940934828483, 0.12071558143361472, 0.13326266402145848, 0.08639412350021303, 0.16759643418481573, 0.2124537545023486, 0.12937884195707738, 0.16871988249477, 0.1383277476998046, 0.24136123771313578, 0.1981595004326664, 0.1508663475397043, 0.12782322621205822, 0.13741275382926688, 0.11918438234715723, 0.11130385013530031, 0.0737553188810125, 0.09673885317170061, 0.12288230384001508, 0.23037858016323298, 0.1208117934584152, 0.1180386176565662, 0.16526138526387513, 0.1492624921957031, 0.24229120812378824, 0.18310263025341555, 0.15887174609815702, 0.09246955960406922, 0.14068687189137563, 0.09711550796055235, 0.12015149724902585, 0.1422401424497366, 0.20362075738376006, 0.11410100472858176, 0.09101149917114526, 0.2130375278647989, 0.12467228982131928, 0.17761137569323182, 0.2526392403524369, 0.14550808584317565, 0.14739317062776536, 0.11970559266046621, 0.1788738727918826, 0.24810844362946227, 0.15438702190294862, 0.07813897740561515, 0.1372738237841986, 0.09423046081792563, 0.08033227612031624, 0.12101045154849999, 0.26148774835746735, 0.17126874416135252, 0.1880570300272666, 0.25531993713229895, 0.11104553079348989, 0.1334158581448719, 0.14471225120360032, 0.20014575478853658, 0.1424948326894082, 0.2049597550649196, 0.09345276426756755, 0.10022181901149452, 0.11594089271966368, 0.14513184665702283, 0.12041694863000885, 0.14537305949488655, 0.09364240526338108, 0.10505596859729849, 0.18955165607621893, 0.13281413965160027, 0.1854793878737837, 0.12948591902386397, 0.14865773089695722, 0.10364906440372579, 0.1606375677511096, 0.20462691667489707, 0.29225855658296496, 0.09142729482846335, 0.12877508997917175, 0.15043664403492585, 0.11890729409060441, 0.14440457161981612, 0.14498548029223457, 0.12202142737805843, 0.07099553142325021, 0.09547178444336168, 0.10001322356401943, 0.1843137262039818, 0.08517339447280392, 0.1440382029977627, 0.1641844547702931, 0.08518255999661051, 0.15960433491272852, 0.18141471926355734, 0.10640589811373502, 0.14741890830919147, 0.1707345462637022, 0.15172881219768897, 0.05872487286978867, 0.16535465838387609, 0.14260153868235648, 0.11927887258934788, 0.10851997256395407, 0.20175145065877587, 0.13996069523273036, 0.2202001732075587, 0.11473169666714966, 0.13350953202461824, 0.30445599113591015, 0.12137235244153999, 0.10237653346848674, 0.18618432426592335, 0.09268447072827257, 0.12477984186261892, 0.1506317249732092, 0.1470338078797795, 0.23644830915145576, 0.07649060062249191, 0.06704730578348972, 0.09241499690688215, 0.1319110646727495, 0.1615103185758926, 0.10943020926788449, 0.2789584390120581], [0.04200096460408531, 0.01920315648021642, 0.06008357086102478, 0.050196813099319115, 0.04367965811979957, 0.04089854504854884, 0.06251598213566467, 0.05676565124304034, 0.03822850179858506, 0.062484656082233414, 0.03200142637069803, 0.022830611051176675, 0.04235983011312783, 0.02449803319905186, 0.07300728597328998, 0.048318689659936354, 0.04684703308157623, 0.011812291450041812, 0.048370205840910785, 0.03861862285702955, 0.05361182047636248, 0.033477765900897793, 0.023566953277622815, 0.013396007689152611, 0.07797809463227168, 0.023046906280796975, 0.005601507091341773, 0.024520759616279975, 0.021160166506888345, 0.01896393074275693, 0.01895083925774088, 0.03374502441147342, 0.05815763084683567, 0.051056301745120436, 0.018645000200194772, 0.039410353419953026, 0.015034733769425657, 0.00429091279329441, 0.02088234352413565, 0.023873150421422906, 0.05326121136022266, 0.02773825737676816, 0.01934077106852783, 0.07567406006273814, 0.03927823629055638, 0.05490452669619117, 0.06439833581680432, 0.04039486426336225, 0.030828968483547214, 0.0379579741274938, 0.02223176466941368, 0.03454620993579738, 0.02313478027645033, 0.05500331397342961, 0.07299113683984615, 0.016818175863591023, 0.12541449686978012, 0.011224835179746151, 0.011634304955805419, 0.033593570624361746, 0.02126937724824529, 0.0157493199367309, 0.04620425155735575, 0.014380920219991822, 0.03775868892262224, 0.020705497154267505, 0.029373672550718766, 0.04340425082773436, 0.03045107801881386, 0.04847913085541222, 0.048545267345616594, 0.020720063657790888, 0.06342822263832204, 0.03848028281936422, 0.038612878634012304, 0.06602196197491139, 0.02310152649442898, 0.023509588972956408, 0.054108907279442064, 0.01519452558568446, 0.08429074339801446, 0.03837486445263494, 0.05078713220427744, 0.038325975474435836, 0.03528673230903223, 0.004929649148834869, 0.07904611935373396, 0.05791786148620304, 0.05101755421492271, 0.05495156401593704, 0.014373029334819876, 0.07612064000568353, 0.009432205297343899, 0.07342121883993968, 0.026629668718669564, 0.057664128617034294, 0.013653082078235457, 0.1014271039457526, 0.04093519601156004, 0.09838639874942601, 0.07122155991964974, 0.03528248351358343, 0.02263695318106329, 0.04481363750528544, 0.11432743398472667, 0.034885085697169416, 0.04541414629784413, 0.03517425611789804, 0.012562697374960408, 0.03252627691836096, 0.11057645635446534, 0.04438204523466993, 0.01601405514520593, 0.03512263603624888, 0.0340769648028072, 0.037167816917644814, 0.04263414644810837, 0.08112273018923588, 0.0627056676603388, 0.08411313261603937, 0.008330364616995212, 0.11430717335315421, 0.034313123614992946, 0.0697402999503538, 0.01215552269059117, 0.07662692572921515, 0.04911917385470588, 0.013572769639722537, 0.047845477747614495, 0.003250260797358351, 0.10692937939893454, 0.03937241854146123, 0.049518055966473185, 0.04609306670317892, 0.050878264228231274, 0.08238174661528319, 0.0500647776061669, 0.034973790898220614, 0.030055101415200625, 0.03851671855954919, 0.061851322097936645, 0.020830994326388463, 0.07741490102489479, 0.01977212399651762, 0.03938676054531243, 0.04876605627941899, 0.05209230279433541, 0.048377274797530845, 0.0552622381655965, 0.02829146724252496, 0.05900483323785011, 0.041372751438757405, 0.07568589731818065, 0.030900131168891676, 0.02866686409106478, 0.050981753011001274, 0.06046235932444688, 0.018428409966873005, 0.046324193754117005, 0.054542495927307755, 0.05272222661005799, 0.05547934975766111, 0.021678757038898766, 0.04312493241741322, 0.019863794077537023, 0.021386169028119184, 0.035342371120350435, 0.03344078468217049, 0.07506824491429143, 0.08948730595875531, 0.02854166377801448, 0.0415364395303186, 0.04828582736081444, 0.04013713121821638, 0.034933180577354506, 0.02279792130138958, 0.03082186056417413, 0.06696815573377535, 0.03602888740715571, 0.06607627976336516, 0.03808849192864727, 0.026395036875328515, 0.051327656910871156, 0.06654138371231966, 0.03916484354704153, 0.08679572187247686, 0.06322581670247018, 0.024011813293327577, 0.038699487267876975, 0.06337258382700384, 0.034116795868612826, 0.15583085536491126, 0.052467900022747926, 0.0829218965373002, 0.023561823181807995, 0.03254014394769911, 0.040129205081029795, 0.018963639449793845, 0.034553319710539654, 0.0207186665647896, 0.03026310499990359, 0.02679901197552681, 0.024254966847365722, 0.049313534909742884, 0.05010128013964277, 0.043402558731031604, 0.05802791456517298, 0.030142676696414128, 0.01867515551566612, 0.01125188275182154, 0.08018426960916258, 0.014464078794844681, 0.011983868571405765, 0.015812523088243324, 0.03114608261967078, 0.036204969364916906, 0.04090483103937004, 0.07285024752491154, 0.013761524696747074, 0.017852972778200638, 0.035358093518880196, 0.033106584451161325, 0.06355611694743857, 0.04441719334863592, 0.045205561982584186, 0.036390762325027026, 0.05555834395636339, 0.0880225290893577, 0.036770756778423674, 0.04775013403559569, 0.02704104674194241, 0.02225745967734838, 0.048511013519600965, 0.017431165724701714, 0.050770842062775046, 0.019241503250668757, 0.029934309459349606, 0.0168310836670571, 0.021889981544518378, 0.013324301380635006, 0.06570347672095522, 0.01662505976128159, 0.05513762043847237, 0.02300058327818988, 0.0518311929772608, 0.010842022420547437, 0.05161892018804792, 0.0648192671360448, 0.05505691558937542, 0.007731453297310509, 0.057127570689772256, 0.06290023651672527, 0.01001605844066944, 0.038813499704701826, 0.032385803206125274, 0.025824117510637734, 0.03286931983893737, 0.01453276549000293, 0.038049269423936494, 0.08707815359230153, 0.018118045663868543, 0.019192499239579774, 0.033204677820322104, 0.01615870529349195, 0.034198869980173185, 0.08510289044352248, 0.04367627392639406, 0.030479788001684938, 0.03949364836444147, 0.04294493934139609, 0.015124397268664325, 0.029079227315378375, 0.07583126920508221, 0.012925893315696158, 0.06574319646460935, 0.01998932279093424, 0.005199930519665941, 0.0450910931249382, 0.02555504259362351, 0.02454274203046225, 0.02408026899502147, 0.08757578587392345, 0.021983197148074396, 0.039014369394863024, 0.04997289972379804, 0.019453757486189716, 0.034938078752020374, 0.019289043375465553, 0.016562580203753896, 0.038682662780047394, 0.08938350176322274, 0.02136978982889559, 0.03479793529550079, 0.04834589308302384, 0.019980906836281065, 0.04811016842722893, 0.08844069961924106, 0.03602910634072032, 0.05477509614138398, 0.04486378442379646, 0.01656068958254764, 0.06372445830493234, 0.012540668576548342, 0.03232199334888719, 0.01841664136009058, 0.017810764984460548, 0.032628778644721024, 0.02397631080384599, 0.015530826094618533, 0.03474905373877846, 0.13861743762390688, 0.021177230337343644, 0.0031606190987076843, 0.0375159769464517, 0.041002267607836984, 0.04292117948352825, 0.003062179935113818, 0.014511354529531673, 0.04904964203888085, 0.05373328036512248, 0.04223632189678028, 0.025168821521219797, 0.07702560746110976, 0.028346790641080588, 0.04222935313009657, 0.015047721353766974, 0.05966971963061951, 0.03818231423792895, 0.10618678643368185, 0.04748633022245485, 0.01526879786979407, 0.01675947569310665, 0.009413307434442686, 0.09782860055565834, 0.03617828173446469, 0.027873879298567772, 0.042088816335308366, 0.03420835462748073, 0.061104732667445205, 0.001211956725910568, 0.02552470916270977, 0.05717202162486501, 0.03837426702375524, 0.072997719689738, 0.05868711610673927, 0.010223070330539485, 0.07392244311631657, 0.057360619903192855, 0.07785610039718449, 0.006300951126831933, 0.023553607607027516, 0.01715568792860722, 0.21155324735445902, 0.11825467910966836, 0.2170251467032358, 0.15160928189288825, 0.11020351230399683, 0.11008009314537048, 0.11494555394165218, 0.1362226903438568, 0.12114557437598705, 0.1413576101185754, 0.12738078745314851, 0.0790484571189154, 0.12108860712032765, 0.12410781971993856, 0.13858565886039287, 0.19397041818592697, 0.17111430322984233, 0.14245609258068725, 0.19140429416438565, 0.20363800489576533, 0.12737945158733055, 0.16556309798033908, 0.10526449725148268, 0.09466954506933689, 0.22042648372007534, 0.06704746163450181, 0.09133078594459221, 0.11519045525346883, 0.2118415420409292, 0.10202503748587333, 0.1539710332872346, 0.1065181999001652, 0.14434864337090403, 0.13898874894948676, 0.16420685278717428, 0.13742256502155215, 0.11841128711239435, 0.08823766285786405, 0.12044189963489771, 0.10881358102778904, 0.252455395529978, 0.21521399467019364, 0.0987447818624787, 0.12745724350679666, 0.12630709272343665, 0.25066581030841917, 0.18503314931876957, 0.1448475001961924, 0.15401369193568826, 0.11067616389482282, 0.15847903123358265, 0.18108382530044764, 0.1538655295735225, 0.12882827228168026, 0.16914612759137526, 0.06212261789187323, 0.1731767613091506, 0.137271968415007, 0.15582980151521042, 0.07795646102749743, 0.16111638658912852, 0.1354529644595459, 0.10156151431147009, 0.12905870913527906, 0.19237742788391188, 0.1921410093200393, 0.13359542819671333, 0.1448352399165742, 0.12385900728986599, 0.15936733747366816, 0.23330571450060233, 0.07461065892130136, 0.18373119964962825, 0.08492688270052895, 0.17776862194295973, 0.13857926154742017, 0.09915858114254661, 0.11694509274093434, 0.21310022450052202, 0.07340636104345322, 0.18928152916487306, 0.06080752849811688, 0.17586394445970654, 0.09855465104919858, 0.16870787454536185, 0.10375426383689046, 0.14131563424598426, 0.16499897668836638, 0.13351820030948147, 0.20000390068162233, 0.10757800162537023, 0.14023448835359886, 0.08107738496619277, 0.2769091021036729, 0.15398170537082478, 0.0996532522549387, 0.17384208185831085, 0.16593178210314363, 0.14770960755413398, 0.22397440974600613, 0.16827015584567562, 0.10112272691912949, 0.11456281354185194, 0.1461242465302348, 0.12046179661410861, 0.22357975045451894, 0.08016936728381552, 0.12413285236107185, 0.14968269621022046, 0.10462236139574088, 0.16088311473140493, 0.13854752731276676, 0.10480044715222903, 0.13473941915435717, 0.14172475057421252, 0.0760100748448167, 0.18690658238483593, 0.198979573615361, 0.10275890279444866, 0.11419698668760248, 0.2476166668930091, 0.16650081641273573, 0.10895633313339204, 0.14158188714645803, 0.06581977868336253, 0.20050724007887766, 0.11014546893420629, 0.13551760552218184, 0.12300527771003544, 0.05123006078065373, 0.2564316149801016, 0.15500149049330503, 0.154519020288717, 0.10348455252824351, 0.16693420096999034, 0.14021459879586473, 0.13758622342720628, 0.10940521373413503, 0.12658458173973486, 0.14907453587511554, 0.12193790607852861, 0.102710269857198, 0.21518542198464274, 0.17554946680320427, 0.1085624827828724, 0.15674543363275006, 0.12870745063992217, 0.12046011936035939, 0.20019163435790688, 0.10783312231069431, 0.09395913904882036, 0.1710141429794021, 0.19620000792201608, 0.14575516164768487, 0.1299727233708836, 0.12473761365981773, 0.12480508972657844, 0.18837745970813558, 0.1316900530946441, 0.12749013549182564, 0.13835529622156173, 0.14626299845986068, 0.07440316185238771, 0.13565242406912148, 0.12373886842397042, 0.13394250097917393, 0.1488643596530892, 0.15006880596047267, 0.17979193915380165, 0.1549247227376327, 0.16092347272206098, 0.0988342848722823, 0.21014476980781183, 0.16309000959154218, 0.16133708646520972, 0.10931798169622198], [0.023470197629649192, 0.05341390453395434, 0.03008896004757844, 0.0741678119811695, 0.0431336340989219, 0.09669528168160468, 0.022212053227121942, 0.0349253026797669, 0.02036282530752942, 0.04918070160783827, 0.008987749752122909, 0.07700237081735395, 0.03477052036032546, 0.04253794926626142, 0.010826004090631614, 0.11820277330116369, 0.0209033797000302, 0.012333279119047802, 0.03185076297086198, 0.026503262415644713, 0.004063067890456296, 0.03331560663355049, 0.02562790108640911, 0.005405011897892109, 0.06148906868475024, 0.04060721868881956, 0.007767355618852889, 0.03474343568086624, 0.03932783773052506, 0.03337509719131049, 0.013430530543701025, 0.01857177248894004, 0.02460096908180276, 0.07593079120852053, 0.01574155336129479, 0.015002478176029399, 0.09057912393473089, 0.04239297442836687, 0.038959253797656856, 0.027519845170900226, 0.04310689080739394, 0.04060496255988255, 0.03914722867193632, 0.0067806967217620695, 0.005360035429475829, 0.03330850799102336, 0.022980701141932514, 0.039575039700139314, 0.07262520608492196, 0.062168983567971736, 0.042182505058008246, 0.05183271066925954, 0.030427937854256015, 0.021955628217256162, 0.054697716113878414, 0.009499838142801309, 0.04229893318552058, 0.03073076379223494, 0.02103032591548981, 0.027011262500309385, 0.06710540110361762, 0.022132778867671732, 0.0399908353574574, 0.02575404207163956, 0.0435943111369852, 0.018013501176028512, 0.02235304087662371, 0.10712314673583023, 0.05015907860070001, 0.01048755691954284, 0.02103968810843071, 0.03076391923968913, 0.0072583002929604845, 0.04439425356395077, 0.022089543199399486, 0.060085296354372986, 0.021888109477004036, 0.03785792890994344, 0.05199620580242481, 0.04504776283283718, 0.033190588146680966, 0.015530103428318398, 0.026930906460620463, 0.022352612286340445, 0.1091585164249409, 0.013099500210955739, 0.010620122120599262, 0.04940111204632558, 0.06366721645463258, 0.01466651998271118, 0.06029631491401233, 0.017207137316290755, 0.034474091735319234, 0.048824244368006475, 0.05408774864918087, 0.04997056566935498, 0.03620129944465589, 0.0738182604254689, 0.013324101928446908, 0.04408968728967011, 0.041616888338467106, 0.017215082007169258, 0.02229614412499359, 0.014200279620126821, 0.07429178032907657, 0.05176701946766116, 0.008877344153006561, 0.03704659080540296, 0.06412477276171558, 0.012429616381268715, 0.07911482738563791, 0.03620009345468134, 0.022059861003072, 0.03270180968684144, 0.03531304144416936, 0.017218692555616144, 0.0313596059277188, 0.08121463775751181, 0.016786916603450663, 0.05497590645973105, 0.013793589187116595, 0.0029196690275057335, 0.027728288478101604, 0.02406704763416201, 0.0750656177115161, 0.07119194080587476, 0.031521635319222696, 0.026612035289872438, 0.046327451782417484, 0.04287652074708603, 0.04139973592828028, 0.033111942757386714, 0.03048340597160859, 0.007084648404998006, 0.02748489372606855, 0.027994209267490078, 0.03135961334919557, 0.016104608293971978, 0.0745004128839355, 0.033994085461017676, 0.03479617640550714, 0.021903358756389935, 0.012260545863682637, 0.03096140659181401, 0.058392520586494356, 0.02160541986086173, 0.0300283933756873, 0.0033943684820769704, 0.04213612082821783, 0.02110465386067517, 0.010033047128672479, 0.05462834385980386, 0.03634702385170385, 0.015582321866531856, 0.030026057465875056, 0.011173194689035881, 0.055779537360649556, 0.030358450567291584, 0.024700457688595634, 0.03886136822984554, 0.03040920419152826, 0.07168083058786578, 0.035929161313106306, 0.024520820843463298, 0.14359362685354427, 0.01450329480576329, 0.0272214016149519, 0.07831477734725922, 0.03884572004608344, 0.09731369107612409, 0.061056878985255025, 0.020108389253437053, 0.03741191670997068, 0.0792935662320815, 0.05696428335795645, 0.05477152641105931, 0.006124871952124522, 0.02167568640288664, 0.10185538252699189, 0.10072512130136602, 0.030463900475297123, 0.05991275444102939, 0.031419660517713055, 0.02533401617256459, 0.03894517896696925, 0.03699705244798679, 0.07161401503253728, 0.045147826604079455, 0.04303499525121879, 0.022732987090421375, 0.045944841258460656, 0.05462432513013482, 0.01932546427269699, 0.02093650917231571, 0.032339248282369226, 0.025820757437031716, 0.019098240918538067, 0.05002574805985205, 0.02791263053950388, 0.0135479457276233, 0.026191580800514203, 0.035814321381621994, 0.031200552548398264, 0.0029563199905169313, 0.019456926456768997, 0.05210059629462194, 0.04678111552493647, 0.04670947229897138, 0.021583751004072838, 0.008700942144059809, 0.04920585299259983, 0.048064975344459526, 0.014813919788139174, 0.02636583707499085, 0.06697686112602241, 0.056398239903501235, 0.054864231788087636, 0.013575826360465726, 0.030685066049045417, 0.033097129489760846, 0.06695822579786181, 0.0376189128292026, 0.052863216114928946, 0.0052972154117014725, 0.0328304721188033, 0.08918727049604058, 0.03706783478264697, 0.041753688419703394, 0.026427066113683395, 0.0899661990115419, 0.03446462935244199, 0.05049923827755265, 0.07133942781365477, 0.03853479356621392, 0.071940522902878, 0.056464168592356145, 0.02846457875421038, 0.007865332099754596, 0.01933145340444753, 0.030912983311282005, 0.03444941161433235, 0.024966248602140695, 0.039898898103274405, 0.03376036089321133, 0.03776087825826835, 0.09332981266197748, 0.03160858163028024, 0.06167092084069736, 0.060401900263968855, 0.033496657270006835, 0.05246317996352445, 0.034040458558592945, 0.027562388786463998, 0.006434401802835055, 0.015539312553300988, 0.09629752021282911, 0.07864586426876485, 0.04507967889367137, 0.020226110573275946, 0.014987700160418171, 0.027214909678150434, 0.05811361035739537, 0.05757397993875202, 0.0489205120538827, 0.012901951631647535, 0.028144252974016126, 0.01895220480946591, 0.021449023370223586, 0.03298766641819384, 0.057740970587474294, 0.05417489162937272, 0.025314701779279858, 0.053898293190286495, 0.04524111085629556, 0.016352849270333536, 0.03563131518603768, 0.054248085943982005, 0.04321320346207358, 0.01403772979756468, 0.02111128495016601, 0.05068040765763726, 0.00937600523684523, 0.024906080834625755, 0.007872690493968548, 0.03667340184620116, 0.005251170714473119, 0.09312138048699126, 0.04556733671051916, 0.027002692550013307, 0.04114668583497405, 0.02828105862135999, 0.05399337715061847, 0.05899533745832741, 0.0344661099370569, 0.02503186187823303, 0.04048854185384698, 0.013794972364848945, 0.03394876992388163, 0.05774690776888747, 0.040857537678675726, 0.028481419940362684, 0.022090036727604456, 0.04822144233912695, 0.06109956360887736, 0.009032678444782505, 0.02990997258166317, 0.02959823345008772, 0.02837025920598535, 0.011178205113537842, 0.0799777967040427, 0.009019133321999107, 0.06411936992662959, 0.028112843428971246, 0.039072390500223264, 0.016141329761012457, 0.043392242878326215, 0.06173317589855287, 0.0458025455736788, 0.06678374687908217, 0.05968427314655855, 0.03434278354689013, 0.042554295068839565, 0.02102101938362466, 0.014318269040813902, 0.05156726670975331, 0.03354682274220977, 0.02764990469586337, 0.009113649539358448, 0.016329345453414135, 0.07261126855155453, 0.03837420023046434, 0.03138370346277952, 0.0372700032312423, 0.054757195539423265, 0.019080522142758127, 0.02290623218868859, 0.05659089772962034, 0.09334946473245509, 0.061631653807125986, 0.04419338387378957, 0.04908875322144013, 0.035191785646020435, 0.0176572461714386, 0.04576609870127868, 0.007796902373229386, 0.03464546847681049, 0.04586076705891173, 0.0332854605949251, 0.010077651131723542, 0.06294786755461246, 0.09596931282430887, 0.09163809445453808, 0.10141799037228338, 0.1864407808170654, 0.16731747571611777, 0.24158103216905147, 0.22371122933691368, 0.16455287171993405, 0.2310052199754864, 0.16888959682546556, 0.06646676076343283, 0.22830384696135297, 0.2199618102167733, 0.18197658442659304, 0.1458867295878008, 0.24216032295953482, 0.10242043892503716, 0.40425155020784587, 0.05320986958395224, 0.11724991505616345, 0.1410573668545112, 0.1151854160707444, 0.11444056697655469, 0.17389570944942534, 0.06458186151576228, 0.08942626431235112, 0.12095974801923148, 0.11439591195085086, 0.07870227491366677, 0.1125436152506154, 0.174770790617913, 0.14716895297169685, 0.09482792680501007, 0.08131862748996355, 0.087021349609131, 0.1773520396091044, 0.14223362639313564, 0.08580818306654692, 0.2036747708916664, 0.13928168948041275, 0.149744235095568, 0.18256510753417388, 0.10216033100732602, 0.09776151040568948, 0.13421179668512195, 0.144895309349522, 0.22908883140189573, 0.11084305064287037, 0.16822299978230149, 0.12360639506368898, 0.151873501308728, 0.146359819045756, 0.14174829149851575, 0.1661130739375949, 0.11030169102014042, 0.1422342794830911, 0.14472958777332678, 0.1014088025840465, 0.26108244666829705, 0.19929005851736292, 0.15346781263360754, 0.1346981557435356, 0.090458168706391, 0.086767052707728, 0.13737005065195262, 0.13797078951029107, 0.13548012706451118, 0.16344171337550506, 0.1547719442169182, 0.1718867602176033, 0.1795788833987899, 0.17001144209643826, 0.11353038222296163, 0.14623449998907745, 0.09990864011342637, 0.15993583743693307, 0.1539124926785007, 0.11005775450030342, 0.10604560768115334, 0.1875079149613157, 0.08761171324294992, 0.12470469198888168, 0.16618800116702914, 0.19061423343373463, 0.14044089446542785, 0.1328895121696405, 0.10415241122245789, 0.1851077945320867, 0.15596893936162814, 0.18039313814369962, 0.14741129387402907, 0.1104106308775954, 0.167026657727547, 0.09441607195185497, 0.1292952909716405, 0.12119129067286849, 0.14338445995235816, 0.14868149446556345, 0.13916414813138545, 0.13777455082163215, 0.17803079303121194, 0.15556856553303078, 0.13113442197209224, 0.15730508719570935, 0.21522149036172777, 0.07025383645668626, 0.1884309240267612, 0.1348208772833459, 0.12519980838987976, 0.10566840370302089, 0.11625428684055805, 0.11301939128316008, 0.2569988532923162, 0.11214755330001935, 0.09318386932136491, 0.16484631691128016, 0.11099654162535444, 0.11315515235764906, 0.12292053928831592, 0.17612005962291732, 0.07799483748385683, 0.12067676711012609, 0.09689367259852588, 0.10790950414957479, 0.16731741634430364, 0.1349676147219725, 0.15578821155941114, 0.17399778444087133, 0.25420089717954397, 0.15684606885770336, 0.1339469093363732, 0.09110129161854275, 0.11685012010275386, 0.17612377036130056, 0.11978528447798453, 0.19158298848196864, 0.10335306622437201, 0.11121841409476474, 0.12037371110636741, 0.14574759174138308, 0.1714684857870452, 0.13140135764842853, 0.22503587388200685, 0.18891035142587498, 0.155766511161346, 0.18879560055211186, 0.21076691220514476, 0.13195278821513057, 0.13168448698706925, 0.07976542372489348, 0.2002649733913131, 0.09310400680988096, 0.1300987697322853, 0.12788538850145414, 0.088964930473594, 0.19203327916329727, 0.18306688842130825, 0.09544762011501007, 0.1270000360091217, 0.07896193012129515, 0.11701748182531446, 0.12014614636427723, 0.1667471500695683, 0.15292675729142502, 0.2701280394103378, 0.19796888722339645, 0.24105294956825674, 0.04958264878951013, 0.15387734456453472, 0.13355699979001656, 0.1308090941165574, 0.22470823052572086, 0.1486642172676511, 0.10799774550832808, 0.09406550365383737, 0.20307379454607144, 0.18461760599166155, 0.2227435726672411], [0.027595449610089418, 0.06581346300663427, 0.07804116976330988, 0.04511367667873856, 0.03060526847548317, 0.045194863923825324, 0.03561335150152445, 0.07009201115579344, 0.03458514671365265, 0.1276865226100199, 0.03777217003516853, 0.004858558359046583, 0.052032151725143194, 0.08631855060230009, 0.0871485834068153, 0.07556302734883502, 0.030399973729799967, 0.0698654112056829, 0.021573318263108376, 0.07819227103027515, 0.04045636975206435, 0.004227400258969283, 0.03750250325538218, 0.020924226628267206, 0.02867016850359505, 0.03420328575884923, 0.02763681135547813, 0.047510798831353895, 0.012755071329593193, 0.06356134166708216, 0.019490996601234656, 0.03453101446211804, 0.07675222994294018, 0.04599044252245221, 0.0049744989883038215, 0.044342974870232865, 0.027498456474859267, 0.034945400038850494, 0.031618018037988804, 0.030788976000621915, 0.016505833737028297, 0.09142212948063388, 0.08680710641783662, 0.05930283521593083, 0.08536088324035518, 0.00241867829572584, 0.0836170143156778, 0.06604301670449786, 0.04354712909844238, 0.02583902169135399, 0.05052744731074199, 0.07044500627671368, 0.06876282466691919, 0.04463516583200544, 0.03721681350725703, 0.07792818520101719, 0.027705192842404358, 0.015525477992923697, 0.038892464217497036, 0.03512385315843858, 0.009915047503454844, 0.017231405545317102, 0.010846044860954862, 0.06104116400820203, 0.018789624373312108, 0.05541316873859614, 0.02526629890780896, 0.047003626241348684, 0.0674433380481787, 0.05224440224992577, 0.04050416777317878, 0.022456650258391164, 0.03002810393809341, 0.03407297204830684, 0.009207816947309766, 0.05822549283038825, 0.03345841440022923, 0.03698885913763661, 0.03763420849281829, 0.015773690211062785, 0.03060524250031449, 0.053492497972911224, 0.028135039210610557, 0.037283458368619904, 0.04908974027785007, 0.018208155379397795, 0.10732071386883035, 0.03988832249888219, 0.0388280903280247, 0.015716210873506498, 0.0397702468035277, 0.02031607371463906, 0.04218923633743543, 0.024013271613512188, 0.0787902862066403, 0.03735698664968368, 0.01216126784129301, 0.05799295940960292, 0.018335663771722466, 0.04641790845198557, 0.022736623614036944, 0.051548735282267444, 0.03662732931843493, 0.04293550293368753, 0.027941162406932563, 0.028988525737076998, 0.02707407602429157, 0.04592832476191688, 0.039721276189084165, 0.009914591082633706, 0.02305115878698416, 0.03206023044185713, 0.05158698186278343, 0.05057157170085702, 0.043939372699242085, 0.03304856705653947, 0.03607836268201936, 0.0541280212928541, 0.036687673346023075, 0.03338725357025396, 0.019170915729773697, 0.025248118145100307, 0.034280680629308335, 0.02715673643251648, 0.03600799223931972, 0.014529589097946882, 0.042817401263164356, 0.025882906738843303, 0.03840336292341817, 0.05602784141956363, 0.021096614545967896, 0.03453899254964199, 0.06405150794307701, 0.052814453301834874, 0.016925271484069526, 0.012988692924409406, 0.05283157093799673, 0.0137385459493089, 0.055936419958015904, 0.05483802284288686, 0.057956634991569445, 0.029231740518298466, 0.025078227554331534, 0.024704552488401532, 0.0780688964005094, 0.04752428736537695, 0.04689400731876958, 0.02002753783017397, 0.04653185038478114, 0.05405881973274518, 0.02914338041591691, 0.051163876050850376, 0.0668201269581914, 0.06594393998966552, 0.021686801919713616, 0.06150890258140862, 0.07009137290879153, 0.05664212447300088, 0.02743231441854732, 0.02732829685555771, 0.027724253050109837, 0.0322471403342206, 0.10512785302125849, 0.06204629913554527, 0.04674109892221168, 0.09555623342748731, 0.022558782766282093, 0.008103932577796513, 0.07296355863218196, 0.043395972170401365, 0.029409601775114425, 0.07567774853669107, 0.02721883007325232, 0.0088783757382771, 0.049053152397391386, 0.04410784393257927, 0.014610056459787302, 0.035490236623445526, 0.049706810095813125, 0.026944552701024804, 0.09152114682365209, 0.032367820967920125, 0.05662298448442016, 0.12177138298284262, 0.029475003539118916, 0.07486436210456304, 0.05054103232396301, 0.0640878509148024, 0.018706513110373635, 0.03873293586366344, 0.06404824991477653, 0.08993081341031939, 0.05457596307678614, 0.04555421182885766, 0.027483695157570764, 0.057076629673247226, 0.03492023752187379, 0.00476455375974183, 0.022209900998859666, 0.017453456130169798, 0.04514906970143784, 0.036092997834202833, 0.0809495203429833, 0.04200509465590585, 0.05519994600035716, 0.03470242831099313, 0.021493975254998077, 0.037310646948753856, 0.0391447090805741, 0.03856483941490296, 0.06454216403653845, 0.05616582893708255, 0.0653995449829381, 0.08353097713552415, 0.027978056423307862, 0.03493080199405085, 0.016066805146692786, 0.02122456451616017, 0.02612127900647465, 0.0306321082462091, 0.12422946514561772, 0.04143217520322651, 0.021944742766208947, 0.02211318616900826, 0.07778402301482856, 0.058918591967085376, 0.006781078000130947, 0.08071166201261804, 0.039932751169544645, 0.04369849011709448, 0.07209776173112914, 0.04346742614870891, 0.055776438894099556, 0.04980137455277145, 0.010017765380325727, 0.017295777579420246, 0.02519590805604821, 0.011113285745523171, 0.03987399162724614, 0.054945463562035, 0.02068094319838565, 0.04978286910045426, 0.029440267317113467, 0.017824029018811416, 0.06203066208399832, 0.033058318877010606, 0.049478499495307915, 0.03453394223470241, 0.05611738524748944, 0.01790982685633935, 0.03657115616078954, 0.025381910672876984, 0.019517470864229836, 0.04498401234741323, 0.04299685257137753, 0.032671010558260605, 0.0723073590779677, 0.06688559922622517, 0.01761235180310905, 0.010580593479971867, 0.031352744772448204, 0.10006066906498745, 0.03252412840083707, 0.07838249090127647, 0.06882785906782374, 0.1071951276389882, 0.03197347708919551, 0.04692242044257, 0.02570327174908016, 0.058685197654995136, 0.052715591809828766, 0.026164336559304502, 0.02683007642190205, 0.01745068235322833, 0.017005646077450365, 0.03399110573809594, 0.02308424373040907, 0.02470429644745309, 0.027940993568336125, 0.08701852202648297, 0.013833288521709619, 0.026816355966730043, 0.0753146898932755, 0.04178424635028932, 0.058665530741564, 0.04831484904570971, 0.021058479287603404, 0.0554835132061271, 0.06330360862193629, 0.06505743716843426, 0.014990082454460207, 0.03290638269390911, 0.040098023746395484, 0.06908804120030254, 0.03567262683645822, 0.012671861732087564, 0.03373370294866618, 0.07013400187133811, 0.050267929400433786, 0.039233362331287935, 0.04156799193879124, 0.02760978419246385, 0.03311297434265725, 0.036918496116413735, 0.06816618246375583, 0.016034800028137397, 0.07648891594726592, 0.029584535259346012, 0.007827643057680689, 0.039004443169687875, 0.01283277048059972, 0.016442862506664824, 0.04723993348306976, 0.01083971990738064, 0.08420665064477362, 0.03470678842859343, 0.054882291951798834, 0.02568106669059489, 0.044382772539393045, 0.0380615074391244, 0.09776560706086457, 0.03772516611206811, 0.025190692613250576, 0.019974444585386664, 0.01377844751914381, 0.03990435659943614, 0.015448365138581721, 0.016787100285000633, 0.045349649954005145, 0.09592695103492588, 0.030656682611152064, 0.05237530967860948, 0.053938539858791046, 0.023561097732454073, 0.047761934183654375, 0.017099355209211353, 0.018795437244989444, 0.03310539330414031, 0.054986767790978774, 0.09283603212679736, 0.04043925953737926, 0.05658913141814992, 0.021651349525200203, 0.03541632984706666, 0.0705620578082744, 0.028200539309182204, 0.06259408575715497, 0.05512191288289614, 0.015926795276755, 0.011359037744114175, 0.07422227819915861, 0.029856194705644157, 0.09657981834607199, 0.09132309729466215, 0.13974850036902353, 0.08497072878526524, 0.10752709029475227, 0.26938942435663193, 0.1927372210775502, 0.35928838478866965, 0.13429904356598854, 0.3018048615194857, 0.11463004469987936, 0.09781448490684852, 0.17438316688640043, 0.19162793294526637, 0.2991479728370905, 0.151333351386711, 0.1292904670117423, 0.11763343471102417, 0.07633319110027514, 0.14461225422564894, 0.15366323495982215, 0.07146892516175285, 0.06239675611141138, 0.10702932442654856, 0.13597914716228843, 0.17928843648405746, 0.1728956654551439, 0.12237674542120658, 0.13124529883498326, 0.14902887895004824, 0.09833853764575906, 0.1447123847901821, 0.14332247577840462, 0.32467648736201227, 0.17820623674197122, 0.17644960287725553, 0.1447649288456887, 0.17386154097039253, 0.09054837675648741, 0.10316708401660435, 0.12313156898017041, 0.1306350901722908, 0.11137488851090893, 0.20743584173033014, 0.3365855826996267, 0.1289736886974424, 0.260905756149441, 0.19956563279265538, 0.1820604471140541, 0.1174473857099656, 0.13403831224422902, 0.19114194496069103, 0.10216468741418794, 0.18465906236087903, 0.15624853607732803, 0.18952113896375522, 0.11707393699907698, 0.08634340512799099, 0.0844700908055529, 0.1818487569107674, 0.1414949371246621, 0.08770410320721567, 0.09925489706802182, 0.10482294906978495, 0.11278015255811624, 0.11099184383056127, 0.10046326933661476, 0.17273096804274246, 0.14510981971397996, 0.19300684332847595, 0.18454068980645388, 0.12481139798182994, 0.1381006059818901, 0.1033794273098465, 0.12604848394403234, 0.11513736200868152, 0.09553266281727701, 0.16240292927250266, 0.14644380047684535, 0.11634494017926045, 0.1565676150494255, 0.12724487052764744, 0.10118926045834087, 0.1129307046358008, 0.14728735521202907, 0.11167655669851229, 0.1529737500823103, 0.15141204872634262, 0.22414608334656805, 0.16764102241722867, 0.1460232402314432, 0.17350151028949767, 0.10738904340541922, 0.14475017494987696, 0.13672215573024005, 0.16295115376124159, 0.0939083167759236, 0.13601574988570064, 0.13252596370875835, 0.11459019136964343, 0.09510992065770552, 0.1353818370262161, 0.10586433068965562, 0.23072554904501885, 0.14394464786164463, 0.09450488476431929, 0.11961689859163016, 0.14069104276131839, 0.14737495832378045, 0.08320510751218535, 0.08457093383185565, 0.13179545290768147, 0.13964890415081754, 0.1333315798547119, 0.16654314851621166, 0.10453334078192711, 0.26063027093186975, 0.14648488577222452, 0.164289646781981, 0.12424884262145497, 0.10352460623835213, 0.1511012075934559, 0.07739561260677874, 0.08617308965767734, 0.11882739447173662, 0.10776313778478652, 0.20145034650340676, 0.1827578284428455, 0.12119901643018238, 0.14893315674271435, 0.16902511299122125, 0.09546065222821198, 0.1510088992654346, 0.1650834479369223, 0.09388349935761653, 0.15845676680328324, 0.13664394820807502, 0.09610569730284624, 0.1995586120756343, 0.10932429737295024, 0.146925201988779, 0.10865637930692174, 0.07136874264688231, 0.1370905281510204, 0.18229861714644358, 0.1513918474665843, 0.14830069849267602, 0.09393380212713964, 0.0863073070649989, 0.24515744182281196, 0.16612494830042124, 0.08324244496179745, 0.12399435276165605, 0.13694917870452628, 0.1748353723087348, 0.15351821930380538, 0.28265219705644995, 0.07968154619447887, 0.08346296672243625, 0.1608789141755551, 0.14081063243793324, 0.15804530528839678, 0.21812281280290335, 0.25714544230140746, 0.18239410186652094, 0.21512300736503676, 0.13705272314837202, 0.12805192644009367, 0.11217985898838378, 0.08448590597254224, 0.12008438483462669, 0.12978258513612673, 0.12480877077905461, 0.07786907313857228, 0.2774110314203426, 0.241846721037291], [0.01990434688195819, 0.027556301320146304, 0.03477548903902061, 0.018722042550507467, 0.024029713895288296, 0.01735811983962776, 0.022301819699350744, 0.04937220168358181, 0.028607943131646607, 0.04218008565658238, 0.034790087083820254, 0.02722312154219253, 0.017494684288976714, 0.021061488696432207, 0.05331161060894374, 0.014278086382546462, 0.020530769616016187, 0.04985512459825259, 0.0700639579736162, 0.012751720532833133, 0.05021544471674133, 0.049310907706967555, 0.021696277290175203, 0.021502086929103825, 0.025660247592895757, 0.02533896444219863, 0.006854345601823297, 0.012646046125155408, 0.055581866326974705, 0.018836418639693875, 0.005746735650973278, 0.05426812022051308, 0.0191348176667816, 0.01640310751099605, 0.020189110800856724, 0.057490421531838365, 0.05171345495909918, 0.026637804512574803, 0.08406899709370919, 0.031064785907801706, 0.06585325696505606, 0.017489005003881175, 0.04048985916597303, 0.07982946364791133, 0.10255078974296339, 0.030426201228692662, 0.06500038085505366, 0.051241081673651934, 0.04111950838705525, 0.041192376156686805, 0.014818984018347692, 0.01105097595427651, 0.016275877424050122, 0.018443271474097855, 0.03647518162324559, 0.09994824111345224, 0.059138030192116275, 0.0266254774396657, 0.00871129510414903, 0.05627272417768836, 0.03928457052097656, 0.029605448980873916, 0.023456705384887755, 0.05731443234253675, 0.07496848542359658, 0.03427329254918732, 0.07093278283718973, 0.015776968648424372, 0.012677685735980049, 0.029760355610051192, 0.024982212198665366, 0.06980146776186302, 0.06826562283094972, 0.027640188127406873, 0.035351403057575226, 0.004178469534963369, 0.023646134868613444, 0.05796575598651543, 0.00739976848308288, 0.011366093713149894, 0.020321630545367952, 0.01330416042037541, 0.04493471889873035, 0.030765208721277304, 0.012735723539663013, 0.05528992769541219, 0.03288390304078348, 0.07934409164590761, 0.03200609076884575, 0.060134975719847716, 0.04335778496169951, 0.09205323702190071, 0.035932441605837084, 0.0428877049125731, 0.042364991750218906, 0.05025945407396648, 0.03526758118823636, 0.0443006501882337, 0.0030992339770818944, 0.054794755633338355, 0.00527529422470252, 0.019580312218749896, 0.059372600808274, 0.03968144141254015, 0.02487907222530339, 0.0063472667079622624, 0.06219962684554048, 0.04904953813820612, 0.035434519886621274, 0.04707448650151491, 0.057699477110872976, 0.045930495543871075, 0.062131939266691916, 0.03736830440175254, 0.01713799141725758, 0.038055421828175895, 0.0251327679870883, 0.055671217196504585, 0.038249819990596734, 0.04017414583358914, 0.0130555325995374, 0.037839757424080744, 0.012529294235719135, 0.09238229045877233, 0.028430180209397804, 0.06408067434676923, 0.05049457016866654, 0.04985701336408965, 0.03367610486748163, 0.06803145297453739, 0.038755166897317395, 0.0777850100712385, 0.013537452687160112, 0.06872941317851655, 0.002093000239256071, 0.02514449392037932, 0.05330616324499715, 0.054271563785732724, 0.023724856328044552, 0.06951318791834638, 0.058279068471165374, 0.0036734343302669004, 0.03253471513744444, 0.07515713936300017, 0.02554476941440953, 0.011871180868183728, 0.04999091164791025, 0.007975255302881123, 0.06617085906327702, 0.0483287049428327, 0.006397226234184927, 0.01611046383914072, 0.023923965272842906, 0.03360742281074636, 0.04408968728967011, 0.023127189961087424, 0.05970536498352885, 0.08083566746790893, 0.08072571086813696, 0.03444653579208534, 0.032925073683145456, 0.058967236036551185, 0.03394072875380516, 0.04540338515653275, 0.012463809907785617, 0.04371975635876879, 0.019948972221754957, 0.05531179878744297, 0.016988320639939047, 0.06459381751483306, 0.07492588614695705, 0.06596896520932205, 0.02350166283576982, 0.04947255118167959, 0.01717871862638276, 0.021732369787059724, 0.015533682435489027, 0.026729155470093247, 0.019234799801779445, 0.02773394178802846, 0.04743486599181779, 0.035173217111150734, 0.037986027309671044, 0.03916390101949219, 0.021491474217327777, 0.04098781799257267, 0.018986885370395612, 0.04667442808568012, 0.025268016979680397, 0.02933888437837595, 0.07267488545039669, 0.022557209413207602, 0.06132243055617437, 0.04463666497031227, 0.03789427559240721, 0.024245296663139015, 0.013990946663398063, 0.042431629190105014, 0.01968920940271346, 0.016672432902851142, 0.024100286573229823, 0.03494334428978618, 0.03905094614310656, 0.01728851751977345, 0.049071869361796416, 0.027793838671641424, 0.03908261358446907, 0.060667782090604305, 0.016468917456222698, 0.028783004636352416, 0.031842462049098685, 0.031623149989172816, 0.03251531168643851, 0.03718987725733314, 0.08205386577174067, 0.037862021854380146, 0.06468863430200145, 0.02564446953329025, 0.04230077000102028, 0.07887883926741779, 0.027549197111511603, 0.018424791996949352, 0.056661839626030996, 0.04251931022736244, 0.05661939620040357, 0.04281734931282699, 0.03885745711158961, 0.028020436766382772, 0.03439114188950043, 0.03650771737738978, 0.023384869200526737, 0.04971756752638612, 0.009440111953153973, 0.0324678624747321, 0.023947370755195152, 0.061968202935531735, 0.08498958675772883, 0.0512236263602972, 0.01885881294583669, 0.0329588376916945, 0.0650186080019921, 0.04775817891641054, 0.03526749584125355, 0.016575996378378477, 0.016603927106189076, 0.06429549641325139, 0.017770401427696925, 0.052924829215044156, 0.049808736657723784, 0.07107121564331464, 0.03237250020902138, 0.053667103056795895, 0.041627397149568424, 0.055753187407390215, 0.022554886490979698, 0.03648628044174984, 0.05127093827468343, 0.05489119401318021, 0.017295807265327312, 0.026389311206003185, 0.06293585960520431, 0.027770689230237622, 0.02754387962340843, 0.017343341824016534, 0.03291646105935797, 0.019759769093070645, 0.056970502555486746, 0.06461470897193067, 0.014820608394074952, 0.044979626254644245, 0.035309505110490136, 0.013075598417344736, 0.08036531653488055, 0.10939290892565623, 0.040406159751000814, 0.08637831575470045, 0.03264805221988354, 0.006774958992536995, 0.05033449633629061, 0.09886613785056397, 0.02296704005857464, 0.04280006469343789, 0.025101120954786893, 0.1001789525616914, 0.025426200190850068, 0.0356126093538478, 0.01795584372302983, 0.13751077669439837, 0.013904274946980877, 0.021644200787704904, 0.037156766338739544, 0.03585208556614816, 0.020025595258630347, 0.01982692974706879, 0.036172893742332235, 0.032691976230125874, 0.04772979547851719, 0.04364927088317927, 0.0887243336183019, 0.04469302366487682, 0.010009509915107628, 0.011189516371814534, 0.04088434776349459, 0.020575209418893792, 0.019014715908269864, 0.04624177825462539, 0.026424275638419203, 0.046035739505896345, 0.036550260992953554, 0.019769296413869597, 0.03604109944717493, 0.013426743735180935, 0.04681866448663641, 0.0074904473331116606, 0.020914767956128344, 0.0061628847561223665, 0.062369600927922875, 0.003782649246204528, 0.06534657048177905, 0.03262647056544665, 0.023628531125723384, 0.009566226035531145, 0.029042756323178764, 0.04405852079798933, 0.04420884280989412, 0.04553381018922664, 0.011413708980398951, 0.024017707801249344, 0.02681299032701645, 0.05899642099393532, 0.039158802464953624, 0.03886687867634464, 0.07343992838286795, 0.030192400590749457, 0.036059664271306247, 0.027782424440374598, 0.06676991324638948, 0.030743727256776765, 0.0016145761310326634, 0.05304746540787164, 0.029570861188403796, 0.045776410843245685, 0.0868325398187153, 0.04424023936735466, 0.06806516132201068, 0.018333674815949053, 0.035726785063161515, 0.03566134619177319, 0.014408984534384217, 0.0342349420679966, 0.004723442953036283, 0.023820005226298235, 0.12845135031966493, 0.10936947932350449, 0.1298405320267193, 0.0677522570185829, 0.23677659075474367, 0.08390797331230715, 0.20180688909022138, 0.1852208681521006, 0.09907252169796266, 0.15651774272555485, 0.18342846276937053, 0.14768697204999626, 0.08274762541987002, 0.12039074339554645, 0.14192282978910953, 0.103491306072101, 0.10180667537497357, 0.10422748688142747, 0.18731023650616407, 0.11133936190162785, 0.10955943944281898, 0.08565660682506859, 0.13645002502016723, 0.06553659739438444, 0.17738356604240835, 0.12002878313069232, 0.12118779515731148, 0.08309898781590164, 0.20393768412759528, 0.06868987155030482, 0.13083490601275116, 0.1826502021867782, 0.10102055544848554, 0.0739535316824913, 0.09708246012451127, 0.09365217192680575, 0.13238609855761752, 0.09994530963012949, 0.17798911401769146, 0.19143259967677295, 0.2235884335823357, 0.09202703178743832, 0.1513221746427007, 0.20250921312253922, 0.13696259673452005, 0.17113337642513216, 0.10706372297136113, 0.11515066129504703, 0.12655217957217246, 0.10583661889540963, 0.17395217204466462, 0.16795753355836496, 0.13039485696936026, 0.15246031747665256, 0.12002689065411687, 0.17036672303220257, 0.14290212333435193, 0.14159689337247983, 0.2286597216152586, 0.16537708608666435, 0.20565618644468486, 0.13155217689927667, 0.09670528583228588, 0.11975081913988106, 0.14690164622152224, 0.10614569371682592, 0.16646977979689837, 0.15060582401929423, 0.09625198203139007, 0.15185003459919244, 0.10559044108958915, 0.21268389449687675, 0.22918064991245046, 0.13044600578723475, 0.12083219509804621, 0.06564314011484385, 0.12135485259932466, 0.19575875659938902, 0.09051809713128023, 0.17110904882429168, 0.14669427531771362, 0.08663896544021554, 0.17231827456271276, 0.10926767892669886, 0.21448357292683795, 0.11143238269141875, 0.13835968973580748, 0.1532012183452025, 0.14802303136093542, 0.12402838765410706, 0.17005181493004784, 0.20490614231675863, 0.14064265473280102, 0.16859011055203155, 0.16206363419769332, 0.11347275445587002, 0.09825577333685942, 0.15721990348538384, 0.11532490272657014, 0.14118633727775887, 0.13547929585911334, 0.10621114372042939, 0.1413411195972003, 0.283097485662438, 0.21171745494939387, 0.1486551482230425, 0.1822261538472958, 0.22213958320207894, 0.14266263227909803, 0.09609938904759474, 0.11359953554347157, 0.2380529511719942, 0.19453219429124147, 0.11583745217649266, 0.08342916931724176, 0.15015664655948058, 0.13783828646410257, 0.16641671623801813, 0.13395162939559668, 0.12749019486363977, 0.15398679650388658, 0.1150747766951099, 0.1489867694908753, 0.14355334307765588, 0.10513748609810136, 0.19540516776032746, 0.13204398332163692, 0.10606877011014149, 0.11327577361953445, 0.246167445438914, 0.08855881984345615, 0.23124122293666005, 0.09807192109292373, 0.1318106520920992, 0.18371761834714562, 0.07588916414533742, 0.09815790632274002, 0.16810661618364975, 0.07644933721167035, 0.10845288983546197, 0.14987886068411171, 0.04754400251840707, 0.11076038281316869, 0.19254435173934326, 0.06997171643888578, 0.08264475633041002, 0.24602191027952358, 0.20019659190438688, 0.14937397761968896, 0.13934964052168652, 0.12525475700385869, 0.16462564672110602, 0.12943785754032433, 0.15934047172777355, 0.1347037812229246, 0.24530674709239975, 0.11778351923567243, 0.13345793791813776, 0.17090806039050221, 0.09244607063010335, 0.19353492592927068, 0.15051338210469112, 0.11179347464349121, 0.16088115546153858, 0.11894197465153411, 0.10738165903603658, 0.17922363214893267, 0.16112125507788733, 0.1397568717948161, 0.07160765482694842, 0.18298836919711903, 0.13258027407573536, 0.14970163581892848, 0.14699824416311458, 0.14368142292369157, 0.11298292956780642], [0.050630665209610015, 0.04619397281203419, 0.03315601890790276, 0.05177270431886427, 0.13364460290176794, 0.03456774335063528, 0.03215965967683587, 0.0405969176790677, 0.01116958970669657, 0.0917846686206758, 0.07575096882646903, 0.07435608000378124, 0.032329284949810244, 0.010606658634060295, 0.024117148168443237, 0.08449453715002164, 0.028788797098968644, 0.050891682258225046, 0.03509483147354331, 0.0301762570234132, 0.02340811141039012, 0.07528625821578316, 0.053990330634405836, 0.05028744417359121, 0.008272362065326888, 0.032030422080424614, 0.02908611630118685, 0.005268834293019609, 0.027543475152924657, 0.07904912505182438, 0.033756446064217016, 0.008440583751507802, 0.04534363484708592, 0.010555881817708723, 0.04200322073302232, 0.020951942133251578, 0.03390032252355013, 0.01250061022801674, 0.03688193050038535, 0.017053199189831503, 0.05283987928123679, 0.05145163639099337, 0.03612041276937816, 0.018037153422483243, 0.08798250506515615, 0.020677575703302864, 0.045073359506204724, 0.01946671909536235, 0.07173016114393249, 0.04253611987223849, 0.014745852786290925, 0.052364411239977926, 0.0403626736078877, 0.017450953237130307, 0.04383580970170442, 0.02468202459567692, 0.04165802929492202, 0.007715718375038705, 0.03807911489275284, 0.00442063464106468, 0.04770240280777216, 0.028774462516594213, 0.011066823590226704, 0.05821162209031172, 0.01917266534292139, 0.012584446940309135, 0.02960291825729655, 0.046271749888546765, 0.04621926891559269, 0.05764882924268022, 0.020166332433291245, 0.03716405051818583, 0.036759398208232597, 0.06115680174843874, 0.02072502491500927, 0.022696187697874848, 0.04109141809749417, 0.061395172160700895, 0.024837068522174377, 0.017794868181226775, 0.05141550493135583, 0.02067845514829969, 0.09898054733639583, 0.008076269023149507, 0.052139199106022716, 0.030531382108165417, 0.0279121833955287, 0.012084601203241618, 0.057211641178582795, 0.04459380223124754, 0.07337035203818232, 0.04674260919273365, 0.032267074420815334, 0.013056865682301577, 0.05301125973346643, 0.020522387058008462, 0.04419923199748155, 0.02022721637331415, 0.010624353290040744, 0.036169324012007564, 0.048177343924180605, 0.04720748678664677, 0.044226127429283224, 0.06928957882337272, 0.014396971018868499, 0.03851127861707937, 0.024020483433560003, 0.054099589615361765, 0.025159008473565336, 0.06177358955028467, 0.025427424734516535, 0.04609806877851952, 0.022835856179881375, 0.05690545331162866, 0.010957777976727812, 0.021647453249897808, 0.04386903194244951, 0.03348817081132438, 0.03101554626482539, 0.06173256362671964, 0.08567582102841698, 0.03428347481531091, 0.059411244437796995, 0.05331937347364146, 0.03899389354046434, 0.0016516756295459345, 0.06678452613414265, 0.03530127098201774, 0.057979712073574774, 0.13440505194012076, 0.026050543056044262, 0.026105513934453484, 0.024749344811425544, 0.025821861381700728, 0.008997541463031666, 0.007073723063513171, 0.025432970433030277, 0.13377703173318878, 0.0672288128407672, 0.010871816866711015, 0.01748925362335285, 0.014472717393800849, 0.040725646904320456, 0.03366332879522815, 0.025060410443984438, 0.03531789880071301, 0.06953878459171392, 0.09229485061950982, 0.021701687546737958, 0.026518530248722527, 0.03577572599169798, 0.03820546182396356, 0.044042171284672804, 0.005893780617043376, 0.02429182375635719, 0.007283091736098868, 0.02519822355679935, 0.10942240929580294, 0.04630696108506527, 0.03755898811505176, 0.036953588569303975, 0.016022977615648415, 0.005410260273492895, 0.01696478528174339, 0.06418737291824073, 0.012216391787660541, 0.04327611532062292, 0.02470642084517749, 0.042593194739311, 0.09257380908820778, 0.027895284692931455, 0.0407606057706289, 0.05163678368262481, 0.044499812938738614, 0.03722986046341248, 0.05230323971773032, 0.029580783702840563, 0.02149090276361676, 0.06454659465816803, 0.023127972926886287, 0.057138528500217944, 0.06689008921966888, 0.01920479477121262, 0.05344102261005901, 0.0617124106065603, 0.06461488708737306, 0.03150089971313719, 0.01999412263103295, 0.050407334420015104, 0.0476971261377912, 0.05071858373412397, 0.040210154838860035, 0.016864543395058718, 0.05315146627253853, 0.05566261570493225, 0.06084358203224838, 0.06215871595486533, 0.06520914699649438, 0.0730833932175301, 0.14624474162701517, 0.024483351662638597, 0.011065987746405881, 0.020859303549514152, 0.009950663170457119, 0.08438683667918667, 0.01409072470778483, 0.025160956611216534, 0.039337493071798235, 0.008929815849114675, 0.022739972555427812, 0.016634466483083088, 0.03936790628358722, 0.03439233303652145, 0.029680958796234336, 0.07084703509462997, 0.041125712741632015, 0.019643402192741632, 0.04120965335459914, 0.10281558803399093, 0.01373880941173411, 0.02248575914563844, 0.011142213734274264, 0.02203293588536326, 0.01980466902750777, 0.012902221587864915, 0.0302863193792291, 0.01375276364342426, 0.03314703149953857, 0.02745177538599819, 0.03678316548757721, 0.020399290733621456, 0.040883609326556325, 0.056346334094996564, 0.050787458749255165, 0.02182419386372203, 0.02049935450486373, 0.02214093692600727, 0.036690025954158045, 0.0068192438720871, 0.027029027660319116, 0.05587810570432339, 0.015713784050603863, 0.015534823487541871, 0.014047603144717868, 0.01935253596457187, 0.05962404415186029, 0.03396014704776462, 0.03559856049832888, 0.0401643049553968, 0.065862919727806, 0.027243781078141183, 0.04464848738280125, 0.06030343211023137, 0.030585419735871255, 0.028918127463839483, 0.024627923885418568, 0.05527822773728985, 0.051184930780436844, 0.03542979611665942, 0.015420409363287035, 0.05327547543856781, 0.01844892107328633, 0.032480857480550185, 0.024262566439574584, 0.03605703706853092, 0.03870822234603111, 0.09770181204658002, 0.0065451075079181464, 0.023859112698119134, 0.03146320232190192, 0.0365063629578799, 0.020258965450921096, 0.07189449490397237, 0.009237065914931009, 0.018216890457551926, 0.05347318357962649, 0.013627027128677582, 0.05113810497277882, 0.0045974958538863575, 0.003828208300546976, 0.026958013404509984, 0.04446888022357598, 0.0268371917627519, 0.06490510393632576, 0.015213583010336151, 0.026082204931299202, 0.029973999517096672, 0.04973765004251618, 0.032294493066729046, 0.030664788719150238, 0.023100070029613562, 0.03285778686404228, 0.04455818285350688, 0.03279496777395252, 0.05004281374567654, 0.043638569113682024, 0.06991409609327093, 0.05762390050222166, 0.014546562015311792, 0.049323876737616956, 0.04386588894703891, 0.03889720654115081, 0.0874935781757813, 0.03946640412323177, 0.02398218490270665, 0.06436340292566456, 0.03780545906920452, 0.003227893394068815, 0.05124682960740756, 0.03677984437672421, 0.06229108170373365, 0.005795342613055254, 0.0608651340007782, 0.03972476799390279, 0.0663574572536163, 0.07407073906506412, 0.02504503499949351, 0.06744596525095403, 0.0038200091921680723, 0.008634212863398716, 0.04197438458504621, 0.010307450666005025, 0.017311110350419767, 0.10783779784105718, 0.03965454227000009, 0.07303876045625657, 0.018541696954343934, 0.04389957131934352, 0.01705172602669336, 0.036355450938572176, 0.04312151111662388, 0.06456174931372516, 0.046286002834676765, 0.04849841556278989, 0.04164475227298681, 0.015619269688613713, 0.01919929731229786, 0.023207879967230838, 0.07328248175326735, 0.05032740882597864, 0.06184368539834395, 0.07239895494421944, 0.03356668632477522, 0.02686530802748166, 0.05465524300234392, 0.054108929543872364, 0.0032210136851063, 0.02048208101768978, 0.02018693816353334, 0.08248894242569804, 0.05320285628840793, 0.014666907754872227, 0.1414566274615936, 0.13300139835337177, 0.17791429068893194, 0.13151017134077847, 0.19777077832259238, 0.14983314438723028, 0.10726441454607993, 0.10412836563773453, 0.08530239458195865, 0.15587345464155078, 0.2162634805426933, 0.10107577865710482, 0.12933604972204193, 0.12179048586403951, 0.08300702087581158, 0.22556544077815488, 0.1347813950269483, 0.18970732897287235, 0.1806749019306153, 0.140075460949447, 0.13387440150836483, 0.19164362194715068, 0.1293890835950151, 0.31556692149024457, 0.18359915673499927, 0.13166176242521033, 0.15204337891191244, 0.10250991967041045, 0.32106582017149776, 0.1232860321761109, 0.1734619538183324, 0.10539909315411933, 0.20815314230276272, 0.1518101367400959, 0.16181465849513188, 0.1350353579618968, 0.09175732047879137, 0.09643757832236588, 0.17903266270877793, 0.19109507091343403, 0.1190427211986389, 0.14338584034703672, 0.19618592195911333, 0.11787841765908524, 0.15029658592538908, 0.16528271458810195, 0.14852194755803794, 0.11221111082704738, 0.11137056921143085, 0.12335252860793844, 0.13951928063761443, 0.2110321112559177, 0.08496526657836512, 0.14262816694099456, 0.16428448143415153, 0.16840349009726197, 0.20069012010935694, 0.14177940232912078, 0.12686233792919666, 0.14958235784433782, 0.2247741777682677, 0.1317320586531423, 0.16090543853351846, 0.1813254240551032, 0.12937247433001176, 0.07833983225282282, 0.10854563603061251, 0.1609226266737096, 0.1333630914450623, 0.16095596394734457, 0.1089749090897385, 0.12602684291778132, 0.14280839008279145, 0.20845179737079889, 0.21422162448288873, 0.13863392814528197, 0.1900285156443715, 0.13147190620657057, 0.1257351491949521, 0.10744339087978005, 0.17034214310115203, 0.19639830978121608, 0.15684166050050408, 0.11742912145564333, 0.28724445845000446, 0.06774832363589667, 0.10691277755540796, 0.14541999291395769, 0.09875623320112936, 0.09285376203479245, 0.22246345644816756, 0.192216589639429, 0.0984709664771799, 0.2861361054237932, 0.21400439785793424, 0.08892686571925879, 0.18425092566758394, 0.09319811855675653, 0.08171981025952846, 0.2136454952415079, 0.1480895871645771, 0.165555854619015, 0.21839828317752108, 0.19135804352117702, 0.11455487256171182, 0.11954839836107567, 0.1123539223044645, 0.1660533607355319, 0.17148297250969335, 0.12009422571281902, 0.1472312636906281, 0.15241045999573544, 0.17382688267389312, 0.16051364393206313, 0.08900444241589867, 0.14293805812485516, 0.13704303069971502, 0.20001000113552436, 0.18397331790765747, 0.11915412498638034, 0.1437511105905287, 0.14301170886028558, 0.12216595321660861, 0.09228377777617425, 0.1771178178023547, 0.08638841638457961, 0.16329328384017572, 0.1068131516512949, 0.17188212921610102, 0.2519843989284709, 0.14676755497930571, 0.13446605647914112, 0.15927165979519486, 0.09368473736685701, 0.10734349038102664, 0.13653847418027, 0.1451690134126693, 0.22764850087696686, 0.23501666175434366, 0.1788288986426778, 0.07643878387170844, 0.23961935774423182, 0.16434622812084854, 0.11241559477639385, 0.21538569795666263, 0.06432415815652348, 0.18537146475864574, 0.18966600619023666, 0.13007478351937607, 0.10540004310314544, 0.10069527954328805, 0.10622235757182352, 0.15664668346289545, 0.2299637789838016, 0.17250882840016857, 0.1286652372800745, 0.17955933522898704, 0.21641961357090622, 0.0866061105625704, 0.08663614527904429, 0.08428499917499721, 0.16498621174832806, 0.13510126067558303, 0.16316006833221763, 0.1863821511506103, 0.14911815931554884, 0.11335418152157217, 0.10819453338626772, 0.10378371967817657, 0.19882073916960508, 0.2209336229134351, 0.07997057560714893, 0.09924094469170086, 0.1855904280091636, 0.13045838481048122, 0.0634519565210212], [0.021484115823113825, 0.022584477774216793, 0.019947894252254628, 0.036019807230331935, 0.05339444171113428, 0.04469215535209514, 0.06891808938235044, 0.03277380543295294, 0.07994306419277564, 0.006171623081172584, 0.05140426510479301, 0.010476139905222226, 0.016156040983332787, 0.06573044636752456, 0.008809916325844824, 0.037121651621419005, 0.11116601104731672, 0.06793279928388074, 0.08069969117059372, 0.04660898179281503, 0.03980528359534219, 0.009680487091827672, 0.052073452243348584, 0.02245788593427278, 0.014405467682081508, 0.029759531826130114, 0.033516658149892464, 0.033201776022906415, 0.03804947351454757, 0.07212451615487225, 0.0522146940784296, 0.043772664066636935, 0.05347624122805428, 0.037233552648103796, 0.01092935650376603, 0.04575400540488772, 0.06311456876574084, 0.07186887596617453, 0.021948459070699755, 0.036877837555948645, 0.05135371371579822, 0.013635135092044948, 0.028382280142977834, 0.05400295827712398, 0.05685953663487453, 0.028913158785144333, 0.053199869144009426, 0.05167371666175313, 0.04028990602819249, 0.03104737141256919, 0.0013777352387478459, 0.09824235530686565, 0.012754280942317564, 0.0364450801134808, 0.02814274270349415, 0.0008784121359894925, 0.05133715640113223, 0.08955544253694825, 0.040907948059611954, 0.044255817047087476, 0.01008343246212462, 0.037511828340939246, 0.046776213639532216, 0.024521653904230334, 0.03474272321909666, 0.014874658081680536, 0.029945736678200774, 0.018536811767262407, 0.1469516521319747, 0.04662053703214042, 0.022155813276185654, 0.012997995745536173, 0.042262363858753815, 0.04158587398706004, 0.016544837308174465, 0.026443591887073126, 0.025952176947612315, 0.015110385520529235, 0.06964574291487224, 0.033284206365351565, 0.007371200899797259, 0.02449361370963743, 0.006354888564601424, 0.013685233770956984, 0.022325022946461104, 0.009522433756501414, 0.07511206131312065, 0.025841621063591447, 0.03482660817098804, 0.017057377481251024, 0.10905068236752413, 0.017067761982616503, 0.06282754315179773, 0.0033219260558325914, 0.034476251385058276, 0.051780864232569, 0.08672467607539147, 0.0657056512136478, 0.09211581491399556, 0.08765844628214836, 0.0406893410399789, 0.010228903611277929, 0.040807457553455606, 0.0219666639532079, 0.01514837606009678, 0.026750659199024085, 0.0050195199855807004, 0.04598065359459724, 0.03554905553755816, 0.03640110786363948, 0.06284991148277186, 0.05412504528067075, 0.059085768152726814, 0.04953345924150199, 0.08036571729462594, 0.014411028223548783, 0.042592393219820224, 0.07081610237946734, 0.04912524462270085, 0.044926859554834664, 0.029311964826774783, 0.029080696767778136, 0.01787874014553381, 0.04932422554702498, 0.0669440878846217, 0.03164281319186557, 0.03811215159657877, 0.0572839003871195, 0.01992546098335879, 0.030084399550105445, 0.03609191800933331, 0.023584720293001737, 0.032348462045774795, 0.10377718135714531, 0.03862392550217919, 0.05745658330852166, 0.06201996773597784, 0.07897381190559827, 0.0317638018168509, 0.022448215750046074, 0.021410888111859094, 0.031327775213867426, 0.08286262120236643, 0.009686680314189289, 0.031524240257567726, 0.06149925466161221, 0.038915886398172006, 0.022078143811086193, 0.03464113804511726, 0.0560376303474186, 0.025817497553362045, 0.004934816352033522, 0.035103822592645884, 0.05253295668808278, 0.027165818464709446, 0.028641850003623404, 0.040198551359935664, 0.02883226468838984, 0.06170934182591736, 0.017940321704372764, 0.02180895386118209, 0.0420799996209098, 0.04256936066667549, 0.036604805136448704, 0.04500245842791628, 0.024241600767709315, 0.036921271748724394, 0.09754777929629199, 0.03713115111168008, 0.07617803770699538, 0.03292486959253438, 0.04206743877148256, 0.0953631340235006, 0.024127540091285482, 0.04317376573453657, 0.16127772949403152, 0.07494721547118388, 0.045277375902514905, 0.04737511568237096, 0.03482654137769714, 0.0682465496356599, 0.015875136232352816, 0.018144119167118333, 0.04094145602721255, 0.06372759758960456, 0.061517366775660776, 0.03580427641281858, 0.03110672281763982, 0.028898230484628584, 0.024967536228359677, 0.029104246968927328, 0.05891201653867029, 0.07597324947710149, 0.019949432353314478, 0.10228871513390914, 0.038176354792085476, 0.04093104740604758, 0.025132120463240426, 0.05665959091857076, 0.007307108098757453, 0.007979462352523115, 0.0126559408090543, 0.018363203016633634, 0.025184330552292522, 0.08671211151522584, 0.04630613730114419, 0.006658251168119023, 0.04063882304762956, 0.043782003995147534, 0.06000018314807676, 0.06628027389524505, 0.011941188586206408, 0.03355802175065037, 0.04876165905443486, 0.011551567549759056, 0.026231918382109143, 0.0048183627131948015, 0.11758307256968692, 0.07784442641423084, 0.061552756087621674, 0.05975104788376484, 0.013288422251207521, 0.07370156512479298, 0.018210860507679172, 0.010556042307143798, 0.0278164853079943, 0.04353165903012268, 0.07493443568819202, 0.03434974489209708, 0.010135684296983527, 0.06163339043268934, 0.01818912485759938, 0.014661340719612781, 0.06316306069493294, 0.03048692931770347, 0.07850063338992186, 0.0445083142403746, 0.043435703046270646, 0.041747090726858005, 0.030812548466201406, 0.015223428526951466, 0.01828658554586582, 0.07072138207149692, 0.0838823989033699, 0.09533222357276827, 0.05577747790084686, 0.018060098773275968, 0.06827896664617583, 0.055719197043799795, 0.06885068753035739, 0.017995168273046147, 0.044917623526998796, 0.08646423419122584, 0.06086135275836568, 0.032832212455105036, 0.055810544290579855, 0.044086091584176756, 0.04567772375594359, 0.05068215912615415, 0.09976823319448158, 0.0420758621476125, 0.01403595699230209, 0.05393853243731428, 0.01425247579390998, 0.02221455240942305, 0.046375194142456166, 0.010740047619037796, 0.04853193095186725, 0.05617867922410369, 0.07351775740971789, 0.05194569152081385, 0.04064551721967291, 0.08727593594812788, 0.06784321463783272, 0.03213861236872617, 0.06634306701016612, 0.03391601894691121, 0.0020575288272084435, 0.026299318378733005, 0.04241468966938555, 0.01700013192021288, 0.06105881227995269, 0.07014707109192386, 0.06640174862695858, 0.0763062882469967, 0.026127010241907556, 0.025287075332016684, 0.029549426108133048, 0.020233463401382323, 0.08221996584325098, 0.09919277188600972, 0.058763850465766154, 0.018621132730913814, 0.04108093897229992, 0.04875286089372821, 0.00439087822996953, 0.02188443027989706, 0.021636361852870323, 0.012175452138762921, 0.06562921000295319, 0.020653465180657804, 0.06618766870815307, 0.043056543509010226, 0.03315996342280414, 0.02863089961465448, 0.06015639410179574, 0.03511499191517942, 0.04285239723685663, 0.04387614542793017, 0.09298974575358443, 0.04462404474907089, 0.034555479360278696, 0.023490860876336228, 0.043042346223955974, 0.03095069740084, 0.030792851866863202, 0.05259802819637116, 0.055498712390544824, 0.08154747614753433, 0.03868216183036566, 0.039367501813103445, 0.07862377053243108, 0.013830451662215637, 0.01872968852694612, 0.034568125556688756, 0.05886375467525795, 0.010102618834935129, 0.03513118557748385, 0.034631378803169355, 0.020887202736048494, 0.03075301709031919, 0.03624596560257487, 0.041897171540767886, 0.011271342791587813, 0.0926774054823909, 0.009152379443548853, 0.025311167300969828, 0.016982843590085395, 0.014283281416282989, 0.02307813585503027, 0.042383523177704774, 0.02282750887388829, 0.021607009912258945, 0.06905255911988206, 0.017790886558941565, 0.051663987105712295, 0.010246417368762195, 0.028424628944776487, 0.029216843759058975, 0.022115434876468498, 0.041390102851437405, 0.05653652056935243, 0.12400393388816155, 0.09838676240178756, 0.12313166545936838, 0.12720117287244648, 0.18303325428860262, 0.1525567818316631, 0.09448881726711988, 0.0943966796330642, 0.22291971399681643, 0.18463163258275017, 0.1419907363015227, 0.10721903221565299, 0.09267650748370215, 0.10695686854887754, 0.14450876915361732, 0.09992452949518338, 0.17211844387929887, 0.16030073660658672, 0.1950272810063325, 0.09896252799080685, 0.15822296059923247, 0.10870800309930928, 0.21435841714264825, 0.15947521605994552, 0.12110966184991412, 0.1432121777907014, 0.15997431037249044, 0.21415060095023364, 0.16214760078582913, 0.10311644728062674, 0.08869278492056765, 0.1343703639577143, 0.10897481261054054, 0.1018611564359162, 0.19707197207026184, 0.11301502745482139, 0.18529993656557053, 0.1705840090289712, 0.07061671698465943, 0.10357741004554555, 0.09281906663090922, 0.20470592571655288, 0.18750077550066635, 0.14927712734788656, 0.21741526405094191, 0.10887130527407862, 0.1601011137245223, 0.12283911826671101, 0.13885713648051023, 0.10330858189263381, 0.18762179010082036, 0.10771496497909538, 0.11482925197924487, 0.1788453891640529, 0.1642558939056471, 0.14814220543485135, 0.22259018558543175, 0.16666496463585645, 0.12534187029814348, 0.12225504062371328, 0.0907956826267764, 0.09525014946120791, 0.1783735168282874, 0.18387004063697532, 0.11796174600021914, 0.07993491541128606, 0.2836893929634243, 0.1565238877083175, 0.3158319869544357, 0.15580200066324323, 0.1311876339605078, 0.12236337934155017, 0.14257606817409396, 0.1466377978795208, 0.11679008777718991, 0.09921655029756948, 0.12710945826256648, 0.24382758740102872, 0.1479374765767716, 0.07564964340417646, 0.1480295177316293, 0.09535341188893653, 0.14303845586255193, 0.17956714262254536, 0.1446952560218051, 0.10698523343307897, 0.2051650924840942, 0.21553546335780993, 0.11553653355804272, 0.14384086593054235, 0.20299971336498857, 0.1784018223406747, 0.15101842844160274, 0.12240425683557987, 0.202405460877344, 0.13480408990290016, 0.24189574731281027, 0.1522683832445182, 0.14168497145874426, 0.1528056981624104, 0.14169925038004294, 0.0649134159903042, 0.10320812478312291, 0.13223176152678207, 0.11114282635389827, 0.14740480750333518, 0.1349015487357974, 0.1168301489087753, 0.13894375995732844, 0.12288022582652047, 0.06477020375314169, 0.12639159365789965, 0.13601494836620986, 0.12807092542061582, 0.17579364823177457, 0.13789532793452963, 0.0632115377811715, 0.1763428671984002, 0.1928600316750817, 0.12056779014528729, 0.07764595386106521, 0.08993391558760777, 0.0907470793754328, 0.1138095410715323, 0.15571380383335054, 0.12759169097989798, 0.09856158270849846, 0.1354707166319713, 0.12530868145404384, 0.13473517406964675, 0.11099024821305647, 0.08089573690085672, 0.10381288608186878, 0.20869961532298476, 0.11523309163749218, 0.14544746722094715, 0.14611176360631362, 0.17606540786800906, 0.11704051066772081, 0.132710135076195, 0.11497651634272188, 0.14011221210239455, 0.23205690260510892, 0.19489611382596195, 0.18162045744247735, 0.17339192476356402, 0.11705056676873937, 0.12467850901884958, 0.15186000906396657, 0.1730740925995633, 0.15281009167665616, 0.11069597181631252, 0.10255689019686542, 0.14498512406134978, 0.13838041049893945, 0.12550640443805605, 0.20971620921045542, 0.1668600455741398, 0.21523464121855795, 0.13318764773430303, 0.0876000318385195, 0.08014424558496103, 0.24606940773082897, 0.10266143654007465, 0.16121405322337523, 0.1363508147187531, 0.09219443061738275, 0.3296562982723117, 0.17587114329217002, 0.30541846761479974, 0.2188387032947503, 0.08575886735343374, 0.16877980349818245, 0.10088547714985907, 0.2553301490843296, 0.2534046914661303], [0.02598975188448094, 0.04282910864276346, 0.08798867231234908, 0.026132175589737017, 0.02094257066346472, 0.022348782804328948, 0.016778842036728747, 0.011174490664416226, 0.03163657172990497, 0.04442567609657999, 0.0143701024899201, 0.011543142318259925, 0.03315329522592947, 0.03278299322118983, 0.07363400000031106, 0.04334343182563316, 0.04960511359968223, 0.024748884679866023, 0.01954390616447199, 0.023170909880718682, 0.011016154385288246, 0.06173829300678335, 0.02185444565839134, 0.027059314707003068, 0.02297176939464407, 0.026153183935093693, 0.05150101147592068, 0.03330113846459426, 0.014023705989529844, 0.008042263816605555, 0.08920704131014645, 0.034120261698262766, 0.024010696361074224, 0.036544420290738344, 0.03366147342603654, 0.04061163075675722, 0.030090208711044397, 0.042727890831884, 0.014422646545426687, 0.03603595636377577, 0.042646169240470044, 0.02068428286293056, 0.035817089592455886, 0.02245420302642742, 0.01788968682376435, 0.04812571271031629, 0.05166351955267601, 0.028825511144532356, 0.037385537070804276, 0.0768008035083767, 0.030176778382156044, 0.010967752441501943, 0.03483384782157373, 0.026011127592937555, 0.016847110346134286, 0.021291239063430112, 0.01913420725031756, 0.057926017689169385, 0.06561789967236109, 0.023265027193701826, 0.048213998597930185, 0.03520847654726822, 0.03636068679043092, 0.0677621275826823, 0.02935723397968104, 0.005895727827009978, 0.01971963374671759, 0.019446002042968757, 0.024312626155733597, 0.03572480352886487, 0.03060941893636482, 0.035799804973066784, 0.01837197705754079, 0.09842056722845882, 0.056531462832936086, 0.003353677684572176, 0.035150451731169596, 0.06545246753375977, 0.021835673032910563, 0.07930772640975192, 0.017907030814967584, 0.014414647121157032, 0.0647682073758915, 0.041247573390137404, 0.07278625213075429, 0.09046834355103783, 0.029766574807581492, 0.022788572096033022, 0.054810878791613504, 0.03277433606854174, 0.011091804281022632, 0.0365350024367217, 0.04417389878653921, 0.038773345804656856, 0.02338126792892581, 0.012003066076431423, 0.045342729426920414, 0.03429976124607492, 0.031078517495188862, 0.047999699745560065, 0.04459098578081466, 0.03869202497298829, 0.0260001623610151, 0.051015457647736184, 0.022420171844714787, 0.02189405779063236, 0.0650732300709933, 0.030023753097339068, 0.04230449929309543, 0.023648249989491887, 0.07503113753045909, 0.029587411081593018, 0.05372835621528793, 0.07502292195567861, 0.048725390297477134, 0.0012686803484029952, 0.015205899926513666, 0.030841067346045747, 0.0576123378414195, 0.03515650765621103, 0.07276942764292471, 0.024741288798395544, 0.017945926774700638, 0.05946434510406107, 0.03839726618025452, 0.007588703047076706, 0.031473837298108265, 0.048465775907970965, 0.03330380277475342, 0.02214446027210215, 0.05335252521035727, 0.030094327630649786, 0.01787052271538414, 0.024518329082638957, 0.03172638644173276, 0.010538968272157945, 0.013700264116778271, 0.05239358506514691, 0.04729621796286665, 0.09329221546067856, 0.048177792923524976, 0.016218329437833745, 0.050471392896724865, 0.04921304069284815, 0.10936602091533132, 0.07014718241407536, 0.05558924327488057, 0.02744410900049843, 0.02941781363915652, 0.015982673430698924, 0.09015592164359987, 0.042273599974578246, 0.0691315830044914, 0.022877479532326106, 0.0113612456334522, 0.05486216861754656, 0.029128042078809813, 0.0798849540296942, 0.05107998367748223, 0.037574001762550324, 0.04184508761682082, 0.01734890236548381, 0.016308151571138296, 0.048441470571560785, 0.03615918256400619, 0.0287842477337108, 0.014583251013391418, 0.041206239475286566, 0.03348978498252109, 0.043612349036266096, 0.05878685333300382, 0.05307264276780188, 0.050650539924390614, 0.042478499526623636, 0.02458836926962249, 0.03371845552464947, 0.009117015179072041, 0.029295541098690592, 0.04216057088342495, 0.009716347667563241, 0.003377540747351304, 0.05383030875236727, 0.005935166018389282, 0.04268358832632657, 0.020207102315907832, 0.03078348596318392, 0.010755012099252781, 0.039737217521178536, 0.054035542270867154, 0.004177898545094649, 0.06089234855608083, 0.053742683376185596, 0.069769911642652, 0.04013016245153267, 0.09501589054707438, 0.015093485890247393, 0.05179629348276649, 0.05281282799842302, 0.026569296860543545, 0.030345082632265985, 0.027434106705186423, 0.02879474912333535, 0.04922873711620923, 0.03486537425487768, 0.03529505920596421, 0.04878472500422504, 0.04028917130199261, 0.005826232654726482, 0.020471635289140977, 0.02599185216240585, 0.047488983400398865, 0.008841156104608672, 0.03329281527840067, 0.006410162332031177, 0.030569138871214818, 0.07046335958875716, 0.002700316381378798, 0.01480181443184847, 0.022334448221954517, 0.04024372588901315, 0.03667967670480721, 0.037887748403591104, 0.047618762764614075, 0.013591005135822343, 0.012140113849454792, 0.043828013440361246, 0.030521565349772573, 0.013185131065256428, 0.020785394917766098, 0.01967381169379223, 0.01942787508596666, 0.07836146585759707, 0.03272312416811474, 0.038013672310626134, 0.02035742247244343, 0.0014682028086099308, 0.03447719391260762, 0.007294437782547902, 0.03764723689528182, 0.01745037250657333, 0.043655920526362024, 0.022796346092945896, 0.026422867413202766, 0.01518941311587696, 0.019190732928109355, 0.011793180219683563, 0.02883631310396595, 0.02032004606007831, 0.03565778388292529, 0.08862821065122262, 0.11828170070657507, 0.028256196674192324, 0.013259767001727596, 0.04377486082375981, 0.02177826976549113, 0.003000747501573642, 0.041867403997457586, 0.08888846699846908, 0.024464629132125992, 0.08756273149629124, 0.02334144985070452, 0.01792166782252025, 0.06871729390695691, 0.06013876809447538, 0.06257369153900072, 0.04406751562783029, 0.04086874410859309, 0.016025419281504583, 0.07734094600891694, 0.036799641165998764, 0.02085235704726074, 0.037988977346685715, 0.037796883552800864, 0.011948906922043534, 0.014827688482910162, 0.03029294119187398, 0.03291947788966354, 0.036543180904118344, 0.019947684595535975, 0.022654026288364548, 0.09217094164341688, 0.014479906021733768, 0.07369143480900675, 0.042963544983649626, 0.04816673492314294, 0.04693517796113156, 0.02564638984040357, 0.04337574864621274, 0.014222313056961866, 0.04158117990300525, 0.008501909269398311, 0.03244066647312138, 0.01801114671252435, 0.06473506306065246, 0.01677505893894704, 0.02835844235960394, 0.031540111085632816, 0.0547571435890859, 0.02689922974241199, 0.018845435733965132, 0.06274625571677461, 0.01749368053424405, 0.014340500074467855, 0.038627361645922065, 0.03682158647279721, 0.02106312327669002, 0.0433042501390446, 0.041674163585412316, 0.04973463321221061, 0.032111605614773, 0.05538349025300704, 0.0322012830292806, 0.031083282083272934, 0.03716885592439212, 0.053059922356624156, 0.07740877088508569, 0.03035068770259386, 0.011702248575602425, 0.0469739217805909, 0.08304906354169361, 0.07166062932810746, 0.04848484168178402, 0.026449132019479293, 0.030110517582215834, 0.018245327701151837, 0.03625749857746996, 0.03393938917724881, 0.049216851621167734, 0.03841372701572254, 0.013658758580277208, 0.04420912853674963, 0.05348778533516452, 0.05504500040842686, 0.047510086369584315, 0.047102962707867846, 0.07744258313323371, 0.055485183038399555, 0.04897281491139438, 0.039557094569317997, 0.0700575161317829, 0.08027243675314821, 0.03067422327148961, 0.039513497104053386, 0.014704835211887257, 0.04586008428304922, 0.057424563347012736, 0.023739018361084163, 0.026491471544431988, 0.054173195821931586, 0.021571594625129364, 0.013814957474096445, 0.08337072518770583, 0.11716916938894428, 0.1437411954975687, 0.12759038479998708, 0.10217801638646051, 0.10907437914283946, 0.1691608369583264, 0.09862683975370601, 0.12869648169726133, 0.07491286887670867, 0.0877559941727668, 0.10421345286886208, 0.1268656924366951, 0.16338195564458147, 0.09898828793666326, 0.2047180078807287, 0.13370758155360818, 0.2126584982033819, 0.08351264608791098, 0.13362561876419932, 0.11158286055433564, 0.14193195820553228, 0.10643825575243682, 0.08148562556016259, 0.17196055938256904, 0.1885838806629181, 0.09199546824675053, 0.21463480778038502, 0.10285986456437968, 0.06693308183457702, 0.10882345901336521, 0.1529747890890576, 0.10009603982325643, 0.08876153005985543, 0.1213072586688213, 0.1568142752512358, 0.08895056249457411, 0.159957894065883, 0.10060316417366266, 0.10356480095651932, 0.1605835245572962, 0.12099712257622741, 0.12490565073676407, 0.06807761456002481, 0.13645682309288532, 0.10067811366752721, 0.1987258778535761, 0.12563107040477917, 0.18008631945122033, 0.18282848090166226, 0.12140818333136849, 0.08638852028525434, 0.124720158346463, 0.13830275216605514, 0.06212220971065108, 0.10054558835690841, 0.16865930840140209, 0.06383786589140072, 0.19246967684011906, 0.1995326517499052, 0.13086594262858853, 0.0851243310899008, 0.10584967327304184, 0.13627210253616795, 0.10487407562322915, 0.10273039690218866, 0.081898074131459, 0.13334719464182854, 0.08891834586393088, 0.16623843752313405, 0.09939106632373296, 0.11717285786289722, 0.09856307442532852, 0.0500578496576054, 0.2092280244687572, 0.17270536394789815, 0.06225100572919473, 0.13322615035576746, 0.15196064428891987, 0.09236943646101281, 0.19836598075926304, 0.09826225970755331, 0.13815613347105682, 0.1724055066006258, 0.1852140700793825, 0.14573219959856942, 0.18665307958144695, 0.14652041980298236, 0.0739982163941022, 0.1818001759238541, 0.10272679006448016, 0.12302018003538251, 0.11582288381760009, 0.17465118609834462, 0.13746439246460795, 0.13132065651006997, 0.11518301151227206, 0.14854666107567027, 0.10562467636191286, 0.08865591502399184, 0.1271747672581114, 0.08978102574474178, 0.10595866508083418, 0.1483449898660183, 0.144273359910585, 0.1845355986733921, 0.08643943161587231, 0.13267099420772865, 0.16877205547643825, 0.23170407075667754, 0.22751810553018004, 0.16286605910863727, 0.13570256356615573, 0.12125862573157065, 0.18579865980427712, 0.12504161219112575, 0.1935347923426889, 0.10785485981614329, 0.136213086952921, 0.15308297937735915, 0.10423954678117298, 0.1598576596006751, 0.10859533766051754, 0.06400027006748132, 0.13516895938664675, 0.1451346222893335, 0.10314189552445896, 0.14400174870388582, 0.10519483927055262, 0.16715156118152663, 0.0611093376937788, 0.15911453228909522, 0.12039497363730334, 0.09666563288192265, 0.13845208712155, 0.17803543887566775, 0.16205886960960925, 0.10541734256548807, 0.13908545079175383, 0.15490844001760706, 0.22077043948229402, 0.13931640714872628, 0.09351854823762551, 0.14321320195449516, 0.21366928849602118, 0.18735402321908623, 0.23306723276618868, 0.08893751553841867, 0.21022760833147913, 0.12688568589510396, 0.07830941904103383, 0.20027456193929538, 0.1294250035425648, 0.1866327298921533, 0.12992641335586086, 0.15523062116699293, 0.2195021091029048, 0.25292196893133223, 0.2227711954037659, 0.1701386462082155, 0.15822573623154312, 0.19559368811314926, 0.09542473970213905, 0.12516700546257198, 0.16010056453524157, 0.1428808830678463, 0.1034563138091471, 0.06455428330809809, 0.11347752646543086, 0.12999586353544146, 0.21961769118206576, 0.15516179439146072, 0.1290364595479332, 0.20246576779754832, 0.16609708807663992, 0.06759536699973978, 0.14789591630687937], [0.0655209826072678, 0.005769906429122784, 0.04022044100565836, 0.03167049158946611, 0.03859466261928901, 0.07127636010409333, 0.04002011308330111, 0.02927890029241098, 0.02276808510941919, 0.03404817318369169, 0.03162554341543, 0.04968892433680594, 0.03020772222953383, 0.04544352792436257, 0.11297940436634235, 0.005509391257874086, 0.053670041961595416, 0.017229082623089198, 0.06741428296663798, 0.1216394810762722, 0.008808364309516037, 0.05000558761821594, 0.043624134341371246, 0.018995600039488636, 0.0338239740813151, 0.008926394548325334, 0.026894244365394115, 0.050135025594499893, 0.0725442155089695, 0.05221690938924439, 0.02013785622693831, 0.005339720528354519, 0.035880227806046605, 0.030480229579552542, 0.08259189315140247, 0.05106916316435672, 0.034383638776489533, 0.02396675194177078, 0.07730794270173647, 0.05570637644268572, 0.03071309140068479, 0.025158986209135037, 0.059518770503927954, 0.022686085212626494, 0.013238654755696189, 0.0744009947811719, 0.03712367397383787, 0.11629133485257626, 0.04562874572002329, 0.11791181430453435, 0.054306452148011886, 0.02420969212835189, 0.05796427169116214, 0.06644019187660888, 0.027756337949540466, 0.02477810860000318, 0.016373983780795243, 0.0307861465626047, 0.04317979939514771, 0.03498458172543906, 0.020771253293787595, 0.026684856675274204, 0.03740517429832835, 0.05266747095447499, 0.03274233466072474, 0.05168880081328098, 0.022848270455142483, 0.0425983526656637, 0.05304724647430703, 0.02133242269337643, 0.05168629235413391, 0.0332350873213727, 0.04224699398037046, 0.043822651423397474, 0.015040639409562573, 0.05041434400482103, 0.030716124929313082, 0.028167947893962264, 0.025945668312488124, 0.08652768781757914, 0.04536018845101353, 0.06675436525256373, 0.04778472924954258, 0.04681941034505144, 0.055894214019645005, 0.012383932553348131, 0.02052752643066924, 0.07112958555808291, 0.029870820580981672, 0.029561588053184096, 0.015421593088831287, 0.021227954275673255, 0.06379890313837677, 0.06460186239564791, 0.015389715063065523, 0.02994460861373227, 0.013434509382932447, 0.019348917994648218, 0.05100852969917469, 0.018995520258613396, 0.04107663451577537, 0.00784838701292756, 0.09539574399241246, 0.06374144606525078, 0.0032047293416326283, 0.04016097642306704, 0.011386563073756406, 0.012519330903160153, 0.014960215648898156, 0.06762615870684385, 0.06207609265402425, 0.038839159460621886, 0.03716598752362188, 0.045780277432641014, 0.013645835006173002, 0.05522119739907794, 0.05908795748837292, 0.017893642470880877, 0.039623973207199015, 0.019273346952104475, 0.02542734866437968, 0.00384435928936, 0.016324959360645153, 0.0777725271473173, 0.02121244524460053, 0.03115668790997006, 0.011915832183149178, 0.07671660685446113, 0.0333231505646836, 0.0668261903047096, 0.022832390350231435, 0.07392606479697861, 0.041886614490067586, 0.08083157081273384, 0.07157261061365716, 0.05647487778333016, 0.04333873774157837, 0.01132050265368889, 0.0036143280658507138, 0.02922776260675164, 0.05032446621044073, 0.0391725952795241, 0.08996680757263675, 0.07981902905157767, 0.060574312301469035, 0.0322275327926036, 0.04100088350242004, 0.07400733738904819, 0.02234084553492721, 0.033000605762936175, 0.053114017500774935, 0.029066326933389064, 0.042999119832529686, 0.02434454221656779, 0.043449907752801664, 0.023855049439589493, 0.07732596204732545, 0.03091171423875494, 0.03492512827506289, 0.04468880455533508, 0.06401245613233186, 0.005993638442305382, 0.07462786190444604, 0.0730129485600628, 0.05822019018523861, 0.05700099740352016, 0.08904194313799962, 0.045633996414835565, 0.06830905331298709, 0.025768968516786117, 0.04506119941652287, 0.03013070028828224, 0.016994229990814347, 0.015088736145116854, 0.05892412838875316, 0.099586570286192, 0.037124267691979185, 0.07245075685204938, 0.07377015441306867, 0.015139873830776196, 0.009276667842641473, 0.04538882421911694, 0.009265889075322775, 0.0940517071285285, 0.06281804366153665, 0.027152897673659027, 0.049575962038943544, 0.051201124442741275, 0.04265297102392651, 0.03310268075438216, 0.02527125645428896, 0.07203700952231884, 0.024544263433199376, 0.014292181622295175, 0.03150537857436575, 0.05551152557018213, 0.019656209806271363, 0.07986239274032414, 0.0489552594081033, 0.04169571926468052, 0.020390112222230528, 0.029230577201815322, 0.029472778951458167, 0.061043716996209696, 0.04148287502175663, 0.06817708461312577, 0.01408334590450977, 0.049829060371848755, 0.03327609098050743, 0.041604687430663034, 0.09797598366276361, 0.02556025247031357, 0.01867645241873106, 0.0045192581819719635, 0.034157521222368814, 0.006679522048216313, 0.048674716454115696, 0.03977344174927566, 0.009231299427483464, 0.03967159311287105, 0.07318740521441214, 0.08216119516873732, 0.06795971698011272, 0.04853926337091252, 0.030082508928899188, 0.08106188150122762, 0.05062775227997918, 0.019829866796499118, 0.06118057273852173, 0.04115035946597345, 0.03348563637700863, 0.06618645158596337, 0.022803023566666525, 0.02971353165776236, 0.0406929033488268, 0.005393043838921585, 0.06875964827486314, 0.06358442245982587, 0.050355740313534625, 0.04501018418523017, 0.03471895593975205, 0.015045962463773321, 0.05149707809323445, 0.023326631016971078, 0.00856655682582641, 0.018227139516966417, 0.036661289996118285, 0.05801411432912573, 0.017568865659995936, 0.027522147684067022, 0.03137344327114988, 0.07787994560203515, 0.021098139659443405, 0.0072669667224545265, 0.014456375301961089, 0.051134186433046125, 0.0941534036246594, 0.05745724753069226, 0.01608288563147653, 0.01315125109613291, 0.10661629698006436, 0.005107195920572849, 0.06710431014653295, 0.031430046874447726, 0.01750621169776423, 0.01057213392414269, 0.033273270819336176, 0.04145795741351321, 0.12694930279394612, 0.027480494645715225, 0.03010753971466329, 0.08020372872124426, 0.03876412090903614, 0.05895017777220346, 0.013429703049041564, 0.022226391520234756, 0.061852160724811256, 0.07451409808709286, 0.0434454511560034, 0.022528065273945685, 0.00709032444319746, 0.03474422977888025, 0.02354217296669958, 0.03325877296447288, 0.018950156481878366, 0.031208894288283773, 0.0069367991363833426, 0.02183170996431727, 0.0584664310736116, 0.058772251577465795, 0.029541505537054036, 0.004769554907397833, 0.04176529560936615, 0.08922351698856801, 0.09197932653478347, 0.009695138014649274, 0.04309857133193873, 0.051615031334222294, 0.010816604790306883, 0.021384400861279573, 0.019465648547338787, 0.032738338195485994, 0.033180190657731146, 0.01387624402923393, 0.020495191056397744, 0.046601794092566706, 0.03019203508301871, 0.05663829870172776, 0.020526062544377055, 0.09326521612820216, 0.02199057038524188, 0.02506023975001881, 0.07931165979243815, 0.07109449681593105, 0.01622262832825072, 0.09618172291084193, 0.07126945813070051, 0.035299141018185765, 0.03482113483187277, 0.06250023376196623, 0.08425184001680464, 0.0048301948663720395, 0.027286085351079237, 0.03158931176585611, 0.047936249829945154, 0.013186387150199153, 0.05644647579174489, 0.06340628475300036, 0.0368961500498699, 0.07973028303240426, 0.015381249013444176, 0.025817966961767524, 0.02898257371271029, 0.08580188223277219, 0.025735375202202704, 0.05543352213862818, 0.08049288429901935, 0.06022778499755077, 0.06257421846385114, 0.04688802931923419, 0.0060785178720834665, 0.06758680261555128, 0.053050753122079186, 0.03112233946012566, 0.006939232453078148, 0.012519116608018521, 0.02659788995515555, 0.005221100745984586, 0.029058836807962507, 0.0339174809778342, 0.07137436812627129, 0.04493643697060179, 0.13143197866156697, 0.1603229861939326, 0.1729967608116567, 0.06954754935577512, 0.16519022814463824, 0.19581610977184027, 0.16639829613268375, 0.1691868863417767, 0.1990426264819689, 0.0903976836707443, 0.12686867587035522, 0.17219966452103108, 0.2176051351125352, 0.13496679835952818, 0.1756475490401499, 0.10337206520489417, 0.09220983018167317, 0.07475144433556125, 0.08715102507267147, 0.16120726999361068, 0.09938133676769212, 0.14549244137015194, 0.11751175959943794, 0.09985424068872817, 0.1481376783340238, 0.10194222122663632, 0.06662874191533774, 0.12411999836331233, 0.18168566253734753, 0.14474698371486738, 0.08701219150680117, 0.22352615254931152, 0.13590712915174663, 0.11323265483952127, 0.13113995839376003, 0.18261808203533292, 0.19101340498309582, 0.12351944504189305, 0.15945278835715726, 0.1131186683778651, 0.10560620430624112, 0.2109491836745292, 0.18210862734122202, 0.11888928958796896, 0.13695146451937035, 0.15303199383197352, 0.1693239461746998, 0.3124778060009703, 0.11431393431848846, 0.3081868268782273, 0.17886141955386847, 0.08768821382545866, 0.1546212288667448, 0.2688357821898535, 0.14688128168927506, 0.1185606220678892, 0.09335055568953976, 0.14795733644859865, 0.11666568898363039, 0.25950481882318854, 0.12472305272240192, 0.23208130442071706, 0.10425871645566076, 0.18352032580878586, 0.11684492506901734, 0.10912100085988641, 0.12043769907904789, 0.09883323102258146, 0.10876872562221251, 0.06870256969705224, 0.11324664432322606, 0.2153858612291515, 0.14380089385667816, 0.12913984071929008, 0.13708929618587717, 0.15498966065933928, 0.05949353377218358, 0.09978742513339967, 0.09093850152567029, 0.1525186057551764, 0.1303720730356872, 0.1270602538716048, 0.11947143022553064, 0.11613552836934105, 0.3540850686840713, 0.1274599152384326, 0.17799580818973482, 0.09731912359711714, 0.060423875256674364, 0.06801330746384338, 0.14260493771871552, 0.1985796302324161, 0.15068897424498573, 0.1936436802498065, 0.10601920206681825, 0.1542714101378806, 0.12891502934508026, 0.11119401970063336, 0.10621203429764137, 0.07974686261150055, 0.19721053104149178, 0.20813950162846595, 0.15625626925611869, 0.1404105851543136, 0.15898863435722888, 0.11098045186372474, 0.16122821340104565, 0.08476615577819757, 0.08619959175121039, 0.10108714093803428, 0.1770446717273444, 0.08971435861894861, 0.1410702950670384, 0.1413643785053864, 0.06989806570345536, 0.11438499495852739, 0.10063908412121236, 0.16275282221613452, 0.12656773498747498, 0.08962663676356897, 0.11384365760022774, 0.12739307741867378, 0.12907061318401247, 0.1384261713246815, 0.07077941059833393, 0.10328625809052028, 0.16048634774051607, 0.13892119866795838, 0.12355266357189976, 0.17860830266727135, 0.08653073804453015, 0.15079287491971627, 0.13334750634385273, 0.24218285456299782, 0.10899904373218305, 0.14390541793545708, 0.3384688566438854, 0.15838072635233402, 0.142158075759653, 0.12366754803224467, 0.14104657602729276, 0.19957522134063765, 0.24250475369626656, 0.1366282146773301, 0.26618290110491216, 0.09929999738233164, 0.0888172876148019, 0.15289612143533304, 0.12589028774527833, 0.12246144673554227, 0.19493617495754734, 0.13847310474375263, 0.1305363845312968, 0.19657356053357944, 0.16690507909515873, 0.10190167027758434, 0.08875661704223603, 0.11335168790537864, 0.08416946904617362, 0.15990370244253427, 0.277384165674448, 0.10246636302326806, 0.15739663853310049, 0.2441508966148831, 0.10386335954535753, 0.21300325548509136, 0.2357274165842682, 0.12837921356549487, 0.10242164120427333, 0.14171253482345492, 0.21535050531383604, 0.10958285420201719, 0.11976591442362405, 0.0914328164071776, 0.26036369148641825, 0.16034229687647894], [0.01437203021851019, 0.034284858920727856, 0.07620655844220892, 0.09797933074878529, 0.019138528405164834, 0.028280952865316067, 0.05973151826765388, 0.060077882299083285, 0.022069674050726462, 0.06988619134062901, 0.01002693832560908, 0.0323129391472321, 0.012950262662343448, 0.04067198220582213, 0.055911851159180515, 0.015476801454497036, 0.024742266577959526, 0.06313940844847821, 0.07196081322035752, 0.04870081778790336, 0.004330541623858153, 0.04257025124388747, 0.013721197319682688, 0.05704436480300501, 0.008779886247793911, 0.028237778424227145, 0.030170310565154068, 0.03210517861589324, 0.014242788911360549, 0.041949993901653215, 0.056080452268361114, 0.03428217976761516, 0.07019270575256087, 0.03462018721620552, 0.03945596581615973, 0.008705961845407728, 0.005603255312962574, 0.029099862731527537, 0.03427323688811157, 0.0732310583407525, 0.024014297632675152, 0.07224230241263285, 0.02091068985464517, 0.005778867862318293, 0.05437767606053967, 0.04960259400832001, 0.025857365726551507, 0.014430506817006972, 0.034007258582278155, 0.06191459018737078, 0.023072360090736765, 0.02076819564535981, 0.052790125700994395, 0.05529059191758279, 0.08277164874016307, 0.022655115390080027, 0.004376235192466993, 0.05163359244761523, 0.03387872602615971, 0.03323610777442809, 0.027288885103189386, 0.03667593999125529, 0.1409747064462863, 0.042385129927424714, 0.008157052725437097, 0.015502951955568278, 0.05810164693684783, 0.060890663880854845, 0.04954407566401642, 0.044022971924277954, 0.023513535343226977, 0.06395831645932049, 0.002499720590094512, 0.0801253505051136, 0.04063837775902357, 0.03326782716612797, 0.05135230363521259, 0.03579516655008774, 0.04794745254912414, 0.030052379588596523, 0.023269786215678323, 0.07160509441746399, 0.06645734290941618, 0.0333225976646645, 0.008769476698944345, 0.02821460300765466, 0.011292599756416166, 0.018237054609926417, 0.014135671954136342, 0.017374317212670576, 0.05452076955407392, 0.02211422146501718, 0.05106815755425487, 0.036218762179487385, 0.03467030815954786, 0.01760809373081429, 0.05314604859449901, 0.044276003463892266, 0.024862436985131353, 0.025302187314082403, 0.003026068188773934, 0.034817409250536, 0.0363663790631108, 0.0456103738542879, 0.04356656223535538, 0.02560618770075962, 0.006039310674168519, 0.039914045337354764, 0.04383799903735053, 0.018587127524369862, 0.04551338257442694, 0.015736011373519432, 0.01426824272130034, 0.025022696354426444, 0.0036104262244407437, 0.02704991726204753, 0.015192103401204804, 0.03333302855025977, 0.03779981503612362, 0.04954492913384456, 0.059861494301003404, 0.08443156591965817, 0.031217213763738982, 0.031130950228543952, 0.05137565531185828, 0.045274967633304186, 0.021802589944854844, 0.04154612084676046, 0.04793163367139641, 0.02736222970270319, 0.019932505820179358, 0.017451207422709558, 0.018617037931107916, 0.03473779906926211, 0.051301640924066305, 0.02442605600663228, 0.0786121039709542, 0.07759889427688904, 0.060307005551294424, 0.05006638806662522, 0.026256637465849053, 0.025871377474686597, 0.030012917741260026, 0.05215131095610559, 0.05027626371884253, 0.012249106584931724, 0.05984449540846981, 0.023013281424937304, 0.035495617194101214, 0.05287931329803541, 0.019707805768121034, 0.045606915446114726, 0.07042303128400818, 0.04563064932881389, 0.02972551363200182, 0.07403386174701154, 0.006433706039388198, 0.09817225945880637, 0.09790924232220277, 0.0098523573615239, 0.04085684377059806, 0.00734413987629523, 0.037166314068599604, 0.04800723625521641, 0.045610633605974726, 0.06524860698846169, 0.011219128991797334, 0.03861090081045404, 0.022945886994421016, 0.017293770069954917, 0.09027207517647184, 0.007181896653492004, 0.08210705549572594, 0.07006151630776003, 0.06164988095406443, 0.05935606204729993, 0.027851447885041125, 0.06816113585955463, 0.06841806738520972, 0.04122273741813842, 0.021814861356688198, 0.01368920055028866, 0.01512388054834446, 0.0198981035646284, 0.003749176066776272, 0.10247114987578243, 0.04110339636099525, 0.029372871031227987, 0.05357297275622841, 0.009282913015340455, 0.025210199964931235, 0.036324340107967146, 0.03357670531840995, 0.03177298218361102, 0.02834580729540903, 0.031565481403958984, 0.03595453534217086, 0.04730250395368785, 0.05051222957263235, 0.016463312385894824, 0.026484293121029623, 0.015187166263785912, 0.002720416755437327, 0.04286018607672304, 0.05202883803576697, 0.061675663164351135, 0.030246735077525955, 0.07677790083107539, 0.0426440986484522, 0.07016280462266877, 0.015344911607826361, 0.03055324763408862, 0.0165953126270324, 0.01991182958590798, 0.02583058532763971, 0.07203946603112854, 0.021067496381874662, 0.005120375071783201, 0.028834633994847536, 0.01924929951201193, 0.009444303232157836, 0.039180584499263205, 0.02131113604264101, 0.05024448495532852, 0.004685148596763611, 0.027700986720446963, 0.006920342939338298, 0.05955163280304987, 0.08358026316273026, 0.05078968890302349, 0.04161023498454597, 0.034276903097634204, 0.04620005842298269, 0.06980143065447919, 0.018693041274673305, 0.01760939063387923, 0.04644265165552497, 0.006538569650729187, 0.02669277168024564, 0.024231412935478147, 0.037780140701215714, 0.02752309948846232, 0.05810142800328322, 0.08173738431651145, 0.05817261851916555, 0.07809130926034413, 0.07569596826215275, 0.05714542305213399, 0.026261060666001868, 0.016405862734245602, 0.05080682138213888, 0.06201939257152844, 0.04389298475871328, 0.02854733007552568, 0.010691747720557032, 0.018507329950807616, 0.07567025284515694, 0.05934580185567029, 0.05499201477505267, 0.05563408383750357, 0.006096381366660353, 0.02746209123870358, 0.026525563953327946, 0.024043152334343176, 0.00986403412753134, 0.040683218321646564, 0.02692170939553762, 0.061469179127016105, 0.022603129800700117, 0.030874588301230688, 0.01269285245143692, 0.08870134930475615, 0.03622768650529906, 0.04941071914799977, 0.017018980615830515, 0.026125277327082586, 0.034539252301328816, 0.020291508626542054, 0.02410496581433108, 0.02650180224009091, 0.03985784620454069, 0.022459758001787122, 0.021052076408523135, 0.011878575442096917, 0.060812122392235324, 0.03456745020230301, 0.06268079829169437, 0.005599224059551489, 0.012799294981959974, 0.02223619714641245, 0.023154022310336586, 0.01935720592882717, 0.0849892824771814, 0.06389369766111486, 0.052969332100474276, 0.035968669544672593, 0.08433240014710464, 0.019299823070468847, 0.054463991546072066, 0.011786218874476617, 0.060616681512328796, 0.14682967273984104, 0.041285467450506985, 0.03145345421216916, 0.04461582546355203, 0.04901129526842851, 0.018459452148817945, 0.05332052751327865, 0.018046428413072135, 0.04192465326923411, 0.050159560996689834, 0.01834169372159522, 0.07686549652135, 0.0906988991482649, 0.013904963288950967, 0.08463000136543997, 0.009689353901194409, 0.016837766706885304, 0.014265186928241747, 0.06023954432748724, 0.010390706647740444, 0.04168702129391022, 0.04710956411145162, 0.0402393991680583, 0.05773340439191088, 0.019488595753500704, 0.04670983224059455, 0.06738168784067966, 0.027554388434509747, 0.04339862534834538, 0.01644282539928099, 0.08622702895081602, 0.05316372284141835, 0.07255516218720004, 0.02754984649072867, 0.01819371318561025, 0.01546225536003476, 0.05161142449651379, 0.012719908372673672, 0.013301717826834647, 0.028843202089774422, 0.01979684308025753, 0.03302731936855707, 0.055728744773659855, 0.05403117844252847, 0.03585728059988469, 0.0646035025420133, 0.05790723022073507, 0.05873711830645334, 0.06427843443816528, 0.06788373590097763, 0.09551842842483893, 0.13755104562733322, 0.13101368938805535, 0.18623655661940575, 0.2852948661893606, 0.12331859019468538, 0.06618749059271067, 0.08113650445011444, 0.11880781661602668, 0.09789395408006385, 0.27884791838005185, 0.14278649672633037, 0.09893191439914517, 0.14438052603509277, 0.15698784874984995, 0.19930539128836244, 0.1996439293725416, 0.1345083292108029, 0.11981163072050549, 0.18796184216625988, 0.12758910830598325, 0.15332336100982502, 0.1643900593626313, 0.12004606032860465, 0.13658197887707502, 0.09795932986889966, 0.11869250171002932, 0.06046387330570724, 0.13425470766378567, 0.08845876349369064, 0.11881853322847746, 0.16206725587835535, 0.1474408758804202, 0.175287043384742, 0.1419862685725093, 0.10772387075121514, 0.12521710043074563, 0.1138301653554663, 0.1162672892678529, 0.10971186915412545, 0.158983736182563, 0.14412289689062163, 0.1383883217931725, 0.12085109017789364, 0.09924233992933296, 0.1038357219658792, 0.11666636433801614, 0.10442981860251166, 0.09767718758666888, 0.1476124455803074, 0.1396877778461203, 0.07801319821737707, 0.1583628257503733, 0.1524935063207522, 0.16022156429244205, 0.13968929182738066, 0.08944685891037807, 0.08963684129412286, 0.20474828750593588, 0.09971379666239955, 0.09888981978292577, 0.1251557990326546, 0.18778564146487042, 0.17280360945733264, 0.14025100856088102, 0.1327831030357629, 0.151881605561357, 0.15267773706000298, 0.1743413691292517, 0.1713636054773815, 0.23100569494999945, 0.11980438735918142, 0.12767739419359714, 0.1002498202433344, 0.1209305519296322, 0.10960331521346234, 0.16485822096001357, 0.1337448225240223, 0.13417929061688483, 0.07579883735161275, 0.0711744483851362, 0.12030969344777986, 0.22702757560182363, 0.13621454156236723, 0.12714350799797103, 0.08096674559055828, 0.0901139531924855, 0.12916079896967858, 0.2101576534914784, 0.09265600936487317, 0.11994831947959028, 0.20397223852341995, 0.11958135713939555, 0.1544238324277103, 0.14315132168121636, 0.06039906154910568, 0.19944957573898137, 0.13914007286075503, 0.20597067894414067, 0.14229351771064103, 0.1668325118953362, 0.1612701892736368, 0.05661590439558495, 0.1562727300915867, 0.18290216132299975, 0.13220071006799117, 0.14923038688721135, 0.11003409483237192, 0.13744358264375478, 0.16663124144542962, 0.13474663282977417, 0.1650305328075774, 0.056640502880327404, 0.10358479441492818, 0.06533779087476432, 0.11483639143989421, 0.10817995018442161, 0.2513541968073696, 0.14184877829393372, 0.14579939364921302, 0.08410284644924104, 0.23875796177890152, 0.19156643858877942, 0.17792199418181553, 0.12944544228957966, 0.11927434548852034, 0.2549822599394247, 0.2705469966167584, 0.13193971157306805, 0.2556876267772168, 0.07919201816548593, 0.04152642053668387, 0.12051295285345986, 0.115055325004505, 0.14134561701212078, 0.10282760340487584, 0.10332721722079441, 0.22281170182395726, 0.17121085664257407, 0.1498727305443026, 0.20134703954681754, 0.12486507010180503, 0.10491002525668591, 0.12829281273297966, 0.09161405629129149, 0.10224693964119069, 0.06970380112761632, 0.21481310133822262, 0.10611749210511334, 0.21829497622093186, 0.12260718227480538, 0.09982445088098757, 0.1262013366795145, 0.14715641067596152, 0.13987321086460724, 0.10256763649522327, 0.14702413027407601, 0.1316660371958278, 0.18752154079265893, 0.2219547439017333, 0.11029910092474893, 0.1907705594203435, 0.10441308317240328, 0.09917317176586948, 0.06497731490526348, 0.1451822681701742, 0.11854137817863375, 0.16893281950615346, 0.11073321278672665, 0.16382978239562362, 0.1093069756461773, 0.17818293330492452, 0.0728591978258919, 0.10971373194479384, 0.1325792499119416, 0.14479391713393852, 0.173970146861393], [0.06696747295791283, 0.011231117459828965, 0.02599760380689986, 0.032413025182904676, 0.02474948953022249, 0.036738131966558285, 0.0067584067801362835, 0.0617649286868982, 0.03448262643360067, 0.0829518644604832, 0.07860408877604641, 0.03823548169748392, 0.012059495275025256, 0.03907754100509919, 0.021506710509129334, 0.04188453276583459, 0.04984120932931546, 0.033064089075196534, 0.09616140290745534, 0.06287746742600575, 0.054573859088122845, 0.016241599478235003, 0.02783289790386334, 0.03343934862641618, 0.02806515301926993, 0.023511032450187486, 0.03650947255664505, 0.04169125895714387, 0.051175776388845406, 0.07071208296110854, 0.03391863872820977, 0.017256723913305905, 0.04175762180238962, 0.02289839325385401, 0.07139631343306974, 0.03911196552508045, 0.033655321021797135, 0.06329136318527162, 0.04522734772763215, 0.03238883116864599, 0.029034806066192687, 0.028063724384992383, 0.08636817801743746, 0.05281126206682529, 0.015848454168008175, 0.06233997439267114, 0.0941302337741945, 0.038541042449651286, 0.057470339015708305, 0.0035673007187142503, 0.11888686276506633, 0.03385744494153187, 0.051287937167217024, 0.039849322638474405, 0.04778499271196779, 0.13548643531976268, 0.04082719868165441, 0.03117610620392952, 0.08315509418025613, 0.015123078101169085, 0.06332995486445725, 0.04314617639465723, 0.06063583634386305, 0.021168936837057117, 0.030013017931196373, 0.057265072100562975, 0.04128751948883291, 0.02282508576172404, 0.037681564936065115, 0.05831174894410651, 0.04423465099534951, 0.03287695653853007, 0.07567649430711754, 0.029917497959104367, 0.030123393844405655, 0.02367650726228021, 0.03715122991707176, 0.056644061478436925, 0.06129980247351341, 0.046486920764436945, 0.0736437518207822, 0.03764679160667583, 0.056114535400411114, 0.0269648708490422, 0.08111539034871385, 0.05063444274128415, 0.07645919293281622, 0.03516793301969301, 0.10425532484077848, 0.012163879273430211, 0.05989603385387454, 0.03365751777892001, 0.02871542837965535, 0.06194910376507323, 0.03565991384675726, 0.03453254699707031, 0.030641824814665597, 0.02529659708670806, 0.011067985979025252, 0.044934778270544484, 0.02702773446799256, 0.05638553062453866, 0.009031684894580394, 0.038703561658621766, 0.011555964774743188, 0.02655259297171142, 0.012940044216520619, 0.0047104470195336035, 0.035896477129426785, 0.1274906549951993, 0.03522756458551157, 0.02084554227621993, 0.04657063131162431, 0.04055247045471333, 0.029928314761491492, 0.011731519807653967, 0.010954026420222363, 0.023487298567488324, 0.03690259560244158, 0.022971704456722364, 0.06516343812108971, 0.02480001679941779, 0.03332406340632588, 0.07236405173898675, 0.023752575543767307, 0.01195297110825777, 0.04164058140304405, 0.05897456103411969, 0.04035377896798309, 0.04597268292855006, 0.013886140568502015, 0.023613061057403684, 0.059007790696341544, 0.009393135860591428, 0.03869933141686488, 0.05708523858629633, 0.038828153410577215, 0.07545033964561298, 0.026432656341057736, 0.01746400390402414, 0.0852347478212323, 0.03417556654312648, 0.06714056406053714, 0.008923579025577055, 0.0362765457975911, 0.028014197159791365, 0.02677757689525606, 0.035197374018025585, 0.06423239901778288, 0.010801822136272676, 0.04020254040369764, 0.09886986343190074, 0.010766770501504652, 0.02667279120942112, 0.08613946294644848, 0.05014447684516199, 0.03622597214416601, 0.06988745299167931, 0.08348574323463254, 0.028418279871402774, 0.07199226543889381, 0.043078678063466214, 0.02838772565155523, 0.025112086186709348, 0.08866022690199316, 0.03604940036893822, 0.052803736689384095, 0.02553462611103896, 0.026298802586097736, 0.07163360773120075, 0.02763239372143289, 0.023338171413342934, 0.040065862776828, 0.02491974191798363, 0.030758269640500657, 0.013532449684134917, 0.039018569950712845, 0.021793103442178108, 0.02090782145387493, 0.020849577704211697, 0.04036199454276357, 0.02421124321699608, 0.026066846185131, 0.05179351042897906, 0.030565242595912423, 0.1430142915342003, 0.011103831711807288, 0.013881535542168422, 0.050733500902424566, 0.024831120208546054, 0.01185575903946301, 0.05491415606229566, 0.03346277451782953, 0.02133358415449038, 0.04187718550383579, 0.021981050485919695, 0.017601291947357822, 0.02267716274218401, 0.03795222990447655, 0.01097473141271621, 0.0370871046470711, 0.023530899743491318, 0.013197485041018808, 0.027388937742216513, 0.07531586990808137, 0.033444625296397135, 0.041252694209106266, 0.03376936314452905, 0.028553807169373613, 0.01899456103274133, 0.025415190430067014, 0.06011278921505436, 0.033373887490597554, 0.05605235826806165, 0.05566520580032375, 0.01777235884219408, 0.021148768973944243, 0.022271237648965325, 0.05504481858224608, 0.032954885755316354, 0.02716880746447714, 0.02095500720315613, 0.017237422507605515, 0.014623581173509592, 0.021794290878460743, 0.023749259999021888, 0.07444501155987382, 0.01800775880838046, 0.058881822260445915, 0.01709043459413806, 0.05098879228171427, 0.0012225026443957177, 0.01876776441349648, 0.04550321515125688, 0.025839298141363543, 0.03122029738733545, 0.02997371193487197, 0.0222998159006238, 0.019274391524959356, 0.0243304859395721, 0.020105875228182413, 0.041504872278892435, 0.01829612214351073, 0.040598116247565486, 0.030750679325137753, 0.040245648051495664, 0.0363569278124487, 0.025324524103780277, 0.023903218534542248, 0.041949340811697766, 0.05509149224963039, 0.030481276007776614, 0.037172280935919844, 0.025440724020882044, 0.019447937193035614, 0.05894053727388382, 0.006619648820560542, 0.02926757140812697, 0.06190924672409892, 0.051674555288627744, 0.04829305216844659, 0.04286039016733412, 0.06876200088299811, 0.009125619453698164, 0.012318989993218565, 0.02854344307706924, 0.01601718886377057, 0.029233208115329035, 0.029198414376878645, 0.05571480352955405, 0.019099485871265642, 0.09502181288553402, 0.012745158092002384, 0.05342309974366799, 0.016893058564164676, 0.025430302412132733, 0.023384997221000958, 0.01037566238665022, 0.035624984666355886, 0.015587442685500719, 0.022267682761594187, 0.07428301556501538, 0.03668504985398613, 0.018300831070519052, 0.05786769230326172, 0.013862556970707374, 0.046937011065892875, 0.056727638439042494, 0.057264534043497406, 0.03143238092889078, 0.06671227063634433, 0.030215444276109338, 0.02530006106098881, 0.06548011995619163, 0.06812879306380637, 0.029890379882999696, 0.012841090883739525, 0.010799385108839488, 0.062025248116697185, 0.07369260740233585, 0.017624834727030247, 0.005529579530048068, 0.057240733367507346, 0.06909824573085643, 0.013935957231296925, 0.032697267743060365, 0.0010401971985629643, 0.023561055058962665, 0.023524283496954013, 0.007656427269466803, 0.05941706658632029, 0.06442838537623174, 0.01698606451100204, 0.04291923134587705, 0.01814079805626534, 0.009619036336516729, 0.05192595781409182, 0.09445154661079869, 0.06596273116883822, 0.027436941709311213, 0.058104763957089745, 0.035127222508890554, 0.04947212444676552, 0.10199108422966674, 0.05239108773821499, 0.026589260633045342, 0.030352279609360266, 0.017215208172274288, 0.010886226591537707, 0.10583847426460125, 0.041088991274591535, 0.03847602289170027, 0.03921809635357931, 0.07483053501346149, 0.05653757070831489, 0.04184210789389908, 0.06048573326552287, 0.06952314754016697, 0.02508368419512408, 0.04411401489051059, 0.08717884076759219, 0.05907659149670508, 0.03492511714284774, 0.02193631196860224, 0.026341218181187287, 0.042293508086004294, 0.04768291400978342, 0.05777532831416465, 0.008527145073458087, 0.05656517118040938, 0.03693330567330122, 0.012780983415723313, 0.16297785623464733, 0.0837301992578432, 0.09228691706084646, 0.15261809807270765, 0.14813273563049734, 0.12176394666312262, 0.11547270143637434, 0.1640167145524174, 0.17328533751424402, 0.3737619862658903, 0.15202381589915603, 0.10694417782360688, 0.11774126876844093, 0.1123765429656487, 0.2035985077964142, 0.21313948411261663, 0.1396467222366482, 0.11771296325605363, 0.1842703699367121, 0.0868065126996953, 0.15246111899614334, 0.12672472890699282, 0.14680515218060464, 0.08406501176068559, 0.16908501915168017, 0.10008722310885787, 0.1355781202437356, 0.07851400689105503, 0.1327772400691174, 0.1489475098787807, 0.17502162168966606, 0.10223982986644842, 0.12148380075814202, 0.10078389197587967, 0.17934007511939853, 0.10843477401067503, 0.14013866224559024, 0.2002108856686391, 0.12500569224357605, 0.12683519016718492, 0.13528636714909226, 0.18211833463283256, 0.1943130380823277, 0.10532675602007657, 0.1713208874571137, 0.06947375761228614, 0.19335918535944074, 0.24139038927387446, 0.18438617466017604, 0.2041967530385591, 0.15387378225568682, 0.1343974968767725, 0.1966404725681059, 0.12196989264339209, 0.1743999691097997, 0.16256606817478314, 0.09699190326500684, 0.128202834748663, 0.1495757675729692, 0.11923900441615842, 0.14289686892880127, 0.12275296976440586, 0.15890014066826552, 0.06663849373580888, 0.087427645776188, 0.12935215432662517, 0.21834936080267653, 0.132995193998795, 0.1296372280921787, 0.17568759532878175, 0.12461251724744216, 0.06823491276009008, 0.1920526343747042, 0.10826730096596293, 0.0997302946052514, 0.15001644002040848, 0.11349887063261122, 0.15350983303505927, 0.11161216054460965, 0.2532818808685988, 0.10448107874253765, 0.1132232444069814, 0.15926832013064995, 0.16508301749126986, 0.1657555962447077, 0.17562699154950678, 0.13044821738731116, 0.12143287458457053, 0.13729510857956484, 0.10276551533024758, 0.14990645373472944, 0.06931628129677847, 0.11528359478688799, 0.21066249202704057, 0.09758265281561762, 0.17385759274475276, 0.11570052593015134, 0.0907471461687237, 0.1403692623716779, 0.20659423142205924, 0.0959623366361484, 0.0938872694678139, 0.163803584582638, 0.21721843164414167, 0.05746809401898645, 0.1254124633851461, 0.0827072600077372, 0.08318866151967086, 0.20462731743464246, 0.18293414788786322, 0.13525221351301298, 0.10552600040682591, 0.1395930055878125, 0.15682135534007102, 0.25542404560837895, 0.09964397540898062, 0.06770634776330553, 0.2811259852023795, 0.12160020662122406, 0.14994589146226645, 0.1526843718602322, 0.08437799027888104, 0.2085091802291572, 0.1514823894831352, 0.18641409318661317, 0.07919742842204869, 0.22753285942599177, 0.14197109907399863, 0.07883428814238869, 0.05839052420924418, 0.07340570795349777, 0.1356574409874156, 0.14053982275072485, 0.12824160454329103, 0.17289612558670342, 0.16464936576085165, 0.12361225803033449, 0.15675812435802072, 0.19743937969906256, 0.12676994054345414, 0.16665157629176974, 0.15412795299198478, 0.13577521982369944, 0.11748752847779542, 0.14482625992968678, 0.09194325815769844, 0.16415049409260973, 0.16004751581931487, 0.09325691149570048, 0.16422175511252135, 0.1237467055034358, 0.20317123853601515, 0.2366509154671803, 0.20110777113586664, 0.10875873631448485, 0.11501882618176751, 0.17705712496535853, 0.15511137287830934, 0.16858973947819322, 0.15601314167724922, 0.19277407613117248, 0.12838072754675522, 0.18241244775708765, 0.10555296263191849, 0.26900760421995074, 0.1693074853392318, 0.12605957163032144, 0.14828340645181015, 0.1326803452684544, 0.11554017008165829, 0.2104714632150717, 0.14290638326201588, 0.1745143934385851, 0.1384316780604422, 0.1144776372530032, 0.1868186378851533], [0.054004583580535837, 0.028495229453255888, 0.04385007378004957, 0.03914768138201907, 0.024270002759294584, 0.029715900964220054, 0.0118102579654078, 0.11812082535470836, 0.027720599828171544, 0.04093823881703429, 0.04010489603388123, 0.029839067792636342, 0.03447517898166552, 0.0066406673704477726, 0.042442991471034475, 0.023735508002573624, 0.03931360333808698, 0.03163605222653132, 0.008867602537065977, 0.017394774513377342, 0.03358567788382061, 0.09062337077921256, 0.07896469833212905, 0.020672215541708283, 0.010973323187499773, 0.02553390437242342, 0.04297148967452813, 0.03584308702556882, 0.027887000469490886, 0.04145666978729423, 0.017974269394471776, 0.020101804548176005, 0.02294738242198946, 0.07960440736496821, 0.039057781323208474, 0.022117177068139426, 0.018080544941767585, 0.06996506679570302, 0.03032574040844338, 0.05952307867119089, 0.06312080280622467, 0.016283603181364015, 0.028138653469795827, 0.014707327900396194, 0.0512818997958675, 0.029582119568658527, 0.028034301940351725, 0.08402815670706332, 0.08475209950120188, 0.06931538329808973, 0.014584140662918799, 0.04280779045075178, 0.009014261122501921, 0.006291325007623527, 0.05011333261791151, 0.004222389834467322, 0.010720528207457392, 0.03753069744561799, 0.03921250798157416, 0.03559108707122505, 0.009785391521290876, 0.005494993592947139, 0.010061303473776206, 0.06526941680931486, 0.03609104227507487, 0.022801164486736525, 0.03825382387731224, 0.05883246201847214, 0.04447783052455634, 0.048516672395635396, 0.05753536970587447, 0.05083477808511816, 0.036157976574031636, 0.021173946333874483, 0.05634710963931866, 0.020126454983255826, 0.05494204226124566, 0.025912633464031387, 0.051712965141632594, 0.04851793775742408, 0.030011003000254277, 0.03762477950658649, 0.05947653859038837, 0.023307752635446377, 0.013745240121352253, 0.04000220505986363, 0.05048825820267666, 0.018499158904887736, 0.11443198032793589, 0.049151646526297554, 0.019433122070040554, 0.03990099467046093, 0.03578567448130343, 0.0495725407381542, 0.06186610567965545, 0.07838039062335156, 0.03674677798699122, 0.07008823362411931, 0.06924030763912015, 0.11004783940734342, 0.08475819995510392, 0.02904153549025068, 0.030896759963070508, 0.08111290415399708, 0.04032150667626411, 0.024745045921008568, 0.041770353345782496, 0.061978403755347244, 0.03715252867550589, 0.027512557280715555, 0.013936036084487569, 0.09023685284773819, 0.04558132990496233, 0.02597486996819498, 0.019130791515635792, 0.02184341548854718, 0.02707444338739151, 0.031524629885097966, 0.04087269975570962, 0.09038111893460155, 0.05417687687440775, 0.03581829929316882, 0.04907033311610576, 0.03032236734725302, 0.019690409826580435, 0.03487267698801588, 0.035685265611391515, 0.04909952920570504, 0.01744393437547842, 0.02996035327669233, 0.016785254192654975, 0.024831994087435305, 0.02224198960902868, 0.05247980407148134, 0.05929782571911346, 0.06614785248530097, 0.010215253660135204, 0.10778170631965622, 0.029532573789765593, 0.03317821283417288, 0.060918802410014905, 0.04173471541434992, 0.057293830323033035, 0.03688091746880673, 0.02310356740053976, 0.04634254706616048, 0.04290399134333711, 0.027188134845346212, 0.03878342417010572, 0.010257630292471731, 0.030298540696094278, 0.023146162966440897, 0.01930447448103223, 0.02576636728917947, 0.04405599378515035, 0.06014006685290951, 0.07593119938974269, 0.019246954325353727, 0.03698474763950799, 0.03444098081672564, 0.005510930286618532, 0.05383992327551823, 0.02069728529022541, 0.051189064542995766, 0.06457228781073354, 0.00943846160225803, 0.0589622747793328, 0.047808652379899286, 0.017668382097326685, 0.047989461818360724, 0.04284314636606723, 0.012763470585923642, 0.05224761203862727, 0.035971415491076186, 0.05622890777885914, 0.010269906342728063, 0.024907236729632132, 0.030826157599221915, 0.05151404729986098, 0.018307465870748274, 0.056647423407412134, 0.036300194333307445, 0.011216091752430657, 0.0605160908162361, 0.014359043561853468, 0.012059226246492472, 0.052515085772029124, 0.0575534447125392, 0.05443320726044476, 0.051248566232970916, 0.05170361037016846, 0.01939217407198157, 0.020351581770228222, 0.01638547779293731, 0.02610282364912564, 0.02353170497372048, 0.04160624594078399, 0.08903768321033567, 0.05719745502574369, 0.025347946284455247, 0.020864329744654242, 0.010170454843319021, 0.04227254983561579, 0.08027617717743851, 0.04200225223030429, 0.029826150712324306, 0.027276088621874806, 0.025893825586535968, 0.026536647928878665, 0.01946877113368828, 0.028786025177396368, 0.025873978702293243, 0.031446273933397606, 0.11046934218029492, 0.04447466526471544, 0.07438561748131178, 0.024046727630775422, 0.03701783629367128, 0.07713211307418533, 0.03622701115091331, 0.038602562781306915, 0.03888398518029135, 0.034415050176903605, 0.05017462659452576, 0.037661471287719905, 0.027232253669353668, 0.019587679889809806, 0.06851387865026481, 0.04449642503459472, 0.0028679332172032446, 0.11413975968025625, 0.015679520947742276, 0.04781693103723228, 0.017111719389504287, 0.019564649192034267, 0.01976025705516804, 0.03168894509144593, 0.03237130535126198, 0.006900746529936441, 0.019348326131876092, 0.0486312711291248, 0.02440073021716671, 0.043738146778196096, 0.01214185604112572, 0.040454885456711054, 0.025538691224937793, 0.048389486837550066, 0.03730267628270667, 0.02361563816521084, 0.04903953398752492, 0.13095915637677535, 0.019608614020398818, 0.03373073435795959, 0.057507702440489084, 0.06373236217768863, 0.04547958516923245, 0.023962807426869404, 0.038222690782276914, 0.04705628161900677, 0.02861636836314574, 0.023328488241531886, 0.030927444058761466, 0.03585580001526978, 0.060467587754828855, 0.02264325401483802, 0.03944834024878219, 0.04238727473421022, 0.04724028971395455, 0.033072902078856714, 0.08895584658603184, 0.02917024616181152, 0.0960572795884218, 0.019273621546744835, 0.019241698064433876, 0.036767832716577686, 0.04926910623908043, 0.0597623656358337, 0.04476200258068275, 0.06488460581749678, 0.03647072131570894, 0.04340193532698322, 0.013494702197931474, 0.021344961278373376, 0.009542590487399139, 0.03205929904652294, 0.034989594932994805, 0.005328923207343905, 0.013326922089618165, 0.050487961343606, 0.061718088036286645, 0.07198465842520818, 0.04447493614861742, 0.03511780836561229, 0.03023082528670784, 0.04309826334065292, 0.03197418212948833, 0.038928747817408293, 0.05724319358705543, 0.006484296854978311, 0.015481255268241512, 0.026749742646643426, 0.043866697888006456, 0.02189155489759287, 0.03305212565464899, 0.02749794253759319, 0.014246739920054097, 0.06831313512520865, 0.05378059599024709, 0.011947299244638998, 0.020657218592532445, 0.07124747571651824, 0.03312335327791516, 0.04091064947715495, 0.14841167925624177, 0.01184126025691512, 0.00925903812458273, 0.030020444974070415, 0.03462121509073768, 0.027639234467642382, 0.05317766408552416, 0.01614073418750195, 0.030755375264561735, 0.06819076239480637, 0.03371830338437576, 0.06552753577125259, 0.008623937828815542, 0.0523467332823202, 0.025813033535087015, 0.022929633960302453, 0.026261266611982137, 0.06567637348780409, 0.04896294805803336, 0.019933715520892292, 0.03876613212923985, 0.028475495746533852, 0.01519616758741904, 0.01339492137049092, 0.03788729569350835, 0.014766672811674653, 0.020742194501508493, 0.021178414062887896, 0.008941992637119256, 0.02299280371516943, 0.008569662713853177, 0.030592369948863052, 0.0639865106495563, 0.0474244388169609, 0.014985739035182633, 0.02735941881837789, 0.0020717673942272086, 0.04088891939318273, 0.04223057025228627, 0.09527987989713438, 0.0861720358079765, 0.1397902684402652, 0.15788704971782863, 0.13508981675840914, 0.15830628894036636, 0.16047224693465978, 0.21340404491638765, 0.12793146102922037, 0.1374229064094834, 0.15668534935684875, 0.1229745899036061, 0.12338378044660203, 0.09274466632632539, 0.15879387996392325, 0.12955954007338732, 0.11406181190977804, 0.22745857044355944, 0.1450795549317263, 0.09762021290953271, 0.11562473038793541, 0.16833785455673933, 0.23934899334562942, 0.09061162258149125, 0.08363042492419481, 0.09236165133188479, 0.1572819470311515, 0.13776205305475742, 0.12118957631173544, 0.06390514157828875, 0.10254209919366986, 0.08013914703042246, 0.06191480169945862, 0.10648392752045766, 0.13842131767887622, 0.08308750679134391, 0.07813749311026186, 0.17419860960217193, 0.2122765444801189, 0.1816665893420577, 0.17379633587552235, 0.06548374905833043, 0.20342163916211575, 0.15819536754861474, 0.14978773979237303, 0.1445257940213196, 0.18938252062071115, 0.15378283947939053, 0.18019448005361483, 0.09560133374179713, 0.07110313541488722, 0.12285046570468694, 0.07588776890770532, 0.07444075905368663, 0.21932090632617474, 0.06510683451779187, 0.13549925963161513, 0.1639265287667513, 0.11837760102935135, 0.12467199296224862, 0.12442812323570251, 0.1294292337843217, 0.09488039664574899, 0.17853911966085434, 0.12399036000715569, 0.07339772986597382, 0.22146997303934768, 0.12194958748295903, 0.10026961332187057, 0.08642711938591674, 0.13856848556315526, 0.1102937055111397, 0.14382145134732127, 0.12704567809123546, 0.20768168556969613, 0.13528289389796555, 0.19937816628953442, 0.09619813921744935, 0.135900538880378, 0.14966921880841255, 0.08359414132428356, 0.13520277163479477, 0.12222848657984287, 0.12343890717602335, 0.11954194909776561, 0.228417425241787, 0.20933283056365326, 0.10589090699795634, 0.16338893183274195, 0.12333672828390263, 0.10034860009909607, 0.16838824638398364, 0.13306749402545393, 0.1548016449669376, 0.18036417954135686, 0.2439312357455492, 0.11853506250190549, 0.15845961665036157, 0.12147181507316418, 0.19530781282810494, 0.15035813965369016, 0.11551321527804248, 0.10702769170165993, 0.17120711621828377, 0.07814054333721288, 0.10004776311689056, 0.1030857594741974, 0.10925948561634868, 0.07124360170564614, 0.14791424735449255, 0.19122172583593056, 0.14823789795627818, 0.11066138773458079, 0.1770775785553269, 0.12397314960253425, 0.18323660275200382, 0.11792263481765985, 0.10150691450689919, 0.11665213736705482, 0.25143963284790516, 0.1844879676355049, 0.1543976939865388, 0.1372333915787749, 0.15893346309894696, 0.16810860513942316, 0.18393333099083975, 0.09059847172466107, 0.15560326835839078, 0.16209015855565667, 0.12555817665997893, 0.15732135507278144, 0.12605660303961486, 0.10609338714857586, 0.18606233003083616, 0.22474553086794913, 0.10543011492700316, 0.08661877902341075, 0.3259800549130887, 0.17295224679401144, 0.15158269816311076, 0.14770699519431219, 0.22295460978057235, 0.16851702384883538, 0.11652294429950416, 0.09210551390424371, 0.14573562832083553, 0.16938713262788951, 0.14004331111209467, 0.19008892646525055, 0.11133890177006833, 0.13901217113016173, 0.13504758855560794, 0.1706455776002258, 0.10200910357525572, 0.1852983483695425, 0.1812676404369995, 0.19474202912533656, 0.18111897341441363, 0.18663799914065748, 0.10733281829743646, 0.09008910608827136, 0.10287158307619393, 0.0934261731163133, 0.1284474614658393, 0.13202649832237512, 0.12937508668983355, 0.08914534657378681, 0.1978091918863356, 0.1153376379807014, 0.2094282113830559, 0.15104244434041902, 0.10056773404357955, 0.14020685077412054, 0.09902835648972541, 0.2098384260898456, 0.12408708411385305], [0.06991091227973811, 0.02427388790238183, 0.04344945504271891, 0.0029025486082900898, 0.008753933343541576, 0.020163658846286125, 0.03881040865962859, 0.0541125289601041, 0.07381299117696472, 0.07731076286290772, 0.06838335713837296, 0.014442722567764577, 0.012435740027285647, 0.022285087979980744, 0.02415460992779117, 0.09374631335958838, 0.032564378780080006, 0.029263608339533675, 0.023239931470016018, 0.04164182078966405, 0.04075687647855375, 0.10455388342961669, 0.08152200563927181, 0.035239891658420675, 0.062092267762636766, 0.04138931988563854, 0.05424481307272799, 0.042569683500914834, 0.01885700210550567, 0.041838701436063275, 0.06194561196025461, 0.09839181642746553, 0.05253511633782182, 0.05479415078298189, 0.05714069557143375, 0.06500967996544205, 0.048016260770964436, 0.025400225022167433, 0.056521788937970996, 0.013278916267154273, 0.046915896964492276, 0.034940101104439236, 0.06967640103539452, 0.027111892159155104, 0.035445915564196184, 0.05796919213025831, 0.011218814506719355, 0.016188415320357308, 0.017774071347957943, 0.052130983531242236, 0.043830043214256875, 0.0022764930054108845, 0.06299567670794204, 0.05418761204055045, 0.032949813175946474, 0.08459743592538871, 0.04796985427674372, 0.009047104867931921, 0.0277275593180093, 0.026323280471842736, 0.04920237231999636, 0.021353267766244244, 0.05571077737840824, 0.02386769378063036, 0.019813374419754837, 0.0329611828783527, 0.00992328812571941, 0.024133820515999105, 0.0141595394234173, 0.014910500103724189, 0.011937044619116932, 0.07653706648852676, 0.0625184980162885, 0.022675747095490806, 0.019949521411035676, 0.016791482667031232, 0.035084107439615764, 0.024308755855599884, 0.03631403909821529, 0.08656617559609003, 0.03753412245714571, 0.026827373148989864, 0.026479892185307108, 0.009335684353573015, 0.06477994815213606, 0.026650808795238845, 0.036041151397512294, 0.03146103896142449, 0.07995500534889288, 0.06756387767381966, 0.02542665104556363, 0.020725191898236517, 0.030860147962812334, 0.06206318299518898, 0.06854483362985775, 0.009422696530236863, 0.008440090223302832, 0.081916664930759, 0.03913237829692662, 0.09479098269366659, 0.0263228017865913, 0.12796925118891522, 0.03798996811383404, 0.06326934366370551, 0.02628808968438534, 0.10920231055933982, 0.018163619097322226, 0.03310715219413396, 0.025483241661277134, 0.03474446726613678, 0.017766163764463272, 0.06706786327413283, 0.040675782001926564, 0.09436866355827078, 0.018470517570676748, 0.060150627614348195, 0.046454778348561376, 0.031892853876343, 0.03765271765587386, 0.04993618938897271, 0.02693783440918196, 0.07524169224780053, 0.01985935974516906, 0.0351608751952881, 0.015491791909880703, 0.05184803230804391, 0.042491075219004415, 0.08384865344851278, 0.014854557939543156, 0.06434322393033653, 0.06966959554119967, 0.03452973054663744, 0.05549052650167141, 0.0436858476314228, 0.06145949781057425, 0.05639857758069411, 0.03387570548511576, 0.04121575380850118, 0.021795626744278707, 0.022234146963455714, 0.037732906712335534, 0.0726956655853428, 0.006383649106282974, 0.03197360325430054, 0.018915828441095073, 0.041897067640093155, 0.01482527000916889, 0.019442647535470314, 0.005934184064244619, 0.012851628453063313, 0.060214834520593286, 0.06411536975065246, 0.03812237468082458, 0.051744881202466786, 0.05847036445629783, 0.016441931111330632, 0.01945640324265696, 0.02481519928551279, 0.03770459006773308, 0.009277688295696862, 0.04056451180076692, 0.03330412189825438, 0.028125944190833252, 0.06424397652153857, 0.021451433494803496, 0.038237530025071464, 0.013899304412916536, 0.012093042205378879, 0.03821676473307889, 0.021206610108492896, 0.06671506111160852, 0.08238761700340547, 0.05111507241963409, 0.08422346028964967, 0.02264380320411874, 0.03260445475461893, 0.022967346194491256, 0.08978704456239939, 0.005354912291295477, 0.06273262246395461, 0.04526198004896287, 0.07547023662482388, 0.022744451416656375, 0.025208750921592582, 0.08954001328675076, 0.02900443181715673, 0.06574518542038277, 0.024332497159775812, 0.021605725996778347, 0.0337199546629563, 0.023134526090871077, 0.06514167835121043, 0.033210611290996894, 0.02326950791029958, 0.016071397185442038, 0.03701851164805703, 0.01024046719976468, 0.022540540776390117, 0.020197502635710407, 0.02395660678303102, 0.03872630848491099, 0.07927950995508581, 0.02632191863085609, 0.02403031503490638, 0.04249441117281094, 0.028840482118539512, 0.058087401412194595, 0.012912726688227849, 0.045407396464725025, 0.004137889827688923, 0.016619868438283447, 0.06187072183820419, 0.045831537572667, 0.04119504046684597, 0.06137359421700239, 0.03806878419709392, 0.0202665780307143, 0.07333389774430543, 0.018294387373316567, 0.01919154001370771, 0.01420218972270959, 0.07632830776856281, 0.04202409734716639, 0.00385060933240311, 0.03728402611159254, 0.04831226266105659, 0.1225828769383952, 0.021832405727764126, 0.040731728804530576, 0.04119657300179824, 0.03253826260333881, 0.059318067796994, 0.01761656349117402, 0.014254362704377854, 0.042925558154820465, 0.030733856692677364, 0.060726675219484605, 0.029371112141234335, 0.04225795179081615, 0.05624000659736339, 0.04004399168479722, 0.03649557213066146, 0.07119953297660686, 0.02092238239129074, 0.03858236894302536, 0.03545877698343247, 0.023241582748596556, 0.0286998803858296, 0.03283402700617444, 0.04520027418038808, 0.053965795232215896, 0.019328553462401032, 0.048648607698851265, 0.07045740756439045, 0.008901387882360723, 0.029860940740036312, 0.025906076589308213, 0.05252441456832457, 0.018554285634309053, 0.07920470889075659, 0.04445587037480436, 0.04386273481941316, 0.049090055690612644, 0.05468513671075925, 0.03552272042725235, 0.05201067768211942, 0.020888132276013494, 0.08629673146060668, 0.020243222643330228, 0.06687377681373619, 0.08091596042504534, 0.09635957118007354, 0.023721930410829373, 0.08876196792698465, 0.02372729613853153, 0.06298699358012527, 0.039904991135699674, 0.04134510272706393, 0.039637387526454404, 0.06157981479191221, 0.016065543495642487, 0.03405076698982157, 0.05701602960471064, 0.02684534982108744, 0.03915631627023686, 0.018923439165519085, 0.012536267640825827, 0.03465064866759349, 0.012535239766293671, 0.043899437732761726, 0.03464206944045145, 0.01328803076830809, 0.011335336330375867, 0.08866545904311351, 0.02674986324564088, 0.02513817453291267, 0.11045963488868438, 0.040519229660276324, 0.009271811413782416, 0.030828463823127095, 0.011689228522300255, 0.027175505347258877, 0.02588203285995405, 0.09764748683664948, 0.05011541063140612, 0.01569258645758964, 0.08947468202677555, 0.05370755752664991, 0.05855206378328148, 0.07983234318089671, 0.04414725197420921, 0.011696937581291422, 0.0527298150700517, 0.022856467476231046, 0.04422365236678161, 0.0393103898386471, 0.01243280019480153, 0.0516786816297099, 0.01354624620944378, 0.09520485618850216, 0.018377524611423723, 0.06600498905754648, 0.03876403185131494, 0.02778211830445798, 0.047159469831967726, 0.04611171687429305, 0.010022207134170458, 0.021156390830583405, 0.023614114907104522, 0.025366214249515906, 0.00785303471275256, 0.04591134071233682, 0.033824118800112046, 0.020191704606986605, 0.05890423883101903, 0.036247553798602894, 0.021213141008047387, 0.033006654266500846, 0.010160849597014021, 0.11155626940308139, 0.02757329093583394, 0.028794183235731907, 0.03200158222171012, 0.02951877540908754, 0.0050376019498799, 0.037932058330625296, 0.029803659926983528, 0.07993666687980294, 0.05600342105026357, 0.06638427847065032, 0.06372652147547342, 0.03825128573225811, 0.14502408681437373, 0.17404200159944594, 0.13640588207636029, 0.1804758282378316, 0.11329397850204259, 0.13671972148586065, 0.2574543538503349, 0.12432210744009353, 0.3012988355476409, 0.2672220265958458, 0.1446433353703469, 0.09675598936155438, 0.15048589295474812, 0.09000571837532334, 0.08641277367132716, 0.1597093784948811, 0.11748041870305315, 0.1288625001325272, 0.12106344089261256, 0.1793438007007353, 0.06317046732874587, 0.27531333616934717, 0.14440152881434187, 0.1325227427878417, 0.1351430287468247, 0.2974751719739288, 0.12249692881596275, 0.12913194426801056, 0.0866791007865686, 0.1785244102939032, 0.1115408401528839, 0.2263047979795374, 0.1351964782224968, 0.07643293574801646, 0.18821920413756743, 0.17638381890719756, 0.19884304812876508, 0.06485789592261426, 0.1368884858675301, 0.13491728226654232, 0.13203458773205057, 0.18137312930775806, 0.15205464471364394, 0.1541240344522521, 0.2065994858276099, 0.12568235280923545, 0.15195098152616993, 0.09064015815965831, 0.13449603924527764, 0.17507475946331397, 0.277796087320894, 0.07968979887664318, 0.17787301243515685, 0.11160473164636642, 0.09333695954410359, 0.1961568446131423, 0.11215764650842175, 0.09458456173888408, 0.25033766229171306, 0.11228292103623971, 0.25303961418103427, 0.16181862156372517, 0.15461229340871796, 0.24021107208682224, 0.11868378147482872, 0.14612089202273637, 0.1760790336993523, 0.1059094829543028, 0.12270581370103173, 0.0907187070697546, 0.11197612460819073, 0.16736466146539897, 0.15440115239471197, 0.16425083245849237, 0.19422883400693536, 0.08517629627021961, 0.146677102020476, 0.12317542990786023, 0.1052351675753016, 0.11331348956446163, 0.12917550833662972, 0.1759773594676517, 0.07773774268571287, 0.12136473800637759, 0.17083101061871275, 0.14405536145204678, 0.1635321811772883, 0.1471669937018305, 0.19443360739387572, 0.13678753894055262, 0.18455155484844, 0.16556042624870315, 0.1295359100913629, 0.10677074533305131, 0.184037558210548, 0.14673484110971913, 0.091539359127637, 0.3253213543212041, 0.19492014456773177, 0.17712469008984044, 0.09051732529769652, 0.13978455390315503, 0.0909057208627928, 0.15741871000500396, 0.12670384487137198, 0.17001755739329383, 0.15783604932948947, 0.13037910859566182, 0.09472946607274935, 0.1036620297236368, 0.15659525262890384, 0.08444774473900907, 0.10462299222126603, 0.10992758179781958, 0.08174346992745996, 0.11446193340816535, 0.1420432803570293, 0.16482504695886746, 0.11165162795805372, 0.12517668306827545, 0.2405452314997092, 0.1412858592811972, 0.07923709621536545, 0.09090880077565089, 0.17201960465172306, 0.08271961676655337, 0.13608813897008076, 0.17335116601316258, 0.12465096049709246, 0.12940974498633295, 0.17972829256905243, 0.18317783949896693, 0.1702995438245125, 0.14482881291769445, 0.1798388280440122, 0.11906859988812357, 0.10610562516376376, 0.1403964843484573, 0.08795507528702728, 0.17720623727655038, 0.09398906244314276, 0.1725608529523015, 0.11649515829049051, 0.17059934179997072, 0.13765543611953035, 0.17339875252218917, 0.16551848006201908, 0.07205148882349022, 0.09857862984063104, 0.16471801442094147, 0.2555671613663435, 0.16391587152611464, 0.1816693798173219, 0.1026386303419713, 0.0849966520036105, 0.14262095326557755, 0.13706495374208316, 0.18982207984663546, 0.1906749707995914, 0.10466542822541669, 0.0774729295517318, 0.12113988210330717, 0.11314785704598762, 0.2009967013145797, 0.10304806579370052, 0.14860318304272369, 0.10412451389129274, 0.1599433776573278, 0.1341205125208944, 0.09534106255159713, 0.10788250481709838, 0.27172623958904296, 0.21768398088170215, 0.1709677290637046, 0.08505899240844883, 0.10159862169530243], [0.0665496289730072, 0.06191556982230395, 0.0100507260140148, 0.04108230823476333, 0.06505593060865067, 0.035779355093836784, 0.028877298209408764, 0.046334865837707184, 0.0534439021430444, 0.054285716541926377, 0.04037669648823794, 0.04879996871750336, 0.06858432330773212, 0.03236719385313336, 0.0432079750316916, 0.006931110110599548, 0.05655129672959447, 0.04191902778984513, 0.014140546936687315, 0.05608956213109195, 0.01025225250486983, 0.00876563794008689, 0.00403732093218423, 0.012778619675373193, 0.043253958501736633, 0.07213563352706842, 0.08432177259237505, 0.04373441748612095, 0.08692153074662201, 0.05135917221195996, 0.011991309529548744, 0.008001377045729896, 0.07597216594149359, 0.02861474120436469, 0.06650844719843008, 0.09055648843059316, 0.01342819648925797, 0.023527222401753534, 0.03647383833595086, 0.011455690419097664, 0.024442507565254346, 0.006800806140745408, 0.053064902167534456, 0.02891172087402083, 0.026673917418520432, 0.06415108931832947, 0.02488394999090815, 0.042737583280541, 0.07822275103535503, 0.04716282805020455, 0.03890408996085171, 0.007453278722096002, 0.011307898203085642, 0.02901887215557508, 0.03517192577419337, 0.07756805804092437, 0.01040901079250034, 0.003649815480457619, 0.021060525759821758, 0.03697797925269697, 0.019890949261025526, 0.0295586658467073, 0.04018740430183243, 0.01936684457177762, 0.03755620877200272, 0.03799333375354763, 0.009189659376716008, 0.04824036339414306, 0.03545999410562217, 0.04641894745873287, 0.027708183697541244, 0.032855152239790186, 0.04152939283812884, 0.01046093886543531, 0.10253124157316051, 0.02791865492326906, 0.028354393944027834, 0.016332536688423716, 0.08354136720299721, 0.03386866250366438, 0.021374456082412507, 0.0050865354569396, 0.021113711773068644, 0.01710803833702812, 0.025309638476755936, 0.08731787471333519, 0.0519234604871599, 0.02741238960879855, 0.04088147936272435, 0.015391687320516212, 0.045002807237324305, 0.011847677978948923, 0.06561227419297211, 0.04770090366946533, 0.02685790510440711, 0.1145432134217117, 0.03723564921529032, 0.07616905772010796, 0.05725948743929621, 0.06016436105710454, 0.08699248006450944, 0.049599432459217496, 0.06312653960776515, 0.007670161639907747, 0.039188009686768055, 0.02235224863397889, 0.06978010133025236, 0.01928800807945663, 0.05555210620514117, 0.03268001280957833, 0.021617166203213856, 0.027323059148329776, 0.015298303806048352, 0.05168197305465583, 0.022060109622543678, 0.024509215509169735, 0.03694491657370236, 0.040143743754015304, 0.0166200113017112, 0.030888974833942484, 0.05367406440200284, 0.024861741221684497, 0.02167629496398149, 0.059866956507903524, 0.03447406204941217, 0.043707963632186875, 0.012241366912348894, 0.02969795768876793, 0.018142987391911447, 0.012975309218745679, 0.031231492685037665, 0.0032339713516194024, 0.004777279737027129, 0.06986985667026602, 0.03304352045233827, 0.03810889356827829, 0.01981392731977394, 0.031913303755573, 0.028503697358246427, 0.022326377365970984, 0.036943628947483376, 0.04085961569217034, 0.06617358274525031, 0.04636552024749108, 0.027157461881870404, 0.043034498012275435, 0.03787926565564703, 0.04128946762648411, 0.026945589852402918, 0.027584820199990645, 0.03966210104408674, 0.03000727556354832, 0.0828832974366378, 0.057096240925602615, 0.05247053093626164, 0.06548753401148133, 0.005403811010182835, 0.02220316786406329, 0.06637838581809774, 0.05196981132030487, 0.033073005979531445, 0.04285460883693304, 0.08269589772680774, 0.01905652850837214, 0.030904739905963652, 0.0651886711420957, 0.057070547773037106, 0.015079577115102438, 0.05408229386375751, 0.05145909126440529, 0.023584833470522426, 0.060591893779928796, 0.07290917405043729, 0.04423497011885047, 0.0672514112375211, 0.036541989757097326, 0.03236734599340707, 0.046709149464732036, 0.0351626897463575, 0.0669440433557611, 0.001151975886841683, 0.02188193851907272, 0.05352455875254236, 0.025688460336823482, 0.05312245571985841, 0.04197675945761148, 0.03712653495313134, 0.019822126196231693, 0.06517574292956851, 0.01588772862305632, 0.06714736213325523, 0.03812539151113015, 0.0474188393127406, 0.08527962549123913, 0.03324787823657971, 0.0073931638326030225, 0.023068270857038442, 0.020804931955353823, 0.004818486095246044, 0.01861734035628615, 0.046452021269942634, 0.03987580617831554, 0.007162096617321367, 0.0267349201021716, 0.08438053584541194, 0.017254885242437012, 0.0520493027579505, 0.019914566255465616, 0.09908755018841475, 0.028794134996132925, 0.06240005124709569, 0.04069107395480387, 0.009658306153141893, 0.0002438948610006264, 0.0357689056545496, 0.02805713411362376, 0.044208293620613404, 0.0565556939545786, 0.017573038385307882, 0.011842751046060584, 0.029439393438224215, 0.03820599245955236, 0.050189836911158636, 0.08378070982871577, 0.033381624380126595, 0.06254922293010168, 0.04608371193171479, 0.03177077058353461, 0.024355804307560902, 0.029726767861575354, 0.04370193368231412, 0.14278370625106618, 0.02337884667213075, 0.014843321823718725, 0.03661199654743541, 0.014568435890396358, 0.008930999574658927, 0.009910807057167403, 0.030010416703589726, 0.05054797882621642, 0.024024042031669524, 0.014680656040582107, 0.032488397700944915, 0.04245754498697352, 0.0356677175295772, 0.056727686678641476, 0.030110037041595206, 0.03558119795343373, 0.026467698698979802, 0.013423446744127432, 0.08580081354011782, 0.03287033658125438, 0.015936574927764013, 0.07751129116513766, 0.023833842569729313, 0.017315620752924588, 0.025544428026478272, 0.05656511180859525, 0.022584570542676374, 0.01955016061401693, 0.02521769009035779, 0.06281050344114192, 0.02657971104781609, 0.04964648833265528, 0.060199742947588675, 0.0449298392777564, 0.0505878878175281, 0.033430854746256955, 0.09265825807233341, 0.04205300399917178, 0.052748721282114275, 0.020956079606548883, 0.03386661417607684, 0.11630146516836248, 0.038427408508141525, 0.034459846210666, 0.013670519765582867, 0.048388154682470486, 0.06014417092956137, 0.034181678129243664, 0.017031478382705245, 0.02462190321239177, 0.0928633802686818, 0.020490491406235378, 0.0270117022228078, 0.04448534476978239, 0.02307399652636377, 0.045271731869434007, 0.03331244508444797, 0.025065928311960306, 0.05023519697715528, 0.04627428432286251, 0.030410651379497722, 0.04961967082635965, 0.024755532467679586, 0.047017719625728205, 0.021381445258157328, 0.025487560960755218, 0.07341031669056974, 0.021556423271249514, 0.0354466651333496, 0.061623712826985866, 0.013549071936722612, 0.006615763677473296, 0.03304005462268833, 0.016300483330269344, 0.02716074031923199, 0.09245540684787557, 0.01982627851248253, 0.037629993094014935, 0.010052369871118572, 0.022419552151404787, 0.06217058289621491, 0.01702038884104695, 0.02632586685649585, 0.04961549253494013, 0.05631955369608477, 0.05937430032645352, 0.02680023837456247, 0.06915598482009955, 0.044940151419723406, 0.034146771213272586, 0.037835764669580385, 0.03521456215821672, 0.0523070951749105, 0.01644151550863171, 0.005353466958695208, 0.008672713629493956, 0.03918537506251596, 0.02571766570326872, 0.0454386074852664, 0.008738841770536965, 0.04140874189033639, 0.025618464678700548, 0.061792254564352334, 0.020044377160957083, 0.02305234065715922, 0.021860293782083318, 0.04731184017146006, 0.052245014521759, 0.03428734511544462, 0.0297978897287976, 0.04496666464547161, 0.027434301518951543, 0.040109040928655304, 0.039769886861904524, 0.043000002988264896, 0.03697941530845128, 0.03587301784136798, 0.07735980398138054, 0.025249249920307193, 0.04456739661691245, 0.11738883767975494, 0.14632462640292943, 0.15440642164321616, 0.11327301283017732, 0.17034880758728832, 0.09699234113213606, 0.14746742992429063, 0.14091474091401324, 0.14273609005613253, 0.15011894545750692, 0.1369912436348386, 0.14081089961109683, 0.11920426448341459, 0.10431956514366902, 0.1595273890416138, 0.13718316302401945, 0.15041141101391986, 0.22530282440129668, 0.1198560482589528, 0.10801417665788904, 0.15200213034404442, 0.15633351198630407, 0.1444969986914657, 0.17174150707433, 0.14082807290833443, 0.18933830346213654, 0.1748716484871693, 0.09277450808440335, 0.25995126517955214, 0.12438373538316227, 0.183901225682348, 0.10850123333511874, 0.11814987301477231, 0.08549495963961817, 0.16188643901841715, 0.29031484213192016, 0.08033687001443468, 0.07264700296218507, 0.10750409113825299, 0.14856922236504033, 0.09242034037015401, 0.1278586414991878, 0.0930885256093461, 0.07753348880214617, 0.11318325749016367, 0.12149329282692634, 0.18128487310605124, 0.20710009412141517, 0.2513107069535181, 0.10995333432219923, 0.18820002704160288, 0.0730029221449513, 0.13439613132504746, 0.07545998014393263, 0.12507729465141892, 0.15596384822856635, 0.10202551988186315, 0.11236437174375169, 0.10683258107746951, 0.11081772856414318, 0.08672978947288357, 0.1051050542446319, 0.14706128218676895, 0.06788822589442134, 0.1313131459755823, 0.1306604567798786, 0.07445783587172627, 0.11951161752222106, 0.12476507312385365, 0.22477632999652997, 0.13638609641930088, 0.16985487862257287, 0.10354091864428483, 0.10528521801461466, 0.30625783663708717, 0.12677751044975594, 0.06278594577452168, 0.13076049828669056, 0.11183679380337708, 0.17261652887100354, 0.11045107792597264, 0.11167910226504318, 0.1539564723498188, 0.04539535140793305, 0.09853588955593295, 0.2031619765330106, 0.24349802930373698, 0.12847196718212217, 0.10132661715033464, 0.12680865096626803, 0.1971661951392889, 0.12895053368993104, 0.22639951086603105, 0.14997134712757543, 0.11267611087532714, 0.1651996237342246, 0.1640806728391908, 0.15907659369986504, 0.1291394844884053, 0.11497023777337745, 0.14654695900389925, 0.08449176893918775, 0.21073905198136345, 0.13572798954555765, 0.05654118867823854, 0.08928570154239424, 0.13070636603515595, 0.09203066831105389, 0.1527850070851855, 0.16643832757836208, 0.11715022978023626, 0.10611996345687658, 0.11047247404349037, 0.13860425708116964, 0.08610466364189051, 0.08900942964828573, 0.15272262215148658, 0.1896106865024194, 0.08307123149279505, 0.11986021912889555, 0.10793432898935862, 0.12216234637890011, 0.14080986060434952, 0.12697012745775282, 0.1255084972945042, 0.17146737256553024, 0.15320276201236993, 0.07021182347671129, 0.20491461764322594, 0.10632495206664316, 0.13047091226326302, 0.17567874892847613, 0.0850318001175765, 0.10595154788461514, 0.10312242156942375, 0.10149578229174949, 0.15564859873848036, 0.0792242496390827, 0.12402248758007772, 0.14527787163387984, 0.16333331528585404, 0.20086462871404365, 0.1489452092209831, 0.1432710894732736, 0.14757214696146548, 0.0971259870857466, 0.1620383418048732, 0.1411917549557984, 0.13687159458640963, 0.1660777922370471, 0.08611515018856153, 0.17505424650153145, 0.2409563516266644, 0.09964911107090302, 0.0983036270190496, 0.164145877934061, 0.10009226971305907, 0.07877616313635372, 0.16038850299082696, 0.13783936999971047, 0.23090880014933646, 0.19136116054141894, 0.19998150266474113, 0.10820580660947599, 0.09445343908737414, 0.17709182779071853, 0.1427391922334209, 0.11230039119254798, 0.1665803894866258, 0.07956974164699204, 0.11600348545471206, 0.13698253082111478, 0.2940958767430857, 0.13274644094053656, 0.14148197922622785, 0.1604700947063975], [0.032174443258554675, 0.08422557541052811, 0.07295121671631932, 0.02458497394400183, 0.015837403589102905, 0.010462245973030804, 0.02780842001811834, 0.02152858902263688, 0.04340120802226011, 0.04075287259183824, 0.0275641588086728, 0.01722028260701336, 0.029470686095010024, 0.01115900853619678, 0.02607222861115588, 0.03512902221700642, 0.056844359714887105, 0.024125154086505063, 0.07399545560474508, 0.012568138245114824, 0.09385147568536922, 0.03781379338761326, 0.06080109778849874, 0.0680034740071278, 0.01160079698820482, 0.02957258482638281, 0.025042845663847402, 0.02079289060930023, 0.05578703305218369, 0.03385180461918935, 0.014429859293159097, 0.031876727007329464, 0.057297696912428364, 0.05421432193543296, 0.0427345293428516, 0.05569321074290201, 0.0043896573970414465, 0.061552815459435806, 0.04775061643158551, 0.06782290947739966, 0.03903498625732027, 0.08279003173811361, 0.02722932033066172, 0.026702792529249564, 0.02239812078187242, 0.06936429825145751, 0.058073092804988846, 0.027094522192783188, 0.045506306196330115, 0.042393449402879924, 0.013689058614545502, 0.043386320539866574, 0.06030076780007221, 0.0646544509800151, 0.021738702162110712, 0.024929516002885066, 0.02080924568872433, 0.052535903014359064, 0.03228975445381366, 0.017103847058024257, 0.02520508656743914, 0.009311060821346473, 0.03905215584381949, 0.03981203342846129, 0.05458872430608608, 0.0378074109175941, 0.03459829014900606, 0.04866422990744468, 0.017002113454509526, 0.04225388853228651, 0.07082008771249093, 0.04318220766435843, 0.09598342847311869, 0.08706915134098381, 0.04610832897014916, 0.0558845660998486, 0.026036581402877346, 0.01721939759590896, 0.11838026533951052, 0.03659020709164906, 0.04556815307296347, 0.07121485090465285, 0.00486850731249433, 0.056861173070501536, 0.026769613650685642, 0.01599786333827069, 0.029882654125685804, 0.024807582994981203, 0.010333679092582315, 0.030524251924362034, 0.02849620723281987, 0.05277077420032583, 0.08388017988181673, 0.030463800285360776, 0.004314090529078385, 0.03194128272298258, 0.026339720898249652, 0.05019390388042666, 0.012493773192545632, 0.025993228846346028, 0.05885948361537885, 0.07366172663751058, 0.0291529875175911, 0.02197498342866311, 0.029220135184004903, 0.07602060592034832, 0.0196353758656187, 0.052432540396694094, 0.04659853977500461, 0.03912424806912895, 0.013996082325320458, 0.0385305039526429, 0.05215562654484529, 0.057777005567913875, 0.04355388635303825, 0.02590854051959468, 0.045743541122647, 0.03765547844523098, 0.03277002790127881, 0.06898523148265667, 0.06011342746205628, 0.04907354661554564, 0.032310282258549705, 0.044121250830357894, 0.010621833698678529, 0.10071531753055751, 0.03464670786343049, 0.09668119571870193, 0.03382332099135965, 0.04774483139044605, 0.018142454900953453, 0.01870054995379178, 0.07734830069239251, 0.07299888486159034, 0.05918336428294424, 0.04534123399935197, 0.021585617505479604, 0.05929633029154502, 0.10196047063800506, 0.017746899466146715, 0.008246636443800526, 0.046066126742516644, 0.05138508800882846, 0.02367167402553605, 0.030406697587750386, 0.019701354649441782, 0.036388098014867865, 0.025175139053317253, 0.02462456381181255, 0.01183771464638994, 0.01421422086423263, 0.023819892048777547, 0.08738666438148357, 0.005495588238773053, 0.023919007726362906, 0.00459456715361739, 0.03332143991428893, 0.047820805048104376, 0.011329153312544804, 0.041060084622586146, 0.11472305064671673, 0.0478061698959209, 0.12582765048136935, 0.012494186012190767, 0.10532033644267358, 0.02862889952666592, 0.07040936092380434, 0.01935095147928223, 0.02297079532581847, 0.09885653445962816, 0.02021232146944385, 0.051507698226487264, 0.04578044070512988, 0.02086832064378541, 0.03057865505979862, 0.010617569132591598, 0.028846313543908764, 0.06785448043956421, 0.023960011385497637, 0.012126491728849942, 0.05955191852990538, 0.009653875531512313, 0.04232184699503705, 0.03372344646777492, 0.023459254662157036, 0.050690545394900255, 0.05014930822653696, 0.04371586750494316, 0.015932585884002037, 0.00919179490665556, 0.03734138670552056, 0.02962133465189254, 0.02154493111447664, 0.0035336515111339395, 0.0587751273997128, 0.03760753941605799, 0.031996672914829105, 0.02865910493710544, 0.02663326999027049, 0.07139306282624602, 0.034034836789942347, 0.08488150779157877, 0.010609044638840714, 0.034846286216634326, 0.03578560397727415, 0.011613141687121242, 0.05733969133871142, 0.010399668080935953, 0.01868559753347654, 0.039809261506889015, 0.046466070125461556, 0.020317533890192863, 0.011810569667431992, 0.04140840421314351, 0.012990959257876966, 0.05398621171480045, 0.06251775586861186, 0.08194335998268798, 0.021709695320168976, 0.05984273651847616, 0.012533559729490662, 0.10388158669229597, 0.0667854463972617, 0.02245154057163745, 0.024320229458680842, 0.01883408458525082, 0.014501905134238768, 0.018348909252381418, 0.12296132030314766, 0.013347881267691264, 0.02665795382199576, 0.05869313121365849, 0.06236462853848934, 0.021954437070235144, 0.028798508101317566, 0.031787572806933895, 0.030171399666869547, 0.07970303879119456, 0.041397045642952435, 0.03876097049214877, 0.024334385925612878, 0.06389737871359102, 0.012423010339261964, 0.021009384363424033, 0.017187253324664198, 0.026320224678784143, 0.031156880868365988, 0.052558957831934094, 0.0345285653747851, 0.058498554935795255, 0.06383091938914731, 0.0616485599312, 0.0029123210697434843, 0.0262179845594801, 0.0485059372294927, 0.04537658991466742, 0.018083216673403513, 0.05150882629095577, 0.040639635699335486, 0.04043198649014812, 0.03830205605481751, 0.025401566454092972, 0.042768193161464296, 0.057704468053998426, 0.03137443774903659, 0.03410720360989217, 0.020396969666762743, 0.05424300594313536, 0.013313344497873913, 0.03760794017580338, 0.019972772897745017, 0.021973061266180594, 0.038606692833127454, 0.019516619249770883, 0.09601728525012732, 0.022378190406016074, 0.01763197418767959, 0.0219043847755529, 0.05875383889360819, 0.044966749992454425, 0.015332913862948772, 0.052853668385068886, 0.025750800741661806, 0.045284719453775324, 0.021751882704847958, 0.021039856947027147, 0.05293177571729757, 0.018981940811499953, 0.05864566715899855, 0.04535126412520185, 0.046128648973535746, 0.03251897789596114, 0.036434964640648104, 0.024869596854841802, 0.01770609804225387, 0.012431508857844165, 0.014570176226698095, 0.08348801420652308, 0.030774129336350597, 0.016664495633449405, 0.027630388067336753, 0.03285655489889905, 0.050790327150025405, 0.06685253654723056, 0.06357139776810072, 0.06619673033128493, 0.036534174942062236, 0.08355712299817242, 0.03680357454868499, 0.03726574330357835, 0.02640937516844133, 0.04135625720664393, 0.005201144394959556, 0.027376063335395884, 0.048563101154286414, 0.012363925179670332, 0.02040195689914981, 0.03799548969254829, 0.039186940994113684, 0.05291116627631709, 0.03100885765888961, 0.04149319829593878, 0.01681754318269668, 0.011026372831111075, 0.0563115125260083, 0.02593536915810546, 0.018085064621118363, 0.05180901018320583, 0.031054971004778054, 0.02095652303978568, 0.04036877035105135, 0.06625720794545487, 0.006754858386557316, 0.05256975236989092, 0.07812627183739096, 0.04582025321724359, 0.03204058208211791, 0.06321141903754324, 0.046627876872662455, 0.02790684549836442, 0.09262000778107904, 0.040248278965009376, 0.1101798823219724, 0.026785026202560402, 0.05896411901630927, 0.043584611266851425, 0.0477015753131127, 0.013991260220791446, 0.08270943450042978, 0.04370090951852035, 0.030771990095672663, 0.056798892037477344, 0.13958816678496078, 0.1607425816473551, 0.19873873185133561, 0.1408424854162149, 0.18203356652520597, 0.04357849968073424, 0.18334431806579232, 0.16660801222315058, 0.12072088778950274, 0.12087534356396645, 0.13187910779379308, 0.09570182795869187, 0.13878011639462784, 0.11028213542886078, 0.14151325332932174, 0.10983883577864617, 0.19861998822307214, 0.13475139741785824, 0.14592140272725374, 0.05738248357374687, 0.11540679872268811, 0.14281201176345348, 0.1001866783190053, 0.1511265296721831, 0.10161897138459608, 0.1563811578671448, 0.05736843100748956, 0.21113636816153303, 0.08958291684393771, 0.19246596610173583, 0.1959370798431337, 0.1860995710012503, 0.11435938344220631, 0.12323455681325868, 0.1990875115734525, 0.12210166096338071, 0.0759665181976743, 0.11756770269130357, 0.1110772204992827, 0.13878250611014664, 0.13924752100137994, 0.22530874673975632, 0.12965598958544433, 0.1504363026469946, 0.19142359000397846, 0.17668234038865194, 0.11884520601597615, 0.045573600436910056, 0.2872809424297884, 0.13048201479250565, 0.13058888405794278, 0.16432347387308255, 0.1866596846957691, 0.13492473342921585, 0.08440497476840392, 0.1610986641026102, 0.18218064535176381, 0.08177768293535337, 0.14649062999524176, 0.18870591942686588, 0.13692790875211358, 0.17799353721784428, 0.11869636829942465, 0.15879851096542552, 0.13369414868066087, 0.16442811669548973, 0.14223272097297013, 0.10554348540608771, 0.13197797670727596, 0.1908889171318151, 0.16012082516681403, 0.19817982043605298, 0.16222873236984015, 0.16355184809071943, 0.15392099769087508, 0.16725276043871418, 0.1493794991984032, 0.11766974799684249, 0.1475082925753668, 0.20422918489202857, 0.0924179506546352, 0.11242096792557277, 0.09984502321458422, 0.10361655833548866, 0.16612116334727034, 0.09165172770735808, 0.0966526972479187, 0.19220918300561607, 0.1273016448249109, 0.1459280968992971, 0.18522687954828143, 0.10885439172852784, 0.19030201190616935, 0.08361860251170583, 0.2086605635122396, 0.09829276939854026, 0.08137553537380882, 0.12216129252919927, 0.17732794949552044, 0.07300402052351274, 0.1056193551630713, 0.15802519308635965, 0.21542135073104873, 0.06967048611841165, 0.09614243361284025, 0.1395731754018925, 0.1404278475092724, 0.15089395543327555, 0.2071064172196202, 0.10937771716271527, 0.143844309495762, 0.11341786521370523, 0.16465773718664423, 0.16482446808367968, 0.12677237478783354, 0.14909783931216225, 0.11293970688711852, 0.05660921764501836, 0.18831580207915977, 0.15932788490317762, 0.19572892226278782, 0.22119301836937666, 0.23339548468356952, 0.09299499273765832, 0.10609291959553957, 0.30959352327045053, 0.14287264522863552, 0.2395102323498577, 0.15791149606229737, 0.1503521579434164, 0.1340045890538022, 0.135028010699898, 0.24172989215003327, 0.20446058653760701, 0.13276432669954374, 0.11190464094397612, 0.101589641708415, 0.20884256780846044, 0.1337081752717495, 0.12824877368984744, 0.11173926075571217, 0.11410800318117253, 0.14077751780860126, 0.1655412491527386, 0.08686117187608033, 0.1578669375157915, 0.13437572226393968, 0.1886327881948091, 0.11339296615915373, 0.13058296171948314, 0.08194891866878606, 0.12006009434117004, 0.1932290571858175, 0.063939169049263, 0.1526573279988952, 0.12704967084573582, 0.11514621583046392, 0.11488534350064583, 0.11739436667994596, 0.12786109058652073, 0.16370997007470578, 0.161607168847695, 0.1826729712774977, 0.06961090650293045, 0.24145878560375422, 0.10323580689146183, 0.20188362715998664, 0.12646148912608624, 0.19007783877896145, 0.23427975364029408, 0.12880249007139355, 0.12272532476345077, 0.12746996391797438, 0.11122598400106654, 0.1195882294268813, 0.10442290178616531], [0.0703687357599847, 0.04008912539575249, 0.040952406416181475, 0.026574955736577976, 0.0604617136559682, 0.06338065097224899, 0.08406072956859134, 0.01669758614298189, 0.03476031211903319, 0.01110436234739609, 0.009402345913258614, 0.017637731398281176, 0.03080242186115356, 0.06079406593926251, 0.022701408706780057, 0.05260294863546733, 0.033522936719236895, 0.07501676955143921, 0.028778009982488584, 0.06950554379727691, 0.02845176186383469, 0.0447648895351449, 0.011287014167464804, 0.06511340252473019, 0.054381627996917814, 0.014160365990392165, 0.02702356916415738, 0.00837845114801894, 0.06814395514084026, 0.025044636095117312, 0.02022729615418939, 0.0013500156751433678, 0.04159852389420848, 0.10495671376702376, 0.047730571022839285, 0.05256706579530146, 0.08216434929636307, 0.09001487647765316, 0.023051733951433562, 0.02193932879890781, 0.04637558748072479, 0.09742910988279618, 0.04191119071037974, 0.06599728556466289, 0.10080424908665009, 0.03640260700194631, 0.01893023909360636, 0.04057210397149902, 0.06734275477356277, 0.06375057448167354, 0.04371843904664274, 0.060454184567788616, 0.005875515435036505, 0.013674767633347074, 0.012908367498312145, 0.0377293072961038, 0.04133092028496321, 0.018610074730531778, 0.04793546315340791, 0.09893381429719739, 0.05354690110834781, 0.03817145661741961, 0.025205658021150157, 0.03330872321384959, 0.017932471637323033, 0.04335856792749837, 0.044855090163764544, 0.07652047206647694, 0.029744169369223528, 0.07240103295771405, 0.014235229209589306, 0.04445793354534544, 0.03840377110464033, 0.04826814940315671, 0.04242871997121256, 0.04117076481634285, 0.058435220053070225, 0.05226821405813098, 0.03829200366453733, 0.05076725748949684, 0.011465672305348562, 0.04976111675205175, 0.054612773601547815, 0.015828189825697336, 0.06346650261548348, 0.07016266361461021, 0.059058342085336335, 0.04332438089477364, 0.024027826984820422, 0.03688970820803661, 0.04324066292610951, 0.025506756610411685, 0.012559914321172982, 0.02399079196038656, 0.03616180234530475, 0.06077792793803383, 0.014990780073276255, 0.029056035200483166, 0.05239472055109218, 0.02821927297190996, 0.008316835264849942, 0.033594372143852524, 0.04616037578671239, 0.015891062721493654, 0.0285384725430049, 0.057696972362464294, 0.05759854131611064, 0.07221282430691645, 0.034213226826977916, 0.06651174975559115, 0.029813443288730923, 0.04127872132812627, 0.08687818190082908, 0.07343433258938603, 0.06966702771023847, 0.01545520402942202, 0.10139081292436458, 0.017184678072226234, 0.03296897171821911, 0.0336219985911157, 0.017538554493512493, 0.05277879681671038, 0.004762639018736081, 0.04368156543932855, 0.04730585103970952, 0.03632069616287481, 0.0421048318821704, 0.03116774962109048, 0.026002197701018304, 0.06350117575493641, 0.07208588736830279, 0.02365045787882991, 0.00018835339858469524, 0.013646068782691145, 0.029365087757469155, 0.04774413748236839, 0.08451618559774943, 0.028647475483012386, 0.10532665211940184, 0.04693082155426964, 0.048331866491935216, 0.029361482775129844, 0.07912855711765587, 0.03208899237506557, 0.05235527169134002, 0.032183671864913777, 0.021948230860289186, 0.02968169908854179, 0.021529826553887688, 0.019849453929055016, 0.03145695343846455, 0.02871234290068969, 0.03309613501187414, 0.054896110741537996, 0.029359992913668975, 0.029971457661304157, 0.04559890767268371, 0.0036621008075599093, 0.085693298606202, 0.048836875721463, 0.02240895242721308, 0.018077546665153932, 0.009821493295021355, 0.044943524480913766, 0.037890973035246134, 0.06115293886978179, 0.01896940593724139, 0.05521236584172584, 0.041241124126827344, 0.02205603708716808, 0.054412913232226856, 0.09791110511287116, 0.011144101572426734, 0.03490074501314666, 0.04287145558919292, 0.0676269231189508, 0.0843893970886711, 0.04638427431927994, 0.016413851953984704, 0.06217453112185467, 0.0018992276841345301, 0.04198171700409148, 0.033090290598920546, 0.07527779773226939, 0.08860040237777866, 0.06642974243732169, 0.031773253067512996, 0.04675245007092599, 0.022781575498811435, 0.05935525681707077, 0.04069759001140483, 0.0745363550959155, 0.01083923101759865, 0.021979738739901222, 0.06394719166564755, 0.04665133987145964, 0.06023948124493472, 0.07539434460340999, 0.029273671862029005, 0.04122305654163938, 0.09037339317728765, 0.04646224435418844, 0.010591376885713544, 0.018219124322058633, 0.07223344116937369, 0.021763369295513257, 0.03803292362135835, 0.03015088484971784, 0.026661814845283516, 0.10017011358286254, 0.06099988575442694, 0.05201346815738361, 0.015572863194392994, 0.05363904245314188, 0.06695452248095535, 0.02290405212988844, 0.007334986412388389, 0.07281043130205944, 0.06371544121066108, 0.07329346553888172, 0.05844003288075328, 0.03855310977087356, 0.07467794202966616, 0.03211531635315623, 0.02631279578054091, 0.062204810747061856, 0.0495690452225972, 0.01887566155346576, 0.023239413822011556, 0.012945296766702086, 0.02001474505959777, 0.02965147141367197, 0.033023478754330426, 0.04737008021038491, 0.04950963630108163, 0.024984529554785695, 0.018163203494623303, 0.023673690811847337, 0.027942531669395976, 0.047258676422643475, 0.029773408132314216, 0.019808828765235376, 0.024812247393128928, 0.020739691608469002, 0.013084902166156098, 0.052969766256865114, 0.05021096585551277, 0.006207985998116783, 0.016845592654135544, 0.03955138003220782, 0.024112862265610602, 0.02686065847228747, 0.06546169242938049, 0.01083744708012091, 0.03691080004500691, 0.04707596337539144, 0.01645762567932252, 0.021332385585992597, 0.05101229980937205, 0.01655675619986141, 0.04301676439354196, 0.10853903833776712, 0.005911763319090824, 0.09006598818814382, 0.037400042347144336, 0.016563224016863387, 0.022603135366807692, 0.012220739845361095, 0.010837657664524158, 0.030803002591710538, 0.04219522175844759, 0.034090089684468694, 0.012844926859543193, 0.018770170827338006, 0.052376667808857746, 0.05646651377901435, 0.017483487135905307, 0.027949791729042772, 0.015352892478404101, 0.008227394409914268, 0.004781860179718933, 0.01896841702546226, 0.03882586759573314, 0.025614547994337045, 0.052627754921559244, 0.008888224037946202, 0.011282062187092379, 0.022650695900665596, 0.07874743459979072, 0.042707693282864057, 0.0477436254004715, 0.011620436071098084, 0.03662082439404912, 0.06122112739831209, 0.049075813876697794, 0.040043127082753927, 0.02213731153460685, 0.03255038187489845, 0.02190848143072799, 0.06137495976872742, 0.06539103997056372, 0.0885357910010498, 0.06634288889472373, 0.06649689938058145, 0.04509605438215658, 0.11662170189083554, 0.047031939175212756, 0.036500963833532296, 0.030991697349236347, 0.03736766615475062, 0.02996844083099859, 0.030002332860021852, 0.08833330342895351, 0.018930163023469504, 0.03676609238027595, 0.030829218958388083, 0.04102602004422806, 0.025366054687765427, 0.08143740080413409, 0.050153894699178636, 0.019119581374980044, 0.06219564893399365, 0.09587110442225821, 0.014453371459239861, 0.05473896839248482, 0.033648181561147794, 0.03797492478042841, 0.032199494453379884, 0.051850433155777864, 0.03982864640420303, 0.03699753484397661, 0.0758526282152161, 0.023035384438117035, 0.039086955148377456, 0.037705766371800564, 0.01092901140509639, 0.061624640511581674, 0.019646710316010285, 0.036930029091308825, 0.0424921402009204, 0.06986751890508458, 0.07284975770744495, 0.020404164788487833, 0.02428373434668174, 0.02418903815851081, 0.019150673651893158, 0.03192200914782006, 0.06097445235354826, 0.039592736211488955, 0.0153174595652672, 0.031396089907502756, 0.06195406873303, 0.1660596689907834, 0.1873888893169351, 0.17500340938568115, 0.1845250156475231, 0.07862499507609755, 0.133942308020778, 0.1892224096809514, 0.13219808286521584, 0.21183959761401638, 0.14454612886765972, 0.09890061061014421, 0.1239652828371618, 0.09544811735395342, 0.1856428533210419, 0.1008262908726465, 0.18986470880918205, 0.10699095539166592, 0.1209220766031649, 0.24223784770583734, 0.1819292057189159, 0.14095236780121922, 0.1790835295105353, 0.07160734312492423, 0.2261458002612926, 0.19765571574680507, 0.07238722901092842, 0.09026213781908154, 0.07262632672791369, 0.23365395987639204, 0.12836653768317774, 0.12054182239808142, 0.046985072549432516, 0.1138466558768414, 0.2598356088856235, 0.20398779393872246, 0.1492289174348116, 0.10926261747954413, 0.1346827784436755, 0.14268647006247193, 0.14754597883438691, 0.1394512999104336, 0.339137947303243, 0.12719529506284744, 0.10694728000089526, 0.17807768192142248, 0.12122813088353723, 0.13419576629530638, 0.12317038330365904, 0.14093543199123815, 0.1235040306346491, 0.1544989229296334, 0.1742730470141396, 0.15039928432088345, 0.07892132722190581, 0.09987335099140182, 0.15800420515006408, 0.11430223064962775, 0.13306939392350614, 0.1649054660811089, 0.24582467711297795, 0.11265244378591888, 0.13385979604208842, 0.143576601985842, 0.11741079040803015, 0.1878682425012812, 0.17983379628276452, 0.1821078109787777, 0.2394424148951657, 0.13578883081208915, 0.24416646687313914, 0.12461257661925629, 0.13244808273157105, 0.1680960480007343, 0.10853399915504269, 0.17164017423056066, 0.08959942220826633, 0.14155328477500007, 0.17327853944152594, 0.0874228663451504, 0.16514670860487968, 0.1007690341793932, 0.12861149094533175, 0.10048717391327955, 0.12686549947829917, 0.19984321086667478, 0.1292788895079866, 0.2156552014639601, 0.21536990505410358, 0.1275462270132266, 0.1310598658164963, 0.14568566693924367, 0.08273779938463122, 0.19348667148733512, 0.1025527341698762, 0.12833998363930732, 0.11259106075158343, 0.0654652547382284, 0.09838040961767547, 0.16971675009699538, 0.1512825142708607, 0.09142694601905532, 0.0772456542472355, 0.22175893565872684, 0.13920429832069203, 0.09645544923841953, 0.09198231738992035, 0.10991946270223707, 0.1606014696881175, 0.11838191290735267, 0.11893601520569064, 0.12373614474199712, 0.21963201463222504, 0.23191495944047347, 0.12433191121090204, 0.14633654529461637, 0.162864129524678, 0.11671701591694728, 0.1677109327283688, 0.2132736347266473, 0.0845469327759929, 0.12050375022226945, 0.12825107434764504, 0.08325805974891409, 0.13045342726400122, 0.13287175999721512, 0.2689992624800652, 0.13249513489427045, 0.12141906321630813, 0.1328395211021416, 0.18195478012785316, 0.2625336719211191, 0.08145967265591025, 0.08673788630403578, 0.13735477725276724, 0.12318751207203604, 0.09065641861525364, 0.34243510162923485, 0.10546264325967059, 0.1094967799144797, 0.09045340411830693, 0.13316446304088458, 0.09809707247768529, 0.1593910565134138, 0.13220630586147308, 0.12772037938702852, 0.1194359184592031, 0.1275521345087327, 0.09917938354192302, 0.11296504380879924, 0.0772296312788967, 0.10791607957798988, 0.09000056044897065, 0.1387478774995543, 0.07327320490730926, 0.12691911222646013, 0.13363801263039932, 0.09967916063033044, 0.22135692910524085, 0.21575130958808586, 0.2308357134461403, 0.15326434542657807, 0.06367348760250024, 0.07912343629868701, 0.1440263880067505, 0.13064191793091595, 0.10178237746004015, 0.13364871439989656, 0.14385465503437445, 0.09030800254549831, 0.12003309500869364, 0.15215663064736873, 0.2219043966033496, 0.07840304097044282, 0.1234804377600085, 0.11476118219434284, 0.18483536696294323], [0.03670368889288511, 0.04746737948153168, 0.04291275610739831, 0.014454943884629756, 0.03917556758096907, 0.01448344235541299, 0.06780927622457966, 0.02229358742624754, 0.03701993286085781, 0.06299627784756012, 0.05046889928053133, 0.020967354685126338, 0.06653149088378996, 0.028182154455862474, 0.017337419485556893, 0.03984108108852524, 0.012143201183789643, 0.025528445876261685, 0.004364013875601813, 0.031171864829957485, 0.002984339776048728, 0.011966790825681528, 0.06047310933354311, 0.015759667330712546, 0.0223599038872635, 0.055721642420394346, 0.019931713577534538, 0.029743479171884246, 0.03804417086939793, 0.07586771607748233, 0.05858703007106669, 0.07422686467180029, 0.03754815275897272, 0.04073289397638291, 0.04524623538600281, 0.013052413723926293, 0.013187350086809602, 0.03216397155483719, 0.02410982873698231, 0.005424638457043329, 0.009857130298769334, 0.013483334350894438, 0.04986829400877468, 0.05128662356582936, 0.05265764491923619, 0.02947754539491143, 0.01741225023579318, 0.045013364288024604, 0.03847703221254051, 0.0457584360265173, 0.015317631186917424, 0.04687933876994066, 0.044468646447057836, 0.022379468755389098, 0.020860739605268463, 0.03617126843892038, 0.09315890347352251, 0.040365434397244826, 0.06931944284588099, 0.040942728810478, 0.0461998135142494, 0.035131356271449476, 0.04637483420083299, 0.005714040798920905, 0.05630955325614195, 0.0523617617727723, 0.023714967210253235, 0.01286381730096764, 0.07396838947897777, 0.06773261236958206, 0.05664758296916261, 0.042692705610534176, 0.02736636346526211, 0.05806728921015747, 0.03196850841050036, 0.031978505139704794, 0.026334820868214592, 0.06099197817093227, 0.038678818455082364, 0.06453932903241366, 0.010917753024841659, 0.041929714716388844, 0.03610631938499864, 0.05262934682832565, 0.04641149629605934, 0.09620470722438768, 0.09364600467961282, 0.016428164271928836, 0.04572069039568305, 0.040824716197676025, 0.05486898895469494, 0.051261579792480916, 0.11245898072957061, 0.04548503624391742, 0.04586411414493341, 0.020234138755768072, 0.014331995989778079, 0.012203885671624448, 0.010420552116556792, 0.07929703948320821, 0.08238209542469122, 0.0018246293188894924, 0.04211213090457022, 0.062007540473132394, 0.018299825460417196, 0.07817889752914198, 0.06162168676382862, 0.04254188635968603, 0.04702334510511719, 0.09103145552217029, 0.01937408793310169, 0.06248699384741485, 0.02679321765754139, 0.0506678727833787, 0.010660421667125775, 0.05725188042561058, 0.08713394825463183, 0.07804738153936341, 0.07159770262660459, 0.03677553620946128, 0.02525189753214363, 0.07228650472825393, 0.057456305003142916, 0.08917266502976418, 0.08377976730116643, 0.047027118926052935, 0.03281107608927414, 0.05149969416379463, 0.017444489130866714, 0.009841727951425128, 0.09056488212081604, 0.006773053064534906, 0.047202547793858685, 0.10706133325584233, 0.05307218263624236, 0.022013743946445175, 0.005494441620612633, 0.0740713179402519, 0.031949988115229644, 0.034522542846389115, 0.061345552167040296, 0.12750028807204217, 0.03189913244568743, 0.010480910059413873, 0.04075618999195285, 0.015456892415386392, 0.08024385664612055, 0.053189894679235294, 0.028388239588821307, 0.04787676669366192, 0.0859464006498456, 0.020881981727143284, 0.039570093285874464, 0.017721098702168092, 0.07055511130602099, 0.015946835119393654, 0.028267696252441965, 0.008290933383250376, 0.02802464474370936, 0.030503655470965896, 0.03959898138418794, 0.05985393923765514, 0.06264433657634072, 0.05591409615590237, 0.07896446084487252, 0.036073742812732235, 0.020398980886966456, 0.06036556471372023, 0.039851341280154884, 0.063928237213986, 0.016979390748019796, 0.013691031799680786, 0.019106501022179145, 0.04432428388099652, 0.06085837303544395, 0.07080707786371931, 0.04829209479794372, 0.056197448138846084, 0.049815082020359114, 0.06609703763388097, 0.00639203351965989, 0.034458280279068276, 0.047854197982815094, 0.13392359105637297, 0.008908490235626232, 0.04302168483263813, 0.005127557205923949, 0.053141354510444216, 0.04789994767634198, 0.025375817640451714, 0.0220731621448067, 0.09621508987038396, 0.018455342506058514, 0.05775231431471184, 0.016300618772220332, 0.05477779755892698, 0.036943513914593495, 0.02835186507581966, 0.020775661650986876, 0.00716899905455648, 0.048991101430146955, 0.02736282898695208, 0.0985925599525217, 0.07454136459273286, 0.010522139145905385, 0.03350479491928127, 0.07181101071182638, 0.003704509445014992, 0.006178024568725959, 0.03512361196044367, 0.07236442281282507, 0.02148580791981658, 0.018703184578043874, 0.04349899340013508, 0.025247437224606983, 0.042560321307973936, 0.045255619843374006, 0.02942534087196691, 0.014930255147191929, 0.06491042513516732, 0.035921609960496426, 0.05639181661535986, 0.03909612809366081, 0.05265154817607254, 0.04571549536194652, 0.04684078048740048, 0.027797887087217532, 0.06604795940802433, 0.04681268648710102, 0.05420330104243476, 0.01849768203101121, 0.044041688888682984, 0.04392170216306113, 0.022376813722075894, 0.039894560250104405, 0.014227111041691387, 0.09719617199152708, 0.050774511983036064, 0.03737363302207086, 0.040516350127290934, 0.02615948105813004, 0.06236881425138563, 0.10471027620951645, 0.05281476129312068, 0.04494326472922694, 0.014996077152318321, 0.03673366052680649, 0.03879345800669398, 0.014270141691667959, 0.04597859784553293, 0.02307227288838476, 0.013761526552116266, 0.030906565589248203, 0.04474430235859472, 0.03508301277179271, 0.027406747431086842, 0.023441190787707455, 0.030172878396115266, 0.08194208348868415, 0.038221911527216434, 0.045532459480455145, 0.12069184755091555, 0.032477369386469945, 0.03745771093235817, 0.04210794890241232, 0.05597892275545746, 0.0630085010197945, 0.1044855390500743, 0.04699974109826144, 0.043361362113500945, 0.004635244267774397, 0.022421320318244398, 0.07440288725774735, 0.06972006158321165, 0.03218179423129186, 0.047843444262980483, 0.02960376801638631, 0.020830075918638613, 0.02459387971612159, 0.06433313072193414, 0.019899396756954957, 0.006892454421176808, 0.04001917797722854, 0.03453705183346756, 0.041065454061026685, 0.035536954819690436, 0.027487700899655465, 0.0667828340374399, 0.026878922726609744, 0.020407853262440767, 0.015060221903695492, 0.012671819058596157, 0.020270199711376335, 0.054385932453442365, 0.03971435195126105, 0.014295014771050774, 0.0044462540427048225, 0.06160168217320461, 0.012679568008024944, 0.03605603145842906, 0.028847786707046907, 0.09009679473820142, 0.048804584876052104, 0.021966500680719037, 0.07489245239412412, 0.04646740228054114, 0.039748164199409075, 0.04622112428478431, 0.03519361504004337, 0.045045105944154784, 0.04564353672321886, 0.029756309049844276, 0.09493728226516396, 0.035602089410531335, 0.01200279890326783, 0.08087350957794115, 0.07759180676657706, 0.07521671897848137, 0.017027023641276173, 0.029043951180938166, 0.02303547164046904, 0.03607429942348972, 0.058830547277466394, 0.0025600226399546955, 0.06986546315602027, 0.015352537175203906, 0.006340632371575339, 0.00788426057624747, 0.026618638548825402, 0.03757615770155098, 0.07780292551615275, 0.01079143021343043, 0.04333671538915951, 0.0395427080366062, 0.06316903498372994, 0.016827230065246113, 0.025974899654102046, 0.02356389377382584, 0.043879997174371965, 0.039147811257862486, 0.04670264825108461, 0.02736981445195852, 0.05410583478806075, 0.0450451244978467, 0.010623702055454487, 0.04396525881020352, 0.01401386047291453, 0.0667469586187508, 0.03523530889651738, 0.029512159162550233, 0.007359069104495575, 0.02265254755911883, 0.11724077921826392, 0.14841878903098404, 0.08564626128645614, 0.151082995289471, 0.08779124618740752, 0.11545002882485278, 0.14588205405743793, 0.17077932745451108, 0.13134357403032482, 0.19066045439103618, 0.12337877837126143, 0.15280598017852753, 0.207373590383213, 0.11690110564813949, 0.1613043577526696, 0.21892396121984348, 0.1448088194592856, 0.1174497086321935, 0.14683048910228536, 0.14551440894138068, 0.12907285446999595, 0.11476448475150391, 0.13253875833470374, 0.12097598621039651, 0.10463191283633932, 0.06890667515108362, 0.12070763303199783, 0.1731360619305633, 0.0863406591815874, 0.14966188638936728, 0.19179000315489247, 0.1858072093455121, 0.09997950779506937, 0.12410309223923832, 0.14594434993341565, 0.19866447255481035, 0.11117286107037216, 0.10428186404169537, 0.07151274898205884, 0.1622102380497381, 0.15206577692879364, 0.16067850461695343, 0.09943857861799188, 0.11526331189088523, 0.15709511877503246, 0.11679015457048081, 0.16851542080985382, 0.18571426277048886, 0.10354386497056112, 0.17035143479006365, 0.12075250328052789, 0.1371699824812822, 0.10143651437829249, 0.07599458622280508, 0.14917521562892944, 0.11222158253076486, 0.11661635100608692, 0.09933275578077883, 0.1786412243382074, 0.1767914806259796, 0.18102475034538656, 0.13027173466980457, 0.13342909805942327, 0.09412675310159102, 0.13629742461489514, 0.16199261066503823, 0.1898469714797102, 0.13715319510083646, 0.14795844967011362, 0.21178751369006932, 0.1358695319504477, 0.1705727432272397, 0.07646708196261898, 0.13310351787367836, 0.1255464952555485, 0.11296739641693421, 0.13743239105679095, 0.18467118905391544, 0.16127810056786984, 0.1098640168493148, 0.0971372974163387, 0.09762923000380397, 0.2766508050262928, 0.13209609693149105, 0.13818335544783622, 0.19665415777126327, 0.16091128665721044, 0.11818091705208644, 0.15398963150801137, 0.21682173886802047, 0.124556114024017, 0.22690877260174602, 0.17613332922337577, 0.142748246435076, 0.12567576253786683, 0.14926586154615507, 0.11846088484162465, 0.1454134620144032, 0.13975872716400772, 0.1810422947164625, 0.09943336874130182, 0.1376049403916113, 0.14719828264787793, 0.16256305505521595, 0.10088907656609081, 0.2687247272115201, 0.13725388969760388, 0.07932143387733959, 0.13247977243736386, 0.16342863673344254, 0.09885605948511511, 0.16043126553995535, 0.17550573946209624, 0.14430864161113277, 0.07582335791084915, 0.12636699888389558, 0.11916053714230657, 0.16744050895795226, 0.20680958783486858, 0.10858493275009096, 0.15559933497570455, 0.17916616023285314, 0.11512297918670811, 0.1607253192923963, 0.1695649660541676, 0.2651322277961299, 0.13693700748262927, 0.11437541383202188, 0.24976534768939018, 0.1340746774803847, 0.2586647670250386, 0.10650371317751706, 0.10383444547187537, 0.21909478877205402, 0.07924007964902557, 0.1837665555649437, 0.29098883096594363, 0.13600601290818304, 0.15747248602565378, 0.11331368994433433, 0.13693632470676675, 0.1328848217963241, 0.09568613895680755, 0.12468858738429844, 0.13509139011148363, 0.10917856183368713, 0.23873630590969697, 0.07791795098455623, 0.16057412896770984, 0.1542104798136279, 0.20768817194039002, 0.0768083734146785, 0.09920480209984817, 0.0859747061622329, 0.1788341233623214, 0.09384780205436982, 0.11958600298385136, 0.15605615655658767, 0.14200955716660246, 0.12051674522808753, 0.12561980460304767, 0.23356853867881, 0.20006181788630784, 0.14222990081179887, 0.17785966861993074, 0.10963170236209407, 0.11759344037272967, 0.11573638650588691, 0.22334796289214864, 0.12071660559740849, 0.18064851115923375, 0.1392129369196482, 0.15145473706070334, 0.1565866734017618, 0.11610013534664176, 0.24712984770303592], [0.01554527663756744, 0.01416446171788266, 0.07633577377418987, 0.021384977881098166, 0.01182644513392006, 0.02552257548813941, 0.04439746335265227, 0.06593260739464313, 0.0346066467318451, 0.010116659341292689, 0.040359430422540754, 0.06801247625844553, 0.030275506287580356, 0.01613193417142611, 0.029217556220828556, 0.04117678734473884, 0.03213302399672102, 0.05173767123778816, 0.03669587407785002, 0.01667480777541641, 0.04885771151748486, 0.08254061816842295, 0.028842203901149333, 0.06470663138316013, 0.049525700087542646, 0.016344392497558147, 0.04069074369908776, 0.061209735431475565, 0.07103941461537033, 0.01589844894624548, 0.06576164625585079, 0.018126459763152525, 0.04834235674934462, 0.01096108053388889, 0.051467076773406006, 0.041480945437797345, 0.017167066907859407, 0.03990595221694093, 0.12239204850629903, 0.023654855103814043, 0.012252660544618266, 0.07956105109769851, 0.04242454167979304, 0.018588899401947856, 0.08040936299948953, 0.03497307843645103, 0.033993833130807616, 0.03364130556292366, 0.007231560248328606, 0.01905631143017672, 0.030472368380287662, 0.09882579470286146, 0.08811016930849291, 0.0302341760834679, 0.023063075823301915, 0.03369686644873582, 0.02307385551830521, 0.030362135330506135, 0.06452452318626456, 0.0706154404906556, 0.03612917753343936, 0.012422990857885452, 0.07261426682816818, 0.047441563874599524, 0.0247230616514571, 0.012816436737921322, 0.02264079750602832, 0.01026415933665703, 0.07278218516148627, 0.004965649804944405, 0.02561214343586471, 0.05233609459537547, 0.07370502353296615, 0.01743494882248342, 0.03711602243129164, 0.005054253424532362, 0.010590490946924547, 0.06081218547478784, 0.023686223830736708, 0.09866835549473763, 0.02853675076039508, 0.019980641518486664, 0.1065714267315343, 0.057990992718259804, 0.0038396983700295095, 0.01645261247176677, 0.01879048711998621, 0.01836301562434528, 0.0557352422765689, 0.05153826728928834, 0.007655818244529655, 0.10656989048584364, 0.040159477284760214, 0.007688621635679738, 0.053144048506510444, 0.031222067409544252, 0.04961176324286498, 0.02077664128592005, 0.024679100533830933, 0.01991282591916388, 0.06630915086134337, 0.0473773643898312, 0.02689136854314711, 0.028728640463668853, 0.028428896293917205, 0.03588417974242475, 0.05158851810847409, 0.010310298657714156, 0.053377316653495654, 0.06611069315113127, 0.04321708118368406, 0.051511635319911875, 0.028434703599486966, 0.029945424976176582, 0.13975142443086952, 0.03227832909033168, 0.005814338346681325, 0.035104431153740734, 0.04653432173654437, 0.008398083737120032, 0.02300655200087931, 0.017830533943197224, 0.06393243776983581, 0.01633012099773623, 0.01237889800904668, 0.009628997813706519, 0.06803131938795559, 0.010816752292157616, 0.009280387857870664, 0.1264164556050673, 0.02941481721791206, 0.06283732465817593, 0.038325444838847034, 0.040005644914344884, 0.0452720658358885, 0.02540246074204333, 0.010476944207766792, 0.011878927034558728, 0.06426804437069222, 0.030590787318942603, 0.02027820377406897, 0.008384436569031095, 0.035580066178226843, 0.0456259775091894, 0.031316950990003534, 0.0640765851130709, 0.024695654137758538, 0.021591653021459933, 0.05607576560578309, 0.06382394320098683, 0.012681116313615348, 0.0343190867715748, 0.006205980344020645, 0.026881624144152738, 0.03569166292436421, 0.030340110242832452, 0.018222784965473693, 0.06026489609212149, 0.08519551047356799, 0.008904387086658971, 0.02723353201872669, 0.024339452938875183, 0.02168468308809679, 0.03842844751488883, 0.038592165292357095, 0.04015316160803195, 0.0528065457183402, 0.039172309552668594, 0.016097372354124673, 0.03911940555553883, 0.04108995235583279, 0.09787948220036924, 0.06000597932143137, 0.0421395569719607, 0.012331031339272158, 0.0565507364080986, 0.07925450699985959, 0.0386825737223262, 0.0234962451577303, 0.04140076751355082, 0.05438477099232841, 0.044143270351924, 0.036738291528308764, 0.034846709240810014, 0.01170800393083482, 0.023626733272976708, 0.05285612489387859, 0.10133953794138506, 0.019649048081191722, 0.03470898147497792, 0.04634325952793006, 0.06071225529012736, 0.020190710129099898, 0.061710020891041495, 0.021083992469357327, 0.023538111563539132, 0.012558905000332743, 0.0339974214148242, 0.027969122820650227, 0.029405312161543407, 0.12921752873808146, 0.02994890935951844, 0.06079792510718107, 0.00479980762975174, 0.08828188001643866, 0.04380403464892879, 0.06349619594402611, 0.02917072855780134, 0.03620456118369475, 0.04494626300584059, 0.07761459812172689, 0.07028776744846255, 0.011254777127760462, 0.0128542649326846, 0.11536133475601673, 0.031166068656602874, 0.013019970738241682, 0.08754598864470609, 0.027511570224305615, 0.1326852137572132, 0.011563119078346062, 0.1048363745212555, 0.11302546205115505, 0.034055375726893544, 0.057793967353063636, 0.036605929490178823, 0.1192583299416583, 0.03700828856381122, 0.0471047883911524, 0.03957952227210626, 0.05132459555170499, 0.010462140216986882, 0.024459068590658717, 0.05272546979540493, 0.004853047448705183, 0.043569738627411425, 0.023382264262181707, 0.04432400928635616, 0.027147018008690793, 0.025596380219212733, 0.027154843955941033, 0.02486186924215872, 0.051007483270950615, 0.026699742302298546, 0.04674130672356114, 0.01954346829734277, 0.05615464848233387, 0.04050850562634878, 0.0339876621728763, 0.04943716186971869, 0.053120284937904216, 0.022288700383796822, 0.05715847742976621, 0.06083050539018586, 0.029140287515474483, 0.0959846010664478, 0.04130023247853387, 0.04149235966906417, 0.06984916559304111, 0.019975125505879987, 0.09312425259849988, 0.07108006204362027, 0.03057749359868467, 0.0286754915578058, 0.020570908673107624, 0.008646108562970767, 0.020251679416105617, 0.008584340539528057, 0.025297085048805457, 0.02302763270563446, 0.041069079452427104, 0.013801324221276445, 0.08203229896025732, 0.0132022672551102, 0.06781312054954469, 0.05105574142362457, 0.0152045204595197, 0.032127012600540183, 0.03544244602380786, 0.03789815331401769, 0.043343539437046275, 0.02698976062674774, 0.04615249788912479, 0.007948818147269776, 0.029723350271524396, 0.04250168793078046, 0.024685301177669317, 0.03170834854245186, 0.03781550032726955, 0.04052224649058189, 0.04685547872213647, 0.04956738281180151, 0.022913373504707124, 0.01722136243188288, 0.01615346202015644, 0.11415562679758295, 0.028372333508741576, 0.02319859941053437, 0.026470214579603635, 0.031675846184953116, 0.015361281530203996, 0.014501273381029023, 0.04123671205888968, 0.04729831824079156, 0.059268900513416156, 0.0625881485757418, 0.054157002159627154, 0.06140382931334898, 0.031217158102663234, 0.018087606476910878, 0.041327239232487045, 0.024978905930765904, 0.059280077257426456, 0.021221334318397567, 0.01852508583397139, 0.037055515131214634, 0.02268364540213952, 0.06668389090918936, 0.023114426876418293, 0.028050300788891036, 0.05732968718803022, 0.01597518887137994, 0.02558827596658375, 0.0251959767047083, 0.037731288830400445, 0.07222482483484782, 0.031115415222302545, 0.049698052753228694, 0.02319284962140955, 0.024489478091709316, 0.06452941393945366, 0.04179797608230729, 0.0675015892193187, 0.03488990223559085, 0.06403503226465546, 0.013485801064234693, 0.05486781636136584, 0.048100078929564916, 0.059722397272707894, 0.0480869354942115, 0.02889043236791622, 0.0908686505863443, 0.008450307741441065, 0.0024813869913486997, 0.053392545523820445, 0.007323967374759377, 0.06349123839754611, 0.0679629750084132, 0.050535544141894206, 0.043252771065454, 0.026746686853584833, 0.03031212014320772, 0.10573036561254412, 0.10520079129491933, 0.15453427884494886, 0.15863191365497187, 0.19308261660626158, 0.11918859774596058, 0.16290024243062362, 0.10771380722871982, 0.13123793673003092, 0.09798723462154157, 0.12019330984912813, 0.2228980284417048, 0.07877347656176426, 0.10650611773598939, 0.14611706254072487, 0.1531317681656219, 0.08266509117675014, 0.12543042335892096, 0.19868253642925993, 0.1321313192602247, 0.11210682423552498, 0.16175871540326625, 0.14075728686293587, 0.14973218261729926, 0.18570194311905652, 0.12932732206536457, 0.17310774157522246, 0.17074474337277934, 0.15733722219010815, 0.11323984625050798, 0.14165255444822833, 0.1306440998450853, 0.10836018816917203, 0.12862536910688505, 0.2234647620934993, 0.1357733050826937, 0.10711276408983395, 0.17934755596797913, 0.21346212539356202, 0.10009814010118134, 0.1418099639704451, 0.24072521715424955, 0.16941316716838628, 0.24855664145434275, 0.15106518374523148, 0.1761437044478953, 0.13906107866205275, 0.12171560316346586, 0.13541202759370208, 0.14524248603265733, 0.2313185398816131, 0.12601404829183593, 0.11260838247835636, 0.10767094820039347, 0.09167375465040095, 0.10235751964501105, 0.10792416898766533, 0.18572980334283784, 0.10720483493059874, 0.14635321393143386, 0.06384352105669677, 0.12492831592680886, 0.16116642218548805, 0.16517860611202195, 0.12418765996699221, 0.11677872549626045, 0.23020042019197717, 0.13523751898901537, 0.1335865372675471, 0.08671446412336081, 0.15485298674320802, 0.18509361951146275, 0.14780132216401398, 0.1171935118327383, 0.1411512930644676, 0.07584064253023826, 0.12966649839654565, 0.10872395927435718, 0.1241968254907988, 0.24973043706268072, 0.2018691404373385, 0.0933132108184509, 0.17565356043633074, 0.08669326096423902, 0.131436268275138, 0.1514697284437716, 0.2186494111083448, 0.12326406460488215, 0.15736330125946552, 0.1006251540093217, 0.1368989798356779, 0.19399211858399212, 0.08309318422107026, 0.08369498435058631, 0.12424804110196419, 0.16519281081855297, 0.15960941120283678, 0.10383360684500076, 0.13365123770199716, 0.18065136100631207, 0.09785069429199211, 0.11956248432397842, 0.10916048311628401, 0.13998376118252054, 0.20325205841800198, 0.10470142238773406, 0.13108710263622925, 0.12900246918434277, 0.18597506830701604, 0.08891823454177938, 0.10148720306460746, 0.10899858360062353, 0.14561511838110164, 0.1021982028032653, 0.2451679209480062, 0.13072934292722493, 0.19135480775730684, 0.12684943940257654, 0.17401795601472259, 0.22151781187858433, 0.09869514702586457, 0.16352942038793117, 0.11168147713760845, 0.13514549267711118, 0.06715154042467475, 0.11514948128024116, 0.19398468226427212, 0.11176033774972893, 0.1716017012950033, 0.2275031735189259, 0.10295845888322219, 0.1515703191398643, 0.1524081444949843, 0.16525221231859177, 0.13780119392322376, 0.14135821867967024, 0.1505255830124952, 0.11848827009089291, 0.15262446569977328, 0.08274876090581529, 0.06830986225395463, 0.1572242969996296, 0.2575052058091387, 0.10322290094336495, 0.13813334953738376, 0.17630383023060858, 0.11194813079782762, 0.09956686626537703, 0.1828951999777928, 0.23562592046801, 0.1257673287182115, 0.10167841741349548, 0.139034376188647, 0.09761164852534421, 0.14323211187729612, 0.1694298951770179, 0.19332485360791907, 0.12856167799327523, 0.13944131060270593, 0.08713480914593674, 0.20008828287245706, 0.12452847644453868, 0.08143052109517157, 0.12211562076117843, 0.09982361225411296, 0.1433923267177306, 0.18348817597143352, 0.11061333367251791, 0.14734404045157135, 0.09340071745100431, 0.13622159196529537, 0.19314593664603308, 0.13755141670117155, 0.14231742970878258, 0.1278251112671569, 0.07854629031498916], [0.05311429580615368, 0.021489978789759334, 0.008767477538640378, 0.04532802377070766, 0.006175192347654956, 0.03334761546284426, 0.005523159024960478, 0.050004663644358516, 0.04427091233083047, 0.039855278373579495, 0.017225063893420156, 0.06637321304879151, 0.03136807383270934, 0.045963294760440476, 0.062433841230813414, 0.02842327823600499, 0.02300206386280479, 0.059843385897693224, 0.034786543328664266, 0.0200316252085031, 0.035717938662855886, 0.029314423190953676, 0.03851906003546901, 0.023668384455959313, 0.043435506377136335, 0.0397527172754053, 0.0009795203641260741, 0.02739342216955265, 0.07332249093451537, 0.027121291459479835, 0.019127591003780253, 0.026877714881266, 0.045656891670660116, 0.01802339214918902, 0.05973541825369466, 0.023670933733228594, 0.015418252496601781, 0.041564088242012076, 0.055379779514623806, 0.06690686917863786, 0.04865886417974252, 0.015312049308704445, 0.04346846144471783, 0.029060178239888046, 0.006036623171894462, 0.08135644733556546, 0.03965899144532159, 0.03334991240990348, 0.05650186227285303, 0.07840885198675096, 0.02502094859664794, 0.05842408041644376, 0.049440137881902047, 0.02792213188513415, 0.037997204053681344, 0.009345902799395844, 0.01838321317336522, 0.013181037193135126, 0.037927672237856314, 0.04555054933007341, 0.04096009877684992, 0.07256733340909705, 0.055718232251820154, 0.10670487230527215, 0.018495071526558604, 0.03271778070484288, 0.022207635593076702, 0.05071445739304181, 0.022910974512342364, 0.012918588727188762, 0.027115658558614086, 0.06999012912274338, 0.08394044227316044, 0.03143139387248084, 0.050911453072330914, 0.04823001043405384, 0.03187771777447779, 0.03085648360865889, 0.022451954318967182, 0.032104751880979165, 0.07891354951425456, 0.09254458331270143, 0.04872907877143007, 0.020505447537289, 0.016803659455035813, 0.0038102685039120843, 0.028114136621297803, 0.03418914413487073, 0.04441952369234059, 0.04440246171725448, 0.021891126307309605, 0.05123121110955253, 0.01710301399725722, 0.03578592310077511, 0.08271018406958319, 0.054214678166317753, 0.009017161064548418, 0.02109695407852996, 0.01546655796119012, 0.04610832897014916, 0.021413353897514753, 0.025204162593581714, 0.06998247015872039, 0.0073241923382738605, 0.023102437480702065, 0.020783843829121906, 0.07329401472816244, 0.07767523158690892, 0.010852026571228635, 0.025335042191727553, 0.02600642979814438, 0.03267075080657378, 0.019633091906143818, 0.00956066734943306, 0.042672738127293997, 0.016166679670277517, 0.06664715459919535, 0.013911774349253392, 0.04160383396083489, 0.04744852521980647, 0.003844286466119229, 0.09190453289193101, 0.05322055651049595, 0.024324971782334615, 0.044987348301219754, 0.013523692341550486, 0.006715757408528589, 0.048315743333660066, 0.0406050404853886, 0.05136975152709056, 0.020198704914946575, 0.03562040932592936, 0.021678777447959874, 0.06849652723758481, 0.0856813945574686, 0.009106827346840873, 0.016324614261975512, 0.038805384319857694, 0.017669302360445727, 0.04339364553743508, 0.031501552803092636, 0.03262790291046258, 0.09825699045904912, 0.05585886181506794, 0.05405114592576865, 0.033418965540477075, 0.04427861582371406, 0.045864199491916224, 0.020134151054662652, 0.028633589899982326, 0.0367518505663611, 0.07984749783645384, 0.022394027837435715, 0.03831210844509769, 0.02915538465458667, 0.05649564307532273, 0.10618193278787658, 0.029548539241659455, 0.07386920144199394, 0.030272300209617242, 0.030164076524670236, 0.0345013433980057, 0.04269797485903837, 0.05953818508714903, 0.04219263908453286, 0.03135474857117515, 0.07787114373059012, 0.012541095311462414, 0.03617680114984978, 0.030196873885870446, 0.03371816979779396, 0.032475072439410724, 0.016670030199748, 0.02516955995815806, 0.038283925387077034, 0.004428397041920107, 0.028453836166590918, 0.015131982017919654, 0.04452023313206155, 0.007454220321960747, 0.05554395371291321, 0.010774960101116449, 0.06088281937991269, 0.024732024940021802, 0.022089333542680833, 0.01424013295036275, 0.05378639587434009, 0.06658666956354864, 0.012761039124598028, 0.028865765234513674, 0.03614289984398056, 0.03963969931646716, 0.01728535225993255, 0.013520160646294244, 0.036456676170928404, 0.02187085268815281, 0.03801760569331236, 0.012257573562237667, 0.06504724005935714, 0.05283309605147224, 0.023429255197697785, 0.08832050880300812, 0.01372767255816143, 0.015922359089017846, 0.11148700476041995, 0.02765815737802768, 0.03316403410281055, 0.0488555333140539, 0.03244533458200749, 0.041120480600511655, 0.015011613086244324, 0.009343668007204542, 0.033056537722586654, 0.037847631610929966, 0.08172401823685504, 0.03375139946001582, 0.013143475243850844, 0.022163307112350594, 0.041336512367706746, 0.008542290452169254, 0.028130621576565318, 0.02579542422608938, 0.021770558851130772, 0.06470513966633007, 0.007352168058787356, 0.08709049550816417, 0.04022467866889201, 0.09355286514619365, 0.007287343778443756, 0.081731773680076, 0.0037882475908190827, 0.003137944167974638, 0.03931665727577638, 0.06564846873516217, 0.049085168648161925, 0.030555728262697812, 0.04963021303410642, 0.034309472248423845, 0.056018635077634826, 0.1059862358670216, 0.03597995018935762, 0.01650695994612761, 0.04067981928528752, 0.030740343063371256, 0.07367002384853549, 0.06265274510951713, 0.07446387695381418, 0.016027556666813325, 0.03236820688471198, 0.05036945891333744, 0.03736916900379583, 0.04970789734215941, 0.021752020002168138, 0.03368097706697881, 0.05357010435545817, 0.017614170064916834, 0.03441599641519133, 0.04500518953136634, 0.04954627984261606, 0.018416235034237616, 0.08996331205707975, 0.030253991426434368, 0.03554593109583948, 0.03247135056881234, 0.04691472066042479, 0.009711956008686684, 0.018463741762388963, 0.06093200892792083, 0.03615545327193104, 0.023779647235642187, 0.01725060119497357, 0.06389279966242611, 0.04734050191473216, 0.05561469522945117, 0.00839673210066394, 0.038492049570777453, 0.009854906638793182, 0.027336189596098848, 0.11773507183534093, 0.056790194066707045, 0.031950058619258925, 0.015169178459473187, 0.009016528383654077, 0.032382419012719765, 0.08680585218826309, 0.057105454689008184, 0.020995111008232925, 0.057259598761447705, 0.027801755531982053, 0.030707293371960986, 0.05341306219634134, 0.03444178233621642, 0.03812079390627332, 0.03242777907871641, 0.0524117342865793, 0.05605703379842453, 0.03413219914364163, 0.030630757537437603, 0.08480281787342392, 0.034537612154963426, 0.03864312486257404, 0.08562829389120452, 0.07425977892125957, 0.012159943107690196, 0.06175342539791018, 0.02493807111022761, 0.004852229694733978, 0.02541978617955465, 0.013872380222892389, 0.0380092528212117, 0.10316522122593597, 0.088948595803231, 0.04416946445417125, 0.029266795863804873, 0.05142335685377475, 0.04378740311949514, 0.029876720655011013, 0.11421030823839828, 0.04589198921166826, 0.02722574874496786, 0.06833135485067032, 0.020409087082953192, 0.06715539217111655, 0.06317927662166767, 0.012844534448959166, 0.02640208727825666, 0.015697536582592875, 0.028046742190781515, 0.017960138902708422, 0.023475259076803923, 0.02362793926295126, 0.04260722504113801, 0.08627863790025003, 0.026612183719407767, 0.05578803124080878, 0.02675244220881723, 0.031147351692197844, 0.03336328962177504, 0.07790445131831802, 0.043702698094421066, 0.03169421062921174, 0.0427117342769634, 0.035568466410040855, 0.01069196294338326, 0.04957487850333564, 0.02175781988626113, 0.04519149457337335, 0.08646913236589171, 0.05090569771709852, 0.07390704355202615, 0.049659576106932946, 0.02344654352782527, 0.10013713996158913, 0.10438396871904843, 0.13575472170487046, 0.12457110540708527, 0.12334912215010263, 0.2195008029229939, 0.09168189601041377, 0.1285887515405193, 0.12171964044682682, 0.13370666129048914, 0.22179451421834528, 0.1066471629019361, 0.10830584811628796, 0.22435523540480062, 0.1146112015703693, 0.1935625189798884, 0.08357216633157805, 0.10699500009650365, 0.15390692657092586, 0.1131797322886996, 0.1189450322999619, 0.21756167494459078, 0.10949130286462605, 0.1461255081812851, 0.1223944679077249, 0.11269057533354498, 0.1146523907664232, 0.11999318972812034, 0.24082505085971206, 0.10455833631567657, 0.11129986480227672, 0.09440698064281605, 0.09537880076095462, 0.1459743030136451, 0.17146934667835012, 0.13036279618972912, 0.11175437830388546, 0.13208585529355332, 0.13462949224049225, 0.10605663599562831, 0.14999754494056106, 0.10080794498207979, 0.11575603115488775, 0.1428695282083936, 0.2025409770430997, 0.10183784557739273, 0.19092782051302493, 0.1165784198383335, 0.21496337139979005, 0.1674874423770234, 0.11642386016319506, 0.17953306320123374, 0.10584683826891705, 0.17306111985817552, 0.10865128075238317, 0.10289527985150926, 0.060356651520123705, 0.1293336451635696, 0.09912957801134326, 0.136914802424144, 0.16686822404153645, 0.17841535911429673, 0.2788232493912801, 0.17725435813190416, 0.11103694414487109, 0.15739941416541114, 0.08802686323178932, 0.13345116953132674, 0.13993010390549898, 0.1419151114532724, 0.11429014106397517, 0.09128294710535556, 0.1576306376955472, 0.13289115973748267, 0.1563870208337903, 0.15935966366669163, 0.09479916116106324, 0.09463910959311761, 0.15598626108840108, 0.1365341103519313, 0.1643505325773731, 0.2520735753932968, 0.16101183282444254, 0.10195216600550339, 0.19575966201955453, 0.11458559005404823, 0.09135834930930287, 0.16160359169589356, 0.1532333088107407, 0.13248903444036841, 0.10816150781465694, 0.16681918292306364, 0.23980821948498487, 0.16049336845753714, 0.1635340365464799, 0.17414719361113384, 0.08541010247427039, 0.10297473418177105, 0.11983903081272729, 0.10337643645470962, 0.1083798031322658, 0.13608940062113106, 0.19634379161288962, 0.12854463828261942, 0.1285132602788508, 0.0883734981471207, 0.14019660913618281, 0.1493808944360353, 0.14198453194694594, 0.1662366563687101, 0.17688383348286152, 0.12542595562990755, 0.1701477894675918, 0.11811149655841291, 0.16553081455640495, 0.10406340545159765, 0.14902779541444033, 0.10641155327903107, 0.21648844034643844, 0.14980923238908872, 0.08379365288419649, 0.1343080383958295, 0.1364967951667495, 0.16229749977355823, 0.1529997994657606, 0.15568401402560994, 0.16679188673151657, 0.12694268283667043, 0.1323311944724992, 0.10338393956772052, 0.16146433510584757, 0.12846712837927043, 0.10916080223978497, 0.16846483602421358, 0.21055651333881542, 0.13102688477374613, 0.1237545425829012, 0.15543340559815988, 0.12336496700299904, 0.10880133559112437, 0.18728019436821342, 0.2080940525047481, 0.1422285649459809, 0.12443525527487509, 0.14176159078488126, 0.08460772209218703, 0.13268505048472434, 0.12392295815516263, 0.1386263285530731, 0.10811754298629239, 0.07655527879251167, 0.18100156565196812, 0.11865668566315435, 0.09825433357036673, 0.07207747141364962, 0.2210707718040794, 0.20724237867398188, 0.08595988547313027, 0.1968713101814501, 0.19058140082051978, 0.16460189799545333, 0.08064135094173253, 0.23800814029527828, 0.12706822453765199, 0.08394982301979326, 0.15103962417924777, 0.1719348959159106, 0.07775700141792186, 0.14697443606564775, 0.09870021589449607, 0.15330489637563005, 0.11747136450139806, 0.08667932343087159, 0.22297006129520014, 0.1352374002453871, 0.1281731785275042], [0.04745264785015024, 0.01918227058922639, 0.02422603236482246, 0.02719147079915274, 0.054973743099253625, 0.048509807529626414, 0.020173162047285587, 0.04110443536774255, 0.05303501216985751, 0.05072550797194708, 0.015823814865143504, 0.01792358627426438, 0.007472003571820096, 0.09278643439756706, 0.033382047404302284, 0.04346417925262358, 0.02181971685786266, 0.03994007616711315, 0.033160393868456595, 0.008793280157988193, 0.06021714631060604, 0.01575380621943623, 0.0182980981116998, 0.06658851008978672, 0.034046930086333305, 0.05406630058132578, 0.022990926081547514, 0.014451682145590894, 0.04606047899869736, 0.027118701364088338, 0.02976677889819257, 0.04848737611609977, 0.035613781947176903, 0.0245771238769521, 0.05005436898500193, 0.023648938331461977, 0.02464487639372237, 0.05809585076349322, 0.0228631393838441, 0.050428244430804625, 0.03621599025791511, 0.03792616567807272, 0.017038283876900095, 0.04673691320931539, 0.05152008838194888, 0.07548343943199143, 0.05132989077537786, 0.07604212820297107, 0.03442779656325001, 0.05147008618223481, 0.02930101443780586, 0.059459877375047654, 0.015710334919276647, 0.05139235363458283, 0.08467439663945697, 0.013847086902387673, 0.01437827817426296, 0.028580413163581397, 0.08309170734719373, 0.02319471797818551, 0.02097098378726514, 0.03823062434094027, 0.012235367576067802, 0.03214319884136785, 0.01929308993567247, 0.026905675294983666, 0.0719542674778495, 0.017121606651926413, 0.07983563831658103, 0.04923016203974839, 0.020326580670371186, 0.027778220173786394, 0.07435652529238723, 0.031784760067239404, 0.04528419995040167, 0.010479749525984516, 0.01290132173380698, 0.032339856843464077, 0.09218836727086455, 0.054817754789837636, 0.031179831785266288, 0.02575636128312908, 0.03833534137811512, 0.045942143551656045, 0.026808229449670762, 0.018775371427182108, 0.028541173960547894, 0.07779816834954545, 0.024442654139420483, 0.018706785849644803, 0.06919339648447931, 0.025335519021609798, 0.03899679533788003, 0.049355054361512884, 0.007845092804927845, 0.023891203163657337, 0.033912927901837975, 0.02596716833068058, 0.044718267818097956, 0.04706557701865677, 0.018937551103590522, 0.017709717867546715, 0.012283588621357922, 0.03774636556045152, 0.10260200535412878, 0.025926853013515938, 0.03897992632118985, 0.05290353328746278, 0.11194188933586702, 0.02249858902359847, 0.014921807651262498, 0.04149112028244417, 0.0033542284973009373, 0.05528942303499207, 0.015816823834029492, 0.007822758798283758, 0.041541675382177345, 0.015936608324409463, 0.06657734076725319, 0.0337017609126633, 0.05355660839995835, 0.015459249661944341, 0.04096845535968896, 0.030794195154157933, 0.046665885965921916, 0.05291476940328721, 0.03495285862300079, 0.05277089665469248, 0.039655314103583805, 0.026193823941866867, 0.048586189368506894, 0.05371821847802494, 0.013749497265962418, 0.03825917847279925, 0.016369007680623326, 0.010190129178226925, 0.06430823166738264, 0.02622516669362085, 0.03871378103212919, 0.04441994671651628, 0.06231057792319916, 0.04053541590110399, 0.06436833820771426, 0.029253038301249035, 0.0236524078718503, 0.021033500452176668, 0.02376875992922578, 0.03687036412884481, 0.049197629996342584, 0.09417823588592, 0.055492274259449914, 0.06736164243193343, 0.04072724623256363, 0.04389271016407292, 0.0341351491806563, 0.03963090115576051, 0.03324611563584767, 0.058710512312245555, 0.05664617659931537, 0.008353278426511679, 0.06031634176906664, 0.044139637539046817, 0.04020989508717321, 0.02924449432612164, 0.033812801048043184, 0.04341472624219023, 0.05487049180374015, 0.021301616143318824, 0.024468076408084016, 0.0541515473742038, 0.04341953906987328, 0.008658766819280572, 0.054094056904432364, 0.04831494552490767, 0.017042113358911593, 0.08878097432898358, 0.05165446535102092, 0.025093295007536653, 0.05463154251629021, 0.024724928152863868, 0.06574607599759474, 0.03657387242128607, 0.04507144847593736, 0.03579628719307948, 0.0651590594497975, 0.04340124884038232, 0.030169575838954188, 0.06471817920100875, 0.10359585241531022, 0.005129440869495738, 0.05274121816910338, 0.013578969355876325, 0.014887764409650117, 0.03798528887273278, 0.10116432429640554, 0.05650274171784986, 0.034919168829219416, 0.019664872525027022, 0.037399307620944455, 0.017272780278290156, 0.011215874674235238, 0.02019243191170972, 0.04604932451911736, 0.021115787931194063, 0.03053825996175874, 0.056381920076091774, 0.030359612028405536, 0.05562692953390069, 0.04368617417640053, 0.10640819877153262, 0.02643067480676109, 0.03804371073783841, 0.05074432512628846, 0.03798488440224901, 0.0404780701501295, 0.07091201012372039, 0.030631577610620297, 0.07019437558483332, 0.01672055932431249, 0.025046571245184168, 0.07211589239886962, 0.06440743454732001, 0.015848467155592516, 0.03779133228817955, 0.051787454503937624, 0.052056627755519, 0.006628987821386545, 0.07071667685522698, 0.020077419430890586, 0.0305846349147032, 0.03998622290964704, 0.022548316628672183, 0.028560774080688134, 0.019728719489648938, 0.05081144867290277, 0.010788290928758215, 0.01099164681363618, 0.05148818716406822, 0.05871875386219472, 0.08873475337168202, 0.01524196088212193, 0.04558021297270898, 0.03024158828338841, 0.06978658770094626, 0.03819671561359428, 0.012322496640990721, 0.016928904296946712, 0.03800582038820721, 0.02729011706833262, 0.04660953098209575, 0.017968185638892464, 0.04207734273222741, 0.049042706668842584, 0.06821685630711727, 0.04301574022974819, 0.007450969251294737, 0.023665957633056678, 0.01566536633617943, 0.06486464204499498, 0.026755930302897468, 0.009541254621581174, 0.04989126719010528, 0.0420560542261228, 0.08359581857803278, 0.054788180204923265, 0.01590216710610548, 0.02446224127197638, 0.032071518508018926, 0.02369910380366491, 0.049050899979192764, 0.03378096662345342, 0.03565295250155032, 0.03544955208781175, 0.023492569671361707, 0.011311828802718082, 0.02334060009161476, 0.011472253299871227, 0.08431833644863218, 0.023414586648868863, 0.029227417508082, 0.05511456933163572, 0.024588619744463358, 0.015368567565019475, 0.051452924017212354, 0.0432223838288337, 0.010992913103109458, 0.06877066916786134, 0.008551052433176665, 0.0744107985519804, 0.028992822772124782, 0.04881012500845827, 0.013523531852115411, 0.06583523761946708, 0.02424195143248653, 0.051517257088562474, 0.018455299832567107, 0.047141910617938265, 0.04516204986430239, 0.04529836012807209, 0.05119150991959032, 0.04294380014471244, 0.05052106855146121, 0.04640598584956024, 0.011726182838174282, 0.03211339047993533, 0.013491180707205785, 0.010816507383424323, 0.02052487510809442, 0.045994806350790896, 0.040882933972170576, 0.02581767566880444, 0.10180861980188638, 0.032127153608598746, 0.037785569511470385, 0.037403942333185114, 0.06158815282105934, 0.02151825090550119, 0.020448047980607953, 0.021150629909243435, 0.01374929781377432, 0.025364190041727852, 0.007449193199136062, 0.07667333964491263, 0.024474525671394076, 0.05371747261960991, 0.014611909973609727, 0.04830059609957971, 0.050217032912769355, 0.0428702867066022, 0.08459220378426835, 0.06794197965064086, 0.019383028957236093, 0.08426133208558895, 0.05912104243179783, 0.03615459609136451, 0.04644508218916599, 0.069105600414332, 0.05875151968211867, 0.024667315228725784, 0.05430438155599404, 0.042710836278274655, 0.023911458229122218, 0.05484434594109189, 0.0711521394259762, 0.028011451213387772, 0.016932704093051143, 0.01910053786559729, 0.004978224569640588, 0.03336835477966815, 0.02472028230840806, 0.030010251575731672, 0.06836867745732889, 0.19495934480801225, 0.045058223404339515, 0.21127434825757518, 0.10737245640484616, 0.16443512256955728, 0.1387183548649773, 0.13443046307656914, 0.12799215386621654, 0.1638785860268399, 0.11659137031529099, 0.10680577470338903, 0.1767355969059281, 0.19320035091368482, 0.13578927610069513, 0.11659747076919302, 0.11324049191898666, 0.15172655606875196, 0.09776225255336612, 0.17720959178404883, 0.11617418684181757, 0.12421992854797281, 0.12332233804045245, 0.0725206003698986, 0.12528223131084815, 0.15173439314821735, 0.12541509058792144, 0.10823952237842605, 0.08757352232350968, 0.10365044479840435, 0.10041126704891212, 0.1357399529661052, 0.10009310091845691, 0.22652318235486746, 0.21113417140441015, 0.23439291631802917, 0.13220051710959524, 0.15016304387245327, 0.1528547689667903, 0.17580624989932403, 0.13858760328730568, 0.10904807000770234, 0.14748317829798907, 0.06751499982783571, 0.18243422236992046, 0.1472778111929074, 0.11417911577154882, 0.17052202485501766, 0.09487443719990551, 0.11202471301658079, 0.15598517755279317, 0.08455537841655314, 0.15040216385386884, 0.07398991918307729, 0.1193614216754213, 0.1520735991653055, 0.1384614233393222, 0.14615264110034332, 0.11936499140574597, 0.19879356172168627, 0.10908603828283958, 0.12304179879720323, 0.1393237098818645, 0.1357867824845016, 0.16514001443283632, 0.08171780646080151, 0.10727167275035754, 0.1553071365924552, 0.14508285006741062, 0.14138031983748078, 0.17536336585180834, 0.08790835709078237, 0.09993183222832158, 0.12999801576370373, 0.17921713093528524, 0.1517323448206298, 0.15238711202982813, 0.10672853939468041, 0.21974851697450504, 0.16732696036342531, 0.13517048821086064, 0.10675919009372592, 0.09328244137577713, 0.14347653079312295, 0.13968145474791527, 0.1478164768195711, 0.21358002297347412, 0.11433843261329457, 0.13593823998235166, 0.11521660111611709, 0.09223386092344299, 0.14645039074821398, 0.1282796321902424, 0.17546478775329888, 0.22100461676018313, 0.11842357707791962, 0.09492971235886216, 0.08798634196864441, 0.11206983559532091, 0.1174722402356565, 0.21125770930666476, 0.07647450343938544, 0.20027122227475047, 0.15820373897440732, 0.10587591561488807, 0.22966760268900543, 0.1176331601163838, 0.1163332439318765, 0.12920599576318637, 0.1766921515809372, 0.20235780015354976, 0.20905240264255553, 0.117549193528248, 0.21593442710582167, 0.11904980128747411, 0.25347581889946014, 0.08671415242133662, 0.14702307642437518, 0.09427222888916731, 0.10606605384964496, 0.07776130587444641, 0.10708261805120856, 0.10359735897509381, 0.17545022681588307, 0.18185674241976812, 0.1436917981482111, 0.12851749052060768, 0.1652688957983628, 0.15491664817091078, 0.06532753439387307, 0.11949603984248824, 0.08773106543230824, 0.06811314859078266, 0.19406156876357272, 0.11517574588651769, 0.08436369651462883, 0.2540924248751253, 0.17649021319812164, 0.09487032570177689, 0.09846582339378074, 0.15426838217535987, 0.1308827448519878, 0.10871060803765431, 0.142569552117493, 0.10614776430884376, 0.179171503696125, 0.21356886107241735, 0.21730360051151365, 0.14182112587150186, 0.14491175534203649, 0.21324607136193663, 0.15005427470896393, 0.1580528900376521, 0.11198727166629396, 0.1654648969997652, 0.15837619925150648, 0.15811941615538672, 0.1830786737264134, 0.1563039151369594, 0.14293551997980103, 0.09416499597136863, 0.2927595953224227, 0.21228638535831124, 0.1978811653680168, 0.1196453747979831, 0.09646488935686648, 0.11477120860945433, 0.15292736585251987, 0.15239680447848514, 0.13499197200872004, 0.16043991898186505, 0.07009396300418302, 0.135008403158281, 0.09823960936046205, 0.2190151860122569, 0.10669296083506197, 0.13606047170469537], [0.05722579764551483, 0.020985318369639572, 0.06842120666988194, 0.022595968075620476, 0.05310536776960362, 0.036847658120677806, 0.017412311462976504, 0.01618809619685635, 0.05820200385642238, 0.035947681608377025, 0.0105530097062001, 0.008619442269264255, 0.03217343764845282, 0.037013216424384154, 0.03139154054224491, 0.08466842235065997, 0.06670547256362624, 0.05627351827570237, 0.03105225659965072, 0.06908162162289955, 0.04693945273174904, 0.04240311958710663, 0.04974750576366205, 0.1005916683061514, 0.017915673124662135, 0.059120493242517114, 0.07104370422894135, 0.023959977988852188, 0.08418489087489434, 0.02028861053986475, 0.034699270472628996, 0.08781195952906273, 0.011495744129206287, 0.012113238826714223, 0.04622388878487982, 0.029703050677198917, 0.0675313344981987, 0.03292004192189779, 0.04065567351062782, 0.024706096155568957, 0.10225240184809081, 0.02821149340888951, 0.027122371284349356, 0.04219731090415735, 0.0705372700758744, 0.03974804545578081, 0.03126239942503162, 0.014936381576262647, 0.04480438292375766, 0.01614022952708183, 0.004596954549924703, 0.09417715977178887, 0.032309410235029645, 0.013826879148837179, 0.03846523577522021, 0.1071592744847294, 0.024695993670320604, 0.04457445815205574, 0.07857390563003719, 0.04777987560373731, 0.0663982456899248, 0.07143170645576902, 0.01791503487766022, 0.04612070799339563, 0.07176862665801309, 0.019717791365110315, 0.01565951079101069, 0.029110954128555022, 0.03129483498923946, 0.023595691091031767, 0.026599489283398725, 0.02584295692940941, 0.03206253481039312, 0.022886776787345298, 0.004655445991375018, 0.02943094037618721, 0.05003718826628756, 0.030516142105625477, 0.018044213102257345, 0.013835465797455981, 0.01668383785727201, 0.056736466285656206, 0.05514555399713572, 0.06935603072633967, 0.06754748363164254, 0.03985846218711231, 0.05607811450317968, 0.03602577780839056, 0.02757827445748262, 0.025935053745342884, 0.03609473445976619, 0.025999607605626807, 0.03556668896635529, 0.01334068243522779, 0.05763995686720591, 0.022004288985044695, 0.07086704339599237, 0.0327120439033024, 0.03783916741667781, 0.027969980001216754, 0.06116044940426946, 0.0075101230595464585, 0.03720909146068152, 0.029709473965340294, 0.05237669749476481, 0.10913931706454605, 0.03423704234592151, 0.06563700255355798, 0.07522475643781945, 0.029743211998720653, 0.04391969836433418, 0.02351183025893988, 0.020461325002543163, 0.03269426575570833, 0.035661821166286245, 0.04229617981764022, 0.018040468967228662, 0.07308760119485669, 0.03636405243014451, 0.034536992461653426, 0.007470830978490994, 0.05286946499836631, 0.02216628683527233, 0.03396529384190217, 0.03130416378553491, 0.02632029147207504, 0.010421538245282136, 0.018787876615533605, 0.029367477472987957, 0.035772746268776245, 0.09168467906420119, 0.034208016950287856, 0.05493759679666255, 0.05556719777814578, 0.024056787442532368, 0.016834185844345484, 0.05536633179872297, 0.01509467518189922, 0.028709372454613913, 0.015219304041238502, 0.045133551393519156, 0.0470364662760403, 0.05714959392207675, 0.03506363900669385, 0.03359775633725803, 0.07725060437223874, 0.039830742971389554, 0.027625436086964328, 0.06804700096836314, 0.024003913131309673, 0.047179893736029044, 0.0531475774187129, 0.04000172637461219, 0.0072166351947089424, 0.06213662592926994, 0.03860295611957554, 0.006947874298930401, 0.05488346083438955, 0.05361185016226955, 0.024122966606228147, 0.029792579662171192, 0.018665591087483335, 0.05811407791043166, 0.04224782147502992, 0.010385328860138543, 0.03123350761597976, 0.014611360784329008, 0.03500029299175367, 0.05549635607167147, 0.03211871167877689, 0.03926209457858931, 0.04111443951842375, 0.02901322255638661, 0.050044735908159055, 0.021391428999777418, 0.02629910501127597, 0.09684396354714409, 0.03190842042386066, 0.09061584540177137, 0.0421829355036607, 0.005481636326294392, 0.04256583546521142, 0.04209776292555034, 0.014426371199078858, 0.010470479173818603, 0.024737969542911742, 0.07812408250174485, 0.024737340572755784, 0.023269454104593024, 0.020717820516438223, 0.04287481751816813, 0.03823727027338464, 0.04670872644055635, 0.04304683992813807, 0.02734763351327274, 0.06661992520093918, 0.024469026357110124, 0.007886486091592815, 0.040530432379455306, 0.02504749150830321, 0.04848680837312713, 0.01671570567850722, 0.05387789526139386, 0.02489773352863267, 0.09498360712314025, 0.015506377894780599, 0.025430853456782643, 0.06581398251000792, 0.055817542743170634, 0.01972791982552735, 0.07040786920697428, 0.01060005351973814, 0.008496500868204748, 0.02536806590796914, 0.07432297279592603, 0.04343007385614328, 0.04707539934315719, 0.09121226496063173, 0.06350717230816372, 0.03216195291315671, 0.015045035706862109, 0.0472545315278694, 0.0405766236508498, 0.016101702785817906, 0.08005282041267492, 0.027129798327223398, 0.08942780055804178, 0.029371011951297987, 0.0368974784942111, 0.013100718260830035, 0.034363292797934264, 0.032301777246175334, 0.01972181380551774, 0.011679694707709132, 0.012347654519544449, 0.0715325643250253, 0.06774545894586481, 0.07236436344101094, 0.018365937830822077, 0.011751602323784027, 0.06643742366577499, 0.01671437537879683, 0.025580509391147643, 0.06263882984058, 0.06008988282701466, 0.06854549414128996, 0.023694726987741888, 0.03500525053823367, 0.04605825997714419, 0.05122855422087014, 0.025134378447546624, 0.034779771231114864, 0.03883224635501392, 0.0399330480286153, 0.04643854757887311, 0.05311191351211164, 0.017600251085241325, 0.0538584992318647, 0.07360417308518663, 0.030498684936901554, 0.04089167276106309, 0.054910994513193145, 0.03016022477822844, 0.12190145920612849, 0.02601268239232013, 0.07447399242664687, 0.037761078638141043, 0.01564815036545042, 0.043573813018156216, 0.011365037080395268, 0.030914599337847903, 0.013979732812003931, 0.04011808770883363, 0.06340723470202647, 0.024870140478014946, 0.024384276803175453, 0.047625278821215034, 0.011937971376028145, 0.07797338941600174, 0.024834632422425784, 0.06562912836670876, 0.05060371040599421, 0.017434310575481504, 0.008404069158132188, 0.026109966820513364, 0.017843104069470428, 0.09592913294909522, 0.0231472465020488, 0.06016444640408736, 0.062443333299597725, 0.042924504305119626, 0.061977980731171556, 0.07486730100936256, 0.015700588664913084, 0.05054539244156331, 0.04402345803100616, 0.034853113975259475, 0.04349902308604214, 0.02340525228646584, 0.022023189630999696, 0.07108924983185716, 0.021391232330643106, 0.04666737026127521, 0.03778161386435386, 0.02850076216418529, 0.03252980583056342, 0.05949913327640388, 0.02920734612416709, 0.05660855342284776, 0.01963208258530358, 0.044974449774599634, 0.0327751858276315, 0.01632290361158084, 0.0434181401215028, 0.006468793853855459, 0.03294724163424689, 0.009358999850519467, 0.01063600222551031, 0.01062606301275082, 0.03804758845944889, 0.043181272558285855, 0.018170988623751327, 0.04188159015029669, 0.10792920074891299, 0.058759408711921424, 0.027880810957867652, 0.02236753687611781, 0.03693827806273475, 0.013815837846777868, 0.030305683867482003, 0.04182256343483459, 0.03078188849030994, 0.010612360183586134, 0.013492057369148824, 0.03406620366149582, 0.015736907516838983, 0.057075089716818184, 0.005511099589057267, 0.06429178567486815, 0.035121300170430914, 0.019441775511950254, 0.04476409543713089, 0.04274921273463406, 0.04091126917046495, 0.03748383453057613, 0.017906481625686865, 0.05910026971832849, 0.03580179763957858, 0.01562345540151, 0.039572275200043805, 0.10729090921813622, 0.044080146981286816, 0.17249505413929, 0.10861743139685132, 0.22515535965794697, 0.2064882082049735, 0.13310694659594446, 0.14986869326094165, 0.09495848542428575, 0.07650235624169, 0.11164741998072714, 0.08542901981854811, 0.17398887866875157, 0.05629476967442315, 0.20409429213032126, 0.0598219675157452, 0.11846688881632872, 0.15336866170400754, 0.16605781362159178, 0.14113435725448653, 0.08087660433375277, 0.13368923566304147, 0.10056429047835991, 0.1374019926879555, 0.14806445804424584, 0.10532355736359023, 0.09107545745791867, 0.15613705065334216, 0.13029768015258014, 0.09453505306737497, 0.1928541241795756, 0.1402135449461639, 0.1016567467013374, 0.1250368179171346, 0.18298611306818202, 0.11962598990066908, 0.16175255557755008, 0.1312436512671411, 0.24377210444072261, 0.12061377361533232, 0.14590546139515936, 0.15172799583524466, 0.13982549076899886, 0.21896209276746958, 0.16595842520473525, 0.12686414876952767, 0.16171242023119703, 0.08281806265586056, 0.10351904013077728, 0.14336091902805492, 0.16589195845881477, 0.06899156200233847, 0.19348870497196913, 0.24600648845080286, 0.16934628481976688, 0.117754709062865, 0.14481186226475984, 0.1316607531043701, 0.04825692070880905, 0.0812023774778936, 0.19933026807848364, 0.24059829505858943, 0.12165263935457915, 0.16121668042615056, 0.16534287307877094, 0.1387584605254233, 0.1715831327601336, 0.09342116361949593, 0.12533664557849988, 0.15589660964906216, 0.14197397860698402, 0.12381997032207437, 0.15367689047707245, 0.11205278104171157, 0.14249055791879073, 0.06284459770540707, 0.08716264710528776, 0.10830071245436557, 0.09769345546374097, 0.17621318431338295, 0.10862184717552736, 0.1324624358676374, 0.11330913315759972, 0.17261575703741983, 0.1700529726804234, 0.09894027840346098, 0.1586496806703508, 0.1501754080527462, 0.165276198531501, 0.36506766686215997, 0.13140992203261703, 0.11919469819986261, 0.13586234796093777, 0.16361219953978434, 0.24255579861346632, 0.11243126151384786, 0.14478103345027193, 0.062868339009583, 0.15308430040022358, 0.1227576304518152, 0.12684661924140528, 0.13803348614601418, 0.1461173890857026, 0.12044981092913076, 0.15508998418226838, 0.09375270325108431, 0.10086759881232865, 0.19866497721523046, 0.1727186335483566, 0.18488120200345293, 0.1918115551234223, 0.15436270914506167, 0.16390843520639464, 0.1052516135678161, 0.17394443886587396, 0.166295419621747, 0.10905070463195443, 0.14883511903462932, 0.15929478511679918, 0.10006084718042985, 0.12526541424449533, 0.09463977752602659, 0.0940148817608133, 0.18407344847219065, 0.10501350290724076, 0.1105107317562215, 0.14445471111685038, 0.10648225026670843, 0.15488899574847892, 0.112897107610479, 0.10482409197720699, 0.20530708017759025, 0.1459897099994123, 0.15803969465196133, 0.13361649034777656, 0.09128587858867832, 0.15371064335340634, 0.17256604798603803, 0.09306529638706706, 0.12990824558073655, 0.14491698006168008, 0.13225988892372698, 0.12982502114027739, 0.18982280715135857, 0.1099729270208627, 0.16096623527118936, 0.09741955844219774, 0.24092862498946488, 0.12748311477480456, 0.16235145390965044, 0.11509514864883386, 0.08682446525199339, 0.1699173971428536, 0.14929956989362836, 0.10115338503965177, 0.06420493955374695, 0.1285994829959236, 0.1287326539750211, 0.09569667745381594, 0.12015191285172477, 0.1174659097159747, 0.10839446054887958, 0.14263077930081636, 0.22653465595794842, 0.1970989565597847, 0.1743832411011681, 0.09359419535030611, 0.06079858932935167, 0.103548317856621, 0.07698519009863958, 0.0981982568919193, 0.11021842205082066, 0.1583726963144727, 0.11057219642680138, 0.09413010760908946, 0.12462931947084144, 0.23332619777647778, 0.15110010921489447], [0.010448265766171971, 0.029490070992324036, 0.028192381250846665, 0.05802308689453639, 0.014213534377631731, 0.08740121047594585, 0.02772781535895774, 0.0070586147921858355, 0.04340989486081526, 0.04213966087263543, 0.025948724105546717, 0.014482496117125265, 0.0357614693348296, 0.035093944607069716, 0.03311186112114228, 0.017523238420835696, 0.029289451777003706, 0.027315999468555674, 0.04294364800443873, 0.043072380940429866, 0.034200543523184024, 0.00984371690719854, 0.023062767832016107, 0.04773822256538551, 0.02095473446388496, 0.022412019352486823, 0.009919438234646805, 0.09469509721384384, 0.028947050814167596, 0.07067120546707883, 0.08296443644212559, 0.02689514421945205, 0.049706557765603065, 0.024376782967010513, 0.042016712977783754, 0.02292588796990458, 0.015425707370013697, 0.02144189133105101, 0.07388526151771657, 0.035905427430407144, 0.039306463877437636, 0.038202081341296434, 0.01154609142759, 0.07718853114056401, 0.03049002778425347, 0.08691062859725207, 0.025489794825261924, 0.022512218565680087, 0.0669016147730872, 0.023726841573079582, 0.046320200999616645, 0.039495685559813865, 0.040427782223559916, 0.10139474630705081, 0.0535781752114417, 0.04708168904471677, 0.008371750482183415, 0.03624382079578936, 0.02488755497324746, 0.0326235613465542, 0.06178458075737581, 0.04288506286684424, 0.017880892373796087, 0.026724346353148576, 0.012395772591844434, 0.029088786177453585, 0.05649472281220369, 0.0854393802001141, 0.05283990525640547, 0.030133748659864068, 0.010143641047761776, 0.021909362731094006, 0.04648036388971377, 0.03855499853671063, 0.03400522509764414, 0.03750753872736823, 0.02296393231517868, 0.016004856224753894, 0.01722580233035842, 0.07531014052801766, 0.07251629591337405, 0.014494053211819846, 0.003868618473461538, 0.0358127702929778, 0.04306404291128274, 0.021950247646600474, 0.012884677216788987, 0.01962154779903358, 0.04697881253378, 0.014685246223962167, 0.011447703054727754, 0.06907613715156913, 0.06880232918774709, 0.07465925475116819, 0.039351033556158654, 0.05556737960432656, 0.09665978475823067, 0.057138736301567405, 0.03701759138493799, 0.056207511661341414, 0.028125664030085318, 0.040391424408880994, 0.028078556206310168, 0.018950269659399055, 0.03174840225256048, 0.02082173974486068, 0.08396431716391817, 0.04552311584120616, 0.045991373917786404, 0.01503854191469145, 0.07462848530849442, 0.025773382440092973, 0.03505255874188151, 0.0478460083832033, 0.03687595992232673, 0.06110007569077425, 0.05491495758178644, 0.04561853376799263, 0.04060982362716459, 0.053180818213149905, 0.07474766680388711, 0.04124515769944992, 0.03520058380672708, 0.03298652722151019, 0.026582907848933246, 0.022250765505305026, 0.045864095591241494, 0.04556396736006718, 0.047113070759223774, 0.09554431453580037, 0.03998204461822752, 0.010472160138306208, 0.010905093840847258, 0.0917972628667485, 0.049143156356876716, 0.03371907150722109, 0.04042498432681896, 0.054664723938913085, 0.014172733881423483, 0.028160133078927174, 0.021562738947977778, 0.0372167096065823, 0.06644808090641163, 0.022355959372362122, 0.0026769533405968104, 0.020288580853957683, 0.018449843191774562, 0.040639004873810336, 0.07695958600379527, 0.07868499771575443, 0.04447948551387526, 0.05890856555197388, 0.029760941906715743, 0.025577537089702673, 0.018530189954617526, 0.03653790794487577, 0.011352944711688906, 0.08601525711128488, 0.050926926851389, 0.027788150109699927, 0.04286700641387142, 0.040748208193690516, 0.05083385782199912, 0.040594305319245905, 0.03103404800640419, 0.05780986415629741, 0.13536951737478375, 0.04104669627849944, 0.011835912155220285, 0.06001393514452502, 0.01695081064099213, 0.0007231309541566588, 0.019129991851514205, 0.0433127477299422, 0.018131339384126477, 0.08562713614082895, 0.05192009484744631, 0.05171664248337038, 0.03336663299705833, 0.01523026649010717, 0.08144035455188714, 0.0629202151321806, 0.062096100955386646, 0.07450668403180316, 0.05976332671707496, 0.017556481070641894, 0.07365645738900639, 0.01824174127250444, 0.05910546475206502, 0.09240255851182155, 0.020001343727926724, 0.025517463946016505, 0.020931720464432146, 0.025517237590975128, 0.0668572862923611, 0.042604512491379865, 0.025393527139385697, 0.029909046752436552, 0.09262685038265772, 0.022108853881945834, 0.025042387387657072, 0.06789926905184984, 0.0352494468097575, 0.03884866266162135, 0.020069771599082742, 0.06655572942690924, 0.02637801200762624, 0.11458990193204954, 0.03133570877253078, 0.08333798905368894, 0.019791432823694777, 0.034209991063107736, 0.035951997197116725, 0.05548039989662357, 0.03165009737131186, 0.07053770052152686, 0.03638298461737577, 0.09737983127706684, 0.048376506674685515, 0.06248928708373569, 0.039552033122163266, 0.028320609526417684, 0.007900973741925554, 0.040347474423469976, 0.035380343106226064, 0.005343641387298703, 0.045500558262574486, 0.08256205881480128, 0.007296895219042199, 0.04012954275822267, 0.0249306811747374, 0.03686221163661685, 0.02745874044194352, 0.0339987498591654, 0.05691348706022836, 0.029289574231370352, 0.06896019142004661, 0.04178693663561717, 0.03981395188020542, 0.06967265318962745, 0.04177366332442034, 0.008448773351119598, 0.006308284937404096, 0.020646980665333103, 0.03853579175483901, 0.08307367315865122, 0.02088238063151948, 0.03145191054500174, 0.013058550357527565, 0.038111056928755715, 0.09334345333627425, 0.057612111486378126, 0.04402813356136903, 0.03816251002717763, 0.03522594670357648, 0.058958768131560646, 0.044096132842241786, 0.04767208607518114, 0.025247555968235247, 0.06720349076204002, 0.01711385677481303, 0.048400088417110965, 0.013851552776031895, 0.027945420479227323, 0.016384062146244105, 0.062268075125757605, 0.02996821262058802, 0.03337599518999923, 0.042937276666634716, 0.029232130145828705, 0.05634496112179477, 0.0316838836442912, 0.03380310117790941, 0.06603580302908085, 0.05779428276582621, 0.018401533088763244, 0.019661571823235136, 0.041409576806472614, 0.020649155158025678, 0.048766668551252224, 0.03864469821564853, 0.04004068912763614, 0.051812438905471936, 0.06066807523893658, 0.025369312716065906, 0.05357333640858997, 0.03910722691216506, 0.05877036652236711, 0.027722445920517202, 0.04330433548602741, 0.021685684987460263, 0.04054294498928357, 0.015421086573041975, 0.005648607957482454, 0.020996155581087805, 0.041738563450053334, 0.0308264043633244, 0.016918243345571682, 0.049043363469536416, 0.038305833586491644, 0.016041868984757457, 0.028033639573550317, 0.04530940699623898, 0.015266075115505373, 0.02502378174540354, 0.05454687088786159, 0.04937679186696187, 0.015493032224185299, 0.02461896245222306, 0.07676587803871371, 0.04370518428913783, 0.014459988633461762, 0.06948955051484518, 0.027807186197605915, 0.01074522780982079, 0.027133134281029925, 0.015310617891373113, 0.02496292563591851, 0.020055670793226454, 0.06795532346586697, 0.03330841522256378, 0.045059232725179754, 0.03630926708865445, 0.06015231971105095, 0.016258846990240272, 0.07631073371157981, 0.011772364832722815, 0.04726414605102036, 0.03754383717023302, 0.06463008627179079, 0.04272492224117741, 0.027821118164865766, 0.03033975030120928, 0.08908291711122729, 0.06334357327432372, 0.02565670383773977, 0.022447571936936583, 0.0684696169628296, 0.03926184224837925, 0.08651975425891578, 0.0441141225019237, 0.05511925970495213, 0.03453026118222624, 0.014176407512422884, 0.04555755891487934, 0.055385917075909674, 0.03499769918562379, 0.035499520890880376, 0.047456518150283955, 0.055369207620969974, 0.06534067782922648, 0.010961937714455416, 0.11551300005521625, 0.1683129629236646, 0.07378006950602867, 0.17114378133555874, 0.12987876747502014, 0.15785798721481115, 0.19155769608914852, 0.12194860042654909, 0.17580837244167924, 0.11773792910389602, 0.1605267947888933, 0.12649864103877917, 0.1580545969773084, 0.19088528060819954, 0.1037451799493283, 0.11054924922063947, 0.07404612202662975, 0.1563898558379151, 0.21250154881272465, 0.12351141500403173, 0.14752634160686284, 0.0873370147019159, 0.19204501993954182, 0.09254299511667341, 0.10665989815606736, 0.14994090422987938, 0.11025932180928066, 0.34171302162576467, 0.1839141093660146, 0.19564853282645345, 0.14905899530276656, 0.21067870053229854, 0.13561825559008867, 0.3159097640309483, 0.1352698024129495, 0.10918402404058725, 0.12258836140972562, 0.19666609150590375, 0.18378705368377268, 0.14749891182873398, 0.10646657610777766, 0.14777844917261973, 0.12652851990424097, 0.12468248693039641, 0.1275051714037545, 0.16576368565438315, 0.16544272162718698, 0.1271236629690975, 0.10011996666435152, 0.10624038433888927, 0.15306494518881664, 0.1727630733512342, 0.10139045669347979, 0.15116724389372393, 0.12022727794828825, 0.15078763535711914, 0.1524041368975304, 0.1611366175347939, 0.15735233231680468, 0.10705926266382448, 0.12131822019000538, 0.19810498226433992, 0.09104692187975161, 0.1528172311373055, 0.14152861578622833, 0.11170394936925732, 0.12622841022675857, 0.18647252989467233, 0.17994467314565554, 0.27097575017251074, 0.0869639370648656, 0.09331828710855916, 0.1475152836064808, 0.14941426139557734, 0.26201675122138113, 0.11105994330137037, 0.1306838492746465, 0.17065259831724688, 0.13653237372636795, 0.23004410904832184, 0.10191740380832925, 0.09277909455704503, 0.11849344286019914, 0.15812772820936516, 0.16437662648968399, 0.13137153815478086, 0.1265379154938273, 0.0687040168850217, 0.18809544359100983, 0.1468478108290583, 0.08047160692512989, 0.1437195247854106, 0.1848525254172273, 0.14572927553672343, 0.13005182147026062, 0.14391977107152343, 0.20234836003510281, 0.19573987636249512, 0.16063201648648828, 0.15541486674919724, 0.13286537752719596, 0.1009004091611132, 0.1014159939950332, 0.09886241969070397, 0.09833329066168517, 0.1403036416741088, 0.2581381984055042, 0.2275517545058392, 0.10780669443192892, 0.12210592831252143, 0.17270306329010054, 0.21551952202571556, 0.0865342038741801, 0.17108442436438054, 0.10994687021593563, 0.13229612057330087, 0.12827745027607307, 0.11388299142709002, 0.14803785947151482, 0.11619217650149949, 0.12604104762431234, 0.06845920463092625, 0.19391358451684937, 0.09499188206973486, 0.14585196739062667, 0.10013510647695512, 0.12430529037374072, 0.11098217364633456, 0.1667768508195877, 0.19292911078082398, 0.11181547932210378, 0.10535296125453897, 0.13200033019529656, 0.21123730024555698, 0.08167767853592522, 0.14012006402481347, 0.2346087625483051, 0.07972608247655444, 0.05216517056396697, 0.1452855602838099, 0.10990113907610066, 0.10121244515175931, 0.1659941373509355, 0.15630398935172707, 0.11324031380354427, 0.12827117170672864, 0.10231173655483872, 0.17280452972045168, 0.24719497858313844, 0.154585724521894, 0.11994843080174178, 0.17133700690465048, 0.1035368294105865, 0.21710670873289928, 0.1551750788348727, 0.16549857566133142, 0.09867487155133858, 0.3141879220493138, 0.16652591584715992, 0.199936380086001, 0.11390127052436583, 0.12910193181596696, 0.10141921491594985, 0.19918707810575143, 0.1041409450408537, 0.11750948120607063, 0.23112470575142652, 0.25281417940277606, 0.19517719483701512, 0.17598154518054798, 0.12078353989636526, 0.10261890405672602, 0.10239173265290447, 0.23325987946009263, 0.1081533738761209, 0.1658201334066689], [0.04679181358369533, 0.014826582682871958, 0.05985159405099694, 0.07038803902105428, 0.03592372879211325, 0.03146562543406617, 0.08522217583958991, 0.051045755826635286, 0.039618971131858416, 0.06721992191160098, 0.06748444560798816, 0.04677580174757168, 0.06670689006568864, 0.03928878591977991, 0.07345933554461226, 0.026353918183303904, 0.04660202786908485, 0.025699546167743392, 0.029328997115953825, 0.05296855655615218, 0.006167160454424447, 0.03327014266687911, 0.05153766986040864, 0.030794992962910328, 0.006674559399471036, 0.024243608277174644, 0.036369588851812296, 0.05103865718410816, 0.03664937110443134, 0.013433895255730022, 0.03448655239481013, 0.09352058914373629, 0.04573229016386904, 0.045122474839445204, 0.03250201611081138, 0.034764393931254745, 0.14666730567114428, 0.027981475868728012, 0.03899496223311871, 0.023037647988530807, 0.0552553770103259, 0.03871608911140356, 0.05716949832276441, 0.0661977322306484, 0.03626935438660439, 0.057789410566329025, 0.10738126569776796, 0.056406845105811954, 0.06397557139280252, 0.03255328738305252, 0.018182690437242854, 0.06318867221125402, 0.06691579721518792, 0.06762511227861978, 0.03412733436562121, 0.04978528850188013, 0.07661945972358808, 0.024631244996271562, 0.11112515581771731, 0.04869101401709486, 0.052685397531604394, 0.0241436484066071, 0.050287447884329595, 0.03205968125257641, 0.03891717402439099, 0.017358134682581294, 0.03870023683703039, 0.010654318430169951, 0.11511530537973158, 0.06458701944211498, 0.07595107410452329, 0.055834734594100155, 0.04190141291473992, 0.08148627865011804, 0.0526336290204199, 0.04090037073183339, 0.00673601664857415, 0.030884251063980628, 0.031219373413478024, 0.017687741019472014, 0.03175251746142749, 0.0223186052244273, 0.0736846738436725, 0.042486106540309265, 0.024302098790940363, 0.04184064957371447, 0.02423218662443105, 0.03870330190693494, 0.04942639701766893, 0.04901860542304348, 0.05920589959714562, 0.02010715728829382, 0.051605542976176366, 0.07361152034718543, 0.04593041761836503, 0.03661979651951697, 0.030585657223127782, 0.04046405840199441, 0.05276041010802146, 0.024552410359319765, 0.03391903948795516, 0.027892150974366814, 0.010083219094667584, 0.053821521723875776, 0.02601392363430932, 0.05088695477752481, 0.04072274881764315, 0.028328402077022474, 0.02064077816612553, 0.03153984020173084, 0.02154326870368095, 0.0298867934543523, 0.012651769939111546, 0.04154763482802082, 0.03763774111575913, 0.0486546413594624, 0.0367611459660111, 0.03333098764414899, 0.006961880480957916, 0.05062246447778307, 0.06576909741852432, 0.03280353586887941, 0.019813908766082022, 0.01587106926308479, 0.031879962771199644, 0.015101723729458172, 0.04608794588421006, 0.043818280173582025, 0.04395436779304873, 0.10092915254062973, 0.027035168932343367, 0.024837306009430904, 0.03670858706755098, 0.048116064790519886, 0.04928792710416019, 0.04701780497271102, 0.0637320356327109, 0.016311704603140242, 0.018315566412638873, 0.07058497532852925, 0.012888162527815439, 0.05649920538417064, 0.02893146014685044, 0.01145977223131922, 0.011903649829037022, 0.033100227956310846, 0.03334907007229049, 0.06496652407804504, 0.005883694366275449, 0.057618193386588246, 0.06485917983809486, 0.10117565689142793, 0.058178210601909086, 0.07687096614972688, 0.02367627719650045, 0.1205252947693225, 0.04474475506867748, 0.015605257940478623, 0.04209544000332244, 0.01951725935214199, 0.0007647681638900394, 0.05295069677231368, 0.02420292188617168, 0.009440734429517761, 0.03039196595636895, 0.07374178210739046, 0.027615392973530106, 0.05727356226998381, 0.016072057696874253, 0.031267045269487426, 0.007420095444103936, 0.06456276605604216, 0.026625714926922228, 0.02308598777744919, 0.038985381106613204, 0.0843350867216941, 0.0422175715357298, 0.039879572577774525, 0.032010042705223896, 0.09432912935153581, 0.07928747319965623, 0.031721106061013415, 0.06327444963972084, 0.0031888891271592, 0.0782810096279718, 0.13719825830776244, 0.020741934749821667, 0.09617335890652612, 0.02840109544195002, 0.024889254491426982, 0.009995702257583616, 0.03891532978741452, 0.029810667656420264, 0.03262424041167833, 0.05377924157073721, 0.02232480030215811, 0.04322498876717873, 0.032976838483591564, 0.08300284258439206, 0.010415780106995953, 0.006254592408367898, 0.037106389354448766, 0.052662424350273795, 0.013092761510051787, 0.039458492828998715, 0.03892471424478572, 0.017688559237285517, 0.04032376280520111, 0.059574405604507774, 0.02913481046562083, 0.0940493174130097, 0.021170220752537716, 0.08539793125237338, 0.03476344769296702, 0.03720429718669038, 0.04683032362663653, 0.10657584251021035, 0.06678199541056529, 0.03925784578314051, 0.03844881946861278, 0.034666322826524265, 0.026758631720440462, 0.05356796697014943, 0.0436412742419634, 0.10859797228476964, 0.046412613228312694, 0.011508728930493817, 0.036092849404667504, 0.042303797963541, 0.024125766358338296, 0.017500443354947492, 0.05813397488964256, 0.07072214648360386, 0.051817359344568104, 0.06548666569869965, 0.025164468825096264, 0.04310165866627358, 0.03318374554510228, 0.03705853938299697, 0.028602594102267176, 0.022915175068192184, 0.008367041555175092, 0.0568345336796483, 0.028349458661978133, 0.019284039444755763, 0.06218300273758359, 0.03117795415164437, 0.08110015405691229, 0.03117975385976024, 0.121011023002211, 0.08925277244998142, 0.04290360171580687, 0.10080971871502697, 0.03731090670044068, 0.013260238265502267, 0.04163594298006501, 0.11937033486901782, 0.035874743334716186, 0.08396079938393086, 0.006193318840814754, 0.013720204697165173, 0.05842410639161244, 0.03357665707881097, 0.023437296367774252, 0.02859752708900487, 0.07032570603769273, 0.011212219596927753, 0.05310852931870613, 0.059711862486437894, 0.048251525295199826, 0.02820807210810017, 0.04024746631330345, 0.04172079643467441, 0.03919679671525955, 0.016665427028783597, 0.012335098308540182, 0.04860315857513342, 0.07442377129336819, 0.01900028484669747, 0.050468112603994086, 0.04619029918103479, 0.03999947395641357, 0.038489114376716316, 0.06733675822033547, 0.0625956516887527, 0.048753276496427134, 0.008797777572908672, 0.04569652606733143, 0.10159796118387021, 0.05436975734482985, 0.05114136671181768, 0.009533472275506938, 0.05021767115977127, 0.020962024209438823, 0.020225956577633042, 0.005164850590517744, 0.05929006285441574, 0.007368184533333988, 0.013327164215297671, 0.10122297622729093, 0.03220834085368551, 0.05287585860060062, 0.0672005963861011, 0.01224312301928876, 0.046017883432796225, 0.05262402934022248, 0.02484681663190713, 0.08887963544111699, 0.04390240632346831, 0.025707579916343093, 0.024849482797435485, 0.015105207185115432, 0.05844345047080424, 0.08631958218757063, 0.03523046638292726, 0.048322801158064976, 0.04512516883551143, 0.04229804631904699, 0.05374306929297745, 0.05043708712037187, 0.027777351861004718, 0.02839693199348403, 0.07813022006303072, 0.03227143082767725, 0.02657539731444558, 0.019503321818774566, 0.019940532147302292, 0.058551032198010944, 0.01948801873368211, 0.05354273394914344, 0.04629411450878251, 0.025024933929671533, 0.04641203435312491, 0.07079501054249704, 0.05832335984450765, 0.057298387109767646, 0.016157334175659344, 0.009862646311376011, 0.01915991339046741, 0.01899986182252178, 0.049464866242487915, 0.03063771888264455, 0.04718770484032575, 0.01811970621929504, 0.0369830184354214, 0.039353215470327996, 0.011918953841814073, 0.05925831006607041, 0.01517386326668202, 0.026563107348920312, 0.03145603317534551, 0.057137816038448364, 0.13993742148159072, 0.10199419382843189, 0.10971074851113372, 0.1832793207722716, 0.11188635442522354, 0.10945261470624246, 0.16265341895632446, 0.1355479148332961, 0.12013861356535926, 0.21699978009564802, 0.18106255534803495, 0.1450639549875632, 0.1436315951286815, 0.09895911411149427, 0.10293154860846698, 0.15135255816858262, 0.15697564784204587, 0.11529433366376907, 0.15141078707529232, 0.17315417033387348, 0.15558893006527796, 0.11281474406132475, 0.17096882744226605, 0.11316382064251229, 0.10232896180241369, 0.17413808003766462, 0.2192668037605472, 0.09058141717105173, 0.11741897629690357, 0.2078814568812959, 0.1685860732686706, 0.19666631415020674, 0.1459625770803541, 0.08533514555892907, 0.17913982883328572, 0.147453403333202, 0.23804012686014175, 0.2217393578030169, 0.12913203332573175, 0.16034510219469666, 0.19860719359712675, 0.1574184576747939, 0.1765506388619542, 0.10262321593472734, 0.3183481050655246, 0.2515342418337241, 0.1874298113398254, 0.19156324735376984, 0.20647473080316558, 0.12710787006653845, 0.15899363643256947, 0.21239111723843962, 0.1404448426910676, 0.1289348743739538, 0.14929194061551243, 0.11524801622726955, 0.16068938450189307, 0.13184902112698182, 0.18521549500292167, 0.12195628907647915, 0.1017485726333689, 0.10757276948424987, 0.20135688042500988, 0.13327706168638542, 0.16087080992292613, 0.07948573052999564, 0.1941706199431792, 0.1104758953442797, 0.21715606155339628, 0.10653375531546772, 0.17860511143226177, 0.15633236907888204, 0.29767448315396905, 0.2565893955761567, 0.17864638968603685, 0.13356280338484794, 0.24694751686183736, 0.09681535375420935, 0.08046432645642199, 0.14040375739568844, 0.2075937410700135, 0.0951353095297236, 0.2242743264650926, 0.09788012044737116, 0.14272800064645708, 0.15321546758059412, 0.07522257452365011, 0.10598350476357155, 0.15447173063876107, 0.13721789553528652, 0.11534772376762703, 0.12524325371487066, 0.1071281784970779, 0.1324869564268738, 0.15983204066287726, 0.20468766888370737, 0.11939651041757315, 0.17268985306145623, 0.11131611041491851, 0.12575877917697653, 0.13147811056114733, 0.1414524862775579, 0.07942546071717516, 0.15562813030555844, 0.2743877889588475, 0.1584087053197436, 0.1361250682384707, 0.19101827347185463, 0.24470572621794418, 0.1325414449092932, 0.11996075787465088, 0.10775401678984053, 0.17765295080607757, 0.13498340762453154, 0.11536343503394164, 0.0950995231687557, 0.0883526512188837, 0.1299385103629902, 0.11820459898444824, 0.08409114278038032, 0.24472781253280118, 0.08636849714093842, 0.12191889225505292, 0.16092693113023415, 0.07213584132841788, 0.11208294934476726, 0.11805901929619722, 0.10527318780077621, 0.1001320339855738, 0.16101119457744062, 0.1304818960488774, 0.1282008903217502, 0.08740085424506105, 0.09643872865126468, 0.18139555701054633, 0.1044854277279228, 0.17299356957664713, 0.1490799683961086, 0.14996585523476824, 0.14934322301996872, 0.12187632266432047, 0.11788559422711842, 0.11489948141388595, 0.059577815773081966, 0.11544360924744979, 0.14646465482655913, 0.2055750400177203, 0.22723901347490028, 0.19183257274562493, 0.21427263971418142, 0.14332626073155552, 0.144783096620813, 0.1044219073082786, 0.18304907687706873, 0.0907646979612764, 0.19919739395845681, 0.14494743780232966, 0.09309936838690192, 0.15215379564324394, 0.1978691722615622, 0.05417466156359296, 0.07518243175582029, 0.08207792619941756, 0.12634164711926132, 0.09952750275260769, 0.18843797442968935, 0.19484266435028985, 0.1276668705395423, 0.12308886580285616, 0.09446569936699234, 0.09617974879802205, 0.1462448009988293, 0.14356297615449876, 0.05730784578190651, 0.10795397363835946, 0.22134787490358576], [0.023672965362493414, 0.03447170201980043, 0.03962904207583051, 0.05624774348689243, 0.060007066567777656, 0.03222640101739671, 0.05739347849157639, 0.06038455627276562, 0.03628725869930349, 0.018167506095778663, 0.049088059313362464, 0.04125051600567531, 0.0358320475788787, 0.030683758013765328, 0.08934919227613136, 0.0397298331517959, 0.05676721346389968, 0.07595583869260736, 0.027906854775210377, 0.07906735219876282, 0.039177990693133324, 0.053870099000050686, 0.01873782432085136, 0.07530058908741921, 0.03538966448104475, 0.04984148392395582, 0.048702153653721325, 0.026146252275793813, 0.03762542888580356, 0.04780171700986102, 0.0034450281782483216, 0.024885185666789766, 0.024660147937538568, 0.12772588612278923, 0.04345960020145867, 0.01656656739214668, 0.03965269061154686, 0.026534011449257378, 0.02594987443444552, 0.03263282334955875, 0.05377777953981422, 0.035881007061107084, 0.038879565690876916, 0.03933926680474542, 0.01573166980961105, 0.01776827331923414, 0.04235764077748172, 0.030220511289371643, 0.019559893880796153, 0.027526967933226842, 0.025247186749766115, 0.003376132754056016, 0.029713414769503288, 0.07682907191338018, 0.06349252231302671, 0.016220116158365272, 0.038899945066077635, 0.028787824885512237, 0.01894343447929714, 0.0759929238120094, 0.01756170950102387, 0.04596972547005862, 0.06789431892684661, 0.035985954164061695, 0.032062542231869884, 0.024878719705156982, 0.017264518319279887, 0.08275315442006104, 0.06314865560852922, 0.039813840558053926, 0.0641464137879666, 0.026936856629617978, 0.007227176938613411, 0.01851595185144106, 0.017319528160442133, 0.025948839138436597, 0.06730985536705703, 0.04385062668006867, 0.042490132691455074, 0.04780781746376306, 0.019091780523012858, 0.03214339551050216, 0.045241044063004665, 0.05976950138574466, 0.1627954066498205, 0.027261436771368608, 0.02308522893144982, 0.0373109252541326, 0.036247312600607984, 0.1111022754048463, 0.06679711295873858, 0.17589171562576666, 0.043855732656084, 0.07382426440017298, 0.05610905835055746, 0.06731413013767451, 0.07887805259088054, 0.018579004718048964, 0.038708964493707754, 0.03037291873624781, 0.0726497414871119, 0.02450225601933198, 0.03251063986681402, 0.08751601330004632, 0.01567561354022473, 0.02369351357629057, 0.049555901787243783, 0.008996260330604855, 0.028850805392721668, 0.01683224141743267, 0.010021674643212464, 0.018260855285916477, 0.03433790763665456, 0.027284463758405764, 0.04833650491491426, 0.02741909305768786, 0.07690048878430389, 0.06544837087858468, 0.04498475078435149, 0.08200478754588403, 0.007130891626729863, 0.06382211009622552, 0.01966776319022756, 0.07874004280893132, 0.042741371944430284, 0.05866892977792304, 0.021710211112804245, 0.03541378799127415, 0.0604659401869867, 0.03496694829664193, 0.01475276125347591, 0.035039285430684686, 0.05202544642088469, 0.02232923092378769, 0.03754109493456781, 0.06300092369201593, 0.04104674080736004, 0.02439060732285725, 0.0297814455916523, 0.013300513692229288, 0.007265805725182872, 0.011401029387343442, 0.049995127046713606, 0.06291639307164587, 0.03359607908350881, 0.024304824328282848, 0.06094777214457281, 0.0672166193544399, 0.06793154505430721, 0.006590571938431822, 0.023478405782952905, 0.023655038785364013, 0.025304231930931564, 0.04044380519189872, 0.02620648498123046, 0.01308737815634231, 0.012303436433285242, 0.03002054145326838, 0.05029236461268738, 0.0033263112209169776, 0.022752895201847423, 0.01784844196663471, 0.08588965603848919, 0.026783265457197558, 0.02998386637045769, 0.029872100785723887, 0.017424568031856325, 0.03486516645352822, 0.05312242232321296, 0.06817883608164266, 0.13288543035741895, 0.02125428567524068, 0.03022894394234754, 0.03153851917886641, 0.03208457288565114, 0.03778420024900697, 0.062212221091613173, 0.025784839344851207, 0.012919405089633074, 0.023025064874673262, 0.027214534893573727, 0.03725864466105122, 0.02164634373912122, 0.06485875681391917, 0.03417915853788145, 0.03536362994054798, 0.015451608323928667, 0.029835696586815175, 0.02148406201740727, 0.026422290393384174, 0.008241108371294104, 0.0820924129220657, 0.045134857573430054, 0.06493726861663163, 0.040166386679629795, 0.06303335554548539, 0.02991132885654224, 0.02495772874681279, 0.039918349793879315, 0.1125449882238172, 0.07598743191920221, 0.024301397461385932, 0.03217679957742803, 0.02357724129979033, 0.06475846297689714, 0.04707014864834491, 0.021487880367203616, 0.04918092425214127, 0.04864446280407719, 0.05740005391999148, 0.02920584513049107, 0.030371742432180326, 0.09503208420937881, 0.04164713456702884, 0.014912226524756989, 0.04250431142281741, 0.04097814409760758, 0.03619026370870415, 0.033022580755641684, 0.045382285898085684, 0.07844875726732425, 0.02607053280371474, 0.01626721099455608, 0.03566823332221247, 0.018487694578652736, 0.050438987018424086, 0.07174752739956602, 0.06368130241753533, 0.10030645353253931, 0.03434154416027013, 0.0684675166849047, 0.05455250007798895, 0.06952409748919308, 0.02954884166683769, 0.05498853039171081, 0.07584573366330005, 0.046723929335712455, 0.09667997859651223, 0.02864263853552984, 0.018693273195822258, 0.058528749214019626, 0.039184566121548414, 0.06965159103856422, 0.05817380966618657, 0.019252854399383068, 0.034707359882304445, 0.07652243875782005, 0.010834953463927377, 0.008189123709598789, 0.054625627599307336, 0.09606136882212013, 0.027716851982404478, 0.06134635739726946, 0.021203086762398016, 0.06249909827602096, 0.02748020149738295, 0.015443505926668877, 0.029985808942001313, 0.019371931994101033, 0.008927196067816112, 0.018361217771598604, 0.029731259710388258, 0.016814734153740574, 0.0389229701977456, 0.04884521746134851, 0.08076962374616414, 0.06473731918958947, 0.03720944769156631, 0.0022770825489715207, 0.01602478474524105, 0.036109536595176905, 0.023070202296366915, 0.0357657403947087, 0.05303622558130883, 0.03260232108004857, 0.1051185093820095, 0.031508447355008684, 0.006711924679621006, 0.03750580952328164, 0.05562574209761806, 0.024558317854825873, 0.06730566965416074, 0.05032262568420265, 0.06517658897791989, 0.013134119544702116, 0.008102651445369702, 0.03279922399087809, 0.04255620609910693, 0.04149399610469118, 0.030074968708504457, 0.02891050375183113, 0.019606257701525465, 0.0294889058204717, 0.06969427195144817, 0.03485001921944786, 0.06096480072301347, 0.016161883540917188, 0.062300930003402755, 0.021471901927725412, 0.03902111551724374, 0.04615502490196377, 0.023344368346442934, 0.015351082565757679, 0.09705137155833654, 0.059612596523948014, 0.043201228909310885, 0.03523218816553708, 0.04506352976022754, 0.043035266135120764, 0.04889225849183276, 0.028972042637178674, 0.04036238417029381, 0.036768059071619064, 0.004152370056544896, 0.031033767845656257, 0.07141269263229333, 0.029089695308357477, 0.03582168719731271, 0.06617125982302241, 0.08413262141402811, 0.04024501351523213, 0.022209283160918858, 0.025057673774426803, 0.0511970018123975, 0.013336493939277716, 0.056474759039701894, 0.013400472635112237, 0.0893177994294092, 0.037873027904424816, 0.026341494631196838, 0.025852521357592195, 0.017094076683861203, 0.026321812874812167, 0.030602390797866974, 0.04288241711037699, 0.031200185185298324, 0.06489862498710863, 0.01827569638408022, 0.10749623921583407, 0.07093103879014961, 0.010658802857506089, 0.012244599893165287, 0.02359748337767087, 0.06135177878604736, 0.03416731386096217, 0.02781750761641888, 0.05563516737311147, 0.034145850950153545, 0.05219972495979164, 0.058457699706195854, 0.039625097560929134, 0.03269441418524366, 0.1371232865494676, 0.2015518574626185, 0.1026620005723089, 0.21239004854578525, 0.15919646539259702, 0.16247778228716925, 0.23539698275271803, 0.14055233536055312, 0.1269349645008333, 0.13972785382065922, 0.17949364031665027, 0.17644133535213768, 0.0725071897613816, 0.1022168381314259, 0.2165085228625685, 0.21540413290495053, 0.14206679159542546, 0.15773927327245474, 0.16469843656523153, 0.19766919314861298, 0.08053882324020378, 0.19892245793016627, 0.1249453259515576, 0.24983276438433677, 0.15004838205641136, 0.12737053097225726, 0.12709305679891258, 0.08627776958746836, 0.28060663025826216, 0.12263585886103101, 0.06454470218159258, 0.15857844933634624, 0.1519386618747376, 0.16700415580999106, 0.1319349618279375, 0.11519917548866943, 0.11703456606483087, 0.08578872395446524, 0.08109945643809624, 0.11218203348107636, 0.08892319208825938, 0.07586177889606915, 0.10343263929826207, 0.1368781106430106, 0.13535981008317322, 0.07976528271683492, 0.12072085810359567, 0.10497091105207801, 0.11432293656980619, 0.09315971241449006, 0.10957984108245, 0.13389289582846686, 0.216358445759397, 0.2891684614587575, 0.14834754285402596, 0.131728763517458, 0.11784362577600405, 0.07599061573273502, 0.1264428612194024, 0.1668518374208361, 0.17216337349964306, 0.16481608181493357, 0.1637009604019113, 0.09192803670885041, 0.1023471741063986, 0.13677165698027238, 0.16359833622118458, 0.14375535567523912, 0.1691541724721901, 0.10222338387393393, 0.27891958015970886, 0.06842160742962733, 0.09040501608978957, 0.2114494505804032, 0.17120110482210293, 0.11700807139277458, 0.18269909487571567, 0.07511051022447646, 0.1004095007374417, 0.07628123334143311, 0.11192158417543396, 0.08314703445648775, 0.1483719001407735, 0.09043576326803304, 0.2120881131850183, 0.19086363958194852, 0.12323054921580479, 0.2775548002682626, 0.10785945371026173, 0.2160762218409218, 0.10979789149132557, 0.29614049359224737, 0.11704576507327147, 0.1306739341816865, 0.2654410502873361, 0.16060718422522768, 0.2171868458390236, 0.1504183723591268, 0.10154621122637764, 0.20625930017558858, 0.14513474103296176, 0.14628110686317086, 0.1443239298532717, 0.20434662234038115, 0.09440899928449653, 0.1718973580864258, 0.10665108886314556, 0.18766951019642875, 0.12403499276842922, 0.13856207340722904, 0.1374541359837167, 0.11398125920095481, 0.1265709410654381, 0.09707772522233427, 0.11754488165024668, 0.13292566960444674, 0.12587655801326036, 0.16476441349368542, 0.12211256311275065, 0.1613171969074756, 0.15969529253197834, 0.15968678751960397, 0.09750644909217954, 0.1542527525452897, 0.1289284325321205, 0.1523180032381788, 0.09546070417854935, 0.25960500875953585, 0.17148925107903779, 0.13180591718992218, 0.12037925494951196, 0.14204713952494785, 0.12244001351064071, 0.12286231038160622, 0.13499250635504723, 0.13454935513436794, 0.10342533656512387, 0.1296942398766987, 0.09390537787112407, 0.19624728272901848, 0.14376506296684965, 0.14095171471126378, 0.21308138879248872, 0.20510674483375624, 0.12244206183822826, 0.11488946984172799, 0.1461269924766384, 0.20787678135093302, 0.17178205802338198, 0.11902024154551327, 0.18993347621290013, 0.10633834783220664, 0.10529572682571597, 0.1768220867961645, 0.17819053289713338, 0.14239755197195336, 0.11525950467330404, 0.06470814536442049, 0.13321000122232363, 0.13075061287963763, 0.14599771035136655, 0.09561645128997043, 0.2067477669334039, 0.2221810692572035, 0.11188268821570091, 0.10790326268761419, 0.0694131241471041, 0.16685821989085525, 0.1419746910687536, 0.19189115788321942, 0.17684151622233912, 0.255438947933726, 0.09821231316891499, 0.1367798651335761, 0.18578677059849724, 0.11834867953439243], [0.05405133888416458, 0.030724893404112663, 0.04659788668504916, 0.046649143114336766, 0.043499082457856275, 0.04399023950099945, 0.0454443183116382, 0.04043563414597884, 0.04541248759778682, 0.04853344493312761, 0.030239267216529697, 0.020192739902995527, 0.04471413034480065, 0.04797911627974827, 0.02963561171782203, 0.03320294119475875, 0.07764823967590928, 0.017676028073765337, 0.01394582037391956, 0.05083824020402972, 0.015311334991565673, 0.056535006588092074, 0.03413578371691983, 0.029562871968664695, 0.01290929611059255, 0.017942331069207285, 0.01862358181824675, 0.05616047805233393, 0.04461531338165514, 0.045289714107639156, 0.034205846168333665, 0.05464638175908476, 0.038663726882077754, 0.044080109873902984, 0.04477873430005275, 0.09208013987517916, 0.1064238729304634, 0.009607259380572941, 0.060816048353444785, 0.018766680877888575, 0.0432986951636849, 0.015165029853960732, 0.02083475515973987, 0.05864205289981328, 0.05326982027327176, 0.08534350214176811, 0.04768082115333527, 0.022335377761919517, 0.000687324242107934, 0.00934231822611764, 0.05239554062427487, 0.040921744584920816, 0.020817960357817356, 0.023297023035411257, 0.030472173566522542, 0.027953387434536126, 0.025265768272220157, 0.013733259074797388, 0.0715553185727913, 0.01698643187410198, 0.06088528702093754, 0.0634311318572145, 0.06823826726758853, 0.0639541752752848, 0.03259499979321845, 0.022234902098716702, 0.04044424305902794, 0.02950814043288119, 0.03263262668042444, 0.06170642518554814, 0.027173748312634416, 0.02854479564120993, 0.028543539556267206, 0.047250791103579104, 0.052084298731642775, 0.020226811902830377, 0.02955851741717197, 0.02525613334000809, 0.03211992509022821, 0.07007503823842853, 0.054662875991198234, 0.029741963335254695, 0.021791030994791072, 0.05823878469527699, 0.05023527119192295, 0.19367732922546566, 0.03200810941052623, 0.07975691129104234, 0.03831243499007542, 0.018373455786786508, 0.007037527129796217, 0.024284762221213896, 0.032449219725094736, 0.04862054338445887, 0.046981974082882516, 0.046435760814347304, 0.07123717470676638, 0.04328150702349376, 0.11509761257912032, 0.035537010480766185, 0.02221254304458853, 0.00896571260454948, 0.04156918679655064, 0.025730376837600488, 0.01640899274207186, 0.06038486055331305, 0.05725166520278435, 0.028464608440117445, 0.04321319604059681, 0.059409040259197354, 0.013880144942959305, 0.06061678541300353, 0.04692246868216898, 0.02802809016429819, 0.02123580805346137, 0.04192010761471465, 0.034520052940933965, 0.06655094999587163, 0.027026914394809864, 0.05345107871107757, 0.023134065959311556, 0.01808609435101971, 0.06988925641053356, 0.07362847100012004, 0.028812876080337446, 0.13191523554269224, 0.018315325214643963, 0.04173828143393621, 0.042134272880502976, 0.009161172038147924, 0.07452943827956915, 0.009833911281020846, 0.07320797754800878, 0.03718704596394673, 0.04572429352265317, 0.047589062014594674, 0.07054318499285728, 0.022539197489095386, 0.07143154318328016, 0.10269416525261477, 0.08421051723416895, 0.08920814711018465, 0.0896093669871334, 0.09915947171975859, 0.05608418898191303, 0.011681189207592979, 0.04929271024593618, 0.02640820628585061, 0.05070365543360822, 0.07689633275731467, 0.06396937445970252, 0.07482136206817813, 0.028622036516026128, 0.04466855134523939, 0.06293483544141054, 0.036756930567207746, 0.0469260495447088, 0.029125168111932, 0.04681206679379102, 0.04390773865452502, 0.08426211134064943, 0.05977032888040412, 0.023016275990812574, 0.03243925268179737, 0.058112764309043996, 0.014736902485310566, 0.012547383157652803, 0.008154804017976858, 0.048381141386926174, 0.06486983707873151, 0.026873839015024714, 0.05870644534297753, 0.05372436346078757, 0.03754403383936733, 0.06795845532906242, 0.025672802876215428, 0.04143268357438501, 0.03455252561252564, 0.04174250425421633, 0.04385868269309867, 0.030913324699213263, 0.0548741320380941, 0.10095787365571596, 0.040455037596984766, 0.06934575940249488, 0.0850748001539614, 0.04719419863249641, 0.03066800407395931, 0.030794723934377544, 0.06123255647253245, 0.05443488451419398, 0.029901512098149396, 0.030774277765885927, 0.05949398277152795, 0.011803518336819252, 0.02911192634201143, 0.025165776860376354, 0.05224457665462978, 0.033270869971602224, 0.03007651979714865, 0.02524395469663432, 0.06549681827891618, 0.053103998507140204, 0.04322023902204819, 0.05795420074719004, 0.07000863828579895, 0.04619765386451036, 0.02222270119091263, 0.06912082928465679, 0.06966197368456051, 0.04234183674270753, 0.05423092748969793, 0.0973800613428466, 0.04433631409483496, 0.03998979263997171, 0.04100869831745513, 0.05671587168762926, 0.06074049400922377, 0.08385704713873565, 0.05526404900592752, 0.02161025309760589, 0.08338952378835529, 0.033976181148318574, 0.060084791693952866, 0.019019740248040762, 0.031663392946938984, 0.024353119588340633, 0.033212448106496595, 0.008835252319840947, 0.04187064347206615, 0.026258587458869442, 0.025794669090828393, 0.052034285399713553, 0.030339104632730596, 0.022818172656116076, 0.061316586143220775, 0.02893779252190143, 0.06020226996042766, 0.04233022213156801, 0.018514148432586808, 0.006466597096732585, 0.03041828251298284, 0.029645669674209785, 0.031347260301117785, 0.030763704016862903, 0.07520894869230688, 0.04299730899219867, 0.02565792095992947, 0.05267477739835158, 0.06527002537040971, 0.03421094843361061, 0.02899441653426038, 0.020072940569662023, 0.03528245382767636, 0.03838933633232955, 0.07869293127441779, 0.009726367588882567, 0.025936949932656717, 0.0382008048472926, 0.021550558449234813, 0.04632039024727419, 0.06237099616555497, 0.016673982136126142, 0.021960886333545204, 0.103908756718738, 0.009660912946856115, 0.10935704834992066, 0.03932770785468165, 0.04951192582666408, 0.014886526878399309, 0.03144502712530084, 0.038099535086075775, 0.1315899076871574, 0.09631880500819534, 0.050011892162729055, 0.03947765508200973, 0.06814535779994912, 0.013307743138284422, 0.06539466907270253, 0.012059349628543714, 0.06281306385062635, 0.05404673756856937, 0.033290759529336356, 0.048215709248324856, 0.0355352590122493, 0.05194297897105571, 0.02870172462280607, 0.03615263682149816, 0.06121264465036802, 0.030993035070423502, 0.059955253527732566, 0.020927831610606518, 0.013793470443488332, 0.06292765887337737, 0.04717628689832054, 0.026756559273053426, 0.030700335737492424, 0.03038270580873359, 0.016826211467559915, 0.0458117519156076, 0.029860439790354576, 0.045340057695284486, 0.04243309122102801, 0.01669060624408303, 0.05445153459731955, 0.018877041948144324, 0.07610453540110029, 0.07338291659834795, 0.09809215946006589, 0.035052688617724925, 0.011901098696398549, 0.04181283016805537, 0.0662459124578163, 0.04444332807906903, 0.042203849225188605, 0.00501498963785707, 0.02870847260055598, 0.08515500405337662, 0.1155757337983232, 0.05621123724267818, 0.045571856389869936, 0.04768096587213222, 0.0871277587430086, 0.02810388756188331, 0.015246375733113382, 0.06696676049614325, 0.08987408364191651, 0.025773015076993033, 0.03371266677277163, 0.028233639095560648, 0.07553443239885382, 0.03334386390633881, 0.07561450271168724, 0.023624764726264402, 0.018508109205868095, 0.009328159903816413, 0.009947127764462493, 0.08267204510048032, 0.019603988585004117, 0.024197507918870542, 0.0022813053692516405, 0.04056776611832902, 0.013736673881794559, 0.05926708967308514, 0.02764504919468891, 0.00914085389013053, 0.033133220131276175, 0.073689742712304, 0.09202562170685269, 0.0737761212803889, 0.033207650121767074, 0.02609747833048459, 0.18318331654882059, 0.12885273346910253, 0.12822745920857415, 0.21298977808328345, 0.15957032970618457, 0.1852339002653025, 0.1561684880289249, 0.14969768759328872, 0.19256795203546062, 0.19844209542497993, 0.1493292854866013, 0.08276798253064044, 0.1371428940910846, 0.15424019540660083, 0.1366283482639119, 0.15580639417748898, 0.13335770345292985, 0.12507184728747234, 0.12204470112919807, 0.16683712805388495, 0.11415144850616343, 0.1621480906032957, 0.10686717258067802, 0.15984299476258457, 0.16807744977995753, 0.17973264155443758, 0.13832114258548245, 0.21565671544522047, 0.07645817619049922, 0.11700919203576632, 0.1563585372059606, 0.08418998200795613, 0.18321211187867448, 0.18497636017855257, 0.13605351035948843, 0.21459580049850047, 0.3083988436264917, 0.1325437010382302, 0.2290259863366373, 0.1263238801038824, 0.17462714051362127, 0.17504044255474582, 0.19780064234510064, 0.10978574253385887, 0.12154621537774801, 0.1473390680621378, 0.1836629814351909, 0.12708597671007738, 0.06111136746767443, 0.07330240841838531, 0.1518885520636104, 0.12207081730593927, 0.13563627493567765, 0.19261268869740888, 0.12540314201032743, 0.12356530976830982, 0.20087485550902784, 0.10211417684331536, 0.15212084428640082, 0.1274083656608127, 0.28415225562639534, 0.15765201154863462, 0.11993237814749591, 0.10707641369663179, 0.07716322390479036, 0.07163316986407153, 0.11580335791222751, 0.09055832153535448, 0.15107444574823603, 0.17475885688327253, 0.12754544033668935, 0.07395925364107825, 0.1447650624322705, 0.10813518383656628, 0.17456107452744618, 0.11023734681657515, 0.09729251760290936, 0.10549420680035837, 0.09457196749281138, 0.13876862794859335, 0.17355233256239444, 0.07283039507456124, 0.14058429223950952, 0.13503117224900052, 0.16666549898218364, 0.3038600762374699, 0.10264795171678998, 0.14149645110592246, 0.20234178460668772, 0.18461649277014658, 0.14257145201554522, 0.13037757977144793, 0.10881023394176736, 0.08427671680692583, 0.14128156966762617, 0.09208039220538922, 0.2291849988978356, 0.1297418263857253, 0.2788502932526171, 0.12737952580209821, 0.10430396519950591, 0.13331828056834638, 0.19011739525012672, 0.07254811920574866, 0.12040377550874837, 0.17025161592755467, 0.0800659490050748, 0.11206209499505349, 0.15208275726763532, 0.09945694677298889, 0.15391148335766047, 0.2562111377483234, 0.17858627572422847, 0.14418461389141157, 0.16685496928403154, 0.26327970845159143, 0.07120616035535932, 0.12634788115974516, 0.11256261423113756, 0.14796278381254524, 0.16276634414680302, 0.08440485602477565, 0.08321928995428607, 0.19516184722306207, 0.07746058763586916, 0.20223804720444605, 0.1476878477842547, 0.1342682889662683, 0.16807080013677478, 0.14585555938538164, 0.19783702242420986, 0.24874673516023904, 0.16424820525571704, 0.153941243479494, 0.21196677203988656, 0.20299920870456845, 0.21867927513085306, 0.10428081019199453, 0.13415689260000363, 0.18477452569641173, 0.1284036599099636, 0.19101340498309582, 0.19078078621532768, 0.193198851775378, 0.22790264192735776, 0.08715175237739459, 0.19652981834951788, 0.10030511024524458, 0.12939554027980193, 0.1410355477128178, 0.09533157048281282, 0.1528397627407685, 0.12982628279132769, 0.1607318947208114, 0.1623196603031829, 0.10175151895964518, 0.1876844570506364, 0.2042233812971972, 0.19604256871389225, 0.19705399725353345, 0.1432810490950942, 0.28563527448568493, 0.07948384547489695, 0.08183974874555133, 0.10173021932132542, 0.09276180251617916, 0.07088885511620902, 0.1736653913394548, 0.13838974671671167, 0.16377858904888853, 0.17486703232862055, 0.15174902830040082, 0.19868376839440316, 0.17485459393355995, 0.13930344925029203, 0.14314018946606666], [0.04737701929116156, 0.07305218590772711, 0.05539560952456668, 0.06640531093580648, 0.024914919813454617, 0.05526937391550746, 0.020531315094558522, 0.040184736280934885, 0.06089730239182245, 0.030930709508538712, 0.11852660201839171, 0.06482109281932935, 0.051870575043722056, 0.0426650568988407, 0.024446615352644585, 0.0643022870644927, 0.040560233319411054, 0.023820029346097726, 0.04579406282573473, 0.027955816112807952, 0.017139742885774467, 0.009958265545719769, 0.02880543233914068, 0.03509726942866109, 0.04830995458178222, 0.04617718172085006, 0.017929914938576985, 0.018347330333199352, 0.035774835414486006, 0.07965367112774402, 0.05004165599530097, 0.07857789838453755, 0.08449843342532404, 0.0403917546645971, 0.02609202725579962, 0.09903433819999918, 0.004926190276819398, 0.04463509532797616, 0.009509311657893704, 0.053441467898664996, 0.0044611364228330785, 0.011244477973377798, 0.10013511389843188, 0.030601069775002543, 0.026510932511882856, 0.02690849174541654, 0.027356157079339027, 0.08637937702587806, 0.058831512069446035, 0.08904189118766226, 0.02854441714589484, 0.04057519501657225, 0.027261820832791273, 0.047581213802914135, 0.013388135357672581, 0.04558350068691652, 0.03782815023441799, 0.02682170128537109, 0.03140828339383006, 0.030045236417208798, 0.040598713676445186, 0.04920977895380929, 0.03935604305297602, 0.025004138951771893, 0.040486215220880695, 0.01188985979752033, 0.03551782967406325, 0.04344233784649987, 0.032918646684265696, 0.02808666045893915, 0.04653401003452018, 0.048881519614951685, 0.027953995995630976, 0.058981351685361005, 0.046514187270076945, 0.0382882038684329, 0.026122073104488663, 0.018160771105613094, 0.0471091039798921, 0.04047394380904734, 0.04261943708115723, 0.019802926835836843, 0.040275486098835245, 0.07717868284089491, 0.017643523860897403, 0.05149295546289068, 0.08933410441386513, 0.03198874677764252, 0.03782202380534727, 0.04996072479116265, 0.012869990114268148, 0.06336610487778671, 0.008954566474130843, 0.06282185087911785, 0.029459201359713916, 0.05146432340552565, 0.0075029576237284346, 0.037893188346060924, 0.07554644034826197, 0.07187245311797597, 0.027391212424845435, 0.03606729726016056, 0.008126751763484208, 0.03197908401489258, 0.03654560030554421, 0.04788616228324827, 0.019524909039319027, 0.04019885564048309, 0.10089364077430218, 0.041623727229307406, 0.073184867069358, 0.049930656678043306, 0.05081089948362205, 0.02028267892455915, 0.04853410544455983, 0.017293421260546893, 0.016669403084961232, 0.022597788192797452, 0.06716716263326816, 0.023910684540169314, 0.032206964169745333, 0.026728211087174714, 0.11409129001549445, 0.08644383255159482, 0.03780423823627643, 0.04178261733613908, 0.038127892548800446, 0.03087253811827395, 0.06585763563634828, 0.028830567025579512, 0.0071593947359360754, 0.004464920448299381, 0.010313616057828767, 0.037134824742679484, 0.03672055419883691, 0.0077714838153042365, 0.010390882907813648, 0.01681886235019192, 0.10449628534843214, 0.00967021391261369, 0.0348304896033369, 0.0453388368623564, 0.010856424723897362, 0.05970188431092538, 0.02925281565694604, 0.02639480124344118, 0.03612877677369397, 0.03782896288612392, 0.026505366404308006, 0.032031386872404255, 0.055091896720114164, 0.03207521069271024, 0.031212935282383114, 0.03770992610952817, 0.012441514863894554, 0.02285789611050859, 0.05894596237340011, 0.03747809772903565, 0.042841580434469506, 0.015806530245754402, 0.061375238074106164, 0.022824642328487244, 0.026807118083524983, 0.020509918977040797, 0.04779210990818683, 0.07008709071669728, 0.040336605670745485, 0.013358419764699647, 0.05474742516526021, 0.04058114704093896, 0.05541755112062674, 0.06700285113765858, 0.024981867099995725, 0.04688588822318707, 0.02994541198859224, 0.046396308243856765, 0.020726088041556068, 0.05756953818490729, 0.05636368179693818, 0.018867575854528695, 0.04479571092815604, 0.03005116988788359, 0.03870961387292482, 0.06305101123871282, 0.05714863284083549, 0.07919857875094749, 0.09345201469841413, 0.003053460395676666, 0.025215352325176354, 0.05188175549847074, 0.04246426513418555, 0.014890709808241809, 0.05651079773087986, 0.02456958365655737, 0.03426655755902175, 0.01725096855807351, 0.08381716412259266, 0.04780754657986108, 0.01873680386779597, 0.035229839268140495, 0.04876876511843875, 0.0036528717373585096, 0.007826094752090285, 0.03759595820156392, 0.02754815068328753, 0.0390772070386447, 0.027833152089442592, 0.00753791602619458, 0.05950774218945298, 0.023826474898669403, 0.048591273080091923, 0.056829141976777464, 0.061122841070755385, 0.05506912020791788, 0.030778650871070568, 0.060125335221528076, 0.0023210060953715583, 0.06857346568722278, 0.030495165301545057, 0.020058656082255766, 0.026386613499198575, 0.03828980690741446, 0.06344302106299438, 0.04751747073896695, 0.04392928320157807, 0.04174952126049902, 0.032433222731924616, 0.07507377391448244, 0.051740647249971516, 0.013805595281155547, 0.026048203435493633, 0.06650815776083618, 0.06746040002326481, 0.027461109748401213, 0.04956170538207516, 0.019680518853419926, 0.026217366721539292, 0.06111516726377886, 0.025924782421498094, 0.05061791882326361, 0.005534191977858427, 0.0451460677140858, 0.03085415326495422, 0.02727619623328792, 0.060327076935209334, 0.045401622555800714, 0.07754263206152245, 0.04359936145192478, 0.017163241136586294, 0.031944410875439644, 0.022762103399145417, 0.10944536392344162, 0.023434273971361108, 0.033905940581462346, 0.024695743195479736, 0.021743181023339275, 0.05353081134671811, 0.012416880199452862, 0.0511214437574381, 0.02403254147793632, 0.07681776158278808, 0.03164365181874018, 0.08430539339315146, 0.03606712656619493, 0.049983813005383126, 0.050843609642470255, 0.044310416851658374, 0.08298428147099912, 0.036318625570856966, 0.017122617828135844, 0.08175837225280702, 0.038483110402012244, 0.048907030941336416, 0.013403411539911758, 0.13737108965869993, 0.08208431609091349, 0.06922287459019572, 0.04458934192371089, 0.019213876803405583, 0.05248381166893523, 0.02811819616908906, 0.06365883018588647, 0.020574756708811037, 0.08379420949495398, 0.041549649758962914, 0.013912988688389305, 0.09798770959605463, 0.0615374344488373, 0.052920201924280263, 0.10782051322166808, 0.060195865225978196, 0.011919415828742785, 0.02911970776040107, 0.03474226679827552, 0.001636930778659007, 0.01563610159792006, 0.0022843996612209594, 0.05234373871644493, 0.022205333079909906, 0.026604799350025132, 0.03420564578846097, 0.03812739530985709, 0.07370909792371094, 0.06947019530343823, 0.032665444450685754, 0.07319568016100675, 0.02365494230616605, 0.036327301277196966, 0.008925551283027744, 0.06631513257161714, 0.05192178323341068, 0.05212491647398565, 0.0872441052342765, 0.030571415409212932, 0.07276127143995836, 0.0521223375108093, 0.015192727732937783, 0.025559898094797973, 0.006581962097698124, 0.03652887971838936, 0.008782281529420288, 0.049774664657888934, 0.015325828208005987, 0.017171586587210186, 0.03410918143345043, 0.016989144423860125, 0.039431248587789014, 0.03367393779626582, 0.016896375964279287, 0.027920643879042473, 0.017944130777323153, 0.05129525845404714, 0.05084216987597756, 0.07285486368346028, 0.04702753823949024, 0.04001566019724123, 0.0653770356439054, 0.035736689023906365, 0.010872182374441763, 0.02432897195831174, 0.06755410358891822, 0.03625296776590403, 0.07520483719417825, 0.03536066877131816, 0.02645491334988037, 0.04676344869949389, 0.05161035209312104, 0.0812511365802493, 0.033292618609266356, 0.01190038345157518, 0.009864776275207987, 0.06567663323949091, 0.12215888797072694, 0.22436921746702865, 0.14971342112403363, 0.1494963132427074, 0.0887627991323825, 0.13744799100095406, 0.08388033573282883, 0.15319777477998286, 0.16985674883471802, 0.10580650996416807, 0.202762626868207, 0.13464939664117992, 0.15804934257175773, 0.17026191693730652, 0.13129763508914039, 0.1992772935773246, 0.19832967489492148, 0.10603744405671023, 0.1405873498879373, 0.13698535098228604, 0.18156445497879758, 0.2099314914084971, 0.11660153031698428, 0.14929780358215794, 0.13280046929139644, 0.07848369015846401, 0.09536960555124097, 0.1791483783745207, 0.17997857445152476, 0.2090297671384178, 0.18248879991006106, 0.08706788226845674, 0.204057214432396, 0.09862707724096254, 0.20201225619530305, 0.24277124408399686, 0.1610999702825211, 0.13797214021906257, 0.1509866348351352, 0.14709337265230715, 0.12796546623576432, 0.1807663493673317, 0.2767543791560456, 0.1072049314097967, 0.12866618722910061, 0.14367006806423888, 0.12138752936152741, 0.14263316901633516, 0.2669261768460274, 0.21871050470508635, 0.12829119485104457, 0.1923542283475399, 0.17504922958323732, 0.16099908272735775, 0.10736726137110963, 0.13043108861893415, 0.17745757300872356, 0.12445073647540994, 0.11073666377342306, 0.1480657493812032, 0.10593379571218975, 0.1573725781054236, 0.13791790406685323, 0.09109969600103796, 0.19910392788005993, 0.07892138659371994, 0.12445813568774611, 0.11793929603300057, 0.15155001397943124, 0.15979132644133642, 0.13080496777547523, 0.14297466084826738, 0.2372461327468045, 0.1502960515790619, 0.10139911755686626, 0.18653518200153485, 0.13084918493404984, 0.0936949418974109, 0.12857917783549055, 0.15318834950448945, 0.15367184387287125, 0.1893274681060575, 0.173320930916816, 0.12794937647413462, 0.17577506485395133, 0.16336703847628087, 0.1727295876480639, 0.17134561581769958, 0.08343271678313613, 0.16184113832423463, 0.17414579837350175, 0.1692586817080155, 0.10234908884740435, 0.17646652384428307, 0.14406497968593612, 0.0974643841618672, 0.1656145288143307, 0.09276747252442874, 0.24763827823335305, 0.16352131613530219, 0.12279490852961317, 0.17965893144719303, 0.07915081412647851, 0.1685121702030301, 0.15400211443193257, 0.20474450255278498, 0.1418688756530173, 0.1511696632951498, 0.19702962512383237, 0.07835709460778162, 0.25450915563851595, 0.12239882431458682, 0.12682177213719115, 0.3273684054147452, 0.1693939752294682, 0.06467582483310252, 0.1094594869937282, 0.1430223512579687, 0.13373716355999932, 0.14924698130926117, 0.05031162334489636, 0.30010804475750774, 0.17847079754574224, 0.1943925369414501, 0.102565038978355, 0.12091429147403687, 0.17775867716409266, 0.1448360859649256, 0.12154538417235017, 0.2062297033262439, 0.17918107740115374, 0.18824086000677198, 0.06275341744185425, 0.18171288451412693, 0.12643462338019162, 0.13499171967850998, 0.13411459018243477, 0.13364660670049489, 0.17424350953660905, 0.1084384105342906, 0.13317299773916602, 0.15298063721274957, 0.1773886868613772, 0.16281358926789835, 0.07005603925790638, 0.11515843900269829, 0.11942658966290765, 0.196042227325961, 0.09517007172689773, 0.14497425901936367, 0.13545713532948866, 0.08194074020138942, 0.1170236490725074, 0.23305838636588305, 0.1020815891388338, 0.1127693839953281, 0.12601617083419114, 0.22667355631710961, 0.0790977208816912, 0.09642722536227666, 0.12955358804902062, 0.12588207959197462, 0.12125495210057124, 0.15572269476251677, 0.09250859657186083, 0.1544822394498624, 0.22333215514663607, 0.08799867646303028, 0.18164322653319687, 0.11293411851511337, 0.16656293417327106, 0.14169812231557444, 0.08402964100241661, 0.07624865305842832, 0.06640206032898277, 0.1366063955356367], [0.05403397633926943, 0.045320283170440234, 0.008220844956667861, 0.07441669120453298, 0.04438849078724161, 0.0410760519298492, 0.021480625873664394, 0.010432869912619935, 0.01378387447402929, 0.04533166029432323, 0.06822383249527775, 0.05242030238150619, 0.04322158973081969, 0.04192525811959058, 0.011027121472579893, 0.06300856039160863, 0.06418716511689126, 0.010593465103738708, 0.027792402615887113, 0.011379041407053592, 0.05407648655818775, 0.07317097406485118, 0.020504961430560797, 0.06399797683116049, 0.01442503162252251, 0.05499618564499542, 0.021940657243249007, 0.05410153775301296, 0.040682197868591174, 0.02765758221357828, 0.036232566126273014, 0.03868037325446494, 0.047960109877749346, 0.03155510246870108, 0.019277313731436152, 0.07259068879648112, 0.019362959428690374, 0.04853780505072791, 0.012029478184558684, 0.02187511261581676, 0.06681194106931798, 0.018209580302936956, 0.05165949711226858, 0.02179088998673251, 0.10363052555476315, 0.05327856648364104, 0.03185520843544509, 0.07644654673640616, 0.015739341761218384, 0.006312247542155092, 0.011510796739457874, 0.11524442423251458, 0.041010093555087224, 0.06864799957838841, 0.02006824277486885, 0.060787163965869695, 0.04199894225166645, 0.023876337945694104, 0.07221138454042375, 0.022991744299361017, 0.024794111159280874, 0.02341247338335961, 0.02984756723890314, 0.04099272358871531, 0.06845162730314769, 0.041979301313403994, 0.033671065684757195, 0.03516667136864271, 0.052634285821113735, 0.054900793693377636, 0.014280687610153109, 0.03179688676027581, 0.08333528763614595, 0.005330154708644841, 0.04418345393787604, 0.05884071841137484, 0.04880233987933025, 0.044142917831777595, 0.04803757896297611, 0.04046213252877351, 0.015063977170939324, 0.02435077440168243, 0.013457983513944782, 0.00954371020270628, 0.007181638757174369, 0.06609232499613427, 0.06554306150064804, 0.061572909107781015, 0.023832235820009373, 0.0421966800786322, 0.027212271343159955, 0.06881937631987967, 0.056888966500991955, 0.06156018498586491, 0.025404163970961235, 0.055101860052673146, 0.043255060591036454, 0.006096727856856887, 0.06120985417510383, 0.056780679733492434, 0.051646750725922175, 0.029483267353498377, 0.01904195643874118, 0.04656051212805323, 0.03116325220617, 0.05698328975995537, 0.06532803905429319, 0.027917009210796095, 0.05126721640408505, 0.06986623498960398, 0.015563093747914536, 0.02213014795415802, 0.027083987406513188, 0.006708575738230138, 0.008700876278453507, 0.05803799293062184, 0.04000302513304632, 0.032047339336713776, 0.04432210938830394, 0.0754299305845052, 0.05248406028840691, 0.03142543813737575, 0.041401131165912375, 0.03619419709139038, 0.051064699146081693, 0.025842448558250908, 0.012002130970358849, 0.008170623823389178, 0.033118221326731145, 0.03028149170859251, 0.010194794504059246, 0.03164609348459635, 0.014839584182482213, 0.046606269243056886, 0.0083599577556015, 0.022689564029860776, 0.03822982653218787, 0.026273667899658903, 0.04600191612553317, 0.0508605306094978, 0.036021458508912474, 0.03973584454797674, 0.01289168123548734, 0.016857492992130574, 0.04321068758144975, 0.03846025596430991, 0.047090442676562816, 0.03299842013802845, 0.03094851734203985, 0.06244843185413629, 0.15126725571462885, 0.03952465900511015, 0.05908833598368801, 0.017520585242891684, 0.028331802968750708, 0.021382280174293555, 0.0270876146532828, 0.017769401383702643, 0.004345704164734343, 0.01107220694393618, 0.016442428350273985, 0.04608248367730994, 0.08649650277220644, 0.04474995381315239, 0.028881762227683794, 0.1049156730005052, 0.03266983425419312, 0.02831656482157996, 0.05638047288812231, 0.05939023052633274, 0.03948510253394488, 0.019367610839253757, 0.041236604447476566, 0.08272365404991433, 0.04461374745005742, 0.02695101866265759, 0.14121298037935048, 0.036115169496042654, 0.011837992024084087, 0.03832470269117039, 0.09737352302181534, 0.02640695576701546, 0.015931034795357846, 0.04475903398997616, 0.039791301533114165, 0.06258929148316383, 0.03846388506644871, 0.07005485924310051, 0.014815320591878844, 0.06541510781971738, 0.08503952587489039, 0.040964547952171415, 0.020022016251459718, 0.06287835058174096, 0.02702925030462211, 0.03366142889717594, 0.017825452086981386, 0.03350959661474917, 0.05261326448817272, 0.03835554263787344, 0.07312504254514351, 0.014041927570360713, 0.03172263859596569, 0.0671918761509005, 0.044656984973698854, 0.03809321569860913, 0.042781640877365135, 0.0455588502518367, 0.10124343723873608, 0.09240031722583808, 0.014317769018816762, 0.037818390992470086, 0.0691044946142938, 0.02099430206726538, 0.06448811342124827, 0.038250844154390506, 0.14333878818433732, 0.042063535074703395, 0.039428001691703685, 0.05394776846515015, 0.07538300458691083, 0.037151040669414215, 0.015634029150533024, 0.012052747297275346, 0.051543677545851097, 0.0685343099758029, 0.024266297587018926, 0.03793408068304416, 0.04010879601992201, 0.01592732034623623, 0.07046103666652925, 0.03233114031900186, 0.07051019652863033, 0.01799802925233962, 0.05766369074990507, 0.08763919497141615, 0.044173479473101906, 0.05688582350558136, 0.05799426187877543, 0.029505277598218527, 0.033525333856232464, 0.030892397990101017, 0.03725234011653811, 0.07589392131194472, 0.061014212915324606, 0.05429582830402069, 0.010765026454464532, 0.017365801068081055, 0.0415439426433295, 0.09109727659961209, 0.09222486609360203, 0.05425680988992099, 0.021284210924932268, 0.016750664544815663, 0.018106494135281537, 0.027434748662926722, 0.006029101969033945, 0.02301596243341919, 0.025026201146829408, 0.015371221670648083, 0.031241901306202635, 0.05121980058902409, 0.050843461212934926, 0.047297431374317966, 0.03464782108494546, 0.0198676717991475, 0.004641651321435347, 0.0268728686569375, 0.01744144447002327, 0.04625241694157012, 0.06443533187848516, 0.10115679891896434, 0.02604825909656938, 0.02961310608952772, 0.06039716536179185, 0.08200916621717624, 0.0497276867099572, 0.04605985930538736, 0.06849142868304625, 0.03754178142116871, 0.013250541178422282, 0.051733737855101936, 0.04128925982513465, 0.03537011260050349, 0.07635299160028808, 0.04844422022870276, 0.02136315688403556, 0.03962343143939506, 0.00702546676620841, 0.09932905246387236, 0.0373622262122808, 0.04514822365308646, 0.0416127953940304, 0.06642100735916756, 0.02947897959529655, 0.060818055862910114, 0.022615408634010237, 0.017952810194401536, 0.04010389413451776, 0.09434343795874156, 0.05567338797845878, 0.041614350193412974, 0.06965619235415943, 0.007921855922177201, 0.03172308388457168, 0.04993213355191983, 0.03902443662809674, 0.031980939384084195, 0.043792564756586216, 0.03899919618561398, 0.025832060346147045, 0.033159109952975996, 0.03569783759303391, 0.05874936003237963, 0.04477628150198143, 0.0171190425317036, 0.024972182072815485, 0.024234771153714973, 0.06883312831632793, 0.031163612147793174, 0.014778657568967901, 0.02324994304217398, 0.10668393631931394, 0.033650408004177734, 0.051926918895333074, 0.021995552051521372, 0.0816560597741045, 0.019676212541526183, 0.037621224619215354, 0.043461110471980646, 0.015578477541566826, 0.03705807182996068, 0.01654850537306629, 0.052617943729273975, 0.03462314838543534, 0.03903821459971368, 0.04896243968687486, 0.029774200374959037, 0.05664887430611998, 0.032338328019250184, 0.03795557699049823, 0.04032232303870842, 0.03389388439245522, 0.031371461736853234, 0.04916335761663504, 0.08950458315666765, 0.03220494923880324, 0.013229280502855545, 0.052465120679698884, 0.028082111093681306, 0.01772676685504848, 0.022795321929152124, 0.36087628395762295, 0.10469184868270531, 0.08715968593605794, 0.17077220283681527, 0.12879285699455068, 0.15805296425241977, 0.17619290883885697, 0.1308739132946357, 0.15801330388057977, 0.17937356082256883, 0.1500965771265328, 0.25824474112596363, 0.1062639920564834, 0.17252479941817, 0.21148547442862764, 0.1968678369303234, 0.14132707816315815, 0.125071698857937, 0.10783745645312592, 0.12148351132054813, 0.17492089740699157, 0.1067859519389458, 0.1434340502601117, 0.1582156281801872, 0.12357014857116155, 0.11244911758694798, 0.17960755998501554, 0.12853697931859642, 0.1624894785345532, 0.10945565009023994, 0.1057073070842307, 0.09218720952048898, 0.31613947357982397, 0.20703986141597852, 0.131361459789332, 0.13003785425098613, 0.14763490296900272, 0.18720976455369964, 0.1455661960062571, 0.1300477990298532, 0.2573077945271507, 0.14951774646760896, 0.16212823073146865, 0.11609759720158763, 0.1445835776394233, 0.15974100882885978, 0.10297414046362974, 0.16690160584403202, 0.09041746190632693, 0.10280392147251405, 0.11272498872131109, 0.16970272350590676, 0.14379206229932606, 0.13452303857775405, 0.10962916421703994, 0.12645152950426564, 0.16824654070660472, 0.10774476962978952, 0.16638471483020112, 0.12327228017966263, 0.08799342947895639, 0.2069803114864044, 0.28109422128181905, 0.2149259819998406, 0.13433153479127213, 0.14775228104554117, 0.16675838618539274, 0.1629814037005417, 0.2279062636080198, 0.17132991197286174, 0.11665440833894536, 0.11027109969290905, 0.1109979442844633, 0.11313164111925289, 0.13225933973444626, 0.12345012102741748, 0.14822106604697183, 0.10560204085777514, 0.12145732835051604, 0.1432903259410523, 0.09380121744470671, 0.11399231720133685, 0.15838341292692348, 0.15963161626132205, 0.07952471554744989, 0.16079595690825954, 0.13793400867143646, 0.2743172849295661, 0.2119268148089759, 0.11060076911235228, 0.11928460939088836, 0.20610055478755385, 0.1887196788447909, 0.21822610491653904, 0.15127832855796441, 0.23753557034069672, 0.09427349796169437, 0.14499699842417613, 0.16162083920789883, 0.16175248136278242, 0.18594510038383305, 0.09362265671370551, 0.12848692887928337, 0.20643262134399265, 0.13615666888654232, 0.1544036905397661, 0.1726654957747087, 0.07699347246671095, 0.20291901222663, 0.16081525274785236, 0.1458391876076348, 0.1726139016682282, 0.11423709234804846, 0.1601259459857829, 0.10294491468812339, 0.16157254023710266, 0.09070049476576969, 0.1413080346537754, 0.17188196594361216, 0.11816793688922189, 0.12476041243644431, 0.1006936765043065, 0.11433512263465673, 0.18111646495526657, 0.07267899694852531, 0.08491594344377518, 0.09080798001377843, 0.09720453599584289, 0.14379179512616247, 0.13005562126636505, 0.13481933361617848, 0.18476409110007808, 0.1813155534910038, 0.12905051582492888, 0.19745915051316842, 0.09556656412314624, 0.09120818314841017, 0.133027640695218, 0.17752040323102847, 0.11669441009871662, 0.1256284728879109, 0.07693973355344497, 0.1542597881052643, 0.07133015096769668, 0.1641161771840416, 0.11542963460669853, 0.14709653420140967, 0.20438326959265396, 0.1675647296360694, 0.08463515929179266, 0.263101949240081, 0.17705010424833745, 0.12336078871157952, 0.09077543683815747, 0.14205374463927, 0.11497628627694212, 0.08931259697419591, 0.1730403397232294, 0.17369831301039085, 0.08675634351675399, 0.14904379611834884, 0.1351022403105162, 0.20617102913092822, 0.08971372779342346, 0.10028800374129787, 0.21387032145867124, 0.1457201619632542, 0.10417636032798328, 0.16702880995580927, 0.1343570795143023, 0.171937552804593, 0.10939341358607635, 0.11293597388430499, 0.1738696452230215, 0.10993672505719587, 0.11334575814544223], [0.023493734843214042, 0.06608078459976241, 0.039934231754159555, 0.045662305637961254, 0.04942671614116989, 0.0457757874391973, 0.030666820348415058, 0.011018405875802273, 0.020270850945962593, 0.03607246260799002, 0.04233298292092513, 0.010800293312058784, 0.057276939041912556, 0.05323784484062344, 0.038786485529271886, 0.04362045328889508, 0.03521784987242427, 0.011584016101551242, 0.021590291180473287, 0.06956336452276446, 0.06852507023722865, 0.005727822481276235, 0.009342671673948644, 0.02102011025272077, 0.05751474542194046, 0.047467832191614434, 0.03009505308000371, 0.021247268668957986, 0.04223123447445687, 0.019695152150234208, 0.0294144980944111, 0.024278209057229105, 0.058613999717636034, 0.03247216322051827, 0.02148244599084137, 0.030578465812141076, 0.07074109351378866, 0.049978762690443546, 0.042297812542528845, 0.06162482975923922, 0.02489924750989303, 0.03863058998831548, 0.03608135353715625, 0.06392978088115342, 0.0076603244724537944, 0.02444717381877126, 0.02462940818077186, 0.07324564896407537, 0.030138253496261314, 0.018862260221794713, 0.0690249066974502, 0.00939405612371047, 0.038229128913371824, 0.02904102897446137, 0.010134430067409994, 0.03938802590710111, 0.06456849543610588, 0.0270364676907775, 0.04157923918683082, 0.03206004861567635, 0.04449071791896131, 0.041137635344057344, 0.07039387230179273, 0.07749788797809742, 0.024405826916336082, 0.0036093707512918627, 0.11179576787981205, 0.032339867975679226, 0.07551707356469706, 0.040755733571131714, 0.01973959009774262, 0.0445772115199361, 0.09257711906684563, 0.021846647541678976, 0.05128124299517367, 0.025960678249248303, 0.034912741830339655, 0.03678205226606224, 0.011089898816862842, 0.07041126082185656, 0.01902892989164684, 0.058191817879560404, 0.026704343617893755, 0.03384617913980037, 0.006046977059668279, 0.0047413305674126605, 0.0401835154480068, 0.06688662339001894, 0.03289463078544941, 0.055768668607925065, 0.03861227749439422, 0.026886921223194804, 0.038697546551702544, 0.027564437114051543, 0.04873500110988971, 0.03411513716855552, 0.05100363152450882, 0.019938478253607173, 0.03972790356783662, 0.03309737810923252, 0.031345538518507965, 0.014878320580464788, 0.02327424837858416, 0.037156699545448646, 0.049237876664847136, 0.08796481968602166, 0.013447593446471728, 0.05277709729853086, 0.05682504161086399, 0.023252061873790808, 0.08105521701509133, 0.04743252822663635, 0.017413484056305606, 0.055266869167098776, 0.029063794354442507, 0.060660702001769096, 0.036041633793502115, 0.033357927604811266, 0.0347989965666784, 0.1237284041417297, 0.027837781235575676, 0.06601033252081834, 0.03908132224751171, 0.029941665998194367, 0.03687369266117457, 0.027210388143430464, 0.029062452922516968, 0.04149737287661992, 0.03056299945455976, 0.07006947955233045, 0.04327118003857322, 0.05267872191325296, 0.011217250430490822, 0.017335261691187043, 0.08334066078532487, 0.011155208740092348, 0.04569244054437149, 0.0044723493465426145, 0.012008573739876738, 0.009888407184917014, 0.04132105714234058, 0.036005175788886845, 0.08859731504344381, 0.03205959219485521, 0.04478277529415209, 0.031036649234010838, 0.02920623290265212, 0.02749506114923861, 0.05409870274888817, 0.027595380961429328, 0.046351322962436825, 0.023695869895163924, 0.07058404764393345, 0.032931485839071684, 0.05115295163705014, 0.0821212973096408, 0.04690045287134126, 0.018840203592844773, 0.01023350678224233, 0.05807356406876352, 0.03706295516167302, 0.06666951550869271, 0.05347021127818152, 0.03253827744629234, 0.03801379476499278, 0.04450110798643436, 0.012120137089368654, 0.059535780528676696, 0.0313076407474, 0.07126964366761968, 0.04036675913084764, 0.020606808211596217, 0.014403482437046478, 0.02663964689418208, 0.0326966851571342, 0.025150523870252073, 0.012993426898901816, 0.057797466579359025, 0.08584065944887698, 0.017233615290024318, 0.0384334124828456, 0.07415149215376005, 0.009364449997519841, 0.012402548400132218, 0.03835124560282566, 0.04617530408722814, 0.03683636634377763, 0.06562992988619953, 0.0330382029642351, 0.01777615492756013, 0.008888805696187774, 0.027461204372229986, 0.029058872059977148, 0.012701097712124465, 0.02018860057432903, 0.019044210712308995, 0.03072672465350479, 0.036263528527342714, 0.02602535085316049, 0.017253903752134647, 0.04476629590499215, 0.016331683218595572, 0.08716785698197782, 0.0224267862358829, 0.037931175174890086, 0.010519101906538708, 0.05007388746889774, 0.008919342290027998, 0.01974647537281271, 0.025231336330762133, 0.0471902170102112, 0.02006717408221448, 0.03471992815320846, 0.06782944037695415, 0.059502005387912504, 0.07273356706718914, 0.030934960159356706, 0.08528640872100368, 0.031228590887621976, 0.03643896110588685, 0.040336583406315185, 0.03957840905059129, 0.00888962762473966, 0.02307777220266871, 0.02912931300670607, 0.005230637807471794, 0.06673246447462589, 0.02131638117134571, 0.04194327375444118, 0.08584077819250524, 0.030461627648037393, 0.05579725242569111, 0.07345851918216795, 0.029181051831983496, 0.03927539015421644, 0.028429319318092894, 0.014246581285988213, 0.03153897188894916, 0.04583586429362185, 0.03540064826665912, 0.005108696450406569, 0.021525679803744424, 0.08989468566142023, 0.016735632343625184, 0.027537335736269597, 0.03785395841987338, 0.07009900218690746, 0.04425824015925173, 0.026914427071460523, 0.04062355335918255, 0.005547776991079445, 0.017751934938132763, 0.05175858867005445, 0.01982735648198286, 0.013208489235694287, 0.03236064439988695, 0.023367104040517006, 0.057809114587143995, 0.053191720362519845, 0.03272231151640881, 0.01766323715855833, 0.003451880984357558, 0.04450589112821035, 0.016663521564623807, 0.03874363021168392, 0.03684464500111062, 0.03613331129599828, 0.0037992093439243035, 0.01597470647539012, 0.02647118493769085, 0.056382402472081594, 0.004436806038938812, 0.04362905478046741, 0.04461626333068125, 0.04952776696882211, 0.01595203942997614, 0.04036924532556441, 0.034605054825078696, 0.019408148800721392, 0.020364047995826695, 0.04055635188706219, 0.04430105836945586, 0.06322102242847905, 0.058565492945490405, 0.03794233336520847, 0.03033924564078916, 0.04686717125878204, 0.04437295763636939, 0.055231030855793506, 0.054736526726628654, 0.019375804149603937, 0.0680199422640726, 0.027776418610301334, 0.0068268351151346, 0.056939595815492794, 0.03216027937014587, 0.023061790052452125, 0.025632435608713422, 0.05208965332712978, 0.006142779511719709, 0.039509467242169194, 0.07347340666456148, 0.020743964523717295, 0.004468184970392031, 0.0695269473362714, 0.04067897694767453, 0.0759949795610737, 0.02277584426337853, 0.051534964732127264, 0.030071102119109128, 0.12602699134731665, 0.021426345192594454, 0.05298936266626697, 0.04292599973268807, 0.02053909280220978, 0.04371865055873059, 0.03433232668612618, 0.027694175660144538, 0.14358810527483, 0.01914456948725274, 0.029913766811660025, 0.02860031385353068, 0.03750213960302062, 0.020784830885531846, 0.03664436160761397, 0.029613529113703407, 0.06647730668191798, 0.03844948369078338, 0.022226415640034247, 0.021558291628025472, 0.023591794815729372, 0.033708351184031926, 0.045774425598210655, 0.02263457645312883, 0.02459564602759201, 0.039182168984552845, 0.048479798788321204, 0.02474521847034339, 0.06569623335963115, 0.012353462752798805, 0.12798311450751498, 0.014568390433851164, 0.04218334739562124, 0.05132267338922247, 0.0016066589228103112, 0.03225322223443072, 0.02412320038274629, 0.020906723075313494, 0.07526832792791538, 0.015005602617748082, 0.013992252843308961, 0.044627514289459214, 0.06564912924659438, 0.17353603499941528, 0.17034120799507946, 0.1402859785594046, 0.15262682572938502, 0.11600108089623973, 0.14651378500275314, 0.11070124106481671, 0.16476797580253333, 0.11037965363357216, 0.22133463498903438, 0.14468847279204056, 0.15978727431502193, 0.08674689597683027, 0.1343044760869816, 0.14108656294411048, 0.09520406209048815, 0.2302618997055106, 0.11521257867570966, 0.114030129625462, 0.12952673714607954, 0.10540114890318364, 0.1038025479647331, 0.1597764834878035, 0.19123713282169774, 0.11817541773780249, 0.16294793284032494, 0.17136531241703779, 0.21710425964556634, 0.04622841959644575, 0.14422376960283145, 0.09505914291366935, 0.17352343333186582, 0.15773517661727965, 0.10004115800256841, 0.09603155674994923, 0.13001806859392673, 0.15395207883557305, 0.09289402354625054, 0.19019529107026756, 0.12062485388014466, 0.22868718107929453, 0.10233066132059321, 0.21315854246495292, 0.10656439859303646, 0.10586542906821705, 0.10110789138707332, 0.15541471831966192, 0.08933946272009052, 0.11180646964930929, 0.1858589518815279, 0.1373284013243392, 0.11294512456515804, 0.17509056720882654, 0.10157332930248231, 0.14582032221369445, 0.15886138571659103, 0.12201785764773376, 0.14951265533454716, 0.21204352495260537, 0.07256124779814854, 0.1732190340408124, 0.1386440361966379, 0.17302635766100138, 0.14436712284805253, 0.12072157798684202, 0.18941492278827354, 0.09796433194424026, 0.13780775450868532, 0.1051237118372228, 0.12343906302703544, 0.18343123840168118, 0.12846978526795283, 0.1040947760338895, 0.1457923580892384, 0.1534240852924995, 0.08124163708998822, 0.08751258457778022, 0.09079884417587891, 0.14869234466459602, 0.09935419642715715, 0.21117510827025399, 0.10451236768858507, 0.13788363168714568, 0.14853655302431434, 0.19009888608707115, 0.15334970725234598, 0.22033847984857857, 0.1283038262045011, 0.07465494287316687, 0.11116827459773049, 0.11054955350118689, 0.21476413443451747, 0.08953079581260681, 0.140144866600167, 0.09531093135592528, 0.21045201894594356, 0.1149758929386735, 0.08162037731381133, 0.11960802250541747, 0.14685636037029326, 0.09721566078951582, 0.18959205859573558, 0.09747433636221103, 0.16832505993079394, 0.20087877404876053, 0.08867184893460944, 0.23766854836139828, 0.11428253405028954, 0.12755103613017127, 0.12535413057776168, 0.1928820289322175, 0.13101156684570014, 0.18325658136745915, 0.07872012356529012, 0.14140764571493492, 0.17875643534353003, 0.09703467323561199, 0.22743716690456495, 0.2412591627216898, 0.15059691824717447, 0.12196321331430227, 0.12109264440368861, 0.14076398103497922, 0.12125121909775771, 0.14599760645069182, 0.08070602169027552, 0.11386007390683517, 0.19323438580613583, 0.1390058480319567, 0.16760459780925885, 0.14348427881486714, 0.11554592914762907, 0.143841830722522, 0.22023995232302696, 0.06674094722256996, 0.1177623234980274, 0.14301521179731935, 0.09122554198256694, 0.12848327751271427, 0.10718943536630832, 0.12335418359725736, 0.25132744980510324, 0.11170665820827708, 0.14591879036743194, 0.0925694897887297, 0.13685459940461442, 0.1424918937846087, 0.09905548198730685, 0.09604428458260372, 0.17494762956630439, 0.15143040945986286, 0.14882829127600417, 0.14829646825091913, 0.22814870841102675, 0.1673567501711659, 0.17405418766429648, 0.12241183416335844, 0.18060488771880046, 0.18225916457595304, 0.17129044455941767, 0.15041860984638333, 0.16831974615342915, 0.10197642681305297, 0.18266477796714753, 0.12304297139053233, 0.16070468758698553, 0.1360976681462489, 0.12166328175226226, 0.15504901763051748, 0.10531123771215789, 0.051789257922791876, 0.20839013974182308, 0.09103588614379987, 0.16669837612425908, 0.06273611797951162], [0.02747201931924792, 0.02420875331154093, 0.023132056594477035, 0.03584998528822325, 0.06495769994216971, 0.06656696554273367, 0.014329935602290789, 0.027383722299418878, 0.017650962035986595, 0.05532835981284734, 0.054970013807178475, 0.03228697140002623, 0.02268518535856856, 0.025719548902998213, 0.047744226540089585, 0.053114039765205234, 0.07806989829987288, 0.05298254603985697, 0.0261551302173757, 0.0308158918414847, 0.03260975739976857, 0.016009401879273355, 0.11186682851985097, 0.05513785050425213, 0.010450931004015729, 0.03677735818200745, 0.02097749056702014, 0.062208528906921856, 0.061312281686696224, 0.008609264641563641, 0.009155155075859511, 0.20650811260566115, 0.007474144204024924, 0.01563846533827018, 0.019354925680090673, 0.043977277891826816, 0.028014748204441275, 0.017100724471674766, 0.02896697562391637, 0.037003290199209005, 0.02433222998661222, 0.046798511466477066, 0.09749723903951235, 0.05793769167212304, 0.09315991279436275, 0.006881208564664121, 0.0675040457281284, 0.04382261060527526, 0.020394628190842923, 0.015087560768733965, 0.0769857838167809, 0.0069850058025622275, 0.04840759895159863, 0.06653001400991343, 0.07736911051324569, 0.04713128677394707, 0.004772571737703402, 0.019905222616216633, 0.03835904557490721, 0.03514275565976277, 0.019597476239141542, 0.03694825623824727, 0.05329667117621284, 0.032263426764984615, 0.0489861995447427, 0.03505395769025199, 0.01580800897500012, 0.04416914904140867, 0.02309751889697509, 0.03796939206949901, 0.042356475605629385, 0.004483869797695661, 0.02393547783867689, 0.04205574994557537, 0.009572023136570351, 0.0614198708353797, 0.05091875580546912, 0.018487073029973544, 0.03974735154770315, 0.06498221307992935, 0.04781402923981659, 0.0037436094953591237, 0.03550986642949283, 0.060124337032902986, 0.05827931337989867, 0.1070886071829591, 0.06944345572264865, 0.018253359594382346, 0.0515818536223378, 0.02553100071963854, 0.031096458915271796, 0.06233360676560551, 0.016303685697494075, 0.07411281883832999, 0.0014627569521508121, 0.016702981556591112, 0.04913653639960103, 0.031094184232642874, 0.02949757039459655, 0.04863138616201468, 0.03585673141060397, 0.016083566551969852, 0.03273120615631342, 0.06449128239182755, 0.06561885704286397, 0.03945623670006171, 0.01729299267026363, 0.005718166212318465, 0.03252138616517186, 0.043094400461995974, 0.031225076818373054, 0.022828204637335148, 0.031736757955513895, 0.055900800580275245, 0.018343870069656987, 0.030354563568835147, 0.056973300452227704, 0.011984184911852935, 0.017221726084244438, 0.0740480367676355, 0.0204875432245899, 0.015397653260151856, 0.010108201640832704, 0.009919797248585382, 0.019370019108464476, 0.025563285998941865, 0.010639584943419322, 0.027163501108589116, 0.056864924627006985, 0.051248473464511335, 0.03175473648298066, 0.034242385809193365, 0.017502308000985067, 0.023720969329588115, 0.015467058910871856, 0.07550919937784784, 0.05425229021057021, 0.03405210285563953, 0.0691031661699526, 0.017143871082225814, 0.13414494402240962, 0.006020660966896685, 0.08630034571979195, 0.010198445870628348, 0.03738762250577565, 0.03651714636362158, 0.017336721866740845, 0.020547002241073642, 0.06515692948596552, 0.06528650847030804, 0.055510508827865124, 0.03325411227706354, 0.059829214587807655, 0.05744191847043112, 0.020313602362875827, 0.03319941970403306, 0.042097239711438306, 0.02627305377245648, 0.019219613604946062, 0.036280594213167205, 0.04369179223431274, 0.04412472037074622, 0.054825762563268654, 0.0264984403111157, 0.07410544189042412, 0.0849362337612547, 0.02570094511611387, 0.036173249973217025, 0.007703561532252934, 0.043437688291305676, 0.060425493138609454, 0.02416074748907704, 0.049458543144282885, 0.022513292824442033, 0.03151749413518701, 0.04602761669957545, 0.072201016737381, 0.01760768183885375, 0.0280144105272484, 0.015437535348610254, 0.03538848817697726, 0.052969309836043976, 0.020715104255941696, 0.031027478144096676, 0.05484141074703075, 0.054925844888202846, 0.08186297054635361, 0.03874130728945602, 0.03622712247306481, 0.03270524583058432, 0.013460351892717881, 0.07653740045498125, 0.05589527529082261, 0.06643083339440636, 0.008110855887935031, 0.04490765277296305, 0.008843997602525633, 0.015246478706103517, 0.007687842380619259, 0.018562456680228934, 0.0654104100249242, 0.011191432040504878, 0.08427446067798883, 0.012455463529477129, 0.05366101744584739, 0.05552412352699321, 0.008324558239110047, 0.04791664228832815, 0.02033864613622427, 0.04827253178518731, 0.021091922317282297, 0.0330547343037324, 0.0135089050490933, 0.035986881848657504, 0.04886553004325833, 0.005236830102148815, 0.04871289995207917, 0.047015504314913414, 0.06560693072970025, 0.0471715594176203, 0.13290937204146758, 0.04538052700809203, 0.02320504681847524, 0.03543886145052966, 0.06695265969028696, 0.02089059620629996, 0.0762282068899367, 0.022423678492486943, 0.06395871721906587, 0.06978324061492458, 0.0347549092839472, 0.06651638075709343, 0.0568483895767713, 0.06101802384364419, 0.048332382284570485, 0.034558715124148875, 0.04875622282270342, 0.021895610734645743, 0.06127398315584287, 0.03580960132239852, 0.06223300122655928, 0.015183365539996885, 0.05526521046704147, 0.047072642264538445, 0.01387361497108941, 0.06712722024531104, 0.07611220178660005, 0.02171658430597745, 0.100911697227275, 0.019220752801629715, 0.004546957452475908, 0.06849637880804949, 0.041445656315772794, 0.02566981016570935, 0.0014901004556122643, 0.03809914916928392, 0.0534451415296644, 0.044864790033898316, 0.039315633111982606, 0.039681237321929075, 0.027549384503799956, 0.07867942418670282, 0.01077925342542585, 0.03523726816638373, 0.04489029393880628, 0.02663909770490136, 0.01833699963754043, 0.015653690497856587, 0.021456266731547657, 0.05977195418381598, 0.023541441951238085, 0.014311270588223124, 0.09696514884126373, 0.0504668695066357, 0.03884697798639536, 0.055317223886959255, 0.023754308458592277, 0.05532612594834063, 0.02439265008433722, 0.053668709806515835, 0.07516752200899646, 0.021010798154748045, 0.03191065799910575, 0.05734068952733651, 0.07836363292881288, 0.057112571885227226, 0.10055665377876721, 0.0015445426697624498, 0.023572498976136558, 0.009195460188493598, 0.03859372380247805, 0.012370846634439658, 0.007889657845225884, 0.04879629508650396, 0.00347536253684666, 0.036229011238901876, 0.026139277943002526, 0.032221358123933896, 0.02825046358339023, 0.03847728825348895, 0.06120182413724251, 0.03073720377869904, 0.03408322481845971, 0.018471536168362945, 0.012072786212229403, 0.026216292462777346, 0.040982185091706924, 0.01592609209183138, 0.01580722600920126, 0.02181720468797721, 0.04410049667058047, 0.09324194237706251, 0.014429322163778124, 0.024497341146343388, 0.02734804726060247, 0.02996135146531742, 0.05438856336695608, 0.04107309447135776, 0.04011228411400225, 0.03182933716743719, 0.031834187102504075, 0.013024370746279601, 0.05429615113826003, 0.010950387113553006, 0.07206064692582004, 0.08684333064593375, 0.07688806523219682, 0.0203143166800146, 0.041206799796782434, 0.0703602159046568, 0.07045118836686015, 0.05472910524986219, 0.011054377773689339, 0.02613002336147474, 0.02301750053447904, 0.06237841022084467, 0.031606544434907846, 0.02587995299109025, 0.013173454299248988, 0.01959917204658268, 0.035984944843221456, 0.09764914924744517, 0.0608490665035788, 0.01723517751088366, 0.03583044825063553, 0.029852498810214456, 0.01644937670789659, 0.017049130365194287, 0.03513012430630624, 0.018842613717424683, 0.14033855230081826, 0.04418672309839167, 0.23759534291457385, 0.16307914454955608, 0.11433339343057014, 0.11389748557121493, 0.14007618825417012, 0.12813687266316265, 0.08255523105617613, 0.14225664781406522, 0.10609584365738556, 0.1153612085909117, 0.2704870904562995, 0.17255452985409647, 0.1461784975253977, 0.12646775285247713, 0.13484964292729273, 0.15330413938499987, 0.12595518113812432, 0.1887696995981969, 0.06492289321613498, 0.13903075450798497, 0.0895660552487243, 0.10530170111451298, 0.2175859283306636, 0.20204489585012197, 0.14489812951069325, 0.13910624576965347, 0.1977723219897598, 0.1870859446353279, 0.13694604684133083, 0.10372005825047381, 0.15214266342809424, 0.2741808781865984, 0.16919669753406197, 0.14678837964311242, 0.12433197058271617, 0.14753702853340656, 0.1152856728003826, 0.1020855299429968, 0.18744183413218707, 0.10786863407702185, 0.08619575484772213, 0.11684488054015674, 0.15085061400895938, 0.1344125031027943, 0.22432853293139488, 0.09676103596575558, 0.07705851428909227, 0.15017218713182956, 0.17405436577973887, 0.12011074592010118, 0.25585579744074494, 0.14619227178627625, 0.2219931871513836, 0.1491581610753201, 0.15992339904187247, 0.1289942758739926, 0.16322588198818266, 0.16233116359217092, 0.14205663901520893, 0.16392915596952662, 0.0931088010838721, 0.10237929425784387, 0.14524061582051218, 0.1241475171991624, 0.17442557320464402, 0.13069400185486302, 0.3611951699713245, 0.14876608445774764, 0.08050428368733265, 0.2549217303749174, 0.15396031667478383, 0.11760547058656812, 0.11398104397812858, 0.1214315312972758, 0.10088333976455033, 0.186415814969223, 0.153410786006134, 0.11981095536611974, 0.09895873561617918, 0.20491696282988414, 0.1651670879800804, 0.1846145631861873, 0.11720102236722596, 0.139669610070996, 0.12592549523105845, 0.17180936905788258, 0.1388377367402427, 0.15044647007016465, 0.17333705036435276, 0.1360940613085404, 0.11801339205703698, 0.08770909043960273, 0.12207254651002586, 0.1912911463296041, 0.13430067629087716, 0.08219048773753457, 0.1381602746550925, 0.1413289483753033, 0.0784668508276809, 0.16707402159227058, 0.13206228468334302, 0.17040262813679874, 0.10048199372249655, 0.21873808291275054, 0.1926666873623617, 0.08249686114140786, 0.12275956003577448, 0.16157132311491296, 0.18922154878964648, 0.1834306149976328, 0.11235669793677516, 0.06509041078970768, 0.0791535378084518, 0.1789343132986687, 0.15234948514262214, 0.09040945413289592, 0.16138355975272134, 0.13637800700962543, 0.056579372176202014, 0.19695765164215118, 0.29530026367865503, 0.09728773817187175, 0.13008625712245703, 0.15525220282142982, 0.10023056151112542, 0.22559111908776686, 0.12155564065324143, 0.10448746121255681, 0.14261072647059336, 0.12596294400282204, 0.12344728602329269, 0.11071037690271623, 0.16985413647489622, 0.07031841072603129, 0.19509582576574758, 0.18041078641545027, 0.12642709800275043, 0.20969652745407075, 0.17694341309834272, 0.12199566001072526, 0.19416506867855787, 0.09570494497893378, 0.09804723726119846, 0.19028002949198708, 0.18257830291986465, 0.245912354439497, 0.12727618915960193, 0.09623662699596025, 0.22380157839506865, 0.23955455340910703, 0.1786537963198498, 0.10879959896556102, 0.20929547084961087, 0.14786220795940608, 0.11754254388506524, 0.12900417612399906, 0.12828015169361606, 0.11855112999910489, 0.09550727394525893, 0.19924986379919574, 0.2033925469731912, 0.17414668895071372, 0.12626216310309246, 0.0935323373414576, 0.1967301982222125, 0.20729441806906834, 0.10797024151543155, 0.08921794345951639, 0.08223137265304103, 0.11907677093404345, 0.23625638976227492, 0.07283046186785214, 0.1380659476853907, 0.09978277186746709, 0.19762317999266088, 0.12701631872914732], [0.08098247169982642, 0.02131623274181038, 0.061603422509506345, 0.047734081381349824, 0.029393918339337688, 0.027494196547195315, 0.04351451541879214, 0.021573947233264334, 0.04956786520779133, 0.026044605874631088, 0.033946472976822406, 0.06117943354183808, 0.03960268841183279, 0.01941626047482714, 0.006987888118601404, 0.03995196537289303, 0.040651639938005246, 0.008324795726366574, 0.012940111009811517, 0.013442300078168046, 0.02523589868360432, 0.041540424863342196, 0.032849263297975995, 0.026951575273415074, 0.03073855819820892, 0.06167907704366371, 0.06074392644222826, 0.05236640390648972, 0.034646377607714385, 0.07774981742841192, 0.010290822847309755, 0.05811989263747819, 0.03705113645992242, 0.06065160698199179, 0.04440570490260143, 0.10375797457527369, 0.0132213228243927, 0.05264922154310625, 0.006973765975999413, 0.054375972831621766, 0.08801689618849196, 0.09034067930770107, 0.01908529971842654, 0.04582511799526401, 0.027751562229241244, 0.05473136880027596, 0.03806628315942362, 0.05735599261242896, 0.023725407372694463, 0.034724425568128936, 0.032840576459420845, 0.06757005976396613, 0.02046252542641014, 0.042303471418563277, 0.007182921744970372, 0.030222340683394577, 0.009362404452986084, 0.039594008994754404, 0.018608154423418455, 0.0630070612533018, 0.02969381464936305, 0.030855869481456466, 0.015777785010868683, 0.03144933158182539, 0.020219670586811844, 0.008635906815470662, 0.03777352816541679, 0.0667035578226205, 0.030347079009516165, 0.05892221364774741, 0.018051176302833483, 0.028757584223058075, 0.062278413242893293, 0.034923002021969296, 0.0439308491331758, 0.06872757265227847, 0.04011402445030399, 0.0816750068042893, 0.03540521989634726, 0.007708535777055658, 0.05620635762170423, 0.029472020105458796, 0.05902494543988723, 0.02074441723380005, 0.012725832566502504, 0.014840727089904249, 0.023258258806890808, 0.052690125012304634, 0.03947126147977542, 0.0684646816807799, 0.020185461289656814, 0.012485842416936066, 0.03824982370133512, 0.0513290632807184, 0.016115825856104493, 0.03455445519648492, 0.12386639165924862, 0.019846307222906034, 0.06857442305772565, 0.05538945712032728, 0.0719763983215671, 0.004053169959661318, 0.023247057943081018, 0.049160415001097135, 0.014127945269137854, 0.04137207979511004, 0.042801059171324596, 0.006782907394153881, 0.017631920381973032, 0.02205747314292239, 0.028490737604442984, 0.03449589232332073, 0.0362523554940708, 0.025242112315027043, 0.03037083886738401, 0.03385499585419893, 0.02983390244480688, 0.02787717257888289, 0.038931642193347216, 0.0367084052413702, 0.05415620806161314, 0.04209208920656238, 0.05327833641786128, 0.034326215100008994, 0.038003697845852, 0.050535254704300314, 0.0423043508635601, 0.05090633967483882, 0.024512712880095933, 0.031052995036588982, 0.04133962938794866, 0.033679752523312345, 0.04836107371374965, 0.026252982388541568, 0.04933947668178007, 0.03729525109520182, 0.011669810228340793, 0.09486114533501677, 0.05439029628178105, 0.030648099673271645, 0.020115701263421215, 0.03694279774208553, 0.03279006217780989, 0.0594829730107449, 0.04105070387595333, 0.09482242006924935, 0.09141640010057017, 0.005760426884080516, 0.00921921169720008, 0.07852212598663755, 0.05325011625245679, 0.05345060373656452, 0.04777614260092378, 0.08889756572898477, 0.02926465847849613, 0.03861881952616386, 0.03393144077563193, 0.0245058591463021, 0.10399405917269178, 0.051454130007186905, 0.013107117429171922, 0.04227451281622052, 0.04862110741669312, 0.005450349235616159, 0.04363439824373927, 0.027820197901746724, 0.07385004661045969, 0.02480474428011803, 0.014891691298544174, 0.07898544135969132, 0.008282959934149403, 0.03499562859360594, 0.10687567759305239, 0.04270538891432807, 0.062474778096657246, 0.047207423704094253, 0.02203229578299215, 0.007716889112998615, 0.01488122145019588, 0.032154750369954854, 0.016405432288593147, 0.0344549554574769, 0.028679712522716727, 0.053109356813365594, 0.008419767436862458, 0.03734855585207697, 0.020364929296192713, 0.0653289444744587, 0.015722764037491288, 0.020822207297896966, 0.0530137013993226, 0.06624562302022241, 0.024839248580974527, 0.011458108892838936, 0.018594100001791958, 0.049332871567457914, 0.014145221539365593, 0.05219619604758918, 0.08306484160129912, 0.07499126935726963, 0.005591843400907237, 0.03932608255126979, 0.05155858729267493, 0.053566278584185056, 0.0567676290665986, 0.0674818480911199, 0.005056207128291135, 0.06101444669184275, 0.046498865631292574, 0.025574818973836955, 0.09286415210226551, 0.13384617021074519, 0.0307124030587147, 0.06960116952541284, 0.05690983198292088, 0.04774083863594569, 0.09124030329985544, 0.03142533423670102, 0.04763230695971288, 0.03645896940724924, 0.05641590301820543, 0.09997138869948685, 0.05364841577829793, 0.04607891765772365, 0.06862291498691775, 0.02564805039583007, 0.1454000291414559, 0.018298467330168933, 0.01614632627024548, 0.0358642048377078, 0.006758391009498155, 0.09840400991379283, 0.0376975025574211, 0.05984089970297646, 0.007373542839559377, 0.03297248207672965, 0.027389661336201243, 0.024542586179450154, 0.01571613294800045, 0.006994027071414166, 0.0234981487665209, 0.05287748390401248, 0.011362233617546735, 0.045095371606294066, 0.02768850750726415, 0.05709832264983561, 0.016724730194255244, 0.033425095680286177, 0.02925251694250619, 0.00636171493169968, 0.03983036076533608, 0.0420442577888025, 0.0715179143298883, 0.09790863376110792, 0.009995540840463946, 0.06250660138903186, 0.03365620788827073, 0.017314529795839917, 0.06686395819997415, 0.08502302793203853, 0.08796214795438573, 0.09436052219825797, 0.01542399579193443, 0.033386878785677254, 0.0786266871728003, 0.034437002905178815, 0.06584183531231247, 0.0460131967702182, 0.0734604116587434, 0.0561453456612071, 0.02475429864716716, 0.0947619424550794, 0.0469148950651288, 0.04144312930293381, 0.029825343626725953, 0.042954260716214776, 0.03599308249249589, 0.037993051737430505, 0.0256187188642798, 0.014064297756704036, 0.057088266548817046, 0.07285875995876268, 0.031913058846839704, 0.031001584611658473, 0.021909898932790384, 0.016832193177833688, 0.019285180496808607, 0.00693524387315847, 0.03401142945222091, 0.038081586244516075, 0.02202219700848218, 0.12232100270921364, 0.008312463087349897, 0.021563399459409993, 0.041066600679187104, 0.021504302239918616, 0.011425645498093218, 0.02846452309313463, 0.01502670373156434, 0.0548271244042553, 0.02941314367490122, 0.07745707727735862, 0.038071326052886434, 0.0007398160573757195, 0.01913963791594142, 0.02627109264722094, 0.01658094464801252, 0.021431636705528945, 0.013294214713823749, 0.04704667822807096, 0.0032708294202166144, 0.022943706935620867, 0.07328542807954364, 0.06049176321539562, 0.04617497012077365, 0.09597978452802636, 0.038391993221011944, 0.019186267054465134, 0.039796834244043566, 0.005557184640565538, 0.045448971577570774, 0.03988243726780638, 0.02306068425241392, 0.030747432429052424, 0.03536332194926217, 0.04025816066132393, 0.017627044471737463, 0.030759516448597424, 0.008562147540942533, 0.16603225405560806, 0.035363956485525705, 0.04985357722034678, 0.023055928941175807, 0.04315204678277951, 0.03628367783676367, 0.0467556561488891, 0.054220407546381466, 0.015384464368253248, 0.034361904981778935, 0.034128373372368515, 0.037194133474258706, 0.01023220987917739, 0.04616494741640054, 0.03292304761998821, 0.051900951148127206, 0.01825079547415953, 0.045580220394185744, 0.05278542419546284, 0.13884821586543694, 0.014579148792108754, 0.0921613308310043, 0.007426118436342222, 0.12253401393536478, 0.14192383910994977, 0.1936944728367962, 0.15515483304625377, 0.15481920418096706, 0.12957815313711762, 0.1422940520569682, 0.09756903440575115, 0.11655717215035111, 0.06523285861476324, 0.18610219820402563, 0.17100228345952928, 0.15339809528086334, 0.11265370543696918, 0.1374575647059828, 0.1930654581519775, 0.13472603081027046, 0.09444373921724036, 0.08381579114939086, 0.14883059193380177, 0.09472755875322036, 0.22486751026008278, 0.13842192623997107, 0.21575442660832778, 0.1240383843833115, 0.12852289335569367, 0.1501109599485062, 0.14140350453089923, 0.09035898066940717, 0.17125789396231994, 0.08444698774837889, 0.1829229563008994, 0.15667665138607845, 0.15350422239862382, 0.11323687023832463, 0.23867294134106487, 0.15045049251057208, 0.20827669504797086, 0.11343086021952331, 0.23903407040052116, 0.2570220676716417, 0.17652966576861218, 0.12088198578567244, 0.25720840611029416, 0.10892227597651072, 0.12515422567958012, 0.1607402364606969, 0.10294004619936459, 0.15092717396328226, 0.13383404351770878, 0.181026294012554, 0.09960018869605847, 0.1367091978318058, 0.10184131140704267, 0.26296212861780077, 0.14861045608995482, 0.10978805803461, 0.1795940232113935, 0.0517182529438287, 0.13015107630053535, 0.07815114120603539, 0.08525952813215554, 0.2137687659705989, 0.11047648164094426, 0.1307817385531962, 0.09359535310068168, 0.09673359876614995, 0.16249654378043488, 0.09878312121145427, 0.15956207702402025, 0.05439437067252584, 0.1730566966580227, 0.11439301015343517, 0.11645799153484404, 0.1316141165443696, 0.17642472608713433, 0.1681196186109446, 0.17525808478239924, 0.11333746093441732, 0.11508035764563829, 0.11559687758563086, 0.15269209019606933, 0.1856679082266055, 0.1513206012896262, 0.08902679590391926, 0.16050277889007702, 0.14384828740730882, 0.09878547381958924, 0.2008387426030822, 0.21813857601955533, 0.12334743747487664, 0.05109400284709409, 0.18139759049518034, 0.13064672704786062, 0.1296995091252029, 0.18219410791061819, 0.17970916000194848, 0.13065024482784793, 0.1717653893865645, 0.10566458906396292, 0.19156979309627786, 0.06358763595926575, 0.07912721383036114, 0.09947302911314182, 0.15232051169732586, 0.10671096533769742, 0.06802948628319427, 0.10875226478674449, 0.10873745151911862, 0.16331790830008686, 0.26168153795879334, 0.12490167282521725, 0.1261085830628872, 0.13182933937059715, 0.09497257880866528, 0.20445371425012127, 0.10520076160901226, 0.16581498290179297, 0.1611209730617702, 0.14575394452549517, 0.21080363367218524, 0.13949440384749323, 0.15015510289231315, 0.13520811509806663, 0.11088087048847228, 0.17561517655849457, 0.12563714117277414, 0.12162512051872909, 0.11994184795184992, 0.17129097890574485, 0.15971130807884037, 0.1839339840807952, 0.12614462175406516, 0.10539552342379466, 0.13162933057174087, 0.132549014815595, 0.15483719384064898, 0.18450091069098562, 0.24375499051529914, 0.13981177587993443, 0.16654592414852232, 0.1438567924196832, 0.13277131773065776, 0.07686942248255946, 0.11227861657971516, 0.07659377399249934, 0.1330691564362496, 0.09198631014442071, 0.0873547891387716, 0.12865296215750277, 0.1641253352863714, 0.2053001633612439, 0.11291209899354726, 0.2809707575943321, 0.138112272543367, 0.09715724634588696, 0.12447337940102443, 0.10378549341112375, 0.2531771786743775, 0.13278773403726518, 0.12676173239015043, 0.10084963141707703, 0.10150157104362734, 0.1606750610517338, 0.11903299164259806, 0.08757877672906034, 0.16009738814318553, 0.13211209763539955, 0.071538738993695, 0.15790615259902552, 0.07983715229784139, 0.16499698773259297, 0.30707595054991543, 0.10825489967828616, 0.20533854723908007, 0.10643581408658065], [0.05872128458577208, 0.06457861833041534, 0.03727133538632188, 0.05732064411859028, 0.06625566427828744, 0.034403736135573126, 0.05495960889675189, 0.053584409251925536, 0.0357595211971784, 0.05357245325285476, 0.09739824396092445, 0.05842881902935915, 0.020736197948281188, 0.04416668882186059, 0.0035895062410418177, 0.05862052690645214, 0.040486066791345365, 0.022330763458739966, 0.0239902520479518, 0.028962906799279153, 0.025818688700383063, 0.015612801871611737, 0.02423144076601602, 0.047008895489852875, 0.026182229739788454, 0.02718725911108777, 0.061668534835916944, 0.04356646575615741, 0.05121197835251223, 0.056716636099736206, 0.07309049557079561, 0.027226548409089446, 0.045472579295164905, 0.01411652176102507, 0.05160786218766589, 0.047928884014254436, 0.07504352397518232, 0.06301648652879521, 0.03492731389997061, 0.03226381268177647, 0.02449893861921737, 0.06972000963287428, 0.09237257574568503, 0.02739773775829235, 0.0578146027692128, 0.019095687930530403, 0.10400651241070591, 0.06260309542994946, 0.03655919645098038, 0.02209043192124227, 0.0563449982291786, 0.04620380997948814, 0.06837395412730984, 0.03737822320545092, 0.02270896191475913, 0.0344785928609781, 0.0163780655930168, 0.04517408007814083, 0.05531086368137039, 0.044664799788733944, 0.03413368343899492, 0.06678839272353798, 0.000805140417696748, 0.004343734226495144, 0.05789250230009202, 0.04047491973324213, 0.032169704645639285, 0.03461584936303552, 0.039560167060699314, 0.01639404032175662, 0.08077009129920043, 0.03288061161583755, 0.04198942791845184, 0.11936781898839399, 0.07375457673333585, 0.04517514506005682, 0.06128382774477359, 0.08508772836648859, 0.012464951887523057, 0.07294976952834986, 0.06954757162020542, 0.025144182218355127, 0.09453975828364491, 0.048530762069276534, 0.012411351199261844, 0.06966074914089404, 0.011484675924293697, 0.009472626370552462, 0.04314825440815184, 0.032611794595140964, 0.025826230776146986, 0.04333556877099909, 0.07231504772789776, 0.03798305129748769, 0.044917486229678616, 0.04658555961214006, 0.03981881665822584, 0.024014587070269044, 0.013567185906140367, 0.05833383525896352, 0.11747908283723518, 0.05392222745285835, 0.08976217519375496, 0.01435820679034805, 0.09395063403644599, 0.07423798946547322, 0.04852328493143432, 0.05237676057731733, 0.0387375705759041, 0.019824963055725675, 0.056687324977247044, 0.0016928555487538688, 0.020298933814046904, 0.029805673002556432, 0.03331017782329582, 0.0772002199664712, 0.05432282021502033, 0.03667835197120439, 0.04811978666111827, 0.02325306191778509, 0.06294285805779509, 0.07670467311982065, 0.00696596739544475, 0.05889787862543017, 0.019913662690669298, 0.07338835654081777, 0.023174240268417634, 0.026002615159086417, 0.06438750788220204, 0.031116424543142784, 0.023629802053619642, 0.024096191773423925, 0.042332455996074714, 0.05238751800789032, 0.05966329263173975, 0.04321920743677765, 0.08746174746192992, 0.012008140511170495, 0.04383845916891005, 0.019337412850291003, 0.029841672730981372, 0.02281994638906326, 0.011257627902523382, 0.047314712282968685, 0.05009469728975091, 0.038942703904467635, 0.01107243051592377, 0.009103973789024167, 0.04160152588156052, 0.038697457493981346, 0.03311245112854522, 0.04469035935471766, 0.05485702924488578, 0.06742549681803212, 0.022114922794571612, 0.0419611966208322, 0.03760048159165308, 0.04312350007239729, 0.009065501781151397, 0.0007301558457584179, 0.08556722998037003, 0.07674432607018389, 0.023156016832217574, 0.05991337042360101, 0.059468486288096756, 0.012588075114763342, 0.03480716761259828, 0.03438536798057612, 0.04103217986994423, 0.04194531837129034, 0.0529704119253438, 0.024523396095901262, 0.046701943210791796, 0.06646164736594073, 0.06922801025211811, 0.04964629537425935, 0.03536833515681792, 0.02261617119074799, 0.020481042010942474, 0.05235391727183014, 0.02279370961332461, 0.037089093602844514, 0.01320300661973306, 0.04369716167275328, 0.021865743001399096, 0.07461862216587178, 0.03660703900095541, 0.058691394588095136, 0.06375565819325857, 0.030270168390416075, 0.039941415743669495, 0.024389442151004914, 0.02497998018952785, 0.07175763545092195, 0.015020911268948112, 0.018457557816873305, 0.06202594573551323, 0.054761718929512426, 0.04577883395540994, 0.022932713873160537, 0.010768805841507856, 0.024386380791838747, 0.04035679950902704, 0.05031865890487097, 0.04513510619290173, 0.07319736483623274, 0.022331769068841822, 0.031003054064058233, 0.010205935068370309, 0.04496417474001646, 0.016773283350630663, 0.018890437713707797, 0.04984432634955738, 0.025798044007387944, 0.09090201754588634, 0.018218024088128004, 0.03072765604883898, 0.060501923217088915, 0.029016154039709363, 0.01998096991883358, 0.021032120057498105, 0.02206683533586329, 0.05157512234291062, 0.03568745494703762, 0.030507130577461794, 0.029451572081597988, 0.032981844269670546, 0.015460977010661736, 0.03904102362866979, 0.004290699889679672, 0.14509423461277038, 0.04256624364643358, 0.04477424059587065, 0.035981430773972534, 0.05321263408404775, 0.03763128072023392, 0.03633857450040523, 0.05447555420687422, 0.05847302505571861, 0.04736828792374581, 0.09695354165160097, 0.024290510154969525, 0.031087339775695, 0.0670949590858072, 0.059857468149857596, 0.040678101213416085, 0.026142628739762586, 0.053737150665256195, 0.038114084891276434, 0.04787751997355372, 0.04285340655769687, 0.012649561122088926, 0.10824696611962281, 0.03779046768613625, 0.016388093863497488, 0.006301922876446042, 0.05081970135506708, 0.020139602129347622, 0.06506346340756863, 0.016873159729584586, 0.06978110322961584, 0.04732703935587779, 0.008475695685774554, 0.01313738777753315, 0.02042509149760008, 0.02561551649705507, 0.02082769547996577, 0.04432822097442113, 0.035184041335014626, 0.013076482500764541, 0.023858012464188505, 0.08892342957551591, 0.06558867389685474, 0.04275356914149597, 0.023706441788817756, 0.034558084298623726, 0.14217689662473276, 0.07506236710469238, 0.035085818090010434, 0.0224909912867588, 0.08407821456785314, 0.029047780662949663, 0.013783273334411206, 0.059621261098072864, 0.08863391776685603, 0.07166218783822842, 0.03326083613501396, 0.06525769829750061, 0.0321859910764033, 0.02239905032183742, 0.06749088744982146, 0.01572873276018072, 0.008247580826719059, 0.04924700508126989, 0.04799509100848809, 0.05821511760586873, 0.026448799908393994, 0.030574035190511495, 0.02652436352946097, 0.03631396859418601, 0.03135660765110515, 0.001531157920453552, 0.007187809251263388, 0.08137564669596031, 0.05219362079515122, 0.05828809669765178, 0.03068587313464377, 0.014169632631819695, 0.08650540112284943, 0.05155433478648774, 0.03509477210172918, 0.011646747061604401, 0.05426542251370847, 0.03815594202023931, 0.059004577196901664, 0.01869590410933597, 0.02564144342613872, 0.03885846272169147, 0.04172809545707423, 0.026083481425303034, 0.059210946201346815, 0.013044084971625125, 0.012255008514330257, 0.03666065545985475, 0.07113190848031081, 0.020567917817970738, 0.020192992233205587, 0.02016776106756879, 0.07360040297498927, 0.006209917437445256, 0.10367438648245297, 0.025937662394426297, 0.04220377129968256, 0.05121684313053265, 0.0394522773422068, 0.044635444137384184, 0.04354942233476322, 0.040474500419804826, 0.045555607066489756, 0.03482257459836546, 0.03729295785888098, 0.0779153683106415, 0.03629176724643912, 0.03329337931063492, 0.031157036719378084, 0.07484148169169202, 0.12282811221666634, 0.06250487218494527, 0.07314798232982866, 0.03269853310484905, 0.04158605581324082, 0.09245850160368718, 0.17539900378324091, 0.11169753721333109, 0.09340263961348683, 0.13205906376242638, 0.16241621371591464, 0.14235467067919672, 0.11363586367224343, 0.11367267419700511, 0.16282261378364637, 0.15967960353009403, 0.15123666438739747, 0.2535736339632422, 0.16094310994958505, 0.09633834575652145, 0.12976897414773703, 0.11685760095133446, 0.08513448367011733, 0.1715470792260021, 0.09088183855055831, 0.09232924916432239, 0.17657201271504164, 0.14967570517910644, 0.15572493604850024, 0.09405300588696264, 0.1002955884905532, 0.10907675401540473, 0.1355351647362113, 0.0811320886714384, 0.16968396201264113, 0.10098881379235536, 0.1941692692344077, 0.1184306645882316, 0.1143532978312578, 0.117385594494408, 0.14057741995202377, 0.12662269844440743, 0.14979617058997974, 0.0830148282693699, 0.14229776279535145, 0.059161545141250826, 0.12071080942405388, 0.11818080572993495, 0.14235284499591216, 0.19062570703681558, 0.1883265929063782, 0.13963630248326808, 0.16434941935585812, 0.1743117129080929, 0.22168179682921618, 0.22959389258176088, 0.1205860692425631, 0.14079081709496677, 0.20136532606557012, 0.13303014915436506, 0.2637320919893682, 0.11707087192917243, 0.09547532448777929, 0.17575694160768762, 0.1290601637447253, 0.11584735242649913, 0.13637080817716196, 0.14866679994156584, 0.14472687151283026, 0.2206240879604593, 0.14471244416199625, 0.13370796747040004, 0.2090161561500281, 0.13088921637972817, 0.2394970814930275, 0.14213750342605636, 0.11474616854684427, 0.197480361093767, 0.17507830692920834, 0.18028301827143878, 0.1666770171141252, 0.1539055016473867, 0.17153832188341767, 0.18452982476446778, 0.12064426846336573, 0.11300291560473852, 0.18397610838292167, 0.0653451010293793, 0.1293972769053653, 0.10266006356687285, 0.20567156374454498, 0.20688034419436008, 0.07433242775732651, 0.09930105865350924, 0.23293801001273096, 0.13871405040845275, 0.07975536762387492, 0.0967849331209436, 0.15348782093496993, 0.2212124626385048, 0.09182776513625868, 0.15017889614682645, 0.3471591090783477, 0.12430169095750898, 0.06686776541755535, 0.11860986356623471, 0.27082144282758236, 0.26461702887900174, 0.1798524390324019, 0.06137460353784263, 0.2155058368225582, 0.1508149760775268, 0.10505884813028388, 0.15702862234320492, 0.1718229503603652, 0.1264863510732539, 0.1142094844544772, 0.11287518456811085, 0.12646177114220336, 0.10779351388919167, 0.1523534778971225, 0.20054709340911359, 0.16007647442165762, 0.11467936041299254, 0.09348584178951569, 0.26059512281790376, 0.1758945209439844, 0.15382686367956921, 0.11463705799542367, 0.18131142714992166, 0.15045567270135507, 0.24887288542231545, 0.1482630122336559, 0.16545216174563393, 0.14031659957254305, 0.1102073714719154, 0.13172413251595572, 0.19324652734212577, 0.26554916636087, 0.13559915270889178, 0.14054635365027934, 0.18646491545950994, 0.12639205378945917, 0.08984322514152154, 0.10496813541976735, 0.11448083590948954, 0.08433337236056104, 0.09708735087770037, 0.08395123310037889, 0.16697887826012447, 0.12450310241547413, 0.1098996250948403, 0.09916016191709787, 0.1046747867076192, 0.17097608564654365, 0.1446258058422245, 0.10239335053483956, 0.09579124933225103, 0.1753156605991535, 0.18790261878166348, 0.12567690544528887, 0.1103359337139409, 0.18748707545455545, 0.14113270968664438, 0.10132804949535057, 0.14007118617882952, 0.26883771177381277, 0.13905245490605012, 0.09292722723330371, 0.08757910327403806, 0.1647752191638574, 0.16596969100646675, 0.17139954026788473, 0.09262480205507018, 0.1792918355204165, 0.20238442841218784, 0.2761435619322583, 0.1557986906846054, 0.13947062543593347, 0.1643938888446428, 0.22717437241226435, 0.12892525614006445], [0.022717748943250626, 0.03523442574078217, 0.05234832518908661, 0.014369133987202076, 0.020030562081956305, 0.04190642983303405, 0.02844114544132026, 0.05374658707296476, 0.07977796602062881, 0.008755065118748462, 0.06590141492779367, 0.035006979742320254, 0.05994611397909466, 0.028163990391476545, 0.06391640738002025, 0.03794045573158655, 0.0280817363091046, 0.015684213176427875, 0.03179859741067048, 0.030932781955925748, 0.048698687824071385, 0.023166859609773383, 0.028229572126292624, 0.008982365470728837, 0.023785554731148295, 0.035809330438496545, 0.023289718446903862, 0.048655216523911804, 0.009140146066783927, 0.038044749744585715, 0.030128880171105266, 0.10470568231539801, 0.03857315517961979, 0.03634071188571397, 0.015602873791067395, 0.05798866237455513, 0.05263163264316972, 0.06295064318692312, 0.017109440996136982, 0.02350106355152093, 0.03933591229724698, 0.07702623086515814, 0.06378101737936959, 0.03055098779441323, 0.06364879634929821, 0.09220007836120203, 0.05321522046870086, 0.02808841749356361, 0.05587716688751243, 0.03145806294924114, 0.0578187402425101, 0.011247406673646765, 0.07431020043441094, 0.05402721908467356, 0.05625266763672698, 0.013544689554692013, 0.0910249246226158, 0.07891878907685168, 0.09698249283246696, 0.0677768443711102, 0.05126203250256367, 0.044168863314553164, 0.03351037586980965, 0.04082139137608465, 0.01887433867523214, 0.0032224054439211613, 0.034335614400333725, 0.03404780582059175, 0.0473371065891115, 0.004125451896470622, 0.05762416396464687, 0.08864804825861938, 0.033397599108866416, 0.04450428066775203, 0.05501321422343608, 0.04876985236478504, 0.08847929129842669, 0.13390019856160507, 0.02870613298000535, 0.030797970830462873, 0.04700660225353204, 0.028677599257207476, 0.08612906545749865, 0.032862054213183, 0.021371789916884154, 0.08616994295152836, 0.06214383589394856, 0.06990207330090925, 0.002665762217475276, 0.02431140346743632, 0.012256940881343326, 0.03028395749424817, 0.012036471071041888, 0.04487246013013646, 0.053192614650470205, 0.05223684347583912, 0.012505610447988147, 0.03278923839388881, 0.03187476031598635, 0.050285785473533906, 0.06699886580463499, 0.028010180285491515, 0.06206606994965114, 0.07643145887413993, 0.05939273898547981, 0.0376070718630217, 0.04036164202261716, 0.03352680701937061, 0.05811545459437184, 0.07078928858391009, 0.04898432562185917, 0.10888579199672677, 0.01179318114736816, 0.024081350675260182, 0.037540208068094216, 0.03529117406287696, 0.0104429918792448, 0.06686522727250122, 0.006021402186888736, 0.00878667875440442, 0.02139185759006068, 0.004430787221281207, 0.05470741969475057, 0.03668830788228661, 0.024928321145125665, 0.059279605993651785, 0.08628409268567339, 0.05388239267631434, 0.02458504259266192, 0.05498217389686033, 0.02580516491434537, 0.06786367564927787, 0.01800970137992408, 0.06400458194548264, 0.03192150448739994, 0.020569465195876546, 0.04091832699486986, 0.047073365858523175, 0.013034419425821397, 0.017037756952049676, 0.09902102407068014, 0.020699084998341277, 0.04406609441502951, 0.028154507599538192, 0.11944096506340429, 0.008454342241748236, 0.023863070200604852, 0.033607960867811926, 0.060852138994960114, 0.088793672475731, 0.07375698871328495, 0.06656742567429319, 0.04075064243806992, 0.04472583772439975, 0.07834904230549, 0.10048844298580661, 0.026669696453609504, 0.03392844620975666, 0.032477358254254796, 0.04978444616426714, 0.02159487579774577, 0.0731169679784216, 0.021913502059760503, 0.020737858503707685, 0.05266276573820505, 0.06796555768232793, 0.040006713606999256, 0.08339565392816439, 0.07577557844342664, 0.02906996160163544, 0.03979282293585129, 0.03840122924884781, 0.012565973029268207, 0.016933579827309586, 0.0078106701403157786, 0.06904406152898446, 0.03681079193484038, 0.030841419866192155, 0.09875673044007272, 0.01418586989530013, 0.06741741482983343, 0.05886020720936358, 0.017673467664280906, 0.004292981066100765, 0.06343815999571234, 0.025718990436871536, 0.06849136931123212, 0.04324432542489376, 0.028736342101183254, 0.05623471879516728, 0.03200154511432629, 0.023380438578897156, 0.042515896348049864, 0.01392947364365682, 0.03861018834868446, 0.035509365479811095, 0.0368695922952611, 0.025399445767106954, 0.0367065238970099, 0.05742774716054555, 0.012027694247080944, 0.010548099471634487, 0.010507212700758828, 0.00130733047171816, 0.04064518325321842, 0.05783301174233202, 0.03931790779461153, 0.07281842423253693, 0.05842460734129418, 0.01805015213903971, 0.005769466242782073, 0.054130492644617334, 0.027821001276606694, 0.022131164696475025, 0.03164596731949132, 0.05834581723320298, 0.03307786704681348, 0.026973253407049924, 0.06990208072238602, 0.07771118864184245, 0.03441755863605067, 0.0741334653866943, 0.05362718293326907, 0.045947939725010656, 0.10882501752348617, 0.05341380434401799, 0.052389473567018285, 0.021014883677707985, 0.06501333133201115, 0.027846208322444, 0.04725456121377647, 0.04637006961274892, 0.06096413650084287, 0.04287560048396699, 0.025465986727795098, 0.06982515711570159, 0.03733083336555865, 0.07824457759852521, 0.023115727490221616, 0.03792759060161188, 0.007981760227266932, 0.030651988527097274, 0.07523633394157514, 0.04793481377419084, 0.06958712809137069, 0.034989661726285703, 0.07568565240944736, 0.0103300750379276, 0.0020177513351882226, 0.043218992213951424, 0.042061950589413755, 0.05753060140705202, 0.0769870677322615, 0.05402979062637314, 0.0539215298340423, 0.08538419409887865, 0.052426677430048585, 0.007212434638859122, 0.0365782473818399, 0.08733123337151483, 0.01432911181836971, 0.01619987036974635, 0.06884086149511859, 0.05683849303750321, 0.03485318819002714, 0.019696215276781004, 0.005704642890123068, 0.08872221107594669, 0.02713803987717256, 0.0554097251733765, 0.03868398751365021, 0.01941558140970301, 0.024534645199310035, 0.027955717778240796, 0.02962057766126236, 0.02239265486423392, 0.05491122086823452, 0.025745995335455518, 0.03340037103043869, 0.008750153028813656, 0.03646714787464589, 0.023296603721973952, 0.04065587017976213, 0.015121882315725088, 0.055087744403863326, 0.04110624620807357, 0.05365618235373404, 0.09031518653500825, 0.05744249363488052, 0.012857103647547774, 0.020240944249962922, 0.044021810463164, 0.06604375143069774, 0.04206352765322663, 0.0425877733505331, 0.036030490446137264, 0.023664471482334193, 0.007083300015437999, 0.06851112528238446, 0.03667764693091158, 0.03893072564096656, 0.03948008190491237, 0.04085856555320788, 0.020331935265858192, 0.09475149301579222, 0.05691238126019016, 0.0441024819156155, 0.02662413229700178, 0.028819657454732805, 0.044009019547956996, 0.03683103030198254, 0.024775145575404167, 0.044607409508898854, 0.09998010893468745, 0.03023026125447359, 0.04293663099815603, 0.07773737161187455, 0.04732821194920689, 0.06117100274423137, 0.02606740836199606, 0.04041826046886854, 0.03592032604501583, 0.029959497951494996, 0.027282927512715105, 0.02808860117511358, 0.07057633672957309, 0.06916135796927847, 0.00771731955865107, 0.042028876778203994, 0.06308019248535857, 0.02510126567358384, 0.02723551355302334, 0.014272012831497705, 0.026743901944428217, 0.004423901482368819, 0.013601479622593615, 0.008517785663570976, 0.014582822423108155, 0.04819022389710881, 0.017563472101755906, 0.06264088558964431, 0.03264190352638252, 0.0987723600701429, 0.08020358029170893, 0.036105406543356366, 0.06185493264638353, 0.03185891175235156, 0.022059885122871492, 0.05370955761463847, 0.013338194385141833, 0.06420921432436444, 0.053579989762511104, 0.12188509484985843, 0.13449114107061177, 0.13996848778333515, 0.13592361967312172, 0.11937662828131579, 0.1282667781924829, 0.0731145782629028, 0.09327496052719653, 0.18126179231330752, 0.1684094124357216, 0.1675510741188191, 0.15895546035608277, 0.09674484972492792, 0.1556796205113642, 0.14761412283405662, 0.1551639020908624, 0.13805321243125945, 0.1709456427488476, 0.16950229910435155, 0.10643470828654245, 0.20336912479251623, 0.08482513425406069, 0.1329569733934477, 0.1598593220114708, 0.1558247400680557, 0.16598824469838291, 0.1588355886633508, 0.16289215302094817, 0.1158086716895923, 0.15365521976491436, 0.20525683677988127, 0.22936556342756376, 0.19222634145990014, 0.1616139817633666, 0.1357276481576264, 0.14105917769484222, 0.12877050350653008, 0.10603188537061214, 0.10193335998337716, 0.1983291405485943, 0.1268995343707502, 0.13757730281213298, 0.16934876359300688, 0.1893385557923466, 0.13589293928816915, 0.19730552594410256, 0.16348159639164805, 0.1338443742133677, 0.17122865334386006, 0.13741624192334712, 0.14634303166531026, 0.08148696142598055, 0.17920283717103302, 0.10945893780444749, 0.12372406257782131, 0.183504621963948, 0.21087088709464297, 0.21076158358482644, 0.2326458116294816, 0.19295321573736146, 0.12538861075881869, 0.15317009267164394, 0.13988740072818473, 0.1087173838459421, 0.11050546250771731, 0.11544477441930212, 0.13548201211960986, 0.1902783670811914, 0.19760946510359645, 0.14067030715523288, 0.12384544825181365, 0.18263688805745915, 0.10280238522682339, 0.14956712897401303, 0.11456657623057254, 0.13330407586181536, 0.1940338421263732, 0.19082118873484433, 0.10357776627643034, 0.19041418010601774, 0.19609043723903596, 0.10189482767600566, 0.20651571219787002, 0.17736593261361122, 0.11189591328729875, 0.16060825291788206, 0.32999433169607073, 0.10912126803305, 0.1401446884847246, 0.14517734030960128, 0.05477969374624081, 0.15638605604181066, 0.11032680529751815, 0.1297412475105375, 0.14007602498168126, 0.22948985832044855, 0.09577301476383582, 0.09767340263351798, 0.08671575546031818, 0.11939378673559986, 0.1855326592340134, 0.11960153613472357, 0.24053628119872883, 0.2349305132520385, 0.12597803928656504, 0.15905523468973115, 0.16911316139157861, 0.10322779911803082, 0.22621769952820614, 0.24252241681097075, 0.17374443006701767, 0.16056795429904014, 0.1478860605857335, 0.05237708712229505, 0.12804704310838133, 0.14682795095723122, 0.2099436626303941, 0.196027577330824, 0.12570185645017773, 0.09443788367207162, 0.10625165756209753, 0.12160935730207711, 0.16491134389070794, 0.22403841256164014, 0.1559548088698648, 0.16461421764688566, 0.18205443571787328, 0.14246320235542953, 0.15130537241930142, 0.15818816871615127, 0.09560623933793977, 0.16621311544440687, 0.17785799136618152, 0.1128025579964742, 0.12984899251023307, 0.11649568521534093, 0.10666985035641119, 0.2287474286276847, 0.09665392921306193, 0.09529848553938791, 0.21176849986659363, 0.1082575491454918, 0.11231605050852522, 0.0809001897869166, 0.1645432980149053, 0.17248742486117408, 0.05877925003005657, 0.1820735089131631, 0.14462101156823337, 0.1726193935610354, 0.1417157705873251, 0.09528677444905043, 0.1582028335542418, 0.1632676797453314, 0.17109695181716233, 0.170283765764907, 0.12271710918867029, 0.09107534613576718, 0.15424663724843413, 0.1419645978603512, 0.06286492513027042, 0.12826818827306852, 0.14302647759905085, 0.12352551580988802, 0.16997771890601143, 0.19250616081990302, 0.25284891191404313, 0.14686116948723793, 0.08951164098107256, 0.1830639792024158, 0.13279448758112267, 0.09425127806025557, 0.11370208550943062, 0.13040762190939859, 0.07777887250995263, 0.12746007851092145], [0.07225776877021417, 0.012841318166465499, 0.01771540271874983, 0.021178002170927357, 0.08196825903723948, 0.0362163464887999, 0.05800601378723513, 0.022968834200582933, 0.0579745281720534, 0.016368222859455273, 0.06513128828373738, 0.00971656474575866, 0.043781673739431426, 0.02505982785805827, 0.0708907401713077, 0.037332221181713976, 0.0590547649335349, 0.03465228510322049, 0.006029728156136116, 0.08510056009981781, 0.05988384407828562, 0.023747764571453445, 0.13002277381019667, 0.06989976522163488, 0.0428628726513125, 0.05424314324045554, 0.05499965889612213, 0.058011605869978666, 0.03088937373831868, 0.03780675782763865, 0.03952805433073081, 0.019253277423558757, 0.07545652173575945, 0.03191404219251126, 0.04422984187840484, 0.010050866094388766, 0.01796988886781037, 0.018170558178098872, 0.08372996919206344, 0.03373762148839887, 0.014939799166313605, 0.07111829749192111, 0.061570337566081434, 0.05681060683855321, 0.027609170065261424, 0.03478054306469858, 0.02535204665036872, 0.038958114600973204, 0.04023654189950321, 0.07017781084869057, 0.04005747279734351, 0.052354485014802776, 0.011773340756917605, 0.03771328803850338, 0.0932596500206273, 0.025671561634226236, 0.050780779420165345, 0.057946089073084295, 0.0038487704296130687, 0.04672421135182958, 0.06873644873849116, 0.06379908125381917, 0.05170548058231361, 0.025739290031197015, 0.061787449158146046, 0.04165604404988699, 0.02206751440098742, 0.0354973463981878, 0.060452908073784783, 0.05105623495182954, 0.04375501208414789, 0.047765845301910304, 0.019000728279934265, 0.032787880263640545, 0.015728857069916558, 0.020549967121041846, 0.04556292464258149, 0.03492102048767265, 0.0360167829785496, 0.04555300583888311, 0.020053756052220706, 0.05304815560521092, 0.05523045198060572, 0.021515247062779963, 0.10717674464103766, 0.02432970668451162, 0.02657959601492621, 0.054557735929847695, 0.019306266767671332, 0.04572739198920317, 0.046630815777461976, 0.00947182763411547, 0.036067397450096905, 0.037359877314884216, 0.01413830379533465, 0.047969405277399346, 0.025873854392557405, 0.12578497698996216, 0.02117898180586053, 0.034967675601365045, 0.07316208313568495, 0.07103444964741357, 0.04780008799571078, 0.04274679333320819, 0.06697264572721906, 0.03465177673206199, 0.08747267929720692, 0.029615876155730803, 0.03682487047626637, 0.015526865809079027, 0.05384867690736428, 0.053008717877673917, 0.03539025448844768, 0.05657558351231273, 0.06277099892031401, 0.022576883748115506, 0.052698207000503317, 0.05544786043174099, 0.02054711356322514, 0.029065028174954932, 0.06443100515753031, 0.01923571078805253, 0.02361079565162072, 0.09410232902155258, 0.029461863814503886, 0.07244510168675333, 0.09015252260724083, 0.03435206781432498, 0.012488764623412862, 0.04391899332404137, 0.042832581893890165, 0.032612714858260006, 0.03712824189278763, 0.055102053011069074, 0.03929410711862147, 0.04424317827215418, 0.028520551531983074, 0.04285557733965106, 0.0268935838539619, 0.0363501779793296, 0.07495425845263526, 0.039348636419163086, 0.007977096756803803, 0.08686209956067614, 0.09561457365634851, 0.017044308260665275, 0.009765012146090157, 0.02151612836314598, 0.03498372083413415, 0.05149297401658259, 0.012819895146094495, 0.014910748723195866, 0.04519444461038802, 0.026180313143413514, 0.023823908923077397, 0.04519755791989155, 0.03825989093456883, 0.053865816807956435, 0.03486682144284714, 0.02972592552396236, 0.0365850640082499, 0.04192997075733729, 0.010746627685875865, 0.018859564370359294, 0.01851331166108139, 0.01407702930009691, 0.04397755990794394, 0.008148317647282965, 0.08532454026862979, 0.029459511206368916, 0.01747365553455893, 0.019667492306325585, 0.010818705995916389, 0.008377381527679972, 0.0387500534998253, 0.1001751676085405, 0.05051727988757193, 0.04460345386178233, 0.03483820051769726, 0.008385059045394883, 0.04729482272523455, 0.020836150397371966, 0.04776342961122282, 0.05580468503467273, 0.07891609508078545, 0.024551779533794615, 0.023253275285242125, 0.08529408994945697, 0.06562762922840193, 0.008960442428360693, 0.062163588154362515, 0.023958079946169164, 0.051724509248742834, 0.019612170763139147, 0.03978924207331147, 0.03471598734904546, 0.0699822697788477, 0.03086617791268509, 0.10082747830892913, 0.10795234091347083, 0.031916398511384614, 0.03767685229831841, 0.04177100272499956, 0.014001096460560802, 0.041902207012753934, 0.030712378938915208, 0.04069072885613423, 0.0073207455261581345, 0.07670348568353802, 0.03606780192058068, 0.011798773230111692, 0.04958579178492073, 0.020324972065282054, 0.10730821610195562, 0.02973755126731703, 0.03274828668509144, 0.029988356363901403, 0.05326125959982164, 0.05854556628037244, 0.01683880571363261, 0.03905755867890548, 0.01613504377019126, 0.04670386166253593, 0.034088783504557796, 0.014225397608242929, 0.03746926617168356, 0.03017585626366781, 0.019516656357154716, 0.010729740115493769, 0.026174576341873035, 0.036491646169452, 0.06371263589244336, 0.026625481150404084, 0.027296839070913848, 0.017457157591707073, 0.03955560656322632, 0.03310308151412755, 0.056740689105936326, 0.019558097883418668, 0.04189917162875645, 0.07718761087744497, 0.021424076076073106, 0.07184441477875225, 0.03723934882145841, 0.019185881137673277, 0.026281861210009083, 0.039413978811353445, 0.046320200999616645, 0.012918067368445918, 0.014785830426262692, 0.04490426115808077, 0.0491432045964757, 0.06590527409571223, 0.024744333459238987, 0.03789489528571721, 0.07971953673404641, 0.027015314626623876, 0.028566008077177685, 0.01323167392911273, 0.027301436675770674, 0.028520276937342715, 0.018419730549794622, 0.04946464359818492, 0.03986416559200734, 0.02269281649205368, 0.07220892803161405, 0.03986252915638033, 0.025979755155276507, 0.017921202124853153, 0.06445896928198636, 0.05400711059337482, 0.004571433482851717, 0.05284901511913631, 0.04359680104244035, 0.007123350478650536, 0.04364254702522885, 0.04529316880507395, 0.09392364212544635, 0.05884772428544238, 0.028032320406055078, 0.021581635883194394, 0.0323514046613127, 0.05715769075322896, 0.029999675971339457, 0.0776167206640821, 0.02024208901275415, 0.017039029735315125, 0.03275863593444228, 0.010750910805654712, 0.04753559027449228, 0.043455462728161365, 0.040517281522625126, 0.08076321901171468, 0.040196362024289556, 0.011058864984079264, 0.08785526384599507, 0.039557024065288715, 0.07327746483497322, 0.07809187329257838, 0.054957237734925, 0.010223805984423961, 0.02806302120006876, 0.04044341927510686, 0.008967606008809526, 0.02046808040176984, 0.0645999179687351, 0.03075246419030009, 0.05311478933435865, 0.029652490011358168, 0.036421446420717984, 0.012369383675832069, 0.025836452005023602, 0.016061790083767846, 0.02403563994448632, 0.032542804547119886, 0.048113712182384916, 0.016878256428753957, 0.046954006247688085, 0.02503292686014902, 0.006272534756135428, 0.04076211233041249, 0.04563079775834922, 0.01596553538547596, 0.018945000410894863, 0.05893583576835226, 0.0795030003064312, 0.01373003166008857, 0.03196280129486695, 0.07452390185790136, 0.05519803497008979, 0.021437020986923017, 0.026097871668753214, 0.024485079011355992, 0.0225960515672341, 0.018321147363167256, 0.008549445683456725, 0.01637943114474183, 0.018211268688901328, 0.03911756502930075, 0.06634860343183391, 0.0426477945438819, 0.011440472680988023, 0.01882149404991651, 0.04066855719429441, 0.04041657579364255, 0.02781783972750418, 0.036780901937163435, 0.025844639749266207, 0.03633262247603852, 0.04617346727172844, 0.01095715642804862, 0.06841886148322374, 0.188678489648737, 0.13763885654043406, 0.1958547905087471, 0.19266345159849152, 0.13295321812620386, 0.08690555972862057, 0.11211349614313804, 0.118389720300911, 0.1519334816839546, 0.16666776995407417, 0.08258512476459146, 0.11937423856579699, 0.13471020822180435, 0.11151584461913444, 0.15345124789746478, 0.1343117342912592, 0.1258437699289061, 0.13462233793688938, 0.04504897253355011, 0.19591230695368722, 0.11814851488452405, 0.057365462416782975, 0.18695759761612862, 0.20048001810209826, 0.15922290069283918, 0.16692278673872352, 0.23287467513000593, 0.14609953301260248, 0.13942743244115263, 0.14985889691160992, 0.09803558554267511, 0.12012607126962394, 0.18074650433845818, 0.167450305307284, 0.11483153779408894, 0.07340052034123801, 0.04877151477558073, 0.1480490659014322, 0.26396376080811024, 0.19788046774920076, 0.10471718560438603, 0.16144207067554817, 0.20169997529592365, 0.15430979401571676, 0.15726789075415581, 0.14124326000455767, 0.1303898252081126, 0.10227687045698985, 0.18233394337585196, 0.1256543886847794, 0.07859726843889803, 0.2270963875344023, 0.1726621709531173, 0.11149172481964342, 0.12332213023910299, 0.14433973759878427, 0.12913382932310924, 0.07001131743891165, 0.1051533012650907, 0.13518261490389705, 0.13309942121850327, 0.20181441446766257, 0.19912602903787047, 0.10408290909253992, 0.2033037118962966, 0.1446233270689845, 0.14684896857943386, 0.12990970019018278, 0.19004963716724887, 0.13889283378375694, 0.12985397974262014, 0.1653738206368871, 0.09033550653839484, 0.1132326696824748, 0.15641773090464994, 0.1786993196583353, 0.16967671865131706, 0.13145514851203188, 0.18793889496009797, 0.1313504611607641, 0.12017979533993639, 0.12866143748397008, 0.19146517995977774, 0.07256849858094938, 0.13519916479708627, 0.11898532349732704, 0.15774230123497546, 0.10896562482230365, 0.07013841765001416, 0.11013344614184462, 0.09937951108440757, 0.06583002032130025, 0.10904606620897539, 0.10983755928464234, 0.12210908244014718, 0.13528262672480196, 0.1525840483373031, 0.14940755238058046, 0.10647116258041933, 0.15302970801712945, 0.13559441780671477, 0.20017576724058017, 0.15105845988728106, 0.168327345745638, 0.16523633035831153, 0.11337759628077038, 0.22268420085310936, 0.12993816897505894, 0.11838415419333614, 0.09396414854563773, 0.16169128386536613, 0.1597430868423544, 0.10287220648024231, 0.11323028738843277, 0.27039179869461805, 0.1425171416485682, 0.1382522119092755, 0.0836345215793699, 0.11507207527756691, 0.11135686916531995, 0.08801783129456453, 0.13144884025678039, 0.09899501179461367, 0.2037603108328767, 0.06507343787234277, 0.1732864952646196, 0.1539571551256813, 0.08670668641570956, 0.12536505499156192, 0.0806892046239227, 0.1364305807510391, 0.12146226363256574, 0.11686278114211746, 0.14968189469072968, 0.15145772049436346, 0.0863577434211038, 0.07791369847836904, 0.14659194799605757, 0.26665814279112965, 0.11414765613153577, 0.1323576594586484, 0.1534147045458667, 0.08490751264616847, 0.22153920057462528, 0.17610212933504954, 0.0532988048507832, 0.108337753044907, 0.14442557439906523, 0.15265030728187412, 0.18069781945087016, 0.15624758612830192, 0.13000793085666373, 0.11174389917869121, 0.16365148883778602, 0.09046034319908358, 0.14498122036457062, 0.08278505192720331, 0.1284257462248206, 0.1196511487069074, 0.09507679860689677, 0.1058003946673125, 0.10848863166756928, 0.17712883127387613, 0.30178927641827613, 0.0808825934655033, 0.06247540150070563, 0.15165192569838837, 0.09200037384289317, 0.19580622436478734, 0.11534345641848631, 0.10755705821793526, 0.10434600044391118, 0.19760829251026735, 0.09630152038880624, 0.10256633773678914, 0.20844868035055697], [0.13302240113262087, 0.03641815128503367, 0.01152613043814199, 0.01490141250542365, 0.047817728845984675, 0.049020078586181626, 0.02019755273067858, 0.03488992078928277, 0.013859788759873481, 0.04206844067084603, 0.032384612059104256, 0.02409464625088731, 0.05497324214957189, 0.02978918990265811, 0.02499674716091249, 0.026477354040252976, 0.027343889378244057, 0.008074740198935615, 0.04437239360413514, 0.05236730932665523, 0.07411417696857825, 0.04130990266276058, 0.05958336703770328, 0.010336439881939441, 0.022546171821886674, 0.04715940674941521, 0.01272609695661231, 0.024949492762971204, 0.030834708995826077, 0.051620356243802235, 0.08054343197727576, 0.034030625101877376, 0.03380222915438935, 0.05107754943310283, 0.050402963170199655, 0.036765661934623495, 0.03220785474695731, 0.01925392494740663, 0.030436671077040955, 0.038230208738241345, 0.08281301605165936, 0.019769270438700914, 0.03274942217103671, 0.018932220627903007, 0.05052914311818313, 0.021761001844424754, 0.021725597689510323, 0.03376154832949396, 0.035539363088901155, 0.0728937893291004, 0.005149567914486397, 0.0575666586519219, 0.016732099720684346, 0.03490641131065786, 0.046178050033631735, 0.03279242962889839, 0.04205272940453142, 0.0530743645504117, 0.10195873401244171, 0.050208427710458636, 0.03183286979037803, 0.03129035983874928, 0.09688257006928325, 0.041073291140492074, 0.048836545465746894, 0.05198287311941385, 0.04084445732587483, 0.026678123540477827, 0.04588408162817359, 0.03189802293491084, 0.02792160496028373, 0.011393512359063607, 0.028814929974032566, 0.011280761573289055, 0.07683478645049036, 0.0399145685514668, 0.0471629282401409, 0.05811614108097274, 0.051334633099031635, 0.03432009609241504, 0.05071262057754211, 0.07104797157808207, 0.01719253556075273, 0.01824041839427082, 0.05274060218653176, 0.02467611338943243, 0.04661337530706078, 0.05312842258717865, 0.03703816000779625, 0.04171734915871639, 0.054750148847233504, 0.08967641260824166, 0.02850652308552526, 0.014372204623214202, 0.031395904370583594, 0.019305123860249296, 0.0307423913909588, 0.042205055215163156, 0.04170095511653926, 0.03227851091651246, 0.015517001738771796, 0.02300085045135347, 0.031835151894483715, 0.05247536602837499, 0.0302540730626788, 0.015346489599323831, 0.0341097862838069, 0.02874443893233547, 0.0247521872370271, 0.036921676219208166, 0.07455266750184819, 0.020988765645597596, 0.10995126373018138, 0.0655580751481466, 0.035362179041840136, 0.03748540417291224, 0.055909877046360634, 0.10024748247815296, 0.019418236443016212, 0.030994918270152994, 0.03134359409159515, 0.023259943482116796, 0.03865006765408907, 0.03465189176495187, 0.10656004960765131, 0.0026021910070994636, 0.0358524084003875, 0.02732850465690717, 0.08452290203422308, 0.04489160382945556, 0.022374670770659577, 0.020005098995170556, 0.08842423136229627, 0.006520704764625407, 0.04910308409307618, 0.03873446839861572, 0.029863009476684965, 0.053139803421800025, 0.09608184467651881, 0.04273650345567148, 0.021187271595408674, 0.0455795005109394, 0.03959656569350045, 0.03986008377978578, 0.05532385126571171, 0.06126573418441694, 0.0168968156867777, 0.0022945125829210156, 0.009526317971904064, 0.038657440891256556, 0.03873890273098368, 0.01186692465125816, 0.03693977720104158, 0.07485154521418735, 0.02421818415314192, 0.026140964473597705, 0.029147345339879394, 0.023507438600063324, 0.053574701960315, 0.05303982499754056, 0.05186768437852152, 0.04497381152759772, 0.036738833296112716, 0.009360112144349841, 0.03726229231688194, 0.056070689315674827, 0.043616961484076455, 0.003647025005193427, 0.045985911710886285, 0.03082436160184443, 0.08028654498048127, 0.03249912173487246, 0.02304267603904009, 0.09709224905236624, 0.06938099657418206, 0.028916637602378614, 0.06804673379519954, 0.059633209675666876, 0.03379006164323073, 0.0630974696832709, 0.03663922965642996, 0.012263936550880317, 0.01075765692803543, 0.044398713871487416, 0.044182314741192386, 0.037508176974370144, 0.014838263159617782, 0.030168611046974547, 0.013681868131243391, 0.031055112012836616, 0.023653689931961708, 0.05788163354736753, 0.04487677571887616, 0.06340801395708695, 0.0031916698617351358, 0.042724272861960344, 0.03657785775430966, 0.026214719109702855, 0.015021764738776255, 0.0257637048343895, 0.0545760818204144, 0.04030888645502273, 0.07875548690208234, 0.021068501991976518, 0.016745666180213448, 0.014571399842679966, 0.011310860300000058, 0.011997085293842247, 0.1058797154109925, 0.024171588411263656, 0.08741612764424644, 0.04198795104457531, 0.045945126985316165, 0.027027565629396122, 0.03415015169593971, 0.03057408714084886, 0.013775361112493556, 0.06319605658063665, 0.025009866476466414, 0.028913667156302836, 0.05978620712994598, 0.03723715206433553, 0.03374164763954468, 0.030156400862324517, 0.01534455352157238, 0.05027565515774768, 0.020151795615674928, 0.026539139689703006, 0.08421972728683613, 0.046648831412312575, 0.015049830908537842, 0.015551327924185898, 0.09929400082910433, 0.03957259061280638, 0.04498652822803706, 0.07371631902060471, 0.009241890802513808, 0.02551400553784333, 0.07252186944242567, 0.05530542373890057, 0.06646143956459127, 0.05336818452633452, 0.03737917315447703, 0.05184475572605152, 0.09051878732861951, 0.025337981096527074, 0.0291795898010605, 0.09046088496688753, 0.009285690503020305, 0.0065631774123176, 0.03994044353021309, 0.023836666441638954, 0.10017625114414841, 0.030206629417079967, 0.0012577548909575853, 0.06970030561205931, 0.022433972080762032, 0.036894064614898525, 0.04016361104731914, 0.027634096950350795, 0.03819947269221302, 0.029053682592348196, 0.02778038353426382, 0.0259189825374051, 0.029762732337985653, 0.06312372686807066, 0.0033027343488356564, 0.062378321163123474, 0.041484619068796746, 0.03925448014342692, 0.02340516322874464, 0.033146200294140726, 0.019611823809100315, 0.097969964845106, 0.05856993098859675, 0.027204502912354656, 0.03355191016453318, 0.01745133544318378, 0.011974690060014836, 0.015526343522651587, 0.00921888422453776, 0.027801059768535197, 0.015036515851534205, 0.07629941595951095, 0.03660744347143918, 0.028453261002141517, 0.01604336626769509, 0.030318812459881883, 0.03594162939407397, 0.03949489146179985, 0.011238951756240567, 0.019546583462215494, 0.06626871865591966, 0.06255663698539138, 0.03507133878883906, 0.06190825966768898, 0.05177621096663643, 0.03956304288294632, 0.04194398992694914, 0.05497362064488698, 0.0263112706670654, 0.05280434153974056, 0.023064797605911735, 0.03479071048786864, 0.011740397749235854, 0.032003604574128985, 0.02944682419183664, 0.033180168393300846, 0.020721516411867924, 0.03471227661066223, 0.04659004960558377, 0.05472097502206452, 0.020375614367367234, 0.012977919723198283, 0.04152976762270555, 0.06642764958087355, 0.04425087434356101, 0.019020593717868906, 0.03709410681040026, 0.03682513764942996, 0.00896876468686969, 0.02336049892619485, 0.007657768701392342, 0.029559257709479425, 0.03994186103227548, 0.0539211550494656, 0.05709365083021112, 0.04117829761526082, 0.044337019135127775, 0.061349133029580116, 0.05143172085809056, 0.0701902640867047, 0.02444120324071264, 0.038765816716477275, 0.05168345735000912, 0.028156643129477743, 0.011959797939198324, 0.012855522872996517, 0.025156531555694528, 0.012145063974458026, 0.08044816990150139, 0.10478477299329825, 0.016309873353748117, 0.035038491332670674, 0.1278338537667878, 0.04000179687864147, 0.05086466437205672, 0.05144173243024852, 0.025091975840041414, 0.07543773055658676, 0.020344230797491036, 0.03654658365121577, 0.26565098902210593, 0.21430999942822382, 0.11031925765564665, 0.17530150042148307, 0.13410035578999668, 0.17581525957211852, 0.12785396596882492, 0.1489917715662159, 0.10676750956918113, 0.11786707764258608, 0.0830917815619614, 0.08411809016251937, 0.1284473724081181, 0.1529027265496552, 0.09788500377908349, 0.16856391273904592, 0.10228650353383273, 0.1281610073056072, 0.16070027922978625, 0.07371142826741561, 0.24641976080602035, 0.19677061558468267, 0.1945620434707962, 0.08395506258239038, 0.1488677438464947, 0.13672846398549154, 0.1045755689847283, 0.13296528544742614, 0.08029721706407145, 0.11514005600474775, 0.2044311974896118, 0.13121960568241775, 0.26110542356036603, 0.09368986560730264, 0.19698157848324627, 0.07687665842240676, 0.1466146725579165, 0.12370475189527497, 0.07247876550536603, 0.1696761546190828, 0.21086487569846213, 0.12040220215567388, 0.12579780130181462, 0.1314804854337126, 0.2560151810757816, 0.10036033345386386, 0.09585675128619187, 0.15196006541373208, 0.07503025437472388, 0.16169581096619368, 0.11379208575817756, 0.15580634964862838, 0.109295004804153, 0.13913130067521706, 0.1392243363079615, 0.12057155283400789, 0.15449487080331892, 0.1968102907994762, 0.22881726472405717, 0.16577820206293836, 0.08693313793628477, 0.12921053770696744, 0.2206216982449405, 0.1337094369227998, 0.14733253716258332, 0.17176314810058102, 0.1870504254475236, 0.09220090956659988, 0.27765887905843556, 0.09108287893468514, 0.13104490411933511, 0.17753928346792236, 0.1279410792631097, 0.10431444432470016, 0.18162768596084788, 0.18210364010883495, 0.20568787615047768, 0.10471368266735226, 0.12130525487009436, 0.11160508787725121, 0.151539534854237, 0.10687618225347251, 0.20081177295651287, 0.1261177856940776, 0.11987922553089447, 0.15394805639516562, 0.10258391179377213, 0.181157668994274, 0.2958269213559106, 0.0999673514161259, 0.17183577467221767, 0.17278676270507276, 0.12383945912006311, 0.17432290449505672, 0.14502460631774738, 0.11705028475262225, 0.14136310201138258, 0.16780344885773957, 0.26460518420208246, 0.1636427314952016, 0.1171896823507268, 0.09110085375141352, 0.13394134322879836, 0.1939226980903186, 0.09904745194944553, 0.131217468297109, 0.10434488722239621, 0.1443038770230487, 0.07056767586618662, 0.11284581778454594, 0.19020781852304935, 0.13551883748732507, 0.161460921226535, 0.15255776146659628, 0.09988409728975967, 0.14450554823270068, 0.20899065595585853, 0.15356898220488802, 0.1885745592880994, 0.10229197316220962, 0.12666385795455426, 0.14749300433322787, 0.16157948673935607, 0.16886434896150604, 0.1435170223703608, 0.0738533862750046, 0.08028653013752773, 0.19364869716810063, 0.1310959193506278, 0.12790293287253007, 0.08322491543367505, 0.16648591408738866, 0.1401582549442537, 0.13121960568241775, 0.172881520120427, 0.20252706919563934, 0.07754200865747407, 0.05876438852283172, 0.17439168674172834, 0.15629725065082312, 0.11287268353044055, 0.15193741506664082, 0.1298332738224417, 0.11649092804873362, 0.1106447413621936, 0.1115978742018342, 0.16866907506482676, 0.13305550091899931, 0.14109153533354402, 0.1541810462367721, 0.11720888171112165, 0.09672389147453941, 0.16390902892453596, 0.17106503946706653, 0.08903265887056477, 0.15788388816872612, 0.1358486182289198, 0.10831996376509778, 0.11033638642402366, 0.1872419292340055, 0.07800665247486904, 0.12550408893730491, 0.14924116287147626, 0.10172421534662135, 0.14967950497521088, 0.19705850951140746, 0.1974887028336525, 0.12322326132562011, 0.24141584493918344, 0.1333238763618283, 0.2674455614760518, 0.224516756425146, 0.15026814682641998, 0.2657083421945572, 0.13380753400269896, 0.11520814805408008]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.039464255605707876, 0.02226222241006326, 0.034974573864019476, 0.05287018488161266, 0.024031513603404164, 0.03690168647153769, 0.02676281928870594, 0.014939077427698066, 0.008234808465203969, 0.028733533072227146, 0.0323109910095809, 0.01662241957092192, 0.050301415103604086, 0.05222836814937182, 0.04367300105514005, 0.06182587756484281, 0.07928920982521959, 0.01597659709659638, 0.033232909117941745, 0.047974385088309646, 0.07476466198568232, 0.03237496413930785, 0.0678151985630393, 0.07055748617858626, 0.04367935012851376, 0.0683509252849035, 0.020778594989678822, 0.051496751548256725, 0.010030841094703646, 0.03591946515371092, 0.006021210156177403, 0.039556118645123206, 0.04262533715518657, 0.03475303536106367, 0.02273449736094335, 0.0367647973325802, 0.009884330011118436, 0.06019281499902718, 0.07677850939217024, 0.021873463192605413, 0.018284392499481328, 0.06541059556184337, 0.026591470377752557, 0.057553170117898844, 0.07806652152794413, 0.029725101740041282, 0.07667857920750976, 0.022718433574482333, 0.0516241486184299, 0.022404482842830475, 0.03369073259818833, 0.03530123758537229, 0.07215428369818255, 0.0009183662359646405, 0.0517343649698887, 0.06154880786198191, 0.07825111591955647, 0.04769620958541054, 0.006667970983471605, 0.053188655292615294, 0.02189690578234149, 0.06994804192800075, 0.05403404313256033, 0.0637992296833545, 0.009546112905809423, 0.034018583755823784, 0.022512194445880596, 0.022663423733320087, 0.013032975020905724, 0.05610182983218692, 0.05795113196654711, 0.0009409598203546921, 0.009677887719590217, 0.028999943679082207, 0.07346127997152507, 0.04918114318570588, 0.14960714557673782, 0.021862963658350054, 0.06547958560986444, 0.03188036353094503, 0.10048836877103895, 0.03552540329110343, 0.01565261623909464, 0.024620251933811232, 0.023018081265036017, 0.056827216103556566, 0.015644601044186857, 0.08152191658155061, 0.0739274377701804, 0.00936922200708068, 0.01677844498772174, 0.038353538839146495, 0.04233780317008495, 0.05508448266482446, 0.061143554412410595, 0.050834622234106064, 0.08908416391932406, 0.04045722322189249, 0.007402821956929984, 0.108800044254167, 0.05012691763113253, 0.045337003757595085, 0.052971168915973976, 0.05541746948438231, 0.034309093753108755, 0.02622496260300977, 0.030647919702460058, 0.09598844539141282, 0.05064450255304109, 0.06630834192037582, 0.03366924371221103, 0.0330766239494551, 0.08216971502406523, 0.036767187048099004, 0.05794008138764184, 0.018438727674947586, 0.05437765379610937, 0.029829761260771193, 0.026026777632068843, 0.02018350758589804, 0.0414888122031698, 0.04179216135526076, 0.05908013154112268, 0.01696944411378354, 0.10360081738326699, 0.06889498632517643, 0.05330548417987302, 0.026611033390508965, 0.03280270466348156, 0.1065802805533167, 0.10576460088486783, 0.007145429372030776, 0.038824836010462604, 0.05354471919417847, 0.027560182752495166, 0.04034147415950429, 0.0174125118428492, 0.03396140869881492, 0.03736506121640559, 0.014710825271322392, 0.033202351187355816, 0.04225700926326681, 0.0047960630308807595, 0.08789747720584273, 0.02059819187707035, 0.026382425930933096, 0.05293601338053122, 0.021926563858869486, 0.012301694241614314, 0.04847926444199402, 0.039246090163942426, 0.035630046113510616, 0.0554170946998056, 0.08747232306632213, 0.06917101331055164, 0.034331358183408156, 0.07189689946244471, 0.03816144133452326, 0.025275278894696385, 0.023119731376937125, 0.033493855662527494, 0.025245292417821474, 0.014587199239031179, 0.055961771722650155, 0.014397652867046418, 0.023805512937542517, 0.01874604175100103, 0.0739112589508295, 0.0647450597898569, 0.024149912132997997, 0.03426959665375762, 0.01679626395343803, 0.02265171078761341, 0.07278440418303944, 0.0192656397484825, 0.10098893253598362, 0.0461842321237782, 0.014294443317339756, 0.062007150845602155, 0.025644018678576685, 0.012860304159403313, 0.06570125769940205, 0.026192699588136747, 0.06982421458815224, 0.06265871197683737, 0.03350152946950402, 0.006255706557567464, 0.053413340501720086, 0.11502016204758547, 0.03241997539589647, 0.01041487561451504, 0.013729764486924978, 0.0238919638650259, 0.022356801709975116, 0.008448919925285736, 0.03309732986963354, 0.031065990042407066, 0.033665822411421686, 0.030998584479675628, 0.022542190199601464, 0.04384635562018957, 0.020843159982177895, 0.044737578500644304, 0.10017243650509045, 0.03178270431817509, 0.01662727321672719, 0.1219931292871479, 0.03926996505470015, 0.14371047058375552, 0.029727354158239905, 0.03301780132460408, 0.02276286595588317, 0.03155475737003144, 0.03812326896877494, 0.03248715460358653, 0.07184296759078279, 0.04420107252371963, 0.03722304754774086, 0.04780302318977192, 0.02575664700998459, 0.04630480514606461, 0.04069885166245513, 0.022758324012102094, 0.035509688314050436, 0.04427139101608191, 0.032593801224720664, 0.02568051564594498, 0.051936871095676906, 0.05201735330047086, 0.02895174675359158, 0.02919281858339673, 0.04088200999831315, 0.0662695053324569, 0.013674371512024663, 0.023947018235048745, 0.03176646241627168, 0.025755839924386237, 0.009785183719941415, 0.06483576507889666, 0.012944959089509211, 0.07557070115581155, 0.03169585448631551, 0.009720767156977672, 0.05379563932365272, 0.00981962215519161, 0.01836149978771573, 0.0350543102103984, 0.07084232245688327, 0.032213450540439226, 0.024774201192485634, 0.021379109348345082, 0.044387626185198314, 0.047548978618578985, 0.04074056036188267, 0.04466214290005155, 0.09151340622338466, 0.0458607076870976, 0.03396629574126564, 0.003284875956524047, 0.008538393249182263, 0.02423390840704087, 0.043777265382232144, 0.02852356650691945, 0.011845538738270989, 0.0431763706728816, 0.01390629266097676, 0.04937782716297079, 0.06444896513130516, 0.037665935305994935, 0.06465817656135187, 0.01909600705403136, 0.09149138670181856, 0.037806342224939726, 0.014116386319074081, 0.0632090812723618, 0.014985621219238965, 0.006328978797682794, 0.04748381063109264, 0.007984038620634237, 0.04605499081662856, 0.08749596046982333, 0.05126347969053313, 0.03610207058954984, 0.07476416474673897, 0.010800932486745296, 0.04710492197773419, 0.03239248995669186, 0.018563282319519203, 0.039299483978538774, 0.04097024393558968, 0.04014310550701339, 0.030425249424297363, 0.0822502380469814, 0.005304625292410492, 0.07408430552459322, 0.027925480826525018, 0.043502054759301245, 0.03169441471982282, 0.03448825933446642, 0.007777005394018488, 0.012500102784542833, 0.04413303984620143, 0.01680294513789704, 0.06232790707144886, 0.027120157828903757, 0.04880050306383055, 0.034820351866073906, 0.04802928917342797, 0.03734834062925074, 0.02497743276762776, 0.03173237928422168, 0.06534314918098971, 0.04328521405113861, 0.04511763974733185, 0.007698759372942732, 0.047286985645769164, 0.037335583110689186, 0.039790544542483985, 0.059141414385521784, 0.04212476596876513, 0.024044593956205063, 0.007571682817797409, 0.07027701372862794, 0.031561306823277846, 0.018915255132014863, 0.021999470591254067, 0.07608621919644065, 0.05900733798625879, 0.06747168066794984, 0.047304693289333954, 0.03445370864938013, 0.014361046432895819, 0.046452251335722394, 0.04838716020458378, 0.05754707337473519, 0.0223549686052138, 0.045585100015159696, 0.02884366964281071, 0.027588358389039058, 0.029688482318306342, 0.030364348785951734, 0.01407872696290724, 0.020659298461396247, 0.0059172445435251575, 0.03686215226480272, 0.06563427145010792, 0.07254999683937058, 0.04152418296143878, 0.019346502303960733, 0.029331808000279125, 0.04458674440684263, 0.02586094844446052, 0.13102942291880026, 0.10859311863896437, 0.2257948979968205, 0.11732323182513937, 0.055876829210319556, 0.11723833013093099, 0.14147834270261228, 0.19778235582634807, 0.1368362089851871, 0.13594484509667382, 0.1628277642885223, 0.12903170980280265, 0.24407984339632094, 0.1371923804981634, 0.07397383684292436, 0.22606371872825548, 0.13396751135587692, 0.1736293378053233, 0.13559624348999932, 0.13430239807348698, 0.2108498991583474, 0.14784988830797374, 0.14589789148885757, 0.1955873501719907, 0.1011335029033944, 0.14280414499808103, 0.106631117669167, 0.18328868667595088, 0.130784350913018, 0.08211527107050642, 0.189720464986749, 0.1126753019343596, 0.3165008994983509, 0.08557816181564704, 0.1484975012135692, 0.1912437824648805, 0.1073723821900785, 0.1534868116141297, 0.13008486188482493, 0.09421243405085988, 0.11565189299290068, 0.17901068029459566, 0.15392058208817616, 0.12789610511390492, 0.2841452497523278, 0.08402951483731158, 0.11030292298528366, 0.14923754119081423, 0.18996305821929127, 0.12600079353433102, 0.08829356884234585, 0.1723180222325027, 0.13555785961216316, 0.15535672690020874, 0.13073020381852984, 0.14315369655378163, 0.12890126992715523, 0.11981378294876777, 0.1512675525736995, 0.12583792180521414, 0.12146064575063065, 0.19871318712830544, 0.14729284710483626, 0.10568105732090771, 0.18861467979149893, 0.1833235824597068, 0.11060064294724725, 0.09944977762643248, 0.09388409307575785, 0.096902852965286, 0.09515564437606372, 0.152748730906751, 0.1530204460141249, 0.09086822756216861, 0.12783300771843642, 0.22139799955766648, 0.23230881721246988, 0.12783087033312768, 0.20509871479589492, 0.15506524097872898, 0.15908952191239223, 0.17114057525759563, 0.1554923618095927, 0.12878816662123427, 0.10325248294975609, 0.13117157388478518, 0.06998492666753009, 0.20708958531031385, 0.13421409734291956, 0.08052559816860594, 0.09608042717445642, 0.16155091405380517, 0.13969739608000964, 0.07470469645340927, 0.16590987390372902, 0.24086408782750368, 0.16513456706888974, 0.10283297655405477, 0.13490784214809537, 0.16664229944581166, 0.0996770677738823, 0.08577989239711314, 0.09150103462161496, 0.19322524254675955, 0.2525160735240206, 0.15069182409206405, 0.12186205116449855, 0.34067448985297233, 0.1352084119571373, 0.18027215322945267, 0.0871325159096159, 0.1384107198100537, 0.3058851300738752, 0.1219050883082673, 0.10064060552394949, 0.1528507168404758, 0.15269341121893376, 0.05913774817599915, 0.2743389259558171, 0.08985619788290933, 0.14790654386160895, 0.17747361824149266, 0.12864988966612145, 0.13860332197509706, 0.25678190868347883, 0.19061568804318085, 0.09624556245398708, 0.07501299201976508, 0.09841449646046385, 0.1939500981825404, 0.18178524391259998, 0.1447327938512899, 0.16029165271902457, 0.22889698622748256, 0.13127964542945847, 0.16937344742473215, 0.19255778461229056, 0.11028410954168066, 0.13674179295776412, 0.09056475595571101, 0.12900186062324792, 0.10337573883589357, 0.12602918810443953, 0.13830901589244604, 0.11946974555030465, 0.12436681441613473, 0.21364402578910813, 0.07839073616196401, 0.10370879987021908, 0.19612283940659836, 0.13189481163863093, 0.13778758293483406, 0.15177044668234885, 0.19392675021663308, 0.15075337782036513, 0.09876032985630445, 0.1129726656654384, 0.1181280316086486, 0.23167723469669, 0.12121675375965424, 0.18572012573713437, 0.15814156184205785, 0.10822245298186317, 0.11659426469122991, 0.10964722067001276, 0.1289468674804084, 0.08389704147703014, 0.22137834748718888, 0.1966072095092386, 0.20296607923228294, 0.10375243073212914, 0.1255964269512333, 0.06411617127014324, 0.22472350392490625, 0.1406053247046657, 0.14120885403826833], [0.06714711722452193, 0.03028424507647287, 0.02884994821215514, 0.021019486848672386, 0.04650884380680509, 0.0556322173360968, 0.0841996818780899, 0.06833122868556529, 0.028948165891051758, 0.020531144400592893, 0.03711828598170541, 0.037875859197811224, 0.04815648957446683, 0.022130433681013528, 0.11304734798613936, 0.014791127505304758, 0.008445776929875137, 0.08154316426953301, 0.04405635372677352, 0.04573642021568958, 0.04522843868471682, 0.05021275814215187, 0.026754872742458247, 0.04391149392176885, 0.014896731408953201, 0.0016371873994103225, 0.01869842741143657, 0.03347100122482516, 0.017504898096376564, 0.03720474989677314, 0.055736214490025304, 0.0277690119764884, 0.0396338474820368, 0.02891946704039583, 0.04747515718918294, 0.07746276212856174, 0.03572851055650972, 0.0996943301288411, 0.013242905406514183, 0.04277430474758148, 0.022394222651200835, 0.04322483662690502, 0.028028852721035946, 0.05363955824577715, 0.020687446267402265, 0.045828316651750356, 0.046679908846272156, 0.05108963530801702, 0.028199561529618222, 0.03370567203091923, 0.024124937008309644, 0.04214708606014028, 0.020676173044194, 0.02779259371891385, 0.028831754461862147, 0.042271121201338246, 0.05291220157232601, 0.006993789584157639, 0.0141863411590748, 0.04190213650872465, 0.01028583097649971, 0.04044027999043465, 0.013329357261682162, 0.04876912134932354, 0.0200133442558581, 0.050371529505355284, 0.041811253104242496, 0.06186108505062293, 0.02221124799689278, 0.023979780344234314, 0.0708559705526568, 0.032439189599244855, 0.0366414115705993, 0.05126047028170433, 0.035772597839240916, 0.014846216199657647, 0.011431704206188442, 0.04316654092690442, 0.0262577339890413, 0.02508933008357417, 0.05434563383460045, 0.013809933134325547, 0.053125698905205354, 0.01637031014979584, 0.018667435324459802, 0.057990510322269984, 0.043241382809355855, 0.032743217816459946, 0.07016802934231237, 0.03315141759230755, 0.06596095001441427, 0.011413185766286915, 0.04937812402204145, 0.021105080595589243, 0.022708741125825327, 0.013894944295316236, 0.0336094488739036, 0.018395325023448095, 0.1066346577135846, 0.04836157837416977, 0.015909577450656798, 0.009588817938492866, 0.016465611188323237, 0.0754201268136967, 0.06485493475338444, 0.015783872477186378, 0.013356343606574228, 0.02311131356691476, 0.05716028084862046, 0.02398201235337183, 0.0443615359836258, 0.03556701551133301, 0.03738465762580745, 0.09473425292526372, 0.09336370654636994, 0.023861020017648116, 0.01580982167070033, 0.05591198103502393, 0.030862062703818083, 0.12330497178481892, 0.06373161260853522, 0.09978463465813547, 0.04854028011322953, 0.049029396250261925, 0.07419491521432064, 0.026218813909508754, 0.05947582612861879, 0.06201011572557036, 0.052669378274003975, 0.017166421239380725, 0.026391225947008934, 0.03762898006243631, 0.02390366938925581, 0.02009625513892388, 0.049021982194972225, 0.037633503452525474, 0.0281527134575299, 0.017416504597349558, 0.019074462506978307, 0.03154920610541012, 0.05062788586656097, 0.09505769572569989, 0.04013849305920303, 0.04658652069338132, 0.03716758685186505, 0.09272499941289425, 0.028581457736436278, 0.13776990497717634, 0.012361926019366365, 0.031289617691072635, 0.08361780841369182, 0.02557946110755438, 0.0659830734366551, 0.013122385262249736, 0.05295529066643212, 0.03112539525318425, 0.06538658708450384, 0.05289405235089362, 0.036190601385897025, 0.0785117136547342, 0.04089188056241255, 0.11813350865850225, 0.03033764074643841, 0.032241919325315394, 0.04732205212349072, 0.024571529938839376, 0.02781085240712855, 0.04538080160273239, 0.012415900564519688, 0.016021864394133445, 0.006571767307832488, 0.06812244770117104, 0.04380979742563795, 0.07641245247214101, 0.05478746032167692, 0.05400413829192985, 0.018629361293278635, 0.03960377194744069, 0.04136526687943842, 0.04502847441472113, 0.0641076588362921, 0.02489099668309791, 0.014901475587976165, 0.08186988736269996, 0.0845632451819256, 0.034013307085842825, 0.08292864265968092, 0.03731181212060619, 0.04669716377975419, 0.04293761434382759, 0.06240746530238539, 0.052862663214909844, 0.022882791454321705, 0.019331162111484446, 0.042192015680484474, 0.02153614037524676, 0.049269926312263124, 0.06375109398504719, 0.02767177764326334, 0.04138601361773908, 0.10118567588506266, 0.011838729533337755, 0.02942621475085616, 0.02809087029163493, 0.04109278735995758, 0.03804976666287985, 0.020028407998324838, 0.018418097824906, 0.02000598771701334, 0.043447993011795916, 0.05230860173469409, 0.048768883862067014, 0.03468225673714187, 0.011000075755873695, 0.06769181651179679, 0.021675981406588107, 0.03348183287016582, 0.03869218453473877, 0.018586066253192257, 0.04244421230396256, 0.018134961064788513, 0.03867649182211608, 0.08885852876119316, 0.09235915771569125, 0.040287972733494826, 0.008672766507515917, 0.03654342581285164, 0.07271165144629776, 0.054563290905207396, 0.06577641499461606, 0.02816246898873942, 0.019730229760170914, 0.07725962146651, 0.007486498179787304, 0.016642999325995333, 0.021146061990293674, 0.018218977747892495, 0.010344389211240923, 0.023295047067222185, 0.09166930918581784, 0.04037147919007111, 0.057988699481938966, 0.006500748877442675, 0.05330969586793799, 0.027783686091424897, 0.09204510308336467, 0.08528851642040536, 0.0178590454015648, 0.0431529559136834, 0.07831718190573156, 0.055978640739340335, 0.009599308195902267, 0.04201732524961699, 0.024595710965513717, 0.046709171729162335, 0.020348897051007953, 0.08385255714529194, 0.049301244944217615, 0.041529775044182315, 0.008054039844864747, 0.02350137339817593, 0.046659815197926946, 0.045202140681794845, 0.033661243360256776, 0.03278539777966216, 0.043737078085541725, 0.058646030811360106, 0.054259548414847814, 0.04086763830855489, 0.024099210459098686, 0.022541078833455686, 0.023481186981371138, 0.029503726509574335, 0.03922261232219171, 0.020616456131392624, 0.04080719780176878, 0.04568623618979473, 0.04626711888704449, 0.09366859565488994, 0.06171917528263293, 0.08617007653811015, 0.051432830368867144, 0.022355104047164787, 0.024460178101435304, 0.005123675309732789, 0.025279659421357792, 0.08620962558779866, 0.047250264178728685, 0.06637660466367379, 0.06586366929695942, 0.05343023549357895, 0.0036397950952959945, 0.025430400746699888, 0.03512994990160223, 0.045103772717993706, 0.028129873862781096, 0.07972360370331444, 0.054754316006437875, 0.0650087374378927, 0.057142721634591, 0.011460286168585299, 0.00808368029538542, 0.04452107546967454, 0.06178874791658018, 0.044391771079972386, 0.023998408250918146, 0.04583812042255886, 0.043911738830502145, 0.03502601211948786, 0.0225694047549041, 0.03606749764003325, 0.026600992132443935, 0.033753392126527615, 0.011798338146036258, 0.009251008086721413, 0.017376738469465636, 0.034275032885489054, 0.026652320921130013, 0.0633988187473733, 0.011836048524855869, 0.07024184335023165, 0.05471706761454698, 0.01665888870775234, 0.08122518367599696, 0.03446988746873103, 0.020901216339552775, 0.017597622027096804, 0.06265727221034467, 0.03915322893590201, 0.02846091811079532, 0.03487812435196247, 0.09023093050927855, 0.060104540243628435, 0.004777027406817069, 0.07936668262118474, 0.03280125376477372, 0.0634445424657315, 0.06152575675514527, 0.03042805659788428, 0.038158346578711644, 0.07131200545700267, 0.03836447809590027, 0.03020299660420278, 0.013000013459532056, 0.008203218021662906, 0.03115472492936533, 0.018374186802248005, 0.03382139511813875, 0.06956444805837236, 0.03735564707312733, 0.04675234617025126, 0.04984799998055678, 0.19413787638768554, 0.11587950968532823, 0.13573392672697082, 0.12718781421426684, 0.19085342762991786, 0.0949382470571436, 0.16513044072780758, 0.1982782589038834, 0.11236953709158115, 0.11632066452875733, 0.1575933225103654, 0.17778741312213242, 0.13672648987267166, 0.12350314747891389, 0.18332343403017148, 0.17680228629615158, 0.08935138161177747, 0.14878739893902093, 0.14876713830744848, 0.12401644649798982, 0.10993982723448426, 0.11616089497692883, 0.09813599070184864, 0.12891670659882948, 0.20919928851071745, 0.08264129050076008, 0.16771489579696208, 0.14480721642030403, 0.12308160017710179, 0.12371108241495676, 0.14055239473236725, 0.1901908975560218, 0.09466565621551126, 0.15793168247910216, 0.25226763216778636, 0.1646223070565611, 0.08279321555164643, 0.1989305324968882, 0.11907747597433627, 0.09428871198906563, 0.11319298704620451, 0.09949740866431966, 0.13081402197713032, 0.2292860348825343, 0.09239524835720658, 0.1345707883592695, 0.22111485537607223, 0.17338025820208713, 0.11298095545498654, 0.12231188913574442, 0.20447988237719983, 0.1433331478619948, 0.16391558950999752, 0.17365256702760234, 0.06720069286529906, 0.1647375922766514, 0.1554089889395982, 0.13025113265030086, 0.1045634645561222, 0.11864444764796644, 0.1436630918760784, 0.11777214211178944, 0.07161543253459968, 0.12191777903353795, 0.16567980812396854, 0.15865610766923055, 0.12769683846272528, 0.14613646228099242, 0.09476737497607246, 0.14744850515853614, 0.10636110950144939, 0.17371440277202055, 0.10483230755198747, 0.17687329498585314, 0.19474265252938494, 0.09410131970071234, 0.10764825332444161, 0.11887632426805794, 0.13983737997477874, 0.09763759400811978, 0.10609848570311442, 0.3397063136799261, 0.10850861028302461, 0.16408723342465237, 0.0746576813980937, 0.21322152111679316, 0.1475548549205996, 0.11269689843175001, 0.17361039819661528, 0.09909797736327164, 0.15140354371396825, 0.17277643200941384, 0.09877543256152421, 0.12751336471410468, 0.07774647034239024, 0.07841848506359383, 0.10204699021414854, 0.14788034604862332, 0.1707885300857015, 0.10717065160861239, 0.14060311310458928, 0.15362645412096754, 0.18886062753153965, 0.11831684139906429, 0.2043175746803172, 0.1374726154608652, 0.10851457715034485, 0.09398523296113126, 0.09559213111060672, 0.09907137136906385, 0.1278562963125296, 0.11582174091017805, 0.23519180860603228, 0.22876215283758938, 0.11834225253551267, 0.08017060667043552, 0.11065535407396965, 0.11611306355916895, 0.16383390873670578, 0.20861051307292655, 0.16130321484524757, 0.11254805329372175, 0.1435630800551735, 0.21157194947591051, 0.18900737981311977, 0.11610726738581434, 0.15778350527398288, 0.15966384031344205, 0.10667329392163083, 0.09162295464193448, 0.14532090135617182, 0.10671561118215322, 0.1477806459297426, 0.11753738595871255, 0.07565254520159215, 0.13400565774645656, 0.07124691168428399, 0.1238831048249267, 0.15781381458509713, 0.10091661766637117, 0.15112942404812202, 0.10211111177341081, 0.20063264819327742, 0.15072964393766597, 0.1894241402624175, 0.171657674072776, 0.138981876662001, 0.20780770224519074, 0.14247476501623169, 0.08224093151511624, 0.1105553719389718, 0.09604332721210085, 0.2074372221250087, 0.11378338778740726, 0.1271826637093909, 0.2076327335089445, 0.2619177190354094, 0.12139416416175663, 0.18119955580914393, 0.16168291243957356, 0.15005816356278956, 0.21561312169069424, 0.1309595868224278, 0.10637288738507777, 0.10607402451569214, 0.14677868719445542, 0.11448536301031709, 0.13303970801644027, 0.11464033828815445, 0.12077822611900046, 0.09254523640265688, 0.15721439674962312, 0.23504483368014917, 0.14699480059789494, 0.2412274878588505, 0.20210910646710545], [0.07674055595998652, 0.053180703180260025, 0.025082095999096055, 0.06516056600958109, 0.05804502849059645, 0.04002563095127698, 0.05912198867008556, 0.039545216495753266, 0.04330824289354496, 0.007701605509282672, 0.04765217425301671, 0.06722504273056984, 0.012365737875370542, 0.033327607161481865, 0.06097550991398748, 0.013177676191844512, 0.09155837295111269, 0.05127651180373505, 0.044012667203787714, 0.029634068050654605, 0.018733892793534324, 0.041753770055947825, 0.014116706370259635, 0.12251293694134802, 0.010344951388105983, 0.05676830813172273, 0.04166584039921872, 0.008406010801991215, 0.019087361033598427, 0.09515669080428779, 0.018077678396366537, 0.09954173714504577, 0.05755203092121519, 0.04022466382593848, 0.0525693812960526, 0.028644293524848763, 0.04455639798834454, 0.054305131125147454, 0.01721836601063842, 0.09329214866738766, 0.07531111274147406, 0.037577708790195175, 0.024819670725264587, 0.08507287057000212, 0.11091432650573552, 0.06631937765632756, 0.05854808216099627, 0.049673198227537796, 0.05474938443512656, 0.04367089335573837, 0.03597112976422068, 0.05787878741102759, 0.03189186681993306, 0.04817901375645306, 0.05636855399643537, 0.07172303652623668, 0.03789799004152883, 0.07389738821075298, 0.013255040448711952, 0.021376406075432897, 0.009859046895144274, 0.08033353034988977, 0.03941242030123249, 0.03797178178501781, 0.029079388732498046, 0.017594146920600906, 0.01732368047669297, 0.05968345307337586, 0.017947527958313003, 0.05619436451524962, 0.02283116951730335, 0.014484867278952152, 0.07538576537626795, 0.03240950740291737, 0.042369741495349444, 0.02782138533802936, 0.03933411258913111, 0.10063945519505069, 0.015901217157079373, 0.026430574616824742, 0.0423343187867431, 0.06643487809924409, 0.02985268620250281, 0.05004791972169187, 0.04870927084994037, 0.023292013538593892, 0.08702668565092608, 0.03486705893010367, 0.021176933478272986, 0.03277874071500264, 0.03740365289559122, 0.03535668343829457, 0.009135277578025125, 0.035939981826231815, 0.05054888424638193, 0.010904656901402632, 0.045895458752056584, 0.03998653090093285, 0.03588056548323948, 0.07454884544131346, 0.05290250541293062, 0.010058716161438497, 0.01411550130796968, 0.06002933470881544, 0.041072638050536625, 0.020529055254883133, 0.06020163913490251, 0.042662752530304715, 0.057777625261223875, 0.022401898313546553, 0.10715277327108197, 0.05666638528055046, 0.09067581835552119, 0.04530752565187868, 0.04099645659152884, 0.05388100486015901, 0.04578008818498347, 0.027051314355048817, 0.021779895068902988, 0.007760835851513548, 0.019825213530566543, 0.01914165470225271, 0.013645193048432702, 0.02678566444956232, 0.0467167490569409, 0.01761556530254893, 0.008963901764218463, 0.009207434741256293, 0.016314966342179105, 0.025278171415266115, 0.028084955374652054, 0.09351673739729449, 0.01702499943348812, 0.058378460598760284, 0.056609610983286984, 0.03140872868243605, 0.012366770388325676, 0.017169543825730216, 0.017401489094481803, 0.022658586785837542, 0.05345064084394835, 0.02151891698304098, 0.025400453232578002, 0.08835032829665579, 0.0630343054945115, 0.06147589927422814, 0.04498088048421778, 0.021399757752078585, 0.023721063953416888, 0.0365937174501596, 0.016511937901668716, 0.011388996390451211, 0.06578019994776696, 0.03069287158723455, 0.05245822241704445, 0.02642934265168151, 0.008690814611327369, 0.036236124724382535, 0.03929952479666099, 0.01367327684420161, 0.03706806484842673, 0.02275784903758904, 0.010509158055356238, 0.053067495973664336, 0.047291876398958266, 0.028593163260666188, 0.025933690048987046, 0.05965352967905346, 0.023971507253008895, 0.03963285300415009, 0.014571417468687287, 0.04236358538037166, 0.06406207612599246, 0.02253536986245308, 0.04682093174778856, 0.05360308168746997, 0.043539247490116395, 0.007965545228216797, 0.02913987191277556, 0.06720136079820804, 0.02282951452798443, 0.04926325811538845, 0.025107219553319737, 0.004239807576595922, 0.03795352124143392, 0.04701910373114515, 0.03216315890313126, 0.05013452835555654, 0.027276513501419686, 0.042221200637868606, 0.025573442289896775, 0.02172625820094254, 0.04398176046379376, 0.06543365409015678, 0.03163120229146443, 0.03410550780245103, 0.03624770222813822, 0.06780799973057583, 0.04782625983352773, 0.04639726932509802, 0.038883729139342904, 0.05084105665446259, 0.06501834082882851, 0.030961523480073083, 0.008515967401763191, 0.031792185254744254, 0.02963418864965206, 0.035464999891701154, 0.04237034634570591, 0.02468657952704234, 0.03283788246335462, 0.05542392245843075, 0.021873238692933228, 0.016774673022155184, 0.03286562023276929, 0.022554354000021704, 0.02249756857054308, 0.04477906826650724, 0.04381944163469598, 0.047452124636038207, 0.10675533834728412, 0.06457510055042803, 0.0031309934911405435, 0.024261234284495004, 0.10038623440777883, 0.03355572851432953, 0.017797011132643092, 0.050344630362815224, 0.0713182394974865, 0.07048481507808901, 0.0897443710709922, 0.09210771808284335, 0.0659784943854902, 0.043294205170241185, 0.03268845845013857, 0.03909531544195488, 0.01573921003000578, 0.06391185059328564, 0.031546961108688265, 0.06795792098273523, 0.05328841107257176, 0.043076982256025076, 0.035108850643155165, 0.07084109049174003, 0.010652620767359622, 0.09139662186498754, 0.08961309256847017, 0.049947306761168875, 0.03972650090872776, 0.030621972364315297, 0.015836568672966678, 0.010399834136478603, 0.009466166902711848, 0.037769424088764936, 0.021811877923028078, 0.031093458783288952, 0.04593200581439305, 0.024196801023208536, 0.04074994852999225, 0.017097646414185874, 0.021345853710954543, 0.004585339938785182, 0.07598753581987694, 0.0055783775951567804, 0.03889405612426344, 0.04040326166432351, 0.022600760494242422, 0.0891889254853595, 0.020111201993131544, 0.034452298568794504, 0.0671321852132678, 0.009724439860292478, 0.047409948383574374, 0.0766409003699664, 0.0442357382416958, 0.048112023796420544, 0.02931575905677164, 0.014382223616848933, 0.030606235122832004, 0.0484069198864745, 0.017696507638902403, 0.04769001265231054, 0.02533344471885357, 0.01874240522738546, 0.00791222006228054, 0.04067637572006788, 0.056959173671202734, 0.046384589732042514, 0.05752540637331549, 0.03965639021771494, 0.06932750256964937, 0.02749701485299738, 0.055630476999795064, 0.021765775709354784, 0.05517351812159177, 0.015829963558644522, 0.02779222635581391, 0.06709519657306373, 0.007451820401911391, 0.04658065772673581, 0.05759834464697633, 0.01483705716964323, 0.0660575256915763, 0.01172123456854024, 0.030117690439510625, 0.03561103600077331, 0.08169730092049576, 0.05699985078535974, 0.008728627963137114, 0.01857706029113615, 0.04628883041732479, 0.01766961406246992, 0.08021769594051875, 0.013061456793366233, 0.03052753036172362, 0.02737202976277331, 0.03512840994517319, 0.0466213608160615, 0.027910482021979988, 0.009009807308757445, 0.06061633270292077, 0.02907507685449673, 0.05085689408588223, 0.06453886890085414, 0.03965318413975183, 0.01571397700899979, 0.025735744420671836, 0.022669123427476734, 0.052410576536203735, 0.01130802251282148, 0.021859421758563258, 0.03808485911577009, 0.029380027190200053, 0.07550881346105598, 0.11177812702953815, 0.09073370587429963, 0.05153094229171984, 0.029469622968463227, 0.057657015131553635, 0.03371814382262528, 0.04985763305739965, 0.05656308203469962, 0.020563726538966876, 0.003236327206650458, 0.11076168899307959, 0.13569478585850447, 0.02309140174475033, 0.0187322600686457, 0.02617714046209585, 0.030069363638176583, 0.03875166396028362, 0.029448252826114185, 0.11011677008355036, 0.13882388826459646, 0.14975021680584177, 0.11247796486713924, 0.1017754383792635, 0.14143755426630378, 0.12609385885298252, 0.16348420875146985, 0.1612310335622169, 0.10345940114348195, 0.08075878096860833, 0.1605292735621333, 0.11542285879841074, 0.11303223785944283, 0.11952463479246944, 0.11928286534384824, 0.20364444673759863, 0.13617082906421274, 0.1422360012657009, 0.09626728511648253, 0.11642261335509829, 0.1281874129199423, 0.12283148898859508, 0.2207885033567436, 0.1339624053798616, 0.16500246478244662, 0.11540244973730296, 0.07782270375173539, 0.12372722412692383, 0.22832640825072303, 0.14477183081908152, 0.14501724421279505, 0.1488096039975062, 0.10803322758874856, 0.12661940330872312, 0.14402775355847552, 0.1802312460495159, 0.18439708423102275, 0.1108605282206554, 0.17016159341437742, 0.135600607318338, 0.14373616373632103, 0.16088865115307271, 0.1400559424655512, 0.2086446073371917, 0.1044235029257834, 0.12159136022091843, 0.11895894756889902, 0.2507261617574841, 0.0679266543011181, 0.10865586722502485, 0.1784604965359904, 0.08789097599219531, 0.0886363816971425, 0.19792701525148004, 0.18681077111978084, 0.18761208280920982, 0.19676726107718423, 0.17434165114536881, 0.20212274714140221, 0.36326712754089385, 0.18968087882967666, 0.12475631578126922, 0.11818436061730608, 0.1475823885994032, 0.09447309115785174, 0.09485580929322168, 0.13246411312138662, 0.08660502702696249, 0.1511785393813625, 0.1720990738249384, 0.1252494877553545, 0.239064424240496, 0.17108060972532257, 0.10725540487328544, 0.10002858602092601, 0.18923775729490444, 0.1686268171761185, 0.11377422968507744, 0.09825821500271559, 0.1573436491889879, 0.19827169831842184, 0.11190078177605756, 0.05550561436393764, 0.16539167670998722, 0.09753889578860253, 0.16849817329784855, 0.05283957128995098, 0.1136170131212566, 0.1293706931755878, 0.0892038871825207, 0.21154428221052513, 0.04528390309133101, 0.09266300781746395, 0.18945398944197223, 0.1441682717995718, 0.1586726278765127, 0.14572253683581948, 0.09404274198459461, 0.12859589100116864, 0.17171504208818078, 0.08295309642562643, 0.0952617714938242, 0.14218571333913133, 0.1022255361021962, 0.1387184884515591, 0.14857458067126572, 0.13671957305632532, 0.1688175936578773, 0.09813815777306445, 0.1709335160558112, 0.3599302831571549, 0.24842207523761317, 0.09336469360277988, 0.16910676407860592, 0.17277233535423875, 0.08269239478977397, 0.16006937948986888, 0.1455882377922535, 0.08940169180277735, 0.09996032327762805, 0.06746117185684852, 0.09776932522072457, 0.13850233051925898, 0.16059962916187942, 0.07319735741475597, 0.17674386443104595, 0.15617265889886767, 0.11973482585744932, 0.08713295377674513, 0.19318815000588074, 0.20618354174075648, 0.14914992323610932, 0.0921726188971661, 0.16735461278585717, 0.09950016945367679, 0.16419511201092973, 0.11317950222291984, 0.15277507714927197, 0.10984030523104593, 0.1470407098531723, 0.08451266039628536, 0.26437844324391335, 0.16986014787107706, 0.13083313970128074, 0.1125460494949948, 0.16581894597038627, 0.1541099336463958, 0.06132945498393383, 0.14402040629647672, 0.12076396204065531, 0.125012876233086, 0.2087986920378171, 0.08972468189313076, 0.09033106849528849, 0.0928261986700818, 0.08144525272655301, 0.19630095484899357, 0.2562620193930343, 0.13781719462713227, 0.13789142423775047, 0.10793137524160556, 0.11665270882076584, 0.18810396344633773, 0.19229917583288625, 0.16404666763264686, 0.1280410762410611, 0.10170285633648746, 0.1496750966180116, 0.15851293253945187, 0.13793887716019526, 0.10674187578842975, 0.13785897754132748, 0.08528619349817745, 0.12069250806234777, 0.09584688814356923], [0.08905496040824801, 0.03953588027798105, 0.08763325779000297, 0.09243494583643042, 0.0034527175239418284, 0.03310474021418486, 0.004121899328310974, 0.0642625153705012, 0.010237024562229635, 0.006260883501454373, 0.03524654501234181, 0.028871643044112716, 0.06330026153591461, 0.028259775681362953, 0.03159541593049653, 0.033937693369807675, 0.018539411139499862, 0.030588058070861734, 0.012189471308374777, 0.01781979877705453, 0.04092730698175728, 0.010131736999028362, 0.020507297340373043, 0.0681561189412605, 0.025221283940481953, 0.033561413365532644, 0.006547457332999329, 0.025053463941731025, 0.04939273319905624, 0.037795529133290984, 0.04266926487616729, 0.09121299226535484, 0.023675420015933923, 0.03657427318103146, 0.006396104199666297, 0.006913362576597137, 0.029823545773979276, 0.05205064604524523, 0.025761276156117674, 0.0297852305448032, 0.03528176363033708, 0.042435269424458966, 0.09806616944842972, 0.030871658673277125, 0.010201949735346716, 0.05295021066558547, 0.03814593786955811, 0.03511019764118828, 0.05217033962253481, 0.017699112577247433, 0.028104707635066006, 0.04153416484768968, 0.05988385892123915, 0.04736274779133964, 0.03159875930577982, 0.05871768145880196, 0.040551858182880096, 0.0724352385441307, 0.022225628963497, 0.07378821828751825, 0.01314947829087032, 0.033807754443841986, 0.02751886368059786, 0.06569523888174444, 0.0337656783813145, 0.07827643057680689, 0.01394486856952426, 0.05172718840185553, 0.037676158390240744, 0.016275740126729943, 0.04277342901332304, 0.025430510213482194, 0.02799549689370906, 0.03784966880630236, 0.0481941647012718, 0.05265865795081481, 0.020518509336397983, 0.05265020859951619, 0.06415802097762935, 0.05540367666981183, 0.05986506774206646, 0.02054595766821876, 0.03448376191954594, 0.034555052625364624, 0.013812050110573182, 0.01712224489892833, 0.023731711917207576, 0.004961259537594742, 0.03837726158963051, 0.07718448643572628, 0.05242400569841266, 0.022089289013820235, 0.015144457520364085, 0.04818961533601396, 0.01652918912441237, 0.05993318947730586, 0.0267929282199475, 0.022495679804706015, 0.01514293147920398, 0.011895329425897216, 0.007612699928358779, 0.040991918358486146, 0.01628254191018641, 0.053530232471530326, 0.009904636099236086, 0.03661457922135014, 0.05928211445279885, 0.015255934595188592, 0.06909803792950697, 0.037009453735663556, 0.05044300945883151, 0.05596220958977938, 0.05881164106540382, 0.051461221228237264, 0.041997283551609144, 0.04160128468356561, 0.00993416151686688, 0.0590367715631146, 0.03975062441895716, 0.12028845318127424, 0.037301867341739126, 0.0435706292046234, 0.04032751065096818, 0.04462173666979652, 0.016097719308163505, 0.1073995151091367, 0.04933387346682139, 0.06537646419019438, 0.03932091349270195, 0.0361344356497284, 0.04990423622075468, 0.06309948090347461, 0.03151251432427671, 0.024692607621545903, 0.06781251198844984, 0.045252944400999695, 0.027564578122110106, 0.06480878058937378, 0.03215503238607198, 0.02990153992868727, 0.007174134252636577, 0.016801805941213388, 0.016375390150642488, 0.033515210961923, 0.030851518640702125, 0.021593272758764215, 0.03832325921393931, 0.06786656260374002, 0.03663954135845415, 0.03520973819831852, 0.08435808587819338, 0.012208521311549703, 0.01773965424945345, 0.04906685986497905, 0.029672973287233617, 0.052736969373654574, 0.07292870737728663, 0.012444518706615781, 0.03524663407006301, 0.0629465316887945, 0.04878598665527534, 0.024912574626796413, 0.024625307814858388, 0.007309660159080522, 0.07045105478027835, 0.03320162017189432, 0.03262251862906851, 0.05295171351463068, 0.028721231974486727, 0.023438593270839192, 0.04599881394824479, 0.013573464475484798, 0.03669608930067625, 0.03895793648553081, 0.028049243228451815, 0.013869775284547359, 0.08346042857738212, 0.000886939354813876, 0.09560974969645031, 0.04659803511458449, 0.04499029462749604, 0.04335609657573514, 0.05780747815151699, 0.06464404606958851, 0.06749271313310601, 0.04788237733009737, 0.05889184496481903, 0.027293816674500704, 0.04717754854937084, 0.030199536340660416, 0.014171128987072734, 0.03508730238536373, 0.03784804721362889, 0.03867103332595434, 0.012113030097680166, 0.013407238238869468, 0.08420683618169278, 0.02573127298092004, 0.03385652838915121, 0.060276985677774064, 0.02691300214792136, 0.10972922798828222, 0.013736351975239813, 0.030961180236772634, 0.09058289404492825, 0.01905356919451151, 0.06480225711129606, 0.0698669400298968, 0.012691835709119914, 0.01510688536654925, 0.022352018568199128, 0.0598716097738361, 0.04060405713971704, 0.035908332938561216, 0.09722047732793726, 0.028937337956449483, 0.09618188618333079, 0.017886193163576536, 0.023884462607384194, 0.0457294885563897, 0.005130724321134039, 0.07899025047663599, 0.012786151546606561, 0.024044413985393476, 0.07163679154473357, 0.02837542455381481, 0.041363400378031656, 0.03748793118575122, 0.04447024948603939, 0.02360960264923051, 0.06710177942295559, 0.049680623415042646, 0.045649165913346224, 0.050099465588573366, 0.04272268466593232, 0.03781927043746691, 0.015437761703651631, 0.017449400293116923, 0.06688307592412457, 0.0328743590216618, 0.013308243160281563, 0.03914159577107057, 0.03653482061054092, 0.12930842698551714, 0.0665234237385448, 0.05273151087749284, 0.0302007571735885, 0.06133417133241892, 0.03506515298795421, 0.023834696039557457, 0.03816469194134697, 0.00647556827061635, 0.0057881716111296555, 0.007416618946081144, 0.041909609935828485, 0.021604276953439694, 0.006760714859410655, 0.0364914012607187, 0.05666697157721501, 0.04227798977808561, 0.037580447315122, 0.006161032633826835, 0.016819370721350424, 0.03391822683624923, 0.012495603514253162, 0.028093206201447174, 0.030992697393230628, 0.03814530333329458, 0.018328080877836328, 0.018873153094318695, 0.029869249083276372, 0.027280461727059446, 0.013809303236484993, 0.0749240827281028, 0.049117804592242464, 0.057205856137443334, 0.06845803945907392, 0.0297023679013364, 0.015166383345786016, 0.030052359179535415, 0.029153534851502627, 0.05706628413463477, 0.08334352547535673, 0.044455139359342866, 0.0436896993778646, 0.026833308475033846, 0.013245142981759273, 0.04630900570191443, 0.03631872576079331, 0.07039673699182458, 0.016573139109823387, 0.10546383811742999, 0.049544242647243664, 0.010850757498701569, 0.01541989913675934, 0.08063317247433588, 0.05033220681070816, 0.0618406425928697, 0.05365431585232727, 0.012011937524221139, 0.03955855288950261, 0.11011213166057132, 0.039114945248002186, 0.09412947678356431, 0.06356842175591737, 0.01067479057383025, 0.031040018584462814, 0.011284314605291001, 0.06672031551715918, 0.0332197063107742, 0.04451995853742119, 0.048132796509889886, 0.07778300627251156, 0.011277746598352678, 0.01992981182411313, 0.03186631467542611, 0.08151427246048115, 0.0407606057706289, 0.060409633442759514, 0.03636258297774475, 0.02353487394429976, 0.024368272388528567, 0.017894718585012015, 0.02932819745183224, 0.04669153087888844, 0.062079436029307544, 0.10085519010317512, 0.0360019993968308, 0.01053925492669805, 0.08229252562159672, 0.03776790639676619, 0.0545433271327056, 0.03917162677680608, 0.05176871898584068, 0.1286305789835751, 0.035164931032340974, 0.08924062349251471, 0.04025896589155309, 0.035071405582129955, 0.024627727216284256, 0.03600018113502301, 0.10531563122640364, 0.017004267538140994, 0.04781001422088593, 0.03601898344641086, 0.014699182829644997, 0.007996990952960914, 0.008583710641687503, 0.03155419704853557, 0.06182487937621772, 0.04205086290312465, 0.031238249939633533, 0.13607267261249945, 0.15442127943970263, 0.22651565697742626, 0.23781276249792427, 0.1643633865751326, 0.11478329077363014, 0.13589092064648867, 0.19606133020715788, 0.10950690280878916, 0.05486759000632446, 0.13048308348516002, 0.11124129450763576, 0.12826229562051594, 0.08695455631823279, 0.0820727385871578, 0.08847348770359531, 0.09560075486660935, 0.10216563736321405, 0.07967278143041767, 0.09478424399276264, 0.18779698148136958, 0.1393849667510949, 0.13761978334514424, 0.17193716688780114, 0.0661272430443205, 0.11512599972775206, 0.1659408214618452, 0.11295256088487804, 0.16539277508854866, 0.11808874231064692, 0.2051589178154245, 0.19117421354167163, 0.12680158572038636, 0.13214978389441967, 0.09188445779727772, 0.09002304010209627, 0.08237923815613613, 0.15954472561134025, 0.13940239237854257, 0.09786993818124756, 0.18609796796226874, 0.13988548598717898, 0.12348345087957568, 0.1744908228283748, 0.08075155987171456, 0.10140783779206686, 0.24354894063435495, 0.11071937173255719, 0.16662448790157214, 0.1487911690492183, 0.11521584412548691, 0.10649630654370412, 0.08451978501398116, 0.08698960053152405, 0.19169667066307738, 0.1333486195653677, 0.1465619058581069, 0.19727241131477058, 0.11779482214478776, 0.1497354925959371, 0.12786199600668624, 0.14477217220701277, 0.16218001779634506, 0.13302875391673297, 0.17231882375199348, 0.159796773805283, 0.09533189702779055, 0.2495331148384139, 0.12720292434096336, 0.12217201656312682, 0.1507507506175898, 0.0967057236994151, 0.14357384119648486, 0.11901546211447567, 0.15289217320969328, 0.23653758951695636, 0.15370230161352083, 0.24024991609621793, 0.16932072525378317, 0.19195913861040026, 0.18595149769680575, 0.11689005506923422, 0.10618793676258065, 0.20585344929713756, 0.18183624430093914, 0.10785800652229227, 0.10318172659026459, 0.13297384983161464, 0.11565422333660536, 0.1309750828659162, 0.17997539805946872, 0.18900668219430372, 0.10123316591489129, 0.16989719588309526, 0.16246886167209595, 0.15774436440551654, 0.07772029479383491, 0.18780800979584455, 0.08053093421040103, 0.12010271588223986, 0.1555996318347752, 0.08701892278622836, 0.12811883847462013, 0.11334451133734547, 0.13676966802449897, 0.12945687136380002, 0.18254996772157028, 0.11220389715163037, 0.12881816423032433, 0.08303010166855529, 0.1567191319190897, 0.2010580917703919, 0.27481986733619124, 0.1672167662763968, 0.12634712416911498, 0.2696128701791167, 0.14863665390294045, 0.16832344204885885, 0.26081883581355214, 0.24876327021047473, 0.12387140857754275, 0.1213559287134558, 0.09824434426263906, 0.08756460912991315, 0.1079051403212361, 0.30453026527538896, 0.11411389583372511, 0.14732501178514212, 0.25213891407474875, 0.21094118332257494, 0.30782314483076334, 0.29688160226214677, 0.11064443708164617, 0.08595123203122057, 0.14816856652032584, 0.1565540485898964, 0.20006661216029897, 0.11563802225282416, 0.14697284786961973, 0.15073814895004034, 0.15006720292149112, 0.16142954322276637, 0.183462482818868, 0.14578585687559098, 0.14140832849079743, 0.15500074834562838, 0.13334398856386542, 0.0883137849450577, 0.09279334379243664, 0.1619225667673163, 0.24717198684811592, 0.1504726381972432, 0.1498786677257158, 0.17948381428141147, 0.1391573203727603, 0.1252456137444824, 0.10839313952601515, 0.14439413702348247, 0.17778267821995541, 0.15313175332266837, 0.1766866893740371, 0.16675535822287202, 0.1436260438640602, 0.09827365167438984, 0.18444202869432047, 0.11263916676398367, 0.15250049735186622, 0.14946307986974716, 0.10220046635367908, 0.10613118472974747, 0.11384931276552379, 0.06888918273034506, 0.12012218983727507, 0.10048151132650673, 0.13038627774221823, 0.09184910930343904], [0.01938572480867151, 0.02861756507627433, 0.04036485181131866, 0.05743935806094669, 0.048113663942785934, 0.05678171874023974, 0.03395711537450552, 0.011675072055368219, 0.025799984723562375, 0.03603869859944098, 0.029486991079465952, 0.04564220827887766, 0.05391290978877805, 0.06110452115535736, 0.036858730964013375, 0.06651449570199475, 0.018371882433712017, 0.029311656835488975, 0.054855556081747636, 0.028711960694636218, 0.0172007529909024, 0.04501258874370251, 0.029739002166024875, 0.07022657737252302, 0.014446928689721972, 0.05956524379143957, 0.1263866657973267, 0.05551361842663027, 0.048253440036205575, 0.0658033623767551, 0.026675551998778246, 0.005096453796795686, 0.07368493359535933, 0.06175804897793569, 0.09409931590198539, 0.033498045086162165, 0.05740643267927226, 0.023317860686802305, 0.0549090352433268, 0.04046174290124327, 0.07229310242109932, 0.04957264092809055, 0.03305557293060701, 0.056047196630970575, 0.028619967779377475, 0.03240331418055575, 0.007862827351345913, 0.015072167698235717, 0.012297479770495556, 0.018601454685267527, 0.0063473098452959675, 0.029806155398546252, 0.014496424373646732, 0.04072693453053944, 0.06648929236689582, 0.0683432217920199, 0.0869455689098686, 0.06475350543041714, 0.020764575820066966, 0.028605380866792984, 0.02511998449335806, 0.06447335210395977, 0.03230657894164324, 0.08714056821190752, 0.06088696056394838, 0.09729793528094888, 0.01688816410023719, 0.04185176323517226, 0.030394095920200925, 0.02364680836763, 0.02876414480851963, 0.06402932514902204, 0.011598521377891302, 0.0404902636364568, 0.05286588042508811, 0.05517411926120985, 0.030466896896541584, 0.007296218936971854, 0.0580028336844407, 0.07423666844260879, 0.02077517183352029, 0.008159066728694597, 0.06060819505364634, 0.04750447202241048, 0.04495746943575796, 0.06936236866749823, 0.039902582866488956, 0.0149764065281488, 0.032261200321954675, 0.06158879477879964, 0.027726993430405855, 0.09133891988312826, 0.02353076430154033, 0.017243656548089348, 0.026070315725519322, 0.0069267193794075865, 0.0266494246898219, 0.045706671226071194, 0.056351280509261414, 0.03148914038320072, 0.008954474633355858, 0.02969533234136179, 0.03628273530921433, 0.07579880024422891, 0.033430086623411626, 0.07076757334289141, 0.05089773818326648, 0.10833882915903814, 0.03575784765416756, 0.1115307692089118, 0.024388213896600064, 0.02018755785684334, 0.06514107721159235, 0.06520015958813019, 0.13089381769532338, 0.042551322767394595, 0.025602473251638003, 0.0568066474806983, 0.005994231696604402, 0.04005129812867381, 0.051277402380947024, 0.0809645488334354, 0.07918297880678438, 0.028034485621901695, 0.006015302196828998, 0.0062851990423951065, 0.03796067554503679, 0.0494176174106542, 0.02583777859399561, 0.07014989867457189, 0.1239231214276515, 0.03728316893102601, 0.03790691065660212, 0.03215703247406054, 0.04504969241679646, 0.062477553728967905, 0.02025587255047867, 0.047182031121337786, 0.038137774245115, 0.0783848509308882, 0.03772066869714763, 0.03683469651150517, 0.04423656202561688, 0.07107079261913896, 0.007379818625850021, 0.0035795443000097293, 0.05609750311123207, 0.0021418041023935075, 0.07528633243055083, 0.06557135217008181, 0.03225411652238108, 0.05004628328606486, 0.050184879364678636, 0.024202678832807578, 0.05375698827265296, 0.031933787031448446, 0.025277457098127343, 0.008171081171894912, 0.03831092471955344, 0.03192224663507659, 0.06973451861995272, 0.019814691731880885, 0.03033622881048359, 0.026272810719092377, 0.02831427158525912, 0.10920529399299994, 0.08756735507631674, 0.01818835487938486, 0.009874738680082373, 0.01784114294423489, 0.03461941909336019, 0.03386020573088899, 0.05118848566780798, 0.028214755147928372, 0.027801197065855376, 0.032153499851119705, 0.04779349030286539, 0.06296394247328863, 0.011482038516987814, 0.03454644371231552, 0.026770543190650642, 0.03296952090749983, 0.021109227345732506, 0.007732579042567522, 0.012157455057604238, 0.018850239284802228, 0.04557320338790305, 0.03182865068083629, 0.02225288248155266, 0.01272831876121927, 0.03916492518328596, 0.0062632528079120675, 0.01758186066581402, 0.07302341284230351, 0.028755218627338763, 0.05725285634980537, 0.018726736634562258, 0.05806515924632549, 0.09629104868508875, 0.03649674843472894, 0.006324513851723168, 0.022912570129847154, 0.07262441940838471, 0.04251660509908106, 0.024545463857066352, 0.034492689956096, 0.09604372055036947, 0.030765327464905567, 0.019681754529301543, 0.04167492799751926, 0.07781556429108605, 0.012896693515358493, 0.02982800237077754, 0.008040478023758624, 0.06527844132506289, 0.0411249854369089, 0.04563998183584772, 0.049507202056702226, 0.029352682759054005, 0.02236331405583769, 0.05783196902484633, 0.020292022563808132, 0.03121401881799102, 0.020392644801177084, 0.03745795584109146, 0.0377204312098911, 0.008557393157389015, 0.03238403318391647, 0.0202045196419931, 0.038864693051436916, 0.06180687116284389, 0.03708959084178787, 0.04664204076107126, 0.01745015357300872, 0.01772917697962839, 0.019663076527649537, 0.04440675504156388, 0.058694203617051244, 0.06454985268646851, 0.04587865281791892, 0.035194702286389656, 0.004686603670052136, 0.02260036901134299, 0.02439675972709665, 0.07797254336765036, 0.04023927300295327, 0.01576767139340518, 0.024863945400284138, 0.021704418650188018, 0.03476827536360361, 0.010357003866374725, 0.015699464311182965, 0.022547140324604698, 0.020997990541218314, 0.07101331328158267, 0.03624916425906122, 0.005357660093068262, 0.03795800752413925, 0.057502448034938425, 0.05123327056935523, 0.04434143491380382, 0.08622072811704129, 0.08123902473016642, 0.04276037463569082, 0.02791149319818942, 0.01791848029824905, 0.04566099574731197, 0.11139405076391995, 0.029668333008885384, 0.053920772843412124, 0.022627088183071464, 0.01685800321865827, 0.05958025372819975, 0.05419982779130805, 0.011438129349699011, 0.026345520782342646, 0.02318886799912434, 0.0023035375625113375, 0.027494541645864956, 0.040636158737470396, 0.036168704318697564, 0.04384472660603933, 0.02614153036120115, 0.09271881732274778, 0.02655871197930537, 0.05341177085938398, 0.05445079987111967, 0.03625926488894038, 0.020090373618586455, 0.022782813030062243, 0.12608899036422372, 0.03849036860628985, 0.015481892587558832, 0.04028169045341201, 0.06362516636727378, 0.024993375955091324, 0.09193782563670538, 0.025378949503647164, 0.06483571312855929, 0.03311481857963372, 0.03413439219002612, 0.04470277177460957, 0.08438102566287853, 0.027849028483615257, 0.02741761432844214, 0.0412253980175592, 0.08430852525634691, 0.07129984165658243, 0.03400413042982109, 0.017634807336435188, 0.04827010496228468, 0.015988358281902038, 0.03844601786113344, 0.033412045013392344, 0.011549687133083353, 0.027719141507986933, 0.05498523896676488, 0.022703709364577662, 0.043796327445306815, 0.04314191646699328, 0.030646034647361375, 0.04647163252229802, 0.07712920385529287, 0.04905470348603558, 0.049341031481162645, 0.034244760681758635, 0.05123497008753475, 0.009307262880611233, 0.09658346971264109, 0.024169497410184704, 0.03257400443544611, 0.028583381754287984, 0.033963226960622706, 0.015455029624718009, 0.0841203388699796, 0.08549503385438584, 0.035235360846854746, 0.08405577202211134, 0.02297700153576443, 0.04070903392857872, 0.0317532892950112, 0.06882869769469835, 0.07808882306562737, 0.019018283783225343, 0.03587992352549918, 0.038666495092911646, 0.014768124638067093, 0.03624006923928391, 0.03590449232433457, 0.08142643928295001, 0.006659666350969928, 0.027590902100200765, 0.1475715235574171, 0.11931550499866717, 0.1149027023348026, 0.15493245591642335, 0.20483507425524294, 0.10897841202677228, 0.14679645420983434, 0.0741149191162549, 0.08791789368842728, 0.1265556231373921, 0.16127553273690864, 0.12485778221162036, 0.14995490113506094, 0.15410070132929832, 0.14144718734314665, 0.16054148931289092, 0.13868046080460772, 0.15405704820295796, 0.127288167423103, 0.0984336512919981, 0.10018113447586074, 0.14808739040745422, 0.13096509355818853, 0.1980193384224549, 0.11075259768404067, 0.10507502694963478, 0.18798336444888264, 0.0917353825934697, 0.1262764271814376, 0.08850674334098585, 0.18036472873063758, 0.1623729316634126, 0.15876097313594073, 0.13640355173265561, 0.16961767338216305, 0.11527827358804643, 0.1067659436375834, 0.12465242994949222, 0.13915124960476533, 0.1739291357807815, 0.15897588426014408, 0.1416087825782597, 0.1255451000179164, 0.11419901275075972, 0.1963038937537931, 0.10427485816762783, 0.09757948384503834, 0.15985826816176996, 0.10379686311352998, 0.08795763569651172, 0.07820410828571767, 0.2229939732933417, 0.125320244114846, 0.07723670394625515, 0.15888173540588468, 0.14897593413479626, 0.17409586667781696, 0.15891560702584684, 0.11561955761862919, 0.12572152336360887, 0.1904317838489078, 0.16670159704517573, 0.12624093767954037, 0.17231174366315827, 0.11786673625465482, 0.23722569399978966, 0.17312332667643204, 0.1207040113513358, 0.14842474105535075, 0.1325085826101713, 0.06342077147564851, 0.10263724252581596, 0.06961202714592218, 0.12637888808967546, 0.11655703114229254, 0.134309611748904, 0.10383401502622291, 0.12648574251215905, 0.17369426088407636, 0.20370758866192773, 0.14064678107388318, 0.07460210195858963, 0.15784415358211845, 0.17854872305179015, 0.18533463939093053, 0.195114498201292, 0.23597012856043875, 0.09188839117996395, 0.08902145244064741, 0.1256225653924048, 0.09197858438710682, 0.19736394780920818, 0.14250878506572917, 0.182285288174171, 0.1270186045439914, 0.16981057240627706, 0.08630739612272009, 0.13926889485446736, 0.12863342883065343, 0.1169317118183244, 0.18148592091165483, 0.10987727902829647, 0.15747612254926935, 0.148819652677048, 0.11014194373274222, 0.155616894189734, 0.06965337219298817, 0.2798604452982545, 0.12754517316352576, 0.19507602526573464, 0.1706509359064512, 0.09982511139241979, 0.09300605815951712, 0.12569146638270468, 0.2957091573625803, 0.18221374513814226, 0.09399168964591809, 0.09187120303977281, 0.13082672754535452, 0.22853754926472902, 0.3399747336516157, 0.16057709755841643, 0.23892815108411014, 0.13409529434284195, 0.09787202361621894, 0.13037772820098326, 0.11148875622893684, 0.12764175626216456, 0.11467613207059912, 0.1680282157030888, 0.3129617456579581, 0.2661202341550961, 0.17102193553000689, 0.29140722414013, 0.24965346150565892, 0.17916218232130632, 0.10417516547022387, 0.20980134839192033, 0.12700739811407402, 0.113024764432339, 0.1884046519990079, 0.220622603665106, 0.13105750578688458, 0.07844858657335863, 0.2230810420587659, 0.10693621457903646, 0.19203155738068745, 0.1379995106253773, 0.20789742789929733, 0.18715797748882324, 0.22624839475611225, 0.0725555926328525, 0.13752979051787406, 0.12747489177854732, 0.12704368913546205, 0.08059781655902043, 0.17128404724644497, 0.06360932151437737, 0.16658785549225286, 0.15052426198963076, 0.12168880421086214, 0.1640255015809089, 0.129375294491183, 0.09890005399938673, 0.13089939864585176, 0.16990945616271347, 0.15016344463219866, 0.0818878696009051, 0.1078222572687082, 0.13560915685957298, 0.1332679926417768, 0.15975938440533355, 0.1548511313740164, 0.12312974329688586, 0.08905583614250645, 0.11522025248268619], [0.017294510362262372, 0.07321677941945381, 0.045898341995780356, 0.08794809167739004, 0.012824956593249226, 0.02768001733784331, 0.012688624992733821, 0.020951320584572386, 0.09230555981048383, 0.009657595546741504, 0.027256605389993638, 0.007329965783355874, 0.10843112264410593, 0.043231801682850346, 0.05587809457210824, 0.02479675877111731, 0.06825879507232457, 0.03802236285991967, 0.025006187279359438, 0.047517786151729524, 0.04032165139506105, 0.03742974309716374, 0.041078834983636625, 0.028102939468226396, 0.03502820516587235, 0.06085607979912311, 0.06794529705075547, 0.0228715497723897, 0.04718366384622641, 0.03377057655598037, 0.07223579377750866, 0.015197609209280927, 0.025161166267935187, 0.019536935542419087, 0.04016730694274884, 0.0258297689651954, 0.07370908308075741, 0.07617169234436005, 0.06840251196990721, 0.03347781785123516, 0.027863453979080077, 0.050882316354545765, 0.04807523553608917, 0.02070370301225921, 0.026822337677003816, 0.06434521288610995, 0.023196204128907993, 0.04338034625106957, 0.027291226579109207, 0.022972459591983352, 0.03959522240620572, 0.045100477582309395, 0.031240457828971557, 0.06686858920147642, 0.03453736353549175, 0.05184802859730553, 0.011456049433036242, 0.15075658389832824, 0.04510945385845844, 0.016160883496922906, 0.03584731726732571, 0.02062116876913933, 0.019771027473325375, 0.037658591754734516, 0.07633857167093083, 0.059070906645501964, 0.030379898635146674, 0.020263063961465377, 0.04225392192893196, 0.04446380022272933, 0.05804137712402735, 0.030069953645579517, 0.1299734358326532, 0.06346780137391761, 0.021119172124599572, 0.018478029960533604, 0.02992651134263724, 0.04993857168301474, 0.04795782035216689, 0.010385939276602585, 0.022956798420636915, 0.0519706239720108, 0.05377343426516745, 0.036757008492713794, 0.01951832618942717, 0.014114023506408557, 0.02912815340096131, 0.061757462681271136, 0.10235630994429812, 0.01125512500948389, 0.018360694557486568, 0.06963383886613883, 0.031141922881943174, 0.06220973489689641, 0.002021926611632807, 0.05754700287070591, 0.010688819020288065, 0.10753247828688473, 0.06434162089135498, 0.018586043988761958, 0.035861592477886006, 0.020655558037105948, 0.06317847510217689, 0.01872389235359151, 0.06046221089491155, 0.03906405247107614, 0.027119523292640224, 0.010467605206940789, 0.017907745132106356, 0.0360557123349281, 0.014908416524122003, 0.029703035834245384, 0.053128340950934216, 0.06053072967915796, 0.03204657863534521, 0.0642948062159121, 0.013767549080512254, 0.014762345163035206, 0.026723871378635522, 0.07340786018176004, 0.03220573591534048, 0.08885711125913076, 0.014844628003629623, 0.00566339756915113, 0.029293837869772688, 0.006365943318087375, 0.05496689678693656, 0.09383456956129521, 0.02339881601074012, 0.016673297504894435, 0.04058849059219938, 0.005203652390264324, 0.05405229996540584, 0.04258205881342292, 0.0486957414977951, 0.045763946473016404, 0.06810899256379344, 0.07817500867531635, 0.031328198238043115, 0.037865591584704816, 0.04647183290217072, 0.047784896232769825, 0.019705859485839028, 0.022857484218548052, 0.0441860959836049, 0.06061094471078832, 0.057244369891122915, 0.015076810759637738, 0.042149913642788306, 0.01821192363422597, 0.016962371446425095, 0.0398221674549859, 0.05689203899237327, 0.04317177677876316, 0.07090803221217357, 0.023800635171937756, 0.06278357832343318, 0.013342464517336339, 0.03491899813525379, 0.050638424363569357, 0.05528495159524027, 0.04500396127696149, 0.05260713063762523, 0.04136738571105525, 0.013269569844851503, 0.06858567401650362, 0.0648615621321369, 0.034927696106024086, 0.044323601105134, 0.03139637934509665, 0.06326944756438024, 0.05556490825256333, 0.04467989878321532, 0.0369899018551223, 0.06833108025602996, 0.06027923067449592, 0.030565890119760297, 0.06601240311283618, 0.03507203269691672, 0.015636242605978623, 0.00557101224330836, 0.07371635612798855, 0.01909081758640241, 0.02709445725486148, 0.05571106681600213, 0.04223224379529711, 0.016799885634100065, 0.033745176551747136, 0.04853351172641851, 0.05524825239263009, 0.045853779738536105, 0.05528573085030075, 0.06268064244068228, 0.050132216565543786, 0.035278461073176004, 0.05755337420850992, 0.02325058314454509, 0.10263461532304063, 0.08509068953571841, 0.015030588874651585, 0.03533499788318295, 0.040938290767371655, 0.07937575166579336, 0.008587184820498805, 0.036155289999442175, 0.04135673589189537, 0.025110152892011683, 0.006956607057873043, 0.07192740915343165, 0.0222086096619023, 0.03849552653264254, 0.03430559081607498, 0.021503587922779843, 0.09316677766037174, 0.06906584356329404, 0.036087928965571336, 0.05113298786454834, 0.02707895007915795, 0.02198292626417242, 0.020293586640036665, 0.0523275450541405, 0.043444549446576275, 0.062373215187108144, 0.032571162009844556, 0.04041962973133195, 0.056955388718051836, 0.02247681812150404, 0.015241992423398187, 0.045679074464715086, 0.025733953989401925, 0.008720482892385917, 0.0344629224127857, 0.02637709359987639, 0.06280898945988156, 0.026097858681168873, 0.05108358309371397, 0.06027651812473778, 0.0745414017001167, 0.021852673780813348, 0.03799239122599829, 0.021607685266644694, 0.06697513934341259, 0.08032939658733085, 0.038624493245151825, 0.10146795917535201, 0.0324636359437136, 0.05730593475163914, 0.027086436493846122, 0.04699852397607174, 0.020376931679493282, 0.007019081049293163, 0.01974119499209337, 0.01454788396586082, 0.003869611095979053, 0.001934732608788181, 0.009484624115430051, 0.030968893006502185, 0.07280473902937956, 0.0478179218043806, 0.08052163510001265, 0.05414730971097015, 0.0624938883993309, 0.026706993085099384, 0.005932259118708316, 0.01957114669494331, 0.010290675345459022, 0.02885728990804637, 0.07103517695213668, 0.022264767976594158, 0.022235017131606583, 0.013044573861407116, 0.0317978626844706, 0.056416671141050756, 0.031243968187482096, 0.03234449526644312, 0.038777958252467215, 0.036086389009142295, 0.011128651913168142, 0.04546967007627245, 0.05437574647658039, 0.04222265524731483, 0.038493474494316615, 0.053236163876135834, 0.013246095713839168, 0.04852462821872905, 0.03609314626373816, 0.08199984484235756, 0.017596191537450068, 0.02321247386134928, 0.07382725525530986, 0.03703165508341044, 0.0931283863610588, 0.0682269866229035, 0.04485757635848131, 0.030536499216395896, 0.03982016736699734, 0.007990833910298534, 0.03728481649886817, 0.038661077414872125, 0.008896401577658253, 0.04347971982497256, 0.03458040067926049, 0.050643355934880674, 0.11328433800372295, 0.009714065563457552, 0.03168614719470497, 0.02045334691501921, 0.04418764336151071, 0.0422332865127828, 0.04746447397337761, 0.04519835943938233, 0.02970063127577305, 0.034235728744533844, 0.03979382112447638, 0.02616819201648468, 0.14897596382070333, 0.01817492942791432, 0.051615595366456546, 0.031304041331168264, 0.029586477830889635, 0.023814485502953175, 0.07298637225176208, 0.0193628648048616, 0.008309543663926888, 0.048405160996480845, 0.008692698738741456, 0.03836399941064883, 0.019927420253225137, 0.00892468668098445, 0.04687707521952689, 0.04743973819131497, 0.018031242216238752, 0.08392674964852631, 0.04773368433234282, 0.0516259186406387, 0.023201714575407095, 0.10184720405959524, 0.04350573210103903, 0.0660329828679096, 0.01745304609357845, 0.04637904217815958, 0.03682599854073487, 0.025591014491510577, 0.023834799940232188, 0.036560669614118524, 0.006843662849860266, 0.002260304909214028, 0.02750784649833804, 0.032417259135399945, 0.010164092782360967, 0.03423601447138935, 0.038149062311276793, 0.14791973924729973, 0.12380455591483042, 0.15006349218310788, 0.19812923565041274, 0.13928262458648533, 0.11242570282774977, 0.0692343630362302, 0.07691359511227347, 0.1510468972264789, 0.13215422193752602, 0.09528060720185749, 0.1156167894077953, 0.2516175404889509, 0.09368171682581306, 0.11505097601911984, 0.17488793120719492, 0.18837189360056072, 0.1555238733999431, 0.20456242404179648, 0.1956067795981653, 0.09828344060224481, 0.13043258775724098, 0.1257863870705478, 0.12922929920023307, 0.13441311166388914, 0.16482192993862554, 0.16913481726078317, 0.06068340429919772, 0.08545676872017793, 0.13276765152113512, 0.16607281984761357, 0.08075866222498007, 0.18347769684623927, 0.09672240717918612, 0.10209549698629417, 0.11707898360327817, 0.15991600725101307, 0.23442327015800402, 0.15863645559875295, 0.13405986421275884, 0.1344418476219289, 0.189380427764263, 0.16585790872341022, 0.09900835560983978, 0.1906617754139006, 0.16358276596292853, 0.1100769241747912, 0.10812728738528676, 0.07808568378095515, 0.12205136561533436, 0.13338428718270734, 0.10758586096926592, 0.12142779829446226, 0.12416551428032108, 0.10490157961612567, 0.15898379555437714, 0.18176663084886968, 0.20064594747964293, 0.17636815959122032, 0.15137785056140274, 0.13817925879266113, 0.13614105409942567, 0.10524520141188987, 0.14387245173566043, 0.21652847179211676, 0.19533932441845536, 0.28765246155671775, 0.16257564187981188, 0.2755983208771795, 0.08953587952419184, 0.0846656912472099, 0.11458338587544858, 0.23725119419395924, 0.09815213241381571, 0.0772867989144288, 0.10188287167693488, 0.1991025623283349, 0.08642738655908033, 0.11056945048039779, 0.0963712896918878, 0.1438199818949215, 0.14152117946650833, 0.13435277505777776, 0.16807145322673023, 0.12769437453243881, 0.15209132165182382, 0.10097176666022278, 0.07900325290393084, 0.20264848455553874, 0.09971577819669619, 0.08423177234362811, 0.1432928047142923, 0.050046754549839534, 0.0885345293499995, 0.11174582134117372, 0.15812682278919965, 0.21358667261665687, 0.2860040031373501, 0.12367925912258215, 0.14628677687142044, 0.12558617047034204, 0.13142785232048482, 0.22914597677299753, 0.12113570381188765, 0.10658464438165538, 0.16768354747910053, 0.08657204598421231, 0.1336774800438434, 0.1138860045466572, 0.09031972847878933, 0.1384471741039306, 0.1100247363501694, 0.13903192710131407, 0.1378695308812894, 0.1068949511682149, 0.18693709949729964, 0.10764898062916473, 0.11401354262488894, 0.1226694781507831, 0.16503605438629165, 0.0798946910072118, 0.12072578596416861, 0.09930850981618278, 0.20869744825176895, 0.15571834577713162, 0.13559931598138064, 0.1895029711886309, 0.1993034320184961, 0.07414386287564412, 0.1686920371139422, 0.13478614477207884, 0.12505329359555617, 0.12359659129288048, 0.2653122728224844, 0.08619418149464764, 0.09045001250342466, 0.1151677752204705, 0.12125374982133508, 0.07785664216498844, 0.16598601825535297, 0.1572178551577963, 0.12355180268059485, 0.11993333551799878, 0.16778479126514867, 0.10962995831505395, 0.11522551430971362, 0.09577517441357486, 0.05893979512620717, 0.10056297687697224, 0.11367806218913756, 0.12507883831858635, 0.10082410153700039, 0.16033149120630696, 0.13334171759197488, 0.11178350017871708, 0.08558156827348284, 0.22452894248999655, 0.10914823025814258, 0.12888528406620026, 0.19659695302834734, 0.1437607585103251, 0.11851358474814333, 0.1303824779461138, 0.1311287222779356, 0.21073879965115339, 0.2293814008589834, 0.10919998763711192, 0.0820964205195196, 0.12097324026399292, 0.17240235989447683, 0.09444856317713857, 0.14439409249462187, 0.1361163257388398, 0.09374359709909186, 0.12646741146454588, 0.09662077747634612], [0.053948443819535896, 0.05924316654272843, 0.05474255667650141, 0.034870316958404146, 0.03040010360564338, 0.058445316972211, 0.012646111063077115, 0.01142965958933928, 0.016681258894095663, 0.046946098664193414, 0.0364054642705014, 0.011883471761393594, 0.004455269745449186, 0.023954233765834942, 0.02748546889051795, 0.005007719837522018, 0.022446965231210925, 0.0408311172213871, 0.014645660994574428, 0.03777850426558871, 0.07358505536103621, 0.0394819780922262, 0.04815188825887162, 0.038264636968960986, 0.03440677151957061, 0.02867775325285038, 0.07213644246803597, 0.04078816171386279, 0.09303959581302479, 0.058130401448579505, 0.06912851793458685, 0.059614800702547655, 0.02217932265921263, 0.020043952281412203, 0.03775157543714158, 0.03136878258374054, 0.05465193302370608, 0.03547852553310804, 0.016276693786494434, 0.039413715348928235, 0.04374940886918921, 0.04734361522423569, 0.024835767908371054, 0.024384395546803717, 0.02677532633242663, 0.015769409874337725, 0.031235878777806647, 0.031503307982347906, 0.09229250543285161, 0.07308477361220866, 0.021267490337777417, 0.04257479318766855, 0.07566855332697742, 0.08348753923201002, 0.04911116608127486, 0.12511173030361533, 0.012807163602701621, 0.023877397361502517, 0.05543683211726602, 0.011293795541860163, 0.016665401053614914, 0.02515021216822788, 0.006682325974907144, 0.022088463374529965, 0.02934688287496101, 0.05557041869906243, 0.0500627849396551, 0.09077188195078634, 0.03386384225450456, 0.010105470537382644, 0.024419092806056142, 0.04245742624334525, 0.062020554032642394, 0.03937640016374644, 0.036996280614403076, 0.03731783464900218, 0.01017141777992947, 0.07839086232706904, 0.03337039197504055, 0.1083800925698597, 0.11350858534569852, 0.015160304228629684, 0.01723843739455333, 0.06374002856318839, 0.02638209938595537, 0.03876495211443398, 0.03480472594674211, 0.03579645046556834, 0.040808351841405965, 0.048216603536275215, 0.012171536382084014, 0.031672358090872876, 0.016527014631719794, 0.05570603134401608, 0.020066537690581754, 0.022321145224850625, 0.07349682142375968, 0.06463280253228731, 0.03569551838154439, 0.0030177702819855767, 0.04393072296807077, 0.06214554654434323, 0.041755020574782975, 0.010044222944998182, 0.02660283451405121, 0.040550192061346024, 0.014603265808545984, 0.05233331525232643, 0.014789808337809518, 0.04026711467304267, 0.05392090642999392, 0.03470556017418858, 0.01628548081498593, 0.054155647740117274, 0.022512001487484667, 0.06778237337130122, 0.053451093554031104, 0.07360099669313058, 0.016088663251139224, 0.06670086382655427, 0.11104472185252234, 0.03312313063361216, 0.08331419579917565, 0.02048806087259436, 0.0175776601099642, 0.026966921031998936, 0.004155129454375128, 0.04484740893531125, 0.004773130667672376, 0.05487317466759123, 0.017086978041334078, 0.03980086781666614, 0.014904837516951375, 0.03271354675234761, 0.06642109641688876, 0.006474051506302203, 0.0600264885724755, 0.047285312102758326, 0.04631788920960389, 0.04853364902373869, 0.02636208366311621, 0.012125269968237262, 0.026418228990223724, 0.05235831078607589, 0.05005832092138007, 0.05471162396133877, 0.042709585759439506, 0.05958444315183442, 0.06729277112754062, 0.018990789067174774, 0.04491354542551562, 0.03347338722960558, 0.04935982637107372, 0.05626005200610962, 0.10950745941954665, 0.027382195330574177, 0.02886769852921134, 0.04034916652017273, 0.01915134158480214, 0.011524920737429056, 0.00782741484727012, 0.017836510087363422, 0.023922905857034493, 0.03180079787853174, 0.027425135995144956, 0.01497956251114374, 0.04895154866972007, 0.016999703329929616, 0.027089455179520883, 0.04161577140621375, 0.0433407897799043, 0.07139361201552674, 0.16625253832899034, 0.008934959860198433, 0.01178798889668542, 0.04056315738125704, 0.022814810727140866, 0.02784039174002828, 0.05735520593589172, 0.039049335682648234, 0.02204091211751802, 0.04123311264265794, 0.02565345694165444, 0.04644510816433467, 0.054304719233186916, 0.004545095589492121, 0.05042567659984343, 0.03172741060552653, 0.03994310784037225, 0.03094351526669925, 0.011319388504489325, 0.021356227080104873, 0.010442058628541417, 0.0015395592640743416, 0.05732655532483477, 0.09655105270212516, 0.10921624809270725, 0.02780251066724304, 0.01887105652713217, 0.018246426079713274, 0.015133957986108726, 0.039710878700134344, 0.090136150829494, 0.08287735283374786, 0.06833132516476326, 0.03958992718253285, 0.03464419198280666, 0.030532048185705207, 0.027097821039205883, 0.07418489622068591, 0.03640389462816529, 0.01011928839943721, 0.033508234773762524, 0.022859816417621914, 0.03107260443357518, 0.028341233810351696, 0.0047004976022435585, 0.012108207993151154, 0.030913775553926826, 0.08272736478829756, 0.055000148713588715, 0.05311078544764314, 0.10594345105346292, 0.047660809141234495, 0.05483397813804913, 0.01879604209534591, 0.02736100144829834, 0.038546938812942244, 0.033016098095686175, 0.06388712223269977, 0.026431784317537677, 0.01988772834010888, 0.07082062205881812, 0.02426402847049758, 0.01633224168472225, 0.07993805469595827, 0.028287259265198372, 0.03472187258012127, 0.05334889981895685, 0.011785745755332755, 0.024298369498865213, 0.06483417688286863, 0.02868175713956589, 0.045099330964148976, 0.03378836212505121, 0.0460281584673794, 0.037650086742360145, 0.04862469941144809, 0.03769917238969356, 0.046821210053167306, 0.04490377505135257, 0.06712935020914301, 0.014039622274140129, 0.07443388676620089, 0.06603881614864804, 0.025488579558441415, 0.01825203486077953, 0.037855446425965056, 0.025674168427940458, 0.07305990424356423, 0.029175591480452567, 0.06660480765276588, 0.04317241131502669, 0.022548351880686823, 0.04319211162510328, 0.03756292520847637, 0.03666287077066954, 0.006628693745369674, 0.02843167934770463, 0.051629952213261276, 0.03907800113665871, 0.057755776433623396, 0.12969204311957583, 0.03798522950091865, 0.02055857788946014, 0.0034163866121161846, 0.059093434538226575, 0.038078190918895416, 0.03141990542644635, 0.04939739388646558, 0.007809786984580569, 0.07277988450368866, 0.02899211958720116, 0.06719563141814433, 0.027294349165458698, 0.04328396724304184, 0.04012979508843273, 0.0490911503584357, 0.08512924410752021, 0.05212893520365469, 0.08380723418667912, 0.0686582041089423, 0.017442962162022013, 0.03725965027115308, 0.01236493913893355, 0.0369091858738102, 0.04818841305677779, 0.02190104882174637, 0.03167626549839042, 0.0776708974444773, 0.0222681892773835, 0.022779844439355657, 0.01318464588621282, 0.04556134757876862, 0.06290740566328168, 0.0740662045427598, 0.01581561784405494, 0.06240117931156419, 0.02847823427146068, 0.0604559805651661, 0.04835677667870186, 0.02615571465867106, 0.0627035228535533, 0.05213726581132505, 0.0281638456726796, 0.03522308572428301, 0.07283987972186878, 0.05498226666531991, 0.06424071849323809, 0.07785980371409096, 0.06994561510509811, 0.03240457212086767, 0.04222510804538615, 0.020112960883125197, 0.05186289381526876, 0.022860502904222813, 0.058664079842856154, 0.04846589465159923, 0.022021252625563648, 0.03726629620359745, 0.05275711497233715, 0.04206729405268561, 0.07840292222681455, 0.06388997950125486, 0.03741672211617697, 0.014917854787199758, 0.044167809464852326, 0.036732840453623794, 0.03118867076409515, 0.04407181637361646, 0.036640944017563015, 0.04013680467323866, 0.026952577172778547, 0.04995351853722241, 0.01960131685336819, 0.054499922625836916, 0.07604520811582915, 0.11671244428725913, 0.07445423645549454, 0.004849136794291553, 0.04609275500115473, 0.019502472059684806, 0.1562812499469146, 0.13990467792609707, 0.13026897388044745, 0.19688567816046998, 0.22177416452905163, 0.1820409731590189, 0.1117777411127463, 0.17049138899892569, 0.16110423021018505, 0.12113728458643891, 0.14634947350714356, 0.08406105611356907, 0.08681866907863878, 0.1068862309330143, 0.15139909082790837, 0.09150453755864874, 0.19495726679451764, 0.14474603376584128, 0.1100896074785851, 0.326273589162156, 0.30530589865520597, 0.1389477081829682, 0.1818676371476613, 0.10606908181216568, 0.11244499866734259, 0.12891060614492744, 0.1314720546361059, 0.2072925478569232, 0.2700197452213615, 0.08944283646997064, 0.09654556080931798, 0.16974113706965, 0.07269819630892016, 0.15348247747169808, 0.1695263001602143, 0.08454024602542631, 0.10986580542521551, 0.07044089477858506, 0.09761101769981906, 0.18088688899297267, 0.1670523508801125, 0.11704359800205566, 0.11749276804039255, 0.132422374736052, 0.1986236247466877, 0.13030186586547643, 0.17620364029426128, 0.09726002637762576, 0.19400935125304386, 0.1412336269277148, 0.08601539069786668, 0.1024484698427841, 0.12837994087021798, 0.19140073185553774, 0.09563403276843019, 0.22998634027317166, 0.1254550478188321, 0.12045716561260633, 0.10612193756969646, 0.13938846968812868, 0.13563094631535932, 0.14697713748319075, 0.1769298911676742, 0.1005484010966029, 0.1760648883646354, 0.102753425744595, 0.2715350326616317, 0.2200262583210133, 0.1657571250689216, 0.1884622871875763, 0.07854847965063527, 0.21528259880142286, 0.17032200121320784, 0.1370063389185816, 0.10904329057666473, 0.19875128899002448, 0.11242412947467528, 0.1776740129571408, 0.15615995333064348, 0.19093199138296768, 0.20882871933281422, 0.1382116015884094, 0.12683357228524983, 0.23593037913087755, 0.10109162351000123, 0.17847072333097458, 0.1686474637244828, 0.09084141376661137, 0.12990405986784026, 0.09459923399845138, 0.09654032866819762, 0.0988787914684508, 0.0833903178863693, 0.14171326212817803, 0.2331695897737518, 0.12022590497508645, 0.24042020930210128, 0.2453543187584728, 0.0784830964403227, 0.10741333389887586, 0.13138869660906494, 0.10142909290152602, 0.1267340502818115, 0.14319875976070762, 0.06914930549100973, 0.11254860990447924, 0.10438948287628591, 0.16467048728372902, 0.11746026939363219, 0.12639327091164887, 0.264962365035899, 0.21254459337797016, 0.16644316638121381, 0.14718251943122596, 0.2174280141480267, 0.16838711831951514, 0.14562813565135002, 0.12475109106162563, 0.10073502155137248, 0.12439870450180024, 0.15336502518039197, 0.18475013872375712, 0.15793441358255222, 0.16251416236627847, 0.15885534463450313, 0.0897582492325455, 0.19633668183814734, 0.09471109049627557, 0.10800723757711239, 0.11298002777039073, 0.10639006810379215, 0.17887569847516716, 0.18305165955098346, 0.1315054958104156, 0.11797175015090033, 0.13158122455934063, 0.1498914771946147, 0.12066081093507819, 0.11147377226734534, 0.15766171884024516, 0.23697631753748283, 0.17008881841320544, 0.14971880911616609, 0.1474338848493062, 0.1467642598436214, 0.06614376325160265, 0.2015516348183155, 0.13342062273295596, 0.16399753745645285, 0.05014063252019696, 0.11447829034295864, 0.133610152406618, 0.2673124795546755, 0.18934044084744528, 0.11345169972628355, 0.08021101661142893, 0.18442659202264622, 0.13840700907167047, 0.0915801698283758, 0.11187739670276642, 0.13929633947554976, 0.17181664210511371, 0.13510661898180842, 0.14496992487693205, 0.16987415961921215, 0.11377340590115637, 0.14998461672803387, 0.07240494407596998, 0.17347057757433504, 0.19518955901730806, 0.20482578256633133, 0.20782723557204008, 0.19355266325874254, 0.10682864769478329, 0.09252757328795269, 0.13964749407023191], [0.02591632193798432, 0.04928480266244151, 0.06092431656725239, 0.03919220282114111, 0.03267551168391947, 0.010268768073729007, 0.0194122194807278, 0.023381837527267635, 0.02521645998058375, 0.020423438363650348, 0.0179866576945642, 0.05705771975044627, 0.06766195991076529, 0.011723858988261782, 0.037824209430254996, 0.04029378746054135, 0.04175001107796561, 0.04543167582596652, 0.036958442215109244, 0.015536188111582305, 0.029903050199209247, 0.059142308673472144, 0.034833306053769775, 0.03237120887206402, 0.024427519892924465, 0.019808199795079418, 0.037868504514335655, 0.045825674606021494, 0.03131196375761647, 0.07231202718685381, 0.01048659398293239, 0.043762073619291186, 0.037692055193474516, 0.04284086055122316, 0.03993218713731039, 0.01672658370807767, 0.09452594691538252, 0.014054902167117689, 0.05597078510618303, 0.021966096210235264, 0.043053203844465315, 0.027430472036940046, 0.09760075379745103, 0.006122951181168901, 0.04419068616698496, 0.10789133637445047, 0.031715862787677906, 0.03900852498190943, 0.03910223596903961, 0.016079425367934164, 0.03851841436699033, 0.010860127113119233, 0.02535026735131396, 0.09951175437890925, 0.0455119316757191, 0.04301592576666735, 0.03709092299686745, 0.04505100972892251, 0.027709616042557172, 0.05119362875120714, 0.03176273683493491, 0.03465945796051528, 0.005118384724482894, 0.04927978203340899, 0.0303829024778679, 0.020002609089715406, 0.029364089568844065, 0.036506311007542536, 0.04378827885375358, 0.04642324449378066, 0.047048912092577666, 0.04646603672881611, 0.04060593848407734, 0.019842316323774867, 0.039028737373882905, 0.037962653368595056, 0.03575169524992816, 0.044672017174889334, 0.015796399929968175, 0.0460751438367879, 0.06048005212505814, 0.05836201831698418, 0.028106108438805677, 0.06307845585979521, 0.014066417516005458, 0.023992968308448326, 0.015671555847802665, 0.09394837048603222, 0.00813549333543051, 0.032339463505195454, 0.025551465441822074, 0.07128288358217105, 0.05087116929644253, 0.03549685286998283, 0.0009601821409432887, 0.07401305934763514, 0.022813814393884968, 0.03957916975195985, 0.017139416340796743, 0.030877508652338292, 0.08309425291372463, 0.030915326642571017, 0.05717277861549519, 0.07872895512264222, 0.013141971467121039, 0.029706861605518498, 0.011823507156805135, 0.027849729813169688, 0.013917034320911625, 0.018236857940792106, 0.07342891491134651, 0.020303180754126515, 0.10397541642305441, 0.027399201644584537, 0.04233962514263112, 0.024706860567675903, 0.038339297025231645, 0.01782217550498899, 0.0407687285769498, 0.06681173326796852, 0.019824230184894986, 0.05992161939502694, 0.013339262150111608, 0.05946614110143855, 0.08508605853421614, 0.039021909615257755, 0.04138723073992878, 0.10121683866600506, 0.016793069007690065, 0.0443676438590046, 0.05813102856336627, 0.015294073564291466, 0.04332316748332232, 0.02539670909754932, 0.020520368416327983, 0.03294946807727683, 0.08088574017165229, 0.03683347938931547, 0.012138964448240586, 0.00921267615922261, 0.055278758372878656, 0.03733400233613793, 0.004879889538642601, 0.031391774318763055, 0.010356219972891267, 0.10523072953219526, 0.02302009434060892, 0.046421923470916227, 0.05167224349861499, 0.10056530722067691, 0.02201643423177302, 0.0491698068799451, 0.03269620276114438, 0.015235899390972918, 0.05410494421084877, 0.012189308963570511, 0.011641274650173727, 0.09376529007568024, 0.0016067333694991248, 0.02413297817838611, 0.031236286959028803, 0.08063204440986738, 0.028313943184912205, 0.03693691251100972, 0.06528677564347163, 0.05686142911144998, 0.06021207002049778, 0.04859273511101492, 0.057547856340534054, 0.024153086669684853, 0.04171602813585196, 0.061029541975585744, 0.019878913481079508, 0.07076331341522746, 0.06629540628637187, 0.05969444056972861, 0.02844258149707457, 0.033336535198031925, 0.04555975567200221, 0.039783508982509375, 0.0014796070672673522, 0.04053867764014285, 0.04676790900703054, 0.03760921295906883, 0.08121047430904582, 0.09017060132464394, 0.04816905413463246, 0.031416769852512516, 0.060853920149384066, 0.08423181687248871, 0.043789325281977654, 0.0026497680073589436, 0.010001670980273047, 0.03655937827716116, 0.07493767887353897, 0.0070280754152918234, 0.027554566549952142, 0.03305817415821366, 0.04156953189522028, 0.0408666846487904, 0.07090001701726578, 0.04426899387908634, 0.04318404076911975, 0.10005026415456086, 0.0752388201362919, 0.10768403226393275, 0.039190466195577756, 0.020682522117567714, 0.006299511824181536, 0.0445925702661043, 0.040115352894645184, 0.029482072495738976, 0.023229476464621257, 0.012255325782462023, 0.032236835613730364, 0.029250065999804065, 0.11053035414079204, 0.029925973285571672, 0.006453472215071088, 0.027125434498884715, 0.044577883163583465, 0.035843677032971755, 0.021399215984274633, 0.06561611851793714, 0.05015156064473558, 0.020815514981222805, 0.11884148043463938, 0.03599601026508026, 0.009278209654439706, 0.012374907109915512, 0.0274340009491425, 0.04218384092382621, 0.02546410723880399, 0.04329914787376765, 0.03149270640278701, 0.031880812530289404, 0.011701600124069955, 0.0178342354047345, 0.02649690221005585, 0.014371153556567151, 0.046075837744865566, 0.08273045212263241, 0.006761201429981156, 0.03310427266114857, 0.060371442523319274, 0.02745746951404726, 0.04361346967925783, 0.0823940068949014, 0.05254901676380541, 0.020563566977216396, 0.048297185931005515, 0.02849224601959577, 0.04119568984606303, 0.017763813011697493, 0.05714808365155477, 0.02117010943038622, 0.05637099937302992, 0.02331319628865458, 0.03186793997883797, 0.03418597887502983, 0.028016067371936515, 0.04098597746633459, 0.02493336403858848, 0.04902408618363552, 0.12447372821043245, 0.012750772439176217, 0.04146792445681058, 0.058768188318936154, 0.009480438402533764, 0.037459900268004276, 0.10876287749852054, 0.05804028616694268, 0.008067538583418354, 0.06929178300197236, 0.05079481714346912, 0.03492901712888852, 0.010962383003061404, 0.06710116344038397, 0.0783778598997742, 0.03527307679178193, 0.025427903419767972, 0.013510920907719992, 0.029559246577264275, 0.03270571709435899, 0.05904846409976017, 0.015714958499302156, 0.03463367946096696, 0.08504827579599805, 0.05150373515789397, 0.016600045673840214, 0.03656884437077679, 0.031217250871122815, 0.009128691945079481, 0.04426286745001562, 0.033627215889282525, 0.04033037905173842, 0.051137848931830376, 0.022234881689655595, 0.04075672433828004, 0.019909363800252322, 0.044885893003083766, 0.04137376447033603, 0.029846010584151372, 0.016070577112259343, 0.03892999462550506, 0.056287941915798, 0.03701100853504613, 0.04642459149181377, 0.049065761486417614, 0.015839631887502037, 0.02834907831129385, 0.015601916420564521, 0.05018392941565253, 0.0802567477512639, 0.044332276811474, 0.03897409304045141, 0.04963245060935151, 0.045457361557055265, 0.05205903231399134, 0.047145639910013415, 0.035620372218545526, 0.05561496982409153, 0.05867636609764304, 0.09550882503390312, 0.045110095816198736, 0.07024018836091273, 0.021568472038779873, 0.02063484840618912, 0.03208087699022144, 0.03269867040216923, 0.06251767423236743, 0.020916699395456817, 0.007221021751320222, 0.023297603765968233, 0.04081369159393944, 0.03311266264063306, 0.043506310976226814, 0.04565004535834305, 0.03378754947334528, 0.02477195990650216, 0.025540264578012284, 0.026082470249093603, 0.0298563839533017, 0.03136160972644575, 0.05293421738315374, 0.010199847602052614, 0.016322792289429344, 0.02093040500767529, 0.04122929058212321, 0.05850199107953813, 0.01720880529319402, 0.013405549852905096, 0.09312406706158072, 0.1742763866786845, 0.1657752037863247, 0.13418834481853992, 0.19621513289166614, 0.30304525746032596, 0.13363587524509057, 0.10208835010416806, 0.12032664410071447, 0.2003397373482585, 0.07062250573653728, 0.09620432872907259, 0.17498659231932834, 0.24249417067039758, 0.10793331224704161, 0.24995254701934755, 0.13253259850898758, 0.14050817757379264, 0.23495089262723923, 0.0661801359092351, 0.1802458515157923, 0.09730644029332325, 0.09026592277223244, 0.0942006561672315, 0.12235897098435089, 0.12529369007097557, 0.13650991633767262, 0.1326026424067095, 0.11220970074646175, 0.2403949762810953, 0.09682856398285367, 0.1672386151039973, 0.07903989273472689, 0.13671872700797394, 0.10252773863612674, 0.08983778519905172, 0.1269607912399806, 0.1228496344992891, 0.11585633983486332, 0.13442025112453848, 0.1489781605778262, 0.09570533089572564, 0.3190803970210254, 0.08691856957739219, 0.12446206164895557, 0.19836445193504915, 0.07321165860048495, 0.17119231779361144, 0.11728915982530452, 0.10031855053966865, 0.19040674378629774, 0.10441093836561777, 0.23682827391894534, 0.1781707175541669, 0.09717527311295271, 0.10282361807185225, 0.1656994453514926, 0.15201903646811843, 0.15681178163504228, 0.10588077668217011, 0.13954586436739191, 0.11124531694804318, 0.10975613826303743, 0.1106272340985015, 0.08748661683057435, 0.159133130509872, 0.0674869169597514, 0.14772609807550907, 0.11606072730501182, 0.11352601097314619, 0.27234082692302763, 0.1916298922151327, 0.12129450115025975, 0.12355644852505066, 0.1417512452462688, 0.14840223913779482, 0.14605009113438427, 0.14110277144936845, 0.16314758540829644, 0.20073614810826257, 0.17892036092234775, 0.11286405235296115, 0.09203067573253065, 0.09735134764923714, 0.18576432805275545, 0.16138404957018793, 0.1408363998052664, 0.27678445097990334, 0.2391105709830299, 0.08066498834523372, 0.13437030458590016, 0.22039693139959127, 0.10641671862686053, 0.11507453920785338, 0.22169079165905714, 0.10285550815751776, 0.08548461410100572, 0.127578406536486, 0.11062448073062114, 0.10320664790924639, 0.14293094835011289, 0.1631988974986598, 0.14430659328354523, 0.17737675312673673, 0.07367902609985322, 0.1612860563909635, 0.13407718593953177, 0.12347735042567365, 0.1587657822528854, 0.07058746152324602, 0.15279097395250574, 0.12456265976652503, 0.1681250214460306, 0.16643740731524304, 0.21591336495475844, 0.12138510996010154, 0.25495569105260074, 0.10179570643231273, 0.14116815465968102, 0.15566750866128132, 0.09766060800757259, 0.0804326293291524, 0.13108238257700577, 0.1423875181353651, 0.11606400017626584, 0.27411325369030237, 0.20757728023454547, 0.10317066858988255, 0.12168187997303903, 0.12044502407661639, 0.16991260286886245, 0.15404560428578407, 0.16832641063956544, 0.09962713607819751, 0.11866327593452297, 0.06254436186281964, 0.17967588210012764, 0.20268584426958114, 0.08940631538280286, 0.11585611719056033, 0.22514385636895895, 0.1772809715475887, 0.13015058648306876, 0.14680190157378092, 0.15374727576272562, 0.10435032716486603, 0.07012784946709871, 0.19692798057803884, 0.17147431906778365, 0.16079064313089475, 0.07159647066146135, 0.22810802387539297, 0.14369895245181397, 0.11395344350603409, 0.211251504952088, 0.09679654031060636, 0.09186341791064478, 0.19672482507303357, 0.11663676748867147, 0.1459516229806468, 0.12153295319876634, 0.145152656477876, 0.09810133240534924, 0.15638216718798503, 0.11454608553322032, 0.18173862219555303, 0.1099069500924088, 0.162095709820278, 0.1255044896970503, 0.1593241296359338, 0.0965548302337993, 0.16035500244470313, 0.065624957496766, 0.10102548330905847, 0.19964786275522783, 0.11621781770372763], [0.06415697454940528, 0.03276596464274917, 0.04207451886031777, 0.07790972056682222, 0.04814233681827318, 0.05690820296877064, 0.02215065534983296, 0.04096635879250243, 0.05747542643803172, 0.06893413461511955, 0.11788784293457866, 0.023861177724029403, 0.05587986459431704, 0.05911622960411478, 0.06410191461327486, 0.01383260017973953, 0.024103225478029344, 0.031588525089318864, 0.03370151229319163, 0.04379612706543412, 0.03916316258255392, 0.0385101876599947, 0.05914547393331304, 0.02785055730782915, 0.018768124355119653, 0.041713204263942316, 0.0051697979324671905, 0.0173600364360027, 0.06035130805685185, 0.04318719860748388, 0.025294018123531714, 0.042699154873844236, 0.0523301128851017, 0.0639257361763157, 0.033916690590558574, 0.014939987486286554, 0.040125991581589915, 0.028791021686629392, 0.02764665594440885, 0.056415843646391295, 0.03363498246471863, 0.046583993680542335, 0.0290172524182708, 0.017335864686174318, 0.052066613352508284, 0.029245110308693256, 0.01817893145926064, 0.05942655123362783, 0.031775156676303595, 0.01745918551023351, 0.09739534958498552, 0.010574236057436792, 0.08073859455180354, 0.07376769790425897, 0.0418471285229316, 0.0642539955151733, 0.036105380568187684, 0.024170232136384584, 0.043342897479305975, 0.06271829901379533, 0.03836990690615494, 0.011380479318177095, 0.024473935663991142, 0.039244572471943684, 0.033344821276841685, 0.03512519644573331, 0.06336004153126851, 0.013758165550825652, 0.004908450628136052, 0.01598524126166012, 0.009071877757378388, 0.025900274849846028, 0.02989271393744275, 0.13564394874265417, 0.02925424800196197, 0.0526095945679117, 0.04569549077132251, 0.01553539679662208, 0.019262539426563308, 0.039528117413283326, 0.041217252946808, 0.0077638151105929865, 0.05113058701681439, 0.05373193707782775, 0.030745827534701675, 0.03996094535978045, 0.04502885291003622, 0.06850908437627368, 0.04785894772794563, 0.06908482770086266, 0.035586723242886364, 0.03240880978410132, 0.05923111406445969, 0.04876280938333366, 0.07349715539021417, 0.023752043052809313, 0.04168801948253531, 0.045347494015004486, 0.036818692096858285, 0.047646452294429764, 0.09064956117072143, 0.032931797541095875, 0.012259995746717323, 0.019446389815129805, 0.04104494480998255, 0.031207944339257665, 0.049315037758788094, 0.004822812352358596, 0.03577076844521798, 0.01080985310181859, 0.04697101998317521, 0.06397216493496671, 0.04877076520642731, 0.09332650268333964, 0.03507447436277289, 0.01296734133575228, 0.013432839550659992, 0.01362247498036595, 0.010856359785975656, 0.042725950115709566, 0.05584223399637267, 0.009894631948554888, 0.021865535200049635, 0.035422975779511034, 0.03992379344708752, 0.017679434531601146, 0.02691453839361202, 0.014962695349822752, 0.07516683181165718, 0.08439038414508104, 0.028827542773797177, 0.055770549952285364, 0.03187487163813785, 0.04791906911123078, 0.07216941608930938, 0.06547497687279247, 0.02121197583619505, 0.027057212573708966, 0.012708171307167504, 0.026599600605550222, 0.04482007563638035, 0.037025532365078107, 0.014875802844471764, 0.10098925908096135, 0.0776969690923579, 0.010287240129400743, 0.028064941507182084, 0.05541085694858339, 0.03358316571393516, 0.023740934957459103, 0.025241012081096414, 0.019542822628864087, 0.015496473006351152, 0.047725531840114854, 0.024680182214069646, 0.019906625275325496, 0.0359146226401208, 0.031212823960231617, 0.06172587687615305, 0.013995093413541326, 0.05033408073359169, 0.015236497747537214, 0.019609218870755285, 0.02250722020107787, 0.08825986049487256, 0.03871158056426793, 0.03828405155218206, 0.06976713601034135, 0.0549542283260962, 0.007640554586032522, 0.04755832225782797, 0.08623013854958117, 0.026931930624414235, 0.02104370498273056, 0.07183824753155932, 0.04415625051478855, 0.051937349780928344, 0.04831681573705282, 0.04840230001718737, 0.01598117800313048, 0.02796562730509322, 0.05489589922945015, 0.01235741654454614, 0.0526020914549008, 0.015707843158452306, 0.033911402788362466, 0.02248951255751308, 0.030017301978659816, 0.03269276290666312, 0.03171982214553282, 0.0757249046000652, 0.02324715442227898, 0.0688478302618023, 0.02568432842963375, 0.040650604641996324, 0.025489332838333212, 0.0717907575017307, 0.048176631462411024, 0.0651774053403642, 0.041214915181626566, 0.02602605032734573, 0.025307701471319888, 0.012031437454425031, 0.010530208146519726, 0.05231345538049936, 0.018234466369904112, 0.04764150216942653, 0.04782541378517635, 0.02056434994301526, 0.023533272760687396, 0.04207549849525094, 0.00956614532697131, 0.0351113442593487, 0.039232913331943564, 0.028575489013746846, 0.036394135386217386, 0.021493927015399095, 0.036014241122757085, 0.05021776392823085, 0.007667995960218832, 0.020407151932886336, 0.08228329330449924, 0.03269847002229653, 0.08132139570079744, 0.026429123718116898, 0.03627567748480942, 0.02870847260055598, 0.11207840740098618, 0.11306783868349157, 0.027565021555346902, 0.023706874089839403, 0.05467741466418374, 0.04195793859253172, 0.06413249851902947, 0.03599800664233044, 0.04579600354190916, 0.1082140147627797, 0.015106217433640268, 0.04765847137605306, 0.03342043870361522, 0.05631948690279387, 0.025702373750391416, 0.041734767364687286, 0.014088437965256162, 0.029598686160170473, 0.033252624270971864, 0.027797981711046305, 0.03277242874901276, 0.06775532950996421, 0.09761041656020097, 0.027427991408330854, 0.05685980009729974, 0.05640759838570375, 0.02695810246223118, 0.031090091288206168, 0.0940705873654224, 0.05204426357522607, 0.017403787896910217, 0.03554462491592858, 0.07244706837809645, 0.04861208661168348, 0.08641803549835458, 0.08543634481611662, 0.016462692692584824, 0.005844214429089334, 0.08080620420514606, 0.042675695585785434, 0.0631892956153024, 0.032008721682359464, 0.014737018445885042, 0.026534395510680042, 0.015316927074309206, 0.035039652793784626, 0.06027689290931448, 0.0277293070757878, 0.03493979682389181, 0.05614870759018231, 0.0791447953088209, 0.02387993550655665, 0.015689410065533593, 0.03489260365313385, 0.024962745665106922, 0.0345044863934163, 0.007021730516498792, 0.011958657814830076, 0.020098002896702383, 0.05514869328180794, 0.022176185229909606, 0.0670824984263163, 0.06616984974243678, 0.01804939329304034, 0.07633056389749981, 0.02966552954603685, 0.07792183983838186, 0.054512405549758114, 0.036563137255143374, 0.016745951907068957, 0.027200565818930045, 0.01176697684059036, 0.06831208127550781, 0.047344721024273895, 0.022044971665309276, 0.0637829395418521, 0.02931504659500206, 0.06975859389058314, 0.037743589928140864, 0.006926795449544443, 0.014026808166818228, 0.029712802497670054, 0.027552306710276753, 0.024142702168319374, 0.0641436010482721, 0.07959651833516546, 0.01347691106275306, 0.06652460375335068, 0.01109029308281606, 0.12289069753023796, 0.025865662937576417, 0.05828026703966316, 0.05742668217862956, 0.04817202272533905, 0.0427414127625525, 0.06745159073034301, 0.03004352947755251, 0.05310538261255715, 0.00929340698348824, 0.02254958941193763, 0.01815503059333423, 0.04316382466640789, 0.02329821789317066, 0.014847009369987063, 0.036998815048718825, 0.05638056194584351, 0.015971943830663804, 0.07105893309926614, 0.018370398138358723, 0.07039828065899201, 0.027333176476531662, 0.0638202769914642, 0.02575039070507046, 0.0861135842569638, 0.020444025540200528, 0.009411724804522237, 0.04427430765645113, 0.05279489028907847, 0.018032509433396626, 0.0694056655629538, 0.12179059718619101, 0.0041375925047759665, 0.02106610485498095, 0.013913809689256595, 0.019898691716662142, 0.13554714299971238, 0.14703382272273302, 0.16145749250426888, 0.16281909600365907, 0.14408185612410307, 0.19256697240052745, 0.09544589091092348, 0.1565776192001067, 0.10122051971848123, 0.15203131159069017, 0.21620382671244442, 0.1848819144652225, 0.07526300672907382, 0.15295795717975125, 0.14248460589442402, 0.05727296484110411, 0.1296908111544326, 0.08606654693721794, 0.06658936355961487, 0.1148779813956935, 0.11187760450411588, 0.12184112260001712, 0.11718583802576177, 0.139026939868927, 0.13198809960158542, 0.1375978603027761, 0.07416016786010005, 0.16748083726270124, 0.18329794867895544, 0.1397857561823912, 0.10072737000882626, 0.11819059465778992, 0.1890933798858896, 0.13954625028418377, 0.12533481989521533, 0.07216963131213561, 0.0720085110515356, 0.10252809486701153, 0.09113364925724454, 0.16238314361544326, 0.13112513028318062, 0.14538135670591146, 0.09548040819936432, 0.11206916766241193, 0.19259892927948385, 0.20066695025889203, 0.09613499729312025, 0.15287609829101712, 0.10816655441885814, 0.1892903310363181, 0.20516835793387145, 0.19000028434675187, 0.16213692870223895, 0.1538958091987297, 0.1181900677329395, 0.2848563459701836, 0.15842892142245546, 0.11463213013485074, 0.12730318849207833, 0.126187146815937, 0.23505655961344019, 0.12156484328443184, 0.1347743594669737, 0.08006637945072725, 0.16857464419445023, 0.12304568022955209, 0.15163392119575292, 0.14795991912251338, 0.08194194990210235, 0.12407964779413305, 0.08879164641257375, 0.16435961646493524, 0.20063058502273634, 0.3693039348581806, 0.07044850179227069, 0.18590545485494658, 0.17866807524114847, 0.1420330535620451, 0.06456667717429809, 0.13878166006179526, 0.1482452155323699, 0.09732235193951055, 0.14844877179712057, 0.13729123456869274, 0.14289750717580318, 0.13732969266129658, 0.18671383179025725, 0.15982396609615535, 0.14966445422032848, 0.1283409187453799, 0.1551371402456425, 0.1363107535871677, 0.14622725662775338, 0.11720895592588931, 0.18745908164419234, 0.07663793920073658, 0.11156192456837744, 0.15914096758933738, 0.12626158422790468, 0.1566495481529273, 0.14071406418224797, 0.17759927868610248, 0.15123319113627076, 0.07119364032405429, 0.13883184408769011, 0.15239239612128586, 0.11765049668611027, 0.08226465055486187, 0.09688264428405091, 0.12472410657210276, 0.19803158385911956, 0.17895752767799422, 0.2641966170631349, 0.17297284881351516, 0.13711452920688316, 0.1327050439431332, 0.1983437905437313, 0.21547576499870047, 0.0975720994756557, 0.08050427626585588, 0.20989379030652344, 0.10805690209963359, 0.18301723874174058, 0.10920358705334365, 0.09586396496160887, 0.11923296333407052, 0.12230285719851963, 0.08229130849940702, 0.1240990920632612, 0.22112833277788013, 0.08282760667498223, 0.22393650084268302, 0.07045233127428219, 0.14303649659268558, 0.12126402856665663, 0.2306155627593398, 0.12732974253594875, 0.08643798442790285, 0.13421316223684698, 0.1400294923223555, 0.23580985434819013, 0.0980410329066217, 0.14346044103149325, 0.17440666328184307, 0.1535673049511388, 0.19706354127265513, 0.1603003210038878, 0.13927505468018353, 0.16833160567330196, 0.0979814532911405, 0.11780318614910357, 0.09517655067611486, 0.05715478524507489, 0.12274258711840957, 0.07344724595895968, 0.10802493779920042, 0.17362984246574342, 0.14960230677388608, 0.1346675050444901, 0.12503220175858587, 0.11953671695664525, 0.11052613874198869, 0.10364453730289824, 0.1608979279990308, 0.17188661178806797, 0.15804252965608612, 0.21247441589366645, 0.14680463267723098, 0.14735192205989733, 0.17327116249362007, 0.20990333432564512, 0.1959587653982453, 0.14172486931784078, 0.20913628017297015, 0.13822257053107023, 0.10371599128120579], [0.02660427984665148, 0.020338525537226815, 0.02274001708428841, 0.04337675796705298, 0.021520596092159394, 0.016927117576415185, 0.0635821366449818, 0.06523956020828336, 0.049827212424133904, 0.0602080809767358, 0.025496839662082493, 0.0252062016443233, 0.02743808461673325, 0.05153887213964481, 0.031732123243273236, 0.048953930963762105, 0.04807069359230809, 0.014340604902827181, 0.020871654742222745, 0.03912557651347015, 0.04974486742867157, 0.05304020349285565, 0.023008027019386645, 0.03938480498618446, 0.029967713526275475, 0.03376226079126354, 0.055938739169505425, 0.018136695834982675, 0.018038040288956836, 0.021761233765573706, 0.03393358187167905, 0.047122277101152577, 0.014663430793007137, 0.03153844867483713, 0.05573809212364722, 0.024992266444314737, 0.02954716626845766, 0.028385245022946037, 0.02371982642216608, 0.019896478261216544, 0.04276142477465328, 0.023425273575412575, 0.025660047213023063, 0.06628021452343091, 0.019066751592617948, 0.04978049051715061, 0.011719075846485794, 0.031983544322429225, 0.018114184640580788, 0.039827288273954764, 0.023090459217200987, 0.0456680053321179, 0.04287936688342597, 0.027158439661434386, 0.03965001516917255, 0.032660590804880485, 0.017916708420671057, 0.015931446687318385, 0.03010754157003248, 0.04167554769082926, 0.04406246902362909, 0.019509463090798818, 0.02300234031281434, 0.1360673736780882, 0.0941301669809036, 0.049049534427467734, 0.04686331580160186, 0.023532571431132965, 0.06442786587285809, 0.00942028269491857, 0.07791467811330222, 0.052205792017048225, 0.0541112450446235, 0.03950684375013225, 0.012077200135536259, 0.023173865483840927, 0.0361153364792699, 0.07331570028327405, 0.02491919087333372, 0.004283710713934852, 0.018574865389382467, 0.022869134081702214, 0.04034003439301159, 0.01081924126992817, 0.033024681033566594, 0.031646627830923535, 0.03054757948120823, 0.04360056002042256, 0.05837991520820651, 0.0632200131076388, 0.04333098971983418, 0.05953443353064358, 0.03560803030268289, 0.0336081872228533, 0.041649821141618304, 0.009733677743497537, 0.04142905447224621, 0.06232314990484156, 0.032718188886065036, 0.03489763170364313, 0.006606604183616582, 0.07357875452726148, 0.0659685347636696, 0.03555055467586499, 0.061588297539856285, 0.015367109244834865, 0.008250235860032262, 0.009059234344022116, 0.017630775619181804, 0.04736834358482156, 0.05025568025303073, 0.02804336356348358, 0.04552037731627934, 0.06245342650800012, 0.00606504093411786, 0.12260253643034957, 0.035395698141655885, 0.0040838234417606145, 0.015363869770226302, 0.025257040615542792, 0.019981598888989538, 0.04511219238338526, 0.033582301111891866, 0.10161157959373668, 0.02869036605261499, 0.045638471565325744, 0.046629862117697485, 0.07938816037494689, 0.053310942676034756, 0.1013110246276483, 0.05546716369281057, 0.03667466349725146, 0.02372681745328009, 0.008565898169763386, 0.018362965529377107, 0.021568047159234993, 0.0351484813290881, 0.029271569728734903, 0.029455024923663586, 0.014129438841337105, 0.03739062820386607, 0.047669072955613956, 0.022455603830167092, 0.021496530098374933, 0.1082163154205773, 0.029323123017093167, 0.0027570055635806057, 0.009891321042232448, 0.035855681271641515, 0.04828882192668971, 0.035058072899119, 0.07158870779676363, 0.04553449296508916, 0.03839906588837039, 0.016681778397469316, 0.03990294280811213, 0.04736661438073497, 0.031668821757193655, 0.06293326950981282, 0.014310861479316372, 0.0247773738738033, 0.03040053776203422, 0.043516994192032143, 0.008203198540286394, 0.061988882880541496, 0.11252302807406522, 0.07240196806378663, 0.019283122892375104, 0.028654062043642625, 0.028989781822019722, 0.03874410147545859, 0.025385953522345517, 0.03228497131203767, 0.05306808227032889, 0.01482708456023829, 0.038849107950227335, 0.07098695961758494, 0.07143964743590914, 0.06783384873415343, 0.053855523219681345, 0.034033756965072826, 0.019003965899173636, 0.02025315072387457, 0.06158478347060736, 0.06232735046069138, 0.07932119639008306, 0.046632259254693054, 0.032834943558555096, 0.056455218291375786, 0.026031187844637316, 0.050896591565106064, 0.05953866748313885, 0.02774387914541876, 0.061465691032935865, 0.03175321136950515, 0.03933460611733608, 0.05837123579112813, 0.024325867925654165, 0.08053475627093576, 0.02038565005932469, 0.026586900603433605, 0.0817168565117754, 0.08562381131923757, 0.038482698510051705, 0.00787499857324292, 0.024669081540196203, 0.0420868830406107, 0.028264818574825767, 0.052128137394902296, 0.020504107960732654, 0.017113277899625245, 0.09131707105552778, 0.0721314107067883, 0.049422715965192765, 0.0594227737019537, 0.04669054011174012, 0.02705976556171663, 0.03434388192545157, 0.00939120998737053, 0.07535648765042424, 0.03930910963390488, 0.057883626213879324, 0.022270517765718978, 0.01771350096532842, 0.04992911301087588, 0.04509383907134179, 0.06899979984154925, 0.0413704953098204, 0.017129994776041713, 0.06564947063452564, 0.0356726750760572, 0.040791872452246025, 0.0015122611011975096, 0.07004528553807177, 0.009534735781926429, 0.031451977338292636, 0.03100628797255922, 0.06158688374853227, 0.01577641574840527, 0.009887974883895367, 0.011111178046121495, 0.08296800617245026, 0.06171611021272838, 0.014435904085985385, 0.026858804958465043, 0.027587608819885645, 0.01992026223888388, 0.0200654875516193, 0.024648431281093508, 0.006394689944499987, 0.06553834886290133, 0.022246470325626433, 0.018836303606803995, 0.0509325486200396, 0.05062338474090211, 0.011678003538690973, 0.019466817429929506, 0.0205439130513696, 0.026768450334202498, 0.03951191632950213, 0.045007430817349814, 0.023169961787061766, 0.012246741916897008, 0.0622075010323897, 0.05056285888713319, 0.029377273822319694, 0.05599539843387902, 0.011941290631511947, 0.030618525088357273, 0.028578641286003403, 0.06520173294120468, 0.04809807884157635, 0.03388974320841953, 0.04052727083035279, 0.09103181175305508, 0.01680520683294162, 0.012251407242729329, 0.03771913245145697, 0.060365349490894005, 0.06961053542909212, 0.05673433261108585, 0.022545253414136823, 0.016608352161711082, 0.06968180387048051, 0.012963883855263703, 0.024209697694459464, 0.034609507711138576, 0.04149351370870136, 0.016585770463279914, 0.011140981769131031, 0.015280711195373442, 0.03298956260550767, 0.013231228640506743, 0.02949277240986703, 0.04215267072140705, 0.03655597924080212, 0.03135067789116874, 0.027015481609851122, 0.03347549863974564, 0.055868988420115784, 0.05127621494466439, 0.025670895556686446, 0.030047401633055415, 0.034233628466608934, 0.03393627586774528, 0.03570150009181816, 0.06282286019995809, 0.0034619688585735275, 0.026595047529553995, 0.015354361930803861, 0.0244972279688227, 0.04893171848380007, 0.08173994472599588, 0.09274377574911341, 0.032333107010344975, 0.07308453612495214, 0.03801605089392979, 0.060078683818574063, 0.07345980309764855, 0.05738427586038597, 0.08849835707223974, 0.010995535667461809, 0.01083309160094359, 0.007356160813287715, 0.02207847221143311, 0.045367643324425444, 0.04126929976337124, 0.04885009337158408, 0.05548596600419842, 0.03618985923822038, 0.012275758963369299, 0.02256079769722419, 0.025840060698101297, 0.05564407314523123, 0.03957755187002476, 0.02445651189191267, 0.02458170107274782, 0.05294046255585272, 0.05297144722135272, 0.032825533126015216, 0.027925653375859838, 0.03428957897995133, 0.05151363911863882, 0.011046421950595686, 0.03790361552091781, 0.028410359300323762, 0.07677290617721155, 0.015803984679223504, 0.03452508841292001, 0.024348371698579285, 0.028211706776346546, 0.05975511856377125, 0.25286707968916744, 0.16587802092544734, 0.06334365491056815, 0.18585432088002563, 0.1076499379996676, 0.09013311544549651, 0.16253181063802913, 0.1350690217805095, 0.16612526000244543, 0.16108583979075775, 0.1559647239628248, 0.10148676519747823, 0.07773234727210365, 0.13484017312293872, 0.16624618554487824, 0.11428015917772427, 0.12987873778911307, 0.15428613434778526, 0.03587362269172445, 0.15557439881376922, 0.1909563338267617, 0.15219143737340346, 0.13986730336910114, 0.153058800206054, 0.11484858492622152, 0.19599300809204578, 0.16073453676654026, 0.10943644330836833, 0.09625310267438181, 0.1231856195954606, 0.1257288409397006, 0.12476096162572503, 0.169419119192753, 0.1244185198447667, 0.1532394389505498, 0.1483819933491759, 0.1778727601049468, 0.0938835067790933, 0.17043431784259155, 0.10329885233659297, 0.11726071330485865, 0.18553921981947497, 0.13433013955364004, 0.14444117434322834, 0.12975447258213535, 0.1467533948016353, 0.10649010218912736, 0.13523511443054304, 0.07143034832552075, 0.1049871566647198, 0.11950088606681675, 0.09107424775720574, 0.1643384207272902, 0.20264158258214593, 0.08189946194761433, 0.15519528009463102, 0.08934982310165651, 0.1369510340737179, 0.1484474359313026, 0.14355752879055217, 0.11350880799000151, 0.2735622238833457, 0.1173868116165977, 0.21659973281202838, 0.1746566779911518, 0.10892355989199132, 0.11185341791133396, 0.06687248547677882, 0.24756067927228287, 0.0988302772748284, 0.12665159767493606, 0.1466813322622329, 0.17489213176304474, 0.12179048586403951, 0.15384746569907293, 0.12680117011768743, 0.14023469615494832, 0.2122005188721232, 0.14265682868426666, 0.09719499197672121, 0.0796656939201057, 0.15236432809615508, 0.14384807960595936, 0.2356102759949863, 0.2010759775293991, 0.08755251954426058, 0.08427565553574823, 0.12836469715693966, 0.22366949095157906, 0.25456297618802637, 0.1797849778085947, 0.1497805558028631, 0.1124171755509451, 0.09176212959573604, 0.13285092049045488, 0.19131729961372912, 0.19380379118956625, 0.2503649436403066, 0.18952020385768265, 0.17791749676689506, 0.10732740061939694, 0.083045746141579, 0.12421018414897844, 0.21447871928103268, 0.16933402454014868, 0.17399678996298462, 0.08160257319104858, 0.15685657766880468, 0.1422871055547148, 0.09334666683571413, 0.23296649364056066, 0.1594979257788509, 0.1336663032998331, 0.07745849477942102, 0.13932025147369131, 0.20275228132959455, 0.10541418843786232, 0.06561304602655582, 0.10960918560158461, 0.07193979559815489, 0.09061069489689544, 0.1600112099549733, 0.13999260758282617, 0.20475156779866666, 0.18728967901552096, 0.13926527317380533, 0.13508233590982854, 0.19821934722131118, 0.1235272672784049, 0.1407218715758063, 0.1749907186604105, 0.20541743753710762, 0.08843497023917735, 0.1295905321603641, 0.08855754334945232, 0.23298896587220952, 0.1218803451047279, 0.23029542993754148, 0.1924472936661914, 0.13736556807998568, 0.08335283942869864, 0.30544714420102537, 0.13170491089113057, 0.2323294192319736, 0.18966959818499163, 0.0732856581453234, 0.09654623616370372, 0.08372956843231805, 0.10632300021825358, 0.0943751870363485, 0.18238383054267615, 0.13390337495366111, 0.09546684916131198, 0.12127763213356957, 0.15519927284913138, 0.10460579665959813, 0.09153846855042502, 0.16760884289396927, 0.15108945197425783, 0.14910180238075554, 0.09043568163178861, 0.059496428148122504, 0.1804782179533504, 0.12417667618137784, 0.19534340623067692, 0.16740883409511298, 0.12787474610377103, 0.1497331028804183, 0.13291124225361273, 0.0714684947161004, 0.2166462506284006, 0.05710969606298022, 0.09648053382989019, 0.08624260663054883, 0.1279525231802836, 0.1384044560836628], [0.07068866078043357, 0.07284484468982555, 0.0305642963576247, 0.03285551218141336, 0.03915817906090524, 0.03027366205060389, 0.015605866501573473, 0.046711464965483174, 0.030611667643825058, 0.060445668423199095, 0.036813389451708645, 0.03725164620846044, 0.020401331639732234, 0.0643678187043406, 0.02449633368087234, 0.07634499124833383, 0.0072232338152389275, 0.04460024407308083, 0.015858944425417576, 0.09521569896605797, 0.037970891207805835, 0.04293878693715669, 0.06785794626921415, 0.03243442872189917, 0.0344945935648866, 0.03219652957341168, 0.06415646246750839, 0.01726215643429896, 0.06269043879001401, 0.02766931185760768, 0.012010524660581723, 0.017327367095276713, 0.014298719943326432, 0.0011984157777078508, 0.03873738503898494, 0.014237446375773288, 0.02244215240352787, 0.0742448988603428, 0.0450501711020479, 0.07491339580155909, 0.011070291275245836, 0.04257536835211795, 0.011713475414580898, 0.058495604898780584, 0.07206164882518351, 0.011525159152370179, 0.041801991101237945, 0.07138604953070171, 0.025370976982230786, 0.047564025662723, 0.0648078900121618, 0.024463829468004405, 0.005558332650252851, 0.0833780130778905, 0.010668785671441583, 0.016825499005790334, 0.07355790759902447, 0.015661134239053354, 0.07826935048797168, 0.009525072091491893, 0.04163172015978489, 0.09943033335730433, 0.0486026093858527, 0.019702952122315764, 0.060050511892768554, 0.04139039599976968, 0.03262286372773815, 0.07011602705460973, 0.017554280602780636, 0.04664540640078485, 0.02932146431703586, 0.05604494050203357, 0.08750206834520213, 0.0633863358234521, 0.023564667462778743, 0.04043180466396734, 0.0372930209414335, 0.030456853783107363, 0.06076966041291598, 0.06652283744188026, 0.08737963624298573, 0.01103205953768338, 0.06755682727089152, 0.03298119860119186, 0.029938608349766582, 0.021523236282519065, 0.018582852753752377, 0.03157120336254593, 0.08080287196207792, 0.0479848196846433, 0.031516733433818445, 0.02658443852851633, 0.042548992423689924, 0.07676843102672137, 0.03215336626453791, 0.020732913944812026, 0.02548648299125489, 0.06084424996515736, 0.04989149354514666, 0.05224965665547643, 0.014861719664622797, 0.05022528188419528, 0.047551835887134075, 0.010838798716577003, 0.011007390548911644, 0.023942313018778805, 0.01867484566901112, 0.0572175486740889, 0.02174717006710125, 0.02722946876019705, 0.023328417737502605, 0.023586033894389402, 0.050995111669180915, 0.048397472346550785, 0.02091732094413601, 0.02554390852310462, 0.05374945918447338, 0.06615547434194013, 0.026595528070174623, 0.009897312957036775, 0.008715968779142713, 0.07332272100029513, 0.056894428707892075, 0.04101811246073339, 0.0999610654253047, 0.009627400340832537, 0.07226096000522375, 0.006377153458743123, 0.03774974975385703, 0.025649731360317674, 0.019348376226844266, 0.035868108534486964, 0.06411165901226923, 0.09482078734436072, 0.08643321241834201, 0.07378126436378807, 0.01988219933991786, 0.03943699281080626, 0.04778116322995629, 0.032644560415064916, 0.026615428760123905, 0.03830950350675266, 0.05414684215793386, 0.031195583869703114, 0.03968689990870189, 0.08179418829968199, 0.027097685597254895, 0.03585166996344924, 0.0813850125996396, 0.030164224954205565, 0.02171649524825625, 0.020925621865899302, 0.0281263319629943, 0.026646765945770312, 0.04743387893540785, 0.0217716590850614, 0.04592137825966347, 0.034639883815543726, 0.02182616797654191, 0.06344347377307713, 0.03567720588762313, 0.04818325141968671, 0.03386223179404624, 0.02291524000611389, 0.051800905930576846, 0.01762456384312827, 0.01948619305039756, 0.010542799609538633, 0.03766845118661877, 0.05002649391826708, 0.006964538761167205, 0.007407899174722843, 0.0566654464637395, 0.0549566403060453, 0.09183245550957508, 0.02673824677913217, 0.029401779538602568, 0.025976059259846807, 0.061475420588976704, 0.027306394222250674, 0.030752323182241526, 0.07851578062400222, 0.03305681231722701, 0.03013333862327272, 0.028735746527672745, 0.018798192468238994, 0.041960632588597946, 0.053792210601386614, 0.008967734956968343, 0.009312173115176847, 0.0607187750574667, 0.043265561980661005, 0.03434111742535606, 0.044693650779663585, 0.03130659431917593, 0.07161366622312926, 0.011625863025983563, 0.022027471823093947, 0.04764290482853539, 0.021926677036390174, 0.06270037614740431, 0.030609057139372453, 0.0635199669341091, 0.023152957328420598, 0.03083945317484904, 0.01741704450978432, 0.026918460644083098, 0.06606580805964768, 0.03572578316379804, 0.01230550609761849, 0.028106368190492503, 0.06652732743532397, 0.028913542846566997, 0.04241952847223729, 0.012052118327119388, 0.012126911969971843, 0.047656690221629106, 0.10079963292810135, 0.03694489802001044, 0.0077688598594249925, 0.07325164551730268, 0.012076105467713205, 0.030574675292882603, 0.05968589844997041, 0.05859038828930352, 0.026672887688619085, 0.025971007089538034, 0.033516268522362225, 0.014510051132674562, 0.03801435508648865, 0.03162254513881635, 0.02120541153999511, 0.02201347677328158, 0.05103600771690253, 0.04657246441638563, 0.04256155327311717, 0.05155752973223571, 0.010108489223057404, 0.013218063868407626, 0.04156378396146465, 0.02551097200921504, 0.07373125103185885, 0.046091270705801435, 0.03597053975681774, 0.056837910451577045, 0.07017372161499225, 0.04429775581229478, 0.040773730652290396, 0.03212157265807036, 0.021542053436860442, 0.018516128111514263, 0.01998418156290427, 0.018169784489145968, 0.03343090298585594, 0.03438949061091989, 0.08969541901024058, 0.07094945889548399, 0.06938334176084027, 0.023430739493051078, 0.04688775472459383, 0.039345285622403026, 0.017955977309611626, 0.07272254617419094, 0.04220529641315807, 0.09653254353906959, 0.04692201968282461, 0.05628258360957261, 0.01556788894959027, 0.023872181918704882, 0.016939852830546442, 0.04109092828002758, 0.005847093034390127, 0.03656823580968194, 0.07831566050299443, 0.046206440893001854, 0.03903582488419488, 0.0301552319797338, 0.034112168577848934, 0.050150989191024564, 0.032916546406340785, 0.02536889154725941, 0.028425751443137415, 0.0185667574260151, 0.011155447155033471, 0.04255921179719735, 0.05105374875711277, 0.04030179152323399, 0.021578526284429245, 0.05552917384193279, 0.012075249214831274, 0.021363722771639004, 0.010682819684006972, 0.03086555821937509, 0.009536203378956998, 0.03533213690388948, 0.04825554773560725, 0.007232564930745866, 0.06500068513560109, 0.052899915317539126, 0.032352477064705454, 0.05464437053888105, 0.03405531264434103, 0.05061957381258253, 0.011666297086776467, 0.05361200972402003, 0.01925860418850789, 0.009281826696678763, 0.033701716383802705, 0.02162347260309616, 0.030182353766576853, 0.058036300833919086, 0.03770897616050206, 0.0057932358413381735, 0.06006111347232945, 0.08620247870567255, 0.046717250006622635, 0.04326632639276795, 0.05759907937317621, 0.08575280400691554, 0.09210785166942514, 0.0609729161078576, 0.030872612333041616, 0.007118758903743583, 0.024892757428460754, 0.03102280075836461, 0.027168146953044925, 0.06286540752626024, 0.04086105545866303, 0.05007887841202319, 0.02436383620079141, 0.02683612678083591, 0.014361439771164441, 0.03672826511319727, 0.037159130079089664, 0.051787179909297265, 0.032216834733844735, 0.02702099947782699, 0.029003223971812986, 0.03860565382638015, 0.016452285926789045, 0.06166632694657892, 0.02638248901348561, 0.027358331572031602, 0.02427695297228638, 0.003752676684598555, 0.004996187790311524, 0.038403837897931226, 0.021034172095824033, 0.030730541147931945, 0.003478041226117057, 0.02388201537542045, 0.01796528755221516, 0.11983073360170238, 0.14365374081535265, 0.13767639436991885, 0.10138446756172925, 0.10708848101785406, 0.19542481983080506, 0.11270526985754259, 0.10969353068503551, 0.12746611959300935, 0.1163206496858038, 0.10296992506482638, 0.13400960597209632, 0.0715763881453313, 0.18541553348768502, 0.12207435735035688, 0.10380991006968543, 0.10510781503398903, 0.1441898534540087, 0.09756579864188097, 0.2744774700840935, 0.19741819880437106, 0.10606569761876017, 0.1649268250912428, 0.08073090590187348, 0.1432428284897469, 0.10134628406376578, 0.13882479368476197, 0.08260755988885649, 0.11032783688278869, 0.19776927918428555, 0.08656053527374752, 0.1340963927214034, 0.14482988161034882, 0.11092191125499085, 0.13948166859336197, 0.14368893345817924, 0.09304166640504263, 0.19456041074590757, 0.1046958785445895, 0.15872331656282768, 0.15893868781859055, 0.1488633206463419, 0.10355324571719393, 0.08797828224487603, 0.15284077206160873, 0.08682908141054213, 0.17786686745239422, 0.15458710491657257, 0.2329649351304397, 0.17093026544898748, 0.10724360472522676, 0.09960927258362062, 0.13488724012859166, 0.2739217202179134, 0.11611792462645099, 0.11732290528016165, 0.21180884301429614, 0.13277404883410782, 0.16223996848566458, 0.17278496670769528, 0.12294944594032131, 0.16728727030567825, 0.18236612289911136, 0.16699099011020735, 0.11431765247834846, 0.16125119029311463, 0.1718249690020457, 0.12456369877327234, 0.13633327034767717, 0.109046682191547, 0.1727371130255051, 0.2190630545374006, 0.24291481997352093, 0.07832589471945539, 0.15343875013059005, 0.08716542273759842, 0.22046691592549905, 0.08687081237439997, 0.13121190218953416, 0.1650015593622811, 0.1881952624535188, 0.11923046971787699, 0.222755016584415, 0.22360277187544852, 0.07630631793290377, 0.11696788409608416, 0.09693518091808073, 0.23518376372521743, 0.21007353847380728, 0.12237525370437652, 0.15675625414587557, 0.1669158847653307, 0.17164061951916665, 0.12374795973300934, 0.15601504157530144, 0.09039369833772071, 0.11417065528803505, 0.16820360004203394, 0.0889933695725631, 0.08821280091069639, 0.10390345036284998, 0.11151365528348833, 0.14738055411726236, 0.07897817573393695, 0.0990956841269508, 0.19098046846920624, 0.13596384407719597, 0.12362327150185592, 0.128959083231166, 0.09571181726641953, 0.1381404889980331, 0.11378125040209852, 0.15590585680911317, 0.1059007181902416, 0.14816914539551362, 0.0796964559413027, 0.09812300311750732, 0.15679969947086647, 0.10815596397151239, 0.14308651734609157, 0.15391853376058862, 0.16042604082031175, 0.18036092893453315, 0.14136059355223551, 0.2328114738338627, 0.1331252182717435, 0.11669377927319147, 0.1791210673400201, 0.20495059696258977, 0.0849435364943929, 0.10241932570352219, 0.10988138310494833, 0.16228100925218314, 0.25285253359470516, 0.1659741290495731, 0.16110525437397882, 0.08138153192703612, 0.17009800620144233, 0.18363902490818873, 0.12298491317778826, 0.19228445162298158, 0.13833836041158065, 0.11891316447872669, 0.1666731431032531, 0.20102319598663598, 0.14271550287958235, 0.14068608521483839, 0.16726482775993645, 0.1621921148034744, 0.08316043764352798, 0.22450035496149212, 0.14593007101211697, 0.11520508298417553, 0.13674443500349298, 0.14029055018909276, 0.11239301122259349, 0.11335846371366642, 0.09788016497623175, 0.11944885409320705, 0.15376476076198742, 0.1065580829163082, 0.10940503561869264, 0.13178549328586087, 0.07110142847523093, 0.15706562582636252, 0.1499845425132662, 0.10394154480309226, 0.14637055050116032, 0.07312501285923645, 0.08592493773903698, 0.1089464031974785, 0.09066872342373244, 0.1656021794769913, 0.14591346174711362, 0.1776216470170766, 0.09269968475564383], [0.030310554211609997, 0.030304919455375057, 0.06809314771089703, 0.025421949540032074, 0.04392635171825532, 0.03990119133959524, 0.01920448492455762, 0.03211591378203593, 0.03349254206113983, 0.02425296861474635, 0.03459031577222049, 0.040227220524684526, 0.051746751414611936, 0.022909200779395178, 0.03227579465601593, 0.030431945451709908, 0.01857660387031501, 0.06267416349146515, 0.05003522528568283, 0.04709835768153425, 0.021738774521509185, 0.009881802998279454, 0.016687116294633597, 0.046218582428991795, 0.017711461914586835, 0.04651881456084084, 0.03628121019573882, 0.044673534866888076, 0.02820126846927451, 0.031817076887818985, 0.026187988805759232, 0.08154320879839361, 0.06548451347043738, 0.021472812913998496, 0.05774673707492184, 0.09846435394138098, 0.04056903890159447, 0.046936413637013175, 0.040677184661035426, 0.11626227234955877, 0.01926115346577717, 0.020857392519246787, 0.08412501440034248, 0.0058673341845860705, 0.025208146071236115, 0.030029094705241732, 0.07867808089940809, 0.028789396383217536, 0.0357030400482472, 0.056149401498259977, 0.07371057479758747, 0.027159230048710015, 0.041531322422088124, 0.06113648916652892, 0.030575252312701195, 0.058597119568730704, 0.033145061097457074, 0.06242842355277389, 0.034003610926447436, 0.006283139582592412, 0.03492338793876115, 0.027870740013895556, 0.04737126764666755, 0.033487554828752764, 0.05662652452883776, 0.0374107849347638, 0.019837818908854388, 0.022666004551865626, 0.03242980885261204, 0.019027744310733397, 0.06946574241737835, 0.0690524181118235, 0.021068451897008345, 0.0277993324198178, 0.02627375510201091, 0.041006423634826206, 0.04993958100385498, 0.04256859996530693, 0.0853403405926656, 0.04778058435476851, 0.0744579620368313, 0.0560511077492265, 0.07300232842680998, 0.029696538331336342, 0.0203000637338846, 0.02294784255354898, 0.028066225422662683, 0.005194651066631195, 0.06075127370422706, 0.021516616325243376, 0.052098837404628284, 0.04362614927231334, 0.06195541573106311, 0.02277082920045359, 0.0297585392036126, 0.036789718651562, 0.06258586276089773, 0.01730772801238345, 0.015311408278648742, 0.043621184304356575, 0.05096208980830852, 0.043528931637411006, 0.10068348681670614, 0.025998839482781477, 0.05496468147612177, 0.06290379140409641, 0.026602597026794683, 0.013902519767725607, 0.11030651498003863, 0.04713664508017246, 0.01851168264693115, 0.02641167211550055, 0.006050778247299604, 0.021203346514084842, 0.055304347624769434, 0.05069587772595696, 0.012078114832547726, 0.022652727529930416, 0.04283336857042741, 0.023726813742541708, 0.014708697162859607, 0.025793314671318512, 0.09583561492036097, 0.028437436558306217, 0.025339701023767702, 0.12978706770809367, 0.04250614823831711, 0.08733690337976441, 0.01762265837896848, 0.03903659300704021, 0.0840573750610929, 0.002216354691881861, 0.08364802866708487, 0.05004984930565115, 0.03701102337799966, 0.03135274106170982, 0.04357387238997035, 0.04713315698609222, 0.04790188468177803, 0.03875841750414111, 0.04841106849198695, 0.050420314582879655, 0.04777907037350815, 0.06780481591704302, 0.03547489643096924, 0.09869525834801607, 0.051665259888977744, 0.022578087882720865, 0.030145691671350505, 0.05111716527608223, 0.04044609100674279, 0.0226852874038741, 0.006020124765200308, 0.009909905347740278, 0.03204363601980731, 0.05512678879313171, 0.00719937283975014, 0.00491944832901936, 0.01807390828616917, 0.02423100475425599, 0.003712462485054857, 0.030151369101076853, 0.026135995794902556, 0.060401384471333586, 0.05477075086673722, 0.00654988276437507, 0.06994107316131704, 0.06551657425006852, 0.0802454819495324, 0.010005660024035024, 0.04820135611225851, 0.04709827604528982, 0.013065852162981173, 0.08849699894199148, 0.0904408395581413, 0.016108239251479972, 0.017189535428769886, 0.03732927485543769, 0.059299447311786935, 0.05402879985922482, 0.08144031002302654, 0.049521785258548334, 0.009711180464364588, 0.006709225117447204, 0.06507001657155342, 0.07653799417312257, 0.0884587709151674, 0.03122155903838575, 0.04157521303568501, 0.01989572683669394, 0.018566909566288814, 0.04028056609968189, 0.008152764039550675, 0.0599857224005973, 0.057864853588398546, 0.062497554608853534, 0.03832714806776494, 0.057924733773688786, 0.041318185030831955, 0.053030292110634036, 0.0671720682294108, 0.10355721620726399, 0.006238030455278931, 0.04203809796308633, 0.03290591143013444, 0.06675727447145618, 0.018072240309265908, 0.06913815101142973, 0.0277150763940881, 0.07265748208737932, 0.03992476937128231, 0.047808982635615394, 0.025282551941927522, 0.04897319340670947, 0.01349459458651836, 0.017718015078571625, 0.02480484818079276, 0.05884173515369184, 0.06952691765036434, 0.02551212048274465, 0.04302926216041669, 0.005589010252151638, 0.02069862857752014, 0.10441042628372088, 0.06777531554689631, 0.0931173209392, 0.018501749000279233, 0.04541606474958826, 0.05032052540627774, 0.05339033763448242, 0.01539042195872753, 0.005132335709276958, 0.031231629982357845, 0.019042982457904145, 0.042683191277319565, 0.024808386369841173, 0.0296652530960273, 0.035619221889646724, 0.012071180390194058, 0.0207593232698855, 0.018487336492398754, 0.022584410980925895, 0.037679820889024995, 0.03762728054425679, 0.03359117348736618, 0.039459227555198595, 0.03728837509697769, 0.0528105087869335, 0.015150827930483501, 0.022110792742751073, 0.00806223222753033, 0.07148997989133932, 0.06859652421553619, 0.039970014404389076, 0.02601785887236474, 0.017098115822591353, 0.0724252566578798, 0.05357505819119979, 0.0821359695692081, 0.045457992382580414, 0.025602397181501146, 0.02454955865687225, 0.002627035328259808, 0.02547989643062465, 0.041736158891581, 0.1307119321427308, 0.03903558368619997, 0.022481519627035595, 0.03870367298077326, 0.010906148618232692, 0.07725709074293263, 0.03650232196378056, 0.010145257074327674, 0.024572056863689795, 0.03616529415012337, 0.037768403635709547, 0.053326720735640265, 0.04118115859455429, 0.0886277282552328, 0.007574160199510516, 0.06507801692350768, 0.08582770897191949, 0.00982280689640902, 0.04850955148867797, 0.06502972537418827, 0.02605570469313534, 0.014812935514783021, 0.02626753590448061, 0.02175205710955197, 0.01240500676431111, 0.02935375516244676, 0.03240870588342659, 0.026968869169650134, 0.04767946302308701, 0.06522561525343917, 0.03796828255872242, 0.042390536473249085, 0.019557025480025914, 0.05461203516460955, 0.012417538855515886, 0.060535397788044065, 0.03798785670369398, 0.01916824399813777, 0.04797237386810593, 0.009874909374048002, 0.019717975046660285, 0.031238661831594072, 0.055347933957818896, 0.0637633097358048, 0.05008677857404109, 0.0061536909379356075, 0.014403520472114906, 0.03577825671527535, 0.04063394713739399, 0.027848739046021365, 0.1099665742367506, 0.047811257318244316, 0.03517921737511642, 0.05948112506303005, 0.033271389474975877, 0.05496067016792949, 0.04205684090266004, 0.045647054503206164, 0.08258067930000834, 0.10437452117912471, 0.03276678100519348, 0.0241671967523871, 0.019247319833084475, 0.039566159903188236, 0.015668743108108174, 0.037636074994225055, 0.015688538042013533, 0.08256969551439397, 0.013236284521553898, 0.011522437325766077, 0.037275806826073676, 0.02096677209920017, 0.022116486870800145, 0.012929584572702879, 0.06212021704413928, 0.02159656047297176, 0.06611971024540253, 0.04115314623049926, 0.039534611205453984, 0.0631049505318515, 0.05443890695460141, 0.009148628814728, 0.1232100288325455, 0.05282791957142763, 0.018756366880552378, 0.06701913385768421, 0.015530396576650674, 0.1336744223954156, 0.14474659779807553, 0.13654454494826496, 0.08551910170353949, 0.16025427816202864, 0.11744731149519794, 0.11043322927434929, 0.17798035667510703, 0.20478808146435767, 0.19426920684054494, 0.14995295670814812, 0.1117345406964887, 0.09226825946825556, 0.15343450504587963, 0.13645890110637993, 0.0961454318894539, 0.12518947769422084, 0.16479267447721213, 0.15674231661250815, 0.1687637434224598, 0.09651403437601402, 0.15701121155871078, 0.17237844789633527, 0.15184865420451388, 0.15019801387097687, 0.16441262065200135, 0.1411370883579366, 0.09737502216012217, 0.1984806574182585, 0.19687133986735716, 0.1571131232776679, 0.25257954199332744, 0.1609447575174272, 0.24857780750608072, 0.1818577665835619, 0.17903279629535973, 0.1889144629240036, 0.16966742696240544, 0.11582842023926787, 0.16491601942107081, 0.14881197887007147, 0.09291432870668359, 0.22033571905922145, 0.0703738714219071, 0.10329690048820339, 0.10436986791319214, 0.22643902280833572, 0.1350787142291665, 0.18347477278439328, 0.17021207429934293, 0.16661809058859944, 0.17342757753795013, 0.09857566867140122, 0.1419841608731076, 0.10028641554526985, 0.10777023271657526, 0.12900696659926325, 0.1504295491031371, 0.1274386452860199, 0.206565510306973, 0.12019864589092322, 0.12206275758217089, 0.12514057016232982, 0.14983664732426405, 0.09835864984779619, 0.10866211610846221, 0.11121259565697983, 0.12661855726037174, 0.09871704038232565, 0.10929182841209695, 0.0954598952375818, 0.312506512273103, 0.15135159337660298, 0.12879996676929295, 0.1437871195957996, 0.15577762853354216, 0.10386246896814555, 0.1124530064407736, 0.20933321648044512, 0.17375182185787708, 0.11661899305181578, 0.1635328194242902, 0.16561311873374507, 0.1411009457660839, 0.07136433428968303, 0.08147425585775636, 0.16706168709788471, 0.1086364674847573, 0.11888023538631387, 0.16335381340468302, 0.14191612077411264, 0.11446579999756068, 0.11632026376901194, 0.06532088475069031, 0.194063498347532, 0.08029870135942474, 0.14776587719097733, 0.0907214530161582, 0.1028477304498665, 0.17357979202643037, 0.16600093542365357, 0.19553355930838734, 0.15439822833286598, 0.15028285619337112, 0.16629531572107226, 0.1522170117823407, 0.1164597058959771, 0.1483713509514928, 0.26583204336930066, 0.1447822802583687, 0.11241684158449061, 0.06477777365944348, 0.11179691078723408, 0.08928762370487675, 0.07530798087827861, 0.11179904817254283, 0.12896144326077774, 0.13648324355017394, 0.18210317997727543, 0.1111923498683609, 0.08557781300623901, 0.13103130797389895, 0.1820027970825322, 0.0895831394882407, 0.17993529239902273, 0.2060662824078463, 0.13839244813425466, 0.22792360017774627, 0.11999874841421843, 0.18371883546933532, 0.11878160396008752, 0.12835311965318397, 0.13496339932316914, 0.14290547784185037, 0.10699958656914532, 0.11004180574673228, 0.13282740925205871, 0.12079744774382561, 0.13486424839356914, 0.22808853507740423, 0.23545797244878486, 0.14416744059417397, 0.25616767758037895, 0.1530317118158564, 0.09589886816684157, 0.13669690786628053, 0.2028822313877754, 0.20131117897108197, 0.18198372388724238, 0.13962632801849395, 0.10766435792902485, 0.09159572524367832, 0.13871845876565203, 0.12097272818209603, 0.16455776989459991, 0.06343623041175306, 0.1479693889268674, 0.10329347918741405, 0.07483328095986508, 0.11336669413140044, 0.11004428451997228, 0.1193689470528625, 0.17004712455673143, 0.10197259733104147, 0.1436359144281596, 0.13426411809632555, 0.17118943826062605, 0.12061772184097208, 0.10068437739391811, 0.11787811337853782, 0.07978949157404713, 0.23189256142359227, 0.10702856743591838, 0.12192505950224586, 0.1844708833959885, 0.07743266061879694], [0.10078717226861045, 0.009043320842465619, 0.012440965674613835, 0.02684995484742103, 0.03355658940563444, 0.03747885100892745, 0.021293918216542806, 0.024104238509607967, 0.03827711989288218, 0.0379443408746738, 0.053296470796340145, 0.042438861419213936, 0.0161441091040615, 0.01931181988766184, 0.03489881542918738, 0.011638137220870703, 0.011708503952831961, 0.045510402851505205, 0.04843534785322845, 0.046658379142172635, 0.07112324019544758, 0.05480154628457967, 0.01388949693136965, 0.04364623920992017, 0.017107895473600365, 0.028481512708822265, 0.09100027789827436, 0.03733586512680631, 0.021360384962463286, 0.07319752068724483, 0.024066845398920123, 0.054890440733288415, 0.044378768652677536, 0.07037965275230817, 0.028671404179476667, 0.022586041850445326, 0.028652420041908044, 0.01220076679601334, 0.09610298846382648, 0.03860576143779326, 0.021606507107208017, 0.06259924368350767, 0.031835508125368506, 0.0506466918886872, 0.09260648585041054, 0.03765025372558739, 0.08475822221953422, 0.05049759813118726, 0.050739534563035704, 0.05065068093244918, 0.0730030557315331, 0.08906946197384968, 0.0018584615122563264, 0.0875975975941401, 0.03325849836983252, 0.03712381127115805, 0.014327316748676822, 0.08802069598459639, 0.004857792091570445, 0.029283026633493137, 0.008668660575494869, 0.03314158784633037, 0.051801284425891936, 0.025186607090290636, 0.026170225501118694, 0.05957458743068855, 0.03137526895443443, 0.09157808439340442, 0.052909277510480024, 0.04191877174889669, 0.025064008004846983, 0.02313593988219509, 0.018625194134074263, 0.07064030985930003, 0.0797475379658863, 0.02501335271517746, 0.042629107265383936, 0.03592382156057283, 0.09354444919154048, 0.08098239748505875, 0.04888345662038773, 0.01821695168473525, 0.03794405514781829, 0.0038080443800936337, 0.019112664558633696, 0.059977710916427895, 0.023494491833844222, 0.004911874248136883, 0.04224663403874729, 0.04413516609929502, 0.023653443167859223, 0.06311317352810875, 0.024127656979544554, 0.04556078725727275, 0.054217342476476915, 0.051567797345342115, 0.04476979884202592, 0.0033397858396710944, 0.02913018317485694, 0.03682879643747583, 0.030898928889655508, 0.0032587825080554467, 0.04698782962805126, 0.06158699507068377, 0.09156730098766275, 0.06135136689408682, 0.08109567148494534, 0.009987745506805368, 0.057189332219422795, 0.038809688776382245, 0.01992469286051346, 0.048432186304125935, 0.06550056612468325, 0.010550171919021523, 0.02615795408928534, 0.05816819902975112, 0.044195179871167056, 0.029349838478083257, 0.014566203881258843, 0.032438466005260125, 0.053053610390634276, 0.056606464277138, 0.09389384489622898, 0.016631282669550274, 0.01957602631591726, 0.02853983809472993, 0.031702355699962936, 0.04315872982260771, 0.05682062212144956, 0.014023172570887255, 0.040744211728451774, 0.0432639032806037, 0.006951914829187444, 0.0483318702026736, 0.017842202360043302, 0.03576466428057756, 0.03494390461128205, 0.031151036455412395, 0.014295127020886866, 0.013907524626119994, 0.025235700159100816, 0.005134576067575836, 0.018441139654896688, 0.04215014741930645, 0.013149270489520859, 0.017184199386974797, 0.022104495619714726, 0.008726355135877384, 0.029068197145534214, 0.05525668690097518, 0.014356919164129067, 0.02756002690148307, 0.05112374070449732, 0.03103298116911901, 0.027705396933015436, 0.00869828154463903, 0.06034156736859586, 0.05150992095877882, 0.0378871732391417, 0.08665037967148237, 0.0019605832358138287, 0.03930880535335746, 0.07983030227478594, 0.037213663090369664, 0.05112165898026433, 0.08087853391771205, 0.06596622668439522, 0.02306958816916449, 0.05806774934171699, 0.042796572888619266, 0.018692503217607737, 0.04146749030041974, 0.012776811618095962, 0.029807947685185354, 0.08985767475678585, 0.02261698569782311, 0.0318456903914921, 0.018995666832779534, 0.01609445571375545, 0.02358372395974584, 0.03265204868512228, 0.02054484073596541, 0.07236375487991609, 0.03247988526709378, 0.038316290447255597, 0.05336023241397925, 0.02886441823648056, 0.03634644497651607, 0.07468077703379095, 0.0038961296559136827, 0.026933962253679056, 0.04332557575253304, 0.0878430184093304, 0.01599878174602054, 0.059227644524071366, 0.0481496135762427, 0.01265775999854668, 0.048343651797040366, 0.009923057132255053, 0.04830487087019719, 0.06057276863430161, 0.06352859069011174, 0.03211736097000539, 0.07182393892435357, 0.04153588291956112, 0.023255583364516497, 0.047435782544198446, 0.08283280913019553, 0.01768524554790929, 0.0383336195955053, 0.050664611044339836, 0.02208087305916706, 0.0322255846549524, 0.017658338983892463, 0.019735448913706932, 0.03462611697614193, 0.04359296784969047, 0.03755088757316116, 0.04840434834477492, 0.03786676417803392, 0.0854653627902735, 0.0031333604783867486, 0.030225301852624398, 0.018342812509217765, 0.028020212266710587, 0.01992566692933906, 0.024187136405089404, 0.04264054376108106, 0.09690091595984995, 0.036446935482672416, 0.034561045467853546, 0.031195847332128324, 0.05056304442405235, 0.008686132587172324, 0.039854038986959495, 0.020948370547557715, 0.01640525046241237, 0.021247122094791848, 0.060133035003673285, 0.01184110533358762, 0.01827261090511456, 0.016815483722893987, 0.016900583941605873, 0.059164365302422084, 0.00723099714377895, 0.02935806889581727, 0.024133130318659823, 0.0434356696496252, 0.06021851557306945, 0.008596010811743326, 0.056236422024085186, 0.02973781472974224, 0.06356857760692947, 0.006443750080507016, 0.026896066337940283, 0.08268777120974846, 0.04927016008878127, 0.04109509914997034, 0.06950770344701596, 0.014144856031634845, 0.02090350586513523, 0.035058310386375524, 0.05604934514849447, 0.04135738898185082, 0.055545489958603866, 0.028359492498566397, 0.05764142631960567, 0.007422749085890246, 0.00503697993735841, 0.028231054566276725, 0.07722243244643323, 0.029022018861724064, 0.12244795449078083, 0.05780516265076585, 0.029033549981249962, 0.0462561388121685, 0.013308871202752925, 0.11381806834833696, 0.06628128321608528, 0.015602218845742755, 0.07218447426566854, 0.033607767909416, 0.028666693397099152, 0.02968047083413694, 0.027504098652570974, 0.0397446835268056, 0.08192565976059996, 0.06919331484823488, 0.007055684236547677, 0.03877992494381033, 0.022625976816925686, 0.008699127592990408, 0.05601402262982447, 0.015587355483148713, 0.02336316138098482, 0.02456758727930719, 0.011675747409753967, 0.0278923309451784, 0.08108747817459516, 0.06548596065840684, 0.04598890256602317, 0.03693962135002948, 0.07398806381388567, 0.040157458643079735, 0.04094777912541758, 0.05376699242333416, 0.0967232754919678, 0.03895893838489428, 0.015251162585627753, 0.03734519392310176, 0.05042294920713175, 0.013695511588593945, 0.030167852200975176, 0.022571124682144728, 0.03240322141209617, 0.08779828174738213, 0.022662041483272333, 0.09046751234563999, 0.03503607935272157, 0.01961752350325696, 0.05396372092945967, 0.09303890561568551, 0.016627440199954435, 0.003929412659999798, 0.054372058002627455, 0.018327683828829322, 0.013086302042211173, 0.004806844117410947, 0.0782190180325415, 0.038564486894756556, 0.023936342440720182, 0.06190821142809, 0.012978911418031203, 0.12973810080438852, 0.02459088329487713, 0.04395133240905125, 0.046679760416736826, 0.049036016207537614, 0.01904754295537714, 0.044705885084113106, 0.05149430246092379, 0.05926058845943771, 0.027031677127524745, 0.07827015200746246, 0.04319027480960358, 0.06624900721362792, 0.029893181490479037, 0.043590533605311066, 0.03355129047122318, 0.04210041239275597, 0.06131811496743467, 0.02450899100949755, 0.22417222178773955, 0.08866407122695819, 0.12757744174450636, 0.1892070472240448, 0.13991076353704557, 0.13365141581743956, 0.08982443396234885, 0.12990729563171044, 0.14772510359762236, 0.11689402555930428, 0.20275511633371934, 0.14110115356743336, 0.15539215703029186, 0.15018895966932178, 0.16672047728206962, 0.11958347226027399, 0.18902205949416384, 0.12669706164160743, 0.18666348449187353, 0.205183022771962, 0.15068447683006525, 0.12266004545381293, 0.1529773123911582, 0.10968317030346952, 0.1465948423719965, 0.18691315781325102, 0.17177471076138318, 0.11516103651956655, 0.1919878151966259, 0.17426062346203253, 0.1401117816567421, 0.13164659292669967, 0.0902438216144219, 0.13543669658247381, 0.12724880391033366, 0.0938968728587497, 0.1827226358000189, 0.20972033555153757, 0.250429569859989, 0.09147762728389353, 0.10968838018015958, 0.12756026844726875, 0.11441588314482942, 0.12319482222665101, 0.2640702738426626, 0.17403805337380618, 0.18475001998012885, 0.12261672629392706, 0.10372457792982459, 0.0697537328233011, 0.13279721868457273, 0.13374186877626926, 0.17570723255630583, 0.11483578287879936, 0.15378113253973424, 0.13368337269639596, 0.16042106843087822, 0.16185284941457212, 0.09108724276302382, 0.0988453280297108, 0.08762020341237076, 0.11538426711922511, 0.14590314589440823, 0.18403798865620047, 0.12384063913486898, 0.18313567066797987, 0.0670195568818599, 0.1551897288300097, 0.14250471809646115, 0.12897780019557104, 0.12601648253621534, 0.10604905866784975, 0.1371937312069349, 0.1740412594517693, 0.1406856399262324, 0.13823683460941538, 0.1585138082737103, 0.07374673965387046, 0.15364704129751772, 0.21445410966407508, 0.11079232484917156, 0.20531770773231983, 0.14104955946095288, 0.1238199851650279, 0.1302615672466345, 0.1655534649034962, 0.16371037083445117, 0.2152359177125618, 0.14274781598942354, 0.14068696094909683, 0.17494525469373912, 0.14104057947406545, 0.10064732938189991, 0.1540168237988837, 0.16174504504306242, 0.19861847424181178, 0.20310971449362114, 0.16208980232477188, 0.12527402315754443, 0.26821454521268606, 0.07098851070622914, 0.17367885389830917, 0.21839947061380371, 0.11171787948114797, 0.21681522281141952, 0.1077020367665682, 0.20426373928785324, 0.21652675000950694, 0.10937453334918246, 0.17339603626169264, 0.20955499989213422, 0.18093233811669052, 0.12479697063099593, 0.13475901185302064, 0.06861927104182541, 0.09971225299523212, 0.14016787317814305, 0.0914068560814485, 0.1309421463520266, 0.09181085901218466, 0.1928982077515684, 0.11272787567577325, 0.17369550769217312, 0.12220170989166945, 0.1201023522298783, 0.1485207601217553, 0.13104582438245416, 0.0953919961466454, 0.1812981575494632, 0.15344881365308538, 0.28242334839887917, 0.12655921513214707, 0.11180333036463708, 0.18419228115817532, 0.1581002093735151, 0.09633333625970408, 0.10705499531468377, 0.11310008500004187, 0.09571650763973594, 0.24710109690204263, 0.1000739609298762, 0.15339107456384227, 0.18589375860756263, 0.10851216517039575, 0.11982243639067747, 0.11965906000114046, 0.11173511957167648, 0.11212198631255887, 0.1788576049148105, 0.15261768247000873, 0.13614546245662495, 0.16651813813950866, 0.20640859060222283, 0.1114725403022021, 0.1414887624559924, 0.0891061314905528, 0.12112267169868574, 0.21136484574526548, 0.12739521480398253, 0.18513939518015832, 0.12418597529176623, 0.1415776865906082, 0.09124461517785676, 0.14040822512470186, 0.11924461505259387, 0.181928567471914, 0.10347463743528351, 0.15907101274933666, 0.1988781220279634, 0.2000293563469313, 0.12030794940073974, 0.12353831785731018, 0.1415150344837457, 0.16896836837986484, 0.27166265237610787, 0.10663040520739742], [0.04874674188613426, 0.02233405117294751, 0.03985160474258009, 0.09106264056754299, 0.01806905092962552, 0.022496486890304368, 0.03913976266630925, 0.02802593236992834, 0.058469084251555614, 0.03157821665809024, 0.06819008704042062, 0.027004586881957948, 0.038726430939277634, 0.02782550611300394, 0.06757949988241307, 0.03893450317264069, 0.018239665114379022, 0.050961006272700615, 0.036487100514932536, 0.04102077306015417, 0.0711371109355241, 0.03232564100471791, 0.02281903725815937, 0.06998761324211955, 0.029046821437077597, 0.00838183719679364, 0.026194178317382466, 0.0323291847598739, 0.04489157043281011, 0.014354216818901477, 0.043402881565270945, 0.01665510375460144, 0.00673272336825903, 0.03758273312996607, 0.06786543453927152, 0.03285072903963737, 0.02573190566181438, 0.04098789591807872, 0.015327189121308038, 0.025427719738218002, 0.04843983413593378, 0.036339223879622295, 0.024771987737040035, 0.006480111605924321, 0.02578888219431974, 0.054926613011048175, 0.01621976920432644, 0.03825968684395775, 0.025690894581202883, 0.030588807640015148, 0.048710692062741145, 0.039104993047658354, 0.05859604716533795, 0.04840299763600342, 0.0377316747471923, 0.09969859747798182, 0.07972459818120115, 0.015613892828696407, 0.036350296722957864, 0.019020693907805253, 0.09657863833126612, 0.06607207920751534, 0.19393362250411883, 0.044795900175813586, 0.016498393706569914, 0.05716633306292351, 0.038256131956586614, 0.025557361805113032, 0.1021571694582235, 0.029030228870396968, 0.06577222186024301, 0.06229095553862862, 0.07851146132452413, 0.019732261389435735, 0.01056670047546504, 0.04057262347487267, 0.011755390987673309, 0.04628416230843868, 0.021500183320313226, 0.05756769394793082, 0.052983514542574994, 0.048480719051440246, 0.0329512009921018, 0.02644672931637615, 0.017513393831904978, 0.015924691288091708, 0.046942002009018324, 0.03876890034007374, 0.04986384854419157, 0.007201487960628583, 0.05002467194572091, 0.009313173159171129, 0.04382897081086412, 0.013199916502344422, 0.022282162062765565, 0.03170879754179623, 0.04534998020972125, 0.02963103452202631, 0.01372363805785426, 0.010021362013503676, 0.04022239656478632, 0.022968494668020867, 0.06507418002001941, 0.031878070294624195, 0.012950384189025499, 0.01939161003974732, 0.03456306039879564, 0.09127387806074694, 0.04993192203983199, 0.033493202572572045, 0.04403835293487646, 0.0470366221270524, 0.03869346845021937, 0.036338329591671936, 0.042595079794409685, 0.026538028323557228, 0.027466861392895225, 0.04030562842672225, 0.024174826030503027, 0.03808587214734871, 0.022333203269226942, 0.06365088178426959, 0.015430762323376257, 0.017650804329605307, 0.02928616220742697, 0.028829706134274602, 0.02421062352368608, 0.04908765113214031, 0.019520960813679267, 0.06448494445066899, 0.04814198429812677, 0.054420349551946856, 0.019498481160553638, 0.036864033609163016, 0.048827090504346415, 0.05126506046508439, 0.08149352943291888, 0.03633952444943134, 0.0690373228280805, 0.018561451070127077, 0.03394601655600127, 0.024389557183894794, 0.036047199901076965, 0.07012128888163716, 0.08231430023442954, 0.012542260483314749, 0.033694877492962405, 0.03557241092494223, 0.08656647245516069, 0.07092932442901656, 0.016418933810200542, 0.0059620275897032116, 0.04175465692242142, 0.04526180935499724, 0.07885868995799683, 0.03969080360548105, 0.06784783079638146, 0.019153903849655762, 0.07495753874536604, 0.03238596647861414, 0.04151925510086585, 0.04035772719362285, 0.04192674983642064, 0.06175690607051365, 0.05445003916975111, 0.07838062068913132, 0.052571581763913855, 0.06156407012895215, 0.007464920236088801, 0.007459443650077446, 0.05621329299174249, 0.028854167321696877, 0.029173865987104364, 0.02019765477598412, 0.035598152317106724, 0.010569676487648394, 0.005868502139492193, 0.0274154992075637, 0.045130178332328796, 0.06546860182425007, 0.005678582838299917, 0.022032017477613408, 0.06190364350914024, 0.01346438453765586, 0.08840786700602621, 0.042371281451778486, 0.023499451235693414, 0.05907498845772352, 0.04714762144431006, 0.03307500977825839, 0.1014261317322962, 0.04695104878919665, 0.04680853788158856, 0.02878842602513032, 0.01868285715318052, 0.04925161010760348, 0.03720853856066242, 0.040935136639745906, 0.09055296322912909, 0.11374392779543996, 0.02506724191334797, 0.02313225882971892, 0.009302104954258539, 0.09184983660816215, 0.04290547192795202, 0.016138058745127637, 0.02165183934266679, 0.020086406839254778, 0.022702338246745057, 0.02208650596003281, 0.0232418610539753, 0.008445214753010077, 0.010306753974873573, 0.020995502491132356, 0.02732020559051307, 0.020564390761137474, 0.01416099588823272, 0.030176605832821224, 0.024275732139358297, 0.023090628055797424, 0.007339874382523703, 0.002013129842453054, 0.01124474514654139, 0.03203386935638264, 0.008902108693291666, 0.04363478787126951, 0.02021490414335858, 0.020896546375297476, 0.038652357179671526, 0.039549368812004104, 0.10070340606034733, 0.011657880204438698, 0.050523528771009296, 0.03908907397999428, 0.05890159678529017, 0.0349260336952284, 0.04231402475852519, 0.07994787330972031, 0.05794853073894046, 0.060993325168965384, 0.03827612541499548, 0.08263513067504391, 0.043948887032456696, 0.05199313331104349, 0.04425358689331915, 0.043321620105416514, 0.058297785435570404, 0.0525525382545311, 0.048477769014425576, 0.029904436159995385, 0.010058245825348422, 0.04134269445785321, 0.02431748536764644, 0.02362005579925608, 0.03481444808130618, 0.043458572326926515, 0.03723918925970793, 0.02768224192550406, 0.018119390806532465, 0.02551263627537992, 0.019193176449334715, 0.02278502277476946, 0.016289145169139374, 0.01460183717426844, 0.05343140066543128, 0.01730400985252345, 0.03530691872583702, 0.027035167076974176, 0.017440414740121923, 0.042985486579709686, 0.044435134768718854, 0.068538183986675, 0.07731977995717898, 0.03091661612415919, 0.04563803369819652, 0.02217950448539341, 0.037055667271488346, 0.005236626939222333, 0.06695333504467271, 0.02696680043300148, 0.02969583514641272, 0.031471221227548085, 0.0461426681431476, 0.023062066502461676, 0.05201040308747906, 0.013119056729919976, 0.06206678241142072, 0.021507823730644304, 0.02719385865930235, 0.04818040157260839, 0.08872148377122357, 0.016599579976173118, 0.01666257347096689, 0.025137578959402163, 0.04486031859414652, 0.014040499863767764, 0.04934230055368971, 0.042421888501849025, 0.021488934216904454, 0.024539511832699645, 0.029519300478568766, 0.05164634254470002, 0.019596997553890105, 0.032909213987295516, 0.02079325982776936, 0.01302715751080541, 0.03191199015418533, 0.05644962620863225, 0.021422272657218855, 0.010781338860397227, 0.0662087753880769, 0.04455347763723694, 0.06439109987695701, 0.025610108095861506, 0.1292011421173811, 0.04242720970069058, 0.00609364423326042, 0.04699729572166689, 0.023820851274649613, 0.0510639236017596, 0.07354362867772579, 0.02499314032320399, 0.08712240043678321, 0.03485424203972798, 0.020017526258016005, 0.04721533499832731, 0.03249402689107228, 0.03513062525598798, 0.07383559699519537, 0.03786659719480667, 0.022309007399599068, 0.03293982757895719, 0.07394727537757717, 0.01662739010498626, 0.047877757460810244, 0.017868860304588452, 0.048903312781476416, 0.0354099251126172, 0.048614765764796175, 0.10139188903849572, 0.04553373968519736, 0.00719598447176395, 0.034609837966854684, 0.027081343505415134, 0.023807815450709313, 0.025435009483771864, 0.06826404205639847, 0.020013602152175736, 0.020889429179078434, 0.06679754340439104, 0.04112850692763459, 0.06693398725474253, 0.13436404085950926, 0.10419992351671681, 0.16204705461859703, 0.13461972557706758, 0.08469680207781494, 0.1419983062078245, 0.1387181322206743, 0.10727856730227359, 0.09101224131882191, 0.12902669288450852, 0.13250490155769512, 0.09547073801513761, 0.10983833853970282, 0.12676057463977486, 0.18196690682088956, 0.13372298853937536, 0.15733622771222144, 0.17189593316288665, 0.05087035293399822, 0.16634849802358076, 0.1858505656127818, 0.10639780870405957, 0.15475656691705808, 0.17461361858295277, 0.23708903492661193, 0.08526271194568835, 0.07213270946522243, 0.2568186301505193, 0.14944253722205758, 0.12811845255782828, 0.15202607202809304, 0.11087629143730737, 0.08408888665144332, 0.10975024561048485, 0.1286781654926017, 0.1315792356035672, 0.07597961710416712, 0.11105914178187959, 0.13301184779265895, 0.09062544879270718, 0.13460627786116675, 0.16139918938279152, 0.08796357287792489, 0.08038487954763696, 0.07335078160394914, 0.07151240759412758, 0.09528854818199761, 0.15626624372089282, 0.18132251483621076, 0.12140603852458298, 0.2244053452159278, 0.10860569804208353, 0.16378982516471297, 0.15542470762738958, 0.1829501337488182, 0.19835312676150352, 0.21198836853727698, 0.12263786265975796, 0.16468915971927345, 0.11968688311753795, 0.17486379656475037, 0.1421001140261069, 0.31625510018784553, 0.17161146795842797, 0.15028157969936728, 0.1826258300570771, 0.09398334048455581, 0.11016057906090282, 0.2486151672201231, 0.13777058775303885, 0.19341352541232482, 0.1580656846635975, 0.18073017708957195, 0.10717485216446221, 0.07461863700882532, 0.15809550415724516, 0.11432254323153757, 0.1577112646191381, 0.14459649100899696, 0.09119069072767161, 0.16827554383780807, 0.12084400266758166, 0.13222202454926446, 0.14679654326755553, 0.10133097355719656, 0.09859791825874709, 0.09335950599052012, 0.1326311260345392, 0.14268678176449612, 0.11994791871984489, 0.14292765321442857, 0.09319405900896527, 0.2556978684151545, 0.12622550100786611, 0.11540947045432404, 0.2067356402403675, 0.2117988240206614, 0.12481518293498084, 0.12448424444301054, 0.12932361132698134, 0.21172637556446716, 0.05727017436583992, 0.21929730603005737, 0.16616339155007154, 0.14744412648724392, 0.17013168486300856, 0.09630999571527354, 0.15671515400754288, 0.14207471773261204, 0.09532106909318827, 0.11572929899557494, 0.12930452328873798, 0.13231945369625464, 0.09719401234178804, 0.17297802900429815, 0.10264635609928519, 0.0905957628856413, 0.16287597420159727, 0.13638422620715573, 0.09819806393352337, 0.10323938404326327, 0.16708738025045022, 0.10760732388007455, 0.10368413830292411, 0.07156826904974878, 0.11403098309529014, 0.071644309500698, 0.13128282182151452, 0.21993043221300468, 0.0941934424918145, 0.14658301253803074, 0.21227847406407818, 0.07707931668846868, 0.18227440828923136, 0.238405070558656, 0.21113322145538405, 0.2886087930528447, 0.08804807381238788, 0.21006252500228584, 0.13488105061696842, 0.18250496388645843, 0.10761315716081299, 0.13953632034827024, 0.32770453894045204, 0.15635821066098288, 0.11126798955956474, 0.12448484558262862, 0.08274996318505146, 0.08344131827470846, 0.09250148679711856, 0.11748180651920848, 0.15514683269429952, 0.19696965959155932, 0.13856864883564413, 0.1524425356183201, 0.12232768945978023, 0.11913036141777411, 0.10135624368558638, 0.24762696790276095, 0.1544970230315812, 0.1760345493676141, 0.11463967777672224, 0.2151031920220703, 0.20073978463187814, 0.23547909397166222, 0.14971995202358812, 0.1531149065704085, 0.15422835072968155, 0.13989188330015168, 0.08792141146841459, 0.13570778828579932, 0.11722267823643051, 0.12268973878235556, 0.15063782542711124, 0.16420308267697692, 0.0778547274239827], [0.05080971204733942, 0.02749605006101774, 0.02676468950085109, 0.0970442766265478, 0.011645972444966901, 0.04043595698021818, 0.0463144567765994, 0.09203370369505137, 0.029698321341129486, 0.04348567184933927, 0.03205225235433318, 0.09030265166074969, 0.03124855094938539, 0.020371760765556246, 0.019907395253540017, 0.06942836043890566, 0.0191847029782366, 0.043094515494885854, 0.04562534668366425, 0.03681596841488499, 0.035102583206025884, 0.12860034388722852, 0.037656420972780325, 0.04816695014596917, 0.021512668099603616, 0.04472408625588287, 0.05900688898691442, 0.039916123350849375, 0.04408857777889352, 0.046932673212722875, 0.015130935589695582, 0.01692347363132285, 0.03544477265677415, 0.038592577184317634, 0.03219335318135563, 0.033791445748647675, 0.046827922778902575, 0.05167794690351002, 0.046704110282007605, 0.038735622438252904, 0.030507544324791525, 0.038314394259941764, 0.06650124094448984, 0.05279657867504284, 0.028346567996777594, 0.04775543668074533, 0.027830389444716275, 0.08004372168215923, 0.020008251267427113, 0.05404854098742362, 0.10235522640869021, 0.035678794083651155, 0.04119412391446531, 0.019567287527024746, 0.10046323965070769, 0.0682591216173023, 0.022058341455704067, 0.02061234277789481, 0.018771007598843426, 0.07671504834434018, 0.04720508222817443, 0.05303152778651565, 0.025543418705638032, 0.043036127026425675, 0.024257909462903626, 0.06080248931539245, 0.02566612725786399, 0.03134845886961557, 0.05848151151440106, 0.03330878258566372, 0.016437812191725243, 0.04508928599534556, 0.03014953043020796, 0.044068921997677535, 0.04328489492763765, 0.04893020821327809, 0.07802533233189024, 0.04321396416344214, 0.01679143257206306, 0.034569661802379414, 0.006342021579257562, 0.04385864929645322, 0.05160766922926996, 0.05885230333660729, 0.06324877875158563, 0.024711691949050874, 0.01127081679442199, 0.0483176617854042, 0.08770813306909986, 0.028789223833882716, 0.03984132970799692, 0.021236030697764363, 0.04169672858552076, 0.04937749690725468, 0.06290557997999713, 0.013538354396587238, 0.012478788303269539, 0.01935710202815244, 0.05531699753191788, 0.027228162580286153, 0.03456224032561295, 0.03960615424148273, 0.06627513823332265, 0.08003070441191085, 0.04903551525785588, 0.020483958651311696, 0.03506444423692301, 0.0616068400995573, 0.015402787994389655, 0.07490037853131071, 0.021176657028263435, 0.05557613694691099, 0.02835111921740463, 0.022912891108717304, 0.0560814949858468, 0.046260272574727423, 0.009235150246240664, 0.0016188331596822536, 0.03518955549225211, 0.0871228011965286, 0.04523371906543616, 0.04966419226548169, 0.033812021792982705, 0.01827677620894974, 0.053668123509851284, 0.029597726934298407, 0.03966370037232991, 0.034538079707999714, 0.03387229531654157, 0.011045997998735402, 0.05249968991847709, 0.021520180489460472, 0.036024030050612055, 0.028665721183642745, 0.0742472663114313, 0.0555646039720159, 0.03484687993477564, 0.07101202936610207, 0.041717794447322376, 0.045976846377016045, 0.032597760582575575, 0.05213010779698379, 0.0412924362171907, 0.02993225927639287, 0.0315109892108012, 0.021549231860262807, 0.014389551397471223, 0.08927903705625795, 0.0122901223039662, 0.01927777015225729, 0.07879979311837815, 0.022213448464754038, 0.029517888542613946, 0.03927930127247237, 0.044540300805238076, 0.061734726987197064, 0.05930647916102316, 0.0029313272398212575, 0.07939567833091132, 0.05259050281892996, 0.019589878502301872, 0.03488809510599822, 0.04054885248478968, 0.0024287503993036808, 0.05691356498573441, 0.0300306068311329, 0.041833584327832796, 0.016869430437509436, 0.03430650365771726, 0.1051710089086555, 0.020693507758551277, 0.004570976134345983, 0.03313526474812534, 0.016983936402539257, 0.021588749368675053, 0.02046778354269918, 0.04112076261662878, 0.04507887737418059, 0.010948977960651973, 0.03010170086781727, 0.0170281906684977, 0.1894721869030036, 0.03467839014774654, 0.03532984366756864, 0.00916353670618264, 0.02320228417374892, 0.03975253173848614, 0.02060938346403418, 0.02931905419245595, 0.058388331162859686, 0.04411995207192376, 0.08034020967897959, 0.028578954843396787, 0.04203217933536507, 0.032844673114595935, 0.05016221788537223, 0.034955259470734745, 0.05071739629784133, 0.05249606823781505, 0.028162667513242923, 0.03035054112842772, 0.005236994766164571, 0.06782282784115523, 0.008865241579769645, 0.03516936536470894, 0.017043978004949167, 0.029563471252913587, 0.0379437879746547, 0.06052389078831766, 0.032077140276669525, 0.036387214859132655, 0.03173065750161186, 0.017332864554191474, 0.02102636470226571, 0.0905897885968443, 0.05232569339568727, 0.005189900857658358, 0.02760369116003858, 0.025892719786497764, 0.010385450386820594, 0.030204091272025835, 0.05189423100091517, 0.06819702612119727, 0.07186337665189058, 0.02234453957498772, 0.03958633889851626, 0.011756633157347096, 0.05573451497184578, 0.07335095971939154, 0.019813587787211873, 0.02205227439844748, 0.04292594407161232, 0.060599330099648796, 0.02995857397763757, 0.05924916309595574, 0.040625256588100456, 0.03865974154905416, 0.0786902298568748, 0.019310170464450493, 0.01813148039218504, 0.018208027358923573, 0.04332706375862472, 0.042592485988279805, 0.0291675725748064, 0.022217665718926582, 0.12450155132682994, 0.01599176845047623, 0.01463206021071528, 0.044077345373807475, 0.07644665063708089, 0.033376596329617314, 0.04340754225268029, 0.06039688705641311, 0.019244106333644595, 0.0237779180315556, 0.017702192490105517, 0.04665423424739856, 0.03717028826940805, 0.02617492515128106, 0.06440955708967522, 0.0118638391722925, 0.028949896950507537, 0.029289058438735083, 0.06256480803131126, 0.03153848578222096, 0.017047163673851173, 0.02231758291600272, 0.049829520503408276, 0.03461266926024109, 0.016525535902474076, 0.036966212501283735, 0.006478005761891836, 0.06656617886619642, 0.02940800244687125, 0.054723550274502486, 0.06702826969558373, 0.039482304637203924, 0.06847406984888949, 0.07439161403453909, 0.04952932918968145, 0.015366017360065598, 0.04936116965836845, 0.012485473198466934, 0.04272430625860579, 0.03808440269494895, 0.10391583680757321, 0.06098208905314095, 0.021126795836607926, 0.07766527938656509, 0.044189405962242745, 0.009463327260164078, 0.048564110475126654, 0.014418912614928558, 0.04030211806821171, 0.04770927880599629, 0.04217427835101262, 0.0349036356783472, 0.039634370696148835, 0.0475670796004124, 0.02742795430094702, 0.04202404168609064, 0.015083333310030866, 0.07580259261885658, 0.02083619863697095, 0.0664458099345211, 0.050148076261393726, 0.037867610226385295, 0.04100376674614381, 0.031012637045932934, 0.03542893522535451, 0.02357539335207548, 0.0502079935540678, 0.018201845268777106, 0.06723115802742541, 0.030953810710343532, 0.10911106350249611, 0.006711343485221732, 0.04113188369956333, 0.019626651919679716, 0.0239149593107868, 0.002829494374054775, 0.037200660663074814, 0.07662076590349898, 0.05849423563631717, 0.039474018558394164, 0.06331513417535461, 0.03204606655344833, 0.051930432964581996, 0.020385047064337414, 0.026631640976120252, 0.040441678938805126, 0.038457543414551765, 0.02569851087173447, 0.04323875931731891, 0.06827176781371236, 0.0437876109208446, 0.03983446855272632, 0.10243833210552111, 0.03864114703901578, 0.023218826645461377, 0.06660432525677606, 0.0842396984808147, 0.02264072885736823, 0.026631761575117707, 0.04650393078918569, 0.02134283316991059, 0.008398143108934164, 0.030639273682027124, 0.032631557987770066, 0.012893185012217145, 0.010564987042016583, 0.007613335392306908, 0.16804075799882412, 0.15037863777251914, 0.16185084561584517, 0.18524276150856167, 0.0909468655299861, 0.25143431907054037, 0.15584048844175413, 0.17755969252903014, 0.10163694620132446, 0.10186436993535608, 0.21312778786523268, 0.1913432005676441, 0.13977085385704413, 0.09855293668806553, 0.07308640633709729, 0.20501565362792462, 0.19751077430555597, 0.10179243356105871, 0.1722104850341566, 0.11916034418391064, 0.17905189917655662, 0.242054715345148, 0.12446204680600204, 0.11051848719944246, 0.09633096880861558, 0.12889586709206924, 0.10328743810532615, 0.10701027349568903, 0.0998568456270732, 0.11944088342715986, 0.13873594376491383, 0.10954617726383731, 0.2601315180072561, 0.1272774804965593, 0.14891058061039075, 0.11352996662026271, 0.12193768343422562, 0.1853219635086134, 0.214813502097968, 0.16375945648178458, 0.10421841041534208, 0.15378928132122383, 0.14616472326451913, 0.15022201492683962, 0.18548392981756479, 0.09186045674141496, 0.1321338870911859, 0.19447052181931213, 0.18912820145487785, 0.14762602688279003, 0.1585065945982933, 0.11112930442322977, 0.17854876758065075, 0.08105671615339816, 0.17970121902180836, 0.24988281482364982, 0.1543260767357424, 0.19522439542924985, 0.10919638822088018, 0.10982610052451491, 0.1383738499134779, 0.21807012031786144, 0.1293211622396484, 0.1403698412468657, 0.1687196153216064, 0.11226676448131911, 0.06610560943954624, 0.11766470139264129, 0.17810433986596763, 0.13600902602775022, 0.10438445853651501, 0.09058126132003963, 0.193135991867166, 0.16065628471551463, 0.16493734874529764, 0.18652998696779832, 0.17561704677063972, 0.14718625985551625, 0.12422516811056994, 0.14113840938080102, 0.09655553527409211, 0.19910226546926424, 0.13432850682875142, 0.1793736350373365, 0.13814645586535335, 0.08722498751012608, 0.29110579343978316, 0.18466712208464742, 0.141332644270733, 0.1437691447790712, 0.20570638531353325, 0.1669394999044016, 0.10149594556423835, 0.08380874816793948, 0.23897659848444164, 0.1767865676083602, 0.19856906204950064, 0.09305936662713066, 0.14884498959872872, 0.12619479093700647, 0.09408060635905713, 0.14322618953883648, 0.17932578135514632, 0.1939448289340362, 0.14597790985135362, 0.16903718031244352, 0.10738771496107802, 0.21210724575212225, 0.12431988841854036, 0.22077278466895223, 0.13156914239516482, 0.15137930517084897, 0.14768863446079195, 0.09038431016961113, 0.14834343135589734, 0.21813726983964443, 0.08620963300927542, 0.14501507714157924, 0.16179018246475607, 0.1718139703734778, 0.14783430320676416, 0.10024815041106194, 0.13320581550942734, 0.10881063470151275, 0.19900121464161202, 0.12322641545324586, 0.20401825167937204, 0.09874605093500577, 0.09914376045344397, 0.1171340880682692, 0.17806285381084308, 0.13746994372922927, 0.16938573739025742, 0.19018389168195426, 0.1675114582758397, 0.27589479403104633, 0.1524381124181673, 0.15610009169904515, 0.08127694847644307, 0.19940498750656843, 0.09315903706010431, 0.10146997039555572, 0.08027884890907444, 0.13488064985722303, 0.08158246098901145, 0.10257834568619728, 0.18623182171722874, 0.2356353754294105, 0.095592821307946, 0.1463657116983086, 0.18642084673047066, 0.18388568510999903, 0.12618469772860408, 0.11294134703348391, 0.08639862833661027, 0.11598057535593398, 0.11648903557215817, 0.13826632755808532, 0.20830964640481398, 0.11227020804653876, 0.16274482186418027, 0.19372893817489967, 0.13713605148950592, 0.11315813579130918, 0.33036614768207073, 0.22900842712260783, 0.18387133197393268, 0.13285342894960195, 0.200984901166521, 0.14156092889606953, 0.10937325685517862, 0.087246695329668, 0.12630042823730037, 0.14472581766312942, 0.08144618783262558, 0.08089679075055756], [0.023310962424147874, 0.04484127137402538, 0.01602881460712524, 0.02289319265400991, 0.04804363488801755, 0.027664864537655376, 0.0003809203406035522, 0.016554026951780543, 0.043492232434800826, 0.057507554010953754, 0.03901180527464021, 0.044032797959516756, 0.028680046489171218, 0.04078491110703908, 0.04644024338631425, 0.025097896323131863, 0.04804923810297623, 0.04940798433381133, 0.01611750867596129, 0.01809026151022408, 0.04184706544037908, 0.09093023400055245, 0.043456542553030886, 0.0328255368367536, 0.02840603257936891, 0.06698129916912876, 0.0440336291649146, 0.013873465613869485, 0.03458335071627516, 0.010902110407187138, 0.04456185648450628, 0.036760166331077926, 0.02500243757822318, 0.043028130385209806, 0.021431766581372358, 0.018418047729937825, 0.008689854457770707, 0.0032101175656862324, 0.05671440594596788, 0.040145970197045244, 0.0072984792404895416, 0.011338198237353936, 0.0408257403614698, 0.031102563079912215, 0.028941790842509363, 0.03539752011420205, 0.019563693676900584, 0.022450006181315985, 0.0462227199022891, 0.03203214015229605, 0.03285360857262276, 0.022360980001394637, 0.0209823460681946, 0.02280789391079452, 0.02969923232740257, 0.033027252575266175, 0.06467464481829666, 0.035011662694159895, 0.021875843631278258, 0.016332178602169733, 0.09979267953895032, 0.04109315101231914, 0.06350172494421713, 0.08075951569480821, 0.10022520320490003, 0.024342620054085273, 0.03421152359806001, 0.008920646614569705, 0.020421967055881396, 0.030950701111578383, 0.02513670322514372, 0.034889972739620134, 0.025963409352698363, 0.04957665594702121, 0.008568188623030437, 0.0184130512207048, 0.027172889276698697, 0.03865977865643799, 0.038619810293312185, 0.03212956929928623, 0.05558823024330195, 0.03721488763403613, 0.09709271660540253, 0.05444263624667656, 0.08954278149758466, 0.0222495984780835, 0.015088142426975537, 0.044914617828908376, 0.017848239731392823, 0.03476010431768373, 0.017218989414686803, 0.03434188554820139, 0.03196941011992749, 0.010388420832896372, 0.012488407464843476, 0.0031471537567995256, 0.01631771599932108, 0.06424937193514779, 0.02333673164685024, 0.011130031380162109, 0.06713037437293679, 0.02757222595391795, 0.03772424584894907, 0.033585893106646836, 0.04427231127920095, 0.04058213780808728, 0.024218364123953506, 0.03774767916183919, 0.011430143840698292, 0.03425844959565438, 0.017206163247465156, 0.026962067386193667, 0.03011722474184353, 0.047038996999617666, 0.044585824143723585, 0.051837456703651696, 0.019990606706414837, 0.017330638111161534, 0.025983538253058214, 0.02635237451613648, 0.07088003098033369, 0.021246669384709094, 0.10672059841454029, 0.011319484983687289, 0.05685569602064788, 0.03817721939412877, 0.02559387547080405, 0.034843013345380314, 0.039134140897658654, 0.0229127371130744, 0.031082167006388772, 0.049053976181312464, 0.09379669776535593, 0.05957976762147155, 0.05262616672553122, 0.07653049106011167, 0.04866925053647719, 0.08932319484301843, 0.03372524988662917, 0.02459179057041183, 0.06102328195993323, 0.015195613759715343, 0.017078471173590515, 0.05365027485822793, 0.026432353915879503, 0.02208152429375332, 0.021012506949773524, 0.047437263128813356, 0.04963413157383911, 0.05659893147822004, 0.03433603371377103, 0.039356428969767876, 0.06761286684195511, 0.05251223221421242, 0.0740567347384058, 0.029587570643343497, 0.034350854402873665, 0.02649694673891645, 0.05482266780745704, 0.009509069532214198, 0.050527224666439, 0.024951390805654228, 0.006551289134222316, 0.1252952782670036, 0.028998032648814842, 0.04484937933739275, 0.06523568619741127, 0.04692257258284371, 0.06946210589376278, 0.05287546897307038, 0.06427038955735043, 0.03333020467835013, 0.024140967398125213, 0.03896413712936919, 0.020443264838831965, 0.013418949329206953, 0.0347772627719678, 0.030717093432031106, 0.036420700562302954, 0.024270837675430812, 0.029969858333060984, 0.09067222636076622, 0.00443094585534709, 0.06322272936813533, 0.026136233282159083, 0.045233804412418976, 0.0679489855247084, 0.045387911377474666, 0.013219981392467162, 0.04711887064331677, 0.04588893527397886, 0.11824520188383758, 0.04653774303733371, 0.0811530023929663, 0.023263420443981886, 0.015210802739602514, 0.010446549549669726, 0.07422661976306699, 0.01948155648278771, 0.022102380498836283, 0.010690166018321179, 0.049626583931967616, 0.03694007777085062, 0.07699940222664736, 0.005141567098689848, 0.05997831576678436, 0.04315252917876933, 0.016575877634750213, 0.042268501420039684, 0.022989274802966975, 0.07136627129511908, 0.07742285684798844, 0.021307586721377447, 0.04143273923546076, 0.048397528007626534, 0.008518406284565572, 0.01997815903450828, 0.0458712870022282, 0.04250569923897274, 0.02393916260189144, 0.03341498020745348, 0.053514350511250086, 0.03586116203223355, 0.014895365857228171, 0.007761265369481407, 0.05137950705830008, 0.019361128179298248, 0.0370238514005905, 0.01462119145799079, 0.0243031749050715, 0.04504366617766209, 0.04424897444550879, 0.011235346773901256, 0.07337562128668651, 0.008895959072106052, 0.050177257508039474, 0.045258740574354306, 0.03335323723149486, 0.023222064264700748, 0.07954295753734186, 0.06835434658569284, 0.03770574781810865, 0.032545754584134556, 0.020299967254686635, 0.013910400448367, 0.015492021047975868, 0.053459472401300445, 0.0440105891902931, 0.021712148118240293, 0.008294091221614508, 0.06395004893420264, 0.029995356671861373, 0.06381435465300456, 0.08519293522113003, 0.03451475771726109, 0.039048545295372605, 0.05294442562444601, 0.018136669859813992, 0.0394205171323847, 0.027061144101026002, 0.02709460568439681, 0.02893831202527508, 0.06291839687037282, 0.04973880037141498, 0.02796935474179918, 0.05364873490179889, 0.023612474760739133, 0.061106762441340834, 0.06481451739091426, 0.010081247764901491, 0.04021344626380596, 0.00044217578931693424, 0.01288894363824511, 0.0422752475424204, 0.10686108696972951, 0.03487250258331187, 0.044486925544333644, 0.0033477648548796424, 0.03916240930266213, 0.02876736944017466, 0.04508922662353143, 0.039731235810904764, 0.008889278815331636, 0.04033683944726363, 0.03271141307777725, 0.058037517956108786, 0.03986243638792075, 0.051731797138927504, 0.07594383816467598, 0.045398791262414306, 0.019780148468271364, 0.06634293342358433, 0.12884020601632074, 0.06519374743220396, 0.03503273597743828, 0.03007713021361269, 0.05071681000117678, 0.04003768342954572, 0.01952235234057298, 0.010842860119737452, 0.09985751355998218, 0.11796847727964632, 0.025428484150324948, 0.01680194509390276, 0.009659089118940756, 0.06826894023106433, 0.07775743186357431, 0.026695150263549294, 0.047851971539785154, 0.035062017414020374, 0.07591521352878772, 0.03099294044659473, 0.04203312928439118, 0.011073710720665986, 0.05998401546094101, 0.02566928324085893, 0.03167298149492126, 0.043914492198382504, 0.0290805279291817, 0.06467215120210312, 0.03834929746517446, 0.03512292918458115, 0.022683884744765237, 0.09556210381560959, 0.0353145368717378, 0.04841192938329186, 0.02432348563161213, 0.02184194789151661, 0.01422691993866465, 0.018148618437408004, 0.053641487829736434, 0.03569051259546541, 0.0052026616231160006, 0.07447627082001418, 0.0394149844214553, 0.04152473957219627, 0.04285442701075226, 0.06911589400260709, 0.022203551925485954, 0.04692087306466419, 0.015048250133986585, 0.030898617187631316, 0.04648355512472335, 0.08311572324601002, 0.07484413115889765, 0.0193831161595881, 0.0195141590302228, 0.0518459765589796, 0.027674239718180615, 0.004599801613949239, 0.0304806154963444, 0.0079157257823681, 0.137459909892641, 0.11926429680897854, 0.16907945304410532, 0.11639104239293374, 0.12759568373439834, 0.19697899580933154, 0.0998333640745841, 0.13058205629931763, 0.15410107240313664, 0.0869266664085444, 0.11961798954871483, 0.10875731881242245, 0.18313773383852094, 0.09305210100137629, 0.10909372693276964, 0.20730307151097804, 0.12862585892435163, 0.15737296402221546, 0.09699546557385474, 0.13779898232314736, 0.13275304605485871, 0.23972135852091014, 0.13828243216266856, 0.09647786951973103, 0.07292417285498232, 0.1316664379555732, 0.14659887965535745, 0.12734155752696097, 0.16072710044682026, 0.1765658232034184, 0.16320661583449692, 0.14335403189761564, 0.09580699770594947, 0.15960715507389978, 0.17072207818273455, 0.17187665216624737, 0.06550669626449235, 0.13020753889577463, 0.1548522594384849, 0.13345393032068387, 0.09183891219436191, 0.1254200778203085, 0.07072343039908446, 0.08680332146468572, 0.10939371044514701, 0.15482465154491365, 0.10216930357273668, 0.0979056280630175, 0.15506861032918096, 0.15729021455626935, 0.1502695569070056, 0.107107042131247, 0.09089006154681556, 0.10912406592979096, 0.13270498457131907, 0.12767117499606684, 0.1253546797670424, 0.1805130098364316, 0.08433941344264895, 0.17496425367426127, 0.14320977323222905, 0.1868014645879157, 0.13287704408867285, 0.13760667701717466, 0.21508267906028777, 0.11973711909377016, 0.12613141152542084, 0.12386652524583042, 0.12803260091459379, 0.12004203788819723, 0.14012580824783072, 0.10796977396239527, 0.07124949435819872, 0.17278936022194102, 0.25664829241577536, 0.07754510341328569, 0.25527959398459643, 0.13489786768332124, 0.16613382438663393, 0.10606065843603574, 0.1646922915824689, 0.09543107022182085, 0.17901106621138752, 0.1607948140008375, 0.12959961604792625, 0.15140210394747555, 0.2447900193510577, 0.1147077624045778, 0.08565288124373183, 0.13640028628287837, 0.06436411538743414, 0.15404149278765544, 0.19004831614438444, 0.17941653117304668, 0.13724683929467574, 0.11203196379938163, 0.11042074635042809, 0.20098898297874257, 0.22881573589984328, 0.0643393796053715, 0.10037952539278194, 0.11628674095845781, 0.132211456366349, 0.10230019615846686, 0.1964980099000968, 0.23908041010145098, 0.10210073654889129, 0.12753249728120863, 0.12903877504868433, 0.2717735292389989, 0.12623997288756073, 0.2119795369799249, 0.22130779892904684, 0.12636774103157222, 0.08654990771901794, 0.13507126306649297, 0.21530657017137855, 0.11957284470554441, 0.11166750991833396, 0.06600430628168397, 0.2342044108081609, 0.23681433638557792, 0.1554012854467146, 0.09946482095983811, 0.2776349225314334, 0.17357562115648761, 0.1680241635767743, 0.1508665701840073, 0.14469938236288726, 0.07693614155869, 0.2548821293748915, 0.12289351026993245, 0.15917713986709714, 0.0824659135832917, 0.16593633888987824, 0.18268840794917196, 0.1441670101485215, 0.1876179309329018, 0.19416806695517153, 0.04727181985799689, 0.15751423925394192, 0.11491903700516559, 0.08926763766794465, 0.18244581471662968, 0.1427377969957888, 0.1269470911938697, 0.161116371746175, 0.14688474009744823, 0.15541225438937545, 0.12977911188500002, 0.13435439293971285, 0.1274249007110484, 0.11655236303340644, 0.13635575742227957, 0.14310783182736486, 0.12595795677043498, 0.1144451682921499, 0.18454009608831257, 0.19768648518947884, 0.1328986999578774, 0.11954626097576693, 0.1401149877347052, 0.0766074369312264, 0.16849113773787394, 0.07180343338404782, 0.1854288624599576, 0.13027087377849966, 0.11501622866489924, 0.16273152257781476, 0.14201148675056174, 0.15269917028490454, 0.12276157867745496, 0.21639491489622742, 0.1618782605510205, 0.09168513177428395, 0.08790433465037495], [0.010964929497276898, 0.02518250301363878, 0.009511617881798884, 0.020423675850906875, 0.03957296910812147, 0.06985982283367775, 0.024031398570514284, 0.0029978784050399554, 0.00828015647130087, 0.07847601635148749, 0.05573119757173117, 0.023807780198694672, 0.05612121844023932, 0.019667791020765435, 0.05297733616316691, 0.03470887757430319, 0.07625902828294784, 0.05312769899319392, 0.008174165723175975, 0.030879840851412155, 0.1132132847851608, 0.0495272808620939, 0.019951519643655047, 0.033865304285427555, 0.030132153042359278, 0.03937484165362548, 0.06008070988173131, 0.10712460876675323, 0.020531046066025738, 0.05396237764216494, 0.04569035139866173, 0.11995248292805627, 0.07967244004248641, 0.06636092308326624, 0.046608402917627245, 0.036923579827998765, 0.05752858647610992, 0.020222470338921994, 0.02199425329308724, 0.017196726839756593, 0.031629792210878804, 0.03073293457418913, 0.02525045034417417, 0.04679384335759096, 0.036696063325507566, 0.0696300168056041, 0.002831335364135157, 0.039944788804859854, 0.03585082020435948, 0.042333420788054354, 0.09332858069683425, 0.05744400761614088, 0.023064823581080418, 0.050051990401698276, 0.031061034351296257, 0.07393949024844915, 0.028716547167277895, 0.024454222366330214, 0.03912735395715572, 0.020848573949479032, 0.03340661249239929, 0.017757155947037973, 0.0502817147935275, 0.09815317884203978, 0.03774552693357691, 0.028399336551956367, 0.03602905067964457, 0.012825116154999705, 0.07624039295478724, 0.029277733265189454, 0.024030324311752338, 0.011397998641768936, 0.08756811206694692, 0.04959721343766432, 0.044888475676998496, 0.05615860784018878, 0.022147610688989516, 0.01277920226129936, 0.027858045577886514, 0.03219353129679803, 0.06404512547305785, 0.030565780652977992, 0.04915609199088067, 0.027799727613455616, 0.059160190721740946, 0.057623002503532916, 0.007194207028078381, 0.046360113701666705, 0.08034508558921516, 0.0713642526534386, 0.04134105060074944, 0.05199798695684876, 0.0442202904378064, 0.01981275843718322, 0.022130120123620145, 0.04097680823178962, 0.055357767414534464, 0.018035683970083483, 0.05995378778607119, 0.05575676455919165, 0.008551002338208491, 0.028570229042088613, 0.015042849154269788, 0.06655311706708744, 0.002158466245418822, 0.07199778701760806, 0.04485716446652077, 0.0712263913010247, 0.033714384844643064, 0.033883204887388274, 0.042183158147963695, 0.029281277020345442, 0.04413470967847388, 0.059861494301003404, 0.017188887904922012, 0.08470458720694296, 0.03781897357839625, 0.05511829862371087, 0.03514669275318738, 0.05422476395324338, 0.019050313021580223, 0.04432716712472029, 0.040711230685701594, 0.0874795441632159, 0.04562654154142365, 0.03525420026562642, 0.055781693299650215, 0.03416798550460953, 0.01643437604798237, 0.05328823295712937, 0.10970458126394078, 0.044065181573387235, 0.04558141896268353, 0.02449713705573231, 0.014469278467004187, 0.01942891780345235, 0.04098782912478782, 0.02046997658908367, 0.0013245310196907667, 0.03130106160824653, 0.05439736523840111, 0.041155391227221116, 0.07016711650067009, 0.02533561364543857, 0.06389627291355282, 0.027007683493138757, 0.04218084264721256, 0.05730657670937944, 0.03832384179986548, 0.03832896632957272, 0.00969656850429601, 0.0252121555240592, 0.007142453823689721, 0.042761387667269446, 0.0559940737002762, 0.01948186632944271, 0.031499990582233295, 0.033267233447986655, 0.04889956864644773, 0.018018436458078213, 0.03258780838223174, 0.02273146568768425, 0.04372526680526789, 0.012704081145784585, 0.037734869692940265, 0.027014958395739086, 0.01672229223913746, 0.051901351907872595, 0.054144482128322124, 0.0545494350080844, 0.04795408734935336, 0.019765427969105076, 0.03940776703529991, 0.03528815723257139, 0.05340739218809176, 0.02217560449935263, 0.07987040051375516, 0.0406075637874892, 0.03140997177979443, 0.028183981994516216, 0.07447331707226112, 0.026038681680802256, 0.046555235458072275, 0.04727574581920635, 0.038243485760176554, 0.054062326380517334, 0.05733982121455483, 0.07474002268281765, 0.043707629665732384, 0.025955835735658184, 0.0851257263275329, 0.06964624757529236, 0.03336549380037468, 0.021299207874108106, 0.05315881353453733, 0.03116770509222988, 0.025344374698761385, 0.06160889213788323, 0.03406404772249516, 0.06191932508954778, 0.105042001378024, 0.038139021053211764, 0.024587161424278747, 0.029680541338166222, 0.045155066254665144, 0.060031887696823105, 0.051835664417012595, 0.08831385915982537, 0.015904573519947007, 0.027582693946897052, 0.022791225273977034, 0.017187184676004108, 0.0597680319333449, 0.050314818290644325, 0.04007747738796752, 0.029583023133454844, 0.020740340987686068, 0.05061080533778295, 0.07070996041875333, 0.028089228289900348, 0.018806354237312917, 0.021849862896488048, 0.07157041385653429, 0.038942726168897934, 0.031807243431103416, 0.04307449977204669, 0.04318871258874424, 0.05050950960139744, 0.06761789118172601, 0.07043665711535141, 0.009703358227852732, 0.05316741131537128, 0.03953516781621147, 0.006856036306999158, 0.05259593533992302, 0.03028535829798784, 0.010146316490136087, 0.029519079689634964, 0.08053975834627636, 0.04145306666032411, 0.06055167679733131, 0.04787091485923156, 0.039957171538844705, 0.05552835005801171, 0.04566756004351191, 0.019691973902808968, 0.038589872056036256, 0.03840814977593254, 0.041583287602406926, 0.016333668463630602, 0.03230272348446306, 0.07388621146674268, 0.03123496222542599, 0.04840540590521414, 0.02258383025036892, 0.025102833460550755, 0.019603179644036572, 0.05582716468779836, 0.06790367740904912, 0.015949764747347217, 0.03515117532515433, 0.03253455557569396, 0.021684731327695772, 0.02414503807813162, 0.05249386034847703, 0.013078239535389002, 0.040904103734646924, 0.028329229571681935, 0.10882355549256317, 0.008319768603541888, 0.028592161361302715, 0.009597825755918166, 0.029586158707388677, 0.053842865891056135, 0.03834419519989751, 0.00694561260388582, 0.021041968357167207, 0.056376264910795726, 0.043047177605330944, 0.009379145449202042, 0.014288197216956178, 0.06385395565303043, 0.0316132386069512, 0.05599989955953788, 0.03749608738871757, 0.025909586947818752, 0.04745510435895994, 0.03156474296702072, 0.08404302934650332, 0.027152840157214087, 0.07339610456256196, 0.06685901549644768, 0.00690939811647695, 0.044497393537312746, 0.0822932826122269, 0.034530955090303905, 0.020575005328282714, 0.016549403371755034, 0.01931631915795151, 0.03482598105620127, 0.12780179298715666, 0.03616821821196936, 0.005176612703507999, 0.008524476124875946, 0.05708887882065028, 0.05708781383873429, 0.15063450060551986, 0.0701136224961374, 0.023418820601364132, 0.02133684218279086, 0.03006715760420775, 0.07120416397810914, 0.03671970443974715, 0.03449192183325067, 0.044774084744858555, 0.04067886562552303, 0.02075154185149586, 0.007953370295581408, 0.04902919215965085, 0.0488828220841242, 0.04578293432132341, 0.019620017119450495, 0.06655318386037834, 0.01018444247165462, 0.03521211307088379, 0.030885605483490508, 0.040459419979015365, 0.01023949127556989, 0.022346623154589906, 0.024748760370130185, 0.03728539537405595, 0.009517147809674498, 0.04498790862271562, 0.025409661429875996, 0.04536571002972778, 0.06815608183387667, 0.0559131387853995, 0.014429636648856103, 0.01259938730072463, 0.02326384903426515, 0.022731645658495836, 0.020283053709135856, 0.041743361434782855, 0.02395666429947596, 0.047556667268509045, 0.029664099056390114, 0.08541626972146332, 0.027955543373536784, 0.061659413840970956, 0.08618099353043362, 0.06265454852837138, 0.019783927855314687, 0.1292208832455799, 0.16428366507170722, 0.12533058965345845, 0.08111551651381887, 0.12295021777390502, 0.11477764302981086, 0.1974443966173567, 0.07899970543803647, 0.14385826187208295, 0.14663616515463218, 0.13480438676197082, 0.17987793922657147, 0.10888523538596928, 0.13375588052440435, 0.17457369103794917, 0.1289515133248642, 0.15873398864641786, 0.11132276747957803, 0.08411088390857913, 0.09682769567007199, 0.16452584270155057, 0.22869353386340663, 0.0746849924325943, 0.17862350185168907, 0.2879888622555882, 0.08796037422143854, 0.16640383255435154, 0.27842495357617736, 0.11692164829582907, 0.14386106719030067, 0.1022853383619804, 0.25652218668255955, 0.22643036936642602, 0.11758053442463279, 0.11442713410360739, 0.13834011188009754, 0.17362363811116666, 0.15695929090725258, 0.09037756404723041, 0.14829164429102093, 0.10814726600074209, 0.11071791712311096, 0.20906301535433158, 0.19555196457076818, 0.09804360073758289, 0.21067807712825015, 0.16546520870178938, 0.1588353660190478, 0.13109462801367044, 0.20456289901630953, 0.18093146238243207, 0.16065134201198816, 0.31202907382976264, 0.20116319472435862, 0.10081983418785967, 0.17643434432102367, 0.08324322421685793, 0.13252204516902566, 0.1502304754103534, 0.12405883797327988, 0.1366572771803476, 0.16897717025130987, 0.1758832551422529, 0.19628441979875788, 0.1645667795673944, 0.1410461455816403, 0.12114343699067831, 0.14806226128712296, 0.15248831128701568, 0.14045437186723575, 0.08285312171210535, 0.14284971286542714, 0.16431563679361716, 0.11651174529106356, 0.16566990787396207, 0.1162064702657517, 0.07376578316325322, 0.14803557365667075, 0.122330175654497, 0.19238137610955164, 0.12100242151063867, 0.1329397555673495, 0.30153112777043134, 0.1008361614367459, 0.19676834461279213, 0.08881581816240214, 0.12703114683972672, 0.10742000580648892, 0.2706449304241687, 0.14408133662072942, 0.08663769636768848, 0.24202955653890967, 0.1306733998353593, 0.0590967259631725, 0.13209924363764003, 0.17837219580542296, 0.09838216850766912, 0.16470903443405405, 0.19482608477119356, 0.08945588342612609, 0.10737457894720137, 0.1734853908419609, 0.05835237039718777, 0.11921838755370118, 0.07860666402848437, 0.15417513874126598, 0.1338898975518532, 0.14212788519216701, 0.1712210092227906, 0.10627493873471394, 0.11383542718249373, 0.15708336315583438, 0.11582986000576057, 0.13436497596558183, 0.12472664471715689, 0.18541158526204526, 0.13749473146162927, 0.139068856369704, 0.2124807983636856, 0.09016141353640705, 0.2401185262715444, 0.11949599531362765, 0.12247569597093388, 0.12555317458463833, 0.1571554405381903, 0.07876764328102581, 0.11676061709295027, 0.23115036921808496, 0.15089028922375292, 0.09821894054766744, 0.19955087889684364, 0.12261432915693149, 0.16390923672588542, 0.10459056778927334, 0.11980967887211591, 0.12119422215619124, 0.07286549865966663, 0.17183433490572497, 0.12183335231384262, 0.14174484793329611, 0.1530169727629982, 0.12617913162102923, 0.15234185586450621, 0.21038347418652847, 0.19706170074641705, 0.08505421297741123, 0.12284929311135784, 0.11287555564194918, 0.10107208276167512, 0.14752985938685015, 0.12818024377338588, 0.1079486524395179, 0.09728744873427786, 0.10548753489274532, 0.13381596480030566, 0.06529631224111654, 0.13652372028445825, 0.15860264335060492, 0.16065429575974122, 0.15501992544159293, 0.14188719185767695, 0.05701595910068136, 0.16319787333486602, 0.0780626326741185, 0.13420456816675141, 0.13841646403307095, 0.08803241449641064, 0.08290480487630703, 0.10512809792999178, 0.1226288455654867, 0.19591339048929513, 0.09656879003159702, 0.1857123035006225, 0.17743738659191877, 0.17452013766160235, 0.1241512353590224], [0.04884908034000546, 0.04750997504743282, 0.05072551539342385, 0.03848498432489578, 0.027760343691625167, 0.0690883603238035, 0.02941825892776251, 0.04813936451682821, 0.023306771145144012, 0.03731075456016697, 0.025326108589069918, 0.005322825072653359, 0.0348448538716184, 0.03956336200644728, 0.030201668159861583, 0.029466077357938047, 0.042757977498695254, 0.05432215970358811, 0.02632288342283573, 0.06918885454069823, 0.01296277991059469, 0.04274615508620627, 0.0749702739994973, 0.025812206040427554, 0.05243483363301493, 0.029787581297568977, 0.010736331314546987, 0.02266911971673835, 0.025999355275416747, 0.0032241128474197467, 0.026761490844364744, 0.030818357627140358, 0.02297072482178919, 0.03243225422920659, 0.01294946114285267, 0.07214943005237728, 0.015417922240885673, 0.04131716086703818, 0.0704978100839071, 0.021152182853256818, 0.039789661386748776, 0.030700593633810058, 0.0926191765756812, 0.03369849546288606, 0.053200577895040624, 0.027966196903435048, 0.10999787802575156, 0.03153434088744689, 0.09735728483065031, 0.028783407251466997, 0.04981837344530504, 0.0023801631505193654, 0.028759638116753194, 0.049573290307307616, 0.06929020964889787, 0.018487783636373933, 0.03222676466975827, 0.07029472137219273, 0.024556471762480214, 0.020459363877307624, 0.07747302603092976, 0.01673042988841189, 0.03545040926837828, 0.008472106474073371, 0.05307331812218763, 0.045898167591076344, 0.04198878596071154, 0.011137763631268172, 0.06795918263378553, 0.07792233707732521, 0.027838310015795287, 0.06402830098522827, 0.03108302604232449, 0.04119182696740609, 0.036111187873757444, 0.040615530742798, 0.02222274757514242, 0.0780777279578615, 0.039463071880163625, 0.0038421047838710365, 0.039160639280453324, 0.038651392387691885, 0.04933861950121354, 0.06041111773811281, 0.023070842398738023, 0.011415660828788532, 0.023565400333609432, 0.032076806310215034, 0.06421780097298324, 0.02063125455606496, 0.020697661930171307, 0.039626095749554224, 0.012769160075549735, 0.05888108382350765, 0.010063145855383482, 0.02147333612811053, 0.018710850963543635, 0.023096515142242424, 0.04026558955956716, 0.01215552918438334, 0.02810434398270445, 0.06212997999682557, 0.071641830727458, 0.02838920623617014, 0.053356477146735415, 0.07979907270055264, 0.03372637424035929, 0.06318369240034372, 0.06076557488995604, 0.06611735763726756, 0.04556037536531221, 0.054645365016767755, 0.050089249925804324, 0.037512904455070384, 0.03163515793858096, 0.00565830272535095, 0.022890801083121914, 0.022713006619596854, 0.021369314854382537, 0.02449211271596141, 0.03604325538617559, 0.07001317280810326, 0.01724165089399321, 0.040803576121106744, 0.020490534079726785, 0.01371105587168131, 0.014482567548839143, 0.03878795127093326, 0.04248542005370837, 0.02548369808209827, 0.023767642996972427, 0.007279758565346128, 0.05958184563496616, 0.02144411777408095, 0.012114498622395331, 0.010554701802902855, 0.020302971097407863, 0.09573958101100288, 0.04163768702710513, 0.043850021829712205, 0.06753060719347559, 0.032944202539511025, 0.023995673436729703, 0.02895801419072086, 0.0354385868558893, 0.05587008308793884, 0.03244026571337599, 0.03388298595382366, 0.0506571598816663, 0.04529721350991167, 0.02874890480597969, 0.022901745905983262, 0.017376309879182372, 0.04382616178190801, 0.032207906697294675, 0.05262791819404811, 0.014528948995575774, 0.006956514289413462, 0.02594895602669567, 0.028579845420608763, 0.06887230629217811, 0.04853104037465528, 0.03410701436223462, 0.030641661542176735, 0.019838926564261783, 0.02337090569199063, 0.024797636360744946, 0.0348559192934772, 0.07149550147005357, 0.029667785674973857, 0.19887531670974568, 0.023514845233876258, 0.02473555941833183, 0.014996527079347288, 0.018481781517039053, 0.04035394966194872, 0.023705660678388085, 0.00985930015303893, 0.010928676510957303, 0.03890091356879566, 0.01767378122167429, 0.10049305172287859, 0.04161741155257914, 0.01975062954443274, 0.022375142034434248, 0.04445908387424424, 0.06712036280077882, 0.02626787914778106, 0.032957112198346294, 0.05767901981016621, 0.013258091603347566, 0.09030706001794897, 0.05235339034697972, 0.030298665005830117, 0.025528559053782374, 0.09163347829598933, 0.01569040268805111, 0.017137351314886473, 0.056956490807351656, 0.028043437778251246, 0.018339253911108244, 0.020152842043899, 0.03295906033599749, 0.04698410404671449, 0.04464756711968221, 0.03778701298870146, 0.021348024492908735, 0.020926805591443554, 0.031073880927579012, 0.015633940092811827, 0.07159347980632447, 0.023188782652141526, 0.03665732692752499, 0.06899626721860841, 0.028910531582369003, 0.06121756508946419, 0.052282941978774033, 0.014648147189291194, 0.056599224626552314, 0.027335475278960075, 0.08819915281492285, 0.04495519104239065, 0.012413707518135197, 0.02118907872500131, 0.026550910151854623, 0.029374184632615652, 0.06076225748984143, 0.0074294209935032995, 0.014383043690031627, 0.02574326608737465, 0.013620415520563256, 0.015686808837926947, 0.059399882156867534, 0.08230006584199145, 0.021864110276510473, 0.01958746652235277, 0.09052727749804035, 0.03880362171912566, 0.058329964958829805, 0.04304226458771154, 0.06754429239663295, 0.030219286745705176, 0.02410714587313123, 0.006117050179454964, 0.05050410676631145, 0.04792919571627863, 0.025096803510678, 0.10716870718169957, 0.03192343778209761, 0.024477544357068837, 0.041085525444941595, 0.06642572741839103, 0.029473244649125263, 0.056333609973080456, 0.03517124670906924, 0.0762267448590137, 0.030148411642585415, 0.04920414234220516, 0.04587130184518173, 0.05791757575934753, 0.02597374561446486, 0.030612276204919908, 0.0710740803333465, 0.0414894318964798, 0.05649014376103878, 0.027544978001969866, 0.009614236496418016, 0.05550542882701848, 0.03772178934013937, 0.04340658488217741, 0.010887364860536763, 0.024497547092323657, 0.01959258363058325, 0.017245261442440096, 0.057998807533294894, 0.03146977775031701, 0.059921834617853165, 0.01498437626651139, 0.06132943643024191, 0.049797225947258994, 0.0708400366420392, 0.02804823947371915, 0.017625868167669978, 0.037981333225616254, 0.017487400109530427, 0.02979474487801781, 0.025849306002783123, 0.020916142784699332, 0.023957131852512248, 0.015098542698979145, 0.03319699659186881, 0.03545266910805367, 0.008995341922855005, 0.023217691159516107, 0.08470256114378572, 0.023407450898957904, 0.03981411886343267, 0.01701276698440779, 0.048418026126455516, 0.04310467549657915, 0.07760626380331814, 0.03215544427803252, 0.0713081908179447, 0.039172116594272666, 0.031420807135873474, 0.04953276533342432, 0.04308377290726639, 0.03309947467641905, 0.04844427960051689, 0.05275484771118499, 0.004210904171486618, 0.04521920265688095, 0.02780667411570903, 0.06346740803564899, 0.021191407213336788, 0.015222668753267499, 0.03768147587834392, 0.05972418584860861, 0.05437152736703865, 0.02297496062965365, 0.05369959799281787, 0.057246492433478124, 0.029194870621722657, 0.04408664448419586, 0.02433497407764662, 0.01985958981094882, 0.025621537170081865, 0.04170137814071495, 0.02233308452559868, 0.056606913276482373, 0.04229599428072106, 0.024436783751298208, 0.012110901061532786, 0.04030158743262291, 0.049863225140143186, 0.05064255812612828, 0.05104144765937235, 0.024838721656124108, 0.04153417226916645, 0.03539143821399193, 0.035738306905841455, 0.017275440877710935, 0.03451604163274169, 0.052320709874038585, 0.046362855937331915, 0.015566705224046018, 0.03733385761734098, 0.021091562375659123, 0.06399283374776132, 0.04197178335743956, 0.03020931784703862, 0.017141327371064108, 0.11983796212007292, 0.1660834177164361, 0.12910729012219235, 0.1487807641387917, 0.11757146538002416, 0.18230201618280262, 0.1641438147635199, 0.17167339276056737, 0.09283968349336646, 0.16527383850188926, 0.16114622092572972, 0.0857219826139044, 0.07995386244147085, 0.17115351831307635, 0.07780888496199623, 0.20993146172259003, 0.13161818351363763, 0.2682612114585936, 0.08163267470081337, 0.17306860070675611, 0.12090442833141424, 0.1492972840787843, 0.3535552939865738, 0.14522324956487864, 0.11873702314915136, 0.09628151208744384, 0.10819733870448545, 0.14503089973004535, 0.09533076154184528, 0.17164676450192928, 0.12036286090733483, 0.11691415260429494, 0.1223747713083867, 0.16968621814157814, 0.16253627836704254, 0.15868935588514432, 0.1114007894648239, 0.15525238093687221, 0.14744387415703386, 0.11445385884144343, 0.12143740910687484, 0.16117923165438697, 0.1749808035674505, 0.1574457687092945, 0.2000077153206803, 0.10577818960882723, 0.19302112224977463, 0.10020494999480434, 0.20354468724690378, 0.1330600428627804, 0.10787750274175778, 0.08511995241860859, 0.1078954033437185, 0.12759284873027354, 0.122478679404594, 0.10449696812429465, 0.17711946537019685, 0.194056062027812, 0.1527289897785522, 0.09788179027964361, 0.2320257917745039, 0.13131563959177583, 0.15814313519513234, 0.11528631846886128, 0.14824745681835338, 0.0921738805482164, 0.0783975787635427, 0.07538399164332077, 0.1143683931150008, 0.14913966675521806, 0.14791487075854093, 0.3381392837036401, 0.10058834348456003, 0.17443335091229528, 0.20116524305194616, 0.12642601446714252, 0.09969943610485643, 0.18512608105083928, 0.09283846637117676, 0.081857174372999, 0.1645532576367259, 0.11940553493332118, 0.2293577411910519, 0.1570330752292648, 0.11080371681600809, 0.09769607524503954, 0.13597619341453537, 0.10026485615526326, 0.22304961952613667, 0.050128290604334325, 0.07914870642707683, 0.2068343904102221, 0.14737332559889182, 0.21034228499047458, 0.09255634635337628, 0.11739316440070979, 0.12137400000938214, 0.11931167551665567, 0.1316920420504175, 0.10976179342833348, 0.13920238357968628, 0.08333653444424272, 0.16183888219529763, 0.158813146117609, 0.16938407497946173, 0.1672788691939786, 0.2040926445624791, 0.15942443831590936, 0.16755373100750148, 0.1453641537227668, 0.13327094638952985, 0.14997004094766453, 0.13826223090291023, 0.16238936281297356, 0.11103391618235037, 0.11736109619960189, 0.08955015844549052, 0.0608291249955073, 0.1435613285866566, 0.08673758944496512, 0.10902963505941443, 0.14774667040910572, 0.11580389968003146, 0.14727616362506524, 0.12203483056509867, 0.07486321177566424, 0.15494173276238143, 0.1922275882679969, 0.148896717291791, 0.1106471978710033, 0.11514004116179422, 0.13653630710905418, 0.09176985535304993, 0.09943128330633044, 0.11682876109261997, 0.11371987478923984, 0.060880336895934306, 0.2011057228082791, 0.15067045023897663, 0.1275969305424951, 0.14558767376001924, 0.11199705317267217, 0.11939237665501423, 0.09154595682048239, 0.2052558571449481, 0.1408302251365967, 0.1523956615710631, 0.1121295487973839, 0.16476772347232327, 0.1407009133254178, 0.1300282805459574, 0.10970700808684342, 0.07048440689686686, 0.0894397491356358, 0.13510884542483836, 0.1516509015345946, 0.06385794098605402, 0.08706278371391818, 0.1817104799556546, 0.10828809594386257, 0.3078337723854929, 0.15172879735473543, 0.20033523993333802, 0.16141327534569427, 0.15477669396204874, 0.07486322661861777, 0.10814317676704377, 0.33150193048641086, 0.12385376772726886, 0.1704167586285621, 0.24568619235651568, 0.06676862933090888, 0.13415990571957082, 0.1256902195746079, 0.12881115835625678, 0.13970226456876844], [0.061262502131285146, 0.009813530978135532, 0.041543590123183094, 0.03125897441350389, 0.07294776572962292, 0.04606000402418431, 0.022038730203348678, 0.015999466377252247, 0.021887992588744964, 0.00555122844161815, 0.07488080067560077, 0.11325719766318798, 0.05394636951677967, 0.019294679987069685, 0.03555999479431193, 0.0502462364238454, 0.050695458412519656, 0.0355158704041969, 0.014843445205769967, 0.035686883493326604, 0.027725273503165226, 0.02753659358859295, 0.0680544892384205, 0.033583173135411926, 0.057644736298243515, 0.07202895722002722, 0.07983795381733216, 0.03353779080498498, 0.05374048661906272, 0.006443725033022929, 0.04639825638150796, 0.04543351264146622, 0.061934668992762454, 0.014773186085221823, 0.01651914972171653, 0.02180435069021769, 0.03996120511146728, 0.016657402557029855, 0.006473639614341664, 0.0537889822589932, 0.030069931381149217, 0.032701019299565814, 0.018089014702127315, 0.04879469575826079, 0.013995594363223063, 0.026891103225352708, 0.025728801629156806, 0.015897985103947576, 0.02440069310978288, 0.026603700971463695, 0.03887462669808883, 0.007099503418430686, 0.04209072365483735, 0.051126015387126245, 0.013605328585981624, 0.1043884216051083, 0.013845300181856146, 0.06805004377383739, 0.009191568551614182, 0.032269805524265394, 0.021204827098699752, 0.039089044294087216, 0.06748870553565212, 0.002901036714320071, 0.042011744299088605, 0.02285096445120871, 0.09497731371084228, 0.05798609825433232, 0.07519556776969694, 0.019845331298711244, 0.02528396202251315, 0.08450506822555326, 0.01910837865580106, 0.021845844166819006, 0.03654952997749206, 0.03541564707120415, 0.0167883693575277, 0.03381266746146139, 0.045299054036149755, 0.03385887357580941, 0.019631574214145076, 0.010407733370811911, 0.06670241491519846, 0.038894597892067395, 0.11593654373427853, 0.038419523189077154, 0.02949287631054176, 0.04275838939065579, 0.021809063327964395, 0.035537652438506484, 0.01960788300493732, 0.02805766289384337, 0.02257328433188377, 0.050326581331319176, 0.06836149346781895, 0.015167376895988127, 0.08001546812010929, 0.022440367538365535, 0.02524537776480429, 0.05262877908535302, 0.015763548763061408, 0.01104996663343627, 0.04756826332595665, 0.04329468385549262, 0.05879477204871364, 0.046519315510522574, 0.04335590732807759, 0.04422489546413999, 0.016898077337828, 0.043095847649965435, 0.03868058847729117, 0.02192468622524757, 0.04595807375153527, 0.07241810977575369, 0.04447574137884658, 0.011992445943178609, 0.007863640930736437, 0.06455098075093701, 0.04400857425935101, 0.05203153945330996, 0.01110503955715103, 0.0856774982821662, 0.023490168823627755, 0.013557767124439124, 0.05094358064525295, 0.013972710239613662, 0.01976374514924828, 0.012246607402630616, 0.03137764011626132, 0.03438088911934756, 0.023370864873868413, 0.0019877783097399515, 0.0166523021471221, 0.03072218085435452, 0.035168341200915165, 0.018996141807292588, 0.04766336583998054, 0.05240040540229529, 0.07756258099107072, 0.010971579140459653, 0.02608838887681486, 0.004718254413091927, 0.048000111637520604, 0.06670983639196493, 0.045253126227180474, 0.06716734817018732, 0.0022739910400559893, 0.04344609682448208, 0.020863910431216937, 0.046261456300271675, 0.09401834759046324, 0.07568286193418317, 0.04926527675706893, 0.07529737558797933, 0.06132905422418844, 0.0678576494101435, 0.03767832546145655, 0.023785705016052816, 0.051835367557941936, 0.012421825686033117, 0.03895610338076949, 0.047826207883190364, 0.04598976345732808, 0.03920613664377015, 0.027365836540411692, 0.08166026775143109, 0.0028884225230285665, 0.036835011924267747, 0.020203836866130587, 0.0697439513169229, 0.012738775621983223, 0.07370997365796939, 0.021977454780426342, 0.010979164817399578, 0.022246555672609247, 0.034787530385074206, 0.026827406545635313, 0.008532070150977233, 0.02290896329213865, 0.04024760361062363, 0.03657629553345032, 0.020310028921812773, 0.0489627179922536, 0.03684437040647026, 0.026829844500753097, 0.03829876834060997, 0.05858126729435753, 0.029128489222784992, 0.06123534323705826, 0.03221168422896881, 0.10238324248348363, 0.008939614053815603, 0.06298562060692348, 0.01840928482124582, 0.01064212401615805, 0.02820248559146421, 0.009960621864593122, 0.036817671643802896, 0.04310844189603813, 0.06103462939790916, 0.027122701540065464, 0.04596959930495359, 0.01720709835353773, 0.04700449084339198, 0.052206159380148165, 0.09236128767952323, 0.027554572116059717, 0.022787254783906974, 0.05805030516057741, 0.039287928739213385, 0.025178317300742492, 0.03228908281016629, 0.039259159384528175, 0.04679750585637521, 0.04738439994980581, 0.027098431455669925, 0.025532982253935188, 0.04235929205606226, 0.03374208179593552, 0.03543392987921834, 0.03726977687620092, 0.0044349687595968135, 0.09417744920938276, 0.044229515333427116, 0.022404445735446643, 0.04899139086774085, 0.06407633278286085, 0.060777950202464126, 0.07323814585106447, 0.015446157249243697, 0.03269087785156444, 0.03644326927314978, 0.06013714650180191, 0.0907434057444334, 0.031017503679322544, 0.049870108559844084, 0.01093772236345103, 0.048895772561081685, 0.025895773724187165, 0.03595039415813517, 0.03260204648540821, 0.040606858747196384, 0.02050127110123867, 0.0759020923578646, 0.013816513201163616, 0.0061000234563834965, 0.07555716438218951, 0.02123463731550146, 0.022050201951060444, 0.08926024587708525, 0.03566851904906798, 0.06632131466176361, 0.03114922932581976, 0.05928792175836861, 0.03348432648635935, 0.04716327333881054, 0.03349882063048426, 0.03486589375825133, 0.11159858666360378, 0.0418940916279098, 0.010587873948679771, 0.048962640066747554, 0.04668817266065162, 0.038727900391677395, 0.029482176396413706, 0.016688411342329346, 0.03201222461939324, 0.01138880435973988, 0.021228275254543405, 0.022351005536620505, 0.04602307846653275, 0.048811104643391445, 0.04660753831558395, 0.013154013740859227, 0.06970305897993967, 0.06869212767924182, 0.036294765523052774, 0.031025116259115748, 0.026577744356472977, 0.017314652250206564, 0.040927321824710816, 0.018640645648702048, 0.03887190672685392, 0.0017606427377359068, 0.019356189186510164, 0.036261739951441996, 0.06365540888509713, 0.008735607862035977, 0.029766582229058258, 0.06581011592061259, 0.040804874879540876, 0.059393251067376696, 0.04597333230776712, 0.05629401268379297, 0.036896795718348585, 0.06831069345935248, 0.01607762937055668, 0.07151690500904806, 0.009025260678754421, 0.009644149686209857, 0.08403231273405254, 0.020279172276786994, 0.08256694214651361, 0.011951417236559791, 0.052354562940308824, 0.025860035602818243, 0.01097560993002844, 0.029530158099078108, 0.016025092736526858, 0.07249041722388938, 0.0031451506538360263, 0.0329115406202618, 0.06207150247064419, 0.022776361911382992, 0.036487237812252715, 0.03881421958794817, 0.02369373065448599, 0.00984621794486884, 0.05710371806344483, 0.04949223293806426, 0.10257822694256902, 0.02245277624751907, 0.01714847981929779, 0.06407395048881881, 0.04103772371308878, 0.0500214881321881, 0.0626117191859521, 0.037635384796885774, 0.05108117111376487, 0.06680046746623702, 0.08083586784778163, 0.09387345067807473, 0.02930633749201661, 0.04616563761373982, 0.06703696766635403, 0.04291769138944801, 0.053649510446120985, 0.012700388961093267, 0.009910082535498077, 0.03521983882819768, 0.07720167457591742, 0.03552490605216008, 0.019615464043454267, 0.049305400971206836, 0.02294256402819883, 0.004669582976930542, 0.025866909745673183, 0.05898106224776711, 0.051208252771175466, 0.04019121523015201, 0.03130997109110467, 0.021642863066517748, 0.11649119522189721, 0.08434765128185973, 0.09858297140453942, 0.08827595025650226, 0.15015208977274597, 0.2043082087766379, 0.13411470892606303, 0.1245030207792297, 0.13946142280474305, 0.10944755325908773, 0.16367382748285308, 0.31973936478607357, 0.26073221233673394, 0.09643655415857211, 0.1328908183495514, 0.15963418409228325, 0.16066602169303223, 0.10045380695373751, 0.23834891966544092, 0.11806898633949459, 0.14923141105100513, 0.09373010485433042, 0.2542764478130266, 0.16495199874043465, 0.144108870299533, 0.255628225277178, 0.10469402317539789, 0.14436966099310666, 0.15838264109333977, 0.24428431992419064, 0.09589183260686696, 0.11733132123481482, 0.16480714635690674, 0.10183567850617692, 0.12324385592364706, 0.10738892466179095, 0.12414086755597964, 0.14754789357539266, 0.09888021639198996, 0.1987487360020168, 0.07242566483910196, 0.2082009514560923, 0.09495586564298719, 0.10845767668797635, 0.12830826424760744, 0.0764563430857379, 0.17864174384158105, 0.16481489437865093, 0.11180806526681408, 0.1487777807051316, 0.1587696562637575, 0.11667308077448979, 0.09026182611705735, 0.15705891681136563, 0.09206301852827892, 0.2162890846375376, 0.13879883335903287, 0.21068186208140105, 0.08090296541922726, 0.11506266484502703, 0.1052549309679307, 0.1217165902198758, 0.14614106359658763, 0.16271519532892853, 0.08709475543582812, 0.17328472895314917, 0.14061160327401012, 0.18807040352839977, 0.10325058305170387, 0.1128289858752396, 0.15494137653149664, 0.15141449781367555, 0.08097913203528151, 0.13458003551932052, 0.1376686166622676, 0.09058440802618861, 0.09828789348830469, 0.10564915981376544, 0.10994382741046138, 0.08139995945384726, 0.15778601373312995, 0.16598241141764447, 0.2359374740626663, 0.1412380946567282, 0.25059545470867306, 0.12098077306291088, 0.16578183858655393, 0.1539266825420782, 0.15605462773237377, 0.10993962685461156, 0.14684982947073877, 0.16626846481813118, 0.0701370149909053, 0.11932694891584106, 0.193062073958572, 0.09690399587270804, 0.2150322575471364, 0.11170404584845528, 0.11150492762681097, 0.1760840803035535, 0.18464150314684957, 0.20138319698162377, 0.12183679587906227, 0.1528961956501007, 0.08987765337224118, 0.11586791733861901, 0.11381368967704475, 0.19184545642929152, 0.14691169490106404, 0.13927066116593778, 0.30147231998853385, 0.1739280522451736, 0.11163998366100714, 0.21689944172976539, 0.1579814509022981, 0.1319575379602611, 0.17548862553667277, 0.17396133014699444, 0.10724928957642987, 0.14722678111866117, 0.14232974936021492, 0.23075048520695418, 0.12947131355758756, 0.07361946132732555, 0.15747932862723246, 0.11603881910559721, 0.23793253028998151, 0.08176056158845313, 0.13478284963639453, 0.1804246794199571, 0.1627297859522514, 0.10023786424426362, 0.10851891129277647, 0.13263169006677344, 0.14055215724511072, 0.1340478562633507, 0.14312426297692582, 0.18573538429336622, 0.1857723284047097, 0.12668083829339594, 0.1728980996995233, 0.10696663521230221, 0.16747317829867825, 0.18287186685483903, 0.18780441780108958, 0.18987061630468816, 0.09899203578243032, 0.1978303282521665, 0.15792969352332875, 0.1239772091503255, 0.09703856951091439, 0.16798105963971466, 0.15039990772493184, 0.23504351265728474, 0.10530783125432208, 0.17227702599484473, 0.17138183262431994, 0.1547960046445951, 0.1538308267481625, 0.11573912503081374, 0.12432955860276707, 0.14543841301929206, 0.15052831411594525, 0.13220974942669272, 0.0990656939393375, 0.09005424741189927, 0.15053111943416297, 0.1631253061350435, 0.08101019833702594, 0.1230301841860637, 0.10332844176446088, 0.19164414145052433, 0.16507427499163896, 0.11269815266132355, 0.1348723823321052, 0.09979234557249583], [0.03413092636037618, 0.05980042667943053, 0.03421572044317145, 0.045740628193016164, 0.022838392469566315, 0.009876895546767628, 0.04827395299798809, 0.09232171636540443, 0.03830819361610338, 0.046455809933831915, 0.04918854981951881, 0.04118272081541363, 0.05749329735408537, 0.009786971368157538, 0.015139985152927693, 0.02367998236877611, 0.047470425997744314, 0.021809981735714246, 0.010531906737014651, 0.0027163133745489176, 0.024356173526030034, 0.07127015574951656, 0.026434014471306, 0.03761146166652907, 0.057228922087233514, 0.0739311336656101, 0.044256919136387296, 0.02605483266961528, 0.03189132134139072, 0.044709510475513525, 0.0271505135242478, 0.03457632257777732, 0.03322624463180546, 0.024341911303054076, 0.06339952378766611, 0.0952283080550842, 0.02563362675573444, 0.07444390575983562, 0.03479347869870253, 0.04684342253312934, 0.03100862759310985, 0.01825673822168028, 0.0841661961749196, 0.01971650002815295, 0.022192453106981702, 0.03312403234303929, 0.05556463736866135, 0.03766159374208655, 0.024890670138120186, 0.07357978611253202, 0.05273281334666535, 0.05140711124113295, 0.01035731278534513, 0.013157187349861488, 0.04073603697179351, 0.05379599184379913, 0.034631196976988576, 0.03166656562825665, 0.028925879196322057, 0.04647797417419497, 0.03833454356936272, 0.09880563797196373, 0.02115068371494999, 0.04420109478814993, 0.02830813216860406, 0.032355438233935274, 0.03961905276810285, 0.04684525563789066, 0.053241284695104696, 0.048157053606701083, 0.05730082135414705, 0.04505100230744574, 0.07338348805205896, 0.0304629542370094, 0.03653603773273062, 0.027295757390675135, 0.04450288543011993, 0.09320904297055677, 0.03377755645487923, 0.011574691015994176, 0.04681294994952623, 0.013651476256200112, 0.04809727361134719, 0.008128552399284672, 0.023652357776882127, 0.012766794479830423, 0.049340148325427435, 0.04625178982678335, 0.03864076854370069, 0.023852938029449433, 0.04566194569633808, 0.05401206813985482, 0.054472782285301946, 0.014451314782490954, 0.05699548695702106, 0.014239756310416851, 0.037305975129129365, 0.008729683668207144, 0.026039459080493543, 0.03560444944014307, 0.03591142769437283, 0.02976820196636254, 0.014119790921540698, 0.13059716642601416, 0.04044731555040926, 0.020370051970530767, 0.04200956609565765, 0.02813944756780984, 0.04409347224282101, 0.014984979261498665, 0.012087969626008999, 0.026144016555917915, 0.05381622278946452, 0.02279528482176829, 0.06170691500301473, 0.04997222808015067, 0.0228073447215138, 0.029665672409464605, 0.020596366193785798, 0.01983634017960867, 0.0250149594648974, 0.04122336824366357, 0.01804443760192953, 0.08380002051126212, 0.008856578861013986, 0.0651613378431648, 0.034180564907728694, 0.02170230909541715, 0.01879681207356043, 0.0419295922620222, 0.019617896432464477, 0.02583651694294531, 0.0421829800325213, 0.02113896334776655, 0.05647815065458417, 0.06377695783157833, 0.07383623524219729, 0.05569510693021584, 0.021420639932330232, 0.0441849901835667, 0.0435923184704734, 0.026293473965779413, 0.03593759953218978, 0.07085174773237668, 0.027355108795745764, 0.025978730991482735, 0.04968703928170726, 0.031010709317342844, 0.036584689223673195, 0.01703268993878737, 0.029458054741553497, 0.00860823120092391, 0.03372977327671833, 0.04643623949959874, 0.030996927634987514, 0.03864702484861482, 0.010170055011258228, 0.03308708452095743, 0.0908883694501128, 0.023776212947268505, 0.008689062215125887, 0.05602873570751399, 0.04345117311459035, 0.00963997046710574, 0.126745761372149, 0.05636329959088471, 0.02607559239550028, 0.03224402331397869, 0.040759830226306804, 0.02154760655685095, 0.045137280685594305, 0.054266721272142604, 0.017560405176482163, 0.012388020859361859, 0.022603124234592542, 0.01652018316235626, 0.02578144772996893, 0.006861707242933335, 0.11603149410802871, 0.06034447287674993, 0.018747834037640132, 0.034496701264288276, 0.03768881942960434, 0.0387030013371259, 0.08547708872356452, 0.0282347782922443, 0.037389841527328826, 0.05643232674628962, 0.02998335057782242, 0.027316186860844027, 0.027462083817226812, 0.06730454158969223, 0.0219465016562026, 0.03618948074290529, 0.022783354797866195, 0.05422247442766093, 0.043963633506791666, 0.06094400945585221, 0.06820111535489559, 0.007214017268779571, 0.06052895594621077, 0.03312171684228815, 0.05484156288730446, 0.04803887029993348, 0.06732925510732457, 0.002422803013359953, 0.05060665302153211, 0.055435574176954105, 0.03473028482403606, 0.04489999009820167, 0.03695739207614679, 0.06434529452235438, 0.044829293110524304, 0.045602944956044666, 0.05845530999067705, 0.06625026144320145, 0.03074676078540506, 0.011830526946141617, 0.07446235555107705, 0.03621573792770505, 0.04539756671874784, 0.07739672582829371, 0.06955189834116027, 0.016524498751095962, 0.02480487044522306, 0.01695457518508192, 0.04407297783473041, 0.023201211770356167, 0.07914688816526905, 0.03991970050265081, 0.06849853845778853, 0.030314066425489727, 0.08598169719334692, 0.030056845462240744, 0.017982356948778033, 0.12398897219100036, 0.041691411097417586, 0.06708370812702924, 0.027222127064305823, 0.0050961068427568534, 0.046273779662442394, 0.028890061294077896, 0.06249439305975102, 0.045261033810675144, 0.0016503729284522706, 0.027119764490635134, 0.023098268466128502, 0.10673244309145957, 0.037066257718834095, 0.018264237623952795, 0.020752052078023553, 0.023008798852970358, 0.12745457177516073, 0.07109872705768794, 0.021926010958850384, 0.044888542470289394, 0.05626744379696902, 0.04504352516960353, 0.04674666502978653, 0.04845428375119809, 0.028822319909522776, 0.04232736486301292, 0.08194933427148499, 0.061856854808866046, 0.05029498068324756, 0.027860320260515437, 0.015784709248691797, 0.03604230914788786, 0.016927416290855035, 0.017069420682673808, 0.0751087290700525, 0.05967674405837897, 0.018813705210050102, 0.022441447363235056, 0.027263208648946602, 0.06655516539467499, 0.05935880428296514, 0.05513831063581165, 0.025557228218531236, 0.020211583032505587, 0.06050847267033532, 0.016434639510407578, 0.04608621296938509, 0.012384731289785122, 0.017816099170886446, 0.02534955488954438, 0.06777138216421008, 0.01868040992121678, 0.11814536817837507, 0.024988657751237042, 0.057636635756352916, 0.02447368147841189, 0.016219533572439104, 0.023237736568262335, 0.02503181734937243, 0.022221389444894157, 0.022652165353065357, 0.044491690132417716, 0.021941445775155444, 0.08652175805764273, 0.040373731608269736, 0.049956772854784504, 0.042455133007024415, 0.030861138729960658, 0.011421410617913352, 0.010764537564682541, 0.041577754891477525, 0.08718861485249363, 0.07023581711109728, 0.031078632528078742, 0.04697157288319431, 0.08264227755717002, 0.015758069857838564, 0.049747056764317676, 0.017438457325624768, 0.04378958503366448, 0.00796114243712509, 0.0497584932600148, 0.043316777591826394, 0.052388842741493136, 0.01805658841476543, 0.04914885234029498, 0.03242453218263108, 0.04240007678163238, 0.065439272148069, 0.06826704033301212, 0.046404479289776646, 0.039255452356883325, 0.046673849210492335, 0.06310555909294635, 0.03507769899442792, 0.026494243466004264, 0.009767451028892538, 0.03147251998598222, 0.04442567238584161, 0.051900698817917146, 0.018135230093321297, 0.021311048840289004, 0.028430571692297235, 0.015347981316153891, 0.06316516839433461, 0.03469365241471678, 0.02354902298975503, 0.011801019154518144, 0.046634648970211856, 0.022928626494831406, 0.03364734293427318, 0.05168769872398116, 0.031095076665224042, 0.016152541757037397, 0.017237973552255426, 0.05914860579650849, 0.16181100712856278, 0.10221494565485045, 0.2545189519878477, 0.14203532453393564, 0.16303532815072685, 0.23102200735593215, 0.1686604809947312, 0.18147023190977052, 0.17014866520185024, 0.1920801680535078, 0.12994440301554278, 0.182585665024817, 0.1214772995444946, 0.05659433016262483, 0.19649443274829537, 0.15147523517953232, 0.15653021080652252, 0.08927617236622609, 0.12777290859958157, 0.11513127639773302, 0.0773138650401961, 0.19099998695310205, 0.18618224625242874, 0.09756405459484085, 0.12173436465673149, 0.17967128078453243, 0.18101636407664046, 0.11766234136302955, 0.14067389914998785, 0.048248092862195335, 0.20606473874067888, 0.1460023265099153, 0.06738678639521822, 0.11144494725158438, 0.10162611826672219, 0.24502314277924597, 0.1281972389551811, 0.14786841231398284, 0.10013388193328865, 0.12045047144056298, 0.09871810165350325, 0.10399322054581717, 0.14355556952068582, 0.10115287295775488, 0.1497470700996928, 0.08681945575517602, 0.13078951626084745, 0.12053236001520418, 0.10022459464380518, 0.19771363295149058, 0.13556669116951525, 0.18326667457586154, 0.1345780465635471, 0.11883675295393914, 0.18189154914580286, 0.1493909876444377, 0.1471414341358468, 0.10971797702950425, 0.229820188251324, 0.2117991357226856, 0.1133157753793057, 0.1603970376891084, 0.12440752863767557, 0.12111496820580214, 0.10777801042422652, 0.1497057918459177, 0.16286693484289572, 0.12381524284137413, 0.1332667755195871, 0.08474378002574667, 0.1969060575356707, 0.14169203670462593, 0.18840309348888695, 0.20174644858343527, 0.13327320251846686, 0.10362457353039645, 0.23566789634060115, 0.2640076068928465, 0.10068665578728542, 0.11118462411104701, 0.11165901974891312, 0.13706847152207047, 0.13891202572267503, 0.15040639409562573, 0.11055103037506342, 0.10707989436923526, 0.17677933908998966, 0.13297533412696794, 0.11331043933751062, 0.08010140139958821, 0.10251620566123165, 0.16403684159740806, 0.06035119673470035, 0.11328775930451229, 0.2774342754855752, 0.18166761350585148, 0.13086077728075907, 0.16008186241379008, 0.11056153176468797, 0.1683489719289355, 0.14329255238408223, 0.10284255025908351, 0.1845584122929722, 0.2994832454714924, 0.10146971806534566, 0.10491986613487825, 0.11030682668206282, 0.08731541820452549, 0.153710494923871, 0.13192957383580506, 0.21788958547404036, 0.06972117480472662, 0.09701833114377223, 0.14998008962720633, 0.15388442465336993, 0.10843381664017215, 0.07208206530776806, 0.0887020469235722, 0.07524831220507622, 0.1111540624697227, 0.1392563822446391, 0.10968504793709144, 0.07852715774788521, 0.14398427854757756, 0.1601033698534593, 0.10982449006405659, 0.0932596054917667, 0.09557849785778672, 0.0839544837072026, 0.1545230724150315, 0.17313757591182366, 0.16276730893878266, 0.1606102121877484, 0.1208870175469201, 0.16684595961123705, 0.23274929670151323, 0.19739630544790998, 0.16586310375714675, 0.13273557589855045, 0.1429572797496803, 0.21662118087988347, 0.08456737894448452, 0.16191559057915583, 0.10655528501956724, 0.1325518052908592, 0.1315549822174944, 0.11205996503122151, 0.11343824458890595, 0.1591733400709927, 0.17954820301383734, 0.18827409337973222, 0.08289192119264044, 0.1691437972476706, 0.2227350528119132, 0.09074316083570011, 0.14622495596995577, 0.1423259940929711, 0.11412378866225481, 0.18666967400349677, 0.11560867773368955, 0.07410429156152532, 0.2621330606052652, 0.10628748103044927, 0.09357788294437341, 0.33223086793441325, 0.14907349686836824, 0.13388661725912243, 0.08697873548953794, 0.1623267849208787, 0.07065713434712961, 0.17230349098099396, 0.16791920905234292, 0.13518717169063166, 0.22441837732912973, 0.18817734700860456, 0.11195489176316187], [0.03138241954729892, 0.025632860488258302, 0.06347494083456695, 0.07027693951386027, 0.034526491072028875, 0.03560595228918828, 0.030186064504960086, 0.02967817388707772, 0.04048720598802902, 0.0671308790333569, 0.06694511204841547, 0.04546589254459832, 0.007616012226208113, 0.02709101183427265, 0.03953253690269776, 0.03632498948718421, 0.05539344245335087, 0.04063905311340932, 0.02101696725731017, 0.01638691199332243, 0.04272649188351352, 0.06866781492135487, 0.045279821279109456, 0.09288691377150826, 0.0385200582240941, 0.024840460137056652, 0.042379497026558965, 0.14851348707452416, 0.034355362950009294, 0.032401124844909646, 0.07669519589398988, 0.06935103607247584, 0.01694626498647267, 0.0188736614654772, 0.026999094989150763, 0.012433704687282443, 0.033768209104891866, 0.03217790166672785, 0.012484352555475198, 0.05107524506456684, 0.04678094854170922, 0.018653533043107018, 0.018417975370539352, 0.05735395541705657, 0.0745649055170361, 0.02623520795168588, 0.04706020758021623, 0.05739950844144914, 0.008167862106347457, 0.07389877602690831, 0.039586242419318296, 0.06726940831867978, 0.05329804043867625, 0.029036030609859154, 0.07136250860639848, 0.027424711115600076, 0.02820956568029942, 0.02698851196328178, 0.044140635727671906, 0.04284056740289088, 0.05129686891450547, 0.06467259649070911, 0.058166057933703996, 0.02855490554793505, 0.020494055570452474, 0.028722263559757266, 0.04710321874881629, 0.07427460703183897, 0.10780004478874616, 0.02509803176508285, 0.0632303289603442, 0.04630828581866808, 0.07305940700462088, 0.025542318471707404, 0.04692156697274186, 0.045038326425128616, 0.002004725483857328, 0.009128788424277445, 0.02678436754649738, 0.08118406869471073, 0.044144031053292565, 0.04636129000573419, 0.013055084527877625, 0.034581243016873486, 0.01610429102584021, 0.023061780775606167, 0.022113766899565235, 0.028590036963578314, 0.00927851207961794, 0.04159584474109579, 0.09574819734552875, 0.012675503821810707, 0.029147137538529932, 0.028481445915531367, 0.08747607833356597, 0.05064003482402768, 0.010453535942360759, 0.04154861075221561, 0.06643225831794553, 0.030481227768177632, 0.008250110622611828, 0.043437814456410706, 0.029319835302885622, 0.062263162108138204, 0.09006270047393627, 0.011509858850331511, 0.03466568457952235, 0.04748385887069162, 0.03746966693142895, 0.02517728200473357, 0.07398698769975454, 0.03942507020838093, 0.04936466517392546, 0.07341259508393705, 0.0419541796145495, 0.01903268330352148, 0.055690357185085304, 0.05602118806564249, 0.009459809480176773, 0.01291870004934026, 0.03420292952796444, 0.023207026497402694, 0.013230391869001323, 0.06808594145695679, 0.0492174787359545, 0.05942356037849095, 0.03361664028489031, 0.06028872274328023, 0.005574400147452252, 0.04139426629990339, 0.04355015335022472, 0.054985802998999134, 0.032510602759430185, 0.028766502982762177, 0.028781177097698674, 0.008081535488599911, 0.014599447458749637, 0.05594284324615728, 0.02130045097146649, 0.041152979247272015, 0.05511172319529578, 0.03962094895541668, 0.031016963766887784, 0.020889072948193643, 0.028906768893648405, 0.05064610930276103, 0.05267453991109505, 0.02380713453021599, 0.02596542613900965, 0.041806685185292736, 0.005782953385278233, 0.014041526810615323, 0.02886288013542071, 0.0522817322780611, 0.008201654873118969, 0.040477958827978, 0.0385015787469456, 0.046553836509701796, 0.0448132478777552, 0.0274328283558134, 0.02186392102885293, 0.03503831321722828, 0.04058395978063345, 0.00917018078325782, 0.07355165871558711, 0.061678060301346704, 0.055979063763516024, 0.03259388657170348, 0.02349015026993584, 0.06806292003602721, 0.04410019610077143, 0.07636850990820676, 0.03061240422539413, 0.06231166888028383, 0.04568044743791688, 0.064514467085246, 0.02356162094656611, 0.043910165477427654, 0.020290560532885138, 0.009269041347579332, 0.01594355853740126, 0.01799465433578007, 0.0592405838688137, 0.007495272684536758, 0.08822640447760932, 0.01563637804792961, 0.02418732565274695, 0.02187793463235721, 0.03265023413405288, 0.028091977947042324, 0.03298662370070815, 0.06309250471531413, 0.024472308505210094, 0.07123977964511141, 0.07666757315746509, 0.05817158322315663, 0.06345985297230072, 0.053871612981311046, 0.023939984530443326, 0.03712780773639679, 0.09209601441398263, 0.09999114467063919, 0.018344740237807855, 0.04182497170404531, 0.09103235352085903, 0.03054279448406305, 0.06280549394432455, 0.05087574463686906, 0.04496070519962814, 0.04136069896048866, 0.012420329330780078, 0.06765537706087343, 0.03356829307449516, 0.019688231623149477, 0.018096874046023004, 0.02790975100651849, 0.10108902599313296, 0.04699754805187695, 0.02150965498003643, 0.02380960031587165, 0.026606662140693516, 0.05920300151046831, 0.06960799728403799, 0.08486115810228512, 0.06646346562774852, 0.06743827660102397, 0.014757659428141778, 0.04766571473737713, 0.050202724305563606, 0.07688918587518856, 0.032043747341958806, 0.02875550064345589, 0.028681239491561428, 0.06299430373474024, 0.04637379519408569, 0.009843272546277149, 0.0313530342100421, 0.07360150877502747, 0.03428335978242103, 0.028774484781024512, 0.054384704199037515, 0.0233723510245909, 0.026120815164176747, 0.06798238217015751, 0.06757430484867655, 0.007598843567393487, 0.04322570493968669, 0.022201525862328708, 0.05878264535567723, 0.0347283070004778, 0.016802627869765274, 0.07173125210101716, 0.020747970265801996, 0.031143347805482335, 0.01775874785380438, 0.014953523332223995, 0.027524722936504986, 0.10226181970210746, 0.021903137967456132, 0.05435471401142422, 0.013841290729033062, 0.05448955111205578, 0.06747829320374876, 0.06133430120826233, 0.007120452855815529, 0.012269651087990496, 0.05439184737042524, 0.02635257118527079, 0.021701297919207718, 0.041272628295701, 0.02709354997932678, 0.025279915462306235, 0.045127825724193826, 0.07282299586222507, 0.04858457890804857, 0.04054221397382207, 0.0477324486564612, 0.04882189918134827, 0.04607685077644419, 0.07735014864010736, 0.047675841342424974, 0.03212249663192779, 0.03656807624793146, 0.05888827894523274, 0.004686774827860063, 0.04504581469518598, 0.029795221707900055, 0.010224734596704366, 0.019651779184641782, 0.05290654269629158, 0.05042714605224319, 0.05866232837433927, 0.0382225609064335, 0.06505512166768312, 0.048318782428395934, 0.06334901321679354, 0.040103211358655244, 0.07452802819898352, 0.012087588347640121, 0.09784956622752361, 0.05413419225078542, 0.039386734570143744, 0.007587998934468487, 0.019572230230551213, 0.01847726740379585, 0.10529604594921693, 0.053862855638726614, 0.0254625338857295, 0.08057196013396606, 0.03766613197512925, 0.030914311755623203, 0.040563138827565126, 0.04417838506924454, 0.02275615137477871, 0.051580454673967324, 0.059603794652502984, 0.04494151326071005, 0.04418540578626562, 0.033333458995912224, 0.061513348045991734, 0.043372056461521424, 0.003687369080580538, 0.06389700021827593, 0.0292366683788714, 0.029584594631160144, 0.10466324631124735, 0.07313371825148351, 0.04402671977004502, 0.006888153211548342, 0.02450704101647716, 0.032473695755470544, 0.037752473435830325, 0.044622419445659034, 0.003349915923536173, 0.03515634438372217, 0.019220865979150403, 0.02390239475062117, 0.040474945708410814, 0.005455552618514048, 0.04257383210642729, 0.08667196874739602, 0.035174456497770734, 0.016387771029258147, 0.038707461644662544, 0.09431874670553952, 0.048304106458090246, 0.08964481938164681, 0.04448901097930502, 0.04907037022348959, 0.047549197552143596, 0.04488992286496796, 0.062232593045337126, 0.15529680589679629, 0.09417664026841521, 0.15297950914828107, 0.16915927844820544, 0.1641776121687144, 0.14489447814412415, 0.14511183835566044, 0.08903655514586717, 0.15620059333741665, 0.15219198656268418, 0.14494580507744104, 0.12576663109939545, 0.08822381438221782, 0.1112965696665924, 0.1684356844634749, 0.0965159194311127, 0.13678598043043166, 0.13717143709072843, 0.21844046685146168, 0.12121353283873759, 0.17467149125877768, 0.11334498631185852, 0.19497400964610279, 0.15924142469884828, 0.19098254648270085, 0.178725101868622, 0.11719806119799614, 0.26185487397015095, 0.14140387560473755, 0.1915785949677229, 0.12374074605759233, 0.17486162949353456, 0.18008994113188237, 0.12656090722884983, 0.08720644123968668, 0.10013620485551655, 0.15786759060574695, 0.11308950939564966, 0.06422052465495653, 0.12093689729226753, 0.20453741366509348, 0.14051224454306066, 0.12056140767526813, 0.2088910894235596, 0.20902452757582068, 0.18570807325886562, 0.1568112027598545, 0.19496839900966734, 0.14380237815203145, 0.18185098335379735, 0.13301153609063476, 0.2099522715434432, 0.13294033444253728, 0.19398024422116578, 0.14240371179766953, 0.1289282989455387, 0.12574117543408647, 0.12766050291247666, 0.15016605699202046, 0.152689462993294, 0.11987755569862202, 0.14700668980367482, 0.1227602650760673, 0.08507177219144069, 0.21084816253278404, 0.11238456558203325, 0.11031038156943396, 0.18720002757618204, 0.21416790783405304, 0.16635357431368902, 0.15459961752640083, 0.0960139455855824, 0.18449452822096646, 0.19055262033361942, 0.0784855084202718, 0.10204057805822231, 0.10216801965725608, 0.1002482691546902, 0.11730447775335051, 0.15539674350293353, 0.146335699246265, 0.2328743931138888, 0.08739189652260393, 0.16623155039269477, 0.10877461827476509, 0.16768409666838124, 0.16185195883736014, 0.15052829927299172, 0.14556247042492032, 0.1275234727654606, 0.24151039455318823, 0.1083601065329276, 0.10728846755228005, 0.1446927327197045, 0.15772696846397594, 0.19086838932707906, 0.08689107300597243, 0.10784118203446269, 0.18310506449779496, 0.14624269329942763, 0.10849194164620712, 0.10052962476038374, 0.11234481615247205, 0.14479424367891625, 0.16868841543328017, 0.13197293010307476, 0.09753738922881894, 0.1947245589690283, 0.08860005356837064, 0.12767068517860025, 0.14943639223929495, 0.1571635447908193, 0.15181490132817999, 0.19357506127562374, 0.1928554303594865, 0.17051997652743012, 0.16353841521777213, 0.14928226300980896, 0.10830720624653623, 0.09759035630850121, 0.18601315532578155, 0.15362556354375556, 0.11248517854255624, 0.1494058602838777, 0.12236672642757185, 0.1494458323577419, 0.11306450644042343, 0.13175908767152578, 0.134673991415184, 0.19942838000133634, 0.18172962736571208, 0.1765375176910311, 0.1506891820463352, 0.11499950065626763, 0.09399105139891617, 0.10612832746119238, 0.10695821183617227, 0.10781022705486976, 0.11204210153664462, 0.1029025528987404, 0.09061027929419652, 0.14784291211981326, 0.12969980598427355, 0.15112577268155292, 0.18878377071814612, 0.12084986563422717, 0.20036649919347838, 0.1104478124761954, 0.13727621349971741, 0.13941399956820533, 0.13764227041974664, 0.11486718314699829, 0.07130655067157932, 0.0896056488272734, 0.08090288378298283, 0.10058515967102721, 0.11892158785485663, 0.1345014272374101, 0.10173736620345153, 0.13494177313987166, 0.12596655084053054, 0.13557688827859238, 0.1866026729112491, 0.11434890431701206, 0.2087987365666777, 0.10857795656193048, 0.18504975858377293, 0.24118925241054967, 0.17840557760791853, 0.13692442065803334, 0.1947838714113459, 0.16860084200743586, 0.13661737932125106, 0.13291017356095836, 0.15076872543431818, 0.17172192921862006], [0.027764084115915466, 0.04190499377727974, 0.05273345159366727, 0.06078323058318347, 0.008190080152417067, 0.06067399757739622, 0.05663569376338273, 0.016815346425573807, 0.044105884662712924, 0.048539827403146774, 0.018589381797937676, 0.04624235341907479, 0.024016525931074284, 0.10006725933635607, 0.029544613280449994, 0.05200978339416906, 0.024575439201726113, 0.02283453144627856, 0.033480660276836716, 0.02182455937145278, 0.009205037604260724, 0.02737273294769693, 0.02384282255661674, 0.014244176727515878, 0.015324834657803876, 0.009313591544923838, 0.015063576411193935, 0.00841970064357156, 0.07385286677163094, 0.02684289516764693, 0.07213889897684567, 0.05963697607512586, 0.024956162815215066, 0.02697964144317666, 0.015467771372641437, 0.04356542674941011, 0.05799323400424328, 0.01861274089606013, 0.08791059095528908, 0.08909167445381172, 0.071075208397815, 0.02338900481845485, 0.011196191990165971, 0.0592194920318434, 0.09190947559545748, 0.04789835948031396, 0.04994444207113702, 0.03385413496289402, 0.03888658269715961, 0.020941338698321488, 0.016857927148521412, 0.04400580233777873, 0.04389701833133586, 0.03267489570134785, 0.00722613700418151, 0.01613495100173168, 0.01241609259523102, 0.03785778048040811, 0.01112218316848157, 0.016569886647630483, 0.08244667711551301, 0.038932135721552186, 0.017255965067306533, 0.019126396146020852, 0.011871465667354641, 0.06134396397101227, 0.03929884573153686, 0.039178506485768594, 0.008767375493334839, 0.056172441472881474, 0.03331276049721055, 0.030384618694370147, 0.03510591544909403, 0.046244702316471376, 0.014634552899224218, 0.05849027256772388, 0.04269837932952214, 0.08311429832247086, 0.02531586138502462, 0.09132985083851963, 0.02584029447461944, 0.05381146191211883, 0.014840885723970132, 0.035815401206491515, 0.02068849455099553, 0.029367666720645502, 0.042663832355174236, 0.051802408779622056, 0.03925688470189925, 0.045771924560540356, 0.06839907582616434, 0.009221097679983359, 0.040338958278880455, 0.022675585678371135, 0.03055088203836931, 0.01930242986418307, 0.05243230662017595, 0.03739694016985595, 0.00783411180236726, 0.10192619825829752, 0.060189783325768076, 0.02829329292580951, 0.0198779412676231, 0.013361688925215276, 0.02294986119522946, 0.04194739267404657, 0.03219518628611695, 0.039907332611619495, 0.048347318006563, 0.04103761981241405, 0.018085103583871387, 0.014486158615909517, 0.028014930030622054, 0.04269087621651124, 0.05278581753373146, 0.026424841526022647, 0.014518519965349697, 0.06506487348815426, 0.03384351482964121, 0.030785775488766376, 0.02157298800739227, 0.05234455136815086, 0.01168831753602717, 0.03405866344110109, 0.050676017854129896, 0.019794872678176034, 0.021789014208479784, 0.022276881682046223, 0.03029364252142841, 0.044485871694632806, 0.01870164276624564, 0.016846099169924855, 0.0960762934118975, 0.06732734036631882, 0.014351169375004247, 0.04572785954223946, 0.04046661139000207, 0.020775464981852565, 0.03924528864445165, 0.028971927604288794, 0.061157692325650714, 0.037496013173949905, 0.06341169500956312, 0.03534501687681768, 0.024157413390639704, 0.057111117275781, 0.06029326839779969, 0.036827586736762896, 0.01918961228511762, 0.052494038463919424, 0.03448521652899217, 0.033618599554756656, 0.05695740364899393, 0.01412683946909965, 0.05974574152787682, 0.017938855962711386, 0.07003605322097428, 0.05371825558540877, 0.05851749825524166, 0.0246651648558327, 0.044464008024078794, 0.02171234107663622, 0.030510646502079908, 0.025588283388060518, 0.043272601251374, 0.0657341125770472, 0.026858357814489864, 0.06170391301566269, 0.032625921376165934, 0.07815097793354653, 0.11523469467647374, 0.010098582479258766, 0.048803772224346176, 0.02209075104474323, 0.01105350760553847, 0.011726212524081348, 0.043207288545090705, 0.04351587354904041, 0.0273417111748131, 0.024033261361182667, 0.026499236264498904, 0.04322939341363963, 0.02310429284989368, 0.024193311073759105, 0.06354124430799857, 0.0610781971772667, 0.06159785269119311, 0.040929637325461954, 0.06547375975060277, 0.04993864960852079, 0.02736965489020804, 0.01390884008287685, 0.025862082075036597, 0.03987317526480183, 0.008362121116078924, 0.05434271719423123, 0.03473135351669043, 0.03300951524579432, 0.01393108039337676, 0.10270316008245572, 0.022390905251086224, 0.03693228150950745, 0.00534398509444145, 0.037203796237008646, 0.0502996858995175, 0.031956771344994195, 0.03259422424889635, 0.07759951768093742, 0.07806682580849156, 0.06886751943966374, 0.0347065732057672, 0.036993709072703496, 0.014931238492863486, 0.01992460194742307, 0.1482771130395122, 0.059112299932166934, 0.036806012503802776, 0.023734476417303085, 0.02984009937790688, 0.03343144475365989, 0.07330139909754507, 0.06160609053040389, 0.038609928596997634, 0.022823263789177872, 0.015169323178270133, 0.014482767001027241, 0.04443815902050119, 0.022578154676011764, 0.02694400907785166, 0.03727779578184709, 0.02823962080583442, 0.028086480488127563, 0.02515510106604779, 0.04122090802411549, 0.04411387017171364, 0.030394695204449818, 0.048709682741900906, 0.036130799126112834, 0.03652746221632697, 0.03585171820304822, 0.040405150430160575, 0.020085206415387802, 0.02681629288417753, 0.03665066615212709, 0.023935954668559134, 0.029373748620855622, 0.01157305458036717, 0.03245836298447102, 0.030862066414556466, 0.02829520766681526, 0.049635994364507496, 0.03222389997972641, 0.06650107025052421, 0.04584253991197329, 0.034400693330098875, 0.04462876851903275, 0.07218820726848207, 0.10991162562277168, 0.016633889463264495, 0.042194115958409384, 0.010796774604386883, 0.02607084265036974, 0.052898319700034335, 0.03917283276678063, 0.04252212296705693, 0.0652346620336175, 0.035749220187426545, 0.025694892901810817, 0.04987755230104085, 0.05483107262989506, 0.04077061734278686, 0.04427945445058867, 0.008081795240286738, 0.03249674686230719, 0.03218267367628869, 0.05129452001710888, 0.05857881449628621, 0.0691131703206338, 0.0292465612074011, 0.05533169947739225, 0.06525171658722684, 0.04395142888824921, 0.04766945516166743, 0.007773533534418675, 0.021261556867102627, 0.03258552256738767, 0.02099834120599553, 0.05680699257936794, 0.05189640178286936, 0.009222512398991967, 0.07470327152987011, 0.029908614451414905, 0.06097265264543239, 0.06655336197582074, 0.04090693502803333, 0.04958900157362223, 0.06405905558494851, 0.03999036409368273, 0.09460537155973725, 0.0264185444029863, 0.0386352989153238, 0.044997311633778736, 0.006147618314571446, 0.044445992389228195, 0.02245496929390356, 0.06822752839070745, 0.014250132462620968, 0.03305953599920031, 0.08927270653657615, 0.013239852396509377, 0.03047224035981344, 0.050228773689013906, 0.03470790536084678, 0.026599097800499294, 0.0475849171198206, 0.020792870200239122, 0.040348324182559736, 0.04593015415593982, 0.032430042629130185, 0.017142358956334647, 0.044569782621692866, 0.020357081084512174, 0.06215937275555916, 0.005874206472071819, 0.033164238193421625, 0.1318961475044489, 0.014977961327531375, 0.026389390986878425, 0.04412887639773544, 0.00587739538786991, 0.035060607333434746, 0.03973499849962536, 0.01426863884262275, 0.02874259283998981, 0.03295720867754426, 0.0450568318774458, 0.017303468084719498, 0.016921495807764586, 0.09517258760752156, 0.022980565699981526, 0.0063289175704994705, 0.04936940378684085, 0.024005575542105362, 0.053033917502034456, 0.04881670043687336, 0.03291048305982258, 0.06440690020099282, 0.03353396874445025, 0.05172275035874918, 0.019246664887759835, 0.02946360044006724, 0.030105012701824307, 0.23165042832260951, 0.17491452977992594, 0.09007446351461112, 0.11574015661608428, 0.14855121786240488, 0.17815823463024572, 0.14526742219459265, 0.11073368776123971, 0.18496824108297005, 0.19184737117029727, 0.16369114920962602, 0.13638864940730855, 0.20220487320329994, 0.19832180812954903, 0.11925059676286764, 0.08110917857266031, 0.08048073534155264, 0.13248919771285728, 0.06869700358947739, 0.16595909313764423, 0.1173644135997165, 0.16658910230034962, 0.15750441321870312, 0.1521501739625819, 0.19354154588654637, 0.13894273579353467, 0.07287344706128351, 0.09829210888710804, 0.15619225159753114, 0.11664030753308907, 0.2175987823284231, 0.20487310190219432, 0.14971143216826022, 0.12674019526457414, 0.14422044478124008, 0.10194100410444662, 0.21068912028567865, 0.05950742677669041, 0.3519514831714332, 0.11932418070500717, 0.15208528056973591, 0.05207485119171906, 0.15455884393304586, 0.11395788154914044, 0.23270138364750892, 0.19971223664470017, 0.08231867148424499, 0.1722315768711269, 0.1081368610903155, 0.147795474040322, 0.20013396948343143, 0.1057717997173313, 0.1774521404877305, 0.16804274695459753, 0.12612816091859713, 0.09606473075109534, 0.10234694404061884, 0.20874320907751098, 0.15923763974569738, 0.10581911163171753, 0.137923440488521, 0.20926238590618595, 0.14989797840826213, 0.09243693479220383, 0.13178751192754135, 0.10799341878737323, 0.1701429655076936, 0.08613040874479339, 0.09998513327445835, 0.10171611109399237, 0.16264129226328805, 0.18538368050940335, 0.0906779408978764, 0.11154262130730785, 0.11582798237213865, 0.1922749966615811, 0.12186182109871879, 0.23409026849549264, 0.11112004242022522, 0.17103685269830748, 0.18328395177377388, 0.17898846039315686, 0.12529787578387186, 0.10106299887411296, 0.195102326979395, 0.15075943374540657, 0.13298251811647788, 0.1094694020866882, 0.1430554807302542, 0.15089028922375292, 0.15163077448960394, 0.10765540020656772, 0.10993201984092593, 0.08526127960067242, 0.14369402459124103, 0.14254065288696438, 0.15898839686997235, 0.13198191008996218, 0.12712115450995043, 0.08681432009325363, 0.22519193269545212, 0.17650383902946487, 0.08900057582650334, 0.22192716569406912, 0.16005624347599223, 0.19537686224794015, 0.09742884270963259, 0.10945787653326988, 0.12301271402975544, 0.1079757408297155, 0.11581949220271781, 0.17879070772323757, 0.09804256173083559, 0.15070046269102022, 0.2047367990599014, 0.15759388654259965, 0.1339706135331653, 0.20739549858262762, 0.13360964774619788, 0.09632456407416612, 0.12678076105657965, 0.08936243219068274, 0.14979180676164106, 0.13065563281998038, 0.09451364210690372, 0.15727900812635198, 0.128235281445086, 0.22627393947914243, 0.08503104312694632, 0.08120337195578031, 0.11645534948911518, 0.0924651586683467, 0.24786357942502946, 0.1210026589978952, 0.13872666691895574, 0.15491599508095533, 0.13907216634834185, 0.18430991156492382, 0.13836696278303862, 0.08772367364144884, 0.18534569739131257, 0.31151078757829964, 0.1007952839427162, 0.11218379237107001, 0.09745127041242085, 0.08676386147271842, 0.19000136788235977, 0.10619718392263167, 0.12409500282956287, 0.1898032144526951, 0.11622116478974931, 0.1257467712275684, 0.13842173328157514, 0.07776088285027072, 0.1615478118765168, 0.15283434506272897, 0.10920743137830868, 0.22788027359638363, 0.11993718726444058, 0.1277739624492824, 0.14436335273785517, 0.1114568513003178, 0.24357323854928836, 0.12635870167287067, 0.1080852744053118, 0.15827626164536923, 0.1165066912653856, 0.13756777363596484, 0.1195073575945571, 0.1479913416551426, 0.20061115559656173, 0.08933499499107711, 0.12977268488612026, 0.12847619742387906, 0.10901040601311252, 0.09737752319779247], [0.035702869354281574, 0.0438817152462434, 0.0652689863636624, 0.05188229355553631, 0.03406177303986624, 0.019511652426444925, 0.023417356715071946, 0.03397011780180037, 0.05009269720176235, 0.07295641175005585, 0.09866660402622074, 0.03656357141153421, 0.003668212161755946, 0.019094062627118547, 0.012321547619649209, 0.021082211314933375, 0.08618129781098105, 0.014302838862931821, 0.0844763767963741, 0.00681568944855826, 0.04039074534375686, 0.029739658966718707, 0.047143150004558265, 0.023450979715562426, 0.03668653043860104, 0.02479873288393719, 0.08201256525353529, 0.06578040032763965, 0.08012331702047959, 0.0528167057200335, 0.02826528056175448, 0.04222172014124226, 0.03261108213337138, 0.018392985402897466, 0.06376834149705246, 0.06698106168187223, 0.1252444411511533, 0.07746604984276928, 0.031055214058142155, 0.08823753669275902, 0.030160966925905086, 0.011238302377023501, 0.03753191827854607, 0.03440143547777552, 0.023384904452541377, 0.03541211444826331, 0.05101030343212187, 0.038302048633340746, 0.04496723609918263, 0.10568685349426232, 0.03234741561755072, 0.08130906120641157, 0.04157545423367992, 0.03495526689221151, 0.08532212086720392, 0.029518584306060802, 0.04689065652200952, 0.043892183239222504, 0.06918933693668805, 0.10400014478364028, 0.06945185683434829, 0.07221550346002914, 0.041514338372508064, 0.05780312174465507, 0.010655812002369203, 0.028108958285884, 0.03244974293920677, 0.04143016027228441, 0.008917749455576995, 0.010439204143040115, 0.0071263079371419735, 0.04898454455542378, 0.055297371436608955, 0.07547723507741466, 0.014902797538525192, 0.07516373705584556, 0.05198197883146349, 0.07202040025731549, 0.037847631610929966, 0.036666878368123434, 0.05751076379965525, 0.06408405111869797, 0.02634793647303013, 0.057785473472904414, 0.019733009103219956, 0.00936489064770285, 0.0614303610927891, 0.03864295045787003, 0.04223021402140148, 0.015205644813249819, 0.046211457811295986, 0.059106381304445677, 0.01099946162867127, 0.04184221921605058, 0.030869320908095688, 0.04358878584753256, 0.03589597617974505, 0.061988504385226406, 0.02740334653935861, 0.0629959067737218, 0.028656967551796697, 0.1256234262837097, 0.004746663362311665, 0.04177101385721471, 0.028407386998878792, 0.03247807442676276, 0.021015961647208314, 0.034063617276842706, 0.0669614170328714, 0.002860050217350363, 0.0494431361585157, 0.039307781189563684, 0.012329701967246365, 0.05995879357215017, 0.013873108455300098, 0.034071832851623185, 0.014029107896931237, 0.0736797385616228, 0.022134033097245265, 0.022816849777882453, 0.041868758416967466, 0.06115192954894155, 0.06453721391153522, 0.058372664425405674, 0.033010038459906355, 0.04544746501778718, 0.038067355562816374, 0.039130827208282426, 0.031992164367693476, 0.04076046847330872, 0.0449460848903982, 0.039978805143618956, 0.019129511310893577, 0.011546237074071541, 0.02113820635713637, 0.035401160348556004, 0.09240549741662107, 0.03594901747419499, 0.012179204622952966, 0.031897533117444254, 0.01111046187361353, 0.01102539134080871, 0.004030043710372411, 0.06657780832028948, 0.044332276811474, 0.054189857037272304, 0.042235394212184474, 0.04684266183176078, 0.08681786013767123, 0.04832502389035653, 0.01542803956908756, 0.032962782206595875, 0.0734690428362228, 0.014562277920049382, 0.023913437908049673, 0.04242335053277202, 0.03680581954540685, 0.012861872874054825, 0.039046055389917456, 0.010611357356538065, 0.019908851718355436, 0.04999234399292618, 0.03497796176816337, 0.023258327455550898, 0.06716178206261247, 0.11018178222002462, 0.04470132087590173, 0.034631000307854265, 0.04392000635561999, 0.08818049522233196, 0.03204875683877617, 0.055611841671634465, 0.008852815244608792, 0.021362976913223974, 0.020051624233019538, 0.03139144406304695, 0.029400293387880083, 0.060342409706208855, 0.07572024391265586, 0.03237361343053635, 0.10212806242634542, 0.06000454697641544, 0.02399696848442545, 0.03905944373400416, 0.013148625748726772, 0.03186730173183605, 0.01040409963025013, 0.01190227592815063, 0.11471335077658296, 0.006506398940473446, 0.04863276655669324, 0.02421519144263584, 0.024420541849394795, 0.05879016702238005, 0.03154994083161, 0.017733793138177134, 0.03162690525641665, 0.026437923734192736, 0.08018807682674378, 0.02895582299970556, 0.04370880596979987, 0.0422015040385304, 0.09285895706852898, 0.02234687919553835, 0.05195175857807044, 0.04338043901952915, 0.0381344753986923, 0.05232946350588463, 0.013822962464473676, 0.01860570348071633, 0.0780205380578991, 0.022250823021749966, 0.03174743746058084, 0.051320472921361215, 0.02902029151300667, 0.05881302146008238, 0.08368263501324691, 0.048214083944913, 0.0399956815817859, 0.025734057890076656, 0.09709244201076217, 0.041487750931992196, 0.02796518016111804, 0.08072967393673025, 0.016300102979585063, 0.061428772896761075, 0.045331333749345504, 0.05346548750821967, 0.01575505859364057, 0.04208463433315046, 0.1263387527433224, 0.04027959759696387, 0.03688899574626703, 0.03902604708855506, 0.001524037825220148, 0.00637383002867864, 0.05125440322444774, 0.04249577301379759, 0.022372095518221613, 0.03274517337558791, 0.027614302016445436, 0.023652604540984612, 0.04167636034253519, 0.027601952679106034, 0.011578422163438518, 0.05781041334557813, 0.019956696123699658, 0.08515867026289925, 0.021478345624927897, 0.056136020575650036, 0.027235294619458728, 0.06125458712631371, 0.03492264208034612, 0.014576529938494787, 0.006060012883608579, 0.053703193698311225, 0.010357661594753154, 0.013569198054028675, 0.034159291244577616, 0.0210029072695761, 0.06219198272447102, 0.038073563628131524, 0.013431482348096324, 0.05807634341181256, 0.008264688258350361, 0.03548139764461666, 0.03000941294885706, 0.041003555234055966, 0.042236819135723636, 0.01041745828842977, 0.016595546403550543, 0.04916680860333145, 0.03786671964917332, 0.04158487579843495, 0.02778232425043825, 0.037246440042508766, 0.04162114084465429, 0.02545220504543977, 0.03301328906673007, 0.011261450890742708, 0.05340939598681871, 0.010245461853628512, 0.021878821498830803, 0.031400323859998025, 0.020829172353842296, 0.029530736974265892, 0.041376996523467824, 0.0504700792953372, 0.05894472298678011, 0.06612868281081319, 0.032098888914333656, 0.009278568668378284, 0.051409330262686126, 0.05390244550653733, 0.05728909542085603, 0.009516601403447567, 0.038170740444911644, 0.02583283589046914, 0.06735976479831152, 0.05234841053606942, 0.023173817244241945, 0.10489843290997669, 0.013409949860943016, 0.05251366826996673, 0.06522253534058109, 0.009117230401898269, 0.08177386087481864, 0.08080998173682019, 0.034328419278608635, 0.014789508695685072, 0.02489554048224818, 0.048999398641171865, 0.04174539863015525, 0.023448003703379072, 0.04171426553511992, 0.0732010904175695, 0.01681393820035737, 0.013684142813872313, 0.00800172585513792, 0.07959193186252378, 0.03692227735882625, 0.02595227342681028, 0.027562696777749807, 0.051683624333236367, 0.02996798255480826, 0.018992627738043666, 0.028896937292302027, 0.024968439793155994, 0.04243348455929663, 0.02636735105625121, 0.12850399827584624, 0.0025549980682626483, 0.014485627980320714, 0.03150915610603988, 0.024406906741205603, 0.07272689515957609, 0.023276005413208622, 0.11043847625842318, 0.06079359467548784, 0.04437605239218101, 0.05139571556355804, 0.010104365665029036, 0.06278843196923845, 0.05597077768470626, 0.0746600711136125, 0.06423672573873773, 0.0039090908012440195, 0.021170515756239183, 0.025368488932144828, 0.09113843610975891, 0.028194247752253432, 0.03144799200526904, 0.13559170154621825, 0.16062085458543152, 0.14573371357982978, 0.13852024596417323, 0.123151888983557, 0.16398965584812686, 0.08583578353864141, 0.13709153747186065, 0.22228376765269786, 0.20557757816277444, 0.17633847368415445, 0.0854082619480323, 0.17833211983088404, 0.0778026509215124, 0.13229476986452937, 0.1194036944070831, 0.14885947632137686, 0.13006969238631427, 0.18563523888587952, 0.15520639746682718, 0.13354662456549704, 0.12669588904827833, 0.15148673846852034, 0.082992452516919, 0.15137425856664777, 0.14281075011240318, 0.17436225316487253, 0.14301432122010738, 0.13082720251986757, 0.11988997925072908, 0.1321095001185313, 0.14819868287304416, 0.06478578885435127, 0.13287673238664865, 0.1761344721307978, 0.1183499486069195, 0.26248394802678376, 0.21472221793374047, 0.08237451809691265, 0.23101102357031778, 0.16349161538528278, 0.12586058699525893, 0.13613900577183813, 0.12820078642107546, 0.1821108240983449, 0.1266577871865593, 0.16577193833654746, 0.15659768687328324, 0.1146520567999687, 0.1846210050280206, 0.17057698831195012, 0.1797033564071171, 0.15615478798281401, 0.1249429807648994, 0.1945279788924381, 0.10005514006479643, 0.12234625057317317, 0.11591470232815482, 0.19620376318925992, 0.1926874229684472, 0.1500382146332413, 0.1260403054766357, 0.10215156624326482, 0.1412868982879445, 0.12230434891534969, 0.1266909166588448, 0.13752973114605993, 0.18457907368429005, 0.11102809774456546, 0.09904312522849068, 0.18077142565743998, 0.1559247073601, 0.10158972334465943, 0.1887532090768218, 0.14546665915986523, 0.13053426198894158, 0.10989979578880593, 0.09523020795313641, 0.09198753468808718, 0.12478500721044838, 0.09423232360859402, 0.23043139139190316, 0.11024991879821755, 0.1424255160964094, 0.13870367518393323, 0.10363093373598531, 0.20417067396920174, 0.11717070563463494, 0.10449781417264603, 0.07271615628269501, 0.18313135136850178, 0.17092673282604665, 0.10041960136732087, 0.09507924027275294, 0.06988581284531392, 0.12983711814740673, 0.12981567007955164, 0.16553540102904662, 0.16184392879949883, 0.2031485881889239, 0.2387932434794493, 0.19246078591095284, 0.0900185872160364, 0.11009212335920893, 0.1287721807602793, 0.19889244547812268, 0.10386624649981968, 0.1458022731821984, 0.2006707203690894, 0.1876529009314254, 0.1157403718389105, 0.12146271634264849, 0.13375065580476075, 0.0930442861863412, 0.16061865782830864, 0.13498913700459525, 0.15991568070603535, 0.16590165090747178, 0.1366603051428683, 0.13360571436351165, 0.08356019548955373, 0.1688682526582852, 0.26648836908861995, 0.25605077447835356, 0.12588329671416432, 0.2095517492853105, 0.1023134212300647, 0.17313226213445887, 0.1716115273302421, 0.14567664242349565, 0.14603190851630643, 0.12206000421429053, 0.13228320720372722, 0.14191828784532845, 0.10869624005863443, 0.18295295390998945, 0.24606905149994418, 0.16021889256080613, 0.09960053750546649, 0.14404848916456103, 0.12229012936586514, 0.1018365468189586, 0.15722431184258312, 0.14766956126550213, 0.17600008402951062, 0.12455186893930659, 0.10830162529600784, 0.14803187776124105, 0.14784586586756632, 0.22714701684890315, 0.1127075482509099, 0.17419997515389696, 0.147153249126859, 0.12760827055899426, 0.1775039275526069, 0.15554247162071988, 0.12060255976393819, 0.09793024510145187, 0.18007101636612788, 0.11978846087004058, 0.09643423865782097, 0.184012993122451, 0.16236605937592685, 0.14737874327693135, 0.33382066700141877, 0.1610890607116744, 0.10400648272479884, 0.14487347536487505, 0.19891801988705993, 0.1863289243192412, 0.08467231862596236, 0.3139355918392539, 0.06911348944413476, 0.19664502935484052, 0.08691107388585806, 0.11089887499110773], [0.035466766203171574, 0.06099326208641287, 0.034705144571489654, 0.03214836789993569, 0.03411376048461534, 0.029424719323287718, 0.007630536056240089, 0.02278197254781844, 0.048449745518155396, 0.11565093562239781, 0.029619651832035743, 0.043690452657756396, 0.05218469275860116, 0.05212570686126128, 0.016850255196914077, 0.06460052652982995, 0.01236362460986129, 0.026405100397823844, 0.05688904813723639, 0.033159521844936535, 0.01927552144479705, 0.06760665506590158, 0.015031147340778261, 0.07832786883227527, 0.03849543005344458, 0.02701819972571684, 0.05705115916498471, 0.025808441496337764, 0.05368695921788458, 0.0896428304258734, 0.03144343150779605, 0.06380868464475498, 0.0432576840830734, 0.06472193446825258, 0.04340065141150262, 0.03263850820076186, 0.0356828350777505, 0.038167690217960626, 0.009648973646108061, 0.01909524820803199, 0.04802773066330701, 0.09689839265774935, 0.01430986607374507, 0.04918770748190582, 0.07711134778219275, 0.07020831311820075, 0.03151749784592539, 0.04314912272093352, 0.06166684273921419, 0.032653154485160485, 0.016664298964315094, 0.04457231334527023, 0.0017427076954845688, 0.053616091536241584, 0.029821708958479576, 0.024854247385519557, 0.06844125950010493, 0.05885000638954807, 0.009686098655947717, 0.05071452418633271, 0.0728181867452804, 0.059415500654722564, 0.019815430168819148, 0.03956581109378021, 0.02440548181766644, 0.019116544135613367, 0.027575458007049747, 0.03124625771306455, 0.0624963894370012, 0.0056066608431137865, 0.015249068801495014, 0.036315248798928224, 0.047510728327324614, 0.05960497466730885, 0.013041079273534706, 0.07676186301978305, 0.08474329762975685, 0.054810834262752905, 0.04872839599556755, 0.09087348938919604, 0.05633235203276854, 0.042815768538275734, 0.002723505945141369, 0.03845430022920482, 0.034719330724328756, 0.019973364760517143, 0.04533942315902095, 0.06407086315448396, 0.043496258585946634, 0.025148939384962432, 0.06606787123018876, 0.09044990860274993, 0.035022976735490374, 0.030567975554731674, 0.04184923993307166, 0.03214326934539713, 0.03126859635813162, 0.017491804755991325, 0.009997465786000248, 0.07134155777748674, 0.04032141019706614, 0.07845203013857827, 0.014621789814555086, 0.012583046136569465, 0.04519975096627604, 0.020960176261723973, 0.028795465295843314, 0.010220102667517494, 0.051158584537915885, 0.03249404915550258, 0.023677937751926947, 0.06973504554480314, 0.04207801066513639, 0.038518217697856016, 0.07502504449803382, 0.034173495951108634, 0.0538448437146144, 0.09517391605186276, 0.02963481947517721, 0.06527507197461091, 0.06946785011678003, 0.07836788543500006, 0.04077832825714722, 0.05895694986975286, 0.028448160592233762, 0.011317045173200313, 0.0663909206923563, 0.09524836088530719, 0.027102368549094535, 0.011051912915718276, 0.009943797376763541, 0.04426662271725945, 0.06668066998827271, 0.044893099257024005, 0.01477073885325808, 0.031681193358963355, 0.02385218846029602, 0.02848802505468484, 0.06680231541395187, 0.023811246028344613, 0.029016658700129483, 0.03170768432028126, 0.06875806750031188, 0.05195752877625637, 0.04100907681277022, 0.04165661921433639, 0.04396610856929328, 0.008643946130177937, 0.007263058387252386, 0.021362015831982717, 0.024274435236293357, 0.03822447935817763, 0.009875442792690592, 0.05264271290798206, 0.03533851937390864, 0.014096858558332315, 0.03522664432239253, 0.018185594090027735, 0.05521232131286524, 0.011656464557745494, 0.02246668595034862, 0.012876107266492909, 0.00445687788669602, 0.0462258406332694, 0.019177706381015014, 0.09933904919307679, 0.024904993588279467, 0.08156081996276043, 0.09655028086854145, 0.033930910140043125, 0.07262437487952411, 0.04996681040211115, 0.050928218188346364, 0.07512675583711825, 0.04910033072519582, 0.06735006492817774, 0.03227417677408084, 0.014630638997914502, 0.01702019217191264, 0.025971960749302525, 0.048311921273125336, 0.014007195986778243, 0.026879269680648576, 0.016270546948362608, 0.022851144422020297, 0.04563250098726712, 0.025349467687192373, 0.11174639279488474, 0.04531324761046562, 0.03873295441735536, 0.04259848625224549, 0.011669557898130734, 0.0015247908731907955, 0.06608766430872492, 0.003633867422649928, 0.050749323490890674, 0.015189454861683771, 0.11214761267183349, 0.06616616868996061, 0.02440340194880264, 0.06290374687523581, 0.0981823897745926, 0.03586650549550541, 0.0735667317348998, 0.032348165186704136, 0.03968790180806536, 0.025718979304656386, 0.03979642235208303, 0.0320768137316918, 0.03874065419950057, 0.009148871868092101, 0.06007387470162939, 0.020701196408481337, 0.033520227880217135, 0.011456080046627903, 0.020428689058462624, 0.03789122907619458, 0.09325899693067186, 0.05660074974002782, 0.034601622392074205, 0.0436073469609255, 0.024587790394434705, 0.01840923843701603, 0.02619745489937486, 0.03153048543026671, 0.07060523596010171, 0.017098941461881623, 0.0071757488876755815, 0.004617214717654861, 0.014311023824120639, 0.04788174279383384, 0.05972913597361185, 0.05542450133361854, 0.040268450538860634, 0.046198811614885926, 0.01121634129958693, 0.010951111635222333, 0.019273103898740374, 0.04393928364152089, 0.06517500820336863, 0.04207018842862453, 0.03165162619552575, 0.03978769098466728, 0.05277321957692038, 0.04919729231914971, 0.05301505581883248, 0.05214880620769691, 0.011380662999727065, 0.06627294889767654, 0.041121434260276146, 0.023777318747306708, 0.01564091999171069, 0.08069134943070821, 0.018934545405500103, 0.044130891328677535, 0.0036900210989188054, 0.021816508924530353, 0.015700345611548983, 0.01947353572177235, 0.02642237945110537, 0.03236453696445096, 0.003928480336981011, 0.04308354284148663, 0.05405740223068278, 0.022378318426490296, 0.02819182278471999, 0.022718387190252542, 0.028045434155501425, 0.06926716596353799, 0.018645525269676, 0.012569184673338896, 0.024097247478493955, 0.022053632528695744, 0.03377958251803648, 0.028326292522251606, 0.04014292739157099, 0.024847094937285874, 0.03731025732122362, 0.02389272085565608, 0.01773357234924333, 0.02233517552667763, 0.0718139496166259, 0.032588706380920485, 0.004139265583944507, 0.0782101196818985, 0.036367900465847924, 0.07906623155577108, 0.008460410226689419, 0.025944440058083273, 0.020204658794682473, 0.04339567902206909, 0.023508585218223743, 0.03530247697199229, 0.09844063490163535, 0.03260161975049414, 0.06918265760759823, 0.024710452562430874, 0.08255842971266247, 0.06566748998011462, 0.014583973679691553, 0.04690292422310449, 0.01980290086066816, 0.02146829509001691, 0.02008558119996451, 0.005433873557194602, 0.01207516386784846, 0.024701218389964197, 0.06875074992422014, 0.024301570010720752, 0.019299921405036002, 0.030135142042126972, 0.06532038751174696, 0.009307175678259227, 0.014479555356956553, 0.033684227673802525, 0.02415836333966581, 0.07715647778240964, 0.03455688201938756, 0.05927251106186304, 0.01062875422576326, 0.011661901717161527, 0.05505045519385021, 0.0654268337530084, 0.021708021777158137, 0.0544546887249453, 0.05846254221978597, 0.032046638007159345, 0.05789618706330657, 0.02357599078095518, 0.023599806299898773, 0.06332870063488372, 0.05858006130438298, 0.03038774499145802, 0.006036480308466707, 0.004641332197934389, 0.00914383268536767, 0.03240198944695294, 0.01607290374522563, 0.028145891265012324, 0.09545308974338695, 0.012745752737828298, 0.051242714398540556, 0.03633423664723523, 0.0386947226797929, 0.07331764471018687, 0.033639023458817974, 0.014337299562612316, 0.030828877570456825, 0.12731249502394348, 0.023536979788332246, 0.040263415066874586, 0.045443739436450414, 0.14162724721245468, 0.1672610131208785, 0.12434027521521784, 0.24308189225848764, 0.051993203815072775, 0.1800615614047274, 0.06818479552748613, 0.12240082811331376, 0.08564925214159302, 0.19374343974050134, 0.13283364329254255, 0.1216137433948461, 0.1088137443002779, 0.19817182008409873, 0.1344428420998156, 0.099311426456552, 0.13777792017208412, 0.246206883166451, 0.1732586944126524, 0.25579375389497727, 0.11647145409369841, 0.19995058479253203, 0.10545276527409442, 0.17925885447766632, 0.10607990232529119, 0.19116995361400768, 0.09326652230811305, 0.15904802101431414, 0.1840058239758946, 0.20949052210198715, 0.10182961515965872, 0.20592082146322355, 0.07145031951949932, 0.1322873038589023, 0.1259208790725097, 0.17331999581074342, 0.06985988220549189, 0.2034807438030839, 0.067432428477332, 0.09827190762734972, 0.13433429558062926, 0.15585942805046216, 0.12690789095358923, 0.10939371786662377, 0.09476523759076372, 0.17023957829223946, 0.16446856374386698, 0.24560820747865364, 0.15248258190695196, 0.15733884007204324, 0.13344514329219237, 0.15960498800268397, 0.10361177890445106, 0.15020671184174716, 0.19250482495408505, 0.18494168703909963, 0.17239456734387204, 0.16555993643123657, 0.10552931780694053, 0.08905822585802525, 0.12334455052041449, 0.13462382223224267, 0.11987993057118729, 0.13179868867155164, 0.147838281118311, 0.0887614706880413, 0.15526032191701233, 0.14554059191141278, 0.09650569263612852, 0.1668130824691616, 0.24113832623697817, 0.12714012380456552, 0.14043473463971168, 0.13145382748916745, 0.06442355399485677, 0.20323675533290952, 0.1707899698521942, 0.17669771768851206, 0.08797935835900716, 0.2933543227845803, 0.10095320554682985, 0.07270299800438806, 0.11680015129968524, 0.10278114496031776, 0.12765861785737798, 0.09972424610168673, 0.1795694135944359, 0.14292119652964175, 0.11835508426884189, 0.10737385164247826, 0.17802647373173386, 0.14110431511653587, 0.22474974626675248, 0.11526317088282667, 0.15932812239043415, 0.19556011335225776, 0.12498106778366491, 0.07590361376060173, 0.1223001632024534, 0.12834532710257918, 0.1165489194681868, 0.10576674569165334, 0.12715667369775474, 0.08540846974938177, 0.08213154636905529, 0.12463712686439976, 0.18951383623061702, 0.102329555520555, 0.1368926270515658, 0.07004115177551284, 0.12076777667971328, 0.18718585255555809, 0.07366178600932471, 0.10562768206000328, 0.22644926444627345, 0.09312015594332479, 0.24870847002603114, 0.3246025397675112, 0.0890602519211825, 0.18392331199720502, 0.22078099282225594, 0.13361456076381728, 0.19887243717676029, 0.1219571870751679, 0.22020578384399414, 0.15497541142394766, 0.11985952893155627, 0.1994168767123483, 0.09217778424499556, 0.10505357888177969, 0.05787237525510136, 0.16617675020825118, 0.09873222472378984, 0.2302103501278907, 0.2204651347710751, 0.17897128709591925, 0.145038855553139, 0.06752064015017822, 0.15921390586299822, 0.1256931436364539, 0.14833857771009207, 0.13060855097137392, 0.12076863757101819, 0.11691058287397027, 0.1193789066746831, 0.15665691025787964, 0.20479808561503887, 0.1310048281447962, 0.15802848822204396, 0.11033824179321527, 0.22155404352815822, 0.17792960861697793, 0.07488861549063586, 0.18472198164090514, 0.14339158457005396, 0.19455484463833272, 0.14250943815568462, 0.14234882255550474, 0.16989501396892592, 0.08917266502976418, 0.14713675860548392, 0.09399852482602, 0.07157185362302698, 0.12554979039123282, 0.19340818194905296, 0.16422825632616878, 0.08282454160507768, 0.16451322619104758, 0.17247086012503132, 0.07404492716887034, 0.15402037126477808, 0.11728118173778057, 0.17998529830947518, 0.11384897137759253, 0.2422298028250225, 0.14188790431944653], [0.04623090208042413, 0.05967536737443879, 0.026664685101422947, 0.019665816907945555, 0.04628395450708922, 0.09234918325091712, 0.018992278928635642, 0.03799970509135164, 0.04938983511237893, 0.038252851663855836, 0.031678966915933415, 0.05187283859413583, 0.0421099675440928, 0.02040608880633954, 0.05143639638845343, 0.012137417070334777, 0.011098725735791959, 0.050806116341846064, 0.04632053867680952, 0.029834034176019486, 0.04648473513952922, 0.03759365383302793, 0.03994296683231369, 0.033914052255568095, 0.03654806423583068, 0.00999042094917968, 0.0666822878702078, 0.010038308028015308, 0.028925131482537836, 0.023912610413390212, 0.0649221584899351, 0.016464471991639584, 0.03212003270164132, 0.056451373966410756, 0.0245111710682977, 0.0005120318019180559, 0.03221743587346282, 0.02241742033220362, 0.006797544401706546, 0.055730900712660514, 0.017268717019760516, 0.07445700466632843, 0.06611169505049475, 0.016078499538707547, 0.057996536561404355, 0.04721598437754437, 0.06788986604078673, 0.02353693897021003, 0.041848594264592975, 0.02599869290861534, 0.033734916360117495, 0.05480800668010488, 0.1141835463931784, 0.0726397818652913, 0.019035956174775492, 0.03370185739186127, 0.08827902274788357, 0.012760694953612983, 0.00536349893991428, 0.05131523335876409, 0.05132887032232247, 0.033289323473582044, 0.02276249859278323, 0.07235680837766267, 0.014214397124305833, 0.029213249908934813, 0.018809124303516, 0.019210149366699625, 0.015764799281896558, 0.010849016234715236, 0.0643705646507442, 0.07554520838311873, 0.052118162930128165, 0.02147437699022703, 0.042992177041014656, 0.05307171508320607, 0.05382588926295284, 0.05291554865834769, 0.03176537516992539, 0.013268691327539273, 0.04539661676972173, 0.036933736118953675, 0.03284923732280731, 0.053892682553851046, 0.019909402763005346, 0.11861927399877459, 0.060029546220903285, 0.023223125535878353, 0.049091870241682045, 0.049705110577633604, 0.033594142078072764, 0.028700008406303823, 0.033627111988607794, 0.02027354308665963, 0.024866546627890784, 0.02338216407224536, 0.05625173624139279, 0.06065759611374233, 0.0302273371926276, 0.022827638749731705, 0.04192430817056447, 0.028395423578331247, 0.06343623041175306, 0.04309668998757843, 0.05102742477902211, 0.04751528882479761, 0.05521891900571063, 0.04016705832327716, 0.004145539978708257, 0.02928765392425703, 0.054304533696267754, 0.04178833187324926, 0.04157464158197399, 0.023288503180083353, 0.04482833945075981, 0.024127534525177907, 0.034598030397319235, 0.033653643768047914, 0.06694448122289032, 0.048706331945140846, 0.03744094581634272, 0.061390329647110775, 0.06342661959934048, 0.06209803425008431, 0.026910942688118666, 0.030572769828722812, 0.0073054609947575955, 0.02340190334507497, 0.02325067405763548, 0.004631665724446066, 0.05176072234462481, 0.022530575588461943, 0.03976279935159255, 0.07142334245145321, 0.04543843308056239, 0.04291128665499855, 0.07091100080288015, 0.018507303975638933, 0.033049962294171564, 0.06868755604955368, 0.025329305390187073, 0.04039978470245842, 0.010612185778882122, 0.057226788412663154, 0.04300394750316627, 0.02138996325811604, 0.0038882928083694424, 0.05942549367318861, 0.04042387110530399, 0.03461063577560708, 0.008468743617413566, 0.059021872948505916, 0.055868405834189616, 0.04448768624570221, 0.037663007533410564, 0.05631202831864357, 0.06126643180323299, 0.03571631707018241, 0.034134377347072586, 0.010417483335913857, 0.04837303342355881, 0.003035425511370704, 0.032986271180561744, 0.042750162683660164, 0.01189536189485807, 0.055642514635110274, 0.022830585076007992, 0.0383612831501523, 0.09725755502586253, 0.00951416159296059, 0.027539677212189417, 0.05698720458894968, 0.06073961456422694, 0.04559692613838706, 0.04229053207382094, 0.008720379919395782, 0.014992057494964683, 0.030090650288912002, 0.04745741985971108, 0.0444730807794258, 0.06241893890546635, 0.03587734456232283, 0.038600900370511226, 0.02734763536864193, 0.05090967191790696, 0.048318563494831324, 0.03241877682739869, 0.010171741541853407, 0.03702645633893553, 0.05158626569027547, 0.05629676234093495, 0.018703676250879653, 0.02844786929927068, 0.05308736697770655, 0.002783728214126313, 0.011381137974240119, 0.043408135970821604, 0.04183289041975513, 0.04053148251841776, 0.04897365353826899, 0.023343197608483024, 0.019228445162298158, 0.022656321380054578, 0.027916662256757263, 0.016074549457698595, 0.05528392372070812, 0.028237869337317534, 0.023059140585246496, 0.06553518731379882, 0.07542309540440328, 0.03105217867414467, 0.030351700734172482, 0.02128213476680685, 0.017109179389080964, 0.014134515131445369, 0.13421788229607046, 0.03549244451278355, 0.04464188597921748, 0.05888018582481891, 0.022936487694096286, 0.034190973528893664, 0.007995773830771213, 0.06135099953098688, 0.03615826972236391, 0.07336447422858328, 0.07197357816039585, 0.02960602600069251, 0.03399513188924175, 0.015862710824876558, 0.06403605642844923, 0.03178773979016114, 0.02422717156150611, 0.06323826994048432, 0.02327369547856506, 0.03246617408876773, 0.03667588433017954, 0.01600521987711545, 0.05276119307382032, 0.011027654891222483, 0.023887939569249284, 0.03222247876692563, 0.024903301491576713, 0.04593431018292904, 0.02504641353880288, 0.051737971807597205, 0.041753332188818604, 0.024520299484720454, 0.0950285664293915, 0.030994244771136437, 0.0193123820645269, 0.02348654899833491, 0.07513606979046017, 0.08442841921350919, 0.05740677035646513, 0.03524396975990385, 0.038759159651817754, 0.026508680093684234, 0.024493021846865304, 0.04977072385372594, 0.06438168202294037, 0.031951205237419344, 0.02809303921821993, 0.02024770150455879, 0.08696547331055626, 0.06631745549384505, 0.015555571153527126, 0.0332891119614942, 0.0371286686277017, 0.08581837275414728, 0.048706239176681265, 0.09594377552275546, 0.04858627842622809, 0.02269225245981943, 0.006572778020199621, 0.03030383220902877, 0.03744217407074757, 0.02758445840299828, 0.04188691877061501, 0.025688254390843213, 0.016144921755767427, 0.029072017350699753, 0.06783497679862194, 0.03084050702454988, 0.028261807310627773, 0.03420089233259205, 0.03104220420937054, 0.07569766778033227, 0.03549778055457864, 0.0501107017043978, 0.025807424754020758, 0.0713219576573465, 0.023463097131752875, 0.02093062208587071, 0.06746822225977667, 0.03635690925875679, 0.03697478059621062, 0.024774251287453808, 0.09273672534618527, 0.04870664735790342, 0.023075169119692873, 0.025337485712952912, 0.025829056503425818, 0.06348410635837354, 0.009674367156549124, 0.029584665135189425, 0.014996718182374025, 0.00807305274065584, 0.023709239685558714, 0.01915687429573154, 0.0534351373789832, 0.005700978535969625, 0.03728955140104517, 0.01721028587780893, 0.024193285098590422, 0.023943487467477098, 0.031036621403472964, 0.05259843266685493, 0.05105193791678175, 0.0940642568457406, 0.06282360234763473, 0.037355951353674755, 0.004975886340616853, 0.05600475320534315, 0.029697748032049276, 0.011739122182916617, 0.02198018217313802, 0.04977075725037139, 0.0534978154610144, 0.036463678334257565, 0.06224300908797886, 0.05192886332224589, 0.0084618527762359, 0.0725999656424392, 0.13153071398846805, 0.02145350223145215, 0.06352200784021989, 0.03205856803106144, 0.04137536008784082, 0.015444338987435913, 0.07012934118392877, 0.042273919098079205, 0.035024435055674985, 0.02467916732712183, 0.025165454026137013, 0.036477756875683554, 0.029758544769720174, 0.03220729442546144, 0.07435327468556352, 0.00918026842555264, 0.03127147218037862, 0.020697116451628972, 0.012044791474181693, 0.08560498303268105, 0.12449020388885401, 0.16749792150221765, 0.1774620110518299, 0.1286910640192218, 0.16554681526031345, 0.07742473448161036, 0.0796169570821803, 0.19188845646567643, 0.11928065374377184, 0.14489449298707768, 0.19176485919160768, 0.20124950649915263, 0.09394753928063437, 0.14289960003225133, 0.07976788765517995, 0.06731980014592409, 0.23258332279510796, 0.13948626990895718, 0.16494474053615704, 0.181623455719091, 0.13858263089787215, 0.08046013332204893, 0.15667390543967485, 0.13253727403935045, 0.11251346921199001, 0.08989409936475568, 0.1122464741638396, 0.1651206295355223, 0.1191669270338025, 0.1418146543437615, 0.19166949321515858, 0.14161494240397587, 0.14189715147949755, 0.18480962928151712, 0.1516592432744801, 0.11805717134848237, 0.09340423523099162, 0.19365818181540817, 0.20606194826541469, 0.06877607200294733, 0.23467975639505312, 0.21937906101811677, 0.08158480617566966, 0.17116628325311467, 0.14560340729076415, 0.13907446700613946, 0.08383827822399326, 0.22814069321611896, 0.15749852056615055, 0.11703725263942033, 0.17337093682726845, 0.15492482663830742, 0.10862236667890102, 0.20398774940986186, 0.1201895768463146, 0.24208601913414896, 0.12599740934092551, 0.10503065394004807, 0.12337782100075856, 0.1782991091022268, 0.1695953941089101, 0.06667990557616577, 0.19583959132432938, 0.12472821807023138, 0.13028550893068314, 0.08533064072253183, 0.0922210662974976, 0.17873512086225674, 0.0883526289544534, 0.09748652242706157, 0.1564502963447012, 0.2330729621462524, 0.13543451466830447, 0.22597670933464542, 0.1823080869507976, 0.21075779863167554, 0.12244494137121364, 0.11941726828808896, 0.11322436504997313, 0.11833914293674752, 0.09931522625265643, 0.11066207793192007, 0.14869320555590093, 0.20466153044253588, 0.2219598795636557, 0.08728974731639028, 0.12124137821956538, 0.15904560161288828, 0.09697775050881319, 0.10958324011880904, 0.08749784552492201, 0.23006520088529214, 0.08697484663571231, 0.21425298764370382, 0.11461444475571625, 0.18391655845334753, 0.1716705280705355, 0.08034672573558055, 0.1429301913594827, 0.14391963748494163, 0.14465431915596128, 0.2194497431628406, 0.18520832585636526, 0.12419134101946838, 0.1209056306106504, 0.13577296369476244, 0.0779351762321312, 0.08819950904580764, 0.1327954523731023, 0.12965662783244625, 0.09767828596523032, 0.1271435376838781, 0.1657019241247326, 0.2930177439702675, 0.06662168409093283, 0.159908318601083, 0.12910954625112936, 0.17369740759022534, 0.172036703734193, 0.1362553596845828, 0.17698786774417385, 0.09519301893305965, 0.14061396330362186, 0.09818546226597391, 0.08551109393010847, 0.1574543776223436, 0.10587821627268568, 0.09105616903980263, 0.08483127923682332, 0.18837011244613677, 0.20221181970555335, 0.1395883597433567, 0.1510199424228631, 0.06860358946141787, 0.11442443268606439, 0.22517072211485356, 0.09737981643411331, 0.14555325295077637, 0.20237368211383, 0.12942717061378062, 0.20660612062783912, 0.13914471870521083, 0.19237751694163308, 0.08620751788839698, 0.07267645138199441, 0.17255153157748282, 0.17858974897535518, 0.10233256121864542, 0.0746205443283543, 0.09475312574068084, 0.16734690929297358, 0.14703549997648224, 0.1816273742588237, 0.11904327038791962, 0.13895130017772317, 0.13990656298119575, 0.2004506142111495, 0.10790891785291024, 0.19733665161766112, 0.1266602214309387, 0.12467589665902779, 0.1456272747600451, 0.1825713415746577, 0.09214082529069856, 0.12845243385527283, 0.06240123126190156, 0.0901536803576164, 0.26809045812115073, 0.14150123053696007, 0.17715065041556954, 0.2700851432746276, 0.07980655354913324, 0.1717350207036361, 0.1765143923694268, 0.08824788223137148], [0.04123322025407106, 0.0273921493862872, 0.011390799809305463, 0.017684662961983122, 0.025035997496161144, 0.023153105757955927, 0.07490716918255202, 0.06745516046066768, 0.04893190030998085, 0.020789691952813882, 0.11851643459522165, 0.027152548864251003, 0.016566053454880603, 0.053728040802525356, 0.021947917302895803, 0.053422450364450924, 0.04387882458104286, 0.069591662613675, 0.03363654839631636, 0.04633356336853467, 0.029517990587919485, 0.04327849019318819, 0.0252449770050589, 0.08667344562127255, 0.03463310429651756, 0.031867190409684554, 0.04547439755697269, 0.013895802403567359, 0.025575139952707104, 0.06110914844612125, 0.04948057008732576, 0.019190642015018966, 0.0353045995143475, 0.06348409151542, 0.038721588425687514, 0.04829362362215761, 0.0789368900586851, 0.024009731569094583, 0.028350827924441546, 0.021474555105669424, 0.041776438956731, 0.029325948744372, 0.019056994206039235, 0.050336266358499415, 0.05830072062963154, 0.04773203676450066, 0.034112272478523664, 0.03265610823291354, 0.007288018205144908, 0.041572775080567226, 0.057323438304592855, 0.048975082172546536, 0.03311961656436324, 0.049594278243603185, 0.02152638669940643, 0.08305652212584391, 0.02955685315100709, 0.024147832264134195, 0.04223647774779238, 0.03191531497577671, 0.028043127931596246, 0.035228566484875046, 0.02362261620874051, 0.0495149537891848, 0.021085228145238943, 0.012728592428175034, 0.020937258741469122, 0.05272888738545589, 0.037082495909999125, 0.024758575273153838, 0.0552473877905868, 0.04369064932689071, 0.04279498098185286, 0.03781210500164889, 0.05197406011575367, 0.020236136988387443, 0.05595663606072776, 0.02857333493011538, 0.03473130527709145, 0.1056693091231864, 0.030186055228114128, 0.05744414862419944, 0.053811306061106734, 0.042226180448778905, 0.014665062590211164, 0.02313377095561009, 0.023860947658249643, 0.0679043230775278, 0.041955960768973455, 0.026704351039370522, 0.030365038983291015, 0.043777565952041186, 0.02786622404528316, 0.07819478691089898, 0.03357433044584468, 0.025852350663626567, 0.01898811176943127, 0.009619603151804768, 0.01498776231528609, 0.040615270991111174, 0.05271378096949775, 0.06931176903890446, 0.012800157728634076, 0.018339836497034412, 0.009730738838698016, 0.022327008191496134, 0.0828994539915584, 0.03925504788639955, 0.01916814380820142, 0.031945067676133476, 0.03200604623998515, 0.07796409772709012, 0.050130598683608696, 0.0519656441611005, 0.03568007057765499, 0.045654045534320176, 0.005446353698062012, 0.03336560141178779, 0.03815175630734302, 0.03509422291244846, 0.011912430363736348, 0.09481873901677318, 0.0621772696467815, 0.040015088743530214, 0.043306587904226035, 0.02076477619993966, 0.048030420948634855, 0.04172025095613208, 0.03054272398003377, 0.02302124095876934, 0.05761541033280082, 0.061088754227967, 0.05997550302708987, 0.007028966456346097, 0.024533956857339945, 0.024242919935204554, 0.012091136741219088, 0.05004610517062247, 0.09372951855766587, 0.12783423968357965, 0.07726722848019563, 0.010842527080967557, 0.0477623497863533, 0.012260540297575062, 0.02283198402437847, 0.03157890685542952, 0.05726481605961453, 0.03343525197124109, 0.08014111372176558, 0.014933894453861285, 0.020463267574086785, 0.022853070295241196, 0.04331218369770795, 0.016696216880518477, 0.018417069950373843, 0.018977307954628486, 0.03696464656968601, 0.05078863134258427, 0.03973239356128033, 0.02976676962134661, 0.05101290465972852, 0.019869692296197172, 0.04222863324685022, 0.030481519061140716, 0.0599099417013349, 0.03665060306957457, 0.04785584926139563, 0.05529746791580692, 0.0416184839559719, 0.04459998803213239, 0.021379832942329813, 0.009076697078853613, 0.002558897590461129, 0.0051791763598885154, 0.05519674363313243, 0.04799175505468156, 0.05311396555043757, 0.023961579172464553, 0.01806629756174516, 0.06645874556852505, 0.013419867736956803, 0.03537436881742906, 0.032148130412679166, 0.0431356712942943, 0.021904071218159515, 0.029693463984585833, 0.12458311335649341, 0.06632259857724421, 0.042961351937265135, 0.010568697780399816, 0.019961787256761454, 0.0315321478410624, 0.08599797249189578, 0.032860774008440785, 0.03548874861735385, 0.025153945171041414, 0.04369348804175388, 0.053599545353790745, 0.059073752781841904, 0.06396770462743007, 0.023970334659679793, 0.02386050793575123, 0.021021078755438793, 0.04789824073668569, 0.07736272804322653, 0.03615841815189924, 0.06545276439283043, 0.0471419254608918, 0.05202766173169948, 0.03964114650443662, 0.051806538831442595, 0.06434902010369115, 0.04753148248710204, 0.06142885082226712, 0.05812991163111292, 0.013235369824542431, 0.04276702427887358, 0.036221400514477864, 0.03835802141111344, 0.06783829419873655, 0.03715459184604697, 0.04873829253483564, 0.025566404874552973, 0.026394385640742257, 0.030145795572025236, 0.016948072116065305, 0.022133404127089307, 0.06011026220221538, 0.025196830174536444, 0.009577783130225725, 0.03185917521477677, 0.02333549226023024, 0.03946547643863596, 0.026422891533002257, 0.022532876246259548, 0.047742849856149405, 0.05011706190998666, 0.05458632716909051, 0.06887980198371224, 0.07895682414527982, 0.02388254230027087, 0.07658801492652856, 0.03441290165937971, 0.0885112259129528, 0.059220104303676635, 0.04956442164257169, 0.042339239225839265, 0.05066593206720427, 0.05370285602111835, 0.11846941211842932, 0.06432444759411737, 0.054457861406262964, 0.008598500717198476, 0.007825651318853488, 0.04811118145880755, 0.0314489976153709, 0.018445945061102975, 0.10736047814134508, 0.043601918150670826, 0.015987256192602217, 0.03815913325524889, 0.07400122951366939, 0.047861036873655394, 0.055883174572954886, 0.04203782336844597, 0.03705555594933685, 0.02429413183563156, 0.06857778498670086, 0.08056833845330402, 0.0723832288349513, 0.02069970840238966, 0.030277421028586105, 0.054611797677353024, 0.011037994863727363, 0.057657393626868725, 0.031538240873487666, 0.06773473491193727, 0.06060082552721724, 0.01764168519002851, 0.010083665310958168, 0.017695604074106086, 0.04627510810678359, 0.02252611899166368, 0.016387804425903596, 0.018570800275483634, 0.02482665062416345, 0.01237117596247117, 0.023155729249992874, 0.014127875692793168, 0.04755270048917737, 0.09962153286323883, 0.03907449819962494, 0.0712503404065501, 0.034822381639969535, 0.04156874892942142, 0.02026945756369969, 0.06338845836580731, 0.04244237548846286, 0.013743240961048286, 0.023532467530458234, 0.04464607540285215, 0.05977637367323041, 0.03765522240428254, 0.004003967424068833, 0.03314817069622222, 0.035727234062505886, 0.05028548119298648, 0.05652528074278962, 0.047268383714254014, 0.024277095835714135, 0.03555130053428002, 0.03886864498781506, 0.04988102555216756, 0.012030439265799941, 0.025142829654214438, 0.041359303722856566, 0.10893628030316904, 0.02423897727567237, 0.016031059603847098, 0.07020207165624015, 0.04854106307902839, 0.053714244277216494, 0.03380984730029013, 0.02230063226306811, 0.06642406500759535, 0.046174973831512034, 0.018628591315064114, 0.025111047179962043, 0.01614287157281069, 0.039492609357694164, 0.06246802455279976, 0.06167596373416018, 0.027228409344388638, 0.031693654018454254, 0.04267805932613555, 0.022535624048032332, 0.07231460986076854, 0.080842116731219, 0.018664466733753216, 0.007700026590100606, 0.03080043661611853, 0.09666598169133067, 0.026133886240131687, 0.08702083752723411, 0.028787663468392566, 0.014756181626580656, 0.08172844885848463, 0.00992398945527384, 0.02164581495890161, 0.02911063129431568, 0.019283570036350284, 0.025495694899291266, 0.09143353629042394, 0.11323925253236666, 0.1084147953952197, 0.18138822459150106, 0.14240394928492606, 0.10064983784104697, 0.1398236205568537, 0.18206311884569004, 0.14175218035234138, 0.05439444117655512, 0.30951559776440263, 0.13971068052342162, 0.06358181752148084, 0.10347761344746687, 0.10706171917263418, 0.12006653618300334, 0.20689033350208774, 0.15073972230311483, 0.13137161236954853, 0.11944713973207399, 0.13536136859329417, 0.09253273863578215, 0.16599992610281333, 0.18676358537049964, 0.11919449039851315, 0.12701361731160432, 0.13276824523927644, 0.054291705673676915, 0.12476925883674994, 0.16007148718927056, 0.14972439006669447, 0.0760247693688143, 0.10253605811158195, 0.1760068821022287, 0.1515421472140588, 0.15722873504273593, 0.2752365090418607, 0.11229253184865229, 0.18209354690043256, 0.11018285091267899, 0.1376374761457555, 0.09930584550602362, 0.10645789297996089, 0.15966481994837523, 0.13242244895081967, 0.1509602737496607, 0.23141838843002915, 0.1746568561065942, 0.08673027186887339, 0.15835141151910648, 0.15830009942874312, 0.15941964404191822, 0.09314874347182922, 0.09360731652122922, 0.13493694917997345, 0.15766827942570671, 0.15564597153570503, 0.08932066411944106, 0.12069184755091555, 0.11713535714079626, 0.14189841313054785, 0.2013961845659651, 0.19133681809762493, 0.15688978135585785, 0.08039296153583564, 0.1644865088746883, 0.12980418163351715, 0.1562802554690279, 0.1810145383933559, 0.09734452731208876, 0.11464594150311314, 0.14524962549330667, 0.11923035839572549, 0.19265720271505415, 0.2950577298179269, 0.12721600098302588, 0.10841276191058569, 0.11178509579622187, 0.16085749579360709, 0.17399111995473504, 0.12066129333106801, 0.17939037788892165, 0.12079783366061747, 0.11210069409571588, 0.14551368163665757, 0.10801081472891383, 0.13551061449106783, 0.14183242135914043, 0.16652993828756735, 0.10855123182409443, 0.16375556762795895, 0.19783016497967765, 0.1833479100605473, 0.1938179216813296, 0.10497840674361214, 0.0964117886906024, 0.12150737878982909, 0.12323803748586215, 0.11366503007593565, 0.12132752672187053, 0.18004323035711423, 0.16106458468129858, 0.15063999249832705, 0.10621753361192532, 0.09760038272361271, 0.24573673261329532, 0.1793900365009904, 0.15007168549345806, 0.13486407027812675, 0.15565210167551413, 0.1574492419604212, 0.1569369967910461, 0.14908841403666884, 0.10565336036961526, 0.17010539799230173, 0.12730707734590396, 0.10786296406877227, 0.12654343707254156, 0.19037489080801606, 0.1322948292363435, 0.10917758962023072, 0.1821423356886953, 0.18349558260524645, 0.09493855875916779, 0.15744061820441857, 0.15198528359178454, 0.15305951266782358, 0.09016991112730466, 0.1526488526724279, 0.12473786599002779, 0.1948140174499713, 0.1487161824479699, 0.14992957905633375, 0.10334082820918411, 0.12362602486973628, 0.15460418915608898, 0.11204012000234798, 0.0976714730495587, 0.17949120607227087, 0.2735102141741663, 0.2276748768053949, 0.0969560575322248, 0.09383807991980575, 0.16549756634049118, 0.09419651498319581, 0.24122120928950608, 0.3257138910703361, 0.11448295845184475, 0.14665863738628104, 0.09522561405901797, 0.07131011298042722, 0.12508663086919114, 0.1354756296495907, 0.07720558569417335, 0.12504336365964264, 0.16319799207849428, 0.09044049817021005, 0.14931969693861902, 0.07057557231746614, 0.11919780779862776, 0.20902982651023194, 0.22169389383634552, 0.15141725860303268, 0.10429964590002783, 0.10842708536074497, 0.19783905590884387, 0.08866548130754381, 0.14934815088054165, 0.09182874477119185, 0.15283516142517328, 0.14977092272602022, 0.06802685908041894, 0.10118198741110973, 0.0730141434178222, 0.12408338079694659, 0.12582327181007713], [0.05013832444092259, 0.027569455887714867, 0.05373893924115691, 0.03684597344545182, 0.040424821054330096, 0.0498465565033257, 0.046134578733472154, 0.034755525266518816, 0.04584354181133676, 0.06584358678082936, 0.030819305720797274, 0.01887215861643199, 0.025111256836680695, 0.008424644274782622, 0.027353667173883878, 0.027687917499861214, 0.0222077469152282, 0.08496909606037661, 0.019112351001240313, 0.06219850249181036, 0.025132669652521145, 0.04868356656515971, 0.01359554707960342, 0.037688507727580145, 0.015637240794603713, 0.08452989306533709, 0.05915475449000951, 0.027483314806886483, 0.024095915323414374, 0.05747617229644675, 0.0464005273533985, 0.023133999166020658, 0.030984867735242005, 0.048563962045591325, 0.027350611380825285, 0.04703918624727521, 0.028831728486693464, 0.02483088457665872, 0.025051430457097013, 0.033026929741026834, 0.036258329782867804, 0.03731442819116637, 0.012516774204414105, 0.08167592706740834, 0.07161779256421141, 0.10672548174625263, 0.031998531994759105, 0.021591176191577688, 0.04122734986594878, 0.007962055278767366, 0.042253068459103815, 0.0447289918520255, 0.051712208151002415, 0.03785711254749913, 0.019971336841990706, 0.04027314091217704, 0.052368118267622776, 0.014150322876957944, 0.015754858213767875, 0.045759508429910056, 0.002562788763498247, 0.031743734143674374, 0.06208932143636048, 0.04002400193712674, 0.05889635351195466, 0.03315117639431264, 0.017091991248889826, 0.045632423061761074, 0.026415460779389832, 0.10777159084682353, 0.05474843077536207, 0.010851913393707946, 0.01135457929194672, 0.020631560691981576, 0.11122357202111743, 0.07953195148729719, 0.03531213602400385, 0.017658752731222194, 0.09496855636825785, 0.0383061749744229, 0.009812291591515532, 0.02930548958829604, 0.03883541161485482, 0.02810095793392975, 0.005827517497891677, 0.02082543749565957, 0.0354285159119172, 0.026541651859588455, 0.008324441350850975, 0.0677394401282072, 0.04877478764683474, 0.029988818350830115, 0.03221457860490773, 0.02927607642050134, 0.02023132416070439, 0.02550596065702848, 0.08574078121455386, 0.055998218595050275, 0.028181057932670228, 0.019287175018689595, 0.04860608263697941, 0.028472400990722235, 0.04644123786420096, 0.01256012954399921, 0.058431457364349626, 0.02280247994349338, 0.029455273543135263, 0.02852783571142936, 0.03698993525176775, 0.04196947156742681, 0.02287367231474491, 0.03378439163498115, 0.04534232495643664, 0.032952362453215756, 0.022282828140305355, 0.057825731273624115, 0.03027703882253263, 0.04677861448726617, 0.018617019377416, 0.08478899908368476, 0.07085915436618961, 0.02854856946214568, 0.031413886608788744, 0.03660529124317691, 0.06539170048199594, 0.03453832461673301, 0.04254698120348621, 0.04337581543950364, 0.054323332296917215, 0.11211020100745372, 0.0824274703336414, 0.10451217473018914, 0.028984980126551818, 0.028676832989731338, 0.03989070108218584, 0.011295245512883412, 0.06913433637237176, 0.0512026013166178, 0.036546991832437925, 0.027157530530530494, 0.03467592992819846, 0.015378236821561586, 0.023151933164626826, 0.01849536467489088, 0.01810744965041522, 0.05857262869540136, 0.054333855950972065, 0.034960250413860194, 0.009954173528967658, 0.05420016917923931, 0.09558960780850612, 0.014956468730815686, 0.10462113685207441, 0.04760303294460755, 0.044863342845928855, 0.016204892854148056, 0.14280776667874306, 0.03372084152942989, 0.0783216644776985, 0.008434879418928176, 0.021773520020360593, 0.013548115493904334, 0.05037921444454696, 0.07258749013999477, 0.029800145857734606, 0.06192165172251407, 0.02626870664244052, 0.06657936683041044, 0.04438479489181191, 0.03769974013266619, 0.08967348854639567, 0.03368477686308324, 0.01819879875256447, 0.007118326138879638, 0.028334643538983073, 0.03220634076569695, 0.026285675849067047, 0.0354695269925287, 0.046065072892815806, 0.040194903704104945, 0.03240309524699114, 0.07467015690053813, 0.009742590009409469, 0.06768370483769104, 0.03500874234305229, 0.07430484212818556, 0.029677561615244485, 0.04196295180008747, 0.011612638882070314, 0.013363462658162462, 0.004431959350768011, 0.020946578260918614, 0.07800363193382509, 0.05207061723922379, 0.007250343542182236, 0.053740857692901045, 0.0508648239338072, 0.02888768085540505, 0.02326365607586922, 0.016371991114283446, 0.05695146646758076, 0.015781814872752875, 0.055870606302050874, 0.060376218243618496, 0.030671818713017274, 0.01944248240761226, 0.061192454522824846, 0.04008714015071746, 0.064162258640863, 0.008877132640918717, 0.07112891762517393, 0.04980906691343989, 0.011801100790762575, 0.020180731953587383, 0.023040239939291496, 0.043080492614535615, 0.0421946428832598, 0.041567335138097405, 0.01966072577488376, 0.007011686475379975, 0.005345203144315747, 0.050056361651513726, 0.05279766963212751, 0.032054441689979285, 0.02426972259854665, 0.06682928506052122, 0.06390408772858791, 0.03302165678178426, 0.02845434268238023, 0.10567595134489238, 0.028077344650228042, 0.06327967435936444, 0.03369622449099552, 0.008446126666967757, 0.01003201554340194, 0.05933013882895466, 0.025152180714940187, 0.044625944647123106, 0.08973485673777759, 0.07582229663967155, 0.026366701677034143, 0.03525955486111343, 0.06700501078739762, 0.06997759424848482, 0.026691734528867528, 0.06425723127904348, 0.006338637385852053, 0.043789752016891725, 0.04117855365620926, 0.053073529634275474, 0.043917338334722444, 0.129620693041943, 0.04176178525085561, 0.05633445231069345, 0.06502411473775283, 0.022936352252145298, 0.023432951093127485, 0.04813867431948893, 0.06265883072046563, 0.05835464136907831, 0.01575071146362461, 0.026114670181414112, 0.09537868943880312, 0.03571977918909397, 0.022771560215915088, 0.008164487189787906, 0.0514685610687593, 0.036045270317117684, 0.04172395798377693, 0.01994328365981346, 0.05140925604791846, 0.014297019497462315, 0.04410160247061867, 0.023084050772013143, 0.04032539181935135, 0.015290794199245283, 0.09342242527054623, 0.05490458235726692, 0.010582920112938154, 0.07461996545316651, 0.027796664398920257, 0.02356406632316066, 0.025806317098613363, 0.05552965623792261, 0.0988364074146375, 0.035624661832116544, 0.022951677601668052, 0.02950306599814212, 0.08450061533949338, 0.02671918657142669, 0.01703173813439207, 0.010096754012920428, 0.032393803558079526, 0.037057021690998226, 0.017598828017071355, 0.0649950819206424, 0.08530756735126488, 0.029329754106584005, 0.009527389447612222, 0.006090019769544597, 0.014595467691833619, 0.0514071001089178, 0.02024826368142385, 0.008777357379585737, 0.09550848364597186, 0.05067932783276774, 0.03584672354918439, 0.051392713576206006, 0.007322723349716398, 0.007930864667287096, 0.02634758024214534, 0.015224613180180313, 0.06741463177604601, 0.031233411136781797, 0.03920071525499225, 0.011002660285157617, 0.03671812737593427, 0.0848210153344553, 0.012471190566429868, 0.022946412063902244, 0.04028442897833884, 0.03789373753534164, 0.05411549012933392, 0.017336675482511055, 0.05312341309036128, 0.05278293429000769, 0.05327615450369194, 0.021562084002653137, 0.06222821066330653, 0.013326535245141713, 0.024256918695755303, 0.03924110293155536, 0.027869290970556904, 0.05388575831602793, 0.047376785514643416, 0.05472083772474434, 0.023616563994437456, 0.04207682693959214, 0.080841894086916, 0.04877312152530067, 0.021955984448140953, 0.04656234152207617, 0.04723803358501755, 0.0440863476251252, 0.07715520870988257, 0.029479443437594455, 0.05506314220838249, 0.022907501261215657, 0.05481818523549009, 0.022165863811096642, 0.008494522116961889, 0.031533201690763235, 0.11422106937970966, 0.12167373119154945, 0.10473658534465358, 0.22081823379267007, 0.11649842374026775, 0.23022994282655418, 0.09955506611731835, 0.20903991971863434, 0.14599312387872487, 0.10687808957300149, 0.12254743938683532, 0.11516530386870727, 0.13792539975838736, 0.11901522462721914, 0.1727181882597506, 0.16116614016937092, 0.13942882767878473, 0.10367544775363058, 0.1224885277042631, 0.11015726908226497, 0.10262473733746447, 0.12202893049106933, 0.12358904365100898, 0.12260344185051508, 0.11625533326878212, 0.16833782487083226, 0.08536283508874476, 0.16938682092586532, 0.14277152018621564, 0.1478103021509014, 0.14171795250149444, 0.09775491271284409, 0.11392437358153984, 0.053360403107944876, 0.3777617169544101, 0.1500527755706571, 0.20586370577802882, 0.1284921239130199, 0.14666182862129062, 0.13645094528328627, 0.11766681651351973, 0.1477258902741596, 0.16183442930923775, 0.10980236664181575, 0.09542718136799522, 0.13731308339629322, 0.12947826005984098, 0.07848210938391276, 0.1802947887335904, 0.12406188077875413, 0.1526287107844837, 0.07796426842105575, 0.16840118943946436, 0.14893919782480225, 0.17699202377116308, 0.15174142870819196, 0.20055113069247454, 0.08094446631730534, 0.049864705724758096, 0.08935976788052358, 0.10990024107741192, 0.12382353263092227, 0.22375191387254745, 0.2977238508174196, 0.19357286451850086, 0.11959306822973303, 0.22333133878419176, 0.1470284495735541, 0.18567915918538347, 0.11987336256424896, 0.10124168577021919, 0.1668660866562277, 0.09815947967581451, 0.12624760216567665, 0.1678749028360471, 0.20467747177463025, 0.1305592426797375, 0.10105863504577428, 0.21936105651548132, 0.11814850004157051, 0.11269939204794355, 0.2068402385339141, 0.11962779331952333, 0.1512083291891031, 0.12442248291336, 0.10190506189246662, 0.12511597538832575, 0.10699353806558065, 0.1172057721123565, 0.13183299073716626, 0.10754949573311023, 0.12673307064687833, 0.0737688853405416, 0.11482260975753888, 0.10922441913862713, 0.12545250967377797, 0.21533031889703125, 0.14132090349448845, 0.12347236319328658, 0.08931327975005843, 0.17111268534790725, 0.16851807769853622, 0.10284997173584998, 0.1379972544964403, 0.14690353127662092, 0.06409940615412779, 0.09769718846655451, 0.13063601043540984, 0.2241184309241362, 0.11061898141633719, 0.11154015737702139, 0.2022703009424731, 0.2485813549719751, 0.1046636322280392, 0.09463266032980755, 0.12462180893635377, 0.144771593331825, 0.11772453333833255, 0.215034335560631, 0.11937840943573974, 0.1555307160015218, 0.15557396836811677, 0.1292033091885969, 0.10479329284862615, 0.1433601471944712, 0.14890200138324872, 0.11204581969650462, 0.0892176762863528, 0.42116414580959827, 0.18058559187920764, 0.23366613109828904, 0.1488592685200274, 0.10527040474698879, 0.2004982452490367, 0.1469932569307275, 0.07683031872147694, 0.15244777518091723, 0.17063103150576353, 0.08806744386674836, 0.08643026609206572, 0.09917340925312601, 0.12332902479101904, 0.12102421838790178, 0.093367454392137, 0.10292016406310722, 0.21595960075501353, 0.2564877807162702, 0.11348303320119157, 0.12314897234318778, 0.14991267293225974, 0.13843353342963383, 0.11581363665754907, 0.20819866564124823, 0.11256509300437756, 0.08359995976206847, 0.0648711209942121, 0.20566766004776582, 0.10807647995534353, 0.14679173415061086, 0.10702118306653574, 0.12012925508315675, 0.08574366816901602, 0.1798622650676407, 0.1572844703332521, 0.11679606948746368, 0.1767212586128153, 0.10768505642772652, 0.11613929847953841, 0.13802688103169203, 0.0931754162593279, 0.16598318325122818, 0.11810472075012513, 0.1634455131716095, 0.1211053499719128, 0.12112047494156286, 0.1072692013985943], [0.06523385309264995, 0.018146818729292136, 0.04767630889546126, 0.04562425943731796, 0.03139741093036719, 0.0081910245353356, 0.05060175113612786, 0.02270891738589853, 0.020148773219261784, 0.024818533383950125, 0.020655292719311547, 0.03034518096683314, 0.03334940774948336, 0.037454712655744515, 0.014664863138023065, 0.10489893757039681, 0.04640452752937563, 0.016249918953690212, 0.029094853234710172, 0.028574626267072745, 0.03104585557593964, 0.022485028130176943, 0.05980233399895951, 0.046525078287231736, 0.08251626088167541, 0.016643594899505842, 0.03375392276211642, 0.011013386174454354, 0.04937627978506498, 0.107388160249684, 0.037407500931294635, 0.030016622913535684, 0.06924513159901835, 0.08765377075178549, 0.020440019798115827, 0.03629363374784589, 0.0681252678623423, 0.0336231934488751, 0.0479431666462915, 0.13134854641975835, 0.021281455701682717, 0.021435204580484424, 0.058069578735739924, 0.06022096837114077, 0.10536564455833286, 0.004970130985384458, 0.1124770446040202, 0.0860853232734371, 0.05718256754335016, 0.057300691478303634, 0.05600189964752644, 0.02535025436372962, 0.019858331870636903, 0.05455486010760069, 0.04244938878400717, 0.041847514439723454, 0.010134526546607958, 0.05184373527299613, 0.03743570625374559, 0.019381899037398398, 0.014323742379929172, 0.03303982826764695, 0.026683043979573995, 0.05837153636093717, 0.04940506398270372, 0.04559213557513431, 0.08364863722817972, 0.0226749734065379, 0.09876531708869152, 0.028933873982168734, 0.0486813549650833, 0.01170053885289235, 0.05806881432363298, 0.03256418953242246, 0.0930031860480085, 0.06224307588126976, 0.0398055470577674, 0.020658170396927744, 0.016695569356670603, 0.10084017645567656, 0.05116321182867978, 0.06445542923756875, 0.013993342872709036, 0.052372845748323016, 0.036538683489197865, 0.01215537426105584, 0.017881727289932314, 0.025784744721022435, 0.021117468895681668, 0.04274832957889885, 0.04568107455270365, 0.02521058588172309, 0.006165718832562561, 0.03834914903563913, 0.03702806308865547, 0.014564515495294472, 0.011780580407503294, 0.01698343359748833, 0.04119534474739339, 0.02326362082385458, 0.06328172268695198, 0.010972572690661764, 0.05895067130040843, 0.010094751141878078, 0.0939887210552115, 0.020759046819875948, 0.03903678596543614, 0.019484914701024536, 0.04019286279799417, 0.03629347789683379, 0.0006485106143827579, 0.0027482725727168145, 0.0319938861503033, 0.042286932657589205, 0.03889580017130356, 0.012431391041900497, 0.02364508472965099, 0.07269545036251657, 0.01604203411261551, 0.019136051487294026, 0.024211078089138027, 0.026689984915719833, 0.026732240949058905, 0.025247118101106025, 0.02759123977739364, 0.08130880887620151, 0.030114870278339367, 0.016718177030270454, 0.014425161498365924, 0.0634420859569218, 0.045651166001334786, 0.09003470666357316, 0.02557848518335959, 0.023062803084030747, 0.049561801861273125, 0.010711674385674996, 0.042915539161185734, 0.07184742789831944, 0.04535682652203832, 0.02642784165800549, 0.047320070589194074, 0.05227438872680068, 0.0012848353958361258, 0.07892619571066462, 0.053082127415109426, 0.02845946350134909, 0.04452246328582987, 0.027565784112084657, 0.05425320676295087, 0.04846585383347701, 0.03289365486125462, 0.02891577300033532, 0.0003788501544477185, 0.018737178652372677, 0.014364095732162241, 0.028429195008357055, 0.06142222715425305, 0.043497405204107054, 0.0028075759701096104, 0.07651639767573215, 0.04460130163352005, 0.0313647861185018, 0.011903110844286857, 0.07763776055071503, 0.05101779170217924, 0.022051565647416282, 0.048382221211795695, 0.05089371574285906, 0.01137891988037154, 0.012361467743176036, 0.02338167239940958, 0.03531666312483139, 0.037281977784004994, 0.1171673065982759, 0.025084025583055336, 0.005643578051603981, 0.0418042360979598, 0.03073987736570416, 0.01672255570156267, 0.028322513135208283, 0.006046594853614806, 0.04784185606695246, 0.06754499743692577, 0.014430238716158783, 0.0692890741629526, 0.033507214320707135, 0.04391818067233544, 0.06109162262873724, 0.052203554441803135, 0.03804055661021266, 0.06591108511202037, 0.016770964139141142, 0.03202257015800569, 0.04001565648650285, 0.030444383846770506, 0.035291890235384926, 0.027606873118202202, 0.0611496400233591, 0.06724721068167128, 0.006611513954339898, 0.02306091431819368, 0.0346824942243984, 0.011098013274022378, 0.0795167003525421, 0.020892410757369362, 0.056598066876176745, 0.10187927226070315, 0.015538819952780614, 0.034307004607398994, 0.06316436687484384, 0.01733734712615842, 0.04553649305307772, 0.027687733818311244, 0.053541052984655835, 0.017824006754381116, 0.04577540894388221, 0.0267519616681966, 0.04794269167177845, 0.11104069199063815, 0.07329247848247178, 0.10537938171182759, 0.05802089013741352, 0.017181076800625306, 0.022365685217664577, 0.03900938587321434, 0.05665345706802327, 0.027440309204393998, 0.0390841572516365, 0.09008244902361184, 0.02634017917443998, 0.026176565297646448, 0.012397047230479075, 0.01423571067789453, 0.04618971288437024, 0.0211857613248867, 0.06838892324594781, 0.09509432813501917, 0.04061625062604435, 0.044465225146268494, 0.004359123586255009, 0.018878939990827348, 0.04732220797450282, 0.056648377067176625, 0.028161960617580917, 0.024165024115063716, 0.05177689374249894, 0.042794758337549865, 0.05870650471479166, 0.03082103492488386, 0.022466645132226404, 0.03623804688686505, 0.020999853331886698, 0.03684512739710044, 0.04346676934801508, 0.07692304265219718, 0.03586214537790511, 0.010349459007557016, 0.05703129558241926, 0.028746993775712326, 0.033288796548731625, 0.027062223925895523, 0.021356594443204813, 0.018893627093348186, 0.040593318262835965, 0.02384230676398147, 0.07210835217847489, 0.03999664266302716, 0.0213173793599708, 0.026962766860378906, 0.05591438559349626, 0.02405846655165078, 0.01699763088254258, 0.026384964075987227, 0.03863268284476362, 0.101654312456958, 0.029143619758542627, 0.014073676647967659, 0.010574447569524636, 0.025328995543532073, 0.0853291638486553, 0.06097762503486592, 0.0331564975931542, 0.020551367924781516, 0.07421458212775178, 0.07483906229026616, 0.026337127092119772, 0.03403937502298504, 0.05246766624622978, 0.05710828227165621, 0.09903753685648553, 0.04220112554321531, 0.0677445980545599, 0.030612016453233082, 0.031464486237382516, 0.045740572531940416, 0.048698550526751205, 0.026192721852567047, 0.06297042884398252, 0.01758678481564857, 0.024656244240759406, 0.021953832219878677, 0.04121922705962788, 0.006427594917113311, 0.02394281211309135, 0.03919970964489039, 0.032077919531730004, 0.05239042351604439, 0.046896456406102516, 0.012971062278666068, 0.044921927983523346, 0.036968301646993496, 0.07650931758689694, 0.03317653558042366, 0.06809562648413703, 0.058495834964560345, 0.04566819086903706, 0.01746715061017312, 0.0045401153147395235, 0.019188873848179355, 0.014618221939599607, 0.02816930787957972, 0.04479063834878616, 0.022232172850635834, 0.0447544438065961, 0.050770003435900435, 0.045391547901090235, 0.03281016324763186, 0.062148485449142754, 0.013865305700164754, 0.026599951270327438, 0.03033272772881901, 0.04814796229766216, 0.008411072249145946, 0.035776924560195766, 0.033919332636287436, 0.01967789536138298, 0.03232981929613743, 0.034586668116389774, 0.0200195857178187, 0.11384235142031685, 0.039974797546165064, 0.0396734187961556, 0.015206115149339894, 0.016773212846601382, 0.04012547207821626, 0.054078943066997454, 0.0571661141293589, 0.034271489130333066, 0.04243845323799178, 0.09373540378874168, 0.053265682799974456, 0.012269220642338041, 0.1647755753947422, 0.14786314306547865, 0.11934457492316142, 0.12770555127644911, 0.08497775692376308, 0.11675028639729135, 0.13162493705749512, 0.12839114730013534, 0.16742769948905334, 0.1543935082736425, 0.14791285211686045, 0.160444401553832, 0.09894018934573978, 0.09289929279475473, 0.24320163036463782, 0.14619329595007002, 0.11318152828607708, 0.1263437102898024, 0.1215564421727322, 0.09097908216062933, 0.07507575544877909, 0.14415381476283073, 0.15449608792550862, 0.1855796668678522, 0.16988753312034532, 0.1198249968001619, 0.13088937965221703, 0.12169555033324286, 0.18369893106864765, 0.16230869136052206, 0.26649377192370594, 0.0943603811901994, 0.11367093757144175, 0.1779852548497729, 0.08364353867364116, 0.1583018954261206, 0.12387770941131748, 0.0971832883078605, 0.10205009239143692, 0.19320190942380577, 0.1438745594350621, 0.10221168762654997, 0.24286056897835806, 0.18327753961784765, 0.19874162622727454, 0.16075680119683966, 0.22286555205937475, 0.15462278737686574, 0.12505373888416216, 0.13467054784996435, 0.17242615314899012, 0.13130177627317607, 0.18922018323792145, 0.08782067976426333, 0.11821838066680357, 0.1255691604455933, 0.11147852201247588, 0.227340969722718, 0.10038777807494625, 0.24298337957588956, 0.22088119760155678, 0.09530184004688635, 0.10557567235082388, 0.10375295765697956, 0.06142512895166874, 0.12432809657184407, 0.11438867601100355, 0.11911211200640537, 0.15918331453576684, 0.15956783608999103, 0.2748564403736964, 0.09688490041298792, 0.08916379636502825, 0.1554664460127242, 0.15075374889420345, 0.11635133749223314, 0.10394932993222028, 0.16974281432339922, 0.19451662403298542, 0.20563687576213852, 0.10494301372091286, 0.14688000519527122, 0.11624039383605123, 0.14910416241036728, 0.07784557674312964, 0.11471401870949194, 0.08692493720445782, 0.0932526144606527, 0.13534459605580196, 0.14977773564169183, 0.10199533673585393, 0.09763806898263283, 0.13366467057494447, 0.09640945092542097, 0.10000704889534973, 0.17687464569462463, 0.08994720745249651, 0.11145385302370414, 0.1932341037900187, 0.2062463719630614, 0.13836121856002137, 0.1014680927619338, 0.14192953880410641, 0.19729871302843094, 0.18118842359399423, 0.09183222544379532, 0.11648115396383218, 0.12871518381871283, 0.12338530184933916, 0.10636491671903059, 0.13727324490901083, 0.10009971345425583, 0.12368329640594311, 0.14899638772476465, 0.1179980296001304, 0.11575905911740847, 0.13828019087668508, 0.15813553560292348, 0.14732156821992248, 0.11325821440550499, 0.1299331520567648, 0.16482764447573572, 0.200194395147264, 0.1058612136694137, 0.06386156266671605, 0.19190825696568936, 0.10506831051316112, 0.1472045315313153, 0.0911351187096443, 0.12468621251173317, 0.14384522975888103, 0.2511169173521921, 0.09455770341446623, 0.11996624976745807, 0.1554819123703055, 0.1290545827941969, 0.0963647142634727, 0.15649463224690408, 0.25378760998137295, 0.12547933089081198, 0.10084761277539656, 0.10634070786181837, 0.1270345161901787, 0.11690958839608356, 0.13793329620966688, 0.09902693898766302, 0.19496762717608362, 0.10573179053608328, 0.1156164777057711, 0.14771569316508248, 0.08218446891987696, 0.1604653152753599, 0.09246572270058095, 0.1543886397848837, 0.08233854619902559, 0.1082401977328118, 0.11980339288129471, 0.09531706891721115, 0.09144385214312933, 0.16271682805381715, 0.09574827156029642, 0.08415985081228428, 0.10420516307931393, 0.17536621569888666, 0.1346712454687804, 0.1373008082737215, 0.17754581436747685, 0.1435513244359754, 0.11955799433053471, 0.19541903107892722, 0.13000698090763763, 0.10038738473667763, 0.22605801903409883, 0.23716844472801313, 0.16715883422875777, 0.13486896845279261], [0.02316871683433419, 0.06519791088066995, 0.06871911959024146, 0.05409649485955015, 0.02757543945335783, 0.06174513189762365, 0.02143373327271547, 0.02654379295563558, 0.031070372424437664, 0.04556287640298251, 0.03865121798298787, 0.02458911698340671, 0.013423001455521444, 0.025336468970635906, 0.01792667360859923, 0.05043805191235151, 0.02726312515733298, 0.03633708649431355, 0.06552622216986492, 0.0597464762540767, 0.04536923152045347, 0.07705297044594772, 0.006874572836750303, 0.00870144865984912, 0.045966367251821794, 0.0004527642943230603, 0.03085484160692431, 0.02684386923647253, 0.1147328841034323, 0.01659494711930165, 0.014382533463503933, 0.06651845134911127, 0.025525620148982853, 0.07997565931873396, 0.02288278774358332, 0.03147612311295234, 0.0645389653800521, 0.03847617503197398, 0.028965522869839333, 0.02686215018911753, 0.05658406254951842, 0.06595898332307115, 0.06530798622407019, 0.008544909305783221, 0.028892285881738644, 0.046714474374311976, 0.05067082282039337, 0.06790138417272829, 0.040325291629415005, 0.030133780201140326, 0.017067372355086263, 0.011683545526466332, 0.024390510843659285, 0.01970193537999876, 0.02111026449711062, 0.060495622383314185, 0.05971371785562951, 0.05670030142937321, 0.040686201755306683, 0.034285200308659114, 0.03991895464423578, 0.02217896642832784, 0.03607485232350882, 0.06858130276668817, 0.042833238694584, 0.015198835608316585, 0.07301933845155872, 0.011399718569009565, 0.07186072718468495, 0.05186735783354379, 0.05052284599514678, 0.06805319047998637, 0.08200740732718259, 0.054756735407863744, 0.021260603207338136, 0.03210196882719174, 0.03040083833184326, 0.004057236001244746, 0.024322481876879465, 0.04356310011644382, 0.03814925526967272, 0.007574514111183817, 0.01592998465639539, 0.007790326017129701, 0.03408431577554438, 0.0655604871280957, 0.03298547708254773, 0.023059331688273232, 0.03396942760446109, 0.029242516502563376, 0.047510119766229764, 0.016794534749351442, 0.006862518039270071, 0.022718828768120147, 0.073385647701798, 0.0496388479223242, 0.024850423469615635, 0.009257378496840829, 0.03995218801719602, 0.03356679393618833, 0.04469753592275083, 0.026311125948268455, 0.028822494314226788, 0.0112581770918041, 0.0341023722285172, 0.04015683523903135, 0.03132162652036641, 0.02458337647112785, 0.040436995986965485, 0.012859123216912849, 0.06642006483161822, 0.003318465560369077, 0.011606748084886931, 0.022030397740309127, 0.01807262251531938, 0.04244178177032154, 0.09970064580556937, 0.0479865006491309, 0.007202780225270544, 0.035068147553829476, 0.022631795254710596, 0.04015459395304788, 0.06272808052017353, 0.025947562644432765, 0.09607719141058624, 0.026188278243353125, 0.07865261039114557, 0.05906881378905382, 0.0395593729626853, 0.04660916732973419, 0.03898229006153997, 0.021473074521054514, 0.04183947326964699, 0.05889695465157274, 0.011447788401710568, 0.03836057810985949, 0.05845761435921304, 0.03545870276866481, 0.035528542575775646, 0.038554044876946136, 0.04669551992265042, 0.050725352120934986, 0.04594543126586359, 0.04151496548729483, 0.027899221786356065, 0.018571412547316868, 0.03321587311802432, 0.015206700518319849, 0.043529996619326994, 0.04267771051672753, 0.011317720527586062, 0.006950173565201112, 0.037163159940973856, 0.057616167323431, 0.018069171528622974, 0.012070082011632621, 0.04561798086797353, 0.02463126540533267, 0.03706630966917146, 0.0026266415261488874, 0.025231931904272642, 0.07424679133691825, 0.021947468303551432, 0.06691364498692565, 0.06513331434689462, 0.05117830711242277, 0.05904174395254813, 0.027500953801791184, 0.006672672025160864, 0.0836171701666899, 0.013295140543050366, 0.04475011708564125, 0.025560155991115607, 0.1556753012118861, 0.012814126803277759, 0.06416239964892156, 0.004104339650439215, 0.05203002176131122, 0.007434539493260672, 0.032839704435900785, 0.0674258307844866, 0.060268276574788615, 0.07330015971092507, 0.016213375602092128, 0.05314961832482368, 0.027601440597209148, 0.020763768734468613, 0.01685447059571743, 0.01967756325029768, 0.0776412857521791, 0.053592717595165595, 0.03474553224805277, 0.0319243246485712, 0.02671913091035094, 0.046013222745386884, 0.04332695985794999, 0.028177590247651096, 0.06150925510155503, 0.04066634188347962, 0.02895910514780553, 0.07711265396210365, 0.04551669626380317, 0.04402434118674137, 0.007751103048576624, 0.09434190913452767, 0.01929307880345732, 0.04157539486186579, 0.062177807703847066, 0.021802704977744725, 0.0853366892260965, 0.06386829394614324, 0.03283131816715468, 0.02403401093033608, 0.060114455336588435, 0.04111628375540022, 0.04209448263281956, 0.030727227458555717, 0.021946809647488408, 0.01331887813648791, 0.013519341500796145, 0.004373746214696439, 0.011958815521211363, 0.026510032657824922, 0.06951522140298039, 0.010559838392509846, 0.0352407933678478, 0.048214054259005934, 0.033407169103156775, 0.043032501635025255, 0.03029682076885365, 0.0337768328608945, 0.01089422416043817, 0.03387092234333977, 0.04261690264684148, 0.09724962146719918, 0.04803233940037899, 0.03664187541289721, 0.040164560996345244, 0.012908886074001202, 0.05754411962698214, 0.11414046472054906, 0.026902664030785672, 0.03439563930442091, 0.036452716813073494, 0.10991281305905432, 0.12411974603310227, 0.017601752078917343, 0.05912645639909897, 0.04784588221809827, 0.02473749642376788, 0.015394032507174416, 0.013331103164091473, 0.06619499370572157, 0.06394229349098168, 0.02572395354945911, 0.010999236201314488, 0.007589965625811601, 0.022686294869345147, 0.02827923664881382, 0.04942464925989043, 0.055953036644496024, 0.060307591847958975, 0.03251858455769252, 0.020077087319805287, 0.028664891833614092, 0.05124212068039924, 0.06391131624695845, 0.026177006875514053, 0.030062942205404397, 0.09936138783814386, 0.04909997449431103, 0.04291659301088657, 0.01706377664959291, 0.05449787058751099, 0.025432935181015637, 0.03925771961803548, 0.05522966901480686, 0.011130215989396675, 0.02794150193949463, 0.015712021449871827, 0.05128491291543469, 0.057129967826767825, 0.008124816613417352, 0.06904145659063943, 0.012358971343928715, 0.03066055662202416, 0.0674928021908272, 0.04070504859555513, 0.06076313693483826, 0.005153125121069024, 0.06855484520201571, 0.033268691768171266, 0.04183007768006064, 0.045627239160239697, 0.01139859514296404, 0.03009790107171284, 0.05072340769402217, 0.008075807036220795, 0.028142579431005288, 0.06423372004064731, 0.019979760218120646, 0.028543122098199092, 0.03697235377330799, 0.026294841372873634, 0.03969522309489548, 0.061516171917901374, 0.0467626063618809, 0.017034660340868868, 0.03115652834821958, 0.007641598231202806, 0.04600240594299976, 0.005482877568283584, 0.06683174156933092, 0.024448335279885214, 0.010812604614329757, 0.008408936719206395, 0.019397834803385194, 0.06678192861727439, 0.05113173363497481, 0.03979876382800285, 0.028645256461459212, 0.016551219778193627, 0.0334781184210442, 0.044419416080927476, 0.004254710829627584, 0.02275491013278952, 0.016279233786917757, 0.04846543452003971, 0.023396791802952066, 0.02522449372918345, 0.04103759754798375, 0.015738185866212007, 0.03246929853048641, 0.04658580452087335, 0.10425695014419034, 0.018780460704874713, 0.04141146557230968, 0.07752030083793215, 0.04638795166101772, 0.02750782423390774, 0.03344462900713552, 0.027891097124665976, 0.012185156647319673, 0.02569485022831941, 0.042331710137659684, 0.04717610136140138, 0.05357466856366955, 0.023554464787594043, 0.04967552486050408, 0.10352487341151573, 0.0291443118112511, 0.02416129853372695, 0.11581575177842751, 0.09289735578931868, 0.15758135908981785, 0.08917975996155292, 0.11388241255190223, 0.14837562572211027, 0.16689571319147944, 0.09050099804881029, 0.12323571456363425, 0.17842677334556356, 0.19127477455185726, 0.1274530726368539, 0.18442206492181867, 0.12473232956836, 0.13676469563506544, 0.11671214742818847, 0.06379906641086563, 0.17736710520694032, 0.1907052652677521, 0.17284836096223444, 0.12008289311779663, 0.13533200923120603, 0.19866812392137945, 0.10406340545159765, 0.1780430829967372, 0.13028895249590278, 0.11138216155814007, 0.06902334818732925, 0.18937953718705103, 0.15194526698905975, 0.16164329659659415, 0.155796033795923, 0.11113007625681348, 0.1684538967674598, 0.18292596942046657, 0.12057835090672597, 0.08604565548012033, 0.18074746913043782, 0.09856587232206948, 0.10652870871126652, 0.07488903109333478, 0.17161881522042677, 0.10311888894648291, 0.12231024156790227, 0.0932112471491564, 0.15830795135116205, 0.11035728530259803, 0.16419227700680494, 0.11324569437419996, 0.10140149242943153, 0.18408573843771592, 0.058373803622089326, 0.22676973865600303, 0.19437751587247476, 0.1557943713851273, 0.17473521205829456, 0.07104026066372171, 0.14303260773885995, 0.23588196141645312, 0.1370853479602374, 0.0898805254837498, 0.1608316838974133, 0.14516478317091241, 0.11639320946414955, 0.20073018124094233, 0.10858258756343275, 0.14842337550362572, 0.15997635870007798, 0.14354881597682834, 0.18750203715171665, 0.08819941256660968, 0.11503178408020176, 0.13038163189776242, 0.18929368554381654, 0.058084221309400164, 0.09586217638570815, 0.12817337148590013, 0.20906052173813805, 0.08245785385952331, 0.17961027624551207, 0.12362989888060838, 0.08961269180872478, 0.10766358609544113, 0.11210055308765732, 0.14293353102402762, 0.15790900244610384, 0.1355186296859756, 0.12505419901572168, 0.11298064375296235, 0.1422019218443893, 0.15120605821721256, 0.091277848550817, 0.1407906092936173, 0.18309840001165867, 0.11718654306605458, 0.26193811325356364, 0.09001670958241448, 0.10927460316452198, 0.12968613562406972, 0.2297343811369501, 0.15649578999727964, 0.11515939637320116, 0.21641327562974766, 0.0875244515191298, 0.08508389146300033, 0.14245857135392725, 0.16976680053630844, 0.13734328880673274, 0.1483073629788123, 0.15070512337842956, 0.10791060994961299, 0.1524962967960164, 0.10570423459284939, 0.1634609795291908, 0.1121336009236984, 0.1084244878438767, 0.17085655534174293, 0.1386744642513804, 0.12445832864614204, 0.1562195923179388, 0.21105750754941255, 0.1268958830041811, 0.09931555279763415, 0.1193490946025122, 0.14369167940458283, 0.1481016247998923, 0.14322400762466714, 0.15426522062625736, 0.15431061037816107, 0.09406616416526958, 0.1760990420007147, 0.14978226274251938, 0.09656391412136145, 0.16833942790981382, 0.16310531267663464, 0.15633533766958863, 0.14935266313841566, 0.11036643598345108, 0.09972730375011452, 0.144119008036796, 0.13260234554763883, 0.12114716999349184, 0.1584617540356703, 0.1349260247661732, 0.16837399714859203, 0.09984890464693308, 0.12448326480807737, 0.1457421889062971, 0.06542992850882001, 0.10282709874445572, 0.14003879885422066, 0.16798678901977837, 0.140455381188076, 0.15929704124573618, 0.0762530614156276, 0.1773401949321851, 0.12416990037309006, 0.16973993479041383, 0.16719110280973837, 0.07692504645092413, 0.14278063375968486, 0.14827399601927027, 0.08859836889314465, 0.11727270641131327, 0.08194002773961984, 0.1351644768146798, 0.09220151812769473, 0.1086317771114409, 0.20769320370163769, 0.1646967593114823, 0.14107942348346114, 0.08370115901925601, 0.194073413440492, 0.2835499285720289, 0.15504904731642455, 0.1442441638209857], [0.05877101590158418, 0.037581519718514755, 0.06589077253011055, 0.04676880700571928, 0.029981265142851043, 0.045384549448499456, 0.03923244948964566, 0.028576598524523433, 0.037165820540394634, 0.024541074053558987, 0.023302874869841617, 0.03993766047642566, 0.03366439006640576, 0.035165472800144926, 0.034013626209343784, 0.06718809861922637, 0.05124744930071756, 0.040895854763220996, 0.06359246734064072, 0.027467594263725914, 0.028122354051447473, 0.07564660059870221, 0.07103408599505201, 0.06538384855957702, 0.03869559470331296, 0.04196199071884621, 0.10003579227486625, 0.029281787246873137, 0.01999784079089295, 0.057869762895279564, 0.027992613649985287, 0.05490647854458075, 0.03530178677465301, 0.05624490477202926, 0.0643617330933921, 0.010141267102881102, 0.011533977722137934, 0.04487484613491688, 0.02858663792721927, 0.059456459784996696, 0.018546725004853215, 0.03797240147832781, 0.06497583060991019, 0.042075973469763994, 0.046423263047472574, 0.05148442076460924, 0.04717334057204425, 0.01777862442395417, 0.029617610925924964, 0.040662196988705546, 0.047236838727258146, 0.05582146128290333, 0.007931340569484746, 0.05157000523468014, 0.02400829180260189, 0.08936698155594058, 0.026544889478827827, 0.0489657941943733, 0.06546297634486109, 0.050064818424289115, 0.006101625567680458, 0.028109054765081964, 0.05633289380057249, 0.03452415701758582, 0.045053058056510054, 0.015855983256187756, 0.02678583885426633, 0.04076517740031704, 0.04547679469396826, 0.009201213688356802, 0.0491903012880357, 0.0735742348479107, 0.06582237620023079, 0.07249185699038208, 0.0045890376895840745, 0.058910877341986634, 0.02527857774111908, 0.05112546248710714, 0.04454169604287017, 0.01395630413753679, 0.017880222585517913, 0.05227039226156194, 0.039911818894324824, 0.011088609335274668, 0.05096288390632253, 0.0553464273980353, 0.0523969507048605, 0.017783218318072613, 0.04849643031775486, 0.03803340601734817, 0.040151810899260454, 0.04949779904563911, 0.009539826914988225, 0.02178812734200619, 0.029973563505336642, 0.06469412619480863, 0.022417251493607182, 0.015309641039493727, 0.04550813930109143, 0.03190123643435072, 0.08494073117617518, 0.04973752387741115, 0.01794613643141929, 0.04961339967849199, 0.029975186953379307, 0.040150181885110214, 0.01233654827956343, 0.023909539777378086, 0.05345732017303817, 0.02672734648513142, 0.07331173721468076, 0.02922403517004568, 0.04126204155909363, 0.027611075529421214, 0.03878223673382308, 0.0107549415952235, 0.01578375929966569, 0.01002387325570453, 0.035931432284996845, 0.027439561490609776, 0.041610472471802495, 0.03207348891010042, 0.07639300820301287, 0.030193738311936613, 0.03956257532991003, 0.03742147557204589, 0.018283988028997555, 0.018410166121611837, 0.053319525613915175, 0.04941661922202911, 0.06987724846112542, 0.03617824833781924, 0.02471508541930234, 0.049057293581427075, 0.09039734970428981, 0.0390244885784341, 0.024341211828868836, 0.03548730514012277, 0.03158853251079563, 0.03898840906913392, 0.06081650106352754, 0.02776656659989385, 0.044085367990192026, 0.03886603633873165, 0.04792450534296222, 0.016085119495983236, 0.025910809636116028, 0.0321381633693818, 0.021814362262375653, 0.022480013067252003, 0.013042906812188448, 0.07577820564620197, 0.07931664702482522, 0.04337475045758765, 0.03357449000759516, 0.006170262167870533, 0.01883535922388546, 0.047586835571564734, 0.0499544499325566, 0.041560826502973214, 0.05173704783373978, 0.0018877943193729152, 0.047238775732694194, 0.008970110757218208, 0.050571875981404446, 0.0384748651413247, 0.07770105090457946, 0.06238995061721653, 0.011970635150646558, 0.034352861912338994, 0.06220503339136485, 0.10340174369048327, 0.054763678199378774, 0.034193600731668994, 0.06832797807874158, 0.027904136659344658, 0.057193120883312076, 0.02767799869616283, 0.04188009843346663, 0.0826403331302572, 0.003383521066098183, 0.034113363435608335, 0.021585103568213526, 0.07621102617122233, 0.02556872965215007, 0.06114690149843227, 0.026975481705449056, 0.04167837898421567, 0.037652520986739546, 0.07308245068998076, 0.012226125982124358, 0.043207759808865376, 0.0075343926800997, 0.017811080397223122, 0.04053050659422297, 0.04478928764001466, 0.0116736155905528, 0.05501588966581039, 0.040577354666311294, 0.0559658127167495, 0.03560319892130792, 0.00978024287178414, 0.056210016409750096, 0.05194671197386924, 0.02574848709627986, 0.05965890653897077, 0.02299651074281428, 0.0635608666925691, 0.05385123360611033, 0.0290863927511964, 0.02830140645528445, 0.015074423827172723, 0.0468394038034603, 0.023750005857436918, 0.010261837342113722, 0.030828935086901765, 0.010778371197375236, 0.026220223990094382, 0.025334094098070636, 0.008120958373183385, 0.030433804531639908, 0.04973849980160594, 0.08965931352577172, 0.07158927182899788, 0.03702641181007493, 0.013974143512314186, 0.03794476760958787, 0.0029887126493122196, 0.0152762499601522, 0.0158450180242653, 0.0074792153918679105, 0.04930980190692935, 0.037409003780339845, 0.05532463052077219, 0.06567566844751127, 0.03504668093228247, 0.0470216381654609, 0.032257515558740124, 0.07304874976398423, 0.07540073449490592, 0.06013060447003227, 0.03569122876797337, 0.10918326704995707, 0.010059141968667973, 0.04656292039726395, 0.030683240365760867, 0.07827795197954401, 0.025272275051975157, 0.049356019153492525, 0.05133752747497056, 0.02849194916052511, 0.044234298475203104, 0.040426631894661114, 0.06654765486018732, 0.09830436174524948, 0.02519445159123279, 0.03291889530373737, 0.07203280154499225, 0.008900794164219406, 0.028168315257062204, 0.021855790801055264, 0.013928399384894874, 0.031427464200532995, 0.03290780761744827, 0.0604354638926452, 0.009543709275021683, 0.022702785390720237, 0.049273095282842405, 0.08403225336223841, 0.019158839131705463, 0.05754572637670208, 0.05376037988753524, 0.0290110332207405, 0.020125640476180706, 0.07057008784613572, 0.022812051793152932, 0.04586950955854263, 0.09689400656498037, 0.02470494026056258, 0.05368744532461278, 0.011630905919446377, 0.08156827854691073, 0.0054181108043849235, 0.02080496535199927, 0.04885253503744025, 0.05315415284712799, 0.10772275010822341, 0.02967598269606242, 0.04114491581276525, 0.004938390720781172, 0.07822213505278341, 0.05118891240272205, 0.030897826800355688, 0.0854826251452323, 0.028770399258064572, 0.009645160862419289, 0.031092145181901287, 0.043087940066470765, 0.03548609543940984, 0.006802508441978716, 0.034912292830995284, 0.038222657385631464, 0.08265961412689649, 0.044540987291838974, 0.04226448269037064, 0.05502395681105554, 0.008178769821824972, 0.006650997602264397, 0.015127081060199998, 0.04601449181791395, 0.012106913873140002, 0.033095819599111564, 0.004386430446174927, 0.052127321032457985, 0.012291824605199508, 0.008321775185322622, 0.04378614517918322, 0.09003135957755148, 0.06693112256471068, 0.015731105777376797, 0.025715008814586326, 0.031060318178788293, 0.026077512702613603, 0.022908564387762453, 0.04917673853924498, 0.03914844579412602, 0.06276588552282192, 0.036329160357126966, 0.025769050153030548, 0.04635561257600784, 0.02271591583848931, 0.05900551601371262, 0.03219565754989162, 0.07516305427998304, 0.03889988198352512, 0.062087228579912335, 0.022189601404534187, 0.018408581636322197, 0.0603210210101679, 0.05374168147682212, 0.032745659482316114, 0.025135064934147522, 0.05748380899603944, 0.03744791087228805, 0.035080437519354746, 0.04036558653751854, 0.02904742072132649, 0.022608695908274967, 0.048652670957380906, 0.02429518754070159, 0.027263984193268698, 0.0593856366322143, 0.16983396490104496, 0.12917782383738086, 0.19488187943352386, 0.20250683824997395, 0.1674660388380289, 0.1425613884930499, 0.07877751384512521, 0.1512775567243807, 0.11120449140435085, 0.2631902351276949, 0.11176729909493588, 0.13083670201012865, 0.08042753819609061, 0.11878916644491255, 0.10834769782377407, 0.16866626974660903, 0.16728624614188448, 0.14055610547075048, 0.1380576059455052, 0.21898131439229473, 0.09899343844153918, 0.18145979731343687, 0.18763200205285102, 0.20182909414870664, 0.21784956887131557, 0.17213140177773312, 0.21043126849690452, 0.1220662976265885, 0.10144484127522446, 0.14875225082505494, 0.12186890860903077, 0.1610882591921836, 0.14619267254602164, 0.1359590794891119, 0.14187856810167432, 0.07318241798202507, 0.11863059917232022, 0.15438437985721976, 0.14258476614486426, 0.11743646129616536, 0.04397370445076376, 0.08775080656050704, 0.10528552971663885, 0.1522578892763704, 0.15590925584547222, 0.25104389002081007, 0.1300949847791344, 0.10141048725927249, 0.13516223552869633, 0.13325556908966973, 0.1619132305495441, 0.11035654315492138, 0.09042049729032442, 0.12173040900961496, 0.2671348094008863, 0.14919874171027914, 0.07128634941182099, 0.10186540894210339, 0.11281769038760103, 0.11630236316705123, 0.1656772699789144, 0.1608424005098641, 0.15085960883880034, 0.1110017737664748, 0.19604865432484075, 0.08489410945912823, 0.13447439821902663, 0.15233483514748514, 0.17523663671454415, 0.17483608477050439, 0.18233520502690226, 0.14177627046592534, 0.1317772109177895, 0.15280338266165927, 0.10933317345916294, 0.1809717164724134, 0.07717848246102221, 0.10425151762319729, 0.1967798627447337, 0.14230077591491863, 0.08447556785540655, 0.14197175216395408, 0.08068694107350893, 0.1258453878108412, 0.1296283074771054, 0.13005904998863116, 0.23346624104306102, 0.12834874098189175, 0.17720775125781074, 0.08755814502364956, 0.13541247288230807, 0.12660720240091905, 0.15216063824482262, 0.09441548565519042, 0.1417446104460396, 0.11182657442986965, 0.1402923313435167, 0.11311060123261996, 0.24612089793663472, 0.11362890974851325, 0.17032544477842748, 0.17061234422726557, 0.1167893382080365, 0.14541387761710212, 0.11159779998706654, 0.176518993685022, 0.10609979188302532, 0.10717219527577981, 0.16157108562765643, 0.21699881530366838, 0.15976962604327127, 0.14540633739670739, 0.163342755404301, 0.1023408213222865, 0.19738303584745154, 0.10074973833980039, 0.11528769886353984, 0.17131909145973623, 0.13044564955634996, 0.11038656302844174, 0.15186979057034478, 0.14739707432454452, 0.11945401201955974, 0.08515895227901638, 0.1490920505602844, 0.09659020841354504, 0.09561130820657127, 0.15351796697359532, 0.17681560042547062, 0.09796060636290349, 0.12919481901917607, 0.09574821960995905, 0.17590342671610415, 0.072334647848038, 0.1373247944866307, 0.19264764385297894, 0.06628056333283894, 0.1772412221180275, 0.056014939182205126, 0.11760440189391375, 0.1668606689781882, 0.1295602525351569, 0.15436432702699676, 0.07369458151515573, 0.12186339445179328, 0.13187694072257727, 0.08627714618341997, 0.13563486485509202, 0.13054876355454326, 0.08721211124793626, 0.09388093152665533, 0.22999929817160591, 0.27434931602329016, 0.16870594496140257, 0.09507822353043593, 0.15388467698358, 0.07184924616012722, 0.1613995456136763, 0.11779287771787494, 0.19535593368345872, 0.10693493808503263, 0.10646445356542245, 0.13863879663404077, 0.14607649674871936, 0.22469721705419943, 0.08863995142746717, 0.15912645118078217, 0.1572124523227103, 0.13664540281752124, 0.10847962941625156, 0.07906527418526821, 0.22635673347394913, 0.17064361833035946, 0.11178696600836702, 0.09013022849103436, 0.170053685142193], [0.03451380776823498, 0.02262835540022934, 0.02510274625819875, 0.026984708456438966, 0.04702879617980216, 0.012782629128196277, 0.03988400691014249, 0.05667670484399423, 0.035235739342169836, 0.07935019952128641, 0.03591605127439834, 0.06456007205997594, 0.05849982400832232, 0.016140359402925242, 0.050521083394414745, 0.022245394211495295, 0.01093474356821389, 0.09171011988655664, 0.01067262164724525, 0.04081262290128507, 0.006390864173226873, 0.022870249158586375, 0.04418452634126879, 0.053497284825425595, 0.015672116169298533, 0.04205114491924178, 0.03804475716606248, 0.06096520519349724, 0.02486631285137264, 0.03965709525800776, 0.06406678876373917, 0.057235612548538484, 0.07095035689417273, 0.07136535103200004, 0.03289039683295414, 0.057931298069888726, 0.037059285241412, 0.07560529265902005, 0.03807328532275278, 0.06181789947731886, 0.077548175904667, 0.008826185130601516, 0.01880299601907609, 0.04709342982096132, 0.09479305328568444, 0.024144036178768147, 0.011147697277920088, 0.043646821795846336, 0.03866207189275883, 0.07385323784546927, 0.028959795345144812, 0.09408242462086491, 0.05385008698794991, 0.02235488882433856, 0.03078270299738506, 0.0208013956216746, 0.02346912708162563, 0.0066656981562118744, 0.027583261689869687, 0.03720384818734601, 0.005795741053589154, 0.026374162116553634, 0.050426500383764505, 0.031601713053532876, 0.0181361151044257, 0.04722671954368707, 0.03552087990101427, 0.0751376579864882, 0.08784877005382441, 0.05146461284311954, 0.022517354227602482, 0.05319724565197248, 0.04704388775280677, 0.021759667833975982, 0.10181740683037788, 0.05436849198304117, 0.04306675917177927, 0.06295060607953928, 0.03211062226910144, 0.058681642767624, 0.012938406853209017, 0.03611072403145954, 0.009066132606676547, 0.021915405668551102, 0.026139858673559502, 0.04676888864196371, 0.07283830636879429, 0.003896775788234663, 0.02374492585659027, 0.006327500996121671, 0.029358779502217658, 0.08137588418321684, 0.02054594468063442, 0.06189266343426425, 0.014481318885373184, 0.02412286827166099, 0.052100971079198644, 0.02427656148938695, 0.05482233013026416, 0.052513720220304094, 0.028390453044266906, 0.026900862467300612, 0.07454769511241466, 0.054951423007878475, 0.026485235648578964, 0.0160089936980512, 0.02196873268985655, 0.002854859590115666, 0.06265519419685006, 0.031953223879099824, 0.03197266814822797, 0.07947472447995096, 0.019448592138360254, 0.06133964467153419, 0.027174542410648428, 0.05287788466375787, 0.00707588781551749, 0.07798155304044485, 0.05489479714015033, 0.04031461583508644, 0.05272539558063727, 0.0017980482562052202, 0.02639837097376585, 0.08931376214604825, 0.07496467078453861, 0.03184586108545773, 0.03717615865753032, 0.01945636799064232, 0.05903359146032017, 0.037246506835799664, 0.017688386687950697, 0.03171598153130617, 0.019034674114664085, 0.019042843305214774, 0.03456486010691151, 0.08011810714378953, 0.02556984287366504, 0.1251922087976709, 0.07785292400512844, 0.03947085700929165, 0.10207630504737608, 0.027994446754746605, 0.04256997664924711, 0.09828628302784637, 0.04861554130911827, 0.02069650603516493, 0.05093640407721978, 0.0033691973840177525, 0.01788259560271399, 0.03890400461386889, 0.01651496215345105, 0.03982240494224243, 0.024799725506454706, 0.008993987503345124, 0.028446190190152265, 0.08382120140595362, 0.02139561842341209, 0.02215837739640847, 0.03925027216610033, 0.05450376324006356, 0.05683300485543441, 0.08244961602031253, 0.0520630028040614, 0.05329216262907721, 0.0349873165396275, 0.015856636346143205, 0.04504752163484227, 0.0271346445515519, 0.005322106580933905, 0.08697567784111015, 0.02302743603650015, 0.07180850225267932, 0.06303754125838168, 0.016625933640170842, 0.05978681940177921, 0.05909857391088735, 0.022291815548669547, 0.04775024535774719, 0.06774516208679415, 0.016784942490630783, 0.14011139573995024, 0.019368570065125823, 0.07886809296905994, 0.04718967524240725, 0.06007081705320161, 0.0596578601107467, 0.049766196752898395, 0.01040403747538221, 0.014553801665897481, 0.004796156727024936, 0.05091536419058684, 0.04293468657124322, 0.03662973758764565, 0.041246519540436566, 0.021455383575812448, 0.037406398841994815, 0.04087700792297255, 0.031492346461163834, 0.02194107284594793, 0.09357625764096156, 0.0403074763744371, 0.017695579954306595, 0.044359877283568494, 0.042233650165144354, 0.038086543790996075, 0.056171962787630036, 0.024856254894984886, 0.004436579220055137, 0.06086271831009071, 0.0520159283769317, 0.05489632225362584, 0.055243205788428895, 0.04531122154730838, 0.053282815279089846, 0.029704588778258767, 0.02569992280768929, 0.08130912799970247, 0.027906465147680137, 0.026055546986754052, 0.04883725421677809, 0.028209925621922594, 0.051157586349290796, 0.015218108255794505, 0.03689169345307164, 0.05955881308182143, 0.042559746143524535, 0.05005217593861744, 0.04270510689821094, 0.048278869726345874, 0.06452651956351474, 0.04319077204854693, 0.03759648883715272, 0.09044248712598346, 0.024994696977955755, 0.011704903608915629, 0.006704266643282608, 0.050972012322745286, 0.0495868159487145, 0.062429551617242396, 0.04866144685365725, 0.04122905680560507, 0.08263895273557864, 0.04148179890762549, 0.02957506359962281, 0.042095506796613336, 0.037461644315044396, 0.039121227528085, 0.02653556439327076, 0.07780581989209168, 0.06000428351399023, 0.12276437657419592, 0.00471209876195644, 0.048431199247715995, 0.008677672103658551, 0.019341900988365524, 0.01852045112173073, 0.03073669911827892, 0.04395161442516837, 0.004523588613665197, 0.03517859397106804, 0.023147548927227035, 0.02337535857805051, 0.023751312037347816, 0.03796218581555877, 0.03875265101669356, 0.04620416249963455, 0.04844850242079701, 0.07409324098262005, 0.013380036671151174, 0.08081018953816965, 0.020123286012676544, 0.055084037376218475, 0.017294545614277013, 0.008119881331367651, 0.06368559203110635, 0.04583309237204958, 0.01751869647705462, 0.051451985200401396, 0.04244048672262579, 0.027774453774327412, 0.03697834661579691, 0.02845487146259984, 0.029943285735498648, 0.05532450435566716, 0.041955697306548245, 0.036026174857397564, 0.009332077515864512, 0.08428974149865098, 0.036909096816089004, 0.056554885013611056, 0.029217290903034154, 0.06505454279249534, 0.024011898640310392, 0.07978031120728701, 0.06519745074911043, 0.06725159677444026, 0.004942182167724241, 0.03700966153701302, 0.03728851239429787, 0.05720038650906645, 0.04133745860599447, 0.04600924483384006, 0.0971372083586175, 0.022974814055487514, 0.06336941485642456, 0.006982486211200012, 0.012352049889159389, 0.043063590201199986, 0.05187378483242355, 0.02305034242453985, 0.01197848707306548, 0.03480080369627103, 0.05152798112249002, 0.026212848897557706, 0.06511740270070732, 0.060114674270153046, 0.04794268425030168, 0.03153898302116431, 0.06159929616842419, 0.04088980997039471, 0.07482625282136723, 0.01671424735832261, 0.06247632176382467, 0.014452261020778678, 0.065680952538969, 0.05657409921695944, 0.022360774055414367, 0.07650917657883838, 0.05674025866028387, 0.018097836982633453, 0.04086595734406728, 0.018212778959423304, 0.026694844127632678, 0.023809253361832816, 0.042462936689844355, 0.03290522494353354, 0.04095342315849848, 0.07882541205617599, 0.03717748339113314, 0.018518872202548664, 0.05396396583819296, 0.03583894584153313, 0.026689617552619893, 0.06869789416668937, 0.07334982423344627, 0.03663252806290984, 0.003995680881416774, 0.055230444559128955, 0.02461226085870294, 0.006353946964736679, 0.11495051148813218, 0.08406471490161493, 0.14072446909267455, 0.17366303130984306, 0.13830509735271335, 0.15560466359602287, 0.21851861500181258, 0.121244472975377, 0.23872098798165098, 0.143477228411939, 0.13295928889419883, 0.1459682174026966, 0.13287867681356147, 0.12222215606016107, 0.12076577288098633, 0.08687651949003339, 0.18114448845153674, 0.176357428135816, 0.1855492388131097, 0.11328096865327097, 0.08173555121175013, 0.15811442892299965, 0.18825990351615474, 0.1349256982211955, 0.12260334537131712, 0.163461068586912, 0.17635637428611517, 0.10552287596510723, 0.14678343693958595, 0.22281407669652253, 0.15225542534608394, 0.14067196956602857, 0.20737905259011313, 0.07717463813605718, 0.1934380311286077, 0.1421958362334408, 0.1089402285288088, 0.13565727771492675, 0.1881904384936206, 0.13745746080530807, 0.12575153581565246, 0.18797520082443953, 0.15406194637762383, 0.13779914559563622, 0.11807459697593004, 0.19831281329970807, 0.12342652073130012, 0.07541958504589275, 0.31294621992856264, 0.11576713368413039, 0.2140029877773486, 0.15826459508389235, 0.08512404165230691, 0.1808061878546141, 0.15368643449619412, 0.179112235782668, 0.14385164191480726, 0.09697821064037271, 0.1333718339446932, 0.06099932172219269, 0.10687599671655335, 0.10383664222899824, 0.09609907734557055, 0.15187826589681208, 0.23108869674615562, 0.0932919408660382, 0.12948461284395307, 0.1170964834454935, 0.12437684083124623, 0.1585403474746272, 0.16266616905340925, 0.20017588598420843, 0.18797160882968456, 0.09997933710110374, 0.1852667031926103, 0.16381416760850698, 0.23368146386928856, 0.2494882297469303, 0.14039226894965395, 0.12514261848991737, 0.1952315794187598, 0.2371423359727487, 0.10014747807872482, 0.10518883529584855, 0.09345028549432755, 0.11006164335412905, 0.16514832648681477, 0.12682079250225797, 0.1867634814698249, 0.08552307961508632, 0.14071504381718114, 0.1676346844760701, 0.09449249831959605, 0.16109309799503535, 0.15170209488132969, 0.17685923870885745, 0.1853035730891861, 0.1274806953733787, 0.1723488955758512, 0.13364055077545345, 0.15805710543645546, 0.14383224217453972, 0.1546327766845934, 0.14872885833028704, 0.12147478366387077, 0.11025143277947791, 0.08757514020544477, 0.13696617388632149, 0.11727930410415865, 0.12894982122816145, 0.19603084278060123, 0.10495563765289262, 0.12619070912478492, 0.23152130946982652, 0.12194867464131676, 0.21823555987793952, 0.1297887894907035, 0.10639085478032939, 0.2667108946479857, 0.25139694451354444, 0.20877424569334835, 0.0862092619354371, 0.21525245276279747, 0.13407579070189968, 0.18273963098181412, 0.15658872172934934, 0.14345281175337732, 0.18568690720712766, 0.23739794647553936, 0.08330365730216727, 0.15456037275725976, 0.10643346889992245, 0.09948114820872433, 0.10727643733844161, 0.09876344687654637, 0.06682256862404756, 0.0771948839246761, 0.12934014637721702, 0.1343784385244362, 0.30248591559939086, 0.13782057882053778, 0.11221157838008367, 0.16443538974272087, 0.2051105149439536, 0.0938513272558339, 0.15038815210573375, 0.1100561663042754, 0.0928282098902855, 0.15373762784292921, 0.08174215632607229, 0.09803243141504936, 0.16339621972292662, 0.10555689601460472, 0.10828142403624952, 0.14147060952382162, 0.11017573371645994, 0.1381452239002101, 0.1672931035864167, 0.0892336324614007, 0.11399045441066846, 0.1455424472806044, 0.16002087271772325, 0.1882516805198975, 0.2085952990455553, 0.12848262442275882, 0.14658500149380416, 0.1579323800979182, 0.12096475009457208, 0.07374986409558915, 0.22086490003857762, 0.19608163536759093, 0.1640058495104313, 0.06841437891125679, 0.15760384616442025, 0.12479272554628551, 0.049685087433317676, 0.1944924597046338, 0.13085779384709895], [0.04389115536469035, 0.06596624894882552, 0.025117819277511444, 0.05918095230299514, 0.025064239925995935, 0.10685989211197011, 0.03271221088652965, 0.018509534129407257, 0.0854494956729468, 0.06334979247185402, 0.028501584092737176, 0.02695831768505741, 0.08123179621179588, 0.06261999413254671, 0.048600546215311624, 0.04176050133537501, 0.05448001451441087, 0.023691927235631738, 0.15795685612829402, 0.1142467328463681, 0.024236630233644973, 0.09029577937326394, 0.05529120418941602, 0.033311829101876356, 0.020281788347347174, 0.02304519191966392, 0.027376944635761902, 0.04803749732673168, 0.04042381544422824, 0.06061723812308628, 0.016529645545233507, 0.039458986357203685, 0.03517407058097888, 0.06114864554547239, 0.0472838129644515, 0.02831976718880469, 0.027831228071590886, 0.027788758670794778, 0.06283665672526695, 0.02706600887904642, 0.08677457066369243, 0.055940783786354586, 0.11908091953955591, 0.029841216310160235, 0.03524957297486253, 0.03584998157748487, 0.03352279200043995, 0.047730110891279764, 0.023797019057383295, 0.048771466535981745, 0.015219958058878547, 0.0192318219342269, 0.011848173362523085, 0.061128544475650415, 0.009650588744989363, 0.05329998857632745, 0.04888517098152079, 0.04922798012557905, 0.04295371523767244, 0.09870607886114158, 0.008622227178420871, 0.03148566713207401, 0.0517461391427787, 0.02568271982454462, 0.00607715603109682, 0.023403150153171737, 0.021524523908738047, 0.05791455150756519, 0.07786965943523683, 0.05761794847785495, 0.03717287465406116, 0.04863025067606941, 0.03692531645356212, 0.047282395462389104, 0.04385676424135454, 0.007892142184573459, 0.02269041935505811, 0.02977874788484769, 0.014581793620891403, 0.055505128257209435, 0.05515271201147698, 0.03639584974735044, 0.020525223917502444, 0.04314590922149364, 0.03395035811990965, 0.07418746405164711, 0.011370979827916017, 0.07726670155534521, 0.07670145962038077, 0.04681174395955168, 0.014276938836701447, 0.06714810428093188, 0.031805428880034015, 0.007073803772073006, 0.01063876208718284, 0.03290002619905863, 0.018948590550280642, 0.04083931795321405, 0.021333645381673705, 0.0503368007048266, 0.014559890059899772, 0.1316195639083162, 0.0085739291353093, 0.1120938292297069, 0.02457964903442189, 0.09593607202987187, 0.07246775203384459, 0.01892933181807166, 0.031289606558857486, 0.03748206821910571, 0.022488109898404218, 0.01792188861145405, 0.05698747176211327, 0.018321353309147526, 0.008640286414447473, 0.03667716453492176, 0.030524734320351854, 0.020637529414671008, 0.02607982820336474, 0.053516907209996134, 0.05913030443480238, 0.05096155175124295, 0.013948724954389036, 0.042159324075328186, 0.06015665756422095, 0.041037040937226266, 0.02568701314885402, 0.006504756474896567, 0.023347700589511078, 0.026543026688159443, 0.04986245330655947, 0.02938802383141592, 0.055355748772853985, 0.018398019019514322, 0.03772255004150793, 0.07218523125629872, 0.08528514706995338, 0.047837225065450184, 0.06644717548624612, 0.018734972618403845, 0.047891242284094915, 0.03796772223722655, 0.02222633956989739, 0.00987783807431697, 0.03948596342524979, 0.019146909107803367, 0.033430064358981326, 0.05113047198392451, 0.06789875696995296, 0.07664934601052664, 0.03064845033804886, 0.0371870088565629, 0.032068256768980063, 0.01981765846721828, 0.026679162547225133, 0.03823786028078757, 0.060347964681568556, 0.009455156214244198, 0.00966637608144083, 0.014362273759616073, 0.009263724787160754, 0.07379074901109561, 0.01212377639603801, 0.07685530683374964, 0.05423138019978069, 0.06670485658105463, 0.018602645832288545, 0.021786236720799934, 0.07636664711753838, 0.08659282611915842, 0.04318407787650358, 0.04579541724524461, 0.05238315789029002, 0.02068382644210942, 0.03517626362736337, 0.05749960560933687, 0.023845115792937577, 0.027450921916170046, 0.04523875824816059, 0.01416197830621968, 0.05287402178510092, 0.013895677166146925, 0.02774920591036789, 0.025208880797435995, 0.04174136134679429, 0.018596521258587018, 0.04700843906903174, 0.0349538085720269, 0.04221549352223519, 0.045287324392120354, 0.06124466461187694, 0.06902969354996458, 0.04439271731826011, 0.02324351604329422, 0.0658481584105175, 0.07440695422701538, 0.03273437141615432, 0.026878269636654295, 0.008123562383843819, 0.030492488003801554, 0.04423283273354173, 0.021659077137883287, 0.00633959197330114, 0.0990240000828635, 0.01694533730187686, 0.05388796991610434, 0.024210111441789195, 0.03393187864276115, 0.02680501595023088, 0.031232698675012216, 0.04544606235867832, 0.05806051711260807, 0.04142893943935633, 0.045798363571520895, 0.04543419541732874, 0.032363987775170244, 0.019950530731875915, 0.05991974918288179, 0.04863374248088803, 0.041328901643282734, 0.024969814621726982, 0.06434038150473498, 0.02991171848407248, 0.04526172771875281, 0.049526961738592945, 0.0626275640388485, 0.007872484547988279, 0.059751545122708194, 0.035599566108430736, 0.05024679674534127, 0.023166440296336077, 0.05784462635347154, 0.09549398950184695, 0.03395246581931133, 0.04502672665694263, 0.07243143874802627, 0.037373488303273916, 0.04727172708953731, 0.05626586302241776, 0.021219894551904872, 0.04962586404872127, 0.029912206446169876, 0.03956887616368476, 0.1132278679870069, 0.02699228763958672, 0.07109396246960387, 0.018088098149746656, 0.07990070982486941, 0.02463526001520222, 0.06911994612892158, 0.062306703912327066, 0.045427145014400594, 0.036622375482693315, 0.05598257412202656, 0.02597949354822049, 0.026569076071609743, 0.027510913423611782, 0.05058726070274133, 0.08135586103890091, 0.02338520687771961, 0.032406011887360364, 0.010561593571765115, 0.033985580448643304, 0.03794909433054272, 0.008234512533817906, 0.08017689266125672, 0.04637603648006916, 0.057284260328742675, 0.040938806560006924, 0.022844531886221375, 0.06498688861029223, 0.028034300084982533, 0.067143206106266, 0.023479561677959282, 0.04164259633398615, 0.01642581722990144, 0.012876727887487505, 0.037446827336680144, 0.07701633061515167, 0.06461653465521522, 0.024134096966008656, 0.032380641569034196, 0.05199236889893655, 0.028828414797317237, 0.03913031883712392, 0.0034487602533772588, 0.038035510006011464, 0.04182565076916944, 0.024711632577236742, 0.00690772271809692, 0.031578038542647846, 0.04471593005291652, 0.018864627672883216, 0.029059968583169393, 0.04135552990192082, 0.014087783019931521, 0.022812677052570507, 0.038587671588175, 0.030239898042054847, 0.029561690098489635, 0.06704587343847379, 0.006782428245060146, 0.041428100812481716, 0.039895788504509255, 0.06794762739446014, 0.0915479235118255, 0.06616073616896756, 0.021995899005560204, 0.04647162510082126, 0.019897177735401783, 0.05448070842248853, 0.05504959059180692, 0.08128301182296127, 0.0602992204221664, 0.05077908732346259, 0.04242143579176627, 0.0730092526646331, 0.0016008341071938048, 0.019836347601085436, 0.0279078010134981, 0.011155092779517872, 0.04484145320020616, 0.04572548838041257, 0.05135435196280014, 0.04514894353633281, 0.03638205693277996, 0.055450101717724465, 0.028823338507208973, 0.05026343569625169, 0.047639279437134974, 0.05197653517825529, 0.09823410262470134, 0.015299401256925194, 0.04992157650121953, 0.017313436983386055, 0.0737268797820434, 0.05652622327033896, 0.0286602422784199, 0.01929608635691693, 0.011835587465611752, 0.05619980816845782, 0.05913842724112328, 0.07965836892253719, 0.03279775082773995, 0.013092384870105889, 0.03415912426135037, 0.022847927211842034, 0.030927282641641796, 0.050405809306539595, 0.03105895077169407, 0.02786817403830355, 0.024908316554501653, 0.17953534901607782, 0.20949310477590188, 0.12852283398387954, 0.10917962310486473, 0.12507886800449342, 0.17064194107661024, 0.20653478539315984, 0.140943031583447, 0.14190746733220294, 0.10195520138950087, 0.09737768647028133, 0.07400344853522256, 0.2381292884820141, 0.20407998352311552, 0.09254647578927688, 0.11933472662349232, 0.17084681836422533, 0.054442543478216976, 0.2602255332749337, 0.19387935666600242, 0.0796853014617227, 0.19021255342522636, 0.12546024285256863, 0.1198276536888443, 0.10831473162397742, 0.09726184463943355, 0.1382458591251634, 0.2492685243487358, 0.11636301889666356, 0.16954449762124568, 0.16002606775145978, 0.1424098270945251, 0.1357773572090082, 0.15169063612120226, 0.1975328309345059, 0.0812309056345839, 0.08417257864493877, 0.14160045568132773, 0.1827288549975492, 0.12495908536948264, 0.14251210988732055, 0.19314029632369056, 0.21436652139527723, 0.08971929390099831, 0.10173140675760806, 0.21119122771779075, 0.14790028013521805, 0.11098123111878522, 0.12331944366451353, 0.1734262565150857, 0.11460329769761302, 0.14711501367855817, 0.10106832007295452, 0.1183572513400577, 0.09156913409242406, 0.14691365417093039, 0.18359246256295592, 0.11815570629551075, 0.178717442904599, 0.19996493792859837, 0.15230679680826142, 0.13783747010165825, 0.12172761853435077, 0.054089652257971466, 0.09155576059129089, 0.10907685791607946, 0.1361746882321313, 0.2560708421515301, 0.1735045382520184, 0.17555503291077912, 0.2078329204232432, 0.25060269806999713, 0.17236523766769096, 0.2059713171911426, 0.11626624283962883, 0.1221949934551958, 0.0913311644399073, 0.22599483258090913, 0.08002691945875995, 0.24971583159640431, 0.102713988017058, 0.0970379906357266, 0.1714566262671724, 0.12598709348822013, 0.12027884979033843, 0.18064757605316117, 0.11253985998337157, 0.18983929767273366, 0.15231801808113232, 0.1361075387103483, 0.13415389432338998, 0.13022161001572385, 0.18597065994981676, 0.1343848358374089, 0.08303266207803972, 0.13444287178572267, 0.0998529716162011, 0.07564630373963155, 0.12518637551693246, 0.1262079121079296, 0.10147324326680973, 0.16270510212052613, 0.13255342317279428, 0.2715843409532681, 0.1617601403268054, 0.1983583069522865, 0.12666514929151163, 0.08801527830655687, 0.18436125334119424, 0.11691138439346105, 0.10515480040339753, 0.14364320231834427, 0.20165327936410904, 0.09127594123128802, 0.14274615357862785, 0.15406595397507772, 0.11310981455608271, 0.07902113866293803, 0.12374064957839437, 0.10906377385254018, 0.09867148735793307, 0.16398545529227704, 0.08685997701832093, 0.11219538471777923, 0.2342716493876651, 0.2603276231093332, 0.1266591378953308, 0.17412386048818007, 0.3184666112065315, 0.13501442939741537, 0.16210492729442194, 0.08938906044932082, 0.10929857453447767, 0.10733822113252245, 0.13346040184842423, 0.2318693173583597, 0.12105796384275891, 0.13062150886980817, 0.19894320837920532, 0.18127555173123255, 0.20624378928914666, 0.09576643933542073, 0.11812487748102285, 0.15513047575950623, 0.1520252853515558, 0.15575116354739293, 0.13638462696690112, 0.17950061650481075, 0.1727939021657221, 0.22962961957091466, 0.20304701785789803, 0.1176333382318262, 0.1458177246968262, 0.08301078356453218, 0.0948586368758697, 0.11342044046614319, 0.1347495717345737, 0.132289188914001, 0.19324228225741535, 0.1072729640873149, 0.24973147606942803, 0.12723356019705534, 0.07702968927333131, 0.17322920146398246, 0.23340182262472808, 0.12183485145214945, 0.18247833562782034, 0.11420917275245301, 0.14947390038287267, 0.18328295729588717, 0.16671819146722555, 0.10755696916021407, 0.1946154038887471, 0.1078720553778112, 0.18667602678760886, 0.11468937940662727], [0.030507197370752692, 0.03325144054542761, 0.049278590886387974, 0.03392970043933019, 0.04916398844216019, 0.052080224340897985, 0.04591746714140754, 0.045842740291845985, 0.04328953706135508, 0.0762987406051252, 0.05843116050527897, 0.013003929216210963, 0.06331291515380144, 0.062328322674147785, 0.04107570683117956, 0.03410742625419516, 0.032267029891954735, 0.01649128393182764, 0.016349333345715422, 0.042052117132698186, 0.055092757611419074, 0.03676584005006589, 0.08878921216819435, 0.018542581965448335, 0.04349238828581292, 0.06776000504032709, 0.02717582818149822, 0.011560736784304027, 0.01341851610050071, 0.013264757944853045, 0.018133059311367106, 0.05252762435702607, 0.06103463681938592, 0.04693891838542186, 0.10554246124229394, 0.016369408440368716, 0.05944662632828113, 0.040727353843976744, 0.0387103040702641, 0.11238173057790846, 0.012487502044677967, 0.03472656666417606, 0.0077953958134457935, 0.03566430365026463, 0.002875116279028589, 0.04605270500178449, 0.017372777256241534, 0.056979222790687345, 0.05464034067699686, 0.0676329419366084, 0.04087948669621255, 0.05389107209339272, 0.033225198203581385, 0.054190558366826735, 0.04297521896660328, 0.01745015542837791, 0.019117241754429415, 0.06621974433073774, 0.009492428725934587, 0.07613410998601466, 0.021173961176828016, 0.048643327318131924, 0.08604510629083961, 0.011386294972908217, 0.03828687171335332, 0.04131811081606429, 0.04960761834809091, 0.02544219903938938, 0.09624680184060708, 0.04731935812742449, 0.04249743913533166, 0.05256834971078206, 0.04017974162707105, 0.02516058553737821, 0.015830447810003534, 0.008363612832908984, 0.009516268364677671, 0.017951257250388153, 0.07604796148370951, 0.03846576641080901, 0.02248522108857287, 0.03712943675054703, 0.03526866472384427, 0.033515719333081506, 0.060440688612288795, 0.034501083646318875, 0.062137620407156646, 0.03118878579698503, 0.054939396504778415, 0.019653066810860764, 0.03110491012193961, 0.04080649647221435, 0.050360868553980254, 0.06926870220922865, 0.08248761398135684, 0.029219161115179304, 0.020002857709187083, 0.06596482402528636, 0.02551797602791339, 0.02347079134779051, 0.06491360894870013, 0.007476557111658622, 0.009962791718862718, 0.02568323747254908, 0.040047932488960214, 0.03294133784947917, 0.03138980762741994, 0.016664059621689375, 0.08483880461426452, 0.030763652066525538, 0.018449410890752915, 0.0676031743932981, 0.04078213176399004, 0.06181346143421251, 0.03050919003726449, 0.06521537361550145, 0.033793638795032166, 0.030182472510205116, 0.045521557331085205, 0.031248628874891438, 0.0056463657438143855, 0.0817395217018202, 0.030022855098650325, 0.05381876464525703, 0.010776295966934413, 0.04754720859637018, 0.007349628522206331, 0.06573175996891223, 0.004360859747976065, 0.04702675898442976, 0.06841447539045475, 0.055559097236255184, 0.009732067283039214, 0.041021893703145906, 0.021775152745249216, 0.013717256515519693, 0.026317406372982077, 0.05092696024803445, 0.08472201283439063, 0.015943532562232576, 0.014105129794188542, 0.0730551544984337, 0.0516297926515108, 0.05065756806288846, 0.007222482854558621, 0.018496179181966, 0.06557941931532696, 0.04447409010026604, 0.023079345555743203, 0.022171843666001223, 0.013176228076190455, 0.03537125179718714, 0.039043862343532965, 0.029452202907123137, 0.03251956048188731, 0.04150881679379381, 0.07186463830294088, 0.050725051551125944, 0.05720102846680675, 0.057308999821543694, 0.058685242183855735, 0.06418859004043043, 0.05108647746965289, 0.024866383355401922, 0.027779324118455406, 0.03227100780350156, 0.05025253725762013, 0.054270302134682424, 0.03583107907616068, 0.03846690560749266, 0.020375042913656216, 0.0364690923015587, 0.048488622924196534, 0.05826172076922376, 0.016393663681810722, 0.05352489271899685, 0.025662767184257973, 0.03158377905492671, 0.011465965453680838, 0.033360911038471386, 0.06509970247861929, 0.02515368913009297, 0.03218441401259042, 0.046793780275038444, 0.060557016549864784, 0.05884335303562693, 0.008481689455948072, 0.036488477198872715, 0.04412918809975963, 0.009001966518553672, 0.043213600511080585, 0.02690628942218609, 0.024651114144944586, 0.05099140835227445, 0.038794356005382724, 0.03559830816811882, 0.023579451044497546, 0.09435470376047306, 0.010087078262586147, 0.024919381976360455, 0.057772426516748965, 0.003551644417711941, 0.0446025521523552, 0.041335926071042195, 0.008945751615101472, 0.03511267641442828, 0.01978729349502828, 0.023504097080149222, 0.01200384811454569, 0.06210814601217862, 0.002105103972098732, 0.04588590731145814, 0.013961626264062943, 0.015440771112480434, 0.018518785000196658, 0.08327023839228787, 0.02633456482726615, 0.01036224157360266, 0.05200484811211936, 0.0329221867286833, 0.09177263840683736, 0.04139474869589321, 0.011869263344124192, 0.07045624981401488, 0.0597018360713264, 0.06618559069465846, 0.009398680631420575, 0.022908030041435268, 0.022978571178100538, 0.009291178685089108, 0.08620243417681195, 0.007722072550677694, 0.017790298406907823, 0.022774617864342872, 0.04766447906149551, 0.06296423933235928, 0.045678970564040355, 0.06874551036162302, 0.024503979657310992, 0.026708508921728935, 0.02571797554992372, 0.06401361388270743, 0.14322636765427887, 0.02615966288431082, 0.060443727707024664, 0.009617494524718495, 0.05316983813827392, 0.06972582064918242, 0.09512983247986995, 0.07124843308702111, 0.05756982762250118, 0.026053094188682735, 0.06326693910523318, 0.04512417806836311, 0.1082797022536397, 0.033375724306097254, 0.0524349078477826, 0.02083951603708556, 0.017921411781571805, 0.0525855155865429, 0.03483092375972774, 0.04416706731717568, 0.040437029383610934, 0.0413970307999989, 0.0316659348027315, 0.04266412179276813, 0.018287450147909112, 0.04321918517234735, 0.009401303195772925, 0.09705690798000433, 0.06999792909482494, 0.05053024891822133, 0.017447897444071714, 0.040435801129206084, 0.047700848008389585, 0.017913123847392853, 0.03313752087706234, 0.0018594034600027953, 0.02066237651888514, 0.011341291137796361, 0.048444212807225995, 0.01291823064093478, 0.025068867216759827, 0.03222942155844066, 0.03552012662112247, 0.025726701351231895, 0.028228739065525588, 0.031928128155414015, 0.011807943392341258, 0.05317385686794296, 0.028343358208076097, 0.05644698045216501, 0.037342203067964874, 0.022240150938159786, 0.010778379546536598, 0.03789427559240721, 0.015629507615813054, 0.01835072380345082, 0.03312256660137791, 0.024367227815673687, 0.022945003838685807, 0.05406868287536781, 0.07418964596581645, 0.054955864761723205, 0.008227295147662517, 0.035704876863746904, 0.06914436278748326, 0.020613851193047594, 0.02082757117022993, 0.034328534311498515, 0.029967758055136073, 0.024456908940919675, 0.010804329667735146, 0.07268375411513261, 0.026980895672750194, 0.024078357964754105, 0.04139760225370992, 0.030367460240086075, 0.01868207418738166, 0.01156686877948232, 0.014545398698828649, 0.06430115157854743, 0.028570761533046607, 0.014994438861322124, 0.014706566271343036, 0.016810468659969047, 0.03695377781696152, 0.04331766816903837, 0.032631201756885275, 0.05963146933936514, 0.08258770743850619, 0.027622897941910196, 0.07526926303398795, 0.011544396547833458, 0.05069226346677169, 0.019027447451662738, 0.04467500431928784, 0.034967401006724685, 0.024884655031200964, 0.03434383368585259, 0.049212777230422944, 0.0270668326629675, 0.025160546574625187, 0.061167262319941074, 0.06649207542068325, 0.0369488462456502, 0.04015818594780285, 0.02312636061105877, 0.03565542385331355, 0.005634532662952552, 0.023866456249379553, 0.031281446645152755, 0.07724724244326353, 0.18061609414871782, 0.09355911402963102, 0.11904091035830788, 0.20052705542184412, 0.12058057734975591, 0.2074940557940863, 0.1576519521768205, 0.1560824879561551, 0.187183789385017, 0.10613351507345214, 0.21750438114395365, 0.1333111262647435, 0.22069812461268157, 0.09453568389290012, 0.10488273648661561, 0.23256632761331275, 0.17187893798109144, 0.1550198660697788, 0.1556136435829103, 0.18012436194112524, 0.31110973097383976, 0.13512600387912244, 0.07299556003999896, 0.09238498445483856, 0.1693484518909827, 0.12804033409338444, 0.13137170142726973, 0.09738283697515726, 0.07872315894928761, 0.0648872775491327, 0.1256336530786939, 0.13212616875534877, 0.12412283336743712, 0.19654034200357273, 0.15952626097714528, 0.1343952407478355, 0.14949316653655842, 0.11177695443620905, 0.23689116351306438, 0.14175749412970617, 0.09645547150284983, 0.15964243677444756, 0.14078440493904054, 0.1892774028237909, 0.12870072678197175, 0.08103451851638965, 0.16702808265108615, 0.1537854369962588, 0.11096983173047192, 0.1446732587646693, 0.1597362442407757, 0.09833714982960373, 0.13290398404933512, 0.1505366706987843, 0.09924515266902745, 0.09226117937942035, 0.11058530275477096, 0.1057697217038367, 0.13535688602132723, 0.09558922931319103, 0.17413404275430366, 0.15223243361106142, 0.11121920077130198, 0.12145960674388334, 0.11084368146839552, 0.2745569095714018, 0.17759601323632523, 0.24865160667104647, 0.07004174549365416, 0.0803483510389924, 0.2243589164572768, 0.206355037225876, 0.1218466144928243, 0.12296079337829724, 0.18165366112953052, 0.15206739481072873, 0.1098203043511603, 0.24581583071267232, 0.1837024191627279, 0.22472044627647847, 0.09200725355185568, 0.1413809580844827, 0.11918254924239591, 0.13011966861085966, 0.13636197661980987, 0.19882157037500292, 0.16166863351827487, 0.1177239247772377, 0.13392837048741058, 0.1224179939890746, 0.1784006497473456, 0.1292074949014932, 0.12525123922387138, 0.1949446354410611, 0.12333036807831377, 0.08075355624896474, 0.19371982460143045, 0.1629666201188229, 0.08281870090286247, 0.19294726371299475, 0.05226729750575032, 0.07543126645032316, 0.09292234390159138, 0.14163800835376605, 0.20604389923391864, 0.09514036355540156, 0.09133135739830323, 0.24285149993374944, 0.11840531282359734, 0.15379754884634167, 0.18039052578387782, 0.10569354766630568, 0.17431871878216043, 0.14424089837120846, 0.1477147580590099, 0.1474520080955699, 0.13242221146356314, 0.19227934564696625, 0.07645773090189323, 0.09468564967392012, 0.19248628610512242, 0.12141270301071927, 0.1770261922501959, 0.0704827370645944, 0.10867911871173419, 0.10370703355874866, 0.14741588034667075, 0.17134870315203443, 0.08742760866880417, 0.1773756102193147, 0.1447901618666947, 0.10883121445658617, 0.2312830206938088, 0.05789455804915633, 0.137713190051727, 0.12567663827212527, 0.22798996302299201, 0.169564698881004, 0.1191726786782965, 0.13464399380609393, 0.20623746619094163, 0.13580076454672962, 0.19108404259895906, 0.11006378816091456, 0.12633820355404168, 0.24256621836684644, 0.10214165857178159, 0.1303557606297545, 0.12481586571084335, 0.1213396163075231, 0.07705090727540664, 0.10998730242135935, 0.13003583560930565, 0.2531223191181198, 0.05485771944222506, 0.1078321278328076, 0.10595285406452604, 0.17619791091419756, 0.08870529010891914, 0.14673819561721757, 0.1596264509134926, 0.09608599328203127, 0.1082588107965421, 0.08184101039660163, 0.13745547184953466, 0.14533307257806882, 0.20416056591784582, 0.15515257691731676, 0.1734104784554802, 0.1469888782594353, 0.08822084579151124, 0.1626943558221683, 0.12361817294731736, 0.1125935692107305, 0.09933190973242745], [0.036936066462658346, 0.05162377012311481, 0.053256168466759846, 0.037118278560228646, 0.04433019879797939, 0.04555822684778832, 0.04753016517497599, 0.01429738593287766, 0.05557999982556794, 0.019502045324770734, 0.02128482134139631, 0.027430802292656153, 0.017313336793449707, 0.05883015393919777, 0.026405198732391, 0.04019644366053399, 0.021759300470876042, 0.04569105643895455, 0.07947295816848055, 0.04684572690166533, 0.03286208389909007, 0.04045463683723938, 0.01252526530151954, 0.005673565920005785, 0.035967166695627384, 0.015663921003579162, 0.042600404703989625, 0.004363021253084298, 0.04316533122619148, 0.026429107019794174, 0.010216532009508228, 0.04472763743251562, 0.03041363295778865, 0.04531390070042107, 0.09738168664625846, 0.022911377127456944, 0.12097968952730298, 0.007755452033961774, 0.07177471969043836, 0.026710943166108336, 0.03853731686831452, 0.021534268307732418, 0.08546183016733266, 0.05843321996508166, 0.04309979216486681, 0.03582819954317529, 0.06425192492315546, 0.08095333498204127, 0.03715663275215775, 0.05183470333577134, 0.017711758773657493, 0.047503099049208686, 0.0173362895657192, 0.07827292763977312, 0.053389191016322, 0.01609422564797569, 0.015112990458874265, 0.016977186569420155, 0.05807180888950825, 0.05389117599406745, 0.0646633048017975, 0.04403631202876568, 0.04391824375488795, 0.039989039360079914, 0.040445924023515545, 0.032524855705560185, 0.011007464763679309, 0.036721400247188285, 0.02949356650788104, 0.05434210863313638, 0.009433460454602027, 0.02685364703211235, 0.052462196617852896, 0.044776322320103645, 0.05959202419035137, 0.015349920176959131, 0.02354997293878114, 0.03356347282533534, 0.04118096563615836, 0.004001534107374027, 0.04907523871224839, 0.05285500054014847, 0.026193272897216957, 0.032711361127439886, 0.011257708611083217, 0.018153631644963752, 0.05631728272419423, 0.059036619422840886, 0.036494948726613075, 0.045994116153451614, 0.021782648436783347, 0.0765368141583167, 0.03209137837984599, 0.020373630977701396, 0.09721364214783534, 0.0045869415862398455, 0.047829295217525214, 0.022993161801423412, 0.0788736590766348, 0.027842130220960826, 0.020781834464287385, 0.07728825352387503, 0.006704345032630954, 0.03565852974134032, 0.03098712200880982, 0.03191163392330054, 0.042623849149094895, 0.06573850609129295, 0.010120884016942, 0.026395658424007706, 0.018917745037470013, 0.04647342109819874, 0.009196733899443643, 0.008147777734848205, 0.030100326039246283, 0.016536560506210662, 0.03969557561504189, 0.03570141474483535, 0.03173442019033246, 0.04678511199017521, 0.013226795235823374, 0.0320247372292215, 0.034912088740384206, 0.06645729095907882, 0.032316891083610244, 0.0463733053766191, 0.04009945238067303, 0.02279263164382428, 0.03176139354764018, 0.006374134309226065, 0.014915779556758935, 0.03885613979946356, 0.01807751141313929, 0.021249593446555082, 0.07832691888324916, 0.08015485087526031, 0.012886624426755589, 0.012684465255006216, 0.02350099490286084, 0.06434242241084576, 0.018240691133541986, 0.03677722088468727, 0.07704574192757718, 0.021344079978007358, 0.04120492216316052, 0.05918904171267059, 0.072515820938861, 0.05174426521989517, 0.05627562597510405, 0.035454179378575645, 0.05099042129586451, 0.0286357643926749, 0.015542343298875494, 0.08808599755866453, 0.06451335386373103, 0.09017863136250526, 0.0095014114958758, 0.03495814271445852, 0.026606788305798545, 0.021354540549509693, 0.028525672350951936, 0.06737206218531355, 0.019946742067986634, 0.04949804024363402, 0.07574145449325442, 0.05864415317773819, 0.001318654485658044, 0.06929951618076302, 0.025190015403495636, 0.08672098760143854, 0.061374733413686045, 0.028343209778540768, 0.02286562928929925, 0.015715303597971797, 0.01724644702335354, 0.08679713195306249, 0.04246317417710088, 0.007601406759931706, 0.047217913961503655, 0.08399378042668104, 0.014391278746188618, 0.053232939244480804, 0.05706256226403639, 0.016639756140648387, 0.029242251184768975, 0.041566567015252076, 0.05103856812638696, 0.03226244341931306, 0.00879873401572695, 0.0239536456138012, 0.04830741272598971, 0.061752390101901256, 0.02742988202953711, 0.008830477527226321, 0.08616959414212033, 0.012059267064614687, 0.04309192911023274, 0.012564150129037444, 0.09082360964384861, 0.013380460623011459, 0.0119644066762703, 0.0457542762887897, 0.039617972943233326, 0.018043914387817495, 0.028954598456039093, 0.025956269892049022, 0.02514765175874345, 0.03935461812943686, 0.0142850718475529, 0.0037672740336347488, 0.008971958704933058, 0.04686936801590491, 0.06237599824089557, 0.0529125578032108, 0.022151007869979367, 0.012451151651475811, 0.015817404564586468, 0.0648713436385151, 0.011617939671850763, 0.12103071218007244, 0.02524215498851845, 0.12864577816799283, 0.028897011507069692, 0.04818089881155174, 0.03104031358816428, 0.03945582851883955, 0.06684507054160349, 0.03350057580973953, 0.05881089891772717, 0.021991490648360923, 0.01253165240996168, 0.0444383779540658, 0.01384135102853179, 0.03645186705398373, 0.03477822014247067, 0.0071129747902887175, 0.011515745009091916, 0.02447043272695737, 0.1224687197827734, 0.05351619474822655, 0.059201565454714, 0.019866345210175496, 0.0061023278249194846, 0.04087570916453842, 0.02443644236336695, 0.0414783887390513, 0.05310059947078116, 0.03872947745549027, 0.03888300925609656, 0.0717287436418701, 0.07297705829842016, 0.03357196299475618, 0.025075810008274857, 0.037431130913319066, 0.07102993738953955, 0.018604645920277108, 0.05937881629506592, 0.08528323232894763, 0.02637105808389606, 0.022610825872106943, 0.028078196264686994, 0.03046623638510937, 0.06991837828536518, 0.034218184373457916, 0.0034073725328198634, 0.048875070351641625, 0.013535851503547747, 0.04481099545955658, 0.03651380669907667, 0.02838366610376397, 0.03248700246331282, 0.05287792919261847, 0.030173533341439907, 0.010902956455538515, 0.010950022533506854, 0.09116084154811688, 0.05812919916934334, 0.02901455471146619, 0.0471264108637115, 0.030426845041802153, 0.07258205019752495, 0.06322316723526455, 0.05459583779156674, 0.04714806673291605, 0.060828223286080174, 0.025089727132581174, 0.03244210623961408, 0.0052076391148148105, 0.05735370308684651, 0.0491002676426433, 0.02242295118776383, 0.020250675661372952, 0.014865281045786105, 0.052248458086978644, 0.03866010520141572, 0.022437094667111523, 0.027588974371610675, 0.017320773113169707, 0.04590000069583766, 0.04971955277142115, 0.015215608145808801, 0.045228408998809755, 0.013120667190378299, 0.015942013014864642, 0.012530750700534554, 0.014544967325491598, 0.0005494632955560519, 0.039594298432348296, 0.027242315336479805, 0.009878918826871086, 0.0759020255645737, 0.05134481907589361, 0.015772838596603833, 0.07589073007693514, 0.03236716045648791, 0.03916878435120452, 0.038762016920372844, 0.04717740754131228, 0.03803873092692811, 0.029862044684705324, 0.09228646435076371, 0.01694688467978267, 0.02121826182701625, 0.04231829210766591, 0.06992697977693751, 0.040629408904351294, 0.034037645818898454, 0.053643599239876494, 0.05496337900694925, 0.05069706887297798, 0.08932727665523998, 0.03029748870176263, 0.01657494438404683, 0.0446900847600773, 0.07002337733865716, 0.01752706233673962, 0.08070613301242702, 0.07290158930118196, 0.03361309652973432, 0.008999591645988403, 0.05128618569870014, 0.06596882420126349, 0.021608894967357628, 0.06368427100824192, 0.02439242187392665, 0.06597766318009235, 0.055415157694369555, 0.08165854596882127, 0.031391176889883354, 0.03332105028675869, 0.04697633376054, 0.052401982466108166, 0.11892652313690633, 0.1044208237726707, 0.14838475413853303, 0.1348307923763059, 0.12628850934561342, 0.14323432347737253, 0.1200172130484134, 0.14738199388375506, 0.18731316056801006, 0.0934261285874527, 0.15752520819660276, 0.13995446119224653, 0.09218808525474742, 0.20858939155004919, 0.14021443552337587, 0.1347694019204937, 0.03472492280707229, 0.07889874366810545, 0.17516254069050774, 0.1128934785083402, 0.10128093796083704, 0.11909815220860764, 0.20548430504277349, 0.15644824801711366, 0.10435639051138423, 0.1550770114408806, 0.18339772301260382, 0.1163704032660462, 0.19486926292302087, 0.15850882104132324, 0.07913713634479791, 0.19791724858805537, 0.12844165787100792, 0.1155110853142105, 0.1544186522369273, 0.11266244051512331, 0.23193373577669263, 0.16492590482812375, 0.14673215453512967, 0.1721625422942452, 0.1043413917068392, 0.24885146704036742, 0.15598936326568946, 0.17526323528727517, 0.19783558265771717, 0.22759184532333165, 0.1815911426092498, 0.13220510358223692, 0.12328617318416946, 0.21070679824333638, 0.1484801052720286, 0.1490715375985019, 0.12639739725273103, 0.11414602340664715, 0.1726226441678591, 0.18098320491844788, 0.09076291680685245, 0.09533306962111965, 0.12243903387570754, 0.1546419644728303, 0.22449312644312158, 0.17410419357474893, 0.16439400758827105, 0.08389936439925805, 0.13557074329582974, 0.07220450483146124, 0.15424697863636538, 0.14918612519977614, 0.11493169804452918, 0.2137159844278358, 0.09190556447720155, 0.08978733399999328, 0.16153679840499535, 0.20770239148987457, 0.160461530322209, 0.11184418559423648, 0.10683288535801694, 0.14675680868094787, 0.12791307060979307, 0.13976757356431335, 0.15241385903209448, 0.18269361782586202, 0.059400286627351306, 0.14270377694629133, 0.07789035051246174, 0.10929696407401934, 0.17003666027449071, 0.1772927271667868, 0.11885028230608441, 0.1788940146798268, 0.19774201267864555, 0.20530473499093205, 0.13753869628999382, 0.1581548314425163, 0.11279619036940858, 0.09810889489017427, 0.15120712690986693, 0.09217491213348694, 0.1262940457672812, 0.1877876155776903, 0.12186820356873795, 0.1883296060259454, 0.11960330986767076, 0.09408079189597629, 0.13652143446961418, 0.16155321471160278, 0.1762525032972917, 0.13320661702891812, 0.22958900925004855, 0.1256199085037224, 0.09441924834391102, 0.2524987666402012, 0.16899581300094724, 0.10238382135867141, 0.18026918463874608, 0.1009763457113877, 0.146353273303248, 0.0933765531226527, 0.1652669216855429, 0.12807162303943187, 0.16900568356504664, 0.12934557889821008, 0.07980477239470929, 0.1481502503156662, 0.08167384163243696, 0.14156634657410905, 0.07884288963396102, 0.11909066393855028, 0.15680180717026815, 0.08328797572175972, 0.07783585460856557, 0.12577175191836432, 0.10089651288581081, 0.12743339088046923, 0.19809537887340412, 0.12267188270925544, 0.12211999943247065, 0.10411181574454531, 0.10998034849762917, 0.17846558766905218, 0.12094209232600406, 0.13622433791169897, 0.1276579944533296, 0.09701499890070409, 0.14614020270528272, 0.11229929281398654, 0.17192725179484114, 0.06526182463858277, 0.22229645837796852, 0.11183821872691624, 0.15569798124488443, 0.15833466866752133, 0.10979877464706078, 0.25616461993195117, 0.21398407785454765, 0.15340581361670047, 0.049572785646887496, 0.16856520407600328, 0.22989682242041454, 0.10827997684828006, 0.12342783433268778, 0.16275546426186338, 0.13116042682668194, 0.11136963410535827, 0.1145008071034681, 0.09895518072880805, 0.07958549002069049, 0.147951859398745, 0.14169748406857252, 0.15464073250768706, 0.1351000732393004, 0.20249539433280006, 0.13496439380105585, 0.11683981167152524, 0.13039788493188098, 0.1806954000494443], [0.029377450082392897, 0.03828595516097266, 0.005862404932486243, 0.030898750774213113, 0.07063599798129871, 0.011169477456860477, 0.032706492638681084, 0.04044187560793944, 0.0036139569920123904, 0.07079975286615081, 0.05464859706989955, 0.0430332215182716, 0.026825009408639744, 0.04674308787798509, 0.0438508864317555, 0.07979544359841384, 0.0032665887420080253, 0.046513177949236706, 0.07044321770081297, 0.006008885402479791, 0.0433704014722025, 0.04215969514916651, 0.07968062593135983, 0.04263007576810196, 0.04368162481114268, 0.1019219754380174, 0.042241628252668306, 0.024037198454607278, 0.008751069581194315, 0.035381066700210795, 0.064182088826783, 0.026603138794598635, 0.018201795173808932, 0.02314046141691506, 0.03519046833389439, 0.0369899241195526, 0.01779036520019872, 0.06079280428821221, 0.00930594000237761, 0.019921000675822143, 0.0914772116811946, 0.011981257139268564, 0.06812913445173763, 0.04150516171648633, 0.040864306065486744, 0.048011934050009586, 0.006131698783065076, 0.029036195737717208, 0.01221658474605647, 0.08125328880851157, 0.030469410921796225, 0.050566617865115404, 0.030083523815847002, 0.031094698169908952, 0.015959572228894103, 0.06159967837447766, 0.09063405028427951, 0.057473656415822916, 0.04004325695859734, 0.01294200255870237, 0.05377032095566392, 0.02517798147891881, 0.026450742479937617, 0.01170133109553717, 0.013988088467158377, 0.006846073902124772, 0.04629872324585449, 0.024610542786831502, 0.012642769543163013, 0.06019293003191706, 0.03396647014596965, 0.027857680070155766, 0.03216372293536551, 0.01751860741933342, 0.02638717196532525, 0.031181664890027605, 0.022276885392784607, 0.038399154946091585, 0.02277458075695904, 0.08562338087358512, 0.011889384823007276, 0.07575018214993179, 0.04560298577416688, 0.02806670596328331, 0.07908131941803731, 0.06570295721758157, 0.07295466770301573, 0.06349339062580839, 0.02151509306713706, 0.03203645574103575, 0.063665487250546, 0.027589109813561663, 0.039804623083909974, 0.022703091526636854, 0.0031517158777205623, 0.051353268427192234, 0.01718423649435863, 0.02980072658829158, 0.048604483308736235, 0.006275673113123048, 0.06237004621652886, 0.03884674049913883, 0.03452496966929175, 0.02777889181743376, 0.029386843816610053, 0.06600221342523582, 0.013124505949235754, 0.0339511002675863, 0.052790882691624574, 0.03862382160150446, 0.055185585442814045, 0.05557076379773207, 0.06495925845229067, 0.03364945063367486, 0.1231704575184267, 0.023876250743342098, 0.024432453319604974, 0.011889232682733564, 0.06088240377721377, 0.02277096464240458, 0.06458808071329258, 0.012412119322107174, 0.045587426648125984, 0.03026962476724293, 0.0102923841404845, 0.03115067651378922, 0.042889248579740524, 0.06940704595763236, 0.024159710337698925, 0.04478916518564802, 0.07825371343642473, 0.06129374654847197, 0.02348731712118024, 0.008399687703786185, 0.06161088851513341, 0.01374587836835417, 0.02569713418779429, 0.03443037181568798, 0.025931999807653483, 0.06436119132558815, 0.041118335793726146, 0.03835750561847817, 0.009175902741844766, 0.005765717933172709, 0.024937032103480306, 0.09869454588624649, 0.033255733869737014, 0.03170214418787509, 0.004507884768827353, 0.03106983807811048, 0.04168671330262441, 0.026600966157275252, 0.0335531681048451, 0.01927259367221268, 0.04210472427075729, 0.0479674014786724, 0.02375207273871638, 0.09414329557330348, 0.04748775143525563, 0.019273012985649984, 0.03519229401717894, 0.026115646105608903, 0.045864381318097, 0.03624481527367607, 0.024449335323879495, 0.06754666726919822, 0.013017333330935799, 0.013882098646718077, 0.028145798496552743, 0.0097383560569142, 0.04592611687257886, 0.011744411840481916, 0.05438274492917117, 0.054138147897901945, 0.048344431052100845, 0.04040319487103261, 0.0018086929730998236, 0.014869078058836749, 0.04075017488503363, 0.027761592355091125, 0.06129505272838287, 0.012430001370375976, 0.02881088526919484, 0.023987700915313326, 0.03980545428930782, 0.03989908735093195, 0.01751339568727417, 0.09848952016909607, 0.012399012066452997, 0.05205507295613643, 0.06016462080879137, 0.022330887768475804, 0.02197301302658161, 0.016962889094429556, 0.03969126373704057, 0.02881713971873978, 0.03480100778688211, 0.01837760068156058, 0.055027300186338834, 0.013038029974268284, 0.029138434001652058, 0.07833807336282916, 0.04841773297812324, 0.04381479579024017, 0.09148905635811388, 0.01406325225616456, 0.025509947845421266, 0.06507213169243187, 0.032300675156875513, 0.06686208056635223, 0.024232258983829524, 0.0316424087213818, 0.015822438181203324, 0.0701891137578059, 0.06835411651991308, 0.0417591098084813, 0.04730919441499282, 0.029229855463199783, 0.04496865731198341, 0.09352039618534036, 0.0091298385632399, 0.0790010264609009, 0.043835664982907474, 0.012575295331771486, 0.048551913278060965, 0.06186649530718569, 0.01760450359142851, 0.07476462487829849, 0.031020633687148802, 0.03866741906676907, 0.04444520571269095, 0.035272894965601154, 0.06373496711603366, 0.08180315344361588, 0.027557761495700106, 0.05579621712968219, 0.04798497182491701, 0.06490203144494444, 0.044691813964163885, 0.008594254704803461, 0.04462857556063682, 0.040951764458441176, 0.056427435993100516, 0.03460912179434672, 0.03992022742750123, 0.07500417530536652, 0.06444975922931917, 0.017377723670506384, 0.03607339029258583, 0.026571476919343695, 0.04151620487391483, 0.020056726498296484, 0.03468516224529594, 0.05211329073063098, 0.05348862396203913, 0.04528042612946592, 0.016205957836064044, 0.05856244271853939, 0.033923407027032226, 0.08348675255547278, 0.050400013133184984, 0.041590571781853214, 0.019495527412800584, 0.00709654132151627, 0.0424501346424222, 0.023608977389812935, 0.03457405160588678, 0.03573086687538307, 0.010327615746064112, 0.006979673471505521, 0.0401947812497383, 0.017631501068535727, 0.034304767032153904, 0.03708470379933715, 0.03502132174617145, 0.02358233428822132, 0.037089394172653556, 0.09525087676593103, 0.020375063322717324, 0.013290444603626383, 0.046432640083367005, 0.05017871953896247, 0.018497609671612736, 0.062173514379537664, 0.05739608342992142, 0.060285950821707956, 0.025757708281162195, 0.06152821697469335, 0.07644362267456017, 0.023597388753842097, 0.06611768418224528, 0.027071361619164236, 0.040778573165880516, 0.0601715190714458, 0.04241571754391771, 0.028006951943098102, 0.06978051693295129, 0.050112649842048995, 0.04080063350556884, 0.050789833621820435, 0.0037830147539352765, 0.04839958004595246, 0.019987721607321873, 0.03726821465534158, 0.025567117336322553, 0.05353418811864685, 0.05973996019747574, 0.014166934925015084, 0.02835271483490942, 0.053388036976684816, 0.05522588406165596, 0.01088439998056856, 0.06233827487449162, 0.06655988545389846, 0.08759911899687722, 0.03732210570888128, 0.02677552300156094, 0.036991208035033196, 0.03714840604516212, 0.04707254578534048, 0.04905640671495348, 0.025786882106331177, 0.056868319952627644, 0.05318062896549236, 0.06457669616793282, 0.053634500509360805, 0.02404856073553674, 0.03460874329903163, 0.04020899337774608, 0.019270430311735254, 0.0203362935280893, 0.01465243494749302, 0.05943660362390801, 0.0332835124572739, 0.02617976952024037, 0.0490934732806636, 0.013454794134304393, 0.014535178397636628, 0.01749464532622369, 0.03190091731084976, 0.02663574505277211, 0.028907948908454273, 0.050573171029100195, 0.03235529722587671, 0.041237038603867404, 0.03946093449485488, 0.04085642816789914, 0.029424969798128586, 0.025413045623281505, 0.026363684846728574, 0.05001645637094043, 0.037706616130890325, 0.09031388035509735, 0.11155298911035061, 0.08499909366946667, 0.2169720979873091, 0.15028647787403315, 0.15425808116560802, 0.13027002773014829, 0.1257975192856975, 0.2379772817948833, 0.18230292160296813, 0.11855798002216034, 0.10603516566334292, 0.1335757612832822, 0.10223728429991752, 0.13080854492727667, 0.13164677104214206, 0.10039561515441164, 0.10465456318343058, 0.16232586465775967, 0.11470166195067577, 0.10821795556694269, 0.1011064590420574, 0.20711121149361134, 0.1294016110477969, 0.10392454962129705, 0.29663547640666366, 0.17175966000650078, 0.11649778549326584, 0.33003752469085157, 0.19502793409628794, 0.15554704325040802, 0.2102174557512626, 0.09185460119624622, 0.15552317578112707, 0.09439820103580132, 0.09724632633151487, 0.10449978828546591, 0.23270007746759802, 0.2009933171211742, 0.12185711588244885, 0.1232461936888285, 0.13959802250610664, 0.14881359675200656, 0.2000951996888034, 0.052481002639979124, 0.12022422029986046, 0.11012727889465168, 0.09050510954693891, 0.084597680834122, 0.2035193651681766, 0.15398801362607628, 0.2417891303775832, 0.13401555799646303, 0.1547996560111642, 0.10448591012391262, 0.13721393246669322, 0.20017484697746113, 0.20162816508673131, 0.10471285888343118, 0.09779345244169235, 0.18286860140506178, 0.09891238107229583, 0.10158062461414374, 0.17715713678626344, 0.15507275151321664, 0.10534035958698951, 0.12479719327529892, 0.2030217699939385, 0.18574139568954706, 0.11992249274044298, 0.14413358381716534, 0.08883897316991352, 0.10444741492392495, 0.11311667942209169, 0.18243339116452262, 0.09516527003142983, 0.11151169601362199, 0.1502127677667886, 0.0972002166963648, 0.1430967589840293, 0.14068648597458377, 0.0763323821593076, 0.12455568357836455, 0.15324527223128825, 0.23730513348709792, 0.13355664355913177, 0.1918821333674714, 0.24229184637079015, 0.10035254832473584, 0.13523328874725848, 0.1382195870974101, 0.0965386068855878, 0.13135011977283284, 0.0871437371824868, 0.14754453906789422, 0.17519403743790463, 0.1656780714984052, 0.12956445309100673, 0.14570240979082882, 0.12079128049663268, 0.1253314653877169, 0.16360360546968877, 0.13893578929128125, 0.10983291344018653, 0.14014329324709252, 0.18899069633334875, 0.10119834434590302, 0.18468551250407472, 0.1012201709090732, 0.13869224610971287, 0.10745470863184892, 0.1561549215693958, 0.18746292596915737, 0.11476961299194954, 0.13814013276714832, 0.12747391214361414, 0.1346788599039428, 0.08672539595863782, 0.2446909574791789, 0.11372635373845696, 0.15863966167671606, 0.09459427645197138, 0.1870018444606103, 0.13861479557817802, 0.0729136863083113, 0.2091681628371589, 0.14826060767518356, 0.1086004362150561, 0.10061290857265703, 0.12507919454947114, 0.15839767700526863, 0.1702037622453645, 0.09094891385757364, 0.1441142286057584, 0.13274575816467404, 0.10402922955108806, 0.16485519299749285, 0.14242489269236103, 0.1413193004555069, 0.13909919536672533, 0.18404144706437364, 0.13299860787810758, 0.08352874327101745, 0.10110482631716877, 0.12191654706839472, 0.17708369385218248, 0.14317168621346354, 0.1356000136001967, 0.14677046419819817, 0.12989938433747739, 0.09896699571982026, 0.13804400980006903, 0.0821696556522511, 0.09985521290218458, 0.14987246337113902, 0.18331252445932478, 0.10147682784008794, 0.12313538361922838, 0.17537035688292235, 0.1508439049939625, 0.12941450957441702, 0.09028020911500789, 0.1367813494289294, 0.13540335930883884, 0.1472056150669232, 0.1512053160695359, 0.17419811978470534, 0.1042297355888877, 0.08263188748969696, 0.09708829340524971, 0.0907535212172661, 0.0630291253037285, 0.12473599577788264, 0.08318391177454032, 0.13650390494149178, 0.11224675617995672], [0.08304176080855541, 0.05616948772512842, 0.02379871115408605, 0.07203791494248435, 0.009003944342111936, 0.06383491214364767, 0.03714543374371715, 0.07713519298704341, 0.04214250329823699, 0.021399262368504424, 0.04292382152925711, 0.07147497366531752, 0.0668954846332781, 0.02944449384813197, 0.03938976253266446, 0.03889748484652955, 0.04160483214945998, 0.027408033201936632, 0.015353980652434984, 0.02078795718261972, 0.032265289555653, 0.08612720266683027, 0.04456367103557568, 0.005205300885791075, 0.05197807142394595, 0.016648511627863627, 0.05381324306654278, 0.013978442402731162, 0.056847309751901776, 0.015958909862092696, 0.008522715379513102, 0.07364254954154603, 0.0553372210561065, 0.026970373874064535, 0.03809266279859003, 0.03291755943791941, 0.06770964289898984, 0.02462564363668207, 0.08519912473275326, 0.010746505231509218, 0.014543681554641807, 0.07584314356790856, 0.03346363169839606, 0.034062181221088395, 0.06915268226293847, 0.0827345265133772, 0.08584454088122584, 0.12736425240291283, 0.024166456460079644, 0.0937210135452915, 0.05091416933282744, 0.04488523249165155, 0.03259024262661114, 0.038796834778622724, 0.007159805236369721, 0.025946711029973812, 0.035247019986854866, 0.06912318931426853, 0.08858213812345639, 0.030670900305267423, 0.015122811855690088, 0.03978310080128722, 0.03181933301675599, 0.045769134085276164, 0.013959771822555922, 0.04884221176325809, 0.07472719094948843, 0.0356388145883102, 0.07749152777250856, 0.05149322263605427, 0.056741501757642254, 0.06508983933599666, 0.013864380798622733, 0.01715908139885869, 0.0495453632902354, 0.020644639189413283, 0.055299378946074285, 0.059506859033717774, 0.019082262479059864, 0.012872850165877026, 0.016022446980059613, 0.04712664092949126, 0.02395595183770638, 0.00642568063994986, 0.012211973225930706, 0.03939364025427494, 0.049715289133018814, 0.03304394718725234, 0.06880921631818637, 0.025575138097337913, 0.04865700138907414, 0.027124332409584895, 0.04825332871405408, 0.07024728329270147, 0.05404763556725811, 0.020627439917006996, 0.023594446138304193, 0.019396276293264236, 0.04709676948550623, 0.017338028046651743, 0.050910640420624986, 0.033759381258278154, 0.007983885552675929, 0.03881485783495009, 0.04954082134645432, 0.06539035719470121, 0.0418941361567704, 0.011627095918811392, 0.01374823747028131, 0.02734117126237834, 0.01613844095118111, 0.027443003200460225, 0.007642063928869902, 0.030805193782725837, 0.02944543637568131, 0.053323967367759906, 0.02592328513856046, 0.0581945192971034, 0.01824824805225944, 0.016302871190418955, 0.04605855683621485, 0.013875944387109485, 0.029081839675200172, 0.03891894404659979, 0.015961271747073624, 0.016472266397613566, 0.009395841916557401, 0.009088993538171053, 0.04993082366127055, 0.021102548016642686, 0.022817723656771705, 0.019700137527252082, 0.01508630468379124, 0.015472530394617934, 0.019969498171121813, 0.037191758601693437, 0.06986126260017045, 0.01989613130717771, 0.05287178420985583, 0.07510917435865849, 0.05821278355142567, 0.03361574599693995, 0.011614732666203054, 0.020890683408651967, 0.0036990743728892994, 0.026663158132578246, 0.013114727225911338, 0.07037839852273464, 0.031154509706539102, 0.0018440717326484446, 0.03487682559352834, 0.012074945861968445, 0.047584126732544973, 0.050292887826799415, 0.03176731588609982, 0.034415072441333905, 0.04267229654942639, 0.014657658739452017, 0.02350047911022557, 0.020217924684402533, 0.027848898607771844, 0.03848057967843488, 0.02255128707474796, 0.07475752252503298, 0.04133141381316818, 0.07378346854238771, 0.02711112032557139, 0.05322237477230374, 0.04134879491175525, 0.11251808537053876, 0.03469448733085301, 0.01791474915080471, 0.06608292940654792, 0.016979218198684976, 0.022533559022122063, 0.08027018062421121, 0.038082617829786614, 0.025005814350151923, 0.042073038275702856, 0.035306510544614866, 0.03649190592113882, 0.030538900064129848, 0.017477401524956804, 0.012458883902581874, 0.06216214467713144, 0.04453451205336023, 0.06117173375969287, 0.02217282515630359, 0.06254112609894946, 0.024530047594453208, 0.06311212709988467, 0.07782795073580928, 0.005038622402935289, 0.033105593684013, 0.023547709388367366, 0.01396145000398974, 0.013735572720179334, 0.013342611091502476, 0.06006345123751089, 0.09515273515717126, 0.025122730439761654, 0.010786263937916374, 0.09370456755277701, 0.010739907538663829, 0.05697987959138118, 0.05435147453681566, 0.04384135354484897, 0.023545264011772815, 0.036720105199492536, 0.036358675570227206, 0.018816141309798695, 0.021869622578378767, 0.048123983506229706, 0.05540987360291183, 0.10244576100376435, 0.02659551322722109, 0.041532298346282914, 0.057724687867448665, 0.09309375775046647, 0.06520430077216588, 0.09074305693502538, 0.0977596698794514, 0.07279710232978687, 0.03285035054432228, 0.029078514853608795, 0.11112158608739264, 0.03212356532458216, 0.09346352540887892, 0.019229463759984355, 0.027177742922503967, 0.04420542893058155, 0.016032627390814014, 0.0848243549990002, 0.00980840552074369, 0.022260003388510086, 0.004389973273646319, 0.03851370915072039, 0.02726498423726298, 0.04974497504008468, 0.04210188184515573, 0.011383681685401825, 0.05267841763270553, 0.0636194518301636, 0.0270460284082219, 0.03741113003343344, 0.01465085695599555, 0.10547072524786927, 0.07704750081757084, 0.05970365433313418, 0.041092605533776805, 0.05112670929520391, 0.008113493295240914, 0.054404534384957515, 0.056351087550865486, 0.03251964211813174, 0.04076702905877028, 0.056110713339876384, 0.027049451564380433, 0.04006850482255686, 0.03828995533694979, 0.07324569349293597, 0.01941195787367178, 0.022900467556610238, 0.023334764955507126, 0.06103366089519113, 0.04233420375385322, 0.04009226096968632, 0.026412959741719533, 0.05573899012233596, 0.07086005236487836, 0.07152487567509525, 0.005993683898850577, 0.0711087163654156, 0.03425471659284085, 0.08829002137645148, 0.07762459485093132, 0.053911317882011645, 0.0268123817659216, 0.0038013843004591763, 0.017189680147566833, 0.06633134849835187, 0.047055817776708864, 0.03565651109965984, 0.01750434334098827, 0.046246401834650896, 0.038529357334482484, 0.0509070744010387, 0.09534658413031138, 0.022243876519496553, 0.10092870725202374, 0.04969577807059977, 0.019232473168813158, 0.04718690332083497, 0.05500118400959764, 0.0009233527146079723, 0.00930749387407559, 0.02866634829842951, 0.04272870719432831, 0.03371645914739929, 0.02968857323139673, 0.011167704651597887, 0.06376601857482456, 0.03138508756819647, 0.012216661743877921, 0.03069424827117473, 0.016594884036749136, 0.037906179641140625, 0.018569655512692407, 0.022821983584435657, 0.03928313446522225, 0.02331299034267431, 0.05526180400920566, 0.03301758239103947, 0.07167986579588614, 0.028347796251182444, 0.05974829451588448, 0.11406066158087924, 0.0271440290089231, 0.013186022570153, 0.03946751734474674, 0.01736318870825926, 0.030413477106776554, 0.025564586612745188, 0.04089422945980914, 0.027887056130566634, 0.04248637742421124, 0.023685485393798444, 0.021142436598893255, 0.07105971977580339, 0.03364847470948007, 0.026681529998313636, 0.020112370875722263, 0.03519641293678433, 0.005780691226391355, 0.045741433423245326, 0.03432758807321079, 0.0458472080208594, 0.04446767423360143, 0.014486581640085205, 0.04364274369436316, 0.006977285147513612, 0.008011498084670166, 0.03197248632204719, 0.021376970107667148, 0.05969130499579478, 0.12136228149756789, 0.04135594179388136, 0.006407395976566477, 0.027581833055592142, 0.06761204305803403, 0.04217913570755627, 0.05078103917185217, 0.12057524130796082, 0.1130050900974311, 0.12410216455464251, 0.16030357161071151, 0.0761786314251367, 0.20217526151100174, 0.21098811674164608, 0.1763204246526584, 0.12003774085314944, 0.14746251690667123, 0.15917222684947774, 0.18634971929714084, 0.1583292509894818, 0.11583449842873961, 0.1148083308362402, 0.16254654969088733, 0.11295121759758331, 0.1331547854351811, 0.12058434003847651, 0.08120051468722522, 0.14012184517923743, 0.1805261310073547, 0.10298076784238219, 0.12299781170440838, 0.20403785922098905, 0.060220972081879154, 0.1200282339414116, 0.11127862453577109, 0.20534763112664223, 0.13710019091377035, 0.1184206604375504, 0.16526582330698147, 0.12851495237555355, 0.14029565616510808, 0.1271125752828084, 0.08309697659569792, 0.18520994373830035, 0.07552291426691227, 0.1707453964627348, 0.146157227572985, 0.13154190557543188, 0.2110515406820923, 0.16129393799928948, 0.22045326040824875, 0.1941047766013071, 0.294853164232336, 0.17896230710903183, 0.20088797667995095, 0.15648753731511533, 0.3399354888824746, 0.13260804524179548, 0.14917149004759267, 0.17619890539208427, 0.10502453122171573, 0.2077325523714535, 0.16817427036585286, 0.15909593406831846, 0.17226512194611132, 0.1540624361950904, 0.1480234766495414, 0.09576056152582169, 0.21816783148096874, 0.08325794100528583, 0.08974794080131687, 0.10552862760960124, 0.11770497032557614, 0.191812994889915, 0.16737270634621382, 0.19447944243438542, 0.16099850385216996, 0.2539784606778994, 0.18806408043019474, 0.14132149721262977, 0.13651037646923214, 0.23999063938390464, 0.19094061513897032, 0.14928011078154668, 0.21866652503376827, 0.15431478124810383, 0.15699006034992635, 0.18889466242399067, 0.12724592437734827, 0.20730091928271577, 0.06832712460891344, 0.28189146600198, 0.06566269570612349, 0.21248382632620633, 0.12867635465227067, 0.1994237638427876, 0.1476160524180159, 0.16513296402990818, 0.09711941907880828, 0.1106175416498445, 0.2403900187346153, 0.22284043778199703, 0.08510615589329973, 0.10810648498591036, 0.14060317247640342, 0.2333153921063058, 0.19265356619143859, 0.13107381819281727, 0.08745717583224177, 0.07741864144918509, 0.07756120801786892, 0.24461910274112597, 0.13486298674251884, 0.21239343273919076, 0.12441005936125293, 0.13167598197469488, 0.13733251282246783, 0.14547415485139936, 0.19536958920070902, 0.11639024087344296, 0.2427094231825322, 0.10121340252226219, 0.1335973577806726, 0.18391079938737676, 0.1696364497183822, 0.09739444416482002, 0.08334135098266415, 0.11224685265915468, 0.10926914095762186, 0.08632632088847458, 0.09496091224718839, 0.11812092183390632, 0.1261877702199854, 0.1641478223609738, 0.13042460224824026, 0.16472484217956662, 0.10292469858541153, 0.15534860780462623, 0.09373878056067042, 0.1794043747941032, 0.11265858134720474, 0.1718183935736306, 0.10267150006256998, 0.09164277740637772, 0.16109315736684948, 0.19265200768131763, 0.09080885574803688, 0.14746600500075147, 0.09422329909284599, 0.1022726550581865, 0.13176765205571428, 0.08790944062639028, 0.13419956609141082, 0.11782396628404967, 0.10392233059974387, 0.13795269594993442, 0.09090483028558083, 0.10358772589825094, 0.09249586873920634, 0.16088428732473403, 0.17776406515622512, 0.08551640770747326, 0.13016541459364817, 0.0994429572892841, 0.10384538472862914, 0.24006473540794104, 0.1806598066468723, 0.06902558205183595, 0.21095363656058908, 0.13376037793932483, 0.12473204755224288, 0.06245829499675892, 0.17327463574474677, 0.22729581745807081, 0.16709695395547897, 0.16090944613097236, 0.20918351045111194, 0.06809327387600206, 0.06545942887896672, 0.19481755007291213, 0.14774018403841183, 0.12110887517337687, 0.14819430420175195], [0.03909666615072638, 0.01632297040487174, 0.06179433999932371, 0.06324704954749905, 0.07326726030441932, 0.031851790845394135, 0.05583035592280794, 0.02423124409688171, 0.04105331623577513, 0.02777311976387864, 0.04048154711199459, 0.009883297498163301, 0.03823165221547242, 0.018678682572499383, 0.026682379757403396, 0.06551919403136708, 0.03252616930694785, 0.023896559614513535, 0.030953845962358173, 0.012233561374159763, 0.044301581583567895, 0.028921064513269812, 0.04403421175084077, 0.03368242425494827, 0.033613352570682764, 0.059791632229462266, 0.021804907300975174, 0.03445426526013762, 0.06101933744503185, 0.006251912791412906, 0.046924535563448444, 0.013216319821367506, 0.02522676655644318, 0.09602544145309366, 0.015831937671464402, 0.03673026891192421, 0.014820888554822886, 0.07393437685095705, 0.0230855870177038, 0.031235247952281497, 0.04712952417321503, 0.009245753681170754, 0.033057146283681504, 0.02739212341111852, 0.030621627265645657, 0.036755702312802896, 0.024862622522050515, 0.023876256309449673, 0.0467873940942809, 0.028731618331221398, 0.0449299283354776, 0.03434868362091947, 0.043742091293097474, 0.08257678302470595, 0.01982337300432846, 0.08955545737990178, 0.07584374470752664, 0.07835546930436976, 0.04152151865127962, 0.06409032226656564, 0.03099474201007979, 0.025871568577713333, 0.011481251840450568, 0.06868334065075032, 0.04115738018299453, 0.03233354116673581, 0.02172257714846637, 0.06312106997938827, 0.03041879830561811, 0.027651140371744987, 0.020531444970401935, 0.027172726004209835, 0.03367849829373881, 0.030281196704891045, 0.03110855777777033, 0.027127649809699506, 0.027173380949534476, 0.040072237825370394, 0.02375262378336629, 0.036469081169343553, 0.03581022843718529, 0.05905790421820711, 0.022024378922651522, 0.034742726929835044, 0.03993547485151794, 0.04329757080995478, 0.012581372593558626, 0.0639315323496703, 0.07531652299803682, 0.027013863727916032, 0.06936765275895596, 0.038080094527686015, 0.05004914055461995, 0.06709854365908541, 0.007522567948399228, 0.06804789896705188, 0.028604592334886547, 0.03284946738858707, 0.02846192928700475, 0.021236284883343615, 0.05732950165111106, 0.04272909682185855, 0.03635683504398912, 0.00331810863372084, 0.04301817076338921, 0.041189459516317584, 0.041731438832357526, 0.035294057306600735, 0.012403528035065392, 0.05402680348197464, 0.01665623738517752, 0.1031033112667501, 0.0487569130200427, 0.040668739020475186, 0.033917451291927136, 0.04911932228424121, 0.04760849886224605, 0.019474185100989416, 0.03192736745404545, 0.07102138784830458, 0.055443949313485064, 0.032629825072945096, 0.010415115884825354, 0.03785057793720625, 0.0639415587647818, 0.022454735517385416, 0.022936370805837214, 0.07277782875462435, 0.07889977525337599, 0.020268663465685677, 0.03606059937737882, 0.04520928385318257, 0.08763084581005387, 0.007323924237425672, 0.036614308337448165, 0.04112687420274597, 0.024441806235699914, 0.01932800056238193, 0.021151385044504423, 0.04501789138885215, 0.016784773652034346, 0.01914363994728774, 0.027396296136430465, 0.06101443927036598, 0.04529972196905874, 0.03586148486647289, 0.07411813261569478, 0.027277719491394237, 0.07068912833346985, 0.033232371060876176, 0.017300364052061923, 0.009489220792602282, 0.039121290610637516, 0.03620524767029565, 0.043510455871000886, 0.05436665145680308, 0.07267597640748136, 0.009344455611426383, 0.02556191302574007, 0.03897513204719871, 0.051938188407802954, 0.014667459727206733, 0.02646349628776079, 0.028101746465836186, 0.014274254117481178, 0.04213581283693202, 0.06555886182468385, 0.02551063989812974, 0.016438661950815003, 0.015396296985272784, 0.027417011333454866, 0.04460736869077664, 0.04989018365449738, 0.02313218647032045, 0.02747462611296214, 0.021386560511018615, 0.047597474258509465, 0.030806260620011017, 0.023920328749227338, 0.045377922069747, 0.06291867888648994, 0.05418977169028949, 0.0023712738448011805, 0.01684592290985165, 0.044589601675397716, 0.02712524339585798, 0.015525529943261063, 0.022113425511633977, 0.038522830145666376, 0.013271183088363614, 0.007683560652367305, 0.05709358403692022, 0.02254605122288922, 0.049152919309563003, 0.02460425122990273, 0.009396226905664662, 0.04736940856673755, 0.028438239933166187, 0.004175203157501528, 0.02394639297563117, 0.04737163872050587, 0.011917529845959507, 0.03790635775658302, 0.06707201187964529, 0.030352726753335446, 0.09426827324205078, 0.07245477187098004, 0.049199099448742345, 0.009911703200486954, 0.1347719697514549, 0.032200941641349345, 0.0420634905458428, 0.018078376015182585, 0.012821342334063957, 0.0606723648525076, 0.06646713925874792, 0.03048518341529416, 0.07134062267141417, 0.0006956885943054658, 0.11256924903136678, 0.047054890092113055, 0.012606158470589435, 0.004930191380481119, 0.029110325158399064, 0.05735414095397573, 0.061176962190074846, 0.08763601115788333, 0.08659333077957854, 0.06459205120336264, 0.039201390609377995, 0.038527075230376795, 0.06343015222228132, 0.04709982342319563, 0.019919477417715825, 0.09555505341268145, 0.032881476217880845, 0.02663662078703055, 0.03210982074961066, 0.059335285623092204, 0.0411826391791692, 0.014707991194882197, 0.01150259971836931, 0.019222546943638008, 0.03410172284930013, 0.029140046317479573, 0.03745191846974194, 0.04773296073835809, 0.04204538214253262, 0.044932310629519634, 0.009540420633129543, 0.04135416435019579, 0.01654552008403698, 0.01354811642158893, 0.02915040669904556, 0.021789854690723587, 0.0462618051096797, 0.049588459805818275, 0.036099666031077504, 0.009542406805849168, 0.04152923698711675, 0.03643188472779002, 0.04665290209231898, 0.10736624462879263, 0.0364678974437993, 0.02316401161806425, 0.07010018962319009, 0.02117560688930098, 0.05320250376826152, 0.05232156705460511, 0.08606628718553111, 0.04946376786392648, 0.022367471938196104, 0.01804069717763923, 0.03191032403265126, 0.04571132449200377, 0.044961759049328975, 0.01802006361685926, 0.022616258393099997, 0.039564794351463206, 0.05262649698124733, 0.04993201480829157, 0.02672575086762663, 0.019615438068285584, 0.019060678969253786, 0.06099921782151796, 0.037499753598240204, 0.030436602428380866, 0.040959085745271295, 0.035666504118125886, 0.011412815620133188, 0.033101077715400606, 0.025921181149897166, 0.03277744566730689, 0.033144649205496535, 0.0609790017188061, 0.032434495515190065, 0.00984278736723354, 0.034321654602536, 0.03381251903192606, 0.02542636346333893, 0.0790282707021106, 0.048534046072745696, 0.031083306203072425, 0.0475968026148621, 0.05136569569003768, 0.018791283073369414, 0.07408786041196436, 0.09552153802360408, 0.03603556673624553, 0.00872394593898207, 0.05235719385382254, 0.02333635315153515, 0.03889034538588021, 0.03947717268601991, 0.0224050747056026, 0.02854236139683053, 0.009358270690427162, 0.049430805374868214, 0.008714842570043402, 0.04906767622742336, 0.08302183414343745, 0.03347875666804612, 0.06983749903156422, 0.04871745673881378, 0.06749724765541032, 0.05865272498340346, 0.05312681954819709, 0.02931724149675574, 0.029133598909538705, 0.054367983611882664, 0.03812778122664895, 0.06682958934106864, 0.051240038956166245, 0.013758961504208855, 0.04512949555646628, 0.04368984780739993, 0.03923237898561638, 0.027520097501110286, 0.04244466130330693, 0.04082490173459519, 0.05215014949499164, 0.041828315079328604, 0.05851326430274639, 0.01649897629249608, 0.060946517914999276, 0.05062323631136678, 0.061890500073786825, 0.05704921844881028, 0.04013376928924117, 0.010876156575250207, 0.03177399150445126, 0.02123236448824173, 0.13697882008273154, 0.10746656815172173, 0.10746295389253646, 0.23856044659623876, 0.16429527226136997, 0.13089464890072122, 0.1376367043121718, 0.11430021942942403, 0.1987270059180446, 0.12702118721790612, 0.10703019273933023, 0.08891375196981244, 0.1324213802581653, 0.11741117632482201, 0.20340839924756438, 0.1681479686521925, 0.1394674787297845, 0.13496160332579166, 0.10828108264831826, 0.08728841145057231, 0.10141729275346734, 0.1526459731394425, 0.06734078808221966, 0.11295101721771061, 0.11381632430129685, 0.11409524566261098, 0.20237929275026545, 0.12307233817409724, 0.1501280887168832, 0.13810177857521921, 0.21429432526929304, 0.13518792868126184, 0.0848392499028705, 0.24480275460518897, 0.10855646396521479, 0.1509354414884001, 0.18385737959761173, 0.1786200434435159, 0.1639115225407295, 0.0920077136834152, 0.0786403649544809, 0.22180825879331678, 0.11499517393531278, 0.2856022637570277, 0.16618028283119202, 0.2390060617472045, 0.12378177198115736, 0.12540655588964, 0.13430388236884028, 0.11293224088149145, 0.1831273882999085, 0.13033306575380266, 0.12503880687290803, 0.1094173255842179, 0.16139369748998433, 0.15948293439578265, 0.17033671058015898, 0.13817373721394688, 0.15941064921207726, 0.21202044415986165, 0.09315798321040347, 0.2710710122482851, 0.14193703449564055, 0.15509951335843652, 0.1321954556624405, 0.20349993574200198, 0.10721066821133718, 0.18513690156396478, 0.15932743961457163, 0.1181885611731559, 0.12182953767478466, 0.08252573810750619, 0.12452933733584359, 0.11729661098797806, 0.11439569672802463, 0.09754422440892085, 0.18127979681594297, 0.15367899817647412, 0.11070174572523683, 0.13999704562593251, 0.14866415789583698, 0.14949818345485255, 0.14551250904332846, 0.1720006502000615, 0.11809074610937387, 0.167120405822061, 0.26393496547825634, 0.18902419687947258, 0.10230686064460315, 0.12717935373075306, 0.11300209924229421, 0.1713755095261149, 0.19289166200906038, 0.18303656426724046, 0.10552059015026316, 0.2107328624697402, 0.06289756478508934, 0.11024233404896222, 0.20671843725722283, 0.10126564971869811, 0.1701637901715003, 0.2219994063489139, 0.09290847316151485, 0.14695560035761446, 0.12982643122086301, 0.08538842434063554, 0.0587558723782422, 0.1751157408580184, 0.20639920985559002, 0.09689143131254241, 0.09345037455204874, 0.18664392147911713, 0.1061625404690858, 0.12019511326798238, 0.0792107722372748, 0.13496154395397753, 0.13425979879684746, 0.1754042285028845, 0.12557370238937438, 0.14929731376469135, 0.19353753828909248, 0.0775064375193324, 0.1585196118685417, 0.0869266664085444, 0.14457112440140918, 0.21297296101693064, 0.09845448337728158, 0.1457454840419814, 0.2169298252556473, 0.08927569739171304, 0.1037976126826834, 0.24679310561623424, 0.13794086611596867, 0.1653767892275937, 0.09602006088243797, 0.13474621722707525, 0.07291660294868052, 0.25812549283728004, 0.13084765610983595, 0.15307192137697712, 0.1053803984541446, 0.11471196296042763, 0.09480651584453881, 0.1556287833955139, 0.16092066740384325, 0.10818568698596209, 0.13394057139521465, 0.1455896775587462, 0.16274894820526242, 0.12169888257631101, 0.08193840985768475, 0.14156505523715168, 0.12575943226693198, 0.08984451647847891, 0.09804462490137666, 0.12358791558654048, 0.20198831451125443, 0.10520888812607154, 0.10400132479844615, 0.15518906089710072, 0.1900597897474654, 0.16785805608378723, 0.16362085298169404, 0.10444906249176711, 0.11389554856577888, 0.10402900690678507, 0.17189247475471348, 0.10050264027086087, 0.13222246983787045, 0.14424858702113852, 0.13432482577627525, 0.1315060895285569, 0.15319333673687652, 0.1913951657479629, 0.10668853021343239, 0.0938671053154394], [0.05078260139271151, 0.0083354353409959, 0.04362994535767939, 0.011607415090111317, 0.09337483876151964, 0.03406523144803941, 0.026036709423351567, 0.04382953484309837, 0.03411800928006414, 0.0534412897832226, 0.020450882984732743, 0.0683878619747702, 0.03178724255121779, 0.05623000986815896, 0.02263090653286781, 0.037877146824030206, 0.05145032278960571, 0.030104552570264786, 0.0939600370475091, 0.04606576309015509, 0.018844509904738516, 0.029590975245810114, 0.026251546332787257, 0.034452873733243905, 0.04299718653783202, 0.016821567478473298, 0.05904275327338837, 0.0024332726297870977, 0.032631788053549826, 0.028043124220857862, 0.07995058957021683, 0.06724375969497487, 0.06249433368793689, 0.023696649150224403, 0.028681317417067476, 0.038268837524810806, 0.033652682686806656, 0.028595029762072954, 0.03207250185369048, 0.020032994470966514, 0.026110085564141627, 0.033660942790447734, 0.039704614973743446, 0.038280897424556315, 0.018357627632212825, 0.010150320376851596, 0.06565223142388277, 0.04891765107458923, 0.04241992923198268, 0.023523986637883354, 0.06210847255715635, 0.050422826752765104, 0.047433967993129045, 0.040730604450800456, 0.014456758435699157, 0.07725536896032281, 0.04219960785121657, 0.07406999691738747, 0.01091573438316118, 0.009855771240836475, 0.02839161821611924, 0.03773272117541637, 0.058531179747660644, 0.08979241029010154, 0.09863294020760804, 0.05205498389841523, 0.020350216218503192, 0.03826238084002398, 0.08622456502052955, 0.026256477904098574, 0.01747059046465438, 0.04810205675312318, 0.03298327290394809, 0.016646912299620453, 0.01902521173178684, 0.0865217209502589, 0.045900223340140656, 0.05990019730234053, 0.04428748448844999, 0.07349662846536376, 0.06366247413097881, 0.043368145343265496, 0.03719290150911547, 0.013021979175391607, 0.035228106353315525, 0.0871102514793165, 0.040496809378964826, 0.08131185910315253, 0.03871104992867913, 0.03807091787166428, 0.09741486064740457, 0.05149458447704092, 0.016912693936319556, 0.039845790015533566, 0.07800812934874557, 0.02061377883364912, 0.020176444195385557, 0.09845823122304864, 0.050334945335634984, 0.07060290561639704, 0.0712525297421962, 0.027356557839084417, 0.021071340706839692, 0.009155352672678418, 0.027064806599810254, 0.07059883122565225, 0.08033704070840031, 0.026362733042333275, 0.035664990136865526, 0.05369916012568865, 0.022454473910329398, 0.024289211396535393, 0.0077242312727321405, 0.034579461862449534, 0.07623136101756245, 0.04034148529171944, 0.022277419739111792, 0.06343750690575689, 0.029123715357854962, 0.017708537852740847, 0.05440760687633883, 0.10681839121389203, 0.0431882561679231, 0.06390969836502336, 0.017552325043652672, 0.019934810188715346, 0.06108120287535712, 0.07952367654070258, 0.022695634797855746, 0.08500560972606763, 0.03873044224746991, 0.06664975953754038, 0.03324993027490564, 0.025277674176322762, 0.016660974142723717, 0.040517890083719976, 0.054725557783967815, 0.04374293734144885, 0.032642723599565215, 0.07263587816851214, 0.09844305430306122, 0.026542627783783246, 0.022279291806626134, 0.014267584992921911, 0.04701441706856713, 0.021013139630667865, 0.03882245742715895, 0.021314507248462178, 0.04804338626854587, 0.015515067516389536, 0.022233701674849726, 0.004138785043323878, 0.03745723224710673, 0.059096993136336096, 0.01740724630508339, 0.011896508513018489, 0.031217959622154012, 0.03585225254937541, 0.008164776627381798, 0.036868586685159244, 0.020585400961863343, 0.06398659970727749, 0.052054701882298104, 0.013005004402657505, 0.04735989794426132, 0.03160257765557617, 0.10299524714355357, 0.03774817269004416, 0.02883509598177625, 0.03934108135581482, 0.02741509844781831, 0.01850063206802588, 0.07555852251243778, 0.040345374145545065, 0.00807891106887837, 0.04654265234421473, 0.04743956378661096, 0.09509347466519102, 0.04069947506650351, 0.03129872384306509, 0.0761936599155888, 0.03935009845008608, 0.02172275897464715, 0.03318960851174779, 0.014706299098179443, 0.04761882584716659, 0.02996759478264721, 0.021466500948008616, 0.024809078422549646, 0.04507676225330215, 0.03183264343533665, 0.03531545342411846, 0.010427227734908229, 0.04957225130056031, 0.08102769817924127, 0.044897140251123346, 0.024618175775685813, 0.01602297204954084, 0.03503232408547774, 0.040426873092656024, 0.054124054513522424, 0.04383227707876358, 0.09064968733582646, 0.03246804430091288, 0.07486147515010089, 0.060807751142419875, 0.024885024249670096, 0.04260602276190184, 0.040922041443991475, 0.026083841366926208, 0.04508259182330221, 0.054158263810677454, 0.052240379809518345, 0.02880871448724065, 0.026031913293991238, 0.01273501386094722, 0.0695234295562841, 0.021455268542922568, 0.04004813286883291, 0.030530862604791764, 0.03777442245336715, 0.058975154752261005, 0.05888351806788705, 0.09660102892667055, 0.05355364723072853, 0.028965975579922087, 0.027456736643216573, 0.034776925094774924, 0.08431303751422092, 0.021056069163023494, 0.015187195949692978, 0.018255068389407825, 0.0449713587295264, 0.06654320939560421, 0.07968228834215552, 0.035318269874551333, 0.04083933279616758, 0.01973039674339816, 0.07285498242708854, 0.02055118795396993, 0.03722614230355248, 0.022459670799435116, 0.0355283087992575, 0.030339459008246195, 0.05823607585625723, 0.015131175860005897, 0.008637807641207473, 0.05645788260153495, 0.04515446140430868, 0.02283353325765347, 0.0664556804986205, 0.01725977228488773, 0.06045133100997191, 0.02599517141788965, 0.06879890046548098, 0.01815836840250995, 0.036158648217679, 0.0490464211179642, 0.042190687236143276, 0.020523433486232534, 0.03815317009866703, 0.024071622974588536, 0.002816800401888031, 0.028385037221596576, 0.06847376556834206, 0.09225378016708419, 0.09943685683538206, 0.0675808209052775, 0.01713427140202839, 0.037608211059705354, 0.07483278372092173, 0.02188122791267233, 0.09057962117367424, 0.04000493616331369, 0.036662633283413015, 0.048691377669456415, 0.016020695511542726, 0.037466245630639605, 0.004628685537682031, 0.03281063451140653, 0.014197703440004261, 0.020866333543381188, 0.08284819385153241, 0.07256570068420842, 0.031168491768767126, 0.03906634199665859, 0.06705751031404361, 0.02584222220320953, 0.07115170155884698, 0.04894278390565887, 0.027575161147979088, 0.020785148153663613, 0.05862803373020142, 0.039415414867107756, 0.03670008576591499, 0.05950456950813532, 0.022192790784174576, 0.054866124264663085, 0.04152266155870166, 0.042756140683195554, 0.020994845690438524, 0.01821684963942971, 0.02920574122981634, 0.008745394934521755, 0.032046682536019944, 0.06014945131028071, 0.06334577003144659, 0.05765644367784262, 0.029854547137802, 0.01918208505230723, 0.010378719107393408, 0.03518020072078798, 0.027715369542420376, 0.11865082269650884, 0.03017505288880784, 0.048652062396286055, 0.03415589962969534, 0.08325187023729086, 0.06585796960280277, 0.029673444551008288, 0.08468868298223242, 0.05640214731101878, 0.010260810395266162, 0.033762342427507974, 0.05355497938580811, 0.02288633149873931, 0.04997334130166564, 0.02391614303633105, 0.01855237645941088, 0.022410048950405326, 0.005660621009155875, 0.030896722855686676, 0.04116377007449046, 0.06058883242076263, 0.009737170476000756, 0.013012883227929706, 0.057001301684067585, 0.024303560821863357, 0.0404067386261886, 0.03100462370639434, 0.06939145343494602, 0.01884925593913067, 0.06756646776921116, 0.066167808836326, 0.010324617469450459, 0.02949667610664619, 0.029667121452803258, 0.05170754375285469, 0.03293686640972737, 0.037784686355735175, 0.036766418925253674, 0.02588453389762435, 0.1561332805431448, 0.1668019502540119, 0.20819970464799553, 0.07634180001332425, 0.2234053160645999, 0.15624188643414527, 0.13805745751596987, 0.15466476324945688, 0.09372135493322276, 0.1248452250729315, 0.10564633223111741, 0.1159650125191547, 0.10348559153499082, 0.13274903845740482, 0.12589386489707977, 0.09544442888000049, 0.1457204291364178, 0.11883771774591878, 0.30799567932263017, 0.126827560889069, 0.12971467862371355, 0.13522276509320363, 0.07750294942525215, 0.10477335134055465, 0.21511137048946694, 0.15145696350373328, 0.19475676817819476, 0.09412680505192839, 0.19500233000144362, 0.1421374737401493, 0.19459932897007093, 0.10960909654386342, 0.13539411214878783, 0.111574236798333, 0.12760078971041366, 0.14395742764463648, 0.10258099515340291, 0.11569665934075601, 0.17028174712322652, 0.10432619252242148, 0.18846203485736623, 0.15639390796422958, 0.14789397187996656, 0.12483229686040431, 0.13907889020629227, 0.16296859423164278, 0.14339419692987576, 0.1964443377801217, 0.205115427961573, 0.10509563639061525, 0.10301567846909165, 0.14440025232033804, 0.09823295229580253, 0.09805460678762756, 0.1188157130673062, 0.13834612327627838, 0.12503548205131665, 0.27858012181241065, 0.22205352375749499, 0.11175617430126294, 0.10702793661039323, 0.07973791973199695, 0.25132492650300264, 0.19549250369891524, 0.19690009066835046, 0.19451043452136219, 0.09039601383847184, 0.13158361427485943, 0.15060456236824393, 0.11101318799774162, 0.11632612673565745, 0.20005398080684245, 0.15802099253050983, 0.11565695444005542, 0.16187085391720757, 0.1879381379694678, 0.15995713707525283, 0.13248527917312458, 0.19841141504002735, 0.12638822430744767, 0.1692613385966979, 0.18703476613154635, 0.1094396345433779, 0.20624770782887936, 0.15905550186289474, 0.203938010672573, 0.13753777602687478, 0.15434633736731485, 0.1398468646220863, 0.1433109724894166, 0.22130352415842935, 0.23210613668197766, 0.11501303742988966, 0.1065167823981028, 0.15432439948199317, 0.12287479330552742, 0.14400366344489157, 0.22698197804857045, 0.15858034923439845, 0.15989179839380085, 0.14851419953629375, 0.05635321380395908, 0.09947184909833595, 0.09652953041950241, 0.13868480978999287, 0.19092464412096888, 0.13101603457471356, 0.1713164642569609, 0.18616468703839928, 0.1886026273132302, 0.1711474623880349, 0.10548495964030735, 0.1372722355881706, 0.17946310836123303, 0.17256288643693551, 0.1665267173666507, 0.15958214469719678, 0.24758799030678347, 0.12729814188787714, 0.11906446612556465, 0.18433646560879424, 0.14332734426716343, 0.15453147352673113, 0.12883029092336074, 0.10912428857409395, 0.10517941002035514, 0.1462054078001529, 0.11891636313521303, 0.16457526973681524, 0.1504294600454159, 0.14957186387619004, 0.20948370918631554, 0.14402108907233924, 0.1098043036472518, 0.1636933014378883, 0.14053789316676557, 0.1563868872472085, 0.20602834381861612, 0.09383703349158168, 0.10546190111199394, 0.18480869417544454, 0.1339993643341586, 0.14461026526987553, 0.11005763575667515, 0.13831412186846137, 0.14853665692498907, 0.1019183686003089, 0.14128345472272485, 0.19471701874863356, 0.043540201149880886, 0.08365883433725685, 0.1292284531518817, 0.0799657590687275, 0.16698999563232064, 0.0766757813107688, 0.20925791817717254, 0.16077771491836756, 0.11349783162586391, 0.10280263013555668, 0.11398998685763218, 0.21036204096162692, 0.1969223254127428, 0.08380348634091206, 0.12212331683258526, 0.1345716047217138, 0.13407608756097034, 0.10395733028417453, 0.12046374104102142, 0.1574195857392624, 0.12372642260743305, 0.1378060327260755, 0.10723056519054808, 0.1343405296211131, 0.143993035890162, 0.20536119758617133, 0.09305585626862012], [0.03832776776107494, 0.06081389612518251, 0.028867657711089123, 0.029551945699495263, 0.06153106311103329, 0.004477685852180002, 0.10018362809205428, 0.04155496724706609, 0.06576103769475594, 0.06966405911953188, 0.014123490527708782, 0.04481279516767245, 0.041430245619267225, 0.03361037655849941, 0.011428512043494266, 0.05392305494751781, 0.031180974692688324, 0.024162625122698955, 0.026562227903923485, 0.06446578219765797, 0.015624837651557755, 0.048629052107571624, 0.012685443034570199, 0.07343762030359358, 0.045477432940970175, 0.02577258834207896, 0.047580089449184015, 0.01650226771744201, 0.02668986617209157, 0.06602088586078025, 0.03917514826753177, 0.047803442503209226, 0.047642047647968866, 0.02666901553311618, 0.09146401629550382, 0.07056264410493895, 0.0337402041623136, 0.053854847865295596, 0.03909615406882949, 0.08150990863214247, 0.016493760849698447, 0.042188390289084055, 0.07020323682809249, 0.025915099249687046, 0.052165890447213314, 0.037423048925120384, 0.06706485757604241, 0.04022703127702698, 0.14290151477325708, 0.06039919513568748, 0.04778017246280797, 0.022309901687549427, 0.006193464023453998, 0.05180688021937385, 0.05267189786536619, 0.04561511617794167, 0.018463617452653125, 0.031337608670582995, 0.07078582275426015, 0.026569400761218276, 0.0698455587553326, 0.09756532366736792, 0.03455731246504001, 0.03597099617763888, 0.02506440690922318, 0.004565026893033064, 0.07460510023520328, 0.012403464024828281, 0.054847247738507576, 0.03201523773896042, 0.05944808835920412, 0.03059305829083314, 0.02949768542748643, 0.05498090111359488, 0.05179781488550361, 0.03814739618974272, 0.022076594577811193, 0.03340841220051516, 0.023489469349442516, 0.03272364367148839, 0.045882927588536404, 0.02157086546503706, 0.055256861305679195, 0.06184358149766922, 0.035948613003711216, 0.038249857097980566, 0.10063194466056302, 0.06918552971910685, 0.06835562307969667, 0.10459795958013274, 0.08706943335710093, 0.03468503608019091, 0.03055053879506886, 0.0405368519568583, 0.07061463897116482, 0.12049853292410262, 0.062055865419097245, 0.0753070754581131, 0.04475777233892586, 0.025038980929821264, 0.06063771026674658, 0.04047916110721417, 0.01170637955510756, 0.03308681363705546, 0.022208233021956403, 0.028225176756677683, 0.07024313468718901, 0.04836684762267396, 0.017321094092039857, 0.03647603509307373, 0.02399633394816192, 0.015551802898698952, 0.058324113124399446, 0.02035757090197876, 0.029367278948484454, 0.041183607681887224, 0.03042939988517901, 0.02621291198011022, 0.054387873169616796, 0.0539364247379126, 0.06388243928086013, 0.04765945101098623, 0.04989026900148019, 0.037878453003941104, 0.057183432145393454, 0.023863196365709882, 0.06291955462074839, 0.0710242822242435, 0.019598400212998968, 0.04151693588937633, 0.04698375894804485, 0.05029277650464792, 0.01131334092860925, 0.07791436641127802, 0.035976692161057144, 0.037959922265144996, 0.033083908128901385, 0.040707215666770935, 0.0641869127866812, 0.04754192821565084, 0.045413444968289696, 0.08083263208391145, 0.05751111631980166, 0.02874166330002481, 0.029286741082614753, 0.034152611915487796, 0.032959798772935756, 0.027967044807155617, 0.04962568964401726, 0.04184006327704992, 0.0289478022386902, 0.0418402005743701, 0.05891167886147741, 0.05133511178428307, 0.04147310464759357, 0.03409129938518163, 0.016886457160580903, 0.0253568316475139, 0.05771258343884256, 0.024698895467736293, 0.024623068384244107, 0.025941354579117615, 0.05828025590744801, 0.02474336124578258, 0.05285719358653296, 0.017079276403819676, 0.04162354540312663, 0.04574702550598886, 0.05538464058190584, 0.03683780239953194, 0.036613239644793794, 0.016561274023842998, 0.02851080342225032, 0.058684288524091244, 0.01582268494530581, 0.028368292514642235, 0.0244275124714477, 0.024330643645953387, 0.1187525043496862, 0.025994410716521088, 0.14053572609554976, 0.05086960707558319, 0.052414261299418285, 0.027179533353773877, 0.05398159184551332, 0.022909944782441016, 0.020048152837262023, 0.014327294484246522, 0.036928526242263615, 0.03861542048980482, 0.0172088980616536, 0.02227761084213853, 0.0016469356251036515, 0.07056009853840806, 0.026221841872029472, 0.06489182691439055, 0.05923297685512807, 0.0721696535765659, 0.020259353223082144, 0.07332533336011693, 0.005281099674903089, 0.04788280035427306, 0.040101730774040334, 0.02016894293774385, 0.019112970694550313, 0.008107090416160645, 0.09007717977510765, 0.04486849706154317, 0.060008268847013824, 0.015782664631842636, 0.074350113136461, 0.07368427308392711, 0.0815819860144984, 0.019688725151354447, 0.03709035154315643, 0.028600241494132206, 0.026721051217464264, 0.02036331883573439, 0.11212787154363468, 0.03896184018230997, 0.044478858399088494, 0.06442819241783582, 0.01717610070045339, 0.02748090097156819, 0.01314624716542312, 0.058773283162736334, 0.06770111562218517, 0.04202016396448016, 0.02927962388639571, 0.022199028535396792, 0.043964045398752205, 0.034277467129868455, 0.05332133645424619, 0.027779196097981185, 0.1501256990013644, 0.04520711307122838, 0.05769852716184687, 0.023760870899423026, 0.007580564470117679, 0.009938713665178511, 0.02705993625568226, 0.026188268966507167, 0.052608945188694634, 0.0915641913888976, 0.04129375724005513, 0.007693816669416265, 0.07570904490421526, 0.02814064057020005, 0.005989069595671026, 0.042836734210141, 0.034145093959523365, 0.036042286883457564, 0.025790114159462973, 0.053140274685574695, 0.035025043616769835, 0.04793469503056258, 0.06435628572944552, 0.03794042975641787, 0.008975545133580454, 0.11398963804822415, 0.03974340703280177, 0.0399065125384368, 0.05224361186265014, 0.04943493542668875, 0.042101473663933575, 0.08249267542851157, 0.1021178653172683, 0.04272246573236771, 0.019185994315193966, 0.04088469286216423, 0.02811259480949957, 0.07665865254239179, 0.08522810559952632, 0.04853722617554013, 0.02488123187504243, 0.034323187137488276, 0.05078849404526409, 0.046511330001521856, 0.04831742429814767, 0.014800213248236105, 0.017909993839566596, 0.024979837326100096, 0.03419294393097516, 0.024159619424608536, 0.020938446177751757, 0.023679449877818115, 0.06556991982506588, 0.0473681357834721, 0.011798327941505704, 0.03669149169581942, 0.02481424748111749, 0.007823823780199746, 0.01839993190515088, 0.04723834528704174, 0.03856575596728362, 0.04074111697264016, 0.030415462351811584, 0.010847428038687212, 0.016237003728747368, 0.03002506298798835, 0.05268622873700224, 0.01542674452139181, 0.022105408461357, 0.06036376871634275, 0.029591129241453018, 0.011760782690544147, 0.014311990471469471, 0.03069444308493985, 0.017679158081591595, 0.022503457512357272, 0.02296515871421434, 0.0067692272932617925, 0.07681953531573527, 0.02496061013516737, 0.026940342868329026, 0.04405580824823119, 0.07111840881407261, 0.016015532019082457, 0.09305542582296766, 0.003890835823767702, 0.010803963232319802, 0.0077483274162659654, 0.17013739940011874, 0.04992978836526163, 0.07474486890714616, 0.020904956763843074, 0.01510259389760904, 0.04299864114727825, 0.02680226072698133, 0.05122101400047541, 0.08834703316097148, 0.044801833646488376, 0.02151565709937131, 0.03244949060899671, 0.04396000069391448, 0.016377969113818835, 0.03383192990440875, 0.08114026713883504, 0.07358542643487453, 0.06275649735471234, 0.058589271357050166, 0.028420497037586756, 0.04913748263788875, 0.06778079259674996, 0.041195841986336745, 0.11865879336255603, 0.0404134216660168, 0.03168367955368012, 0.03148029398289509, 0.06381189814419486, 0.13800602668197826, 0.05619277260848321, 0.1360355206998065, 0.15158755180891603, 0.1630497703445144, 0.12969073693966493, 0.34456910274457186, 0.14443577150814235, 0.23076773271895945, 0.14910920901456848, 0.12710515380604193, 0.1728533927234821, 0.10299615256371908, 0.20715231163194403, 0.08974521711934358, 0.10133713338291273, 0.14412973949220031, 0.20312115841079503, 0.24195549020078033, 0.1173841547279153, 0.13054140144959092, 0.16952766571193933, 0.15084090671734884, 0.11717478002537973, 0.14959810621803626, 0.15668027306674048, 0.11501444751047529, 0.21389424829976633, 0.09633315072278492, 0.07779635008773766, 0.1235808503406588, 0.10307870907126926, 0.13236408645752817, 0.11837046899017878, 0.1636745102587156, 0.13498931512003765, 0.2530985703924671, 0.1683193157077767, 0.21307929593604058, 0.1646702052676119, 0.08227766040363349, 0.193471294187475, 0.15211225021630526, 0.1113748959323857, 0.2569118735846132, 0.148231960774865, 0.16194894269574434, 0.09664460041676648, 0.20868610823526978, 0.21793694933876395, 0.10380571693531238, 0.18953636783408, 0.17236645478988066, 0.15481442474992946, 0.17374190676491708, 0.17337809113087133, 0.08396799821639434, 0.18002935219556093, 0.13088032545056194, 0.10381194355431944, 0.2991832990664989, 0.16627484728815034, 0.17047374072717503, 0.187426709162537, 0.16465787077322602, 0.1623738370835781, 0.1065976987592876, 0.14874428015900776, 0.10473748334334232, 0.15691209031501785, 0.1340089231962338, 0.2733567974064499, 0.17488858429715037, 0.131393906485755, 0.10603972245007753, 0.15001750871306285, 0.15111524902749807, 0.12241238335263915, 0.07683853429625742, 0.15051347116241232, 0.12494796799728647, 0.11445412601460703, 0.18052771920338273, 0.18340333364903927, 0.1397202690714039, 0.20254209026461467, 0.10844117132364772, 0.4018910159356892, 0.22117958549642935, 0.16732316056732088, 0.26146958058234304, 0.2198950169258751, 0.3050043492112309, 0.14048258832190186, 0.17090905486838892, 0.13103253993904218, 0.18105727125657722, 0.16910294943954796, 0.18023681215709075, 0.12467595603084192, 0.14537494454998523, 0.23028450552374125, 0.23737802723189816, 0.08212777625885792, 0.07464704642188735, 0.139942052483093, 0.13993332482641563, 0.09974337866879068, 0.17063509847503155, 0.14567069039912894, 0.1389554562047124, 0.3011777764186263, 0.23275677755009383, 0.10419444646686316, 0.1641171271330677, 0.1136940777359996, 0.1102281293424312, 0.17887602502014488, 0.10988714959239587, 0.11448270612163469, 0.17826727096689865, 0.12280561029911041, 0.1199601122061722, 0.11343171368935145, 0.09751234916620888, 0.18076866486808285, 0.16057539061876014, 0.10370603908086196, 0.15701836586231366, 0.16126820031786337, 0.07041044445941225, 0.126284264260903, 0.10474652270204388, 0.13648952211951837, 0.09040477118105628, 0.1148107428161893, 0.1690755196614191, 0.18338997499085963, 0.13640077610034496, 0.1274901206488721, 0.14067965821595863, 0.2136219691601582, 0.1419942095526494, 0.158106473099906, 0.20598577422788367, 0.11582806400838308, 0.11785779337515123, 0.09722945731482469, 0.31688093848060817, 0.201818214263767, 0.16732820717152208, 0.0840944008086808, 0.12310363454162143, 0.1211983039684128, 0.11043712554965168, 0.08987307432107627, 0.25523506512399763, 0.16574575536651537, 0.1505380214075558, 0.14399953710380942, 0.23180641292128712, 0.10891975267441012, 0.16240049502812326, 0.1495982546475716, 0.15370862471172586, 0.08700844366103411, 0.13523542613256723, 0.24449142365483567, 0.103923629358178, 0.1568490226054564, 0.15235891041811556, 0.16173202777281404, 0.15826437243958935, 0.10111414769198745, 0.14608200348448008, 0.22142526606330648, 0.22309561783913523, 0.1020919717848301], [0.0649880463606678, 0.05070136219728738, 0.08399780286708847, 0.0479698357230518, 0.02870942626032047, 0.022413190090446733, 0.0422115527180722, 0.027085668371000793, 0.04285640112357214, 0.008745441318751546, 0.04915490084385965, 0.021207248355494812, 0.05626055666652974, 0.06307891599135473, 0.031071153534867335, 0.024391648184973747, 0.0329227396287024, 0.089329310139874, 0.06597594139748253, 0.05290485431032721, 0.019563521127565764, 0.010167255259148078, 0.031029404017317574, 0.06831947306636721, 0.03050448667636374, 0.031528314648312517, 0.020076204164070077, 0.07087813108228147, 0.028038550735800527, 0.011641284854704281, 0.006895836759213125, 0.04607410854077898, 0.02633849078847561, 0.09718301371322013, 0.07484765636036173, 0.048322099828510545, 0.07657053734874353, 0.07269396606716327, 0.005967550096102059, 0.03208677706425078, 0.062066274040262215, 0.02152431981812697, 0.043540958140511066, 0.03000216958753299, 0.07912628614576533, 0.02780110986350337, 0.05374656480853446, 0.02782986808597343, 0.06428731794585474, 0.04042300279252231, 0.02089330318995053, 0.02876417634979589, 0.05102435970911756, 0.03811773996858392, 0.020120597582717892, 0.03986848118074704, 0.03376055014086887, 0.03871724686177913, 0.026003277525887825, 0.058762785483850166, 0.018351237740716897, 0.09149517165496945, 0.07513463744544424, 0.0355644068622496, 0.005797692901978735, 0.03181516585755162, 0.06713343202136457, 0.015208805434667738, 0.03529675872414373, 0.015269303457898786, 0.03347669349750504, 0.020838720083702356, 0.04022871966299135, 0.07910497908596881, 0.03268616150307935, 0.07845332147553563, 0.13422500691376626, 0.015320930961024715, 0.08430707064690068, 0.12619605258805677, 0.05948706966591999, 0.29902789334300905, 0.3132585750427097, 0.1372684951638803, 0.2677751937881112, 0.1574033623910509, 0.14202567661413923, 0.6266141042578965, 0.5513004236854613, 0.6442546576727182, 0.3432273888029158, 0.041240404243581, 0.10810243285959587, 0.15280026564141735, 0.17050664755515754, 0.1994384138379246, 0.23985067033208907, 0.0771802116651088, 0.05776815174613148, 0.06470052350778133, 0.06762828867067583, 0.04007512849057093, 0.0346502033789875, 0.01934455787704792, 0.04088805479113944, 0.044706905537168495, 0.024451827084703837, 0.04512937681283802, 0.030755640582356136, 0.026348847459303215, 0.04625902947736904, 0.022270614244916942, 0.024771887547103688, 0.069912441103952, 0.04139702708926052, 0.04522590425040107, 0.061010286954115145, 0.06332874516374432, 0.07359320414252579, 0.023382826439046767, 0.05774872603069525, 0.032627461332594976, 0.05700724999769591, 0.05479349027154967, 0.03172865370288491, 0.07441571156959981, 0.02052346502750879, 0.025063597968255635, 0.03792090756178368, 0.0176799317705445, 0.05681645496224519, 0.016475993834319524, 0.06609401709283702, 0.04046286725497339, 0.05367496982216835, 0.041481910229776986, 0.09599858312867582, 0.03646832788945176, 0.013544011417252477, 0.038091994865681045, 0.08522778647602536, 0.05566105348407291, 0.05421267436759081, 0.038010918942745775, 0.010875853222387377, 0.03008027506439248, 0.017357099386572372, 0.040536569940741174, 0.023343219872913323, 0.0833831487398129, 0.030347492756845895, 0.029628424017573707, 0.014610074085794622, 0.0689174808212556, 0.03147083531075623, 0.06877631691168062, 0.024444524351565633, 0.08476597024127841, 0.022406124844565056, 0.031636608837288804, 0.0530658446950838, 0.029316234031284694, 0.044520837982418016, 0.03184987981512677, 0.06014557358867023, 0.06209123617736623, 0.05046129968832247, 0.011527010810823413, 0.04659608697693329, 0.029727621331403498, 0.0697627202316653, 0.060453104742919095, 0.04218692454742268, 0.07068541759508662, 0.050262971853953786, 0.024368671292904764, 0.06028143114235718, 0.023021697379590478, 0.05460593099996913, 0.030920326862542424, 0.02756642050371738, 0.052352347629494034, 0.08123155872453935, 0.049447700366727076, 0.02622893309307983, 0.038353538839146495, 0.023481103489757515, 0.03287154628196731, 0.012443486193660647, 0.09128813471761532, 0.011930629680136917, 0.05658566558849998, 0.05388576944824308, 0.03656907814729493, 0.0609401168912882, 0.03396934967895504, 0.047161785332718864, 0.04130298584641423, 0.002285044402015046, 0.0383620809589047, 0.017737939888320398, 0.03885736805386841, 0.030861929117236286, 0.07811171089997515, 0.04125398183532525, 0.051273227800265886, 0.10355533857364208, 0.016329139507433865, 0.01913155778311193, 0.09376462956424803, 0.0868601848196704, 0.04586214003211353, 0.03642256706370972, 0.022871805813338142, 0.026149775621888693, 0.01914948250487214, 0.039251136768143624, 0.04915811063256115, 0.05600756594503764, 0.013708899932680652, 0.0701059857965447, 0.03831960784737021, 0.02711348221055232, 0.032197097316384315, 0.04994614158931654, 0.06772320935851894, 0.1063869362405967, 0.028813542157877237, 0.03317256137961522, 0.06247706391150132, 0.010517276223254157, 0.040869653239496984, 0.014477023705694592, 0.026008693348558154, 0.04736476643302012, 0.0717980602348689, 0.04092547758773435, 0.04133486851060297, 0.06890106451464817, 0.08660959123517387, 0.021417105454020202, 0.02391198700934183, 0.0669563704286702, 0.07684580734348856, 0.033497243566671386, 0.052054575717193075, 0.0404090615484165, 0.033029868645826355, 0.05764652858488262, 0.08607384224887937, 0.08186744569684379, 0.019616050340118818, 0.05717474901757669, 0.019236931620980613, 0.06323937574052252, 0.08039103195187636, 0.016752249030105304, 0.20360926893772557, 0.28170373232569546, 0.11462557697086595, 0.17257746221730486, 0.11404267192119732, 0.056072236693580635, 0.41063108132220805, 0.5165575817227364, 0.46686871675774455, 0.3662600606912747, 0.04289961638278328, 0.0653351414075587, 0.0979405757971108, 0.29121399857103825, 0.2919776982162148, 0.141128939576447, 0.0883213548513595, 0.062275786040117964, 0.04321679545682855, 0.08107442379696295, 0.07939875082229264, 0.055285081471083686, 0.03867533407174051, 0.06515158602269366, 0.08374486409593374, 0.022353391541400924, 0.02379390203714138, 0.01810340123483911, 0.04166306105616968, 0.0398513820982771, 0.050478680786909536, 0.02467274960508803, 0.06672665345831774, 0.023710698005743325, 0.027042544024880044, 0.03133450649329461, 0.07948420912725851, 0.04321920372603927, 0.026616840696078725, 0.03652544357464649, 0.060793164229835384, 0.03961944239563309, 0.04998829557735007, 0.020537961027002893, 0.046371323842322454, 0.04027685907203704, 0.008077914735622471, 0.021365676475397777, 0.013621468442579499, 0.07383920383290388, 0.044810004692408256, 0.007637046082891175, 0.036044387161382474, 0.009767806332092732, 0.008698544079379644, 0.061187118481029756, 0.051705714358831756, 0.03561404169886373, 0.038745058845961466, 0.021876216560485773, 0.0072636456116015324, 0.04546437856333796, 0.06801961571909487, 0.023479114533984102, 0.03858701107674278, 0.018241581710753962, 0.06623529232456349, 0.02349070131458575, 0.01983672980713891, 0.03790104768995661, 0.026962384654325433, 0.010276909433741821, 0.02227561632025754, 0.029402532818494365, 0.03314595167466905, 0.03388336073840037, 0.0582044566544937, 0.013853552864020457, 0.038723896504961886, 0.04374158292193897, 0.03128695709165186, 0.0574747436621692, 0.022015807116986252, 0.05843591767188627, 0.01608518072316656, 0.0024327851315320004, 0.031888386147329584, 0.03266583036747761, 0.020179518542136066, 0.03549688626662828, 0.09804792745853774, 0.016594611297477968, 0.05566047089814674, 0.010253586515318602, 0.030680874770041555, 0.16167958761798218, 0.1383827705285512, 0.21579466585535556, 0.21006528579164296, 0.13230628799647093, 0.12554008309962228, 0.16476684773806483, 0.09938368937582709, 0.08707874731044285, 0.12797281349776313, 0.2130253566429019, 0.1412757660727948, 0.09352074499474838, 0.22143409762065858, 0.12001128328847699, 0.10940416730591096, 0.14669860946014524, 0.14067137584788725, 0.3337918419856578, 0.2002010151045397, 0.19726455939235166, 0.13209649769123644, 0.12700772465905175, 0.12356139865005389, 0.12835812172852457, 0.1055252285732422, 0.06681040482362732, 0.15557721897494048, 0.09876899071969092, 0.11622283462202176, 0.17747191130183637, 0.09724324641865678, 0.12833918211981654, 0.24718804692383856, 0.26955343899317086, 0.12564426579046994, 0.18263363745063543, 0.21276700019370764, 0.08109290327411145, 0.11329706583637744, 0.2241740029421635, 0.12356668274151161, 0.11218379237107001, 0.13998386508319527, 0.3160630620550364, 0.10991667222697288, 0.15053714567329735, 0.10278276284225285, 0.15394355898024514, 0.16836693190271035, 0.15488669509068131, 0.1084556060959585, 0.11714955442585051, 0.12717050733044744, 0.04562277514196467, 0.1333748470642604, 0.091310072602937, 0.1458131827530451, 0.14342610927997157, 0.20995472063077614, 0.106091984489467, 0.12023363815387711, 0.12813497276511043, 0.18288507708348334, 0.15100725169759244, 0.14022365299751982, 0.1573228690540418, 0.1924200271605514, 0.12919372064061463, 0.16881861782167107, 0.15784163028001785, 0.16697009123163298, 0.15130627783946693, 0.2106961706886068, 0.1683815967408009, 0.07535530021414161, 0.13440401293337345, 0.25932269578333944, 0.20110316982027143, 0.21708414744352922, 0.2247618284309283, 0.41095810127444565, 0.522780935280025, 0.3318956249859184, 0.38820026151370257, 0.3355828224448487, 0.3223549306858331, 1.2809886876493692, 1.1595232179388404, 1.204818687401712, 0.5971211555879563, 0.13730934297200292, 0.23166807659436017, 0.3212010988499969, 0.3769596334313974, 0.45440802758093923, 0.5268281337339431, 0.2184233083971776, 0.13745328993536532, 0.21544872113736346, 0.25658446771558374, 0.15347939013736323, 0.20483765692915767, 0.18266486702486873, 0.15312020550481975, 0.21116554940817878, 0.06864634458906949, 0.10106796384206973, 0.12224123667692766, 0.08591589838033542, 0.3089666459709406, 0.11544955385033973, 0.10663016772014089, 0.2162703825160861, 0.17407513107173145, 0.1279321438050829, 0.10282847171765752, 0.15138637041673064, 0.18662455142475665, 0.10364754300098866, 0.19133986090309918, 0.15614408621331677, 0.1328849553829059, 0.32548486429732293, 0.12660381820751354, 0.18478025507647544, 0.1817701040999964, 0.16945551411481574, 0.13052234309725463, 0.12100034349714406, 0.18515172967454419, 0.11266083747614175, 0.1300728984642774, 0.1301558705745265, 0.11357953466358595, 0.08080923216766678, 0.21395562391262501, 0.11461178044555709, 0.08268869889434427, 0.12429939772118814, 0.1677459620987065, 0.08696051576407626, 0.07469204283552244, 0.24399157235166058, 0.1207114476710558, 0.13217519503086805, 0.1502780322334729, 0.22056360292481259, 0.15001790947280824, 0.1510850733029656, 0.11127516612759791, 0.08017746411496773, 0.08597321444540285, 0.18220798607217148, 0.09732595135574229, 0.1055476488545537, 0.09695244327303953, 0.21384513296652585, 0.14380740991327912, 0.21215201209997758, 0.14776918716961518, 0.11245680623687804, 0.14292809850303456, 0.11122737923869863, 0.18123223999282345, 0.1311035783146508, 0.24081822310108691, 0.10924128073384054, 0.11419133152230643, 0.17071435984689742, 0.20624022698029876, 0.1511591099551879, 0.11231412092456594, 0.13694358291104436, 0.12508121319115162, 0.12380100102745928], [0.04362882471468765, 0.028238503873581067, 0.027759011536545586, 0.02203726260631811, 0.05087559620733373, 0.04047268215799704, 0.025775423346203752, 0.020148051480646245, 0.02164950899896212, 0.05273229013255332, 0.015902068771538325, 0.02964874958706787, 0.03699465531099122, 0.04964776111592073, 0.015312757132051047, 0.031713038915768266, 0.009862287297437433, 0.05407720273069572, 0.0395440142165171, 0.021219200643827207, 0.023771795313223265, 0.0200350112572778, 0.04097505305253435, 0.0338988901785342, 0.018500170081097167, 0.026856411532207858, 0.08738341377465986, 0.06864960261736996, 0.022478474966192152, 0.038110136665636674, 0.12948001152835786, 0.02903133467043517, 0.009547491445118794, 0.07243193598696962, 0.06925951442099176, 0.02445660466037225, 0.040616948244860396, 0.017658283322816715, 0.02232209146313835, 0.012952694123669062, 0.04134528826398309, 0.03957100612751674, 0.03308468367322348, 0.10423238505609334, 0.04231079641613178, 0.02448856339469785, 0.028695204855466727, 0.03841389770968817, 0.05095411172078457, 0.020992392892367207, 0.06354408673360012, 0.022496264246001374, 0.015656534778827336, 0.008381470761378296, 0.03375980428245384, 0.06460360644268803, 0.038488368518301286, 0.03236945369280875, 0.07604170517879538, 0.07483609369955957, 0.015311419410863891, 0.06958128738915548, 0.0585346418665722, 0.05317169721820392, 0.011704729204211617, 0.0372357865126105, 0.034644288462004624, 0.02722898450883804, 0.027340145243215375, 0.05900092211959418, 0.05967639524897095, 0.18034167762380093, 0.2549655764596537, 1.026913421228528, 1.1373842996545136, 2.2075656428933144, 1.6234263125807047, 2.6649057772010565, 6.221712045371532, 7.981906794011593, 11.018500551581383, 10.135633125901222, 14.224574714899063, 16.409301683306694, 13.964358028024435, 15.89969202876091, 16.587394326925278, 19.202372208237648, 19.979189224541187, 12.727045621722937, 9.722814727574587, 10.162782669067383, 8.560633789747953, 14.042245298624039, 13.10422858223319, 12.76497708633542, 6.216220865026116, 10.402214471250772, 8.295250330120325, 3.670548889786005, 1.8364196084439754, 0.32756465894635767, 0.12550503888633102, 0.08061105647357181, 0.04621845255314838, 0.05914492845477071, 0.044473741290858015, 0.05183274777664337, 0.03600917596486397, 0.016184340929612517, 0.027863611685461365, 0.008636494039819809, 0.024688959965715185, 0.06896983933984302, 0.0750615655852016, 0.02088923065457493, 0.02567857864050893, 0.024180397704185452, 0.04805477452464402, 0.05514485637831967, 0.011934968460991513, 0.00893323622221942, 0.04119391611311585, 0.01648379195103189, 0.031142093575908802, 0.031620303852832876, 0.02685750434466172, 0.02323088097909931, 0.0207655202029855, 0.02553957066993462, 0.04703682250692509, 0.004389172217997839, 0.025480521690042224, 0.015608185713062994, 0.03057699079363374, 0.03494498443615157, 0.05643610056722537, 0.038068780486355536, 0.03458360304648522, 0.03021581349457847, 0.09297278025769629, 0.04963688494171947, 0.0328298078966327, 0.021432740650197957, 0.02249847584607778, 0.0372105794667732, 0.01965634339285316, 0.05844012564921286, 0.024373890446440782, 0.033072193327825516, 0.020230787959008012, 0.019227203920308966, 0.04547631229797844, 0.10968348200549372, 0.027179598291695584, 0.05534542549867183, 0.027720482939912472, 0.06415741983801126, 0.03081309394474374, 0.011349836968292948, 0.07276541262399405, 0.07300284793018363, 0.060367141777533107, 0.05162289809959475, 0.067717487399932, 0.037874404588364996, 0.0020752297450599144, 0.06881117558805272, 0.06260092835873365, 0.03752590317162685, 0.03942743023799267, 0.048782724916236475, 0.05370126411435194, 0.06602271896554157, 0.023089479582267813, 0.01005129468467203, 0.040435916162095964, 0.0498372611036757, 0.03361729708558414, 0.059490977073437534, 0.04332543845521286, 0.051836525308317505, 0.020561294149956666, 0.01531207250081934, 0.01591019899933599, 0.038750417152186856, 0.00878146238392219, 0.058144023569184355, 0.05154686135938391, 0.18171196425100788, 0.05223170039243996, 0.03511172275466379, 0.056320481380680576, 0.07536833974882029, 0.08360180770978332, 0.01627008125069551, 0.04739559524750803, 0.023440224140358623, 0.03243036175263114, 0.01783953619451495, 0.018839956828742288, 0.0965234448085539, 0.12410696625011042, 0.012949725532962475, 0.024392566592723597, 0.03577518793463241, 0.08249012986198068, 0.08455516319372691, 0.030702480544277932, 0.043469392840052024, 0.08353168217581697, 0.012523385812528431, 0.06256143868085928, 0.029151419730624184, 0.05337772112397943, 0.009649564581195591, 0.028680248724413104, 0.03946925397031009, 0.06393406307324767, 0.03444528156251181, 0.045959391063661315, 0.034923369385069236, 0.02179138537030667, 0.05722373447497375, 0.03879822259477805, 0.07017539886874147, 0.02587783044873504, 0.03206764820788521, 0.06115566997323185, 0.03271103087172378, 0.012721442762995139, 0.015183555715339025, 0.03290080545411911, 0.049547263188287616, 0.02456350175634725, 0.03887074155500159, 0.05142018788319547, 0.03733939032827038, 0.06666532979579642, 0.0025386230436197366, 0.025358321508974768, 0.025248574565921444, 0.054887364531168714, 0.0742869934765622, 0.03463193170318846, 0.14945015165721998, 0.03934709275199566, 0.0689344092097599, 0.16497132426593453, 0.8542167255654931, 1.0705159627832472, 1.5470866276882589, 2.2228218242526054, 3.400853374041617, 7.216838272288442, 9.732445310801268, 13.497445732355118, 12.518180329352617, 16.49073701351881, 18.74709963798523, 17.574892938137054, 17.926955446600914, 17.81891394406557, 21.196822486817837, 20.976704098284245, 15.041604973375797, 11.40894290059805, 10.706393849104643, 10.151313934475183, 16.842373944818974, 15.824997536838055, 15.553701594471931, 8.891209401190281, 12.899872697889805, 11.981649119406939, 6.016751043498516, 2.164194770157337, 0.16177263809368014, 0.13554456032579765, 0.08317587431520224, 0.024612177367089316, 0.11417452187743038, 0.07905135149485432, 0.05272617854643613, 0.04486566947889514, 0.01945542546309298, 0.02576154889538884, 0.032821514396346174, 0.004914795063086785, 0.050942942398251034, 0.045548512134701014, 0.012468861150409793, 0.028953266300959513, 0.01380920861265622, 0.05365774828533176, 0.012293046365812188, 0.022077904468460474, 0.031000395320006646, 0.019660616308101453, 0.03318375667731743, 0.035905071199522354, 0.06317894265521318, 0.007714090752415359, 0.061306314819375984, 0.0382839550729841, 0.04808945508557372, 0.06409008477930911, 0.029844535565644037, 0.016412224795203656, 0.036027473615831695, 0.04632283562386874, 0.02759318049356807, 0.07067638565786183, 0.02120541153999511, 0.03546376421581954, 0.020071278158866335, 0.026140524751099292, 0.08445356317679398, 0.07517500285757706, 0.022175598933245055, 0.030731492952327244, 0.058783565618796274, 0.049079647069447674, 0.018696174993237946, 0.060037487201043405, 0.04764762117702048, 0.02786599212413421, 0.03528253917465918, 0.058280285593355075, 0.06101047249103431, 0.011614566610660404, 0.04762008749821689, 0.032674706453690305, 0.06578644883120432, 0.03794708682107739, 0.02685603489226196, 0.0817036240187008, 0.07463182497303933, 0.041391665072296746, 0.04682176666392479, 0.04649213806260377, 0.06415790223400109, 0.012945798644068418, 0.02820945064740954, 0.020828012748097535, 0.04836611660721246, 0.00603060806497524, 0.022255873336689547, 0.08265904267318547, 0.041625437879702076, 0.004143342757743085, 0.06978282501222566, 0.09523192231426947, 0.16720414976589382, 0.07242484105518088, 0.14677978557301685, 0.10785911974380724, 0.1367972610751167, 0.18589218525448814, 0.08973966585472226, 0.14868008438497782, 0.11822924570878968, 0.18053916312055662, 0.1308629591949284, 0.19054136937484145, 0.22092778963269666, 0.13164184318156913, 0.30257497332058847, 0.14333708124468103, 0.13182960654376075, 0.1441602862905711, 0.06293991915299557, 0.09280279875383712, 0.09328507600002922, 0.10591493031824939, 0.10124780848855153, 0.15705382567830384, 0.2180693781701848, 0.25930895120836794, 0.13398432842222974, 0.21508511330466717, 0.10479574935743585, 0.20912005682475865, 0.16951314930338413, 0.08080307976342738, 0.1810432446654886, 0.17036568402545527, 0.19635560660390183, 0.1254183115088381, 0.17719243332976475, 0.10917791616520844, 0.11516712955199182, 0.13238612824352458, 0.1553478359710425, 0.10423179875942878, 0.18091549136443064, 0.23316209408221766, 0.12245957652339712, 0.12774724513292313, 0.12423576597939245, 0.15878951613558456, 0.22804583190008998, 0.16697234736056998, 0.08480799806420691, 0.15556259866571054, 0.15965122380293906, 0.11525686262757517, 0.13377391471294686, 0.1262940457672812, 0.17517517204396427, 0.1153747973148711, 0.12217203140608035, 0.18826974439434707, 0.2668213559081778, 0.168359792442061, 0.16567200073041022, 0.1349140761885792, 0.17800119618186727, 0.16805206832941622, 0.1504286882118322, 0.1846192090306431, 0.19550365075701848, 0.19118104130029678, 0.32190922647714615, 0.5341990850865841, 1.9561271974816918, 2.8213286586105824, 3.1307880906388164, 3.860739846713841, 5.6778643280267715, 10.571113508194685, 12.204183228313923, 18.303868621587753, 18.280042000114918, 22.825928069651127, 24.826079942286015, 22.90875032544136, 23.464668095111847, 24.645570628345013, 28.425755985081196, 30.05543153733015, 22.1383036673069, 16.78766068071127, 16.689506247639656, 16.620929427444935, 23.989045657217503, 22.754471004009247, 21.29785716533661, 14.22473905608058, 17.745995856821537, 15.146440397948027, 9.023246616125107, 3.14336565323174, 0.3332945436704904, 0.23311719414778054, 0.227938576717861, 0.1828136676340364, 0.1453313953243196, 0.212841066531837, 0.13670945016201586, 0.24776567530352622, 0.14703889901284128, 0.07349870647885837, 0.1192734252254013, 0.13273648131871596, 0.15501804038649425, 0.16398872074205428, 0.06810046528698877, 0.11132377680041827, 0.10479487362317741, 0.1206679578172043, 0.10179242613958195, 0.17288889706833288, 0.1154751431022305, 0.08510720974300057, 0.08972495648777112, 0.1092217028781306, 0.11964686651481315, 0.09632451212382875, 0.1901854798779823, 0.11654310103040189, 0.1828031736658886, 0.20181249972665682, 0.055842905640020035, 0.08226053905673325, 0.06364790577208623, 0.1264977059327066, 0.07616317991050892, 0.18596979905851185, 0.07544105537817813, 0.0778394540247973, 0.17205111624207348, 0.18304181867279112, 0.16981352615403011, 0.14685986330732703, 0.17662976664723828, 0.10043475602287799, 0.08994581221486442, 0.0974928900541272, 0.17412541899830103, 0.24546109896618873, 0.20340639544883743, 0.1222036914259661, 0.10645964444847777, 0.22262609069002792, 0.2048726417706348, 0.09991710059694014, 0.2779135841410607, 0.15702062199125066, 0.14290043123764917, 0.1003020080679562, 0.12129948838264681, 0.20256097050150856, 0.1917406206484884, 0.18811766349244863, 0.17980743519729003, 0.12577935151057318, 0.19721945165656507, 0.1835585612570867, 0.14253314235247672, 0.10794327186886221, 0.14524631551466882, 0.1184477265633177, 0.145909350248985, 0.15383894584374502, 0.10375034529715776, 0.14607324614189565, 0.11881552010891028], [0.046765745646553114, 0.055339614482363686, 0.026999065303243697, 0.057835679763229564, 0.030272650874394458, 0.01733988156047417, 0.05951595405349508, 0.08314445178257301, 0.046213339155656286, 0.040179526404244825, 0.002444242732053681, 0.07843589584808797, 0.08040770801017061, 0.015773654959048145, 0.04714854541816749, 0.060566542015294544, 0.03803676794632338, 0.06352954063913785, 0.034313661672058515, 0.043965284785372205, 0.017998057082877494, 0.01321489582551294, 0.011676924641506048, 0.006159546019262052, 0.06330685180728324, 0.06770838866941631, 0.013750196740147658, 0.020218362551531754, 0.049838893828564323, 0.03753251570742577, 0.02246111984277377, 0.029630717253894545, 0.04195702575088944, 0.030728153287782334, 0.08621838293038309, 0.03684429990244098, 0.035217308104620315, 0.0404171843547374, 0.035800369005301036, 0.03444659887463786, 0.01797023396648001, 0.01965290168300271, 0.029998861464264337, 0.010518370891077211, 0.01617760779481614, 0.06512008927529678, 0.053824976421310566, 0.052963461712352, 0.0652520357107278, 0.040190268991864286, 0.08921519009163603, 0.05938202237302903, 0.01945279826031765, 0.028908316271554213, 0.03503062456729822, 0.05177931314392481, 0.0641859183087945, 0.04019803927803878, 0.012244365188962547, 0.06332234785077162, 0.069433021126315, 0.02529185476305429, 0.09344800710096024, 0.07047280712868087, 0.0600437954562949, 0.08405949760344811, 0.06460722812335007, 0.33200935169588774, 0.7520869933068752, 1.0796906892210245, 2.5708577362820506, 5.968297943472862, 8.338540457189083, 13.288031369447708, 18.10251172631979, 23.814243637025356, 25.440071895718575, 40.55162161588669, 47.677865624427795, 61.24648913741112, 61.3247649371624, 56.063202470541, 70.22210910916328, 62.09195137023926, 71.69477328658104, 75.78118801116943, 66.84983566403389, 68.04090455174446, 62.224188074469566, 50.62254801392555, 51.87137380242348, 50.86503580212593, 58.60115848481655, 63.978139758110046, 60.690635964274406, 61.16797775030136, 52.983574122190475, 53.472007513046265, 46.04567460715771, 35.84631510078907, 29.06357455998659, 11.169665940105915, 2.84262509085238, 0.15444735850906, 0.07190534510300495, 0.012887684770248597, 0.0999495992437005, 0.06980025806115009, 0.044581924157682806, 0.023962840823514853, 0.09224741996149532, 0.06405702952179126, 0.027451816204120405, 0.018458854719938245, 0.0551444741722662, 0.002925748376583215, 0.04019192398118321, 0.01081789148884127, 0.07515116507420316, 0.0654997349192854, 0.023392279545078054, 0.030436971646849997, 0.025633149925852194, 0.033129513103631325, 0.06123865692643449, 0.03951807244447991, 0.0208017054683296, 0.02787618366710376, 0.01925870808918262, 0.09118488713284023, 0.013769297765975352, 0.0671407941263169, 0.038370500624296255, 0.015897009179752786, 0.08915920989238657, 0.01963302696822211, 0.0161071705588256, 0.020078922279935796, 0.05914446090173442, 0.044413367577362806, 0.007011984262135229, 0.04063426997163333, 0.09503299705102108, 0.01774510346876923, 0.06431851783418097, 0.04527060751570389, 0.029901226371293887, 0.03166175651131198, 0.058396958629600704, 0.04275763982150238, 0.06259985224460252, 0.03217533383576665, 0.018928669451270252, 0.040639279468450695, 0.027818941816804, 0.05583582184044644, 0.07270992966368794, 0.02642695850227028, 0.029059096559649333, 0.04168174462392926, 0.019843334921461064, 0.018551118519098964, 0.04557784181088209, 0.0324989361979533, 0.0149901947042963, 0.028636248644033913, 0.013180190217099153, 0.041398021567147225, 0.026814957018359564, 0.048069138792925514, 0.0983879721025005, 0.10813556975335814, 0.007620025853611878, 0.05982746683002915, 0.04978833872883115, 0.054769396447227336, 0.06490051004220732, 0.018074208855978213, 0.04526726785115898, 0.0639626283373218, 0.06331137148663402, 0.054887193837203085, 0.02326685473235557, 0.028518352919491008, 0.022428841984947212, 0.03754797093279194, 0.008578796696383506, 0.0874819784075953, 0.03861334247631021, 0.05781923377071507, 0.07873693321016617, 0.0439754670514958, 0.02037606707744999, 0.08061009910306893, 0.03476047168078367, 0.06045561320206616, 0.04022284927486908, 0.016717985927243717, 0.07007717562373728, 0.04172013963398058, 0.0716416303475853, 0.03582774312235415, 0.036271413846407086, 0.04623917331628036, 0.0412991192570189, 0.04770479252329096, 0.009074166355276247, 0.061662775769946165, 0.046326397932716645, 0.029490239830920473, 0.06943069078261033, 0.04160261683864519, 0.059629651077557355, 0.07236977369757369, 0.046793631845503114, 0.0275130563750281, 0.030515574362652842, 0.01869156811153516, 0.013369592797971563, 0.03909736005880404, 0.017068431770894676, 0.02608684892038582, 0.06120590966020245, 0.024501101979694795, 0.021311063683242537, 0.019864339556079358, 0.09952315376722254, 0.02883275636122562, 0.01455912472010823, 0.04764340577821713, 0.031010328966658562, 0.0314117269590497, 0.026509151357458904, 0.022127810188976582, 0.0238464164067409, 0.03477306592685636, 0.09025999301229604, 0.09482635345193557, 0.1213619252666831, 0.022203268053999636, 0.062447830714518204, 0.09323224992840551, 0.1054026851488743, 0.2795125264674425, 1.177826242055744, 1.256107147783041, 3.104117796756327, 6.400388432666659, 8.401023354381323, 14.363802094012499, 19.626096971333027, 26.170026026666164, 28.77736061811447, 47.81543344259262, 53.20493504405022, 68.29213187098503, 67.71832466125488, 63.86175200343132, 80.36274656653404, 70.27817890048027, 79.42000195384026, 83.35928857326508, 75.61512172222137, 76.73655554652214, 71.2230134010315, 58.70372258126736, 58.275819942355156, 57.76370622217655, 66.92698672413826, 74.41614165902138, 69.91544276475906, 69.0433743596077, 63.7539441883564, 64.37875986099243, 56.43842853605747, 46.56949169933796, 38.390981554985046, 16.16512108594179, 5.177599797025323, 0.4055834678001702, 0.04723665690107737, 0.06730753244482912, 0.03385849508049432, 0.018956462881760672, 0.0486168623319827, 0.01277713074159692, 0.05001142832043115, 0.05052720611274708, 0.06155684532132, 0.022595843765884638, 0.07797075479174964, 0.016914198640733957, 0.1311808655736968, 0.0477114236127818, 0.016972973025985993, 0.02988185631693341, 0.029964134519104846, 0.019482090829114895, 0.03705964518303517, 0.03693877901241649, 0.11086951562901959, 0.014209484106686432, 0.013725178014283301, 0.0037322228627090226, 0.06465825077611953, 0.04830308229429647, 0.025434909293835517, 0.02462315373122692, 0.06333605531835929, 0.033018369067576714, 0.07221037521958351, 0.013788210471830098, 0.04984742481610738, 0.07840338235837407, 0.05418917797214817, 0.027730273723136634, 0.02143486875866074, 0.0717026942584198, 0.03880739925079979, 0.053110332737560384, 0.03291115470346995, 0.04647463822038844, 0.010009074831032194, 0.0072151968197431415, 0.03570508837583475, 0.04621856758603826, 0.07873990180087276, 0.07243589905556291, 0.07950861836434342, 0.02800319667585427, 0.056193284690380096, 0.030021131460671313, 0.059349686998757534, 0.045019331155344844, 0.03837658623524476, 0.019083477745880373, 0.03222178856958635, 0.038767872465541586, 0.053262432193150744, 0.017581797583261505, 0.10916640545474365, 0.01212539891639608, 0.04721868950582575, 0.037799065466970205, 0.030495974242512602, 0.04038375431264285, 0.08530560065992177, 0.03440065622271504, 0.020609079183486756, 0.09965596851543523, 0.009628174029785441, 0.04782170304679312, 0.08668603244586848, 0.1344352276646532, 0.12516114249592647, 0.1325869682477787, 0.1876751653617248, 0.16200838872464374, 0.15146514197112992, 0.1637967865099199, 0.16787325526820496, 0.20195714430883527, 0.07564871571958065, 0.12276040608412586, 0.12518370378529653, 0.2124350078520365, 0.21185579127632082, 0.1497455412754789, 0.1511305817984976, 0.15499285189434886, 0.14977221406297758, 0.11022803286323324, 0.12989211129024625, 0.08665466928505339, 0.21605867746984586, 0.10814570006914437, 0.1815274663385935, 0.13094204245135188, 0.16350893711205572, 0.14643342525232583, 0.17132919951109216, 0.13636179850436747, 0.1448205899214372, 0.11985782941337675, 0.08550969127099961, 0.08453025671769865, 0.15303102903999388, 0.13026547094341367, 0.14857891481369734, 0.16502671816851944, 0.17342095758067444, 0.09761502529727295, 0.09071749736904167, 0.12269513419596478, 0.07960394723340869, 0.15050389745738357, 0.09193056001095101, 0.18420905369566754, 0.2013605911633931, 0.1954082105658017, 0.1283119453000836, 0.11080274460255168, 0.20894655754091218, 0.0936092683696188, 0.10502899895072915, 0.16526564519153908, 0.1019690053362865, 0.13918308774009347, 0.2785790531197563, 0.06463298806920648, 0.10747592663392425, 0.15332062990637496, 0.2685422182548791, 0.13969847961561754, 0.18947442818898708, 0.318674145382829, 0.26904393977019936, 0.3633907693438232, 0.43468414689414203, 1.1527638556435704, 2.4449533922597766, 2.7715009823441505, 6.2507538869977, 9.924314115196466, 15.046702399849892, 21.30618441849947, 27.389925867319107, 33.68537485599518, 38.60011473298073, 60.887024626135826, 66.81673184037209, 83.73826503753662, 81.41343578696251, 79.65150833129883, 93.51872742176056, 83.82043942809105, 94.95636507868767, 94.92154374718666, 86.44635692238808, 91.27946957945824, 83.3265571296215, 74.74696710705757, 72.11753100156784, 69.32786509394646, 82.87200272083282, 89.75577414035797, 82.37397864460945, 84.92849037051201, 79.81692105531693, 77.54346504807472, 68.94082546234131, 59.412392154335976, 46.839881390333176, 20.459266863763332, 5.851281797513366, 0.4929442534921691, 0.1410309167113155, 0.1480007075588219, 0.20669666264439002, 0.13721742056077346, 0.21258555992972106, 0.09324718193965964, 0.15757013781694695, 0.16361800313461572, 0.1347045085276477, 0.13834918092470616, 0.20345567405456677, 0.08336695507750846, 0.169398843718227, 0.12875904474640265, 0.1603451170376502, 0.1427245422382839, 0.10170237394049764, 0.11443862254964188, 0.09770266551640816, 0.16307988669723272, 0.26012860878836364, 0.14413539465749636, 0.12412469615810551, 0.11402459320379421, 0.14118011808022857, 0.26676400273572654, 0.1611678025801666, 0.2091662777820602, 0.1599188570980914, 0.08941307634813711, 0.1932075497461483, 0.10606868847389705, 0.10968418704578653, 0.15542697859928012, 0.19811216625384986, 0.13640971155837178, 0.20393263752339408, 0.1402298573520966, 0.17437973816413432, 0.16350706689991057, 0.15301842737244442, 0.10609061893774197, 0.12864796008216217, 0.1067684224108234, 0.09406885816133581, 0.13513097626855597, 0.14785263425437734, 0.23252399550983682, 0.18901683477452025, 0.09843935098615475, 0.13154171261703596, 0.08776124857831746, 0.13498076557880268, 0.12602743663592264, 0.15857687598327175, 0.08929155708756298, 0.13832320575602353, 0.15282051143003628, 0.10303728238795884, 0.10484056023415178, 0.2445776018430479, 0.09936736212694086, 0.11230379022890702, 0.13791103177936748, 0.15945737482979894, 0.17133893648860976, 0.18660909991012886, 0.19013327721040696, 0.23215664725285023, 0.1219852476788219, 0.1359412827878259, 0.12683521985309198], [0.01557794133987045, 0.024263390223495662, 0.012014484018436633, 0.041691214428283274, 0.08992584102088585, 0.05044238605478313, 0.051697532180696726, 0.01943146336998325, 0.018333164589421358, 0.07299934499314986, 0.032630741625325754, 0.04496282403124496, 0.05972481296339538, 0.03292208282800857, 0.03473079690593295, 0.046204982572817244, 0.0023223375546876923, 0.008409279962506844, 0.06569717588718049, 0.029762285194010474, 0.01708446772681782, 0.03436831713770516, 0.007132341597753111, 0.012488390766520752, 0.06408950590412132, 0.03847475010843482, 0.11125207049190067, 0.055587031674804166, 0.017712551016302314, 0.024753740181040484, 0.08253843625425361, 0.05349648330593482, 0.030147205652610864, 0.04322320019127801, 0.09358606883324683, 0.034459898161003366, 0.00957683039814583, 0.025323112167825457, 0.0077957928624527995, 0.0143098373155226, 0.05516534707567189, 0.07276329008163884, 0.05827901652082801, 0.03452843920968007, 0.021903700144321192, 0.04979781966540031, 0.055153717621578835, 0.01106455818444374, 0.0314917119249003, 0.020451231794140767, 0.09648555816966109, 0.0918506455491297, 0.04523227929894347, 0.03894744993885979, 0.016617189285170753, 0.07526282861363143, 0.038193932559806854, 0.044515064073493704, 0.05471717522596009, 0.06371314797434025, 0.014850836068944773, 0.25258144189137965, 1.0357739520259202, 2.6581302657723427, 5.590457143262029, 6.8164219334721565, 11.916136834770441, 13.62430952489376, 18.88780988752842, 24.85028464347124, 36.83880664408207, 43.10707949101925, 47.77827523648739, 65.28799787163734, 64.01964113116264, 71.55448481440544, 74.15335536003113, 76.00320249795914, 76.49580806493759, 81.55182436108589, 82.34861120581627, 80.2718098461628, 70.70059463381767, 77.12012216448784, 63.74141626060009, 69.73935261368752, 74.15666118264198, 72.4194324016571, 69.229716360569, 71.78240418434143, 69.82090383768082, 70.23996815085411, 80.94177469611168, 79.04351055622101, 74.55326870083809, 69.79999735951424, 70.48338308930397, 68.49605932831764, 70.83374708890915, 78.99979010224342, 68.78969237208366, 62.687915191054344, 46.96410432457924, 17.85168718546629, 5.727824047207832, 1.560983075760305, 0.44832054642029107, 0.06372740463120863, 0.044312357567832805, 0.013928969910921296, 0.022393513900169637, 0.051026842193095945, 0.023040121195663232, 0.011723450807039626, 0.01015247724353685, 0.033550592852407135, 0.06814645617851056, 0.05576331401243806, 0.015435290351888398, 0.024032730725593865, 0.06863057395094074, 0.03611447929870337, 0.03355141663632821, 0.021505680779227987, 0.03809911206190009, 0.016394860394939315, 0.05726414812670555, 0.04695949442975689, 0.049227456911467016, 0.010374483299528947, 0.018068768913508393, 0.06666175264399499, 0.025409106674487703, 0.06140622645034455, 0.027410139045969117, 0.03871864209941123, 0.005070072766102385, 0.05716111576475669, 0.006067002987037995, 0.03945516058593057, 0.09260190679924563, 0.01085346169929835, 0.040330616538994946, 0.012628921995201381, 0.07154063889174722, 0.021702006670238916, 0.0196743274864275, 0.02536431435146369, 0.03618589988036547, 0.026554121795925312, 0.024372309671889525, 0.03629366714449134, 0.052407307375688106, 0.016742519474064466, 0.022244269857765175, 0.017806421565182973, 0.06466490041930228, 0.09707879391498864, 0.03769461931369733, 0.033040436828741804, 0.02041421346802963, 0.015997176851669792, 0.004789740396518027, 0.011204853781237034, 0.00725986158613523, 0.024722184061829466, 0.012347582160145976, 0.013712966901948676, 0.05372142455598805, 0.038593096687691286, 0.05498227779753506, 0.08117587538436055, 0.029077895160298795, 0.027785086895164568, 0.005898432491449057, 0.04481978990952484, 0.014185220516083064, 0.08347682261955924, 0.04337557795224711, 0.03296424423751887, 0.05248066867352463, 0.034912166665890254, 0.04524171199591365, 0.034289701434317976, 0.05651608924381435, 0.021255081628623884, 0.05792097108496819, 0.014879957016091794, 0.08859610534273088, 0.013259440456749871, 0.03347977341036312, 0.024329806874447968, 0.03556928648322355, 0.05435262486571446, 0.010716627293732017, 0.0768232237896882, 0.03392083919607103, 0.032644100283505395, 0.023646741574339103, 0.017424536490580067, 0.074934086878784, 0.029597084976558108, 0.042386796048958786, 0.03322304597531911, 0.027423588617239147, 0.014816831790085416, 0.06099130281654652, 0.07128950353944674, 0.02436283615679713, 0.07242080377181992, 0.08972457799245603, 0.07416366337565705, 0.023889305120974313, 0.03928948353859596, 0.0212206849391805, 0.02796424876578385, 0.02984434260724811, 0.03313360233732965, 0.0437485034490237, 0.02862883273337502, 0.05023862569942139, 0.024411669473920483, 0.018234789204143453, 0.030429203216044698, 0.07035646805888973, 0.033718073318596, 0.036993571775383316, 0.015884016029303893, 0.0413530993682798, 0.04525331547483802, 0.058195113015244715, 0.04701606463640928, 0.013533592591556953, 0.051867843940271996, 0.02152184290025616, 0.040422687379759736, 0.020274374292057473, 0.3145425202092156, 1.25756781315431, 3.0378348659723997, 6.148402579128742, 6.95038422010839, 11.94682588800788, 15.577211882919073, 21.28646157681942, 28.148175179958344, 41.716232523322105, 47.11787447333336, 55.209897458553314, 75.14258667826653, 74.05455306172371, 85.56294992566109, 89.64265421032906, 85.98802551627159, 87.70188555121422, 93.43552708625793, 91.45343944430351, 91.80119678378105, 80.83896741271019, 85.73381155729294, 74.24856305122375, 80.66483035683632, 85.4028645157814, 82.68130615353584, 80.7873585820198, 82.80336320400238, 83.35668191313744, 81.51194170117378, 90.03996849060059, 89.40667167305946, 85.27035042643547, 82.21654549241066, 80.15929028391838, 78.39629888534546, 81.83484837412834, 89.3893750011921, 81.59240618348122, 76.46920949220657, 59.86622080206871, 24.692463912069798, 9.359404128044844, 1.5967659931629896, 0.6681348325219005, 0.02519093937735306, 0.016256730013992637, 0.022513294679811224, 0.04539191155345179, 0.010279505095240893, 0.03686225616547745, 0.035154307188349776, 0.034897720761364326, 0.03827467451628763, 0.04130390610953327, 0.028412557912815828, 0.02762005551630864, 0.0504669140354963, 0.04398437653435394, 0.03260621364461258, 0.009117115369008388, 0.03211763556464575, 0.03489581715257373, 0.06518532405607402, 0.05121819755004253, 0.09171117373625748, 0.028442967413866427, 0.03925212753529195, 0.07779346313327551, 0.09730357560329139, 0.03756601254281122, 0.022777469566790387, 0.050115759440814145, 0.040848535427358, 0.026351157393946778, 0.01409912581948447, 0.02243210929009365, 0.018419277839711867, 0.15622701379470527, 0.02479385326296324, 0.08299108696519397, 0.023795299130142666, 0.06084577507863287, 0.02618648224597564, 0.05079001173726283, 0.03773335942241829, 0.045023327620583586, 0.03114995291980449, 0.030786259740125388, 0.04668243956984952, 0.03368307363416534, 0.024891221182770096, 0.043473021942190826, 0.0842492350784596, 0.043087572703370824, 0.030665371305076405, 0.022052990570955444, 0.015466371496586362, 0.042340697546023875, 0.043472435645526275, 0.007300747893168591, 0.02246960259071784, 0.031073964419192635, 0.0723223653039895, 0.044243341544643044, 0.024474280762660783, 0.0453619213658385, 0.016356726991944015, 0.05782457723398693, 0.06880857807118446, 0.03970722733356524, 0.01975356659386307, 0.039503626539953984, 0.013543989152822178, 0.1712648553075269, 0.2041564098908566, 0.16611531522357836, 0.157265946327243, 0.16754721495090052, 0.1202226840541698, 0.21560185588896275, 0.10181382225709967, 0.10936225822661072, 0.12796335853636265, 0.11953040127991699, 0.2398660031030886, 0.12992443924304098, 0.15876590099651366, 0.10551385144935921, 0.10458341348567046, 0.12934884434798732, 0.14487712673144415, 0.1539431285345927, 0.14929450844647363, 0.12583244475536048, 0.12067713818396442, 0.10139557751244865, 0.13107129489071667, 0.1930942089529708, 0.11857318662805483, 0.222677729325369, 0.159717898350209, 0.0976625079056248, 0.10378440987551585, 0.16407626448199153, 0.1905268381233327, 0.08020621491596103, 0.24876592709915712, 0.20927878736983985, 0.15427130623720586, 0.11804606881923974, 0.0747816200600937, 0.1556208572583273, 0.09868364373687655, 0.11249614006374031, 0.17888672678964213, 0.29805734229739755, 0.09987504308810458, 0.12601234135217965, 0.15238798776408657, 0.15664338832721114, 0.1355896532186307, 0.16955564467934892, 0.20782239676918834, 0.1649909614934586, 0.17893748969072476, 0.12830808613216504, 0.13273116754135117, 0.14471633301582187, 0.17783317394787446, 0.12985608744202182, 0.1182653140858747, 0.1311275496846065, 0.18134302779799327, 0.10195410301093943, 0.41036996408365667, 1.8456731806509197, 5.243524834513664, 10.51610006019473, 12.158022355288267, 18.43859039247036, 22.715340703725815, 30.80034926533699, 41.397817209362984, 57.200147062540054, 58.70818354189396, 66.28298968076706, 85.8342857658863, 88.04931610822678, 100.3871400654316, 103.96464809775352, 102.70747795701027, 101.96551457047462, 105.83440616726875, 103.40588048100471, 103.94202411174774, 95.76922506093979, 100.21228864789009, 84.62581381201744, 90.21909087896347, 98.47765892744064, 95.11301547288895, 92.51871228218079, 94.88514170050621, 93.8015766441822, 93.45299854874611, 101.68751388788223, 102.53389567136765, 97.10179075598717, 92.67456471920013, 91.86210751533508, 92.52054378390312, 95.60795411467552, 101.96212515234947, 97.16941192746162, 87.44210109114647, 67.47413456439972, 31.68238453567028, 11.685198526829481, 1.9951012311503291, 0.8901796583086252, 0.15947589883580804, 0.21868693409487605, 0.13529653457226232, 0.1365654735127464, 0.08625310802017339, 0.11339387157931924, 0.14966412767535076, 0.1312321628211066, 0.0882285344414413, 0.1591809990350157, 0.16622889350401238, 0.09562050341628492, 0.12317735207034275, 0.18511907517677173, 0.17038027464877814, 0.07111420825822279, 0.09600097284419462, 0.11315097406622954, 0.13805215858155861, 0.16470005444716662, 0.16932918573729694, 0.16036092478316277, 0.14061605616007, 0.22944626456592232, 0.15609639580361545, 0.08781285752775148, 0.18135784106561914, 0.12159461082774214, 0.12269236598513089, 0.09311518355389126, 0.11829230599687435, 0.044557663350133225, 0.07509712188038975, 0.2517562924185768, 0.12428936388459988, 0.14391991950105876, 0.08956652280176058, 0.16498463839525357, 0.18618184549268335, 0.18023572862148285, 0.15025199769297615, 0.14390414144145325, 0.1050332588783931, 0.18090265220962465, 0.21727881277911365, 0.21881746302824467, 0.1404571474995464, 0.24194266588892788, 0.22911235748324543, 0.1908429930335842, 0.12803681631339714, 0.12499181408202276, 0.13415465131402016, 0.15321576443966478, 0.11935334710869938, 0.13441483344649896, 0.08197993302019313, 0.10188239670242183, 0.1419490424450487, 0.11936161463381723, 0.08588640543166548, 0.12130581890232861, 0.08551542807254009, 0.1283657064777799, 0.18800761783495545, 0.08443219674518332, 0.09804434288525954, 0.10183581209275872, 0.2019844256574288], [0.0131598182633752, 0.0802111130906269, 0.05731597600970417, 0.046565929806092754, 0.03055122899240814, 0.04392161310533993, 0.022332589142024517, 0.026028764732473064, 0.03677986293041613, 0.060556099997484125, 0.06222334588528611, 0.03995105253125075, 0.015737998473923653, 0.0445790483354358, 0.061846605749451555, 0.029845196077076253, 0.054760661369073205, 0.032862748121260665, 0.024206866401073057, 0.04097897901374381, 0.03143687834381126, 0.07629061408806592, 0.038206062963581644, 0.02446597984089749, 0.02344658805668587, 0.009567846700520022, 0.03307508028228767, 0.0432155672024237, 0.11264612068771385, 0.03681136709928978, 0.023965174877957907, 0.038746031059417874, 0.053498924971790984, 0.06565597926964983, 0.03387841432413552, 0.06364345288602635, 0.024070494910120033, 0.036330273578641936, 0.0440938284737058, 0.03010923737747362, 0.015461786879313877, 0.027983787658740766, 0.02900111627241131, 0.029064248919894453, 0.05223809399467427, 0.027184500177099835, 0.022475022124126554, 0.028322444486548193, 0.04726965649751946, 0.007158059797802707, 0.06446643528761342, 0.023251577622431796, 0.014159822367219022, 0.040274866405525245, 0.020183542837912682, 0.028015789066557772, 0.0352749878220493, 0.011111526855529519, 0.07890948254498653, 0.30427247285842896, 3.6428661877289414, 7.987577989697456, 20.699476674199104, 31.7338090762496, 38.517643958330154, 49.32281635701656, 52.52064496278763, 65.42492732405663, 61.34760931134224, 64.70214530825615, 69.25833642482758, 76.59719422459602, 79.96141970157623, 74.61169436573982, 81.75747692584991, 74.86552834510803, 68.70657563209534, 60.418011993169785, 65.70158287882805, 66.17781892418861, 64.22527089715004, 54.32991027832031, 33.37389037013054, 36.62418656051159, 40.16235910356045, 45.1793172955513, 46.077383905649185, 51.745315566658974, 30.340180657804012, 40.26923596858978, 41.534602269530296, 56.11507348716259, 54.54750180244446, 54.73108895123005, 57.56570264697075, 50.44196270406246, 54.95009019970894, 52.87148013710976, 52.923434749245644, 59.353274926543236, 67.85701721906662, 71.7179824411869, 71.81318253278732, 69.757090061903, 53.7774883210659, 24.26875624805689, 10.244853515177965, 1.3357764040119946, 0.3537238802528009, 0.050895444946945645, 0.047562704639858566, 0.07506083085900173, 0.073237366596004, 0.013393240406003315, 0.031017872897791676, 0.05471360178489704, 0.06634056597249582, 0.015446078396053053, 0.01910264927573735, 0.024400437068834435, 0.08017701140488498, 0.04059650207636878, 0.05626112069876399, 0.020649748876166996, 0.005743566216551699, 0.051114586312905885, 0.009442635255254572, 0.022902189339220058, 0.07327575047384016, 0.03661451984953601, 0.019939333578804508, 0.03331090512801893, 0.05666255208780058, 0.07758617386571132, 0.03746255715668667, 0.010488242478459142, 0.020732559569296427, 0.08219586830819026, 0.013966187689220533, 0.02398678807367105, 0.06498377159005031, 0.08994475836516358, 0.04418533899297472, 0.009543744527036324, 0.018155791294702794, 0.051317867983016185, 0.03884263271174859, 0.021588604649878107, 0.1233490627782885, 0.0354465538111981, 0.038078406141721644, 0.05011414898035582, 0.02223168674390763, 0.026026358318631537, 0.07572891961899586, 0.03798561170697212, 0.019983921811217442, 0.024551514216000214, 0.02546200881624827, 0.09185045259073377, 0.044635217782342806, 0.017183000818477012, 0.004051460236951243, 0.06298447027802467, 0.005565559313254198, 0.03595535541535355, 0.014199966990418034, 0.057018872030312195, 0.04112292226636782, 0.08862979884725064, 0.04140857119637076, 0.03286610262875911, 0.054431032767752185, 0.07415463885990903, 0.06840922840638086, 0.0581678279559128, 0.07392025378067046, 0.034972655412275344, 0.04394874602439813, 0.02015994439716451, 0.05270487519737799, 0.03712617501150817, 0.04253625716955867, 0.018212242757726926, 0.007734333294138196, 0.0455893933394691, 0.03015262704138877, 0.038356971272150986, 0.020836907388002146, 0.0639355622115545, 0.05447257819469087, 0.06560725727467798, 0.055683403261355124, 0.03877704541082494, 0.06552772130817175, 0.05987299016851466, 0.07599964024848305, 0.10378329665400088, 0.04266685660695657, 0.04785881414136384, 0.04498840215092059, 0.02319669394637458, 0.055155736263259314, 0.04485659672354814, 0.0436313368845731, 0.07945936202304438, 0.019675307121360675, 0.05611339620372746, 0.021105126979819033, 0.06419394834665582, 0.07471061137039214, 0.04672899449360557, 0.036419565076357685, 0.016368647739000153, 0.00940911708312342, 0.07329846761422232, 0.03720627129951026, 0.03741424334293697, 0.04690670546551701, 0.03136956183880102, 0.05273568174743559, 0.00922534462006297, 0.029435914620989934, 0.09923675897880457, 0.07609351450810209, 0.034554284502519295, 0.020147107097727712, 0.023283788686967455, 0.0065942089258896885, 0.052371283527463675, 0.07498547318391502, 0.013077411113044946, 0.0602216251718346, 0.02961742167826742, 0.05277720119920559, 0.586459580808878, 4.888963485136628, 9.986634571105242, 26.82194374501705, 36.51036746799946, 42.12862819433212, 54.12410572171211, 60.24207003414631, 73.2161508500576, 70.09947448968887, 72.78140097856522, 80.73391065001488, 87.33345732092857, 90.7368814945221, 84.56520706415176, 96.14700078964233, 89.46831956505775, 80.901398062706, 74.58530858159065, 76.64043590426445, 77.64864340424538, 79.27951589226723, 64.95845675468445, 47.89155475795269, 46.76182217895985, 49.24531191587448, 52.98778049647808, 58.73550407588482, 61.19295760989189, 43.153706789016724, 55.46709805727005, 54.08235356211662, 66.34295806288719, 66.24325141310692, 64.99127939343452, 71.55520677566528, 58.87785583734512, 65.76947003602982, 63.14872786402702, 65.2131874859333, 68.87774124741554, 78.68468061089516, 78.41507747769356, 83.07104364037514, 79.50859040021896, 66.23987719416618, 34.27177459001541, 15.322142019867897, 2.340793856419623, 0.18540667224442586, 0.06137144941021688, 0.15731645689811558, 0.14186504617100582, 0.06983770683291368, 0.07705184238147922, 0.0665075343567878, 0.07677317335037515, 0.04420105025928933, 0.03766691865166649, 0.07196448685135692, 0.07370540202828124, 0.04865400682319887, 0.03155473510560114, 0.08941928812419064, 0.04787481113453396, 0.04296417209843639, 0.031084324800758623, 0.04466183119802736, 0.05553570474148728, 0.05157187915756367, 0.054856450369697995, 0.05607223298284225, 0.012001381401205435, 0.03940659073123243, 0.03908309226972051, 0.09950597304850817, 0.06463221623562276, 0.029230658838059753, 0.028085656704206485, 0.07907597595476545, 0.025848378318187315, 0.027527845522854477, 0.11192995560122654, 0.016625913231109735, 0.07225531226140447, 0.001722663214422937, 0.10263418487738818, 0.022286982311925385, 0.019400727323954925, 0.001257555322808912, 0.04750220105051994, 0.023728071682853624, 0.04289813950890675, 0.019178303809894715, 0.06137730124464724, 0.06473215384176001, 0.05202500855375547, 0.029420114296954125, 0.01041949455611757, 0.024047158076427877, 0.04685433581471443, 0.05229628208326176, 0.03346074103319552, 0.039785149128874764, 0.017480110363976564, 0.05806862136523705, 0.06968384477659129, 0.028180011504446156, 0.006241671617317479, 0.04355882905656472, 0.06851642421679571, 0.046809836640022695, 0.03578890653443523, 0.06972115996177308, 0.047933967725839466, 0.010321178542653797, 0.0818622209772002, 0.15599160455167294, 0.12972906144568697, 0.1282317191362381, 0.10372054064646363, 0.15600365702994168, 0.1172366677201353, 0.14443275838857517, 0.07507744754548185, 0.11968604449066333, 0.13360403710976243, 0.15811540855793282, 0.10757414245745167, 0.16225623636273667, 0.14599812595406547, 0.15248596610035747, 0.1547021378064528, 0.1651431166101247, 0.10330859673558734, 0.25361854874063283, 0.11929465807043016, 0.16107395058497787, 0.19365340238437057, 0.1056602771859616, 0.11991717154160142, 0.12492620822740719, 0.08956912031862885, 0.10522100739763118, 0.23436100396793336, 0.17507127136923373, 0.18740080820862204, 0.12067726434906945, 0.18475110351573676, 0.11731319798855111, 0.2597615425474942, 0.14444353437284008, 0.12093452241970226, 0.1831377189955674, 0.24123191105900332, 0.1183499263424892, 0.12042191359796561, 0.14315578941022977, 0.08351940705324523, 0.13173343904782087, 0.0907411273510661, 0.20465471752686426, 0.12820604082662612, 0.1571687843534164, 0.20613975502783433, 0.1677237421972677, 0.19217721128370613, 0.15462237177416682, 0.11299190955469385, 0.08879914210410789, 0.20073694962775335, 0.1534996656118892, 0.10713372976169921, 0.13689804472960532, 0.10120157268829644, 0.17655679868767038, 0.9595795499626547, 7.960388548672199, 16.700782142579556, 39.008779004216194, 50.65684497356415, 55.03476485610008, 67.9611924290657, 74.43663775920868, 87.73060441017151, 86.0610879957676, 86.81840255856514, 90.8870342373848, 99.11970287561417, 103.08999583125114, 96.6885857284069, 108.07855054736137, 104.35520634055138, 93.40972647070885, 86.3405553996563, 87.80334770679474, 87.82991588115692, 86.76180839538574, 76.9532199203968, 55.26883989572525, 56.84873811900616, 59.715292900800705, 64.64090779423714, 69.71754178404808, 71.93334728479385, 49.59909953176975, 61.413497775793076, 63.85676667094231, 77.41763859987259, 75.45064374804497, 74.49029088020325, 81.931803971529, 69.897720515728, 77.66497492790222, 74.83039543032646, 76.9553630053997, 79.91275951266289, 90.1678316295147, 90.89737728238106, 93.48181620240211, 93.03356185555458, 76.1800754070282, 41.84905059635639, 18.70605044066906, 3.2980878883972764, 0.5710476671811193, 0.13885931839467958, 0.18308645143406466, 0.3235517180291936, 0.17689400090603158, 0.10997444100212306, 0.10433845280203968, 0.10860555703402497, 0.20755189878400415, 0.10889986311667599, 0.07264542218763381, 0.17833934834925458, 0.14672044344479218, 0.08655877638375387, 0.22316995135042816, 0.13301548431627452, 0.15541636588750407, 0.08143712620949373, 0.1641782355727628, 0.13792569661745802, 0.1711177616380155, 0.10081735541461967, 0.13143994932761416, 0.07124484851374291, 0.08608094460214488, 0.1632918737595901, 0.13240710133686662, 0.21298657200532034, 0.11778877364122309, 0.23267364216735587, 0.15151387138757855, 0.1291723913163878, 0.16605383571004495, 0.25951699004508555, 0.08905429247533903, 0.12742889346554875, 0.07858621785999276, 0.17040589358657598, 0.10164108738536015, 0.1128843797778245, 0.15650202403776348, 0.1350450504105538, 0.12088291347026825, 0.18910682760179043, 0.15232987760100514, 0.10588617209577933, 0.12034458181005903, 0.13036448828643188, 0.10054017810034566, 0.09490644602919929, 0.09004478502902202, 0.1905097538838163, 0.24679874593857676, 0.12706984241958708, 0.15005595196271315, 0.13345878396648914, 0.10904289723839611, 0.11890216585015878, 0.10990800394210964, 0.165494107932318, 0.15602267085341737, 0.19720763666555285, 0.09701968927402049, 0.09660798285040073, 0.12806635379092768, 0.181318789254874, 0.12315404863329604, 0.17959472083020955], [0.051694363210117444, 0.04634216114936862, 0.05137605607160367, 0.02721824563195696, 0.07089854756486602, 0.006086650882934919, 0.026666174962883815, 0.035470105867716484, 0.023453987269022036, 0.021246736177999992, 0.01702658391877776, 0.05505245157110039, 0.03649996193416882, 0.04518740162893664, 0.03833328191831242, 0.06038539489964023, 0.032715650741010904, 0.018188724097853992, 0.030481032954412512, 0.051988097839057446, 0.003077603619203728, 0.016945572933764197, 0.035224113598815165, 0.028217308135936037, 0.0027293076846035547, 0.02549355194787495, 0.023347973328782246, 0.016864801291376352, 0.008656523677927908, 0.01962814734724816, 0.036599480226868764, 0.02155155292712152, 0.035013499509659596, 0.015333745996031212, 0.0265275436322554, 0.05397794047894422, 0.038459896022686735, 0.0808791647432372, 0.11851280549308285, 0.008877041727828328, 0.0316162257513497, 0.017798313601815607, 0.02241075213532895, 0.04937709243677091, 0.03972411490394734, 0.037842970923520625, 0.04718787924502976, 0.06852149308542721, 0.1238036727590952, 0.036671939815278165, 0.10067786133731715, 0.05523372485185973, 0.052082773618167266, 0.02969574608869152, 0.020638705718738493, 0.034288770038983785, 0.07772312237648293, 1.7976881680078804, 6.793713876977563, 18.70982363820076, 35.61283282935619, 48.38484048843384, 60.354050025343895, 63.57791103422642, 71.43923699855804, 66.83735713362694, 64.79794576764107, 62.0922439545393, 63.21913428604603, 71.68177038431168, 76.07567980885506, 61.805108562111855, 49.59187991917133, 62.67609402537346, 47.79241427779198, 57.02694855630398, 41.62817604839802, 30.56672640144825, 47.30772748589516, 49.956952929496765, 24.394964575767517, 27.711259424686432, 24.46915939450264, 23.219499550759792, 21.116910874843597, 26.835146136581898, 23.373921364545822, 30.432038828730583, 23.019787967205048, 14.461248815059662, 26.389815732836723, 26.62104282528162, 20.93858264386654, 34.80270870029926, 28.014515452086926, 29.520224556326866, 31.32643673568964, 29.46566328406334, 32.683060839772224, 42.0558051019907, 50.52129864692688, 60.927283465862274, 56.321011036634445, 59.98597897589207, 63.81733998656273, 64.74578216671944, 48.74379962682724, 27.31423582881689, 13.441848065704107, 8.381947427988052, 3.0752885062247515, 0.3459656465565786, 0.06042491797416005, 0.1079201688116882, 0.050865721932495944, 0.03759856685064733, 0.09498062368948013, 0.014675682723463979, 0.0033472989252913976, 0.042266883538104594, 0.009706747987365816, 0.0653425331984181, 0.06702283717459068, 0.0027151335916641983, 0.06745255552232265, 0.046820349161862396, 0.014724708071298664, 0.0026117540437553544, 0.026663319549697917, 0.057900495230569504, 0.006779199902666733, 0.008179855212802067, 0.03848627195111476, 0.061923354951431975, 0.041174646248691715, 0.021624754663207568, 0.03277266994700767, 0.047175088329822756, 0.06642782027483918, 0.032174914522329345, 0.032116581714944914, 0.017910878850670997, 0.058418762928340584, 0.02635512973938603, 0.05376307759433985, 0.03761089392355643, 0.02651989765581675, 0.030332089481817093, 0.04130613255256321, 0.02945788590295706, 0.008142271926772082, 0.02022024946199963, 0.05319308962498326, 0.04208988873870112, 0.08189978107111529, 0.04325555040850304, 0.0547943919809768, 0.07380193317658268, 0.01703140416793758, 0.03882407530909404, 0.02456660949974321, 0.034500797919463366, 0.02528339984564809, 0.05373189997044392, 0.02827938507834915, 0.053755121771246195, 0.030370137537829578, 0.03770854942558799, 0.06523958247271366, 0.039399198940373026, 0.040137353862519376, 0.0626735549303703, 0.0059703888109652326, 0.05809919042803813, 0.02030591927905334, 0.05395936081185937, 0.032304727283190005, 0.012200287183077307, 0.07234261109260842, 0.034939915567520075, 0.08161999881849624, 0.05230020062299445, 0.0030633001142632565, 0.014559351075149607, 0.04175695386948064, 0.04844871393288486, 0.024582009064033628, 0.012239126554050017, 0.018856501155823935, 0.048590942824375816, 0.022188644034031313, 0.06534514555823989, 0.05046283964475151, 0.008031556481000734, 0.018351681173953693, 0.03854077527648769, 0.04198934999294579, 0.017292473166889977, 0.028560822320287116, 0.053421155316755176, 0.05311726068612188, 0.023400738173222635, 0.035678875719895586, 0.02350726048462093, 0.02286043054482434, 0.04986890256986953, 0.03629478036600631, 0.08970269205747172, 0.02366268847254105, 0.05085706477984786, 0.005754372350565973, 0.0077029436943121254, 0.009362500004499452, 0.056099388166330755, 0.06876407889649272, 0.0493686839035945, 0.0563071746728383, 0.016551414591958746, 0.014365176484716358, 0.05851447400345933, 0.033469034533482045, 0.09966962403268553, 0.021177560593059752, 0.05244633321126457, 0.08771308319410309, 0.02794946889480343, 0.11818033075542189, 0.023930644601932727, 0.07958514863275923, 0.04447502149560023, 0.0539304281846853, 0.04974723487976007, 0.08452921028947458, 1.9942512642592192, 7.934636855497956, 21.500682681798935, 41.30793683230877, 55.588528141379356, 68.82936224341393, 71.2842509150505, 80.11730253696442, 76.01134166121483, 74.92110416293144, 73.47107917070389, 71.99793621897697, 82.1863143146038, 85.72959378361702, 74.21029150485992, 59.723781645298004, 72.44160041213036, 57.35229089856148, 69.42684978246689, 61.98341019451618, 46.3009525090456, 54.805063381791115, 57.54788160324097, 37.05004870891571, 41.47366113960743, 32.425453662872314, 36.69024221599102, 31.249849945306778, 36.804502084851265, 32.6121224462986, 44.53302897512913, 29.37595769762993, 23.846030831336975, 37.05635257065296, 41.834337785840034, 30.32736584544182, 47.395776361227036, 40.31107932329178, 39.19270433485508, 41.5555277466774, 41.92085154354572, 46.2700829654932, 53.78380738198757, 64.1273957490921, 69.90928709506989, 65.34212216734886, 69.99007076025009, 72.85879522562027, 75.18567636609077, 59.598730355501175, 34.52192656695843, 17.968485318124294, 10.777389239519835, 3.680570852011442, 0.4745746438857168, 0.09069167062989436, 0.05909205414354801, 0.07045696969726123, 0.09665999255958013, 0.06337269514915533, 0.0316027706139721, 0.01012636384984944, 0.05330124651663937, 0.002940378426501411, 0.1144128551823087, 0.07594607945065945, 0.025334576494060457, 0.02753081967966864, 0.028459053464757744, 0.015997091504686978, 0.014137758316792315, 0.058039306532009505, 0.03991958175902255, 0.04142850528296549, 0.07633998175151646, 0.06868748925626278, 0.049824010056909174, 0.027592098813329358, 0.05506288987817243, 0.034385293765808456, 0.02288597526785452, 0.024929996543505695, 0.0185122689435957, 0.03176846250426024, 0.02045341370831011, 0.04483384618652053, 0.034717549569904804, 0.056574036134406924, 0.08356850754353218, 0.052422384105739184, 0.027433006471255794, 0.04050553332490381, 0.01027090731440694, 0.01962774473213358, 0.03746522146684583, 0.04862958645389881, 0.03155511360091623, 0.07469631760613993, 0.03377248387550935, 0.09133753948844969, 0.07356621965300292, 0.07199354935437441, 0.008799071692919824, 0.004656238234019838, 0.023618237537448294, 0.01907722144096624, 0.005068062937425566, 0.03990110970335081, 0.03186790658219252, 0.027092770724266302, 0.05137403742992319, 0.019585559202823788, 0.01713671677862294, 0.02869276318961056, 0.06109990499680862, 0.014814459700573934, 0.05787449408671819, 0.024244088817795273, 0.057974376031779684, 0.10231628592009656, 0.11811098447651602, 0.15110509644728154, 0.06180997705087066, 0.21256096515571699, 0.08748047926928848, 0.13746746495598927, 0.08310187477036379, 0.08367228205315769, 0.11462642301921733, 0.18751171475742012, 0.22160013089887798, 0.17411284701665863, 0.18627537094289437, 0.09120865812292323, 0.2285099116852507, 0.11215415841434151, 0.13145327829988673, 0.10408967005787417, 0.15299338730983436, 0.09550253162160516, 0.17449891223805025, 0.15138975461013615, 0.2227427117759362, 0.14701424486702308, 0.22689139150315896, 0.10685372486477718, 0.14208311884431168, 0.09202948829624802, 0.15609810274327174, 0.12555828056065366, 0.18954773753648624, 0.12453619478037581, 0.12890845391666517, 0.15389938635053113, 0.11632148089120165, 0.09797573875403032, 0.12172175556770526, 0.23258470318978652, 0.12141238388721831, 0.12009658574243076, 0.12207066145492718, 0.12222308374475688, 0.13425357959931716, 0.23963095009094104, 0.18467967922333628, 0.15146123827435076, 0.19188395905075595, 0.23068882757797837, 0.0662124712835066, 0.3458402829710394, 0.1026382963755168, 0.11856724202516489, 0.08362637279788032, 0.17091560061089694, 0.119988306396408, 0.3412418469088152, 2.8626260301098228, 12.36599089577794, 31.95339359343052, 56.684890910983086, 71.85273841023445, 84.9987182021141, 86.599792689085, 92.1890039741993, 87.1684093773365, 89.41366329789162, 85.54964303970337, 82.50952497124672, 93.96855488419533, 98.27905878424644, 83.17521125078201, 70.60300827026367, 83.6279645562172, 68.12672674655914, 78.52581113576889, 64.21546742320061, 48.09824466705322, 63.31681564450264, 71.19437053799629, 39.48558121919632, 47.56036452949047, 39.21723961830139, 41.23202830553055, 37.27656215429306, 44.56479527056217, 38.59935097396374, 47.517115250229836, 36.87298960983753, 27.083892188966274, 43.25671926140785, 44.37281057238579, 36.93433351814747, 51.24253414571285, 43.88473816215992, 47.43927642703056, 49.134908840060234, 48.695637211203575, 51.063058376312256, 63.01860764622688, 72.00026169419289, 83.61841186881065, 75.48176407814026, 80.41717484593391, 83.1768299639225, 89.01384875178337, 71.87213256955147, 41.83172732591629, 22.771138809621334, 13.500008694827557, 5.041150068864226, 1.0956936492584646, 0.21243258845061064, 0.26338981348089874, 0.17067033564671874, 0.19917636149330065, 0.1991679158527404, 0.12301073991693556, 0.16230319946771488, 0.10999309117323719, 0.07946344383526593, 0.1962935779010877, 0.20220849488396198, 0.10178793614613824, 0.13820165680954233, 0.1564901793608442, 0.05328487473889254, 0.1080352536519058, 0.24229212838690728, 0.19782421295531094, 0.1906784440507181, 0.13087915285723284, 0.20755874138558283, 0.13051783083938062, 0.09738361623021774, 0.1356916391523555, 0.1502598644583486, 0.08883091344614513, 0.20030843355925754, 0.09839397607720457, 0.14346097537782043, 0.07322879479033872, 0.1494552131043747, 0.15169431717367843, 0.40462859091348946, 0.11078138559241779, 0.13473872153554112, 0.17140512121841311, 0.1573461279622279, 0.11524688074132428, 0.10687798567232676, 0.09184599970467389, 0.18565080914413556, 0.1272042453638278, 0.1809714047703892, 0.07982239098055288, 0.19818733097054064, 0.19839271291857585, 0.2029774637776427, 0.09640929507440887, 0.13922720099799335, 0.09132028455496766, 0.08499493022100069, 0.11196684776223265, 0.11214808764634654, 0.12147508794441819, 0.1345249087898992, 0.1110288621566724, 0.16870772611582652, 0.1897367773926817, 0.13251950702397153, 0.21874170459341258, 0.07882356410846114, 0.3081349952844903, 0.09029895576531999, 0.30796326231211424], [0.05109384699608199, 0.031782811929588206, 0.027007471981050912, 0.04263449525751639, 0.043315734874340706, 0.04494594759307802, 0.047540703671984375, 0.02038178346992936, 0.035252664019935764, 0.05470828429679386, 0.017331118651782162, 0.01592837605130626, 0.023619974163011648, 0.0643718930950854, 0.002525200143281836, 0.06254314474062994, 0.013289890775922686, 0.027742133243009448, 0.04380031277833041, 0.06434580660425127, 0.027453460061224177, 0.04562206639093347, 0.05383335897931829, 0.04778550108312629, 0.06232169529539533, 0.08077919745119289, 0.041771522228373215, 0.05564998064073734, 0.07730562720098533, 0.05532155431865249, 0.011490165961731691, 0.0467037800262915, 0.03254009199736174, 0.038530140300281346, 0.013416492820397252, 0.05603710342256818, 0.02679959641682217, 0.05087674282549415, 0.05829164045280777, 0.06560595851624385, 0.09775753249414265, 0.07462829977157526, 0.08160852521541528, 0.027018058717658278, 0.013509372602129588, 0.02321427356946515, 0.01408172802257468, 0.043285150968586095, 0.05288611508149188, 0.06998849639785476, 0.08788976629148237, 0.01868046929303091, 0.050838410897995345, 0.08485774422297254, 0.11501706729177386, 0.9944678528700024, 10.436025056988, 35.44059567153454, 47.230884209275246, 63.083147183060646, 71.56457707285881, 74.69640702009201, 71.05933338403702, 69.29786190390587, 57.497937083244324, 56.459646597504616, 48.03661957383156, 47.53343537449837, 51.642732471227646, 38.70542228221893, 35.04186026751995, 41.64105735719204, 31.589551717042923, 43.24967823922634, 36.054547727108, 30.094685330986977, 17.45950262993574, 25.97640361636877, 49.90199267864227, 34.05720770359039, 35.71628227829933, 19.825622364878654, 20.227312110364437, 15.835731010884047, 14.154562521725893, 15.700571313500404, 18.630166612565517, 22.5451972335577, 22.403016462922096, 21.781014539301395, 20.580187775194645, 17.89129626005888, 18.99890262633562, 14.341749027371407, 17.30812445282936, 19.30168367922306, 16.641492024064064, 16.180094182491302, 16.427193023264408, 20.253053829073906, 19.88202653825283, 35.39247505366802, 52.191654816269875, 59.911886751651764, 61.49453982710838, 65.80404818058014, 63.39428588747978, 62.815101966261864, 48.106942400336266, 47.70778901875019, 28.826279193162918, 15.319158229976892, 6.129512842744589, 2.6349249109625816, 0.6179942074231803, 0.24462643516017124, 0.07845891726901755, 0.06430447640013881, 0.06648554452112876, 0.07190101096057333, 0.03120654910162557, 0.03990881690697279, 0.037718768799095415, 0.032607022585580125, 0.020157738363195676, 0.02078984038234921, 0.023641797015443444, 0.08421428734436631, 0.05102814095153008, 0.05658972142555285, 0.04181470780167729, 0.025004469207488, 0.07297466858290136, 0.017238852997252252, 0.036680032935692, 0.03648169025836978, 0.08309961864142679, 0.049097825976787135, 0.07235956174554303, 0.02047288766334532, 0.057170615255017765, 0.03628184102126397, 0.15639217133866623, 0.04709847271442413, 0.024888875996111892, 0.060227744179428555, 0.021596176411549095, 0.03799381614953745, 0.03716721206728835, 0.024999598863360006, 0.04092027884325944, 0.05267002765322104, 0.06930961681064218, 0.06123628205386922, 0.0355705815309193, 0.037773346339236014, 0.016127891321957577, 0.04789729820913635, 0.013361463497858495, 0.021453075496538077, 0.05250746391538996, 0.03346400277223438, 0.0037683914297304, 0.04203933734970633, 0.050313315441599116, 0.053330954688135535, 0.052292949840193614, 0.07868648201110773, 0.011465988645795733, 0.030907168584235478, 0.02537307169404812, 0.07410316349705681, 0.05353788030333817, 0.06355616889777593, 0.032933485927060246, 0.057007877112482674, 0.010165497296839021, 0.024797324658720754, 0.021033817720308434, 0.043902087199967355, 0.01693656882707728, 0.05251333430351224, 0.06524794647702947, 0.043041496464866214, 0.05769505391072016, 0.03269356813689228, 0.0035750255483435467, 0.04778729708050378, 0.019231055666750763, 0.03362068870046642, 0.03656032451544888, 0.08136562028084882, 0.03994722675997764, 0.0233227310309303, 0.09814923061640002, 0.0050835255842685, 0.022726721508661285, 0.050359376837150194, 0.0310498038015794, 0.09597070806194097, 0.011375579288142035, 0.020092184458917473, 0.04084960412001237, 0.052788656248594634, 0.014628143526351778, 0.025259946123696864, 0.01807433316571405, 0.014642706319136778, 0.02992820715007838, 0.08041233159019612, 0.05809475980640855, 0.04332134180003777, 0.05156657280167565, 0.05139467284607235, 0.03328205413708929, 0.06231938721612096, 0.03171599266352132, 0.042474183937883936, 0.0448975261679152, 0.034263258712599054, 0.030886403292242903, 0.005682310738848173, 0.03957132896175608, 0.027756955787481274, 0.02683829570742091, 0.042799545190064237, 0.05297195559251122, 0.040209924773080274, 0.09198383137118071, 0.03713356680236757, 0.04764611832797527, 1.1422017286531627, 12.8308161534369, 43.404763117432594, 57.69219405949116, 71.81525722146034, 80.34354239702225, 84.8827788233757, 80.72343841195107, 77.57377222180367, 66.11354917287827, 64.92098316550255, 55.34989334642887, 54.5236998796463, 62.39269383251667, 49.402171298861504, 47.29631669819355, 50.543968230485916, 37.94761374592781, 52.159394547343254, 46.51937618851662, 42.60506182909012, 22.60113213211298, 24.996274709701538, 55.240588411688805, 42.38644815981388, 32.62212350964546, 23.15354458987713, 32.24856935441494, 30.614668428897858, 16.224166117608547, 27.77918267995119, 30.27162853628397, 31.56455285847187, 30.214040726423264, 24.157908596098423, 30.361138433218002, 26.61921512335539, 23.477178923785686, 24.33048203587532, 28.39782938361168, 30.35382192581892, 27.255363687872887, 29.13207918405533, 25.56094530969858, 34.05409947037697, 31.260671764612198, 49.09707807004452, 61.360673010349274, 69.8134258389473, 69.76822346448898, 72.21720725297928, 70.48959195613861, 74.58784684538841, 58.68649050593376, 57.87255898118019, 35.24549514055252, 20.924249812960625, 8.758453074842691, 3.459592047147453, 0.7567390124313533, 0.16973390855127946, 0.13259946601465344, 0.1269764208700508, 0.03663759693154134, 0.14030068792635575, 0.007034318268779316, 0.011913422986253863, 0.03703387039422523, 0.01500056343502365, 0.04055063363921363, 0.050936274201376364, 0.017102429555961862, 0.05782638065284118, 0.05646225756208878, 0.020159447158221155, 0.11321827943902463, 0.05481245956616476, 0.07302189143956639, 0.10322065965738147, 0.05537804288906045, 0.021495750843314454, 0.028075750888092443, 0.06773813394829631, 0.0764402978529688, 0.005186707767279586, 0.020055796958331484, 0.039269935368793085, 0.03897329152096063, 0.03864279460685793, 0.026015226103481837, 0.0411769506172277, 0.02110158693540143, 0.05222256455454044, 0.021193088177824393, 0.10372960226959549, 0.035756749275606126, 0.05521031009266153, 0.059700010388041846, 0.07849467394407839, 0.012562789215735393, 0.04876997852989007, 0.05709989971364848, 0.01392886044413899, 0.01613808657566551, 0.030352997637237422, 0.044395786098903045, 0.023144990373111796, 0.04043218315928243, 0.018960451925522648, 0.06270649886573665, 0.02966229378216667, 0.030375673959497362, 0.014250896874727914, 0.03293931178632192, 0.03202377243724186, 0.01861714739789022, 0.13049230095930398, 0.030130030500004068, 0.02588848026789492, 0.05543019360629842, 0.09357066926895641, 0.21223869494860992, 0.13520853070076555, 0.1432696497067809, 0.12159613965195604, 0.09881405392661691, 0.21668435249011964, 0.1306030887644738, 0.17734525637933984, 0.14664278511190787, 0.24612158071249723, 0.10690616501960903, 0.09995511340093799, 0.20986057177651674, 0.23216319299535826, 0.10704059764975682, 0.19023285858565941, 0.28645567421335727, 0.12072149635059759, 0.14193321985658258, 0.16296803019940853, 0.07258904865011573, 0.1377330647665076, 0.1282349697430618, 0.15531169337918982, 0.18090305296937004, 0.1493155854404904, 0.11802690656622872, 0.14305889460956678, 0.22109928511781618, 0.09863964180112816, 0.14995959150837734, 0.1420159693225287, 0.15526946517638862, 0.14576014888007194, 0.15882751409662887, 0.11939794276258908, 0.06622520653763786, 0.13124366611009464, 0.19548989133909345, 0.1327003090409562, 0.16324589028954506, 0.20944251999026164, 0.26996328262612224, 0.09986137272790074, 0.14648277807282284, 0.13502749119652435, 0.16609006735961884, 0.1678745317622088, 0.15233970363624394, 0.15053699724376202, 0.1608344298438169, 0.08335031612659805, 0.1189535298908595, 0.21597340470179915, 0.2583847992355004, 1.8281400902196765, 17.69794173538685, 51.29758559167385, 70.49360454082489, 83.8076189160347, 91.53021052479744, 92.99909770488739, 90.1652629673481, 88.06371733546257, 76.77712976932526, 77.71225959062576, 64.90566998720169, 67.76169553399086, 72.14067175984383, 56.89750850200653, 54.56216141581535, 61.331296786665916, 49.718185141682625, 63.01053687930107, 54.755464643239975, 49.14918087422848, 28.95846839994192, 40.879585817456245, 65.84025263786316, 52.344611808657646, 52.12526097893715, 34.697518944740295, 34.16395537555218, 27.28773795068264, 25.687090940773487, 29.454890862107277, 31.94791428744793, 35.41922561824322, 36.55819930136204, 33.88857275247574, 34.05777007341385, 31.432223059237003, 35.01800514757633, 26.678824424743652, 32.318531200289726, 36.02073334157467, 31.29383448511362, 30.226167775690556, 28.560952730476856, 36.09372742474079, 32.418997809290886, 56.53438478708267, 70.11370092630386, 80.517238676548, 80.99849805235863, 82.70391494035721, 81.28135487437248, 87.73277789354324, 72.50842362642288, 67.3491820693016, 42.3014847189188, 25.780489929020405, 13.23449794203043, 4.708036668598652, 1.1537863570265472, 0.34098159056156874, 0.2606644097249955, 0.1605225497041829, 0.1891137147322297, 0.24152240250259638, 0.09643898840295151, 0.06287640615482815, 0.16765298583777621, 0.14577971189282835, 0.09849777285126038, 0.1327379804570228, 0.1076236659719143, 0.2499047527089715, 0.19584349502110854, 0.09122948278672993, 0.20681412977864966, 0.18361290130997077, 0.18560865515610203, 0.11051673573092557, 0.1422329287743196, 0.15434531320352107, 0.23157216142863035, 0.17411459848517552, 0.20611484855180606, 0.11426677825511433, 0.15343118022428825, 0.06087722358643077, 0.2771439770003781, 0.13679049268830568, 0.09391435043653473, 0.17311802774202079, 0.1631455816095695, 0.1811842230381444, 0.17178944981424138, 0.16773129726061597, 0.11665737692965195, 0.18845826474716887, 0.16001628624508157, 0.2202720131026581, 0.07150874880608171, 0.10794190631713718, 0.14589017315302044, 0.09095994959352538, 0.12503809441113845, 0.19699738622875884, 0.12831580446800217, 0.1155210004071705, 0.14529375359416008, 0.17156720627099276, 0.15162632160354406, 0.12941842811414972, 0.09327405510703102, 0.11917926894966513, 0.14654344122391194, 0.1005399702989962, 0.14683077111840248, 0.23796180059434846, 0.13782474969048053, 0.11930743043194525, 0.14558198890881613, 0.1837358603370376], [0.032120908435899764, 0.031520210395683534, 0.020661625094362535, 0.04930878145387396, 0.07401726732496172, 0.0755623891018331, 0.030467985998257063, 0.05135845232871361, 0.0418397144676419, 0.02940424717962742, 0.05680611313437112, 0.03980844143370632, 0.04188612838333938, 0.015651143075956497, 0.07848348977859132, 0.01656621301663108, 0.0681984807306435, 0.029053764228592627, 0.09609259839635342, 0.02747307316894876, 0.08283193339593709, 0.0852905870124232, 0.03228362060326617, 0.009460428245802177, 0.015246561270032544, 0.05838065735588316, 0.01247053283805144, 0.07183216192061082, 0.07781577209243551, 0.02114114526193589, 0.04773453409143258, 0.03251599446230102, 0.04124635255720932, 0.018444644447299652, 0.08654964054585434, 0.04910824201942887, 0.06434821858420037, 0.006967154367885087, 0.02107542437443044, 0.05978183959086891, 0.029837885922461282, 0.01955959145561792, 0.08744912352995016, 0.06830041471403092, 0.0335215414816048, 0.06347586851916276, 0.07092994783306494, 0.012174270268587861, 0.03224446118110791, 0.05350426472432446, 0.08756329552852549, 0.015746468234283384, 0.5823798466008157, 3.463815520517528, 11.666314490139484, 31.04315623641014, 53.53243187069893, 73.8428208231926, 81.08450263738632, 78.05421844124794, 67.9729413986206, 62.92462348937988, 51.409253999590874, 41.17909714579582, 32.92399451136589, 34.12348374724388, 28.621302992105484, 27.55917638540268, 20.875772014260292, 26.289238929748535, 19.73064076155424, 18.528951443731785, 16.37255385518074, 28.92717707902193, 24.65068705379963, 21.521621458232403, 61.766495034098625, 75.81469461321831, 43.28953430056572, 42.6540943980217, 70.96407249569893, 45.538253635168076, 31.026505529880524, 48.34567219018936, 42.388465851545334, 31.796826794743538, 33.34362879395485, 37.80675150454044, 32.882006764411926, 34.38330240547657, 33.89993034303188, 44.68253955245018, 35.363459810614586, 46.04624077677727, 31.884605884552002, 17.411319315433502, 17.281765267252922, 22.690788321197033, 30.46537633985281, 19.792873822152615, 17.733929604291916, 15.57292951270938, 18.539987951517105, 26.317066736519337, 47.706763073801994, 57.400327920913696, 61.99319086968899, 63.80122125148773, 63.38256351649761, 63.85380282998085, 65.01858472824097, 63.59113812446594, 46.71679459512234, 26.05851151049137, 14.470165986567736, 5.121849663555622, 0.847423046361655, 0.1584265020210296, 0.07942678174003959, 0.03870906097290572, 0.004602288272508304, 0.045954696979606524, 0.04197333815682214, 0.01674419858318288, 0.07204172216006555, 0.040207457132055424, 0.04164277073869016, 0.01372303599055158, 0.004208058498988976, 0.06609064774238504, 0.023450144799426198, 0.018489379253878724, 0.009559043901390396, 0.06889929820317775, 0.03570122178643942, 0.10113053431268781, 0.010849614591279533, 0.018181118939537555, 0.04929734866891522, 0.01771477374859387, 0.022314558664220385, 0.039366295823128894, 0.033234115107916296, 0.03819826299150009, 0.10409175549284555, 0.11354042348102666, 0.0352501555607887, 0.023378638870781288, 0.01602989072125638, 0.05328450366505422, 0.053773174513480626, 0.06750723696313798, 0.0347554621839663, 0.05583838596066926, 0.018370810030319262, 0.024760278502071742, 0.0989431505149696, 0.08934732206398621, 0.04004758739029057, 0.016050383273977786, 0.03315768874017522, 0.03138526568363886, 0.017746070116118062, 0.07960767281474546, 0.004627694770533708, 0.02346908255276503, 0.06224447482964024, 0.11473542224848643, 0.0141829105814395, 0.02072582643450005, 0.054991884899209253, 0.04251128018950112, 0.047855574666755274, 0.06343205212033354, 0.06602755776839331, 0.054107864561956376, 0.03577133247745223, 0.05094886102597229, 0.03153585857944563, 0.06204249933944084, 0.0368448936205823, 0.0663573236670345, 0.016747738627600484, 0.02348664176679449, 0.044884252856718376, 0.043714357234421186, 0.04036933067254722, 0.015368353269877844, 0.055478652138845064, 0.012865220887761097, 0.005650258772220695, 0.06127071028458886, 0.06323938316199929, 0.02254620150779374, 0.08468185522360727, 0.04606474634783808, 0.03453721139521804, 0.08666166773764417, 0.036205232827342115, 0.0885481626028195, 0.05206686197197996, 0.02528448894736357, 0.03454340090684127, 0.05170985183212906, 0.019946053726016544, 0.03446137132414151, 0.07562767583294772, 0.037898342561675236, 0.0650968452100642, 0.05839802361151669, 0.03900441719451919, 0.024095928310998715, 0.07390320664853789, 0.022700811277900357, 0.04201962590741459, 0.04028575000120327, 0.07223840613733046, 0.038110151508590207, 0.039010250475257635, 0.04665546250180341, 0.016369636650779285, 0.029725851309194695, 0.014987053564254893, 0.04012505647551734, 0.03274850932939444, 0.08863108276273124, 0.02754194076260319, 0.056184961504186504, 0.8215819986071438, 5.0618627574294806, 15.551579408347607, 40.03119774162769, 66.01449608802795, 84.11195978522301, 88.51843893527985, 87.08863645792007, 77.82442957162857, 73.24945226311684, 61.18983797729015, 49.8097488284111, 43.567375391721725, 43.901309072971344, 38.17722402513027, 36.28306366503239, 30.068854317069054, 37.34204784035683, 28.59097681939602, 35.34429743885994, 28.22570811957121, 48.30976411700249, 40.90960040688515, 28.970502354204655, 53.42159181833267, 68.8277055323124, 46.007745042443275, 43.8896930962801, 67.56963863968849, 39.91751164197922, 23.15053705126047, 28.45215506851673, 42.7644594758749, 33.126827627420425, 33.73731806874275, 34.376481771469116, 31.956965401768684, 32.20623202621937, 35.11132813990116, 45.018091946840286, 37.5843570381403, 40.097245797514915, 31.557021662592888, 22.94655829668045, 24.42721724510193, 30.0446268171072, 39.13837485015392, 28.448024690151215, 27.973302863538265, 29.180317595601082, 32.90776178240776, 41.68205335736275, 61.58813640475273, 66.83546483516693, 67.01718628406525, 71.0330767929554, 72.76644498109818, 73.0407902598381, 75.80656304955482, 75.09080305695534, 57.18229942023754, 32.598226591944695, 19.41863190382719, 8.205542843788862, 1.6653812862932682, 0.16592499887337908, 0.09685657263617031, 0.023054568955558352, 0.0162754172924906, 0.02098442222632002, 0.03802073755650781, 0.038688091590302065, 0.025204578196280636, 0.035873756278306246, 0.025987968874687795, 0.022780575454817154, 0.05447638170153368, 0.022572187808691524, 0.03225343745725695, 0.03341316565638408, 0.07108885649358854, 0.05326235055690631, 0.04262711459887214, 0.05883469588297885, 0.02624265540362103, 0.011633271515165688, 0.05307829793309793, 0.02987644234963227, 0.0329388516547624, 0.011279913669568487, 0.02688389882678166, 0.08670208510011435, 0.07244695705594495, 0.038613761789747514, 0.07686526645557024, 0.015289031598513247, 0.04254267303622328, 0.08065192654612474, 0.043937732552876696, 0.06677254787064157, 0.04534747546131257, 0.039597753129783086, 0.029274336084199604, 0.02149604584701592, 0.009261656978196697, 0.04916676778520923, 0.04041859443532303, 0.05832560113049112, 0.04372716670332011, 0.02800228012347361, 0.008595546969445422, 0.056443488647346385, 0.02720610409596702, 0.0371287131565623, 0.005626959973596968, 0.069195058895275, 0.010928721967502497, 0.022432519326684996, 0.03715387196280062, 0.0382274516596226, 0.0889584663673304, 0.03075431399338413, 0.07082244774210267, 0.05768527611508034, 0.1251670648343861, 0.22377391112968326, 0.18481844599591568, 0.14104679867159575, 0.14069985947571695, 0.15978160430677235, 0.0746565978624858, 0.20299496361985803, 0.19763420830713585, 0.13641358556924388, 0.1458495479892008, 0.14322026720037684, 0.17137359478510916, 0.05521888560906518, 0.20759066857863218, 0.13329371548024938, 0.14572011743439361, 0.10408403715700842, 0.17370756017044187, 0.13882283441489562, 0.13974167261039838, 0.23843797738663852, 0.13673938839929178, 0.17576330923475325, 0.08433611830696464, 0.12380944666801952, 0.13085798680549487, 0.19000090775080025, 0.24301594501594082, 0.06736655544955283, 0.18773192481603473, 0.09872581998934038, 0.18582319520646706, 0.1316731469705701, 0.15774562605656683, 0.13851340336259454, 0.2280956003232859, 0.06987476968788542, 0.09633601541281678, 0.17903294472489506, 0.1782255622674711, 0.0678277482802514, 0.18308689672267064, 0.14039762725587934, 0.07874768693000078, 0.23874148610047996, 0.19043249631067738, 0.14655580540420488, 0.11819368941360153, 0.28482075256761163, 0.19129010732285678, 0.15804794733412564, 1.1431927629746497, 7.031275229528546, 20.92463169246912, 49.08289723098278, 79.83403533697128, 96.27449154853821, 99.62331265211105, 97.03631266951561, 89.96761277318001, 83.05570006370544, 72.13183343410492, 61.23239189386368, 52.135334238409996, 53.44119116663933, 46.88626930117607, 43.317751586437225, 34.837663024663925, 40.3140127658844, 33.740433901548386, 35.025023370981216, 30.24680256843567, 45.84937334060669, 38.49932134151459, 36.673979088664055, 80.31216368079185, 89.45836409926414, 58.52950192987919, 61.83092437684536, 94.72551986575127, 66.42735913395882, 46.25909015536308, 65.64471513032913, 61.558418199419975, 44.95568789541721, 48.41746173799038, 54.679043143987656, 50.66578969359398, 50.793497040867805, 49.90226626396179, 60.8089654147625, 51.14596612751484, 61.24578237533569, 47.60243967175484, 29.003647975623608, 29.698932766914368, 37.86037802696228, 46.447556242346764, 33.69409918785095, 29.810236394405365, 29.888080917298794, 32.43213750422001, 43.74558962881565, 66.67976438999176, 75.68624630570412, 81.1968170106411, 81.39841139316559, 83.25642049312592, 85.83647444844246, 87.20935598015785, 87.79881834983826, 66.05882450938225, 42.72446662187576, 24.8952267318964, 11.103253103792667, 2.987677319906652, 0.5015488027129322, 0.22554801515070722, 0.16808224405394867, 0.155771468707826, 0.12999575963476673, 0.17112035915488377, 0.12686453468631953, 0.16157736419700086, 0.19141609431244433, 0.17280654836213216, 0.06520594091853127, 0.21410432062111795, 0.1705699082231149, 0.13155864842701703, 0.13178102555684745, 0.13027351582422853, 0.10497569790459238, 0.10212729801423848, 0.2658633916871622, 0.15074030117830262, 0.09445202158531174, 0.1540030346950516, 0.07995536157977767, 0.16264270234387368, 0.10122542531462386, 0.12141206476371735, 0.1830176543444395, 0.2868752845097333, 0.22962231683777645, 0.10317642765585333, 0.13091312837786973, 0.15541501517873257, 0.16048719378886744, 0.122441720450297, 0.3527002508053556, 0.0988327115192078, 0.1274993974948302, 0.11182262620422989, 0.10395160090411082, 0.1800325879594311, 0.13818868406815454, 0.13277355901664123, 0.12583039642777294, 0.08297568740090355, 0.0740282288461458, 0.24375047825742513, 0.21917844365816563, 0.16058350971434265, 0.17560278269229457, 0.15019093378214166, 0.1698056742316112, 0.13118723320076242, 0.12322281603701413, 0.15180636662989855, 0.12809670763090253, 0.15201502887066454, 0.19473202497465536, 0.2011882941587828, 0.18104854359989986], [0.03500997801893391, 0.025823993200901896, 0.10700785409426317, 0.07643326229299419, 0.07591810048324987, 0.019527428630681243, 0.0251238046985236, 0.02224351843324257, 0.06252651321119629, 0.021158402050787117, 0.009410195052623749, 0.024251770046248566, 0.03554821319994517, 0.03286316372395959, 0.016585935591137968, 0.0683409879275132, 0.0459171888360288, 0.00890882698513451, 0.02172789092583116, 0.029579703877971042, 0.021874615376873408, 0.04798586240212899, 0.09243004024028778, 0.09249515627743676, 0.048537259572185576, 0.02277003695780877, 0.032422183285234496, 0.062323491292772815, 0.02280257085658377, 0.028063919198757503, 0.0582266542915022, 0.026438656605023425, 0.033389795426046476, 0.01599196326424135, 0.06697551041725092, 0.06467534985858947, 0.06274396990193054, 0.09589993685949594, 0.028400310620781966, 0.08564104398828931, 0.01590090359968599, 0.04932465228193905, 0.026962226947944146, 0.06093708892876748, 0.014986733513069339, 0.09038857751875184, 0.01414826527252444, 0.0829501575208269, 0.07321673489059322, 0.14059763605473563, 0.3886473015882075, 9.074576161801815, 18.047654069960117, 40.430442318320274, 56.456105187535286, 82.06264615058899, 70.17403408885002, 61.695689633488655, 53.25198791921139, 48.23802016675472, 43.104898408055305, 38.64694721996784, 32.69777365028858, 25.67765984684229, 15.032206177711487, 16.153546907007694, 13.58010459691286, 17.744251750409603, 21.123159639537334, 14.102916643023491, 15.302364081144333, 15.717021580785513, 22.951118052005768, 18.650514520704746, 32.18497596681118, 41.46882399916649, 56.69009283185005, 69.72701847553253, 73.93066450953484, 51.06424391269684, 39.51379090547562, 40.1130111515522, 64.60589647293091, 65.0116690993309, 41.50445468723774, 64.70438718795776, 60.51240652799606, 43.86802285909653, 53.51140379905701, 54.89344283938408, 59.593961611390114, 47.911230102181435, 62.59825520217419, 82.26203665137291, 47.7530711889267, 46.957842260599136, 44.48099836707115, 40.08013531565666, 26.530850864946842, 31.531583927571774, 26.15461215376854, 18.240499421954155, 17.962373346090317, 11.009759120643139, 11.97146376594901, 28.70519869029522, 36.93097069859505, 41.443806141614914, 59.096078127622604, 57.62703895568848, 62.39972725510597, 55.80645024776459, 61.24556578695774, 58.745326548814774, 52.974902987480164, 36.155550107359886, 31.65683090686798, 15.712760109454393, 6.664972985163331, 3.110612123273313, 0.6842157477512956, 0.12173419396276586, 0.050868913167505525, 0.027307750497129746, 0.005874011194464401, 0.010510240663279546, 0.06678157980786636, 0.03065971985051874, 0.04397037220769562, 0.034692672779783607, 0.014583060838049278, 0.03316475769679528, 0.051915456424467266, 0.03527056462189648, 0.017039057565853, 0.03107755270320922, 0.04561863766866736, 0.003026269728252373, 0.03793046642385889, 0.01735100449877791, 0.01640687019971665, 0.02864915644749999, 0.046308141099871136, 0.044622638379223645, 0.022500167942780536, 0.12374626763630658, 0.020547640488075558, 0.018550890308688395, 0.017369795677950606, 0.031266700170817785, 0.021844755065103527, 0.020322083255450707, 0.036945636456948705, 0.03378802073711995, 0.0449949293397367, 0.0969389064994175, 0.02798077268380439, 0.024718072563700844, 0.0372514792252332, 0.0305434475740185, 0.019307339171064086, 0.02559379568992881, 0.05748517454776447, 0.08886451047146693, 0.07182475528679788, 0.025135024116025306, 0.01698972329904791, 0.01675422870903276, 0.04004602516943123, 0.012070715620211558, 0.025421229656785727, 0.05682201364834327, 0.04477301976294257, 0.08464675163850188, 0.032355657167499885, 0.07569067674921826, 0.04614441219018772, 0.08627054106909782, 0.06729053726303391, 0.08104975480819121, 0.002991069200106722, 0.021880968160985503, 0.04007496521808207, 0.023191246582427993, 0.036494262240012176, 0.054926887605688535, 0.024263093364425004, 0.05986820702673867, 0.01722270571917761, 0.054602446616627276, 0.0617756193241803, 0.05298619740642607, 0.0933417835040018, 0.023093383279046975, 0.011829694813059177, 0.03428596101002768, 0.04620496772986371, 0.04228493999107741, 0.028072149616491515, 0.03423224807193037, 0.0871499786444474, 0.0014774813939766318, 0.02370814316236647, 0.02983983220474329, 0.009614779191906564, 0.018901864932558965, 0.044830695769633166, 0.01194524720631307, 0.05986395452055149, 0.0440329204138834, 0.05940341477980837, 0.0508277313929284, 0.051585148758022115, 0.011722209565050434, 0.032014621756388806, 0.09374713714350946, 0.010163997230847599, 0.05018295720219612, 0.017861154956335668, 0.05254575502476655, 0.09083568438654765, 0.03688099910505116, 0.057369455171283334, 0.09376428075484, 0.027054282945755403, 0.15558657003566623, 0.9061108971945941, 13.21952959522605, 24.453109055757523, 49.074644073843956, 66.42600640654564, 89.31167677044868, 80.87311238050461, 70.45621454715729, 66.25642910599709, 56.929008811712265, 54.21433947980404, 46.67649395763874, 44.66470330953598, 34.867932200431824, 24.658368341624737, 25.704340115189552, 21.755800992250443, 29.71965305507183, 29.17258881032467, 25.313314497470856, 23.49865537136793, 22.218416668474674, 26.931119486689568, 26.159956566989422, 29.074255786836147, 39.01939183473587, 61.70922450721264, 70.79246610403061, 63.81653442978859, 54.771526381373405, 47.74395167827606, 43.38170975446701, 47.04897657036781, 48.04399497807026, 36.53654046356678, 38.915516808629036, 36.573770865798, 34.95634965598583, 39.29901123046875, 37.63488672673702, 41.12957440316677, 31.69302586466074, 49.67661917209625, 66.52581185102463, 36.617004945874214, 38.52050140500069, 36.6909109801054, 36.03412762284279, 34.89796198904514, 33.600099831819534, 30.852102488279343, 27.256762012839317, 29.076377972960472, 21.9193784147501, 22.260719798505306, 38.22678476572037, 44.94089528918266, 49.769011214375496, 65.8462943136692, 65.56727528572083, 66.79970115423203, 66.36267900466919, 68.63685697317123, 66.69432520866394, 60.57875096797943, 45.192046612501144, 37.72200085222721, 19.13811955600977, 6.88128350302577, 3.060714863240719, 0.6271714868489653, 0.04781437062774785, 0.011559389786270913, 0.06909753326908685, 0.025530375460220966, 0.0883696909295395, 0.012828845447074855, 0.027275339052721392, 0.04240277819917537, 0.013355460450839018, 0.029987920352141373, 0.014464281030086568, 0.03136971397907473, 0.0171641910856124, 0.0654119165847078, 0.018439343657519203, 0.013374543850659393, 0.06505066136014648, 0.02831739046087023, 0.030438400281127542, 0.004111067682970315, 0.0401191341370577, 0.047835974546615034, 0.033396229846403, 0.03029906019946793, 0.04048005539516453, 0.04104256251594052, 0.028899458739033435, 0.03756671758310404, 0.027404539541748818, 0.038879528583493084, 0.0878667226061225, 0.03369734142324887, 0.06423340091714635, 0.007968788413563743, 0.019524643721524626, 0.05397932829509955, 0.04330656192905735, 0.021303579123923555, 0.01375666084641125, 0.03973096863774117, 0.08169501510565169, 0.05935118242632598, 0.044219737537787296, 0.06548051329446025, 0.04950529102643486, 0.027401287079555914, 0.04711144545581192, 0.02381741884164512, 0.03872462752042338, 0.04070581300766207, 0.02371985054196557, 0.009155237639788538, 0.02579265972599387, 0.05001202203857247, 0.04421736637596041, 0.0834524430683814, 0.17881509469589218, 0.3002959565492347, 0.18893931002821773, 0.22266166924964637, 0.09138584588072263, 0.12975383433513343, 0.11150244885357097, 0.1275201331009157, 0.15164736891165376, 0.10691467745346017, 0.11286579640000127, 0.1039933689753525, 0.144560229673516, 0.12181892496300861, 0.14871765190036967, 0.18582482793135568, 0.08826511490042321, 0.08116715514915995, 0.1172540191328153, 0.14696628728415817, 0.11323730068397708, 0.15288987255189568, 0.14532673463691026, 0.18281163414940238, 0.13555348094087094, 0.1982127272640355, 0.14677806379040703, 0.09048351304954849, 0.10420810198411345, 0.1416534895543009, 0.1370131369912997, 0.16383223148295656, 0.10096688332851045, 0.11551524134119973, 0.11864489293657243, 0.1884654487366788, 0.2623820659937337, 0.15480019035749137, 0.18214432464446872, 0.20100458292290568, 0.10597220185445622, 0.219145254814066, 0.14212430804036558, 0.2786656469106674, 0.22348770929966122, 0.14315727370558307, 0.17996901558944955, 0.09115923850913532, 0.4417898249812424, 1.389699310529977, 18.465865328907967, 31.334365010261536, 59.310937598347664, 78.8449864089489, 100.94019278883934, 89.03707310557365, 80.56769236922264, 72.71464616060257, 67.87591740489006, 61.56511344015598, 57.19208389520645, 50.20322911441326, 43.01193259656429, 29.691137485206127, 32.10746772587299, 26.098587960004807, 29.324911236763, 34.85937885940075, 26.11857108771801, 26.729565002024174, 24.156529270112514, 37.16171331703663, 30.7124200835824, 46.070479676127434, 58.49788382649422, 75.06064027547836, 81.19967445731163, 90.48095002770424, 67.2470511496067, 55.89728057384491, 54.75080229341984, 90.52342414855957, 87.60273367166519, 53.97901810705662, 81.43440306186676, 77.0795251429081, 59.48287837207317, 70.17561480402946, 71.81040108203888, 76.88077300786972, 66.56997308135033, 80.09716361761093, 98.74270230531693, 67.89534196257591, 64.36147078871727, 63.95224794745445, 56.41276851296425, 40.363246724009514, 47.87481665611267, 38.89601245522499, 26.97229977697134, 29.833192862570286, 20.04429303109646, 23.99713922291994, 45.15062503516674, 54.26717944443226, 58.28324094414711, 77.17863902449608, 77.0714695751667, 79.42053392529488, 76.14376455545425, 81.71370327472687, 80.28858974575996, 76.54963597655296, 60.72967126965523, 48.76265801489353, 26.679206304252148, 11.304761040955782, 4.88294318318367, 1.2957343901507556, 0.19873027136782184, 0.15102145640412346, 0.1534497636021115, 0.15440196875715628, 0.21323715074686334, 0.10546139645157382, 0.07190520409494638, 0.25794491346459836, 0.13123587355948985, 0.06569515724550001, 0.12010395526885986, 0.12371542397886515, 0.15322873718105257, 0.16359260684112087, 0.20347590500023216, 0.08370517403818667, 0.11055689334170893, 0.20386750664329156, 0.08601734254625626, 0.0925372212077491, 0.18667087628273293, 0.12807491817511618, 0.12477288051741198, 0.15784519258886576, 0.2377325511770323, 0.09238377475412562, 0.11025808242266066, 0.12465346895623952, 0.1067067647818476, 0.11112518550362438, 0.1257068436825648, 0.11838713762699626, 0.07834938369342126, 0.1330230393796228, 0.21168848150409758, 0.15331669652368873, 0.09178053485811688, 0.08563443887396716, 0.0705148275301326, 0.11528976945555769, 0.22736269980669022, 0.1491427986184135, 0.13084174861432984, 0.1703620029729791, 0.09881264384603128, 0.10004685769672506, 0.1693710873951204, 0.1497599240974523, 0.17628172907279804, 0.08379345992580056, 0.10698826881707646, 0.14390252355951816, 0.2055369529989548, 0.13043356739217415, 0.3060807305155322], [0.02570810498582432, 0.04792152933077887, 0.05582326470175758, 0.138221783854533, 0.014869465830997797, 0.022101617942098528, 0.03295384674856905, 0.033635984364082105, 0.03667146484076511, 0.059755652910098433, 0.050628724493435584, 0.10539713388425298, 0.04222170900902711, 0.08013579252292402, 0.0494770857039839, 0.06710143803502433, 0.0353950079443166, 0.07996713204192929, 0.07133679318940267, 0.030451083584921435, 0.012525243964773836, 0.04844102899369318, 0.022011803230270743, 0.03976354521000758, 0.06770383930415846, 0.05850121182447765, 0.015802823218109552, 0.06684036532533355, 0.03595803085772786, 0.10170963956625201, 0.01236057252754108, 0.03605140787840355, 0.03405870054848492, 0.07741732042632066, 0.013090347674733493, 0.048180590820265934, 0.03094809246249497, 0.013615394891530741, 0.03777664889639709, 0.03593920628190972, 0.08617104133008979, 0.05711169615096878, 0.017406910483259708, 0.050283362361369655, 0.06736101160640828, 0.03874836882459931, 0.04629986244253814, 0.023097639495972544, 1.9504132540896535, 8.957413248717785, 23.844400718808174, 50.99233277142048, 61.75072968006134, 68.27887058258057, 67.49059528112411, 60.929684937000275, 40.69158710539341, 49.36562865972519, 29.83949862420559, 35.46766921877861, 31.48053366690874, 21.240732930600643, 22.626628763973713, 20.745165422558784, 18.774887546896935, 16.68344557285309, 23.721315823495388, 17.72348966449499, 21.87786754220724, 35.228973627090454, 36.74529366195202, 59.4209872931242, 52.767042741179466, 57.82749339938164, 64.27023768424988, 45.03634996712208, 29.9385517090559, 22.783005572855473, 17.620376497507095, 11.237628143280745, 13.872004933655262, 13.962578773498535, 10.928525179624557, 13.320569023489952, 26.102581545710564, 25.465110652148724, 23.765611946582794, 24.53801739960909, 24.258301109075546, 23.705799356102943, 26.445763930678368, 35.26460811495781, 31.054403632879257, 34.6971769630909, 37.38126553595066, 49.211056753993034, 59.36445772647858, 68.92090693116188, 72.3690015077591, 56.59047357738018, 59.050852954387665, 38.93945932388306, 42.12356686592102, 28.8958078622818, 25.68189661949873, 20.382951758801937, 16.03652648627758, 25.255251713097095, 29.108586944639683, 41.225002482533455, 55.73456570506096, 63.67914140224457, 52.66498401761055, 52.58355438709259, 56.096401289105415, 53.61947000026703, 58.7091638892889, 57.67372705042362, 40.98274268209934, 22.4284029006958, 15.425919201225042, 2.8281804034486413, 0.26442887960001826, 0.04500207622186281, 0.021830479854543228, 0.08615027603809722, 0.050053526647388935, 0.0802965417096857, 0.019940359597967472, 0.01824700681027025, 0.054172231029951945, 0.0468375669879606, 0.05664254378643818, 0.0505141220492078, 0.029437925841193646, 0.024803152373351622, 0.0580213799548801, 0.06318248269963078, 0.054626774217467755, 0.044539302616612986, 0.06069171635317616, 0.024432336431345902, 0.005963649182376685, 0.04129158645810094, 0.02504944335669279, 0.059762413875432685, 0.023852687554608565, 0.0639825030521024, 0.017297408448939677, 0.07107744226232171, 0.11225094931432977, 0.0742327721673064, 0.020074230051250197, 0.03024594840098871, 0.05576736242801417, 0.0824101857142523, 0.006069323126212112, 0.041929336221073754, 0.04523773408436682, 0.08531895189662464, 0.03978042906965129, 0.09816179517656565, 0.059624348432407714, 0.059138831711607054, 0.03022278040589299, 0.022362701784004457, 0.03327009813801851, 0.0647087390825618, 0.075654170505004, 0.004263545170033467, 0.07010482062469237, 0.04601161228492856, 0.03479282560874708, 0.038720809170627035, 0.0784691737499088, 0.04629562849004287, 0.04238970155711286, 0.11560218394151889, 0.07198832463473082, 0.08039398569962941, 0.019967483240179718, 0.022832228933111764, 0.01884668439743109, 0.03085340555117, 0.005716868381568929, 0.0906429041060619, 0.022447714800364338, 0.07760730281006545, 0.03113769635092467, 0.03445287744398229, 0.037958898101351224, 0.0449992449284764, 0.04340052153565921, 0.032232178637059405, 0.03756683261599392, 0.007878770538809476, 0.03462052118266001, 0.039455969526898116, 0.04662224768253509, 0.0463101411878597, 0.052842651202809066, 0.036595327910617925, 0.025146169318759348, 0.051258837556815706, 0.026877970922214445, 0.07798127844580449, 0.05630935658700764, 0.03385594580322504, 0.03726191011082847, 0.015276626600098098, 0.02349356043851003, 0.041345210338477045, 0.005018151186959585, 0.0373901569400914, 0.04096046613994986, 0.06475139030953869, 0.08082434971584007, 0.03656249158666469, 0.051324844171176665, 0.0873966388462577, 0.030368289590114728, 0.0404997148871189, 0.050834726134780794, 0.045614374030265026, 2.7899748785421252, 13.678211532533169, 31.829480342566967, 60.881560519337654, 74.60565268993378, 78.8544175028801, 76.02029398083687, 69.71169009804726, 49.602310359478, 57.29214392602444, 37.62700214982033, 43.34091134369373, 38.82101207971573, 37.357995584607124, 35.44198639690876, 32.646943777799606, 23.848337307572365, 24.81028039008379, 25.126368328928947, 20.185738541185856, 24.683131612837315, 29.77653030306101, 29.509807415306568, 40.77836684882641, 44.55036364495754, 40.56401275098324, 47.371396869421005, 41.00450411438942, 31.041778810322285, 26.835108138620853, 23.063538819551468, 14.045493174344301, 16.093700118362904, 14.668243657797575, 11.675322856754065, 10.94368351623416, 16.995843909680843, 17.215050347149372, 16.632315516471863, 16.117623634636402, 16.069149635732174, 19.418396316468716, 19.653979875147343, 22.313842847943306, 26.422868259251118, 29.711810275912285, 32.15032562613487, 43.6183762550354, 46.31238989531994, 48.13909247517586, 45.82088626921177, 45.291399881243706, 44.593806713819504, 33.392881751060486, 38.63288797438145, 30.77494192868471, 29.136971421539783, 32.9509312659502, 27.625330835580826, 33.56769137084484, 40.26137039065361, 49.642398208379745, 69.25564616918564, 71.55169576406479, 62.75057762861252, 61.32043696939945, 65.87988451123238, 61.41007795929909, 67.97933265566826, 65.7629419863224, 47.682178393006325, 28.381068482995033, 17.864222712814808, 3.4836404817178845, 0.5324669124092907, 0.05429446646303404, 0.08781859432929195, 0.03958857276302297, 0.043109020771225914, 0.04652401701605413, 0.0851074249658268, 0.0172941058917786, 0.02997420360770775, 0.03277580923167989, 0.08002170216059312, 0.03794883086811751, 0.010251350795442704, 0.035368316603126004, 0.026240115403197706, 0.031047779593791347, 0.030025456326256972, 0.06255478903767653, 0.04188410603092052, 0.06419644938432612, 0.017026795430865604, 0.011339719640091062, 0.018187683235737495, 0.06557865490322001, 0.0698555629060138, 0.1517450949177146, 0.013527192495530471, 0.1179545842751395, 0.08935083242249675, 0.026849823116208427, 0.028767089279426727, 0.029336019688344095, 0.06443579201004468, 0.17258133622817695, 0.030055075440031942, 0.03573461843188852, 0.06774535504519008, 0.07200378357083537, 0.029210908433014993, 0.04983086750144139, 0.09169083146844059, 0.04217714675178286, 0.06312912970315665, 0.008733005706744734, 0.03833131522696931, 0.04324608431488741, 0.05522501945961267, 0.006270625581237255, 0.06642902997555211, 0.043740187684306875, 0.021734826295869425, 0.02005754657147918, 0.016342999115295243, 0.027147511536895763, 0.14273493230575696, 0.19179733557393774, 0.15792972320923582, 0.15802247682586312, 0.07667434896575287, 0.0932649860624224, 0.12148653928306885, 0.1186585336108692, 0.16801317979115993, 0.2308095304761082, 0.17412093642633408, 0.21508880920009688, 0.1715257647447288, 0.18757212557829916, 0.09485557922744192, 0.21162346936762333, 0.11752813879866153, 0.13868182635633275, 0.1909168070415035, 0.08637703183921985, 0.07378585083642974, 0.09918247087625787, 0.10422766499686986, 0.15058189717819914, 0.14675530954264104, 0.13592436182079837, 0.12973878358025104, 0.241633323894348, 0.1555269755772315, 0.15596006327541545, 0.10098678030772135, 0.07733025908237323, 0.09734619714436121, 0.2427214608178474, 0.2360974662587978, 0.08207681297790259, 0.10455904877744615, 0.09554718664730899, 0.22839668963570148, 0.18337835295824334, 0.1586070071789436, 0.16027596371714026, 0.11061294033424929, 0.19483527255943045, 0.19243044691393152, 0.10806587466504425, 0.21228228870313615, 0.14825124177150428, 4.012971315532923, 19.09632369875908, 43.38732585310936, 73.14201682806015, 84.06807214021683, 88.9249487221241, 86.84336721897125, 81.19314640760422, 60.288689732551575, 67.6429595053196, 46.066303700208664, 51.44730135798454, 45.03812447190285, 38.1098498404026, 35.078334510326385, 34.06476549804211, 29.66247372329235, 28.704339936375618, 36.54859721660614, 27.951108254492283, 32.499036714434624, 49.418518021702766, 53.43878969550133, 78.01954910159111, 68.99383261799812, 78.00789892673492, 86.19141340255737, 62.418680638074875, 45.39155870676041, 36.54697850346565, 26.87666080892086, 17.65417568385601, 22.409945391118526, 19.914906173944473, 15.833002757281065, 18.659157156944275, 33.13185855746269, 33.11892785131931, 30.64128030091524, 31.454649455845356, 30.215068571269512, 30.036478154361248, 35.72505980730057, 46.79130479693413, 38.5184533149004, 45.94592235982418, 51.61389201879501, 66.22236013412476, 78.37101504206657, 86.59838676452637, 91.39398783445358, 74.37302157282829, 75.3245285153389, 53.628144934773445, 58.658246621489525, 41.57256223261356, 37.32807599008083, 34.08258654177189, 33.198301792144775, 40.03554470837116, 48.388226106762886, 59.28474560379982, 74.20504778623581, 77.91821613907814, 71.80374383926392, 71.96436882019043, 74.95754420757294, 71.9045752286911, 77.22066476941109, 75.62875539064407, 57.768235579133034, 37.360389456152916, 23.33332434296608, 6.302695199847221, 1.0424790484830737, 0.25958945334423333, 0.1793831048416905, 0.14963197783799842, 0.23681859631324187, 0.2175163445645012, 0.13029019930399954, 0.11020377947716042, 0.2324230337399058, 0.12517893919721246, 0.18071062891976908, 0.13458528992487118, 0.17409319494618103, 0.09484429116128013, 0.12360201639239676, 0.15992276079487056, 0.11535199853824452, 0.14028931822394952, 0.1466669494402595, 0.12410465074935928, 0.11256392041104846, 0.11797013226896524, 0.10716627293732017, 0.2007761350250803, 0.17297192855039611, 0.2409698735573329, 0.09951404761523008, 0.15457690780749545, 0.1574260721099563, 0.19579311803681776, 0.12924633891088888, 0.10967870999593288, 0.09532195967040025, 0.35381860798224807, 0.24959118047263473, 0.13308043708093464, 0.14932511461665854, 0.2182863376219757, 0.0913645833497867, 0.16798499302240089, 0.21218805079115555, 0.14091949065914378, 0.18630076723638922, 0.06388194946339354, 0.12319814704824239, 0.15431013540364802, 0.11051842040615156, 0.07981224582181312, 0.32964852056466043, 0.1511311309877783, 0.10676252975827083, 0.19433365494478494, 0.13772448553936556, 0.27033874997869134], [0.026400352508062497, 0.04859152912104037, 0.029302806724444963, 0.06455172289861366, 0.06292423757258803, 0.014753608229511883, 0.04710735993285198, 0.0270996764083975, 0.03375758897163905, 0.13370300992392004, 0.07075596615322866, 0.07702925140620209, 0.02861913471861044, 0.02008124334679451, 0.06132712464022916, 0.0502687234984478, 0.03480564249912277, 0.015045720338093815, 0.05757998391345609, 0.09242796964826994, 0.026312387599318754, 0.04309006631956436, 0.0732234439055901, 0.07912598186521791, 0.04592983503243886, 0.059820516617037356, 0.020505965185293462, 0.041654953092802316, 0.02408257521892665, 0.03584598882298451, 0.0866615712584462, 0.07497288635931909, 0.03029903793503763, 0.021787756268167868, 0.017565262533025816, 0.06197904942382593, 0.02680981022422202, 0.035615184606285766, 0.049747836019378155, 0.05922991920670029, 0.08174979302566499, 0.01227269574883394, 0.01592994940438075, 0.05030914457165636, 0.022401510541385505, 0.028085461890441366, 1.164919522125274, 6.097802594304085, 29.542928338050842, 62.18476518988609, 68.09857785701752, 68.62074583768845, 64.54013720154762, 51.20770521461964, 57.05692134797573, 42.62320205569267, 44.03150148689747, 34.555471166968346, 29.43733010441065, 17.931082025170326, 17.426668591797352, 13.78702249377966, 15.521756708621979, 17.65340242534876, 31.326353140175343, 33.46841409802437, 55.763075575232506, 75.35002514719963, 57.449573278427124, 65.28883382678032, 63.01483064889908, 57.76891194283962, 52.03590877354145, 48.41316416859627, 28.675938360393047, 17.444968409836292, 9.733885433524847, 5.015825852751732, 3.0309038003906608, 2.707388922572136, 1.1318696080707014, 1.1363673792220652, 2.0113075990229845, 1.6098581906408072, 0.9971302631311119, 0.4646134190261364, 1.1878106812946498, 1.2453257013112307, 0.7887601316906512, 0.7121866405941546, 1.373365530744195, 1.8161290534771979, 2.4872042750939727, 5.248742904514074, 8.36582014337182, 14.146798588335514, 20.101213976740837, 33.2330547273159, 58.49719226360321, 47.83141918480396, 67.84726694226265, 70.14821827411652, 68.34631696343422, 59.97328765690327, 38.22110027074814, 25.157083980739117, 22.528607323765755, 22.60755378752947, 12.334752772003412, 17.615147978067398, 16.64661604911089, 32.64791652560234, 55.024570003151894, 71.0087276995182, 69.12551835179329, 71.0197015106678, 68.18982616066933, 63.966656774282455, 67.320197224617, 64.33043405413628, 52.436426281929016, 31.431202813982964, 15.488985367119312, 2.669294779188931, 0.43130265490617603, 0.17503009701613337, 0.03366191129316576, 0.03653310253866948, 0.02950248155684676, 0.12287265592021868, 0.09068603030755185, 0.020220288424752653, 0.004714101169156493, 0.038935108022997156, 0.004684264977186103, 0.07247475790791214, 0.03880490934534464, 0.01726251452055294, 0.04008166681160219, 0.0458410333521897, 0.059402097467682324, 0.03526074600813445, 0.03032792046724353, 0.07124740150175057, 0.0339379976503551, 0.01952141166839283, 0.045706626697210595, 0.04418334261572454, 0.01479469909099862, 0.04674439776863437, 0.06401338381692767, 0.052905210541212, 0.05961231821856927, 0.034056960212183185, 0.035819772456306964, 0.024189800715248566, 0.047271174189518206, 0.019654844254546333, 0.00886135179825942, 0.021208688121987507, 0.02736820770223858, 0.01492738674642169, 0.05136945837875828, 0.05493856529938057, 0.05234202806605026, 0.04197065529297106, 0.029668817260244396, 0.009156132855423493, 0.04474536734051071, 0.033485996318631805, 0.03055613829928916, 0.03526113563566469, 0.015473522089450853, 0.03224126252462156, 0.03924778226064518, 0.046138411926222034, 0.05482972934260033, 0.034256019062013365, 0.08006168907741085, 0.041382069102837704, 0.0259301592814154, 0.02613836324599106, 0.007862751281209057, 0.05238368110440206, 0.009747101339598885, 0.015357395459432155, 0.010657022630766733, 0.07009282009676099, 0.015995289941201918, 0.010109389077115338, 0.05221437124419026, 0.0316839281731518, 0.024993288752739318, 0.03973952560045291, 0.04311682074330747, 0.09387385885929689, 0.02018011968175415, 0.043845821273862384, 0.019053439318668097, 0.05515592551091686, 0.03550816691131331, 0.055842927904450335, 0.02632382409501588, 0.014794040434935596, 0.030377111870620865, 0.026987940509570763, 0.06457070703618228, 0.011576962915569311, 0.027473492482386064, 0.058992435660911724, 0.05793541327875573, 0.02314117202331545, 0.022941066745261196, 0.0694306759396568, 0.03178759878210258, 0.10233621258521453, 0.08638849802082404, 0.030539542021870147, 0.09472194811678492, 0.02103969924064586, 0.0272375804343028, 0.08893634294508956, 1.4717448642477393, 9.158349316567183, 36.26795947551727, 71.31123706698418, 76.02981626987457, 77.46996939182281, 70.71633338928223, 60.47554470598698, 66.22957974672318, 52.581791281700134, 54.47366036474705, 49.752588495612144, 45.17738699913025, 35.329569429159164, 24.367480650544167, 18.566736616194248, 27.081148736178875, 23.088446483016014, 33.19538734853268, 24.702235087752342, 49.412453547120094, 56.96556285023689, 42.58853651583195, 48.065395429730415, 52.82150521874428, 51.012874469161034, 37.916121035814285, 39.26546663045883, 25.549031049013138, 15.680709779262543, 11.26994825899601, 5.0389309879392385, 3.0582278966903687, 2.659053853712976, 1.1536296154372394, 1.058120196685195, 1.2001380510628223, 1.5120294713415205, 0.6892418686766177, 0.2901030034990981, 0.4947202722541988, 0.8290274022147059, 0.8271784451790154, 0.3234981943387538, 0.5550254706759006, 1.2799566867761314, 1.8689216393977404, 3.726076022721827, 5.857142508029938, 9.10608597099781, 14.553103186190128, 24.963121488690376, 42.654151394963264, 40.1007454097271, 46.54505901038647, 46.8514783680439, 50.766974464058876, 43.978992104530334, 35.41905462741852, 32.16946519911289, 30.7926394790411, 29.807935617864132, 23.284356370568275, 30.624287612736225, 23.49456489086151, 38.18111501634121, 54.999084770679474, 74.31476309895515, 73.21406856179237, 75.49350544810295, 74.11313831806183, 71.66111469268799, 78.22049751877785, 73.68475690484047, 60.01660913228989, 35.788429006934166, 18.2816569134593, 3.283443949185312, 0.7270662859082222, 0.069933510676492, 0.04328267590608448, 0.029665440488315653, 0.07407816796330735, 0.03525298314343672, 0.03284001613792498, 0.04015630460344255, 0.04123192520637531, 0.022587810017284937, 0.037869973966735415, 0.031986368194338866, 0.030113697685010266, 0.02380807520239614, 0.004631850333680632, 0.009781925691640936, 0.07278323158971034, 0.03631523024523631, 0.00960837724051089, 0.021181479132792447, 0.10655009740730748, 0.053662420104956254, 0.07476921877241693, 0.02651591788890073, 0.047832972559263, 0.008577190874348162, 0.027645767222566064, 0.07119028581655584, 0.02948467001260724, 0.03240577440010384, 0.11080131967901252, 0.037830888759344816, 0.03179840816301294, 0.0291703834591317, 0.009351563530799467, 0.042033730424009264, 0.01619964030396659, 0.0057348334576090565, 0.02102587117406074, 0.021633229989674874, 0.02832865069649415, 0.03915801949915476, 0.03264175509684719, 0.053147458675084636, 0.015895192773314193, 0.14606512704631314, 0.04445109094376676, 0.06304505921434611, 0.024869728586054407, 0.06196702292072587, 0.047245020905393176, 0.008161592813848983, 0.11476086307084188, 0.19305199559312314, 0.16759310936322436, 0.14761021913727745, 0.12524677149485797, 0.08627084534964524, 0.09476428022026084, 0.16738051373977214, 0.1298366580158472, 0.2319533284753561, 0.11844232372823171, 0.2698738093022257, 0.07333076588110998, 0.07762011970044114, 0.11014851173968054, 0.10217322211246938, 0.2219625364523381, 0.16659031942253932, 0.15982337237801403, 0.15815729537280276, 0.10480343058588915, 0.11563600361114368, 0.11593420596909709, 0.21577051636995748, 0.14868208818370476, 0.15883112093433738, 0.10445364896440879, 0.1021225334261544, 0.1134830925730057, 0.1525320831569843, 0.20425743103260174, 0.1503549632616341, 0.1276990055339411, 0.11502793233375996, 0.11563421503524296, 0.19296618847874925, 0.10768452208139934, 0.1262298203073442, 0.08018458131118678, 0.21434121415950358, 0.187067954975646, 0.22194899967871606, 0.231394431903027, 0.19074966054176912, 0.07371232626610436, 0.28703208547085524, 2.1473790099844337, 11.580667085945606, 42.489061653614044, 79.01619002223015, 84.55270573496819, 86.07362732291222, 81.75800129771233, 71.50302037596703, 76.46855592727661, 64.37742993235588, 62.362496852874756, 48.792501613497734, 44.495270401239395, 30.798698253929615, 29.062615111470222, 23.018112257122993, 22.78388522565365, 27.43968229740858, 46.016062796115875, 46.36742614209652, 70.23826584219933, 89.67166945338249, 76.40075236558914, 84.1628086566925, 81.29105195403099, 79.0539675951004, 66.1895602941513, 60.7179868966341, 37.16192990541458, 23.88306364417076, 14.19200761243701, 7.19213199801743, 5.040124598890543, 4.473587824031711, 1.826184382662177, 2.1062291180714965, 3.4952058736234903, 3.0644747614860535, 1.807205944787711, 1.2984103965573013, 1.9697684654965997, 2.192318723537028, 2.2014211351051927, 1.0814478574320674, 2.224852340295911, 2.6689290488138795, 3.822811944410205, 7.03080452978611, 12.34859162941575, 19.026922322809696, 25.238262824714184, 43.11176843941212, 73.7693327665329, 64.04611051082611, 83.81797716021538, 86.66745185852051, 86.65084674954414, 77.73421481251717, 50.87200462818146, 40.433117374777794, 37.38578349351883, 36.62036396563053, 24.807909317314625, 31.40540599822998, 29.7824389860034, 46.59204348921776, 69.7248449921608, 89.30717781186104, 87.98911973834038, 88.25227081775665, 83.59274044632912, 81.3834097981453, 88.53850185871124, 87.4560995399952, 69.08183589577675, 46.91213831305504, 24.88715786486864, 5.5150240659713745, 1.0334119037725031, 0.32008152455091476, 0.09618192329071462, 0.20259760291082785, 0.11023289393051527, 0.2828107198001817, 0.24911837303079665, 0.10760727935121395, 0.1535147608956322, 0.17282989632803947, 0.1194854048662819, 0.1516542411991395, 0.10982146952301264, 0.14063382317544892, 0.10697279503801838, 0.07100635935785249, 0.14587292564101517, 0.11010238726157695, 0.0821015116525814, 0.10399491264251992, 0.3252153459470719, 0.13609478861326352, 0.25658262718934566, 0.15220577566651627, 0.1786940504098311, 0.1519566960632801, 0.2502849994925782, 0.09991413942771032, 0.1400419307174161, 0.1226855901768431, 0.24990427773445845, 0.14873932261252776, 0.11702821328071877, 0.11451758706243709, 0.13136987574398518, 0.17599690763745457, 0.1617330074077472, 0.13933650450780988, 0.1067388552473858, 0.09451773134060204, 0.1503143974696286, 0.144833117374219, 0.14605408388888463, 0.1299827720504254, 0.16762092505814508, 0.2736866078339517, 0.12239820091053843, 0.1884083478944376, 0.10341256420360878, 0.11209941760171205, 0.26831716939341277, 0.0755020599171985], [0.029338782333070412, 0.017552293502376415, 0.05070251994766295, 0.017523229143989738, 0.08858537388732657, 0.03641741655883379, 0.050895938475150615, 0.048235387293971144, 0.022960987844271585, 0.06345130343106575, 0.03535824565915391, 0.029797377646900713, 0.015166368502832484, 0.045436121290549636, 0.030328773937071674, 0.005432259849840193, 0.024179622159863357, 0.022924333170522004, 0.058196523095830344, 0.09714247018564492, 0.08011394369532354, 0.01214953819726361, 0.05148940428625792, 0.026213513119728304, 0.06476100854342803, 0.013312379705894273, 0.02033827877312433, 0.0036821422736466047, 0.034960606644744985, 0.04123502367292531, 0.08106913228402846, 0.027133119438076392, 0.02368547982769087, 0.02751775973592885, 0.044593282727873884, 0.05264499872282613, 0.026881744743150193, 0.02854215545085026, 0.017134323352365755, 0.031574090317008086, 0.05133099286467768, 0.029861330367566552, 0.04881502318312414, 0.0972762645687908, 1.4522921643219888, 7.313806694000959, 26.516799218952656, 46.623418405652046, 63.41226652264595, 62.8550074249506, 61.479656025767326, 60.99987857043743, 58.00186604261398, 55.34115381538868, 62.61454872786999, 47.04136177897453, 18.722461760044098, 13.047407381236553, 10.153135936707258, 14.448699038475752, 18.094326965510845, 37.47376397252083, 48.194691091775894, 40.33988557755947, 48.6063914000988, 52.108260691165924, 55.23041255772114, 65.1103726029396, 50.72749838232994, 42.72755965590477, 37.08301953971386, 24.651538208127022, 19.766565933823586, 9.895781446248293, 2.3121322318911552, 1.4327948167920113, 0.4253075266024098, 0.16606168763246387, 0.11889846995472908, 0.037230131347314455, 0.03524636689689942, 0.03590811771573499, 0.05332875422027428, 0.03789347407291643, 0.06224074553756509, 0.11692075029714033, 0.08390742412302643, 0.034060722900903784, 0.04139420321735088, 0.044258433117647655, 0.14508044550893828, 0.2108935671276413, 0.12761025951476768, 0.1366952751413919, 0.2566159050911665, 1.4201023103669286, 1.253602725919336, 1.945830937474966, 3.5435364302247763, 9.289476480334997, 18.526380881667137, 28.294317238032818, 41.42190411686897, 60.60416400432587, 54.87747609615326, 61.37634716928005, 39.87984046339989, 36.01489685475826, 28.29293791204691, 22.87733931094408, 48.59137460589409, 63.95499899983406, 66.59615367650986, 60.91551549732685, 61.731962487101555, 49.238840863108635, 64.60413336753845, 59.46065716445446, 46.62564128637314, 62.69206836819649, 56.98796644806862, 59.13116544485092, 50.004305988550186, 28.10214065015316, 10.523909591138363, 1.502469778060913, 0.32994561712257564, 0.10632780191372149, 0.011514620655361796, 0.07071029438520782, 0.05322517637978308, 0.03289952524937689, 0.015342541373684071, 0.02272764362714952, 0.07424953728332184, 0.04311554424930364, 0.07109972153557464, 0.04664414103899617, 0.016602216455794405, 0.011853886044264073, 0.015951954082993325, 0.0649704723036848, 0.06328460221993737, 0.04640199309505988, 0.04764657474879641, 0.024999507950269617, 0.015502375863434281, 0.06388779016560875, 0.025156067713396624, 0.017458855254517402, 0.04057647893205285, 0.06362318483297713, 0.04693420574767515, 0.051234472848591395, 0.02828453743859427, 0.034035419375868514, 0.05693647137377411, 0.017246628849534318, 0.04438301744812634, 0.025377127531100996, 0.03262442223785911, 0.055887282360345125, 0.07708384378929622, 0.04926877598336432, 0.09822240637731738, 0.08965630040620454, 0.06193370049004443, 0.04263999086106196, 0.11210565906367265, 0.07942221011035144, 0.10301945600076579, 0.07146134783397429, 0.011672406817524461, 0.028005517742712982, 0.034929139583255164, 0.03362574272614438, 0.026760000982903875, 0.026524838503974024, 0.08410919181187637, 0.02653815634403145, 0.04404742197948508, 0.04468889732379466, 0.037683479677070864, 0.061198877810966223, 0.04525003518210724, 0.0469063306809403, 0.017974211878026836, 0.03357781111844815, 0.03041582600417314, 0.019213503874198068, 0.028601720223377924, 0.027836159642902203, 0.03680979374621529, 0.048845473502296954, 0.053426157392095774, 0.04398079567181412, 0.022771257790736854, 0.010151214664801955, 0.020441223932721186, 0.0769259370281361, 0.04998698197596241, 0.07097246547346003, 0.013325095478649018, 0.03444724454311654, 0.0379522855655523, 0.010025998581113527, 0.07108711244654842, 0.024291209629154764, 0.09392235078848898, 0.06813814412453212, 0.03529504065227229, 0.03889041588990949, 0.07114460662705824, 0.04019548629003111, 0.038294827536446974, 0.010441256181366043, 0.04924226275761612, 0.05516254917893093, 0.023829181882319972, 0.27065021451562643, 2.543020904995501, 10.507839303463697, 34.33189116418362, 57.82783918082714, 73.85398462414742, 72.00552821159363, 68.58328744769096, 69.92501825094223, 65.0614008307457, 62.081657722592354, 71.733667999506, 54.11969795823097, 34.783466532826424, 22.693026401102543, 17.42384724318981, 19.399684220552444, 22.753631249070168, 36.774909272789955, 31.504301391541958, 29.922290481626987, 42.89698116481304, 47.34039053320885, 47.67929054796696, 58.19236122071743, 50.45836642384529, 45.4496955871582, 33.52329835295677, 21.155302114784718, 16.99582301080227, 7.00364881195128, 3.0598454223945737, 1.3001825264655054, 0.2740066219121218, 0.3114109538728371, 0.11443999552284367, 0.10413593554403633, 0.029302741786523256, 0.10539121154579334, 0.013485778799804393, 0.10844145333976485, 0.09538878264720552, 0.06725894403643906, 0.02835644412698457, 0.021653173353115562, 0.104396058304701, 0.044019186971127056, 0.14453569427132607, 0.09942885648342781, 0.13191786274546757, 0.2121121736126952, 0.13766931428108364, 0.7206661824602634, 0.7296699180733413, 1.4653859054669738, 3.4424072317779064, 7.46321277692914, 13.541816901415586, 20.738838762044907, 30.055467635393143, 42.26737014949322, 40.049695149064064, 45.365180522203445, 36.842173263430595, 35.88888801634312, 29.78511594235897, 18.262562938034534, 39.86032471060753, 56.01793929934502, 71.95597127079964, 76.21653825044632, 72.90948450565338, 61.50402411818504, 72.55451515316963, 69.29725393652916, 57.13819898664951, 71.07626527547836, 67.02654898166656, 68.00624281167984, 58.043868988752365, 33.745639622211456, 14.203111566603184, 2.192854732275009, 0.24165002221707255, 0.08442809266853146, 0.02378162505920045, 0.035625533855636604, 0.048922501009656116, 0.02977939169795718, 0.045124348762328736, 0.045922072167741135, 0.028391362175170798, 0.05258994991891086, 0.05066306366643403, 0.017385141436534468, 0.06193137385707814, 0.06178054718475323, 0.04020711945486255, 0.03571538196410984, 0.0429793527291622, 0.08603905778727494, 0.02109558852680493, 0.004526168968368438, 0.03315777408715803, 0.03475250843621325, 0.044661575157078914, 0.048609889854560606, 0.07094871674780734, 0.046223105819080956, 0.036095305913477205, 0.01322464950135327, 0.037432014069054276, 0.07919021474663168, 0.06553283470566384, 0.08276761887827888, 0.0397962739225477, 0.02265218205138808, 0.0507135965017369, 0.033992374810623005, 0.051363105594646186, 0.0422686312958831, 0.07647681151865982, 0.10108210175530985, 0.0476904653623933, 0.026027593994513154, 0.049906592539628036, 0.04477032205613796, 0.08305147552164271, 0.021791563485749066, 0.04862337467784528, 0.05289407090458553, 0.05252358336292673, 0.033645461589912884, 0.11023645623936318, 0.11767820848035626, 0.11801244952948764, 0.0770624254073482, 0.20255081792129204, 0.1756578203639947, 0.1428179192589596, 0.12165263935457915, 0.13379433861700818, 0.11049811524571851, 0.12734863761579618, 0.10870774334762245, 0.10069004740216769, 0.272711900761351, 0.10767201689304784, 0.07020634642685764, 0.13249690120574087, 0.1438430033158511, 0.22342195501551032, 0.3054065041942522, 0.16784012579591945, 0.15683689591242, 0.11783480164012872, 0.20596858608769253, 0.16804740764200687, 0.21727148036006838, 0.1645827357424423, 0.10434185183839872, 0.12118380982428789, 0.11620695266174152, 0.1823705164133571, 0.07068009639624506, 0.21340554405469447, 0.1020448750932701, 0.08982669009128585, 0.1652824622578919, 0.16461181308841333, 0.1123504490533378, 0.10144270388991572, 0.20110417914111167, 0.09341743803815916, 0.12504754937253892, 0.24637668655486777, 0.4539785615634173, 3.7214193725958467, 14.708123467862606, 41.82512328028679, 70.72150871157646, 85.45150950551033, 79.63395327329636, 80.72748139500618, 79.40376162528992, 76.28508657217026, 70.58890342712402, 76.0393537580967, 62.64853410422802, 31.140085235238075, 22.415270805358887, 17.902061082422733, 22.736262381076813, 30.098431929945946, 54.203042685985565, 64.20970693230629, 55.784331634640694, 64.50376555323601, 70.71593061089516, 72.06456944346428, 81.14409103989601, 65.54959863424301, 57.288078144192696, 48.240045458078384, 31.978217661380768, 25.57787910103798, 13.554337229579687, 4.180566547438502, 2.259162599220872, 0.8102419227361679, 0.8018013287801296, 0.42772039712872356, 0.34211235644761473, 0.2521239226916805, 0.3467069036560133, 0.10054093509097584, 0.22083804913563654, 0.19276499224361032, 0.34295531746465713, 0.2554273110581562, 0.2888368401909247, 0.2828073059208691, 0.27895386738236994, 0.6235274230130017, 0.6143281166441739, 0.3890542656881735, 0.5315546051133424, 0.7659598113968968, 2.0713536394760013, 2.326869028620422, 2.8600628301501274, 5.100903762504458, 11.727884486317635, 23.52437239140272, 36.916269287467, 51.44321657717228, 77.67227813601494, 68.94198060035706, 78.07599127292633, 55.310827642679214, 53.99370051920414, 43.32541957497597, 34.60073433816433, 60.37333399057388, 71.06779173016548, 78.0384948849678, 71.10306903719902, 76.92330792546272, 63.77751052379608, 80.75259804725647, 77.75167867541313, 66.44285470247269, 81.06468290090561, 77.49450847506523, 77.62836009263992, 69.40015241503716, 42.97222472727299, 22.41180919110775, 4.175796378403902, 0.5528430221602321, 0.3236986038973555, 0.1004259689943865, 0.17439213203033432, 0.2215320462710224, 0.13758148852502927, 0.20422344066901132, 0.11547236004844308, 0.0986232774448581, 0.19407813349971548, 0.15666271385271102, 0.10254228473058902, 0.10380396546679549, 0.15392476780107245, 0.10882152200792916, 0.14044859795831144, 0.18630173202836886, 0.15156056731939316, 0.13550004630815238, 0.09157440334092826, 0.1267018262296915, 0.09510753836366348, 0.15537814528215677, 0.11102602715254761, 0.16415479854913428, 0.1663799799280241, 0.17323558393400162, 0.16075819643447176, 0.12393755619996227, 0.1312161621171981, 0.12540201394585893, 0.142213054059539, 0.14491364039713517, 0.2602490148274228, 0.12663558212807402, 0.10442746599437669, 0.153906763298437, 0.17510499455966055, 0.22994709550403059, 0.21937535027973354, 0.1702003928949125, 0.14069108729017898, 0.21999931836035103, 0.1728886298951693, 0.2552341448608786, 0.09556254168273881, 0.09323101796326227, 0.22542772785527632, 0.17820182838477194, 0.15100888442248106], [0.010659984727681149, 0.03473743541690055, 0.03871618187986314, 0.03303493751445785, 0.01357690989607363, 0.03091132646659389, 0.05898770075873472, 0.052651210498879664, 0.013083391895634122, 0.07691801831242628, 0.0465598553273594, 0.0015509898457821691, 0.05093078601930756, 0.05753270539571531, 0.013006047120143194, 0.04014300160633866, 0.04323012813983951, 0.03197499849193264, 0.06844206844107248, 0.012021195816487307, 0.018625116208568215, 0.08489902247674763, 0.028532602154882625, 0.03464108980551828, 0.049642695958027616, 0.09618634649086744, 0.03471350486506708, 0.08092448028037325, 0.005707201444238308, 0.043674522457877174, 0.023984741601452697, 0.010026608997577569, 0.06287901109317318, 0.020522036393231247, 0.030566413333872333, 0.05804545522551052, 0.03658707151771523, 0.041244512030971237, 0.055570196054759435, 0.015063184000609908, 0.02645808974193642, 0.05915908492170274, 0.7550757110584527, 8.135456554591656, 26.321009024977684, 50.89315049350262, 71.72096908092499, 68.16376715898514, 64.0376977622509, 56.3490991294384, 51.14059321582317, 35.710624381899834, 30.804890021681786, 31.86135683208704, 89.17041555047035, 65.84873378276825, 15.001727063208818, 23.668453060090542, 45.265295282006264, 55.1090394705534, 40.11775329709053, 44.333524480462074, 75.51203325390816, 63.01023289561272, 55.401407182216644, 42.90310263633728, 41.87506780028343, 35.571646839380264, 24.009765945374966, 14.483457673341036, 5.900585576891899, 1.6565886768512428, 0.3047166927717626, 0.04110430549189914, 0.083340720157139, 0.08822504634736106, 0.04357564241217915, 0.055337180237984285, 0.07615323513164185, 0.12957711413037032, 0.13876839046133682, 0.04505041601078119, 0.21713406429626048, 0.15989408420864493, 0.09243409978807904, 0.0559730263921665, 0.07830973816453479, 0.05744030429923441, 0.16659524728311226, 0.16269437066512182, 0.10161632933886722, 0.12732684816000983, 0.1045623142272234, 0.12386138216243125, 0.1135589623299893, 0.12250815008883364, 0.08721711332327686, 0.011521117230586242, 0.16986997390631586, 0.1528049263288267, 0.669596150983125, 1.5602467465214431, 5.801486894488335, 12.875366862863302, 24.521839767694473, 35.916086956858635, 48.13176266849041, 42.494867742061615, 54.72070790827274, 54.02640916407108, 38.89083333313465, 37.04402983188629, 22.11210787296295, 15.326789170503616, 14.380847029387951, 14.938882235437632, 30.582723543047905, 25.620393119752407, 30.889558978378773, 46.58217541873455, 48.22505906224251, 59.27901171147823, 63.00067260861397, 62.39628084003925, 53.88069458305836, 25.830892324447632, 7.936413260176778, 0.6510273786261678, 0.1746980453026481, 0.11174152430612594, 0.04418265612912364, 0.01978099266125355, 0.09998199398978613, 0.02884710022044601, 0.01787940251233522, 0.052704136760439724, 0.04589956653944682, 0.06372920062858611, 0.029827809412381612, 0.047799149178899825, 0.025273915198340546, 0.058443528396310285, 0.01299485367781017, 0.008275630298157921, 0.02871886081265984, 0.03792617681028787, 0.019740590141736902, 0.04942517618474085, 0.03588223902625032, 0.05481740226969123, 0.08888869706424884, 0.0182216105167754, 0.03952846622269135, 0.048688449896872044, 0.04108106513740495, 0.022440128195739817, 0.012768102515110513, 0.0780193432001397, 0.04642261366825551, 0.03391177757293917, 0.048506126477150247, 0.07805973087670282, 0.011067889499827288, 0.04566950818116311, 0.028433942898118403, 0.040994578957906924, 0.04785569712112192, 0.015924507606541738, 0.0691243248002138, 0.014353130500239786, 0.041953148029278964, 0.06921102249179967, 0.02828949312970508, 0.08460830096737482, 0.016529755012015812, 0.02268302570882952, 0.040764639343251474, 0.037448319053510204, 0.022851474677736405, 0.008858579876687145, 0.01997118099097861, 0.021038613849668764, 0.1040439389180392, 0.04696853749919683, 0.02828252992912894, 0.008604073318565497, 0.031059264329087455, 0.07010656467173249, 0.018497411147109233, 0.005791390212834813, 0.04383313425933011, 0.01381246014716453, 0.023827834884286858, 0.0038156019945745356, 0.08701434373506345, 0.0596447352290852, 0.04483666634769179, 0.047894225717755035, 0.017882911015476566, 0.02017643677390879, 0.05500416002178099, 0.08654400022351183, 0.04470717642107047, 0.016641177353449166, 0.02077649100101553, 0.015528139520029072, 0.04229499238135759, 0.04556049781967886, 0.053423381759785116, 0.014909795063431375, 0.03248752938816324, 0.061225583995110355, 0.0374807880143635, 0.04554286068014335, 0.0017768591283129354, 0.020275407732697204, 0.04821884482225869, 0.08489032450597733, 0.9341410431079566, 10.64837096258998, 33.71537044644356, 61.687371879816055, 83.0472569167614, 78.134705722332, 71.94130405783653, 67.00833275914192, 58.59701290726662, 46.64650596678257, 43.349206298589706, 47.33553819358349, 92.02157735824585, 71.14786103367805, 17.22224336117506, 21.58894244581461, 34.202736094594, 39.42320756614208, 38.65429602563381, 42.09459722042084, 59.135276824235916, 53.56188789010048, 43.57339046895504, 38.37239295244217, 38.66184242069721, 26.69947251677513, 19.52462151646614, 12.121749501675367, 6.267672479152679, 2.3078422620892525, 0.45465822040569037, 0.35945103387348354, 0.06960836835787632, 0.07521654828451574, 0.06851479891338386, 0.16856450645718724, 0.19478971953503788, 0.1591918195481412, 0.08497791277477518, 0.0266391774857766, 0.10035162064014003, 0.04589575190038886, 0.057031599862966686, 0.06265062256716192, 0.052041320959688164, 0.040975290539790876, 0.05800616963824723, 0.31901627546176314, 0.29943277942948043, 0.10913795151282102, 0.25651627918705344, 0.12392982302117161, 0.11720488153514452, 0.07011951514868997, 0.04098334284208249, 0.06312665835139342, 0.2028548312955536, 0.1736081569106318, 0.3618178912438452, 1.1982804257422686, 3.4971235832199454, 9.287871066480875, 18.6280520260334, 27.313937544822693, 35.83685740828514, 35.91419845819473, 43.18201906979084, 49.169209599494934, 45.33102795481682, 45.23584686219692, 32.28550337255001, 21.700996533036232, 23.775869496166706, 24.97408390045166, 45.8724495023489, 36.00942514836788, 40.86600914597511, 55.37638932466507, 58.798827677965164, 68.37541580200195, 71.62422627210617, 72.48459130525589, 61.17225632071495, 32.43116095662117, 10.937116518616676, 1.3694719271734357, 0.07189504409325309, 0.05674216597981285, 0.008134541531035211, 0.021212063038547058, 0.039308070627157576, 0.05243628082098439, 0.03570292501535732, 0.08109722257358953, 0.00835194812680129, 0.027440544836281333, 0.05838192271767184, 0.027857655950356275, 0.04142587065871339, 0.03825766820227727, 0.051044846695731394, 0.012016686341667082, 0.03896512047504075, 0.06335126192425378, 0.03605980899010319, 0.015083495654835133, 0.004930888535454869, 0.0052608413625421235, 0.03276985720731318, 0.0353648878808599, 0.08079202918452211, 0.12420279235811904, 0.01912369843921624, 0.10101737905642949, 0.040656411947566085, 0.08136238451697864, 0.012549755247164285, 0.016587690770393237, 0.03807367495028302, 0.0608848528645467, 0.01510270243670675, 0.06757446812116541, 0.026256585515511688, 0.06547380427946337, 0.03259052464272827, 0.03752041498955805, 0.11674753302941099, 0.025269851939810906, 0.024751292949076742, 0.038115209245006554, 0.06316732804407366, 0.035849265404976904, 0.021966268759570085, 0.05112597827974241, 0.09144473529886454, 0.1417649898212403, 0.07820205995813012, 0.1440395982353948, 0.18202325067250058, 0.13565251312684268, 0.21849692944670096, 0.17521392699563876, 0.12751180620398372, 0.18506985594285652, 0.2571690722834319, 0.14743421139428392, 0.19594657933339477, 0.10265400022035465, 0.1405161779257469, 0.13924419617978856, 0.13093018293147907, 0.09733478291309439, 0.28215599711984396, 0.12716032506432384, 0.10420954917208292, 0.26934255030937493, 0.13745091506280005, 0.11449597572209314, 0.16074624785687774, 0.3128492954419926, 0.16102679452160373, 0.13090307969832793, 0.17685428116237745, 0.1482497129472904, 0.21773738582851365, 0.1387337173218839, 0.2383916822145693, 0.11789833690272644, 0.11791604454629123, 0.21008636278565973, 0.19486960431095213, 0.16642623057123274, 0.1353516909875907, 0.14158058096654713, 0.21346925001125783, 0.11201093133422546, 1.4106801222078502, 14.839105289429426, 44.01541315019131, 73.94236788153648, 92.35445469617844, 87.33212739229202, 81.79129511117935, 77.49330013990402, 68.26693922281265, 55.19318975508213, 45.9485974162817, 47.23786063492298, 97.61047706007957, 75.36175891757011, 26.795772649347782, 37.30484403669834, 62.826524153351784, 72.57333934307098, 53.409709855914116, 60.213305577635765, 103.44199374318123, 79.33387577533722, 71.23021021485329, 56.024402752518654, 56.95882201194763, 46.23073227703571, 33.16177815198898, 21.574446223676205, 9.577983599156141, 3.008846458978951, 0.8638917782809585, 0.5213994719088078, 0.27607899508439004, 0.2038847393123433, 0.2604790509212762, 0.19714295107405633, 0.31335873529314995, 0.19659312354633585, 0.1894521340727806, 0.2552064775954932, 0.6201708968728781, 0.5219425458926708, 0.32625708379782736, 0.1991300069494173, 0.265873663011007, 0.2840195002499968, 0.6314173433929682, 0.49805928370915353, 0.5117103480733931, 0.3925430722301826, 0.647298531839624, 0.5410304060205817, 0.2496767055708915, 0.20589843828929588, 0.1779098526458256, 0.2179908292600885, 0.547367634717375, 0.6262826907914132, 1.3090589689090848, 2.7903667325153947, 8.37034285068512, 17.318064719438553, 31.8565196916461, 47.631834894418716, 59.80064392089844, 54.652733355760574, 69.354228079319, 71.01828798651695, 51.08690209686756, 48.6593871563673, 35.04692539572716, 25.79041689634323, 27.275684997439384, 27.891067676246166, 46.24626584351063, 40.53330659866333, 48.03496666252613, 66.95691391825676, 68.69191601872444, 80.63704624772072, 81.7647497355938, 83.54585096240044, 71.4415092766285, 43.54474760591984, 14.291434977203608, 2.345584211871028, 0.3678092494374141, 0.12717893812805414, 0.16724262270145118, 0.13541048392653465, 0.178224167029839, 0.12326261741691269, 0.2019766776356846, 0.24735072569455951, 0.10973779979394749, 0.12109581337426789, 0.14600346941733733, 0.11819053528597578, 0.16204089479288086, 0.19445409066975117, 0.2116080920677632, 0.12003320633084513, 0.14204408187652007, 0.12239754782058299, 0.1546527404570952, 0.15907366963801906, 0.15396505157696083, 0.13409199920715764, 0.18820284720277414, 0.08830565100652166, 0.1694491910166107, 0.23984363477211446, 0.11868300221976824, 0.17738119116984308, 0.10527683916734532, 0.19981134304543957, 0.2195716928690672, 0.1196366768272128, 0.08578700217185542, 0.12838736234698445, 0.15153236570768058, 0.15875405631959438, 0.11210024138563313, 0.22070085571613163, 0.12747364497045055, 0.10194199116085656, 0.19774697022512555, 0.08299974040710367, 0.1865941975847818, 0.1535715500358492, 0.1260653158533387, 0.11436287895776331, 0.10443861305247992, 0.12368377880193293], [0.055029252034728415, 0.09619223914342001, 0.03019171595951775, 0.03695994135341607, 0.04083768522832543, 0.01011281037790468, 0.05194504214159679, 0.07108950216206722, 0.024512106174370274, 0.03874574904330075, 0.01197464738652343, 0.03370758677192498, 0.05002652731491253, 0.03829682391369715, 0.06481441349023953, 0.04944021951814648, 0.0707565524498932, 0.02209495160059305, 0.03381318325409666, 0.020099244138691574, 0.038209473132155836, 0.03437011313508265, 0.0729989368119277, 0.04505586708546616, 0.027445656378404237, 0.0063361409866047325, 0.012743893657898298, 0.0657813205907587, 0.05189702147617936, 0.015517798619839596, 0.02529792553104926, 0.03906300233211368, 0.10916288767475635, 0.07693499865126796, 0.05147424220922403, 0.038385543957701884, 0.024797293117444497, 0.04009075812064111, 0.06650299983448349, 0.005860146948180045, 0.12821272015571594, 2.7861059736460447, 17.10181452333927, 35.26051573455334, 67.01597034931183, 72.7801850438118, 59.385808780789375, 56.18676044046879, 47.30008229613304, 36.330268532037735, 31.78080305457115, 17.195709384977818, 22.28167947381735, 16.345784291625023, 24.82749916613102, 25.556744635105133, 43.41620430350304, 45.86470551788807, 42.67397493124008, 57.62346714735031, 47.87834286689758, 55.635064244270325, 31.374779641628265, 28.968978635966778, 27.06411425024271, 18.653573356568813, 11.98724526911974, 7.521827006712556, 4.283742411062121, 1.2346132448874414, 0.03530964982928708, 0.05535141463042237, 0.035622105133370496, 0.04319895422668196, 0.011466223349998472, 0.04569780627207365, 0.08563325143768452, 0.034205456540803425, 0.05213021911913529, 0.04534790961770341, 0.07460813561920077, 0.10297206245013513, 0.12009457452222705, 0.017959957076527644, 0.10289166559232399, 0.10757646537967958, 0.010335247807233827, 0.04633626107533928, 0.044547150828293525, 0.018479009595466778, 0.06386276494595222, 0.05068879763712175, 0.23421873425832018, 0.67258914350532, 0.22837184253148735, 0.0989231644780375, 0.10988734997226857, 0.1559236238244921, 0.07547167639131658, 0.032427129699499346, 0.04204215008940082, 0.05331812295480631, 0.04781647090567276, 0.31488016771618277, 1.248247150797397, 2.793316561728716, 7.293403688818216, 17.219093330204487, 28.864554539322853, 25.344064347445965, 30.688532665371895, 49.24561969935894, 60.134892985224724, 58.190366327762604, 41.48180030286312, 34.827175587415695, 19.63330138474703, 20.358340479433537, 17.403966709971428, 25.09132280945778, 33.139914125204086, 50.18715217709541, 55.267464369535446, 61.509161442518234, 68.76701518893242, 60.433214977383614, 51.14516817033291, 29.769684970378876, 8.591430187225342, 3.7265395978465676, 0.5233027541544288, 0.06951011542696506, 0.017566271853866056, 0.006912612543601426, 0.04647591100365389, 0.07379880131338723, 0.0681139575317502, 0.041927903876057826, 0.029992647832841612, 0.10783387930132449, 0.021642690517182928, 0.05522942781681195, 0.02399518918537069, 0.007062717477310798, 0.02475649911502842, 0.026649682586139534, 0.03414751336094923, 0.05586923703958746, 0.02467831756803207, 0.02942368959338637, 0.03622971256845631, 0.08836368695483543, 0.027501885197125375, 0.07213069082354195, 0.024694353523955215, 0.12553742621093988, 0.09924285201122984, 0.047265789908124134, 0.02639635233208537, 0.06445510269259103, 0.03577502095140517, 0.010876134310819907, 0.027647446331684478, 0.03329981002025306, 0.07958046568091959, 0.050474996023694985, 0.06317973675322719, 0.07733598846243694, 0.0802467881294433, 0.0367970659135608, 0.029482148565875832, 0.03199178958311677, 0.03390929508896079, 0.058165022637695074, 0.020803924489882775, 0.0513533203775296, 0.04807616693142336, 0.09268900525057688, 0.06486556972959079, 0.05064782366389409, 0.03821229329332709, 0.07152690915972926, 0.016620942697045393, 0.038146527876961045, 0.03135913095320575, 0.0382788639399223, 0.022641454306722153, 0.12159613223047927, 0.03867749372147955, 0.0430357225559419, 0.0281691353302449, 0.047805706053623, 0.016005067736841738, 0.005347471796994796, 0.046963739514467306, 0.013620150202768855, 0.050537529386929236, 0.05795503195258789, 0.04864759466727264, 0.023316326296480838, 0.0063139039230009075, 0.02819377463310957, 0.0452360790950479, 0.05896702452446334, 0.04218392998154741, 0.014651518395112362, 0.006318429168459261, 0.0045842072358937, 0.07135385516448878, 0.011292440194665687, 0.04341648513218388, 0.01909690134198172, 0.021245658208499663, 0.0674322948907502, 0.08354843244887888, 0.013978678034618497, 0.11847604691865854, 3.6670098546892405, 20.561340786516666, 42.65413239598274, 77.11401209235191, 81.41036555171013, 66.38131320476532, 64.0569019317627, 56.81874252855778, 46.366214007139206, 44.463317915797234, 29.59171772003174, 30.73396112769842, 24.15576931089163, 43.91527712345123, 40.11885143816471, 43.68624061346054, 43.229075744748116, 41.19436472654343, 48.08916315436363, 38.629034981131554, 40.51331967115402, 28.11346974223852, 26.016326174139977, 23.0717121809721, 16.67444195598364, 11.09460761770606, 7.46386444196105, 3.979946575127542, 1.1382587277330458, 0.08251750026829541, 0.059052167416666634, 0.1438182601123117, 0.0700380421767477, 0.10255743196466938, 0.046303469280246645, 0.11285296466667205, 0.10222767348750494, 0.06568840370164253, 0.1743512396933511, 0.1576154978829436, 0.056415762010146864, 0.1239451186847873, 0.10073401223053224, 0.09992680788855068, 0.04958845238434151, 0.0790050117939245, 0.0977770435565617, 0.22089829668402672, 0.23093722440535203, 0.07131875900086015, 0.24693282233783975, 0.5003057944122702, 0.7730886444915086, 0.3964267607079819, 0.08334612299222499, 0.19933010480599478, 0.009752156292961445, 0.027073205856140703, 0.05095439373690169, 0.05461999840917997, 0.015343747363658622, 0.08466268554911949, 0.1271169984829612, 0.9885941399261355, 2.0253062853589654, 5.3131950460374355, 11.536154374480247, 21.429742388427258, 26.707898564636707, 31.693200655281544, 45.687787011265755, 59.93803694844246, 51.39289207756519, 42.79063247144222, 36.65345638990402, 25.88409896939993, 27.523577995598316, 24.25380975008011, 35.798760652542114, 44.977384731173515, 57.15381234884262, 64.82560828328133, 69.69364106655121, 76.31851717829704, 70.08371293544769, 62.22336731851101, 38.888511657714844, 12.768069170415401, 6.31122431717813, 0.8923560508992523, 0.06282118294620886, 0.055744559940649197, 0.0217344774864614, 0.07101899813278578, 0.05334093286364805, 0.04941468592733145, 0.034526479939813726, 0.03850127446639817, 0.0023247810759130516, 0.061412041177391075, 0.0441253660392249, 0.04979690311301965, 0.024058715171122458, 0.03169945390254725, 0.007920647149148863, 0.03766515234019607, 0.04062244755914435, 0.030701152099936735, 0.07290224981261417, 0.058810008340515196, 0.09644762700190768, 0.02264904833282344, 0.09419517169590108, 0.03895257817930542, 0.12805263890186325, 0.02006599221203942, 0.0306745127090835, 0.04727899642603006, 0.020839258140767924, 0.035247650812380016, 0.03622859934694134, 0.059300746070221066, 0.02592587894469034, 0.05551247922994662, 0.009316308733104961, 0.04625173045496922, 0.05029573025240097, 0.03745361427718308, 0.05092809573397972, 0.022200305029400624, 0.014143460794002749, 0.03840277291601524, 0.08203160876291804, 0.028121071991336066, 0.02708620457269717, 0.18131132324924693, 0.1813164440682158, 0.1302588064572774, 0.0695307768182829, 0.16927938762819394, 0.12859733076766133, 0.1067485476960428, 0.20821089623495936, 0.13177363376598805, 0.10720670514274389, 0.10279045149218291, 0.3484559973003343, 0.13391740154474974, 0.1893819565884769, 0.11428760291892104, 0.146487127058208, 0.1597439477336593, 0.11873461859067902, 0.1005668805737514, 0.0862957740901038, 0.2267938436125405, 0.11573459050850943, 0.15910878806607798, 0.1434589270502329, 0.10461543715791777, 0.11371016007615253, 0.2121065036044456, 0.14879467198625207, 0.1613403222290799, 0.07926356862299144, 0.1818722829921171, 0.16101497953059152, 0.23098297038814053, 0.14746603468665853, 0.14381521730683744, 0.1085162692470476, 0.05958917805401143, 0.1213113107951358, 0.2096779886051081, 0.07940308496472426, 0.3817715111654252, 6.546065965667367, 27.803041599690914, 53.14201422035694, 86.94011002779007, 89.88002747297287, 76.42440229654312, 75.01390278339386, 65.88315233588219, 55.39899431169033, 47.12724097073078, 31.140121333301067, 33.47009360790253, 28.162789195775986, 37.91882649064064, 35.03689393401146, 62.549906596541405, 62.61071093380451, 60.179236605763435, 73.95648792386055, 64.08618316054344, 69.77782934904099, 41.605742052197456, 37.376637384295464, 35.363775193691254, 24.665006585419178, 15.812493357807398, 10.9855430200696, 6.7718360759317875, 2.1088984748348594, 0.1912755166995339, 0.24865107232471928, 0.30896361800841987, 0.21832565660588443, 0.15173605555901304, 0.15637795178918168, 0.13899410725571215, 0.24746108305407688, 0.18367208016570657, 0.18724848981946707, 0.3149428643519059, 0.3185465553542599, 0.3631604363908991, 0.25881554174702615, 0.3154566086595878, 0.4282110754866153, 0.1382162474328652, 0.1873602721025236, 0.13775056460872293, 0.35359916975721717, 0.6027683650609106, 0.8457580825779587, 1.2888378789648414, 2.3102990677580237, 1.2554736505262554, 0.7037270476575941, 0.4243684426182881, 0.30684710189234465, 0.16002185235265642, 0.26931758446153253, 0.18473617150448263, 0.19162667129421607, 0.4992050409782678, 0.6758672988507897, 2.2272576112300158, 3.6714679654687643, 9.644744116812944, 21.901582069694996, 37.61929236352444, 34.8039398342371, 42.858645021915436, 65.20952448248863, 76.80134207010269, 73.14379513263702, 56.544184461236, 46.32668852806091, 29.65360499918461, 32.335064113140106, 29.63733997195959, 41.11885517835617, 47.46336333453655, 69.08166110515594, 75.16532465815544, 79.69339728355408, 87.02788531780243, 80.48872500658035, 72.5906740128994, 46.693836227059364, 17.412350960075855, 7.471537180244923, 1.404063489753753, 0.1905753745813854, 0.14006308192620054, 0.20474190503591672, 0.15208649769192562, 0.11652159359073266, 0.2530381892574951, 0.16003832803107798, 0.132419673318509, 0.21801819966640323, 0.10447724926052615, 0.15775276551721618, 0.2006147921201773, 0.09698667854536325, 0.13907262647990137, 0.07995971798663959, 0.11488133590319194, 0.1512874272884801, 0.12462370883440599, 0.27383278124034405, 0.1398353316471912, 0.3051812178455293, 0.09616861658287235, 0.19861651497194543, 0.12816779053537175, 0.25120612350292504, 0.21920703118667006, 0.1282176183303818, 0.13453379971906543, 0.10638906620442867, 0.18583683588076383, 0.1695187747827731, 0.11802751512732357, 0.11341399120283313, 0.16556943592149764, 0.12599899753695354, 0.15086821775184944, 0.17454583081416786, 0.215978748165071, 0.10761207362520508, 0.08314936480019242, 0.15316210716264322, 0.14570845087291673, 0.18996607133885846, 0.15917102457024157, 0.1588214878574945], [0.03703802271047607, 0.06178716714202892, 0.027090583243989386, 0.07142201400711201, 0.026432381746417377, 0.1131946717214305, 0.042967489498551004, 0.01817737294913968, 0.030821259424556047, 0.0292221055860864, 0.0581937660172116, 0.058051585365319625, 0.1357140371692367, 0.04033203404105734, 0.04852878053497989, 0.037602303564199246, 0.04796794324647635, 0.0560203234635992, 0.015352973186963936, 0.05230634560575709, 0.036738269263878465, 0.08392236355575733, 0.03510721420752816, 0.06330835094559006, 0.06415763506083749, 0.02330650397198042, 0.05173795325390529, 0.019789510661212262, 0.03563605379895307, 0.05271929512673523, 0.02786404213111382, 0.004326954267526162, 0.03072553165111458, 0.09187668751110323, 0.05715377221349627, 0.0056265207149408525, 0.015997740883904044, 0.07596205789013766, 0.1470015392987989, 1.0904196510091424, 7.206985400989652, 30.30161462724209, 51.33906036615372, 63.37392657995224, 63.650772124528885, 61.66240341961384, 52.87182591855526, 39.11847911775112, 36.96868747472763, 24.240170381963253, 19.44212034344673, 17.58999142795801, 20.14145001769066, 30.91241855174303, 19.78476695716381, 25.637458004057407, 37.62730993330479, 44.75821629166603, 40.92701867222786, 27.211806625127792, 24.300072267651558, 10.49258217215538, 7.488931696861982, 4.464758047834039, 2.6121318340301514, 1.1317220097407699, 0.8751781820319593, 0.042016898514702916, 0.09053470639628358, 0.057070399343501776, 0.06846900098025799, 0.04854895953030791, 0.020161755237495527, 0.044936648482689634, 0.019442346965661272, 0.03550594046828337, 0.11303453851724043, 0.1369244503439404, 0.03723331516084727, 0.15213320846669376, 0.09434029867406934, 0.09596264833817258, 0.05684120187652297, 0.07238752586999908, 0.025461758341407403, 0.03135412887786515, 0.05649229227856267, 0.027083707245765254, 0.05001377721782774, 0.2746737829875201, 0.28852124931290746, 0.061353125784080476, 0.12222581484820694, 0.31459447054658085, 0.26331144268624485, 0.09027991225593723, 0.06734249502187595, 0.07392908533802256, 0.07567031963844784, 0.10563963805907406, 0.10340588487451896, 0.02359391550271539, 0.044680017526843585, 0.06237062509171665, 0.09447143616853282, 0.16696387203410268, 0.3056261205347255, 0.5305797792971134, 2.520395969040692, 6.489586746320128, 14.771764352917671, 27.751172482967377, 34.19710099697113, 34.36323568224907, 47.69712679088116, 56.647117137908936, 44.46985736489296, 25.415926091372967, 22.067813649773598, 17.108542062342167, 20.661531910300255, 29.722993075847626, 36.57369486987591, 51.14823840558529, 55.03406569361687, 60.373284593224525, 65.12937918305397, 61.84979796409607, 58.521138578653336, 50.49493566155434, 19.31206852197647, 4.908612230792642, 0.36262220120988786, 0.06654012948274612, 0.04333231445343699, 0.03852747970086057, 0.052165890447213314, 0.09961129864677787, 0.04888002047664486, 0.06097474921261892, 0.043428025528555736, 0.03688069111376535, 0.025520356466586236, 0.06148618173028808, 0.0845280970679596, 0.05694381121429615, 0.0059835480169567745, 0.029675131081603467, 0.04712851485237479, 0.043701711038011126, 0.048791252193041146, 0.017691299617581535, 0.013876187440473586, 0.015096003626240417, 0.042381170569569804, 0.05461623200972099, 0.015681932927691378, 0.02957360899017658, 0.06847116062999703, 0.03697243540955242, 0.003210273880540626, 0.06365120090777054, 0.04076142955454998, 0.02772874489892274, 0.06497128124465235, 0.044186251834616996, 0.06869027973152697, 0.025871470243146177, 0.01944103707501199, 0.022213621014088858, 0.06478520997916348, 0.07012006433797069, 0.04641835745132994, 0.028606136002053972, 0.016935158746491652, 0.0425728561822325, 0.037515349831664935, 0.020380202695378102, 0.04383397288620472, 0.025945866836991627, 0.009839057147473795, 0.06408715329598635, 0.03427355601161253, 0.017575133097125217, 0.03647342273325194, 0.08982545070466585, 0.04433416928804945, 0.006441630321205594, 0.03116088846581988, 0.028979525341128465, 0.031005709097371437, 0.03227765002520755, 0.03920898278011009, 0.1569792695227079, 0.031632797908969223, 0.03563310005120002, 0.03289149892225396, 0.06254207604797557, 0.027098937971459236, 0.03510356284095906, 0.09081511947442777, 0.04292603312933352, 0.015553226894553518, 0.06013811500451993, 0.06588399672182277, 0.05209981703956146, 0.048245510188280605, 0.017118695577664766, 0.02837263593391981, 0.021227933866612148, 0.029492321555153467, 0.0672387279337272, 0.042489813567954116, 0.06569817778654397, 0.09641254568123259, 1.5169485448859632, 9.560690727084875, 35.83822913467884, 58.605680242180824, 72.31574356555939, 73.19838300347328, 67.18492448329926, 62.216109707951546, 50.675406977534294, 48.69556121528149, 37.961688190698624, 29.983265809714794, 26.818368136882782, 29.492233358323574, 30.89362856000662, 19.973134249448776, 24.50575713068247, 36.43278323113918, 37.5836730748415, 32.9670500010252, 24.328437745571136, 19.08144559711218, 11.730256509035826, 6.561746774241328, 4.37524245120585, 2.395261083729565, 1.2809933186508715, 0.6945114734116942, 0.06540483649587259, 0.05492582262377255, 0.14836645277682692, 0.0546692361967871, 0.1511103063239716, 0.05515456366993021, 0.05990847967041191, 0.25733810383826494, 0.09784718393348157, 0.7327190763317049, 0.43925441103056073, 0.8521547424606979, 0.6720271299127489, 0.2895862015429884, 0.2865720429690555, 0.27506314334459603, 0.1527709508081898, 0.033517096017021686, 0.02078920584608568, 0.177195698779542, 0.5157323135063052, 0.4229057882912457, 0.8028569596353918, 0.8359029551502317, 0.542881025467068, 0.5105201213154942, 1.0013754665851593, 0.8809235924854875, 0.22967113531194627, 0.24777591694146395, 0.27611785393673927, 0.23208053258713335, 0.30573670053854585, 0.232778032659553, 0.052293009212007746, 0.05803767380712088, 0.04581958899507299, 0.0880054671142716, 0.08313657017424703, 0.06844105169875547, 0.5260379542596638, 1.6652879538014531, 5.03293395973742, 13.040833733975887, 28.296441324055195, 33.60591731965542, 33.001259565353394, 41.43725149333477, 41.50437489151955, 37.60072275996208, 26.012214794754982, 26.43222525715828, 24.893000051379204, 29.832807183265686, 42.95636057853699, 47.050891667604446, 57.557483687996864, 62.71122694015503, 69.85428124666214, 72.2171388566494, 71.70694023370743, 70.50494313240051, 63.10755707323551, 25.797020941972733, 6.731801424175501, 0.6090356537606567, 0.05805856897495687, 0.04109062771021854, 0.03977694839704782, 0.02018671922996873, 0.035137586601194926, 0.027820270261145197, 0.07218736864160746, 0.04752985718369018, 0.034762089562718756, 0.02708652740693651, 0.04296325925679412, 0.03468109527602792, 0.026933743320114445, 0.031386772243422456, 0.036066503162146546, 0.020926145080011338, 0.030444855110545177, 0.03048334845516365, 0.03311700791527983, 0.04571736186335329, 0.05475705082062632, 0.03898171489709057, 0.04422856538440101, 0.033547538914717734, 0.03033510260138428, 0.029233575478428975, 0.03147651645122096, 0.05168091920495499, 0.07053932582493871, 0.04917335434583947, 0.05051062282291241, 0.04334714627475478, 0.018199435144197196, 0.028348612613626756, 0.018258166855957825, 0.07671370505704544, 0.04553088983811904, 0.04740008524095174, 0.06436358104110695, 0.03686729534820188, 0.0137107924092561, 0.04796408778929617, 0.023896889870229643, 0.12133283307775855, 0.1671061120578088, 0.13183919509174302, 0.1702875952469185, 0.09272042036172934, 0.25943487882614136, 0.12782058416632935, 0.09521632237010635, 0.0965384287701454, 0.144471216481179, 0.1635165960760787, 0.09033862355863675, 0.21803393319714814, 0.14046952652279288, 0.20797036617295817, 0.1859226281521842, 0.16515950323082507, 0.34008801507297903, 0.13656462746439502, 0.14506474166410044, 0.09352047040010802, 0.17833347053965554, 0.0784038202255033, 0.1837889535818249, 0.18941750546218827, 0.09245736611774191, 0.18139481486286968, 0.21782702242489904, 0.1857089638360776, 0.13869669899577275, 0.134220375912264, 0.08297932392451912, 0.18067356606479734, 0.177319860085845, 0.2403155664796941, 0.176578261598479, 0.1490665355231613, 0.17101202043704689, 0.23382333281915635, 2.7647784305736423, 15.366906467825174, 45.536083951592445, 71.51581808924675, 84.82700541615486, 80.50284504890442, 79.32002931833267, 73.00791442394257, 60.422917529940605, 52.82181300222874, 41.18922360241413, 32.1342296898365, 27.25672971457243, 31.687377467751503, 43.66556592285633, 29.599203318357468, 38.41908484697342, 50.852279886603355, 57.6600705832243, 52.660101279616356, 35.980375707149506, 31.96690946817398, 15.384414978325367, 10.778048504143953, 6.718858843669295, 3.9032541029155254, 2.261385954916477, 1.4131972496397793, 0.2482288793544285, 0.18651820166269317, 0.18865010992158204, 0.17154715344076976, 0.263742808601819, 0.1350912416819483, 0.16132218413986266, 0.2699762850534171, 0.12618909124284983, 0.8160429645795375, 0.454320929129608, 0.9113401884678751, 0.8801766356918961, 0.317734912969172, 0.4497723950771615, 0.75466527370736, 0.4422743583563715, 0.2126092344406061, 0.182743638579268, 0.20526265521766618, 0.25256128516048193, 0.6854020559694618, 1.024591033346951, 0.8101404563058168, 0.42244503332767636, 1.0094883874990046, 2.4067830154672265, 1.5383517276495695, 0.24812766525428742, 0.19910239905584604, 0.28474021470174193, 0.19258034590166062, 0.2074913543765433, 0.5084498855285347, 0.2809932001400739, 0.2746082661906257, 0.30087376304436475, 0.31555190042126924, 0.3331939084455371, 0.3895127942087129, 0.9857409680262208, 3.392948373220861, 9.044575821608305, 19.19136419892311, 33.83214958012104, 44.47487309575081, 49.526933804154396, 63.51011507213116, 75.50732150673866, 63.63987810909748, 40.606946647167206, 35.657982006669044, 30.690250173211098, 31.231044754385948, 44.948194697499275, 53.501395136117935, 70.13361185789108, 76.06580793857574, 79.18625369668007, 83.19324508309364, 80.88590249419212, 79.03546258807182, 72.01919227838516, 30.852300077676773, 8.544374462217093, 1.0156572377309203, 0.3111882205121219, 0.15288430644432083, 0.12785736500518396, 0.12512105167843401, 0.18050662736641243, 0.23074100055964664, 0.1824534885236062, 0.17333246389171109, 0.1068033478804864, 0.15673876914661378, 0.12111194766475819, 0.13988192367833108, 0.09975114153348841, 0.12413509364705533, 0.08982821891549975, 0.14256419381126761, 0.17486663156887516, 0.1861816822201945, 0.12097202314180322, 0.13272836222313344, 0.07999790890607983, 0.17921785824000835, 0.10295937172486447, 0.1029447143082507, 0.11276220742729492, 0.15102218370884657, 0.11130757571663707, 0.1536513160681352, 0.2629768825136125, 0.06681213402771391, 0.10175678820814937, 0.18367144191870466, 0.10034054779680446, 0.11184981107362546, 0.17640008678426966, 0.08226259480579756, 0.15434890519827604, 0.21877367631532252, 0.16179496189579368, 0.20090379926841706, 0.08389717506361194, 0.14380859734956175, 0.1134040390024893], [0.05773511504230555, 0.0665870109514799, 0.021308957839210052, 0.07845689862733707, 0.011571817976800958, 0.05248800851404667, 0.022471077609225176, 0.060402772287488915, 0.09563203639118001, 0.0426336306554731, 0.018368921264482196, 0.07270975154824555, 0.007635341462446377, 0.045647800361621194, 0.03412352343730163, 0.029828900369466282, 0.05315956681442913, 0.034910712056444027, 0.03229381029086653, 0.05483596338308416, 0.026720199603005312, 0.005671431781593128, 0.017354911906295456, 0.03012941451743245, 0.010321749996364815, 0.02811746144288918, 0.034874150151154026, 0.014023385010659695, 0.01881157895695651, 0.01725822305161273, 0.09165240306174383, 0.04597899860527832, 0.026770532058435492, 0.05191575699427631, 0.022590390835830476, 0.11349002423230559, 0.012519077645265497, 0.37241721467580646, 1.0536145884543657, 16.848508715629578, 49.5656993240118, 59.093007892370224, 58.63184563815594, 54.85207445919514, 52.65560992062092, 55.28104864060879, 36.647266522049904, 19.65772457420826, 15.757280420511961, 17.315408661961555, 18.16260740160942, 27.386929728090763, 46.5114726126194, 47.0032574236393, 70.63582330942154, 53.184978514909744, 37.783470153808594, 20.1400288939476, 8.893971852958202, 3.328590514138341, 0.6697120447643101, 0.28497598017565906, 0.051075627270620316, 0.039409607561537996, 0.13511559896869585, 0.07628639868926257, 0.0565661619475577, 0.13723063078941777, 0.04223592113703489, 0.1142803298716899, 0.04463205252250191, 0.06822674913564697, 0.026801934182003606, 0.008365809590031859, 0.05567441214225255, 0.08239594390033744, 0.5335719406139106, 0.3341418388299644, 0.11187685493496247, 0.44350231590215117, 0.1995240873657167, 0.12797205650713295, 0.09898031727061607, 0.06403967810911126, 0.21943749772617593, 0.03697506632306613, 0.07902150231529959, 0.3659287659684196, 0.6353740592021495, 0.42963332729414105, 0.2125814781174995, 0.045283906802069396, 0.030872630886733532, 0.21707988751586527, 0.2830860565882176, 0.013826825343130622, 0.42725943436380476, 0.1185926457401365, 0.04730211432615761, 0.5540528416167945, 0.404263780801557, 0.06342520951875485, 0.018116789578925818, 0.028843448853876907, 0.07931401240057312, 0.016937789660005365, 0.04237198278133292, 0.08032716272282414, 0.0049557532656763215, 0.051757664696197025, 0.3818678419338539, 0.287275806767866, 6.527014737948775, 22.793194726109505, 29.621899500489235, 37.91179306805134, 43.21496710181236, 49.46193069219589, 42.56121598184109, 31.511220820248127, 17.691214196383953, 14.283965528011322, 22.777366675436497, 26.80751781910658, 36.7403919249773, 45.801347717642784, 55.69102384150028, 66.02125212550163, 67.59496048092842, 68.18802505731583, 57.95741602778435, 40.32358065247536, 16.525657139718533, 1.7471816344186664, 0.12868756108218804, 0.034892188050434925, 0.05484106935909949, 0.05540179532545153, 0.04941986611811444, 0.00935729940465535, 0.03751308628125116, 0.03462735636276193, 0.014109737603575923, 0.06466450708103366, 0.013134332912159152, 0.03377880697371438, 0.03475427103694528, 0.03181629392202012, 0.0725243407941889, 0.03942954164813273, 0.049317690936732106, 0.04804177580808755, 0.03771760733798146, 0.012543371849460527, 0.09964992001187056, 0.09474504375248216, 0.015067528347572079, 0.027565624550334178, 0.03625919809564948, 0.02240656456706347, 0.05634022621961776, 0.03380925358214881, 0.011026981392205926, 0.02546076942962827, 0.00728238298506767, 0.07056292612105608, 0.055006757538649254, 0.01996951672481373, 0.04064455613843165, 0.0210090151449549, 0.05394556799728889, 0.05143692331330385, 0.01612844422197668, 0.010739282279246254, 0.013747601078648586, 0.008943447246565484, 0.052544578720699064, 0.027351750577508938, 0.03629429054853972, 0.04115088268008549, 0.022508680376631673, 0.03669257894216571, 0.00889205537532689, 0.009412747112946818, 0.06825732561992481, 0.04654819618735928, 0.046604373055743054, 0.07631189888343215, 0.015403806592075853, 0.057392339294892736, 0.0835974290384911, 0.02060527196590556, 0.03717242565471679, 0.028108756050642114, 0.07249916714499705, 0.01930672318849247, 0.05291203829983715, 0.03760425541258883, 0.03323876837384887, 0.023247872450156137, 0.07621190932695754, 0.00552236631847336, 0.061316059218370356, 0.025198963849106804, 0.009880894795060158, 0.03834736788121518, 0.04929697017360013, 0.04796589862962719, 0.036313241289462894, 0.09178200431051664, 0.012893931798316771, 0.11499242798890918, 0.04269171484338585, 0.3736662492156029, 1.8009136011824012, 20.411556623876095, 58.541254699230194, 68.01882013678551, 68.55905994772911, 64.13228988647461, 62.482730001211166, 63.163976445794106, 48.93864557147026, 33.58570620417595, 28.20636335760355, 27.24202260375023, 26.700796745717525, 28.631703034043312, 41.558749973773956, 41.83710403740406, 49.66126039624214, 44.12727914750576, 27.453777641057968, 14.947528671473265, 7.73246917873621, 2.825005673803389, 0.901929815299809, 0.2636520587839186, 0.014921390193194384, 0.03181615291396156, 0.12739264697302133, 0.05142342364706565, 0.026300247918698005, 0.0930963404243812, 0.11986765544861555, 0.33254043257329613, 0.2593525598058477, 0.12920586217660457, 0.3705717308912426, 0.12831452797399834, 0.6789660325739533, 0.9555348451249301, 1.9958768645301461, 1.2816223036497831, 0.7849423459265381, 1.2173814070411026, 0.9342129423748702, 0.8831346582155675, 0.09289493638789281, 0.09405307268025354, 0.1926644312334247, 0.10466358027770184, 0.7171191915404052, 1.6879638307727873, 2.7359607769176364, 2.3298582807183266, 1.478336916770786, 1.927362740971148, 1.2671658606268466, 1.8263676040805876, 1.4249950228258967, 1.1783002666197717, 2.3650508048012853, 1.4586823526769876, 0.22834375966340303, 1.7592801852151752, 1.8650068994611502, 0.18642476527020335, 0.03060703478695359, 0.01351886003249092, 0.014536384387611179, 0.06903966801473871, 0.05128686476382427, 0.03171939169988036, 0.04217155837977771, 0.05812013754621148, 0.10506136401090771, 0.3971485735382885, 4.376231348142028, 16.488603428006172, 24.901464097201824, 36.95560097694397, 39.76887121796608, 43.731461986899376, 35.39704240858555, 30.392536148428917, 21.685829646885395, 19.086818508803844, 33.10052923858166, 38.68391923606396, 45.38674056529999, 54.283529967069626, 65.57757273316383, 73.94020959734917, 75.21563395857811, 75.30527874827385, 70.92126399278641, 49.77116949856281, 22.319339253008366, 3.8298320677131414, 0.20707356976345181, 0.12642518326174468, 0.013512258628907148, 0.08053367273532785, 0.04684567124058958, 0.008331401768373325, 0.05039433570345864, 0.013062281504971907, 0.022457639170170296, 0.07289378190762363, 0.031231800676323473, 0.031863383192103356, 0.056757142519927584, 0.06440280354581773, 0.01770942471921444, 0.03250131478125695, 0.044817622838309035, 0.02297531314980006, 0.08831224127789028, 0.03284301441453863, 0.09028498112456873, 0.017321745326626115, 0.016458872487419285, 0.01681671383266803, 0.038995333306957036, 0.03355494554853067, 0.052112930789007805, 0.0509616742056096, 0.03197440106305294, 0.0208699162612902, 0.07950609506224282, 0.023115304466045927, 0.059248391262372024, 0.040290221440955065, 0.054491220944328234, 0.03159937899908982, 0.08927689224947244, 0.07172686600824818, 0.04010730059235357, 0.01786005472240504, 0.11587484899791889, 0.026118358655367047, 0.10488751591765322, 0.15952259476762265, 0.11966077436227351, 0.16436267411336303, 0.08056626043980941, 0.13561332772951573, 0.10922274930635467, 0.12813589302822948, 0.18446064175805077, 0.14148846559692174, 0.11210092416149564, 0.22528768458869308, 0.10314227401977405, 0.1345288273296319, 0.18556041555712, 0.13696774723939598, 0.18541731464210898, 0.1298294888692908, 0.11158568813698366, 0.15407463710289448, 0.1299326473963447, 0.14635680592618883, 0.13341783225769177, 0.11671983607811853, 0.22017158567905426, 0.12194898634334095, 0.10412682939204387, 0.12327323012868874, 0.07068759950925596, 0.1550300483359024, 0.13891867536585778, 0.10791082517243922, 0.09673124615801498, 0.23726130224531516, 0.13474973500706255, 0.25169855332933366, 0.1322845579124987, 0.6847271171864122, 3.642923184670508, 27.867717929184437, 71.04279667139053, 78.3724057674408, 80.47059997916222, 76.35156780481339, 73.00523936748505, 73.96066009998322, 52.31240093708038, 33.762719705700874, 26.955084800720215, 26.985390074551105, 29.78239718824625, 36.58137805759907, 58.395855501294136, 61.6230109333992, 89.58824872970581, 68.61965909600258, 50.12451633810997, 27.42278840392828, 12.406805455684662, 5.230867713689804, 1.4695093967020512, 0.5600459512788802, 0.19712965178769082, 0.1484179132967256, 0.4856112110428512, 0.34457284316886216, 0.17357792181428522, 0.266324354452081, 0.16865599842276424, 0.2546446124324575, 0.2628319262294099, 0.15327351837186143, 0.15416452602948993, 0.2135682970401831, 0.45394694607239217, 0.4680530063342303, 1.7596105299890041, 1.6526288143359125, 0.8893733890727162, 1.713034410495311, 1.1096565937623382, 0.7599849288817495, 0.26568812609184533, 0.4677709605311975, 0.5365465872455388, 0.27269524696748704, 0.4444869380677119, 1.4443296915851533, 1.4629881153814495, 2.064009583555162, 0.8393817278556526, 1.110529953148216, 0.5346241279039532, 1.3486380013637245, 1.2884656176902354, 0.8031211048364639, 1.6360589722171426, 0.8403474104125053, 0.19267586030764505, 0.6126763334032148, 0.6341515341773629, 0.1802367824711837, 0.11070853637647815, 0.1657455030363053, 0.2181259891949594, 0.17109885171521455, 0.1615993317682296, 0.16782534221420065, 0.17517729458631948, 0.20483985368628055, 0.8200271101668477, 1.0008699749596417, 9.86098576337099, 29.36347346752882, 41.64960689842701, 54.024387672543526, 59.27810736000538, 67.11376950144768, 58.33970211446285, 46.54567837715149, 30.077327862381935, 23.4549368172884, 37.727088779211044, 43.12132112681866, 55.42847692966461, 65.93865975737572, 76.19219675660133, 84.31453451514244, 86.31563633680344, 85.71048080921173, 81.81068927049637, 58.42409938573837, 28.495928719639778, 6.3943614810705185, 0.36349214671645314, 0.17686278617475182, 0.13204070302890614, 0.15006049390649423, 0.11131133840535767, 0.07950147890369408, 0.2841317723505199, 0.10104697590577416, 0.1075571398541797, 0.13607822387712076, 0.10249145503621548, 0.1424118160502985, 0.13849726907210425, 0.23789108876371756, 0.12733750540064648, 0.12281990406336263, 0.1184218330308795, 0.21465140220243484, 0.1624308043392375, 0.1481339824385941, 0.30420134542509913, 0.151578527293168, 0.16601687675574794, 0.08797902439255267, 0.1076201927207876, 0.115992301289225, 0.15015965967904776, 0.14507096086163074, 0.08932006297982298, 0.13072836329229176, 0.17275142163271084, 0.13558620965341106, 0.3314177709398791, 0.10014642422902398, 0.11070015752920881, 0.10992796029313467, 0.1745478346128948, 0.16700474952813238, 0.14960995089495555, 0.20330050581833348, 0.18934887164505199, 0.11970176317845471], [0.05063300297479145, 0.03756354119104799, 0.004409547882460174, 0.0346397131215781, 0.054909443424548954, 0.045805684858351015, 0.024555811251048, 0.021411819507193286, 0.036127941857557744, 0.06597947402042337, 0.04890511620033067, 0.07915196445537731, 0.02661844187969109, 0.017381844445480965, 0.07323637211811729, 0.019914757358492352, 0.010911903973465087, 0.13299961719894782, 0.034007570284302346, 0.020918771842843853, 0.05082438430690672, 0.02005638882110361, 0.009691289051261265, 0.040888199509936385, 0.03403571623493917, 0.07562248822068796, 0.04321134438214358, 0.031455075804842636, 0.013161182887415634, 0.0837103022786323, 0.02863151745259529, 0.013354840757529018, 0.037551522109424695, 0.08571310652769171, 0.03623405413236469, 0.025086962632485665, 0.4155491752317175, 5.695968931540847, 21.77187602967024, 50.623003989458084, 65.18144398927689, 63.41790162026882, 57.60352581739426, 50.997637286782265, 39.97879855334759, 28.81106860935688, 20.605614110827446, 19.034989289939404, 22.193075828254223, 21.94784078747034, 19.13319882005453, 34.90053445100784, 57.13566452264786, 45.81332087516785, 27.32503104954958, 8.881519921123981, 4.456786550581455, 0.8543587429448962, 0.18894260516390204, 0.1463802726357244, 0.01180254705104744, 0.0979690148960799, 0.08644863424706273, 0.06540050977491774, 0.10072826058603823, 0.07396715009235777, 0.09204499176121317, 0.04353876880486496, 0.06634200573898852, 0.3375689283711836, 0.08744380975258537, 0.3459269361337647, 0.36359388031996787, 0.08305042167194188, 0.7281046989373863, 1.4316320791840553, 1.4629508298821747, 2.1173375844955444, 0.8023416122887284, 0.4637213278329, 0.5244100384879857, 0.17730902472976595, 0.13553278986364603, 0.10960816143779084, 0.10329444397939369, 0.051680284668691456, 0.5848642601631582, 1.7105815233662724, 1.1612759926356375, 1.2349619949236512, 2.3367496859282255, 1.4950693189166486, 0.4196807707194239, 0.9136927372310311, 0.28374267916660756, 1.0449600778520107, 1.5789675107225776, 0.8287761406973004, 1.3189266831614077, 4.677129602059722, 4.088582033291459, 0.17089360335376114, 0.0661692931316793, 0.06508309321361594, 0.03753755860088859, 0.05167197261471301, 0.13988406106363982, 0.02625939825520618, 0.009164228758891113, 0.0752214687236119, 0.03559923956345301, 0.38499353046063334, 0.046983591964817606, 0.06073572199966293, 1.5934219351038337, 7.064142040908337, 19.4188541918993, 34.965408369898796, 54.47541207075119, 50.688656866550446, 39.04529504477978, 33.66159573197365, 16.73542868345976, 17.989897169172764, 15.315928403288126, 21.652917712926865, 36.30787253379822, 40.36344051361084, 56.79311290383339, 65.98628640174866, 67.47254624962807, 64.97608780860901, 60.483604073524475, 37.163776606321335, 6.831566970795393, 0.36214158637449145, 0.0501787789107766, 0.24382120493100956, 0.045670020263059996, 0.06705333202262409, 0.07136259024264291, 0.04731129469291773, 0.024769865194684826, 0.07908362749731168, 0.08697506185853854, 0.04287280258722603, 0.011374329696991481, 0.041043753662961535, 0.0790001210407354, 0.024266334694402758, 0.050665954331634566, 0.039788729991414584, 0.018107729811163153, 0.04053655509778764, 0.03085262815147871, 0.04638172504201066, 0.03272239315265324, 0.01924213778693229, 0.013049029530520784, 0.042774067260324955, 0.00537862159035285, 0.04294505066354759, 0.04354708828032017, 0.05322289056493901, 0.022847951331641525, 0.03650354650744703, 0.026051220265799202, 0.06320459127891809, 0.015655660899938084, 0.03263584017986432, 0.010823163520399248, 0.041209234041161835, 0.05956290973699652, 0.121189939964097, 0.014965877307986375, 0.09089058105018921, 0.007560000949524692, 0.09767553259734996, 0.05282919235469308, 0.07121179325622506, 0.03908629834768362, 0.014746996621397557, 0.027037302606913727, 0.06681825674604625, 0.026298752491129562, 0.04036739366711117, 0.07630103384144604, 0.03863808939058799, 0.030325777515827212, 0.02307393715454964, 0.007289945933734998, 0.019122635312669445, 0.05166765702597331, 0.06209852777828928, 0.031086768321983982, 0.03357248620886821, 0.04679514211602509, 0.009630216791265411, 0.07708080840529874, 0.03686748088512104, 0.03816297758021392, 0.008986228349385783, 0.043781603235402144, 0.030791571662120987, 0.02431522181723267, 0.03320338648336474, 0.04649269838409964, 0.04213810607325286, 0.016751688708609436, 0.1031021164089907, 0.029293043771758676, 0.06296720792306587, 0.6196614867076278, 7.506319563835859, 26.545780263841152, 59.46882292628288, 74.23438221216202, 72.16771110892296, 66.6513343155384, 60.49214981496334, 51.25219322741032, 40.484148636460304, 31.096737161278725, 28.394616656005383, 29.31842878460884, 29.55835171043873, 22.728427201509476, 26.763557977974415, 48.319974169135094, 42.65086457133293, 26.457374207675457, 10.315312184393406, 4.2495575454086065, 0.7195230375509709, 0.20236577081959695, 0.038419445263571106, 0.02719154130318202, 0.12203480087919161, 0.15228233562083915, 0.07269387700944208, 0.10358872779761441, 0.22245110711082816, 0.2731956623028964, 0.18903874297393486, 0.35073563747573644, 0.9098822542000562, 2.0398409804329276, 2.228048681281507, 2.1673849364742637, 1.6369306691922247, 1.8153966427780688, 3.5863715317100286, 3.9083928521722555, 3.3704946655780077, 5.222171880304813, 3.7845553597435355, 1.6764276497997344, 1.6658374993130565, 0.43264137057121843, 0.2683039888506755, 0.1876365885254927, 0.39379825175274163, 1.5520083135925233, 3.634854080155492, 4.3184407241642475, 5.24540763348341, 4.986617295071483, 4.792734598740935, 2.621282455511391, 3.310511796735227, 2.2997524961829185, 3.5777692683041096, 4.730412242934108, 2.485189908184111, 2.829653061926365, 4.326357124373317, 7.890703612938523, 1.3125399383716285, 0.3650840831687674, 1.0200650012120605, 0.6040350627154112, 0.4788178880698979, 0.5234376469161361, 0.08157995995134115, 0.1145566240302287, 0.08411264279857278, 0.11441862909123302, 0.3923375270096585, 0.16631943552056327, 0.24231866758782417, 1.671083711553365, 6.286661010235548, 14.954848978668451, 31.636728085577488, 46.180088594555855, 43.63854557275772, 29.654313661158085, 35.771139934659004, 30.086289681494236, 30.78038513660431, 28.843214884400368, 34.28035072982311, 52.46643327176571, 52.62430340051651, 65.11780500411987, 75.04595786333084, 75.53148061037064, 76.63548097014427, 71.00277721881866, 46.44365765154362, 10.098742805421352, 0.9776709729339927, 0.03653203384601511, 0.2040085443877615, 0.08611061566625722, 0.035006623511435464, 0.021278850763337687, 0.009652416283643106, 0.01891446103400085, 0.03268662534537725, 0.03757697777473368, 0.04010363067209255, 0.04470122810744215, 0.024402765557169914, 0.06706096130074002, 0.026049056905321777, 0.05788341470179148, 0.06385056403814815, 0.033274094603257254, 0.04867972595093306, 0.048601637172396295, 0.06962203871808015, 0.01884939323645085, 0.01902031355712097, 0.021298311730788555, 0.03480817693343852, 0.01896470072097145, 0.04274766535672825, 0.06388384936144575, 0.02108669388690032, 0.036392836627783254, 0.03125279974483419, 0.08204449244658463, 0.03165974158036988, 0.03607821425248403, 0.039820427118684165, 0.016499885423399974, 0.04008685442386195, 0.06981920509133488, 0.02616183181089582, 0.029458466633514035, 0.06231209190445952, 0.10201069177128375, 0.1594055283931084, 0.1315974775934592, 0.20227237895596772, 0.19875638012308627, 0.13798840809613466, 0.169431067770347, 0.12079585212632082, 0.13204193499404937, 0.25573194783646613, 0.11165070027345791, 0.14804070931859314, 0.17937541619176045, 0.16505342064192519, 0.191985841083806, 0.08052428456721827, 0.07422140988637693, 0.2770670014433563, 0.16252124245511368, 0.09457998268771917, 0.142215310188476, 0.11186109913978726, 0.17043412488419563, 0.15385608945507556, 0.12039816487231292, 0.14966801652917638, 0.21312869328539819, 0.19061086408328265, 0.1490449093398638, 0.23201143863843754, 0.10220447395113297, 0.12558588845422491, 0.08334010417456739, 0.3111311048269272, 0.10242405318422243, 0.21985798375681043, 0.8961795957293361, 10.623056720942259, 36.672941744327545, 70.4167802631855, 82.97121539711952, 83.11742395162582, 77.65951082110405, 71.07118874788284, 59.18010301887989, 45.70342317223549, 33.60944353044033, 28.26258134096861, 31.77965171635151, 33.336534574627876, 31.81303482502699, 50.61411626636982, 73.95277172327042, 60.45071303844452, 35.663119331002235, 13.187419418245554, 6.298524448648095, 1.3292631972581148, 0.5340432340744883, 0.4447230597725138, 0.18560469208750874, 0.34483586030546576, 0.3839934419374913, 0.30590620706789196, 0.2304197396733798, 0.22167940711369738, 0.31509815133176744, 0.16114785365061834, 0.3997350769350305, 0.8249776507727802, 1.765796123072505, 1.7813268397003412, 1.596701752860099, 1.242468967102468, 2.022584918886423, 2.852802132256329, 4.658812684938312, 4.577140342444181, 3.7261748174205422, 5.16105548478663, 2.2736374475061893, 1.677054853644222, 0.409958636155352, 0.4359560989541933, 0.308330922271125, 0.3001442615641281, 2.250490989536047, 6.9850345607846975, 7.427951144054532, 4.335791543126106, 6.799961691722274, 4.215022623538971, 2.2462805779650807, 1.9885705690830946, 1.3475256110541523, 2.356976713053882, 4.3123952485620975, 1.2490263464860618, 4.159128572791815, 11.171251405030489, 6.174284890294075, 1.0772372083738446, 0.16171657625818625, 0.5419590999372303, 0.3346528223482892, 0.3150663577252999, 0.498380841454491, 0.28651979577261955, 0.19364452629815787, 0.41401432477869093, 0.2549910172820091, 0.8141057810280472, 0.24932222615461797, 0.5093633802607656, 2.376206531189382, 9.6494872123003, 25.55682063102722, 46.618281081318855, 69.76556360721588, 65.38159444928169, 54.6248010545969, 50.73355905711651, 27.456794679164886, 29.045859910547733, 28.02805222570896, 36.390388906002045, 53.29543098807335, 58.69227759540081, 77.75778114795685, 85.35852089524269, 86.51367411017418, 86.82207316160202, 79.94022443890572, 58.38548585772514, 15.737886261194944, 1.305719898082316, 0.1401477016042918, 0.28427088051103055, 0.2134279123856686, 0.1653271692339331, 0.09304190389229916, 0.11282022853265516, 0.13345577084692195, 0.18822773883584887, 0.2213057060725987, 0.12492521374952048, 0.1183934829896316, 0.14952182827983052, 0.17372770205838606, 0.1186843158211559, 0.16055435815360397, 0.12082694069249555, 0.07116869674064219, 0.11791594806709327, 0.1370928733376786, 0.15517493040533736, 0.15321070299251005, 0.17142610915470868, 0.1314270359580405, 0.10649954972905107, 0.1167841802816838, 0.13374897855101153, 0.1567526621511206, 0.14657798077678308, 0.11176087951753289, 0.0960229997872375, 0.1242736897256691, 0.11170814992510714, 0.11050987828639336, 0.11745255105779506, 0.07815353092155419, 0.09875298259430565, 0.19064397871261463, 0.15448600956005976, 0.12311346057686023, 0.16096543375169858], [0.05273346272588242, 0.009220046613336308, 0.04371432754851412, 0.07022818041150458, 0.042499075570958667, 0.026059094452648424, 0.046333938153111376, 0.04644038439437281, 0.03088581514020916, 0.04797638517629821, 0.01612855925486656, 0.05467562237754464, 0.042720098281279206, 0.0077653351218032185, 0.04184574441751465, 0.07152982580009848, 0.048702439380576834, 0.037142090368433855, 0.05844562496349681, 0.05427016112662386, 0.00952825312197092, 0.029767116575385444, 0.030930781867937185, 0.06240275266463868, 0.05202713109611068, 0.014504945156659232, 0.02349742702790536, 0.04015685379272327, 0.015043650673760567, 0.04798542824573815, 0.030289872411231045, 0.014371365996339591, 0.10523849981836975, 0.08225077981478535, 0.10861149421543814, 1.1899973452091217, 10.15159796923399, 33.321920558810234, 55.819988921284676, 67.6904645562172, 59.494619742035866, 51.6871102899313, 39.37821038067341, 39.25132758915424, 27.148431725800037, 19.735968075692654, 16.0259972512722, 15.726440325379372, 26.064617782831192, 28.59311230480671, 38.884396478533745, 49.14089351892471, 30.244923569262028, 10.745649542659521, 3.9746859949082136, 0.45821966836228967, 0.18240364588564262, 0.061796065492671914, 0.03541717218467966, 0.02185581121011637, 0.03408528427826241, 0.06290212157182395, 0.01668412543949671, 0.06734507769579068, 0.29029257770162076, 0.07410811362206005, 0.22018577554263175, 0.37131699558813125, 0.8552506263367832, 1.1703076330013573, 1.1647021025419235, 2.9657615208998322, 2.3373918514698744, 0.7459311455022544, 2.175109446980059, 3.824856234714389, 2.379813250154257, 1.0758257028646767, 3.071824279613793, 2.7934079943224788, 1.5466595068573952, 1.1445755325257778, 0.4988830676302314, 0.10211923086899333, 0.06299467480857857, 0.5753585952334106, 2.1738818753510714, 2.783282487653196, 8.405717052519321, 6.285194763913751, 4.43331615999341, 5.002772603183985, 5.8662092965096235, 4.152458980679512, 2.0481271483004093, 4.704291019588709, 4.872986767441034, 3.778583980165422, 1.1200274247676134, 6.479123057797551, 18.85783139616251, 0.8481834805570543, 0.2814759820466861, 0.8990734373219311, 0.35167035763151944, 0.15668377600377426, 0.11202512119780295, 0.24080205912468955, 0.18961377383675426, 0.15195418760413304, 0.0757583012455143, 0.1620135540724732, 0.06833775958511978, 0.2735283225774765, 0.07577760450658388, 0.33376755891367793, 1.116833221167326, 4.8638848308473825, 12.673418149352074, 33.47084976732731, 58.79650220274925, 49.427295550704, 28.436062932014465, 18.979056291282177, 17.353621311485767, 16.464106142520905, 12.490782849490643, 20.601421035826206, 37.7811598777771, 40.256700441241264, 50.18726237118244, 64.03463512659073, 64.255760461092, 60.44266887009144, 34.448932483792305, 9.032294880598783, 2.4001583084464073, 0.3703613468678668, 0.020682844951807056, 0.006929971377758193, 0.028314136143308133, 0.0302243500482291, 0.059404691273812205, 0.02530065848986851, 0.02744516656093765, 0.03727880510268733, 0.0628768143360503, 0.021401811645773705, 0.01772374816937372, 0.030147242759994697, 0.07596383162308484, 0.04317424070904963, 0.012045323037455091, 0.03944347918150015, 0.04869104741374031, 0.016124546091305092, 0.022659750102320686, 0.10454452494741417, 0.03289221138402354, 0.02086087133648107, 0.048019069799920544, 0.049752964259823784, 0.011042703790735686, 0.002703487207327271, 0.07137564462027512, 0.01979669279535301, 0.04592453238728922, 0.05868218082468957, 0.03839203774987254, 0.022340175746649038, 0.02095928753988119, 0.058135633589699864, 0.14252566150389612, 0.0279722713821684, 0.05654089924064465, 0.039971654550754465, 0.033016372690326534, 0.01633255153137725, 0.018285663427377585, 0.02529599780245917, 0.054185233457246795, 0.05329567298758775, 0.059562175010796636, 0.07278527991729788, 0.042197800721623935, 0.0310408182485844, 0.06513579312013462, 0.0714510542456992, 0.039038641334627755, 0.03386842872714624, 0.04738949479360599, 0.04419159529788885, 0.08918784937122837, 0.05201157197006978, 0.03159871477691922, 0.05160406610229984, 0.05606594328128267, 0.06404747065971605, 0.048696279554860666, 0.07249771253555082, 0.05403668517828919, 0.04136328163440339, 0.02573884845332941, 0.08446701089269482, 0.01801574617275037, 0.009438188862986863, 0.07733782156719826, 0.028979939088458195, 0.06825108415796421, 0.03415733197471127, 0.08150930749252439, 0.9650353447068483, 12.985639795660973, 40.20995914936066, 65.20781457424164, 77.2785584628582, 69.67543244361877, 59.965593069791794, 50.874626487493515, 51.073709204792976, 38.46924975514412, 28.993107341229916, 23.76823950558901, 23.22610169649124, 25.399125292897224, 29.602389447391033, 32.69441083073616, 41.7829417437315, 30.08521243929863, 11.317658498883247, 3.2127803284674883, 0.355376138468273, 0.03643378091510385, 0.11989956779871136, 0.027948164570261724, 0.08210309242713265, 0.15686502330936491, 0.054657747750752605, 0.14716056670295075, 0.16649134660838172, 0.8612322178669274, 0.8834641717839986, 1.4799324749037623, 2.6159698655828834, 3.0199209647253156, 4.122630106285214, 5.159284779801965, 5.997746838256717, 5.907641798257828, 3.6578371468931437, 6.566238608211279, 7.264215080067515, 5.777859762310982, 6.052784509956837, 7.160532418638468, 3.6234005447477102, 3.753962963819504, 2.5263868225738406, 1.0849790554493666, 0.29838967602699995, 0.2829378645401448, 0.39354054839350283, 1.9264351157471538, 2.620558119378984, 3.0192372389137745, 5.158246960490942, 7.480488549917936, 9.35568792745471, 10.02050880342722, 9.760554302483797, 7.202394772320986, 8.298044130206108, 9.47379034012556, 2.6984781632199883, 5.934822214767337, 7.379578789696097, 8.961074352264404, 4.0882329270243645, 1.4202096546068788, 3.338429373688996, 1.0660267411731184, 0.8085021504666656, 0.6271008937619627, 0.6018573639448732, 0.5779397254809737, 0.47603124228771776, 0.3021489211823791, 0.17778607725631446, 0.17078763950848952, 0.08899322114302777, 0.08241155868745409, 0.4005845094798133, 1.1598729179240763, 5.4357935674488544, 14.215484652668238, 33.101847767829895, 50.81512168049812, 46.786087676882744, 21.251940429210663, 22.146173045039177, 24.597826190292835, 24.73199889063835, 25.965714789927006, 30.5975104495883, 51.904713213443756, 47.48352125287056, 57.9639782756567, 73.91051799058914, 72.29352995753288, 71.61914974451065, 47.54629008471966, 21.439823247492313, 4.040222503244877, 0.6286062661092728, 0.00808108648925554, 0.019443046439846512, 0.07957374182296917, 0.04505863158556167, 0.03067664452828467, 0.05326062877429649, 0.004564410446619149, 0.013673595967702568, 0.017192125524161384, 0.05308028688887134, 0.03950981605157722, 0.026727860422397498, 0.018312518041057047, 0.039977083361009136, 0.04931256640702486, 0.07799006547429599, 0.06201489144586958, 0.028658915689447895, 0.04197389476757962, 0.0693102105287835, 0.012022080827591708, 0.01787832454283489, 0.05720635337638669, 0.07882938254624605, 0.024442412941425573, 0.010902678150159772, 0.021592322809738107, 0.05059549483121373, 0.04779149021487683, 0.05891803535632789, 0.03149449868942611, 0.016417583101429045, 0.020626773839467205, 0.03984814633440692, 0.07173666235757992, 0.022567990963580087, 0.03344595002999995, 0.021059681566839572, 0.11012565359123982, 0.1058400327747222, 0.14211433357559144, 0.14406576636247337, 0.1531547005288303, 0.15805873816134408, 0.17221214744495228, 0.16241487785009667, 0.10851589075173251, 0.09850371745415032, 0.1271022149012424, 0.19894516764907166, 0.19870025891577825, 0.11313789000269026, 0.10409522132249549, 0.181020891177468, 0.19964321691077203, 0.11387436767108738, 0.11986821205937304, 0.1845323183806613, 0.15684363461332396, 0.15321984625188634, 0.16768406698247418, 0.1505711954087019, 0.20166987378615886, 0.24121329799527302, 0.12550054147141054, 0.24189270450733602, 0.10310668061720207, 0.1430821089888923, 0.21686125081032515, 0.16195115429582074, 0.21762707299785689, 0.12748419831041247, 0.23730286251520738, 1.9655590038746595, 18.85792449116707, 51.35061174631119, 77.87489846348763, 85.66856905817986, 80.1751658320427, 70.99780708551407, 58.77457357943058, 54.70251448452473, 40.857649594545364, 30.557101517915726, 24.605963453650475, 23.44071228057146, 35.78647971153259, 40.44561490416527, 54.26652207970619, 65.22129625082016, 43.35438922047615, 16.104121059179306, 5.532283214852214, 0.9227434359490871, 0.4218122485326603, 0.3567149431910366, 0.18098471889970824, 0.12609485333086923, 0.20078797970199957, 0.1048499187163543, 0.17787850432796404, 0.15043168648844585, 1.153169246390462, 0.48998174839653075, 0.7183268142398447, 2.307899259030819, 2.7465956937521696, 3.8732948480173945, 6.184520591050386, 6.706917509436607, 5.876875324174762, 4.211639855057001, 7.552876565605402, 12.20785478129983, 10.855246111750603, 7.497696401551366, 9.448491297662258, 5.3806770499795675, 4.999093450605869, 1.6566989896818995, 0.8975732303224504, 0.25884694943670183, 0.4890644538681954, 1.877147366758436, 6.886798432096839, 11.657998636364937, 22.15900495648384, 14.650175627321005, 11.804638467729092, 16.066400483250618, 17.98844564706087, 12.021047305315733, 9.172684047371149, 10.2944266051054, 14.938730243593454, 10.549352075904608, 7.800533026456833, 19.137114509940147, 33.54512058198452, 7.141622733324766, 1.676513145212084, 3.1311519211158156, 1.1602469603531063, 0.6949812825769186, 0.319049108074978, 1.2453140644356608, 0.7254655030556023, 0.8811912406235933, 0.44838045258075, 0.29470672365278006, 0.21730756358010694, 0.5583312339149415, 0.44123288767877966, 0.9347861772403121, 1.8548340140841901, 7.245956109836698, 18.172505870461464, 47.171603590250015, 76.00868940353394, 62.881074026227, 39.79780666530132, 29.390566013753414, 26.88481517136097, 27.107861302793026, 23.050769604742527, 31.30475129932165, 55.48929266631603, 57.14223437011242, 67.78752654790878, 84.08885702490807, 84.60367619991302, 84.48649048805237, 66.05984285473824, 40.67976973950863, 11.322820521891117, 0.4916066658915952, 0.11136288798297755, 0.20396241248818114, 0.11952485743677244, 0.10992655763402581, 0.16379659355152398, 0.15736331610241905, 0.14081265107961372, 0.11976706475252286, 0.1992288907058537, 0.16908758698264137, 0.08045457463595085, 0.12028554396238178, 0.20455981168197468, 0.14685747359180823, 0.16794981522252783, 0.16553344175918028, 0.19537137035513297, 0.11991899722488597, 0.12394033183227293, 0.18670590565307066, 0.1028256886638701, 0.043833015515701845, 0.08093596130493097, 0.12527357786893845, 0.13132135412888601, 0.08493132816511206, 0.1747980125946924, 0.11829038383439183, 0.24478765932144597, 0.13835998659487814, 0.09329483524197713, 0.10329537908546627, 0.13339942699531093, 0.17059542326023802, 0.2401432694750838, 0.09546436296659522, 0.08800330746453255, 0.07721579022472724], [0.01369728995996411, 0.026131646809517406, 0.05868498243216891, 0.029050112862023525, 0.0372576761583332, 0.056724966707406566, 0.023653901444049552, 0.06199063434905838, 0.025085331762966234, 0.06763871584553272, 0.02879377505450975, 0.04768535938637797, 0.060109705591457896, 0.031875947752268985, 0.024451415192743298, 0.050442541905795224, 0.04324928297137376, 0.021565147217188496, 0.02023254128289409, 0.00930337959289318, 0.05870482375030406, 0.024251037175417878, 0.0192851823521778, 0.03297430033853743, 0.037353795414674096, 0.05612063585431315, 0.07700359536102042, 0.09084745484869927, 0.009932575176208047, 0.027800232273875736, 0.019998273091914598, 0.02021546632022364, 0.03468715491180774, 0.01198386300529819, 0.3619567322311923, 8.500439319759607, 47.761103957891464, 59.44535918533802, 68.12550321221352, 60.562024265527725, 43.83212238550186, 44.69563364982605, 34.69857528805733, 31.730583049356937, 21.61346822977066, 14.493225049227476, 27.63307861983776, 34.294664561748505, 43.263247311115265, 58.46254572272301, 49.550747126340866, 23.324643708765507, 7.113272929564118, 0.9237972856499255, 0.082848683668999, 0.040177953051170334, 0.10067326744319871, 0.02871352291549556, 0.0785373400140088, 0.08889719465514645, 0.050558172224555165, 0.06985546642681584, 0.13289521186379716, 0.2116020509856753, 0.3647931612795219, 1.6042196494527161, 1.9615302700549364, 2.773635992780328, 1.5708448528312147, 3.799531781114638, 4.228660091757774, 4.7660063579678535, 5.804329616948962, 4.337940802797675, 3.5161023773252964, 6.561809945851564, 4.06689184717834, 3.0898590618744493, 13.945379946380854, 2.028835820965469, 3.3305205730721354, 3.069950742647052, 1.3363805715925992, 0.2882916881935671, 0.24175953352823853, 0.35430732707027346, 2.749304948374629, 5.185124343261123, 6.094271158799529, 1.0130077111534774, 4.301813766360283, 9.513334818184376, 4.12804339081049, 8.897620607167482, 5.837497562170029, 9.757282678037882, 6.873938972130418, 3.5967881977558136, 3.9667940558865666, 1.5408832230605185, 7.112373327836394, 1.9849354703910649, 2.1492732083424926, 3.8988905120640993, 2.1149016777053475, 0.9150704008061439, 1.5704554924741387, 0.40961537801194936, 0.4912889376282692, 0.060725138973793946, 0.8371175243519247, 0.4450927977450192, 0.04765490164572839, 0.14662942645372823, 0.04468383216590155, 0.03934398315323051, 0.03736527272849344, 0.1622234334354289, 1.0749251511879265, 4.955164482817054, 19.246195256710052, 47.13946111500263, 73.13120260834694, 50.682884976267815, 28.461120687425137, 25.805420391261578, 23.08252640068531, 22.727897129952908, 14.084237795323133, 27.44582276791334, 36.04686453938484, 39.03273291885853, 55.17674043774605, 56.064148619771004, 59.60482142865658, 53.17987158894539, 28.005485236644745, 8.972217254340649, 0.8046977233607322, 0.2181595194269903, 0.018890307837864384, 0.11636816198006272, 0.02113881491823122, 0.1140148562262766, 0.006746907201886643, 0.03388877470570151, 0.01917750785651151, 0.10235403897240758, 0.06090846058214083, 0.06440578697947785, 0.06868576005217619, 0.034516164087108336, 0.02097857966873562, 0.054561294527957216, 0.11622733945841901, 0.04506013814534526, 0.020224001018505078, 0.057547021424397826, 0.03287300089141354, 0.042227122976328246, 0.027438550314400345, 0.032077737705549225, 0.018709978940023575, 0.012379597483231919, 0.05902223660086747, 0.07500195628381334, 0.03722199369804002, 0.07339065719861537, 0.0373127175407717, 0.03066250847041374, 0.027818876878882293, 0.02264131515403278, 0.06566269570612349, 0.09677855807240121, 0.043057942457380705, 0.045434685234795325, 0.024974534680950455, 0.038117023796075955, 0.09066240774700418, 0.05275340052321553, 0.04524260257312562, 0.06465703365392983, 0.039056289606378414, 0.027797707116405945, 0.037657144566765055, 0.09706696408102289, 0.006669479398624389, 0.04175325055257417, 0.04515627595537808, 0.08899391134036705, 0.06504303208203055, 0.027536463712749537, 0.020043551521666814, 0.047702306328574196, 0.043822321167681366, 0.019757334848691244, 0.05399879482865799, 0.058889165811706334, 0.0483418743533548, 0.031066643132362515, 0.06094246949942317, 0.05527086563233752, 0.05866157509444747, 0.07344341647694819, 0.07135011474019848, 0.04020247361040674, 0.06483335309894755, 0.03551090172550175, 0.028286583910812624, 0.1035492010123562, 0.34117309434805065, 11.098597403615713, 55.6547661870718, 69.11542609333992, 77.85337641835213, 70.73086380958557, 53.86128142476082, 52.874702364206314, 44.55165937542915, 42.69009366631508, 29.729010052978992, 23.213680163025856, 29.901914075016975, 28.769971914589405, 30.29162496328354, 35.54896205663681, 40.75004316866398, 22.703610733151436, 6.009755143895745, 0.8749444351997226, 0.11287950386758894, 0.07571446258225478, 0.07591204455820844, 0.069402036460815, 0.13290355360368267, 0.4225241462700069, 0.17831277946243063, 0.8164509083144367, 1.7800235096365213, 1.8234585039317608, 2.190926098264754, 4.153399430215359, 5.60570714995265, 4.936352167278528, 5.469201849773526, 3.9601327758282423, 9.705967381596565, 8.817566502839327, 5.749615877866745, 9.296898432075977, 8.751099519431591, 7.721356675028801, 7.803785651922226, 6.7325651831924915, 8.871649950742722, 6.224452648311853, 5.89436293579638, 2.7209484949707985, 1.256056206766516, 0.28874905896373093, 0.18972036108607426, 0.7295726076699793, 0.8116951072588563, 3.392295283265412, 3.718672594986856, 3.938064747489989, 2.9325023805722594, 3.4827342303469777, 6.678063757717609, 10.863101240247488, 6.389636434614658, 11.323013361543417, 12.421853598207235, 7.2286019660532475, 9.31513650342822, 6.718580508604646, 8.116966746747494, 2.778211422264576, 1.8223166652023792, 3.613901766948402, 2.3935298016294837, 3.0411136150360107, 1.9165468588471413, 1.9931638101115823, 1.1637142742983997, 0.9961518156342208, 1.0711727337911725, 1.62773456890136, 0.21852752077393234, 0.16004197939764708, 0.12264468299690634, 0.05286799554596655, 0.018503556129871868, 0.07902758050477132, 0.7768977619707584, 4.900752827525139, 17.033860869705677, 39.00285892188549, 51.59885622560978, 37.76065997779369, 24.003289192914963, 24.39847558736801, 23.891350999474525, 30.291364677250385, 26.218458227813244, 40.290469229221344, 46.02951407432556, 45.921109691262245, 63.00225332379341, 65.59676930308342, 71.31001353263855, 66.59991547465324, 41.71351566910744, 16.639521829783916, 2.2314295498654246, 0.17059224686818197, 0.09987142140744254, 0.03908892555045895, 0.05343389057088643, 0.049048217115341686, 0.005243687546681031, 0.06472948211012408, 0.012896298321720678, 0.06791488383896649, 0.031359116110252216, 0.019606337482400704, 0.03877470393490512, 0.03598897470510565, 0.08066798662184738, 0.05100456291984301, 0.07692754748859443, 0.008793032466201112, 0.015958828225848265, 0.09535584613331594, 0.06609731222852133, 0.08342097600689158, 0.03334498454933055, 0.004659025462387945, 0.02041422460024478, 0.04678143093769904, 0.02126062918250682, 0.01989560067158891, 0.05335846981324721, 0.038906212503206916, 0.01968669723282801, 0.03282135854533408, 0.05094311309221666, 0.04159811571298633, 0.021076485645608045, 0.059716660471167415, 0.04423744889209047, 0.037592273438349366, 0.07392113693640567, 0.14032679668162018, 0.12763801583787426, 0.13488118420355022, 0.14941399422241375, 0.1769114562193863, 0.1687320091878064, 0.12856080225901678, 0.08063214088906534, 0.14810776978265494, 0.14054141094675288, 0.12307037148275413, 0.2028535251156427, 0.11103112570708618, 0.11591675807721913, 0.17215492785908282, 0.1609104999806732, 0.139887742116116, 0.1694091150420718, 0.08278847322799265, 0.20145083632087335, 0.10562646493781358, 0.12527311773737893, 0.18745914101600647, 0.15225812676362693, 0.12401289161061868, 0.14980457170167938, 0.15251606761012226, 0.17413141555152833, 0.10689164861105382, 0.16256603848887607, 0.1904606237076223, 0.23328545386902988, 0.1840745023218915, 0.8977028983645141, 16.8445835262537, 64.45106238126755, 80.57733625173569, 86.63275212049484, 79.84679505228996, 63.6969168484211, 62.25229896605015, 49.59199011325836, 45.08384741842747, 31.0113063454628, 23.11977580189705, 37.65897363424301, 45.14046438038349, 58.79138007760048, 74.58258032798767, 63.989174365997314, 31.269644983112812, 9.986974652856588, 1.6252329968847334, 0.2957942965440452, 0.28776221035514027, 0.2924143779091537, 0.20414998289197683, 0.21558441541856155, 0.28726604010444134, 0.3051527787465602, 0.5456400336697698, 1.116137858480215, 1.3022683770395815, 1.7710423353128135, 4.433119520545006, 8.090064190328121, 9.663265272974968, 7.410395611077547, 9.53396961092949, 13.051658403128386, 17.929081432521343, 13.914464805275202, 13.251967504620552, 11.186475288122892, 16.296575032174587, 15.846701972186565, 13.795041963458061, 24.32231817394495, 12.296722512692213, 6.240336745977402, 7.296387953683734, 3.8576862355694175, 2.777463337406516, 1.1535860365256667, 3.0906821927055717, 2.815114804543555, 4.486542753875256, 6.183738308027387, 16.99475906789303, 16.689228862524033, 20.169711001217365, 15.004522763192654, 19.14141207933426, 18.518745191395283, 21.18023257702589, 17.86677997559309, 14.817022774368525, 15.372782852500677, 8.867255486547947, 18.953147381544113, 11.606542747467756, 6.298294086009264, 10.866641700267792, 7.190345143899322, 7.326123733073473, 4.558667633682489, 1.2189181870780885, 1.992624239064753, 1.8477570125833154, 2.570747067220509, 2.1151427272707224, 0.28318986820522696, 0.3792846039868891, 0.2314610025496222, 0.27343905705492944, 0.22324746125377715, 0.4891024518292397, 2.015036386437714, 7.763485964387655, 25.17102163285017, 61.15966759622097, 93.49496349692345, 68.90578374266624, 42.666732519865036, 36.14005073904991, 32.84318804740906, 34.62602958083153, 26.70166689902544, 43.40124070644379, 51.58222831785679, 57.262163534760475, 76.08148589730263, 77.41855815052986, 81.37109845876694, 81.36029943823814, 57.568202912807465, 30.250125490128994, 3.5102065186947584, 0.3368049318669364, 0.17392220412148163, 0.16851740976562724, 0.19098863209364936, 0.18541600846219808, 0.09942818112904206, 0.1446487382054329, 0.09094448323594406, 0.17910148948431015, 0.13400199153693393, 0.20482869178522378, 0.21537839522352442, 0.14177754695992917, 0.23174067348008975, 0.13424670731183141, 0.22907121281605214, 0.11083617835538462, 0.10362672575865872, 0.17173518397612497, 0.09715427775518037, 0.14716294157551602, 0.12101552783860825, 0.12974185607163236, 0.12060988476150669, 0.11726699929567985, 0.1580925949383527, 0.13661905657500029, 0.14180684695020318, 0.12438278543413617, 0.14743403327884153, 0.2196815307252109, 0.10389370596385561, 0.12868266290752217, 0.12068135358276777, 0.17595543642528355, 0.11653930123429745, 0.18112654332071543], [0.04105920517758932, 0.0771976298710797, 0.01505238760728389, 0.022470593357866164, 0.04163842175330501, 0.033408490126021206, 0.03604165234719403, 0.04159807118412573, 0.055558433014084585, 0.05368720041587949, 0.06781712814699858, 0.026062628930958454, 0.027514850517036393, 0.03641059622168541, 0.08328727068146691, 0.006294114091360825, 0.0687524420209229, 0.022128478121885564, 0.020874079709756188, 0.030455317537416704, 0.08154192488291301, 0.012751739086525049, 0.10478169308044016, 0.13265782850794494, 0.13851521420292556, 0.1821443988592364, 0.056015191512415186, 0.12702292384346947, 0.19227475917432457, 0.14695132558699697, 0.25166776904370636, 0.08468746586004272, 0.14792534988373518, 0.2835958229843527, 9.792397543787956, 49.964978098869324, 61.50503106415272, 68.04117053747177, 50.537535175681114, 51.22569724917412, 50.84726795554161, 26.313285939395428, 23.270711302757263, 20.60782939195633, 25.452653020620346, 21.652628928422928, 37.5938755273819, 64.88838851451874, 54.18413870036602, 44.63992103934288, 20.485751442611217, 3.0605438724160194, 0.31783453887328506, 0.08458250391413458, 0.05415261235611979, 0.10153867842745967, 0.1879200740950182, 0.19664670660858974, 0.1104449552076403, 0.390695896348916, 0.5257492291275412, 1.0666195093654096, 2.3043944220989943, 2.909223404712975, 1.5579294646158814, 4.110086979344487, 4.0647193137556314, 2.4487842991948128, 5.50698559731245, 5.781668582931161, 7.8614461328834295, 6.654887851327658, 7.910813083872199, 5.182594154030085, 8.959088958799839, 4.84113497659564, 2.680541225709021, 5.828695809468627, 5.323498193174601, 0.8560063107870519, 5.037183556705713, 5.45871346257627, 1.6956790792755783, 0.3089585417183116, 0.5452072131447494, 5.668593775480986, 20.823965594172478, 31.310226805508137, 27.70125076174736, 28.16834829747677, 11.874796003103256, 7.76586321182549, 7.59306225925684, 12.495934423059225, 6.548103131353855, 5.813282411545515, 6.665575252845883, 1.7438551504164934, 4.354628557339311, 3.6084272107109427, 0.7648810849059373, 2.9959250148385763, 0.9926327294670045, 3.315177708864212, 0.10761953963083215, 1.1609944514930248, 1.143557543400675, 0.9251526847947389, 0.8259658946190029, 0.9992691921070218, 0.39575535454787314, 0.4510295041836798, 0.7648684387095273, 0.42703931336291134, 0.29163224331568927, 0.29642945621162653, 0.09835291304625571, 0.07003122926107608, 0.0233447301434353, 0.36377757671289146, 2.415577881038189, 11.986993532627821, 33.977202996611595, 59.211124554276466, 49.9580966681242, 47.42381505668163, 44.725222662091255, 43.65530267357826, 29.912828989326954, 11.795836240053177, 22.869730219244957, 30.79267557710409, 41.55426241457462, 45.6302011013031, 50.166857466101646, 56.08787454664707, 58.772065714001656, 56.35477602481842, 22.287225276231766, 1.0898455255664885, 0.16070299549028277, 0.04381006830953993, 0.05771968208136968, 0.05936204004683532, 0.03841463243588805, 0.05194429628318176, 0.06359380320645869, 0.19736704998649657, 0.12053092767018825, 0.22320474323350936, 0.14559466479113325, 0.1436017607920803, 0.02361397575441515, 0.034755892629618756, 0.04132020738325082, 0.07865802806918509, 0.0352890626527369, 0.04432837311469484, 0.05393691455537919, 0.062174879931262694, 0.07628560459124856, 0.020752788659592625, 0.12128166941693053, 0.008928887236834271, 0.0390102133678738, 0.07018011150648817, 0.06778978742659092, 0.11885590778547339, 0.004007365532743279, 0.058077990979654714, 0.06260460198973306, 0.027329128060955554, 0.019146630802424625, 0.11696199886500835, 0.05232126648479607, 0.02788710993627319, 0.04852509948250372, 0.043447258285596035, 0.06274917235714383, 0.011294088690192439, 0.02388020082435105, 0.007002767251833575, 0.01639137972233584, 0.03193629177985713, 0.09430784455616958, 0.055289304291363806, 0.07026056773611344, 0.028764551134372596, 0.04514770786045119, 0.025486085942247882, 0.07398269808618352, 0.053001255582785234, 0.028529707778943703, 0.018909826321760193, 0.0198287201783387, 0.05393754909164272, 0.09204291374771856, 0.029540839459514245, 0.04976215946953744, 0.040101868071360514, 0.08062787353992462, 0.13471912883687764, 0.06761070719221607, 0.07194528749096207, 0.1494446152355522, 0.026874113609665073, 0.1606714987428859, 0.06286735195317306, 0.1827649530605413, 0.5701111361850053, 13.22095736861229, 58.185719177126884, 70.40987223386765, 75.83476513624191, 60.55466786026955, 58.56140501797199, 58.954303935170174, 40.10155476629734, 34.53421890735626, 30.88944498449564, 30.841824039816856, 21.12262386828661, 29.3294557929039, 49.47828121483326, 48.22578102350235, 43.38740944862366, 17.00006738305092, 2.6496239472180605, 0.1317505381302908, 0.08495526242768392, 0.15851869160542265, 0.18933745741378516, 0.24888401763746515, 0.3310052555752918, 0.7051241851877421, 1.0801619826816022, 1.8853546888567507, 3.0648984387516975, 6.000145934522152, 5.071437768638134, 6.425208700820804, 8.799394927918911, 8.315863274037838, 8.895118441432714, 8.325843438506126, 7.689270246773958, 8.521067462861538, 8.69871648028493, 11.744677685201168, 8.66350281983614, 12.257020343095064, 10.284900516271591, 6.0456532426178455, 8.27672727406025, 6.9533243123441935, 7.793445456773043, 5.392810273915529, 2.978482525795698, 1.076639334205538, 0.18521187332225963, 0.23643903230549768, 4.926787130534649, 19.682784229516983, 32.89542764425278, 30.15427753329277, 27.433159947395325, 13.694095630198717, 3.1068351259455085, 2.9169985000044107, 5.784706044942141, 6.6374007146805525, 6.558913551270962, 6.965947709977627, 4.284755056723952, 6.165493112057447, 6.578083522617817, 2.7916092658415437, 3.6745308386161923, 4.020967511460185, 3.042934429831803, 1.051050794776529, 2.03440323472023, 2.96501153614372, 3.504970637150109, 2.3778504179790616, 2.17593542765826, 1.971519102808088, 1.9261118955910206, 2.0075814239680767, 1.1758402548730373, 0.5798013287130743, 0.4059813776984811, 0.14452031697146595, 0.025958112273656297, 0.051967429026262835, 0.1302858057897538, 1.5217877039685845, 9.535454381257296, 33.064681962132454, 52.317032888531685, 40.30639037489891, 34.41567666828632, 31.120276898145676, 39.843848794698715, 30.124971605837345, 20.195462219417095, 31.75943300127983, 41.175696328282356, 48.36314745247364, 52.50650592148304, 59.51443187892437, 68.04755419492722, 70.14379531145096, 69.8899233341217, 30.14597687870264, 1.9622234953567386, 0.12219811789691448, 0.057410135996178724, 0.04385570668091532, 0.038240101566771045, 0.026750816905405372, 0.02504249870980857, 0.08734587594517507, 0.06883323221700266, 0.13447328499751166, 0.03575305709091481, 0.14719077211339027, 0.11540564097231254, 0.048342757509090006, 0.01608351645700168, 0.023911363605293445, 0.03541934667737223, 0.02514594110834878, 0.01763555505021941, 0.0508145619824063, 0.009639472300477792, 0.045853033880121075, 0.031682098779128864, 0.09772748293471523, 0.0208891712827608, 0.035073632025159895, 0.07408852834487334, 0.020156198406766634, 0.0884254855918698, 0.051536504688556306, 0.013539125302486354, 0.0709305341297295, 0.03550939145497978, 0.07075838555465452, 0.17034246964612976, 0.03783751613809727, 0.0031883584915703977, 0.11224714951822534, 0.1820226272684522, 0.14051349135115743, 0.17426298349164426, 0.132621344528161, 0.14693162898765877, 0.11189363489393145, 0.14730056544067338, 0.14044430834474042, 0.2195811181445606, 0.1557398383738473, 0.12589438440045342, 0.1614987856009975, 0.16059103509178385, 0.24935562280006707, 0.182156391965691, 0.12902648508315906, 0.1790635657380335, 0.19010853400686756, 0.08925865025958046, 0.16784030391136184, 0.08108047972200438, 0.12310367164900526, 0.310343211167492, 0.17470622377004474, 0.20929947844706476, 0.11568162342882715, 0.154608256125357, 0.31107336573768407, 0.31137604324612767, 0.33392453799024224, 0.14820769254583865, 0.37596996466163546, 1.107542363461107, 18.242885693907738, 66.13663673400879, 79.92034390568733, 86.40408799052238, 66.67616218328476, 68.56132462620735, 67.85789117217064, 42.41406887769699, 32.62159153819084, 29.612424708902836, 36.07511602342129, 30.176415145397186, 48.67351479828358, 79.18506056070328, 69.9164991080761, 60.09496092796326, 26.554660387337208, 4.87833640538156, 0.5436649709008634, 0.30378654424566776, 0.3808121517067775, 0.27526533405762166, 0.28200338187161833, 0.26145844836719334, 0.5145756911952049, 0.5449714476708323, 1.3665623520500958, 3.1424351781606674, 6.067733382806182, 7.040121629834175, 8.647163696587086, 13.588941972702742, 13.8017419539392, 12.29503445327282, 14.999104253947735, 17.73957420140505, 18.62127508968115, 13.577601481229067, 18.62655870616436, 13.21857014670968, 20.124715715646744, 14.526284225285053, 13.794167060405016, 16.19437761604786, 17.19040296971798, 14.228265266865492, 13.961153849959373, 9.05341699719429, 4.968172609806061, 0.6242960505187511, 0.6823714217171073, 4.296651743352413, 12.340198829770088, 21.73340879380703, 17.22156699746847, 20.15157837420702, 15.885068513453007, 17.22076714038849, 20.99645733833313, 24.97159693390131, 21.772199012339115, 18.885852992534637, 14.421379454433918, 6.341806976124644, 12.531338073313236, 12.837822027504444, 10.80455968156457, 10.672367624938488, 7.836689036339521, 11.279528494924307, 6.974100647494197, 6.167651871219277, 8.305042404681444, 4.74169478751719, 3.483518650755286, 3.430540468543768, 1.90784354461357, 2.0949142752215266, 2.3853277042508125, 0.9810479229781777, 0.7806180592160672, 0.3355693450430408, 0.24899431562516838, 0.09333796144346707, 0.1780839604907669, 0.6308002327568829, 3.3704324439167976, 16.434832513332367, 44.85015615820885, 73.73911678791046, 70.05444690585136, 61.4316987991333, 59.29747872054577, 55.58306023478508, 40.665858685970306, 21.113373264670372, 37.17612974345684, 48.03406611084938, 57.36524820327759, 62.673441767692566, 71.31967261433601, 79.01418372988701, 82.33661904931068, 83.09426799416542, 40.197514817118645, 3.063949914649129, 0.32719373353756964, 0.1931467084796168, 0.1312901542405598, 0.11541484360350296, 0.18161573738325387, 0.12591185455676168, 0.21718485688325018, 0.18781544611556455, 0.19576660852180794, 0.20985503535484895, 0.3258983592968434, 0.19697483978234231, 0.14093341334955767, 0.13571393326856196, 0.14680728956591338, 0.15564656525384635, 0.1330060590407811, 0.12428188303601928, 0.12281445669941604, 0.1266780775040388, 0.1268192785209976, 0.15734789427369833, 0.2709664584835991, 0.08799004528555088, 0.1546639172011055, 0.15341535763582215, 0.16912669816520065, 0.2663602150278166, 0.14618838293245062, 0.15073473507072777, 0.21338240389013663, 0.14758307137526572, 0.21933552663540468, 0.26641436212230474, 0.09842697938438505, 0.08374075259780511], [0.026827078145288397, 0.06871205434435979, 0.04536536864179652, 0.13263278844533488, 0.06009261393046472, 0.089512516715331, 0.10209121479419991, 0.04227231605909765, 0.16834299021866173, 0.03322428907267749, 0.034256638755323365, 0.04346779351180885, 0.040352431969949976, 0.12890064652310684, 0.03084026582655497, 0.10430625843582675, 0.037763846848974936, 0.05687698823749088, 0.07220713945571333, 0.1793449732940644, 0.05582890873483848, 0.02158813709684182, 0.18437866412568837, 0.15557944541797042, 0.2940495667280629, 0.345233473344706, 0.28538650658447295, 0.26992489874828607, 0.3203152120113373, 0.09182628826238215, 0.06660639584879391, 0.132283786078915, 0.21925872919382527, 6.835847441107035, 38.74346204102039, 59.55718718469143, 65.3885480761528, 55.311933383345604, 48.209673687815666, 50.75346238911152, 27.32846036553383, 17.523236609995365, 18.384004421532154, 18.715367540717125, 31.133106909692287, 45.026820078492165, 55.75040705502033, 47.87373371422291, 27.161341533064842, 7.867355290800333, 1.187804862856865, 0.004008117421108182, 0.09291726019000635, 0.049998811809928156, 0.10579004170722328, 0.059296359977452084, 0.12812980741728097, 0.48450348142068833, 0.8546909282449633, 2.3746645264327526, 1.2221787683665752, 3.9067727141082287, 6.655913796275854, 3.240301301702857, 3.702055849134922, 4.934712080284953, 4.60419774055481, 4.64636217802763, 5.408177124336362, 1.9798154826276004, 10.552781391888857, 8.613752089440823, 4.820686848834157, 10.842662137001753, 8.811189495027065, 5.472132442519069, 6.676317751407623, 7.133833626285195, 7.84718407317996, 4.759706296026707, 6.51698375120759, 1.7567736259661615, 0.3987534827319905, 0.270549074630253, 7.013653200119734, 41.28655917942524, 65.0108939409256, 61.49628393352032, 62.15365245938301, 61.34094826877117, 44.12672817707062, 16.220434717833996, 3.0521121248602867, 7.663813512772322, 3.20089646615088, 5.44567066244781, 10.383448228240013, 3.297549979761243, 8.282607458531857, 6.705925762653351, 1.1692864377982914, 2.1408846834674478, 0.8478616853244603, 1.1775546753779054, 0.4381077631842345, 1.278645875863731, 1.2067885254509747, 4.595265844836831, 2.336203227750957, 0.4326179187046364, 0.897121470188722, 1.0380709287710488, 0.8618375135120004, 0.8029026165604591, 0.661660514306277, 0.16327296383678913, 0.08418004465056583, 0.09001161102787592, 0.041382232375326566, 0.04627424721547868, 0.05777485705038998, 0.5942647182382643, 4.498542034998536, 19.554755799472332, 47.21605360507965, 47.359381914138794, 49.417017102241516, 85.99484235048294, 98.0908776819706, 41.747033670544624, 23.616783432662487, 21.414526104927063, 59.241830706596375, 46.379102915525436, 45.754614025354385, 54.224925711750984, 55.59843420982361, 56.85476839542389, 55.25315433740616, 16.846871003508568, 1.4323938195593655, 0.09616869079764001, 0.12139674683567137, 0.09650329549913295, 0.18262338096974418, 0.08676401732373051, 0.15515760867856443, 0.14091857039602473, 0.21891222044359893, 0.4121051944093779, 0.34067594446241856, 0.2587529638549313, 0.035525822604540735, 0.05247428249276709, 0.24286935600684956, 0.07659839757252485, 0.09377140537253581, 0.019519363340805285, 0.27891949110198766, 0.09981108480133116, 0.07802004081895575, 0.17126743798144162, 0.022018267336534336, 0.07912060871603899, 0.05777307218522765, 0.13913885573856533, 0.11598067925660871, 0.23270130943274125, 0.0422659744072007, 0.02122197071003029, 0.10434617855935358, 0.05441240115032997, 0.0767998312949203, 0.0465624231583206, 0.041154530335916206, 0.030176904547261074, 0.03628116937761661, 0.061075217454344966, 0.012463757957448252, 0.07088219063007273, 0.07152687205234542, 0.03495205339277163, 0.052605278979172, 0.027803466182376724, 0.09681987343356013, 0.029533104425354395, 0.03991212317487225, 0.1123502486734651, 0.021097783428558614, 0.1085969184350688, 0.07679116301005706, 0.05044209290645085, 0.04811186052393168, 0.025818922476901207, 0.03342881012940779, 0.11072637018514797, 0.034284959110664204, 0.034676961513468996, 0.11177797117852606, 0.10605196046526544, 0.14414572535315529, 0.19388766871998087, 0.17013217468047515, 0.19400083139771596, 0.3288689092732966, 0.05503140055225231, 0.08627087503555231, 0.1405686922953464, 0.1521986213629134, 10.724817160516977, 46.662305518984795, 71.8785086274147, 73.42586159706116, 64.40421849489212, 53.24675939977169, 57.92430840432644, 38.88946160674095, 26.098234578967094, 24.305367283523083, 25.904391780495644, 35.822026804089546, 31.688646599650383, 45.60499705374241, 39.32884342968464, 25.482331328094006, 8.890819922089577, 1.2096471595577896, 0.02304564834048506, 0.037690136741730385, 0.05805771921586711, 0.33142801257781684, 0.6544593663420528, 0.7363307825289667, 1.1606794246472418, 2.1051164902746677, 4.291824102401733, 5.898281475529075, 5.128795690834522, 8.832556698471308, 9.977962486445904, 9.672551024705172, 7.34696751460433, 8.174902237951756, 12.921389043331146, 8.81272366270423, 5.016661332920194, 9.225119333714247, 6.565260160714388, 8.23189252987504, 7.985747437924147, 9.110091906040907, 7.7312318701297045, 6.020429246127605, 7.400946943089366, 5.814677411690354, 3.663929644972086, 2.893252861686051, 1.8562642810866237, 0.41058272297959775, 0.17202099988935515, 6.815578378736973, 45.574636682868004, 72.87712544202805, 72.2547796368599, 72.47796446084976, 71.15571141242981, 48.780805841088295, 19.139865562319756, 4.022582424804568, 4.103956483304501, 3.5560800321400166, 4.229588191956282, 3.385075908154249, 2.868986176326871, 4.731119005009532, 5.48945571295917, 1.9718094309791923, 1.3413516548462212, 2.4714906932786107, 0.5800305039156228, 1.362531480845064, 1.6793295065872371, 3.2383201830089092, 4.838760104030371, 3.861356838606298, 2.2300872718915343, 3.2930484088137746, 2.599735949188471, 3.255584556609392, 2.480438738130033, 0.9087696857750416, 0.5411589459981769, 0.6405105523299426, 0.15914844843791798, 0.11412910986109637, 0.10194516013143584, 0.03748703689780086, 0.3517767519224435, 3.25615500099957, 17.057507000863552, 45.78064262866974, 46.18882812559605, 41.029882952570915, 69.23217862844467, 78.34965258836746, 34.53206442296505, 28.875670842826366, 32.69036404788494, 64.53301638364792, 51.074993535876274, 53.5246916860342, 61.09292417764664, 66.40292644500732, 70.13419702649117, 68.53731751441956, 25.133268758654594, 1.7696916265413165, 0.020994183323637117, 0.04946188651956618, 0.06611795135540888, 0.1567492779577151, 0.07926644073450007, 0.02469321247190237, 0.12928743904922158, 0.11117206697235815, 0.31981565756723285, 0.19543777772923931, 0.130206351459492, 0.029445543987094425, 0.08067397575359792, 0.12709917209576815, 0.06100006015913095, 0.04441159013367724, 0.01439080933778314, 0.13376493472605944, 0.19893087388481945, 0.04499296635913197, 0.07514573997468688, 0.09087703685509041, 0.056072444494930096, 0.14335909334477037, 0.13428166246740147, 0.10073101395391859, 0.10278570174705237, 0.04016283179225866, 0.03217992401914671, 0.01319101536864764, 0.05407536220445763, 0.08358770690392703, 0.034989249834325165, 0.0692570950195659, 0.027232159045524895, 0.16324578638887033, 0.17410777072655037, 0.21270704950438812, 0.2974651975091547, 0.1619151304475963, 0.18966691161040217, 0.2530874381773174, 0.14980853477027267, 0.3397404227871448, 0.2001141689834185, 0.094964229647303, 0.15649771958123893, 0.12298281289986335, 0.2980943309376016, 0.20743790490087122, 0.20393064856762066, 0.13388293620664626, 0.11454473482444882, 0.12816838425351307, 0.285159824998118, 0.14669443859020248, 0.1536431969725527, 0.29037554981186986, 0.2503306861035526, 0.5462437262758613, 0.4928528505843133, 0.44490313448477536, 0.4102026839973405, 0.49315128300804645, 0.1600281457649544, 0.27758407057262957, 0.2085794319282286, 0.5272582231555134, 14.322952385991812, 57.344862297177315, 80.80969378352165, 83.8929395377636, 74.01065781712532, 66.46562308073044, 63.12215968966484, 40.692483857274055, 29.42049890756607, 28.700794726610184, 28.55676155537367, 44.50965262949467, 59.67372693121433, 74.83220413327217, 63.81106272339821, 36.900963708758354, 11.953770015388727, 1.8788066902197897, 0.16786454245448112, 0.23620966414455324, 0.17954760929569602, 0.37029354425612837, 0.42322155728470534, 0.41607455641496927, 0.7167481177020818, 2.363642742857337, 6.46670532412827, 6.394944749772549, 11.578074675053358, 18.001389652490616, 14.902388043701649, 13.990267887711525, 17.941862046718597, 14.802014529705048, 14.041284900158644, 16.40185598284006, 10.899084359407425, 23.94530050456524, 21.496041230857372, 16.29858512431383, 25.718921832740307, 20.165766812860966, 16.321589089930058, 16.385499760508537, 19.731966890394688, 14.79950761422515, 12.056261915713549, 15.806620772928, 6.0916834976524115, 1.3777922932058573, 0.3781044407514855, 7.74330192245543, 38.75845983624458, 59.49551649391651, 62.29173704981804, 61.17005243897438, 57.45940715074539, 41.30459301173687, 19.69679407775402, 11.114073023200035, 17.258115336298943, 12.202722206711769, 13.653427362442017, 23.117685914039612, 13.781297150999308, 14.354831725358963, 17.61745635420084, 10.913360193371773, 4.553625304251909, 4.27673558704555, 5.00898526981473, 4.376834090799093, 3.658706587739289, 7.684820210561156, 11.167976930737495, 7.587446635589004, 4.0121852327138186, 4.903017980977893, 4.564619539305568, 3.0383635126054287, 2.844332861714065, 1.3014689949341118, 0.6349602970294654, 0.4237598815234378, 0.20073065621545538, 0.2336096388171427, 0.2358877650112845, 0.25102788931690156, 1.2257497454993427, 6.616925988346338, 27.670590206980705, 60.249502435326576, 61.44056752324104, 65.0001785159111, 96.84465855360031, 108.87380227446556, 56.3557905703783, 34.65602517127991, 33.45837123692036, 69.92476746439934, 59.81404200196266, 60.34829333424568, 72.72894099354744, 78.06574702262878, 79.13691714406013, 82.84810200333595, 31.936693489551544, 2.5069945631548762, 0.18256353418109939, 0.24447693693218753, 0.1491551034268923, 0.2815697301412001, 0.1839856820879504, 0.260650219861418, 0.36140472278930247, 0.4013979627052322, 0.6492943747434765, 0.500288576586172, 0.4615734633989632, 0.18172183481510729, 0.09902848265483044, 0.28038276883307844, 0.23564085247926414, 0.17702821089187637, 0.13962212746264413, 0.3398138063494116, 0.20538202224997804, 0.18413559591863304, 0.2576150733511895, 0.21844285656698048, 0.16099880071124062, 0.30880266102030873, 0.3839015937410295, 0.3366006928263232, 0.30157669563777745, 0.2005958228255622, 0.086323129653465, 0.17850495118182153, 0.2338485955260694, 0.2725696755805984, 0.1488169067306444, 0.1591883462970145, 0.1382919168099761], [0.043338388932170346, 0.01671445330430288, 0.020250768429832533, 0.09884946179226972, 0.06460586257162504, 0.023313775163842365, 0.09625673177652061, 0.1265260559739545, 0.06386455352185294, 0.03316828660899773, 0.0551272118173074, 0.10810304142069072, 0.05136968844453804, 0.09635749316657893, 0.09560293678077869, 0.06999247430940159, 0.060393476887838915, 0.05118673048855271, 0.03858210548060015, 0.12979769526282325, 0.0579745281720534, 0.05929392573307268, 0.024588406377006322, 0.17798595246858895, 0.26112543186172843, 0.2369328573695384, 0.17633172014029697, 0.24676782806636766, 0.4048682452412322, 0.1077998369873967, 0.1552896070643328, 0.054843162215547636, 6.862915763631463, 36.281270161271095, 64.32468876242638, 58.39504994452, 54.74148899316788, 43.795458152890205, 45.30464977025986, 34.315365850925446, 20.79986348748207, 20.887610279023647, 29.11673180758953, 29.523070603609085, 42.52677083015442, 52.93910890817642, 36.64778329432011, 19.869302920997143, 4.4586484506726265, 1.0340176150202751, 0.06055562502297107, 0.038050282455515116, 0.0806114794977475, 0.10122100953594781, 0.11461467482149601, 0.558315203525126, 1.0736117279157043, 2.329051299020648, 2.4156348779797554, 5.173197258263826, 5.223751645535231, 6.056151604279876, 8.255617506802082, 4.601452862843871, 7.446313658729196, 5.64312469214201, 6.670718276873231, 11.489634420722723, 6.575411790981889, 6.1571126617491245, 3.8860897114500403, 7.779197171330452, 10.996819864958525, 5.8059716038405895, 7.5968235824257135, 10.2969990670681, 2.9024709295481443, 7.834055777639151, 2.0530212856829166, 6.3144090212881565, 2.1527718706056476, 1.0713088139891624, 1.390983760356903, 5.5810697469860315, 30.026813372969627, 57.425847351551056, 54.28415313363075, 56.32376208901405, 54.123695343732834, 59.86105687916279, 62.6322215795517, 43.30907665193081, 12.285590060055256, 5.952492691576481, 3.312869807705283, 2.2433148371055722, 4.531300077214837, 4.085005950182676, 4.080845648422837, 2.5592778576537967, 2.326592830941081, 0.9153887524735183, 2.7306405873969197, 0.6468924880027771, 1.1937123583629727, 0.752498380606994, 1.2570483097806573, 2.665320667438209, 1.0232708416879177, 0.8586777455639094, 3.6111861001700163, 1.0913768433965743, 1.0222192481160164, 1.9688273034989834, 1.2533023045398295, 0.6727704650256783, 0.47431682178284973, 0.09869115427136421, 0.03436954539211001, 0.059840576868737116, 0.0493284261028748, 0.032641443394823, 0.15438492904650047, 2.710074665956199, 9.653993770480156, 31.54452033340931, 36.30044773221016, 81.42747223377228, 109.19710412621498, 50.62684938311577, 32.965408489108086, 24.868039190769196, 27.8329136967659, 29.49676651507616, 31.61153543740511, 50.47154791653156, 56.68811693787575, 52.557301595807076, 56.654895320534706, 45.97496420145035, 9.780488982796669, 0.39541978505440056, 0.06470408581662923, 0.0761055076145567, 0.11573351439437829, 0.06719436976709403, 0.13270934839965776, 0.19525169162079692, 0.17964192142244428, 0.3696792240953073, 0.2631297055631876, 0.1733125446480699, 0.027646166126942262, 0.01792240254872013, 0.07531842289608903, 0.018518334145483095, 0.018870527746912558, 0.03994891514594201, 0.04168453880993184, 0.18550319597125053, 0.18498473160434514, 0.2368331720936112, 0.05679692534613423, 0.011959562307310989, 0.08694254094734788, 0.11327460102620535, 0.07450065779266879, 0.06921133419382386, 0.00838327789097093, 0.012056892192049418, 0.0444191451970255, 0.044609383621718735, 0.08845347940223292, 0.08723010090761818, 0.060309577092994004, 0.01975122697331244, 0.03198737009370234, 0.03685631527332589, 0.03137902051093988, 0.06716318472172134, 0.03397860797122121, 0.02618009049911052, 0.032929122098721564, 0.08431837355601601, 0.0381946524430532, 0.06341819622321054, 0.06040804524673149, 0.14480043319053948, 0.01911550327349687, 0.2020207018358633, 0.13663854537298903, 0.06584173141163774, 0.0739684933796525, 0.07462765410309657, 0.06423550861654803, 0.06718475153320469, 0.06028807707480155, 0.07933080720249563, 0.18261076445924118, 0.05531796232389752, 0.14447224064497277, 0.24138868233421817, 0.024662153591634706, 0.24772200733423233, 0.3926546615548432, 0.24480937456246465, 0.11402661926695146, 0.09979373338865116, 8.003874365240335, 48.291635289788246, 75.45458033680916, 70.76155856251717, 62.985587418079376, 56.49880729615688, 57.297193855047226, 42.48238541185856, 31.38629872351885, 26.527362652122974, 31.710757613182068, 26.161852665245533, 34.00618404150009, 47.08660215139389, 35.24918854236603, 19.248486533761024, 4.54909167252481, 0.8250508562196046, 0.194951121811755, 0.20159126550424844, 0.43700923619326204, 0.14944776194170117, 0.8221847412642092, 1.6612000856548548, 2.3242813674733043, 2.8235365776345134, 4.932386605069041, 7.1784997545182705, 7.566286521032453, 10.319369416683912, 9.073958694934845, 9.952615946531296, 9.353514444082975, 6.489535449072719, 9.863619022071362, 19.6426659822464, 14.3202630802989, 7.0091024693101645, 6.885288013145328, 9.912674389779568, 8.459943942725658, 5.382992075756192, 5.532647520303726, 5.869379276409745, 4.546355819329619, 4.292718954384327, 2.2038494423031807, 1.297224028967321, 2.064819415099919, 2.7167777437716722, 3.3206456154584885, 6.716253608465195, 36.84873931109905, 68.76499369740486, 64.7847680747509, 62.86173686385155, 64.180988073349, 70.28928950428963, 72.38023370504379, 47.63209708034992, 13.987333495169878, 4.992366386577487, 2.8433064417913556, 0.6570379436016083, 4.5614980068057775, 3.087178305722773, 2.3664443800225854, 1.1851030890829861, 1.1076575447805226, 1.0250154230743647, 2.4054958345368505, 1.228655877057463, 1.3495674077421427, 1.9451703666709363, 2.14177003595978, 3.6706576589494944, 2.5555424205958843, 1.2956264521926641, 4.567635152488947, 4.0992233622819185, 4.243569541722536, 3.551302026025951, 4.324235888198018, 2.7876624651253223, 1.172363560181111, 0.36911246075760573, 0.1966034690849483, 0.1367958658374846, 0.09829187882132828, 0.02240858320874395, 0.11088628074503504, 1.8912129057571292, 9.576150197535753, 29.234867468476295, 34.90530699491501, 72.17412516474724, 97.46799990534782, 42.719751074910164, 33.58338072896004, 27.930066883563995, 34.38382677733898, 40.6381543725729, 36.996004208922386, 58.26627865433693, 65.79488307237625, 63.746857568621635, 67.36904740333557, 56.71797953546047, 15.686295479536057, 0.6502369022928178, 0.1066408769111149, 0.0215783370367717, 0.1091733667999506, 0.06186448037624359, 0.0888072611996904, 0.1346422274946235, 0.047360294993268326, 0.11258634811383672, 0.13758349232375622, 0.26058589050080627, 0.02183104388677748, 0.056592192777316086, 0.016506785541423596, 0.026693543513829354, 0.01902880372654181, 0.07685594508075155, 0.02562201214459492, 0.10455633993842639, 0.08562475384678692, 0.06105829648731742, 0.10646838694810867, 0.0397403234092053, 0.04357731595518999, 0.06665718843578361, 0.11549837974598631, 0.0469608191633597, 0.022571718400286045, 0.012213834161229897, 0.06989124536630698, 0.02178417911636643, 0.005591198196270852, 0.05005327802791726, 0.041223520383937284, 0.024529116199119017, 0.15465333417523652, 0.15818576415767893, 0.07513851145631634, 0.2774768747622147, 0.2029239252442494, 0.09554723117616959, 0.17664774146396667, 0.15563872817438096, 0.24246080371085554, 0.1467565563507378, 0.2107175742276013, 0.42392211500555277, 0.13919750024797395, 0.2499358932254836, 0.2843241667142138, 0.1983454084256664, 0.2313430604408495, 0.17749674356309697, 0.15386946295620874, 0.18760831269901246, 0.16407362243626267, 0.18377794011030346, 0.3285516262985766, 0.29529744351748377, 0.41457808983977884, 0.47903937462251633, 0.25255457614548504, 0.47854091855697334, 0.7154332101345062, 0.39239986741449684, 0.3421915287617594, 0.41951078921556473, 11.307818926870823, 57.864845395088196, 87.0191153883934, 81.39549314975739, 75.48863410949707, 61.60108990967274, 61.94652937352657, 48.31769049167633, 32.110332772135735, 31.91197581589222, 41.6134138405323, 41.39264948666096, 55.426060259342194, 69.97196853160858, 49.08784456551075, 27.080662362277508, 6.722388379275799, 1.6793226194567978, 0.5231059959623963, 0.40209825325291604, 0.39754066499881446, 0.21123991260537878, 0.49664774851407856, 1.8751682667061687, 2.9278198443353176, 5.818376513198018, 6.7378530744463205, 14.31748827919364, 15.116448607295752, 17.404160499572754, 18.1601033359766, 14.822977054864168, 16.440106630325317, 17.27924220263958, 17.174937799572945, 23.87728415429592, 17.972577698528767, 14.362351521849632, 14.150886218994856, 19.692135527729988, 24.786932542920113, 14.755810908973217, 18.78155428916216, 21.724220886826515, 12.671830784529448, 17.829990349709988, 10.705416351556778, 16.375960372388363, 6.069724950939417, 5.0311304815113544, 3.9188206801190972, 7.789652785286307, 40.82043819129467, 67.69989565014839, 67.59021073579788, 64.55395326018333, 63.69397200644016, 67.82230228185654, 71.71434983611107, 51.35816194117069, 16.30342986434698, 13.910125438123941, 10.765286888927221, 11.468469556421041, 11.52391903102398, 9.903298392891884, 12.410711646080017, 10.764939207583666, 5.845197848975658, 5.741355121135712, 6.197105040773749, 2.9820301104336977, 3.1582145439460874, 3.6396943079307675, 5.039422111585736, 8.279722463339567, 5.7671229634433985, 4.667902272194624, 9.406025726348162, 6.945812115445733, 6.022336268797517, 7.439837856218219, 4.776955470442772, 3.4434277145192027, 1.2075058557093143, 0.2668632724089548, 0.15000740066170692, 0.14661773020634428, 0.20472323260037228, 0.1085212935868185, 0.4535636119544506, 3.796589314006269, 14.154406730085611, 43.604324609041214, 48.765979036688805, 91.54566809535027, 109.28145959973335, 65.03407269716263, 49.8810938000679, 36.60904437303543, 40.3563766926527, 42.59365104138851, 44.52825263142586, 69.31181475520134, 75.73852390050888, 74.90527421236038, 80.3624501824379, 68.96819919347763, 18.213125690817833, 1.2135825608856976, 0.2921940787928179, 0.1414706392097287, 0.21606903785141185, 0.3368107503047213, 0.2552753785857931, 0.4654521349584684, 0.3517060697777197, 0.46063705114647746, 0.47094943060074, 0.43685433513019234, 0.14129336981568485, 0.13580356986494735, 0.1309201936237514, 0.17048396752215922, 0.1797632477246225, 0.20093660219572484, 0.16760226746555418, 0.49862652202136815, 0.410019492264837, 0.326213208027184, 0.13633096968987957, 0.10436681026476435, 0.20389076555147767, 0.2500031911768019, 0.3697101568104699, 0.43426150863524526, 0.19715072878170758, 0.18239009426906705, 0.19906509871361777, 0.20203462452627718, 0.12681610212894157, 0.2175198178156279, 0.11552494863281026, 0.09399030182976276], [0.07643899909453467, 0.037137730250833556, 0.07932343025458977, 0.03521027625538409, 0.024616776827315334, 0.03193084441591054, 0.03581104851036798, 0.06440612094593234, 0.07661329989787191, 0.049201797155546956, 0.004931031862724922, 0.02800340447720373, 0.06805879369494505, 0.09787325558136217, 0.14721373416250572, 0.00649561970931245, 0.016978032617771532, 0.14274269517045468, 0.034907209119410254, 0.07758977328194305, 0.015762441107654013, 0.012136634104535915, 0.036147809150861576, 0.10152785791433416, 0.09374039102112874, 0.23519551934441552, 0.11391760519472882, 0.28876885946374387, 0.1801460178103298, 0.13155176129657775, 1.232568717096001, 5.534737883135676, 33.84212784469128, 65.44746771454811, 59.88222174346447, 51.73099033534527, 52.09247253835201, 34.54023398458958, 39.61190924048424, 35.21320827305317, 15.217824317514896, 28.825334943830967, 28.181206807494164, 45.989616215229034, 53.78341220319271, 33.161975741386414, 11.449000351130962, 1.574450028128922, 0.10420197926578112, 0.038016577818780206, 0.01412464642271516, 0.0919160881312564, 0.16442344116512686, 0.19486457254970446, 1.182270459830761, 1.7255657818168402, 1.66750572854653, 3.530680532567203, 1.999247521162033, 4.738628352060914, 7.234887778759003, 5.230349041521549, 4.915116056799889, 8.76919224858284, 8.358999509364367, 3.0581792118027806, 7.848492152988911, 19.88758184015751, 10.24334404617548, 2.863204786553979, 4.6156978234648705, 3.881862675771117, 4.248542999848723, 4.4986864272505045, 5.681386739015579, 4.7612998355180025, 3.826642851345241, 3.6340991081669927, 5.31135119497776, 7.324476996436715, 13.370287455618382, 17.062011659145355, 26.918863244354725, 35.82889683544636, 36.79577015340328, 42.225367203354836, 41.798965483903885, 53.69917072355747, 49.810789972543716, 48.633354753255844, 45.46055540442467, 58.86180929839611, 25.288974903523922, 18.699144311249256, 13.679552860558033, 11.25554133206606, 8.201768696308136, 6.089353272691369, 6.277277888730168, 6.0454418789595366, 5.510169826447964, 11.743329707533121, 11.967134848237038, 4.524906445294619, 6.7198030930012465, 5.5901560094207525, 8.52676810696721, 8.658742625266314, 4.626368600875139, 3.167165438644588, 1.9683826086111367, 2.0452910754829645, 4.11193510517478, 0.9645135258324444, 1.0636458126828074, 1.6165252891369164, 1.3246490573510528, 0.9924022480845451, 0.8726516738533974, 0.16804316255729645, 0.051571044241427444, 0.04061858096974902, 0.07347748847678304, 0.015610979899065569, 0.9703940071631223, 10.066980309784412, 23.731193393468857, 52.286976501345634, 64.68690812587738, 66.85313388705254, 59.22497481107712, 40.12401536107063, 22.632394954562187, 14.227719996124506, 22.990501038730145, 30.249534621834755, 44.205592945218086, 54.95904631912708, 59.24527332186699, 65.36783158779144, 42.36092872917652, 3.6588953901082277, 0.11978601178270765, 0.010934251895378111, 0.0637521552562248, 0.14896023028995842, 0.09307072148658335, 0.17413364199455827, 0.08679722101078369, 0.1745669820229523, 0.2090371589292772, 0.06079689352191053, 0.10255885688820854, 0.10562391937128268, 0.016905511802178808, 0.026220993968308903, 0.0141299490678648, 0.017464412085246295, 0.0306376632215688, 0.10297890505171381, 0.10517398492083885, 0.06452753630583175, 0.01310591607762035, 0.0835030575399287, 0.17793370527215302, 0.05998790431476664, 0.03187733185768593, 0.05757856270065531, 0.04118058343010489, 0.04405587875226047, 0.026491308271943126, 0.048683321656426415, 0.056239735713461414, 0.047339006487163715, 0.025746958272065967, 0.07491895448765717, 0.03160533473419491, 0.027507072809385136, 0.04057079408084974, 0.009017609136208193, 0.02999953125254251, 0.01980603272386361, 0.05196797450480517, 0.04029685995192267, 0.07118119450751692, 0.03146338043734431, 0.06063069697120227, 0.04056729856529273, 0.09853631258010864, 0.12086634131264873, 0.056648250902071595, 0.021920632243563887, 0.06580869099707343, 0.0513749873789493, 0.02287125476868823, 0.1583578236750327, 0.055233004968613386, 0.07356734029599465, 0.05254516130662523, 0.050138791993958876, 0.14805892162257805, 0.21000065957196057, 0.0961157311394345, 0.13053479633526877, 0.10069574709632434, 0.07821961917215958, 1.042290364857763, 6.898490879684687, 48.35301339626312, 75.81399545073509, 72.52356201410294, 58.76077651977539, 60.56545168161392, 40.137652829289436, 47.02805869281292, 37.66192987561226, 22.2207972407341, 36.289029344916344, 25.5901600420475, 34.15914103388786, 44.42291468381882, 31.646318770945072, 10.50375547260046, 1.800589074846357, 0.05050774328992702, 0.03871458255161997, 0.03902755364833865, 0.3212962718680501, 0.617478919448331, 0.9217797126621008, 2.2091729566454887, 4.011439997702837, 3.073267489671707, 6.043648375198245, 6.0626711044460535, 7.009476749226451, 7.6017409935593605, 9.579120688140392, 8.30443063750863, 7.685699388384819, 8.253747057169676, 6.747488882392645, 7.388025736436248, 12.18304781243205, 12.996993586421013, 4.565559038892388, 6.91297760233283, 5.661227395758033, 6.45247271284461, 4.639357253909111, 3.4534126287326217, 4.015188496559858, 2.535552168264985, 2.869523847475648, 4.640117213129997, 9.035335667431355, 13.37525948882103, 17.466528452932835, 30.657556727528572, 41.776292100548744, 44.70179691910744, 50.58313652873039, 48.02074782550335, 58.63168224692345, 56.09024941921234, 57.0560359954834, 54.61943954229355, 64.37449648976326, 30.88799726217985, 22.04805091023445, 16.134546026587486, 12.98917455598712, 8.950794003903866, 6.194895934313536, 6.246312875300646, 6.4138121623545885, 7.474178513512015, 13.10000415891409, 13.386717773973942, 6.419885661453009, 7.706241086125374, 6.501055955886841, 6.876902338117361, 8.358357343822718, 5.2756331115961075, 6.379186995327473, 4.941874220967293, 4.4442301243543625, 5.340044880285859, 3.595470618456602, 3.0034065758809447, 4.452380212023854, 3.0207690317183733, 1.9159390102140605, 1.128701171837747, 0.36830182769335806, 0.04464868034119718, 0.1188183699559886, 0.06071978437830694, 0.056417357627651654, 0.6580864498391747, 9.319748505949974, 24.788004085421562, 56.171116679906845, 75.03702834248543, 69.4442680478096, 54.13055397570133, 31.58969420939684, 30.600664280354977, 22.1358584985137, 27.57989477366209, 42.19401128590107, 49.40184071660042, 62.748738527297974, 68.46128359436989, 76.09428361058235, 52.41012789309025, 7.218376714736223, 0.13447310688206926, 0.020594861489371397, 0.07085025601554662, 0.0632613581547048, 0.016238998250628356, 0.10311896316125058, 0.1287519052857533, 0.03644401513156481, 0.04845963092520833, 0.0922322875703685, 0.09461662993999198, 0.05533174400625285, 0.1567281861207448, 0.024312425775860902, 0.12343757873168215, 0.042784579782164656, 0.035892220912501216, 0.029400976163742598, 0.033595693166716956, 0.0683187457616441, 0.07271973343449645, 0.04121397636481561, 0.07811916206264868, 0.12234469206305221, 0.043551344497245736, 0.030886750246281736, 0.062269396148622036, 0.040055966237559915, 0.0632698780100327, 0.07480926506104879, 0.013619230867334409, 0.08297788415802643, 0.06440010212827474, 0.022913538632565178, 0.26351767068263143, 0.1361879429896362, 0.16967835137620568, 0.10218127441476099, 0.16276352398563176, 0.114340993022779, 0.15821745386347175, 0.1822070509660989, 0.2193727676058188, 0.13838674844009802, 0.16497801843797788, 0.09240752347977832, 0.1578024003538303, 0.247476460353937, 0.16448509879410267, 0.1162068264966365, 0.14522897894494236, 0.3175172855844721, 0.09723002134705894, 0.2690926246577874, 0.1989851100370288, 0.18277184019098058, 0.14531698281643912, 0.22370444610714912, 0.2685497881611809, 0.4028256767196581, 0.19932775961933658, 0.6823904206976295, 0.40541033959016204, 0.3350684844190255, 1.3704168889671564, 12.049645520746708, 59.65035058557987, 89.97446000576019, 80.68276539444923, 68.69803369045258, 67.5441800057888, 50.15679180622101, 51.06203243136406, 46.04036629199982, 23.161336071789265, 39.74133409559727, 40.677657052874565, 60.98018802702427, 69.35782268643379, 45.10661959648132, 16.452471166849136, 2.7430523838847876, 0.3791166114388034, 0.10681688465410843, 0.12764052429702133, 0.4038236278574914, 0.3998832096112892, 0.893572341883555, 2.661760258488357, 5.305767394602299, 6.7877705208957195, 11.996120642870665, 10.329216588288546, 12.681965790688992, 18.569128587841988, 14.793158154934645, 14.646592419594526, 23.176911436021328, 18.341000229120255, 13.349647913128138, 17.707034647464752, 37.06723898649216, 22.15769972652197, 10.237992983311415, 15.048595648258924, 11.014738753437996, 14.476538244634867, 14.048149231821299, 11.613803207874298, 12.160723060369492, 9.690430015325546, 11.20780449360609, 11.03840958327055, 11.408410929143429, 19.277446679770947, 22.580615133047104, 32.65537552535534, 43.68722856044769, 52.69477441906929, 54.04792740941048, 56.72368682920933, 63.90503168106079, 60.67450203001499, 61.99518196284771, 61.42300106585026, 70.2513599395752, 35.41378431022167, 28.11612769961357, 23.762171231210232, 18.297053687274456, 15.969955958425999, 10.049751084297895, 8.768049459904432, 8.626660946756601, 8.230117075145245, 14.658532328903675, 16.352019757032394, 7.41414126008749, 8.897225428372622, 7.4446474481374025, 13.513707909733057, 17.1883187815547, 11.601671408861876, 11.162319034337997, 7.82524025067687, 9.428754206746817, 13.208307847380638, 5.608739387243986, 5.994767798110843, 7.219421658664942, 4.7539139818400145, 2.6383509021252394, 2.270821323618293, 0.4949575220234692, 0.20821900048758835, 0.2070603595348075, 0.11168652374180965, 0.2148173761088401, 1.8512692116200924, 13.159904144704342, 33.97243805229664, 63.85449439287186, 73.23768049478531, 74.98893812298775, 71.52354687452316, 57.11566999554634, 32.551261112093925, 24.841351322829723, 35.597158670425415, 46.9479475915432, 59.933412596583366, 74.75589662790298, 78.44952642917633, 86.50042042136192, 64.04671847820282, 10.76914843171835, 0.7077985885553062, 0.24703756906092167, 0.2855821663979441, 0.2044024912174791, 0.22017483628587797, 0.3649582446087152, 0.43495001387782395, 0.2436509562539868, 0.3176534845260903, 0.3304571349872276, 0.22112775390269235, 0.21050849638413638, 0.22446246090112254, 0.18493530456908047, 0.2111351807252504, 0.1084668273688294, 0.18497585551813245, 0.2437550202012062, 0.32884311222005635, 0.1783211508882232, 0.27831078157760203, 0.20453916513361037, 0.35039834619965404, 0.30844830034766346, 0.11888335240655579, 0.15712520544184372, 0.17374852672219276, 0.10181824545725249, 0.10436552634928375, 0.15215722436551005, 0.20434616220882162, 0.22855071496451274, 0.12558833754155785, 0.09344074889668263], [0.07783399181789719, 0.025722018399392255, 0.03328035461890977, 0.030998634574643802, 0.019241154441260733, 0.11152452774695121, 0.024922090815380216, 0.028917760100739542, 0.02084664436551975, 0.04094721138244495, 0.08311113677336834, 0.006212965345184784, 0.045249675240484066, 0.11507806440931745, 0.004379845277071581, 0.0721747001807671, 0.08529949278454296, 0.13426866004010662, 0.011337723262840882, 0.029126309163984843, 0.027236448659095913, 0.04482986085349694, 0.022613235996686853, 0.017979928270506207, 0.07113756364560686, 0.06795328255975619, 0.08528822698281147, 0.3011063818121329, 0.3479847335256636, 0.056288576452061534, 5.4574562050402164, 41.51737779378891, 64.81187582015991, 67.87227720022202, 52.59778842329979, 38.62102881073952, 46.217432990670204, 44.51033279299736, 73.74075829982758, 78.14136296510696, 30.11019989848137, 25.068157352507114, 41.20020881295204, 47.099863439798355, 25.65558113157749, 7.213943302631378, 0.7749514351598918, 0.12050241435645148, 0.08114679803838953, 0.13848540955223143, 0.08557170513086021, 0.4276278067845851, 0.6358329439535737, 0.7613397343084216, 2.6570314122363925, 1.8771445169113576, 3.1236933963373303, 2.2575066005811095, 5.741444416344166, 4.761900678277016, 4.022930106148124, 9.310669843107462, 6.058627171441913, 7.840491682291031, 6.340253334492445, 3.084206390194595, 8.828226830810308, 16.52839869260788, 16.856942363083363, 5.01841826364398, 3.6740803252905607, 4.549521999433637, 4.354278976097703, 3.909491468220949, 4.001384312286973, 4.249130543321371, 5.457931654527783, 7.335791839286685, 12.859004940837622, 21.096836552023888, 29.846330657601357, 34.70342002809048, 58.1577754765749, 54.50161926448345, 38.1744197756052, 41.90393105149269, 41.23835116624832, 49.23333115875721, 43.00611890852451, 46.085200086236, 40.62997721135616, 40.36646515130997, 43.244400322437286, 23.73363856226206, 33.284534364938736, 38.87108959257603, 35.37233233451843, 34.337112084031105, 30.456940792500973, 34.9793916195631, 38.49697686731815, 38.88601519167423, 34.487880393862724, 32.04825550317764, 26.531960405409336, 22.946923077106476, 21.356377825140953, 20.85330381989479, 14.049640651792288, 7.611060468479991, 13.754588384181261, 6.176729584112763, 3.4595906222239137, 1.5622664568945765, 2.9155286913737655, 2.680295188911259, 1.5169846429489553, 0.5337189452257007, 1.4553760550916195, 0.3695424908073619, 0.20751391566591337, 0.026839698366529774, 0.01975842023966834, 0.014730173988937167, 0.056455585654475726, 0.1807284849928692, 2.04259037040174, 13.089747559279203, 30.615179501473904, 35.479300394654274, 59.746679216623306, 55.7724192738533, 24.328958317637444, 34.018852561712265, 24.952993132174015, 19.482014402747154, 32.81179413199425, 44.87494982779026, 55.911108031868935, 58.84941056370735, 60.39677873253822, 37.84582860767841, 5.076819704845548, 0.23382021579891443, 0.003954648464059574, 0.027411836708779447, 0.08127686684019864, 0.1256074255798012, 0.14189725538017228, 0.17978065850911662, 0.07234901582705788, 0.10140247948584147, 0.05427136711659841, 0.022720281522197183, 0.024490439172950573, 0.04482726704736706, 0.01667325668677222, 0.06986465421505272, 0.08485764032229781, 0.1564007654087618, 0.07861521356971934, 0.06312547091511078, 0.030048457338125445, 0.05287218125886284, 0.033012621133821085, 0.01928655903611798, 0.00957354825004586, 0.013873184525436955, 0.026317968549847137, 0.07514179917052388, 0.07476763799786568, 0.061323699628701434, 0.050426351954229176, 0.03544638311723247, 0.010355711601732764, 0.02833405353158014, 0.054571413711528294, 0.022505058695969637, 0.031184922918328084, 0.02666197997314157, 0.04110309950192459, 0.16260056319879368, 0.118763792415848, 0.024468556948704645, 0.0649062245793175, 0.04352008894784376, 0.036289956406108104, 0.08515747540513985, 0.04139597323955968, 0.0475137637113221, 0.04892109463980887, 0.05225000546488445, 0.04138641437748447, 0.05440700573672075, 0.06566336363903247, 0.03042673928575823, 0.02606834161269944, 0.06258388864807785, 0.05081697025161702, 0.06902881039422937, 0.03292744113423396, 0.10613751524942927, 0.0912664491625037, 0.34769342571962625, 0.2206631694571115, 0.04220850249112118, 10.297116860747337, 54.61077980697155, 76.5139938890934, 74.91645321249962, 62.41813726723194, 48.48740838468075, 54.705873504281044, 54.52993154525757, 78.07983666658401, 70.58372810482979, 20.461242757737637, 27.169171012938023, 35.813792645931244, 41.86902992427349, 23.737896233797073, 7.101489286869764, 0.7573649694677442, 0.04940998071106151, 0.0995508061896544, 0.5592685961164534, 0.4772111086640507, 1.3738961960189044, 3.60170085914433, 3.619965766556561, 4.509823629632592, 4.134047068655491, 4.455456146970391, 6.5500277280807495, 7.49917927198112, 7.19361106865108, 9.744244627654552, 7.642098153010011, 9.208112396299839, 9.089917838573456, 7.318410146981478, 5.127774970605969, 5.2324132807552814, 4.965373585000634, 7.10195523686707, 3.8212150800973177, 1.9537860481068492, 3.334551206789911, 2.9106269543990493, 5.284690400585532, 3.5530694061890244, 3.062945818528533, 4.429630832746625, 8.339592050760984, 14.136214256286621, 22.696328423917294, 32.350103706121445, 37.70021662116051, 62.716299667954445, 57.59608581662178, 45.950231328606606, 47.41871193051338, 48.648808524012566, 55.97116380929947, 52.39944666624069, 53.292125165462494, 47.55877621471882, 46.64710633456707, 47.94902667403221, 28.522236607968807, 37.191465720534325, 43.34846913814545, 37.79269985854626, 38.42461355030537, 33.753022626042366, 37.47296221554279, 40.587016716599464, 44.55617733299732, 37.443430200219154, 33.26599895954132, 27.83551275730133, 26.35183297097683, 25.597522146999836, 23.93983069807291, 17.695563063025475, 10.936289113014936, 12.250462844967842, 5.704076746478677, 4.616630198433995, 4.291590889915824, 4.994857627898455, 4.273007987067103, 2.91569659486413, 3.3016380853950977, 3.1526734912768006, 1.1629853071644902, 1.094585177488625, 0.05302409146679565, 0.23840648063924164, 0.05398623397923075, 0.05652376676152926, 0.029786501472699456, 2.2592668561264873, 15.385984294116497, 35.922577008605, 47.58032105863094, 60.292489528656006, 47.9240658134222, 17.89100557565689, 24.93980024009943, 30.597687140107155, 25.798472464084625, 41.871298402547836, 50.95574073493481, 61.389144882559776, 68.7163183093071, 69.57739010453224, 47.44691401720047, 8.306482527405024, 0.2042593012447469, 0.04301571425457951, 0.04721989178506192, 0.1030151144368574, 0.042172003668383695, 0.05110930964292493, 0.07841336424462497, 0.018409381300443783, 0.015430125931743532, 0.04672508337534964, 0.02443970039166743, 0.040269014571094885, 0.036531005971482955, 0.07839895915822126, 0.0023966246817508363, 0.08630321783130057, 0.13712904561543837, 0.0546201468387153, 0.020241948004695587, 0.07525983033701777, 0.0297779927495867, 0.05593902860709932, 0.0369321590551408, 0.06394063850166276, 0.056967931013787165, 0.028711684244626667, 0.02394223880401114, 0.0723796219972428, 0.05393455452576745, 0.06457451425376348, 0.006668702926617698, 0.05470046577102039, 0.031605015610693954, 0.33868274360429496, 0.2021965166204609, 0.09287634558859281, 0.13969487277790904, 0.27755815477576107, 0.3918603260535747, 0.210143048025202, 0.13630009634653106, 0.11306370492093265, 0.2713921247050166, 0.13736942724790424, 0.1313068377203308, 0.11689275648677722, 0.17272069671889767, 0.16449817543616518, 0.17440531257307157, 0.14623153139837086, 0.23133865208365023, 0.11792929930379614, 0.15538169274805114, 0.16531124274479225, 0.0841713763657026, 0.13078758667688817, 0.23146426799939945, 0.20281396864447743, 0.2942755358526483, 0.26233667624183, 0.6760291464161128, 0.47061766090337187, 0.3102711634710431, 13.729708269238472, 67.55187839269638, 87.10017263889313, 83.51496621966362, 71.3888593018055, 57.26157836616039, 60.94084873795509, 57.89347305893898, 80.02763494849205, 83.28958511352539, 39.9935569614172, 36.074736043810844, 57.62518085539341, 61.47914305329323, 35.35733073949814, 10.2549372240901, 1.5933365584351122, 0.41063969023525715, 0.2582954743411392, 0.5687794857658446, 0.46955060097388923, 1.0013048141263425, 3.304351852275431, 4.254189021885395, 8.181202299892902, 6.870824564248323, 7.705446928739548, 8.689681515097618, 14.287092760205269, 13.78975074738264, 15.47070549800992, 18.50973017513752, 17.19639714807272, 17.557820454239845, 14.863280542194843, 11.201519630849361, 20.330503173172474, 28.92842721194029, 28.865848369896412, 12.78904689475894, 10.797474011778831, 15.295817032456398, 12.612270880490541, 12.561986278742552, 11.068664509803057, 10.102092325687408, 9.329780917614698, 10.606161877512932, 15.751009806990623, 25.604492872953415, 38.08423161506653, 43.698498755693436, 65.21176636219025, 59.75852318108082, 53.02516669034958, 52.266123220324516, 55.54666578769684, 61.01932592689991, 56.41504839062691, 59.57975037395954, 53.25946591794491, 54.51853595674038, 53.78961727023125, 34.73287984728813, 39.89535503089428, 42.653053253889084, 40.054300501942635, 39.35790807008743, 34.276596531271935, 39.16419826447964, 45.22272236645222, 46.25500537455082, 39.17327217757702, 36.936696991324425, 33.802321180701256, 34.48015920817852, 29.84983216971159, 26.35196216404438, 19.622855745255947, 14.338146820664406, 19.789856784045696, 14.013458993285894, 10.485933478921652, 7.818072410300374, 9.983516838401556, 8.183606620877981, 6.1840722151100636, 5.351013466715813, 4.346591513603926, 1.665792257990688, 0.9135325520765036, 0.12044795555993915, 0.1844547491054982, 0.18357214255956933, 0.15010493370937183, 0.2823363390052691, 3.094836794771254, 20.233313888311386, 42.432319298386574, 48.352956399321556, 71.17948293685913, 68.13149929046631, 34.46946278214455, 48.701553493738174, 39.14544627070427, 31.530143804848194, 47.80042804777622, 61.35176628828049, 75.88052228093147, 79.60945218801498, 80.71782231330872, 57.442661449313164, 11.527998112142086, 0.5055362137500197, 0.19581520435167477, 0.1600037291063927, 0.32553372730035335, 0.22285026381723583, 0.2753557276446372, 0.35950250923633575, 0.240788062219508, 0.21627214882755652, 0.17316095356363803, 0.13952447567135096, 0.15481105539947748, 0.1919925500988029, 0.1260102039668709, 0.18063819530652836, 0.2003800359671004, 0.32816704537253827, 0.2563637826824561, 0.18090263736667112, 0.1407390003441833, 0.15356022486230358, 0.24925736244767904, 0.15746295684948564, 0.16242654441157356, 0.19347794383065775, 0.1515798780019395, 0.1321265843580477, 0.10791561202495359, 0.14406851230887696, 0.2282742946408689, 0.14646578289102763, 0.13020985439652577, 0.10293744126101956], [0.07541053826571442, 0.05004685473977588, 0.008411203052673955, 0.0869516545208171, 0.0036901066778227687, 0.0293128906560014, 0.09820272462093271, 0.0766225544793997, 0.019674355316965375, 0.025883758353302255, 0.041133449631161056, 0.03349680198880378, 0.05197537371714134, 0.0520294057787396, 0.058031321023008786, 0.15137609909288585, 0.2537998999468982, 0.017787372489692643, 0.05224596076004673, 0.03594028610677924, 0.04476840731513221, 0.023349971561401617, 0.13268145848996937, 0.03633367261500098, 0.06328201954602264, 0.0878690009994898, 0.11753984246752225, 0.18405207461910322, 0.15607042063493282, 6.131650228053331, 41.75951600074768, 60.53778536617756, 61.258336901664734, 55.312020778656006, 40.7675526291132, 42.2679553180933, 37.606247663497925, 20.51315937191248, 26.56920600682497, 31.379409693181515, 36.64891563355923, 42.12575174868107, 43.69266226887703, 21.403671987354755, 4.907522639259696, 0.23749111569486558, 0.07498997802031226, 0.05394298532337416, 0.0959001669252757, 0.27929855044931173, 0.447896869154647, 1.269447400700301, 1.9723438960500062, 2.68621479626745, 2.08688554354012, 4.879557089880109, 2.3794389702379704, 5.624144235625863, 6.221468858420849, 3.6128862714394927, 4.895592704415321, 7.7176423743367195, 8.6047931201756, 4.182823151350021, 4.687836477532983, 5.522485440596938, 3.3223543362692, 9.172521606087685, 13.392998836934566, 8.826570119708776, 7.231983784586191, 9.102262426167727, 8.90726638957858, 9.444948937743902, 9.059914648532867, 13.73503178358078, 21.936756782233715, 36.40706241130829, 40.59851869940758, 55.140995755791664, 39.617130160331726, 43.00435580313206, 59.43842075765133, 58.364993557333946, 50.53604185581207, 37.90823645889759, 45.75943596661091, 38.65513198077679, 43.027808144688606, 39.16894420981407, 41.225963830947876, 41.182315573096275, 53.74256059527397, 31.08267981559038, 51.924494951963425, 63.25194172561169, 61.58074200153351, 56.84187948703766, 56.36948503553867, 52.5652127712965, 56.07122004032135, 62.512588798999786, 56.073385924100876, 49.0764831751585, 52.61645682156086, 46.261073648929596, 45.626321509480476, 40.774187073111534, 32.47349828481674, 32.19596117734909, 31.048517748713493, 14.95816620066762, 9.138292092829943, 5.934300217777491, 4.088748749345541, 2.428882154636085, 2.164733628742397, 2.844941304065287, 1.7430095770396292, 0.9122275002300739, 0.39256257587112486, 0.23052485747030005, 0.20009353727800772, 0.13956327515188605, 0.08118220590404235, 0.06436402632971294, 0.15016117366030812, 1.0667610517702997, 16.58304926007986, 30.744724050164223, 35.926103219389915, 60.52527263760567, 85.95602363348007, 72.09770366549492, 36.56585969030857, 32.90320962667465, 17.56358664482832, 29.47972632944584, 39.88026604056358, 54.00069214403629, 54.85397815704346, 62.69374407827854, 45.42872451245785, 6.803626595064998, 0.2373168445774354, 0.01971879697521217, 0.02469914594257716, 0.07554024341516197, 0.15402494289446622, 0.12194757626275532, 0.058572216803440824, 0.08606855815742165, 0.03863781108520925, 0.08431222857325338, 0.03218642894353252, 0.02946174136013724, 0.10056924802483991, 0.01332552221356309, 0.07649302744539455, 0.11071497821831144, 0.06674111049505882, 0.06531109582283534, 0.04220950067974627, 0.029621249304909725, 0.045042181882308796, 0.012236300826771185, 0.0037757809013783117, 0.04059675811731722, 0.04445582955668215, 0.05071256491646636, 0.022948820333112963, 0.0690414417476859, 0.020484016167756636, 0.04483982418605592, 0.03793472264078446, 0.13310544745763764, 0.031860856179264374, 0.06709343026159331, 0.04163857389357872, 0.06394015610567294, 0.11665290177916177, 0.022074577791499905, 0.07047616905765608, 0.030349581902555656, 0.00530355242517544, 0.017531721168779768, 0.03767474459891673, 0.03236191347241402, 0.07285484884050675, 0.014171077964419965, 0.03707894473336637, 0.07728480253717862, 0.1478228296036832, 0.08089557362836786, 0.06496749629150145, 0.05934413202339783, 0.01068831992597552, 0.04729568732727785, 0.10156552190892398, 0.06548297722474672, 0.11380339608876966, 0.008731162397452863, 0.05961868213489652, 0.09594377552275546, 0.09302720936830156, 9.480553977191448, 53.463055193424225, 70.42199358344078, 69.44305211305618, 64.76354241371155, 49.800918102264404, 49.00636933743954, 51.25087469816208, 33.06734561920166, 39.90974485874176, 50.00353462994099, 38.67342419922352, 32.297871708869934, 38.224835470318794, 20.830284655094147, 4.68024923466146, 0.2233194198925048, 0.0050611322058102814, 0.08741062832996249, 0.0842815036594402, 0.5856767040677369, 1.586851968895644, 4.204436866566539, 4.892354803159833, 4.941382147371769, 5.72856405749917, 5.118694882839918, 5.120683126151562, 7.721803151071072, 7.102147126570344, 8.388280738145113, 8.91969932243228, 8.36504403501749, 9.934504218399525, 6.6334080789238214, 6.042245300486684, 5.20017771050334, 5.6752462685108185, 6.640530796721578, 9.018001947551966, 7.215714482590556, 5.752536021173, 7.726898202672601, 7.975448090583086, 9.154844004660845, 9.756975844502449, 13.786809705197811, 22.798890620470047, 37.76089556515217, 43.81438493728638, 58.30243371427059, 43.73164817690849, 46.42001911997795, 61.752363592386246, 60.295061990618706, 55.94809524714947, 43.54271091520786, 51.21065005660057, 43.65280240774155, 48.6025346070528, 46.950508654117584, 47.80981734395027, 47.334428653120995, 55.53697630763054, 34.89228889346123, 54.47384275496006, 62.28666432201862, 62.48334176838398, 57.40584522485733, 56.83146044611931, 54.80930395424366, 60.092859640717506, 64.21672135591507, 58.961747735738754, 55.2814856171608, 56.83633178472519, 52.114237770438194, 48.15932258963585, 42.4981127679348, 35.361358523368835, 30.79805798828602, 27.8825219348073, 16.729005128145218, 9.887176807969809, 6.0681090876460075, 4.287474760785699, 2.743557281792164, 3.0835801362991333, 2.8492645220831037, 4.484662804752588, 1.7560918000526726, 2.3220938723534346, 1.175197376869619, 0.4757073987275362, 0.2295883116312325, 0.018732564349193126, 0.02516383428883273, 0.09475543381995521, 1.064571300521493, 12.4585472792387, 25.114385671913624, 41.08193635940552, 61.82049013674259, 70.85721462965012, 68.34759369492531, 35.75763925909996, 35.08243829011917, 24.878182746469975, 36.083517372608185, 51.70765578746796, 58.972991332411766, 65.22535443305969, 71.65789246559143, 54.80205774307251, 9.01930432766676, 0.22204576089279726, 0.08099101381958462, 0.05467234950629063, 0.05753796351200435, 0.2341960690682754, 0.1213969397940673, 0.0414113505394198, 0.050821471377275884, 0.01164566723673488, 0.06695320887956768, 0.04983599574188702, 0.028476924380811397, 0.056555445335106924, 0.027267437035334297, 0.08150826106430031, 0.0612847554293694, 0.0561715508956695, 0.07107533456292003, 0.06352721029543318, 0.056096486368915066, 0.03622636177169625, 0.0409123193094274, 0.007778263798172702, 0.011671686006593518, 0.026413054365548305, 0.04225015552947298, 0.008159319986589253, 0.03861154276819434, 0.03180932515533641, 0.04563182563288137, 0.05067364669230301, 0.09705481512355618, 0.13878263969672844, 0.16934843704802915, 0.13286046450957656, 0.13810517761157826, 0.14048861456103623, 0.13138948328560218, 0.17225833871634677, 0.17522860667668283, 0.13922546437243, 0.13525954593205824, 0.1441290567163378, 0.1224650684162043, 0.16197656543226913, 0.11323609098326415, 0.1847900217399001, 0.18730351264821365, 0.39066341996658593, 0.15204769821139053, 0.21001021843403578, 0.15998747607227415, 0.10373719444032758, 0.23172958579380065, 0.3456860053120181, 0.14654645434347913, 0.21809000987559557, 0.20702754176454619, 0.23162078694440424, 0.3042407089378685, 0.27737125230487436, 14.003779962658882, 69.93726119399071, 83.40911149978638, 77.39135921001434, 76.6757208108902, 57.855402901768684, 58.41731674969196, 52.11227707564831, 30.11182051151991, 34.95661184191704, 40.186195224523544, 47.76071637868881, 57.39349588751793, 57.88504131138325, 29.096429497003555, 7.640426242724061, 0.5564564501401037, 0.1565083026071079, 0.14550510240951553, 0.21195301262196153, 0.3886424034135416, 1.3670959859155118, 6.19904151186347, 6.608762601390481, 9.320534113794565, 8.286677040159702, 10.500017423182726, 6.447597099468112, 15.020093377679586, 15.621645748615265, 10.617649611085653, 11.280917320400476, 17.436688654124737, 22.372369207441807, 14.627900272607803, 13.768889866769314, 15.483592506498098, 10.395989455282688, 14.922534562647343, 20.406048819422722, 14.917589128017426, 11.164216082543135, 12.86989325657487, 12.233382761478424, 13.193530440330505, 13.431471772491932, 16.72041568905115, 24.152737073600292, 39.66952174901962, 43.78545708954334, 64.00542989373207, 48.71390663087368, 50.18707238137722, 66.88837319612503, 61.32024697959423, 61.344835460186005, 49.66910697519779, 58.64815056324005, 50.053509548306465, 54.23403762280941, 51.911974623799324, 54.98869612812996, 51.499962732195854, 60.66466435790062, 38.568633422255516, 57.298102006316185, 64.52120661735535, 62.186482697725296, 59.154929369688034, 57.5730324536562, 55.205189511179924, 60.32923735678196, 62.92229801416397, 62.54283897578716, 61.33956894278526, 60.94389997422695, 51.04046858847141, 48.30991990864277, 45.298551097512245, 35.46017602086067, 34.829242676496506, 36.05210825800896, 17.72073481231928, 13.68019787594676, 10.677075572311878, 9.559792075306177, 7.570697134360671, 7.629617722705007, 8.459146935492754, 7.531605307012796, 3.54511643294245, 3.026233850978315, 0.800860048038885, 0.33498729346320033, 0.3310850216075778, 0.245892524253577, 0.1656889810692519, 0.4746490070829168, 1.9787555770017207, 23.990873359143734, 42.36505910754204, 47.50762715935707, 71.01404741406441, 93.05684700608253, 88.04743140935898, 50.99490903317928, 43.755583092570305, 29.645011760294437, 42.89079129695892, 58.93951512873173, 72.06513181328773, 74.79839354753494, 81.53249099850655, 64.88657981157303, 11.132789868861437, 0.5188528366852552, 0.1439594166004099, 0.19789633486652747, 0.2438431279733777, 0.3860913746757433, 0.2740896830800921, 0.34665388462599367, 0.239233648753725, 0.10745712803327478, 0.18015550245763734, 0.16422077547758818, 0.09323775666416623, 0.18883125332649797, 0.16871725529199466, 0.3302314627217129, 0.2473000666941516, 0.13310776295838878, 0.1108184558688663, 0.11460757988970727, 0.1863185639376752, 0.1476696354802698, 0.22368056379491463, 0.047198209940688685, 0.11807722417870536, 0.14758250734303147, 0.16506594809470698, 0.12130514354794286, 0.10126196124474518, 0.11155032480019145, 0.09878600816591643, 0.10149898094823584, 0.2876671263948083], [0.04383123065053951, 0.03509357353323139, 0.059608718802337535, 0.006844508434369345, 0.02671992129762657, 0.04186767117062118, 0.013474006482283585, 0.06651310788583942, 0.005741740997109446, 0.04024838286568411, 0.010303748276783153, 0.04392626266053412, 0.007829761889297515, 0.04061293322592974, 0.12008386533125304, 0.015227314597723307, 0.13415018358500674, 0.144116529263556, 0.019499197333061602, 0.05563075901591219, 0.03232866154576186, 0.07946748854010366, 0.072391882276861, 0.03310513355245348, 0.008726921951165423, 0.0882270056172274, 0.08562742557842284, 0.08410950351390056, 4.612148813903332, 33.8886259496212, 70.76537355780602, 69.41678792238235, 61.588413789868355, 45.0902196764946, 44.9287473410368, 44.39225412905216, 19.04936771839857, 20.49235548824072, 18.882632665336132, 10.440644659101963, 21.646743044257164, 42.195911183953285, 21.135013103485107, 4.4685279205441475, 0.11476452928036451, 0.0281476445888984, 0.06881997003802098, 0.13247650698758662, 0.15245448419591412, 1.0109833697788417, 1.0461777937598526, 2.9317583329975605, 6.786641031503677, 4.899857025593519, 5.8176488522440195, 4.050694266334176, 5.376914301887155, 6.481231469660997, 5.648837685585022, 5.490894410759211, 7.983743995428085, 6.218362050130963, 8.890381045639515, 8.14447347074747, 13.365508262068033, 10.76697874814272, 19.551174491643906, 21.8719569593668, 25.73861427605152, 32.4949861317873, 35.21969832479954, 44.86252449452877, 42.4943433701992, 49.72276769578457, 42.13056989014149, 44.019140750169754, 53.25215891003609, 59.144666120409966, 53.39099206030369, 54.98934969305992, 55.248693376779556, 53.962097615003586, 52.23756395280361, 58.288743048906326, 56.275519877672195, 37.273051142692566, 41.94656856358051, 36.97882153093815, 40.73536075651646, 34.96608853340149, 34.620299488306046, 62.625549137592316, 62.93258026242256, 55.18234133720398, 64.7533817589283, 62.59634010493755, 60.060941353440285, 55.1160728931427, 54.99785743653774, 56.81645505130291, 68.30940574407578, 59.554405733942986, 57.84485086798668, 64.52268093824387, 67.18381494283676, 65.58278605341911, 63.20510543882847, 62.471057027578354, 61.71408824622631, 51.32579147815704, 45.885942578315735, 33.145762011408806, 27.0922327414155, 23.96919172257185, 13.449601549655199, 5.704350331798196, 2.063956861384213, 1.8452097242698073, 3.237632419914007, 2.302031423896551, 1.9835718185640872, 0.8451847883407027, 1.023604036308825, 0.14261841512052342, 0.12130233080824837, 0.04050203409860842, 0.05654927808791399, 0.08419354431680404, 0.21886828530114144, 16.051324792206287, 30.588886812329292, 28.86558998376131, 42.0745836943388, 47.89230331778526, 49.52558107674122, 46.82502418756485, 28.166019022464752, 16.815355494618416, 30.25978647172451, 39.34732183814049, 50.731453970074654, 57.982650473713875, 52.75847800076008, 26.606563702225685, 3.626127135939896, 0.18740034807706252, 0.11824403671198525, 0.014458738114626613, 0.09143597795628011, 0.01918425397889223, 0.1439867276349105, 0.012650708667933941, 0.03380389898666181, 0.04106090469576884, 0.01154776682597003, 0.056706090181251056, 0.06603542453376576, 0.04777147820277605, 0.08211486288928427, 0.07639006187673658, 0.07682223673327826, 0.015691890694142785, 0.03942090304917656, 0.027786699210992083, 0.011638016621873248, 0.07196002654382028, 0.05342822798411362, 0.005304200412865612, 0.021809037352795713, 0.03568676103895996, 0.010446745291119441, 0.01045024451741483, 0.04850304656429216, 0.006040044008841505, 0.01083230121366796, 0.03587071718357038, 0.04422305493790191, 0.0265015833065263, 0.03049970167921856, 0.03131581921479665, 0.04107951404876076, 0.08068430644925684, 0.04583645430102479, 0.03730790471308865, 0.055446372425649315, 0.03621957112045493, 0.02233549650554778, 0.02574701949924929, 0.02347159657801967, 0.04601484062732197, 0.06979524114285596, 0.053700807693530805, 0.08828715668641962, 0.04447676554264035, 0.06202380463946611, 0.07242202831548639, 0.022828892979305238, 0.027070625037595164, 0.08176868810551241, 0.05650627063005231, 0.06926390793523751, 0.09331884371931665, 0.03970120851590764, 0.12205463106511161, 6.208870159462094, 42.58960045874119, 78.316670358181, 75.66214799880981, 69.93618965148926, 55.032484978437424, 52.67622761428356, 58.164041340351105, 30.318935997784138, 27.04032752662897, 26.044161580502987, 18.885568007826805, 25.28081864118576, 38.22681896388531, 22.946761585772038, 4.3663309793919325, 0.0815693027107045, 0.0381370209652232, 0.10715229829656892, 0.4418429033830762, 0.7550099270883948, 2.382336789742112, 2.452196991071105, 4.643381712958217, 8.19083858281374, 9.080277755856514, 8.043596483767033, 5.9903158619999886, 5.957118943333626, 11.187933459877968, 7.555858455598354, 8.790967930108309, 6.910512009635568, 6.9732456933707, 7.493495726957917, 9.388683456927538, 14.500348716974258, 11.767970435321331, 20.43246690183878, 24.121242463588715, 27.400538697838783, 32.408825755119324, 38.27015183866024, 45.0830190628767, 45.023605450987816, 48.55895094573498, 42.56504997611046, 42.94441781938076, 53.63859437406063, 59.84650366008282, 54.68917340040207, 57.19604708254337, 60.65653279423714, 56.626640036702156, 57.59105488657951, 59.4654107093811, 60.21906606853008, 42.74211287498474, 46.95614755153656, 41.84218816459179, 47.22134672105312, 41.59571439027786, 43.382872492074966, 61.75903603434563, 62.550848945975304, 56.736564338207245, 66.2596133351326, 61.99789501726627, 58.48703920841217, 56.831509843468666, 56.87163569033146, 58.03694576025009, 69.63482022285461, 59.49621185660362, 62.94358067214489, 66.31393522024155, 66.56461536884308, 66.47327587008476, 66.06485098600388, 64.53267440199852, 61.601747274398804, 54.70919832587242, 48.46372425556183, 35.43124057352543, 27.55153499543667, 21.95651952177286, 13.12551124021411, 6.440123375505209, 3.4546914976090193, 1.3978843088261783, 2.786517539061606, 3.0102469213306904, 3.299041874706745, 2.408100119791925, 1.822592387907207, 1.0042113019153476, 0.24570560693973675, 0.04708020846010186, 0.018499897341826, 0.1203158829594031, 0.2601865556789562, 11.925621125847101, 28.696208372712135, 38.704772517085075, 50.008831545710564, 49.78301726281643, 49.40361522138119, 46.320369467139244, 31.70130182057619, 24.827244579792023, 39.29311774671078, 45.84397383034229, 59.27396558225155, 65.52306085824966, 63.616395369172096, 36.37852594256401, 5.14307152479887, 0.28421913797501475, 0.14548788458341733, 0.08749938919208944, 0.06009470307617448, 0.07221257197670639, 0.04783375181432348, 0.015542090968665434, 0.030775077430007514, 0.051548931951401755, 0.03547254382283427, 0.025580809960956685, 0.07528657733928412, 0.03532348717271816, 0.0445120546646649, 0.09749833741807379, 0.07825695662177168, 0.003664522296276118, 0.06303157439106144, 0.011343595506332349, 0.026940459756588098, 0.03799498503212817, 0.0447506143245846, 0.008225654073612532, 0.050760110607370734, 0.07122232433175668, 0.07465464601409622, 0.045081278221914545, 0.05668009274813812, 0.009432290644326713, 0.014220967914297944, 0.03801105252932757, 0.13658708485309035, 0.16244086786173284, 0.16358591266907752, 0.1416565917315893, 0.11251200718106702, 0.1693255640566349, 0.11986430836259387, 0.13168129575205967, 0.11351323119015433, 0.2285301426309161, 0.13296164892381057, 0.1359508268069476, 0.14550343999871984, 0.08895407285308465, 0.23176574322860688, 0.13867962959920987, 0.2019359337282367, 0.31221989484038204, 0.18395365099422634, 0.16199284815229475, 0.17047969275154173, 0.20538055279757828, 0.15541595028480515, 0.2921257121488452, 0.10344745998736471, 0.2288024959852919, 0.30047517037019134, 0.22339366434607655, 8.513975143432617, 54.75965581834316, 89.26033392548561, 83.5570527613163, 80.79210832715034, 61.33996032178402, 59.20645460486412, 57.40878626704216, 28.773230239748955, 29.578682519495487, 29.0371697768569, 18.090827353298664, 31.394817866384983, 57.67861358821392, 30.201075822114944, 6.962121790274978, 0.3022965491982177, 0.19892593118129298, 0.25160881283227354, 0.4953068064060062, 0.46412784664426, 2.8899040538817644, 3.603449477814138, 8.299107123166323, 14.926314409822226, 12.172110099345446, 12.411094475537539, 9.958131350576878, 12.68136827275157, 15.03161245957017, 15.008418504148722, 14.589557480067015, 16.27189915627241, 15.90981563553214, 16.5321034938097, 16.42809357494116, 21.92322190850973, 14.794204998761415, 23.295848853886127, 25.826849341392517, 30.588989406824112, 37.488982155919075, 42.085736095905304, 50.06202109158039, 44.861285760998726, 52.01801933348179, 45.088331177830696, 47.36978955566883, 53.89708690345287, 61.4117194712162, 55.25644116103649, 61.36655509471893, 64.50099930167198, 61.55519217252731, 63.00835199654102, 60.5801796913147, 61.96928255259991, 47.39495560526848, 52.619223073124886, 48.201690316200256, 52.653326243162155, 45.83224005997181, 49.7734759747982, 64.98374059796333, 64.25487890839577, 57.2985427826643, 67.65904024243355, 61.390148028731346, 59.009777158498764, 56.39087788760662, 56.60656191408634, 57.67920635640621, 66.69218212366104, 61.93500079214573, 67.13635548949242, 67.16603189706802, 64.62919682264328, 68.36704105138779, 68.77484276890755, 67.73151755332947, 65.47770649194717, 54.70896653831005, 51.74866318702698, 38.78989174962044, 34.62756469845772, 29.201383665204048, 19.510174691677094, 11.44120316952467, 7.698284313082695, 7.460564319044352, 8.455625474452972, 7.0864648930728436, 10.4680734872818, 4.253453286364675, 2.7852085093036294, 0.6057829689234495, 0.23581991787068546, 0.08054269725107588, 0.19651230366434902, 0.29183873848523945, 0.6554787803906947, 19.540120884776115, 44.003740176558495, 42.71004259586334, 50.35704866051674, 55.98334975540638, 59.92705173790455, 59.08453054726124, 43.26659493148327, 30.521050952374935, 44.83473278582096, 55.9561850130558, 68.963373452425, 78.39552372694016, 73.91068518161774, 46.55223682522774, 6.89586142078042, 0.4392209550132975, 0.3139530768385157, 0.17039612692315131, 0.2061345599940978, 0.2203390735667199, 0.22615771915297955, 0.08274047111626714, 0.0916830611822661, 0.1386888322304003, 0.09071133012184873, 0.14806586812483147, 0.3226080921012908, 0.10163885352085344, 0.13821455533616245, 0.18161486164899543, 0.18076879845466465, 0.10940352163743228, 0.2204977595829405, 0.1612353973905556, 0.241655187564902, 0.20341179828392342, 0.12896135420305654, 0.2133946938556619, 0.1677150442264974, 0.1434012918616645, 0.15376112423837185, 0.15130010317079723, 0.13682414166396484, 0.10601244852296077, 0.11966144971665926, 0.1341206015786156], [0.015817642051842995, 0.061456555195036344, 0.024360732168133836, 0.03851205787213985, 0.024911914115364198, 0.015564063178317156, 0.06257465633098036, 0.023107931228878442, 0.07013906331849284, 0.05892911933187861, 0.03223674284527078, 0.008072304099187022, 0.03222777770133689, 0.0252806538992445, 0.022003257399774157, 0.018618290305312257, 0.03801995459070895, 0.029766485749860294, 0.031387952258228324, 0.03229527974326629, 0.0940829589671921, 0.03364323885762133, 0.07369008410023525, 0.12222879086039029, 0.014809231270191958, 0.02212108447565697, 0.07561449529021047, 1.1549492133781314, 15.894943233579397, 60.20747669041157, 66.98263093829155, 63.18519830703735, 47.63898991048336, 48.91871564090252, 36.580363512039185, 13.595824353396893, 22.48095978051424, 31.461000815033913, 38.25090207159519, 41.72590300440788, 48.63236680626869, 29.254844896495342, 3.9651228580623865, 0.040121423662640154, 0.041698847417137586, 0.08073724384303205, 0.4091693175723776, 0.27787502214778215, 0.7719653891399503, 1.9478176371194422, 3.033743198029697, 3.5126505000516772, 4.182769004255533, 3.9842270454391837, 4.546200027689338, 3.175549926236272, 4.619334228336811, 7.399572841823101, 5.242673205211759, 11.232121288776398, 12.135637756437063, 7.957602823153138, 10.902343634516, 12.941765449941158, 23.430580124258995, 28.381602354347706, 38.928584307432175, 44.3311458081007, 49.11114491522312, 52.57684774696827, 61.78200580179691, 61.283677741885185, 63.00587832927704, 57.814946472644806, 55.73330037295818, 54.92948390543461, 58.20990867912769, 57.38389380276203, 58.70508670806885, 57.04597033560276, 63.74293237924576, 56.750817373394966, 59.57215458154678, 61.05230435729027, 60.425531789660454, 41.93184815347195, 33.76143917441368, 34.43554200232029, 39.581499472260475, 26.270044259727, 47.57168412208557, 54.221008121967316, 63.48812185227871, 69.63685691356659, 65.39299383759499, 60.7827278226614, 59.67945322394371, 57.533157393336296, 59.286945685744286, 62.000630870461464, 62.570376098155975, 58.7505778670311, 64.81897383928299, 60.23953936994076, 63.10360908508301, 65.00743612647057, 63.08785133063793, 63.73629413545132, 63.71234022080898, 64.28674399852753, 58.08275990188122, 57.36661992967129, 44.79428015649319, 34.09905485808849, 25.65359763801098, 16.41416922211647, 11.483662091195583, 2.7769218664616346, 2.8582897502928972, 1.6234581358730793, 3.853607391938567, 2.0218501333147287, 1.2880649766884744, 0.174517955747433, 0.265677617280744, 0.03027290505997371, 0.0635893725848291, 0.07722327107330784, 0.05400547415774781, 0.2682360081234947, 10.064630135893822, 31.372161582112312, 37.988400757312775, 33.51607494056225, 24.662019945681095, 36.16974234580994, 45.896722599864006, 25.70866998285055, 19.65476643294096, 35.261465683579445, 46.65547728538513, 61.61334045231342, 61.16859331727028, 59.20173905789852, 28.090840056538582, 2.597676459699869, 0.25703827617689967, 0.04430642038641963, 0.04393707946292125, 0.03269764994911384, 0.02544673356169369, 0.04559091103146784, 0.06628215152886696, 0.030199410175555386, 0.008163850798155181, 0.06260987123823725, 0.06274494211538695, 0.12816730071790516, 0.030809012132522184, 0.0678462054929696, 0.02113911363267107, 0.02777959314698819, 0.03533726143359672, 0.008435709696641425, 0.00953300936089363, 0.05654120723193046, 0.06146848521893844, 0.044212082284502685, 0.044602566995308734, 0.05864225699042436, 0.017658218384895008, 0.029941270804556552, 0.06440098528400995, 0.04826240518013947, 0.028191245764901396, 0.018668461343622766, 0.02892262487875996, 0.02902464235376101, 0.050259424388059415, 0.04158072348218411, 0.018886203761212528, 0.03744687186554074, 0.10943456567474641, 0.0734219684090931, 0.03635000728536397, 0.02990275705087697, 0.06451592169469222, 0.006622595146836829, 0.007441905772793689, 0.033422798733226955, 0.06832689454313368, 0.04661356455471832, 0.024095642584143206, 0.07475888065528125, 0.025624396294006146, 0.016401860702899285, 0.055472915337304585, 0.027642637214739807, 0.05632373569824267, 0.051029907263000496, 0.04861418688960839, 0.03810325695667416, 0.05648024351103231, 1.428878651931882, 20.34747876226902, 70.86450263857841, 76.92969918251038, 71.42947152256966, 57.09101691842079, 57.98293545842171, 51.96891836822033, 28.081357665359974, 27.326150089502335, 27.807785645127296, 29.603307098150253, 36.076229363679886, 42.05085776746273, 23.22613399475813, 3.8571590138599277, 0.12997066020034254, 0.06375642260536551, 0.4133768496103585, 0.6328667281195521, 1.2661130796186626, 1.3664047792553902, 3.9121335139498115, 5.159244406968355, 5.349595192819834, 7.162011014297605, 9.97048543766141, 7.616567797958851, 7.225381638854742, 6.573756029829383, 7.550154961645603, 8.286637142300606, 10.800838731229305, 10.51355229690671, 9.285530392080545, 12.57478304207325, 16.77852027118206, 24.487293921411037, 31.132018268108368, 39.71019856631756, 48.25502425432205, 51.643967404961586, 56.95814184844494, 64.00204047560692, 65.9845232963562, 64.38003659248352, 61.76256984472275, 60.52889384329319, 58.298337534070015, 59.97749783098698, 60.59929646551609, 60.68438529968262, 58.915416821837425, 65.69340571761131, 61.03498488664627, 60.63071697950363, 61.104490756988525, 59.85113941133022, 44.792220667004585, 40.96997156739235, 40.95643289387226, 44.298459962010384, 34.426756873726845, 49.54756669700146, 54.48518894612789, 61.58622890710831, 69.83168005943298, 64.77778404951096, 60.59761315584183, 59.62717182934284, 56.679350808262825, 58.89602646231651, 61.2198905646801, 62.51250900328159, 61.450500190258026, 66.61696895956993, 62.54286177456379, 64.0341791510582, 68.22932124137878, 65.53302392363548, 67.39203616976738, 66.5078616142273, 64.87052947282791, 59.40586790442467, 59.25426743924618, 46.91756062209606, 35.7110271602869, 26.11385554075241, 16.79865349084139, 11.83470530435443, 4.445978980511427, 2.918216809630394, 2.357927612029016, 4.754558997228742, 3.888039719313383, 1.6781368455849588, 2.2597335185855627, 1.5049829869531095, 0.24328751169377938, 0.13116168847773224, 0.19152168708387762, 0.04162533026828896, 0.2289225161075592, 8.712373897433281, 26.11672818660736, 35.23895189166069, 31.462703123688698, 24.96333047747612, 31.787616088986397, 49.4848320633173, 32.03500561416149, 28.665715008974075, 42.33965367078781, 53.31181950867176, 68.76968264579773, 70.17721071839333, 72.85383269190788, 37.00168490409851, 3.3101090183481574, 0.23828899866202846, 0.09219215964549221, 0.07044413054245524, 0.010691794104786823, 0.037730153344455175, 0.06417594384402037, 0.08742278470890597, 0.02306410184246488, 0.04017133680463303, 0.033092580124503, 0.00761280382903351, 0.049601302671362646, 0.05017718329327181, 0.05153152116690762, 0.05447173956781626, 0.051760373535216786, 0.059318657804396935, 0.02387776657997165, 0.05858048803929705, 0.057409839137108065, 0.010233246102870908, 0.02427359104331117, 0.10862669339985587, 0.0053412628039950505, 0.012718442631012294, 0.015489894794882275, 0.02351951705350075, 0.03225405715056695, 0.06926271307747811, 0.006574991011802922, 0.13759711815509945, 0.2164364603231661, 0.21589647367363796, 0.21287164301611483, 0.10539138966123573, 0.15448617283254862, 0.18693583784624934, 0.17695589602226391, 0.2475166105432436, 0.12577559624332935, 0.209453726420179, 0.09430253820028156, 0.14045814197743312, 0.11249575414694846, 0.11378613373381086, 0.12602477974724025, 0.1160355239699129, 0.2635262202238664, 0.11494994745589793, 0.12270148698007688, 0.19551985926227644, 0.11354613801813684, 0.3215748444199562, 0.21643113170284778, 0.19817039516055956, 0.12257360751391388, 0.213299416936934, 1.9630037597380579, 28.159741759300232, 82.66995996236801, 85.91965198516846, 82.10182204842567, 64.20893177390099, 65.70103570818901, 47.872152999043465, 24.302487038075924, 32.07984700798988, 40.76053820550442, 50.4925911873579, 54.79410856962204, 62.49174311757088, 39.78948891162872, 6.324328863993287, 0.4569955402985215, 0.2307409411878325, 0.4609470907598734, 0.8618777676019818, 1.5847848798148334, 1.3510427973233163, 6.561894491314888, 9.67101400718093, 10.927242748439312, 9.156698305159807, 12.319376897066832, 13.271651398390532, 10.70453004911542, 11.993291694670916, 13.390553668141365, 14.68748202547431, 23.0003672093153, 22.163749001920223, 14.695115815848112, 17.89574772119522, 19.030957706272602, 29.79568887501955, 36.464427933096886, 43.12087655067444, 51.543740183115005, 54.7114098072052, 57.016271129250526, 64.5302577316761, 66.26479625701904, 68.15118223428726, 60.87996080517769, 59.59169693291187, 56.97835296392441, 61.064976677298546, 60.79505056142807, 62.052467688918114, 60.70151098072529, 65.24097919464111, 61.16121791303158, 61.736944019794464, 60.46985641121864, 61.217074915766716, 48.075274899601936, 45.517054572701454, 44.384228959679604, 48.670391365885735, 40.64811363816261, 54.74200576543808, 58.454919531941414, 65.70588424801826, 66.75361722707748, 64.06443312764168, 64.07498136162758, 60.88488534092903, 56.73931919038296, 59.343026876449585, 59.23240341246128, 62.22495183348656, 60.2370885014534, 64.22339379787445, 60.20463824272156, 69.34557974338531, 71.1105926334858, 69.88948255777359, 69.78026881814003, 68.62028986215591, 70.33598899841309, 64.86366704106331, 62.806708216667175, 48.82756233215332, 38.72469484806061, 30.558771528303623, 20.039203204214573, 17.792134881019592, 6.553505016490817, 8.278530277311802, 5.310807824134827, 9.82474995777011, 8.781909216195345, 3.6413605185225606, 2.6544895861297846, 1.1032573808915913, 0.1665826901444234, 0.23511901876190677, 0.269214129075408, 0.2769076474942267, 0.7531663135159761, 14.897510055452585, 42.268095910549164, 55.277693420648575, 48.564472049474716, 35.57242579758167, 47.01805002987385, 58.25608380138874, 37.9530930519104, 32.32941761612892, 48.3832635730505, 62.73125946521759, 79.64912965893745, 77.34602764248848, 80.10325849056244, 46.034260019659996, 4.704294819384813, 0.5036956875119358, 0.2164182925480418, 0.12718882353510708, 0.16448888374725357, 0.10125242464710027, 0.17474132735515013, 0.16937962209340185, 0.1963532911031507, 0.08430984627921134, 0.154565894335974, 0.12580600945511833, 0.2469957119319588, 0.20677163440268487, 0.12108995040762238, 0.3424404747784138, 0.16672064055455849, 0.22374685242539272, 0.08474212503642775, 0.3133290493860841, 0.2190681011416018, 0.10893577564274892, 0.10642399909556843, 0.15986105863703415, 0.14170082373311743, 0.0928459175338503, 0.12212126108352095, 0.16605442942818627, 0.19494096923153847, 0.12014035761239938, 0.11060610515414737], [0.038978716620476916, 0.05661978211719543, 0.04794276588654611, 0.04850912846450228, 0.05498241138411686, 0.15746745426440611, 0.030039004232094157, 0.0570293400232913, 0.045262228668434545, 0.04567756419419311, 0.0350956960755866, 0.05565599574765656, 0.01953093713382259, 0.012910934401588747, 0.07414591120323166, 0.028400485025485978, 0.010279188754793722, 0.058559537210385315, 0.05882992016267963, 0.01799424058845034, 0.03634611101006158, 0.07493546727346256, 0.03049865525099449, 0.0374824912432814, 0.02019441715674475, 0.11912547066458501, 0.25414924370124936, 7.477998258545995, 39.57950837910175, 75.78453943133354, 68.19182485342026, 56.788762137293816, 45.47150261700153, 30.901969112455845, 14.4018978998065, 21.450846455991268, 35.7033933699131, 48.920881524682045, 40.66531151533127, 47.480215430259705, 35.06286934018135, 8.76119652763009, 0.19499950984027237, 0.10936728998785838, 0.029092357763147447, 0.1457855451735668, 0.22099965921370313, 0.8253314474131912, 1.6788761434145272, 2.7240258548408747, 1.8403599970042706, 2.850313503295183, 7.082385336980224, 10.65276162698865, 6.062510088086128, 8.260694984346628, 10.216684676706791, 14.999292343854904, 12.081509660929441, 16.518602818250656, 20.19659075886011, 19.04857736080885, 26.6196957975626, 42.266784980893135, 44.18223939836025, 47.878601253032684, 54.51078437268734, 54.89198751747608, 63.153291419148445, 63.79994451999664, 62.30766199529171, 62.673844546079636, 58.89503851532936, 57.29297608137131, 59.532769694924355, 60.68742513656616, 61.69276379048824, 62.94237233698368, 64.04986470937729, 61.3420008122921, 57.232699915766716, 59.972360506653786, 61.18114784359932, 62.4173317104578, 66.17525786161423, 61.31848767399788, 35.42799174785614, 31.451647616922855, 29.924108684062958, 33.871754854917526, 57.106250301003456, 53.31173211336136, 58.18646013736725, 55.42262524366379, 64.81781110167503, 62.51211002469063, 64.61886897683144, 60.67756086587906, 60.33334493637085, 57.078036814928055, 59.43575710058212, 60.4091926664114, 57.401612251996994, 60.32560475170612, 71.13187149167061, 63.236263766884804, 61.75525143742561, 59.910207241773605, 60.006608068943024, 57.96828344464302, 62.953961715102196, 63.015814796090126, 62.63949818909168, 50.80504082143307, 47.14430585503578, 38.680085241794586, 34.45800259709358, 18.77880323678255, 11.342406570911407, 3.6718358332291245, 0.764372565317899, 1.8596046580933034, 2.1482199523597956, 3.1083481572568417, 2.22775443457067, 0.18059470545267686, 0.0682603164750617, 0.019403686637815554, 0.030655986847705208, 0.04520111651800107, 0.35924575582612306, 7.192245991900563, 28.285174928605556, 47.85570368170738, 47.9413852840662, 41.50693215429783, 39.823842868208885, 32.190956845879555, 20.170982033014297, 20.30642956495285, 33.77454087138176, 47.98366941511631, 52.0966637134552, 59.42674398422241, 56.653307005763054, 30.16642738133669, 1.9756294135004282, 0.1265857691760175, 0.04552244790829718, 0.058016196053358726, 0.027080360159743577, 0.0022130173465484404, 0.011834698743768968, 0.0597810454928549, 0.022547229382325895, 0.040335767043870874, 0.046449887595372275, 0.057593027158873156, 0.11171294419909827, 0.06243229756364599, 0.13926938467193395, 0.06044836984074209, 0.06765997095499188, 0.032420539428130724, 0.030945767684897874, 0.09496863800450228, 0.07239951897645369, 0.11019946017768234, 0.06610144599108025, 0.035103240006719716, 0.025518321126583032, 0.012372712208161829, 0.05504176835529506, 0.030807620605628472, 0.04280668465071358, 0.06287011274253018, 0.03306223370600492, 0.053070984067744575, 0.027589098681346513, 0.03969555335061159, 0.04613935816450976, 0.07711605299846269, 0.046673285178258084, 0.01144222414950491, 0.033175771168316714, 0.018344833006267436, 0.05105886586534325, 0.01793197625374887, 0.015098988915269729, 0.026812789947143756, 0.08832818260998465, 0.02380800655373605, 0.03634879016317427, 0.05252822920738254, 0.0587280307081528, 0.020860422337136697, 0.02525385865737917, 0.0827050038788002, 0.025310323107987642, 0.054690717661287636, 0.008585204213886755, 0.07343466655584052, 0.2953780407551676, 9.702715706080198, 47.87989318370819, 85.70519149303436, 74.59625199437141, 65.68330585956573, 52.938614934682846, 43.06115135550499, 24.126089103519917, 22.754847183823586, 28.32883458584547, 40.44205829501152, 36.04403369128704, 40.26299670338631, 29.142103046178818, 6.742385756224394, 0.39309549727477133, 0.10957480189972557, 0.12827736121835187, 0.7158112898468971, 0.9464127221144736, 3.8103714119642973, 3.267007931135595, 5.025545731186867, 7.253935681656003, 8.267628662288189, 9.360231533646584, 10.697431080043316, 7.32122247107327, 8.74470541253686, 9.640197660773993, 11.953936256468296, 12.57943969219923, 13.170058149844408, 16.90946314483881, 21.53686624020338, 26.600164845585823, 39.52851891517639, 44.29462976753712, 50.178921818733215, 56.83930702507496, 59.1596183180809, 64.90953058004379, 66.03044763207436, 66.31675466895103, 67.21162185072899, 62.677952125668526, 61.344596073031425, 60.679282173514366, 59.46728400886059, 60.65939404070377, 62.174106761813164, 61.707180216908455, 60.889331102371216, 57.15978562831879, 61.2667952477932, 61.27086862921715, 62.826022580266, 66.75818458199501, 62.888267040252686, 39.54545460641384, 37.98691123723984, 35.84422901272774, 39.20548304915428, 58.952221646904945, 55.54468609392643, 59.8675811290741, 55.76604701578617, 64.44096252322197, 64.23531755805016, 65.36354541778564, 61.35187268257141, 60.834321454167366, 58.38043212890625, 59.39623922109604, 59.55282121896744, 58.324696719646454, 62.191764414310455, 72.09873721003532, 64.20181095600128, 64.06216084957123, 61.556590497493744, 62.894285917282104, 62.85444125533104, 66.01782470941544, 63.74955162405968, 61.36553294956684, 50.10853819549084, 46.3389428704977, 40.36627136170864, 34.72025692462921, 20.602439381182194, 12.871019896119833, 4.887052187696099, 2.2456918470561504, 2.590391063131392, 3.7678467063233256, 4.642995558679104, 2.3133063688874245, 0.9762233099900186, 0.3047656448325142, 0.1512935574282892, 0.017174247186630964, 0.09755439925356768, 0.34416130743920803, 6.0102153941988945, 26.095971800386906, 42.731158062815666, 41.627032309770584, 37.10904434323311, 37.93189398944378, 32.136650159955025, 22.325014248490334, 29.842899441719055, 41.98701739311218, 57.84919023513794, 57.6362344622612, 66.84086814522743, 67.97029674053192, 40.282957032322884, 2.2977027436718345, 0.1712526989285834, 0.03196315010427497, 0.07621502634719945, 0.006735907645634143, 0.06463419034844264, 0.05877000658074394, 0.052664261165773496, 0.027724401479645167, 0.05918354610912502, 0.03860317505314015, 0.0772644454264082, 0.048349744829465635, 0.03800856262387242, 0.09462735397391953, 0.025381268715136684, 0.03336662928631995, 0.058918718132190406, 0.05231357783486601, 0.03141646186122671, 0.01001363718387438, 0.06789814098738134, 0.04005168404546566, 0.01259944481716957, 0.02170804775232682, 0.04007685027318075, 0.0019075354475717177, 0.078691335656913, 0.0612679569167085, 0.05521960178157315, 0.16361117537599057, 0.14820272015640512, 0.10738502838648856, 0.09560672173392959, 0.12107411297620274, 0.25085692817810923, 0.16657152824336663, 0.17457698617363349, 0.17742067342624068, 0.07656104527995922, 0.11604244820773602, 0.17028266738634557, 0.07982968629221432, 0.09719856170704588, 0.35628408193588257, 0.21127086016349494, 0.13263439148431644, 0.2224065930931829, 0.22789119801018387, 0.14601948496419936, 0.21233327424852178, 0.1808198433718644, 0.11447771888924763, 0.18810479465173557, 0.11903601960511878, 0.23319286352489144, 0.6686685851309448, 13.789076283574104, 64.55506280064583, 95.5511623620987, 86.79686531424522, 74.72851529717445, 61.20383262634277, 43.67752768099308, 24.80744194239378, 30.155157186090946, 48.97876761853695, 65.52371442317963, 54.69586864113808, 60.20293213427067, 47.00255066156387, 12.507332861423492, 0.47291929833590984, 0.3572380088735372, 0.21520130394492298, 0.5384542036335915, 1.027799011208117, 4.247134700417519, 6.700337687507272, 7.540144398808479, 7.3794391471892595, 9.102071486413479, 14.843682143837214, 19.201621748507023, 13.49650813266635, 17.96275332570076, 15.670950952917337, 21.796673499047756, 17.454264611005783, 22.130455188453197, 25.202050767838955, 25.84491167217493, 34.26942631602287, 50.4979033023119, 51.240915432572365, 52.552061676979065, 58.45597967505455, 59.79680612683296, 67.84433349967003, 70.16427621245384, 68.46564576029778, 65.44952720403671, 66.1872348189354, 63.45968797802925, 63.01145642995834, 59.6931628882885, 60.288655534386635, 61.14715486764908, 62.940738424658775, 60.21451771259308, 57.382841259241104, 58.79091650247574, 61.278411224484444, 65.59579655528069, 70.08538484573364, 65.06247237324715, 45.12194037437439, 42.10899844765663, 40.38042940199375, 43.338118493556976, 61.05661332607269, 55.26859670877457, 61.53782330453396, 59.0965911000967, 66.03114679455757, 65.86535409092903, 68.50975379347801, 64.03889089822769, 62.385048642754555, 58.27136278152466, 57.035384103655815, 60.564494132995605, 58.107960149645805, 63.16958114504814, 72.77676522731781, 68.4648098051548, 66.6562132537365, 67.09959626197815, 67.30359971523285, 65.37604674696922, 68.40772926807404, 67.21129506826401, 65.12287393212318, 52.12081901729107, 51.379319205880165, 44.859655648469925, 38.838802725076675, 21.679577082395554, 16.562368869781494, 7.230671430006623, 4.604057148098946, 5.4219941329211, 9.181743711233139, 11.31396984681487, 6.2716475408524275, 0.6762816547416151, 0.14153005555272102, 0.16600866860244423, 0.1101053855381906, 0.4283434746321291, 0.8603489433880895, 9.80868062004447, 38.51557306945324, 62.717732191085815, 67.39254534244537, 57.59542465209961, 51.532830968499184, 46.67321853339672, 31.830749474465847, 33.105012997984886, 47.354495376348495, 67.1297362446785, 69.5901346206665, 77.11686953902245, 78.77576172351837, 48.098468855023384, 3.6433375999331474, 0.2650976140284911, 0.091737660986837, 0.16551405686186627, 0.08632199416751973, 0.12307793396757916, 0.17484191805124283, 0.18094960047164932, 0.13499856228008866, 0.1328872560407035, 0.17371495196130127, 0.14624999603256583, 0.20077472494449466, 0.18297171540325508, 0.3529315337073058, 0.10163873477722518, 0.12693774013314396, 0.1530226130853407, 0.10613902923068963, 0.15250827505951747, 0.14505889354040846, 0.1727724095690064, 0.09595973911928013, 0.12488837353885174, 0.07922381177195348, 0.11123917196528055, 0.09304509512730874, 0.14670775271952152, 0.11879272133228369, 0.10744235929450952], [0.05017465628043283, 0.04944870226609055, 0.06438223121222109, 0.11816974030807614, 0.09595656272722408, 0.038986909930827096, 0.028126960933150258, 0.0245628264019615, 0.0322366723412415, 0.04694972405559383, 0.029308894190762658, 0.04346028668805957, 0.043432188977021724, 0.036852923658443615, 0.0165750835367362, 0.042307508701924235, 0.06358395490678959, 0.043034212285419926, 0.04531520688033197, 0.046914345875848085, 0.07194495352450758, 0.04400926445669029, 0.018866084137698635, 0.017571997523191385, 0.042300439745304175, 0.030098160823399667, 4.712206944823265, 38.01567189395428, 66.64194121956825, 64.60173189640045, 52.520728558301926, 43.39138023555279, 36.32879041135311, 18.88429317623377, 22.850003577768803, 43.133704662323, 50.589356794953346, 33.28094355762005, 52.07159265875816, 43.844027146697044, 7.938159266486764, 0.042385222695884295, 0.02749228551692795, 0.04807352117495611, 0.020703684458567295, 0.7909687038045377, 0.7636421138886362, 1.4377330080606043, 2.1099624177441, 3.134447056800127, 4.95697888545692, 6.496102446690202, 5.577971488237381, 12.308981604874134, 11.13187126815319, 16.845035701990128, 25.367691479623318, 29.811366833746433, 32.26514786481857, 36.41759164631367, 32.89302237331867, 41.170935183763504, 51.14217013120651, 59.19147580862045, 62.32209362089634, 65.84432601928711, 64.03462752699852, 65.54035753011703, 61.562833562493324, 63.36931362748146, 59.139684587717056, 59.04921904206276, 61.381974667310715, 62.387047335505486, 59.40759681165218, 59.39284600317478, 59.75551374256611, 62.20173507928848, 58.52619230747223, 62.98505164682865, 61.01901434361935, 65.11395961046219, 61.819137409329414, 64.733577221632, 59.72544215619564, 65.82882285118103, 50.99019728600979, 34.410755932331085, 21.183356009423733, 46.81144371628761, 60.38691446185112, 58.55547733604908, 55.948513224720955, 58.98265801370144, 59.934484139084816, 59.157767817378044, 58.75481463968754, 61.52733586728573, 60.93383811414242, 60.382578894495964, 55.664178282022476, 57.174893617630005, 55.134881883859634, 62.94966794550419, 59.6975402534008, 58.71240891516209, 54.958567544817924, 53.46589744091034, 54.80288989841938, 59.40409719944, 58.60832870006561, 64.57054316997528, 59.7020848095417, 58.60085070133209, 54.91081930696964, 53.353997245430946, 51.5769200026989, 47.565410658717155, 41.51979826390743, 26.879862137138844, 11.607467997819185, 1.2629113951697946, 1.2536762282252312, 2.9685063986107707, 2.269985843449831, 1.2481387378647923, 0.5911954923067242, 0.21670532558346167, 0.09910779597703367, 0.0252679056575289, 0.011307193162792828, 0.055650778449489735, 2.5607559783384204, 17.138666845858097, 34.98162589967251, 47.889749854803085, 33.41905854642391, 33.65634821355343, 24.721207469701767, 12.305146660655737, 21.00843619555235, 34.39986951649189, 44.517522007226944, 57.605615705251694, 56.995482444763184, 60.69089815020561, 22.585703060030937, 0.9223469509743154, 0.0603053505619755, 0.03373220009962097, 0.052021984301973134, 0.019151913038513158, 0.06787401376641355, 0.06661783234449103, 0.05090751226816792, 0.0706415789318271, 0.04075562967045698, 0.015112667624634923, 0.04990891546185594, 0.044668117188848555, 0.015575082215946168, 0.04615464640664868, 0.024637204442115035, 0.049671647138893604, 0.008791759682935663, 0.08133189709042199, 0.08503157005179673, 0.05543875056901015, 0.01854413676483091, 0.01978037482331274, 0.06930215080501512, 0.02718646872381214, 0.044809681858168915, 0.056608486629556865, 0.029745197243755683, 0.023969464491528925, 0.030026478634681553, 0.09291265887441114, 0.041620202027843334, 0.019761884213949088, 0.07679114074562676, 0.030389344319701195, 0.03841439123789314, 0.04353814911155496, 0.02873585599445505, 0.048488819593330845, 0.01997344268602319, 0.049636246694717556, 0.007566389449493727, 0.031934072758303955, 0.053476308021345176, 0.07164854716393165, 0.020471483148867264, 0.012253346103534568, 0.031003965050331317, 0.04589927339111455, 0.06533586871228181, 0.058327326623839326, 0.04746139777125791, 0.0466665316344006, 0.03752324999368284, 0.07014748669462278, 6.2888064701110125, 46.486857533454895, 79.1439239680767, 71.49162098765373, 63.91827777028084, 50.81832490861416, 46.86815947294235, 28.531975485384464, 31.64169441908598, 39.67886924743652, 52.47059024870396, 39.91644389927387, 45.22892743349075, 36.95392906665802, 6.251631639897823, 0.01587926071806578, 0.020624269091058522, 0.10874374493141659, 0.6827501545194536, 1.9360462250187993, 1.693796874023974, 3.324776468798518, 5.910991318523884, 6.598725439980626, 10.05446758121252, 7.429840117692947, 10.03106938675046, 10.330822952091694, 10.306218322366476, 16.084310822188854, 21.944472268223763, 26.94981638342142, 25.163746923208237, 31.14854548126459, 33.35461400449276, 39.85234133899212, 49.96473491191864, 60.39399728178978, 64.9921989440918, 67.12462931871414, 66.71852990984917, 67.23242193460464, 62.921845838427544, 65.61706021428108, 63.18698801100254, 61.72563582658768, 63.46044793725014, 64.2328704893589, 61.23657926917076, 59.56737443804741, 61.06366194784641, 61.47938244044781, 58.599068596959114, 62.46938891708851, 61.82305499911308, 66.66464120149612, 63.7042960524559, 66.05390757322311, 62.46786519885063, 67.66463354229927, 54.44620683789253, 38.62005606293678, 25.405719839036465, 47.60058917105198, 60.62022194266319, 58.103047013282776, 58.1400266289711, 60.901695638895035, 61.330198645591736, 61.56532622873783, 60.82172133028507, 64.03879210352898, 62.28637933731079, 61.48678444325924, 56.72757402062416, 58.09787169098854, 56.7006828635931, 65.69144502282143, 62.96982206404209, 61.87326170504093, 59.418677017092705, 56.33312478661537, 58.32090072333813, 61.25186584889889, 63.39508764445782, 65.96391320228577, 62.53508359193802, 59.32492844760418, 56.55810311436653, 54.00895670056343, 53.62823233008385, 49.11679521203041, 43.452218770980835, 27.727545350790024, 13.066494707018137, 2.467403062619269, 2.107671140693128, 4.412639094516635, 3.804151858203113, 5.839454932138324, 2.8949283342808485, 1.157915429212153, 0.2041090905549936, 0.12360859182081185, 0.04741130651382264, 0.16621170536382124, 2.518123690970242, 16.774503886699677, 32.99430973827839, 46.933375373482704, 31.6574464738369, 32.22651153802872, 30.91154459863901, 23.212084248661995, 39.62069056928158, 51.18479624390602, 54.054751843214035, 65.87870657444, 65.11778980493546, 71.23448878526688, 31.353776268661022, 1.4191090199165046, 0.07930132909677923, 0.05876275208720472, 0.0548210833221674, 0.022792618656239938, 0.04065788882144261, 0.08425810374319553, 0.01924871321534738, 0.026869619905482978, 0.026167108480876777, 0.0724489608546719, 0.026002923150372226, 0.05614603956928477, 0.040000089938985184, 0.05602600831480231, 0.04585734204738401, 0.06808344784076326, 0.00789925288700033, 0.048933596117421985, 0.04801577095349785, 0.035384450893616304, 0.003768768533518596, 0.08261899638455361, 0.06303995323833078, 0.07543370069470257, 0.028431440005078912, 0.03991019730165135, 0.01739181148877833, 0.01821617057430558, 0.10936609513009898, 0.2065593356383033, 0.10281114999088459, 0.19150623556924984, 0.20296557457186282, 0.3294624196132645, 0.1347652162075974, 0.1237147040956188, 0.13116105023073032, 0.1828457580995746, 0.09543942680465989, 0.19406780280405656, 0.08581048372434452, 0.13084832404274493, 0.16581642266828567, 0.1581046325736679, 0.10997703109751455, 0.113429821212776, 0.130270354275126, 0.13766692456556484, 0.15783879527589306, 0.13741541071794927, 0.13658001960720867, 0.1303845559596084, 0.09854316260316409, 0.1543431609752588, 8.899137675762177, 60.10569155216217, 89.5560796558857, 80.78345999121666, 72.83684760332108, 59.96907748281956, 49.43969428539276, 31.010734476149082, 32.78040401637554, 59.19055625796318, 65.46586632728577, 45.91333530843258, 64.41169649362564, 56.07001930475235, 10.58984650298953, 0.17528426775243133, 0.07753057216177694, 0.20714641897939146, 0.7651055103633553, 2.0012569008395076, 2.8266787715256214, 4.665922103449702, 8.477672841399908, 9.613542091101408, 12.442271802574396, 13.753058966249228, 15.374600104987621, 20.23294910788536, 17.77007896453142, 20.654686577618122, 32.93552689254284, 35.65171234309673, 37.731067165732384, 42.141038328409195, 36.534830555319786, 45.29623322188854, 53.20906542241573, 65.43935894966125, 66.78717702627182, 67.44441255927086, 69.82994735240936, 69.9108374118805, 65.51123589277267, 69.05625566840172, 64.62356552481651, 64.23965692520142, 63.78996625542641, 64.41798895597458, 60.69693222641945, 61.05303771793842, 61.5087054669857, 63.40063154697418, 59.27065595984459, 63.50950710475445, 63.60777363181114, 67.86311209201813, 65.43214693665504, 68.99387821555138, 65.14716982841492, 71.32563069462776, 57.711922600865364, 44.56275478005409, 30.23187506943941, 50.38876935839653, 59.76591378450394, 60.433062985539436, 56.45188361406326, 60.96862904727459, 62.55692861974239, 66.13950178027153, 64.90448445081711, 66.08635023236275, 64.40954580903053, 62.21432000398636, 57.164345383644104, 58.51327300071716, 55.06111644208431, 65.59879839420319, 66.84059455990791, 64.84962299466133, 62.08004280924797, 59.58047993481159, 60.907372534275055, 65.43606072664261, 66.49677380919456, 67.58275553584099, 62.483740746974945, 59.36629302799702, 57.754833698272705, 53.35400864481926, 53.415367752313614, 51.499730944633484, 46.973592415452, 32.328733652830124, 18.54949314147234, 5.812506778165698, 5.97998421639204, 10.757692996412516, 10.60302134603262, 8.913654796779156, 2.2750908695161343, 0.7204517908394337, 0.17384568869601935, 0.20291601395001635, 0.16923175659030676, 0.6598721165210009, 4.871953222900629, 25.398739613592625, 46.574906408786774, 64.85811933875084, 47.21313536167145, 48.85225720703602, 37.8591088950634, 22.226229049265385, 35.1340015232563, 50.11780209839344, 61.49735927581787, 77.18588903546333, 72.32762172818184, 80.64384788274765, 40.269862934947014, 1.978795356117189, 0.16711126256268471, 0.11629026615992188, 0.1639474424882792, 0.1009698370762635, 0.11954588248045184, 0.2986293303547427, 0.11190934616024606, 0.17126813560025766, 0.13703284843359143, 0.21360066952183843, 0.09116545770666562, 0.07627377475728281, 0.10061040753498673, 0.14665400638477877, 0.1571361001697369, 0.19523920869687572, 0.13532319251680747, 0.14997547346865758, 0.1691785446018912, 0.21487869234988466, 0.10645882808603346, 0.1661572020384483, 0.0844291687826626, 0.19970800640294328, 0.14548510895110667, 0.15934164432110265, 0.08650371644762345, 0.12460934085538611], [0.02744182504102355, 0.03894433662935626, 0.025422995968256146, 0.033260520722251385, 0.021031079195381608, 0.062038799733272754, 0.02708796160732163, 0.03968465491198003, 0.029649755197169725, 0.06836860324256122, 0.003923795529772178, 0.03216331475414336, 0.035011443760595284, 0.052452429954428226, 0.030376139657164458, 0.03469039067567792, 0.0711209766450338, 0.08838152076350525, 0.025418103359697852, 0.02554051319748396, 0.03072997340495931, 0.019661569967865944, 0.03283105470472947, 0.045508302573580295, 0.09485145288635977, 0.21233465464320034, 12.963661774992943, 60.72682522237301, 66.71754196286201, 60.41984349489212, 40.250886753201485, 37.23596133291721, 18.55433028191328, 19.914547093212605, 25.353394746780396, 49.55687619745731, 26.07013888657093, 37.94479809701443, 37.029336020350456, 4.2101365607231855, 0.25857680768240243, 0.06220405004569329, 0.35550559870898724, 0.10480637691216543, 0.1344232345581986, 1.3285893271677196, 1.1319736274890602, 3.085952871479094, 1.672000887338072, 5.65390613861382, 10.115262418985367, 8.668994475156069, 15.0841180421412, 18.39447855949402, 23.449472710490227, 33.99355351924896, 39.3458741158247, 40.25765419006348, 44.665402472019196, 45.49966670572758, 46.669825315475464, 56.7908900231123, 59.77836951613426, 63.01166921854019, 59.982144981622696, 60.656506195664406, 60.78657701611519, 58.006596788764, 59.53698366880417, 57.736997455358505, 58.714354410767555, 60.395357608795166, 60.86784325540066, 60.42647413909435, 57.635295912623405, 58.24022725224495, 58.53927120566368, 58.99272747337818, 63.465437069535255, 63.381784558296204, 61.914451494812965, 61.56392030417919, 62.18924514949322, 58.998457565903664, 61.181375831365585, 59.46194909512997, 66.07785388827324, 36.765364184975624, 25.212652198970318, 60.51208734512329, 60.44296145439148, 63.70490401983261, 58.59396167099476, 59.333850368857384, 60.00880055129528, 58.12293894588947, 56.110464334487915, 57.983456030488014, 61.197669357061386, 63.13441023230553, 58.59722189605236, 57.366266548633575, 56.35945737361908, 60.29037684202194, 63.21257583796978, 57.74249956011772, 53.25592450797558, 48.235158920288086, 52.768129482865334, 54.89318445324898, 62.86803312599659, 58.00527445971966, 62.42131769657135, 59.993103593587875, 61.813479512929916, 58.84750686585903, 58.332801684737206, 68.34583818912506, 62.85296693444252, 55.06716571748257, 39.55114670097828, 18.522244803607464, 5.066715097054839, 1.5743615641258657, 0.6170553609263152, 3.3334578154608607, 2.7590773114934564, 2.000280828215182, 0.09702060953713953, 0.01189972850625054, 0.044441687932703644, 0.09220782638294622, 0.2430052135605365, 2.79979663901031, 11.679608076810837, 32.29806549847126, 52.6607396453619, 31.60426452755928, 19.51865393668413, 28.178231567144394, 10.100879240781069, 12.974784728139639, 39.41729128360748, 47.847568318247795, 52.85520561039448, 59.562620893120766, 54.98896211385727, 10.838679000735283, 0.21781197167001665, 0.16737471014494076, 0.009992551840696251, 0.02873869099857984, 0.06430957495467737, 0.06902106979396194, 0.03068061687372392, 0.07724655966740102, 0.032787694726721384, 0.05985561649140436, 0.014608524852519622, 0.033590780149097554, 0.05937901667493861, 0.06612301280256361, 0.07080749346641824, 0.021370726790337358, 0.007753613363092882, 0.025147052474494558, 0.05900786491110921, 0.037760689010610804, 0.005398185530793853, 0.07453806945704855, 0.028050864821125288, 0.05677345863659866, 0.06099800441006664, 0.026940342868329026, 0.01838660849898588, 0.025723877479322255, 0.03387895609193947, 0.011606096850300673, 0.02973276441480266, 0.03902812139131129, 0.05268412845907733, 0.022900634539837483, 0.030818144259683322, 0.0572653763811104, 0.017818934175011236, 0.016913575236685574, 0.059659785983967595, 0.027372194890631363, 0.03115448373137042, 0.01651817379752174, 0.01369081193843158, 0.02260989262140356, 0.0397131014324259, 0.02029726583714364, 0.04329139985202346, 0.04764978824823629, 0.03653242718428373, 0.02799400332150981, 0.0560798140213592, 0.05460191969177686, 0.07771829841658473, 0.1552429556613788, 18.439264856278896, 72.17710420489311, 73.29916879534721, 68.81443664431572, 49.449550956487656, 48.43228094279766, 30.496498569846153, 28.694354072213173, 24.105080030858517, 45.79738453030586, 31.120738573372364, 32.4863263964653, 34.59738291800022, 5.352776572108269, 0.13223486370407045, 0.04991192487068474, 0.45620829972904176, 0.6340225785970688, 2.264957050792873, 3.913411907851696, 3.9805448055267334, 6.364109879359603, 6.907978495582938, 6.536838635802269, 10.832675322890282, 10.391435399651527, 8.571545854210854, 14.078182820230722, 22.94910605996847, 31.456868536770344, 37.75059051811695, 39.94497276842594, 44.738248363137245, 44.906716123223305, 49.11804914474487, 57.80556097626686, 63.84833872318268, 65.11171773076057, 63.98806482553482, 62.79089346528053, 61.9896874576807, 61.28057710826397, 62.77545869350433, 59.55980144441128, 59.716820418834686, 61.83334104716778, 62.9293542355299, 62.04574204981327, 58.056028336286545, 58.59181858599186, 59.44848261773586, 58.57251562178135, 63.96025791764259, 63.961975425481796, 64.45237711071968, 62.857747077941895, 64.43706393241882, 60.669239312410355, 62.527518197894096, 60.86741767823696, 67.33246296644211, 41.123027354478836, 27.757740430533886, 60.72346620261669, 60.32033443450928, 63.336361795663834, 58.657441064715385, 60.387389436364174, 62.1286042034626, 59.836039021611214, 58.5388608276844, 60.698197558522224, 62.23668560385704, 65.4951399564743, 58.94385449588299, 57.85854533314705, 57.163976803421974, 59.73838046193123, 65.49992769956589, 59.69953894615173, 54.607466384768486, 50.90416990220547, 53.72422277927399, 58.54784734547138, 64.96243134140968, 62.345937341451645, 63.21941927075386, 60.87909825146198, 61.541748493909836, 59.08507391810417, 61.25977702438831, 69.93223026394844, 66.52717977762222, 57.285334691405296, 42.5459636002779, 21.28533113747835, 6.596731022000313, 3.9273027749732137, 4.185649249702692, 5.06699675694108, 6.770617291331291, 3.3838141383603215, 0.8153779408894479, 0.19049491093028337, 0.07991794249392115, 0.05944308628386352, 0.15909078356344253, 2.3469901364296675, 11.654726061969995, 34.41180467605591, 46.40978626906872, 30.069059506058693, 14.547555483877659, 18.77466905862093, 18.950599618256092, 24.110281951725483, 52.15621031820774, 53.9551667869091, 59.31265890598297, 65.69326892495155, 65.07058873772621, 14.987244140356779, 0.08553688356187195, 0.10094510129420087, 0.0420107275567716, 0.05408551849541254, 0.03106332016614033, 0.022873726120451465, 0.03450783719017636, 0.06104293774114922, 0.06182486453326419, 0.0570230317680398, 0.0071264336384047056, 0.027019787921744864, 0.009349545816803584, 0.017292157754127402, 0.01782079696567962, 0.04018120736873243, 0.03913215194188524, 0.021213280160736758, 0.06377593366778456, 0.037943016141070984, 0.03176361627993174, 0.05340367402823176, 0.04902479122392833, 0.06885940034408122, 0.017269390518777072, 0.034495309737394564, 0.05833057723066304, 0.03479114835499786, 0.09387451194925234, 0.17090762994484976, 0.14306428260169923, 0.1274087218916975, 0.2228180694510229, 0.21553322207182646, 0.12080855769454502, 0.1446859643328935, 0.1635423634434119, 0.1386502999230288, 0.1740401759161614, 0.11686747151543386, 0.20442683366127312, 0.06946445108042099, 0.11133563632029109, 0.18287485028849915, 0.09931039487128146, 0.08621073138783686, 0.12418159662047401, 0.12481749843573198, 0.16908446996239945, 0.08339929045177996, 0.14216862909961492, 0.149759107735008, 0.20538176991976798, 0.7602129760198295, 26.476779766380787, 80.16706466674805, 82.75585815310478, 78.87923017144203, 56.63461580872536, 52.80721418559551, 29.94550533592701, 31.299701370298862, 34.3998771160841, 63.789320290088654, 36.4135866612196, 49.65260826051235, 48.63490886986256, 7.014878634363413, 0.5560112802777439, 0.14322849019663408, 0.7840078335721046, 0.5800721829291433, 1.5888158697634935, 5.097720958292484, 5.313418284058571, 9.743549264967442, 10.142613351345062, 13.697156365960836, 20.274089500308037, 14.979869686067104, 20.73385912925005, 22.965733967721462, 28.25634017586708, 38.60529385507107, 42.97246411442757, 42.7946412563324, 48.642538860440254, 47.002372071146965, 50.47959588468075, 59.594083204865456, 63.68133008480072, 68.36972370743752, 65.97339749336243, 65.91286674141884, 64.48324665427208, 62.72139139473438, 64.71407666802406, 62.74753779172897, 63.20859745144844, 63.20764370262623, 65.39234787225723, 64.66040074825287, 59.29318495094776, 58.94044607877731, 58.50740611553192, 58.77298526465893, 65.75114741921425, 67.16148734092712, 65.54913505911827, 66.69928774237633, 66.26994118094444, 64.51548412442207, 66.25679388642311, 66.35131761431694, 70.24308398365974, 43.59318360686302, 33.68828549981117, 62.17253364622593, 62.30460315942764, 66.3486197590828, 62.57516764104366, 61.78689233958721, 63.946221470832825, 62.42829792201519, 60.26047244668007, 63.205755203962326, 65.90642988681793, 66.72991409897804, 60.876776576042175, 56.72618709504604, 57.66130551695824, 63.080882504582405, 67.59375974535942, 62.9257520288229, 57.77111202478409, 53.3545558154583, 57.54443898797035, 60.04551038146019, 68.0222399532795, 63.023129403591156, 64.60227146744728, 61.47737234830856, 62.57267877459526, 60.493198558688164, 64.08148661255836, 72.56497219204903, 70.02705797553062, 60.46033792197704, 46.82530917227268, 23.568887002766132, 10.644660461694002, 8.86592460796237, 7.927898392081261, 9.871195815503597, 11.164055541157722, 5.637449696660042, 0.24877958261640742, 0.13532605720683932, 0.1678657002048567, 0.48643710266333073, 0.41299948235973716, 4.270845903083682, 17.094887495040894, 45.07234923541546, 69.5307894051075, 46.66960492730141, 32.52443455159664, 40.79550392925739, 17.98438936471939, 21.38945695012808, 53.05282920598984, 63.672142177820206, 70.33475786447525, 74.86615151166916, 75.60478627681732, 20.601086653769016, 0.5905806377995759, 0.33840313204564154, 0.0994264445034787, 0.21344680746551603, 0.18565714708529413, 0.09565223765093833, 0.1149412346421741, 0.12148990863352083, 0.13954587921034545, 0.14019224530784413, 0.10916612343862653, 0.18219951074570417, 0.13393420376814902, 0.15312673640437424, 0.1667849550722167, 0.10284395291819237, 0.10685460802051239, 0.1364167025894858, 0.11689893115544692, 0.14818179159192368, 0.18217782519059256, 0.22097043343819678, 0.13605017069494352, 0.1494106842437759, 0.1362261042231694, 0.1426281372550875, 0.11208390671527013, 0.10235803172690794], [0.06023990426911041, 0.06526016964926384, 0.06674079879303463, 0.08124526619212702, 0.014637070635217242, 0.0549565735127544, 0.020753760873049032, 0.02707670137169771, 0.010599777069728589, 0.049201852816622704, 0.03797387835220434, 0.036028059912496246, 0.008954315999289975, 0.04537140230240766, 0.06053658151358832, 0.017234771185030695, 0.047952361856005155, 0.04709202716185246, 0.08009586497792043, 0.025629821393522434, 0.05109539066324942, 0.014418641731026582, 0.04817970395379234, 0.06324932051938958, 0.07784633373375982, 5.393014037981629, 50.4811006039381, 67.78873488306999, 65.73904886841774, 44.869877099990845, 37.08533741533756, 23.180433847010136, 22.287527360022068, 31.349397003650665, 48.445010259747505, 28.79589032381773, 43.32057863473892, 45.40858559310436, 6.317289741709828, 0.15892610099399462, 0.06749385604052804, 0.03496472185361199, 0.04782174015417695, 0.36600597901269794, 0.9802198049146682, 2.205702317878604, 1.452362579293549, 4.251746227964759, 5.678750155493617, 4.589305864647031, 13.612619452178478, 16.03321496397257, 22.518610060214996, 30.091371908783913, 36.49819292128086, 47.39883899688721, 53.01714912056923, 58.88476386666298, 60.568472519516945, 58.460896611213684, 61.25334016978741, 60.1174671202898, 67.59482368826866, 58.68724666535854, 56.71036474406719, 57.21470408141613, 57.465840205550194, 54.55198556184769, 54.66980203986168, 52.98896983265877, 55.20913749933243, 55.86860351264477, 60.935722813010216, 58.504905849695206, 58.28343093395233, 58.54945845901966, 57.934723645448685, 58.108286932110786, 61.686102747917175, 58.85081648826599, 60.93924522399902, 58.21199856698513, 60.71843147277832, 54.14374686777592, 56.287576630711555, 54.634999707341194, 65.95286339521408, 39.98786486685276, 33.16366285085678, 65.45579686760902, 57.08159722387791, 62.10574463009834, 57.82261826097965, 61.62085644900799, 59.19706530869007, 57.58124001324177, 50.84913745522499, 53.44776101410389, 57.638776525855064, 62.878824546933174, 59.265043660998344, 56.37455776333809, 54.39096160233021, 57.58877880871296, 57.63525411486626, 54.893344044685364, 48.07298742234707, 44.25659380853176, 48.3812914788723, 57.072633504867554, 59.92743171751499, 61.72649458050728, 56.18646405637264, 56.91159434616566, 57.92115457355976, 55.921226888895035, 63.238931223750114, 65.12918919324875, 61.60778895020485, 65.46234011650085, 61.81836225092411, 45.74506513774395, 24.64702595025301, 5.427602156996727, 1.947425901889801, 4.8708375077694654, 5.9374716226011515, 2.5405612494796515, 1.6437948821112514, 0.07219019622425549, 0.03183545617503114, 0.023624701643711887, 0.06941274565178901, 0.13088491192320362, 1.1072797025553882, 9.66373074799776, 31.713001392781734, 37.93447785079479, 44.87507902085781, 40.258056968450546, 32.701687440276146, 23.604183308780193, 16.749360635876656, 38.711684346199036, 51.748514994978905, 45.6163926422596, 56.248130947351456, 40.327198058366776, 3.1865826342254877, 0.16577260626945645, 0.05898421637539286, 0.024565399799030274, 0.14028995647095144, 0.033032506980816834, 0.0024274182442241, 0.06838831468485296, 0.06389246569597162, 0.04168427905824501, 0.07409373080008663, 0.057597365012043156, 0.056276787436218, 0.05275463990983553, 0.03330952844407875, 0.04378512472612783, 0.022198277110874187, 0.03082554532738868, 0.06591324476175942, 0.08140738093061373, 0.03398590699362103, 0.0693426126963459, 0.017360717356496025, 0.08706361491931602, 0.07734913189779036, 0.023224479955388233, 0.05752668286731932, 0.05308351152052637, 0.01148547651609988, 0.039820230449549854, 0.08878184264176525, 0.03964602241467219, 0.050449577465769835, 0.05433866135717835, 0.042733271402539685, 0.04006654555269051, 0.024259775964310393, 0.009755655519256834, 0.021660455677192658, 0.013073115933366353, 0.031025930766190868, 0.08261031325673684, 0.048154931064345874, 0.037731574557255954, 0.0327883775025839, 0.035115645005134866, 0.008499718078383012, 0.04639557722839527, 0.035228841079515405, 0.01654691903240746, 0.03086016466113506, 0.04148751715547405, 0.07302274490939453, 6.966312015429139, 58.31070587038994, 77.92028322815895, 74.23054441809654, 57.33317032456398, 45.784370228648186, 35.441123843193054, 30.83091102540493, 30.568274818360806, 42.809456661343575, 33.4688700735569, 35.15477500855923, 39.93114911019802, 7.6309125032275915, 0.10901707792072557, 0.09033636000822298, 0.028791325967176817, 0.08572438717237674, 1.1687342799268663, 2.1316043939441442, 3.3035028353333473, 6.238051168620586, 9.790259208530188, 10.991809833794832, 4.067430943250656, 6.728459978476167, 10.05694029852748, 21.255561634898186, 27.459931410849094, 39.75779861211777, 46.88070259988308, 53.18302921950817, 57.22955748438835, 59.46965128183365, 56.81314542889595, 60.21970443427563, 60.81958204507828, 68.00023153424263, 60.967432111501694, 60.731924548745155, 57.533738762140274, 60.226270481944084, 56.701887398958206, 57.18182064592838, 56.11183226108551, 60.364032089710236, 58.16247962415218, 63.20551961660385, 58.657517060637474, 61.498495414853096, 59.947844222187996, 58.34915220737457, 60.67214235663414, 64.77553457021713, 59.14055094122887, 63.207297921180725, 60.52355132997036, 63.68888407945633, 57.378030717372894, 57.962370961904526, 57.451100796461105, 66.28643989562988, 42.32535883784294, 36.135156601667404, 66.73798486590385, 58.555439338088036, 62.8757581114769, 57.85523571074009, 62.303755804896355, 62.39896349608898, 59.45110447704792, 53.6755245923996, 55.44487684965134, 59.58514228463173, 64.24214199185371, 59.93488311767578, 57.394529432058334, 56.38033725321293, 59.882130548357964, 61.49879179894924, 57.88171648979187, 50.67474961280823, 46.07503183186054, 52.26444751024246, 59.4034930318594, 63.236221969127655, 63.89175519347191, 57.38021560013294, 59.18175972998142, 59.61728855967522, 58.959433659911156, 67.87619099020958, 67.60242328047752, 63.7957039475441, 68.28240439295769, 64.2037108540535, 48.58234629034996, 26.058906689286232, 9.628438241779804, 5.15478297136724, 5.022719632834196, 9.055498335510492, 4.918767660856247, 4.490320226177573, 1.5813569887541234, 0.27404613385442644, 0.02531107824324863, 0.02726760216319235, 0.09733012222568505, 0.9025525662582368, 10.595113970339298, 34.211160242557526, 41.06196463108063, 43.781961277127266, 36.79800443351269, 20.57691615074873, 29.04235079884529, 31.85044001787901, 48.50745990872383, 60.79837538301945, 53.13756085932255, 64.72245141863823, 47.190142795443535, 4.288487881422043, 0.057170774816768244, 0.026090893625223543, 0.03178689374180976, 0.053281460859579965, 0.058513976764515974, 0.030172839433362242, 0.011691530107782455, 0.045439527748385444, 0.03506031789584085, 0.10687846064683981, 0.11397646492696367, 0.006851404377812287, 0.09542526662698947, 0.077616787457373, 0.030816689650237095, 0.07308531538001262, 0.057997545882244594, 0.04067216032126453, 0.08508037368301302, 0.08559568392229266, 0.03351483988808468, 0.07376991692581214, 0.042423643681104295, 0.028358139934425708, 0.06156918723718263, 0.029179940465837717, 0.04268788165063597, 0.10395467339549214, 0.13120261050062254, 0.18122308189049363, 0.12743276747642085, 0.12893119332147762, 0.20759319188073277, 0.16043276467826217, 0.14610644982894883, 0.09737757514812984, 0.16609679121756926, 0.10033032100182027, 0.08072487224126235, 0.10732345239375718, 0.28846689441706985, 0.14394313388038427, 0.09273459538235329, 0.12259602779522538, 0.07568612738396041, 0.17221284506376833, 0.1403248670976609, 0.16423837922047824, 0.08729204055271111, 0.19242293637944385, 0.1863266236614436, 0.16870103194378316, 9.923846740275621, 74.03419375419617, 85.20594388246536, 84.4320698082447, 60.41265808045864, 52.606334164738655, 36.355616971850395, 33.70826102793217, 42.79274895787239, 63.397340923547745, 39.00213696062565, 57.626807168126106, 60.5978449434042, 9.39198262989521, 0.43839675548952073, 0.2880441671004519, 0.21244051458779722, 0.14375262457178906, 0.6891838030423969, 3.515759683214128, 6.585948150604963, 8.366324566304684, 10.921717844903469, 14.106086622923613, 12.702504638582468, 21.208854541182518, 22.44845252484083, 28.02845310419798, 33.185549676418304, 41.51857852935791, 49.473732858896255, 55.2531923353672, 61.368622183799744, 60.60407280921936, 58.61904792487621, 60.52604019641876, 61.628288850188255, 70.40627002716064, 63.578655794262886, 63.53563070297241, 61.42744682729244, 63.29273633658886, 60.361512824893, 59.51534762978554, 57.09087252616882, 62.499825283885, 60.1947283744812, 63.34068976342678, 60.17859824001789, 60.594660714268684, 59.576281160116196, 60.138890370726585, 61.36261470615864, 66.54380768537521, 62.53457821905613, 67.4858683347702, 63.55326555669308, 65.79902485013008, 59.718534126877785, 61.123991310596466, 60.58959178626537, 67.56358936429024, 45.169726610183716, 39.362661615014076, 67.76151314377785, 61.266054287552834, 64.74256753921509, 59.7702569514513, 63.12632046639919, 65.17594948410988, 63.6285737156868, 56.15625187754631, 58.98509368300438, 61.14845059812069, 66.88305348157883, 60.681459456682205, 58.23492273688316, 56.75581030547619, 61.47610321640968, 65.43362885713577, 60.94245605170727, 53.72108034789562, 49.32187780737877, 54.262083917856216, 63.16470980644226, 67.02809929847717, 66.01223140954971, 58.26595947146416, 59.27527651190758, 59.97399061918259, 59.942330718040466, 69.69145238399506, 71.50174364447594, 66.83858826756477, 71.72039911150932, 68.97737190127373, 50.41006721556187, 29.23723854124546, 11.414654944092035, 8.238865155726671, 15.462405793368816, 15.148546434938908, 12.353634908795357, 7.627803320065141, 0.9147889190353453, 0.16205793450353667, 0.24047946237260476, 0.1868833531625569, 0.4202451294986531, 1.9459921913221478, 14.69938488677144, 44.86062079668045, 52.3551220446825, 63.931394666433334, 60.36535061895847, 45.28018668293953, 36.25564433634281, 28.851399645209312, 55.25489464402199, 70.05146026611328, 64.20160576701164, 73.59428375959396, 58.88630658388138, 6.766626555472612, 0.18553782458184287, 0.16337158042006195, 0.09751837540534325, 0.23245784046594054, 0.1407855181605555, 0.11480312095955014, 0.16804901068098843, 0.2063834763248451, 0.15247067785821855, 0.3270815801806748, 0.2631932927761227, 0.1477103348588571, 0.12997236713999882, 0.15606062428560108, 0.18427746486850083, 0.2633679349673912, 0.20268954016501084, 0.1267364399973303, 0.17445561534259468, 0.19528054632246494, 0.12243821751326323, 0.16695613885531202, 0.1669980405131355, 0.13772424805210903, 0.14753318420844153, 0.13746289332630113, 0.1316169070196338], [0.012414061893650796, 0.03682821014081128, 0.06794059183448553, 0.023485246529162396, 0.058940429662470706, 0.08359830477274954, 0.012357444375084015, 0.023275363455468323, 0.04280253233446274, 0.06500202842289582, 0.012174162657174747, 0.05527216439077165, 0.05958769004791975, 0.0517721217329381, 0.06056145088223275, 0.05479588740854524, 0.06475088564911857, 0.047636800663894974, 0.017736650406732224, 0.017287751252297312, 0.01712006484012818, 0.0884629343636334, 0.10052486759377643, 0.12964104273123667, 0.11267736510490067, 19.401451125741005, 66.03767484426498, 62.34193615615368, 54.099532440304756, 41.94239258766174, 31.918397471308708, 19.616137705743313, 18.441007062792778, 40.1144702732563, 29.33960884809494, 36.38482980430126, 44.58971053361893, 9.834314044564962, 0.2451184345409274, 0.005981587819405831, 0.1350886738509871, 0.07656302681425586, 0.20815599214984104, 1.2158757378347218, 3.2242918107658625, 4.290404878556728, 3.4542196104303002, 8.00856901332736, 5.614948254078627, 3.682355093769729, 17.14273262768984, 32.834224328398705, 38.00424590706825, 44.40975598990917, 57.503914162516594, 58.784833028912544, 61.94059409201145, 53.7783432751894, 58.299709260463715, 55.00808268785477, 56.7128612101078, 57.67049342393875, 60.768702775239944, 59.30757097899914, 56.48540161550045, 52.01089471578598, 52.87787899374962, 50.76695926487446, 56.93467430770397, 54.87937219440937, 60.37718318402767, 61.98981665074825, 61.749661937355995, 57.54487596452236, 58.708213940262794, 55.824636071920395, 60.20118422806263, 60.227558612823486, 60.620848909020424, 57.33527921140194, 57.263235077261925, 52.05213010311127, 55.29916226863861, 48.30448620021343, 56.57851181924343, 54.835986122488976, 65.04497051239014, 38.185287192463875, 41.378711834549904, 67.16787859797478, 54.67331305146217, 60.504939928650856, 56.91405661404133, 59.33897629380226, 57.95173533260822, 61.3404580950737, 50.845634043216705, 48.903877437114716, 52.330221980810165, 60.35326726734638, 61.22230343520641, 57.83619873225689, 51.64902873337269, 57.05962300300598, 58.42912271618843, 60.52956260740757, 49.321900606155396, 44.8669246584177, 46.20221480727196, 57.79488354921341, 57.847951501607895, 57.121194899082184, 54.44882109761238, 58.96373502910137, 58.14777821302414, 59.2718642950058, 62.83959925174713, 62.416332364082336, 60.49106687307358, 57.2330304980278, 62.55988106131554, 63.38937275111675, 50.93481905758381, 36.25319346785545, 14.855510909110308, 3.1174971163272858, 6.461568474769592, 2.867529192008078, 5.51374495960772, 2.1356214908882976, 0.201513325155247, 0.04366539404145442, 0.07395455584628507, 0.0461055310734082, 0.1153425287338905, 0.5908383114729077, 9.527095779776573, 35.852193385362625, 26.067672818899155, 28.035471327602863, 42.670015543699265, 30.363481007516384, 14.76708110421896, 19.619502425193787, 30.918336734175682, 51.39556333422661, 54.27540220320225, 57.232973501086235, 17.40677285939455, 0.7908480009064078, 0.1306901130010374, 0.010076613052660832, 0.013137092773831682, 0.019087678301730193, 0.011305463958706241, 0.04139101569307968, 0.03212573610653635, 0.03336362729896791, 0.05305820428475272, 0.050311341328779235, 0.028343135563773103, 0.019058625075558666, 0.02493128788046306, 0.046150130438036285, 0.022599181575060356, 0.11182530535734259, 0.021803970339533407, 0.00439356062997831, 0.06437335512600839, 0.016552017586946022, 0.06384167310898192, 0.0560294852766674, 0.0314298761804821, 0.007001277390372707, 0.07023028068942949, 0.024896123068174347, 0.03729322132130619, 0.027965525259787682, 0.02685147996089654, 0.01565573511470575, 0.03581794677302241, 0.09623762147384696, 0.03360701091878582, 0.019348027417436242, 0.018143582965421956, 0.04615808626112994, 0.006968065818000468, 0.03782950836466625, 0.033344498442602344, 0.01462493188228109, 0.07169444899773225, 0.017000334155454766, 0.0825758850260172, 0.03754372213734314, 0.05104695439513307, 0.12557521637063473, 0.03466448230028618, 0.07383432792266831, 0.12193841073894873, 0.060190907679498196, 0.09837389356107451, 25.73416281491518, 75.74142694473267, 70.81911027431488, 63.28807778656483, 49.520622342824936, 39.79514680802822, 27.191889993846416, 24.2341648042202, 41.224101930856705, 31.095460429787636, 31.746597290039062, 39.575058817863464, 9.352308008819818, 0.18339763395488262, 0.02986377203342272, 0.17716907052090392, 0.283837970928289, 1.6077725775539875, 3.9641021378338337, 7.562861954793334, 10.517816618084908, 9.26998257637024, 6.892279163002968, 9.00404529646039, 5.918028065934777, 12.85865630954504, 26.233492121100426, 35.86988903582096, 45.281512811779976, 57.7122113853693, 58.090002313256264, 61.13886371254921, 56.604198440909386, 59.95758689939976, 57.42790304124355, 57.60455936193466, 58.825977221131325, 63.09445537626743, 61.386108845472336, 57.48021483421326, 54.364667013287544, 56.086290031671524, 53.401992470026016, 58.22113327682018, 57.66768537461758, 61.23636648058891, 63.089758828282356, 62.87135034799576, 58.340716660022736, 58.921059519052505, 56.6055815666914, 60.222387090325356, 61.20564512908459, 61.74559235572815, 58.16693298518658, 61.70618087053299, 54.202552512288094, 57.67518997192383, 52.20410294830799, 57.41009719669819, 56.04958780109882, 67.67310708761215, 41.35790415108204, 43.277918323874474, 69.40263748168945, 56.094926968216896, 63.10324430465698, 59.578857421875, 60.53213506937027, 59.62895393371582, 61.86641447246075, 52.83579245209694, 51.59095264971256, 55.341526195406914, 63.17856766283512, 62.695427387952805, 58.14632669091225, 52.39614464342594, 57.27229759097099, 61.0594479739666, 62.436482682824135, 50.25168411433697, 45.82687474787235, 48.47982779145241, 59.35373090207577, 61.37508183717728, 59.50015604496002, 54.18355353176594, 59.031481593847275, 58.689237758517265, 62.05891974270344, 65.50574138760567, 65.9428471326828, 64.93777066469193, 58.57441931962967, 64.92753401398659, 65.29560506343842, 54.28405053913593, 33.769228756427765, 12.300643902271986, 2.550682006403804, 5.2778982650488615, 4.580570133402944, 7.236149786040187, 4.887208929285407, 2.1013221563771367, 0.18155957164708525, 0.062030595290707424, 0.09291230264352635, 0.11271533338003792, 0.6721663568168879, 11.050584129989147, 36.53859235346317, 30.264764204621315, 29.384017065167427, 34.800626412034035, 29.562436491250992, 22.15256430208683, 31.315293833613396, 38.29561427235603, 58.01085256040096, 61.262212693691254, 65.29805973172188, 23.51746816188097, 0.8002400281839073, 0.0693597192002926, 0.0919879725552164, 0.013518580799427582, 0.027410456314100884, 0.07136135827749968, 0.06708540764520876, 0.017469447557232343, 0.031142943334998563, 0.053899636477581225, 0.025410179077880457, 0.04397339274873957, 0.026965598153765313, 0.02796854023472406, 0.029839565031579696, 0.01770489390764851, 0.09012651775265113, 0.0031947490788297728, 0.027644336732919328, 0.08901174514903687, 0.01887939084554091, 0.0031766821894052555, 0.06373253287165426, 0.023224466967803892, 0.025726953681441955, 0.03926249162759632, 0.05357725494832266, 0.11988391590421088, 0.14891770522808656, 0.17537246458232403, 0.2157522298512049, 0.13063474878435954, 0.17008826922392473, 0.10598429886158556, 0.12236697133630514, 0.1296888815704733, 0.1886629342334345, 0.0973005624837242, 0.09701041242806241, 0.18414056830806658, 0.11395310211810283, 0.1559933411772363, 0.23390890244627371, 0.16684937349054962, 0.09120533330133185, 0.1816765489638783, 0.19501387781929225, 0.12742130871629342, 0.22616254311287776, 0.2730854385299608, 0.2891076647210866, 0.2756315690930933, 34.106988832354546, 84.96222496032715, 77.237908244133, 73.27887788414955, 58.24968874454498, 44.33189436793327, 28.563257306814194, 28.066815845668316, 53.37876811623573, 39.137288108468056, 48.23221027851105, 57.215376645326614, 13.962238691747189, 0.6594775314442813, 0.1826992878341116, 0.3164227365050465, 0.314259227598086, 1.5767680224962533, 5.41248039342463, 9.995104316622019, 12.846429515630007, 9.30870059877634, 17.44182787835598, 13.498776610940695, 10.794819854199886, 25.36337301135063, 38.84635291993618, 42.54448547959328, 48.57003875076771, 60.83928398787975, 61.42734803259373, 63.42702113091946, 57.04559035599232, 59.916518703103065, 57.004829943180084, 59.499977454543114, 60.738270208239555, 65.66436007618904, 65.58660104870796, 61.133346408605576, 58.15490283071995, 58.31086166203022, 56.12935312092304, 59.63162899017334, 60.477531999349594, 63.11384953558445, 65.656608492136, 65.02056822180748, 58.693884909152985, 59.98794727027416, 57.255893871188164, 62.13239639997482, 64.27380949258804, 65.19772231578827, 61.80114157497883, 63.803615123033524, 55.9603001922369, 61.13870412111282, 54.05553460121155, 61.18862584233284, 59.37874875962734, 69.38163220882416, 44.14428323507309, 46.14892266690731, 70.3417494893074, 58.62311750650406, 65.72850823402405, 61.89620107412338, 61.75420269370079, 62.87419259548187, 64.68570739030838, 56.23468726873398, 54.30083803832531, 56.90739557147026, 67.3196728527546, 65.11932492256165, 59.198877811431885, 54.32344302535057, 60.24527706205845, 64.1141040623188, 64.98446255922318, 53.52900445461273, 49.170642122626305, 51.605703458189964, 63.65530528128147, 64.64195653796196, 59.4461153447628, 55.0109439343214, 59.423780143260956, 59.48252119123936, 65.07843151688576, 69.3612577021122, 68.473731726408, 68.79815071821213, 61.07153132557869, 69.72745165228844, 67.65302896499634, 54.89080958068371, 42.77831733226776, 21.455242820084095, 9.55609867349267, 14.00953570380807, 11.859891302883625, 13.599210921674967, 6.790333483368158, 1.3478848105296493, 0.15085192018887028, 0.17147851962363347, 0.3708935558097437, 0.2401645839563571, 1.2864332017488778, 14.646452777087688, 49.111380502581596, 40.252414271235466, 42.94026844203472, 61.205892115831375, 39.94326665997505, 22.88903508335352, 31.791216395795345, 45.34917198121548, 67.40649059414864, 69.22991394996643, 74.65460166335106, 28.207638189196587, 1.3931840797886252, 0.24197753198677674, 0.3089418582385406, 0.1312912823050283, 0.07789660681737587, 0.25107678200583905, 0.21817690052557737, 0.09320170313003473, 0.12701746163656935, 0.17376776318997145, 0.10405495238956064, 0.11974913446465507, 0.18623575509991497, 0.17643924249568954, 0.16136135469423607, 0.16896223824005574, 0.2658385445829481, 0.08156733601936139, 0.08768575731664896, 0.2308812367846258, 0.14538690797053277, 0.14310346799902618, 0.2607393963262439, 0.11257442922214977, 0.06143236118077766, 0.18611051025800407, 0.10320406523533165], [0.06545954762259498, 0.035751665564021096, 0.03292951543699019, 0.03230164737033192, 0.04590401200402994, 0.03893002802215051, 0.00455141451311647, 0.028641898243222386, 0.07925889309262857, 0.020546740634017624, 0.056507947883801535, 0.02584596262749983, 0.025051888733287342, 0.04947814697516151, 0.017884966764540877, 0.021748715589637868, 0.009117170102399541, 0.03804636391578242, 0.03337844056659378, 0.05878892021428328, 0.08268604200566188, 0.08783250217675231, 0.02061322593363002, 0.043748139796662144, 1.663951613008976, 50.00159673392773, 67.8552009165287, 64.35881853103638, 42.98143543303013, 54.28474970161915, 28.744608275592327, 22.063694670796394, 39.186955243349075, 38.11768501996994, 48.326243832707405, 53.09771619737148, 13.64726409316063, 0.4852143401512876, 0.0646322533430066, 0.02182678766985191, 0.05639480004901998, 0.0642464924021624, 1.3198509835638106, 2.635407722555101, 2.4857102427631617, 1.8523924075998366, 8.953642901033163, 7.707211459055543, 23.411381654441357, 13.350473418831825, 29.86680205911398, 39.994085133075714, 60.94508171081543, 54.47723217308521, 54.40618738532066, 49.27323281764984, 52.78640650212765, 54.50016774237156, 57.30633996427059, 56.39564283192158, 57.968192249536514, 53.4136426448822, 59.31811161339283, 58.119313940405846, 61.12394571304321, 58.13740096986294, 57.71886482834816, 54.75962162017822, 55.40613412857056, 55.47526001930237, 58.112702295184135, 57.49403469264507, 59.412304759025574, 56.006688103079796, 57.787557542324066, 56.99879586696625, 59.38167080283165, 56.597981974482536, 57.489645928144455, 54.01405982673168, 54.979808405041695, 48.82449209690094, 50.87714955210686, 48.41419771313667, 52.66513980925083, 53.814654126763344, 65.69443926215172, 37.16857574880123, 41.301321387290955, 65.70203125476837, 53.963708728551865, 58.22310537099838, 56.66486978530884, 60.3395652025938, 57.29681767523289, 58.68318848311901, 49.43840995430946, 46.29012688994408, 52.68685184419155, 60.60161434113979, 56.89335912466049, 57.09758296608925, 52.79799208045006, 55.70337317883968, 56.9278384745121, 58.275451362133026, 52.43124715983868, 40.65000593662262, 47.92375423014164, 57.92218431830406, 58.514568731188774, 57.52188339829445, 53.28165292739868, 53.777241334319115, 55.71172513067722, 56.509826704859734, 61.113804057240486, 61.05755567550659, 55.61074174940586, 57.632955238223076, 57.954919561743736, 62.96303182840347, 61.323560401797295, 51.51480093598366, 31.770479008555412, 12.659361753612757, 8.642961122095585, 3.7818206939846277, 4.713052874431014, 5.185282034799457, 3.0653071543201804, 0.14239137730328366, 0.0607162740197964, 0.12302904870011844, 0.04438157026015688, 0.12240284675499424, 0.6745247240178287, 20.1764727383852, 43.13500419259071, 40.35661228001118, 35.883081927895546, 31.733241006731987, 25.623805336654186, 10.653776172548532, 22.58203625679016, 36.402016282081604, 52.06405766308308, 54.620875865221024, 40.51942594349384, 3.3326648455113173, 0.09616783732781187, 0.05263435632514302, 0.03275359675171785, 0.049850463910843246, 0.02368169301917078, 0.05464573980134446, 0.06381024315487593, 0.06222163894562982, 0.032014079988584854, 0.07102169212885201, 0.04251283127814531, 0.07132626953534782, 0.04297443600080442, 0.0401569131645374, 0.028000543497910257, 0.07296720257727429, 0.019847147705149837, 0.05789532617200166, 0.0300888802667032, 0.10715640979469754, 0.08854756888467818, 0.02611122290545609, 0.059277861946611665, 0.009084241009986727, 0.011190963559783995, 0.023101539482013322, 0.08164950661011972, 0.01105747809560853, 0.025270380720030516, 0.0368285589502193, 0.04267707226972561, 0.053212363200145774, 0.05658609603415243, 0.02185833451221697, 0.018192997013102286, 0.036417305236682296, 0.04161367112828884, 0.02585212616395438, 0.02486593250068836, 0.009950571329682134, 0.026261242492182646, 0.0722963159205392, 0.009531808009342058, 0.05298937379848212, 0.045272418356034905, 0.004122057034692261, 0.037483964406419545, 0.10232753687887453, 0.040685893764020875, 0.08810367551632226, 2.270110286772251, 58.86199548840523, 75.25589659810066, 72.92640119791031, 52.72706888616085, 57.27705493569374, 36.17340534925461, 26.08625192195177, 32.40766681730747, 38.67063134908676, 39.28479239344597, 42.30004079639912, 11.473471038043499, 0.5245692143216729, 0.01902814878121717, 0.06038584018824622, 0.09307311862357892, 0.517544875619933, 2.827955740503967, 7.555446177721024, 8.066352512687445, 9.9989896081388, 9.324620794504881, 5.7778573874384165, 12.738876286894083, 12.412555497139692, 29.46544859558344, 41.01046599447727, 56.414995193481445, 56.347791999578476, 58.043929785490036, 53.51616874337196, 56.643385738134384, 56.596522852778435, 57.82477654516697, 56.531626135110855, 59.523824974894524, 57.14464344084263, 62.054922357201576, 60.12257404625416, 63.55238400399685, 59.612151235342026, 59.14473831653595, 56.671006456017494, 58.49803201854229, 58.57309319078922, 61.09216421842575, 59.62169632315636, 59.94679167866707, 56.25945433974266, 59.62795078754425, 57.04872898757458, 59.08323481678963, 59.85215775668621, 59.6261078864336, 56.36400952935219, 58.173328042030334, 50.101778358221054, 52.33097814023495, 50.85533872246742, 56.03759564459324, 55.681018978357315, 67.81298518180847, 38.441556841135025, 43.91955189406872, 69.00044426321983, 56.65942847728729, 60.09077735245228, 59.69365306198597, 60.53348779678345, 59.70678895711899, 60.73193594813347, 51.14159256219864, 48.761898055672646, 53.90334516763687, 62.13544003665447, 60.027746334671974, 58.71120058000088, 52.66662932932377, 56.31470337510109, 59.09766644239426, 60.77056087553501, 55.30390441417694, 42.243040055036545, 49.01709236204624, 59.93634983897209, 61.443622559309006, 59.14815053343773, 54.64699186384678, 55.11081397533417, 57.57559731602669, 60.65071530640125, 63.46851870417595, 63.59442874789238, 58.4688837826252, 59.65641126036644, 59.723036885261536, 64.48298826813698, 63.31998087465763, 53.69619928300381, 31.774685382843018, 11.62841722369194, 4.0389946941286325, 2.159342193044722, 5.601309360936284, 7.2404734790325165, 5.062279785051942, 1.7334362282417715, 0.15430716681294143, 0.027961053820035886, 0.044149905152153224, 0.09389541824930348, 0.835219407454133, 21.197206266224384, 42.96650983393192, 41.82657100260258, 36.0600346326828, 19.49462402611971, 16.324718222022057, 17.555582374334335, 34.944973066449165, 45.8225391805172, 59.195275604724884, 63.98478180170059, 48.7243864685297, 4.259079359471798, 0.06761976139387116, 0.010854346710402751, 0.04913030606985558, 0.019003492780029774, 0.04015377759060357, 0.03158075109240599, 0.012476660194806755, 0.021808374985994305, 0.03449184019700624, 0.00983174606517423, 0.06256312335608527, 0.019361697777640074, 0.042805534321814775, 0.054728815812268294, 0.041729063959792256, 0.1418689201818779, 0.03629597893450409, 0.057075961740338244, 0.0059840271660505095, 0.06290375429671258, 0.008926334248826606, 0.058055440822499804, 0.055350768961943686, 0.04888274044787977, 0.01983493009902304, 0.041273659880971536, 0.1642250205622986, 0.20329029386630282, 0.11781521636294201, 0.11140980655909516, 0.15012436313554645, 0.11181163499713875, 0.16382001573219895, 0.11565477994736284, 0.15233002603054047, 0.18283376499311998, 0.17141007876489311, 0.06915277132065967, 0.09882077036309056, 0.09863209415925667, 0.12964739551534876, 0.1968129922170192, 0.1423605188028887, 0.15184169285930693, 0.12843546835938469, 0.12037534383125603, 0.15958546951878816, 0.2595166041282937, 0.14320729445898905, 0.19871924305334687, 4.8431564681231976, 70.12156650424004, 83.27070012688637, 82.50536799430847, 61.95210747420788, 67.43470028042793, 40.81997461616993, 32.16511823236942, 50.54777942597866, 50.28681702911854, 61.778449192643166, 69.50475320219994, 18.7345128133893, 0.8688351348973811, 0.13941445969976485, 0.23721040575765073, 0.229331647278741, 0.5696356273256242, 3.3008871506899595, 10.290505215525627, 8.963702861219645, 8.52078152820468, 18.274859078228474, 20.015933252871037, 31.847802959382534, 18.72072145342827, 37.343153581023216, 44.61608111858368, 64.64623510837555, 59.467872977256775, 60.29575355350971, 54.04293827712536, 56.34946011006832, 56.47554114460945, 58.932360112667084, 58.083056285977364, 59.604536443948746, 56.15900292992592, 62.461891919374466, 62.03810065984726, 64.60560768842697, 60.92874638736248, 61.78932040929794, 60.74406109750271, 60.884220376610756, 59.6193328499794, 63.8399563729763, 61.42360143363476, 60.968522652983665, 56.50706425309181, 59.989398792386055, 58.479386419057846, 61.060800701379776, 61.57429374754429, 61.968860775232315, 60.14053948223591, 60.93365952372551, 52.138548865914345, 55.79233780503273, 54.14079822599888, 57.161902114748955, 59.14577566087246, 69.12577673792839, 42.81978450715542, 47.12105870246887, 69.5834469795227, 60.33068127930164, 61.967067271471024, 62.287652269005775, 61.630644723773, 61.90091282129288, 64.71943438053131, 54.47283960878849, 51.389935836195946, 55.50133801996708, 64.4770073890686, 62.34260492026806, 59.54355351626873, 53.11036951839924, 57.68315054476261, 61.780584678053856, 63.554986864328384, 58.92220325767994, 43.63087758421898, 52.15466380119324, 63.96603360772133, 64.57609847187996, 60.73408283293247, 52.67672538757324, 55.27551993727684, 57.559018805623055, 61.23750261962414, 67.06946387887001, 66.61161884665489, 61.24472223222256, 63.147546127438545, 62.853802889585495, 65.99285244941711, 64.99158337712288, 56.40318542718887, 38.16338136792183, 18.009988591074944, 16.6496691852808, 13.871850091964006, 15.04462106153369, 12.133824303746223, 6.140456730499864, 0.8899956056848168, 0.13841305015375838, 0.2105808409396559, 0.14992809476098046, 0.37892475142143667, 1.2477808445692062, 28.95136658102274, 55.09012408554554, 53.060398399829865, 53.47496755421162, 47.31090411543846, 37.47680380940437, 22.009562775492668, 37.15852148830891, 53.99295195937157, 68.70982065796852, 72.97431662678719, 59.830688908696175, 5.994547409936786, 0.3472068440169096, 0.1712212318670936, 0.13449048798065633, 0.08514367887983099, 0.0777592723898124, 0.22496345511171967, 0.21564038819633424, 0.12748311477480456, 0.13347027241252363, 0.1204683052492328, 0.13019662932492793, 0.13859195227269083, 0.18994408892467618, 0.1572978586773388, 0.15211748977890238, 0.20905465877149254, 0.19683432154124603, 0.11975238507147878, 0.117147409619065, 0.12390708361635916, 0.16189737827517092, 0.14274431305238977, 0.1825008078594692, 0.16900369460927323, 0.07747000548988581, 0.1019043123233132], [0.006907841461725184, 0.03172911012370605, 0.003914607277692994, 0.0750209997931961, 0.09031761335791089, 0.033939942077267915, 0.050707447808235884, 0.05538778357731644, 0.07368897830019705, 0.09576575655955821, 0.027377063379390165, 0.028327999461907893, 0.06959612292121165, 0.026432891972945072, 0.04207045189104974, 0.07157329338951968, 0.1032149005914107, 0.05555667412409093, 0.10596661348245107, 0.019196501270926092, 0.0639984814915806, 0.03667131641122978, 0.030445630654867273, 0.10427114000776783, 22.310689017176628, 64.47178646922112, 61.21076725423336, 53.96177463233471, 41.921634301543236, 36.29552319645882, 19.708066172897816, 25.317342281341553, 35.23618943989277, 41.491983756423, 48.16860169172287, 17.797446995973587, 0.8064060879405588, 0.020872790228168014, 0.039038515169522725, 0.088053536019288, 0.43421116133686155, 0.11748083430575207, 2.434472367167473, 5.928836110979319, 9.490315653383732, 15.100847594439983, 9.906354378908873, 6.458023739978671, 27.290640994906425, 35.43123297393322, 51.61731943488121, 56.97458356618881, 49.97967571020126, 49.73287135362625, 53.535171523690224, 60.23701250553131, 61.38172388076782, 59.94115278124809, 58.5463198274374, 56.92151561379433, 55.92907726764679, 56.08756676316261, 54.95668284595013, 57.27525383234024, 60.05200043320656, 57.41412118077278, 59.13558080792427, 59.751770943403244, 58.07747058570385, 56.85165636241436, 59.39368195831776, 58.12551900744438, 61.20600610971451, 55.79274818301201, 57.108419984579086, 54.21607978641987, 60.05144186317921, 59.19763147830963, 55.12676551938057, 51.89194969832897, 50.584724843502045, 45.62765143811703, 48.74587431550026, 45.72339490056038, 54.57410417497158, 54.203643053770065, 64.58228453993797, 38.178265169262886, 43.384115025401115, 65.78714668750763, 52.30224408209324, 54.730613976716995, 55.581194534897804, 58.49485918879509, 57.21759952604771, 59.311401173472404, 52.42058113217354, 42.41949878633022, 44.43595938384533, 57.5192691385746, 59.59972210228443, 59.51620638370514, 55.63416749238968, 49.93305221199989, 57.16271907091141, 60.28549410402775, 54.03913468122482, 41.83730162680149, 47.360943630337715, 57.77065984904766, 59.313339069485664, 57.2121050208807, 55.31438425183296, 52.594235613942146, 58.745174556970596, 59.76813666522503, 58.49439941346645, 58.200648576021194, 55.30272647738457, 55.92745095491409, 57.44293123483658, 62.76784770190716, 62.21766382455826, 62.112367674708366, 51.01818658411503, 28.26705940067768, 10.977703090757132, 2.7814526483416557, 5.253231413662434, 5.422053504735231, 4.812923390418291, 1.5141622256487608, 0.13724897667998448, 0.06093540054280311, 0.07733860824373551, 0.02944069590739673, 0.16113091784063727, 2.0648593129590154, 26.227653734385967, 38.96317385137081, 31.90800502896309, 56.91135875880718, 73.6710624396801, 24.451292753219604, 10.823520664125681, 34.740479439496994, 48.326980993151665, 54.001474902033806, 52.93152071535587, 9.760615099221468, 0.07195521000539884, 0.026709343837865163, 0.007167511976149399, 0.025365498077007942, 0.021872821234865114, 0.056630164763191715, 0.05844893123139627, 0.07354957328061573, 0.05498362850630656, 0.05699633671611082, 0.0401091077219462, 0.06708410888677463, 0.04518688212556299, 0.05856288058566861, 0.04409928325912915, 0.024980523812700994, 0.025847415381576866, 0.03365931748703588, 0.08700813195900992, 0.03355542794452049, 0.08496237962390296, 0.06700778641970828, 0.03423879010370001, 0.044201202399563044, 0.04072632968018297, 0.019989651191281155, 0.027170681387360673, 0.020212122944940347, 0.061878380802227184, 0.013672431723534828, 0.03904149489244446, 0.027331037235853728, 0.02895252786402125, 0.031443988118553534, 0.04236328481056262, 0.05450943695905153, 0.020473954500630498, 0.022963054725551046, 0.03446307084232103, 0.031760592028149404, 0.05223298059718218, 0.02809166253427975, 0.04852822021348402, 0.022116546242614277, 0.08887090778443962, 0.04720800629002042, 0.02938713882031152, 0.026155414088862017, 0.09533505857689306, 0.16468812071252614, 26.193480268120766, 76.29552081227303, 69.93836313486099, 63.54101121425629, 48.86445075273514, 48.18725489079952, 26.19940035045147, 23.645242005586624, 36.07493743300438, 37.82165050506592, 42.15915575623512, 19.75249908864498, 0.9635302692186087, 0.06465456972364336, 0.03281787045125384, 0.14180328464135528, 1.0045910440385342, 2.837877720594406, 6.932729417458177, 7.4842968955636024, 7.9740687645971775, 14.848410040140152, 10.358934793621302, 9.478984661400318, 28.448575660586357, 33.06503154337406, 48.81935477256775, 56.64583660662174, 55.94575457274914, 52.61679120361805, 55.539415776729584, 59.792820140719414, 62.457791939377785, 58.27795922756195, 61.383578181266785, 57.936988323926926, 58.056560307741165, 56.55445531010628, 58.32065373659134, 58.48300002515316, 60.76002784073353, 60.129140093922615, 62.101922035217285, 60.66608928143978, 59.71610225737095, 59.854692220687866, 61.25712476670742, 59.66724067926407, 60.32044842839241, 57.16111175715923, 57.89933994412422, 55.29112949967384, 60.32370865345001, 60.5568603426218, 57.00145572423935, 53.42452526092529, 52.801522091031075, 47.237032279372215, 49.95949499309063, 47.052707970142365, 56.14517167210579, 56.60557396709919, 66.55363395810127, 39.34377282857895, 47.51460358500481, 67.60208889842033, 55.25019809603691, 56.641843020915985, 58.02480161190033, 57.55573958158493, 57.34808452427387, 61.51681423187256, 54.77575555443764, 45.606828555464745, 47.06952966749668, 60.45045465230942, 61.02673552930355, 59.50299069285393, 56.33899927139282, 51.06691516935825, 59.0872398018837, 62.38770470023155, 56.803930923342705, 44.23156075179577, 49.78992909193039, 60.24321757256985, 61.14569574594498, 58.19197744131088, 54.92885313928127, 53.23403388261795, 59.09713067114353, 64.39620852470398, 60.805446803569794, 62.91549637913704, 58.06971900165081, 56.62642724812031, 60.15974745154381, 65.99056497216225, 65.74940711259842, 64.95573610067368, 54.09053072333336, 31.510498858988285, 12.137031331658363, 4.09791243262589, 3.0096548656001687, 7.621970158070326, 8.141846861690283, 5.62248419970274, 1.0675411974079907, 0.4384698421927169, 0.08498848837916739, 0.10887682685279287, 0.048650707976776175, 2.4675809405744076, 31.69230580329895, 46.0708786547184, 38.338981345295906, 47.71133042871952, 56.293527111411095, 24.292900152504444, 18.133242577314377, 39.68394577503204, 54.785023257136345, 58.957605957984924, 63.14540684223175, 14.31633124127984, 0.13174764375435188, 0.05757339364208747, 0.09248096641385928, 0.011238798688282259, 0.030520318541675806, 0.02891749292757595, 0.05916953807172831, 0.06016136278049089, 0.06483891178504564, 0.056410129109281115, 0.03201063642336521, 0.06032574478012975, 0.031788801061338745, 0.04038725353893824, 0.03887502374709584, 0.05307825711497571, 0.05061751064204145, 0.08249832317233086, 0.09300055884523317, 0.007374213091679849, 0.05104559997562319, 0.023960326798260212, 0.009737960863276385, 0.009266569068131503, 0.05543657607631758, 0.05404832947533578, 0.0731466241995804, 0.15467123477719724, 0.06290609948337078, 0.18747778376564384, 0.15013873111456633, 0.10571731865638867, 0.19585188128985465, 0.07144231916754507, 0.1697871056967415, 0.23536057298770174, 0.11064311605878174, 0.10480787605047226, 0.12217959389090538, 0.18536343472078443, 0.21303729037754238, 0.08624343783594668, 0.25838554138317704, 0.14796778588788584, 0.25530358019750565, 0.11428053767303936, 0.1047555026889313, 0.12960435095010325, 0.2486934934859164, 0.491432172129862, 34.35859993100166, 88.10545429587364, 78.20034340023994, 71.89841955900192, 55.58347821235657, 50.209551975131035, 32.520896941423416, 36.583236157894135, 47.611467987298965, 56.18126593530178, 62.773915976285934, 24.719919338822365, 1.4695927547290921, 0.16915310377953574, 0.31351025216281414, 0.2940476668300107, 0.9405434026848525, 2.575113270431757, 8.549748323857784, 12.756000068038702, 16.72550741583109, 26.820404827594757, 22.309030406177044, 13.590366896241903, 34.723878130316734, 39.70178961753845, 54.814452677965164, 61.2613957375288, 57.22559429705143, 55.447852090001106, 56.86030089855194, 61.66634760797024, 65.0785531103611, 59.80082631111145, 61.4162640273571, 57.09242284297943, 57.88885250687599, 56.16714209318161, 59.381477013230324, 59.691513776779175, 63.026602417230606, 60.86533918976784, 63.47360663115978, 62.69085243344307, 61.87354288995266, 62.26989962160587, 63.402641639113426, 61.231840923428535, 63.64161841571331, 59.071204662323, 60.58287374675274, 56.34733982384205, 62.59541675448418, 64.18008372187614, 59.487818107008934, 56.67017810046673, 56.282712891697884, 50.30494965612888, 52.564042434096336, 50.44062897562981, 59.5381236076355, 60.20863562822342, 70.38216412067413, 42.85658933222294, 50.58081865310669, 70.29154658317566, 58.11062000691891, 58.61640706658363, 60.195203348994255, 58.67164850234985, 60.768197402358055, 64.9614205956459, 57.56370395421982, 48.437600657343864, 49.048839658498764, 63.69714863598347, 63.50676745176315, 60.91731660068035, 57.827835381031036, 52.234695106744766, 61.64173632860184, 64.80478540062904, 58.34785267710686, 46.85170255601406, 53.07462103664875, 63.26689012348652, 63.75706762075424, 59.76477384567261, 56.335047483444214, 52.40332245826721, 58.93193453550339, 66.15339383482933, 63.55617620050907, 65.34521520137787, 61.22834511101246, 60.67832462489605, 63.51051785051823, 68.88591080904007, 68.4666945040226, 66.33411973714828, 56.16491921246052, 33.11362333595753, 15.734752379357815, 7.704357337206602, 16.33323546499014, 18.291133604943752, 15.088598001748323, 6.6730940993875265, 0.4890213499311358, 0.2167290446232073, 0.26504572306293994, 0.3572538314620033, 0.2692794083850458, 3.819705373607576, 38.43221314251423, 49.93071533739567, 43.6733441054821, 73.25708225369453, 89.74103093147278, 36.54227815568447, 22.592715583741665, 48.11782121658325, 66.05614945292473, 67.76339784264565, 72.87517234683037, 19.74795453250408, 0.2573622087948024, 0.24941965530160815, 0.23801381030352786, 0.12624304537894204, 0.10461709214723669, 0.14281938871135935, 0.18019088805885985, 0.19342191168107092, 0.15656259813113138, 0.17784556781407446, 0.08658665145048872, 0.14141669991659, 0.09794258701731451, 0.17473567218985409, 0.14706101501360536, 0.12222358098370023, 0.16961786634055898, 0.19327409070683643, 0.18418975785607472, 0.16677236824762076, 0.23331013770075515, 0.18540067569119856, 0.14528694067848846, 0.1697311329189688, 0.20244241983164102, 0.21705906285205856], [0.021244927193038166, 0.052768172972719185, 0.02312744785740506, 0.04497493588132784, 0.0818138848990202, 0.028018015509587713, 0.022134686187200714, 0.023900929008959793, 0.01532195883555687, 0.010927220046141883, 0.04646985878935084, 0.026481159402464982, 0.1263727282639593, 0.039278830008697696, 0.026658764618332498, 0.04159404132224154, 0.012252948126842966, 0.0628558115568012, 0.044134242125437595, 0.024240886450570542, 0.10718550940509886, 0.09535243225400336, 0.05967163808236364, 0.5792001297231764, 30.955683030188084, 60.541547164320946, 62.34140418469906, 50.43028213083744, 32.87924811244011, 19.92547530680895, 26.9383504986763, 41.30554296076298, 40.22263906896114, 42.08276465535164, 24.34162873774767, 1.9864578824490309, 0.06089730239182245, 0.06377153273206204, 0.0892149080755189, 0.0683347242011223, 0.6224607490003109, 1.8433969840407372, 5.010593058541417, 5.364902196452022, 9.944787416607141, 12.00951112434268, 10.344939194619656, 19.97278656810522, 41.911656036973, 50.08008152246475, 51.19089871644974, 46.21019817888737, 57.19749100506306, 61.35807774960995, 62.13362753391266, 57.97691658139229, 58.07170249521732, 57.70970731973648, 58.365274742245674, 55.04368677735329, 57.297733426094055, 55.822056010365486, 54.20605592429638, 57.32103377580643, 58.847286477684975, 57.29798421263695, 58.830643370747566, 56.91853277385235, 56.02436475455761, 57.57178612053394, 58.07603806257248, 55.44911362230778, 55.98450869321823, 55.043359994888306, 56.28381483256817, 54.37158264219761, 57.70119197666645, 54.70033340156078, 55.412787571549416, 50.03101475536823, 47.38819196820259, 46.02591186761856, 46.87026835978031, 44.94639739394188, 52.33026757836342, 53.35665710270405, 64.35937330126762, 36.52474209666252, 44.22685660421848, 62.38258637487888, 51.53552122414112, 51.310949474573135, 55.33072717487812, 59.15623649954796, 57.927982807159424, 57.86126218736172, 51.47840268909931, 45.09797126054764, 43.57096239924431, 53.070509657263756, 56.27440273761749, 56.05955466628075, 58.821835443377495, 53.612075597047806, 52.30953589081764, 55.86822733283043, 55.056530088186264, 41.2092599272728, 48.12983237206936, 59.57881182432175, 58.266438245773315, 56.69650308787823, 53.65928426384926, 53.925026804208755, 59.9463053047657, 59.24306184053421, 57.3674900829792, 55.4174917191267, 54.28846210241318, 52.6597934961319, 52.827710285782814, 58.94233077764511, 62.10651978850365, 64.1670124232769, 63.66999909281731, 55.0059662014246, 32.76475265622139, 9.59439491853118, 2.9717191262170672, 5.873129675164819, 4.868566654622555, 5.9773072600364685, 1.6387238167226315, 0.23830056132283062, 0.05613573484879453, 0.020819576384383254, 0.07646259196917526, 0.07519528575357981, 8.01449004560709, 32.75931514799595, 47.4628009647131, 80.91920390725136, 101.91251501441002, 59.40078757703304, 28.2681043446064, 39.914714992046356, 41.041073352098465, 43.9604414999485, 58.1872732937336, 31.125045642256737, 0.23271132842637599, 0.0360211430961499, 0.019602322463470045, 0.008720323330635438, 0.012847435318690259, 0.02417146595689701, 0.014208904303814052, 0.010431999744469067, 0.06985856860410422, 0.016854557798069436, 0.02978593372972682, 0.10814825305715203, 0.012809666495741112, 0.09596278192475438, 0.009648428167565726, 0.07567394874058664, 0.028158754539617803, 0.020405361501616426, 0.038622107240371406, 0.11244552559219301, 0.038375825533876196, 0.03724152331415098, 0.011635850478342036, 0.04628240341844503, 0.022473439494206104, 0.04887707043963019, 0.019768925340031274, 0.018854951922548935, 0.07018858683295548, 0.033597069850657135, 0.037641329399775714, 0.02107699587213574, 0.029586110467789695, 0.021987950603943318, 0.021141677752893884, 0.024706044205231592, 0.03063257765461458, 0.005360547975215013, 0.1254852829151787, 0.017628712448640727, 0.028843871878052596, 0.05820038597448729, 0.049876134798978455, 0.05484247572894674, 0.017399910175299738, 0.027492517438076902, 0.018915462933364324, 0.0361616798909381, 0.12626707612071186, 1.4562838501296937, 39.24716301262379, 69.78055000305176, 69.90754678845406, 57.91625663638115, 42.316657304763794, 28.367444314062595, 38.7927757948637, 42.46385000646114, 34.62606377899647, 38.88655096292496, 26.14585742354393, 1.8309816252440214, 0.05634119843307417, 0.007610078291691025, 0.14395227713976055, 0.43826530629303306, 2.6563405618071556, 4.452240569517016, 6.5887172520160675, 9.694268759340048, 8.624101784080267, 11.625994853675365, 15.222214981913567, 20.70487428456545, 40.13140596449375, 51.292341873049736, 54.78889524936676, 53.02616223692894, 58.18849302828312, 61.045776307582855, 62.09640473127365, 61.35572947561741, 60.36641076207161, 60.05225121974945, 57.33336791396141, 54.7499131411314, 58.905924931168556, 57.76390001177788, 55.887697488069534, 58.46083201467991, 58.74434620141983, 57.7702646702528, 58.723040744662285, 57.68685534596443, 58.69220159947872, 59.47779044508934, 59.83958423137665, 56.79623633623123, 57.036782428622246, 55.85702173411846, 57.11988776922226, 54.80104319751263, 60.00596970319748, 57.47466713190079, 57.50112511217594, 51.369329541921616, 51.3294392824173, 48.41642439365387, 48.58455777168274, 46.702815145254135, 54.972083419561386, 55.64576826989651, 66.06690287590027, 39.094677194952965, 47.108454778790474, 65.12129321694374, 54.93390306830406, 53.26881341636181, 56.75037279725075, 59.674053713679314, 58.951123505830765, 59.370510801672935, 53.971486911177635, 46.651373505592346, 44.677398428320885, 54.32342782616615, 58.04601967334747, 58.47843647003174, 59.833930134773254, 55.20654983818531, 53.69015380740166, 59.55312520265579, 58.34421247243881, 43.59217286109924, 49.75934073328972, 61.27303831279278, 60.18069192767143, 56.41317889094353, 54.2747638374567, 53.33008132874966, 61.97832986712456, 61.281310468912125, 61.060945093631744, 58.08259271085262, 56.29575379192829, 56.26299574971199, 56.45392790436745, 60.02470649778843, 64.22399416565895, 66.99328556656837, 66.13430365920067, 57.19611167907715, 35.174796134233475, 12.649653274565935, 3.9312106277793646, 6.549251144751906, 9.195354580879211, 8.82521454244852, 4.934571012854576, 0.9135041723493487, 0.06324607733404264, 0.053660319827031344, 0.12419346356182359, 0.08793796136160381, 9.19465446844697, 40.888237953186035, 50.179719775915146, 77.7239553630352, 96.65529951453209, 51.66534125804901, 30.375305972993374, 47.20175497233868, 49.0641338378191, 51.44077330827713, 64.57983747124672, 37.924602180719376, 0.6495481298770756, 0.009809737675823271, 0.010520449832256418, 0.050539881995064206, 0.006468035007856088, 0.03980879766459111, 0.01927392582729226, 0.018374064347881358, 0.04309094947529957, 0.012287109184399014, 0.027951340962317772, 0.07686712182476185, 0.0026611799194142804, 0.04772960994159803, 0.04190937244857196, 0.062029103573877364, 0.0006664992883997911, 0.019258706233813427, 0.04154755319177639, 0.018890595420089085, 0.017664125880401116, 0.02222770326625323, 0.03828281587630045, 0.015324617579608457, 0.09452302285353653, 0.016742452680773567, 0.13363735954044387, 0.15453856845851988, 0.12476391537347808, 0.10363471126765944, 0.2367369006969966, 0.1086528466839809, 0.07735070525086485, 0.147428615600802, 0.20014023320982233, 0.09065585458301939, 0.0959916366264224, 0.06502297925180756, 0.34133241861127317, 0.08044461501413025, 0.1016753375006374, 0.10530038751312532, 0.17478968569776043, 0.2440921778907068, 0.07923898127046414, 0.159648492699489, 0.23108290799427778, 0.1534018653910607, 0.16993635159451514, 2.8986369352787733, 48.51152949035168, 77.44163051247597, 79.61363956332207, 66.77909106016159, 48.324332535266876, 29.48861215263605, 40.47561429440975, 53.85653927922249, 51.981434896588326, 55.30865415930748, 33.93461488187313, 2.9060071147978306, 0.1772956215427257, 0.14793222217122093, 0.2668210887350142, 0.3552855964517221, 2.493980498984456, 5.68259839899838, 10.248753055930138, 14.414750710129738, 22.236526496708393, 23.94139241427183, 18.936314284801483, 24.313369654119015, 47.48463839292526, 54.482928067445755, 59.42658819258213, 55.43110638856888, 58.62913638353348, 62.56663329899311, 65.88907241821289, 61.97920002043247, 61.220445334911346, 61.12585321068764, 58.967056050896645, 56.89099185168743, 60.44774919748306, 58.056628704071045, 55.91870002448559, 57.88468413054943, 60.50911210477352, 58.19493368268013, 61.03939265012741, 58.717553839087486, 60.59324339032173, 59.55636262893677, 61.28074809908867, 57.28433534502983, 57.68123544752598, 56.31707064807415, 58.00984941422939, 55.7355460524559, 61.92525431513786, 59.73702013492584, 60.61128482222557, 54.41404916346073, 55.177219212055206, 51.712971702218056, 50.937224328517914, 48.64927589893341, 56.64316534996033, 59.22519899904728, 69.6246063709259, 42.216954454779625, 49.75807540118694, 67.26846680045128, 57.883460596203804, 56.40359580516815, 60.35116598010063, 61.167913153767586, 60.93900963664055, 63.043279722332954, 55.76060190796852, 49.61667358875275, 47.30531081557274, 57.08730451762676, 60.67130260169506, 61.005156487226486, 62.06312611699104, 55.58577708899975, 55.93330264091492, 61.17014363408089, 60.79189293086529, 46.90536327660084, 53.50786618888378, 65.69444686174393, 63.01014930009842, 56.58682957291603, 54.03161868453026, 54.17352207005024, 65.70421233773232, 63.12995307147503, 63.38228613138199, 60.4705023765564, 60.32295249402523, 59.14688520133495, 58.59817184507847, 63.397538512945175, 67.42650032043457, 69.71048176288605, 68.48209127783775, 60.623979941010475, 38.71901795268059, 15.818508435040712, 10.50295751541853, 16.513729579746723, 16.83535572141409, 13.559453655034304, 6.792181609198451, 0.7140952663030475, 0.189605996129103, 0.29941173212137073, 0.37289732485078275, 0.2828726446023211, 12.161924745887518, 48.6377739161253, 56.347731202840805, 83.98711368441582, 103.15068617463112, 70.15630424022675, 40.8580219745636, 51.52515158057213, 55.94636254012585, 58.71934354305267, 74.58325669169426, 45.12124881148338, 1.1657110671512783, 0.23742666759062558, 0.07464124282705598, 0.07451680692611262, 0.10168900786084123, 0.0987002307374496, 0.22775333665776998, 0.1667818528949283, 0.15025383821921423, 0.07028063540928997, 0.1177387528878171, 0.20371851307572797, 0.09736130727105774, 0.1491199404699728, 0.1264155947137624, 0.1598382747033611, 0.09342561650555581, 0.10724900756031275, 0.08326278722961433, 0.2276829513721168, 0.09643043144023977, 0.07361441472312436, 0.07831724869902246, 0.16316845460096374, 0.2184943319298327, 0.13813565019518137], [0.021899182320339605, 0.03995640712673776, 0.023650545081181917, 0.029497861687559634, 0.05042089716880582, 0.03743628883967176, 0.046181148500181735, 0.03784624008403625, 0.0316113349981606, 0.03292616464023013, 0.02105127859977074, 0.06565344854607247, 0.023199445458885748, 0.055674234026810154, 0.014239828669815324, 0.04038035898702219, 0.029418027006613556, 0.019771231563936453, 0.011807890514319297, 0.013833367374900263, 0.06571891339262947, 0.07234632183099166, 0.04579891647154, 6.859066570177674, 55.22765010595322, 58.2383843511343, 54.41443674266338, 42.48572163283825, 35.75183317065239, 19.49701599776745, 26.665430143475533, 27.41252515465021, 38.03327254951, 41.39141455292702, 4.0196846053004265, 0.24732166319154203, 0.016255119553534314, 0.10322969901608303, 0.0987756997346878, 0.36593874043319374, 1.8027379782870412, 4.417974958196282, 7.315879482775927, 7.116084778681397, 6.276767291128635, 21.388696990907192, 39.975545927882195, 42.37643949687481, 58.55856657028198, 48.993317037820816, 49.18370962142944, 62.4311363697052, 61.26249007880688, 57.41137012839317, 58.78278873860836, 60.08517645299435, 61.819293200969696, 60.234383046627045, 57.98094056546688, 55.98075449466705, 56.22206434607506, 53.64522501826286, 56.75346203148365, 56.547817066311836, 56.332877799868584, 55.6768012046814, 55.42655423283577, 52.10953742265701, 57.02708154916763, 54.95694123208523, 57.05041229724884, 57.22761198878288, 55.31397387385368, 55.874793380498886, 55.78949175775051, 53.90823170542717, 58.22894565761089, 54.565987810492516, 51.74150437116623, 48.10519069433212, 47.54261188209057, 45.52063778042793, 47.29942873120308, 44.721449464559555, 52.15727426111698, 53.84722977876663, 61.92191429436207, 38.443555533885956, 46.14563584327698, 61.74806982278824, 48.74414540827274, 49.26223620772362, 53.14918823540211, 59.44004327058792, 54.20172415673733, 58.13589625060558, 53.74739393591881, 46.42579101026058, 41.317417323589325, 46.01611599326134, 52.26845629513264, 56.2907874584198, 56.90558306872845, 57.30009309947491, 53.375709280371666, 56.76457643508911, 54.75341655313969, 41.83388561010361, 46.33852109313011, 58.22921924293041, 58.030653297901154, 54.55197416245937, 52.56990171968937, 58.44499446451664, 59.38017748296261, 58.739976435899734, 54.51212950050831, 52.14119732379913, 51.77919074892998, 48.75503182411194, 52.08015739917755, 55.1289352029562, 56.390376314520836, 59.58630122244358, 59.70407210290432, 60.41781820356846, 52.50076822936535, 31.990118622779846, 8.148541152477264, 4.883680818602443, 5.964904725551605, 7.870472073554993, 3.461858625523746, 1.612870004028082, 0.6053307338152081, 0.012430078368197428, 0.1333438846631907, 0.026166587122133933, 1.2459882907569408, 14.834014512598515, 55.73231242597103, 76.14947944879532, 92.07690238952637, 61.92029558122158, 19.983260706067085, 23.327172473073006, 38.33432279527187, 49.47087921202183, 58.116483092308044, 43.67059305310249, 1.8214946030639112, 0.017392826375726145, 0.021700377656088676, 0.026715967505879235, 0.04805565025890246, 0.04685392021201551, 0.03426113245950546, 0.040258294247905724, 0.08066374153713696, 0.006185927977639949, 0.017820501961978152, 0.017108058746089227, 0.06561168047483079, 0.09052249806700274, 0.058835586460190825, 0.03221227052563336, 0.022502633728436194, 0.04604877161909826, 0.033504357052152045, 0.01701569290162297, 0.04160781929385848, 0.022207372130651493, 0.018105896706401836, 0.047658296971349046, 0.016014930879464373, 0.03427039075177163, 0.009664078206697013, 0.05692969927622471, 0.07687090677791275, 0.015378538319055224, 0.030770752564421855, 0.061385142034851015, 0.05361131581594236, 0.01340137063380098, 0.035894870379706845, 0.046166335232555866, 0.05120044537761714, 0.06600846973014995, 0.022417218096961733, 0.001088351682483335, 0.02322784002899425, 0.08990229267510585, 0.049036454074666835, 0.05819434860313777, 0.045921864366391674, 0.029344329886953346, 0.039364369949907996, 0.04339449900726322, 0.061471772933145985, 9.046490918844938, 64.84154462814331, 66.03000685572624, 62.10889846086502, 48.50869104266167, 43.65356236696243, 23.961871415376663, 29.01580162346363, 33.8580109924078, 35.3397186845541, 39.7471933811903, 5.283323423936963, 0.32147530757356435, 0.0517493266670499, 0.24768135248450562, 0.5133197992108762, 2.7160374959930778, 5.032116053625941, 10.530981961637735, 8.672989010810852, 6.737917670980096, 7.705997424200177, 19.033516868948936, 30.83619274199009, 41.20414540171623, 57.7116984128952, 53.750760555267334, 53.63675907254219, 62.91686050593853, 61.723276153206825, 61.068286299705505, 59.74670581519604, 61.316580176353455, 61.61609150469303, 62.46235929429531, 60.23877181112766, 56.98252893984318, 56.10148161649704, 54.579948261380196, 56.6535159945488, 56.82007625699043, 56.0523996502161, 54.64028142392635, 56.74054652452469, 53.450021892786026, 57.020181119441986, 56.27179227769375, 57.643689662218094, 58.46560075879097, 56.95503741502762, 56.601025611162186, 57.42527358233929, 55.623246878385544, 59.90801475942135, 56.19366466999054, 53.72416578233242, 49.96710978448391, 51.3785782456398, 49.15029801428318, 51.129824593663216, 46.09138995409012, 54.36435543000698, 56.151110753417015, 65.3002180159092, 40.23082382977009, 48.81508760154247, 63.2562430948019, 52.3821309953928, 51.09882205724716, 54.925972893834114, 59.59200471639633, 55.94488441944122, 60.45726388692856, 56.96415312588215, 48.95958624780178, 42.96763837337494, 48.00972081720829, 54.25823472440243, 58.67997385561466, 59.038701206445694, 58.64320322871208, 54.86872136592865, 59.44254353642464, 57.82490573823452, 44.550287649035454, 49.97472457587719, 60.92578634619713, 58.99813838303089, 55.27254469692707, 52.88092643022537, 57.28948786854744, 61.46045185625553, 61.447129771113396, 56.93149007856846, 55.596785098314285, 54.978942051529884, 50.99742449820042, 53.01271475851536, 56.51638515293598, 60.320307835936546, 60.67234754562378, 62.607241719961166, 63.52750673890114, 52.774098962545395, 31.950935125350952, 10.385331977158785, 4.141459045931697, 5.8565943874418736, 7.376190796494484, 6.019197162240744, 5.320720542222261, 1.5216192067600787, 0.11969947736361064, 0.04585853690514341, 0.018929164834844414, 1.1585564073175192, 17.550863027572632, 61.07022799551487, 80.41877076029778, 97.2081546485424, 67.71140903234482, 21.92450623959303, 28.68921484798193, 43.76729026436806, 56.356854513287544, 64.46025028824806, 51.85526646673679, 3.1764523778110743, 0.028679137358267326, 0.10133952309843153, 0.025491525884717703, 0.03337957605253905, 0.03361214286996983, 0.13258423714432865, 0.03460666528553702, 0.0465467972389888, 0.11372516630217433, 0.04495256383961532, 0.05098903347970918, 0.0830233258602675, 0.12439329424523748, 0.03756295489438344, 0.023899713742139284, 0.07255085030919872, 0.03514000229188241, 0.014765561445528874, 0.04483509670535568, 0.03643097559688613, 0.01360795671644155, 0.021452808323374484, 0.07864517407142557, 0.0362988324923208, 0.04245931500918232, 0.13710304076084867, 0.1586482854327187, 0.31168029410764575, 0.05172218632651493, 0.11637732750386931, 0.24349181010620669, 0.19324697263073176, 0.10025093346484937, 0.11528855975484475, 0.17062850820366293, 0.13635835493914783, 0.1883947369060479, 0.15549089235719293, 0.1288351000403054, 0.18890857027145103, 0.14323559997137636, 0.23566108342492953, 0.15722616721177474, 0.19606898917118087, 0.12154836760601029, 0.13866374763892964, 0.2532939630327746, 0.15529790427535772, 14.556652195751667, 76.92710772156715, 74.60109293460846, 72.09585696458817, 56.50781661272049, 50.70990152657032, 30.07464900612831, 35.852029994130135, 38.44441048800945, 51.30512438714504, 56.224598810076714, 6.66322935372591, 0.4620691586751491, 0.08842301424010657, 0.3209063474787399, 0.3284240362700075, 2.2037299862131476, 5.880524078384042, 14.595484212040901, 18.605671226978302, 17.49572418630123, 15.794723611325026, 27.946873381733894, 41.957040801644325, 46.152904853224754, 63.74274238944054, 58.18001188337803, 55.47236457467079, 63.07105243206024, 66.13148421049118, 63.68931345641613, 62.61146329343319, 62.50227615237236, 64.27235037088394, 65.2264715731144, 62.977585047483444, 59.121023789048195, 57.82946549355984, 57.42406904697418, 57.9185327142477, 56.40386179089546, 56.367368549108505, 56.34948670864105, 56.580514311790466, 54.340690299868584, 58.32506150007248, 57.94323518872261, 58.556484282016754, 60.20369589328766, 58.02502579987049, 57.58808724582195, 59.857667461037636, 56.46987184882164, 62.17925168573856, 59.687398597598076, 55.711804926395416, 53.68623621761799, 54.165671691298485, 50.76375983655453, 51.79160088300705, 48.89875151216984, 56.277499571442604, 60.7303324341774, 67.46016651391983, 43.31967428326607, 50.206850320100784, 66.52310639619827, 55.02968452870846, 53.177150934934616, 58.977106511592865, 60.55512383580208, 56.9968655705452, 60.56228645145893, 58.7095058709383, 51.36858098208904, 44.7255190461874, 51.30649991333485, 56.28027722239494, 61.83157414197922, 62.06319831311703, 61.808478981256485, 57.600292190909386, 62.39317260682583, 59.405814707279205, 46.48216858506203, 52.71191529929638, 64.02139663696289, 61.96844279766083, 54.90041546523571, 53.74769791960716, 59.427492544054985, 64.4463050365448, 63.01506623625755, 59.75311607122421, 58.4261778742075, 57.114807441830635, 54.27434206008911, 55.77509433031082, 59.96938146650791, 62.720570638775826, 65.55285885930061, 64.54113274812698, 66.7192442715168, 57.979580238461494, 38.0280402302742, 12.944178320467472, 12.113855425268412, 13.277047108858824, 17.20253001898527, 12.682563308626413, 5.139586161822081, 1.2605676334351301, 0.1242523975088261, 0.18822509679012, 0.1023679987702053, 1.8412578175775707, 22.626243084669113, 69.44130420684814, 79.02911692857742, 98.37247297167778, 70.98487257957458, 30.217641033232212, 35.79033650457859, 51.50294177234173, 63.755654096603394, 70.8755524456501, 60.96918001770973, 5.04005097784102, 0.09221575994160958, 0.2359978255117312, 0.08913125318940729, 0.09387615951709449, 0.07816520490450785, 0.25380117644090205, 0.1780700674862601, 0.18621398048708215, 0.17995792790316045, 0.11906534928129986, 0.08933504694141448, 0.12643679045140743, 0.34497823391575366, 0.19414221053011715, 0.09829456539591774, 0.1397042683674954, 0.2302568085724488, 0.10457485652295873, 0.10602329130051658, 0.1243308350967709, 0.11712529361830093, 0.14257246133638546, 0.1959095906931907, 0.12020282418234274, 0.148326376802288], [0.07346712067374028, 0.012256818426976679, 0.033230122353415936, 0.013901323054597015, 0.023196128058771137, 0.02321052386832889, 0.05665463337209076, 0.015562352527922485, 0.012593944575201022, 0.023737001574772876, 0.021850135635759216, 0.02566566898167366, 0.04416914533067029, 0.01585217789397575, 0.06683093262836337, 0.005859353314008331, 0.07961922063259408, 0.006814559528720565, 0.03779901351663284, 0.009391777730343165, 0.02347545017983066, 0.03875774586049374, 0.13057466450845823, 27.764196284115314, 63.74278798699379, 59.571299627423286, 51.55533716082573, 43.81101451814175, 23.673584684729576, 21.93309187889099, 44.90077704191208, 39.39928025007248, 50.797217041254044, 13.733294326812029, 0.3518970392178744, 0.024074970060610212, 0.03363121235452127, 0.09529487128020264, 0.423220043303445, 0.4807474126573652, 4.289752738550305, 6.62966575473547, 3.67503906134516, 7.496563112363219, 12.232420463114977, 38.33467237651348, 51.864845752716064, 52.90860794484615, 47.19473294913769, 53.141546845436096, 65.608069896698, 58.368808552622795, 57.93720491230488, 57.65845187008381, 57.33046866953373, 53.28028120100498, 52.86486469209194, 56.3384635001421, 57.93975077569485, 59.93276663124561, 57.57120095193386, 56.950025483965874, 53.87485809624195, 57.11402088403702, 59.238984659314156, 59.07431669533253, 56.76449663937092, 56.885858327150345, 57.30084925889969, 54.773969650268555, 55.82530103623867, 53.12564089894295, 54.720890298485756, 54.09795552492142, 53.484991416335106, 54.70188371837139, 57.45721086859703, 53.90081450343132, 51.41844190657139, 47.065004110336304, 46.43639624118805, 45.978323221206665, 49.69088740646839, 44.762593656778336, 51.34473726153374, 51.750813871622086, 60.731084793806076, 37.14742228388786, 47.64815881848335, 61.32684342563152, 48.76284420490265, 46.7956555634737, 51.38093791902065, 57.78949923813343, 54.3978164345026, 58.13490450382233, 54.38172809779644, 48.55737783014774, 41.032565608620644, 42.625417336821556, 45.64148269593716, 52.304238975048065, 56.834724470973015, 56.499400064349174, 50.72982005774975, 56.59500293433666, 52.1895345300436, 41.3312865793705, 47.86187835037708, 58.23136992752552, 56.37725181877613, 56.21044456958771, 51.42996668815613, 54.52994294464588, 58.729128018021584, 58.46891038119793, 53.806226179003716, 48.71198393404484, 48.22663977742195, 48.11025582253933, 51.44065551459789, 50.89757725596428, 54.637838155031204, 57.0592088252306, 59.71728399395943, 62.48307578265667, 61.965345963835716, 47.5836306810379, 20.18859028816223, 7.102864813059568, 7.095023933798075, 6.702721109613776, 4.650393286719918, 1.4481588173657656, 0.9618198859971017, 0.04303503235860262, 0.028189570366521366, 0.1369181420886889, 0.050652295103645884, 5.025758994743228, 24.407198019325733, 42.48864747583866, 42.959016636013985, 25.853702500462532, 25.764781571924686, 30.941910669207573, 39.718041345477104, 41.175540536642075, 47.003683000802994, 48.705619275569916, 7.388307396322489, 0.10682373467716388, 0.04597246770572383, 0.025340361535199918, 0.027325354240019806, 0.01812458212953061, 0.10426664259284735, 0.020781387320312206, 0.06771326457965188, 0.017039530684996862, 0.05119490895594936, 0.0242845618413412, 0.019309589733893517, 0.03396913074539043, 0.05594295827904716, 0.04505598953983281, 0.009233963737642625, 0.05896939568629023, 0.05105845026264433, 0.0067682689950743224, 0.03476926613075193, 0.015830503471079282, 0.044356641519698314, 0.12164304338512011, 0.09766513510840014, 0.018633285399118904, 0.01718481165880803, 0.023153183683461975, 0.056272546062245965, 0.015099462962098187, 0.062038332180236466, 0.027896756000700407, 0.00994898777207709, 0.029935992279206403, 0.03716960549354553, 0.014933128186385147, 0.016464540640299674, 0.024178694475267548, 0.014090194072196027, 0.021942078456049785, 0.023304110545723233, 0.015567653317702934, 0.1219321544340346, 0.048329966593883, 0.055021908483467996, 0.0485667117027333, 0.012688627775787609, 0.05224404972977936, 0.4574208799749613, 33.38089719414711, 73.64264756441116, 66.28180414438248, 57.61700749397278, 50.75583726167679, 31.27459231764078, 25.699062198400497, 34.85731936991215, 31.019707694649696, 47.685241028666496, 15.66091189160943, 0.2616689511341974, 0.03957471686589997, 0.12797621253412217, 0.2133102819789201, 1.2649831152521074, 4.60072947666049, 7.976928111165762, 9.296834785491228, 5.692504942417145, 8.665528111159801, 14.979300666600466, 34.594753459095955, 48.796506598591805, 54.256053641438484, 52.320334911346436, 54.684393256902695, 64.3539547920227, 60.869864746928215, 60.11533163487911, 59.782891273498535, 59.426728785037994, 57.20609754323959, 56.58754013478756, 58.00894506275654, 57.55775727331638, 61.113443076610565, 57.05005891621113, 56.73734329640865, 55.617117807269096, 58.36016781628132, 60.301658436656, 58.857165947556496, 56.28618970513344, 55.97996033728123, 55.94141900539398, 54.53742854297161, 55.776177272200584, 54.891527742147446, 56.67482145130634, 54.67025801539421, 55.925292670726776, 56.01657897233963, 58.1903625279665, 56.08215965330601, 53.17633017897606, 47.8692651540041, 49.909919053316116, 47.975287064909935, 50.43883927166462, 47.502493634819984, 53.14031571149826, 54.01148356497288, 63.47254268825054, 38.75423826277256, 50.099327489733696, 62.331300526857376, 51.28903605043888, 48.95950265228748, 54.260864183306694, 60.33538542687893, 54.25065793097019, 59.355349615216255, 57.20270052552223, 50.88626906275749, 43.38963232934475, 44.98147711157799, 46.97613067924976, 54.59626458585262, 58.79472769796848, 58.12724411487579, 52.53552496433258, 58.04309383034706, 54.5131516456604, 43.52715075016022, 50.13455159962177, 60.01371368765831, 58.86675663292408, 55.9936586022377, 52.51760512590408, 56.464552134275436, 61.84725970029831, 61.06042072176933, 56.650753542780876, 50.67780464887619, 49.63280752301216, 51.92705601453781, 54.50966723263264, 54.989585280418396, 55.956386402249336, 60.023053586483, 62.18942753970623, 64.19063195586205, 63.870742321014404, 47.92907014489174, 20.488766580820084, 6.080108368769288, 5.376591794192791, 7.633207105100155, 7.267623972147703, 7.358862776309252, 3.2365976879373193, 0.851092521334067, 0.14510437235003337, 0.07054006797261536, 0.023397710210701916, 5.209566056728363, 28.80491103976965, 53.664220198988914, 62.526530250906944, 36.60167656838894, 30.10737854987383, 34.570632353425026, 43.77224139869213, 47.16533772647381, 53.588125482201576, 58.557506427168846, 10.39510315284133, 0.0781670528522227, 0.06493847831734456, 0.03640276656369679, 0.023486897807742935, 0.018401395791443065, 0.0676023357664235, 0.02445649148285156, 0.05337214759492781, 0.03929050770238973, 0.06209190411027521, 0.04310637501475867, 0.06765230456949212, 0.03315437505079899, 0.024418706889264286, 0.021825012081535533, 0.006719897201037384, 0.010698021651478484, 0.06678826655843295, 0.010782127392303664, 0.004631090096154367, 0.05251592068816535, 0.024204209512390662, 0.021448771040013526, 0.053610299073625356, 0.0387406913068844, 0.16807025094749406, 0.16580276715103537, 0.17489689635112882, 0.07775988837238401, 0.16008089762181044, 0.10472273686900735, 0.1249145416659303, 0.09717490946059115, 0.06423499653465115, 0.12352314835879952, 0.10265607823384926, 0.19842291832901537, 0.13980402785819024, 0.12173072813311592, 0.17089556262362748, 0.08541654431610368, 0.18992045894265175, 0.13903244660468772, 0.16241910809185356, 0.08560787740861997, 0.10571166349109262, 0.25061528489459306, 0.916236819466576, 41.40357010066509, 82.71364241838455, 75.63784450292587, 68.24118420481682, 59.330077171325684, 35.38104146718979, 32.88090482354164, 62.063437700271606, 51.07874393463135, 65.49602910876274, 20.740786157548428, 0.589083933737129, 0.133220985007938, 0.5263136175926775, 0.2026476088212803, 1.1187948659062386, 6.875711577013135, 14.374273382127285, 14.092896580696106, 11.425651554018259, 18.20854503661394, 16.06066469103098, 43.42344671487808, 53.27666379511356, 55.045408084988594, 56.334868893027306, 57.615650966763496, 65.78802824020386, 65.17127573490143, 62.72435903549194, 63.42571400105953, 61.926952823996544, 58.00004594027996, 58.18970896303654, 61.91906824707985, 61.48639686405659, 63.403412997722626, 59.131416231393814, 57.74251475930214, 54.83606591820717, 58.87885518372059, 62.52767778933048, 59.93674121797085, 58.088691383600235, 57.59221762418747, 56.67639456689358, 55.132541209459305, 56.945275738835335, 55.785627365112305, 56.48846045136452, 55.15052564442158, 56.151369139552116, 57.67008684575558, 60.62239542603493, 59.19024087488651, 55.535593181848526, 53.72501313686371, 52.140444964170456, 50.72887770831585, 53.60218092799187, 49.54238757491112, 54.92815017700195, 55.84833540022373, 65.21240472793579, 41.877625063061714, 51.722026616334915, 65.32957524061203, 52.68066957592964, 51.28289557993412, 56.20179623365402, 61.93681329488754, 55.72486102581024, 63.517900854349136, 60.575555339455605, 54.2104484885931, 45.13207823038101, 46.3382551074028, 48.68625931441784, 58.34601357579231, 60.908341482281685, 59.94925394654274, 56.02893590927124, 61.08195796608925, 58.14108297228813, 45.669984966516495, 51.995798125863075, 62.606975734233856, 60.57728424668312, 57.17393606901169, 52.920383512973785, 57.450663819909096, 65.03256797790527, 64.63048115372658, 59.7429022192955, 53.06449078023434, 52.95442208647728, 54.4556987285614, 57.29445420205593, 57.1652003377676, 59.63211536407471, 62.887039706110954, 66.3427072763443, 68.06013911962509, 67.09499850869179, 50.96875123679638, 24.288517087697983, 14.029566328972578, 17.305455096065998, 15.25874337181449, 11.99382271617651, 11.660407707095146, 2.730146376416087, 0.5190487043000758, 0.20133056386839598, 0.470080494415015, 0.163479087932501, 7.515137465670705, 36.67882762849331, 55.42397417128086, 52.07840949296951, 37.5095846503973, 37.06527829170227, 44.05652694404125, 52.64179766178131, 55.514967888593674, 61.845310404896736, 68.15966337919235, 14.322756696492434, 0.28209042095113546, 0.14184263331117108, 0.0657626407337375, 0.14604830997996032, 0.09290314454119653, 0.1947458734503016, 0.07542166305938736, 0.1123627761262469, 0.11497175917611457, 0.10779308344353922, 0.1595428999280557, 0.2026796102290973, 0.22701813548337668, 0.13529674237361178, 0.13307484128745273, 0.10347270785132423, 0.1780864392640069, 0.1317603641655296, 0.10569054938969202, 0.08553228224627674, 0.09691199622466229, 0.12849941180320457, 0.14017674926435575, 0.16965354880085215, 0.13866022985894233], [0.052915485575795174, 0.02708063846512232, 0.030224678448576014, 0.028100011695642024, 0.04396355558128562, 0.06700140394968912, 0.06647191868978553, 0.035226291802246124, 0.05015048081986606, 0.07671472922083922, 0.03006109796842793, 0.01550700593725196, 0.05315604532370344, 0.024328838371729944, 0.01213004661622108, 0.018699501670198515, 0.053479543785215355, 0.070303293177858, 0.03995346080046147, 0.05191617630771361, 0.0925361599365715, 0.03195718694769312, 0.751534360460937, 37.92654387652874, 64.18715134263039, 64.55124780535698, 43.70333589613438, 31.7068400233984, 26.405550688505173, 41.26241147518158, 53.67110162973404, 49.78910073637962, 33.4929683804512, 1.7938358872197568, 0.08076652156887576, 0.042698546312749386, 0.09112650237511843, 0.5175230861641467, 2.0450436137616634, 5.664073443040252, 8.626296166330576, 8.926282469183207, 4.187570996582508, 10.352477040141821, 42.7248428016901, 52.52949468791485, 57.408679872751236, 45.06001129746437, 55.80364979803562, 60.88106654584408, 58.801168352365494, 58.828044310212135, 56.55467949807644, 51.993655040860176, 52.18879736959934, 49.598776549100876, 53.0866663902998, 50.73155656456947, 55.14340862631798, 56.050704941153526, 60.33721312880516, 55.21712467074394, 57.883555591106415, 56.77097909152508, 55.564209446311, 56.47025942802429, 60.123599991202354, 56.10448345541954, 54.842897951602936, 53.646710738539696, 55.26456132531166, 53.89362908899784, 52.27936550974846, 52.6889493316412, 53.819027692079544, 55.39046756923199, 56.8337669223547, 53.130774423480034, 49.9544108659029, 45.146726444363594, 47.78966322541237, 46.322831735014915, 51.1382145434618, 46.907126381993294, 51.51263885200024, 51.369542330503464, 61.24946817755699, 37.47961185872555, 49.88242752850056, 59.46846954524517, 49.478106424212456, 45.430438220500946, 51.8633334338665, 56.66199713945389, 55.41121065616608, 56.08266122639179, 55.09628735482693, 51.04600869119167, 43.8075453042984, 39.62403059005737, 44.88532707095146, 48.953939750790596, 52.60984517633915, 53.37022617459297, 55.66009730100632, 57.11896061897278, 47.22493752837181, 40.210361927747726, 48.05275350809097, 56.645281836390495, 57.43357993662357, 50.93022130429745, 49.84565310180187, 56.008572801947594, 56.740329936146736, 58.187520280480385, 50.94044655561447, 44.56836327910423, 47.95505695044994, 51.02704770863056, 53.53494733572006, 56.98490001261234, 59.683135226368904, 61.134178563952446, 61.03159926831722, 60.151976868510246, 61.2163757532835, 56.34422779083252, 43.1649199873209, 16.927947252988815, 5.072796670719981, 4.081664029508829, 4.366167113184929, 8.769924659281969, 3.1789448065683246, 0.8669897995423526, 0.05387979144870769, 0.036368865257827565, 0.15432061452884227, 0.12031522244797088, 17.022104300558567, 32.434835359454155, 17.71344680339098, 23.210893012583256, 18.350313529372215, 36.81674122810364, 42.99347698688507, 54.6266021579504, 50.374710112810135, 50.62486208975315, 19.15567271411419, 0.27274298190604895, 0.05692457845725585, 0.04326262678659987, 0.020182039988867473, 0.03736424485396128, 0.008432372815150302, 0.02671135876880726, 0.05549853798584081, 0.02795304975734325, 0.024386720324400812, 0.04566388270177413, 0.07450387871358544, 0.07211339136119932, 0.04189956496702507, 0.02655134430824546, 0.036953336239093915, 0.029747651897196192, 0.04369978887552861, 0.023362512001767755, 0.04296423889172729, 0.06302223075181246, 0.01755094464897411, 0.021523110117414035, 0.13601241022115573, 0.03939613758120686, 0.034339584890403785, 0.015840516898606438, 0.04662652616389096, 0.02863533951313002, 0.1253905106568709, 0.04060945997480303, 0.016461466293549165, 0.02712177756620804, 0.06690830152365379, 0.06646220397669822, 0.03231841619708575, 0.09447213378734887, 0.04834923274756875, 0.012315198546275496, 0.03616538320784457, 0.011933038877032232, 0.035748863956541754, 0.02411928740912117, 0.03870617401844356, 0.03760882333153859, 0.05024544232583139, 0.025638001716288272, 1.3831672235392034, 47.338426038622856, 73.20133924484253, 71.11390605568886, 51.46216996014118, 40.06683222949505, 29.456292986869812, 38.14383901655674, 53.72064337134361, 47.831403985619545, 37.28342838585377, 2.1759781753644347, 0.11388398590497673, 0.09485751623287797, 0.23291245044674724, 1.091963555663824, 4.812013814225793, 5.919433040544391, 6.2372855097055435, 6.669848123565316, 6.070969384163618, 16.723204739391804, 38.56238275766373, 50.10399363934994, 57.504404336214066, 49.26529124379158, 57.15502828359604, 60.75761117041111, 61.780721470713615, 60.750095173716545, 57.93831825256348, 55.68946972489357, 56.51616096496582, 52.040191143751144, 56.128771752119064, 52.93756239116192, 56.654009968042374, 56.289206743240356, 61.99252590537071, 57.36236035823822, 58.353081196546555, 59.09840740263462, 57.43957981467247, 59.16533701121807, 61.5435191988945, 58.09167042374611, 53.9372393488884, 53.778046891093254, 55.379197373986244, 54.643917828798294, 53.26160900294781, 53.54770705103874, 54.94256280362606, 55.04162348806858, 58.44196982681751, 53.409117087721825, 51.507311537861824, 47.37428851425648, 49.513839706778526, 48.95616643130779, 51.236712858080864, 48.43715988099575, 53.13781164586544, 54.01358105242252, 64.44505110383034, 39.9712635576725, 51.78389489650726, 61.1945079267025, 51.79948166012764, 48.07676061987877, 54.662639424204826, 59.22313570976257, 54.76782537996769, 57.9102985560894, 57.636907026171684, 52.859104201197624, 45.30617728829384, 41.51972606778145, 47.169673293828964, 51.74071401357651, 55.10177806019783, 54.41247224807739, 56.69172674417496, 58.63564923405647, 49.11742217838764, 42.940211445093155, 50.868554413318634, 59.31087680160999, 58.42101015150547, 52.98697113990784, 51.012171506881714, 56.97376661002636, 60.560188964009285, 58.537097722291946, 52.54753232002258, 47.11657494306564, 51.03713616728783, 51.60421393811703, 56.81017778813839, 61.29611827433109, 62.50430144369602, 61.82896748185158, 63.01106125116348, 62.55616866052151, 62.69055224955082, 58.932892084121704, 40.698229148983955, 17.90427066385746, 3.8530003745108843, 6.675153588876128, 9.307076185941696, 7.234373381361365, 7.799134701490402, 2.6793431024998426, 0.36719350435305387, 0.026073865046782885, 0.18695223930990323, 0.15168845420703292, 17.750378921628, 35.468539372086525, 20.31151369214058, 24.702005200088024, 22.677730321884155, 36.84418335556984, 45.515709444880486, 56.84309542179108, 58.62448923289776, 59.16615016758442, 25.592219531536102, 0.22130239609396085, 0.03687148477183655, 0.06199752519023605, 0.021378677047323436, 0.04741434931929689, 0.027680243692884687, 0.046389020353672095, 0.05524680149392225, 0.08444623075774871, 0.04894372272246983, 0.00840150132717099, 0.06402692801202647, 0.059361954699852504, 0.028994754211453255, 0.0482641900453018, 0.020443576540856156, 0.03457415179582313, 0.03744709822058212, 0.0641062858630903, 0.010834767927008215, 0.014040610258234665, 0.009666074583947193, 0.016834770285640843, 0.07624586258316413, 0.04095639545994345, 0.18812615366186947, 0.14176717173540965, 0.11138035071780905, 0.10098404178279452, 0.22688294586259872, 0.21994451817590743, 0.1978905312716961, 0.1322315982542932, 0.12355149840004742, 0.19919656275305897, 0.11355718117556535, 0.20747143513290212, 0.07653543376363814, 0.11867684981552884, 0.12405327186570503, 0.1195172949519474, 0.11610566434683278, 0.12022933369735256, 0.1253257508506067, 0.1528033529757522, 0.2075690423953347, 0.16670699988026172, 2.782238256186247, 57.64057382941246, 82.13732734322548, 81.15919902920723, 59.6601502597332, 44.227578565478325, 37.51191392540932, 51.56006410717964, 63.505980893969536, 62.89560824632645, 45.564217641949654, 2.837440031580627, 0.15278481412678957, 0.2499889419414103, 0.2580394927645102, 1.3719132961705327, 4.582938831299543, 11.159530933946371, 16.111006289720535, 19.822280444204807, 14.867217130959034, 16.577531956136227, 46.00231513381004, 54.881674870848656, 59.32888403534889, 50.733255073428154, 60.55971018970013, 60.290183052420616, 65.20317882299423, 62.3496725410223, 61.81928560137749, 56.968310102820396, 59.92479845881462, 53.91376420855522, 59.59580071270466, 55.903656631708145, 60.45070543885231, 59.74254883825779, 64.50323358178139, 58.10541048645973, 60.40035434067249, 62.552874237298965, 60.53427815437317, 61.76931068301201, 63.169189766049385, 58.37945178151131, 54.295902103185654, 53.45899321138859, 55.959677025675774, 54.257527962327, 53.30172725021839, 54.08041946589947, 56.68029695749283, 57.64991372823715, 60.55743031203747, 56.08621023595333, 54.27036367356777, 50.52261337637901, 53.644240871071815, 50.63893273472786, 56.28212012350559, 51.950341165065765, 56.678313463926315, 56.145338863134384, 66.37827336788177, 43.17185081541538, 54.25421454012394, 65.10389015078545, 54.266662672162056, 51.01435258984566, 57.20589615404606, 62.44844824075699, 57.96552859246731, 59.17047433555126, 60.915526896715164, 56.589310839772224, 49.55912187695503, 43.839972764253616, 50.229421108961105, 54.38908450305462, 55.93434378504753, 57.8377528488636, 59.1639918833971, 61.382198855280876, 51.97372891008854, 45.47335311770439, 51.79071173071861, 62.65676066279411, 61.98195867240429, 52.58840672671795, 52.1573730558157, 58.42015139758587, 61.32199488580227, 61.7143390327692, 54.32069577276707, 49.19607795774937, 53.74574102461338, 55.13780392706394, 60.08002012968063, 62.729788944125175, 65.91812565922737, 66.05152130126953, 64.38100174069405, 64.1731908917427, 63.240534737706184, 58.52873437106609, 45.64208686351776, 22.50099040567875, 10.98656041547656, 11.916006691753864, 13.308633863925934, 19.73190039396286, 13.18640012294054, 3.9173746202141047, 0.21052246360341087, 0.2434650037321262, 0.35314387700054795, 0.20632253115763888, 24.321145936846733, 47.14874401688576, 28.797474838793278, 35.476127564907074, 26.86095055192709, 49.22520339488983, 55.79048730432987, 66.71723797917366, 65.46464279294014, 67.7472411096096, 30.71268606930971, 0.6967217079363763, 0.32499267195817083, 0.15881749510299414, 0.11856313794851303, 0.10477653515408747, 0.07903326535597444, 0.13668976840563118, 0.16104310692753643, 0.1541426029871218, 0.20073200692422688, 0.13204886665334925, 0.18522468279115856, 0.09509021663689055, 0.14515253773424774, 0.1471495977602899, 0.10542766583967023, 0.10500513148144819, 0.09729759389301762, 0.13991419225931168, 0.1141812012065202, 0.14782996906433254, 0.11777146675740369, 0.13361408578930423, 0.2133024448994547, 0.10400810060673393], [0.0468810123129515, 0.037340080525609665, 0.04762130090966821, 0.026190048265561927, 0.034622588063939475, 0.023660643855691887, 0.018334123815293424, 0.037121239729458466, 0.044276437620283104, 0.03130345503450371, 0.030405929464905057, 0.052955891806050204, 0.07941050644149072, 0.08801081799902022, 0.005035895937908208, 0.028666057005466428, 0.0859068070712965, 0.01627570301934611, 0.04136580493650399, 0.01588141665706644, 0.06267745862714946, 0.038023657907615416, 14.679063577204943, 66.35593056678772, 64.95236948132515, 57.70377963781357, 52.85457104444504, 30.78302789479494, 24.5103282853961, 38.690922260284424, 55.215608552098274, 41.37307293713093, 10.85595477372408, 0.08684113388881087, 0.02555991850385908, 0.08026520823477767, 0.08683930078404956, 0.8830175176262856, 4.128346424549818, 4.443258326500654, 4.948806948959827, 8.783537428826094, 13.479432798922062, 44.000293761491776, 52.602819353342056, 61.6950436681509, 50.77923260629177, 56.648462265729904, 57.605300322175026, 57.32644468545914, 62.2503686696291, 53.65948185324669, 52.92982220649719, 53.83376330137253, 52.240147814154625, 47.82427176833153, 47.5306311249733, 47.122776210308075, 50.06848454475403, 55.913175120949745, 57.01154038310051, 57.660222575068474, 56.296023577451706, 51.698410883545876, 53.33401791751385, 54.66971084475517, 54.69796232879162, 56.87916688621044, 56.732046380639076, 53.90533626079559, 55.910766050219536, 53.06547112762928, 53.645912781357765, 49.94064040482044, 54.24343831837177, 55.083653032779694, 55.695424005389214, 50.584021881222725, 48.48544768989086, 43.630205020308495, 47.41258665919304, 45.93511953949928, 49.644499495625496, 45.323101580142975, 50.91146171092987, 51.04878254234791, 60.50478793680668, 36.29771187901497, 47.097420170903206, 57.50554047524929, 49.85627353191376, 42.17929467558861, 46.976362466812134, 57.6245728880167, 53.26637014746666, 55.92200204730034, 56.39899805188179, 54.97174143791199, 46.88987910747528, 42.98678554594517, 40.888230353593826, 45.94325490295887, 47.664676532149315, 52.35826827585697, 52.499890476465225, 49.17311578989029, 41.619812697172165, 41.06438510119915, 46.56726881861687, 55.405146181583405, 54.9541711807251, 54.3888983130455, 50.64103402197361, 55.9423803538084, 57.500691935420036, 54.87595997750759, 49.773631766438484, 43.33583101630211, 45.24473458528519, 53.72108414769173, 57.56901226937771, 58.281667828559875, 58.929582461714745, 61.88685357570648, 61.384805515408516, 60.884786546230316, 58.03001493215561, 60.652277022600174, 55.928370505571365, 41.148759573698044, 17.179706543684006, 6.951371217146516, 6.227748971432447, 3.682829118333757, 4.922310495749116, 1.8975065555423498, 0.41130210156552494, 0.06080481965909712, 0.015958779986249283, 0.04202797506877687, 2.396747278980911, 33.63558992743492, 54.8368676751852, 38.459959253668785, 30.775658190250397, 43.435746654868126, 36.97027198970318, 32.692776918411255, 47.21531264483929, 58.922241255640984, 35.82427628338337, 1.2305589811876416, 0.04001238361524884, 0.06686868568067439, 0.009889672546705697, 0.0058668791552918265, 0.028177094864076935, 0.10191193417995237, 0.04792484673089348, 0.09526664740405977, 0.057320269334013574, 0.042135326730203815, 0.0319455055432627, 0.03122679489024449, 0.08384106127778068, 0.05718257496482693, 0.029580852351500653, 0.026883464670390822, 0.0729880495055113, 0.07897355957538821, 0.05724705275497399, 0.08129173205816187, 0.009695171411294723, 0.007091114830473089, 0.07058787712594494, 0.028517590362753253, 0.0713949924102053, 0.060472682598629035, 0.06599779022508301, 0.05374028994992841, 0.04303910674934741, 0.027518372007762082, 0.02703187750739744, 0.015097945270099444, 0.08627297531347722, 0.02482210868038237, 0.04212085113977082, 0.08282656766823493, 0.01869215255283052, 0.07262436745804735, 0.06210632032889407, 0.04724326943687629, 0.016146689922607038, 0.03964954761613626, 0.06312841724138707, 0.06324712376226671, 0.09866356122074649, 0.07873405367718078, 18.53922039270401, 75.60235440731049, 72.55298003554344, 64.7783388197422, 59.30361919105053, 35.343051105737686, 31.706992015242577, 39.84471894800663, 56.476152911782265, 44.1931714117527, 12.15013587847352, 0.0938384881010279, 0.06636679347138852, 0.04301493871025741, 0.7972979173064232, 1.922099667135626, 4.629451660439372, 8.0355285666883, 6.63293500430882, 7.33079225756228, 14.153951704502106, 40.62758333981037, 53.01013469696045, 62.83584125339985, 54.80209954082966, 56.73196278512478, 58.82002294063568, 58.95879149436951, 62.54911623895168, 57.03647084534168, 55.729990750551224, 55.08720204234123, 54.46254216134548, 50.27534544467926, 49.64337095618248, 48.923890963196754, 52.04335257411003, 58.38377594947815, 59.510081112384796, 59.002557545900345, 58.10957506299019, 54.99974213540554, 54.53712835907936, 56.76747187972069, 57.06682741641998, 58.977174907922745, 56.34998068213463, 53.40779095888138, 54.84148822724819, 53.70218016207218, 56.046099588274956, 51.1208076775074, 55.24362064898014, 54.291391745209694, 60.57405821979046, 53.80635157227516, 50.9563335031271, 45.42528949677944, 50.742104798555374, 47.995258793234825, 53.02674360573292, 47.70549774169922, 53.346466049551964, 53.812682032585144, 61.999156549572945, 38.54283280670643, 50.14278195798397, 60.3707767277956, 50.19754081964493, 44.00742597877979, 50.664387568831444, 60.88882952928543, 53.98961953818798, 55.943231508135796, 57.105494141578674, 57.606235072016716, 48.349525183439255, 46.00299909710884, 43.54579254984856, 46.633674055337906, 51.719659343361855, 55.060003101825714, 54.87088344991207, 50.334827452898026, 44.28649440407753, 41.69013172388077, 47.21743293106556, 58.4710306674242, 57.30530261993408, 54.90761987864971, 51.30917116999626, 55.79379312694073, 60.05974821746349, 57.79974728822708, 51.572630032896996, 45.091606602072716, 48.579416647553444, 55.813916847109795, 60.123721584677696, 60.21671399474144, 61.91922023892403, 61.60181187093258, 62.99154929816723, 61.984056159853935, 62.980647683143616, 61.931645572185516, 58.72199200093746, 40.495890006423, 17.38612286746502, 4.072839478030801, 2.8775630285963416, 6.440146649256349, 9.113474674522877, 9.6106200478971, 2.981787398457527, 0.21859103377209976, 0.029486349121725652, 0.19006079906830564, 3.03384009283036, 35.65782241523266, 44.245270416140556, 35.504804626107216, 27.434679865837097, 49.623387828469276, 45.51885947585106, 39.75478917360306, 50.91467633843422, 66.99469149112701, 45.56407704949379, 2.5267748767510056, 0.03292469889856875, 0.013388279148784932, 0.016599852715444285, 0.009126234508585185, 0.0534642629645532, 0.08415376520133577, 0.06552599210408516, 0.07420714580803178, 0.0031396262920679874, 0.022052138956496492, 0.023786608580849133, 0.023318023959291168, 0.05416921048890799, 0.10972258576657623, 0.01617656507733045, 0.044367636437527835, 0.08589741890318692, 0.06709812805638649, 0.0495905341085745, 0.06147942447569221, 0.004763665501741343, 0.012764023485942744, 0.060405963522498496, 0.03680069130496122, 0.22463944827904925, 0.2177084717550315, 0.1745478346128948, 0.17259441287023947, 0.12610974081326276, 0.11668552659102716, 0.10653307996108197, 0.10317338485037908, 0.1136185642099008, 0.11555212608072907, 0.1483203802490607, 0.23822138900868595, 0.19079469406278804, 0.21232674334896728, 0.11057902418542653, 0.10047095056506805, 0.1914494761149399, 0.09923923775204457, 0.16373631631722674, 0.1408509013708681, 0.2039989855256863, 0.21097778604598716, 22.303374409675598, 88.49605053663254, 80.20817086100578, 74.16086375713348, 68.60276520252228, 43.657954931259155, 35.53421124815941, 50.440138801932335, 64.2263576388359, 53.14106427133083, 15.920582357794046, 0.2047049906104803, 0.27101698389742523, 0.1411709451349452, 0.8332220208831131, 2.645665272139013, 10.442035384476185, 13.4934426471591, 14.035345818847418, 20.00686503946781, 22.265385948121548, 51.266925036907196, 54.20922115445137, 65.28369650244713, 56.080400347709656, 56.860707476735115, 59.0959869325161, 61.25884987413883, 66.59851714968681, 59.367740750312805, 58.2039999961853, 58.89140211045742, 57.567097172141075, 54.0960556268692, 52.200899720191956, 50.58882862329483, 56.460862532258034, 60.65115988254547, 61.72999419271946, 60.28532311320305, 60.05352795124054, 57.355444729328156, 57.26337946951389, 58.83168451488018, 59.56635229289532, 61.69726274907589, 58.01745280623436, 53.834910839796066, 55.50824224948883, 54.28672939538956, 55.98110027611256, 51.86924211680889, 57.04575754702091, 57.892405316233635, 60.725305303931236, 56.32830284535885, 52.15920075774193, 48.73282961547375, 53.67709770798683, 51.87404125928879, 54.54359941184521, 49.58901487290859, 54.28579844534397, 56.03626571595669, 63.57360206544399, 40.879715010523796, 52.44716830551624, 62.96440355479717, 53.69261607527733, 44.66349497437477, 51.758504658937454, 63.47567372024059, 56.51300333440304, 58.29846292734146, 61.53292536735535, 60.297778844833374, 50.76772302389145, 47.61568956077099, 46.34943030774593, 49.60680931806564, 53.22372883558273, 57.80192457139492, 56.385409981012344, 53.131967559456825, 45.88926360011101, 44.83646549284458, 50.483597069978714, 61.4394997805357, 59.36812072992325, 55.71065738797188, 50.5695104598999, 58.81982535123825, 61.59253276884556, 60.32445341348648, 53.69782939553261, 47.635592892766, 50.59873089194298, 59.004434645175934, 62.477326691150665, 62.63405308127403, 61.53706334531307, 64.85108211636543, 65.65548375248909, 64.5929391682148, 62.68996708095074, 64.13941830396652, 58.892314061522484, 43.942008689045906, 21.870579533278942, 12.878397200256586, 14.970620982348919, 12.107247579842806, 15.324058067053556, 6.237033773213625, 2.050081668421626, 0.1681828050641343, 0.14091356832068413, 0.27566306584049016, 3.753979825414717, 47.17007987201214, 72.2673037648201, 51.08404844999313, 40.90804249048233, 56.17541044950485, 49.23024192452431, 46.69360063970089, 61.841544806957245, 74.03369218111038, 55.07323399186134, 3.889156384393573, 0.14085251925280318, 0.11436921689892188, 0.10414860400487669, 0.1517979209893383, 0.1892953331116587, 0.3600744082359597, 0.1144665273022838, 0.18298079929081723, 0.10785325677716173, 0.14253979199565947, 0.11706484569003806, 0.07343902296270244, 0.145988003059756, 0.2782231190940365, 0.132809508650098, 0.14459847996477038, 0.225925590202678, 0.19997967698145658, 0.13087303756037727, 0.22081844159401953, 0.1153178745880723, 0.08494816749589518, 0.16392798337619752, 0.10621234599966556], [0.015949959561112337, 0.03400858702661935, 0.022665314354526345, 0.018760574857878964, 0.037375403044279665, 0.02518335462809773, 0.048616910571581684, 0.031166922126431018, 0.03548241438693367, 0.07169573291321285, 0.04949052970914636, 0.011624249782471452, 0.025139397221209947, 0.012163603751105256, 0.10004233059589751, 0.04719688891782425, 0.029329481367312837, 0.07102886869688518, 0.035996592851006426, 0.08348192859557457, 0.036610864772228524, 0.021243400224193465, 29.2164346575737, 59.77901928126812, 56.90081052482128, 52.21458658576012, 36.305281072854996, 28.581712916493416, 26.211202517151833, 36.44571773707867, 42.89304457604885, 30.182572714984417, 2.9367441404610872, 0.01166805597677012, 0.04846884839935228, 0.18082483060425147, 0.5914760835003108, 1.5444385260343552, 6.649849321693182, 5.904364949092269, 3.945783320814371, 10.11824430897832, 34.88293759524822, 55.171181336045265, 65.40924176573753, 55.537394285202026, 62.54993699491024, 60.34527629613876, 56.86799168586731, 61.61338225007057, 58.11563953757286, 55.8082627505064, 48.92745517194271, 48.90195094048977, 49.54076126217842, 46.860787868499756, 47.549888491630554, 45.400818809866905, 46.81761458516121, 51.657901257276535, 56.44229672849178, 55.976236537098885, 53.118341490626335, 48.878870978951454, 45.811888352036476, 49.795833975076675, 54.348666071891785, 54.36852000653744, 58.734504729509354, 56.32426366209984, 51.444816291332245, 55.20072855055332, 53.677751272916794, 52.687402814626694, 56.635831743478775, 54.161032140254974, 54.37031351029873, 49.607675671577454, 47.69895449280739, 42.817261442542076, 46.77350275218487, 46.54948577284813, 49.66927796602249, 45.75323469936848, 51.42192631959915, 51.35762996971607, 60.867368280887604, 36.033455058932304, 47.21116326749325, 61.222854405641556, 48.26404117047787, 44.49618615210056, 44.058347046375275, 57.65074588358402, 54.589474350214005, 55.74217289686203, 53.29977035522461, 52.181623354554176, 48.52567233145237, 44.688778817653656, 42.5879817456007, 42.78649069368839, 41.73900470137596, 45.56656591594219, 44.89824637770653, 42.642862200737, 41.03668078780174, 40.46486847102642, 44.66809272766113, 52.250661849975586, 56.41696348786354, 56.27499170601368, 51.02868162095547, 56.606170535087585, 57.63985946774483, 58.604745492339134, 50.57228051126003, 46.07317753136158, 47.776686921715736, 53.17974619567394, 57.91362337768078, 61.308433413505554, 56.51395708322525, 58.53732571005821, 58.96439239382744, 58.09741571545601, 58.84323209524155, 60.326129123568535, 60.49998499453068, 60.3648566454649, 40.168214589357376, 26.483879685401917, 6.128792306408286, 4.570468375459313, 7.34043993987143, 4.688999690115452, 2.698495974764228, 0.26846209599170834, 0.03632192070654128, 0.14865643955999985, 0.023201540170703083, 9.866686407476664, 31.06055550277233, 43.54662090539932, 34.198605716228485, 37.90027968585491, 31.092726476490498, 38.759687170386314, 48.9291612803936, 48.79511587321758, 55.72726629674435, 12.49976746737957, 0.1316885242704302, 0.06219120346941054, 0.05124678136780858, 0.014485640967905056, 0.04174386980594136, 0.0031687518776379875, 0.033150133676826954, 0.04620941690518521, 0.01239259527210379, 0.020946992008248344, 0.048993097807397135, 0.020767639034602325, 0.01603689288458554, 0.05452943041746039, 0.060469680611277, 0.02793437917716801, 0.04972749746229965, 0.08207543258322403, 0.06967499095480889, 0.0456259329803288, 0.01963496582902735, 0.023979205179784913, 0.051147648991900496, 0.03431112723774277, 0.0684175627247896, 0.07425096962833777, 0.02742255703196861, 0.04133125054067932, 0.09341354918433353, 0.035758630619966425, 0.025483449462626595, 0.03849988293950446, 0.04227543679007795, 0.06550384641741402, 0.09819700266234577, 0.0419394850905519, 0.021242737857392058, 0.027977919125987682, 0.012440288464858895, 0.027255083987256512, 0.07205873218481429, 0.022222818079171702, 0.01393015734720393, 0.03562842452083714, 0.03410511075344402, 0.22214367985725403, 35.71465976536274, 70.67047744989395, 64.10781919956207, 59.91716846823692, 43.98746185004711, 38.016287460923195, 25.253739394247532, 32.736903950572014, 44.98503752052784, 31.150236390531063, 3.169339634478092, 0.051627529101097025, 0.08652407355839387, 0.4822578316088766, 1.224378019105643, 5.124731808900833, 8.058024309575558, 6.492876894772053, 5.634235544130206, 12.26119726896286, 36.28120556473732, 54.6525813639164, 65.73179885745049, 59.25588995218277, 62.63569459319115, 60.31886011362076, 57.478257939219475, 62.54934802651405, 61.22961804270744, 56.87138490378857, 51.03141747415066, 51.27770885825157, 51.57945066690445, 48.85451428592205, 50.66730201244354, 47.651274651288986, 49.190921634435654, 53.096534460783005, 57.110741659998894, 58.05009685456753, 55.96205189824104, 51.439344584941864, 47.727962136268616, 53.27593803405762, 56.62318982183933, 57.00009539723396, 60.35443000495434, 56.527879536151886, 51.68401725590229, 54.222182258963585, 55.14944650232792, 55.03011390566826, 57.50987984240055, 56.29040747880936, 56.23117245733738, 52.345117181539536, 50.96706032752991, 44.550340846180916, 49.58991542458534, 49.47704628109932, 53.104776218533516, 48.39934431016445, 53.34275744855404, 53.202567771077156, 64.40990298986435, 37.276531755924225, 48.70266303420067, 61.367885023355484, 51.43229976296425, 45.94452403485775, 46.483726501464844, 58.77472937107086, 55.12013487517834, 55.93716323375702, 56.75855755805969, 55.505202412605286, 50.903318747878075, 46.995923817157745, 44.11295011639595, 45.527234226465225, 45.6137365847826, 48.47108066082001, 46.501752734184265, 44.61367964744568, 41.607926934957504, 42.61347837746143, 46.278788298368454, 54.94545824825764, 58.911582827568054, 55.85665315389633, 51.09830528497696, 57.037253603339195, 58.879322558641434, 61.90791964530945, 52.86939024925232, 47.29057140648365, 49.71463233232498, 54.60278883576393, 60.7877017557621, 62.216786071658134, 57.70178094506264, 58.05925816297531, 61.42297066748142, 59.98861223459244, 61.994706988334656, 62.80566707253456, 63.29290732741356, 63.4936885535717, 43.403965160250664, 21.60804782062769, 2.8557298751547933, 4.081312548369169, 5.905846394598484, 12.476867996156216, 6.923852618783712, 2.9949330305680633, 0.05753140663728118, 0.06574813916813582, 0.02595693225885043, 11.301060989499092, 33.41148555278778, 41.01554252207279, 31.271662674844265, 41.801306158304214, 34.22892048954964, 42.371891140937805, 58.702742233872414, 54.46810886263847, 65.94277113676071, 18.059444837272167, 0.10123997140908614, 0.05746187482145615, 0.040417900527245365, 0.02495800519682234, 0.05571421352215111, 0.045043877689749934, 0.027228145881963428, 0.07681776158278808, 0.035319245798746124, 0.04506906247115694, 0.03804892061452847, 0.03917185684258584, 0.04661949060391635, 0.05926196514337789, 0.07526053537731059, 0.062404385389527306, 0.027691774812410586, 0.024190340627683327, 0.033435730656492524, 0.008159232784237247, 0.006471858459917712, 0.05862495752808172, 0.03394875137018971, 0.06634595396462828, 0.09489469783147797, 0.19160505995387211, 0.13260914362035692, 0.13709121092688292, 0.20124497939832509, 0.1700012301444076, 0.09312320617027581, 0.15172948013059795, 0.16262146207736805, 0.20900399977108464, 0.21002549183322117, 0.12746611959300935, 0.14437141246162355, 0.16247012332314625, 0.20730302698211744, 0.19545970077160746, 0.14121750748017803, 0.23173666588263586, 0.11123550575575791, 0.16794604511233047, 0.1266975811449811, 0.5648008023854345, 44.79159750044346, 79.11259844899178, 72.59440541267395, 68.72644856572151, 50.572231113910675, 40.17890341579914, 37.61936075985432, 49.35489423573017, 53.35171356797218, 41.32400617003441, 4.460937352851033, 0.26764653506688774, 0.2774647035403177, 0.5872795649338514, 1.5883602504618466, 6.5062265284359455, 15.946345925331116, 11.473904214799404, 12.42885947227478, 14.819270353764296, 40.70444941520691, 57.33915500342846, 70.5578362941742, 61.52564115822315, 65.14932051301003, 62.200511544942856, 59.98394228518009, 63.925649374723434, 63.77920523285866, 60.39319172501564, 54.45986710488796, 53.79522196948528, 55.57661198079586, 50.1902262121439, 52.67123468220234, 50.5730214715004, 52.82593198120594, 56.55531406402588, 60.16931913793087, 61.85792572796345, 58.029505759477615, 53.4077225625515, 49.41611275076866, 55.05394622683525, 59.442661330103874, 59.82414945960045, 64.4308702647686, 57.68070347607136, 51.68336749076843, 55.59589974582195, 55.772670060396194, 56.06938473880291, 61.06164425611496, 58.180076479911804, 58.26861172914505, 53.85100297629833, 52.31650851666927, 45.573196560144424, 53.08974042534828, 51.75180561840534, 55.27421660721302, 50.18929146230221, 57.183272168040276, 55.08412040770054, 65.15529379248619, 40.84826409816742, 52.16141223907471, 64.2718032002449, 53.40445093810558, 49.109416007995605, 49.49759937822819, 61.51194669306278, 57.95352503657341, 57.555040419101715, 58.56368489563465, 57.507311180233955, 53.72893452644348, 48.63749273121357, 46.43569327890873, 47.71452605724335, 46.82259611785412, 50.56279242038727, 49.257148280739784, 46.46215505897999, 43.722517266869545, 43.53150151669979, 48.9579713344574, 58.226547986269, 61.58134236931801, 57.489516735076904, 52.439967691898346, 59.42574463784695, 61.29118613898754, 63.94059017300606, 55.167940109968185, 50.592605620622635, 52.02230170369148, 58.276359513401985, 63.536003082990646, 64.87415447831154, 59.81941871345043, 60.421914383769035, 63.26254315674305, 63.05675379931927, 64.38583508133888, 64.4336973130703, 65.35754173994064, 63.997647911310196, 43.97206887602806, 29.42347414791584, 12.662200201302767, 11.43517479300499, 18.445884101092815, 19.75370742380619, 6.040701633319259, 0.9687017917167395, 0.12716739031020552, 0.3528208943316713, 0.14668943651486188, 15.780688114464283, 46.39267198741436, 57.53154627978802, 47.45384864509106, 47.11569719016552, 42.57265716791153, 51.12534083425999, 66.44823521375656, 61.21906600892544, 73.27414333820343, 22.207706943154335, 0.2769314852776006, 0.4353231063578278, 0.13363446516450495, 0.1098243564774748, 0.16227381041971967, 0.12469252076698467, 0.1969121431466192, 0.28319725999608636, 0.11611950540100224, 0.12172609713161364, 0.16206676606088877, 0.0847437948687002, 0.14329102355986834, 0.18569189443951473, 0.28910858498420566, 0.1441181471454911, 0.1702267094515264, 0.16642691334709525, 0.15503714326769114, 0.10912438505329192, 0.072756261943141, 0.20678537897765636, 0.09365819816594012, 0.13308353925822303], [0.10125174929271452, 0.016950415447354317, 0.031028209159558173, 0.02767356621916406, 0.03685048570332583, 0.042517881593084894, 0.028586730695678852, 0.0187809727867716, 0.05812088340462651, 0.027896683641301934, 0.0032542609733354766, 0.038088759101810865, 0.01716001093882369, 0.05580161996476818, 0.02898017472034553, 0.02229814235761296, 0.0888631003908813, 0.05849908557138406, 0.046400404899031855, 0.07406956647173502, 0.0775867527408991, 3.266979195177555, 40.988077595829964, 61.221216693520546, 53.993362337350845, 35.945987552404404, 25.135111659765244, 19.731244929134846, 35.42720898985863, 51.689956337213516, 46.667974814772606, 16.087382957339287, 0.07299339296878316, 0.03703515059896745, 0.08049341864534654, 0.14556711626937613, 1.383374312426895, 1.8988531082868576, 2.556913672015071, 5.478684240952134, 10.28378052636981, 35.610476955771446, 54.86855797469616, 66.42525404691696, 57.31731377542019, 58.07732619345188, 60.392492562532425, 62.48942144215107, 58.08970972895622, 56.92384868860245, 60.55707313120365, 51.60349577665329, 46.58622220158577, 48.632078021764755, 49.172948598861694, 48.59732128679752, 47.34465390443802, 43.94085355103016, 44.68899920582771, 46.7842485755682, 51.47173784673214, 51.44318997859955, 52.265503853559494, 45.558088570833206, 42.111874893307686, 45.67488670349121, 53.12210328876972, 52.30044297873974, 55.46909675002098, 57.43392951786518, 55.27306146919727, 51.1876080930233, 52.73218721151352, 51.74314208328724, 55.80884791910648, 54.06408794224262, 53.07881221175194, 49.11140330135822, 47.64966353774071, 41.81040666997433, 46.22123658657074, 47.16725282371044, 51.641326546669006, 48.450394570827484, 52.592844888567924, 51.924468353390694, 61.02433405816555, 33.74037690460682, 43.3712375164032, 58.81143160164356, 48.441845029592514, 43.98250691592693, 40.392121374607086, 54.73270766437054, 54.268843755126, 53.753317818045616, 52.553391605615616, 57.93300613760948, 50.074423626065254, 49.24126133322716, 42.65509754419327, 41.37020029127598, 41.76623784005642, 41.91364713013172, 40.06389498710632, 42.82215557992458, 41.99312746524811, 41.7240297049284, 43.60312767326832, 52.29050271213055, 55.366867035627365, 55.957397148013115, 49.539324939250946, 53.88460457324982, 58.02946396172047, 56.45986318588257, 50.28785437345505, 43.18031296133995, 45.46054020524025, 52.378183007240295, 56.7747712880373, 56.06802821159363, 59.399434849619865, 58.99081237614155, 58.73564086854458, 57.29266069829464, 59.27727900445461, 58.458951115608215, 59.002352356910706, 57.2094451636076, 60.58357670903206, 38.87236252427101, 13.806187715381384, 3.377592684701085, 6.21175610460341, 20.365493595600128, 7.923152921721339, 3.0102644953876734, 0.13477789208991453, 0.07249771995702758, 0.20902197458781302, 0.9475551545619965, 19.821668677031994, 42.12121859192848, 40.435621440410614, 47.37223282456398, 48.377472683787346, 34.83547054231167, 32.25849822163582, 49.02958229184151, 56.40417717397213, 37.06028915941715, 1.4112090063281357, 0.03377839137101546, 0.19975214934675023, 0.05241890343313571, 0.048930349221336655, 0.08349242256372236, 0.020579814445227385, 0.03591669323213864, 0.06465241749538109, 0.0628396772663109, 0.005496125368154026, 0.05054563363955822, 0.02345422290090937, 0.0347046473325463, 0.01854990881838603, 0.024799261664156802, 0.033840653850347735, 0.025681107508717105, 0.07913395995274186, 0.04596067497914191, 0.0020693118131021038, 0.02357619858230464, 0.02577051032858435, 0.01343260762951104, 0.04387392269563861, 0.041132299302262254, 0.050531250817584805, 0.003626770403570845, 0.0833570102986414, 0.05095983367937151, 0.04730655608000234, 0.03587611630791798, 0.009780874624993885, 0.025500088413537014, 0.023617250481038354, 0.04869924443482887, 0.06555064624990337, 0.0753123001777567, 0.0371341122809099, 0.059512106017791666, 0.09503826629952528, 0.06791938867536373, 0.07369134575128555, 0.01486410474171862, 0.09333278867416084, 4.417710397392511, 49.853518679738045, 70.61455965042114, 61.25337436795235, 43.32144878804684, 34.10893812775612, 28.206255063414574, 33.69492754340172, 48.85336294770241, 50.55839225649834, 17.905792482197285, 0.25796195317525417, 0.07744662041659467, 0.06562425987794995, 0.5944248440209776, 2.1445631235837936, 6.8022144958376884, 7.139862002804875, 5.913638826459646, 11.340899951756, 34.01169374585152, 55.42477212846279, 67.08881244063377, 61.09041251242161, 60.81347957253456, 64.13187950849533, 62.36171789467335, 58.698190078139305, 57.90646456182003, 62.399199083447456, 54.91329677402973, 48.85886885225773, 49.713845774531364, 51.73824414610863, 50.76847158372402, 49.80693317949772, 46.97917811572552, 46.329511776566505, 49.772396832704544, 53.47156673669815, 55.29697358608246, 55.21497018635273, 46.99409231543541, 44.63906988501549, 47.8479178994894, 54.14722368121147, 55.611072331666946, 57.529281601309776, 58.013478219509125, 53.559570014476776, 51.738027557730675, 53.36697354912758, 53.35866339504719, 58.179597705602646, 55.95186464488506, 56.281797140836716, 50.304368287324905, 50.52726812660694, 44.190473556518555, 48.71548354625702, 49.7554649412632, 54.26124796271324, 49.60000388324261, 55.32157726585865, 53.40837612748146, 64.6746575832367, 36.12112395465374, 45.55733621120453, 61.19715258479118, 51.247633472085, 46.78540751338005, 43.69831636548042, 55.50432845950127, 56.2509123980999, 55.70144668221474, 53.8397441804409, 59.48760911822319, 52.92976140975952, 50.02398893237114, 43.94853673875332, 42.687414810061455, 44.24775168299675, 45.02921015024185, 42.37458139657974, 45.9261292219162, 43.44334624707699, 42.74638384580612, 45.35066910088062, 53.94180670380592, 56.42369292676449, 57.905689403414726, 50.85970848798752, 55.26169627904892, 59.181383550167084, 58.77205431461334, 53.21782775223255, 46.17288798093796, 47.13564611971378, 55.134634897112846, 60.64815804362297, 59.109996780753136, 60.863777473568916, 60.42443364858627, 61.1662944406271, 60.03921411931515, 61.95260904729366, 60.05841448903084, 61.74835480749607, 58.79926845431328, 61.23145334422588, 42.57547281682491, 17.881327494978905, 4.499101554974914, 7.161567388102412, 13.897459767758846, 10.948574803769588, 7.1260174456983805, 0.3085432358784601, 0.17567491944646463, 0.11545725734322332, 1.1466020112857223, 21.74591962248087, 42.00753629207611, 37.60060876607895, 54.4087028503418, 50.42599216103554, 40.151886865496635, 38.62544037401676, 52.568423599004745, 63.39417949318886, 44.995813742280006, 2.546612899750471, 0.04480198949750047, 0.1252342588850297, 0.030624588434875477, 0.06722805585013703, 0.05183100001886487, 0.0560135291016195, 0.021091280359541997, 0.0995681130734738, 0.014159799175104126, 0.01844293194153579, 0.05191210191696882, 0.029815751368005294, 0.047992560284910724, 0.12078590734745376, 0.01501815419032937, 0.09497871636995114, 0.07085482764523476, 0.0921986905450467, 0.07743280162685551, 0.022827078428235836, 0.011486020139273023, 0.023819365123927128, 0.046254053377197124, 0.1808093790896237, 0.14678149251267314, 0.09138612789683975, 0.110898771090433, 0.1928762550232932, 0.17612005962291732, 0.1575820567086339, 0.12144585474743508, 0.17821413319325075, 0.0638286855246406, 0.15730827843071893, 0.1807822016417049, 0.18501162703614682, 0.22664734366117045, 0.15595421515172347, 0.09480108332354575, 0.23546545329736546, 0.3429310640785843, 0.213968240423128, 0.18642348877619952, 0.1974537773639895, 6.694872155785561, 61.56496524810791, 76.91009983420372, 69.88765105605125, 50.102678909897804, 40.344544127583504, 30.796277783811092, 49.37395401299, 65.83140671253204, 60.01356169581413, 23.923919051885605, 0.34836426784750074, 0.17014023440424353, 0.3267474059248343, 0.5320268485229462, 4.0943054761737585, 8.131669107824564, 7.371215438470244, 13.976935353130102, 15.908780191093683, 38.77478376030922, 59.78563852608204, 70.51314309239388, 63.27779173851013, 65.2750937640667, 65.88021889328957, 65.00481426715851, 61.43189258873463, 60.477919578552246, 65.53471103310585, 56.7623383551836, 50.535623878240585, 52.798710241913795, 54.11332570016384, 53.06741662323475, 52.09599494934082, 49.07232999801636, 50.008447766304016, 52.231993451714516, 56.815345510840416, 57.39080183207989, 57.01042324304581, 49.94863897562027, 46.097047850489616, 49.56436559557915, 57.886660024523735, 57.42735207080841, 60.220859572291374, 61.05535939335823, 55.24580933153629, 51.29493333399296, 53.547897040843964, 54.146942496299744, 59.499798864126205, 58.95500309765339, 56.748894676566124, 53.24280381202698, 52.997295185923576, 46.76800064742565, 51.02474503219128, 52.428819090127945, 56.420501098036766, 53.197293654084206, 57.25112892687321, 56.0031732916832, 66.87580347061157, 38.1785349547863, 47.90971778333187, 62.96908490359783, 54.440111964941025, 48.073344603180885, 44.6783559769392, 58.03991340100765, 59.17292520403862, 58.34938399493694, 55.28532721102238, 60.872273817658424, 56.21057376265526, 51.22855469584465, 47.007912173867226, 45.00871405005455, 45.923948138952255, 46.9224813580513, 44.85732637345791, 46.58604361116886, 45.66084265708923, 46.729098334908485, 48.73203545808792, 56.585625037550926, 59.3782813847065, 59.33559827506542, 51.20700605213642, 55.79232260584831, 62.726984694600105, 61.26076877117157, 56.7589945346117, 48.311424627900124, 49.4798619300127, 57.504746317863464, 62.03818425536156, 60.22918872535229, 63.73637393116951, 65.17128333449364, 64.03823733329773, 62.209026888012886, 65.89727997779846, 62.977406457066536, 64.28257182240486, 61.25148966908455, 63.33627440035343, 43.03364843130112, 18.952799700200558, 7.989712525159121, 14.519007615745068, 37.80689209699631, 15.214450098574162, 6.5143875405192375, 0.2116409395239316, 0.262224463513121, 0.1910874416353181, 1.141336562577635, 30.562111549079418, 59.66433383524418, 52.8319850564003, 54.085381999611855, 58.77522334456444, 51.23895473778248, 48.253131955862045, 64.15159285068512, 67.35711604356766, 52.12231233716011, 2.7755076298490167, 0.10806047182995826, 0.28611544403247535, 0.12302239163545892, 0.1881249959114939, 0.15703341661719605, 0.06899564381456003, 0.11693506632582285, 0.22176764847245067, 0.12369118543574587, 0.14057937922189012, 0.1576171602937393, 0.12463782448321581, 0.17387534491717815, 0.24507099646143615, 0.11962441654759459, 0.1656618926790543, 0.1657319365767762, 0.2147194868302904, 0.12830492458306253, 0.08588789714849554, 0.1728705214918591, 0.19112474197754636, 0.11522159576998092], [0.026519858693063725, 0.03223616768082138, 0.01117761046771193, 0.023200428804557305, 0.01621304349100683, 0.03357242683705408, 0.11957372786127962, 0.09317108211689629, 0.0034303990560147213, 0.07045998281682841, 0.013395112473517656, 0.08111865579849109, 0.029156549826439004, 0.04155774287937675, 0.11213882564334199, 0.0726545209181495, 0.04913717093586456, 0.02855351773177972, 0.03468391172646079, 0.03672162660222966, 0.03560193727025762, 3.6435066908597946, 44.908217042684555, 57.74428926408291, 54.922097101807594, 50.827429220080376, 22.055352218449116, 20.091370604932308, 37.94973023235798, 35.8351095020771, 35.60018330812454, 4.674275480210781, 0.019400807104830164, 0.035621311035356484, 0.02600732223072555, 0.3000594489276409, 0.48588975390885025, 7.255828455090523, 7.548313960433006, 6.326706111431122, 26.36459458619356, 48.48398856818676, 62.686011493206024, 58.36595110595226, 57.099946439266205, 56.61343954503536, 57.7585157006979, 61.595618203282356, 55.73761694133282, 58.851059675216675, 58.281728625297546, 56.07759229838848, 44.84655775129795, 45.85454486310482, 49.364560917019844, 51.200276613235474, 48.7317580729723, 46.64682894945145, 44.154569283127785, 42.87266626954079, 47.21303276717663, 49.6565942466259, 48.18293072283268, 43.17936681210995, 41.82095870375633, 46.11788593232632, 46.67330212891102, 52.79643036425114, 52.58067414164543, 58.03452908992767, 54.60592366755009, 52.04874828457832, 52.745072320103645, 53.52667137980461, 57.00881592929363, 52.48065210878849, 50.689386427402496, 47.063263803720474, 43.60367864370346, 40.56436613202095, 43.817436173558235, 46.36022172868252, 51.444884687662125, 46.64672635495663, 52.17687740921974, 51.980439350008965, 61.36676408350468, 36.52685098350048, 45.047521367669106, 59.436479061841965, 48.172766268253326, 47.444516345858574, 39.50579233467579, 48.51241484284401, 53.308091908693314, 53.659538850188255, 54.34302717447281, 55.27018882334232, 53.054748103022575, 49.58806112408638, 45.648546516895294, 44.298649951815605, 42.055364325642586, 44.53387252986431, 43.86934518814087, 44.798163548111916, 43.34632605314255, 42.897190153598785, 41.80010922253132, 47.72649921476841, 53.44634748995304, 54.73220229148865, 52.321398854255676, 50.087939500808716, 56.371776312589645, 56.30658321082592, 52.18842498958111, 43.905538246035576, 42.54719853401184, 44.26116496324539, 56.28883816301823, 58.60028073191643, 57.75274761021137, 57.16341823339462, 55.70893608033657, 55.263801366090775, 53.73416684567928, 55.178590938448906, 57.89678268134594, 57.80481241643429, 60.58975137770176, 59.791372418403625, 36.22196674346924, 11.801127456128597, 3.0137645825743675, 9.23923272639513, 9.121108464896679, 16.33963242173195, 1.1722766398452222, 0.09168845659587532, 0.023299991626117844, 0.08532371648470871, 3.7308210181072354, 33.61092545092106, 36.339452639222145, 14.430966340005398, 31.89908690750599, 29.040409103035927, 32.055049538612366, 47.664212957024574, 50.343753173947334, 53.136614710092545, 13.294441625475883, 0.14133694872725755, 0.10779957723570988, 0.0652912953228224, 0.06420566685847007, 0.023031220989651047, 0.06019001710228622, 0.057613625467638485, 0.07862305064918473, 0.03576344715838786, 0.05784559114545118, 0.06432898953789845, 0.06643399494350888, 0.007389775000774534, 0.020329988983576186, 0.005289531400194392, 0.0328193399036536, 0.056556031631771475, 0.0656065670773387, 0.06402761078788899, 0.024572639449615963, 0.046533145432476886, 0.03027687555004377, 0.038917790006962605, 0.018222835060441867, 0.03582208424631972, 0.09697062589111738, 0.03149368603772018, 0.04561986221233383, 0.05111775899422355, 0.07450538527336903, 0.06093713716836646, 0.02715369177167304, 0.0412334985594498, 0.03349673890625127, 0.019555008693714626, 0.08002879709238186, 0.017103038117056713, 0.051392746972851455, 0.051149508071830496, 0.009568220557412133, 0.008860552134137833, 0.052580843766918406, 0.018321952593396418, 0.007376550856861286, 6.152113080024719, 56.40889272093773, 66.22964814305305, 61.94318175315857, 57.402702793478966, 27.78836488723755, 22.805405370891094, 37.59708635509014, 42.78739124536514, 39.33933466672897, 5.823489613831043, 0.08154657072736882, 0.04756219626870006, 0.1546283534844406, 1.550110790412873, 5.510400664061308, 5.577051462605596, 7.154173459857702, 8.288314752280712, 27.694247737526894, 49.553722366690636, 65.72070345282555, 60.59963844716549, 60.72680622339249, 59.16523441672325, 59.80420432984829, 62.58339799940586, 57.47263044118881, 60.32862938940525, 60.98823979496956, 57.57261447608471, 46.78715921938419, 49.3481457978487, 52.25114822387695, 52.89709456264973, 52.64424093067646, 49.535867124795914, 46.56447596848011, 44.98983286321163, 50.271610245108604, 51.075217723846436, 49.4380109757185, 44.340926483273506, 43.990623280406, 49.52238544821739, 48.957386165857315, 53.266476541757584, 55.977171286940575, 59.67459328472614, 55.889437794685364, 51.203939616680145, 53.84905368089676, 55.11426039040089, 57.73851357400417, 54.350843355059624, 52.1367933601141, 48.347579687833786, 46.153832003474236, 43.4801434725523, 45.45094192028046, 47.14016407728195, 52.59512096643448, 50.387291237711906, 54.131560921669006, 53.08931104838848, 62.611166909337044, 39.00119461119175, 46.520386934280396, 62.02866956591606, 52.01055273413658, 47.81603381037712, 42.385893389582634, 49.632416144013405, 55.04606544971466, 56.967793330550194, 54.54974748194218, 56.25446520745754, 54.90754008293152, 51.57204486429691, 46.9891943782568, 45.8204834908247, 44.48749601840973, 48.27498458325863, 46.399861201643944, 46.54259294271469, 45.01172348856926, 44.18284356594086, 44.147820845246315, 50.46270199120045, 55.97784385085106, 57.80168138444424, 53.4554024040699, 50.41656866669655, 58.30573193728924, 58.51095512509346, 55.28472304344177, 45.60247018933296, 44.878521636128426, 46.73358969390392, 59.79187399148941, 60.05280219018459, 60.86637273430824, 59.37009662389755, 57.9859334975481, 56.979131922125816, 56.365765035152435, 56.47071920335293, 60.53521290421486, 60.98908334970474, 64.07003402709961, 61.3081294298172, 39.47534456849098, 10.246536824852228, 5.720726978033781, 8.87553334236145, 10.280672293156385, 10.62486732378602, 3.9158007921651006, 0.307336711557582, 0.06165952145238407, 0.1427176402648911, 4.573190454393625, 35.09278513491154, 37.79029458761215, 20.556792430579662, 35.43890856206417, 36.064772978425026, 39.53045301139355, 54.63053114712238, 54.841936603188515, 63.55113387107849, 19.01418350636959, 0.10117023921338841, 0.06214510867721401, 0.07620167511049658, 0.03567558429494966, 0.08000676272786222, 0.05052054904808756, 0.04990994704712648, 0.04480967814743053, 0.02717904353630729, 0.054910660546738654, 0.053837047453271225, 0.04421452395035885, 0.007761928200125112, 0.012110683983337367, 0.035146377340424806, 0.03998367363237776, 0.09185463088215329, 0.026359504699939862, 0.06197396942297928, 0.03321776559459977, 0.031619613655493595, 0.006853117347418447, 0.040176197871915065, 0.12667886418057606, 0.19774561951635405, 0.169847946963273, 0.32274357858113945, 0.17993573768762872, 0.13388197141466662, 0.34503763541579247, 0.17293994198553264, 0.13092788227368146, 0.10060141270514578, 0.08783658398897387, 0.12113464254071005, 0.14235167240258306, 0.112855985207716, 0.26710328296758235, 0.17010424024192616, 0.14607462653657421, 0.17822314286604524, 0.16455413337098435, 0.14654102182248607, 0.15811626944923773, 9.573419094085693, 68.07476833462715, 75.53966537117958, 71.57634884119034, 66.18024319410324, 35.634871646761894, 29.937706254422665, 52.05195531249046, 47.6063534617424, 48.01223628222942, 6.983450995758176, 0.14981285406975076, 0.16492675087647513, 0.3422323171980679, 1.1625344376079738, 5.310936542227864, 15.38610303774476, 15.28863636776805, 12.28288745507598, 30.07622592151165, 51.734615340828896, 67.1283607184887, 63.5791801661253, 63.47569651901722, 61.51738800108433, 60.18850810825825, 66.00607573986053, 58.2262098044157, 63.68538446724415, 63.072572350502014, 60.143073946237564, 49.51533682644367, 50.76182574033737, 55.28823025524616, 56.18346981704235, 53.43866050243378, 51.337574645876884, 48.214191645383835, 48.03067669272423, 52.373585253953934, 55.41810728609562, 52.70650438964367, 47.785475850105286, 45.44837325811386, 52.14087814092636, 51.328683122992516, 57.082520574331284, 57.850721552968025, 63.45237337052822, 56.55254781246185, 53.18141050636768, 54.4722506403923, 56.84720300137997, 61.64634548127651, 57.01983153820038, 54.16372999548912, 51.73683062195778, 47.9981542378664, 45.47489583492279, 48.07963706552982, 50.684043914079666, 54.091127291321754, 51.58303387463093, 56.081137508153915, 55.58307163417339, 64.70809578895569, 41.64557911455631, 49.82479602098465, 64.07996669411659, 53.22363764047623, 50.14644116163254, 44.93730068206787, 52.47113361954689, 57.74538740515709, 57.41004779934883, 57.1765199303627, 58.859575018286705, 57.953718826174736, 54.41481672227383, 49.166355952620506, 48.33974830806255, 46.51920899748802, 51.42065718770027, 47.67027363181114, 48.02286051213741, 48.06801728904247, 46.585488840937614, 46.47542394697666, 53.33301097154617, 58.749692514538765, 60.262193754315376, 53.82105678319931, 51.03652819991112, 59.683925583958626, 61.49050824344158, 56.803630739450455, 47.99380727112293, 46.75587549805641, 49.02154952287674, 61.59330412745476, 64.79067295789719, 62.84804619848728, 63.82078260183334, 60.632871463894844, 59.4645519554615, 59.1374047100544, 60.679031386971474, 63.030254021286964, 64.08459484577179, 64.09839570522308, 64.60539489984512, 38.91189180314541, 14.996730331331491, 7.797469440847635, 15.645515117794275, 25.554377362132072, 24.957366697490215, 3.681212542578578, 0.4974881565431133, 0.10866367461858317, 0.2989306126255542, 6.528130453079939, 48.08105818927288, 49.45317976176739, 21.843931563198566, 41.64559431374073, 41.576232835650444, 44.7819460183382, 61.45484335720539, 64.7517478466034, 69.92991998791695, 23.227585516870022, 0.3855252347420901, 0.2905755437677726, 0.15329582733102143, 0.10316510990378447, 0.1953713406692259, 0.17860713007394224, 0.11640339915174991, 0.22845904488349333, 0.11259369537583552, 0.19758452894166112, 0.10197791852988303, 0.08560909453080967, 0.09240436935215257, 0.079730164288776, 0.23374478390906006, 0.1439243575441651, 0.17249110591365024, 0.14500243094516918, 0.13112176093272865, 0.12962998473085463, 0.10874837593291886, 0.08877678861608729, 0.20215684140566736], [0.009591485031705815, 0.03454116333159618, 0.037345097443903796, 0.04245525175065268, 0.058599553813110106, 0.04101261314644944, 0.0351373268495081, 0.024989943522086833, 0.00623398946117959, 0.008693290601513581, 0.027170067260158248, 0.015304748430935433, 0.035672756712301634, 0.05725089336920064, 0.038997730443952605, 0.0510193279478699, 0.02146831735444721, 0.020700725144706666, 0.014415252899198094, 0.09652120352257043, 0.08840382230118848, 24.894941747188568, 61.0479573905468, 58.939040154218674, 48.84021185338497, 38.41685816645622, 28.441456742584705, 28.402928709983826, 39.17441211640835, 48.77233229577541, 25.809125192463398, 0.5125910695642233, 0.04256017658917699, 0.02171296076994622, 0.0603600171598373, 1.029402525164187, 3.478918047621846, 4.925906527787447, 9.692691843956709, 19.707539901137352, 42.5923553109169, 63.90030473470688, 63.25371243059635, 58.103628382086754, 58.305541947484016, 51.580989584326744, 57.572884261608124, 59.10908862948418, 58.54230344295502, 55.22662416100502, 59.43871334195137, 55.024030432105064, 47.27457046508789, 43.34559269249439, 51.21775567531586, 50.03178231418133, 50.06702922284603, 47.19030238687992, 45.62266230583191, 41.820479929447174, 44.41075913608074, 44.23961631953716, 44.164919927716255, 41.31951101124287, 43.46923045814037, 47.924856171011925, 48.305937722325325, 49.22822043299675, 53.42396669089794, 54.016206711530685, 56.670740470290184, 50.79344384372234, 51.41981743276119, 51.979709789156914, 55.15803404152393, 50.46955302357674, 49.52751137316227, 42.48289458453655, 42.42503508925438, 41.24384947121143, 43.242204040288925, 43.242101445794106, 47.17809744179249, 46.29496403038502, 54.016145914793015, 48.80306884646416, 59.791182428598404, 34.593279138207436, 42.96000458300114, 57.26284369826317, 49.834740087389946, 47.05088786780834, 40.13378083705902, 43.30895125865936, 52.79923461377621, 55.48608183860779, 52.595109567046165, 54.425646141171455, 55.01863092184067, 51.93212114274502, 48.94237697124481, 47.24797949194908, 46.80606700479984, 47.34139747917652, 47.68702693283558, 47.26442500948906, 49.15672346949577, 47.453400269150734, 43.46597783267498, 47.84127965569496, 52.21046380698681, 56.797440871596336, 53.430323749780655, 50.79456478357315, 54.457040056586266, 56.34336903691292, 50.22841416299343, 45.77485553920269, 42.010473534464836, 41.275999546051025, 42.06051304936409, 49.910527020692825, 53.906392604112625, 53.23739290237427, 51.97027489542961, 50.16798600554466, 49.29967179894447, 48.91113504767418, 52.29421891272068, 55.63563421368599, 60.277423337101936, 57.63794057071209, 50.059786811470985, 19.673518426716328, 7.426587017253041, 7.718991776928306, 10.776056461036205, 7.683254219591618, 2.8498173924162984, 0.4166973667452112, 0.024137978398357518, 0.03598638460971415, 0.2175339631503448, 14.278562217950821, 38.40336129069328, 38.92742156982422, 32.39203445613384, 15.103932078927755, 16.139001287519932, 35.66451385617256, 45.53794965147972, 53.19511257112026, 41.02700650691986, 2.365645235404372, 0.09298616118030623, 0.028033255512127653, 0.040902693654061295, 0.04918135469779372, 0.03337728281621821, 0.019076327153015882, 0.03581799130188301, 0.029195249117037747, 0.08659164610435255, 0.0517486847093096, 0.054624466138193384, 0.06664659798843786, 0.04075356278917752, 0.009596559466444887, 0.04955704469466582, 0.05884613608941436, 0.020642542622226756, 0.07909873020253144, 0.054466344154207036, 0.026203841080132406, 0.03638479916844517, 0.027250347229710314, 0.05649097125569824, 0.03061916519072838, 0.029639253807545174, 0.009032636698975693, 0.09843040068517439, 0.0904584358795546, 0.04001119246822782, 0.03002453791850712, 0.027680056300596334, 0.03024643265234772, 0.011778012576542096, 0.04972203525539953, 0.07118227804312482, 0.006908174500495079, 0.013015304484724766, 0.04306016518967226, 0.08066273221629672, 0.07272902512340806, 0.04913713753921911, 0.10785394697450101, 0.1196847679966595, 31.377469897270203, 71.11567676067352, 67.08140283823013, 55.98922424018383, 45.15665531158447, 32.62056939303875, 21.207593008875847, 43.57953853905201, 50.376545414328575, 25.796969644725323, 0.5260310671292245, 0.10521530770347454, 0.07757007668260485, 0.4662710503907874, 4.5143301878124475, 6.5901008527725935, 8.728662673383951, 7.320313369855285, 18.213258683681488, 41.192366033792496, 62.70670138299465, 66.2721298635006, 61.99732504785061, 59.16786767542362, 53.721228539943695, 59.73498344421387, 60.989797711372375, 59.97632749378681, 57.44657143950462, 62.44158960878849, 57.522882744669914, 49.58245262503624, 43.990782871842384, 53.63413721323013, 53.29741068184376, 53.6963626742363, 50.104335620999336, 47.653049156069756, 43.91007520258427, 46.14075690507889, 45.85269816219807, 46.78362540900707, 43.27049732208252, 46.08985863626003, 49.95747730135918, 49.792421758174896, 51.603199392557144, 54.174323827028275, 55.149735286831856, 57.612356543540955, 52.54898004233837, 53.42108644545078, 55.65258890390396, 57.72157408297062, 53.205284625291824, 50.483289286494255, 44.01657588779926, 43.28861854970455, 42.35261097550392, 45.00986158847809, 44.559874534606934, 49.65277165174484, 47.77789145708084, 56.249407678842545, 53.08874487876892, 62.77639724314213, 35.967118218541145, 44.09096069633961, 59.607690274715424, 51.41323618590832, 49.661830365657806, 41.76147669553757, 45.26957765221596, 55.94923138618469, 55.072379037737846, 54.16453555226326, 55.13348735868931, 55.90989589691162, 54.923795610666275, 50.05239620804787, 49.62939530611038, 48.03107187151909, 50.314426347613335, 50.576775670051575, 50.23470662534237, 49.80508267879486, 48.90507057309151, 44.332316145300865, 49.60142880678177, 54.73495714366436, 59.619937017560005, 53.26137721538544, 53.065501525998116, 57.717420905828476, 59.214597567915916, 53.721304535865784, 48.30405682325363, 43.334816470742226, 41.938809379935265, 44.01538275182247, 52.02935792505741, 56.05762057006359, 56.370746567845345, 54.49758768081665, 53.4515418112278, 51.84709690511227, 51.33958853781223, 54.748176634311676, 59.06889818608761, 61.003537774086, 61.385645270347595, 51.32963687181473, 22.245144434273243, 7.594868112355471, 7.599007040262222, 9.845005720853806, 8.957015220075846, 9.25490403547883, 2.843466983176768, 0.17157444963231683, 0.09642609729780816, 0.18973472906509414, 16.225760132074356, 38.0959577858448, 31.739599965512753, 36.83100186288357, 26.11206203699112, 24.29682534188032, 39.98588137328625, 51.492040157318115, 59.46074455976486, 48.97540859878063, 3.437801403924823, 0.14843060402199626, 0.028560696155182086, 0.016925855925364885, 0.032969368767226115, 0.07428911601891741, 0.04664568099542521, 0.06348974668071605, 0.04411915426317137, 0.05372082712710835, 0.020670837002398912, 0.00935615093112574, 0.026140357767872047, 0.05619046452920884, 0.03491168055916205, 0.051136802503606305, 0.01560859389428515, 0.07499697647290304, 0.040940183243947104, 0.06497326277894899, 0.03788542919210158, 0.07410977603285573, 0.01092732023607823, 0.10918806874542497, 0.08349670475581661, 0.14599109039409086, 0.1270552517962642, 0.21110423316713423, 0.24610013264464214, 0.10070716132759117, 0.07172699217335321, 0.08995102951303124, 0.11242278618738055, 0.14004892174853012, 0.18267512350575998, 0.11280094011453912, 0.15558933082502335, 0.06055961406673305, 0.1376422555767931, 0.15647772612283006, 0.2802465105196461, 0.1394295846694149, 0.21804208197863773, 0.2818748418940231, 38.067926689982414, 80.96823647618294, 73.91719043254852, 63.58682155609131, 51.7093238979578, 40.61201937496662, 38.24433982372284, 51.21295653283596, 61.29508472979069, 36.514798030257225, 1.001063408330083, 0.17961593141080812, 0.4606452147709206, 0.3240061498945579, 4.777918243780732, 11.485694982111454, 13.957491796463728, 18.222387693822384, 24.223629869520664, 44.21772189438343, 65.25484085083008, 69.49900031089783, 65.48715278506279, 62.453786954283714, 56.00336708128452, 62.97498598694801, 63.70602495968342, 61.49621933698654, 58.390657380223274, 63.79486799240112, 60.24847649037838, 52.160998061299324, 46.96039952337742, 56.38675130903721, 55.43787382543087, 56.449596136808395, 51.27537578344345, 50.97284361720085, 45.98111227154732, 49.06126879155636, 48.68831880390644, 50.26847541332245, 46.05764016509056, 48.177326023578644, 53.10908518731594, 53.09229388833046, 54.651559218764305, 57.18993321061134, 58.44613820314407, 60.28320662677288, 51.814973428845406, 53.19280229508877, 56.683758571743965, 59.737666100263596, 56.05841852724552, 52.75845520198345, 46.12836576998234, 45.90278707444668, 45.145620703697205, 46.32628194987774, 47.13776260614395, 52.487191557884216, 51.51333421468735, 60.120598152279854, 55.21973133087158, 63.885637521743774, 38.353211581707, 47.889947444200516, 60.516464710235596, 54.95281845331192, 52.41433426737785, 43.93459148705006, 46.843833178281784, 58.32150109112263, 59.725153371691704, 56.25715546309948, 57.08635836839676, 58.843403086066246, 58.38327817618847, 53.93420711159706, 50.667864382267, 50.794560983777046, 51.9474533200264, 52.27058418095112, 52.189956307411194, 53.742476999759674, 51.381583884358406, 46.02075554430485, 51.23188331723213, 56.408588737249374, 61.56525403261185, 53.845535069704056, 51.96842059493065, 59.07337814569473, 61.64343483746052, 55.92969283461571, 52.03163780272007, 46.416576504707336, 45.16444489359856, 47.19177670776844, 54.443953558802605, 58.42700242996216, 58.5424592345953, 55.98545104265213, 55.80458074808121, 54.597442522645, 53.81611704826355, 57.97521807253361, 60.398598834872246, 65.43781623244286, 63.03520895540714, 54.430954456329346, 25.787905231118202, 12.824755478650331, 15.985301434993744, 18.798497579991817, 17.603815086185932, 7.69391312263906, 0.9774532564915717, 0.20835993433138356, 0.35780014120973647, 0.4664369352394715, 21.893933080136776, 54.26347464323044, 53.55042390525341, 44.44238103926182, 25.776897221803665, 26.31721682846546, 49.86562862992287, 58.95643562078476, 66.92938059568405, 56.17629200220108, 4.217474916949868, 0.31725293258205056, 0.16877965506864712, 0.09447859047213569, 0.1468315429519862, 0.1736433050245978, 0.1429894592729397, 0.11171056190505624, 0.14097884763032198, 0.13253957469714805, 0.22667596087558195, 0.24708430952159688, 0.2310904036858119, 0.22994688770268112, 0.1851452878327109, 0.089650311274454, 0.14357409352669492, 0.1467697517364286, 0.11413096523028798, 0.12907344818813726, 0.1031328784301877, 0.2147288972628303, 0.1316975784720853], [0.030320825535454787, 0.03283904763520695, 0.04385373627883382, 0.05365223412809428, 0.021626910602208227, 0.045528993650805205, 0.03009251864568796, 0.10695855322410353, 0.06305855888058431, 0.0688467021973338, 0.04861130364588462, 0.0184004588300013, 0.04184428609733004, 0.04334834113251418, 0.038382215425372124, 0.01795136671717046, 0.06714621180435643, 0.02733307072048774, 0.029761079204035923, 0.01828300839406438, 0.6975956610403955, 37.88357198238373, 57.443862184882164, 50.37767395377159, 40.62849909067154, 31.874036751687527, 24.415063597261906, 33.9328745752573, 37.90529161691666, 40.660280585289, 9.294826593250036, 0.06065509878681041, 0.1935327291721478, 0.043053341141785495, 0.634672581218183, 4.008921682834625, 7.244020588696003, 2.8671769984066486, 7.94237514026463, 32.24020980298519, 59.40343223512173, 63.291129022836685, 59.20291319489479, 56.552661806344986, 56.42964720726013, 49.041414856910706, 53.48411746323109, 56.86034269630909, 58.32573026418686, 57.70710065960884, 55.54055951535702, 58.054759204387665, 45.47765828669071, 40.96065826714039, 49.445321783423424, 51.08744166791439, 53.102340549230576, 49.81131814420223, 48.66097927093506, 41.752163395285606, 40.10230712592602, 39.96597424149513, 41.271720975637436, 43.34699101746082, 46.27629943192005, 48.34035627543926, 49.1624041646719, 46.6226052492857, 50.108880177140236, 52.484155520796776, 55.621301382780075, 52.57712513208389, 51.26624867320061, 54.570574164390564, 54.654842242598534, 48.8517252355814, 45.18500939011574, 40.747535303235054, 40.459537357091904, 40.16710884869099, 44.08945977687836, 42.69280292093754, 48.40747207403183, 47.15722896158695, 56.564528569579124, 49.39945824444294, 62.97278590500355, 37.337286695837975, 43.78869831562042, 58.83951209485531, 49.33241464197636, 48.67880031466484, 40.23470722138882, 40.53994104266167, 44.99955654144287, 57.846606373786926, 52.45383694767952, 53.12157891690731, 51.41694478690624, 54.09858629107475, 51.66322857141495, 50.655264258384705, 49.385904371738434, 50.844938680529594, 52.17164508998394, 53.71842049062252, 49.40754421055317, 48.3980143815279, 47.23752245306969, 49.98550459742546, 53.30784872174263, 54.37610059976578, 55.0701941549778, 50.94257444143295, 55.78981094062328, 56.174251511693, 54.78465087711811, 52.150107845664024, 50.292250737547874, 44.176950082182884, 41.06747053563595, 42.70446069538593, 45.51122948527336, 45.2497199177742, 47.00916990637779, 45.57136885821819, 45.02552054822445, 44.77471120655537, 50.02457030117512, 54.443919360637665, 59.52930428087711, 58.394088596105576, 58.113507851958275, 31.29769127815962, 13.942674491554499, 5.239405855536461, 6.999528408050537, 5.125648034736514, 5.718838954344392, 0.8410317893140018, 0.16801441175630316, 0.09920532902469859, 0.08161694859154522, 2.534799096174538, 31.75765849649906, 38.545298874378204, 34.18442487716675, 27.018856778740883, 21.72294605523348, 34.087822660803795, 35.832624435424805, 49.58633601665497, 47.40008533000946, 11.913780011236668, 0.15058044256875291, 0.07518154117860831, 0.049552450800547376, 0.05919684910622891, 0.06031985212757718, 0.011681997220875928, 0.037809566856594756, 0.08540899667423218, 0.03243584622396156, 0.04736649934784509, 0.05442392670374829, 0.056119711880455725, 0.05184604706300888, 0.041685039759613574, 0.061339778258115984, 0.0615152368118288, 0.014749750916962512, 0.021780705865239725, 0.02523930885217851, 0.049430805374868214, 0.04359126462077256, 0.03573895257432014, 0.027509883693710435, 0.10076107093482278, 0.09509502575383522, 0.061356580481515266, 0.07025531333056279, 0.03669583697046619, 0.04869544463872444, 0.04484486336878035, 0.049649052452878095, 0.05459711428557057, 0.07159633707487956, 0.039664449941483326, 0.06463035344495438, 0.059224649958196096, 0.05869932814675849, 0.07977623681654222, 0.06731177752953954, 0.009819747392612044, 0.011003200197592378, 0.033036755776265636, 1.0692343628033996, 47.847131341695786, 65.7813709974289, 57.66666702926159, 48.00986520946026, 40.61984695494175, 32.75764323771, 33.59625443816185, 38.22425030171871, 43.45819965004921, 10.437507927417755, 0.020954558203811757, 0.016799039585748687, 0.14232011628337204, 2.364854640327394, 4.927307702600956, 8.273466099053621, 4.333803774788976, 10.476914662867785, 31.768430918455124, 58.43993313610554, 65.23987725377083, 61.24912619590759, 61.29227668046951, 58.945180624723434, 52.387899085879326, 55.88246516883373, 58.517528772354126, 59.97272148728371, 58.353981748223305, 57.86976993083954, 60.00398240983486, 47.97500587999821, 43.91330882906914, 51.994563192129135, 52.820851653814316, 55.07989503443241, 52.28444583714008, 49.49674442410469, 44.86326925456524, 42.9603161662817, 42.471612989902496, 42.991216108202934, 45.64141429960728, 49.81601469218731, 50.93803748488426, 51.70454375445843, 50.22694744169712, 52.87231609225273, 53.8559503108263, 57.20513239502907, 53.051814660429955, 50.891930758953094, 55.0448989123106, 56.81379519402981, 49.885813146829605, 47.62125626206398, 43.05650420486927, 41.20923712849617, 42.347982823848724, 45.01519650220871, 44.13009099662304, 48.38401973247528, 49.91123378276825, 55.9196537733078, 52.52524271607399, 65.51179066300392, 39.12348724901676, 46.95968136191368, 61.98089472949505, 53.02448272705078, 51.15033209323883, 42.68415458500385, 43.18280942738056, 47.9575078189373, 59.523672983050346, 56.030467227101326, 56.82166077196598, 52.67313838005066, 58.546821400523186, 53.1358889490366, 52.496444061398506, 51.02817244827747, 52.67174765467644, 53.03565792739391, 55.292349234223366, 51.57595865428448, 51.16939567029476, 46.55401133000851, 52.3215888440609, 55.39964407682419, 56.12728603184223, 55.236902609467506, 51.63354076445103, 56.07595458626747, 58.8150642067194, 56.05215646326542, 54.766579046845436, 53.14410790801048, 45.826688557863235, 42.91687689721584, 43.89130041003227, 47.00133852660656, 47.17009127140045, 49.54558700323105, 46.927983462810516, 48.11547674238682, 49.05713841319084, 51.44493788480759, 57.09184907376766, 61.14706367254257, 60.81889808177948, 60.004860162734985, 35.73064550757408, 12.708887346088886, 5.721574332565069, 8.869565762579441, 8.653505556285381, 11.432419940829277, 6.216322984546423, 1.0701307584531605, 0.10303414310328662, 0.03175547863065731, 2.5747178541496396, 34.965913742780685, 35.854705050587654, 40.83825923502445, 29.211379028856754, 27.93354369699955, 39.807507544755936, 42.43760481476784, 54.68857683241367, 55.84339566528797, 15.566426161676645, 0.1809865445829928, 0.046606543837697245, 0.05055340763647109, 0.05133229904458858, 0.03761405918339733, 0.024515115583199076, 0.09689819227787666, 0.09718113607959822, 0.04755120135087054, 0.04867820083745755, 0.05270716101222206, 0.021618266437144484, 0.009641454762459034, 0.03343661381222773, 0.04480259434785694, 0.0585744803538546, 0.05868809203093406, 0.07315385271795094, 0.0030565080714950454, 0.053610102404491045, 0.019250375626143068, 0.05140818364452571, 0.20089873782126233, 0.16963499510893598, 0.20768903283169493, 0.12676575483055785, 0.166838048317004, 0.17411011591320857, 0.15293403033865616, 0.20699530286947265, 0.19621491024736315, 0.1604505316936411, 0.09285910549806431, 0.2851240831660107, 0.12613902596058324, 0.148249089543242, 0.14708704955410212, 0.2674441959243268, 0.08531217608833686, 0.1459181818063371, 0.08573628379963338, 0.15679195144912228, 1.5462766773998737, 59.68503512442112, 73.2387900352478, 67.35701724886894, 55.092924535274506, 48.036999553442, 33.6087329685688, 46.18332602083683, 50.76747603714466, 55.62027543783188, 14.145334716886282, 0.13645324594108388, 0.4594470915617421, 0.21224289550445974, 1.885798315051943, 10.69836013019085, 16.6418245062232, 9.82346847653389, 14.299019370228052, 36.70752748847008, 62.45239242911339, 66.61485627293587, 64.27596777677536, 61.56608998775482, 61.94735772907734, 55.14392539858818, 57.539168670773506, 60.364803448319435, 62.489512637257576, 60.000213012099266, 60.36478444933891, 63.3618888258934, 51.17743603885174, 45.259276404976845, 53.783226013183594, 56.754993349313736, 56.9921538233757, 55.04084452986717, 52.65839137136936, 47.08212599158287, 45.76379053294659, 45.2263967692852, 45.242690294981, 48.24118159711361, 52.612653225660324, 53.176482170820236, 53.80872264504433, 52.345253974199295, 56.35272033512592, 55.57480327785015, 58.7507488578558, 54.62409049272537, 51.271366998553276, 57.84974120557308, 59.808547496795654, 52.165303230285645, 48.860571160912514, 45.14851234853268, 44.83912155032158, 45.23173168301582, 47.49344252049923, 46.708336248993874, 51.21277034282684, 52.383791506290436, 59.89913463592529, 54.38043616712093, 66.09686806797981, 42.00224317610264, 49.22510080039501, 63.165424168109894, 54.94972541928291, 53.881104961037636, 45.25161601603031, 45.40284030139446, 48.85312356054783, 61.72233760356903, 56.818723529577255, 57.281610891222954, 55.11348903179169, 61.62453845143318, 55.185913145542145, 55.31995855271816, 53.10824543237686, 56.27316400408745, 56.757710203528404, 59.06315669417381, 53.2144421339035, 53.730952218174934, 50.27801290154457, 54.21237498521805, 58.276085928082466, 59.016252011060715, 55.74598029255867, 51.93437822163105, 58.00253860652447, 62.726581916213036, 60.62610402703285, 57.44319722056389, 56.84810735285282, 48.0626405775547, 45.805181711912155, 46.15518093109131, 50.74879243969917, 49.689888060092926, 53.14464747905731, 48.87662909924984, 51.261582523584366, 50.52537202835083, 55.74810437858105, 58.365574926137924, 65.58479234576225, 63.13680410385132, 62.38055348396301, 35.33833555877209, 18.072869516909122, 12.109680399298668, 14.726689271628857, 12.482284605503082, 11.789267342537642, 4.265505289658904, 0.41636473615653813, 0.2243241691030562, 0.15580596373183653, 3.689941861666739, 47.37664058804512, 51.365016773343086, 44.004006162285805, 34.51762139797211, 33.705103397369385, 45.69875702261925, 51.6688446700573, 61.85401193797588, 65.33114075660706, 19.437233805656433, 0.31877483997959644, 0.17936112242750823, 0.1862746139522642, 0.19365908723557368, 0.13542351603973657, 0.1651940873125568, 0.3246593289077282, 0.336281509953551, 0.22024462785338983, 0.19220621441490948, 0.1789435010869056, 0.17670519853709266, 0.12097864309907891, 0.08071230025961995, 0.14603612391510978, 0.14120882435236126, 0.12661725108046085, 0.1489873483660631, 0.0818704736593645, 0.13803229870973155, 0.1136270840652287, 0.0920425055664964], [0.052978133971919306, 0.06490928964922205, 0.06250584439840168, 0.0071793367078498704, 0.01995349746721331, 0.05922109878156334, 0.04370372225821484, 0.04477664886508137, 0.022704215880366974, 0.02579929081548471, 0.0475149585690815, 0.03441069377004169, 0.04904806497506797, 0.02714124409976648, 0.026841342223633546, 0.016906114797166083, 0.04047029615321662, 0.03706553783558775, 0.0718228034384083, 0.05957014567684382, 4.330680817365646, 48.63084688782692, 57.135884910821915, 52.15656749904156, 38.03227700293064, 24.944202303886414, 19.15630728006363, 39.14657860994339, 44.53752413392067, 29.982929527759552, 2.157276766374707, 0.08047881317907013, 0.1306102579110302, 0.33972688601352274, 1.1842601280659437, 4.626565715298057, 6.21061616577208, 7.246697070077062, 19.322124682366848, 46.97654485702515, 66.36779353022575, 59.66252513229847, 58.18172559142113, 57.92449079453945, 54.73029479384422, 46.5837637335062, 50.777340307831764, 58.75631555914879, 59.75788101553917, 53.64769868552685, 57.679388746619225, 55.46064980328083, 47.26483918726444, 42.1139457821846, 48.524099215865135, 50.6088687479496, 52.59160615503788, 51.85814291238785, 52.29619100689888, 43.759192898869514, 39.20357935130596, 38.910755664110184, 40.65372593700886, 45.259713381528854, 49.400826171040535, 49.01643879711628, 50.24763733148575, 50.600296407938, 47.791357934474945, 50.90581141412258, 54.33045744895935, 52.266225814819336, 52.31892518699169, 54.60054695606232, 53.42429727315903, 47.16268166899681, 42.18703866004944, 39.93618004024029, 39.696834683418274, 41.49638012051582, 46.51072025299072, 47.341648265719414, 51.87771186232567, 50.65325416624546, 54.22608844935894, 51.106843426823616, 59.765150025486946, 33.80929380655289, 42.60453745722771, 58.60589303076267, 50.93390330672264, 48.055276572704315, 41.37761369347572, 42.23001055419445, 38.74069958925247, 47.389096319675446, 53.365598022937775, 52.651798725128174, 52.5315123796463, 53.58391530811787, 54.30740788578987, 53.06788019835949, 52.8108923882246, 54.515720307826996, 53.72892692685127, 52.39987224340439, 51.104947328567505, 50.503295212984085, 49.91320587694645, 52.25426025688648, 55.378084033727646, 53.42904321849346, 51.17650888860226, 48.74696105718613, 51.60257242619991, 56.19168497622013, 55.153633877635, 57.06236645579338, 55.986279398202896, 52.75922656059265, 42.525763884186745, 41.60979263484478, 42.8523563593626, 41.42749361693859, 44.44972224533558, 47.525193616747856, 47.73784540593624, 44.439728781580925, 44.56601120531559, 50.88006779551506, 58.215878158807755, 56.159926280379295, 59.93628904223442, 48.366787657141685, 23.074495531618595, 8.853596169501543, 8.637367822229862, 6.930876541882753, 18.518895283341408, 14.441229589283466, 0.9144117892719805, 0.07486531205358915, 0.058144561626249924, 0.12952764256624505, 11.910267099738121, 34.28495608270168, 48.17707523703575, 50.51175735890865, 26.34577039629221, 20.80929648131132, 33.15770857036114, 41.00007355213165, 51.00793853402138, 24.15417719632387, 0.2622720500221476, 0.060875846902490593, 0.05283194943331182, 0.05205003006267361, 0.01847178293246543, 0.028464747592806816, 0.016780552687123418, 0.04826145894185174, 0.0153849838716269, 0.0551996714057168, 0.12789698084816337, 0.023573228136228863, 0.055616765821469016, 0.04112799113499932, 0.01889707251393702, 0.056596667927806266, 0.02251804071420338, 0.024866387066140305, 0.06132848277047742, 0.052496083080768585, 0.013847812351741595, 0.07318384290556423, 0.02826195202942472, 0.033516888215672225, 0.06035291851731017, 0.042164786282228306, 0.02648274203238543, 0.056424771682941355, 0.0254863920781645, 0.03314605928608216, 0.03281197408796288, 0.046010732839931734, 0.06823423740570433, 0.005597356630460126, 0.04724641614302527, 0.03197479811205994, 0.023513347950938623, 0.1009919901844114, 0.021004590089432895, 0.07816965036909096, 0.056341628878726624, 0.05794209260784555, 6.501566553488374, 58.001318871974945, 64.6075151860714, 58.6783741414547, 44.65156361460686, 30.137193650007248, 21.19101259857416, 40.35769522190094, 43.661059364676476, 33.184048756957054, 1.7228729138150811, 0.046614967213827185, 0.07846106207580306, 0.6463697191793472, 4.966158242896199, 8.524177595973015, 5.150934727862477, 4.549060799181461, 17.8591575846076, 48.12193259596825, 68.7034521996975, 63.22950392961502, 60.446335673332214, 61.55782923102379, 57.13963910937309, 50.34836232662201, 54.463685899972916, 60.96521683037281, 61.06687657535076, 55.737195163965225, 59.54434007406235, 57.50034615397453, 47.532808408141136, 43.77296715974808, 52.44084544479847, 53.4443373978138, 56.36720135807991, 54.11417305469513, 53.48667852580547, 44.80316407978535, 42.56758823990822, 41.33341446518898, 42.55058415234089, 47.15003214776516, 51.403938084840775, 51.07037678360939, 52.365020513534546, 51.4556685090065, 50.567017793655396, 52.09054984152317, 57.190826162695885, 53.11760053038597, 51.37573599815369, 56.318970546126366, 55.52680425345898, 48.687080070376396, 45.35952262580395, 42.04580403864384, 43.361004665493965, 43.063849210739136, 48.80078136920929, 48.63385632634163, 54.160199984908104, 52.399568259716034, 57.04685568809509, 53.221080377697945, 61.20515875518322, 35.05927473306656, 45.81018224358559, 61.196347028017044, 52.961140125989914, 50.312188267707825, 43.75104993581772, 43.6648553609848, 42.3591086268425, 50.02554304897785, 55.392025485634804, 54.660142958164215, 56.18574969470501, 55.24437300860882, 55.17707861959934, 55.09067885577679, 55.63400790095329, 56.435301303863525, 54.80220593512058, 55.13265140354633, 52.50863380730152, 53.31042878329754, 52.59426221251488, 54.633954763412476, 56.85585893690586, 55.3703248500824, 52.3462875187397, 49.517981484532356, 51.51260085403919, 57.46876984834671, 59.215213134884834, 57.8002792596817, 56.41493059694767, 54.76076155900955, 44.75479267537594, 43.333934918046, 44.77180436253548, 44.200094640254974, 46.96454130113125, 49.26784090697765, 50.32146356999874, 46.0609345883131, 48.14464397728443, 52.844801768660545, 61.61294907331467, 58.79620961844921, 63.863659501075745, 47.859366685152054, 23.40758565813303, 7.9319945722818375, 9.4099167175591, 8.382766284048557, 11.874424573034048, 11.65469091385603, 4.934088438749313, 0.3431165713118389, 0.11913398309843615, 0.0918059163086582, 14.69063775613904, 34.18229699134827, 48.63309636712074, 57.66614645719528, 31.900599226355553, 26.612877063453197, 38.66785749793053, 48.28993298113346, 59.783586636185646, 32.96796575188637, 0.32962135795969516, 0.041778201557463035, 0.009370299976581009, 0.07930785999633372, 0.017067281441995874, 0.025370967705384828, 0.02785287651931867, 0.0868092141172383, 0.04421574849402532, 0.029687135320273228, 0.10398568032542244, 0.09337622657767497, 0.034496986991143785, 0.04281281850126106, 0.04611193580785766, 0.05695158150047064, 0.08138891629641876, 0.058280504526919685, 0.05491782969329506, 0.009522587752144318, 0.023751792577968445, 0.03938390698749572, 0.10126687426236458, 0.23045812355121598, 0.08670736919157207, 0.11033557748305611, 0.2259154079365544, 0.16974656959064305, 0.11643725592875853, 0.12590342375915498, 0.14984985755290836, 0.2072390983812511, 0.16799979144707322, 0.12415690536727197, 0.09297007141867653, 0.18945119896670803, 0.1318789296783507, 0.159625961096026, 0.10572073253570125, 0.1944165231543593, 0.12068041105521843, 0.282585967797786, 9.806972611695528, 70.19959911704063, 73.4738378226757, 68.5870948433876, 51.60229504108429, 37.67633490264416, 29.511230438947678, 55.007497519254684, 56.203718930482864, 41.65094442665577, 2.930868468247354, 0.25116123841144145, 0.3228298161411658, 0.8329376298934221, 4.6001694817095995, 14.877806212753057, 15.252623800188303, 15.38080707192421, 23.48728448152542, 52.288804203271866, 70.72913870215416, 65.3421601653099, 64.68732610344887, 63.739071786403656, 59.015017077326775, 50.98250649869442, 55.970749631524086, 64.87856224179268, 64.24091085791588, 57.556514739990234, 62.75674469769001, 61.510430574417114, 51.17892175912857, 44.91682358086109, 53.272316828370094, 55.35075590014458, 57.86570034921169, 55.74932411313057, 56.24947227537632, 48.08691747486591, 43.95951434969902, 44.458697363734245, 44.257361367344856, 50.503963977098465, 55.1963359862566, 55.194667875766754, 54.73564110696316, 55.470267087221146, 51.019246727228165, 55.21419882774353, 60.709722340106964, 54.680954441428185, 53.55905704200268, 57.50781275331974, 56.96339316666126, 53.40784415602684, 47.27495424449444, 44.66282241046429, 45.225576013326645, 46.278172731399536, 51.398648768663406, 51.79450772702694, 58.8106906414032, 54.925304129719734, 59.54203359782696, 56.954220458865166, 63.05932246148586, 37.38477274775505, 47.4105803668499, 64.87314373254776, 54.96668390929699, 51.295385509729385, 46.18881672620773, 46.13084323704243, 44.12623420357704, 51.12480506300926, 57.245364636182785, 56.453274339437485, 57.299868911504745, 55.58567829430103, 57.911613285541534, 58.145775720477104, 58.40083323419094, 58.211975768208504, 57.3348194360733, 56.099608317017555, 54.64055500924587, 56.2272472679615, 55.50655514001846, 56.31765581667423, 59.74632203578949, 55.79499766230583, 52.01934926211834, 51.27819903194904, 53.594835922122, 58.42094175517559, 59.168445244431496, 61.321649104356766, 59.598129987716675, 56.9567359238863, 46.65803834795952, 45.77475294470787, 47.32038080692291, 45.87346404790878, 49.50371325016022, 51.58837638795376, 52.09948696196079, 48.51756736636162, 50.087415128946304, 55.54189324378967, 64.23676148056984, 60.74912242591381, 65.62520697712898, 52.12219834327698, 29.31870996952057, 13.539215940982103, 18.28853454440832, 16.724935546517372, 28.911953195929527, 26.604112833738327, 2.6884293649345636, 0.2875186671735719, 0.2519885846413672, 0.2581644704332575, 18.366724848747253, 48.567215502262115, 59.1895455121994, 56.76659032702446, 34.34761852025986, 32.11427316069603, 45.76360434293747, 56.91037081182003, 66.3602927327156, 42.84533813595772, 0.9005852811969817, 0.12036450105370022, 0.14360061788465828, 0.1753808360081166, 0.10185388338868506, 0.2315308534889482, 0.10872743994696066, 0.20864833291852847, 0.1823482074541971, 0.2023862540954724, 0.19909318158170208, 0.23302175395656377, 0.1478634844534099, 0.14945721690310165, 0.1255752905854024, 0.15651282970793545, 0.19378577184397727, 0.16284422512399033, 0.18393171310890466, 0.07985320495208725, 0.14040969457710162, 0.09059117641299963], [0.05876803617866244, 0.02968084747408284, 0.057373080562683754, 0.03678729925013613, 0.014508193908113753, 0.03370272199390456, 0.009829386963247089, 0.08108772308332846, 0.03458959217823576, 0.028281537306611426, 0.04754577254061587, 0.016940593122853898, 0.04632886928447988, 0.07375645436695777, 0.04388391942484304, 0.08705366271897219, 0.040528513927711174, 0.10505135243874975, 0.04901881322439294, 0.07730740835540928, 13.753957618027925, 59.0956449508667, 57.49572940170765, 53.40872570872307, 40.14940559864044, 31.75962869077921, 31.798035129904747, 48.829906806349754, 44.05031427741051, 14.159446209669113, 0.08144485196680762, 0.0207459553348599, 0.07505850051529706, 0.31322933442424983, 6.075744302943349, 2.3384420201182365, 3.3704996528103948, 4.77365487255156, 33.664791360497475, 57.79025159776211, 62.00896382331848, 55.606767162680626, 58.01149092614651, 57.13253729045391, 53.73510919511318, 45.29993802309036, 50.34152269363403, 55.713286846876144, 57.74536460638046, 56.761673390865326, 56.467071399092674, 53.983338475227356, 43.34378018975258, 40.27064569294453, 48.45802076160908, 53.708176240324974, 55.45388236641884, 53.794879987835884, 51.8070812523365, 46.23474106192589, 38.7158565223217, 39.42162685096264, 40.69042816758156, 46.077915877103806, 49.833512753248215, 50.806161761283875, 50.137101262807846, 48.33665907382965, 48.79642300307751, 51.083311289548874, 53.05547006428242, 55.35864047706127, 51.4058455824852, 54.17235553264618, 52.566124722361565, 43.62572506070137, 38.97716850042343, 39.23821069300175, 41.06162264943123, 44.96522918343544, 50.6451416015625, 52.958936244249344, 55.23308761417866, 52.51702755689621, 55.46380363404751, 53.60761843621731, 59.55095931887627, 33.39040048420429, 39.9234127253294, 58.7975699454546, 47.791015952825546, 49.38205897808075, 42.62267388403416, 44.16290603578091, 39.500541016459465, 41.81708671152592, 42.35503524541855, 52.55098633468151, 51.1163467168808, 54.31580163538456, 53.1005622446537, 55.46751603484154, 54.425790533423424, 56.37461856007576, 53.519067987799644, 56.744847893714905, 53.1243983656168, 50.674696415662766, 50.33695913851261, 54.075650721788406, 52.590770199894905, 51.30798943340778, 47.76610068976879, 52.49152712523937, 50.966638550162315, 53.75006899237633, 53.67882281541824, 57.656339183449745, 55.72649493813515, 55.5215073376894, 48.176984041929245, 43.359545543789864, 40.438383892178535, 42.24305905401707, 46.69074699282646, 50.8510335534811, 48.394605964422226, 49.55282561480999, 42.7046924829483, 47.953616827726364, 55.855353623628616, 60.65775252878666, 57.36605755984783, 53.08018013834953, 36.588571071624756, 16.57694298774004, 9.173325262963772, 8.715225644409657, 9.725989457219839, 9.596330914646387, 7.155149057507515, 0.7746264338493347, 0.11697817768435925, 0.0683804701839108, 2.8106488566845655, 29.80880007147789, 31.656663715839386, 13.63938046619296, 28.25149543583393, 36.7974154651165, 28.030062317848206, 35.491718128323555, 46.77286058664322, 41.002554818987846, 2.0729901641607285, 0.02703128007851774, 0.04593168669089209, 0.08683166408445686, 0.045097171314409934, 0.06481259522843175, 0.040699330347706564, 0.03946160613850225, 0.03300704760476947, 0.039756149708409794, 0.056880910487961955, 0.010093904165842105, 0.044761241879314184, 0.08302576752612367, 0.03703686124936212, 0.04001453213277273, 0.03721611588844098, 0.006412411039491417, 0.012953010464116232, 0.04313930781790987, 0.04959781828802079, 0.034057119773933664, 0.045119836504454724, 0.03535282055963762, 0.06826615717727691, 0.012336345116636949, 0.06355851408443414, 0.03299929587228689, 0.051810108561767265, 0.08023015660000965, 0.012140468224970391, 0.0030511047725667595, 0.02508106997993309, 0.019800013906206004, 0.04224042597343214, 0.0506416898133466, 0.02807434637361439, 0.040704506827751175, 0.0488871376728639, 0.030841733423585538, 0.007176476192398695, 0.11727842836990021, 19.037333764135838, 67.92102098464966, 65.18945395946503, 60.27738533914089, 46.785703897476196, 40.0032464414835, 37.0002181828022, 47.82663144171238, 48.99906612932682, 16.377683579921722, 0.09885180697892793, 0.11667913669953123, 0.07300339711946435, 1.6993614379316568, 5.562915746122599, 7.314078379422426, 6.988371256738901, 6.206703325733542, 31.900508031249046, 59.22651752829552, 64.11383047699928, 60.91432996094227, 60.984933972358704, 59.154363200068474, 55.52481696009636, 47.71053247153759, 52.151376977562904, 58.92461992800236, 60.43038412928581, 59.636162146925926, 59.622878059744835, 55.950622111558914, 45.00531703233719, 43.76394264400005, 51.23107776045799, 56.41245312988758, 57.11399428546429, 55.94705030322075, 54.52401526272297, 49.13358271121979, 41.62175439298153, 40.93057908117771, 42.08881393074989, 48.322178050875664, 51.73616945743561, 53.50895293056965, 53.1386362016201, 50.52030690014362, 52.10239380598068, 51.81362450122833, 54.81820687651634, 57.37043872475624, 53.01328472793102, 55.66013529896736, 54.463659301400185, 46.01475186645985, 42.14008457958698, 40.39355389773846, 42.420247346162796, 46.30567945539951, 53.69008921086788, 54.045028164982796, 57.47187428176403, 55.5935400724411, 58.954870104789734, 55.20595706999302, 60.99663354456425, 34.542848244309425, 42.222289368510246, 60.67222215235233, 50.62176525592804, 52.27800138294697, 44.933702275156975, 45.955486446619034, 41.3351471722126, 42.41505682468414, 45.500582456588745, 53.29583376646042, 54.96438503265381, 57.0692440867424, 53.638339787721634, 56.186551451683044, 55.95636360347271, 57.46497765183449, 55.64244344830513, 58.45522351562977, 53.78541849553585, 52.543075159192085, 52.36785136163235, 56.93181686103344, 54.91265840828419, 51.2673582136631, 47.494202479720116, 54.788591265678406, 51.189120411872864, 54.763721600174904, 55.31925559043884, 60.11161923408508, 57.94788993895054, 57.51058280467987, 50.85004560649395, 44.92911972105503, 43.30547824501991, 43.17573420703411, 47.82643765211105, 52.07581043243408, 52.14568488299847, 51.623007729649544, 44.998864978551865, 49.63968515396118, 57.557989060878754, 60.43666139245033, 61.32408857345581, 56.713849157094955, 38.682604506611824, 14.205035213381052, 6.937116757035255, 6.26527433283627, 11.750508472323418, 9.958207346498966, 5.667750695720315, 2.0260512828826904, 0.21012431621784344, 0.03259330027503893, 2.818195251747966, 31.193274781107903, 34.17724706232548, 15.69853937253356, 29.932304844260216, 42.22714550793171, 35.0217517465353, 43.58822487294674, 52.50866800546646, 55.55103175342083, 6.033855825662613, 0.07130053185392171, 0.05675697924743872, 0.09876766227534972, 0.06586245959624648, 0.03534151765052229, 0.023480333511542995, 0.01953093898919178, 0.026800232808454894, 0.036807032956858166, 0.06503446027636528, 0.06944719614693895, 0.016564138713874854, 0.03802603649091907, 0.024633245084260125, 0.02949385223473655, 0.06776285488740541, 0.0434226338256849, 0.010918303141806973, 0.04644549779186491, 0.016531480505364016, 0.020279899581510108, 0.17187271878356114, 0.13249111245386302, 0.16725593683077022, 0.0827754930651281, 0.148172915505711, 0.13781152461888269, 0.18610337079735473, 0.19990382948890328, 0.115145577583462, 0.09370019630296156, 0.19243256945628673, 0.1302603946533054, 0.15212347148917615, 0.10150027970666997, 0.1689430166152306, 0.14479912701062858, 0.12218213945743628, 0.22123805189039558, 0.1508293440565467, 0.15354213130194694, 26.25942002981901, 77.87060469388962, 72.83186227083206, 67.34947085380554, 54.55527238547802, 44.6094124764204, 44.70883034169674, 60.50612546503544, 58.59703190624714, 20.998786613345146, 0.3354789217701182, 0.2635666821151972, 0.26919658470433205, 1.814170377328992, 17.497521489858627, 10.655216295272112, 12.792309019714594, 9.55759484320879, 38.00107307732105, 62.06836983561516, 67.52527981996536, 63.734945207834244, 62.97195754945278, 63.460060358047485, 58.08072321116924, 51.11680269241333, 53.57757344841957, 60.353989228606224, 61.39932073652744, 60.57713985443115, 61.45286366343498, 58.682352527976036, 47.16806598007679, 45.39269104599953, 52.734052911400795, 59.8708413541317, 58.70434194803238, 58.250581696629524, 55.89241683483124, 50.98551593720913, 43.161313980817795, 42.5269266217947, 44.34837408363819, 51.49061143398285, 55.68912014365196, 56.39898285269737, 55.42573727667332, 54.410279765725136, 54.200702011585236, 55.3515462577343, 57.24498465657234, 60.228474363684654, 54.48561072349548, 58.09880644083023, 56.47640369832516, 48.38838189840317, 42.72565595805645, 42.85668432712555, 45.21240971982479, 49.74664181470871, 56.095208153128624, 56.97896473109722, 58.574415519833565, 58.18792685866356, 59.726285710930824, 58.31545941531658, 62.00936660170555, 37.477628365159035, 44.2950439453125, 62.51901425421238, 52.7671567350626, 54.374006912112236, 46.95795625448227, 48.20830576121807, 43.08366894721985, 45.415611416101456, 46.46758496761322, 55.890357345342636, 57.9776119440794, 59.50420282781124, 55.36257706582546, 57.71142862737179, 59.858275428414345, 59.37441699206829, 56.55539385974407, 59.30210307240486, 57.26192034780979, 54.652201384305954, 54.914277121424675, 58.89234445989132, 55.74355982244015, 52.29181744158268, 49.00252394378185, 56.48711912333965, 53.813540786504745, 55.979975536465645, 56.82631552219391, 60.42508341372013, 60.40749795734882, 60.24518586695194, 52.87325084209442, 48.76352436840534, 45.4390599578619, 45.81716626882553, 51.126351580023766, 55.50625495612621, 53.656495213508606, 55.09268134832382, 47.25487992167473, 53.59276883304119, 59.65652905404568, 64.61690828204155, 62.47492142021656, 60.55571660399437, 40.31398996710777, 23.331903219223022, 15.350608192384243, 15.26182595640421, 24.60166208446026, 20.265819244086742, 12.756177708506584, 2.1682244539260864, 0.36491365637630224, 0.271940334350802, 3.9134969282895327, 41.74220412969589, 43.87483589351177, 19.678765945136547, 36.689801439642906, 48.52901995182037, 39.84681263566017, 50.789457857608795, 57.35879994928837, 66.08203366398811, 10.56316053494811, 0.3319034620653838, 0.27512643369846046, 0.25085535482503474, 0.1649476497550495, 0.15768245444633067, 0.14474481664365157, 0.10774209789815359, 0.2531457116128877, 0.1563785009784624, 0.22188306727912277, 0.16616564767900854, 0.15542504901532084, 0.17852758668595925, 0.17913172458065674, 0.24662526149768382, 0.2519900392508134, 0.16388970339903608, 0.08338009851286188, 0.21691091533284634, 0.14997059013694525, 0.08742072895984165], [0.11882692691870034, 0.04855027684243396, 0.04672285322158132, 0.02233776747743832, 0.06184207493788563, 0.0699748334591277, 0.035265748083475046, 0.06038096427801065, 0.06864514230983332, 0.015355287760030478, 0.08485723214107566, 0.06763745419448242, 0.005674067797372118, 0.04607427181326784, 0.03947172161133494, 0.040211943414760754, 0.03516161363222636, 0.060767782779294066, 0.06365810288116336, 0.38231416954658926, 30.790509693324566, 55.36401338875294, 54.410313963890076, 38.29998403787613, 22.410733848810196, 15.921525657176971, 26.357625760138035, 39.22347508370876, 32.95177482068539, 4.640596462413669, 0.0027231643252889626, 0.146712472778745, 0.11750852383556776, 0.8189476712141186, 5.482519185170531, 8.907562773674726, 1.9855763297528028, 13.76831989735365, 47.72081471979618, 64.8048385977745, 62.63996936380863, 57.639506086707115, 61.12516924738884, 56.12625248730183, 55.21737925708294, 45.379954129457474, 47.94117249548435, 55.46807460486889, 58.44537064433098, 56.8977364897728, 57.44997225701809, 46.84412956237793, 42.45430491864681, 44.30073224008083, 48.57104949653149, 53.91791358590126, 52.98048868775368, 55.430194437503815, 54.19787496328354, 49.27241586148739, 41.07252046465874, 39.005769565701485, 39.436313062906265, 46.926550939679146, 52.14554809033871, 53.11022512614727, 53.0926738679409, 51.58405601978302, 49.62623007595539, 48.22776451706886, 52.51140005886555, 51.75478845834732, 54.16314862668514, 53.00987631082535, 50.177884474396706, 40.85057057440281, 39.41494680941105, 38.16586263477802, 41.6821825504303, 49.32322673499584, 53.290350660681725, 55.52299305796623, 56.63287930190563, 50.72013817727566, 58.59941057860851, 49.277222603559494, 57.283035814762115, 30.504096262156963, 38.18961516022682, 59.84263926744461, 49.875565096735954, 52.61356517672539, 48.761692866683006, 48.24427083134651, 42.30205088853836, 42.02844277024269, 39.696226716041565, 44.727255553007126, 51.15789368748665, 52.022320702672005, 52.88830943405628, 51.2334868311882, 50.85639126598835, 50.67276991903782, 50.38732923567295, 53.52381393313408, 52.015838250517845, 53.31338122487068, 50.375234484672546, 55.74881874024868, 49.39409293234348, 49.661579579114914, 51.74652010202408, 52.798881232738495, 53.50041478872299, 54.653770700097084, 56.33027873933315, 55.09804666042328, 54.60416816174984, 54.962211549282074, 51.72415070235729, 43.77978779375553, 41.5747395157814, 42.179917842149734, 49.21032339334488, 54.97187063097954, 55.09891301393509, 53.93960662186146, 47.926296293735504, 43.07635433971882, 52.436570674180984, 59.0196718275547, 57.862975895404816, 56.70795947313309, 59.47583734989166, 39.714602530002594, 25.333886593580246, 8.135232366621494, 8.286127019673586, 7.485274393111467, 12.079275380820036, 0.8679236588068306, 0.16709120973246172, 0.06782627140637487, 0.14748739369679242, 11.722870655357838, 40.875778421759605, 43.58127884566784, 40.67939355969429, 39.120189025998116, 19.042072109878063, 33.50779518485069, 41.19599483907223, 44.601653292775154, 19.368936270475388, 0.25980497302953154, 0.0376406243594829, 0.034587792470119894, 0.043049140585935675, 0.03409878023376223, 0.03842348996840883, 0.008828430127323372, 0.09144264986389317, 0.022450429205491673, 0.03910454404831398, 0.08517798836692236, 0.036404967031558044, 0.01822905982407974, 0.05946758457866963, 0.017310948933300097, 0.059857572050532326, 0.018686755283852108, 0.02486457808117848, 0.027344633381289896, 0.06822267474490218, 0.03548344968294259, 0.07444901173585095, 0.07355636393185705, 0.04678543482441455, 0.04708731452410575, 0.029482497375283856, 0.042333732490078546, 0.020096958323847502, 0.04527772842266131, 0.04397016440634616, 0.0443720039766049, 0.056708728516241536, 0.03662175207864493, 0.04310801887186244, 0.015960080600052606, 0.019137693489028607, 0.027536714187590405, 0.02495418128091842, 0.031466527143493295, 0.044804850476793945, 0.5660046252887696, 38.491345569491386, 64.7538149356842, 59.520139172673225, 45.49978069961071, 30.271738730371, 22.930963933467865, 25.759701244533062, 39.69912976026535, 41.33287489414215, 4.320428017526865, 0.07568209752207622, 0.14835952111752704, 0.3140408283798024, 4.276290535926819, 7.0590208657085896, 6.763158291578293, 1.9235154474154115, 15.817900467664003, 48.38056571781635, 67.40544185042381, 62.95107766985893, 60.340347960591316, 61.54204107820988, 59.50269430875778, 55.87209552526474, 47.532147243618965, 49.64946202933788, 58.63385193049908, 59.61194984614849, 60.70181876420975, 58.96669887006283, 50.04554137587547, 45.132834389805794, 45.02722665667534, 51.33440561592579, 56.81178130209446, 54.44564826786518, 56.780546978116035, 55.26473991572857, 52.14443475008011, 44.254693910479546, 40.40479749441147, 42.38761089742184, 48.61869893968105, 53.3636487275362, 54.87149901688099, 53.94773058593273, 54.417191594839096, 52.429677844047546, 50.54548054933548, 55.10042153298855, 54.49947237968445, 54.9186734855175, 54.818518459796906, 52.696244940161705, 42.807313576340675, 42.49941989779472, 40.64957655966282, 44.435784593224525, 51.82247042655945, 56.84456594288349, 55.81876918673515, 58.78341570496559, 53.49376514554024, 58.84939916431904, 51.47185184061527, 57.593809738755226, 32.253083512187004, 39.762213975191116, 60.96744351089001, 51.96098819375038, 57.147162705659866, 49.710760340094566, 50.64431704580784, 44.72835369408131, 43.8856653124094, 41.61548472940922, 47.15742275118828, 53.01580399274826, 55.48642002046108, 54.29142974317074, 53.30401852726936, 53.18384237587452, 52.11392618715763, 51.10504612326622, 55.64159229397774, 54.180806279182434, 55.414691269397736, 53.43515709042549, 57.524288669228554, 50.960893258452415, 51.19745336472988, 51.719385758042336, 56.10498122870922, 55.34823663532734, 56.385702565312386, 56.523350179195404, 56.28997050225735, 55.74357882142067, 57.22945488989353, 55.021948143839836, 46.17631159722805, 42.611133903265, 44.451561346650124, 50.736496299505234, 56.56608268618584, 57.77542859315872, 57.07357585430145, 49.59326684474945, 46.41789123415947, 53.888031989336014, 62.90225028991699, 59.63539458811283, 59.93759237229824, 57.731278762221336, 41.805482134222984, 17.51311395317316, 2.598295114003122, 5.308009274303913, 10.662502404302359, 6.931377165019512, 3.9732810202986, 0.5665358842816204, 0.10887076350627467, 0.14756027259863913, 14.300388246774673, 40.33145383000374, 30.02262219786644, 38.92639942467213, 42.57307134568691, 23.217719346284866, 37.90853664278984, 45.39849333465099, 54.15859267115593, 28.34739089012146, 0.37403304828330874, 0.045370077568804845, 0.023055769379425328, 0.040100502519635484, 0.0848159019369632, 0.01867349124950124, 0.05342348937119823, 0.08161530102370307, 0.06251403028727509, 0.029292401814018376, 0.007777125529173645, 0.0025338000114061288, 0.050718546626740135, 0.056642157869646326, 0.057952230345108546, 0.09816414036322385, 0.04920548934023827, 0.023131284760893323, 0.051658996162586845, 0.053891246498096734, 0.045960815987200476, 0.34683864971157163, 0.22930724546313286, 0.18597389571368694, 0.14810869004577398, 0.09787808696273714, 0.1624396804254502, 0.2105845368350856, 0.17158222733996809, 0.1882464558002539, 0.11622409627307206, 0.15848510200157762, 0.14033249637577683, 0.12891606835182756, 0.13498423882992938, 0.07255308417370543, 0.14433964854106307, 0.07122820214135572, 0.11706406643497758, 0.17199557390995324, 1.2572099198587239, 46.43790476024151, 72.3221804201603, 70.93195661902428, 52.982912957668304, 35.49794219434261, 23.009205535054207, 36.61186382174492, 51.4687056094408, 47.44940668344498, 7.304114839062095, 0.15171316772466525, 0.5595889664255083, 0.18416305538266897, 5.811788616701961, 15.025877617299557, 16.357405968010426, 7.158815385773778, 18.10596004128456, 53.1548423320055, 68.55353504419327, 67.52002850174904, 62.59855158627033, 65.24257510900497, 61.18878163397312, 58.519576862454414, 49.887682646512985, 51.56904302537441, 60.38460798561573, 62.11336322128773, 62.48914025723934, 61.973610520362854, 51.33366085588932, 47.94676959514618, 48.051161393523216, 53.34994286298752, 59.36475031077862, 56.28549434244633, 59.42428171634674, 57.480195835232735, 54.802122339606285, 46.76729008555412, 42.379547730088234, 43.963659927248955, 51.62950538098812, 57.21843168139458, 57.27635957300663, 57.07271710038185, 56.59246847033501, 54.29351583123207, 52.81852997839451, 58.14572632312775, 55.697259306907654, 57.58434824645519, 56.63743905723095, 55.73353596031666, 45.9821268171072, 44.97026011347771, 43.09416018426418, 46.06788441538811, 53.07704150676727, 59.180277809500694, 57.81666398048401, 60.62916286289692, 54.64415721595287, 60.45436464250088, 52.99977645277977, 59.11449573934078, 34.771026000380516, 43.8264948874712, 62.439921498298645, 55.06970018148422, 57.985678911209106, 52.470795437693596, 51.88577502965927, 47.96538859605789, 46.48056507110596, 44.20431241393089, 49.35877002775669, 56.36036932468414, 58.068419471383095, 57.59482428431511, 55.74675165116787, 53.4172410517931, 52.91121460497379, 52.02072858810425, 56.355011612176895, 56.53842017054558, 56.76948957145214, 55.60952201485634, 59.40421499311924, 51.645346730947495, 50.280494168400764, 56.14225722849369, 57.86250092089176, 58.09536002576351, 58.67573708295822, 59.0566286444664, 57.1078310161829, 56.72498635947704, 60.16439840197563, 57.03209728002548, 47.78989881277084, 46.37581989169121, 45.75469762086868, 54.39934015274048, 59.217048436403275, 61.320592761039734, 60.25479555130005, 53.059600442647934, 49.016966968774796, 57.48578913509846, 63.86059686541557, 63.01369450986385, 61.39462798833847, 60.36998637020588, 45.85683614015579, 32.845433726906776, 17.986745238304138, 15.642068702727556, 19.046206288039684, 22.961896173655987, 3.8911118544638157, 0.5188992060720921, 0.23908256232971326, 0.2498680609278381, 18.871531561017036, 58.62613454461098, 58.724902644753456, 49.002045169472694, 49.935016706585884, 27.82213557511568, 47.72109590470791, 54.9773233383894, 61.9107960909605, 37.27267876267433, 1.1488676397129893, 0.14019690599525347, 0.13395032321568578, 0.07421640038955957, 0.3705572441685945, 0.09644589037634432, 0.1522929483326152, 0.12213108711875975, 0.10081429034471512, 0.16186736582312733, 0.148162109835539, 0.1193957905343268, 0.12631343066459522, 0.15298275975510478, 0.1959923846879974, 0.1360255165491253, 0.08852097031194717, 0.28648325242102146, 0.14809660788159817, 0.17341941391350701, 0.17674563074251637], [0.07863378952606581, 0.06184397483593784, 0.04392716808069963, 0.055516913562314585, 0.008189338932425017, 0.013860411236237269, 0.030595629832532723, 0.04002885187219363, 0.013737633107666625, 0.026338967618357856, 0.038755248533561826, 0.08602233720012009, 0.012508507606980857, 0.030401780859392602, 0.12799392017768696, 0.017070541325665545, 0.07756520077236928, 0.01686871240963228, 0.12195761752082035, 4.103869087994099, 46.67229898273945, 58.6946676671505, 51.78702212870121, 36.221647560596466, 26.357977241277695, 26.565468907356262, 55.17015919089317, 49.635683968663216, 21.749071553349495, 0.45584108505863696, 0.07672488922253251, 0.07746331131784245, 0.34005034365691245, 2.1549617405980825, 2.87945793941617, 6.196711286902428, 7.826310843229294, 30.793555229902267, 54.920691177248955, 61.70466095209122, 55.11664666235447, 59.12725165486336, 55.599030777812004, 57.14291453361511, 53.0262116342783, 46.888355389237404, 43.30233961343765, 52.72895738482475, 55.03835566341877, 56.532458290457726, 47.24153883755207, 42.992777824401855, 42.70387552678585, 45.38645178079605, 48.37914079427719, 53.840758726000786, 54.117684066295624, 54.24721151590347, 52.045404464006424, 53.79649870097637, 42.44312211871147, 37.911112904548645, 40.0301755964756, 43.13868619501591, 51.662480011582375, 49.81215789914131, 50.8559200912714, 48.742089718580246, 51.619492918252945, 49.76591058075428, 52.36323080956936, 54.322348684072495, 56.47619470953941, 50.864465832710266, 46.61930322647095, 39.34121556580067, 40.29091760516167, 38.551131561398506, 46.71197645366192, 52.01512388885021, 54.41413655877113, 52.15533256530762, 54.54498253762722, 52.00213998556137, 55.05308747291565, 47.640528827905655, 55.56183837354183, 26.99925173074007, 34.65846464037895, 60.37590265274048, 50.65510846674442, 54.61200334131718, 51.98266223073006, 54.58148717880249, 52.964176163077354, 47.19238467514515, 37.703397050499916, 40.5286518484354, 42.1683132648468, 49.57679092884064, 54.005582481622696, 54.515195935964584, 52.74215787649155, 53.85199472308159, 52.27461576461792, 51.58956952393055, 51.62627175450325, 56.256543695926666, 51.43719010055065, 50.4424262791872, 51.32248945534229, 52.537063881754875, 53.5423531383276, 50.93029350042343, 52.02375702559948, 54.41027216613293, 56.14335156977177, 55.240022242069244, 54.350398778915405, 55.494509786367416, 53.81429694592953, 42.4200763553381, 40.99211297929287, 42.78857298195362, 53.06465417146683, 56.54857702553272, 56.92568399012089, 55.8098928630352, 53.774361088871956, 48.591636791825294, 44.706090688705444, 55.00818148255348, 56.62372559309006, 54.411256313323975, 56.48765489459038, 57.60011740028858, 40.8285241574049, 13.102078847587109, 6.875563859939575, 8.137440048158169, 3.2008684426546097, 2.8271786822006106, 0.11935385919059627, 0.012607199332705932, 0.1376948886900209, 2.438571397215128, 29.789880886673927, 34.792282059788704, 35.13456769287586, 40.205403193831444, 26.16066712886095, 35.84151975810528, 44.38509911298752, 49.326874539256096, 34.146407917141914, 1.8530085682868958, 0.058288122672820464, 0.12026848198729567, 0.009101510786422295, 0.04521657174336724, 0.008565880543756066, 0.03412019490497187, 0.020492083313001785, 0.05080943003122229, 0.04625016823410988, 0.020943082745361608, 0.022606860948144458, 0.04803619856829755, 0.018918874957307708, 0.03866627987008542, 0.05053549219155684, 0.03488845133688301, 0.03921774754417129, 0.04526794691628311, 0.032748253288445994, 0.0472051341785118, 0.04705509418272413, 0.03134475184197072, 0.04949876754835714, 0.06062344247766305, 0.024865758095984347, 0.0493383857246954, 0.006472958693848341, 0.030233513716666494, 0.04161259130341932, 0.02360978818614967, 0.04466983154998161, 0.06049671705113724, 0.07796648002113216, 0.040870573502616026, 0.050084741378668696, 0.042260423142579384, 0.029167604116082657, 0.08195938295102678, 0.05742159475630615, 5.199786806479096, 56.06592312455177, 64.89695325493813, 59.64780852198601, 41.96981951594353, 32.46954649686813, 25.484328120946884, 44.94513586163521, 57.04193115234375, 24.046758860349655, 0.5590987333562225, 0.04130032524699345, 0.12486646533943713, 1.5815842640586197, 5.606069080531597, 6.472532311454415, 3.889120048843324, 6.791093917563558, 31.545648872852325, 56.61610320210457, 62.00975798070431, 60.67518599331379, 60.36778248846531, 58.88534523546696, 58.38411793112755, 55.303573831915855, 48.38718496263027, 46.155511513352394, 54.965513572096825, 58.55004362761974, 58.18239815533161, 50.51261231303215, 45.32883167266846, 44.15543183684349, 46.062883883714676, 51.31447188556194, 55.60318015515804, 55.2122001349926, 57.1190670132637, 54.287447556853294, 54.907904863357544, 45.0337091088295, 39.84230227768421, 39.761028438806534, 46.16150379180908, 53.371746093034744, 52.27544791996479, 53.968675062060356, 51.62701651453972, 53.9771182090044, 51.89663104712963, 52.78657369315624, 56.72115616500378, 57.2325175255537, 54.121844843029976, 48.45247685909271, 41.538227275013924, 41.98486290872097, 40.84980681538582, 49.69489239156246, 54.40295375883579, 55.375313982367516, 53.643100932240486, 56.22636191546917, 52.19461105763912, 55.48902288079262, 47.798980325460434, 56.441673561930656, 28.804052285850048, 35.23188427090645, 60.26899918913841, 53.19697447121143, 57.00464375317097, 54.70801658928394, 57.25859932601452, 52.633688896894455, 48.558175787329674, 41.247117295861244, 43.29636253416538, 44.95356000959873, 53.165804743766785, 55.31517080962658, 55.73530666530132, 54.915253669023514, 54.94121767580509, 53.3181157708168, 53.01487684249878, 53.6969668418169, 56.76925778388977, 54.13379520177841, 50.89684009552002, 50.43537765741348, 53.72700423002243, 55.2930673956871, 53.71957182884216, 52.82678313553333, 56.13395847380161, 58.25452208518982, 57.275884598493576, 54.81515184044838, 56.559520438313484, 56.94775700569153, 44.21316213905811, 42.59120397269726, 45.30140094459057, 54.60431255400181, 58.23425777256489, 60.3985608369112, 58.15080285072327, 54.192179068923, 50.170182287693024, 46.37025699019432, 56.4949619024992, 59.6506317704916, 57.52062186598778, 58.47503945231438, 60.19006222486496, 45.6524109095335, 13.184883054345846, 1.7743257153779268, 5.159455770626664, 6.485927542671561, 8.043480589985847, 1.4158593630418181, 0.0385342666413635, 0.1602237462066114, 2.6944724656641483, 34.81263376772404, 34.899379312992096, 37.42137998342514, 41.79102770984173, 30.44712021946907, 42.03193858265877, 50.216068625450134, 57.18833729624748, 44.09382954239845, 3.1190213095396757, 0.04398547491291538, 0.07216036930913106, 0.009742225429363316, 0.12292957864701748, 0.0127260106819449, 0.021793257437821012, 0.05722850277379621, 0.040203349344665185, 0.04096910102816764, 0.06417822223738767, 0.0209731174618355, 0.0289725899710902, 0.06500927178421989, 0.07971210041432641, 0.0726262821990531, 0.019248481294198427, 0.03528549292241223, 0.013059194170637056, 0.040806733959470876, 0.06421868412871845, 0.1565374986967072, 0.13939051801571622, 0.15621427854057401, 0.14828457904513925, 0.11863553445436992, 0.12046040137647651, 0.11691369989421219, 0.09512123098829761, 0.14376559731317684, 0.14898377121426165, 0.22604506113566458, 0.2849554375279695, 0.16761179664172232, 0.16612564591923729, 0.15749898069771007, 0.1336647299467586, 0.13420795236015692, 0.2228958168416284, 0.2572240505833179, 7.422189703211188, 68.20993468165398, 73.57696428894997, 67.59886667132378, 49.18400980532169, 39.065950736403465, 39.52441893517971, 68.16738456487656, 59.845910891890526, 32.03644573688507, 0.8084148145280778, 0.1605708635179326, 0.28812378470320255, 1.262223394587636, 6.663200855255127, 10.2093605697155, 13.479201961308718, 13.301537744700909, 36.73708610236645, 57.29672648012638, 64.52129781246185, 60.425531789660454, 63.14241640269756, 60.41642367839813, 61.70887492597103, 59.37916673719883, 51.043516024947166, 48.14698465168476, 57.4530690908432, 59.52681541442871, 62.045821845531464, 52.67079770565033, 47.109750509262085, 46.63696467876434, 48.74946892261505, 53.04014168679714, 57.64958694577217, 55.88563799858093, 58.16792853176594, 56.49781934916973, 58.07095393538475, 46.764265447854996, 41.45730681717396, 43.07974375784397, 48.3948415517807, 57.061101123690605, 54.54002380371094, 55.64022436738014, 53.3506116271019, 57.175725772976875, 55.3386839479208, 56.59600228071213, 59.14307780563831, 59.905894473195076, 56.52072452008724, 50.20586997270584, 43.96278977394104, 44.79258544743061, 42.58483551442623, 52.193756103515625, 58.99321764707565, 57.71549440920353, 54.76419657468796, 58.55319745838642, 55.499559715390205, 56.61714434623718, 49.91081960499287, 54.87197019159794, 30.815043076872826, 38.51304240524769, 61.098452880978584, 56.31347604095936, 59.314915984869, 58.81146959960461, 58.58895733952522, 56.395924016833305, 51.39570012688637, 44.4681778550148, 44.850061163306236, 47.927067652344704, 53.67445684969425, 58.4279827773571, 58.29479992389679, 56.62635125219822, 57.06352159380913, 54.62046168744564, 53.47628228366375, 54.55658331513405, 58.658482208848, 54.727870523929596, 51.42500415444374, 51.61133095622063, 55.76573543250561, 59.08289663493633, 56.47019103169441, 56.04866825044155, 58.71433921158314, 60.515324771404266, 60.73963813483715, 57.08063967525959, 58.82062330842018, 60.557111129164696, 48.23118433356285, 44.97893124818802, 47.21035771071911, 57.33796186745167, 61.802004128694534, 62.63351731002331, 60.00259168446064, 57.58091703057289, 55.07322259247303, 50.12372598052025, 60.367478504776955, 62.52299264073372, 61.19712978601456, 60.076942294836044, 61.45976409316063, 49.713066816329956, 18.53524010628462, 15.018224827945232, 17.35511653125286, 12.454384602606297, 7.789595313370228, 0.8452540752477944, 0.11500248408992775, 0.45289674773812294, 3.7844178546220064, 45.24598851799965, 48.55521194636822, 45.43535515666008, 47.119280397892, 40.38625828921795, 49.15578491985798, 58.59615795314312, 63.5854422301054, 53.84115770459175, 4.482899699360132, 0.16892858926439658, 0.1867045697872527, 0.12468937406083569, 0.16834490495966747, 0.10222167693427764, 0.09821239480515942, 0.19382032623980194, 0.15258764033205807, 0.14501834259135649, 0.17629633453907445, 0.09256374556571245, 0.15373155707493424, 0.14491202251520008, 0.11036697032977827, 0.13307022512890399, 0.13352532492717728, 0.1396264467621222, 0.14155910321278498, 0.15880047023529187, 0.10893899656366557], [0.015969580090313684, 0.022762788030377124, 0.05124742703628726, 0.05228221467405092, 0.017580866187927313, 0.019999477226519957, 0.04412326947203837, 0.058821415150305256, 0.0679146166658029, 0.016887724377738778, 0.008538329238945153, 0.018298662143934052, 0.12347484196652658, 0.05269781737297308, 0.01856939390563639, 0.09174453327432275, 0.1257987364078872, 0.04846130446821917, 0.02995594677486224, 10.548379328101873, 51.38641342520714, 50.91612406075001, 47.00210988521576, 35.02882316708565, 15.299132354557514, 35.089764297008514, 54.238946959376335, 33.54323588311672, 12.576371356844902, 0.07366490302956663, 0.34886759240180254, 0.07770882861223072, 1.23757898574695, 4.693415528163314, 7.026891214773059, 1.8724370445124805, 17.870642468333244, 47.98596069216728, 56.160766035318375, 55.48258222639561, 58.50024729967117, 58.426151275634766, 56.10678233206272, 52.71257646381855, 50.96767969429493, 47.51167394220829, 44.11735787987709, 43.0108268558979, 45.62508277595043, 44.72450830042362, 44.072345495224, 40.94576306641102, 44.7650483250618, 49.381789192557335, 53.46230663359165, 52.89797231554985, 52.786360904574394, 51.99107497930527, 53.328124433755875, 55.1646912842989, 46.514554247260094, 39.367247968912125, 39.69495378434658, 39.16212357580662, 49.72492977976799, 51.153250336647034, 51.37095205485821, 48.912290185689926, 47.85731479525566, 46.246193647384644, 49.523236602544785, 49.39878948032856, 48.80819097161293, 44.441795870661736, 41.614804565906525, 37.707873210310936, 41.01553872227669, 39.17505428195, 47.55574777722359, 52.35053189098835, 54.81297455728054, 49.275413900613785, 55.651999935507774, 53.817785158753395, 58.00356075167656, 48.80286745727062, 55.179936066269875, 26.22250121086836, 31.363127566874027, 58.30117978155613, 49.019376039505005, 56.39259159564972, 50.4594873636961, 55.67077472805977, 52.96588987112045, 56.00734926760197, 41.60135328769684, 40.116788148880005, 41.252315416932106, 41.34587399661541, 47.9059673845768, 50.74739411473274, 52.83857770264149, 54.37081888318062, 52.29760833084583, 50.648284032940865, 49.07492145895958, 51.77591532468796, 51.274410635232925, 49.46816235780716, 51.22659780085087, 53.06673265993595, 50.793291851878166, 49.874356761574745, 47.762528881430626, 52.44621455669403, 52.67742834985256, 56.06218792498112, 55.87682247161865, 54.739634692668915, 50.10032303631306, 42.358101680874825, 41.16208925843239, 44.295176938176155, 54.93023246526718, 58.36856156587601, 56.82243213057518, 56.859670132398605, 53.38488198816776, 52.45266281068325, 45.66696032881737, 47.06902429461479, 49.90367978811264, 55.94946317374706, 56.17805890738964, 59.202453419566154, 55.89588604867458, 33.775437623262405, 11.063561383634806, 7.9237110167741776, 3.4437183989211917, 7.316247588023543, 1.5669516054913402, 0.03036899091966916, 0.022794416508986615, 0.3695999033516273, 15.023461896926165, 43.477206230163574, 29.15067918598652, 18.92201755195856, 23.687655329704285, 21.170476600527763, 42.88775905966759, 44.43330332636833, 44.17742885649204, 6.511168638244271, 0.02780766117211897, 0.13014982949243858, 0.07037137780571356, 0.026651890475477558, 0.025649100534792524, 0.015849880946916528, 0.029080858184897806, 0.023102483864931855, 0.0637968399678357, 0.05100988782942295, 0.02043304732069373, 0.024812163901515305, 0.005771424121121527, 0.020991899364162236, 0.06224963646673132, 0.04306261798774358, 0.019532642218109686, 0.003232506073800323, 0.07022780933766626, 0.024521859850210603, 0.042209745588479564, 0.047599953031749465, 0.03545439460140187, 0.01736704787617782, 0.02906824909587158, 0.04245363757945597, 0.058780136896530166, 0.07612581277498975, 0.06876008614199236, 0.010109831582667539, 0.026041709643322974, 0.0059614663405227475, 0.08507777616614476, 0.023116801748983562, 0.04262539281626232, 0.019336138211656362, 0.06829945734352805, 0.06831448583398014, 0.08906578834285028, 15.027658771723509, 61.2676540017128, 57.34908007085323, 54.23005923628807, 38.36818277835846, 21.464732810854912, 37.418416142463684, 57.042193338274956, 39.943285658955574, 13.122812435030937, 0.06166189632494934, 0.18005621794145554, 0.18663226976059377, 2.8453877801075578, 6.992303095757961, 8.886837735772133, 5.225820634514093, 20.225322917103767, 49.975792318582535, 56.089018285274506, 59.48838047683239, 62.70114228129387, 60.3154630959034, 58.407988250255585, 54.42846558988094, 52.95852206647396, 48.698612451553345, 45.89180566370487, 45.65947473049164, 48.93650248646736, 46.808384880423546, 44.194185957312584, 43.842286840081215, 46.04823186993599, 51.495212987065315, 54.79575388133526, 54.86846677958965, 53.75714421272278, 53.01939480006695, 54.823629185557365, 59.20579344034195, 48.83923150599003, 41.00458391010761, 41.77134096622467, 42.62958191335201, 52.48635560274124, 52.207005992531776, 52.578337267041206, 51.270466446876526, 50.714518278837204, 47.965426594018936, 52.60931700468063, 51.09741233289242, 52.76222079992294, 46.87865450978279, 42.34167896211147, 40.68606600165367, 43.17685894668102, 41.703377813100815, 50.23562617599964, 54.415466487407684, 55.98961941897869, 50.4193577170372, 56.968944668769836, 55.16084589064121, 58.48506711423397, 49.69542056322098, 54.31479848921299, 27.390205152332783, 31.94450967013836, 58.80958490073681, 51.85296759009361, 57.12552286684513, 52.412996739149094, 57.55215637385845, 53.74441109597683, 57.010643631219864, 44.51340302824974, 41.79998762905598, 42.64943964779377, 43.880592584609985, 49.272799640893936, 51.858826875686646, 55.21539196372032, 55.60516744852066, 54.83785182237625, 51.160264760255814, 50.17500042915344, 53.0038346350193, 52.67887607216835, 49.63757246732712, 51.338167414069176, 56.363587751984596, 53.06918352842331, 51.99906215071678, 50.393739491701126, 53.01564820110798, 56.072029396891594, 58.42123053967953, 56.99152685701847, 57.399898543953896, 52.540312707424164, 44.50414292514324, 42.17499330639839, 46.031163185834885, 55.97778305411339, 59.43651705980301, 58.470810279250145, 58.89422155916691, 57.038556933403015, 54.08515401184559, 47.48049281537533, 48.84809263050556, 52.98258997499943, 57.9393669962883, 58.816014155745506, 60.20631395280361, 58.610878363251686, 37.73450218141079, 10.271548982709646, 2.2587562585249543, 4.287816267460585, 10.332860592752695, 3.93835733179003, 0.15586450434057042, 0.04880942367890384, 0.3653698100242764, 18.55655126273632, 37.888439521193504, 25.682785771787167, 26.05263512581587, 29.09139856696129, 29.084323346614838, 48.738350719213486, 50.380026027560234, 53.759446889162064, 11.8759910389781, 0.05209178329096176, 0.12945520895300433, 0.05054314373410307, 0.03279531287262216, 0.02628292433655588, 0.057039069579332136, 0.05863899896212388, 0.032606380627839826, 0.04694025054050144, 0.048646173454471864, 0.05710509845812339, 0.033357742067892104, 0.007634584471816197, 0.02070443773845909, 0.05429129378171638, 0.04594119731336832, 0.03280644137703348, 0.03214775562810246, 0.02099243185512023, 0.05008090447518043, 0.1471208914881572, 0.25511816202197224, 0.12944835150847211, 0.1374032543390058, 0.21944533480564132, 0.1704433572012931, 0.18889289611252025, 0.15316013304982334, 0.16018698021071032, 0.10072021570522338, 0.05810858972836286, 0.11289409449091181, 0.31417028862051666, 0.150470515654888, 0.10321012116037309, 0.2059825384640135, 0.18498488003388047, 0.21329678973415866, 0.1465610004379414, 19.9644498154521, 70.45832723379135, 65.03741651773453, 62.750566229224205, 49.819176122546196, 24.707991778850555, 46.946667060256004, 65.10047793388367, 46.06571853160858, 18.497825413942337, 0.1406161897466518, 0.5708628427237272, 0.3667246748227626, 3.999755149707198, 11.379756666719913, 15.882916878908873, 8.754312247037888, 23.476854041218758, 52.63126082718372, 56.87106192111969, 60.191464349627495, 63.86449545621872, 63.054264932870865, 60.76491817831993, 57.16137394309044, 55.76383173465729, 51.20016261935234, 48.92079032957554, 46.614139303565025, 50.50005778670311, 48.06286856532097, 47.37692557275295, 45.34143939614296, 48.993248641490936, 54.14009906351566, 57.48192474246025, 57.98869214951992, 55.334906950592995, 54.691578671336174, 58.07143650949001, 60.64156919717789, 51.080491840839386, 44.32144112884998, 43.58806148171425, 44.556222930550575, 54.506304413080215, 56.07059687376022, 56.23035930097103, 53.830571472644806, 52.136037200689316, 50.39051726460457, 56.012870371341705, 53.306780979037285, 53.619492799043655, 48.90413962304592, 44.70552071928978, 42.215882912278175, 45.4817620664835, 43.55510205030441, 52.98520803451538, 56.658436730504036, 58.33344765007496, 52.642135843634605, 59.51060548424721, 59.4337660074234, 60.79537354409695, 52.884779423475266, 54.425817131996155, 29.7448818013072, 33.25802318751812, 59.325156435370445, 53.59219506382942, 58.29937107861042, 53.731845170259476, 58.05994972586632, 56.648754850029945, 59.626590460538864, 47.980105206370354, 44.62182641029358, 45.369858071208, 44.26827058196068, 52.77352139353752, 54.10386800765991, 57.955459132790565, 58.6144083738327, 57.25348100066185, 53.130234852433205, 50.45513279736042, 53.3038779348135, 53.327611461281776, 50.76002083718777, 52.719651684165, 57.4956002086401, 55.536869913339615, 54.49459344148636, 52.404808178544044, 56.22766524553299, 59.75682467222214, 62.0554543286562, 61.134281158447266, 58.437151685357094, 54.79001998901367, 46.492226645350456, 44.345075860619545, 48.48731338977814, 60.222223699092865, 63.48780646920204, 59.21527773141861, 60.929023772478104, 58.69601659476757, 56.86016410589218, 50.885018929839134, 51.869648694992065, 55.66643536090851, 61.415230482816696, 61.40495963394642, 63.360406905412674, 59.833151176571846, 39.37193691730499, 16.86442606151104, 15.36866007372737, 12.19906110316515, 16.144207008183002, 6.303385812789202, 0.17820801789639518, 0.12427356356056407, 0.6831893872004002, 23.069667890667915, 60.53706720471382, 40.557594895362854, 27.57416658103466, 32.19384089112282, 32.629483714699745, 56.74679338932037, 57.084321677684784, 63.30790512263775, 17.637414783239365, 0.28965427132789046, 0.2244340960169211, 0.2929100434994325, 0.15766185242682695, 0.10207230487139896, 0.18491626105969772, 0.1132133293140214, 0.056923405863926746, 0.24674323329236358, 0.11679989896947518, 0.1855755553697236, 0.16967189469141886, 0.1325129167526029, 0.17523543443530798, 0.1326293745660223, 0.11256999117904343, 0.08275612301076762, 0.12553113279864192, 0.20208207744872198, 0.14196845702826977], [0.1037739084858913, 0.023848926721257158, 0.07261530583491549, 0.03807448018051218, 0.03878343530232087, 0.010790889373311074, 0.02900685492932098, 0.04423613157996442, 0.02005501213716343, 0.05376412402256392, 0.07756496328511275, 0.019899578583135735, 0.03512263603624888, 0.03348473095684312, 0.06054451507225167, 0.05437500432890374, 0.002697643490137125, 0.019655749674711842, 0.09124126067035832, 21.775354743003845, 55.316865518689156, 54.37035910785198, 37.24599279463291, 24.78644046932459, 19.813763201236725, 35.37035644054413, 46.44913695752621, 35.22373370826244, 3.5568772768601775, 0.190736539370846, 0.0515715637448011, 0.2681751816999167, 2.797890091314912, 4.109083833172917, 6.384465862065554, 4.360826974734664, 33.77575300633907, 52.357508316636086, 58.132278844714165, 50.53467392921448, 57.63471834361553, 53.495459854602814, 56.60732947289944, 49.82611075043678, 50.20134061574936, 45.843529254198074, 43.637949004769325, 43.994343280792236, 41.78503543138504, 39.228304624557495, 41.541495099663734, 43.75151731073856, 49.02230568230152, 51.97590999305248, 55.201306119561195, 55.70251062512398, 62.06846483051777, 49.727730229496956, 53.637663424015045, 52.661233618855476, 52.02144294977188, 38.272933289408684, 40.12076273560524, 37.58639372885227, 41.810714453458786, 45.57796910405159, 45.979987531900406, 42.52245046198368, 43.41104418039322, 41.525554955005646, 44.507368952035904, 39.096546694636345, 40.31028896570206, 40.26349067687988, 41.51019237935543, 38.15407946705818, 42.10818909108639, 40.147874280810356, 41.90407544374466, 51.1603407561779, 56.32347330451012, 51.918020099401474, 55.98292417824268, 51.434670835733414, 57.66310662031174, 50.4727790504694, 62.3491595685482, 27.855077907443047, 28.066542260348797, 52.183344662189484, 48.082904890179634, 53.15650664269924, 49.57762308418751, 51.98793634772301, 51.004685908555984, 52.808973491191864, 46.92098043859005, 39.2015540599823, 40.228198170661926, 43.128985315561295, 40.59080511331558, 42.718044966459274, 46.46110251545906, 53.340412974357605, 54.39491719007492, 54.775538966059685, 50.450489446520805, 51.919745206832886, 50.08924663066864, 50.511939749121666, 54.73399579524994, 51.435666382312775, 50.30295476317406, 46.87800474464893, 44.16285663843155, 45.997994765639305, 48.08448940515518, 51.72658637166023, 51.718819588422775, 51.88750393688679, 46.66134417057037, 40.225230529904366, 40.71299135684967, 42.472452744841576, 53.67857202887535, 55.66640496253967, 53.97491432726383, 54.50364835560322, 56.51525281369686, 56.253610253334045, 51.226518005132675, 44.879988357424736, 47.220541164278984, 48.14683645963669, 53.65150988101959, 52.13017411530018, 60.75492091476917, 54.98428836464882, 26.108085550367832, 5.528664859011769, 3.383277654647827, 11.874345727264881, 3.5382473515346646, 0.37892050633672625, 0.04269209333870094, 0.04177727758360561, 6.50386163033545, 29.954915530979633, 34.1531677544117, 23.647890463471413, 22.904777638614178, 21.01982418447733, 40.22412098944187, 45.05464218556881, 49.92347672581673, 23.39793037623167, 0.23886920971563086, 0.09064907135325484, 0.013569497696153121, 0.0800176797201857, 0.0708349677734077, 0.016688155301380903, 0.06697838252875954, 0.0873468852660153, 0.03049989463761449, 0.027060904758400284, 0.09910251930705272, 0.028170172481623013, 0.06289589495281689, 0.008212890061258804, 0.014647075713583035, 0.03875475871609524, 0.03450651616731193, 0.04399143435875885, 0.07495857033063658, 0.039140682929428294, 0.02210547711001709, 0.013520165284717223, 0.0416523889725795, 0.04939861100865528, 0.01645071813982213, 0.015556638918496901, 0.06385394081007689, 0.043161431240150705, 0.025426916363358032, 0.021158309282327536, 0.027404250104154926, 0.03651722057838924, 0.023304663445742335, 0.0602824887027964, 0.033388441006536596, 0.03286885970737785, 0.030791109675192274, 0.0536148484388832, 0.1861594177898951, 28.239383585751057, 65.64406156539917, 62.136849761009216, 43.09574469923973, 32.14962646365166, 24.05081894248724, 32.59776681661606, 50.486393719911575, 34.952261075377464, 4.630064852535725, 0.23861943249357864, 0.0928705716796685, 0.5665650358423591, 5.256795147433877, 9.11453576758504, 8.161240071058273, 7.807453880086541, 30.915148705244064, 56.03985272347927, 57.87412449717522, 54.01715286076069, 57.0245660841465, 57.780052945017815, 58.585134744644165, 52.70025372505188, 50.25463655591011, 48.71102258563042, 45.80128692090511, 46.35358348488808, 44.06061552464962, 42.4329424649477, 43.37491191923618, 45.0436569750309, 50.87664417922497, 54.56634119153023, 56.281067579984665, 57.34351336956024, 60.4068785905838, 50.422944724559784, 56.11701898276806, 56.519861966371536, 55.52158333361149, 40.63903972506523, 42.53358006477356, 40.02636060118675, 45.3679733723402, 47.98840016126633, 49.01712276041508, 45.53883880376816, 46.19458481669426, 45.675285682082176, 45.93452297151089, 42.41721510887146, 42.29477807879448, 40.26945635676384, 42.27185770869255, 40.18140748143196, 43.6953829228878, 40.78203745186329, 44.3195716291666, 53.99244278669357, 58.863956183195114, 52.13717333972454, 58.13849151134491, 52.741504311561584, 58.450511768460274, 52.09087662398815, 63.24069432914257, 28.74087307602167, 28.93967840820551, 52.085032537579536, 49.78082858026028, 53.690632581710815, 50.85323363542557, 52.75731526315212, 53.92657332122326, 55.62513157725334, 48.85529324412346, 40.02235561609268, 43.007836416363716, 44.021302834153175, 42.533952444791794, 45.6812209635973, 48.65858539938927, 55.74639447033405, 56.29042647778988, 56.257151663303375, 50.297080278396606, 52.28201776742935, 49.548208862543106, 50.745741203427315, 55.82317315042019, 52.43415020406246, 53.630356416106224, 47.15068191289902, 45.26827052235603, 47.82221607863903, 50.16357444226742, 55.79246699810028, 53.810941725969315, 53.22965271770954, 49.74325619637966, 42.75827340781689, 43.27842369675636, 44.11997593939304, 55.32740615308285, 57.306377962231636, 56.94716423749924, 56.59122973680496, 59.176504611968994, 57.07459419965744, 55.188641399145126, 47.21047170460224, 49.90080714225769, 50.562085658311844, 54.642470106482506, 55.607443526387215, 62.279497906565666, 56.446655094623566, 29.373252242803574, 5.754913743585348, 2.39604574162513, 8.178799878805876, 10.593253020197153, 1.181404700037092, 0.17426662001525983, 0.04991166511899792, 7.694256054237485, 34.990361630916595, 32.456042021512985, 28.463024385273457, 23.901296965777874, 24.34183392673731, 47.512072920799255, 52.03696511685848, 57.355615720152855, 32.886859104037285, 0.6526153371669352, 0.03378613568202127, 0.03848280612146482, 0.04441214674443472, 0.013800838114548242, 0.06575325998710468, 0.017300605250056833, 0.0712103905971162, 0.034513911668909714, 0.011852426796394866, 0.08000426911166869, 0.019583653738663998, 0.05330810396117158, 0.012627746618818492, 0.01748741680785315, 0.017178369816974737, 0.051362348604016006, 0.040576953906565905, 0.09967906415113248, 0.0663539617380593, 0.12357444560620934, 0.1829591582645662, 0.16244345053564757, 0.11159225614392199, 0.09568627254338935, 0.19223266455810517, 0.0973778497427702, 0.13614645693451166, 0.07236456382088363, 0.11747235897928476, 0.12463019520509988, 0.05953103078354616, 0.17111416964326054, 0.12644145113881677, 0.17785353848012164, 0.16941061418037862, 0.1560892563429661, 0.14649058546638116, 0.5390570650342852, 35.70765294134617, 73.94793838262558, 70.3441509604454, 51.42656207084656, 37.05291375517845, 29.92567040026188, 46.16397365927696, 57.47033916413784, 47.84197121858597, 5.532255191355944, 0.3394364984706044, 0.14056394255021587, 0.6737080053426325, 5.024877917021513, 16.148411482572556, 13.132640607655048, 9.252633657306433, 36.25036261975765, 54.71858002245426, 59.378133192658424, 54.63853731751442, 62.28139400482178, 59.770097360014915, 61.04656286537647, 54.74061504006386, 53.93772952258587, 51.182801350951195, 49.435263723134995, 48.01931530237198, 46.773346960544586, 43.83919380605221, 45.937547609210014, 47.83605493605137, 53.62345598638058, 56.91366143524647, 59.000156074762344, 59.756068512797356, 61.84700891375542, 52.627651020884514, 58.1480859965086, 57.8344090282917, 56.956165954470634, 43.762665912508965, 44.93812523782253, 41.636877581477165, 48.036000207066536, 50.4497978836298, 50.276789367198944, 47.85921849310398, 48.15006248652935, 47.41106674075127, 47.97329977154732, 43.07383507490158, 44.138009771704674, 43.16852979362011, 46.482244580984116, 43.32992613315582, 45.829071030020714, 43.8507641851902, 45.51479749381542, 56.366091817617416, 62.113712802529335, 55.16514725983143, 59.60881121456623, 56.10763728618622, 61.8875565379858, 54.79619465768337, 65.22806748747826, 32.30749659240246, 31.406173557043076, 51.773304864764214, 50.329826921224594, 56.26929581165314, 53.04570458829403, 55.78151598572731, 54.74259093403816, 55.89077532291412, 49.801218286156654, 42.541183456778526, 44.129220843315125, 46.665307357907295, 44.913627952337265, 48.029988929629326, 50.148230865597725, 59.60001848638058, 58.6778611689806, 58.319905176758766, 51.13161809742451, 53.90466369688511, 49.321068450808525, 50.944823920726776, 57.39601135253906, 56.46339699625969, 56.255745738744736, 50.80907620489597, 48.93894575536251, 50.716980546712875, 52.53941975533962, 57.95824058353901, 56.07438527047634, 55.64458653330803, 51.03471949696541, 44.09663379192352, 43.72176490724087, 48.136010840535164, 57.271442636847496, 60.47134593129158, 57.78418332338333, 57.932493165135384, 61.08129300177097, 59.75320726633072, 56.73945978283882, 49.45597641170025, 52.63957858085632, 52.23221763968468, 57.902018800377846, 58.41063670814037, 66.09579652547836, 58.90117898583412, 30.51385223865509, 8.528866544365883, 11.006829477846622, 24.999523535370827, 9.29118923842907, 1.083279715385288, 0.29433179064653814, 0.12488783919252455, 9.445556905120611, 49.033173099160194, 47.2106958925724, 32.83621542155743, 34.38398636877537, 32.697895243763924, 53.724693953990936, 59.67952162027359, 65.65175995230675, 41.52891017496586, 1.39764076564461, 0.3197506454307586, 0.18048606987576932, 0.17166577832540497, 0.19522181275533512, 0.12326416850555688, 0.20830937923165038, 0.24365791759919375, 0.12787152518285438, 0.12971859716344625, 0.24782489868812263, 0.147708716976922, 0.12111869378713891, 0.07003141479799524, 0.13443601434119046, 0.1108009040763136, 0.10100214276462793, 0.1078505405166652, 0.22819635429186746, 0.1529512630077079], [0.028203981019032653, 0.04525915617705323, 0.018265720063936897, 0.05055100307799876, 0.03497527519357391, 0.01285114884012728, 0.074050404218724, 0.02563998325058492, 0.030523383611580357, 0.042647397494874895, 0.004060725486851879, 0.005847755865033832, 0.016605949458607938, 0.03080944443354383, 0.005269713738016435, 0.015352690243162215, 0.028368737803248223, 0.0378402546630241, 0.750532461097464, 31.82499658316374, 61.849091202020645, 49.20691877603531, 41.131755486130714, 19.478351399302483, 19.539657309651375, 39.70110185444355, 43.130623027682304, 19.418705999851227, 0.5781132692936808, 0.13103829900501296, 0.14940765628125519, 0.7113427889999002, 3.2357738446444273, 5.923983296379447, 6.175317959859967, 13.476638048887253, 41.020391061902046, 58.27975653111935, 58.98803472518921, 53.02105151116848, 56.90616063773632, 56.44209913909435, 56.44329987466335, 49.56964731216431, 47.89507336914539, 43.987446650862694, 43.44581991434097, 44.77681629359722, 41.50903344154358, 42.73711994290352, 42.500955015420914, 48.30575533211231, 52.73563742637634, 55.85142843425274, 54.22533228993416, 57.05922782421112, 54.38062235713005, 49.869819805026054, 54.54820476472378, 54.22112591564655, 53.445921912789345, 42.570517882704735, 38.48362058401108, 39.71732318401337, 39.44703608751297, 38.114310801029205, 39.60867941379547, 39.41745087504387, 38.44083487987518, 38.80765579640865, 39.83310677111149, 38.1967967748642, 38.948563635349274, 37.99586355686188, 39.89592880010605, 39.14237983524799, 42.03452244400978, 40.553472116589546, 40.14580339193344, 40.48108600080013, 48.255028054118156, 46.19706608355045, 51.11978933215141, 49.061352387070656, 53.79065461456776, 48.36022920906544, 61.99554294347763, 32.02130354940891, 25.28825294226408, 59.82090063393116, 50.993126928806305, 56.445556953549385, 49.22328069806099, 54.19352039694786, 51.23778440058231, 55.45896649360657, 48.52392062544823, 42.8979767113924, 39.3660244345665, 42.84787639975548, 39.093898236751556, 40.59697978198528, 38.61212968826294, 45.35351134836674, 51.47055611014366, 53.3266045153141, 51.78028129041195, 52.34386704862118, 48.85099187493324, 56.311097368597984, 52.25968636572361, 51.94238819181919, 46.01347893476486, 40.89915096759796, 40.21791212260723, 40.99527060985565, 42.130911871790886, 46.636227518320084, 48.9658597111702, 48.674476146698, 41.49472340941429, 40.4107441753149, 40.492056012153625, 42.23800532519817, 46.26944459974766, 54.23678867518902, 55.721707195043564, 54.535673037171364, 56.15936391055584, 53.53863313794136, 53.47506634891033, 54.08144921064377, 49.6558228880167, 53.00515316426754, 51.39126196503639, 55.67389436066151, 53.862968534231186, 58.640752360224724, 49.50986512005329, 23.494861274957657, 2.020800202153623, 8.625134378671646, 7.633417518809438, 1.0252736904658377, 0.052046935306862, 0.03371604354470037, 1.2698774901218712, 17.503502368927002, 36.432562842965126, 33.44758361577988, 23.90001643449068, 23.568700812757015, 34.084015265107155, 44.285160675644875, 43.25498655438423, 42.98000290989876, 4.8170694429427385, 0.024791107316559646, 0.014155229400785174, 0.02332708001631545, 0.015159080612647813, 0.05350821294996422, 0.07214270619442686, 0.06890327611472458, 0.03842479985905811, 0.07874225440900773, 0.10219251053058542, 0.0672550848685205, 0.032414297966170125, 0.055496255881735124, 0.03733238816494122, 0.01626091016078135, 0.06924968838575296, 0.03185726047377102, 0.011217527808184968, 0.03758588725759182, 0.04781801828357857, 0.06271087753702886, 0.010859276426344877, 0.025864076596917585, 0.08210171945393085, 0.09423814204637893, 0.03741049920790829, 0.03530779074935708, 0.005520433951460291, 0.04833517275983468, 0.01820805704483064, 0.04299288208130747, 0.09661528558353893, 0.062487261020578444, 0.07593696587719023, 0.026421075126563665, 0.03550953246303834, 0.014637382337241434, 1.002106808591634, 41.96904055774212, 68.61183911561966, 57.49856024980545, 47.20191076397896, 24.997085966169834, 24.229515753686428, 38.959583044052124, 46.62506751716137, 20.708011016249657, 0.6976114539429545, 0.11325388768455014, 0.17594011849723756, 1.8104722257703543, 5.881531499326229, 5.901739289984107, 8.195662423968315, 13.74858945608139, 41.128548458218575, 59.9113167822361, 58.438945189118385, 54.30476322770119, 57.88108952343464, 58.40682551264763, 57.9930505156517, 51.726897954940796, 50.301898419857025, 46.89136102795601, 45.620325431227684, 44.797734171152115, 42.87579730153084, 44.297380819916725, 45.10883867740631, 49.50748644769192, 56.20205461978912, 58.92876550555229, 55.87975591421127, 57.013569474220276, 57.23367266356945, 50.40026754140854, 56.294796243309975, 56.06369264423847, 55.545153468847275, 43.913897797465324, 39.7011436522007, 40.67696548998356, 42.22114942967892, 40.36262355744839, 42.386820539832115, 40.24905905127525, 40.43863087892532, 40.3116150945425, 42.64992222189903, 40.023609548807144, 42.47738488018513, 39.87546309828758, 41.3492976129055, 41.71434782445431, 42.9931616038084, 42.23324418067932, 42.60078325867653, 45.41973799467087, 50.70341147482395, 49.225875958800316, 53.53727661073208, 50.482620522379875, 56.03751204907894, 51.50771051645279, 64.73741501569748, 32.55502291023731, 26.4798766002059, 59.175125285983086, 53.38949874043465, 58.8386495411396, 51.646410673856735, 55.33707283437252, 53.19079600274563, 56.72405920922756, 49.88302789628506, 44.35851953923702, 41.0223213583231, 44.11711469292641, 42.92246259748936, 42.316212728619576, 40.34937746822834, 47.767305225133896, 53.43158148229122, 54.81665275990963, 54.73467595875263, 53.09450536966324, 49.4841481000185, 55.056951865553856, 52.65128195285797, 54.18512284755707, 49.35881942510605, 42.59617790579796, 43.145354837179184, 42.4636410176754, 44.447104185819626, 49.49913449585438, 52.32907444238663, 49.97557193040848, 43.27548265457153, 41.42909713089466, 41.933569461107254, 42.86257781088352, 49.82922278344631, 56.633593663573265, 58.173362240195274, 55.02244971692562, 57.743643298745155, 55.48323579132557, 55.41972219944, 55.045693069696426, 52.118569537997246, 54.66641262173653, 53.870127350091934, 55.69362670183182, 56.479728519916534, 59.7543054074049, 51.465817764401436, 22.58614383637905, 2.323222649283707, 4.047506237402558, 9.948747754096985, 3.114277976565063, 0.1384985604090616, 0.07464079753844999, 1.0717147984541953, 24.876621030271053, 32.94485539197922, 37.46520683169365, 28.18587865680456, 27.344202920794487, 40.809741765260696, 50.10227993130684, 49.46717441082001, 52.38974578678608, 6.383222853764892, 0.03811523150943685, 0.06129606575996149, 0.03275006041803863, 0.026731346661108546, 0.053243121510604396, 0.03307391882117372, 0.04340625091572292, 0.030385525969904847, 0.040744271100265905, 0.017305215842498, 0.006567574637301732, 0.04273710830602795, 0.06665775988949463, 0.044585961441043764, 0.014983607215981465, 0.027967076348431874, 0.022750071329937782, 0.08423645529546775, 0.0383080785832135, 0.1305834366939962, 0.1811639327206649, 0.07083411430357955, 0.14436608384130523, 0.2554905420402065, 0.21054432727396488, 0.23825082258554175, 0.10259446513373405, 0.14907751930877566, 0.21662296203430742, 0.046230861262301914, 0.181792457588017, 0.14490075671346858, 0.17935165262315422, 0.08551742444979027, 0.12816584610845894, 0.12495800183387473, 0.10235130786895752, 1.6081041097640991, 50.537493377923965, 77.65001893043518, 63.94579589366913, 55.96753880381584, 30.281897485256195, 30.604623667895794, 51.3017463684082, 56.58749833703041, 28.53558909147978, 0.9726235968992114, 0.2032653577043675, 0.5363864020910114, 1.8524112878367305, 10.118306055665016, 14.307804498821497, 16.9744111597538, 19.10801377147436, 43.68241801857948, 61.76715239882469, 58.923005014657974, 58.038526475429535, 59.28424023091793, 61.78932800889015, 59.748898297548294, 53.955751955509186, 53.034134209156036, 49.10301715135574, 46.455532014369965, 48.07450354099274, 44.38000738620758, 46.819377690553665, 47.67060421407223, 53.78526270389557, 59.327755495905876, 61.627129912376404, 55.0701067596674, 56.82255372405052, 56.823207288980484, 51.435400396585464, 59.27961587905884, 60.331764221191406, 58.62535558640957, 46.494111344218254, 42.162252590060234, 43.41903895139694, 43.605456948280334, 41.52830220758915, 43.309099450707436, 42.07669638097286, 43.25147934257984, 43.558464869856834, 45.92763014137745, 42.54758611321449, 42.5932102650404, 42.3437612503767, 43.2253747433424, 43.78241345286369, 46.17543384432793, 44.52492021024227, 45.4220824688673, 46.35392166674137, 52.82721251249313, 51.69727474451065, 55.690632462501526, 53.54932576417923, 57.41847574710846, 53.87303799390793, 67.55096644163132, 35.7896563410759, 29.67861145734787, 60.36562420427799, 55.655662938952446, 60.203752890229225, 52.26760894060135, 58.06922882795334, 56.041220650076866, 59.83462169766426, 52.48961582779884, 45.97755566239357, 43.05533766746521, 46.062496304512024, 43.97157110273838, 43.67822304368019, 42.387686893343925, 49.98756028711796, 55.40929555892944, 58.170576989650726, 56.180429980158806, 55.624413415789604, 50.08915923535824, 58.91877964138985, 55.458879098296165, 57.27646976709366, 51.708005368709564, 44.427010864019394, 45.24653188884258, 44.85154688358307, 47.4588605761528, 52.234444320201874, 55.074795708060265, 53.88425499200821, 44.86982770264149, 43.900906294584274, 44.19164389371872, 46.729596108198166, 50.738031417131424, 59.952764958143234, 61.06272719800472, 58.298877105116844, 59.9962118268013, 58.32071453332901, 58.15212517976761, 60.35083159804344, 55.20339220762253, 58.44439409673214, 57.11733430624008, 59.42466929554939, 60.16376383602619, 62.61101491749287, 56.67920641601086, 26.45188920199871, 4.521817686036229, 15.929333288222551, 16.090367697179317, 2.2754342760890722, 0.35617884539533406, 0.12366733280941844, 1.5702583780512214, 30.20126771181822, 51.6020480543375, 47.906111776828766, 35.692985728383064, 34.512130692601204, 46.92226096987724, 59.20822151005268, 56.89768709242344, 59.28955614566803, 8.800245132297277, 0.16303420008625835, 0.16954258288023993, 0.11612291928031482, 0.1244052873516921, 0.15573963057249784, 0.22815961798187345, 0.10867093282286078, 0.18142558430554345, 0.16620875161606818, 0.14483709528576583, 0.1940511490101926, 0.12423566950019449, 0.24519643426174298, 0.09770305885467678, 0.0749972065386828, 0.17395632807165384, 0.10609334261971526, 0.14140911516733468, 0.11507876944961026], [0.03690088866278529, 0.01675960185821168, 0.03232004521123599, 0.06328340736217797, 0.021158481831662357, 0.021232581566437148, 0.021953975083306432, 0.013918006534368033, 0.031021242248243652, 0.00766345494412235, 0.07229384456877597, 0.09484491456532851, 0.005119479392305948, 0.046098350794636644, 0.03761744708754122, 0.0789316430746112, 0.05632257423712872, 0.10237837399472483, 3.2872309209778905, 48.76444771885872, 56.28068760037422, 48.5858117043972, 35.185249373316765, 23.228220082819462, 26.443370059132576, 37.41484433412552, 39.16405387222767, 11.435062699019909, 0.05325995713064913, 0.0987314603116829, 0.02733139532210771, 1.5947616007179022, 5.56735010817647, 7.18189487233758, 5.625581033527851, 22.82030437141657, 50.21087810397148, 60.70099800825119, 57.38432697951794, 56.7324947565794, 54.35224547982216, 59.16405647993088, 53.47085237503052, 50.426436737179756, 45.53764566779137, 42.19837345182896, 42.283583879470825, 42.865066677331924, 40.35272888839245, 44.41573306918144, 45.397577583789825, 52.297087758779526, 54.295989498496056, 53.184370547533035, 52.319400161504745, 51.400894448161125, 50.578903555870056, 54.43643756210804, 52.804626524448395, 54.21632677316666, 48.03900584578514, 39.432615861296654, 38.754242062568665, 39.541597813367844, 38.70300181210041, 38.26643943786621, 39.410603642463684, 38.073869571089745, 38.7861717492342, 39.29993458092213, 39.26214560866356, 37.89508156478405, 39.243294820189476, 38.13903607428074, 39.46972467005253, 37.5029806047678, 37.971594259142876, 38.19495767354965, 39.06326428055763, 37.274601459503174, 39.689976051449776, 38.08985151350498, 42.942012548446655, 41.75637736916542, 51.25658579170704, 47.58497200906277, 58.6968981474638, 35.16674816608429, 30.89075781404972, 58.51002037525177, 48.153178319334984, 54.0024134516716, 48.79255101084709, 52.1455404907465, 48.79919305443764, 51.09604820609093, 47.39566996693611, 41.8144154548645, 39.220560640096664, 41.3071046769619, 39.37126815319061, 40.21078370511532, 38.98778893053532, 40.29551915824413, 44.21792708337307, 51.86362981796265, 51.19630962610245, 53.76586094498634, 53.117509335279465, 55.04872910678387, 51.7988470941782, 50.40535546839237, 41.68253593146801, 39.47843760251999, 40.19749581813812, 40.93660555779934, 40.016929507255554, 44.03020195662975, 44.86708804965019, 43.2992085814476, 42.688752338290215, 40.983293652534485, 41.17372803390026, 41.78040727972984, 41.73032596707344, 48.09860944747925, 53.099707290530205, 55.81879198551178, 53.54624792933464, 56.81787237524986, 55.01485772430897, 53.94688323140144, 56.811735704541206, 56.99799410998821, 57.181607857346535, 54.12149906158447, 57.65668496489525, 58.501166850328445, 58.84237714111805, 42.94452041387558, 11.128153167665005, 2.7495773462578654, 19.286980368196964, 2.839121916331351, 0.06713496084557846, 0.06601705637876876, 0.09953052329365164, 6.1750211007893085, 35.352235212922096, 30.30226819217205, 17.943858839571476, 20.02523895353079, 26.241747178137302, 43.70136760175228, 46.434754729270935, 53.47867615520954, 17.232797294855118, 0.18424227222567424, 0.07100411065039225, 0.04131127192522399, 0.10735013260273263, 0.09342248464236036, 0.04702885555161629, 0.1275751114008017, 0.09580445956089534, 0.03951360842620488, 0.03701752830238547, 0.02752849304670235, 0.006955793478482519, 0.026008865897892974, 0.014174873122101417, 0.07983917093952186, 0.03817806544248015, 0.01722923290799372, 0.04233588100760244, 0.036390060995472595, 0.026837922778213397, 0.022172064454935025, 0.056800120291882195, 0.05486099973495584, 0.05585591177805327, 0.03350045706611127, 0.0750804903509561, 0.016774433679529466, 0.0540060307685053, 0.03454505218542181, 0.03518336598062888, 0.05121773370774463, 0.015853196491661947, 0.0643256795592606, 0.020893071268801577, 0.03482286774669774, 0.046933419071137905, 0.09544897824525833, 5.628944803029299, 58.797961324453354, 61.99134036898613, 55.88451325893402, 41.79738476872444, 31.153084337711334, 25.08406899869442, 39.95573379099369, 42.864819690585136, 13.882218785583973, 0.08992074988782406, 0.11999818438198417, 0.11518976505612954, 3.934599095955491, 10.476282946765423, 6.766960462555289, 5.338912541046739, 23.83515391498804, 54.10590469837189, 61.04852356016636, 59.56097938120365, 58.703866973519325, 57.05808788537979, 60.67352928221226, 56.22433662414551, 54.244924038648605, 48.42284984886646, 45.67011035978794, 44.231085777282715, 44.96551416814327, 44.29372541606426, 46.1459132283926, 47.54959210753441, 54.13260206580162, 55.486275628209114, 56.18914291262627, 53.86963717639446, 51.67380340397358, 51.14247791469097, 56.603126898407936, 55.084150806069374, 55.89590884745121, 52.11659364402294, 40.36713011562824, 40.295906737446785, 39.94171254336834, 40.93927301466465, 39.32036228477955, 41.82640001177788, 39.988503232598305, 39.79923538863659, 40.80286793410778, 42.27545231580734, 40.4085136950016, 40.73571413755417, 41.21172599494457, 41.03093169629574, 40.822509080171585, 40.54966852068901, 39.490919932723045, 41.59271255135536, 38.744544982910156, 41.88789591193199, 39.17217403650284, 45.31519040465355, 42.86314018070698, 53.13260592520237, 50.61483822762966, 60.94190888106823, 38.36929231882095, 32.09601134061813, 61.51334881782532, 50.27477167546749, 54.87656034529209, 49.16960097849369, 54.582725912332535, 52.86395274102688, 54.46925260126591, 49.0928602963686, 44.65496823191643, 40.09790316224098, 43.39116744697094, 40.08500285446644, 43.07917378842831, 41.28360293805599, 42.58119910955429, 45.7886715978384, 54.5937567204237, 53.157221004366875, 55.2790879458189, 56.84735879302025, 56.447418853640556, 52.99502670764923, 52.78142876923084, 44.96282011270523, 41.50736913084984, 40.56938946247101, 43.32010746002197, 42.27662645280361, 46.01724073290825, 45.604050904512405, 45.66188000142574, 43.317819982767105, 43.186328038573265, 42.85278953611851, 44.39650610089302, 43.348921313881874, 51.49552837014198, 55.18085181713104, 57.16662526130676, 53.71517166495323, 59.40559811890125, 57.04350806772709, 56.22695468366146, 58.60318377614021, 58.82172904908657, 58.72771829366684, 57.402615398168564, 58.564425855875015, 61.431812793016434, 59.49629545211792, 43.76719906926155, 10.683582723140717, 2.037035543471575, 9.043986853212118, 6.023324690759182, 0.28370138606987894, 0.14020855771377683, 0.03978241431468632, 7.730471910908818, 36.79782584309578, 29.4770360738039, 25.916199646890163, 22.80684359371662, 28.219643644988537, 50.218865275382996, 52.48122587800026, 61.01388841867447, 23.679820150136948, 0.20003659970825538, 0.055409881024388596, 0.03837703894532751, 0.06448349726269953, 0.04509110796789173, 0.051810394288622774, 0.0941263152344618, 0.034513329082983546, 0.05711688005249016, 0.04648587804695126, 0.024099511028907727, 0.051560798892751336, 0.0445826551731443, 0.021397509044618346, 0.05790474773675669, 0.015024416061351076, 0.038226995238801464, 0.029837108522769995, 0.08101379033178091, 0.1100781858258415, 0.10615139341098256, 0.16269748768536374, 0.1671163536957465, 0.12554474378703162, 0.08120444064843468, 0.14298257214250043, 0.2779676718637347, 0.12431890136213042, 0.12558007001644, 0.1636822137515992, 0.17125439102528617, 0.1440724011627026, 0.15696208138251677, 0.09107550940825604, 0.20534246577881277, 0.20372599392430857, 0.1918655537883751, 7.706354130059481, 67.91481211781502, 69.81575891375542, 64.66897308826447, 49.15230430662632, 35.31582176685333, 37.52423666417599, 49.803661555051804, 51.14527456462383, 18.040605448186398, 0.1758483742014505, 0.22836422809632495, 0.27332259924151003, 4.580316497012973, 12.735552415251732, 15.848710164427757, 11.64722241461277, 26.164077445864677, 54.28150087594986, 62.133076563477516, 60.284274369478226, 59.85301651060581, 58.021488189697266, 64.79421436786652, 58.984679505228996, 57.4531526863575, 50.645635575056076, 47.84933142364025, 45.391798093914986, 47.730105221271515, 45.004910454154015, 49.42890286445618, 48.958982080221176, 57.8988041728735, 57.88140870630741, 58.323419988155365, 53.48054185509682, 52.38146223127842, 52.87244528532028, 57.25530870258808, 57.373246774077415, 60.123865976929665, 53.55939142405987, 42.66101382672787, 42.82391108572483, 42.78395622968674, 42.981329038739204, 41.57513089478016, 43.98969992995262, 42.2220765799284, 41.59097604453564, 43.72722141444683, 43.46204124391079, 42.549174427986145, 42.59163714945316, 43.08879867196083, 43.34401197731495, 41.913555935025215, 41.17568872869015, 42.0990239828825, 44.6123269200325, 41.460795029997826, 45.29073491692543, 42.403551042079926, 47.017001286149025, 45.64367517828941, 56.77882947027683, 52.867486551404, 62.88113482296467, 41.109750866889954, 34.108060374855995, 62.70790211856365, 53.25899474322796, 57.36451484262943, 52.026720866560936, 56.59076236188412, 53.987180069088936, 55.507714077830315, 50.24882286787033, 46.5292214602232, 43.685910031199455, 45.511997044086456, 43.25606569647789, 44.0819475799799, 42.91851080954075, 46.159045323729515, 48.604525700211525, 55.128999799489975, 55.972421541810036, 58.21624293923378, 57.97904446721077, 58.20415198802948, 54.505369663238525, 54.9557138979435, 47.13985629379749, 43.72301883995533, 43.134988993406296, 45.386653169989586, 43.18972885608673, 49.07086707651615, 49.6342970430851, 47.733551636338234, 46.896004378795624, 44.6924190223217, 44.147452265024185, 46.15998387336731, 44.39619071781635, 52.91028365492821, 57.54712164402008, 60.00133015215397, 57.987529411911964, 59.58842530846596, 59.88497279584408, 59.17767494916916, 62.090560644865036, 62.349778935313225, 63.67504522204399, 59.1417820751667, 62.581935077905655, 63.18042956292629, 62.377905026078224, 46.734372451901436, 15.808376278728247, 9.610508903861046, 30.539075285196304, 7.758356239646673, 0.30806787544861436, 0.25405427848454565, 0.5172040814068168, 11.099052429199219, 52.136952951550484, 39.92334432899952, 27.918918281793594, 30.07823221385479, 39.0917931497097, 57.81123787164688, 59.583208188414574, 68.35893228650093, 29.535454139113426, 0.5594882124569267, 0.20423620560904965, 0.17619330959860235, 0.14108041796134785, 0.1345183333614841, 0.16406300972448662, 0.24567657412262633, 0.1473914785310626, 0.11788840696681291, 0.12189084649435245, 0.1061436157033313, 0.16992872231639922, 0.20996604580432177, 0.10025091862189583, 0.11065047816373408, 0.24005566636333242, 0.15111649583559483, 0.07257505174493417, 0.21861531684407964], [0.04653716416214593, 0.060889161031809635, 0.028955255256732926, 0.027552733445190825, 0.07181473629316315, 0.025277366185036954, 0.03748876981262583, 0.02450382566166809, 0.13116565154632553, 0.0588258977222722, 0.03448792907875031, 0.11128404221381061, 0.06426929860026576, 0.06797851558076218, 0.008343632362084463, 0.05334982379281428, 0.05229417438386008, 0.08108466543490067, 11.766715552657843, 47.61214815080166, 51.45048938691616, 45.79530604183674, 33.0045235902071, 14.117428064346313, 38.29435274004936, 44.721844643354416, 31.46919507533312, 4.748387653380632, 0.08017254367587157, 0.011648238778434461, 0.11798702355008572, 1.866626087576151, 4.421058492735028, 3.341902387328446, 9.016916155815125, 38.171927109360695, 57.64432802796364, 61.14662669599056, 56.90350458025932, 61.027879267930984, 55.07611803710461, 56.79419584572315, 51.69194743037224, 50.73195554316044, 45.34478321671486, 41.44368834793568, 39.9493957310915, 39.96289260685444, 40.78311279416084, 41.448179706931114, 47.31197185814381, 53.423180133104324, 55.95577843487263, 55.118136182427406, 53.40130090713501, 48.32221984863281, 54.944409504532814, 53.81886050105095, 48.668392673134804, 49.22028265893459, 43.34103673696518, 40.26440642774105, 39.76351350545883, 39.19364668428898, 38.620512038469315, 39.066782891750336, 41.215518191456795, 39.32755909860134, 38.912207186222076, 37.99484521150589, 38.897988349199295, 39.01536025106907, 38.941446617245674, 37.667405381798744, 41.26981347799301, 36.82320088148117, 40.85134953260422, 44.55479420721531, 46.03259190917015, 46.21260724961758, 47.43166163563728, 41.445641443133354, 44.91203583776951, 40.51361985504627, 49.61716376245022, 46.74321837723255, 60.61685912311077, 33.76232832670212, 31.84758447110653, 61.492054760456085, 49.168499037623405, 52.45048172771931, 45.999092906713486, 49.8453339189291, 47.93478883802891, 48.12708891928196, 45.875379145145416, 42.789355739951134, 39.97423119843006, 42.54515044391155, 39.387478083372116, 39.73254896700382, 38.93170014023781, 40.42658172547817, 39.14424553513527, 42.169457003474236, 46.24311201274395, 51.257919520139694, 52.36454173922539, 52.80097872018814, 48.58771540224552, 43.474728763103485, 40.739380940794945, 38.82601261138916, 38.081313371658325, 38.443186953663826, 38.4120362251997, 39.612737596035004, 38.88714373111725, 40.82133874297142, 39.72836159169674, 38.92499350011349, 41.85645639896393, 42.51214541494846, 45.68670406937599, 51.32684022188187, 51.26725181937218, 55.62429942190647, 55.83302602171898, 49.84845735132694, 54.136379063129425, 58.1910502910614, 55.465669333934784, 57.38629147410393, 55.86442373692989, 56.48800827562809, 58.96560072898865, 55.646752417087555, 57.2610691934824, 57.53104470670223, 29.164747931063175, 4.300549384206533, 4.986387882381678, 6.8263014033436775, 0.49689535866491497, 0.06108068708272185, 0.018412455647194292, 2.6139585860073566, 21.217660568654537, 38.86792816221714, 28.92925936728716, 24.060933999717236, 24.004011154174805, 47.27224878966808, 44.85005736351013, 49.45941522717476, 29.078011885285378, 2.2934284480288625, 0.07804921464412473, 0.023918234037410002, 0.08066152993706055, 0.09732790320413187, 0.003240544228901854, 0.0079614058995503, 0.02818872431816999, 0.016990599033306353, 0.033680175547488034, 0.04774502434884198, 0.00929289119085297, 0.03205159926437773, 0.007505396506530815, 0.03873923298669979, 0.03671519589261152, 0.02264572165586287, 0.016576649468333926, 0.09469478551181965, 0.022670937978546135, 0.18850485677830875, 0.11828434275230393, 0.027801818614534568, 0.029347402378334664, 0.014248393981688423, 0.06354776036459953, 0.06252838342334144, 0.031459643723792396, 0.0542450765351532, 0.049924322447623126, 0.006592379531866754, 0.028355958020256367, 0.019109933455183636, 0.06470450141932815, 0.044921341686858796, 0.06683288447675295, 0.12242750832228921, 17.145318388938904, 56.2001471221447, 58.30521896481514, 50.43982341885567, 38.12736690044403, 18.357945419847965, 37.353272438049316, 49.42474968731403, 37.10307486355305, 5.885533159598708, 0.22220566403120756, 0.16686460236087441, 0.38158184790518135, 4.894790947437286, 4.982409495860338, 4.25219127908349, 8.510400485247374, 37.77089282870293, 58.6052280664444, 63.72682124376297, 59.486351385712624, 61.847263500094414, 59.04619440436363, 56.876974403858185, 52.34410643577576, 52.076319605112076, 46.275547072291374, 43.41666787862778, 42.26110428571701, 40.84574483335018, 42.309232503175735, 43.161606565117836, 49.52535688877106, 56.565250530838966, 57.9057539999485, 54.95129473507404, 52.56232112646103, 48.63210842013359, 54.53438490629196, 56.36754333972931, 51.28745533525944, 51.533989906311035, 46.363109573721886, 42.182858884334564, 40.37687659263611, 42.21836797893047, 40.89739926159382, 40.924222022295, 43.56151610612869, 41.187760680913925, 39.94427740573883, 40.912077873945236, 40.13447619974613, 39.88874338567257, 39.844141378998756, 39.71963346004486, 41.34545221924782, 40.4440113902092, 42.42857649922371, 46.14630840718746, 48.93603131175041, 48.26765097677708, 48.63655038177967, 43.5016655176878, 45.63053548336029, 43.313985988497734, 52.194785848259926, 49.064772203564644, 62.26947404444218, 35.70626601576805, 32.65583910048008, 63.69411639869213, 50.20044006407261, 53.938386887311935, 47.823857590556145, 52.6691447943449, 50.5208844691515, 51.40462964773178, 47.28919968008995, 43.49878527224064, 41.18545800447464, 43.68338316679001, 40.80833584070206, 41.036467999219894, 40.9709557145834, 42.53389164805412, 40.48570275306702, 44.76792097091675, 47.3364919424057, 52.15862698853016, 55.60745492577553, 54.303733482956886, 51.340705677866936, 46.59605607390404, 42.34550155699253, 40.12003697454929, 39.82228875160217, 42.60901741683483, 40.00172272324562, 41.65857061743736, 41.31802909076214, 41.66319116950035, 43.4498742967844, 41.84661492705345, 43.38981091976166, 43.96819308400154, 47.76909492909908, 54.22307141125202, 53.01647275686264, 57.54313565790653, 55.23876450955868, 52.39654362201691, 56.31353683769703, 60.002090111374855, 57.84544363617897, 59.162031188607216, 58.515704870224, 57.643305882811546, 60.70307269692421, 59.789502918720245, 58.077466785907745, 60.244365110993385, 31.68894298374653, 4.877722263336182, 3.749583223834634, 4.298013020306826, 2.1639190474525094, 0.06568271885043941, 0.10760508259409107, 2.5556789757683873, 28.473929800093174, 36.89005069434643, 37.48324826359749, 27.271545119583607, 28.03229469805956, 54.29704584181309, 51.179662719368935, 57.70473338663578, 37.58319430053234, 3.3709841268137097, 0.05398731380410027, 0.09896397517877631, 0.10541743904468603, 0.060857497301185504, 0.05662514784489758, 0.10018592874985188, 0.022355790533765685, 0.04870575306995306, 0.0629118288634345, 0.03350651670189109, 0.05210640731093008, 0.040064033382805064, 0.04438680611201562, 0.0740727799711749, 0.02242592534457799, 0.02434331767290132, 0.0551277424528962, 0.08740371893509291, 0.14010320242960006, 0.257292150054127, 0.16071583464508876, 0.11057368814363144, 0.10367970025981776, 0.14541617827489972, 0.2796108165057376, 0.16017130605177954, 0.2517546893795952, 0.12875448795966804, 0.14744056417839602, 0.26287176471669227, 0.15956555027514696, 0.20385947660543025, 0.19173031963873655, 0.2195503783877939, 0.15487553318962455, 0.17804933188017458, 23.4687015786767, 67.9935970902443, 66.92225977778435, 58.923297598958015, 44.65844884514809, 22.481429055333138, 49.8259549587965, 53.85923333466053, 44.31691937148571, 7.144661620259285, 0.3514978231396526, 0.3055747045436874, 0.8658459421712905, 4.98094467446208, 12.85107096657157, 10.623995270580053, 17.643323466181755, 42.28193856775761, 60.21960563957691, 65.69051027297974, 61.82318799197674, 66.44566655158997, 59.59059879183769, 60.057836920022964, 54.89943891763687, 55.40785163640976, 49.41356308758259, 45.340869426727295, 44.20919895172119, 43.019224405288696, 45.57696595788002, 45.53312391042709, 51.59035608172417, 58.1740690022707, 59.39924106001854, 55.8793531358242, 53.259078338742256, 49.71862971782684, 57.12341018021107, 58.48975606262684, 53.01344811916351, 54.115069806575775, 47.66832433640957, 44.418617114424706, 43.20396289229393, 44.84992817044258, 42.37907275557518, 44.15918603539467, 46.170201525092125, 43.36529083549976, 42.49090455472469, 43.190762400627136, 42.44138561189175, 44.03788514435291, 41.54066674411297, 41.455623507499695, 43.930765092372894, 41.93818621337414, 45.990406572818756, 49.144282937049866, 52.28264473378658, 51.18853144347668, 51.48239627480507, 45.73860928416252, 48.80803517997265, 46.081164702773094, 54.441544488072395, 51.70711241662502, 64.49159860610962, 38.88581000268459, 35.47026067972183, 66.94053679704666, 53.03011402487755, 56.27941466867924, 50.133309066295624, 54.75737974047661, 53.43946985900402, 53.12356621026993, 52.24814638495445, 46.410968005657196, 42.832130044698715, 44.93375927209854, 43.11907544732094, 43.039940893650055, 42.146190851926804, 46.040484085679054, 42.53185115754604, 46.901666074991226, 49.8853799700737, 53.70558477938175, 58.42830576002598, 57.790730372071266, 53.80128264427185, 48.20081636309624, 46.97133153676987, 41.983890160918236, 41.88202142715454, 43.979026302695274, 41.390384808182716, 45.1897781342268, 42.96388417482376, 43.81326399743557, 44.91148866713047, 43.3793880790472, 46.16697549819946, 45.88495083153248, 50.44547751545906, 57.4836802482605, 55.87724044919014, 59.628931134939194, 58.84549677371979, 53.74227561056614, 58.92572946846485, 62.13527664542198, 61.61453738808632, 61.85584343969822, 59.857709258794785, 58.700420558452606, 62.748499140143394, 60.88111214339733, 60.93474626541138, 62.07027733325958, 34.03300680220127, 7.436906788498163, 14.66711986809969, 14.629455339163542, 1.7776751169003546, 0.2341004359186627, 0.09293703842558898, 3.3261479577049613, 36.667223051190376, 52.154747396707535, 39.86377492547035, 34.19023476541042, 35.55527351796627, 60.54698467254639, 59.01448890566826, 63.157999366521835, 46.8955522030592, 4.774972451850772, 0.223644450888969, 0.18034890614217147, 0.22326227452140301, 0.18492874398361892, 0.16167930560186505, 0.36735199741087854, 0.08379535982385278, 0.14663962356280535, 0.2770708902971819, 0.11141125374706462, 0.10099220540723763, 0.12126742018153891, 0.10753056354587898, 0.1916327717481181, 0.13370572618441656, 0.09564617430442013, 0.16564871213631704, 0.13644346443470567], [0.07434476967318915, 0.10862036288017407, 0.051403419056441635, 0.020576636197802145, 0.021286281516950112, 0.04400096724566538, 0.033303439122391865, 0.048327677068300545, 0.009035563543875469, 0.04693642847996671, 0.08186807652236894, 0.0415607188915601, 0.03422742411203217, 0.00864009252836695, 0.0659768097102642, 0.0922184316732455, 0.02549466702475911, 0.10773083951789886, 22.842278592288494, 53.837525099515915, 50.222551077604294, 44.94430750608444, 31.65218375623226, 22.839286252856255, 38.561858385801315, 32.738363072276115, 27.950500287115574, 1.7412926629185677, 0.05564054794376716, 0.06266790718655102, 0.12098104023607448, 5.133098009973764, 10.534727610647678, 3.4053632570430636, 11.029719449579716, 54.22487251460552, 62.98439048230648, 58.826938569545746, 59.46484073996544, 59.01798851788044, 56.14173285663128, 52.82179020345211, 50.55114604532719, 45.92579863965511, 40.866560116410255, 40.9564670920372, 42.093806862831116, 40.04383206367493, 37.766397669911385, 41.817428693175316, 48.50329153239727, 55.25902882218361, 53.0820382386446, 53.906856179237366, 49.585724249482155, 51.08648791909218, 54.292919263243675, 52.22816705703735, 47.661066725850105, 42.652171701192856, 40.03838695585728, 41.69412910938263, 40.333140939474106, 39.31415341794491, 40.23454762995243, 37.54854775965214, 39.114819914102554, 38.4519112855196, 38.77093456685543, 38.94894361495972, 39.225226789712906, 38.98547485470772, 39.91750784218311, 39.52683940529823, 38.74770261347294, 39.49427895247936, 49.52572166919708, 50.92989072203636, 54.616357907652855, 50.84054611623287, 53.264291658997536, 48.35772134363651, 51.9172677397728, 46.391072273254395, 51.313514336943626, 47.08618797361851, 59.52710799872875, 30.96947629004717, 30.44581688940525, 61.89936250448227, 47.739657908678055, 51.97447367012501, 45.21752044558525, 47.78400532901287, 43.52607160806656, 45.98149225115776, 42.53731906414032, 41.5684774518013, 39.070392698049545, 41.39091677963734, 41.53703793883324, 40.992382764816284, 40.23710489273071, 39.568602964282036, 39.293474927544594, 40.47106593847275, 39.94406081736088, 41.217345893383026, 43.59002597630024, 42.90111914277077, 38.50329972803593, 39.79738488793373, 38.378974199295044, 40.37813052535057, 40.2423220127821, 39.22771565616131, 40.470951944589615, 39.273719787597656, 37.604017183184624, 41.32901430130005, 39.700273498892784, 40.55632196366787, 41.26799337565899, 45.63730292022228, 50.243320763111115, 55.992640256881714, 55.203449204564095, 55.63706673681736, 49.13415268063545, 49.94219832122326, 50.422876328229904, 50.9814615547657, 51.86878614127636, 55.6096588075161, 57.264777794480324, 54.668624103069305, 54.669437259435654, 62.3629642277956, 54.678613767027855, 58.43671090900898, 40.64418464899063, 13.450075574219227, 2.9852561373263597, 4.627063488587737, 1.2486552726477385, 0.12519637966761366, 0.06761104858014733, 0.44039767468348145, 16.444554291665554, 31.476517282426357, 27.27996926754713, 25.546654276549816, 18.893741369247437, 35.61577007174492, 47.27833226323128, 43.332475796341896, 38.99962529540062, 5.7954399939626455, 0.24240180297056213, 0.03680769346829038, 0.046560697664972395, 0.053275126629159786, 0.01893564192869235, 0.043699825982912444, 0.02306742109794868, 0.03432116107433103, 0.029321384536160622, 0.032157770910998806, 0.029675149635295384, 0.029002312985539902, 0.05890086948056705, 0.009436413274670485, 0.025555690117471386, 0.027150667519890703, 0.05655364191625267, 0.04238952344167046, 0.06162013938592281, 0.03959947862313129, 0.07009293884038925, 0.031187572385533713, 0.030230348456825595, 0.05502964908373542, 0.01585816702572629, 0.012136547829868505, 0.038484776523546316, 0.012537036691355752, 0.04429483917192556, 0.033182587794726714, 0.021199667316977866, 0.06786314872442745, 0.026520463543420192, 0.031631053861929104, 0.00678836310726183, 0.23360552731901407, 31.5884592756629, 64.61696907877922, 56.58709175884724, 52.03266754746437, 37.56672978401184, 23.822056017816067, 38.89055974781513, 38.522275909781456, 30.523786805570126, 2.087460500188172, 0.14975889993365854, 0.05935167966526933, 1.3915743911638856, 13.516202475875616, 7.243284378200769, 4.9343629740178585, 12.607625629752874, 55.49001082777977, 65.72763428092003, 60.498001500964165, 61.48689463734627, 61.06539085507393, 57.699919044971466, 55.590507835149765, 52.97283589839935, 49.06090781092644, 42.92864866554737, 42.93074235320091, 44.807621240615845, 42.114960327744484, 40.791715532541275, 43.784309551119804, 50.15681840479374, 57.12559886276722, 54.16745759546757, 52.712983042001724, 51.240820437669754, 50.76744183897972, 56.06876917183399, 53.24263662099838, 50.654800683259964, 44.981123730540276, 42.32171103358269, 43.35490979254246, 42.894917875528336, 41.91717714071274, 42.01471410691738, 39.570780247449875, 40.85564710199833, 41.10875532031059, 41.3887394964695, 41.03341296315193, 41.950136572122574, 40.373863354325294, 41.324629336595535, 40.8292081207037, 39.877343997359276, 40.78130789101124, 51.432896330952644, 53.27877268195152, 56.24473012983799, 52.034316658973694, 54.554653018713, 50.63754200935364, 54.419266283512115, 48.776303082704544, 53.2141837477684, 48.96954171359539, 61.499183177948, 32.475120797753334, 32.85926878452301, 62.44329571723938, 50.18790453672409, 53.679654970765114, 47.15993821620941, 49.62947890162468, 45.89188925921917, 47.657886296510696, 44.94733214378357, 43.02529267966747, 41.33794762194157, 42.01390475034714, 43.963530734181404, 42.34585873782635, 41.85081370174885, 41.05029545724392, 40.289561077952385, 42.07370214164257, 42.17361778020859, 44.67036500573158, 47.05110065639019, 45.746235474944115, 40.74708692729473, 39.885840341448784, 39.283701851964, 42.153756245970726, 41.36716805398464, 41.89533971250057, 42.5798349827528, 42.77803994715214, 42.57798068225384, 43.31775538623333, 40.93861944973469, 42.845756113529205, 42.621910125017166, 46.87533728778362, 53.89915019273758, 58.109271079301834, 57.58792765438557, 56.74249202013016, 49.407798796892166, 51.149469539523125, 51.08241453766823, 51.89965948462486, 53.360548093914986, 54.91954363882542, 57.85116232931614, 57.40701176226139, 57.63835854828358, 61.40304833650589, 57.722136452794075, 59.51426848769188, 46.41518957912922, 13.778377957642078, 4.570047073066235, 3.3451362513005733, 2.908957893960178, 0.24351299100089818, 0.16768154368037358, 0.501244937768206, 19.456162489950657, 34.24541160464287, 29.36853289604187, 29.939507357776165, 26.308300606906414, 42.093514278531075, 52.716524451971054, 49.674521684646606, 50.63207410275936, 8.858374413102865, 0.2817384054651484, 0.03695627885463182, 0.0575406315329019, 0.107301625830587, 0.03315732508781366, 0.10636917664669454, 0.021898779705225024, 0.003593125602492364, 0.07919631520053372, 0.037838759235455655, 0.07818841928383335, 0.03307911385491025, 0.001146720669567003, 0.016926074858929496, 0.025622240355005488, 0.03422523106564768, 0.0068863660271745175, 0.020604199562512804, 0.12716681143501773, 0.20977084612241015, 0.12323546965490095, 0.10729328409070149, 0.09551362672937103, 0.21862650843104348, 0.11986899873591028, 0.1652094497694634, 0.12802072655176744, 0.12078577376087196, 0.2996131213149056, 0.17467297555413097, 0.19997929106466472, 0.14857924135867506, 0.19004782632691786, 0.11398460628697649, 0.07688303347094916, 0.6949962442740798, 39.55599904060364, 73.7540651857853, 65.30807599425316, 59.5836565643549, 42.306591644883156, 33.66887614130974, 49.54234577715397, 45.13766773045063, 38.27150836586952, 2.8401803970336914, 0.30634413356892765, 0.1761422646814026, 0.7423124928027391, 13.607978001236916, 24.92046307772398, 9.584242813289165, 16.14718984812498, 60.17241217195988, 66.59501373767853, 63.208662047982216, 64.61792662739754, 64.42747324705124, 61.787162125110626, 57.412536665797234, 56.569597497582436, 50.91187208890915, 45.557393208146095, 45.780357643961906, 45.930799171328545, 43.194714188575745, 42.01067112386227, 45.56479901075363, 52.42110550403595, 59.18680585920811, 57.77227856218815, 54.37552683055401, 51.32239446043968, 52.93528251349926, 57.72732317447662, 56.53780460357666, 52.927698120474815, 46.88256449997425, 44.53269079327583, 46.3181883841753, 45.05264729261398, 44.704186990857124, 43.553319945931435, 41.60698838531971, 42.12751105427742, 44.452781081199646, 42.98494264483452, 42.70789571106434, 43.467174768447876, 41.25461809337139, 44.273438304662704, 43.4007353335619, 42.58586905896664, 43.44017721712589, 53.20832446217537, 54.75452609360218, 58.897314593195915, 54.08780246973038, 56.80249460041523, 52.27282226085663, 57.191616520285606, 52.15285889804363, 55.30582711100578, 52.545005455613136, 63.36822308599949, 35.95043331384659, 35.11876054108143, 65.16180664300919, 51.517893970012665, 56.533666625618935, 48.82427550852299, 52.324750274419785, 48.94907981157303, 49.760461673140526, 46.41558475792408, 44.642523899674416, 43.54724407196045, 44.64338265359402, 45.26123329997063, 45.05946032702923, 44.03441593050957, 44.372335597872734, 43.16743545234203, 45.49344643950462, 42.960585951805115, 46.53966709971428, 48.33233490586281, 46.876864805817604, 42.6442339271307, 42.273438423871994, 42.414251267910004, 45.1732262223959, 44.00462172925472, 43.58909882605076, 44.76281404495239, 43.31212028861046, 44.42481838166714, 45.70397034287453, 42.26330056786537, 45.99582888185978, 45.533557087183, 49.79355029761791, 56.73548139631748, 61.09811469912529, 59.49946068227291, 59.365012496709824, 51.32660463452339, 52.286934703588486, 51.186171770095825, 54.65779468417168, 53.652060851454735, 56.742951795458794, 60.286520048975945, 58.704311549663544, 59.573416113853455, 66.66640430688858, 59.49316821992397, 62.904378175735474, 47.12376795709133, 17.051843404769897, 6.010547401383519, 10.960256326943636, 4.231017865240574, 0.2111607402912341, 0.27263157069683075, 0.5200875923037529, 25.93739490956068, 44.349776208400726, 39.062348529696465, 35.94931997358799, 30.19137304276228, 47.46847786009312, 60.94813294708729, 57.02702075242996, 59.96733717620373, 11.979628577828407, 0.48717770667281, 0.1800379462656565, 0.10102988424478099, 0.19938950630603358, 0.2487044921144843, 0.18070835794787854, 0.21768723148852587, 0.13080655597150326, 0.18505243031540886, 0.21646378620062023, 0.15799981163581833, 0.14221547346096486, 0.10511380416573957, 0.16432445350801572, 0.06366701607475989, 0.09076237503904849, 0.10321176130673848, 0.0960090103035327], [0.018846630591724534, 0.008613209156465018, 0.022501290441141464, 0.0855819096614141, 0.09986351753468625, 0.03141070279525593, 0.03575001428544056, 0.04449900399777107, 0.024107680219458416, 0.07180004176916555, 0.032113219785969704, 0.04239058842358645, 0.08592248865170404, 0.09630249260226265, 0.07793807802954689, 0.047328575601568446, 0.01666926393227186, 1.6397821786813438, 38.61127473413944, 60.4011294990778, 42.620382606983185, 29.48459006845951, 14.083475936204195, 19.281092584133148, 34.55559656023979, 36.42594739794731, 21.381737664341927, 0.08946697853389196, 0.004949810981997871, 0.1158433077216614, 1.6906733228825033, 6.692628376185894, 1.669722672086209, 2.6277603954076767, 24.15095116943121, 61.06405712664127, 60.62677279114723, 57.051985412836075, 55.354673489928246, 54.12679597735405, 54.29760821163654, 47.06854172050953, 42.224136069417, 39.310118034482, 42.93274864554405, 40.62246881425381, 40.90534843504429, 36.71342097222805, 40.07844440639019, 37.77736768126488, 48.33097457885742, 52.86653280258179, 55.136983171105385, 49.26361933350563, 50.43490268290043, 49.59889814257622, 51.6583002358675, 50.593772158026695, 48.13528507947922, 42.40483917295933, 41.44031412899494, 40.1370220631361, 39.85493279993534, 37.808886989951134, 37.569279447197914, 38.50416988134384, 39.084755927324295, 39.533367455005646, 38.7419269233942, 39.8806232213974, 41.51148051023483, 38.3417171984911, 39.99882347881794, 36.366841569542885, 38.48920248448849, 47.16962769627571, 52.515393644571304, 52.73342214524746, 51.90671570599079, 50.89304409921169, 54.89448398351669, 51.45531512796879, 54.10458616912365, 48.607500940561295, 57.56868928670883, 48.466524705290794, 60.45520439743996, 26.610737778246403, 35.172687247395515, 59.0148688852787, 47.54660926759243, 50.860202461481094, 44.60235245525837, 44.75796550512314, 41.528590992093086, 40.8840087801218, 38.78601595759392, 40.878658667206764, 38.96120935678482, 39.84059616923332, 39.937635362148285, 39.22101281583309, 39.48826387524605, 39.77458991110325, 37.253421396017075, 39.82236094772816, 38.0594265460968, 38.975405395030975, 38.84824901819229, 38.86151410639286, 37.385479509830475, 38.29148389399052, 38.361430540680885, 39.470389634370804, 38.932718485593796, 40.681403651833534, 39.702245593070984, 39.76517401635647, 41.068618074059486, 41.074876338243484, 41.01326264441013, 39.876511842012405, 41.87819883227348, 50.469902604818344, 52.768912240862846, 54.24359031021595, 51.41417473554611, 50.444854348897934, 53.12457695603371, 54.44473631680012, 52.67589323222637, 50.066064074635506, 52.4771448969841, 57.92185753583908, 55.56424744427204, 56.49211585521698, 53.18450354039669, 51.95653483271599, 58.34841124713421, 55.81118479371071, 45.88792607188225, 15.760847479104996, 3.8240556651726365, 0.4379099066136405, 4.5485160034149885, 0.2366538840578869, 0.09270150301745161, 0.03742346823855769, 8.580683413892984, 31.867387108504772, 41.10052116215229, 20.475714281201363, 14.793335795402527, 37.075864523649216, 34.51965048909187, 39.398239105939865, 41.028553023934364, 16.314014196395874, 0.6310088653117418, 0.08813089007162489, 0.044531602834467776, 0.06376428937073797, 0.12982276501134038, 0.07166670009610243, 0.09138735986198299, 0.0282537457314902, 0.04084750013134908, 0.04911414209345821, 0.04864396556513384, 0.036381188619998284, 0.04524734860751778, 0.05642444142722525, 0.02834926013747463, 0.09534840239211917, 0.04132575122639537, 0.030151795835990924, 0.0516612411593087, 0.018905147080658935, 0.04272123747796286, 0.05592559573415201, 0.025767304250621237, 0.038387150707421824, 0.023534317333542276, 0.052129443574813195, 0.008161907298926963, 0.023930436800583266, 0.08592084108386189, 0.053999314332031645, 0.11957727532717399, 0.058950081293005496, 0.04033712517411914, 0.045805926056345925, 0.0742373734829016, 2.8813708992674947, 48.71207132935524, 65.56203156709671, 49.00389187037945, 34.81086306273937, 22.20909956842661, 22.195000424981117, 38.24247792363167, 39.64289277791977, 23.89338009059429, 0.07154641280067153, 0.02785487475193804, 0.10238458577077836, 2.2929629730060697, 13.03141973912716, 9.409157708287239, 2.347619477659464, 24.424386397004128, 61.789183616638184, 61.66218303143978, 60.34079633653164, 58.7026472389698, 57.22646065056324, 55.447532907128334, 50.622069239616394, 46.2441835552454, 41.63949944078922, 43.267320692539215, 42.95769050717354, 42.08100154995918, 40.084896460175514, 42.58042775094509, 40.744696855545044, 51.171078979969025, 56.30333058536053, 56.24238945543766, 52.18989551067352, 49.928294867277145, 51.426345482468605, 53.49420212209225, 52.78753884136677, 51.51448555290699, 43.56731839478016, 42.95485205948353, 41.80689565837383, 40.80269694328308, 40.85032358765602, 39.810756370425224, 40.35835638642311, 40.88422156870365, 41.507965698838234, 40.23460082709789, 40.6926928460598, 42.074230313301086, 41.184150874614716, 42.478061243891716, 38.90448600053787, 41.865553110837936, 49.14554066956043, 54.85764876008034, 54.71910059452057, 54.949151650071144, 54.34150345623493, 58.88218380510807, 55.13506047427654, 56.58653698861599, 51.303779259324074, 59.08009998500347, 50.324606001377106, 62.65183612704277, 28.566490933299065, 35.90387441217899, 61.19445852935314, 50.25095455348492, 53.3096232265234, 45.0754688680172, 47.074112221598625, 43.538348749279976, 44.48457017540932, 40.94580866396427, 41.12030670046806, 38.69991257786751, 41.768848299980164, 41.27028085291386, 41.09933942556381, 40.53177148103714, 41.447735130786896, 39.9794103205204, 41.967425644397736, 40.1461947709322, 41.34033389389515, 40.134290009737015, 40.48743546009064, 39.7546523809433, 39.612327218055725, 41.23082377016544, 41.10242486000061, 41.16626903414726, 41.296149864792824, 42.094988599419594, 40.271732434630394, 43.450512662529945, 43.614530861377716, 41.78631216287613, 41.56557820737362, 42.608352452516556, 52.34734006226063, 56.51943638920784, 56.748286709189415, 52.782211527228355, 50.122076869010925, 55.56808903813362, 54.92757260799408, 52.91285611689091, 50.54646089673042, 53.58501344919205, 57.85789176821709, 59.175269678235054, 57.43074528872967, 57.36959517002106, 54.45360504090786, 60.11311635375023, 57.808616012334824, 49.808825477957726, 16.009014062583447, 6.059570470824838, 3.604194950312376, 5.922156544402242, 0.43272665818221867, 0.1665738585870713, 0.02909387545514619, 9.960244037210941, 34.11159798502922, 38.04751418530941, 28.398382253944874, 18.99697992950678, 41.57985404133797, 40.044747814536095, 43.660922572016716, 50.63758000731468, 23.00727143883705, 1.059521371498704, 0.09698194364318624, 0.02245022882561898, 0.008920281106838956, 0.10064421978313476, 0.056826915533747524, 0.058865639730356634, 0.02510408026864752, 0.040333035940420814, 0.06577127933269367, 0.050092441160813905, 0.07453981350408867, 0.027603973176155705, 0.021936777666269336, 0.044289577344898134, 0.058339041424915195, 0.04001456552941818, 0.036478517577052116, 0.1317908664350398, 0.10055341801489703, 0.12668490526266396, 0.19233997911214828, 0.15609020629199222, 0.1498176483437419, 0.19292305485578254, 0.104284513508901, 0.10976667676004581, 0.13517629180569202, 0.16189237619983032, 0.16179435333469883, 0.3175641596317291, 0.2576307475101203, 0.20972432830603793, 0.14257853210438043, 0.19723255798453465, 5.083276033401489, 58.61103795468807, 74.30932939052582, 54.922465682029724, 41.33773483335972, 25.635558106005192, 28.82818479090929, 46.32117122411728, 49.61657099425793, 29.111945964396, 0.4465967451687902, 0.13451297505525872, 0.24416435917373747, 3.6640241649001837, 14.67383410781622, 9.872100166976452, 7.88638086989522, 28.65856759250164, 64.42596092820168, 65.1466378569603, 62.50312350690365, 60.595500469207764, 59.261323660612106, 58.93614090979099, 51.045822501182556, 47.42655850946903, 42.94843800365925, 46.98491960763931, 44.72319357097149, 45.03736451268196, 41.89946249127388, 44.264144003391266, 43.4957530349493, 52.304436564445496, 60.31187228858471, 58.34374509751797, 53.153618797659874, 52.00392968952656, 51.17110177874565, 55.26555687189102, 55.00636138021946, 53.837019726634026, 46.381356194615364, 46.70653134584427, 43.41331645846367, 42.243511229753494, 42.258193641901016, 40.46535864472389, 41.67967468500137, 45.006445571780205, 43.7545495480299, 43.374699130654335, 44.1985747218132, 45.600038319826126, 43.12866613268852, 44.77007545530796, 41.36891596019268, 44.04890075325966, 52.844938561320305, 58.18529739975929, 56.61262258887291, 56.422173008322716, 54.71216216683388, 61.39887236058712, 57.24434249103069, 58.891063928604126, 53.04196938872337, 61.69886626303196, 52.45752274990082, 64.24930080771446, 30.902311094105244, 38.739844635128975, 63.07749308645725, 51.718021631240845, 56.28516376018524, 47.623832523822784, 48.20299744606018, 45.322296023368835, 46.002334132790565, 43.58182981610298, 43.963298946619034, 40.956634283065796, 43.126173466444016, 44.026740342378616, 42.714974731206894, 41.76805034279823, 43.7217953056097, 40.78077971935272, 46.13752707839012, 41.503455340862274, 43.81379596889019, 43.4873440861702, 43.41655008494854, 42.251547798514366, 41.08398824930191, 43.115857020020485, 43.6345823854208, 42.963648587465286, 45.338707342743874, 43.83505962789059, 41.52082800865173, 46.63408823311329, 45.654576793313026, 45.11245608329773, 44.02133323252201, 46.35717049241066, 56.10597677528858, 59.51736532151699, 60.57468518614769, 53.87274920940399, 51.78381510078907, 56.014850065112114, 57.111292630434036, 53.751490116119385, 52.0698257535696, 54.102275893092155, 61.90365247428417, 62.708916664123535, 61.93952254951, 58.911107853055, 56.08744136989117, 63.011570423841476, 59.4967932254076, 50.6388833373785, 19.464763328433037, 11.473636329174042, 7.236316027119756, 16.19448211044073, 1.1713446211069822, 0.24585826671682298, 0.3242520976345986, 12.569732163101435, 49.569020345807076, 53.76000925898552, 32.286981493234634, 23.435854241251945, 47.5067114084959, 45.52304305136204, 51.79596304893494, 58.55128616094589, 30.521358735859394, 1.2847821903415024, 0.2733702748082578, 0.12257812719326466, 0.17627334280405194, 0.230249238666147, 0.15504621231229976, 0.12147686167736538, 0.09834261203650385, 0.09176933584967628, 0.1778429257683456, 0.1825973464292474, 0.15758768218802288, 0.12288882731809281, 0.1706894682138227, 0.1441250936477445, 0.20248691900633276, 0.23848971992265433, 0.2118868872639723], [0.06072274183679838, 0.07541799684986472, 0.010185010214627255, 0.022127724841993768, 0.05666172088240273, 0.024905969512474257, 0.007132989585443283, 0.008113283638522262, 0.019493230465741362, 0.040830386205925606, 0.07208334922324866, 0.03481232182821259, 0.04422250945935957, 0.020320333642303012, 0.018303183678654023, 0.035925443153246306, 0.05456484570458997, 3.141304263845086, 41.97295054793358, 53.31867054104805, 44.82847072184086, 31.7776283249259, 21.498830281198025, 32.66810104250908, 35.7988366484642, 36.722411289811134, 9.883796889334917, 0.11156964290421456, 0.19816417596302927, 0.39289309876039624, 3.7622897420078516, 24.122777581214905, 4.108015140518546, 3.2846458721905947, 36.043463721871376, 63.85381042957306, 59.59874175488949, 51.42270527780056, 47.726366221904755, 45.3270647674799, 42.89150945842266, 39.88101840019226, 42.85866022109985, 45.60754671692848, 50.033830404281616, 50.54118677973747, 50.20653873682022, 45.966969430446625, 41.82953104376793, 36.74197643995285, 43.419548124074936, 50.43891906738281, 54.06225644052029, 52.85989835858345, 56.12118735909462, 48.4230550378561, 51.16450533270836, 52.99609065055847, 51.751961410045624, 47.56437711417675, 45.6574722379446, 46.10772527754307, 47.044321820139885, 41.15342952311039, 37.78835289180279, 37.194809541106224, 39.579656571149826, 39.02526631951332, 39.70846585929394, 39.32988457381725, 39.77093070745468, 37.775178998708725, 40.546594485640526, 37.31576465070248, 40.2455822378397, 46.06623150408268, 52.06531919538975, 47.651077061891556, 48.440739288926125, 48.661902621388435, 50.60896374285221, 47.90576219558716, 53.35218474268913, 49.780912175774574, 53.68052892386913, 45.31776666641235, 57.148207649588585, 21.5914636105299, 35.684907361865044, 61.35088473558426, 50.28190389275551, 50.21234102547169, 42.6651556044817, 43.80095645785332, 37.99258433282375, 38.66745851933956, 36.55960902571678, 40.82679525017738, 39.94284488260746, 39.74055513739586, 39.48907323181629, 41.69201262295246, 39.3112313747406, 38.62712748348713, 39.96950805187225, 39.46975886821747, 39.209841415286064, 39.27498511970043, 39.901202917099, 39.74651321768761, 39.206155613064766, 38.30608271062374, 39.81248527765274, 38.816437125205994, 39.15124095976353, 38.076734617352486, 42.81825318932533, 46.880630403757095, 49.06467340886593, 46.501828730106354, 45.679993629455566, 42.75172255933285, 44.27070625126362, 49.69092920422554, 54.83733884990215, 46.88370443880558, 49.95790667831898, 53.73099401593208, 54.99612092971802, 54.13896292448044, 53.2540550082922, 56.618132293224335, 56.714757308363914, 53.55271138250828, 55.04508130252361, 48.32627423107624, 50.69596007466316, 52.97292709350586, 55.063168331980705, 52.87209190428257, 58.120393082499504, 25.014433935284615, 6.920353956520557, 3.3277322351932526, 2.3701755423098803, 0.8425315213389695, 0.07826162473065779, 0.11821205756859854, 2.488412610255182, 21.506367176771164, 43.819613456726074, 25.341947861015797, 35.2872397005558, 42.064145654439926, 43.92436243593693, 49.136265367269516, 43.436852395534515, 35.97168557345867, 5.670694587752223, 0.12102373599191196, 0.09384032120578922, 0.06509658545837738, 0.05526310276763979, 0.024301942939928267, 0.06180733871588018, 0.1140051637776196, 0.07171728488174267, 0.016359216897399165, 0.0671249715378508, 0.03222755876777228, 0.01994879225094337, 0.06092220515711233, 0.024591484434495214, 0.07055632100673392, 0.02586572230939055, 0.06219548195076641, 0.008861717305990169, 0.03246148371545132, 0.01766890531143872, 0.023314396712521557, 0.03203220694558695, 0.040403796010650694, 0.018504532054066658, 0.022304584199446253, 0.0514387712610187, 0.13540107349399477, 0.06911642092745751, 0.08441502344794571, 0.029663867135241162, 0.0492186290648533, 0.043753843201557174, 0.01064174552084296, 0.0404730235459283, 6.228602975606918, 50.929765328764915, 59.71324101090431, 51.43618315458298, 37.27644056081772, 22.227857261896133, 28.28540101647377, 38.84667590260506, 39.86013472080231, 11.948626041412354, 0.16168975504115224, 0.06939737577340566, 0.7973824627697468, 4.192830864340067, 11.059751138091087, 11.475907657295465, 3.5160411056131124, 37.02504605054855, 66.05623304843903, 61.30947835743427, 53.795301765203476, 49.97065119445324, 47.80471421778202, 44.891676530241966, 41.6911044716835, 45.32738775014877, 47.026211991906166, 52.69198156893253, 53.368934243917465, 50.98396562039852, 48.479318618774414, 43.58588419854641, 38.83349820971489, 45.22294655442238, 53.13480220735073, 56.72300286591053, 54.1250366717577, 56.73705451190472, 48.113683238625526, 52.368843108415604, 54.55021105706692, 54.9077794700861, 49.440100863575935, 46.68903708457947, 48.775018751621246, 48.30160975456238, 42.888135239481926, 40.079553946852684, 39.63630773127079, 41.593985483050346, 42.087339609861374, 42.387580499053, 39.83230121433735, 41.913829520344734, 39.87700201570988, 41.669438034296036, 39.79689471423626, 41.822049245238304, 48.471935614943504, 54.289609640836716, 50.87236560881138, 50.14182820916176, 47.45628051459789, 53.420676067471504, 50.359841510653496, 55.252284184098244, 51.74709007143974, 55.79277478158474, 47.39713288843632, 56.94749101996422, 22.028331868350506, 36.9003177434206, 62.754784002900124, 51.613842621445656, 51.28123886883259, 44.592522382736206, 44.98106673359871, 39.93417754769325, 40.59437692165375, 39.096007123589516, 42.666044756770134, 41.71947754919529, 41.64996027946472, 41.565430015325546, 42.92139105498791, 41.21944338083267, 40.693665593862534, 41.369717717170715, 42.66713909804821, 41.276580914855, 40.93396469950676, 42.541267052292824, 40.65175384283066, 40.51515117287636, 40.204221457242966, 40.05785331130028, 40.94073213636875, 40.93024469912052, 40.7216776907444, 42.816307693719864, 48.413924127817154, 50.940921530127525, 48.41714635491371, 47.74522460997105, 43.14550682902336, 45.16268938779831, 51.30488499999046, 56.59686103463173, 50.455136597156525, 50.98997689783573, 56.0890106856823, 56.27837732434273, 56.120993569493294, 55.122448951005936, 57.01366446912289, 58.933416455984116, 56.17342695593834, 56.11247822642326, 49.85363647341728, 52.00121283531189, 56.252607107162476, 56.42096847295761, 55.211827754974365, 59.98925440013409, 27.702149413526058, 5.813759760931134, 2.5934812473133206, 5.420314148068428, 2.394039686769247, 0.21949131827568635, 0.07425195668474771, 2.4306666338816285, 27.83063191920519, 40.508186146616936, 27.535387761890888, 35.684899762272835, 47.21992179751396, 48.11830759048462, 55.14503873884678, 51.73274204134941, 44.99009504914284, 7.202071789652109, 0.1397209518472664, 0.09708994097309187, 0.021085152075102087, 0.0025124637295448338, 0.010912882680713665, 0.04333008429966867, 0.060802919761044905, 0.02504557491192827, 0.023608838237123564, 0.04946407956595067, 0.042210847677779384, 0.04784699915035162, 0.02473843709594803, 0.06949464906938374, 0.02913324824476149, 0.0456581125035882, 0.018406420131213963, 0.1451637886930257, 0.13288658810779452, 0.10816987924044952, 0.0792528223246336, 0.15386398590635508, 0.13359904987737536, 0.09763686670339666, 0.12712332158116624, 0.15083979349583387, 0.28218592051416636, 0.11736708533135243, 0.10564870710368268, 0.17631610535318032, 0.09308605425758287, 0.11995361099252477, 0.18577875540358946, 0.21534663130296394, 10.402697995305061, 62.5008512288332, 67.7134457230568, 60.63311085104942, 44.22445513308048, 32.687639594078064, 43.705418184399605, 48.23689162731171, 49.1827292740345, 14.486337918788195, 0.501260255696252, 0.5437029688619077, 0.8331697736866772, 10.68539522588253, 39.62985187768936, 16.25734593719244, 7.772093927487731, 40.24437390267849, 68.39205130934715, 63.35003726184368, 55.71606829762459, 51.736716628074646, 48.70316080749035, 45.417644307017326, 43.47635127604008, 48.294583931565285, 49.40814457833767, 54.95637506246567, 55.606979951262474, 53.737058490514755, 51.30301170051098, 46.3959664106369, 41.401351019740105, 48.381314277648926, 54.396456107497215, 61.12220160663128, 56.253910437226295, 59.393123388290405, 49.445914551615715, 52.55278743803501, 57.83856600522995, 57.23007045686245, 52.90146432816982, 49.6435609459877, 51.770295426249504, 52.20494270324707, 44.807423651218414, 41.56865984201431, 41.121796220541, 43.973512798547745, 44.74235974252224, 44.30715389549732, 42.74717800319195, 44.11159738898277, 42.79063627123833, 43.96459847688675, 41.896783635020256, 43.408665508031845, 51.625299006700516, 56.14264480769634, 53.785027116537094, 51.98283702135086, 47.47768856585026, 53.84743496775627, 51.380212157964706, 54.85431253910065, 51.18028588593006, 55.34737028181553, 48.896939009428024, 57.36496701836586, 24.66921865940094, 40.57387702167034, 66.15449577569962, 54.271970987319946, 54.096006229519844, 47.472163662314415, 48.68592493236065, 42.32007332146168, 42.422097846865654, 39.771242290735245, 44.727871119976044, 44.603891372680664, 44.14940536022186, 42.72195115685463, 46.21500112116337, 42.99279682338238, 42.22282133996487, 43.83692152798176, 43.59671741724014, 43.270124942064285, 43.016667142510414, 44.95294064283371, 43.65906447172165, 43.63402381539345, 42.43979349732399, 42.09987513720989, 44.656826332211494, 42.56805941462517, 41.683140099048615, 45.84631830453873, 51.51812195777893, 54.06780794262886, 50.90997979044914, 49.67575281858444, 45.738825872540474, 48.5454236716032, 54.30552698671818, 59.15376663208008, 51.540008783340454, 51.58878296613693, 58.6037727445364, 58.02144259214401, 60.213803350925446, 57.06871971487999, 59.348308593034744, 61.18306294083595, 59.00834083557129, 60.20863562822342, 53.39078687131405, 54.36612233519554, 59.217451214790344, 59.29129645228386, 59.18102256953716, 63.06185692548752, 30.35370983183384, 12.638541720807552, 7.76346649043262, 10.363403353840113, 1.9770916225388646, 0.4170031612738967, 0.24880211421987042, 3.1438579643145204, 34.04170833528042, 56.89275115728378, 37.01275750994682, 41.818097457289696, 52.30467975139618, 57.021929025650024, 64.39351826906204, 58.978280648589134, 55.04106491804123, 9.8112359829247, 0.21693176968256012, 0.22543675237102434, 0.11103690703748725, 0.15521769295446575, 0.1272645522840321, 0.19629958929726854, 0.2619563404005021, 0.1340605618315749, 0.17215348809259012, 0.20065507589606568, 0.12923018977744505, 0.11003532679751515, 0.11906154948519543, 0.2057389952824451, 0.15362149657448754, 0.10731343340012245, 0.15914148709271103], [0.04328475391957909, 0.027871625024999958, 0.03655070628155954, 0.061639594787266105, 0.025514608532830607, 0.023357682475761976, 0.01561545690492494, 0.09840444778092206, 0.04389475849166047, 0.020602730110113043, 0.04976126518158708, 0.06044770932930987, 0.037672121106879786, 0.031608240242348984, 0.046654891048092395, 0.03938602581911255, 0.4524793045129627, 16.10572077333927, 54.46879282593727, 53.94491493701935, 45.319499373435974, 25.549578219652176, 26.251421459019184, 44.69321697950363, 32.73102566599846, 31.490185149013996, 3.5423159832134843, 0.1098078659560997, 0.08667719346703961, 0.1671914293547161, 0.8902390894945711, 6.717258654534817, 9.450439643114805, 3.7486767349764705, 42.622989267110825, 63.13737027347088, 55.27487777173519, 51.31531924009323, 44.95658464729786, 45.41515164077282, 46.951040625572205, 50.33199280500412, 53.42366650700569, 53.69849056005478, 57.66426935791969, 54.86309006810188, 53.56297843158245, 52.391474694013596, 49.438463151454926, 40.55588498711586, 39.11436773836613, 42.480470314621925, 48.95534187555313, 50.7904040068388, 54.08545799553394, 51.870085671544075, 49.11102332174778, 51.41990102827549, 51.179199144244194, 50.19504055380821, 50.82901373505592, 52.458043321967125, 50.86212895810604, 48.81237834692001, 42.36780256032944, 39.2764138430357, 40.18430672585964, 38.61712262034416, 38.14332604408264, 35.945269390940666, 38.779145926237106, 37.33623795211315, 38.413875326514244, 38.81930597126484, 39.76575158536434, 47.92033441364765, 51.15174941718578, 50.492583587765694, 53.87536346912384, 49.82170298695564, 53.33015352487564, 48.29730078577995, 52.10874326527119, 50.36694332957268, 55.20789876580238, 48.0659805983305, 56.221726164221764, 25.96749309450388, 38.65391984581947, 56.53317645192146, 49.79922339320183, 50.77948719263077, 39.2859323322773, 41.385315880179405, 37.764923349022865, 37.922432497143745, 38.465028181672096, 39.38929818570614, 39.50215592980385, 40.24207502603531, 39.25096660852432, 39.77382995188236, 38.48462373018265, 39.177204966545105, 38.970967233181, 39.84219588339329, 40.41899353265762, 41.29711501300335, 39.54682253301144, 37.94257901608944, 38.04206147789955, 40.05201682448387, 38.957747742533684, 38.79700496792793, 38.281399235129356, 42.50665470957756, 48.79584543406963, 52.312454134225845, 56.02477893233299, 53.39675635099411, 51.630417332053185, 44.91313777863979, 45.75132720172405, 49.70436908304691, 54.37401071190834, 52.58875250816345, 50.24496987462044, 54.86860737204552, 51.990223824977875, 51.20027281343937, 51.551833748817444, 53.53490173816681, 53.04334491491318, 51.05851002037525, 45.52685424685478, 47.217128947377205, 52.38203600049019, 53.936278000473976, 59.11885790526867, 55.088661164045334, 54.870963245630264, 35.85497483611107, 10.308162868022919, 2.5830080593004823, 2.4025775911286473, 0.5105916643515229, 0.17041720391716808, 0.06137377604318317, 0.3724157897522673, 10.840613096952438, 39.79977495968342, 34.17677968740463, 15.542187262326479, 17.78457898646593, 24.31213852018118, 37.8229196369648, 44.05265875160694, 47.06167168915272, 16.008618883788586, 0.2628025965532288, 0.021519714791793376, 0.06563505812664516, 0.02398166911007138, 0.036770033184438944, 0.02459214309055824, 0.044936396152479574, 0.01149840380094247, 0.023078453123162035, 0.026415475622343365, 0.0371266982256202, 0.041209200644516386, 0.03678452361782547, 0.04972734903276432, 0.043039741285610944, 0.06849320241599344, 0.11235884274356067, 0.04818424589757342, 0.014392346511158394, 0.06883276466396637, 0.04688069318945054, 0.020316274094511755, 0.07483070570742711, 0.006672441031696508, 0.034885004060924985, 0.009719204008433735, 0.06612158787902445, 0.03361822477017995, 0.08407091183471493, 0.04111590526008513, 0.005499243316080538, 0.07110957725672051, 0.06879533815663308, 0.5243192589841783, 23.17071206867695, 64.20913696289062, 59.41876821219921, 51.16041675209999, 32.83615842461586, 28.612987138330936, 41.65940657258034, 37.4725366383791, 35.98072148859501, 4.30164230056107, 0.270145702525042, 0.03404477043659426, 1.284507061354816, 6.447113575413823, 10.386679004877806, 10.447915568947792, 4.38213718123734, 42.993119806051254, 64.81111586093903, 56.222421526908875, 52.95536823570728, 47.56188064813614, 46.655598878860474, 47.69260883331299, 51.48221768438816, 55.07450312376022, 55.78385666012764, 59.722736701369286, 57.54538133740425, 57.43935942649841, 56.70656494796276, 52.25623995065689, 42.639119401574135, 40.885372906923294, 45.695462599396706, 51.26591429114342, 53.02738197147846, 54.181760028004646, 52.08530232310295, 48.32707218825817, 53.2881885766983, 52.22442805767059, 52.67097249627113, 52.81084679067135, 53.99652376770973, 52.75201074779034, 51.08514279127121, 43.17813187837601, 40.77684313058853, 41.0441017895937, 40.43639659881592, 39.91824120283127, 38.66578280925751, 40.656621381640434, 39.82469402253628, 41.22693657875061, 39.374630972743034, 41.90049983561039, 49.950075298547745, 55.80470234155655, 52.11009219288826, 56.41210354864597, 52.79999457299709, 55.02255231142044, 49.31197173893452, 53.850087225437164, 51.10706001520157, 56.299865171313286, 47.392945513129234, 56.504879370331764, 25.944707617163658, 40.894583612680435, 58.929438069462776, 50.75450353324413, 52.19611957669258, 41.80314525961876, 42.46846675872803, 40.32628230750561, 40.49313135445118, 40.04436023533344, 41.59888722002506, 40.647771656513214, 41.96362964808941, 39.59371201694012, 41.68143019080162, 39.639176577329636, 40.64367927610874, 41.145974323153496, 40.02796031534672, 41.123764514923096, 42.78729245066643, 40.91541789472103, 39.80145066976547, 39.333220794796944, 42.343738451600075, 41.07144512236118, 40.58352090418339, 40.22286705672741, 43.66066798567772, 50.87194763123989, 54.31164085865021, 57.69526049494743, 56.063498854637146, 52.16725252568722, 47.02676296234131, 47.73237369954586, 53.02507929503918, 56.65529429912567, 54.51784819364548, 50.452366545796394, 55.307715609669685, 55.330696776509285, 52.79509663581848, 55.865008905529976, 55.14159232378006, 55.419209226965904, 54.62236538529396, 47.99024686217308, 48.79533626139164, 54.72398713231087, 56.897253915667534, 60.68438529968262, 58.2814322412014, 56.195537969470024, 36.733594089746475, 9.050536751747131, 2.30999912135303, 6.22253280133009, 2.8510829620063305, 0.31469893525354564, 0.12407767368131317, 0.34988935163710266, 13.502324670553207, 43.82002383470535, 35.67574605345726, 22.211480140686035, 26.24612834304571, 31.36836178600788, 43.45590837299824, 50.21397493779659, 54.53481428325176, 19.198099337518215, 0.3257285262225196, 0.04555503561277874, 0.04468166138394736, 0.0464936149364803, 0.06081034123781137, 0.009149211400654167, 0.05351922271074727, 0.060283045313553885, 0.06921544569195248, 0.02689142605959205, 0.045907303428975865, 0.05758991384936962, 0.009283059589506593, 0.05885869322810322, 0.0681884097866714, 0.0530397730472032, 0.0546771586232353, 0.1593546467483975, 0.2171786525286734, 0.18010043510003015, 0.2531978994375095, 0.09576042793923989, 0.1419860459282063, 0.0969725480535999, 0.17917248333105817, 0.14211709436494857, 0.14205677260179073, 0.1077339936455246, 0.19142954202834517, 0.09487054092460312, 0.0932832651596982, 0.18720443593338132, 0.13302716572070494, 1.0546767502091825, 30.955836921930313, 72.33096554875374, 66.25916495919228, 57.75685139000416, 37.60409697890282, 38.1793937087059, 55.10340437293053, 43.68459530174732, 43.42393308877945, 5.306316465139389, 0.3199902403866872, 0.16528396139619872, 1.453622686676681, 8.097440544515848, 18.378388322889805, 19.91319816559553, 7.409964809194207, 46.99055850505829, 67.06784516572952, 58.33415061235428, 55.51828511059284, 50.53734518587589, 50.48505239188671, 51.45765200257301, 53.951051607728004, 56.76033206284046, 57.44227387011051, 61.51468634605408, 58.531694412231445, 59.00114022195339, 58.63663338124752, 55.798045098781586, 46.417990028858185, 43.50117154419422, 47.95794099569321, 53.605995923280716, 56.3307499140501, 57.437774911522865, 53.60235191881657, 49.43945869803429, 54.413555189967155, 54.47894588112831, 55.39503492414951, 55.57522505521774, 56.64892964065075, 53.22019502520561, 52.164497673511505, 47.25408956408501, 44.03259202837944, 44.52518239617348, 42.544835060834885, 43.58808048069477, 39.679283425211906, 43.49552124738693, 40.8575963973999, 42.04009674489498, 42.75373265147209, 43.26012387871742, 52.260077744722366, 57.0604095607996, 54.725647643208504, 58.83589468896389, 53.07280473411083, 56.64133004844189, 52.44149520993233, 54.24230977892876, 53.635296151041985, 58.022130355238914, 50.023650750517845, 57.61401325464249, 29.375387728214264, 43.86094003915787, 60.38916394114494, 54.706310480833054, 55.19267678260803, 43.24759595096111, 45.280122086405754, 42.48757593333721, 42.49283865094185, 43.280019611120224, 45.490095019340515, 42.56840139627457, 44.43900682032108, 41.10570788383484, 44.05165180563927, 41.572813019156456, 41.802240908145905, 42.870838567614555, 43.507099226117134, 43.86530600488186, 44.45724204182625, 42.063157707452774, 42.53984972834587, 42.59241230785847, 43.91744680702686, 44.027219116687775, 42.06758826971054, 42.43909053504467, 47.13792599737644, 53.714711889624596, 55.672545433044434, 59.897181540727615, 57.62909844517708, 56.09758302569389, 50.06946109235287, 49.405739307403564, 55.48561066389084, 59.0413648635149, 56.251269578933716, 52.84276507794857, 57.516290098428726, 56.75058178603649, 55.78270152211189, 57.638681530952454, 58.997815400362015, 58.137758150696754, 56.7547045648098, 49.684655740857124, 52.74031117558479, 56.50235630571842, 58.86636905372143, 63.14310796558857, 61.4648862183094, 57.65752092003822, 37.92163833975792, 14.246338047087193, 7.82056650146842, 9.346878100186586, 5.468238601461053, 0.4620272421743721, 0.13683095457963645, 0.5743271880783141, 16.88101787120104, 57.57536172866821, 45.69436825811863, 23.53825494647026, 27.043931633234024, 34.11288611590862, 53.05525727570057, 56.350630447268486, 62.77719520032406, 24.66458860784769, 0.8308997517451644, 0.23452733410522342, 0.16882050287676975, 0.1469466500566341, 0.13473984960000962, 0.10430894501041621, 0.12045537703670561, 0.15398483723402023, 0.20967363961972296, 0.17915191099746153, 0.12810889369575307, 0.1468871594988741, 0.10760990655398928, 0.17882579646538943, 0.20725720678456128, 0.14940755238058046, 0.1721677670138888], [0.03427829091378953, 0.015218864318740088, 0.009411729442945216, 0.049298376543447375, 0.026846023320103996, 0.06129651104856748, 0.04962650600646157, 0.04640387815015856, 0.047470333229284734, 0.025741527606442105, 0.024056379261310212, 0.018168921742471866, 0.03942989045754075, 0.034004813205683604, 0.03941397510061506, 0.09601014578947797, 1.1176716699264944, 26.11260160803795, 55.34776546061039, 42.144553139805794, 38.73655021190643, 27.822004482150078, 27.04100389033556, 31.273241490125656, 29.117421470582485, 21.297783069312572, 1.22769191628322, 0.02976830586703727, 0.19986795407021418, 0.8210904593579471, 2.832744908519089, 5.655939504504204, 8.98560393601656, 3.934079948812723, 43.04833464324474, 63.14645558595657, 55.88962018489838, 53.632947877049446, 51.9385351985693, 52.53035344183445, 53.41371864080429, 54.37848687171936, 56.029977053403854, 54.204140827059746, 47.53774054348469, 52.65167713165283, 55.603191554546356, 55.63330493867397, 52.79926501214504, 43.39219719171524, 36.961471661925316, 42.22000569105148, 44.124505296349525, 49.08281363546848, 49.3791863322258, 54.70661826431751, 47.686088383197784, 48.3764923363924, 51.38812713325024, 51.42142094671726, 50.592795610427856, 55.255122631788254, 50.82974709570408, 51.57292261719704, 48.58089096844196, 38.48142810165882, 39.03627432882786, 37.65323594212532, 38.163738548755646, 36.99199542403221, 41.52365505695343, 38.180947825312614, 39.898866042494774, 37.444486543536186, 41.55682347714901, 43.471563532948494, 49.59769360721111, 51.302107349038124, 52.64822691679001, 52.28013686835766, 53.11072289943695, 51.84004448354244, 56.00140638649464, 52.71783158183098, 53.845440074801445, 49.09271590411663, 58.338015004992485, 28.391839005053043, 42.74211287498474, 57.08059407770634, 47.06050515174866, 50.780239552259445, 41.17003083229065, 41.851026490330696, 37.31906667351723, 41.181886196136475, 42.27265186607838, 45.43543875217438, 42.236299216747284, 41.440264731645584, 39.73118104040623, 39.894887655973434, 38.21516498923302, 38.98799791932106, 39.49558988213539, 40.23304671049118, 39.69936154782772, 40.1028922945261, 38.093772903084755, 39.95559319853783, 40.586252957582474, 41.68353907763958, 38.379874750971794, 36.44476778805256, 42.077007964253426, 51.11916996538639, 52.0842269808054, 52.78676748275757, 50.65586842596531, 50.97059793770313, 54.74267452955246, 49.4308103621006, 48.96829158067703, 50.61373628675938, 52.50384606420994, 54.35830235481262, 51.16317920386791, 52.503963857889175, 54.000452756881714, 49.510313495993614, 47.34252601861954, 52.35559321939945, 51.98206566274166, 44.90543179214001, 44.61355425417423, 49.970088824629784, 58.99676285684109, 61.65981575846672, 54.54649865627289, 57.33497142791748, 56.418726593256, 49.24727641046047, 19.344307892024517, 4.216721607372165, 4.439811436459422, 5.677503347396851, 0.01681181380263297, 0.07589532397105359, 0.02803388262691442, 6.471700631082058, 26.47912234067917, 33.75520370900631, 28.14547162503004, 17.619979418814182, 22.175285182893276, 39.795982763171196, 44.77443382143974, 46.08822092413902, 23.18381756544113, 1.125054673757404, 0.05619523653876968, 0.07615741342306137, 0.04564048649626784, 0.04097398807061836, 0.0602166898897849, 0.06226503974176012, 0.044107766007073224, 0.05456828555907123, 0.050118434883188456, 0.05108248100441415, 0.010966266290779458, 0.04364464730315376, 0.06716290270560421, 0.05716907158785034, 0.05159603235370014, 0.012708254798781127, 0.02097341617627535, 0.04333304546889849, 0.05872802699741442, 0.013318357705429662, 0.03549991793988738, 0.09138791647274047, 0.06112600633059628, 0.016211674228543416, 0.05981178896035999, 0.028104603734391276, 0.026127685596293304, 0.05561545222008135, 0.044320090746623464, 0.06387950779753737, 0.012403100372466724, 0.09226439287886024, 1.6402867203578353, 33.163632452487946, 62.6972246915102, 47.988312765955925, 43.60503137111664, 34.03709538280964, 33.70330989360809, 41.236964240670204, 32.66929417848587, 24.458649158477783, 0.6241704197600484, 0.037000800293753855, 0.2517872548196465, 1.9369192281737924, 8.860839530825615, 8.878064956516027, 12.747334633022547, 6.843619924038649, 45.75903698801994, 62.90065437555313, 58.64444576203823, 53.03855337202549, 54.018144607543945, 53.91299284994602, 56.7703141272068, 57.341362684965134, 59.00661192834377, 53.937554731965065, 50.21411933004856, 54.17291410267353, 57.35032640397549, 55.88548220694065, 55.03671035170555, 45.22481985390186, 38.75176079571247, 43.937608525156975, 46.42099566757679, 49.58499848842621, 53.5354109108448, 54.97281298041344, 49.91602152585983, 49.86470527946949, 53.92958275973797, 53.88757221400738, 52.63703651726246, 56.30336478352547, 53.23665954172611, 53.235565200448036, 50.310284569859505, 41.63845829665661, 41.14479638636112, 40.10037682950497, 40.38926772773266, 39.886098727583885, 43.12140852212906, 39.206497594714165, 41.83057218790054, 41.23453237116337, 43.09308484196663, 45.47374069690704, 51.850345730781555, 52.78839759528637, 54.89078678190708, 56.15072317421436, 55.14435097575188, 53.084367513656616, 57.92414881289005, 53.54122839868069, 56.153109446167946, 52.097910046577454, 61.102955639362335, 30.91371428221464, 42.744259759783745, 59.96333219110966, 49.60010267794132, 52.12574355304241, 41.75347052514553, 43.302263617515564, 40.430742502212524, 43.31050157546997, 43.83115343749523, 46.54117941856384, 44.16821055114269, 42.90058717131615, 40.65199322998524, 42.6865940541029, 39.787535816431046, 40.482244938611984, 41.49886518716812, 40.9801322221756, 41.52492418885231, 41.22033633291721, 39.93067413568497, 42.57305234670639, 43.137097880244255, 43.50459136068821, 40.51390863955021, 39.36026394367218, 42.73828648030758, 52.36728519201279, 54.5779799669981, 54.09150347113609, 52.78427481651306, 53.520071133971214, 54.61874037981033, 52.11585268378258, 50.733916237950325, 54.10041019320488, 54.86446179449558, 56.02851413190365, 51.48095615208149, 54.4881983846426, 55.648758709430695, 52.00145222246647, 51.834952756762505, 54.00973565876484, 54.948475286364555, 47.73089937865734, 46.18550330400467, 53.693771213293076, 61.97506584227085, 62.755779549479485, 56.49740517139435, 58.30987371504307, 56.407653987407684, 48.42694602906704, 23.33573341369629, 3.273415337316692, 2.942211809568107, 3.4794559562578797, 0.8976599131710827, 0.3719675028696656, 0.0549113359011244, 6.910555707290769, 31.322047971189022, 37.10879735648632, 30.740114897489548, 19.708890728652477, 25.102602504193783, 44.96634252369404, 49.96085911989212, 52.80267342925072, 30.385588221251965, 2.1517190895974636, 0.02447093738737749, 0.05659162132360507, 0.02524039795389399, 0.038371899572666734, 0.017906529865285847, 0.03498622929328121, 0.0456246935937088, 0.032884218453546055, 0.08098186313873157, 0.08043579829973169, 0.0564534222939983, 0.019044438922719564, 0.018177352540078573, 0.06941198123968206, 0.016683926914993208, 0.018311666426598094, 0.14470601716311648, 0.08912887089536525, 0.1515627492335625, 0.1359962165588513, 0.1055711526714731, 0.24826910375850275, 0.2357535995543003, 0.20348991674836725, 0.16498364391736686, 0.08234278386225924, 0.19488235440803692, 0.15286116627976298, 0.20034475426655263, 0.2344503882341087, 0.1552518317475915, 0.24693553859833628, 2.4220703076571226, 43.0827683955431, 74.44096952676773, 54.70615088939667, 51.89174070954323, 38.1875404715538, 39.26300436258316, 43.72920870780945, 40.3387076407671, 30.660446472465992, 2.258869777433574, 0.16824934602482244, 0.418191755306907, 2.8201789828017354, 10.679431445896626, 15.588562823832035, 17.033539786934853, 5.811915909871459, 48.38774353265762, 65.06316393613815, 60.22153213620186, 57.67234392464161, 56.972364485263824, 56.262501776218414, 58.88530343770981, 58.01606968045235, 62.26441651582718, 54.95633326470852, 53.092160895466805, 58.472789973020554, 58.645992279052734, 59.793352112174034, 56.40471674501896, 46.83837287127972, 41.18412807583809, 46.27913028001785, 49.130200892686844, 52.882685735821724, 54.643575847148895, 58.83203409612179, 50.79277887940407, 49.90603566169739, 54.85138289630413, 54.79322321712971, 55.08079558610916, 58.88310335576534, 55.700485333800316, 54.18476186692715, 52.57458686828613, 41.95492051541805, 43.722106888890266, 42.04924285411835, 43.01704332232475, 42.41060346364975, 45.77884912490845, 41.638918071985245, 44.42538075149059, 43.72244507074356, 47.26404882967472, 47.845527827739716, 54.93004247546196, 56.58942863345146, 59.03594255447388, 56.69569753110409, 57.75472350418568, 54.78266358375549, 61.32482573390007, 56.73588037490845, 57.039955258369446, 55.56494660675526, 61.415804252028465, 33.03499795496464, 45.38664557039738, 62.00642175972462, 53.56299363076687, 54.32677164673805, 44.530000537633896, 45.22157482802868, 42.10060849785805, 45.96006900072098, 47.735071554780006, 49.39365595579147, 47.334789633750916, 46.2897165119648, 43.19358564913273, 45.14316983520985, 41.99993669986725, 43.78391437232494, 44.18635077774525, 43.09599548578262, 44.157681316137314, 44.37038250267506, 42.391304299235344, 44.56635698676109, 44.90876041352749, 45.0987958163023, 41.628920808434486, 40.43812930583954, 46.0559606552124, 55.777036026120186, 57.7941007912159, 57.089383006095886, 54.8538451641798, 55.09607836604118, 60.239056795835495, 53.465388268232346, 54.206325709819794, 55.917377695441246, 58.45393918454647, 55.992571860551834, 52.001414224505424, 55.93017540872097, 58.45794416964054, 54.443113803863525, 52.86635421216488, 57.018353417515755, 56.470544412732124, 49.23153765499592, 49.53383803367615, 55.49233250319958, 63.60518977046013, 64.42603692412376, 61.02481283247471, 57.83240653574467, 57.45312228798866, 50.80359689891338, 24.468642622232437, 7.791492361575365, 10.911827925592661, 12.551148310303688, 0.8865283511113375, 0.34917659300845116, 0.13271524105221033, 10.036454647779465, 38.94132882356644, 46.04510463774204, 39.526634216308594, 27.835573554039, 33.38531255722046, 52.84642808139324, 59.29722033441067, 59.79350030422211, 37.57633566856384, 2.726359642110765, 0.16218818142078817, 0.13910461304476485, 0.10257854606606998, 0.17639581201365218, 0.12673085904680192, 0.1573403985821642, 0.08482756107696332, 0.15387695864774287, 0.12872757768491283, 0.1346950387232937, 0.10777822564705275, 0.0784631326678209, 0.15966127248248085, 0.157345267070923, 0.18898046953836456, 0.1167778942908626], [0.05471286705869716, 0.05594881753495429, 0.04498968235566281, 0.034622806997504085, 0.043827367771882564, 0.0703900947701186, 0.035626569151645526, 0.05034427042119205, 0.08247467092587613, 0.05309276981279254, 0.03626228171924595, 0.0363596069655614, 0.028370897452987265, 0.17286387184867635, 0.02802342762151966, 0.05256043470581062, 1.9679641560651362, 34.99261491000652, 50.25870233774185, 48.483718782663345, 40.89966394007206, 16.64785858243704, 22.94082820415497, 22.919883728027344, 35.05421340465546, 21.184843629598618, 0.41410911187995225, 0.024757068713370245, 0.3239317570114508, 1.6703408514149487, 8.797085601836443, 7.411678517237306, 9.731455463916063, 3.3745245868340135, 39.9283030629158, 61.95373758673668, 56.44701607525349, 57.870932668447495, 54.65486504137516, 54.46263335645199, 53.77957820892334, 55.12200437486172, 54.75580282509327, 50.49803629517555, 46.28467038273811, 56.72359183430672, 52.37619951367378, 54.89758841693401, 53.549131974577904, 43.00532855093479, 39.102755561470985, 45.517141968011856, 48.67763377726078, 50.12784495949745, 49.60159979760647, 51.68030485510826, 47.92417220771313, 47.95840077102184, 48.207982778549194, 49.92214299738407, 50.292680114507675, 48.965662121772766, 52.88305811583996, 48.88483285903931, 48.507361114025116, 42.603815495967865, 36.312774270772934, 38.37347589433193, 37.22490772604942, 38.567850664258, 39.45527404546738, 35.65251410007477, 38.309069350361824, 37.914612516760826, 40.12654222548008, 42.32530564069748, 41.25895746052265, 42.15404883027077, 45.09825624525547, 43.60897935926914, 42.55404196679592, 42.74007238447666, 45.72337970137596, 45.27574472129345, 50.01708850264549, 47.9852881282568, 58.32959845662117, 35.49568511545658, 47.557256296277046, 54.60024677217007, 48.38919885456562, 45.484642311930656, 41.31745532155037, 44.17128078639507, 43.95655810832977, 47.67237111926079, 51.23670145869255, 51.01358123123646, 49.35529321432114, 51.26762039959431, 43.10427904129028, 38.159433379769325, 37.955669313669205, 38.827825114130974, 40.032227486371994, 37.11486183106899, 39.89959180355072, 39.95682433247566, 39.25894618034363, 43.47428798675537, 45.11260807514191, 44.539082050323486, 42.622518092393875, 44.12351354956627, 48.70476812124252, 50.2233262360096, 53.288207575678825, 51.651084423065186, 51.58356584608555, 50.27140885591507, 53.19543935358524, 54.49357129633427, 53.14962141215801, 51.435487791895866, 53.74879606068134, 48.410907089710236, 49.47671189904213, 51.935008987784386, 56.52186445891857, 49.90029416978359, 43.27031873166561, 38.397676795721054, 42.85994075238705, 39.59491655230522, 48.575643450021744, 54.84099805355072, 57.375887632369995, 35.48416033387184, 31.98316879570484, 64.97728854417801, 57.63890951871872, 59.002831131219864, 36.158392354846, 11.542705222964287, 4.6285739075392485, 1.4224778953939676, 1.0949005605652928, 1.013808399438858, 0.04821316368179396, 1.4281256985850632, 26.031367667019367, 47.11160480976105, 24.265459924936295, 20.675211176276207, 28.50077535957098, 38.511427491903305, 43.594574332237244, 43.402027264237404, 32.24285066127777, 2.2544387402012944, 0.10703386637032963, 0.06818141875555739, 0.025182506724377163, 0.028296946147747803, 0.023133941649575718, 0.028503682515292894, 0.05961310489510652, 0.03157578241371084, 0.06153549002192449, 0.055639612837694585, 0.12592833023518324, 0.05936592890066095, 0.009122755691350903, 0.04981001315172762, 0.058710523444460705, 0.026870875990425702, 0.03634552100265864, 0.035622298091766424, 0.04207860438327771, 0.03062567197048338, 0.032777942906250246, 0.10227961640339345, 0.08938825150835328, 0.07002341444604099, 0.04616216436261311, 0.035523904152796604, 0.04785796067153569, 0.03205079032341018, 0.02067834011540981, 0.025095692144532222, 0.020974753897462506, 0.057403471510042436, 3.196476115845144, 45.819313153624535, 59.41634774208069, 53.471562936902046, 47.5378355383873, 26.325745470821857, 29.81892842799425, 28.58723971992731, 37.05785728991032, 22.137002237141132, 0.486556202522479, 0.009437776971026324, 0.451089974376373, 3.54439162183553, 8.93231749534607, 8.635995145887136, 11.122864801436663, 5.21537309512496, 42.87077397108078, 63.861516416072845, 56.08821652829647, 60.29995612800121, 57.92200192809105, 57.089466601610184, 57.099380269646645, 56.784962341189384, 55.524144396185875, 51.94869205355644, 48.56846183538437, 58.823902532458305, 55.51106549799442, 57.45192915201187, 54.272388964891434, 46.22375965118408, 42.02197551727295, 47.608124166727066, 51.02161779999733, 52.95643597841263, 51.309946328401566, 54.72388833761215, 48.7381911277771, 48.650849014520645, 47.47458793222904, 49.64469328522682, 51.200911179184914, 51.44820190966129, 54.4099909812212, 51.11972473561764, 50.79878255724907, 45.29624082148075, 38.26809234917164, 39.47819821536541, 39.12887915968895, 41.289857402443886, 41.47936463356018, 37.76887133717537, 39.226967096328735, 41.16523168981075, 41.42376981675625, 44.40440207719803, 45.012320056557655, 44.64154355227947, 46.789579689502716, 46.74537666141987, 46.14737614989281, 46.403619199991226, 48.06708633899689, 46.85967452824116, 52.03281953930855, 50.171504616737366, 58.64894852042198, 36.72526873648167, 50.300526693463326, 55.906194895505905, 50.83124801516533, 49.63519759476185, 41.95807434618473, 45.87005563080311, 45.13608701527119, 48.80651146173477, 52.06335850059986, 54.187786504626274, 50.39927959442139, 51.54275603592396, 44.70951810479164, 39.18702743947506, 40.75665861368179, 40.423754677176476, 40.928352400660515, 38.38933244347572, 41.330606415867805, 41.287121549248695, 40.019733756780624, 45.59171296656132, 46.88074439764023, 46.40982426702976, 44.556659907102585, 46.95341169834137, 50.49861766397953, 52.70591542124748, 56.407878175377846, 53.56638304889202, 51.69399932026863, 53.27586583793163, 56.09846077859402, 54.8891718685627, 55.165914818644524, 55.150917023420334, 56.411883160471916, 48.83851334452629, 48.79418112337589, 52.67087750136852, 58.504940047860146, 51.11152097582817, 44.57537390291691, 42.769015431404114, 44.88939665257931, 42.1210628002882, 50.466858968138695, 57.739740908145905, 60.447338819503784, 38.29357758164406, 34.789899587631226, 66.07999697327614, 58.27938795089722, 60.39511822164059, 37.14535139501095, 12.19951232895255, 2.6127295894548297, 5.477654496207833, 2.7013527089729905, 0.6848435453139246, 0.07431400765199214, 1.310737885069102, 28.117239139974117, 46.03208273649216, 32.16884583234787, 23.268792405724525, 31.503338143229485, 43.042437359690666, 49.95772048830986, 48.77421319484711, 40.434815883636475, 3.4034652588889003, 0.046698740843567066, 0.03859054369968362, 0.05168825162400026, 0.0721996437641792, 0.048207341533270665, 0.03471970179816708, 0.03572212437575217, 0.04177057227934711, 0.0526280740450602, 0.028275932236283552, 0.0640272990858648, 0.047505277252639644, 0.018868481274694204, 0.03573282614524942, 0.026788358445628546, 0.03375885804416612, 0.10752643720479682, 0.08593583988840692, 0.18419621454086155, 0.18523636419558898, 0.10354936428484507, 0.32068854197859764, 0.23754089896101505, 0.16238801210420206, 0.2178029768401757, 0.14309217251138762, 0.12920710898470134, 0.1791551912901923, 0.10017234002589248, 0.2125441629323177, 0.1280738940113224, 0.21637406054651365, 5.38833886384964, 54.66738536953926, 63.33785891532898, 62.11834855377674, 53.643477112054825, 26.18975266814232, 32.14860811829567, 32.89213702082634, 46.89359910786152, 28.574193120002747, 0.6919225654564798, 0.1357230616849847, 0.7031131430994719, 5.278129102662206, 18.00350993871689, 16.755818389356136, 20.737463235855103, 5.851751072332263, 44.76962707936764, 65.59595614671707, 61.84711530804634, 63.26994135975838, 60.54432101547718, 59.27755258977413, 58.96740563213825, 58.38575564324856, 57.612261548638344, 52.46731102466583, 51.468971595168114, 61.83572731912136, 57.191065549850464, 59.497492387890816, 57.31539487838745, 48.16496528685093, 43.022705018520355, 50.04711829125881, 53.362296000123024, 55.78820362687111, 53.29777546226978, 56.74999661743641, 48.41781511902809, 48.529038950800896, 47.8148140758276, 51.04358822107315, 51.64785839617252, 52.10281938314438, 56.08569726347923, 54.99875798821449, 52.8195521235466, 47.51763202250004, 41.91807009279728, 43.01830865442753, 41.318169683218, 43.565616086125374, 43.946431651711464, 39.16992075741291, 41.36396482586861, 43.6362960934639, 42.40334205329418, 46.77864387631416, 44.95899371802807, 45.5610828101635, 49.183907210826874, 47.97222062945366, 47.08448186516762, 47.37304598093033, 48.93813639879227, 48.81492421030998, 53.764721006155014, 52.60543741285801, 59.92386370897293, 37.96742968261242, 51.10756538808346, 59.57641415297985, 53.32731507718563, 50.86559437215328, 43.6261772364378, 49.744339138269424, 48.236093670129776, 51.304835602641106, 55.05113437771797, 55.263732969760895, 54.89618629217148, 55.58010779321194, 47.04925775527954, 40.86066663265228, 42.194034084677696, 42.53079101443291, 44.72269959747791, 41.33797042071819, 43.03451478481293, 44.25467871129513, 41.254131719470024, 47.00785517692566, 50.13761043548584, 48.297027200460434, 46.37686483561993, 48.96296426653862, 52.20287561416626, 55.16645438969135, 58.829385638237, 52.834956496953964, 53.03197592496872, 53.22908274829388, 57.35331304371357, 56.49103291332722, 59.29802589118481, 56.94255128502846, 58.927234187722206, 49.170334339141846, 49.45835888385773, 55.41286736726761, 61.398363187909126, 55.0310904532671, 47.66442574560642, 43.12066376209259, 46.414251029491425, 44.43222418427467, 53.92395906150341, 61.908550411462784, 63.57684329152107, 40.82815557718277, 39.89052928984165, 67.00842395424843, 62.34776884317398, 61.29313923418522, 38.745882511138916, 13.56134595349431, 9.218773674219847, 5.369583545252681, 2.3924278607591987, 1.536970145534724, 0.18407931143883616, 2.001161905936897, 35.268369913101196, 57.878745049238205, 36.15148052573204, 32.327354326844215, 41.223364770412445, 51.62868082523346, 58.358131125569344, 55.88476404547691, 49.906898215413094, 6.041136709973216, 0.23614579491550103, 0.10553607877227478, 0.12675727950409055, 0.1237308606505394, 0.1396529414341785, 0.1402321134810336, 0.08284769661258906, 0.08727707143407315, 0.12418725920724683, 0.14944838534574956, 0.13241882727015764, 0.1416054429137148, 0.1327453722478822, 0.2239382968400605, 0.16104465059470385, 0.15195590938674286], [0.02655052609043196, 0.11062762743677013, 0.029512513538065832, 0.03492721742077265, 0.07410979829728603, 0.06783346281736158, 0.09421288676094264, 0.016619981615804136, 0.060670271996059455, 0.0501403579255566, 0.014264895635278663, 0.024830387337715365, 0.03649354606750421, 0.05260733472823631, 0.07662788309971802, 0.07181613153079525, 8.032357636839151, 50.06859853863716, 48.76192845404148, 43.60927194356918, 27.047917619347572, 15.680789574980736, 38.57125528156757, 38.453750386834145, 39.95313473045826, 17.09477350115776, 0.17479648377047852, 1.5810217754915357, 12.810898572206497, 5.150596546009183, 7.874316992238164, 5.356807205826044, 14.04919607564807, 5.598236275836825, 26.093287244439125, 61.4571650326252, 59.82417605817318, 58.049914464354515, 55.782093554735184, 55.55765099823475, 54.60350699722767, 52.17357158660889, 54.16257865726948, 52.46509574353695, 56.14948824048042, 51.758170276880264, 53.20546321570873, 50.46236380934715, 49.60508421063423, 40.61782546341419, 41.696336790919304, 49.75464038550854, 53.66360083222389, 52.1299347281456, 53.9494176954031, 50.33784069120884, 47.46747851371765, 49.061196595430374, 51.07291504740715, 47.74222657084465, 48.65170016884804, 44.401388838887215, 47.49234817922115, 51.25429831445217, 46.93165026605129, 43.588445261120796, 36.076768934726715, 36.848997697234154, 39.29726332426071, 37.52914600074291, 36.28576532006264, 37.798665538430214, 38.26572127640247, 38.158985003829, 39.47016924619675, 38.66542562842369, 38.611457124352455, 37.37647399306297, 39.45814669132233, 37.86861978471279, 38.842822909355164, 40.67446902394295, 43.76491919159889, 41.84667952358723, 49.058950915932655, 47.32657827436924, 56.502299308776855, 33.32321248948574, 43.95519018173218, 56.5264356136322, 48.827702924609184, 50.10870538651943, 45.98770871758461, 48.444314897060394, 50.06045177578926, 51.50466687977314, 52.177557572722435, 52.442437559366226, 51.08196996152401, 52.549523413181305, 50.68434029817581, 43.814966306090355, 37.60632365942001, 37.28296101093292, 39.07288536429405, 40.57791620492935, 38.11569392681122, 37.35187031328678, 41.354127153754234, 48.710137233138084, 47.92052820324898, 48.66406090557575, 49.93871010839939, 49.3831305205822, 51.70978747308254, 53.96477647125721, 51.24974995851517, 48.13013635575771, 48.53550620377064, 47.14462883770466, 50.69131292402744, 51.61899134516716, 53.60702566802502, 49.34977971017361, 50.556769743561745, 49.600387662649155, 51.58341005444527, 55.06765589118004, 54.016145914793015, 48.91444846987724, 40.89383505284786, 39.17104549705982, 41.81221917271614, 41.65993474423885, 50.758706107735634, 55.97630873322487, 58.51220905780792, 39.97624509036541, 54.35868613421917, 55.0645362585783, 56.24330900609493, 61.20157174766064, 53.212325647473335, 24.115215986967087, 4.5594351924955845, 1.8683614069595933, 1.5701589896343648, 0.6238239852245897, 0.36951704998500645, 0.17627568799071014, 13.681579101830721, 45.06563499569893, 40.88042177259922, 15.511893387883902, 18.44282526522875, 31.685036793351173, 41.990551203489304, 42.36850552260876, 37.636167258024216, 6.317084552720189, 0.09278502431698143, 0.0455674814293161, 0.05438510124804452, 0.05250456582871266, 0.030849730064801406, 0.04767637568875216, 0.008620284606877249, 0.052714155754074454, 0.016663072565279435, 0.08938886006944813, 0.06137585405667778, 0.04112275528314058, 0.05765042114944663, 0.06265552816330455, 0.06148311666038353, 0.07900783195509575, 0.02280149103171425, 0.04158456409641076, 0.03784156826441176, 0.05955712098511867, 0.009972046300390502, 0.040243651674245484, 0.11481393405119888, 0.06406263273674995, 0.07334633613936603, 0.02148513256543083, 0.024627094535389915, 0.05417820160801057, 0.12009566547931172, 0.04933005882776342, 0.04163726400292944, 0.0033219218812519102, 12.99187621101737, 57.41118773818016, 53.71313117444515, 48.57720896601677, 33.34072954952717, 18.910545967519283, 33.915650099515915, 35.58176189661026, 42.216912657022476, 19.550351835787296, 0.3450484707718715, 1.3143619406037033, 17.558610811829567, 5.181581033393741, 10.960923191159964, 10.758159421384335, 12.471391540020704, 5.594433629885316, 29.433598704636097, 64.56413671374321, 61.98292762041092, 60.601701736450195, 56.53924472630024, 58.36616389453411, 55.893940553069115, 55.09428486227989, 57.243324145674706, 54.20807361602783, 58.42321403324604, 53.4342185407877, 56.714791506528854, 51.764386743307114, 51.27607114613056, 43.278150111436844, 43.87331597507, 52.34159477055073, 54.37727093696594, 54.38344180583954, 55.63610918819904, 51.68932557106018, 48.748013600707054, 49.03994433581829, 51.44771933555603, 48.2626960426569, 48.37328530848026, 45.93205690383911, 49.358044266700745, 51.57023996114731, 49.31477218866348, 45.846238508820534, 38.3158215880394, 37.75264620780945, 41.14034302532673, 39.98113162815571, 39.04289357364178, 40.94344899058342, 40.06480313837528, 40.601699128746986, 41.48372299969196, 40.65739654004574, 41.33431501686573, 40.13569973409176, 41.147919818758965, 40.53372457623482, 40.76111197471619, 43.01080405712128, 45.002809166908264, 44.34288717806339, 50.429290384054184, 50.396688133478165, 58.21379967033863, 34.63554047048092, 44.93687130510807, 57.274349480867386, 50.8557491004467, 52.84702844917774, 47.65724793076515, 49.205406457185745, 51.29587568342686, 53.563719391822815, 51.89105674624443, 55.10001115500927, 53.54984253644943, 54.781850427389145, 52.815406545996666, 45.094426050782204, 39.690017849206924, 40.3443693369627, 40.197309628129005, 40.8534774184227, 40.04850201308727, 40.370853915810585, 42.48864367604256, 48.106968998909, 50.02578243613243, 49.87820215523243, 51.3983029872179, 52.87806138396263, 54.27255995571613, 55.984185710549355, 52.82664254307747, 48.63166764378548, 48.363424837589264, 47.152805998921394, 51.602393835783005, 55.279433727264404, 57.1224108338356, 52.44313292205334, 49.84363541007042, 49.10910062491894, 52.815106362104416, 57.20554277300835, 55.77814556658268, 51.02540999650955, 42.745589688420296, 40.84577903151512, 44.34155344963074, 43.54065902531147, 53.219682052731514, 58.16716857254505, 59.563031271100044, 45.98977580666542, 56.960942298173904, 56.95618495345116, 57.65091687440872, 62.487540543079376, 54.87610436975956, 26.901598870754242, 5.640226872637868, 5.297901341691613, 3.415077910758555, 0.8247672370634973, 0.6676218006759882, 0.057113477305392735, 18.440881669521332, 45.94434164464474, 31.417253762483597, 16.534459367394447, 26.13362777978182, 40.723045617341995, 46.92194938659668, 48.93525995314121, 47.78294898569584, 10.652176458388567, 0.046307406373671256, 0.053948911372572184, 0.03647682548034936, 0.022110770478320774, 0.02342560197575949, 0.010296511409251252, 0.0819213107752148, 0.004195143274046131, 0.00869919809701969, 0.0614010573917767, 0.041279511715401895, 0.04922726395307109, 0.049814451194833964, 0.11682467185892165, 0.03875355643685907, 0.03830246423603967, 0.09165614348603413, 0.1581338286632672, 0.21890626841923222, 0.1325306689250283, 0.15172839659499004, 0.13158861635020003, 0.21840629837242886, 0.1274581192410551, 0.17512366699520499, 0.1318003807682544, 0.06116324359027203, 0.19746305420994759, 0.23057410639012232, 0.13607811997644603, 0.18787440232699737, 0.26170605851802975, 18.132957592606544, 67.43496626615524, 59.98593717813492, 58.160689920187, 38.16512927412987, 24.4260336086154, 49.21672224998474, 50.47530971467495, 52.31261372566223, 23.685210160911083, 0.5062126368284225, 2.338130436837673, 21.72442987561226, 11.80474391207099, 16.580507196485996, 10.491196196526289, 26.969159245491028, 11.06585931032896, 30.52011240273714, 64.66993823647499, 64.616779088974, 61.96997791528702, 57.66336880624294, 59.152220115065575, 56.09276868402958, 55.33172272145748, 59.7576530277729, 56.57622054219246, 60.54136477410793, 56.110027357935905, 58.51284362375736, 55.60464307665825, 54.904853627085686, 45.6677582859993, 46.47058680653572, 56.00837521255016, 58.03483307361603, 57.109335735440254, 57.92925573885441, 53.023749366402626, 49.86204542219639, 51.0784475505352, 54.43395249545574, 50.27697175741196, 48.500912860035896, 45.58341421186924, 52.799379006028175, 55.13012833893299, 51.71114020049572, 48.26790176331997, 41.56503863632679, 40.82711823284626, 44.19941447675228, 42.15344466269016, 40.590953305363655, 41.9805995374918, 42.39372856914997, 42.76781469583511, 43.95797923207283, 42.605787590146065, 42.74307422339916, 42.49706782400608, 44.33914817869663, 41.346550360322, 42.05729842185974, 45.80749958753586, 48.190712705254555, 46.777572333812714, 52.96424075961113, 50.74776269495487, 61.15319274365902, 37.306382954120636, 47.69262783229351, 58.71145896613598, 54.02127183973789, 55.23455433547497, 50.9179175645113, 52.86790832877159, 55.529657900333405, 56.51729330420494, 56.185875087976456, 57.607770189642906, 55.95251061022282, 57.84216061234474, 53.881720528006554, 47.07170695066452, 41.50463327765465, 41.086195930838585, 43.33991959691048, 42.80596844851971, 42.169225215911865, 41.88692696392536, 45.61271443963051, 52.65017241239548, 50.779931768774986, 51.97698533535004, 55.20732879638672, 54.190009385347366, 56.89265616238117, 59.08111833035946, 54.31485928595066, 48.748435378074646, 48.90246011316776, 48.23319062590599, 51.39411561191082, 57.48019203543663, 58.2588766515255, 52.585127502679825, 50.266191735863686, 50.6728383153677, 54.84325133264065, 59.023198038339615, 59.76394549012184, 53.989649936556816, 46.001631170511246, 42.672990784049034, 48.783910274505615, 45.75992614030838, 56.303619369864464, 60.0079569965601, 65.15379667282104, 47.65991158783436, 57.00799137353897, 60.40990322828293, 62.11619406938553, 65.45257464051247, 58.85397411882877, 27.295886613428593, 7.1651387214660645, 4.199756942689419, 5.9406890999525785, 3.5494807362556458, 0.6302448094356805, 0.3334666328737512, 22.304974123835564, 58.479128032922745, 48.35470050573349, 25.777383595705032, 29.08080093562603, 45.73977582156658, 56.67346492409706, 56.41110420227051, 57.10224151611328, 16.625696271657944, 0.4300304356729612, 0.2598699851660058, 0.3817706205882132, 0.13639803015394136, 0.11638595125987194, 0.1281518640462309, 0.13226074981503189, 0.18184060812927783, 0.17605648725293577, 0.21126183564774692, 0.15060431003803387, 0.15431050647748634, 0.12146027467679232, 0.17297446669545025, 0.1436137390555814, 0.14185937616275623], [0.02814228257193463, 0.027596156505751424, 0.027901574394491035, 0.06845524898380972, 0.06978504403377883, 0.05804737738799304, 0.09448917349800467, 0.02202406722062733, 0.01211416465594084, 0.034435763518558815, 0.02411467310594162, 0.08144327861373313, 0.05603024968877435, 0.02128096773958532, 0.04358500831585843, 0.12386452886858024, 20.73213592171669, 50.45855261385441, 51.451085954904556, 35.94866640865803, 21.418077014386654, 28.78484431654215, 62.35633738338947, 35.603443533182144, 44.57111433148384, 9.062402565032244, 0.03097269836871419, 0.568465527612716, 30.346226133406162, 13.91535870730877, 6.848962912335992, 9.391406960785389, 5.111833875998855, 4.796445574611425, 19.476305209100246, 54.86159674823284, 51.601827666163445, 58.832896649837494, 52.06359788775444, 55.51440551877022, 53.54058623313904, 54.880010560154915, 51.8233709782362, 50.95870837569237, 46.98572896420956, 47.94512428343296, 49.36256982386112, 51.152463778853416, 47.696043848991394, 42.29411691427231, 49.2221749573946, 51.17906995117664, 52.040354534983635, 50.95737844705582, 49.54259276390076, 48.81798304617405, 50.19904553890228, 52.52546690404415, 51.24595396220684, 54.25648681819439, 50.01425385475159, 50.69411717355251, 50.15974044799805, 51.04513093829155, 48.216034546494484, 41.86812177300453, 36.637311056256294, 36.10634654760361, 36.88475377857685, 37.64286629855633, 39.19398486614227, 37.27684333920479, 36.40926629304886, 38.67359519004822, 40.028317496180534, 38.56538459658623, 39.77443411946297, 41.600980907678604, 44.80271950364113, 47.11510822176933, 51.20240829885006, 47.44088374078274, 53.14234860241413, 51.590439677238464, 52.91869260370731, 49.35272075235844, 58.001011088490486, 30.46741873025894, 41.750662475824356, 57.54781700670719, 48.61861914396286, 51.534529477357864, 49.74177427589893, 52.5845043361187, 49.65065896511078, 52.87327744066715, 50.77532261610031, 51.546149253845215, 50.11777549982071, 51.28910444676876, 47.481940537691116, 50.943801775574684, 40.0727941095829, 38.61641205847263, 37.584733217954636, 41.16439573466778, 41.20143994688988, 38.927136585116386, 41.845247000455856, 48.03242079913616, 50.76153315603733, 51.15052588284016, 51.188041269779205, 53.49816910922527, 51.590663865208626, 47.12400734424591, 46.42458647489548, 48.06017071008682, 48.2789021730423, 47.915493473410606, 45.58335721492767, 47.96480342745781, 47.78817370533943, 50.05773492157459, 52.94473260641098, 53.77636358141899, 51.734888926148415, 51.71082481741905, 48.03976580500603, 42.203157395124435, 42.904546558856964, 47.467345520853996, 46.56376540660858, 41.49120479822159, 43.88091176748276, 53.91022279858589, 56.303053200244904, 60.765195563435555, 56.85435801744461, 56.643138751387596, 52.34762504696846, 59.63760606944561, 58.12735430896282, 37.797920778393745, 8.635258935391903, 8.965102136135101, 8.237721417099237, 7.1697573736310005, 3.2686532428488135, 0.2350478616426699, 10.375280566513538, 34.75735433399677, 48.57237182557583, 27.498938217759132, 18.410435803234577, 22.816590070724487, 41.08119159936905, 43.75713720917702, 51.73023797571659, 11.568383295089006, 0.07744646456558257, 0.11765497183660045, 0.013930820641689934, 0.033714043456711806, 0.017069094137696084, 0.08368216746021062, 0.06887966097565368, 0.07025289392913692, 0.03181188556482084, 0.05991055026242975, 0.07099668917362578, 0.010954820518236374, 0.1140076202864293, 0.018598179958644323, 0.10481901568709873, 0.08734608374652453, 0.017230296034540515, 0.029872718623664696, 0.07068017061101273, 0.07631868953467347, 0.10030096163973212, 0.008594338196417084, 0.09942992517608218, 0.042144829931203276, 0.012354374666756485, 0.02369972164160572, 0.06436734372982755, 0.026765105103550013, 0.04773601467604749, 0.008041325927479193, 0.04166877559327986, 0.16410877055022866, 26.706353947520256, 60.18030434846878, 57.49758370220661, 45.66373810172081, 30.842922180891037, 31.627711169421673, 57.816481590270996, 38.878985568881035, 47.80922457575798, 10.192601568996906, 0.13538542902097106, 0.33728774345945567, 37.938030660152435, 19.61414661258459, 8.754933513700962, 12.609128449112177, 9.663093332201242, 3.488063681870699, 21.86002179980278, 54.83012303709984, 52.03227996826172, 59.09000605344772, 53.70866261422634, 56.619496420025826, 54.29852396249771, 57.05282136797905, 53.71550604701042, 53.54188576340675, 50.10161116719246, 49.27058815956116, 51.457534208893776, 53.52055750787258, 52.25670352578163, 44.93158958852291, 51.659238785505295, 51.98075853288174, 54.20425862073898, 52.05261267721653, 49.71218906342983, 50.22569730877876, 50.7884319126606, 53.781580701470375, 53.349802270531654, 54.13466155529022, 51.58252850174904, 50.02643600106239, 48.93790081143379, 51.65454983711243, 50.15689440071583, 44.03046794235706, 38.92472751438618, 39.270254373550415, 39.85836021602154, 39.35707591474056, 40.400317534804344, 39.233210161328316, 39.7986426204443, 40.407385155558586, 41.746931076049805, 40.25161251425743, 41.61117196083069, 43.77340413630009, 47.61059023439884, 49.93198446929455, 51.680282056331635, 48.769322857260704, 55.63419409096241, 53.57964813709259, 54.22042295336723, 50.91189108788967, 59.95686873793602, 32.01718457043171, 43.07933337986469, 59.17691498994827, 50.17137162387371, 53.808893635869026, 50.92911556363106, 53.58958080410957, 52.53551356494427, 53.94156351685524, 53.50923411548138, 52.215973511338234, 50.70767864584923, 54.091127291321754, 50.33938340842724, 52.11582228541374, 41.36809140443802, 41.64663925766945, 38.82683716714382, 42.799896374344826, 41.895814687013626, 39.88494358956814, 44.522545337677, 49.880151450634, 53.41502957046032, 52.4621357023716, 53.89288812875748, 55.93177892267704, 53.745478838682175, 51.33812941610813, 46.78357221186161, 47.959430515766144, 49.0416694432497, 47.44524970650673, 46.10568478703499, 48.58706183731556, 48.444102108478546, 49.53599251806736, 52.1262451261282, 55.94187878072262, 54.49170559644699, 54.197631776332855, 49.68723200261593, 42.271603122353554, 44.69353996217251, 48.75456444919109, 48.754925429821014, 43.415755927562714, 47.20628432929516, 56.87819413840771, 59.29251618683338, 62.43594691157341, 57.19595208764076, 57.85545989871025, 54.8733115196228, 59.93837893009186, 59.05622586607933, 39.75455358624458, 8.582655508071184, 4.259565258398652, 6.391068482771516, 10.708985310047865, 3.958667479455471, 0.318301884108223, 8.982145171612501, 45.587628185749054, 49.3612626940012, 25.00745940953493, 21.972507163882256, 30.644534826278687, 50.853625014424324, 49.59954030811787, 59.98680733144283, 17.00587347149849, 0.07726969983195886, 0.038191353596630506, 0.024954565342341084, 0.03858239491819404, 0.048558076814515516, 0.010301555230398662, 0.0304247763051535, 0.015138473954721121, 0.009611120403860696, 0.03145323156786617, 0.048137568519450724, 0.03507902001729235, 0.04582019755616784, 0.032975762369460426, 0.03296968789072707, 0.0315841352858115, 0.18047630321234465, 0.17655751114943996, 0.1516478438861668, 0.14543431636411697, 0.1236289415101055, 0.10202465156908147, 0.22228370828088373, 0.32457724737469107, 0.1696509512839839, 0.10905626331805252, 0.16369496384868398, 0.21565696777543053, 0.25525471719447523, 0.10230312022031285, 0.12159331949078478, 0.5344694049563259, 33.68974082171917, 67.42930456995964, 64.189393222332, 50.57413101196289, 33.53989586234093, 39.79866161942482, 71.47275120019913, 48.05738165974617, 57.20577836036682, 12.14494725689292, 0.2641384326852858, 0.9185026853810996, 39.24481853842735, 19.453916810452938, 18.544994182884693, 17.78394252061844, 16.30112148821354, 9.93477875366807, 23.506640642881393, 54.26706925034523, 52.33223207294941, 61.85296319425106, 55.39598107337952, 59.22409325838089, 56.76865741610527, 59.23017293214798, 56.58704236149788, 55.08912093937397, 52.45996981859207, 51.38839311897755, 53.65538187325001, 56.835932806134224, 54.09744635224342, 45.88369309902191, 53.97855073213577, 55.11863395571709, 55.746652856469154, 54.120522513985634, 51.308255419135094, 49.92747411131859, 52.56831340491772, 56.76271453499794, 55.34354388713837, 58.27082701027393, 54.36804883182049, 50.38879595696926, 51.105247512459755, 53.96396331489086, 52.62534074485302, 47.00990326702595, 41.74763783812523, 41.473083570599556, 42.100863084197044, 41.55076660215855, 41.28897204995155, 42.01157167553902, 40.25194689631462, 42.76571720838547, 43.78433994948864, 43.294572830200195, 44.82467472553253, 45.79190142452717, 49.35678653419018, 51.04096256196499, 53.64990636706352, 51.710399240255356, 57.67025023698807, 55.30573971569538, 57.20349848270416, 52.738358080387115, 61.371958404779434, 34.4854561239481, 46.02278083562851, 61.86137214303017, 52.738228887319565, 56.358629018068314, 54.46077525615692, 56.01648397743702, 54.652159586548805, 56.92615896463394, 55.50962537527084, 53.811276108026505, 50.6413684040308, 55.81243492662907, 53.129972666502, 53.18655163049698, 43.86527940630913, 44.198456928133965, 41.99296787381172, 44.84661854803562, 44.81154642999172, 41.8572011590004, 48.080966994166374, 51.88411831855774, 55.758546218276024, 54.72856588661671, 56.78795278072357, 58.12918581068516, 55.64976945519447, 52.84455098211765, 46.99534624814987, 48.2594358175993, 49.9590428173542, 49.33515049517155, 47.45695687830448, 49.579610377550125, 48.14618669450283, 51.79408974945545, 54.594208896160126, 57.64470420777798, 57.10942693054676, 56.811750903725624, 52.21244730055332, 45.69501422345638, 48.70198667049408, 53.59102472662926, 51.21871702373028, 47.71562799811363, 47.78142146766186, 58.93829919397831, 62.207172587513924, 65.70894688367844, 61.61264128983021, 62.25849263370037, 56.65899530053139, 65.65647169947624, 61.10208548605442, 42.57100045681, 9.988549668341875, 14.367542043328285, 19.274864718317986, 9.195468574762344, 4.209918072447181, 0.5333450215402991, 12.100248355418444, 53.89298692345619, 61.71935096383095, 39.04399551451206, 29.53009832650423, 33.186921402812004, 55.19747972488403, 55.77186070382595, 68.33607271313667, 23.62729176878929, 0.3426584880799055, 0.1788856729399413, 0.14173275092616677, 0.13499969034455717, 0.10510305044590496, 0.12100218402338214, 0.12236849273904227, 0.14931717363651842, 0.16350731923012063, 0.13495587394572794, 0.15697837894549593, 0.11032530615921132, 0.2449229676858522, 0.09142320559476502, 0.20963709626812488, 0.203469077241607], [0.05058950569946319, 0.05800382074085064, 0.046098788661765866, 0.07344403988099657, 0.03684817762405146, 0.027972709249297623, 0.05337889742804691, 0.050320209993515164, 0.0036068694817004143, 0.05508025613380596, 0.032004658423829824, 0.057664841078803875, 0.014979925235820701, 0.035074055049335584, 0.05826432570756879, 0.48214757815003395, 32.723733857274055, 53.69459576904774, 46.445739939808846, 39.09993231296539, 18.42262364923954, 20.922251120209694, 49.62411358952522, 32.44179278612137, 42.34969273209572, 4.27919453009963, 0.13241823355201632, 0.5334557499736547, 9.704752396792173, 12.31552105396986, 6.64934204891324, 15.230018813163042, 7.928447462618351, 4.732970455661416, 21.206002794206142, 50.1228254288435, 58.3800483494997, 54.81172062456608, 53.51901859045029, 53.382130935788155, 52.86599323153496, 49.6790586411953, 47.86780223250389, 43.30455869436264, 46.71472370624542, 48.10021296143532, 53.82706046104431, 50.65467908978462, 48.47906023263931, 47.26493038237095, 49.65434476733208, 54.10343863070011, 50.206952914595604, 46.23896263539791, 49.409102126955986, 48.781748190522194, 53.7917223572731, 48.3467323333025, 48.54725897312164, 47.88606405258179, 53.570065051317215, 50.16916774213314, 50.7673392444849, 49.882442727684975, 47.310805320739746, 38.884259685873985, 37.21086747944355, 36.318751350045204, 38.177535608410835, 36.458245664834976, 38.914350271224976, 38.04418556392193, 38.09177801012993, 38.746080100536346, 41.228201910853386, 40.679321363568306, 47.306439355015755, 45.20849972963333, 47.95308865606785, 50.928230211138725, 53.135079592466354, 51.3998457044363, 52.315319180488586, 49.6943224221468, 53.01318593323231, 48.342066183686256, 52.44500622153282, 27.141630090773106, 38.760089948773384, 56.59209989011288, 52.45946064591408, 52.54054829478264, 50.06411097943783, 53.21862950921059, 50.13147756457329, 48.6203670501709, 47.38230608403683, 45.20797535777092, 45.07962964475155, 48.7827817350626, 49.58274520933628, 53.37218686938286, 46.78218148648739, 38.68739224970341, 36.639617532491684, 39.50964532792568, 40.51276870071888, 38.1304257363081, 39.9228997528553, 46.1845001578331, 51.57675661146641, 54.77582395076752, 52.26116828620434, 49.334401935338974, 48.51954706013203, 46.89909741282463, 48.933736234903336, 54.179324358701706, 52.433124259114265, 53.20542521774769, 50.63721902668476, 49.38762187957764, 48.03964041173458, 51.64323404431343, 53.47227729856968, 52.36153610050678, 50.695481300354004, 48.541293293237686, 44.13056217133999, 48.50557141005993, 51.52220293879509, 52.23007455468178, 55.58424197137356, 48.659732937812805, 40.90919762849808, 42.452078238129616, 48.0762704461813, 49.822280555963516, 47.47344799339771, 47.861065194010735, 54.26886275410652, 58.12881343066692, 59.09084960818291, 45.558525547385216, 16.985426768660545, 9.02983071282506, 3.5570831783115864, 22.861258573830128, 2.7907317504286766, 0.1472678960999474, 6.893982896581292, 30.473568700253963, 21.74925584346056, 49.18242909014225, 43.421622812747955, 21.234370172023773, 32.860868498682976, 43.72662864625454, 48.46173696219921, 19.851149395108223, 0.06624151152209379, 0.050502915619290434, 0.03581980585295241, 0.02828624623361975, 0.027438986326160375, 0.038545710558537394, 0.035880743598681875, 0.023123670325730927, 0.021991416433593258, 0.059722029909607954, 0.04356759010988753, 0.051126371618011035, 0.049452746970928274, 0.029365148984652478, 0.01537451773401699, 0.08422243612585589, 0.06361793784890324, 0.02461444277287228, 0.03739521838724613, 0.0903852007468231, 0.0835963900317438, 0.06705739899189211, 0.0404204386722995, 0.06797431502491236, 0.040939841856015846, 0.021226161989034154, 0.08834430205752142, 0.04295679143979214, 0.009759014665178256, 0.10264324650052004, 0.02157012146199122, 1.1510617844760418, 41.77821099758148, 59.84025679528713, 53.70780386030674, 45.60762271285057, 25.25239236652851, 23.117893002927303, 48.89551408588886, 34.03720177710056, 46.7601502686739, 4.901545085012913, 0.06360640487400815, 0.5025165039114654, 11.440563853830099, 14.866954945027828, 8.224270138889551, 14.865988846868277, 8.756511379033327, 3.6582498997449875, 20.97814802080393, 52.31218434870243, 57.872897163033485, 57.62706555426121, 55.614028573036194, 56.50896415114403, 54.85957905650139, 54.02801647782326, 50.067614391446114, 45.91504141688347, 47.828455343842506, 49.48031410574913, 54.67966251075268, 51.99434280395508, 50.51192454993725, 48.77698324620724, 52.09991253912449, 56.8764728307724, 52.14290343225002, 46.73877261579037, 47.4700091779232, 52.42193765938282, 55.98327375948429, 50.10194554924965, 51.125846207141876, 50.311656296253204, 54.98081535100937, 50.91401897370815, 50.55685713887215, 52.74927109479904, 49.130390882492065, 42.54556842148304, 39.68953147530556, 38.235949873924255, 40.45918397605419, 38.66756111383438, 38.79794351756573, 39.58138547837734, 40.230451449751854, 40.37010915577412, 41.71217814087868, 41.6504580527544, 49.58840690553188, 46.92019388079643, 50.44811837375164, 52.0515601336956, 53.55389691889286, 54.32564690709114, 53.44002842903137, 52.11831875145435, 54.2536673694849, 50.17106004059315, 53.88084277510643, 28.567381985485554, 39.023039638996124, 60.35780802369118, 55.730009749531746, 54.367342069745064, 52.6908378303051, 54.19789016246796, 51.98867730796337, 50.28360240161419, 47.843700125813484, 45.94214916229248, 46.19491919875145, 50.66874973475933, 52.613409385085106, 54.2818770557642, 50.47472834587097, 39.95489023625851, 38.48131790757179, 40.22364221513271, 43.177873492240906, 40.225238129496574, 41.43717169761658, 48.31126503646374, 54.49374608695507, 56.582159623503685, 52.34984032809734, 50.07987253367901, 49.722558706998825, 47.371807247400284, 49.79886241257191, 56.874128356575966, 54.68120902776718, 54.47933726012707, 51.33898437023163, 51.64726562798023, 48.27877677977085, 51.770948991179466, 54.61182855069637, 53.50655145943165, 52.10845448076725, 50.64250074326992, 46.86043068766594, 51.89234867691994, 53.10219995677471, 53.297726064920425, 57.54068858921528, 50.862706527113914, 43.88742841780186, 45.47472484409809, 50.475647896528244, 51.38418674468994, 50.94582326710224, 52.08410158753395, 56.7502436041832, 58.834663555026054, 61.780428886413574, 48.065593019127846, 17.22781766206026, 4.132273988798261, 5.359333120286465, 25.43616760522127, 2.9376280680298805, 0.16561215394176543, 6.988508049398661, 35.20623564720154, 31.494813300669193, 43.74578721821308, 42.08955489099026, 26.900358237326145, 37.79661364853382, 50.65804950892925, 56.01198121905327, 28.03220920264721, 0.17564273992320523, 0.02959091401862679, 0.04559546781820245, 0.03238510187657084, 0.06849173296359368, 0.021561989378824364, 0.0478273730550427, 0.0544590265781153, 0.048114573073689826, 0.06016681385517586, 0.020256349380360916, 0.05864633138116915, 0.08169572756742127, 0.015747143588669132, 0.012344877959549194, 0.08146346503053792, 0.1315305952448398, 0.10877386870561168, 0.2620606269920245, 0.17501078633358702, 0.19959846540587023, 0.1653858582722023, 0.13367556530283764, 0.13439748203381896, 0.08369885093998164, 0.14638962369645014, 0.22333968052407727, 0.2752098807832226, 0.07692880171816796, 0.12846044905018061, 0.1589478607638739, 2.0619087712839246, 50.17202518880367, 66.75585150718689, 60.63963130116463, 51.51760898530483, 28.55780839920044, 31.146620884537697, 58.25747452676296, 43.80462326109409, 53.67264434695244, 5.393283348530531, 0.25490184081718326, 1.0559521755203605, 14.20009832829237, 15.194234233349562, 14.367683585733175, 27.331887781620026, 18.31594817340374, 9.5805000141263, 26.852193921804428, 56.00351147353649, 59.317815229296684, 60.359065756201744, 56.549557372927666, 58.85697975754738, 59.17446792125702, 55.379318967461586, 53.73737767338753, 47.000510171055794, 51.39596231281757, 51.98648862540722, 56.51881702244282, 55.20528830587864, 52.864249125123024, 49.98108923435211, 54.21912342309952, 59.68517191708088, 52.48551584780216, 47.06737898290157, 49.34350624680519, 52.97897256910801, 58.936855271458626, 52.31073662638664, 53.56634885072708, 52.55040496587753, 56.459559202194214, 51.41577824950218, 52.85872422158718, 53.25245149433613, 51.93845920264721, 43.86981636285782, 41.052959114313126, 39.975811913609505, 43.019068613648415, 40.789477452635765, 42.73260958492756, 41.14927254617214, 43.445067554712296, 41.978076472878456, 46.40027537941933, 44.219029024243355, 53.32048684358597, 49.72608871757984, 53.68539646267891, 55.44764690101147, 56.03483319282532, 56.1695321649313, 55.5562374740839, 53.6412238329649, 56.70154921710491, 50.61242535710335, 54.71750468015671, 30.167238637804985, 41.334277018904686, 59.32352252304554, 57.39869020879269, 56.22137278318405, 55.99477954208851, 56.07136823236942, 51.189481392502785, 50.68924583494663, 47.11262695491314, 45.44408328831196, 47.279855981469154, 52.53285750746727, 56.133874878287315, 57.15002775192261, 52.246151491999626, 42.20071032643318, 40.65997660160065, 42.655876502394676, 45.2474058419466, 42.08574369549751, 43.44846077263355, 50.19781820476055, 56.8183321505785, 57.81934283673763, 55.70211924612522, 50.92029623687267, 51.44764333963394, 47.515975311398506, 50.41105516254902, 58.998305574059486, 56.65279023349285, 57.068613320589066, 53.75268705189228, 52.19582699239254, 49.582346230745316, 53.704688027501106, 56.20739333331585, 56.59159071743488, 54.70618508756161, 53.474804162979126, 48.36256988346577, 53.996751755476, 56.508139595389366, 56.69914774596691, 58.817188292741776, 53.926090747117996, 46.91859796643257, 48.21448802947998, 53.26680712401867, 54.361718371510506, 53.057464957237244, 53.76692108809948, 60.45486621558666, 60.912707448005676, 62.98774570226669, 50.047137290239334, 22.66650952398777, 15.061565302312374, 9.869335815310478, 30.527746193110943, 3.943254556506872, 0.31454697309527546, 9.68246754258871, 39.59696464240551, 37.10871376097202, 61.14521697163582, 56.63941875100136, 32.437046840786934, 46.733418703079224, 57.00194589793682, 62.567701041698456, 37.230767011642456, 0.8359270601067692, 0.15808970056241378, 0.10772859081043862, 0.08048190793488175, 0.2223046071594581, 0.07482154018362053, 0.14008401049068198, 0.17278553073992953, 0.17089479079004377, 0.15944955259328708, 0.15215389954391867, 0.14900331938406453, 0.17765085794962943, 0.1314653901499696, 0.11712113016983494, 0.13591683644335717], [0.0003032826197113536, 0.02334752989554545, 0.02365491076488979, 0.03265457198722288, 0.08192575623979792, 0.05238362544332631, 0.1161435955145862, 0.05268245491606649, 0.026308122105547227, 0.042620487220119685, 0.06986031265114434, 0.0419815351779107, 0.01671409892878728, 0.07373830885626376, 0.022547719199792482, 3.3888887660577893, 42.25554138422012, 51.21668793261051, 42.24912732839584, 25.190867967903614, 18.114135302603245, 29.305729866027832, 57.472478449344635, 41.97486564517021, 38.479604199528694, 1.0723688383586705, 0.01973880713194376, 0.304598780348897, 11.980368588119745, 5.748530086129904, 4.284845776855946, 7.327215224504471, 7.45122916996479, 3.62166166305542, 29.5999613776803, 54.32409659028053, 54.23330046236515, 55.70809252560139, 49.154907166957855, 48.94090265035629, 45.560968816280365, 43.1537751853466, 39.70272436738014, 43.05534526705742, 48.04220527410507, 52.618029937148094, 53.44197392463684, 51.47639259696007, 52.91779585182667, 50.19349783658981, 51.91191762685776, 50.08085288107395, 46.714073941111565, 52.269406244158745, 52.10863687098026, 52.84521974623203, 49.86897625029087, 47.24003031849861, 46.825723350048065, 49.95585098862648, 51.329180896282196, 50.152414441108704, 50.16172394156456, 52.878331169486046, 46.50569312274456, 36.30336977541447, 36.01077787578106, 37.18855507671833, 37.30520121753216, 36.260732263326645, 38.244301825761795, 37.615997940301895, 35.802438855171204, 39.47281010448933, 42.028556764125824, 45.65464898943901, 44.4828412681818, 47.99174018204212, 51.797745153307915, 48.8147684186697, 51.636386811733246, 50.30440628528595, 53.73403385281563, 49.40823957324028, 51.80860877037048, 45.575598031282425, 51.29924990236759, 23.08392472565174, 31.187233105301857, 49.32256557047367, 43.98722246289253, 52.30766639113426, 44.79880191385746, 46.25955373048782, 42.41230197250843, 43.79364565014839, 40.30529983341694, 49.25169937312603, 41.05107061564922, 39.25533637404442, 46.125215739011765, 52.65102356672287, 49.459840804338455, 42.99234464764595, 37.7544891089201, 37.066490426659584, 37.59660378098488, 38.74189652502537, 36.06614850461483, 49.446290731430054, 50.884984731674194, 50.986283496022224, 46.481507420539856, 48.96407000720501, 52.742028683423996, 52.54101946949959, 52.650548592209816, 52.75293789803982, 51.42094977200031, 50.452358946204185, 53.768528401851654, 50.437668934464455, 49.0690241754055, 48.85666877031326, 51.57509610056877, 52.57772549986839, 48.10588225722313, 49.81581710278988, 51.215396001935005, 50.64278572797775, 53.55251379311085, 54.17951814830303, 52.23766654729843, 55.75439304113388, 49.90786716341972, 43.790218234062195, 42.77945727109909, 48.241170197725296, 52.16965779662132, 56.09599471092224, 57.433427944779396, 58.57938565313816, 53.55839967727661, 52.06761047244072, 20.84814939647913, 5.778478654101491, 1.3727301335893571, 14.137208852916956, 2.904078005813062, 0.3433921159012243, 1.6599646769464016, 36.413791850209236, 44.00443933904171, 64.18706014752388, 61.564068496227264, 21.15859653800726, 30.82437537610531, 37.48578652739525, 51.762475445866585, 33.1529626250267, 1.3955200044438243, 0.14968021743698046, 0.11356343748047948, 0.08017730826395564, 0.04848329430387821, 0.02455274803651264, 0.04964191670296714, 0.014561444859282346, 0.034679507079999894, 0.021540758389164694, 0.024096696433844045, 0.02271527388074901, 0.08336581217008643, 0.0427668869815534, 0.07723062575678341, 0.08170068511390127, 0.05095941807667259, 0.02300959109561518, 0.042023414571303874, 0.021420732700789813, 0.03128830408968497, 0.05693700943083968, 0.022198770639079157, 0.06873519450891763, 0.06041573760739993, 0.02858921874576481, 0.022037307135178708, 0.03247331354941707, 0.09794498415431008, 0.09542706262436695, 0.03694251943670679, 5.06555805914104, 50.856053084135056, 56.996033415198326, 49.95819926261902, 31.08598943799734, 24.53903764486313, 26.406289748847485, 56.98229715228081, 43.61054487526417, 42.284560427069664, 1.448338832706213, 0.05361464063753374, 0.9120326419360936, 14.245863072574139, 7.446988122537732, 5.229437565430999, 11.804865505546331, 8.602804876863956, 4.1259710770100355, 32.279571890830994, 54.68035787343979, 55.211185589432716, 57.848559468984604, 51.63232862949371, 50.845770835876465, 46.90805733203888, 44.95732180774212, 42.81593531370163, 45.82590579986572, 50.44556491076946, 54.36372846364975, 56.55650720000267, 54.337304681539536, 54.31427791714668, 52.762745171785355, 54.336369931697845, 51.818275451660156, 47.94308379292488, 52.557567581534386, 54.49360929429531, 56.32633455097675, 52.80718758702278, 48.95691119134426, 49.71352279186249, 51.13808915019035, 53.3755686879158, 52.72144518792629, 52.316861897706985, 54.20686528086662, 48.260590955615044, 39.94506016373634, 37.5941377133131, 38.284545466303825, 39.52501930296421, 38.75546179711819, 40.746763944625854, 39.359196200966835, 37.79950529336929, 41.942685171961784, 44.76420097053051, 47.55153760313988, 47.061721086502075, 52.13800549507141, 52.416633144021034, 50.63721902668476, 53.53784658014774, 51.46816223859787, 55.31260974705219, 51.48320563137531, 53.87605123221874, 46.64204500615597, 52.624675780534744, 23.65448120981455, 31.947256922721863, 49.138708636164665, 47.191206738352776, 52.97464460134506, 47.47037015855312, 46.59430056810379, 41.7191431671381, 43.27230982482433, 39.36275281012058, 48.31232137978077, 43.500187397003174, 42.52490893006325, 48.99590089917183, 54.616726487874985, 52.369606867432594, 44.71533179283142, 40.110244899988174, 38.52827958762646, 40.31560108065605, 40.450946018099785, 39.468786120414734, 51.620659455657005, 52.24992848932743, 53.57030063867569, 49.18717123568058, 49.70808148384094, 51.92598067224026, 51.30521558225155, 55.470362082123756, 53.51998753845692, 52.635018825531006, 52.12683789432049, 55.142154693603516, 51.94982819259167, 50.13716585934162, 50.22150233387947, 54.16625306010246, 54.515701308846474, 50.40315918624401, 51.53726913034916, 53.10379967093468, 52.28901319205761, 55.60411870479584, 56.982209756970406, 53.23700912296772, 56.62977106869221, 51.45170532166958, 45.55737800896168, 45.63892163336277, 49.246394857764244, 53.815733268857, 56.915587931871414, 59.130842462182045, 59.12698566913605, 56.77602522075176, 51.00499369204044, 24.800602309405804, 7.282682089135051, 2.1068605966866016, 16.905984431505203, 3.6038061836734414, 0.4443176690256223, 1.590523284394294, 37.72073931992054, 43.39498244225979, 66.82973474264145, 60.42237415909767, 26.061688140034676, 36.16747006773949, 44.503158777952194, 59.01205703616142, 43.2113990932703, 2.4064179975539446, 0.07456011124304496, 0.043888695145142265, 0.04823047427635174, 0.011409911967348307, 0.04677792800066527, 0.045656145812245086, 0.01245764544364647, 0.08465400242130272, 0.03743993649550248, 0.0387549219885841, 0.02396238069195533, 0.09033153604832478, 0.014220880711945938, 0.04908969574898947, 0.0285892651299946, 0.2044608537107706, 0.06040724372724071, 0.07803397835232317, 0.11933076355489902, 0.22224073793040588, 0.15706464619142935, 0.13211591227445751, 0.1415846182499081, 0.12685084948316216, 0.1692923009977676, 0.13897870026994497, 0.15406344551593065, 0.1945822744164616, 0.17329280351987109, 0.16577517410041764, 7.252616677433252, 62.21403121948242, 64.0291178226471, 57.58951596915722, 34.729950204491615, 28.012007586658, 39.73054267466068, 71.27976715564728, 52.09485501050949, 50.00850856304169, 1.3869368587620556, 0.1484144845744595, 0.7608606631401926, 20.2900068461895, 10.200362652540207, 13.701184149831533, 16.485329903662205, 17.46767409145832, 6.889331471174955, 34.05231736600399, 57.20857121050358, 56.69868417084217, 61.363967433571815, 51.98519669473171, 53.31096455454826, 48.95981423556805, 47.530714720487595, 44.65833865106106, 47.77392067015171, 53.38891737163067, 57.5541702657938, 58.233767598867416, 56.55656419694424, 56.73159420490265, 54.51036259531975, 57.239619344472885, 53.18910889327526, 47.549143731594086, 55.25896042585373, 57.51424200832844, 58.82954142987728, 57.22202628850937, 51.6946604847908, 51.707458198070526, 54.96107541024685, 55.934723764657974, 54.01177994906902, 53.191787749528885, 57.41920530796051, 50.573002472519875, 40.736105516552925, 41.51433415710926, 41.321566700935364, 41.9478452950716, 40.959438532590866, 42.27127254009247, 41.5906872600317, 39.87605966627598, 44.4966459274292, 46.27414494752884, 51.172948479652405, 50.01455023884773, 54.27260935306549, 54.982605054974556, 51.9430835545063, 54.9645484238863, 53.47680665552616, 57.383460626006126, 54.11378927528858, 54.813346937298775, 47.30023808777332, 52.26466789841652, 26.522071436047554, 35.04098251461983, 47.40297317504883, 50.11611878871918, 54.352842047810555, 48.31889882683754, 45.84104798734188, 41.213846281170845, 42.77357138693333, 38.97440604865551, 47.53316938877106, 45.831103920936584, 43.27088490128517, 47.84873865544796, 56.133901476860046, 54.19976346194744, 46.74764133989811, 43.10002326965332, 40.46750172972679, 41.570795327425, 41.31331354379654, 40.29245652258396, 54.197039008140564, 55.00292256474495, 55.02829000353813, 52.59281449019909, 48.885258436203, 50.681505650281906, 54.58803802728653, 57.246907353401184, 56.03125378489494, 54.94735814630985, 54.38184209167957, 58.01659405231476, 55.6965259462595, 52.31071762740612, 50.92459000647068, 54.49870102107525, 57.32739083468914, 52.89942763745785, 54.95366580784321, 54.864085614681244, 54.39386084675789, 57.13753022253513, 60.16465678811073, 56.15723602473736, 59.624910950660706, 55.01424975693226, 48.35391014814377, 47.919711247086525, 52.26491868495941, 58.398006185889244, 59.333234801888466, 62.89563864469528, 59.95601378381252, 58.513121008872986, 52.565026581287384, 26.953420490026474, 9.258888121694326, 3.5657716495916247, 21.208130680024624, 3.858488705009222, 0.38219649461098015, 1.7998364777304232, 47.0691154897213, 53.87531027197838, 77.71232038736343, 67.35310345888138, 32.336967810988426, 41.4850415289402, 52.75264911353588, 64.50821131467819, 53.75272884964943, 4.168711183592677, 0.293436671490781, 0.30248784518335015, 0.2837050671223551, 0.09873216535197571, 0.12875288492068648, 0.18899366492405534, 0.08025274015381001, 0.14150436240015551, 0.12390871634124778, 0.14797614247072488, 0.11626805367995985, 0.1987673490657471, 0.12872149207396433, 0.17691622080747038, 0.1534807705320418], [0.018806137159117498, 0.05533671639568638, 0.0333994618995348, 0.020645641088776756, 0.046420888174907304, 0.06647685397183523, 0.06294780076132156, 0.015082939971762244, 0.03393288054212462, 0.07480237050913274, 0.034303345819353126, 0.0865798385348171, 0.057709919128683396, 0.02531174432078842, 0.06898366555105895, 8.4197829477489, 45.65740384161472, 45.27017042040825, 37.579535096883774, 24.780847169458866, 16.957788951694965, 36.45270176231861, 39.79222856462002, 45.11803038418293, 24.249624274671078, 0.4903355153510347, 0.054030803657951765, 5.36169184371829, 10.382778514176607, 4.260913711041212, 7.8947418462485075, 14.046451672911644, 9.705713745206594, 14.314291700720787, 50.77294774353504, 53.90282839536667, 57.087597101926804, 55.221722424030304, 54.37126345932484, 52.51156724989414, 49.27048176527023, 40.37731356918812, 38.23262505233288, 44.58850599825382, 52.835480868816376, 51.0214202105999, 53.93634259700775, 51.73185668885708, 52.80722178518772, 50.70900857448578, 50.36524102091789, 46.683409586548805, 51.96876637637615, 49.877324402332306, 51.20730623602867, 49.75172974169254, 50.51787883043289, 43.34324821829796, 41.86290085315704, 45.67924126982689, 50.050146728754044, 49.192312359809875, 51.49500399827957, 51.630280539393425, 44.92701843380928, 34.80809301137924, 36.36971801519394, 35.39954647421837, 36.24299481511116, 38.01836974918842, 38.585945293307304, 37.95324124395847, 39.66376505792141, 39.64894585311413, 43.062777668237686, 44.75252039730549, 48.25516864657402, 46.47802300751209, 46.27798654139042, 47.24879264831543, 47.46844366192818, 47.76901513338089, 53.2140127569437, 50.8686114102602, 56.41349047422409, 49.34827879071236, 59.34140436351299, 25.162624083459377, 28.60006023198366, 48.110354617238045, 40.74957579374313, 45.27176633477211, 41.749435141682625, 45.805850476026535, 45.11584170162678, 47.51273788511753, 46.85180515050888, 48.42033438384533, 51.99238210916519, 50.58504782617092, 43.37073214352131, 49.94170814752579, 50.28089314699173, 46.52769774198532, 38.91681253910065, 36.7947594076395, 36.190656423568726, 37.982948049902916, 37.225071117281914, 43.34047056734562, 54.648857563734055, 45.989471822977066, 45.89291140437126, 49.00766886770725, 48.028195425868034, 53.90193924307823, 51.0211656242609, 49.11315880715847, 47.15016134083271, 45.94415545463562, 50.85964009165764, 52.534996792674065, 48.507326915860176, 51.645749509334564, 51.47321216762066, 50.84988981485367, 49.51406009495258, 50.500517562031746, 52.24776640534401, 55.79780951142311, 53.50744441151619, 49.43757779896259, 52.90632426738739, 54.39760744571686, 51.14959113299847, 51.21499702334404, 49.237195551395416, 52.857671678066254, 50.820585787296295, 56.435103714466095, 58.282515183091164, 52.45995841920376, 47.06789955496788, 51.27810403704643, 21.411528065800667, 5.303420070558786, 2.1569639956578612, 16.536575853824615, 24.964405819773674, 0.6343608198221773, 0.37770632305182517, 19.099817611277103, 52.67253801226616, 57.705303356051445, 67.21144706010818, 30.428833700716496, 25.170081183314323, 41.71842880547047, 42.31132619082928, 44.88755375146866, 4.351873705163598, 0.03135022889182437, 0.012068928899680031, 0.0498780940688448, 0.034188528152299114, 0.020615760367945768, 0.05944281168922316, 0.11504829686600715, 0.03288231855549384, 0.041752816396183334, 0.06113215131335892, 0.007280510453711031, 0.12269641068996862, 0.028820896841352805, 0.016821394929138478, 0.03382541013706941, 0.06578176587936468, 0.04792451647517737, 0.013691439980902942, 0.052666992269223556, 0.04990958339476492, 0.03935098531655967, 0.10159557888982818, 0.0402939321793383, 0.018505203697714023, 0.061918226710986346, 0.042580277658998966, 0.03868884487019386, 0.04024664252938237, 0.028101928292016964, 0.050305522890994325, 12.537385448813438, 54.36929136514664, 54.677036851644516, 42.67069950699806, 32.37188793718815, 20.14014668762684, 33.480254262685776, 47.14121662080288, 48.87361206114292, 28.383982926607132, 0.4066888819215819, 0.08272520513855852, 6.999630052596331, 12.961994614452124, 4.437167253345251, 12.222374752163887, 10.45555790886283, 4.66439126059413, 13.986135609447956, 50.3976608812809, 54.29428718984127, 58.28963980078697, 57.14454084634781, 56.371802911162376, 55.67185387015343, 50.8006938546896, 42.50404804944992, 40.91151550412178, 46.96632720530033, 54.78609099984169, 52.450299337506294, 57.07671068608761, 54.60111692547798, 54.34709295630455, 52.490569576621056, 51.36627830564976, 46.78019419312477, 52.29390732944012, 53.54856200516224, 53.20849545300007, 51.57001957297325, 50.61373628675938, 46.241041123867035, 43.2965487241745, 48.43010365962982, 53.58484245836735, 49.30963486433029, 52.04671919345856, 53.74809689819813, 45.68423420190811, 37.85377398133278, 38.35766114294529, 37.38462455570698, 39.4537503272295, 40.25260806083679, 41.09262518584728, 39.72945973277092, 41.33731685578823, 40.79384341835976, 47.17297911643982, 46.07001610100269, 50.13642489910126, 49.06260631978512, 49.42058131098747, 47.366046756505966, 50.25454916059971, 49.705767408013344, 55.9490641951561, 52.81607910990715, 56.82207874953747, 51.31652757525444, 61.1864447593689, 27.03385267406702, 30.7319263368845, 47.039587274193764, 41.75328813493252, 46.67250037193298, 41.67021319270134, 44.939447566866875, 45.866297632455826, 50.533480793237686, 47.01368026435375, 49.591906517744064, 51.46640293300152, 48.63064169883728, 43.51626433432102, 51.44451230764389, 52.193319126963615, 49.51659455895424, 40.44841155409813, 40.20550958812237, 38.14329944550991, 39.76742349565029, 39.81394059956074, 45.23118831217289, 56.40608847141266, 48.325274884700775, 49.07516084611416, 49.79939058423042, 50.12742318212986, 55.61296842992306, 53.59597206115723, 50.92891417443752, 48.11667747795582, 48.65985833108425, 52.02043980360031, 54.93080623447895, 49.49755758047104, 52.33098953962326, 53.52969601750374, 52.723291888833046, 50.06304703652859, 52.95437648892403, 54.591138660907745, 56.69316686689854, 55.23340679705143, 50.32565854489803, 54.39057022333145, 56.254647597670555, 53.3139131963253, 52.43455298244953, 52.147125005722046, 56.13708570599556, 52.92267479002476, 59.37972150743008, 60.05405232310295, 52.59388603270054, 46.48173540830612, 51.99584372341633, 23.291429691016674, 6.654876451939344, 1.5201458358205855, 21.173049062490463, 27.90360700339079, 0.3540514939231798, 0.4132475971709937, 22.082849442958832, 53.23195919394493, 58.941939398646355, 67.50243544578552, 33.94077055156231, 31.36260699480772, 46.987142488360405, 50.0647759437561, 52.88355588912964, 6.364016309380531, 0.1311158831231296, 0.05816963508550543, 0.09909003638313152, 0.016017506131902337, 0.10287973185768351, 0.058767464724951424, 0.09351796194096096, 0.05888471663638484, 0.03981324683991261, 0.03511227565468289, 0.03270108609285671, 0.034997580441995524, 0.039707012110739015, 0.007058214032440446, 0.024290072287840303, 0.12580551963765174, 0.17144653305877, 0.10810885243699886, 0.128143566835206, 0.20510868926066905, 0.11359904572600499, 0.11583991610677913, 0.15298140904633328, 0.14512553840177134, 0.20427310519153252, 0.1838482660241425, 0.11004899715771899, 0.1470145268831402, 0.12229456740897149, 0.2358061881386675, 16.308113113045692, 63.557449132204056, 60.08214421570301, 50.470058396458626, 37.85039596259594, 25.980418100953102, 48.25164243578911, 52.59287528693676, 55.26286281645298, 30.858011171221733, 0.7511931506451219, 0.1907321606995538, 9.24043346196413, 13.700098358094692, 7.787555297836661, 17.416722625494003, 22.68540021032095, 15.958254486322403, 18.162964582443237, 54.30232375860214, 54.69871088862419, 59.975001364946365, 59.37668927013874, 60.02254821360111, 56.451944410800934, 53.93940903246403, 45.25053687393665, 44.55938436090946, 49.250924214720726, 57.53661520779133, 54.205341562628746, 59.525025710463524, 55.712549686431885, 54.24544081091881, 53.23944479227066, 51.43244035542011, 46.90753675997257, 54.09057632088661, 53.75888451933861, 56.38335049152374, 53.64382669329643, 54.03109051287174, 48.46382685005665, 45.69807305932045, 50.1660481095314, 54.733957797288895, 51.05591855943203, 53.52029152214527, 57.158687487244606, 48.276318311691284, 38.72493803501129, 41.46732687950134, 38.394735753536224, 40.01682311296463, 42.784279212355614, 43.49436990916729, 43.03027421236038, 43.368646055459976, 44.0245820581913, 48.593342900276184, 49.34340365231037, 53.52289818227291, 50.59041313827038, 51.168035343289375, 50.840899497270584, 52.72431023418903, 51.037941724061966, 57.79309384524822, 54.96065363287926, 60.03944970667362, 53.78855712711811, 61.57750077545643, 29.84247576445341, 31.61950170993805, 46.64110645651817, 41.5910330414772, 45.00356152653694, 41.380110159516335, 45.858116671442986, 48.12809206545353, 50.62186025083065, 47.97794312238693, 50.64529739320278, 55.076896995306015, 50.10362505912781, 45.62525376677513, 53.48922058939934, 52.092483937740326, 54.070726186037064, 43.28764960169792, 41.57248243689537, 39.78052519261837, 41.1470914632082, 41.166478022933006, 47.20908857882023, 57.44754798710346, 50.99980317056179, 49.62480515241623, 49.27510231733322, 50.82221210002899, 57.18136087059975, 55.93410439789295, 52.35826067626476, 51.282728388905525, 50.71976199746132, 55.368462949991226, 56.047410517930984, 51.160549744963646, 53.50296065211296, 55.07110230624676, 55.414254292845726, 52.292790189385414, 55.48135869204998, 56.59536391496658, 60.445435121655464, 57.76781000196934, 52.30529151856899, 56.31216511130333, 60.083827525377274, 56.49842731654644, 55.552160292863846, 55.545943826437, 58.02474841475487, 53.85387562215328, 62.343494072556496, 62.09908738732338, 55.44293895363808, 48.160424530506134, 55.19594460725784, 26.531069353222847, 10.291436165571213, 7.064151540398598, 20.101546458899975, 29.02620166540146, 1.1343173892237246, 0.4512226110091433, 27.74387687444687, 64.73473235964775, 62.51459129154682, 76.29710912704468, 40.31816214323044, 36.905398070812225, 56.79988034069538, 57.63783037662506, 62.639448791742325, 10.90663930401206, 0.3189499274594709, 0.15226612711558118, 0.19798269117018208, 0.1284973486326635, 0.1757854103925638, 0.12738317716866732, 0.2296353637939319, 0.1837430740124546, 0.17873117263661698, 0.17975276859942824, 0.14204455685103312, 0.2199112848029472, 0.14486197207588702, 0.14286342775449157, 0.14749349415069446], [0.03835405092104338, 0.06295025727013126, 0.05290291359415278, 0.012168692101113265, 0.018536754250817467, 0.04490253566473257, 0.029413893244054634, 0.01822778704081429, 0.06863542017526925, 0.04147006184211932, 0.02716616912948666, 0.027435270021669567, 0.03585116159229074, 0.03383105417015031, 0.03711612633196637, 18.963790610432625, 51.33233092725277, 38.29117611050606, 37.37106308341026, 13.480017017573118, 31.23949360102415, 42.759128361940384, 38.69787968695164, 42.65019200742245, 19.40356571227312, 0.26415318658109754, 2.825957997702062, 22.558716908097267, 6.822369564324617, 23.98435290902853, 2.494816929101944, 12.211798019707203, 9.533136505633593, 40.21665059030056, 58.467466458678246, 57.47978165745735, 51.68138399720192, 54.68909740447998, 52.11651384830475, 53.879474848508835, 51.538500264286995, 44.16763678193092, 37.79138132929802, 44.10943530499935, 53.06816138327122, 51.348723247647285, 51.9415370374918, 55.22689014673233, 49.37051139771938, 49.61495228111744, 53.066231086850166, 51.220043152570724, 51.499715745449066, 50.29872938990593, 48.2844802737236, 45.03952659666538, 42.732476592063904, 39.037300273776054, 37.37036772072315, 45.46554073691368, 48.935974314808846, 51.71587094664574, 50.320464223623276, 50.27055390179157, 41.465415582060814, 35.41667215526104, 35.07435232400894, 35.749754682183266, 36.91126495599747, 35.86259722709656, 38.42153951525688, 37.77082063257694, 38.289287611842155, 43.54416623711586, 49.42706756293774, 47.95538753271103, 47.850714549422264, 48.133457377552986, 50.33813327550888, 47.38884173333645, 47.46118605136871, 43.48948337137699, 48.00641879439354, 45.913297310471535, 51.753686517477036, 47.42531977593899, 57.137290835380554, 30.952050425112247, 30.29474649578333, 48.8804516941309, 43.23151521384716, 48.733445182442665, 43.32929536700249, 50.998610034585, 47.38807037472725, 51.427477821707726, 51.42104096710682, 50.18136128783226, 49.520078971982, 52.522229477763176, 51.91549323499203, 49.10136044025421, 52.43747502565384, 48.12883682549, 38.434242233633995, 38.15687611699104, 37.90545500814915, 37.778883799910545, 35.8186449855566, 37.66439974308014, 47.62514725327492, 54.49766747653484, 51.72276757657528, 49.352925941348076, 51.774661391973495, 51.890460178256035, 51.70826755464077, 42.80276522040367, 42.914125844836235, 47.09615483880043, 50.386740267276764, 50.37355877459049, 48.591929376125336, 52.729835137724876, 52.59453199803829, 53.072360157966614, 53.65557186305523, 53.62687960267067, 51.31253778934479, 50.45181557536125, 46.918130591511726, 47.586761713027954, 49.34399642050266, 54.11679871380329, 55.87972171604633, 54.02053467929363, 53.949337899684906, 54.085940569639206, 56.772537007927895, 54.4379498809576, 53.58828887343407, 52.20295920968056, 36.980371847748756, 28.56877651065588, 16.27241212874651, 6.537832757458091, 4.768770709633827, 4.803145565092564, 13.85968504473567, 4.688627310097218, 0.3585745574673638, 12.495967671275139, 43.495996221899986, 57.616661712527275, 53.05090270936489, 21.067618019878864, 30.346081741154194, 43.98195594549179, 50.19248329102993, 44.89084057509899, 6.450334377586842, 0.1485793897882104, 0.031008312180347275, 0.07068089791573584, 0.01652244300203165, 0.044645841626334004, 0.060389539794414304, 0.05063663578766864, 0.03250377871154342, 0.05604669568128884, 0.04457967545022257, 0.07074639244819991, 0.04843845003051683, 0.02341257728403434, 0.05373079045966733, 0.03244363877456635, 0.057010931050172076, 0.032083923506434076, 0.045732813377981074, 0.05255438249150757, 0.009764529750100337, 0.013178699427953688, 0.07422666429192759, 0.007378988348136772, 0.07227002162835561, 0.0629176027723588, 0.017912196162797045, 0.009531467549095396, 0.026736734653241, 0.04065558816364501, 0.07160578461480327, 23.139814026653767, 60.85564970970154, 44.35350760817528, 44.509797021746635, 22.15278659015894, 31.404906325042248, 42.121435180306435, 46.2024237960577, 48.17466616630554, 22.84087646752596, 0.317646567709744, 3.5785282775759697, 25.97960114479065, 11.09414879232645, 27.080147489905357, 10.250906590372324, 9.502018075436354, 5.363291082903743, 44.70747381448746, 59.656570851802826, 61.421842128038406, 53.68359915912151, 56.516438350081444, 54.96117040514946, 56.44694767892361, 52.75449201464653, 47.05737791955471, 39.396635591983795, 46.432858631014824, 54.10969689488411, 54.48741942644119, 54.4182213395834, 55.96821516752243, 50.541027188301086, 49.49837073683739, 51.91434949636459, 53.1593868881464, 52.999977841973305, 52.06225275993347, 50.90669296681881, 49.50251251459122, 44.537280946969986, 40.84903545677662, 38.678318336606026, 47.91306160390377, 50.52112765610218, 51.98466472327709, 51.637158170342445, 52.5066427141428, 42.7466232329607, 36.01598359644413, 37.3042930662632, 37.381398528814316, 39.056173861026764, 38.22353594005108, 40.84090769290924, 40.037467405200005, 39.68561768531799, 45.84618151187897, 51.08059823513031, 49.82693910598755, 51.24645173549652, 50.85671424865723, 51.79801493883133, 49.6623395383358, 50.07790803909302, 46.45866684615612, 49.52947586774826, 47.58239954710007, 53.85922193527222, 49.56887595355511, 59.70081947743893, 32.500435039401054, 31.403908878564835, 48.41661058366299, 44.434120282530785, 48.96498575806618, 44.947191551327705, 50.54706126451492, 49.79494862258434, 52.624744176864624, 52.67002634704113, 52.67736375331879, 51.74196794629097, 53.66803899407387, 53.18158149719238, 51.47542364895344, 54.52664092183113, 50.681486651301384, 40.52190341055393, 39.21406678855419, 40.15937626361847, 40.38624309003353, 37.68865764141083, 39.84196789562702, 50.47356940805912, 55.462462306022644, 53.6775840818882, 53.11257340013981, 53.3553309738636, 52.447179704904556, 52.314255237579346, 45.964165180921555, 45.02268590033054, 50.19964970648289, 53.574009239673615, 52.98563741147518, 49.95078586041927, 53.59512850642204, 53.614853248000145, 54.714647233486176, 54.8653319478035, 54.659637585282326, 54.04419980943203, 50.579872503876686, 49.07264158129692, 46.391440853476524, 49.690264239907265, 56.39144405722618, 58.50522503256798, 55.09828984737396, 56.0787208378315, 56.36680617928505, 57.9740971326828, 56.896775141358376, 55.7327987998724, 53.318005576729774, 37.24939741194248, 27.404252998530865, 16.899127699434757, 6.802527979016304, 2.9826592141762376, 6.328034615144134, 12.682940438389778, 4.087715204805136, 0.275722022051923, 14.371084403246641, 48.38831350207329, 60.60758762061596, 63.19612272083759, 29.99983862042427, 34.65360850095749, 51.09863206744194, 54.885448068380356, 51.9385351985693, 10.155770145356655, 0.13658845040481538, 0.040058341110125184, 0.061483261379180476, 0.04755001762532629, 0.04495008135563694, 0.04647683126677293, 0.031213729380397126, 0.03908313679858111, 0.050018330293823965, 0.07148709293687716, 0.055584048241144046, 0.06646464564255439, 0.015290898099920014, 0.06375766941346228, 0.026286720421921927, 0.14329655998153612, 0.11295483927824534, 0.1407352153910324, 0.13071543507976457, 0.11293077885056846, 0.14099492254899815, 0.14551041618688032, 0.0758141849655658, 0.22912362328497693, 0.15408242965349928, 0.11690503160934895, 0.09926106431521475, 0.12249959312612191, 0.1411215477855876, 0.22006314306054264, 28.947925865650177, 71.6056376695633, 51.90786324441433, 52.6542191952467, 22.008761018514633, 45.50598196685314, 55.1706949621439, 49.85801763832569, 53.917890787124634, 25.871067568659782, 0.2557440893724561, 3.813981218263507, 31.789090409874916, 13.538578525185585, 32.54366911947727, 10.071717705577612, 20.22760659456253, 13.859352562576532, 45.84330506622791, 61.73668943345547, 63.48011188209057, 55.499088540673256, 58.74158374965191, 57.1190670132637, 58.31392049789429, 56.41423903405666, 47.84431949257851, 41.95719659328461, 48.743237257003784, 56.56308464705944, 57.0297946035862, 57.37740755081177, 58.61829176545143, 50.953688845038414, 52.10319556295872, 53.53564269840717, 54.78827208280563, 55.78197196125984, 54.77982133626938, 53.366703763604164, 51.64866775274277, 47.605559304356575, 43.735466971993446, 40.23590415716171, 50.849475637078285, 51.37638196349144, 53.71139846742153, 53.78995165228844, 56.87231965363026, 46.16255633533001, 39.75063979625702, 39.136189967393875, 40.03787398338318, 40.834736824035645, 39.23389412462711, 41.634331718087196, 42.62267388403416, 42.190644666552544, 49.20097589492798, 54.23024542629719, 52.95510984957218, 53.1108482927084, 52.619686648249626, 55.02676248550415, 52.073754742741585, 51.76570147275925, 47.62270778417587, 51.735694482922554, 49.85816203057766, 56.595109328627586, 51.62954717874527, 61.61278188228607, 35.00087946653366, 33.32248292863369, 48.86389218270779, 44.413479790091515, 49.804930686950684, 45.59731386601925, 53.552536591887474, 51.458115577697754, 54.76597487926483, 56.418536603450775, 55.52878014743328, 54.6746201813221, 56.34353242814541, 54.51787479221821, 53.57625491917133, 57.472812831401825, 52.828876823186874, 41.78382329642773, 41.13529309630394, 42.088395953178406, 42.09934316575527, 40.09776636958122, 42.317987233400345, 52.218002602458, 57.60655805468559, 56.07216998934746, 52.7223951369524, 55.36776378750801, 55.604073107242584, 56.72712944447994, 47.66244225203991, 46.652274057269096, 51.682288348674774, 55.50757348537445, 53.81332039833069, 52.13824488222599, 54.92901653051376, 54.64010663330555, 56.80724434554577, 56.69891215860844, 55.25994077324867, 55.46057380735874, 52.17411495745182, 48.93708385527134, 46.33408673107624, 49.88853380084038, 56.17945723235607, 59.4889922440052, 57.953460440039635, 59.07751992344856, 58.341263830661774, 60.982619896531105, 57.69722878932953, 59.31536056101322, 54.89846996963024, 40.02724215388298, 33.234711438417435, 19.798299930989742, 11.527485139667988, 9.837494473904371, 6.755343535915017, 18.168992958962917, 6.677035437896848, 0.347991680027917, 17.187568321824074, 57.43470847606659, 62.29879327118397, 64.4057460129261, 31.348331160843372, 43.57638090848923, 57.787865325808525, 62.52464935183525, 60.78154608607292, 15.107377544045448, 0.3301448095589876, 0.15925510990200564, 0.3008076822152361, 0.15651465539122, 0.18411244091112167, 0.17953175702132285, 0.11503734276629984, 0.19038002646993846, 0.25350957177579403, 0.19589298142818734, 0.1678675110451877, 0.13457172346534207, 0.11391134146833792, 0.18269692780449986, 0.16185918735573068], [0.110441660071956, 0.03513852912874427, 0.07059922456392087, 0.03629217542766128, 0.03763283551961649, 0.0454137752240058, 0.034287931412109174, 0.05894947644264903, 0.1213410338095855, 0.009268932808481622, 0.01611767009308096, 0.02985127426654799, 0.05344626588339452, 0.06460571414208971, 0.19116265088086948, 24.541883692145348, 44.12835828959942, 37.91466951370239, 27.240764871239662, 13.972097262740135, 34.96092081069946, 43.84524688124657, 46.452549174427986, 33.42500902712345, 14.032842703163624, 0.7858005654998124, 2.719225287437439, 4.5685661025345325, 3.211671025492251, 6.110125808045268, 11.448446530848742, 10.54568337276578, 15.418606493622065, 60.95651909708977, 52.4051121622324, 57.23489999771118, 53.37212607264519, 54.594182297587395, 54.526686519384384, 55.12198157608509, 51.958126947283745, 42.86714896559715, 37.013650462031364, 39.785126745700836, 44.340094327926636, 52.6302956789732, 49.4875793159008, 53.00150156021118, 52.51089468598366, 52.727646455168724, 49.26390051841736, 51.145301163196564, 49.93422254920006, 49.17176306247711, 45.55282965302467, 42.54093647003174, 37.798084169626236, 37.93172299861908, 38.32776054739952, 40.89657850563526, 46.79883599281311, 50.991181433200836, 51.580791994929314, 45.95580942928791, 38.407632261514664, 35.53682930767536, 35.55748499929905, 37.12657280266285, 37.109975293278694, 37.180446311831474, 39.664532616734505, 37.169719487428665, 42.50047244131565, 48.01760159432888, 52.247025445103645, 49.96296800673008, 52.0043970644474, 50.574803575873375, 51.86508893966675, 48.671120926737785, 48.50163482129574, 45.763342157006264, 43.336632773280144, 42.498716935515404, 49.50074560940266, 49.779240265488625, 59.23429951071739, 32.87769019603729, 30.362348668277264, 48.99678245186806, 42.83165507018566, 50.25369040668011, 48.474508076906204, 50.81298619508743, 49.86856207251549, 52.461987510323524, 49.006958305835724, 50.61093583703041, 50.150993317365646, 49.70043629407883, 49.439439699053764, 50.94229705631733, 46.92679412662983, 45.65596751868725, 39.602345153689384, 38.34970436990261, 38.17597009241581, 38.17267946898937, 37.644545808434486, 37.805698961019516, 41.09509125351906, 48.69517743587494, 52.1423714607954, 52.801085114479065, 50.924320220947266, 50.09108953177929, 43.42908561229706, 40.80973036587238, 44.07950051128864, 51.55339926481247, 51.279289573431015, 50.92449501156807, 47.796727046370506, 52.599954307079315, 50.933736115694046, 54.00419935584068, 52.0952919870615, 55.056659281253815, 49.72457639873028, 51.37286715209484, 54.33209516108036, 52.91290171444416, 51.72418870031834, 49.567717015743256, 52.88732148706913, 57.550925239920616, 55.59702828526497, 53.10511440038681, 54.421872943639755, 53.34133632481098, 49.30624544620514, 51.73532970249653, 42.61861950159073, 34.23539534211159, 29.309960938990116, 6.812224583700299, 0.42454688460566103, 2.157352287322283, 1.0869693174026906, 1.6153241973370314, 0.19590736425016075, 7.95383770018816, 36.07125163078308, 35.91899000108242, 33.42773348093033, 19.753532633185387, 24.523069001734257, 31.53814997524023, 44.925316125154495, 45.52006021142006, 18.199966996908188, 0.23828142875572667, 0.03211324947187677, 0.029648484269273467, 0.036591368552763015, 0.05259737510641571, 0.02652589977515163, 0.038471417865366675, 0.05242343795544002, 0.005724810289393645, 0.05897510651266202, 0.006775889924028888, 0.04270451689080801, 0.007911742304713698, 0.10597947490168735, 0.036312951851869, 0.017265959941141773, 0.04084192289155908, 0.08896524217561819, 0.027221214222663548, 0.07317006864468567, 0.01968999236851232, 0.03396355350560043, 0.019262673013145104, 0.041100134621956386, 0.03687661672302056, 0.0206493277073605, 0.0047999843536672415, 0.05828901325003244, 0.04439980853931047, 0.28130932536441833, 31.491427682340145, 54.17697988450527, 45.71292266249657, 37.40858606994152, 18.61377239227295, 37.32207231223583, 49.79386568069458, 50.87987780570984, 39.50518436729908, 15.742703452706337, 0.7365838845726103, 2.192005952820182, 3.814434581436217, 3.2904244121164083, 9.84489742666483, 11.184344552457333, 7.226039478555322, 17.013372369110584, 62.269052267074585, 54.89098437130451, 58.36004242300987, 55.118504762649536, 56.11649461090565, 56.683465987443924, 57.95349843800068, 54.58948574960232, 45.514071732759476, 39.45952221751213, 41.694786474108696, 46.181897297501564, 53.70959356427193, 51.793698370456696, 54.79773357510567, 54.6063606441021, 55.34200116991997, 49.657164216041565, 52.92275458574295, 52.565155774354935, 50.635353326797485, 48.00339795649052, 45.3016821295023, 39.60629314184189, 39.92975078523159, 39.714655727148056, 43.87386314570904, 48.701485097408295, 52.93977007269859, 53.22569712996483, 49.382347762584686, 39.94576312601566, 38.67799915373325, 38.12476024031639, 38.586040288209915, 38.60320396721363, 38.40768165886402, 40.586545541882515, 39.40663665533066, 44.59679715335369, 48.9646627753973, 53.545658960938454, 51.99424400925636, 54.7542829066515, 52.33542390167713, 51.74493558704853, 48.909630328416824, 50.12074314057827, 47.18094728887081, 46.962196826934814, 44.993112087249756, 51.4898818731308, 52.60999336838722, 61.987202391028404, 34.86272267997265, 31.782870143651962, 51.18415027856827, 43.463538363575935, 52.11911290884018, 50.54508917033672, 51.410412937402725, 49.8372707515955, 54.1729748994112, 51.23575150966644, 52.08792418241501, 52.340135648846626, 50.951648354530334, 52.076395601034164, 51.58912114799023, 49.640631303191185, 47.516754269599915, 42.38539181649685, 39.865887612104416, 39.48115065693855, 39.87011678516865, 39.677497521042824, 39.33041654527187, 43.535388708114624, 50.017973855137825, 53.953548073768616, 54.612155333161354, 53.20839285850525, 51.374292075634, 44.715001210570335, 42.82593257725239, 46.73054985702038, 52.84498795866966, 52.2849740087986, 52.103442549705505, 48.567413091659546, 53.01155962049961, 52.4478180706501, 55.764481499791145, 53.40012677013874, 55.61723940074444, 51.495342180132866, 52.47221276164055, 53.771838024258614, 54.56766352057457, 52.443037927150726, 52.07261860370636, 53.45646254718304, 58.829355239868164, 57.12825112044811, 55.45365057885647, 56.83270677924156, 54.39411163330078, 51.44853629171848, 53.53616327047348, 46.11748315393925, 37.80768245458603, 32.804468125104904, 9.049988631159067, 2.660887730307877, 4.596497928723693, 2.904685973189771, 2.0269665587693453, 0.173089737072587, 9.626710284501314, 42.566718086600304, 44.690116345882416, 41.65649972856045, 20.859324596822262, 27.116750925779343, 37.65813387930393, 49.525809064507484, 53.645775988698006, 22.24156692624092, 0.3977425885386765, 0.13937960844486952, 0.06592776859179139, 0.05314733993145637, 0.06279304812778719, 0.038025895482860506, 0.037401122172013856, 0.04759517731145024, 0.054208343935897574, 0.05622354947263375, 0.04199150593194645, 0.04307023984438274, 0.08658808379550464, 0.04488017104449682, 0.06359859748044983, 0.18517987191444263, 0.09865771309705451, 0.23845096497097984, 0.13243907305877656, 0.12362642562948167, 0.10601100875646807, 0.14381377754034474, 0.14537164941430092, 0.16446130553958938, 0.09962413780158386, 0.1208338129799813, 0.10926113318419084, 0.24000097007956356, 0.14932327409042045, 0.5168148397933692, 38.199977204203606, 64.00789976119995, 54.424137622117996, 41.976890936493874, 23.712910674512386, 48.064099699258804, 54.88803572952747, 55.75620174407959, 45.04298061132431, 18.311384618282318, 0.9178907400928438, 3.068232759833336, 7.8654563426971436, 7.161539839580655, 12.110533453524113, 18.184904605150223, 16.637462340295315, 18.93260568380356, 65.7110595703125, 58.059303760528564, 60.664326176047325, 58.21210876107216, 57.7578317373991, 59.21625807881355, 60.212302431464195, 56.904560923576355, 46.72223970293999, 42.353857308626175, 44.442008659243584, 47.41105914115906, 56.9548474252224, 54.27374169230461, 57.25224606692791, 56.756433472037315, 55.73463410139084, 50.688090696930885, 54.92566131055355, 54.62239198386669, 52.312685921788216, 50.84758333861828, 46.81017078459263, 41.620120480656624, 41.976951733231544, 43.833361119031906, 46.18961088359356, 51.51520371437073, 56.28759562969208, 57.24310375750065, 51.422811672091484, 42.55194827914238, 39.670004323124886, 40.56478410959244, 40.83946757018566, 40.3000333160162, 39.64704595506191, 43.39056707918644, 41.44243061542511, 47.20579415559769, 51.484083384275436, 55.86989924311638, 55.11419199407101, 55.42976126074791, 53.42918761074543, 54.12834249436855, 51.27752646803856, 52.108655869960785, 50.17822265625, 48.25361452996731, 46.093240454792976, 53.08231942355633, 54.8799117654562, 62.90970169007778, 38.38950343430042, 34.25434112548828, 51.27409905195236, 45.17953388392925, 54.04139555990696, 52.02293246984482, 54.08711850643158, 51.91151484847069, 55.568674206733704, 52.95780770480633, 53.7644512206316, 53.93815129995346, 53.78082074224949, 53.95577475428581, 52.57826507091522, 50.66691443324089, 48.24633792042732, 43.79054881632328, 43.26643913984299, 42.520516365766525, 41.37786827981472, 41.72439068555832, 42.51164764165878, 46.082521229982376, 52.64514148235321, 56.85598433017731, 57.1700032800436, 55.22620238363743, 54.13008660078049, 46.43302582204342, 45.24870157241821, 48.488966301083565, 56.48558780550957, 54.16338801383972, 53.09720702469349, 49.53608751296997, 55.86985744535923, 53.50357621908188, 58.15768048167229, 55.8158091455698, 59.631891176104546, 51.74778163433075, 54.515059143304825, 56.4123847335577, 56.27667881548405, 55.7755921036005, 52.199482396245, 55.52181892096996, 61.27187177538872, 57.91778415441513, 55.69320112466812, 56.84436455368996, 55.08470177650452, 50.345888659358025, 55.128992199897766, 47.114124074578285, 37.92655527591705, 31.968843564391136, 11.619378458708525, 6.882803421467543, 7.946206284686923, 2.2588265547528863, 2.1312533877789974, 0.23665697139222175, 10.535832401365042, 51.09172783792019, 48.93158175051212, 45.605054050683975, 30.781538374722004, 35.11203110218048, 45.555660501122475, 56.86243258416653, 64.14572596549988, 29.037336967885494, 0.4283237038180232, 0.1611915958346799, 0.19776199129410088, 0.22346678073517978, 0.15128518600249663, 0.10056652434286661, 0.0886437512235716, 0.08247518300777301, 0.10989009591867216, 0.1546041149413213, 0.11558511454495601, 0.09795014950213954, 0.21897028607781976, 0.1459080885979347, 0.12103912071324885], [0.033070927966036834, 0.031462074257433414, 0.03280147640907671, 0.03878309391438961, 0.05888495041290298, 0.006314379825198557, 0.03302043965959456, 0.05646164157951716, 0.10047460935311392, 0.04220238719426561, 0.010133699051948497, 0.04394342111481819, 0.07425085830618627, 0.06275857536820695, 1.0577357048168778, 25.494851656258106, 36.54377527534962, 35.59858359396458, 20.978738889098167, 23.091655410826206, 39.97972570359707, 52.160861268639565, 40.08070908486843, 35.1448879390955, 7.433118866756558, 0.31070190598256886, 0.670736861648038, 2.6509272772818804, 11.32624888792634, 20.487989522516727, 15.593087431043386, 13.868197537958622, 35.02954512834549, 58.197228759527206, 54.10215049982071, 51.530490294098854, 47.78398633003235, 50.78710958361626, 50.24603381752968, 47.8540051728487, 43.05434212088585, 39.03386525809765, 38.93633209168911, 38.7134550511837, 38.882861360907555, 41.35334059596062, 45.18080301582813, 48.21800284087658, 49.790362268686295, 53.171652629971504, 49.7153352946043, 47.075081169605255, 52.99921028316021, 50.26324689388275, 48.05420882999897, 47.307176515460014, 44.27919119596481, 38.40539038181305, 37.39565536379814, 36.292863339185715, 41.501870825886726, 44.939086586236954, 46.11636981368065, 39.781824722886086, 37.87592679262161, 35.60358792543411, 38.151723593473434, 36.364227309823036, 38.46544995903969, 36.76838502287865, 39.45813149213791, 35.140031799674034, 44.46505822241306, 49.7287941724062, 50.43858088552952, 52.61525608599186, 51.46361008286476, 50.25499753654003, 52.32161544263363, 48.51791314780712, 47.72062472999096, 43.69884833693504, 45.35865627229214, 43.37623804807663, 49.72897656261921, 46.6424135863781, 53.93740653991699, 39.07012291252613, 30.68070888519287, 48.147117644548416, 46.009553745388985, 52.4500447511673, 47.3169381916523, 51.83128595352173, 47.46223099529743, 52.406875267624855, 48.56408067047596, 51.02349869906902, 50.30746512115002, 49.591366946697235, 48.28185461461544, 46.972239688038826, 47.18938283622265, 43.846318423748016, 39.97037820518017, 37.9944272339344, 37.72738516330719, 38.867153003811836, 37.68180660903454, 39.42985340952873, 38.28122824430466, 46.8285807967186, 50.3143959492445, 50.157388374209404, 47.161921709775925, 42.20927506685257, 39.21301044523716, 42.18954272568226, 47.48324766755104, 52.3720121383667, 47.96764947474003, 46.5504927188158, 47.33864262700081, 50.54934114217758, 52.46780499815941, 50.63753820955753, 47.964765429496765, 49.69317868351936, 50.791661739349365, 55.07892608642578, 51.07530511915684, 52.77070194482803, 54.92888353765011, 51.923715993762016, 49.841332733631134, 55.736002027988434, 50.07136479020119, 55.48195905983448, 51.121043264865875, 53.326881900429726, 54.36981953680515, 58.650187253952026, 58.65658991038799, 59.67244639992714, 42.408771961927414, 11.236776988953352, 0.9337078069802374, 2.68241286277771, 0.6925913889426738, 0.6941604672465473, 0.05902658558625262, 4.041026160120964, 39.60418425500393, 39.64682176709175, 25.65960891544819, 19.887089766561985, 29.837849512696266, 46.07766509056091, 48.2620120793581, 48.844794407486916, 22.93682511895895, 0.44832968967966735, 0.08343153676833026, 0.03243108534661587, 0.011746978743758518, 0.01669473815127276, 0.013269314731587656, 0.06266343203606084, 0.04241880858899094, 0.06018509295245167, 0.01926766024553217, 0.01246031439222861, 0.10433587754960172, 0.06103053274273407, 0.07301834397367202, 0.03950497724872548, 0.07595929710078053, 0.059594168997136876, 0.03060477123653982, 0.07956464309245348, 0.08271530488855205, 0.03162787375913467, 0.04666604181693401, 0.031049280587467365, 0.09784153618966229, 0.018420804808556568, 0.011829268078145105, 0.024054729838098865, 0.09489342133747414, 0.0643182432395406, 2.101309569552541, 35.711749121546745, 47.151958644390106, 43.018890023231506, 28.460567817091942, 24.379013031721115, 37.89172254502773, 55.586476251482964, 44.72981661558151, 40.76012782752514, 7.563987169414759, 0.2203372330404818, 2.284425781108439, 2.9918891564011574, 13.050304725766182, 21.25779591500759, 7.969696149230003, 5.77628237195313, 38.07017236948013, 60.567469373345375, 57.90454566478729, 54.096728190779686, 51.18479624390602, 52.35325254499912, 52.98177681863308, 50.66002920269966, 45.683747828006744, 40.88084734976292, 40.220059007406235, 38.697887286543846, 42.54449687898159, 43.48869301378727, 48.597906455397606, 50.200162678956985, 52.83437132835388, 52.403067871928215, 51.37469105422497, 49.407574608922005, 55.00328354537487, 52.14076794683933, 50.496007204055786, 48.502428978681564, 45.34386366605759, 39.509664326906204, 38.55989009141922, 39.184048399329185, 43.99332493543625, 48.52435000240803, 47.42985673248768, 43.111586049199104, 40.77870883047581, 36.542411148548126, 41.13238625228405, 38.944722041487694, 39.54624876379967, 37.52533480525017, 40.560657531023026, 36.78079515695572, 46.626203656196594, 50.59940725564957, 52.83356197178364, 54.20772023499012, 52.798315063118935, 52.35917642712593, 54.5069769769907, 49.68101553618908, 50.7585047185421, 45.32766133546829, 46.89491763710976, 45.11627487838268, 51.93060502409935, 48.89801435172558, 56.032971292734146, 41.06106407940388, 32.33046256005764, 47.97033593058586, 47.84607119858265, 53.164102435112, 47.91019655764103, 53.50255407392979, 50.8599478751421, 53.31757239997387, 51.23836576938629, 53.61751690506935, 51.374603658914566, 51.067644730210304, 50.340983122587204, 50.100193843245506, 48.193285167217255, 45.76666697859764, 41.19855970144272, 39.80607882142067, 40.240589305758476, 39.62038278579712, 39.94312986731529, 40.28807535767555, 40.812329426407814, 48.87993112206459, 51.58155955374241, 53.35424043238163, 51.33078821003437, 44.69422772526741, 40.47015778720379, 43.22480857372284, 49.70018930733204, 53.58113385736942, 50.28151251375675, 48.04391898214817, 49.282033145427704, 51.715886145830154, 54.489513114094734, 51.24528519809246, 49.25380066037178, 50.68723954260349, 51.778871566057205, 56.847776770591736, 53.21036495268345, 55.220753476023674, 56.45486265420914, 52.78080180287361, 50.75658202171326, 56.408881321549416, 52.42608703672886, 54.80861999094486, 51.653535291552544, 53.1634146720171, 56.03898636996746, 59.63328570127487, 59.756969064474106, 59.799895361065865, 44.61303748190403, 11.364014111459255, 3.128735488280654, 5.974841192364693, 3.7353273387998343, 2.3957343958318233, 0.2502088254550472, 4.242693213745952, 43.89626294374466, 45.14142952859402, 31.47777881473303, 22.242735363543034, 36.45098425447941, 51.90911717712879, 54.88830551505089, 58.38826350867748, 31.0900704190135, 0.4871405696030706, 0.059920502462773584, 0.0422046247695107, 0.018649169214768335, 0.029903165232099127, 0.05316888076777104, 0.02219092242739862, 0.025597873791411985, 0.039573974718223326, 0.06439734876039438, 0.05498418140632566, 0.05902201766730286, 0.03478797196294181, 0.07802393709425814, 0.04808600409887731, 0.11196277337148786, 0.07332728520850651, 0.08848082012264058, 0.27359749074094, 0.19072726252488792, 0.12710096809314564, 0.1948929819627665, 0.11417428439017385, 0.19671296555316076, 0.14896760723786429, 0.0739636916841846, 0.09022532729431987, 0.258486473467201, 0.1152893241669517, 3.280668198131025, 46.13744728267193, 56.39414571225643, 51.30673170089722, 31.960780397057533, 32.34113998711109, 52.93182469904423, 61.273387894034386, 51.0579514503479, 47.21604220569134, 9.898271262645721, 0.3999356646090746, 3.6852958984673023, 4.41993897780776, 15.052290000021458, 30.95315046608448, 28.690366186201572, 21.01879633963108, 37.87076286971569, 62.97349266707897, 59.30326581001282, 57.0562069863081, 52.68563210964203, 55.53371608257294, 55.432793498039246, 53.918449357151985, 47.021143063902855, 43.690815567970276, 41.05599135160446, 41.91606380045414, 43.496604189276695, 46.18535131216049, 51.564053893089294, 53.72906371951103, 55.24646669626236, 55.96226088702679, 52.66067124903202, 50.96813187003136, 58.38775813579559, 54.36164237558842, 52.510978281497955, 50.56204006075859, 48.44486966729164, 41.337012872099876, 41.62446744740009, 40.457052290439606, 46.38991713523865, 50.751049518585205, 49.905176907777786, 44.416299238801, 41.95706360042095, 39.38248135149479, 42.711228132247925, 40.75082212686539, 42.571479231119156, 40.20517520606518, 43.0073918402195, 38.620333448052406, 48.31616297364235, 53.96649397909641, 54.04300667345524, 56.770222932100296, 54.02431167662144, 55.10379575192928, 57.02358193695545, 50.67047484219074, 51.64582170546055, 47.975792437791824, 48.21575716137886, 48.353906348347664, 53.63491617143154, 51.53109826147556, 58.2014237344265, 44.94117647409439, 33.21983143687248, 47.82249726355076, 49.49802875518799, 55.738525092601776, 50.379178673028946, 55.30245669186115, 52.53407724201679, 56.528453305363655, 53.19851338863373, 55.827945694327354, 54.71418745815754, 52.73604400455952, 51.629938557744026, 52.02208511531353, 51.26173831522465, 48.031565845012665, 43.45185399055481, 41.72847546637058, 41.57304860651493, 42.33929269015789, 40.140498876571655, 42.54417769610882, 43.2753686606884, 51.87040105462074, 52.927473932504654, 54.81609798967838, 52.22885861992836, 44.58383224904537, 42.186195105314255, 46.19252532720566, 51.97421908378601, 56.863314136862755, 52.89766073226929, 49.65211808681488, 50.13435401022434, 52.79827706515789, 57.93617136776447, 53.42505343258381, 50.02341516315937, 51.398397982120514, 53.55194002389908, 58.84561836719513, 54.92615148425102, 57.820665165781975, 60.01703470945358, 54.04258869588375, 51.14969752728939, 56.52693718671799, 51.40268035233021, 56.513352915644646, 53.29476602375507, 54.96478021144867, 57.384676560759544, 61.47219702601433, 59.864081516861916, 60.46479128301144, 46.94096356630325, 16.099496707320213, 3.9684196561574936, 7.784600481390953, 2.980733192525804, 2.2338419454172254, 0.22008706990163773, 4.601150779053569, 50.846447199583054, 52.60419487953186, 37.662431448698044, 29.624002687633038, 43.09484414756298, 57.96199858188629, 63.70539419353008, 65.4437667131424, 40.706151723861694, 1.251014827284962, 0.22571968875126913, 0.17629235662752762, 0.08441575075266883, 0.08235055414843373, 0.12376575643429533, 0.11337370742694475, 0.27458240976557136, 0.1950569372274913, 0.14329451165394858, 0.13237962702987716, 0.21762123971711844, 0.13431528175715357, 0.15006252739112824, 0.13288689980981871], [0.10447592823766172, 0.022270951922109816, 0.06103131570853293, 0.05604758254776243, 0.0545346291619353, 0.015940424818836618, 0.03237756907765288, 0.027868474608112592, 0.11132645595353097, 0.01850879198173061, 0.031710489638498984, 0.0733436866721604, 0.043443885224405676, 0.08721443417016417, 2.7845000848174095, 26.655157394707203, 34.112604930996895, 31.91027730703354, 22.137982584536076, 19.411400891840458, 35.15540197491646, 51.59633316099644, 32.71568588912487, 33.59480291604996, 4.202031595632434, 0.5944107135292143, 4.870810434222221, 1.291617073584348, 3.203553236089647, 14.243655391037464, 8.125241752713919, 17.08904530853033, 47.51009322702885, 58.630515709519386, 53.654154539108276, 48.997629806399345, 42.950201109051704, 40.84815010428429, 40.14978937804699, 40.89404784142971, 45.01728259027004, 45.444999039173126, 44.469990357756615, 43.771052062511444, 42.40900754928589, 44.45901274681091, 44.46930639445782, 46.31011001765728, 47.94773854315281, 51.283507347106934, 50.48959694802761, 49.259705543518066, 49.73868124186993, 51.34512484073639, 48.88332433998585, 48.55171613395214, 47.52889841794968, 42.8586982190609, 39.992018043994904, 35.114675760269165, 35.346763506531715, 37.60049857199192, 37.391027212142944, 37.6814304292202, 38.29864650964737, 37.85075694322586, 36.23069107532501, 37.01168596744537, 37.29682266712189, 36.57263092696667, 41.967801824212074, 37.15790972113609, 42.578064277768135, 52.08481214940548, 50.86242534220219, 48.69740031659603, 49.49586287140846, 52.148530930280685, 49.27037917077541, 47.32185512781143, 45.98731353878975, 45.908323377370834, 49.88746605813503, 48.94637815654278, 52.11476594209671, 48.129030615091324, 57.00375460088253, 34.32109214365482, 31.420363895595074, 50.91608226299286, 46.44196294248104, 53.61660495400429, 48.4115606546402, 49.49610985815525, 49.44790944457054, 49.949011355638504, 48.24764505028725, 51.08366847038269, 49.94948633015156, 51.13489732146263, 46.38363987207413, 47.443600594997406, 43.43086391687393, 41.942419186234474, 39.21706482768059, 37.5079545378685, 39.18939471244812, 38.70284982025623, 37.3124398291111, 38.315946981310844, 38.05401563644409, 37.44317941367626, 38.62322509288788, 42.02530413866043, 39.51474465429783, 39.88167196512222, 40.35661228001118, 45.98105147480965, 49.758557975292206, 50.901244059205055, 47.63323321938515, 49.04273718595505, 49.60149720311165, 48.166333213448524, 50.50198048353195, 47.48703986406326, 49.08625245094299, 53.53068396449089, 51.825434267520905, 50.02692997455597, 50.12190207839012, 48.96978110074997, 52.62773461639881, 52.97162376344204, 53.78636844456196, 44.25651401281357, 50.92505358159542, 53.35326008498669, 54.892804473638535, 59.10594619810581, 57.85666823387146, 59.86802950501442, 57.179840952157974, 57.61320389807224, 48.432885110378265, 11.065041404217482, 2.2292617661878467, 3.185680420137942, 4.691914608702064, 0.3717761771986261, 0.17251106968615204, 1.2594770919531584, 30.995265506207943, 41.10549509525299, 46.68711818754673, 36.693753227591515, 19.84962187707424, 32.383367121219635, 42.32823148369789, 51.75465166568756, 30.240802690386772, 0.8046242804266512, 0.009299250468757236, 0.008926756345317699, 0.0376299559866311, 0.04620048144715838, 0.027074851568613667, 0.009797431939659873, 0.016549050851608627, 0.018285067853867076, 0.01758451013301965, 0.05303757257934194, 0.019044416658289265, 0.03823350758466404, 0.06387461704434827, 0.066755723382812, 0.02442787055770168, 0.0383998377219541, 0.05422066729806829, 0.029519495292333886, 0.025658405211288482, 0.013084444817650365, 0.041891913424478844, 0.07001941427006386, 0.1560562604572624, 0.05056873669673223, 0.0615624002966797, 0.045460059263859876, 0.10432726121507585, 0.09063448072993197, 4.206330114975572, 38.60211342573166, 44.59187261760235, 40.06188489496708, 28.168475590646267, 26.562746353447437, 42.83871129155159, 58.05491879582405, 38.43665510416031, 37.004166170954704, 4.0519686229527, 0.3701797581743449, 6.040705433115363, 2.7305182814598083, 5.636589992791414, 22.657739594578743, 7.227301485836506, 16.39869835227728, 50.64478442072868, 60.66133573651314, 57.10177794098854, 50.923222079873085, 45.11678405106068, 44.20892156660557, 42.920532301068306, 44.294405579566956, 46.25714085996151, 48.387101367115974, 46.889556124806404, 44.499514773488045, 45.28057426214218, 46.64817027747631, 45.82198441028595, 48.46180155873299, 49.50587533414364, 53.46672959625721, 51.38584345579147, 50.604232996702194, 51.135980263352394, 53.37482392787933, 51.78653575479984, 50.526010394096375, 49.690659418702126, 44.401662424206734, 41.685739159584045, 36.48144342005253, 37.40532584488392, 38.8205599039793, 39.03401345014572, 38.93445499241352, 40.66802456974983, 39.937369376420975, 38.23407657444477, 39.41824123263359, 38.604682087898254, 37.38512232899666, 43.21902148425579, 38.99121634662151, 45.91214217245579, 53.89706410467625, 53.06465037167072, 49.94788281619549, 50.543470457196236, 54.14406605064869, 52.02059179544449, 48.64848934113979, 48.36488015949726, 45.76134346425533, 51.83273367583752, 52.201971262693405, 55.4718592017889, 51.291688308119774, 57.33011148869991, 37.44099073112011, 33.527451530098915, 49.85560476779938, 47.26492278277874, 54.10432778298855, 49.484193697571754, 50.93221999704838, 50.78275881707668, 53.526880368590355, 50.534723326563835, 52.80591085553169, 52.13850326836109, 52.53351107239723, 49.65744540095329, 48.93290787935257, 45.276599675416946, 44.53327976167202, 41.36285908520222, 41.60997122526169, 40.1655737310648, 40.94155669212341, 39.12157595157623, 40.323531255126, 39.901928678154945, 40.19658386707306, 42.01110430061817, 43.00009623169899, 42.788086608052254, 41.67016379535198, 42.20036454498768, 47.95342303812504, 52.556127458810806, 53.22270669043064, 48.47796589136124, 50.04440523684025, 50.1326896995306, 49.18695084750652, 51.76381677389145, 49.032960310578346, 48.45646284520626, 53.980180844664574, 53.81126470863819, 53.376024663448334, 51.75994098186493, 51.64248928427696, 55.813438072800636, 54.61070001125336, 52.023092061281204, 46.48610137403011, 52.002204582095146, 53.170307502150536, 55.96479915082455, 59.927348122000694, 58.203042447566986, 61.413676366209984, 58.367600217461586, 59.45310316979885, 47.96619035303593, 13.857002388685942, 2.9374091047793627, 6.168732913210988, 10.209524910897017, 1.5097729861736298, 0.26556297030765563, 1.4888410968706012, 34.12037931382656, 47.879638597369194, 44.61401782929897, 33.76363165676594, 27.980704866349697, 39.059939458966255, 49.57831844687462, 62.107435539364815, 38.856209591031075, 1.2429524911567569, 0.04311332893848885, 0.06618729021283798, 0.048633241531206295, 0.027727828346542083, 0.057713704081834294, 0.028740832094626967, 0.045451290789060295, 0.036242804053472355, 0.026770945805765223, 0.05250053967756685, 0.013426402347249677, 0.07965279539348558, 0.06302534035057761, 0.027297111810185015, 0.1826232622261159, 0.10702347630285658, 0.11641442004474811, 0.07949989070766605, 0.11830530100269243, 0.09457790467422456, 0.1450562514946796, 0.12510010827099904, 0.27401439961977303, 0.17853551282314584, 0.175977953185793, 0.08958333244663663, 0.16076644911663607, 0.2155374374706298, 6.109083713963628, 49.45922903716564, 53.47736522555351, 47.908547446131706, 34.265679717063904, 28.656111024320126, 45.75364127755165, 59.816264882683754, 43.973683789372444, 43.07204157114029, 5.432243132963777, 0.7527185906656086, 7.530462993308902, 2.6102791959419847, 4.820210449397564, 22.169760279357433, 13.332968708127737, 19.536011405289173, 51.08819782733917, 65.06789088249207, 60.84771953523159, 54.12508986890316, 48.53584058582783, 45.35021312534809, 44.13644805550575, 46.56083956360817, 49.2792858928442, 50.459312573075294, 50.64014106988907, 48.30886736512184, 46.082623824477196, 49.58227403461933, 48.45647044479847, 52.896311804652214, 51.87743827700615, 56.15493714809418, 53.02590765058994, 51.43986135721207, 53.167632445693016, 54.99769784510136, 53.24078992009163, 52.34848380088806, 52.699341773986816, 46.71603083610535, 44.56962861120701, 39.71272923052311, 38.49410802125931, 40.25591008365154, 41.317048743367195, 41.19345657527447, 42.48649679124355, 41.79010055959225, 39.41577136516571, 42.289937138557434, 40.12198247015476, 40.378126725554466, 44.21029709279537, 39.740714728832245, 46.92795306444168, 56.32821924984455, 55.491051971912384, 53.116301000118256, 52.35355652868748, 57.09382116794586, 55.02033703029156, 51.43466703593731, 50.03774419426918, 49.092761501669884, 55.45666001737118, 54.17731426656246, 56.30590304732323, 52.16213420033455, 59.234877079725266, 39.663795456290245, 35.64951606094837, 50.811865255236626, 47.841633036732674, 56.373414024710655, 51.38120770454407, 53.02848011255264, 52.56323307752609, 54.13843475282192, 52.6102289557457, 54.884144738316536, 52.759177163243294, 54.6860271692276, 52.0483835041523, 49.94946353137493, 47.46704153716564, 47.779893949627876, 42.7171216160059, 41.65262393653393, 42.74587847292423, 42.01122969388962, 41.3727081567049, 41.828113719820976, 42.2421433031559, 41.32517270743847, 43.12536410987377, 45.557359009981155, 43.527732118964195, 44.29533272981644, 44.366445913910866, 49.95582818984985, 55.521666929125786, 55.703958347439766, 49.891094863414764, 50.8373960852623, 51.687030494213104, 50.64156599342823, 54.21692334115505, 50.32440461218357, 49.923662915825844, 55.082908272743225, 56.038613989949226, 55.74597269296646, 53.738669604063034, 54.88014355301857, 58.85204762220383, 58.33947032690048, 54.77460041642189, 50.07455661892891, 52.81049720942974, 54.174589812755585, 58.07487152516842, 63.05286280810833, 59.2177589982748, 64.33006927371025, 60.42674772441387, 61.6615104675293, 51.97195440530777, 16.481849290430546, 6.658029332756996, 8.83075749501586, 14.068193156272173, 1.444234934169799, 0.397609862848185, 1.6911732335574925, 37.802697122097015, 55.25540001690388, 57.1149480342865, 47.90681853890419, 33.8966853171587, 44.161009937524796, 56.775238662958145, 66.40451475977898, 49.69236932694912, 1.725595467723906, 0.1105581178853754, 0.24533270741812885, 0.18603632517624646, 0.12973345495993271, 0.15134234621655196, 0.3067780227866024, 0.0866428023437038, 0.14234279631637037, 0.13477131666149944, 0.11476804706035182, 0.117366781050805, 0.12049817669321783, 0.2210429115802981, 0.15288693364709616], [0.04027046546980273, 0.05535429416340776, 0.023543458737549372, 0.036129066211287864, 0.1362632858217694, 0.0512256858200999, 0.03879025563946925, 0.017570414893270936, 0.0060235094224481145, 0.019751945001189597, 0.041057754278881475, 0.10889251585467719, 0.0707554021209944, 0.1706831599585712, 6.661110492423177, 33.782015070319176, 36.71737655997276, 38.646734431385994, 23.75467613339424, 19.489475302398205, 42.097108885645866, 44.60822694003582, 28.785235695540905, 35.37460081279278, 1.3062176713719964, 0.10667975060641766, 1.4545683609321713, 2.6553756510838866, 2.9357217578217387, 10.437264740467072, 8.698913119733334, 27.811872325837612, 56.61538504064083, 54.751623049378395, 54.47231523692608, 47.826490849256516, 42.64465570449829, 40.948350727558136, 43.00009623169899, 49.82722409069538, 54.62897703051567, 51.29730440676212, 51.85758054256439, 48.43666210770607, 47.80213415622711, 48.98097150027752, 49.89585980772972, 47.9257757216692, 50.745646208524704, 52.29930683970451, 53.39413829147816, 48.30838859081268, 44.635973051190376, 46.89748629927635, 49.888385608792305, 48.175509721040726, 47.667241394519806, 45.16185723245144, 42.29405991733074, 37.9107291251421, 38.56892220675945, 36.11214883625507, 37.99612194299698, 36.326426938176155, 38.32334518432617, 38.22267718613148, 37.91128769516945, 37.048122212290764, 37.781919836997986, 36.07022948563099, 39.16949138045311, 37.16064177453518, 40.80555438995361, 48.24172876775265, 49.83559884130955, 49.32213619351387, 51.06431990861893, 51.62456564605236, 49.98893201351166, 46.15048058331013, 43.89811724424362, 48.55006702244282, 50.08670076727867, 51.36068880558014, 53.25460597872734, 45.98218381404877, 51.3241233676672, 35.48368155956268, 31.482116281986237, 49.122810289263725, 46.5786188095808, 50.05273438990116, 47.41343401372433, 49.16521221399307, 45.36734260618687, 45.11996068060398, 46.116658598184586, 48.672629445791245, 48.8417811691761, 51.340268701314926, 47.7680803835392, 47.30081185698509, 44.10720482468605, 41.857421547174454, 39.568173587322235, 38.83748039603233, 37.155922427773476, 39.64770331978798, 38.68485018610954, 39.70248878002167, 38.974580839276314, 38.411390259861946, 37.781885638833046, 38.50393809378147, 38.68130497634411, 39.23818789422512, 41.60762295126915, 46.29045367240906, 49.966137036681175, 50.380318611860275, 49.94605511426926, 49.871989488601685, 47.79961109161377, 47.88631483912468, 46.172925978899, 49.176926985383034, 53.182896226644516, 52.10061550140381, 47.55574017763138, 48.054710403084755, 43.73352527618408, 43.69498394429684, 48.85810129344463, 54.35288764536381, 49.393519163131714, 49.888925179839134, 54.42154236137867, 54.63838532567024, 59.26739953458309, 55.49420580267906, 55.20206227898598, 54.49962057173252, 58.19308318197727, 56.82628132402897, 55.166215002536774, 15.710977055132389, 4.979687416926026, 5.678344527259469, 9.394827727228403, 1.2167164427228272, 0.04041499501909129, 0.20908516104100272, 24.325563199818134, 39.00331869721413, 49.4770272821188, 55.33396080136299, 23.687545135617256, 37.33337290585041, 44.31386053562164, 55.37232354283333, 32.1940840780735, 1.4853480155579746, 0.02992719782923814, 0.0548097061982844, 0.08948545801104046, 0.15500566136324778, 0.05123937102325726, 0.05945057826465927, 0.037733218414359726, 0.03612423111917451, 0.05351467334548943, 0.026776172380778007, 0.06074309523683041, 0.07654491098946892, 0.05531762835744303, 0.01264344304217957, 0.023742931334709283, 0.038089538356871344, 0.023609329909959342, 0.03992573787400033, 0.030737825327378232, 0.06671261202427559, 0.05884242164029274, 0.017392334702890366, 0.018133870107703842, 0.026583009894238785, 0.01925825166836148, 0.1480122999055311, 0.06529461272293702, 0.1109359304246027, 9.053491093218327, 44.90369148552418, 45.39803735911846, 43.97286683320999, 29.411487691104412, 21.704568341374397, 48.847572058439255, 53.40682581067085, 32.47610494494438, 37.60265685617924, 1.6074054222553968, 0.09817694983212277, 1.9193180976435542, 5.446900371462107, 3.164539304561913, 10.790489986538887, 8.17166006192565, 28.660769574344158, 57.45806202292442, 56.64319574832916, 55.36366380751133, 49.64963302016258, 43.197252452373505, 42.87205830216408, 44.698829278349876, 51.369097754359245, 56.80447809398174, 53.50553311407566, 53.14391031861305, 51.18890002369881, 50.77009029686451, 51.439276188611984, 51.482514068484306, 50.185343474149704, 51.72841027379036, 52.75427542626858, 53.45885641872883, 49.4428975135088, 45.84401562809944, 49.169646576046944, 51.77301608026028, 49.5040438324213, 50.42214296758175, 46.80944882333279, 43.96158903837204, 39.69841539859772, 40.04004366695881, 38.869106099009514, 38.91717351973057, 38.55116195976734, 38.586245477199554, 40.314035564661026, 39.67633478343487, 38.12912620604038, 39.289899319410324, 37.07728564739227, 40.91469593346119, 39.978357776999474, 42.56571114063263, 50.22921971976757, 53.56875032186508, 51.30075842142105, 52.7708425372839, 54.01348985731602, 53.189352080225945, 47.32898734509945, 45.580948144197464, 48.701785281300545, 53.382054939866066, 53.277864530682564, 54.09677378833294, 47.67868638038635, 52.83779874444008, 35.90398080646992, 33.48128400743008, 50.08195102214813, 47.860791608691216, 53.27731356024742, 47.63690762221813, 49.74411875009537, 46.32946237921715, 47.694364339113235, 46.7315948009491, 48.97633194923401, 51.07731141149998, 53.32600794732571, 51.07481114566326, 47.66847252845764, 46.18521071970463, 43.97425375878811, 40.35827659070492, 39.54733170568943, 39.308020547032356, 40.42478062212467, 39.5648829638958, 40.56828372180462, 40.706512704491615, 39.47617672383785, 38.57570484280586, 39.325871989130974, 39.78718623518944, 41.86954289674759, 42.64864169061184, 47.62801229953766, 50.96592038869858, 51.369800716638565, 51.03486008942127, 52.007699087262154, 49.047707319259644, 49.19580437242985, 49.03131879866123, 48.2383431494236, 55.20047776401043, 55.04878990352154, 50.735895931720734, 49.60374288260937, 46.32449224591255, 47.030764147639275, 49.95591938495636, 57.62175343930721, 52.48587302863598, 53.39999757707119, 54.8277747631073, 57.311625480651855, 59.67166744172573, 58.56552019715309, 57.2368872910738, 58.81498821079731, 59.074863865971565, 59.84905332326889, 57.15742215514183, 21.34770669043064, 5.379514787346125, 3.3696050383150578, 10.971293784677982, 1.4467463619075716, 0.19747711048694327, 0.175157479243353, 25.729375071823597, 46.31603769958019, 57.453768253326416, 56.007820442318916, 29.89706363528967, 42.165117636322975, 51.094862669706345, 60.53955987095833, 42.369824051856995, 2.3031528387218714, 0.015198894052446121, 0.04658242774894461, 0.07837625686079264, 0.03223960753530264, 0.036895511802867986, 0.016183454063138925, 0.03756176003662404, 0.08737979209399782, 0.06023948124493472, 0.033175474309246056, 0.020335666413302533, 0.03101575592154404, 0.09028162661707029, 0.013352979822229827, 0.1089562292327173, 0.22542314138263464, 0.079942099400796, 0.13108259037835523, 0.23390627524349838, 0.118996797100408, 0.18747343478025869, 0.11107800717581995, 0.05893102294066921, 0.2077802873100154, 0.20685748604591936, 0.3126505186082795, 0.2109308823128231, 0.21527897712076083, 12.166286911815405, 57.349908426404, 53.69089096784592, 52.81803220510483, 34.179260954260826, 29.75433759391308, 53.586597964167595, 51.524581611156464, 41.94793649017811, 44.5032499730587, 2.20454219263047, 0.18979948887135834, 5.656304759904742, 7.73705885745585, 6.047800127416849, 16.254887469112873, 15.47215512022376, 31.883268356323242, 57.72802233695984, 60.39952598512173, 57.10332065820694, 52.11679883301258, 46.31101056933403, 45.38123086094856, 47.748180851340294, 56.34027220308781, 58.234512358903885, 54.92379941046238, 54.32041838765144, 53.36974740028381, 52.30576269328594, 53.82543034851551, 55.129900351166725, 51.70754559338093, 54.007896557450294, 54.604069367051125, 55.88815726339817, 50.90862326323986, 46.74002654850483, 49.85878899693489, 55.67648962140083, 52.00730010867119, 51.053068712353706, 49.24231767654419, 46.33940264582634, 42.35183581709862, 42.92857646942139, 39.66758005321026, 41.91207021474838, 41.17201432585716, 40.99506162106991, 42.534613609313965, 42.361042723059654, 40.249515026807785, 41.520425230264664, 39.06310848891735, 41.35921888053417, 40.77367030084133, 44.748496413230896, 52.22622536122799, 55.75745947659016, 55.601561442017555, 52.76755191385746, 55.06156861782074, 54.30721029639244, 51.08660191297531, 48.17302465438843, 50.66272705793381, 55.40296129882336, 56.32375068962574, 55.32680958509445, 50.81908106803894, 51.88004493713379, 39.335648864507675, 35.70752754807472, 51.779000759124756, 50.21984562277794, 54.14378486573696, 49.73569840192795, 51.610274612903595, 47.90760509669781, 49.06571455299854, 48.27213853597641, 51.9447972625494, 51.796837002038956, 54.53425191342831, 51.80428460240364, 50.580275282263756, 48.353188186883926, 46.462443843483925, 43.12808856368065, 41.30786843597889, 41.77594251930714, 42.97381304204464, 41.752136796712875, 43.584421277046204, 42.90098235011101, 41.78007669746876, 40.26966534554958, 41.76338039338589, 42.77424395084381, 44.782899767160416, 45.723657086491585, 50.9815489500761, 52.99846552312374, 52.58099712431431, 52.324381694197655, 53.549990728497505, 51.56062267720699, 51.213758289813995, 50.87746873497963, 50.124185755848885, 57.528783828020096, 57.48939134180546, 52.133111357688904, 51.88153065741062, 47.576574459671974, 48.5623137652874, 50.71899063885212, 59.60593096911907, 55.699531584978104, 54.741401597857475, 57.576950043439865, 60.10725326836109, 64.73319724202156, 60.806202962994576, 60.03884933888912, 60.85721142590046, 62.07946144044399, 61.726809963583946, 59.724211022257805, 21.647001430392265, 10.383071098476648, 12.780912481248379, 16.222465708851814, 2.291764849796891, 0.2732551231747493, 0.28218880004715174, 29.604846015572548, 54.327220022678375, 62.177906557917595, 65.05436360836029, 34.90484721958637, 50.23972995579243, 57.873831912875175, 68.3583091199398, 51.70998506247997, 4.070299314334989, 0.20202846470056102, 0.14563508215360343, 0.17473028419772163, 0.1904457510681823, 0.149277780437842, 0.10594370338367298, 0.1665553791099228, 0.20842175523284823, 0.14911131671397015, 0.14130404189927503, 0.138887683278881, 0.21448471583426, 0.18057901645079255, 0.10180153971305117], [0.030918287811800838, 0.04800652008270845, 0.019241503250668757, 0.030384698475245386, 0.008169819520844612, 0.01589315928868018, 0.03169937226630282, 0.03266263913246803, 0.023981925151019823, 0.09978724701795727, 0.04649460570362862, 0.02608013805001974, 0.06435578849050216, 0.06457187220803462, 7.152807433158159, 34.23699505627155, 37.27607198059559, 30.882016383111477, 19.078078977763653, 32.668587416410446, 49.02687303721905, 43.310900554060936, 31.10517840832472, 32.6104923337698, 0.30759943183511496, 0.01722277251246851, 2.7846456645056605, 2.992489286698401, 5.837950687855482, 14.855814892798662, 26.686011739075184, 47.49645955860615, 56.464593932032585, 57.04144477844238, 53.237107917666435, 48.26885171234608, 42.29267679154873, 41.57029755413532, 45.05374163389206, 51.145730540156364, 51.88540644943714, 52.26457290351391, 50.81468850374222, 51.42825298011303, 51.119910925626755, 49.42555144429207, 51.395912915468216, 51.818959414958954, 52.70293638110161, 51.076657846570015, 48.86551849544048, 46.63820721209049, 49.70856785774231, 47.168757542967796, 45.953069776296616, 45.802643448114395, 47.07016423344612, 47.82768778502941, 43.46954584121704, 38.628085032105446, 36.68821692466736, 37.310961708426476, 36.03532835841179, 37.100320011377335, 36.62550888955593, 37.23095320165157, 37.44165189564228, 36.892911940813065, 36.55546344816685, 37.69693739712238, 37.52162240445614, 36.473209261894226, 38.778458163142204, 47.85835973918438, 48.590154871344566, 47.94911406934261, 48.56373108923435, 51.05075463652611, 46.506327688694, 44.47534807026386, 44.22001697123051, 46.837616711854935, 49.85814303159714, 51.4668133109808, 51.239106729626656, 46.368965059518814, 49.38868962228298, 35.0388128310442, 35.723410695791245, 50.40267661213875, 45.885479003190994, 49.09981392323971, 44.83106978237629, 44.17806722223759, 43.62032935023308, 46.58452369272709, 45.945454984903336, 47.61680290102959, 49.456565380096436, 50.671325996518135, 50.63155733048916, 48.349798768758774, 43.493526354432106, 41.424837559461594, 36.891540214419365, 38.44066008925438, 36.30007155239582, 38.9258598536253, 43.14981959760189, 41.268426552414894, 39.81269046664238, 39.24819275736809, 37.71206438541412, 39.71424914896488, 39.070195108652115, 39.381037428975105, 41.940215304493904, 45.12409865856171, 48.548254519701004, 49.97817859053612, 49.644507095217705, 49.58741135895252, 48.924825713038445, 47.860833406448364, 46.93710297346115, 50.44395759701729, 56.19935296475887, 50.056340396404266, 48.844178840518, 44.01627570390701, 43.01591478288174, 41.69941462576389, 45.29472090303898, 49.67842407524586, 52.926763370633125, 55.76316297054291, 53.49917605519295, 55.33945530653, 53.9139162003994, 52.934849336743355, 54.080442264676094, 52.44817145168781, 56.89135663211346, 55.415204241871834, 54.76578488945961, 25.343403182923794, 3.471580403856933, 2.5398058025166392, 12.467534746974707, 2.0763418218120933, 0.2788669470464811, 0.030321461927087512, 15.88607830926776, 43.20171341300011, 36.6820764541626, 31.142526604235172, 16.483933478593826, 36.742675602436066, 48.84355187416077, 52.12649591267109, 42.90656045079231, 3.0472329491749406, 0.02875527243304532, 0.14184186147758737, 0.13386110222199932, 0.03127125324681401, 0.030203931710275356, 0.05493581193150021, 0.0570651486486895, 0.009326601393695455, 0.03035572688531829, 0.007017370398898493, 0.03944261457945686, 0.053963257087161765, 0.03805865388130769, 0.06420182253350504, 0.03710884957399685, 0.060430680750869215, 0.03414145001443103, 0.07180381930083968, 0.030609331734012812, 0.03649242171377409, 0.013296417964738794, 0.017874988589028362, 0.060675882632494904, 0.08011902740690857, 0.0536879945138935, 0.1006352249532938, 0.01742664975608932, 0.1310700926114805, 10.062438603490591, 46.46098092198372, 44.88590084016323, 38.4932454675436, 22.10437148809433, 31.503397040069103, 51.75610698759556, 46.935674250125885, 34.671030566096306, 35.817455649375916, 0.3800976416096091, 0.08649224284454249, 6.112898234277964, 5.918401395902038, 4.35898169875145, 12.400806527584791, 23.563913069665432, 49.65262345969677, 58.07404316961765, 56.60165257751942, 55.73981702327728, 50.177044719457626, 44.05822925269604, 43.19171614944935, 47.15475149452686, 54.137784987688065, 54.242815151810646, 54.65241797268391, 53.60882677137852, 53.2334791123867, 52.208677902817726, 51.686920300126076, 51.46333649754524, 52.70123787224293, 54.34086509048939, 52.080708369612694, 49.43736121058464, 47.424176037311554, 49.13134843111038, 48.38751934468746, 49.871286526322365, 47.90324293076992, 49.56395901739597, 49.73401129245758, 46.2879192084074, 40.392755940556526, 38.598397225141525, 38.392892852425575, 38.51087652146816, 38.63296777009964, 38.576290011405945, 39.05230566859245, 38.68989631533623, 38.27038362622261, 38.42220827937126, 38.78183238208294, 40.264915600419044, 38.30108217895031, 41.03471249341965, 49.122415110468864, 51.415987238287926, 50.91769717633724, 52.35641397535801, 52.14055135846138, 49.97058279812336, 46.00166156888008, 44.90114942193031, 47.957143038511276, 51.603457778692245, 51.698916256427765, 53.77584680914879, 49.029726684093475, 50.271978825330734, 37.42634631693363, 36.580895483493805, 51.24383747577667, 47.11633175611496, 51.55314087867737, 47.54224330186844, 45.82526743412018, 43.82141835987568, 46.04542002081871, 44.8016669601202, 47.9419856518507, 50.48785664141178, 52.52640925347805, 52.59459279477596, 50.62271520495415, 45.147961378097534, 43.33892025053501, 39.33796674013138, 39.670517295598984, 39.06070701777935, 40.93838766217232, 43.521557450294495, 41.29863113164902, 41.38823412358761, 39.328892827034, 39.58941824734211, 41.892539262771606, 41.005811244249344, 41.44956283271313, 43.55868525803089, 46.962926387786865, 49.40280966460705, 50.749506801366806, 52.03889921307564, 51.819088608026505, 49.06872779130936, 50.22381640970707, 47.2098333388567, 50.23227855563164, 55.67125350236893, 51.97453446686268, 51.181053444743156, 46.496649608016014, 44.86910954117775, 43.64294193685055, 48.26785996556282, 51.44827790558338, 55.3088403493166, 57.307388707995415, 54.28389094769955, 54.87969517707825, 56.658934503793716, 55.84445580840111, 55.59603273868561, 53.39203700423241, 57.8103981167078, 59.207222163677216, 56.79181717336178, 27.720696218311787, 6.818873751908541, 4.492916436865926, 11.264131721109152, 2.5698923505842686, 0.17330199130810797, 0.06549426529090852, 17.362486235797405, 46.94414399564266, 39.69901196658611, 28.431653268635273, 18.86876530945301, 41.72859326004982, 55.471331030130386, 56.52735896408558, 53.54419603943825, 5.0258853379637, 0.17613003408769146, 0.04434428847162053, 0.11583181185415015, 0.013551867978094378, 0.053093463720870204, 0.07873388298321515, 0.06456192742916755, 0.039676428204984404, 0.059603876288747415, 0.029292982544575352, 0.07746408315142617, 0.09229865041561425, 0.016020059119910002, 0.01469867538617109, 0.1062319238553755, 0.2247325432836078, 0.19808120385278016, 0.13542891887482256, 0.11900929486728273, 0.13005562126636505, 0.1358822820475325, 0.08374684563023038, 0.06694545343634672, 0.12361967950710095, 0.17024579748976976, 0.15278799051884562, 0.21541627444094047, 0.22500172024592757, 14.285295456647873, 58.79613742232323, 55.13740114867687, 45.154934003949165, 28.549298755824566, 44.75523725152016, 56.67900122702122, 52.543116956949234, 43.19567933678627, 40.546362698078156, 0.4969222837826237, 0.10503157420316711, 6.088791852816939, 9.65130826458335, 11.751418523490429, 23.91853094100952, 31.76741447299719, 53.60781602561474, 59.384566247463226, 61.59941039979458, 57.69530229270458, 53.8101589679718, 46.679465398192406, 46.031592562794685, 48.13370816409588, 55.59805043041706, 56.56427018344402, 55.62768504023552, 56.0025729238987, 56.35489761829376, 54.598761051893234, 53.64162661135197, 52.969758063554764, 54.93769906461239, 55.263569578528404, 53.22774142026901, 51.53151623904705, 49.10068787634373, 51.48571729660034, 51.91285617649555, 51.078656539320946, 51.34206220507622, 52.37699367105961, 52.37455800175667, 48.145384937524796, 42.91781924664974, 42.25885100662708, 40.38641408085823, 39.714526534080505, 41.93569354712963, 40.51738925278187, 40.193597227334976, 39.92732651531696, 39.89388071000576, 40.119995176792145, 40.631136149168015, 41.63068771362305, 40.76736643910408, 43.51076602935791, 51.948163881897926, 53.127191215753555, 53.429913371801376, 53.5330056399107, 54.92651246488094, 51.85497008264065, 48.40686410665512, 47.64954574406147, 51.14828780293465, 53.98105479776859, 54.69453491270542, 57.04047583043575, 51.73622265458107, 50.38812719285488, 39.71243664622307, 39.51728671789169, 51.80263929069042, 49.32384230196476, 53.033404648303986, 49.36982363462448, 46.00413143634796, 45.820137709379196, 47.891680151224136, 45.955881625413895, 49.57057446241379, 53.057293966412544, 53.22893835604191, 55.26846371591091, 51.75520643591881, 47.11385428905487, 47.13074438273907, 40.40420472621918, 41.131025925278664, 40.38854576647282, 41.620644852519035, 45.15034005045891, 44.03366357088089, 45.13299398124218, 43.17482225596905, 41.437547877430916, 44.32958409190178, 43.24945405125618, 43.612798154354095, 46.8841490149498, 49.79408986866474, 51.71235233545303, 53.01528722047806, 53.44149515032768, 54.44110371172428, 52.08687923848629, 51.18783988058567, 50.13916835188866, 52.95604079961777, 58.98290120065212, 54.55855920910835, 54.463188126683235, 48.72992277145386, 46.33176885545254, 45.69793626666069, 50.705687552690506, 52.61299140751362, 58.409017994999886, 57.54470497369766, 56.34383641183376, 59.01944763958454, 58.5198238492012, 58.58286626636982, 57.65966780483723, 56.05233125388622, 61.29096195101738, 59.96124230325222, 59.900198578834534, 29.662321731448174, 9.262048602104187, 7.018599109724164, 21.789117604494095, 4.0738060511648655, 0.6554535473696887, 0.18488819303456694, 19.790875129401684, 55.41301175951958, 48.643173426389694, 43.262175768613815, 26.54662761837244, 47.84558482468128, 61.48466035723686, 65.21157637238503, 64.07764121890068, 8.11913263052702, 0.35419033491052687, 0.24373547203140333, 0.3355209867004305, 0.08718122306163423, 0.09248840273357928, 0.20410680474014953, 0.20742889522807673, 0.12603932584170252, 0.22485504217911512, 0.1850702121737413, 0.1766786741791293, 0.213155648089014, 0.061997142984182574, 0.13048308348516002], [0.09628425803384744, 0.001966585355148709, 0.01599180184712168, 0.05555255520448554, 0.04491754931223113, 0.017066318505385425, 0.04956050310283899, 0.025040867840289138, 0.020184667191642802, 0.02412837500742171, 0.06791593026719056, 0.02608277452964103, 0.08892380064935423, 0.03395414307306055, 10.730572901666164, 33.21171507239342, 38.74002702534199, 36.528055518865585, 20.545286647975445, 23.11884105205536, 47.708161398768425, 38.62240053713322, 32.13445007801056, 27.608615532517433, 0.07250053269672208, 0.017598933773115277, 1.5642241830937564, 2.452174904756248, 8.10471335425973, 20.836174339056015, 27.276302464306355, 53.67978796362877, 56.170257925987244, 53.023661971092224, 50.28922989964485, 43.56424055993557, 38.15214917063713, 41.4335922896862, 45.181190595030785, 51.76459573209286, 53.04419606924057, 51.09701335430145, 51.639335453510284, 50.9721976518631, 50.084508284926414, 49.504970982670784, 47.874793857336044, 49.81652766466141, 47.39833742380142, 45.816714093089104, 46.64042629301548, 47.895168364048004, 48.260446563363075, 49.237237349152565, 44.77835141122341, 47.993716076016426, 47.06778936088085, 47.27198660373688, 42.09385626018047, 38.18945176899433, 35.97615033388138, 36.61005511879921, 37.20329448580742, 37.72689498960972, 37.33208857476711, 37.23360925912857, 35.561030209064484, 36.66511796414852, 36.9112915545702, 36.46087132394314, 37.64777563512325, 36.79712288081646, 38.00785571336746, 46.271507889032364, 51.32883511483669, 49.95493143796921, 48.63447569310665, 50.857854187488556, 50.35113237798214, 44.39993731677532, 42.337419390678406, 45.588460341095924, 48.917210921645164, 50.10731466114521, 51.717789843678474, 49.54237997531891, 55.802221074700356, 44.689052402973175, 35.67044533789158, 48.87076981365681, 45.09864762425423, 46.280976980924606, 43.49329076707363, 45.835443288087845, 47.896540090441704, 51.68663911521435, 51.200174018740654, 52.40213692188263, 50.75594745576382, 51.98116131126881, 49.709859788417816, 49.12209212779999, 43.77519004046917, 37.942164838314056, 37.93487682938576, 38.00353914499283, 38.41810069978237, 39.353751093149185, 40.37788353860378, 39.18719843029976, 39.94293987751007, 38.95106390118599, 37.7799591422081, 41.10169529914856, 37.00855873525143, 38.76702077686787, 40.21594762802124, 43.04048426449299, 44.88053172826767, 46.90092511475086, 49.50461380183697, 48.493005484342575, 49.40125174820423, 49.28231433033943, 49.99246962368488, 53.404777720570564, 50.76512776315212, 49.5277089625597, 46.217459589242935, 46.183185428380966, 45.88537260890007, 43.720678165555, 44.78607639670372, 48.96968990564346, 51.47824689745903, 49.89655137062073, 51.126248985528946, 48.31503823399544, 47.823754996061325, 45.794523283839226, 43.55928562581539, 51.24232895672321, 56.803391352295876, 58.866384252905846, 56.185213923454285, 38.415676429867744, 10.134411491453648, 1.395733980461955, 8.574566692113876, 2.127044163644314, 0.41853620088659227, 0.057512500425218605, 10.806650519371033, 45.03995977342129, 38.05194094777107, 40.34476451575756, 37.054194286465645, 35.915410593152046, 39.784473180770874, 50.950618609786034, 45.60832567512989, 6.4248548448085785, 0.2884245029417798, 0.04480810108361766, 0.07576742224046029, 0.05818434074171819, 0.08548353798687458, 0.08226551144616678, 0.03894852605299093, 0.08795205474598333, 0.03945267068047542, 0.0489968456531642, 0.06742203098838218, 0.023190419087768532, 0.014732648123754188, 0.01952874594280729, 0.06266669748583809, 0.009136484495684272, 0.02923924919741694, 0.0550259791634744, 0.08324047827045433, 0.0400937044469174, 0.008429718709521694, 0.03759636638278607, 0.02116191612003604, 0.019719095689652022, 0.08513224980561063, 0.014395198213605909, 0.017130636733782012, 0.09165255149127916, 14.558911174535751, 44.0106900036335, 45.95977641642094, 41.21225416660309, 24.2416675016284, 28.680807799100876, 50.44805757701397, 40.078414008021355, 37.3323355615139, 29.75732423365116, 0.04376962868263945, 0.06529739577672444, 2.6492639165371656, 6.312838755548, 9.401842150837183, 20.06672702729702, 29.192676432430744, 56.14144027233124, 57.610479444265366, 56.296616345644, 53.487373888492584, 45.615336298942566, 40.84233641624451, 43.87954384088516, 47.41741240024567, 53.79057101905346, 54.58565555512905, 51.54543489217758, 53.49804751574993, 53.11459869146347, 52.62656807899475, 52.55789816379547, 48.35098810493946, 49.30788695812225, 49.580149948596954, 46.50770701467991, 48.519657254219055, 48.03842447698116, 48.63560043275356, 49.87583868205547, 47.32237569987774, 49.75347764790058, 49.86279018223286, 48.57939384877682, 44.2899864166975, 40.51452420651913, 37.89005063474178, 37.72256322205067, 40.40017694234848, 40.699635073542595, 38.20442296564579, 39.538751766085625, 38.92490230500698, 37.73276947438717, 39.520246759057045, 38.05552415549755, 40.57491056621075, 39.61810290813446, 40.01796305179596, 49.00546498596668, 52.572041004896164, 53.09662565588951, 51.05536378920078, 52.42788814008236, 51.184363067150116, 46.31113976240158, 45.14923430979252, 46.54193937778473, 51.63236282765865, 51.97690933942795, 53.97247105836868, 50.24902805685997, 58.35018575191498, 44.00067754089832, 36.69510215520859, 50.33931881189346, 47.31574885547161, 48.62486980855465, 46.01194381713867, 47.32666566967964, 47.8113866597414, 55.93101516366005, 52.46834076941013, 52.312883511185646, 54.169308096170425, 52.469260320067406, 52.85147421061993, 49.86686736345291, 46.36561743915081, 39.60590556263924, 39.46709901094437, 40.034955739974976, 39.81522873044014, 40.602033510804176, 42.69059143960476, 40.28774097561836, 41.354659125208855, 39.36922766268253, 40.195345133543015, 41.90163977444172, 39.89484965801239, 40.74530862271786, 42.22090244293213, 45.62064081430435, 46.82265691459179, 50.50457954406738, 50.869283974170685, 50.112110003829, 51.16225205361843, 51.32522530853748, 51.25774472951889, 54.138316959142685, 53.60196053981781, 51.21366709470749, 49.44920517504215, 49.852420538663864, 47.676672488451004, 45.640494748950005, 45.351337864995, 50.423666685819626, 54.20965813100338, 52.51207262277603, 54.57372799515724, 50.359909906983376, 50.96935160458088, 47.625360041856766, 46.27154588699341, 53.650757521390915, 59.2150991410017, 59.45173904299736, 57.327086851000786, 36.309601441025734, 9.053963217884302, 3.0739766266196966, 8.66654360666871, 2.2200610348954797, 0.6091242365073413, 0.09308672219049186, 12.033606581389904, 50.263197496533394, 43.98489698767662, 43.1600296497345, 33.21767695248127, 39.82372507452965, 45.81197954714298, 57.14378848671913, 56.11305579543114, 8.69684698060155, 0.21044918394181877, 0.0607212093018461, 0.05064865115855355, 0.05123097733303439, 0.0282266777503537, 0.03559932119969744, 0.03662106188130565, 0.03601536918722559, 0.05592655681539327, 0.03229389192711096, 0.019884394241671544, 0.030371295288205147, 0.04802758223377168, 0.07912451983429492, 0.1694294053595513, 0.14473055256530643, 0.1596095596323721, 0.15462387091247365, 0.21320719766663387, 0.10853030325961299, 0.07244340216857381, 0.1312404897180386, 0.14180444239173084, 0.05149458076630253, 0.23271014099009335, 0.10674968318198808, 0.14517475763568655, 0.2335139611386694, 20.05571521818638, 56.15137293934822, 55.50441965460777, 50.100836008787155, 32.534667402505875, 34.32771138846874, 56.77291318774223, 47.399617955088615, 45.24608351290226, 33.79222892224789, 0.13174730236642063, 0.16757494158810005, 3.2733768643811345, 8.549352195113897, 13.161618802696466, 27.03656192868948, 33.37510630488396, 58.78100283443928, 59.89576801657677, 58.434674218297005, 56.133350506424904, 48.20392459630966, 42.23362796008587, 46.52870088815689, 50.1564422249794, 56.49163328111172, 56.87956586480141, 52.265503853559494, 54.564992263913155, 54.6952910721302, 51.96749344468117, 53.07615615427494, 50.29262311756611, 50.335340425372124, 49.203844740986824, 47.585492581129074, 49.12713825702667, 50.72731599211693, 49.75369043648243, 51.918107494711876, 49.378779754042625, 53.4602015465498, 53.52538324892521, 50.712075009942055, 45.3473024815321, 42.69888259470463, 40.38687385618687, 39.7440205514431, 41.98336198925972, 42.26903825998306, 41.38416454195976, 40.71761190891266, 39.80742394924164, 40.157837346196175, 41.71338647603989, 40.004796758294106, 43.21168787777424, 40.95210112631321, 42.04140767455101, 52.94472120702267, 55.14527812600136, 55.10233663022518, 52.316037341952324, 54.779673144221306, 53.08678038418293, 48.566375747323036, 46.69311046600342, 49.29173402488232, 53.06898593902588, 53.72291564941406, 55.64641423523426, 53.944971933960915, 58.74820299446583, 48.765610456466675, 38.67041476070881, 50.577075853943825, 48.28892223536968, 48.92791874706745, 47.89892636239529, 47.42735266685486, 50.194493383169174, 56.23228199779987, 55.4701416939497, 53.490881100296974, 56.08070433139801, 54.67250369489193, 53.505654707551, 52.03538440167904, 48.4208207577467, 41.60787373781204, 41.72353953123093, 41.823971942067146, 41.84549018740654, 43.161940947175026, 43.56946147978306, 41.71695828437805, 44.788633659482, 41.05464242398739, 42.03775607049465, 45.46587511897087, 41.76097132265568, 42.83869229257107, 44.10993307828903, 47.35613688826561, 49.961155503988266, 51.52358986437321, 53.13192576169968, 52.970214039087296, 52.473478093743324, 53.06423619389534, 53.24687339365482, 56.901251301169395, 57.06566847860813, 52.07327976822853, 52.238973677158356, 52.17131070792675, 49.59594190120697, 48.38642880320549, 49.846709445118904, 54.1124327480793, 55.93924932181835, 55.27969591319561, 56.68587885797024, 52.54717133939266, 52.578987032175064, 50.63238948583603, 47.02028430998325, 56.75754301249981, 60.87528705596924, 63.15671123564243, 59.031052216887474, 41.00735016167164, 14.116995837539434, 6.358269592747092, 18.225999400019646, 5.653628753498197, 1.1616442166268826, 0.22391100064851344, 13.319582026451826, 58.41521926224232, 52.97808341681957, 50.38180813193321, 50.64984194934368, 47.420634627342224, 55.2462425082922, 62.53498859703541, 66.62133112549782, 11.977784726768732, 0.446253219852224, 0.16784579580416903, 0.1891269546467811, 0.19969587970990688, 0.20944364805473015, 0.1503724037320353, 0.17452113213948905, 0.16224753839196637, 0.1521021718508564, 0.20311436033807695, 0.08543638192350045, 0.15727166086435318, 0.14551801577908918, 0.2223770259297453], [0.03560225639375858, 0.05267356398690026, 0.015963290388754103, 0.013066905084997416, 0.0518845311307814, 0.017934757452167105, 0.017422682976757642, 0.03754708777705673, 0.048594831678201444, 0.043868545835721307, 0.044467510961112566, 0.05304049664118793, 0.05765767193224747, 0.10968391987262294, 11.366580873727798, 34.13937449455261, 39.602945521473885, 33.950319439172745, 19.48089726269245, 25.527974478900433, 49.30087253451347, 30.732874386012554, 40.56322619318962, 20.227291211485863, 0.1933518232544884, 0.48981387459207326, 3.1399308750405908, 4.895701948553324, 4.180234065279365, 8.232378903776407, 35.93216389417648, 59.103882908821106, 53.06775100529194, 49.255605563521385, 45.55864714086056, 41.50499805808067, 40.74627377092838, 40.98565712571144, 46.6204621642828, 50.17878122627735, 53.728147968649864, 49.49231006205082, 46.77892126142979, 49.235231056809425, 48.589793890714645, 46.8127166479826, 48.70992824435234, 48.50456826388836, 47.027051746845245, 47.51366503536701, 45.463640838861465, 48.34145441651344, 48.63450989127159, 47.34777353703976, 46.14670738577843, 46.5088127553463, 47.46318854391575, 46.22845999896526, 40.80251455307007, 36.215833872556686, 36.42023250460625, 35.28306372463703, 38.44525404274464, 38.24289210140705, 38.33600610494614, 38.90267349779606, 36.456486359238625, 35.257650688290596, 36.55710496008396, 35.9164023399353, 35.12030705809593, 36.88798360526562, 36.00185975432396, 43.99927541613579, 50.33819407224655, 48.72611157596111, 50.20856782793999, 52.445488795638084, 49.7176493704319, 46.06545254588127, 41.354282945394516, 42.28842481970787, 47.190306186676025, 46.4963798224926, 51.772833690047264, 48.88813108205795, 54.50883127748966, 44.524946808815, 36.53131194412708, 46.75055958330631, 45.17273224890232, 49.58785593509674, 46.45912282168865, 52.310877218842506, 50.09477533400059, 52.51415491104126, 48.93758922815323, 48.73789854347706, 49.2412993311882, 49.81505714356899, 45.96143692731857, 45.58418557047844, 38.22637818753719, 37.391353994607925, 38.25160503387451, 37.89727784693241, 38.49646009504795, 37.86052241921425, 38.69685374200344, 38.70433174073696, 38.066589161753654, 38.901392966508865, 38.54571305215359, 38.521014377474785, 37.62774311006069, 38.5662167519331, 39.012183621525764, 41.73087693750858, 42.53883898258209, 47.00296863913536, 47.491527423262596, 48.63462008535862, 50.563605576753616, 48.93777921795845, 50.73589213192463, 49.842233285307884, 47.81614400446415, 48.799869418144226, 50.76359644532204, 50.60537673532963, 49.53334406018257, 46.44849859178066, 44.28760014474392, 41.712254136800766, 45.715837106108665, 43.03022101521492, 42.317079082131386, 43.43698538839817, 44.591732025146484, 46.86963379383087, 45.95690757036209, 48.334998562932014, 54.16374899446964, 57.89115518331528, 57.567328959703445, 37.87889443337917, 14.070086404681206, 4.860333921387792, 6.06756049208343, 2.3364067543298006, 0.2769144158810377, 0.026590813577058725, 5.45263378880918, 47.188334092497826, 33.28241407871246, 31.5203308314085, 26.44471898674965, 19.074186086654663, 37.64106139540672, 49.2591317743063, 52.48304218053818, 9.189864825457335, 0.09328437838121317, 0.05432198158814572, 0.08102849969873205, 0.046421314909821376, 0.05689746409188956, 0.01131623344917898, 0.047853188661974855, 0.05455593993247021, 0.04466040998522658, 0.09431119164219126, 0.019975262803200167, 0.08153111921274103, 0.0265353120630607, 0.032026106491684914, 0.055664033206994645, 0.06805843746406026, 0.030444235417235177, 0.05328272993210703, 0.022516202043334488, 0.03751032920263242, 0.03231312468415126, 0.06476629263488576, 0.03958362263801973, 0.03713726640853565, 0.05167510447790846, 0.055251892626984045, 0.049600760903558694, 0.10561265356955118, 15.367010962218046, 45.74684724211693, 48.100604340434074, 41.64665065705776, 25.8610912039876, 29.37909632921219, 55.02373404800892, 33.66913452744484, 45.64682140946388, 23.71963821351528, 0.1884285343112424, 0.8718174998648465, 4.5913031324744225, 9.033419620245695, 9.273077510297298, 10.332510061562061, 34.80878837406635, 59.90477733314037, 55.74088856577873, 51.97538182139397, 46.77838549017906, 43.74176703393459, 42.215453535318375, 43.68313618004322, 49.087950959801674, 53.37486192584038, 54.53645199537277, 50.65129727125168, 46.97879433631897, 49.35268275439739, 49.29348573088646, 48.69314454495907, 47.37206943333149, 48.97888921201229, 45.530536249279976, 47.790062204003334, 47.51141935586929, 49.50354985892773, 49.16828244924545, 49.112288653850555, 48.40492241084576, 48.21119360625744, 49.62771579623222, 47.29746803641319, 42.991808876395226, 37.89624810218811, 37.83213414251804, 38.222787380218506, 40.535780265927315, 40.97261242568493, 38.98550525307655, 38.29729378223419, 37.807036489248276, 37.73776240646839, 38.28153222799301, 37.41478353738785, 37.864523604512215, 39.69778083264828, 39.392888993024826, 45.47818265855312, 51.818153858184814, 50.51219813525677, 50.22088296711445, 53.55663277208805, 51.19061753153801, 49.342807084321976, 42.863634154200554, 44.055500999093056, 49.15326565504074, 48.77273887395859, 53.47057119011879, 51.422743275761604, 54.54927250742912, 47.41674363613129, 38.624783009290695, 48.243708461523056, 48.091583624482155, 50.89240953326225, 47.71144822239876, 54.29729662835598, 51.16603285074234, 54.275322407484055, 51.25848188996315, 50.94795495271683, 51.47788591682911, 50.7650251686573, 48.806249275803566, 45.410029515624046, 40.759687051177025, 39.57504361867905, 39.31335926055908, 39.59520533680916, 40.46855807304382, 39.1301254928112, 39.52304720878601, 39.46539290249348, 38.909874111413956, 40.03659725189209, 39.11109231412411, 41.149618327617645, 39.709594398736954, 40.172705948352814, 39.632625728845596, 43.19623790681362, 43.56243185698986, 49.610643312335014, 49.6370404958725, 51.87307611107826, 52.7197390794754, 50.89932136237621, 52.00018309056759, 53.2161558419466, 50.83168499171734, 51.050435453653336, 52.33337961137295, 52.98568680882454, 50.24558924138546, 49.05149571597576, 45.87985910475254, 44.17122378945351, 47.797164022922516, 45.621457770466805, 45.33446677029133, 45.58005899190903, 47.16212309896946, 47.94080011546612, 48.98939564824104, 50.86181357502937, 57.231001406908035, 58.64623546600342, 60.2733613550663, 40.03220848739147, 12.000193074345589, 4.107053792104125, 5.0802813190966845, 2.7531973645091057, 0.5045724310912192, 0.11320040110149421, 6.913809757679701, 51.739467680454254, 37.13590130209923, 41.6438540071249, 34.96627852320671, 24.088830202817917, 42.944945991039276, 53.91608588397503, 60.81770494580269, 12.495386302471161, 0.236982477363199, 0.03586552957131062, 0.019444321078481153, 0.004573028636514209, 0.01664428138610674, 0.012162487746536499, 0.0225002421575482, 0.05315962989698164, 0.044038501364411786, 0.032205784154939465, 0.046121657942421734, 0.01792430801287992, 0.052682781461044215, 0.04049809700518381, 0.16309645143337548, 0.1001702768553514, 0.15588572976412252, 0.1181016927876044, 0.09550924805807881, 0.13983322394778952, 0.18868214101530612, 0.24895196867873892, 0.14841163472738117, 0.1647429505828768, 0.21665404317900538, 0.15719208779046312, 0.15423673699842766, 0.1917056061211042, 22.51766011118889, 55.88240057229996, 55.32661959528923, 46.80957421660423, 31.931951344013214, 37.206231728196144, 56.538716554641724, 40.66084675490856, 53.866756930947304, 26.74785152077675, 0.20909878687234595, 1.0084261070005596, 7.715648906305432, 10.045140031725168, 7.133840750902891, 12.274406310170889, 39.56673726439476, 62.76530183851719, 58.53999696671963, 54.8179142922163, 50.745680406689644, 45.324902683496475, 44.86822798848152, 44.330309852957726, 51.33307188749313, 54.262840077281, 56.79176017642021, 52.80421994626522, 47.26765103638172, 50.241417065262794, 50.64112141728401, 48.671352714300156, 48.0511461943388, 50.05524605512619, 47.75610722601414, 48.68585653603077, 48.643861189484596, 50.51159776747227, 49.85727667808533, 50.35894475877285, 50.92871278524399, 50.72670802474022, 51.24072544276714, 50.16968831419945, 45.155405178666115, 41.163005009293556, 39.33345638215542, 39.46879372000694, 42.87343382835388, 42.1960935741663, 41.92701481282711, 40.03512293100357, 40.34170188009739, 39.139036014676094, 41.1907397210598, 38.6692900210619, 39.63916897773743, 40.70716626942158, 40.64165398478508, 48.487191796302795, 55.601500645279884, 54.151616245508194, 52.09706649184227, 56.07041448354721, 54.235508143901825, 51.99415661394596, 45.02002224326134, 46.290871649980545, 50.91159850358963, 51.1526233702898, 57.4581304192543, 53.55165883898735, 57.667993158102036, 47.41025358438492, 42.46128134429455, 48.68389204144478, 48.769144266843796, 52.80129790306091, 49.405910298228264, 56.467542573809624, 54.72734235227108, 57.9016388207674, 53.89137201011181, 53.806860744953156, 54.45711225271225, 52.06898979842663, 49.47187475860119, 49.982935935258865, 41.87085002660751, 41.09440729022026, 42.82560579478741, 41.1090213060379, 42.990950122475624, 42.20058873295784, 42.07854688167572, 43.10388386249542, 39.99842070043087, 41.336651891469955, 41.30666010081768, 44.04828138649464, 42.05550491809845, 43.30833949148655, 41.82551085948944, 46.015325635671616, 46.34894013404846, 52.71893732249737, 52.0861990749836, 52.82456785440445, 54.96406964957714, 53.07447284460068, 53.99034149944782, 56.099076345562935, 51.78969718515873, 53.89118582010269, 55.62632471323013, 56.120480597019196, 52.749480083584785, 51.65890820324421, 50.995425805449486, 46.153642013669014, 49.55332338809967, 46.33566364645958, 47.05328933894634, 47.35324144363403, 49.66433443129063, 49.52321380376816, 52.38995477557182, 51.49413004517555, 60.082045421004295, 61.06864348053932, 61.655282601714134, 39.532337710261345, 17.985158823430538, 11.261550709605217, 14.414758309721947, 6.3926425483077765, 0.611510924063623, 0.27359300816897303, 7.412326382473111, 59.5315233618021, 45.231081917881966, 42.691214606165886, 37.87803567945957, 27.52359889447689, 50.710395500063896, 62.13911823928356, 70.83373188972473, 17.884663715958595, 0.4945476190187037, 0.1538009033538401, 0.14115945668891072, 0.10814265726367012, 0.22994455735897645, 0.12785767670720816, 0.20993551384890452, 0.15118293289560825, 0.25578769796993583, 0.21525410033063963, 0.10957686507026665, 0.1530844488297589, 0.18296760390512645, 0.10410933697130531], [0.03198903250449803, 0.039278945041587576, 0.03567691645002924, 0.08373372445930727, 0.05835772128193639, 0.056716417166171595, 0.02662578543095151, 0.016565960686421022, 0.03289863467216492, 0.02029275357926963, 0.026653872009774204, 0.035582522687036544, 0.012236452039360302, 0.9347187902312726, 19.78576820343733, 38.439387157559395, 41.177178248763084, 29.78281706571579, 20.950135923922062, 27.42448501288891, 31.184844933450222, 28.380188830196857, 45.59667930006981, 11.920612044632435, 0.16106476279674098, 0.43443172762636095, 1.5458228392526507, 8.164537344127893, 1.9791792542673647, 8.189559951424599, 43.840656727552414, 55.70311859250069, 53.450956642627716, 45.272792279720306, 45.63692294061184, 42.548840045928955, 42.22572818398476, 40.67253492772579, 44.16784197092056, 51.37712672352791, 51.115674152970314, 51.76152929663658, 45.26524968445301, 45.19785650074482, 46.421660631895065, 43.37352879345417, 47.75068871676922, 45.23876130580902, 46.97457656264305, 45.433147475123405, 47.549451515078545, 47.04824320971966, 49.09324027597904, 47.83433362841606, 47.67187334597111, 46.23488925397396, 44.706246480345726, 41.42999388277531, 37.91636802256107, 34.98120792210102, 34.81604218482971, 35.71274086833, 36.40028357505798, 36.87812693417072, 37.287790551781654, 38.04328501224518, 35.54991200566292, 35.9574743360281, 37.41123452782631, 35.881991386413574, 34.86110396683216, 34.82599765062332, 38.32367196679115, 44.013232067227364, 49.367802143096924, 49.35187339782715, 47.79553771018982, 50.93979299068451, 50.14937840402126, 45.9166145324707, 44.38332840800285, 46.13995514810085, 46.789150312542915, 46.53148613870144, 48.84685389697552, 49.85055483877659, 53.60637970268726, 49.09384064376354, 35.4244389384985, 47.255373895168304, 48.664946258068085, 50.294454619288445, 53.07684391736984, 52.42572605609894, 48.39165352284908, 49.23943743109703, 45.5718020349741, 43.68643440306187, 41.42818138003349, 40.77129542827606, 39.35141421854496, 37.833190485835075, 38.299018889665604, 38.446306586265564, 37.77454063296318, 37.51180753111839, 37.764349579811096, 37.98690743744373, 38.96827317774296, 38.17628547549248, 38.35010714828968, 39.59644787013531, 38.76955904066563, 39.00970235466957, 36.69574052095413, 38.25593680143356, 36.46112971007824, 38.180400654673576, 40.58318272233009, 44.06243182718754, 46.6767143458128, 48.65974433720112, 50.21747075021267, 51.11047603189945, 49.25203375518322, 51.841271817684174, 52.20838911831379, 52.34040543437004, 54.39632311463356, 54.73029099404812, 51.35198347270489, 48.995931297540665, 44.05216097831726, 40.67822702229023, 40.27904324233532, 39.559589847922325, 42.26828970015049, 47.122981399297714, 50.843525156378746, 51.99161075055599, 48.226521983742714, 49.1397687792778, 54.51711483299732, 56.456241980195045, 58.25291857123375, 55.233429595828056, 18.207564689218998, 4.2246517818421125, 2.95231475494802, 1.9827594934031367, 0.8831104938872159, 0.12776866351487115, 2.96314203646034, 42.09452882409096, 45.056549683213234, 33.43578144907951, 34.810239896178246, 27.667852453887463, 43.78737598657608, 47.06546388566494, 48.811238408088684, 12.095452062785625, 0.09238873972208239, 0.11869514375575818, 0.013145829707355006, 0.03260930097894743, 0.020926276811223943, 0.06597165920538828, 0.042825030541280285, 0.06678361329250038, 0.009915611535689095, 0.06100515129219275, 0.02669298690307187, 0.06194568988576066, 0.029659013489435893, 0.04649158145184629, 0.025186987440974917, 0.03986424722825177, 0.042167517385678366, 0.0975995218323078, 0.019242868802393787, 0.041015303431777284, 0.0479600319522433, 0.014673672430944862, 0.04691896574513521, 0.03073054671403952, 0.02695492235943675, 0.014082177949603647, 0.016584647964918986, 0.8644951740279794, 22.98664804548025, 47.0084897428751, 48.1910964846611, 34.93510499596596, 25.095035210251808, 30.085885003209114, 38.56394827365875, 31.966005116701126, 50.8770127594471, 15.353189203888178, 0.16812754474813119, 0.902344883652404, 5.559244668111205, 12.082856688648462, 6.509873857721686, 9.337735790759325, 43.32958795130253, 57.97213263809681, 53.25932152569294, 48.209791481494904, 47.807795852422714, 44.4514549523592, 43.703978061676025, 42.88765646517277, 45.534358844161034, 53.129668682813644, 53.28589729964733, 52.67922945320606, 46.32618695497513, 47.680567279458046, 48.0212228000164, 45.30447497963905, 48.967075645923615, 44.5501546561718, 47.410002797842026, 46.83663636445999, 47.62070149183273, 48.35437752306461, 50.19584611058235, 50.47241806983948, 49.8629117757082, 49.41696010529995, 45.634114891290665, 43.25265347957611, 40.6428737193346, 36.21014177799225, 37.21095487475395, 37.94948324561119, 39.37137454748154, 38.97723309695721, 39.39616061747074, 39.31235231459141, 37.586146742105484, 38.01890172064304, 39.56197611987591, 36.893751695752144, 36.54162839055061, 37.053191140294075, 39.519304409623146, 46.76516979932785, 51.19108870625496, 50.35578332841396, 49.64734934270382, 52.65538193285465, 51.908296421170235, 47.82315082848072, 46.30905747413635, 48.49973112344742, 47.65410549938679, 49.028765335679054, 49.83258180320263, 49.52167108654976, 56.30841851234436, 50.35656228661537, 38.41930143535137, 49.907954558730125, 50.07562056183815, 52.28431284427643, 52.38639056682587, 53.213150203228, 49.3372555822134, 51.21808245778084, 47.39232614636421, 46.65977105498314, 42.11279824376106, 42.453438565135, 40.928618386387825, 40.17442345619202, 39.27914969623089, 39.6449788659811, 39.771242290735245, 39.52997803688049, 38.03165763616562, 39.89508144557476, 39.92414988577366, 40.58842644095421, 39.974413588643074, 40.4133128374815, 40.057404935359955, 40.20754247903824, 38.84109020233154, 40.409604236483574, 38.78610335290432, 41.00983142852783, 42.871473133563995, 46.52457430958748, 48.88118125498295, 50.420303866267204, 51.32456034421921, 51.34351372718811, 51.07336722314358, 53.60895976424217, 53.68104949593544, 53.68782453238964, 55.73165886104107, 54.1534211486578, 53.544777408242226, 51.85249261558056, 46.489695981144905, 41.96707226336002, 43.297179490327835, 41.532569378614426, 43.670824840664864, 48.87060262262821, 52.70702116191387, 54.58953134715557, 51.68626293540001, 50.63894033432007, 55.07836751639843, 57.80652992427349, 60.42576737701893, 53.3985498547554, 19.899359308183193, 5.8372581750154495, 4.7461410239338875, 3.5670987283810973, 0.33132188546005636, 0.09198127838317305, 3.3435412868857384, 48.90471339225769, 48.28976958990097, 37.81245119869709, 39.097755029797554, 29.933076202869415, 47.82627426087856, 51.037554144859314, 55.54831109941006, 16.528651379048824, 0.16192133480217308, 0.04248773926519789, 0.03567112027667463, 0.04783068303368054, 0.05820952923386358, 0.016288493934553117, 0.05560204903304111, 0.11022114573279396, 0.014126405312708812, 0.024409732468484435, 0.044547436555149034, 0.05328767634637188, 0.03658995105070062, 0.010663866160030011, 0.08788915773038752, 0.10547758269240148, 0.10789394873427227, 0.20894856133963913, 0.12606196134584025, 0.2424279265687801, 0.07525290609919466, 0.12618397042388096, 0.0997032507439144, 0.0847712840186432, 0.12598264060216025, 0.12641636654734612, 0.08409777758060955, 1.4967905078083277, 29.574407748878002, 56.23362712562084, 55.30993469059467, 41.684211641550064, 33.69897432625294, 36.91623508930206, 40.3510607779026, 39.241596311330795, 57.85664923489094, 17.458628676831722, 0.3782911057351157, 0.6578428472857922, 4.039440220221877, 13.553927801549435, 3.4435949055477977, 10.346020236611366, 47.484459802508354, 58.55465278029442, 57.343148589134216, 48.700584545731544, 51.302126348018646, 45.07184386253357, 46.1504577845335, 44.32426817715168, 48.11978571116924, 54.8641312122345, 53.25856536626816, 53.42468485236168, 48.325084894895554, 48.92344258725643, 50.04418484866619, 45.56436963379383, 47.911154106259346, 44.784081503748894, 48.095049038529396, 47.989076524972916, 50.67050904035568, 50.539670661091805, 52.74735599756241, 52.91836582124233, 52.68023259937763, 52.59305387735367, 48.39886553585529, 45.833531990647316, 42.33806535601616, 38.88594679534435, 38.66074047982693, 40.45269392430782, 41.13902069628239, 40.37157587707043, 40.63041798770428, 41.06378473341465, 38.51383276283741, 38.94469164311886, 41.4738093316555, 38.7873724848032, 37.567060366272926, 39.099126756191254, 41.794481724500656, 47.78165325522423, 52.33811415731907, 52.42914967238903, 50.1197399944067, 55.92965863645077, 53.652661219239235, 51.341648027300835, 48.75896081328392, 50.56249223649502, 50.09133651852608, 51.49634912610054, 51.969986110925674, 54.41586546599865, 57.8437565267086, 54.182212203741074, 40.99168360233307, 49.0741690993309, 53.032633289694786, 52.97835320234299, 55.360563173890114, 57.317302376031876, 50.992226377129555, 52.37473279237747, 49.23404932022095, 48.520892187952995, 44.95132192969322, 44.29219029843807, 43.20641376078129, 41.657415479421616, 42.44197458028793, 41.90861999988556, 42.32397571206093, 41.28094308078289, 40.33466085791588, 42.11878292262554, 42.301112338900566, 41.93358086049557, 42.15054161846638, 44.4919303804636, 43.54766584932804, 41.87766306102276, 41.039899215102196, 43.68089810013771, 41.399808302521706, 42.53230333328247, 45.910348668694496, 49.22738827764988, 51.264333575963974, 52.24934712052345, 53.81419815123081, 54.09440651535988, 53.675342202186584, 55.37772685289383, 58.03573742508888, 55.2746307849884, 57.14752748608589, 56.501125171780586, 56.71744376420975, 54.146908298134804, 49.558901488780975, 44.481009766459465, 46.60533517599106, 43.68900686502457, 45.71284666657448, 52.44614236056805, 54.952677860856056, 56.324791833758354, 53.70201297104359, 54.75071109831333, 59.31456260383129, 61.07802137732506, 62.0860730856657, 58.89034576714039, 22.338522523641586, 7.439787508919835, 8.863983862102032, 7.819849764928222, 2.1897578984498978, 0.2546219323994592, 4.023520024493337, 55.61367139220238, 57.55703151226044, 44.467322900891304, 47.8317915648222, 39.07408609986305, 57.64414183795452, 59.07631918787956, 66.0370896756649, 21.715730242431164, 0.4627853014972061, 0.20021146454382688, 0.1509141715359874, 0.17341073078569025, 0.1585142535623163, 0.13121832918841392, 0.11966164267505519, 0.17490520840510726, 0.18070771970087662, 0.11651411274215207, 0.16739949787734076, 0.20211608265526593, 0.20142349560046569, 0.20780041435500607], [0.034172289961134084, 0.05335294081305619, 0.014666250954178395, 0.0376709893316729, 0.003722639185070875, 0.03444360430876259, 0.0354130013147369, 0.03423634472710546, 0.026455592415004503, 0.05269592489639763, 0.029269159604154993, 0.04260980771505274, 0.0449279134045355, 0.8571431029122323, 21.161159500479698, 44.12747673690319, 41.23710863292217, 27.88757186383009, 18.22446808218956, 17.952512875199318, 28.85462187230587, 29.445689655840397, 46.755757704377174, 8.371966313570738, 0.14152186224237084, 2.019855477847159, 7.062444481998682, 12.457862365990877, 13.294289633631706, 12.846779096871614, 47.02249959111214, 55.677211582660675, 49.121343567967415, 51.16855211555958, 47.544530779123306, 47.825160920619965, 44.49686251580715, 44.39022123813629, 45.61295002698898, 50.06401218473911, 50.32598912715912, 48.02899718284607, 51.35311581194401, 44.85028155148029, 43.621758073568344, 46.23411409556866, 45.570650696754456, 50.82524053752422, 49.02396999299526, 47.78528966009617, 46.58139646053314, 47.75064691901207, 47.19910651445389, 47.67258770763874, 47.3478115350008, 43.10939736664295, 42.45786912739277, 39.6061335504055, 36.64904482662678, 33.27211283147335, 36.66627690196037, 37.08172380924225, 36.66570693254471, 36.838263273239136, 38.06419149041176, 41.411067098379135, 37.11843743920326, 36.01463086903095, 36.66507616639137, 36.53663545846939, 35.15707388520241, 35.39985805749893, 40.69767437875271, 48.16463850438595, 49.01505187153816, 45.450922921299934, 48.93567033112049, 50.451534390449524, 48.52060720324516, 48.68175655603409, 49.733338728547096, 50.16462318599224, 50.77077426016331, 49.9381173402071, 49.1927607357502, 51.60112850368023, 51.649378314614296, 45.11682964861393, 34.72914084792137, 51.07911251485348, 47.35824957489967, 51.799116879701614, 48.48214566707611, 49.91353265941143, 46.290297880768776, 47.20587395131588, 45.25817446410656, 42.64179825782776, 39.56184312701225, 39.938611909747124, 38.56468543410301, 38.486079052090645, 36.56908951699734, 37.219010442495346, 38.21148298680782, 38.780757039785385, 38.221028074622154, 37.53698877990246, 37.500875517725945, 38.50042708218098, 38.99409659206867, 37.34356015920639, 38.62781524658203, 38.293729573488235, 36.53716742992401, 37.55772806704044, 37.71151341497898, 37.540142610669136, 39.44270431995392, 43.03331404924393, 45.64685560762882, 48.15279833972454, 48.981963247060776, 50.49425549805164, 48.603385761380196, 52.02470317482948, 50.84481708705425, 50.617558881640434, 49.11938667297363, 50.87667837738991, 51.86846315860748, 48.937304243445396, 43.890206068754196, 41.11234612762928, 38.67717079818249, 38.755347803235054, 41.28459848463535, 52.57594719529152, 53.79314348101616, 55.299200266599655, 55.55605128407478, 53.797171264886856, 51.597856879234314, 54.54715982079506, 54.54120174050331, 57.86414623260498, 31.640396788716316, 6.779476515948772, 2.710806601680815, 0.9019865153823048, 0.3291036357404664, 0.04229616497468669, 1.3208388118073344, 36.823007091879845, 48.41006353497505, 35.333677008748055, 31.465647965669632, 27.232827097177505, 42.68305644392967, 50.335591211915016, 50.71132265031338, 19.27245944738388, 0.48511587199755013, 0.09953815257176757, 0.01706728886347264, 0.045057043389533646, 0.02413360714854207, 0.04082988896698225, 0.055287742070504464, 0.0240872563153971, 0.01795953776309034, 0.027792946239060257, 0.05023258832807187, 0.0734575543901883, 0.06826406432082877, 0.029548251659434754, 0.018285936166648753, 0.058085208365810104, 0.008114105567074148, 0.03491600356937852, 0.018211508031527046, 0.03542602600646205, 0.034836783015634865, 0.1098860141064506, 0.008615771421318641, 0.03914456807251554, 0.033246163875446655, 0.02202831416070694, 0.039831373796914704, 1.0445804544724524, 26.299308389425278, 50.99959418177605, 46.853971034288406, 33.80718491971493, 23.438236713409424, 25.695706978440285, 38.02398964762688, 36.370838955044746, 51.32479593157768, 9.476080667227507, 0.16473401512484998, 0.5066202243324369, 6.74313954077661, 13.073724769055843, 12.829983048141003, 13.554329629987478, 46.199896931648254, 58.82658138871193, 50.29470160603523, 52.75047183036804, 49.68233406543732, 49.84866254031658, 45.736880376935005, 46.15538232028484, 47.20428563654423, 52.840496599674225, 51.69050730764866, 49.563822224736214, 50.25454916059971, 45.512707605957985, 46.630182042717934, 46.30200885236263, 46.48227497935295, 50.242549404501915, 50.90717174112797, 48.58541652560234, 48.109419867396355, 49.083862379193306, 49.02346082031727, 49.531580954790115, 49.3249898403883, 46.11153647303581, 44.02288354933262, 42.028590962290764, 37.30685792863369, 36.12701363861561, 39.40702423453331, 38.80832456052303, 38.65491919219494, 39.222422540187836, 39.63258013129234, 43.38479518890381, 37.631364315748215, 38.26272323727608, 37.891072779893875, 38.37061084806919, 37.697419971227646, 36.90380975604057, 41.140270829200745, 49.66287910938263, 52.036520540714264, 47.1462931483984, 48.6956562101841, 53.78436595201492, 49.79992255568504, 49.95931640267372, 50.876499786973, 52.568894773721695, 52.24522054195404, 52.81348004937172, 51.21026247739792, 51.090660095214844, 54.46169100701809, 46.13154999911785, 35.465203151106834, 52.247352227568626, 48.63484427332878, 53.2841531932354, 51.511350721120834, 51.445709243416786, 47.53690838813782, 48.61365661025047, 44.40682254731655, 44.439531192183495, 42.018095925450325, 41.73390917479992, 40.33729791641235, 39.96021755039692, 37.32424959540367, 38.71412381529808, 38.869166895747185, 39.194475039839745, 40.72012357413769, 38.94443325698376, 40.605483725667, 40.18746055662632, 39.384271055459976, 39.71965625882149, 40.3937628865242, 41.15840345621109, 38.903330862522125, 40.47233127057552, 39.38325650990009, 39.343898221850395, 42.24766060709953, 45.1974119246006, 47.6772690564394, 49.7910500317812, 50.0096371024847, 51.15842945873737, 48.36341343820095, 54.11734588444233, 52.69894279539585, 52.841123566031456, 51.22135028243065, 52.48886726796627, 54.403770714998245, 49.331726878881454, 44.98030297458172, 42.67116688191891, 40.83447463810444, 40.960278287529945, 44.75931443274021, 54.8127693682909, 56.031417176127434, 58.29247064888477, 56.77711956202984, 54.82341259717941, 54.235610738396645, 55.65582633018494, 56.97398699820042, 59.84258987009525, 33.721199333667755, 5.625695027410984, 4.306916892528534, 3.647426893003285, 0.3724944870918989, 0.08930822572438046, 1.400644623208791, 41.38343118131161, 52.144791930913925, 38.17815877497196, 38.60830329358578, 33.529594615101814, 48.85887645184994, 59.05212588608265, 58.756406754255295, 24.9433758482337, 0.5706036253832281, 0.15322703024139628, 0.029755893447145354, 0.03145747665257659, 0.037502544073504396, 0.016081779831438325, 0.04397554868774023, 0.03799054327828344, 0.030738159293832723, 0.0407134645502083, 0.05326330050593242, 0.059743214515037835, 0.09514495002804324, 0.03047028851142386, 0.13967789243906736, 0.22444847883889452, 0.06592531208298169, 0.06833620107499883, 0.07541637154645287, 0.09523980392259546, 0.07274539690115489, 0.17755388893419877, 0.09325323786470108, 0.21665195032255724, 0.19092747912509367, 0.166766163893044, 0.2510545472614467, 1.6189176170155406, 34.19876530766487, 62.3430684953928, 56.313601434230804, 39.88968953490257, 27.774812914431095, 27.799329198896885, 38.225435838103294, 41.58505596220493, 60.57903975248337, 11.200983859598637, 0.30129934020806104, 2.844464429654181, 14.780225548893213, 23.73858019709587, 20.531096309423447, 17.542127296328545, 50.52521623671055, 59.45495367050171, 54.06101770699024, 56.39142885804176, 52.788351997733116, 52.81011343002319, 47.380090802907944, 48.237799778580666, 48.55467237532139, 54.638731107115746, 52.70877666771412, 49.37265828251839, 51.497846245765686, 46.400051191449165, 45.84503777325153, 47.74736389517784, 48.79748314619064, 52.643104791641235, 52.7811323851347, 49.55034054815769, 48.74476097524166, 50.422868728637695, 51.473466753959656, 51.23515114188194, 51.67101815342903, 49.35748569667339, 46.950398460030556, 44.15160544216633, 40.952173322439194, 37.76989348232746, 40.55650435388088, 41.41834370791912, 39.68732759356499, 39.399603232741356, 41.97909861803055, 45.570179522037506, 40.10654769837856, 39.264148101210594, 40.455961748957634, 39.77950304746628, 39.294143691658974, 38.138466104865074, 43.53212088346481, 52.57896423339844, 53.61127384006977, 48.59277293086052, 49.62354741990566, 53.79973232746124, 51.77913375198841, 53.05567525327206, 55.02704367041588, 55.561249405145645, 54.25400175154209, 55.659785717725754, 52.34019264578819, 55.84606312215328, 55.64359478652477, 48.00594002008438, 39.52987924218178, 52.96059675514698, 50.57305946946144, 55.207480788230896, 52.9239971190691, 53.748925253748894, 50.38398161530495, 50.362824350595474, 47.670687809586525, 46.5046139806509, 42.878650948405266, 43.20036068558693, 41.76945626735687, 43.473186045885086, 39.87124152481556, 40.93479685485363, 42.78799921274185, 41.77263289690018, 43.682463616132736, 41.16077072918415, 41.52618572115898, 42.56455220282078, 41.92303642630577, 41.16553947329521, 42.50910937786102, 42.836708799004555, 40.19429638981819, 42.283044308423996, 40.725010111927986, 42.54617638885975, 46.166952699422836, 46.07803367078304, 49.451162070035934, 52.334234565496445, 51.45254507660866, 54.96680550277233, 49.920148104429245, 56.25796481966972, 54.826399236917496, 53.44793580472469, 52.51287057995796, 53.074959218502045, 56.668696179986, 53.3105693757534, 47.96760007739067, 45.27004882693291, 43.04606236517429, 43.4056256711483, 45.88141322135925, 56.613785326480865, 57.958476170897484, 58.88533763587475, 61.265643909573555, 58.62557977437973, 57.45502978563309, 58.600459322333336, 59.33557167649269, 60.7195296138525, 37.81221941113472, 11.083450466394424, 11.83968873694539, 6.136001469567418, 2.5071173440665007, 0.09610324079403654, 1.6745669371448457, 48.1923808157444, 62.296004220843315, 45.75518399477005, 42.36165449023247, 40.90978279709816, 55.99668703973293, 65.78991293907166, 66.48375570774078, 31.875117793679237, 0.9446369705256075, 0.16885507211554796, 0.18794916628394276, 0.2733680186793208, 0.0884716100699734, 0.1372609697864391, 0.23069440852850676, 0.12303834038903005, 0.09381594907608815, 0.15042790153529495, 0.16022616560803726, 0.1652644874411635, 0.15548390132607892, 0.09642928111134097], [0.06882742120069452, 0.0443064278078964, 0.1024609527667053, 0.028112466789025348, 0.016683936191839166, 0.04257176522514783, 0.08613454992882907, 0.03810504553257488, 0.042586997806211, 0.024164337628462818, 0.0733460541232489, 0.012612065966095543, 0.02677322790987091, 0.6267406255938113, 26.9621904194355, 45.77424377202988, 40.78149788081646, 29.79780726134777, 12.840019259601831, 14.525278229266405, 30.484424717724323, 31.369017250835896, 46.68140709400177, 6.093701189383864, 0.16948484379099682, 0.6489763793069869, 8.221832569688559, 13.539618719369173, 13.453193306922913, 11.704097762703896, 44.30107042193413, 57.93921120464802, 51.936490908265114, 50.95811940729618, 50.65340995788574, 53.09443697333336, 47.41887532174587, 47.04042322933674, 42.975481152534485, 47.27511763572693, 53.64676773548126, 52.351075261831284, 49.52055774629116, 49.758873358368874, 48.50411228835583, 51.57089352607727, 50.32962553203106, 49.36904467642307, 51.052817925810814, 50.23394286632538, 48.92713978886604, 49.76516582071781, 48.385729640722275, 47.67294868826866, 45.69284453988075, 42.29018412530422, 38.51536028087139, 36.039793118834496, 34.46972876787186, 35.428732708096504, 36.2332559376955, 36.455741599202156, 37.5382275134325, 36.366207003593445, 36.0690363496542, 36.802959367632866, 36.37630306184292, 35.290667116642, 36.70129582285881, 37.516013905406, 35.36345221102238, 35.98083168268204, 40.905432030558586, 48.58353942632675, 47.740687653422356, 50.47823555767536, 48.54384295642376, 50.0926398485899, 50.64563937485218, 49.13658834993839, 49.40532132983208, 51.78994797170162, 49.66906897723675, 50.77031448483467, 49.070004522800446, 46.16086922585964, 53.99926342070103, 46.768475621938705, 33.085022270679474, 50.57881236076355, 49.20371934771538, 51.38674020767212, 52.78766803443432, 50.28156191110611, 48.00227701663971, 50.721319913864136, 45.00405550003052, 48.099840581417084, 45.26531048119068, 46.05135150253773, 45.43393023312092, 42.033865079283714, 40.80009028315544, 38.628385215997696, 36.49935185909271, 37.31420673429966, 38.193863332271576, 37.412594854831696, 39.543691501021385, 40.75608864426613, 39.14831131696701, 38.02542597055435, 38.15818704664707, 38.49726565182209, 36.88450679183006, 36.70408107340336, 36.616567969322205, 36.94054238498211, 35.759751945734024, 41.01326644420624, 43.65501008927822, 47.71084025502205, 49.69494938850403, 49.52803194522858, 49.18121695518494, 50.42492061853409, 49.92761090397835, 49.69671629369259, 48.06873545050621, 51.0999695956707, 53.21819253265858, 51.18298754096031, 48.91851805150509, 47.426406517624855, 41.34951040148735, 39.26182262599468, 41.55589632689953, 53.44507075846195, 55.71142874658108, 55.9058453142643, 56.04237578809261, 54.22357678413391, 54.42006804049015, 56.08691319823265, 56.95979095995426, 55.13729475438595, 50.51137737929821, 25.811978839337826, 2.8207451524212956, 4.148881947621703, 0.33913162420503795, 0.1298434560885653, 0.7901253271847963, 33.34035336971283, 52.41703972220421, 33.75057935714722, 29.805057272315025, 35.642957612872124, 37.20477260649204, 50.897410064935684, 46.88676707446575, 24.316542483866215, 0.7323243131395429, 0.019848811971314717, 0.06036949809640646, 0.02513351199013414, 0.04400858910230454, 0.05314253823598847, 0.08692676288774237, 0.041923977914848365, 0.06695255578961223, 0.0716878216189798, 0.04684732994064689, 0.03662326234916691, 0.01659093952184776, 0.06197961345606018, 0.03465749126917217, 0.08625536414911039, 0.02939232643257128, 0.00919224854442291, 0.012659556923608761, 0.05420742367277853, 0.013992873464303557, 0.03516079355904367, 0.018426083333906718, 0.03907676175003871, 0.03839068333036266, 0.01358228582830634, 0.06004810733429622, 0.9748278942424804, 31.424710862338543, 54.094026535749435, 46.26687973737717, 35.919130593538284, 19.412468634545803, 20.548845157027245, 34.30543318390846, 34.07963030040264, 51.14828780293465, 6.8488009460270405, 0.22778541228035465, 0.9032080310862511, 10.475674979388714, 16.076181158423424, 14.557079672813416, 11.392631325870752, 46.061983332037926, 59.38790246844292, 55.098867416381836, 52.79683694243431, 52.07684397697449, 54.71181258559227, 49.05061416327953, 47.59732514619827, 45.990379974246025, 49.93928387761116, 53.83659414947033, 52.62811839580536, 51.94333054125309, 49.55782234668732, 48.78416486084461, 52.92137145996094, 52.12996892631054, 51.400757655501366, 53.07359889149666, 51.572801023721695, 49.77342277765274, 52.28482201695442, 51.66002914309502, 48.446647971868515, 46.34117715060711, 44.15542423725128, 41.052081361413, 38.60635779798031, 36.98552057147026, 37.18871466815472, 37.854336351156235, 39.058430939912796, 39.56996329128742, 38.553916811943054, 38.459400683641434, 39.02131833136082, 37.612232342362404, 37.07394182682037, 36.90281800925732, 39.63915757834911, 37.52126902341843, 37.25222826004028, 43.54744926095009, 49.97891955077648, 50.975419878959656, 50.308715254068375, 49.491200521588326, 49.48852926492691, 51.80635929107666, 51.57612584531307, 53.081099689006805, 52.821391224861145, 51.04767680168152, 51.73526510596275, 50.544576197862625, 49.25231114029884, 54.604593738913536, 47.664068564772606, 36.341132149100304, 51.17933213710785, 50.433595553040504, 53.431026712059975, 53.21033835411072, 53.250939175486565, 48.827995508909225, 51.43441244959831, 47.975184470415115, 47.627176344394684, 47.7300938218832, 47.39050604403019, 46.10737569630146, 44.38056215643883, 42.49720461666584, 39.65387038886547, 38.374600633978844, 38.943669497966766, 40.11143423616886, 39.11458432674408, 41.06818109750748, 41.73648163676262, 40.84466569125652, 41.11239932477474, 41.224565505981445, 41.4707200974226, 38.28012630343437, 38.96644167602062, 39.15117256343365, 38.490049839019775, 38.34136761724949, 44.01327006518841, 45.5331315100193, 47.370967492461205, 51.55152216553688, 51.09286017715931, 51.213165521621704, 52.74568788707256, 50.08513145148754, 50.32364845275879, 47.849103435873985, 51.65319710969925, 54.79446955025196, 52.10484467446804, 51.91936142742634, 49.29505504667759, 44.408608451485634, 41.1480376124382, 44.432018995285034, 56.020348370075226, 57.84706994891167, 58.39190371334553, 57.55619175732136, 58.19097809493542, 56.30092151463032, 57.719256207346916, 59.69302989542484, 56.48583099246025, 55.431824550032616, 25.292869694530964, 2.753095719963312, 2.8517901990562677, 0.8067891548853368, 0.1224393084703479, 0.9941380424425006, 38.68951253592968, 57.551130428910255, 37.956604063510895, 32.549991980195045, 37.91350677609444, 42.43467137217522, 57.609320506453514, 54.879007413983345, 31.103295609354973, 1.0184448631480336, 0.09583829407347366, 0.03960994661611039, 0.0715699908323586, 0.03274397851782851, 0.13448956771753728, 0.04400196543429047, 0.05782781299785711, 0.03381717229785863, 0.05638069924316369, 0.007912946439319057, 0.04180700801953208, 0.052937464279239066, 0.04311908800445963, 0.09525904039037414, 0.17628854198846966, 0.1721408567391336, 0.06679325379082002, 0.08226243895478547, 0.16271981148747727, 0.12621223140740767, 0.18934668973088264, 0.1743228451232426, 0.19124600890791044, 0.12569686921779066, 0.12167612832854502, 0.07170434924773872, 1.8649588082917035, 39.85676810145378, 63.39787669479847, 53.18535469472408, 43.28941650688648, 23.531493209302425, 21.46621473133564, 39.316482692956924, 41.97008930146694, 60.58101184666157, 7.612972240895033, 0.25940670690033585, 1.7361287400126457, 14.94292426854372, 18.50933499634266, 21.24504379928112, 14.359078947454691, 47.507665157318115, 60.98447419703007, 57.75501988828182, 54.070445001125336, 55.385277047753334, 58.82929444313049, 52.148633524775505, 50.82992948591709, 47.540054619312286, 53.118846863508224, 56.92387528717518, 53.94434496760368, 53.37356239557266, 52.45645880699158, 51.821155697107315, 55.37831962108612, 54.53223802149296, 52.290286123752594, 56.23365752398968, 54.4898284971714, 52.73333474993706, 55.06020829081535, 52.571433037519455, 52.278917133808136, 48.360905572772026, 46.76279492676258, 43.1456284224987, 40.04537098109722, 40.028773471713066, 40.23101381957531, 40.37573665380478, 40.30330114066601, 41.091314256191254, 39.45916123688221, 39.8336311429739, 40.28673402965069, 39.14522208273411, 39.38142880797386, 39.139123409986496, 41.18828125298023, 38.65486219525337, 38.99896413087845, 44.93341729044914, 51.01192831993103, 51.18171460926533, 49.988749623298645, 51.077497601509094, 50.01482002437115, 53.649359196424484, 52.232430428266525, 52.34980992972851, 54.1559062153101, 52.143393605947495, 54.894039407372475, 53.05189825594425, 49.81698364019394, 56.362421214580536, 50.43549545109272, 39.42286558449268, 52.28078283369541, 51.75366371870041, 55.077402368187904, 55.0846029818058, 56.283442452549934, 50.700592026114464, 55.16716115176678, 47.9551937431097, 51.66883707046509, 49.24814656376839, 49.93452273309231, 48.367095440626144, 46.809061244130135, 45.976658910512924, 42.69103601574898, 39.75305266678333, 40.947765558958054, 42.058115378022194, 40.783895552158356, 43.614530861377716, 44.63365517556667, 43.49468909204006, 42.89664298295975, 42.310174852609634, 43.53943929076195, 41.53644897043705, 41.47300377488136, 42.12487019598484, 40.99215857684612, 40.67976213991642, 46.04792408645153, 48.17481055855751, 49.955717995762825, 53.45615476369858, 52.20897048711777, 51.877708062529564, 52.29209862649441, 52.10871286690235, 51.09192542731762, 49.83998000621796, 53.19076180458069, 56.25318847596645, 54.8670494556427, 54.09024193882942, 52.84260168671608, 46.638457998633385, 43.78318481147289, 45.86569346487522, 57.085385620594025, 60.26459142565727, 60.75389117002487, 61.418711096048355, 60.41288986802101, 59.31767463684082, 62.19056747853756, 61.929209902882576, 57.942140847444534, 57.033772990107536, 31.795580461621284, 7.464016433805227, 8.231974225491285, 2.0533034205436707, 0.4072707850718871, 1.2127587175928056, 43.249929025769234, 65.77333062887192, 45.06279654800892, 40.75697019696236, 46.906545013189316, 48.48563767969608, 64.15361434221268, 63.22563573718071, 39.705942794680595, 1.574111133813858, 0.23133014707127586, 0.12531295622466132, 0.10013280581915751, 0.09990340055082925, 0.2438894083024934, 0.23569507378851995, 0.11088973173173144, 0.16747417277656496, 0.20396408974193037, 0.11680581388645805, 0.10480314856977202, 0.14946104638511315, 0.16304969612974674], [0.03669138779514469, 0.038754606575821526, 0.10942206790787168, 0.013954953428765293, 0.029926505776529666, 0.033250353299081326, 0.03415146900806576, 0.0376573338144226, 0.035525017374311574, 0.03990074976172764, 0.031130460411077365, 0.011032357324438635, 0.04001124812930357, 1.3037064811214805, 28.574502803385258, 47.95712783932686, 42.57329173386097, 36.01599499583244, 20.166701562702656, 27.849380113184452, 45.4403480887413, 39.62057277560234, 43.53315442800522, 4.942814195528626, 0.1791889886953868, 7.336414055898786, 8.209424335509539, 12.893251553177834, 12.54878293722868, 12.34735194593668, 45.13348415493965, 54.79962207376957, 53.45515161752701, 51.85877367854118, 49.58074651658535, 50.45566476881504, 52.09792144596577, 44.8245607316494, 42.84274287521839, 48.40181037783623, 51.02258674800396, 51.30088001489639, 48.466353714466095, 45.36948949098587, 49.68400597572327, 46.31675586104393, 45.577638521790504, 45.0873052328825, 48.77575971186161, 50.36220118403435, 50.81439591944218, 50.239144787192345, 47.03746698796749, 44.91479828953743, 40.6948397308588, 37.92199172079563, 37.53666199743748, 36.578049436211586, 35.58356299996376, 35.032140389084816, 35.768525674939156, 36.06144815683365, 35.998219549655914, 36.84944607317448, 37.359564900398254, 36.80496945977211, 34.749724343419075, 35.14821656048298, 36.032717898488045, 36.57472461462021, 37.16188810765743, 36.18936829268932, 45.63556641340256, 49.53289948403835, 54.67824898660183, 44.39432501792908, 47.27356731891632, 48.76984342932701, 51.124611273407936, 50.76358884572983, 48.82370933890343, 47.020945474505424, 51.91688776016235, 49.82117861509323, 53.95780384540558, 49.11544628441334, 49.64315816760063, 47.248891443014145, 34.517704993486404, 50.69673903286457, 50.42722329497337, 50.781284496188164, 50.00321164727211, 51.83042719960213, 48.387101367115974, 53.42642895877361, 48.2116723805666, 49.50624771416187, 51.053171306848526, 47.371123284101486, 45.53519859910011, 44.88537646830082, 42.98800528049469, 40.72199307382107, 36.671345829963684, 38.209864273667336, 35.518480092287064, 37.4331783503294, 37.81568102538586, 39.14225064218044, 39.57481563091278, 38.98638300597668, 39.0068981051445, 37.923633232712746, 36.6632104665041, 38.55399280786514, 36.682528629899025, 35.861411690711975, 35.44718451797962, 39.39309798181057, 41.724413484334946, 44.096155017614365, 46.374041587114334, 50.78262202441692, 49.98722970485687, 52.54134625196457, 51.59654214978218, 51.87057204544544, 49.34620790183544, 47.132860869169235, 55.337635204195976, 55.34133620560169, 51.72389231622219, 51.44011974334717, 48.978068456053734, 43.34401957690716, 42.465548515319824, 48.02097961306572, 51.7858099937439, 54.78204041719437, 57.1528510004282, 57.040521427989006, 57.93779008090496, 54.43384610116482, 55.81326708197594, 62.35864385962486, 52.05504074692726, 31.766897700726986, 11.913116946816444, 2.2602854389697313, 0.21245604031719267, 0.022654248932667542, 0.38916882360354066, 27.699153274297714, 54.138145968317986, 37.35303305089474, 36.92899100482464, 31.66571483016014, 35.95091208815575, 47.35819257795811, 46.31685845553875, 29.293832704424858, 0.42384611908346415, 0.048657569132046774, 0.027623146561381873, 0.04900155829091091, 0.07408565623336472, 0.04832084559893701, 0.0451202409749385, 0.047812300035730004, 0.033453256473876536, 0.10056529237772338, 0.05355050423531793, 0.08759656600886956, 0.02551407233113423, 0.02722474127949681, 0.026889401851803996, 0.03801042170380242, 0.052558349270839244, 0.026989077850885224, 0.013030151148996083, 0.016292367945425212, 0.005044941790401936, 0.08355315992957912, 0.07588853331981227, 0.009108198464673478, 0.039883142308099195, 0.023581517925777007, 0.058739073865581304, 2.1863988786935806, 36.39293096959591, 58.13106290996075, 49.28011804819107, 40.71530923247337, 19.593278132379055, 22.206739895045757, 38.30198273062706, 39.69580113887787, 50.42536899447441, 4.735211860388517, 0.1773737696930766, 6.647805031388998, 4.277973370626569, 14.220694173127413, 10.48353960737586, 13.26214810833335, 45.62705487012863, 55.84646590054035, 55.39592407643795, 53.615617007017136, 50.25513432919979, 52.708164900541306, 53.468895480036736, 48.27842339873314, 45.72698950767517, 50.04757046699524, 53.77536043524742, 51.41881808638573, 48.7724044919014, 46.86023689806461, 52.83748336136341, 48.9747778326273, 47.77181178331375, 48.19327376782894, 50.82441598176956, 52.028939947485924, 52.45797872543335, 51.44028693437576, 49.13501903414726, 47.13167913258076, 42.75915876030922, 39.761989787220955, 39.253094494342804, 38.19360114634037, 37.69790254533291, 36.60873658955097, 38.02396684885025, 38.89262683689594, 38.16643260419369, 38.418302088975906, 39.177280962467194, 37.376766577363014, 35.940268859267235, 37.7458293735981, 37.84139044582844, 37.75469809770584, 38.87082740664482, 39.097386449575424, 48.61314743757248, 50.38962811231613, 52.95781530439854, 45.709757432341576, 47.53609523177147, 50.210760310292244, 51.73162490129471, 50.53940087556839, 49.41437244415283, 49.31515596807003, 51.51904530823231, 50.32773703336716, 54.64809000492096, 49.834610894322395, 52.76336453855038, 48.65107320249081, 37.111073434352875, 51.875420585274696, 50.19352823495865, 51.70119233429432, 51.204144805669785, 53.17012131214142, 50.30334614217281, 55.52175052464008, 50.75117111206055, 51.95187248289585, 51.66262820363045, 49.12957772612572, 47.34838530421257, 46.86277896165848, 44.691666662693024, 42.885509580373764, 38.29848311841488, 38.21721687912941, 38.66873525083065, 38.44083487987518, 40.358926355838776, 40.64146399497986, 41.945352628827095, 39.35424126684666, 39.485379830002785, 39.785476326942444, 38.596930503845215, 40.03023639321327, 38.90933454036713, 37.23085060715675, 37.453822642564774, 40.69006718695164, 42.99917288124561, 46.74187704920769, 49.12499517202377, 51.96276269853115, 52.80801214277744, 53.19721005856991, 53.14944662153721, 54.27035227417946, 50.812663212418556, 49.18532833456993, 55.53695730865002, 57.41683043539524, 54.573336616158485, 54.04457598924637, 50.31360559165478, 45.994521751999855, 43.713040575385094, 49.47965294122696, 55.48920527100563, 56.328333243727684, 60.15343979001045, 59.441513791680336, 58.19042332470417, 56.80514305830002, 57.40703836083412, 64.03944566845894, 53.76511238515377, 37.78062030673027, 15.039691776037216, 3.9015857549384236, 0.9660810604691505, 0.07212489465018734, 0.3705309424549341, 30.671296790242195, 58.61831076443195, 39.29983198642731, 37.93959617614746, 39.30835112929344, 41.48676283657551, 54.31328997015953, 54.606197252869606, 36.34569950401783, 1.0035122581757605, 0.08168358603143133, 0.05976490749162622, 0.049669090440147556, 0.02875218324334128, 0.08272596955066547, 0.06505007506348193, 0.07241048049763776, 0.011367149418219924, 0.07217346821562387, 0.05589644417341333, 0.010205017588305054, 0.05788282840512693, 0.06471204163972288, 0.1392846877570264, 0.09939039839082398, 0.2012863615527749, 0.1434787572361529, 0.07779957843013108, 0.20220819802489132, 0.1628723376779817, 0.22516518569318578, 0.1134226743306499, 0.13415668479865417, 0.13312312541529536, 0.2045521081890911, 0.14617312437621877, 2.938330080360174, 43.43422673642635, 63.97582188248634, 57.67836280167103, 48.66331234574318, 31.146508790552616, 38.58265087008476, 57.38598749041557, 51.96211293339729, 54.77520078420639, 5.785193843767047, 0.29254959721583873, 10.354489032179117, 15.488916970789433, 28.59110601246357, 21.205368228256702, 13.793695885688066, 47.308282256126404, 56.01277157664299, 56.4407654106617, 56.59393899142742, 52.13089607656002, 54.007888957858086, 55.417959094047546, 50.46783171594143, 47.90606617927551, 51.95730999112129, 55.11920392513275, 53.069643303751945, 49.52194087207317, 47.643770053982735, 53.328983187675476, 50.49234040081501, 50.240748301148415, 50.77298194169998, 53.63146975636482, 54.89823438227177, 55.34002147614956, 53.711634054780006, 51.80179953575134, 49.72518436610699, 44.24023188650608, 42.934507951140404, 42.071528658270836, 40.24857647716999, 39.4780196249485, 37.80572175979614, 38.864246159791946, 40.06918050348759, 38.74810539186001, 41.23054638504982, 40.83036705851555, 38.867597579956055, 38.03842507302761, 38.328528106212616, 40.27186542749405, 39.66894418001175, 40.96985377371311, 40.40733955800533, 51.087103486061096, 52.56406903266907, 53.77533383667469, 47.36590996384621, 49.35627356171608, 50.62544345855713, 52.982183396816254, 52.79840245842934, 49.254834204912186, 50.826768055558205, 53.2389660179615, 52.56233252584934, 56.14313118159771, 53.78894850611687, 53.83139222860336, 51.00448451936245, 41.15239217877388, 54.13470335304737, 52.3866755515337, 55.097066313028336, 54.83220912516117, 54.14489820599556, 51.388108134269714, 56.93354956805706, 53.30489628016949, 53.67682032287121, 54.15655218064785, 50.64092382788658, 48.8275433331728, 47.83894658088684, 47.23798222839832, 45.2483481913805, 40.44089175760746, 40.92141397297382, 39.411933571100235, 41.465749964118004, 42.50081442296505, 43.407730758190155, 45.09300112724304, 41.97934180498123, 44.03147108852863, 42.40837678313255, 41.036657989025116, 43.01983617246151, 41.106099262833595, 40.269479155540466, 40.64336769282818, 43.93035091459751, 46.72344423830509, 49.381386414170265, 50.644632428884506, 53.41056860983372, 53.64845484495163, 55.149237513542175, 54.69709597527981, 56.400175988674164, 51.775493547320366, 49.94261249899864, 57.116494551301, 58.73098611831665, 56.751999109983444, 54.50915426015854, 51.80160194635391, 48.73644322156906, 47.06247724592686, 52.59722225368023, 57.180733904242516, 58.47233399748802, 63.93067270517349, 61.97406269609928, 62.47213996946812, 59.931961074471474, 59.675607830286026, 63.57064202427864, 57.015507370233536, 41.559331342577934, 20.741392225027084, 8.126099556684494, 1.954697286710143, 0.14893551677232608, 0.6148814619518816, 34.501042887568474, 68.72589379549026, 49.61597442626953, 47.88209326565266, 44.37795549631119, 47.332080379128456, 62.2564597427845, 62.77228966355324, 46.9015596807003, 1.8216118030250072, 0.1787156765931286, 0.11771871490054764, 0.1686573342885822, 0.14684809284517542, 0.1431432768004015, 0.14503796497592703, 0.13359713513636962, 0.1515364772058092, 0.30481284542474896, 0.20090988487936556, 0.22351859748596326, 0.10156906937481835, 0.18519146426115185], [0.0723159457265865, 0.024146891591954045, 0.0485381612816127, 0.04012344230432063, 0.034385969120194204, 0.05358620153856464, 0.01661248221353162, 0.01289652374907746, 0.028735668602166697, 0.010192574554821476, 0.022616783462581225, 0.048897034212131985, 0.1313260296592489, 3.2231967570260167, 25.616198144853115, 41.51029497385025, 40.82058258354664, 34.910535514354706, 27.719107903540134, 20.68012621253729, 29.114233441650867, 39.908452928066254, 39.57812525331974, 4.060484915971756, 1.4863901096396148, 25.176462940871716, 43.895753771066666, 10.55876987054944, 12.799654975533485, 9.92290249094367, 35.800151377916336, 37.07284368574619, 49.472676515579224, 48.54204185307026, 51.59843444824219, 52.832547426223755, 51.51611186563969, 43.39981198310852, 41.45436577498913, 44.705585315823555, 51.65361508727074, 51.466786712408066, 49.95110884308815, 47.093080803751945, 48.29241044819355, 49.60230655968189, 44.76680003106594, 40.47661744058132, 41.743408665061, 42.83144608139992, 45.56281931698322, 43.09062257409096, 43.64885821938515, 40.1418250054121, 38.36328104138374, 35.32170385122299, 36.5760013461113, 35.2128054946661, 36.773674339056015, 34.357855170965195, 33.795641139149666, 36.921904385089874, 36.26058407127857, 34.06851589679718, 37.04147256910801, 35.82491084933281, 37.489350736141205, 36.29629075527191, 36.330496519804, 37.882420644164085, 33.815920650959015, 36.47110037505627, 46.682011261582375, 50.76641969382763, 42.74193808436394, 42.51521185040474, 49.29484985768795, 48.679412081837654, 49.50145237147808, 48.317033126950264, 49.61990721523762, 49.289940521121025, 51.42446458339691, 51.686088144779205, 47.73890174925327, 50.25495953857899, 51.32677562534809, 47.60978847742081, 32.56146736443043, 44.879954159259796, 49.489733800292015, 50.017468482255936, 48.69832746684551, 50.393788889050484, 51.05907618999481, 49.89126205444336, 52.87067078053951, 51.520105451345444, 49.83056031167507, 49.542908146977425, 47.9316084086895, 44.73525032401085, 42.391091510653496, 41.09936982393265, 37.914559319615364, 37.32226990163326, 37.43366092443466, 37.949582040309906, 37.9948528110981, 38.51010896265507, 38.45255345106125, 39.41394746303558, 39.46514971554279, 37.79737360775471, 37.05181181430817, 37.564495503902435, 38.29735457897186, 36.298608630895615, 36.863953694701195, 36.4781603962183, 37.80158758163452, 39.9794977158308, 45.023407861590385, 47.26125977933407, 49.308179542422295, 48.547817543148994, 48.14451478421688, 51.65321610867977, 50.32946214079857, 47.89860337972641, 49.00135740637779, 52.9381437599659, 50.42979575693607, 50.55163621902466, 52.39338219165802, 50.26171177625656, 44.880501329898834, 43.59562307596207, 49.032625928521156, 54.397991225123405, 57.78099909424782, 54.85096871852875, 57.40852788090706, 55.506273955106735, 58.132278844714165, 58.698319271206856, 60.87621420621872, 38.09405028820038, 10.488400496542454, 2.904975232668221, 0.38595048536080867, 0.1305284583941102, 0.19370869238628075, 21.32015436887741, 59.5668538659811, 42.39756256341934, 39.41028065979481, 26.92404616624117, 32.431962713599205, 46.312104910612106, 49.253333285450935, 29.27309911698103, 0.5266142764594406, 0.1285675261169672, 0.03985200550232548, 0.021307098759280052, 0.032088157458929345, 0.045816011843271554, 0.0595288525801152, 0.01353372617813875, 0.03456493803241756, 0.03201664410880767, 0.03135075581667479, 0.042633363482309505, 0.08519018185324967, 0.016581974377913866, 0.004835715053559397, 0.015508888209296856, 0.00796794607595075, 0.06520395938423462, 0.011566626653802814, 0.07561042832094245, 0.050965251357411034, 0.018588060775073245, 0.04184537705441471, 0.05652448293403722, 0.034523047506809235, 0.051598507416201755, 0.07096392335370183, 3.804731327109039, 33.16807061433792, 50.57652868330479, 48.14579911530018, 40.54578512907028, 30.058940649032593, 27.261133678257465, 38.803704008460045, 44.882139042019844, 47.094110548496246, 4.477712977677584, 1.135800734627992, 24.943022467195988, 37.44084633886814, 8.115321435034275, 10.180564764887094, 13.016715478152037, 37.86232732236385, 39.92723152041435, 48.76083791255951, 49.08153310418129, 53.06456297636032, 52.43772201240063, 54.05790187418461, 44.78934422135353, 44.75286617875099, 48.64280864596367, 54.45701725780964, 52.508481815457344, 49.65294264256954, 47.62833148241043, 50.89026264846325, 51.632792204618454, 47.374938279390335, 43.97307962179184, 44.83344845473766, 45.668218061327934, 47.944216132164, 46.70216917991638, 44.81104105710983, 42.56743244826794, 40.14510042965412, 38.12458164989948, 37.92887695133686, 36.81596986949444, 37.668503522872925, 37.641471773386, 35.4944121837616, 38.55946831405163, 38.58459256589413, 36.82993032038212, 38.65621492266655, 37.68096685409546, 37.427094876766205, 38.54543186724186, 37.455220967531204, 38.778176978230476, 36.3572508841753, 39.070803076028824, 47.925251349806786, 53.01067806780338, 45.49723483622074, 43.41906554996967, 48.73111970722675, 49.428009912371635, 49.667378067970276, 50.770352482795715, 50.705524161458015, 51.650294065475464, 53.069985285401344, 53.1575021892786, 49.57755088806152, 52.210023030638695, 54.312066435813904, 49.74165268242359, 35.6304182857275, 45.62101699411869, 52.02548213303089, 50.318438932299614, 49.71781276166439, 52.303843796253204, 50.64825743436813, 52.55939148366451, 55.30159413814545, 52.92284198105335, 51.85858368873596, 50.948365330696106, 48.7192377448082, 46.93254701793194, 44.64930273592472, 42.43700824677944, 39.95962478220463, 39.81444217264652, 38.22965361177921, 39.85752806067467, 40.106798484921455, 40.27294836938381, 40.80157980322838, 41.486641243100166, 40.065217316150665, 39.564495384693146, 38.20945009589195, 39.74271722137928, 39.61678437888622, 38.73464651405811, 38.31528201699257, 39.18653726577759, 39.972973465919495, 42.86503627896309, 46.656123250722885, 48.88902023434639, 50.81366255879402, 51.70734420418739, 50.24938903748989, 53.219750449061394, 51.96076400578022, 48.43213275074959, 49.59002561867237, 53.45215357840061, 51.44072391092777, 52.44602456688881, 53.62513929605484, 51.61336004734039, 46.958929002285004, 45.85429787635803, 50.90424969792366, 57.17905059456825, 59.17360156774521, 57.457324862480164, 57.38777719438076, 57.09510549902916, 58.96000362932682, 60.02512447535992, 60.0749322026968, 40.49459047615528, 11.842874865978956, 3.6995163979008794, 0.24725627998122945, 0.14841628057183698, 0.2427727877511643, 23.853721618652344, 66.6942036151886, 46.92886121571064, 46.01748012006283, 33.220579996705055, 36.93130508065224, 54.24808546900749, 56.927044317126274, 38.1143070012331, 1.2355191400274634, 0.08883541828254238, 0.062478229083353654, 0.08692334158695303, 0.00848316818519379, 0.07219382532639429, 0.01992291541682789, 0.034585373068694025, 0.022011480396031402, 0.019714644658961333, 0.05938563292147592, 0.011316285399516346, 0.05917599846725352, 0.009568895911797881, 0.12691448122495785, 0.08922450404497795, 0.17880602565128356, 0.19072082068305463, 0.13344361446797848, 0.17132309905719012, 0.13562998152337968, 0.10749579392722808, 0.15342764760134742, 0.12026558018987998, 0.13243770750705153, 0.25119255704339594, 0.1847459381679073, 4.895680099725723, 40.31185068190098, 57.42353707551956, 56.65839113295078, 46.55286759138107, 38.782402351498604, 29.707748293876648, 40.10693907737732, 52.132898569107056, 53.63851457834244, 5.474143959581852, 1.6718659945763648, 29.221741072833538, 48.48080433905125, 19.490520246326923, 17.65502493828535, 13.192931022495031, 42.611361891031265, 44.278720021247864, 51.73353239893913, 46.81958667933941, 54.317059367895126, 55.132909789681435, 56.94898433983326, 48.749145939946175, 46.8402461707592, 49.642759189009666, 55.04188947379589, 53.080104142427444, 50.25355741381645, 47.9150564968586, 52.73566022515297, 52.45849169790745, 48.64995986223221, 46.24768316745758, 46.146612390875816, 48.48015457391739, 49.88523177802563, 47.94521927833557, 48.23951728641987, 45.19250638782978, 42.03837163746357, 40.42303651571274, 40.04643492400646, 38.84980693459511, 39.67345833778381, 39.06368225812912, 37.42624372243881, 40.205403193831444, 40.757783353328705, 38.42334821820259, 40.60319624841213, 38.38132247328758, 41.683706268668175, 39.34017062187195, 40.254488959908485, 41.77647449076176, 37.459294348955154, 41.01566791534424, 50.61619095504284, 54.30148780345917, 48.26654903590679, 46.60366706550121, 49.52835112810135, 52.067572474479675, 51.515424102544785, 51.09272338449955, 52.00819306075573, 53.637773618102074, 54.625678807497025, 56.049838587641716, 50.961022451519966, 56.05689100921154, 56.282876282930374, 51.73219487071037, 37.99011826515198, 46.66520096361637, 54.24122303724289, 50.62729775905609, 49.092761501669884, 54.22464072704315, 53.1296306848526, 54.766586646437645, 56.478930562734604, 54.81905423104763, 54.05564859509468, 53.72324623167515, 51.81468464434147, 49.17131468653679, 46.61681815981865, 45.099890157580376, 41.83178052306175, 41.32038116455078, 40.31064994633198, 41.59859083592892, 41.73831693828106, 42.129008173942566, 42.256536930799484, 44.2281599342823, 42.77336239814758, 41.83189071714878, 39.82701189815998, 42.70373873412609, 41.50786690413952, 40.726792216300964, 41.86502493917942, 41.108405739068985, 42.73625358939171, 43.68572764098644, 49.45897825062275, 51.5946726500988, 53.137747049331665, 53.612151592969894, 53.89674872159958, 54.77071702480316, 54.0708439797163, 47.92313866317272, 50.47152131795883, 53.271982446312904, 53.46751615405083, 53.981339782476425, 56.67308874428272, 55.017650574445724, 48.77908453345299, 48.155769780278206, 53.228250592947006, 59.846157878637314, 61.911708042025566, 60.25276646018028, 62.08203010261059, 59.37841817736626, 60.99998116493225, 61.81173540651798, 61.640372201800346, 42.12160237133503, 14.019574765115976, 5.788198057562113, 1.9955484196543694, 0.5468689708504826, 0.3157109278254211, 26.648327261209488, 71.73434436321259, 56.738844215869904, 49.827623069286346, 39.70358692109585, 43.989874720573425, 60.016426742076874, 64.15470108389854, 46.15652605891228, 2.5575318513438106, 0.26100259157828987, 0.29606719908770174, 0.19559900189051405, 0.17184986063512042, 0.23520902643213049, 0.12280739145353436, 0.12499617791036144, 0.16350409830920398, 0.07810897237504832, 0.1664594787871465, 0.23184398043667898, 0.296953353099525, 0.0700118369422853], [0.028399297589203343, 0.060730371114914306, 0.0742560533399228, 0.047497785271843895, 0.006030986096448032, 0.02557295618316857, 0.04836407570110168, 0.03772285803279374, 0.0443163206364261, 0.07223712222184986, 0.026861743863264564, 0.0493346898292657, 0.009886932166409679, 2.5360366422683, 32.237416952848434, 44.73580129444599, 38.56902480125427, 32.833479568362236, 19.35455784201622, 16.746296100318432, 31.514547541737556, 39.21389199793339, 36.47700905799866, 2.563334139995277, 0.9720577241387218, 1.7272208305075765, 13.863427843898535, 5.256343921646476, 4.838915895670652, 12.945742886513472, 22.177447266876698, 17.557351179420948, 38.96662786602974, 50.1757375895977, 53.484003469347954, 50.98685726523399, 52.93286204338074, 45.11255867779255, 42.70159184932709, 44.3812271207571, 51.35913468897343, 52.951374650001526, 52.6542229950428, 47.21777491271496, 49.88414503633976, 50.0639133900404, 47.43130445480347, 41.68097421526909, 35.19648537039757, 34.96589474380016, 36.300485730171204, 36.42473526299, 35.037524700164795, 34.01949092745781, 36.11061371862888, 36.552803590893745, 34.717266485095024, 34.81657795608044, 35.21994151175022, 36.461030915379524, 35.22044688463211, 36.03155896067619, 37.40206561982632, 36.970499977469444, 36.93344436585903, 36.506582871079445, 35.188464000821114, 36.3914642482996, 36.101053431630135, 37.120599523186684, 35.24087838828564, 34.91986781358719, 45.55976428091526, 46.868942230939865, 42.64384634792805, 49.41928558051586, 46.965559646487236, 48.442430198192596, 46.43898010253906, 49.98168960213661, 51.9361375272274, 50.80974116921425, 49.824408441782, 50.91636344790459, 48.715985119342804, 49.1761290282011, 53.489174991846085, 49.46080595254898, 35.803700387477875, 48.8092777132988, 48.24624292552471, 48.74266728758812, 48.36566671729088, 49.80374135077, 47.18843288719654, 46.945397928357124, 45.889791771769524, 47.841788828372955, 48.353564366698265, 48.69234658777714, 49.409915283322334, 45.91848023235798, 42.003466710448265, 38.582403883337975, 36.74874387681484, 37.47618444263935, 35.31959496438503, 38.438323214650154, 38.14690925180912, 37.66272023320198, 37.9459760338068, 38.28561320900917, 39.33900028467178, 41.088168025016785, 38.60433250665665, 38.01428496837616, 37.07056760787964, 37.81530484557152, 35.96967548131943, 36.54337249696255, 36.649060025811195, 37.41398178040981, 41.27513699233532, 43.579166159033775, 42.909391298890114, 44.19366538524628, 47.56074070930481, 50.3468956053257, 50.278411880135536, 52.251209020614624, 46.37344881892204, 44.64070379734039, 48.656001538038254, 52.60210879147053, 52.12607033550739, 50.96381150186062, 47.78908185660839, 45.36287024617195, 43.87773893773556, 52.62656807899475, 55.187524259090424, 58.15823905169964, 55.787538662552834, 53.18470872938633, 55.807392597198486, 57.255354300141335, 50.32619811594486, 47.04309828579426, 17.54249967634678, 2.730218335054815, 0.9025695465970784, 0.09461253328481689, 0.039456381418858655, 12.172847259789705, 54.980081990361214, 38.029776737093925, 29.22255802899599, 33.770798072218895, 28.00070509314537, 42.63418346643448, 49.55272302031517, 27.58047614246607, 1.7196519928984344, 0.17760858521796763, 0.037197736601228826, 0.04659835794882383, 0.03930909850168973, 0.02291761673404835, 0.09697010638774373, 0.023253505351021886, 0.022729591764800716, 0.0369866252731299, 0.04819686240807641, 0.018096052117471118, 0.020317155394877773, 0.03930301660147961, 0.07659092414542101, 0.049893645773408934, 0.050590017781360075, 0.046999381156638265, 0.07199963496532291, 0.04693287359259557, 0.03653862782812212, 0.08266015589470044, 0.024938210262916982, 0.0564071011467604, 0.027667178183037322, 0.06538021945743822, 0.053891131465206854, 3.9697531471028924, 37.327570617198944, 51.9779808819294, 46.85884237289429, 38.28914321959019, 23.10078252106905, 16.85912534594536, 30.639407001435757, 42.874672561883926, 43.10734547674656, 2.9027174413204193, 0.7743312965612859, 3.4044961910694838, 18.16742744296789, 5.270149055868387, 6.912758639082313, 13.514673057943583, 23.09545710682869, 19.00426223874092, 41.787216514348984, 50.68670757114887, 54.599217027425766, 54.03927147388458, 54.97541204094887, 46.89859203994274, 44.28932525217533, 48.32863010466099, 52.52769738435745, 55.10642521083355, 52.962428256869316, 47.82078355550766, 50.13284169137478, 53.7806611508131, 49.47287790477276, 43.47725182771683, 37.46509663760662, 38.08727145195007, 39.60397906601429, 38.848492205142975, 37.45151236653328, 37.15156026184559, 37.03738398849964, 38.88037629425526, 36.911941319704056, 35.24473898112774, 37.413073629140854, 38.23953688144684, 35.96912071108818, 37.74097703397274, 38.6583162099123, 37.933254316449165, 38.215548768639565, 37.5202164798975, 37.989027723670006, 37.497128918766975, 38.53075325489044, 39.234486892819405, 38.10563966631889, 36.24631583690643, 47.452894896268845, 50.14019049704075, 43.857809007167816, 50.89435122907162, 50.021986439824104, 49.64052110910416, 48.684788793325424, 51.54079154133797, 52.88365088403225, 51.03284239768982, 49.74196806550026, 50.05238100886345, 50.393412709236145, 50.95019303262234, 55.35012513399124, 53.392781764268875, 36.92544959485531, 49.175889641046524, 49.351596012711525, 51.454961746931076, 50.39169140160084, 48.39598909020424, 48.15969116985798, 48.75693932175636, 46.336321011185646, 49.77290220558643, 48.32747496664524, 51.00711777806282, 51.03713996708393, 49.0602770447731, 44.342032223939896, 40.171018838882446, 38.712258115410805, 38.964344188570976, 37.84346893429756, 40.06733000278473, 39.43589888513088, 40.05236640572548, 39.09913435578346, 39.96761955320835, 39.939599856734276, 40.822216495871544, 41.151316836476326, 40.77790707349777, 39.47914816439152, 40.73778122663498, 38.829782009124756, 39.36419293284416, 38.8469722867012, 39.48378011584282, 43.76071661710739, 45.540096536278725, 44.819043427705765, 47.41479054093361, 49.461436718702316, 53.514728620648384, 51.562571972608566, 52.16238118708134, 46.94176912307739, 47.65567861497402, 50.719697400927544, 53.257045447826385, 54.263463243842125, 53.037546426057816, 50.04545018076897, 45.270056426525116, 46.93910926580429, 53.609974309802055, 57.84936882555485, 59.82156179845333, 56.35455183684826, 56.45024590194225, 57.35533833503723, 58.39631147682667, 51.91613160073757, 46.676934733986855, 16.83183331042528, 2.5916590075939894, 1.4538284693844616, 0.10019047069363296, 0.012427617220964748, 13.312148675322533, 61.0897209495306, 42.00961858034134, 36.36972561478615, 43.458325043320656, 32.31134958565235, 46.3843010365963, 57.112732753157616, 34.68274913728237, 1.8738993722945452, 0.07105545984813944, 0.01935599993885262, 0.03226454369723797, 0.034287474991288036, 0.07908235842478462, 0.00693654077622341, 0.05491232295753434, 0.019540763169061393, 0.029454177019943018, 0.021126745741639752, 0.04970712179783732, 0.02320774452527985, 0.05639019873342477, 0.19706570834387094, 0.1505736296530813, 0.13018058409215882, 0.07983363451785408, 0.1082773348025512, 0.0815867209166754, 0.0979960587574169, 0.16164409811608493, 0.09529247414320707, 0.11336349547491409, 0.1108702874626033, 0.15575996541883796, 0.1984246846404858, 5.573250241577625, 45.67995563149452, 60.78636422753334, 52.38521263003349, 43.65161307156086, 28.978204540908337, 22.760983854532242, 40.751806274056435, 53.01284395158291, 49.887458458542824, 4.431902635842562, 1.1924311146140099, 3.5648815473541617, 16.998720355331898, 9.622719548642635, 9.064503852277994, 15.526369661092758, 26.005922332406044, 19.950973838567734, 45.32260000705719, 54.72004294395447, 57.04382345080376, 55.491112768650055, 57.58895739912987, 49.99229483306408, 46.34840056300163, 49.763444513082504, 54.74473401904106, 56.34985908865929, 55.089082941412926, 47.58624494075775, 52.21936292946339, 56.783024445176125, 51.52832441031933, 45.83517350256443, 39.0333104878664, 38.363478630781174, 40.95968171954155, 40.27215801179409, 39.336025044322014, 39.09542575478554, 39.06669929623604, 40.65051510930061, 38.72850224375725, 38.923834562301636, 39.85838681459427, 40.41422098875046, 37.56546825170517, 40.11741891503334, 41.71074941754341, 39.98383708298206, 40.252311676740646, 40.053726732730865, 39.736880734562874, 40.444873943924904, 41.433645486831665, 40.8087158203125, 39.86875265836716, 38.1050430983305, 49.20224882662296, 52.59770482778549, 46.302130445837975, 51.55447460711002, 50.888955518603325, 51.64537712931633, 49.480249509215355, 52.39901348948479, 53.72779458761215, 52.2828309237957, 51.48845694959164, 53.363918513059616, 51.53091587126255, 52.33914390206337, 58.12117584049702, 54.469199404120445, 40.74790768325329, 49.1961083561182, 49.84167851507664, 52.401798740029335, 51.74473039805889, 50.873254761099815, 48.027560859918594, 50.456500723958015, 48.53343911468983, 51.2583526968956, 52.75839440524578, 51.674631759524345, 54.78580221533775, 51.80583871901035, 46.581407859921455, 41.89321182668209, 41.13611005246639, 40.3727538138628, 38.78369428217411, 41.63869388401508, 43.234923630952835, 41.0160668939352, 40.769334733486176, 42.37057261168957, 42.52678222954273, 44.31066110730171, 41.84349149465561, 42.515637427568436, 41.785613000392914, 42.026550471782684, 40.79393081367016, 41.26215688884258, 41.09674796462059, 41.19343377649784, 45.60206741094589, 48.53070326149464, 47.46550641953945, 49.21349622309208, 51.61403641104698, 56.38729467988014, 54.11445043981075, 54.52882580459118, 47.68477365374565, 49.20217663049698, 48.470085114240646, 56.55569024384022, 56.48568280041218, 56.774706691503525, 52.71899811923504, 48.94006669521332, 48.02984073758125, 57.67654649913311, 59.50713247060776, 61.94943241775036, 59.32887263596058, 56.578910797834396, 58.44308316707611, 59.64195303618908, 51.05254054069519, 48.67026977241039, 20.901173651218414, 6.751285353675485, 2.5219572102651, 0.3359073487808928, 0.10142138940864243, 14.534182101488113, 65.79191163182259, 50.87389312684536, 37.72205784916878, 45.22229678928852, 40.436256006360054, 57.21671797335148, 65.40765345096588, 44.410933926701546, 4.656064482405782, 0.25764947931747884, 0.18865980237023905, 0.07867778404033743, 0.12563574593514204, 0.15482181654078886, 0.22755864163627848, 0.20032400381751359, 0.08609137919847853, 0.14066043659113348, 0.07944285665871575, 0.1630115497391671, 0.23080393468262628, 0.19216138869524002], [0.015685452563047875, 0.023741530530969612, 0.015102454744919669, 0.11962112883338705, 0.006483835331891896, 0.10588744858978316, 0.007653282882529311, 0.09156815445749089, 0.03846338040602859, 0.037749144903500564, 0.0439462969370652, 0.01811243131669471, 0.03671053520520218, 0.9072771377395838, 27.505014091730118, 46.153505221009254, 38.21081042289734, 32.175666466355324, 25.406344905495644, 25.20248394459486, 44.51854035258293, 39.50291208922863, 35.65887115895748, 1.5038352110423148, 0.07090248836902902, 2.084765019826591, 6.742233764380217, 6.282169176265597, 5.6945117097347975, 10.895955227315426, 32.26435750722885, 32.74767257273197, 40.58692932128906, 50.66326662898064, 51.91050410270691, 51.30209594964981, 44.97746832668781, 48.33590291440487, 48.61203029751778, 49.798509031534195, 50.79305246472359, 50.626021027565, 49.17015194892883, 47.547821402549744, 46.516450345516205, 50.67104481160641, 47.04259291291237, 45.95651239156723, 38.71837578713894, 35.43612711131573, 35.27594670653343, 35.10386534035206, 38.37076283991337, 37.9903956502676, 36.387105882167816, 36.26739330589771, 36.15285225212574, 35.003755912184715, 35.622309520840645, 33.97688381373882, 32.655630111694336, 35.59684708714485, 36.05705179274082, 36.204229295253754, 37.255017310380936, 35.44376850128174, 35.348940789699554, 34.84419107437134, 35.28897240757942, 37.16939650475979, 35.239814445376396, 37.77723088860512, 40.56231804192066, 47.113455310463905, 47.97615721821785, 49.45024631917477, 48.43346267938614, 49.680677354335785, 48.68981592357159, 50.60362882912159, 48.89107592403889, 50.721422508358955, 50.99471144378185, 53.21498170495033, 50.30535623431206, 51.388947889208794, 50.3629307448864, 52.48745374381542, 34.09922204911709, 45.52207790315151, 52.27087676525116, 46.34630687534809, 46.37070156633854, 48.18801485002041, 49.44277971982956, 46.90729357302189, 48.765800446271896, 49.310417622327805, 51.823762357234955, 50.799937695264816, 47.68293455243111, 41.93155936896801, 41.72045409679413, 38.37566077709198, 35.90532213449478, 36.077369302511215, 36.7697149515152, 36.283071264624596, 38.19966182112694, 37.80421704053879, 37.52314232289791, 37.139860689640045, 37.82265745103359, 37.27126523852348, 37.34718516469002, 38.70341219007969, 38.41325215995312, 38.20660024881363, 36.610017120838165, 36.6848237067461, 37.27036468684673, 36.69129855930805, 36.50432959198952, 38.91954459249973, 41.91696435213089, 43.54572415351868, 43.71280498802662, 50.75931027531624, 48.71202953159809, 50.48434562981129, 52.596291303634644, 48.999294117093086, 44.83366124331951, 46.65386997163296, 52.73666337132454, 54.70963530242443, 50.9493038803339, 47.32555612921715, 44.708362966775894, 47.76743061840534, 52.64415733516216, 58.352636620402336, 55.754001662135124, 54.7391103208065, 51.28057010471821, 58.37149880826473, 58.185985162854195, 49.51860465109348, 20.712196491658688, 4.160053348168731, 0.17188600322697312, 0.15363093669293448, 0.08689918468007818, 7.394959414377809, 54.26932632923126, 48.43950815498829, 37.50549226999283, 31.879692748188972, 44.1785915941, 46.47298827767372, 46.74429751932621, 34.02121223509312, 3.9603486517444253, 0.037319790208130144, 0.02809087214700412, 0.023561294401588384, 0.03414086742850486, 0.08369591203518212, 0.03600773990910966, 0.03906404504959937, 0.07746371207758784, 0.047918152558850124, 0.07690650018048473, 0.06600743814487942, 0.047323458493337967, 0.04455939255421981, 0.03324589670228306, 0.06992396665737033, 0.10060109358164482, 0.051529984921216965, 0.034644666957319714, 0.02956490916403709, 0.06964177242480218, 0.019967206790170167, 0.031568375779897906, 0.055514894920634106, 0.0321629288373515, 0.05070098370197229, 0.03138482781650964, 1.8975293543189764, 33.55209320783615, 51.83176472783089, 43.86067405343056, 36.47965371608734, 28.001276962459087, 25.429333671927452, 36.54836542904377, 44.71635393798351, 41.68163537979126, 1.7789879464544356, 0.22458596911747009, 0.5885782046243548, 8.722526002675295, 8.63691184669733, 6.197791378945112, 9.471750799566507, 36.41974613070488, 31.21686201542616, 42.83949784934521, 52.8918432444334, 54.97642278671265, 53.81216526031494, 47.28707939386368, 49.63072903454304, 51.09303496778011, 50.588722229003906, 50.9328393638134, 52.006585747003555, 51.38742417097092, 48.8348313421011, 46.87224045395851, 51.94424249231815, 50.067770183086395, 47.590200528502464, 41.76181107759476, 37.53156267106533, 37.71369069814682, 36.86920881271362, 39.69697527587414, 39.350851848721504, 37.96383127570152, 38.07281702756882, 38.3977185934782, 37.53184765577316, 36.702329367399216, 37.262639701366425, 35.35547263920307, 37.736709862947464, 38.47920902073383, 37.715761587023735, 38.72792087495327, 36.484973430633545, 37.28599704802036, 35.98921783268452, 36.495726853609085, 39.391285479068756, 38.29230844974518, 37.870405688881874, 42.59133696556091, 47.35881954431534, 48.99332083761692, 51.169331073760986, 50.64963296055794, 49.96657781302929, 50.26407144963741, 52.41308033466339, 49.69717986881733, 52.20533408224583, 53.55201601982117, 53.9136616140604, 51.662350818514824, 52.77151510119438, 52.60604538023472, 52.23767414689064, 36.270387545228004, 46.490467339754105, 52.56510257720947, 47.98124894499779, 46.44632130861282, 48.317333310842514, 50.54223172366619, 47.69872270524502, 49.224709421396255, 53.31148512661457, 52.125720754265785, 52.41433426737785, 49.58741135895252, 43.988947570323944, 43.49424071609974, 39.24785077571869, 37.41603747010231, 38.31340491771698, 38.462565913796425, 38.29752936959267, 41.17602311074734, 38.59911538660526, 38.42427916824818, 39.45867106318474, 39.2374013364315, 38.70415315032005, 39.35390308499336, 39.917287454009056, 39.63919557631016, 40.80034486949444, 38.89084853231907, 37.9560074955225, 40.14178320765495, 38.13757695257664, 37.60424517095089, 39.76633295416832, 43.517237082123756, 46.19557276368141, 45.898694694042206, 50.967246517539024, 51.801225766539574, 53.120039999485016, 53.31968888640404, 51.47840268909931, 46.70675553381443, 48.08011204004288, 54.90094743669033, 56.85972712934017, 53.28815437853336, 48.65701608359814, 47.33130902051926, 48.671094328165054, 55.5643842369318, 59.98550780117512, 58.21299031376839, 56.479523330926895, 54.268566370010376, 57.991192415356636, 56.565831899642944, 49.88241992890835, 21.149659417569637, 5.429138224571943, 0.5849066516384482, 0.1932347717229277, 0.13369376276386902, 8.379732146859169, 59.15032021701336, 53.47911313176155, 34.88433592021465, 30.97258072346449, 45.04014976322651, 52.17270143330097, 53.02188366651535, 42.989472001791, 5.020657768473029, 0.02803046503686346, 0.05210855582845397, 0.04178714443696663, 0.02763226755632786, 0.0941079470794648, 0.05268390952551272, 0.011314213879813906, 0.060716277730534784, 0.006454721806221642, 0.02041041738266358, 0.024495131401636172, 0.0062517884816770675, 0.044692377996398136, 0.14009245613124222, 0.17226562660653144, 0.18501714861486107, 0.2957875875290483, 0.10949816030915827, 0.18049510923447087, 0.17517377680633217, 0.24473320052493364, 0.12122859843657352, 0.11599632372963242, 0.1686638651881367, 0.11056344650569372, 0.1542585709830746, 2.9049388971179724, 40.64739927649498, 59.45624940097332, 51.35830633342266, 44.20525476336479, 36.86029449105263, 33.57402943074703, 57.17822603881359, 52.05564871430397, 48.093023747205734, 2.1008925419300795, 0.36129203508608043, 3.5527039133012295, 10.850841198116541, 13.10101205483079, 11.240071412175894, 13.259450253099203, 37.332202568650246, 34.39114898443222, 43.586454167962074, 54.54742580652237, 56.08741097152233, 55.18185116350651, 48.91020029783249, 52.520641162991524, 54.17930155992508, 54.150700494647026, 53.53888012468815, 51.67728781700134, 50.784381330013275, 49.55293580889702, 49.13603737950325, 54.53698396682739, 52.11917370557785, 50.32301768660545, 44.16124552488327, 38.885433822870255, 39.39685598015785, 37.58398845791817, 43.34648944437504, 42.355468422174454, 40.467771515250206, 39.84896332025528, 39.820533245801926, 39.00442823767662, 39.59216549992561, 38.109173476696014, 36.85404762625694, 39.78203371167183, 40.06071835756302, 40.40903426706791, 40.716536566615105, 38.55166733264923, 39.72399182617664, 38.57610762119293, 38.55840057134628, 41.36630170047283, 40.04599794745445, 41.53673775494099, 44.757695719599724, 49.937589168548584, 51.34363532066345, 54.038921892642975, 51.5473347902298, 52.357177734375, 51.5193796902895, 53.12597148120403, 51.32346600294113, 54.0975109487772, 54.87629055976868, 56.35456703603268, 53.50186251103878, 55.358959659934044, 54.37377892434597, 55.64676381647587, 40.400507524609566, 45.553217232227325, 51.01248688995838, 48.77764441072941, 48.866943418979645, 50.79406701028347, 51.008219718933105, 49.05900411307812, 50.535965859889984, 55.038420259952545, 55.12309491634369, 54.61627051234245, 51.83585710823536, 47.37107768654823, 45.48220284283161, 41.70132212340832, 39.01019632816315, 39.695318564772606, 39.92204859852791, 40.13368584215641, 42.86627121269703, 41.776147708296776, 39.445668160915375, 40.13221152126789, 40.81022433936596, 40.24445749819279, 40.4660502076149, 43.110651299357414, 41.759253814816475, 43.98725666105747, 40.6295820325613, 39.86344814300537, 43.347139209508896, 40.19375301897526, 40.98301626741886, 43.04100103676319, 46.56356401741505, 48.87124478816986, 48.50321173667908, 54.948672875761986, 53.09740461409092, 55.46384923160076, 55.69559879601002, 53.65147188305855, 47.79531732201576, 49.39166486263275, 56.687033995985985, 57.86448821425438, 56.178355291485786, 50.77623836696148, 50.359351336956024, 51.66754133999348, 57.6225969940424, 63.646459355950356, 60.65992221236229, 60.049743354320526, 54.54713702201843, 60.2412910759449, 55.96603028476238, 53.424209877848625, 23.56577306985855, 6.683815224096179, 0.9604399662930518, 0.4924888419918716, 0.1854992180597037, 8.86815033853054, 66.68105632066727, 61.70320563018322, 48.627662658691406, 43.28727342188358, 54.78327535092831, 59.519941583275795, 63.1391865760088, 54.85141709446907, 7.7572927717119455, 0.3812232718337327, 0.1616782962810248, 0.1278625155100599, 0.11705113080097362, 0.18650723272003233, 0.11798421081039123, 0.10481217308552004, 0.23577280633617193, 0.10589417986921035, 0.12404000968672335, 0.11529575116583146, 0.13364170852582902, 0.11856749435537495], [0.04181627002253663, 0.03325482102809474, 0.04644543842005078, 0.015534152771579102, 0.006663528301942279, 0.03132252080831677, 0.06422333739465103, 0.03568841973901726, 0.027118892467115074, 0.04402788865263574, 0.022681929185637273, 0.07385766846709885, 0.030246963287936524, 0.7773133646696806, 27.67052561044693, 48.11474338173866, 45.12380227446556, 35.77427476644516, 18.570046238601208, 21.653867661952972, 35.8032938092947, 35.33441036939621, 34.50442090630531, 1.022519669495523, 0.17778074863599613, 0.29917905398178846, 4.867818569764495, 5.83378373645246, 7.47407496906817, 8.557332716882229, 36.943050250411034, 54.01899196207523, 51.427143439650536, 53.201940804719925, 50.52728332579136, 47.925764322280884, 49.41006347537041, 52.0770263671875, 53.24621602892876, 51.34861305356026, 51.11605033278465, 49.375211745500565, 48.263987973332405, 43.98045502603054, 45.60857266187668, 48.174145594239235, 46.96877047419548, 48.381485268473625, 41.38089671730995, 36.87387116253376, 36.05591185390949, 35.20507290959358, 36.27798713743687, 36.638033017516136, 37.430457696318626, 35.4744366556406, 35.022663697600365, 32.94642470777035, 36.770706698298454, 35.00698193907738, 34.832749888300896, 35.59467740356922, 36.36542044579983, 35.61963826417923, 34.84200619161129, 36.396305188536644, 36.29391208291054, 34.744039848446846, 36.63524776697159, 37.41591967642307, 35.806101858615875, 34.31195743381977, 36.37998886406422, 41.38351857662201, 43.854575380682945, 46.19513958692551, 49.96560886502266, 44.81943100690842, 45.897862538695335, 46.37360841035843, 44.71465162932873, 48.65489959716797, 48.0677855014801, 49.612573608756065, 49.79617215692997, 52.14522510766983, 50.25684803724289, 49.10209760069847, 34.48936991393566, 47.79976308345795, 47.71616756916046, 46.44936494529247, 46.323329508304596, 50.1717060059309, 48.8999180495739, 51.35059654712677, 49.5893644541502, 50.18145248293877, 50.3992035984993, 48.38809311389923, 42.19062566757202, 38.30159515142441, 37.56894886493683, 38.130448535084724, 37.627461925148964, 35.89323118329048, 37.07973651587963, 36.77462048828602, 36.618676856160164, 38.61554190516472, 36.51775047183037, 37.60522551834583, 38.85850466787815, 38.11921253800392, 37.76942990720272, 39.17416512966156, 39.96770314872265, 40.48549376428127, 39.99699577689171, 38.427767381072044, 37.6502189040184, 37.23441481590271, 37.21249759197235, 38.4284133464098, 39.309228882193565, 40.34191846847534, 41.67032718658447, 43.532706052064896, 47.336864322423935, 48.11188593506813, 49.09214213490486, 54.115062206983566, 55.99877692759037, 53.30311417579651, 52.11577668786049, 53.81456673145294, 53.02199386060238, 51.78114764392376, 43.56843173503876, 44.48422819375992, 50.859936475753784, 55.302449092268944, 54.3179827183485, 56.76229275763035, 56.3860559463501, 51.00275561213493, 54.636120647192, 58.00913505256176, 29.022101685404778, 6.379345636814833, 1.1078557278960943, 0.15423835488036275, 0.08435140654910356, 5.196821540594101, 47.874261885881424, 48.514641523361206, 34.88347716629505, 27.301599606871605, 42.40280248224735, 42.00651794672012, 53.116000816226006, 41.015382930636406, 3.179481290280819, 0.07443501483066939, 0.055614583907299675, 0.048581302326056175, 0.04395271280372981, 0.04337797508924268, 0.022732577053830028, 0.026073473563883454, 0.05530240319785662, 0.03862997400574386, 0.027890579476661514, 0.037650602534995414, 0.015596010780427605, 0.06879648848553188, 0.11760054272599518, 0.0545142906048568, 0.08135501499054953, 0.015148505935940193, 0.03904573997715488, 0.036569415824487805, 0.08924789653974585, 0.01344913340290077, 0.025702783786982764, 0.04392691946122795, 0.10196821123827249, 0.06856934676761739, 0.05672574967320543, 1.212543910369277, 33.39188240468502, 53.08259300887585, 49.880865812301636, 39.818439558148384, 24.63838141411543, 17.882528230547905, 43.09047818183899, 42.98360891640186, 38.72212618589401, 1.0991658316925168, 0.12730879912851378, 0.4378337028902024, 4.560486311092973, 8.282110635191202, 3.7527311174198985, 7.595640420913696, 38.434284031391144, 59.779684245586395, 55.13315677642822, 54.313935935497284, 51.80226691067219, 52.55768157541752, 50.883749797940254, 53.41220632195473, 55.04007317125797, 52.38871604204178, 52.51679576933384, 50.93689374625683, 49.00362968444824, 45.876690074801445, 48.76798152923584, 50.456078946590424, 50.04288151860237, 50.07817402482033, 42.62267008423805, 37.714724242687225, 37.38177090883255, 37.19064116477966, 38.04208807647228, 38.36462616920471, 40.10240972042084, 37.156625390052795, 36.84400096535683, 35.537034496665, 37.15394653379917, 37.95341223478317, 36.86967618763447, 37.7345971763134, 37.88618244230747, 37.19090715050697, 37.155527248978615, 37.49237537384033, 38.18503260612488, 37.932961732149124, 37.30599917471409, 40.00658266246319, 38.104765713214874, 37.595760226249695, 38.99910852313042, 43.94561089575291, 46.41567975282669, 47.15265400707722, 48.39101515710354, 47.06121191382408, 46.541798785328865, 46.56743600964546, 45.274942964315414, 48.49743604660034, 49.260416105389595, 50.86722068488598, 51.60582885146141, 52.15073101222515, 50.744677260518074, 51.12637057900429, 37.18900345265865, 48.54789353907108, 50.00669226050377, 47.290180027484894, 47.00801096856594, 50.780315548181534, 50.97594045102596, 52.75744065642357, 49.588064923882484, 51.96255750954151, 52.83003956079483, 51.693368554115295, 45.13965882360935, 41.53698854148388, 38.50023329257965, 39.32320073246956, 39.61661718785763, 38.33304226398468, 39.74440433084965, 39.47950154542923, 39.16840463876724, 40.55813446640968, 37.911181300878525, 38.9556198567152, 39.63332109153271, 40.03168411552906, 38.99536192417145, 42.03465923666954, 41.661735847592354, 42.3774578422308, 41.77720405161381, 39.38044086098671, 38.73140148818493, 39.306819811463356, 39.569606110453606, 41.59919500350952, 40.77188819646835, 42.43933752179146, 43.52417171001434, 45.73144666850567, 48.928538113832474, 52.63701371848583, 53.37571308016777, 55.02156436443329, 55.124162659049034, 54.92237448692322, 52.800511345267296, 56.824107840657234, 55.754860416054726, 53.03737163543701, 43.766971081495285, 47.321429550647736, 53.84730577468872, 56.07183940708637, 57.37747214734554, 59.36066932976246, 53.20047788321972, 54.34482827782631, 54.70159873366356, 56.40776418149471, 29.687107801437378, 5.350664360448718, 1.2433322332799435, 0.2859669551253319, 0.023480298259528354, 5.8466526959091425, 51.513759791851044, 54.11342829465866, 42.84902773797512, 35.817284658551216, 54.17823761701584, 48.44834268093109, 58.90534356236458, 47.51635529100895, 5.584463914856315, 0.20024959609145299, 0.031802720041014254, 0.06417309399694204, 0.03990424156654626, 0.05492767428222578, 0.08356555379577912, 0.04303839428757783, 0.06128194640041329, 0.1001257702591829, 0.010959425544569967, 0.011638210507953772, 0.03793346470047254, 0.04757051574415527, 0.15878145641181618, 0.2536437223898247, 0.12586533674038947, 0.06367825219058432, 0.1184303083573468, 0.11894016381120309, 0.2599045989336446, 0.12262569885933772, 0.07987829696503468, 0.1748257243889384, 0.1616618799744174, 0.229277559556067, 0.09058435607585125, 2.0278830220922828, 38.917116522789, 59.769933968782425, 58.48426155745983, 47.585614174604416, 29.45585411041975, 31.554848179221153, 49.79489542543888, 47.54896514117718, 47.120142951607704, 1.2785551557317376, 0.2414074438274838, 1.7527682846412063, 10.108263194561005, 13.672683779150248, 17.722148336470127, 11.787757873535156, 40.77832505106926, 58.43031205236912, 55.61100393533707, 57.3442505300045, 55.79890765249729, 55.18719747662544, 52.520606964826584, 55.9962310642004, 56.7362679541111, 53.202043399214745, 55.1864755153656, 50.658737272024155, 50.7059383392334, 45.803019627928734, 49.44342568516731, 51.77670568227768, 51.938292011618614, 54.20501098036766, 44.999165162444115, 40.84399312734604, 40.704772397875786, 39.66914176940918, 40.34027315676212, 41.42661966383457, 41.66316457092762, 38.60259599983692, 38.34200978279114, 37.49980017542839, 39.91387903690338, 40.097914561629295, 38.81385326385498, 40.60768000781536, 40.93622177839279, 39.512829557061195, 38.06193821132183, 41.55419021844864, 42.41323672235012, 39.75883595645428, 38.83197069168091, 43.12612026929855, 39.899451211094856, 39.33403015136719, 40.06194569170475, 46.05472192168236, 48.00757773220539, 46.99704475700855, 52.10323356091976, 48.18711429834366, 48.78988355398178, 46.27533048391342, 44.72590662539005, 49.12518136203289, 51.86483055353165, 52.060162872076035, 51.529582142829895, 55.00684395432472, 52.68273666501045, 52.343555465340614, 40.58184139430523, 49.19603995978832, 50.513414070010185, 48.12753729522228, 47.37391993403435, 53.37837293744087, 53.17921042442322, 55.395490899682045, 52.397565767169, 56.36815890669823, 54.367095082998276, 51.99962452054024, 46.8742011487484, 41.708583533763885, 41.53418429195881, 41.748424395918846, 42.43636608123779, 40.6438160687685, 41.42213210463524, 39.60709109902382, 39.95331332087517, 43.577931225299835, 40.01738928258419, 41.77508756518364, 43.08424271643162, 42.00747549533844, 40.901461243629456, 43.850133419036865, 42.88675591349602, 44.72917824983597, 43.347576186060905, 42.309566885232925, 42.05521613359451, 42.01607443392277, 41.94647736847401, 42.882268354296684, 43.92700709402561, 43.83879102766514, 45.62075860798359, 47.28969745337963, 52.250171676278114, 55.05375623703003, 54.917655140161514, 57.45292849838734, 57.91635163128376, 56.96759954094887, 54.00477692484856, 59.39205564558506, 58.10080133378506, 55.167966708540916, 46.68757036328316, 49.88667190074921, 55.717215836048126, 58.21448743343353, 60.00070698559284, 61.0723102837801, 55.77124133706093, 54.70535293221474, 55.35644419491291, 53.37506331503391, 29.854122139513493, 8.060307037085295, 3.2177901221439242, 0.761365620419383, 0.15038800367619842, 6.941518820822239, 57.456450909376144, 62.2022670507431, 47.774163857102394, 39.93009656667709, 57.16544732451439, 55.739133059978485, 65.9156633913517, 59.795411601662636, 8.722294215112925, 0.30531937605701387, 0.21929171023657545, 0.17498904140666127, 0.1784000263432972, 0.1454617312992923, 0.16898390895221382, 0.1343851475394331, 0.14295350963948295, 0.20598549221176654, 0.12483850121498108, 0.09515209691016935, 0.11836076169856824, 0.12191994610475376], [0.09048780266311951, 0.014402487031475175, 0.03521998725773301, 0.06665404172963463, 0.023501130344811827, 0.10038282052846625, 0.0256899613304995, 0.03809278154221829, 0.06446958941523917, 0.04634779405023437, 0.06538374465890229, 0.12235689297085628, 0.02590145857539028, 0.6598067481536418, 23.453713282942772, 49.727411046624184, 40.371746867895126, 40.401886850595474, 19.988320134580135, 26.842793226242065, 30.640811026096344, 37.325085550546646, 32.411683201789856, 1.0182720911689103, 0.06919830950209871, 0.4460834164638072, 5.319724045693874, 9.737543687224388, 4.444747846573591, 3.0077772913500667, 30.45167237520218, 50.374907702207565, 52.60813906788826, 51.34761370718479, 53.91661785542965, 53.35500419139862, 51.53587460517883, 49.5303688198328, 46.3212776184082, 49.115529879927635, 48.351687267422676, 46.540161073207855, 44.85462851822376, 47.41089954972267, 47.07842878997326, 46.97709962725639, 50.15727438032627, 47.6609755307436, 43.11032071709633, 36.65089152753353, 35.6277584284544, 34.55111280083656, 34.22573626041412, 34.65249516069889, 34.03048753738403, 34.272044375538826, 35.035347416996956, 33.93640838563442, 35.30631847679615, 36.747949719429016, 36.788105964660645, 36.314430981874466, 34.458226785063744, 35.55682383477688, 37.80816502869129, 35.46636588871479, 36.897817477583885, 34.35669623315334, 36.10499382019043, 37.62574061751366, 34.621268436312675, 33.939524218440056, 33.95851559937, 37.972236424684525, 40.74313893914223, 48.2957124710083, 50.587031319737434, 49.177287966012955, 49.04972121119499, 50.64212076365948, 48.383499160408974, 50.944538936018944, 47.299417331814766, 44.90699350833893, 44.96769145131111, 49.41310711205006, 47.99184277653694, 47.80296631157398, 35.86382836103439, 44.95807036757469, 49.731811210513115, 45.62671288847923, 48.87673169374466, 51.70533411204815, 48.38870108127594, 45.532808527350426, 45.56102581322193, 45.56371986865997, 42.97385483980179, 38.261864483356476, 37.70975410938263, 37.13042199611664, 36.68174207210541, 36.44921734929085, 35.115713104605675, 36.92114822566509, 38.37066784501076, 37.37224481999874, 37.587339878082275, 37.35100015997887, 36.25874117016792, 37.49729610979557, 35.33606328070164, 37.4797448515892, 38.062173798680305, 38.735866248607635, 37.466464564204216, 38.50634716451168, 37.758277505636215, 38.580424189567566, 38.549706637859344, 37.49938979744911, 36.13653972744942, 38.328235521912575, 38.1806780397892, 38.91942299902439, 37.909714579582214, 40.27419090270996, 40.49814708530903, 43.18734258413315, 45.995764285326004, 46.98091082274914, 49.89337854087353, 53.661073967814445, 53.71399752795696, 52.24447958171368, 54.29989568889141, 52.81273528933525, 45.63382610678673, 42.578964829444885, 46.62260144948959, 52.99717739224434, 57.05668956041336, 53.72842155396938, 55.06922900676727, 55.86663141846657, 48.82738374173641, 51.22046872973442, 25.567891336977482, 6.097699524834752, 0.44142744911368936, 0.0654747913358733, 0.041121731119346805, 3.6409323289990425, 48.58594469726086, 49.418601617217064, 36.55850328505039, 14.896926786750555, 29.372007809579372, 41.92736819386482, 46.33563704788685, 46.24072194099426, 5.865727197378874, 0.07291698144399561, 0.03204650813131593, 0.045968411868670955, 0.03709505304868799, 0.03066141936869826, 0.018743191903922707, 0.026212526063318364, 0.09817044861847535, 0.026128503814106807, 0.044722190068569034, 0.047412727726623416, 0.07956706991535611, 0.04141339515626896, 0.07245497225085273, 0.0478136952733621, 0.057633489050203934, 0.043566799722611904, 0.013286461125971982, 0.05891147106012795, 0.06530722923344001, 0.0404519762378186, 0.017770952472346835, 0.07875770592363551, 0.02540688950830372, 0.07807359419530258, 0.03817777971562464, 0.78754544374533, 27.781027480959892, 56.794910207390785, 45.38019731640816, 45.94222895801067, 22.597902305424213, 28.652630411088467, 33.6080452054739, 40.807906463742256, 38.74128095805645, 1.0824749898165464, 0.12288568803342059, 0.07320835604332387, 4.640682907775044, 7.269404651597142, 9.255424607545137, 7.043310608714819, 32.58001036942005, 51.16200126707554, 53.237176313996315, 55.19047290086746, 56.62387378513813, 54.500756710767746, 53.07032346725464, 51.0630963742733, 47.8303362429142, 49.423643946647644, 49.19019587337971, 47.62099027633667, 45.963264629244804, 47.27498844265938, 47.247690707445145, 48.59496161341667, 51.60054333508015, 50.647041499614716, 46.61396451294422, 39.72931534051895, 37.17451483011246, 37.1427371352911, 37.03804135322571, 35.910075679421425, 35.16886085271835, 34.938456416130066, 36.507817804813385, 36.12845756113529, 38.00001673400402, 39.090474620461464, 39.003463089466095, 38.63689675927162, 36.83555781841278, 37.03838713467121, 38.96043799817562, 37.32622928917408, 37.944410517811775, 36.026680022478104, 36.87034115195274, 39.93112251162529, 36.903699561953545, 36.03524476289749, 35.95407351851463, 38.82048390805721, 43.49919945001602, 49.84469935297966, 52.48658739030361, 50.2295047044754, 50.49993619322777, 51.10629245638847, 49.11320820450783, 51.65565937757492, 47.17883080244064, 44.05525781214237, 47.24755011498928, 50.57426020503044, 49.45462368428707, 49.23942223191261, 36.85167655348778, 47.111927792429924, 49.71972405910492, 45.51939904689789, 51.882708594202995, 53.26189398765564, 49.5447738468647, 49.68338280916214, 47.74120822548866, 47.03776337206364, 45.19717253744602, 41.024437844753265, 39.48549762368202, 38.61716441810131, 37.66120031476021, 38.5398955643177, 37.87089966237545, 38.494799584150314, 38.13788093626499, 39.57833044230938, 38.73556986451149, 37.70464338362217, 37.51737803220749, 38.81152018904686, 38.5379196703434, 37.446261048316956, 40.13961732387543, 40.90711914002895, 39.951595813035965, 39.48790669441223, 40.49960620701313, 40.80298952758312, 39.82473962008953, 39.4677259773016, 38.41924823820591, 39.87982526421547, 41.52672529220581, 41.104271560907364, 39.67296056449413, 42.59611330926418, 44.29879434406757, 45.8151675760746, 47.28561647236347, 49.50874038040638, 52.703859731554985, 55.73667459189892, 56.86157003045082, 54.714191257953644, 56.70395828783512, 55.992324873805046, 46.9747057557106, 43.360943868756294, 50.002417489886284, 54.52443324029446, 57.74974197149277, 56.854567006230354, 57.01220154762268, 54.460744857788086, 52.713651806116104, 51.58234231173992, 27.45909735560417, 6.838452676311135, 0.9584529104176909, 0.09695865504909307, 0.07826825210941024, 3.9644863922148943, 54.5364785939455, 52.228315249085426, 37.70866356790066, 19.29257556796074, 33.674207255244255, 48.374212458729744, 53.31977628171444, 51.77716925740242, 7.33619081787765, 0.1164919522125274, 0.02104177725414047, 0.029259901311888825, 0.005834775702169281, 0.01410971162840724, 0.02280448559758952, 0.005291179895721143, 0.028815147052227985, 0.030420132316066884, 0.0021214757498455583, 0.054794020907138474, 0.012565207689476665, 0.037012025277363136, 0.1556052573141642, 0.11399915238143876, 0.10969080700306222, 0.10532662985497154, 0.0926451814302709, 0.24366666009882465, 0.16775958793004975, 0.15826017188373953, 0.17815643863286823, 0.09855377531494014, 0.13887558627175167, 0.1713617649511434, 0.11277176628937013, 1.290898199658841, 33.8844233751297, 65.39550930261612, 52.381082251667976, 52.69839562475681, 30.67853920161724, 39.149816036224365, 42.70940043032169, 49.989042207598686, 44.72644999623299, 1.4978665625676513, 0.2580077585298568, 1.6337608080357313, 15.30228903517127, 19.51117403805256, 8.352503757923841, 4.999603573232889, 36.15257106721401, 50.77182300388813, 52.98950560390949, 55.67998543381691, 58.027343675494194, 57.55869582295418, 55.08247509598732, 52.507436871528625, 49.3143580108881, 51.30762845277786, 50.51119118928909, 48.08217532932758, 48.43810223042965, 47.95249588787556, 49.09350246191025, 50.97484990954399, 53.56895171105862, 53.158189952373505, 47.53448411822319, 42.075670436024666, 39.36703138053417, 38.839479088783264, 38.81264492869377, 38.476184383034706, 36.85764983296394, 37.23941534757614, 37.633541598916054, 37.45471179485321, 39.44891318678856, 41.468375623226166, 41.87144659459591, 39.41946476697922, 38.23814995586872, 39.477001279592514, 41.696424186229706, 38.316015377640724, 41.32526010274887, 38.490023240447044, 38.411622047424316, 41.04626007378101, 37.941572070121765, 36.564491763710976, 37.766397669911385, 43.079591765999794, 44.6353954821825, 53.399230018258095, 54.65535521507263, 51.18371330201626, 52.25208297371864, 52.92383752763271, 50.915702283382416, 53.91136273741722, 48.13429333269596, 44.876496344804764, 48.30109678208828, 52.07063890993595, 50.82644507288933, 52.19694793224335, 39.54280234873295, 47.00628586113453, 50.59634082019329, 46.79612293839455, 53.13412584364414, 55.9885136783123, 50.4705485701561, 50.33895023167133, 48.64166110754013, 48.9491406083107, 46.90420813858509, 42.13832147419453, 39.98510241508484, 40.108531191945076, 40.05862466990948, 40.87009012699127, 39.50599752366543, 40.93043848872185, 41.651833578944206, 41.51080794632435, 41.478768065571785, 39.789473712444305, 39.39369075000286, 40.4747973382473, 38.98610182106495, 39.868631064891815, 41.84357888996601, 43.69824416935444, 42.15695187449455, 42.36830033361912, 42.09218055009842, 41.03838309645653, 41.77461639046669, 41.29465654492378, 41.13465093076229, 41.87466502189636, 43.89949657022953, 44.571760296821594, 41.05424724519253, 44.98508311808109, 45.27640588581562, 46.51225537061691, 50.411583334207535, 49.840758964419365, 55.4294078797102, 58.12027908861637, 60.37665121257305, 59.3165422976017, 59.10779669880867, 58.21202516555786, 49.34833198785782, 45.89272141456604, 51.91593401134014, 57.638339549303055, 60.943105816841125, 59.83342856168747, 60.810147151350975, 57.468842044472694, 55.70812292397022, 58.27792502939701, 27.470086365938187, 9.431753195822239, 1.3566566398367286, 0.36204302916303277, 0.45508970506489277, 4.623969504609704, 60.120461359620094, 61.83136135339737, 49.19701650738716, 26.59629475325346, 40.24710975587368, 55.359852612018585, 61.61610670387745, 62.22921900451183, 11.605394259095192, 0.29812110762577504, 0.14727841975400224, 0.09938607166986912, 0.21271372883347794, 0.1172888555447571, 0.1359837781637907, 0.11027526314137504, 0.20572495384840295, 0.08729169174330309, 0.13021616265177727, 0.18864196114009246, 0.1834195718402043, 0.1313502830453217], [0.028785548347514123, 0.02376893062319141, 0.04366654065961484, 0.02183332784625236, 0.023106192747945897, 0.0727428068057634, 0.051696808586711995, 0.09481874643824995, 0.04138023970881477, 0.033261381613556296, 0.0881477516668383, 0.08162665588315576, 0.023606038485013414, 0.26784587593283504, 25.14378659427166, 47.90460705757141, 42.2115283459425, 34.53921563923359, 24.15110696107149, 18.990297988057137, 36.67231097817421, 36.721297949552536, 32.49362200498581, 1.178558652754873, 0.09746491850819439, 0.3435170935699716, 2.239612410776317, 5.345472889021039, 4.340520389378071, 4.203245155513287, 17.970440313220024, 52.37259730696678, 50.896140933036804, 50.6463423371315, 49.69496838748455, 52.54738412797451, 52.06767126917839, 52.72499039769173, 48.278275206685066, 49.98089924454689, 48.97410526871681, 48.90787482261658, 48.17409999668598, 50.2891881018877, 48.54106530547142, 49.37071658670902, 46.68870270252228, 43.66757221519947, 37.562918588519096, 35.33178471028805, 34.624011889100075, 34.4989188015461, 34.368650391697884, 35.530099868774414, 36.27139449119568, 36.30336217582226, 36.30961284041405, 34.268594160676, 35.325024873018265, 36.888960152864456, 36.88517175614834, 37.92412340641022, 34.94444489479065, 35.27361363172531, 35.10291539132595, 36.511788591742516, 36.199574545025826, 35.24996370077133, 35.42964845895767, 35.455908849835396, 34.17410843074322, 35.61774976551533, 34.68338370323181, 35.70723496377468, 39.70887243747711, 46.087871342897415, 47.39546097815037, 50.63391700387001, 47.36308291554451, 50.37016935646534, 48.371632397174835, 48.203096240758896, 48.56452524662018, 52.20298960804939, 46.50443159043789, 46.158821135759354, 44.60167609155178, 45.939504504203796, 37.141464203596115, 42.37819500267506, 47.57109895348549, 44.827463775873184, 50.05038611590862, 50.12087233364582, 47.49331332743168, 45.00256597995758, 40.083653926849365, 38.78703810274601, 37.94013574719429, 37.65963859856129, 36.49736076593399, 36.677193716168404, 36.682418435812, 36.44804701209068, 35.47562979161739, 36.85608811676502, 38.89043815433979, 36.759147718548775, 36.440519616007805, 35.738340094685555, 37.37317956984043, 36.963914930820465, 38.064187690615654, 39.02422517538071, 38.09445686638355, 38.26916389167309, 35.73862507939339, 39.53369803726673, 37.23849959671497, 37.78674177825451, 38.42906691133976, 37.91937746107578, 39.68168489634991, 40.694497749209404, 38.043334409594536, 37.237618044018745, 36.53118275105953, 38.21633152663708, 38.400112465023994, 38.91767129302025, 39.96964484453201, 44.270368069410324, 46.27260982990265, 49.29346673190594, 52.85994775593281, 54.743347093462944, 55.009591206908226, 53.454600647091866, 48.4512647241354, 44.05015468597412, 45.983509942889214, 52.07308977842331, 54.129965007305145, 55.47920040786266, 53.55819068849087, 55.62174215912819, 56.73585757613182, 53.01768869161606, 27.83980842679739, 3.4646733244881034, 0.8725287148263305, 0.046209264764911495, 0.025069023067771923, 2.5855617597699165, 44.420254826545715, 52.459707632660866, 43.47152553498745, 26.83088656514883, 36.490855515003204, 43.960916474461555, 48.12649615108967, 47.753679156303406, 8.779193311929703, 0.11296234981273301, 0.02617668404127471, 0.054955497398623265, 0.006119036352174589, 0.021679445380868856, 0.0255589184598648, 0.0390121837699553, 0.03209375325241126, 0.033632106642471626, 0.018491329246899113, 0.016492636495968327, 0.008417289591307053, 0.016100045941129792, 0.04879939726379234, 0.08595336199505255, 0.037161690488574095, 0.03914958499080967, 0.041312607791041955, 0.016118007770273834, 0.034698776944424026, 0.031230323802446947, 0.042446112202014774, 0.050558149960124865, 0.030793621845077723, 0.016484621301060542, 0.03921841547708027, 0.6719273852650076, 31.684020347893238, 54.99589294195175, 49.13533441722393, 42.35639177262783, 29.786816351115704, 24.55243192613125, 35.85608817636967, 40.842944383621216, 37.35477335751057, 1.6316946689039469, 0.0823031531763263, 1.0534145054407418, 6.101795230060816, 7.73747113533318, 8.121347911655903, 6.3023527432233095, 22.37992700189352, 53.31092655658722, 51.99802100658417, 50.8981092274189, 52.00288474559784, 53.289210721850395, 52.201146706938744, 52.260290533304214, 48.90525296330452, 49.888161420822144, 50.523874908685684, 49.08073514699936, 49.873182624578476, 51.26693643629551, 51.70364700257778, 51.55621871352196, 48.42012159526348, 47.082790955901146, 40.79769641160965, 38.29190567135811, 37.08988957107067, 36.72079257667065, 35.99084794521332, 35.67703038454056, 37.517674416303635, 36.85933314263821, 38.20745140314102, 35.549231842160225, 36.94127194583416, 37.805603966116905, 39.28382724523544, 40.108333602547646, 38.79849448800087, 36.6651825606823, 36.589505821466446, 37.22381338477135, 37.91903167963028, 36.52123488485813, 36.32450424134731, 37.43282876908779, 36.22001364827156, 36.8913958221674, 36.032425314188, 36.30756475031376, 41.56661935150623, 48.32530528306961, 49.665155187249184, 53.161928951740265, 50.77747330069542, 53.252611085772514, 50.01922778785229, 52.073720544576645, 49.94417801499367, 52.44366489350796, 49.080567955970764, 46.983452886343, 47.038508132100105, 47.26409822702408, 37.48112417757511, 44.239274337887764, 49.77970004081726, 46.46100752055645, 52.016309425234795, 52.23089151084423, 48.80364641547203, 47.301123440265656, 41.575085297226906, 40.74647516012192, 40.22016540169716, 41.50069668889046, 37.588035240769386, 38.039356023073196, 37.35792338848114, 38.57226222753525, 38.254428282380104, 37.86372944712639, 39.95405048131943, 38.347033113241196, 38.04034397006035, 36.84330940246582, 37.764649763703346, 39.19641673564911, 39.45548303425312, 39.13516782224178, 39.923006147146225, 38.961186558008194, 37.50286281108856, 40.858515948057175, 38.45923349261284, 40.36977857351303, 40.498272478580475, 40.52526243031025, 41.021531000733376, 41.56966298818588, 40.809775963425636, 39.71447713673115, 39.69856359064579, 40.48295930027962, 41.006890386343, 40.8678862452507, 41.91617779433727, 45.59770904481411, 48.22729714214802, 51.555394157767296, 54.375154450535774, 56.37109234929085, 56.46841272711754, 56.363758742809296, 50.527845695614815, 46.303338780999184, 48.22362653911114, 53.09306524693966, 57.94770374894142, 57.51186713576317, 54.733881801366806, 56.899792179465294, 56.444888189435005, 56.24521270394325, 29.852708615362644, 5.4753028973937035, 1.8805548339150846, 0.3568411379819736, 0.05836491640366148, 2.58450232911855, 48.11753623187542, 55.89280441403389, 46.988882794976234, 30.903572626411915, 41.79736576974392, 52.188576981425285, 54.24072906374931, 55.352374613285065, 11.709662564098835, 0.19645218970254064, 0.0691402809752617, 0.06354119977913797, 0.06180154254252557, 0.04242847877321765, 0.05006947540096007, 0.04362296545878053, 0.031740821214043535, 0.03932393774448428, 0.021535231244342867, 0.04255196101439651, 0.04849027049203869, 0.013376054121181369, 0.15381172386696562, 0.23509589344030246, 0.14887277560774237, 0.17918875120813027, 0.10172966271056794, 0.16808724612928927, 0.1380933032487519, 0.1600442800554447, 0.17046528024366125, 0.06718734162859619, 0.19337528996402398, 0.19982531026471406, 0.2143142741988413, 1.1016120691783726, 40.35884276032448, 62.59049981832504, 55.51783673465252, 47.81568802893162, 34.813583716750145, 29.221934862434864, 50.28063856065273, 48.82663898169994, 46.67603798210621, 1.862803848925978, 0.2127861327608116, 1.1383298551663756, 6.142277307808399, 11.85975356027484, 11.854861322790384, 6.66407385841012, 19.690820798277855, 56.596864834427834, 52.89464749395847, 52.76487685739994, 52.82862223684788, 56.10300913453102, 53.7451558560133, 54.65826965868473, 49.225807562470436, 50.851250141859055, 51.81833624839783, 50.05050390958786, 50.878768265247345, 55.24097979068756, 52.939496487379074, 53.89768347144127, 50.07369786500931, 49.186931848526, 42.40710385143757, 39.4628394395113, 38.79455029964447, 38.144272193312645, 38.26012797653675, 38.41647058725357, 40.34710519015789, 39.601437002420425, 40.91827914118767, 37.30584338307381, 37.34231762588024, 40.6460427492857, 41.22361175715923, 43.430145755410194, 39.54051487147808, 38.99734541773796, 38.154493644833565, 40.09515590965748, 40.531999468803406, 38.80127593874931, 39.31415721774101, 39.548194259405136, 36.68090611696243, 37.31301359832287, 38.036654368042946, 37.9601264744997, 44.7450727969408, 51.10624685883522, 53.04127022624016, 56.06370784342289, 52.41639755666256, 55.93526713550091, 52.49409198760986, 52.92959801852703, 52.75440461933613, 54.74833242595196, 50.086936354637146, 49.1281908005476, 48.60281199216843, 49.91109699010849, 40.35674527287483, 45.534024462103844, 49.32679854333401, 48.53815846145153, 54.582296535372734, 52.508603408932686, 52.22332611680031, 48.9919301122427, 43.130615428090096, 42.80211545526981, 41.55379503965378, 43.10020565986633, 39.283907040953636, 40.0926860421896, 39.07663196325302, 41.47328495979309, 39.84485574066639, 40.12911468744278, 41.57412774860859, 39.76469524204731, 40.26525758206844, 38.527918606996536, 40.00946290791035, 41.24145179986954, 41.43912099301815, 42.90667064487934, 42.584675922989845, 41.27677470445633, 40.08613519370556, 43.889639899134636, 41.01238489151001, 42.75206834077835, 43.62760215997696, 42.12212674319744, 42.697997242212296, 44.5100212097168, 42.122062146663666, 41.54661722481251, 40.99658153951168, 42.24890314042568, 43.496364802122116, 43.23460444808006, 44.596139788627625, 47.95298986136913, 51.253941133618355, 53.84578965604305, 57.383605018258095, 59.65581089258194, 59.4447436183691, 58.29278603196144, 52.89901725947857, 48.105673268437386, 50.07350407540798, 57.56252221763134, 59.875948280096054, 59.00005728006363, 56.913574039936066, 58.10541428625584, 58.53254176676273, 58.61033879220486, 33.77275116741657, 5.19909524358809, 2.914929511025548, 0.45748856384307146, 0.14243721234379336, 3.2375834975391626, 52.4442158639431, 66.63311049342155, 55.3072976320982, 37.679161950945854, 50.8493160456419, 59.203961938619614, 63.08109529316425, 64.93587076663971, 16.322803124785423, 0.3643178305355832, 0.1207882673770655, 0.2333029537112452, 0.0880995491752401, 0.17495567444711924, 0.11624828286585398, 0.10748049826361239, 0.24181681248592213, 0.10921484543359838, 0.16718713974114507, 0.12091231736121699, 0.11859721736982465, 0.1093643881904427], [0.07804288412444293, 0.05036979287979193, 0.0365001214959193, 0.03667076722194906, 0.04119667690247297, 0.01852687812061049, 0.04992159876564983, 0.02328552902326919, 0.015262970155163202, 0.025286398122261744, 0.046305580690386705, 0.06281181704252958, 0.11623381840763614, 0.9144137485418469, 17.5515640899539, 49.20522406697273, 36.90980203449726, 27.696358524262905, 11.194566003978252, 26.757664494216442, 46.22285149991512, 38.640312775969505, 33.60297627747059, 1.6137067903764546, 0.07685383738134988, 0.6661784718744457, 4.833852667361498, 5.613700496032834, 11.899090949445963, 6.802856661379337, 19.77727945894003, 41.327741369605064, 50.77152281999588, 49.586461409926414, 54.00299862027168, 50.564992502331734, 53.71465489268303, 54.70742002129555, 53.494156524538994, 51.92202128469944, 53.80151443183422, 49.119645059108734, 50.7332094758749, 47.92475737631321, 46.99729174375534, 43.05634081363678, 41.365610137581825, 37.54015401005745, 34.93283271789551, 34.19623464345932, 35.09808585047722, 34.943833127617836, 39.71725858747959, 41.44416332244873, 41.89145252108574, 41.14784762263298, 39.620937556028366, 37.16315723955631, 36.5850942581892, 37.3431421816349, 39.1196608543396, 39.54962678253651, 37.34975002706051, 35.40784142911434, 35.996239855885506, 34.86124075949192, 34.76958587765694, 34.38183568418026, 35.14855474233627, 35.061345621943474, 35.47642394900322, 35.69667153060436, 33.92057083547115, 35.61905309557915, 34.9266504496336, 37.296742871403694, 41.92771017551422, 41.713625863194466, 45.038937628269196, 42.17174828052521, 43.327433466911316, 45.04380516707897, 46.22191295027733, 47.147395089268684, 47.698718905448914, 48.11709925532341, 45.44247977435589, 44.62559200823307, 37.7872509509325, 39.67471607029438, 47.17118181288242, 50.587631687521935, 49.770648926496506, 48.51312920451164, 45.761054679751396, 44.93685230612755, 44.417682364583015, 44.73610147833824, 44.27526980638504, 44.010944589972496, 41.9129441678524, 38.62373806536198, 36.923929676413536, 36.27273961901665, 36.59175530076027, 36.58618099987507, 37.63508431613445, 35.908422768116, 38.59552837908268, 37.94727176427841, 36.522352024912834, 37.27321453392506, 37.6336669921875, 36.24746337532997, 37.030346766114235, 36.972232684493065, 37.87996217608452, 36.88038021326065, 38.173523023724556, 38.65958534181118, 38.39850515127182, 38.83013918995857, 38.29701639711857, 39.09140557050705, 38.28362591564655, 37.46685214340687, 37.18894645571709, 37.6337505877018, 38.95679019391537, 39.24471214413643, 37.403608337044716, 38.86021077632904, 42.70439609885216, 44.57100793719292, 50.581647008657455, 52.64373555779457, 54.50004234910011, 54.14915397763252, 50.33952780067921, 41.83948650956154, 43.64617936313152, 53.528552278876305, 57.31597624719143, 55.6527104973793, 56.92922540009022, 57.79388040304184, 57.80855141580105, 56.453506126999855, 29.194906912744045, 3.27051751781255, 1.6181682259775698, 0.35063316172454506, 0.07075782152242027, 1.9979304168373346, 43.061721324920654, 49.988278448581696, 33.720640763640404, 18.66010330617428, 27.414510548114777, 45.79585701227188, 46.90734677016735, 45.3838375210762, 11.295437291264534, 0.15232060075504705, 0.0466732146742288, 0.08787960628978908, 0.07844121704692952, 0.029206995459389873, 0.044468312480603345, 0.11232603239477612, 0.07307705527637154, 0.03686411895614583, 0.06858418972115032, 0.03557016221748199, 0.018015337991528213, 0.02612234398839064, 0.020425141592568252, 0.06238872607355006, 0.07062456890707836, 0.044372018819558434, 0.07989125486346893, 0.04947272187564522, 0.009108851554628927, 0.014518529242195655, 0.05667851939506363, 0.02473138112691231, 0.026965544348058756, 0.044086399575462565, 0.06192183725943323, 1.0991926677525043, 24.91176914423704, 57.318415716290474, 44.84082005918026, 33.75208407640457, 18.938221782445908, 24.25171796232462, 43.02672140300274, 44.512867256999016, 39.276695027947426, 2.212957078590989, 0.06330983524094336, 1.1154490266926587, 5.666520511731505, 6.745434617623687, 11.429265160113573, 6.613891376182437, 20.190642178058624, 43.3282770216465, 51.7476562410593, 50.167241245508194, 55.19289717078209, 53.01976338028908, 55.59361606836319, 54.568260088562965, 53.65911327302456, 53.71483728289604, 54.23989690840244, 51.39338605105877, 52.13411830365658, 49.87357780337334, 48.84027644991875, 46.19019225239754, 43.292710930109024, 41.13833673298359, 35.74964448809624, 35.914681032299995, 37.4898637086153, 35.6765516102314, 40.94004437327385, 40.38340464234352, 43.126937225461006, 43.86606216430664, 41.612893268465996, 38.60128127038479, 39.028442949056625, 38.65544356405735, 40.97512029111385, 41.07298023998737, 38.8814440369606, 37.39655591547489, 38.819560557603836, 36.425084844231606, 36.36962302029133, 35.992937833070755, 36.71614542603493, 37.97250621020794, 37.45148956775665, 38.34992855787277, 35.47770068049431, 37.509881034493446, 37.96676851809025, 40.491790026426315, 43.57724726200104, 45.72575457394123, 49.42973881959915, 45.17396338284016, 45.479615181684494, 48.0889617651701, 48.62576276063919, 51.14537715911865, 49.8846086114645, 50.708252415061, 46.74523986876011, 47.59483627974987, 40.05542904138565, 41.67702242732048, 47.22999885678291, 51.02376848459244, 51.67345002293587, 49.94625650346279, 46.98827862739563, 46.02987505495548, 46.16351768374443, 47.32163093984127, 46.41573674976826, 45.30672445893288, 43.72303783893585, 39.64815929532051, 38.28034669160843, 36.92178279161453, 37.89121717214584, 39.00006227195263, 38.35229963064194, 37.81988739967346, 39.1968385130167, 38.97003248333931, 39.52580966055393, 39.16723810136318, 40.419654697179794, 38.72503682971001, 38.88497784733772, 38.54877568781376, 39.343598037958145, 39.13978077471256, 38.86646144092083, 38.280342891812325, 39.70214679837227, 39.53381583094597, 39.889845326542854, 41.02887220680714, 39.60432484745979, 41.15205779671669, 38.691214844584465, 40.46786271035671, 41.197621151804924, 40.77607937157154, 39.95227597653866, 42.140411362051964, 45.07973983883858, 47.357546612620354, 52.65517674386501, 53.60931694507599, 56.50358743965626, 56.30820192396641, 51.50641858577728, 45.67403934895992, 45.51585003733635, 55.04601985216141, 59.26181383430958, 56.66321687400341, 57.00325682759285, 59.28251512348652, 59.57301713526249, 56.92751169204712, 30.763430446386337, 4.826198453083634, 1.904759060125798, 0.6558232556562871, 0.12601758091477677, 1.8668791302479804, 46.31017081439495, 56.429768800735474, 40.72383597493172, 24.415312483906746, 35.47518901526928, 52.565463557839394, 54.49841223657131, 53.4746977686882, 14.168412778526545, 0.08561603361158632, 0.03448590672633145, 0.019999189644295257, 0.02386652118730126, 0.011304990839562379, 0.0760424992768094, 0.01345112328635878, 0.02828817396220984, 0.04627230649930425, 0.04097312717931345, 0.06740703960531391, 0.028974231972824782, 0.032766487856861204, 0.21208052843576297, 0.27709362970199436, 0.12444558597053401, 0.1013132807565853, 0.22251806367421523, 0.15250214491970837, 0.11519199892063625, 0.08863579540047795, 0.17018264072248712, 0.06705050443997607, 0.15818594227312133, 0.26657291455194354, 0.23634785204194486, 1.6711528203450143, 32.84990228712559, 66.13147661089897, 50.812568217515945, 39.160447865724564, 18.450616747140884, 35.780787616968155, 58.08700807392597, 49.40168112516403, 44.28917706012726, 2.6902147941291332, 0.1298107422189787, 2.0053053461015224, 13.126367144286633, 12.272238526493311, 18.543736450374126, 10.647973883897066, 24.085851162672043, 43.81585165858269, 52.15229652822018, 51.06966242194176, 57.75725416839123, 55.90174153447151, 59.0255843102932, 60.08540444076061, 57.28560067713261, 55.88590778410435, 58.49126078188419, 54.64003823697567, 54.614017233252525, 53.07426765561104, 51.20205491781235, 46.97740361094475, 45.49861416220665, 42.46889613568783, 38.83010499179363, 37.06946186721325, 38.380440920591354, 37.574416771531105, 45.584652945399284, 44.28521767258644, 46.13441504538059, 46.18781737983227, 44.038607105612755, 41.8531733751297, 41.79849050939083, 41.94834686815739, 43.92023205757141, 45.42210906744003, 40.46741433441639, 40.313298404216766, 40.019957944750786, 39.03788544237614, 37.99274392426014, 38.773047253489494, 38.90937253832817, 39.99395594000816, 39.819226115942, 39.70660015940666, 37.40092188119888, 39.96861129999161, 39.50824320316315, 40.81596963107586, 45.59393584728241, 45.67501209676266, 50.49046330153942, 46.25003904104233, 47.85852313041687, 50.56528128683567, 51.03196084499359, 53.42347651720047, 51.44000954926014, 52.041589468717575, 50.25121293962002, 48.72680313885212, 43.41185353696346, 42.484441101551056, 48.69184881448746, 51.79276742041111, 53.891729190945625, 51.554364413022995, 49.16508302092552, 48.49506497383118, 49.117528572678566, 48.881770223379135, 48.043854385614395, 49.59398880600929, 47.08397649228573, 40.31682841479778, 40.326039120554924, 38.5627855360508, 40.12275382876396, 40.48308469355106, 41.24507300555706, 38.753531500697136, 41.35978125035763, 41.1565263569355, 40.69426976144314, 41.02874681353569, 42.113087028265, 39.60969775915146, 41.11386604607105, 40.390859842300415, 40.5822441726923, 41.744066029787064, 41.32901810109615, 40.795264542102814, 41.775889322161674, 42.2418013215065, 39.78861875832081, 42.879901081323624, 42.884772419929504, 42.26971082389355, 40.66813476383686, 42.08210729062557, 43.76977913081646, 43.20671774446964, 41.16666041314602, 43.33471767604351, 48.53439286351204, 48.35658520460129, 54.47989962995052, 56.39791131019592, 60.11412709951401, 57.560683116316795, 54.94993440806866, 47.48400382697582, 47.208252623677254, 57.467101737856865, 62.95604780316353, 59.54650595784187, 59.75335165858269, 62.96875052154064, 61.012197509408, 58.40125121176243, 30.975242480635643, 5.930684711784124, 3.5401959344744682, 1.5769654931500554, 0.32154299144167453, 2.68020898103714, 51.66213043034077, 63.127205818891525, 45.364450961351395, 29.87215217202902, 39.22852501273155, 58.77520814538002, 61.95396177470684, 62.73280218243599, 19.62830275297165, 0.3870667051523924, 0.13765249721473083, 0.23818880872568116, 0.1169192511588335, 0.09770573058631271, 0.1613482483662665, 0.15089302032720298, 0.1342302464763634, 0.12597247317899019, 0.19225792726501822, 0.1323167819646187, 0.0930368943954818, 0.18030473351245746], [0.05178927647648379, 0.01909650985908229, 0.06085870700189844, 0.01025121442580712, 0.008328591811732622, 0.013048785549472086, 0.029867315788578708, 0.13240680447779596, 0.015351665151683846, 0.058154421058134176, 0.05348319886252284, 0.01214582653119578, 0.09206194983562455, 1.245849123224616, 18.15951246768236, 45.13117767870426, 37.384400367736816, 22.779528759419918, 20.09751297533512, 61.89322963356972, 65.77637046575546, 34.231302961707115, 33.89581136405468, 2.3103508399799466, 0.09763958296389319, 1.1501557705923915, 8.954688794910908, 5.92137711122632, 7.586452513933182, 4.869126649573445, 20.01921057701111, 46.29345931112766, 53.97348180413246, 51.841727793216705, 48.55361983180046, 47.614777609705925, 46.67367830872536, 44.859192073345184, 48.86709161102772, 47.80670151114464, 46.55942223966122, 49.86000493168831, 47.548182383179665, 45.64502790570259, 40.29602833092213, 37.13282346725464, 36.78253546357155, 34.98638704419136, 33.43786373734474, 34.38202187418938, 37.08115763962269, 41.56769469380379, 46.26397289335728, 45.108508095145226, 43.52589301764965, 45.33097095787525, 44.528336226940155, 42.9537121206522, 42.47155599296093, 40.07967174053192, 40.61170779168606, 39.941837936639786, 38.06886903941631, 35.41341952979565, 34.57086034119129, 37.63699181377888, 35.47096364200115, 35.056622475385666, 34.06521387398243, 35.71203030645847, 36.24154709279537, 35.8939341455698, 34.76774677634239, 33.24348896741867, 35.09625054895878, 36.37167491018772, 35.70070691406727, 37.02313855290413, 36.24000817537308, 36.97351321578026, 39.89143364131451, 41.942213997244835, 41.69639378786087, 45.86866870522499, 45.91869302093983, 48.149492517113686, 46.26176901161671, 47.01981693506241, 37.412104681134224, 42.31335528194904, 42.38231398165226, 45.156374126672745, 50.90212941169739, 49.44839581847191, 51.95341520011425, 51.233832612633705, 48.86348940432072, 48.667218536138535, 49.87961947917938, 50.90065509080887, 49.135106429457664, 44.61976692080498, 40.78413873910904, 36.487443298101425, 36.720705181360245, 36.33422411978245, 37.48949512839317, 34.82412815093994, 39.72622990608215, 37.559745758771896, 35.9175992757082, 36.19505278766155, 38.18474382162094, 36.09952971339226, 38.26893970370293, 39.71783235669136, 38.882485181093216, 40.313879773020744, 40.76160974800587, 38.887535110116005, 36.833065152168274, 37.066809609532356, 37.058773040771484, 37.60396018624306, 38.20947289466858, 38.01431156694889, 37.23674029111862, 39.80124168097973, 39.84980687499046, 39.972502291202545, 39.367943331599236, 39.507521241903305, 39.823500886559486, 39.65402618050575, 41.08136638998985, 48.446340188384056, 54.361855164170265, 51.55749164521694, 47.59753793478012, 40.95630370080471, 48.30135136842728, 55.86851231753826, 58.082577511668205, 53.41823659837246, 55.48989683389664, 57.22812116146088, 56.76016487181187, 56.679419204592705, 28.356542699038982, 3.6491686245426536, 0.9330010449048132, 0.34185299067758024, 0.0728962681023404, 1.5944242500700057, 40.42525179684162, 53.36521044373512, 47.552126571536064, 28.48232164978981, 28.79437230527401, 42.62689545750618, 44.471593871712685, 42.02843517065048, 12.016804832965136, 0.11379192990716547, 0.06753773923264816, 0.02116853793268092, 0.027661031344905496, 0.031484568753512576, 0.05074752749351319, 0.030258841361501254, 0.014995363762864145, 0.06228415004443377, 0.06034089201421011, 0.032424777091364376, 0.057192671883967705, 0.03263575112214312, 0.05792345356894657, 0.03679440160340164, 0.025590290897525847, 0.019601060812419746, 0.04590467251546215, 0.028946035927219782, 0.04736045826575719, 0.008469108197459718, 0.04516586821409874, 0.021901744585193228, 0.09001798607641831, 0.04542949391179718, 0.022712535355822183, 1.9509878545068204, 25.029475428164005, 54.08202677965164, 44.495870769023895, 28.67494471371174, 18.8804192841053, 56.34197071194649, 73.26543420553207, 41.41661860048771, 38.711023181676865, 2.6766678085550666, 0.14985530491685495, 1.1699517583474517, 8.7394236959517, 7.321387762203813, 8.193948715925217, 6.232890570536256, 20.44152371585369, 48.57211723923683, 52.89351135492325, 53.96248899400234, 50.10405443608761, 50.725666880607605, 49.610438123345375, 49.09109719097614, 51.93649850785732, 50.581244230270386, 49.57587517797947, 50.93579940497875, 49.012103229761124, 47.018312215805054, 44.12979081273079, 38.682228326797485, 36.96765013039112, 36.04705832898617, 36.091356351971626, 35.8130668848753, 38.11856657266617, 43.65008935332298, 47.620515301823616, 46.95491261780262, 46.42027370631695, 47.32604630291462, 47.450922802090645, 45.251954197883606, 45.67568086087704, 42.72006265819073, 42.106068804860115, 42.040469124913216, 40.04393085837364, 36.34440377354622, 37.53081791102886, 38.69740091264248, 36.76870800554752, 36.898759827017784, 35.59128798544407, 37.01165936887264, 37.27709412574768, 37.65893563628197, 36.12815357744694, 34.8367852717638, 36.79426543414593, 37.07899935543537, 36.41639471054077, 38.463508263230324, 37.72008575499058, 38.93350124359131, 42.05912992358208, 45.3156615793705, 46.306367218494415, 48.67399737238884, 48.54008115828037, 50.86542338132858, 48.401320204138756, 50.96783168613911, 39.02182750403881, 42.28420704603195, 44.177250266075134, 47.42671050131321, 51.422272101044655, 51.5939012914896, 53.95204335451126, 51.806328892707825, 50.591378286480904, 50.68179823458195, 52.675543650984764, 51.153105944395065, 50.88030718266964, 45.76150685548782, 42.04080730676651, 37.99913138151169, 38.028070628643036, 38.46961073577404, 39.139472991228104, 36.99231840670109, 39.462467059493065, 38.76854829490185, 38.09140183031559, 39.198221638798714, 39.726112112402916, 38.30135956406593, 39.7885237634182, 40.79469457268715, 40.8920643478632, 42.377602234482765, 41.826191022992134, 39.39941704273224, 39.6711290627718, 38.17742541432381, 39.71223525702953, 39.70045208930969, 39.19575937092304, 39.819400906562805, 38.846888691186905, 42.284218445420265, 41.23966969549656, 42.37241551280022, 41.18380129337311, 40.945493280887604, 41.21451884508133, 41.45495094358921, 45.688277184963226, 52.792972549796104, 56.49173207581043, 54.20515537261963, 50.111650228500366, 43.661762326955795, 50.81255301833153, 56.109290197491646, 58.68980012834072, 55.39456754922867, 58.117144256830215, 60.71143984794617, 58.03878106176853, 60.1306714117527, 30.34766435623169, 3.8307026959955692, 1.6781931300647557, 0.5133056093472987, 0.09073778026504442, 1.6079064016230404, 44.33263912796974, 58.36758501827717, 48.0748151242733, 28.14670655876398, 34.658039063215256, 47.411218732595444, 50.35800240933895, 49.000639244914055, 14.983403496444225, 0.17657331889495254, 0.12467448657844216, 0.01732507942506345, 0.06256967652007006, 0.002569054113337188, 0.07493370096199214, 0.027315494808135554, 0.011631427278189221, 0.048258924507535994, 0.13229015370598063, 0.05132173086167313, 0.05161321307241451, 0.02209739512181841, 0.1378569143707864, 0.10422517138067633, 0.17362273269100115, 0.09952981083188206, 0.16199330828385428, 0.09410059239598922, 0.19251396821346134, 0.2568076166789979, 0.18364803458098322, 0.12982794520212337, 0.19565141235943884, 0.24164003290934488, 0.20615915476810187, 2.2759512858465314, 34.86140035092831, 62.78882257640362, 52.517084553837776, 34.095840230584145, 28.70173517614603, 68.70675042271614, 72.72671431303024, 44.50216323137283, 45.003462731838226, 3.720533545129001, 0.25357529637403786, 3.0551555240526795, 12.528936602175236, 12.985534351319075, 18.29831901937723, 9.36569944024086, 23.20393368601799, 50.85929051041603, 55.25874383747578, 57.16591089963913, 53.01394209265709, 51.69940643012524, 51.0444887727499, 50.24367414414883, 52.91601374745369, 53.326357528567314, 52.34547816216946, 54.39484499394894, 51.440408527851105, 49.77710098028183, 44.98207747936249, 40.902977362275124, 40.07259652018547, 39.0063813328743, 37.76693344116211, 37.43028670549393, 40.56161507964134, 45.83348259329796, 51.18148662149906, 50.10947674512863, 47.32120916247368, 51.16108551621437, 48.64294923841953, 47.381325736641884, 48.626708909869194, 43.480903431773186, 46.896338760852814, 44.73841555416584, 42.58075453341007, 39.14428733289242, 38.04619565606117, 41.410459131002426, 38.38286519050598, 38.940511867403984, 36.95006847381592, 39.27410736680031, 39.71790835261345, 39.87990885972977, 38.31767588853836, 35.85529401898384, 39.87123392522335, 39.22655291855335, 37.89397582411766, 40.883735194802284, 39.278005957603455, 40.664802342653275, 43.73438403010368, 46.92624315619469, 46.47709585726261, 50.698851719498634, 50.0580845028162, 53.53033438324928, 51.81932419538498, 51.57119370996952, 42.260576114058495, 44.750707894563675, 44.85786974430084, 51.26869574189186, 52.87382461130619, 52.187547236680984, 55.66851004958153, 55.31057685613632, 51.22521087527275, 51.93385384976864, 54.92327883839607, 55.41544362902641, 53.46372775733471, 47.901145443320274, 44.567344933748245, 40.49095407128334, 39.50349345803261, 40.414106994867325, 41.46043784916401, 38.32939825952053, 41.822907999157906, 40.492500588297844, 39.494822323322296, 42.29349374771118, 42.359131425619125, 40.64470902085304, 42.845892906188965, 43.70480641722679, 42.70699895918369, 44.76258225739002, 45.40389284491539, 43.27820710837841, 40.9183057397604, 40.23279592394829, 41.477867513895035, 41.01772740483284, 41.52392864227295, 42.313169091939926, 40.876010209321976, 44.660626128315926, 43.65924306213856, 45.08729763329029, 43.26583497226238, 43.77083547413349, 44.11761246621609, 43.89808304607868, 45.40374085307121, 54.57007259130478, 60.06996966898441, 56.218743324279785, 53.380063846707344, 45.61933368444443, 52.5812479108572, 61.13433055579662, 63.59983205795288, 56.286402493715286, 58.94862703979015, 61.468070447444916, 59.45954002439976, 61.96814641356468, 32.265296056866646, 5.645206980407238, 3.469014116562903, 1.0641339677385986, 0.2792344585759565, 2.0803377823904157, 48.70761796832085, 67.9054494202137, 59.90449234843254, 41.679298505187035, 43.10989893972874, 54.69826631247997, 59.34245690703392, 59.96197946369648, 20.938679538667202, 0.5204780213534832, 0.4309492144966498, 0.07220403727842495, 0.07849703397369012, 0.11643993508187123, 0.16103889152873307, 0.08906345057766885, 0.12298978166654706, 0.18828010477591306, 0.25861133239232004, 0.1298537867842242, 0.15517411404289305, 0.1106955784780439], [0.020018444665765855, 0.011557123452803353, 0.043320369586581364, 0.07187849420006387, 0.024395078762609046, 0.02414553160633659, 0.06312846177024767, 0.06718410586472601, 0.1614184258505702, 0.0401611619599862, 0.011844924611068564, 0.01614822987903608, 0.11701735566020943, 1.7614075960591435, 19.701969400048256, 43.13812002539635, 40.53771436214447, 21.08571644872427, 33.31281244754791, 48.97487662732601, 32.49935209751129, 32.645879834890366, 44.10938210785389, 3.25553135946393, 0.10514193898416124, 0.2521898550912738, 3.142352532595396, 5.6227910332381725, 8.577862065285444, 5.9328805189579725, 26.031373366713524, 47.60757319629192, 50.18869869410992, 51.59387469291687, 50.55789828300476, 48.48200507462025, 41.526231318712234, 37.38471955060959, 37.2878285497427, 38.01115773618221, 40.40647320449352, 39.1532738506794, 38.31034988164902, 39.37467657029629, 35.04872269928455, 35.035818591713905, 36.51368089020252, 35.652502700686455, 35.16960181295872, 37.16719262301922, 43.77947241067886, 47.19398818910122, 47.18749053776264, 44.94290918111801, 43.130820617079735, 42.16723792254925, 44.57226186990738, 43.465803042054176, 43.57419602572918, 45.37175036966801, 41.878381222486496, 42.91040584445, 37.39413924515247, 35.60269117355347, 34.393295869231224, 36.22865438461304, 36.468767300248146, 34.830982983112335, 34.21731971204281, 34.47910286486149, 35.809901654720306, 35.36842614412308, 35.81222712993622, 34.4537316262722, 36.12838536500931, 36.622237265110016, 34.915919825434685, 35.80954447388649, 36.789470091462135, 35.319872349500656, 38.17217789590359, 39.41203236579895, 41.21710650622845, 41.88479147851467, 44.296772852540016, 47.616244331002235, 45.76187163591385, 49.28167596459389, 35.83614304661751, 40.39155900478363, 46.97900712490082, 43.95970053970814, 45.33457696437836, 45.44584259390831, 46.65897689759731, 47.374938279390335, 46.66135936975479, 48.49543355405331, 47.534727305173874, 46.22251711785793, 49.711531698703766, 46.50915093719959, 43.25297646224499, 37.07261569797993, 35.38098827004433, 35.886045768857, 37.24451847374439, 37.13659666478634, 36.53220109641552, 36.61179542541504, 37.58156418800354, 37.653866708278656, 36.669932305812836, 38.60713675618172, 37.06114411354065, 38.73361296951771, 40.487040281295776, 43.75894211232662, 42.525353506207466, 37.7721581608057, 35.624103024601936, 36.44259810447693, 36.93223223090172, 36.19991272687912, 35.7136832177639, 38.22296217083931, 36.9914710521698, 39.107129126787186, 40.46166144311428, 41.78375869989395, 42.837035581469536, 41.72942541539669, 42.13454827666283, 41.16856791079044, 39.88044083118439, 39.195383191108704, 42.41192579269409, 42.513399347662926, 42.028275579214096, 41.21221996843815, 50.484250634908676, 55.79049110412598, 58.79738375544548, 56.778016313910484, 57.93500483036041, 59.88446742296219, 59.73737731575966, 59.60005268454552, 32.893797531723976, 3.947426495142281, 1.8617260130122304, 0.6901524541899562, 0.11705389901180752, 1.083265703637153, 37.101752534508705, 52.44065925478935, 42.51570962369442, 31.529931016266346, 34.904756024479866, 49.33311000466347, 52.08121374249458, 46.133970469236374, 14.861156456172466, 0.26293386763427407, 0.035958342559752055, 0.020507642439042684, 0.017600458886590786, 0.11022657083231024, 0.05439535030745901, 0.04177631650236435, 0.029030509031144902, 0.028133714477007743, 0.02337740133953048, 0.025384667751495726, 0.019692372807185166, 0.0254355326978839, 0.03503165986330714, 0.040900237145251594, 0.08689618640346453, 0.05450694705359638, 0.027440027188276872, 0.05945135751971975, 0.028766853647539392, 0.055858694831840694, 0.11811806456535123, 0.033096005136030726, 0.043790531271952204, 0.06255897475057282, 0.09335015492979437, 1.9169268384575844, 28.02957784384489, 52.45839670300484, 46.775087267160416, 25.754531621932983, 31.24559037387371, 59.328302666544914, 49.914471209049225, 38.970431461930275, 47.807351276278496, 3.194964984431863, 0.1246058676042594, 0.44591830344870687, 3.7430309504270554, 5.324181681498885, 6.843827962875366, 6.543598948046565, 26.32959846407175, 47.569826021790504, 52.20255263149738, 52.896140813827515, 52.88015507161617, 49.958453848958015, 43.054129332304, 41.01165533065796, 39.20456349849701, 41.86600908637047, 43.999659195542336, 42.79755190014839, 41.94562241435051, 41.16219565272331, 36.31363682448864, 37.02181622385979, 38.010249584913254, 37.36056424677372, 36.94605588912964, 38.64988826215267, 45.608131885528564, 48.47594439983368, 49.91916015744209, 48.61293084919453, 44.8818426579237, 44.73628766834736, 46.65792815387249, 46.35804824531078, 45.15048824250698, 46.847959756851196, 45.18867999315262, 44.93232674896717, 39.42972421646118, 37.671178579330444, 36.80038310587406, 37.12462730705738, 36.969892010092735, 37.12080471217632, 34.432175382971764, 36.63738705217838, 36.33732855319977, 37.14612655341625, 36.12161412835121, 35.471617206931114, 37.23059222102165, 37.860674411058426, 35.822710767388344, 37.37305797636509, 38.218653202056885, 39.20542985200882, 39.78291906416416, 41.01148433983326, 42.88311950862408, 44.99774783849716, 47.38434657454491, 50.468755066394806, 47.82239846885204, 49.61172625422478, 37.846345379948616, 42.11824335157871, 46.78489834070206, 45.437030866742134, 47.31843151152134, 45.77373459935188, 48.70564967393875, 48.58550012111664, 49.57698091864586, 49.854043051600456, 49.90273743867874, 48.65277171134949, 50.94090633094311, 49.61888127028942, 44.22407515347004, 39.86073888838291, 37.90262036025524, 38.43352407217026, 39.10047188401222, 38.887698501348495, 38.85722793638706, 38.70465852320194, 38.33286367356777, 37.3379098623991, 38.66852626204491, 39.733229130506516, 38.75807225704193, 40.24348855018616, 42.398577108979225, 45.82899883389473, 44.681703597307205, 40.54955832660198, 38.589957877993584, 37.20361366868019, 38.44226360321045, 37.70354904234409, 38.59771706163883, 40.34982204437256, 38.723843693733215, 40.573193058371544, 42.10239440202713, 43.35284270346165, 44.430818259716034, 43.71455289423466, 42.157442048192024, 42.45007574558258, 42.368760108947754, 43.03824998438358, 46.04690574109554, 43.638822957873344, 44.28264141082764, 43.19084979593754, 52.736720368266106, 57.37127847969532, 60.87432190775871, 58.76296140253544, 59.44717548787594, 61.5088764578104, 61.01290427148342, 60.93460947275162, 35.27835577726364, 4.342620251700282, 2.7263945527374744, 0.9086246404331177, 0.13348806911380962, 1.2077845470048487, 41.52060002088547, 59.74146209657192, 45.90008541941643, 34.991843551397324, 40.76394282281399, 56.13539099693298, 59.22362968325615, 52.26146087050438, 17.798807322978973, 0.2688045526156202, 0.05352003907319158, 0.057540167690603994, 0.04632869859051425, 0.08079438179265708, 0.05952942403382622, 0.02070199050649535, 0.030079260177444667, 0.02428506650176132, 0.06629372161114588, 0.02896690697525628, 0.0025358789525853354, 0.028100739000365138, 0.09393835891387425, 0.09412636718479916, 0.1726048326236196, 0.1642052794340998, 0.08564105883124284, 0.10917867315583862, 0.11604909785091877, 0.1617974555119872, 0.25131735659670085, 0.1263448828831315, 0.10407971043605357, 0.14464884210610762, 0.2037283539539203, 2.831166093237698, 36.19009405374527, 61.20862416923046, 55.40188975632191, 32.927068546414375, 43.673929274082184, 57.63181149959564, 41.679135113954544, 46.14859588444233, 54.17791463434696, 4.917744090780616, 0.194435536977835, 2.322431104257703, 9.057041052728891, 14.361168835312128, 18.1463822722435, 9.580662455409765, 32.661990970373154, 50.535734072327614, 53.34582768380642, 55.21653190255165, 56.58818610012531, 53.325190991163254, 45.848476588726044, 42.78909355401993, 41.55023083090782, 42.17150889337063, 45.85533142089844, 43.476134687662125, 42.9682881385088, 45.25495223701, 39.56492856144905, 38.85905183851719, 40.597659945487976, 39.85779784619808, 38.66314195096493, 41.17369003593922, 49.735044836997986, 51.32608786225319, 53.149374425411224, 50.54303728044033, 48.018129765987396, 46.43522970378399, 49.3461737036705, 48.54699678719044, 46.79269552230835, 49.23407591879368, 47.659463211894035, 47.21915423870087, 40.86697809398174, 40.301085859537125, 37.48766742646694, 38.121051639318466, 39.65002499520779, 38.11672747135162, 37.0986595004797, 38.3534699678421, 38.66469606757164, 39.92181681096554, 39.13565419614315, 37.74484142661095, 40.44388599693775, 39.4113028049469, 37.27150842547417, 39.44066762924194, 39.04102027416229, 39.24801416695118, 42.84431219100952, 43.96229960024357, 45.2113875746727, 45.46980790793896, 48.63302797079086, 52.886793315410614, 51.118163019418716, 51.97701953351498, 41.92867912352085, 42.334117367863655, 46.810254380106926, 46.332350224256516, 49.71775196492672, 48.876024931669235, 50.030828565359116, 49.94874157011509, 50.324374213814735, 51.28147065639496, 50.49716234207153, 48.522890880703926, 52.415527403354645, 50.4936171323061, 47.44639344513416, 40.034731552004814, 39.0364795178175, 39.73109744489193, 41.88542224466801, 41.15269996225834, 40.18429912626743, 40.1895010471344, 40.861559584736824, 40.79620309174061, 40.60220830142498, 43.201215639710426, 41.17317706346512, 41.51129812002182, 44.21923041343689, 48.97133141756058, 46.07448846101761, 41.995593532919884, 39.162792339921, 39.93300721049309, 40.70335887372494, 39.895377829670906, 39.8878238350153, 42.06494361162186, 40.3131540119648, 42.66393207013607, 44.462238773703575, 44.66345317661762, 47.22970627248287, 45.7264119386673, 45.14049097895622, 44.97261978685856, 43.79695147275925, 44.45345364511013, 47.1988595277071, 45.187562853097916, 45.964955538511276, 45.114766359329224, 55.41656456887722, 59.6351969987154, 63.02491910755634, 60.53169049322605, 60.48866920173168, 64.70125615596771, 65.79214721918106, 63.64919900894165, 37.397099286317825, 5.869619138538837, 6.540873069316149, 2.701678778976202, 0.31444138032384217, 1.4087683497928083, 45.77517472207546, 66.2753976881504, 56.84346780180931, 42.36268423497677, 47.26168155670166, 61.35490112006664, 66.68911188840866, 62.99045115709305, 23.208227455615997, 0.8839703164994717, 0.15591315954225138, 0.21286926814354956, 0.11738310087821446, 0.157018514291849, 0.1027735898969695, 0.12849498860305175, 0.07955513618071564, 0.12632331607164815, 0.13944070204161108, 0.07324295496800914, 0.1077466101560276, 0.09202312066918239], [0.0565953765908489, 0.02152388566173613, 0.03432073433941696, 0.04293799654988106, 0.018112173420377076, 0.051441483810776845, 0.07864347455324605, 0.033008316677296534, 0.013226600422058254, 0.03440572509134654, 0.011547946796781616, 0.08825704775517806, 0.06711746100336313, 2.004637294448912, 20.86798433214426, 40.04223234951496, 40.61686031520367, 27.182115018367767, 21.458366252481937, 28.51364526897669, 30.226777642965317, 35.72030246257782, 43.54944795370102, 4.0700960252434015, 0.23039606516249478, 0.15509388787904754, 4.602746218442917, 5.318300547078252, 5.1090567000210285, 14.797582067549229, 36.28901794552803, 47.65209920704365, 49.84291344881058, 50.870389714837074, 51.360213831067085, 47.674821987748146, 48.4700471162796, 42.07478508353233, 39.15830858051777, 37.63813555240631, 34.75144945085049, 35.03408968448639, 36.00424602627754, 36.92211337387562, 37.40456588566303, 37.14669652283192, 36.17942042648792, 35.18854759633541, 35.239453464746475, 40.37598364055157, 47.59599141776562, 47.42694228887558, 47.617992237210274, 44.597769901156425, 39.342739284038544, 39.39942084252834, 41.940610483288765, 42.489183247089386, 44.3903162330389, 43.88432018458843, 43.350080251693726, 40.05905784666538, 38.51663701236248, 34.7699848562479, 34.87208537757397, 36.90828211605549, 39.83103588223457, 35.67931406199932, 34.47706617414951, 34.523020908236504, 34.37068708240986, 36.847283989191055, 36.308298110961914, 34.112338945269585, 35.89467130601406, 35.839338675141335, 33.8034725189209, 33.9002875238657, 33.79197433590889, 37.77875080704689, 40.50649903714657, 41.32839873433113, 41.61309465765953, 44.408300668001175, 45.954570695757866, 46.43393777310848, 47.41986706852913, 46.88071019947529, 37.25560627877712, 40.53832232952118, 44.35306303203106, 42.960988730192184, 44.04035121202469, 43.00798840820789, 45.726229548454285, 47.52189539372921, 49.436567053198814, 49.3291050195694, 49.96173307299614, 49.55982863903046, 47.85071074962616, 48.514280542731285, 42.600179091095924, 37.34691917896271, 35.547286346554756, 35.59578314423561, 37.5486009567976, 36.30109369754791, 38.0072895437479, 36.369106248021126, 35.22394649684429, 35.179872661828995, 35.95143266022205, 37.60520651936531, 38.35228443145752, 38.83588448166847, 42.7425042539835, 44.91775453090668, 44.41560387611389, 39.91099499166012, 37.6455869525671, 36.18524931371212, 35.13073369860649, 37.578892931342125, 37.15235821902752, 37.58321329951286, 37.74062365293503, 38.222460597753525, 41.748071014881134, 43.1225560605526, 47.060527950525284, 48.429446294903755, 47.68375910818577, 43.780338764190674, 40.809578374028206, 39.107961282134056, 37.95185811817646, 40.514360815286636, 40.2935204654932, 41.48523151874542, 52.64625482261181, 58.776617869734764, 57.00043737888336, 59.775386676192284, 58.541608080267906, 58.44317816197872, 58.1922510266304, 59.30257424712181, 39.19735908508301, 5.148129053413868, 0.8602783503010869, 0.5022200010716915, 0.16135872749146074, 0.8533438411541283, 35.28251655399799, 54.92100656032562, 47.72604323923588, 26.889880299568176, 26.32049035280943, 43.6551620811224, 48.81641373038292, 47.189371436834335, 14.49045404791832, 0.16750516486354172, 0.029143961146473885, 0.06484808473032899, 0.06666160421445966, 0.0047870774778857594, 0.010010714977397583, 0.012858569389209151, 0.04351039278844837, 0.04382586863357574, 0.06312248748145066, 0.05478058803419117, 0.02631524115713546, 0.0065673051449266495, 0.03631980187492445, 0.03670210440759547, 0.0877933538868092, 0.05580950157309417, 0.010818387800100027, 0.04074921380379237, 0.027045930073654745, 0.056647560704732314, 0.04058615282701794, 0.02018464121647412, 0.07633417073520832, 0.11870034621097147, 0.08548742684070021, 2.937298910692334, 26.651103012263775, 50.45502260327339, 47.3894876986742, 32.207060381770134, 27.197403497993946, 33.02286900579929, 34.84536901116371, 39.78967510163784, 50.0634004175663, 4.928308948874474, 0.2626889885868877, 0.4824738559545949, 3.9873782638460398, 5.005496107041836, 2.957097510807216, 13.413417991250753, 38.72558780014515, 49.34124156832695, 49.17566545307636, 52.79987297952175, 53.10290291905403, 50.81041753292084, 48.76090630888939, 43.75757798552513, 40.618384033441544, 37.597287744283676, 37.19763658940792, 36.94195210933685, 38.25882084667683, 38.67118611931801, 39.50600892305374, 38.843313083052635, 37.74821564555168, 36.80432349443436, 36.42950400710106, 42.32983499765396, 50.78319579362869, 49.76184859871864, 50.65820150077343, 46.008748188614845, 42.53302149474621, 41.30412943661213, 44.24405828118324, 44.4632913172245, 45.673526376485825, 46.52245782315731, 45.39332561194897, 42.26090669631958, 40.12582026422024, 36.43591046333313, 37.02517144382, 39.43724021315575, 41.12529203295708, 37.07124777138233, 36.19485139846802, 36.39494106173515, 37.63653203845024, 38.27969692647457, 38.40113840997219, 36.937304958701134, 36.771428659558296, 36.67348511517048, 36.07779487967491, 36.58585421741009, 35.73935844004154, 39.70837086439133, 42.94083081185818, 42.62374922633171, 44.67441938817501, 45.08090637624264, 49.1185013204813, 50.24840869009495, 50.22242188453674, 50.2532572299242, 39.60110642015934, 40.086336582899094, 43.76361966133118, 42.554722130298615, 44.990737214684486, 42.501084208488464, 46.180928349494934, 48.21343168616295, 48.62177297472954, 50.403402373194695, 50.53911209106445, 50.708336010575294, 50.40698558092117, 49.65030938386917, 45.67119710147381, 39.15233910083771, 37.32574291527271, 38.1913098692894, 39.13610637187958, 37.94859789311886, 39.29471366107464, 37.393994852900505, 38.153251111507416, 36.937639340758324, 38.5729917883873, 39.10655915737152, 39.06430922448635, 41.6617776453495, 45.43484978377819, 47.00693942606449, 46.441271379590034, 41.998553574085236, 39.61849048733711, 38.21988433599472, 37.354625165462494, 39.50610011816025, 40.417177230119705, 39.15800839662552, 41.53939761221409, 40.98157234489918, 43.4874314814806, 46.160785630345345, 48.58717203140259, 48.73572885990143, 49.507209062576294, 44.970267713069916, 43.021470084786415, 40.78605003654957, 40.301412642002106, 42.72026404738426, 40.88167950510979, 43.78335580229759, 55.215996131300926, 60.5498231202364, 60.3170970082283, 61.200454607605934, 60.54913155734539, 61.33898377418518, 60.410921573638916, 61.407957673072815, 41.05204716324806, 5.815065940842032, 2.1863031713292003, 0.33555729256477207, 0.1099554420216009, 0.7043431489728391, 38.432809710502625, 59.93745557963848, 54.67922933399677, 32.39511229097843, 31.958508118987083, 50.74483685195446, 54.68022108078003, 56.19459182024002, 18.09470884501934, 0.22829847381217405, 0.028737607462971937, 0.03624083736212924, 0.03362548668519594, 0.009856202614173526, 0.05249841713521164, 0.07743813024717383, 0.030434698819590267, 0.014778270724491449, 0.03693195125379134, 0.03725609909452032, 0.01278943833312951, 0.024321285163750872, 0.19328590569784865, 0.10474370254087262, 0.1606019595055841, 0.14384496258571744, 0.07789637675159611, 0.11024514678865671, 0.1646484454977326, 0.17037717247148976, 0.11406786783481948, 0.11966005447902717, 0.17283859429880977, 0.31144936743658036, 0.13044168648775667, 3.5995043395087123, 36.211604699492455, 59.45849508047104, 53.509173318743706, 39.43185970187187, 32.67482668161392, 38.49377363920212, 39.363379776477814, 45.58328501880169, 55.80871492624283, 6.2621029280126095, 0.3617616364499554, 1.3904590322636068, 13.623224683105946, 11.52632050216198, 9.45797748863697, 18.171117044985294, 40.046214535832405, 51.688899993896484, 49.82477322220802, 54.26345184445381, 56.34555771946907, 52.41067126393318, 53.40666241943836, 47.793261632323265, 43.646335154771805, 41.84660352766514, 39.97357003390789, 38.689174354076385, 39.93694379925728, 41.14348545670509, 41.30420543253422, 41.00146807730198, 39.89970959722996, 39.69624571502209, 39.45525884628296, 44.8173563182354, 51.82879328727722, 50.73450140655041, 52.63375349342823, 50.092989429831505, 44.387823566794395, 42.971631959080696, 46.09259448945522, 46.279715448617935, 47.70510636270046, 49.286038130521774, 49.29834187030792, 44.962652921676636, 42.1071707457304, 38.152426555752754, 39.72197413444519, 42.70167924463749, 42.429173067212105, 40.615006014704704, 37.84428969025612, 38.62417124211788, 38.506761342287064, 40.41037939488888, 40.341287702322006, 38.796096816658974, 39.18408639729023, 37.79527612030506, 38.02542597055435, 39.08530309796333, 37.570567578077316, 41.587981805205345, 44.4927891343832, 44.301154017448425, 47.60938949882984, 47.15952783823013, 51.69137366116047, 52.94070482254028, 51.63259081542492, 49.092677906155586, 41.72793589532375, 42.89481908082962, 44.49107922613621, 44.48097176849842, 45.34993954002857, 45.44776909053326, 48.1157161295414, 50.67521318793297, 51.086981892585754, 51.96311227977276, 53.596640825271606, 52.569202557206154, 51.26923531293869, 50.95506817102432, 46.77771292626858, 41.71119399368763, 37.374931275844574, 38.93008902668953, 41.5033945441246, 39.878046959638596, 42.41996996104717, 39.67645637691021, 39.45043310523033, 39.01597581803799, 40.894420221447945, 41.806572675704956, 41.42950750887394, 44.683402106165886, 48.09998497366905, 49.55416314303875, 49.750445410609245, 42.772112265229225, 41.08108900487423, 41.650306060910225, 38.08460779488087, 40.716973543167114, 41.926874220371246, 41.315281838178635, 40.903045758605, 43.88082057237625, 44.48628768324852, 47.81117387115955, 51.69108867645264, 51.729307025671005, 51.91297397017479, 47.55234315991402, 44.335564970970154, 42.08985887467861, 42.63873942196369, 46.35312370955944, 44.844084084033966, 46.20726853609085, 57.3338732868433, 64.35479834675789, 61.043340638279915, 64.88643541932106, 62.43987210094929, 62.804238349199295, 62.95972600579262, 64.1988243162632, 43.851934522390366, 6.932175597175956, 3.8367013866081834, 1.9489535386674106, 0.3490606101695448, 1.3669454189948738, 42.587810754776, 68.16043093800545, 61.40647575259209, 39.907666370272636, 39.37671326100826, 56.993160769343376, 62.91733168065548, 64.56393912434578, 24.341315254569054, 0.5148515326436609, 0.08873143597156741, 0.1527934378827922, 0.15861154912272468, 0.10333317666663788, 0.3290342597756535, 0.1256275674677454, 0.13278092112159356, 0.11012963892426342, 0.26327210885938257, 0.08091514406260103, 0.10317424574168399, 0.05465508715133183], [0.03923085387214087, 0.045138037676224485, 0.009914082711475203, 0.038425204329541884, 0.050414841243764386, 0.017502170703664888, 0.02937551493232604, 0.018022065560217015, 0.016020075818232726, 0.02123018628481077, 0.03843211743514985, 0.055307227157754824, 0.04920826497254893, 1.225690373685211, 19.791219010949135, 40.429929345846176, 41.28964081406593, 28.136730194091797, 15.604682508856058, 27.40248989313841, 47.73305006325245, 32.75887057185173, 48.38895566761494, 4.014984732493758, 0.12825540849007666, 0.4023916687583551, 1.5867335814982653, 1.7349821515381336, 4.7341108694672585, 15.556940920650959, 32.96572007238865, 54.11008067429066, 49.92394030094147, 51.97106525301933, 50.791790932416916, 50.87714955210686, 50.08799649775028, 51.417195573449135, 48.34353670477867, 46.522161439061165, 43.92647132277489, 36.46112211048603, 34.53341335058212, 35.608751848340034, 34.69566844403744, 36.240863129496574, 34.23237830400467, 34.708382561802864, 36.89965657889843, 46.564008593559265, 45.6519815325737, 48.49958673119545, 46.59461595118046, 42.10681736469269, 37.84045189619064, 35.95938943326473, 37.11643494665623, 38.645450100302696, 39.34768661856651, 41.22423492372036, 41.86356581747532, 39.87373039126396, 37.66789935529232, 37.211205661296844, 35.57583041489124, 36.54183357954025, 37.577084228396416, 34.810049906373024, 35.35857327282429, 36.78183630108833, 35.36483533680439, 35.03151722252369, 35.99773317575455, 35.12262873351574, 35.6938710808754, 35.18920496106148, 35.81638030707836, 40.6303533911705, 42.05121494829655, 40.23329369723797, 42.45804011821747, 41.542422249913216, 40.90409070253372, 42.499678283929825, 44.91756834089756, 47.886972203850746, 46.91838517785072, 48.16457390785217, 35.78568175435066, 38.67573067545891, 43.19881796836853, 42.504891604185104, 49.03623953461647, 48.516492024064064, 48.35358716547489, 47.692057862877846, 47.865275368094444, 47.5590156018734, 49.4612505286932, 47.49172501266003, 49.30082693696022, 47.580313459038734, 40.19878014922142, 35.76453968882561, 35.51289439201355, 35.088453367352486, 38.10677960515022, 36.910835579037666, 36.84985265135765, 36.95020146667957, 39.10912401974201, 36.93334177136421, 37.81411550939083, 37.40406431257725, 36.714215129613876, 40.021603256464005, 44.83034402132034, 45.37371106445789, 44.70352582633495, 39.21477735042572, 36.628016754984856, 36.46302580833435, 38.77590090036392, 38.98102909326553, 40.136098712682724, 39.55667920410633, 37.18082249164581, 35.20444594323635, 38.80622707307339, 44.6076075732708, 47.426208928227425, 51.34534142911434, 52.469533905386925, 51.778100207448006, 49.469461888074875, 42.82383129000664, 41.22364595532417, 38.97958517074585, 41.633214578032494, 38.948746025562286, 43.98742765188217, 53.072713539004326, 57.49764829874039, 56.55455030500889, 57.18737214803696, 56.4443676173687, 61.89902812242508, 57.97063171863556, 42.665729373693466, 9.085510075092316, 0.8813822991214693, 0.3804690419929102, 0.12558130198158324, 1.1361753707751632, 35.248698368668556, 51.83629788458347, 41.60160407423973, 29.00703739374876, 25.43302897363901, 42.73091107606888, 47.65559881925583, 50.5117953568697, 13.155094552785158, 0.19224082818254828, 0.013972688902867958, 0.004301684602978639, 0.059257961256662384, 0.10979734972352162, 0.0323723406472709, 0.03274766328104306, 0.019486219025566243, 0.043729330063797534, 0.07129822377464734, 0.07190921169240028, 0.03972208884079009, 0.054928412719164044, 0.024551111600885633, 0.009314755789091578, 0.01976737239601789, 0.05162325433047954, 0.015205816434900044, 0.0193901535749319, 0.04022236687887926, 0.05312178036547266, 0.029646981420228258, 0.028115320346842054, 0.03719918378919829, 0.06737776930094697, 0.0970453156332951, 1.5961253712885082, 24.418929889798164, 48.032724782824516, 47.648280411958694, 32.863775342702866, 22.65194870531559, 38.906298503279686, 46.21859572827816, 39.35198038816452, 51.990816593170166, 4.876397084444761, 0.13383039215113968, 0.02338745558517985, 2.5452979328110814, 5.484573924914002, 6.059387130662799, 18.439760729670525, 35.92227302491665, 50.634494572877884, 51.40718691051006, 51.64311245083809, 52.030091285705566, 53.385330364108086, 53.00409682095051, 53.07584837079048, 51.34476765990257, 49.15066659450531, 44.4880735874176, 37.72089131176472, 36.74550265073776, 37.52479903399944, 36.2328265607357, 36.83072067797184, 36.02342739701271, 36.17683656513691, 39.96133089065552, 48.26815254986286, 47.54074238240719, 47.91875369846821, 50.24889886379242, 44.17803682386875, 40.14185920357704, 37.33452424407005, 39.34882275760174, 40.507448986172676, 41.93397603929043, 43.16175475716591, 43.71403992176056, 41.24101482331753, 37.992371544241905, 37.780057936906815, 37.84582860767841, 38.54113429784775, 39.17413853108883, 35.94347208738327, 37.30049327015877, 37.49554060399532, 37.12679699063301, 37.73936592042446, 36.951899975538254, 36.84081293642521, 37.131052762269974, 36.483943685889244, 37.769426107406616, 40.52082046866417, 43.37572507560253, 41.837666407227516, 42.75395303964615, 42.69918657839298, 42.637105509638786, 44.575267508625984, 46.814798936247826, 49.76065546274185, 48.68165776133537, 49.81083557009697, 38.07268403470516, 38.87168236076832, 43.2449246942997, 44.305725172162056, 49.94101278483868, 50.96108324825764, 50.73768563568592, 50.97830772399902, 50.4864127188921, 50.30065968632698, 51.92354120314121, 50.237670466303825, 49.665003195405006, 48.10385696589947, 42.90735840797424, 37.88173288106918, 37.99046404659748, 36.81384578347206, 37.727860137820244, 38.23339641094208, 38.87469179928303, 37.85822734236717, 39.79814864695072, 39.36855509877205, 40.6620778888464, 38.98287959396839, 38.81093882024288, 41.318686455488205, 47.77925558388233, 47.22917050123215, 46.77220322191715, 42.21790060400963, 38.382268622517586, 39.157206639647484, 39.72591832280159, 40.174096673727036, 42.801534086465836, 40.67505419254303, 39.24349620938301, 38.38689677417278, 41.58114597201347, 45.51499508321285, 49.55410614609718, 53.72776418924332, 55.930369198322296, 52.97711066901684, 51.5511079877615, 45.06210118532181, 42.22745329141617, 41.427197232842445, 43.34896311163902, 40.756548419594765, 45.702176839113235, 55.53099922835827, 60.75332120060921, 58.9909453690052, 59.424285516142845, 58.322587832808495, 62.61643722653389, 60.01539319753647, 44.03027415275574, 9.122555237263441, 2.31388655025512, 0.6570187071338296, 0.11675805668346584, 1.1550160660408437, 39.78060118854046, 59.50064241886139, 45.65980151295662, 28.68192683905363, 30.495206639170647, 46.73878401517868, 52.36570447683334, 58.63168224692345, 17.121060490608215, 0.24318148847669363, 0.01741851581755327, 0.026201306645816658, 0.03529788678861223, 0.04740111682622228, 0.08415252581471577, 0.01427480701750028, 0.029193310256232508, 0.0491492456785636, 0.043869933651876636, 0.06450073735322803, 0.02859930453269044, 0.016290182320517488, 0.18305795296328142, 0.1573962377733551, 0.10749635053798556, 0.17189812992000952, 0.22929269936867058, 0.09410122322151437, 0.1293171546421945, 0.17104670841945335, 0.08618644089438021, 0.11019920042599551, 0.17700958298519254, 0.16616241191513836, 0.1503777175094001, 1.8976775463670492, 32.856890112161636, 58.08344006538391, 53.96177463233471, 38.88001151382923, 26.089111268520355, 36.685906648635864, 54.96956415474415, 43.841420486569405, 57.71771349012852, 5.434599481523037, 0.2967795717995614, 0.6924727640580386, 5.540951499715447, 9.054213054478168, 10.751003455370665, 18.594089448451996, 37.19648905098438, 53.530995547771454, 49.33524549007416, 52.84829378128052, 52.679506838321686, 55.275181755423546, 54.23632130026817, 56.72504335641861, 53.34356680512428, 51.994665786623955, 49.396745190024376, 40.92038042843342, 37.91378416121006, 38.458382338285446, 36.94332763552666, 39.79002088308334, 37.10864536464214, 37.685370817780495, 41.118216812610626, 50.25426037609577, 47.85289943218231, 50.21270960569382, 52.399834245443344, 46.98648892343044, 42.652308493852615, 39.05295543372631, 40.19590750336647, 42.723045498132706, 43.89610335230827, 46.75680264830589, 46.575635969638824, 42.86594823002815, 39.93673101067543, 41.38707898557186, 40.192677676677704, 40.2620467543602, 39.76105123758316, 37.41349920630455, 39.01756413280964, 39.86540123820305, 38.46078380942345, 39.20310437679291, 38.70450273156166, 38.45278903841972, 39.58596423268318, 38.69190260767937, 40.356961861252785, 44.7961800545454, 45.76215662062168, 44.834231212735176, 46.103306114673615, 45.13061910867691, 42.835663855075836, 47.65409789979458, 48.65541636943817, 52.10413411259651, 51.24368168413639, 50.7108286768198, 40.934253484010696, 41.75598978996277, 43.136387318372726, 44.132598862051964, 52.26762033998966, 53.35045583546162, 52.48162865638733, 52.611349895596504, 52.46638007462025, 52.08408638834953, 52.73664057254791, 51.51360020041466, 53.337403535842896, 50.615415796637535, 45.26116870343685, 38.416166603565216, 38.956710398197174, 38.836975023150444, 39.63652051985264, 40.188254714012146, 41.53321914374828, 40.819628834724426, 42.96190828084946, 42.005731388926506, 41.761852875351906, 41.30972273647785, 40.80272734165192, 43.18795435130596, 48.467888832092285, 50.27444489300251, 48.82907085120678, 43.71344335377216, 40.2541583776474, 40.83412125706673, 42.589288875460625, 42.76766650378704, 45.747041031718254, 43.561474308371544, 42.33628325164318, 39.08809594810009, 42.86447770893574, 48.36754381656647, 51.30978673696518, 56.697111055254936, 57.439173236489296, 56.04863405227661, 55.44352412223816, 47.00522191822529, 45.27663767337799, 43.99223439395428, 45.31046725809574, 43.55970740318298, 48.88925962150097, 59.13066007196903, 62.648735493421555, 60.40407054126263, 61.098821461200714, 60.780356749892235, 66.4349815249443, 62.15434402227402, 47.08665534853935, 11.267922967672348, 3.884646026417613, 1.7857834068126976, 0.27353808924090117, 1.6389284119941294, 43.35402823984623, 65.15970155596733, 53.897877261042595, 42.636907920241356, 39.72324326634407, 57.32015982270241, 61.61745943129063, 67.6735782623291, 23.151885978877544, 0.5037042370531708, 0.3003151633311063, 0.1199312723474577, 0.14503999846056104, 0.24811325274640694, 0.10601143178064376, 0.09155815772828646, 0.0817887632001657, 0.10595860570902005, 0.10652796656358987, 0.13169751910027117, 0.11068450563470833, 0.1735113066388294], [0.04064279353769962, 0.01695184408163186, 0.004086078643013025, 0.027871292913914658, 0.03682924172608182, 0.022761151594750118, 0.04386525441077538, 0.040863203976186924, 0.03814334035268985, 0.034505146904848516, 0.12380100102745928, 0.055726002537994646, 0.02203324944275664, 0.44253238826058805, 16.56793937087059, 45.46119377017021, 42.69368067383766, 37.32773020863533, 20.215889923274517, 16.246776804327965, 55.336415469646454, 39.788880944252014, 46.49253062903881, 6.271791933104396, 0.03264231912908144, 0.027962404528807383, 1.7790651298128068, 4.398388909175992, 2.778668347746134, 16.959373466670513, 42.32497125864029, 53.914075791835785, 53.586993142962456, 53.290677443146706, 51.37290135025978, 53.06169793009758, 53.130132257938385, 50.376879796385765, 47.89565473794937, 48.654827401041985, 46.69847197830677, 45.91053485870361, 37.481306567788124, 35.155664160847664, 36.37724921107292, 36.611681431531906, 36.177596524357796, 34.80569913983345, 39.34953331947327, 48.94061006605625, 46.66765183210373, 47.280224561691284, 46.197829842567444, 42.847162038087845, 40.180415734648705, 35.13907045125961, 37.15980961918831, 35.60614138841629, 36.1041122674942, 38.34285333752632, 36.652730628848076, 36.07471324503422, 35.644314140081406, 37.116818726062775, 34.26187992095947, 35.57668536901474, 34.051044434309006, 34.57606606185436, 34.335010796785355, 35.21222412586212, 35.78558295965195, 35.402552112936974, 35.653068870306015, 34.44385975599289, 34.580998197197914, 39.708925634622574, 44.21978518366814, 47.827064618468285, 45.0216181576252, 46.03758484125137, 44.76529151201248, 46.110544726252556, 43.075708374381065, 47.791289538145065, 46.7855329066515, 47.613740265369415, 46.40724800527096, 47.466357573866844, 34.88174445927143, 36.12800158560276, 49.60774406790733, 50.18160827457905, 50.085640624165535, 47.26029463112354, 48.08320887386799, 45.33557251095772, 46.617688313126564, 45.40042743086815, 46.92254215478897, 46.41717307269573, 44.80220653116703, 41.79585725069046, 37.178295627236366, 35.12281112372875, 35.56431323289871, 36.9196131080389, 36.851167380809784, 35.02892576158047, 37.34561584889889, 36.34460896253586, 36.926099359989166, 36.209366619586945, 38.476894944906235, 38.75445865094662, 37.39762745797634, 43.005590736866, 46.354655027389526, 44.409094825387, 42.76596039533615, 38.70320700109005, 39.0039798617363, 43.10118220746517, 46.418993175029755, 52.17517890036106, 51.52162916958332, 51.14954173564911, 46.98166698217392, 37.875679805874825, 36.77163004875183, 38.10047194361687, 48.60036492347717, 50.65480828285217, 53.88069838285446, 53.82964052259922, 51.081639379262924, 50.99091924726963, 43.89641493558884, 40.808111652731895, 39.6023565530777, 43.50863054394722, 43.4295529872179, 42.86811411380768, 47.849977388978004, 50.12235805392265, 53.55502925813198, 57.999776154756546, 58.12145322561264, 61.61600410938263, 42.530813813209534, 7.01089977286756, 1.719411180820316, 0.30261602893006057, 0.13131086016073823, 0.9357272798661143, 34.73496213555336, 54.76444736123085, 45.73292478919029, 37.235687747597694, 31.661061979830265, 38.83294723927975, 48.34576338529587, 48.204346373677254, 10.702641550451517, 0.24374608474317938, 0.032032878589234315, 0.08094335309579037, 0.01979440883587813, 0.13351502391742542, 0.011277279973000987, 0.04272485544788651, 0.07719679866568185, 0.05193729783059098, 0.03598821771447547, 0.07327984712901525, 0.03847513231448829, 0.08946020272560418, 0.09150435202172957, 0.03502689527522307, 0.032500023444299586, 0.030328740540426224, 0.01025759504045709, 0.06501778421807103, 0.03660457507066894, 0.04166631537373178, 0.01505524487583898, 0.06611339456867427, 0.11143128431285731, 0.13214439590228721, 0.024899835661926772, 0.7132724917028099, 22.382358871400356, 52.89695397019386, 49.60836723446846, 44.37010131776333, 23.76518066972494, 19.96605522930622, 52.312993705272675, 40.99554039537907, 52.46800638735294, 6.993316216394305, 0.12966817565029487, 0.2677145751658827, 1.6383710294030607, 5.323139587417245, 4.405103148892522, 16.581799127161503, 42.74482972919941, 54.33163918554783, 55.142557471990585, 52.98491545021534, 52.06523559987545, 53.612615168094635, 54.089858159422874, 53.16985532641411, 50.24051271378994, 50.066979825496674, 50.722501650452614, 46.10644094645977, 39.24292244017124, 37.315779849886894, 37.9524926841259, 38.29451233148575, 35.926916375756264, 36.5579979121685, 42.174670323729515, 49.24469634890556, 47.0330136269331, 49.49645943939686, 48.381519466638565, 45.184424221515656, 41.708085760474205, 37.140734642744064, 38.29906068742275, 37.94660300016403, 38.1992856413126, 39.748903289437294, 39.246501848101616, 38.35436291992664, 37.702359706163406, 37.789276242256165, 37.592382207512856, 37.64484979212284, 36.04132443666458, 35.149782076478004, 35.73394373059273, 36.71879008412361, 38.52430880069733, 37.240996062755585, 37.02536903321743, 36.19738966226578, 35.85276335477829, 40.44287905097008, 46.09714664518833, 49.06358666718006, 47.76041999459267, 47.32120156288147, 46.801651641726494, 48.10699179768562, 45.58736599981785, 48.08912515640259, 49.00586016476154, 49.98319812119007, 48.37753728032112, 47.43779830634594, 38.610051199793816, 37.125505059957504, 48.26216407120228, 50.19208051264286, 50.24216942489147, 50.15830412507057, 48.8098818808794, 48.857383131980896, 48.70410695672035, 46.37771598994732, 48.38179685175419, 49.013269767165184, 46.98395825922489, 42.968158945441246, 39.89152483642101, 35.79555742442608, 37.05593839287758, 38.662822768092155, 38.59368547797203, 37.177300080657005, 40.01682311296463, 38.318485245108604, 37.929788902401924, 38.045606687664986, 39.49207507073879, 40.49137964844704, 39.69126798212528, 45.365017130970955, 48.070832937955856, 47.18047611415386, 44.36617612838745, 39.86684896051884, 39.729695320129395, 43.6212944984436, 48.12083825469017, 53.350368440151215, 54.120343923568726, 52.06633374094963, 48.65800783038139, 41.21403247117996, 37.98597268760204, 41.250111535191536, 49.83010433614254, 53.538963720202446, 55.28488643467426, 56.928074061870575, 53.552236407995224, 51.570958122611046, 45.23892469704151, 41.64348162710667, 41.02218836545944, 45.077345967292786, 44.53587122261524, 45.74671424925327, 51.460783034563065, 52.65277147293091, 56.86111405491829, 59.24213849008083, 59.30963046848774, 62.91115701198578, 42.3615974932909, 7.449589082971215, 1.8824520008638501, 0.7120327488519251, 0.1389536156784743, 1.1525637726299465, 38.07565167546272, 59.72603492438793, 49.34803940355778, 42.96698100864887, 40.1268158107996, 45.47580398619175, 54.5633165538311, 56.23502165079117, 15.202724877744913, 0.3052414208650589, 0.01691130797553342, 0.10652597018633969, 0.01950681547896238, 0.12028961835312657, 0.03663400864752475, 0.03644325814093463, 0.03403505572350696, 0.04583181216730736, 0.04948249596054666, 0.056729831485426985, 0.09230722964275628, 0.038074966287240386, 0.1507024368038401, 0.07922784163383767, 0.09033002206706442, 0.08280087451566942, 0.17987188330153003, 0.21140081022167578, 0.12703301705187187, 0.1401350405649282, 0.13708528858842328, 0.09403181757079437, 0.21748076600488275, 0.19087189226411283, 0.13436499080853537, 1.2044533132575452, 27.44113951921463, 62.495607510209084, 55.17665684223175, 51.479709818959236, 30.102007538080215, 23.341193720698357, 63.26278634369373, 51.57268323004246, 58.06082367897034, 8.009510412812233, 0.24896249233279377, 0.6581876787822694, 6.3241255749017, 8.69924085214734, 4.645473025739193, 19.882305823266506, 44.55605573952198, 55.32857649028301, 58.97506982088089, 55.09719930589199, 53.3036233484745, 54.52616594731808, 56.033484265208244, 54.847305715084076, 51.6000721603632, 51.93506978452206, 51.552126333117485, 50.199235528707504, 41.18184059858322, 38.50530222058296, 39.58314098417759, 40.08604399859905, 39.41766366362572, 38.80222208797932, 43.874949887394905, 52.12911397218704, 48.293709978461266, 51.50123946368694, 49.70503784716129, 48.33334185183048, 43.84318359196186, 38.842009752988815, 41.68606214225292, 40.52105225622654, 40.41193351149559, 41.87719568610191, 40.66236287355423, 40.74262596666813, 39.91550914943218, 39.76018488407135, 38.58978308737278, 39.224189445376396, 38.49141776561737, 37.75208003818989, 36.79363086819649, 38.768631890416145, 40.36127842962742, 41.21990315616131, 39.011841639876366, 37.43495285511017, 37.794584557414055, 43.385957926511765, 49.33294281363487, 53.03459398448467, 49.950683265924454, 50.134733989834785, 50.41394300758839, 51.7546858638525, 47.82886952161789, 51.902775317430496, 51.79180987179279, 52.918548211455345, 50.14112524688244, 47.94534847140312, 40.700706616044044, 38.44877265393734, 50.24880766868591, 52.016465216875076, 54.44053754210472, 50.60799479484558, 53.52240040898323, 51.464658826589584, 50.16072079539299, 49.03065003454685, 50.31815394759178, 50.982776284217834, 48.02631452679634, 45.71244388818741, 41.92802555859089, 38.743944615125656, 38.99057798087597, 41.09042130410671, 40.234053656458855, 38.8217568397522, 41.103226616978645, 39.431365728378296, 39.385186806321144, 39.24475394189358, 42.320723086595535, 41.781866401433945, 41.95783495903015, 48.57954204082489, 51.26177631318569, 49.4610795378685, 46.56837455928326, 42.794553861021996, 41.17918074131012, 46.99029251933098, 52.19005890190601, 56.871958673000336, 56.604198440909386, 54.476745799183846, 50.41742742061615, 42.87933111190796, 40.5491479486227, 41.774946972727776, 51.76899969577789, 55.829214826226234, 57.5234717130661, 57.4946578592062, 54.60648223757744, 54.97701935470104, 49.05127912759781, 45.9170401096344, 42.7355582267046, 47.10069939494133, 48.43829222023487, 46.41733646392822, 53.413654044270515, 55.54543845355511, 59.195834174752235, 62.578522861003876, 63.733470886945724, 65.01340940594673, 46.51874162256718, 9.251956343650818, 6.412624726071954, 1.318438765592873, 0.1858990575419739, 1.6433662176132202, 41.74991011619568, 67.32539534568787, 58.193223774433136, 50.114872455596924, 46.38581335544586, 52.65249788761139, 63.518113642930984, 66.86798349022865, 21.369012147188187, 0.8257033524569124, 0.14348954806337133, 0.20010805368656293, 0.19699176074936986, 0.28153309773188084, 0.11195343715371564, 0.10124306616489775, 0.1988945234916173, 0.14457256416790187, 0.19525589217664674, 0.20749565883306786, 0.11097562048234977, 0.1568133253022097], [0.06213150511030108, 0.09804199027712457, 0.009731002301123226, 0.034338976329308935, 0.015481903719773982, 0.06465324127930216, 0.05603871017228812, 0.027315988336340524, 0.03400352557946462, 0.030659677177027334, 0.06547534794663079, 0.038991566907498054, 0.016057808461482637, 0.09941879296093248, 10.880474857985973, 38.19752253592014, 46.630413830280304, 36.83113105595112, 26.10957697033882, 20.902102701365948, 37.80340388417244, 45.88424026966095, 47.79611147940159, 7.974383197724819, 0.13757169217569754, 0.036487282341113314, 1.392194232903421, 4.814370637759566, 6.726791393011808, 24.454739168286324, 41.79544307291508, 55.88974937796593, 52.13973060250282, 51.46693490445614, 49.19872261583805, 51.162426844239235, 50.352260917425156, 54.46348451077938, 48.46415363252163, 51.04497894644737, 47.12900787591934, 50.07365606725216, 43.665296137332916, 35.832651033997536, 36.600928008556366, 36.03299908339977, 35.73767893016338, 37.321825325489044, 42.14719779789448, 47.635288909077644, 46.293375715613365, 44.72852848470211, 45.36893852055073, 44.0132624655962, 41.9651685655117, 39.866966754198074, 36.316007897257805, 35.542722791433334, 34.03205305337906, 35.46444319188595, 34.36494939029217, 33.3333807438612, 34.92317743599415, 35.907408222556114, 35.19980639219284, 36.75024099647999, 34.86409440636635, 36.03263050317764, 36.02340839803219, 37.283485382795334, 34.86014261841774, 34.68167759478092, 34.36007805168629, 35.19526943564415, 35.67235663533211, 45.46809419989586, 47.39249713718891, 48.7365610152483, 53.42819966375828, 47.809399366378784, 49.47452321648598, 47.99404665827751, 43.72728981077671, 46.37900412082672, 46.34131394326687, 48.81731428205967, 46.26429967582226, 47.11803026497364, 38.82997199892998, 40.08486606180668, 49.585245475173, 48.12252536416054, 49.328949227929115, 46.97996087372303, 46.49208225309849, 46.942654475569725, 45.83498731255531, 44.6447429805994, 42.03245535492897, 40.02664178609848, 37.732587084174156, 37.00561389327049, 35.43626390397549, 36.165342181921005, 38.72808426618576, 36.507380828261375, 36.750058606266975, 35.45750096440315, 37.60618306696415, 37.783633545041084, 36.13863721489906, 34.86032500863075, 38.751969784498215, 37.81665377318859, 37.94488549232483, 43.303095772862434, 45.537831857800484, 46.11413173377514, 42.363349199295044, 40.47220207750797, 43.42881582677364, 46.67528562247753, 48.72173421084881, 47.87303075194359, 49.77563425898552, 39.84020859003067, 50.45088082551956, 49.23026852309704, 36.153353825211525, 36.80244639515877, 39.48795609176159, 48.815148398280144, 50.72999864816666, 53.012566566467285, 53.622133657336235, 54.49838563799858, 46.55170105397701, 41.164684519171715, 46.19099780917168, 54.566417187452316, 53.451230227947235, 50.12089133262634, 49.29690554738045, 47.697768956422806, 51.449292451143265, 55.90754762291908, 57.8867170214653, 60.808653831481934, 39.59235168993473, 6.007093861699104, 1.578958248719573, 0.4322776588378474, 0.17618551704799756, 0.9489838185254484, 36.538440361618996, 51.7314463108778, 38.06549482047558, 27.712728045880795, 27.92508915066719, 38.34901660680771, 46.286456286907196, 49.64820809662342, 7.650880431756377, 0.16331572638591751, 0.020072428487765137, 0.11532842792803422, 0.02612577642139513, 0.12105282075935975, 0.03208833557437174, 0.04061749372340273, 0.038847319374326617, 0.03417574094783049, 0.028677126138063613, 0.007110013621058897, 0.08481873694108799, 0.03071402094064979, 0.0705573451705277, 0.07108612539013848, 0.04214544220303651, 0.026833870651898906, 0.033301717339782044, 0.04310431926569436, 0.07115064770914614, 0.007998642231541453, 0.03561624216672499, 0.04868600080953911, 0.08854378393152729, 0.0591741876269225, 0.05698128225049004, 0.23926003952510655, 14.35352174565196, 46.57822743058205, 52.92540684342384, 42.26960062980652, 25.45306909829378, 19.826327227056026, 45.78896798193455, 47.69644282758236, 50.814171731472015, 9.777058716863394, 0.17742940108291805, 0.03386420590686612, 2.395409750752151, 7.54647770896554, 4.991791667416692, 22.921682931482792, 43.191130980849266, 57.53910407423973, 55.0405253469944, 53.54068502783775, 51.60484850406647, 54.36000846326351, 51.06553204357624, 54.86055180430412, 50.112121403217316, 50.94775356352329, 49.34305027127266, 53.22461798787117, 44.995057582855225, 37.37560383975506, 38.021740168333054, 37.85090133547783, 35.732792392373085, 39.73151542246342, 45.12652672827244, 48.833550810813904, 46.042087599635124, 45.583281219005585, 46.9022436439991, 46.124109998345375, 43.100585639476776, 40.66069856286049, 38.059798926115036, 36.217539981007576, 36.22140437364578, 38.1506634503603, 37.355020344257355, 36.28603130578995, 36.028781309723854, 38.68536315858364, 36.38873979449272, 37.2742822766304, 36.25915914773941, 37.61610433459282, 36.59096494317055, 38.816824704408646, 35.738305896520615, 35.6506559997797, 35.27824938297272, 36.82405583560467, 36.38659290969372, 47.32633128762245, 48.562439158558846, 51.26920111477375, 53.313016444444656, 48.9132097363472, 50.34364677965641, 49.26090247929096, 46.65920488536358, 47.995790764689445, 48.00129286944866, 52.16576300561428, 47.19730921089649, 48.06267477571964, 40.99204458296299, 40.79977490007877, 51.550617814064026, 50.053011775016785, 50.30191361904144, 48.87780703604221, 47.04196974635124, 48.17160353064537, 45.20465813577175, 45.96565470099449, 44.112421944737434, 41.598579436540604, 38.81319209933281, 38.772165700793266, 38.331769332289696, 37.64500558376312, 39.67777870595455, 37.18236900866032, 39.04278337955475, 37.55482882261276, 38.42975467443466, 39.174974486231804, 39.57166559994221, 36.411268785595894, 40.1563174277544, 38.51895108819008, 38.812724724411964, 44.5948326587677, 47.80703969299793, 47.978022918105125, 43.989745527505875, 42.2230227291584, 46.7372564971447, 49.43627826869488, 50.10354146361351, 51.01873755455017, 50.40243722498417, 44.02615137398243, 52.595014572143555, 49.55762095749378, 37.636296451091766, 38.075001910328865, 42.42621302604675, 51.9475407153368, 54.88422833383083, 55.46764522790909, 55.73588043451309, 56.84315621852875, 48.141516745090485, 44.455600529909134, 47.80344508588314, 55.62542036175728, 55.09750708937645, 52.57538482546806, 49.83239561319351, 49.73373770713806, 54.27971497178078, 57.33510822057724, 60.35938113927841, 61.74487039446831, 42.000996842980385, 5.1868504006415606, 2.487619402818382, 0.14062485803151503, 0.2311476826434955, 1.1765698157250881, 39.819271713495255, 57.087684497237206, 46.080925315618515, 33.3584214001894, 34.941902831196785, 46.07850104570389, 54.129972606897354, 58.64319182932377, 12.000086680054665, 0.20560074801323935, 0.014434047789109172, 0.03447204711847007, 0.013261179865367012, 0.005159932470633066, 0.019740647658181842, 0.013279625945870066, 0.02786982531688409, 0.04717385636467952, 0.027812238367914688, 0.05804021937365178, 0.014678871175419772, 0.035645352909341455, 0.1646095866453834, 0.20279001211747527, 0.05509086142410524, 0.11010884394636378, 0.1618014185805805, 0.11669501865981147, 0.19144793244777247, 0.1127727904531639, 0.10978854785207659, 0.11646602157270536, 0.1467126508941874, 0.09121536713792011, 0.18871126289013773, 0.3032042254926637, 18.006656169891357, 53.20261336863041, 62.07193024456501, 48.73770475387573, 35.50588756799698, 29.73012149333954, 47.93893061578274, 52.949539348483086, 59.77366916835308, 11.452305223792791, 0.30452426872216165, 0.23170588159700856, 3.931992673315108, 12.267063204199076, 12.183487638831139, 27.125534154474735, 44.65772308409214, 59.019649028778076, 57.15532086789608, 55.08542753756046, 52.925486639142036, 54.725244864821434, 53.467052578926086, 57.66975626349449, 51.10210508108139, 53.18678341805935, 50.18478870391846, 55.19948221743107, 47.605285719037056, 38.89092832803726, 41.00974403321743, 39.25527557730675, 38.54069732129574, 42.20867469906807, 46.675091832876205, 50.42074464261532, 46.90424233675003, 46.96391053497791, 49.83616501092911, 48.36381621658802, 47.89124697446823, 43.245684653520584, 40.01847602427006, 38.720138892531395, 39.64891165494919, 39.767529889941216, 38.36396120488644, 36.4459153264761, 38.6956188082695, 39.68435995280743, 38.313142731785774, 40.02577543258667, 38.079485669732094, 39.827110692858696, 39.282406121492386, 40.23858301341534, 37.60201469063759, 37.135726511478424, 36.75174191594124, 37.699570655822754, 38.23011338710785, 49.6725457906723, 51.90611153841019, 53.2378488779068, 55.943505093455315, 50.085982605814934, 53.47112976014614, 53.05318258702755, 48.261046931147575, 49.82259213924408, 50.803555101156235, 54.33549977838993, 49.01412092149258, 48.284867852926254, 43.64062786102295, 42.99199506640434, 51.86114855110645, 52.6639998704195, 52.007581293582916, 51.639859825372696, 49.78349223732948, 50.469739213585854, 48.09844985604286, 48.26613485813141, 46.4236631244421, 43.386455699801445, 39.999857023358345, 41.010348200798035, 39.491383507847786, 40.00819757580757, 42.24055878818035, 39.50489178299904, 39.67028930783272, 39.15046960115433, 41.55369244515896, 41.32241025567055, 40.25652565062046, 36.54999554157257, 42.17496670782566, 40.5060088634491, 39.35467064380646, 48.61600488424301, 50.67994773387909, 50.22109195590019, 46.28573052585125, 45.361209735274315, 48.81031505763531, 53.280000016093254, 53.455869778990746, 54.19777236878872, 55.904454588890076, 46.46078713238239, 54.97124366462231, 53.97682562470436, 40.18294259905815, 40.3353676199913, 43.11429910361767, 53.92190337181091, 57.010902017354965, 55.95992021262646, 56.84566408395767, 58.63199383020401, 50.58389648795128, 46.98639772832394, 50.10170616209507, 57.53030754625797, 57.81984061002731, 56.16954356431961, 54.60318021476269, 53.44207651913166, 56.78972348570824, 61.95812255144119, 63.45016568899155, 66.70366510748863, 42.933219820261, 8.095454201102257, 5.352415116503835, 2.477778880856931, 0.36301743937656283, 1.1413119826465845, 45.503018125891685, 62.12074622511864, 52.09051564335823, 40.961745008826256, 39.98561158776283, 50.691624507308006, 60.35900115966797, 67.49570980668068, 16.33290108293295, 0.5884312000125647, 0.06442875645007007, 0.12731124821584672, 0.09143151764874347, 0.18281761585967615, 0.10072374090668745, 0.23063324071699753, 0.09031981753651053, 0.11628223612206057, 0.17601917206775397, 0.11632508772891015, 0.2762760501354933, 0.1033014127460774], [0.014779360753891524, 0.05464585483423434, 0.027166905711055733, 0.04466953098017257, 0.03732849560037721, 0.07113500323612243, 0.00947999868003535, 0.04203706266707741, 0.02849479529686505, 0.04506527751800604, 0.06138289703812916, 0.04207995880278759, 0.06215194385731593, 0.06371331866830587, 5.154850417748094, 35.87333545088768, 51.36089779436588, 41.81257255375385, 33.02385315299034, 21.092227399349213, 21.305699944496155, 31.263540610671043, 48.03356073796749, 10.941993556916714, 0.10155902811675332, 0.14997200021753088, 0.959172259317711, 4.583382932469249, 3.883659979328513, 20.793177746236324, 44.58002485334873, 55.61114452779293, 49.38348390161991, 49.054619148373604, 45.1969825476408, 47.86545015871525, 47.415284514427185, 49.11689780652523, 48.89787755906582, 50.70314548909664, 49.81898233294487, 46.321004033088684, 43.68685618042946, 37.22770057618618, 37.16208189725876, 36.86156742274761, 35.341455191373825, 38.35881628096104, 42.109234035015106, 47.78627760708332, 46.2748859077692, 45.72320111095905, 46.15960769355297, 45.91247275471687, 44.48792539536953, 43.68274860084057, 40.5958816409111, 38.599141985177994, 33.90881426632404, 33.777212128043175, 35.15384025871754, 34.29515093564987, 34.53046850860119, 36.28737263381481, 35.48421733081341, 37.25676901638508, 34.05363969504833, 33.32782544195652, 36.09067618846893, 37.68102765083313, 34.714728221297264, 33.76290589570999, 35.124391838908195, 35.88841304183006, 39.21432137489319, 47.25477732717991, 51.49436183273792, 46.337734535336494, 44.88131448626518, 44.75952722132206, 48.704521134495735, 49.92690034210682, 46.324537843465805, 48.28738331794739, 45.84200173616409, 47.91425473988056, 49.676318988204, 51.73009358346462, 44.646365493535995, 44.39900256693363, 49.96964804828167, 46.123585626482964, 47.32638828456402, 44.910154938697815, 44.02623496949673, 43.5796183347702, 42.26725235581398, 41.1101308465004, 38.91588918864727, 36.67411968111992, 36.399402022361755, 36.42481125891209, 36.302476823329926, 38.58513593673706, 36.54303431510925, 37.54092536866665, 36.34469635784626, 37.410466969013214, 37.848617658019066, 37.24454887211323, 36.421121656894684, 35.19069068133831, 35.967350006103516, 37.0544146746397, 37.38259546458721, 42.90687583386898, 47.237872034311295, 46.15752540528774, 43.826285898685455, 46.03277429938316, 48.056416511535645, 47.64744445681572, 48.83250966668129, 46.064665988087654, 52.13970020413399, 48.38460110127926, 47.829124107956886, 54.69231203198433, 42.824541851878166, 37.34103709459305, 38.41523565351963, 38.761951848864555, 48.97610016167164, 54.431486427783966, 53.30282919108868, 55.88556580245495, 49.189781695604324, 41.99958711862564, 49.34124916791916, 55.377027690410614, 52.82582178711891, 56.831886023283005, 56.86782069504261, 55.96996307373047, 56.948817148804665, 54.56243880093098, 56.193087100982666, 59.16803486645222, 31.50254588574171, 2.6109158992767334, 0.8700700092595071, 0.3264364163624123, 0.0863478283281438, 1.0359280812554061, 36.24246284365654, 51.50940142571926, 47.30135902762413, 37.94455870985985, 33.23735989630222, 34.11360427737236, 43.71543824672699, 43.18690560758114, 6.271192515268922, 0.13704058161238208, 0.040662378814886324, 0.07757593222777359, 0.12867675541201606, 0.03960570895287674, 0.006392248742486117, 0.029858408161089756, 0.05072215346444864, 0.00980391274424619, 0.04720677432487719, 0.11818898419733159, 0.017434089786547702, 0.07081023199134506, 0.059745259131886996, 0.017102720848924946, 0.020354370390123222, 0.02961752557894215, 0.025613651851017494, 0.058746395152411424, 0.13552713469834998, 0.11005304928403348, 0.030567010762752034, 0.007359831661233329, 0.01849049804150127, 0.02798341472953325, 0.015057096534292214, 0.04547958516923245, 8.189767990261316, 43.79743404686451, 57.86266431212425, 45.196009799838066, 35.29405273497105, 18.127651177346706, 30.43500456959009, 42.5331848859787, 52.57255017757416, 11.577096227556467, 0.12555142311612144, 0.08437614233116619, 1.9755319249816239, 6.769672092050314, 3.329365672543645, 20.889029502868652, 47.36171878874302, 58.58852796256542, 51.80035561323166, 52.6275522261858, 47.90779888629913, 50.55687993764877, 50.42023167014122, 50.431931242346764, 50.387477427721024, 53.067637011408806, 50.357242450118065, 48.955577462911606, 44.37411770224571, 38.21324609220028, 39.82918918132782, 39.380129277706146, 36.77676357328892, 40.89511178433895, 44.2114332318306, 47.765264734625816, 47.94717237353325, 47.67968192696571, 47.47407875955105, 47.67902456223965, 45.933706015348434, 45.27835138142109, 42.50140339136124, 39.71019096672535, 36.25879056751728, 34.97729033231735, 36.96075350046158, 36.25099718570709, 35.73677837848663, 37.8236947953701, 37.43466027081013, 38.70249643921852, 35.628294199705124, 35.69646634161472, 36.93867668509483, 40.52664555609226, 36.388614401221275, 35.78961834311485, 37.31478430330753, 37.0094820857048, 39.704578667879105, 48.33985850214958, 54.504168927669525, 46.07878603041172, 47.735580727458, 45.888473242521286, 50.48219874501228, 51.468656212091446, 48.534396663308144, 49.05417837202549, 47.58125580847263, 49.51602078974247, 50.18207184970379, 52.16617338359356, 45.48583544790745, 46.22705027461052, 51.991895735263824, 47.314114943146706, 49.44646932184696, 48.04886631667614, 46.24566167593002, 45.233190804719925, 43.92438143491745, 42.17558227479458, 39.70242418348789, 40.46397551894188, 39.28449220955372, 38.49815860390663, 38.52988690137863, 38.41750033199787, 37.67413102090359, 38.98033373057842, 38.36729742586613, 38.925411477684975, 39.62300464510918, 39.04245659708977, 37.02589340507984, 36.65295481681824, 39.00972135365009, 39.065813943743706, 38.99490214884281, 45.2673015743494, 49.74557787179947, 47.795241326093674, 46.78165711462498, 46.04941740632057, 49.888856783509254, 50.394852831959724, 50.37255942821503, 48.47134284675121, 53.94591428339481, 47.906985729932785, 49.72854718565941, 55.94586096704006, 43.63324485719204, 38.301720544695854, 39.625755697488785, 43.8126902282238, 50.94708479940891, 56.65457993745804, 55.903930217027664, 56.87969125807285, 50.98576672375202, 44.329880475997925, 50.54718665778637, 57.63670563697815, 55.42090393602848, 59.055766090750694, 59.599159732460976, 57.713355123996735, 59.310337230563164, 57.00256146490574, 58.32123130559921, 62.45488129556179, 32.793475314974785, 3.6447812849655747, 1.0957576520740986, 0.46353567217011005, 0.18914072890765965, 1.2264314526692033, 39.789249524474144, 57.36687071621418, 48.79678018391132, 43.36987338960171, 39.178481698036194, 40.621043890714645, 50.09108953177929, 52.0054230093956, 9.05847167596221, 0.15643327147699893, 0.02998527645104332, 0.037404895992949605, 0.04293841957405675, 0.015485725780308712, 0.0633018571534194, 0.03350911421875935, 0.08079357285168953, 0.02097580218105577, 0.009154857289104257, 0.014764716324862093, 0.02427805320621701, 0.0563010890618898, 0.1346119775553234, 0.12322148017119616, 0.07303108664928004, 0.10168717475607991, 0.16148921189596877, 0.17658589087659493, 0.2893591340398416, 0.1799138740170747, 0.17080436751712114, 0.08406012842897326, 0.1695473029394634, 0.15367965126642957, 0.10401504710898735, 0.20985993352951482, 9.810045696794987, 51.27995453774929, 67.04756945371628, 54.887967333197594, 46.32495202124119, 31.89527191221714, 32.991133108735085, 42.30006739497185, 58.7341171503067, 14.016552027314901, 0.2620124170789495, 0.40517270390409976, 2.716207061894238, 9.453062452375889, 6.998445466160774, 25.50011247396469, 47.59806610643864, 60.052631199359894, 55.44831566512585, 56.23491145670414, 49.45193722844124, 51.812598556280136, 51.25236041843891, 54.44607384502888, 52.320076525211334, 55.4778628796339, 53.115708231925964, 51.87545858323574, 46.751486733555794, 40.509098097682, 40.7805897295475, 40.70723086595535, 39.17923025786877, 42.90257826447487, 46.432243064045906, 49.55965384840965, 49.45967361330986, 49.376705065369606, 48.97764287889004, 50.80443285405636, 48.57104949653149, 47.68099285662174, 44.804406613111496, 42.077847719192505, 38.21011126041412, 36.22678868472576, 39.77482549846172, 38.60470108687878, 38.552032113075256, 41.20736762881279, 38.359568640589714, 42.173074409365654, 37.036152854561806, 37.05339252948761, 38.82698155939579, 42.373863235116005, 38.44998098909855, 36.38616353273392, 38.045534491539, 40.749704986810684, 42.207770347595215, 50.45617014169693, 56.36017933487892, 49.65284384787083, 46.564985141158104, 46.25015303492546, 53.78844693303108, 52.43648327887058, 50.28187349438667, 50.55171601474285, 50.44689103960991, 50.156480222940445, 51.606459617614746, 52.030467465519905, 48.85425589978695, 47.84364312887192, 53.640699461102486, 49.629782885313034, 52.89461329579353, 50.73720686137676, 49.36274841427803, 48.37870001792908, 45.54462969303131, 44.66425113379955, 42.06242814660072, 42.50778704881668, 40.26139698922634, 39.58164766430855, 39.61434870958328, 40.980694591999054, 39.31015603244305, 40.7648091763258, 39.571844190359116, 41.48275025188923, 41.87714248895645, 42.302012890577316, 40.251479521393776, 38.42427536845207, 40.057412534952164, 41.12438768148422, 41.02737508714199, 47.4664905667305, 52.80950166285038, 50.54655209183693, 48.48868891596794, 51.632176637649536, 53.39883103966713, 52.21375063061714, 52.22543120384216, 51.28097288310528, 54.514264985919, 50.229094326496124, 50.66132873296738, 57.95767821371555, 48.036136999726295, 40.54965332150459, 42.66457423567772, 43.72407138347626, 53.68005774915218, 60.405947640538216, 57.68985338509083, 59.323879703879356, 55.19701614975929, 46.03352665901184, 54.57857273519039, 59.87548090517521, 56.433036625385284, 61.18754670023918, 62.47474282979965, 61.07451796531677, 63.133524879813194, 58.55032101273537, 60.757014602422714, 63.28954450786114, 34.413001611828804, 3.8477991661056876, 1.331300837919116, 1.6867881501093507, 0.43777824961580336, 1.5885437093675137, 43.689459040760994, 63.367216140031815, 59.64211642742157, 53.46907787024975, 42.42293760180473, 47.102838680148125, 56.33982002735138, 62.545833215117455, 13.137586042284966, 0.500554027967155, 0.1981406201957725, 0.18280946707818657, 0.13816661259625107, 0.16789171990239993, 0.14361031033331528, 0.09576312193530612, 0.16202565107960254, 0.09014014358399436, 0.12928936863318086, 0.1614544348558411, 0.14904372190358117, 0.14545805024681613], [0.02215750537288841, 0.05534698771953117, 0.017880662308016326, 0.08506220590788871, 0.030244703448261134, 0.030966933736635838, 0.01406616704116459, 0.040189096398535185, 0.08626922746771015, 0.04830674108234234, 0.008980403417808702, 0.06304021299001761, 0.058685954645625316, 0.0660042543313466, 2.3645024467259645, 29.94093608111143, 47.00937509536743, 39.93872590363026, 36.33559204638004, 32.97616571187973, 31.697196140885353, 36.02501951158047, 48.387469947338104, 19.42959811538458, 0.14173025730997324, 0.02726264276134316, 5.347640672698617, 10.067338440567255, 1.5506820660084486, 19.917583130300045, 43.494939878582954, 54.39100719988346, 46.380679830908775, 46.328003257513046, 42.13390991091728, 40.60362942516804, 41.18186719715595, 44.92022059857845, 45.94180338084698, 48.09338852763176, 48.562439158558846, 45.2592384070158, 40.33746510744095, 36.78809076547623, 34.50505927205086, 36.340053007006645, 36.916288286447525, 39.02967408299446, 39.27171349525452, 43.68587203323841, 45.4598144441843, 47.46887683868408, 44.970233514904976, 46.72201171517372, 45.506601333618164, 43.86892721056938, 41.299144104123116, 39.50506277382374, 33.770361095666885, 33.603504449129105, 34.062405824661255, 35.9029358625412, 33.962900564074516, 36.80751912295818, 35.23582085967064, 35.72399586439133, 34.75949741899967, 36.764114052057266, 33.724155575037, 36.336621791124344, 36.00606232881546, 35.50196997821331, 34.81025129556656, 34.3643756210804, 37.070016637444496, 49.24097254872322, 47.179681956768036, 49.12146516144276, 35.40836200118065, 45.32965622842312, 44.558255821466446, 45.797730311751366, 44.99935135245323, 45.89726597070694, 47.07613371312618, 50.80680772662163, 49.52274642884731, 53.14087428152561, 46.56385660171509, 46.53318464756012, 51.32288083434105, 47.22293883562088, 46.19696728885174, 42.44050405919552, 44.07571591436863, 43.80333133041859, 41.89237967133522, 40.12302741408348, 38.63631919026375, 37.7961652725935, 36.51641294360161, 36.16088502109051, 36.81329481303692, 37.21274457871914, 36.66760303080082, 38.28826166689396, 37.285810858011246, 36.556139811873436, 37.656412571668625, 37.6740550249815, 37.447005808353424, 37.70040661096573, 37.10693545639515, 37.093905955553055, 37.162268087267876, 41.19083471596241, 44.68021787703037, 46.30613923072815, 47.283184602856636, 45.293147787451744, 48.623555079102516, 45.68632788956165, 45.59528097510338, 47.902167588472366, 50.67470781505108, 54.7486288100481, 47.32631228864193, 49.83647659420967, 50.903292149305344, 38.052062541246414, 36.39668896794319, 35.91490902006626, 43.21795754134655, 53.42473424971104, 53.36540423333645, 52.89237901568413, 53.08209903538227, 46.032698303461075, 47.99991354346275, 52.44886301457882, 56.452974155545235, 59.37892735004425, 53.82156975567341, 52.49607168138027, 59.48849447071552, 55.696993321180344, 59.85531158745289, 51.957423985004425, 20.66940888762474, 0.8339240332134068, 1.3492680550552905, 0.29052896657958627, 0.014028822170075728, 0.7866704219486564, 33.67725849151611, 54.267373234033585, 46.880991384387016, 23.632026314735413, 23.13549555838108, 43.36355812847614, 47.59250320494175, 40.99398247897625, 10.726919397711754, 0.2966078685130924, 0.08967808986199088, 0.05559870565775782, 0.02661044152773684, 0.045563488674815744, 0.11612693429924548, 0.03731300697836559, 0.018540346245572437, 0.0193808359108516, 0.031076044288056437, 0.017484138370491564, 0.07211966250906698, 0.04861835033807438, 0.03410494377021678, 0.038215013264562, 0.03155190381221473, 0.04089889014721848, 0.028396618436090648, 0.03942376402847003, 0.011541465992195299, 0.019496996865200344, 0.07518580110627227, 0.02333994700165931, 0.00635546048215474, 0.06626471847994253, 0.08040088767302223, 0.04430477652931586, 3.4610566310584545, 35.94330869615078, 54.60778936743736, 47.874056696891785, 40.88453695178032, 33.247942328453064, 28.786829710006714, 37.56648279726505, 55.108085721731186, 21.00821390748024, 0.04979011617251672, 0.06414498144295067, 3.263612100854516, 9.747440256178379, 3.3754764357581735, 22.183711230754852, 45.38582481443882, 54.84386309981346, 49.42151606082916, 48.78299832344055, 44.13147032260895, 44.111152812838554, 43.85812819004059, 47.61017985641956, 49.74610224366188, 50.661473125219345, 50.861129611730576, 46.79684489965439, 43.20948779582977, 39.61920864880085, 35.8856999874115, 39.261343851685524, 38.36449317634106, 40.27696095407009, 42.3227483779192, 45.582551658153534, 45.570145323872566, 48.63169424235821, 46.56380720436573, 48.53741370141506, 48.40526059269905, 47.24248878657818, 43.33224020898342, 41.01665586233139, 36.22168555855751, 35.67165367305279, 36.55305057764053, 37.48502656817436, 34.82395716011524, 37.92223110795021, 37.4403827637434, 37.273985892534256, 36.450535878539085, 38.186617121100426, 35.29528386890888, 38.75712610781193, 36.55394732952118, 37.435317635536194, 36.555246859788895, 36.1294075101614, 38.81822682917118, 51.38006016612053, 51.11284330487251, 50.47602027654648, 37.84229479730129, 47.057347521185875, 45.74511833488941, 45.342275351285934, 46.744422912597656, 47.82276324927807, 48.016465455293655, 51.17001883685589, 51.61627069115639, 55.46844318509102, 47.82777898013592, 48.2580678910017, 52.17321440577507, 48.897402584552765, 49.02593448758125, 47.14690491557121, 45.4960834980011, 45.311679393053055, 45.20252265036106, 42.42645241320133, 40.401123091578484, 39.80388633906841, 37.589209377765656, 37.5258781760931, 37.41613246500492, 38.060467690229416, 38.84310029447079, 40.03205269575119, 38.02266351878643, 38.25694754719734, 39.99571144580841, 37.9252215474844, 39.271686896681786, 38.56881581246853, 38.5824266821146, 38.17928731441498, 39.27869372069836, 43.18640783429146, 46.921174228191376, 47.96842463314533, 48.64679083228111, 48.40602055191994, 50.144081488251686, 49.144142344594, 47.53677919507027, 51.28068409860134, 51.51038557291031, 57.55527600646019, 48.62656831741333, 51.11795023083687, 52.19575859606266, 39.199707359075546, 37.54823997616768, 38.279476538300514, 46.769547164440155, 56.03143997490406, 54.50207144021988, 54.46440026164055, 55.23636303842068, 47.8396001458168, 50.42246975004673, 56.05166628956795, 57.29360304772854, 61.03310778737068, 54.71332490444183, 53.97144131362438, 62.20940686762333, 58.1478276103735, 62.52021498978138, 54.16535250842571, 22.97754943370819, 1.9715765747241676, 1.7325182212516665, 0.32376032089814544, 0.07570595756988041, 0.9087439184077084, 37.891243770718575, 60.3994157910347, 51.25093549489975, 35.34768305718899, 27.532813400030136, 44.71692770719528, 53.52860547602177, 50.08723273873329, 13.950509671121836, 0.16664170572767034, 0.041832400602288544, 0.04328903611167334, 0.0561132774600992, 0.04011815079138614, 0.020197055491735227, 0.018741887579381, 0.04952719922584947, 0.023739639909763355, 0.01578478160809027, 0.04893903234915342, 0.05814658397866879, 0.015666950821469072, 0.079686563112773, 0.2174614107934758, 0.12954931327840313, 0.14895996311679482, 0.11783751047914848, 0.14899459172738716, 0.22216972924070433, 0.10075626181787811, 0.2523963205749169, 0.182657104160171, 0.11682479802402668, 0.1622729643713683, 0.2420339797390625, 0.2540106402011588, 4.188934648409486, 41.73810034990311, 62.14674822986126, 52.71995186805725, 48.411773443222046, 44.08037066459656, 42.485022470355034, 47.498051673173904, 60.52704714238644, 24.453511834144592, 0.22538619727129117, 0.13700031267944723, 8.508114907890558, 20.06897270679474, 4.190193330869079, 22.95402679592371, 47.82590948045254, 58.08002784848213, 50.22850915789604, 50.94949387013912, 45.88305473327637, 45.11269547045231, 45.26948265731335, 49.00299891829491, 51.24530799686909, 52.26736195385456, 53.20642076432705, 48.07741418480873, 44.42593552172184, 40.56717798113823, 37.78586782515049, 40.400241538882256, 40.071973353624344, 42.69340708851814, 43.68569724261761, 47.86359965801239, 46.73968456685543, 50.53768336772919, 47.31656961143017, 50.36212898790836, 51.9420500099659, 48.36711063981056, 47.017225474119186, 42.91894778609276, 37.36034765839577, 38.1035003811121, 37.78040371835232, 39.15323585271835, 37.65875704586506, 38.791141882538795, 40.12419015169144, 37.94715017080307, 38.737367168068886, 40.92904016375542, 37.304521054029465, 41.32661283016205, 37.81326815485954, 39.19916778802872, 38.74394841492176, 38.460859805345535, 40.606790855526924, 53.41997690498829, 52.28905878961086, 51.16757556796074, 38.126872926950455, 48.57263781130314, 46.27090372145176, 47.3714804649353, 46.83575861155987, 48.94553080201149, 50.508679524064064, 54.36148278415203, 54.59105506539345, 57.79532432556152, 49.776291623711586, 50.17310433089733, 53.04785907268524, 52.25033886730671, 50.61588317155838, 47.90300354361534, 47.60655105113983, 49.20860208570957, 46.86859264969826, 44.29686784744263, 41.86952009797096, 41.987971141934395, 39.38331350684166, 39.814958944916725, 40.26379466056824, 40.10517217218876, 41.15305334329605, 41.946348175406456, 39.85012985765934, 39.985338002443314, 41.722585782408714, 40.49584060907364, 42.17635743319988, 40.796184092760086, 40.63590109348297, 40.96974737942219, 41.29985846579075, 46.02346859872341, 50.078352615237236, 50.70833221077919, 50.14888063073158, 50.92407323420048, 53.90454590320587, 50.46486787497997, 49.86347034573555, 53.009085953235626, 55.68204492330551, 57.24835887551308, 50.031094551086426, 53.52115407586098, 54.00372438132763, 42.53643371164799, 40.01487761735916, 40.04854001104832, 48.96364443004131, 59.44274492561817, 57.95693725347519, 56.5066234767437, 56.62096694111824, 50.40084891021252, 52.83745676279068, 57.738334983587265, 62.647253572940826, 63.03158015012741, 59.453236162662506, 57.07975052297115, 63.665906712412834, 60.79149015247822, 65.23432195186615, 56.492488235235214, 24.27368838340044, 2.0424509653821588, 4.020173829048872, 0.5377260083332658, 0.17071973299607635, 1.143754064105451, 42.482073828577995, 66.10477164387703, 59.65236447751522, 36.31644867360592, 35.607174932956696, 56.227619647979736, 61.877791061997414, 60.4514691978693, 18.47763329744339, 0.457377033890225, 0.21469998318934813, 0.16724940593121573, 0.11803201254224405, 0.15578988881316036, 0.1628299758885987, 0.1605529332300648, 0.13279411650728434, 0.13700161885935813, 0.1802478256286122, 0.1658892273553647, 0.16007282305508852, 0.1315926091047004], [0.04101328850083519, 0.02395820240053581, 0.04644864078727551, 0.02457590489939321, 0.11989912993158214, 0.055033567623468116, 0.040177518894779496, 0.017630593793001026, 0.019541588808351662, 0.04832096063182689, 0.05220018880208954, 0.15362842823378742, 0.017515147155791055, 0.05333273955329787, 0.7293538225349039, 25.101418867707253, 53.36140684783459, 41.67574569582939, 35.677140578627586, 19.432290270924568, 28.55186741799116, 42.829052209854126, 48.38971942663193, 27.274750247597694, 0.0874339985603001, 0.048427596120745875, 6.294034514576197, 11.275943387299776, 0.8787403127644211, 12.31848394498229, 40.174928829073906, 57.33873702585697, 50.64002327620983, 49.79800745844841, 46.60925656557083, 44.959977865219116, 39.47694808244705, 40.529529601335526, 42.35718593001366, 43.10196876525879, 42.291772440075874, 42.68210269510746, 38.44176962971687, 36.663225665688515, 37.065084502100945, 36.827338859438896, 37.02078267931938, 37.63247385621071, 39.586815387010574, 42.341998144984245, 45.856608152389526, 48.39319624006748, 43.628567308187485, 46.60387985408306, 46.396885961294174, 46.41656130552292, 41.805987507104874, 38.9121387898922, 36.71550326049328, 36.05718098580837, 35.240430012345314, 35.946280136704445, 37.90844924747944, 34.85660880804062, 35.3400644659996, 37.292122319340706, 34.53732714056969, 35.67044533789158, 37.600604966282845, 36.26736290752888, 35.957204550504684, 35.924765691161156, 36.648357063531876, 35.82374811172485, 37.80932016670704, 47.53746695816517, 49.71365958452225, 46.89457945525646, 48.1549946218729, 48.62106241285801, 46.134658232331276, 45.258178263902664, 41.87312230467796, 43.95167917013168, 46.026360243558884, 49.824302047491074, 48.78976956009865, 51.90036244690418, 48.24034184217453, 47.63558529317379, 50.84135927259922, 47.46820047497749, 46.385592967271805, 44.40147243440151, 44.72463749349117, 43.2306070625782, 41.82858869433403, 39.47329267859459, 36.61965720355511, 36.84378057718277, 35.08450157940388, 37.058370262384415, 37.37485907971859, 37.38978087902069, 37.5365936011076, 36.90050393342972, 37.589277774095535, 38.13547566533089, 36.039629727602005, 37.83984772861004, 35.54987780749798, 36.34667605161667, 36.06643348932266, 38.426593244075775, 38.716855868697166, 38.193072974681854, 46.50173373520374, 45.87020002305508, 47.00822375714779, 45.11419638991356, 43.848522305488586, 42.936635836958885, 45.10946564376354, 43.603006079792976, 47.55057245492935, 49.253762662410736, 50.82302525639534, 49.3458317220211, 50.18905967473984, 46.68059393763542, 36.24629683792591, 35.79286716878414, 37.859439477324486, 48.92968185245991, 52.11151331663132, 52.96694241464138, 54.06193345785141, 49.85058903694153, 45.27500756084919, 51.180023699998856, 51.956462636590004, 56.90642662346363, 55.52035219967365, 56.528692692518234, 57.88849152624607, 60.17219178378582, 56.12354323267937, 43.230447471141815, 9.678441658616066, 0.7800150196999311, 0.9993739239871502, 0.20266154635464773, 0.060969387195655145, 1.0695084230974317, 37.13529713451862, 53.53719301521778, 45.06227217614651, 29.71973665058613, 33.99558641016483, 42.11955048143864, 43.20771709084511, 37.84326374530792, 8.48342003300786, 0.14521904900902882, 0.0225159998080926, 0.04275317209248897, 0.09647703089285642, 0.013880031765438616, 0.04612681957951281, 0.01680637386016315, 0.02872404471418122, 0.04740803735330701, 0.06984959603869356, 0.021992665097059216, 0.014623596016463125, 0.07417336324579082, 0.021456745416799095, 0.030125607299851254, 0.07894625596236438, 0.011899135715793818, 0.07550476875621825, 0.07656848159967922, 0.07511933436035179, 0.08037635969230905, 0.028582806589838583, 0.041733034449862316, 0.03406814066693187, 0.11562395113287494, 0.05754670230089687, 0.08121272301650606, 1.1295747687108815, 30.507003106176853, 59.56313766539097, 46.99220761656761, 41.70754238963127, 27.599741108715534, 37.24218539893627, 46.62578947842121, 53.387104868888855, 29.468722119927406, 0.15499536035349593, 0.12919643690111116, 6.28404057584703, 17.409588508307934, 2.1142027527093887, 14.494937807321548, 40.855282321572304, 58.89990985393524, 52.91478641331196, 52.718188762664795, 46.89832225441933, 46.623065024614334, 41.97741910815239, 43.787550777196884, 45.510233938694, 45.84611311554909, 45.034393072128296, 44.6094086766243, 40.095520690083504, 37.79309503734112, 36.354142650961876, 39.88723486661911, 39.33094471693039, 40.43008893728256, 40.87653458118439, 44.101892709732056, 48.079321682453156, 49.388598427176476, 45.16629919409752, 47.82994866371155, 48.025588765740395, 46.911458149552345, 43.617179319262505, 41.8952751159668, 38.05621951818466, 37.04953953623772, 36.27143248915672, 36.97287105023861, 38.09867084026337, 36.009102165699005, 36.44810400903225, 37.95033439993858, 35.486744195222855, 37.863854840397835, 38.15090663731098, 37.413107827305794, 36.26170501112938, 37.20717027783394, 37.269106954336166, 37.123764753341675, 39.435214921832085, 48.753451108932495, 52.118181958794594, 49.55606684088707, 47.83930376172066, 51.672591269016266, 48.32868330180645, 48.24373506009579, 42.94051542878151, 45.296673998236656, 47.37372614443302, 51.527978628873825, 51.36144496500492, 54.03994023799896, 50.14292635023594, 49.55561846494675, 53.2493432611227, 49.150655195117, 47.147995457053185, 46.04903742671013, 46.0357229411602, 44.82655942440033, 45.00344753265381, 41.445873230695724, 39.74174827337265, 39.26753371953964, 37.219823598861694, 38.23613986372948, 38.664658069610596, 38.90014663338661, 38.35918106138706, 38.83252926170826, 38.631162866950035, 39.5829813927412, 37.586473524570465, 38.063450530171394, 38.26358199119568, 39.504519402980804, 38.46348166465759, 38.95472310483456, 39.47915576398373, 41.36493377387524, 47.68362991511822, 46.47675767540932, 48.515678867697716, 49.13610577583313, 46.026455238461494, 44.32997927069664, 46.489156410098076, 45.507570281624794, 49.42254200577736, 51.50014892220497, 52.80764736235142, 50.247154757380486, 51.538089886307716, 49.354863837361336, 38.499062955379486, 38.33509795367718, 39.649698212742805, 50.55811867117882, 55.73234282433987, 56.5850892663002, 56.050678342580795, 51.249989345669746, 47.83215254545212, 54.13722261786461, 55.84737405180931, 59.49804335832596, 56.30762815475464, 56.73765107989311, 59.49834354221821, 60.51056742668152, 59.25799123942852, 44.142641723155975, 11.349559687078, 1.334017098415643, 3.9193562138825655, 0.7676821283530444, 0.08379630235140212, 0.9852044249419123, 40.15704698860645, 58.76982383430004, 52.73587301373482, 32.768263667821884, 32.29664817452431, 49.22868400812149, 51.066007018089294, 46.60001926124096, 10.822850950062275, 0.23105852102162316, 0.028362095581542235, 0.07468604628229514, 0.07482810076908208, 0.01430685852028546, 0.06102354913309682, 0.03946847471524961, 0.055910095979925245, 0.04032375909446273, 0.009616291317797732, 0.018025666831817944, 0.028499864165496547, 0.031883120609563775, 0.1680349840898998, 0.1191828609444201, 0.18805750500177965, 0.08917203420423903, 0.27663257787935436, 0.11593204631935805, 0.1724713944713585, 0.22289505985099822, 0.09818877224461176, 0.1922825665678829, 0.22333732049446553, 0.18817323551047593, 0.19725566846318543, 0.1766278815921396, 1.4158033160492778, 34.6157169342041, 68.04437756538391, 54.939830750226974, 47.92810119688511, 29.23457868397236, 38.66978399455547, 52.83369116485119, 62.788290604949, 34.33061823248863, 0.6619986367877573, 0.17555739294039086, 9.012984316796064, 18.22916842997074, 2.8321412159129977, 15.291147083044052, 43.86209137737751, 60.28684303164482, 56.08713738620281, 56.937216371297836, 51.49259872734547, 48.88446807861328, 43.540955409407616, 46.64561301469803, 47.798904329538345, 48.950481936335564, 46.900697126984596, 47.576327472925186, 42.18876376748085, 38.925609067082405, 39.573542699217796, 40.952002331614494, 40.91698341071606, 42.561831548810005, 44.25298020243645, 46.780437380075455, 49.79929938912392, 51.41146168112755, 46.41256012022495, 49.312013536691666, 50.44390060007572, 50.46304777264595, 46.124220192432404, 42.60664254426956, 41.38781234622002, 38.848097026348114, 37.291126772761345, 39.523153603076935, 40.592632815241814, 37.258969098329544, 37.47912548482418, 40.03312423825264, 37.7626396715641, 39.813887402415276, 41.49247393012047, 39.987807869911194, 38.63364413380623, 40.01241534948349, 39.73399668931961, 39.85703408718109, 41.06977321207523, 49.73773509263992, 55.229690596461296, 48.72173801064491, 52.088083773851395, 53.14091607928276, 50.26058703660965, 48.69081526994705, 43.60470838844776, 45.951466262340546, 49.31527756154537, 52.10588961839676, 53.645905181765556, 54.644947573542595, 51.82204484939575, 51.475602239370346, 54.04447339475155, 50.427645072340965, 50.31993605196476, 47.90200799703598, 47.9401845484972, 46.59067936241627, 48.115894719958305, 43.24692718684673, 41.77876576781273, 41.195717453956604, 39.38212797045708, 40.369318798184395, 41.89089775085449, 41.261214539408684, 41.27199836075306, 41.17080599069595, 40.29135078191757, 40.96327632665634, 38.55612829327583, 41.046244874596596, 40.34031495451927, 41.879213377833366, 39.79682631790638, 40.34893289208412, 42.52261005342007, 43.164828792214394, 50.820688381791115, 49.87404517829418, 51.70115813612938, 51.97019889950752, 49.45450209081173, 47.53078691661358, 50.21710216999054, 49.24514852464199, 50.2319023758173, 54.539412036538124, 53.7832298129797, 53.0581147223711, 52.596181109547615, 50.64859561622143, 40.648562014102936, 39.72196273505688, 41.634666100144386, 54.18628938496113, 56.549994349479675, 58.042170479893684, 59.122669100761414, 55.63755311071873, 49.29306015372276, 57.4574426561594, 57.57257267832756, 62.383103147149086, 57.975833639502525, 59.09398823976517, 60.97680240869522, 63.20081166923046, 57.92915694415569, 47.25100792944431, 11.554987113922834, 1.4544435613788664, 3.949196725152433, 1.2192719243466854, 0.4958792100660503, 1.2798268999904394, 44.33197796344757, 65.66853985190392, 57.81277298927307, 42.32602380216122, 47.87059128284454, 56.06675148010254, 58.49036023020744, 55.069453194737434, 14.913316257297993, 0.38809600460808724, 0.10450816713273525, 0.23536233929917216, 0.18244817474624142, 0.15420659095980227, 0.09161790061625652, 0.22203863627510145, 0.1635836565401405, 0.1459370768861845, 0.11919302094611339, 0.17401152901584283, 0.06771603279048577, 0.2950784208951518], [0.02087350640067598, 0.012423859170667129, 0.07439565131790005, 0.04245458010700531, 0.022181589920364786, 0.04089385467523243, 0.10680267252610065, 0.12037831984343939, 0.022906432568561286, 0.0219818464393029, 0.06287165640969761, 0.02784115986287361, 0.04086295906745363, 0.031673790435888804, 0.10793460358399898, 16.659687347710133, 50.967007130384445, 45.8423513174057, 40.85452236235142, 24.60157848894596, 20.13749063014984, 32.471237406134605, 46.525695249438286, 35.29948264360428, 1.2207262963056564, 0.13019324513152242, 1.9597797514870763, 12.843329831957817, 1.0257770447060466, 7.4795732740312815, 30.545282252132893, 53.01951639354229, 55.41684575378895, 52.40516155958176, 48.97169999778271, 45.82696594297886, 41.97145722806454, 39.78917732834816, 39.66368906199932, 40.717988088727, 38.460088446736336, 38.82316276431084, 35.66584378480911, 37.75327317416668, 39.00075763463974, 39.28537756204605, 38.025942742824554, 36.46150968968868, 37.11542420089245, 40.43765813112259, 45.823481529951096, 47.292418107390404, 44.6130982786417, 42.70090788602829, 48.701321706175804, 46.2765122205019, 43.76716107130051, 39.21225808560848, 35.19154943525791, 33.77233698964119, 35.50728589296341, 35.20821914076805, 36.32113762199879, 35.19662596285343, 37.028348073363304, 36.20986819267273, 35.82108065485954, 36.582901775836945, 35.37292890250683, 35.752840116620064, 36.25475138425827, 36.45758830010891, 35.365903079509735, 34.12026911973953, 39.88307408988476, 47.741090431809425, 49.559870436787605, 51.093730330467224, 46.59818395972252, 49.407247826457024, 49.1269064694643, 52.57064267992973, 48.22417750954628, 49.77718077600002, 48.32356497645378, 53.073990270495415, 46.17512226104736, 52.73103967308998, 48.38529646396637, 47.933705896139145, 50.668582543730736, 47.64915816485882, 45.90328864753246, 42.31577955186367, 42.93015718460083, 43.02118889987469, 41.78271375596523, 41.24670311808586, 39.67657417058945, 35.87108597159386, 36.19946055114269, 36.66973851621151, 37.106905058026314, 37.78051771223545, 37.11991176009178, 37.78471648693085, 37.50233083963394, 36.78492173552513, 35.94799384474754, 36.901419684290886, 37.95380361378193, 36.54640853404999, 36.782326474785805, 37.18375213444233, 36.03233031928539, 37.54747621715069, 39.95060406625271, 44.03020955622196, 43.20994757115841, 42.247706204652786, 39.209206849336624, 39.15901534259319, 38.2719187438488, 42.54921242594719, 44.60189267992973, 46.11253581941128, 48.3692841231823, 50.217603743076324, 48.2390271127224, 50.979166477918625, 40.87275758385658, 36.22255951166153, 35.39942488074303, 39.27792616188526, 50.71828007698059, 55.50622835755348, 55.61453774571419, 54.04109537601471, 51.331468373537064, 50.237841457128525, 50.6244783103466, 50.6258462369442, 52.98147663474083, 56.4665812253952, 56.70841544866562, 57.643020898103714, 53.58132004737854, 33.574253618717194, 5.613443059846759, 1.516782185062766, 2.8512480156496167, 0.6040168355684727, 0.07616885734023526, 1.3174484437331557, 36.170889884233475, 55.81390544772148, 47.121104300022125, 40.606019496917725, 27.14176308363676, 42.832206040620804, 47.725431472063065, 43.76749165356159, 10.193670261651278, 0.21916555997449905, 0.08336102531757206, 0.002375347075940226, 0.022478521350421943, 0.023202504962682724, 0.08142846534610726, 0.0355443985608872, 0.019376802338229027, 0.07998467641300522, 0.021285676666593645, 0.025393580945092253, 0.02531802103476366, 0.029427836343529634, 0.030930715074646287, 0.036405104328878224, 0.03254577313782647, 0.02537815355026396, 0.08330238080816343, 0.0394279311876744, 0.2297434353386052, 0.07131691847462207, 0.03395297419046983, 0.019424804449954536, 0.03630203485954553, 0.06672647534287535, 0.003046352476303582, 0.01737813185172854, 0.22700531117152423, 21.957682259380817, 59.664561823010445, 52.32586741447449, 46.91807359457016, 24.090851694345474, 27.638930305838585, 42.20063433051109, 52.45475649833679, 37.70636089146137, 1.0677226376719773, 0.1419456730945967, 2.257009777240455, 8.677300829440355, 2.887908685952425, 10.378956869244576, 32.816578075289726, 55.03799848258495, 55.549690425395966, 53.29079143702984, 52.42270901799202, 49.68920409679413, 42.97743804752827, 40.86564056575298, 41.387048587203026, 43.49405452609062, 41.67680963873863, 40.67617513239384, 37.99794964492321, 40.59463530778885, 40.56528188288212, 41.62717670202255, 40.95318406820297, 39.69540975987911, 39.52246583998203, 42.77832493185997, 46.775129064917564, 47.14062765240669, 45.6853399425745, 43.07793885469437, 50.36400988698006, 48.17937031388283, 45.96468195319176, 41.47482767701149, 36.84879630804062, 36.013072952628136, 36.33157566189766, 36.99461728334427, 37.714560851454735, 36.209537610411644, 39.1806323826313, 38.5326037555933, 37.23075941205025, 38.73726077377796, 37.952701672911644, 36.31299465894699, 38.56308571994305, 37.88530848920345, 36.598165556788445, 35.40127918124199, 40.76361604034901, 49.870952144265175, 50.109385550022125, 51.50676056742668, 49.30823653936386, 52.144054770469666, 50.89261472225189, 54.56524305045605, 48.684017434716225, 50.809456184506416, 48.754978626966476, 54.502041041851044, 49.099091961979866, 55.02814941108227, 51.51014618575573, 50.193653628230095, 51.90587595105171, 50.3018794208765, 48.523274660110474, 44.43440906703472, 43.997128531336784, 44.723611548542976, 43.31899031996727, 42.99942746758461, 41.369983702898026, 37.97966122627258, 37.85381957888603, 38.45490552484989, 38.78024406731129, 37.95916132628918, 38.07905249297619, 39.54785227775574, 39.08534489572048, 37.177197486162186, 37.7199337631464, 40.03167271614075, 38.373031318187714, 38.40974494814873, 38.16091150045395, 39.02205929160118, 36.79225914180279, 38.73477950692177, 41.43646113574505, 45.68205311894417, 45.173841789364815, 45.32670758664608, 40.786597207188606, 40.674047246575356, 40.38052439689636, 45.08086457848549, 46.695561334490776, 49.35214318335056, 50.72294242680073, 52.18877077102661, 49.298387467861176, 54.01788242161274, 42.31149338185787, 38.321563079953194, 37.56747454404831, 43.00452679395676, 52.056492269039154, 56.64359472692013, 57.61047564446926, 55.04137270152569, 53.45222197473049, 51.466228142380714, 52.93399438261986, 55.17362840473652, 56.03837460279465, 60.20031787455082, 58.48408676683903, 58.12839925289154, 54.95624966919422, 36.20346933603287, 6.340968171134591, 2.388847265392542, 4.5248698722571135, 0.30509055708535016, 0.11197547151823528, 1.357414461672306, 40.76130576431751, 61.42777740955353, 50.468720868229866, 40.36268435418606, 34.40972998738289, 47.17769846320152, 51.38360537588596, 49.831464663147926, 12.554839812219143, 0.20542478479910642, 0.05248425324680284, 0.03586268714570906, 0.041190539341187105, 0.027493304114614148, 0.0538274700375041, 0.026190725475316867, 0.02004579837375786, 0.05539440353459213, 0.02022922388277948, 0.022516255849041045, 0.03151431774313096, 0.08243637610576116, 0.09296644973801449, 0.10332434510928579, 0.17040322185494006, 0.06655418575974181, 0.15894502575974911, 0.08939515348174609, 0.3387914237100631, 0.23855833889683709, 0.11535837358678691, 0.14972955541452393, 0.22094377549365163, 0.11202792651602067, 0.20611002459190786, 0.13605733984149992, 0.4712895123520866, 25.19274316728115, 64.72893387079239, 58.60281139612198, 52.754761800169945, 32.89440169930458, 30.376867689192295, 44.60973545908928, 57.017050087451935, 43.11221681535244, 1.8891945015639067, 0.23139052820624784, 3.9566901605576277, 25.534992702305317, 5.914066778495908, 9.238742552697659, 34.46654453873634, 54.344060719013214, 57.81403072178364, 57.097598165273666, 55.97720168530941, 51.72765411436558, 45.531581193208694, 42.588886097073555, 44.08715710043907, 45.27923293411732, 43.68385814130306, 42.68712602555752, 39.813150241971016, 42.78464779257774, 43.06183531880379, 43.384244218468666, 42.139210626482964, 41.59233257174492, 40.74921101331711, 44.97596740722656, 51.8461811542511, 50.12175388634205, 45.31547538936138, 43.358124420046806, 52.56253771483898, 49.72494877874851, 49.57215137779713, 44.44251023232937, 38.617202416062355, 37.03125111758709, 37.87481725215912, 38.95381115376949, 40.23397006094456, 38.59947256743908, 41.47284038364887, 40.67939355969429, 39.42568123340607, 40.97492270171642, 40.17121262848377, 39.07179482281208, 40.4305487126112, 40.36260075867176, 38.008577674627304, 37.31600783765316, 44.051891192793846, 53.180692344903946, 51.09204322099686, 51.91952861845493, 51.79654821753502, 52.69360788166523, 54.483665227890015, 57.41672024130821, 49.45150025188923, 53.389601334929466, 50.70990152657032, 56.276583820581436, 51.15231938660145, 57.27749951183796, 53.15813675522804, 51.58181793987751, 54.199166893959045, 53.22028622031212, 49.70544062554836, 46.17486007511616, 48.82742553949356, 46.39976620674133, 45.34809663891792, 45.16650818288326, 42.577095329761505, 38.22277598083019, 40.66481374204159, 39.67385731637478, 40.037638396024704, 40.1058067381382, 40.313803777098656, 42.46033899486065, 42.09829442203045, 39.77018974721432, 39.750704392790794, 41.61613829433918, 40.18840670585632, 39.28815521299839, 41.60647541284561, 41.160269156098366, 39.008034244179726, 41.19118049740791, 43.157533183693886, 48.04070055484772, 47.661435306072235, 46.31840117275715, 42.62138195335865, 42.874440774321556, 41.24285012483597, 47.278047278523445, 50.311948880553246, 51.73136651515961, 53.341321125626564, 53.232141584157944, 50.993263721466064, 54.863443449139595, 44.98032957315445, 39.93690960109234, 38.35639201104641, 43.83516222238541, 55.07419154047966, 59.48187902569771, 60.971395298838615, 57.36549898982048, 57.29891136288643, 55.39704501628876, 56.28732584416866, 56.948782950639725, 58.119621723890305, 63.95920157432556, 62.358089089393616, 61.24649293720722, 55.308847948908806, 37.735227942466736, 7.48801214620471, 4.013702776283026, 6.469151917845011, 2.3711053049191833, 0.18160947365686297, 1.6416830266825855, 44.58118379116058, 68.06634798645973, 59.7049118578434, 53.9756590873003, 40.76365403831005, 58.815922960639, 61.73048436641693, 58.143837824463844, 17.665611170232296, 0.4405887331813574, 0.2325964588089846, 0.10372454082244076, 0.1778405805816874, 0.11015283103915863, 0.12645092094317079, 0.13054741284577176, 0.08923800371121615, 0.2537874021800235, 0.2778142847819254, 0.06650233932305127, 0.11687550155329518, 0.17147452686913311], [0.041228158806916326, 0.035393323269090615, 0.060634893816313706, 0.053890407871222124, 0.04181260010227561, 0.02067909710603999, 0.12920489738462493, 0.0063010258054418955, 0.046218593561206944, 0.038368997775251046, 0.05681729729985818, 0.05882376404770184, 0.03034806235518772, 0.01038127951687784, 0.06094743075664155, 7.602541800588369, 44.72030192613602, 46.12931951880455, 36.16282671689987, 23.100907914340496, 28.845253475010395, 39.91816520690918, 41.10358379781246, 42.35376991331577, 3.2885171519592404, 0.09714458530652337, 1.4223571331240237, 4.605000922456384, 1.4685175311751664, 2.765118037350476, 20.0266220793128, 46.13075204193592, 50.52707813680172, 52.708028107881546, 49.517088532447815, 48.32442373037338, 43.25522594153881, 38.46309408545494, 36.99587881565094, 37.80294790863991, 38.16868968307972, 36.09926752746105, 37.93351650238037, 41.2644025683403, 44.346584379673004, 42.48709335923195, 39.726788476109505, 38.95153887569904, 40.67593194544315, 46.04655236005783, 47.46569640934467, 46.22451961040497, 43.20147782564163, 45.64407415688038, 46.92797586321831, 47.18780592083931, 44.155477434396744, 38.911724612116814, 34.59447607398033, 33.60240250825882, 35.16616299748421, 35.88705271482468, 34.616659283638, 36.30086950957775, 35.87267428636551, 37.48912654817104, 36.24535448849201, 35.94317950308323, 34.56701494753361, 35.52484855055809, 35.71927271783352, 35.90457737445831, 36.531965509057045, 33.519665747880936, 40.44110454618931, 49.90843713283539, 50.25161191821098, 53.93477328121662, 46.35456383228302, 48.28327193856239, 46.51168540120125, 47.65427649021149, 48.06090787053108, 51.52474120259285, 48.42783138155937, 46.46064653992653, 44.80157196521759, 51.15629397332668, 50.438071712851524, 49.51423108577728, 49.15198512375355, 47.31416434049606, 46.58658318221569, 42.153653651475906, 41.98893629014492, 38.95107910037041, 39.47608932852745, 38.417306542396545, 36.98491260409355, 34.6046557277441, 36.30410313606262, 36.769034788012505, 36.072102785110474, 35.981515645980835, 36.79626412689686, 36.73220336437225, 36.75475135445595, 37.762958854436874, 36.098651960492134, 36.62407636642456, 38.596288338303566, 35.83216845989227, 36.805395036935806, 37.2515556961298, 37.1645213663578, 38.74315805733204, 39.9468232691288, 38.37031826376915, 38.666842952370644, 36.776144206523895, 36.605685353279114, 33.469945415854454, 37.73627668619156, 38.94262075424194, 42.59857177734375, 44.99587073922157, 47.44378298521042, 48.62940676510334, 47.17567317187786, 52.79320053756237, 47.97214463353157, 38.81239414215088, 36.48658074438572, 34.95132252573967, 41.8091831356287, 51.25235661864281, 54.66830871999264, 52.53932476043701, 54.24501143395901, 53.74991700053215, 51.37556500732899, 52.02630668878555, 51.58040441572666, 52.139817997813225, 52.75801062583923, 58.57837110757828, 54.60688501596451, 24.06997751444578, 3.0511066038161516, 0.8151231170631945, 4.801403833553195, 0.46023949747905135, 0.1824820166802965, 0.8253731857985258, 35.60627058148384, 55.288773626089096, 58.414273113012314, 41.22043892741203, 27.782135121524334, 45.66435366868973, 45.199026837944984, 44.98758718371391, 7.380793774500489, 0.22566845087567344, 0.07407842029351741, 0.03620068346208427, 0.03278925323684234, 0.043324789075995795, 0.010084814712172374, 0.042640592000680044, 0.037271639666869305, 0.015898669735179283, 0.04873479330854025, 0.04169536674453411, 0.015602831117575988, 0.0046748090881010285, 0.021169699393794872, 0.06895596859976649, 0.02652129845955642, 0.08194493333576247, 0.005035693702666322, 0.0680101384932641, 0.022816987075202633, 0.02929135167505592, 0.04025452413770836, 0.04683800114435144, 0.050640454137464985, 0.015374289523606421, 0.10529353749006987, 0.04966144260833971, 0.0764030049322173, 11.002440713346004, 52.105509638786316, 51.3490804284811, 42.49633066356182, 24.772054441273212, 24.967688843607903, 47.5191405415535, 48.44755992293358, 45.337035432457924, 3.15628947224468, 0.1386242060107179, 2.424589334987104, 7.425607619807124, 3.937075138092041, 4.325836077332497, 21.393663324415684, 50.76259709894657, 49.635212793946266, 54.79013778269291, 50.86343228816986, 48.693862706422806, 44.42351505160332, 40.796799659729004, 39.21816296875477, 39.90126371383667, 40.906682163476944, 38.47006291151047, 38.67385737597942, 43.651274889707565, 46.44094839692116, 44.555998742580414, 41.66588142514229, 41.09973840415478, 41.51508651673794, 47.3340030759573, 50.348316729068756, 48.6861377209425, 42.92560122907162, 46.71699218451977, 48.63986000418663, 49.80639360845089, 46.24471552670002, 41.289925798773766, 35.758809596300125, 35.7772272080183, 36.96104608476162, 37.20932096242905, 38.01662564277649, 37.85641863942146, 37.79734320938587, 39.798870608210564, 37.6264663785696, 38.00494126975536, 35.463599637150764, 38.137394562363625, 37.73471496999264, 37.69857130944729, 37.1979633718729, 35.58991625905037, 41.03009954094887, 50.037284418940544, 53.21248143911362, 52.88038305938244, 50.02818010747433, 50.467854514718056, 48.885079845786095, 48.78873981535435, 50.57881236076355, 53.2060331851244, 50.35311967134476, 48.58911372721195, 46.43766537308693, 53.70982155203819, 52.89712496101856, 50.163734033703804, 50.44695183634758, 49.19904179871082, 48.09443347156048, 43.67294132709503, 43.95213134586811, 42.695192992687225, 41.60340517759323, 40.327935218811035, 39.69751104712486, 37.40099027752876, 38.911587819457054, 38.39448116719723, 39.3180900067091, 37.75412432849407, 38.300204426050186, 38.00629019737244, 39.19074364006519, 39.15276847779751, 37.65475586056709, 37.40182243287563, 38.985300064086914, 37.04814501106739, 38.96203011274338, 39.75000903010368, 38.34765627980232, 39.964845702052116, 40.56393675506115, 39.500514417886734, 41.36632829904556, 39.30004097521305, 37.90646955370903, 36.88270568847656, 39.182076305150986, 41.12416349351406, 45.22341772913933, 47.72173427045345, 48.50286215543747, 50.32703027129173, 48.105817660689354, 55.014033168554306, 49.503831043839455, 40.581932589411736, 37.381474524736404, 37.17479981482029, 43.34752678871155, 53.85361723601818, 56.076832339167595, 56.54999054968357, 57.61126220226288, 56.165971755981445, 54.76654104888439, 53.25459457933903, 53.6190178245306, 54.340390115976334, 55.776975229382515, 60.80439046025276, 53.83893482387066, 26.20803538709879, 5.178608167916536, 3.8397918082773685, 8.200450167059898, 0.5084384861402214, 0.033264431840507314, 0.8471051102969795, 38.21571595966816, 61.29422217607498, 60.888069570064545, 44.00879770517349, 32.821301221847534, 51.68480381369591, 52.66764007508755, 54.64312367141247, 10.698649864643812, 0.38840378809254616, 0.017548417636135127, 0.04150039341766387, 0.052785442749154754, 0.016707998474885244, 0.014376366216310998, 0.08860406116582453, 0.03978728280344512, 0.02028373648499837, 0.05482287931954488, 0.0037344597421906656, 0.056301474978681654, 0.030159256275510415, 0.10965083492919803, 0.13111733773257583, 0.12312594350078143, 0.12134685966884717, 0.14055880688829347, 0.1722784063895233, 0.2003236921154894, 0.07175066668423824, 0.1857807592023164, 0.0950225253473036, 0.1599089420051314, 0.17728698294376954, 0.15880369115620852, 0.07735328050330281, 0.1636723431874998, 12.623097449541092, 60.2817627042532, 59.016981571912766, 49.110658541321754, 32.58268542587757, 38.11374083161354, 53.37586887180805, 53.2776365429163, 50.43529786169529, 4.705081377178431, 0.21917606878560036, 3.35814509075135, 16.598100252449512, 5.951386475935578, 4.724035235121846, 22.717252001166344, 52.23983243107796, 55.03034949302673, 56.397261545062065, 53.294716626405716, 52.222577556967735, 47.67430521547794, 42.37897776067257, 40.983791425824165, 41.25345915555954, 43.12871553003788, 40.10032743215561, 43.81403535604477, 45.644526332616806, 48.89218546450138, 46.33026033639908, 44.56608720123768, 43.22749882936478, 43.975253105163574, 50.35311967134476, 52.591902539134026, 47.16125674545765, 43.66719223558903, 47.56547525525093, 49.637253284454346, 52.91999593377113, 48.91270436346531, 43.965753614902496, 38.33904214203358, 37.51797080039978, 38.604811280965805, 39.13881182670593, 41.26598708331585, 40.684610679745674, 40.10122798383236, 41.52977652847767, 40.34346118569374, 39.259174168109894, 36.79865039885044, 40.627218559384346, 38.56622815132141, 40.14110304415226, 39.27749678492546, 36.95702590048313, 43.4809186309576, 52.67303578555584, 54.67044420540333, 53.41254070401192, 50.246957167983055, 53.69422718882561, 51.08125559985638, 50.29847860336304, 52.48744234442711, 56.34502574801445, 53.03158074617386, 50.326946675777435, 47.49094605445862, 54.199474677443504, 55.3659512847662, 52.22679153084755, 50.55601358413696, 51.83197371661663, 49.86131966114044, 45.850399285554886, 47.472239658236504, 44.303152710199356, 45.139533430337906, 43.507733792066574, 40.80410286784172, 39.152012318372726, 41.371948197484016, 40.8448176831007, 40.44746920466423, 38.48651222884655, 40.95018222928047, 40.641813576221466, 40.04031345248222, 41.531634628772736, 39.54138122498989, 38.972703740000725, 41.46487221121788, 38.610590770840645, 40.74221558868885, 41.80293247103691, 40.318914502859116, 42.288538813591, 42.363949567079544, 42.30480194091797, 42.794485464692116, 41.87713868916035, 39.68737319111824, 37.84245818853378, 41.9246931374073, 42.80359737575054, 47.03411556780338, 50.55258996784687, 52.339858263731, 52.25592456758022, 49.65115673840046, 57.68935561180115, 51.5136343985796, 44.92853835225105, 39.31161515414715, 38.130003958940506, 46.28977730870247, 56.43636904656887, 59.08013038337231, 59.0164989978075, 60.070855021476746, 58.83587948977947, 56.99299357831478, 57.7971900254488, 56.73059865832329, 57.6249984651804, 57.74651974439621, 64.03747737407684, 57.14902080595493, 27.905320711433887, 4.974164888262749, 4.080753978341818, 13.796383291482925, 2.072683568112552, 0.5305488465819508, 1.0590645647607744, 42.22671993076801, 66.42319455742836, 73.01345452666283, 52.53487899899483, 41.847895458340645, 60.373489782214165, 59.72279749810696, 62.444260865449905, 13.821399249136448, 0.6442353618331254, 0.20587126084137708, 0.15293708798708394, 0.10616079642204568, 0.22743600915418938, 0.08133366340189241, 0.3092172247124836, 0.07427746430039406, 0.12055239058099687, 0.15212075522867963, 0.0800794041424524, 0.12808198342099786, 0.17355947202304378], [0.049205570976482704, 0.04146926032262854, 0.0649257430632133, 0.051063496866845526, 0.1124161810730584, 0.05678056098986417, 0.02350347553147003, 0.03872299479553476, 0.028815731493523344, 0.03527161847159732, 0.09159738023299724, 0.02390892379480647, 0.04022247449029237, 0.007694977202845621, 0.08682772328029387, 3.6838429514318705, 35.11008180677891, 46.8464170396328, 34.780525490641594, 28.749929890036583, 25.380920469760895, 32.98109024763107, 42.39336758852005, 49.03596214950085, 8.89676945284009, 0.12519819050794467, 0.31107606715522707, 1.170680250506848, 4.909538431093097, 1.4370289770886302, 8.421665746718645, 36.1443255096674, 48.286608159542084, 50.1663026958704, 47.260150238871574, 46.98239654302597, 40.20934738218784, 36.897551491856575, 35.399234890937805, 39.17364075779915, 38.680134639143944, 38.224322497844696, 41.59748129546642, 45.142269283533096, 46.707754880189896, 45.77648565173149, 43.356399312615395, 43.53430576622486, 42.70908124744892, 47.61799983680248, 48.8723087310791, 43.63038741052151, 44.742716923356056, 46.01057589054108, 47.05918662250042, 45.61192028224468, 43.40002477169037, 37.594817876815796, 33.4449427574873, 35.26817612349987, 35.868631303310394, 36.400465965270996, 35.959511026740074, 36.389822736382484, 35.756734907627106, 37.396438121795654, 35.45384556055069, 36.139161586761475, 37.2416952252388, 36.74215503036976, 35.73809690773487, 36.229501739144325, 35.59333987534046, 34.35289263725281, 38.94290193915367, 49.09805081784725, 46.030623614788055, 51.03714756667614, 53.42209719121456, 50.77917940914631, 45.443042144179344, 45.377640053629875, 44.94900405406952, 45.393811985850334, 44.77032244205475, 44.90802325308323, 48.590367659926414, 52.08629786968231, 48.39506193995476, 48.84942635893822, 51.81893661618233, 47.62293957173824, 42.58925087749958, 40.24238660931587, 39.199346378445625, 37.50711478292942, 37.57882833480835, 37.355012744665146, 36.557040363550186, 35.8208716660738, 36.24167248606682, 36.30659580230713, 36.135019809007645, 36.37619286775589, 36.25147596001625, 37.38887272775173, 36.816866621375084, 38.53478863835335, 36.6947677731514, 36.67386509478092, 37.25516930222511, 36.884784176945686, 35.70943884551525, 36.71536646783352, 35.601908415555954, 38.730128556489944, 39.477662444114685, 35.74702262878418, 36.81001178920269, 35.03377050161362, 34.64443579316139, 36.6844779253006, 37.04392723739147, 38.12598757445812, 42.26691037416458, 46.70139022171497, 48.920923322439194, 50.40652580559254, 46.44813381135464, 49.476749897003174, 50.16787201166153, 46.285529136657715, 38.01878772675991, 36.36936083436012, 37.302009388804436, 42.16260977089405, 50.42108662426472, 54.69189025461674, 55.19828148186207, 54.65328432619572, 54.590906873345375, 52.52071335911751, 48.64843234419823, 46.618056893348694, 52.18607671558857, 56.64105646312237, 51.41957424581051, 20.49214079976082, 2.8677994525060058, 2.6324890041723847, 4.114141836762428, 0.2504483610391617, 0.07622546094353311, 1.1141544836573303, 34.86496455967426, 53.73724088072777, 46.14005774259567, 36.05495050549507, 32.899155244231224, 46.1859554797411, 49.278715923428535, 44.78568121790886, 6.68079343624413, 0.1917474187212065, 0.054238241355051287, 0.05988932854961604, 0.037996216997271404, 0.05464647452754434, 0.03283293975982815, 0.023065333807608113, 0.04116860516660381, 0.06244449847145006, 0.023163876176113263, 0.026138129469472915, 0.07579979472211562, 0.0590205927437637, 0.043315066941431724, 0.00986450353593682, 0.0428033153002616, 0.04707404863438569, 0.03914583343430422, 0.08924331006710418, 0.022017866576788947, 0.0359239180397708, 0.013064057093288284, 0.01080255593478796, 0.07871895839343779, 0.030552613097825088, 0.02927492794697173, 0.038176180387381464, 0.006260844074859051, 5.0177352502942085, 44.75485347211361, 53.56417156755924, 39.07991498708725, 30.93243397772312, 26.390672586858273, 37.25486911833286, 48.6921413987875, 52.678150311112404, 9.015426635742188, 0.17502286849776283, 0.3530065203085542, 1.1450932547450066, 6.106926379725337, 2.4587813252583146, 11.05806877836585, 38.31629276275635, 48.35154667496681, 51.582627296447754, 49.36710298061371, 49.06960554420948, 42.19021148979664, 38.01262825727463, 37.40126386284828, 40.30770890414715, 40.48802822828293, 40.05087688565254, 42.24865235388279, 46.65936067700386, 47.9545895755291, 48.19957762956619, 45.39296843111515, 45.89453771710396, 45.653117671608925, 49.00453023612499, 51.88952922821045, 44.91116188466549, 45.44488124549389, 48.92321079969406, 49.07630458474159, 48.24164517223835, 45.87153375148773, 40.13824939727783, 35.9344095736742, 37.800637632608414, 37.81764551997185, 37.13809758424759, 37.64889657497406, 37.34748534858227, 37.65636697411537, 38.914897441864014, 37.676521092653275, 37.74335190653801, 38.2430174946785, 38.02086241543293, 37.48555473983288, 37.214215099811554, 37.478555515408516, 35.50222836434841, 40.89207574725151, 49.18035440146923, 49.83328476548195, 50.489000380039215, 53.31643246114254, 51.79969444870949, 47.75526367127895, 47.21021331846714, 48.11531335115433, 48.06291416287422, 47.17278532683849, 46.513235718011856, 49.357265308499336, 52.14817754924297, 50.97807973623276, 50.475340113043785, 52.85231776535511, 48.42854954302311, 45.45506849884987, 43.32259252667427, 40.682330802083015, 39.854780808091164, 39.55007515847683, 39.547301307320595, 39.016496390104294, 37.13960610330105, 37.38097295165062, 38.49420681595802, 38.25363032519817, 38.11139635741711, 38.61249066889286, 39.99023213982582, 38.45924489200115, 39.00894619524479, 38.258125483989716, 37.45910815894604, 38.639788404107094, 39.00806464254856, 38.025669157505035, 38.70715118944645, 36.98554337024689, 39.08050775527954, 41.08075462281704, 37.58972615003586, 38.44699054956436, 36.61151424050331, 36.75811417400837, 39.03999052941799, 39.2596111446619, 40.317987352609634, 46.48091085255146, 49.830769300460815, 50.354833379387856, 51.256513595581055, 48.44610080122948, 52.333204820752144, 54.439150616526604, 45.49515634775162, 39.123206064105034, 37.57554531097412, 39.23570662736893, 43.502581268548965, 54.24335092306137, 54.59939941763878, 58.203118443489075, 55.80597907304764, 55.949155390262604, 52.70762152969837, 51.46288812160492, 50.04832282662392, 54.69430312514305, 58.52770462632179, 54.37110386788845, 22.275647297501564, 4.328456036746502, 6.012747958302498, 7.406288981437683, 0.9438413882162422, 0.031870496677584015, 1.1041281279176474, 37.65730932354927, 60.12117192149162, 56.604411229491234, 42.52917990088463, 34.80077840387821, 50.89302510023117, 53.83376330137253, 54.34270039200783, 9.391350913792849, 0.23833118233596906, 0.12129251219448633, 0.019046724737563636, 0.065228576422669, 0.010464773913554382, 0.03942639123124536, 0.010026136806118302, 0.01816448555473471, 0.030061203724471852, 0.05312461536959745, 0.030354181362781674, 0.0495310212863842, 0.05216795361775439, 0.0990534336597193, 0.09717154011013918, 0.29286147735547274, 0.1525025605224073, 0.2582899230765179, 0.2591718320036307, 0.09478570602368563, 0.1937973641906865, 0.1056530635105446, 0.08820245537208393, 0.3348503523739055, 0.13626474043121561, 0.12593468301929533, 0.14108898234553635, 0.13279827253427356, 5.513955848291516, 49.564791172742844, 61.2657655030489, 45.814210027456284, 39.176011830568314, 34.67391461133957, 43.65616902709007, 54.58610773086548, 59.0376790612936, 11.768823489546776, 0.30892674811184406, 1.0731828259304166, 3.6853139474987984, 12.413502596318722, 3.6968515533953905, 11.375744082033634, 37.992713525891304, 51.60804033279419, 55.30616149306297, 52.31100641191006, 52.15175695717335, 45.09823724627495, 39.90275323390961, 39.21614907681942, 42.23376475274563, 42.86706157028675, 43.19222912192345, 44.76417817175388, 49.83125947415829, 50.91820254921913, 52.06689231097698, 47.16077797114849, 47.89534315466881, 49.01684157550335, 52.008455246686935, 53.299637362360954, 45.36773778498173, 44.18760471045971, 48.480055779218674, 49.61863808333874, 51.582783088088036, 48.397976383566856, 42.0404539257288, 37.997189685702324, 38.726245164871216, 40.96193879842758, 38.873772248625755, 39.740414544939995, 40.79075038433075, 39.36167746782303, 40.729064494371414, 41.28773711621761, 39.06175576150417, 40.45185796916485, 40.8670274913311, 39.16515201330185, 39.79199677705765, 40.34365877509117, 37.1992477029562, 42.46423378586769, 50.61316631734371, 50.224386379122734, 52.41614677011967, 52.86852389574051, 54.513858407735825, 50.599259063601494, 49.30971086025238, 48.552430495619774, 49.081263318657875, 48.59930098056793, 47.046833485364914, 54.36353847384453, 55.30508615076542, 52.61062033474445, 53.00440080463886, 55.13989381492138, 50.747207924723625, 45.67843571305275, 44.94197063148022, 43.38083200156689, 41.97611577808857, 41.468751803040504, 41.18207238614559, 39.61441330611706, 40.48292890191078, 40.06256505846977, 41.1025046557188, 40.51012024283409, 39.44080822169781, 39.521945267915726, 42.78551794588566, 40.60216650366783, 41.1922862380743, 40.04279471933842, 39.40567530691624, 40.59284180402756, 40.02845048904419, 39.33811113238335, 39.17925305664539, 38.31082485616207, 41.74798361957073, 43.4714837372303, 38.24451841413975, 41.391771733760834, 38.145773112773895, 39.540245085954666, 40.65691776573658, 41.681810170412064, 41.748424395918846, 49.108979031443596, 51.8430121243, 53.31020839512348, 54.23971451818943, 48.35172526538372, 51.77113898098469, 56.998013108968735, 50.51519997417927, 41.30656510591507, 39.52593505382538, 41.505077853798866, 46.27215765416622, 55.748111978173256, 58.60873907804489, 60.07889539003372, 58.31086926162243, 57.55500242114067, 58.197844326496124, 53.24841611087322, 52.192091792821884, 57.31654241681099, 63.23860824108124, 56.34945251047611, 24.189646393060684, 5.070195710286498, 8.233657535165548, 12.09296414628625, 1.2700773356482387, 0.14701469015562907, 1.5454568713903427, 41.50420390069485, 65.3920666873455, 58.79016034305096, 49.67790350317955, 42.72663630545139, 60.084222704172134, 63.19852039217949, 62.356348782777786, 14.002103302627802, 0.3609157365281135, 0.1454766484675929, 0.1769021200016141, 0.14711314346641302, 0.13119599054334685, 0.1268112930119969, 0.10356612197938375, 0.12178299759398215, 0.2329026986262761, 0.17557879647938535, 0.1343813625862822, 0.17172056366689503, 0.12052130201482214], [0.008341151733475272, 0.034528888209024444, 0.032719554437790066, 0.05844426683324855, 0.005913701716053765, 0.05292488116538152, 0.039158160507213324, 0.025253420790249947, 0.042751791697810404, 0.02253859449410811, 0.021613859935314395, 0.01757779926265357, 0.057870189630193636, 0.03524109022691846, 0.01703621328488225, 1.7781033064238727, 30.51292698830366, 47.53281980752945, 38.396468460559845, 23.409724943339825, 19.097034260630608, 41.17532014846802, 39.96625542640686, 48.7097230553627, 14.39962087199092, 0.0740488753945101, 0.4430801229318604, 2.0100064063444734, 4.138401634991169, 0.9712870779912919, 1.5371861401945353, 27.90720161050558, 58.333014473319054, 51.868482157588005, 45.83903029561043, 40.63998207449913, 36.451436430215836, 36.883598640561104, 38.66648577153683, 44.296943843364716, 39.81701463460922, 42.620451003313065, 45.36526791751385, 48.06525103747845, 45.036262571811676, 46.906913593411446, 44.249780774116516, 46.53423339128494, 47.01800063252449, 48.73169347643852, 45.12010507285595, 47.7267462015152, 46.16814203560352, 46.25040762126446, 45.26952065527439, 44.56583261489868, 40.20409606397152, 34.08915638923645, 34.187878891825676, 34.651906192302704, 35.115747302770615, 34.942871779203415, 35.16901284456253, 35.73063790798187, 38.208895325660706, 35.880311876535416, 35.90727902948856, 35.753843262791634, 38.579633831977844, 36.871576085686684, 35.04667840898037, 34.57997225224972, 36.73350669443607, 34.857342168688774, 38.224767073988914, 49.42212022840977, 47.728467509150505, 40.38438878953457, 45.0151015073061, 52.77450554072857, 51.073192432522774, 47.020808681845665, 46.1554317176342, 46.28695026040077, 45.256874933838844, 43.77140924334526, 49.66099441051483, 53.20273496210575, 47.74094603955746, 45.59888698160648, 50.94018056988716, 47.858758717775345, 45.2759613096714, 41.12549342215061, 39.27098013460636, 37.527185305953026, 36.924435049295425, 35.21869137883186, 35.33686883747578, 35.916926711797714, 36.64389230310917, 34.870557859539986, 36.62540249526501, 36.1330933123827, 38.02436962723732, 37.239966318011284, 37.39266872406006, 37.036768421530724, 36.65623404085636, 36.328057050704956, 38.29015776515007, 37.64190874993801, 37.63893350958824, 37.26979471743107, 37.77973875403404, 36.01870805025101, 37.900249287486076, 35.376021936535835, 36.01330853998661, 34.84629236161709, 35.84544874727726, 35.83108551800251, 36.304319724440575, 39.773138388991356, 43.07159699499607, 47.864409014582634, 48.42316523194313, 49.75321926176548, 47.158213108778, 47.46112525463104, 51.71710968017578, 51.75196520984173, 45.30088797211647, 36.797419264912605, 36.3130858540535, 36.473251059651375, 39.20456349849701, 46.2900622934103, 49.959798976778984, 53.27784173190594, 52.870142608881, 49.01110388338566, 45.68032421171665, 46.874721720814705, 53.76422703266144, 55.31779646873474, 53.238111063838005, 17.16605957597494, 2.6294995145872235, 6.54023707844317, 5.308622941374779, 0.6871785200200975, 0.037065649157739244, 0.7301698881201446, 33.96372132003307, 53.3753103017807, 45.57126626372337, 39.85161177814007, 34.217505902051926, 48.226274996995926, 46.69119156897068, 39.58114989101887, 6.175476126372814, 0.035166114757885225, 0.04198968395940028, 0.023928058217279613, 0.013182524271542206, 0.04043345965328626, 0.04326772163040005, 0.010974248089041794, 0.09733550279634073, 0.020170323332422413, 0.04229690341162495, 0.038310241943690926, 0.0969613045162987, 0.08172953239409253, 0.04168177802057471, 0.006500734962173738, 0.036091725050937384, 0.054606587800662965, 0.04901570733636618, 0.019449100509518757, 0.0693993795721326, 0.08032455778447911, 0.03187768808857072, 0.010953627515846165, 0.034444806587998755, 0.05793770651507657, 0.07465564791345969, 0.018558868396212347, 0.03943462164897937, 2.467334666289389, 35.15433803200722, 56.04164622724056, 41.74834460020065, 31.85260020196438, 20.370731614530087, 41.4365903288126, 48.50123584270477, 51.80283688008785, 15.539135076105595, 0.028384933320921846, 0.3498713026056066, 1.5927727636881173, 5.299665872007608, 3.3840691996738315, 3.0890570674091578, 29.53525085002184, 60.46991340816021, 53.362364396452904, 49.15010802447796, 45.09483262896538, 38.501643016934395, 38.19463089108467, 41.36956952512264, 45.465544536709785, 43.3158402889967, 43.15206527709961, 45.99945768713951, 47.67118938267231, 48.0250795930624, 46.33437551558018, 46.80950582027435, 47.97606602311134, 50.32842859625816, 49.68962587416172, 46.31486356258392, 45.19136644899845, 46.51835784316063, 48.495285362005234, 48.05155657231808, 46.36890046298504, 41.090835481882095, 37.19601787626743, 36.889970898628235, 34.580185040831566, 38.10244783759117, 36.49107210338116, 37.85740278661251, 38.478996232151985, 39.59914572536945, 37.78180584311485, 37.627393528819084, 37.57527932524681, 40.829360112547874, 38.08500677347183, 37.271979600191116, 35.50817884504795, 37.892383709549904, 36.182072684168816, 41.46218955516815, 50.54470919072628, 50.61423406004906, 43.53407397866249, 46.00462540984154, 53.82858417928219, 52.03694611787796, 47.37614281475544, 47.90723271667957, 47.761191353201866, 47.42149718105793, 46.50958031415939, 50.22962249815464, 54.19880211353302, 48.413855731487274, 47.87065967917442, 51.38282261788845, 48.94190959632397, 47.085473611950874, 42.80045494437218, 40.07726266980171, 38.14732722938061, 39.55278821289539, 37.58720688521862, 37.42084801197052, 37.69064873456955, 39.213880598545074, 37.51879535615444, 37.81216241419315, 38.333270251750946, 38.5895437002182, 38.80954049527645, 40.07231153547764, 38.427037820219994, 38.149424716830254, 39.170327335596085, 38.91390189528465, 39.10702273249626, 40.11056028306484, 39.03498239815235, 39.00087922811508, 37.91955605149269, 38.9492703974247, 37.22904950380325, 36.43134690821171, 35.813914239406586, 37.52372369170189, 38.10147128999233, 38.198518082499504, 41.44745014607906, 45.28103783726692, 50.3613044321537, 49.00453023612499, 50.88777758181095, 46.15456536412239, 47.21498966217041, 52.56653130054474, 52.89419151842594, 46.72290846705437, 39.01943743228912, 38.383005782961845, 39.77313078939915, 42.23799392580986, 50.905762016773224, 53.09216849505901, 55.77452436089516, 54.84433427453041, 50.1238551735878, 48.192718997597694, 48.9896996319294, 54.84395429491997, 57.49342292547226, 52.98152603209019, 19.34219140559435, 3.9420288847759366, 6.4474959298968315, 3.7401046324521303, 1.0967868031002581, 0.02181891533837188, 0.7903908973094076, 36.576043143868446, 61.95048116147518, 48.56980316340923, 40.2860576659441, 39.42297577857971, 57.203620076179504, 55.794245302677155, 48.5648026317358, 9.158023484051228, 0.112929331662599, 0.03064460601308383, 0.08306746880407445, 0.05049612125731073, 0.03874850612191949, 0.019561745539249387, 0.014199730430846103, 0.06735882969223894, 0.07524470536736771, 0.009380078699905425, 0.05796156656288076, 0.047259882412618026, 0.044309073564363644, 0.0881526424200274, 0.12688240560237318, 0.10559212576481514, 0.21269143471727148, 0.12795846036169678, 0.12595403823070228, 0.14483387436484918, 0.1555487947189249, 0.1317544566700235, 0.13159488007659093, 0.16826237813802436, 0.15856089012231678, 0.30288747686427087, 0.13135963410604745, 0.08739378157770261, 3.1931427447125316, 41.388633102178574, 62.65780560672283, 49.49492812156677, 35.47236576676369, 27.551772482693195, 52.554394751787186, 51.6837664693594, 57.18892626464367, 18.239403180778027, 0.20270850945962593, 1.0176474996842444, 5.336187137290835, 11.74991950392723, 5.390451550483704, 2.3746654763817787, 32.74490252137184, 63.528962060809135, 58.58091697096825, 51.19530647993088, 45.76528385281563, 39.74507689476013, 41.761260107159615, 43.164452612400055, 49.04256619513035, 44.97269958257675, 47.0951022952795, 49.276778027415276, 51.072174087166786, 48.22648398578167, 52.13102146983147, 48.96419160068035, 50.542398914694786, 51.83744162321091, 52.07020953297615, 45.91648913919926, 45.63329793512821, 46.11370235681534, 49.88733686506748, 48.862638249993324, 48.6012426763773, 43.83345231413841, 38.199882209300995, 37.864686995744705, 37.20834441483021, 40.19999608397484, 38.3441224694252, 39.77408453822136, 40.43769992887974, 41.28600440919399, 38.68405982851982, 40.34218445420265, 39.63291451334953, 43.088175505399704, 39.637975841760635, 38.110305815935135, 36.533793210983276, 39.506749883294106, 38.87828640639782, 43.29455763101578, 51.05530299246311, 51.6514378041029, 47.944569513201714, 47.53522887825966, 54.256980791687965, 55.226791352033615, 50.16053460538387, 51.4055036008358, 50.5982331186533, 49.56403121352196, 48.01850974559784, 53.02356317639351, 56.51613436639309, 51.14107199013233, 51.592301577329636, 54.00307081639767, 51.06092669069767, 49.7329967468977, 46.01347513496876, 43.25628988444805, 39.0595480799675, 41.35859191417694, 38.66618558764458, 39.66307729482651, 40.05070589482784, 39.543193727731705, 39.66224513947964, 39.978342577815056, 38.29049214720726, 39.99152787029743, 40.54144196212292, 41.67039178311825, 41.336214914917946, 40.50710320472717, 40.890852212905884, 41.4260420948267, 40.89483819901943, 41.89816676080227, 40.89211754500866, 41.93016104400158, 38.681757152080536, 40.864219442009926, 38.865557089447975, 39.06287670135498, 38.43640811741352, 38.935591131448746, 39.39259260892868, 38.82405951619148, 44.24827605485916, 47.70511396229267, 54.119321778416634, 50.72748698294163, 52.738453075289726, 48.313594311475754, 48.23661424219608, 54.309493973851204, 56.677576303482056, 50.57745963335037, 41.251422464847565, 39.78472776710987, 42.2056994587183, 42.903064638376236, 51.839497312903404, 54.33527559041977, 58.588246777653694, 57.85348400473595, 52.4033984541893, 50.63954450190067, 52.24872015416622, 58.87309089303017, 61.42401181161404, 56.379793882369995, 19.928311854600906, 5.690832557156682, 11.98508508503437, 13.23092708364129, 2.4679423961788416, 0.23363040410913527, 1.1432680464349687, 40.24854227900505, 66.86762630939484, 58.23217548429966, 55.43868698179722, 48.72659035027027, 62.66041226685047, 60.78082412481308, 57.8754848241806, 12.57378464564681, 0.2514433139003813, 0.08886346404324286, 0.1931554509792477, 0.12741534184897318, 0.17237605818081647, 0.136825343943201, 0.07079721472109668, 0.18327601079363376, 0.1785252711852081, 0.1226921210763976, 0.21411013905890286, 0.16908175370190293, 0.10924717338639311], [0.02525196618080372, 0.02933432573627215, 0.06168683248688467, 0.08696013726876117, 0.04698626740719192, 0.02375426578510087, 0.04409952074638568, 0.01976850602659397, 0.08237006521085277, 0.052018381175003015, 0.019501381102600135, 0.06926341811777093, 0.05459901789436117, 0.048634135819156654, 0.029609488119604066, 0.7573042914737016, 21.661167070269585, 48.202640265226364, 41.644492372870445, 28.491467759013176, 16.744496896862984, 21.56812146306038, 37.64839120209217, 52.00912781059742, 22.707093246281147, 0.13564241991844028, 0.05283284743200056, 0.5110713886097074, 3.909872635267675, 3.5039651161059737, 0.9502323484048247, 19.250508025288582, 56.2178997695446, 46.553160175681114, 48.67608726024628, 37.273529917001724, 38.659391552209854, 40.381143763661385, 47.65350133180618, 43.73461201786995, 45.08908353745937, 43.61586458981037, 48.51546607911587, 49.940556809306145, 45.738518089056015, 43.397836089134216, 46.926497742533684, 45.576403588056564, 45.2007557451725, 41.69059529900551, 44.102861657738686, 40.90404890477657, 49.44766245782375, 47.40996100008488, 45.570795089006424, 43.03913153707981, 35.99464014172554, 35.46521455049515, 33.446253687143326, 36.505313739180565, 35.93253627419472, 37.57597088813782, 34.53946642577648, 35.00973679125309, 35.75451202690601, 36.15455836057663, 35.61856672167778, 36.2135273963213, 35.911713391542435, 36.224417611956596, 37.28741817176342, 34.536612778902054, 34.799349680542946, 35.19719213247299, 35.63742510974407, 45.03531642258167, 52.55711920559406, 47.18264579772949, 41.52761824429035, 44.32321943342686, 50.50308622419834, 50.544439405202866, 48.94437946379185, 46.40846014022827, 44.65105824172497, 47.402764186263084, 49.92230638861656, 53.991097658872604, 47.19505973160267, 46.13705210387707, 48.420604169368744, 46.342716068029404, 44.959392696619034, 39.93261583149433, 37.78256580233574, 36.02278523147106, 38.45252685248852, 36.18204228579998, 36.17006532847881, 37.04076960682869, 36.63701847195625, 38.58347162604332, 38.49878937005997, 37.10564352571964, 38.65185275673866, 36.70399747788906, 37.09126129746437, 36.08934246003628, 36.43625624477863, 35.980170518159866, 38.27624671161175, 37.610055059194565, 37.034583538770676, 38.53649854660034, 38.99236388504505, 38.34264434874058, 36.693821623921394, 36.84199467301369, 35.713831409811974, 33.73393625020981, 34.47643160820007, 34.879149198532104, 37.76011660695076, 40.12740097939968, 47.49139063060284, 49.59926292300224, 53.35225313901901, 51.0618956387043, 51.05936877429485, 50.00893794000149, 50.28788857161999, 48.988206312060356, 49.65834215283394, 45.502083376049995, 38.564199060201645, 36.84954486787319, 38.36611948907375, 37.51828618347645, 41.30208134651184, 41.30301609635353, 42.305493503808975, 41.67824596166611, 45.33022239804268, 46.7292845249176, 56.743913143873215, 53.21979224681854, 56.06391683220863, 20.1649384573102, 3.420968782156706, 4.7890435717999935, 3.246120451949537, 1.3648840296082199, 0.08222388438298367, 0.7244498888030648, 33.9146925508976, 49.370701387524605, 46.66519336402416, 37.714268267154694, 32.96894609928131, 40.95267869532108, 39.43285904824734, 39.380095079541206, 4.4263136107474566, 0.09039007665705867, 0.04322381988458801, 0.01941567417816259, 0.030952324559621047, 0.02721598393691238, 0.08131809314363636, 0.022088819605414756, 0.007591104358652956, 0.07441980080329813, 0.047224259324138984, 0.008436411026195856, 0.039198511076392606, 0.009430144909856608, 0.015736970599391498, 0.023850769102864433, 0.009229023817169946, 0.020407074007380288, 0.046842806550557725, 0.03344632852531504, 0.02437420956994174, 0.032443609088659286, 0.014503758648061194, 0.05762696928286459, 0.06421394180506468, 0.06643150132731535, 0.030727106859558262, 0.018064423638861626, 0.06502427058876492, 0.833687970880419, 28.45817394554615, 54.40278276801109, 47.91551627218723, 28.110272213816643, 16.89655713737011, 34.74793463945389, 48.717942014336586, 57.86506958305836, 23.879497535526752, 0.05159374653885607, 0.05064343014964834, 0.9177542442921549, 5.353288119658828, 5.499652940779924, 1.7123562656342983, 20.269028171896935, 57.66173869371414, 49.173385575413704, 50.854586362838745, 39.911317974328995, 39.314502999186516, 41.98962785303593, 48.00702676177025, 44.70426298677921, 46.176505386829376, 45.1447581499815, 49.7850501537323, 51.382123455405235, 46.9186245650053, 46.321725994348526, 49.484349489212036, 46.62299282848835, 47.173302099108696, 43.72872233390808, 45.18473580479622, 42.56107918918133, 49.74135249853134, 50.49786150455475, 48.5681426525116, 44.91541005671024, 38.5308900475502, 36.06750503182411, 35.15978693962097, 37.839133366942406, 37.127442955970764, 37.68682233989239, 36.81815095245838, 35.79621098935604, 38.429089710116386, 37.73612469434738, 37.194938734173775, 37.29558393359184, 37.426160126924515, 38.820810690522194, 38.36313284933567, 35.798057690262794, 36.27326399087906, 36.34818457067013, 37.51457378268242, 47.853716388344765, 54.28334757685661, 48.805329725146294, 41.46699249744415, 44.779837131500244, 51.83219410479069, 52.7131312340498, 50.795237347483635, 49.14095811545849, 45.80009378492832, 49.35479164123535, 52.11428336799145, 54.230663403868675, 47.637887969613075, 47.25538149476051, 51.546483635902405, 48.79141867160797, 45.94421625137329, 42.225838378071785, 40.02119667828083, 37.57473595440388, 39.36421953141689, 38.312834948301315, 37.75491088628769, 37.094601318240166, 37.92451098561287, 41.261799708008766, 40.53833372890949, 38.358892276883125, 40.897885635495186, 37.14503601193428, 38.89711059629917, 38.52207072079182, 38.237450793385506, 35.93632847070694, 39.216308668255806, 38.93036261200905, 41.01048119366169, 38.97214137017727, 40.079056173563, 39.20459769666195, 37.59123466908932, 39.786437675356865, 37.075872123241425, 37.286548018455505, 37.313404977321625, 37.35019840300083, 40.50770737230778, 42.84324064850807, 48.211360797286034, 50.69729000329971, 55.345204398036, 50.20679332315922, 51.23663306236267, 49.063693061470985, 50.094653740525246, 50.77352911233902, 52.561264783144, 46.9367153942585, 40.13106398284435, 39.89857725799084, 40.675863549113274, 40.6828323751688, 43.449577912688255, 44.705456122756004, 47.587225288152695, 43.81715498864651, 45.989540219306946, 50.1170801371336, 57.30082266032696, 56.183937191963196, 57.25422956049442, 20.803657583892345, 2.187901698052883, 8.984324354678392, 6.508971406146884, 0.9136310499161482, 0.0191735484986566, 0.9730158664751798, 37.02072948217392, 56.70097164809704, 51.88201703131199, 43.77672515809536, 39.72937233746052, 47.62399971485138, 46.92388728260994, 48.08736965060234, 6.222042627632618, 0.10228855928289704, 0.08269045036286116, 0.018123784320778213, 0.014901817903592018, 0.005449971204143367, 0.04522082796029281, 0.031030441168695688, 0.07174238431616686, 0.012938020008732565, 0.05129755169036798, 0.03590074076782912, 0.06346108493744396, 0.03572921559680253, 0.11621704587014392, 0.08249602993601002, 0.07474187805200927, 0.14104969304753467, 0.226156338758301, 0.13056673837127164, 0.171714017924387, 0.12372027762467042, 0.1748716930160299, 0.25740540178958327, 0.22624650970101357, 0.1493168470915407, 0.10872625251067802, 0.1871486264280975, 0.15214235172607005, 1.0646329284645617, 31.391859725117683, 61.98833093047142, 55.37899598479271, 38.64391878247261, 26.111577562987804, 31.110292933881283, 48.7659752368927, 63.9173886179924, 27.891082875430584, 0.3627970512025058, 0.13949536863947287, 2.492277715355158, 10.821987446397543, 9.560266099870205, 2.6853132946416736, 21.85071799904108, 60.71183502674103, 51.449421644210815, 52.52476394176483, 40.963245928287506, 42.46233008801937, 44.157004952430725, 52.6067179441452, 46.66334666311741, 48.497189059853554, 46.79795064032078, 53.25453758239746, 53.721186742186546, 48.9733225107193, 47.35238268971443, 50.37657581269741, 49.005784168839455, 46.104404255747795, 42.66261734068394, 44.95014399290085, 42.564970180392265, 52.355502024292946, 51.91929303109646, 51.104046776890755, 47.80820243060589, 40.49583300948143, 38.44164803624153, 36.63992911577225, 39.71139930188656, 39.82656352221966, 40.50307162106037, 37.763464227318764, 38.53643774986267, 38.70369717478752, 40.44119954109192, 39.97419320046902, 38.401218205690384, 40.13276629149914, 40.14372110366821, 41.6708629578352, 37.34198324382305, 36.96443930268288, 38.271683156490326, 39.29080747067928, 48.84451702237129, 56.78766779601574, 50.258189365267754, 45.10635741055012, 46.30205824971199, 53.940434977412224, 54.42503057420254, 53.72350461781025, 50.79720564186573, 48.41441810131073, 50.34225985407829, 54.36577655375004, 57.30730511248112, 49.88997772336006, 51.19250223040581, 52.34211914241314, 49.676318988204, 48.91776569187641, 44.279149398207664, 42.177216187119484, 39.53920014202595, 43.818465918302536, 40.8232956379652, 40.27039870619774, 40.48031844198704, 40.57398721575737, 42.19047747552395, 42.12445221841335, 41.57760836184025, 42.66007147729397, 38.616309463977814, 40.7130179554224, 40.28369039297104, 38.33767421543598, 38.87002944946289, 41.80783420801163, 40.914220958948135, 42.04470209777355, 41.502547189593315, 42.68700823187828, 42.95678235590458, 40.13694606721401, 41.98075532913208, 39.72973331809044, 38.47213760018349, 38.878711983561516, 39.47548136115074, 41.66403092443943, 43.998792842030525, 52.86500908434391, 52.66314871609211, 58.34525741636753, 52.9201403260231, 53.742530196905136, 50.972110256552696, 51.3570524007082, 51.45525433123112, 54.15657497942448, 51.517593786120415, 43.47492255270481, 40.581073835492134, 43.824013620615005, 42.899789214134216, 45.795260444283485, 45.710221007466316, 48.50141443312168, 45.455596670508385, 51.73947907984257, 51.989992037415504, 62.4395377188921, 56.96087770164013, 60.10834380984306, 24.323104731738567, 6.216404205188155, 12.04589607194066, 12.109649050980806, 3.6589868227019906, 0.20123599941143766, 1.290895112324506, 40.352709889411926, 62.85993956029415, 60.110008120536804, 50.39524421095848, 44.14540797472, 55.916477143764496, 56.938690692186356, 56.04600839316845, 9.52664265409112, 0.18273986846907064, 0.17692873341729864, 0.17904614011058584, 0.07748556090518832, 0.13639761455124244, 0.1327040494652465, 0.16310832579620183, 0.09455751787754707, 0.19842670328216627, 0.07723427712335251, 0.11112459920695983, 0.18240846984554082, 0.07349535197135992], [0.013655153597937897, 0.036971318477299064, 0.043113187930430286, 0.04927583380776923, 0.06952768948394805, 0.058974134299205616, 0.010989482525474159, 0.04755690104502719, 0.04022192530101165, 0.07980566297192127, 0.07720507361227646, 0.04654412179661449, 0.05690170917659998, 0.014436991332331672, 0.0355662882066099, 0.16616978886304423, 11.161365285515785, 41.24933257699013, 45.44586539268494, 45.706918984651566, 23.08854717761278, 22.631593197584152, 40.041943565011024, 50.0783222168684, 34.161637499928474, 0.5887231312226504, 0.08437821292318404, 0.8924123947508633, 2.70385819952935, 1.9670926965773106, 1.4583191159181297, 16.971063539385796, 58.43626633286476, 49.79155920445919, 47.12445572018623, 40.93220919370651, 44.02500003576279, 46.309213265776634, 49.43180210888386, 46.978566348552704, 50.037911385297775, 47.52297833561897, 50.160819590091705, 46.65413975715637, 47.968238443136215, 43.58643896877766, 44.37293976545334, 44.98401917517185, 45.5904134362936, 46.710566729307175, 48.4371142834425, 44.97474767267704, 49.71367858350277, 43.68988461792469, 44.295853301882744, 37.51428879797459, 33.86051885783672, 35.47076225280762, 34.946139603853226, 34.82363037765026, 36.404847130179405, 35.67059352993965, 35.412055402994156, 36.46744877099991, 38.22933442890644, 35.88213957846165, 37.11154080927372, 35.902164503932, 37.57928051054478, 35.60399450361729, 36.453169137239456, 36.03186294436455, 36.05397775769234, 36.378324553370476, 35.52139073610306, 41.92593567073345, 46.78519852459431, 50.6955648958683, 50.111821219325066, 48.27846519649029, 47.36404046416283, 50.774235874414444, 51.00199565291405, 51.640357598662376, 49.21305924654007, 46.993248760700226, 48.704882115125656, 53.01031328737736, 50.71349233388901, 47.442612648010254, 52.307685390114784, 48.38773973286152, 47.039769664406776, 41.59253016114235, 41.545207500457764, 39.86406750977039, 38.88003431260586, 39.647794514894485, 38.74536953866482, 35.39296142756939, 36.241319105029106, 36.842112466692924, 39.83598321676254, 38.011134937405586, 36.8271678686142, 36.231002658605576, 38.631307259202, 36.22770443558693, 36.62315681576729, 35.92329517006874, 37.493382319808006, 36.61565221846104, 37.787741124629974, 36.56191170215607, 37.63535030186176, 35.72380207479, 37.54203490912914, 36.855799332261086, 37.149420976638794, 34.900416657328606, 35.561391189694405, 35.38548722863197, 34.43773828446865, 39.95084725320339, 45.633670315146446, 47.54399500787258, 47.04496778547764, 48.678975105285645, 50.582315772771835, 50.791927725076675, 49.5661287009716, 49.18505094945431, 51.59428507089615, 50.591841861605644, 46.064563393592834, 40.87242320179939, 41.19403414428234, 41.88461668789387, 38.437346667051315, 38.242405727505684, 38.30499216914177, 39.80453610420227, 42.575165033340454, 49.92089666426182, 53.01762789487839, 57.893982231616974, 53.2411926984787, 21.866413056850433, 2.222826573997736, 5.406794948503375, 1.4023814862594008, 0.31552675645798445, 0.0933541328413412, 0.7576202088966966, 33.78548048436642, 50.29258131980896, 41.01707004010677, 31.9540623575449, 45.74065737426281, 45.37329688668251, 49.43020239472389, 30.651541650295258, 2.2012755554169416, 0.005638391367028817, 0.028989119455218315, 0.021588660310953856, 0.032574557335465215, 0.10701091916416772, 0.020347386780485976, 0.021569152959273197, 0.05100665206555277, 0.04493003594689071, 0.033397955339751206, 0.024734999096835963, 0.06268174081924371, 0.01886131398350699, 0.0129021585053124, 0.03848344807920512, 0.07266469576279633, 0.056961767477332614, 0.022912434687896166, 0.029824232260580175, 0.01996223068999825, 0.11842616717331111, 0.12120701678213663, 0.05759164676419459, 0.06363448774209246, 0.05038140378019307, 0.07976596549269743, 0.040535768421250395, 0.03597460672608577, 0.17013566277455539, 15.581890381872654, 48.43997173011303, 52.81199432909489, 49.26484666764736, 24.564169496297836, 21.36445429176092, 44.29633967578411, 55.78200615942478, 36.66477598249912, 0.5694760358892381, 0.16385755356168374, 0.6426522124093026, 3.8522731885313988, 5.838247071951628, 1.3751639029942453, 18.310655057430267, 59.55550767481327, 52.23962344229221, 49.072147607803345, 42.87920951843262, 46.419661939144135, 47.610730826854706, 51.04430638253689, 48.229463025927544, 50.95297448337078, 50.23615054786205, 51.65254354476929, 48.24653171002865, 49.06828701496124, 44.780163913965225, 46.282595694065094, 45.28851963579655, 45.60168743133545, 46.820605024695396, 49.32269476354122, 47.330176681280136, 51.08056403696537, 47.45767503976822, 47.23066762089729, 39.587142169475555, 36.99098847806454, 35.78304469585419, 36.38256512582302, 36.225755140185356, 38.65289390087128, 36.571901366114616, 36.31120875477791, 38.15504841506481, 38.31429407000542, 37.71176040172577, 37.54857815802097, 38.42247046530247, 37.54510894417763, 38.3655571192503, 38.10863770544529, 37.74400547146797, 37.334018871188164, 37.61811062693596, 37.178063839673996, 43.97653363645077, 48.55355143547058, 51.623893082141876, 52.02006742358208, 49.90730479359627, 47.53136448562145, 51.18801847100258, 52.739095240831375, 52.33200028538704, 51.175159960985184, 47.651848420500755, 50.368467047810555, 54.47898767888546, 50.038587749004364, 49.41953256726265, 53.25970910489559, 50.55421248078346, 46.830267906188965, 43.85920733213425, 43.78951907157898, 41.624357253313065, 40.68839527666569, 41.49473860859871, 39.697359055280685, 37.618699595332146, 38.49601551890373, 39.686039462685585, 40.76076619327068, 40.02387933433056, 38.677254393696785, 38.63073728978634, 40.40880627930164, 38.3600702136755, 37.258076146245, 37.597036957740784, 39.1252351552248, 39.60392966866493, 38.594776019454, 38.70983384549618, 38.596337735652924, 37.74746708571911, 40.26974894106388, 38.11219051480293, 37.111939787864685, 36.94887913763523, 37.89487637579441, 37.47330419719219, 36.440983191132545, 42.7798106521368, 48.35114769637585, 49.88832861185074, 49.85482580959797, 50.207940861582756, 52.814635187387466, 52.36636184155941, 50.58845244348049, 49.89148624241352, 53.26262354850769, 51.49686589837074, 47.18405932188034, 42.34608672559261, 43.30413691699505, 43.21634262800217, 41.90739646553993, 39.741588681936264, 41.08030624687672, 42.05953650176525, 44.44418214261532, 51.878597214818, 57.3642298579216, 58.288192078471184, 54.47363756597042, 22.255555875599384, 2.456597867421806, 5.301150167360902, 7.37777816131711, 1.1806199233978987, 0.03285487764514983, 0.5797442723996937, 37.33502961695194, 56.646524369716644, 48.26704300940037, 38.14074218273163, 46.76493801176548, 49.577980265021324, 54.970745891332626, 39.48814608156681, 3.585572624579072, 0.021564833659795113, 0.07635935922735371, 0.02432706834952114, 0.03959429472160991, 0.06261444286792539, 0.035809790570056066, 0.06314479644061066, 0.12558248941786587, 0.02511697879526764, 0.03506876353640109, 0.029497642753995024, 0.029867851990275085, 0.019863810775859747, 0.15123308723559603, 0.17744093405781314, 0.19797347369603813, 0.17747738835169002, 0.14732199866557494, 0.14352756086736917, 0.19244511175202206, 0.19575161713873968, 0.26191478013060987, 0.13922065525548533, 0.1868246344383806, 0.16767170280218124, 0.18216445168945938, 0.17708970524836332, 0.23290394543437287, 0.2712772402446717, 18.958286605775356, 57.44858153164387, 58.435840755701065, 59.7687104344368, 32.879605293273926, 32.45311997830868, 51.00657060742378, 61.79917328059673, 41.41515947878361, 1.2190872780047357, 0.4054684052243829, 3.7043514009565115, 9.629689324647188, 8.761875741183758, 3.8340420043095946, 20.52839085459709, 64.3922871351242, 54.40847106277943, 52.4198629707098, 46.613177955150604, 49.280627220869064, 50.12383617460728, 54.49427805840969, 48.871016800403595, 54.720992892980576, 51.43418066203594, 53.69415879249573, 50.610947236418724, 50.671918764710426, 46.2085984647274, 47.150438725948334, 46.49055853486061, 48.138644099235535, 50.35664588212967, 52.05767780542374, 49.431045949459076, 53.33987720310688, 49.87478993833065, 49.859453961253166, 40.15823632478714, 38.97881381213665, 38.03631618618965, 40.22006280720234, 38.496403098106384, 40.017058700323105, 40.21787032485008, 38.34929399192333, 40.13113617897034, 39.65191349387169, 38.46572354435921, 41.22429572045803, 39.55763675272465, 38.92849691212177, 40.254120379686356, 40.07448121905327, 39.31538835167885, 39.32016469538212, 40.36523021757603, 38.309232741594315, 47.37454690039158, 52.05244168639183, 53.81981045007706, 54.509287253022194, 51.47537425160408, 48.64645645022392, 52.96417996287346, 55.2922086417675, 54.39629651606083, 52.83954665064812, 50.23669391870499, 53.23368050158024, 55.80249086022377, 51.79723218083382, 49.832748994231224, 56.159926280379295, 52.9468946903944, 50.18004275858402, 45.96771419048309, 46.54385067522526, 44.57207188010216, 43.77777770161629, 44.67414200305939, 42.63043686747551, 38.960681185126305, 40.42304411530495, 40.35292647778988, 43.010853454470634, 41.644758358597755, 40.34398935735226, 40.32678388059139, 42.03420706093311, 39.84761439263821, 39.55053873360157, 39.374467581510544, 41.143683046102524, 39.941913932561874, 41.47370673716068, 40.03361061215401, 40.44187590479851, 38.70531588792801, 40.79023361206055, 40.64935237169266, 39.79323171079159, 37.810072526335716, 39.19009007513523, 39.59452897310257, 37.53100410103798, 43.79735805094242, 50.17216958105564, 53.24680499732494, 52.19537101686001, 51.69111147522926, 55.121780186891556, 54.58922356367111, 51.405302211642265, 52.506714910268784, 54.50369395315647, 54.03901308774948, 49.582589417696, 44.69115749001503, 45.740687772631645, 46.73129461705685, 44.06146667897701, 43.013159930706024, 42.56501957774162, 45.03009930253029, 47.40052990615368, 53.54078382253647, 59.215984493494034, 61.59802347421646, 56.33104629814625, 25.604785457253456, 5.275944219902158, 12.30243930593133, 9.46472592651844, 2.319609518162906, 0.1921170824789442, 0.8618280733935535, 40.58648854494095, 63.792854100465775, 55.33385440707207, 46.325009018182755, 58.42016279697418, 59.23960782587528, 62.04219304025173, 49.559577852487564, 5.415895460173488, 0.1538260473171249, 0.19831910671200603, 0.13974572473671287, 0.17459580703871325, 0.19247191812610254, 0.089695945935091, 0.19109112268779427, 0.25724729464855045, 0.10578627901850268, 0.19770207029068843, 0.13486307580024004, 0.16633929539239034, 0.056068370104185306], [0.027673276781570166, 0.05394816922489554, 0.038214256273931824, 0.05522547216969542, 0.09126564764301293, 0.022531442045874428, 0.02022726090217475, 0.08904367234208621, 0.057615243349573575, 0.03646577119070571, 0.06800439427024685, 0.05915918511163909, 0.019869696006935555, 0.02860410066205077, 0.03789395275816787, 0.04116563286515884, 8.08719439432025, 43.097017630934715, 44.325172528624535, 35.636364966630936, 24.71127290278673, 33.25308345258236, 43.962949365377426, 47.95688845217228, 45.15966095030308, 2.8150264592841268, 0.006838843992227339, 0.22492109332233667, 3.1457410007715225, 5.9018314350396395, 0.8513148687779903, 13.34934202954173, 49.294948652386665, 50.14731511473656, 48.04367959499359, 45.54347835481167, 49.17760334908962, 50.394108071923256, 51.61709904670715, 49.768623635172844, 48.02894398570061, 50.063233226537704, 47.776857912540436, 48.2386015355587, 48.133901953697205, 46.82264931499958, 46.78981527686119, 44.42591272294521, 46.39842867851257, 47.660261169075966, 47.681209444999695, 47.000517770648, 45.35627759993076, 43.64772208034992, 36.675153225660324, 35.21101199090481, 34.96913976967335, 34.807675033807755, 34.69783812761307, 36.64202280342579, 37.828585132956505, 38.885870799422264, 38.07135410606861, 37.26728305220604, 37.72167406976223, 38.460430428385735, 37.686100378632545, 35.329998806118965, 36.728946939110756, 36.1518719047308, 37.091360092163086, 36.81646764278412, 34.67301785945892, 35.483768954873085, 37.320411801338196, 39.68100093305111, 41.42795339226723, 46.81936629116535, 46.867631301283836, 48.96619029343128, 49.52870450913906, 47.60691963136196, 48.164087533950806, 47.7136293053627, 49.017335548996925, 54.56764452159405, 47.9640244692564, 49.716513231396675, 52.58969485759735, 46.765937358140945, 50.580830052495, 50.084379091858864, 47.61596314609051, 43.04448164999485, 42.44187958538532, 42.92319215834141, 43.768016025424004, 41.42674505710602, 39.55481730401516, 37.50123269855976, 36.12047038972378, 36.1536768078804, 37.35280506312847, 37.64545015990734, 38.32223564386368, 37.48723044991493, 35.04045434296131, 38.33366543054581, 36.68124049901962, 38.35079491138458, 36.181111335754395, 37.818268686532974, 38.385775834321976, 38.77048999071121, 38.29236164689064, 38.46839480102062, 39.29533302783966, 36.9892443716526, 36.630520820617676, 34.93023745715618, 36.15963488817215, 36.66734464466572, 35.19140124320984, 35.600563287734985, 38.50402548909187, 43.65360036492348, 44.86815959215164, 45.14480374753475, 46.38401225209236, 48.81756506860256, 52.11260765790939, 50.94933807849884, 48.66464227437973, 50.757300183176994, 49.597480818629265, 48.36344003677368, 51.74131818115711, 46.11607722938061, 43.48887540400028, 39.23058830201626, 39.772340431809425, 40.16118876636028, 43.85482616722584, 49.92402769625187, 55.257482305169106, 57.56730996072292, 52.46310465037823, 18.334301188588142, 1.5241987933404744, 5.407770071178675, 6.068273428827524, 0.5743436934426427, 0.02165432924812194, 1.234367920551449, 34.8140624910593, 51.5359316021204, 41.97893142700195, 34.078904539346695, 45.91164819896221, 44.163928180933, 47.01193995773792, 35.221085250377655, 1.7848991230130196, 0.11367022510967217, 0.04940242193697486, 0.032693538450985216, 0.05117457782034762, 0.09814010219997726, 0.012571154147735797, 0.012561410676426021, 0.06598427571589127, 0.014053661852813093, 0.05796146266220603, 0.05410165278590284, 0.028810163530579302, 0.035749038361245766, 0.012821243071812205, 0.06564353345311247, 0.015107812123460462, 0.0049356419913237914, 0.035536654249881394, 0.07852216309402138, 0.038789227764937095, 0.038560379107366316, 0.03984642826253548, 0.06927008260390721, 0.024236311110144015, 0.03781238330702763, 0.025439132114115637, 0.035462521118461154, 0.012358902695268625, 0.08229285216657445, 10.111707709729671, 49.84838895499706, 52.258379235863686, 44.99063082039356, 27.763877101242542, 32.06339009106159, 49.04464848339558, 53.91761340200901, 48.31804767251015, 2.660744288004935, 0.05625776248052716, 0.30483451613690704, 1.7787229106761515, 6.368408873677254, 1.8791816825978458, 14.854659754782915, 50.81734076142311, 52.700892090797424, 50.294610410928726, 47.13732562959194, 50.70491999387741, 53.05474050343037, 53.00430580973625, 50.25712542235851, 49.17177826166153, 51.06341935694218, 49.189842492341995, 50.66242687404156, 48.39840196073055, 46.476001515984535, 46.91962771117687, 46.342613473534584, 48.68804141879082, 50.79435959458351, 49.370306208729744, 49.72788602113724, 47.05058008432388, 45.03188520669937, 38.95525507628918, 36.73854522407055, 36.86287835240364, 37.291358560323715, 36.18793196976185, 37.82916270196438, 39.92256537079811, 39.218949526548386, 39.67552922666073, 38.3820254355669, 39.806880578398705, 38.38009133934975, 38.474261686205864, 37.20688909292221, 39.38564658164978, 38.90208072960377, 38.74273627996445, 37.596060410141945, 37.26492717862129, 37.49539241194725, 37.62178882956505, 41.830359399318695, 44.07702684402466, 47.573926001787186, 51.344847455620766, 52.21581012010574, 51.30015805363655, 50.01655273139477, 47.91093751788139, 50.05809210240841, 49.41899299621582, 53.32406625151634, 52.89039172232151, 51.71106420457363, 52.648591697216034, 48.348533436656, 53.36157403886318, 50.496314987540245, 50.47422297298908, 45.51672779023647, 43.6208651214838, 42.19944879412651, 45.147759988904, 43.19349065423012, 42.026387080550194, 39.10186640918255, 39.16386008262634, 37.98253387212753, 38.919305205345154, 38.371386006474495, 40.34051634371281, 39.37225230038166, 37.8088603913784, 39.24965187907219, 39.63771365582943, 38.95958684384823, 39.53268349170685, 38.83904591202736, 40.75283981859684, 39.82416205108166, 40.013285502791405, 39.38953757286072, 41.685233786702156, 38.656716495752335, 37.522089779376984, 36.65775775909424, 36.90849870443344, 37.140229269862175, 36.40622265636921, 37.136953845620155, 41.16022735834122, 45.22542782127857, 48.6075921356678, 48.06275077164173, 48.36136534810066, 49.69795122742653, 54.80418182909489, 50.932767167687416, 49.64953802525997, 52.39751257002354, 52.719552889466286, 51.38302780687809, 52.849612310528755, 49.41941857337952, 45.55882953107357, 41.64294205605984, 41.81671433150768, 42.434808164834976, 45.40470600128174, 51.54142610728741, 57.39923357963562, 59.91341806948185, 53.825236558914185, 20.88370978832245, 2.4778453772887588, 4.126921026036143, 8.490864783525467, 1.0153107438236475, 0.1528274134034291, 1.0999368340708315, 38.45227226614952, 56.46721579134464, 48.02025765180588, 39.39078390598297, 51.2642727792263, 49.15119856595993, 54.95096415281296, 39.50226232409477, 2.904058056883514, 0.06437742209527642, 0.07449748882208951, 0.08403334431932308, 0.03118045518931467, 0.09371600404847413, 0.018664112358237617, 0.06440071811084636, 0.07127443052013405, 0.01588047784025548, 0.05986848162137903, 0.09667287624324672, 0.053626674562110566, 0.015676068105676677, 0.07692092753131874, 0.1912564880331047, 0.1675583323230967, 0.11573068681173027, 0.15430626139277592, 0.14875274064252153, 0.11780867804191075, 0.148298442363739, 0.13925713923526928, 0.15948582877172157, 0.1729675053502433, 0.11387351420125924, 0.10291823447914794, 0.16263256460661069, 0.14982272463385016, 0.18441897758748382, 11.587484870105982, 57.53965124487877, 57.72779054939747, 49.09271590411663, 33.52675996720791, 43.936913162469864, 54.801993146538734, 59.42811571061611, 55.4116590321064, 4.484067661687732, 0.14671971614006907, 1.3169648009352386, 10.243933964520693, 13.856779150664806, 2.452965024858713, 15.649286415427923, 52.214662581682205, 54.8872871696949, 52.96509951353073, 51.006787195801735, 53.31298224627972, 55.382472798228264, 56.340382397174835, 52.99787275493145, 51.88207782804966, 51.82754695415497, 50.10358706116676, 51.331016197800636, 50.808365643024445, 47.88978785276413, 49.08075034618378, 48.6546678096056, 50.89288830757141, 52.064794823527336, 52.13547483086586, 51.14858038723469, 49.51868824660778, 48.23547810316086, 40.70018984377384, 39.914832785725594, 39.211197942495346, 39.8159658908844, 38.11718724668026, 40.21716356277466, 41.8822456151247, 40.91294802725315, 42.400780990719795, 40.826289877295494, 40.95647469162941, 41.235482320189476, 41.01707763969898, 39.93863470852375, 41.28780171275139, 40.74487544596195, 42.40942172706127, 40.65465308725834, 38.0035999417305, 39.708154276013374, 40.85834875702858, 42.29525305330753, 45.173765793442726, 52.21286527812481, 53.186479434370995, 52.7094492316246, 52.785958126187325, 51.26378260552883, 49.25251252949238, 50.965369418263435, 51.003116592764854, 54.76292364299297, 54.23412501811981, 53.38275030255318, 55.143370628356934, 51.42446078360081, 53.89969736337662, 55.566128343343735, 52.99288362264633, 48.40448923408985, 45.166724771261215, 45.75168438255787, 47.59524665772915, 46.03995591402054, 43.87222923338413, 40.14947399497032, 41.44194044172764, 40.148379653692245, 41.496433317661285, 40.97234643995762, 41.710658222436905, 41.83579310774803, 38.975044414401054, 41.85409292578697, 40.82329943776131, 42.33457334339619, 40.82936771214008, 41.02696470916271, 43.543037697672844, 41.93445481359959, 42.89138786494732, 43.27538765966892, 41.70613646507263, 39.57996815443039, 39.483365938067436, 37.82738819718361, 38.58989328145981, 40.86238034069538, 38.585679307579994, 39.28552195429802, 42.72490359842777, 47.595740631222725, 51.34249918162823, 50.24891026318073, 50.93749791383743, 52.451287284493446, 57.27126784622669, 51.705562099814415, 50.55014669895172, 54.8449270427227, 54.3657423555851, 53.93967121839523, 57.09492690861225, 50.623619556427, 49.35121603310108, 43.85571911931038, 44.09192584455013, 45.61909429728985, 47.52338871359825, 54.91576284170151, 60.7064089179039, 61.51507392525673, 57.14039146900177, 21.722393184900284, 3.34303995128721, 13.754313848912716, 14.700375683605671, 1.3585885986685753, 0.2805532846832648, 1.6471052169799805, 42.35032729804516, 64.60274264216423, 54.51086036860943, 48.56956757605076, 56.48388169705868, 59.66284051537514, 61.478333696722984, 50.68884305655956, 5.024658003821969, 0.27369693852961063, 0.2299519639927894, 0.22078969079302624, 0.1652821505558677, 0.21866008319193497, 0.09159881999948993, 0.12778877571690828, 0.14230668341042474, 0.08597191568696871, 0.17308339913142845, 0.14385135989869013, 0.12023325965856202, 0.13593635492725298], [0.05344914912711829, 0.0359312653017696, 0.06358225538861006, 0.04137025411182549, 0.05716012128686998, 0.08223916520364583, 0.02138343421393074, 0.06815075321355835, 0.022071458915888797, 0.10648659925209358, 0.011703976852004416, 0.03669730642286595, 0.03915447574399877, 0.06494405926787294, 0.03461694032012019, 0.033272272630711086, 3.060864955186844, 36.72247588634491, 46.95376127958298, 41.466513723134995, 32.38930620253086, 21.94307204335928, 36.42831467092037, 43.22542414069176, 51.063624545931816, 8.158116638660431, 0.06619504565605894, 0.1743587205419317, 1.1458304151892662, 4.706797935068607, 1.1810072651132941, 7.801603144034743, 39.15608949959278, 55.88174320757389, 50.4730374366045, 50.58800406754017, 48.53710971772671, 51.82775594294071, 48.93655188381672, 48.89106832444668, 50.04531338810921, 50.26520378887653, 51.12041249871254, 49.74501930177212, 49.66418243944645, 48.07592086493969, 46.93378195166588, 46.17716655135155, 48.22847507894039, 44.06196445226669, 43.8106345385313, 42.46536232531071, 40.179720371961594, 34.98111292719841, 33.13112899661064, 34.30346488952637, 35.092534348368645, 37.785161063075066, 37.069697454571724, 37.478965893387794, 40.24071849882603, 40.90622998774052, 40.195200741291046, 42.03167259693146, 41.54243744909763, 42.056572660803795, 38.501437827944756, 37.114812433719635, 35.961749106645584, 37.301082238554955, 37.044892385602, 36.68606624007225, 36.56990647315979, 36.142273619771004, 36.51224076747894, 35.5265736579895, 36.493264585733414, 39.152491092681885, 47.2836671769619, 47.100368812680244, 48.19299638271332, 48.02142798900604, 40.95710925757885, 49.52010937035084, 58.03924083709717, 52.47305631637573, 47.71055527031422, 53.794914186000824, 49.12831239402294, 45.99110573530197, 53.29423405230045, 48.448217287659645, 46.46955706179142, 40.720602348446846, 43.46534326672554, 45.47020688652992, 43.75385798513889, 42.825579196214676, 44.252592623233795, 40.1017789542675, 38.14265727996826, 38.23539510369301, 37.52035707235336, 37.38625846803188, 36.31972409784794, 35.97105860710144, 38.09679374098778, 36.124532371759415, 38.07103872299194, 36.833828911185265, 38.16734075546265, 39.448996782302856, 43.36117185652256, 43.70639853179455, 45.20047836005688, 43.335698023438454, 40.434671491384506, 37.17657431960106, 38.14659006893635, 36.413233280181885, 36.774635687470436, 35.13602301478386, 34.627458304166794, 35.44730231165886, 37.09448352456093, 36.32805325090885, 37.23943434655666, 40.35200692713261, 44.54743780195713, 46.28826878964901, 49.43657465279102, 51.042930856347084, 50.40278680622578, 49.7307700663805, 51.67023539543152, 50.138404592871666, 44.331047013401985, 50.78332498669624, 50.283271819353104, 41.52832880616188, 39.79603596031666, 40.87001033127308, 42.93564788997173, 49.58852469921112, 56.26264616847038, 59.132119193673134, 48.173218443989754, 17.69880048930645, 1.2268160632811487, 0.6664703437127173, 5.807395102456212, 1.2509586615487933, 0.02162230000976706, 2.6244771340861917, 36.92966736853123, 54.62136223912239, 37.652787566185, 31.573824360966682, 42.3603967577219, 39.79069724678993, 52.774725928902626, 35.42283922433853, 3.0366954021155834, 0.1752299425425008, 0.028225657297298312, 0.03818800651060883, 0.059830223908647895, 0.16946283169090748, 0.04533230596280191, 0.01998254141653888, 0.026744339811557438, 0.06119708552432712, 0.033179537567775697, 0.017243272486666683, 0.03458362160017714, 0.02597328548290534, 0.0673135364195332, 0.013760189758613706, 0.009275687280023703, 0.026166614952671807, 0.10159447308978997, 0.07398054585792124, 0.03380793255928438, 0.03978800268669147, 0.04875474965956528, 0.0973591921501793, 0.04219254260533489, 0.039191716714412905, 0.02477590627677273, 0.030493612357531674, 0.026964900534949265, 0.04735951573820785, 4.828333938494325, 42.9638309776783, 52.4358981102705, 45.15502519905567, 33.9543092250824, 27.028607055544853, 44.37580481171608, 47.94092170894146, 54.83290448784828, 7.990882862359285, 0.12787810061126947, 0.18216715310700238, 1.3680430850945413, 5.449866112321615, 2.564475266262889, 8.928809333592653, 43.14176023006439, 56.87676161527634, 51.979060024023056, 52.58609265089035, 51.67118154466152, 52.510453909635544, 49.61847089231014, 50.42872041463852, 51.4539548009634, 51.37556500732899, 52.45658420026302, 50.70840820670128, 48.422276079654694, 49.48461167514324, 49.11951966583729, 48.75938259065151, 50.616057962179184, 48.00212502479553, 47.17569977045059, 46.12598329782486, 43.366742357611656, 37.477157190442085, 35.62145456671715, 36.36233501136303, 36.08273461461067, 38.31381909549236, 38.58552731573582, 41.04259327054024, 43.592689633369446, 41.9914935529232, 41.577623561024666, 43.30930843949318, 43.20936620235443, 43.02530787885189, 39.20977681875229, 37.57005840539932, 37.92917713522911, 39.39634680747986, 39.340964779257774, 37.40140825510025, 38.28062787652016, 37.69140489399433, 37.064879313111305, 36.94221809506416, 38.20814296603203, 41.84388667345047, 49.450820088386536, 46.990512907505035, 48.98736275732517, 46.513912081718445, 41.77809700369835, 47.44008578360081, 56.36029712855816, 56.293485313653946, 49.60452564060688, 54.135144129395485, 50.670015066862106, 46.72790139913559, 53.839557990431786, 51.70123793184757, 48.186331540346146, 43.50803017616272, 44.35250826179981, 44.19920928776264, 44.74132999777794, 44.86497916281223, 45.85462465882301, 40.92202953994274, 37.88281962275505, 39.55983303487301, 38.479022830724716, 38.08527275919914, 38.44243459403515, 38.60116347670555, 39.19835843145847, 38.76341097056866, 39.195546582341194, 38.77532333135605, 40.21589823067188, 41.7980345338583, 45.07963724434376, 44.603857174515724, 46.35084383189678, 44.105563312768936, 41.21958017349243, 38.70928667485714, 38.43212574720383, 38.10320779681206, 37.85252384841442, 36.996672973036766, 36.903862953186035, 36.4740452170372, 38.458921909332275, 38.801507726311684, 39.28646810352802, 43.15040476620197, 47.72453472018242, 50.04328049719334, 51.557176262140274, 53.516453728079796, 53.09513233602047, 52.19736970961094, 52.39012956619263, 52.79576160013676, 48.309239745140076, 51.93248212337494, 51.079728081822395, 43.19303847849369, 41.63903206586838, 42.66366608440876, 44.26259368658066, 52.11834914982319, 58.34746889770031, 60.16866557300091, 50.30977159738541, 19.31262519210577, 1.5896013588644564, 5.168362017720938, 6.525216484442353, 0.9304047748446465, 0.07982646537129767, 2.1166849695146084, 40.73195233941078, 58.93539994955063, 46.23574800789356, 39.36008155345917, 47.25985765457153, 48.557096645236015, 58.560762852430344, 43.90232361853123, 4.02561703696847, 0.19266811228590086, 0.0996227128780447, 0.015169310190685792, 0.02969215223856736, 0.038162216878845356, 0.027455439740151633, 0.08401613391470164, 0.007729289009148488, 0.01903941829368705, 0.09553583920933306, 0.019319241364428308, 0.024615999427624047, 0.01895122888527112, 0.16021377174183726, 0.0881737787858583, 0.1565534994006157, 0.10497183873667382, 0.14901203219778836, 0.2800288237631321, 0.10251085477648303, 0.125555059639737, 0.17464622855186462, 0.1635429126326926, 0.08773289111559279, 0.14486847328953445, 0.14241767901694402, 0.14225066610379145, 0.09054168258444406, 0.11756906082155183, 5.769839817658067, 48.665573224425316, 60.90734973549843, 52.17019736766815, 42.58852891623974, 29.427146650850773, 47.91343778371811, 54.66929666697979, 60.35263650119305, 10.69835253059864, 0.31049953715410084, 0.7920986087992787, 4.543830854818225, 12.65727661550045, 3.7463823705911636, 9.968341402709484, 43.01635555922985, 59.17031854391098, 55.44257037341595, 55.165162459015846, 52.231210693717, 55.35028852522373, 50.73560334742069, 52.747944965958595, 53.22711445391178, 54.17648211121559, 54.72254320979118, 52.51073129475117, 52.11262285709381, 51.620127484202385, 50.2603742480278, 49.517552107572556, 52.384099289774895, 49.50041122734547, 50.5233733355999, 48.13188426196575, 44.053673297166824, 38.24312008917332, 37.158057913184166, 38.316171169281006, 38.32873709499836, 41.03717856109142, 40.592617616057396, 41.24864101409912, 45.402627512812614, 45.017096400260925, 44.76493813097477, 46.49686239659786, 44.547810181975365, 46.66329346597195, 41.292198076844215, 39.75423060357571, 38.66210840642452, 41.629023402929306, 40.744183883070946, 39.5723457634449, 39.81695003807545, 39.53522175550461, 38.83858613669872, 39.19114641845226, 39.500943794846535, 43.92218895256519, 51.158197671175, 51.28043331205845, 50.458309426903725, 49.140422344207764, 42.63408087193966, 47.6091843098402, 55.24614751338959, 58.80122534930706, 51.472797989845276, 55.90482696890831, 52.37957373261452, 49.652190282940865, 56.96459770202637, 54.05015408992767, 51.419836431741714, 45.792592987418175, 46.407741978764534, 48.55177693068981, 47.07921154797077, 46.26333832740784, 47.55972616374493, 43.48253354430199, 40.46106867492199, 41.344745457172394, 40.49650177359581, 39.586378410458565, 38.913354724645615, 39.946648478507996, 42.459598034620285, 40.12084633111954, 42.247204631567, 41.8842177093029, 42.9714647680521, 42.80222184956074, 49.46180149912834, 47.211813032627106, 49.5672420412302, 46.40083394944668, 43.17962899804115, 41.2295014411211, 40.96686713397503, 39.47869598865509, 39.85788904130459, 39.167610481381416, 37.53261521458626, 38.758486434817314, 40.45128419995308, 40.56848891079426, 40.325328558683395, 45.657267048954964, 48.10766436159611, 52.08854354918003, 54.247960075736046, 57.356679663062096, 53.763478472828865, 52.85035327076912, 55.18799543380737, 53.21750096976757, 48.88666436076164, 54.23095978796482, 55.271237567067146, 46.841382309794426, 43.7342282384634, 44.50821250677109, 47.194052785634995, 54.45745423436165, 61.193740367889404, 63.88554632663727, 50.47051817178726, 20.40972702205181, 3.2302449038252234, 7.083064550533891, 14.812476318329573, 4.470621608197689, 0.20096679276321083, 3.0042843287810683, 45.177041217684746, 67.37755134701729, 51.67876973748207, 45.56668370962143, 56.05764716863632, 53.77145804464817, 67.61788085103035, 50.299120768904686, 5.515884244814515, 0.24498415034031495, 0.2122854205663316, 0.1495551210246049, 0.14505783969070762, 0.19344442844158038, 0.14594380074413493, 0.14653358550276607, 0.0644447719969321, 0.0962052786780987, 0.153907208587043, 0.0820022048719693, 0.18895780434831977, 0.08497138929669745], [0.02903859658545116, 0.06004712398862466, 0.08476417424390092, 0.0546121130901156, 0.022189426999830175, 0.0084967773182143, 0.07187922150478698, 0.03700825516716577, 0.04437208561284933, 0.016379290136683267, 0.013753141211054754, 0.007828763700672425, 0.05770872056018561, 0.1262446484179236, 0.011663891600619536, 0.03685714276798535, 0.9756764955818653, 29.83879756182432, 51.01229690015316, 42.95541822910309, 33.08359354734421, 27.227440886199474, 42.30737820267677, 45.03411568701267, 51.72024071216583, 15.581167470663786, 0.07345612946664914, 0.09614562484784983, 0.4341106745414436, 3.9223554404452443, 1.7818951467052102, 3.4478019922971725, 23.38493127375841, 48.51349018514156, 55.788655802607536, 49.486203789711, 47.84377232193947, 49.619280248880386, 48.738878890872, 50.655347853899, 47.75383114814758, 49.047726318240166, 47.54543513059616, 47.3472111672163, 50.903086960315704, 49.16705511510372, 50.22611528635025, 46.43226586282253, 44.372233003377914, 44.40219059586525, 38.99885393679142, 39.35175620019436, 34.40379850566387, 34.98649723827839, 34.39673848450184, 35.364668145775795, 38.09997797012329, 39.090733006596565, 39.20087769627571, 39.26739692687988, 38.855696618556976, 42.0567474514246, 42.32721693813801, 42.972532510757446, 43.89906719326973, 45.423826575279236, 42.033899277448654, 39.0518344938755, 36.57479681074619, 36.383743062615395, 37.18453489243984, 38.865652084350586, 36.21701180934906, 36.03972852230072, 36.48615516722202, 37.34208203852177, 37.13717423379421, 38.17953810095787, 40.38819618523121, 46.53868295252323, 49.347959607839584, 49.884080439805984, 41.81694991886616, 43.471992909908295, 43.706345334649086, 47.94554986059666, 50.92605672776699, 50.741667822003365, 48.19887466728687, 45.46582952141762, 51.55616171658039, 47.86776803433895, 46.683983355760574, 42.16302774846554, 42.46992588043213, 42.0711524784565, 46.739490777254105, 45.53374707698822, 46.91320985555649, 40.462007224559784, 37.390597835183144, 37.642410323023796, 37.06460952758789, 36.36918984353542, 37.65348672866821, 36.56586728990078, 37.79193989932537, 36.01172022521496, 36.630562618374825, 37.19605207443237, 42.52177029848099, 47.85463213920593, 46.82522177696228, 47.7727085351944, 48.48417855799198, 45.835203900933266, 46.406438648700714, 43.430677726864815, 43.52186903357506, 39.52212765812874, 39.20074090361595, 38.821171671152115, 39.12674367427826, 35.33753000199795, 36.96653299033642, 38.324025347828865, 37.95322984457016, 36.292091980576515, 39.107873886823654, 42.9483962059021, 47.77096062898636, 46.11476629972458, 49.929461404681206, 50.42786546051502, 53.734991401433945, 46.51252135634422, 44.09387893974781, 53.553832322359085, 53.652463629841805, 47.84541763365269, 43.227719217538834, 40.21710656583309, 42.34851859509945, 50.67345768213272, 53.04358810186386, 59.08721700310707, 41.48305803537369, 11.920326109975576, 1.2994415662251413, 2.8641753969714046, 5.540194865316153, 0.6683726166374981, 0.07824848871678114, 3.3881653798744082, 42.67667658627033, 49.95572939515114, 35.29955103993416, 39.10869464278221, 38.07827353477478, 35.9808012843132, 48.23927789926529, 26.317226327955723, 2.413013493642211, 0.09651770800701343, 0.0966599777166266, 0.08796222959063016, 0.04191225940303411, 0.042128328277613036, 0.039036782254697755, 0.06783265387639403, 0.026100259528902825, 0.03455179088632576, 0.10011942489654757, 0.07551593065727502, 0.019394287337490823, 0.05829504691064358, 0.05908792038098909, 0.016445250366814435, 0.023254607440321706, 0.05707928285119124, 0.021967005341139156, 0.07165226532379165, 0.0585689031140646, 0.04403331746289041, 0.06261652088142, 0.035807415697490796, 0.04461787008040119, 0.0120947417235584, 0.03975952276960015, 0.05931239407800604, 0.041225264430977404, 0.12864407122833654, 1.7075515422038734, 36.49437412619591, 56.32733389735222, 47.47477412223816, 36.787266209721565, 27.048871368169785, 43.81251163780689, 51.51500232517719, 56.38339228928089, 16.14933293312788, 0.11629009546595626, 0.1491620796150528, 1.0214915871620178, 4.826521435752511, 3.487531947903335, 4.77318037301302, 25.97194455564022, 52.6205188035965, 58.201112151145935, 53.61329913139343, 47.92775921523571, 49.306215047836304, 51.22697778046131, 52.590135633945465, 51.47959202528, 51.83385081589222, 49.53714765608311, 48.84065642952919, 52.46934771537781, 51.98356278240681, 52.524938732385635, 49.115537479519844, 47.724762707948685, 46.92944258451462, 41.61054499447346, 40.03761179745197, 36.39200761914253, 36.17018312215805, 37.28337898850441, 37.43977099657059, 39.00519199669361, 42.35595479607582, 41.39553353190422, 41.64979688823223, 40.950398817658424, 44.712915122509, 43.266412541270256, 43.992944955825806, 47.52512902021408, 47.27299354970455, 44.88620102405548, 40.74797607958317, 37.97994241118431, 38.22848707437515, 38.6576284468174, 39.08764377236366, 38.07257764041424, 37.89033941924572, 37.31606103479862, 39.194269850850105, 37.54523813724518, 40.05044370889664, 42.75692068040371, 47.61469781398773, 50.66423177719116, 50.657870918512344, 41.57915487885475, 43.553285747766495, 49.07414250075817, 49.18549172580242, 51.22400254011154, 52.77482092380524, 48.91564540565014, 47.67367444932461, 53.703597486019135, 50.403702557086945, 48.18377427756786, 44.14897218346596, 44.55576315522194, 45.48179626464844, 46.63815401494503, 46.74026593565941, 48.26871111989021, 42.2559479624033, 38.730960711836815, 38.381934240460396, 37.28773355484009, 38.6457122862339, 38.75533640384674, 38.6156103014946, 40.10113678872585, 37.85158909857273, 39.32661294937134, 37.73328244686127, 44.06422533094883, 49.26249839365482, 47.71109864115715, 49.5060121268034, 49.9958286434412, 46.99430130422115, 47.818241491913795, 46.37517772614956, 44.62234318256378, 41.05736307799816, 39.57765407860279, 40.571676939725876, 39.16072525084019, 36.469280272722244, 38.79792831838131, 41.211437210440636, 38.42150531709194, 38.07925768196583, 40.95128037035465, 46.145924627780914, 49.224975407123566, 49.01763193309307, 51.30211114883423, 52.03884221613407, 54.31436911225319, 47.722954005002975, 44.47895407676697, 53.867452293634415, 55.385999009013176, 49.61676098406315, 45.833273604512215, 43.86390008032322, 45.888515040278435, 52.46426738798618, 56.402714252471924, 60.1875239610672, 45.38756512105465, 12.201261185109615, 2.5958409206941724, 4.497315175831318, 4.151266794651747, 1.3524748454801738, 0.15796442603459582, 3.869824684225023, 44.826684817671776, 59.59045059978962, 46.776922568678856, 41.54923528432846, 41.991675943136215, 42.0486006885767, 55.726517736911774, 33.0339378118515, 3.3832087833434343, 0.0875192490639165, 0.024129642224579584, 0.01124388889365946, 0.019540212124411482, 0.03685293107992038, 0.07089953462127596, 0.05004096579796169, 0.036866156151518226, 0.06536214816151187, 0.02998523006681353, 0.059726909530581906, 0.02035289722698508, 0.07129353340133093, 0.09589299035724252, 0.12513464782387018, 0.18319104972761124, 0.19045709108468145, 0.10005928867030889, 0.16063497023424134, 0.20206214336212724, 0.14240904041798785, 0.1084954000543803, 0.16512405825778842, 0.09422999326488934, 0.16356158506823704, 0.14206152234692127, 0.1966225274372846, 0.10457203636178747, 0.2930799953173846, 2.5038813427090645, 41.96221612393856, 64.30830404162407, 52.98490025103092, 44.8883631080389, 35.876614674925804, 54.556264132261276, 56.215141117572784, 61.48011200129986, 19.369610734283924, 0.2651335339760408, 0.4198156634811312, 2.687048614025116, 10.562618114054203, 4.664913732558489, 4.581510107964277, 25.84022842347622, 52.730948477983475, 60.750687941908836, 53.723964393138885, 49.52257543802261, 51.09314516186714, 51.517164409160614, 55.60449868440628, 52.70461969077587, 54.32205989956856, 51.24507240951061, 50.51417402923107, 56.04274816811085, 53.27028773725033, 53.447183445096016, 51.955349296331406, 48.998298570513725, 49.74748916924, 42.753067687153816, 41.23663365840912, 39.09723065793514, 39.101520627737045, 39.50169995427132, 39.84785757958889, 42.37871177494526, 44.22638542950153, 43.74799109995365, 44.22641582787037, 42.834307327866554, 47.01571315526962, 47.37366534769535, 48.35167206823826, 48.12412887811661, 51.08845241367817, 46.253740042448044, 42.90270745754242, 40.353644639253616, 40.51849119365215, 39.639047384262085, 41.987978741526604, 40.416535064578056, 40.15725217759609, 38.95053572952747, 41.42400540411472, 39.044751673936844, 42.41020828485489, 43.646566942334175, 50.86529798805714, 52.19651855528355, 53.4340513497591, 42.14476212859154, 44.39864918589592, 51.918278485536575, 51.00749775767326, 52.302745655179024, 54.65645715594292, 50.08809149265289, 50.55680774152279, 55.88821806013584, 53.11438970267773, 50.10018244385719, 46.41879178583622, 47.25311681628227, 48.82540784776211, 49.15902994573116, 49.14203725755215, 49.68916989862919, 45.35529725253582, 40.96405528485775, 40.07499039173126, 39.085827469825745, 41.42067678272724, 40.649804547429085, 39.0872447937727, 42.489285841584206, 39.08119171857834, 40.6164575368166, 40.57278648018837, 47.36785165965557, 52.1453694999218, 50.07220834493637, 52.14257664978504, 53.84388595819473, 49.533792436122894, 51.47145286202431, 49.67646338045597, 47.5767682492733, 44.279647171497345, 43.57006944715977, 43.00865717232227, 42.22975976765156, 37.91281521320343, 40.41024260222912, 43.18782135844231, 41.342002004384995, 38.93090598285198, 42.30085775256157, 47.61305250227451, 51.739422082901, 52.32988379895687, 56.192897111177444, 54.56492006778717, 55.89584045112133, 50.44359661638737, 46.09527334570885, 55.486636608839035, 57.7020089328289, 52.665348798036575, 48.28598499298096, 46.33419692516327, 46.9406595826149, 57.05457307398319, 59.773904755711555, 63.9750999212265, 46.283583641052246, 14.472105782479048, 3.015440055169165, 9.138614125549793, 12.961669731885195, 1.90250649349764, 0.22237367142224684, 4.060407970100641, 52.57819667458534, 63.29853482544422, 50.14779768884182, 51.30436822772026, 48.52344945073128, 50.33747211098671, 64.69426453113556, 39.10332553088665, 4.051477974280715, 0.24427893193205819, 0.1376329193590209, 0.15098850504728034, 0.17312617652351037, 0.22197941289050505, 0.1229336456162855, 0.2263440130627714, 0.0934967290959321, 0.16178328049136326, 0.32195497245993465, 0.1806805719388649, 0.07957549329148605, 0.20469072653213516], [0.013659359719895292, 0.01928416189912241, 0.034439344381098635, 0.010998241723427782, 0.08296324158436619, 0.057219752852688543, 0.038717859133612365, 0.027601724468695465, 0.08283574061351828, 0.017610644863452762, 0.02047883226623526, 0.04029904186609201, 0.011632861478574341, 0.036125017795711756, 0.011928787298529642, 0.027671712705341633, 0.44882134767249227, 20.16685165464878, 49.987852871418, 44.0635109692812, 32.30620086193085, 22.87079606205225, 29.402539171278477, 37.60755859315395, 49.237966910004616, 23.169870413839817, 0.4284557467326522, 0.10528938146308064, 0.383309627068229, 2.343746297992766, 3.1545166298747063, 1.0519817448221147, 11.432225201278925, 33.54710787534714, 50.3934621065855, 48.96475397050381, 52.48899646103382, 51.98534108698368, 52.22002789378166, 50.172918140888214, 49.303593188524246, 48.696169182658195, 46.05596825480461, 48.57905186712742, 49.37415160238743, 50.124588534235954, 48.6639279127121, 46.679062619805336, 43.151134327054024, 39.14469011127949, 35.59982992708683, 32.91846200823784, 34.91672918200493, 33.58645476400852, 34.295694306492805, 36.25072360038757, 35.657381638884544, 38.816668912768364, 38.401210606098175, 38.95547166466713, 39.46853153407574, 41.955676674842834, 41.873544082045555, 43.01175020635128, 43.821870535612106, 44.577642381191254, 41.53567761182785, 43.18220905959606, 37.13283106684685, 36.27236343920231, 37.07261949777603, 37.242591977119446, 36.22008964419365, 36.379798874258995, 36.77245460450649, 35.52069157361984, 35.12064903974533, 37.21698135137558, 42.99609124660492, 44.98776577413082, 46.82690128684044, 49.44507099688053, 49.1521181166172, 43.78171809017658, 45.062089785933495, 51.23728662729263, 49.915405958890915, 50.4316196590662, 47.444968521595, 44.9372398853302, 51.261726915836334, 46.940689980983734, 46.46184727549553, 42.652050107717514, 44.043847024440765, 43.9711607247591, 49.10653576254845, 45.147395208477974, 48.52469198405743, 43.07844802737236, 36.65497250854969, 36.2076985090971, 35.81155836582184, 37.709457725286484, 35.88854223489761, 36.16768665611744, 36.60505838692188, 38.20012539625168, 38.65869618952274, 43.59394736588001, 46.69018842279911, 49.026614651083946, 48.57798032462597, 47.14227296411991, 48.73589225113392, 48.0987386405468, 47.931897193193436, 48.02794083952904, 47.03922249376774, 47.84138984978199, 46.73058405518532, 44.48496535420418, 43.320160657167435, 39.053293615579605, 38.466605097055435, 35.98557762801647, 34.996338710188866, 36.96335256099701, 36.42977759242058, 36.93350896239281, 39.642588794231415, 44.58285190165043, 47.59987860918045, 46.05411775410175, 49.8322968184948, 54.405416026711464, 51.77331246435642, 54.31813471019268, 53.20018909871578, 53.2658913731575, 50.46032331883907, 43.799231350421906, 43.140612691640854, 47.244339287281036, 52.78049021959305, 56.89776308834553, 41.07793517410755, 6.787838442251086, 0.6661793030798435, 5.538190947845578, 1.8109754612669349, 1.2463566334918141, 0.13964274432510138, 3.559856554493308, 41.18065886199474, 52.55417816340923, 41.721411645412445, 41.274403631687164, 34.46055606007576, 34.18496064841747, 54.88101750612259, 20.762310102581978, 0.7198448921553791, 0.060866725907544605, 0.03409667995583732, 0.03672677339636721, 0.015582496271235868, 0.052450570874498226, 0.06127993889094796, 0.05896250113437418, 0.08401513201533817, 0.046570876220357604, 0.03286780585767701, 0.0714174126915168, 0.009687081073934678, 0.09060429016244598, 0.06395371514372528, 0.0664171259268187, 0.02060318467556499, 0.027108784415759146, 0.024788797381916083, 0.05627243845083285, 0.014722468640684383, 0.0722927981405519, 0.028573986164701637, 0.02036638205026975, 0.09607406696886756, 0.02832294729159912, 0.019975824980065227, 0.0196322551346384, 0.05268332322884817, 0.0517820590903284, 0.7116234989371151, 24.903662279248238, 55.47543101012707, 49.10705253481865, 36.82673469185829, 24.879145994782448, 39.28155116736889, 46.084861904382706, 53.17575640976429, 25.500965528190136, 0.27561087801586837, 0.04063940192281734, 0.555863028857857, 2.924990183673799, 4.102900614961982, 2.7914261631667614, 13.564482685178518, 36.993549540638924, 51.18367910385132, 50.89815862476826, 50.63968889415264, 53.539647683501244, 53.639901503920555, 53.16605173051357, 51.210292875766754, 49.458879455924034, 47.64858819544315, 50.47176070511341, 51.22450411319733, 50.65146066248417, 50.231188014149666, 50.330393090844154, 45.293174386024475, 41.1880798637867, 37.9258219152689, 35.38126565515995, 34.86247569322586, 35.23232884705067, 35.60258857905865, 37.335819974541664, 38.13723877072334, 41.867627799510956, 38.77623908221722, 41.09602980315685, 41.92633844912052, 43.9372855424881, 43.8611414283514, 46.41829401254654, 46.599688678979874, 46.89704932272434, 43.88891413807869, 43.82031261920929, 37.82445855438709, 37.59493567049503, 39.07314375042915, 39.029685482382774, 36.40186049044132, 37.929222732782364, 38.697560504078865, 37.35802598297596, 38.04738499224186, 38.240752816200256, 43.86378988623619, 45.747812390327454, 48.50471265614033, 50.44098235666752, 50.5560439825058, 45.6123648583889, 45.656932666897774, 52.24642127752304, 51.36719025671482, 52.481127083301544, 47.46416129171848, 46.829572543501854, 54.13719981908798, 49.452936574816704, 48.2746995985508, 44.21050228178501, 46.38991333544254, 45.403657257556915, 50.12616544961929, 48.036247193813324, 49.760872051119804, 44.75526764988899, 38.026774898171425, 38.02295610308647, 38.29973325133324, 39.06256131827831, 37.859678864479065, 37.79182970523834, 38.08213032782078, 38.87410283088684, 40.77816545963287, 44.886470809578896, 48.55728663504124, 50.65056391060352, 51.12620338797569, 48.32082152366638, 50.10989472270012, 49.98778447508812, 51.138731315732, 51.33095920085907, 49.69866178929806, 49.145533069968224, 48.227741718292236, 47.07326486706734, 44.19396176934242, 40.85334822535515, 39.227445870637894, 37.26548574864864, 36.555744633078575, 38.02980333566666, 38.64753618836403, 39.07309055328369, 43.51011246442795, 47.433626130223274, 49.068701192736626, 48.51373717188835, 51.7775796353817, 56.68253883719444, 51.612444296479225, 55.828485265374184, 54.19296942651272, 55.0157430768013, 49.829139187932014, 44.719408974051476, 46.13443024456501, 50.20550899207592, 54.79092814028263, 58.600303530693054, 43.34702901542187, 8.180259000509977, 2.9216093150898814, 5.961947534233332, 3.963835914619267, 1.1048371461220086, 0.09597953961929306, 3.762907446362078, 47.26207673549652, 57.7188990265131, 42.82152481377125, 42.9197533428669, 40.0736528635025, 39.89513464272022, 61.76421135663986, 26.014428175985813, 1.1712464201264083, 0.09310197332524695, 0.04151581524638459, 0.10059206164442003, 0.015740757407911588, 0.01148805269622244, 0.09856242133537307, 0.015405172143800883, 0.06413451716070995, 0.027205855476495344, 0.05532941366254818, 0.03299751471786294, 0.02782317762466846, 0.05511990537343081, 0.18362115399213508, 0.17354795389110222, 0.12380997359286994, 0.17818440275732428, 0.19481079652905464, 0.2104346378473565, 0.14799658121773973, 0.16206176398554817, 0.20660071779275313, 0.12651535420445725, 0.13453810417558998, 0.13498205691576004, 0.11597365111811087, 0.13309382542502135, 0.12515933165559545, 0.140645578794647, 0.8945627231150866, 28.88021729886532, 63.59842233359814, 56.399275436997414, 45.16626499593258, 31.459904573857784, 40.81076771020889, 48.92884209752083, 59.481328055262566, 28.740645088255405, 0.7588250411208719, 0.27768348867539316, 2.154733040370047, 9.617345687001944, 6.44880685955286, 2.1068655839189887, 13.909744508564472, 38.38721975684166, 52.10203282535076, 51.36123977601528, 52.65262708067894, 55.118470564484596, 56.744916290044785, 55.29336377978325, 54.7521436214447, 51.37058727443218, 52.77404576539993, 52.326046004891396, 53.53831775486469, 54.24727611243725, 53.71121987700462, 53.076691925525665, 46.77705176174641, 43.1108982861042, 40.21744854748249, 37.31014475226402, 37.9618363827467, 36.71712577342987, 37.89510816335678, 40.811592265963554, 39.52053174376488, 45.34155339002609, 41.64185531437397, 43.56353759765625, 44.41684640944004, 46.196750700473785, 45.43934114277363, 48.713937029242516, 47.63541430234909, 49.847199618816376, 45.645495280623436, 47.671459168195724, 40.39438605308533, 38.587548807263374, 41.47675797343254, 41.05686530470848, 38.83072055876255, 39.0063813328743, 40.57818979024887, 38.2034882158041, 39.84288364648819, 40.90752571821213, 46.14332176744938, 46.67758829891682, 50.37358157336712, 52.541650235652924, 51.32771037518978, 47.06767916679382, 48.5355594009161, 52.92009852826595, 52.989988178014755, 53.57422962784767, 49.967748150229454, 49.33789774775505, 54.54674184322357, 51.8257762491703, 49.808422699570656, 46.72013841569424, 47.33027547597885, 48.00593622028828, 53.15565928816795, 48.91447886824608, 51.58017262816429, 46.18591748178005, 39.78693924844265, 38.54087211191654, 39.831860437989235, 41.24950356781483, 38.843750059604645, 39.25590254366398, 39.70610238611698, 42.130721881985664, 43.13728787004948, 48.84946435689926, 51.25949263572693, 53.356406316161156, 53.63468058407307, 50.39529740810394, 52.53033064305782, 52.08978608250618, 51.93334847688675, 52.57737971842289, 53.143423944711685, 52.72619493305683, 50.945724472403526, 50.761229172348976, 46.590394377708435, 42.81936652958393, 42.11856633424759, 39.112068861722946, 36.749800220131874, 39.82046104967594, 42.14552968740463, 40.73099859058857, 45.28132662177086, 50.93278996646404, 50.79955391585827, 50.87002493441105, 54.140247255563736, 59.439420104026794, 52.580282762646675, 57.07430921494961, 53.826840072870255, 56.80767372250557, 55.82256518304348, 48.256680965423584, 48.675638884305954, 53.47823157906532, 58.683534264564514, 59.95434187352657, 46.87459632754326, 9.61301676928997, 2.582038873806596, 11.650184355676174, 10.741480216383934, 3.5348049737513065, 0.26315009978134185, 3.657231079414487, 51.609100475907326, 65.79268679022789, 56.26793548464775, 57.205911353230476, 47.41784177720547, 46.81381858885288, 70.37996783852577, 33.49651739001274, 1.5138627542182803, 0.1854336418909952, 0.13634478847961873, 0.14241727825719863, 0.052477195422397926, 0.14234147529350594, 0.17136074078734964, 0.17857021564850584, 0.2313846503966488, 0.09491221251664683, 0.12922739930218086, 0.10107351510669105, 0.09702774157631211, 0.18546453007729724], [0.04974684154149145, 0.03914778899343219, 0.042277971224393696, 0.0706030688888859, 0.08545010423404165, 0.027419248908699956, 0.04499225389736239, 0.026795611083798576, 0.01931930073624244, 0.016690075608494226, 0.05356247507734224, 0.05876128634554334, 0.07560196783742867, 0.07163515881984495, 0.008462546684313565, 0.05094112413644325, 0.20294872781960294, 11.541376244276762, 43.95251892507076, 48.84973034262657, 28.195638433098793, 22.264561392366886, 40.29146857559681, 39.98700611293316, 46.06674447655678, 29.758937247097492, 1.1359470267780125, 0.04306559399992693, 0.6308463646564633, 1.523412591777742, 3.4898909088224173, 2.0174112590029836, 1.8988430150784552, 13.888985272496939, 35.670004561543465, 52.53182016313076, 50.1116768270731, 53.290514051914215, 49.41523499786854, 48.46007265150547, 47.09747716784477, 44.18210260570049, 46.37542851269245, 46.03184334933758, 46.858120411634445, 47.38908492028713, 45.32000474631786, 41.70844294130802, 36.93941004574299, 35.46429879963398, 33.42960678040981, 34.762054681777954, 33.38077940046787, 35.96974387764931, 35.47273434698582, 36.239799186587334, 36.4566383510828, 38.224200904369354, 36.20313875377178, 37.19203568994999, 39.48417529463768, 40.8796314150095, 39.854241237044334, 40.302347391843796, 43.21634262800217, 45.173834189772606, 43.46958763897419, 42.38755390048027, 39.48863245546818, 37.274669855833054, 36.072866544127464, 36.23638316988945, 36.33570224046707, 35.98799429833889, 36.241463497281075, 36.48672893643379, 36.47409841418266, 38.32100450992584, 40.409269854426384, 43.33266578614712, 47.21691615879536, 47.87670135498047, 47.25067734718323, 49.45369653403759, 47.32052139937878, 48.24262551963329, 50.19484296441078, 50.32933294773102, 47.74432025849819, 46.57888099551201, 52.48338796198368, 48.21153178811073, 48.609294444322586, 43.743731528520584, 44.13780838251114, 44.347553327679634, 49.92153882980347, 48.94344851374626, 49.99378815293312, 43.51930037140846, 34.70559351146221, 36.002395525574684, 37.57273726165295, 38.0800936371088, 38.71518015861511, 36.6216254979372, 38.302750289440155, 37.91001096367836, 44.71006527543068, 46.143713146448135, 50.97047634422779, 50.36643035709858, 49.70890983939171, 46.87191367149353, 47.631276324391365, 49.96663860976696, 49.58463750779629, 50.100106447935104, 50.60753121972084, 48.12848724424839, 49.87146891653538, 48.784354850649834, 51.5920127928257, 46.01641237735748, 45.77701762318611, 40.85102275013924, 38.066288977861404, 34.02824565768242, 35.89296519756317, 35.69547459483147, 39.34068359434605, 39.141205698251724, 41.926247254014015, 44.63630363345146, 47.74489402770996, 47.775725573301315, 52.39355318248272, 49.20933164656162, 48.88813488185406, 54.06889468431473, 54.71094623208046, 47.10815839469433, 44.14880879223347, 46.431410908699036, 52.621221765875816, 56.331908851861954, 34.413499385118484, 3.375573568046093, 3.4499061293900013, 2.0011526439338923, 0.7629971578717232, 1.0255465633235872, 0.15825095440959558, 5.017756624147296, 40.50310201942921, 49.97715264558792, 43.99941220879555, 47.78562404215336, 33.20880822837353, 35.24129256606102, 49.4867167621851, 15.92315386980772, 0.6437228049617261, 0.09955697343684733, 0.0440645470371237, 0.01840817159973085, 0.05284226528601721, 0.01858852647274034, 0.028001092687190976, 0.026874310278799385, 0.046317458763951436, 0.036194193380651996, 0.08475453374558128, 0.06859232365968637, 0.05240906626568176, 0.08461080942652188, 0.0127287993018399, 0.057442397155682556, 0.1487008496769704, 0.04489477651077323, 0.04144924459978938, 0.06067874361178838, 0.09426251417608, 0.010598620247037616, 0.04214127504383214, 0.010412937681394396, 0.08617842569947243, 0.03469340750598349, 0.03282051991845947, 0.03739620544365607, 0.018279548130522016, 0.02245596933789784, 0.20252237882232293, 15.54726094007492, 51.06949903070927, 53.39747831225395, 33.35312828421593, 25.54357074201107, 38.27647849917412, 43.21896068751812, 51.556404903531075, 31.312504783272743, 1.2573691550642252, 0.032848977571120486, 0.541349173290655, 2.517479150556028, 4.892248408868909, 3.0132385483011603, 3.317225561477244, 18.90242390334606, 39.69710446894169, 52.776139453053474, 50.76352804899216, 54.118618816137314, 52.140178978443146, 52.04885467886925, 49.52430434525013, 47.13014781475067, 48.245889544487, 46.38878479599953, 48.67788456380367, 48.939591720700264, 48.16343016922474, 44.34358634054661, 39.427231550216675, 36.805505231022835, 36.21658243238926, 36.69189132750034, 34.37591180205345, 37.65418589115143, 37.917690351605415, 37.93504782021046, 39.21907112002373, 39.572288766503334, 38.33195552229881, 39.18105036020279, 40.05731754004955, 43.236124366521835, 43.14626678824425, 43.67286913096905, 46.135532185435295, 46.85568854212761, 45.91751508414745, 43.85302886366844, 40.96502423286438, 37.622385397553444, 37.61469841003418, 37.713694497942924, 38.41635659337044, 37.68003970384598, 38.118615970015526, 37.87897802889347, 37.78554864227772, 38.11569392681122, 42.807853147387505, 45.39786256849766, 48.01961928606033, 49.487427324056625, 48.98476369678974, 49.04133506119251, 48.37066724896431, 49.49559308588505, 48.73041674494743, 50.54627850651741, 48.24534237384796, 48.438391014933586, 52.76384711265564, 50.64452983438969, 49.15942892432213, 46.40517711639404, 46.04514643549919, 46.40157870948315, 50.82969769835472, 50.91021917760372, 53.14044490456581, 45.9853832423687, 38.42704921960831, 37.781988233327866, 38.95702198147774, 40.06283864378929, 39.55904267728329, 38.16357135772705, 40.10600432753563, 38.10133829712868, 45.48230163753033, 47.721445485949516, 52.73450888693333, 54.33565177023411, 50.989695712924004, 49.26713414490223, 52.15193174779415, 52.43437819182873, 51.46505020558834, 51.14737965166569, 51.25981941819191, 50.80851003527641, 51.5375617146492, 52.03918419778347, 51.23087637126446, 49.06813882291317, 46.51286333799362, 42.536722496151924, 39.74336318671703, 36.1832620203495, 38.25556442141533, 36.521314680576324, 40.22306464612484, 41.34385250508785, 44.50308658182621, 47.331263422966, 49.89990659058094, 50.54673068225384, 53.93136486411095, 50.42571857571602, 51.029137596488, 55.28791107237339, 56.883559450507164, 48.777625411748886, 47.2965332865715, 47.909687384963036, 54.914945885539055, 56.55555345118046, 38.374551236629486, 3.87440153863281, 4.066586913540959, 7.512846188619733, 4.112315559759736, 0.5643146659713238, 0.1244955621950794, 4.073940943926573, 45.61488792300224, 55.39004199206829, 48.83910991251469, 52.44637414813042, 39.96821232140064, 41.28614120185375, 57.87682235240936, 20.928099006414413, 0.7648535363841802, 0.057450200838502496, 0.03638020898506511, 0.040315684527740814, 0.008714853702258551, 0.02549261313106399, 0.02308092818566365, 0.08571825703256764, 0.06295072482316755, 0.04152050933043938, 0.027209371401113458, 0.04265962808858603, 0.06668778718449175, 0.032156049128388986, 0.10149596782866865, 0.13189310469897464, 0.2997556433547288, 0.16548661224078387, 0.1037563566933386, 0.1370667794253677, 0.14398341765627265, 0.1870907685952261, 0.08142756734741852, 0.15602555038640276, 0.22502615174744278, 0.15106132457731292, 0.1369384175632149, 0.11731350226909854, 0.13111186068272218, 0.06938239923329093, 0.4496547201415524, 17.205009385943413, 59.05958488583565, 60.404522716999054, 39.72420461475849, 32.219462916255, 50.88820695877075, 52.37706206738949, 56.567203626036644, 37.053232938051224, 1.6204093932174146, 0.10839249385753646, 1.7575606587342918, 8.021228034049273, 9.189461097121239, 4.2513990215957165, 2.7986562252044678, 16.927859857678413, 38.869106099009514, 53.1978028267622, 51.526641100645065, 56.335632652044296, 54.49563078582287, 53.77992779016495, 51.761548295617104, 48.805648908019066, 51.09948322176933, 49.698513597249985, 51.50775611400604, 51.85288019478321, 49.82537738978863, 45.885232016444206, 40.442860051989555, 39.225200191140175, 36.937023773789406, 39.28963713347912, 37.05270856618881, 39.99816231429577, 39.40543971955776, 40.081176459789276, 41.177641823887825, 42.59871616959572, 41.366620883345604, 41.04855515062809, 42.17523269355297, 46.53573431074619, 45.92071071267128, 44.57854673266411, 47.938645631074905, 50.28511852025986, 48.65494519472122, 46.81284964084625, 42.55232825875282, 40.99546059966087, 39.337981939315796, 39.978023394942284, 39.990262538194656, 40.18176846206188, 40.502311661839485, 38.87740485370159, 38.61832715570927, 41.77750043570995, 45.878654569387436, 46.87155269086361, 51.2663284689188, 50.86532078683376, 50.46164944767952, 51.74406163394451, 48.854552283883095, 51.88864767551422, 52.49094195663929, 53.072789534926414, 50.23915238678455, 50.72404056787491, 54.82298702001572, 53.328964188694954, 52.69077703356743, 48.45629945397377, 47.89701886475086, 47.800868824124336, 54.82243224978447, 52.56573334336281, 54.48675446212292, 47.3452390730381, 39.26879525184631, 39.72231611609459, 40.390301272273064, 41.55730605125427, 41.52257591485977, 38.46234932541847, 42.95799449086189, 40.23133300244808, 48.97911719977856, 50.61234176158905, 55.623642057180405, 55.78552857041359, 52.96578727662563, 51.1363260447979, 52.7043841034174, 53.69819417595863, 53.40243324637413, 53.11404772102833, 53.37573207914829, 51.08425363898277, 55.14220409095287, 54.5393930375576, 55.4851508885622, 50.6522586196661, 50.42137160897255, 45.64321920275688, 43.745969608426094, 37.36012727022171, 40.54322026669979, 39.649766609072685, 43.200246691703796, 43.2435567677021, 46.889882907271385, 48.84188376367092, 52.97953873872757, 53.47221650183201, 56.86612218618393, 51.93536996841431, 52.95671336352825, 53.973390609025955, 59.540950655937195, 53.09851415455341, 48.78810904920101, 51.74368545413017, 56.963507160544395, 60.55014610290527, 38.51342998445034, 4.720835331827402, 8.45607005059719, 10.221967343240976, 7.470019161701202, 2.4941861629486084, 0.1612627974827774, 5.007003201171756, 50.63113555312157, 62.583511993288994, 57.98504054546356, 59.12706546485424, 46.69048860669136, 49.42328676581383, 66.9813846051693, 27.381667010486126, 1.3708589714951813, 0.16470087080961093, 0.10010229612817056, 0.11522367378347553, 0.11023527622455731, 0.11053582376916893, 0.10719439291278832, 0.12041973168379627, 0.1639513164991513, 0.11345967039233074, 0.22421453904826194, 0.19115643168333918, 0.14138791942968965, 0.1573043895768933], [0.026494649791857228, 0.06098374033172149, 0.04528062650933862, 0.05073677748441696, 0.033422579799662344, 0.00821434930912801, 0.047574100317433476, 0.03762103908229619, 0.06199197763635311, 0.07625522106536664, 0.021910151263000444, 0.025768458290258422, 0.03633637403254397, 0.06099134363466874, 0.007824631793482695, 0.015779760979057755, 0.014245983857108513, 5.539654344320297, 30.669393092393875, 51.52130998671055, 34.45953391492367, 19.281193278729916, 29.749034978449345, 42.8895715624094, 48.990425392985344, 39.47918236255646, 4.457047311589122, 0.12221600365592167, 0.19424150988925248, 1.0646108421497047, 2.736326982267201, 6.326651014387608, 1.0435104556381702, 5.582352178171277, 27.38657634705305, 49.55644302070141, 53.9796906709671, 51.30213774740696, 48.02586995065212, 47.805789560079575, 43.71119387447834, 41.37419007718563, 39.06628891825676, 41.23492754995823, 39.57006208598614, 40.16326725482941, 37.982811257243156, 33.56845512986183, 33.931943625211716, 34.361825957894325, 32.674211114645004, 33.98391343653202, 35.09771727025509, 34.677942395210266, 35.29159426689148, 36.05784974992275, 36.599066108465195, 37.23476439714432, 36.36303797364235, 35.54277218878269, 37.78079889714718, 39.893576726317406, 38.325431272387505, 40.66816136240959, 40.8924975246191, 45.3299830108881, 42.634882628917694, 41.24792665243149, 38.84661130607128, 39.65740039944649, 35.55272005498409, 35.45438513159752, 35.37051223218441, 36.93784072995186, 36.565323919057846, 36.179139241576195, 34.893478229641914, 36.89856983721256, 39.6025275439024, 42.598814964294434, 44.311751648783684, 48.44608560204506, 48.282732367515564, 50.782614424824715, 47.761096358299255, 49.843038842082024, 47.607387006282806, 49.48588080704212, 46.13096863031387, 45.24707905948162, 50.4796376824379, 49.16110843420029, 48.47094006836414, 42.810862585902214, 46.43728919327259, 43.925251588225365, 49.606064558029175, 48.97171899676323, 48.068078085780144, 44.00873310863972, 35.83715759217739, 36.929253190755844, 37.11553439497948, 38.07141490280628, 37.85616025328636, 37.24869064986706, 37.3006908595562, 41.017028242349625, 47.33471363782883, 47.70325966179371, 51.408003866672516, 52.434598580002785, 47.69942186772823, 45.177014619112015, 45.89581824839115, 47.191719710826874, 49.46473874151707, 50.47769598662853, 48.99049758911133, 49.59149233996868, 50.2163840085268, 50.14931000769138, 50.34256003797054, 52.87899613380432, 49.016066417098045, 46.870579943060875, 44.69925485551357, 40.19518934190273, 36.84675581753254, 36.31618268787861, 36.22841119766235, 35.61114192008972, 37.57637746632099, 40.09539909660816, 45.084523782134056, 46.79147578775883, 48.61174151301384, 56.72923073172569, 46.24052055180073, 48.38555105030537, 55.09348690509796, 56.50264889001846, 48.36039640009403, 50.27384452521801, 50.66924370825291, 56.28068760037422, 26.397605314850807, 1.9895639782771468, 2.682270370423794, 5.68293278105557, 1.4037558250129223, 0.1872927663498558, 0.1733683393104002, 3.8692896254360676, 43.79499837756157, 50.23768946528435, 40.09082414209843, 30.3969382122159, 26.488156355917454, 46.387470066547394, 47.74471163749695, 14.22414818778634, 0.1394102443009615, 0.12525782949524, 0.021288491261657327, 0.08874120263499208, 0.13192681304644793, 0.10356711645727046, 0.03696254258102272, 0.05764816502050962, 0.01738364044285845, 0.0739248699392192, 0.06823241914389655, 0.0257140848407289, 0.007598469246659079, 0.020982403584639542, 0.03186225141689647, 0.06856254127342254, 0.009532231961202342, 0.04044069930387195, 0.009420748392585665, 0.038668365305056795, 0.0573136679304298, 0.036886973393848166, 0.0303454332970432, 0.060046574799343944, 0.05520874045032542, 0.05509460926987231, 0.05794202952529304, 0.028271594383113552, 0.0735037456615828, 0.04353137701400556, 0.025026900621014647, 7.544495165348053, 41.736880615353584, 57.24388271570206, 38.94236236810684, 24.381885677576065, 38.55244629085064, 47.72151008248329, 52.7404897660017, 42.01741196215153, 4.146321834996343, 0.10185780934989452, 0.1409064288600348, 1.2276682863011956, 3.157002408988774, 7.6258093770593405, 2.6748721674084663, 8.035672008991241, 29.777248464524746, 49.916872680187225, 55.009222626686096, 53.795043379068375, 51.78626976907253, 49.76048447191715, 46.2927183508873, 44.26269628107548, 42.57874824106693, 43.91506053507328, 41.45283825695515, 42.390103563666344, 40.018559619784355, 35.04655301570892, 35.733366161584854, 36.331469267606735, 34.45953391492367, 35.55569909512997, 36.883686035871506, 36.27563126385212, 38.89317400753498, 38.89247864484787, 38.233548402786255, 39.48249578475952, 38.976435139775276, 37.631295919418335, 39.07090567052364, 40.21785892546177, 41.099985390901566, 41.74840919673443, 44.7747378051281, 46.22134678065777, 43.50259646773338, 42.52244286239147, 42.089243307709694, 41.00923106074333, 37.62216120958328, 38.12833584845066, 36.94941870868206, 39.56954151391983, 37.79627926647663, 37.90592238306999, 37.59734854102135, 38.963793218135834, 41.32201887667179, 44.75619480013847, 45.70951424539089, 50.06864033639431, 49.776899591088295, 51.33573554456234, 47.287565767765045, 50.75834132730961, 50.504264160990715, 50.701777562499046, 49.11825053393841, 46.81622385978699, 52.60963998734951, 52.12402984499931, 50.94808794558048, 45.65851718187332, 47.28887289762497, 46.14172585308552, 50.85688903927803, 51.48513972759247, 49.90025997161865, 45.962185487151146, 36.40618085861206, 38.158608824014664, 38.86155590415001, 40.27930922806263, 39.049813002347946, 39.84159171581268, 39.47431482374668, 42.77287222445011, 49.03152398765087, 50.07554456591606, 53.385904133319855, 53.25263008475304, 49.74209725856781, 46.92243576049805, 47.694425135850906, 49.88911896944046, 51.91114626824856, 52.386295571923256, 51.82707577943802, 51.24107122421265, 52.50146359205246, 53.00448440015316, 53.020489141345024, 51.92107133567333, 51.42804019153118, 48.65197755396366, 45.69827064871788, 41.991307362914085, 38.838468343019485, 39.24241326749325, 38.646658435463905, 38.4127201884985, 40.391897186636925, 43.09780418872833, 46.87538668513298, 49.29041549563408, 51.474941074848175, 56.67061507701874, 49.01083789765835, 51.99708625674248, 55.4604522138834, 57.411449924111366, 51.11818961799145, 52.24360562860966, 53.12330022454262, 56.253739446401596, 29.17989581823349, 3.6991418804973364, 3.505388139747083, 7.527829259634018, 5.940482961013913, 0.7162023126147687, 0.25371202966198325, 4.030107920989394, 47.88850352168083, 54.13412198424339, 47.620959877967834, 39.93638902902603, 30.810122340917587, 51.23531833291054, 56.577048897743225, 18.016628734767437, 0.37708829215262085, 0.06622396715101786, 0.023843254857638385, 0.10576189204584807, 0.03805175190791488, 0.09732184727909043, 0.01714921269012848, 0.05705915951693896, 0.15315063355956227, 0.08617778745247051, 0.011740145419025794, 0.010912915149674518, 0.02120978278981056, 0.03865232378302608, 0.10742144557298161, 0.1413316943217069, 0.12248245693626814, 0.14687613118439913, 0.07151927988161333, 0.1442754824529402, 0.17035392840625718, 0.1185928906488698, 0.1583473148639314, 0.16757100820541382, 0.21030026458902285, 0.1887123761116527, 0.17106230836361647, 0.14587614656193182, 0.1352421796764247, 0.13984609278850257, 0.1382424749317579, 8.424305655062199, 46.56579829752445, 65.38017332553864, 45.25839105248451, 29.220836721360683, 40.1498007774353, 54.12749893963337, 58.89074854552746, 46.60723127424717, 6.314386697486043, 0.2720850828336552, 0.7754943310283124, 6.154008228331804, 9.408741630613804, 13.972307201474905, 2.348522166721523, 8.108711689710617, 30.91501571238041, 50.71332134306431, 58.340724259614944, 54.97821629047394, 53.70038665831089, 53.19372944533825, 48.59073244035244, 45.06822645664215, 43.049125000834465, 44.36984293162823, 42.312500327825546, 43.616647347807884, 41.528803780674934, 36.290290877223015, 38.670779541134834, 38.2464487105608, 35.76240040361881, 38.45908910036087, 39.29894283413887, 39.78504315018654, 40.40874928236008, 42.459202855825424, 40.237621665000916, 42.041916847229004, 40.331218242645264, 39.20748174190521, 41.63375034928322, 43.31122353672981, 42.288428619503975, 45.07994122803211, 45.78004226088524, 50.10252311825752, 45.74444197118282, 46.44319407641888, 43.96706074476242, 44.31433171033859, 39.19369228184223, 38.60534705221653, 39.08428095281124, 41.78985737264156, 41.55881077051163, 39.50043082237244, 38.461262583732605, 41.59205138683319, 43.4797140955925, 46.06730304658413, 47.81176283955574, 52.68467456102371, 52.2662790119648, 53.907129764556885, 48.03923383355141, 51.76172308623791, 50.27638278901577, 52.07737594842911, 50.25989927351475, 49.11948546767235, 56.04151323437691, 52.81279228627682, 52.090295255184174, 46.72991909086704, 48.957625553011894, 47.65234999358654, 53.391805216670036, 53.396220579743385, 52.8529067337513, 49.37426179647446, 38.39271426200867, 40.89831501245499, 40.415908098220825, 41.18578098714352, 42.13781610131264, 41.40586897730827, 41.0090334713459, 45.44139303267002, 50.44663265347481, 52.01556846499443, 56.03218853473663, 58.386644795536995, 51.85156166553497, 49.317527040839195, 49.501763954758644, 51.631044298410416, 53.187072202563286, 55.30207671225071, 53.06070238351822, 52.86810591816902, 54.918255507946014, 54.37897324562073, 55.98035551607609, 57.173966467380524, 54.56868566572666, 51.84932358562946, 48.904546201229095, 44.2244703322649, 41.844627633690834, 40.58978296816349, 40.53559027612209, 39.66969273984432, 40.97389295697212, 45.082851871848106, 50.40940225124359, 52.22867242991924, 53.583014756441116, 60.54070740938187, 51.01137354969978, 53.7439589202404, 55.105897039175034, 60.08166924118996, 54.94271859526634, 56.25359505414963, 55.72359189391136, 61.2628548592329, 30.380291305482388, 4.121014242991805, 7.836955497041345, 15.060107130557299, 4.486096752807498, 0.664864870486781, 0.32839895167853683, 4.60375458933413, 53.60107518732548, 62.364168763160706, 52.57051348686218, 43.1827562302351, 38.09968538582325, 59.70506004989147, 63.96735593676567, 23.895023502409458, 0.48734172130934894, 0.2439606247935444, 0.06993270915700123, 0.2246006636414677, 0.19238116830820218, 0.21380011428846046, 0.2382230365765281, 0.15216497238725424, 0.30029373010620475, 0.255754865356721, 0.1499071513535455, 0.11344401849783026, 0.06648388953180984, 0.12044209259329364], [0.038617940081167035, 0.07248072477523237, 0.057377214325242676, 0.0014494845686385815, 0.03094781786785461, 0.03222617837309372, 0.029716246062889695, 0.049612950679147616, 0.05692183993232902, 0.050849736071540974, 0.02231045458756853, 0.020328254213382024, 0.06553106839419343, 0.019217381595808547, 0.01662341590417782, 0.022024119170964696, 0.030938583695387933, 2.140556713566184, 23.5788918659091, 50.085047855973244, 42.31713607907295, 27.480480708181858, 30.51490668207407, 47.4051770567894, 42.28213995695114, 47.68431767821312, 9.120767433196306, 0.07897445757407695, 0.1349032556754537, 1.0097307432442904, 1.700020821299404, 3.995248591527343, 2.6009886944666505, 2.514283759519458, 22.54595909267664, 49.4345797598362, 51.86768040060997, 49.84463095664978, 47.97991521656513, 46.12255968153477, 43.32027085125446, 38.69977958500385, 38.337058648467064, 36.45307034254074, 36.760443449020386, 33.9741213619709, 35.20417235791683, 34.91668738424778, 34.36512418091297, 34.51400399208069, 36.08214184641838, 37.20891438424587, 35.07951244711876, 34.75346714258194, 35.34238614141941, 34.90030646324158, 37.10143335163593, 35.8614344894886, 36.516162157058716, 36.08774274587631, 35.49122415482998, 37.35839456319809, 35.98592720925808, 37.82104633748531, 39.78130795061588, 39.80674758553505, 41.63739815354347, 39.96895328164101, 38.876249715685844, 37.25162789225578, 36.45088165998459, 35.41948780417442, 36.15036338567734, 36.635931730270386, 36.5800329297781, 36.21452294290066, 35.91328650712967, 36.23480625450611, 39.44555416703224, 40.47924689948559, 41.65004387497902, 46.28222331404686, 47.03688561916351, 49.26818288862705, 49.86905984580517, 50.706553906202316, 48.806598857045174, 49.59866635501385, 46.85166075825691, 38.58485475182533, 48.895525485277176, 48.079431876540184, 47.222068682312965, 41.693114563822746, 44.749199375510216, 47.302194982767105, 49.99692678451538, 50.19607409834862, 50.44579289853573, 45.06633035838604, 35.51838129758835, 35.339593291282654, 36.44433081150055, 36.72819457948208, 36.25332646071911, 36.394435688853264, 36.841333508491516, 43.99572640657425, 47.46882364153862, 51.201374754309654, 51.33614972233772, 48.749301731586456, 44.70023900270462, 42.80869670212269, 43.538949117064476, 46.78235247731209, 49.173951745033264, 48.33067059516907, 50.595805048942566, 49.42114368081093, 48.4945710003376, 48.26992325484753, 49.6007714420557, 49.86192382872105, 50.28679043054581, 49.68513071537018, 50.39813585579395, 45.62528036534786, 43.61723251640797, 39.975906908512115, 37.027827501297, 36.74113288521767, 37.53866069018841, 38.7076261639595, 39.16727989912033, 45.873912423849106, 46.740596517920494, 48.852675184607506, 54.753655940294266, 48.77076677978039, 47.91374556720257, 50.32475799322128, 56.486400961875916, 51.73268884420395, 56.36661998927593, 46.62390477955341, 19.819090515375137, 1.7602316779084504, 2.2047371696680784, 5.555437272414565, 8.313551098108292, 0.425346830743365, 0.2745182882063091, 3.408399294130504, 40.071999952197075, 47.85107173025608, 43.20175901055336, 25.524425469338894, 29.778713285923004, 44.84898202121258, 44.108975529670715, 11.819085292518139, 0.07158717155107297, 0.02013489505770849, 0.03229808135074563, 0.04657019715523347, 0.06265430361963809, 0.03427624258620199, 0.08897537249140441, 0.027005458905478008, 0.007336414118981338, 0.0566969172359677, 0.008726372761884704, 0.082198005693499, 0.01739938510581851, 0.06672554765827954, 0.08454967872239649, 0.1013232403784059, 0.12046121031744406, 0.04146153085457627, 0.01864915251644561, 0.004432324394656462, 0.023634752178622875, 0.04001988301752135, 0.04134264250751585, 0.012816916350857355, 0.03368156336364336, 0.04822043301828671, 0.05269653716823086, 0.022127286974864546, 0.010596877127682092, 0.0384203766589053, 0.02279834803630365, 3.311418523080647, 28.92154388129711, 56.06355205178261, 45.40003225207329, 27.261203974485397, 32.41059646010399, 53.85764122009277, 48.71085539460182, 52.79325373470783, 10.402252469211817, 0.047696773617644794, 0.1933154431753792, 0.827849762281403, 4.0318643767386675, 8.401255141943693, 4.780076052993536, 4.495613342151046, 25.372549518942833, 51.53422549366951, 54.2354017496109, 51.49267852306366, 51.4507819712162, 47.51512795686722, 46.535377129912376, 40.37401154637337, 40.57144895195961, 38.64649124443531, 38.97941417992115, 36.634130626916885, 37.44405336678028, 36.14600121974945, 35.96359580755234, 35.00842206180096, 36.47497996687889, 38.51309560239315, 38.38800631463528, 37.22041256725788, 36.98568016290665, 36.808978244662285, 39.03882019221783, 37.211171463131905, 37.67154335975647, 37.67569653689861, 38.16351816058159, 38.932821080088615, 38.76530706882477, 40.48699848353863, 41.393409445881844, 41.933364272117615, 44.71558257937431, 41.77105598151684, 41.88101068139076, 39.52677480876446, 37.40683436393738, 36.75746440887451, 38.506119176745415, 38.356361612677574, 38.79266940057278, 37.34059251844883, 36.871541887521744, 38.98634120821953, 40.921938344836235, 40.844623893499374, 45.082335099577904, 47.3415532708168, 48.06875444948673, 51.32313162088394, 49.97082218527794, 50.213230177760124, 50.538599118590355, 52.45081230998039, 48.27989012002945, 42.137857899069786, 51.7132680863142, 51.72268398106098, 49.20506067574024, 45.23537188768387, 47.16514393687248, 49.48613919317722, 51.15499064326286, 50.5851124227047, 50.8188720792532, 45.971016213297844, 39.21828456223011, 37.132048308849335, 38.08631010353565, 37.452914491295815, 38.70701439678669, 38.475591614842415, 38.00430290400982, 45.32918505370617, 50.0537945330143, 53.85576792061329, 53.73791724443436, 49.603218510746956, 48.60112488269806, 45.02962052822113, 45.917336493730545, 48.33580031991005, 50.95938093960285, 49.39957983791828, 52.92436569929123, 51.40492603182793, 52.143325209617615, 49.21678684651852, 52.74522811174393, 51.33666269481182, 51.789754182100296, 50.14533542096615, 51.58513896167278, 48.3667116612196, 44.57643784582615, 42.622928470373154, 39.37175452709198, 38.505176827311516, 38.87001425027847, 40.91349899768829, 42.20451392233372, 47.433557733893394, 48.80112335085869, 53.349004313349724, 54.74295571446419, 52.240516394376755, 49.964601919054985, 54.61370564997196, 56.6018957644701, 54.31210823357105, 57.24224880337715, 51.911469250917435, 21.025594174861908, 2.6181371742859483, 5.034119496122003, 6.171252178028226, 7.973832227289677, 1.0349967749789357, 0.18300793220987543, 3.5111426934599876, 46.65892370045185, 53.42369690537453, 45.67254222929478, 26.564699448645115, 34.69487428665161, 50.84189884364605, 52.76903383433819, 14.93807952851057, 0.12028903205646202, 0.06873557300423272, 0.027796033573395107, 0.014984472745709354, 0.061240801733219996, 0.04286889889044687, 0.09674468645243905, 0.021263668277242687, 0.08602396250353195, 0.029995358527230565, 0.018621193958097138, 0.010823202483152272, 0.061278992652660236, 0.061962981926626526, 0.12010466030915268, 0.18707694980548695, 0.24398633278906345, 0.12079261636245064, 0.09928067185683176, 0.11827085050754249, 0.09755385748576373, 0.11508327428600751, 0.1770862319972366, 0.13767424214165658, 0.14799343451159075, 0.1326245951349847, 0.16949477372691035, 0.09260975130018778, 0.17436943715438247, 0.11570431088330224, 0.10707713357987814, 3.268439741805196, 35.66131442785263, 61.24418266117573, 54.82568867504597, 38.52616690099239, 41.58374883234501, 58.82330596446991, 53.33118326961994, 57.73231230676174, 11.494825892150402, 0.17762987001333386, 0.5603055842220783, 3.8178050005808473, 7.463876316323876, 9.72246989607811, 6.052714688703418, 4.1163210198283195, 25.293460562825203, 54.03844691812992, 55.5945698171854, 54.87929239869118, 54.515351727604866, 51.92158430814743, 48.27335447072983, 43.171603828668594, 42.60015249252319, 39.014011323451996, 41.1470952630043, 37.37954802811146, 38.81583675742149, 38.61727461218834, 40.037725791335106, 38.138568699359894, 40.869398564100266, 41.186252161860466, 39.41543698310852, 40.0798237323761, 39.79996494948864, 38.645921275019646, 40.984836369752884, 39.6225106716156, 38.99428278207779, 39.508987963199615, 38.88989478349686, 41.41098730266094, 40.098017156124115, 41.81915380060673, 44.391570165753365, 43.264379650354385, 45.693737491965294, 43.89747507870197, 44.63245823979378, 41.2330162525177, 39.045078456401825, 37.949384450912476, 38.527318239212036, 40.122567638754845, 39.49560508131981, 39.21786278486252, 39.55689959228039, 39.7405019402504, 43.03047180175781, 42.93423056602478, 47.492598965764046, 49.92060787975788, 50.227912589907646, 53.382070139050484, 51.94131284952164, 51.81448705494404, 51.44133947789669, 53.90452690422535, 50.90179122984409, 45.83766236901283, 54.004681929945946, 53.39950740337372, 50.18757775425911, 46.51371829211712, 47.85566948354244, 52.247599214315414, 55.13577103614807, 52.98813007771969, 53.70120361447334, 48.50491784512997, 40.85805997252464, 38.67187388241291, 40.174826234579086, 39.0114426612854, 40.862357541918755, 40.815787240862846, 40.94533748924732, 48.089440539479256, 53.611270040273666, 54.41958926618099, 55.71837477385998, 51.39182813465595, 48.7994210422039, 46.27547487616539, 47.24445328116417, 50.35252310335636, 53.50315444171429, 54.108157977461815, 53.81986744701862, 54.278495237231255, 54.20496538281441, 52.25835643708706, 54.99769784510136, 51.230986565351486, 54.73933070898056, 52.66531080007553, 54.82154309749603, 50.608462169766426, 47.064293548464775, 43.94203528761864, 41.4139511436224, 40.326932072639465, 41.55170515179634, 43.37730959057808, 43.21788914501667, 50.54250530898571, 52.27583169937134, 54.35033418238163, 57.99101002514362, 53.43595504760742, 54.53388333320618, 53.5934641957283, 61.294902339577675, 56.05844512581825, 61.79763816297054, 51.65671572089195, 24.146275520324707, 2.665725820697844, 6.132432986050844, 15.611673183739185, 18.440490290522575, 2.33215288259089, 0.2361853959155269, 4.796137316152453, 48.103435188531876, 63.28931272029877, 56.055686473846436, 36.755701303482056, 42.47965335845947, 59.04820829629898, 60.32725006341934, 19.49575826525688, 0.2858901576837525, 0.1378122073947452, 0.11229471376282163, 0.15598894766299054, 0.1277532713720575, 0.12289565507671796, 0.19741917843930423, 0.0917897597537376, 0.19509463832946494, 0.15213681530440226, 0.2096533344592899, 0.1517998951021582, 0.17113843787228689, 0.14259831776143983], [0.03591848551877774, 0.00818742604678846, 0.026420236499689054, 0.013007227134949062, 0.017433852299291175, 0.11350811037118547, 0.029694337863475084, 0.03841903337161057, 0.030657179850095417, 0.015564465793431737, 0.11967134254518896, 0.014702401895192452, 0.020707035255327355, 0.02534719300456345, 0.05824292959005106, 0.051953625079477206, 0.07025620390777476, 0.22532412403961644, 22.565594539046288, 48.42189610004425, 44.98295523226261, 26.94501344114542, 29.084716625511646, 45.07673040032387, 38.71372103691101, 48.761966452002525, 13.247533142566681, 0.4266450251452625, 0.13999241462443024, 0.30950182350352407, 2.4284230917692184, 2.007754077203572, 3.2282799342647195, 2.6313875382766128, 17.458676174283028, 46.38186156749725, 52.21531234681606, 50.060634166002274, 48.27941134572029, 45.42254224419594, 41.33193254470825, 38.26836213469505, 36.78421497344971, 35.98351813852787, 38.06057408452034, 35.53064323961735, 35.051055774092674, 34.072087705135345, 33.34566928446293, 34.94739733636379, 36.377063021063805, 35.51191404461861, 36.451805010437965, 36.41875058412552, 34.42982330918312, 36.75175331532955, 35.804927721619606, 35.02107158303261, 33.91422517597675, 36.320278868079185, 36.54825523495674, 35.41418708860874, 35.937593802809715, 37.299778908491135, 35.24532034993172, 37.96784766018391, 37.21027851104736, 37.871838212013245, 38.246881887316704, 37.29381702840328, 34.987325593829155, 36.22207313776016, 35.830051973462105, 36.304224729537964, 35.73925964534283, 34.86268848180771, 35.78290410339832, 36.37944549322128, 37.23951794207096, 39.760249480605125, 40.434705689549446, 43.78436654806137, 45.47034367918968, 47.839885130524635, 48.144294396042824, 51.13107472658157, 49.308677315711975, 48.574571907520294, 46.019045636057854, 42.458655685186386, 55.14867514371872, 48.6716452986002, 49.01399552822113, 43.75456854701042, 45.93280166387558, 49.10714752972126, 49.360282346606255, 49.88712787628174, 47.78606481850147, 44.67452198266983, 35.095843970775604, 34.37237039208412, 35.60548782348633, 36.01974159479141, 35.635908991098404, 36.18853233754635, 37.82539710402489, 44.625895991921425, 48.85382652282715, 50.50818555057049, 48.672998026013374, 46.32810965180397, 43.47795099020004, 40.10268710553646, 40.217376351356506, 41.20589330792427, 43.62732857465744, 45.94479762017727, 45.45705959200859, 44.8315941542387, 47.5047355145216, 46.873794570565224, 48.38380314409733, 47.124987691640854, 49.66235473752022, 49.74087372422218, 48.934131413698196, 49.11429114639759, 46.703552305698395, 45.12570597231388, 45.047950744628906, 39.82543498277664, 39.97509375214577, 39.11709979176521, 40.448810532689095, 41.2740920484066, 44.52502280473709, 47.10191152989864, 50.73562614619732, 55.037527307868004, 53.38698707520962, 46.818838119506836, 47.831574976444244, 55.12263514101505, 57.83487640321255, 39.176236018538475, 6.518347403034568, 2.639627158641815, 2.8609598195180297, 2.747944383881986, 8.163826782256365, 1.0259295115247369, 0.03536241652909666, 3.09155757073313, 35.949452966451645, 43.64691272377968, 47.44184888899326, 32.02067658305168, 32.74377778172493, 44.52909618616104, 42.001863196492195, 6.234918236732483, 0.025964077285607345, 0.031828999490244314, 0.05947799691057298, 0.06088180634833407, 0.04914720848319121, 0.024498780912836082, 0.07699401423451491, 0.07334028763580136, 0.02126641422364628, 0.026578798206173815, 0.01333443262410583, 0.02476421188475797, 0.04655448588891886, 0.04615745914634317, 0.03923814918380231, 0.07153057536925189, 0.04214500433590729, 0.018108314252458513, 0.11356072864145972, 0.04133868314966094, 0.02341049741517054, 0.020949025492882356, 0.014547044411301613, 0.04939713042404037, 0.0711644219700247, 0.11386300539015792, 0.042214602945023216, 0.03136788829579018, 0.019377078788238578, 0.1107005582889542, 0.04954059870215133, 0.6724984827451408, 27.83787813037634, 55.22312834858894, 51.95160269737244, 33.32091361284256, 31.681014709174633, 52.544017508625984, 43.0649321526289, 54.409155026078224, 12.792533207684755, 0.10114705451996997, 0.06271613936405629, 0.8448274887632579, 3.9565783040598035, 7.83635750412941, 6.278007449582219, 2.478251955471933, 18.45128171145916, 49.17342357337475, 52.74644784629345, 52.07921124994755, 49.66119199991226, 47.71040327847004, 43.585887998342514, 40.87907284498215, 39.29648816585541, 38.283918499946594, 38.888135477900505, 37.86996491253376, 35.482036247849464, 34.52199496328831, 36.56170651316643, 37.549976482987404, 38.026201128959656, 36.73804745078087, 37.92398281395435, 39.16783466935158, 37.049889117479324, 39.09573353827, 37.09304340183735, 37.88350358605385, 36.42409309744835, 37.207561656832695, 39.06868278980255, 37.18000553548336, 37.69009776413441, 39.45501945912838, 37.925871312618256, 39.09123457968235, 39.18624088168144, 40.56476891040802, 41.86334542930126, 39.42301757633686, 37.461156249046326, 38.811026215553284, 36.27831771969795, 39.00721728801727, 37.73274287581444, 37.25126691162586, 36.27236723899841, 38.04166629910469, 39.493971168994904, 40.96159681677818, 42.83649601042271, 45.86611904203892, 48.07042635977268, 49.85055483877659, 49.593046456575394, 51.09855607151985, 51.20529994368553, 49.46734540164471, 47.356003895401955, 44.87586937844753, 56.55113808810711, 50.280931144952774, 50.91254085302353, 44.935864359140396, 47.69005537033081, 48.50989177823067, 51.13458953797817, 50.30806548893452, 50.69182209670544, 46.87710799276829, 36.95318430662155, 37.375121265649796, 38.16346876323223, 38.72101664543152, 38.57780233025551, 36.756206676363945, 40.210437923669815, 46.59137472510338, 51.06974221765995, 51.77471838891506, 51.24744348227978, 48.50373610854149, 44.419320076704025, 42.39389955997467, 42.82530181109905, 43.13099920749664, 44.9074000865221, 48.60378473997116, 48.23029138147831, 47.38224908709526, 50.137633234262466, 49.601520001888275, 50.79472437500954, 49.103214740753174, 51.12312935292721, 52.89812050759792, 51.7508290708065, 51.098996847867966, 48.90098959207535, 46.2489029020071, 46.41633331775665, 42.764634266495705, 42.073329761624336, 40.56186966598034, 42.511427253484726, 43.95278871059418, 48.68341326713562, 49.325708001852036, 53.61169561743736, 55.63997358083725, 53.87149527668953, 48.102337047457695, 49.73636716604233, 57.542322501540184, 59.78344984352589, 41.98681220412254, 9.645242840051651, 2.762529426254332, 5.558327017351985, 7.261979850009084, 5.090924073010683, 0.32231236109510064, 0.04505150696786586, 3.1473675509914756, 40.34138649702072, 50.57221211493015, 51.25024393200874, 36.05898968875408, 36.40950947999954, 49.63210076093674, 49.96755436062813, 8.946527782827616, 0.07273928160429932, 0.019740970492421184, 0.0456593518902082, 0.04952514347678516, 0.09056510476511903, 0.020924083764839452, 0.04217539157252759, 0.03162694236380048, 0.013873559310013661, 0.03728180337930098, 0.05754763740696944, 0.03494435361062642, 0.0377212512830738, 0.08012347287149169, 0.11380525887943804, 0.15022084233351052, 0.11998015019344166, 0.07630702297319658, 0.23428091139066964, 0.15704958059359342, 0.19216802349546924, 0.12711972958641127, 0.1525633572600782, 0.1128290749329608, 0.26625589875038713, 0.14761836791876704, 0.15063738013850525, 0.09210119460476562, 0.1802962730289437, 0.1816147132194601, 0.11924062971957028, 0.7566845684777945, 31.761486791074276, 61.91811449825764, 58.95035594701767, 39.38925638794899, 37.542414888739586, 56.78639866411686, 49.77928206324577, 59.16923560202122, 17.890629395842552, 0.6302884477190673, 0.16751945862779394, 1.9336196989752352, 10.50586910918355, 8.534086514264345, 8.20773247629404, 4.560229349881411, 19.88045532256365, 50.79826578497887, 54.24509882926941, 54.70520094037056, 53.17414149641991, 50.3932037204504, 45.88598057627678, 43.14351573586464, 41.531573832035065, 40.302191600203514, 42.140662148594856, 40.0511808693409, 37.926315888762474, 36.753941997885704, 39.0496002137661, 40.27394391596317, 41.84273153543472, 39.45797190070152, 41.01848356425762, 41.194482520222664, 38.97143080830574, 41.67891852557659, 39.106760546565056, 40.02799071371555, 38.00314776599407, 39.34737503528595, 40.98638288676739, 38.68000164628029, 40.28867572546005, 41.087791845202446, 39.87739339470863, 40.65379433333874, 41.00942485034466, 41.85387633740902, 43.66001822054386, 41.94901943206787, 37.978703677654266, 40.36943279206753, 37.747550681233406, 41.07084855437279, 39.78187792003155, 38.63888405263424, 38.67405876517296, 40.37267781794071, 41.70492812991142, 42.46359921991825, 45.18467880785465, 48.29943247139454, 49.61323097348213, 50.86793504655361, 52.929043248295784, 54.234805181622505, 53.2462540268898, 50.49734853208065, 47.91475631296635, 48.835883885622025, 57.18070350587368, 51.68924577534199, 52.80898109078407, 47.822759449481964, 49.23069030046463, 51.66682317852974, 51.50370933115482, 52.75123178958893, 51.55020743608475, 48.418263494968414, 39.00905258953571, 38.8450837880373, 39.684831127524376, 40.12217625975609, 39.83923204243183, 39.93163548409939, 41.830454394221306, 49.93395276367664, 53.52187983691692, 53.36648337543011, 53.948840126395226, 50.80449365079403, 46.60390645265579, 44.03039574623108, 43.51599454879761, 44.60583306849003, 46.79561756551266, 51.689963936805725, 50.227346420288086, 49.131762608885765, 53.23365390300751, 51.46546058356762, 54.12515826523304, 50.978087335824966, 53.07035766541958, 54.96271692216396, 53.52044351398945, 53.53946149349213, 52.44874522089958, 48.36879774928093, 48.69654916226864, 44.66192565858364, 43.76651890575886, 43.37095633149147, 44.63769055902958, 46.313742622733116, 49.62244547903538, 51.3326995074749, 55.56723028421402, 59.20412912964821, 57.519599720835686, 52.092525735497475, 51.77853338420391, 61.321082934737206, 60.32519057393074, 43.74709814786911, 8.9115060120821, 5.3790635615587234, 8.886144272983074, 13.011590503156185, 17.65360951423645, 2.7770463097840548, 0.19988055573776364, 4.832771150395274, 47.859419882297516, 58.301837146282196, 63.23833845555782, 44.4727224111557, 45.66482864320278, 58.58968310058117, 56.91376402974129, 11.803477630019188, 0.1505180131061934, 0.057877236322383396, 0.1482766232220456, 0.1983857070445083, 0.22837874450488016, 0.11509032468893565, 0.11854110358399339, 0.15940405894070864, 0.07380493145319633, 0.12998694292036816, 0.13823839311953634, 0.13002164574572816, 0.12864267599070445, 0.1493120231316425], [0.049906214044312946, 0.033535928014316596, 0.03746237533050589, 0.02859144333342556, 0.060815669858129695, 0.015151971765590133, 0.05932255779043771, 0.029372735589277, 0.05734242244216148, 0.020374551240820438, 0.006718107233609771, 0.08287813951028511, 0.06520015958813019, 0.04499485883570742, 0.05098532645206433, 0.011420017235650448, 0.04589319520164281, 0.06309847900411114, 12.242860402911901, 45.44243797659874, 43.03403601050377, 23.54912046343088, 26.153225228190422, 44.5621620118618, 41.89083695411682, 51.176824271678925, 33.149706199765205, 2.183100893162191, 0.27606462710537016, 0.44347292685415596, 2.658837977796793, 10.925095863640308, 5.914496630430222, 1.3878716086037457, 14.196294732391834, 47.07392983138561, 55.55363081395626, 49.993218183517456, 47.42871679365635, 45.28181679546833, 40.23510240018368, 40.080473497509956, 38.01382519304752, 39.19561877846718, 36.00196994841099, 35.69034107029438, 33.838559836149216, 35.693209916353226, 35.89154027402401, 35.68293906748295, 35.21975912153721, 35.39301462471485, 35.551169738173485, 32.74035796523094, 34.6381851285696, 35.668503642082214, 35.47273434698582, 34.20560114085674, 34.784230291843414, 36.34718522429466, 35.682661682367325, 36.18007779121399, 34.559320360422134, 37.32337944209576, 37.28356137871742, 37.11503282189369, 37.28582985699177, 35.680921375751495, 37.79369160532951, 37.37827129662037, 36.095342338085175, 36.60419583320618, 35.464629381895065, 36.621766090393066, 35.87871216237545, 35.82188241183758, 36.19479440152645, 34.64609630405903, 38.787573873996735, 41.90631352365017, 43.74495506286621, 44.65463005006313, 44.72424991428852, 44.81776289641857, 48.67595426738262, 49.64826129376888, 48.55343744158745, 50.60061939060688, 46.162423342466354, 44.77940395474434, 52.20346458256245, 48.849414959549904, 48.08505557477474, 44.37091827392578, 45.345748364925385, 48.77661466598511, 50.644871816039085, 48.16748835146427, 49.95459705591202, 44.81869004666805, 37.19712361693382, 35.4024875164032, 35.73095329105854, 37.292669489979744, 36.36300377547741, 37.17109501361847, 39.217209219932556, 44.930597841739655, 49.26782950758934, 50.908722057938576, 48.08151036500931, 44.87737409770489, 37.801557183265686, 37.85136491060257, 36.5116062015295, 37.757376953959465, 37.05214239656925, 37.52536900341511, 39.26375672221184, 37.82883211970329, 37.99694649875164, 41.885874420404434, 42.664528638124466, 47.29049541056156, 48.869037106633186, 48.97858522832394, 48.31390969455242, 49.528237134218216, 49.086210653185844, 47.420334443449974, 46.96679838001728, 45.48910327255726, 42.61951245367527, 42.21553333103657, 41.43589876592159, 40.1953337341547, 40.934287682175636, 44.49882701039314, 48.085462152957916, 51.036072224378586, 55.07835611701012, 55.49553573131561, 54.96855340898037, 53.34499552845955, 52.03535780310631, 27.861951738595963, 3.473271788097918, 1.3758165179751813, 4.890457279980183, 3.023445988073945, 1.8458628142252564, 0.7061246002558619, 0.1353533088695258, 7.310836678370833, 40.35025142133236, 45.497485622763634, 37.15686097741127, 21.263765394687653, 35.56343927979469, 50.84916025400162, 31.33641880005598, 4.451251197606325, 0.07215104793431237, 0.046566905730287544, 0.011679204890242545, 0.024330248452315573, 0.057689524910529144, 0.05327123777533416, 0.05575248978857417, 0.05210561321291607, 0.019104079765384085, 0.05251295951893553, 0.03344450284203049, 0.04508494814217556, 0.055391657588188536, 0.0357668907236075, 0.04522754439676646, 0.013576958135672612, 0.011618666048889281, 0.020913691841997206, 0.005535700856853509, 0.0621406186837703, 0.024145008392224554, 0.018385537950962316, 0.023210516446852125, 0.003740566689884872, 0.02845001596142538, 0.021727915045630652, 0.04044450652145315, 0.04927018235321157, 0.01666247142566135, 0.014284261051216163, 0.11374729714589193, 0.07588163876789622, 17.24006250500679, 53.66701304912567, 49.62295465171337, 27.669913843274117, 28.308745063841343, 46.96376994252205, 47.47966066002846, 54.53257620334625, 32.42717117071152, 2.2052522795274854, 0.3070962260244414, 0.7494788488838822, 3.870893851853907, 8.086314741522074, 8.636341877281666, 3.7257513776421547, 14.770309031009674, 49.79454964399338, 55.76218642294407, 53.053855150938034, 49.409512504935265, 47.02165603637695, 42.65755221247673, 41.717372462153435, 39.54390808939934, 41.010553389787674, 36.69187992811203, 38.082023933529854, 35.890362337231636, 38.20695362985134, 39.08675841987133, 39.31598871946335, 37.489358335733414, 37.1866437792778, 36.53231509029865, 35.62566854059696, 36.40088394284248, 38.373050317168236, 35.839509665966034, 36.83335393667221, 35.46116016805172, 38.473114147782326, 37.96733468770981, 37.318610697984695, 36.48991696536541, 38.295804262161255, 38.569104596972466, 40.093582794070244, 39.193711280822754, 38.9592220634222, 39.18143033981323, 40.33042408525944, 36.96314737200737, 37.72733576595783, 36.311505138874054, 38.245741948485374, 37.6962648332119, 36.23704053461552, 36.88056640326977, 36.905876845121384, 39.7065469622612, 42.46739141643047, 45.118873938918114, 46.61283977329731, 45.7159510999918, 46.87911048531532, 50.69236546754837, 51.05362348258495, 51.038010120391846, 51.60557806491852, 47.576369270682335, 47.616080939769745, 54.88132908940315, 52.00022108852863, 50.297931432724, 44.847857281565666, 48.14640708267689, 50.402167439460754, 51.497314274311066, 51.75011470913887, 51.88259080052376, 47.601744309067726, 39.38497021794319, 36.267419904470444, 37.44194447994232, 38.75711850821972, 37.24899463355541, 38.35901387035847, 39.257502257823944, 46.649219021201134, 51.582121923565865, 51.96873217821121, 49.893135353922844, 47.05072067677975, 40.11766970157623, 38.77944990992546, 39.254766404628754, 39.321422427892685, 39.37944911420345, 39.95893321931362, 40.99175199866295, 41.28476947546005, 41.33913695812225, 43.34425136446953, 44.59539122879505, 49.122973680496216, 50.3767392039299, 51.472471207380295, 50.43182484805584, 52.83272221684456, 51.414227932691574, 50.86622513830662, 49.047692120075226, 47.34632581472397, 45.51055312156677, 45.17766818404198, 44.40139263868332, 43.400716334581375, 42.82664693892002, 47.905123829841614, 51.843323707580566, 53.19007784128189, 56.30336858332157, 55.612622648477554, 56.074655055999756, 54.62121404707432, 53.84030655026436, 30.796218886971474, 5.012022731825709, 2.759128608740866, 4.955457067117095, 6.60003399476409, 2.5916977180168033, 0.6417712534312159, 0.12386146379867569, 7.819643625989556, 43.43073472380638, 51.08695529401302, 45.36429136991501, 28.306738771498203, 41.67953409254551, 54.9925035238266, 38.756609335541725, 5.399696454405785, 0.12951124110259116, 0.06690331429126672, 0.005132614478497999, 0.07305795981665142, 0.060260461759753525, 0.02449416475428734, 0.1209752589056734, 0.046356451202882454, 0.03033734388736775, 0.038068457652116194, 0.024350141720788088, 0.03939921749406494, 0.008669903672853252, 0.03228918671084102, 0.14058209548238665, 0.1226450243848376, 0.17515051789814606, 0.16648803662974387, 0.21795162901980802, 0.1462298838305287, 0.09687553450930864, 0.06396456534275785, 0.16468559741042554, 0.09547856767312624, 0.11589975547394715, 0.21297336177667603, 0.12689132621744648, 0.11462716516689397, 0.2768411807483062, 0.07287027809070423, 0.1987328688846901, 0.3657277923775837, 19.592856355011463, 60.46472668647766, 54.92608688771725, 33.794003427028656, 36.16847701370716, 54.39883477985859, 53.53313863277435, 59.87863853573799, 39.58145387470722, 3.2411586306989193, 0.7367699558380991, 2.4717854149639606, 10.901998803019524, 20.561426281929016, 10.74919855222106, 3.1806492526084185, 16.76117990165949, 51.23647727072239, 59.48920503258705, 54.36611853539944, 53.266810923814774, 48.796445801854134, 44.79383558034897, 43.41884136199951, 41.930989399552345, 41.93071201443672, 39.28500898182392, 39.13437746465206, 39.01533745229244, 40.09109012782574, 41.938672587275505, 40.99858023226261, 39.31460179388523, 38.93165074288845, 39.62084636092186, 36.41300529241562, 37.91121929883957, 41.6540564596653, 38.04086834192276, 38.3207993209362, 37.54530653357506, 40.54518096148968, 40.42290732264519, 38.762464821338654, 37.585143595933914, 42.286266535520554, 40.792821273207664, 41.27534978091717, 41.32269524037838, 40.49227640032768, 42.49872833490372, 41.85341276228428, 39.85989913344383, 39.661352187395096, 37.30931639671326, 40.795530527830124, 39.36006635427475, 37.85042256116867, 39.97643128037453, 38.62583175301552, 41.96620590984821, 46.24479532241821, 47.290248423814774, 48.4302594512701, 47.249962985515594, 46.92120082676411, 53.29365648329258, 52.121286392211914, 52.999651059508324, 55.41374891996384, 47.83824361860752, 49.67161864042282, 55.46479918062687, 52.7241088449955, 53.878840282559395, 48.15048426389694, 50.01805745065212, 54.41814534366131, 55.158585011959076, 52.611976861953735, 54.3475641310215, 49.44205775856972, 41.746254712343216, 39.61583063006401, 37.83564515411854, 42.425570860505104, 39.743287190794945, 40.68520724773407, 42.41388648748398, 49.23208862543106, 54.37015391886234, 54.949622824788094, 53.55519264936447, 48.869713470339775, 42.16086946427822, 41.645837500691414, 39.58748035132885, 41.53566241264343, 40.20791865885258, 42.338422536849976, 43.31296764314175, 42.609450593590736, 42.01441012322903, 46.665675938129425, 46.837419122457504, 52.0307182520628, 53.74453268945217, 54.59699034690857, 52.82047927379608, 54.23072040081024, 54.85861770808697, 53.50204490125179, 52.39983044564724, 49.71511870622635, 47.10189253091812, 47.761806920170784, 46.362972781062126, 45.851136445999146, 45.35220801830292, 49.40974809229374, 54.06880348920822, 55.48648461699486, 59.93068814277649, 57.02956661581993, 56.604574620723724, 55.16406811773777, 55.14161132276058, 33.47162872552872, 6.4825523737818, 4.443094460293651, 12.834579851478338, 13.882191237062216, 7.041763141751289, 1.5807198104448617, 0.4612146795261651, 8.938010539859533, 52.015203684568405, 56.22746005654335, 51.786212772130966, 33.31893391907215, 48.30024942755699, 63.92093762755394, 45.00482305884361, 6.91162914969027, 0.1442446981673129, 0.21979890880174935, 0.1054374992963858, 0.1930449006613344, 0.1606067389366217, 0.18158237042371184, 0.14973654644563794, 0.13367848936468363, 0.1276379861519672, 0.12283362637390383, 0.1395851981942542, 0.128240238991566, 0.0950459401065018, 0.10299103174475022], [0.025064668516279198, 0.0650806218618527, 0.11032103138859384, 0.05939762973866891, 0.04847732743655797, 0.02138081814337056, 0.06673860203591175, 0.03600793286750559, 0.05144250055309385, 0.10639131491188891, 0.019513439146976452, 0.04590556309267413, 0.01632580540899653, 0.07922361881355755, 0.03660433016193565, 0.02703623762499774, 0.02275816073961323, 0.09824390639550984, 8.178081717342138, 40.95318786799908, 46.56795658171177, 35.10747514665127, 29.938830994069576, 36.19121879339218, 38.52230630815029, 48.2428041100502, 42.820244282484055, 4.620057614520192, 0.12149512593168765, 0.1415256768814288, 1.9638575264252722, 4.2935439851135015, 5.181624256074429, 1.6272935550659895, 9.322636350989342, 43.396008387207985, 51.436129957437515, 52.400522008538246, 46.87764756381512, 43.79630550742149, 40.786768198013306, 41.0153791308403, 37.51870036125183, 36.251050382852554, 36.60102680325508, 35.20901329815388, 35.46330325305462, 35.256328359246254, 35.11985868215561, 35.76814189553261, 34.93627533316612, 34.486132487654686, 33.93156744539738, 33.86909119784832, 33.845205679535866, 34.45986449718475, 34.64783661067486, 35.18379785120487, 37.138025388121605, 36.8324039876461, 36.54730908572674, 36.49439312517643, 36.137018501758575, 35.09419105947018, 34.9858208745718, 36.33702836930752, 36.509995087981224, 35.1375999301672, 36.84105232357979, 36.52517527341843, 34.76674363017082, 36.00220933556557, 34.95727680623531, 37.011302188038826, 37.194638550281525, 33.43203105032444, 36.11173465847969, 44.38487112522125, 45.8527285605669, 49.705794006586075, 47.44336120784283, 47.66023077070713, 50.73580853641033, 49.69531796872616, 46.66586212813854, 49.35049407184124, 49.79689411818981, 47.8863338381052, 47.68476605415344, 41.99984550476074, 51.680711433291435, 49.746030047535896, 45.11218249797821, 44.331852570176125, 47.01325088739395, 49.430487379431725, 51.69545844197273, 51.27546697854996, 48.793120980262756, 47.674031630158424, 36.617426723241806, 33.64400267601013, 35.82905262708664, 36.42992578446865, 35.879779905080795, 36.26037888228893, 39.88016724586487, 45.372555926442146, 48.46430562436581, 48.665561825037, 47.1839415282011, 41.45170971751213, 36.12675525248051, 39.56097677350044, 36.69900834560394, 36.240768134593964, 36.391479447484016, 36.74180164933205, 36.973896995186806, 37.739267125725746, 36.37005999684334, 36.01372271776199, 37.11781047284603, 40.0617291033268, 43.000100031495094, 42.902946844697, 46.309179067611694, 47.85133011639118, 48.44906844198704, 48.11731584370136, 47.21178263425827, 46.58086448907852, 45.31013287603855, 43.35538476705551, 43.588376864790916, 40.733970031142235, 40.76084218919277, 43.22051860392094, 46.05461932718754, 50.91849893331528, 52.85935498774052, 55.7919692248106, 50.91813035309315, 52.23458491265774, 40.82790859043598, 17.370427809655666, 2.7420974476262927, 1.9718658342026174, 2.4931509559974074, 3.522336892783642, 1.3529816432856023, 0.4669433174422011, 0.02567038533015875, 12.0326167345047, 39.97759401798248, 45.77080115675926, 40.88355280458927, 27.45470479130745, 35.89175686240196, 52.18845538794994, 22.12386444211006, 1.3360657822340727, 0.03472048105322756, 0.06815411514253356, 0.05082083313027397, 0.019215199681639206, 0.13570572511525825, 0.011912203081010375, 0.0346711393649457, 0.03257400443544611, 0.027201458251511212, 0.17852133780252188, 0.022558211312571075, 0.07670096980291419, 0.025930658375727944, 0.06409717971109785, 0.04512299063208047, 0.009771540262590861, 0.04705970663053449, 0.023285926072276197, 0.03679816429212224, 0.02293212201038841, 0.050164885906269774, 0.062172356629162095, 0.019314456367283128, 0.0555386659107171, 0.015323712159442948, 0.04178667317319196, 0.023355361408903264, 0.10530397208640352, 0.05331486863724422, 0.01612812509847572, 0.037940377806080505, 0.04324985813582316, 10.112545564770699, 47.089136615395546, 52.344756200909615, 39.140297546982765, 30.602615475654602, 42.20872789621353, 46.77040211856365, 56.157798394560814, 46.26085326075554, 5.194629533216357, 0.0657266762573272, 0.5247872869949788, 3.324060207232833, 7.387658581137657, 9.259828571230173, 3.8683042908087373, 9.995210710912943, 46.39507345855236, 53.96281577646732, 54.38475273549557, 48.45279984176159, 47.04552635550499, 42.374456003308296, 41.656112149357796, 39.38954517245293, 39.6670176833868, 39.37163673341274, 38.75948578119278, 38.63921083509922, 37.85408176481724, 37.39159718155861, 37.50418893992901, 36.969728618860245, 37.13877014815807, 35.720564648509026, 35.90698264539242, 35.467631220817566, 36.09162613749504, 37.38930970430374, 37.48516336083412, 38.58861654996872, 39.27591226994991, 37.907012924551964, 38.06446887552738, 36.75637386739254, 37.23378024995327, 37.526892721652985, 38.720165491104126, 37.617130279541016, 37.07104258239269, 38.93877916038036, 37.8643374145031, 37.22184509038925, 37.9862804710865, 37.31608383357525, 38.257369324564934, 38.012822046875954, 36.71727016568184, 37.45971992611885, 46.64463646709919, 47.290677800774574, 49.61286619305611, 48.91243077814579, 50.01884400844574, 51.97294235229492, 51.34882964193821, 47.54750981926918, 51.639301255345345, 51.73369199037552, 51.5580540150404, 49.148569107055664, 44.89200331270695, 52.5815898925066, 52.663916274905205, 47.775801569223404, 46.502482295036316, 48.143010064959526, 51.73374518752098, 52.51520365476608, 52.469172924757004, 49.19898480176926, 49.40188251435757, 39.86230060458183, 37.144439443945885, 37.59303577244282, 37.930913642048836, 37.83124879002571, 39.15725603699684, 41.22895807027817, 46.868581250309944, 50.214001536369324, 51.84654973447323, 51.00073792040348, 44.03223104774952, 38.029845133423805, 40.34886449575424, 37.97948643565178, 37.530270740389824, 38.2108636200428, 38.06172542273998, 38.031277656555176, 38.58775779604912, 37.77604915201664, 38.214006051421165, 38.406192138791084, 42.081921100616455, 45.84358625113964, 46.34898953139782, 48.11995290219784, 49.640057533979416, 51.60587824881077, 50.06473034620285, 48.47258538007736, 47.741990983486176, 46.461372300982475, 44.5499836653471, 45.807077810168266, 43.28365221619606, 43.019737377762794, 44.32344742119312, 49.13761809468269, 53.431482687592506, 54.546692445874214, 54.62839566171169, 51.707131415605545, 53.61058607697487, 44.6901885420084, 21.534932143986225, 3.3074076008051634, 2.5969794346019626, 6.7235582415014505, 5.542355999350548, 2.3890809528529644, 1.0269362200051546, 0.02260465862491401, 12.148678656667471, 45.63130684196949, 49.564509987831116, 43.28510753810406, 29.86507125198841, 39.15569432079792, 60.28960168361664, 28.406888097524643, 2.2578697185963392, 0.043257550496491604, 0.045055061855237, 0.02525752115616342, 0.014258094779506791, 0.10214195543085225, 0.060524621803779155, 0.019507565048115794, 0.005792058609586093, 0.041442086585448124, 0.07006857413216494, 0.019749315943045076, 0.04406589032441843, 0.055849711134214886, 0.024044898236752488, 0.08412841343670152, 0.12643730995478109, 0.19890887662768364, 0.12743943196255714, 0.1646037385216914, 0.07095727371051908, 0.19968204607721418, 0.2013698680093512, 0.15057523269206285, 0.18073651503073052, 0.11020559773896821, 0.15530937787843868, 0.15136741596506909, 0.23320972512010485, 0.10272337618516758, 0.14450955583015457, 0.18120059481589124, 0.20098718698136508, 13.219730034470558, 54.623862504959106, 59.24110874533653, 48.1518217921257, 39.3174060434103, 48.031239062547684, 52.924886271357536, 60.007105842232704, 52.009465992450714, 6.401594867929816, 0.24016182316699997, 0.53851209115237, 5.720148459076881, 12.425385508686304, 14.814293570816517, 5.353938834741712, 11.471588239073753, 47.76371821761131, 54.57329101860523, 58.98387774825096, 50.85310444235802, 49.077060744166374, 44.751369059085846, 43.34391698241234, 42.272461876273155, 41.55092999339104, 41.74045242369175, 40.149656385183334, 39.76745009422302, 40.63605308532715, 39.77649360895157, 40.23080863058567, 40.69988586008549, 39.20332856476307, 37.66827553510666, 37.386353462934494, 36.65418595075607, 39.59109015762806, 39.770334139466286, 38.882663771510124, 40.79173073172569, 41.083581671118736, 39.8591847717762, 40.3082674741745, 39.25366826355457, 39.30732138454914, 38.211209401488304, 40.89957654476166, 41.02764867246151, 39.571407213807106, 41.50383532047272, 40.78447312116623, 37.78748653829098, 38.97646553814411, 38.63286517560482, 40.33171981573105, 40.55613197386265, 37.496228367090225, 38.989742025732994, 50.01222476363182, 50.763611644506454, 52.533856853842735, 51.407669484615326, 52.55245305597782, 54.02489684522152, 52.325951009988785, 49.56897474825382, 52.62029081583023, 52.036205157637596, 51.93911276757717, 49.99992102384567, 47.12410233914852, 53.66162493824959, 54.87434886395931, 50.15348978340626, 47.20123440027237, 50.18831491470337, 52.635258212685585, 55.866346433758736, 55.57665757834911, 51.30167417228222, 50.88269345462322, 41.20225690305233, 38.46043802797794, 39.11618024110794, 39.34438839554787, 38.870075047016144, 40.9503760188818, 43.415987715125084, 49.28484499454498, 52.78927154839039, 54.07576471567154, 51.66116528213024, 46.318568363785744, 38.84406924247742, 42.29163944721222, 39.82432544231415, 39.79031726717949, 40.833657681941986, 39.94647368788719, 41.17719724774361, 42.319932729005814, 38.78038085997105, 39.21856954693794, 40.22064417600632, 45.36699682474136, 47.37198583781719, 47.62275718152523, 51.17239370942116, 51.676672250032425, 53.424981236457825, 51.53776690363884, 51.08972154557705, 52.17608705163002, 49.031227603554726, 47.5287464261055, 47.91851431131363, 45.254602655768394, 44.75885085761547, 46.865108236670494, 51.72655217349529, 55.25169141590595, 57.394651025533676, 57.36461743712425, 50.89533917605877, 53.75668443739414, 44.859397262334824, 22.0363437384367, 3.8356937281787395, 5.311261424794793, 11.19241151958704, 14.52189166098833, 6.563845686614513, 2.392954844981432, 0.2347348237526603, 14.169281981885433, 50.38821838796139, 57.39789605140686, 54.6180260181427, 39.392896592617035, 50.43346256017685, 67.5461483001709, 36.177106350660324, 2.8353674802929163, 0.08976264274679124, 0.26592807727865875, 0.149699617177248, 0.0853985249705147, 0.23617781116627157, 0.17818700027419254, 0.18587388389278203, 0.05146502844581846, 0.11215394319151528, 0.3515988145954907, 0.08853251070831902, 0.12193922710139304, 0.1671712429379113, 0.11678017268422991], [0.05190618699998595, 0.049170422862516716, 0.006827312872701441, 0.03679433109937236, 0.03229804053262342, 0.03988909062172752, 0.02530644353100797, 0.0768429426534567, 0.06576895641046576, 0.09103728138143197, 0.02650098773301579, 0.03667574703285936, 0.040015905105974525, 0.040664939224370755, 0.06548158940859139, 0.023358014586847275, 0.02997103649249766, 0.038095230629551224, 2.7783161541447043, 33.95219273865223, 48.88783849775791, 36.178709864616394, 18.62153347581625, 27.977845519781113, 43.81587825715542, 46.45995117723942, 51.04795038700104, 11.121915802359581, 0.04944014159264043, 0.6966884003486484, 4.84360009431839, 5.246393205597997, 8.409423753619194, 6.257660016417503, 8.490196969360113, 41.64978168904781, 55.52438758313656, 51.16045854985714, 48.366856053471565, 42.75464840233326, 40.0537533313036, 39.07873325049877, 38.080241829156876, 37.60008059442043, 35.59070281684399, 37.02424809336662, 35.401446372270584, 35.04545107483864, 35.92130407691002, 35.20057015120983, 33.56123931705952, 35.20046375691891, 34.37219940125942, 34.11085702478886, 33.77324894070625, 36.46321199834347, 34.10723961889744, 36.73041746020317, 34.97325114905834, 36.62577487528324, 37.42209434509277, 36.81641444563866, 36.36660598218441, 37.77072563767433, 37.134483978152275, 35.23816913366318, 35.047206580638885, 36.52640260756016, 38.04562948644161, 36.10988795757294, 34.930119663476944, 35.394868925213814, 35.36431096494198, 35.50521120429039, 35.984061509370804, 36.371652111411095, 42.81795300543308, 51.357067599892616, 51.26361161470413, 49.23468768596649, 50.25935970246792, 47.2792100161314, 47.594847679138184, 53.63030321896076, 55.71739062666893, 50.816820189356804, 49.47131238877773, 48.87527257204056, 44.85195346176624, 43.675988763570786, 51.59746930003166, 50.03661945462227, 46.701538413763046, 43.3033237606287, 45.46423740684986, 49.48964640498161, 49.726871475577354, 49.859290570020676, 50.727794766426086, 50.50793096423149, 41.84360928833485, 34.29357782006264, 35.73101028800011, 36.39719434082508, 36.737245693802834, 36.394686475396156, 37.75525286793709, 40.182722210884094, 47.26306088268757, 47.384148985147476, 46.935974434018135, 40.06786197423935, 38.171634525060654, 38.839342296123505, 37.54565991461277, 37.01564535498619, 36.91438838839531, 36.77986800670624, 36.961479261517525, 36.17043390870094, 36.49166487157345, 34.473638758063316, 35.856395959854126, 35.31775586307049, 36.444687992334366, 38.64025577902794, 39.21530172228813, 43.44487376511097, 46.420999467372894, 45.95213882625103, 46.25474698841572, 45.416511967778206, 44.877860471606255, 43.40450093150139, 42.799227610230446, 39.802465215325356, 37.61243373155594, 40.409030467271805, 45.69848723709583, 49.84587348997593, 53.20248797535896, 55.30613109469414, 52.67208583652973, 50.32687447965145, 37.04353965818882, 9.105466604232788, 1.0782071063295007, 0.6407310592476279, 3.4270118828862906, 2.9603339871391654, 1.30491683492437, 0.6058104580733925, 0.12223909187014215, 13.705079890787601, 42.60278955101967, 38.48606385290623, 31.410416029393673, 30.344056449830532, 43.55949081480503, 46.696066707372665, 17.231476865708828, 0.38797752815298736, 0.06768279941752553, 0.053479521520785056, 0.023731986511847936, 0.06983222236158326, 0.033266094251303, 0.02959459692647215, 0.0020329164271970512, 0.0912716293532867, 0.006405080939657637, 0.004768046956087346, 0.0377503991330741, 0.05757356804679148, 0.10982296866131946, 0.05427196083473973, 0.0644537816697266, 0.06087910493079107, 0.02596788264781935, 0.04023507244710345, 0.04853862883464899, 0.03563597216270864, 0.009998130935855443, 0.05385141914302949, 0.028010562491544988, 0.05114930398121942, 0.006872501317047863, 0.033442573258071207, 0.07372678330284543, 0.018894128043029923, 0.09875023664790206, 0.04458430274098646, 0.040027838840615004, 0.053260918211890385, 4.785666977986693, 40.01336149871349, 55.04821993410587, 40.79521894454956, 24.16096743196249, 34.9211635440588, 48.01802337169647, 52.05484315752983, 56.929274797439575, 11.609603483229876, 0.031643128604628146, 0.2149508142611012, 3.7045687017962337, 4.261534977704287, 4.342020833864808, 1.946864363271743, 9.944400787353516, 42.36633203923702, 56.46981105208397, 52.80332699418068, 50.9987848252058, 45.43893076479435, 41.636679992079735, 40.88094234466553, 41.35190427303314, 40.25580368936062, 38.46739545464516, 39.0352787822485, 37.992766723036766, 37.530536726117134, 37.442829832434654, 36.973064839839935, 35.66200979053974, 37.41024658083916, 36.56404718756676, 37.15949423611164, 36.32411666214466, 38.40839222073555, 36.1878065764904, 37.02473446726799, 37.16780439019203, 39.76942598819733, 38.5691349953413, 38.16957503557205, 37.51051180064678, 39.28191974759102, 38.97418186068535, 37.866427302360535, 36.71441271901131, 37.624349892139435, 40.078782588243484, 38.66033770143986, 37.622248604893684, 37.18279078602791, 36.39812529087067, 38.52363243699074, 38.616472855210304, 37.81140625476837, 43.06893713772297, 50.68733073771, 51.99805520474911, 51.19167007505894, 51.76158249378204, 50.09818375110626, 49.97704245150089, 57.421173602342606, 56.158383563160896, 49.78853076696396, 51.907430067658424, 52.285904958844185, 48.79351235926151, 46.08981303870678, 53.3709367364645, 52.2546174377203, 47.11786687374115, 44.12663318216801, 49.09396603703499, 51.36938653886318, 51.319594010710716, 51.11211754381657, 52.20809653401375, 50.83461083471775, 42.94764384627342, 35.92417672276497, 37.83032163977623, 38.50221298635006, 39.00568217039108, 38.364964351058006, 38.002687990665436, 44.26206171512604, 47.686886340379715, 50.95045141875744, 47.85251945257187, 42.15515457093716, 38.94803546369076, 40.65527245402336, 39.42009173333645, 39.88796062767506, 40.00726282596588, 37.27174401283264, 37.76284486055374, 38.330063223838806, 37.78916984796524, 37.42521397769451, 37.661112919449806, 37.113406509160995, 38.473285138607025, 42.8851979970932, 41.51376038789749, 45.10441951453686, 47.75846689939499, 48.675338700413704, 48.82340535521507, 46.897805482149124, 45.838578119874, 46.962136030197144, 44.85052473843098, 43.13697628676891, 40.95828339457512, 42.876317873597145, 47.51123696565628, 52.59463459253311, 55.14468915760517, 55.33773019909859, 52.265496253967285, 52.57793068885803, 38.16956743597984, 13.395275864750147, 2.6386349368840456, 3.9911172632128, 4.5582634303718805, 4.016810059547424, 2.541315509006381, 0.5928369448520243, 0.020286491708247922, 14.615659229457378, 49.44801963865757, 48.365355134010315, 41.54706560075283, 34.823204800486565, 47.575768902897835, 55.19287057220936, 22.437395118176937, 0.9217408241238445, 0.09111718842177652, 0.011032733964384533, 0.03154268633807078, 0.11521053034812212, 0.0158487584485556, 0.04635357909137383, 0.014142483014438767, 0.02498265192116378, 0.10179785123909824, 0.042280598427169025, 0.04012580604467075, 0.038754513807361946, 0.03336373119964264, 0.02214549185737269, 0.13453669409500435, 0.13926361076300964, 0.08577139480621554, 0.12240866519277915, 0.17180335766170174, 0.1274347712751478, 0.17777887842385098, 0.12656654755119234, 0.0954152995836921, 0.17953197966562584, 0.16244879399891943, 0.13348443259019405, 0.2192991168703884, 0.15289192087948322, 0.1504660924547352, 0.18636626919033006, 0.1709234228474088, 0.17230614786967635, 5.489019211381674, 45.916340947151184, 64.72257301211357, 48.42849634587765, 28.156014159321785, 39.82146419584751, 54.90232676267624, 56.80520385503769, 61.789502799510956, 15.05000727251172, 0.29507212748285383, 1.7269788309931755, 12.581289242953062, 14.053082317113876, 14.402114488184452, 9.959561973810196, 11.951217502355576, 44.538721069693565, 60.14294095337391, 53.908657282590866, 54.04915474355221, 47.64085181057453, 44.543307423591614, 42.78118617832661, 43.355525359511375, 42.01979823410511, 41.2308693677187, 41.40626795589924, 41.22326597571373, 40.64979314804077, 40.524297282099724, 39.27758798003197, 38.55649307370186, 39.61220562458038, 38.46942834556103, 38.95845830440521, 37.7352811396122, 40.299577340483665, 37.71313592791557, 38.41571822762489, 39.05296303331852, 42.28176757693291, 42.01256342232227, 41.16037555038929, 40.1678916066885, 42.13636077940464, 40.612296760082245, 39.90718759596348, 38.28954599797726, 40.04669710993767, 41.891509518027306, 40.48927076160908, 39.2022418230772, 39.80322517454624, 38.00451949238777, 40.15431493520737, 41.860081404447556, 39.18336443603039, 45.1108867675066, 55.30274547636509, 55.03140963613987, 52.36112952232361, 54.61463660001755, 51.603020802140236, 51.947476118803024, 58.07239405810833, 55.128399431705475, 53.46266761422157, 54.839090555906296, 53.51753666996956, 48.71883876621723, 50.03942370414734, 54.23029102385044, 53.65470930933952, 49.669950529932976, 45.830203369259834, 50.301434844732285, 53.21471571922302, 53.71858008205891, 51.106509044766426, 53.30418571829796, 53.65327298641205, 44.830131232738495, 37.92931392788887, 39.44113880395889, 39.357018917798996, 40.18797732889652, 39.91088479757309, 39.96528647840023, 44.52542558312416, 49.9180506169796, 52.95586220920086, 50.91004058718681, 44.02226038277149, 40.76632909476757, 41.95174768567085, 41.63187325000763, 41.018206179142, 40.443038642406464, 39.48455907404423, 40.223368629813194, 39.57807965576649, 40.28937868773937, 39.13667254149914, 39.64249759912491, 39.19164039194584, 40.00222809612751, 43.66330124437809, 43.55551242828369, 47.60792277753353, 50.988247990608215, 51.727414727211, 50.49282677471638, 49.502683505415916, 48.822694793343544, 48.15549619495869, 46.731799989938736, 43.76030243933201, 43.58591079711914, 44.16862852871418, 51.61116376519203, 52.384426072239876, 58.198171108961105, 58.472748175263405, 54.17775124311447, 52.664208859205246, 41.654421240091324, 13.197994250804186, 2.8654545033350587, 4.912578742951155, 10.573091302067041, 8.46954982727766, 5.445009972900152, 1.91980387782678, 0.10079606319777668, 16.51933617889881, 54.86950792372227, 50.680320113897324, 44.39916215837002, 42.20120809972286, 55.85642136633396, 62.10464648902416, 26.65446773171425, 1.486020223237574, 0.2518936787964776, 0.08693170559126884, 0.09229234216036275, 0.26405949785839766, 0.1514267284073867, 0.14503324491670355, 0.14997306891018525, 0.1511984586250037, 0.18573051580460742, 0.08105731729301624, 0.2150524439639412, 0.1243381155654788, 0.1796813591499813, 0.10739627934526652], [0.04001031302323099, 0.020644585383706726, 0.08024004200706258, 0.04019489628262818, 0.07672820662264712, 0.009877975371637149, 0.06358496422762983, 0.0675213080830872, 0.015827698152861558, 0.04832597012864426, 0.02718932413699804, 0.03318106639198959, 0.0033594898604860646, 0.024330895976163447, 0.04048521332151722, 0.030353622896654997, 0.06195671820023563, 0.02291482625878416, 0.44402078026905656, 23.222451992332935, 49.243111833930016, 40.99813565611839, 25.180243737995625, 33.037722408771515, 44.25240643322468, 43.88794519007206, 47.66656503081322, 15.979463048279285, 0.06362052052281797, 0.10660082320100628, 1.4511802489869297, 2.346460777334869, 5.670746359974146, 2.0195322576910257, 4.655783772468567, 35.80227166414261, 51.47165045142174, 48.94945219159126, 49.605695977807045, 47.06742078065872, 41.16583585739136, 40.219587832689285, 39.06169876456261, 41.054501831531525, 38.86578507721424, 37.76357442140579, 35.97926236689091, 33.964716866612434, 32.239047065377235, 35.659619718790054, 35.0414764881134, 34.418902695178986, 35.28445445001125, 35.19598759710789, 34.854222536087036, 34.493994265794754, 34.768058359622955, 34.888872876763344, 36.019916385412216, 35.72314850986004, 35.86064413189888, 37.36292012035847, 36.13010287284851, 36.043600514531136, 36.70905880630016, 35.47851003706455, 36.24741017818451, 38.026372119784355, 38.48867051303387, 35.97989313304424, 34.990088045597076, 35.371089801192284, 36.12402319908142, 36.150788962841034, 35.56005746126175, 37.115857377648354, 47.32065439224243, 51.12319014966488, 51.50433249771595, 51.55261270701885, 51.05854041874409, 49.14437033236027, 45.60908183455467, 42.943589463829994, 45.51471769809723, 55.232031270861626, 51.22043453156948, 47.474872916936874, 46.836681962013245, 41.50987319648266, 53.22998709976673, 48.898010551929474, 46.32224656641483, 45.734513103961945, 47.45873138308525, 49.371240958571434, 52.949581146240234, 50.96164561808109, 49.85658511519432, 50.96984937787056, 43.677136301994324, 34.42810580134392, 35.45989103615284, 36.07561759650707, 36.9083771109581, 37.389963269233704, 37.62259438633919, 43.19314107298851, 45.03104165196419, 44.16841574013233, 44.30517040193081, 38.67346219718456, 37.22040496766567, 38.03307496011257, 37.12827131152153, 36.22554615139961, 35.245396345853806, 38.01767058670521, 37.07467518746853, 36.58091448247433, 36.672512367367744, 36.535841301083565, 34.72700536251068, 36.05509489774704, 36.49525947868824, 33.67094323039055, 35.194992050528526, 36.27552106976509, 40.03664284944534, 40.56880809366703, 41.82624042034149, 41.95549428462982, 42.81589351594448, 43.29252474009991, 38.36567871272564, 37.21746012568474, 39.28703047335148, 42.16018930077553, 46.9316540658474, 50.606524273753166, 52.21307806670666, 55.89638762176037, 48.97693231701851, 49.24096494913101, 25.308270268142223, 6.3601048942655325, 1.6601696284487844, 2.355822524987161, 3.658043285831809, 3.627659878693521, 1.3932307460345328, 0.34507732547353953, 0.07118063047528267, 15.166283883154392, 46.54845982789993, 40.84853768348694, 26.596547439694405, 25.837830752134323, 39.26479406654835, 43.37935008108616, 14.478196855634451, 0.17828422161983326, 0.13078936783131212, 0.026705063501140103, 0.055561234621563926, 0.01943399038282223, 0.051462497722241096, 0.06088972506404389, 0.0734120978449937, 0.010092720440297853, 0.05359767143090721, 0.06714155853842385, 0.05645362638460938, 0.05496672238223255, 0.009391081966896309, 0.021438553521875292, 0.0464644448220497, 0.03153851175738964, 0.024383486415899824, 0.04330391617259011, 0.03912665262760129, 0.026066178252222016, 0.05080807561171241, 0.03847410072921775, 0.02032216674706433, 0.04738084506243467, 0.027795321111625526, 0.03230892041756306, 0.03398090862901881, 0.025520916788082104, 0.03592019245843403, 0.011845744684251258, 0.06490711515652947, 0.0278083847661037, 1.0539727192372084, 29.756944254040718, 54.23304207623005, 44.651107639074326, 26.42326343804598, 34.67864155769348, 49.49450634419918, 48.20208929479122, 53.66339944303036, 18.564331345260143, 0.121115131478291, 0.19136536109726876, 2.389518879354, 6.213497361168265, 7.6850600726902485, 3.6436494207009673, 6.488976404070854, 37.18836508691311, 53.97086374461651, 52.23536767065525, 51.50521405041218, 49.40873734652996, 42.99107551574707, 41.328539326786995, 42.409672513604164, 42.3808054625988, 40.920730009675026, 39.62423957884312, 38.38638760149479, 35.397604778409004, 36.54655672609806, 37.441226318478584, 35.99268704652786, 37.48100258409977, 37.44113892316818, 37.839509546756744, 37.27318413555622, 37.03118272125721, 36.82638891041279, 36.25834979116917, 37.35017940402031, 37.443962171673775, 37.346660792827606, 38.026877492666245, 37.94402673840523, 38.2138616591692, 38.69948700070381, 36.6642402112484, 37.94722616672516, 39.38501201570034, 39.862722381949425, 37.846660763025284, 36.709746569395065, 38.168419897556305, 37.141069024801254, 38.44558462500572, 37.896476089954376, 38.85953441262245, 48.26809175312519, 53.024649918079376, 52.11138032376766, 51.67314983904362, 52.909132316708565, 50.443045645952225, 46.61890424787998, 46.731439009308815, 52.6339016854763, 57.45189115405083, 52.25216656923294, 48.62358167767525, 46.68399475514889, 43.89910139143467, 54.31818790733814, 50.826589465141296, 48.636751770973206, 46.680973917245865, 50.2293337136507, 53.088277503848076, 54.52175058424473, 51.347815096378326, 52.89258040487766, 50.77756829559803, 45.02581313252449, 36.03558674454689, 37.60970547795296, 37.085664197802544, 37.16936230659485, 38.56861062347889, 39.79087583720684, 44.17003445327282, 46.52070231735706, 47.77483642101288, 45.98999239504337, 41.18106544017792, 39.854541420936584, 39.442495331168175, 38.30895155668259, 38.51506009697914, 38.44916023313999, 40.22675804793835, 38.39416578412056, 38.48207786679268, 38.42899851500988, 37.433945909142494, 35.87461978197098, 38.032615184783936, 38.72833125293255, 35.03437086939812, 37.20097281038761, 38.72351311147213, 42.67165705561638, 42.39130809903145, 43.84489730000496, 44.88547146320343, 45.04274122416973, 44.948194697499275, 40.36339871585369, 39.59416799247265, 40.59825271368027, 44.62822146713734, 48.415793627500534, 53.53761859238148, 54.0837062895298, 55.454915910959244, 50.1462359726429, 50.60033440589905, 29.617286548018456, 8.21409523487091, 2.653481215238571, 4.75512801669538, 4.382765097543597, 6.158614531159401, 2.923042788170278, 0.8037643984425813, 0.07031539018498734, 14.789087623357773, 51.338330805301666, 45.142938047647476, 30.30928261578083, 30.856616646051407, 46.53332144021988, 50.01588396728039, 18.66069797426462, 0.19220974703785032, 0.0973082882410381, 0.07032339053694159, 0.05798481062811334, 0.029741206344624516, 0.052826631945208646, 0.006477750648627989, 0.054142760345712304, 0.04925208879285492, 0.013777651565760607, 0.04611786927853245, 0.03053403528610943, 0.03845114610157907, 0.022762229564250447, 0.046260973904281855, 0.11083012243034318, 0.2127397633739747, 0.2346176831633784, 0.17862250737380236, 0.1308002625592053, 0.11449679950601421, 0.14903579576639459, 0.16743108368245885, 0.08066786787821911, 0.12375190053717233, 0.12065091068507172, 0.1899796526413411, 0.133950189629104, 0.11366744205588475, 0.14359557128045708, 0.16761415667133406, 0.14539545751176775, 0.14141054009087384, 1.5187688847072423, 35.17034277319908, 61.93998992443085, 52.200831323862076, 34.1223020106554, 44.260583594441414, 55.52363522350788, 52.50546857714653, 57.234953194856644, 21.333949528634548, 0.30879393336363137, 0.8452981291338801, 5.2312856912612915, 9.04342733323574, 13.11297856271267, 6.092867134138942, 7.733083795756102, 40.02987161278725, 55.91737389564514, 52.90229268372059, 55.134239718317986, 52.548828050494194, 46.469731852412224, 43.24740216135979, 44.381641298532486, 46.556032821536064, 43.49657379090786, 43.908676877617836, 40.90114586055279, 36.85421861708164, 38.08736264705658, 40.81250801682472, 39.5206381380558, 38.806937634944916, 39.65239606797695, 39.00225095450878, 38.92038434743881, 38.7198843061924, 38.19115027785301, 38.96297246217728, 38.34541819989681, 38.80097955465317, 38.35734196007252, 42.16048188507557, 39.140297546982765, 39.95872043073177, 42.04400673508644, 39.202063232660294, 41.021325811743736, 41.122837364673615, 42.4611559510231, 39.91348385810852, 38.441788628697395, 38.08200113475323, 39.70158062875271, 40.53944706916809, 39.10455286502838, 40.64243294298649, 51.73886351287365, 55.52599489688873, 53.58499825000763, 53.78572627902031, 55.39874732494354, 50.990546867251396, 48.612140491604805, 48.5220131278038, 53.140927478671074, 53.82630430161953, 51.694242507219315, 50.81694558262825, 47.710125893354416, 46.11252062022686, 57.33158580958843, 53.647352904081345, 50.107576847076416, 49.29856225848198, 52.92044810950756, 54.37051109969616, 55.326991975307465, 53.83097045123577, 55.60077868402004, 53.8512309640646, 47.1747650206089, 38.16298998892307, 38.52229490876198, 38.57228882610798, 39.277166202664375, 40.77322192490101, 40.9043300896883, 46.52701377868652, 49.58581164479256, 49.615488052368164, 48.79479669034481, 42.181118577718735, 42.03658953309059, 41.04397639632225, 39.96068112552166, 40.948236733675, 39.65258605778217, 43.152053877711296, 40.68053349852562, 41.24915398657322, 40.288755521178246, 40.418583154678345, 38.07030916213989, 39.40234288573265, 40.90291656553745, 37.86660589277744, 38.00283618271351, 41.12254098057747, 44.25857350230217, 44.085291400551796, 45.683569237589836, 47.344752699136734, 47.802916914224625, 47.45961293578148, 42.11747579276562, 41.145784333348274, 42.08503693342209, 46.030597016215324, 50.53533889353275, 56.847176402807236, 55.71677125990391, 58.51980485022068, 48.54272581636906, 51.42646707594395, 31.218856908380985, 8.309072088450193, 3.879239629022777, 8.162538651376963, 11.10758202150464, 12.175928894430399, 5.354687869548798, 1.6236993041820824, 0.19011322438018396, 17.845466919243336, 58.33886615931988, 51.892314478755, 38.467703238129616, 38.926106840372086, 53.588767647743225, 57.19927690923214, 22.300625257194042, 0.43041243392508477, 0.34905621665529907, 0.1580113297677599, 0.11422875802963972, 0.13759839464910328, 0.11576990931644104, 0.1127557507425081, 0.17690706270514056, 0.14028326229890808, 0.1484974566847086, 0.1799941447097808, 0.16167733148904517, 0.16636770480545238, 0.13715568871703, 0.1939753905753605], [0.012270839451957727, 0.07560315527371131, 0.03520947473589331, 0.04085481028596405, 0.04059620521729812, 0.007367301377598778, 0.05532456001674291, 0.06792284708353691, 0.04439265052496921, 0.03182873973855749, 0.0421979194652522, 0.027515047186170705, 0.017065101383195724, 0.03365574033523444, 0.022327525839500595, 0.1228766560961958, 0.013856860059604514, 0.03845562496280763, 0.035358275345060974, 15.069375783205032, 46.27389796078205, 42.80652701854706, 34.268449768424034, 35.81805221736431, 36.90054193139076, 41.6923014074564, 51.980199962854385, 25.15058822929859, 0.3531561075942591, 0.18105749390088022, 1.317530139349401, 4.0688620414584875, 0.9910188848152757, 0.9610346937552094, 4.393031671643257, 30.857718586921692, 51.09728313982487, 50.19226290285587, 48.846739903092384, 46.835568621754646, 42.36071974039078, 40.217057168483734, 40.36234237253666, 39.141027107834816, 37.43863865733147, 38.323998749256134, 36.86996877193451, 36.5331244468689, 36.86905302107334, 35.804942920804024, 35.87188772857189, 39.57201138138771, 38.83297763764858, 36.660926789045334, 37.68928840756416, 35.93171551823616, 35.523188039660454, 35.611951276659966, 37.676787078380585, 36.073371917009354, 36.46221645176411, 37.411093935370445, 35.67334458231926, 36.324420645833015, 35.96774898469448, 36.34097255766392, 36.16905838251114, 36.03994891047478, 36.361054480075836, 36.98607914149761, 35.893759354949, 36.30256801843643, 36.70839384198189, 37.24353812634945, 35.24120517075062, 37.31860309839249, 48.481385707855225, 51.76005117595196, 49.13215398788452, 49.74716238677502, 50.78702598810196, 48.781508803367615, 52.245258539915085, 48.79184044897556, 39.96597424149513, 40.027219355106354, 49.135338217020035, 48.129091411828995, 45.17332881689072, 44.49869401752949, 52.142295464873314, 52.928427681326866, 44.829789251089096, 44.6024664491415, 48.36138814687729, 49.3944501131773, 51.91111586987972, 60.67167118191719, 52.52518191933632, 49.678602665662766, 45.25076866149902, 35.72308771312237, 35.6407081335783, 35.13800650835037, 36.63906656205654, 36.343123242259026, 37.32524894177914, 38.85598160326481, 44.306291341781616, 41.15531422197819, 41.54441714286804, 39.090071842074394, 38.838768526911736, 37.62352153658867, 36.78428336977959, 36.6565266251564, 37.10634648799896, 35.90304985642433, 36.622947826981544, 38.241900354623795, 34.04458478093147, 36.67066566646099, 34.211460426449776, 35.52590869367123, 36.87017396092415, 36.96322716772556, 35.90255208313465, 36.78878612816334, 36.37009419500828, 33.68047691881657, 37.44469553232193, 36.168017238378525, 37.446139454841614, 39.84223388135433, 37.01255992054939, 38.60031232237816, 40.65303057432175, 44.08410586416721, 45.610122978687286, 49.45581682026386, 55.47995276749134, 54.28197585046291, 51.21614456176758, 45.42749337852001, 21.045296117663383, 3.5357568226754665, 1.2977670435793698, 4.659726060926914, 1.1754510132595897, 2.3681728122755885, 2.4514166079461575, 0.4684773663757369, 0.04527484517893754, 15.297373048961163, 44.186837151646614, 46.244172155857086, 37.35443897545338, 31.69059779495001, 46.24927148222923, 43.22509355843067, 7.653044890612364, 0.05252510847640224, 0.022451616641774308, 0.037525335428654216, 0.02920961895142682, 0.05049071471148636, 0.047221494824043475, 0.03325828685774468, 0.023820198184694164, 0.08564180097891949, 0.0005879014429410745, 0.04888757182925474, 0.042983475359505974, 0.07595186078106053, 0.049935729257413186, 0.0426645262632519, 0.02710421093070181, 0.04463624565687496, 0.04842745140194893, 0.04987092121155001, 0.007593371155962814, 0.07155471743317321, 0.0345911766635254, 0.04461785894818604, 0.027860758127644658, 0.028105806013627443, 0.04210600818623789, 0.010966561294480925, 0.05863187434442807, 0.010152651648240862, 0.020900147646898404, 0.06346517417114228, 0.033281705327681266, 0.016378527579945512, 0.2570526144700125, 19.062969088554382, 53.8048392534256, 48.29769216477871, 37.17341668903828, 37.61599414050579, 43.862266167998314, 46.16405725479126, 57.26354666054249, 26.44269749522209, 0.2082440405501984, 0.05318839925166685, 1.5424165595322847, 4.497802499681711, 3.2267175056040287, 2.0090289087966084, 5.312061756849289, 33.73944975435734, 51.66777692735195, 54.00786995887756, 51.814973428845406, 48.8731674849987, 43.24461691081524, 41.83923192322254, 41.955247297883034, 42.559361681342125, 38.213884457945824, 40.784195736050606, 38.10842491686344, 38.48793335258961, 38.79190944135189, 38.050922602415085, 37.27875843644142, 39.715271294116974, 38.4563684463501, 39.15806919336319, 39.59724582731724, 37.647752836346626, 37.95267887413502, 36.63137197494507, 38.30386742949486, 38.99946190416813, 39.04441349208355, 38.26816074550152, 37.282182052731514, 36.478369385004044, 37.46855445206165, 38.627363070845604, 38.12370389699936, 38.29434894025326, 38.58612388372421, 39.98588137328625, 36.48157261312008, 37.81965181231499, 38.15044306218624, 38.71600851416588, 36.681962460279465, 39.7340726852417, 50.37735857069492, 53.487389087677, 51.12684175372124, 50.43451510369778, 50.869044587016106, 50.70837780833244, 53.574301823973656, 49.126017317175865, 40.81153906881809, 46.6848649084568, 52.49990947544575, 49.86530564725399, 46.39849707484245, 48.661731630563736, 52.84316785633564, 54.17761445045471, 48.31596538424492, 49.834610894322395, 51.019983887672424, 52.51045770943165, 53.30372214317322, 57.643089294433594, 52.84084618091583, 50.43508127331734, 48.22315536439419, 37.73696444928646, 36.845608279109, 37.84156523644924, 38.783192709088326, 38.22797790169716, 38.20232927799225, 41.957382783293724, 45.92513367533684, 43.20109024643898, 44.578972309827805, 41.190006360411644, 40.06891831755638, 38.579436242580414, 37.69958205521107, 37.63885751366615, 37.729798033833504, 37.45299808681011, 38.802537471055984, 40.186727195978165, 35.87897814810276, 38.21110300719738, 37.16156132519245, 37.366906106472015, 39.23738233745098, 37.672706097364426, 37.12988242506981, 38.81401285529137, 38.89658622443676, 37.01626092195511, 39.018768668174744, 38.30988250672817, 38.16157266497612, 40.915197506546974, 38.11073899269104, 40.38917273283005, 42.30136312544346, 46.71576105058193, 48.052635714411736, 52.744745537638664, 55.331760719418526, 55.37900738418102, 49.09832060337067, 45.40018804371357, 22.830427028238773, 4.9032350443303585, 3.187176352366805, 5.583721529692411, 3.4872690495103598, 5.862072268500924, 3.2207088405266404, 0.7112617464736104, 0.0331132081191754, 16.49203084409237, 50.917579382658005, 50.37327378988266, 37.58788704872131, 34.977446123957634, 51.94455407559872, 48.6093894392252, 10.637443698942661, 0.045272993520484306, 0.044406792148947716, 0.09251178780687042, 0.06717377516906708, 0.06099054211517796, 0.05370072976802476, 0.048080868436954916, 0.0010331212843084359, 0.02167681075661676, 0.010314837818441447, 0.02847450497938553, 0.08756250885198824, 0.0750011696072761, 0.04719760509033222, 0.05147428673808463, 0.10304832554538734, 0.23606733506312594, 0.19957507291110232, 0.1300579812959768, 0.13779172411886975, 0.12513699301052839, 0.15790138801094145, 0.15351149544585496, 0.17065334046492353, 0.08618020685389638, 0.10108623551786877, 0.1672419547685422, 0.14048748649656773, 0.2160584251396358, 0.1060693638282828, 0.2028248633723706, 0.08119371661450714, 0.09320296478108503, 0.44324879825580865, 22.522407956421375, 61.80738843977451, 55.23511290550232, 47.21030831336975, 46.855950728058815, 50.043956860899925, 50.305679216980934, 63.265480399131775, 31.31142184138298, 0.6592089927289635, 0.3697629680391401, 4.18668326921761, 10.033682696521282, 5.532513102516532, 4.383451910689473, 5.987358195707202, 35.100707709789276, 53.8878457993269, 56.20407231152058, 53.12987767159939, 52.292284816503525, 46.30211524665356, 44.373167753219604, 45.79694755375385, 43.34642864763737, 41.24903239309788, 43.12996566295624, 40.65292038023472, 40.35644888877869, 41.25578463077545, 41.34941540658474, 38.69957819581032, 44.23337705433369, 40.76267749071121, 41.93595573306084, 42.562295123934746, 41.24653212726116, 40.456125140190125, 39.47248712182045, 41.200151816010475, 39.0016695857048, 39.56306666135788, 40.09207047522068, 39.57841403782368, 38.693186938762665, 41.036570593714714, 39.5124875754118, 40.73872737586498, 40.109112560749054, 39.98475283384323, 41.40236556529999, 38.17308984696865, 40.6185208261013, 41.044873148202896, 40.48949874937534, 38.9262892305851, 40.522127598524094, 50.49855686724186, 56.54352709650993, 51.88712775707245, 51.54130071401596, 51.55795522034168, 52.514546290040016, 56.20737053453922, 50.72696641087532, 42.18816339969635, 51.41561105847359, 49.13601838052273, 50.48883318901062, 47.648204416036606, 52.23419353365898, 55.69634735584259, 54.47548046708107, 48.83343681693077, 51.04615308344364, 51.6718465089798, 54.712777733802795, 56.14053972065449, 57.18250460922718, 53.480788841843605, 53.58090206980705, 49.83151026070118, 39.360370337963104, 38.32972124218941, 40.35115957260132, 39.58893187344074, 41.39115996658802, 40.34910388290882, 43.08060631155968, 47.221031337976456, 43.54931876063347, 46.81411497294903, 42.880132868885994, 42.836967185139656, 40.7315381616354, 39.51175421476364, 39.3245230615139, 40.731363371014595, 39.427892714738846, 40.554543659090996, 42.752535715699196, 35.61890870332718, 39.171870052814484, 38.95683579146862, 41.084668412804604, 40.982248708605766, 40.51210753619671, 41.57461032271385, 40.58602876961231, 40.77468864619732, 37.570848762989044, 40.52925601601601, 38.86130891740322, 41.66550524532795, 43.85940872132778, 40.97659841179848, 43.117760717868805, 45.20541809499264, 49.780330806970596, 50.1422955840826, 53.92387166619301, 58.90753984451294, 56.67433127760887, 52.312659323215485, 47.069301679730415, 24.818687438964844, 5.889027547091246, 3.890704088844359, 11.0995502024889, 7.0886944234371185, 8.31873781979084, 7.416708022356033, 1.7750958865508437, 0.13589604146545753, 20.10054711252451, 56.667354851961136, 59.51534762978554, 50.0814950466156, 43.30217242240906, 61.96840099990368, 57.27449767291546, 13.122616745531559, 0.17445172648876905, 0.07338473486015573, 0.20303450524806976, 0.10712630086345598, 0.23567761847516522, 0.13611026981379837, 0.16517495474545285, 0.13324457046110183, 0.1534731560968794, 0.1852033386239782, 0.1020557846641168, 0.26748442032840103, 0.2063103747786954, 0.1496109156869352, 0.20056818524608389], [0.03558466749382205, 0.014079754837439395, 0.033638303575571626, 0.04546627103991341, 0.01593939508893527, 0.024621652737550903, 0.018955824634758756, 0.015700551557529252, 0.031224828198901378, 0.040053728662314825, 0.003926579975086497, 0.07134954328648746, 0.06890525764902122, 0.03205295739462599, 0.011953850553254597, 0.04351076757302508, 0.05040502263000235, 0.05842443664732855, 0.10816272493684664, 8.538379333913326, 41.73561528325081, 44.592624977231026, 34.49085183441639, 24.65242736041546, 27.62138854712248, 38.04535590112209, 40.897817239165306, 36.96764633059502, 2.1142284013330936, 0.04624171146133449, 1.3307337183505297, 4.797315252944827, 6.6080263908952475, 3.598072291351855, 2.990704569965601, 21.194945387542248, 48.470856472849846, 54.53460529446602, 49.250126257538795, 48.48737418651581, 45.865397080779076, 42.87189111113548, 41.77946873009205, 39.01821009814739, 40.15579305589199, 38.924142345786095, 38.25586840510368, 38.08697506785393, 39.933691173791885, 39.754933565855026, 38.15648853778839, 41.2926160544157, 41.411340683698654, 39.55250322818756, 40.04249073565006, 41.477825716137886, 39.79535959661007, 36.55080109834671, 36.282573491334915, 36.96998320519924, 34.825047701597214, 37.09981843829155, 36.80363953113556, 36.95284612476826, 36.816292852163315, 37.50438652932644, 37.73308485746384, 36.73360548913479, 36.248648911714554, 37.94697158038616, 37.11073525249958, 36.612315997481346, 34.95442695915699, 37.186826169490814, 35.3091075271368, 35.561664775013924, 44.79340240359306, 50.003971606492996, 51.073355823755264, 50.14643736183643, 51.13087333738804, 48.67925629019737, 51.05587676167488, 47.61979714035988, 49.98152621090412, 40.331244841217995, 41.88933223485947, 50.07966734468937, 44.6534863114357, 43.5125595331192, 51.37436047196388, 50.04863440990448, 46.527880132198334, 45.95329016447067, 47.6312193274498, 49.93186667561531, 44.70317244529724, 46.484285071492195, 60.93991778790951, 49.00079123675823, 46.41036003828049, 33.46968702971935, 35.55840075016022, 35.546651780605316, 35.63357591629028, 36.70882321894169, 37.47283682227135, 36.055364683270454, 38.32737676799297, 40.904402285814285, 39.724945574998856, 37.50517688691616, 36.960818096995354, 37.79120273888111, 37.23443001508713, 36.50219410657883, 37.0521841943264, 36.89681813120842, 35.59690408408642, 36.84115491807461, 37.41606406867504, 36.62743918597698, 35.7702773809433, 35.37939615547657, 37.14897260069847, 35.78801482915878, 36.199737936258316, 35.86787514388561, 35.544379502534866, 35.22076986730099, 34.788106083869934, 35.31000427901745, 36.544219851493835, 37.176570519804955, 40.47005519270897, 40.665429309010506, 43.34455914795399, 45.896031036973, 48.072075471282005, 50.858291164040565, 52.45436891913414, 52.20447152853012, 47.57180571556091, 41.060144528746605, 15.223702602088451, 2.802277193404734, 4.623150648549199, 3.2560619059950113, 2.381772994995117, 5.945063140243292, 2.0422377018257976, 0.23360857012448832, 0.176119243260473, 14.914027769118547, 41.26904971897602, 36.606639102101326, 33.36475186049938, 32.79035948216915, 47.52708211541176, 36.866689547896385, 3.741394425742328, 0.13516536739189178, 0.024052904154814314, 0.04823414048587438, 0.035723938926821575, 0.12610027100890875, 0.11238469174713828, 0.09800563246244565, 0.028115734094171785, 0.00503613667206082, 0.01786592139978893, 0.04484085206058808, 0.020701068388007116, 0.0874945058603771, 0.08362616499653086, 0.05278398442897014, 0.07633752524270676, 0.10444239800563082, 0.030304592910397332, 0.02000228068936849, 0.06929636947461404, 0.041386110096937045, 0.06437174466555007, 0.042227913363603875, 0.04951643066306133, 0.08553218576707877, 0.04041332889755722, 0.0501031763269566, 0.019304595080029685, 0.05514240729098674, 0.08357630751561373, 0.019706681414390914, 0.06897597690112889, 0.009735648145579034, 0.08607835450675339, 11.91461881622672, 47.762794867157936, 49.48446728289127, 40.60080997645855, 33.0708110332489, 39.903402999043465, 44.138636738061905, 49.84968088567257, 38.3261988312006, 1.9590474595315754, 0.11826362941064872, 0.469036708236672, 7.087490363046527, 5.235023265704513, 3.1200812151655555, 4.034467237070203, 22.63371728360653, 51.16956666111946, 56.69622950255871, 50.93528263270855, 51.632484421133995, 46.081723272800446, 44.31927524507046, 44.26201991736889, 42.06785425543785, 42.908353954553604, 40.44175811111927, 39.60855022072792, 40.515063777565956, 41.431149020791054, 40.73431581258774, 39.92264896631241, 43.1007794290781, 42.47195117175579, 40.922504514455795, 41.54269203543663, 43.73666770756245, 41.04021839797497, 38.32324258983135, 38.06948460638523, 39.0520890802145, 36.59874692559242, 38.72985877096653, 37.37930104136467, 38.355461061000824, 38.09462025761604, 39.401050955057144, 39.211171343922615, 38.06064248085022, 37.75317057967186, 38.83379079401493, 38.78087863326073, 38.33939552307129, 36.44817240536213, 39.00032065808773, 36.66340045630932, 36.81993305683136, 45.755180194973946, 52.76684895157814, 52.09823302924633, 50.3852279484272, 52.88697190582752, 51.86862275004387, 52.21384562551975, 51.11914336681366, 50.248492285609245, 42.30558089911938, 47.810831889510155, 50.31092293560505, 46.11458770930767, 44.5887453854084, 53.76041583716869, 50.12260504066944, 48.7152973562479, 47.72931106388569, 49.38050106167793, 49.71444994211197, 47.012266740202904, 50.27667157351971, 59.090633019804955, 53.155815079808235, 49.26975220441818, 37.32042700052261, 35.63840925693512, 37.86857798695564, 37.30098344385624, 38.28976258635521, 37.22392737865448, 38.39222028851509, 40.14196939766407, 41.290172785520554, 42.784134820103645, 40.333509519696236, 38.42259965837002, 39.29391570389271, 39.163837283849716, 38.941841796040535, 38.69901582598686, 37.77155019342899, 38.06700713932514, 38.42066556215286, 38.43777224421501, 38.08088019490242, 37.264467403292656, 37.32463337481022, 38.98110508918762, 37.18185603618622, 38.06724652647972, 39.198316633701324, 37.14863441884518, 35.82081086933613, 37.38478794693947, 38.11526454985142, 38.49397882819176, 38.721100240945816, 41.4672888815403, 42.25446604192257, 45.42994424700737, 48.60448010265827, 50.4186737537384, 53.55132445693016, 55.7998576015234, 52.837924137711525, 49.72351625561714, 42.50981993973255, 19.509232342243195, 3.6210750695317984, 3.7157712131738663, 5.9786466881632805, 5.75164164416492, 5.44543270021677, 2.4549981532618403, 0.21612127020489424, 0.088563369208714, 16.806617863476276, 45.80139711499214, 42.89191983640194, 35.864079147577286, 40.114010497927666, 54.00720499455929, 43.504948541522026, 5.216751471161842, 0.0764649074699264, 0.020115196603001095, 0.014033520892553497, 0.027509032079251483, 0.048213698028121144, 0.06714389630360529, 0.042154975089943036, 0.08577690154197626, 0.08763113524764776, 0.050267469268874265, 0.11599437188124284, 0.0476469532441115, 0.039255819719983265, 0.05175766098545864, 0.03003698744578287, 0.14684043388115242, 0.1513406986487098, 0.23996433767024428, 0.12675723497522995, 0.16146345937158912, 0.1533215946983546, 0.13924100494477898, 0.17580856540007517, 0.19338054436957464, 0.18581820797408, 0.13429864280624315, 0.19382656028028578, 0.2571348147466779, 0.09519350132904947, 0.12987855967367068, 0.1428155295434408, 0.1887426557368599, 0.14471723843598738, 0.21088414185214788, 13.482287395745516, 54.55789424479008, 58.20572130382061, 46.38141319155693, 35.032919347286224, 39.682361260056496, 48.977494686841965, 51.97082206606865, 44.53563943505287, 3.147962694056332, 0.18199452955741435, 3.7883166829124093, 11.252945121377707, 14.062847793102264, 6.920574344694614, 4.1006335616111755, 25.682913064956665, 51.50376632809639, 58.29302541911602, 53.89302872121334, 52.53551356494427, 49.94933433830738, 48.543778359889984, 46.83563321828842, 44.13785398006439, 45.742032900452614, 43.65095190703869, 43.03271748125553, 42.861749455332756, 43.07707630097866, 43.217026591300964, 41.45347282290459, 47.05904982984066, 45.011548697948456, 43.7531778216362, 43.457390293478966, 46.85255751013756, 44.43317413330078, 40.862950310111046, 39.9602897465229, 41.02246195077896, 36.8192794919014, 41.19095630943775, 39.56177093088627, 40.53348898887634, 39.397011771798134, 43.503694608807564, 42.334383353590965, 40.50800375640392, 40.464074313640594, 41.05054624378681, 40.86086042225361, 39.74979244172573, 38.49330626428127, 41.634468510746956, 38.32173407077789, 39.06305529177189, 48.00242900848389, 55.41384771466255, 54.872882142663, 54.33558717370033, 55.68708345293999, 53.96679036319256, 55.55890113115311, 52.998210936784744, 51.012532487511635, 45.533621683716774, 51.36440120637417, 48.896426036953926, 47.560239136219025, 48.51373717188835, 55.79645678400993, 52.71607227623463, 49.75801460444927, 49.831799045205116, 51.92231386899948, 51.59028768539429, 50.454999804496765, 52.88775086402893, 60.73999151587486, 52.16245338320732, 50.49047850072384, 37.80667930841446, 38.408498615026474, 40.1703804731369, 38.53729650378227, 40.79762801527977, 38.8110414147377, 41.15615017712116, 41.31615199148655, 43.88560451567173, 44.81095366179943, 41.37131743133068, 39.81573790311813, 41.33915975689888, 41.60376235842705, 41.42641827464104, 40.16713924705982, 39.96839851140976, 39.64711055159569, 41.164992302656174, 41.16323679685593, 40.95734864473343, 39.24921490252018, 39.667876437306404, 40.515029579401016, 39.83506366610527, 39.47567135095596, 40.77057346701622, 39.52761456370354, 38.821798637509346, 39.28505077958107, 40.27874305844307, 40.21027073264122, 40.842344015836716, 43.926444724202156, 45.37042424082756, 46.470917388796806, 51.38993963599205, 52.6435037702322, 55.151517391204834, 57.25523270666599, 54.791334718465805, 49.14093531668186, 45.171311125159264, 20.184594802558422, 4.80779841542244, 9.80792636051774, 10.412238333374262, 9.66934684664011, 14.65129941701889, 7.006212724372745, 0.7965016819071025, 0.3522519045509398, 18.494067415595055, 52.8948412835598, 48.23772378265858, 46.5985981374979, 45.198350474238396, 62.656547874212265, 48.978053256869316, 6.434652144089341, 0.14961066335672513, 0.15142346295760944, 0.14701161766424775, 0.13401391042862087, 0.21035169542301446, 0.2832414029398933, 0.21806473232572898, 0.15386932936962694, 0.12052441161358729, 0.15837737184483558, 0.1817432531970553, 0.15224138391204178, 0.18434483703458682, 0.30509028991218656, 0.1486421309527941], [0.0218023561683367, 0.027458254335215315, 0.05634870525682345, 0.03366064964211546, 0.039752342490828596, 0.06399621051969007, 0.04091907656402327, 0.08424391387961805, 0.05239770769549068, 0.055444695171900094, 0.05110063393658493, 0.09857709359494038, 0.06692831724649295, 0.007386029474218958, 0.01853512709203642, 0.007968798618094297, 0.0517809532902902, 0.036618371595977806, 0.0630307431856636, 2.8069841908290982, 29.32140212506056, 47.367030903697014, 36.40940308570862, 19.76289913058281, 26.8116956949234, 36.21369458734989, 42.97006644308567, 44.51599828898907, 3.9107138151302934, 0.14804490987444296, 0.6179299077484757, 3.247066126205027, 1.7070811986923218, 1.661445766221732, 2.840356850065291, 15.946159735321999, 40.62621161341667, 55.581247732043266, 49.91042822599411, 48.419422432780266, 46.18925370275974, 43.71790811419487, 40.067018419504166, 42.00886242091656, 40.03296084702015, 41.69971860945225, 40.245339050889015, 42.042209431529045, 42.38462805747986, 43.50619487464428, 43.15455034375191, 44.12332735955715, 43.82051020860672, 44.85301360487938, 44.045511335134506, 45.795834213495255, 44.079527109861374, 42.317060083150864, 36.455380618572235, 36.430358961224556, 35.66537261009216, 36.16944596171379, 37.10223130881786, 36.49964064359665, 37.595562636852264, 37.773214504122734, 38.75711090862751, 39.31809760630131, 37.8102321177721, 37.609925866127014, 36.42737232148647, 36.30131408572197, 37.683303728699684, 35.4162959754467, 36.529419645667076, 35.52677504718304, 40.04893139004707, 44.92972008883953, 46.552886590361595, 47.57504694163799, 47.147763669490814, 47.26470239460468, 49.28362525999546, 49.64431710541248, 49.24960948526859, 49.55925866961479, 42.400439009070396, 47.41257146000862, 52.26326197385788, 44.55898158252239, 51.901316195726395, 49.517525508999825, 48.084561601281166, 47.9256085306406, 48.25491406023502, 50.81548646092415, 53.312723860144615, 41.00527927279472, 49.315281361341476, 52.600091099739075, 46.460832729935646, 37.81132645905018, 33.818648904562, 34.930644035339355, 35.259732976555824, 35.92343956232071, 35.238682106137276, 35.990338772535324, 37.753466963768005, 39.33743476867676, 39.90989685058594, 38.438083827495575, 38.5461538285017, 38.36121015250683, 37.80493140220642, 39.21349301934242, 37.037927359342575, 35.66555880010128, 39.13813166320324, 45.567854046821594, 46.76198557019234, 44.90654893219471, 44.37782630324364, 43.70271272957325, 42.39443153142929, 38.94467644393444, 37.736911252141, 36.008862778544426, 36.16484060883522, 34.760470166802406, 37.396669909358025, 35.395659282803535, 35.99851593375206, 39.3463908880949, 41.48985207080841, 45.7813835889101, 47.40056790411472, 47.46176742017269, 48.15090224146843, 52.31428183615208, 52.74052016437054, 53.88392820954323, 49.39749754965305, 40.22008180618286, 13.840873204171658, 2.1342359902337193, 1.2785524246282876, 3.6053529381752014, 3.2754707895219326, 4.319096188992262, 1.5215376298874617, 0.15424380224430934, 0.5990270501933992, 20.92934723943472, 41.04884013533592, 41.48335061967373, 28.780322559177876, 33.43123309314251, 44.59999278187752, 23.75247985124588, 1.5117368870414793, 0.05249211630143691, 0.045452589547494426, 0.09659066854510456, 0.027695789831341244, 0.05401807211455889, 0.016286723912344314, 0.04762634009239264, 0.07902587356511503, 0.04050291725434363, 0.019992430534330197, 0.03878235547745135, 0.018284826655872166, 0.004989167537132744, 0.008967345329438103, 0.014562945852958364, 0.060161425863043405, 0.02509952162654372, 0.04904606488707941, 0.02320150306331925, 0.05065577206551097, 0.07717740634689108, 0.015334968684328487, 0.09647571729146875, 0.015482121725653997, 0.04058061269461177, 0.022681033042317722, 0.11278099118499085, 0.025230967112293, 0.04415097013406921, 0.028626578459807206, 0.04445421167474706, 0.07290976034710184, 0.0423999172198819, 0.025927860478986986, 4.216210534796119, 36.77200622856617, 53.4154399484396, 43.03866796195507, 22.816873155534267, 31.542973816394806, 44.386425241827965, 46.3450263440609, 48.24315369129181, 4.2630320973694324, 0.06063352084311191, 0.9892772720195353, 4.245809046551585, 5.025004735216498, 2.7115143137052655, 3.7335701705887914, 17.37535424530506, 44.43195439875126, 57.442817240953445, 52.12459221482277, 49.918818175792694, 48.46119359135628, 45.74036858975887, 42.15465299785137, 44.3386086076498, 42.251521199941635, 43.90988901257515, 42.816600278019905, 43.310512974858284, 44.01911415159702, 46.13164119422436, 46.506073102355, 46.131527200341225, 47.37664818763733, 46.759762689471245, 46.704110875725746, 45.805903673172, 47.15033233165741, 44.494362249970436, 38.07162009179592, 37.71911300718784, 37.767693400382996, 38.64660143852234, 38.518673703074455, 38.58970329165459, 39.550679326057434, 40.28848573565483, 41.05297811329365, 40.59312678873539, 39.45871666073799, 39.078805446624756, 37.339251190423965, 37.42590554058552, 39.75152514874935, 37.646688893437386, 37.94669419527054, 36.80110886693001, 43.40103171765804, 46.66863597929478, 50.74156902730465, 48.35450291633606, 50.09981766343117, 49.67757672071457, 51.063434556126595, 51.02564178407192, 52.25104562938213, 50.087810307741165, 45.02115838229656, 49.055504500865936, 52.05788679420948, 45.4235377907753, 53.41661788523197, 51.19029834866524, 50.65100848674774, 48.07977005839348, 50.85862934589386, 51.68145999312401, 51.50324955582619, 42.671106085181236, 50.117608308792114, 55.66409468650818, 49.21996347606182, 38.770432993769646, 35.76794810593128, 36.47395022213459, 38.46421502530575, 38.00595581531525, 36.483411714434624, 37.48532295227051, 40.50295002758503, 41.618535965681076, 40.93215599656105, 39.23968881368637, 39.63329829275608, 39.06697668135166, 38.78095082938671, 41.046408265829086, 37.51742362976074, 37.5099266320467, 39.374459981918335, 44.190963730216026, 47.50723958015442, 45.65144956111908, 47.117657884955406, 44.57961067557335, 43.49929064512253, 41.41854129731655, 39.60193857550621, 38.05202454328537, 38.12590017914772, 36.22334986925125, 38.17698463797569, 38.32303740084171, 38.23635645210743, 42.062986716628075, 44.124315306544304, 47.22678802907467, 48.76489229500294, 50.52389770746231, 50.64927577972412, 54.370214715600014, 55.10798692703247, 53.38882997632027, 50.524862855672836, 42.649162262678146, 16.076808124780655, 2.567598936147988, 3.3401730051264167, 3.647047388367355, 5.980279175564647, 6.15693929605186, 2.07457990385592, 0.29090176220051944, 0.4821851308224723, 21.647257916629314, 47.1197135746479, 47.292600497603416, 34.78607319295406, 36.34397819638252, 51.45444117486477, 30.31750727444887, 2.401957274414599, 0.12622144888155162, 0.006149827131594066, 0.08675003526150249, 0.021059332757431548, 0.04053522294270806, 0.0043600132357823895, 0.007866606738389237, 0.14590235921787098, 0.044735927222063765, 0.06398467012331821, 0.029263207579788286, 0.0212609427399002, 0.05144529844983481, 0.04390002031868789, 0.03735416648851242, 0.07837832745281048, 0.06098690188082401, 0.1588266235194169, 0.18109568482032046, 0.1909484076895751, 0.2596882183570415, 0.06858096137875691, 0.19953453680500388, 0.08980222890386358, 0.12140334452851675, 0.11554140946827829, 0.3384443954564631, 0.12717997713480145, 0.11341670746332966, 0.10765658022137359, 0.10314918341464363, 0.1403964398195967, 0.20830511930398643, 0.17712028173264116, 5.059878788888454, 42.16521643102169, 59.69469800591469, 50.88753819465637, 28.32887638360262, 37.98185370862484, 47.84349113702774, 54.79763478040695, 53.232399970293045, 5.733058266341686, 0.32855340745300055, 2.611553790047765, 12.361075859516859, 4.333084663376212, 3.6348837660625577, 4.224894493818283, 19.004822708666325, 45.568591207265854, 57.84673556685448, 55.73876827955246, 52.2912322729826, 51.21685512363911, 48.28099966049194, 44.74260672926903, 46.08143448829651, 45.07876329123974, 45.74904352426529, 45.18816702067852, 46.422071009874344, 46.400427371263504, 49.102675169706345, 47.875565215945244, 47.07490257918835, 50.16237750649452, 50.20681992173195, 49.17368195950985, 50.19878715276718, 49.89350013434887, 46.75624027848244, 39.81780119240284, 38.849187567830086, 38.465841338038445, 41.118258610367775, 40.54424621164799, 38.79159785807133, 41.553776040673256, 42.65215650200844, 43.14460247755051, 42.79829666018486, 42.344931587576866, 41.50971740484238, 39.06832180917263, 38.71510036289692, 41.13734498620033, 37.995654568076134, 40.08964240550995, 39.53763462603092, 43.331411853432655, 49.07885044813156, 52.20553167164326, 52.549926191568375, 52.01030194759369, 51.67916111648083, 53.52048151195049, 53.57246272265911, 53.99329774081707, 53.60286869108677, 47.42174416780472, 50.7603058218956, 52.42101050913334, 49.98517021536827, 56.50084778666496, 53.205277025699615, 51.024631038308144, 51.57689340412617, 51.55722565948963, 55.648785308003426, 53.18649083375931, 46.56220369040966, 52.868622690439224, 54.054048880934715, 52.027131244540215, 40.55357091128826, 37.654748260974884, 38.038995042443275, 40.359534323215485, 38.373194709420204, 37.86721006035805, 39.53558653593063, 41.83699004352093, 43.798801973462105, 44.171136394143105, 42.01691418886185, 41.55534155666828, 42.044740095734596, 40.075909942388535, 43.570248037576675, 40.229547098279, 40.33534862101078, 42.468713745474815, 48.75421866774559, 51.2674456089735, 50.17576038837433, 49.230283722281456, 48.53243216872215, 47.08634756505489, 42.90605127811432, 41.539086028933525, 39.80282619595528, 40.8869194239378, 38.759918957948685, 41.146152913570404, 40.83955496549606, 39.941032379865646, 42.9889552295208, 45.09088844060898, 51.46614454686642, 51.49249233305454, 52.25579537451267, 52.76545062661171, 56.594216376543045, 57.86226913332939, 55.68176753818989, 52.9631882160902, 45.40553815662861, 18.697726987302303, 5.034051099792123, 6.539356950670481, 10.204866360872984, 9.298274908214808, 8.770241942256689, 5.312227997928858, 0.9718214836902916, 0.8061121974606067, 26.316181384027004, 52.93776378035545, 55.7707853615284, 39.90790195763111, 46.45224139094353, 58.72092425823212, 36.23331293463707, 3.029406205751002, 0.22214316035388038, 0.21061953651951626, 0.22950179205508903, 0.17476065288065, 0.13831186573952436, 0.13001135957892984, 0.1417271699756384, 0.26728211087174714, 0.16636003099847585, 0.11074155452661216, 0.11629343513050117, 0.10144648142158985, 0.10345481467084028, 0.12765517429215834, 0.14908746408764273], [0.014594153162761359, 0.028483420028351247, 0.03874897738569416, 0.12566262652399018, 0.03930374761694111, 0.05838862431119196, 0.01997138879232807, 0.04454243076907005, 0.02319053226528922, 0.059395844873506576, 0.05852311631315388, 0.09861290222033858, 0.014306503217085265, 0.007634104858880164, 0.01601011990715051, 0.02207865589298308, 0.04963740815583151, 0.03414173945202492, 0.007809247999830404, 0.8773505373392254, 14.853376373648643, 44.962531328201294, 38.096903935074806, 29.414611123502254, 27.480254620313644, 36.98905438184738, 44.89334084093571, 42.715008929371834, 10.500854328274727, 0.07184198053437285, 0.36702601646538824, 3.7690369924530387, 5.732731483876705, 1.7094111861661077, 1.3650820939801633, 9.454247988760471, 31.58201292157173, 53.06542173027992, 52.59348705410957, 50.21183185279369, 48.37913699448109, 48.36382381618023, 47.396779507398605, 45.15895798802376, 46.34275786578655, 44.254298731684685, 47.22263865172863, 45.71071118116379, 46.146327406167984, 46.95372328162193, 44.72293898463249, 47.119337394833565, 46.306401416659355, 46.98647752404213, 45.106638595461845, 47.406392991542816, 48.355433866381645, 47.288200333714485, 41.25829629600048, 36.6909983754158, 36.51179999113083, 34.4028789550066, 36.204822063446045, 36.05126470327377, 38.32082211971283, 39.41525459289551, 39.422516003251076, 38.79747234284878, 38.24621692299843, 36.51210397481918, 35.566072538495064, 35.62617391347885, 38.71488377451897, 36.970336586236954, 35.35975120961666, 35.874840170145035, 36.852052733302116, 38.12518581748009, 40.253398418426514, 40.183554366230965, 41.47056810557842, 40.643185302615166, 43.22497196495533, 45.591488778591156, 48.86333741247654, 50.66281445324421, 46.36139586567879, 45.68707264959812, 48.98260161280632, 43.291365802288055, 52.019071877002716, 49.563609436154366, 48.42469274997711, 47.50865690410137, 50.25738000869751, 50.45773945748806, 50.715684816241264, 46.52663379907608, 42.77427434921265, 49.48396950960159, 46.67866364121437, 38.22935342788696, 33.80254536867142, 35.92627041041851, 34.30387906730175, 37.22873792052269, 36.959480568766594, 36.284769773483276, 37.5261365622282, 37.36690230667591, 37.87147343158722, 37.61238053441048, 35.739977806806564, 37.91211225092411, 36.725105345249176, 36.041370034217834, 36.75148352980614, 36.70072965323925, 48.0514919757843, 49.322345182299614, 49.156879261136055, 49.35221157968044, 45.87737023830414, 48.74212771654129, 47.010416239500046, 47.11537420749664, 44.66362416744232, 42.001304626464844, 39.36145707964897, 36.26776948571205, 33.88877034187317, 37.12985962629318, 36.723346039652824, 39.37095656991005, 43.75083714723587, 48.25718253850937, 50.95639429986477, 50.93386150896549, 51.95462353527546, 52.088881731033325, 53.65551866590977, 47.39005006849766, 52.343787252902985, 38.515964448451996, 14.517521895468235, 1.6368416114710271, 2.3478871257975698, 2.8663408057764173, 6.739366818219423, 6.0644864570349455, 1.1685726698487997, 0.10908056123298593, 0.5628867738414556, 26.721828617155552, 41.7061972618103, 30.32395552843809, 28.488065041601658, 40.78424133360386, 41.946826949715614, 14.775550849735737, 0.7884755032137036, 0.11381859527318738, 0.034188528152299114, 0.09834446740569547, 0.02811094167554984, 0.021734518304583617, 0.02516664517315803, 0.02277991865412332, 0.021680775680579245, 0.08332848956342787, 0.04850078301387839, 0.04814063730009366, 0.13703192817047238, 0.033503588929306716, 0.07641109434189275, 0.07013112975982949, 0.03728811534529086, 0.05671642458764836, 0.12330657482380047, 0.025598897955205757, 0.018023496049863752, 0.014286759305832675, 0.04166143204201944, 0.05560714387684129, 0.021662518847733736, 0.06618487081141211, 0.062303972808877006, 0.06610855576582253, 0.050592003026395105, 0.10278077388647944, 0.028652165856328793, 0.015983452685759403, 0.012015891315968474, 0.04229785336065106, 0.02057088269793894, 1.2728678109124303, 20.745756290853024, 52.97106519341469, 43.23912240564823, 31.61723703145981, 31.27834651619196, 41.526257917284966, 48.97554539144039, 47.2530522197485, 9.554352667182684, 0.040641220184625126, 0.42315779195632786, 5.215983912348747, 5.734862694516778, 1.8749702023342252, 2.904356815852225, 12.193407956510782, 34.48739781975746, 54.46325272321701, 53.31538751721382, 51.28787711262703, 49.27951768040657, 49.00975115597248, 48.05592253804207, 46.11039273440838, 46.538420766592026, 46.713868752121925, 48.4797365963459, 47.310854718089104, 47.21411190927029, 47.72227004170418, 46.94049999117851, 49.60940457880497, 48.44103567302227, 49.15780261158943, 46.371735110878944, 48.83550010621548, 48.944436460733414, 48.28560121357441, 43.12851034104824, 38.6078093200922, 37.94824831187725, 37.069955840706825, 38.152950927615166, 37.145837768912315, 40.852763056755066, 41.199661642313, 41.16753816604614, 40.93136943876743, 39.10889983177185, 38.93042340874672, 37.41395138204098, 36.95935517549515, 39.400218799710274, 38.42684403061867, 38.57160486280918, 38.40832382440567, 39.29145723581314, 40.15077352523804, 42.87350222468376, 43.28819677233696, 43.84936586022377, 42.87018500268459, 47.457610443234444, 48.66429649293423, 50.40071591734886, 52.923666536808014, 48.4397779405117, 47.280456349253654, 50.66600628197193, 45.00560961663723, 53.971194326877594, 53.31780418753624, 50.52271217107773, 50.049736350774765, 50.74653536081314, 51.337035074830055, 51.793740168213844, 47.00957268476486, 43.914558961987495, 51.51322782039642, 50.37578545510769, 39.89442028105259, 35.429667457938194, 37.95900173485279, 37.81273618340492, 37.75842569768429, 39.007243886590004, 38.04334580898285, 40.18155187368393, 39.54263515770435, 39.40428838133812, 38.28256957232952, 37.4677374958992, 39.23589661717415, 38.22520025074482, 37.18876786530018, 38.225188851356506, 38.40198576450348, 50.03413438796997, 51.150978058576584, 51.39313146471977, 50.38395881652832, 48.035966008901596, 49.123384058475494, 48.419764414429665, 48.91425848007202, 46.19330808520317, 42.919475957751274, 41.488012969493866, 37.83829741179943, 37.176023349165916, 38.43754805624485, 38.019460290670395, 41.271359995007515, 45.142740458250046, 50.70189915597439, 51.23304225504398, 51.79536648094654, 53.626902401447296, 53.49603742361069, 53.897447884082794, 49.41343009471893, 53.03059659898281, 40.485839545726776, 16.217691265046597, 2.4825445376336575, 2.816904983483255, 5.58814306743443, 6.764816902577877, 7.13240347802639, 2.9554733354598284, 0.22741030115867034, 0.6913157855160534, 29.237747713923454, 48.81495460867882, 39.402878656983376, 31.06849517673254, 44.03114810585976, 50.112729370594025, 20.28462253510952, 1.0312109906226397, 0.11933951347600669, 0.02379446421400644, 0.03505914530251175, 0.02282307639688952, 0.05568323627812788, 0.059805228374898434, 0.024314435140695423, 0.046763278005528264, 0.11195198996574618, 0.027065188805863727, 0.030133800610201433, 0.06438111799070612, 0.03759458522836212, 0.043414815299911425, 0.044751764653483406, 0.05631922344036866, 0.14409502182388678, 0.2258882304886356, 0.1792246859986335, 0.1459189981687814, 0.20230029855156317, 0.12489251472288743, 0.16686816466972232, 0.1109061183524318, 0.13767502881819382, 0.1262444703024812, 0.12517962197307497, 0.11326734282192774, 0.1338148515787907, 0.14985146059188992, 0.12172848684713244, 0.10756222356576473, 0.12914608960272744, 0.12235494854394346, 1.4965650136582553, 25.435785725712776, 60.51083721220493, 51.196066439151764, 40.73545575141907, 36.9212432205677, 48.13995122909546, 53.80649596452713, 51.53397470712662, 13.503103628754616, 0.1378905781893991, 0.9011662937700748, 9.31588601320982, 14.962558764964342, 5.733585488051176, 3.5838161688297987, 12.246632650494576, 35.65503716468811, 55.281740203499794, 56.56124174594879, 54.790004789829254, 53.28802898526192, 52.899408638477325, 51.330115646123886, 49.19920139014721, 50.26711128652096, 50.06170950829983, 50.54643049836159, 49.60481442511082, 49.32783968746662, 50.694402158260345, 49.17460910975933, 51.63156867027283, 50.03841295838356, 51.38961285352707, 48.398284167051315, 50.87559163570404, 52.22687892615795, 51.783176735043526, 46.55428871512413, 40.677151679992676, 39.6917961537838, 37.472817823290825, 39.246604442596436, 39.65471774339676, 43.62677380442619, 43.664110600948334, 44.45610970258713, 42.73544043302536, 41.39116756618023, 40.27145504951477, 38.21727767586708, 36.80568382143974, 40.43348215520382, 41.4233024418354, 40.12058414518833, 40.3141837567091, 41.477156952023506, 41.57409355044365, 43.537550792098045, 44.21694673597813, 45.59504918754101, 43.51452402770519, 47.75274060666561, 50.80605536699295, 52.07185484468937, 53.854187205433846, 49.7223649173975, 49.82719749212265, 50.93242518603802, 47.331426814198494, 55.15242554247379, 54.871487617492676, 50.47105774283409, 51.879604160785675, 53.31952169537544, 52.99124211072922, 53.739262372255325, 46.64268337190151, 47.62198202311993, 52.0106553286314, 49.31183874607086, 41.98506809771061, 38.293531984090805, 40.08207321166992, 38.90328526496887, 40.46371333301067, 40.535540878772736, 39.112049862742424, 41.670775562524796, 42.1671961247921, 42.25507780909538, 41.87103621661663, 38.953290581703186, 41.9234924018383, 40.64988434314728, 39.49581407010555, 40.25804176926613, 39.531600549817085, 53.687037974596024, 53.491747453808784, 52.04372875392437, 52.35523983836174, 50.4129284620285, 53.879201263189316, 50.52095286548138, 52.68932171165943, 48.30885596573353, 46.32085204124451, 44.651552215218544, 40.086636766791344, 38.02151598036289, 40.9479745477438, 40.20509161055088, 43.52246940135956, 48.00842508673668, 53.202917352318764, 55.61119772493839, 55.111395344138145, 57.74112023413181, 54.819263219833374, 56.90141849219799, 52.23144628107548, 55.003519132733345, 43.0102264881134, 18.1822257488966, 4.494889006018639, 5.980367045849562, 8.731095492839813, 17.675657831132412, 17.936703823506832, 4.877987774088979, 0.39678260567598045, 0.8459734241478145, 32.111636102199554, 55.61383098363876, 42.3820897936821, 37.4548751860857, 54.056218564510345, 58.03247720003128, 23.480023071169853, 1.5064624138176441, 0.20280271768569946, 0.10345707079977728, 0.22692744503729045, 0.11453651182819158, 0.09851354348938912, 0.12774516711942852, 0.29478919110260904, 0.07140928617445752, 0.21567866817349568, 0.14830578962573782, 0.12779110606061295, 0.30719350674189627, 0.2548579650465399, 0.09838201265665703, 0.1941500772954896], [0.035997635568492115, 0.0890566228190437, 0.047249644485418685, 0.040116020827554166, 0.020956931221007835, 0.05642591087962501, 0.033731164803612046, 0.05926020254264586, 0.02008139363169903, 0.041583573329262435, 0.06397874778485857, 0.028357553637761157, 0.04081026287167333, 0.034744370786938816, 0.05695983418263495, 0.012503196612669853, 0.04964973893947899, 0.007786851838318398, 0.03989427823398728, 0.0315687097463524, 9.646655414253473, 39.15975630283356, 44.053631499409676, 24.457758106291294, 19.870554953813553, 33.5288992524147, 37.45623171329498, 51.16341479122639, 23.459289483726025, 0.5251277843490243, 0.5419765552505851, 3.1043776078149676, 2.584517765790224, 3.5272469418123364, 4.025284554809332, 7.487982697784901, 27.186581678688526, 45.981461852788925, 56.49886429309845, 49.214085191488266, 46.82776764035225, 48.02769385278225, 46.58877946436405, 49.29670415818691, 47.83393085002899, 49.35679033398628, 48.565182611346245, 48.35761874914169, 49.867771714925766, 49.021408930420876, 47.2042628377676, 49.18630488216877, 47.456899881362915, 49.95173200964928, 48.96923393011093, 49.73521202802658, 48.07577647268772, 47.380280792713165, 43.86048026382923, 36.840535551309586, 36.37390159070492, 36.878841295838356, 36.51415206491947, 36.91694185137749, 37.028511464595795, 38.98103669285774, 40.740520879626274, 40.06114773452282, 36.562185287475586, 35.9556732326746, 36.56679444015026, 35.626949071884155, 37.13551752269268, 39.38409246504307, 35.160896480083466, 36.34861394762993, 38.027211874723434, 36.389309763908386, 37.195463106036186, 38.54134328663349, 38.971297815442085, 40.98952151834965, 40.40664419531822, 41.914019510149956, 45.92404693365097, 46.71913906931877, 51.80797800421715, 47.31317259371281, 46.92986436188221, 42.5780338793993, 50.07734566926956, 51.4674174785614, 50.51919735968113, 50.41965790092945, 50.44779159128666, 51.565589010715485, 47.88803614675999, 46.612877771258354, 43.820308819413185, 48.31644035875797, 46.57957635819912, 39.04579281806946, 34.92161571979523, 36.01322114467621, 35.8238735049963, 37.53180965781212, 36.36594481766224, 36.97950929403305, 36.39934882521629, 38.608223497867584, 36.2793854624033, 37.96800725162029, 36.370341181755066, 37.09809713065624, 35.66791087388992, 39.10521022975445, 35.94922497868538, 42.49992907047272, 47.47775316238403, 48.50891523063183, 52.234634310007095, 47.2443962842226, 53.37954707443714, 47.85849653184414, 49.02634106576443, 49.238369688391685, 47.48871557414532, 48.709863647818565, 47.82856173813343, 43.05783413350582, 39.54500623047352, 36.32927678525448, 36.562835052609444, 37.65672795474529, 44.167594984173775, 47.84724533557892, 51.99479877948761, 50.59955544769764, 51.66419371962547, 49.40999507904053, 51.74698367714882, 50.660967752337456, 53.724975138902664, 37.07420401275158, 13.782548233866692, 1.4211897645145655, 1.1294682556763291, 1.9790543359704316, 7.24540276452899, 2.9494394967332482, 2.603898150846362, 0.2606116875540465, 1.2172581511549652, 24.15318924933672, 42.32316255569458, 37.32616849243641, 40.43026752769947, 40.748223066329956, 42.78500497341156, 11.087316758930683, 0.07150402874685824, 0.056239828481920995, 0.059142494210391305, 0.034171822408097796, 0.018597250418679323, 0.017680031960480846, 0.05746010850998573, 0.02911014704295667, 0.023999348923098296, 0.017633256247790996, 0.10488381260074675, 0.02986966097523691, 0.047258364720619284, 0.015731150306237396, 0.05174167141376529, 0.02564909496868495, 0.04403287959576119, 0.0574984701233916, 0.011862881801789626, 0.03539435856509954, 0.012809592280973447, 0.055042929816409014, 0.004625859810403199, 0.01777564099029405, 0.049241271990467794, 0.01711795528535731, 0.011560203365661437, 0.02396664618572686, 0.03363750576681923, 0.07076316498569213, 0.01103070975659648, 0.02433500747429207, 0.033713501688907854, 0.06498937480500899, 0.07887823070632294, 0.13510348711861297, 13.322942946106195, 45.88756509125233, 49.64111007750034, 29.957197308540344, 22.48513575643301, 41.31058149039745, 46.147528141736984, 54.08853203058243, 23.428180553019047, 0.2415518360794522, 0.28189297998324037, 4.1251427214592695, 5.396647593006492, 3.259240435436368, 2.3572341492399573, 8.3656957000494, 30.592378824949265, 46.802552193403244, 57.80906438827515, 52.379915714263916, 49.39191944897175, 50.786148235201836, 49.51597139239311, 51.296662241220474, 50.14136083424091, 49.99211244285107, 50.43932564556599, 50.07129639387131, 51.35264843702316, 51.27471461892128, 49.07660856842995, 52.24496215581894, 50.48181116580963, 51.223208382725716, 50.56313440203667, 50.92272810637951, 50.395874977111816, 51.2280835211277, 46.0127417743206, 38.15287113189697, 37.985752299427986, 37.88369357585907, 37.15398833155632, 38.6104691773653, 39.45749692618847, 40.61001308262348, 43.40385116636753, 40.684595480561256, 37.292361706495285, 37.41912670433521, 37.56334036588669, 36.653543785214424, 39.5153222233057, 39.83422391116619, 36.54257073998451, 36.27933606505394, 40.281440913677216, 37.792783454060555, 40.02838969230652, 41.02947637438774, 40.97052253782749, 43.39489884674549, 43.23599137365818, 44.19569447636604, 47.342746406793594, 50.194595977663994, 51.85379974544048, 50.909520015120506, 47.023681327700615, 44.07059758901596, 53.56112793087959, 53.02691079676151, 50.93325354158878, 52.91881799697876, 49.618995264172554, 52.0657941699028, 49.99200604856014, 46.76146499812603, 45.7975897192955, 49.68907110393047, 48.3195523917675, 40.57870656251907, 37.14041166007519, 37.20487140119076, 37.235319167375565, 38.39733101427555, 37.57238008081913, 37.94535666704178, 37.44460813701153, 39.30304281413555, 37.96894960105419, 38.7696236371994, 38.641745299100876, 38.170262798666954, 37.13110975921154, 38.7748559564352, 36.86239577829838, 43.63559313118458, 50.997261106967926, 50.65798871219158, 51.38519749045372, 49.76432986557484, 53.690564185380936, 48.674027770757675, 50.933872908353806, 49.720913395285606, 49.783537834882736, 49.635759964585304, 49.04718674719334, 44.575054720044136, 42.39250883460045, 37.963652685284615, 38.27256850898266, 40.011286810040474, 45.27603730559349, 50.674274638295174, 53.10466982424259, 54.35277745127678, 53.563514202833176, 51.461976170539856, 52.611281499266624, 52.180198431015015, 54.55146498978138, 39.35258835554123, 15.092471893876791, 2.6775429490953684, 6.425900738686323, 6.166821615770459, 14.625278413295746, 3.462026766501367, 2.7017735363915563, 0.1935694061103277, 1.4319260884076357, 28.00855167210102, 46.36422671377659, 38.01343381404877, 43.85111376643181, 46.262316182255745, 48.463386073708534, 14.445288721472025, 0.14059155044378713, 0.018704323774727527, 0.06890434480737895, 0.05760947315138765, 0.04310309472202789, 0.020741580374306068, 0.0139354757629917, 0.05200772764510475, 0.09911227854900062, 0.0774616192211397, 0.07299178250832483, 0.015135872727114474, 0.0587118518888019, 0.04870242082688492, 0.031749979316373356, 0.07009293141891249, 0.1955623397952877, 0.17571011208929121, 0.09156647720374167, 0.23110803711460903, 0.08900899920263328, 0.12010294594801962, 0.0910176218894776, 0.09958829206880182, 0.20848555024713278, 0.13594662625109777, 0.23461328964913264, 0.06325441907392815, 0.20970803074305877, 0.11143380019348115, 0.13575782388215885, 0.18061900336761028, 0.20554946560878307, 0.17411605309462175, 0.2576289663556963, 0.3139200364239514, 16.806549467146397, 53.33899945020676, 56.85244292020798, 35.80542549490929, 30.26180226355791, 45.95874287188053, 47.91828252375126, 61.749832928180695, 29.028804525732994, 1.0189095069654286, 1.7051130230538547, 12.102886363863945, 9.49575126171112, 5.541661586612463, 6.471742428839207, 9.451405741274357, 32.99261122941971, 49.844942539930344, 57.473147213459015, 54.55601714551449, 50.116570964455605, 53.49653519690037, 51.47326156497002, 53.98216813802719, 54.16001379489899, 52.484790086746216, 52.84006342291832, 51.96067661046982, 54.65226598083973, 53.824431002140045, 50.74304334819317, 53.936319798231125, 52.78681308031082, 52.31631852686405, 53.24562706053257, 52.973497062921524, 51.96175195276737, 53.40792015194893, 48.26417416334152, 39.37210790812969, 40.16205511987209, 39.40476335585117, 38.540214747190475, 39.7589385509491, 40.17939738929272, 42.12518937885761, 45.395236909389496, 43.854575380682945, 38.95377315580845, 38.27698767185211, 39.50814440846443, 39.00859661400318, 41.44412152469158, 42.14812494814396, 38.07665482163429, 38.081073984503746, 42.27422118186951, 39.9636335670948, 41.979653388261795, 42.08881013095379, 43.14780570566654, 44.7089671343565, 44.706090688705444, 45.676733404397964, 50.42292572557926, 52.55474433302879, 54.23312187194824, 52.58488051593304, 49.191214218735695, 45.24975411593914, 54.02259036898613, 55.431053191423416, 53.338535875082016, 55.6950668245554, 51.36464059352875, 54.687721878290176, 50.507763773202896, 46.781999096274376, 47.83997252583504, 51.23659886419773, 51.86169192194939, 43.01938019692898, 38.792540207505226, 38.57249401509762, 39.46974366903305, 40.597994327545166, 39.17350396513939, 39.417112693190575, 39.31959852576256, 41.14228092133999, 41.1735912412405, 41.383146196603775, 40.79219050705433, 39.96895328164101, 38.507190719246864, 41.867798790335655, 39.769767969846725, 45.40351286530495, 52.81285308301449, 51.161131113767624, 55.61310142278671, 53.324875608086586, 55.86903668940067, 51.110624223947525, 53.35049383342266, 51.84244975447655, 52.89967842400074, 53.029407262802124, 52.01493389904499, 47.353860810399055, 44.54156331717968, 39.58352856338024, 41.330313831567764, 41.722749173641205, 47.12851770222187, 53.01279075443745, 56.14072971045971, 56.0456246137619, 56.213074028491974, 51.53233699500561, 54.80069361627102, 53.44190172851086, 55.154758617281914, 43.54392684996128, 17.362338043749332, 2.9344200901687145, 7.122738696634769, 6.835190551355481, 18.257683999836445, 8.593566622585058, 5.304762348532677, 0.894462859723717, 1.8243215326219797, 30.613226406276226, 54.391858354210854, 49.003770276904106, 50.10964773595333, 53.415762931108475, 57.80166998505592, 17.522945925593376, 0.26471425022464246, 0.19907189678633586, 0.14767624059459195, 0.11333323069266044, 0.1219183875946328, 0.10661746957339346, 0.07330721011385322, 0.09961975170881487, 0.1643988909199834, 0.15718569047749043, 0.1960321786464192, 0.10802206568769179, 0.21063053514808416, 0.2525010524550453, 0.14240828342735767, 0.13787803589366376], [0.043144803421455435, 0.012894817737105768, 0.02175252837332664, 0.04764877892739605, 0.03317665061331354, 0.03354483007569797, 0.026889902801485732, 0.07623962112120353, 0.03444581961957738, 0.08512948159477673, 0.05549675312067848, 0.0673539463605266, 0.019213841551390942, 0.007678914344069199, 0.025010222707351204, 0.031607657656422816, 0.03683945367811248, 0.10816681417054497, 0.03344893346366007, 0.018126571085304022, 4.117834763601422, 30.54997880011797, 42.563872039318085, 31.537355817854404, 23.136075027287006, 26.75862394273281, 37.18476288020611, 46.181289330124855, 33.63396741449833, 1.1307451059110463, 0.10713258685427718, 2.537049287930131, 4.340765476226807, 1.997669655829668, 2.0777693577110767, 5.986761152744293, 23.07803314179182, 46.6328950971365, 47.65386611223221, 48.83553810417652, 52.08614207804203, 49.95438426733017, 51.25819690525532, 50.58476664125919, 50.70621572434902, 47.40297697484493, 50.233433693647385, 51.14436261355877, 51.69369533658028, 48.6751639097929, 48.22969861328602, 51.72792010009289, 50.178887620568275, 49.81128394603729, 46.69731304049492, 46.691666543483734, 46.61466367542744, 48.47084127366543, 45.07245182991028, 36.04562200605869, 36.49271361529827, 36.045204028487206, 39.26371872425079, 36.14273339509964, 40.42223855853081, 39.480911269783974, 41.4089772105217, 40.25157451629639, 39.42587122321129, 35.542775988578796, 37.046013325452805, 37.13925652205944, 37.02622778713703, 36.82916656136513, 36.798190623521805, 39.69684608280659, 38.704316541552544, 38.61201949417591, 42.69324369728565, 42.848423570394516, 44.02748890221119, 45.038105472922325, 43.62650781869888, 42.42130368947983, 43.48285272717476, 46.13842763006687, 49.351937994360924, 46.95814624428749, 48.174685165286064, 42.540229707956314, 48.719389736652374, 50.46338215470314, 48.75232256948948, 50.020348727703094, 50.13773202896118, 48.73838871717453, 48.63426670432091, 46.864868849515915, 46.80009752511978, 47.011829763650894, 47.798372358083725, 39.4629230350256, 34.1238447278738, 36.32296912372112, 35.520642176270485, 37.13224209845066, 36.886832267045975, 37.46464446187019, 36.8991170078516, 35.40673568844795, 34.6808872371912, 35.98513685166836, 37.93070085346699, 38.3316021412611, 35.96521072089672, 37.37861327826977, 34.67095077037811, 40.73743924498558, 50.20985595881939, 45.68689405918121, 45.424468740820885, 45.06818845868111, 46.270006969571114, 44.77324828505516, 49.05879892408848, 49.417666867375374, 50.97166568040848, 47.94458471238613, 49.18156273663044, 47.02427789568901, 46.297243908047676, 42.432577684521675, 38.09184640645981, 35.05474157631397, 41.4611142128706, 47.99743227660656, 51.82008035480976, 50.971722677350044, 51.4412634819746, 50.0393933057785, 55.01696281135082, 51.02506801486015, 53.42310793697834, 33.163039684295654, 13.185230735689402, 2.1071161329746246, 4.557247459888458, 6.550932079553604, 10.01459727063775, 3.678578808903694, 1.8972183647565544, 0.10519419360207394, 2.8016554517671466, 30.304021798074245, 38.92729237675667, 34.787562713027, 41.13223046064377, 44.634745717048645, 37.82640404999256, 6.203182814642787, 0.11281253246124834, 0.014555410270986613, 0.03625500496127643, 0.019927210596506484, 0.06675147829810157, 0.0655320480291266, 0.01746084977639839, 0.009352748184028314, 0.05920927636907436, 0.02361329854466021, 0.014449844402406598, 0.04244792304234579, 0.04614159573975485, 0.029470426343323197, 0.019415757669776212, 0.03050622886803467, 0.02029507464612834, 0.03598657014663331, 0.06284721006522886, 0.054426787683041766, 0.04021751323307399, 0.036277232284191996, 0.03487499991024379, 0.09245371475117281, 0.07131671809474938, 0.09700097973109223, 0.04544691211776808, 0.03236519747588318, 0.021996832256263588, 0.019416835639276542, 0.02610376432130579, 0.022812584284110926, 0.04809337362530641, 0.025040075597644318, 0.048818470459082164, 0.01642293769691605, 6.454798663035035, 37.17486821115017, 48.58928471803665, 33.483168706297874, 27.64973882585764, 35.063241720199585, 44.30195577442646, 53.512954115867615, 35.83734378218651, 1.0852398164570332, 0.07949125953018665, 3.730877540074289, 2.73052089381963, 3.3071219036355615, 1.229908384848386, 7.310125641524792, 27.18202192336321, 50.160314217209816, 52.37108878791332, 51.05747267603874, 53.11074189841747, 52.24340803921223, 51.9070690870285, 53.2507985830307, 50.96826486289501, 50.569290071725845, 51.5571154654026, 51.35626204311848, 52.849878296256065, 50.89618273079395, 50.42739428579807, 53.400696739554405, 50.30983619391918, 51.40814445912838, 49.10357192158699, 48.68810221552849, 48.914003893733025, 51.21308572590351, 45.12465722858906, 39.15388181805611, 36.9611144810915, 38.33178073167801, 39.499435275793076, 38.626154735684395, 41.3807637244463, 41.773309260606766, 43.15852113068104, 41.62874221801758, 40.35144455730915, 37.50442452728748, 38.004565089941025, 38.29812973737717, 37.10951171815395, 38.26133631169796, 37.614926397800446, 40.83334609866142, 39.82332989573479, 40.86280971765518, 42.94774644076824, 44.60896410048008, 46.96488328278065, 46.80412910878658, 44.703389033675194, 44.54180270433426, 45.98711594939232, 48.324837908148766, 52.03477643430233, 48.92851911485195, 49.71453733742237, 44.603017419576645, 50.06049357354641, 52.30622246861458, 50.75392596423626, 52.564745396375656, 51.000783517956734, 50.51674649119377, 50.40098190307617, 49.06015545129776, 47.765975296497345, 48.9869599789381, 48.5560517013073, 40.85722781717777, 36.84028476476669, 37.390461042523384, 38.00825469195843, 37.94052332639694, 39.29319754242897, 39.23299357295036, 40.020223930478096, 38.45573768019676, 37.6491017639637, 38.16446430981159, 39.45267118513584, 39.50155936181545, 38.51231664419174, 39.258695393800735, 37.13522493839264, 41.79505929350853, 51.57969765365124, 48.12871903181076, 46.41575574874878, 46.53210550546646, 47.825521901249886, 47.95316085219383, 51.290685161948204, 52.919722348451614, 53.45906160771847, 50.22576190531254, 51.77649289369583, 48.86234186589718, 47.52716951072216, 42.8177972137928, 39.05064895749092, 36.195732951164246, 42.240440994501114, 51.221654266119, 53.94786737859249, 52.78628870844841, 53.305109068751335, 51.606440618634224, 57.6459239423275, 53.1605876237154, 55.289955362677574, 34.908065646886826, 14.994827583432198, 2.5489165261387825, 6.040201485157013, 6.096639856696129, 11.65265517309308, 5.757709443569183, 1.5960408258251846, 0.13503243390005082, 2.3328332835808396, 32.95223839581013, 44.920866563916206, 43.078983798623085, 46.72831177711487, 48.93203392624855, 44.37541723251343, 8.979102484881878, 0.17970075889024884, 0.08313316371641122, 0.07298905882635154, 0.005185891868677572, 0.0254968823355739, 0.030302772793220356, 0.08416969911195338, 0.03342099160363432, 0.015185102165560238, 0.018790581743814982, 0.05099049179989379, 0.03231156246329192, 0.060731528865289874, 0.03570886961824726, 0.07151131663704291, 0.03346940931805875, 0.1709592982660979, 0.09205473616020754, 0.17687172163277864, 0.1764855079818517, 0.2541970380116254, 0.1018896400637459, 0.12883949355455115, 0.16287883889162913, 0.11969051964115351, 0.14030684775207192, 0.16832209134008735, 0.143841830722522, 0.13798177329590544, 0.10497749390196986, 0.13064720202237368, 0.18931062135379761, 0.10242779360851273, 0.19983495818451047, 0.09614136492018588, 0.08287544551421888, 6.5904266852885485, 41.96002744138241, 56.74779273569584, 42.21561312675476, 34.50625620782375, 39.113672375679016, 47.03151650726795, 55.52828997373581, 41.482712253928185, 1.6656295792199671, 0.21023418375989422, 6.618212219327688, 9.705523755401373, 4.808154171332717, 3.605724605731666, 8.704802803695202, 28.405860252678394, 54.33814823627472, 56.41364246606827, 49.4789157807827, 56.02483972907066, 54.87312152981758, 55.04148289561272, 55.69429166615009, 53.850379809737206, 53.078200444579124, 54.340409114956856, 53.5258924216032, 55.0921455770731, 51.19938746094704, 50.623133182525635, 53.68440471589565, 52.752626314759254, 51.2592950463295, 49.86851267516613, 49.69448201358318, 50.88536471128464, 53.57994832098484, 47.749183997511864, 40.74406988918781, 39.40484315156937, 39.534233808517456, 41.780202090740204, 40.35995990037918, 44.94269639253616, 43.97868812084198, 43.957409262657166, 44.43361110985279, 42.72979773581028, 38.87756444513798, 39.385015815496445, 40.17599277198315, 38.79836529493332, 40.93133144080639, 39.63683970272541, 42.10774451494217, 41.92703001201153, 42.86021053791046, 45.09386748075485, 46.373562812805176, 49.08605486154556, 49.61467869579792, 48.14638048410416, 46.126150488853455, 47.99576796591282, 50.977942943573, 53.94914411008358, 50.55454686284065, 51.44724056124687, 46.371564120054245, 51.60649001598358, 53.03851157426834, 51.629877761006355, 54.91733215749264, 54.042429104447365, 52.51203462481499, 52.40418121218681, 48.72851684689522, 50.89209794998169, 50.493047162890434, 51.26159392297268, 42.820449471473694, 38.79034012556076, 40.15322059392929, 38.64844053983688, 40.30900463461876, 40.342332646250725, 42.503812462091446, 41.43829643726349, 40.1503099501133, 39.53296087682247, 39.91026163101196, 40.857246816158295, 42.171873673796654, 38.95156167447567, 41.08857460319996, 38.826343193650246, 43.12353640794754, 53.784992918372154, 51.23747281730175, 47.74832144379616, 46.43962226808071, 49.51850585639477, 48.14047560095787, 52.58717559278011, 53.62539008259773, 56.00245513021946, 51.92770957946777, 53.77561882138252, 51.19483530521393, 50.72187468409538, 46.02437674999237, 42.22606636583805, 37.67680607736111, 45.127681866288185, 52.75228053331375, 56.380257457494736, 54.99414503574371, 55.82511104643345, 53.646520748734474, 59.31729465723038, 55.38302756845951, 58.42745080590248, 36.86945199966431, 17.133444026112556, 3.580270721577108, 9.829832185059786, 13.899705447256565, 17.504716403782368, 11.601089090108871, 5.208438467234373, 0.4253258428070694, 3.4422635519877076, 39.53631229698658, 53.7497878074646, 47.63406917452812, 51.5524835139513, 57.934457659721375, 49.809604436159134, 11.85143580660224, 0.2916949993232265, 0.21692271548090503, 0.16575236048083752, 0.05087906203698367, 0.16355014115106314, 0.19589565315982327, 0.15425152058014646, 0.16227844142122194, 0.13589428999694064, 0.125962246384006, 0.13460740592563525, 0.1316675660200417, 0.16069891367806122, 0.17376207833876833, 0.15939124947180972, 0.13272316718939692], [0.015616100718034431, 0.012066801718901843, 0.04935775577905588, 0.026223142485832796, 0.052187086184858344, 0.03149085103359539, 0.01891346099000657, 0.025578483327990398, 0.054821380181238055, 0.030749731231480837, 0.01382146981995902, 0.018906123004853725, 0.05446306757221464, 0.015024412350612693, 0.022412872822314966, 0.02734887475526193, 0.030673462570121046, 0.027663671535265166, 0.05148990894667804, 0.07644189347047359, 1.1793427169322968, 16.740159429609776, 40.307268127799034, 36.125801503658295, 19.456751458346844, 28.458785712718964, 41.45395539700985, 45.36854714155197, 39.624049589037895, 2.674930114299059, 0.30654902569949627, 1.9547534524463117, 4.10774820484221, 4.087292952463031, 0.9698600170668215, 5.449580177664757, 23.722161278128624, 40.37008635699749, 47.18438610434532, 43.17091226577759, 48.17828357219696, 48.04497912526131, 46.98895499110222, 51.43004268407822, 50.03933630883694, 49.977266639471054, 51.00183606147766, 53.21099191904068, 51.88028432428837, 46.24637223780155, 46.502121314406395, 49.33714538812637, 47.39386886358261, 47.02852986752987, 47.841933220624924, 46.04006990790367, 48.48192907869816, 47.523863688111305, 44.18367572128773, 37.76902332901955, 35.861316695809364, 37.65463046729565, 38.296959400177, 38.308822363615036, 39.55257162451744, 42.20376156270504, 42.73294396698475, 40.427356883883476, 38.75805325806141, 36.14575803279877, 36.35079503059387, 37.73469977080822, 36.489586383104324, 35.67240983247757, 36.14595182240009, 36.47679626941681, 39.22992713749409, 46.52120389044285, 47.08550401031971, 49.424742087721825, 47.99436204135418, 46.11241042613983, 46.68226584792137, 45.167195945978165, 45.06144382059574, 43.95739786326885, 48.925958052277565, 48.6126496642828, 51.258641481399536, 42.08668224513531, 47.3688168078661, 50.99770948290825, 50.48664070665836, 52.588224336504936, 48.971741795539856, 49.04880926012993, 47.807917445898056, 48.79910945892334, 46.55176945030689, 48.4576103836298, 45.79474747180939, 40.90881384909153, 35.22665575146675, 35.11698603630066, 35.047111585736275, 34.33663330972195, 37.18918204307556, 35.88213577866554, 36.32938697934151, 37.77967415750027, 36.55699856579304, 36.66865177452564, 35.728624016046524, 35.04453532397747, 35.02772882580757, 36.87346838414669, 35.21414302289486, 37.029909789562225, 48.199938610196114, 49.3794409185648, 49.13311533629894, 48.39497834444046, 47.88839712738991, 48.73579725623131, 49.035076797008514, 48.23261305689812, 49.603256508708, 49.44284811615944, 51.37468725442886, 48.57518747448921, 49.45878066122532, 45.105335265398026, 40.298813581466675, 38.39294984936714, 34.89959590137005, 42.104567885398865, 51.40853203833103, 49.33613084256649, 53.7770589441061, 49.449790343642235, 54.5472776144743, 51.54660142958164, 51.479056254029274, 31.97803147137165, 10.115525554865599, 3.475523879751563, 6.077956259250641, 6.683968640863895, 8.346718568354845, 1.2723675440065563, 1.208823078777641, 0.06458408053731546, 4.210821473971009, 35.59282690286636, 34.171326979994774, 21.621882878243923, 45.135330855846405, 46.634589806199074, 33.038364574313164, 2.9681007703766227, 0.1063424073799979, 0.07224301487440243, 0.06658763435552828, 0.04615413061401341, 0.04684051702497527, 0.10775784627185203, 0.04172538661805447, 0.022751587166567333, 0.03905995581590105, 0.04667806460929569, 0.04058013029862195, 0.09687034689704888, 0.029900905392423738, 0.014048336015548557, 0.046982582643977366, 0.03887900908011943, 0.023358882899628952, 0.03899418668879662, 0.0533650452416623, 0.050043485389323905, 0.012356304250715766, 0.03644417469331529, 0.026895411392615642, 0.0392949197703274, 0.06160662116599269, 0.016955092833086383, 0.08451679415884428, 0.03606079233577475, 0.027519572431629058, 0.05341567826690152, 0.03211402130546048, 0.01062190420270781, 0.07901793258497491, 0.025283531576860696, 0.014654044480266748, 0.014439303122344427, 1.9168719789013267, 21.847062595188618, 47.92039141058922, 42.13381491601467, 25.058053694665432, 29.236771166324615, 43.44289027154446, 52.11592108011246, 42.27480635046959, 3.0515594920143485, 0.1514160563237965, 1.8378957104869187, 2.3617946170270443, 3.1758489226922393, 2.018998861312866, 5.971413776278496, 24.997925721108913, 45.9455955773592, 49.66244973242283, 43.94821375608444, 48.578850477933884, 49.385904371738434, 50.994635447859764, 52.88332410156727, 52.73663677275181, 51.767586171627045, 52.42649361491203, 53.445758521556854, 50.74889503419399, 46.68993763625622, 47.14771427214146, 49.34018522500992, 48.90306048095226, 49.27516311407089, 47.441275119781494, 47.092951610684395, 49.3435138463974, 49.59102116525173, 46.533317640423775, 39.59525853395462, 37.08243437111378, 39.39753994345665, 39.18230049312115, 39.69871558248997, 41.57611884176731, 43.277705535292625, 45.703719556331635, 42.15320147573948, 41.854130923748016, 38.66080887615681, 39.24709461629391, 39.24269825220108, 38.886843547225, 37.51609370112419, 37.868391796946526, 39.52373117208481, 39.40953969955444, 47.392740324139595, 49.55188326537609, 49.917986020445824, 49.20165605843067, 47.444850727915764, 47.31917627155781, 46.275341883301735, 47.857523784041405, 46.88993990421295, 51.18605397641659, 49.6475887298584, 52.228965014219284, 43.327380269765854, 49.97849017381668, 53.30308757722378, 50.45822583138943, 53.59629884362221, 50.296419113874435, 49.88052763044834, 49.90542769432068, 50.64886920154095, 47.86653310060501, 50.905051454901695, 48.955258280038834, 42.648774683475494, 36.08805812895298, 37.29730524122715, 37.09990203380585, 36.3938657194376, 38.954259529709816, 37.48702146112919, 38.42190809547901, 38.89700040221214, 38.52261409163475, 37.908301055431366, 37.651465237140656, 37.03443914651871, 37.67948493361473, 38.434979394078255, 36.5273829549551, 39.777888134121895, 51.528149619698524, 50.71621298789978, 50.54913975298405, 48.90489958226681, 47.72943265736103, 49.68522951006889, 50.63174732029438, 48.36296506226063, 51.72188602387905, 52.06813484430313, 53.18620204925537, 50.364986434578896, 52.684195786714554, 47.942924201488495, 42.99690060317516, 38.09027709066868, 38.61052617430687, 44.63432013988495, 52.74141311645508, 51.58138856291771, 54.34984780848026, 52.380497083067894, 56.947437822818756, 53.35450641810894, 51.96669168770313, 34.67208310961723, 12.365473173558712, 2.893572044558823, 7.376229269430041, 7.28695590980351, 8.969121370464563, 6.601599035784602, 2.3755261301994324, 0.10007577177020721, 4.9849501345306635, 39.5855538547039, 43.49449910223484, 29.38492711633444, 49.47309449315071, 50.57663507759571, 38.542357832193375, 4.762123441323638, 0.12061184403137304, 0.03969353099819273, 0.07140631758375093, 0.024071747284324374, 0.03743253357242793, 0.03908505525032524, 0.09817182159167714, 0.0070810016768518835, 0.032302341278409585, 0.05531769886147231, 0.014674126068712212, 0.09604947219486348, 0.0490761663968442, 0.03975017913035117, 0.03833743052382488, 0.02055197091976879, 0.0940248636470642, 0.12494430178776383, 0.12341792666120455, 0.23465274221962318, 0.1834150150534697, 0.1853797768126242, 0.0927182829764206, 0.1847137586446479, 0.19461307354504243, 0.11125869787065312, 0.18593076209072024, 0.11143003008328378, 0.13137584261130542, 0.0926687075116206, 0.09300831428845413, 0.19977226154878736, 0.15387669147457927, 0.11700038274284452, 0.1780883688479662, 0.2841418358730152, 2.1074991999194026, 24.569422714412212, 55.327789932489395, 47.73681566119194, 30.620863996446133, 38.89532469213009, 53.33461828529835, 56.62592947483063, 47.88569167256355, 3.809077343903482, 0.401982864132151, 4.622973008081317, 10.119825974106789, 7.6676807552576065, 1.9017673144116998, 6.819440871477127, 28.589549995958805, 47.434560880064964, 50.60707904398441, 44.55549716949463, 48.45722280442715, 51.72271817922592, 50.83936057984829, 55.336613059043884, 54.1496479511261, 53.11855807900429, 53.65063592791557, 53.61603118479252, 51.207488626241684, 46.850600615143776, 47.892949283123016, 51.58376723527908, 48.76381315290928, 49.49221506714821, 49.94765482842922, 49.55919027328491, 51.995231956243515, 51.62075065076351, 47.97746054828167, 41.00344777107239, 39.98162940144539, 41.300344839692116, 41.03504307568073, 41.86895772814751, 43.50996807217598, 45.79954281449318, 47.86152496933937, 45.28508082032204, 43.33019591867924, 39.503816440701485, 40.60005381703377, 41.729524210095406, 40.74663855135441, 38.979376181960106, 38.02595794200897, 39.928888231515884, 43.44224810600281, 50.82831837236881, 50.33630557358265, 53.035239949822426, 51.55160576105118, 50.82589030265808, 50.355597138404846, 48.17238248884678, 49.82893779873848, 49.674365893006325, 53.796346709132195, 52.12665930390358, 52.70372673869133, 46.222672909498215, 50.43159306049347, 53.940499573946, 52.30738140642643, 57.52116523683071, 52.34284870326519, 51.034039333462715, 50.365867987275124, 51.763907968997955, 50.416359677910805, 51.77827499806881, 50.160998180508614, 44.56511065363884, 38.32563266158104, 39.47333447635174, 38.358736485242844, 36.821034997701645, 40.74536181986332, 38.362631276249886, 41.19590364396572, 41.9732279330492, 39.53562833368778, 40.667374804615974, 39.05724160373211, 37.712664753198624, 38.27613651752472, 41.663373559713364, 38.38264100253582, 41.33471019566059, 53.926105946302414, 54.73989687860012, 53.67749288678169, 50.00649847090244, 49.52763296663761, 50.07018305361271, 50.93589819967747, 50.441149547696114, 53.22210252285004, 51.74303948879242, 55.48951305449009, 51.80569052696228, 54.326156079769135, 49.89649437367916, 45.29031693935394, 42.387462705373764, 40.945143699645996, 45.32000854611397, 55.24061121046543, 53.95777724683285, 57.76620268821716, 54.6722225099802, 58.04889231920242, 55.93134954571724, 55.34927777945995, 36.6766731441021, 13.446967341005802, 5.414903713390231, 11.389656085520983, 15.760230012238026, 17.2007118165493, 8.618094306439161, 3.257006867788732, 0.16813864727737382, 5.205913977697492, 45.23161008954048, 46.07986897230148, 34.09902825951576, 56.68593965470791, 56.87187887728214, 47.10656248033047, 6.338753839954734, 0.21729350730311126, 0.17480988695751876, 0.20012562774354592, 0.10788489453261718, 0.12192373105790466, 0.22337159287417307, 0.19547607254935429, 0.14724083739565685, 0.12366984869004227, 0.14622313028667122, 0.15331121947383508, 0.2141943431342952, 0.14990767085691914, 0.1636653669993393, 0.12166335596702993, 0.2100824739318341], [0.01973366775928298, 0.021924188986304216, 0.08351403390406631, 0.052139254767098464, 0.0598220565734664, 0.008974861430033343, 0.020812540824408643, 0.02419820553768659, 0.04599197876814287, 0.03759755752980709, 0.07289456858416088, 0.03597248418373056, 0.10980848936014809, 0.082443404244259, 0.056970009027281776, 0.06094836586271413, 0.03768029957427643, 0.022517218785651494, 0.02973019658384146, 0.058596362578100525, 0.441607553511858, 5.915058050304651, 35.07888548076153, 39.32738430798054, 30.640888921916485, 24.70415398478508, 32.801922261714935, 39.24123153090477, 45.45683540403843, 4.9167547188699245, 0.05128733973833732, 1.5216498426161706, 1.1878569913096726, 1.5646761213429272, 0.6308352027554065, 3.7518915999680758, 23.157179094851017, 44.15657177567482, 50.93869864940643, 49.41236615180969, 48.754378259181976, 51.0978265106678, 47.9310954362154, 47.39478461444378, 47.719154208898544, 48.42183530330658, 48.15071605145931, 48.02265912294388, 49.56553213298321, 46.43264204263687, 48.06857965886593, 47.37768933176994, 46.361069083213806, 50.030091404914856, 50.27790650725365, 47.14305192232132, 46.40417777001858, 44.97072748839855, 40.08347533643246, 36.59981846809387, 36.00374065339565, 35.79459227621555, 36.73933558166027, 38.0374713242054, 40.06259545683861, 43.29545818269253, 44.72255140542984, 41.27689629793167, 37.496030777692795, 36.70236736536026, 34.96920436620712, 36.75874873995781, 35.771671906113625, 36.14697016775608, 36.84771716594696, 34.74622093141079, 39.612232223153114, 47.18598581850529, 50.30484326183796, 49.812298491597176, 49.62325483560562, 50.59879168868065, 49.924529269337654, 47.9018560051918, 45.99884212017059, 46.42562761902809, 47.99924097955227, 48.972292765975, 52.25595496594906, 42.2417139261961, 44.316565990448, 49.764576852321625, 49.807088971138, 49.7404595464468, 49.084546342492104, 47.81713955104351, 48.43731947243214, 49.898496866226196, 48.40091362595558, 45.93205690383911, 44.299789890646935, 38.770740777254105, 34.768187552690506, 36.20700314640999, 36.78323842585087, 35.23495830595493, 36.676878333091736, 36.72166272997856, 37.548726350069046, 38.06553281843662, 36.238393262028694, 37.12229423224926, 36.61131665110588, 35.732526406645775, 36.4695880562067, 36.48709751665592, 35.276668667793274, 35.754728615283966, 42.02018201351166, 47.2308424115181, 50.11434428393841, 47.456041127443314, 49.49373498558998, 47.9979794472456, 50.879007652401924, 49.861904829740524, 49.65734280645847, 47.51371443271637, 46.83144584298134, 48.72572019696236, 50.90158224105835, 49.65342901647091, 46.11240282654762, 40.04881739616394, 35.88897541165352, 36.97497993707657, 45.506620332598686, 48.961854726076126, 51.29081815481186, 49.8812647908926, 51.84628374874592, 51.567751094698906, 47.83988133072853, 28.690265491604805, 8.231977075338364, 1.9537029275670648, 4.302230793982744, 3.4041829453781247, 5.719612212851644, 4.1544809471815825, 1.1650345847010612, 0.09387532831169665, 2.055489015765488, 26.02975845336914, 30.438796766102314, 33.45019027590752, 37.25903369486332, 49.59856376051903, 19.786632657051086, 2.1291046030819416, 0.03567536907212343, 0.03466217422101181, 0.059801157694892026, 0.018725944391917437, 0.04835292864299845, 0.039800426238798536, 0.04644228800316341, 0.06337632425129414, 0.0430121519457316, 0.045490836128010415, 0.027729331195587292, 0.05823137063998729, 0.07947384132421575, 0.031776659525348805, 0.018857829600165132, 0.08411014918237925, 0.024312049135915004, 0.06825494332588278, 0.012876106338808313, 0.002784343037092185, 0.05829480942338705, 0.02691687801416265, 0.05466374430397991, 0.020804900414077565, 0.05685564407031052, 0.03217771984054707, 0.04571848621708341, 0.07435693347360939, 0.05715446612157393, 0.0366006008698605, 0.10545218639890663, 0.04318726911151316, 0.06555369647685438, 0.030741710470465478, 0.0245454749892815, 0.06710242509143427, 0.5674896331038326, 9.81290789321065, 42.00902961194515, 43.731959760189056, 30.41486755013466, 30.064894929528236, 41.63702577352524, 45.425008311867714, 48.11076879501343, 5.0175761338323355, 0.03804767009569332, 2.087553832679987, 3.640796011313796, 3.9795186230912805, 1.6479773889295757, 4.108871044591069, 25.027168951928616, 44.044857770204544, 51.432949528098106, 48.641193732619286, 47.55159839987755, 49.6619975566864, 47.14396007359028, 48.6636733263731, 48.98768573999405, 49.38731789588928, 49.34957452118397, 51.481252536177635, 51.253846138715744, 47.0509372651577, 48.75495582818985, 47.64501638710499, 49.25833001732826, 50.79502835869789, 52.41848364472389, 49.785886108875275, 49.29287776350975, 46.50942452251911, 40.82225829362869, 38.85993339121342, 37.310061156749725, 38.901358768343925, 37.96343229711056, 38.63093487918377, 42.71968647837639, 45.445299223065376, 46.14639200270176, 43.04550759494305, 39.92446906864643, 38.509592190384865, 38.355829641222954, 38.12846504151821, 39.06129978597164, 38.050348833203316, 39.02661144733429, 37.28043794631958, 40.5247912555933, 48.35115149617195, 50.66758319735527, 51.48406058549881, 51.539093032479286, 51.87004007399082, 50.55669754743576, 49.071171060204506, 48.33403721451759, 48.91875363886356, 49.424229115247726, 50.98320186138153, 53.33024092018604, 43.82995270192623, 45.236739814281464, 49.79859262704849, 51.53063088655472, 51.36517256498337, 50.66857494413853, 49.50286589562893, 51.43067345023155, 50.605802312493324, 49.400491788983345, 46.93812131881714, 48.34827125072479, 41.424461379647255, 36.45611397922039, 38.22394251823425, 37.370542511343956, 37.88959465920925, 39.47850979864597, 38.14344763755798, 38.39510813355446, 40.063313618302345, 39.01671677827835, 39.79390807449818, 38.13293360173702, 37.78471648693085, 37.65992358326912, 38.978680819272995, 37.53191985189915, 38.14574271440506, 45.645229294896126, 49.37168553471565, 52.27552771568298, 50.329887717962265, 51.1637681722641, 51.01349003612995, 51.336510702967644, 50.71609899401665, 50.00143714249134, 47.403459548950195, 47.74918779730797, 50.9709969162941, 52.90927670896053, 51.13441474735737, 47.803319692611694, 41.83175012469292, 37.743348106741905, 39.36966463923454, 48.377636075019836, 51.31256818771362, 54.267228841781616, 52.53257252275944, 53.92464302480221, 54.31408032774925, 49.495486691594124, 31.72068078070879, 9.303557574748993, 2.989833941683173, 4.919529045000672, 7.409906387329102, 9.830514248460531, 6.444687405601144, 1.6742805275134742, 0.09561868515447713, 2.6364049315452576, 34.33742366731167, 36.62169769406319, 31.881668642163277, 43.937840312719345, 53.82405482232571, 28.66257067769766, 2.166991182602942, 0.025945178495021537, 0.03342031624924857, 0.025005999887071084, 0.026623930061759893, 0.03246628912165761, 0.051505761221051216, 0.01703091991657857, 0.04151044580794405, 0.02454964029311668, 0.025330858334200457, 0.012571804454637459, 0.018770493661577348, 0.013995647241245024, 0.029929697011539247, 0.05134954284585547, 0.006349403629428707, 0.12352489240583964, 0.15549780917353928, 0.1348459767177701, 0.17977815004996955, 0.22653075226116925, 0.1437989345868118, 0.15440228045918047, 0.17134240973973647, 0.19721165910596028, 0.11317233307636343, 0.1722481267643161, 0.14846468344330788, 0.20788527152035385, 0.27184130216483027, 0.25991202041041106, 0.18466489564161748, 0.19830263103358448, 0.18484485161025077, 0.16496794007252902, 0.1422337896656245, 0.8577426988631487, 11.862278524786234, 49.281588569283485, 51.71402424573898, 41.81365169584751, 38.14546152949333, 44.93885859847069, 49.68858852982521, 54.636869207024574, 6.175657566636801, 0.14510458015138283, 4.737935364246368, 5.281094368547201, 4.1546049155294895, 1.496403522323817, 5.2118706330657005, 27.056201174855232, 48.60447250306606, 49.70484785735607, 49.34202432632446, 48.45337741076946, 50.365465208888054, 49.34320226311684, 49.120511412620544, 48.79263460636139, 50.6511452794075, 50.35681687295437, 51.648956537246704, 50.85798718035221, 47.68483445048332, 49.949406534433365, 48.942198380827904, 50.049367770552635, 53.50400559604168, 53.552092015743256, 51.00786633789539, 51.215791180729866, 49.37211111187935, 43.69972988963127, 40.47139652073383, 38.990266397595406, 39.49060074985027, 39.3402998149395, 41.96965612471104, 44.449178874492645, 49.487666711211205, 47.553893476724625, 45.73520086705685, 41.6040663421154, 41.155192628502846, 38.49050961434841, 40.744491666555405, 40.22849075496197, 40.39224296808243, 41.98993943631649, 38.10200326144695, 42.866172417998314, 50.51108859479427, 54.55281771719456, 51.37776888906956, 53.41470278799534, 53.34811136126518, 52.90440157055855, 52.267631739377975, 50.13211973011494, 52.385402619838715, 51.88420191407204, 53.64949218928814, 54.89519074559212, 45.185358971357346, 45.65643109381199, 49.980595260858536, 52.951777428388596, 51.63586623966694, 51.25349275767803, 50.98090298473835, 54.32975448668003, 51.89729981124401, 51.575107499957085, 49.65858913958073, 48.30859757959843, 42.842617481946945, 37.56829150021076, 39.77776274085045, 40.85994467139244, 40.438513085246086, 41.19187965989113, 40.0736528635025, 40.52543342113495, 42.23690338432789, 40.7190178334713, 41.03567384183407, 39.96156267821789, 39.01275359094143, 39.90990065038204, 39.75610390305519, 39.57679532468319, 40.230983421206474, 45.82622118294239, 51.418962478637695, 54.330187663435936, 50.96900962293148, 53.67031887173653, 52.07112528383732, 55.095907375216484, 52.29059010744095, 52.055815905332565, 48.35430532693863, 50.389742106199265, 50.33629037439823, 54.59237739443779, 52.88001447916031, 49.74196806550026, 43.81498910486698, 41.100422367453575, 42.001023441553116, 49.57365229725838, 52.95686535537243, 57.7250736951828, 55.11849716305733, 56.24461993575096, 55.46567313373089, 51.43408566713333, 31.865185126662254, 9.988308381289244, 3.6834036000072956, 11.407679468393326, 12.031774129718542, 15.701084285974503, 13.985384199768305, 3.8426753785461187, 0.22364041360560805, 2.7327960217371583, 37.2210281342268, 40.42968235909939, 45.04179127514362, 47.06519789993763, 62.512622997164726, 34.233883023262024, 3.375060595571995, 0.13209572585765272, 0.16991557145956904, 0.13169449113775045, 0.31796569121070206, 0.10491474531590939, 0.11273045092821121, 0.12267313693882897, 0.20663228875491768, 0.156547102087643, 0.16869813756784424, 0.10850370468688197, 0.14735211501829326, 0.14973399345763028, 0.06860800524009392, 0.30249158560764045, 0.22030382155207917], [0.095159035990946, 0.08381674109841697, 0.036520782887237146, 0.00886627409272478, 0.046483558835461736, 0.03546171588823199, 0.012525089969130931, 0.028780991560779512, 0.06792968968511559, 0.03159029882226605, 0.015125185800570762, 0.02274151807796443, 0.08780347678111866, 0.05013587906432804, 0.02687340856937226, 0.045669433966395445, 0.08161617675796151, 0.06013015175994951, 0.04103512619622052, 0.07442588641424663, 0.12436462508048862, 2.7588818594813347, 30.578908547759056, 47.14627794921398, 33.67627054452896, 23.576849475502968, 35.64947806298733, 41.72793209552765, 46.1663219332695, 8.585493005812168, 0.016209720524784643, 0.540857455926016, 2.0333015313372016, 2.5168954068794847, 11.264641843736172, 10.096386931836605, 18.867372684180737, 45.675661861896515, 51.16835832595825, 47.44792476296425, 48.94603617489338, 49.19252134859562, 46.02566488087177, 50.50054036080837, 50.33535562455654, 51.75858825445175, 50.78587085008621, 50.00720143318176, 50.03259927034378, 47.9404429346323, 50.74148163199425, 48.62630233168602, 49.753652438521385, 49.86192382872105, 47.132697477936745, 45.873612239956856, 44.400248900055885, 40.465712025761604, 38.89278642833233, 36.15121454000473, 36.45257256925106, 37.440181374549866, 38.301017582416534, 37.84952960908413, 41.585880517959595, 44.7633346170187, 44.262745678424835, 42.014657109975815, 37.39818602800369, 34.99130018055439, 38.40132459998131, 36.81802935898304, 36.20827607810497, 35.45316159725189, 36.581666842103004, 36.27729557454586, 35.83421654999256, 46.27986744046211, 50.32896816730499, 49.29851286113262, 47.268855571746826, 49.47792403399944, 52.02620789408684, 47.598252296447754, 49.245950281620026, 45.41755311191082, 49.172606617212296, 49.47927676141262, 53.08957323431969, 40.280779749155045, 44.054402858018875, 46.910986974835396, 50.25177910923958, 49.60984915494919, 49.67662677168846, 49.02133673429489, 51.166302636265755, 49.827091097831726, 48.95002596080303, 44.036600813269615, 41.21147520840168, 40.22848315536976, 35.35765752196312, 36.22684568166733, 35.17461374402046, 33.96011911332607, 36.625178307294846, 36.57724387943745, 38.01349461078644, 36.37976847589016, 37.88250043988228, 37.664901316165924, 37.076662480831146, 37.47537508606911, 36.228703781962395, 35.92167265713215, 37.065221294760704, 35.46168453991413, 36.430073976516724, 40.920171439647675, 43.97459574043751, 45.40122538805008, 46.304360926151276, 47.41921730339527, 45.84650069475174, 46.68628603219986, 47.023312747478485, 47.69075073301792, 47.45480619370937, 46.46586365997791, 50.59954784810543, 49.523426592350006, 47.56280019879341, 47.78189264237881, 41.89191609621048, 36.98504939675331, 37.661857679486275, 44.791456907987595, 48.621522188186646, 47.234486415982246, 51.01516954600811, 48.3529108017683, 46.52083531022072, 23.87341596186161, 3.803112613968551, 1.7241803999058902, 3.552051060833037, 6.317697744816542, 6.294490490108728, 4.077539825811982, 1.5040852851234376, 0.009607386473362567, 6.01878915913403, 27.539550438523293, 30.50770416855812, 24.385434687137604, 36.54257073998451, 41.30146957933903, 10.900036208331585, 0.8589801262132823, 0.053755834233015776, 0.05368339319829829, 0.06405850639566779, 0.024262518199975602, 0.06203172335517593, 0.06209716222656425, 0.040734044305281714, 0.14213496528100222, 0.07359864408499561, 0.0693955723545514, 0.01909180464281235, 0.03964033014199231, 0.02247589043690823, 0.04312973040214274, 0.01671873364102794, 0.052632701335824095, 0.04612055214238353, 0.06530601211125031, 0.052211565925972536, 0.06110924492531922, 0.018421971835778095, 0.04332044751208741, 0.025126476430159528, 0.024406047705269884, 0.03879729119944386, 0.028148511046310887, 0.03960645481129177, 0.04300364322261885, 0.042873322090599686, 0.04778432848979719, 0.060126871467218734, 0.02261233614262892, 0.021729308427893557, 0.045944896919536404, 0.06141195583040826, 0.10423196203191765, 0.22218886180780828, 4.335622452199459, 36.88160374760628, 51.92629225552082, 38.68178755044937, 28.079400770366192, 37.8139179199934, 46.36987321078777, 51.327174603939056, 8.97146014496684, 0.17065185616957024, 0.1571468761540018, 6.045075198635459, 4.38557124696672, 11.88734482973814, 9.840084034949541, 20.882900431752205, 48.39102275669575, 50.98972991108894, 47.72182546555996, 50.243449956178665, 49.371860325336456, 46.75079897046089, 49.74599964916706, 51.13833613693714, 52.24217310547829, 51.41683839261532, 51.922686249017715, 49.687725976109505, 49.287170469760895, 50.958921164274216, 50.59178866446018, 50.29301829636097, 52.18184374272823, 49.34942252933979, 46.88680127263069, 46.55772753059864, 42.39731177687645, 40.371180698275566, 37.93000549077988, 39.13268655538559, 38.274734392762184, 40.27835547924042, 39.36750255525112, 42.940572425723076, 47.64985352754593, 47.26907975971699, 44.474956691265106, 40.407951325178146, 37.15183764696121, 40.07831521332264, 37.878845036029816, 39.18608509004116, 37.86031723022461, 37.29659467935562, 37.87275776267052, 38.787513077259064, 48.09637516736984, 51.93572334945202, 51.055048406124115, 49.91683088243008, 49.63925197720528, 52.47381627559662, 49.22703109681606, 49.97325025498867, 47.613310888409615, 49.77575205266476, 51.34689174592495, 53.160386234521866, 42.580439150333405, 43.4355528652668, 48.70960906147957, 50.04995673894882, 50.6275637447834, 50.42738288640976, 49.76142302155495, 51.87407165765762, 51.93857699632645, 50.98085358738899, 46.647512912750244, 43.71126987040043, 41.749925315380096, 36.260055899620056, 37.78342455625534, 36.85338646173477, 35.138565078377724, 37.669738456606865, 38.43914397060871, 40.182053446769714, 38.662925362586975, 39.317922815680504, 39.75180633366108, 38.740084022283554, 38.94507922232151, 36.73710510134697, 38.01533751189709, 38.203115835785866, 36.964686289429665, 39.34286467730999, 43.55490446090698, 46.89073406159878, 48.61339822411537, 48.34696412086487, 48.58227789402008, 48.56409206986427, 49.63407665491104, 49.45262499153614, 49.03804823756218, 47.81024672091007, 47.78004594147205, 50.65921604633331, 52.50660851597786, 49.35465484857559, 48.60080569982529, 42.79520362615585, 38.389883413910866, 39.69127558171749, 47.18369074165821, 49.68787796795368, 50.94214506447315, 53.17667216062546, 51.69048450887203, 46.269159615039825, 27.698066532611847, 4.182311128824949, 2.2282241843640804, 5.345606356859207, 7.351855002343655, 9.187081474810839, 4.904990075156093, 1.5288958163000643, 0.023124507097236346, 5.253648916259408, 30.34875299781561, 33.88456776738167, 31.10934678465128, 40.49842067062855, 50.44056437909603, 16.451578214764595, 1.2582142534665763, 0.0418446274852613, 0.02290881486260332, 0.017708114828565158, 0.03133671067189425, 0.01547883864986943, 0.10855052678380162, 0.03998730273451656, 0.019775354194280226, 0.06666823159321211, 0.022076839486544486, 0.05778774073405657, 0.010575026444712421, 0.003857914848595101, 0.06447355248383246, 0.04057102785736788, 0.0054023958273319295, 0.13412354048341513, 0.16301131225191057, 0.18746907095192, 0.13727357145398855, 0.119583249615971, 0.1551750343060121, 0.08456452167592943, 0.1317091114469804, 0.14167256274959072, 0.0960466149263084, 0.05999504748615436, 0.13687193597434089, 0.1847879437264055, 0.13019150850595906, 0.20484297070652246, 0.1134052115958184, 0.14237325405701995, 0.22254390525631607, 0.13866653811419383, 0.1571999693987891, 0.39373935491312295, 5.779600068926811, 44.114625826478004, 60.688800662755966, 44.98939588665962, 36.63185454905033, 47.144043669104576, 51.430855840444565, 55.06561540067196, 10.84768071770668, 0.25442538200877607, 2.135740709491074, 7.517970213666558, 4.942593807354569, 18.38260419666767, 15.83724807947874, 22.65809677541256, 51.50493286550045, 51.70061096549034, 49.284066036343575, 50.80914460122585, 49.85563516616821, 45.70705197751522, 50.545142367482185, 52.64259561896324, 54.70842316746712, 53.60909655690193, 53.17086987197399, 52.59653069078922, 50.60767561197281, 53.006289303302765, 53.76395344734192, 51.97834946215153, 54.57607626914978, 52.381861209869385, 49.935772866010666, 48.7407635897398, 45.26955485343933, 41.7874027043581, 39.21019099652767, 40.214853286743164, 40.64697749912739, 41.079857870936394, 41.416641399264336, 44.97360773384571, 51.55771963298321, 48.11327666044235, 47.75203764438629, 42.74231046438217, 38.79689857363701, 42.86513887345791, 39.78057838976383, 41.06183923780918, 40.03365620970726, 39.84993226826191, 39.842621460556984, 39.81374680995941, 48.977221101522446, 54.40887004137039, 51.42389461398125, 49.38813865184784, 51.35984905064106, 53.669201731681824, 50.43475829064846, 52.22350090742111, 49.37372222542763, 52.532116547226906, 53.724169582128525, 53.87227043509483, 45.127792060375214, 43.45327511429787, 48.19244921207428, 52.54381611943245, 52.754290625452995, 51.851307079195976, 51.60921826958656, 53.86107623577118, 55.25553300976753, 53.7762001901865, 48.737415969371796, 44.51420098543167, 43.48039045929909, 38.82646858692169, 39.25166957080364, 38.327756747603416, 37.445402294397354, 40.8010858297348, 39.91663008928299, 41.68003186583519, 40.038839131593704, 42.18977831304073, 41.20962470769882, 40.51255211234093, 41.01088397204876, 39.40353222191334, 40.23708589375019, 39.30401936173439, 39.0387973934412, 40.042749121785164, 44.92349602282047, 49.10282716155052, 49.100832268595695, 50.561777874827385, 51.02491222321987, 51.82535067200661, 52.19953179359436, 51.232897862792015, 50.77114284038544, 49.25391845405102, 47.86448121070862, 52.773969769477844, 54.30290512740612, 51.68019086122513, 52.26048432290554, 44.92303624749184, 41.497299671173096, 42.04489588737488, 49.64359134435654, 50.65154045820236, 53.044002279639244, 55.7340033352375, 53.37836913764477, 49.98737409710884, 30.36558609455824, 5.337435845285654, 4.572949167340994, 10.841597244143486, 15.741746854037046, 14.539705105125904, 10.535053443163633, 4.245123658329248, 0.16853008564794436, 7.886449741199613, 39.7881817817688, 44.48365822434425, 35.54847948253155, 48.590736240148544, 53.79185535013676, 22.776412926614285, 1.3026591623201966, 0.1198992709396407, 0.21961641468806192, 0.1119277291581966, 0.1343828468816355, 0.26651802530977875, 0.18076461274176836, 0.11061227982281707, 0.18268361367518082, 0.11141843773657456, 0.2834838774288073, 0.11450986872659996, 0.09721387963509187, 0.10037798914709128, 0.10565489661530592, 0.13329371548024938, 0.18359364999923855], [0.09405112083186395, 0.01295514877710957, 0.08351012278581038, 0.05097892171761487, 0.012848317546740873, 0.029901610432716552, 0.005738387417295598, 0.041721349334693514, 0.04719756427221, 0.030003533283888828, 0.061471613371395506, 0.0321295321919024, 0.04667741523007862, 0.013417560585367028, 0.13752653991105035, 0.018806925691023935, 0.022971604266786017, 0.07884890845161863, 0.03712839403306134, 0.014303770258266013, 0.07243267813464627, 1.8609888525679708, 17.90369689464569, 43.59517090022564, 35.98544843494892, 22.99082212150097, 31.08870819211006, 30.304432176053524, 44.149355962872505, 17.156107909977436, 0.08323810339788906, 0.6239256891421974, 3.2877009082585573, 6.619865130633116, 10.647100880742073, 13.368731439113617, 22.113508097827435, 46.09914913773537, 51.255115270614624, 55.98066709935665, 50.73188714683056, 49.76990036666393, 50.0586848706007, 52.739798203110695, 50.88463515043259, 51.11081801354885, 51.63610182702541, 51.29092454910278, 49.80162486433983, 50.353967025876045, 49.15133535861969, 48.89438174664974, 48.67512211203575, 47.957184836268425, 45.21199554204941, 43.58569800853729, 38.153463900089264, 35.60488745570183, 35.469645112752914, 37.23005644977093, 36.00027143955231, 36.714332923293114, 37.2490706294775, 38.58714982867241, 42.100597098469734, 42.626770064234734, 44.97106187045574, 43.0702518671751, 40.77973857522011, 34.823599979281425, 35.58354780077934, 38.17247427999973, 38.22457328438759, 37.16330923140049, 36.31487935781479, 35.39463713765144, 34.75891225039959, 40.612821131944656, 47.75848589837551, 48.63269738852978, 48.90035502612591, 43.68917405605316, 45.68371742963791, 48.30946773290634, 50.39407007396221, 50.39960637688637, 49.25764985382557, 49.621233344078064, 51.96779362857342, 40.92110998928547, 43.16152296960354, 45.08105456829071, 46.07483424246311, 48.24951454997063, 47.6838731020689, 49.57574978470802, 49.52867791056633, 47.72070832550526, 47.82079115509987, 45.55621147155762, 42.499480694532394, 38.90895836055279, 35.9014805406332, 35.88414587080479, 35.676942989230156, 35.47121062874794, 36.280130222439766, 37.79320143163204, 35.78135758638382, 36.03178694844246, 35.42285442352295, 38.491094782948494, 38.17134954035282, 37.32935652136803, 36.00044623017311, 35.49449197947979, 36.60188175737858, 35.855297818779945, 34.5744663476944, 33.132717311382294, 35.341394394636154, 38.78154739737511, 40.36736190319061, 41.23539872467518, 43.554091304540634, 46.3004357367754, 47.595664635300636, 47.63734079897404, 50.985949113965034, 50.14483384788036, 46.9228233397007, 50.59788353741169, 50.14510743319988, 48.539568185806274, 46.48411028087139, 45.6019040197134, 42.70857587456703, 44.62179981172085, 46.773954927921295, 50.95755323767662, 52.426049038767815, 52.26778373122215, 36.36328876018524, 21.2882037833333, 3.3280732668936253, 1.7435375112108886, 1.944064269773662, 5.569809526205063, 8.50737964734435, 1.8655883870087564, 1.274278366472572, 0.08696627483004704, 7.856062296777964, 40.778089463710785, 31.092040613293648, 21.69151794165373, 38.23837794363499, 37.35915072262287, 7.754676612094045, 0.18388164782663807, 0.023794412263669074, 0.030413293425226584, 0.03994290003902279, 0.017369966371916234, 0.04370292073872406, 0.03483910593786277, 0.01690304601652315, 0.015396680119010853, 0.09650838663219474, 0.13351779954973608, 0.08369839822989888, 0.04139243690588046, 0.045871520778746344, 0.025198631738021504, 0.12304714968195185, 0.01867861948994687, 0.01798498044081498, 0.02517908542358782, 0.05770748117356561, 0.0254442529330845, 0.05958066933089867, 0.028718612193188164, 0.005543929883060628, 0.028459867971832864, 0.012545448007585946, 0.010293000123056117, 0.06967484252527356, 0.018879453928093426, 0.04040592597448267, 0.0208503959220252, 0.004951461796736112, 0.04417392847244628, 0.037148561896174215, 0.028305013292992953, 0.017874708428280428, 0.09333494832389988, 0.0687215686775744, 2.7365409582853317, 25.9551190584898, 52.273608818650246, 39.506844878196716, 28.652645610272884, 38.94675873219967, 39.60860721766949, 47.227076813578606, 16.89788706600666, 0.16544810961931944, 0.34463503514416516, 5.408701971173286, 7.756810672581196, 16.33685477077961, 16.928530521690845, 24.510153494775295, 48.047095611691475, 48.85877765715122, 54.09229762852192, 50.09951747953892, 50.46904765069485, 48.850881680846214, 53.89345809817314, 52.13301636278629, 53.740504905581474, 53.631522953510284, 53.99449087679386, 52.11652144789696, 50.85867114365101, 50.60470037162304, 50.47011539340019, 50.69147251546383, 50.14012210071087, 47.599589824676514, 46.523198783397675, 40.80943778157234, 38.11793200671673, 36.86672754585743, 39.751965925097466, 36.52093470096588, 38.91172841191292, 38.91784228384495, 40.091378912329674, 44.63725358247757, 45.43070040643215, 47.04627871513367, 44.02362830936909, 42.19827465713024, 37.773480489850044, 37.09669500589371, 39.182083904743195, 39.22420844435692, 37.30315312743187, 38.93886275589466, 37.15871907770634, 36.56386859714985, 43.17379631102085, 49.73667494952679, 50.690473169088364, 50.11437088251114, 46.815346106886864, 49.85775925219059, 49.78149354457855, 52.69365347921848, 51.62470243871212, 51.265826895833015, 51.280756294727325, 52.938588336110115, 42.41974577307701, 43.45237836241722, 44.476765394210815, 48.45664903521538, 49.328519850969315, 49.57919619977474, 51.19562566280365, 51.5018018335104, 50.699007511138916, 48.33222471177578, 47.2570876032114, 45.149591490626335, 42.29881726205349, 37.19889432191849, 38.24633851647377, 35.436073914170265, 36.74541525542736, 38.01891691982746, 39.65404897928238, 37.833524867892265, 38.10665801167488, 38.42496693134308, 39.549539387226105, 39.36903767287731, 39.1495044529438, 37.25947447121143, 36.90941445529461, 36.05992443859577, 37.76570610702038, 37.4346374720335, 36.959583163261414, 37.57928431034088, 40.797400027513504, 43.108303025364876, 44.72837269306183, 46.820304840803146, 48.10188107192516, 50.28848893940449, 48.753690496087074, 54.487541019916534, 50.78423693776131, 47.427272871136665, 50.676805302500725, 51.99037581682205, 49.75904814898968, 46.761898174881935, 46.150925159454346, 43.44341084361076, 46.42090827226639, 49.09902736544609, 53.25340524315834, 53.261194825172424, 52.297429740428925, 41.367282047867775, 25.306776948273182, 4.726837109774351, 1.6476351697929204, 6.5088526625186205, 7.468335377052426, 8.639026433229446, 4.339854950085282, 1.3016839209012687, 0.04349185765022412, 8.663689959794283, 40.878255888819695, 36.10043026506901, 24.404977038502693, 42.812587693333626, 41.89381219446659, 12.259818892925978, 0.24564080260461196, 0.028433085717551876, 0.04020098931505345, 0.026381887873867527, 0.02102157970512053, 0.018085834599332884, 0.021634298682329245, 0.03541796999343205, 0.017140210438810755, 0.11746321571990848, 0.04264116345439106, 0.03781682135013398, 0.09502190936473198, 0.029630967728735413, 0.07194748424808495, 0.03874994959915057, 0.015733424988866318, 0.1813372242031619, 0.18646965036168694, 0.1943278661929071, 0.13731845654547215, 0.12576547334901989, 0.11680158364470117, 0.08888863027095795, 0.13078270334517583, 0.08991200738819316, 0.11427080811699852, 0.23187762941233814, 0.09615961433155462, 0.12615783198270947, 0.12381689040921628, 0.2531478489981964, 0.1636681129457429, 0.13616593088954687, 0.16282038734061643, 0.09231351563357748, 0.15423854783875868, 0.14981628279201686, 3.759591174311936, 29.416944198310375, 56.56592309474945, 46.05708919465542, 35.50143040716648, 41.49108700454235, 41.96666568517685, 55.233847573399544, 20.571252554655075, 0.2782186365220696, 1.5664497949182987, 8.839730713516474, 14.162308406084776, 21.116513796150684, 19.75915253162384, 28.469736725091934, 51.79582625627518, 49.5470879226923, 54.1866085678339, 51.57725438475609, 51.45702123641968, 50.51873758435249, 56.74128368496895, 55.292957201600075, 56.52703978121281, 55.76185584068298, 54.664413928985596, 53.956367522478104, 53.809167221188545, 52.8860979527235, 51.718458607792854, 51.85360215604305, 53.55232000350952, 47.62584641575813, 48.87080401182175, 41.4046074450016, 39.69544395804405, 38.47835786640644, 42.66722649335861, 38.057465851306915, 40.44475995004177, 40.58523081243038, 43.55059929192066, 46.1654631793499, 47.55460023880005, 49.27509091794491, 47.197381407022476, 44.64050240814686, 39.719200283288956, 37.66226805746555, 43.41984450817108, 42.04857029020786, 38.89790095388889, 39.89711053669453, 38.81073743104935, 38.379908949136734, 45.38196802139282, 51.39223091304302, 53.784814327955246, 50.95031462609768, 47.87483565509319, 50.30708894133568, 50.68039231002331, 54.202012941241264, 54.36978153884411, 53.40144529938698, 52.85828344523907, 53.36250878870487, 44.983232617378235, 43.810421749949455, 45.5621125549078, 48.134673312306404, 49.69882518053055, 51.09641298651695, 53.00385743379593, 53.149237632751465, 52.09557697176933, 52.19692513346672, 49.1418244689703, 46.889077350497246, 43.841249495744705, 40.71647956967354, 40.89000105857849, 38.71130436658859, 40.40157146751881, 40.1866739988327, 41.11518457531929, 38.59930917620659, 39.69933494925499, 39.806177616119385, 42.65153333544731, 40.780532732605934, 40.56884989142418, 38.5294309258461, 39.58362355828285, 38.816421926021576, 38.62159878015518, 39.868441075086594, 36.77561603486538, 38.48956346511841, 41.48129492998123, 44.50288899242878, 45.60531243681908, 47.62528404593468, 50.90139985084534, 53.87315198779106, 51.063761338591576, 55.67883029580116, 50.991652607917786, 46.35990634560585, 52.54182122647762, 53.572979494929314, 52.46172532439232, 49.03277412056923, 50.526439771056175, 45.95596142113209, 49.43967528641224, 53.340002596378326, 55.76874107122421, 56.92777007818222, 55.74332423508167, 43.41984070837498, 27.079946100711823, 5.467062089592218, 4.238246502354741, 7.536399699747562, 12.793581951409578, 20.017671659588814, 8.449434656649828, 2.8211921034380794, 0.22562059719348326, 10.053654424846172, 50.372772216796875, 42.502843514084816, 32.9963768273592, 47.14391827583313, 50.766586884856224, 16.421867609024048, 0.3948021400719881, 0.23155647242674604, 0.1398089705617167, 0.09233412507455796, 0.09098579859710298, 0.15298733138479292, 0.1125548587879166, 0.10780498007079586, 0.0972848957462702, 0.19797973742242903, 0.21058838116005063, 0.12443029772839509, 0.21650653390679508, 0.1594140037195757, 0.16143822635058314, 0.24897206603782251, 0.06799037510063499], [0.030043432998354547, 0.03539390585501678, 0.02685260431462666, 0.029480076118488796, 0.06847383978310972, 0.03050464809348341, 0.025161656085401773, 0.04532186023425311, 0.02582503035228001, 0.04450179076229688, 0.04198401024041232, 0.019960340068791993, 0.017585265268280637, 0.04765955491166096, 0.036516352265607566, 0.022797110505052842, 0.011308651482977439, 0.020921220930176787, 0.08031338104046881, 0.1293530300608836, 0.036581371823558584, 0.590986741008237, 10.87421564385295, 40.23860581219196, 44.876249358057976, 29.926698245108128, 26.695108450949192, 37.27963238954544, 41.82311698794365, 26.84717819094658, 0.3357314597815275, 0.3389316302491352, 5.627286667004228, 6.5371867921203375, 5.366409765556455, 7.549601616337895, 23.912550061941147, 42.15700127184391, 49.531641751527786, 51.72881305217743, 47.39582195878029, 52.218462377786636, 54.293424636125565, 51.21105283498764, 49.085234105587006, 48.80289785563946, 47.646103128790855, 50.55805027484894, 48.54331478476524, 51.22714877128601, 50.30835807323456, 49.2290335893631, 46.48243457078934, 43.911215141415596, 39.03886578977108, 34.612015932798386, 37.08500683307648, 35.97610093653202, 36.76626093685627, 36.28557913005352, 35.68517714738846, 35.13850428164005, 36.06359504163265, 38.04395377635956, 40.57473197579384, 42.07729294896126, 44.51802358031273, 41.865826696157455, 41.05461202561855, 37.35894933342934, 36.97497993707657, 36.78596667945385, 36.10681012272835, 37.00135052204132, 36.306728795170784, 35.06214737892151, 35.631501227617264, 37.47712679207325, 45.10926805436611, 46.043588519096375, 50.3259739279747, 44.32584889233112, 43.72740760445595, 47.28203326463699, 45.0275344401598, 50.88317982852459, 50.66163271665573, 49.33677680790424, 51.210251078009605, 40.82711823284626, 43.88531193137169, 45.35664238035679, 46.18017598986626, 46.60435862839222, 47.73859016597271, 48.90076540410519, 49.62638966739178, 48.769049271941185, 45.38903944194317, 44.20067600905895, 41.229110062122345, 37.75005854666233, 35.98291017115116, 34.39057141542435, 34.960107654333115, 35.1328843832016, 35.73716975748539, 37.48191453516483, 36.90986283123493, 38.720602467656136, 37.54329264163971, 37.44848012924194, 37.05621957778931, 36.41202114522457, 38.03948521614075, 35.923865139484406, 35.17445795238018, 36.17697335779667, 35.603796914219856, 33.16517136991024, 33.83459284901619, 34.87282633781433, 35.49058198928833, 36.91191852092743, 36.186651438474655, 40.55854104459286, 44.63587045669556, 47.758584693074226, 47.20325209200382, 49.44646932184696, 48.009724617004395, 47.651111260056496, 49.07580301165581, 50.73465719819069, 49.941689148545265, 47.84859426319599, 47.61024445295334, 46.229018568992615, 46.41761004924774, 50.429951548576355, 51.86292685568333, 49.198863208293915, 30.275304839015007, 10.386921241879463, 3.3252763794735074, 2.132542231120169, 7.861495055258274, 8.079297468066216, 5.465042972937226, 2.787986872717738, 1.2132345233112574, 0.09628808751585893, 8.743155095726252, 30.922309421002865, 24.94269948452711, 30.702251829206944, 46.55034452676773, 36.29895441234112, 3.907929752022028, 0.04436868657649029, 0.06434211070882156, 0.016353018108929973, 0.05937491630902514, 0.03184911540301982, 0.04876049388258252, 0.01009539681035676, 0.04424876664415933, 0.012937961564603029, 0.02329567232663976, 0.04203125536150765, 0.06023587069648784, 0.0825687604083214, 0.035846820028382353, 0.02260203327750787, 0.07075961751979776, 0.011422048864915268, 0.052646783587988466, 0.0469628563587321, 0.0483257400628645, 0.06080431128793862, 0.053569581141346134, 0.012508726540545467, 0.052416279941098765, 0.06428157372283749, 0.03473271535767708, 0.010736535405158065, 0.03986403942690231, 0.07760865351883695, 0.02586231399618555, 0.04125459410715848, 0.03571341156202834, 0.04201787814963609, 0.031028878947836347, 0.03636074987298343, 0.057547937976778485, 0.072383206570521, 0.012993369382456876, 1.1349396058358252, 15.082717817276716, 46.28941252827644, 48.98860529065132, 34.232872277498245, 29.249658174812794, 36.238085478544235, 46.43791235983372, 26.76704429090023, 0.1730993701494299, 0.13834842393407598, 5.273202667012811, 9.863083250820637, 6.640393054112792, 10.758441556245089, 28.182107359170914, 45.30143514275551, 51.440735310316086, 54.3982458114624, 50.536326840519905, 52.56715066730976, 55.2419563382864, 53.0743208527565, 51.47203043103218, 51.651247814297676, 50.287964567542076, 52.36546888947487, 51.639396250247955, 53.55485066771507, 51.12468346953392, 50.17812766134739, 48.39635007083416, 46.0535553842783, 40.42680971324444, 37.58807323873043, 39.16533060371876, 38.12273494899273, 39.060049653053284, 39.369759634137154, 37.025099247694016, 39.182908460497856, 38.063955903053284, 41.48302763700485, 42.49500833451748, 43.75925749540329, 45.98449409008026, 44.06226083636284, 43.869102001190186, 38.723509311676025, 40.036300867795944, 37.75564804673195, 38.96121695637703, 38.39250907301903, 37.991478592157364, 35.83607845008373, 37.25376717746258, 38.86195108294487, 45.37479020655155, 48.03190402686596, 50.04475101828575, 46.90982423722744, 45.58470234274864, 48.85826848447323, 47.6295930147171, 51.10340841114521, 52.48729795217514, 50.691932290792465, 51.60584405064583, 43.82671907544136, 44.32896472513676, 45.31820364296436, 47.06378057599068, 48.66635598242283, 48.57016794383526, 50.88663004338741, 49.3095588684082, 49.11255843937397, 47.58220195770264, 46.029217690229416, 42.0433683693409, 39.576749727129936, 37.61852100491524, 37.11499482393265, 36.232169196009636, 37.80387885868549, 38.76958943903446, 38.50969858467579, 37.904296070337296, 40.79395741224289, 39.03167277574539, 39.89123985171318, 39.49767976999283, 39.515272825956345, 39.53816279768944, 37.58436843752861, 37.123635560274124, 37.851068526506424, 37.15958543121815, 36.14905625581741, 35.80060355365276, 35.364531353116035, 37.06878550350666, 38.07143770158291, 40.450851023197174, 43.155192509293556, 47.00307123363018, 50.24696856737137, 48.68375904858112, 50.342989414930344, 47.861657962203026, 47.94158287346363, 51.378711238503456, 50.92113979160786, 51.97938300669193, 51.275079399347305, 48.92411895096302, 47.40224741399288, 49.24633406102657, 53.598612919449806, 54.815345630049706, 51.2196783721447, 32.13292255997658, 12.717211749404669, 6.270489078015089, 3.598757917061448, 9.764128010720015, 9.18088685721159, 2.947825533337891, 3.45130801666528, 1.363917337730527, 0.10639032785547897, 9.639902226626873, 39.25306409597397, 30.8593562990427, 33.2452292740345, 48.54442052543163, 42.66975335776806, 7.032680679112673, 0.026369276929472107, 0.03372693456185516, 0.05322588142007589, 0.012961701013409765, 0.058853705995716155, 0.049045107516576536, 0.03721769666299224, 0.020360535781946965, 0.029025070944044273, 0.014492959471681388, 0.04722331308585126, 0.047083945173653774, 0.0360124451253796, 0.06715194118442014, 0.03004767251695739, 0.04013080812001135, 0.03643758442194667, 0.17291050840867683, 0.1116177489166148, 0.20004755380796269, 0.10829358041519299, 0.20153794961515814, 0.11191937257535756, 0.17809599812608212, 0.2173050254350528, 0.1346737242420204, 0.17384991893777624, 0.1537628608639352, 0.11448533332441002, 0.13555061625083908, 0.16625336953438818, 0.1392885617678985, 0.12732554198009893, 0.15646785555873066, 0.12523500103270635, 0.12009805519483052, 0.23135371768148616, 0.1320874286466278, 1.551553881727159, 20.462741777300835, 55.01181788742542, 56.00088581442833, 41.121192052960396, 37.85716339945793, 48.045450299978256, 52.34764784574509, 32.7783977240324, 0.473496689228341, 0.7760354457423091, 11.767782345414162, 13.72785396873951, 12.915487959980965, 12.234868481755257, 30.58114092797041, 49.3114397674799, 54.550971016287804, 58.291399106383324, 51.186798736453056, 51.70797497034073, 59.48659837245941, 53.882286697626114, 53.24343077838421, 52.96485632658005, 52.685696706175804, 55.179738476872444, 52.71002300083637, 55.036421567201614, 53.44246409833431, 53.567834571003914, 51.50047950446606, 48.67578707635403, 41.90234273672104, 38.45255725085735, 41.48271605372429, 40.271888226270676, 40.022959783673286, 40.885502099990845, 39.82536278665066, 39.69611272215843, 39.287824630737305, 42.08629086613655, 44.85159628093243, 46.51912160217762, 47.78457909822464, 46.23456247150898, 45.675585865974426, 39.75535534322262, 41.72151803970337, 39.810551181435585, 39.33785654604435, 40.46240620315075, 38.99252727627754, 38.28087106347084, 39.915398955345154, 40.99215477705002, 47.53547966480255, 50.324518606066704, 53.22809100151062, 49.58966463804245, 46.08955845236778, 50.01664772629738, 49.28512617945671, 53.67958277463913, 54.76169250905514, 52.63806626200676, 51.88037171959877, 45.305341333150864, 45.8052197098732, 45.057271644473076, 48.094585463404655, 48.584846556186676, 48.83135072886944, 52.08591789007187, 52.68611088395119, 51.40140742063522, 49.161731600761414, 49.03449162840843, 43.339421823620796, 41.64220109581947, 39.95558559894562, 38.55431579053402, 37.040363028645515, 39.22060243785381, 39.564229398965836, 40.655086264014244, 40.01521199941635, 43.69570590555668, 41.4487648755312, 41.71777904033661, 40.56356817483902, 40.84701016545296, 41.93138837814331, 39.01768572628498, 38.98982562124729, 39.35208298265934, 39.548733830451965, 37.01883338391781, 38.02128039300442, 38.65992732346058, 39.38599996268749, 40.631770715117455, 40.696435645222664, 43.620173558592796, 49.41551238298416, 53.45431566238403, 51.1049435287714, 51.976099982857704, 49.69691388309002, 48.723618909716606, 52.45032973587513, 53.08899566531181, 55.260655134916306, 51.84487022459507, 51.150712072849274, 49.91835080087185, 50.669388100504875, 55.72264954447746, 57.234474420547485, 53.44406381249428, 33.35913196206093, 14.23787210136652, 5.164257287979126, 4.204792147502303, 18.062186390161514, 18.507203310728073, 14.776730686426163, 8.01225671544671, 2.9084399342536926, 0.21703525475459173, 11.640260238200426, 43.32168437540531, 38.284743055701256, 41.04991167783737, 55.7294549793005, 49.2834048718214, 8.738070018589497, 0.05633204033074435, 0.19156266847858205, 0.10580682166619226, 0.15801012748852372, 0.126058695896063, 0.13448504061670974, 0.166639523813501, 0.10574514177278616, 0.17032854695571586, 0.21061385166831315, 0.13662275247043, 0.13691029016627, 0.21122878039022908, 0.18583530705654994, 0.13324835541425273, 0.18540196702815592, 0.19028881652047858], [0.05051353575254325, 0.012100981330149807, 0.023120870573620778, 0.0382784668909153, 0.052858221461065114, 0.07240135208121501, 0.07956603090860881, 0.10954216966638342, 0.010377736689406447, 0.03217760851839557, 0.05792797324829735, 0.020874441506748553, 0.02664378993358696, 0.05056751957454253, 0.09509057286777534, 0.06188088555063587, 0.038833066428196616, 0.06746856364770792, 0.025255645377910696, 0.02528142387745902, 0.04800378155778162, 0.12107596092391759, 9.539390970021486, 40.615264400839806, 50.899245366454124, 47.66516290605068, 67.4422238767147, 56.17597661912441, 41.19068272411823, 22.08793167024851, 1.7659012111835182, 0.4107394942548126, 0.8976584882475436, 6.805803403258324, 6.594232181087136, 7.519758492708206, 15.68839866667986, 38.919290006160736, 35.90399980545044, 42.66105182468891, 48.035263046622276, 53.60531575977802, 52.01127469539642, 51.86147913336754, 48.87339547276497, 44.10892993211746, 40.80045886337757, 41.402285769581795, 42.83830851316452, 44.00299921631813, 41.7656184732914, 39.39260020852089, 37.672303318977356, 35.99174089729786, 35.34905478358269, 37.4486131221056, 36.72081537544727, 37.048217207193375, 35.85531681776047, 36.11037813127041, 35.77519431710243, 37.31556326150894, 36.761678382754326, 37.32630528509617, 37.62298956513405, 41.218383237719536, 40.130243226885796, 40.69331981241703, 41.56383790075779, 37.10711404681206, 37.18906804919243, 35.47948278486729, 36.390191316604614, 36.56229928135872, 35.95036491751671, 36.82909056544304, 35.48671379685402, 36.24750517308712, 42.064039260149, 47.43671916425228, 48.33216391503811, 47.834774404764175, 46.08587644994259, 41.28072269260883, 47.79918931424618, 47.44311422109604, 49.20942284166813, 49.571866393089294, 48.81405785679817, 40.06046377122402, 42.534286826848984, 43.76320168375969, 45.35314276814461, 45.025045573711395, 44.96073782444, 46.07410468161106, 50.1263402402401, 47.063788175582886, 47.43858486413956, 45.85072606801987, 42.92975440621376, 39.93838392198086, 36.2790434807539, 34.90016967058182, 36.09797939658165, 34.81658175587654, 36.90979823470116, 35.80611325800419, 39.602276757359505, 37.47179567813873, 36.85879737138748, 37.66283802688122, 38.83176930248737, 38.30847278237343, 38.16607162356377, 35.76858647167683, 36.91893674433231, 34.9876219779253, 34.2221150547266, 35.8041525632143, 35.00767730176449, 33.412165716290474, 35.27988329529762, 36.11618421971798, 36.219158694148064, 36.38482980430126, 41.3318033516407, 44.275429397821426, 46.99874326586723, 48.18621374666691, 48.5332453250885, 47.061230912804604, 45.40869198739529, 50.88272005319595, 48.69761310517788, 49.70537602901459, 47.18277879059315, 50.769896507263184, 50.409687235951424, 54.7395358979702, 50.128095746040344, 43.56571488082409, 23.641432709991932, 4.034655801951885, 2.7438738523051143, 5.702658472582698, 10.355132147669792, 4.698604149743915, 3.4540246333926916, 3.7131042312830687, 0.922475669067353, 0.1601227547507733, 11.221646200865507, 34.992204532027245, 28.834279663860798, 30.999230593442917, 47.1521258354187, 26.91582340747118, 2.2296814061701298, 0.05263703547825571, 0.036950720168533735, 0.02761973453743849, 0.032539201420149766, 0.04695005060057156, 0.028849527043348644, 0.026617239600454923, 0.07640056326636113, 0.033085169779951684, 0.05638850663672201, 0.02131883582478622, 0.026216151454718783, 0.05827100874739699, 0.018074116087518632, 0.047450217316509224, 0.011454902814875823, 0.003872709098686755, 0.0768046329903882, 0.03854107955703512, 0.03830361085420009, 0.021069656031613704, 0.0802530295914039, 0.07554229916422628, 0.05154674261575565, 0.03955274558393285, 0.03334349283250049, 0.09822225794778205, 0.023280358109332155, 0.04328187809733208, 0.03948368503188249, 0.14383622008608654, 0.035568065650295466, 0.045777973064105026, 0.028839456099376548, 0.05340318050002679, 0.04012418816273566, 0.016767511297075544, 0.10987809539074078, 0.2989107824396342, 12.69666625186801, 46.63287989795208, 55.830552354454994, 46.20552442967892, 55.05380943417549, 53.59825573861599, 45.61731219291687, 25.474484749138355, 1.5632580849342048, 0.35665007948409766, 2.0696209324523807, 12.211919613182545, 8.77182550728321, 10.979601088911295, 17.890365310013294, 44.59973819553852, 40.91803975403309, 47.798672541975975, 47.15522646903992, 54.69851329922676, 52.870792374014854, 54.22947406768799, 52.039883360266685, 48.594175055623055, 42.61861950159073, 45.52482135593891, 45.83299241960049, 47.002930641174316, 44.58412103354931, 42.43638128042221, 42.67764553427696, 37.22992345690727, 36.053795367479324, 38.466031327843666, 38.54491889476776, 37.919457256793976, 38.34418706595898, 37.37681597471237, 37.81722754240036, 39.587639942765236, 39.07606579363346, 39.35563199222088, 39.174229726195335, 42.528070360422134, 42.115355506539345, 43.8920945674181, 42.93831914663315, 39.30409535765648, 39.3440730124712, 37.40097887814045, 38.262677639722824, 37.91888728737831, 38.250639885663986, 37.974767088890076, 37.159976810216904, 38.68659809231758, 44.176444709300995, 49.82242114841938, 49.850345849990845, 48.765842244029045, 45.86989603936672, 43.52783091366291, 49.50578793883324, 48.210984617471695, 49.96659681200981, 49.991724863648415, 47.49168321490288, 43.462998792529106, 43.45594637095928, 44.23642449080944, 44.637789353728294, 45.17693102359772, 46.33819431066513, 47.93114863336086, 52.289241179823875, 48.80515493452549, 49.3502014875412, 46.27552807331085, 44.51056458055973, 41.83846436440945, 38.61284025013447, 36.08384035527706, 37.984224781394005, 36.62700600922108, 39.030388444662094, 36.80456668138504, 39.88015204668045, 39.21910911798477, 37.242770567536354, 38.97526100277901, 40.86690589785576, 40.26491940021515, 38.96554872393608, 37.33779966831207, 37.03647583723068, 36.52939684689045, 35.385616421699524, 37.51727543771267, 37.471472695469856, 35.99626645445824, 36.10418826341629, 38.26923608779907, 37.32404060661793, 38.03306736052036, 43.43365676701069, 47.431524842977524, 47.98459656536579, 49.491379112005234, 50.35154275596142, 46.72478936612606, 45.57474687695503, 53.06050479412079, 49.63728368282318, 50.1176805049181, 49.678697660565376, 52.92257979512215, 51.93069241940975, 56.14663079380989, 49.95436146855354, 45.457029193639755, 29.2560950294137, 8.38423490524292, 5.330222882330418, 11.269689872860909, 10.984850507229567, 0.9307827358134091, 0.46587302174884826, 0.4506369971204549, 0.3237178106792271, 0.06592090372578241, 12.049479279667139, 39.44779984652996, 30.772287771105766, 35.531524792313576, 51.648622155189514, 35.04256322979927, 3.2398935360834002, 0.006317033930827165, 0.07197884740890004, 0.02885185367631493, 0.052689163931063376, 0.06068679962481838, 0.01673094568104716, 0.05073530432127882, 0.026287622131349053, 0.050989534429390915, 0.044114044576417655, 0.04190845960692968, 0.01538707765575964, 0.054481008992297575, 0.018280956355738454, 0.08208182989619672, 0.0330083463632036, 0.029719893718720414, 0.10191523673711345, 0.09946098405634984, 0.15188914578175172, 0.20511048525804654, 0.1491832159808837, 0.23472719447454438, 0.17184389376780018, 0.3078391752205789, 0.13630472734803334, 0.20913038752041757, 0.08608836607891135, 0.08349533178261481, 0.15770176512887701, 0.2994480082998052, 0.21678552206140012, 0.09201009597745724, 0.13338716671569273, 0.16155012737726793, 0.11347866195137613, 0.12000684524537064, 0.23551024933112785, 0.5846794950775802, 15.63667394220829, 54.44743037223816, 63.01702693104744, 56.54312811791897, 72.50256434082985, 63.42965438961983, 50.72442054748535, 29.45484146475792, 2.5641100108623505, 0.6381930329371244, 3.5891698440536857, 16.820673309266567, 10.582524295896292, 12.028909083455801, 21.920962929725647, 48.13618943095207, 43.867464289069176, 50.05035571753979, 49.1584599763155, 55.45923247933388, 55.91332331299782, 58.38586203753948, 53.80532942712307, 49.7623235732317, 43.98258291184902, 45.81606812775135, 47.35181272029877, 48.17027360200882, 45.791692435741425, 43.301423862576485, 42.13192641735077, 39.386611729860306, 38.16436171531677, 40.228866934776306, 42.19088785350323, 41.38331338763237, 39.68055635690689, 39.81369361281395, 40.96260376274586, 41.9882333278656, 39.62083876132965, 40.70737145841122, 40.7757031917572, 45.815961733460426, 43.318317756056786, 45.60875505208969, 45.70059612393379, 40.03988027572632, 41.38672560453415, 37.33143500983715, 39.06193055212498, 39.463565200567245, 39.67574201524258, 40.22365741431713, 39.50253210961819, 40.38275867700577, 44.47603963315487, 52.35041789710522, 52.6772915571928, 49.860996678471565, 47.28318080306053, 44.96141418814659, 50.44546991586685, 50.027116164565086, 51.999905705451965, 51.456607058644295, 48.992982655763626, 43.996854946017265, 43.55368472635746, 42.92031951248646, 45.93108415603638, 45.57156264781952, 46.125249937176704, 47.705459743738174, 54.65034708380699, 50.23587316274643, 51.65185198187828, 49.6896068751812, 47.310820519924164, 44.38620485365391, 40.343559980392456, 37.459328547120094, 39.91773962974548, 37.311972454190254, 39.250214248895645, 38.035419434309006, 42.22288213670254, 41.96624770760536, 40.93928441405296, 42.371419966220856, 43.041286021471024, 42.10893765091896, 42.14623264968395, 38.97915579378605, 39.07525643706322, 38.07074993848801, 38.0951826274395, 39.98518981039524, 39.03398685157299, 36.8941430747509, 38.66767890751362, 41.565335020422935, 39.606384336948395, 41.007741540670395, 45.97376346588135, 50.88202849030495, 50.308285877108574, 52.10459768772125, 52.36743338406086, 48.22647638618946, 45.79677276313305, 54.2660129070282, 51.460285261273384, 53.98384764790535, 51.010636389255524, 57.27638237178326, 54.5784967392683, 60.2748204767704, 49.636687114834785, 47.07630470395088, 31.00396703928709, 13.063091989606619, 7.694632234051824, 13.275801725685596, 22.0369878038764, 13.511519227176905, 11.757748033851385, 7.580051282420754, 2.3770310869440436, 0.27388357382733375, 14.397128205746412, 48.08717966079712, 39.22915957868099, 42.28959895670414, 59.87998366355896, 40.468979850411415, 4.917563600465655, 0.18263440928421915, 0.10221707561868243, 0.1824387939996086, 0.11439864305430092, 0.18005557969445363, 0.09145451680524275, 0.08756912880926393, 0.19028078648261726, 0.22272056608926505, 0.19246777694206685, 0.0950289226602763, 0.08411116592469625, 0.13039461948210374, 0.0793344214616809, 0.1281151722650975, 0.08654143239255063, 0.10324141010642052], [0.04916392164886929, 0.06050384537957143, 0.04737999530334491, 0.01583843146363506, 0.016818283475004137, 0.007009828786976868, 0.06267145465244539, 0.015111841985344654, 0.06504672797746025, 0.07893754314864054, 0.0155806742986897, 0.03792588737269398, 0.06115194810263347, 0.037908565645921044, 0.009106309698836412, 0.0074824251805694075, 0.046841359362588264, 0.07014556453214027, 0.03403679234907031, 0.04201053088763729, 0.08163861188222654, 0.0938064866932109, 5.884834947064519, 37.6109404116869, 46.06708645820618, 54.18512284755707, 63.74928183853626, 62.554751336574554, 41.71970173716545, 24.774055033922195, 3.83246888872236, 0.06467474129749462, 2.1626750892028213, 8.380711544305086, 4.2012084648013115, 5.704492349177599, 13.029042966663837, 32.963975965976715, 43.646840527653694, 54.93195757269859, 49.504792392253876, 52.55244165658951, 51.41116909682751, 50.34354418516159, 47.59955942630768, 43.501673117280006, 40.37706658244133, 39.79866921901703, 37.783994525671005, 35.72702430188656, 35.58576688170433, 36.608516201376915, 35.333171635866165, 34.948959052562714, 34.53421890735626, 36.27045214176178, 37.1831289678812, 37.057161927223206, 40.16839697957039, 39.795484989881516, 38.904626592993736, 37.91564606130123, 36.54949016869068, 37.52849243581295, 36.669563725590706, 36.67525202035904, 38.88257637619972, 37.65645056962967, 37.983461022377014, 37.0277439057827, 37.47151829302311, 36.816619634628296, 37.292859479784966, 36.07456125319004, 35.61975225806236, 35.5160254240036, 35.660109892487526, 36.409486681222916, 38.76757934689522, 44.052404165267944, 48.80390480160713, 48.60499307513237, 49.421242475509644, 48.803144842386246, 45.64467832446098, 47.108276188373566, 47.30437606573105, 48.14948871731758, 45.971916764974594, 40.04134699702263, 44.07874055206776, 43.131215795874596, 42.76378311216831, 46.63305088877678, 46.59729100763798, 47.90189780294895, 46.708397045731544, 47.63386398553848, 48.20208929479122, 48.191750049591064, 44.998899176716805, 39.90608565509319, 36.99956841766834, 35.13410031795502, 36.34449116885662, 35.41234418749809, 36.42507344484329, 36.75268806517124, 37.045283764600754, 35.75161658227444, 38.105324283242226, 38.68017643690109, 37.998314425349236, 38.1966295838356, 36.93541266024113, 35.53562477231026, 35.74551410973072, 37.63178989291191, 35.15487380325794, 35.549273639917374, 35.01110091805458, 34.028876423835754, 34.270121678709984, 33.36308375000954, 35.3706756234169, 37.20317669212818, 40.313279405236244, 42.763760313391685, 44.25554506480694, 47.64347746968269, 46.707530692219734, 48.595170602202415, 46.911355555057526, 45.492770075798035, 50.54253190755844, 51.41867749392986, 53.30575503408909, 48.70249584317207, 51.548223942518234, 49.09918695688248, 48.86785916984081, 29.78379551321268, 16.427671797573566, 3.79397576674819, 6.234146878123283, 4.884319184347987, 4.7872804664075375, 1.784794747363776, 0.05828963294334244, 0.9637332614511251, 0.4606681322911754, 0.15102326724445447, 11.763437278568745, 32.56917715072632, 25.613422393798828, 34.228156730532646, 44.679986089468, 19.861330948770046, 1.0426685633137822, 0.07864021652494557, 0.0729420140851289, 0.02310812418727437, 0.05183114102692343, 0.044229778795852326, 0.009512712549621938, 0.016713969052943867, 0.034466577490093186, 0.004509199297899613, 0.04586438873957377, 0.01882065727841109, 0.02195377655880293, 0.018677009029488545, 0.03519382655213121, 0.020227876884746365, 0.09725667929160409, 0.072265464841621, 0.05203727996558882, 0.029937647268525325, 0.050178886522189714, 0.031309184414567426, 0.0542713040340459, 0.01840368531702552, 0.011524811270646751, 0.05774359036877286, 0.029263873657328077, 0.050352756879874505, 0.0107014707828057, 0.015456102028110763, 0.046078290542936884, 0.03349650512973312, 0.022401180285669398, 0.0042806864621525165, 0.02351241470023524, 0.03284132973931264, 0.00857012470078189, 0.023027857205306645, 0.05278874159557745, 0.09042034143931232, 8.722207769751549, 45.910280272364616, 53.00438940525055, 58.09704713523388, 69.10000652074814, 64.00256484746933, 45.836807414889336, 26.893617399036884, 3.26060242485255, 0.11154410560266115, 1.4617760991677642, 8.59236778691411, 8.693390116095543, 9.745449163019657, 16.855281852185726, 38.40965375304222, 45.65262369811535, 54.055659994482994, 49.386436343193054, 53.74279238283634, 55.114628970623016, 53.1192534416914, 51.1007409542799, 45.12320190668106, 42.555117309093475, 41.57706879079342, 39.89757411181927, 39.26122225821018, 38.16002994775772, 39.21449236571789, 36.96685217320919, 37.70499296486378, 36.26726411283016, 37.05903522670269, 39.409490302205086, 38.66978399455547, 40.541757345199585, 40.26392005383968, 41.94352112710476, 40.011974573135376, 38.93154054880142, 38.53919260203838, 38.96308645606041, 39.07213680446148, 40.37902347743511, 39.39820870757103, 39.901438504457474, 38.87966573238373, 38.87292109429836, 38.2527107745409, 39.32315893471241, 37.65308015048504, 38.28270636498928, 37.69785314798355, 38.0707423388958, 37.866659089922905, 41.74986071884632, 45.99093854427338, 49.7886523604393, 50.276679173111916, 50.97971364855766, 49.21673744916916, 47.42495499551296, 48.41690696775913, 47.64604613184929, 50.46987220644951, 47.42044843733311, 42.66406886279583, 44.97607760131359, 43.43436352908611, 42.87450157105923, 47.61112600564957, 46.17329455912113, 48.6454077064991, 47.63428956270218, 51.83824338018894, 49.27289843559265, 50.189340859651566, 46.158315762877464, 40.28763838112354, 39.25828501582146, 37.525547593832016, 37.03681401908398, 37.39207975566387, 37.82262705266476, 38.53552959859371, 38.82502846419811, 37.863778844475746, 39.66270491480827, 40.35815879702568, 41.02601855993271, 39.70166802406311, 38.629422560334206, 36.00424982607365, 37.915193885564804, 38.58255587518215, 37.64390744268894, 36.63318827748299, 36.46722838282585, 35.56323789060116, 35.50353929400444, 35.31715549528599, 37.27112464606762, 39.60818164050579, 41.56053587794304, 44.70196411013603, 46.22385464608669, 48.470666483044624, 49.244054183363914, 49.35821145772934, 47.59140506386757, 45.68243309855461, 50.390874445438385, 53.543721064925194, 55.030839666724205, 51.76690220832825, 51.62244156002998, 49.66780744493008, 49.9467808753252, 35.06232596933842, 21.670734956860542, 8.970532044768333, 9.495595470070839, 10.906772296875715, 3.3231596555560827, 0.3969313617562875, 0.3663814760511741, 0.3361793013755232, 0.47645367274526507, 0.1426801024354063, 13.484660368412733, 40.4804552346468, 31.922151669859886, 39.18437518179417, 49.89742152392864, 25.900056213140488, 1.5332126221619546, 0.08696562174009159, 0.05766845904872753, 0.05112705068313517, 0.041655387249193154, 0.02795666216115933, 0.029798524265061133, 0.030848833921481855, 0.08065152578637935, 0.059485663296072744, 0.05818709782033693, 0.10719297541072592, 0.07968231060658582, 0.0293494080324308, 0.037670054225600325, 0.057247112126788124, 0.028948045292054303, 0.014577275796909817, 0.12447297121980228, 0.18239950470160693, 0.14537728973664343, 0.13585112668806687, 0.18025057157501578, 0.059852061604033224, 0.12804557365598157, 0.12220197706483305, 0.15334117255406454, 0.17284168163314462, 0.05483185930643231, 0.09716528380522504, 0.13514659105567262, 0.12289482387132011, 0.13961331074824557, 0.06434897557483055, 0.09601453188224696, 0.13121841824613512, 0.15605263877660036, 0.17114713584305719, 0.1626952612423338, 0.20102021255297586, 11.316895689815283, 51.71365946531296, 58.571679666638374, 62.08153612911701, 68.91644597053528, 67.87951961159706, 48.448319882154465, 33.53904850780964, 4.863989325240254, 0.15229346783598885, 4.33005147613585, 16.95395115762949, 9.683667328208685, 9.913585390895605, 17.9449949786067, 42.58239984512329, 48.87040123343468, 55.58225467801094, 50.70327468216419, 54.5557701587677, 56.18489094078541, 54.96344268321991, 52.25619815289974, 47.65239179134369, 45.6392066180706, 44.61402542889118, 42.09669090807438, 40.54891616106033, 40.53870990872383, 41.467912048101425, 39.193171709775925, 39.65060256421566, 38.87566834688187, 38.970055282115936, 41.968033611774445, 41.76555007696152, 43.48570257425308, 42.27425538003445, 43.542859107255936, 41.77300527691841, 40.74443846940994, 40.461760237812996, 39.92546081542969, 39.88470800220966, 42.8966049849987, 41.279491558671, 41.268430352211, 40.37949085235596, 40.5334509909153, 40.130140632390976, 42.00365670025349, 38.52258749306202, 38.124471455812454, 39.506347104907036, 39.658711329102516, 38.74684005975723, 43.506096079945564, 47.053000554442406, 51.251900643110275, 51.47326156497002, 52.40523375570774, 51.95220686495304, 49.1190180927515, 50.45436143875122, 51.50367893278599, 51.444318518042564, 47.76021860539913, 45.44211499392986, 45.21160036325455, 42.71147891879082, 42.5380752235651, 49.31416802108288, 47.20427043735981, 48.76015014946461, 49.40614968538284, 51.67080156505108, 52.48233921825886, 53.48192498087883, 47.8183326870203, 43.08703936636448, 41.037273555994034, 39.01854068040848, 40.2443815022707, 40.24554803967476, 38.76908026635647, 38.73958244919777, 41.46896079182625, 38.95147427916527, 42.597443237900734, 43.29834222793579, 42.77696080505848, 41.98748856782913, 39.98394347727299, 39.486709758639336, 39.319621324539185, 41.54797375202179, 38.98109748959541, 39.30829793214798, 38.158464431762695, 37.813028767704964, 37.38278925418854, 36.92917339503765, 40.12262083590031, 41.23877294361591, 44.10652086138725, 47.65161283314228, 48.00997920334339, 50.67585915327072, 50.63239328563213, 49.55233924090862, 48.23226347565651, 46.51262395083904, 51.92123472690582, 53.73737387359142, 56.739873960614204, 53.26545059680939, 53.712378814816475, 51.37198939919472, 50.91904230415821, 40.24087429046631, 24.244673140347004, 12.17746876180172, 14.150904268026352, 12.452161721885204, 14.03754685074091, 6.49526079185307, 1.2658898415975273, 1.8777059367857873, 1.274766402784735, 0.4736694908933714, 16.729052625596523, 45.4004730284214, 35.68937212228775, 45.46729624271393, 53.92057344317436, 31.249481365084648, 1.8687327182851732, 0.20424865884706378, 0.15956923132762313, 0.11604955798247829, 0.11881188358529471, 0.24698216031538323, 0.16489500179886818, 0.10671501746401191, 0.19868826580932364, 0.11963864351855591, 0.19175789784640074, 0.19369053945410997, 0.17407116800313815, 0.115002825477859, 0.0954739292501472, 0.1646145441918634, 0.2530418703099713, 0.11480422675958835], [0.04520798880548682, 0.013772363763564499, 0.04591999044350814, 0.044092908210586756, 0.041114443229162134, 0.09164679242530838, 0.03290377775556408, 0.027014937986677978, 0.040079158352455124, 0.0958926415478345, 0.06479672068962827, 0.07926317528472282, 0.047397565649589524, 0.03652958104794379, 0.03197946251020767, 0.03638482143287547, 0.04972442868165672, 0.029566855446319096, 0.06512823063530959, 0.006532962261189823, 0.08280059992102906, 0.02370453075855039, 2.8883019648492336, 32.0373272895813, 47.10937812924385, 37.79690243303776, 51.38207025825977, 56.158596351742744, 32.20581404864788, 32.69546717405319, 9.553134832531214, 0.023399845740641467, 0.6466508447192609, 4.10427519120276, 2.9718426195904613, 1.3636031420901418, 4.891970073804259, 15.241345055401325, 37.02511824667454, 48.039678409695625, 50.46723514795303, 50.604738369584084, 52.40902215242386, 49.23070549964905, 46.34740501642227, 41.83257848024368, 39.74480710923672, 41.501905024051666, 39.37458537518978, 38.41248080134392, 36.16933576762676, 35.10136507451534, 35.550398379564285, 35.09354509413242, 35.17728500068188, 37.48164474964142, 37.39557556807995, 37.43100106716156, 38.43972533941269, 38.147779405117035, 36.27815052866936, 36.2095832079649, 36.83306135237217, 36.328706815838814, 35.94029165804386, 36.66748903691769, 37.85745978355408, 36.88026621937752, 37.081446424126625, 38.05267430841923, 37.45805561542511, 37.261465564370155, 36.681867465376854, 36.38545297086239, 35.53006947040558, 35.99809795618057, 36.224630400538445, 36.06256529688835, 37.685697600245476, 42.06530079245567, 47.076848074793816, 47.7945763617754, 49.364614114165306, 47.97624461352825, 49.684089571237564, 47.001805901527405, 49.09360125660896, 46.99095368385315, 48.92196826636791, 39.42752793431282, 43.44529554247856, 46.919312328100204, 50.88379919528961, 49.5085845887661, 50.01151420176029, 47.92992129921913, 51.23705103993416, 49.698486998677254, 50.61176799237728, 47.687049731612206, 46.14135727286339, 39.383017122745514, 34.97207321226597, 35.32400652766228, 36.365211457014084, 36.21415436267853, 36.08866609632969, 36.102622747421265, 38.31723511219025, 38.01549330353737, 40.20684711635113, 39.41979914903641, 40.47754839062691, 38.263836577534676, 36.393151357769966, 36.06743283569813, 35.20881570875645, 34.5382808893919, 35.7790245115757, 33.56033876538277, 35.604781061410904, 34.5398274064064, 35.56836761534214, 36.82741865515709, 38.16015154123306, 38.96485336124897, 39.54472504556179, 41.17286927998066, 45.62751084566116, 47.48023062944412, 50.040525645017624, 45.7773520052433, 45.52856795489788, 46.719511449337006, 47.16133274137974, 49.63580176234245, 45.96855394542217, 49.44066323339939, 52.77593046426773, 46.45458206534386, 36.1087404191494, 20.207836255431175, 4.416805570945144, 0.5632417579181492, 1.0508661484345794, 4.78794970549643, 0.5686746351420879, 0.19728614104678854, 0.0319218458753312, 0.04422539641382173, 0.11802885099314153, 0.14815675152931362, 13.510333690792322, 28.420221582055092, 25.490768775343895, 33.854705169796944, 35.688775554299355, 13.359917812049389, 0.334603603114374, 0.010682533029466867, 0.05443914815259632, 0.01636743989365641, 0.04585988019243814, 0.03485097658995073, 0.038858574043842964, 0.06261603848543018, 0.06736305993399583, 0.02734118424996268, 0.01645787800953258, 0.027005900483345613, 0.018956101084768306, 0.04812939376279246, 0.02351019011257449, 0.0195215285566519, 0.052986189984949306, 0.03668518715130631, 0.016948129632510245, 0.02096482210617978, 0.02370292400883045, 0.055004278765409254, 0.026220708241453394, 0.02737761813477846, 0.01886275189463049, 0.039745158501318656, 0.04795758657564875, 0.00719670806574868, 0.054095927116577514, 0.028980738752579782, 0.0272301218501525, 0.052654906394309364, 0.019546674375305884, 0.05174834332137834, 0.0713354127947241, 0.04017482489871327, 0.01717766292131273, 0.057297674647998065, 0.08521743351593614, 0.07738654356217012, 5.0793655682355165, 38.74571152031422, 51.984341740608215, 44.913551956415176, 58.870799615979195, 61.382704228162766, 39.91075940430164, 35.509451776742935, 9.75897453725338, 0.04273080747225322, 0.3955455345567316, 5.768748326227069, 6.169134741649032, 4.386382978409529, 7.26227005943656, 21.342905648052692, 43.19883316755295, 51.07439696788788, 52.36134231090546, 52.08889693021774, 53.51868040859699, 51.594178676605225, 49.795001819729805, 43.31819236278534, 41.00400634109974, 41.13867871463299, 40.12929327785969, 39.42765332758427, 38.72956618666649, 36.4033006131649, 36.81256905198097, 36.55933164060116, 37.00387738645077, 38.9888034760952, 39.87028397619724, 40.220666974782944, 39.82717528939247, 40.231652185320854, 36.621602699160576, 38.2178058475256, 38.37723769247532, 37.6252656430006, 38.5697353631258, 38.424096778035164, 39.25768464803696, 38.10164228081703, 38.97409066557884, 39.50925774872303, 39.745886251330376, 38.93182173371315, 38.75935658812523, 38.422812446951866, 37.70492836833, 37.5843608379364, 37.3547999560833, 37.66029216349125, 39.273203015327454, 43.82374383509159, 49.217360615730286, 50.20181179046631, 50.09828634560108, 51.252527609467506, 51.59693352878094, 48.49357545375824, 51.20326705276966, 49.16010148823261, 49.27281863987446, 41.96772202849388, 44.461372420191765, 47.413620203733444, 50.28744399547577, 50.75878590345383, 51.3283259421587, 49.471726566553116, 50.65758593380451, 50.630945563316345, 50.10406583547592, 49.83361154794693, 49.09324407577515, 40.18852449953556, 37.59177044034004, 36.328828409314156, 37.217490524053574, 36.41202874481678, 37.60411977767944, 37.407366335392, 38.84887218475342, 39.32220138609409, 41.22707337141037, 41.682266145944595, 43.20215418934822, 40.18070071935654, 37.74422965943813, 38.62741246819496, 37.32269927859306, 36.83755651116371, 36.708880215883255, 36.54001347720623, 37.69899308681488, 35.83422414958477, 37.02295996248722, 39.09210853278637, 39.418940395116806, 40.91894410550594, 42.70476847887039, 42.98227518796921, 47.753979340195656, 48.79889287054539, 50.35916514694691, 48.485561683773994, 45.83760157227516, 46.907221376895905, 48.263645991683006, 48.64441215991974, 48.13482530415058, 48.61552990972996, 52.705755829811096, 47.09950625896454, 39.88609492778778, 24.81570839881897, 7.298316350206733, 0.8904251013882458, 3.2450137613341212, 4.33422127738595, 0.27649628988001496, 0.1282724185148254, 0.049257569553446956, 0.10151914510061033, 0.10487568608368747, 0.2726004895521328, 14.504625387489796, 32.26755693554878, 27.127282060682774, 37.83310689032078, 43.54307569563389, 17.833837643265724, 0.3808013757225126, 0.05181346306926571, 0.0789604606688954, 0.007055688411128358, 0.040565558228990994, 0.03617396985646337, 0.03887360624503344, 0.02953457944386173, 0.03779202248551883, 0.006838857443653978, 0.015853459954087157, 0.005626380634566885, 0.023628759336133953, 0.05142311565577984, 0.02897712078265613, 0.05067235164460726, 0.061387023379211314, 0.071907059464138, 0.10335817220038734, 0.11773845602874644, 0.12912333535496145, 0.14885247044730932, 0.22086702258093283, 0.21900650288444012, 0.11428004785557278, 0.0777241910691373, 0.10753534297691658, 0.1719846940250136, 0.09998927445849404, 0.19196899433154613, 0.19689476204803213, 0.16362440044758841, 0.17555761558469385, 0.11060515520512126, 0.17402883589966223, 0.09206317437929101, 0.15167101373663172, 0.11208584372070618, 0.17611259361729026, 0.2719601051649079, 5.713746752589941, 44.70397040247917, 60.06559610366821, 47.88103312253952, 59.03487481176853, 62.81974531710148, 45.49881935119629, 42.06406585872173, 11.798496097326279, 0.16719960782211274, 1.2537263380363584, 9.809398781508207, 8.75933462753892, 3.999462565407157, 6.4859123434871435, 22.565932720899582, 44.8495139926672, 50.606224089860916, 53.35131078958511, 53.1858866661787, 57.004700750112534, 54.17449101805687, 53.22540834546089, 45.00505864620209, 44.03977744281292, 44.2652003467083, 43.12895871698856, 42.41432726383209, 41.21101923286915, 39.56146314740181, 39.65084195137024, 38.377990052103996, 39.203324764966965, 41.8452849984169, 41.617779806256294, 41.25206843018532, 40.91285303235054, 42.06628113985062, 38.52520555257797, 40.13597711920738, 39.812489077448845, 39.25771124660969, 39.0273904055357, 39.7920385748148, 42.17713639140129, 40.201819986104965, 40.885604694485664, 41.27959415316582, 41.7801982909441, 41.214078068733215, 40.716194584965706, 40.23828662931919, 39.775254875421524, 38.964283391833305, 39.489453211426735, 40.41020080447197, 41.497797444462776, 46.238195076584816, 52.12747626006603, 50.892523527145386, 51.57098472118378, 52.85888761281967, 52.14951127767563, 52.1422004699707, 53.39861825108528, 51.36169575154781, 49.351827800273895, 43.814856112003326, 44.0840070694685, 48.420288786292076, 53.00799161195755, 51.69582702219486, 52.58589506149292, 49.8596515506506, 52.73360453546047, 51.35445713996887, 53.10202516615391, 52.343889847397804, 51.75212860107422, 41.917405128479004, 38.453621193766594, 38.524916768074036, 39.57898400723934, 39.70018610358238, 40.119087025523186, 39.13221538066864, 40.42139880359173, 41.65089502930641, 43.62905368208885, 43.79097059369087, 45.269566252827644, 42.334759533405304, 39.79089103639126, 41.517510786652565, 39.32602018117905, 38.926749005913734, 38.85936342179775, 36.82488039135933, 38.72824005782604, 38.23922909796238, 38.691781014204025, 41.06246620416641, 41.50293476879597, 41.85996361076832, 43.967357128858566, 44.9450408667326, 49.25577275454998, 51.12840346992016, 52.42811992764473, 48.99511054158211, 46.508071795105934, 47.59433090686798, 49.589505046606064, 50.568682104349136, 48.202796056866646, 50.37859730422497, 53.36614139378071, 48.083463460206985, 40.37057273089886, 27.10936602205038, 7.771701123565435, 1.2922398839145899, 4.909603027626872, 13.458843603730202, 6.392203196883202, 1.0454804124310613, 0.09442524489713833, 0.6812465633265674, 0.6148742185905576, 0.7851591124199331, 18.810911513864994, 40.09203627705574, 35.03871403634548, 45.43242551386356, 48.06791089475155, 22.658562250435352, 0.6359076336957514, 0.1557889091782272, 0.13344570732442662, 0.08482671502861194, 0.10085650370456278, 0.157094910973683, 0.27066645270679146, 0.09647237020544708, 0.1647499416139908, 0.13517093349946663, 0.10206760707660578, 0.11057212221203372, 0.08505285484716296, 0.21027534327004105, 0.09401678165886551, 0.07840833248337731, 0.20632895815651864, 0.12890275422250852], [0.06823574396548793, 0.06848391814855859, 0.059213632775936276, 0.04352868301793933, 0.01108337255573133, 0.11482767120469362, 0.048490886474610306, 0.05098301466205157, 0.041451912620686926, 0.0496936035779072, 0.04687382090196479, 0.022236497716221493, 0.0886163066024892, 0.010723164687078679, 0.02087515953462571, 0.07256711076479405, 0.07727631978923455, 0.015506923373322934, 0.06555467611178756, 0.13200754387071356, 0.0756825650751125, 0.03173560391587671, 0.14278066344559193, 19.888917468488216, 44.525539577007294, 39.187358021736145, 30.225538909435272, 46.137975454330444, 45.079694241285324, 34.441823065280914, 13.175536505877972, 0.23480320523958653, 0.49546307302080095, 3.948619868606329, 2.1421158174052835, 3.786082877777517, 0.715987446019426, 4.5288188103586435, 21.519968546926975, 39.587674140930176, 51.52719967067242, 48.538994416594505, 51.3179524987936, 49.046157002449036, 45.195322036743164, 43.7269402295351, 40.89594013988972, 39.580735713243484, 40.03027819097042, 37.00995326042175, 37.9137347638607, 35.743116438388824, 36.505150347948074, 38.12406487762928, 36.74203343689442, 38.181848376989365, 37.001749500632286, 36.74169905483723, 35.96335642039776, 34.89302605390549, 37.17244394123554, 36.83935761451721, 37.94927425682545, 37.38364040851593, 37.709286734461784, 35.99875912070274, 37.77671031653881, 36.36598661541939, 37.104967162013054, 36.720344200730324, 37.720477133989334, 37.23533056676388, 36.468269526958466, 34.875771179795265, 35.74234887957573, 36.26354791224003, 37.34354496002197, 35.78706108033657, 36.70084364712238, 36.69383302330971, 42.21386522054672, 43.322619125247, 45.30044339597225, 45.572698786854744, 48.208172768354416, 46.15093655884266, 45.91865502297878, 49.744776114821434, 50.56631863117218, 42.48561143875122, 44.59073267877102, 49.899834394454956, 51.718485206365585, 49.39505808055401, 47.190606370568275, 49.10733371973038, 48.71303267776966, 51.933071091771126, 48.63510265946388, 49.50024023652077, 45.603613927960396, 37.02299416065216, 35.517313554883, 36.31812058389187, 36.85940533876419, 36.273681968450546, 34.084847420454025, 36.31721243262291, 36.67297974228859, 38.50805327296257, 39.10934440791607, 38.954593911767006, 37.904630452394485, 36.222650706768036, 35.56408904492855, 34.487443417310715, 34.29651506245136, 36.88791900873184, 35.668237656354904, 35.048414915800095, 32.913579270243645, 36.219082698225975, 34.755332842469215, 37.400606498122215, 38.88659656047821, 40.03544211387634, 42.155621945858, 43.441062569618225, 44.69949044287205, 47.09971524775028, 46.14189304411411, 49.420661106705666, 47.32760801911354, 49.184784963727, 42.88164138793945, 42.66866661608219, 46.902608424425125, 46.71097710728645, 43.909911811351776, 39.79784846305847, 31.015685610473156, 11.131831370294094, 3.0537467496469617, 10.922033227980137, 4.733673417940736, 1.4621262741275132, 0.28622415382415056, 0.06256341279367916, 0.018131419165001716, 0.01953121172846295, 0.3943299560341984, 0.2941506472416222, 14.137398842722178, 37.25269563496113, 43.78410056233406, 49.91202414035797, 33.52270558476448, 10.980854071676731, 0.07336494920309633, 0.06663970343652181, 0.050140376479248516, 0.041813616844592616, 0.07831613547750749, 0.04449891494004987, 0.056438542233081535, 0.027891201025340706, 0.1147337895235978, 0.040075429060379975, 0.04654802178265527, 0.1270246901549399, 0.027524949291546363, 0.06087458896217868, 0.08174136964953505, 0.033796748393797316, 0.05375010114221368, 0.07177403691457585, 0.020622256015485618, 0.05748199073423166, 0.08973404779681005, 0.010984689179167617, 0.06566789816133678, 0.05477076570969075, 0.041900121577782556, 0.058454764512134716, 0.020975086008547805, 0.032674580288585275, 0.020781947641808074, 0.04265519746695645, 0.05412980244727805, 0.03380763570021372, 0.05570309986069333, 0.04951239337970037, 0.011602795220824191, 0.048213597838184796, 0.018963283218909055, 0.1275545687531121, 0.07171796765760519, 0.019858875493810046, 0.5107932316605002, 24.78899583220482, 53.365856409072876, 43.04922379553318, 39.187289625406265, 52.03639134764671, 46.388260424137115, 38.78796525299549, 15.06576407700777, 0.1693208291544579, 0.04826588956348132, 5.8859592117369175, 5.798942456021905, 5.506566669791937, 2.6369646890088916, 6.232014242559671, 25.680806078016758, 43.319396898150444, 52.078394293785095, 51.10275864601135, 52.02441059052944, 50.972091257572174, 47.58700110018253, 46.341063156723976, 42.78729625046253, 40.314077362418175, 41.33760944008827, 38.13543386757374, 39.74687419831753, 37.86100499331951, 37.366579324007034, 38.83761338889599, 38.12585838139057, 39.454517886042595, 39.45222660899162, 38.77102196216583, 37.39374786615372, 36.95019006729126, 39.798486828804016, 39.62138973176479, 38.465567752718925, 38.535316810011864, 39.26018111407757, 38.48059594631195, 39.442658722400665, 38.66316854953766, 38.7748521566391, 38.45490172505379, 39.60605375468731, 39.08240005373955, 38.05813081562519, 36.275129690766335, 37.231633365154266, 37.50157468020916, 38.278841972351074, 36.18268445134163, 36.85844399034977, 39.07454967498779, 43.72165471315384, 45.301518738269806, 48.60558204352856, 47.53814332187176, 50.03629267215729, 47.901745811104774, 49.25589434802532, 51.686593517661095, 52.98594519495964, 43.31751599907875, 46.74047872424126, 50.81373855471611, 53.41941073536873, 51.065003871917725, 50.88394358754158, 50.95114678144455, 50.46768732368946, 53.56119632720947, 50.72772637009621, 50.745870396494865, 47.51052260398865, 38.630862683057785, 37.61711128056049, 38.007430136203766, 38.400146663188934, 38.04105453193188, 37.448765113949776, 38.09644415974617, 39.175977632403374, 40.874980464577675, 42.0147331058979, 40.11179901659489, 40.007213428616524, 38.48756097257137, 35.92779032886028, 35.22392749786377, 36.4496923238039, 38.70457872748375, 37.32750982046127, 37.281410694122314, 35.122195556759834, 37.28673420846462, 36.75777219235897, 38.190766498446465, 41.74026243388653, 41.92973546683788, 45.35641439259052, 44.24893721938133, 46.90373316407204, 51.01160153746605, 49.733217135071754, 49.299588203430176, 47.397980242967606, 49.272301867604256, 44.74448002874851, 46.43885850906372, 47.151202484965324, 49.04893845319748, 46.072204783558846, 42.36179128289223, 34.34898644685745, 13.890082463622093, 3.5538652259856462, 9.15108410641551, 4.840951636433601, 1.4986469456925988, 0.11279109923634678, 0.11295452757622115, 0.08132984876283444, 0.09774818885489367, 0.3206884826067835, 0.5341609090100974, 16.65734477341175, 39.90664802491665, 44.82992224395275, 48.84831681847572, 38.39504353702068, 13.749851938337088, 0.2002499671652913, 0.05661566319759004, 0.02702905549085699, 0.041951875246013515, 0.06437175208702683, 0.045444155039149337, 0.08090144401649013, 0.049282412946922705, 0.11124157652375288, 0.013297317818796728, 0.023609066447534133, 0.08528201520675793, 0.009290020934713539, 0.04199482704279944, 0.059670265109161846, 0.03806780827289913, 0.07488536488381214, 0.06373711934429593, 0.11820865111076273, 0.14675450802315027, 0.18272466928465292, 0.1355297173722647, 0.17489554564235732, 0.2168305407394655, 0.15133909560972825, 0.12128195885452442, 0.08919685162254609, 0.14758998819161206, 0.11269726208411157, 0.1523638828075491, 0.17464701522840187, 0.11118943322799169, 0.22099452355178073, 0.1567835354944691, 0.11086210157372989, 0.14360110770212486, 0.1627574086887762, 0.34751441970001906, 0.13405458012130111, 0.12275697736185975, 0.6721527012996376, 28.2479103282094, 60.73903776705265, 51.04207210242748, 43.61371770501137, 55.77405318617821, 56.33341737091541, 45.6180265545845, 17.543489523231983, 0.46506589162163436, 1.3869287841953337, 10.381292793899775, 8.98764157667756, 8.215056583285332, 2.0331262657418847, 6.823377935215831, 28.583179637789726, 44.45707865059376, 51.473645344376564, 50.62125988304615, 53.59055735170841, 53.38006004691124, 49.78362523019314, 48.613443821668625, 45.3580255061388, 42.12490439414978, 43.914403170347214, 41.33709266781807, 42.18052200973034, 40.28848193585873, 40.27889885008335, 42.28170298039913, 40.62064491212368, 41.75591379404068, 41.9109682738781, 41.078641936182976, 39.35794986784458, 37.53812491893768, 41.148212403059006, 41.47469848394394, 40.98689965903759, 41.43322370946407, 41.56790368258953, 39.28888097405434, 42.49031938612461, 41.18780627846718, 40.63004180788994, 41.45610988140106, 41.45508773624897, 41.4615473896265, 40.76619230210781, 38.24044123291969, 38.5068791359663, 39.03834521770477, 41.082327738404274, 38.64410117268562, 39.90517370402813, 39.93493750691414, 44.023514315485954, 47.744023874402046, 48.31281915307045, 49.62820217013359, 51.901848167181015, 50.447795391082764, 50.11701934039593, 55.377430468797684, 53.88252608478069, 46.78185850381851, 48.77624228596687, 51.31355993449688, 56.46180868148804, 52.51954682171345, 51.9971926510334, 51.37803867459297, 51.09384812414646, 56.280406415462494, 51.39901354908943, 51.9623751193285, 49.14058953523636, 40.67018285393715, 38.134077340364456, 39.146069437265396, 40.05127586424351, 40.63842415809631, 38.734973296523094, 41.036897376179695, 40.684432089328766, 43.73372286558151, 44.061451479792595, 42.12211914360523, 42.1419008821249, 39.827752858400345, 39.10014130175114, 37.0353738963604, 37.997353076934814, 41.03643000125885, 38.586579859256744, 40.00472076237202, 37.22423896193504, 39.20133747160435, 38.62471841275692, 40.69640524685383, 43.440633192658424, 44.42321106791496, 47.612376138567924, 46.22081860899925, 48.25271777808666, 51.70533411204815, 51.02824844419956, 51.34922482073307, 48.98007854819298, 51.42209731042385, 45.57442769408226, 47.04294629395008, 51.925095319747925, 53.15048396587372, 48.92212025821209, 44.195401892066, 39.10451486706734, 14.91424910724163, 6.124220676720142, 19.845818281173706, 9.942001216113567, 10.567135121673346, 1.4582004910334945, 0.2572198648704216, 0.2873845462454483, 0.21038904029410332, 0.8372929680626839, 1.112581961788237, 21.164425425231457, 48.5535704344511, 50.104282423853874, 56.90908648073673, 44.227502569556236, 16.207570508122444, 0.45241957646794617, 0.1626853461493738, 0.16009391489205882, 0.15025642089312896, 0.24361028656130657, 0.1898380508646369, 0.16497711301781237, 0.16675718390615657, 0.29441318940371275, 0.10177553485846147, 0.10286085904226638, 0.1684985146857798, 0.09990330407163128, 0.22831209964351729, 0.18463068263372406, 0.09160259753116407, 0.13382240664213896, 0.13439081754768267], [0.053486289907596074, 0.027184279388166033, 0.022650065075140446, 0.02979550372401718, 0.013571360486821504, 0.057271833065897226, 0.03662294693640433, 0.03859550124616362, 0.043602467339951545, 0.03163022265653126, 0.020202608611725736, 0.017953591304831207, 0.029153406831028406, 0.09868575885775499, 0.021924255779595114, 0.05940817565715406, 0.09062851386261173, 0.020042349242430646, 0.10663623106665909, 0.03587742990930565, 0.02935148233518703, 0.07127166973077692, 0.05462190572870895, 5.863492917269468, 35.67566245794296, 46.52912646532059, 25.387917794287205, 30.68715713918209, 45.1612264662981, 34.42136876285076, 19.03329648077488, 0.462959231226705, 0.0841479838709347, 4.998809415847063, 4.786323867738247, 3.317925911396742, 3.5694189788773656, 1.3991847890429199, 7.336576022207737, 29.74556766450405, 50.73113098740578, 51.78900182247162, 52.442486956715584, 49.20852988958359, 48.40369887650013, 45.10725796222687, 43.09179291129112, 40.258638337254524, 40.37999242544174, 38.472479581832886, 40.63354142010212, 39.161074832081795, 42.18204952776432, 41.16547107696533, 41.46188177168369, 40.25280185043812, 37.22170069813728, 37.21788950264454, 36.62743918597698, 36.90746136009693, 36.552966982126236, 37.676144912838936, 38.43024864792824, 38.27504977583885, 36.843184009194374, 37.2178553044796, 36.93339116871357, 37.27955639362335, 36.75880193710327, 35.38555182516575, 37.54423879086971, 35.52553631365299, 36.94415219128132, 33.72786797583103, 38.1817951798439, 36.02860651910305, 36.721271350979805, 36.290127485990524, 37.0279186964035, 35.729380175471306, 39.02072176337242, 40.417982786893845, 41.6572292894125, 42.75890417397022, 43.83572459220886, 44.5344614982605, 48.28053988516331, 47.587422877550125, 51.353567987680435, 38.43993812799454, 47.833778858184814, 52.88560777902603, 47.87138544023037, 46.47114917635918, 45.74720822274685, 48.17864455282688, 49.40956570208073, 50.242283418774605, 47.93008089065552, 46.935571655631065, 39.833490550518036, 36.93554565310478, 34.677452221512794, 35.5731325596571, 34.91062290966511, 35.746828839182854, 35.582958832383156, 35.35047210752964, 37.82900311052799, 36.76387846469879, 37.936700731515884, 39.04952421784401, 37.22868092358112, 34.17087480425835, 34.342747181653976, 33.96852046251297, 36.08012035489082, 35.89027874171734, 34.72920544445515, 34.161208122968674, 33.85220870375633, 34.1888402402401, 36.66926734149456, 38.17240588366985, 38.69761750102043, 40.30015870928764, 41.87179237604141, 41.905116587877274, 44.66936565935612, 45.64014136791229, 47.12219104170799, 48.98591883480549, 46.41807362437248, 46.08044654130936, 50.020135939121246, 43.38061161339283, 41.95572227239609, 40.92078700661659, 43.43433313071728, 34.41399335861206, 16.574566215276718, 2.779056401923299, 2.189303347840905, 7.768581015989184, 2.7418770594522357, 0.18398358923150226, 0.05238064200966619, 0.08872107559000142, 0.07763769375742413, 0.1815802330384031, 0.0801107227744069, 1.4290155633352697, 20.297995917499065, 32.183471247553825, 31.979460194706917, 41.659497767686844, 26.991581842303276, 4.031919948756695, 0.07115312648238614, 0.031283639691537246, 0.06527861944050528, 0.06351768111926503, 0.03987478201452177, 0.05800945364171639, 0.013309687565197237, 0.010542604795773514, 0.0296113397780573, 0.037085204749018885, 0.009907785588438855, 0.06893501777085476, 0.06243026407901198, 0.027173980233783368, 0.04078495563589968, 0.04333066688559484, 0.027289109602861572, 0.05789223883766681, 0.0434961992141325, 0.05280988538288511, 0.0051785079631372355, 0.06404423489584588, 0.04018983854621183, 0.04560209890769329, 0.02517434495530324, 0.054976900937617756, 0.02967620162962703, 0.03512464354571421, 0.02137494033377152, 0.014377941424754681, 0.03032630444067763, 0.05165318143554032, 0.019370889276615344, 0.08177357143722475, 0.05702116897737142, 0.04462573313503526, 0.024925718062149826, 0.03643830059445463, 0.16410903772339225, 0.08653712793602608, 0.04048358430736698, 9.838913697749376, 46.03130757808685, 51.986450627446175, 30.17144501209259, 38.93189772963524, 52.444683238863945, 38.29399175941944, 20.97491629421711, 0.5613320041447878, 0.18855510017601773, 3.6514755757525563, 8.846044074743986, 5.0489068776369095, 6.327545391395688, 4.1157918982207775, 9.85596813261509, 34.13837514817715, 52.53353767096996, 52.808707505464554, 54.28919166326523, 51.23604029417038, 50.41992388665676, 47.21991039812565, 43.80991257727146, 41.67666904628277, 42.56304368376732, 40.79672746360302, 41.05447143316269, 40.845414251089096, 43.60596612095833, 43.38900916278362, 44.13347281515598, 42.05037899315357, 38.34718510508537, 37.45442681014538, 36.9959282130003, 38.502285182476044, 37.638378739356995, 40.1697801053524, 40.05393572151661, 38.969701901078224, 38.87121878564358, 37.81001552939415, 38.29960785806179, 38.86808015406132, 38.24425622820854, 38.302750289440155, 40.120929926633835, 38.37139740586281, 38.88812407851219, 35.996076464653015, 38.878085017204285, 37.62830168008804, 38.398467153310776, 37.470245361328125, 38.64707261323929, 37.48777762055397, 39.73155342042446, 42.15655289590359, 44.9287473410368, 45.65720625221729, 46.18922710418701, 47.16629147529602, 49.10612538456917, 49.678975045681, 52.7286572009325, 39.84582468867302, 50.312119871377945, 53.74861367046833, 48.901912942528725, 48.00196163356304, 47.138579562306404, 49.89802189171314, 51.456778049468994, 52.29354254901409, 49.1882161796093, 48.71183194220066, 41.79596744477749, 38.221525847911835, 37.78841748833656, 36.105563789606094, 36.187456995248795, 37.97532945871353, 38.59287612140179, 37.304289266467094, 39.96093951165676, 39.895199239254, 39.77791853249073, 41.221563667058945, 39.90662902593613, 37.468341663479805, 36.18544690310955, 35.347192883491516, 38.965123146772385, 38.21804903447628, 36.3772302120924, 36.14357315003872, 36.2047004699707, 36.52295619249344, 37.84614019095898, 40.45767165720463, 40.74881963431835, 41.98844611644745, 44.42276269197464, 44.28047172725201, 46.5363422781229, 48.20355601608753, 47.81007573008537, 50.55023029446602, 47.528381645679474, 46.72688685357571, 49.49248485267162, 45.37829361855984, 46.181631311774254, 44.54949729144573, 46.004648208618164, 37.64256611466408, 21.587171740829945, 5.407728273421526, 2.8496984113007784, 12.560490109026432, 2.9372466634958982, 0.1489854633109644, 0.11382420590962283, 0.06551241080160253, 0.09650477979448624, 0.08603821173892356, 0.17822590365540236, 1.5182426129467785, 23.344374150037766, 36.734699830412865, 39.23857167363167, 49.58337977528572, 33.49612981081009, 5.939461290836334, 0.08473435475025326, 0.027196161172469147, 0.07996350293979049, 0.03530962756485678, 0.050851929117925465, 0.0685972960491199, 0.004612259954228648, 0.027707435983757023, 0.0952441306435503, 0.036691369241452776, 0.022921691124793142, 0.045463996357284486, 0.03184608372976072, 0.0006216532756297966, 0.051910543406847864, 0.0555542695656186, 0.05270694578939583, 0.02202173873229185, 0.15392595523735508, 0.1462967216502875, 0.11657439739792608, 0.1037217874545604, 0.2233636667369865, 0.14892569073708728, 0.13746979529969394, 0.11920912555069663, 0.17576216632733122, 0.1338481591665186, 0.0752640308928676, 0.10596860243822448, 0.14124361623544246, 0.17571607895661145, 0.12513936788309366, 0.18542675476055592, 0.1759296393720433, 0.09729507059091702, 0.10823802324011922, 0.1761977031128481, 0.2655458712251857, 0.12593235267559066, 0.18954188941279426, 9.994215164333582, 52.51125566661358, 60.381628945469856, 36.094966158270836, 41.258326694369316, 54.13436517119408, 46.760055273771286, 25.431607849895954, 0.9228326717857271, 0.2507469418924302, 11.30620876327157, 15.17945397645235, 10.22657174617052, 8.543836791068316, 4.702494191005826, 11.330672800540924, 35.42431354522705, 53.454410657286644, 53.452240973711014, 55.46219252049923, 54.9809255450964, 52.25439324975014, 50.41589990258217, 47.3163378238678, 43.54946315288544, 45.14002360403538, 42.84973829984665, 44.213754907250404, 43.952572122216225, 47.1149942278862, 45.7851567864418, 47.34346456825733, 44.74749706685543, 40.89372105896473, 39.51018489897251, 39.36798132956028, 39.272758439183235, 40.41909992694855, 42.272537872195244, 42.07572363317013, 41.380007565021515, 40.49153544008732, 39.89592120051384, 40.776983723044395, 40.753880962729454, 39.518719241023064, 38.844779804348946, 41.99977330863476, 38.68762783706188, 39.962957203388214, 36.53495594859123, 41.565992385149, 39.49532009661198, 39.887394458055496, 39.385942965745926, 40.128210335969925, 39.06552515923977, 41.51913709938526, 43.85381922125816, 45.672025457024574, 48.24413023889065, 47.90529862046242, 46.625356301665306, 53.02233584225178, 51.76296181976795, 54.394123032689095, 41.29702001810074, 50.69778397679329, 55.660507678985596, 49.922188594937325, 50.7852628827095, 49.32923421263695, 52.37139277160168, 54.256319627165794, 53.16184535622597, 51.149340346455574, 51.71770244836807, 43.38822640478611, 40.37242703139782, 39.00070823729038, 38.11440959572792, 36.82927295565605, 39.237283542752266, 41.20124615728855, 39.606684520840645, 42.64093950390816, 42.18018762767315, 42.825089022517204, 42.93108053505421, 41.712295934557915, 38.289656192064285, 38.15333850681782, 37.471111714839935, 40.36048427224159, 39.979816898703575, 38.308358788490295, 38.08121457695961, 37.81885005533695, 39.1693127900362, 41.90225914120674, 41.95377677679062, 42.72255912423134, 45.05422420799732, 46.527830734848976, 46.48227497935295, 48.38398553431034, 49.38192218542099, 49.247124418616295, 52.58369877934456, 47.93734610080719, 46.28394842147827, 49.183094054460526, 46.81351460516453, 43.802438378334045, 44.493769481778145, 46.577197685837746, 42.036764323711395, 22.158045507967472, 5.861315634101629, 3.7696240609511733, 13.867105096578598, 8.084310349076986, 1.686084356624633, 0.18367571668932214, 0.3239334194222465, 0.23004381218925118, 0.3175155638018623, 0.5130193184595555, 2.7780375815927982, 27.640756107866764, 45.85747830569744, 43.34248825907707, 50.24332836270332, 36.88255749642849, 6.056562457233667, 0.18933336075861007, 0.10422881532576866, 0.11796839564340189, 0.17556545266415924, 0.13130392850143835, 0.1461846276652068, 0.196676347986795, 0.08799391929642297, 0.14698831422720104, 0.09424201605725102, 0.06987753789871931, 0.1383629403426312, 0.10894364982959814, 0.13961126242065802, 0.19619178492575884, 0.1984135524253361, 0.14052371814614162, 0.16807327891001478], [0.04017520710476674, 0.006999995794103597, 0.032353007700294256, 0.018343005467613693, 0.04688116074248683, 0.03324324723507743, 0.024196615486289375, 0.054379034190787934, 0.027077295089839026, 0.03787253066548146, 0.024638837167003658, 0.026647445010894444, 0.005359532160582603, 0.013807225222990382, 0.0271188646365772, 0.026350739935878664, 0.05500338076672051, 0.04845170478802174, 0.03871921726386063, 0.04980052850442007, 0.07529843685915694, 0.012805505830328912, 0.035650711215566844, 0.19118996191537008, 14.833938516676426, 43.62195946276188, 39.46090914309025, 29.076064489781857, 39.26993139088154, 37.83220253884792, 16.47533643990755, 0.9545475512277335, 0.14784435188630596, 1.8536649830639362, 4.607251826673746, 4.209654461592436, 1.276276702992618, 0.9440569079015404, 1.0735289636068046, 13.550114706158638, 39.19181518256664, 51.985816061496735, 53.64528961479664, 51.31447948515415, 49.10411149263382, 47.223979979753494, 44.67490956187248, 41.43332630395889, 40.94450153410435, 42.66702130436897, 45.15313670039177, 43.30016992986202, 43.22316326200962, 43.66903893649578, 40.46361833810806, 40.588038861751556, 38.24478819966316, 37.173165902495384, 36.17633879184723, 36.83083467185497, 37.483373656868935, 37.78489127755165, 36.365633234381676, 36.28412000834942, 38.33732843399048, 38.89236845076084, 37.69363917410374, 37.89442420005798, 37.17287711799145, 38.12145061790943, 36.60503178834915, 36.43040455877781, 36.97702422738075, 36.2897665053606, 37.35107995569706, 38.65972213447094, 37.391790971159935, 38.40146139264107, 36.110796108841896, 35.75974814593792, 37.551089823246, 38.04068595170975, 38.50260816514492, 38.726047575473785, 41.880919486284256, 43.454757034778595, 47.087909281253815, 48.170171007514, 51.73777677118778, 42.951838821172714, 47.20538757741451, 51.41197845339775, 46.43589086830616, 45.81665329635143, 40.51907256245613, 42.641460075974464, 42.377963215112686, 42.75242172181606, 40.326673686504364, 38.625957146286964, 35.50869561731815, 34.94970001280308, 36.26518942415714, 34.94405351579189, 34.90162879228592, 35.5717608332634, 34.50830049812794, 36.93670079112053, 37.2537861764431, 36.476982459425926, 37.154265716671944, 39.66245412826538, 37.22532570362091, 34.415840059518814, 33.48001107573509, 34.875778779387474, 35.05506835877895, 36.02745518088341, 35.310756638646126, 35.88092744350433, 35.32501347362995, 34.58959333598614, 33.87405753135681, 36.45590119063854, 35.781509578228, 37.1240459382534, 39.36274901032448, 40.76800100505352, 42.755776941776276, 43.4427572786808, 47.55868121981621, 46.56487874686718, 48.62017326056957, 47.77998134493828, 46.30051173269749, 49.03543017804623, 46.37194789946079, 45.33500634133816, 39.87330861389637, 23.365898095071316, 6.578894779086113, 0.6193940166849643, 0.16242091893218458, 0.4418909054948017, 0.20395154744619504, 0.08969405345851555, 0.042043990615638904, 0.06175356640596874, 0.04016261656943243, 0.1981320112827234, 0.38368803332559764, 3.9817415038123727, 30.224022790789604, 34.431259632110596, 34.682528749108315, 32.342849895358086, 15.587560627609491, 0.9156457730568945, 0.016130898875417188, 0.029317004009499215, 0.007065065910865087, 0.0023237499544848106, 0.016826554710860364, 0.03188016315107234, 0.016008244128897786, 0.08828546458971687, 0.046561361887142994, 0.008329561242135242, 0.03286339750047773, 0.03927322308300063, 0.02419914806523593, 0.014131943589745788, 0.03707564217620529, 0.0297222871449776, 0.02744419063674286, 0.013387458147917641, 0.04741580021800473, 0.024328033141500782, 0.018693753736442886, 0.045503953588195145, 0.026612675392243546, 0.006972787268750835, 0.016467410896439105, 0.04783941440109629, 0.025968838162953034, 0.05737104707804974, 0.038291409946396016, 0.06672608200460672, 0.07100933537003584, 0.017100804252550006, 0.029440619837259874, 0.05599094554781914, 0.017728505335981026, 0.034597570265759714, 0.04723843805550132, 0.03224749285436701, 0.054073655264801346, 0.013622936039610067, 0.023362706815532874, 0.37456264486536384, 23.243179880082607, 52.07601562142372, 40.42994074523449, 34.303677678108215, 45.86052194237709, 42.48137466609478, 21.035948619246483, 1.093604473862797, 0.234379320172593, 0.6730958819389343, 2.8335003554821014, 2.365666846744716, 3.463594657368958, 3.6041726265102625, 2.335031940601766, 18.340244069695473, 42.36045375466347, 53.72639626264572, 55.15589475631714, 54.420345425605774, 51.3008002191782, 49.31763343513012, 45.22425748407841, 43.07242535054684, 44.62723731994629, 45.22182181477547, 45.274600982666016, 45.909353122115135, 46.25995270907879, 45.176543444395065, 43.23827505111694, 41.612034514546394, 40.21796531975269, 39.29500624537468, 38.804296776652336, 39.653049632906914, 39.28639590740204, 41.10020577907562, 38.519247472286224, 38.2388187199831, 40.412879660725594, 39.673340544104576, 40.08637838065624, 38.4977862238884, 39.39431391656399, 39.259808734059334, 39.53168414533138, 37.428432404994965, 38.859845995903015, 37.8594546765089, 39.876443445682526, 39.757772013545036, 40.04995733499527, 39.45150464773178, 38.032512590289116, 38.20452556014061, 38.37163679301739, 39.47307229042053, 41.534336283802986, 42.71713301539421, 45.051473155617714, 45.424202755093575, 49.02088075876236, 49.31047081947327, 52.09528058767319, 44.56335514783859, 49.49233666062355, 53.005449548363686, 48.3800033479929, 48.070183172822, 43.08858968317509, 45.23555427789688, 45.826851949095726, 45.480242148041725, 44.92436237633228, 41.652278155088425, 37.32997588813305, 37.161333337426186, 37.347511947155, 37.53653660416603, 37.121294885873795, 37.50789374113083, 37.40280278027058, 39.6035610884428, 38.977917060256004, 36.807264536619186, 39.08275343477726, 39.91427421569824, 37.75515787303448, 35.75822062790394, 36.056933999061584, 35.61945967376232, 36.37897051870823, 38.23310762643814, 38.03255818784237, 37.46527902781963, 37.12551265954971, 36.997812911868095, 36.119987815618515, 38.76082330942154, 37.168142572045326, 39.4598376005888, 41.83779940009117, 42.41914160549641, 44.74511079490185, 47.04749085009098, 49.04125526547432, 49.91824820637703, 50.03206729888916, 47.878498658537865, 47.618816792964935, 47.515990510582924, 46.75867974758148, 45.97501739859581, 43.252296298742294, 28.931930623948574, 7.715323073789477, 1.0793184279464185, 0.2692413213662803, 0.7670372317079455, 0.27832102321553975, 0.12704017135547474, 0.0862044825043995, 0.03485077621007804, 0.04642616113414988, 0.4922239843290299, 0.6144314236007631, 4.836128745228052, 33.88264887034893, 39.45166423916817, 38.06022070348263, 37.64371745288372, 21.022649332880974, 1.6733684577047825, 0.03127322735963389, 0.040272157566505484, 0.021421044402814005, 0.004475726582313655, 0.044866957105114125, 0.017319368598691653, 0.05598718656983692, 0.03254090835980605, 0.08887417323421687, 0.03480298189970199, 0.04750204519950785, 0.00937477048864821, 0.060655722190858796, 0.03825092579063494, 0.030605854772147723, 0.006369268139678752, 0.028512267308542505, 0.02459622861351818, 0.14488600281765684, 0.0920352473622188, 0.10886326039326377, 0.1937177762738429, 0.1074307001545094, 0.12314142470131628, 0.13996348570799455, 0.195739816990681, 0.13859818631317466, 0.21985749393934384, 0.11100594463641755, 0.14284849574323744, 0.08481537501211278, 0.08878752749296837, 0.10284960808348842, 0.21122186357388273, 0.16323995310813189, 0.14997906546341255, 0.1884695453918539, 0.2574469323735684, 0.20520298654446378, 0.11750472403946333, 0.1251882902579382, 0.5388035473879427, 25.055494531989098, 60.94843693077564, 49.1639506816864, 40.497706308960915, 50.1527564227581, 48.581088557839394, 24.394540898501873, 1.9122879998758435, 0.769266999559477, 4.690936636179686, 15.698943100869656, 15.47662653028965, 12.313491962850094, 4.37185968272388, 3.010724983178079, 18.88516142964363, 42.054095193743706, 53.05412493646145, 56.09166294336319, 57.743445709347725, 54.65409368276596, 52.3347095400095, 47.694972306489944, 45.54259680211544, 46.88730664551258, 46.7889641225338, 48.08846399188042, 50.088083893060684, 49.08225126564503, 47.834782004356384, 45.068439245224, 44.1051871329546, 42.1597371250391, 41.27467341721058, 41.39040760695934, 41.13223806023598, 40.97194366157055, 43.09380680322647, 40.0829091668129, 41.16882249712944, 43.27479109168053, 42.5553110986948, 41.22024893760681, 41.333015486598015, 41.48425877094269, 40.752562433481216, 41.33138917386532, 40.64223155379295, 41.04431077837944, 39.221917167305946, 40.505655482411385, 42.090041264891624, 41.53612598776817, 41.90956234931946, 39.389765560626984, 38.95962864160538, 40.815319865942, 41.893945187330246, 41.96875177323818, 43.522689789533615, 46.52808532118797, 47.28991024196148, 50.60598470270634, 52.4709702283144, 52.513584941625595, 47.45407663285732, 50.35726144909859, 56.03985272347927, 49.663870856165886, 50.54803021252155, 44.62977938354015, 47.409178242087364, 46.11619122326374, 47.65622578561306, 46.040552482008934, 41.426794454455376, 38.16739395260811, 38.91686953604221, 39.84498493373394, 39.12477917969227, 37.96001248061657, 39.44994293153286, 40.32598592340946, 41.19610883295536, 42.30879172682762, 39.16061885654926, 41.6137520223856, 43.61445486545563, 42.108580470085144, 36.86630576848984, 38.22170823812485, 38.35725836455822, 39.70713593065739, 40.128639712929726, 39.709962978959084, 39.911523163318634, 39.78600449860096, 39.30113151669502, 39.277268797159195, 40.876979157328606, 39.45807449519634, 41.30968853831291, 43.669574707746506, 44.3400639295578, 46.96240581572056, 47.84064128994942, 50.698380544781685, 51.50071509182453, 51.558232605457306, 48.840721026062965, 46.5662656724453, 47.47077293694019, 48.66629518568516, 45.89200705289841, 42.34717346727848, 29.287644736468792, 9.004102293401957, 1.0665812739171088, 0.2940744435181841, 1.343405325897038, 0.8728949795477092, 0.7360096997581422, 0.24555498064728454, 0.25358340062666684, 0.1736509194597602, 1.0079734562896192, 1.2970349891111255, 7.5527226738631725, 41.89454935491085, 43.262681141495705, 46.10198378562927, 46.02912649512291, 23.482599332928658, 1.5904193837195635, 0.14000188442878425, 0.12671208271058276, 0.17983403377002105, 0.11105172772658989, 0.0909455148212146, 0.09704500393127091, 0.11474335580714978, 0.14535567839629948, 0.21199960465310141, 0.1353013882180676, 0.07024439633823931, 0.18062047282001004, 0.21703939593862742, 0.08785835860180669, 0.1351818282273598, 0.13653425878146663, 0.1167656340112444, 0.13978906616102904], [0.04354209733719472, 0.041014798771357164, 0.04724765552964527, 0.006008372856740607, 0.0208045608815155, 0.058931638923240826, 0.06366211790009402, 0.037873154069529846, 0.04815678272279911, 0.010444429790368304, 0.027735980838770047, 0.09911377026583068, 0.013140570663381368, 0.017466076351411175, 0.02637027697346639, 0.054904096250538714, 0.07616424118168652, 0.03730416799953673, 0.0323012095032027, 0.09000885023851879, 0.09326736093498766, 0.03490819988655858, 0.06559167959494516, 0.012420858110999689, 3.9952994138002396, 31.088658794760704, 48.06431628763676, 26.866621747612953, 32.085140123963356, 38.73894788324833, 16.666715070605278, 1.8136503989808261, 0.0836257345508784, 0.7558050937950611, 2.7007126808166504, 1.8645126884803176, 1.8741541961207986, 1.7121906182728708, 0.13848766568116844, 3.379198336042464, 23.04195787757635, 46.31343103945255, 53.26840303838253, 51.21699571609497, 50.728919506073, 48.310379683971405, 45.13571463525295, 43.89783225953579, 43.166219517588615, 46.60184696316719, 43.815308287739754, 44.07152473926544, 43.421296030282974, 43.977259397506714, 38.906195908784866, 39.372514486312866, 38.02085101604462, 37.98821456730366, 36.42883524298668, 38.63465867936611, 36.836967542767525, 36.7479383200407, 37.82175689935684, 38.277804628014565, 40.23125320672989, 39.084394946694374, 38.34693431854248, 36.919324323534966, 39.096143916249275, 37.77596175670624, 39.508531987667084, 39.09270890057087, 38.251118659973145, 35.93746840953827, 37.10836797952652, 35.92826530337334, 35.4871241748333, 37.16159172356129, 39.23994340002537, 37.85394497215748, 37.92304806411266, 37.04638570547104, 38.68763543665409, 39.585333466529846, 41.130991727113724, 43.64567019045353, 48.23648504912853, 46.525995433330536, 50.479413494467735, 39.23684276640415, 46.93727396428585, 50.08802689611912, 46.74301318824291, 44.30819883942604, 39.023134633898735, 36.615865007042885, 36.11825130879879, 35.101992040872574, 35.229095220565796, 36.63080960512161, 34.71891559660435, 35.3311463445425, 35.56735686957836, 35.317280888557434, 35.42750157415867, 35.25906041264534, 36.36472508311272, 35.48089250922203, 34.95826095342636, 35.55275425314903, 36.560125797986984, 37.36945576965809, 35.46087518334389, 36.06489457190037, 35.39296142756939, 35.067512691020966, 34.10671904683113, 35.80487072467804, 34.96391125023365, 35.06332531571388, 36.19018144905567, 35.09691931307316, 37.12741635739803, 34.50065530836582, 35.52570350468159, 35.407089069485664, 36.94529592990875, 38.98444510996342, 40.76114237308502, 42.011252492666245, 46.69577792286873, 47.83960774540901, 46.75753980875015, 49.419623762369156, 47.645612955093384, 47.59898945689201, 46.42158843576908, 42.59519375860691, 31.41936644911766, 11.85447184368968, 1.4482300635427237, 0.1149520774197299, 0.6875975069124252, 0.19990393338957801, 0.07398514717351645, 0.08019148328457959, 0.06528471989440732, 0.043598199990810826, 0.13327823427971452, 0.6736753508448601, 1.65344612672925, 11.736629717051983, 27.78768092393875, 28.691363632678986, 32.84526273608208, 28.444395884871483, 5.713899219408631, 0.09203442357829772, 0.08676555356942117, 0.04067568923346698, 0.05313288660545368, 0.00968010024735122, 0.03935720080335159, 0.015488754670514027, 0.013341435715119587, 0.004625145029422129, 0.030618504679296166, 0.06666389002930373, 0.017246035131393, 0.030407315425691195, 0.07766241469653323, 0.0687931413995102, 0.023456725793948863, 0.03958532957767602, 0.027139598387293518, 0.08885523362550884, 0.04821801732759923, 0.0006952186640774016, 0.01938225526828319, 0.0723770319018513, 0.03040890362171922, 0.04007116542197764, 0.04557377855235245, 0.06512001506052911, 0.07567632361315191, 0.03298256415291689, 0.03322602198750246, 0.0627526975586079, 0.026888414795394056, 0.034701611948548816, 0.004331078753239126, 0.02723831701587187, 0.02765050212474307, 0.02124594022461679, 0.0855351246718783, 0.07079766000970267, 0.03578279123757966, 0.03256603748013731, 0.07304460115847178, 0.06036215083440766, 6.768995728343725, 40.04600174725056, 52.918840795755386, 31.984688714146614, 38.42869833111763, 43.791323974728584, 16.745175160467625, 2.3827737662941217, 0.05618558490823489, 0.25587058102246374, 1.6917318035848439, 1.3933215849101543, 0.8574848470743746, 3.389477259479463, 1.7930620349943638, 6.95393037982285, 27.1763963252306, 49.21088956296444, 54.24987517297268, 53.404162153601646, 52.0195734500885, 50.719826593995094, 47.00155511498451, 46.07298754155636, 46.79533638060093, 47.49134503304958, 46.41942635178566, 46.76160179078579, 45.51424652338028, 45.1040281355381, 40.60923792421818, 40.612125769257545, 40.327008068561554, 39.595288932323456, 38.18935677409172, 39.444459825754166, 38.28082926571369, 38.362733870744705, 39.814666360616684, 41.23838156461716, 41.70846574008465, 41.88924103975296, 39.477430656552315, 38.47803108394146, 40.55452086031437, 39.40801218152046, 40.99413447082043, 40.6606225669384, 39.66985233128071, 38.26388977468014, 40.2353797852993, 37.43867665529251, 38.4413630515337, 39.09272029995918, 40.88386818766594, 39.76826325058937, 39.22604374587536, 39.5244113355875, 38.60334075987339, 40.674689412117004, 44.20363985002041, 45.25313973426819, 49.050838351249695, 49.853758066892624, 51.624159067869186, 41.27266712486744, 49.86524485051632, 53.13495799899101, 49.48708914220333, 46.5991947054863, 39.9868693202734, 39.16375748813152, 39.765857979655266, 38.03553722798824, 37.013008296489716, 38.21179077029228, 36.503847017884254, 36.63289949297905, 37.74350009858608, 37.69962765276432, 36.942913457751274, 35.62699466943741, 38.5677594691515, 37.95183151960373, 36.692484095692635, 36.71915106475353, 38.58343742787838, 38.44214580953121, 38.42491753399372, 36.55950643122196, 36.9991010427475, 35.806504637002945, 36.07686772942543, 37.30601817369461, 37.54850596189499, 37.65334993600845, 37.11713790893555, 39.06514897942543, 38.343267515301704, 37.14218616485596, 37.808210626244545, 37.72976003587246, 38.761009499430656, 40.634430572390556, 41.726453974843025, 45.334223583340645, 46.645396426320076, 49.12780322134495, 48.17937031388283, 50.45083522796631, 47.81570702791214, 47.97689437866211, 47.2582845389843, 44.132899045944214, 32.74339020252228, 14.302772618830204, 2.244705562479794, 1.4628462167456746, 2.360060722567141, 0.24442954338155687, 0.0806672073667869, 0.042135831390623935, 0.010755801558843814, 0.0752229975478258, 0.21527010103454813, 1.2723296647891402, 1.677869197446853, 13.556790947914124, 34.02858003973961, 34.92140293121338, 39.742979407310486, 34.52995553612709, 9.649138581007719, 0.020504154344962444, 0.019330080431245733, 0.05786467547295615, 0.03422742411203217, 0.053754090185975656, 0.06325058959191665, 0.0498293386772275, 0.023596559403813444, 0.03274483198765665, 0.029963822817080654, 0.04754069625050761, 0.008422541213803925, 0.022322559016174637, 0.007042248116704286, 0.035970769822597504, 0.018655226995178964, 0.07936167312436737, 0.04033934048493393, 0.08103089683572762, 0.11173824401339516, 0.09480881650233641, 0.06988827677560039, 0.13512938807252795, 0.09845832028076984, 0.2123284206027165, 0.2233655666350387, 0.24337812792509794, 0.10541184325120412, 0.14995108649600297, 0.19565366848837584, 0.21517408196814358, 0.17967041989322752, 0.0797397008864209, 0.15321530430810526, 0.1686837844317779, 0.16517088777618483, 0.10438845871249214, 0.3083618253003806, 0.20986820105463266, 0.14175630669342354, 0.11456366701168008, 0.20499726320849732, 0.21097386750625446, 8.457950949668884, 45.73188364505768, 60.71037210524082, 37.25364938378334, 42.56487138569355, 48.70878450572491, 24.85572785139084, 3.602311913855374, 0.15813584730494767, 2.06590520683676, 10.65100897103548, 10.008547995239496, 6.863604951649904, 6.080359630286694, 2.2069154027849436, 5.835225759074092, 28.250023014843464, 49.72557954490185, 53.88289086520672, 55.177903175354004, 56.009636744856834, 52.491314336657524, 48.632412403821945, 48.02186496555805, 48.84010165929794, 50.5182284116745, 49.413285702466965, 48.656286522746086, 47.49102205038071, 48.67421396076679, 42.301857098937035, 43.28246667981148, 44.47279840707779, 41.70899771153927, 41.55114658176899, 42.65497215092182, 40.563332587480545, 40.060919746756554, 41.32657863199711, 42.59688846766949, 43.32215175032616, 42.91790284216404, 41.01888254284859, 39.181304946541786, 41.75191640853882, 41.271652579307556, 45.58160550892353, 40.53527869284153, 41.66506066918373, 39.84971188008785, 40.7325679063797, 38.03647957742214, 39.50030542910099, 40.99044866859913, 43.1002626568079, 40.63792638480663, 41.261172741651535, 40.928789377212524, 41.77465818822384, 42.99334779381752, 45.514337718486786, 47.24820747971535, 52.29109548032284, 50.534415543079376, 52.43454538285732, 43.21939766407013, 51.608397513628006, 55.53971976041794, 50.67672550678253, 48.34716930985451, 43.34685042500496, 38.63916903734207, 41.16985984146595, 39.516481161117554, 39.43880572915077, 39.733073338866234, 36.73411086201668, 37.98794478178024, 39.902399852871895, 39.49291482567787, 38.38432811200619, 37.99910858273506, 40.99935159087181, 39.21924211084843, 38.67933288216591, 38.11314046382904, 40.66691882908344, 39.90298122167587, 38.63537684082985, 38.57867248356342, 38.892885223031044, 38.219261169433594, 37.28941306471825, 39.99751254916191, 39.862277805805206, 40.72796255350113, 39.06037263572216, 39.465647488832474, 41.811725199222565, 39.02475334703922, 38.6275302618742, 39.52647842466831, 41.77542954683304, 42.70976521074772, 43.33310656249523, 46.74753874540329, 49.9590390175581, 52.040457129478455, 49.25689749419689, 51.94304175674915, 48.86382378637791, 48.39514933526516, 46.40012338757515, 46.005111783742905, 35.18602833151817, 16.492925696074963, 2.5259636202827096, 0.9919204458128661, 2.2798109287396073, 1.6736673354171216, 0.2636247774353251, 0.20706886454718187, 0.1971264011808671, 0.2760380582185462, 0.7099150749854743, 4.619034994393587, 4.9259288515895605, 19.976964443922043, 37.690264955163, 37.941347882151604, 45.30584290623665, 39.79620315134525, 10.999857801944017, 0.12533878296380863, 0.22032721404684708, 0.16747452900744975, 0.1347190249362029, 0.21275781240547076, 0.16962610417976975, 0.13752423925325274, 0.09099202521611005, 0.20565339596942067, 0.14463892701314762, 0.13880070357117802, 0.07114091073162854, 0.11973960528848693, 0.15725528908660635, 0.13308141671586782, 0.08606980496551841, 0.10906647527008317, 0.19489044381771237, 0.1492066975333728], [0.07378498252364807, 0.029901387788413558, 0.017602705738681834, 0.008082656131591648, 0.014972732897149399, 0.05110777710797265, 0.049132150306832045, 0.02309295283339452, 0.033647814198047854, 0.022559138997166883, 0.03176821759552695, 0.019055372613365762, 0.04594680794980377, 0.0391820465301862, 0.010251883286400698, 0.01284631745875231, 0.009675224337115651, 0.050210123517899774, 0.048641594403306954, 0.05092789164336864, 0.0504398033808684, 0.05451532590086572, 0.05736192237236537, 0.008945218196458882, 0.37923859083093703, 14.79958551004529, 44.556960090994835, 33.30408811569214, 25.016972199082375, 38.04724059998989, 22.62286886572838, 4.14897789247334, 0.08968299545813352, 0.18546359497122467, 1.9979289919137955, 0.5489944817963988, 0.2502376207849011, 2.7911535277962685, 0.9698197629768401, 2.427265578880906, 7.768728258088231, 29.732072688639164, 49.23819489777088, 55.37119500339031, 51.832938864827156, 53.73103201389313, 47.00568929314613, 45.95476068556309, 44.13822256028652, 46.334288120269775, 45.6397195905447, 44.36937935650349, 43.22564072906971, 41.89240247011185, 39.51722972095013, 37.416531443595886, 35.188422203063965, 35.35269118845463, 35.43746843934059, 36.119292452931404, 36.96005433797836, 37.62512505054474, 37.503105998039246, 39.868357479572296, 43.50283585488796, 43.968975841999054, 45.18510818481445, 45.276375487446785, 44.28820051252842, 44.17055502533913, 44.25164267420769, 43.04534040391445, 38.18259313702583, 37.50642701983452, 35.870766788721085, 36.3248386234045, 37.09375016391277, 36.37487433850765, 35.696914717555046, 36.944638565182686, 36.02639123797417, 34.593655318021774, 39.54377129673958, 39.74269062280655, 44.8709562420845, 45.871081575751305, 50.10736405849457, 49.51340653002262, 52.262521013617516, 41.30336567759514, 45.39703421294689, 51.081536784768105, 47.18203403055668, 46.90286301076412, 42.17931367456913, 37.74956837296486, 35.55871233344078, 36.26175820827484, 35.95849268138409, 34.04772721230984, 35.18671989440918, 34.59731072187424, 33.94637145102024, 35.55353321135044, 35.950250923633575, 35.25133162736893, 34.99421842396259, 34.651203230023384, 35.02848118543625, 35.50394967198372, 36.4098134636879, 35.07027134299278, 34.2219440639019, 35.038683637976646, 35.586097463965416, 35.45532368123531, 34.439774975180626, 35.99937468767166, 36.730086877942085, 38.26509810984135, 35.85253156721592, 36.527550145983696, 37.329459115862846, 38.486652821302414, 36.877047792077065, 36.66679747402668, 34.28374394774437, 36.04505583643913, 38.0169790238142, 40.81036493182182, 45.16280718147755, 46.30407594144344, 48.82166124880314, 48.73069792985916, 45.65430700778961, 47.07373224198818, 44.23173554241657, 33.69947589933872, 17.11138240993023, 3.358961809426546, 0.3518110985169187, 2.6930577540770173, 0.8255049912258983, 0.16598947666352615, 0.16030995408073068, 0.05313837849826086, 0.04926934743707534, 0.021988898697600234, 0.26253744203131646, 0.15775393811054528, 6.007664306089282, 26.615086644887924, 26.588733159005642, 32.96546548604965, 38.88266757130623, 22.823433503508568, 1.4438783470541239, 0.09581008504028432, 0.016528539745195303, 0.03408598931855522, 0.006155146938908729, 0.06429760411265306, 0.02776629200525349, 0.06751083637936972, 0.0887356662133243, 0.011044994244002737, 0.08811393199721351, 0.06192820117576048, 0.018617427558638155, 0.02751006180915283, 0.04943984102283139, 0.03698417989653535, 0.04293809673981741, 0.05828745473991148, 0.03458464205323253, 0.03175844351062551, 0.018137087317882106, 0.011409563157940283, 0.0305568377734744, 0.030370981730811764, 0.0632968550780788, 0.08071368065429851, 0.03089762085437542, 0.012640750901482534, 0.017803003975132015, 0.04952870207489468, 0.013856672667316161, 0.061649866111110896, 0.06743061021552421, 0.08614309947006404, 0.03142371635476593, 0.07141775407944806, 0.041291619854746386, 0.009249550694221398, 0.03190221978002228, 0.05987077485769987, 0.0545811952179065, 0.02118656841048505, 0.0744571234099567, 0.029618900407513138, 1.1965556745417416, 21.21018636971712, 52.335762083530426, 33.45323771238327, 28.461413271725178, 43.52227561175823, 24.708877131342888, 4.431648524478078, 0.14485342253465205, 0.3640125406673178, 0.9327442618086934, 0.29542538977693766, 0.11264309272519313, 0.36161688796710223, 1.3636162038892508, 5.100365616381168, 12.027774844318628, 36.46317780017853, 50.39850823581219, 56.90074972808361, 54.23521935939789, 55.02032183110714, 48.42059276998043, 46.383362486958504, 46.82897977530956, 48.93357664346695, 46.783602610230446, 45.89908987283707, 45.505392998456955, 44.83508616685867, 41.68729327619076, 40.15605144202709, 37.03267224133015, 37.81905524432659, 37.19097174704075, 38.941568210721016, 37.206224128603935, 38.857968896627426, 39.32506263256073, 41.72794349491596, 45.983502343297005, 44.22021076083183, 45.57676076889038, 45.688353180885315, 45.48057273030281, 45.799512416124344, 45.4409446567297, 44.40676175057888, 39.80811931192875, 38.48342299461365, 38.221715837717056, 37.947875931859016, 38.72441366314888, 38.1691874563694, 37.59107127785683, 39.277200400829315, 38.473851308226585, 37.12103269994259, 41.020432859659195, 41.006840988993645, 46.45887203514576, 48.63204762339592, 51.40802666544914, 50.32046042382717, 51.856117621064186, 43.5332228243351, 48.1841466575861, 52.337707579135895, 48.74735243618488, 47.44159810245037, 42.925342842936516, 39.292224794626236, 37.51556172966957, 37.578129172325134, 37.72548906505108, 36.06379263103008, 36.35687090456486, 35.9679389744997, 35.986542776227, 37.28509269654751, 37.928481772542, 36.87151528894901, 37.69648142158985, 36.251206174492836, 36.79472140967846, 36.46427974104881, 39.074697867035866, 37.94522367417812, 36.69123016297817, 36.97605527937412, 36.677075922489166, 36.09622769057751, 36.2042672932148, 36.589452624320984, 38.369619101285934, 39.461893290281296, 39.18624848127365, 38.860111981630325, 39.50964912772179, 40.652130022645, 37.849123030900955, 38.248485401272774, 36.261530220508575, 38.16964343190193, 40.29158636927605, 43.875223472714424, 46.50939032435417, 49.83402192592621, 50.864473432302475, 49.557674154639244, 45.860225558280945, 46.3247886300087, 44.97852087020874, 36.37018918991089, 20.03941599279642, 5.359664177522063, 1.704744917806238, 3.081813231110573, 3.6670174542814493, 0.19248147698817775, 0.09346508391899988, 0.06468455248977989, 0.06079146100091748, 0.08420794198173098, 0.30285200220532715, 1.3230207259766757, 7.428045189008117, 29.55776274204254, 31.34792648255825, 32.88731127977371, 41.89016439020634, 27.074905671179295, 2.424909705296159, 0.04926397428789642, 0.0336646238429239, 0.013936518480477389, 0.05548239998461213, 0.055759291572030634, 0.04603966917784419, 0.06300110180745833, 0.07594559705466963, 0.023723019512544852, 0.053764728872920386, 0.04046271140396129, 0.021751428139396012, 0.037240495439618826, 0.007754149100946961, 0.07477185339666903, 0.03708384661877062, 0.06866918789455667, 0.0038537634600288584, 0.054475880751851946, 0.20484521199250594, 0.16030254744691774, 0.124945726711303, 0.1298371033044532, 0.16267057741060853, 0.20772217714693397, 0.13379773765336722, 0.1981737941969186, 0.09463116861297749, 0.1687816737103276, 0.13354806433198974, 0.08975381118943915, 0.12683835171628743, 0.12645095062907785, 0.07755465485388413, 0.14709739509271458, 0.19874150748364627, 0.098642157681752, 0.151053250010591, 0.13573688047472388, 0.22797851910581812, 0.3113773197401315, 0.1952390157384798, 0.09380100964335725, 1.341232554987073, 22.230729907751083, 60.31971126794815, 44.35501992702484, 34.646780267357826, 47.39860340952873, 32.032436951994896, 6.3718348648399115, 0.49667716724798083, 1.1563958670012653, 6.036024559289217, 1.3451746059581637, 1.5273688919842243, 8.205293957144022, 2.996110492385924, 5.883970018476248, 11.6305479593575, 34.44256782531738, 50.096352249383926, 57.622802183032036, 56.658615320920944, 58.23088355362415, 50.04604294896126, 49.49085094034672, 48.347784876823425, 51.3013169914484, 48.21516439318657, 48.412852585315704, 46.94381341338158, 45.938611552119255, 44.08033646643162, 41.61362662911415, 38.40043164789677, 38.90417821705341, 38.964963555336, 40.300082713365555, 39.81581769883633, 40.8100875467062, 42.256624326109886, 44.104643762111664, 49.252432733774185, 47.29546934366226, 47.01557636260986, 47.68964119255543, 49.06363986432552, 48.18501681089401, 48.97101603448391, 47.54899933934212, 41.61420799791813, 41.30237393081188, 40.58766648173332, 40.92858038842678, 40.69129832088947, 39.09747004508972, 39.70846585929394, 41.43509320914745, 39.36060592532158, 37.57477015256882, 43.01881022751331, 43.52595381438732, 49.45192202925682, 51.21297173202038, 54.45059560239315, 52.13553562760353, 52.78714366257191, 46.57342068850994, 49.84851814806461, 54.70998488366604, 50.7663094997406, 51.18101164698601, 46.196458116173744, 41.80102877318859, 38.90766642987728, 39.40217189490795, 38.69808107614517, 36.94401539862156, 38.549140468239784, 37.77084343135357, 36.68091371655464, 39.85552176833153, 39.6219938993454, 39.61781792342663, 39.66673269867897, 38.16379554569721, 38.061915412545204, 38.377807661890984, 40.46782471239567, 40.065946877002716, 37.29066699743271, 37.97287859022617, 38.09563860297203, 38.816737309098244, 37.2485576570034, 37.82331861555576, 39.7366451472044, 42.09349907934666, 42.29776851832867, 40.89485339820385, 40.90151064097881, 42.68627107143402, 39.747033789753914, 42.213017866015434, 38.38307797908783, 40.20769067108631, 42.57828086614609, 46.6235475987196, 48.22950102388859, 49.767012521624565, 53.55565242469311, 51.39751262962818, 46.656799614429474, 47.51859337091446, 47.10917294025421, 37.41393618285656, 20.105072669684887, 4.603380309417844, 2.092581200413406, 4.651855258271098, 3.316888567060232, 0.510855334578082, 0.32798590196762234, 0.2563842956442386, 0.25534341868478805, 0.22777126694563776, 1.4243802870623767, 2.7750984393060207, 12.68352085724473, 36.74589402973652, 37.640582621097565, 41.32747918367386, 49.89314295351505, 31.255618035793304, 3.253726218827069, 0.1782082553836517, 0.15639260178431869, 0.16333931183908135, 0.07070158899296075, 0.18289846542757004, 0.15670666383812204, 0.186487699393183, 0.19379807665245607, 0.17278386832913384, 0.17721115029416978, 0.19562280998798087, 0.15440582792507485, 0.10474444468854927, 0.06669937953120098, 0.14419948653085157, 0.126745316083543, 0.14405972528038546, 0.07629351588548161, 0.12380437779938802], [0.07723307484411635, 0.05453923047753051, 0.05405416275607422, 0.027016678322979715, 0.024489797215210274, 0.03178415892762132, 0.04496135086810682, 0.05041021766373888, 0.041355010398547165, 0.037950281766825356, 0.03753412245714571, 0.021826663360116072, 0.01901301453472115, 0.034278420789632946, 0.0041427147152717225, 0.03938094210752752, 0.006774684861738933, 0.027272530023765285, 0.08294069513794966, 0.04029337185784243, 0.009827796911849873, 0.049604950327193365, 0.058437364859855734, 0.022286164094111882, 0.09121458046138287, 2.5508522847667336, 34.401837810873985, 49.811097756028175, 27.132445983588696, 35.9902323782444, 31.224094927310944, 5.494464794173837, 0.05647040263283998, 0.16280431242194027, 0.2270087695796974, 0.28788154770154506, 0.1408019196242094, 0.5931434221565723, 1.2666863738559186, 3.099887673743069, 1.2010980932973325, 11.374913826584816, 40.554045885801315, 52.486435398459435, 57.0974575728178, 50.42257994413376, 51.18209458887577, 45.94031386077404, 46.70802466571331, 47.8864174336195, 45.441001653671265, 44.09298978745937, 43.57665069401264, 39.238655269145966, 39.8719634860754, 39.86851327121258, 38.42594347894192, 38.0162912607193, 36.70488283038139, 38.00316296517849, 37.72897347807884, 36.58870406448841, 37.8392169624567, 41.2655995041132, 47.267020270228386, 47.50524468719959, 49.12995770573616, 50.47521471977234, 50.31361699104309, 50.94804234802723, 49.832209423184395, 48.350855112075806, 46.743754148483276, 39.19039025902748, 37.3437425494194, 36.83438368141651, 35.04152208566666, 37.34324857592583, 36.29798926413059, 37.101117968559265, 36.69981770217419, 36.634506806731224, 39.400553181767464, 47.96189658343792, 50.171383023262024, 49.42302078008652, 49.99691158533096, 47.518779560923576, 45.902673080563545, 36.903897151350975, 45.686210095882416, 47.81759552657604, 47.08763189613819, 47.63222247362137, 42.92883485555649, 42.268551886081696, 39.71777155995369, 37.48589292168617, 35.36665923893452, 35.06375849246979, 33.77969719469547, 35.30937731266022, 34.41337779164314, 34.68775726854801, 35.283265113830566, 35.91203637421131, 34.8250363022089, 35.34481421113014, 35.8387915045023, 34.38198767602444, 35.84156535565853, 34.52735647559166, 35.055197551846504, 36.13139100372791, 36.409733667969704, 34.70152013003826, 36.22467219829559, 34.74989153444767, 36.452207788825035, 36.45534262061119, 40.41298605501652, 40.8331561088562, 42.01754875481129, 41.070871353149414, 39.68415476381779, 37.888063341379166, 38.10850091278553, 35.89130848646164, 36.44004464149475, 38.341956585645676, 40.06818875670433, 44.73617747426033, 46.4650809019804, 47.67410762608051, 47.29600131511688, 46.68737277388573, 38.470807671546936, 18.93790639936924, 5.443360386416316, 0.4259062616620213, 1.071957154199481, 1.637812815606594, 5.860236492007971, 0.22647690202575177, 0.07795848709065467, 0.07555743897682987, 0.0576007863128325, 0.16127268288983032, 0.17591918993275613, 0.4122378013562411, 10.765053201466799, 28.981056287884712, 28.796315900981426, 31.862141489982605, 37.34738275408745, 11.988607496023178, 0.2962650853442028, 0.10031949306721799, 0.06269498815527186, 0.057734569563763216, 0.05575107228651177, 0.05313565852702595, 0.04774192959303036, 0.07628333361935802, 0.05114729647175409, 0.05932627595029771, 0.016543566380278207, 0.049671751039568335, 0.026395957138447557, 0.04267637094017118, 0.021719211508752778, 0.0015917331734272011, 0.06181267846841365, 0.07121493254089728, 0.017842283996287733, 0.01691258446953725, 0.03299185955256689, 0.037270745378918946, 0.03972184764279518, 0.018408830255793873, 0.040619564315420575, 0.0400706422078656, 0.008392598338105017, 0.04108749213628471, 0.05511041701538488, 0.03468844253802672, 0.014994819212006405, 0.03307171464257408, 0.034985405509360135, 0.10669846757082269, 0.023974971227289643, 0.018098434411513153, 0.042888068564934656, 0.05360107788874302, 0.03248621949751396, 0.015770981372043025, 0.04025196743896231, 0.020750309886352625, 0.10886328265769407, 0.0665198169008363, 0.05394376828917302, 5.263685127720237, 40.79494535923004, 52.445412799715996, 29.21903371810913, 41.04094795882702, 35.85363730788231, 6.8515211250633, 0.11410288978368044, 0.13909949222579598, 0.4041309957392514, 0.06096932040236425, 0.18505982210626826, 0.13632663554744795, 1.4848419302143157, 2.0462398370727897, 2.848865306004882, 13.875003922730684, 42.857622876763344, 52.72131599485874, 57.99718849360943, 54.64830659329891, 53.66584651172161, 48.212116956710815, 49.31989051401615, 50.60700684785843, 47.022009417414665, 45.66539101302624, 46.47648029029369, 41.57917767763138, 41.84649333357811, 41.40141561627388, 40.27605280280113, 39.174803495407104, 39.11954306066036, 39.68649163842201, 39.15926232933998, 39.066277518868446, 39.78675305843353, 43.082867190241814, 46.98880299925804, 49.15021061897278, 50.833174511790276, 52.37301908433437, 50.529775992035866, 52.327444329857826, 53.42151582241058, 49.24300163984299, 48.027329072356224, 40.99327951669693, 39.751810133457184, 38.936696872115135, 36.74383834004402, 38.82301837205887, 37.040526419878006, 37.828592732548714, 37.67624370753765, 38.917530700564384, 42.25425325334072, 48.48439134657383, 51.16655342280865, 50.93537002801895, 52.373133078217506, 50.637393817305565, 46.324845626950264, 39.022465869784355, 47.87963479757309, 50.10882318019867, 50.56266322731972, 49.81003001332283, 45.11871814727783, 42.93903350830078, 40.09292542934418, 38.39564010500908, 35.746220871806145, 36.145465448498726, 36.97693683207035, 36.10083304345608, 36.66865177452564, 35.53764246404171, 36.685830652713776, 37.28318899869919, 37.357551008462906, 38.23700241744518, 38.050390630960464, 36.342933252453804, 37.10856556892395, 36.70047126710415, 37.07528695464134, 37.12020814418793, 36.38625852763653, 35.75598254799843, 38.144633173942566, 36.94536432623863, 37.13476896286011, 38.765063881874084, 41.695086658000946, 42.62770861387253, 42.76132844388485, 42.40525335073471, 41.920262575149536, 40.24581402540207, 38.4889554977417, 37.741452008485794, 37.962611541152, 40.171129032969475, 42.72674269974232, 47.38066077232361, 48.29072713851929, 49.22743767499924, 46.804440692067146, 47.34404593706131, 39.20958682894707, 23.15061304718256, 8.255412317812443, 1.9984265277162194, 4.052361426874995, 4.221209166571498, 8.81288705393672, 0.12551021907711402, 0.09083435594220646, 0.09399899237905629, 0.0776661625423003, 0.28475054539740086, 0.20677392021752894, 0.6685173651203513, 13.820608891546726, 33.329090774059296, 33.38837519288063, 34.70862194895744, 45.04504010081291, 15.998446829617023, 0.5302809609565884, 0.07688433222938329, 0.026454714825376868, 0.11638450407190248, 0.07081089992425404, 0.010212835186393932, 0.012942005341756158, 0.0810077715141233, 0.04561410314636305, 0.05768545794126112, 0.01382498667226173, 0.019307144357298966, 0.10320150482584722, 0.06148291256977245, 0.04609072893799748, 0.025704635445435997, 0.05668817844707519, 0.05045363701356109, 0.002566749976722349, 0.05822835380968172, 0.16819190379465, 0.18317567242775112, 0.10848170742974617, 0.09097311529330909, 0.12354703809251077, 0.14695168181788176, 0.15054147981572896, 0.17559776577400044, 0.18091057834681123, 0.13090051186736673, 0.11774078637245111, 0.1533268639468588, 0.13914877083152533, 0.18299112998647615, 0.12300679911277257, 0.16020084352931008, 0.1409922359744087, 0.12565484881633893, 0.13196022453485057, 0.10037956992164254, 0.09048788429936394, 0.13656734372489154, 0.2095992022077553, 0.17578949220478535, 0.26900757453404367, 5.29071687720716, 46.04716792702675, 61.29781298339367, 37.21011511981487, 47.836412116885185, 43.10718588531017, 10.106687229126692, 0.2607974025886506, 0.43775331345386803, 2.2771249478682876, 0.7781499729026109, 0.6188328936696053, 2.2706403583288193, 6.088787103071809, 7.905779778957367, 3.7719965586438775, 14.693072475492954, 41.68676130473614, 55.29451131820679, 59.55288201570511, 57.41558790206909, 56.07305534183979, 49.996425211429596, 52.22188979387283, 54.067982733249664, 47.85830654203892, 47.66279563307762, 47.50475071370602, 42.93792396783829, 44.31346155703068, 43.17518323659897, 43.57179835438728, 41.96896456182003, 41.636850982904434, 42.35277056694031, 42.24236749112606, 41.087894439697266, 41.899158507585526, 44.3741898983717, 51.156620755791664, 50.241109281778336, 53.21123130619526, 54.26026001572609, 53.88708584010601, 55.45103631913662, 54.93815504014492, 53.01642335951328, 51.89863733947277, 43.58863905072212, 42.15256690979004, 41.27041384577751, 37.66802474856377, 41.50677636265755, 39.071756824851036, 39.95094984769821, 39.88364405930042, 41.00626341998577, 44.93559077382088, 50.62100149691105, 55.02244591712952, 53.69783319532871, 52.84353643655777, 51.62300392985344, 46.18307523429394, 41.821483075618744, 49.598689153790474, 51.72334134578705, 51.03114768862724, 53.236549347639084, 46.982134357094765, 45.959518030285835, 43.33951681852341, 40.61813324689865, 38.52330185472965, 37.62741632759571, 37.7333964407444, 39.698062017560005, 37.76892073452473, 37.53627821803093, 39.300542548298836, 40.01176938414574, 37.902665957808495, 40.20447984337807, 40.60196131467819, 37.18866907060146, 39.108105674386024, 36.65779575705528, 38.31362910568714, 38.5075668990612, 39.719302877783775, 37.93026767671108, 40.358101800084114, 38.81268672645092, 39.99696537852287, 40.476697236299515, 45.02122297883034, 44.5461268723011, 46.46370157599449, 43.514098450541496, 43.85816238820553, 42.9752379655838, 41.95261403918266, 38.85430209338665, 40.11914402246475, 42.102819979190826, 43.801100850105286, 49.505670145154, 51.06231361627579, 51.01517714560032, 48.26508231461048, 47.92312726378441, 40.911253318190575, 21.957627162337303, 7.037899699062109, 1.7023081798106432, 2.747912798076868, 4.8835046030581, 16.044754944741726, 0.6100534647703171, 0.29067056835629046, 0.1542444108054042, 0.3158278012415394, 0.9036963048856705, 0.5929070629645139, 2.419429449364543, 17.847864590585232, 37.57364921271801, 41.60125069320202, 40.50392657518387, 51.828641295433044, 17.136861942708492, 0.7293440261855721, 0.41436482628341764, 0.20116519852308556, 0.18125784408766776, 0.16344796225894243, 0.18984939088113606, 0.06599427986657247, 0.2386570445378311, 0.12744118343107402, 0.15511742880335078, 0.1302905406919308, 0.11428861223976128, 0.14853009633952752, 0.2020430107950233, 0.09956084744771942, 0.138960458280053, 0.17746242665452883, 0.13901885045925155, 0.10613432401441969, 0.14556113455910236], [0.047929674401530065, 0.06963383886613883, 0.043714791390812024, 0.021266974545142148, 0.024471781580359675, 0.051081007841276005, 0.06655786681221798, 0.003429451426200103, 0.008434346927970182, 0.01703757698123809, 0.041711137382662855, 0.015723070173407905, 0.1156550768064335, 0.06818519628723152, 0.014387864866876043, 0.03608344639360439, 0.036344626714708284, 0.061235120592755266, 0.024784177512628958, 0.022940986964385957, 0.09955001951311715, 0.07922511795186438, 0.06235696215298958, 0.04518527908658143, 0.027659322549880017, 0.5120810656808317, 13.625497911125422, 50.21516427397728, 31.566804237663746, 26.835151836276054, 36.04313313961029, 12.386494595557451, 0.795761909103021, 0.08219071780331433, 0.048899156754487194, 0.07610705128172413, 0.058480721127125435, 0.026877818781940732, 1.3632580731064081, 1.3717538234777749, 1.2789232609793544, 2.240614606998861, 15.52521737292409, 41.75113745033741, 55.87698206305504, 54.12676177918911, 50.480777621269226, 48.76187525689602, 48.059623539447784, 45.69070905447006, 45.70316098630428, 43.581438437104225, 40.95742464065552, 40.16104057431221, 41.77439980208874, 42.340204641222954, 39.425586238503456, 38.297099992632866, 38.4003746509552, 36.45384930074215, 36.93697817623615, 36.86637416481972, 38.69243457913399, 42.033093720674515, 44.64197672903538, 47.834584414958954, 48.92560467123985, 49.68147911131382, 51.96835599839687, 50.748047679662704, 50.31763717532158, 49.923260137438774, 51.06239341199398, 45.520793572068214, 38.41508746147156, 35.38492105901241, 35.86429953575134, 37.5430266559124, 36.26298554241657, 35.92853128910065, 35.71906752884388, 37.535381466150284, 42.950398698449135, 47.449011504650116, 49.13671374320984, 48.355536460876465, 52.46573030948639, 42.53030464053154, 57.994680628180504, 51.09903484582901, 42.89338655769825, 50.33766970038414, 48.82788151502609, 49.92327153682709, 45.064122676849365, 45.02857558429241, 43.03514175117016, 41.104731336236, 39.04478967189789, 36.99195742607117, 38.24035003781319, 36.483445912599564, 36.103188917040825, 36.19736306369305, 36.15795157849789, 34.20372024178505, 34.11978654563427, 34.145910143852234, 36.93028673529625, 36.510280072689056, 36.72900013625622, 34.67211730778217, 37.88641422986984, 42.10465148091316, 40.072702914476395, 37.59097248315811, 37.361939772963524, 33.77116285264492, 35.019080489873886, 36.045280024409294, 36.853321865200996, 41.31341613829136, 42.73542903363705, 43.728691935539246, 41.208393573760986, 40.0363502651453, 36.05835512280464, 37.015744149684906, 37.683269530534744, 38.77455957233906, 41.78456425666809, 44.986302852630615, 46.935237273573875, 50.04915118217468, 49.09608632326126, 39.58171226084232, 23.42560239136219, 7.233411557972431, 1.1556975357234478, 2.30726255569607, 3.8612578064203262, 2.950380421243608, 5.4332201555371284, 0.1264099543914199, 0.07556904616649263, 0.10866409764275886, 0.03872108005452901, 0.08466480066999793, 0.09211075346684083, 1.2784614670090377, 13.320094998925924, 34.28091309964657, 25.881374515593052, 33.81322659552097, 23.702457435429096, 4.3824767880141735, 0.043961188130197115, 0.13577370584243909, 0.03020022839336889, 0.0100868231493223, 0.02956217991595622, 0.040433968024444766, 0.03486240195343271, 0.020848210297117475, 0.04132486064918339, 0.024535517222830094, 0.018579570605652407, 0.012941637050971622, 0.018389588221907616, 0.014207624099071836, 0.06068883682019077, 0.020011739361507352, 0.028917364907101728, 0.029934847516415175, 0.020690047495008912, 0.05284669590764679, 0.06174955880851485, 0.020292024419177324, 0.050314862819504924, 0.03655770473415032, 0.04783230091561563, 0.00416127072639938, 0.07766668204567395, 0.03282495054008905, 0.03684954317577649, 0.07336810333072208, 0.056526917178416625, 0.01290714481001487, 0.03605428741138894, 0.02893109092838131, 0.029990985422045924, 0.04389657304272987, 0.035946776188211516, 0.060008628788637, 0.04420738077897113, 0.04358773570857011, 0.029952128425065894, 0.05829542540595867, 0.052600169292418286, 0.011405843142711092, 0.04535276697424706, 0.5414290877524763, 20.601096153259277, 54.83661308884621, 34.203013479709625, 31.96080319583416, 40.3510569781065, 12.437515407800674, 0.6937414803542197, 0.049123337303171866, 0.05447476010886021, 0.029776465780742, 0.11687304504448548, 0.050437146492186, 1.0953178256750107, 0.7197876577265561, 1.1304405285045505, 3.74621304217726, 18.940250873565674, 44.026113376021385, 56.538313776254654, 55.773768201470375, 53.40486131608486, 49.91175055503845, 49.76111903786659, 49.44975234568119, 47.993165105581284, 44.835336953401566, 44.50844809412956, 42.00060546398163, 44.160538762807846, 43.23423966765404, 42.45193764567375, 40.366385355591774, 40.24886906147003, 39.24615986645222, 38.773871809244156, 38.33197832107544, 41.06447249650955, 44.24180120229721, 46.68529808521271, 50.009561106562614, 51.17522455751896, 50.796799063682556, 52.658851146698, 52.471137419342995, 53.0245815217495, 52.20123790204525, 53.57968993484974, 46.51485823094845, 39.625284522771835, 37.857980355620384, 38.12955938279629, 38.463937640190125, 37.86595232784748, 38.696796745061874, 38.02793003618717, 39.43993426859379, 44.41947586834431, 49.274308159947395, 51.64041839540005, 51.34911462664604, 53.22651408612728, 44.87103223800659, 52.73482047021389, 47.45181955397129, 47.257372587919235, 51.84885621070862, 51.17824539542198, 51.07991427183151, 48.71670328080654, 47.024574279785156, 45.00632397830486, 41.95672161877155, 39.62486654520035, 37.254888117313385, 37.63296402990818, 38.13027374446392, 37.078866362571716, 37.40973740816116, 36.799630746245384, 35.78277111053467, 36.800671890378, 35.93073897063732, 37.66892150044441, 37.76176951825619, 38.67033116519451, 37.008368745446205, 39.85358007252216, 43.832468166947365, 41.62960857152939, 39.98835124075413, 38.511685878038406, 35.16691915690899, 37.2870571911335, 38.13123129308224, 39.26370732486248, 43.13753865659237, 44.79083754122257, 44.61889296770096, 45.18803782761097, 42.011613473296165, 38.53498622775078, 40.04539757966995, 39.77444551885128, 39.57666993141174, 43.47651086747646, 47.06926368176937, 47.88520909845829, 52.22122482955456, 47.031045332551, 42.95270137488842, 24.651200026273727, 9.949805997312069, 3.2721861032769084, 4.286102559417486, 5.557217476889491, 6.8871826864778996, 6.274546310305595, 0.42587090574670583, 0.03508904643240385, 0.1019924646243453, 0.04539859830401838, 0.08167022737325169, 0.23278459324501455, 1.9342548586428165, 14.917453285306692, 40.39121322333813, 30.39451964199543, 37.96556018292904, 29.877509884536266, 5.907511655241251, 0.019163703909725882, 0.021295480437402148, 0.06242861651116982, 0.029386584064923227, 0.01839311527874088, 0.05450743316032458, 0.014301859227998648, 0.04322452121414244, 0.03857436488033272, 0.03999476874014363, 0.05575523573497776, 0.042302803485654294, 0.017967994535865728, 0.019706473613041453, 0.057609666109783575, 0.03920960247342009, 0.011293253774056211, 0.008382367832382442, 0.046244861878221855, 0.016620677379250992, 0.18573155481135473, 0.13210467615863308, 0.10800795746035874, 0.1507048265193589, 0.1468104956438765, 0.21966208645608276, 0.15340277081122622, 0.14883396128425375, 0.06817341840360314, 0.23638994665816426, 0.18612996937008575, 0.05259622848825529, 0.2459111373173073, 0.17507009877590463, 0.08217976370360702, 0.0802085897885263, 0.11888627646840177, 0.13136773835867643, 0.17006371897878125, 0.1401632570195943, 0.14123373082838953, 0.23092719056876376, 0.1888512764708139, 0.1333691770560108, 0.14014620246598497, 1.1716754408553243, 22.336387038230896, 62.53932036459446, 40.95942713320255, 36.43506310880184, 46.58901505172253, 17.89439119398594, 1.6315291402861476, 0.28025856299791485, 0.5132259917445481, 0.7823390106204897, 0.2702961803879589, 0.44709814013913274, 5.7332810293883085, 3.2576091354712844, 3.6321341386064887, 5.362397655844688, 19.348381273448467, 42.61210285127163, 57.16047339141369, 57.24939621984959, 56.412586122751236, 52.94276051223278, 53.88721123337746, 50.7760863751173, 51.46847002208233, 47.08775728940964, 46.167097091674805, 43.40893529355526, 47.06027336418629, 46.64603479206562, 44.665881246328354, 41.37070946395397, 42.97533676028252, 40.55481344461441, 40.86206495761871, 38.9758537709713, 43.29272232949734, 46.98823682963848, 47.67893336713314, 51.24417945742607, 52.37285569310188, 53.32215875387192, 56.127768605947495, 54.546939432621, 53.361292853951454, 52.91355147957802, 56.38148099184036, 49.184165596961975, 41.270193457603455, 39.818295165896416, 39.45504605770111, 41.50659017264843, 39.395203068852425, 39.27677482366562, 39.29702013731003, 41.74486018717289, 47.45871238410473, 49.78987969458103, 53.3634777367115, 54.04427960515022, 54.11587916314602, 45.16064129769802, 53.067671209573746, 52.109548822045326, 47.575673907995224, 54.0737584233284, 52.98044688999653, 53.25582571327686, 50.140342488884926, 48.45442235469818, 46.82567775249481, 45.09050466120243, 42.892824187874794, 40.543326660990715, 39.983734488487244, 39.55162167549133, 38.926741406321526, 39.33734357357025, 39.424229711294174, 37.03660123050213, 37.20084361732006, 37.08765149116516, 39.92056667804718, 39.955574199557304, 40.261537581682205, 37.99695409834385, 42.35105685889721, 47.11931839585304, 42.87332743406296, 41.897855177521706, 41.63362495601177, 36.9528803229332, 39.0972800552845, 40.91039076447487, 40.705251172184944, 45.191370248794556, 48.609663024544716, 46.38648971915245, 47.933876886963844, 44.07195791602135, 41.0383564978838, 42.18980111181736, 41.252083629369736, 42.430107817053795, 44.099593833088875, 48.87495718896389, 50.40466770529747, 54.8242599517107, 48.73398095369339, 41.866829842329025, 26.519531272351742, 8.58169510960579, 1.989434666465968, 3.8093701656907797, 8.13758634030819, 9.927099365741014, 11.703697834163904, 1.5265199937857687, 0.15309167734812945, 0.3518677392276004, 0.13129147526342422, 0.306603439967148, 0.4379248683108017, 4.168768655508757, 18.486674912273884, 44.98833954334259, 35.899956822395325, 44.14402484893799, 34.89973269402981, 6.420958153903484, 0.13514209364075214, 0.18510087771574035, 0.15702204691478983, 0.05944037373410538, 0.1154296865570359, 0.12909109645988792, 0.1253412023652345, 0.08651849260786548, 0.12920528330141678, 0.09443317103432491, 0.2292484525241889, 0.12285609118407592, 0.07957171575981192, 0.15012316085631028, 0.33781256061047316, 0.1642202856601216, 0.06415397627279162, 0.05890327403903939, 0.15496387844905257, 0.19898542173905298], [0.05208950489759445, 0.037649685982614756, 0.10189131731749512, 0.04451794731721748, 0.10221421092865057, 0.054063970237621106, 0.035762293118750677, 0.018996746657649055, 0.04669962771004066, 0.01937372057000175, 0.06016768216795754, 0.0058065935718332184, 0.0240831837800215, 0.02512374718207866, 0.014410492949537002, 0.07759222979075275, 0.02873055334930541, 0.05732513411203399, 0.01934722033183789, 0.022399365734599996, 0.053093074093339965, 0.01450896945243585, 0.06951598581508733, 0.021845202209078707, 0.021360049140639603, 0.19655919255455956, 3.277921420522034, 31.708834916353226, 43.61755929887295, 19.667900428175926, 34.57295782864094, 23.72343610972166, 2.826410410925746, 0.061119857637095265, 0.0566963643359486, 0.06053146440535784, 0.08025029848795384, 0.14679209038149565, 0.4002959030913189, 0.18326673394767568, 0.3231696307193488, 1.878791016060859, 4.1235738806426525, 18.833003528416157, 45.394704937934875, 54.655134826898575, 52.07307077944279, 50.16692966222763, 47.968675419688225, 47.82472774386406, 46.469982638955116, 44.3407516926527, 44.25699658691883, 44.228486716747284, 41.905633360147476, 43.558860048651695, 40.17902880907059, 38.15446324646473, 36.242622435092926, 36.95389486849308, 38.53211358189583, 37.60589428246021, 38.86372558772564, 43.03365223109722, 46.575138196349144, 49.465361908078194, 48.95838551223278, 49.65705782175064, 52.0624465495348, 49.89042989909649, 50.99968537688255, 53.17476466298103, 52.34416723251343, 51.057681664824486, 42.52646304666996, 36.63435861468315, 36.74525186419487, 36.54747247695923, 37.10771441459656, 37.720598727464676, 38.77987928688526, 40.19674725830555, 44.56279277801514, 47.2588887065649, 48.27669449150562, 47.827125415205956, 46.16604454815388, 45.93792758882046, 47.832604721188545, 37.291426956653595, 48.122969940304756, 47.80397705733776, 49.44662131369114, 47.17802904546261, 47.72019535303116, 44.95201349258423, 45.28874762356281, 43.40924687683582, 41.903376281261444, 40.7959409058094, 38.149287924170494, 34.06483009457588, 36.1066847294569, 34.18188661336899, 34.80083540081978, 36.973243430256844, 35.173432007431984, 36.292502358555794, 34.667523354291916, 37.05746591091156, 35.75739227235317, 41.03331796824932, 45.58442875742912, 47.28149749338627, 46.337924525141716, 43.232651352882385, 37.952735871076584, 34.551055803895, 34.67421479523182, 35.59446081519127, 37.543247044086456, 42.36055254936218, 43.95531177520752, 43.20635676383972, 43.78449194133282, 41.677618995308876, 40.11534422636032, 40.89193515479565, 39.70905862748623, 40.6854048371315, 42.895997017621994, 44.70923312008381, 44.38811995089054, 47.39719748497009, 44.69235062599182, 28.4614322707057, 8.998791128396988, 2.0699629141017795, 2.385167400352657, 2.7609764970839024, 7.245140578597784, 6.217706585302949, 4.570677364245057, 0.1733104369486682, 0.11792043806053698, 0.028077968054276425, 0.10596215317491442, 0.09375752721098252, 0.04177410119154956, 2.0134692080318928, 20.38617018610239, 28.216351121664047, 27.300315275788307, 33.32912117242813, 12.978856209665537, 0.8394054765813053, 0.0035367499776839395, 0.035273058238090016, 0.027594215789576992, 0.0062796705060463864, 0.023767338716425, 0.10593715021968819, 0.03862195138935931, 0.022208192203834187, 0.036784011535928585, 0.03734076330147218, 0.042548372730379924, 0.042738822667161, 0.012996754503546981, 0.08663701359182596, 0.0406439475773368, 0.012086020560673205, 0.040886537099140696, 0.03620777468313463, 0.02171529853512766, 0.011824598113889806, 0.06078565369534772, 0.01077115752195823, 0.08218859526095912, 0.06588537711650133, 0.12989684619242325, 0.009162874339381233, 0.05520033933862578, 0.09092961801798083, 0.056088760611601174, 0.05762388194852974, 0.012304370611673221, 0.033364054033881985, 0.009834831544139888, 0.013122811997163808, 0.05695224572264124, 0.12834758323151618, 0.027342805842636153, 0.017325764056295156, 0.04697128344560042, 0.035455901161185466, 0.10564670330495574, 0.05147008618223481, 0.09924614714691415, 0.03216634642740246, 0.1408723642816767, 0.20409405464306474, 5.452145989984274, 42.76881784200668, 47.62580081820488, 24.52283151447773, 38.90679627656937, 24.01148535311222, 2.920425678603351, 0.12291361505049281, 0.01658822140598204, 0.13609386835014448, 0.1034141301352065, 0.12208417596411891, 0.17446514451876283, 0.316759166889824, 0.3688877681270242, 3.4492226410657167, 4.622006909921765, 22.84032929688692, 46.379589289426804, 56.56330123543739, 54.54172611236572, 52.404610589146614, 50.27471087872982, 49.56693425774574, 49.08252865076065, 46.5453439950943, 45.98371133208275, 46.35363668203354, 42.703168764710426, 45.045515075325966, 42.337461188435555, 39.73735950887203, 38.95272821187973, 39.189390912652016, 39.81267146766186, 39.247273206710815, 41.99921853840351, 46.443501859903336, 49.64279718697071, 50.82397140562534, 50.038048177957535, 50.98556913435459, 51.55810721218586, 53.07621695101261, 53.532633259892464, 53.48754867911339, 53.264565244317055, 53.13757225871086, 45.73808491230011, 37.75908686220646, 38.9779132604599, 39.52069133520126, 39.18347083032131, 39.29683014750481, 38.37680831551552, 42.497945576906204, 45.459096282720566, 48.97317051887512, 50.14087826013565, 50.66267006099224, 47.38166391849518, 46.866970136761665, 48.22483107447624, 41.81590877473354, 51.38983704149723, 48.36918532848358, 53.14389131963253, 49.109492003917694, 48.97567838430405, 48.08743044734001, 47.24121205508709, 45.301450341939926, 43.951808363199234, 40.902593582868576, 40.01149959862232, 36.46271802484989, 38.844943195581436, 35.403118282556534, 37.45320327579975, 36.94313384592533, 37.676160112023354, 37.492325976490974, 35.39669282734394, 37.45441921055317, 37.50784434378147, 41.25542365014553, 47.00066216289997, 49.13886822760105, 47.2247551381588, 44.56509165465832, 39.04830448329449, 36.32461443543434, 36.05297081172466, 37.62322895228863, 40.41839696466923, 44.21308234333992, 44.20221112668514, 45.97533658146858, 45.57162344455719, 43.04793566465378, 40.94070553779602, 42.353857308626175, 40.772317573428154, 41.55126057565212, 44.93168458342552, 46.77819550037384, 46.84848792850971, 49.1879577934742, 45.23765176534653, 30.293011888861656, 11.853903774172068, 4.209538567811251, 3.5587619757279754, 6.203902401030064, 11.036365292966366, 8.923730906099081, 7.11412550881505, 0.9176169172860682, 0.1423808981780894, 0.1339174312306568, 0.06519533562823199, 0.21308055758709088, 0.05813267984194681, 1.9349145982414484, 22.832205332815647, 35.29299259185791, 28.400529138743877, 38.41691516339779, 18.43198824673891, 1.2062965705990791, 0.0008890046706255816, 0.03367709192389157, 0.021310542324499693, 0.050567044600029476, 0.060431749443523586, 0.0578052183118416, 0.01628833808354102, 0.09037724492372945, 0.04963993145793211, 0.012648203919525258, 0.04073950651218183, 0.019516491229296662, 0.044633047000388615, 0.09107262987527065, 0.037433160687214695, 0.030733637759112753, 0.0665251529426314, 0.06167993422423024, 0.05639780945784878, 0.059364641274441965, 0.1275050378171727, 0.1679832860827446, 0.34602691826876253, 0.15841838292544708, 0.16646593547193334, 0.1409506460186094, 0.11655821115709841, 0.19943168997997418, 0.1507854089140892, 0.11231370532186702, 0.10206106133409776, 0.14622264046920463, 0.11500380511279218, 0.13025229040067643, 0.23761873540934175, 0.19945123814977705, 0.13949927233625203, 0.17843115201685578, 0.06127102569735143, 0.111709552584216, 0.20720424712635577, 0.12809770210878924, 0.16502533777384087, 0.18365107738645747, 0.19112346548354253, 0.36423862853553146, 6.005767732858658, 45.30139334499836, 56.221091598272324, 29.17979322373867, 46.056819409132004, 30.546756573021412, 5.695396112278104, 0.3346801333827898, 0.12765045423293486, 0.3947617078665644, 0.22315674112178385, 0.3453667036956176, 1.6889952379278839, 0.5962609173730016, 0.7330993528012186, 7.121368395164609, 6.534852767363191, 22.62574151158333, 46.40660583972931, 56.6144160926342, 55.32105669379234, 54.27177719771862, 51.750483289361, 53.25195752084255, 50.485253781080246, 48.95876929163933, 48.151928186416626, 47.067329585552216, 44.46336731314659, 47.81082049012184, 45.112725868821144, 42.66572177410126, 40.47827795147896, 40.7443168759346, 41.891140937805176, 41.84647053480148, 42.07142226397991, 48.283701315522194, 51.59939959645271, 54.01925414800644, 52.36779436469078, 53.360282108187675, 54.84959319233894, 54.353640004992485, 54.15765792131424, 54.49314571917057, 55.88681973516941, 54.65140722692013, 47.56736375391483, 40.6493865698576, 39.73791427910328, 41.11817881464958, 42.22622595727444, 39.631269201636314, 41.10717460513115, 43.82513076066971, 47.32949271798134, 52.43736483156681, 50.83677291870117, 52.02009402215481, 48.223934322595596, 47.208169028162956, 48.56781207025051, 47.89517976343632, 50.67959055304527, 49.34973791241646, 54.91893567144871, 50.91392017900944, 50.65777212381363, 49.16438385844231, 48.27604092657566, 47.423792257905006, 45.27642488479614, 43.48704390227795, 40.82796558737755, 37.464329078793526, 39.933235198259354, 38.55966970324516, 39.43682983517647, 38.77607949078083, 38.33219110965729, 39.47567515075207, 38.489293679594994, 39.78306345641613, 39.2315686494112, 45.040035769343376, 49.64722774922848, 50.68589821457863, 49.55311439931393, 46.94065198302269, 41.28803350031376, 37.463360130786896, 37.8233490139246, 39.78073038160801, 42.443578094244, 47.47711859643459, 47.46345832943916, 48.348248451948166, 47.85459414124489, 45.93131594359875, 42.676053419709206, 44.63359817862511, 44.54253986477852, 43.693825006484985, 46.97360381484032, 48.75581458210945, 48.09387490153313, 49.75506976246834, 44.74003426730633, 33.19631449878216, 10.113981887698174, 3.6762462090700865, 4.339030394330621, 8.673631176352501, 14.669450093060732, 11.13719668239355, 11.011165995150805, 0.8926832489669323, 0.4017335025127977, 0.15132820088183507, 0.19023913715500385, 0.3884312475565821, 0.22603251883992925, 3.4255299624055624, 27.62143224477768, 39.0648677945137, 35.424017161130905, 45.72946697473526, 21.04868173599243, 1.3010579044930637, 0.12663158937357366, 0.12252735687070526, 0.20524442807072774, 0.1316093816421926, 0.16298020142130554, 0.17724088073009625, 0.11751994548831135, 0.16347595606930554, 0.08854180239723064, 0.17209208279382437, 0.14670502161607146, 0.15895112621365115, 0.08844104100717232, 0.2615927770966664, 0.12911315308883786, 0.09078088420210406, 0.1444541322416626, 0.11467409858596511, 0.11924594349693507, 0.17080577759770676], [0.030328031789395027, 0.04854406135564204, 0.07523091626353562, 0.027421610793680884, 0.040896392820286565, 0.09657025948399678, 0.013733506766584469, 0.06542116374475881, 0.014554836961906403, 0.021697312586184125, 0.03839911412796937, 0.008428350374742877, 0.048074890437419526, 0.08415833683102392, 0.023980862024473026, 0.03115881045232527, 0.01752373565977905, 0.040051973483059555, 0.05846003376063891, 0.03273683905717917, 0.0531418443279108, 0.04683284321799874, 0.008230491948779672, 0.06845812109531835, 0.012869930742454017, 0.15568821458145976, 0.39624822966288775, 11.801459938287735, 39.367738142609596, 32.31573075056076, 24.807289950549603, 35.445592403411865, 18.27086929231882, 1.5466036973521113, 0.10228804720100015, 0.45549135538749397, 0.10094351309817284, 0.14574551372788846, 0.18272140383487567, 0.03785736487770919, 0.8862580312415957, 2.8672926547005773, 0.15397610957734287, 3.659001071937382, 24.27290752530098, 48.14313165843487, 54.11532819271088, 53.84946025907993, 52.19912141561508, 48.41587722301483, 50.077725648880005, 49.027291014790535, 43.74875105917454, 43.75001639127731, 42.43769221007824, 42.10554823279381, 41.73432715237141, 41.3859998434782, 36.5151210129261, 38.094639256596565, 35.927904322743416, 38.71157415211201, 38.09676714241505, 40.80849543213844, 44.035202488303185, 47.718272656202316, 47.343244180083275, 48.0201930552721, 47.64378905296326, 49.604856222867966, 51.17210112512112, 47.228748723864555, 49.0480986982584, 51.01008541882038, 46.49579085409641, 38.731868863105774, 36.53388820588589, 38.66275817155838, 35.43469078838825, 37.51778081059456, 36.231310442090034, 37.210992872714996, 45.19460007548332, 48.77539113163948, 50.66856734454632, 49.44874919950962, 49.31680127978325, 48.616574853658676, 43.20816546678543, 36.10904820263386, 43.080287128686905, 48.912024199962616, 48.236238062381744, 50.35904735326767, 46.71883888542652, 48.32647942006588, 47.5970059633255, 47.174236848950386, 47.05873444676399, 44.95126873254776, 38.93878296017647, 35.835934057831764, 33.97839613258839, 34.714359641075134, 35.14850914478302, 36.49912007153034, 34.475455060601234, 34.21008110046387, 35.01953646540642, 38.26310321688652, 43.282652869820595, 46.735417395830154, 47.15983562171459, 47.50700019299984, 47.78006114065647, 44.637960344552994, 39.13915000855923, 35.316175147891045, 35.1085314899683, 35.729121789336205, 35.94148479402065, 42.688007578253746, 42.7675487101078, 43.668039590120316, 41.3583867251873, 42.64581464231014, 42.43589490652084, 41.86872214078903, 41.030612513422966, 40.79142674803734, 43.89875940978527, 44.92076396942139, 46.6712312400341, 47.160078808665276, 32.793441116809845, 13.133237175643444, 2.2232861118391156, 0.9834241610951722, 2.9186131758615375, 5.896734483540058, 4.609694145619869, 8.454390540719032, 6.968129742890596, 0.3175323363393545, 0.1508705926244147, 0.11392130851163529, 0.1392065396066755, 0.114576476480579, 0.16051346581662074, 6.425377791747451, 28.57421211898327, 26.867565996944904, 28.65800142288208, 30.340490341186523, 5.284353168681264, 0.055852546138339676, 0.05243789870291948, 0.043661772360792384, 0.08433441878878511, 0.059035550730186515, 0.038001141147105955, 0.030848240203340538, 0.0492837191268336, 0.0337334543291945, 0.06056605590856634, 0.041145669092657045, 0.03116388303169515, 0.07428213240928017, 0.04197244757961016, 0.03618069371441379, 0.016648005112074316, 0.02682375517906621, 0.04417022515553981, 0.008616045088274404, 0.028402895150065888, 0.049032253518817015, 0.060522592029883526, 0.05400604561145883, 0.14603854331653565, 0.03215637196262833, 0.023934175369504374, 0.04015207807242405, 0.014301745122793363, 0.028432015169528313, 0.06224798518815078, 0.006994230698182946, 0.09552047675242648, 0.02273102967592422, 0.02509163816284854, 0.08465269624139182, 0.03256058269471396, 0.025817597743298393, 0.041073328247875907, 0.06528670885018073, 0.01726527902064845, 0.05913662753300741, 0.07617029710672796, 0.04402064158057328, 0.015157261423155433, 0.10807381564518437, 0.0239669690199662, 0.217333048931323, 1.0408023884519935, 17.794004380702972, 49.87812615931034, 33.77948820590973, 30.97975093871355, 39.97423879802227, 17.966057248413563, 1.3478165329433978, 0.00933179921048577, 0.5984639085363597, 0.17679189622867852, 0.10924728470854461, 0.06264201365411282, 0.10151934548048303, 1.2734270934015512, 4.388576410710812, 1.213180257473141, 4.9436957482248545, 27.318615093827248, 51.116532906889915, 55.75264513492584, 55.547923520207405, 52.32272498309612, 52.16564521193504, 51.22366815805435, 49.27255265414715, 46.58673137426376, 45.68389981985092, 44.61808741092682, 46.33637800812721, 43.02275821566582, 43.754348158836365, 39.26961600780487, 40.07869139313698, 37.97054931521416, 40.17407767474651, 39.823972061276436, 43.95811602473259, 46.402399465441704, 49.92414928972721, 48.95909987390041, 49.380185678601265, 48.6847697943449, 52.73404911160469, 53.195519149303436, 50.319727063179016, 49.95377629995346, 54.50542666018009, 47.38843895494938, 40.3454826772213, 38.225428238511086, 40.33122964203358, 36.6007874161005, 38.69897402822971, 37.55727209150791, 40.15017315745354, 48.04417356848717, 49.73954759538174, 51.06289118528366, 51.906366124749184, 49.43305604159832, 50.046631917357445, 43.84644001722336, 36.46451912820339, 45.293132588267326, 50.45868560671806, 49.26658697426319, 51.55990071594715, 48.78405846655369, 48.02412964403629, 48.495543748140335, 47.65310235321522, 47.23908796906471, 45.91642074286938, 41.79621063172817, 38.01105514168739, 36.25311367213726, 35.454947501420975, 36.58224441111088, 37.099822238087654, 36.70398227870464, 37.65691414475441, 36.2215031683445, 39.56939332187176, 44.208507388830185, 47.462413385510445, 49.76746089756489, 50.248636677861214, 50.39480723440647, 47.758831679821014, 40.67360267043114, 37.66363978385925, 36.5782356262207, 37.325032353401184, 38.25636237859726, 43.96447688341141, 45.78720107674599, 45.80786056816578, 43.99651676416397, 44.47412073612213, 45.42142130434513, 44.30604435503483, 43.502220287919044, 42.379882112145424, 44.39482279121876, 47.14960277080536, 48.423058837652206, 46.864937245845795, 37.42256172001362, 16.1209674552083, 3.622226407751441, 3.5500421561300755, 6.091088354587555, 7.646113587543368, 12.926350627094507, 9.656310696154833, 4.244431145489216, 2.0501977996900678, 0.4582460591336712, 0.21335069934139028, 0.3725318913348019, 0.075147261377424, 0.26058609830215573, 6.459839567542076, 32.16207079589367, 29.893767312169075, 31.688819490373135, 36.011279448866844, 8.406931087374687, 0.07791064825141802, 0.06235186359845102, 0.025406470194866415, 0.029653773926838767, 0.013304907206475036, 0.030141422466840595, 0.03893431021424476, 0.03555357521690894, 0.05565743180341087, 0.046219098221627064, 0.084585509612225, 0.031225028578774072, 0.05137838641530834, 0.0491809390950948, 0.05950650280283298, 0.04090951399120968, 0.006655462084381725, 0.01281336981264758, 0.10968581977067515, 0.04058211554365698, 0.03701069683302194, 0.14964449044782668, 0.17368642380461097, 0.18645048810867593, 0.1902152696857229, 0.15177810564637184, 0.15377371106296778, 0.1167893382080365, 0.1707733457442373, 0.08801740084891208, 0.13009213493205607, 0.23721132602076977, 0.06688858265988529, 0.11453384009655565, 0.22919712559087202, 0.12225282160216011, 0.06571650883415714, 0.1847802402335219, 0.14700642263051122, 0.17223485716385767, 0.20162176777375862, 0.211296568159014, 0.20064447802724317, 0.09194279802613892, 0.23315069469390437, 0.1859276302275248, 0.2432374018826522, 1.2310777720995247, 20.364950224757195, 58.350782319903374, 41.61905273795128, 34.394230619072914, 44.736352264881134, 27.962868623435497, 3.85542678181082, 0.1994506741175428, 1.826210506260395, 0.5627731361892074, 0.5592291138600558, 0.3996570029994473, 0.3256168181542307, 1.8020928441546857, 6.126546626910567, 1.4600571664050221, 6.067729108035564, 27.434883154928684, 52.05866955220699, 55.62405623495579, 57.59054571390152, 54.87191699445248, 53.127035424113274, 54.373121559619904, 52.388172671198845, 49.85292591154575, 47.94653780758381, 46.54695510864258, 46.69108897447586, 45.48278421163559, 46.83452367782593, 39.839878007769585, 41.10535070300102, 38.721039444208145, 43.66972289979458, 41.162317246198654, 45.45151948928833, 48.55027221143246, 52.80664041638374, 50.98685726523399, 52.00416147708893, 50.71955680847168, 54.111589193344116, 55.90037360787392, 50.29157057404518, 50.85345022380352, 56.32811285555363, 51.249567568302155, 43.0278005450964, 39.484274089336395, 43.74034970998764, 39.2508640140295, 40.7703872770071, 40.18940985202789, 41.23908072710037, 49.139909371733665, 52.01951265335083, 52.89804831147194, 53.70618514716625, 50.72845593094826, 53.28986048698425, 49.342548698186874, 41.074310168623924, 46.15026019513607, 49.81059618294239, 51.52602173388004, 54.41541709005833, 50.25339402258396, 51.434397250413895, 50.91756038367748, 51.37341432273388, 49.455227851867676, 48.24142478406429, 44.01865437626839, 40.296248719096184, 36.836127787828445, 37.240954264998436, 37.565171867609024, 39.39305238425732, 37.53422252833843, 38.692088797688484, 38.695998787879944, 42.10489086806774, 46.469294875860214, 50.630010813474655, 50.9299249202013, 51.55424281954765, 52.37113058567047, 49.60827983915806, 42.07225441932678, 40.24517945945263, 37.774251848459244, 39.30015876889229, 39.64246340095997, 47.41124913096428, 48.732639625668526, 47.79238007962704, 44.43002790212631, 46.4338693767786, 48.268532529473305, 46.19172737002373, 44.916732385754585, 44.17133018374443, 47.87236958742142, 49.44977894425392, 51.22130088508129, 50.174590051174164, 37.08651915192604, 15.950785987079144, 3.8026946363970637, 2.8797018388286233, 7.394598908722401, 13.89893788844347, 13.993150983005762, 16.02982174605131, 13.25564380735159, 2.3947538109496236, 0.5105516477487981, 0.3340125270187855, 0.4351861058967188, 0.22902613476617262, 0.6601107912138104, 8.705653008073568, 36.70605316758156, 36.07635855674744, 37.92678706347942, 42.68560990691185, 9.159129224717617, 0.21349564078263938, 0.14981519925640896, 0.07100838542100973, 0.14018639718415216, 0.169544646050781, 0.09073426990653388, 0.19064624968450516, 0.14468532608589157, 0.13629286782816052, 0.16918356152018532, 0.16347475379006937, 0.10082068765768781, 0.1460914287599735, 0.15123374032555148, 0.11149818892590702, 0.1408134525991045, 0.10810563151608221, 0.10382125008618459, 0.24828146793879569, 0.14874499262077734, 0.1139744240208529], [0.056109889555955306, 0.026139517285628244, 0.11423989766626619, 0.00761950310334214, 0.0901966358651407, 0.041227984402212314, 0.018462220359651837, 0.061964254709891975, 0.015446197139681317, 0.06819713744334877, 0.021016316022723913, 0.03839425677142572, 0.03460246844042558, 0.07972510284162126, 0.0729211226280313, 0.012061539891874418, 0.012052289948769612, 0.009007574371935334, 0.07146486561396159, 0.018286205195181537, 0.036906046589137986, 0.008597524793003686, 0.028403787582647055, 0.038063407337176614, 0.02878191739000613, 0.08984492465970106, 0.11906377592822537, 2.725913403555751, 30.010637640953064, 40.564164742827415, 18.613470308482647, 35.662294775247574, 23.238599225878716, 4.735225159674883, 0.268134749494493, 0.831327288178727, 0.12928708281833678, 0.054383650349336676, 0.09568350433255546, 0.055485940029029734, 0.6622111878823489, 0.6109436263795942, 1.8498162645846605, 0.6876385328359902, 3.8609257992357016, 24.37243938446045, 46.70734830200672, 55.54702676832676, 54.770489037036896, 53.11081409454346, 50.66708542406559, 48.213617876172066, 48.13288360834122, 45.12499921023846, 46.38919897377491, 44.73355561494827, 45.064928233623505, 40.940948724746704, 38.89056734740734, 38.743256852030754, 38.8796429336071, 38.181111216545105, 39.22958895564079, 40.87956681847572, 43.46743315458298, 45.47083005309105, 44.27740529179573, 43.49762253463268, 46.03536956012249, 48.69361571967602, 51.005442067980766, 52.61950805783272, 48.91688793897629, 52.678066715598106, 50.79755902290344, 42.41126462817192, 38.369379714131355, 37.37360894680023, 36.798293218016624, 37.82507412135601, 37.27306254208088, 39.45770211517811, 44.62365411221981, 48.50704573094845, 49.72780242562294, 47.77701370418072, 50.37749916315079, 47.51740783452988, 55.33687524497509, 45.72340250015259, 41.65871120989323, 47.06494711339474, 46.54741108417511, 50.17861023545265, 48.470556288957596, 48.963758423924446, 47.173001915216446, 47.97991901636124, 42.28289611637592, 45.481005907058716, 42.21861116588116, 38.14033940434456, 35.16763351857662, 33.763346672058105, 34.08659912645817, 35.25172680616379, 33.685036674141884, 35.88588997721672, 41.09389811754227, 45.8884846419096, 45.540096536278725, 47.91774295270443, 48.27105559408665, 48.70588906109333, 48.27309608459473, 45.20343080163002, 39.2308808863163, 35.25867663323879, 34.93947476148605, 35.91238595545292, 37.16649726033211, 41.05927437543869, 43.91225628554821, 44.32073816657066, 43.09433877468109, 43.48441444337368, 42.9250730574131, 45.551457926630974, 43.040472865104675, 45.71743302047253, 46.5391693264246, 45.92444971203804, 45.4692455381155, 40.21910525858402, 18.38161624968052, 3.2424800097942352, 0.5853840603958815, 4.196413122117519, 4.077783487737179, 4.257976943627, 13.412940166890621, 10.952907521277666, 2.8394498862326145, 1.802756383549422, 0.24355927133001387, 0.13309953996213153, 0.12960990221472457, 0.09044921840541065, 0.5527022515889257, 13.537185899913311, 29.82914797961712, 24.588624984025955, 33.17461386322975, 23.154304549098015, 1.2398801185190678, 0.08678113124915399, 0.08039169246330857, 0.037919089299975894, 0.04871191660640761, 0.04883332454483025, 0.005567045927818981, 0.030242623579397332, 0.04871899298450444, 0.07275272932020016, 0.023958387937454972, 0.008747600968490588, 0.010169530869461596, 0.03943677387724165, 0.016713573859306052, 0.09453558741370216, 0.07676669440115802, 0.055509889134555124, 0.02119840937666595, 0.04400427351356484, 0.007666516767130815, 0.05146942196006421, 0.038378051976906136, 0.028322641155682504, 0.029268517646414693, 0.011502563538670074, 0.03634507942479104, 0.025877618936647195, 0.03631655497883912, 0.028258013080630917, 0.020948003184457775, 0.05196211895963643, 0.04629791801562533, 0.04317859711591154, 0.05338057097105775, 0.022812688184785657, 0.021962049650028348, 0.07453585785697214, 0.04784771903359797, 0.04753491120936815, 0.0815532129490748, 0.05484497676661704, 0.004706904192062211, 0.03701235924381763, 0.01915904136694735, 0.022044305587769486, 0.04924218854284845, 0.06007496565871406, 0.08184855803847313, 5.974572831764817, 37.70445719361305, 45.36979727447033, 24.034077040851116, 40.14382749795914, 30.027138255536556, 5.313757415860891, 0.10630656906869262, 0.8504587272182107, 0.1559232230647467, 0.10603282047668472, 0.1131724072911311, 0.2751677267951891, 0.6173600570764393, 1.33498830255121, 4.45170764811337, 1.7261868109926581, 4.440177166834474, 30.758834592998028, 49.971574544906616, 56.87020316720009, 55.85291035473347, 54.59245339035988, 51.71419143676758, 50.548041611909866, 50.45624993741512, 49.13639456033707, 47.278852835297585, 47.75153607130051, 44.592434987425804, 42.7627419680357, 40.78575745224953, 40.83363488316536, 40.83037845790386, 39.576149359345436, 40.23509860038757, 42.998291328549385, 44.947655126452446, 47.21023991703987, 47.05549702048302, 46.38815402984619, 47.85456754267216, 49.98795926570892, 52.72698529064655, 51.28053970634937, 49.648014307022095, 53.97494092583656, 51.39116697013378, 43.63426320254803, 39.117684960365295, 37.54244148731232, 38.11897315084934, 38.099723383784294, 38.42427916824818, 40.26156038045883, 46.8302147090435, 49.87154871225357, 51.74315728247166, 50.45688450336456, 51.18373230099678, 49.22321230173111, 56.81489713490009, 48.35482969880104, 42.43036240339279, 47.336134761571884, 47.92790740728378, 52.78641030192375, 51.060698702931404, 51.30962334573269, 49.817006438970566, 51.15170381963253, 45.55864714086056, 46.75451897084713, 44.37414050102234, 39.85127739608288, 36.13347329199314, 35.41875824332237, 35.94106301665306, 37.57385440170765, 35.95477268099785, 37.08853304386139, 42.448905408382416, 45.73722615838051, 48.11737284064293, 49.33584585785866, 48.83674643933773, 50.70021964609623, 49.663905054330826, 46.926254555583, 42.627123445272446, 35.89385814964771, 36.39220140874386, 35.97672790288925, 38.5139125585556, 43.398839235305786, 45.93265727162361, 45.800431966781616, 44.78006511926651, 45.445743799209595, 44.29790519177914, 46.11899547278881, 45.79603560268879, 46.30873069167137, 48.935776725411415, 47.31131449341774, 47.03346200287342, 43.94904211163521, 21.589390821754932, 5.884836846962571, 2.3449304094538093, 4.995862198993564, 4.453392857685685, 7.531677503138781, 9.821038506925106, 11.305036526173353, 4.763939268887043, 2.4049168406054378, 1.3585788616910577, 0.6179107306525111, 0.7530375360511243, 0.10230720945401117, 0.5281875701621175, 14.379559848457575, 35.128799602389336, 26.854770183563232, 35.92559404671192, 28.863709084689617, 2.2883808938786387, 0.06334230420179665, 0.03829897614195943, 0.01963142949534813, 0.005503371512531885, 0.042199808231089264, 0.03106877309619449, 0.09803036824450828, 0.049317368102492765, 0.04509518235863652, 0.030186582152964547, 0.026212928678432945, 0.0869613914983347, 0.04492687810852658, 0.009602510563126998, 0.013697940266865771, 0.049364075166522525, 0.05321349497535266, 0.04829772769880947, 0.023536796106782276, 0.020518594683380798, 0.05562749727687333, 0.10437472155899741, 0.08571054611820728, 0.25138869183138013, 0.09453959501115605, 0.22884212667122483, 0.101076313003432, 0.20527739427052438, 0.1197454534121789, 0.10570614191237837, 0.23467126622563228, 0.09691519488114864, 0.08436187825282104, 0.12597413558978587, 0.23044562578434125, 0.1480136506143026, 0.0843438514857553, 0.22553683840669692, 0.14951320452382788, 0.18804678838932887, 0.10346161274355836, 0.1302042289171368, 0.1348161869100295, 0.13790812256047502, 0.07887818617746234, 0.27439280587714165, 0.22798111662268639, 0.31525563506875187, 8.051376566290855, 43.38634550571442, 52.273042649030685, 28.215034492313862, 45.568625405430794, 32.95434348285198, 9.001317042857409, 0.5757827474735677, 2.347500971518457, 0.4720713204005733, 0.4768384021008387, 0.3590692434227094, 0.3268998133717105, 1.150379958562553, 2.293454334139824, 6.130169257521629, 1.6442870744504035, 5.504891909658909, 28.155295997858047, 51.03963643312454, 57.838562205433846, 57.91369557380676, 55.92596523463726, 55.19497945904732, 52.53225713968277, 52.27993547916412, 52.174255549907684, 49.054535552859306, 50.728075951337814, 48.94985117018223, 46.071099042892456, 41.96843259036541, 43.33113446831703, 43.07090163230896, 42.825157418847084, 42.31521338224411, 45.236937403678894, 46.284252405166626, 49.5832733809948, 46.96733795106411, 47.82837934792042, 49.04867626726627, 53.7095707654953, 55.24077460169792, 55.643142610788345, 50.74891023337841, 55.91829724609852, 54.1500773280859, 45.504226461052895, 41.67072236537933, 39.63265612721443, 39.605886563658714, 42.032056376338005, 38.89858491718769, 42.461277544498444, 47.93511562049389, 53.31784978508949, 53.92833262681961, 51.25769533216953, 54.014405608177185, 51.63843870162964, 56.53831757605076, 49.660705626010895, 44.43149082362652, 46.20927482843399, 49.93689380586147, 54.224025160074234, 52.11447715759277, 52.57869824767113, 52.25940518081188, 52.35675975680351, 48.16335417330265, 49.69074301421642, 46.31680905818939, 40.65279878675938, 38.932365104556084, 36.391521245241165, 37.71147541701794, 39.20273959636688, 38.235246911644936, 38.758729621768, 44.97765451669693, 48.20176251232624, 49.034278839826584, 50.68678356707096, 50.16041301190853, 52.62203112244606, 50.3143085539341, 50.38982570171356, 42.696298733353615, 39.3707399815321, 38.515166491270065, 40.15340678393841, 41.693061366677284, 45.01361198723316, 49.460775554180145, 46.70997396111488, 46.26328133046627, 46.866764947772026, 46.11638881266117, 48.51085312664509, 47.34025754034519, 48.73192146420479, 51.32288083434105, 49.74965885281563, 48.261244520545006, 43.83562959730625, 21.280195713043213, 4.985401835292578, 2.024084650911391, 7.965658390894532, 9.548481982201338, 9.993100874125957, 25.015465579926968, 21.20234739035368, 8.631640579551458, 7.307474333792925, 1.9230054435320199, 0.6347917404491454, 0.9409167326521128, 0.318647992098704, 0.9518501115962863, 18.49484447389841, 40.41705943644047, 33.70514519512653, 43.101227805018425, 32.80427813529968, 2.6090865349397063, 0.16596397646935657, 0.25695560092572123, 0.16797636926639825, 0.14410829142434523, 0.1685915800044313, 0.0814093773078639, 0.19636846060166135, 0.13177087297663093, 0.1046874922758434, 0.09396868306794204, 0.14890130376443267, 0.1504686157568358, 0.12892332655610517, 0.13910341076552868, 0.2389663568465039, 0.2115248973132111, 0.10392395590315573, 0.1725947839440778, 0.11132558764074929, 0.13801709952531382, 0.10337352723581716], [0.04012653706013225, 0.05306459788698703, 0.03152533863612916, 0.013660318018082762, 0.06935733690625057, 0.0507001413643593, 0.045846907451050356, 0.03247204818762839, 0.037081646150909364, 0.03411856589082163, 0.06911699238116853, 0.04646609610063024, 0.033639001194387674, 0.009059943095053313, 0.036319761056802236, 0.024192197852244135, 0.0286941046215361, 0.039850343091529794, 0.06273772843996994, 0.07553823961643502, 0.05188837545574643, 0.06852131496998481, 0.042722918442450464, 0.03011733977473341, 0.00886493729922222, 0.049155123488162644, 0.05598423653282225, 1.0764488694258034, 13.644365798681974, 42.704909071326256, 30.42796354740858, 30.355868116021156, 34.91439610719681, 7.116374038159847, 1.3872356177307665, 0.4806163493776694, 0.08551657840143889, 0.014837696344329743, 0.16923460643738508, 0.13638183649163693, 0.31420282437466085, 1.6003831615671515, 4.00139001198113, 1.4433531439863145, 0.6751718174200505, 4.9673323798924685, 25.48380944877863, 47.8763023763895, 56.43136851489544, 55.23781456053257, 55.386804565787315, 51.78578719496727, 48.04069295525551, 48.24496999382973, 45.976829901337624, 45.20409196615219, 42.842309698462486, 41.097583919763565, 40.29141157865524, 37.866119518876076, 38.14239129424095, 39.442624524235725, 39.19155679643154, 38.51893588900566, 41.21848963201046, 41.45112454891205, 44.32834155857563, 42.036703526973724, 44.296506866812706, 47.89111018180847, 50.88650465011597, 51.5046326816082, 50.59357076883316, 50.52014730870724, 49.424536898732185, 46.40573188662529, 41.1125361174345, 37.8098027408123, 37.64706887304783, 37.11167760193348, 37.93043866753578, 35.86800813674927, 41.831970512866974, 45.17350360751152, 48.57312798500061, 46.45726092159748, 47.9544223845005, 46.12770840525627, 50.039720088243484, 45.616081058979034, 42.661971375346184, 49.4833729416132, 46.771055683493614, 49.55961965024471, 48.114693984389305, 48.98068651556969, 50.550055503845215, 47.068340331315994, 40.15711158514023, 47.78296418488026, 43.09009060263634, 37.276060581207275, 34.523750469088554, 35.102216228842735, 33.74635398387909, 35.73260620236397, 35.27028501033783, 41.28612980246544, 46.501220762729645, 46.45156502723694, 47.19262406229973, 48.830499574542046, 48.2921938598156, 47.56454810500145, 47.363516092300415, 44.69499908387661, 39.399466440081596, 35.31670331954956, 35.12015886604786, 36.01650036871433, 36.82967573404312, 42.82387688755989, 42.688786536455154, 43.396376967430115, 43.040883243083954, 42.78447300195694, 43.043953478336334, 43.969139233231544, 46.18253946304321, 46.08092911541462, 46.79618373513222, 48.74789580702782, 47.4321024119854, 28.29455092549324, 5.815626885741949, 0.8245510049164295, 0.7769370661117136, 4.353568414226174, 3.6456523882225156, 8.944954667240381, 7.969306670129299, 5.484378235414624, 2.1996110072359443, 1.0809534089639783, 1.118435903917998, 0.8504573616664857, 0.5651728855445981, 0.09546589921228588, 2.041125549003482, 24.43863943219185, 30.270072519779205, 30.998672023415565, 34.167838767170906, 10.177908707410097, 0.16477232478791848, 0.06493681590654887, 0.06888302290462889, 0.011996952634945046, 0.05583165468124207, 0.04640386330720503, 0.03987153140769806, 0.0429695266939234, 0.036830395765719004, 0.06524564581923187, 0.03834852192085236, 0.028526555506687146, 0.05555068128160201, 0.05006943458283786, 0.048910700861597434, 0.030866608358337544, 0.015156388471950777, 0.037535157753154635, 0.012450494850781979, 0.032243607711279765, 0.04809500263945665, 0.024570683890488, 0.05236463017354254, 0.024198719474952668, 0.03957298024033662, 0.016055361229518894, 0.04529153236944694, 0.06462980425567366, 0.10504891077289358, 0.02549116779846372, 0.014901162958267378, 0.0682579267595429, 0.03956510976422578, 0.041526435379637405, 0.03147332521621138, 0.02171262680349173, 0.0720225895929616, 0.06986699940171093, 0.013983859153086087, 0.012397080627124524, 0.03777080819418188, 0.035703938046935946, 0.08933405246352777, 0.055357448291033506, 0.03629767845268361, 0.031350073040812276, 0.02750339546764735, 0.051214423729106784, 0.09165151248453185, 1.4599599153734744, 19.711573384702206, 47.419965863227844, 31.47590931504965, 36.09136015176773, 34.341880828142166, 8.258159570395947, 1.815554928034544, 0.7418236252851784, 0.08931648582802154, 0.21014916332205757, 0.3463437856407836, 0.3705673076910898, 0.38494517211802304, 2.34956378582865, 5.47107657417655, 4.265018915757537, 1.97894366690889, 3.577227797359228, 27.206433713436127, 51.20843857526779, 56.56738221645355, 55.506984516978264, 55.22187441587448, 51.32029317319393, 48.67548309266567, 47.92159214615822, 48.328250125050545, 47.959586307406425, 45.63462786376476, 44.14781704545021, 42.55871191620827, 40.049816742539406, 39.20694977045059, 40.84397792816162, 40.54447419941425, 40.7233078032732, 42.70378053188324, 43.81009876728058, 46.1491696536541, 46.119899824261665, 46.32039986550808, 49.99183885753155, 51.56022749841213, 54.23092179000378, 51.35735638439655, 51.8853722512722, 51.49894818663597, 46.88579432666302, 42.244214192032814, 38.046910017728806, 38.96261528134346, 38.82611520588398, 39.86438289284706, 38.65476340055466, 43.92747446894646, 47.23815321922302, 50.59512488543987, 49.87867712974548, 50.27496166527271, 48.50449226796627, 51.866836845874786, 46.50887735188007, 44.541259333491325, 48.61391119658947, 47.44880631566048, 51.720388904213905, 48.80239628255367, 50.984809175133705, 53.297133296728134, 47.943155989050865, 41.25407472252846, 49.79939058423042, 44.15654897689819, 39.45053569972515, 36.48978017270565, 37.194106578826904, 35.93169651925564, 37.0129968971014, 37.745156809687614, 43.39028589427471, 48.47482345998287, 48.08952793478966, 49.58727456629276, 50.788918286561966, 50.53257264196873, 48.25055569410324, 49.859795942902565, 46.07595518231392, 41.51877611875534, 36.35901018977165, 36.617692708969116, 37.34869748353958, 40.68044990301132, 42.71221607923508, 45.18674969673157, 44.85479190945625, 45.06335511803627, 44.28407393395901, 44.907780066132545, 45.393667593598366, 49.00853142142296, 47.402433604002, 49.25951175391674, 49.24539551138878, 48.690929263830185, 30.620143935084343, 9.103335868567228, 2.0434617111459374, 3.4278288390487432, 6.470602490007877, 6.127763036638498, 6.747810440137982, 10.088127125054598, 8.69668548926711, 6.109225256368518, 4.63858257047832, 0.5521204078104347, 0.6954446202144027, 1.0574660380370915, 0.15779217355884612, 1.9665749743580818, 25.138628371059895, 32.80464291572571, 30.89111689478159, 39.39841769635677, 14.9396051466465, 0.39096965978387743, 0.07971785948029719, 0.005151814302735147, 0.04901679087197408, 0.01014015202599694, 0.0718872070137877, 0.07835084572434425, 0.05304990707372781, 0.029340826949919574, 0.02792878709442448, 0.06503434153273702, 0.05556147210882045, 0.06361847219523042, 0.031321556016337126, 0.03802775085205212, 0.011115929646621225, 0.05459684340166859, 0.07014572780462913, 0.020654455947806127, 0.03977530082920566, 0.02336261961318087, 0.020545237784972414, 0.1158311364997644, 0.13619401375763118, 0.11218882413231768, 0.12238553987117484, 0.1077427361451555, 0.16696575708920136, 0.3285684285219759, 0.14978431107010692, 0.11676314039505087, 0.10322892718249932, 0.14335412095533684, 0.16128172224853188, 0.10266852405038662, 0.07470853335689753, 0.1795631943969056, 0.22002127108862624, 0.17285011243075132, 0.08448836248135194, 0.13991886778967455, 0.21720574091887102, 0.18385564297204837, 0.18903464631875977, 0.08660677107400261, 0.17605978238862008, 0.1342233593459241, 0.12712329189525917, 0.21800343092763796, 1.9264095858670771, 22.182506695389748, 57.43664637207985, 41.78262256085873, 38.5715364664793, 46.385585367679596, 11.21720613911748, 6.679651597514749, 1.3589369924739003, 0.12384616813506, 0.3864658623933792, 0.5776768864598125, 0.38262866204604506, 1.647394832689315, 9.302353989332914, 7.018087087199092, 4.452314665541053, 1.6384440567344427, 6.357508208602667, 29.47299499064684, 50.960729867219925, 58.34924720227718, 59.378304183483124, 60.05614601075649, 55.53511440753937, 50.796848461031914, 50.88809296488762, 50.444443970918655, 50.79201892018318, 47.81759932637215, 46.28170654177666, 44.62502583861351, 42.7181513607502, 41.64180211722851, 42.61830411851406, 43.125880882143974, 41.88397832214832, 44.69420872628689, 45.18754385411739, 48.054368421435356, 47.49597318470478, 47.978467494249344, 51.38751916587353, 52.86495968699455, 56.33214443922043, 52.37842619419098, 53.71285378932953, 54.9174727499485, 50.057978108525276, 44.15917083621025, 41.46494820713997, 41.681099608540535, 40.41059598326683, 41.52467340230942, 40.747090727090836, 45.159546956419945, 48.00906345248222, 52.15893097221851, 51.754963248968124, 51.827843338251114, 50.496588572859764, 53.319533094763756, 50.809532180428505, 46.25478498637676, 48.082802295684814, 48.59402306377888, 51.18736870586872, 49.4854362308979, 51.698711067438126, 54.44270342588425, 49.436422660946846, 43.91083136200905, 51.9991647452116, 44.63068753480911, 40.676095336675644, 38.93597491085529, 39.819796085357666, 37.478734105825424, 38.64822015166283, 39.83091048896313, 45.689458921551704, 50.328918769955635, 51.52133658528328, 51.420239210128784, 51.88897825777531, 51.87736228108406, 51.20495796203613, 51.386554017663, 49.74164128303528, 42.63615936040878, 38.56980375945568, 37.89678007364273, 39.046913757920265, 42.84606009721756, 47.63228327035904, 47.452450320124626, 46.66692987084389, 48.42131093144417, 46.45213879644871, 45.32129667699337, 47.525364607572556, 50.38142815232277, 49.673465341329575, 50.58272235095501, 50.3917445987463, 50.70949114859104, 31.70525550842285, 8.230765890330076, 2.278521847911179, 3.361182790249586, 10.126928742974997, 10.206435676664114, 16.451080441474915, 16.72821667045355, 12.971579600125551, 7.256647786125541, 8.234247453510761, 1.253155656158924, 2.675040545873344, 2.4006202211603522, 0.33738187747076154, 2.9802850540727377, 32.338278740644455, 39.43441316485405, 39.61673878133297, 46.93201504647732, 15.32719574868679, 0.44958979706279933, 0.1965181072591804, 0.16769107285654172, 0.21574814803898335, 0.14563699689460918, 0.20294216723414138, 0.11329591550747864, 0.1393354358151555, 0.14376185688888654, 0.3272161463974044, 0.1166738303436432, 0.10396025434602052, 0.2017224920564331, 0.12547348276712, 0.23392622417304665, 0.10125641740160063, 0.14850162755465135, 0.2065556397428736, 0.12216679184348322, 0.20424935646587983, 0.15706163307186216, 0.04954308860760648], [0.06700847661704756, 0.08371853269636631, 0.044303956456133164, 0.012371936663839733, 0.13324587664101273, 0.004176787178948871, 0.026847743247344624, 0.04893245320999995, 0.024032832770899404, 0.08057985658524558, 0.0232966593830497, 0.024365563549508806, 0.07070310297422111, 0.007802171621733578, 0.04823909061087761, 0.010948024300887482, 0.0849979804479517, 0.04591569711919874, 0.022280705597950146, 0.03007749572134344, 0.008825186941976426, 0.022132652702566702, 0.0076817864555778215, 0.029738521625404246, 0.09081192081794143, 0.12171089052571915, 0.08593996622948907, 0.07312588859349489, 3.9601501123979688, 27.05459576100111, 43.988810777664185, 18.113932013511658, 46.87948666512966, 12.863751836121082, 3.042395571246743, 1.0689554340206087, 0.06999153920332901, 0.0937049460480921, 0.11531707306858152, 0.28237047779839486, 0.2744267071830109, 0.6938184262253344, 6.077460385859013, 6.081738481298089, 3.035278315655887, 0.3021291206823662, 3.7616708502173424, 25.718766041100025, 51.39852337539196, 56.05407916009426, 52.60194920003414, 50.28304763138294, 50.52872724831104, 49.243522211909294, 46.71566225588322, 46.593909189105034, 42.98996977508068, 42.53673769533634, 40.0848812609911, 38.49680967628956, 39.84865553677082, 38.886102586984634, 37.905641198158264, 37.73246169090271, 38.70560847222805, 40.79066678881645, 39.96428333222866, 40.70484459400177, 39.7983880341053, 44.86461438238621, 50.41651166975498, 51.05155259370804, 51.08543537557125, 49.54225458204746, 52.71318823099136, 48.695029243826866, 43.76457341015339, 39.79546599090099, 38.356813788414, 36.01629137992859, 37.96008087694645, 36.40243045985699, 37.58912958204746, 37.80933536589146, 40.99180519580841, 42.53892257809639, 44.42232571542263, 46.582452803850174, 54.7341325879097, 45.95778912305832, 42.2447157651186, 44.65276055037975, 48.228950053453445, 45.954912677407265, 48.451021537184715, 46.70669473707676, 50.37652641534805, 43.90333816409111, 46.91675506532192, 51.28863327205181, 44.246615543961525, 37.46428728103638, 33.87501507997513, 34.66566905379295, 33.66628848016262, 34.655037224292755, 40.16004502773285, 48.15309852361679, 48.32625523209572, 48.53766828775406, 46.934902891516685, 48.680571019649506, 48.61732721328735, 48.09667155146599, 47.20427803695202, 43.705547377467155, 39.930791929364204, 35.92655159533024, 33.529731407761574, 34.86243389546871, 39.31943133473396, 41.23678185045719, 43.29960756003857, 42.40608170628548, 40.900670886039734, 41.77305467426777, 44.30517420172691, 42.28310890495777, 45.03633476793766, 47.9605058580637, 47.64575354754925, 45.800431966781616, 35.456524416804314, 13.472113441675901, 1.9657094520516694, 0.4480372241232544, 2.8414224553853273, 4.458246622234583, 2.971233227290213, 3.7622113712131977, 7.851809849962592, 8.065491858869791, 5.734632331877947, 2.3093548184260726, 0.46024748298805207, 0.5526080285198987, 0.6546136736869812, 0.2174899389501661, 6.718670278787613, 22.17459362000227, 28.71462408453226, 27.78571642935276, 25.186334811151028, 2.303179674781859, 0.048242801349260844, 0.0541918719682144, 0.012048086609866004, 0.038087601351435296, 0.02378319470153656, 0.11341754609020427, 0.038283294561551884, 0.01789896923583001, 0.034704112986219116, 0.026150616104132496, 0.01652086964895716, 0.0722838107321877, 0.04656723598600365, 0.020529760295175947, 0.055860832217149436, 0.02690607976546744, 0.05425892130006105, 0.07027673913398758, 0.00039902990351947665, 0.01085024819985847, 0.009628678690205561, 0.0315567797224503, 0.03755774501769338, 0.03367053133843001, 0.04701889964053407, 0.03748692928638775, 0.024252111434179824, 0.028510152187664062, 0.012577570942085003, 0.05092662257084157, 0.0435656716581434, 0.04675379335822072, 0.04647524307074491, 0.06829684498370625, 0.03776525321882218, 0.01714766531222267, 0.004921188201478799, 0.011256972029514145, 0.04759766350616701, 0.016631045182293747, 0.027249805461906362, 0.013661717894137837, 0.02071319322567433, 0.06019582811859436, 0.05162876477697864, 0.038993793350527994, 0.07601702876854688, 0.04979212368198205, 0.1428892693365924, 0.17312530078925192, 6.669671908020973, 39.88777443766594, 46.97989247739315, 22.950473986566067, 50.316029861569405, 12.937328238040209, 5.808519367128611, 1.659506920259446, 0.11041055666282773, 0.14561936346581206, 0.30194842256605625, 0.44019530585501343, 0.3352180420188233, 2.461691494099796, 6.028694277629256, 6.418680176138878, 5.2164883352816105, 2.0482905395329, 3.650812986306846, 28.61133422702551, 54.365388974547386, 54.69165466725826, 53.984185829758644, 52.56359405815601, 52.80256323516369, 50.153675973415375, 48.82007293403149, 46.98409505188465, 43.70773985981941, 44.83920514583588, 42.36538968980312, 39.934325739741325, 42.15514697134495, 40.942578837275505, 39.44868139922619, 39.765196815133095, 39.819066524505615, 42.38862544298172, 42.42799133062363, 41.91978760063648, 43.00037361681461, 45.88476084172726, 52.0839723944664, 51.563461124897, 50.711140260100365, 51.813316717743874, 53.771127462387085, 48.990015015006065, 46.35835982859135, 41.17123916745186, 39.26096387207508, 38.58564130961895, 39.587081372737885, 37.621735632419586, 39.06744785606861, 39.93323139846325, 43.027754947543144, 43.76694828271866, 47.71879322826862, 48.540039360523224, 55.69295793771744, 48.026078939437866, 43.30274999141693, 45.110806971788406, 48.27555075287819, 46.44506737589836, 48.102036863565445, 47.67939314246178, 50.479242503643036, 45.716034695506096, 49.23703595995903, 51.42079018056393, 46.346652656793594, 39.4040983915329, 35.9525004029274, 36.62015117704868, 35.93494534492493, 37.171615585684776, 39.97153714299202, 50.3835978358984, 50.104480013251305, 49.95142042636871, 48.59011307358742, 50.309752598404884, 50.62605142593384, 51.81970797479153, 48.17001901566982, 45.1817187666893, 40.90547762811184, 37.35595889389515, 35.83079293370247, 35.40016584098339, 40.00966049730778, 43.27121548354626, 45.50995275378227, 43.74372012913227, 43.886330276727676, 44.0948136895895, 44.59298595786095, 45.419563204050064, 47.79627487063408, 49.36470530927181, 48.104875311255455, 48.000833094120026, 38.21796923875809, 17.96873800456524, 3.734729108400643, 1.7986590159125626, 5.3543691616505384, 5.727961789816618, 6.085369661450386, 7.9633519146591425, 10.529795475304127, 9.769307132810354, 6.688246261328459, 4.097120650112629, 0.47791243821848184, 0.6043316842988133, 0.3660768095869571, 0.17143857723567635, 7.061790442094207, 28.969900086522102, 34.13066916167736, 33.309392631053925, 31.63573443889618, 4.991491958498955, 0.10639625761541538, 0.0816002428473439, 0.04867206698691007, 0.031018494446470868, 0.03125990951957647, 0.03355618493515067, 0.037625978075084276, 0.04149339125433471, 0.052710953386849724, 0.04504936958255712, 0.03612262436945457, 0.02598728795419447, 0.02008596155064879, 0.06160948585602455, 0.046010469377506524, 0.053474148371606134, 0.04293745107133873, 0.026604357772157528, 0.027583373012021184, 0.0977457917178981, 0.007399711430480238, 0.030618604869232513, 0.10270073325955309, 0.15088867134181783, 0.13132871623383835, 0.3181121021043509, 0.24440027307718992, 0.10235030596959405, 0.12315672778640874, 0.11468801385490224, 0.21808091114507988, 0.196577419701498, 0.1586816375493072, 0.14876807341352105, 0.14192952396115288, 0.146885541616939, 0.10189005566644482, 0.09679090740974061, 0.20718183426652104, 0.0849991975701414, 0.14288091275375336, 0.1970494256238453, 0.1596497988793999, 0.14040047710295767, 0.13407752732746303, 0.195758979243692, 0.15326689841458574, 0.2684515278087929, 0.230598523048684, 0.2652921457774937, 8.624346870929003, 45.08733183145523, 56.66344866156578, 27.138825841248035, 58.73288981616497, 16.82443130761385, 12.262827381491661, 3.993075108155608, 0.15619793644873425, 0.5132387566845864, 0.503343315795064, 0.6855384330265224, 0.6356149900238961, 5.62410481274128, 14.955867324024439, 14.091032780706882, 4.808953078463674, 1.8978952034376562, 5.413702027872205, 29.968883581459522, 54.82201047241688, 57.719305604696274, 55.615358501672745, 54.04144115746021, 53.78385677933693, 53.11915464699268, 50.13372324407101, 50.28588987886906, 46.69727884232998, 48.09343032538891, 44.63752716779709, 42.570859864354134, 44.729022458195686, 43.58162842690945, 40.5795007199049, 40.089665204286575, 41.86977468430996, 43.76054182648659, 44.525087401270866, 44.274038672447205, 43.12170870602131, 49.211683720350266, 54.34631399810314, 55.602032616734505, 52.651190757751465, 52.118740528821945, 55.819620341062546, 51.60544127225876, 47.94193625450134, 43.27760674059391, 41.26899652183056, 39.53402101993561, 41.36616870760918, 39.603211507201195, 40.123794972896576, 43.00606571137905, 44.46623235940933, 46.701169833540916, 48.62015426158905, 50.942095667123795, 57.37469829618931, 50.054539293050766, 45.662275180220604, 43.95351827144623, 48.10278542339802, 46.71207904815674, 49.09737065434456, 48.314745649695396, 51.142618507146835, 47.136694863438606, 48.90735425055027, 53.318168967962265, 49.49630744755268, 41.158536449074745, 37.916748002171516, 38.549672439694405, 36.912739276885986, 38.93888175487518, 43.99789609014988, 52.14023977518082, 52.32383452355862, 51.463545486330986, 49.61890786886215, 52.80438333749771, 52.19924680888653, 52.15349726378918, 49.764671847224236, 47.93173000216484, 43.410861790180206, 40.61044625937939, 38.331013172864914, 39.064354822039604, 43.602189123630524, 45.31256474554539, 48.50312054157257, 47.30240777134895, 43.678492829203606, 45.90345963835716, 46.72217130661011, 47.675456553697586, 48.9700660854578, 52.00122803449631, 51.04156292974949, 48.47100846469402, 38.90205033123493, 16.08419682830572, 3.011847110465169, 2.0849756710231304, 8.250355739146471, 11.518558468669653, 8.744635116308928, 12.851038668304682, 14.23443328589201, 16.59899700433016, 13.525893855839968, 8.893831260502338, 0.8321011404041201, 3.2107339007779956, 2.356871743686497, 0.6781000352930278, 8.857746496796608, 30.949126482009888, 40.00361502170563, 38.421509116888046, 36.80772051215172, 5.9694193582981825, 0.24392651568632573, 0.24972458893898875, 0.15460847876966, 0.1449827937176451, 0.2171941931010224, 0.16897994588362053, 0.1284676033537835, 0.08815805267659016, 0.10114280201378278, 0.09717742534121498, 0.12279652641154826, 0.17160085524665192, 0.15468287165276706, 0.1378246012609452, 0.1389791158726439, 0.0912741081265267, 0.15547659859294072, 0.14878969959681854, 0.06937751590157859, 0.16527648054761812, 0.09411508654011413, 0.13146685960236937], [0.028449051169445738, 0.052827971521764994, 0.06293418977293186, 0.06320121450698934, 0.1934988278662786, 0.04159075360803399, 0.0503071444836678, 0.010886479849432362, 0.05158731582923792, 0.061129449895815924, 0.03353300395247061, 0.03293149697128683, 0.06835744876298122, 0.044389830363797955, 0.027862036477017682, 0.05679550413333345, 0.038104492632555775, 0.03632788015238475, 0.07075336121488363, 0.0659982577781193, 0.007288830856850836, 0.04318428567785304, 0.08141649450408295, 0.07201953936601058, 0.13711329724173993, 0.060530325208674185, 0.051071935085929, 0.19980758777819574, 1.7397995805367827, 7.937909429892898, 41.11949734389782, 20.598206408321857, 46.209639608860016, 33.15841533243656, 2.6625698525458574, 2.4011628795415163, 0.12370470736641437, 0.33531707420479506, 0.2671065187314525, 0.2573242108337581, 0.1730936110834591, 0.7980166131164879, 2.807087260298431, 5.112143559381366, 7.399393301457167, 1.4500145427882671, 0.08889971795724705, 4.181438125669956, 24.73304383456707, 53.42655435204506, 52.52092994749546, 54.89841677248478, 50.19705444574356, 50.50875172019005, 47.59612061083317, 47.30240777134895, 43.02097611129284, 43.96200321614742, 41.823337376117706, 42.04608902335167, 39.963378980755806, 41.24712109565735, 39.2424588650465, 40.501342713832855, 37.04527996480465, 38.36840696632862, 38.12132142484188, 38.948746025562286, 39.2770180106163, 45.870139226317406, 48.815209195017815, 51.56324453651905, 51.680316254496574, 51.21148981153965, 50.46066530048847, 48.74655447900295, 46.40597887337208, 40.23789145052433, 37.8821774572134, 37.969561368227005, 38.28780569136143, 36.237587705254555, 36.85187414288521, 38.2166089117527, 39.28548015654087, 39.233183562755585, 45.24198353290558, 48.14287707209587, 51.57584086060524, 45.9821268171072, 43.006901666522026, 48.91448266804218, 43.751365318894386, 47.59810030460358, 46.87494970858097, 50.0327854603529, 46.68605424463749, 47.18989580869675, 52.185464948415756, 49.0611319988966, 43.22190172970295, 35.09959816932678, 35.599362552165985, 35.43744944036007, 36.27213545143604, 35.13176344335079, 44.448114931583405, 47.785415053367615, 47.80182637274265, 46.39767251908779, 50.04313990473747, 48.663308545947075, 46.977084428071976, 44.36445102095604, 44.61191274225712, 41.74634210765362, 37.6912073045969, 34.34430509805679, 36.00665509700775, 34.98180828988552, 35.73815010488033, 39.4582112878561, 38.776546865701675, 38.757141306996346, 40.63365161418915, 40.026877373456955, 41.44410252571106, 44.36538577079773, 45.39799936115742, 44.028685837984085, 47.943927347660065, 42.682733461260796, 25.49221459776163, 4.740599971264601, 1.1509211920201778, 1.3441139878705144, 4.406751310452819, 4.242409178987145, 5.696890857070684, 4.847364742308855, 10.38676355034113, 8.361133094877005, 4.219884937629104, 3.6498402385041118, 0.7571341318544, 0.13906875246902928, 0.049163962466991507, 0.6356682465411723, 12.499760817736387, 30.401030592620373, 23.496599681675434, 27.475960850715637, 15.669174548238516, 0.45688522746786475, 0.10414482647320256, 0.08904693779186346, 0.04242014074407052, 0.08809062113869004, 0.013367880292207701, 0.06722796679241583, 0.10394443917903118, 0.012321289723331574, 0.09239849154255353, 0.026328247295168694, 0.018723172470345162, 0.06754249639925547, 0.06765373691450804, 0.017053904230124317, 0.06529994876473211, 0.01886945163278142, 0.005904107601963915, 0.04039482715597842, 0.01722439224977279, 0.02200700339017203, 0.048944201407721266, 0.017617405828787014, 0.04621334286639467, 0.08829985483316705, 0.07254641226609237, 0.033339578003506176, 0.08477825278532691, 0.034918823730549775, 0.05729510681703687, 0.04260807480022777, 0.015150049603107618, 0.011769910179282306, 0.015980003554432187, 0.01790398615412414, 0.0625793838116806, 0.03902025091520045, 0.029645322720170952, 0.04461469368834514, 0.006509495551654254, 0.0670938755501993, 0.06089840448112227, 0.10805587051436305, 0.05435531886178069, 0.03464108980551828, 0.12743051134748384, 0.06694819196127355, 0.05558158431085758, 0.06851113270386122, 0.02938743567938218, 0.16924937517615035, 2.3581631993874907, 16.541091911494732, 50.27534544467926, 24.072536677122116, 50.10083980858326, 34.43231217563152, 4.234666619449854, 2.8061954956501722, 0.030311747214000206, 0.4943653178634122, 0.3639553359244019, 0.029658638704859186, 0.6768879003357142, 1.179805223364383, 6.011066548526287, 7.5423321314156055, 9.10555874928832, 3.218877576291561, 0.5271292675752193, 5.269254203885794, 28.119697608053684, 55.44752150774002, 52.829374596476555, 55.93629688024521, 51.78730711340904, 52.212090119719505, 49.12092179059982, 48.29986184835434, 46.95388667285442, 46.32937118411064, 43.10665771365166, 43.4927473962307, 41.837442219257355, 41.84577137231827, 39.59959790110588, 41.84280373156071, 38.74233730137348, 40.90957760810852, 40.36064766347408, 40.79607009887695, 39.51835826039314, 48.57441611588001, 51.70621946454048, 55.08562512695789, 52.47213676571846, 51.86415039002895, 52.1402283757925, 51.010697185993195, 47.81272038817406, 42.243864610791206, 39.47488099336624, 39.91521656513214, 40.332969948649406, 38.86657923460007, 39.74784314632416, 40.28501272201538, 40.09405396878719, 41.711353585124016, 48.32820452749729, 49.65934529900551, 53.77014711499214, 47.89177134633064, 43.57123598456383, 47.49984137713909, 45.558799132704735, 46.638328805565834, 47.25619085133076, 50.41302725672722, 47.52080485224724, 47.12987422943115, 53.0094925314188, 50.83399526774883, 44.29519973695278, 36.73982575535774, 36.39845207333565, 35.900693982839584, 37.02375791966915, 36.631721556186676, 45.42914628982544, 49.805162474513054, 49.73167061805725, 47.00999066233635, 49.97203052043915, 50.752945616841316, 49.4245520979166, 47.148022055625916, 45.33332683146, 43.05849529802799, 39.72495697438717, 36.020490154623985, 37.65972599387169, 37.484532594680786, 38.7461256980896, 40.876473784446716, 41.61956571042538, 42.2934215515852, 42.81051680445671, 41.08974874019623, 43.43020275235176, 46.54151380062103, 46.64201460778713, 46.00983493030071, 49.97230410575867, 43.58512423932552, 27.129077464342117, 6.192258400842547, 2.593426387757063, 3.144179997034371, 4.297556094825268, 5.280049899592996, 7.927387319505215, 7.002820931375027, 8.634902704507113, 11.136635262519121, 8.598478808999062, 2.8863806929439306, 0.4339360917219892, 0.3673736681230366, 0.1692477721371688, 0.5696926242671907, 13.135119024664164, 30.03862503916025, 29.095424450933933, 31.68355867266655, 20.9664199501276, 0.9889082761947066, 0.15709548984887078, 0.030655057307740208, 0.016707996619516052, 0.0238864311540965, 0.07583842350868508, 0.05180730324354954, 0.038970716268522665, 0.041431210411246866, 0.009195205075229751, 0.019871840813721064, 0.0165761021344224, 0.0377968983957544, 0.05607056686130818, 0.021613653989334125, 0.004679161784224561, 0.044028460106346756, 0.021133862937858794, 0.029721812170464545, 0.01165514631793485, 0.02976806652441155, 0.0667317520128563, 0.02871314442018047, 0.13552826276281849, 0.14241902972571552, 0.1377929115551524, 0.23455620364984497, 0.32910194364376366, 0.13960514712380245, 0.14247329556383193, 0.12154322452261113, 0.1262302210670896, 0.12857598660048097, 0.16352437378372997, 0.09980363363865763, 0.17367839376674965, 0.13744113355642185, 0.11852081326651387, 0.18117651954526082, 0.13955034693935886, 0.10528034210437909, 0.1910450798459351, 0.15239686385029927, 0.13275886449264362, 0.16354098304873332, 0.21934078104095533, 0.20144354843068868, 0.3115487558534369, 0.17168069549370557, 0.09992775041610003, 0.24288427317515016, 2.8721411945298314, 21.023149006068707, 63.407296389341354, 30.56571565568447, 52.23324738442898, 42.255533784627914, 8.42621885240078, 5.385775901377201, 0.13148326106602326, 0.8144027588423342, 0.6597431015688926, 0.7196411280892789, 0.6823058158624917, 3.421870283782482, 7.216312950477004, 18.097782880067825, 14.282408561557531, 4.873744826763868, 0.5857380945235491, 6.03417738340795, 29.155795611441135, 56.50157354772091, 55.68891875445843, 60.669376105070114, 54.65869143605232, 55.95236621797085, 50.93786269426346, 51.2457487732172, 48.519794046878815, 48.16207364201546, 45.62528416514397, 46.9808766245842, 43.068503960967064, 44.769239500164986, 41.85392193496227, 44.00291182100773, 40.71123585104942, 42.453423365950584, 41.63721576333046, 42.481446862220764, 42.01506748795509, 50.83222076296806, 53.15708041191101, 56.535270139575005, 53.97174909710884, 53.88645887374878, 53.884577974677086, 53.719735220074654, 50.282698050141335, 43.91465775668621, 40.456315129995346, 42.661097422242165, 42.31625832617283, 41.4189288765192, 41.31833307445049, 43.09435777366161, 43.41770142316818, 43.64449605345726, 51.23470276594162, 51.82638041675091, 54.84713472425938, 52.18834899365902, 45.9281887114048, 47.54029780626297, 44.634909108281136, 47.56057731807232, 46.818081960082054, 51.36229991912842, 48.37757907807827, 48.03940102458, 54.17721927165985, 52.76794709265232, 47.14224636554718, 39.18894253671169, 38.57464849948883, 38.14733862876892, 38.50995697081089, 38.737579956650734, 47.37086869776249, 51.571292504668236, 51.71663090586662, 47.6986239105463, 52.62850597500801, 53.024494126439095, 51.1263819783926, 47.62986660003662, 47.73900054395199, 45.01778416335583, 41.3739924877882, 37.952135503292084, 38.92147868871689, 38.80599148571491, 40.111704021692276, 44.384950920939445, 43.84332798421383, 42.818177193403244, 45.61272203922272, 43.08668218553066, 45.455152094364166, 48.35085891187191, 48.86636584997177, 48.08700866997242, 52.36760817468166, 46.41616612672806, 29.05936438590288, 6.475152270868421, 3.1868160841986537, 4.2820424772799015, 7.889836309477687, 9.87366758286953, 12.905543893575668, 13.280651215463877, 18.84556945413351, 16.818648017942905, 12.459021303802729, 8.198603466153145, 2.462542410939932, 1.2188154738396406, 0.4444343049544841, 1.3928878144361079, 16.077733375132084, 36.47787921130657, 35.18599033355713, 38.65687608718872, 23.945363201200962, 1.4346412802115083, 0.18827986728865653, 0.13914750918047503, 0.06206390287843533, 0.1273461736855097, 0.09114398737438023, 0.16875010274816304, 0.21452874003443867, 0.16887698031496257, 0.2430042636115104, 0.13538096129195765, 0.12263161377632059, 0.18743882101261988, 0.11054018017603084, 0.11868184446939267, 0.1439224131172523, 0.14228038169676438, 0.14838083559880033, 0.1773014251375571, 0.05752766992372926, 0.09243729844456539, 0.1384108979254961, 0.14134693803498521], [0.038184158474905416, 0.009435262018087087, 0.05594088768702932, 0.027090985859103967, 0.042914244113489985, 0.02221915558038745, 0.025697275195852853, 0.06801544484915212, 0.025723131620907225, 0.08341327251400799, 0.034056548320222646, 0.02502869476302294, 0.018487544293748215, 0.0500480013579363, 0.04432803914824035, 0.009222607022820739, 0.06467093407991342, 0.02863841571524972, 0.05726853050873615, 0.016394596932514105, 0.07930225678137504, 0.03635746586951427, 0.04817532899323851, 0.0806656562781427, 0.023220284965645988, 0.03324479090224486, 0.06171507862745784, 0.11724127645720728, 0.14173944509821013, 3.098951024003327, 20.252006985247135, 34.20734144747257, 27.607160210609436, 37.50428393483162, 17.54118874669075, 3.2560476567596197, 0.04852391946769785, 0.04378524718049448, 0.18832075962563977, 0.11467648830148391, 0.39818315708544105, 0.6360921612940729, 1.4480229746550322, 5.030945241451263, 8.993771597743034, 3.650606134906411, 1.0439807991497219, 0.060681266913888976, 2.868088949471712, 24.314878173172474, 49.033636674284935, 52.808072939515114, 52.36600086092949, 51.20925173163414, 51.33216753602028, 48.17933991551399, 47.598168700933456, 45.418886840343475, 44.19427715241909, 44.29148353636265, 44.794090166687965, 44.019440934062004, 48.17259907722473, 46.25821240246296, 46.13268233835697, 40.42611815035343, 36.720534190535545, 38.28357271850109, 38.64283584058285, 42.21651367843151, 49.92273956537247, 49.97123256325722, 51.07620187103748, 48.668077290058136, 49.26557242870331, 48.752645552158356, 46.1850169301033, 42.67755053937435, 39.421144276857376, 36.24625504016876, 38.5408341139555, 36.582970172166824, 37.84887224435806, 38.45234826207161, 39.3384113162756, 42.43903733789921, 48.93647588789463, 47.18887746334076, 53.34869273006916, 43.69787558913231, 40.673712864518166, 50.1802783459425, 49.46181669831276, 51.27929337322712, 48.69288615882397, 48.317359909415245, 46.232047006487846, 50.643978863954544, 49.48437608778477, 45.22913262248039, 37.92261868715286, 34.551234394311905, 34.5557751506567, 35.99082514643669, 34.17183615267277, 38.645955473184586, 48.77461597323418, 47.73028381168842, 48.673856779932976, 49.37576271593571, 47.71234877407551, 46.79861180484295, 47.17050164937973, 43.64574618637562, 42.11950868368149, 40.45235954225063, 36.48051247000694, 35.651970729231834, 35.51695257425308, 35.29382474720478, 38.448434472084045, 38.728680834174156, 39.0636670589447, 38.343791887164116, 38.19440670311451, 40.424286648631096, 41.38259902596474, 42.475625574588776, 46.17956422269344, 49.03841681778431, 45.879296734929085, 37.48702526092529, 15.17714275047183, 1.8600202607922256, 1.6425513988360763, 2.089898781850934, 4.149458566680551, 3.8004456320777535, 6.660978449508548, 5.530036585405469, 8.168625924736261, 8.527713306248188, 7.478490332141519, 1.7548391735181212, 0.330802085227333, 0.27565561467781663, 0.08046574395848438, 4.051752984523773, 15.804054010659456, 24.605724066495895, 24.774391315877438, 24.974518977105618, 7.204266171902418, 0.062393208645517007, 0.08323068934259936, 0.010263588810630608, 0.024490878895448986, 0.04840726498514414, 0.03300966738606803, 0.02003984263865277, 0.01608257764019072, 0.03551641959347762, 0.010521328349568648, 0.08414920841460116, 0.013724831060244469, 0.03164696921885479, 0.04520643771684263, 0.06012103447574191, 0.03134669255814515, 0.07973949308507144, 0.021827379532624036, 0.04997474025003612, 0.0658689608098939, 0.016294158376695123, 0.007812149797246093, 0.10572165279882029, 0.05518991587450728, 0.010077406222990248, 0.01971358338778373, 0.01574940342834452, 0.04353349584562238, 0.0471673106221715, 0.10384904351667501, 0.14412475225981325, 0.02786197524983436, 0.041798128222581, 0.07555390635388903, 0.014095800070208497, 0.01915541412017774, 0.0019898317395927734, 0.04576380175421946, 0.05175949780095834, 0.05103323950606864, 0.0018300067586096702, 0.12493477261159569, 0.06342445994960144, 0.03939794100006111, 0.021962114587950055, 0.06732717709382996, 0.017250547389267012, 0.01208275511089596, 0.06913174627698027, 0.0333561501611257, 0.10575125706964172, 0.3013761673355475, 5.467085838317871, 34.71255473792553, 36.387577056884766, 36.887535229325294, 46.37825556099415, 13.981931135058403, 3.578763627447188, 0.11992244079010561, 0.2567469089990482, 0.15551890101050958, 0.2095160074532032, 0.4822902486193925, 3.7938123755156994, 6.107490174472332, 7.587194899097085, 9.873681832104921, 6.349901016801596, 2.8242604387924075, 0.5191410868428648, 4.235053723677993, 29.559478349983692, 50.79825058579445, 55.25913141667843, 53.97384278476238, 54.65665474534035, 53.00630830228329, 50.537827759981155, 47.87137784063816, 46.04254737496376, 45.904303193092346, 45.13564243912697, 46.60661190748215, 47.57441617548466, 49.46790777146816, 47.88495071232319, 46.636786088347435, 41.4841827750206, 38.397342413663864, 39.67682495713234, 39.16425906121731, 45.86418494582176, 50.69630965590477, 51.50985740125179, 51.9729233533144, 48.15476283431053, 50.342571437358856, 50.904082506895065, 48.525394946336746, 44.4116634875536, 41.80068679153919, 38.957044780254364, 39.60413105785847, 38.080815598368645, 39.261970818042755, 39.5795463770628, 40.738316997885704, 42.74079814553261, 48.98843050003052, 51.16204686462879, 54.78854186832905, 46.73298552632332, 42.43219010531902, 49.878437742590904, 49.13844645023346, 50.2025755494833, 48.8725671172142, 50.15905648469925, 47.25258484482765, 53.76670829951763, 50.61409346759319, 48.011962696909904, 39.216479659080505, 36.156697645783424, 36.82291969656944, 38.349073603749275, 34.91798311471939, 39.74790774285793, 49.80488508939743, 48.950364142656326, 50.261552184820175, 48.73556546866894, 49.72312867641449, 48.882944360375404, 47.94972203671932, 46.18277885019779, 44.35341641306877, 42.857505083084106, 37.17031605541706, 37.09050513803959, 37.919670045375824, 37.84013271331787, 39.907073602080345, 41.01493075489998, 41.01273067295551, 40.264839604496956, 40.194539576768875, 42.01406814157963, 42.46052898466587, 43.99586319923401, 47.78791531920433, 48.99463936686516, 48.660758882761, 37.788675874471664, 18.357633836567402, 3.1878562783822417, 2.076618019491434, 5.182298719882965, 5.525176171213388, 4.755684211850166, 8.864708673208952, 7.356166820973158, 8.565979152917862, 8.409260362386703, 4.169663032516837, 0.7306490186601877, 0.18397506937617436, 0.3472722717560828, 0.09384241406223737, 4.43842688575387, 21.026386432349682, 30.372625216841698, 26.531838811933994, 30.374622009694576, 10.55607296526432, 0.08951501033152454, 0.01607109104952542, 0.032244824833469465, 0.04907131275103893, 0.01639082682231674, 0.05567364030866884, 0.08367096103029326, 0.012021003785775974, 0.04084695094206836, 0.05141788722539786, 0.13630355475470424, 0.028533338736451697, 0.0008296861403778166, 0.0073005906506296014, 0.031108565199247096, 0.023061610081640538, 0.022904311881575268, 0.021760955460194964, 0.004658089428630774, 0.03337180947710294, 0.019832698089885525, 0.02515186344680842, 0.06964818458072841, 0.1331249510985799, 0.06968991554458626, 0.15453962230822071, 0.18749330949503928, 0.13180893030948937, 0.10496643590158783, 0.18574477988295257, 0.1678743091179058, 0.12206332161440514, 0.12851964274886996, 0.17328290326986462, 0.07086886907927692, 0.07505374334868975, 0.09074733170564286, 0.15706059406511486, 0.1695847071823664, 0.16139452869538218, 0.12484679842600599, 0.3148982464335859, 0.08983912848634645, 0.14501972298603505, 0.1637041219510138, 0.09687099998700432, 0.17113260459154844, 0.1690893087652512, 0.2893412037519738, 0.21506084507564083, 0.23949193098815158, 0.4755481635220349, 9.013735726475716, 45.231545493006706, 49.11984644830227, 35.74093535542488, 47.8223642706871, 22.612183839082718, 4.902978558093309, 0.3535320202354342, 0.27646238857414573, 0.9031889727339149, 0.37864321027882397, 0.8142854401376098, 5.384483495727181, 12.364295236766338, 9.200232569128275, 17.399498149752617, 9.172250870615244, 2.437654221430421, 0.5819285020697862, 5.15407525934279, 28.887100629508495, 51.15997597575188, 56.80099368095398, 57.17751167714596, 57.29549914598465, 54.74938116967678, 53.66143874824047, 50.69790557026863, 50.104875192046165, 47.70905815064907, 48.780479058623314, 47.585861161351204, 50.3058236092329, 52.299325838685036, 49.80560705065727, 49.557769149541855, 44.69645440578461, 41.283055767416954, 41.97873763740063, 42.032565549016, 48.010849356651306, 53.52321356534958, 52.689906880259514, 54.03044834733009, 51.98645822703838, 51.77727185189724, 52.82237537205219, 48.57127368450165, 45.74710562825203, 43.93170364201069, 40.34348398447037, 40.97976364195347, 38.946713134646416, 40.5854170024395, 41.99566952884197, 43.57734985649586, 45.68786680698395, 51.33086420595646, 52.29256220161915, 57.68604978919029, 48.36991488933563, 43.054072335362434, 50.83624854683876, 50.00556372106075, 51.11633911728859, 51.34656496345997, 50.94925448298454, 47.62337274849415, 53.21081332862377, 52.698011845350266, 48.67802515625954, 40.528397262096405, 38.35755094885826, 38.06376211345196, 39.61412452161312, 37.20921076834202, 42.411329224705696, 52.53902457654476, 52.01167367398739, 51.703460812568665, 52.12461121380329, 50.449991673231125, 50.477004423737526, 49.90537449717522, 47.53494769334793, 46.43167309463024, 45.00457227230072, 39.15615789592266, 38.44598360359669, 39.1229210793972, 39.80822950601578, 42.337951362133026, 43.33961561322212, 43.37693341076374, 42.299679815769196, 42.87650786340237, 45.9724335372448, 45.4081866145134, 46.24896749854088, 50.32355345785618, 51.62247575819492, 49.55619603395462, 39.50015723705292, 16.959162577986717, 3.181076729670167, 5.521397748962045, 8.01980311051011, 9.52787283807993, 10.54944897070527, 15.191971454769373, 14.08160263672471, 17.774315737187862, 16.785950772464275, 16.478115990757942, 5.231655221432447, 1.0670737037435174, 0.6424268963746727, 0.3519100713310763, 5.853844759985805, 21.865111626684666, 33.20533901453018, 33.74565862119198, 35.68979009985924, 11.035040114074945, 0.14970107178669423, 0.21167004655580968, 0.1338761529768817, 0.1848633459303528, 0.1878486794885248, 0.10502148099476472, 0.09220030842698179, 0.1324040288454853, 0.13258098653750494, 0.15497213113121688, 0.20356401277240366, 0.09348901818157174, 0.12949221243616194, 0.24251462426036596, 0.12615182058652863, 0.10920306754997, 0.23294237384106964, 0.14574126864317805, 0.11860223428811878, 0.2116742916405201, 0.13978551869513467, 0.16767044115113094, 0.2434096543584019], [0.05167460723896511, 0.04006869035947602, 0.027454589981061872, 0.0336540445277933, 0.07276058124261908, 0.06345118468743749, 0.05695159263268579, 0.0416104056785116, 0.06823549163527787, 0.014166990586090833, 0.047932542802300304, 0.01858426654507639, 0.07023540150839835, 0.049712123873177916, 0.04444065263669472, 0.05404982490290422, 0.03295139395049773, 0.05879352152987849, 0.03564130820450373, 0.03336621739435941, 0.03143953894323204, 0.041364695425727405, 0.05039380135713145, 0.023689218396611977, 0.01062633946276037, 0.03516635966661852, 0.016833278568810783, 0.018020618372247554, 0.01578318784595467, 0.6276244344189763, 12.654874194413424, 38.79345215857029, 24.004077650606632, 26.77480347454548, 37.32717543840408, 8.514010291546583, 0.7071481109596789, 0.08283400398795493, 0.18822741229087114, 0.17745781049598008, 0.5713859084062278, 1.773030934855342, 7.9075210355222225, 8.392051085829735, 6.754030231386423, 5.0155845656991005, 3.3587561454623938, 0.6911440822295845, 0.19875998696079478, 3.092769468203187, 23.85722693055868, 49.019976407289505, 53.695332929492, 51.37586139142513, 49.633092507719994, 48.54478530585766, 49.373866617679596, 48.786353543400764, 47.95980669558048, 48.94121043384075, 50.80988176167011, 52.68166892230511, 51.603001803159714, 53.43309000134468, 51.93171076476574, 48.24764885008335, 40.8454180508852, 36.676578149199486, 38.873916640877724, 40.88680922985077, 49.786691665649414, 48.53484123945236, 52.688029780983925, 49.92269776761532, 50.823621824383736, 51.93449601531029, 48.489034697413445, 42.42438532412052, 37.87693753838539, 36.99161924421787, 37.58234314620495, 37.814187705516815, 38.443753123283386, 37.02536903321743, 37.940166145563126, 41.401882991194725, 47.78205223381519, 47.63039097189903, 51.932075545191765, 42.59997010231018, 41.228201910853386, 50.62837690114975, 48.48528049886227, 49.51091006398201, 47.55093723535538, 50.00018320977688, 50.526147186756134, 49.904173761606216, 46.80883325636387, 40.18878288567066, 33.48529279232025, 36.32514260709286, 35.14305643737316, 36.914958357810974, 34.802659302949905, 40.11373691260815, 46.52705937623978, 50.863367691636086, 47.48030662536621, 47.186806574463844, 48.799276649951935, 45.32060131430626, 45.82350432872772, 41.153220534324646, 40.15166647732258, 39.31250810623169, 36.16839721798897, 34.776110127568245, 35.93211069703102, 37.13861435651779, 36.94426238536835, 35.47957018017769, 37.75681458413601, 37.91952945291996, 37.359420508146286, 39.057427793741226, 38.86447794735432, 43.51148799061775, 44.80092220008373, 44.754017516970634, 45.051389560103416, 27.6472195610404, 7.628126302734017, 0.876263736281544, 1.4652450755238533, 3.8656206848099828, 3.524937853217125, 2.821068372577429, 6.331868609413505, 5.393827194347978, 3.7318103900179267, 6.716644037514925, 3.739111223258078, 0.277341803885065, 0.09342626959551126, 0.13026315544266254, 1.3071903004311025, 7.127011092379689, 20.237334072589874, 26.40516310930252, 24.620604068040848, 17.709548212587833, 2.1357364347204566, 0.07970901307999156, 0.049097781447926536, 0.11380549636669457, 0.027209289764869027, 0.034831758675863966, 0.04854180522670504, 0.09074071916984394, 0.021413502327050082, 0.037515316435019486, 0.04025025307782926, 0.05796381155960262, 0.03739473228051793, 0.006224592016224051, 0.03541474536177702, 0.02298595369211398, 0.055966428699321114, 0.006183085088196094, 0.020936332912242506, 0.0419616827275604, 0.03715090708283242, 0.03857278039504308, 0.047100517331273295, 0.04799391841515899, 0.03344097392982803, 0.031030014433781616, 0.041486533809802495, 0.055258412394323386, 0.06483632911113091, 0.02668508303031558, 0.024123207804223057, 0.049866609333548695, 0.0471270528214518, 0.03770587398321368, 0.0007301111429569573, 0.06335008190944791, 0.047369256426463835, 0.05801955056085717, 0.03356922075909097, 0.05304169520968571, 0.01469631813961314, 0.05508265327080153, 0.09352741690236144, 0.004491737490752712, 0.02262460384372389, 0.04353565920609981, 0.09611983521608636, 0.002254810465274204, 0.012233793295308715, 0.03391161430045031, 0.05161012573807966, 0.044534333937917836, 0.09703450996312313, 1.5156507957726717, 17.8696621209383, 49.04906004667282, 25.724672824144363, 31.83198630809784, 41.05575576424599, 8.084196355193853, 0.7823551003821194, 0.22892998211318627, 0.28155432315543294, 0.2405584417283535, 0.9821768186520785, 5.519874030724168, 10.47597136348486, 7.030567042529583, 7.665361929684877, 7.705843057483435, 3.566487436182797, 1.652755276300013, 0.637410928029567, 4.29060579277575, 30.6319423019886, 52.195401415228844, 54.84973378479481, 52.95267418026924, 52.09365427494049, 49.80167046189308, 52.01216384768486, 50.62964603304863, 49.5052407681942, 51.73707760870457, 52.11131952702999, 54.10763740539551, 54.03984524309635, 55.65755143761635, 54.86263409256935, 49.005217999219894, 41.589060947299004, 38.12859043478966, 40.239491164684296, 42.592917680740356, 51.93058602511883, 49.221836775541306, 54.724963679909706, 49.5953681319952, 52.06512160599232, 52.02190652489662, 50.31784616410732, 43.846155032515526, 39.169092401862144, 38.01749959588051, 39.50236111879349, 40.108975768089294, 40.26777304708958, 39.296366572380066, 39.44113880395889, 42.94982872903347, 50.77519342303276, 49.416595324873924, 51.74075961112976, 43.17078307271004, 42.58846811950207, 51.92321062088013, 50.61322711408138, 50.07784724235535, 50.368888825178146, 51.29691682755947, 52.2264913469553, 51.29710301756859, 49.03531238436699, 43.00111837685108, 35.60345493257046, 37.426623702049255, 36.4137614518404, 38.52541834115982, 36.45761489868164, 41.19498409330845, 47.12532587349415, 51.53273217380047, 47.41077795624733, 49.07861486077309, 48.97714890539646, 47.60680563747883, 46.95786505937576, 43.22779901325703, 42.94102840125561, 40.0099378824234, 38.3625590801239, 36.26993916928768, 37.40562982857227, 37.51168213784695, 38.866286650300026, 36.39931462705135, 39.31625850498676, 39.72110778093338, 39.03531678020954, 40.142402574419975, 41.4911288022995, 45.5305552482605, 46.90640442073345, 46.78973168134689, 46.96197643876076, 28.860600851476192, 9.747148621827364, 1.1342624109238386, 3.550728731788695, 3.7517151469364762, 4.956989334896207, 5.812289239838719, 9.205360393971205, 7.50925300642848, 9.13915179669857, 7.767452476546168, 2.300189947709441, 0.8315536729060113, 0.07001194084296003, 0.19037965539610013, 1.157662149053067, 8.04342644289136, 19.35109432786703, 25.13034861534834, 27.38942239433527, 22.071077674627304, 3.1288786930963397, 0.025043248278961983, 0.07645427249372005, 0.021368116285884753, 0.06670011425740086, 0.023627380796824582, 0.05010466804378666, 0.04301512053643819, 0.05425740731880069, 0.04405994201079011, 0.048763020895421505, 0.029901990783400834, 0.051396190538071096, 0.06130145375209395, 0.04524051342741586, 0.01762660660460824, 0.08202285142033361, 0.03892563079716638, 0.004343413711467292, 0.010721439193730475, 0.04224296040774789, 0.035906288321712054, 0.061916378763271496, 0.004344608569226693, 0.10469174478203058, 0.19689885870320722, 0.14658476400654763, 0.21382576291216537, 0.28752686048392206, 0.09712399070849642, 0.12628009339096025, 0.26208980823867023, 0.10692831812775694, 0.13246210932265967, 0.12182288061012514, 0.1734012016095221, 0.2233621824416332, 0.25704222440253943, 0.1776726622483693, 0.17722011543810368, 0.15402621938847005, 0.2828566142125055, 0.13418448565062135, 0.07188106945250183, 0.13637379161082208, 0.18230347079224885, 0.1798134169075638, 0.10985546730807982, 0.14572158688679338, 0.10967231268296018, 0.22424766852054745, 0.13368410000111908, 0.22475486708572134, 1.8839435395784676, 25.657443031668663, 59.266168400645256, 32.98001490533352, 33.91061916947365, 48.732081055641174, 10.894706044346094, 1.370329256169498, 0.2429120591841638, 0.7041314290836453, 0.5791103595402092, 1.2486920831725001, 10.002835001796484, 20.97715437412262, 16.615543216466904, 13.038262221962214, 11.916656456887722, 7.2198686096817255, 1.6097318474203348, 0.6729185383301228, 4.783698208630085, 28.661385141313076, 52.94995732605457, 57.099175080657005, 56.66937254369259, 53.51250194013119, 52.245197743177414, 54.04066599905491, 53.367440924048424, 52.588060945272446, 52.61606924235821, 54.9798122048378, 56.9339295476675, 55.23993484675884, 57.376453801989555, 56.47061660885811, 52.909022122621536, 44.67091217637062, 39.79844503104687, 42.48304657638073, 44.85791154205799, 53.127062022686005, 50.99499262869358, 56.95907659828663, 50.403900146484375, 53.11867967247963, 54.621898010373116, 52.089877277612686, 47.38737881183624, 40.28439715504646, 41.51833914220333, 40.98671346902847, 42.01032914221287, 41.43214076757431, 42.504420429468155, 41.33730925619602, 45.67421793937683, 50.94830833375454, 51.66538305580616, 53.72848995029926, 47.219340428709984, 46.38439603149891, 52.05385521054268, 52.16035969555378, 51.2011543661356, 51.390767991542816, 52.892572805285454, 53.31974968314171, 54.21599239110947, 51.70251466333866, 42.981226444244385, 36.6263372451067, 39.00087542831898, 38.92135709524155, 39.588943272829056, 39.187023639678955, 43.965324237942696, 49.7202218323946, 54.32321883738041, 49.389445781707764, 48.324264138937, 52.158444598317146, 49.79532480239868, 49.9334017932415, 44.53862987458706, 44.92995947599411, 42.44144640862942, 40.09046696126461, 38.366541266441345, 39.292574375867844, 41.27925217151642, 42.03549139201641, 39.135866984725, 41.80352903902531, 41.93735785782337, 41.7923728376627, 41.63806311786175, 42.76063688099384, 47.93890401721001, 48.3314723521471, 47.38389439880848, 47.73298166692257, 29.654235765337944, 9.914137311279774, 1.9137865444645286, 5.029340302571654, 9.275899808853865, 9.176297653466463, 8.003782220184803, 13.242058586329222, 12.947275154292583, 12.198703922331333, 15.384862404316664, 10.729097630828619, 2.653436092659831, 0.48160156526137143, 0.3856710222316906, 2.5298052141442895, 10.302685461938381, 29.05425935983658, 34.62012089788914, 33.96830767393112, 26.38792533427477, 2.9479096038267016, 0.19206485012546182, 0.21102005877764896, 0.15850111754843965, 0.12136187331634574, 0.10090163370477967, 0.18511962436605245, 0.21141652890946716, 0.1287440088344738, 0.12462590559152886, 0.15431772015290335, 0.07371923566097394, 0.1584328548051417, 0.12878960638772696, 0.09001788217574358, 0.12605848809471354, 0.16633730643661693, 0.12064726673997939, 0.05917937894992065, 0.13489084696630016, 0.15452339896000922, 0.08099020487861708, 0.18970069417264313, 0.1432820435729809], [0.0811738493212033, 0.018476608747732826, 0.024918574890762102, 0.055216904074768536, 0.01876980717497645, 0.07457980784238316, 0.0480751390568912, 0.04979096964234486, 0.016839618365338538, 0.02501918042980833, 0.05050836298323702, 0.024217377067543566, 0.05126058902533259, 0.02606205005577067, 0.08215602982090786, 0.09579060366377234, 0.0150095823846641, 0.05025740945711732, 0.023610999742231797, 0.009004397979879286, 0.06631093943724409, 0.046386404283111915, 0.036705447782878764, 0.04317580664064735, 0.056639174435986206, 0.02633136246004142, 0.07197556711616926, 0.03462391650828067, 0.06236788656678982, 0.2910572866676375, 4.967778855934739, 31.17307886481285, 41.971255838871, 27.166568152606487, 32.44897820055485, 20.7680743932724, 3.1342029199004173, 0.054471620824187994, 0.07949467340949923, 0.35319170099683106, 1.0480763856321573, 4.447889802977443, 4.640796426683664, 5.5724418349564075, 7.869951976463199, 5.475445864722133, 3.9026200119405985, 2.3516515363007784, 0.44378691469319165, 0.3241345117567107, 4.300644379109144, 21.016740649938583, 48.20674404501915, 52.381219044327736, 53.322379142045975, 51.441404074430466, 50.573963820934296, 53.82600411772728, 56.17075189948082, 48.48255604505539, 53.05770814418793, 52.01572425663471, 51.74432381987572, 53.592267259955406, 52.27681204676628, 51.23418219387531, 44.08007048070431, 38.89209486544132, 38.37795965373516, 41.28640718758106, 48.491211980581284, 48.31234037876129, 52.820190489292145, 50.0684617459774, 51.565862596035004, 49.980431869626045, 49.94139276444912, 42.433949410915375, 38.35186265408993, 38.300949186086655, 37.713291719555855, 37.43947081267834, 38.450767546892166, 36.69613189995289, 40.00717543065548, 44.476738795638084, 48.70464272797108, 48.76392334699631, 54.20230932533741, 44.1682143509388, 39.156659469008446, 52.061758786439896, 48.62330809235573, 47.615871950984, 48.11375543475151, 46.34938471019268, 45.2384877204895, 45.195352435112, 39.51044708490372, 35.419635996222496, 34.49380427598953, 36.55898205935955, 36.00735045969486, 35.700019150972366, 34.73194509744644, 39.635969549417496, 46.9303697347641, 47.914197742938995, 50.03917671740055, 47.445553690195084, 47.471255511045456, 46.202507391572, 44.63791474699974, 40.27016691863537, 38.489913046360016, 36.592678651213646, 36.20059669017792, 34.48877714574337, 35.65197452902794, 38.191864639520645, 38.47985878586769, 35.648927092552185, 37.394431829452515, 38.293026611208916, 40.19570991396904, 38.68775703012943, 40.613797679543495, 43.41294027864933, 47.89809040725231, 47.085766196250916, 39.164813831448555, 19.475978426635265, 3.596029900945723, 0.27396532881539315, 2.2322077956050634, 3.3287615049630404, 4.935480589047074, 5.311924489215016, 8.954945281147957, 5.708479760214686, 8.391988389194012, 4.587323796004057, 1.4742567669600248, 0.6485715229064226, 0.22995781211648136, 0.3005440119886771, 3.520823623985052, 27.278576642274857, 51.48444056510925, 40.48179656267166, 31.875984147191048, 11.281848270446062, 0.2884121536044404, 0.09570136040565558, 0.0889943640504498, 0.013518243122234708, 0.07085144345182925, 0.021584044152405113, 0.057327935719513334, 0.012280097744223895, 0.08723082079086453, 0.05195702411583625, 0.009443767030461458, 0.007472802772099385, 0.05217175712459721, 0.0523318161140196, 0.05610505446384195, 0.020118697684665676, 0.0553032715106383, 0.007123391296772752, 0.056754570978228, 0.05335662928700913, 0.02180130046326667, 0.08892999758245423, 0.038404446459026076, 0.019922507235605735, 0.034845124755520374, 0.031243370758602396, 0.020941758011758793, 0.03185621775628533, 0.07302863014047034, 0.03865954859065823, 0.03258646509493701, 0.060235054334043525, 0.07701843089307658, 0.0506609448348172, 0.07481794076738879, 0.051859765662811697, 0.0438552465493558, 0.07261431877850555, 0.040654575132066384, 0.04741594864754006, 0.008115584296319867, 0.05224870299571194, 0.015215059884212678, 0.035514701521606185, 0.0549090575077571, 0.04181730902928393, 0.04385311658552382, 0.018966437346534804, 0.04928921473037917, 0.01883981025457615, 0.04301778484659735, 0.04036635837110225, 0.03318047267384827, 0.36138501134701073, 8.776366263628006, 40.88361360132694, 42.19246096909046, 28.165747337043285, 38.19912604987621, 22.22149070352316, 2.4672947684302926, 0.08849609352182597, 0.053505537507589906, 0.12349486511084251, 2.0775670185685158, 4.274731194600463, 7.196300849318504, 7.044139439240098, 8.869496416300535, 9.041769672185183, 6.4388499688357115, 3.1930389627814293, 1.355737920384854, 0.8764515887014568, 5.123136844485998, 28.28917421400547, 51.92084714770317, 55.507645681500435, 53.502998650074005, 54.95817996561527, 51.62831224501133, 55.800651758909225, 56.33392654359341, 51.81005649268627, 54.59047369658947, 53.61958399415016, 54.39654350280762, 53.87994982302189, 53.50383460521698, 53.673267513513565, 45.067793279886246, 40.69491192698479, 40.05136325955391, 43.07997554540634, 50.32737225294113, 50.3614754229784, 54.994224831461906, 50.548444390296936, 52.998203337192535, 51.81629575788975, 50.4632605612278, 43.774312287569046, 39.927550703287125, 39.71304081380367, 38.016089871525764, 39.03995633125305, 40.339984372258186, 38.9112838357687, 41.817592084407806, 46.62662163376808, 50.86150959134102, 50.97143389284611, 55.30045419931412, 46.78886912763119, 40.46054810285568, 54.318328499794006, 49.845303520560265, 50.734885185956955, 49.65555690228939, 49.25969034433365, 48.79406712949276, 47.69782215356827, 41.602842807769775, 37.21071168780327, 35.714131593704224, 38.95565405488014, 37.48258329927921, 37.03912049531937, 37.59208582341671, 42.61669680476189, 48.56618195772171, 50.63750401139259, 50.94823233783245, 48.32492530345917, 50.45752286911011, 47.29326546192169, 46.8266960978508, 41.485372111201286, 41.35500110685825, 38.64270284771919, 37.64022544026375, 35.97106620669365, 36.61012351512909, 39.81299825012684, 40.828957334160805, 36.50578111410141, 39.158065393567085, 39.88264471292496, 41.28597781062126, 39.57430645823479, 42.74674102663994, 45.769482627511024, 49.148698300123215, 47.26010464131832, 39.40005540847778, 20.511647053062916, 5.627521779388189, 1.5635842736810446, 4.382489137351513, 5.162188773974776, 5.074317064136267, 4.876485904678702, 9.281798042356968, 8.013504948467016, 7.566151628270745, 4.654076239094138, 2.1083964267745614, 0.6544284336268902, 0.10526099431444891, 0.2672989130951464, 3.5187731590121984, 23.4381740167737, 42.627533823251724, 37.33699411153793, 32.18700885772705, 15.867537204176188, 0.5636147316545248, 0.11386832658899948, 0.05256711403490044, 0.01868420044047525, 0.044181936245877296, 0.044306999261607416, 0.021119140583323315, 0.0074386245523783145, 0.012137800204072846, 0.016702849825378507, 0.03843663711450063, 0.02786471748549957, 0.033389197997166775, 0.028083552715543192, 0.0030416792651521973, 0.07674366555875167, 0.012445300744730048, 0.04098470468306914, 0.007623673973284895, 0.05498867882124614, 0.05474628967931494, 0.016280473173537757, 0.052811321438639425, 0.03677438959130086, 0.2291410934412852, 0.13246182730654255, 0.16807844425784424, 0.1416044929646887, 0.15717890724772587, 0.1383977322257124, 0.11760218287236057, 0.1390340199577622, 0.20963335584383458, 0.08967574467533268, 0.1486697536893189, 0.10513874774915166, 0.19327882560901344, 0.10705884706112556, 0.11911280962522142, 0.15944886981742457, 0.08647542577818967, 0.1615725105511956, 0.13052875525318086, 0.14769304281799123, 0.15277331083780155, 0.10717977260355838, 0.14156765275401995, 0.15686346479924396, 0.18281066935742274, 0.07744284288492054, 0.10102363536134362, 0.18939519650302827, 0.17954875220311806, 0.48861022980418056, 10.8684067055583, 48.62558417022228, 53.95905017852783, 36.598739326000214, 42.993609979748726, 26.26916080713272, 3.996219439432025, 0.5351257603615522, 0.15362198639195412, 0.9793023916427046, 1.487986024003476, 9.666304159909487, 12.339033242315054, 13.22104286402464, 15.82514002919197, 13.322283681482077, 10.110596269369125, 4.702398246154189, 2.0108649227768183, 0.9696984069887549, 6.237901076674461, 25.367611683905125, 49.97030921280384, 56.287952810525894, 56.821501180529594, 56.86168782413006, 53.952579125761986, 57.40519545972347, 60.480226054787636, 52.800081968307495, 57.026773765683174, 55.69152161478996, 55.15477001667023, 56.71130329370499, 56.924190670251846, 55.93437418341637, 47.61078022420406, 42.39566266536713, 42.27034159004688, 46.00803382694721, 53.26909080147743, 52.41838485002518, 57.45639771223068, 50.95199033617973, 54.08406347036362, 54.89799879491329, 54.2640446126461, 44.68361109495163, 42.38708272576332, 41.976480558514595, 40.68229280412197, 40.001255348324776, 40.4531878978014, 41.52341566979885, 43.89939397573471, 47.8500571846962, 52.94716827571392, 53.342453464865685, 55.85463926196098, 47.12366536259651, 42.70390212535858, 52.857793271541595, 53.44306066632271, 52.03298673033714, 53.25659327208996, 49.453795328736305, 50.69734700024128, 48.985614851117134, 42.41145081818104, 38.91113564372063, 38.03214780986309, 41.202363297343254, 39.62522752583027, 37.86363065242767, 38.85307475924492, 44.1129045188427, 49.7530634701252, 52.92249999940395, 52.79405929148197, 49.090154841542244, 51.19377136230469, 50.20932398736477, 49.07627038657665, 43.8496470451355, 42.98883743584156, 39.91203233599663, 40.34776635468006, 38.46142217516899, 39.652570858597755, 42.58933447301388, 43.189595863223076, 39.54280994832516, 42.03133061528206, 42.04042732715607, 43.87512847781181, 42.96231105923653, 45.43501317501068, 48.10290701687336, 52.550682350993156, 49.621522128582, 40.34919507801533, 20.90130664408207, 5.577225778251886, 1.7454543896019459, 7.292335946112871, 9.043757915496826, 10.162484385073185, 13.015432097017765, 15.930386781692505, 13.521013967692852, 15.949646048247814, 10.895379558205605, 4.383572079241276, 1.3262823759578168, 0.5406507826410234, 0.805530947400257, 5.660059433430433, 34.205525144934654, 55.9723911434412, 46.83539763092995, 41.15955859422684, 18.250149004161358, 0.6566808221396059, 0.238400335656479, 0.11174185085110366, 0.09012708920636214, 0.12258517759619281, 0.16906532255234197, 0.18252132082125172, 0.1400483725592494, 0.167256738350261, 0.1051821411238052, 0.2111266608699225, 0.10307534714229405, 0.1647691780817695, 0.06459096024627797, 0.12119866019929759, 0.14945150236599147, 0.1133567419310566, 0.1458114164415747, 0.1658425314235501, 0.1383370245457627, 0.15069807297550142, 0.11456861713668332, 0.08987728229840286, 0.05930595965764951], [0.03755216777790338, 0.029178845798014663, 0.06114486059232149, 0.16683861234923825, 0.04151744054979645, 0.037657908978872, 0.041643776348792017, 0.03218812475097366, 0.03949083933548536, 0.00737482582735538, 0.08028750977246091, 0.02389069108176045, 0.02764893062703777, 0.04496942172409035, 0.02461567102727713, 0.012953808272868628, 0.07649536521057598, 0.0481955822033342, 0.025352106022182852, 0.03135639242827892, 0.01654108018556144, 0.05285782812279649, 0.020445161026145797, 0.040104910876834765, 0.03907878781319596, 0.03870720189297572, 0.015974209236446768, 0.008362050612049643, 0.01148781149822753, 0.08290536148706451, 0.721774238627404, 19.881300777196884, 34.24177519977093, 27.270198091864586, 21.265422105789185, 30.235224589705467, 10.732560195028782, 1.4037717366591096, 0.12024801355437376, 0.2497315948130563, 2.4940434331074357, 2.866661651059985, 6.6531765181571245, 3.467618403956294, 8.29837091267109, 7.94446692802012, 2.645373400300741, 3.415859006345272, 1.35985535569489, 0.2493185451021418, 0.7948574388865381, 6.644631726667285, 24.867239333689213, 46.69501796364784, 52.96612545847893, 53.62777255475521, 54.91446331143379, 54.31696057319641, 53.530490174889565, 56.67439207434654, 54.608142748475075, 55.834523141384125, 52.86419592797756, 53.70338849723339, 52.24857196211815, 51.823017597198486, 43.92658531665802, 38.656674697995186, 39.16826784610748, 41.71945855021477, 49.562176913022995, 49.97709944844246, 52.95991279184818, 49.66656491160393, 52.12917476892471, 52.07797631621361, 49.23079289495945, 44.04830038547516, 37.80646272003651, 35.770136788487434, 38.10402475297451, 36.93914406001568, 39.491733089089394, 36.819328889250755, 42.798102870583534, 44.45550553500652, 49.97896134853363, 47.424305230379105, 55.48253282904625, 43.33671256899834, 38.41813489794731, 53.89298692345619, 48.407536670565605, 48.498724177479744, 44.15136605501175, 43.81092332303524, 41.46117500960827, 36.809536814689636, 35.13642959296703, 35.1352022588253, 35.953723937273026, 38.679028898477554, 35.27253448963165, 36.482142582535744, 34.84103724360466, 38.574986681342125, 47.278852835297585, 49.821456000208855, 49.08329240977764, 45.64367137849331, 48.4220252931118, 48.1383553147316, 46.97663985192776, 43.13239373266697, 37.74630054831505, 35.52379980683327, 34.789128229022026, 34.398228004574776, 39.43121373653412, 39.24153931438923, 39.65060256421566, 38.13372015953064, 39.98033747076988, 38.77456717193127, 39.65187169611454, 41.05141259729862, 45.736055821180344, 43.462166637182236, 45.863937959074974, 43.60399782657623, 30.336795039474964, 9.604483377188444, 1.4149947906844318, 1.5980500867590308, 2.4421560298651457, 2.912854109890759, 2.348882434889674, 3.543018945492804, 6.753216600045562, 6.964918915182352, 7.036184566095471, 5.092563210055232, 1.2886265153065324, 0.6158048124052584, 0.07123060669982806, 1.744038846809417, 9.146978426724672, 25.934508964419365, 32.0124576240778, 28.196206502616405, 28.41853067278862, 4.526147078722715, 0.058260032383259386, 0.05482675333041698, 0.05264518425974529, 0.026845001011679415, 0.03374624524440151, 0.02252708378364332, 0.01866486192739103, 0.08797022994258441, 0.04894073186733294, 0.050353996266494505, 0.06743741570971906, 0.007304441005544504, 0.021880270542169455, 0.03736428938282188, 0.016429229253844824, 0.023362673418887425, 0.02363444604270626, 0.04930220231472049, 0.057824536415864713, 0.03354737193149049, 0.07002943326369859, 0.044126230641268194, 0.0190651021694066, 0.053825651775696315, 0.05142583562701475, 0.02902403564803535, 0.034819958527805284, 0.09612937181373127, 0.031849475344643, 0.018456630132277496, 0.021587144474324305, 0.031143589003477246, 0.06947347559616901, 0.080100518243853, 0.030628980093752034, 0.03145071197650395, 0.0424989790917607, 0.005832257038491662, 0.023215108485601377, 0.027513054519658908, 0.025566601543687284, 0.008162886933860136, 0.011785178940044716, 0.020605886093107983, 0.01135353471909184, 0.04088823661732022, 0.040137903051800095, 0.05838888406287879, 0.0892462267074734, 0.03299628646345809, 0.02447978564305231, 0.030857923375151586, 0.10061399210826494, 0.020957677079422865, 1.6569390892982483, 26.612846665084362, 41.63857229053974, 30.850595869123936, 27.658421359956264, 33.5401314496994, 10.935867335647345, 0.9663940686732531, 0.03074490170547506, 0.40183547360356897, 0.8463452698197216, 4.57813398912549, 8.900202568620443, 8.744099345058203, 7.136876787990332, 9.4902453571558, 6.764072617515922, 4.940240308642387, 2.8768586413934827, 1.6117776813916862, 1.8460751278325915, 7.913923216983676, 30.103732645511627, 49.08204227685928, 56.83652177453041, 55.87573952972889, 57.72247463464737, 55.929210260510445, 55.55908352136612, 56.27143129706383, 55.66510163247585, 56.14127688109875, 52.65761621296406, 55.496797263622284, 52.90416218340397, 53.151578307151794, 44.770672023296356, 40.762096121907234, 41.45439997315407, 43.38002644479275, 51.05519279837608, 52.36600086092949, 54.89452198147774, 50.63508354127407, 52.91432663798332, 53.8118726760149, 48.856182396411896, 45.29022954404354, 39.1138319671154, 37.97597162425518, 39.95611757040024, 38.38177464902401, 39.934728518128395, 39.27307762205601, 43.76311428844929, 45.96541531383991, 50.13824500143528, 49.459008648991585, 56.034179627895355, 43.92092742025852, 40.01157559454441, 55.596211329102516, 49.2948954552412, 50.68868726491928, 47.65435628592968, 46.68166548013687, 43.642812743783, 40.07454961538315, 37.29542434215546, 35.93853995203972, 38.16269740462303, 40.7943107932806, 36.506172493100166, 37.781900838017464, 36.22633270919323, 40.296241119503975, 48.1636543571949, 50.862493738532066, 50.42946137487888, 45.617821365594864, 50.392014384269714, 49.53813560307026, 48.559866696596146, 44.41748857498169, 39.441560581326485, 36.87738977372646, 36.995453238487244, 37.20152758061886, 40.707952827215195, 41.41568765044212, 41.91306956112385, 39.54948239028454, 40.87232060730457, 40.888374745845795, 41.59381449222565, 42.311470583081245, 46.040613278746605, 45.23242324590683, 46.02261744439602, 46.019364818930626, 33.48603755235672, 11.991324350237846, 2.9006334906443954, 2.5116737745702267, 3.5470263054594398, 5.185305783525109, 7.246746467426419, 6.11038276925683, 7.284557763487101, 5.496466336771846, 5.678431922569871, 1.7928700265474617, 0.2101417863741517, 0.3881813812768087, 0.1720798818860203, 1.4229212841019034, 10.621714442968369, 34.877435490489006, 43.19635570049286, 34.57771897315979, 32.52337820827961, 6.253093611449003, 0.060369204948074184, 0.016425420180894434, 0.02972150788991712, 0.048637108120601624, 0.03568860898667481, 0.03549133129126858, 0.04152205670834519, 0.03137149884423707, 0.06462608609581366, 0.011914062160940375, 0.027892304970009718, 0.044112749528721906, 0.05103063827846199, 0.07372479434707202, 0.03484006330836564, 0.037291124754119664, 0.03716269238793757, 0.06594986974960193, 0.02297756371262949, 0.018512252245272975, 0.054289939362206496, 0.10165692481677979, 0.0653498581959866, 0.03900342642737087, 0.2225314371753484, 0.09328252301202156, 0.17403888457920402, 0.2564837731188163, 0.14293796906713396, 0.127122089616023, 0.12893552746390924, 0.07426501848385669, 0.16860241536051035, 0.17204620322445408, 0.14643753675045446, 0.0892137132177595, 0.07556040756753646, 0.14284990582382306, 0.1284066730295308, 0.1225236758182291, 0.12429926413460635, 0.23902464512502775, 0.10046067924122326, 0.1268035449902527, 0.06508638092782348, 0.1633904903428629, 0.08826446181046776, 0.15834275807719678, 0.1230203581508249, 0.10375297992140986, 0.08546916258637793, 0.12036006301059388, 0.15761364251375198, 0.11572068266104907, 2.670975001528859, 32.77417995035648, 50.11565141379833, 38.39078016579151, 30.933746807277203, 40.462128818035126, 12.748979944735765, 2.003731280565262, 0.20146971655776724, 0.872617238201201, 6.616466213017702, 9.672987051308155, 16.249983832240105, 14.252141285687685, 15.66157115623355, 19.129697307944298, 8.24133787304163, 8.280052095651627, 3.7034040642902255, 1.4626023173332214, 1.3825422758236527, 8.574259858578444, 29.144078940153122, 47.7269171923399, 58.2185760140419, 58.50935161113739, 58.653394281864166, 59.81050059199333, 57.85158030688763, 60.5366226285696, 58.386052027344704, 58.033191561698914, 55.30573211610317, 57.39725008606911, 56.06451719999313, 54.57392938435078, 47.546115294098854, 42.12760604918003, 42.319282963871956, 45.546871572732925, 53.75148631632328, 53.53273205459118, 57.16241888701916, 50.73639750480652, 54.37189042568207, 56.717082783579826, 52.42318399250507, 47.968949005007744, 41.86145693063736, 39.74497430026531, 42.04964943230152, 40.92958353459835, 42.23934665322304, 41.44903086125851, 46.50597810745239, 47.852971628308296, 52.66318291425705, 52.444443851709366, 57.4138817936182, 47.72404834628105, 42.93427996337414, 57.05309875309467, 52.20956705510616, 54.05847564339638, 49.375709518790245, 49.138100668787956, 44.22649182379246, 40.179617777466774, 38.03492546081543, 38.30396242439747, 39.81815077364445, 43.538880720734596, 38.357098773121834, 40.336990132927895, 38.25598619878292, 41.75630137324333, 51.06664538383484, 52.09629513323307, 50.938390865921974, 46.75617568194866, 50.967436507344246, 52.159455344080925, 50.65796971321106, 47.05612398684025, 42.51125246286392, 37.80154958367348, 38.82437489926815, 37.626014202833176, 43.75871792435646, 42.0058149844408, 43.845262080430984, 42.22874902188778, 44.038880690932274, 41.74013324081898, 45.006411373615265, 45.26749536395073, 48.8794257491827, 47.642227336764336, 49.32987257838249, 46.15759760141373, 31.63505807518959, 11.31357466802001, 3.1130366306751966, 3.6892890091985464, 6.115922871977091, 7.567633548751473, 8.385442290455103, 10.163316540420055, 16.604618802666664, 15.257623381912708, 15.082462280988693, 10.457833986729383, 3.5188425052911043, 1.3627975853160024, 0.39654410909861326, 2.377104707993567, 12.785777170211077, 34.95502732694149, 43.287053033709526, 39.76056106388569, 38.031585440039635, 7.028726991266012, 0.08005737719940953, 0.13363099191337824, 0.16187993780476972, 0.17425237077986822, 0.1681465734145604, 0.13012887124205008, 0.1377281962777488, 0.10738319528172724, 0.16632840066449717, 0.1222519607108552, 0.09379315772093832, 0.15848367707803845, 0.14917576481821015, 0.22883924713823944, 0.14810178807238117, 0.11500235792482272, 0.1420245782355778, 0.20004425867227837, 0.14142888598144054, 0.1683281027362682, 0.19266953720944002, 0.12956924736499786, 0.15564549656119198, 0.18740177300060168], [0.029676134836336132, 0.04449501124327071, 0.020451194686756935, 0.05704625727958046, 0.020502250736171845, 0.0553843845409574, 0.0390876750316238, 0.010410987688374007, 0.04217560308461543, 0.008027656494959956, 0.037671200843760744, 0.042413936389493756, 0.03961820300901309, 0.06941906132851727, 0.058033065070048906, 0.018146703696402255, 0.034693715497269295, 0.01828031996410573, 0.11337306175846606, 0.06284948845859617, 0.0457647665461991, 0.015323969128075987, 0.08149384113494307, 0.1376421665190719, 0.009209894960804377, 0.04994539573090151, 0.09357594593893737, 0.032056575364549644, 0.05979311652481556, 0.11256160491029732, 0.025022698209795635, 8.326520752161741, 28.006815165281296, 30.92376284301281, 18.62832371145487, 26.472018621861935, 27.05306064337492, 4.688368448987603, 0.32935837050899863, 0.05213980395637918, 1.0998842306435108, 3.3371894527226686, 6.873501995578408, 5.540776709094644, 4.25433293916285, 7.667391020804644, 6.772977914661169, 3.1137329433113337, 1.952485330402851, 0.8920984365977347, 0.5277672770898789, 1.012925065588206, 11.962195113301277, 31.405776478350163, 47.09984064102173, 51.8486662209034, 53.37543949484825, 52.49262906610966, 53.70823323726654, 55.12029066681862, 53.97636964917183, 53.898185044527054, 56.2557989358902, 51.830715984106064, 52.76548482477665, 48.37821364402771, 42.18336425721645, 39.132477566599846, 39.3277832865715, 41.679898872971535, 49.259215369820595, 50.19389681518078, 54.32453356683254, 47.41330862045288, 50.66278025507927, 49.849711284041405, 50.80166660249233, 44.796328246593475, 38.88197220861912, 36.15333862602711, 36.76301211118698, 36.782634258270264, 39.31049041450024, 40.84335096180439, 43.72669704258442, 44.72553424537182, 50.435662642121315, 50.178484842181206, 54.61566634476185, 42.02324464917183, 38.622005358338356, 54.32256907224655, 47.33600176870823, 48.51666681468487, 42.74693861603737, 38.82258139550686, 35.34978814423084, 35.051792934536934, 35.797457322478294, 36.95498540997505, 37.48016282916069, 35.28696231544018, 36.14915885031223, 35.31660072505474, 34.56488326191902, 35.98322935402393, 44.613265469670296, 48.032208010554314, 49.28443841636181, 46.36173024773598, 48.02426643669605, 46.70240856707096, 47.69254803657532, 44.8660659044981, 39.506217911839485, 34.297229424118996, 35.04242643713951, 38.95941965281963, 43.04781027138233, 44.64408181607723, 42.590079233050346, 41.69618479907513, 41.07889272272587, 40.24316556751728, 43.61480064690113, 43.44064079225063, 45.14559030532837, 44.48999248445034, 46.168168634176254, 35.946006551384926, 18.160443417727947, 3.2537093572318554, 1.2730688438750803, 1.7979255365207791, 1.9147591735236347, 4.312916295602918, 5.906826741993427, 3.5399954952299595, 5.033094976097345, 3.4030470438301563, 3.8094069762155414, 1.8609868339262903, 0.41437132749706507, 0.20462639717152342, 0.6781906366813928, 4.704264421015978, 20.317089892923832, 26.892692148685455, 28.707459568977356, 27.466776743531227, 15.927133206278086, 1.6553017334081233, 0.03939308364351746, 0.07169338772655465, 0.037744046348962, 0.026227374582958873, 0.018480052312952466, 0.04902871718513779, 0.015007810507086106, 0.05404635165177751, 0.016247837229457218, 0.025662859952717554, 0.0199827584947343, 0.07895339542301372, 0.023140765697462484, 0.007580782012155396, 0.01732803873892408, 0.03636341789388098, 0.05559387798712123, 0.08199638643418439, 0.015411619551741751, 0.10704195578000508, 0.03038470404135296, 0.04909974442853127, 0.062261922721518204, 0.07486734553822316, 0.03322895347082522, 0.03836461539322045, 0.02675058498425642, 0.02960582191008143, 0.062405713833868504, 0.09758079002494924, 0.03507055211230181, 0.0581651933316607, 0.02165927751775598, 0.018576551919977646, 0.030195912804629188, 0.040027794311754405, 0.0383515239082044, 0.059269668636261486, 0.015918436838546768, 0.1062443845148664, 0.05759422943810932, 0.028782269910152536, 0.039232156341313384, 0.01579993997438578, 0.05913910259550903, 0.04329698822402861, 0.05086129873234313, 0.022721348359482363, 0.03286221748567186, 0.024077879279502667, 0.060462882538558915, 0.05177193248528056, 0.06406796135706827, 0.0999869812221732, 0.18016203335719183, 13.671787027269602, 34.38345439732075, 35.748071372509, 21.902583315968513, 34.49984595179558, 26.720458790659904, 4.605513419955969, 0.1831274328287691, 0.11625928891589865, 0.3363772766897455, 3.610997535288334, 6.443293830379844, 7.18756559304893, 7.844116687774658, 8.131570313125849, 9.165107253938913, 5.912922089919448, 5.478571197018027, 1.2140217935666442, 1.3177400780841708, 2.7655930118635297, 14.617683570832014, 34.34090428054333, 49.6579659730196, 52.492473274469376, 54.975161254405975, 54.08537060022354, 53.09701323509216, 56.6140703111887, 55.18955335021019, 54.513079449534416, 57.367577478289604, 54.61347006261349, 54.39525917172432, 51.45177371799946, 44.503622353076935, 40.008801743388176, 40.825510919094086, 43.84015515446663, 52.29437090456486, 50.66151112318039, 55.395095720887184, 48.49662289023399, 51.9961629062891, 53.03057000041008, 53.061625733971596, 45.17311982810497, 41.26947909593582, 37.93155960738659, 38.639020845294, 38.035582825541496, 40.566847398877144, 41.91157624125481, 45.33036679029465, 46.37076236307621, 52.630550265312195, 52.02701725065708, 55.10480269789696, 44.1890562325716, 40.65479747951031, 54.70985949039459, 49.44159038364887, 51.40649914741516, 44.33038964867592, 40.08045069873333, 37.79068596661091, 35.35976640880108, 38.16836670041084, 38.28764609992504, 39.27953727543354, 36.49169147014618, 37.35920391976833, 36.79557256400585, 37.06512629985809, 39.00254733860493, 46.25350445508957, 50.31114712357521, 51.91912584006786, 46.328352838754654, 49.42894086241722, 47.70811200141907, 50.120017379522324, 46.82782083749771, 41.903178691864014, 35.28633534908295, 36.02949567139149, 40.74015609920025, 44.593259543180466, 45.531110018491745, 44.253800958395004, 43.48447524011135, 42.24998228251934, 41.98331259191036, 45.0613222271204, 44.68677632510662, 46.32892280817032, 45.678735896945, 47.45339646935463, 37.23361685872078, 22.306028567254543, 4.850831106305122, 2.4707418959587812, 5.013713641092181, 4.213438583537936, 5.046462658792734, 6.624404937028885, 6.435912251472473, 7.343638418242335, 4.4943503849208355, 1.5708072111010551, 0.5959677987266332, 0.16531015920918435, 0.09614369526389055, 0.5949277826584876, 5.759128192439675, 21.574564017355442, 30.215380154550076, 31.35812133550644, 30.874131806194782, 20.98277237266302, 2.312367344275117, 0.0653734288061969, 0.04205881130474154, 0.03906204496161081, 0.02811068934533978, 0.048925013179541565, 0.06033923702489119, 0.025366032423335128, 0.07231385287013836, 0.014937473461031914, 0.08587572592659853, 0.03745119116501883, 0.061976626311661676, 0.03241328122385312, 0.06166134713566862, 0.06318718049442396, 0.11654505287879147, 0.011005952637788141, 0.07242095962283202, 0.08242989715654403, 0.08273097162600607, 0.0288849478965858, 0.05433825688669458, 0.033142155589303, 0.07903697609435767, 0.10570321042905562, 0.0955542222072836, 0.17265209258766845, 0.21560700639383867, 0.12373383666272275, 0.23960304533829913, 0.10167947126319632, 0.13230146403657272, 0.12642098270589486, 0.21914662036579102, 0.1364212593762204, 0.14389752148417756, 0.16170165908988565, 0.17081113590393215, 0.14623963565099984, 0.15930190973449498, 0.15554573707049713, 0.19279133848613128, 0.259265253553167, 0.1965771525283344, 0.11351510140229948, 0.1569923758506775, 0.28166223142761737, 0.21998337702825665, 0.05871004846994765, 0.1538352796342224, 0.19824222021270543, 0.1972191547974944, 0.1797804655507207, 0.207698977610562, 0.38425215461757034, 16.020820029079914, 42.36402556300163, 44.075016751885414, 27.50983413308859, 36.62178508937359, 33.47397319972515, 5.906318044289947, 0.8294080349151045, 0.49786089279223233, 3.334958259947598, 8.048611264675856, 17.04184614121914, 16.103435195982456, 13.854838404804468, 15.233964901417494, 14.997825622558594, 7.774876328185201, 7.378137242048979, 2.5415005115792155, 1.3102877279743552, 1.820362382568419, 14.169740807265043, 34.677539616823196, 48.343247920274734, 54.15104627609253, 55.11610709130764, 53.91439117491245, 55.19441328942776, 57.5814376026392, 56.5926356613636, 56.417833641171455, 59.15098898112774, 54.808741584420204, 56.540939435362816, 53.632723689079285, 45.0277092307806, 41.97295054793358, 43.44979450106621, 45.74071817100048, 52.978839576244354, 51.899549290537834, 57.591313272714615, 48.202298283576965, 51.19320519268513, 55.31671352684498, 53.56266684830189, 47.72518448531628, 43.271128088235855, 40.603249445557594, 38.680290430784225, 39.16823744773865, 43.27693037688732, 45.32190844416618, 47.644370421767235, 48.47034350037575, 55.00534303486347, 56.203205958008766, 55.99761798977852, 45.513368770480156, 43.85222710669041, 55.74316084384918, 50.98809599876404, 54.26051080226898, 46.44748404622078, 42.03945457935333, 39.50808361172676, 37.44662202894688, 40.14785908162594, 40.282409861683846, 41.56623937189579, 39.26790229976177, 39.209704622626305, 38.78745228052139, 38.86102773249149, 40.74537701904774, 47.393074706196785, 53.19159775972366, 53.327345475554466, 47.383453622460365, 50.14172941446304, 48.85345794260502, 52.79958799481392, 50.390650257468224, 44.73145052790642, 37.81055510044098, 38.24892617762089, 43.345174714922905, 46.556488797068596, 47.48454339802265, 47.63941928744316, 45.72691731154919, 45.23845352232456, 43.600870594382286, 46.8016592413187, 47.1380589902401, 49.4269497692585, 48.78657393157482, 49.5601212233305, 38.42632345855236, 20.313328094780445, 4.980274485424161, 2.912760777398944, 6.431359620764852, 6.683258078992367, 9.79592565447092, 12.166230864822865, 9.982515592128038, 15.408973060548306, 10.686842948198318, 8.73277310281992, 3.487615780904889, 0.8327649172861129, 0.4418009571963921, 1.149353301152587, 6.821161229163408, 26.685320176184177, 36.35904438793659, 37.28112570941448, 37.93630175292492, 22.724636904895306, 2.6478287810459733, 0.22703533846652135, 0.11873077426571399, 0.1972075624507852, 0.0824285983981099, 0.13178724475437775, 0.12177939075627364, 0.12712905096122995, 0.15244808688294142, 0.12747265049256384, 0.16657461557770148, 0.0956011185189709, 0.14115123369265348, 0.08311180470627733, 0.10774124442832544, 0.15683799429098144, 0.21306328038917854, 0.14970662305131555, 0.16998660983517766, 0.12946427799761295, 0.27306715201120824, 0.08415956879616715, 0.19495438726153225, 0.2527142863254994, 0.1390033692587167], [0.008887774110917235, 0.015082185764185851, 0.002434345033179852, 0.033265352103626356, 0.08110600218060426, 0.027964933397015557, 0.10844724951311946, 0.01705930149910273, 0.11976262670941651, 0.021733241810579784, 0.05827852299262304, 0.07994821469765157, 0.05488540526130237, 0.09470292687183246, 0.03987517535279039, 0.054048960300860927, 0.020682557369582355, 0.03215520308003761, 0.09751153280376457, 0.049892669849214144, 0.0562434575840598, 0.04734239439130761, 0.035898566275136545, 0.01524233473901404, 0.0358742980461102, 0.02164334546250757, 0.07343760546064004, 0.09763937516254373, 0.12431634095264599, 0.05560841294936836, 0.13030713511398062, 2.2162303654477, 19.461330212652683, 35.8055204898119, 26.269088611006737, 31.032543405890465, 45.54589502513409, 17.440820932388306, 2.0419002324342728, 0.2168595141847618, 0.05169515359739307, 3.310496835038066, 5.695466408506036, 7.348093204200268, 4.774570623412728, 6.388737307861447, 7.282030424103141, 5.600045453757048, 4.139906354248524, 2.0575090823695064, 1.7793939309194684, 1.275908479001373, 5.321537023410201, 17.92567301541567, 40.43592542409897, 49.33287441730499, 52.73390471935272, 51.96953013539314, 55.60658477246761, 53.56119252741337, 54.34697896242142, 53.180426359176636, 54.45986710488796, 51.112888902425766, 52.475279197096825, 44.949266240000725, 42.54666656255722, 43.455520793795586, 41.20970830321312, 44.334615021944046, 51.72890804708004, 50.17509542405605, 53.51267293095589, 47.56816931068897, 50.8987095952034, 52.163870707154274, 50.67670650780201, 47.37114228308201, 41.4109493046999, 37.01562635600567, 37.36901879310608, 37.16681644320488, 37.92586751282215, 37.22808055579662, 45.131318271160126, 46.74113988876343, 52.437505424022675, 47.60187730193138, 55.45975685119629, 41.01804278790951, 40.6272641569376, 54.50409293174744, 46.569111719727516, 46.90963424742222, 42.18411661684513, 38.759318590164185, 36.744613498449326, 38.27805161476135, 35.98972700536251, 37.5444021821022, 35.402552112936974, 36.16539157927036, 36.415703147649765, 36.5260112285614, 35.329337641596794, 35.4091789573431, 41.30085401237011, 47.509432062506676, 47.46258817613125, 49.35761868953705, 48.41116927564144, 48.25100786983967, 48.20821836590767, 45.20029976963997, 44.42277409136295, 38.423428013920784, 33.947841972112656, 40.513631254434586, 47.043660655617714, 46.04022189974785, 44.85202185809612, 45.117221027612686, 43.36688295006752, 42.78179794549942, 45.57121306657791, 45.72177618741989, 44.30512100458145, 45.17960987985134, 41.80732883512974, 21.957604363560677, 8.130602315068245, 0.9383620822336525, 1.491967379115522, 3.9210594724863768, 3.3545215101912618, 3.1559192296117544, 7.359463619068265, 4.65877516195178, 4.991589328274131, 2.3149922909215093, 1.7315617413260043, 0.5295153020415455, 0.13508328585885465, 0.4040737316245213, 2.9639385687187314, 14.285888224840164, 32.985319420695305, 29.79838103055954, 29.985665380954742, 24.4026667624712, 4.850424053147435, 0.047798863452044316, 0.03935167922463734, 0.025265352669521235, 0.08910773452953435, 0.030683698641951196, 0.028735620362567715, 0.07458757070708089, 0.021484438657353166, 0.09448970784433186, 0.023228014433698263, 0.023615940590389073, 0.0036650823858508375, 0.002875092159229098, 0.007123972491172026, 0.02372015853325138, 0.0334050391393248, 0.06848573641036637, 0.07023503043456003, 0.06492503802292049, 0.10573858860880136, 0.06306059236521833, 0.003220877083549567, 0.016314381900883745, 0.014792470792599488, 0.020006282720714808, 0.07693898398429155, 0.029223732744867448, 0.029239809518912807, 0.023855118088249583, 0.018618997200974263, 0.05337631475413218, 0.05863944053999148, 0.05906884718569927, 0.04414261355123017, 0.037699443273595534, 0.01567786224768497, 0.017862928689282853, 0.041144544738926925, 0.06669010268524289, 0.04861317385802977, 0.028421608403732534, 0.0906841378309764, 0.06542592833284289, 0.01292299801207264, 0.007782425855111796, 0.019159174953529146, 0.04113650356885046, 0.0157496520478162, 0.06629878305830061, 0.05980735833873041, 0.009525777131784707, 0.05501750754774548, 0.06915386227774434, 0.135375484242104, 0.09692980034742504, 0.10345945309381932, 4.072524094954133, 26.93530686199665, 39.77116249501705, 29.330464638769627, 32.84947670996189, 50.265393778681755, 15.838424116373062, 2.1040333108976483, 0.03366239739989396, 0.15343977429438382, 0.7836030959151685, 3.4777721716091037, 5.253690714016557, 7.205078853294253, 8.107434958219528, 7.756970264017582, 7.9251297656446695, 5.546466428786516, 3.3519568853080273, 2.069622832350433, 2.8059097984805703, 7.53101491369307, 20.666412748396397, 41.31270557641983, 49.92067247629166, 55.05269229412079, 52.638423442840576, 55.417742505669594, 54.45889055728912, 56.14082470536232, 55.17954468727112, 56.53446078300476, 54.32766079902649, 53.775029852986336, 48.27385984361172, 44.20976512134075, 44.442962408065796, 42.42424853146076, 47.13064178824425, 52.67379194498062, 52.19861604273319, 54.4600684940815, 47.068401128053665, 51.01718343794346, 54.341925233602524, 52.691939771175385, 49.23264339566231, 41.63720816373825, 39.896122589707375, 38.70623543858528, 38.39134253561497, 40.451804772019386, 39.250617027282715, 46.53536193072796, 49.644514694809914, 52.33610026538372, 51.667127162218094, 55.099448785185814, 42.37493097782135, 44.55997712910175, 54.856163039803505, 49.708856642246246, 48.458104357123375, 43.408004343509674, 40.45116260647774, 38.72347131371498, 38.48515950143337, 37.56424471735954, 38.12911860644817, 37.359667494893074, 38.0559117347002, 38.01185689866543, 37.020186111330986, 37.1916177123785, 37.184956669807434, 43.320932015776634, 50.75453773140907, 49.81050118803978, 51.39613710343838, 48.11383903026581, 49.27796356379986, 51.040692776441574, 47.53637261688709, 44.80677768588066, 39.08320561051369, 35.32942123711109, 42.400549203157425, 48.178389966487885, 47.73779220879078, 47.2007442265749, 45.86496390402317, 44.89889994263649, 45.40629431605339, 47.245152443647385, 47.65820927917957, 45.83507090806961, 46.742002442479134, 44.67776320874691, 27.244439274072647, 10.214743930846453, 1.9602955738082528, 3.3726268261671066, 4.758956311270595, 5.158231286332011, 4.853006489574909, 7.6158163882792, 7.115676775574684, 6.984900617972016, 2.9349031392484903, 0.3503590717446059, 0.3442064003320411, 0.06830952828750014, 0.6060376740060747, 3.4361860156059265, 13.97493191063404, 34.63244743645191, 33.20319592952728, 35.141593515872955, 29.9746098741889, 8.237358536571264, 0.166448658274021, 0.0990496264421381, 0.02453773995512165, 0.03308993065729737, 0.04525201671640389, 0.06756989649147727, 0.03482788095425349, 0.03354532360390294, 0.056277206749655306, 0.029780349068460055, 0.056984020775416866, 0.021156932598387357, 0.022246808002819307, 0.017762632996891625, 0.050135040437453426, 0.06441654069931246, 0.06832711718743667, 0.031576739784213714, 0.03384782299690414, 0.05935506385867484, 0.034985372112714685, 0.07581802929053083, 0.043955173023277894, 0.03606878155551385, 0.020132067475060467, 0.1435575881623663, 0.15126942278584465, 0.1477266472647898, 0.10522365686483681, 0.21190263563767076, 0.13707523990888149, 0.18279800831805915, 0.12168016561190598, 0.1733850673190318, 0.09974582775612362, 0.1664643472759053, 0.1444944753893651, 0.14198899967595935, 0.22756600374123082, 0.12381242268020287, 0.2199646897497587, 0.17805411131121218, 0.19754381472012028, 0.1652775492402725, 0.13707636797335, 0.121617083059391, 0.1023420161800459, 0.1876700296998024, 0.2020328730577603, 0.20138570544077083, 0.12187702770461328, 0.18010668398346752, 0.3015176800545305, 0.2963016286958009, 0.16170697286725044, 0.25205905898474157, 5.480428822338581, 32.41487503051758, 50.4624056071043, 35.83600625395775, 39.39822010695934, 55.78791484236717, 20.06915509700775, 3.0733175994828343, 0.49810885917395353, 0.29853415733668953, 6.499123759567738, 14.051664043217897, 15.14937099069357, 12.86465808749199, 16.566879227757454, 15.860746018588543, 13.299714792519808, 10.102880783379078, 5.654978631064296, 4.243477396667004, 2.644425113685429, 6.600278606638312, 19.30893748998642, 41.811615005135536, 49.10338573157787, 53.965536430478096, 52.0145121216774, 56.802532598376274, 56.58518426120281, 58.39727662503719, 56.75468176603317, 57.910815328359604, 55.78185796737671, 57.10807040333748, 49.58050712943077, 45.78979253768921, 46.64119005203247, 45.21752044558525, 48.63841228187084, 54.70828637480736, 54.983779191970825, 55.68611830472946, 47.33792066574097, 51.667495742440224, 55.565759763121605, 55.31444884836674, 51.96281209588051, 43.74143645167351, 41.030859500169754, 40.39191618561745, 40.62162905931473, 41.31467767059803, 42.37091079354286, 50.02553164958954, 51.59005589783192, 54.81336213648319, 53.73405285179615, 55.903360247612, 45.14597788453102, 47.272104397416115, 56.63287170231342, 50.78943885862827, 50.36420747637749, 45.297677144408226, 42.3467592895031, 39.5665168762207, 41.695823818445206, 38.985524252057076, 39.74057033658028, 38.496102914214134, 39.93323899805546, 40.01470282673836, 39.280468225479126, 38.76307658851147, 39.88569214940071, 44.9181193113327, 51.821353286504745, 51.088722199201584, 52.47647613286972, 49.038371220231056, 50.2357591688633, 53.80570560693741, 49.258219823241234, 47.516412287950516, 42.09181196987629, 36.9107785820961, 44.59226779639721, 50.8361953496933, 49.94225151836872, 48.37867721915245, 47.826164066791534, 47.53802552819252, 47.63540290296078, 49.514542669057846, 48.91462706029415, 48.63997019827366, 49.446883499622345, 44.7325486689806, 26.5382756665349, 10.436125751584768, 1.3511754339560866, 3.7305236840620637, 8.892346490174532, 7.5705156940966845, 7.132967747747898, 16.01738691329956, 12.431191597133875, 10.180065091699362, 6.378325866535306, 3.7740057008340955, 1.5476814145222306, 0.6079185730777681, 0.7875528652220964, 4.493869710713625, 19.1194948554039, 41.16178907454014, 40.59391714632511, 40.70842020213604, 34.70579870045185, 8.075970746576786, 0.18133759527700022, 0.23595782375195995, 0.11550009410711937, 0.1960297444020398, 0.13507003110134974, 0.17200954112922773, 0.16970650845905766, 0.11750775200198404, 0.25908838491886854, 0.06676248434814624, 0.17965381062822416, 0.11357497787685134, 0.07876513482187875, 0.07264574873261154, 0.20168893213849515, 0.2746214170474559, 0.15715116576757282, 0.1429250111686997, 0.15813319041626528, 0.21062513231299818, 0.13582357816630974, 0.11438362198532559, 0.1209838010254316, 0.07273247611010447, 0.09161456837318838], [0.026921564676740672, 0.06085196087951772, 0.02990302051330218, 0.02245658717583865, 0.06038212202838622, 0.029652508565050084, 0.020624113240046427, 0.07110728402039967, 0.10249071288853884, 0.03674359788419679, 0.028456335348892026, 0.069020305381855, 0.023863051646912936, 0.03446164591878187, 0.02280132961459458, 0.023839241694076918, 0.0837685534497723, 0.020043074691784568, 0.0409613641386386, 0.04065936569531914, 0.03405797324376181, 0.043679813970811665, 0.02460078540025279, 0.03474162112979684, 0.042188828156213276, 0.02424896287266165, 0.026780842345033307, 0.011732235980161931, 0.07938608236145228, 0.031917571104713716, 0.16834834852488711, 0.4180909419665113, 7.326194029301405, 32.844935953617096, 32.348868772387505, 36.90581984817982, 32.441207617521286, 31.022304855287075, 10.299861263483763, 1.0159582528285682, 0.12530354579212144, 0.5716076027601957, 1.5233899117447436, 3.8110736617818475, 7.198553178459406, 4.983609756454825, 4.355893414467573, 5.2864292822778225, 3.698304262943566, 1.672026060987264, 1.379955445881933, 2.512470306828618, 3.527815011329949, 10.258293393999338, 24.18400939553976, 43.58698233962059, 52.42316499352455, 55.05379803478718, 56.12144574522972, 54.226666018366814, 55.13371154665947, 52.125625759363174, 51.437167301774025, 48.86643424630165, 47.25556008517742, 43.83111543953419, 43.123866990208626, 41.48818776011467, 40.698992908000946, 44.45652388036251, 54.16365019977093, 52.648576498031616, 53.76838780939579, 47.983194440603256, 52.776158452034, 51.420368403196335, 52.173742577433586, 49.45177763700485, 45.99161110818386, 37.907932475209236, 39.002896919846535, 36.84173248708248, 38.1781929731369, 38.55660326778889, 43.553893715143204, 45.25187060236931, 54.17343467473984, 48.04350860416889, 55.00591680407524, 45.18072322010994, 37.059210017323494, 54.20453980565071, 48.696845546364784, 49.39231462776661, 43.30873467028141, 40.46498246490955, 36.77892945706844, 35.866951793432236, 37.463489323854446, 36.0873019695282, 36.38556696474552, 36.00587613880634, 36.539185121655464, 36.843218207359314, 36.98743186891079, 35.263061597943306, 37.28038474917412, 44.00856971740723, 49.102899357676506, 47.81475327908993, 48.49690027534962, 48.34339991211891, 48.077387586236, 47.2546823322773, 47.35498555004597, 40.9933403134346, 35.86704298853874, 40.45355647802353, 47.344908490777016, 47.879972979426384, 48.68386164307594, 44.739920273423195, 45.41146203875542, 44.39105339348316, 47.67314247786999, 46.51024527847767, 47.93883562088013, 44.909581169486046, 27.253974862396717, 7.790865395218134, 2.1615021396428347, 1.0454702004790306, 2.8793052351102233, 2.0848400657996535, 4.775327732786536, 3.783158459700644, 3.7891153525561094, 4.852484492585063, 5.180168934166431, 2.449463987722993, 0.23583254922414199, 0.09127577795879915, 0.37337802874390036, 2.0803273329511285, 11.305550448596478, 25.539717748761177, 30.190278701484203, 25.063764788210392, 28.977797962725163, 14.048822745680809, 0.7538682071026415, 0.07150943158194423, 0.08280698239104822, 0.0663860744680278, 0.039321507210843265, 0.0401810812036274, 0.08837999936076812, 0.054828530774102546, 0.016630160171189345, 0.079902216384653, 0.025121834296442103, 0.03837599251710344, 0.06175296897708904, 0.08880532419425435, 0.05104004128952511, 0.056552142777945846, 0.038646917237201706, 0.05323814541043248, 0.018123487461707555, 0.0537059210910229, 0.08308337302878499, 0.014777246560697677, 0.057119904304272495, 0.013912349513702793, 0.04226947363349609, 0.06399323450750671, 0.016129047216963954, 0.033903758667293005, 0.058685368348960765, 0.06120085934526287, 0.06259530287934467, 0.06260924783418886, 0.04960846439644229, 0.07713957165833563, 0.07863712176913396, 0.0638314759999048, 0.04943503190588672, 0.048415295023005456, 0.045358039933489636, 0.020624810858862475, 0.019683797290781513, 0.035109641030430794, 0.0715821620542556, 0.03239073477743659, 0.047522595268674195, 0.08761121600400656, 0.01711045959382318, 0.04147418076172471, 0.04651732655474916, 0.020702144502138253, 0.07962375515489839, 0.027960159532085527, 0.02609828170534456, 0.01755128974764375, 0.07215188656118698, 0.08217158523621038, 0.1019279497268144, 0.5363364110235125, 12.97872606664896, 40.25926150381565, 32.93751798570156, 37.07471698522568, 44.42884236574173, 32.928174287080765, 9.343330040574074, 0.7019642984960228, 0.08266110584372655, 0.2347198175266385, 1.618178675416857, 4.560526208952069, 7.768163038417697, 7.4711220525205135, 7.18018401414156, 7.678165817633271, 3.8713465025648475, 5.107578104361892, 2.900515221990645, 2.6357675157487392, 5.601834682747722, 13.199351727962494, 28.06730791926384, 45.263076201081276, 54.668084532022476, 57.01990373432636, 58.24444122612476, 56.79006166756153, 56.410021260380745, 55.181642174720764, 54.92409959435463, 50.28771758079529, 48.87206174433231, 44.72503647208214, 45.94157539308071, 44.35175210237503, 41.49832181632519, 46.159748286008835, 53.847404569387436, 53.41099038720131, 54.127761125564575, 49.447442069649696, 52.86062031984329, 53.58478166162968, 53.373839780688286, 50.23141220211983, 45.88577538728714, 39.303681179881096, 39.84874673187733, 38.79839189350605, 40.653003975749016, 41.0506222397089, 45.38496986031532, 47.30481684207916, 55.02060301601887, 49.71946567296982, 55.07631182670593, 48.41819129884243, 41.39969050884247, 57.16368801891804, 49.58709217607975, 51.60764895379543, 45.33944450318813, 42.53650210797787, 39.02745880186558, 37.02676735818386, 40.270387306809425, 38.611662313342094, 37.275365218520164, 37.2106508910656, 37.926840260624886, 38.85300636291504, 37.95185051858425, 37.481025382876396, 40.124136954545975, 48.15926939249039, 49.80945624411106, 50.79672686755657, 48.63677836954594, 47.95273907482624, 48.55426959693432, 48.44256319105625, 47.99750827252865, 43.913297429680824, 37.26130597293377, 42.678720876574516, 49.41840402781963, 49.0000806748867, 48.74081678688526, 47.20267832279205, 46.535654515028, 46.89974717795849, 49.32107985019684, 48.96438159048557, 47.27211579680443, 46.77272379398346, 30.35782501101494, 10.752733312547207, 3.2304581673815846, 2.2498369496315718, 4.55552140250802, 5.447511663660407, 4.975397447124124, 6.550684617832303, 5.796900540590286, 6.900599291548133, 4.3309468030929565, 2.396155223250389, 0.4796289367368445, 0.04459068150026724, 0.3435991157311946, 2.105445647612214, 10.507286433130503, 28.150823637843132, 35.65981350839138, 30.004918947815895, 32.44059965014458, 18.622411228716373, 1.5022387029603124, 0.024843940809660126, 0.0032918414763116743, 0.019406278588576242, 0.013806248371110996, 0.04536364314844832, 0.0699348168564029, 0.029096632533764932, 0.01581763463036623, 0.05975722255243454, 0.02912457439379068, 0.03908952669007704, 0.10674443619791418, 0.11115490109659731, 0.0361277303454699, 0.11731175822205842, 0.08493343586451374, 0.06380424660164863, 0.014650040593551239, 0.0330399952508742, 0.021045755165687297, 0.030524021858582273, 0.04856224397371989, 0.03183079919836018, 0.029050059056316968, 0.06822542069130577, 0.07986781783984043, 0.17295246943831444, 0.17181132832774892, 0.19063799700234085, 0.13831731310347095, 0.1249716870370321, 0.12354772828985006, 0.19963659695349634, 0.24683108873432502, 0.13188982440624386, 0.1595356417237781, 0.24422888149274513, 0.10676662641344592, 0.14655565697466955, 0.08480467324261554, 0.13131160230841488, 0.17425575497327372, 0.1935621033771895, 0.15089138760231435, 0.1480612816521898, 0.12666798429563642, 0.09122002782532945, 0.12301715207286179, 0.14285187993664294, 0.20647542842198163, 0.13534375000745058, 0.12222362551256083, 0.09138222420006059, 0.1553673396119848, 0.24514400894986466, 0.24813394382363185, 0.6510992778930813, 14.936537761241198, 48.99137534201145, 44.676463678479195, 44.712797328829765, 42.679895013570786, 37.667097598314285, 12.00892310589552, 1.4890522230416536, 0.477749373530969, 2.984642470255494, 4.6310950722545385, 11.090713776648045, 16.479470618069172, 13.002015966922045, 12.136715948581696, 15.250004790723324, 11.283773817121983, 6.484190560877323, 4.517186209559441, 5.254061669111252, 5.581380380317569, 12.521942127496004, 27.90320612490177, 45.37827841937542, 56.271746680140495, 59.37337964773178, 59.52259764075279, 58.779019340872765, 57.96030007302761, 56.477224454283714, 56.79765745997429, 52.719799876213074, 50.94971425831318, 47.55711570382118, 47.525698989629745, 44.26787540316582, 43.10726948082447, 47.99068383872509, 56.273110806941986, 55.88862843811512, 55.99157631397247, 49.19793225824833, 52.62258589267731, 54.94614981114864, 55.360221192240715, 53.003990426659584, 49.94760923087597, 41.71543076634407, 42.79366470873356, 39.88646350800991, 41.89663164317608, 42.64866828918457, 47.2314465790987, 49.43325363099575, 56.07924520969391, 52.98074707388878, 55.616688430309296, 50.21100349724293, 44.57962587475777, 56.378885731101036, 52.44595617055893, 53.536269664764404, 48.40200416743755, 43.677094504237175, 41.95814274251461, 38.786597326397896, 41.82560585439205, 40.163909420371056, 40.373357981443405, 39.089566469192505, 41.133317202329636, 41.58227451145649, 39.952059388160706, 39.13014069199562, 41.0625422000885, 48.96698825061321, 53.15400257706642, 53.704087659716606, 50.058293491601944, 48.88017810881138, 49.73148822784424, 51.68272152543068, 51.78223818540573, 45.45086972415447, 40.34311160445213, 43.722619861364365, 51.290438175201416, 50.3061655908823, 50.63111275434494, 48.56793746352196, 49.276280254125595, 48.68583753705025, 52.266294211149216, 52.337768375873566, 50.29403664171696, 48.54635842144489, 30.43959092348814, 10.51514346152544, 3.356644408777356, 2.782420408912003, 6.109243305400014, 7.16248931363225, 10.204497780650854, 10.649355109781027, 10.354768317192793, 12.173801008611917, 11.792059242725372, 7.135110832750797, 1.720508134458214, 0.2894358424236998, 0.6195862032473087, 3.0103822890669107, 14.334765952080488, 33.294634222984314, 39.1531066596508, 36.174457892775536, 38.66034150123596, 19.76036086678505, 1.7286622594110668, 0.11644503363640979, 0.1654413709184155, 0.15115832327865064, 0.10467267900821753, 0.11559214268345386, 0.2159491810016334, 0.1788636459968984, 0.0998280725616496, 0.18678304448258132, 0.13481119967764243, 0.14705377165228128, 0.17387915955623612, 0.31405157467816025, 0.21422910533146933, 0.24698100256500766, 0.229752816085238, 0.16577477334067225, 0.10917971216258593, 0.15746331308037043, 0.14372224104590714, 0.10833191976416856, 0.17247920186491683, 0.0856749081867747, 0.24279278120957315, 0.15342577738920227], [0.08834536332869902, 0.030577432371501345, 0.011667272083286662, 0.05756515951361507, 0.02913640608312562, 0.019293292170914356, 0.010814417310029967, 0.06274455619859509, 0.031225603743223473, 0.03707897070853505, 0.032320334648829885, 0.013097667106194422, 0.00412754614444566, 0.05880168144358322, 0.02977945849124808, 0.02889743267587619, 0.048616417043376714, 0.0010623423054312298, 0.03796435659751296, 0.049275908022536896, 0.00356878362254065, 0.012753936771332519, 0.0786963377322536, 0.060590457724174485, 0.04200318733637687, 0.03663198629510589, 0.10130887982086278, 0.06319785257801414, 0.022985744035395328, 0.12117137885070406, 0.10458747303346172, 0.25358625047374517, 1.5476449602283537, 17.28433582931757, 41.12717293202877, 34.24912020564079, 29.788797944784164, 36.99963681399822, 28.117607720196247, 7.228741133585572, 0.6765349942725152, 0.020905275887344033, 0.9639852354303002, 2.6316076889634132, 3.8812988810241222, 5.958388550207019, 4.399782959371805, 6.406156998127699, 3.672617166303098, 3.533819164149463, 1.3272553612478077, 1.8200112576596439, 3.1287863105535507, 6.907401401549578, 17.609423585236073, 32.72632531821728, 46.46806374192238, 54.51165072619915, 54.74268212914467, 52.59941853582859, 52.22165420651436, 49.76924680173397, 47.94974483549595, 45.1076303422451, 44.20288369059563, 44.29262347519398, 42.93245606124401, 40.707789435982704, 40.34235164523125, 44.552886709570885, 53.61014910042286, 54.05781447887421, 53.668266981840134, 47.66532249748707, 49.35327552258968, 54.21733371913433, 50.471156537532806, 52.359507009387016, 50.24352215230465, 42.68208369612694, 36.292221173644066, 37.904132679104805, 38.17228429019451, 38.83756399154663, 41.04756720364094, 45.42312741279602, 50.87928883731365, 51.139050498604774, 53.08119848370552, 48.15866142511368, 39.85297590494156, 56.262167394161224, 50.59392414987087, 49.21611428260803, 43.21494050323963, 41.036217212677, 40.28144471347332, 38.84990192949772, 34.65826325118542, 38.454289957880974, 37.274996638298035, 38.7438952177763, 38.252319395542145, 39.09234032034874, 38.262711837887764, 36.409828662872314, 36.32374048233032, 40.360339879989624, 46.256510093808174, 47.2453386336565, 48.29453833401203, 49.54684093594551, 47.44669742882252, 48.03158484399319, 46.1994219571352, 47.38780438899994, 37.62371152639389, 38.41518245637417, 46.3200730830431, 47.00464054942131, 47.08673134446144, 45.93037359416485, 47.493936493992805, 44.79736939072609, 46.88625790178776, 46.81382618844509, 45.2186793833971, 30.060933642089367, 12.465617749840021, 2.813887232914567, 0.7191014976706356, 1.413103323429823, 4.595272494480014, 4.221838982775807, 2.9659427236765623, 4.599144486710429, 5.346206249669194, 6.502028703689575, 4.158161524683237, 1.264234792906791, 0.2911517472239211, 0.14510689565213397, 1.9456460536457598, 10.160941667854786, 20.903269238770008, 26.481597907841206, 28.285682201385498, 28.424503952264786, 25.254326462745667, 3.3281188644468784, 0.1967997819883749, 0.05918601746088825, 0.03792414332565386, 0.037983433503541164, 0.030761640846321825, 0.026133622777706478, 0.028058152711309958, 0.1439207507064566, 0.11467880380223505, 0.03936619934393093, 0.03396782085474115, 0.04108293906028848, 0.026523669621383306, 0.06076056539313868, 0.0628196912293788, 0.008289364668598864, 0.034850943193305284, 0.030804264242760837, 0.043545444423216395, 0.031435542477993295, 0.032167938334168866, 0.02976222211145796, 0.043484105917741545, 0.12761569203576073, 0.10284752264851704, 0.037772522555314936, 0.0300684303874732, 0.041637542308308184, 0.04243921022862196, 0.044837523528258316, 0.07284512670594268, 0.04381702223327011, 0.035056143315159716, 0.05903468612814322, 0.046282870971481316, 0.012430001370375976, 0.05830865789903328, 0.05711322868592106, 0.06743323741829954, 0.035123322522849776, 0.05171060511202086, 0.02162227960070595, 0.01105329980418901, 0.01709062013105722, 0.03740529304195661, 0.052863691089442, 0.01519990801170934, 0.08287259566714056, 0.015399760031868936, 0.05231622730207164, 0.10673592376406305, 0.02237399727164302, 0.07758250023471192, 0.08120804748614319, 0.042383478648844175, 0.09939697381923907, 0.06996027994318865, 0.16563473007408902, 3.738745730370283, 25.361370518803596, 46.003242284059525, 35.815225169062614, 31.235344223678112, 44.465704187750816, 29.685787372291088, 6.350436313077807, 0.49954150104895234, 0.11113109299913049, 0.6521180388517678, 2.2402524389326572, 4.246548106893897, 7.1776566747576, 6.414601569995284, 6.385814314708114, 6.278243036940694, 4.226128477603197, 2.724323901347816, 2.553882384672761, 3.8902576128020883, 8.243827689439058, 20.605013743042946, 34.438650235533714, 49.03183177113533, 55.48608563840389, 57.100770995020866, 54.39447641372681, 53.8476287573576, 51.878927797079086, 50.20032227039337, 47.739581912755966, 47.080826461315155, 45.63889503479004, 44.491539001464844, 42.89854288101196, 42.3024270683527, 46.184891536831856, 54.104445576667786, 54.977391734719276, 54.610715210437775, 48.70831713080406, 49.414110258221626, 55.0614508241415, 52.76011571288109, 54.36589054763317, 51.36842139065266, 43.343707993626595, 39.86830048263073, 39.31215852499008, 38.361772522330284, 40.7182502746582, 44.61461439728737, 47.23239652812481, 53.130037263035774, 53.19942153990269, 54.31303918361664, 49.51784089207649, 43.18029396235943, 57.1899788081646, 50.93535102903843, 49.138374254107475, 45.11573910713196, 42.1497018635273, 40.43114148080349, 40.27304336428642, 37.91680119931698, 40.21158166229725, 39.71675701439381, 39.7138387709856, 39.565772116184235, 40.81774793565273, 39.06092740595341, 38.64970587193966, 36.88534654676914, 41.419609040021896, 50.341002121567726, 48.926797807216644, 50.388267785310745, 50.43686717748642, 48.06327134370804, 49.037117287516594, 48.534115478396416, 47.49303214251995, 40.40347136557102, 41.434485241770744, 49.539222344756126, 49.13083925843239, 48.71449559926987, 48.01100134849548, 48.72865743935108, 46.48898921906948, 49.994263127446175, 48.49436201155186, 47.358739748597145, 34.51959729194641, 16.430422849953175, 4.371780836954713, 1.6072818101383746, 3.949069194495678, 6.141714937984943, 5.008429549634457, 5.720067238435149, 5.0272703636437654, 6.568416366353631, 6.506912391632795, 2.088129739277065, 0.313053653226234, 0.09003613900858909, 0.15352013404481113, 1.7293238989077508, 10.065500289201736, 23.899077884852886, 31.399681605398655, 31.70428466051817, 32.66028106212616, 31.267184615135193, 6.092012654989958, 0.27064593974500895, 0.0735286447161343, 0.09415126623935066, 0.08494912486639805, 0.032077908399514854, 0.02492418367182836, 0.03571071756596211, 0.040143561927834526, 0.014293345866462914, 0.09684755554189906, 0.031371669538202696, 0.006045900017852546, 0.013440120947052492, 0.017367187028867193, 0.05605115969956387, 0.037725986185250804, 0.00971595618466381, 0.051212668549851514, 0.03947614481148776, 0.032416535541415215, 0.06009805016219616, 0.039240891419467516, 0.01003023624434718, 0.08530925944796763, 0.02686761239601765, 0.05409893281466793, 0.19969110027886927, 0.11912783069419675, 0.14942151959985495, 0.11019534125807695, 0.17075353040127084, 0.13319656834937632, 0.10945514542981982, 0.15500894165597856, 0.11780396540416405, 0.11172461818205193, 0.20020113384816796, 0.19645796361146495, 0.19747483951505274, 0.11219200794585049, 0.16026434168452397, 0.12628898432012647, 0.1248017797479406, 0.16646964621031657, 0.10886380958254449, 0.2094009894062765, 0.08257555105956271, 0.24736025487072766, 0.12617643020348623, 0.20279271353501827, 0.20623584830900654, 0.17821419256506488, 0.21551857207668945, 0.15691231295932084, 0.11718412366462871, 0.1780629131826572, 0.19858329644193873, 0.30077660107053816, 5.353174125775695, 30.578486770391464, 54.38300862908363, 44.150359109044075, 37.17426024377346, 47.716581746935844, 33.374513536691666, 8.087654169648886, 1.3271163124591112, 0.35908188961911947, 3.0399591894820333, 8.758770357817411, 11.205234881490469, 15.172196365892887, 15.738993901759386, 14.022571854293346, 8.318881262093782, 7.451916933059692, 4.9245186522603035, 4.579270603135228, 5.085492264479399, 9.360821451991796, 21.405131109058857, 35.27200251817703, 49.098506793379784, 58.242161348462105, 58.776678666472435, 56.19725167751312, 55.013079419732094, 54.22810234129429, 51.66521966457367, 49.42265219986439, 47.686859741806984, 47.74729169905186, 46.53066158294678, 45.064396262168884, 44.49432045221329, 49.06135618686676, 57.45314508676529, 58.85395511984825, 55.162297412753105, 47.50726617872715, 50.52479065954685, 55.916477143764496, 55.786398723721504, 56.22661650180817, 53.64826865494251, 47.970134541392326, 41.187555491924286, 41.350946724414825, 39.6573244035244, 42.99904368817806, 45.28931379318237, 50.1847393065691, 55.11736482381821, 54.76186349987984, 56.110756918787956, 50.50277844071388, 46.016096994280815, 59.129649326205254, 54.22617204487324, 52.37723305821419, 46.44499517977238, 43.74975040555, 42.525456100702286, 42.20494709908962, 39.405861496925354, 42.8510682284832, 41.85949623584747, 42.5799185782671, 42.08940289914608, 42.73578621447086, 42.14343219995499, 40.87437629699707, 39.282903894782066, 43.62827092409134, 49.89356853067875, 50.776363760232925, 52.56008684635162, 52.420611530542374, 48.773628026247025, 50.009887889027596, 50.491367653012276, 51.7446544021368, 41.01825937628746, 43.55078548192978, 50.82612968981266, 50.32392203807831, 49.897862300276756, 49.23840008676052, 50.60133375227451, 48.62643912434578, 52.15381644666195, 49.953787699341774, 46.42605699598789, 35.82667775452137, 16.009671427309513, 4.205555431544781, 1.995418039150536, 6.227377541363239, 10.393497738987207, 10.611611735075712, 8.252367731183767, 10.769094284623861, 9.82045428827405, 14.184357672929764, 11.199615933001041, 3.664507451467216, 0.49930769484490156, 0.35704442707356066, 2.5132240913808346, 13.312988430261612, 26.907670944929123, 36.83613918721676, 38.82835328578949, 38.581092953681946, 35.85986517369747, 6.125034783035517, 0.2910877444082871, 0.27244481665547937, 0.2325768512673676, 0.19708550884388387, 0.0836580476607196, 0.1223390072118491, 0.10689847636967897, 0.29784606769680977, 0.17625548673095182, 0.24879819568013772, 0.13051193818682805, 0.09959840754163451, 0.10114177042851225, 0.15006588189862669, 0.09956716312444769, 0.05341285439499188, 0.08572917402489111, 0.10529327773838304, 0.10325658702640794, 0.10582032875390723, 0.2946973725920543, 0.1297488619456999, 0.17242143308976665, 0.1676672202302143, 0.20473475073231384, 0.10271213264786638], [0.030972505410318263, 0.03738455372513272, 0.02966919018945191, 0.04353730306320358, 0.037802920924150385, 0.02814573726936942, 0.05070249397249427, 0.04999611781386193, 0.007659258562853211, 0.03785414024605416, 0.02388615655945614, 0.03600839670980349, 0.05918259244936053, 0.036459763505263254, 0.04012676712591201, 0.07772022800054401, 0.050137541475123726, 0.1290311457705684, 0.03887158389261458, 0.06948155758436769, 0.05941225004789885, 0.006828534633314121, 0.03900077696016524, 0.0879852584330365, 0.050612519698916, 0.06504088727524504, 0.02407782361842692, 0.07172050580265932, 0.026186795803369023, 0.03932960404199548, 0.015707362617831677, 0.17641016514971852, 0.555744047742337, 8.756845761090517, 32.662549540400505, 34.203921630978584, 28.003617636859417, 29.5921565964818, 39.90705460309982, 21.58333394676447, 6.680088099092245, 0.5319149326533079, 0.25436399155296385, 1.7069651861675084, 3.8899809401482344, 4.592642560601234, 5.2266675140708685, 4.054186278954148, 2.113585048355162, 4.407386351376772, 3.287346102297306, 1.1841843696311116, 2.5682270899415016, 4.1475363448262215, 10.517396740615368, 25.156762897968292, 38.49004223942757, 51.375040635466576, 55.78781984746456, 55.85410729050636, 55.16064070165157, 48.448285683989525, 47.965510189533234, 46.24443434178829, 47.72614203393459, 47.137432023882866, 48.61275605857372, 46.32349289953709, 39.73395109176636, 41.12696014344692, 50.370971113443375, 51.76689840853214, 53.77128705382347, 52.659877091646194, 47.805952951312065, 51.95954047143459, 55.95656879246235, 52.60788828134537, 52.94318988919258, 46.338232308626175, 37.77568057179451, 37.42668069899082, 41.35922268033028, 40.587582886219025, 40.73151156306267, 44.65150661766529, 50.4485135525465, 48.32134589552879, 54.62167762219906, 48.179358914494514, 40.56293360888958, 49.655287116765976, 52.01655261218548, 49.783803820610046, 45.5156372487545, 45.78152038156986, 43.59148129820824, 43.65366876125336, 38.59305091202259, 37.603899389505386, 37.95518673956394, 38.618239760398865, 38.53593237698078, 41.24983415007591, 39.26248379051685, 37.89798080921173, 37.125163078308105, 36.66936993598938, 41.44740454852581, 44.38363999128342, 46.40047676861286, 48.19944843649864, 49.513486325740814, 49.205433055758476, 47.368851006031036, 47.02783830463886, 41.3071046769619, 37.15083070099354, 44.49023947119713, 48.0366575717926, 49.372263103723526, 46.26835025846958, 46.3384260982275, 47.37838849425316, 46.5130989253521, 45.199832394719124, 31.850772500038147, 17.376765869557858, 4.911759411916137, 0.7409809611272067, 0.5768981063738465, 2.60103452950716, 3.0360496742650867, 4.220867184922099, 4.468779657036066, 3.915088805370033, 6.016943883150816, 4.178474759683013, 1.1515975557267666, 0.5747506278567016, 0.31085924129001796, 1.0977046913467348, 7.223201980814338, 17.458072006702423, 22.831156589090824, 28.757683373987675, 23.416919857263565, 27.130319997668266, 11.872028801590204, 0.7537844928447157, 0.07998627203051001, 0.021549588091147598, 0.06347450296743773, 0.01566343675222015, 0.054983175796223804, 0.051028196612605825, 0.033657476960797794, 0.018940861082228366, 0.04572975944029167, 0.02865295438823523, 0.0411268667812692, 0.06049365569197107, 0.04369975176814478, 0.09306058374932036, 0.01078078039427055, 0.13787601725198328, 0.08838297537295148, 0.07855692529119551, 0.03725080758158583, 0.018316605419386178, 0.04490515173529275, 0.016880930015759077, 0.05319172407325823, 0.06207387734320946, 0.007187905266619055, 0.019837193649436813, 0.024290419241879135, 0.0953027157811448, 0.024577081203460693, 0.02038297647231957, 0.05414523169747554, 0.0554054541134974, 0.050933773163706064, 0.0657626852625981, 0.035341591865289956, 0.07224835833767429, 0.033939585846383125, 0.023046518508635927, 0.04199033704935573, 0.05716907529858872, 0.058801892955671065, 0.051263565037515946, 0.08332674551638775, 0.06506940801045857, 0.03841409437882248, 0.07481258988264017, 0.045997767520020716, 0.05435449507785961, 0.037472683761734515, 0.03753717268409673, 0.03670534017146565, 0.08063665314693935, 0.07342842509387992, 0.025762921868590638, 0.029927596733614337, 0.07522840780438855, 0.0257132220940548, 0.1193465490359813, 1.0141338757239282, 12.02191460877657, 40.103580057621, 35.47618456184864, 30.252851843833923, 36.741140484809875, 44.988977909088135, 22.31414683163166, 6.067171012982726, 0.3927877137903124, 0.06868020878755488, 0.8073172078002244, 3.1936956150457263, 4.400343429297209, 6.390788247808814, 6.78474398329854, 7.866926388815045, 5.0676968693733215, 3.6647487385198474, 3.6473266733810306, 2.4529448384419084, 5.693984013050795, 12.434709258377552, 27.31843840330839, 39.97304566204548, 53.678773418068886, 55.99111273884773, 55.17276585102081, 56.04766130447388, 49.644111916422844, 49.23989720642567, 48.92370857298374, 48.131055906414986, 49.41401906311512, 49.171516075730324, 46.76079623401165, 42.181908935308456, 44.722760394215584, 52.590743601322174, 53.75186249613762, 55.06571799516678, 51.79091311991215, 48.85634198784828, 51.75465166568756, 55.22125884890556, 54.37652237713337, 53.376309648156166, 47.20294810831547, 38.26516650617123, 38.51917527616024, 42.29980520904064, 41.49765685200691, 42.23607502877712, 46.39623239636421, 50.78005716204643, 51.50220841169357, 55.9733334928751, 50.58981657028198, 42.42514528334141, 51.44344836473465, 54.32937070727348, 50.930776074528694, 46.5210746973753, 46.254135221242905, 44.57133091986179, 44.370253309607506, 40.09661503136158, 39.12254869937897, 39.50784422457218, 40.64464062452316, 40.75792774558067, 42.69341468811035, 41.24323770403862, 40.611722990870476, 38.22712294757366, 38.886558562517166, 44.770721420645714, 48.07529769837856, 48.829101249575615, 49.582106843590736, 50.011764988303185, 49.56001862883568, 49.43283565342426, 49.94971051812172, 41.868228167295456, 39.59234409034252, 47.66399636864662, 48.431186601519585, 49.09127198159695, 47.92680166661739, 47.61502459645271, 48.50344352424145, 48.36528293788433, 47.37856328487396, 35.90213030576706, 21.048828028142452, 6.509635895490646, 2.6850271224975586, 1.7187311360612512, 4.38852321356535, 6.317473081871867, 5.677553694695234, 2.3161583533510566, 4.2575067188590765, 7.437827764078975, 3.7117876019328833, 1.0755128134042025, 0.1504957041470334, 0.2135042051668279, 1.195414667017758, 7.372762430459261, 19.772493615746498, 26.551839038729668, 34.316813573241234, 29.295863695442677, 31.786877028644085, 15.700051691383123, 1.3273984473198652, 0.0739350522053428, 0.029891903141106013, 0.037175357138039544, 0.007938292637845734, 0.023786957390257157, 0.026631459149939474, 0.005308291501933127, 0.03211529408872593, 0.060903402845724486, 0.009023017537401756, 0.03166237991536036, 0.054042243864387274, 0.02314343371836003, 0.009271366125176428, 0.009760839420778211, 0.09399621674674563, 0.0638958350464236, 0.03282827907241881, 0.040853693353710696, 0.06539004549267702, 0.019977719312009867, 0.04819178611796815, 0.055853243757155724, 0.07980393376783468, 0.035682489979080856, 0.05540171739994548, 0.08817948590149172, 0.25305911782197654, 0.1327214899356477, 0.18629190599313006, 0.1311591948615387, 0.11373773086233996, 0.17666834348347038, 0.1439343171659857, 0.08236518187914044, 0.1939431665232405, 0.13437180372420698, 0.12548537197289988, 0.14380209613591433, 0.23103097249986604, 0.14613885199651122, 0.171126993955113, 0.23517880617873743, 0.23338464932749048, 0.19835860381135717, 0.19748519989661872, 0.08769248117459938, 0.11097548689576797, 0.12953236262546852, 0.1358935033204034, 0.22782997082686052, 0.1725549009279348, 0.15606665052473545, 0.18751164054265246, 0.10946705690003, 0.16131946787936613, 0.0788240390829742, 0.4874829371692613, 1.0526571585796773, 15.11783268302679, 46.90214864909649, 46.02385997772217, 38.3543287217617, 38.41691516339779, 49.58924666047096, 25.58367568999529, 8.003216050565243, 0.7830456539522856, 0.7642492500599474, 2.99505771137774, 9.443434718996286, 14.67207195237279, 11.503297537565231, 10.510236024856567, 9.031646065413952, 10.567421056330204, 7.7595835737884045, 4.032896971330047, 3.636984103359282, 5.9864728432148695, 12.748024296015501, 28.724503554403782, 41.21283173561096, 55.77522352337837, 57.38895893096924, 58.76746416091919, 59.547501504421234, 51.711007207632065, 52.00591318309307, 51.43752448260784, 51.022609546780586, 52.223519906401634, 53.57122398912907, 49.44148778915405, 43.54052983224392, 46.07236057519913, 54.362831711769104, 56.116072833538055, 56.09686866402626, 53.18515330553055, 47.964035868644714, 52.84891314804554, 57.01884739100933, 57.924874573946, 57.46981859207153, 50.08368752896786, 41.97051487863064, 39.93071213364601, 44.49923738837242, 45.34571796655655, 44.022210985422134, 48.05528037250042, 54.20310728251934, 53.23168560862541, 58.25907804071903, 51.25205643475056, 44.535118862986565, 52.2825725376606, 56.63066402077675, 52.11636945605278, 48.751745000481606, 49.21948470175266, 47.301286831498146, 47.394138649106026, 41.78558640182018, 40.60365602374077, 41.27770945429802, 42.42590144276619, 42.69618093967438, 44.22084532678127, 43.44968430697918, 42.23415233194828, 40.46970561146736, 41.07433296740055, 46.25894196331501, 47.48968452215195, 51.880212128162384, 50.668753534555435, 52.508105635643005, 49.94149535894394, 50.76826639473438, 51.71286150813103, 43.990570083260536, 41.656609922647476, 48.20222608745098, 50.40442071855068, 52.46767580509186, 48.0845881998539, 49.71955306828022, 48.84526178240776, 50.202613547444344, 48.223117366433144, 38.26751857995987, 20.28212796896696, 6.078573726117611, 2.284818347543478, 2.6331945788115263, 7.346492065116763, 8.038028832525015, 10.376239065080881, 8.336348924785852, 10.619065035134554, 14.846036117523909, 10.41176525875926, 2.6823318796232343, 0.865417990135029, 0.7626644382253289, 1.978745840024203, 9.224550314247608, 22.35763169825077, 30.949675552546978, 39.10745590925217, 33.524537086486816, 36.46111451089382, 16.50087296962738, 1.3495194353163242, 0.2510230801999569, 0.16308183112414554, 0.13435271568596363, 0.15029869362479076, 0.13411346211796626, 0.12268913022126071, 0.13378751085838303, 0.15041429054690525, 0.11037399846827611, 0.1218046979920473, 0.15566296671750024, 0.13545156922191381, 0.14778809709241614, 0.15114169917069376, 0.10831081308424473, 0.26112828170880675, 0.13856352801667526, 0.12938414089148864, 0.1817921904148534, 0.09630572094465606, 0.07429716089973226, 0.1272424214403145, 0.1531213038833812, 0.17509089375380427, 0.14052241196623072, 0.13752829137956724], [0.012952488177688792, 0.05608490144368261, 0.03132602374535054, 0.031806701663299464, 0.03184941226209048, 0.03542370679497253, 0.05406876080087386, 0.011898119901161408, 0.04740576638141647, 0.05281256824673619, 0.07106043965904973, 0.02954271709313616, 0.02307553462742362, 0.022712683785357513, 0.024437689171463717, 0.052630601057899185, 0.051705792284337804, 0.052472831594059244, 0.04801577095349785, 0.029868920682929456, 0.011590555350267095, 0.049165027448907495, 0.020175854187982623, 0.03730841308424715, 0.054049142127041705, 0.054491246919496916, 0.06231966181076132, 0.07437605861923657, 0.027895859857380856, 0.03639883689174894, 0.0785013310087379, 0.045063618817948736, 0.05411022459156811, 1.5387382381595671, 17.247021831572056, 33.15469153225422, 29.944946765899658, 35.77685862779617, 45.58650344610214, 39.42334055900574, 21.617330722510815, 5.032287519425154, 0.669388409005478, 0.5245090113021433, 1.7270156415179372, 3.9845022931694984, 4.341419516131282, 4.46627939119935, 8.730936851352453, 3.530988316051662, 1.5064584952779114, 3.3998124673962593, 1.2800798239186406, 1.6954525164328516, 5.03104736097157, 15.860897060483694, 26.28611169755459, 43.54083001613617, 56.2004055082798, 51.92423656582832, 54.9042646586895, 53.537496998906136, 52.93285444378853, 50.8426284044981, 51.05645053088665, 52.867045775055885, 51.94820187985897, 53.17477606236935, 47.45698347687721, 41.853845939040184, 48.31253036856651, 53.81588526070118, 54.80662129819393, 52.30321682989597, 51.610335409641266, 50.396414548158646, 53.0610291659832, 53.81628803908825, 52.439013943076134, 49.52427014708519, 38.41654658317566, 38.68294268846512, 40.77470764517784, 42.76491165161133, 39.487488716840744, 43.09881493449211, 50.1053349673748, 49.99935485422611, 51.75420328974724, 51.77504137158394, 39.947256445884705, 39.92853865027428, 47.41917550563812, 54.074115604162216, 48.20051237940788, 48.99905472993851, 47.159083262085915, 47.636447846889496, 43.65109249949455, 37.731523141264915, 35.64370237290859, 38.88628117740154, 40.61289332807064, 40.94911448657513, 41.40531040728092, 40.02849608659744, 39.11006636917591, 38.6096104234457, 35.05837798118591, 41.03935204446316, 46.970370188355446, 49.25248593091965, 49.80543985962868, 50.31707100570202, 47.37505987286568, 45.91765567660332, 45.70463910698891, 41.9625923037529, 41.13434694707394, 46.56440757215023, 48.53755809366703, 48.1813196092844, 43.647304102778435, 43.93524505198002, 42.56235972046852, 34.408825635910034, 23.68525005877018, 6.842195950448513, 0.7389988924842328, 4.58952815271914, 0.8132895966991782, 3.648021323606372, 6.165162529796362, 2.194537566974759, 2.481720456853509, 2.078455458395183, 5.208454141393304, 2.8075608098879457, 1.0651145526207983, 0.05456411468912847, 0.47439344110898674, 4.998837439343333, 17.704063206911087, 23.254018798470497, 23.2135471701622, 21.158976517617702, 25.098679214715958, 15.63116043806076, 2.2098740190267563, 0.0779139062797185, 0.01735536276100902, 0.006042796912879567, 0.020369667909108102, 0.042362765307188965, 0.03098650231549982, 0.04682015620346647, 0.09186938477796502, 0.014648919022874907, 0.020452460048545618, 0.04417913092765957, 0.037996573228156194, 0.07288052715011872, 0.046177638141671196, 0.06390115624526516, 0.046244542754720896, 0.04756723174068611, 0.05205399313126691, 0.03929581034753937, 0.018364039788139053, 0.054541761201107875, 0.05262067112198565, 0.03284663238446228, 0.04765518366184551, 0.01363590692562866, 0.06278961198404431, 0.04958714620443061, 0.047936468763509765, 0.03909763094270602, 0.07463718327926472, 0.0473811048141215, 0.024106208911689464, 0.027735771182051394, 0.058169041367364116, 0.04880514519754797, 0.027547373283596244, 0.045583263199659996, 0.04580543623887934, 0.06123493876657449, 0.05208687398408074, 0.04716853887657635, 0.07600637152791023, 0.012770619323418941, 0.05018182171625085, 0.02363490617426578, 0.03713770427566487, 0.05449597811093554, 0.05596977207460441, 0.0422246330708731, 0.07686704760999419, 0.060493807832244784, 0.036409408785402775, 0.0343179587071063, 0.031925923976814374, 0.057867595824063756, 0.03855942173686344, 0.04401665624754969, 0.07564867119072005, 0.03576972572773229, 0.03740538581041619, 3.4896755078807473, 23.648357838392258, 39.290560483932495, 30.975358374416828, 33.40223304927349, 49.34849537909031, 43.897596672177315, 20.39590146392584, 4.405506877228618, 0.50475666183047, 0.28131564846262336, 0.8098980411887169, 2.8168655605986714, 2.311025303788483, 6.327975718304515, 9.062418714165688, 4.444424863904715, 3.7838364858180285, 4.299927642568946, 2.6610200107097626, 3.2657535234466195, 7.255000099539757, 18.53243015706539, 30.266472212970257, 46.43535889685154, 56.766894310712814, 54.367573857307434, 56.616958156228065, 55.83976686000824, 53.145225048065186, 53.128065168857574, 51.98185667395592, 53.57395604252815, 53.23829345405102, 54.1336964070797, 47.08104304969311, 44.03037294745445, 49.51841466128826, 54.881553277373314, 56.651669293642044, 52.51263879239559, 50.650282725691795, 50.66052697598934, 53.407882153987885, 55.0916364043951, 55.07206365466118, 50.64893759787083, 40.37606343626976, 38.33559192717075, 43.047316297888756, 44.4160370528698, 41.79901108145714, 44.67708304524422, 52.434530183672905, 52.41764388978481, 54.576672837138176, 53.19765463471413, 41.94609358906746, 42.18172274529934, 50.131903141736984, 55.34981735050678, 51.45599529147148, 51.17226831614971, 48.11418481171131, 49.42175164818764, 44.33176517486572, 37.64339067041874, 37.695128694176674, 40.29093660414219, 42.02359043061733, 42.41942659020424, 43.11504386365414, 41.19014695286751, 40.581829994916916, 40.27440749108791, 38.569568172097206, 44.96655911207199, 47.79923491179943, 51.13154590129852, 50.97443953156471, 50.58706171810627, 48.37887480854988, 48.30131717026234, 48.17044839262962, 43.7427131831646, 43.64218197762966, 47.305743992328644, 49.082266464829445, 47.851368114352226, 46.602853909134865, 45.35869427025318, 44.568819254636765, 39.07327674329281, 26.59893561154604, 10.581430904567242, 4.331529121845961, 6.7107700277119875, 2.9045456182211637, 4.843133669346571, 5.750477956607938, 4.195764781907201, 5.073217023164034, 4.670926434919238, 5.647098803892732, 1.450335863046348, 0.12022784940199926, 0.04989216147805564, 0.4843680246267468, 5.641429983079433, 18.501372523605824, 26.53967209160328, 29.09633830189705, 25.433838330209255, 26.362453401088715, 21.64596028625965, 4.380212584510446, 0.08060172025579959, 0.019454217617749237, 0.06763974743080325, 0.047638155083404854, 0.030008192115928978, 0.0652245242963545, 0.06031823795638047, 0.04007549214293249, 0.010215766669716686, 0.06794819884817116, 0.030131212370179128, 0.012465330382838147, 0.01948538967553759, 0.013622480546473525, 0.032911496091401204, 0.05294370945193805, 0.02130258464603685, 0.040573662481619976, 0.0475974668370327, 0.07857051401515491, 0.10354616562835872, 0.03472217314993031, 0.021353347547119483, 0.03421490408072714, 0.0474870501057012, 0.010657767561497167, 0.029019974244874902, 0.1596459248685278, 0.13458217290462926, 0.14555567235220224, 0.12866226868936792, 0.15637997043086216, 0.13175588159356266, 0.16524836799362674, 0.18066743592498824, 0.11311546229990199, 0.2735647471854463, 0.18759428610792384, 0.14003108051838353, 0.13303997518960387, 0.11525919297127984, 0.21621555264573544, 0.15460488677490503, 0.11251317235291936, 0.10813251952640712, 0.1302487577777356, 0.1264716120203957, 0.18672166886972263, 0.1447039539925754, 0.17257235624128953, 0.11955012756516226, 0.17262598383240402, 0.10638258725521155, 0.17232813028385863, 0.15693802095483989, 0.14369507844094187, 0.19887404021574184, 0.2254900534171611, 0.22258332814089954, 0.19807492528343573, 3.8182768877595663, 27.219193428754807, 46.434291154146194, 40.86851701140404, 44.17112119495869, 54.43866044282913, 49.90851312875748, 25.544078014791012, 6.3554354198277, 1.0672921920195222, 1.0877831862308085, 5.943810632452369, 10.72672275826335, 13.062861151993275, 12.130705621093512, 14.837956801056862, 8.492019921541214, 5.121035082265735, 7.6023494359105825, 4.137971308082342, 2.824026276357472, 7.829606216400862, 19.158404767513275, 29.14840690791607, 46.7231934517622, 60.53592726588249, 55.96322603523731, 59.35626156628132, 58.809334114193916, 56.62851333618164, 54.376560375094414, 55.18706068396568, 55.461846739053726, 56.71310059726238, 56.982148960232735, 50.57107217609882, 45.53155459463596, 51.38249583542347, 58.40874060988426, 58.29696960747242, 52.44086444377899, 51.53355672955513, 51.75985738635063, 53.29189717769623, 55.84900036454201, 56.878612115979195, 53.31771679222584, 42.671550661325455, 42.35160782933235, 43.59620064496994, 48.39212089776993, 43.97975966334343, 46.789287105202675, 55.19095167517662, 53.56286443769932, 54.43352311849594, 53.57832960784435, 46.399382427334785, 41.49439662694931, 52.67492048442364, 58.915321826934814, 53.81636023521423, 52.477080300450325, 49.48719933629036, 52.689906880259514, 47.12864309549332, 40.671569779515266, 39.29231978952885, 41.94587700068951, 44.83839958906174, 45.523202642798424, 45.01494571566582, 43.030551597476006, 44.09388653934002, 42.50299550592899, 39.295044243335724, 45.19924342632294, 49.61882807314396, 52.454106733202934, 52.379227951169014, 52.472706735134125, 50.0235253572464, 49.76456545293331, 51.746482104063034, 46.081354692578316, 45.408201813697815, 49.21186611056328, 51.985713467001915, 49.17836710810661, 47.03880071640015, 44.65003229677677, 47.158517092466354, 38.85147124528885, 27.664244547486305, 8.735710345208645, 4.4277589581906796, 10.347094628959894, 2.8877692809328437, 9.68230890110135, 13.140011262148619, 6.674092970788479, 7.865467267110944, 9.305447973310947, 11.0468128323555, 6.342706577852368, 2.141359895467758, 0.22973769111558795, 0.836568275699392, 7.268366357311606, 23.705936148762703, 33.50662104785442, 32.34636850655079, 30.684305392205715, 34.12207022309303, 23.732124343514442, 4.745192974805832, 0.18185337306931615, 0.17532527883304283, 0.09181484434520826, 0.131155498966109, 0.172063524951227, 0.12776465591741726, 0.15410044899908826, 0.21172627166379243, 0.0720334991638083, 0.21124204999068752, 0.12946102739078924, 0.10695433782530017, 0.18151007039705291, 0.12972937314771116, 0.18163568631280214, 0.1907605107408017, 0.13803718204144388, 0.253255371353589, 0.1132525221328251, 0.19419548189034685, 0.10629884331137873, 0.13602486345916986, 0.15042083628941327, 0.09662361248047091, 0.25095726654399186, 0.18133437435608357, 0.17832104698754847], [0.03714559330546763, 0.03842105943476781, 0.05713829101296142, 0.11339899981976487, 0.009944389239535667, 0.04019459942355752, 0.03783082196605392, 0.0504311054100981, 0.042003836715593934, 0.03620491370384116, 0.03692613281600643, 0.06212367916305084, 0.051906895751017146, 0.006401250993803842, 0.14676522463560104, 0.06100574872107245, 0.009997107699746266, 0.05109370598802343, 0.024316678282048088, 0.043265539716230705, 0.0460361031582579, 0.019621954124886543, 0.02670950339961564, 0.07030268461676314, 0.02070862345135538, 0.06630225630942732, 0.04414174152771011, 0.08083497727056965, 0.03240319543692749, 0.02390820020082174, 0.04804952011909336, 0.05530283735424746, 0.012523011027951725, 0.13614807481644675, 1.703712441958487, 22.377048656344414, 36.13940477371216, 29.081175215542316, 28.268512822687626, 36.217840164899826, 37.29234650731087, 20.407335050404072, 4.712987802922726, 0.5178051616530865, 0.5677441600710154, 1.8928337562829256, 2.2029294166713953, 6.395980669185519, 7.069214293733239, 2.061572726815939, 3.581896796822548, 2.952825352549553, 1.899281416554004, 1.948081604205072, 1.8670280347578228, 9.533291347324848, 16.31559681147337, 30.067758075892925, 45.544059723615646, 55.78460521996021, 53.398888036608696, 52.434097006917, 54.797209203243256, 53.86199578642845, 54.88156847655773, 55.58758199214935, 57.14511841535568, 52.45534926652908, 53.520500510931015, 42.42840550839901, 47.12037853896618, 51.89189650118351, 55.34992374479771, 53.363257348537445, 53.25970150530338, 53.881036564707756, 52.30021879076958, 53.35417963564396, 53.9191485196352, 50.27933143079281, 38.952287435531616, 37.99139119684696, 39.55376476049423, 39.7070637345314, 42.75810241699219, 48.161511272192, 50.71770630776882, 50.02736695110798, 55.01887030899525, 45.89033894240856, 44.35101494193077, 53.17460887134075, 44.534450098872185, 53.008193001151085, 50.55068626999855, 52.81196393072605, 50.38090378046036, 49.462850242853165, 49.08602066338062, 40.962181985378265, 35.702891796827316, 38.339357525110245, 39.03448082506657, 41.19806572794914, 40.626899376511574, 40.47799676656723, 40.43917044997215, 40.57453818619251, 37.62061849236488, 37.42284670472145, 41.791255697607994, 46.376074478030205, 49.4706816226244, 48.81987154483795, 49.082874432206154, 49.805428460240364, 46.43459513783455, 46.902942806482315, 45.30420899391174, 46.341773718595505, 47.58744567632675, 47.413449212908745, 45.63591219484806, 42.14348539710045, 37.689786180853844, 24.450451098382473, 8.226201385259628, 2.437577750533819, 2.029982409439981, 3.507125359028578, 2.366041364148259, 2.349333898164332, 3.9203014131635427, 3.902570139616728, 1.7612039507366717, 2.922744029201567, 4.019804773852229, 0.7689263834618032, 0.36291027325205505, 0.20809964829823002, 4.026484340429306, 16.240909919142723, 26.263094432651997, 23.159707859158516, 21.080953404307365, 23.176187574863434, 23.44633597880602, 7.959097092971206, 0.25968216243200004, 0.0316541161009809, 0.021180705443839543, 0.06957414050702937, 0.08614724065409973, 0.00997607708995929, 0.024850057961884886, 0.046915700295357965, 0.013285423046909273, 0.009515330475551309, 0.0073051850085903425, 0.06533118576044217, 0.03863267913402524, 0.02412864032521611, 0.04803033189091366, 0.04045708221383393, 0.0363674403342884, 0.01123563806686434, 0.02651195853104582, 0.04726501807454042, 0.09621478558983654, 0.021473582892213017, 0.014077700943744276, 0.039684358052909374, 0.035575464862631634, 0.07563617342384532, 0.043415264299255796, 0.07333321496844292, 0.04048819304443896, 0.00330058235249453, 0.022486794441647362, 0.10728201828897, 0.02435678950860165, 0.04771102285303641, 0.03929160608095117, 0.043583579681580886, 0.008385333640035242, 0.012640629374800483, 0.051640679957927205, 0.0811157094722148, 0.017904565029311925, 0.022729601041646674, 0.03486612382403109, 0.02422271682007704, 0.012179233381175436, 0.04010014628875069, 0.015575770557916258, 0.07854436073102988, 0.07722546040895395, 0.04915359095321037, 0.05380494585551787, 0.08115440505207516, 0.019842277361021843, 0.028073478060832713, 0.07572298985905945, 0.015053335700940806, 0.005420635034170118, 0.024948633727035485, 0.08540038776118308, 0.06837309323600493, 0.033006023440975696, 0.21494947839528322, 5.27383248321712, 28.337976895272732, 37.50957325100899, 31.30300909280777, 34.62546721100807, 48.28422948718071, 44.569856598973274, 19.332543723285198, 4.165535978972912, 0.3364717372460291, 0.3247365419520065, 0.9942368371412158, 2.345865871757269, 4.42321915179491, 7.926653008908033, 6.286008395254612, 4.090183647349477, 4.088899791240692, 3.3507554372772574, 3.0318290507420897, 3.4602083265781403, 10.11470764875412, 18.371881172060966, 32.13917322456837, 48.733445182442665, 56.62842974066734, 56.89666114747524, 54.74664531648159, 56.575950756669044, 54.37160164117813, 56.180935353040695, 55.726453140378, 58.87057542800903, 54.621468633413315, 55.348635613918304, 44.98685762286186, 49.277078211307526, 53.69148373603821, 57.61434003710747, 54.62622597813606, 53.27813811600208, 53.587274327874184, 53.47806438803673, 53.377715572714806, 56.379254311323166, 51.405746787786484, 40.770698860287666, 39.27848473191261, 43.113542944192886, 42.154330015182495, 44.492200165987015, 50.2076330780983, 53.41926634311676, 51.3291846960783, 55.31264394521713, 47.35062338411808, 46.59048177301884, 56.15023300051689, 46.384950801730156, 54.674213603138924, 52.484394907951355, 52.96642564237118, 51.912259608507156, 49.55012395977974, 51.58376723527908, 43.54621432721615, 36.752072498202324, 39.85668070614338, 41.92521370947361, 42.206501215696335, 43.16366225481033, 42.03853502869606, 42.73583561182022, 41.771147176623344, 39.01621900498867, 39.744924902915955, 44.73362401127815, 48.82788151502609, 51.86754360795021, 49.98715750873089, 48.93213652074337, 50.438827872276306, 48.74889515340328, 47.32151314616203, 47.10495136678219, 47.47167728841305, 49.06212754547596, 49.30518910288811, 46.720187813043594, 44.36607353389263, 41.76958166062832, 27.232697904109955, 11.333148367702961, 5.080329766497016, 3.3360409643501043, 6.930059110745788, 3.0203707655891776, 4.322316516190767, 4.984618602320552, 3.03147139493376, 2.4629276152700186, 5.278998306021094, 2.8029091469943523, 0.04205409495625645, 0.13162793533410877, 0.2105706586735323, 4.046885445713997, 17.31423642486334, 30.466981753706932, 27.854699827730656, 26.258306689560413, 24.409101717174053, 29.20508086681366, 10.681223999708891, 0.6363097589928657, 0.04823713134101126, 0.023341143714787904, 0.04167702456470579, 0.03901808013324626, 0.058800434635486454, 0.0619950130203506, 0.05846125088282861, 0.02997192150360206, 0.031044749775901437, 0.05806291053886525, 0.08904308604542166, 0.045238635793793947, 0.05776744299510028, 0.01942896233231295, 0.026233950011373963, 0.03880613388901111, 0.04939463680784684, 0.03843688202323392, 0.0841987319290638, 0.10371895245043561, 0.005153619113116292, 0.07433217542711645, 0.04022182140033692, 0.03479267717921175, 0.11857327568577603, 0.023512054758612067, 0.08147821150487289, 0.11771081844926812, 0.12372643745038658, 0.19137923925882205, 0.2128563547739759, 0.1148789758735802, 0.13775513623841107, 0.1667163212550804, 0.15717347472673282, 0.10008284443756565, 0.10545752244070172, 0.12894127168692648, 0.15926665771985427, 0.08630502125015482, 0.05499113533005584, 0.19660079735331237, 0.1366358291124925, 0.12190802721306682, 0.17111765773734078, 0.10807461716467515, 0.1765166484983638, 0.11460009904112667, 0.14330865698866546, 0.18032293097348884, 0.19898837548680604, 0.10646581911714748, 0.16719401202863082, 0.1603473286377266, 0.12179908735561185, 0.07338308729231358, 0.07673473752220161, 0.165949979564175, 0.24041523691266775, 0.11328694294206798, 0.3763985401019454, 6.459451513364911, 35.265675857663155, 47.01497599482536, 39.445257782936096, 36.38978473842144, 45.37399224936962, 45.40135458111763, 24.124200604856014, 6.098516480997205, 0.9977149567566812, 1.0589302657172084, 3.9757860358804464, 7.262733159586787, 13.479308355599642, 16.910952664911747, 9.977403916418552, 8.022018391638994, 8.149878680706024, 5.086348643526435, 3.880678089335561, 3.9657132513821125, 11.187472734600306, 19.650482162833214, 32.42751695215702, 48.35131108760834, 59.382062181830406, 58.258120492100716, 55.79039990901947, 59.77898508310318, 56.96457490324974, 59.58781734108925, 58.95300820469856, 61.06103628873825, 55.45032575726509, 58.3542363345623, 46.27984844148159, 50.765336751937866, 55.67996263504028, 58.71016703546047, 55.70856750011444, 52.48919405043125, 53.48605915904045, 54.418707713484764, 55.4312127828598, 58.676675632596016, 53.60615931451321, 42.87296645343304, 41.52709387242794, 44.565836414694786, 43.01426947116852, 45.59954434633255, 52.848966345191, 55.07716678082943, 52.24770940840244, 58.16053032875061, 47.13131435215473, 51.197738349437714, 54.6725644916296, 44.25215184688568, 59.21660766005516, 55.51169626414776, 55.03560081124306, 53.7223494797945, 53.82223851978779, 52.659379318356514, 44.416489228606224, 38.89847852289677, 41.369527727365494, 43.35256911814213, 44.73533771932125, 45.200166776776314, 45.00216320157051, 45.22111885249615, 44.58185255527496, 42.18857377767563, 40.26682309806347, 46.61115646362305, 50.9478485584259, 53.60798701643944, 50.72956547141075, 50.09027637541294, 53.043736293911934, 50.80270394682884, 51.913346350193024, 49.077748507261276, 48.536319360136986, 49.47735786437988, 50.482251942157745, 46.997690722346306, 46.83060608804226, 41.3970572501421, 28.89759946614504, 11.338452883064747, 4.430360868573189, 4.26648136228323, 7.929249219596386, 5.4027980379760265, 7.741527417674661, 9.535396434366703, 9.045749958604574, 6.1486514657735825, 8.868698459118605, 9.108550138771534, 2.5048210797831416, 1.1129959020763636, 0.8333500858861953, 4.926560092717409, 20.979867428541183, 33.99926841259003, 30.877599120140076, 31.32789585739374, 32.40132495760918, 33.06111395359039, 11.278260312974453, 0.7397999370004982, 0.16466794913867489, 0.08180812583304942, 0.16299057664582506, 0.1446826840401627, 0.1447724987519905, 0.15845082962187007, 0.16602958232397214, 0.09024919476360083, 0.11134107626276091, 0.10030717341578566, 0.18939341534860432, 0.248757986119017, 0.19179775117663667, 0.14819848991464823, 0.09125890894210897, 0.12115916309994645, 0.10179082310060039, 0.14695610501803458, 0.15681657590903342, 0.26200698455795646, 0.13935998606029898, 0.13244414934888482, 0.12874127773102373, 0.12153647840023041, 0.2082036528736353, 0.11793921439675614, 0.2363079838687554], [0.10288330900948495, 0.023891236560302787, 0.08840733265969902, 0.07603652498801239, 0.05148993863258511, 0.02710547072638292, 0.013300083246576833, 0.018869928462663665, 0.10007195713114925, 0.009841132377914619, 0.05652224906953052, 0.09598261953215115, 0.027702905172191095, 0.028110566890973132, 0.00856088217915385, 0.06414305928046815, 0.05027557723224163, 0.03299991927633528, 0.03359534064657055, 0.09361491611343808, 0.022038223687559366, 0.03333143293275498, 0.021578915911959484, 0.019002715380338486, 0.03195946163032204, 0.09283989129471593, 0.013901200600230368, 0.012679772098636022, 0.06052179051039275, 0.11839978382340632, 0.03869880449201446, 0.08408784022321925, 0.06812036226619966, 0.0673841591924429, 0.26423241826705635, 7.1328300051391125, 29.771391078829765, 33.26268173754215, 25.756036341190338, 29.280998893082142, 34.14077281951904, 36.8918251991272, 18.83515801280737, 5.321268187835813, 0.3093096666270867, 0.786666622152552, 0.6238679797388613, 2.1935075847432017, 6.421370431780815, 4.7787670232355595, 3.8032313575968146, 3.698861883021891, 2.4320844328030944, 1.6805995884351432, 0.5884147540200502, 2.359440643340349, 7.567199422046542, 15.145390704274178, 29.841799400746822, 47.41906151175499, 55.836031660437584, 56.271207109093666, 55.671002715826035, 56.10673673450947, 57.81428910791874, 53.59024956822395, 57.27240778505802, 56.853829845786095, 54.48664426803589, 50.83697810769081, 50.738525390625, 54.92487475275993, 54.48662146925926, 53.10418725013733, 50.107987225055695, 47.98298925161362, 54.425174966454506, 52.79746010899544, 54.47928786277771, 45.45658841729164, 38.13827991485596, 38.50367210805416, 40.53766496479511, 40.80813065171242, 48.02898958325386, 50.982605293393135, 53.73883679509163, 51.29510052502155, 55.23323580622673, 47.597275748848915, 39.46246325969696, 57.402831986546516, 45.30053459107876, 53.26618395745754, 51.860703974962234, 52.28065364062786, 51.96948453783989, 52.061458602547646, 52.19134323298931, 46.122240498661995, 35.69025367498398, 36.673002541065216, 39.15256708860397, 39.82171878218651, 41.00478909909725, 40.59076331555843, 40.40483549237251, 39.805398657917976, 40.5822441726923, 40.05027651786804, 44.982837438583374, 48.78386847674847, 47.53520987927914, 49.82465922832489, 47.04541616141796, 51.73209607601166, 49.07268337905407, 47.49520942568779, 46.57413884997368, 48.25365632772446, 48.831578716635704, 47.594395503401756, 44.92450676858425, 36.13596595823765, 25.45599304139614, 10.982854664325714, 3.054975983686745, 2.729333695024252, 1.9810295174829662, 3.9015862299129367, 3.2330873887985945, 3.2046874752268195, 3.027139864861965, 1.2248667678795755, 2.093490776605904, 4.002293888479471, 2.0383569225668907, 0.2009936436661519, 0.3187099169008434, 2.777356468141079, 13.822579085826874, 24.342234805226326, 33.90724495053291, 17.096378915011883, 22.31734625995159, 25.74525821954012, 14.618407431989908, 1.8362838844768703, 0.02047798436251469, 0.0864039792213589, 0.03602276468882337, 0.0152110049748444, 0.01366992140901857, 0.05294926813803613, 0.02377778073423542, 0.0382454895589035, 0.060198997089173645, 0.03336612833663821, 0.04996961200959049, 0.006586631134268828, 0.0318504698225297, 0.02515547770599369, 0.05306043443852104, 0.019027143171115313, 0.045943416334921494, 0.024156821527867578, 0.014594834083254682, 0.04038486382341944, 0.03457966595306061, 0.013128331720508868, 0.0711247393337544, 0.02405035116680665, 0.044575749489013106, 0.0369421186769614, 0.04427582534844987, 0.0470129624591209, 0.015807073868927546, 0.013303413634275785, 0.060708830278599635, 0.021002374778618105, 0.06670980670605786, 0.0609803301631473, 0.029436337645165622, 0.03575577706214972, 0.044913571400684305, 0.038575927101192065, 0.04474240617128089, 0.02935505392088089, 0.063682616018923, 0.042089996350114234, 0.03182545944582671, 0.05157870320545044, 0.00850042682941421, 0.036246281015337445, 0.06706363303237595, 0.04291878234653268, 0.054588123166467994, 0.028252775373402983, 0.06126327396486886, 0.01881340278487187, 0.061401610291795805, 0.0851865230652038, 0.015490688892896287, 0.026984337382600643, 0.04036826569063123, 0.016090257013274822, 0.01030151812301483, 0.045246862500789575, 0.053447386526386254, 0.14217291871318594, 0.7252176257316023, 11.707146149128675, 36.80829048156738, 34.445657059550285, 25.226595550775528, 32.04665958881378, 46.316691264510155, 41.92372798919678, 18.26906628906727, 4.396707974374294, 0.23694347008131444, 0.23740744596580043, 0.7316646922845393, 4.3044099770486355, 4.063983103260398, 5.499769784510136, 6.070986008271575, 4.549329159781337, 7.429298646748066, 4.943045508116484, 2.6361976051703095, 4.124232670292258, 9.218141008168459, 17.47954275459051, 33.06307464838028, 52.40752123296261, 58.99245388805866, 57.6681337505579, 57.17299371957779, 58.844569623470306, 59.964745715260506, 56.37083396315575, 58.81145440042019, 57.72085592150688, 55.38468807935715, 52.260358929634094, 50.986481085419655, 56.19090601801872, 55.77372260391712, 53.98803502321243, 50.83846762776375, 48.961501345038414, 55.92567265033722, 54.06582444906235, 54.40595559775829, 48.254967257380486, 40.54799281060696, 39.622138291597366, 40.84145866334438, 42.29412451386452, 49.412643536925316, 53.6192724108696, 55.8985611051321, 53.71888026595116, 54.54769939184189, 47.969978749752045, 41.920828744769096, 57.685536816716194, 48.67217347025871, 52.2031681984663, 53.33711855113506, 53.007224053144455, 53.92754606902599, 52.62404881417751, 53.19502517580986, 47.46950380504131, 38.14991109073162, 39.03271771967411, 41.106460243463516, 42.682706862688065, 43.146753162145615, 42.37308047711849, 42.39688619971275, 42.344544008374214, 41.999298334121704, 41.66484788060188, 45.54804190993309, 49.85754266381264, 50.907228738069534, 50.769778713583946, 47.14060105383396, 51.819422990083694, 49.91727165877819, 49.78747062385082, 50.18047213554382, 49.637329280376434, 50.39671093225479, 47.606452256441116, 47.18323856592178, 39.146753400564194, 31.564074084162712, 13.40895228087902, 4.786077830940485, 4.714189488440752, 2.3950048349797726, 5.471694516018033, 4.5056932512670755, 3.918947735801339, 3.575509339570999, 3.8106143614277244, 3.9997423253953457, 4.7276602406054735, 0.41745955240912735, 0.4549339727964252, 0.11025162573787384, 2.9358010785654187, 14.853458069264889, 29.37171522527933, 37.10213251411915, 19.106172770261765, 22.822086475789547, 29.80229292064905, 17.9865400493145, 3.099755155853927, 0.03082803523284383, 0.06444414859288372, 0.026910898159258068, 0.014885064847476315, 0.01568709827552084, 0.04898315673926845, 0.13199663429986686, 0.01960081404831726, 0.0933118378452491, 0.01494643118348904, 0.020300039614085108, 0.029469250039255712, 0.03610937332268804, 0.021786785910080653, 0.04952797848090995, 0.010753407204902032, 0.020186542969895527, 0.07707507902523503, 0.003906600431946572, 0.009694034997664858, 0.030361343087861314, 0.01786647058906965, 0.05954888685664628, 0.008973967142082984, 0.05645220146107022, 0.06943423082702793, 0.05379757632908877, 0.07174193902756087, 0.13764096423983574, 0.10492053406778723, 0.1346899030613713, 0.17940637859283015, 0.2133081149077043, 0.08886465147952549, 0.15015105076599866, 0.11100819334387779, 0.25044770794920623, 0.10491642256965861, 0.16547398088732734, 0.2061508724000305, 0.1961645035771653, 0.14768348395591602, 0.09643829820561223, 0.1884496706770733, 0.13564691733336076, 0.14223877689801157, 0.17993462446611375, 0.18492473638616502, 0.11897823598701507, 0.08147942862706259, 0.15652476344257593, 0.09536697834846564, 0.15519587381277233, 0.20046691177412868, 0.13661727542057633, 0.08129261521389708, 0.22118308843346313, 0.21217476634774357, 0.07965023498400114, 0.2700951474253088, 0.154110022704117, 0.23114731156965718, 0.8936996350530535, 13.064010590314865, 43.938672468066216, 45.313860476017, 36.13860301673412, 38.251916617155075, 42.894024923443794, 45.73813430964947, 21.83220349252224, 6.657503060996532, 0.7271355728153139, 1.7841920047067106, 2.831637030467391, 9.317242540419102, 17.89594531059265, 11.096164584159851, 9.071652218699455, 9.489144366234541, 7.31381144374609, 3.8614012487232685, 2.1005906956270337, 3.6476038210093975, 8.838911857455969, 16.996246688067913, 31.8952377140522, 51.35400116443634, 61.035433262586594, 59.99660320580006, 58.79581443965435, 60.49634478986263, 62.566542103886604, 56.690180227160454, 60.979181081056595, 60.333082750439644, 56.904792711138725, 54.41353239119053, 53.75015638768673, 59.479671344161034, 58.84292431175709, 54.39891077578068, 52.19575099647045, 49.15190912783146, 57.483000084757805, 56.79649472236633, 57.342897802591324, 49.20289859175682, 41.37592278420925, 41.06096148490906, 43.37488532066345, 43.85494016110897, 52.48869247734547, 57.838691398501396, 58.648891523480415, 55.2200923115015, 55.565155595541, 49.78210151195526, 44.55780744552612, 58.28734092414379, 45.70556625723839, 53.926672115921974, 54.49235916137695, 54.58797723054886, 55.74262507259846, 55.597849041223526, 55.89956805109978, 51.187072321772575, 39.68199647963047, 39.594285786151886, 42.858945205807686, 43.168928772211075, 44.75480407476425, 44.64888475835323, 44.146981090307236, 44.13862533867359, 44.315783232450485, 44.296643659472466, 49.039887338876724, 51.952906027436256, 51.409041211009026, 53.821991533041, 47.25870631635189, 53.00466299057007, 53.05532567203045, 52.15550735592842, 50.75992204248905, 52.246235087513924, 50.67127279937267, 48.4929408878088, 46.0497821867466, 40.593362376093864, 30.98923522979021, 13.926327768713236, 4.713399605825543, 6.6600503493100405, 4.513982031494379, 10.593458209186792, 6.813854221254587, 8.740862868726254, 7.21146441064775, 7.900236351415515, 9.135587587952614, 10.074662547558546, 4.28085551597178, 0.7799103471916169, 0.7574729074258357, 4.084404157474637, 16.59782476723194, 32.2914082556963, 42.96157009899616, 24.11064103245735, 31.633604653179646, 35.60188561677933, 20.155013389885426, 2.600254383869469, 0.13184228242607787, 0.12504768295912072, 0.08667399481055327, 0.07260940576088615, 0.187813397787977, 0.14994259632658213, 0.2231763189774938, 0.11147656274260953, 0.14164125896058977, 0.07821887702448294, 0.15648027911083773, 0.17049539659637958, 0.07444546426995657, 0.13667784951394424, 0.09075292749912478, 0.08337488863617182, 0.13404552591964602, 0.17165589291835204, 0.08777762777754106, 0.10899424945819192, 0.10543377371504903, 0.09077347756829113, 0.13790182914817706, 0.09599018201697618, 0.16579150134930387, 0.2183740891632624, 0.1307606912450865, 0.1827263316954486], [0.01727404749544803, 0.01209969277624623, 0.04551213947706856, 0.05859449607669376, 0.07076927286107093, 0.01609645023563644, 0.06397445817128755, 0.018478080055501778, 0.05662448733346537, 0.04952492083248217, 0.03887323517119512, 0.05204170316574164, 0.05078477588540409, 0.04611041069438215, 0.029401772117125802, 0.02968654160213191, 0.06218831280421, 0.020353181098471396, 0.022155826263769995, 0.0377992658468429, 0.03403113347303588, 0.028289372530707624, 0.024709929348318838, 0.07830315531464294, 0.02966666317661293, 0.042692037677625194, 0.022097575092629995, 0.0590756786550628, 0.05288910222589038, 0.049771176563808694, 0.0409513822523877, 0.050266274411114864, 0.033651832927716896, 0.019831685058306903, 0.021652523973898496, 0.7552121474873275, 9.600807074457407, 37.379099652171135, 30.702115036547184, 25.267549753189087, 30.145439207553864, 38.263502195477486, 40.598036125302315, 17.713931277394295, 4.972221767529845, 0.3603622131049633, 0.4445520095760003, 2.944703050889075, 2.8583823703229427, 4.26116687245667, 3.477145442739129, 1.8946106359362602, 7.611978119239211, 6.768384911119938, 2.740517444908619, 1.2774838507175446, 1.425291288178414, 4.862698819488287, 15.101949535310268, 30.520914159715176, 44.91506427526474, 50.58620676398277, 54.0320860594511, 54.45704385638237, 53.81554327905178, 55.965346321463585, 55.054576992988586, 55.00025510787964, 54.360380843281746, 52.56995111703873, 51.57375857234001, 55.48839971423149, 54.16083835065365, 53.9370683580637, 48.26073534786701, 54.55658331513405, 54.90871421992779, 53.86646814644337, 50.81699497997761, 43.167549446225166, 39.32798467576504, 41.9283789396286, 41.31895624101162, 47.41506792604923, 49.79240655899048, 51.890391781926155, 52.73588441312313, 52.47946657240391, 50.19424259662628, 52.52589628100395, 36.233609318733215, 57.30224758386612, 50.80234296619892, 48.4305140376091, 55.0886345654726, 51.34205840528011, 53.72789718210697, 50.80458104610443, 50.11599339544773, 47.02316835522652, 37.134920954704285, 36.639043763279915, 36.69222570955753, 39.50486898422241, 39.12906534969807, 40.74874363839626, 40.14838345348835, 42.01851770281792, 42.92872466146946, 43.794823586940765, 45.72381287813187, 48.40612694621086, 47.21122786402702, 51.12453147768974, 47.58243754506111, 47.9445581138134, 48.757668882608414, 47.807085290551186, 50.38775861263275, 49.32278975844383, 48.8957192748785, 44.77677449584007, 33.83878022432327, 26.50146894156933, 12.312405221164227, 4.248862182721496, 0.860245042713359, 1.4465025812387466, 2.3858793871477246, 2.938851364888251, 4.3912139441818, 2.6145245181396604, 2.348364475183189, 1.8444564146921039, 1.7652015737257898, 3.5849886434152722, 0.47129693382885307, 0.18541244615335017, 1.5343072009272873, 12.495819479227066, 27.320440895855427, 27.59819269180298, 38.77470776438713, 26.88672076910734, 19.330309443175793, 21.185996867716312, 6.239151684567332, 0.1744242521817796, 0.10135383912711404, 0.04048471979331225, 0.052040530572412536, 0.04702536745753605, 0.06178285155328922, 0.019840950772049837, 0.02668725010153139, 0.02422741090413183, 0.008769085216044914, 0.01156703483502497, 0.011242141135880956, 0.04192457163298968, 0.05965237563941628, 0.06746912767994218, 0.029115271572663914, 0.05009183631045744, 0.03157750048558228, 0.01692324356554309, 0.055608090115129016, 0.14183540479280055, 0.04473113665881101, 0.0012355724447843386, 0.008103491927613504, 0.05425341456430033, 0.03794430005655158, 0.029182229991420172, 0.009330520861112745, 0.08531682193279266, 0.09186482799123041, 0.035408470503170975, 0.032706667043385096, 0.01144547753938241, 0.06228946382179856, 0.041898882191162556, 0.05530140500923153, 0.034297401216463186, 0.030616973999713082, 0.05042946526373271, 0.025831475904851686, 0.03665461808850523, 0.03753195909666829, 0.021938761055935174, 0.06449546810472384, 0.02974768529384164, 0.05866641760803759, 0.030757603562960867, 0.02677613156265579, 0.01611105941265123, 0.007894379759818548, 0.04150107619352639, 0.010693590102164308, 0.07137952605262399, 0.04526592085312586, 0.03737066814210266, 0.04840016263187863, 0.08489833227940835, 0.058812750576180406, 0.06524756798171438, 0.037704159622080624, 0.018231809481221717, 0.04434524955286179, 0.022035383117327, 0.014795039551245281, 1.6388476663269103, 15.97039483487606, 42.727229073643684, 34.43991556763649, 24.904125854372978, 30.61669372022152, 45.68359583616257, 43.00615310668945, 17.596726566553116, 3.593222564086318, 0.33387902949471027, 0.08560070826206356, 0.7200135081075132, 3.413763656280935, 5.144203864037991, 4.906593589112163, 6.450505843386054, 6.458294475451112, 9.38105821609497, 5.015471046790481, 2.015126394107938, 2.480473886243999, 6.387995397672057, 18.43136887997389, 33.36377911269665, 47.30189099907875, 53.248571902513504, 56.648652255535126, 55.79165004193783, 54.80568274855614, 57.47951187193394, 57.06659942865372, 56.640805676579475, 56.313096061348915, 53.89009527862072, 53.45824085175991, 57.10473418235779, 55.98062910139561, 53.4597759693861, 48.714450001716614, 52.65030540525913, 54.734387174248695, 55.79517625272274, 52.824229672551155, 45.55901952087879, 41.602052450180054, 43.24875108897686, 43.01938399672508, 49.76054526865482, 52.32864886522293, 54.86506596207619, 56.861934810876846, 54.24034908413887, 51.39826498925686, 52.873323038220406, 39.78387661278248, 55.829439014196396, 52.99314960837364, 49.95324432849884, 53.18332940340042, 51.69535584747791, 55.34689150750637, 53.15942868590355, 53.037888407707214, 47.20264032483101, 39.81598109006882, 37.94742375612259, 38.69580879807472, 42.0303350687027, 41.397201642394066, 42.02741302549839, 42.787273451685905, 42.95873545110226, 44.896768257021904, 45.12987054884434, 47.435830011963844, 49.42699916660786, 49.595311135053635, 52.91026845574379, 47.2640336304903, 49.329617992043495, 50.150305554270744, 49.36367556452751, 50.91679662466049, 50.04494860768318, 49.894225895404816, 47.39873260259628, 37.88641422986984, 29.482226595282555, 16.54439203441143, 4.912177864462137, 2.8352850722149014, 3.0765441013500094, 4.10522086545825, 4.639706835150719, 5.646703625097871, 3.489882596768439, 5.215499438345432, 4.600663930177689, 3.297504619695246, 1.5449144504964352, 0.09856262171524577, 0.13890202157199383, 1.8217534641735256, 12.617380656301975, 28.743781819939613, 30.925033874809742, 40.24676017463207, 26.76374226808548, 21.52979101985693, 25.22658795118332, 8.94956286996603, 0.2413192024687305, 0.08301164445583709, 0.03719946580531541, 0.024329999832843896, 0.04933456737489905, 0.03492860894766636, 0.0541676594002638, 0.013511221477529034, 0.02317399350431515, 0.024146785835910123, 0.0618530809879303, 0.055738670998835005, 0.08478690622723661, 0.025566416006768122, 0.04207720914564561, 0.038603779903496616, 0.08125254666083492, 0.016758629644755274, 0.010724700005084742, 0.04679364668845665, 0.09265612810850143, 0.004177555765636498, 0.009452792473894078, 0.047976852729334496, 0.03513104828016367, 0.03800508566200733, 0.10492218905710615, 0.02842921170667978, 0.053915151074761525, 0.1583133838721551, 0.09590664587449282, 0.10920306012849323, 0.1398614255595021, 0.2150783597608097, 0.14005257311509922, 0.11207651492441073, 0.09777743689483032, 0.12524766207206994, 0.09301137935835868, 0.15214790299069136, 0.1183710181794595, 0.10236621019430459, 0.11607428634306416, 0.15649801644030958, 0.23869841184932739, 0.15400532050989568, 0.08482587640173733, 0.21321021078620106, 0.10281002192641608, 0.0961358062340878, 0.11730847050785087, 0.09924141224473715, 0.19922562525607646, 0.13161548209609464, 0.09250447023077868, 0.12398813356412575, 0.20443130139028654, 0.13687580998521298, 0.1785885912249796, 0.2072678491822444, 0.12039654699037783, 0.0913932673574891, 0.15507600212004036, 0.16421921696746722, 2.1297783544287086, 17.44757317006588, 52.894442304968834, 43.53756979107857, 33.55454407632351, 36.92090883851051, 47.79851675033569, 48.57874408364296, 20.634758546948433, 5.601144544780254, 0.9150206472259015, 1.040934668853879, 6.158946063369513, 7.312540886923671, 10.269822925329208, 11.286575216799974, 9.16365098208189, 13.323131036013365, 11.679264195263386, 4.5979575254023075, 2.4228098429739475, 2.285358631052077, 6.415024297311902, 17.20317218452692, 32.79474064707756, 46.16073623299599, 52.152148336172104, 57.021799832582474, 56.37495294213295, 55.85183501243591, 59.8160444945097, 59.14075993001461, 56.97805657982826, 57.9208467900753, 56.32133021950722, 55.90474337339401, 58.1004099547863, 56.14647500216961, 53.98774243891239, 49.423028379678726, 54.1487056016922, 57.212264612317085, 57.81377233564854, 55.70071332156658, 47.5451235473156, 44.38778556883335, 44.87299293279648, 44.63585905730724, 51.95338860154152, 55.020694211125374, 56.071584820747375, 57.83221274614334, 55.74847675859928, 50.68834528326988, 53.924871012568474, 42.772807627916336, 57.260267436504364, 51.333372071385384, 49.303866773843765, 57.40562103688717, 52.865552455186844, 57.18392953276634, 55.20180009305477, 54.93601195514202, 49.208552688360214, 42.2030396014452, 40.45192636549473, 40.01183778047562, 43.96885044872761, 42.813788428902626, 45.03202959895134, 44.81687754392624, 44.74478781223297, 47.806921899318695, 46.80936902761459, 50.40986202657223, 50.7893742620945, 50.337665900588036, 52.3563227802515, 47.19625286757946, 48.76006655395031, 49.59175452589989, 50.605939105153084, 51.06271639466286, 51.504568085074425, 47.79806077480316, 48.045226112008095, 41.22723676264286, 32.50980153679848, 15.88258059695363, 5.086764246225357, 2.3949787113815546, 4.430148554965854, 6.320230308920145, 8.892236296087503, 11.51348764076829, 6.34230712428689, 9.040317200124264, 8.346743267029524, 5.6513099279254675, 7.518179202452302, 1.3480645883828402, 0.39717529085464776, 2.10874458309263, 15.806109700351954, 31.81636344641447, 35.859542191028595, 47.79714122414589, 32.55660742521286, 29.267215132713318, 29.00443833321333, 8.48889933899045, 0.21269719378324226, 0.22121126035926864, 0.09392602441948839, 0.24321041739312932, 0.15172628889558837, 0.183611654501874, 0.07802203719620593, 0.10980757651850581, 0.14779250544961542, 0.07109808138920926, 0.21188256796449423, 0.15197060391074046, 0.1557942377985455, 0.22364387201378122, 0.2134441802627407, 0.13951387780252844, 0.10440552810905501, 0.10795125737786293, 0.09737551197758876, 0.15399853728013113, 0.3430201217997819, 0.1355707729817368, 0.07216849582619034, 0.11403441923903301, 0.1064411352854222, 0.12894719402538612, 0.15420820884173736, 0.06644207693170756, 0.16933812119532377], [0.02677229651453672, 0.009650068313931115, 0.010881082580453949, 0.04817745153559372, 0.03363705676747486, 0.024682649855094496, 0.008923357308958657, 0.026861638107220642, 0.022389999830920715, 0.07930823849164881, 0.023781144518579822, 0.030526867994922213, 0.004235802762195817, 0.0470196677633794, 0.04026561182399746, 0.015448861449840479, 0.025843417060968932, 0.07814639146090485, 0.04531814578513149, 0.030388620725716464, 0.011266230321780313, 0.08056091697653756, 0.07429917954141274, 0.030845427463646047, 0.0571347101504216, 0.02571923534560483, 0.02585266607638914, 0.010337984476791462, 0.030636579685960896, 0.08735736439120956, 0.020578014737111516, 0.05696217194781639, 0.02238954712083796, 0.0035217806271248264, 0.08579715475207195, 0.07367680707830004, 0.8306353690568358, 15.201936420053244, 34.57749478518963, 21.122215390205383, 28.55716623365879, 17.1875911206007, 40.83822503685951, 38.84181596338749, 17.76279855519533, 3.327176277525723, 0.5442279938142747, 0.4538259463151917, 1.8975346977822483, 2.869571107439697, 3.459576847963035, 4.612810453400016, 8.11672355979681, 9.757589511573315, 6.862130155786872, 2.281287149526179, 0.9744236909318715, 0.47599472862202674, 4.048579204827547, 15.762512739747763, 28.740681186318398, 41.099814400076866, 50.53200647234917, 51.813145726919174, 54.48034040629864, 56.86636157333851, 54.53191503882408, 56.58190503716469, 55.46477258205414, 56.70520082116127, 54.5383632928133, 56.79234154522419, 54.35248106718063, 50.403934344649315, 54.03569966554642, 57.21562743186951, 53.32611434161663, 52.97603152692318, 47.3868278414011, 40.26371866464615, 40.905166044831276, 42.279613092541695, 46.08752176165581, 49.83157105743885, 49.93611104786396, 54.080434665083885, 53.871757462620735, 52.22279034554958, 51.387644559144974, 53.177261129021645, 37.76176191866398, 51.84312991797924, 54.70760241150856, 52.21898674964905, 56.882392913103104, 51.958522126078606, 52.67344616353512, 50.838817209005356, 51.569791585206985, 43.91189530491829, 38.28332953155041, 37.440291568636894, 39.99132268130779, 37.91181206703186, 39.00551117956638, 39.88278150558472, 41.73339240252972, 42.7633423358202, 45.98710834980011, 46.68463312089443, 47.024958059191704, 50.439975410699844, 50.53391017019749, 49.30463433265686, 48.96435499191284, 48.521758541464806, 49.694466814398766, 47.350763976573944, 47.14120142161846, 45.279343128204346, 38.90895076096058, 33.91669504344463, 28.13361246138811, 16.012903153896332, 8.00314860418439, 1.1969401664100587, 1.0173654835671186, 1.7236858326941729, 3.275340171530843, 2.9659883212298155, 4.61310351267457, 2.72307091858238, 2.931303782388568, 2.765390435233712, 3.9880000054836273, 1.6827313927933574, 0.09296220465330407, 1.6571574588306248, 8.15017031505704, 21.830166801810265, 27.562201023101807, 18.91466874629259, 44.272039979696274, 37.95993268489838, 26.45517222583294, 12.729408144950867, 0.5495705071371049, 0.060191171141923405, 0.013187863096391084, 0.0687601009849459, 0.006301920557234553, 0.012086171773262322, 0.08551504215574823, 0.057404317558393814, 0.08324751383042894, 0.015221970206766855, 0.047111018720897846, 0.057682010665303096, 0.0752416106115561, 0.04544774332316592, 0.016162813080882188, 0.005235444605204975, 0.03630640982009936, 0.06866039344458841, 0.010000735874200473, 0.11283177635050379, 0.032040211008279584, 0.03535957781423349, 0.033729520946508273, 0.13598075020126998, 0.00730649582692422, 0.0806446757633239, 0.05964995623799041, 0.09991149738198146, 0.03914817119948566, 0.06598219770239666, 0.05287936895911116, 0.031144665117608383, 0.03651225932117086, 0.0676243998168502, 0.04139830358326435, 0.06784696248359978, 0.006540209797094576, 0.01737430979119381, 0.008211976291931933, 0.05785830784589052, 0.029234169196570292, 0.014310729748103768, 0.009492441713518929, 0.030488450720440596, 0.018700468317547347, 0.03613645429140888, 0.031160320722847246, 0.04102361548575573, 0.06074344404623844, 0.032904360341490246, 0.09571856338880025, 0.08162091908161528, 0.0491816701105563, 0.032397302784374915, 0.022960605638218112, 0.016052550345193595, 0.041196357778972015, 0.05540918340557255, 0.016349771212844644, 0.044057838022126816, 0.08789267551037483, 0.024214393633883446, 0.07115880391211249, 0.08861045105732046, 0.0833171940757893, 0.048516831957385875, 2.2762745060026646, 23.1618794426322, 39.82730448246002, 22.31877688318491, 25.35938322544098, 28.537650480866432, 49.14040334522724, 39.92081746459007, 17.181095369160175, 3.1634311890229583, 0.6160481774713844, 0.1693396648624912, 1.556816955562681, 2.0435887668281794, 5.0948677863925695, 5.696707516908646, 10.251658000051975, 13.940762244164944, 10.205242540687323, 4.216463221237063, 1.7483737017028034, 1.9058143347501755, 6.253532487899065, 17.95970778912306, 31.65999423712492, 44.279654771089554, 51.09689936041832, 53.869492784142494, 54.432257786393166, 58.41745734214783, 56.394955068826675, 58.90460640192032, 56.77472949028015, 57.155959233641624, 55.876643881201744, 57.745091021060944, 54.662278443574905, 50.29795043170452, 54.085777178406715, 56.67172081768513, 55.596545711159706, 55.36688983440399, 49.083167016506195, 42.15284809470177, 43.10002326965332, 43.35695028305054, 48.01840715110302, 51.005814447999, 52.585496082901955, 55.720704048871994, 57.32819639146328, 52.454106733202934, 52.633662298321724, 51.48131713271141, 40.814525708556175, 51.33101999759674, 56.887986212968826, 52.47368708252907, 57.038598731160164, 54.56506825983524, 55.72931058704853, 53.57662349939346, 53.11879366636276, 46.74511447548866, 39.16696071624756, 39.32630896568298, 40.51650770008564, 39.40524213016033, 41.868543550372124, 41.886003613471985, 44.56857606768608, 44.192901626229286, 47.327011451125145, 48.03294897079468, 49.49887990951538, 50.9655100107193, 53.012840151786804, 51.06522046029568, 50.44888213276863, 48.882875964045525, 50.07874399423599, 48.323329389095306, 50.01258194446564, 48.48132111132145, 42.354533672332764, 37.46337532997131, 32.40308806300163, 19.740315042436123, 10.666727777570486, 2.9507646756246686, 1.4961014385335147, 3.0475528445094824, 4.435450220480561, 4.154096692800522, 4.806617628782988, 4.866701429709792, 4.56760142929852, 2.516321875154972, 2.5121378246694803, 0.7029024325311184, 0.07652363361557946, 1.5339716314338148, 9.71851335838437, 25.737573131918907, 36.52025453746319, 22.393334582448006, 47.44681902229786, 39.584904089570045, 28.9199897646904, 15.91392321512103, 1.2999679567292333, 0.03536623116815463, 0.039985091134440154, 0.018068106546706986, 0.021630365299643017, 0.018719650979619473, 0.0507179343549069, 0.04710173074272461, 0.12357596700894646, 0.04605840098520275, 0.08005737719940953, 0.011706635596056003, 0.036261565546737984, 0.016957263615040574, 0.010574507869023364, 0.023618673549208324, 0.02001036082219798, 0.08756066090427339, 0.06857116502942517, 0.011658326420729281, 0.06554848660016432, 0.08628712806967087, 0.04464180063223466, 0.030618948112532962, 0.03001084714924218, 0.041061724768951535, 0.04394536554173101, 0.02442615805193782, 0.033957994819502346, 0.02142697230738122, 0.19208511075703427, 0.14297721383627504, 0.10195995113463141, 0.19440681586274877, 0.12951183482073247, 0.10517706483369693, 0.08756232331506908, 0.13941809622338042, 0.1592327415710315, 0.13154338987078518, 0.07867796957725659, 0.08838002162519842, 0.09060682830750011, 0.14970463409554213, 0.14248610503273085, 0.0733985536498949, 0.10574618077953346, 0.2078170087770559, 0.1700796899967827, 0.06459930940764025, 0.35890810831915587, 0.22219873237190768, 0.12239889110787772, 0.12020388545352034, 0.13001232437090948, 0.09905821309075691, 0.19394864357309416, 0.10109091104823165, 0.194636317610275, 0.1482992884120904, 0.19309278402943164, 0.11617619806202129, 0.13783534755930305, 0.19125693332171068, 0.21341879881219938, 0.24554876144975424, 3.6732039973139763, 28.07648252695799, 47.0052333176136, 29.976756758987904, 36.11959643661976, 27.178254425525665, 49.43773739039898, 46.00670009851456, 20.417875684797764, 4.478369392454624, 1.1173672112636268, 1.2847378989681602, 4.7151736356318, 8.399562332779169, 9.47886211797595, 11.070572007447481, 14.963937141001225, 17.466967329382896, 13.28540001064539, 5.573827335610986, 2.7748079923912883, 1.1164577538147569, 5.171881103888154, 18.246024325489998, 32.43912152945995, 45.20368158817291, 51.61086358129978, 53.04438225924969, 56.39261819422245, 59.79358769953251, 56.83700434863567, 60.80291993916035, 59.46247346699238, 59.99963164329529, 58.159489184617996, 60.97308240830898, 54.11438204348087, 50.93907482922077, 54.409120827913284, 59.20770853757858, 57.9783871024847, 55.67418314516544, 51.50923803448677, 44.22483131289482, 44.677691012620926, 46.00660130381584, 50.92755384743214, 53.72167691588402, 53.31668324768543, 58.77720303833485, 58.16860109567642, 52.8121767193079, 51.70059196650982, 52.94502139091492, 44.096060022711754, 52.89267539978027, 54.57050196826458, 53.70078943669796, 61.44703097641468, 56.71159207820892, 58.78463163971901, 53.485367596149445, 55.73390834033489, 47.64608412981033, 41.930081248283386, 40.61930738389492, 43.74791510403156, 40.49361392855644, 43.81274342536926, 43.16133677959442, 46.52504548430443, 46.05064854025841, 49.995866641402245, 50.83643473684788, 50.96008010208607, 53.56547109782696, 55.262456238269806, 51.209426522254944, 49.57558639347553, 48.562275767326355, 49.57848943769932, 47.75490269064903, 50.25750160217285, 50.48709288239479, 47.16364301741123, 42.0854777097702, 35.01324400305748, 18.57099238783121, 9.843986425548792, 2.046683938242495, 2.6884576259180903, 5.373104056343436, 8.137553092092276, 6.691153105348349, 9.396668728441, 7.758809365332127, 9.028652776032686, 7.985258214175701, 6.895693279802799, 3.2648855075240135, 0.4090970620745793, 2.699894062243402, 11.491071693599224, 26.55512586236, 36.84987545013428, 28.136036731302738, 53.58181782066822, 44.82000857591629, 36.93781793117523, 17.428412698209286, 1.1761494632810354, 0.11820195693871938, 0.15773597813677043, 0.1547221015789546, 0.0969303198507987, 0.1681265205843374, 0.1367078916518949, 0.17992583743762225, 0.24329839157871902, 0.11825687586679123, 0.17317443096544594, 0.10909639866440557, 0.13827981980284676, 0.1297498564235866, 0.14542741439072415, 0.043407735211076215, 0.10238321279757656, 0.30096299888100475, 0.11084583369665779, 0.27361064159777015, 0.1355360256275162, 0.1181971478217747, 0.0883784556936007, 0.21058397280285135, 0.0846374079992529, 0.11844178196042776, 0.24491851479979232, 0.1465868717059493, 0.15598231286276132, 0.13921814679633826], [0.013405957106442656, 0.013390210588113405, 0.010203832007391611, 0.06863668182631955, 0.027592976402956992, 0.01081696380424546, 0.0123720767442137, 0.03819020697847009, 0.041780624669627286, 0.08099236452835612, 0.11160609719809145, 0.04905142690404318, 0.03504133004753385, 0.03318251729069743, 0.04570995151880197, 0.058210182323819026, 0.020624317330657504, 0.035001517535420135, 0.03106234424194554, 0.010637106170179322, 0.04464804951567203, 0.039554638060508296, 0.047729561701999046, 0.06673908443190157, 0.04635208366380539, 0.05087631237984169, 0.016422876469732728, 0.06478310970123857, 0.037687773001380265, 0.03595021604269277, 0.07888599357102066, 0.048586007542326115, 0.029835707719030324, 0.018985200695169624, 0.004715749664683244, 0.06114857875218149, 0.08750224646064453, 2.7687352057546377, 21.53104305267334, 33.75089854001999, 31.16556666791439, 14.971471186727285, 18.84358786046505, 51.02176979184151, 34.027067720890045, 16.913044452667236, 3.4193374821916223, 0.5857629119418561, 1.4879359141923487, 2.6327226916328073, 2.6427919138222933, 6.07110190205276, 6.654571518301964, 10.860961955040693, 10.33948838710785, 4.447911651805043, 1.2129831430502236, 0.8677783759776503, 0.7687118137255311, 4.292245404794812, 14.2413498647511, 25.19073497503996, 36.73588156700134, 49.81903932988644, 52.817146852612495, 55.59881418943405, 54.2926836758852, 56.96476489305496, 56.83607339859009, 57.34229363501072, 58.33238370716572, 56.63134038448334, 52.245224341750145, 56.549359783530235, 56.29578039050102, 56.815250515937805, 52.86445811390877, 50.80278754234314, 43.08150686323643, 40.627689734101295, 42.766161784529686, 45.948791205883026, 48.73726397752762, 53.04330311715603, 52.99224905669689, 53.26651833951473, 54.235432147979736, 55.23836553096771, 52.1620924025774, 55.432056337594986, 39.987199902534485, 50.63290245831013, 58.59610475599766, 52.81429320573807, 53.730310052633286, 50.70434242486954, 49.63908478617668, 48.3451060205698, 46.24127671122551, 40.384179800748825, 40.51762104034424, 38.957876935601234, 37.53478869795799, 38.87359745800495, 40.78438952565193, 40.69007858633995, 44.2000338435173, 45.32052531838417, 48.73863570392132, 49.460414573550224, 48.288709446787834, 54.46570739150047, 51.13347239792347, 48.96258808672428, 51.99561193585396, 49.717850759625435, 48.899245485663414, 44.31886866688728, 42.332977429032326, 38.82208362221718, 36.96614161133766, 29.309949539601803, 19.466513134539127, 8.311875388026237, 2.618908532895148, 1.0377886751666665, 1.4280983875505626, 2.4739869218319654, 3.1295032845810056, 3.695145919919014, 2.565743923187256, 3.899813387542963, 2.780985035933554, 3.6555736558511853, 3.9868462923914194, 0.19530043588019907, 1.19824409019202, 6.707287039607763, 19.568239375948906, 23.512653820216656, 21.988783590495586, 17.124163024127483, 25.554867535829544, 38.30573692917824, 14.902398493140936, 3.3014870434999466, 0.02917332050856203, 0.07575813797302544, 0.11339447271893732, 0.016339216017513536, 0.045935041198390536, 0.04219067981466651, 0.04590014541463461, 0.04949643349391408, 0.0382634829293238, 0.021383907333074603, 0.08311401630635373, 0.02285927093907958, 0.03655610540590715, 0.009283551262342371, 0.0307086848988547, 0.006647580476055737, 0.005919804489167291, 0.06266144308028743, 0.022517690049426164, 0.029871707447455265, 0.03673578677990008, 0.038518102664966136, 0.020206736808177084, 0.07451029086951166, 0.09412709448952228, 0.02191217732615769, 0.02676979362149723, 0.046668787763337605, 0.032081296303658746, 0.0362040416803211, 0.06230956860235892, 0.025219395174644887, 0.033898411493282765, 0.065960831270786, 0.053008120448794216, 0.04503227421082556, 0.03997744330263231, 0.03372205865161959, 0.03238874582166318, 0.034731446285150014, 0.01744692894135369, 0.04890069300017785, 0.03039702740352368, 0.01551842851768015, 0.05561836143897381, 0.06985067957430147, 0.06643406173679978, 0.03818045515799895, 0.0429135984450113, 0.022960026763030328, 0.05563878163229674, 0.010408460675535025, 0.015289762613974744, 0.05747114053519908, 0.04571869401843287, 0.045522050859290175, 0.042507933103479445, 0.02022582855715882, 0.011510363510751631, 0.0295759504660964, 0.022476276353700086, 0.020892830070806667, 0.0195162834279472, 0.09853726252913475, 0.05953092688287143, 0.06690447946311906, 0.21507545054191723, 5.243056509643793, 30.429834946990013, 35.919833555817604, 29.827282279729843, 14.575203750282526, 28.130981102585793, 57.28466972708702, 33.28703463077545, 16.297517381608486, 3.8293340569362044, 0.4604133975226432, 0.35745156928896904, 0.40099521400406957, 2.9657990438863635, 4.922182252630591, 9.517362602055073, 15.159145966172218, 11.149244885891676, 7.13463538326323, 2.225859761238098, 1.812863009981811, 1.3886493793688715, 6.155276410281658, 16.932681798934937, 29.084678627550602, 41.091211661696434, 52.090348452329636, 53.52703236043453, 59.295708015561104, 57.17656172811985, 59.37432959675789, 57.98911012709141, 58.722611367702484, 59.777275174856186, 57.483395263552666, 53.137515261769295, 55.098103657364845, 57.8699067234993, 58.907612040638924, 54.04141075909138, 51.53971619904041, 44.604921117424965, 41.68238013982773, 44.0406209975481, 48.68981592357159, 50.56124970316887, 54.55367647111416, 55.045529678463936, 55.113728418946266, 54.4568994641304, 56.93390674889088, 53.471946716308594, 54.67785380780697, 42.26201243698597, 49.81681264936924, 58.01789738237858, 55.62898837029934, 55.47294594347477, 52.30208449065685, 52.510617300868034, 50.62931165099144, 47.48135156929493, 43.8926113396883, 41.772845685482025, 41.283374950289726, 38.921474888920784, 41.18003949522972, 43.23042467236519, 42.826118767261505, 45.2089861035347, 46.41323268413544, 50.83078823983669, 51.93407043814659, 50.377624556422234, 55.77720321714878, 54.00206387042999, 49.981511011719704, 50.02025753259659, 50.54293468594551, 49.67742472887039, 45.384396091103554, 44.6714099496603, 42.24515654146671, 43.882796466350555, 34.18908342719078, 22.04002194106579, 11.674952376633883, 3.824111237190664, 2.8442136431112885, 1.6866818745620549, 3.0632737884297967, 3.9872091729193926, 4.421485494822264, 4.7240727581083775, 6.455431804060936, 6.448751287534833, 4.350217944011092, 3.0116580706089735, 0.09198748273774981, 0.8270461647771299, 7.216250253841281, 22.377854213118553, 27.435071244835854, 25.444992631673813, 20.698446929454803, 33.01645115017891, 43.61976318061352, 21.141607649624348, 5.408502006903291, 0.04499536720686592, 0.06499644005089067, 0.07086307290592231, 0.0614904268149985, 0.038633443546132185, 0.09136041990132071, 0.011750760913855629, 0.07100578790414147, 0.07443263253662735, 0.020970356672478374, 0.06045955029549077, 0.046871520244167186, 0.039797327772248536, 0.008420982703682967, 0.10035825544036925, 0.012124046352255391, 0.0034094679404006456, 0.03934358239348512, 0.01602656218892662, 0.023102964405552484, 0.04557065411063377, 0.05132015379786026, 0.022092788240115624, 0.05883010569959879, 0.055095158459153026, 0.030915896240912843, 0.018940169029519893, 0.020270080967748072, 0.012357180912658805, 0.07335311194765382, 0.133696909470018, 0.1556626847013831, 0.08830863444018178, 0.20701491041108966, 0.1521453054738231, 0.1597983471583575, 0.1054845737235155, 0.14000878640217707, 0.16200070007471368, 0.2527476829709485, 0.2771152707282454, 0.16739967599278316, 0.169520748895593, 0.08407564673689194, 0.1238238814403303, 0.14107048802543432, 0.2267774718347937, 0.09997397137340158, 0.1142887829337269, 0.09944602978066541, 0.3215423977235332, 0.11423088057199493, 0.15653675654903054, 0.11153174142236821, 0.15752007253468037, 0.10848858713870868, 0.2644502237671986, 0.14977966522565112, 0.11188504082383588, 0.12395570171065629, 0.19326732232002541, 0.19962484133429825, 0.1008437313430477, 0.1269582234090194, 0.11699005946866237, 0.15782239381223917, 0.29072085628286004, 7.274579023942351, 36.50506295263767, 44.44618843495846, 42.296970561146736, 20.960144586861134, 28.342916630208492, 61.13154910504818, 37.28052534162998, 20.874582678079605, 4.986662417650223, 1.1830078577622771, 2.655498431995511, 6.9614060036838055, 6.511927172541618, 15.873885713517666, 11.382329128682613, 16.93303517997265, 18.200434371829033, 10.454709604382515, 4.013831494376063, 2.0350541872903705, 1.5652441908605397, 5.529767274856567, 17.067437767982483, 28.358927071094513, 41.169631853699684, 51.228714287281036, 55.22938281297684, 59.0345024317503, 57.942441031336784, 59.96049374341965, 58.75802546739578, 59.876814633607864, 62.739546820521355, 57.354741767048836, 53.79936754703522, 55.71571871638298, 58.79870228469372, 60.7305908203125, 56.53331324458122, 55.08634328842163, 46.58798150718212, 43.83431486785412, 46.24266363680363, 50.912461057305336, 53.96571882069111, 58.46148177981377, 58.38255241513252, 57.147934064269066, 57.152547016739845, 59.40425679087639, 53.94085295498371, 55.53064964711666, 44.59031090140343, 51.50107227265835, 58.256421983242035, 56.1253709346056, 57.58420765399933, 56.08415834605694, 53.906358405947685, 52.37352065742016, 49.429176449775696, 44.95720401406288, 45.14421857893467, 43.34832474589348, 39.92192320525646, 44.050561264157295, 46.670110300183296, 43.41095678508282, 47.55313731729984, 49.01504427194595, 53.645707592368126, 53.84776555001736, 51.70391298830509, 57.480503618717194, 55.053076073527336, 49.719986245036125, 51.196169033646584, 51.659873351454735, 51.63627661764622, 49.55895848572254, 50.753192603588104, 46.781474724411964, 45.338699743151665, 32.56517596542835, 20.05382861942053, 10.838346518576145, 3.3043582644313574, 1.8523356481455266, 3.480371944606304, 7.385065695270896, 8.504817634820938, 7.4844474624842405, 7.664672741666436, 8.786987643688917, 10.260605569928885, 10.991281662136316, 8.293840605765581, 0.978887026431039, 1.872421014122665, 8.56488386169076, 25.38333334028721, 30.64446073025465, 31.767513267695904, 26.153439916670322, 37.061337903141975, 47.059141024947166, 24.11297980695963, 5.797029733657837, 0.28888680157251656, 0.22123926901258528, 0.158460715028923, 0.11768394528189674, 0.12289720616536215, 0.21690162364393473, 0.194593733176589, 0.10613067264785059, 0.25338892824947834, 0.20577880408382043, 0.1475640427088365, 0.09158483793726191, 0.17457633308367804, 0.1389634417137131, 0.1712334030889906, 0.1730072102509439, 0.06608942319871858, 0.2611234725918621, 0.15370529989013448, 0.12381280859699473, 0.11308631816064008, 0.21696581941796467, 0.1788229911471717, 0.16170219343621284, 0.13033852796070278, 0.11287720320979133, 0.13544107525376603, 0.18759707658318803, 0.11009357796865515, 0.1822776737390086], [0.00323412905800069, 0.04111771238967776, 0.06549472542246804, 0.0809834290703293, 0.05490066010679584, 0.01837115141825052, 0.017574580197106116, 0.04097228855243884, 0.040512828636565246, 0.05004411250411067, 0.10321435140212998, 0.017603863489057403, 0.022824801890237723, 0.07968150908709504, 0.07953132808324881, 0.007536401117249625, 0.06718992430251092, 0.007179436897786218, 0.02845090097252978, 0.03469021256023552, 0.03170801828673575, 0.046446136038866825, 0.0011166319154654047, 0.037473199554369785, 0.0451944483211264, 0.04263367889507208, 0.05825517502671573, 0.013251115415187087, 0.033658512256806716, 0.04515029053436592, 0.02294109272042988, 0.024784177512628958, 0.027404270513216034, 0.07149724551709369, 0.018842754725483246, 0.0615691946586594, 0.046703639018232934, 0.1337901529041119, 4.277864126488566, 26.889715008437634, 39.69932734966278, 33.88943910598755, 13.360230345278978, 26.609951220452785, 50.80924339592457, 27.022153101861477, 16.00087109953165, 4.141954919323325, 1.5198683319613338, 0.08101966814137995, 4.670106628909707, 1.2838696455582976, 11.150853149592876, 19.856474809348583, 10.544248949736357, 6.974644493311644, 1.609939292538911, 2.8896328434348106, 0.7025482202880085, 0.454630107851699, 2.0432422729209065, 14.363416414707899, 18.570281825959682, 32.64006994664669, 44.50166545808315, 50.92870518565178, 53.741929829120636, 58.35264042019844, 59.34491537511349, 58.88205461204052, 55.56012846529484, 57.05567501485348, 57.81308837234974, 59.22337509691715, 56.21332101523876, 54.37060609459877, 53.748146295547485, 46.60805583000183, 44.15913283824921, 44.46040727198124, 47.89266809821129, 50.01144580543041, 51.030471324920654, 52.907821387052536, 54.79720160365105, 52.23205804824829, 53.646539747714996, 55.06930500268936, 53.52506786584854, 56.65543869137764, 39.88191515207291, 47.295317351818085, 55.8531953394413, 52.44158260524273, 52.04140707850456, 50.10664589703083, 48.676531836390495, 46.65320500731468, 44.51955869793892, 43.03681366145611, 42.26839989423752, 42.45445691049099, 41.32728539407253, 40.75643062591553, 43.72308723628521, 44.85109090805054, 49.44223254919052, 48.504161685705185, 51.45180031657219, 52.23075091838837, 53.00826899707317, 50.728068351745605, 48.626359328627586, 50.230424255132675, 48.479842990636826, 47.88565747439861, 45.05562633275986, 43.12232047319412, 43.45911540091038, 38.205885887145996, 31.68077912181616, 20.64244743436575, 7.078831577673554, 2.3605012614279985, 0.9016679262276739, 2.7118817064911127, 0.520462584681809, 1.168698538094759, 2.8452091896906495, 3.7787613831460476, 4.7279860731214285, 6.881570862606168, 6.284722639247775, 1.1532740970142186, 0.9279405476991087, 1.3962392346002162, 5.390941724181175, 21.070002391934395, 26.31363172084093, 21.87822662293911, 21.460355445742607, 21.64532572031021, 26.99967160820961, 16.63032252341509, 6.678001061081886, 0.48203287180513144, 0.06251861675991677, 0.05892937166208867, 0.047869827612885274, 0.03749155286641326, 0.09368715676828288, 0.021035847494204063, 0.03727628180058673, 0.0628298734955024, 0.03504399435769301, 0.01386138716043206, 0.021034715718997177, 0.05988978868117556, 0.05770475007011555, 0.07723614733549766, 0.07574053423013538, 0.039839555975049734, 0.02987273346661823, 0.015520292236033129, 0.031353271697298624, 0.03127735370071605, 0.05763040542660747, 0.014898769532010192, 0.03490842253086157, 0.050898955305456184, 0.07523522072006017, 0.05781710009614471, 0.019233237580920104, 0.0625371556088794, 0.04415599076310173, 0.012851047722506337, 0.03456549093243666, 0.047132626350503415, 0.08135717464028858, 0.019802565038844477, 0.05541017417272087, 0.043153649821761064, 0.05206086912949104, 0.04204846947686747, 0.027938160419580527, 0.09385471887071617, 0.05856594565557316, 0.06085261768021155, 0.07503547909436747, 0.04475905996514484, 0.03218664045562036, 0.029826954087184276, 0.03578539617592469, 0.06902005305164494, 0.03794366180954967, 0.06626032496569678, 0.026842982369998936, 0.05615407702862285, 0.005665129092449206, 0.04593435842252802, 0.02870368945877999, 0.033584401389816776, 0.03445828398980666, 0.04321754131524358, 0.023039148982206825, 0.07264217900228687, 0.020215462609485257, 0.05031362714362331, 0.030482565489364788, 0.02050244926067535, 0.018446529502398334, 0.04538994857284706, 0.07824808053555898, 0.4011706280289218, 7.97404121607542, 34.68356989324093, 42.86759354174137, 27.335488088428974, 14.604819361120462, 37.64017604291439, 51.076228469610214, 29.02213018387556, 19.490776732563972, 5.584498587995768, 0.9946285129990429, 0.12192763475468382, 0.34147784986998886, 2.8962437761947513, 10.577825848013163, 22.17870879918337, 12.894628029316664, 5.880482280626893, 4.114368874579668, 3.7110867770388722, 1.9593515619635582, 1.4472615905106068, 4.38052274286747, 16.536583453416824, 21.733638681471348, 36.54297731816769, 47.56216563284397, 52.678845673799515, 57.18435510993004, 57.85267844796181, 60.00260308384895, 60.0666980445385, 57.21873186528683, 57.2139897197485, 57.53956764936447, 58.19599002599716, 58.33903335034847, 56.33249022066593, 56.25419162213802, 48.41282598674297, 45.878293588757515, 45.84937334060669, 49.83665518462658, 50.3035931289196, 53.34605187177658, 54.56220701336861, 55.768494084477425, 54.05318632721901, 56.18886552751064, 56.570205464959145, 54.83013063669205, 54.21782769262791, 42.369618862867355, 48.483992367982864, 54.03052054345608, 56.046243980526924, 53.95984813570976, 52.28003427386284, 49.21037659049034, 49.63414505124092, 45.1138012111187, 45.60955300927162, 44.0359890460968, 43.769604340195656, 41.32928028702736, 43.14013011753559, 46.05957806110382, 47.634156569838524, 49.69703547656536, 51.53911583125591, 52.86968283355236, 53.91754500567913, 54.04420740902424, 54.53459769487381, 50.070110857486725, 50.129535868763924, 49.92275856435299, 48.153436705470085, 47.32346624135971, 46.0632448643446, 45.318994000554085, 42.56357565522194, 34.275627583265305, 23.43433242291212, 9.49751341715455, 4.114307127892971, 2.4270345037803054, 3.450512196868658, 3.5359867103397846, 4.94603737257421, 4.630006905645132, 4.491004664450884, 5.65564502030611, 6.660049399361014, 4.771075285971165, 2.17833214905113, 0.30482632282655686, 0.44079220038838685, 5.344436494633555, 21.005164571106434, 28.48538428544998, 24.65445265173912, 24.86293226480484, 24.776925779879093, 29.011637046933174, 23.821514546871185, 9.007391966879368, 0.863768522394821, 0.07800663763191551, 0.032379160984419286, 0.05981631977192592, 0.07325672922888771, 0.0893489622103516, 0.034501347108744085, 0.035608620310085826, 0.08124911793856882, 0.0195383048048825, 0.04597254563122988, 0.037497642188100144, 0.007203193508757977, 0.047318797805928625, 0.11742584858438931, 0.10466794410604052, 0.0423162808874622, 0.02878497318306472, 0.017393162197549827, 0.024680230453668628, 0.050935517210746184, 0.04747697545099072, 0.045052980131004006, 0.05050832958659157, 0.044279936846578494, 0.021787637524539605, 0.04907839283987414, 0.046821117284707725, 0.018740505329333246, 0.018854996451409534, 0.04116865340620279, 0.08240412978921086, 0.10547836194746196, 0.1840495364740491, 0.12467819731682539, 0.12199373784824274, 0.07923347453470342, 0.14057966123800725, 0.12339995184447616, 0.13755776948528364, 0.183658305904828, 0.21676089760148898, 0.15473087376449257, 0.24024915910558775, 0.12462033948395401, 0.20406837633345276, 0.09046275517903268, 0.13191565114539117, 0.1388485572533682, 0.15760007605422288, 0.1395534788025543, 0.12194486742373556, 0.1616343908244744, 0.11668163773720153, 0.10179877150221728, 0.11293264906271361, 0.14955829741666093, 0.11204026101040654, 0.14289560727775097, 0.10688865775591694, 0.11033881324692629, 0.1176195713924244, 0.18101991154253483, 0.15574044693494216, 0.10276596061885357, 0.1273666272754781, 0.12910697842016816, 0.10340759181417525, 0.6648367282468826, 10.374427512288094, 40.37401534616947, 52.71938569843769, 41.50221660733223, 19.066934175789356, 39.55289460718632, 56.66442520916462, 34.6164882928133, 20.697884559631348, 5.914176972582936, 1.8222423316910863, 0.4680512548657134, 8.629220109432936, 5.283877244219184, 19.588218703866005, 31.722316592931747, 16.865108124911785, 15.593361966311932, 5.586564727127552, 7.860110029578209, 1.6655795881524682, 0.9904192888643593, 4.099777657538652, 17.23961602896452, 21.634285412728786, 34.40388970077038, 46.586362794041634, 54.853985756635666, 58.34641255438328, 60.22524073719978, 62.308509349823, 60.56228645145893, 56.512247174978256, 56.72756642103195, 57.92344965040684, 59.24875773489475, 60.425524190068245, 58.238224759697914, 58.2566499710083, 49.298258274793625, 47.919479459524155, 48.4400325268507, 52.973086684942245, 52.442452758550644, 54.32807117700577, 57.12974064052105, 58.830856159329414, 57.18847408890724, 57.31147728860378, 58.8654001057148, 55.68089738488197, 55.824370086193085, 45.08753702044487, 48.72050687670708, 55.643777176737785, 56.805800423026085, 56.23192861676216, 55.477710887789726, 51.87207296490669, 51.53445728123188, 47.00667344033718, 48.04785557091236, 46.80032931268215, 46.52881108224392, 44.98623825609684, 44.428409188985825, 48.15792426466942, 48.74535374343395, 53.840439543128014, 53.210197761654854, 54.25642602145672, 57.26576194167137, 54.90641914308071, 53.718853667378426, 50.31930148601532, 51.72269158065319, 51.69363833963871, 49.739555194973946, 49.185092747211456, 46.62751078605652, 47.58119121193886, 42.122559919953346, 32.678311094641685, 23.1075993552804, 9.83417060226202, 3.7096848897635937, 2.7945959055796266, 5.9034358989447355, 4.695153934881091, 5.82199439406395, 6.353227263316512, 6.71303185634315, 10.150464680045843, 13.196012657135725, 13.210454732179642, 3.3340624580159783, 1.6784541285596788, 1.9588288525119424, 6.85058637522161, 26.299270391464233, 32.64497168362141, 29.172850996255875, 33.24159286916256, 32.239886820316315, 36.78467474877834, 24.87988505512476, 10.870059616863728, 0.7944414205849171, 0.18275739799719304, 0.15824859437998384, 0.14941779401851818, 0.16962415975285694, 0.17831687611760572, 0.1660037852707319, 0.14753449038835242, 0.15030013339128345, 0.07248280278872699, 0.1418011769419536, 0.0833471619989723, 0.1285266486229375, 0.14294801774667576, 0.22582056146347895, 0.18260098295286298, 0.14285795070463791, 0.22605294274399057, 0.1279491389868781, 0.1955457602161914, 0.18994992220541462, 0.19961464422522113, 0.1266267357277684, 0.1671873772284016, 0.20011348620755598, 0.11531319163623266, 0.12438575402484275, 0.1460626334301196, 0.149679564347025, 0.17220861482201144, 0.10533396227401681], [0.10405064051155932, 0.051891277253162116, 0.048772086229291745, 0.06353596021654084, 0.02956021693535149, 0.002812868410728697, 0.020346091732790228, 0.0626857484166976, 0.05527911831450183, 0.030590334608859848, 0.04682471299020108, 0.01758420028636465, 0.016261823002423625, 0.020281972028897144, 0.06582048372365534, 0.04782448238984216, 0.05723517097067088, 0.01539762357424479, 0.043995512460242026, 0.02810978392517427, 0.04780930175911635, 0.060673485495499335, 0.04890394731773995, 0.07196512509835884, 0.02399149328994099, 0.018266016923007555, 0.04845524854317773, 0.014721956558787497, 0.006861608444523881, 0.026150317389692646, 0.0457424798514694, 0.02963013652333757, 0.07934490058687516, 0.03552761489117984, 0.022225003704079427, 0.04401757279993035, 0.10519900271901861, 0.11839871513075195, 0.4902840103022754, 9.017431978136301, 27.096744999289513, 39.947461634874344, 26.19070451706648, 13.697024323046207, 40.931920409202576, 36.89141482114792, 21.996481977403164, 13.450200017541647, 5.6264483369886875, 1.0719780530780554, 0.27638799569103867, 1.8625199329108, 8.884315621107817, 19.247988760471344, 13.188144229352474, 3.141299751587212, 2.8263246780261397, 2.3479419853538275, 1.5917092957533896, 1.281587511766702, 0.3795242286287248, 3.0251266853883862, 10.698315482586622, 16.806739456951618, 28.888394460082054, 42.44171239435673, 46.959358379244804, 55.874295607209206, 58.515822663903236, 59.04242120683193, 53.962732180953026, 57.98979789018631, 54.154891669750214, 57.58804924786091, 56.617189943790436, 55.50975076854229, 51.798569709062576, 48.308734372258186, 47.32055179774761, 51.169502064585686, 50.50068095326424, 53.311317935585976, 52.86081790924072, 56.17629960179329, 52.828329652547836, 53.301472663879395, 51.88899725675583, 56.23180702328682, 52.440036088228226, 55.86656682193279, 40.79806499183178, 48.77027280628681, 55.489604249596596, 53.73420484364033, 50.63085436820984, 50.75717478990555, 47.448787316679955, 47.08273395895958, 47.60416477918625, 47.61158958077431, 46.84844613075256, 44.745133593678474, 42.85283513367176, 42.28612594306469, 46.01494945585728, 47.651692628860474, 48.028856590390205, 51.89302884042263, 52.79307894408703, 54.38642464578152, 51.24328650534153, 48.12045827507973, 52.13159143924713, 50.13051241636276, 49.81807418167591, 49.581248089671135, 48.473660722374916, 45.45165628194809, 35.89404433965683, 25.983636528253555, 11.872423980385065, 6.498583713546395, 1.747091745492071, 0.854399650124833, 1.278370984364301, 3.4286094596609473, 3.152863481082022, 3.9827997470274568, 3.9954381063580513, 4.2758554592728615, 3.033693563193083, 3.51233440451324, 4.581241747364402, 1.9025459163822234, 1.2060307036153972, 3.884053733199835, 18.553899005055428, 27.361564189195633, 25.539294071495533, 17.729263454675674, 24.75400920957327, 26.768233627080917, 14.882861841470003, 6.650437815114856, 0.535185132175684, 0.05939799339103047, 0.027560707821976393, 0.026430415055074263, 0.06595331331482157, 0.016778886565589346, 0.07906327038654126, 0.035624019874376245, 0.07111393366358243, 0.00851126682391623, 0.05625822632282507, 0.0564031826070277, 0.044404780928744, 0.046337125677382573, 0.042185889251413755, 0.02437270486552734, 0.02771165694866795, 0.058792849886231124, 0.034310667106183246, 0.03853266731312033, 0.02562216057413025, 0.07164468057453632, 0.031087734969332814, 0.015892983028606977, 0.05785538007330615, 0.025313690603070427, 0.08787456710706465, 0.03554253577021882, 0.04799890193680767, 0.023378646292258054, 0.036593272161553614, 0.03011821365362266, 0.005204573117225664, 0.0741198321338743, 0.025595200204406865, 0.012035158397338819, 0.03789525893807877, 0.06837117107352242, 0.10080366278998554, 0.055030662115314044, 0.025711852831591386, 0.04874604426731821, 0.05995914980303496, 0.04399933081003837, 0.05227388035564218, 0.04839599918341264, 0.06018429885443766, 0.021538489272643346, 0.009486094495514408, 0.0714796714601107, 0.04737064053188078, 0.03461492909991648, 0.03148571166093461, 0.08147454529535025, 0.030094765497779008, 0.016788384200481232, 0.03439168736804277, 0.025803005264606327, 0.0159758623703965, 0.029708130678045563, 0.016130182702909224, 0.01950786005181726, 0.05029867657867726, 0.02344920412724605, 0.06464335587224923, 0.040795316017465666, 0.06016849110892508, 0.05664127100317273, 0.031914472638163716, 0.12297631168621592, 0.8570345712359995, 13.603750728070736, 35.002057403326035, 41.53958760201931, 20.824349373579025, 16.159094609320164, 52.16764010488987, 41.03116728365421, 25.341355092823505, 19.036518707871437, 6.81507870554924, 0.47878434299491346, 0.3031141881365329, 0.817124362802133, 6.487729120999575, 12.532637603580952, 9.447970725595951, 4.78972896002233, 4.307656902819872, 3.3269520895555615, 4.040793897584081, 1.9372553913854063, 1.2537618423812091, 4.782748259603977, 12.609916906803846, 20.169015638530254, 32.08793297410011, 45.294872894883156, 51.20577871799469, 56.595014333724976, 60.56421294808388, 60.23345209658146, 55.50048306584358, 57.76578091084957, 55.138191506266594, 59.038898795843124, 59.66000586748123, 57.99601435661316, 53.24100650846958, 48.08432221412659, 48.953920751810074, 52.81437300145626, 52.64348857104778, 55.549834817647934, 54.80094440281391, 56.738597229123116, 55.29882408678532, 54.46091204881668, 52.89435490965843, 56.13067165017128, 54.51984688639641, 56.46897129714489, 43.19325126707554, 50.21272860467434, 56.71924106776714, 54.26219791173935, 51.81122682988644, 52.11765378713608, 48.545435070991516, 49.419296979904175, 49.97038520872593, 49.524410739541054, 48.24098780751228, 45.53169138729572, 45.15155218541622, 43.06924492120743, 48.811762779951096, 48.414748683571815, 50.298364609479904, 53.62708479166031, 54.04955752193928, 55.9428059309721, 53.19666288793087, 48.85176323354244, 51.34820267558098, 50.84937684237957, 50.129152089357376, 52.15353526175022, 50.32709866762161, 47.8022937476635, 39.29952420294285, 27.903715297579765, 15.515582989901304, 8.286887928843498, 2.8936798637732863, 2.1963828429579735, 2.8023743256926537, 4.746115375310183, 5.041321059688926, 5.386524461209774, 5.333786141127348, 5.549235055223107, 4.504501540213823, 3.4055632213130593, 0.8451410313136876, 0.6133545970078558, 0.6823862646706402, 4.154752632603049, 18.018416538834572, 29.604295045137405, 26.78037777543068, 19.68894749879837, 28.126406148076057, 29.56642247736454, 20.836415626108646, 9.652498550713062, 1.3693173229694366, 0.07723798044025898, 0.07278687553480268, 0.04625076937372796, 0.043766467133536935, 0.03198638674803078, 0.075100387330167, 0.019332340270921122, 0.038218801928451285, 0.06144409082480706, 0.015917941454972606, 0.03484492437564768, 0.03359639820700977, 0.0363693662075093, 0.008800156156212324, 0.058649530037655495, 0.018077491004078183, 0.025860132082016207, 0.007334214578804676, 0.033600190581637435, 0.030111105734249577, 0.07425943011185154, 0.028752719445037656, 0.046323195565491915, 0.05641562842356507, 0.0216415902832523, 0.04386397420603316, 0.07555646676337346, 0.013387778199103195, 0.015733296968392096, 0.05869339838682208, 0.034713727509370074, 0.1430538628483191, 0.1488156005507335, 0.16392547491705045, 0.13286862813401967, 0.13922892278060317, 0.0998070920468308, 0.1462123988312669, 0.15160111826844513, 0.11991683757514693, 0.09063421355676837, 0.09674733591964468, 0.09808705348405056, 0.12474861228838563, 0.11682442695018835, 0.1645380732952617, 0.14026530232513323, 0.13893709547119215, 0.14776267111301422, 0.14754048694157973, 0.10436375261633657, 0.11307684835628606, 0.2376839256612584, 0.20101063884794712, 0.1442528172628954, 0.10052370984340087, 0.14508574444334954, 0.1730397905339487, 0.12231211920152418, 0.12477101030526683, 0.07459718894097023, 0.21344094449887052, 0.06804802513215691, 0.18317772075533867, 0.1121669307758566, 0.14260774303693324, 0.21090576803544536, 0.25790074083488435, 0.22343354736221954, 1.003127172589302, 16.31557021290064, 41.20414160192013, 53.29098142683506, 31.977518498897552, 21.126132979989052, 53.003709241747856, 42.25581876933575, 29.32437926530838, 18.463188372552395, 8.044278547167778, 1.386911328881979, 0.7550376537255943, 5.407657027244568, 18.3949763327837, 26.409874856472015, 23.279080353677273, 9.120883326977491, 7.072262680158019, 7.330906726419926, 5.477452632039785, 3.114001303911209, 1.3404705771245062, 4.780563851818442, 12.885824851691723, 20.616206042468548, 30.38903083652258, 43.21773715317249, 51.395544335246086, 57.54268728196621, 61.4775775372982, 60.76530955731869, 56.08282461762428, 57.583459094166756, 52.61703819036484, 59.839880615472794, 59.76623676717281, 61.09531804919243, 55.12467563152313, 51.36655569076538, 51.81663393974304, 55.49670606851578, 54.93437044322491, 58.92856031656265, 56.35007947683334, 59.56475257873535, 56.79257333278656, 57.63368099927902, 55.254111886024475, 57.913250997662544, 55.889320001006126, 57.04556755721569, 45.648744106292725, 51.65313631296158, 57.20617353916168, 56.607105284929276, 54.37060609459877, 54.97143745422363, 50.90995319187641, 51.27931237220764, 51.71492859721184, 51.34990498423576, 51.53580620884895, 48.236743435263634, 48.809722289443016, 46.138104647397995, 51.20616629719734, 51.97374030947685, 52.77409516274929, 55.71760341525078, 56.659637466073036, 58.255160450935364, 52.416686341166496, 51.02606736123562, 52.5061297416687, 50.622601211071014, 50.33612698316574, 50.420125275850296, 48.974416851997375, 46.26768909394741, 38.48011337220669, 27.542383186519146, 15.062824934720993, 7.609702041372657, 2.682480071671307, 2.6541483169421554, 4.357353486120701, 9.63611762970686, 7.927675154060125, 10.109342336654663, 12.970192674547434, 11.562201976776123, 9.052080418914557, 9.539288375526667, 7.5541062746196985, 3.3039063261821866, 1.822145318146795, 5.505822384729981, 22.290700189769268, 33.81611064076424, 34.27657373249531, 26.109202690422535, 34.22326259315014, 37.12732136249542, 22.24038138985634, 10.791097953915596, 0.9868716448545456, 0.17660128301940858, 0.25136963347904384, 0.1705131636117585, 0.3072514239465818, 0.13496430474333465, 0.1282337526208721, 0.09187499541440047, 0.20314941939432174, 0.2894105203449726, 0.08735757219255902, 0.18485751264961436, 0.1643384207272902, 0.1053862836852204, 0.08536088324035518, 0.14323684677947313, 0.08849342179019004, 0.12101802887627855, 0.1101676665712148, 0.10110435134265572, 0.12612826481927186, 0.15119103714823723, 0.1156933196762111, 0.09833225165493786, 0.14775144984014332, 0.14774052542634308, 0.16622841852949932, 0.14592921012081206, 0.13143859861884266, 0.11699384442181326, 0.2005568303866312, 0.13023189618252218], [0.012455426422093296, 0.06070042174542323, 0.04580762186378706, 0.04708430882601533, 0.03792206531215925, 0.06636901991441846, 0.016839247291500214, 0.023637435042473953, 0.09668198981671594, 0.0788300801650621, 0.04421778197865933, 0.048843603290151805, 0.02638664132973645, 0.01312336025875993, 0.04593409124936443, 0.04654135729651898, 0.012593094816111261, 0.0127679949036974, 0.033532024317537434, 0.022375450025720056, 0.022055011068005115, 0.07492569318856113, 0.05910711603064556, 0.06400613303412683, 0.039315102476393804, 0.04664113534090575, 0.02568238771345932, 0.051939153199782595, 0.07815629171091132, 0.019141602751915343, 0.01438936400518287, 0.011758407817978878, 0.06302725509158336, 0.046258495131041855, 0.05042075616074726, 0.036108453059569, 0.04704115664935671, 0.07978524648933671, 0.2235939254751429, 0.48862302443012595, 10.66387128084898, 29.8269023001194, 39.643515944480896, 20.354447588324547, 15.999917350709438, 36.90825931727886, 40.80705150961876, 22.774328738451004, 16.772923171520233, 7.5733014196157455, 1.4498561387881637, 1.1538016749545932, 3.8644208991900086, 14.784938246011734, 9.587738625705242, 2.7832941245287657, 4.535775287076831, 1.9152299920096993, 3.6261772457510233, 1.6503826598636806, 0.13646075647557154, 0.21894977311603725, 1.7685488378629088, 9.843636844307184, 15.116728842258453, 23.633451238274574, 36.52275860309601, 42.645696848630905, 46.95225656032562, 55.71604169905186, 54.8287171125412, 56.49505689740181, 56.98032885789871, 59.315782338380814, 58.2332394272089, 56.21876612305641, 51.92682042717934, 52.35596559941769, 52.03865982592106, 53.60067620873451, 53.45294013619423, 56.24154590070248, 54.068583101034164, 52.33632065355778, 52.79958799481392, 53.801259845495224, 51.963640451431274, 56.256175115704536, 51.45207390189171, 58.99335443973541, 41.64014920592308, 43.03613729774952, 56.48196280002594, 56.30669340491295, 52.11290784180164, 51.186403557658195, 52.68831096589565, 52.07414612174034, 49.91195574402809, 49.12033662199974, 46.499343663454056, 46.95970416069031, 44.84950639307499, 47.590629905462265, 50.48279531300068, 51.56471125781536, 50.79956151545048, 52.595778331160545, 51.71180136501789, 56.59801237285137, 50.96957579255104, 51.50462508201599, 48.82836788892746, 48.57782833278179, 50.20553179085255, 45.13408452272415, 39.78811338543892, 27.47538138180971, 16.36414110660553, 9.030166994780302, 3.1162144476547837, 1.1428676429204643, 0.41111733647994697, 1.031875954940915, 1.8773462623357773, 3.068369789980352, 3.7834489066153765, 5.166030367836356, 3.0319425696507096, 4.442972866818309, 4.46886895224452, 3.069298602640629, 0.536100467434153, 0.30274501419626176, 3.4784810710698366, 14.051715340465307, 24.179461039602757, 31.502135507762432, 22.749675661325455, 22.338965199887753, 23.468424193561077, 16.393268443644047, 6.362314000725746, 0.6309125642292202, 0.041916014670277946, 0.06805142416851595, 0.027373044649721123, 0.0720036202983465, 0.043579698249232024, 0.001830032501857204, 0.04001721870736219, 0.01096407046134118, 0.03516501637932379, 0.039991299199755304, 0.03244768719014246, 0.056918871341622435, 0.039576316194143146, 0.02024028744926909, 0.024598039453849196, 0.016109920215967577, 0.02615516361402115, 0.01156136018835241, 0.07478083338355646, 0.020708467600343283, 0.018686946386878844, 0.04311963348300196, 0.17230933910468593, 0.03130668708763551, 0.1269111267174594, 0.037448894217959605, 0.053383687991299666, 0.04806028497114312, 0.05780217921710573, 0.012312574126553955, 0.04485747616854496, 0.05330199608579278, 0.04576568680931814, 0.07515477191191167, 0.058111754988203757, 0.008024756552913459, 0.017414558315067552, 0.01134040612669196, 0.06042812034138478, 0.03257902877521701, 0.03877566872688476, 0.07364525838056579, 0.02603656284918543, 0.005289132495818194, 0.01880781441286672, 0.04669783542340156, 0.021632057396345772, 0.01815103412809549, 0.012709696420643013, 0.057227879369747825, 0.046336680388776585, 0.026108063211722765, 0.021295762453519274, 0.04275879015040118, 0.05494826516951434, 0.0573801087011816, 0.006863691560283769, 0.05196482037717942, 0.009999681096815038, 0.08920469612348825, 0.03439996602537576, 0.012197727701277472, 0.031395125115523115, 0.05122151123941876, 0.038975020725047216, 0.03306879058072809, 0.06225581113540102, 0.03305099016870372, 0.0829491407785099, 0.11386217418476008, 0.19179887924110517, 1.4833991951309144, 15.985170342028141, 37.055900394916534, 40.624748691916466, 22.036750316619873, 22.127848528325558, 41.130923330783844, 34.00297321379185, 25.182552114129066, 23.04634854197502, 7.938452800735831, 0.810755310812965, 0.48145177017431706, 1.3736369786784053, 2.4885007180273533, 6.772781275212765, 3.5041771922260523, 6.353252436965704, 4.7770751640200615, 6.513625681400299, 2.653410444036126, 1.6012781322933733, 0.9890824730973691, 2.864791676402092, 10.469148829579353, 16.966995857656002, 28.047075904905796, 37.96510800719261, 45.50858482718468, 49.495247304439545, 56.91724084317684, 55.98026432096958, 56.90745256841183, 57.192361280322075, 60.93089707195759, 58.4367299079895, 58.15871402621269, 53.902627006173134, 54.71376948058605, 53.05273801088333, 55.71167953312397, 55.630656480789185, 58.30259710550308, 55.27176193892956, 54.03378836810589, 53.5709960013628, 54.68329891562462, 53.06098356842995, 58.54927986860275, 52.180266827344894, 57.667297795414925, 43.38600352406502, 46.36793911457062, 56.13181918859482, 58.21435444056988, 54.672773480415344, 52.35436588525772, 54.068868085742, 52.94634371995926, 51.40209898352623, 51.609811037778854, 49.64535064995289, 48.48059915006161, 45.750875025987625, 49.086366444826126, 51.398717164993286, 52.381553426384926, 52.18660108745098, 54.66240003705025, 52.83454231917858, 55.1075841486454, 53.85777801275253, 51.69094808399677, 50.44933430850506, 49.175642654299736, 52.23351337015629, 46.061561554670334, 43.516283333301544, 30.909773893654346, 19.466423839330673, 11.531678214669228, 5.45541001483798, 2.290251343511045, 0.9526102489326149, 1.6935222200118005, 3.3946378575637937, 3.557937894947827, 3.9353488432243466, 4.677191823720932, 4.255838133394718, 4.210040615871549, 2.5819778395816684, 1.5145340119488537, 0.40075796423479915, 0.563363351393491, 2.847680957056582, 14.163762778043747, 29.636553414165974, 35.86740396916866, 26.547241285443306, 24.32662144303322, 26.92478522658348, 21.85475718230009, 9.00461621582508, 1.5915734530426562, 0.016317265144607518, 0.08281674163299613, 0.05646365651045926, 0.03194797689502593, 0.04938199803291354, 0.02079297224554466, 0.03823036087851506, 0.04360579958301969, 0.03211505289073102, 0.06896028047776781, 0.018610286242619622, 0.016689993972249795, 0.016973679921648, 0.05995802544930484, 0.03786482717259787, 0.02655694195709657, 0.014214815510058543, 0.01787597193469992, 0.06328696967102587, 0.06005310198816005, 0.0139226171268092, 0.04275362480257172, 0.05412203216110356, 0.04703333070210647, 0.05647655503707938, 0.028786422226403374, 0.028929970285389572, 0.10630633900291286, 0.07816674857167527, 0.006498684779217001, 0.001986952206607384, 0.021915728502790444, 0.10666256988770328, 0.10004919546190649, 0.160493309085723, 0.13853179378202185, 0.17531365680042654, 0.14810129825491458, 0.10893402417423204, 0.12377668826957233, 0.14956231985706836, 0.21041293744929135, 0.17417342111002654, 0.10780678348965012, 0.21321930951671675, 0.1417892283643596, 0.15227121824864298, 0.10417811179650016, 0.13979893672512844, 0.11041349556762725, 0.2169273464824073, 0.10519430492422543, 0.10424928375869058, 0.16586807614658028, 0.13721598079428077, 0.147686853306368, 0.13061423582257703, 0.13863756466889754, 0.13588107976829633, 0.19430309330346063, 0.15604726562742144, 0.07813926684320904, 0.12682506727287546, 0.10656410915544257, 0.16109278629301116, 0.18848944979254156, 0.1981483236886561, 0.08885481802280992, 0.2560097782406956, 0.24241578503279015, 0.2578352834098041, 1.4872159715741873, 18.391303829848766, 43.44478257000446, 51.58898435533047, 28.26688650995493, 24.78448547422886, 44.12594921886921, 48.50430227816105, 29.77864868938923, 22.474110648036003, 10.140207130461931, 1.8687158566899598, 2.3329256661236286, 6.208961829543114, 22.778386920690536, 20.18172025680542, 9.880785550922155, 11.482453756034374, 6.809360487386584, 9.45916872471571, 4.964393712580204, 1.0406828136183321, 0.6367303489241749, 2.4839326506480575, 11.717809326946735, 18.562507443130016, 26.805312037467957, 37.571939304471016, 45.723881274461746, 48.2847348600626, 57.607846185564995, 55.877244248986244, 55.43218553066254, 56.86152443289757, 62.073161378502846, 63.155658692121506, 60.28875432908535, 55.56965835392475, 56.649218425154686, 56.16385146975517, 57.546954452991486, 58.241526782512665, 60.53148530423641, 57.605136930942535, 55.39300963282585, 56.41306109726429, 57.54577271640301, 54.87780287861824, 60.14561600983143, 54.911123290658, 58.58441658318043, 45.59446781873703, 46.97963409125805, 56.73166260123253, 61.409602984786034, 57.115905582904816, 56.1484394967556, 56.69984690845013, 55.1970237493515, 53.64479944109917, 52.5533764064312, 50.55037468671799, 51.6325756162405, 48.0335683375597, 51.584565192461014, 54.83021803200245, 55.064635053277016, 54.94271859526634, 56.55460350215435, 55.00388391315937, 54.85181987285614, 54.36282031238079, 54.228828102350235, 51.55941814184189, 51.23624548316002, 54.2573531717062, 48.56492042541504, 44.205934926867485, 30.01462172716856, 18.146800249814987, 10.633739847689867, 4.63806769810617, 2.507382142357528, 1.119173183105886, 3.3437505131587386, 4.966580020263791, 8.745092041790485, 10.56086640805006, 11.278312560170889, 9.293072037398815, 10.023111663758755, 9.129105135798454, 5.05247013643384, 1.7884558509103954, 0.8830274920910597, 4.71529807895422, 18.359944112598896, 31.89858913421631, 41.62288673222065, 32.05253787338734, 32.69142799079418, 33.59302081167698, 23.846511505544186, 9.099535122513771, 1.1077528959140182, 0.16027105069952086, 0.18384850351139903, 0.12833593151299283, 0.21770409308373928, 0.1478877229965292, 0.15232388104777783, 0.10427903645904735, 0.0768577930284664, 0.140046160959173, 0.17228890035767108, 0.1528134907130152, 0.1184652115625795, 0.11737613953300752, 0.15462550363736227, 0.1275392359821126, 0.10714075047872029, 0.09744493247126229, 0.0621554913232103, 0.13267914298921824, 0.15852130396524444, 0.11791814482421614, 0.19535134721081704, 0.21214321022853255, 0.08734557908610441, 0.18484336731489748, 0.1075743576802779, 0.1783456714474596, 0.1954484052839689, 0.21343567525036633, 0.10495456153876148, 0.1335405686404556, 0.21024013578426093], [0.023290373392228503, 0.028693753956758883, 0.042348419592599384, 0.03172308759531006, 0.0844393287843559, 0.017949192224477883, 0.06368611153448, 0.06794819884817116, 0.036603109329007566, 0.05298055708408356, 0.09500483996816911, 0.06888795818667859, 0.027557143657759298, 0.016279116898658685, 0.0969983302638866, 0.03969713783590123, 0.09688769088825211, 0.06996426527621225, 0.02588625382486498, 0.00959426808549324, 0.021703591155528557, 0.031312178980442695, 0.05853462702361867, 0.02881112275645137, 0.035162971762474626, 0.026084264391101897, 0.05576084637141321, 0.016195022290048655, 0.042252252096659504, 0.008794171662884764, 0.06291589583270252, 0.03282988582213875, 0.05835276373545639, 0.03705639086547308, 0.024384265670960303, 0.022785946748626884, 0.07742616682662629, 0.06242667208425701, 0.02816622054524487, 0.07598847834742628, 0.7782476395368576, 11.557027604430914, 32.90118433535099, 34.119079783558846, 20.098048746585846, 18.293897956609726, 36.88699185848236, 25.17798475921154, 22.8207166492939, 21.111479066312313, 8.792413752526045, 0.9765842906199396, 1.5222118562087417, 1.6381229739636183, 2.9290885012596846, 3.0644963728263974, 4.257084466516972, 3.4530343115329742, 5.6716597359627485, 1.9624949432909489, 3.2289175875484943, 1.2273023184388876, 0.26554575248155743, 1.7994526983238757, 4.943311968818307, 13.008344527333975, 18.56187477707863, 29.186013489961624, 36.16141699254513, 45.10217763483524, 46.42585940659046, 53.75695422291756, 54.40101206302643, 59.834017530083656, 57.46406190097332, 56.888293996453285, 54.727133363485336, 55.60748912394047, 54.57065396010876, 56.00460961461067, 54.90269534289837, 54.973052367568016, 51.77024602890015, 54.02895122766495, 51.39498196542263, 54.52187977731228, 53.03706005215645, 55.07050193846226, 54.359814673662186, 59.381427615880966, 43.18670801818371, 48.15243735909462, 55.31095303595066, 52.46009901165962, 55.704395323991776, 51.938463002443314, 52.8962168097496, 49.72567833960056, 51.245232000947, 49.323401525616646, 50.688132494688034, 48.93265329301357, 50.432258024811745, 51.661674454808235, 53.64481844007969, 52.23271161317825, 56.13003708422184, 52.97135777771473, 57.73915573954582, 51.00443132221699, 42.8764508664608, 47.230447232723236, 46.370800361037254, 48.95515948534012, 35.79206161201, 24.109039418399334, 15.433207210153341, 8.307608217000961, 3.827345338650048, 0.9471595007926226, 0.9401121851988137, 1.0964670265093446, 1.0075008566491306, 1.3180267252027988, 2.4635063717141747, 1.5289517445489764, 3.0428230483084917, 3.18018211517483, 2.766853356733918, 2.2560061560943723, 1.3815983827225864, 0.8744020143058151, 1.078048583585769, 2.441186844371259, 12.761303633451462, 20.907502211630344, 27.563863433897495, 21.7719729244709, 22.168622240424156, 24.948670864105225, 18.34741808474064, 5.380119429901242, 0.6724939704872668, 0.108801283640787, 0.01200313101435313, 0.038253916645771824, 0.10433449715492316, 0.027055078899138607, 0.03354370943270624, 0.057448753650533035, 0.03966179305280093, 0.11922333767870441, 0.03743894943909254, 0.024313247704412788, 0.035195893433410674, 0.005337232942110859, 0.035541073739295825, 0.03887633363774512, 0.05789827620901633, 0.06461648270487785, 0.017287411719735246, 0.014985021007305477, 0.031464449129998684, 0.0375420040654717, 0.01231306208865135, 0.03820595164143015, 0.021574203274212778, 0.03718945794389583, 0.03636548477516044, 0.1254874054575339, 0.030229420772229787, 0.005718063703170628, 0.037475908393389545, 0.028782123335986398, 0.021529856239794753, 0.034342705621384084, 0.019725064412341453, 0.011267436311754864, 0.05516287201317027, 0.04310046380851418, 0.012667831870203372, 0.005904155377720599, 0.026852368682739325, 0.04935034172376618, 0.03859161239233799, 0.05708529795811046, 0.06528322075610049, 0.08528510254109278, 0.02903817170590628, 0.023484511802962516, 0.044272088634897955, 0.08710473732207902, 0.051572027587099, 0.04265900839527603, 0.05759263010986615, 0.01881415049865609, 0.035417595208855346, 0.033207720625796355, 0.02213666586612817, 0.014753734394616913, 0.03855436771118548, 0.017100822806241922, 0.0573656999040395, 0.02431183947919635, 0.0464432861917885, 0.04569378012092784, 0.13489872857462615, 0.04410691253724508, 0.011700129743985599, 0.05012151108530816, 0.01787696084647905, 0.009175755239994032, 0.03480728635622654, 0.07573893119115382, 0.032286388814100064, 0.03792993949900847, 1.7723352159373462, 17.05695603042841, 38.77616688609123, 36.82195454835892, 21.030258424580097, 27.706545777618885, 46.675297021865845, 25.49814037978649, 30.43456569314003, 26.37040827423334, 8.980311769992113, 0.9246983716730028, 0.18058523564832285, 0.6518601870629936, 1.6528654703870416, 4.005377423018217, 5.392364747822285, 4.568765591830015, 5.224939081817865, 2.3060570703819394, 5.059571480378509, 2.192366933450103, 1.014241457451135, 2.8444335563108325, 7.768694059923291, 14.735868629068136, 21.745668835937977, 30.772962234914303, 38.34924079477787, 46.177276745438576, 49.07266438007355, 54.15597841143608, 55.62542416155338, 60.48925057053566, 59.1639044880867, 57.13626869022846, 57.28313460946083, 56.44513137638569, 55.675805658102036, 57.952730879187584, 55.58689042925835, 57.868428602814674, 55.64663462340832, 54.33911718428135, 54.58302989602089, 55.43899856507778, 52.93301023542881, 57.866619899868965, 55.82012191414833, 58.29419195652008, 43.83000589907169, 48.99796038866043, 57.805040404200554, 54.020226895809174, 55.399058908224106, 51.52810402214527, 54.52783785760403, 52.05712303519249, 53.76160517334938, 51.59805826842785, 52.26220563054085, 50.189553648233414, 52.837555557489395, 52.74025797843933, 54.46888402104378, 53.09912972152233, 56.348494961857796, 53.855061158537865, 56.787002831697464, 54.7809536755085, 46.42492085695267, 48.98131348192692, 49.94809940457344, 50.325077176094055, 39.76893961429596, 29.801576659083366, 19.956071265041828, 11.665626727044582, 5.198318660259247, 2.8123176796361804, 2.439974471926689, 2.1356832375749946, 1.4939361484721303, 2.1709375083446503, 3.70066583622247, 4.500504154711962, 4.87181500531733, 3.1709343614056706, 5.700163431465626, 3.1150488601997495, 1.736269926186651, 0.5233779782429338, 0.7814087730366737, 2.4674785835668445, 14.045142643153667, 24.413448683917522, 32.042495012283325, 26.7166817933321, 25.644763112068176, 27.535708844661713, 23.35991531610489, 8.18749476224184, 1.4619891252368689, 0.09492790151853114, 0.06799678725656122, 0.07174131562351249, 0.08835816537612118, 0.039410835815942846, 0.04595268204866443, 0.025389287620782852, 0.07063436525641009, 0.09748540178406984, 0.02506636803445872, 0.09839609119808301, 0.03021902884938754, 0.03103508886852069, 0.04867424147960264, 0.065326042677043, 0.024469083873555064, 0.014383193974936148, 0.0016068349509623658, 0.03535296527843457, 0.056551200250396505, 0.011574817181099206, 0.02528555392927956, 0.03904621124092955, 0.023340123261732515, 0.01133419156758464, 0.021601696134894155, 0.03974686544097494, 0.03480934210529085, 0.025529134218231775, 0.0507100119284587, 0.06777933798730373, 0.018894838649430312, 0.00791551519796485, 0.14355266030179337, 0.13416849978966638, 0.10631284763803706, 0.11113852189737372, 0.20223828469170257, 0.13066035287920386, 0.15039944759337232, 0.20455850550206378, 0.187117307796143, 0.1553614914882928, 0.1833728759083897, 0.11996779343462549, 0.16494226176291704, 0.11985043020104058, 0.20845990162342787, 0.29387263872195035, 0.1709783566184342, 0.141863324388396, 0.21500179980648682, 0.11445626339991577, 0.18744870641967282, 0.14203554717823863, 0.20675731095252559, 0.21333864686312154, 0.18769452057313174, 0.12675701233092695, 0.13347004976822063, 0.11163094430230558, 0.19212698272895068, 0.14875437336741015, 0.30547341622877866, 0.07931601619930007, 0.1646590285236016, 0.1553421956487, 0.09717859051306732, 0.08179680065950379, 0.1365121576236561, 0.1515110957552679, 0.1705139799742028, 0.22437810839619488, 1.7923375801183283, 18.145149238407612, 45.171945691108704, 48.01014259457588, 26.65331829339266, 32.01971523463726, 45.077190175652504, 33.97297382354736, 31.86000220477581, 25.09882550686598, 12.635913211852312, 1.3852961780503392, 2.296450948342681, 3.6422285344451666, 7.92750796303153, 8.458131439983845, 10.239452105015516, 9.31710859760642, 10.875537022948265, 5.271196849644184, 8.288456294685602, 3.374939002096653, 0.8265302237123251, 2.3040771391242743, 6.792372073978186, 16.27689778804779, 22.219328619539738, 29.880570620298386, 37.853264808654785, 45.936605259776115, 49.65210668742657, 55.38352534174919, 56.44056782126427, 62.01757416129112, 60.23344449698925, 60.239630565047264, 58.19414332509041, 60.61648674309254, 59.43893752992153, 61.52249872684479, 59.12204593420029, 60.075467973947525, 58.17188411951065, 56.37118734419346, 57.64497019350529, 57.757748141884804, 56.622540056705475, 59.171264693140984, 59.52661022543907, 59.33361478149891, 47.15244881808758, 52.348419204354286, 56.93817771971226, 54.64926414191723, 57.115210220217705, 55.18188536167145, 57.513425052165985, 53.758667930960655, 55.030144304037094, 52.844535782933235, 54.41824793815613, 53.5276023298502, 54.22574646770954, 57.452111542224884, 57.460163310170174, 56.529061272740364, 56.77741974592209, 55.46202912926674, 56.17778152227402, 55.2521587908268, 50.902608186006546, 52.326783165335655, 51.41917146742344, 52.15378224849701, 38.22892785072327, 27.38522931933403, 15.79725332558155, 10.265111178159714, 5.147563358768821, 2.0109340315684676, 2.8047546604648232, 2.0348573103547096, 2.5558164808899164, 3.360895668156445, 6.457730680704117, 6.315688127651811, 9.049418661743402, 7.578267753124237, 6.9441145565360785, 7.513556275516748, 5.121556129306555, 2.699009422212839, 1.6596373007632792, 3.907781559973955, 16.37368619441986, 28.411083072423935, 37.649139761924744, 31.486299857497215, 32.88521759212017, 36.35923817753792, 25.890587121248245, 7.70366339944303, 0.928817706881091, 0.20379321766085923, 0.19296338316053152, 0.1505632247426547, 0.17749199381796643, 0.09549195601721294, 0.14805651706410572, 0.16035013395594433, 0.17140633834060282, 0.23350198287516832, 0.16114556783577427, 0.1885150687303394, 0.08795912741334178, 0.08485367725370452, 0.13583033171016723, 0.13329292880371213, 0.10122888372279704, 0.13600641366792843, 0.1213893253589049, 0.11771181292715482, 0.1526646307320334, 0.1992917209281586, 0.09605446684872732, 0.09473446072661318, 0.11684737415635027, 0.09776288337889127, 0.10246396588627249, 0.13763624418061227, 0.15698416769737378, 0.13354469498153776, 0.17465845914557576, 0.19700353121152148, 0.05069501683465205, 0.11456986394478008], [0.022047311285859905, 0.056527744673076086, 0.050606322765816, 0.04100253478100058, 0.06673593772575259, 0.01563524256198434, 0.07486084432457574, 0.03786706474784296, 0.03452450211625546, 0.0374006694619311, 0.04547191136225592, 0.04235544030962046, 0.02245025294541847, 0.03753945107746404, 0.09215975005645305, 0.044518656068248674, 0.04685930449340958, 0.005534204965442768, 0.015343937539000763, 0.0601720942358952, 0.05222512125328649, 0.015607027962687425, 0.0806558079784736, 0.05972631581244059, 0.03220658938516863, 0.05849074383149855, 0.062179113883757964, 0.10839417111128569, 0.08915879428968765, 0.03935684828320518, 0.02996788236487191, 0.09840884871664457, 0.042424686398589984, 0.024985674317576922, 0.033467290486441925, 0.026516539437579922, 0.014945213133614743, 0.04506278761255089, 0.09753661739523523, 0.0707406630681362, 0.015552245404251153, 1.4326374814845622, 13.997591994702816, 29.612020030617714, 41.45797558128834, 16.857808716595173, 17.433779910206795, 40.84158405661583, 31.18723690509796, 19.60472121834755, 18.344515040516853, 10.494960844516754, 1.1627189652062953, 0.5778319656383246, 1.0731818759813905, 1.205535305198282, 5.015323804691434, 3.693754244595766, 4.343798663467169, 2.082260479219258, 3.7343868892639875, 1.5500870416872203, 2.192175993695855, 0.2548371849115938, 0.700724971247837, 2.705477625131607, 6.301755700260401, 13.007587417960167, 16.705410294234753, 25.389703698456287, 30.253180526196957, 38.97843383252621, 49.13505703210831, 57.49488204717636, 58.111904338002205, 60.93137204647064, 56.09310686588287, 58.861007541418076, 55.49590811133385, 59.08623665571213, 53.991458639502525, 55.912411361932755, 52.70340755581856, 53.51100482046604, 51.079291105270386, 52.72878259420395, 50.97068913280964, 58.98645021021366, 53.583759516477585, 63.26345130801201, 44.834580793976784, 38.00287418067455, 49.74357917904854, 51.24560818076134, 57.70659528672695, 53.53110954165459, 53.56788016855717, 53.14534284174442, 51.34276136755943, 52.274000197649, 51.62847563624382, 51.43521040678024, 52.663186714053154, 54.88096810877323, 51.46688170731068, 56.89642556011677, 56.09476737678051, 54.40036989748478, 46.86317414045334, 40.72032496333122, 43.433010801672935, 52.160587683320045, 47.1727891266346, 32.96352379024029, 20.036476850509644, 7.74051952175796, 3.217615094035864, 1.294135507196188, 0.1631662726867944, 0.7573753595352173, 1.2305119587108493, 2.7607480343431234, 1.4357751631177962, 1.2169532175175846, 4.224847471341491, 4.155845548957586, 2.289673537015915, 2.5106511544436216, 4.403279246762395, 1.9637194275856018, 0.7460364117287099, 1.3922002888284624, 2.977040740661323, 13.366071581840515, 22.159143649041653, 25.889145098626614, 20.64422193914652, 20.291515365242958, 27.041503563523293, 19.4134508818388, 5.417473800480366, 0.4735410399734974, 0.047134244232438505, 0.04676989425206557, 0.025163457648886833, 0.014803297799517168, 0.023118811113818083, 0.009417095170647372, 0.06250692793400958, 0.05632719039567746, 0.03404599498026073, 0.08557912660762668, 0.01910845658130711, 0.04010292192106135, 0.06887603187351488, 0.047570185488439165, 0.06691490663797595, 0.027858468602062203, 0.02451269989251159, 0.04352872754679993, 0.04616870639438275, 0.08127395019982941, 0.05841387217515148, 0.047414917062269524, 0.01285480298975017, 0.05816305223561358, 0.028897575539303944, 0.052275175403337926, 0.05227717920206487, 0.07065464815241285, 0.02644484797201585, 0.06051757140085101, 0.033657213498372585, 0.007202998694992857, 0.0073959037490567425, 0.019280072665424086, 0.03535033065418247, 0.046945961366873235, 0.06198579925694503, 0.10505570884561166, 0.0587169207574334, 0.036563148387358524, 0.0422201616311213, 0.03143418063700665, 0.0434318846964743, 0.0604831802775152, 0.0051255617563583655, 0.017230166158697102, 0.04601305576215964, 0.018242379519506358, 0.09573636009008624, 0.016714735320420004, 0.046052345060161315, 0.03143154601275455, 0.00873721182870213, 0.034464807467884384, 0.004631336396414554, 0.037744083456345834, 0.053448663020390086, 0.08490966487443075, 0.05789638373244088, 0.02644080697791651, 0.08361019397852942, 0.0621809210133506, 0.027586631040321663, 0.024267171465908177, 0.00784606965680723, 0.09038897827849723, 0.02115049817803083, 0.0471882466081297, 0.0389341914706165, 0.051937672615167685, 0.02728870698774699, 0.009226330748788314, 0.08264353178674355, 0.09824972483329475, 0.01990927103179274, 2.6517637073993683, 19.69668198376894, 36.255047768354416, 42.06997834146023, 20.022708289325237, 20.956061705946922, 38.528917953372, 22.364288941025734, 31.533105745911598, 27.286480218172073, 11.373674143105745, 1.2422117684036493, 0.3194124635774642, 0.39209805079735816, 1.302775649819523, 2.2111847111955285, 3.0305696558207273, 5.382572673261166, 4.030979024246335, 6.123379496857524, 4.841360114514828, 4.775173366069794, 1.6207298822700977, 2.53898860886693, 5.406939340755343, 8.935011550784111, 14.44882633164525, 19.79301441460848, 28.622838109731674, 32.264471501111984, 40.546773076057434, 48.87247212231159, 59.246694445610046, 60.291235595941544, 60.00143274664879, 56.33175306022167, 60.259723886847496, 58.832493871450424, 60.75088933110237, 55.886986926198006, 56.69822059571743, 52.74379558861256, 55.29424913227558, 53.873866349458694, 54.939256981015205, 54.84298154711723, 59.41134341061115, 54.90772247314453, 60.84709256887436, 45.216262713074684, 42.688357159495354, 51.73523850739002, 52.634315863251686, 59.73999537527561, 53.879045471549034, 54.86393362283707, 55.73337256908417, 53.87422353029251, 54.2788752168417, 54.29854296147823, 52.347731441259384, 54.11601595580578, 54.87374849617481, 54.205238968133926, 56.970365792512894, 57.42823742330074, 54.72897246479988, 53.41169334948063, 44.89748261868954, 45.56677870452404, 52.405005767941475, 49.441077411174774, 35.985159650444984, 23.105505667626858, 8.981433659791946, 5.442898711189628, 2.8191005531698465, 0.9131193242501467, 1.45085406024009, 2.494400138966739, 2.441436918452382, 3.4150992846116424, 3.299140906892717, 5.339865339919925, 4.786710496991873, 4.573590382933617, 3.8174494821578264, 3.230283376760781, 1.8190541840158403, 0.14120061619905755, 0.7678750867489725, 3.055054829455912, 12.667410671710968, 26.290823444724083, 29.359295591711998, 27.904743142426014, 23.658045418560505, 29.81157012283802, 25.109852515161037, 9.020887892693281, 1.2540336465463042, 0.0332691481889924, 0.05694201150618028, 0.018766599241644144, 0.03576913943106774, 0.0386694265762344, 0.004526146240095841, 0.03946016266127117, 0.032996301306411624, 0.01700731776509201, 0.06055119440134149, 0.059846911099157296, 0.03707179414050188, 0.0251008092527627, 0.022120273679320235, 0.040821157599566504, 0.034915840296889655, 0.05867955362191424, 0.02931069760961691, 0.06639379280386493, 0.04641161875042599, 0.016213431263167877, 0.02696565195947187, 0.04184420075034723, 0.039031297783367336, 0.05467003400553949, 0.062141520393197425, 0.042399865269544534, 0.010896617586695356, 0.01774876596755348, 0.01896505509648705, 0.05821818638651166, 0.013398647879512282, 0.025755691494850907, 0.05398684996180236, 0.1049115986097604, 0.1336375970277004, 0.11650938526145183, 0.14579860697267577, 0.24783877684967592, 0.1357705591362901, 0.1638070133049041, 0.19880405568983406, 0.328042542678304, 0.15796568768564612, 0.1400611226563342, 0.1710478513268754, 0.09364848345285282, 0.1443471442325972, 0.2026777993887663, 0.16057047760114074, 0.14933969039702788, 0.19187975849490613, 0.08700474034412764, 0.14211103843990713, 0.15589555579936132, 0.12701375089818612, 0.20642751536797732, 0.151313075912185, 0.18903982650954276, 0.1710671471664682, 0.15248221083311364, 0.20168406364973634, 0.19809085177257657, 0.22213944961549714, 0.18415912199998274, 0.22373438434442505, 0.09633061257773079, 0.16537998046260327, 0.14520649187033996, 0.11134571468573995, 0.08790820866124704, 0.1434502736083232, 0.13148510159226134, 0.17349076399113983, 0.09775808910490014, 2.7143116760998964, 21.261715404689312, 41.56971238553524, 54.02224458754063, 25.98152194172144, 26.45189680159092, 49.126815274357796, 37.84973479807377, 28.4779404848814, 22.180452905595303, 13.289955966174603, 1.8576603499241173, 0.9736168279778212, 3.026839680969715, 4.937882060185075, 11.279555093497038, 10.05175357684493, 11.574313826858997, 7.4545710906386375, 9.291048645973206, 5.8731363248080015, 3.2200521882623434, 0.8354670472908765, 1.2428541714325547, 3.647662717849016, 7.358320355415344, 15.19328048452735, 18.934722170233727, 26.506885550916195, 30.796665363013744, 39.31602671742439, 47.99850381910801, 60.940267369151115, 61.084519028663635, 64.71257194876671, 59.525086507201195, 62.6004932820797, 61.67831316590309, 62.82903581857681, 58.6712609231472, 59.74746197462082, 55.566926300525665, 56.56478315591812, 55.59741586446762, 57.998343631625175, 56.156650856137276, 62.074396312236786, 57.450568825006485, 61.77474819123745, 51.41310699284077, 46.55887506902218, 55.707670748233795, 58.406479731202126, 59.70089927315712, 57.21282318234444, 56.25623971223831, 57.85246945917606, 55.716759860515594, 56.86929501593113, 55.27387462556362, 54.24293674528599, 57.25470453500748, 59.5317779481411, 55.80185629427433, 59.338885098695755, 58.408014848828316, 56.12736202776432, 54.81710493564606, 51.00152067840099, 46.71983443200588, 52.644373923540115, 48.86677622795105, 34.942571595311165, 22.773131802678108, 8.867238387465477, 5.391540667042136, 2.637181752361357, 0.5508752027526498, 1.8702710419893265, 3.1342596793547273, 5.409298539161682, 3.7631587078794837, 4.1799429059028625, 10.96961047500372, 9.91730634123087, 7.19842778518796, 9.354900419712067, 12.11145680397749, 5.041736662387848, 1.6739637195132673, 1.6936877486295998, 4.297980722039938, 16.288439668715, 29.63612023741007, 35.66500402987003, 31.408683322370052, 30.615747570991516, 37.86666288971901, 27.143526189029217, 8.304321393370628, 0.8538576448336244, 0.09172568272333592, 0.14210152410669252, 0.11065501268603839, 0.10821670875884593, 0.15430019062478095, 0.06373986529069953, 0.18322020128834993, 0.15075907751452178, 0.11549417919013649, 0.17855795536888763, 0.10595147366984747, 0.14602059818571433, 0.11567398672923446, 0.10556802822975442, 0.18466979381628335, 0.14579183858586475, 0.14206069114152342, 0.148812216357328, 0.19594040466472507, 0.08855693478835747, 0.16192638140637428, 0.12479002412874252, 0.2054883720120415, 0.16128277609823272, 0.17755523964297026, 0.22579341370146722, 0.3683035197900608, 0.13652597641339526, 0.16325752716511488, 0.18183556152507663, 0.16251802153419703, 0.14049032150069252, 0.14671996847027913, 0.22708761534886435], [0.06048440111044329, 0.03877071489114314, 0.02574989717686549, 0.02274425103678368, 0.07541956278146245, 0.07290051318705082, 0.019807305507129058, 0.005825153757541557, 0.04388769324577879, 0.04986904728866648, 0.061229509956319816, 0.02895504374464508, 0.06862030262709595, 0.041683399613248184, 0.04609105548297521, 0.05598297488177195, 0.040526758748455904, 0.04029336072562728, 0.008401175709877862, 0.010117122255905997, 0.08759662538068369, 0.034811397854355164, 0.06293272774200886, 0.07737520354567096, 0.05084525349957403, 0.03928555015590973, 0.04039820021716878, 0.04459271869563963, 0.009382622411067132, 0.03395483327039983, 0.039991425364860334, 0.052833389199804515, 0.03625442237535026, 0.05005844337574672, 0.021663030929630622, 0.07083807737217285, 0.02314058758202009, 0.019868321178364567, 0.01926345041283639, 0.010067259208881296, 0.22220355633180588, 0.031721655250294134, 1.502616188954562, 11.980152949690819, 28.960784375667572, 38.26396957039833, 18.73967293649912, 25.201408602297306, 37.898885160684586, 23.928229920566082, 16.868716031312943, 15.038170907646418, 10.20310990512371, 3.6765608796849847, 0.11048037049476989, 0.7954976451583207, 1.9448913191445172, 2.1653040731325746, 3.5926157841458917, 1.477407985366881, 5.513899801298976, 3.777135545387864, 4.738483484834433, 2.894386388361454, 2.5562753062695265, 0.8888650476001203, 1.1650211666710675, 3.944681379944086, 6.149320229887962, 8.074499275535345, 13.421687297523022, 21.599209494888783, 30.827968083322048, 39.19341489672661, 44.99712847173214, 57.46642917394638, 60.891344994306564, 58.10614764690399, 57.68086686730385, 57.70619250833988, 59.204444512724876, 58.91610458493233, 56.749780029058456, 55.557981580495834, 55.88082745671272, 54.05930779874325, 54.6226541697979, 55.74145473539829, 54.83407482504845, 62.06841163337231, 51.30854420363903, 39.35888461768627, 52.74071775376797, 52.40852437913418, 54.745022803545, 55.89178986847401, 55.16696736216545, 53.29501301050186, 56.00348487496376, 54.31192584335804, 52.41230897605419, 53.795902132987976, 55.351276472210884, 53.2194958627224, 56.69375583529472, 55.296301022171974, 55.33254347741604, 54.26594831049442, 37.523377910256386, 47.236842289566994, 50.23641273379326, 43.81954126060009, 26.77502006292343, 10.562969595193863, 3.1102219317108393, 0.5394857889041305, 0.06329045776510611, 0.6877886841539294, 0.36891944298986346, 0.8876121242064983, 1.540766735561192, 1.5732285124249756, 2.56828052457422, 3.450731160119176, 3.090082537382841, 3.3325230656191707, 3.2278111344203353, 1.5902778413146734, 3.2455728063359857, 2.4685855116695166, 1.2517401133663952, 3.5036228969693184, 10.315699763596058, 20.173398703336716, 24.85497359186411, 17.821307815611362, 16.347862780094147, 24.87927708774805, 16.813468895852566, 5.202790070325136, 0.27826135454233736, 0.04650593829865102, 0.06555252388352528, 0.06433378381188959, 0.040295386788784526, 0.05900135627598502, 0.03213211486581713, 0.035743516782531515, 0.03173398603394162, 0.06477176968473941, 0.050814955320674926, 0.049424081516917795, 0.0392321971594356, 0.031047076408867724, 0.04840092333324719, 0.053696952236350626, 0.012127457448514178, 0.057399809011258185, 0.024632313688925933, 0.1178291390533559, 0.04256893022102304, 0.01572305161971599, 0.06407093736925162, 0.02538492564781336, 0.08435887255473062, 0.05844838575285394, 0.03905492776539177, 0.03773007912968751, 0.04966858577972744, 0.011612708458415, 0.026948153972625732, 0.037299399700714275, 0.022250579968385864, 0.032448095371364616, 0.061972897019586526, 0.04610730480635539, 0.02014160592807457, 0.052946896976209246, 0.056081383663695306, 0.06874720245832577, 0.07242583553306758, 0.07087817561114207, 0.029740185891569126, 0.06851260957773775, 0.019016677033505403, 0.024465942733513657, 0.025036424231075216, 0.05943952397501562, 0.03608273764257319, 0.029310957361303736, 0.0165726492923568, 0.024668441437825095, 0.06469543237471953, 0.0708694924833253, 0.03810775437159464, 0.028707517085422296, 0.059570286684902385, 0.03585067548556253, 0.01194828351799515, 0.027860490954481065, 0.03783183128689416, 0.06575335646630265, 0.03383985233085696, 0.0363215830293484, 0.02741698350291699, 0.04260144371073693, 0.0780812680022791, 0.0820097970427014, 0.0530817786057014, 0.08182370351278223, 0.027041167340939865, 0.07186201110016555, 0.017907643086800817, 0.053159704111749306, 0.0375650440400932, 0.005209312193983351, 0.03730359283508733, 0.046209587599150836, 2.7399859484285116, 15.86736336350441, 37.46712572872639, 36.44958592951298, 19.63247112929821, 31.419216357171535, 35.641578286886215, 15.845961011946201, 23.78187697380781, 25.233554877340794, 14.47874117642641, 3.269510571844876, 0.3239503700751811, 0.5367429298348725, 0.8804366842377931, 1.8711403640918434, 4.016535999253392, 4.635271048173308, 6.047183135524392, 8.607988748699427, 13.386803269386292, 4.0469433926045895, 2.961500999517739, 1.3658069050870836, 2.504425188526511, 4.548761090263724, 7.074063308537006, 10.150122698396444, 16.690895073115826, 24.57843203097582, 33.35829980671406, 42.23698318004608, 50.12671262025833, 61.42010562121868, 61.19055613875389, 59.65835675597191, 59.34387423098087, 59.63326670229435, 61.179171949625015, 59.90658983588219, 57.65037730336189, 58.54712538421154, 55.600299909710884, 56.819194704294205, 55.62065161764622, 57.02317535877228, 57.240014523267746, 63.35051603615284, 52.23105490207672, 42.38670654594898, 56.34685344994068, 55.95897786319256, 56.701321229338646, 58.427617996931076, 55.16406811773777, 56.50352284312248, 55.812313333153725, 56.27027615904808, 54.070726186037064, 55.616293251514435, 56.31406120955944, 55.07493630051613, 55.38451708853245, 57.32480697333813, 54.194629937410355, 57.22714461386204, 43.222532495856285, 48.63378793001175, 51.13655023276806, 46.95215776562691, 30.17654623836279, 13.42200743034482, 4.488460700958967, 2.399485744535923, 1.5053812530823052, 1.5070678875781596, 1.565051469951868, 2.571200430393219, 4.030706388875842, 4.037098120898008, 3.266009772196412, 5.612239949405193, 4.697821866720915, 4.592118663713336, 5.165224336087704, 1.9227284146472812, 1.1174892797134817, 0.41424741852097213, 0.7270842755679041, 4.202869925647974, 12.357172518968582, 23.63320615142584, 30.026332698762417, 24.237607419490814, 19.76078074425459, 28.540532626211643, 23.148627653717995, 8.953166026622057, 0.9467018628492951, 0.035459778882795945, 0.052394108279258944, 0.021349495800677687, 0.02956767551950179, 0.09460579458391294, 0.009659694896981819, 0.01486082259361865, 0.040426264531561173, 0.05121108777530026, 0.03945157972339075, 0.1365481221000664, 0.020016335110994987, 0.022165463051351253, 0.16804822400445119, 0.08124145155306906, 0.03614055836806074, 0.014958768460928695, 0.03990356621216051, 0.07565794803667814, 0.07142389164073393, 0.03376814231160097, 0.06063085653295275, 0.05438975822471548, 0.014905828284099698, 0.09499334410065785, 0.017624545289436355, 0.023843113849579822, 0.016301861869578715, 0.01844647940743016, 0.07175413993536495, 0.03192107404174749, 0.03534656796546187, 0.04110874724574387, 0.013268259026517626, 0.02714496225962648, 0.14911646721884608, 0.10443789316923358, 0.18003509641857818, 0.1385804044548422, 0.1429084167466499, 0.13868368172552437, 0.08534143897122703, 0.09670668849139474, 0.08994240575702861, 0.14643229718785733, 0.08109128539217636, 0.1338613693951629, 0.13685335259651765, 0.22580706921871752, 0.16016032226616517, 0.08966992623754777, 0.09773264828254469, 0.16427639202447608, 0.0755799186299555, 0.05578384552791249, 0.16176637436728925, 0.12780986755387858, 0.16756130091380328, 0.12501799705205485, 0.15692786837462336, 0.10131549977813847, 0.15047897613840178, 0.07796229430823587, 0.10141792357899249, 0.10528532191528939, 0.12356189588899724, 0.14082694484386593, 0.1969828104483895, 0.30580088146962225, 0.11484045098768547, 0.21451069100294262, 0.11409730883315206, 0.11137018329463899, 0.1056221679027658, 0.17812759877415374, 0.2596555935451761, 0.12061300920322537, 2.672144863754511, 18.573956228792667, 40.45383006334305, 50.42290672659874, 25.2885265275836, 37.22292423248291, 43.10128480195999, 32.78213672339916, 25.480982400476933, 19.849779568612576, 13.004353791475296, 4.282983876764774, 0.4598444967996329, 1.7734490311704576, 5.702929208055139, 9.356955159455538, 11.650406643748283, 7.004622034728527, 13.650522418320179, 7.359962817281485, 8.608426675200462, 6.131079783663154, 4.48690278455615, 1.9743653875775635, 2.190137403085828, 4.533503958955407, 7.788633489981294, 8.945496138185263, 15.056310184299946, 24.33876559138298, 32.406006306409836, 40.31709060072899, 48.628141433000565, 60.09659484028816, 62.88411006331444, 61.449196860194206, 63.25240910053253, 62.485078275203705, 64.76202249526978, 63.400034978985786, 62.811723947525024, 59.854965806007385, 59.819221124053, 59.13132883608341, 59.11633484065533, 57.87551522254944, 59.32120084762573, 62.69008867442608, 56.16461142897606, 47.7491308003664, 56.31468057632446, 56.946415677666664, 58.81692610681057, 59.8553191870451, 57.64585554599762, 57.07795321941376, 59.470950812101364, 58.79127748310566, 56.32886901497841, 58.57645221054554, 59.979006350040436, 57.95367702841759, 59.31942254304886, 57.75478050112724, 55.74140913784504, 59.081414714455605, 47.86702707409859, 50.52825227379799, 52.483418360352516, 44.9432435631752, 29.563230648636818, 12.44930712506175, 3.6356629617512226, 1.236934089101851, 1.4313906733877957, 1.7486107139848173, 1.3986574485898018, 3.080896530300379, 5.216909162700176, 5.404248610138893, 5.677746534347534, 7.3413746897131205, 6.822183849290013, 9.196232333779335, 10.528222359716892, 5.02834428101778, 6.498856348916888, 3.977812514640391, 2.3739257035776973, 4.258998613804579, 15.303619913756847, 25.820036306977272, 36.695459336042404, 27.368443720042706, 25.816762782633305, 36.007369458675385, 25.518493987619877, 8.780546989291906, 0.8143641077913344, 0.19195524975657463, 0.15919889963697642, 0.2181755201308988, 0.14147004549158737, 0.17362043203320354, 0.10216959301033057, 0.16861903946846724, 0.07607703140820377, 0.12907033116789535, 0.1631976358476095, 0.26162264111917466, 0.1482571047381498, 0.11780364628066309, 0.2627433434827253, 0.16952236677752808, 0.08817786059807986, 0.10883810158702545, 0.10055688384454697, 0.3723313333466649, 0.13006967754336074, 0.08510430052410811, 0.18443193548591807, 0.09476837687543593, 0.1840290383552201, 0.19342571147717535, 0.10814700624905527, 0.17379966069711372, 0.16955263155978173, 0.10952577562420629, 0.18485899694496766, 0.15512053098063916, 0.11450059930211864, 0.09533447228022851, 0.18092600017553195, 0.12216109957080334], [0.07469542702892795, 0.040186676997109316, 0.017720863070280757, 0.0661916911485605, 0.038905214314581826, 0.007874848288338399, 0.043738937165471725, 0.025371834162797313, 0.003565389224604587, 0.06303181929979473, 0.04498623879044317, 0.029296177490323316, 0.014990569488873007, 0.09422194096259773, 0.020905500387016218, 0.05535197866265662, 0.021251018370094243, 0.10308058670489118, 0.0021344250671972986, 0.01824854305596091, 0.04645084867661353, 0.033759418365661986, 0.0888110461528413, 0.0387332549871644, 0.05326420592609793, 0.041222455402021296, 0.03205631561286282, 0.02664963249117136, 0.06099970392824616, 0.08054846373852342, 0.024707014563318808, 0.026167817231907975, 0.04876997852989007, 0.03281534343841486, 0.08340939850313589, 0.09322750760475174, 0.04560642933938652, 0.09550302143907174, 0.02325855937669985, 0.08590227997046895, 0.051719677867367864, 0.10850918173673563, 0.02190741459344281, 1.352058055344969, 10.683963652700186, 30.717234425246716, 36.636395305395126, 21.07491932809353, 22.688457146286964, 34.03804153203964, 42.057799994945526, 25.88208507746458, 12.834576051682234, 10.131002124398947, 4.084413656964898, 1.532957679592073, 0.16508356668055058, 1.0198590997606516, 2.607845664024353, 4.420684687793255, 3.5645979875698686, 8.776148725301027, 24.216676242649555, 5.47210774384439, 3.8790030917152762, 0.6902540987357497, 0.2047144901007414, 0.24919840623624623, 0.6009435129817575, 1.5366229391656816, 3.441614736802876, 6.600838601589203, 13.941310364753008, 20.67933015525341, 29.793566688895226, 42.25822024047375, 57.721562683582306, 62.47458703815937, 59.98640835285187, 59.05033238232136, 57.834359630942345, 59.9300991743803, 58.24024625122547, 53.83423067629337, 55.14533892273903, 54.017304852604866, 58.049640879034996, 59.955903589725494, 59.61951524019241, 55.26892349123955, 56.19606614112854, 54.98554229736328, 54.90373648703098, 59.824806824326515, 58.163577765226364, 58.63945662975311, 59.562449902296066, 57.2477775067091, 53.22798080742359, 55.39720080792904, 57.4743365496397, 56.81711621582508, 56.6081578284502, 57.233273684978485, 55.36716341972351, 57.362569347023964, 52.49018579721451, 43.57377044856548, 40.90164363384247, 45.51670119166374, 34.139583483338356, 17.963347993791103, 5.137012749910355, 1.3334185117855668, 0.4479086247738451, 0.5342274648137391, 0.9951790084596723, 0.437067806487903, 1.6839279723353684, 2.760309395380318, 3.2936820248141885, 3.232237184420228, 2.585715176537633, 4.03366120532155, 4.12529993802309, 2.174204383045435, 3.8404059503227472, 1.4688924048095942, 0.6907415413297713, 0.7404810504522175, 4.431040557101369, 8.65576358512044, 15.901164449751377, 18.2531850412488, 14.85660145059228, 16.508793644607067, 23.436625599861145, 16.37939728796482, 6.589655326679349, 0.5307688191533089, 0.11393885288271122, 0.026170915698457975, 0.014566763275070116, 0.03281500576122198, 0.0475930176617112, 0.02260663459310308, 0.03831793801509775, 0.021314093501132447, 0.023090884096745867, 0.051614066542242654, 0.03418670989049133, 0.0798537689843215, 0.024861576093826443, 0.033489462148281746, 0.053938435958116315, 0.021037821607023943, 0.03392204518604558, 0.06382219173246995, 0.06747367704520002, 0.039133959071477875, 0.003942373805330135, 0.10426239750813693, 0.05531541304662824, 0.05177510145585984, 0.02948992627352709, 0.02605642643175088, 0.06063576955057215, 0.08523604657966644, 0.03239408557419665, 0.065123228559969, 0.01886979487608187, 0.034651795285753906, 0.05789668430224992, 0.059927434122073464, 0.024893117370083928, 0.07265647276653908, 0.03578781928808894, 0.039520209829788655, 0.07060649761115201, 0.012656787785090273, 0.035947911674156785, 0.015411817148560658, 0.06731249741278589, 0.018614796645124443, 0.05657788417011034, 0.014423652155528544, 0.021871064200240653, 0.03978707500209566, 0.0583059750351822, 0.10827772071934305, 0.017812037767725997, 0.009470204186072806, 0.036507491022348404, 0.015090505239641061, 0.02692393583856756, 0.010946012152999174, 0.009716637105157133, 0.01553770765895024, 0.03391345111595001, 0.09312432681326754, 0.05115593507071026, 0.10040960463811643, 0.060992074650130235, 0.03291820510639809, 0.028972803338547237, 0.02574476893641986, 0.01496349686931353, 0.01486774775912636, 0.0103260247669823, 0.017556564562255517, 0.04326173620938789, 0.051623202380142175, 0.018768788577290252, 0.05068705359008163, 0.02079031906760065, 0.02770643408439355, 0.06470913242083043, 0.05372907609853428, 0.032995763249346055, 2.2433609096333385, 14.284118469804525, 37.92622469365597, 36.28203772008419, 24.082197658717632, 28.546612299978733, 33.33187222480774, 27.22074754536152, 20.67064382135868, 18.964888751506805, 17.2456881031394, 5.321741737425327, 1.3971822964958847, 0.09036341129103675, 0.7949874037876725, 1.674955110065639, 3.4716701740399003, 4.906710432842374, 17.933213710784912, 19.397911615669727, 4.9093864392489195, 4.537595864385366, 2.6369827380403876, 1.4114122954197228, 0.8373440278228372, 0.9725330548826605, 1.6440315381623805, 4.120011096820235, 8.344134707003832, 16.372599452733994, 22.89411161094904, 32.721590772271156, 46.82593233883381, 60.411221757531166, 62.575984597206116, 60.10865919291973, 60.3509683907032, 60.0468935072422, 61.19712978601456, 60.039126724004745, 56.891896203160286, 57.990968227386475, 57.49267436563969, 59.074366092681885, 61.54142551124096, 59.05523031949997, 57.54807539284229, 55.59118799865246, 52.03232556581497, 57.028601467609406, 59.83539305627346, 58.85157264769077, 60.46267479658127, 60.450545847415924, 58.68228793144226, 55.05735844373703, 57.078302800655365, 59.18999768793583, 57.853791788220406, 57.00148992240429, 57.828443348407745, 55.97317010164261, 55.07881209254265, 55.48007436096668, 52.13742792606354, 45.715407729148865, 49.23607461154461, 38.1053850799799, 22.019626535475254, 7.677105674520135, 2.844815435819328, 1.0904967156238854, 1.4250042848289013, 2.4291082425042987, 2.420595749281347, 3.18475398235023, 3.1642635818570852, 3.5679736314341426, 3.25596216134727, 4.406993072479963, 5.073181875050068, 3.791157742962241, 2.2780019883066416, 3.037066594697535, 0.9309821657370776, 0.6856119947042316, 0.4931308887898922, 5.011708298698068, 10.888111498206854, 19.24686212092638, 22.98996526747942, 21.895320005714893, 19.41611833870411, 25.35682786256075, 21.993797421455383, 10.158264711499214, 1.188821664545685, 0.006996377360337647, 0.0045884666997153545, 0.08915276062907651, 0.007771886894261115, 0.029967069713165984, 0.0156665686154156, 0.02581901710072998, 0.008880459317879286, 0.03364969183166977, 0.026313858907087706, 0.04584304086165503, 0.04145836930547375, 0.03631613195466343, 0.01927711706230184, 0.09391204977873713, 0.014571926767530385, 0.0285505342981196, 0.047770747187314555, 0.0664267515821848, 0.04749578518385533, 0.053402301055029966, 0.008717530072317459, 0.035245090402895585, 0.06490019834018312, 0.04984018887626007, 0.01070995816917275, 0.10206163278780878, 0.057108909386442974, 0.014970077863836195, 0.048187774809775874, 0.006926557962287916, 0.07845271291444078, 0.06841146227088757, 0.05345262979972176, 0.0778075194102712, 0.0466628134745406, 0.20186578592984006, 0.20470482733799145, 0.17103121237596497, 0.1654457050608471, 0.1304196595447138, 0.1668238139245659, 0.1859654500731267, 0.10889954399317503, 0.147374750522431, 0.11865759850479662, 0.11001805702107958, 0.10488867366802879, 0.20206849614623934, 0.15638613025657833, 0.14112987468251958, 0.15092537796590477, 0.10847266064956784, 0.14827677165158093, 0.11433858846430667, 0.12533682369394228, 0.15025349683128297, 0.0859662308357656, 0.14723714150022715, 0.18987768155056983, 0.14173588278936222, 0.19236104126321152, 0.14504149759886786, 0.10200220160186291, 0.09260396254830994, 0.12068934651324525, 0.12470708170440048, 0.12777957308571786, 0.10846535791642964, 0.08662004809593782, 0.25525011587888, 0.20255446928786114, 0.16633695020573214, 0.1626528103952296, 0.18750175513559952, 0.1745058735832572, 0.1808685579453595, 0.19456174661172554, 0.1377934607444331, 1.9763741735368967, 15.922487955540419, 43.45770187675953, 47.39746727049351, 29.55139998346567, 34.56536203622818, 42.000259682536125, 52.71715521812439, 36.53834916651249, 18.529610708355904, 13.8477698341012, 5.222187079489231, 2.328057177364826, 0.5166510329581797, 2.0521131344139576, 7.6817642245441675, 11.662081517279148, 9.197408370673656, 19.301807172596455, 34.26278807222843, 11.216543074697256, 8.663215935230255, 3.090166845358908, 1.3355474662967026, 0.7524878124240786, 0.8629508537705988, 1.8527419888414443, 4.468752583488822, 7.762140361592174, 15.728057138621807, 23.003790825605392, 32.99410454928875, 45.565068796277046, 60.423818081617355, 65.08435919880867, 62.45881028473377, 63.096077889204025, 61.77402622997761, 63.495166674256325, 60.9821031242609, 58.91727492213249, 59.898519068956375, 59.63341109454632, 61.90789304673672, 63.74431550502777, 60.81974923610687, 57.773502096533775, 56.81196749210358, 56.8425178527832, 55.716364681720734, 58.639939203858376, 58.25424090027809, 62.31960095465183, 62.016590014100075, 60.38477137684822, 56.62458434700966, 59.08982366323471, 59.62097816169262, 58.346591144800186, 57.692209258675575, 59.69982013106346, 54.469499588012695, 55.60812748968601, 54.018323197960854, 50.4425972700119, 48.46658170223236, 48.68264190852642, 36.06820799410343, 20.385250635445118, 6.698576956987381, 2.4926648195832968, 0.9243209450505674, 1.6355839977040887, 2.9902766179293394, 2.9735558526590466, 5.562010444700718, 5.9819221124053, 7.860232098028064, 7.187632564455271, 7.585151558741927, 9.509806707501411, 10.090217962861061, 6.559560941532254, 8.949456475675106, 3.9109320659190416, 2.6672260276973248, 1.395249031484127, 5.638544987887144, 11.675139516592026, 22.807835340499878, 27.138265371322632, 23.902214616537094, 25.708301402628422, 32.59169094264507, 25.02489287406206, 10.294137820601463, 0.9874609694816172, 0.13829960545990616, 0.18064698233501986, 0.1599084967165254, 0.11404151417082176, 0.14733808842720464, 0.1174387322680559, 0.12968799099326134, 0.13235262769740075, 0.08319003449287266, 0.14594200474675745, 0.19359836471267045, 0.16927867516642436, 0.2023357732105069, 0.12391952943289652, 0.1814023105544038, 0.11073332410887815, 0.1486055727582425, 0.2053426142083481, 0.13074713962851092, 0.09536391327856109, 0.12046631629345939, 0.18428280833177269, 0.2976877230685204, 0.2406651180353947, 0.18571678607258946, 0.09071302964002825, 0.24501434090780094, 0.18395896477159113, 0.17206459364388138, 0.20328459417214617, 0.08849554433254525, 0.22589835338294506, 0.22671544313197955, 0.1556455559330061, 0.1493539841612801, 0.10482539073564112], [0.03458302788203582, 0.01669802029937273, 0.04606575566867832, 0.01953616927494295, 0.03707827680045739, 0.04539873560133856, 0.04446296901733149, 0.08978847690741532, 0.10958666884107515, 0.06736731986165978, 0.1204089260136243, 0.033754954347386956, 0.10340639695641585, 0.008320543220179388, 0.08310721081215888, 0.020139440712227952, 0.006260315758481738, 0.11422513634897768, 0.03047183960006805, 0.026593110524117947, 0.012883042636531172, 0.03952698934881482, 0.030725457436346915, 0.08389813985559158, 0.07224460307043046, 0.08826043194858357, 0.039596168644493446, 0.04377582561573945, 0.08432163900579326, 0.014662762860098155, 0.06716429052175954, 0.04602550528943539, 0.051814090184052475, 0.09080625080969185, 0.032233291858574376, 0.16292174987029284, 0.041034688329091296, 0.04606544396665413, 0.036614389973692596, 0.030149398698995356, 0.06667937865131535, 0.010401858344266657, 0.07370660430751741, 0.0295980609007529, 0.7570161006879061, 8.89680840075016, 23.904238007962704, 36.85124337673187, 19.685504883527756, 13.08580907061696, 17.526360042393208, 40.260260850191116, 34.94995079934597, 15.846392288804054, 11.356326173990965, 6.9842589274048805, 2.3015327006578445, 0.6731155340094119, 1.2739949254319072, 2.2779658902436495, 3.582938415929675, 20.08754041045904, 20.283176712691784, 1.9226595433428884, 2.122862725518644, 2.0134699204936624, 2.4462215742096305, 0.32533705816604197, 0.06304310736595653, 0.1414772294810973, 0.29809284664224833, 0.9258709056302905, 2.978457589633763, 8.050781898200512, 15.014000404626131, 25.445708893239498, 40.264915600419044, 49.4457283616066, 55.83813674747944, 59.27465334534645, 60.543914437294006, 61.70505233108997, 61.21639095246792, 61.532298400998116, 60.276161804795265, 60.248985663056374, 59.585043489933014, 56.32377348840237, 58.89298662543297, 55.077839344739914, 60.26608854532242, 55.124291852116585, 54.92349922657013, 56.94185212254524, 58.833660408854485, 59.94788981974125, 57.34659120440483, 58.249004781246185, 56.0849829018116, 57.71480664610863, 56.01017251610756, 58.790639117360115, 58.6665453761816, 60.857112631201744, 59.58558306097984, 61.71697989106178, 49.800386130809784, 37.63351120054722, 36.423241943120956, 23.952503018081188, 10.425435025244951, 2.7735155867412686, 0.5606643087230623, 0.6634239165578038, 0.6363519723527133, 3.2729892851784825, 2.344422424212098, 1.682196690235287, 2.501082792878151, 2.8464999329298735, 2.7860216656699777, 2.869162866845727, 2.1719774650409818, 5.377744557335973, 2.665143976919353, 1.8070926633663476, 2.3600685596466064, 0.6519933580420911, 1.4263352821581066, 4.5789647195488214, 11.75284344702959, 18.536912016570568, 18.804123178124428, 14.458982236683369, 19.551816657185555, 25.475195311009884, 18.447404019534588, 7.0672431495040655, 0.6255723664071411, 0.017278609848290216, 0.04978096178092528, 0.04749748841277324, 0.04114931674848776, 0.01964003655302804, 0.04981551617674995, 0.04373091825982556, 0.10322545393137261, 0.04850748460739851, 0.016287033758999314, 0.06366814413922839, 0.006836330894657294, 0.016214026836678386, 0.007773659699523705, 0.03508280868118163, 0.02805516000080388, 0.024411472804786172, 0.02088188524794532, 0.013815088277624454, 0.039707757969154045, 0.052356755986693315, 0.011977404465142172, 0.022149549549794756, 0.046712567054782994, 0.02413965750747593, 0.032802073837956414, 0.02189777595049236, 0.02503940024325857, 0.017482587281847373, 0.011175446179549908, 0.01364811711027869, 0.025900321234075818, 0.04023718385724351, 0.03459147352259606, 0.08352651682798751, 0.021238002955215052, 0.049392466025892645, 0.02324516917724395, 0.07273795315995812, 0.05493728880537674, 0.02788256428175373, 0.04745870748593006, 0.03178495302563533, 0.011688622744259192, 0.04498117734328844, 0.04283870090148412, 0.06551742029841989, 0.03308361869130749, 0.0746749882819131, 0.05828208159073256, 0.04629877148545347, 0.037489816240849905, 0.0061082881984475534, 0.04213758285914082, 0.020094674364372622, 0.03303115627204534, 0.0645814607560169, 0.0038227351933528553, 0.029516717804654036, 0.11101802680059336, 0.04550144883978646, 0.07381070536212064, 0.10425583692267537, 0.05771200085291639, 0.01603738455742132, 0.016003882155928295, 0.0356559656211175, 0.03489195427391678, 0.07297490607015789, 0.05066651094239205, 0.022443983652919997, 0.03830023037153296, 0.07086777070071548, 0.04345572990132496, 0.014833967052254593, 0.06813706058892421, 0.028870027017546818, 0.08159483259078115, 0.10060116779641248, 0.03178322011081036, 0.03542447120707948, 1.3459849124774337, 12.357672192156315, 32.81999409198761, 38.9129975438118, 24.56231329590082, 19.41380426287651, 27.42434062063694, 36.70128062367439, 22.38726630806923, 16.447523832321167, 18.584382869303226, 10.083169341087341, 1.6584930871613324, 0.43691388505976647, 0.17656490294029936, 0.9866760147269815, 1.9876053021289408, 11.643465366214514, 9.837752860039473, 6.5252891555428505, 4.3625330831855536, 2.5540391262620687, 2.78807426802814, 1.3446858571842313, 0.7868849916849285, 0.23427780921338126, 0.48513021029066294, 1.4443654334172606, 4.064740212634206, 10.274031199514866, 16.084388718008995, 28.608070202171803, 43.60443100333214, 52.47717909514904, 59.06933896243572, 59.6347676217556, 60.92909216880798, 61.487654596567154, 63.09275306761265, 63.26548419892788, 60.470939353108406, 60.244794487953186, 59.60074804723263, 58.94602417945862, 59.130876660346985, 56.42313815653324, 58.29151690006256, 52.94165097177029, 56.369006261229515, 58.1696992367506, 60.63378721475601, 59.52797815203667, 59.17260602116585, 59.928180277347565, 58.38171266019344, 59.96193386614323, 57.55838803946972, 58.351614475250244, 59.0327051281929, 58.035327047109604, 58.264044374227524, 61.30766585469246, 54.6868859231472, 40.05758352577686, 41.95636823773384, 27.61696558445692, 13.56145329773426, 5.149934906512499, 1.4893969357945025, 1.7415462993085384, 2.244783458299935, 4.019029615446925, 4.719946654513478, 3.5830324608832598, 3.4324669651687145, 4.284375552088022, 3.7700104527175426, 5.839246893301606, 4.387784628197551, 5.396370207890868, 1.5548257436603308, 1.9913367019034922, 0.6847367947921157, 0.10655349644366652, 1.0076390742324293, 6.07466658577323, 13.773953095078468, 21.933240070939064, 24.2065516859293, 20.00820256769657, 20.694326050579548, 26.982312239706516, 23.345219604671, 10.291928239166737, 1.6250373073853552, 0.012430549631972099, 0.07024897538940422, 0.07505286019295454, 0.02307097598531982, 0.0261557053818251, 0.026957690570270643, 0.050657872343435884, 0.06676231365418062, 0.05155753344297409, 0.06493749868241139, 0.05711005229386501, 0.08804664146737196, 0.06740181488567032, 0.029946842478238977, 0.03900827265169937, 0.01173986525827786, 0.04831457816180773, 0.07789639901602641, 0.036649048270192, 0.04238806141074747, 0.08256656365119852, 0.03186490459484048, 0.05056788322690409, 0.03500784434436355, 0.027594152707024477, 0.010686887580959592, 0.018083853065036237, 0.06924945089849643, 0.013929038559581386, 0.16182078863494098, 0.04624014924047515, 0.039498668993473984, 0.04338946353527717, 0.035950446108472534, 0.058894375688396394, 0.01766392364515923, 0.018324884076719172, 0.08864398128935136, 0.20211839815601707, 0.19740243558771908, 0.08151754533173516, 0.13259780360385776, 0.13030948030063882, 0.1639764753053896, 0.23566889081848785, 0.2021049355971627, 0.1842275628587231, 0.14712627948028967, 0.22031076805433258, 0.19838413369143382, 0.1295838231453672, 0.2241328137461096, 0.15937910793581977, 0.1270092831691727, 0.22496948135085404, 0.1216532033868134, 0.1427491073263809, 0.11588966226554476, 0.13925344333983958, 0.16935437422944233, 0.114297837135382, 0.2093835489358753, 0.19882891763700172, 0.10649858493707143, 0.1155655960610602, 0.21685503161279485, 0.08077647376921959, 0.1146152536966838, 0.14427393878577277, 0.20849025546340272, 0.2881891233846545, 0.18604088196298108, 0.3333743097027764, 0.2152649060008116, 0.14151493058307096, 0.1590679699438624, 0.15579637518385425, 0.25460325996391475, 0.1564804869121872, 0.21161333163036034, 0.0883846080978401, 1.3032642798498273, 12.775337230414152, 36.503383442759514, 50.3201450407505, 29.5777078717947, 22.931058928370476, 26.415183171629906, 48.217322677373886, 48.77298966050148, 25.008234567940235, 16.906045228242874, 8.932937812060118, 2.7767506381496787, 1.3406143756583333, 2.8367118956521153, 5.654510306194425, 9.105722140520811, 32.607471495866776, 30.232614129781723, 8.714725971221924, 8.233566340059042, 6.5321810357272625, 6.599983647465706, 2.3647525208070874, 0.6883408420253545, 0.4064337315503508, 0.6633910839445889, 1.4438885590061545, 3.3654409367591143, 9.266011789441109, 15.750248897820711, 28.667941689491272, 42.75144137442112, 52.99111671745777, 59.02506373822689, 62.538408413529396, 64.11199897527695, 64.26302567124367, 65.48972144722939, 65.18777444958687, 62.78911896049976, 62.528057768940926, 59.95798587799072, 59.61361415684223, 60.41941411793232, 59.11769136786461, 57.94191285967827, 55.47463685274124, 56.52515888214111, 57.757603749632835, 62.2387108951807, 59.231780245900154, 58.62008906900883, 60.16529895365238, 57.66765497624874, 60.48204615712166, 57.76806838810444, 59.89724613726139, 58.00183944404125, 58.16619962453842, 57.32131116092205, 60.26104621589184, 55.02630650997162, 48.20408798754215, 42.38253436982632, 26.25069759786129, 12.632555142045021, 3.8890369283035398, 1.6466605220921338, 1.5957370796240866, 2.8709855815395713, 7.3428366612643, 7.910496275871992, 5.89094596914947, 8.154556229710579, 7.253417484462261, 7.839860916137695, 7.880857391282916, 5.870253704488277, 11.861899495124817, 8.345399089157581, 6.526559237390757, 5.932864844799042, 2.0211538206785917, 1.7036174470558763, 6.7807812709361315, 13.965857047587633, 25.233674570918083, 28.332706578075886, 23.692954145371914, 29.078543856739998, 34.610788598656654, 26.463921256363392, 10.073874089866877, 1.3459114101715386, 0.10223102057352662, 0.16540741024073213, 0.1615795906400308, 0.10849215686903335, 0.062489992124028504, 0.165354851342272, 0.15931544650811702, 0.28135566506534815, 0.170960248215124, 0.18988450930919498, 0.12639913387829438, 0.1311945656198077, 0.19671572634251788, 0.07049249630654231, 0.13807859388180077, 0.08544742508092895, 0.21788621612358838, 0.15422532276716083, 0.18054838059470057, 0.0655929338245187, 0.16789393150247633, 0.11431843173340894, 0.12787682411726564, 0.0883326429175213, 0.10527323975111358, 0.0967590618529357, 0.1181987879681401, 0.12209350476041436, 0.05225452514423523, 0.21542942529777065, 0.14338247099658474, 0.135395537072327, 0.1415333803743124, 0.08645408903248608, 0.20863979822024703, 0.11107371756224893, 0.13445421180222183], [0.11285056752967648, 0.0667492815409787, 0.027996819771942683, 0.014363951013365295, 0.055294328631134704, 0.06772640801500529, 0.09737609827425331, 0.03806624605203979, 0.023565313131257426, 0.022963594637985807, 0.02188495906011667, 0.04975238909537438, 0.10153559109312482, 0.041424508817726746, 0.06880650747916661, 0.03311680011393037, 0.03983970811532345, 0.017897930229082704, 0.03653855361335445, 0.03394976811250672, 0.08272858191048726, 0.01425184496838483, 0.05152591424121056, 0.06644753171713091, 0.01504877334809862, 0.0347357878490584, 0.012465430572774494, 0.034688412852119654, 0.031362363006337546, 0.06968343659536913, 0.027782489378296304, 0.04149699438130483, 0.08102319334284402, 0.03933915177185554, 0.060563662482309155, 0.029647745832335204, 0.05195900936087128, 0.08016037987545133, 0.022015217109583318, 0.08766746337641962, 0.009122415231104242, 0.05610700260149315, 0.017185772740049288, 0.05185227368201595, 0.05814858406665735, 0.34586302237585187, 4.802212240174413, 20.163350142538548, 33.629924431443214, 21.76150258630514, 10.209428016096354, 8.509508483111858, 26.824339516460896, 47.26940654218197, 29.07028689980507, 12.763421069830656, 6.812611212953925, 2.539875623770058, 0.21913952543400228, 0.718216085806489, 2.4670439818874, 12.408025190234184, 7.615801189094782, 4.078410929068923, 3.471001647412777, 1.9151867693290114, 1.6899425745941699, 1.3707946124486625, 1.1074730171822011, 0.29362927365582436, 0.41545792075339705, 0.24614589347038418, 0.8316030108835548, 0.7079052203334868, 3.637484726496041, 7.784782871603966, 13.29948490485549, 23.56416005641222, 35.79933442175388, 43.64717110991478, 54.45442199707031, 62.28480242192745, 58.082672506570816, 58.33134636282921, 57.80545838177204, 56.75258427858353, 59.02225948870182, 58.763694763183594, 59.93881970643997, 48.3483624458313, 65.89441493153572, 38.222787380218506, 38.999279513955116, 57.69059434533119, 59.543789103627205, 61.62817485630512, 61.481833308935165, 58.81080463528633, 57.904872447252274, 56.80284798145294, 62.37555295228958, 59.18916553258896, 57.485606744885445, 58.74282248318195, 57.41752199828625, 45.71443498134613, 28.182968012988567, 26.7979309335351, 15.855599194765091, 3.1109752412885427, 0.8053735527209938, 0.3952355543151498, 0.3941674850648269, 1.2610150594264269, 2.3637814354151487, 1.5808852203190327, 3.2323568779975176, 2.972844340838492, 2.5224509462714195, 3.7199545511975884, 2.3253255989402533, 2.864456344395876, 4.735566666349769, 2.791124079376459, 0.6453239440452307, 0.9403139899950475, 0.8250218827743083, 1.4556535589508712, 5.005125151947141, 10.461678430438042, 20.087278224527836, 14.183919746428728, 9.390329718589783, 14.367961920797825, 27.933120019733906, 22.733735516667366, 8.019147645682096, 1.2815054599195719, 0.04516166394751053, 0.036410351312952116, 0.03717872277775314, 0.03171998912876006, 0.009077954091480933, 0.03816029471636284, 0.07836099088308401, 0.061577373126056045, 0.026432162812852766, 0.025991835464083124, 0.04365359760413412, 0.13818669511238113, 0.10693070784327574, 0.0356342763552675, 0.029119633545633405, 0.037001627788413316, 0.04589835683873389, 0.06641044659772888, 0.0833183889335487, 0.025175419214065187, 0.06414688876247965, 0.12082746019586921, 0.01647042401600629, 0.03402249487407971, 0.05907869548536837, 0.008865144172887085, 0.05896848284464795, 0.034837057610275224, 0.04886052425717935, 0.04255151201505214, 0.028919448486703914, 0.03837725045741536, 0.040130032575689256, 0.027290558646200225, 0.020642299568862654, 0.04346563757280819, 0.04561991787340958, 0.027211263877688907, 0.013259097213449422, 0.07230084302136675, 0.02584032972663408, 0.05312286019034218, 0.045419938760460354, 0.08128255911287852, 0.08167729261913337, 0.054399061045842245, 0.026599533812259324, 0.04290235861844849, 0.03277523777796887, 0.04574857659463305, 0.01813647133531049, 0.050926485273521394, 0.03947618191887159, 0.031078552747203503, 0.026315910945413634, 0.019708082218130585, 0.015862465916143265, 0.03535586336511187, 0.035957882428192534, 0.08631431293906644, 0.016970509095699526, 0.025378413301950786, 0.033175036442116834, 0.05003787846362684, 0.02524896975955926, 0.04577471503580455, 0.0370697754988214, 0.05158973151992541, 0.008758163585298462, 0.043135897649335675, 0.08735547933611088, 0.052237270210753195, 0.053940684665576555, 0.04804235097253695, 0.019801624366664328, 0.04403259757964406, 0.02073889751045499, 0.046157670658431016, 0.03792855168285314, 0.08072699478361756, 0.026952870321110822, 0.05067625534138642, 0.06099613419792149, 0.7407843810506165, 8.370155710726976, 28.428790122270584, 37.05902762711048, 23.800300285220146, 12.226054854691029, 15.719987321645021, 33.798179402947426, 40.094585940241814, 21.07768177986145, 20.99841993302107, 14.973551575094461, 3.559238137677312, 0.32850157585926354, 0.16851260064868256, 1.2560222460888326, 2.6971437223255634, 4.569479953497648, 2.591406083665788, 4.545289501547813, 3.3878991566598415, 3.9505729638040066, 1.930400321725756, 3.241439815610647, 0.7544515945482999, 0.46870683843735605, 0.587593998061493, 1.3825693493708968, 2.114977198652923, 4.377181297168136, 10.978421252220869, 17.73941271007061, 28.462986387312412, 38.98440331220627, 47.68048368394375, 57.039157301187515, 61.60498850047588, 58.45673583447933, 59.82782386243343, 58.52480158209801, 57.79865674674511, 60.742453783750534, 59.458088502287865, 59.69129718840122, 54.67782720923424, 60.209422186017036, 41.964321210980415, 49.655971080064774, 58.13164047896862, 59.8273640871048, 60.920774415135384, 60.77404908835888, 62.3795123398304, 58.94608877599239, 58.779441118240356, 60.113017559051514, 59.46475334465504, 56.457723900675774, 58.499658331274986, 60.209874361753464, 51.97140343487263, 35.2525969594717, 32.90646605193615, 19.776956476271152, 5.236972086131573, 2.2166041703894734, 1.0405324841849506, 1.430031058844179, 2.7247715648263693, 3.6787944473326206, 2.6784586999565363, 6.547164581716061, 3.4725576639175415, 3.668254050426185, 5.332790119573474, 4.139942927286029, 4.2592517752200365, 4.56111422739923, 2.6438948046416044, 0.9646711579989642, 0.13985571102239192, 0.2292271825717762, 1.371440696530044, 6.608927892521024, 15.421798322349787, 25.78931875526905, 22.39902287721634, 15.315148495137691, 14.940202664583921, 29.046726264059544, 28.51006966084242, 11.765648759901524, 2.3739221412688494, 0.055230915822903626, 0.04562363974400796, 0.03443039779085666, 0.01701136803603731, 0.015540690164925763, 0.03592323526390828, 0.013494329268723959, 0.02458840452163713, 0.039083901210688055, 0.036994395559304394, 0.040366247048950754, 0.03816318538156338, 0.01602211115823593, 0.024803645901556592, 0.0066909460201713955, 0.026099192691617645, 0.02913020915002562, 0.005819231882924214, 0.022057489841245115, 0.01310563035076484, 0.03224969703296665, 0.03409653152630199, 0.021827424061484635, 0.044090314404456876, 0.06316988845355809, 0.0636242980544921, 0.06324539455818012, 0.030835536490485538, 0.0355328247678699, 0.08025114453630522, 0.061694057294516824, 0.06589068347238936, 0.03164690613630228, 0.014874405751470476, 0.06858766297227703, 0.014238772964745294, 0.07099763912265189, 0.05613581648503896, 0.18318085261853412, 0.22407721204217523, 0.13565574889071286, 0.11690921732224524, 0.15606204920914024, 0.18365590134635568, 0.22272058093221858, 0.13083431229460984, 0.12326991272857413, 0.11685961959301494, 0.08796379552222788, 0.10719053374486975, 0.19838817097479478, 0.22543029568623751, 0.19554356345906854, 0.13435102358926088, 0.07452463658410124, 0.15025584201794118, 0.1508251583436504, 0.21852291945833713, 0.15738666406832635, 0.09867565080639906, 0.11104831384727731, 0.14980767387896776, 0.08546838333131745, 0.17897042620461434, 0.12259764567716047, 0.10736526499385945, 0.13717997178900987, 0.14268804341554642, 0.16340278030838817, 0.1771711782203056, 0.15217723266687244, 0.21267081785481423, 0.2171281716437079, 0.07670265447814018, 0.1318560863728635, 0.15104588790563866, 0.15983775519998744, 0.16481741768075153, 0.13173461164114997, 0.18450597213814035, 0.08050848424318247, 0.15363570128101856, 0.17028796632075682, 1.0466621490195394, 8.820593990385532, 30.933739207684994, 49.08071614801884, 32.015714049339294, 19.71203126013279, 16.440346017479897, 33.522777780890465, 59.22483801841736, 37.196447253227234, 21.94652035832405, 9.61770761758089, 3.2485081488266587, 0.6712341599632055, 1.6055804514326155, 4.611486699432135, 17.48001392930746, 15.594135224819183, 10.281670689582825, 9.822214543819427, 5.7300288788974285, 6.140518002212048, 4.38384186476469, 3.035070989280939, 0.7780039182398468, 1.1316159716807306, 0.6557401351165026, 1.6774146468378603, 1.600275698583573, 4.406706187874079, 8.973006661981344, 15.56652020663023, 25.447483398020267, 38.40745747089386, 45.588760524988174, 57.650525495409966, 62.93932110071182, 59.51738052070141, 60.24092249572277, 58.933230265975, 57.687596306204796, 60.84141567349434, 59.23039332032204, 60.62286280095577, 53.63249570131302, 61.16394616663456, 44.86721344292164, 48.88315334916115, 62.29878567159176, 60.52917502820492, 61.211937591433525, 62.592388316988945, 63.56475993990898, 59.07065749168396, 58.175763711333275, 61.07231788337231, 59.47711028158665, 58.06360512971878, 57.686395570635796, 59.34722185134888, 51.29868373274803, 39.60138000547886, 32.14458413422108, 16.495621651411057, 3.89639048371464, 1.5433434722945094, 1.2752670259214938, 1.47201833082363, 2.956580026075244, 4.745159726589918, 3.190814657136798, 6.500487411394715, 6.772591760382056, 7.3221363220363855, 9.894285276532173, 7.6730650663375854, 8.563380092382431, 9.892432875931263, 8.664204832166433, 4.285534014925361, 3.0092725111171603, 1.8014688463881612, 1.7277828441001475, 6.992483111098409, 14.593279380351305, 27.56904635578394, 22.391136400401592, 16.77811749279499, 22.597801610827446, 35.98081648349762, 30.80830603837967, 12.35434927046299, 2.1076939394697547, 0.15406424703542143, 0.15529362950474024, 0.1265779320965521, 0.11631558823864907, 0.18383924150839448, 0.17996582435443997, 0.21641582861775532, 0.1896180782932788, 0.08898376618162729, 0.0952989308279939, 0.16972188575891778, 0.2970571944024414, 0.19682183861732483, 0.10868435827433132, 0.17312248062808067, 0.13200469402363524, 0.1380041564698331, 0.1533622050192207, 0.22566776809981093, 0.11555951787158847, 0.15053159440867603, 0.275467851315625, 0.20375182066345587, 0.13752518920227885, 0.20333943888545036, 0.16016630397643894, 0.10946321257506497, 0.15702494129072875, 0.10680516614229418, 0.26111872284673154, 0.20363579329568893, 0.18427391740260646, 0.11901820806087926, 0.10847778889001347, 0.17169185739476234, 0.0938570789003279, 0.13217439351137727, 0.18675442726816982], [0.058014630121761, 0.022786935660406016, 0.009329950335086323, 0.012170934314781334, 0.030953146488172933, 0.04722417397715617, 0.05232167837675661, 0.04125374434806872, 0.045131747974664904, 0.026570280206215102, 0.121356017771177, 0.08071592194028199, 0.017631141126912553, 0.08465222126687877, 0.01828778040362522, 0.041091711245826446, 0.03325817553559318, 0.06257808505324647, 0.00406016980377899, 0.054433693367172964, 0.03507236295263283, 0.031935278748278506, 0.018788264387694653, 0.05083445525087882, 0.016940851019171532, 0.12725505279377103, 0.030299550016934518, 0.09311140602221712, 0.06092799019825179, 0.10262194686220028, 0.026325161816203035, 0.06722380334394984, 0.024148155098373536, 0.07580394332762808, 0.04144847647694405, 0.01581846398039488, 0.0258433354247245, 0.014466503762378125, 0.03844800310616847, 0.07526725181378424, 0.00846197708597174, 0.03925464712665416, 0.02074742478725966, 0.002906847266785917, 0.07695916297961958, 0.049644221071503125, 0.08224944394896738, 3.275102209299803, 17.533948235213757, 29.865065552294254, 36.455407217144966, 22.549082525074482, 10.131141766905785, 20.296502597630024, 40.02950303256512, 32.37059220671654, 19.33872789144516, 12.353356573730707, 7.363939778879285, 0.6315197597723454, 0.8433718699961901, 1.440062045585364, 2.822064394131303, 3.7446247274056077, 3.002530485391617, 1.8276718840934336, 2.5916991429403424, 1.0279962443746626, 1.9023625762201846, 0.6423020374495536, 0.24103647388983518, 0.8125790941994637, 1.0065633757039905, 0.8733801066409796, 0.23395907162921503, 1.0129551077261567, 1.072688139975071, 3.295810385607183, 8.387635722756386, 16.15932259708643, 29.772909097373486, 46.40575088560581, 55.507242903113365, 65.6699001789093, 61.243304908275604, 60.29695048928261, 57.95765541493893, 62.303653210401535, 49.69326227903366, 42.23987862467766, 47.13142454624176, 28.596017248928547, 38.86822834610939, 48.95705558359623, 58.56828264892101, 54.53539565205574, 59.038762003183365, 60.24423211812973, 60.97908988595009, 60.40800713002682, 63.27387794852257, 60.41945971548557, 58.22092428803444, 48.8562735915184, 36.57572776079178, 24.12044830620289, 17.667370475828648, 9.408032968640327, 1.2056602234952152, 0.2103135787183419, 0.5203879543114454, 1.1748887621797621, 1.861233226954937, 2.7035155054181814, 2.574236229993403, 3.6320006707683206, 8.314989320933819, 3.1765637593343854, 2.884019357152283, 4.005845272913575, 2.975811744108796, 6.394122093915939, 3.539675837382674, 2.2140948800370097, 0.8278360473923385, 0.8081313141155988, 2.1573871979489923, 8.087993301451206, 13.26575031504035, 19.49579246342182, 12.548149321228266, 12.864549793303013, 17.91491199284792, 22.04792931675911, 23.458594121038914, 8.686542883515358, 1.0193702322430909, 0.07258710422320291, 0.03976381980464794, 0.04223147567245178, 0.041884202510118484, 0.04780923496582545, 0.05223274682066403, 0.013676751950697508, 0.043548761823331006, 0.04506473946094047, 0.04274319391697645, 0.03707364579895511, 0.0387717650301056, 0.08041685869102366, 0.042602905741659924, 0.047539991210214794, 0.007658023350813892, 0.0503381959424587, 0.042418214870849624, 0.010372384876973229, 0.019457820744719356, 0.06788629631046206, 0.0334106386435451, 0.029231924199848436, 0.05529458467208315, 0.028857505130872596, 0.08425963256740943, 0.028725185766234063, 0.06386811583070084, 0.02935776090453146, 0.03182328124239575, 0.024040601201704703, 0.008449252964055631, 0.057945825610659085, 0.02461381009197794, 0.036386446736287326, 0.02532300084567396, 0.028218313746037893, 0.02599731436930597, 0.0809917708102148, 0.021370858521549962, 0.02825646570272511, 0.004176465272394125, 0.03836245945421979, 0.035732269534491934, 0.031163155726972036, 0.07888991953223012, 0.034824574686354026, 0.025545839962433092, 0.07015893061179668, 0.09379800394526683, 0.043534163778531365, 0.04259372166416142, 0.0762416620273143, 0.02635723001731094, 0.014355096263898304, 0.0386428465571953, 0.01917828711157199, 0.0325447044451721, 0.0438762493286049, 0.021045630855951458, 0.022004704587743618, 0.032985310099320486, 0.05138090971740894, 0.02058017809758894, 0.04328664639615454, 0.03191681040334515, 0.021027850852988195, 0.03787965528317727, 0.03431646327953786, 0.03307100589154288, 0.02091036702040583, 0.06535379900014959, 0.028118140508013312, 0.06061819178285077, 0.08152581285685301, 0.08934960045735352, 0.05760922082117759, 0.04408578359289095, 0.04997283664124552, 0.04410996647493448, 0.041270754372817464, 0.052223659222363494, 0.05977645530947484, 0.09689314567367546, 0.03443633497226983, 0.25417750468477607, 5.929330084472895, 23.02822921425104, 34.68935318291187, 35.20242065191269, 18.90720594674349, 13.284339867532253, 28.112460896372795, 41.62811905145645, 24.219298101961613, 17.35217358916998, 13.31665713340044, 5.270553734153509, 0.5851826712023467, 0.581976652611047, 0.45959083072375506, 2.0672344230115414, 1.7039496917277575, 3.2131367968395352, 2.5640658382326365, 4.399317959323525, 3.4362382628023624, 5.213215285912156, 2.4551727063953876, 1.9880603277124465, 1.84423650149256, 2.582363043911755, 1.6147655085660517, 0.6390295224264264, 1.7242020112462342, 2.0653307251632214, 5.576674332842231, 11.529581677168608, 20.923358760774136, 35.60876704752445, 48.59415225684643, 57.72300660610199, 61.72179043292999, 62.051449343562126, 58.868151158094406, 58.67142051458359, 61.373356729745865, 53.02006736397743, 48.30643929541111, 50.84008254110813, 32.88020186126232, 42.49044097959995, 54.467801079154015, 61.53121925890446, 55.75650192797184, 60.472147688269615, 61.769033297896385, 60.004867762327194, 61.7687027156353, 62.636568546295166, 61.80315166711807, 60.17936959862709, 51.99789561331272, 41.43697030842304, 28.309115543961525, 22.304527647793293, 12.062559127807617, 2.220460488460958, 0.6161054712720215, 1.9776034075766802, 2.0084641641005874, 2.7111640200018883, 3.683273931965232, 4.877608744427562, 4.6729735750705, 5.899024335667491, 6.058912156149745, 6.008058534935117, 5.501521015539765, 2.91981581132859, 1.797320181503892, 2.157781426794827, 0.9324850444681942, 0.37646034616045654, 0.7133045524824411, 2.4868919793516397, 8.92407288774848, 17.243957296013832, 22.37178783863783, 16.31818827241659, 14.750986117869616, 15.299936961382627, 23.105076290667057, 28.040036782622337, 14.049592204391956, 2.3939520539715886, 0.11381839489331469, 0.04475432877370622, 0.03542462705809157, 0.08262122282758355, 0.05048396858910564, 0.06588697273400612, 0.007722620812273817, 0.019625640743470285, 0.034301520136068575, 0.02784850526950322, 0.007818428366590524, 0.018976352439494804, 0.07237640849780291, 0.07197309576440603, 0.08534566921298392, 0.07242602849146351, 0.026304105231247377, 0.06466272592660971, 0.07224181259516627, 0.061119271340430714, 0.09279181496822275, 0.05296323535731062, 0.08452822323306464, 0.022165784030221403, 0.0606481300201267, 0.02797640328935813, 0.05041135686042253, 0.06928075468749739, 0.008832195599097759, 0.017080686484405305, 0.026878468161157798, 0.023860559886088595, 0.050103354442398995, 0.0662325909070205, 0.02944464413303649, 0.011577998211578233, 0.010243196447845548, 0.046742624035687186, 0.05346128324163146, 0.12654352613026276, 0.07253883493831381, 0.10431172064272687, 0.09909657470416278, 0.08761329401750118, 0.09709300604299642, 0.1593257623608224, 0.16325979813700542, 0.08919017971493304, 0.12876486318418756, 0.21722842095186934, 0.20139759464655071, 0.09393464075401425, 0.19943207589676604, 0.06268801196711138, 0.0959867458732333, 0.10859856600291096, 0.12851426959969103, 0.0796558678848669, 0.13070100772893056, 0.09900753924739547, 0.15053043665830046, 0.10901125206146389, 0.11208180643734522, 0.1456931626307778, 0.22120226552942768, 0.13772844860795885, 0.10080965192173608, 0.1921002208837308, 0.18240045465063304, 0.09568844703608193, 0.2311328545329161, 0.11131654086057097, 0.13656961469678208, 0.1308658832567744, 0.13680885342182592, 0.20305089186877012, 0.20533578644972295, 0.24963232513982803, 0.20292380650062114, 0.1150093563774135, 0.16679350461345166, 0.16617902118014172, 0.09353748042485677, 0.1811311743222177, 0.09454571030801162, 0.3809952543815598, 5.589125314727426, 23.6807643994689, 42.06457503139973, 49.61613781750202, 34.2925138771534, 17.76836335659027, 30.767885707318783, 49.23390492796898, 39.1331235319376, 27.170605435967445, 16.814508140087128, 9.653552044183016, 1.0508102201856673, 1.7728025908581913, 4.49919892475009, 7.472579274326563, 10.240134168416262, 7.416041158139706, 6.613231161609292, 7.114585759118199, 6.328187081962824, 8.367346711456776, 2.6049708807840943, 1.4917581528425217, 3.0233106203377247, 3.1929195066913962, 1.9781084242276847, 0.5391111527569592, 1.3450644118711352, 1.8763327854685485, 3.947435519658029, 10.27737122029066, 18.86740118265152, 34.45042960345745, 47.49578699469566, 57.24995099008083, 62.323735132813454, 62.66765087842941, 59.50546056032181, 59.40436318516731, 61.46288372576237, 54.62877944111824, 47.54659026861191, 52.99942307174206, 37.24946200847626, 47.94881008565426, 57.96841263771057, 65.08205652236938, 57.336742132902145, 60.481195002794266, 61.91768892109394, 61.31244219839573, 61.49467661976814, 64.07918393611908, 61.282716393470764, 59.8691276460886, 50.229831486940384, 43.27812351286411, 32.04001374542713, 22.068068236112595, 9.529590345919132, 2.032850543037057, 0.4649820289341733, 1.87665885547176, 1.981454857159406, 4.531388422474265, 6.081718057394028, 5.911273928359151, 10.417080223560333, 17.149025090038776, 10.189318545162678, 8.585488256067038, 12.225795518606901, 7.07741710357368, 12.45837913826108, 7.124109948053956, 5.932734226807952, 1.743587264791131, 1.6306710988283157, 2.87769578397274, 10.923289060592651, 18.18181537091732, 26.222413815557957, 20.356007404625416, 22.62244898825884, 25.131239667534828, 30.72525579482317, 30.812223628163338, 13.599043730646372, 2.4161184020340443, 0.27010990132112056, 0.15432595799211413, 0.1912564435042441, 0.21562363050179556, 0.11905110004590824, 0.15294749289751053, 0.11799599611549638, 0.09873145289020613, 0.16641020018141717, 0.1420860132202506, 0.1390141897718422, 0.11271568218944594, 0.17813412967370823, 0.22745957976439968, 0.12030680649331771, 0.10640825072186999, 0.17081806756323203, 0.14042476017493755, 0.23425382300047204, 0.25453587295487523, 0.20523320679785684, 0.11867028923006728, 0.15440805436810479, 0.12123141859774478, 0.059715684546972625, 0.09604113787645474, 0.14833816210739315, 0.19933739269617945, 0.1546613493701443, 0.1152756909141317, 0.13319420831976458, 0.13738786219619215, 0.07930367428343743, 0.1879312063101679, 0.13603066705400124, 0.09699287547846325, 0.15111213200725615, 0.09938537405105308, 0.1456365516060032], [0.05915491405175999, 0.03945805125113111, 0.024256551332655363, 0.022874458991282154, 0.02240003366750898, 0.03301878095953725, 0.030798074731137604, 0.030519431675202213, 0.0767550129967276, 0.04210134378809016, 0.06391470786184072, 0.026658037313609384, 0.02764086348179262, 0.02480842904333258, 0.015142718111746944, 0.03292269138910342, 0.03351253551954869, 0.0416866056912113, 0.04307946845074184, 0.007515176157539827, 0.08672808995470405, 0.023235261505760718, 0.003272230223956285, 0.03377899993211031, 0.026147254175157286, 0.06632761549553834, 0.0523039299150696, 0.03239109100832138, 0.054751629431848414, 0.016199888923438266, 0.018859265655919444, 0.05713197904697154, 0.032990393810905516, 0.01709548305370845, 0.04363708110759035, 0.018008560327871237, 0.015168569898378337, 0.090427629329497, 0.04180763142358046, 0.053713925153715536, 0.0862065827823244, 0.060001084857503884, 0.03386957534530666, 0.06820851456723176, 0.03013242021552287, 0.043042416727985255, 0.024717985361348838, 0.030993753098300658, 2.4875868670642376, 7.657773261889815, 24.092876985669136, 42.25987695157528, 35.28711810708046, 19.968671388924122, 21.45932760089636, 44.339132979512215, 58.034745678305626, 30.709532238543034, 16.770208217203617, 9.227577801793814, 1.9379157247021794, 0.27238022012170404, 1.2197311059571803, 0.19981958088465035, 3.0432718992233276, 2.4874738231301308, 4.489816278219223, 1.5600720746442676, 5.333327790722251, 2.5345575716346502, 1.2399406777694821, 0.637482114834711, 1.58080198103562, 1.6001631296239793, 0.4593192640459165, 0.7080305542331189, 0.24739408196182922, 0.17887280409922823, 0.2959306736011058, 1.500016178470105, 5.822516866028309, 16.41838699579239, 27.98164911568165, 45.73154926300049, 52.4935220181942, 59.40766140818596, 63.00140596926212, 60.123770982027054, 52.56739765405655, 37.75660939514637, 35.44773928821087, 32.694106847047806, 59.77905347943306, 41.24185457825661, 51.262825056910515, 60.06650425493717, 59.51697774231434, 59.83219362795353, 58.13286401331425, 57.325639128685, 56.022628247737885, 50.1301172375679, 37.05791808664799, 30.274267494678497, 19.10330582410097, 12.442898768931627, 5.365741951391101, 0.7176271767821163, 0.4889996792189777, 0.7585599459707737, 1.9202204304747283, 1.8649357720278203, 1.9537606369704008, 3.5267764795571566, 4.172343313694, 3.150875950232148, 4.459977904334664, 3.196179731748998, 2.4380745738744736, 3.321305117569864, 2.52004187554121, 0.8589956222567707, 1.3008121051825583, 0.5064802255947143, 0.7470176497008651, 3.8063134672120214, 9.255435056984425, 14.113827757537365, 16.419247649610043, 13.494678530842066, 15.052054412662983, 17.328012585639954, 22.41105493158102, 19.824963100254536, 9.043007455766201, 1.1250894656404853, 0.09706736484076828, 0.042346675545559265, 0.022840511301183142, 0.05028486892115325, 0.043107462261104956, 0.03450378506386187, 0.051312658106326126, 0.009824921089602867, 0.014308148929558229, 0.034080931582138874, 0.05617569579044357, 0.030261238498496823, 0.008880425921233837, 0.035634498999570496, 0.07494890756788664, 0.04625161913281772, 0.04927317320834845, 0.037321434065233916, 0.07520967599702999, 0.030862834537401795, 0.051177887798985466, 0.03361416522238869, 0.035856356626027264, 0.11441341921454296, 0.010811061874846928, 0.008598689037171425, 0.0464013251621509, 0.15751128550618887, 0.06514523323858157, 0.07768426352413371, 0.019889993745891843, 0.004437831594259478, 0.014491165329673095, 0.05818320525577292, 0.023759817049722187, 0.046933051708037965, 0.016671126722940244, 0.06550260703079402, 0.022321429096336942, 0.041724551701918244, 0.08607125957496464, 0.028525959933176637, 0.056166934737120755, 0.04548685079498682, 0.026989139078068547, 0.03157413855660707, 0.04528057084826287, 0.0025148277018161025, 0.0812882068566978, 0.05701333189790603, 0.15544814465101808, 0.0381723212194629, 0.023152113135438412, 0.04560799898172263, 0.03993130769231357, 0.03465707937721163, 0.023728552223474253, 0.05108330107759684, 0.06972098926780745, 0.030390286847250536, 0.07400708505883813, 0.0411825946503086, 0.043886743296752684, 0.020651173799706157, 0.055719668307574466, 0.06138031436421443, 0.05238952551735565, 0.04265012488758657, 0.07349503284785897, 0.012507114224717952, 0.053070880167069845, 0.010606368268781807, 0.034216703788843006, 0.02873685232771095, 0.048756341566331685, 0.027193623027415015, 0.05992800557578448, 0.05701716509065591, 0.051370115179452114, 0.024566965730628, 0.06452143585192971, 0.026289369889127556, 0.03619843104388565, 0.061763670746586286, 0.04400558340421412, 0.058381800263305195, 0.03483716893242672, 0.042766033511725254, 4.019598159939051, 12.860316820442677, 31.346626952290535, 43.839414194226265, 29.604095555841923, 19.996408000588417, 27.813857719302177, 44.099559634923935, 44.25638861954212, 35.675810649991035, 26.05262752622366, 9.858414251357317, 2.3932607285678387, 0.882640031632036, 0.7077870704233646, 0.5274366354569793, 0.8059124113060534, 2.404103921726346, 2.254954562522471, 4.3514196295291185, 4.203559588640928, 4.636220997199416, 2.6750574074685574, 2.8226540749892592, 3.671619719825685, 3.4883519914001226, 1.4939976576715708, 2.2536816308274865, 1.0283265891484916, 0.6782320782076567, 1.4011280285194516, 3.15777400508523, 9.711628127843142, 22.609387189149857, 32.789170145988464, 50.507839769124985, 55.84640130400658, 62.55944788455963, 62.3094516992569, 61.14456720650196, 53.76247152686119, 46.01353973150253, 34.965408369898796, 37.89952352643013, 62.74572528898716, 49.80642780661583, 56.23148404061794, 61.84132821857929, 60.89409604668617, 61.6346725076437, 59.21723462641239, 57.98315204679966, 58.226331397891045, 55.07881589233875, 42.33667463064194, 35.951751843094826, 23.788070641458035, 15.617574267089367, 7.417640872299671, 1.4835418062284589, 1.046658824197948, 2.65431622043252, 2.672713645733893, 3.8550375401973724, 4.607373895123601, 3.661426054313779, 6.6735439002513885, 5.715353116393089, 5.66217259503901, 4.02796246111393, 4.513960657641292, 3.4810765692964196, 2.350573344156146, 1.1102278693579137, 0.46793162066023797, 0.25891276309266686, 0.8240317984018475, 4.206342939287424, 11.737204436212778, 19.01866726577282, 24.15406320244074, 15.510266125202179, 14.368562288582325, 18.165552243590355, 25.912975519895554, 25.45842681080103, 15.365562289953232, 2.394484975375235, 0.13531525153666735, 0.021933491807430983, 0.01536983478217735, 0.061473413079511374, 0.032190039491979405, 0.03135901963105425, 0.027620621403912082, 0.05144891270902008, 0.008433101047558011, 0.0108770434417238, 0.05099195383081678, 0.05129857956490014, 0.05713861755793914, 0.0068416191606957, 0.02120816490787547, 0.03194582095602527, 0.04083830121089704, 0.022663442287012003, 0.03704972637933679, 0.009330002285423689, 0.06955001328606158, 0.04937651727232151, 0.0683393923100084, 0.06446299172239378, 0.019928633664676454, 0.01977369363885373, 0.022506606073875446, 0.02945578748040134, 0.03519463549309876, 0.062213805576902814, 0.008834934124024585, 0.04841868292714935, 0.023526715885964222, 0.009843265124800382, 0.07682588809984736, 0.03909069928340614, 0.0332198176329257, 0.11074977752286941, 0.0030559465903934324, 0.07304901693714783, 0.21620905143208802, 0.14627024182118475, 0.17257021885598078, 0.21504738251678646, 0.05035217800468672, 0.059398954472271726, 0.14289585960796103, 0.16255373368039727, 0.2522995148319751, 0.18340526323299855, 0.2244019164936617, 0.1352162638795562, 0.09690618520835415, 0.12476620118832216, 0.08706624212209135, 0.10569846810540184, 0.12650809600017965, 0.19223083887482062, 0.2405274347984232, 0.13688854523934424, 0.24253381619928405, 0.13698523223865777, 0.11670833278913051, 0.08983640480437316, 0.1333202695241198, 0.2715115511091426, 0.11423353003920056, 0.15569527982734144, 0.1388656414928846, 0.0792008126154542, 0.1708408069680445, 0.11461494941613637, 0.1029273628955707, 0.1559732438181527, 0.17489936028141528, 0.13724131771596149, 0.20243676466634497, 0.1874615901033394, 0.21949973423033953, 0.14203799626557156, 0.2500342723214999, 0.16456626006402075, 0.16963474277872592, 0.14414097560802475, 0.17744507524184883, 0.25289700308348984, 0.11342462617903948, 0.14012861356604844, 3.416449399664998, 12.933704182505608, 35.50123281776905, 55.014614537358284, 46.03204093873501, 28.351718857884407, 32.60950818657875, 53.927291482687, 60.7318751513958, 38.08011643588543, 22.019799426198006, 11.5391144156456, 3.1469203624874353, 0.6924345879815519, 2.0623184368014336, 1.299694252666086, 6.8414160422980785, 9.607001692056656, 11.67729115113616, 7.309537623077631, 12.934163957834244, 7.953607812523842, 3.751136865466833, 3.609434156678617, 4.818795975297689, 3.7208555778488517, 1.2197460676543415, 1.7489745444618165, 1.045267980080098, 0.4193722450872883, 0.8398472622502595, 2.143808864057064, 8.324797544628382, 20.219438932836056, 32.47796684503555, 49.42653939127922, 56.854969784617424, 62.51154765486717, 64.84798908233643, 60.73615752160549, 54.790605157613754, 46.629247292876244, 44.92153912782669, 42.80903108417988, 65.06415948271751, 56.99773192405701, 61.50114767253399, 63.72304804623127, 64.56959322094917, 65.0373937189579, 60.87522625923157, 59.35379549860954, 59.34602491557598, 54.92525853216648, 43.79715286195278, 38.47614638507366, 25.313263200223446, 14.911343213170767, 5.537987658753991, 1.308759378734976, 0.8300968073308468, 2.051662146113813, 5.310784075409174, 5.204880908131599, 4.975093463435769, 8.639995381236076, 12.343252915889025, 6.751846773549914, 10.590156186372042, 8.733743000775576, 7.473924877122045, 8.573175016790628, 8.641483001410961, 3.110161847434938, 3.3825887041166425, 1.1156924511305988, 1.1734269093722105, 5.431687887758017, 13.048010598868132, 19.771197885274887, 24.41894318908453, 20.429244674742222, 23.474619761109352, 26.285209245979786, 32.53902576863766, 29.829581156373024, 14.52604103833437, 2.325670667923987, 0.1867487869458273, 0.11195748185855336, 0.20038578019011766, 0.1686900481581688, 0.18600604555103928, 0.21086861612275243, 0.1522498592385091, 0.13711172388866544, 0.1351020621950738, 0.14063173031900078, 0.1456643673009239, 0.13965718651888892, 0.20959468994988129, 0.15693885216023773, 0.14856948953820392, 0.12750775407766923, 0.1697121636243537, 0.10777481176774018, 0.10632671837811358, 0.15244899230310693, 0.16119739942951128, 0.2110844326671213, 0.14090310403844342, 0.20863616169663146, 0.08026566094486043, 0.11753621336538345, 0.15399211028125137, 0.35609569516964257, 0.24584094499005005, 0.21587155235465616, 0.19182843156158924, 0.15740175935206935, 0.16587407269980758, 0.21996872703311965, 0.1220240248949267, 0.1942095678532496, 0.14518629061058164, 0.2088476440985687, 0.08767899635131471, 0.1729687670012936], [0.03816771619312931, 0.07378051479463466, 0.04253699931723531, 0.019758670714509208, 0.08571375961764716, 0.021311416203388944, 0.0985652266535908, 0.04659570106014144, 0.02894656099670101, 0.030434791588049848, 0.09245901368558407, 0.02100461791997077, 0.06212691492692102, 0.025246865770895965, 0.01414330772604444, 0.00999904099444393, 0.018285650439793244, 0.13803143781842664, 0.037453506665769964, 0.06961905528442003, 0.048134633325389586, 0.07243744272273034, 0.05918172042584047, 0.05644790071528405, 0.02783832671411801, 0.0162039540373371, 0.03490152055746876, 0.06683496991172433, 0.08801016490906477, 0.0037396448033177876, 0.022639448652626015, 0.038902446103747934, 0.06118569726822898, 0.034440112503943965, 0.020448279901756905, 0.04998459597118199, 0.029541941548814066, 0.012050135865138145, 0.023628072849533055, 0.024121794012899045, 0.05016972470912151, 0.11516380473040044, 0.049283607804682106, 0.026155237828788813, 0.005516398987310822, 0.0190821437354316, 0.05197670587222092, 0.04350106399215292, 0.03512250244966708, 0.8572037215344608, 4.723430592566729, 21.796979382634163, 37.72376395761967, 38.548627495765686, 28.352889195084572, 21.53560470789671, 17.451764345169067, 11.36439599096775, 14.820399843156338, 13.623395673930645, 7.807601122185588, 2.527429866604507, 0.5054235260467976, 0.4908180300844833, 0.4443334916140884, 1.0747960768640041, 1.5823845961131155, 3.9274364802986383, 2.7088511316105723, 3.834957517683506, 4.162652408704162, 1.9578580046072602, 2.977374647744, 2.6155404886230826, 2.420325488783419, 1.9757426949217916, 0.7706068432889879, 0.648878178326413, 0.971639568451792, 0.1510391492047347, 0.5740220169536769, 2.4694490153342485, 8.567801155149937, 17.275047227740288, 25.513844937086105, 31.912135407328606, 42.013680562376976, 45.18058642745018, 46.80906504392624, 32.70409271121025, 34.54568289220333, 40.21546125411987, 63.247773349285126, 55.98156005144119, 52.88048945367336, 61.35344199836254, 56.62022218108177, 57.14923359453678, 51.14788122475147, 44.37294356524944, 35.065650790929794, 33.662792667746544, 17.477093786001205, 11.38860734179616, 5.311221526935697, 1.313489293679595, 0.2165749153937213, 0.899761141045019, 0.8035965543240309, 2.9411286301910877, 2.3636515298858285, 2.3415440786629915, 4.246523408219218, 2.3440571688115597, 3.5457412619143724, 4.558296203613281, 2.5356960855424404, 4.362361142411828, 5.541455447673798, 2.961489837616682, 0.6179214175790548, 0.6165560439694673, 0.8265527850016952, 2.1660219971090555, 6.154712615534663, 13.33991663530469, 19.495904557406902, 20.591566264629364, 11.271833907812834, 13.2335289940238, 16.536353565752506, 23.733676560223103, 20.408288799226284, 10.129282716661692, 1.1615162109956145, 0.00909281652639038, 0.031110743402678054, 0.02771611911157379, 0.009353796467621578, 0.03872712855809368, 0.02546197170886444, 0.027713128256436903, 0.03020152529643383, 0.018301508280273993, 0.011224537392990896, 0.04624838336894754, 0.07308810585527681, 0.06270884405239485, 0.03375286149093881, 0.05450397846288979, 0.08387801281060092, 0.05129607852722984, 0.033365831477567554, 0.04620995867298916, 0.029453449715219904, 0.05116052154335193, 0.028741136375174392, 0.032212957012234256, 0.028810452968173195, 0.01848216743383091, 0.028518558865471277, 0.07120046808267944, 0.03344810596900061, 0.010668346876627766, 0.03312982480565552, 0.025480818549112882, 0.0325535137380939, 0.062052458961261436, 0.042143738974118605, 0.027233845576120075, 0.11731097154552117, 0.061807542806491256, 0.021303133835317567, 0.04989995031792205, 0.05661247196258046, 0.03761414081964176, 0.037820305733475834, 0.023692300164839253, 0.027571233331400435, 0.04948636626068037, 0.05919961360632442, 0.022694002072967123, 0.02615533616335597, 0.03637231253378559, 0.04222143812512513, 0.052147563110338524, 0.06886216855491512, 0.06286961550358683, 0.04394895011500921, 0.07523737294832245, 0.06509911618195474, 0.05329554311174434, 0.011092843287769938, 0.09822130057727918, 0.05224894419370685, 0.07141818452510051, 0.03824285122391302, 0.028426667995518073, 0.045494108999264427, 0.05693785547919106, 0.029070941236568615, 0.034584775639814325, 0.07159417000366375, 0.09200779531965964, 0.008550745369575452, 0.04274979903129861, 0.07156584964832291, 0.015914542418613564, 0.09568039473379031, 0.05218328267801553, 0.02149695126718143, 0.07483453518943861, 0.038291421078611165, 0.016697751270839944, 0.08791027925326489, 0.0654501149256248, 0.042560996662359685, 0.10330308257834986, 0.050776775533449836, 0.06687569155474193, 0.04891769560344983, 0.04251017438946292, 0.07164566763094626, 0.05177881219424307, 0.09969836741220206, 1.5698756673373282, 8.640446607023478, 28.124344758689404, 43.42922240495682, 40.845927223563194, 28.368312567472458, 26.232205890119076, 26.78171720355749, 16.167577654123306, 20.178228244185448, 22.131103053689003, 10.10976031422615, 4.271200709044933, 1.0708017786964774, 0.39495900040492415, 0.4424549377290532, 0.6398235610686243, 2.262546317651868, 1.3766188686713576, 4.077110448852181, 4.117792965844274, 4.05131695792079, 2.8934397641569376, 4.461593292653561, 4.547138577327132, 4.223387874662876, 3.2379786763340235, 1.7948848684318364, 1.8689491879194975, 2.0967814000323415, 0.8790979685727507, 1.6695051337592304, 3.8686125492677093, 11.727980431169271, 21.35801173746586, 30.312246456742287, 36.6557514667511, 46.8724874407053, 48.778096586465836, 50.543675646185875, 42.12621912360191, 34.62759889662266, 44.41910348832607, 66.57295972108841, 60.605003759264946, 58.35994742810726, 66.83438569307327, 61.94661296904087, 62.8923974186182, 55.82302875816822, 49.352504163980484, 41.40660993754864, 38.61598268151283, 22.491316124796867, 13.595450073480606, 7.8016838897019625, 2.845621705055237, 0.6035844900179654, 1.5142590017057955, 1.9072512513957918, 2.7357216272503138, 1.955500349868089, 4.345906600356102, 5.558314668014646, 3.626197907142341, 5.0933255441486835, 4.54874019138515, 4.199670497328043, 3.050689813680947, 2.119493018835783, 1.5803324687294662, 0.8279916609171778, 0.4904976597754285, 0.7510857470333576, 2.733266009017825, 8.456825260072947, 17.04080879688263, 24.726485386490822, 24.023416712880135, 11.941513773053885, 11.547943241894245, 18.292208947241306, 25.62393832951784, 24.201366864144802, 13.766658436506987, 2.4936589412391186, 0.06754454472684301, 0.06308542462647893, 0.032173526706174016, 0.04122152771742549, 0.011778162861446617, 0.032967554216156714, 0.06663634892902337, 0.04136690331506543, 0.0293953321306617, 0.04295312151953112, 0.10315834893845022, 0.03623343072831631, 0.05327934573870152, 0.030149446938594338, 0.015742612777103204, 0.08816743342322297, 0.03581993201805744, 0.07617610070155933, 0.055232511440408416, 0.037007720820838585, 0.008333495552506065, 0.015998983981262427, 0.0033693124169076327, 0.026393547013867646, 0.04170341162534896, 0.0888024817686528, 0.036549552241922356, 0.019772572995861992, 0.07881663244916126, 0.02751290794549277, 0.0334917294094339, 0.04616062811692245, 0.036563460089382716, 0.05684253774234094, 0.047046548352227546, 0.02987698040669784, 0.016513739465153776, 0.04924024411593564, 0.031037758744787425, 0.019719891643035226, 0.04618193517671898, 0.07676275359699503, 0.1916816644370556, 0.1175478428194765, 0.1441100874217227, 0.17905195854837075, 0.082049056654796, 0.17790217883884907, 0.11969953673542477, 0.10847107987501658, 0.09791731688892469, 0.2047128276899457, 0.18843607453163713, 0.19853254838380963, 0.12027867167489603, 0.22120366076705977, 0.12150717098847963, 0.05442902896902524, 0.32673814392182976, 0.13820702995872125, 0.12152016599429771, 0.10483318328624591, 0.16456931771244854, 0.14562277734512463, 0.11464563722256571, 0.15845761285163462, 0.12759390257997438, 0.1635469202301465, 0.15376105002360418, 0.1184947119327262, 0.15898456738796085, 0.15974338370142505, 0.139961214736104, 0.16653830971335992, 0.12014497377094813, 0.08392355099203996, 0.15020962106063962, 0.08261607232270762, 0.09927682753186673, 0.1495270975283347, 0.16644076182274148, 0.21357038989663124, 0.21227305638603866, 0.19476824178127572, 0.12265418248716742, 0.12047983080265112, 0.19744997756788507, 0.13181627757148817, 0.19045415217988193, 0.15119050280191004, 1.7524939868599176, 8.012372609227896, 29.7161952406168, 50.73470279574394, 54.41617704927921, 39.24723140895367, 33.99528622627258, 25.109995007514954, 17.61378765106201, 21.28169473260641, 20.996170453727245, 10.75265921652317, 3.8755044294521213, 0.7741950976196676, 1.0123189981095493, 2.1060457779094577, 4.04660758562386, 5.389013327658176, 11.333402954041958, 10.493754409253597, 9.311320558190346, 9.499655552208424, 4.7673628851771355, 8.069489244371653, 7.689494909718633, 6.095576388761401, 3.8120255107060075, 1.9222860946319997, 1.8532244442030787, 2.4621006846427917, 0.9200223069638014, 1.0498517216183245, 2.96578835695982, 9.731899090111256, 20.23202195763588, 27.449873350560665, 35.590102449059486, 44.36747565865517, 48.658095225691795, 50.52134424448013, 45.963093638420105, 42.14100793004036, 48.43535117805004, 66.07836306095123, 66.57696470618248, 62.725286185741425, 68.63349035382271, 64.01181355118752, 63.29481862485409, 58.38980622589588, 54.58484619855881, 44.67572271823883, 40.616233348846436, 22.619481347501278, 13.152294103056192, 6.156550291925669, 1.9551670365035534, 0.694082808913663, 1.6785950772464275, 3.1855170289054513, 6.6450862772762775, 5.12330356054008, 5.519091272726655, 11.854396797716618, 7.03357458114624, 10.408261846750975, 10.962558053433895, 7.643895456567407, 8.716821558773518, 11.436292883008718, 6.968476949259639, 2.377643804065883, 2.0095570804551244, 1.8431306420825422, 2.8565078834071755, 7.959013497456908, 17.780731692910194, 26.227893121540546, 29.11171417683363, 18.484045453369617, 21.788173355162144, 24.64213751256466, 33.02556686103344, 27.966056652367115, 13.528193682432175, 2.3909910628572106, 0.15637906501069665, 0.1926652030670084, 0.09765826282091439, 0.16743238986236975, 0.13815700920531526, 0.20885392266791314, 0.11868723246152513, 0.1402840786613524, 0.20346116594737396, 0.09556369201163761, 0.17847674957010895, 0.17971388006117195, 0.23902455606730655, 0.1549112008069642, 0.10342075751395896, 0.20652577572036535, 0.15102294069947675, 0.20672777347499505, 0.10873480947338976, 0.17377726268023252, 0.13278651691507548, 0.1444202012498863, 0.07620677366503514, 0.13017066899919882, 0.12692353542661294, 0.16253768844762817, 0.17049199756002054, 0.08912381686968729, 0.2043968954239972, 0.07681040689931251, 0.09408844343852252, 0.09950529769412242, 0.2032591385068372, 0.1964770516497083, 0.12132386051234789, 0.15314736810978502, 0.15349452994996682, 0.19946940592490137, 0.10197971452726051, 0.1158198484336026, 0.17252707039006054], [0.033546781924087554, 0.0332811004773248, 0.03549671557266265, 0.01807362070394447, 0.11769921868108213, 0.06340336811263114, 0.053114177062525414, 0.018065282674797345, 0.09344649311969988, 0.046799839910818264, 0.03368489931744989, 0.06244673233595677, 0.05099827321828343, 0.040205416225944646, 0.04635558660083916, 0.013627108764922014, 0.015035878532216884, 0.03198882841388695, 0.021879469022678677, 0.03201026534952689, 0.043532853887882084, 0.03725878937984817, 0.03327133381390013, 0.028979150556551758, 0.06038353581971023, 0.02093514362059068, 0.03834611736238003, 0.04099811158084776, 0.024013794827624224, 0.04217803361825645, 0.053980218872311525, 0.04026278795208782, 0.022847754662507214, 0.08536203356925398, 0.035967741860076785, 0.08889547287253663, 0.02048742819170002, 0.011418601588957245, 0.038835957093397155, 0.052402899018488824, 0.0677397740946617, 0.04982030674000271, 0.015124424171517603, 0.047321643942268565, 0.13241170265246183, 0.09671871128375642, 0.07898147829109803, 0.022151375233079307, 0.05571695575781632, 0.05289457185426727, 0.4543668532278389, 1.6931981686502695, 11.387014277279377, 25.18827460706234, 35.15738546848297, 33.04077364504337, 26.609899923205376, 27.680699564516544, 32.953925505280495, 27.22045686095953, 20.17366848886013, 12.905864976346493, 6.163888173177838, 2.4670855421572924, 0.883974531898275, 0.5073529318906367, 1.6055521904490888, 1.4298569806851447, 2.3595178266987205, 3.3468732330948114, 1.996219321154058, 3.4260540967807174, 3.041816814802587, 3.8175573013722897, 2.028929628431797, 4.167547021061182, 2.534367819316685, 2.321032304316759, 2.4984804075211287, 0.8804816880729049, 0.9652462927624583, 0.27662153472192585, 0.37906166282482445, 2.4868715554475784, 4.898896627128124, 10.002216584980488, 13.569831848144531, 15.704395808279514, 13.792063873261213, 19.431629106402397, 23.082915879786015, 29.268231578171253, 39.52963225543499, 39.821946769952774, 41.51779197156429, 35.11673904955387, 35.519905015826225, 26.51609055697918, 19.578039050102234, 12.779874186962843, 8.651710152626038, 5.321290986612439, 1.6653489880263805, 0.40583363093901426, 0.05079420858237427, 0.25877760315779597, 0.7272844179533422, 1.962522016838193, 0.8825542393606156, 2.608661432750523, 1.7243291856721044, 3.749271878041327, 3.9922747761011124, 2.6778588071465492, 3.6613042233511806, 5.08585324510932, 3.5062882164493203, 1.6774596506729722, 1.2165193282999098, 1.3509950623847544, 0.5359577969647944, 0.9436819748952985, 3.644153606146574, 7.099554240703583, 13.210903108119965, 14.709523692727089, 19.805523343384266, 19.425794519484043, 19.373917803168297, 20.665485598146915, 27.91616342961788, 19.30072423070669, 9.264164138585329, 1.3243094505742192, 0.03041004096303368, 0.11162632814375684, 0.06157394440378994, 0.019797318054770585, 0.009161985617538448, 0.04177442031505052, 0.01094433304388076, 0.08994990887003951, 0.0404693053860683, 0.06523041694890708, 0.04933376956614666, 0.013020432725170394, 0.022671526130579878, 0.013163521580281667, 0.03586350350815337, 0.05551740337978117, 0.029305517418833915, 0.052028103309567086, 0.00618785106780706, 0.023298533305933233, 0.038849831544212066, 0.01650931255426258, 0.032153455322259106, 0.03021607881237287, 0.06389348243828863, 0.020384902345540468, 0.021968715991533827, 0.01810478719562525, 0.00641798317701614, 0.011411503874114715, 0.0485215186199639, 0.030929312415537424, 0.036381671015988104, 0.06741199715179391, 0.016584165568929166, 0.03753174387384206, 0.010641909721016418, 0.04163497818808537, 0.036741690564667806, 0.08101091079879552, 0.05784959503216669, 0.1009179832180962, 0.015802027264726348, 0.020669395380537026, 0.07597177260322496, 0.08564977906644344, 0.040913217308116145, 0.0031819108517083805, 0.06042363034794107, 0.04716054223536048, 0.09254285410861485, 0.015308632646338083, 0.015277544080163352, 0.007881762321630958, 0.03923992291674949, 0.046707386864, 0.04722116456832737, 0.005309200632837019, 0.02511396010959288, 0.04360025945061352, 0.06047531351214275, 0.11512938392115757, 0.05153699450602289, 0.04950081587594468, 0.037455503043020144, 0.04242866431013681, 0.02492993346095318, 0.03301512588222977, 0.03896548041666392, 0.05081286988570355, 0.05476670245116111, 0.040057354053715244, 0.028561657236423343, 0.008932812270359136, 0.04061636936967261, 0.006198274995767861, 0.056590563763165846, 0.08241418589022942, 0.03448620729614049, 0.06358190657920204, 0.033481061036582105, 0.030037269461899996, 0.04571828212647233, 0.09922296245349571, 0.01774061533069471, 0.05288971449772362, 0.031002744217403233, 0.02411363038845593, 0.015013514839665731, 0.04614327299350407, 0.01900958024634747, 0.0203654636425199, 0.6077239522710443, 3.9905658178031445, 17.195095717906952, 31.90994292497635, 39.45719674229622, 34.686165153980255, 22.08671383559704, 18.334037102758884, 19.617784917354584, 23.68724875152111, 25.044627115130424, 13.229492660611868, 8.001983966678381, 3.9416755037382245, 0.574033297598362, 0.35947329830378294, 0.45497170358430594, 1.1392122390680015, 2.2170477965846658, 2.5135228503495455, 2.6324479188770056, 3.426080932840705, 4.8220044281333685, 4.415156934410334, 4.824320878833532, 5.67592310719192, 5.264403764158487, 5.360885336995125, 5.465946849435568, 4.010339006781578, 2.5333088636398315, 1.154275699518621, 1.908647082746029, 5.355265913531184, 8.381301462650299, 12.342783641070127, 17.157907113432884, 19.674525372684002, 18.541832752525806, 25.923453457653522, 25.84328915923834, 32.65217609703541, 47.34379895031452, 45.02669848501682, 47.17531979084015, 42.56609871983528, 41.286547780036926, 35.338248163461685, 27.378311790525913, 20.119247809052467, 13.839358985424042, 9.141727108508348, 3.368302183225751, 1.4357562828809023, 0.6767148314975202, 1.2543265870772302, 1.679564737714827, 2.9115947149693966, 3.4718969743698835, 4.7279865480959415, 3.852991587482393, 4.8631790187209845, 5.999808702617884, 2.2086635464802384, 4.74280527792871, 2.1452781977131963, 3.472031392157078, 0.9274215786717832, 1.4505524514243007, 0.6727626279462129, 0.397840611403808, 1.247540507465601, 4.766600076109171, 10.875526573508978, 18.03455237299204, 21.25336155295372, 25.239780843257904, 18.594285137951374, 15.64338818192482, 22.586953192949295, 28.66352252662182, 24.645006358623505, 13.454175554215908, 2.5848528603091836, 0.11608904766035266, 0.061864472954766825, 0.0714473138214089, 0.05327467020833865, 0.03359811627888121, 0.03915012304787524, 0.031648520307498984, 0.0911440393247176, 0.021946668639429845, 0.009706355576781789, 0.02040086965280352, 0.04805375407158863, 0.053268057672539726, 0.011019732464774279, 0.03902680778992362, 0.03278337913798168, 0.035008438062504865, 0.0713185289350804, 0.013079075379209826, 0.09596880816388875, 0.011709965983754955, 0.05374332904466428, 0.025904319554683752, 0.052643236122094095, 0.016358606480935123, 0.044592124977498315, 0.015842132925172336, 0.03100439364061458, 0.04450157182873227, 0.04863212088821456, 0.04420759971253574, 0.03783988729992416, 0.0307823393450235, 0.018309714578208514, 0.015500077988690464, 0.022410024830605835, 0.026198527302767616, 0.05065629899036139, 0.04714270471595228, 0.10043767266324721, 0.09016012219944969, 0.12551952560897917, 0.07822304047294892, 0.137477261305321, 0.14321836730232462, 0.18925461889011785, 0.2278753902646713, 0.10842813178896904, 0.1975768996635452, 0.18951782898511738, 0.23785488680005074, 0.18612771324114874, 0.09603699669241905, 0.2782729617320001, 0.18508728157030419, 0.10805615253048018, 0.1818405487574637, 0.08857484281179495, 0.10218059906037524, 0.11101150332251564, 0.2526546473382041, 0.242225305410102, 0.1860228180885315, 0.10323507216526195, 0.10639555257512257, 0.16280165553325787, 0.2839365875115618, 0.13450411381199956, 0.10394804601673968, 0.13512952165910974, 0.1184041699161753, 0.12523397686891258, 0.10182576341321692, 0.10406347966636531, 0.15182107599684969, 0.16113704798044637, 0.1252955009113066, 0.24001426936592907, 0.12257294700248167, 0.19988033309346065, 0.10604319570120424, 0.14149756432743743, 0.17312170879449695, 0.20354894717456773, 0.16289985651383176, 0.18781932012643665, 0.19195750588551164, 0.16358215740183368, 0.09444549810723402, 0.1361452991841361, 0.1540503540309146, 0.10762183286715299, 0.5666514812037349, 3.842552835121751, 18.370148465037346, 38.91768269240856, 50.06421357393265, 46.83277577161789, 36.588175892829895, 38.34063045680523, 40.15714578330517, 35.38612939417362, 30.040671229362488, 18.781016618013382, 10.557391494512558, 3.8305663783103228, 1.5378493233583868, 1.138214198872447, 3.073173682205379, 5.579219721257687, 7.5551455188542604, 7.882688893005252, 8.480145558714867, 12.292351797223091, 9.242522399872541, 11.163886450231075, 7.507645692676306, 9.56532932817936, 8.074599020183086, 7.035497277975082, 7.271686904132366, 3.885780740529299, 3.0546940863132477, 0.8456773962825537, 0.9905292454641312, 3.674246803857386, 5.950711062178016, 11.387630794197321, 15.106397196650505, 17.836128920316696, 18.524906560778618, 28.703969456255436, 30.629683323204517, 37.252881824970245, 47.22609266638756, 48.64795736968517, 47.28945806622505, 42.587814554572105, 41.886243000626564, 34.4614490121603, 24.74212534725666, 17.600480765104294, 12.16495318338275, 8.334530722349882, 2.657177704386413, 0.6388652406167239, 0.2851744898362085, 0.5144043441396207, 2.267117234878242, 5.577212478965521, 4.527280842885375, 7.780270613729954, 6.931602777913213, 10.043774005025625, 12.113362401723862, 7.98663754016161, 11.085641998797655, 12.126477397978306, 10.603140089660883, 6.557226441800594, 5.742194401100278, 3.084661178290844, 1.4145426149480045, 1.8324902630411088, 4.8271868750452995, 10.149124301970005, 18.35152756422758, 21.292383559048176, 29.032313637435436, 27.935677282512188, 26.823697350919247, 29.782364889979362, 36.89012289047241, 26.83360531926155, 12.504235077649355, 2.2739421436563134, 0.22537818207638338, 0.2955037011997774, 0.2001657779328525, 0.11190412144060247, 0.1388260701787658, 0.15612873859936371, 0.1393727064714767, 0.1635503934812732, 0.07677913279621862, 0.17355175368720666, 0.1471098483307287, 0.12551799678476527, 0.09611700763343833, 0.14104396366747096, 0.06792370055336505, 0.10533462278544903, 0.10440511992783286, 0.20607919577741995, 0.12306476084631868, 0.2204343504854478, 0.3063026920426637, 0.07692417071666569, 0.09205158945405856, 0.20712477795314044, 0.10687471280107275, 0.12396080768667161, 0.06483672244939953, 0.13063988444628194, 0.1160640966554638, 0.10990043403580785, 0.12795114278560504, 0.16382353351218626, 0.14044620824279264, 0.17247822222998366, 0.13529040443245322, 0.13775574479950592, 0.2559326245682314, 0.10236934205750003, 0.08881705012754537, 0.2344996074680239, 0.1877667018561624, 0.233853374957107], [0.056370732199866325, 0.02900765830418095, 0.07089903738233261, 0.08090093193459325, 0.026267313260177616, 0.006907966699145618, 0.028599909383046906, 0.04139861157455016, 0.05056685535237193, 0.0689410514314659, 0.008646704136481276, 0.025223927841580007, 0.05770245683379471, 0.02925848380982643, 0.038851093195262365, 0.029820655108778737, 0.11045363833545707, 0.015534561880485853, 0.05251502268947661, 0.02553973394242348, 0.0608445505349664, 0.044502269447548315, 0.06083990840124898, 0.0400087619345868, 0.006298550742940279, 0.01929514568473678, 0.04105956882995088, 0.07355151770752855, 0.07541191866039298, 0.007087839176165289, 0.03910468134563416, 0.05936728332017083, 0.047153053965303116, 0.02336382745852461, 0.05312378787493799, 0.03399332475964911, 0.03980331319326069, 0.05142713438544888, 0.1361789630027488, 0.0356605038541602, 0.01973284026462352, 0.03382935836270917, 0.10368266885052435, 0.01526007577922428, 0.018575193789729383, 0.07337404051213525, 0.005407206335803494, 0.06790056781028397, 0.09336173243355006, 0.060499674509628676, 0.07725794421276078, 0.06692067312542349, 1.3436029152944684, 6.995658790692687, 19.971811920404434, 30.731230974197388, 40.2842565625906, 33.8416338711977, 24.85079951584339, 22.649057060480118, 23.673153407871723, 21.90648190677166, 15.071940645575523, 11.09940581023693, 6.481250943616033, 2.5550904823467135, 1.1301810736767948, 0.32709152495954186, 1.271420088596642, 3.0383499758318067, 0.7288700016215444, 2.021300825290382, 3.781952024437487, 2.6270514959469438, 5.295729758217931, 3.076173858717084, 4.097761390730739, 4.239174127578735, 2.9709567921236157, 3.149233488366008, 2.1314467024058104, 2.1714937034994364, 1.397210438735783, 0.9637394361197948, 1.884327200241387, 0.8024601184297353, 1.0668281419202685, 1.390492517966777, 2.639788412488997, 4.155400972813368, 8.212690260261297, 14.417097084224224, 13.62582279369235, 14.81791952624917, 9.478603731840849, 5.093607679009438, 5.503590954467654, 2.3747284105047584, 1.116516888141632, 0.21038007515016943, 0.03818560566287488, 0.08666292938869447, 0.12190166700747795, 0.2922685310477391, 0.6634139420930296, 2.3298114957287908, 1.9642718229442835, 2.9284859960898757, 2.0305478665977716, 2.373058875091374, 2.1205659862607718, 2.92448409833014, 3.4185768105089664, 1.6468319878913462, 2.326371967792511, 0.3840625804150477, 2.042884617112577, 1.8463888484984636, 0.37811147631146014, 0.9693497756961733, 3.8904483150690794, 6.832138365134597, 10.117926076054573, 15.71776919066906, 18.282331377267838, 14.307902343571186, 16.855038665235043, 20.17873741686344, 23.53168699890375, 28.687275052070618, 18.89407955110073, 6.312994547188282, 0.7089945150073618, 0.028661520627792925, 0.0364387718582293, 0.025850821839412674, 0.03517188124533277, 0.01439941639546305, 0.07449440148775466, 0.039789145594113506, 0.05442614572530147, 0.03070331360504497, 0.042386302520753816, 0.044252202787902206, 0.04006307601230219, 0.08484034085995518, 0.05368400175939314, 0.07799162398441695, 0.007446449571943958, 0.052805710802203976, 0.022401042988349218, 0.020803408697247505, 0.04623464621545281, 0.0166776873084018, 0.05531540562515147, 0.04656503180740401, 0.027813590932055376, 0.06929498165845871, 0.039493091753683984, 0.07744109883788042, 0.014793367863603635, 0.01731104541249806, 0.02637241435877513, 0.015856300524319522, 0.02431522367260186, 0.030515657854266465, 0.06818979760282673, 0.04502988820604514, 0.04107164357264992, 0.02572620225691935, 0.06618939049076289, 0.02190493582020281, 0.034649453809834085, 0.027861416783707682, 0.03651608509244397, 0.01169773260699003, 0.011552910837053787, 0.03317101771244779, 0.08101837680442259, 0.01900522012874717, 0.05418591623310931, 0.010702107174438424, 0.05990116209432017, 0.0165537486464018, 0.031291844134102575, 0.07069453116855584, 0.11698111658915877, 0.03718716099683661, 0.07309051041374914, 0.02930693492089631, 0.04919825711112935, 0.03265047162130941, 0.02461539643263677, 0.022803954962000716, 0.0662610300059896, 0.002088139171974035, 0.0913521672191564, 0.01741336345730815, 0.09251963230781257, 0.036501880385912955, 0.02566190258221468, 0.06414055082132109, 0.08579097266192548, 0.040279538225149736, 0.08016167121240869, 0.011972671418334357, 0.04819399029656779, 0.04943092411849648, 0.05793205877125729, 0.06655253077042289, 0.05806226487038657, 0.03637856512796134, 0.01604397111805156, 0.0473861291538924, 0.026580965277389623, 0.04580282387905754, 0.023324163375946227, 0.06763217010302469, 0.025203752556990366, 0.0573318171518622, 0.03500623017316684, 0.04617327431333251, 0.02591308246337576, 0.09401931238244288, 0.032060582962003537, 0.007753547033644281, 0.05052765140135307, 0.11871790542500094, 2.326386454515159, 11.983326729387045, 27.98787698149681, 40.29423102736473, 45.586644038558006, 37.89387322962284, 25.47135181725025, 18.871404267847538, 22.526224851608276, 27.856605425477028, 19.94994219392538, 14.54314012080431, 9.727930203080177, 2.9530770890414715, 0.6403060164302588, 0.09522618551272899, 0.1279811403946951, 0.3334824851481244, 1.2678480427712202, 1.8669584509916604, 4.4679731503129005, 3.114766487851739, 3.868549852631986, 7.062319563701749, 3.56451035477221, 11.0482719540596, 6.813368322327733, 2.4102370301261544, 5.816889367997646, 3.4352526906877756, 2.800483452156186, 2.07552557811141, 1.4717224217019975, 2.1755165001377463, 2.404562747105956, 2.2749737882986665, 3.8475692784413695, 7.271473640576005, 13.032143600285053, 16.935054771602154, 18.548871874809265, 19.07082136720419, 14.19921962544322, 8.363734055310488, 9.50189458206296, 4.627025965601206, 2.5097667519003153, 0.43568684777710587, 0.12455693038646132, 0.31146346824243665, 0.6237367680296302, 0.9469047957099974, 2.5896166171878576, 6.903281947597861, 3.415144169703126, 3.8467117119580507, 3.424666221253574, 4.2691573686897755, 5.4252538830041885, 5.22903336212039, 5.18623910844326, 2.2018032521009445, 1.270510156173259, 0.9447962651029229, 1.3793833390809596, 0.7849379524122924, 0.6553714955225587, 1.0516205267049372, 3.3886923640966415, 7.911236761137843, 15.696525480598211, 20.51993440836668, 22.137435413897038, 13.224133048206568, 16.8882317841053, 20.109398737549782, 26.216592527925968, 32.07839548587799, 25.054428689181805, 9.518350549042225, 1.4962129388004541, 0.08188396590412594, 0.06518532405607402, 0.023943704545672517, 0.03790473616390955, 0.028200685883348342, 0.02925613120169146, 0.10099999053636566, 0.049447767160017975, 0.03829013345239218, 0.0871126411948353, 0.05239358506514691, 0.029196679606684484, 0.043095183427794836, 0.08992446804768406, 0.05307882485794835, 0.05939391157880891, 0.019786773991654627, 0.0360271841782378, 0.056792672839947045, 0.01422605255356757, 0.016929436787904706, 0.006750252896381426, 0.048594705513096415, 0.02432530945952749, 0.03865879902150482, 0.041200157575076446, 0.040641572704771534, 0.0625409628264606, 0.01020229854475474, 0.011145165626658127, 0.01124320055168937, 0.034479553942219354, 0.023301999135583173, 0.06954985001357272, 0.06757566297892481, 0.0726658980420325, 0.024517720521544106, 0.03269827335316222, 0.04608161536452826, 0.04403397426358424, 0.023467960054404102, 0.07614821079187095, 0.039856243165559135, 0.21679764875443652, 0.14447053370531648, 0.18031185813015327, 0.1671958080260083, 0.1563835921115242, 0.08797771079116501, 0.14015525666764006, 0.1358212626655586, 0.11467818039818667, 0.15571844967780635, 0.2030273064156063, 0.20194365206407383, 0.16897003079066053, 0.10421263650641777, 0.13220930413808674, 0.12780434597516432, 0.2610270230798051, 0.06764063058653846, 0.16867602156708017, 0.0830819332622923, 0.16531053028302267, 0.1084294899192173, 0.1594877286697738, 0.10134211319382302, 0.09900854856823571, 0.12469816108932719, 0.22241572150960565, 0.13901399681344628, 0.1569738518446684, 0.15737903479021043, 0.14076611842028797, 0.19500054884701967, 0.11126553305075504, 0.16311427782056853, 0.1620935575920157, 0.12097350001567975, 0.20141485700150952, 0.19431109365541488, 0.16425749694462866, 0.12558676418848336, 0.08267440513009205, 0.1877712141140364, 0.4431617591762915, 0.15073522488819435, 0.15694945002906024, 0.339283526991494, 0.09285287145758048, 0.19253837002906948, 0.24245427281130105, 0.08315291968756355, 0.15337029442889616, 0.22356950881658122, 2.6341388281434774, 12.434705458581448, 32.368874698877335, 48.32061633467674, 55.11173352599144, 48.67520950734615, 36.63060821592808, 31.17138035595417, 30.789966322481632, 31.735522784292698, 23.524290695786476, 16.9676361232996, 8.529476411640644, 2.933173757046461, 1.2370028416626155, 1.0477593401446939, 2.7087492495775223, 7.323682839050889, 6.6468745563179255, 8.13794732093811, 8.557451460510492, 9.770472720265388, 12.526429686695337, 9.508339986205101, 9.559987764805555, 7.785623101517558, 7.439457401633263, 9.122103061527014, 9.688510168343782, 4.758667051792145, 4.583252789452672, 2.1793654561042786, 3.084072209894657, 1.4320517191663384, 1.8124394514597952, 2.0229204883798957, 3.998721605166793, 6.272144364193082, 12.448671609163284, 16.53638396412134, 18.78461692482233, 18.41540403664112, 12.548080924898386, 7.054813066497445, 7.1227035485208035, 3.5708260908722878, 1.7168509494513273, 0.5730619153473526, 0.1886378793278709, 0.300142866326496, 0.4390228015836328, 0.9805920661892742, 1.4856966468505561, 5.012606950476766, 6.251627365127206, 7.949787592515349, 8.468331042677164, 8.392623905092478, 6.824584370478988, 9.140066597610712, 9.208992999047041, 5.915917279198766, 6.132828164845705, 3.878140300512314, 4.969560485333204, 4.034886639565229, 1.0710137360729277, 1.6002613306045532, 5.316749280318618, 9.471246376633644, 14.529799036681652, 22.785186655819416, 27.250184565782547, 20.848267190158367, 26.146349497139454, 30.593041889369488, 32.32002452015877, 38.35724696516991, 26.855467446148396, 10.265548154711723, 1.26220807665959, 0.11322781603666954, 0.2132851825444959, 0.12497866322519258, 0.11708752572303638, 0.09184716487652622, 0.18901598872616887, 0.20576885930495337, 0.1702923746779561, 0.1370689761824906, 0.2645911427680403, 0.21507766214199364, 0.1288382467464544, 0.11946625003474765, 0.13606229738797992, 0.12035781430313364, 0.12014933759928681, 0.10651291580870748, 0.14556713111232966, 0.14598613284761086, 0.14405127963982522, 0.0860045850276947, 0.08342591128894128, 0.16654016508255154, 0.08050484029809013, 0.22420913621317595, 0.12663739296840504, 0.12350127726676874, 0.14181284350343049, 0.08376771482289769, 0.13158637506421655, 0.17997711984207854, 0.11951225576922297, 0.07916917485999875, 0.19546151161193848, 0.17173607455333695, 0.1224852325685788, 0.09830761235207319, 0.19561402295948938, 0.08962991705629975, 0.11070099615608342, 0.17575872276211157, 0.1380559880635701, 0.11725350705091842], [0.033644188806647435, 0.10836667453986593, 0.012768622946168762, 0.021755482121079694, 0.01748207891068887, 0.038190077102626674, 0.06053843317204155, 0.022079075206420384, 0.054987996045383625, 0.04613561774021946, 0.03402602749702055, 0.0393592342879856, 0.05860717938048765, 0.023844056377129164, 0.0234525790438056, 0.018278709503647406, 0.0994763316703029, 0.0178389053689898, 0.05161818546184804, 0.002256244433738175, 0.0572821081004804, 0.1031207740015816, 0.023751438202452846, 0.045852414186811075, 0.027333738653396722, 0.03629115497460589, 0.06309592601610348, 0.03705737050040625, 0.01328270585872815, 0.04693131508247461, 0.027102116218884476, 0.06076796831621323, 0.03225792745070066, 0.042423977647558786, 0.013596381068055052, 0.04746625512780156, 0.03564210230251774, 0.009589795718056848, 0.08033263235120103, 0.0643521742313169, 0.028204582158650737, 0.040750534826656803, 0.03279648175521288, 0.03165722941048443, 0.04095652904652525, 0.0707119790604338, 0.04516884793702047, 0.10257974092382938, 0.03791751965763979, 0.04265985815436579, 0.11681929128826596, 0.07085766264935955, 0.07400900722132064, 0.16019811242586002, 3.7704650033265352, 15.490618329495192, 26.669756211340427, 34.41107511520386, 27.989894673228264, 25.38540232926607, 21.715561151504517, 16.878924183547497, 19.835087656974792, 19.093061573803425, 14.868038836866617, 10.272824764251709, 4.944354062899947, 2.48139011207968, 0.8847123454324901, 0.8571467245928943, 1.065381250809878, 1.6799818840809166, 4.083823263645172, 2.512629898265004, 2.9153197025880218, 5.695416536182165, 2.2424121480435133, 14.541958384215832, 10.04078546538949, 2.478385423310101, 5.086693949997425, 2.739485325291753, 1.5246427757665515, 1.7981511494144797, 1.3393686362542212, 0.6366884324233979, 0.6007693754509091, 0.14024486357811838, 0.10856186680030078, 0.8968954416923225, 0.6783295073546469, 1.8139179283753037, 1.4657832216471434, 0.9343075810465962, 0.1759967888938263, 0.3358663525432348, 0.05606103397440165, 0.3034759109141305, 0.1161830332421232, 0.05835193624079693, 0.06746884566382505, 0.43674716900568455, 0.2822444017510861, 1.712423237040639, 6.221674047410488, 8.907054550945759, 2.286795903928578, 1.802811836823821, 1.9161121384240687, 3.8069841312244534, 2.7974134543910623, 3.593355556949973, 4.468711260706186, 1.1334154126234353, 1.6430315980687737, 0.5053272843360901, 0.7404489896725863, 0.9743928769603372, 1.9384794007055461, 8.84391713887453, 21.9193784147501, 16.882722079753876, 12.693123891949654, 15.481933895498514, 13.649448025971651, 20.262038446962833, 23.51703118532896, 24.041032567620277, 29.27186418324709, 16.27359576523304, 4.8437107633799314, 0.5888483463786542, 0.08644761008326896, 0.03948113204387482, 0.02015161378949415, 0.015996653637557756, 0.044914948084624484, 0.06730080116540194, 0.03950075442844536, 0.021217076246102806, 0.009030763703776756, 0.013365165887080366, 0.026593806287564803, 0.02679074816114735, 0.02752244454313768, 0.039392415710608475, 0.10791685141157359, 0.057639893784653395, 0.027221633536100853, 0.0702607532730326, 0.08451418922049925, 0.05600095340923872, 0.04406235399073921, 0.03691501173307188, 0.026857361481233966, 0.04077637269801926, 0.07848035791539587, 0.036600296589313075, 0.03558621116098948, 0.01639976599108195, 0.022087099678174127, 0.023742975863569882, 0.03837361393379979, 0.037495957512874156, 0.031238342708093114, 0.01490050522988895, 0.05971335049252957, 0.006603466754313558, 0.026975316577591002, 0.03180563297064509, 0.040285757422680035, 0.04095265503565315, 0.042585728733683936, 0.014567194648407167, 0.04583862879371736, 0.00873142214913969, 0.013454543659463525, 0.03799336715019308, 0.03253101182053797, 0.021738657633250114, 0.03367296187207103, 0.00864670320879668, 0.04815290871192701, 0.004496582787396619, 0.06136711897852365, 0.0840934063307941, 0.018255528520967346, 0.0500537121843081, 0.05433645346784033, 0.01869250878371531, 0.04570470453472808, 0.005693188304576324, 0.10163722079596482, 0.028461220535973553, 0.025787679915083572, 0.06563763337908313, 0.03842847349005751, 0.06245195705560036, 0.009275458141928539, 0.04903148910671007, 0.02490906983439345, 0.03444835034315474, 0.0508846095908666, 0.046294140483951196, 0.022393304243450984, 0.06776091788196936, 0.04613421137037221, 0.06283404436544515, 0.021577359257207718, 0.11340306678903289, 0.036525198665913194, 0.049974161374848336, 0.05749858886701986, 0.03111924284894485, 0.01430561449524248, 0.04233387720887549, 0.03215866890968755, 0.014029999401827808, 0.09718935907585546, 0.0031467052212974522, 0.015140051018533995, 0.04557473963359371, 0.020153033146925736, 0.0762704796215985, 0.04804703021363821, 0.034297757447347976, 0.08211980559281074, 0.04673068287956994, 0.10940451611531898, 0.520736644975841, 7.016335856169462, 21.20581280440092, 32.91636072099209, 40.102132335305214, 30.188701786100864, 25.369129702448845, 17.737837694585323, 15.927197802811861, 18.284757547080517, 23.317036516964436, 22.709023542702198, 16.70409746468067, 8.231049925088882, 3.12720132060349, 0.8498325326945633, 0.5290248908568174, 0.2911342622246593, 0.4146276949904859, 0.7674316980410367, 1.7504366347566247, 1.2411878420971334, 4.6290588565170765, 2.293822676874697, 11.976999118924141, 2.5150715047493577, 3.2910117181017995, 4.574707522988319, 6.204767329618335, 4.186167921870947, 6.2527369055897, 1.9922250229865313, 1.1068452196195722, 1.2776361987926066, 0.43228588183410466, 0.4627929604612291, 3.4360515978187323, 1.448929226025939, 2.9008572036400437, 2.3691913951188326, 1.9232770102098584, 0.6147892575245351, 0.7373302476480603, 0.3174061712343246, 0.7709585619159043, 0.4536436451599002, 0.4905586940003559, 0.9175312437582761, 1.3679623394273221, 2.792214620858431, 4.4697267562150955, 4.718117052689195, 8.775744996964931, 4.643368888646364, 5.183176947757602, 6.380953900516033, 3.778118030168116, 3.729018014855683, 3.5267268447205424, 2.936576474457979, 0.5300254840403795, 0.4800300230272114, 0.14202480087988079, 0.11472820115159266, 0.9841313981451094, 3.2961616292595863, 8.185763955116272, 21.832917854189873, 24.484356679022312, 18.341763988137245, 17.93149810284376, 14.396789073944092, 16.303384266793728, 22.955770902335644, 27.418994307518005, 32.00084164738655, 22.69401054829359, 7.4290739838033915, 1.2386518344283104, 0.03237411438021809, 0.008339570958924014, 0.045309841152629815, 0.012287836489122128, 0.037854971451452, 0.02255133345897775, 0.0219963647032273, 0.10109467373695225, 0.05243354229605757, 0.07283847706275992, 0.030844637076370418, 0.0288245277988608, 0.030375629430636764, 0.027786652826762293, 0.11254013457801193, 0.06814839318394661, 0.014713110158481868, 0.0380193015007535, 0.023007822928775568, 0.061388652393361554, 0.01588298073329497, 0.01775841388734989, 0.03632439205830451, 0.07207842878415249, 0.017507300799479708, 0.01625929227884626, 0.010560599093878409, 0.0654527050210163, 0.03130098739347886, 0.024596798211860005, 0.04033119541418273, 0.01775994271156378, 0.009938795301422942, 0.009230596242559841, 0.0014169227233651327, 0.02439050527755171, 0.03301118136732839, 0.06483396908151917, 0.027987411194771994, 0.016143507964443415, 0.042921554268104956, 0.041076894267462194, 0.026447708951309323, 0.029626392388308886, 0.1763886131811887, 0.14256557420594618, 0.07271796712302603, 0.13403941062279046, 0.16999453597236425, 0.08672201176523231, 0.19206581491744146, 0.10453442431753501, 0.19019555824343115, 0.18853145535103977, 0.15928607230307534, 0.1296435808762908, 0.13343239319510758, 0.14458782272413373, 0.11499059488414787, 0.11754345672670752, 0.2582858857931569, 0.1537426744471304, 0.1252809993457049, 0.13034324801992625, 0.1414920575916767, 0.21455808455357328, 0.10738445693277754, 0.09610432432964444, 0.08341482360265218, 0.18268358398927376, 0.20047470432473347, 0.16756268130848184, 0.08636423721327446, 0.155077189556323, 0.13665522885276005, 0.15205213625449687, 0.16200087819015607, 0.15063378814375028, 0.10577285356703214, 0.1412892880034633, 0.14074735692702234, 0.10483788850251585, 0.11805494490545243, 0.16254145855782554, 0.10281450449838303, 0.10516066337004304, 0.21151333465240896, 0.13796185405226424, 0.11537323880475014, 0.11229985684622079, 0.11528612551046535, 0.19586066831834614, 0.2789550251327455, 0.21213406696915627, 0.212322557636071, 0.18148400617064908, 0.1688482888857834, 0.7598149473778903, 7.7953387051820755, 26.010149605572224, 42.49882332980633, 50.52806228399277, 40.30531883239746, 35.76130986213684, 31.586156599223614, 23.343053720891476, 28.068341463804245, 28.29371877014637, 22.741905078291893, 15.12648006901145, 7.258817469701171, 2.9243981279432774, 1.206214043777436, 1.8999500619247556, 2.9483043076470494, 5.159739330410957, 9.430070836097002, 8.635233286768198, 8.804062977433205, 14.754726067185402, 8.101717215031385, 29.087127596139908, 23.550304099917412, 8.856996987015009, 12.67308946698904, 11.428339909762144, 4.57110864110291, 5.917262407019734, 2.839530394412577, 1.8430420593358576, 1.4674534695222974, 0.6850309227593243, 0.2652451826725155, 2.0500484202057123, 1.5793938003480434, 2.573364651761949, 2.1035944344475865, 2.0770255476236343, 0.4728704650187865, 0.5420329584740102, 0.27043326990678906, 0.7887657126411796, 0.6552496051881462, 0.32312608149368316, 0.5720673187170178, 0.909707760438323, 1.2020117067731917, 4.380235858261585, 9.719859436154366, 16.32207166403532, 8.163507599383593, 6.9033194705843925, 7.974716629832983, 10.98721208050847, 8.98247005417943, 10.595030374825, 12.759744767099619, 4.774028677493334, 4.837360829114914, 1.9988506799563766, 1.479008411988616, 1.780081456527114, 3.1036506593227386, 11.73176882788539, 27.76173021644354, 23.230676651000977, 17.554812915623188, 23.742381893098354, 21.315355226397514, 27.715935073792934, 33.24050232768059, 34.699852019548416, 39.57016848027706, 23.145903199911118, 7.851088838651776, 1.0785354324616492, 0.17250143660930917, 0.13204453251091763, 0.13571645657066256, 0.140259558102116, 0.1666739149368368, 0.1619250455405563, 0.0893031049054116, 0.10517374743358232, 0.15684443613281474, 0.23196861671749502, 0.1573308842489496, 0.0787319014489185, 0.18401372042717412, 0.09595398747478612, 0.18912036437541246, 0.1166827286942862, 0.16937179985689, 0.1724454341456294, 0.07983087372849695, 0.13619950565043837, 0.09256920777261257, 0.06478873518062755, 0.1424903649603948, 0.09974072178010829, 0.0923857266025152, 0.08781345124589279, 0.15911796101136133, 0.27863308147061616, 0.1550248236162588, 0.09699030022602528, 0.07456016319338232, 0.13771091907983646, 0.18414096906781197, 0.14571771287592128, 0.165402170678135, 0.07540511316619813, 0.1486183376982808, 0.1446931780083105, 0.14317394234240055, 0.07059942494379357, 0.11263162654358894, 0.11842503910884261, 0.11573907308047637, 0.1512128414469771], [0.030321680860652123, 0.020117654967179988, 0.04666016771807335, 0.05210034396441188, 0.03557855961844325, 0.06857736196252517, 0.01755720095388824, 0.03436856946791522, 0.1179656496969983, 0.03007221719599329, 0.020768245740327984, 0.06933372176717967, 0.014532684781443095, 0.09119438662310131, 0.022157306848384906, 0.023853997445257846, 0.08303436159621924, 0.030198651329556014, 0.027546195124159567, 0.06469182553701103, 0.008942815493355738, 0.10224123994703405, 0.008589480839873431, 0.023383019397442695, 0.14123013883363456, 0.01859025753219612, 0.024078896021819673, 0.0401353129564086, 0.05418804990767967, 0.015958792973833624, 0.0061694740998063935, 0.019962833684985526, 0.049295612043351866, 0.016306374127452727, 0.029894977487856522, 0.02620642560941633, 0.052884022225043736, 0.029063436268188525, 0.006108762709118309, 0.019657890770758968, 0.05535921089176554, 0.07568510322016664, 0.04109122142835986, 0.0375916463235626, 0.0020531033078441396, 0.021146460894669872, 0.12084283007425256, 0.012303291714488296, 0.05004991980968043, 0.010681804797059158, 0.017510133948235307, 0.017587142901902553, 0.03765205343370326, 0.07426518175634556, 0.049966758451773785, 2.175715039484203, 10.937298908829689, 24.246557839214802, 39.03533957898617, 38.695193231105804, 29.36909906566143, 22.472748421132565, 20.137002356350422, 19.144339822232723, 23.623613566160202, 17.86846898496151, 16.945563107728958, 9.942360296845436, 6.854814598336816, 2.0260066352784634, 0.7861727674026042, 0.11383986522560008, 0.5163232411723584, 1.303462937939912, 1.262868291232735, 3.774884403683245, 1.4692039880901575, 11.079701967537403, 1.8905347608961165, 2.036235211417079, 2.9280459322035313, 3.205014020204544, 3.1028605392202735, 6.68404083698988, 1.3463141885586083, 1.5014319587498903, 0.7315246341750026, 0.8449662406928837, 0.16430275310995057, 2.5593265425413847, 0.06830875645391643, 0.13580235274275765, 0.1421989532536827, 0.18167640053434297, 0.24302470235852525, 0.18787548586260527, 0.268325837678276, 0.722053226782009, 0.4765277390833944, 0.9288644324988127, 0.19237174303270876, 1.2707424187101424, 6.0969718638807535, 2.3533775936812162, 3.3781799906864762, 8.694250769913197, 3.150921785272658, 4.391393009573221, 3.0670517357066274, 1.62179988110438, 3.776104850694537, 3.523255493491888, 1.2046759575605392, 0.5722542805597186, 0.5511414853390306, 1.2597841629758477, 4.62056583724916, 9.973635468631983, 11.617130879312754, 25.687476620078087, 53.176584765315056, 16.091462038457394, 18.947242498397827, 14.16840422898531, 20.833096504211426, 25.007087029516697, 30.850073397159576, 25.378169417381287, 8.165363799780607, 2.573609263636172, 0.1817514019785449, 0.012285018183320062, 0.10774296621093526, 0.042631229807739146, 0.03898052003933117, 0.04054012111737393, 0.049600727506913245, 0.021207608297117986, 0.0571816955198301, 0.05644336990371812, 0.06860998677439056, 0.053400694305310026, 0.00813422982901102, 0.047027311884448864, 0.04287308460334316, 0.07101753610186279, 0.04259935827576555, 0.03035154859389877, 0.04945401975419372, 0.03330838182591833, 0.03958675450121518, 0.06204265890119132, 0.07469235453754663, 0.04770998013555072, 0.01585235044331057, 0.046447835557046346, 0.041631241474533454, 0.041931358573492616, 0.024355099267268088, 0.049695540583343245, 0.008488048733852338, 0.06672623043414205, 0.007700258511249558, 0.023035864978737663, 0.039548496788484044, 0.016272816064883955, 0.010884314633585745, 0.005639641422021668, 0.004676086045947159, 0.053850818003411405, 0.010848007841559593, 0.0686209111881908, 0.024208662398450542, 0.022590919616050087, 0.05084455588075798, 0.06357402497087605, 0.008648746897961246, 0.07481589986127801, 0.06297274434473366, 0.04474571986065712, 0.030597320073866285, 0.03138940315693617, 0.026573380528134294, 0.00885228646438918, 0.007391751896648202, 0.027232413231104147, 0.030824320783722214, 0.06078307102143299, 0.059756216942332685, 0.07591302419314161, 0.02310574745933991, 0.0421973220363725, 0.04591438722854946, 0.05129431221575942, 0.030918148659111466, 0.04110091016627848, 0.03353551983309444, 0.05002844947739504, 0.057463303455733694, 0.0322962296922924, 0.08697636803844944, 0.024996249921969138, 0.03361557159223594, 0.0968483867472969, 0.0017321689665550366, 0.022907152451807633, 0.03227530112781096, 0.043650365551002324, 0.057133548689307645, 0.019113501330139115, 0.0848888476321008, 0.034447452344466, 0.036674967777798884, 0.010570755384833319, 0.07914571557193995, 0.043955599758191966, 0.0860453511995729, 0.054212752293096855, 0.022258903154579457, 0.03842013917164877, 0.014115665508143138, 0.00878025175552466, 0.0285102987618302, 0.029750876528851222, 0.024445327726425603, 0.03353646236064378, 0.03296510883956216, 0.04832795908441767, 0.051476680164341815, 0.03471842901490163, 0.14198589749867097, 4.804315902292728, 16.5505401045084, 33.22146914899349, 44.38291423022747, 40.69427356123924, 28.50798737257719, 15.030945595353842, 16.13868970423937, 19.46150690317154, 21.01914022117853, 21.538781337440014, 22.96178787946701, 14.214545153081417, 9.269111473113298, 2.6841652812436223, 0.638340215664357, 0.31938096683006734, 0.17478964116889983, 0.1981378297205083, 1.1505773104727268, 0.9437234164215624, 0.3632211440708488, 2.993181562051177, 2.110525737516582, 1.8753567128442228, 3.937990888953209, 5.340036805719137, 5.703825959935784, 5.087183173745871, 3.9168203249573708, 2.128934324719012, 2.4613331258296967, 1.4395646285265684, 1.63238920038566, 3.0047545535489917, 0.21001073793740943, 0.28342886944301426, 0.28593863476999104, 0.48196500982157886, 1.377893106546253, 1.1078495532274246, 1.2331038946285844, 1.6372855938971043, 1.1742702266201377, 1.9185085035860538, 1.4418896287679672, 2.6364360423758626, 7.24761139601469, 5.423097023740411, 5.545232919976115, 7.811940489336848, 4.141380675137043, 3.7775259744375944, 4.342275895178318, 1.9641144876368344, 1.854192204773426, 0.5584705201908946, 0.5507445253897458, 0.03192387564922683, 0.42286565294489264, 1.1799845262430608, 4.31649380363524, 12.466891631484032, 15.493180342018604, 27.95635387301445, 55.70785313844681, 18.116303086280823, 13.422819636762142, 9.852777253836393, 14.751854371279478, 25.08727602660656, 34.740798622369766, 30.61551198363304, 14.379022177308798, 4.329832037910819, 0.413427107851021, 0.024816147379169706, 0.11612592497840524, 0.03213374759070575, 0.03499640784866642, 0.024824273896228988, 0.03339862327266019, 0.04220054666802753, 0.09200403263093904, 0.06997890784987248, 0.07851008092984557, 0.018956871062982827, 0.019227007251174655, 0.08704384410521016, 0.022804893778811675, 0.02008664061577292, 0.0015778787837916752, 0.004030622121717897, 0.02335257835511584, 0.022875208560435567, 0.04512505009188317, 0.004389089654068812, 0.02785881926683942, 0.1133716590993572, 0.04884572212176863, 0.003161641870974563, 0.036100953657296486, 0.05883476638700813, 0.041073176107602194, 0.0259294950592448, 0.04056190315168351, 0.026873829738178756, 0.005287363865136285, 0.002751184110820759, 0.02785204902465921, 0.05374587461119518, 0.08032716272282414, 0.04861028319282923, 0.05996362124278676, 0.02335109034902416, 0.042401609316584654, 0.05949113292444963, 0.02613874545204453, 0.037010381420259364, 0.030062598962103948, 0.026205162102996837, 0.18607724719913676, 0.11986110228463076, 0.13261380430776626, 0.08953996875789016, 0.11047268184483983, 0.22542553109815344, 0.1713412965182215, 0.1214426189835649, 0.1872371943318285, 0.12154562908108346, 0.1296328048920259, 0.1821290364023298, 0.11384700468624942, 0.17573662160430104, 0.1478270598454401, 0.1253854195238091, 0.23136127274483442, 0.15937287389533594, 0.12125959052355029, 0.1256635764730163, 0.06594440754270181, 0.12282125477213413, 0.16874906374141574, 0.19925817585317418, 0.21654319600202143, 0.15546928101684898, 0.12044630057062022, 0.22338664362905547, 0.12467827153159305, 0.12194675247883424, 0.07545905988081358, 0.09012941955006681, 0.12706950103165582, 0.07578885546536185, 0.12689816881902516, 0.13123858981998637, 0.17165791156003252, 0.18750218558125198, 0.09593322218279354, 0.10868049910641275, 0.18702876957831904, 0.16401453263824806, 0.22513267962494865, 0.17042625811882317, 0.14594253909308463, 0.13437156623695046, 0.24392399238422513, 0.20963944145478308, 0.13309481990290806, 0.2166953808045946, 0.0860158508294262, 0.22714504273608327, 0.18919094261946157, 0.12585622316692024, 0.1947586829192005, 4.552537612617016, 19.056726023554802, 36.878753900527954, 53.94181810319424, 52.14924529194832, 41.30118079483509, 28.640938438475132, 29.73220568150282, 28.444097600877285, 31.18250235915184, 25.75040314346552, 23.527617417275906, 13.925637155771255, 9.56344272941351, 2.9501837817952037, 0.8609608886763453, 0.4411169938975945, 1.965285656042397, 2.888502641580999, 5.2194763999432325, 10.117978323251009, 7.038665832951665, 22.69960194826126, 6.573747955262661, 4.661684380844235, 9.266846794635057, 8.968172371387482, 7.512559304013848, 15.46377182006836, 6.364085180684924, 5.107788518071175, 5.044750850647688, 2.0847994554787874, 2.8014972852542996, 5.768837621435523, 0.6065565242897719, 0.30622669612057507, 0.37358980800490826, 0.5368988995905966, 1.0452520684339106, 0.9737061825580895, 0.7875371910631657, 2.129478882998228, 1.3656131154857576, 2.779556787572801, 1.2293609767220914, 3.447097367607057, 9.11108935251832, 7.719036424532533, 11.43180152401328, 15.707744378596544, 13.176686894148588, 10.262001994997263, 8.272237814962864, 7.012287648394704, 8.277723770588636, 8.409245163202286, 4.21638960018754, 1.6869184118695557, 1.5142525895498693, 1.7044859379529953, 6.414916478097439, 12.930703293532133, 16.359925232827663, 29.185523316264153, 65.69048747420311, 19.63140908628702, 26.418097615242004, 20.28391007333994, 28.710117526352406, 34.673747420310974, 39.99807111918926, 35.346505120396614, 14.809226542711258, 4.937521079555154, 0.4020286101149395, 0.1437242003157735, 0.18279080948559567, 0.18344217765843496, 0.14359739696374163, 0.22372448409441859, 0.14745433843927458, 0.11465682880952954, 0.2929784101434052, 0.1298534602392465, 0.13769874785793945, 0.10234161542030051, 0.17139232659246773, 0.11840079314424656, 0.1594213955104351, 0.09824214008403942, 0.11948237690376118, 0.08073614546447061, 0.16984325658995658, 0.15074093942530453, 0.14256275404477492, 0.15822867513634264, 0.18000443087657914, 0.23085055639967322, 0.1183338588452898, 0.10688171125366352, 0.09820024584769271, 0.14896196691552177, 0.173980507242959, 0.12672615383053198, 0.1633186504477635, 0.1474191903253086, 0.12969808420166373, 0.17875043879030272, 0.11000779311871156, 0.12668116483837366, 0.12273136584553868, 0.11435067804995924, 0.10963580643874593, 0.13483153452398255, 0.20317569142207503, 0.17426013364456594, 0.1005932193947956, 0.09704573865747079, 0.25481088319793344, 0.11082672339398414], [0.032753611594671384, 0.004409475523061701, 0.06599153392016888, 0.0071998788916971534, 0.024235702549049165, 0.041418849941692315, 0.050994584744330496, 0.05489376555487979, 0.07838839839678258, 0.020259574012015946, 0.017047781511791982, 0.03262753554736264, 0.03689077690069098, 0.008989443704194855, 0.02598644747195067, 0.055452740052714944, 0.023915300698718056, 0.06120614714745898, 0.056131085293600336, 0.02316039550350979, 0.0219160698907217, 0.0623339184676297, 0.04567857722577173, 0.04789260412508156, 0.05053263492300175, 0.023476372298318893, 0.05830468740896322, 0.03195415156369563, 0.023004021277301945, 0.06333959536277689, 0.015055124276841525, 0.01845681752456585, 0.027173141606908757, 0.04183555472991429, 0.06319126972812228, 0.05795912118628621, 0.015365880062745418, 0.009427854456589557, 0.007106686944098328, 0.020277190742490347, 0.07750699413008988, 0.031080404405656736, 0.011842922667710809, 0.05508493537490722, 0.04282397298084106, 0.015518576947215479, 0.03351766375999432, 0.07940096984384581, 0.1033685622678604, 0.05681203918356914, 0.033611975886742584, 0.04852621270401869, 0.14687486953334883, 0.052497025608317927, 0.052217406628187746, 0.0805829736054875, 1.4813487301580608, 7.678941451013088, 17.949480637907982, 35.593993440270424, 35.47223277390003, 32.73664176464081, 20.73872096836567, 17.813337743282318, 23.371812477707863, 23.760761506855488, 17.319216057658195, 20.97714677453041, 17.283300384879112, 13.145565614104271, 6.913090646266937, 3.3427053317427635, 1.1502352100796998, 0.4613642964977771, 0.04909759962174576, 0.8132538548670709, 0.5302608339115977, 1.8495601345784962, 0.6953996163792908, 1.841766752768308, 2.6260381378233433, 6.284279963001609, 5.683970600366592, 4.947294630110264, 2.588236816227436, 0.6587033823598176, 1.6938300034962595, 0.970585421891883, 1.5567144798114896, 3.1880066078156233, 0.46657438098918647, 0.6565423670690507, 0.3954762773355469, 0.6399557227268815, 1.489365587476641, 2.363927490077913, 2.028406444005668, 1.266238591633737, 0.28877503413241357, 2.853747569024563, 2.7576048905029893, 3.7605446856468916, 10.355894956737757, 8.538755513727665, 4.119569845497608, 4.199731769040227, 1.6142735537141562, 2.719272547401488, 8.454875964671373, 1.295597122516483, 0.5362601182423532, 0.7592825009487569, 0.8768200501799583, 2.504392177797854, 5.474569536745548, 11.226624883711338, 16.79018184542656, 22.674181312322617, 14.241407811641693, 36.1193760484457, 40.835561379790306, 15.1737941801548, 21.327187791466713, 22.18385562300682, 29.30076353251934, 32.378298193216324, 21.364328898489475, 8.379317969083786, 0.8121900900732726, 0.12666262598941103, 0.0971832660434302, 0.03318983857752755, 0.016571838496020064, 0.048456562144565396, 0.036065022577531636, 0.018998752311745193, 0.05171803029952571, 0.14049144956516102, 0.03204067485057749, 0.1431487686932087, 0.04461036696739029, 0.007855930944060674, 0.015679550633649342, 0.07045347418170422, 0.08759847332839854, 0.02505010943423258, 0.024811434741423, 0.027148871522513218, 0.024020245946303476, 0.027072550910816062, 0.09517524449620396, 0.005943150599705405, 0.02039849106949987, 0.12659218133194372, 0.037062699120724574, 0.03794425923842937, 0.05794232267362531, 0.0610721338307485, 0.06349684903398156, 0.03304590274638031, 0.07814547861926258, 0.01914819673402235, 0.02966788029880263, 0.023893912002677098, 0.06334675708785653, 0.02242053178633796, 0.03560796350939199, 0.11786515548010357, 0.04886497714323923, 0.029253793436510023, 0.03460416053712834, 0.058300724340369925, 0.05738955253036693, 0.04317220351367723, 0.06627047012443654, 0.09914225389366038, 0.03266331819759216, 0.03289382926595863, 0.03374621555849444, 0.05121378548210487, 0.011666908430925105, 0.06836274027591571, 0.022575985749426764, 0.034602264349814504, 0.038907919442863204, 0.021645464294124395, 0.020884909499727655, 0.017095143521146383, 0.042069019546033815, 0.024629951803945005, 0.005868588878001901, 0.04970866546500474, 0.09328945467132144, 0.001830060564316227, 0.03527107670379337, 0.07441887311870232, 0.014675509246444562, 0.04589654228766449, 0.035583131248131394, 0.05148948963324074, 0.01984005833946867, 0.025529670419928152, 0.01628375903237611, 0.033413815035601147, 0.03899996059772093, 0.025739304874150548, 0.023723227313894313, 0.04542854396277107, 0.018487260422261897, 0.015061236790643306, 0.06462221950641833, 0.03320291521959007, 0.028628641630348284, 0.023388481604342815, 0.017101019475376233, 0.06610653712414205, 0.07839284386136569, 0.02280371933011338, 0.0096533912801533, 0.020780890081368852, 0.04856701227254234, 0.02611212090414483, 0.016030618025979493, 0.09042458652402274, 0.013596174194390187, 0.0630506624293048, 0.05925639903580304, 0.03327110745885875, 0.04601912653015461, 0.010151205387955997, 0.026521773434069473, 0.15506878844462335, 2.6186028867959976, 11.02212555706501, 25.967745780944824, 42.59241230785847, 39.64899145066738, 30.9157794713974, 20.51830619573593, 14.718367718160152, 16.433238498866558, 21.012264490127563, 20.147905871272087, 27.83931255340576, 25.45376256108284, 17.450202628970146, 10.37857498973608, 4.191101957112551, 1.4528896822594106, 0.32412257802207023, 0.19751124928006902, 0.13032481307163835, 0.19679363700561225, 0.5154428165405989, 0.4911654145689681, 0.5196668242570013, 1.0533595271408558, 3.2902348972857, 1.9358201371505857, 1.898117728997022, 1.6001000767573714, 2.9833609890192747, 1.8421445949934423, 2.012732522562146, 2.741942130960524, 3.609357448294759, 1.1727117164991796, 0.7803819968830794, 1.0304473503492773, 1.4355571498163044, 2.2805609134957194, 1.8711770558729768, 2.5118279037997127, 3.1337483692914248, 3.1182437762618065, 2.3148386366665363, 3.489189608953893, 3.9876409247517586, 4.717083508148789, 3.2808045158162713, 0.9710355196148157, 3.1812603073194623, 0.8717204269487411, 1.2044885801151395, 1.3831103453412652, 0.5774993053637445, 0.25997952616307884, 0.557586889481172, 0.2580453112022951, 1.8389235553331673, 5.030683530494571, 12.454726584255695, 19.62568089365959, 27.317059077322483, 18.13906766474247, 41.61192812025547, 51.16175428032875, 12.23005698993802, 15.216835420578718, 19.44892007857561, 29.709579795598984, 37.298182994127274, 28.165713138878345, 12.769041918218136, 1.5368793066591024, 0.3111396246822551, 0.1453449172549881, 0.04467827719054185, 0.052266373531892896, 0.05942891126323957, 0.027548983744054567, 0.027592466176429298, 0.024385492069995962, 0.09529807735816576, 0.03593581837776583, 0.07258517463924363, 0.013580045470007462, 0.03448982155532576, 0.08379729682928883, 0.026232332129438873, 0.004505040487856604, 0.020409402495715767, 0.08472145622363314, 0.019044257096538786, 0.09874447016045451, 0.032807550887810066, 0.17776505963411182, 0.06266188836889341, 0.0376386762218317, 0.03560436409316026, 0.02970981349790236, 0.05000450037186965, 0.03832027949101757, 0.018928695426438935, 0.060129109042463824, 0.0690769831999205, 0.05082890027551912, 0.029856604742235504, 0.01628677771805087, 0.04382997642096598, 0.10952224300126545, 0.08574545674491674, 0.014843047229078365, 0.015255534763127798, 0.021155804533918854, 0.031170291476882994, 0.043634093963191845, 0.06149133223516401, 0.03584836740628816, 0.038601586857112125, 0.03350362603669055, 0.055833818041719496, 0.11861840568599291, 0.07474483179976232, 0.21727839717641473, 0.09384770557517186, 0.08649167139083147, 0.19802356866421178, 0.12165874722995795, 0.17973100882954895, 0.1468160469084978, 0.19827481533866376, 0.11686491110594943, 0.16603544529061764, 0.18328033009311184, 0.08043098176131025, 0.07274953066371381, 0.156170551199466, 0.09099465241888538, 0.19324151042383164, 0.2040139026939869, 0.2173318763379939, 0.20070018363185227, 0.14999344828538597, 0.12835987319704145, 0.1595511971390806, 0.10367186318035237, 0.092342481657397, 0.16297769296215847, 0.11731808874174021, 0.1497103041037917, 0.13370914006372914, 0.1144503707473632, 0.1455671459552832, 0.09545584311126731, 0.14236920193070546, 0.22895940084708855, 0.2602562285028398, 0.11752978636650369, 0.12512630608398467, 0.1123465082491748, 0.14028562232851982, 0.16066382493590936, 0.09981120354495943, 0.07666384015465155, 0.09882840706268325, 0.19853286008583382, 0.07060864983941428, 0.18856188340578228, 0.16151376214111224, 0.11122588752186857, 0.16639541659969836, 0.13953054643934593, 0.1290171785512939, 0.20999641448725015, 0.1518598457914777, 0.15595660486724228, 0.1835509468219243, 2.4332982301712036, 11.603008937090635, 28.20583898574114, 50.157183185219765, 48.62395405769348, 42.91822962462902, 30.92311877757311, 25.852146483957767, 30.811646059155464, 34.47453930974007, 26.87455002218485, 30.681529641151428, 22.67492227256298, 17.93066404759884, 10.374979432672262, 3.881584578193724, 1.9283386948518455, 0.5219141661655158, 0.2385678087011911, 1.209882153198123, 1.3467411906458437, 3.0489122215658426, 2.1889473544433713, 6.263606222346425, 5.424262611195445, 12.906927969306707, 16.947937980294228, 10.989120528101921, 7.863135142251849, 4.2583436239510775, 5.100240698084235, 4.485259372740984, 6.683189207687974, 7.747966172173619, 1.5693495143204927, 1.7936676274985075, 1.0956048290245235, 1.617592794355005, 3.468389050103724, 5.967345619574189, 5.254099192097783, 5.552484830841422, 5.927933184430003, 6.905776038765907, 8.014572691172361, 10.747132413089275, 17.36829422414303, 19.46822304278612, 10.688406564295292, 14.973492678254843, 7.945818230509758, 8.843502961099148, 13.804505355656147, 3.8283781707286835, 2.30521185323596, 1.6332565038464963, 1.2661206792108715, 3.7249852437525988, 7.199217667803168, 15.112132988870144, 21.898770220577717, 29.851690270006657, 19.25184365361929, 42.832301035523415, 51.298736929893494, 20.02125296741724, 28.69013249874115, 32.56348505616188, 37.9125340282917, 43.08263920247555, 29.051109328866005, 12.70406635478139, 2.2254348965361714, 0.26538188627455384, 0.3852301271399483, 0.17839735461166129, 0.08350975913344882, 0.18547304993262514, 0.19552095764083788, 0.10917737439740449, 0.10358817860833369, 0.20688393618911505, 0.1026856602402404, 0.20256622490705922, 0.1400177663890645, 0.10101593186846003, 0.1773378052166663, 0.1570151894702576, 0.16196350363316014, 0.14613377570640296, 0.1558339872281067, 0.09267768749850802, 0.1679547133971937, 0.18240351229906082, 0.17495600099209696, 0.20885347737930715, 0.10502277975319885, 0.3657548956107348, 0.06555350351845846, 0.13081311655696481, 0.10479274365934543, 0.23102687584469095, 0.1567193545633927, 0.212030285038054, 0.4178025433793664, 0.144032028329093, 0.09340305521618575, 0.204000425292179, 0.17812660429626703, 0.1797616298426874, 0.1609371876111254, 0.10939529864117503, 0.12239544754265808, 0.09814921577344649, 0.20603408804163337, 0.18514985946239904, 0.1709545633639209, 0.17501644149888307, 0.10536142173805274, 0.2020427881507203], [0.04205403558444232, 0.047619738688808866, 0.055310340467258357, 0.04081717226654291, 0.04529102770902682, 0.043582314319792204, 0.07338725816225633, 0.0555930875998456, 0.05812086856167298, 0.029464754479704425, 0.0812623133242596, 0.025056805461645126, 0.06395931835868396, 0.04157238916377537, 0.02878497132769553, 0.04115449693927076, 0.0589177904475946, 0.048700168408686295, 0.052765107902814634, 0.05142232897924259, 0.07056974645820446, 0.01801127102226019, 0.10735756150097586, 0.044689658025163226, 0.04557984932034742, 0.01539875442176708, 0.023251659258676227, 0.02241887679701904, 0.018928773351944983, 0.03272739522799384, 0.05231414186710026, 0.09348626481369138, 0.03189899514836725, 0.09941642550984398, 0.039174651028588414, 0.036487100514932536, 0.07965030177729204, 0.07426340802339837, 0.06469038577051833, 0.056444694637320936, 0.03162657500070054, 0.02873742563679116, 0.009525265049887821, 0.09739664092194289, 0.06591469937120564, 0.029346723313210532, 0.08358674211194739, 0.03145748036331497, 0.041809598114923574, 0.023564865987282246, 0.00791839473095024, 0.038324194320011884, 0.028497327875811607, 0.05759841144026723, 0.06393422634573653, 0.08431556081632152, 0.09724038915010169, 0.45457308122422546, 1.1247471277602017, 11.979907862842083, 28.179021924734116, 39.79386627674103, 40.84851488471031, 28.454531840980053, 26.821219883859158, 20.43074369430542, 25.81911675632, 16.692327596247196, 16.10886700451374, 17.94530276209116, 19.334392324090004, 15.317820701748133, 9.548524729907513, 7.829583892598748, 3.6773327132686973, 1.4130219840444624, 0.9565760486293584, 0.37314763641916215, 1.0736747807823122, 0.32415823079645634, 1.5955992182716727, 3.3245981158688664, 3.3047228073701262, 1.2285484140738845, 1.3693568645976484, 3.571444032713771, 1.2505963747389615, 1.5408378629945219, 1.4084173436276615, 1.7780767078511417, 0.3645933454390615, 1.0674089170061052, 0.6537100940477103, 1.4059527008794248, 3.048902484588325, 1.5125866164453328, 2.513445666991174, 1.8787730857729912, 2.857706481590867, 0.6586742307990789, 2.7697499888017774, 2.2387436823919415, 3.5547068808227777, 2.2714891377836466, 1.5668712160550058, 4.0811733808368444, 1.057177847251296, 0.5728421802632511, 0.5969458899926394, 0.8742471132427454, 1.8148777331225574, 3.9695534203201532, 8.204051423817873, 15.632879845798016, 17.7458343654871, 21.032040528953075, 29.708842635154724, 51.76459953188896, 29.031848162412643, 26.234544664621353, 26.527288556098938, 24.308745302259922, 25.482405424118042, 26.3807912170887, 30.412918254733086, 15.493406429886818, 5.855471547693014, 0.2643428498413414, 0.057842221794999205, 0.05459477280965075, 0.064198200852843, 0.03607601749536116, 0.06574631348485127, 0.04295132552215364, 0.013956641814729664, 0.03408381853660103, 0.024654425978951622, 0.07977750588906929, 0.020424648064363282, 0.008587647735112114, 0.03426708819461055, 0.03915208231774159, 0.03241253907617647, 0.16196553711779416, 0.021741249584010802, 0.036982083329348825, 0.09305818661232479, 0.05095207081467379, 0.053487956029130146, 0.00597039159401902, 0.03392793041712139, 0.08577360640629195, 0.04636136793124024, 0.034375779432593845, 0.031129792478168383, 0.044685917600872926, 0.008999365290947026, 0.04991182097001001, 0.004286077701181057, 0.04657984507502988, 0.0055354772848659195, 0.022501522362290416, 0.027929161879001185, 0.035845985112246126, 0.026042379431601148, 0.040429581931675784, 0.013556627000070876, 0.10966130663291551, 0.04378470541269053, 0.01962571495823795, 0.04574261714878958, 0.04640799706976395, 0.04345462039054837, 0.03955089392547961, 0.12660978507483378, 0.057989994529634714, 0.05207813148444984, 0.01358159748633625, 0.04654037766158581, 0.020950400321453344, 0.10159143028431572, 0.02256892421428347, 0.024074435714283027, 0.027598874621617142, 0.01729655126837315, 0.06591602039407007, 0.08967278350610286, 0.03223168881959282, 0.029711796887568198, 0.039589593216078356, 0.037100422487128526, 0.0279136880999431, 0.01821745820052456, 0.024880296768969856, 0.10993125542881899, 0.09583516221027821, 0.027102793428639416, 0.04491650288400706, 0.06478795592556708, 0.025754567141120788, 0.06912507436936721, 0.016927175092860125, 0.04938701124046929, 0.03630873645306565, 0.053439675612025894, 0.056885971935116686, 0.02722468376305187, 0.06898178791743703, 0.031231262619257905, 0.05570075838477351, 0.05427358984888997, 0.026277580873284023, 0.04596612605382688, 0.0281778110365849, 0.04315659614803735, 0.02390192534221569, 0.028610754015971906, 0.0454776258993661, 0.027828734455397353, 0.02254692324640928, 0.033755195545381866, 0.046124274012981914, 0.05391458333178889, 0.061953638287377544, 0.040746245213085786, 0.04574826489260886, 0.04874357662629336, 0.049767606833484024, 0.05245359512628056, 0.07111620463547297, 0.011498919593577739, 0.055393594593624584, 0.10600442590657622, 0.9699286508839577, 3.8067708676680923, 18.232894130051136, 34.84644815325737, 44.27798666059971, 40.42885020375252, 27.677169553935528, 24.933553375303745, 15.933136884123087, 18.809404894709587, 15.950544700026512, 15.266329664736986, 19.99497927725315, 24.977674707770348, 23.745512925088406, 16.340776160359383, 8.679176028817892, 3.533997517079115, 1.969523022416979, 1.160715997684747, 0.14714799472130835, 0.22173398465383798, 0.27032919111661613, 0.28075256617739797, 0.23392150411382318, 0.61945790075697, 0.7277375436387956, 0.6870042043738067, 0.4662538325646892, 0.9009501209948212, 1.177097512409091, 1.9146727281622589, 1.2012165994383395, 1.6350389644503593, 0.4883998160948977, 0.8028919890057296, 1.6591519955545664, 1.8513797619380057, 1.9939572550356388, 1.11277527641505, 1.417965400032699, 1.2635442987084389, 1.1025877855718136, 1.2168540665879846, 2.3423909582197666, 0.9570897335652262, 0.6526954297441989, 0.17299892788287252, 0.87533985148184, 0.07005079969530925, 0.2742015098920092, 0.3925740049453452, 0.30352708941791207, 1.5446751820854843, 3.9956774935126305, 9.16341444477439, 19.346021600067616, 23.246540799736977, 27.27010689675808, 31.904288828372955, 46.12292446196079, 19.121632240712643, 28.751064129173756, 28.214597515761852, 21.69473636895418, 26.526127718389034, 29.668581895530224, 33.14874865114689, 20.57476546615362, 8.390298429876566, 0.6177544046659023, 0.05425155548437033, 0.06588617863599211, 0.07065950179821812, 0.05229473470535595, 0.10617454099701717, 0.028117292604292743, 0.0439630954497261, 0.028755932944477536, 0.07032362802419811, 0.026092867738043424, 0.021187069360166788, 0.08218555245548487, 0.025074726472666953, 0.02189637514675269, 0.022266948035394307, 0.06523872158140875, 0.028947622267878614, 0.03917098852980416, 0.04485454839596059, 0.031045679315866437, 0.0628333022177685, 0.07182207613368519, 0.018689209937292617, 0.05104170741105918, 0.017333222640445456, 0.05446049231977668, 0.033413789060432464, 0.03418304739170708, 0.04762111908348743, 0.02712422294280259, 0.01931474580487702, 0.022762500448152423, 0.018697412524488755, 0.007625331745657604, 0.032828379262355156, 0.055992043926380575, 0.017946867446880788, 0.03708421027113218, 0.04633589371223934, 0.0031679536050432944, 0.03894986191880889, 0.04148777690716088, 0.0358624793443596, 0.027093165917904116, 0.024085046570689883, 0.06348076669382863, 0.02968304237583652, 0.1035408147436101, 0.13507828378351405, 0.1983455420122482, 0.14061314694117755, 0.0763037649448961, 0.21812331746332347, 0.11984869357547723, 0.179488786670845, 0.2317993328324519, 0.19159526360454038, 0.1200578011048492, 0.27766811137553304, 0.0708784798916895, 0.09828204536461271, 0.08990569913294166, 0.11810130687081255, 0.13636954652611166, 0.1337256157421507, 0.15282671578461304, 0.22224085667403415, 0.16425362293375656, 0.20414607919519767, 0.15309442329453304, 0.22783850552514195, 0.14313514286186546, 0.1457941095577553, 0.10225200850982219, 0.17528211552416906, 0.14628376375185326, 0.16530296037672088, 0.14682999928481877, 0.18725836038356647, 0.19854265643516555, 0.06468144289101474, 0.16796730022178963, 0.12349478347459808, 0.13006642693653703, 0.3112002433044836, 0.15032460942165926, 0.13927775609772652, 0.26371526008006185, 0.1629322289954871, 0.1447016978636384, 0.15212845872156322, 0.24472186050843447, 0.17591081850696355, 0.16057139786425978, 0.22953349660383537, 0.20195668417727575, 0.1631546951830387, 0.13949566549854353, 0.15531052078586072, 0.14148013869998977, 0.14265915902797133, 0.126400989247486, 0.17081392637919635, 0.2062325383303687, 0.21801992144901305, 0.7007876678835601, 3.879936416633427, 20.38147173821926, 39.98092643916607, 53.20275016129017, 54.285536259412766, 39.68295022845268, 38.59935097396374, 29.271790087223053, 34.46641154587269, 26.732680834829807, 25.17854142934084, 28.085816726088524, 26.310455091297626, 22.286092936992645, 13.639502059668303, 11.21605385094881, 4.662667103111744, 2.54544778726995, 1.550601082853973, 0.8887043280992657, 2.0268133794888854, 1.337429671548307, 3.289618380367756, 5.614692242816091, 6.106852758675814, 4.348163679242134, 5.105470167472959, 9.0080844797194, 3.999551385641098, 7.257744977250695, 5.658550439402461, 5.273595945909619, 4.315662598237395, 2.7861045487225056, 3.6936205392703414, 5.5031881760805845, 7.977011706680059, 7.901675524190068, 7.912098364904523, 7.163163777440786, 8.833989221602678, 5.936592444777489, 7.769663007929921, 5.219777058809996, 9.944273494184017, 5.718504572287202, 4.800437735393643, 7.300873612985015, 2.5864900974556804, 1.7055098642595112, 0.9138019219972193, 1.4323302917182446, 2.4499460868537426, 5.235483990982175, 11.397772450000048, 20.378559194505215, 23.87174215167761, 27.943024188280106, 38.25057528913021, 59.6661539375782, 35.59940055012703, 34.29273806512356, 34.56879325211048, 30.67522767931223, 35.32659038901329, 35.66375769674778, 39.99639920890331, 20.226090475916862, 8.13203863799572, 0.7859534479212016, 0.12979566177818924, 0.10713646086514927, 0.1436998281860724, 0.11555070857866667, 0.233649892907124, 0.08718564626178704, 0.14881770825013518, 0.15678029973059893, 0.2081648533931002, 0.15658181975595653, 0.10706521468819119, 0.21549327968386933, 0.1799504618975334, 0.12015413929475471, 0.12267964557395317, 0.16790696361567825, 0.18302313139429316, 0.19965204846812412, 0.14032620296347886, 0.14381640474312007, 0.13548164104577154, 0.11457118496764451, 0.12491890549426898, 0.22417185071390122, 0.18982497422257438, 0.15017252851976082, 0.129546997777652, 0.19345711916685104, 0.15078710101079196, 0.11599152203416452, 0.08996685952297412, 0.1853394039790146, 0.06312262848950922, 0.16187981906114146, 0.1501367866876535, 0.12729175941785797, 0.15473479230422527, 0.2053819183493033, 0.09758920597960241, 0.21568496158579364, 0.13671048916876316, 0.12370899697998539, 0.14517141797114164, 0.08008376797079109, 0.16958307445747778, 0.16306553356116638, 0.1349674366065301, 0.36630862683523446], [0.06176088769279886, 0.06772817432647571, 0.09402760959346779, 0.06508878548629582, 0.11090723899542354, 0.007801770861988189, 0.09126276811002754, 0.039811454553273506, 0.03395101863134187, 0.009986358618334634, 0.01762609823344974, 0.0028443424298529862, 0.04323487417423166, 0.018344591808272526, 0.06042511093255598, 0.014206411615305115, 0.039913173313834704, 0.028451388934627175, 0.04845440991630312, 0.028823032371292356, 0.04437055678863544, 0.06589359269128181, 0.020865173937636428, 0.03189110982930288, 0.0192218623124063, 0.03670397090900224, 0.04381352300697472, 0.05295854127325583, 0.05662574898451567, 0.056820893005351536, 0.03441745473537594, 0.04991802532458678, 0.10841273222467862, 0.05620388998067938, 0.07050017011351883, 0.024328587896889076, 0.05450144031783566, 0.012072688805346843, 0.03749569405044895, 0.056463641667505726, 0.05148448755790014, 0.011901851976290345, 0.03327913749672007, 0.03751817741431296, 0.03861252982460428, 0.07698760950006545, 0.07101787006831728, 0.04196614674583543, 0.03133394988253713, 0.08564393836422823, 0.019488003890728578, 0.02256140625831904, 0.05242891871603206, 0.03138338062854018, 0.04787043988471851, 0.06226129931746982, 0.032423088705400005, 0.14571608015103266, 0.13131799962138757, 1.1404564348049462, 8.391093537211418, 17.98485103994608, 30.469377525150776, 37.84555122256279, 37.710126489400864, 31.139916144311428, 25.546943061053753, 25.179662369191647, 26.54725268483162, 25.118552148342133, 20.43575182557106, 16.253952719271183, 18.443129248917103, 18.489066883921623, 17.881851866841316, 13.455853164196014, 9.06337721273303, 5.118483519181609, 2.347288182936609, 1.55195725383237, 0.9514500643126667, 0.5616464372724295, 0.22523895517224446, 0.5360212060622871, 0.3729532827856019, 0.5602579680271447, 0.7455870264675468, 0.44335263955872506, 0.6927973497658968, 1.2221743748523295, 0.9778740839101374, 0.5426143272779882, 0.6555516296066344, 1.2522530858404934, 1.5870226034894586, 0.7499379117507488, 0.8125234034378082, 1.328386275563389, 0.6005473248660564, 0.8111031109001487, 0.787330458406359, 1.737567437812686, 0.8096072974149138, 0.4421880020527169, 0.11228273549932055, 0.6704568048007786, 1.1683288891799748, 1.9993256544694304, 4.0441856905817986, 8.327610343694687, 9.737860020250082, 19.670165106654167, 23.63812878727913, 24.716788306832314, 25.544250905513763, 18.744574673473835, 21.897223703563213, 27.00434535741806, 29.536913260817528, 23.85955050587654, 28.70306320488453, 31.83291155844927, 31.89423456788063, 21.48427516222, 8.192197009921074, 2.8025234676897526, 0.1993643623427488, 0.11866421104059555, 0.10019845620263368, 0.06531845792778768, 0.05477053564391099, 0.021026012182119302, 0.04088605099241249, 0.03587762657843996, 0.06165360282466281, 0.027567136676225346, 0.06877086954773404, 0.014305899294413393, 0.04141035977227148, 0.06160729652037844, 0.08604092799942009, 0.012273903594177682, 0.017306104564340785, 0.055337799931294285, 0.04539212677627802, 0.03050437164347386, 0.027132559116580524, 0.04752883301989641, 0.057187176280422136, 0.013825361456838436, 0.057403619939577766, 0.030484777089441195, 0.05948559279204346, 0.013251321361167356, 0.09783105706446804, 0.10418917721835896, 0.031138668564381078, 0.03330168023239821, 0.01985049108043313, 0.03482289001112804, 0.019267203824711032, 0.012715718021354405, 0.02319745093700476, 0.0593273186677834, 0.03622030955739319, 0.02821409834723454, 0.01683724720351165, 0.0071225174178835005, 0.06417240379960276, 0.04589617492456455, 0.035018753915210254, 0.10323650451027788, 0.027016847161576152, 0.027979370024695527, 0.015770370955578983, 0.01646160915697692, 0.019904684559151065, 0.03784769469348248, 0.02299973537446931, 0.061828920370317064, 0.006193539165906259, 0.03174801262503024, 0.031707747402833775, 0.024663508011144586, 0.03636165158241056, 0.06870856625027955, 0.026074475463246927, 0.05228555804933421, 0.03641739429440349, 0.01955796429683687, 0.04039030747662764, 0.06188318249769509, 0.047797405131859705, 0.03144106776744593, 0.01714620699203806, 0.04852981583098881, 0.027758929900301155, 0.06809248719946481, 0.08638919563964009, 0.06077221711166203, 0.06635861500399187, 0.04836972715565935, 0.02431788427202264, 0.023927880101837218, 0.023872345191193745, 0.07036703624180518, 0.04830328267416917, 0.0060037757157260785, 0.023831309990782756, 0.03939633796107955, 0.06974207368330099, 0.00996752291030134, 0.021508363643079065, 0.055877998092910275, 0.03687610093038529, 0.033385168135282584, 0.021117422511451878, 0.003670740102279524, 0.02839679284079466, 0.006953188076295191, 0.08945301131461747, 0.08104668231680989, 0.045203747431514785, 0.04832681246625725, 0.021559683154919185, 0.04890403266472276, 0.026951551153615583, 0.10118974285433069, 0.04873178761044983, 0.03364783646247815, 0.007176969720603665, 0.050561111129354686, 0.0767077159252949, 0.09372294312925078, 0.22172117518493906, 2.229717504233122, 12.636107951402664, 26.13776955753565, 39.530768394470215, 44.10963289439678, 40.173272117972374, 28.05255141109228, 20.501932874321938, 15.502544939517975, 14.292990993708372, 21.972402669489384, 21.725020743906498, 20.579688102006912, 27.48942732810974, 26.806955449283123, 22.938896007835865, 15.11330807581544, 10.339671727269888, 6.825902899727225, 3.104604408144951, 1.5338102588430047, 1.6528457589447498, 0.691702296026051, 0.3893834230257198, 0.2441603664192371, 0.08274138395790942, 0.08199563686503097, 0.3104944311780855, 0.10346067763748579, 0.4453531134640798, 0.3332079795654863, 0.20187730406178162, 0.4962667595827952, 0.3190285951131955, 0.30666037753690034, 0.24242060899268836, 0.19812387734418735, 0.31939557229634374, 0.6186150584835559, 0.11355666909366846, 0.246412843989674, 0.3014780196826905, 0.8417126059066504, 0.2017007174436003, 0.06266295706154779, 0.21297926927218214, 0.3427411039592698, 0.7832634297665209, 1.8904904695227742, 5.119730327278376, 9.745806343853474, 14.835940059274435, 22.78779711574316, 29.01039831340313, 31.45385529845953, 27.23225712776184, 21.45534161478281, 23.718826957046986, 33.11971440911293, 29.599176719784737, 24.413496181368828, 29.27600786089897, 34.25190165638924, 35.31451463699341, 26.56827125698328, 12.921350095421076, 4.17979471385479, 0.4508326866198331, 0.04677636949054431, 0.0320538850792218, 0.030751345402677543, 0.061969442322151735, 0.01382110709528206, 0.05340451265510637, 0.04605340633133892, 0.05719333981687669, 0.020597867187461816, 0.02414881560980575, 0.02905111661675619, 0.006641505997322383, 0.028518328799691517, 0.04847291907935869, 0.014555368525179802, 0.011682741223921767, 0.037812836017110385, 0.07430526515236124, 0.05862703554157633, 0.08581915200920776, 0.027549679507501423, 0.05989951081573963, 0.029744301100436132, 0.009063206689461367, 0.05271413720038254, 0.020647613346227445, 0.025835700580500998, 0.039815376803744584, 0.027253059779468458, 0.016028131831262726, 0.02939312980743125, 0.01937577446369687, 0.012780462056980468, 0.041547022556187585, 0.007247592957355664, 0.008393709704250796, 0.07094949600286782, 0.048992121883202344, 0.011426527726143831, 0.013926186857133871, 0.00802808508524322, 0.05418125925643835, 0.02337122852622997, 0.04109122142835986, 0.05620682146400213, 0.05934025801252574, 0.015100984364835313, 0.037490217000595294, 0.02587800485343905, 0.19716629903996363, 0.1612190849846229, 0.2965180983301252, 0.12597651046235114, 0.2501342841424048, 0.11092850894783624, 0.2163438848219812, 0.1539345196215436, 0.08855559150106274, 0.11096478512627073, 0.0893901291419752, 0.1632683476782404, 0.1370708315516822, 0.04465864738449454, 0.19880007777828723, 0.09307212414569221, 0.16901730559766293, 0.12254047062015161, 0.09412200335646048, 0.18929558544186875, 0.12927657400723547, 0.12430451111868024, 0.23101065249647945, 0.2043004013830796, 0.11889812856679782, 0.18813028000295162, 0.17454974935390055, 0.1160775072639808, 0.22552779904799536, 0.1560463453643024, 0.09919096846715547, 0.06507598343887366, 0.18169041228247806, 0.28985744167584926, 0.14473548042587936, 0.07248384921695106, 0.11615764437010512, 0.22155586921144277, 0.1565801870310679, 0.2070163650205359, 0.10837364330654964, 0.1165363697509747, 0.08627467483165674, 0.14642912079580128, 0.1716383040184155, 0.212604915141128, 0.16469895606860518, 0.1449715279159136, 0.1692462878418155, 0.17995869973674417, 0.10575422566034831, 0.17747645324561745, 0.13114050758304074, 0.11522682048962452, 0.0894915139360819, 0.13738514593569562, 0.2084405315690674, 0.20327007776359096, 0.28975030523724854, 2.0207928400486708, 12.57090725004673, 27.486036010086536, 44.400222301483154, 51.4092767983675, 52.18180954456329, 41.42806738615036, 35.357079952955246, 32.04857848584652, 33.713687136769295, 37.12118849158287, 30.771058537065983, 26.555944718420506, 27.16244537383318, 25.192902758717537, 26.77311446517706, 16.82945653796196, 12.445051353424788, 7.1252161636948586, 3.5674003371968865, 2.1057567559182644, 1.8168341531418264, 0.9149784338660538, 0.9989483468234539, 1.2699384056031704, 1.8975685397163033, 1.4520968310534954, 2.4996576318517327, 1.543793985620141, 3.2091194624081254, 4.303239164873958, 3.468965906649828, 1.6323882504366338, 4.1884468495845795, 3.8044242560863495, 4.964114902541041, 4.825246129184961, 2.9670159285888076, 3.280187761411071, 2.544743400067091, 3.1888513499870896, 2.518652337603271, 4.744876166805625, 2.515866137109697, 1.6446446115151048, 0.7559700286947191, 1.63355918135494, 1.5048423944972456, 2.86007565446198, 5.810851017013192, 10.728216078132391, 14.150269702076912, 25.661372020840645, 32.649797424674034, 33.067512810230255, 34.44540247321129, 25.556512847542763, 30.26367176324129, 35.90922832489014, 35.09795285761356, 34.58191774785519, 40.01130200922489, 43.8649982213974, 40.73498837649822, 29.030210450291634, 11.835365518927574, 3.628587741404772, 0.33322080387733877, 0.25394927943125367, 0.14814698486588895, 0.1743795452057384, 0.24299745069583878, 0.1407016406301409, 0.1703822339186445, 0.10388877810328268, 0.2613279194338247, 0.12128319081966765, 0.15333289018599316, 0.20549194916384295, 0.08270230988273397, 0.15820816217456013, 0.2032167767174542, 0.12326499228947796, 0.12688783812336624, 0.14263894292525947, 0.16367458447348326, 0.14518209005473182, 0.11219090956728905, 0.1291859577759169, 0.15438230184372514, 0.25673987343907356, 0.13368873100262135, 0.10327593481633812, 0.12963425950147212, 0.10871719088754617, 0.20699083514045924, 0.18944683513836935, 0.09524336623144336, 0.14802420395426452, 0.08505819831043482, 0.1608520039007999, 0.12796530296327546, 0.056262701473315246, 0.0696087023243308, 0.1786370386253111, 0.09236116893589497, 0.13793142599752173, 0.1165340468287468, 0.07956030895002186, 0.18163777916925028, 0.10416905759484507, 0.13824528024997562, 0.3051828208845109, 0.1322675182018429, 0.18552344175986946, 0.10148608242161572, 0.1566875757998787], [0.03982672424172051, 0.011621144822129281, 0.0401117868750589, 0.03957793778681662, 0.038759723684052005, 0.03151822886138689, 0.0108870689291507, 0.037684032577089965, 0.022562354351975955, 0.01820050569222076, 0.07172793470090255, 0.028203802903590258, 0.007052401624605409, 0.04253582301316783, 0.022654150598100387, 0.06665387845714577, 0.041308166037197225, 0.03816589422058314, 0.06654898330452852, 0.05444664755486883, 0.062030354092712514, 0.012508967738540377, 0.1271309657022357, 0.03083923238591524, 0.01780960908945417, 0.01309984530962538, 0.020453096440178342, 0.02233065399195766, 0.032310271126334555, 0.04967508699337486, 0.006063344198992127, 0.05021504395699594, 0.073479046986904, 0.02703581460082205, 0.03415685328945983, 0.083087885286659, 0.0816548649163451, 0.04544031442492269, 0.015116412687348202, 0.047079644427867606, 0.055528984594275244, 0.048951452190522105, 0.026949384082399774, 0.015554123037873069, 0.03802788443863392, 0.025746095525391866, 0.013451232753141085, 0.03695491330290679, 0.013420301893347641, 0.024539808691770304, 0.02434005593386246, 0.021401650228654034, 0.04182328331808094, 0.09425481810467318, 0.016062728900578804, 0.02371213962760521, 0.04670312693633605, 0.010798243129102048, 0.09890804692986421, 0.05821770027978346, 0.16897243534913287, 2.0601879386231303, 7.816360602155328, 19.717428870499134, 31.851336769759655, 42.115233913064, 38.818059638142586, 34.68378648161888, 34.89268407225609, 26.37628845870495, 25.72058044373989, 20.276576466858387, 24.34890154749155, 15.393727328628302, 15.270654782652855, 26.698361076414585, 26.389363557100296, 18.918934017419815, 17.252164855599403, 12.864540293812752, 10.140670705586672, 6.2365013267844915, 4.239041609689593, 3.7310919910669327, 1.2639879249036312, 1.6640812810510397, 1.0064495005644858, 0.6013646372593939, 0.241697549354285, 0.46236966911237687, 0.3424614924006164, 0.1198337170353625, 0.18755847006104887, 0.47365081845782697, 0.25802684656810015, 0.32969545398373157, 0.20481086539803073, 0.1500223475159146, 0.3391982690664008, 0.23139676224673167, 0.47527787333820015, 1.1963267368264496, 1.4593816339038312, 2.0336380507797003, 3.30417278688401, 5.813355557620525, 8.433302622288465, 11.343083884567022, 12.095108181238174, 18.064319975674152, 20.35631138831377, 15.031232479959726, 20.885883271694183, 24.906968101859093, 26.48961927741766, 26.196953281760216, 19.41852930933237, 20.58341760188341, 26.265286915004253, 30.195904299616814, 32.937529385089874, 22.558335028588772, 11.676012519747019, 2.9275277350097895, 0.5212077009491622, 0.021704680257244036, 0.00926929646084318, 0.03422210291319061, 0.029969227507535834, 0.019310183452034835, 0.012590150345204165, 0.02771769060927909, 0.0247690080141183, 0.05528269917704165, 0.04697699056123383, 0.033479866178822704, 0.01986396477150265, 0.019961614707426634, 0.028923088721057866, 0.042294780869269744, 0.0887022027745843, 0.0850750005338341, 0.07397945490083657, 0.06224579214176629, 0.03713044978212565, 0.10021576308645308, 0.03785921653616242, 0.04200549541565124, 0.027308205062581692, 0.0019800609015874215, 0.020977349558961578, 0.05796841287519783, 0.07846967841032892, 0.029192364017944783, 0.045373428365564905, 0.024603095334896352, 0.07449990822351538, 0.06852374921436422, 0.008527204445272218, 0.017783257280825637, 0.03360387905559037, 0.04342164676927496, 0.02089843328576535, 0.035247639680164866, 0.04463916971872095, 0.03349241960677318, 0.05706936033675447, 0.04090584036021028, 0.038796686349087395, 0.0526175392587902, 0.09304943669121712, 0.025096567878790665, 0.06515828761621378, 0.026391437459096778, 0.04929191985866055, 0.08241615258157253, 0.03012979301274754, 0.030225977207010146, 0.03940455353586003, 0.02634245014633052, 0.00919341464395984, 0.009427226414118195, 0.04646898676583078, 0.02719397183682304, 0.047046077088452876, 0.0218255946674617, 0.04168710293015465, 0.013738708294113167, 0.09451246951357462, 0.02436020709865261, 0.014871222865622258, 0.02315238587470958, 0.023002004490990657, 0.09566818640450947, 0.03787584435485769, 0.058107417135033756, 0.03947140990931075, 0.01703239122434752, 0.033451156195951626, 0.05994813262077514, 0.046302170521812513, 0.0742510290001519, 0.02251093650556868, 0.04480797862925101, 0.034285857109352946, 0.03738828672794625, 0.04354598619102035, 0.007205276160675567, 0.01953722498001298, 0.010399116108601447, 0.029102222761139274, 0.01989132033486385, 0.05200252518989146, 0.017303360473306384, 0.052662149755633436, 0.04864612521487288, 0.04066161440277938, 0.02976185474835802, 0.035334534040885046, 0.025022488553076982, 0.03872162182233296, 0.016440348481410183, 0.028898460550408345, 0.007618259078299161, 0.009688626596471295, 0.004575121956804651, 0.025208274091710337, 0.06387042390997522, 0.03795276425080374, 0.027722303057089448, 0.04336566285928711, 0.016097296283987816, 0.04033685429021716, 0.04891830787528306, 0.0688059582898859, 0.027107589557999745, 0.36214734544046223, 3.862947290763259, 12.907439041882753, 26.613811813294888, 39.73809666931629, 44.954205974936485, 39.41860981285572, 32.62769781053066, 31.522969789803028, 23.991775810718536, 17.28364996612072, 15.230750273913145, 18.57352875173092, 19.326348155736923, 25.520857460796833, 33.20763409137726, 29.3671003729105, 25.433813631534576, 25.127200484275818, 18.546103723347187, 10.878983438014984, 7.171755591407418, 4.423881741240621, 4.11850162781775, 2.2034509386867285, 1.9294812460429966, 1.0620745969936252, 0.389030606020242, 0.3909465344622731, 0.3130735724698752, 0.6767304462846369, 0.1474816197878681, 0.16722136759199202, 0.27922252484131604, 0.4264376690844074, 0.24415665568085387, 0.4321914806496352, 0.14049150893697515, 0.29951557342428714, 0.15450057049747556, 0.5982609756756574, 1.0273493290878832, 1.4399536326527596, 1.9029995170421898, 3.975607445463538, 6.458819797262549, 13.388535976409912, 19.49298821389675, 22.60128792375326, 27.690767124295235, 26.694684773683548, 21.907486952841282, 25.908022485673428, 24.94973860681057, 22.787734419107437, 19.870537854731083, 19.577611573040485, 18.999924771487713, 26.908514499664307, 32.546047791838646, 37.44963526725769, 28.005477637052536, 17.283516973257065, 5.141529757529497, 1.0844603832811117, 0.013998119520692853, 0.016307563419104554, 0.05647865902574267, 0.021876045866520144, 0.027617788255156484, 0.04694321170973126, 0.04417785814439412, 0.012844050197600154, 0.024772972938080784, 0.01070623815394356, 0.04714346170658246, 0.05609258638287429, 0.03141535235045012, 0.041788988673943095, 0.04851405632507522, 0.06380617618560791, 0.020986925119359512, 0.04414757109771017, 0.06663581458269618, 0.018237626063637435, 0.07373264626949094, 0.007749030601189588, 0.04626629139238503, 0.021758476686954964, 0.0263140815513907, 0.09455497973249294, 0.09097957939957269, 0.06650398689089343, 0.04609063245879952, 0.04535192834737245, 0.014744859236088814, 0.017624786487431265, 0.008483924248139374, 0.03615578723838553, 0.03472847027296666, 0.046543565185857005, 0.019013522905879654, 0.06348596172756515, 0.027122287792735733, 0.016733992197259795, 0.0493228488630848, 0.07210886426037177, 0.025347436057927553, 0.07600244556670077, 0.054509295950992964, 0.03029755735042272, 0.049593773583183065, 0.04751711821882054, 0.01618629648874048, 0.021300029802659992, 0.03718067462614272, 0.1380757737206295, 0.12730758200632408, 0.17050635069608688, 0.12019653077004477, 0.1396285544615239, 0.18508768233004957, 0.10959869163343683, 0.13424569799099118, 0.13931263703852892, 0.11562415151274763, 0.1987888416624628, 0.13150714337825775, 0.2419779624324292, 0.1104600504913833, 0.07022482590400614, 0.1430627389345318, 0.09629656284232624, 0.18872524495236576, 0.15294737415388227, 0.14913257182342932, 0.17651050351560116, 0.07214355224277824, 0.21456563961692154, 0.1216408095206134, 0.09764663336682133, 0.185116047214251, 0.08365401779883541, 0.0971319836389739, 0.16197107353946194, 0.15660868550185114, 0.18859158415580168, 0.12392437565722503, 0.18387194053502753, 0.048982563021127135, 0.2480876338086091, 0.16593973792623729, 0.1379247466684319, 0.12867475161328912, 0.12564724922413006, 0.15080454148119316, 0.12727241904940456, 0.14173377508996055, 0.1330748709733598, 0.12662045715842396, 0.07794852746883407, 0.1336988538969308, 0.12469513312680647, 0.1106014296237845, 0.15769398742122576, 0.11009649460902438, 0.1294480249634944, 0.12469734472688287, 0.10280969538143836, 0.28642619610764086, 0.11563064530491829, 0.061572875711135566, 0.12541379925096408, 0.17971414723433554, 0.15719781717052683, 0.11706538003636524, 0.5447638244368136, 3.965372694656253, 13.886237069964409, 28.626295924186707, 44.56496246159077, 55.2252334356308, 52.317222878336906, 47.14461363852024, 46.68377436697483, 37.188182696700096, 33.95204454660416, 29.54372439533472, 32.20596984028816, 22.7376664057374, 27.234250120818615, 38.424526154994965, 35.70841670036316, 27.203741557896137, 25.075188875198364, 19.199816845357418, 14.496730361133814, 8.984284456819296, 5.558570679277182, 5.489935912191868, 2.108782581053674, 2.9454929335042834, 1.752106526400894, 0.810305509949103, 0.714259073138237, 0.7237551198340952, 1.1971915466710925, 0.5038881115615368, 0.7844775239937007, 0.9195613441988826, 0.9339378133881837, 0.7217943063005805, 0.8720751141663641, 0.4055317846359685, 0.5980288912542164, 0.5518243205733597, 1.4535008557140827, 1.6520253592170775, 2.1703148167580366, 2.8613319620490074, 5.202146479859948, 8.132855594158173, 12.316509000957012, 16.20061308145523, 18.086334094405174, 27.005422599613667, 29.11535058170557, 21.91612768918276, 32.122511118650436, 32.48417191207409, 34.623472318053246, 35.42674921452999, 27.89131846278906, 32.12551675736904, 37.0672731846571, 41.674727350473404, 42.666276544332504, 31.035885326564312, 16.908927373588085, 4.621690101921558, 0.9452928509563208, 0.10013106919359416, 0.06899904285091907, 0.09934154280927032, 0.15026805776869878, 0.12941868044435978, 0.12246946193045005, 0.19008742732694373, 0.11923688929527998, 0.10805338431964628, 0.15471652062842622, 0.15045067062601447, 0.1177823317993898, 0.13934254558989778, 0.15600025799358264, 0.17071012960514054, 0.16777775570517406, 0.10065211623441428, 0.15037250763271004, 0.18742933636531234, 0.21122012694831938, 0.18211797840194777, 0.09366006837808527, 0.08573573461035267, 0.11927967410883866, 0.1037578632531222, 0.18548305408330634, 0.11956424321397208, 0.2665313542820513, 0.2540203771786764, 0.0751175606274046, 0.10818446986377239, 0.13995717745274305, 0.140189261874184, 0.20380810514325276, 0.08998804041766562, 0.16028855054173619, 0.14925358642358333, 0.09998122957767919, 0.11394962144549936, 0.1717505167471245, 0.11178407905390486, 0.11976278998190537, 0.10660027401172556, 0.16067007381934673, 0.1114196029084269, 0.14118658960796893, 0.23437115654814988, 0.14148589776596054, 0.09489820076851174, 0.16883261472685263, 0.17213011044077575], [0.019562684356060345, 0.021287810341164004, 0.03318122595374007, 0.06381588347721845, 0.05113267987326253, 0.01270844868486165, 0.03258460601500701, 0.03446632887062151, 0.04728067739051767, 0.034928694294649176, 0.04787617668625899, 0.05961982133158017, 0.05566805564740207, 0.03609892388340086, 0.02407745811069617, 0.02777285630145343, 0.053433434150065295, 0.06289773547905497, 0.02337405239813961, 0.01738401893817354, 0.05932150022999849, 0.0134343869285658, 0.013188811190048, 0.04155813992838375, 0.06422244681743905, 0.019486232013150584, 0.07190748990979046, 0.04574871389195323, 0.06341850050375797, 0.014863280957797542, 0.047718084388179705, 0.04272652899089735, 0.024243667648988776, 0.05254325027635787, 0.04203690310532693, 0.013254485693323659, 0.06790376646677032, 0.03642891242634505, 0.07130364145268686, 0.020403665694175288, 0.042362705935374834, 0.004945613673044136, 0.030379347590496764, 0.024741437227930874, 0.027283649251330644, 0.07962866075104102, 0.02121616154909134, 0.08660947991302237, 0.021296346894814633, 0.04450419532076921, 0.04178298469923902, 0.013239583367976593, 0.04459599898837041, 0.04668060275434982, 0.046930710232118145, 0.007663382120881579, 0.025394332369614858, 0.0348267714434769, 0.002683385441741848, 0.0463974288868485, 0.07698187269852497, 0.03606265141570475, 0.6055657868273556, 3.082505981437862, 9.004020597785711, 19.364080131053925, 32.30626925826073, 42.45569184422493, 42.10680976510048, 43.22987750172615, 40.012377351522446, 31.61830097436905, 34.6366386115551, 29.759482517838478, 12.189306076616049, 37.59638339281082, 44.4475981593132, 30.416474863886833, 16.980359740555286, 22.68990106880665, 22.86073610186577, 21.352828815579414, 16.868678033351898, 14.638048578053713, 16.074159666895866, 12.019866518676281, 12.084466852247715, 9.588597379624844, 8.662721011787653, 6.955984169617295, 4.787393035367131, 6.219680579379201, 4.4049943797290325, 3.4447324695065618, 3.2953859958797693, 3.4974612900987267, 3.649349589832127, 4.357293164357543, 3.447532206773758, 5.7907861936837435, 7.212417684495449, 8.726990763098001, 12.355573754757643, 14.3120726197958, 16.847423873841763, 22.036187946796417, 16.910348497331142, 13.316294252872467, 16.769605949521065, 16.236745342612267, 23.04588496685028, 22.403288148343563, 20.00512283295393, 25.68669956177473, 25.487354658544064, 30.858018770813942, 34.95652064681053, 36.623950973153114, 29.463406205177307, 25.75277041643858, 15.066558234393597, 7.4419419933110476, 0.15912521921563894, 0.04341293024481274, 0.0758193428919185, 0.08175416427548043, 0.027161155921930913, 0.01764294498570962, 0.03276171213656198, 0.04981113379471935, 0.031829229556024075, 0.046058003936195746, 0.035293508117320016, 0.01714316789730219, 0.027478889751364477, 0.03040840081666829, 0.02582763714599423, 0.03202089290425647, 0.0660598931426648, 0.055302878172369674, 0.043992721984977834, 0.03201656989404, 0.01232584558238159, 0.06389735644916072, 0.008035898044909118, 0.006117305756561109, 0.045073233341099694, 0.06351143223582767, 0.02145622220268706, 0.025558256093063392, 0.023128627872210927, 0.11685745252179913, 0.050021866627503186, 0.07037961564492434, 0.03754128789296374, 0.07367069178144448, 0.04466592785320245, 0.04198844457278028, 0.020998678883188404, 0.10816163397976197, 0.030581245155190118, 0.026835050666704774, 0.025586086630937643, 0.013548776933021145, 0.029620260393130593, 0.06417564698494971, 0.06420539968530647, 0.03286843297246378, 0.029614948471134994, 0.018928326207969803, 0.040348654438275844, 0.08383129461435601, 0.03641243674792349, 0.02750077754171798, 0.0423136907920707, 0.0414683845883701, 0.08789562925812788, 0.03097710487054428, 0.042581342640914954, 0.05264627150609158, 0.07519795006373897, 0.1182493801752571, 0.022049867984605953, 0.05533325798751321, 0.07362447824561968, 0.02950912563392194, 0.022233389972825535, 0.046355649683391675, 0.03745499467186164, 0.09384402452269569, 0.0670948922925163, 0.01753867880324833, 0.027146596839884296, 0.038984475686447695, 0.008198200175684178, 0.03479612074443139, 0.02031057811109349, 0.029892684251535684, 0.01117466692448943, 0.05488387272635009, 0.026229118629998993, 0.07765295231365599, 0.054245733335847035, 0.04287678049877286, 0.09129904428846203, 0.06616208687773906, 0.03159656254865695, 0.044821697229053825, 0.02691635294468142, 0.07680540482397191, 0.03780483937589452, 0.06133755923656281, 0.07343135657720268, 0.03273062357038725, 0.01112062929678359, 0.037479912280105054, 0.037050227329018526, 0.04958317200362217, 0.023155534436227754, 0.05206751877267379, 0.09293890863773413, 0.13240986212622374, 0.022755514983145986, 0.05170274947886355, 0.04024190391646698, 0.020534519317152444, 0.05583502403169405, 0.07938200797070749, 0.046086231523077004, 0.10149289533728734, 0.08427849796134979, 0.07329748055781238, 0.029530017091019545, 0.02903740358306095, 0.05487432128575165, 0.027303340284561273, 0.059850443722098134, 0.06098764773923904, 1.5077887801453471, 5.2313118148595095, 14.257040172815323, 26.74271609634161, 39.87198628485203, 47.38886073231697, 48.183097913861275, 42.38239377737045, 36.36140786111355, 24.196233339607716, 22.80163787305355, 19.20749433338642, 11.424224730581045, 37.18896545469761, 41.00342117249966, 26.734803020954132, 26.213603988289833, 31.217944957315922, 30.7013151794672, 29.23865206539631, 26.181999184191227, 22.562153823673725, 19.28277399390936, 16.187353692948818, 14.032060895115137, 11.067444775253534, 8.354683890938759, 8.119014836847782, 5.366652002558112, 6.251026522368193, 6.02061971090734, 5.21152057684958, 4.806233374401927, 5.432445947080851, 4.559869794175029, 6.495239892974496, 5.971638914197683, 7.040281221270561, 10.730163473635912, 12.842468228191137, 15.07301028817892, 21.145874820649624, 25.468378476798534, 29.799836352467537, 25.733771435916424, 17.87907611578703, 18.65861378610134, 16.000722907483578, 20.35349953919649, 16.6356498375535, 17.1058252081275, 23.890030570328236, 25.91371838003397, 32.173762768507004, 36.9235534965992, 39.80172425508499, 36.3081993162632, 30.74946239590645, 20.38498654961586, 9.937328416854143, 1.0789491352625191, 0.0740194418176543, 0.037234135234029964, 0.07445423645549454, 0.1177212010952644, 0.05568418622715399, 0.015354656006820733, 0.05672397594025824, 0.06652539042988792, 0.01754119282850297, 0.04479015595279634, 0.07753063895506784, 0.05970539466943592, 0.05646424280712381, 0.04781537252711132, 0.048906615338637494, 0.023699213270447217, 0.05907490682147909, 0.0381927488342626, 0.0504267898213584, 0.03471360876574181, 0.053500750655075535, 0.028999988207942806, 0.06357325313729234, 0.01413775924447691, 0.005649871463901945, 0.045123588060960174, 0.03598928640712984, 0.03218440659111366, 0.02422811037831707, 0.037988598851370625, 0.06330381642328575, 0.01582772227266105, 0.034891601753770374, 0.05035449350543786, 0.07471422562957741, 0.006282942449615803, 0.06066324014682323, 0.06289042532444, 0.07945149525767192, 0.009173688358714571, 0.03908388636773452, 0.027567453944357112, 0.013956190032331506, 0.04231527156662196, 0.01639077116124099, 0.04218280562781729, 0.04014072321297135, 0.08662712076329626, 0.07230705479742028, 0.04577881169097964, 0.015996341935533565, 0.01902292962768115, 0.03642404393758625, 0.18392638448858634, 0.10986336375935934, 0.23959848855156451, 0.12716709345113486, 0.08823312833555974, 0.2489516866626218, 0.09657582559157163, 0.12848885846324265, 0.17248741001822054, 0.15682754485169426, 0.07208100403659046, 0.14552919252309948, 0.07475230522686616, 0.10748794942628592, 0.1216076577838976, 0.06805900149629451, 0.14227934269001707, 0.1497865078272298, 0.13891681999666616, 0.09711086211609654, 0.1161758195667062, 0.1375014553195797, 0.0769557045714464, 0.12447530156350695, 0.11957352005993016, 0.1013879111269489, 0.24445879884297028, 0.1516820420511067, 0.18506139545934275, 0.10536574103753082, 0.1125599499209784, 0.1460755616426468, 0.08440337172942236, 0.176494205952622, 0.12630554905626923, 0.06861486268462613, 0.1916018093470484, 0.17943601997103542, 0.13184293551603332, 0.10058518935693428, 0.11299041041638702, 0.1253406234900467, 0.07781178675941192, 0.10621771172736771, 0.18394631857518107, 0.29274902713950723, 0.1363341906107962, 0.1871532722725533, 0.16509748937096447, 0.13223072252003476, 0.15350453410064802, 0.17552871635416523, 0.1635940169217065, 0.2885931188939139, 0.13532237615436316, 0.2219596123904921, 0.14122437976766378, 0.19515644438797608, 0.19944636966101825, 0.16040034766774625, 0.18254973023431376, 0.12528502178611234, 1.21020169230178, 5.068712364882231, 14.650978334248066, 29.57233875989914, 48.23389358818531, 57.51478157937527, 58.234314769506454, 57.81380273401737, 53.152950033545494, 43.1217885017395, 43.65791313350201, 40.352253913879395, 15.555496048182249, 47.516138702631, 52.55542829632759, 37.465237230062485, 24.70037318766117, 31.898494139313698, 31.726673059165478, 31.21860232204199, 25.731483958661556, 20.79334493726492, 21.62129580974579, 16.133050806820393, 16.45634885877371, 13.679432217031717, 11.188749466091394, 10.147001165896654, 6.492946241050959, 8.37970269843936, 5.895361332222819, 4.947656085714698, 4.491140507161617, 4.722571838647127, 5.2863499615341425, 5.787447597831488, 5.2341407630592585, 8.79061359912157, 9.664244670420885, 12.551174908876419, 17.251653783023357, 20.220305286347866, 24.782503880560398, 31.53558511286974, 25.779904760420322, 20.542567893862724, 25.41104145348072, 23.81205305457115, 34.27214317023754, 29.624386467039585, 27.314410619437695, 37.83276490867138, 36.19789883494377, 42.98514023423195, 46.38256832957268, 51.3026013225317, 41.98785334825516, 36.22951693832874, 19.79154199361801, 9.700237289071083, 1.0700037027709186, 0.2121089823776856, 0.19416518742218614, 0.20320859825005755, 0.1801718890783377, 0.13786892232019454, 0.19459514325717464, 0.14279559545684606, 0.14128511713352054, 0.1256807052413933, 0.17818547144997865, 0.1359824719838798, 0.11999936439679004, 0.1972639953601174, 0.11189871860551648, 0.170921478420496, 0.14723393542226404, 0.12253180233528838, 0.11616589705226943, 0.11703669602866285, 0.19113189628114924, 0.20134960737777874, 0.14922254980774596, 0.13936889183241874, 0.10156794131034985, 0.1582952606258914, 0.10905013317824341, 0.16354545077774674, 0.1169936811493244, 0.15350018511526287, 0.11029283719835803, 0.14733066695043817, 0.14162463485263288, 0.15953161928337067, 0.19051494891755283, 0.21096937009133399, 0.1981458449154161, 0.15510003286181018, 0.12609987024916336, 0.17049781599780545, 0.1235474536952097, 0.17542493442306295, 0.1592921430710703, 0.18648061930434778, 0.20452542055863887, 0.0964307579852175, 0.08565460302634165, 0.1568010204937309, 0.22876976727275178, 0.14781238016439602, 0.1206454262137413, 0.09489844567724504, 0.16039648849982768, 0.11689208855386823], [0.015559428466076497, 0.01756675796059426, 0.041525563356117345, 0.05468558942084201, 0.04186215330264531, 0.02226445998530835, 0.040844683680916205, 0.004148133320995839, 0.00471408400699147, 0.06792119951569475, 0.03395873325644061, 0.0838131045748014, 0.024218855796789285, 0.08467510910122655, 0.02158332983526634, 0.07484192698029801, 0.06195775720698293, 0.016138053179020062, 0.020874755064141937, 0.0233706904691644, 0.05069598904810846, 0.02586107460956555, 0.01621906787477201, 0.031607817218173295, 0.0792603031732142, 0.08836336783133447, 0.03111290676315548, 0.011171221503900597, 0.06339422485325485, 0.04394533214508556, 0.012330492354521994, 0.029783171085000504, 0.0051079533750453265, 0.022858601150801405, 0.025716925410961267, 0.02629692680784501, 0.08644221466965973, 0.05107337114168331, 0.06061187610612251, 0.07342935277847573, 0.01740401054121321, 0.06255688189412467, 0.01930706643179292, 0.01757961010298459, 0.022552198061021045, 0.10293330749846064, 0.06595129467314109, 0.01163354796517524, 0.10656676604412496, 0.07022798003163189, 0.01868398150691064, 0.025544144154991955, 0.033944016468012705, 0.021306525450199842, 0.028330767672741786, 0.055337696030619554, 0.07807282236171886, 0.028008055887767114, 0.053494060193770565, 0.04219822003506124, 0.06160459139209706, 0.05050558364018798, 0.11370394087862223, 0.015464984608115628, 0.2265041388454847, 1.0233793733641505, 4.276230214163661, 13.908629268407822, 24.677747301757336, 30.252323672175407, 42.45036832988262, 46.79554156959057, 45.355532839894295, 42.445166409015656, 34.01778481900692, 28.89768496155739, 77.35031381249428, 52.701880037784576, 26.999734304845333, 22.63396617025137, 27.655774801969528, 17.71966326981783, 14.401797205209732, 18.542442619800568, 23.234071768820286, 23.574444204568863, 22.0141339302063, 23.275191262364388, 20.29160276055336, 16.854039318859577, 18.760378025472164, 15.414763949811459, 14.208209943026304, 13.657252807170153, 16.138161532580853, 14.8642941378057, 15.821272786706686, 14.444864094257355, 20.459559448063374, 22.29687485843897, 13.120193425565958, 18.59251633286476, 16.453702300786972, 13.747142683714628, 17.075825817883015, 16.126235872507095, 24.231020472943783, 27.114229761064053, 29.645929411053658, 27.886557318270206, 31.06145605444908, 35.28044566512108, 35.78714467585087, 36.262062191963196, 33.86062525212765, 25.61185497790575, 18.005350939929485, 11.705750674009323, 9.83389986678958, 5.223897937685251, 2.1424741856753826, 0.21025650756200776, 0.026411354847368784, 0.029371414566412568, 0.05532252282137051, 0.06148286804091185, 0.03755144789465703, 0.036134187030256726, 0.09335129783721641, 0.038583741916227154, 0.011657290197035763, 0.02088836790790083, 0.06953350792173296, 0.024719139400986023, 0.05310855158313643, 0.041561264370102435, 0.03610004823713098, 0.04514753716648556, 0.06305589457042515, 0.004630246830856777, 0.014121124004304875, 0.02177046237193281, 0.015287951773643726, 0.013990018978802254, 0.032476875858264975, 0.04310930649808142, 0.0844752487319056, 0.016861303920450155, 0.006098880548961461, 0.050276567999389954, 0.05098664005345199, 0.03960360867495183, 0.12941065040649846, 0.022790364382672124, 0.04287672483769711, 0.0742075168818701, 0.05129712495545391, 0.05584576661931351, 0.054277786694001406, 0.03271905719884671, 0.037698099986300804, 0.10684795837732963, 0.06066147754609119, 0.029708152942475863, 0.004757784909088514, 0.025148482964141294, 0.06064769586373586, 0.0961056379310321, 0.04154694834141992, 0.04386437125504017, 0.014607389366574353, 0.0521030824893387, 0.015046135940792738, 0.015862567961448804, 0.07173080681241117, 0.03963815193856135, 0.02261687994177919, 0.0393392927799141, 0.015341184171120403, 0.014306289849628229, 0.03460413085122127, 0.0036223750339559047, 0.0623117430950515, 0.030937129085941706, 0.046191742658265866, 0.04404790808621328, 0.06992579976213165, 0.039863416022853926, 0.018745143752312288, 0.047247418042388745, 0.02517168064514408, 0.03712684665515553, 0.052512540205498226, 0.05864383034349885, 0.03479570514173247, 0.04439566735527478, 0.023600969616381917, 0.017515202816866804, 0.046008105637156405, 0.008908237905416172, 0.008739597833482549, 0.03230239322874695, 0.04823826682695653, 0.008438560471404344, 0.04685619489464443, 0.07902808516519144, 0.033367783325957134, 0.01972267284145346, 0.052848618070129305, 0.01837809420976555, 0.012944617701577954, 0.05193077806325164, 0.10467543979757465, 0.04485679710342083, 0.04544657072983682, 0.041335755377076566, 0.044742562022292987, 0.03284277321654372, 0.05094543972518295, 0.026235066943627317, 0.02094722764013568, 0.0468796170753194, 0.036608478767448105, 0.017168156009574886, 0.09060759271960706, 0.020452478602237534, 0.0567534874426201, 0.033155425189761445, 0.010893650851357961, 0.024968129946500994, 0.03495138917060103, 0.06195484798809048, 0.046603549271821976, 0.03513405397825409, 0.04878453575656749, 0.08465156817692332, 0.018740032210189383, 0.02527528446080396, 0.03646143704827409, 0.015210379715426825, 0.5406244215555489, 2.3329142667353153, 8.478713985532522, 21.246609315276146, 33.25004741549492, 42.55580507218838, 48.91822546720505, 50.52359752357006, 45.45313820242882, 38.379506170749664, 20.608425959944725, 29.528183229267597, 74.876988530159, 45.49999728798866, 14.729564767330885, 18.80244366824627, 27.032543644309044, 23.15214056521654, 21.19091760367155, 25.141159035265446, 27.69549787044525, 27.681858502328396, 31.202660277485847, 33.783531188964844, 32.55310021340847, 27.94977642595768, 28.3342207968235, 25.802975222468376, 21.84084612876177, 21.476455181837082, 24.70055367797613, 24.446415714919567, 25.83120010793209, 22.549008429050446, 21.550347916781902, 27.51698724925518, 22.996329925954342, 29.71178747713566, 26.705725081264973, 22.05723311752081, 20.502145662903786, 20.323830731213093, 18.603330552577972, 16.904791295528412, 17.939861454069614, 19.954471550881863, 27.2597049549222, 31.87523178756237, 33.10625173151493, 37.96642653644085, 37.670338824391365, 33.139860928058624, 27.98707142472267, 19.52765565365553, 14.563080500811338, 8.874801881611347, 3.4128927905112505, 0.4532644076971337, 0.06973652984015644, 0.00747507467167452, 0.0572158899740316, 0.04827388620469719, 0.04262223497789819, 0.06887059935252182, 0.02501196118828375, 0.07075365065247752, 0.07512108582886867, 0.04912914089800324, 0.07693789302720688, 0.03666742755740415, 0.05721408284443896, 0.02884916710172547, 0.05824472558742855, 0.05344720098946709, 0.02041444353380939, 0.05031990571296774, 0.027575905151024926, 0.016545490398129914, 0.05901893775444478, 0.042740822755149566, 0.01887042570160702, 0.04769497019879054, 0.09216678561642766, 0.014505668750643963, 0.05002799676731229, 0.12329072997090407, 0.11558122569113038, 0.010716232100094203, 0.07208509327028878, 0.013362755762500456, 0.008397626388614299, 0.060961353447055444, 0.0057785422450251644, 0.055760876057320274, 0.014144049873721087, 0.026383271979284473, 0.01944769228430232, 0.017403771198587492, 0.07320569173316471, 0.022904449178895447, 0.01087035483578802, 0.028540899365907535, 0.030830311770841945, 0.039754832396283746, 0.0033188758288815734, 0.0395174119330477, 0.042699473997345194, 0.01619259361177683, 0.023217308953462634, 0.012483644732128596, 0.03429280361160636, 0.07759395157336257, 0.08304022456286475, 0.1256512271356769, 0.12364422975224443, 0.11090209591202438, 0.12533099041320384, 0.16366777155781165, 0.16781363112386316, 0.10235112233203836, 0.12342924441327341, 0.18388764437986538, 0.1600720957503654, 0.1850690841092728, 0.12769943597959355, 0.16006268531782553, 0.11665628597256728, 0.13352747715543956, 0.20332346786744893, 0.1307037685182877, 0.09951460422598757, 0.10393821256002411, 0.14126798836514354, 0.0980062410235405, 0.1257712027290836, 0.18945634947158396, 0.14898308843839914, 0.27946093236096203, 0.14263073477195576, 0.1007194141857326, 0.15899859397904947, 0.15855799574637786, 0.18493487412342802, 0.1257262285798788, 0.08449225133517757, 0.10846113509614952, 0.13767455384368077, 0.1203356686164625, 0.22380533366231248, 0.13687269296497107, 0.1288046719855629, 0.14847698825178668, 0.1462842832552269, 0.11362720280885696, 0.12749207991873845, 0.10869088175240904, 0.211221314384602, 0.2132445276947692, 0.2028062503086403, 0.14708259666804224, 0.2714309241855517, 0.14365964831085876, 0.1926067515159957, 0.13348649576073512, 0.1286843401612714, 0.07275340467458591, 0.1525994107942097, 0.12155561096733436, 0.20664732466684654, 0.09164878880255856, 0.2022294234484434, 0.10904895316343755, 0.16914982348680496, 0.15312033909140155, 0.21811546554090455, 0.0812361748830881, 0.48975292942486703, 2.1250221971422434, 8.292003404349089, 23.656432405114174, 37.29615770280361, 49.399959817528725, 59.574453458189964, 62.40451119840145, 60.692847445607185, 54.93791565299034, 42.40547753870487, 38.72300013899803, 87.2070761024952, 60.312031880021095, 36.52307778596878, 32.36442133784294, 39.905443489551544, 26.209661699831486, 23.086056411266327, 27.91465301066637, 31.68108880519867, 34.519103318452835, 31.671817302703857, 34.21244837343693, 30.904419980943203, 25.33040788024664, 28.846589103341103, 23.65418292582035, 22.086309157311916, 21.70239105820656, 23.678891099989414, 21.99865736067295, 24.143579564988613, 21.312870159745216, 28.072061464190483, 33.42381589114666, 20.612115561962128, 29.661145694553852, 26.050771325826645, 22.503690160810947, 25.930771864950657, 25.5169265717268, 33.71555283665657, 36.45382650196552, 37.61988513171673, 35.94965435564518, 42.35171042382717, 45.11527173221111, 48.51382836699486, 49.558943286538124, 49.053376615047455, 39.69859018921852, 31.436136849224567, 21.805481426417828, 15.65785400569439, 8.322337176650763, 3.198181511834264, 0.37091240636073053, 0.11478264510515146, 0.1604210090590641, 0.13636895280797035, 0.09515122859738767, 0.13033961149631068, 0.18695324863074347, 0.1793560164514929, 0.18682643043575808, 0.12909638055134565, 0.17853908997494727, 0.13619441451737657, 0.15891522110905498, 0.09125235577812418, 0.18706808856222779, 0.11855326738441363, 0.1357611783896573, 0.1798447355395183, 0.1381394054624252, 0.09179174128803425, 0.13819101441185921, 0.13968659040983766, 0.1561119660618715, 0.18823985068593174, 0.08614714417490177, 0.17894492601044476, 0.07689011355978437, 0.1518625026801601, 0.19082785322098061, 0.18227356224087998, 0.07983977207913995, 0.23476324800867587, 0.10330800301744603, 0.1309447141829878, 0.19675802876008675, 0.14650734316091985, 0.17932873510289937, 0.2908665844006464, 0.1734667777782306, 0.12050521225319244, 0.2821818832308054, 0.10493672773009166, 0.10783849545987323, 0.10937474857200868, 0.10671495067072101, 0.2502855338389054, 0.2399638478527777, 0.11924186168471351, 0.13755186198977754, 0.2803608012618497, 0.16666126874042675, 0.1733588843489997, 0.11071707107475959, 0.1528579750447534, 0.1750967270345427], [0.02704607479245169, 0.043014059265260585, 0.021120415221957956, 0.04267987016646657, 0.0166690783953527, 0.024491520853189286, 0.08413625051616691, 0.019030957810173277, 0.08800568233709782, 0.04594059988448862, 0.026696139175328426, 0.049129304170492105, 0.03333276879857294, 0.07622943143360317, 0.03883650257193949, 0.025514962908346206, 0.022635194291069638, 0.05719264590879902, 0.0592443688219646, 0.0170053288093186, 0.004283652269805316, 0.05503921907802578, 0.02552994315919932, 0.050714149401756003, 0.05560063153097872, 0.018761513674689922, 0.043880835801246576, 0.02083576448058011, 0.021825670737598557, 0.034207957578473724, 0.054484760548803024, 0.04605868671205826, 0.035714149998966604, 0.02846155079168966, 0.07458581181708723, 0.049058417935157195, 0.035915539192501456, 0.023758735369483475, 0.018516990858188365, 0.047953107714420184, 0.03896780704963021, 0.08679282007506117, 0.01582431581482524, 0.04186003818176687, 0.06268354423809797, 0.03704359623952769, 0.09788755676709116, 0.026172327634412795, 0.057903653068933636, 0.049977797898463905, 0.029423799060168676, 0.051440864117466845, 0.02033236942224903, 0.039645295109949075, 0.02413177033304237, 0.044745864579454064, 0.029539292081608437, 0.018399041327938903, 0.09123780226218514, 0.02772704538074322, 0.003151073688059114, 0.06412554459529929, 0.015413332985190209, 0.03593703549995553, 0.05793280462967232, 0.08041415727348067, 0.04442246259714011, 0.2777995902579278, 3.557327315211296, 7.098376303911209, 16.754676550626755, 32.697416469454765, 38.828854858875275, 43.434124141931534, 56.22180216014385, 33.81267562508583, 53.7873449921608, 71.51581048965454, 46.68746776878834, 30.73793761432171, 38.101079910993576, 30.879554115235806, 28.93552143126726, 30.781316086649895, 34.90501821041107, 30.169638209044933, 32.40646228194237, 23.903612941503525, 15.559692922979593, 19.29683703929186, 14.14891792461276, 15.968578532338142, 18.468948863446712, 20.964236967265606, 19.992032535374165, 18.776485361158848, 20.281943678855896, 15.305369719862938, 54.03732217848301, 44.38185028731823, 15.63359895721078, 25.30253827571869, 18.80114033818245, 29.309470765292645, 26.40986915677786, 26.217681169509888, 40.64010746777058, 33.71996060013771, 37.946150824427605, 37.71224297583103, 37.23578654229641, 36.699654310941696, 29.124785475432873, 24.691168181598186, 18.454313948750496, 9.484068788588047, 3.314275969751179, 1.8465921375900507, 0.7492757379077375, 0.08243932243203744, 0.02080809721519472, 0.04838869645027444, 0.11074662339524366, 0.047375624053529464, 0.030172971164574847, 0.018179675462306477, 0.025124606218014378, 0.06548646531882696, 0.04947695953887887, 0.014749977272003889, 0.005685590103894356, 0.015547469683951931, 0.04654309021134395, 0.03261845537053887, 0.02843880582076963, 0.041337005895911716, 0.04449464759090915, 0.04209073849779088, 0.016906177879718598, 0.016083650043583475, 0.053370225432445295, 0.05007167215808295, 0.012357270898064598, 0.053368596418295056, 0.014566743793693604, 0.03946002536395099, 0.0221668694211985, 0.03581936427508481, 0.045111940053175204, 0.011429597434471361, 0.04278264648746699, 0.053519708817475475, 0.027786769715021364, 0.03441329870838672, 0.020188593152852263, 0.03745686117326841, 0.04255316700437106, 0.04587462295603473, 0.0772336611407809, 0.034772071448969655, 0.05896055299672298, 0.05863771875738166, 0.030071812725509517, 0.056673955186852254, 0.009696949782664888, 0.019363261853868607, 0.006303647905951948, 0.04555985957267694, 0.0299103418001323, 0.04683296196162701, 0.05637862122966908, 0.025588036623958033, 0.03325246841995977, 0.08144333056407049, 0.03132375277346, 0.03285271057393402, 0.021842560163349845, 0.024502549167664256, 0.046723721534362994, 0.10636659397277981, 0.025278690918639768, 0.0291951711915317, 0.020982761670893524, 0.03996126077254303, 0.05236571370915044, 0.014876663735776674, 0.04126174098928459, 0.030257841317506973, 0.002723157599575643, 0.033645120201981626, 0.08394220858463086, 0.012689712239080109, 0.07606953571666963, 0.03136234445264563, 0.06640995678026229, 0.03121628236840479, 0.030050535351620056, 0.07405688316794112, 0.045325288956519216, 0.059263609000481665, 0.03555924151442014, 0.056513376694056205, 0.04973615090420935, 0.05332835346052889, 0.04453902060049586, 0.0038421235694841016, 0.03921012568753213, 0.0732319414964877, 0.015758426088723354, 0.03425370727200061, 0.01347279028777848, 0.052232724556233734, 0.01003210181806935, 0.016221253499679733, 0.04922421743685845, 0.07735503939329647, 0.038063455576775596, 0.03631027640949469, 0.01912661136884708, 0.05700192508811597, 0.026445968615007587, 0.026019265242211986, 0.04472557426197454, 0.0331706392171327, 0.06271327467402443, 0.030372106084541883, 0.009039577635121532, 0.0601732668292243, 0.035413806544966064, 0.02204855809395667, 0.013009408121433808, 0.06457378694904037, 0.05849713743373286, 0.03133152305963449, 0.036787751960218884, 0.018205611668236088, 0.005424182963906787, 0.04412231581227388, 0.03886923870595638, 0.09668310303823091, 0.04186479534837417, 0.029826197096554097, 0.3108498902292922, 1.1951672052964568, 5.886797541752458, 11.718526538461447, 23.77478465437889, 40.775258615612984, 47.59281478822231, 49.17931325733662, 57.765089347958565, 32.93216787278652, 61.49048924446106, 72.92361214756966, 39.88241292536259, 23.32368616014719, 30.499627701938152, 23.86531289666891, 17.432440482079983, 21.117862723767757, 31.582214310765266, 26.28662846982479, 30.217357948422432, 27.20762874931097, 19.555160477757454, 22.116194553673267, 20.89425042271614, 22.302401661872864, 21.46073542535305, 23.81155338138342, 24.55403733998537, 21.119789220392704, 24.78862915188074, 16.809600703418255, 51.53594680130482, 46.635741144418716, 14.002948757261038, 21.780809350311756, 16.094161793589592, 18.8693979755044, 18.597577661275864, 21.700293570756912, 34.65509422123432, 31.93689487874508, 36.14574283361435, 39.43526431918144, 41.22634381055832, 41.34665675461292, 35.970994010567665, 32.250442653894424, 25.0001448020339, 15.551549009978771, 7.032052762806416, 3.8564586639404297, 1.9228444271720946, 0.4018905112752691, 0.03297164716059342, 0.026374251174274832, 0.05167443654499948, 0.08807167410850525, 0.05123458417074289, 0.05145106122654397, 0.03529259156493936, 0.03635932494944427, 0.06942065694602206, 0.010988585454470012, 0.04618557541107293, 0.08540325245121494, 0.046349085387191735, 0.0060090240913268644, 0.03047368383704452, 0.041391238337382674, 0.030198501044651493, 0.020167987422610167, 0.032566846421104856, 0.08695779208210297, 0.014692297554574907, 0.04603335721185431, 0.007142837421270087, 0.006124999972598744, 0.07046984595945105, 0.048892696358961985, 0.02312499134859536, 0.020770034316228703, 0.03601781456382014, 0.0766945056966506, 0.036058113182662055, 0.12059018074069172, 0.06546997479745187, 0.01585916706972057, 0.0672676568501629, 0.051897348021157086, 0.044671007854049094, 0.023669258334848564, 0.04237128887325525, 0.02001351494982373, 0.03146326540445443, 0.04398709279485047, 0.03941281363950111, 0.08168621323420666, 0.05899289208173286, 0.015811241028131917, 0.0193117401067866, 0.03717113802849781, 0.026650467407307588, 0.04331400567025412, 0.050827152517740615, 0.035861477444996126, 0.03356314256961923, 0.02347319219552446, 0.060418093926273286, 0.03772239047975745, 0.1206415967317298, 0.13898294535465539, 0.14308492915006354, 0.21124427643371746, 0.10941259810351767, 0.09297358177718706, 0.21286447386955842, 0.150312319456134, 0.1396021043183282, 0.1640069330460392, 0.1297328612417914, 0.13898257428081706, 0.13893967814510688, 0.1413074557785876, 0.2568695117952302, 0.07853931412682869, 0.251290847081691, 0.17478325869888067, 0.11195411992957816, 0.11390915955416858, 0.17788996308809146, 0.20007309853099287, 0.12077304592821747, 0.2657845459179953, 0.13314864045241848, 0.14738702564500272, 0.2134000966907479, 0.1578678874648176, 0.1510796110960655, 0.10680185616365634, 0.16335424385033548, 0.16332047613104805, 0.10421288883662783, 0.1773693464929238, 0.11515130696352571, 0.12225279191625305, 0.16709869058104232, 0.13689031155081466, 0.08803270393400453, 0.2180798424524255, 0.15054691233672202, 0.21873649471672252, 0.14188882458256558, 0.14721042418386787, 0.23301912675378844, 0.18936638633022085, 0.22776676953071728, 0.18752807169221342, 0.16508153319591656, 0.17092135967686772, 0.14352821395732462, 0.1724865342839621, 0.09237524005584419, 0.15547192306257784, 0.14905497286235914, 0.14387120492756367, 0.1296629657736048, 0.06739650110830553, 0.17432793625630438, 0.08511662017554045, 0.06983158411458135, 0.3105161612620577, 0.08602572881500237, 0.25881432462483644, 0.19895517179975286, 0.1513376261573285, 0.3022067790152505, 0.9811056323815137, 5.5426704324781895, 12.796549592167139, 26.306704692542553, 45.45914947986603, 56.77430771291256, 60.527860298752785, 72.01642602682114, 43.73064883053303, 66.97605729103088, 81.7381663620472, 56.84488892555237, 42.378073409199715, 48.05936515331268, 41.09457828104496, 38.26066754758358, 39.64603900909424, 51.46792285144329, 38.68564814329147, 45.01345619559288, 34.45511855185032, 24.916583485901356, 28.85294046252966, 22.98168171197176, 28.10412984341383, 28.49808130413294, 32.02234089374542, 29.977364726364613, 26.539696790277958, 31.969968304038048, 23.652539514005184, 65.98028272390366, 56.52520067989826, 21.216370537877083, 35.48715077340603, 26.805310137569904, 38.274434208869934, 33.739867731928825, 36.47775001823902, 50.351333767175674, 45.100593119859695, 53.63294407725334, 51.244285851716995, 52.931007742881775, 49.9835629016161, 40.78842110931873, 37.26498417556286, 25.27161743491888, 15.074182525277138, 6.646499326452613, 3.28372442163527, 1.2492145551368594, 0.439008908579126, 0.13689589250134304, 0.12979193619685248, 0.17919393139891326, 0.1653960850671865, 0.1888604642590508, 0.121686933998717, 0.13830793235683814, 0.23456690541934222, 0.22827126667834818, 0.15574803168419749, 0.135652661556378, 0.22730959171894938, 0.0922456759144552, 0.10501474971533753, 0.0744952326931525, 0.15228779782773927, 0.07305782623006962, 0.14672345656435937, 0.0816341293102596, 0.11688865983160213, 0.2852033742237836, 0.2196408313466236, 0.09225617730407976, 0.11743091745302081, 0.12475728057324886, 0.14918413624400273, 0.12497891555540264, 0.09899709722958505, 0.09046147868502885, 0.11262516243732534, 0.11205678863916546, 0.16645227995468304, 0.16503176477272063, 0.10515327157918364, 0.11819722945801914, 0.11400791714549996, 0.19470388273475692, 0.14268198749050498, 0.17888203641632572, 0.14549425221048295, 0.1770370127633214, 0.15378392301499844, 0.06884478745632805, 0.15458677837159485, 0.08438877368462272, 0.10173323244089261, 0.11639096817816608, 0.13267558068037033, 0.11050878732930869, 0.1274449090124108, 0.13833062723279, 0.20395573315909132, 0.1852624729508534, 0.18490248679881915, 0.13578114216215909, 0.12070044162101112], [0.0024831059909047326, 0.019726752798305824, 0.025835912092588842, 0.012514262962213252, 0.03662566690763924, 0.05884806938411202, 0.07134031839086674, 0.02985583290865179, 0.04847129006520845, 0.037582699733320624, 0.03865895116177853, 0.14109356881817803, 0.06143960825284012, 0.04155222872213926, 0.05977811772027053, 0.029895049847254995, 0.04408684486406855, 0.06704927247483283, 0.011511766169860493, 0.004463079458218999, 0.07199225801741704, 0.045435958018060774, 0.022469684226962272, 0.013274780649226159, 0.05701083086023573, 0.021660392594640143, 0.03383800067240372, 0.036605999994208105, 0.035429310009931214, 0.08956926132668741, 0.03810435904597398, 0.024901021242840216, 0.04436972187249921, 0.015855430356168654, 0.03736175123776775, 0.08874866864061914, 0.04044550471007824, 0.03973895414674189, 0.03315734364150558, 0.028204244481457863, 0.007409109803120373, 0.04635018376575317, 0.026473288926354144, 0.02531028600060381, 0.04010404256405309, 0.03194446653651539, 0.053029568516649306, 0.055888488350319676, 0.03707228766870685, 0.04094409065146465, 0.010306129643140594, 0.02895367448218167, 0.018845461709133815, 0.06515119268442504, 0.051500540212146007, 0.04281912675651256, 0.015691339649492875, 0.0526708106190199, 0.056072351726470515, 0.03106775078776991, 0.030216772720450535, 0.045733492443105206, 0.052811365967500024, 0.0365039287135005, 0.06403250154107809, 0.10238742819637991, 0.06860536319436505, 0.09757776206242852, 0.04269678000127897, 0.1144006394315511, 0.6644689792301506, 2.574686980806291, 9.764413945376873, 23.276226706802845, 36.94151893258095, 47.31641761958599, 45.39390318095684, 55.51402933895588, 51.847267895936966, 45.23521989583969, 47.55528040230274, 44.13543350994587, 37.99838662147522, 38.763733953237534, 39.089634865522385, 36.14035092294216, 30.721349604427814, 29.66040663421154, 29.135873280465603, 29.38325710594654, 26.676848530769348, 28.018486239016056, 28.430937007069588, 27.1469859033823, 26.129508800804615, 30.748630240559578, 31.333831138908863, 24.8357143253088, 78.62913519144058, 62.331669107079506, 26.757333911955357, 31.477619223296642, 34.58145797252655, 39.17953424155712, 38.12448285520077, 42.977384850382805, 42.68676124513149, 42.91260212659836, 34.387569576501846, 30.85263065993786, 20.697236694395542, 13.108190819621086, 7.557339901104569, 3.3141890494152904, 1.555834945756942, 0.6153063266538084, 0.3104582440573722, 0.03799678474024404, 0.022598780815314967, 0.055821079076849855, 0.051692389097297564, 0.06762019926100038, 0.007099429203663021, 0.024861256970325485, 0.02692005811695708, 0.010435705844429322, 0.0724612433987204, 0.05990980440401472, 0.016680305234331172, 0.011203100457350956, 0.018127140683645848, 0.009777475588634843, 0.021614654033328407, 0.01719998115731869, 0.04382177197840065, 0.02038902497588424, 0.0426026905188337, 0.04817213775822893, 0.0237487701815553, 0.03029395236808341, 0.031460894242627546, 0.004113163786314544, 0.08833101019263268, 0.06629347670241259, 0.022128710043034516, 0.021076314951642416, 0.019166080637660343, 0.022277056086750235, 0.021250092540867627, 0.028193811740493402, 0.032452192026539706, 0.029265389493957628, 0.042006775620393455, 0.040508524180040695, 0.06415329349692911, 0.024566468491684645, 0.015096355218702229, 0.027487676779855974, 0.06815342494519427, 0.0334142677456839, 0.013224549311416922, 0.0343501159659354, 0.04865531671384815, 0.053427775274030864, 0.02818647561070975, 0.03500690923829097, 0.0030195187355275266, 0.01727284336084267, 0.0612411542533664, 0.062462636560667306, 0.008918177118175663, 0.03925521858036518, 0.061849314588471316, 0.024282468984893057, 0.05952903440629598, 0.03278324555139989, 0.044594455321202986, 0.0121712738473434, 0.07797404250595719, 0.03388926081242971, 0.01942328119184822, 0.018160127292503603, 0.009604541264707223, 0.04418498276208993, 0.03058720460103359, 0.031904294082778506, 0.02016561440541409, 0.03627691687142942, 0.06574862898560241, 0.021038504382886458, 0.03434572245168965, 0.02142769404599676, 0.04181640731985681, 0.02891905514843529, 0.005755471192969708, 0.010986710603901884, 0.005730148650400224, 0.049948097148444504, 0.03436839877394959, 0.04954182695655618, 0.027498053859744687, 0.006195607438712614, 0.05864013444806915, 0.04484775032324251, 0.03789006390434224, 0.05222684674663469, 0.00993738151009893, 0.044256377368583344, 0.05659265290887561, 0.019800863665295765, 0.010741135793068679, 0.04686357555328868, 0.04600669184583239, 0.043693079860531725, 0.03927381680114195, 0.03291003406047821, 0.06522447234601714, 0.04668170113291126, 0.039703260554233566, 0.030208150819817092, 0.052722211767104454, 0.04284227434254717, 0.08060094842221588, 0.017013644574035425, 0.02560336568421917, 0.060623093668255024, 0.05870530614629388, 0.03810485257417895, 0.029161518505134154, 0.0623016053577885, 0.07858269265852869, 0.05745676513470244, 0.025052937016880605, 0.03737584462214727, 0.031427453068317845, 0.10779429314425215, 0.043181387591175735, 0.02788270157907391, 0.038333341290126555, 0.020071051803824957, 0.05208444345043972, 0.06014652724843472, 0.02374980362219503, 0.06495852372609079, 0.07144349176087417, 0.11788810268626548, 1.7021088092587888, 4.932117769494653, 14.405499156564474, 29.70072817057371, 45.837886556982994, 52.422481030225754, 51.14855378866196, 63.64185780286789, 57.86017544567585, 48.60560484230518, 48.02523158490658, 44.5091662555933, 36.21526390314102, 37.93842203915119, 40.96035048365593, 37.49636135995388, 32.55468472838402, 27.252130061388016, 22.058830931782722, 19.721659943461418, 18.79863627254963, 21.400428861379623, 25.856799334287643, 22.823346108198166, 18.038055785000324, 19.369781725108624, 23.008202388882637, 19.325628094375134, 79.286347925663, 60.77369190752506, 18.418595865368843, 22.696269527077675, 27.535729743540287, 39.45645958185196, 37.815962210297585, 44.76442515850067, 47.79468655586243, 47.09914147853851, 42.5044584274292, 38.975378796458244, 28.37737128138542, 20.480047948658466, 11.478021293878555, 6.876860540360212, 3.6921666422858834, 1.2232292932458222, 0.47166147676762193, 0.07383717034826986, 0.08656055011670105, 0.04421398960403167, 0.011861258353746962, 0.05769773677457124, 0.013501452031050576, 0.037255056377034634, 0.02626814446557546, 0.04400331985380035, 0.04835474319406785, 0.04844993105507456, 0.009729137655085651, 0.0374492059199838, 0.029414145574264694, 0.0427481625956716, 0.0688529213948641, 0.02534728577302303, 0.03657017652585637, 0.021776748362754006, 0.058601160562830046, 0.02220282647613203, 0.0573962207272416, 0.04325791043811478, 0.026451395569893066, 0.03668019991891924, 0.01362525710646878, 0.02481875788362231, 0.01636940101889195, 0.04027107774163596, 0.03931749961338937, 0.0385375432233559, 0.008839281254040543, 0.007458529416908277, 0.048656181315891445, 0.04689691653766204, 0.020347271747596096, 0.07076614841935225, 0.019503850598994177, 0.02733129327680217, 0.06096286371757742, 0.013934174221503781, 0.048599032234051265, 0.11230761971091852, 0.03419344859139528, 0.06450542030506767, 0.034316841774852946, 0.061795067304046825, 0.02837705542333424, 0.008791789368842728, 0.03130634198896587, 0.011396671125112334, 0.04612154662027024, 0.010425319487694651, 0.03657099659903906, 0.015948772124829702, 0.07115642903954722, 0.02571323322626995, 0.017642573911871295, 0.042989457069779746, 0.11659859883366153, 0.13199424458434805, 0.17724732257192954, 0.12813087610993534, 0.2515481348382309, 0.17241616384126246, 0.13352284615393728, 0.19167259539244696, 0.12078990010195412, 0.14579639537259936, 0.10660065250704065, 0.21827807009685785, 0.15152803156524897, 0.09192920188070275, 0.202750900934916, 0.1211014536966104, 0.12897780019557104, 0.1372977506252937, 0.19054895412409678, 0.08444597100606188, 0.18992788041941822, 0.1180707971798256, 0.1198226070846431, 0.09565624524839222, 0.1465105195529759, 0.08201787160942331, 0.1104636350646615, 0.11856663346407004, 0.12122960775741376, 0.2215804936713539, 0.061075158082530834, 0.200216926750727, 0.15605393011355773, 0.14528198313200846, 0.16970969969406724, 0.13024390413193032, 0.10762532838271, 0.09760515473317355, 0.1530085419653915, 0.10664854329661466, 0.11184607064933516, 0.10059621767140925, 0.11819012710475363, 0.0913619932543952, 0.1311892963713035, 0.1534906410961412, 0.2665273763705045, 0.17790844256523997, 0.10877756460104138, 0.15980187978129834, 0.16482656094012782, 0.17211700411280617, 0.07025470476946793, 0.23190946754766628, 0.23678655037656426, 0.18196614983025938, 0.06859466884634458, 0.10036578081781045, 0.11392998421797529, 0.176873012969736, 0.11625842802459374, 0.15101050230441615, 0.18807485641445965, 0.09326523097115569, 0.1616046455455944, 0.14252966910135, 0.1333584901294671, 0.2990676130866632, 0.2750922949053347, 0.2507730951765552, 1.458913665264845, 4.704477209597826, 17.44945026934147, 33.66134874522686, 53.02781514823437, 62.42388255894184, 61.05661332607269, 71.40934780240059, 65.82312315702438, 63.37888911366463, 64.09480109810829, 59.363427981734276, 50.972691625356674, 51.93679869174957, 56.03735625743866, 49.38018947839737, 43.486990705132484, 43.46541166305542, 38.19746933877468, 42.13717773556709, 35.81677168607712, 39.43444736301899, 40.12651942670345, 38.17868314683437, 34.80809301137924, 40.14818586409092, 40.843947529792786, 33.37302781641483, 89.63063165545464, 68.73474732041359, 35.12615114450455, 43.44465717673302, 45.531273409724236, 55.395414903759956, 51.19430333375931, 55.877080857753754, 58.40381607413292, 57.53846190869808, 49.75927993655205, 44.21691253781319, 31.45903442054987, 20.14083445072174, 10.427337773144245, 5.49848260357976, 2.8754736157134175, 1.1047162651084363, 0.5506210320163518, 0.10758926742710173, 0.15535993297817186, 0.2329746721079573, 0.08373782111448236, 0.1101351308170706, 0.12667398084886372, 0.09052997149410658, 0.13813576893880963, 0.1641918465611525, 0.1319096694351174, 0.18870456871809438, 0.1476023969007656, 0.08131284615956247, 0.11112511128885671, 0.1489361995481886, 0.11755922736483626, 0.1572883443441242, 0.14953434088965878, 0.10916987870587036, 0.1639735809294507, 0.11101395983132534, 0.14350262470543385, 0.12392413074849173, 0.11691027859342285, 0.12162499435362406, 0.17697827919619158, 0.1919901158544235, 0.08420748185017146, 0.10397367979749106, 0.10994925993145443, 0.12160692305769771, 0.06662310159299523, 0.17933473165612668, 0.11968332080869004, 0.21580756438197568, 0.11381047617760487, 0.12663650239119306, 0.11965723431785591, 0.2305742696626112, 0.0961566086334642, 0.13676371600013226, 0.1431212795432657, 0.20431163749890402, 0.13908113149227574, 0.17876684025395662, 0.06939585437066853, 0.22634672932326794, 0.08255082269897684, 0.09221000829711556, 0.09072040658793412, 0.10614041704684496, 0.13552855962188914, 0.1926528092008084, 0.14578088448615745, 0.10075827303808182, 0.2228468202520162, 0.09800036321394145, 0.20040742121636868, 0.11226263071876019], [0.12367990479106084, 0.02764999746432295, 0.09269376241718419, 0.04515524437010754, 0.02731879365455825, 0.012814474685001187, 0.03496993173030205, 0.02448609760904219, 0.059355323610361665, 0.008342226919921814, 0.010194539390795399, 0.026025117076642346, 0.016546750193811022, 0.03327148595417384, 0.016826421124278568, 0.030146474637149367, 0.035248029307695106, 0.08345814276253805, 0.07614188027218916, 0.04148977328441106, 0.016623723895463627, 0.007544959007645957, 0.032010892464313656, 0.03881146250932943, 0.09078761548153125, 0.033775975680327974, 0.0256908463416039, 0.05454480029584374, 0.031091267592273653, 0.07086603407515213, 0.04508329315285664, 0.09196733342832886, 0.04029042553156614, 0.06994283205131069, 0.11224605856114067, 0.08582169015426189, 0.02336708548682509, 0.03242113314627204, 0.05144199589267373, 0.06179782438266557, 0.11932752036955208, 0.020335633016657084, 0.06010677410813514, 0.017599046950635966, 0.015594853030052036, 0.029224484169390053, 0.052601560819312, 0.034209805526188575, 0.10462611666298471, 0.05970549114863388, 0.06049109528248664, 0.04916320547636133, 0.07615243361215107, 0.012653956491703866, 0.038930287773837335, 0.020909172162646428, 0.036029700058861636, 0.0755999937246088, 0.11189590586582199, 0.04837123000470456, 0.0016649749159114435, 0.00407177142733417, 0.01706490100332303, 0.035324607815709896, 0.024862633654265665, 0.04071861876582261, 0.05995215877192095, 0.08041907029110007, 0.04706220766820479, 0.019510676502250135, 0.04189284853055142, 0.08519122085999697, 0.0800335023086518, 1.135716901626438, 3.5850582271814346, 10.926858019083738, 23.197684921324253, 26.984457224607468, 31.019449308514595, 34.06223863363266, 44.47010055184364, 42.919441759586334, 46.15352801978588, 49.355764389038086, 50.23962736129761, 43.941613510251045, 45.83241865038872, 45.05243830382824, 44.773810654878616, 42.39742957055569, 45.767844915390015, 41.76477111876011, 45.22294655442238, 47.948642894625664, 47.48182274401188, 44.78809788823128, 43.55235859751701, 37.28643402457237, 59.621943309903145, 50.04691310226917, 43.12211528420448, 47.25971706211567, 44.85756956040859, 42.78232991695404, 39.85488720238209, 31.029678359627724, 24.102366976439953, 17.969345971941948, 9.214418157935143, 5.451805433258414, 1.7021766118705273, 0.2360615017823875, 0.16398839419707656, 0.13695622910745442, 0.03442491331952624, 0.06030755102983676, 0.05906383397814352, 0.03800687052716967, 0.012835659290431067, 0.011421480194258038, 0.04677924531279132, 0.055532532060169615, 0.030191344885679428, 0.030479038432531524, 0.05908273276872933, 0.0036612227540899767, 0.08423849620157853, 0.019891544834536035, 0.019157419774273876, 0.0487427713960642, 0.042907093520625494, 0.028409385231498163, 0.00929010257095797, 0.006277797974689747, 0.020375983585836366, 0.012470518922782503, 0.007790513409418054, 0.03985355288023129, 0.08556006825529039, 0.011434339758125134, 0.01535156032332452, 0.011847929381474387, 0.05369199840060901, 0.0863655582361389, 0.04393927250930574, 0.024232674586528447, 0.047241050415323116, 0.027223746801610105, 0.027811143700091634, 0.047992619656724855, 0.021165240941627417, 0.017572685865161475, 0.015144926928769564, 0.030582447434426285, 0.049805571397882886, 0.08630107302451506, 0.04020888576633297, 0.11691198553307913, 0.025221035321010277, 0.04188573875580914, 0.023461636956199072, 0.00921363445741008, 0.0535068882163614, 0.032956388604361564, 0.0319565264362609, 0.039860889010014944, 0.037633481188095175, 0.05076041488791816, 0.021531153142859694, 0.016690292686689645, 0.05080076545709744, 0.029387962604232598, 0.047901283542159945, 0.03692019192385487, 0.04220885872200597, 0.017173226733575575, 0.053013248689239845, 0.023992144524527248, 0.03130482800770551, 0.03484546243271325, 0.041188747054548, 0.004175153526375652, 0.01693986025202321, 0.020623070522560738, 0.05189171512029134, 0.033497584954602644, 0.02110439039824996, 0.01297389264436788, 0.06221667768841144, 0.002413310016891046, 0.0035160950801582658, 0.03741674809134565, 0.04704522361862473, 0.07906623155577108, 0.06430299952626228, 0.028022319966112264, 0.021934456599410623, 0.009467716135986848, 0.0027369680401534424, 0.04474903726077173, 0.02875249494536547, 0.020890429223072715, 0.03498648904496804, 0.02313472276000539, 0.03814644252997823, 0.08040247586905025, 0.05620502917736303, 0.09620400218409486, 0.03942918912798632, 0.028628632353502326, 0.012414336488291156, 0.02100545469147619, 0.02040651368588442, 0.026787130191223696, 0.05035470130678732, 0.040607834671391174, 0.03912813692295458, 0.03673368279123679, 0.051117421317030676, 0.03980900175520219, 0.07368327118456364, 0.08944533008616418, 0.051636319840326905, 0.07549411893705837, 0.0648674250987824, 0.042128235509153455, 0.06476224793004803, 0.02945873751741601, 0.04537658991466742, 0.11354515838320367, 0.026047609717352316, 0.031537528411718085, 0.04480541079828981, 0.04091948474524543, 0.03774177166633308, 0.0661962479352951, 0.049508036972838454, 0.014556452988472302, 0.0256316656304989, 0.040676127100596204, 0.04803309639100917, 0.04247370896337088, 0.017355748677800875, 0.021693154703825712, 0.04876506922300905, 0.05810547270812094, 0.07179131411248818, 0.0631049060029909, 0.1471583847887814, 1.8615037249401212, 5.8990556839853525, 15.979090668261051, 30.015716068446636, 35.27591250836849, 40.1998782902956, 42.81943492591381, 50.79617589712143, 48.9329344779253, 53.20693753659725, 55.474572256207466, 56.43576867878437, 49.25152078270912, 47.817648723721504, 47.51313306391239, 44.13063436746597, 40.15096731483936, 44.48956310749054, 42.325567826628685, 46.97891592979431, 47.036080062389374, 44.46980036795139, 41.06920324265957, 40.43312497437, 38.57891567051411, 70.0265184044838, 55.70337317883968, 43.252965062856674, 48.206174075603485, 49.48059909045696, 46.76222875714302, 46.500122621655464, 40.22410959005356, 31.20748981833458, 24.91048101335764, 13.767143860459328, 9.114942345768213, 3.593454589135945, 1.0775164933875203, 0.3374266141327098, 0.09554175412631594, 0.009094583765545394, 0.023854635692259762, 0.032148876271094196, 0.0320947180443909, 0.04301122797187418, 0.05181447239010595, 0.01357273809844628, 0.018273865134688094, 0.06479013783973642, 0.0497443739004666, 0.03408637523534708, 0.026755260514619295, 0.05433374833955895, 0.009637940693210112, 0.0466374060488306, 0.020041289826622233, 0.018698123130889144, 0.012788218427886022, 0.05441685774712823, 0.02724819500144804, 0.013687907357962104, 0.04080646678630728, 0.02423759131488623, 0.03702104979311116, 0.09748106022016145, 0.03790481780015398, 0.09332025379990228, 0.0160514426897862, 0.02613371554616606, 0.0610777110705385, 0.01618036301806569, 0.054610766092082486, 0.013106728729326278, 0.027293402927170973, 0.056796539429342374, 0.010619896693242481, 0.052674944381578825, 0.022458704152086284, 0.020302490556787234, 0.03667631848657038, 0.059902579596382566, 0.0686583599599544, 0.06900829001097009, 0.020624718090402894, 0.05745676142396405, 0.04710798333690036, 0.02637677262100624, 0.07428837387124076, 0.0677583648939617, 0.06833938488853164, 0.02430822522001108, 0.03007907092978712, 0.05601891338301357, 0.03301106633443851, 0.037580324860755354, 0.007808888058207231, 0.04943827138049528, 0.039621954565518536, 0.0546332271915162, 0.029068740768707357, 0.027250827770330943, 0.054743666187277995, 0.19725246238522232, 0.1527713070390746, 0.15177314809989184, 0.17016601661453024, 0.11238532257266343, 0.07067018130328506, 0.11679340517730452, 0.16179855389054865, 0.10232922155410051, 0.09397367772180587, 0.12438724574167281, 0.12111589589039795, 0.1690194132970646, 0.0832761607307475, 0.1188544457545504, 0.1328537258086726, 0.11681719101034105, 0.1555406756233424, 0.12031531892716885, 0.11762010573875159, 0.15833273908356205, 0.10291534752468579, 0.17831591132562608, 0.17221907910425216, 0.19628115434898064, 0.24800510698696598, 0.15654224844183773, 0.09225340909324586, 0.1172774116275832, 0.1429812956484966, 0.09505520953098312, 0.22915728710358962, 0.1144413165457081, 0.13880802114726976, 0.21364273445215076, 0.1301160766161047, 0.0666114647174254, 0.17328477348200977, 0.13484539784258232, 0.16610042774118483, 0.14414015924558043, 0.11575452459510416, 0.14391346281627193, 0.19720443058758974, 0.2160867751808837, 0.1280645132646896, 0.11488722113426775, 0.18899767252150923, 0.20956997643224895, 0.14978165418142453, 0.10858262467081659, 0.1640689914347604, 0.14428659982513636, 0.16515133960638195, 0.19613757845945656, 0.16871358908247203, 0.1754679047735408, 0.15368413383839652, 0.18762340798275545, 0.1580591092351824, 0.1374622996081598, 0.12438967998605222, 0.130981984839309, 0.10925865441095084, 0.09676135508925654, 0.11068302133935504, 0.12605471798451617, 0.2027144911698997, 0.13861558225471526, 0.15401571057736874, 0.1283885646262206, 0.18070408317726105, 0.33569263061508536, 1.7023587645962834, 5.88555215857923, 15.58508601039648, 30.41227798908949, 37.061577290296555, 43.596462830901146, 45.8879678696394, 55.341552793979645, 60.13304628431797, 62.67809271812439, 66.5750952064991, 66.87400236725807, 60.34374877810478, 64.17888298630714, 60.521404445171356, 59.953365325927734, 56.28728024661541, 60.53322561085224, 57.60264806449413, 59.640250727534294, 64.1608415544033, 62.3001080006361, 57.47243285179138, 60.2679618448019, 50.125625878572464, 75.62276691198349, 64.42170515656471, 59.85701769590378, 63.25245089828968, 60.64143620431423, 55.4793182015419, 53.31480614840984, 43.58312554657459, 31.335936225950718, 23.69735810905695, 13.974653575569391, 7.569701112806797, 2.685465761460364, 0.8626269805245101, 0.26129134639631957, 0.27245066477917135, 0.14615319028962404, 0.08792651002295315, 0.16355450497940183, 0.11632372217718512, 0.2037310108426027, 0.17280491563724354, 0.0936230129445903, 0.21892614313401282, 0.1614919726853259, 0.1985991487163119, 0.09323924838099629, 0.10225580088444985, 0.19100479607004672, 0.1265343086561188, 0.2012768026906997, 0.15866844216361642, 0.11784111731685698, 0.10456369462190196, 0.15271874814061448, 0.14953055593650788, 0.14312847837572917, 0.19711838598595932, 0.10416683115181513, 0.19151913409586996, 0.16345997020835057, 0.0999955010775011, 0.1342809054767713, 0.04699121753219515, 0.21366584493080154, 0.16238909563980997, 0.07182208355516195, 0.17997961345827207, 0.07325019832933322, 0.16766840766649693, 0.17883675056509674, 0.07539679369074292, 0.13929389038821682, 0.2208230725955218, 0.14319056645035744, 0.23432526213582605, 0.12484859442338347, 0.15363785350928083, 0.13955123751657084, 0.18298379756743088, 0.14763089537154883, 0.10724721898441203, 0.12708045513136312, 0.20926211873302236, 0.19980985875008628, 0.14702190383104607, 0.1207037219137419, 0.17046674969606102, 0.14671443204861134, 0.12215689901495352, 0.09902833422529511, 0.1405688704107888, 0.13251451979158446, 0.17961158242542297, 0.1704426744254306, 0.12469117005821317, 0.10461819052579813, 0.12952114135259762], [0.05801284154586028, 0.04447108069143724, 0.05007166473660618, 0.08677531281136908, 0.03467251604888588, 0.021266557087074034, 0.017285816102230456, 0.021666565407940652, 0.06923274515429512, 0.024011165769479703, 0.00922338349482743, 0.018698605526878964, 0.031090545853658114, 0.0365157919441117, 0.028414318658178672, 0.08404577529290691, 0.053102725723874755, 0.017493802988610696, 0.04152539266215172, 0.017115374466811772, 0.04544514951703604, 0.017954893774003722, 0.05147100644535385, 0.05211771764152218, 0.11819930747151375, 0.023081887411535718, 0.027711864750017412, 0.047860213089734316, 0.08324798138346523, 0.027796452886832412, 0.01902234147564741, 0.05948001555225346, 0.043902146571781486, 0.01694929480436258, 0.041849054396152496, 0.005233284955465933, 0.05076545407064259, 0.05132678859808948, 0.04192719883576501, 0.020236817908880766, 0.12243441029568203, 0.03891996449965518, 0.07524521002778783, 0.05109991776407696, 0.05929997794737574, 0.0400621223525377, 0.07419481131364591, 0.08141377824358642, 0.0304973249512841, 0.07721293295617215, 0.032255096157314256, 0.02297078233823413, 0.003774035926653596, 0.015209021585178562, 0.014231909954105504, 0.018488900568627287, 0.06903183093527332, 0.005957384064458893, 0.05500290950294584, 0.05509283553692512, 0.05949597543803975, 0.0569091195211513, 0.018911882070824504, 0.03608012157201301, 0.014908915618434548, 0.028306516142038163, 0.04467077407753095, 0.05790405753941741, 0.023543378956674132, 0.09294205534388311, 0.06185325168189593, 0.04246332260663621, 0.05111947706609499, 0.062149450241122395, 0.12030241297907196, 0.05909367944695987, 0.37482242623809725, 1.618657330982387, 4.500630022957921, 4.057832658290863, 8.958848621696234, 11.067971996963024, 14.937426913529634, 18.999370001256466, 26.31341513246298, 27.54824247211218, 29.384588934481144, 33.614892438054085, 38.44678916037083, 43.818378522992134, 40.6649087369442, 40.542863085865974, 37.767153829336166, 39.39982362091541, 41.526858285069466, 40.568245723843575, 41.72125965356827, 42.88945756852627, 38.10363717377186, 43.65583844482899, 33.71692456305027, 26.749924309551716, 25.960336178541183, 17.23260160535574, 5.7025140803307295, 3.2026994694024324, 1.4466088567860425, 0.23057943501044065, 0.09753484366228804, 0.08717672564671375, 0.042530746723059565, 0.04840484929445665, 0.02340221319172997, 0.15475395455723628, 0.059082740190206096, 0.14849563100142404, 0.02845187689672457, 0.034183503812528215, 0.026291104659321718, 0.036080629943171516, 0.032289316586684436, 0.05358352238545194, 0.014397462691704277, 0.059411634065327235, 0.027636813210847322, 0.01904678782011615, 0.02883303281123517, 0.057182055461453274, 0.0440956430247752, 0.022982014743320178, 0.03535201532940846, 0.019086049287579954, 0.011478957676445134, 0.06353152959491126, 0.07833080031559803, 0.022961036083870567, 0.08819426948321052, 0.052013319727848284, 0.040222136813099496, 0.027229713668930344, 0.024851798298186623, 0.0032013451482271194, 0.03102017355558928, 0.02679331042600097, 0.07411380589473993, 0.037086581432959065, 0.028699136382783763, 0.02704935508518247, 0.04270847624866292, 0.015146567075134953, 0.0376443647837732, 0.012510415854194434, 0.022277054231381044, 0.08384270884562284, 0.09499378196778707, 0.06365263325278647, 0.03651321298093535, 0.08971219896920957, 0.0398804186261259, 0.05459507337945979, 0.049495335115352646, 0.01646702683501644, 0.05212388117797673, 0.031946548260748386, 0.039991150770219974, 0.04409527937241364, 0.04082558079971932, 0.08386106215766631, 0.003921200795957702, 0.02828595865139505, 0.017923152117873542, 0.040677700453670695, 0.013186250780563569, 0.034559115883894265, 0.10054743630462326, 0.0467762618791312, 0.043518396851141006, 0.034202243041363545, 0.043592771180556156, 0.003289137739557191, 0.060058074377593584, 0.024022381476243027, 0.0504861245281063, 0.01664079143665731, 0.04990066649043001, 0.048659717649570666, 0.08980213242466561, 0.060790492498199455, 0.07830620554159395, 0.013208432646933943, 0.060191044976818375, 0.03858349700749386, 0.02055603046756005, 0.059301822184352204, 0.04407673310197424, 0.01916659457492642, 0.07041234435746446, 0.03897663118550554, 0.03698749358591158, 0.0566808942676289, 0.07942497832118534, 0.032448588899569586, 0.05161805929674301, 0.047016699172672816, 0.03581784287234768, 0.051115502865286544, 0.017405194266757462, 0.0462964411417488, 0.08653930985019542, 0.03647462872322649, 0.05389923200709745, 0.007819792990630958, 0.0827989300887566, 0.023346698690147605, 0.0938857183791697, 0.025310106029792223, 0.026700005764723755, 0.06440939381718636, 0.12603686191141605, 0.05653346292092465, 0.015926659834804013, 0.031071248158696108, 0.05096129942103289, 0.06045360569260083, 0.05281009689497296, 0.051216524007031694, 0.061383294087136164, 0.02305873054865515, 0.04846978721616324, 0.05997369960823562, 0.08180414792150259, 0.05369908962165937, 0.02023265631578397, 0.026416095315653365, 0.04365223947388586, 0.02661308171809651, 0.043291496331221424, 0.03417887281102594, 0.019371518246771302, 0.048857960136956535, 0.05399788940849248, 0.08910749704227783, 0.02938935227575712, 0.06645499030128121, 0.038429623818956316, 0.06985890257055871, 0.027789100058726035, 0.03687221207655966, 0.0875046881265007, 0.05143767659319565, 0.0609308437560685, 0.21765067329397425, 0.9477134398184717, 3.3451516879722476, 7.337547345086932, 8.324979934841394, 15.118494797497988, 18.1775975972414, 23.46651289612055, 28.24341706931591, 35.843636244535446, 36.771497055888176, 39.40078116953373, 43.70804764330387, 48.40300351381302, 52.6656261831522, 50.29864959418774, 47.93605796992779, 48.07349659502506, 50.967314913868904, 50.314965918660164, 49.70493905246258, 52.46186211705208, 52.343015894293785, 48.663506135344505, 51.675327122211456, 43.57324607670307, 37.48153455555439, 34.42428320646286, 23.728487938642502, 10.41228013113141, 5.665476992726326, 2.836045981384814, 0.7767699938267469, 0.20736039499752223, 0.103302919305861, 0.054787066983408295, 0.030845353248878382, 0.05507774025318213, 0.0932846826617606, 0.05636173365928698, 0.07816934608854353, 0.027615680555754807, 0.07753319194307551, 0.02031747266300954, 0.04114653369470034, 0.026836429206014145, 0.014250900585466297, 0.02889595209126128, 0.013029295823798748, 0.035984566347906366, 0.009310204568464542, 0.02744294011790771, 0.06483258868684061, 0.03086925597017398, 0.00622836351794831, 0.03244510822696611, 0.019137207382300403, 0.004539519277386717, 0.07322046047192998, 0.026278981677023694, 0.06706862768623978, 0.07328533160034567, 0.09202167348121293, 0.009257040819647955, 0.02564933616667986, 0.0558138097403571, 0.015976456088537816, 0.0228802032142994, 0.006475309910456417, 0.044542263785842806, 0.03828948407317512, 0.030678375587740447, 0.008544438969693147, 0.03485891757009085, 0.08463898877380416, 0.01958529759576777, 0.024945661425590515, 0.05179460138606373, 0.030179542882251553, 0.06646584792179056, 0.035814666480291635, 0.009619935262890067, 0.08291279780678451, 0.03507979927235283, 0.017800567875383422, 0.061428245971910655, 0.02195740566094173, 0.045579326106235385, 0.024244346714112908, 0.09525308836600743, 0.0582217635383131, 0.06630857940763235, 0.10271697145071812, 0.03202941647032276, 0.00929234663999523, 0.050740350925480016, 0.07164114053011872, 0.017044545747921802, 0.02578744799393462, 0.10926347837084904, 0.04651757517422084, 0.08724392711883411, 0.0928483963070903, 0.18141647073207423, 0.23417199379764497, 0.11750823439797387, 0.1191416717483662, 0.16064567200373858, 0.15979632851667702, 0.1659186015604064, 0.2132815311779268, 0.21074289630632848, 0.15555738878902048, 0.17388028762070462, 0.1671337496372871, 0.14757450699107721, 0.15493399958359078, 0.1226361482986249, 0.16673490463290364, 0.13595076743513346, 0.127680036239326, 0.15632754511898383, 0.14019107271451503, 0.09914115551509894, 0.10518288327148184, 0.2916814625496045, 0.11450153440819122, 0.11298577941488475, 0.10478601237991825, 0.21017650404246524, 0.15100812743185088, 0.08514640998328105, 0.14822580094914883, 0.1191913140064571, 0.18137363396817818, 0.1900912419660017, 0.08195298563805409, 0.24560560996178538, 0.1194974870304577, 0.18722048116615042, 0.11642062439932488, 0.19970831810496747, 0.11798531661042944, 0.22659380512777716, 0.12455482268705964, 0.16180570819415152, 0.15785175317432731, 0.16844021156430244, 0.1742766983807087, 0.18299671093700454, 0.15091635345015675, 0.12328968354268, 0.16514534305315465, 0.09076648653717712, 0.07697009481489658, 0.19669886474730447, 0.1190687260532286, 0.1305506337666884, 0.22577932773856446, 0.1107721978041809, 0.15655519149731845, 0.15414221707032993, 0.08296014682855457, 0.12133552707382478, 0.1100570939888712, 0.08545986347598955, 0.16239034244790673, 0.14020637579960749, 0.19020345469471067, 0.06737383591826074, 0.17136710841441527, 0.2002106630243361, 0.12437183133442886, 0.14425360393943265, 0.2088754894793965, 0.16611151542747393, 0.20530878711724654, 0.8155142585746944, 2.9596056137233973, 5.924910921603441, 7.049407856538892, 13.341959975659847, 17.418411634862423, 22.210059016942978, 27.98638556152582, 36.251247972249985, 38.603336960077286, 42.497447803616524, 50.18288500607014, 52.303372621536255, 58.84093701839447, 54.621305242180824, 54.25382316112518, 52.04825051128864, 57.65678755939007, 59.25898678600788, 58.6782905459404, 61.15597419440746, 63.629926443099976, 57.79869094491005, 58.98608922958374, 49.92237478494644, 40.47750659286976, 35.30269727110863, 23.191907331347466, 9.13619365543127, 4.675029739737511, 2.3148927837610245, 0.634400777053088, 0.29166938038542867, 0.21447086735861376, 0.17058912984794006, 0.11004893778590485, 0.161021510430146, 0.23713181231869385, 0.13211508106905967, 0.2503997355233878, 0.15433823311468586, 0.16990639851428568, 0.13695958361495286, 0.08376642348594032, 0.1088508813700173, 0.0938759368727915, 0.09559578247717582, 0.18464690598193556, 0.09550641305395402, 0.09749982913490385, 0.1489036637940444, 0.22595330199692398, 0.1303418230963871, 0.16534319962374866, 0.11579198820982128, 0.08517995505826548, 0.0683370693877805, 0.13715396693442017, 0.12539149029180408, 0.19074900745181367, 0.14252554276026785, 0.17460910632507876, 0.07104139614966698, 0.0906419541570358, 0.2875044773099944, 0.08864624483976513, 0.1251245546154678, 0.10828630736796185, 0.21656780561897904, 0.06637725033215247, 0.1446133229183033, 0.12244166107848287, 0.1428005678462796, 0.21224426105618477, 0.1481219448032789, 0.08150469133397564, 0.10844924589036964, 0.2806428767507896, 0.19489143829559907, 0.17922478989930823, 0.09991445112973452, 0.16082457412267104, 0.13668645842699334, 0.20627645862987265, 0.12194383583846502, 0.09827530666370876, 0.10795339476317167, 0.11258029961027205, 0.26514006487559527, 0.10718660778366029, 0.1380848279222846, 0.2998105325968936, 0.09839339720201679, 0.06837309323600493, 0.16619904432445765, 0.2849739615339786, 0.0882124446798116, 0.1531070694909431, 0.16107525676488876, 0.11870989023009315], [0.029983849672134966, 0.02515315849450417, 0.02959125911729643, 0.026088338781846687, 0.02767161808151286, 0.020039636692672502, 0.023248317738762125, 0.007684060674364446, 0.060457030704128556, 0.03860026212350931, 0.02484730644937372, 0.03707395379024092, 0.07250323411426507, 0.01468037216909579, 0.02556533432652941, 0.0021910567329541664, 0.05188789677049499, 0.07382916257483885, 0.02783094791084295, 0.05679714056896046, 0.03039146129594883, 0.03832774920738302, 0.05808634014101699, 0.034357062468188815, 0.06831131686340086, 0.07075065979734063, 0.035660225548781455, 0.03588614272302948, 0.12658921274123713, 0.07472246346878819, 0.019756511064770166, 0.011024671457562363, 0.02853352427337086, 0.03091732487519039, 0.037266259096213616, 0.03596093265514355, 0.05622165328531992, 0.01551325389300473, 0.0503950296115363, 0.02297334274771856, 0.04485403260332532, 0.03585215607017744, 0.03285007594968192, 0.051149804930901155, 0.0232284931189497, 0.011315031169942813, 0.019052485658903606, 0.04336222671554424, 0.035212695656809956, 0.03493934411380906, 0.057441339595243335, 0.03432253033679444, 0.0026327688829042017, 0.03668819656013511, 0.005363881609810051, 0.027971681374765467, 0.02126575927832164, 0.006944634824321838, 0.046654189718537964, 0.08512961518135853, 0.06587543233763427, 0.012997106096008793, 0.023408462075167336, 0.01628523776162183, 0.025695249132695608, 0.028798253915738314, 0.028010957685182802, 0.017610496433917433, 0.0461005289980676, 0.035706231283256784, 0.026527513946348336, 0.037098585671628825, 0.012077842093276558, 0.08508769868058152, 0.010907102277997183, 0.07539122016169131, 0.017350690941384528, 0.05499773302290123, 0.048947459436021745, 0.06245993514312431, 0.1257378951413557, 0.38009075447916985, 0.5515129747800529, 0.7501392415724695, 1.3534271693788469, 3.1098763877525926, 3.1046818289905787, 5.520704761147499, 5.335338357836008, 3.346617934294045, 3.4606861509382725, 5.93596737831831, 8.900249116122723, 6.036402639001608, 10.985637065023184, 10.614815913140774, 10.902040600776672, 12.794436905533075, 11.822762545198202, 8.843259774148464, 7.667075637727976, 3.7184032844379544, 1.3686555647291243, 0.2910175669239834, 0.08707488814252429, 0.07407948898617178, 0.08335467995493673, 0.02304023251781473, 0.018902211886597797, 0.03713766716828104, 0.014377508196048439, 0.05314918787917122, 0.06358754690154456, 0.05423048962256871, 0.02310243376996368, 0.022660854046989698, 0.022384042240446433, 0.056627352023497224, 0.06716423114994541, 0.043255591226625256, 0.02054665528703481, 0.060216990459593944, 0.038977670192252845, 0.005227211868259474, 0.03989932483818848, 0.05814518874103669, 0.018542548568802886, 0.03441326902247965, 0.06030022232152987, 0.03132209778414108, 0.012549351704365108, 0.04479789284232538, 0.029498008261725772, 0.03834688919596374, 0.02533438353566453, 0.046438287827186286, 0.029056252278678585, 0.023392969742417336, 0.041624792211223394, 0.037863020043005235, 0.026967414560203906, 0.04453727284271736, 0.045367275961325504, 0.05678678389813285, 0.032443802047055215, 0.010867644141399069, 0.014454963366006268, 0.06174205940624233, 0.023760742878948804, 0.011725732911145315, 0.06614637561142445, 0.07409942307276651, 0.010258189686283004, 0.08006307689356618, 0.016849954627105035, 0.007823022260708967, 0.06685477041173726, 0.05851093395904172, 0.047474593156948686, 0.0476613397768233, 0.08203460703953169, 0.033679982589092106, 0.010301785296178423, 0.008168541171471588, 0.06009668461047113, 0.02091207952616969, 0.07511257339501753, 0.056721775472396985, 0.01044699576596031, 0.010777941679407377, 0.06575098159373738, 0.02955793112050742, 0.06049053496099077, 0.01768725491274381, 0.01808215911296429, 0.051140761861461215, 0.04142672412854154, 0.017087664527934976, 0.028390243387548253, 0.01979505264898762, 0.011922798166779103, 0.02754755139903864, 0.013746723489020951, 0.007729975031907088, 0.025769128078536596, 0.05100542381114792, 0.10722166683990508, 0.05367911471694242, 0.042790361112565733, 0.007601504630656564, 0.031842862808844075, 0.008602515736129135, 0.047512394448858686, 0.051810750519507565, 0.026113477179023903, 0.10761607380118221, 0.06767738916096278, 0.03842164944217075, 0.022982829250395298, 0.040026061396929435, 0.03447204340773169, 0.04515942266152706, 0.01341536661129794, 0.02282001503772335, 0.013800798224110622, 0.04211994200886693, 0.07296855328604579, 0.03159151223371737, 0.025928734357876237, 0.024490214673278388, 0.04045369802042842, 0.031135685130720958, 0.03480318970105145, 0.0637150181864854, 0.029441549377224874, 0.018378489403403364, 0.03701766188896727, 0.027991031020064838, 0.03282680219854228, 0.03800271821091883, 0.03535340685630217, 0.026309185232094023, 0.06752134519047104, 0.022731085336999968, 0.037848492502234876, 0.02432952300296165, 0.06927491398528218, 0.028682323027169332, 0.039779757426003926, 0.03466230409685522, 0.027183114216313697, 0.08440622157650068, 0.030215542610676493, 0.018515749616199173, 0.04081879756995477, 0.05805368935398292, 0.06961923339986242, 0.06719301163684577, 0.03785107517614961, 0.020623178133973852, 0.028280665283091366, 0.03472690805210732, 0.029121526022208855, 0.018901608891610522, 0.029642923727806192, 0.046428955320152454, 0.007416321159325889, 0.015250531760102604, 0.06963319319766015, 0.010920790264208335, 0.03997346539108548, 0.03535571122483816, 0.030600461213907693, 0.04852319216297474, 0.058488869908615015, 0.0799443777941633, 0.301995177869685, 0.7633256027474999, 1.0355916805565357, 1.7342736083082855, 2.8168327873572707, 5.117971021682024, 5.466298330575228, 9.51151566579938, 9.470314476639032, 8.19598350673914, 8.33088006824255, 11.423885598778725, 14.980691391974688, 11.507396567612886, 18.16470678895712, 17.006006464362144, 17.363894060254097, 19.142335429787636, 17.458130903542042, 13.870016690343618, 11.456450801342726, 5.879479134455323, 3.3605665108188987, 0.7495819183532149, 0.1878402932197787, 0.05356621179089416, 0.048074819933390245, 0.026409041201986838, 0.03855978909996338, 0.032582201456534676, 0.020226617089065257, 0.14255462010623887, 0.059229581529507414, 0.10147587046958506, 0.04886911832727492, 0.03757142279937398, 0.010013106548285577, 0.0672165302967187, 0.08452623427729122, 0.06645912406384014, 0.0224956612510141, 0.05207463225815445, 0.08393666474148631, 0.06791445339331403, 0.08001636611879803, 0.03768972113903146, 0.06935575613169931, 0.05796910678327549, 0.019809880759567022, 0.03600036296120379, 0.022936188979656436, 0.061485406185965985, 0.016628681441943627, 0.07209939445601776, 0.0531185408908641, 0.04605548063409515, 0.031194674738799222, 0.05089251346362289, 0.06456957897171378, 0.04968435641785618, 0.01722893604892306, 0.02380457412073156, 0.04580836401146371, 0.04942909843521193, 0.03480983563349582, 0.014647713032900356, 0.021489785831363406, 0.022332255175570026, 0.05178108316613361, 0.024496502519468777, 0.027182398043805733, 0.04146341962041333, 0.022290425877145026, 0.01577711522259051, 0.041757970611797646, 0.02888734503358137, 0.04978223456419073, 0.012298183883103775, 0.020825060855713673, 0.031618912325939164, 0.05510692521056626, 0.007677213898205082, 0.03561991579772439, 0.12395429163007066, 0.020645236618292984, 0.027837810921482742, 0.1354425001773052, 0.036219255707692355, 0.04993743248633109, 0.05760217783972621, 0.016472123534185812, 0.02388765013165539, 0.04342550222645514, 0.06612538767512888, 0.0747161329491064, 0.05316653929185122, 0.10175006435019895, 0.1311517140129581, 0.08913115671020932, 0.10116632809513249, 0.13771731639280915, 0.14676368096843362, 0.11467777221696451, 0.12883003859315068, 0.1432846114039421, 0.1138194784289226, 0.19429120409768075, 0.1729748080833815, 0.1366939244326204, 0.10442078666528687, 0.1318546466063708, 0.09750856421305798, 0.1415665989043191, 0.11365050624590367, 0.13259140629088506, 0.1575970184057951, 0.19382610014872625, 0.07979499088833109, 0.10616423256578855, 0.11693764157826081, 0.20706827082904056, 0.11057692390750162, 0.2181169349933043, 0.10143102990696207, 0.20859118754742667, 0.3514266957063228, 0.10680532199330628, 0.13869389367755502, 0.09221334054018371, 0.20475581288337708, 0.12925330025609583, 0.0891447305912152, 0.25940958643332124, 0.08231918356614187, 0.1537314977031201, 0.08803489326965064, 0.16957816143985838, 0.1364683560677804, 0.14931227546185255, 0.11912279893294908, 0.1378226568340324, 0.076204458164284, 0.15342902799602598, 0.13181957270717248, 0.17062945815268904, 0.11101821975898929, 0.24059256567852572, 0.07715491927228868, 0.1926168892532587, 0.1556111648096703, 0.07513546865084209, 0.22069987608119845, 0.09044208636623807, 0.10874659477849491, 0.09567907371092588, 0.17144767596619204, 0.21158128569368273, 0.13640163699164987, 0.11107712402008474, 0.1775354243000038, 0.09652396431192756, 0.16183429572265595, 0.07437652617227286, 0.12016710461466573, 0.10320234345272183, 0.1842639280948788, 0.18558999756351113, 0.11125290911877528, 0.18352189916186035, 0.16230860230280086, 0.1399766662507318, 0.13300156162586063, 0.12162535058450885, 0.1625703281024471, 0.12071932927938178, 0.1784003380453214, 0.3363051399355754, 0.6544523010961711, 1.0282332566566765, 1.3052614289335907, 2.375980680808425, 4.133023023605347, 4.6542994771152735, 8.638143930584192, 8.44881433993578, 6.763576744124293, 6.780484886839986, 9.737886618822813, 12.995267529040575, 10.788506492972374, 15.888212844729424, 16.310446187853813, 18.152845725417137, 18.774914145469666, 18.19062899798155, 14.72123846411705, 11.451448369771242, 5.7409836910665035, 2.6337170507758856, 0.5886766430921853, 0.28296271164435893, 0.17559592524776235, 0.1740385580342263, 0.11499117375933565, 0.08659691535285674, 0.18594328954350203, 0.24466945003950968, 0.27660111081786454, 0.10816048365086317, 0.1810692049912177, 0.13582872867118567, 0.11034287279471755, 0.06803563868743367, 0.1483203802490607, 0.14929784811101854, 0.14800159813603386, 0.17100992758059874, 0.13637410331284627, 0.2237459470052272, 0.1254093018360436, 0.10933107318123803, 0.14582176198018715, 0.13050908833974972, 0.1352117516216822, 0.17543525027576834, 0.10238702743663453, 0.10914989266893826, 0.14363885333295912, 0.0787729570583906, 0.11080992117058486, 0.13447913312120363, 0.30008349451236427, 0.07570909685455263, 0.1562524397741072, 0.15570727293379605, 0.10522287018829957, 0.14181607926730067, 0.15597889898344874, 0.16743924730690196, 0.18986843439051881, 0.0996807414048817, 0.09482908455538563, 0.14589324564440176, 0.1572718538227491, 0.12186570253106765, 0.07418415407300927, 0.14036949985893443, 0.1695348645444028, 0.07324975304072723, 0.14656828832812607, 0.13800472050206736, 0.1186111920105759, 0.17016540805343539, 0.18997021252289414, 0.1345584835507907, 0.1755958955618553, 0.14876688597723842, 0.15766796772368252, 0.13059559307293966, 0.19321198778925464, 0.13650182692799717, 0.1082249911269173, 0.2812029904453084, 0.10700332699343562, 0.09692762585473247, 0.12925646180519834, 0.27469661145005375, 0.12595194537425414, 0.11715730986907147, 0.19045700202696025, 0.21287434443365782, 0.12548415485071018], [0.019838013722619507, 0.05071447965747211, 0.0781258413917385, 0.09785824193386361, 0.041441734065301716, 0.025005884854181204, 0.03396801752387546, 0.04134410082770046, 0.06103904888732359, 0.03425264971156139, 0.04196107045572717, 0.018918023342848755, 0.04420835670316592, 0.03130924378638156, 0.05085565098852385, 0.039322308730334044, 0.02001973600272322, 0.03399447137780953, 0.03515626274747774, 0.06413712209905498, 0.004537686172625399, 0.0702387337514665, 0.03827578402706422, 0.03374758111021947, 0.037349320264183916, 0.06363275111652911, 0.022570846376765985, 0.024052067383308895, 0.02195439625211293, 0.052048401048523374, 0.05605926024145447, 0.03876628426951356, 0.14237433759262785, 0.04696394731581677, 0.08687556211953051, 0.012341537367319688, 0.018009328450716566, 0.05794110184069723, 0.025821881790761836, 0.028056334449502174, 0.019238953973399475, 0.011786036120611243, 0.046382148066186346, 0.043368223268771544, 0.037432403696584515, 0.008022593192436034, 0.05350346691557206, 0.06920310377608985, 0.03797533667238895, 0.019784282230830286, 0.015200197449303232, 0.018028353406407405, 0.0619335743249394, 0.027905828756047413, 0.05057622867752798, 0.06505443889182061, 0.048931944838841446, 0.08965106084360741, 0.025895280195982195, 0.016021198316593654, 0.04060619823576417, 0.1036151111475192, 0.023783719771017786, 0.04938592028338462, 0.05781000516435597, 0.07112812352715991, 0.0400316683226265, 0.04309090865717735, 0.01968099197256379, 0.06009715958498418, 0.044821652700193226, 0.031432948671863414, 0.014476024589384906, 0.01833502552472055, 0.052180785351083614, 0.03831364469078835, 0.009076517108042026, 0.063763398793526, 0.047501585067948326, 0.1341544435126707, 0.08295519670355134, 0.032190429119509645, 0.10579386376775801, 0.040180042196880095, 0.04894181540294085, 0.025275128609791864, 0.04824900199309923, 0.015059023335197708, 0.06407972439774312, 0.04446890248800628, 0.027584697745624, 0.04375429962237831, 0.07310384680749848, 0.17289421084569767, 0.10277376801241189, 0.18183091568062082, 0.09511194672086276, 0.10447937180288136, 0.337350083864294, 0.1652510100393556, 0.0693511325516738, 0.05044264209573157, 0.07703423121711239, 0.023132880378398113, 0.02114565566444071, 0.03291054985311348, 0.01662509501329623, 0.03681507041619625, 0.035589350445661694, 0.05914936278713867, 0.030859413236612454, 0.0355123526242096, 0.04947865163558163, 0.0446540757548064, 0.040195731198764406, 0.008155258583428804, 0.00880436877196189, 0.024596015246061143, 0.028109887825849, 0.08571017504436895, 0.07753746671369299, 0.02901814856159035, 0.025748290427145548, 0.004251316431691521, 0.032891918235691264, 0.052954837956349365, 0.08167703286744654, 0.030827430382487364, 0.03083201685512904, 0.05126972486323211, 0.009217300666932715, 0.05063080621766858, 0.04404984509164933, 0.06509490078315139, 0.039185887144412845, 0.020649166290240828, 0.02995522318087751, 0.024614444628241472, 0.022399341614800505, 0.0439227040624246, 0.012926382205478149, 0.03607185775763355, 0.018369333156442735, 0.16315741144353524, 0.020605900936061516, 0.06486320969997905, 0.03791047667618841, 0.017052108232746832, 0.061065473055350594, 0.04942593317537103, 0.039575603732373565, 0.015523900929110823, 0.03620539981056936, 0.0851061855792068, 0.07709122073720209, 0.023944817767187487, 0.05015495225961786, 0.015175493208516855, 0.007387827790807933, 0.11304361498332582, 0.039823674014769495, 0.020078849920537323, 0.0723523332271725, 0.01360682123049628, 0.06096175049606245, 0.03548748696630355, 0.016697606552043, 0.04037095968669746, 0.03681413902086206, 0.04129061795538291, 0.02980286026286194, 0.012443502891983371, 0.06023878733685706, 0.05218113787123002, 0.040273007325595245, 0.05795484270493034, 0.04659184931369964, 0.07538640362326987, 0.045560071084764786, 0.03481212515907828, 0.03149530020891689, 0.023312435587286018, 0.021204071963438764, 0.0477114904060727, 0.01665292369580129, 0.03461660264292732, 0.037388342389022, 0.05715048078855034, 0.03235895601392258, 0.04332629563577939, 0.019796765154751483, 0.04926931775116827, 0.010239874409307959, 0.05675740598235279, 0.037556320094154216, 0.017205222575285006, 0.03249975998187438, 0.042322644803789444, 0.02481418810930336, 0.04310321717639454, 0.0574681719444925, 0.03173064636939671, 0.009538890881231055, 0.00783671674071229, 0.010996129385603126, 0.08979216538136825, 0.06737428862834349, 0.020615380017261487, 0.09310890498454683, 0.02954280800622655, 0.019026998452318367, 0.030238320978241973, 0.060859964942210354, 0.05777743230282795, 0.02294345646078, 0.015551094147667754, 0.015762914226797875, 0.021525219672184903, 0.038379495454137214, 0.020705868228105828, 0.08105165470624343, 0.03378945679287426, 0.039447523886337876, 0.03182429056323599, 0.01513656849056133, 0.05727206684241537, 0.021007939030823763, 0.02326556154002901, 0.04276020765246358, 0.034757347239064984, 0.05016497496399097, 0.09634504735004157, 0.029091394826536998, 0.036574592304532416, 0.0351917262742063, 0.06460302014602348, 0.07037785675493069, 0.03831400092167314, 0.04763082637509797, 0.021381949918577448, 0.09143495379248634, 0.034768308760249056, 0.04054173157783225, 0.03427352261496708, 0.031496684314333834, 0.02759785045782337, 0.06660085942712612, 0.014469680154434172, 0.038155225847731344, 0.04914406919851899, 0.013895082520321012, 0.024110973499773536, 0.08624083289760165, 0.043039559459430166, 0.029754778370261192, 0.013071341272734571, 0.02241961337858811, 0.02241283014882356, 0.04839664114115294, 0.036448093233047985, 0.0821037232526578, 0.03717812163813505, 0.07595476257847622, 0.021809887111885473, 0.18900890863733366, 0.07708298289799131, 0.07906665457994677, 0.11514676501974463, 0.24070390267297626, 0.2207915610051714, 0.3202248481102288, 0.36946207168512046, 0.3365667618345469, 0.503620938397944, 0.6495259248185903, 0.29183045611716807, 0.057904328423319384, 0.05535874704946764, 0.06999264500336722, 0.030988433754828293, 0.08193196059437469, 0.041304240075987764, 0.02005915332119912, 0.03661232680315152, 0.01825853050831938, 0.01963243881618837, 0.010629859098116867, 0.03135392107651569, 0.09462104571866803, 0.015895437682047486, 0.037352544895838946, 0.057366998662473634, 0.03404622504604049, 0.03852283385640476, 0.022080203270888887, 0.05986805117572658, 0.03950740036088973, 0.028022364494972862, 0.045773267847835086, 0.025787728154682554, 0.03970975063566584, 0.09671897103544325, 0.044176425799378194, 0.04522320654359646, 0.022767942245991435, 0.04792009698576294, 0.0188491835797322, 0.03795217795413919, 0.029291758000908885, 0.03057805577554973, 0.026395348577352706, 0.020868255705863703, 0.08313966493005864, 0.05863558879354969, 0.006412144330170122, 0.02450306867103791, 0.023391411232296377, 0.03830160705547314, 0.021676675314665772, 0.018117448234988842, 0.05427549716841895, 0.06405935244401917, 0.030816919716016855, 0.09834159529418685, 0.018481510633137077, 0.02544937189668417, 0.06582302929018624, 0.03346419573063031, 0.07666058954782784, 0.030369449195859488, 0.05671802020515315, 0.042244645082973875, 0.04820495923922863, 0.02780651640932774, 0.043315081784385256, 0.03452170793025289, 0.03978836633905303, 0.030747584569326136, 0.06386904351529665, 0.033660323097137734, 0.02635283650306519, 0.041528294459567405, 0.04410081579408143, 0.03211322720744647, 0.02206566830864176, 0.023267838078027125, 0.01940720627317205, 0.019321625513839535, 0.026532272968324833, 0.10438581666676328, 0.0755016146285925, 0.0449293309065979, 0.12723448046017438, 0.21567172167124227, 0.176134115899913, 0.2904145867796615, 0.11047832216718234, 0.09884169150609523, 0.05980024485324975, 0.11175453415489756, 0.1373805446201004, 0.08477112074615434, 0.10758275879197754, 0.0885868284967728, 0.15218340733554214, 0.18180321872932836, 0.09648009596276097, 0.23529716389020905, 0.11278393008979037, 0.1286390097811818, 0.11965868892730214, 0.2920357935363427, 0.10021502093877643, 0.14883670723065734, 0.09050036722328514, 0.20568790583638474, 0.1838746716384776, 0.10648829134879634, 0.06532000901643187, 0.12648042873479426, 0.09500029802438803, 0.2530244446825236, 0.1465625737910159, 0.13412119529675692, 0.24670269718626514, 0.12525287194876, 0.17653591465204954, 0.1265781992697157, 0.147731693868991, 0.19642149447463453, 0.08348542411113158, 0.15172015875577927, 0.07950035826070234, 0.11510942014865577, 0.09943883094820194, 0.10744804414571263, 0.11929509593755938, 0.14616095315432176, 0.14379273023223504, 0.13498924090526998, 0.1878669363213703, 0.14035936212167144, 0.08318633859744295, 0.1588944112882018, 0.17565397603902966, 0.10495473223272711, 0.19010699033970013, 0.19368647248484194, 0.11518306346260943, 0.3230480075580999, 0.19623064377810806, 0.19530013902112842, 0.23002226022072136, 0.26578430843073875, 0.18838464369764552, 0.15447486250195652, 0.2322268989519216, 0.1919800671748817, 0.12666448135860264, 0.12555877037812024, 0.1519809346063994, 0.1305264249094762, 0.08782246834016405, 0.07513445933000185, 0.10261400588206016, 0.09597755066351965, 0.13337725162273273, 0.20974473736714572, 0.20260989287635311, 0.21700838900869712, 0.136609468027018, 0.25400663260370493, 0.08675899298395962, 0.06865602961624973, 0.2581042080419138, 0.23622042528586462, 0.2057666625478305, 0.0943778661894612, 0.14508641237625852, 0.10440195095725358, 0.21612389740766957, 0.16818062314996496, 0.1286669887485914, 0.21567287942161784, 0.44597417232580483, 0.2656525030033663, 0.2515646698884666, 0.23168492334662005, 0.3118612593971193, 0.481434611720033, 0.5379535804968327, 0.22431550081819296, 0.20865685277385637, 0.1464312878670171, 0.17818091466324404, 0.12662587483646348, 0.24404177122050896, 0.07518797559896484, 0.1895259035518393, 0.17804351344238967, 0.14008914615260437, 0.11767461648560129, 0.06823517993325368, 0.10749416862381622, 0.26862818864174187, 0.11332512644003145, 0.183309466810897, 0.21760669362265617, 0.1334338032756932, 0.1174165568954777, 0.21797668392537162, 0.22748827119357884, 0.1590418315026909, 0.13272577954921871, 0.16834768059197813, 0.15212684083962813, 0.09552800212986767, 0.19146371050737798, 0.2444109451607801, 0.07400519258226268, 0.17387406842317432, 0.12132317031500861, 0.1182245033851359, 0.12224821286508814, 0.24224982596933842, 0.12557738344185054, 0.09704039519419894, 0.07481279768398963, 0.1751154291559942, 0.14354212180478498, 0.12326566022238694, 0.10582249582512304, 0.09373363747727126, 0.15988332306733355, 0.07490609306842089, 0.1749657528125681, 0.11054857386625372, 0.26892834284808487, 0.11546890906174667, 0.10826781304785982, 0.0843352203082759, 0.1400499904411845, 0.16044875053921714, 0.10064661692013033, 0.09666593716247007, 0.1917279150802642, 0.1371004432439804, 0.14455737982643768, 0.10397864476544783, 0.0868188175081741, 0.08790256833890453, 0.16733613330870867, 0.13839164661476389, 0.11421654970035888, 0.21556571329711005, 0.11194067963515408, 0.16092137986561283, 0.13195865118177608, 0.1298604957992211, 0.1673878016299568, 0.18220057943835855, 0.17148990416899323, 0.19270199874881655, 0.12660513923037797, 0.10113116513821296, 0.13052927475655451, 0.1698852176195942, 0.1958497884334065], [0.04598944433382712, 0.06950661991140805, 0.014273776359914336, 0.08558013592846692, 0.03981134694186039, 0.04718001247965731, 0.03485918845399283, 0.10669499431969598, 0.1004429196473211, 0.051761646318482235, 0.000418182850694393, 0.043884175465791486, 0.021997566982463468, 0.05731195728003513, 0.056804124178597704, 0.020348509278846905, 0.04299351290683262, 0.04611018805007916, 0.0021866639144718647, 0.06857292391941883, 0.012104165143682621, 0.0932932025170885, 0.05123419454321265, 0.0373498546105111, 0.035330663740751334, 0.012396876536513446, 0.023403023988066707, 0.06630216725170612, 0.021183495919103734, 0.01787822249752935, 0.08231771411374211, 0.044829293110524304, 0.0563548242644174, 0.09764065907802433, 0.03348854930663947, 0.012908593853353523, 0.058263668906874955, 0.016267309329123236, 0.15762343886308372, 0.030081469922151882, 0.13834187819156796, 0.08644766203360632, 0.03535584852215834, 0.036594351986423135, 0.015508124724874506, 0.03443729234277271, 0.019091819485765882, 0.04562786627502646, 0.014563895801984472, 0.04003944603027776, 0.030122904026939068, 0.056758864302537404, 0.024589274689788, 0.0066428608806745615, 0.04892718767223414, 0.034165246979682706, 0.03293570494861342, 0.044911151999258436, 0.02936660916020628, 0.030668575527670328, 0.04602105982485227, 0.05704154464183375, 0.011178410131833516, 0.03784836262639146, 0.031021878639876377, 0.04620674517354928, 0.02455215060763294, 0.0325230597081827, 0.08651262964121997, 0.020839072603848763, 0.052820583441643976, 0.020300622200011276, 0.009503139772277791, 0.029379730331129394, 0.04441483331902418, 0.046091834738035686, 0.01846256916905986, 0.05005899627576582, 0.06508156438940205, 0.021902969128859695, 0.025169413383991923, 0.040099218604154885, 0.06117042386904359, 0.022343749187712092, 0.07960218092193827, 0.06369320646626875, 0.030672208340547513, 0.014915908504917752, 0.005120053629070753, 0.01072512766768341, 0.05247569999482948, 0.022328446102619637, 0.07346825615968555, 0.05379157606512308, 0.030875814700266346, 0.01872627835837193, 0.01928142151882639, 0.0575256030424498, 0.018550079512351658, 0.06062144610041287, 0.04239161258738022, 0.06482967946794815, 0.00675123902510677, 0.0758884368406143, 0.04887240233074408, 0.028467738447943702, 0.033436272424296476, 0.05482317617861554, 0.00767339647609333, 0.03177200254867785, 0.04742148877994623, 0.008462281366519164, 0.035007243204745464, 0.04055394361785147, 0.08652912016259506, 0.018029592793027405, 0.0656000361777842, 0.046615976534667425, 0.01683260878053261, 0.08785692625679076, 0.12629098811885342, 0.04359655984444544, 0.0026267855491823866, 0.07893539834185503, 0.07314925140235573, 0.020993815960537177, 0.04230697435559705, 0.02272203484608326, 0.0971114038839005, 0.041555961724952795, 0.05839420155098196, 0.012797763374692295, 0.02686758085474139, 0.07556330936495215, 0.02781799186777789, 0.06376094970619306, 0.04713414775324054, 0.01081608992535621, 0.006403386059901095, 0.04836735599383246, 0.026157853899348993, 0.0292322859968408, 0.09211107259034179, 0.04737829578516539, 0.04293173653422855, 0.09615511691663414, 0.06264727548114024, 0.04871953104157001, 0.06939029568457045, 0.014814275091339368, 0.02589160099887522, 0.022618332695856225, 0.03899519600963686, 0.03254276001825929, 0.05405835217970889, 0.03982207097578794, 0.02621408086270094, 0.020599039780790918, 0.011005524975189473, 0.03539439567248337, 0.057131344510708004, 0.022652694133284967, 0.03759630701097194, 0.016200796198972967, 0.03876895229041111, 0.018263204183313064, 0.04341064442996867, 0.038162239143275656, 0.05055268404248636, 0.028578689525602385, 0.018652612779987976, 0.04765765872434713, 0.04265379480784759, 0.015664932179788593, 0.04062113395775668, 0.014406506688828813, 0.03315825277240947, 0.04904419096419588, 0.009339849657408195, 0.043633785971906036, 0.03237690485548228, 0.05896171445783693, 0.06738470096024685, 0.05404442206781823, 0.05963803734630346, 0.023047433205647394, 0.03891681037202943, 0.046531664847861975, 0.017066756372514647, 0.006926409996594884, 0.06648467620834708, 0.03998232292360626, 0.00783828823841759, 0.0031639000872019096, 0.04987519969290588, 0.03531837006448768, 0.02676840766071109, 0.03147420837194659, 0.04628908645827323, 0.025200906420650426, 0.027399426144256722, 0.007452709123754175, 0.02532483766117366, 0.04671391405281611, 0.04306498543883208, 0.02770620587398298, 0.026211472213617526, 0.030278409940365236, 0.08304270333610475, 0.04001923734904267, 0.015306338482332649, 0.016543438359803986, 0.043739063330576755, 0.024713285711186472, 0.05446819952339865, 0.013946827839390608, 0.01113920247007627, 0.03115011248155497, 0.00594306757193408, 0.021444544508995023, 0.042898083847831, 0.045855431017116643, 0.08192563749616966, 0.03894439971190877, 0.05765123380115256, 0.009505574944341788, 0.056115811894414946, 0.03738016763236374, 0.04501798415731173, 0.08300916568259709, 0.07825676366337575, 0.06100096186855808, 0.055619964477955364, 0.03157526662107557, 0.036953143280697986, 0.05330024832801428, 0.009564294596202672, 0.034014717166428454, 0.03315620073408354, 0.07601497301948257, 0.027257466281298548, 0.04346391579019837, 0.06658387908828445, 0.04280291082977783, 0.03475613753835205, 0.08887251824489795, 0.04258927991031669, 0.016736550751375034, 0.017975289847527165, 0.05225720058660954, 0.11744172312319279, 0.03702664558659308, 0.02592619064671453, 0.04531351107289083, 0.042383408144814894, 0.01563350964715937, 0.048763651720946655, 0.054539902121177875, 0.018022970980382524, 0.035052310122409835, 0.052003935270477086, 0.017340482700092252, 0.06034224643371999, 0.023311938348342665, 0.018637727152963635, 0.040226886558230035, 0.016849004678078927, 0.03030410865903832, 0.06447284002206288, 0.06198561743076425, 0.04486749145144131, 0.02937856701464625, 0.059741986260632984, 0.1191904531151522, 0.049196449981536716, 0.0302047183868126, 0.03929114966013003, 0.0331086253572721, 0.013918690237915143, 0.06523377887788229, 0.05774900804681238, 0.04549516655970365, 0.039618373702978715, 0.06578047454240732, 0.037100055124028586, 0.039921492789289914, 0.11957286696997471, 0.01044292137521552, 0.04216731700580567, 0.029583299583464395, 0.0845814797503408, 0.03855066068354063, 0.008091221443464747, 0.06968984875129536, 0.06668424714007415, 0.04793696600245312, 0.015248763593262993, 0.03642821109679062, 0.021823381212016102, 0.02060624789010035, 0.015140737505134894, 0.018517118878662586, 0.08170211003744043, 0.052378857144503854, 0.019066632848989684, 0.06345996429445222, 0.02844108978024451, 0.03908976788807195, 0.036181717878207564, 0.0412179171689786, 0.04849629302043468, 0.03415432627662085, 0.031726809465908445, 0.014616387907153694, 0.01786656150216004, 0.03613717417465523, 0.03925418699509464, 0.07050615924526937, 0.07575610448839143, 0.04993389986339025, 0.017423974313715007, 0.08562376679037698, 0.026705249038059264, 0.047672353248344734, 0.06131966976681724, 0.026649890387488995, 0.01287147719267523, 0.04864653339609504, 0.01999387957766885, 0.07954365515615791, 0.09252805568394251, 0.017482615112385247, 0.018933964674943127, 0.017149802697531413, 0.048192331596510485, 0.02989058026287239, 0.006207218802956049, 0.021904761415498797, 0.07563177990959957, 0.039538411001558416, 0.02324325258086901, 0.004941962306475034, 0.0831006131193135, 0.053777957655256614, 0.056179054008680396, 0.03672495142382104, 0.0383737883385038, 0.019730335516214836, 0.05215079145273194, 0.05520410202734638, 0.05324320314684883, 0.06831679391325451, 0.1549918722594157, 0.1446170633425936, 0.07439191831508651, 0.24209499912103638, 0.11250507552176714, 0.06204456993145868, 0.10499667841941118, 0.2364567993208766, 0.1680400752229616, 0.1791940798284486, 0.10523490782361478, 0.1980027588433586, 0.08469173320918344, 0.07483251654775813, 0.1241114414006006, 0.09369473409606144, 0.14878785907058045, 0.12868548306869343, 0.131666794186458, 0.103364888636861, 0.1797901134705171, 0.17710439977236092, 0.2248038785182871, 0.10187892345129512, 0.15439763461472467, 0.10910707816947252, 0.08738120217458345, 0.19480353832477704, 0.12212631510919891, 0.13258726510684937, 0.1560062397038564, 0.10002699040342122, 0.23842067050281912, 0.3025620599510148, 0.09277917619328946, 0.10582708971924148, 0.19069212925387546, 0.09818923237617128, 0.24739540298469365, 0.0932312777149491, 0.185134289204143, 0.18009394872933626, 0.08707051689270884, 0.1035630791739095, 0.11470029639895074, 0.14435906312428415, 0.14706913410918787, 0.15263077395502478, 0.1546097404207103, 0.13496273139026016, 0.13441882620099932, 0.09390160033944994, 0.1296357437968254, 0.1584215444745496, 0.19038385595194995, 0.12363089335849509, 0.11350477070664056, 0.1934337118291296, 0.09543288848362863, 0.08905296403099783, 0.10245848141494207, 0.14030488848220557, 0.1193561301624868, 0.14721794956130907, 0.06943785250768997, 0.22139348729979247, 0.18124193244148046, 0.08472311863442883, 0.14690047362819314, 0.192990634823218, 0.14018712448887527, 0.11562521278392524, 0.08850427198922262, 0.16086833114968613, 0.21761601499747485, 0.1781182031845674, 0.11808719122200273, 0.107111777033424, 0.13077709270874038, 0.07695119973504916, 0.08368112845346332, 0.16081654408480972, 0.12761168443830684, 0.11612718662945554, 0.25017005566041917, 0.1323942473391071, 0.0793782007531263, 0.10798780072946101, 0.22592504101339728, 0.10083080313052051, 0.15244511829223484, 0.10386628360720351, 0.18968726129969582, 0.16783136845333502, 0.1808055941364728, 0.08578905049944296, 0.17044513835571706, 0.18223388702608645, 0.15002684493083507, 0.09936904680216685, 0.10332859761547297, 0.2224956062855199, 0.1877539517590776, 0.15260154817951843, 0.09427986558876, 0.12332982631050982, 0.13334155431948602, 0.25206282909493893, 0.09329055304988287, 0.128171278629452, 0.33573436900042, 0.13716842397116125, 0.08903379435651004, 0.11516690690768883, 0.2076477842638269, 0.1365302363410592, 0.11971034240559675, 0.13471193000441417, 0.12856963381636888, 0.17551133525557816, 0.2381386692286469, 0.1631276958505623, 0.12632307858439162, 0.11487326875794679, 0.11170777142979205, 0.08315407743793912, 0.15094850328750908, 0.16221693222178146, 0.20082271221326664, 0.14356698375195265, 0.1707415669807233, 0.1399830635637045, 0.1191456793458201, 0.24986687349155545, 0.14121542946668342, 0.19302180502563715, 0.18833242618711665, 0.11399721537600271, 0.14782613958232105, 0.18395820778096095, 0.12266193050891161, 0.14562981290509924, 0.13786445459118113, 0.1791351829888299, 0.15144452510867268, 0.19935631746193394, 0.13662779907463118, 0.12933898862684146, 0.13252658711280674, 0.07389482780126855, 0.12160782105638646, 0.0995532626984641, 0.08843882940709591, 0.1843177486443892, 0.26313139765989035, 0.11759435321437195, 0.16286617785226554, 0.12502273195423186, 0.13413758191745728, 0.11954802728723735, 0.15039126912597567, 0.2581267396453768, 0.16232053603744134, 0.10972655625664629, 0.07253881267388351, 0.1010072413191665, 0.21348829352064058, 0.1317102395114489, 0.18735611607553437, 0.07222348154755309, 0.11483479582238942, 0.09661760850576684, 0.09655002853833139, 0.10810152743943036, 0.11230833959416486, 0.2846261317608878], [0.04798556554305833, 0.03232441275031306, 0.00483976022223942, 0.0676974123052787, 0.056426493465551175, 0.04140413315326441, 0.014031810242158826, 0.0331112154526636, 0.022943731055420358, 0.03896733578585554, 0.08907341019948944, 0.050262797449249774, 0.13709377875784412, 0.0025967292640416417, 0.03768068549106829, 0.028335200149740558, 0.06334490171866491, 0.024743344547459856, 0.0720049487426877, 0.0711672569741495, 0.034519559412728995, 0.013657242743647657, 0.0328031165554421, 0.051400161028141156, 0.02645724183821585, 0.02181660725909751, 0.017065632018784527, 0.04124190709262621, 0.016238081698247697, 0.057749865227378905, 0.036229823890607804, 0.05916214628086891, 0.035561820477596484, 0.01431983218935784, 0.02310823736479506, 0.052795127776334994, 0.019508527984726243, 0.027885026356671005, 0.021782646581414156, 0.03447163151577115, 0.053689872147515416, 0.02257223048218293, 0.04535206564469263, 0.02552998768805992, 0.01569850694068009, 0.044985273998463526, 0.025917655948433094, 0.04488950355153065, 0.02291441251145443, 0.012025528103549732, 0.049225575567106716, 0.029895220541220624, 0.06155939459858928, 0.05998144762997981, 0.06908188137458637, 0.02742640321230283, 0.04170042448095046, 0.009857532913883915, 0.05631323430861812, 0.012679625524469884, 0.03160126776492689, 0.050583991542225704, 0.02183498283557128, 0.046912063771742396, 0.06767210506950505, 0.03705389353854116, 0.025182933459291235, 0.0424884888343513, 0.027138769037264865, 0.05098474015539978, 0.022368690915754996, 0.06577852269401774, 0.02377229440753581, 0.016063673283497337, 0.02429814685456222, 0.04309617790568154, 0.07006229556282051, 0.037692192490794696, 0.03459042709437199, 0.052542537814588286, 0.038199936534510925, 0.03936049964977428, 0.023233740103023592, 0.04077429468452465, 0.05938916925515514, 0.05590858570940327, 0.06286744843237102, 0.008961197563621681, 0.09632593704736792, 0.029991686751600355, 0.07882671081461012, 0.010960510007862467, 0.04566145216813311, 0.04885943701083306, 0.07766691953293048, 0.011776239771279506, 0.037983938163961284, 0.04347972724644933, 0.04465449877898209, 0.04961329948855564, 0.019065287706325762, 0.0346731542958878, 0.03232949646189809, 0.03565481158148032, 0.031337437976617366, 0.040843570459401235, 0.032051688322098926, 0.045689390317420475, 0.06891317636473104, 0.034621233644429594, 0.11089056293712929, 0.05307192659529392, 0.10011199599830434, 0.03030805502930889, 0.038855776147102006, 0.02018028109887382, 0.03230997797800228, 0.017023687687469646, 0.07972867257194594, 0.009509743958915351, 0.0413388464221498, 0.02344093289138982, 0.0243057204716024, 0.06484393612481654, 0.04938420592225157, 0.031396802369272336, 0.03266081344918348, 0.05656533445289824, 0.02033186476182891, 0.03980257846706081, 0.019169626248185523, 0.07723717149929143, 0.041793200362008065, 0.019094943927484564, 0.07243573578307405, 0.02941714941698592, 0.03142204281175509, 0.029786763079755474, 0.07881887373514473, 0.015893300296738744, 0.0682095016236417, 0.08730280911549926, 0.0011167156390001765, 0.04095939744729549, 0.045144739269744605, 0.017930512367456686, 0.018636461791174952, 0.07805337809259072, 0.029777009403915145, 0.01966120817087358, 0.022802001258241944, 0.03341782634379342, 0.0852211813617032, 0.019364896434126422, 0.03475607074506115, 0.024808699927234557, 0.01481631321439636, 0.06897200641105883, 0.011593231720326003, 0.009475915012444602, 0.024555004165449645, 0.019899459839507472, 0.0628943438641727, 0.03586266488127876, 0.07013020949671045, 0.04024215253593866, 0.024705426367290784, 0.028751550562446937, 0.021620611623802688, 0.007371904084720882, 0.028779214117093943, 0.017830858632805757, 0.025426354186492972, 0.05837649019667879, 0.040849503930076025, 0.023194688292278443, 0.05376593857363332, 0.03334804219775833, 0.02110449058818631, 0.05098242836538702, 0.03627149548265152, 0.026368724029453006, 0.08664932582178153, 0.019711744716914836, 0.03480409512121696, 0.027931401309615467, 0.06078577243897598, 0.039104499519453384, 0.040305138609255664, 0.01869094656285597, 0.06857515036244877, 0.05764137808000669, 0.03413682643440552, 0.060663236436084844, 0.06284590388531797, 0.06953511838219129, 0.03137331710604485, 0.08261879600468092, 0.03379588379175402, 0.02906554025685182, 0.0163061366401962, 0.05571067718847189, 0.06247523080674, 0.04146155682974495, 0.05827861576108262, 0.016882028394320514, 0.04061567546159495, 0.013319070167199243, 0.015262305932992604, 0.015784074712428264, 0.030463286348094698, 0.018447985967213754, 0.015937318930809852, 0.005733247116950224, 0.07960049624671228, 0.05251646616670769, 0.03118969121715054, 0.04452391047379933, 0.05817829223815352, 0.0048374233847425785, 0.03556245501386002, 0.006795128711019061, 0.057980216733994894, 0.03513647709041834, 0.1049490919103846, 0.02552615449531004, 0.07301841818843968, 0.038529130979441106, 0.0326277210842818, 0.10761348370579071, 0.03071871688007377, 0.011166687909280881, 0.02853616446373053, 0.020482646905293223, 0.027346724382368848, 0.06288784265052527, 0.04158527655818034, 0.04625088440661784, 0.010145251508220099, 0.06592808771529235, 0.06648470589425415, 0.03928703816200141, 0.02141838751413161, 0.055579996114829555, 0.01926234832353657, 0.0206564096515649, 0.028883291051897686, 0.019488760881358758, 0.05818482684844639, 0.026500731692067347, 0.08146812571794726, 0.06482736396719702, 0.01389180501064402, 0.019249566685175523, 0.00678351409987954, 0.004154974531047628, 0.054516847303602844, 0.08389252921915613, 0.03245100087951869, 0.031151348157436587, 0.019451200787443668, 0.03414445571252145, 0.08081553300144151, 0.03386851036339067, 0.05169590687728487, 0.03402838752663229, 0.0898450508248061, 0.045677445450564846, 0.03261072219174821, 0.029893641622038558, 0.04609498515492305, 0.02857831474102568, 0.06768333376385272, 0.04453273089893628, 0.03252157541282941, 0.10172211506869644, 0.0003969185803498476, 0.06389407615642995, 0.037887440412305295, 0.03154668280330952, 0.05579004617175087, 0.10162681588553824, 0.049420511786593124, 0.013811608532705577, 0.053386578656500205, 0.019748165614146274, 0.04563082744425628, 0.017722872435115278, 0.06937531172297895, 0.03919667055015452, 0.024055433023022488, 0.04011300770798698, 0.04109482826606836, 0.06379940779879689, 0.043962976706097834, 0.021028240480518434, 0.028322056714387145, 0.07349161896854639, 0.02593980163510423, 0.0747702874650713, 0.03242577899072785, 0.04929369730234612, 0.060390953585738316, 0.06554839012096636, 0.054240452955127694, 0.0109529558721988, 0.062374224507948384, 0.08093210955848917, 0.01605878624104662, 0.020772403622686397, 0.010259870650770608, 0.037034905690234154, 0.021120955134392716, 0.014826414771960117, 0.007531644878326915, 0.009816343717830023, 0.012024728439428145, 0.032967454026220366, 0.03560667588317301, 0.010964255070575746, 0.06567157179233618, 0.03913095708412584, 0.026755275357572827, 0.05434271719423123, 0.03026375994522823, 0.04020333450171165, 0.014584697273676284, 0.07037039074930362, 0.05998653134156484, 0.0409955585928401, 0.01959740573511226, 0.01139707930633449, 0.03553021982952487, 0.030237094579206314, 0.037673438419005834, 0.0497041606286075, 0.02115322928148089, 0.010348185296606971, 0.019183161166438367, 0.018600807161419652, 0.04237030181684531, 0.08981319784652442, 0.027224822915741242, 0.017631003829592373, 0.003746798643078364, 0.06063573244318832, 0.07026398161542602, 0.03474534671113361, 0.0417962914070813, 0.028360030555631965, 0.019038780046685133, 0.05522685627511237, 0.11516636513988487, 0.08695612967130728, 0.1665154960937798, 0.13881318649509922, 0.10299502449925058, 0.135388100752607, 0.19064427557168528, 0.09191400269628502, 0.10660186962923035, 0.057888802693923935, 0.17077413242077455, 0.11125161778181791, 0.30723337491508573, 0.09244883141946048, 0.16672547935741022, 0.16349140758393332, 0.08034127837163396, 0.17212821054272354, 0.14005208329763263, 0.23866130446549505, 0.05694794497685507, 0.1643770420923829, 0.18131797289242968, 0.1001876060036011, 0.1706070452928543, 0.10507566519663669, 0.09601597164873965, 0.26919225056190044, 0.12541449686978012, 0.12097710685338825, 0.12141447674366646, 0.2141306668636389, 0.11989518170594238, 0.05322110198903829, 0.19516359869157895, 0.13534967234591022, 0.1603640418034047, 0.1384828714071773, 0.23579559026984498, 0.09051620465470478, 0.12327682954492047, 0.1141588922473602, 0.09716794069390744, 0.12059534608852118, 0.07616396658704616, 0.09351202475954778, 0.13870220573153347, 0.1235003124747891, 0.2062770226621069, 0.061927588903927244, 0.15728884900454432, 0.11901881662197411, 0.11017243858077563, 0.14807033585384488, 0.17918213125085458, 0.10305395844625309, 0.13499201653758064, 0.04969950736267492, 0.13134078355506063, 0.1442793564638123, 0.13276490557473153, 0.14223105856217444, 0.09674011482275091, 0.12191183443064801, 0.18414579302771017, 0.14142763917334378, 0.15870897826971486, 0.13674805668415502, 0.1261865530977957, 0.15607224631821737, 0.09447988180909306, 0.09222335953381844, 0.20021428470499814, 0.12154562908108346, 0.15045288222609088, 0.1815277335117571, 0.2246612822636962, 0.21361487422836944, 0.08407571353018284, 0.09344400692498311, 0.16916512657189742, 0.1971489773131907, 0.2040250794379972, 0.12216068396810442, 0.14174346753861755, 0.2073132834630087, 0.28500050073489547, 0.11306406857329421, 0.15903547871857882, 0.1050751753791701, 0.147654851898551, 0.16099299711640924, 0.12711503921309486, 0.13176719192415476, 0.1279492280445993, 0.04680373989685904, 0.15699014940764755, 0.12194148323033005, 0.22961207519983873, 0.23189296218333766, 0.11991476698312908, 0.1425478665623814, 0.13553703494835645, 0.17731555562932044, 0.12568489095428959, 0.17069365392671898, 0.13484058872563764, 0.1580819525406696, 0.23421325720846653, 0.1251939602661878, 0.14343255112180486, 0.10984345193719491, 0.19120578450383618, 0.23270151723409072, 0.1433372890460305, 0.09637435476179235, 0.1361850486136973, 0.14324361516628414, 0.2149341456242837, 0.0856798657332547, 0.06949813716346398, 0.12658835184993222, 0.14033776562428102, 0.19798227556748316, 0.061921347441966645, 0.14289772982010618, 0.2206830887007527, 0.14212960697477683, 0.11427878620452248, 0.09921883611241356, 0.17240290908375755, 0.23241580522153527, 0.15478631219593808, 0.09408370853634551, 0.13161962328013033, 0.12231139931827784, 0.21974062052322552, 0.0825068578706123, 0.14442716259509325, 0.1371883283718489, 0.09974453641916625, 0.0993648759322241, 0.12787001120159402, 0.08724000115762465, 0.18368775432463735, 0.15446496225195006, 0.07031567220110446, 0.18383294809609652, 0.10772121386253275, 0.11918568110559136, 0.09969162128982134, 0.13254070276161656, 0.15877672150963917, 0.12658839637879282, 0.10188892760197632, 0.15467625169549137, 0.10665417619748041, 0.15330157155403867, 0.12946332804858685, 0.1018065566313453, 0.12329836667049676, 0.0904399564024061, 0.19047381909331307, 0.09885367719107307, 0.2292540780035779, 0.28608403634279966, 0.1463395287282765, 0.09739980989252217, 0.0840200376114808, 0.15647940337657928, 0.09931006090482697, 0.08568574354285374, 0.08191247921786271, 0.14620564528740942, 0.08091168565442786, 0.2192541427211836], [0.01702648001810303, 0.04378050485684071, 0.022794878495915327, 0.03733972058398649, 0.017012872740451712, 0.01477151810831856, 0.05503143394889776, 0.04989663291780744, 0.018104933769791387, 0.03989846023614518, 0.021699672615795862, 0.11147387616802007, 0.022200468301889487, 0.04821979106054641, 0.025813879583438393, 0.045080005438649096, 0.043779425031971186, 0.008052105622482486, 0.047505934053333476, 0.035396295570535585, 0.05100854083138984, 0.009998440782510443, 0.03436651000811253, 0.06686254811938852, 0.028234930432518013, 0.02380873014772078, 0.04518426976574119, 0.03135412887786515, 0.037855939954170026, 0.019051810304517858, 0.032798129323055036, 0.050808940213755704, 0.05435319631942548, 0.03676159125461709, 0.03758923805435188, 0.06470614156569354, 0.03303959820186719, 0.04272929349099286, 0.06188049592310563, 0.0670341846125666, 0.0495472446345957, 0.05722986832552124, 0.020620647410396487, 0.024124020455928985, 0.036560877415467985, 0.01705744241917273, 0.03993843602074776, 0.023361179846688174, 0.02194074259023182, 0.06470436041126959, 0.050783614424290136, 0.06244951538974419, 0.11065561382565647, 0.006794425526095438, 0.0652655799058266, 0.05267709289910272, 0.03013324771018233, 0.03451430871791672, 0.03298196672403719, 0.027978737343801185, 0.01301750773563981, 0.03233984942198731, 0.06235696957446635, 0.09086203805054538, 0.022805689732194878, 0.008300551617139718, 0.030137693174765445, 0.02683100781723624, 0.061862016445957124, 0.038402424106607214, 0.11044863626011647, 0.04551966114377137, 0.03630852865171619, 0.050280171126360074, 0.07742212212178856, 0.017522032430861145, 0.04973073322616983, 0.04234329506289214, 0.06659924154519103, 0.08078166880295612, 0.07767546165268868, 0.026155677551287226, 0.059857293745153584, 0.09284748346544802, 0.01266828829102451, 0.08094240314676426, 0.04570370263536461, 0.05962962139165029, 0.02114559814799577, 0.05568756299908273, 0.015207798896881286, 0.02749784049228765, 0.027742955171561334, 0.04935424913128372, 0.054041305047576316, 0.06944207532797009, 0.02834207614796469, 0.010299839941581013, 0.06314682992524467, 0.03204176951840054, 0.047751937454449944, 0.05698063658201136, 0.06819709291448817, 0.08015344079467468, 0.006302916426648153, 0.027695656244759448, 0.0938226655125618, 0.037339828195399605, 0.05781016101536807, 0.02012905435549328, 0.047862717838143, 0.03544946674082894, 0.09234561352059245, 0.04076413097209297, 0.027931226904911455, 0.03882480632455554, 0.06586611096281558, 0.028004296909784898, 0.049236982376896776, 0.06444950689910911, 0.029304600866453256, 0.031610136429662816, 0.08786676713498309, 0.030927238112781197, 0.06506646910565905, 0.014572744985343888, 0.043037032446591184, 0.057598730563768186, 0.04327480542997364, 0.09065137943252921, 0.025542778603266925, 0.04155773545789998, 0.02542315181926824, 0.029579625952464994, 0.021441657554532867, 0.03937279703677632, 0.06617665523663163, 0.027710586400644388, 0.02516447439120384, 0.016057212887972128, 0.044859394620289095, 0.03159932704875246, 0.04912276956019923, 0.036374728224473074, 0.02332869975361973, 0.01879774161352543, 0.05959123751381412, 0.01530378642200958, 0.07503556815208867, 0.08067677365033887, 0.06080812592699658, 0.0331082283082651, 0.1052886170509737, 0.027238278053118847, 0.026652899796317797, 0.07009886117884889, 0.04295101382012945, 0.08389133436139673, 0.0232560249423841, 0.0349650966381887, 0.023600253443873953, 0.0851517979754135, 0.06344973007799126, 0.034279348474228755, 0.044140082827652805, 0.07800612555001862, 0.024488923336321022, 0.02662654427695088, 0.07407407130813226, 0.0038288096720862086, 0.06818167108576745, 0.03103906121395994, 0.06151339257485233, 0.055331016701529734, 0.04590251286572311, 0.02262788599182386, 0.014939670218154788, 0.018117333202098962, 0.03906758138327859, 0.07733894221019, 0.047223019937518984, 0.052623417068389244, 0.06017366387823131, 0.027951680494879838, 0.016417200895375572, 0.05773520410002675, 0.05612055421806872, 0.04449785366887227, 0.06821085975388996, 0.032979432289721444, 0.05253912022453733, 0.04625490684702527, 0.0548768334556371, 0.030829359966446646, 0.01040071358147543, 0.026622037585184444, 0.03655601634818595, 0.04159911390161142, 0.021225386444712058, 0.05220929866482038, 0.044712208182318136, 0.05271083464322146, 0.058467388444114476, 0.05679397530911956, 0.0537375254498329, 0.017206760676344857, 0.07790818432113156, 0.09641382959671319, 0.013165761938580545, 0.008105257311399328, 0.04415869218064472, 0.052307570149423555, 0.010112519084941596, 0.11930927095818333, 0.047248245537048206, 0.056332266685785726, 0.04447542967682239, 0.016202230399358086, 0.05947400044533424, 0.024112086721288506, 0.020119478795095347, 0.01041215564328013, 0.04762546806887258, 0.007222027361422079, 0.013293009651533794, 0.00827900335934828, 0.015687426675867755, 0.04841703164856881, 0.08935495134210214, 0.019708369800355285, 0.05633867142023519, 0.0645054796768818, 0.026270333801221568, 0.07239788625156507, 0.06369913622620516, 0.015885283246461768, 0.049611536887823604, 0.01746755136991851, 0.011970651848969283, 0.03825140818662476, 0.01764399141393369, 0.02871858436265029, 0.03789597139984835, 0.003900050051015569, 0.05634768480376806, 0.02299397630849853, 0.10889027456869371, 0.07438839311362244, 0.03514262949465774, 0.07734096827334724, 0.030766622512601316, 0.08789358093054034, 0.01868436927907169, 0.017349470108456444, 0.042410422320244834, 0.04224541691655759, 0.03378630266524851, 0.070033106894698, 0.010957516369671794, 0.05412610655184835, 0.04844541137572378, 0.057431654568063095, 0.021286044029693585, 0.03895391404512338, 0.013003967251279391, 0.03333205633680336, 0.05509319176780991, 0.01229607803907129, 0.04715102790214587, 0.05488335322297644, 0.05432839745481033, 0.042123311359318905, 0.01794379310013028, 0.04193774475425016, 0.0717783191066701, 0.026804242261277977, 0.026832607145479415, 0.032603282161289826, 0.025995969226642046, 0.012236147758812876, 0.028102149080950767, 0.052863019445794635, 0.08107329573249444, 0.020543772043311037, 0.03762927692150697, 0.027172540467290673, 0.024783186745480634, 0.02120022392773535, 0.008872053567756666, 0.024508426977263298, 0.0646728636638727, 0.01665334671997698, 0.006536903065352817, 0.04103317805856932, 0.10240867588436231, 0.05030545609770343, 0.006843179990028148, 0.10050738259451464, 0.020248590226401575, 0.09034491697093472, 0.06363942302414216, 0.060732872152584605, 0.09308172011515126, 0.07025184750091285, 0.026360732954344712, 0.09639157258789055, 0.01051354414812522, 0.050671910066739656, 0.06315021411865018, 0.07324861755478196, 0.03258247234043665, 0.011502771340019535, 0.048627560390741564, 0.08479754862491973, 0.01485679458710365, 0.057131069916067645, 0.03747116235899739, 0.07492173011996783, 0.015575180550513323, 0.030417456873692572, 0.019716685565072112, 0.02785108608804876, 0.037864682453800924, 0.04650148912332952, 0.024448144176858477, 0.053143246987019666, 0.07945930265123025, 0.025843992225418333, 0.05207429829169996, 0.072259267908521, 0.044436455791583285, 0.05010925080568995, 0.027267034420219716, 0.020622387746698223, 0.06452428569900803, 0.0071893533822731115, 0.04437892079295125, 0.02695106690225657, 0.09241527892299928, 0.013167943852749886, 0.03232155548175797, 0.06617261053179391, 0.04565215676848311, 0.054124009984661825, 0.04769084756844677, 0.03173003780830186, 0.060157904372317716, 0.01827062566007953, 0.03755948164325673, 0.06576421408681199, 0.02775614870188292, 0.0164173938537715, 0.09067483129911125, 0.11525098481797613, 0.15104912366950884, 0.1627885937341489, 0.09202634159009904, 0.14454381336690858, 0.13323857390787452, 0.11251925054239109, 0.09409201316884719, 0.21932739269686863, 0.22268483910011128, 0.1708285021595657, 0.13607243512524292, 0.14081410568905994, 0.12894090061308816, 0.12397553931805305, 0.13252997130621225, 0.10421358645544387, 0.126321000570897, 0.1596820674603805, 0.12865652446635067, 0.0980062855524011, 0.11756431849789806, 0.1849122386192903, 0.2710024081170559, 0.11251157673541456, 0.1359971665078774, 0.1906512220739387, 0.20027571968967095, 0.0943705411918927, 0.1388346790918149, 0.17197051900438964, 0.11486830378999002, 0.13922932354034856, 0.1873665358289145, 0.12314854189753532, 0.1482832877081819, 0.20600032032234594, 0.13251489086542279, 0.14767460786970332, 0.21645792323397473, 0.11279472833848558, 0.1961772536742501, 0.12542732118163258, 0.13779564265860245, 0.1521810027770698, 0.18777997145662084, 0.06672656440059654, 0.10843598371138796, 0.15181019611191005, 0.11926023726118729, 0.21994174254359677, 0.27189708198420703, 0.20238453231286258, 0.1365209446521476, 0.15339563135057688, 0.1679286194848828, 0.11816489408374764, 0.15788945427630097, 0.12612957099918276, 0.18589651939691976, 0.10995357180945575, 0.22363581229001284, 0.21092467795824632, 0.09451388701563701, 0.0919927742506843, 0.1526866725180298, 0.14606719021685421, 0.20339162671007216, 0.14486581640085205, 0.2597725560190156, 0.1566683393321, 0.22346652840496972, 0.12916321837110445, 0.14442688057897612, 0.22846722335088998, 0.1343329151859507, 0.12102867127396166, 0.22955331194680184, 0.09541605657432228, 0.15086349769262597, 0.16211576265050098, 0.07785774796502665, 0.12318153778323904, 0.11555150267668068, 0.17851177894044667, 0.08831460872897878, 0.15791882848134264, 0.0601610065496061, 0.132599035569001, 0.1236190041527152, 0.13081574375974014, 0.11385138335754164, 0.08705898391781375, 0.13123058946803212, 0.12599764682818204, 0.126990937278606, 0.09504447807557881, 0.12101175030693412, 0.10134241747437045, 0.1326632165000774, 0.2668131922837347, 0.15544784779194742, 0.1719595055328682, 0.09227399626979604, 0.1126936923537869, 0.2758597646607086, 0.14044671290321276, 0.13542741973651573, 0.07776464553899132, 0.1033798503340222, 0.11063463331083767, 0.15199929533991963, 0.1333753517246805, 0.24386126606259495, 0.21964641229715198, 0.19008803588803858, 0.11262704007094726, 0.15669615502702072, 0.1146710260945838, 0.03909543789632153, 0.13102954166242853, 0.1154254785797093, 0.20291654829634354, 0.14102425222517923, 0.13934636022895575, 0.15061596175655723, 0.17177450296003371, 0.12485484330682084, 0.20449891104362905, 0.12227847764734179, 0.11872701899847016, 0.18857260001823306, 0.1286818168591708, 0.102607400767738, 0.08071109055890702, 0.12174832445452921, 0.19271559489425272, 0.08054634119616821, 0.10820945055456832, 0.1658751562354155, 0.21800234739203006, 0.1727344561368227, 0.08484641162795015, 0.1278741523856297, 0.14303266711067408, 0.1478221913566813, 0.09317180200014263, 0.14317827648483217, 0.3253047005273402, 0.21870428550755605, 0.14446375047555193, 0.22628378035733476, 0.15357900119852275, 0.11931252898648381, 0.13466627307934687, 0.1387974084354937, 0.17704995581880212, 0.10557382440310903, 0.20711941964691505, 0.09203023786540143, 0.1374780628248118, 0.19282074237708002, 0.11198408043128438, 0.1987335813464597, 0.15220717090414837, 0.12487393134506419, 0.14881801995215937, 0.16622093768091872, 0.1548255718080327, 0.11697232213919051, 0.16631631850032136, 0.23333743389230222, 0.1610166864702478, 0.13240279688034207, 0.09774156147614121], [0.02142905959772179, 0.007579673892905703, 0.036300480060162954, 0.038799577014287934, 0.04249128673109226, 0.04083318039192818, 0.04759920346259605, 0.07344318641116843, 0.0236270227105706, 0.03204549509973731, 0.012285941229492892, 0.07406633070786484, 0.011404782799218083, 0.07382887313724495, 0.022253244278545026, 0.02822396705596475, 0.02324479810340563, 0.041596564624342136, 0.03391157719306648, 0.09019136661663651, 0.031900000758469105, 0.031024214549688622, 0.012017101944366004, 0.006540678741657757, 0.03544869119650684, 0.015612761053489521, 0.022148334282974247, 0.018001968201133423, 0.0026873232309299055, 0.0663215818349272, 0.0334602363727754, 0.026352207532909233, 0.05855885072378442, 0.017308138048974797, 0.03765659908822272, 0.05344648481695913, 0.06670268950983882, 0.02620582075905986, 0.027164438070030883, 0.008190137668862008, 0.005633280752590508, 0.050926923140650615, 0.03370783168065827, 0.07149710450903513, 0.030135717206576373, 0.07892415480455384, 0.01193460388094536, 0.0180303238084889, 0.033074453167500906, 0.026826361972780433, 0.07676743654883467, 0.028269323411223013, 0.026586485000734683, 0.02227260691142874, 0.022716492858307902, 0.046260892268037423, 0.047658193070674315, 0.02251260262710275, 0.014173170820868108, 0.0902649134513922, 0.09545300810714252, 0.04379069454444107, 0.06265520161832683, 0.05187899470911361, 0.024653668988321442, 0.05192826960410457, 0.049019147190847434, 0.06689695408567786, 0.031928666212479584, 0.0019628017935247044, 0.047420104674529284, 0.047667889230069704, 0.09172698148177005, 0.01756327172188321, 0.0508338615327375, 0.03824895538855344, 0.021702522462874185, 0.06642477004788816, 0.033662033747532405, 0.04961147380527109, 0.06744872604031116, 0.041808841124293394, 0.027053622434323188, 0.006021351164235966, 0.005088502148282714, 0.0239998572942568, 0.020250404777470976, 0.10713344774558209, 0.04578668958856724, 0.04857932079175953, 0.03086428543610964, 0.048388303112005815, 0.023629208335478324, 0.019701015116879717, 0.018390037221251987, 0.046969669274403714, 0.04899486040812917, 0.05364588876545895, 0.013723255851800786, 0.002820229124154139, 0.039504810265498236, 0.017726137884892523, 0.03729033065610565, 0.10819968389114365, 0.06473623565398157, 0.04946557128278073, 0.04842334732529707, 0.04832247461308725, 0.04823771021619905, 0.05554463277803734, 0.015563667984679341, 0.016838557094160933, 0.0114819309055747, 0.058559399913065135, 0.05956799344858155, 0.01824339255108498, 0.024991899081214797, 0.030380564712686464, 0.021764567864011042, 0.03586150342016481, 0.03608376922784373, 0.003884885190927889, 0.028778564737876877, 0.006166924358694814, 0.05051174717664253, 0.037742981367046013, 0.06273899751249701, 0.031329849516623653, 0.03218127843865659, 0.05233668089204002, 0.023267047690751497, 0.07691627426538616, 0.04342381755122915, 0.006452948537116754, 0.023084124986780807, 0.005839930845468189, 0.03070816910621943, 0.03311820648377761, 0.06418834513169713, 0.030158464032865595, 0.029969802671985235, 0.036059155900147744, 0.03110339614067925, 0.05974889194476418, 0.012124012027925346, 0.044300950758042745, 0.03780299884965643, 0.024022539182624314, 0.043879871009266935, 0.0469950581464218, 0.02125518181856023, 0.09552307426929474, 0.03643158786871936, 0.052494190604193136, 0.038901206717127934, 0.05034080088080373, 0.025273635037592612, 0.06138667456980329, 0.03592829300032463, 0.007671524872421287, 0.020274309354135767, 0.07356998234172352, 0.0461366047966294, 0.020358079273137264, 0.010065929836855503, 0.08110649941954762, 0.01751273146510357, 0.05508090922376141, 0.05365264602005482, 0.07009777764324099, 0.016149821785802487, 0.06020692322636023, 0.05227979156188667, 0.0641587408608757, 0.033312322630081326, 0.020951179576513823, 0.009377024762216024, 0.061168950705905445, 0.05190922238398343, 0.08264143150881864, 0.0536911152448738, 0.040475268542650156, 0.009325379633082775, 0.04120112607779447, 0.030559852748410776, 0.04105598425667267, 0.05308588639309164, 0.03910737163096201, 0.05154137317731511, 0.05660272014210932, 0.1112349343020469, 0.06023477602866478, 0.060535327284014784, 0.011370209849701496, 0.05690040299668908, 0.08203734556445852, 0.022134803075459786, 0.021981453101034276, 0.036083130980841815, 0.05576946270593908, 0.05107708559080493, 0.014880754824844189, 0.02662841263372684, 0.04813953892153222, 0.005873433710803511, 0.07360651085036807, 0.03930457511160057, 0.03879041891195811, 0.019026677473448217, 0.017144227313110605, 0.04994056434952654, 0.0402751632645959, 0.02938817040558206, 0.025959613267332315, 0.08147055996232666, 0.0347648689057678, 0.028327693325991277, 0.013324516603461234, 0.046015508560230955, 0.1254687923938036, 0.04138999152928591, 0.013020771330047864, 0.044857925167889334, 0.03356080109369941, 0.05653528118273243, 0.023691272290307097, 0.03505082211631816, 0.025647998445492703, 0.05250068068562541, 0.022076141867728438, 0.044517301648738794, 0.015416557616845239, 0.0331373538938351, 0.03578501025913283, 0.010592709040793125, 0.03355251501488965, 0.02261313024064293, 0.041405045994906686, 0.02951362490421161, 0.03878018840623554, 0.03907960417564027, 0.019353309653524775, 0.03382588140084408, 0.008093919150269357, 0.07035856833681464, 0.005515853972610785, 0.1063731248723343, 0.014028904734004755, 0.08669311253470369, 0.02917663976404583, 0.06686867083772086, 0.07915597947430797, 0.022390053636627272, 0.07122597569832578, 0.03161323118547443, 0.07049590276437812, 0.04169845407886896, 0.04312861346988939, 0.005569302984440583, 0.021421871897473466, 0.05845831197802909, 0.022298077419691253, 0.020933397718181368, 0.0659609648573678, 0.08434322066023014, 0.028223390036146156, 0.016250954249699134, 0.06398487792466767, 0.01839658110839082, 0.03677871631225571, 0.08145736457663588, 0.08422184982919134, 0.03077210141782416, 0.07410580554278567, 0.020689487173513044, 0.03121127658232581, 0.048229513195110485, 0.01957587603101274, 0.005455425525724422, 0.02336187746550422, 0.04025998634460848, 0.023862821581133176, 0.034610446527949534, 0.0035193591384086176, 0.07299227974726819, 0.03624158322054427, 0.01505487751273904, 0.021375947799242567, 0.04200899835268501, 0.01666665713855764, 0.06438847267418168, 0.039420105240424164, 0.06577327570994385, 0.027384438471926842, 0.05979032976028975, 0.03984956012573093, 0.029345142538659275, 0.09208968389430083, 0.021829843462910503, 0.052822327488684095, 0.06700675483443774, 0.019425283135205973, 0.06913478908245452, 0.01568650270201033, 0.08343481706106104, 0.05831157825014088, 0.02935178290499607, 0.062297820404637605, 0.02153211422410095, 0.026650957224774174, 0.01618474540009629, 0.025773753513931297, 0.00516819350195874, 0.01922509807627648, 0.009951856172847329, 0.05396077460318338, 0.024208471295423806, 0.03494613105431199, 0.048695990117266774, 0.024909561507229228, 0.03929280093871057, 0.07045486941933632, 0.01530096440546913, 0.03914890221494716, 0.033782907339627855, 0.008139066776493564, 0.04902991575363558, 0.02278217663842952, 0.03823903658485506, 0.03598790230171289, 0.050579438466229476, 0.01917457080708118, 0.04926716923364438, 0.009606678650015965, 0.041815175354713574, 0.0587126942264149, 0.03184275519743096, 0.03485256478597876, 0.04059112892718986, 0.015053456299938262, 0.015093199235707289, 0.06372252872097306, 0.05398792236519512, 0.052514614508254454, 0.02977792039018823, 0.07961907220305875, 0.017587302463653032, 0.02772758529317798, 0.03677459368191194, 0.0099440719714039, 0.05609864601865411, 0.04934473479806911, 0.13736308930674568, 0.15152568637859076, 0.15476057451451197, 0.15023641259176657, 0.15018367557786405, 0.09774180638487451, 0.07442255417117849, 0.10891000085393898, 0.14375676575582474, 0.1611164608038962, 0.12634774757316336, 0.18766530964057893, 0.19454124849289656, 0.15626789128873497, 0.25654899305664003, 0.19055308046517894, 0.15780085668666288, 0.08542173192836344, 0.22579467535251752, 0.30923655023798347, 0.11915399882127531, 0.10334486549254507, 0.1113115758926142, 0.1311181837809272, 0.16454084892757237, 0.12291039412957616, 0.06659971651970409, 0.13580555882072076, 0.12542411510366946, 0.1289480400737375, 0.14697844366310164, 0.14089189760852605, 0.14895402593538165, 0.08970531183877029, 0.18455682409694418, 0.16568426101002842, 0.13146907120244578, 0.07422238209983334, 0.13059563760180026, 0.11608822387643158, 0.06878888147184625, 0.07004604995017871, 0.10653213743353263, 0.19581434346036986, 0.1258699528989382, 0.1881051211967133, 0.10539890761720017, 0.18110883567715064, 0.1030584707041271, 0.128423445567023, 0.09113724125199951, 0.16537337534828112, 0.1514833394321613, 0.10042469250038266, 0.14339715067762882, 0.1479986443882808, 0.14586430188501254, 0.054436695354525, 0.10945038084173575, 0.15393961075460538, 0.12953543511684984, 0.17900340724736452, 0.14848369726678357, 0.285607815021649, 0.11428580692154355, 0.1771698275115341, 0.11611189838731661, 0.1722634892212227, 0.11372991604730487, 0.08667444752063602, 0.2243520738556981, 0.16073747567133978, 0.23726526531390846, 0.18008455313974991, 0.17488135577877983, 0.21179906150791794, 0.05993123762891628, 0.1446976012084633, 0.12070747718098573, 0.21081543382024392, 0.15436722140293568, 0.14378392836079001, 0.10946517926640809, 0.09521921674604528, 0.19596982339862734, 0.07840343430871144, 0.09256911871489137, 0.15520069777267054, 0.11344794445903972, 0.09756378742167726, 0.1031726723886095, 0.16828467225423083, 0.10349796313676052, 0.0870051930542104, 0.15602699015289545, 0.15783361508511007, 0.15296336001483724, 0.14747508888831362, 0.12860050715971738, 0.11154006089782342, 0.15506507770624012, 0.09797493723453954, 0.14183264400344342, 0.1846108672907576, 0.14471352769760415, 0.16756922705098987, 0.14940259483410046, 0.12618500943062827, 0.10920597676886246, 0.14050232945010066, 0.11916547242435627, 0.08241791147156619, 0.09502469983999617, 0.09956473630154505, 0.14392364508239552, 0.11875312033225782, 0.14719077211339027, 0.11497215993585996, 0.23213580774609, 0.19063434563577175, 0.17374824470607564, 0.16327297867974266, 0.0960412788845133, 0.1158793389913626, 0.09283117105951533, 0.1916428204276599, 0.19298411876661703, 0.11420030408771709, 0.14434742624871433, 0.10734674098785035, 0.17684314894722775, 0.14976376842241734, 0.14144972548820078, 0.10963258551782928, 0.15288631024304777, 0.09043237907462753, 0.10851131912204437, 0.13145606877515092, 0.10568815967417322, 0.15489947487367317, 0.1032518150168471, 0.11137213514302857, 0.21132386435056105, 0.17249717668164521, 0.09457907726755366, 0.150393451040145, 0.16983104083919898, 0.0665930965624284, 0.11260126528213732, 0.08723915510927327, 0.11283303800155409, 0.192621297610458, 0.11244545879890211, 0.1731559366453439, 0.0813192360510584, 0.12205407445435412, 0.14007569843670353, 0.13629297172883525, 0.117653079360025, 0.09304299484938383, 0.1472009692224674, 0.1072459424904082, 0.09819896193221211, 0.12891042802948505, 0.09653591288952157, 0.16081992827821523, 0.1134026882937178, 0.13661353499628603, 0.14229302789317444, 0.2518095192499459, 0.20047031081048772, 0.13057644566288218, 0.0916469185904134, 0.2136972377775237, 0.14018657529959455, 0.10564891490503214], [0.01474791873988579, 0.04138615091505926, 0.11387188147637062, 0.06141306534118485, 0.04137627292948309, 0.05757228784204926, 0.008665845980431186, 0.016819914344523568, 0.02245745919935871, 0.042202149707009085, 0.023084432978066616, 0.04590347765770275, 0.028537103280541487, 0.013045883752056397, 0.03840014571323991, 0.05586375256825704, 0.038012432924006134, 0.050732580639305525, 0.05208316695643589, 0.014929219851183007, 0.03849745240586344, 0.06813694184529595, 0.008823615444271127, 0.09386896810610779, 0.021730648004449904, 0.04877717736235354, 0.009893877740978496, 0.0137143779102189, 0.03781279890972655, 0.027942826673097443, 0.04854016508033965, 0.008268920355476439, 0.04255710409779567, 0.06048436029232107, 0.008344716825376963, 0.036144168916507624, 0.014819442294538021, 0.026217218292003963, 0.06534709740662947, 0.0050235234084539115, 0.02581982233095914, 0.03296648181276396, 0.09181882225675508, 0.012963340232090559, 0.06233025967958383, 0.04452481218322646, 0.10145353924599476, 0.05321607393852901, 0.12061564382747747, 0.04673482777434401, 0.07873492198996246, 0.06062658918381203, 0.025691788869153243, 0.06911049858899787, 0.049028420326067135, 0.011307721015327843, 0.07047464765491895, 0.061654649252886884, 0.016162738866114523, 0.08363265878870152, 0.011043461709050462, 0.014960058870201465, 0.014247782637539785, 0.1138528082810808, 0.0074108301942032995, 0.02151634358597221, 0.03759313804039266, 0.0009957983297681494, 0.05517914360098075, 0.008462453915853985, 0.02543213366152486, 0.04590073171129916, 0.04306576469389256, 0.07812944080797024, 0.03451785247307271, 0.014304991091194097, 0.018937441636808217, 0.03646584169473499, 0.060229625523788854, 0.0170037795760436, 0.026396986868348904, 0.045035009025014006, 0.07047347506158985, 0.046076765429461375, 0.006814192629462923, 0.025277284548792522, 0.04277915468264837, 0.017501846014056355, 0.05253972136415541, 0.06573719991138205, 0.06936627236427739, 0.03878168383380398, 0.016633381092105992, 0.027311810044921003, 0.05294253314787056, 0.039258150063687935, 0.04526500059000682, 0.03165929258102551, 0.01045506291120546, 0.018856258102459833, 0.04025111396913417, 0.06883982248837128, 0.05560098776186351, 0.02359583209909033, 0.06104573192715179, 0.03217489967937581, 0.09487543167779222, 0.02843401896825526, 0.05260580590402242, 0.034695103313424625, 0.025748769112396985, 0.024604887621535454, 0.028154900937806815, 0.015142617921810597, 0.09742736583575606, 0.029464969702530652, 0.08715679156011902, 0.0384115228371229, 0.022664429343421943, 0.05804460175568238, 0.049004192915163, 0.030760516492591705, 0.031147214394877665, 0.03222627485229168, 0.023410018729919102, 0.03714225364092272, 0.028953004693903495, 0.011826056434074417, 0.006693123295917758, 0.080576442705933, 0.04175672380370088, 0.15678170981118456, 0.0280216260580346, 0.03350927378050983, 0.01716734706860734, 0.0016602229675299895, 0.04263372342393268, 0.04314882586186286, 0.053104273101780564, 0.024432523823634256, 0.018851679051294923, 0.013370327524171444, 0.03608660423196852, 0.09063114848686382, 0.05192741613427643, 0.048695704390411265, 0.02954238312668167, 0.026918545991065912, 0.01561939214298036, 0.01334431895884336, 0.036050264970981516, 0.06773976667318493, 0.01393350814396399, 0.009293865259678569, 0.06622054585022852, 0.07418663284624927, 0.09203201159834862, 0.05734154299716465, 0.034131976499338634, 0.05663124829879962, 0.032003730739234015, 0.05406838230555877, 0.039671700724284165, 0.024350698331545573, 0.11037534175557084, 0.015210477122309385, 0.0034464628424757393, 0.014996087356848875, 0.04410319437738508, 0.033835421709227376, 0.01571573218825506, 0.0226468218897935, 0.0038345617804225185, 0.022614675763179548, 0.01819572069507558, 0.06509555387310684, 0.0167437514392077, 0.02004549780394882, 0.052365305527928285, 0.07642455690074712, 0.06956526442081667, 0.045196459541330114, 0.017263288209505845, 0.045852688781451434, 0.026443295028002467, 0.04847390984650701, 0.049093900015577674, 0.02930446542450227, 0.022857486073917244, 0.08384015585761517, 0.06490818384918384, 0.06812021383666433, 0.07838701800210401, 0.04071585055498872, 0.04145423925365321, 0.03271722038334701, 0.04152808294747956, 0.1422449664096348, 0.03133531172352377, 0.07856983866076916, 0.05271443777019158, 0.07484963789465837, 0.019541605506674387, 0.031170499278232455, 0.04732444554974791, 0.04878853593254462, 0.017604036038392223, 0.0660214498930145, 0.021570000862993766, 0.0493203700898448, 0.052437267877394333, 0.06922725326148793, 0.03779515805945266, 0.06049435331078712, 0.02467515045282198, 0.0490880964207463, 0.03253493778174743, 0.012370238073344808, 0.036908399197272956, 0.028984816854062956, 0.03445477363129612, 0.02817339525790885, 0.044488131534308195, 0.025548964404151775, 0.11114365755929612, 0.013077738585707266, 0.02043410117039457, 0.04893606004770845, 0.03181361476890743, 0.07982974566402845, 0.0802900330745615, 0.01860238608060172, 0.027316734194755554, 0.02964646933833137, 0.008719352044863626, 0.021901651816733647, 0.009860003337962553, 0.0657847938418854, 0.05074254768260289, 0.060396163462428376, 0.010349452513764845, 0.016672714918968268, 0.033453794530942105, 0.03327795377117582, 0.01394194265230908, 0.019745352874451783, 0.015513749276578892, 0.011767535306717036, 0.015329793131968472, 0.03789004906138871, 0.025637842154537793, 0.05524387743207626, 0.05744194073486142, 0.031197606222121976, 0.024258334342448507, 0.011339885695633711, 0.02861655204469571, 0.08713716917554848, 0.07800547246006317, 0.04586165021464694, 0.11262998639722355, 0.027701931103365496, 0.024393594467255753, 0.0320774779538624, 0.030013544856046792, 0.06950339156901464, 0.04144627229834441, 0.0221872970359982, 0.02352719457121566, 0.015666819090256467, 0.0406910665333271, 0.010846551376744173, 0.01219162631969084, 0.0359572033630684, 0.019443185592535883, 0.04342641506809741, 0.0045304033847060055, 0.0331533768621739, 0.016845457212184556, 0.038406535604735836, 0.04730206979729701, 0.01886199119326193, 0.0774590291257482, 0.01076647457011859, 0.05976549749902915, 0.046253481923486106, 0.09270056048990227, 0.012691557403741172, 0.06569225544808432, 0.08512451662681997, 0.06425861167372204, 0.013276106310513569, 0.021856638704775833, 0.020523253515420947, 0.0401477068226086, 0.05608102001133375, 0.027823778764286544, 0.05708104174118489, 0.07804496955941431, 0.028860178717877716, 0.022546782238350715, 0.05097862856928259, 0.013167412289476488, 0.04122398422623519, 0.04246944532496855, 0.017903154948726296, 0.033157262005261146, 0.0012429062553565018, 0.05575520233833231, 0.044254874519538134, 0.06153226910100784, 0.03648173478723038, 0.05073145257483702, 0.0157483458679053, 0.04856006948102731, 0.02576914292149013, 0.0022001879324307083, 0.03171642681991216, 0.023689997651672456, 0.027623996320471633, 0.013112924734741682, 0.029433977615553886, 0.037955710577080026, 0.019208579724363517, 0.03733704885235056, 0.026579237928672228, 0.061459505232051015, 0.03712707301019691, 0.04071259252668824, 0.02753153214143822, 0.05331861648301128, 0.015788405144121498, 0.042898555111605674, 0.059748780622612685, 0.010882361857511569, 0.059590231903712265, 0.026516943908063695, 0.12491908360971138, 0.03843183541903272, 0.03675177264085505, 0.024184095454984345, 0.005187487022340065, 0.012772185255016666, 0.019346392837178428, 0.01993314035644289, 0.04659350430301856, 0.0283175518779899, 0.03635957727965433, 0.07552877723355778, 0.048944190275506116, 0.05193672637687996, 0.0077660322767769685, 0.11170053548994474, 0.112342879147036, 0.2051492253667675, 0.11923933096113615, 0.12919336440972984, 0.16749407717725262, 0.07323531826841645, 0.11696308982209302, 0.07367020938545465, 0.08710101174074225, 0.1252962727448903, 0.17122617457062006, 0.08633136007119901, 0.14104460191447288, 0.14384536334546283, 0.29305924486834556, 0.20967985881725326, 0.17322906787740067, 0.11723530216841027, 0.09822748266742565, 0.13031503156526014, 0.2152455211034976, 0.09996417502406985, 0.18546625185990706, 0.13596716889878735, 0.23755013127811253, 0.14037022716365755, 0.12527141079772264, 0.15707105834735557, 0.20810565969441086, 0.19523382070474327, 0.17273629666306078, 0.05987201053358149, 0.1671865608659573, 0.1443591818679124, 0.09281990525778383, 0.08859186025802046, 0.11247995382291265, 0.1837134623201564, 0.18108671967638656, 0.14388946176040918, 0.052222226877347566, 0.13004858570639044, 0.1145917053509038, 0.21787269419291988, 0.08255962457042187, 0.2446180785773322, 0.10330015851650387, 0.34153499524109066, 0.12952232878888026, 0.20351163198938593, 0.14172801602398977, 0.12159334917669185, 0.1977876399178058, 0.2671391435433179, 0.13779804721707478, 0.15636563213774934, 0.10742855534772389, 0.13126643520081416, 0.1807481370633468, 0.07201660046121106, 0.1536729422514327, 0.1925550535088405, 0.19822604139335454, 0.10678357706638053, 0.15791115467436612, 0.12682943110121414, 0.060209554139873944, 0.1281582613592036, 0.12000524220638908, 0.11095338573795743, 0.10390912779257633, 0.12226387960254215, 0.1516074562096037, 0.10915315069723874, 0.11734528103261255, 0.08366097172256559, 0.13645017344970256, 0.17135487782070413, 0.1131821220042184, 0.1895104965660721, 0.1027682761196047, 0.15402023767819628, 0.10775809860206209, 0.21635693177813664, 0.08123643463477492, 0.1235710465698503, 0.09466146308113821, 0.1437572852591984, 0.1631342267501168, 0.12007675555651076, 0.07928943989099935, 0.07909864114481024, 0.1116732986702118, 0.1413265141309239, 0.11445399242802523, 0.11557813093531877, 0.10179011063883081, 0.10976057630614378, 0.1176893110095989, 0.14059325738344342, 0.22909671301022172, 0.14162646053591743, 0.178162420343142, 0.25172292545903474, 0.17129268584540114, 0.19864585949108005, 0.20778658072231337, 0.15839337254874408, 0.15210322570055723, 0.12320815119892359, 0.10092571639688686, 0.12558519083540887, 0.20042569289216772, 0.1672183396294713, 0.15100680640898645, 0.15763615927426144, 0.20251687208656222, 0.16638771310681477, 0.20467134163482115, 0.10656458412995562, 0.19910467002773657, 0.12431026276317425, 0.248584471992217, 0.06795161272748373, 0.17640373815083876, 0.0724225775047671, 0.1640716483234428, 0.16570738633163273, 0.15833658340852708, 0.09852739938651212, 0.2477227643248625, 0.1380575614166446, 0.2076477397349663, 0.14737911435076967, 0.06463621641159989, 0.13300530205015093, 0.13038123113801703, 0.15072811511345208, 0.15122551732929423, 0.14053796738153324, 0.13269573741126806, 0.09439558867597952, 0.11807143542682752, 0.17911513015860692, 0.21331826748792082, 0.14867672987747937, 0.10407969559310004, 0.1155520073371008, 0.0823379895882681, 0.17543376598041505, 0.17252117773750797, 0.10523964272579178, 0.07969805155880749, 0.12947600393090397, 0.13373199821216986, 0.12838694674428552, 0.12164656858658418, 0.06401267877663486, 0.11847298184875399, 0.09680949078756385, 0.1962214708328247, 0.07041172837489285, 0.15778614731971174, 0.17791181191569194, 0.08854858562699519, 0.07840196485631168, 0.10050568307633512, 0.11727584569598548, 0.22288510022917762, 0.08447933054412715, 0.0702820454898756, 0.1887188624823466, 0.1999009054270573, 0.11825722467619926, 0.09483748566708528], [0.047092242384678684, 0.039115516701713204, 0.024579619348514825, 0.04868574105785228, 0.026598706317599863, 0.015793976817803923, 0.049051612440962344, 0.024007406791497488, 0.0384561407554429, 0.06407783934264444, 0.01903245509311091, 0.03278103395132348, 0.020236162963556126, 0.03393883627722971, 0.007878199085098458, 0.05581609184446279, 0.023294312341022305, 0.03777081932639703, 0.015192513437796151, 0.049764244904508814, 0.028443987866921816, 0.048256842783303, 0.10147587046958506, 0.06213405809830874, 0.03292656168923713, 0.04525812830252107, 0.045855627686250955, 0.06468004023190588, 0.015875472054176498, 0.04240377638780046, 0.03295634036476258, 0.04298944222682621, 0.0037367882305261446, 0.01453862845664844, 0.0187016297786613, 0.03893980581779033, 0.0036797226402995875, 0.0369147408491699, 0.05150665921973996, 0.06920967920450494, 0.021543021939578466, 0.021847885072929785, 0.06060442865418736, 0.02447431230393704, 0.008029819855437381, 0.0395334349013865, 0.08117718156427145, 0.05402774600952398, 0.036855677026323974, 0.03678856090118643, 0.10570474667474627, 0.01964356175449211, 0.021411370507848915, 0.016726175526855513, 0.03784528642427176, 0.03049549926799955, 0.04258956192643382, 0.017862735730886925, 0.09079586074221879, 0.027751324741984718, 0.028241390828043222, 0.047716295812278986, 0.018044894022750668, 0.04262760441633873, 0.0564287904126104, 0.023821105460228864, 0.008696062523085857, 0.10311533405911177, 0.05663517797074746, 0.024024765625654254, 0.051698393072001636, 0.07173948994022794, 0.017930649664776865, 0.045908691245131195, 0.029893101709603798, 0.03885870763042476, 0.07083193238941021, 0.005487246498887544, 0.06443354330258444, 0.04320955580624286, 0.019984808677691035, 0.02972153015434742, 0.012444378626241814, 0.010894470924540656, 0.027882467802555766, 0.06637662692810409, 0.05230952570855152, 0.0370666102389805, 0.09510487405350432, 0.057000177330337465, 0.06297475556493737, 0.06721003650454804, 0.03152680066705216, 0.02780917515337933, 0.03493120275379624, 0.020328109494585078, 0.008872896833054256, 0.042149980436079204, 0.061336219660006464, 0.04594289683154784, 0.1292207051301375, 0.08796144291409291, 0.00993686386209447, 0.02163173270673724, 0.06368424132233486, 0.1210532066761516, 0.021216948225628585, 0.017125877711805515, 0.041411276324652135, 0.07617669441970065, 0.021487004632945172, 0.07581981786643155, 0.02760688239504816, 0.0419002440321492, 0.09497317252680659, 0.023205670222523622, 0.03249280976888258, 0.012152289709774777, 0.0373677811876405, 0.12312093400396407, 0.0469651124876691, 0.018634778971318156, 0.0302298159658676, 0.02541286750783911, 0.0036404978163773194, 0.008084539331321139, 0.08543911302695051, 0.04561690104310401, 0.014944570248189848, 0.08919202024117112, 0.027938627972616814, 0.02282800054672407, 0.04723228565126192, 0.01989506261452334, 0.0625101785408333, 0.012831252788600978, 0.03755293961148709, 0.006937055177331786, 0.018368847049714532, 0.044190771513967775, 0.0021146034623598098, 0.02481201918271836, 0.011837353777082171, 0.06225257908226922, 0.01708161973510869, 0.005738013560403488, 0.038538630469702184, 0.06616102560656145, 0.09462069690926, 0.08462909594527446, 0.03767733840504661, 0.06312302924925461, 0.03171139505866449, 0.032099438103614375, 0.026818203914444894, 0.035644469753606245, 0.06934696168173105, 0.009349165466119302, 0.044354852943797596, 0.04384306048450526, 0.020167488328297623, 0.043782282300526276, 0.01929028090671636, 0.014118868803052465, 0.0767638000252191, 0.05087379278847948, 0.04178262846835423, 0.04008339601568878, 0.005647982234222582, 0.033915005915332586, 0.032637190888635814, 0.025118418561760336, 0.07482015978894196, 0.01717064962576842, 0.03815070987911895, 0.008822589425108163, 0.04237611654389184, 0.031373090751003474, 0.0345019185624551, 0.06604937691008672, 0.07372005202341825, 0.027722277081920765, 0.03803698687988799, 0.017212187631230336, 0.04540977504802868, 0.036372561153257266, 0.010389470971858827, 0.06778913433663547, 0.025325049173261505, 0.06710458474117331, 0.0761193635116797, 0.007956681201903848, 0.06589198965230025, 0.035596089146565646, 0.03495530771033373, 0.02679151813936187, 0.02816981439536903, 0.05069553262728732, 0.023189938547147904, 0.04262891430698801, 0.07449702869052999, 0.048608913930365816, 0.01663283746893285, 0.0387207497988129, 0.0480826866987627, 0.030078234158281703, 0.040452280518366024, 0.033511875008116476, 0.07849088156945072, 0.06501238880446181, 0.01807435543014435, 0.12497557589085773, 0.007521521984017454, 0.01599541981704533, 0.02587621442216914, 0.06562176626175642, 0.01045571136273793, 0.05997205946187023, 0.04587461182381958, 0.07846929249353707, 0.07855312549509108, 0.023927924630697817, 0.05971452308585867, 0.03458496859821025, 0.015954280715959612, 0.011250372481299564, 0.0411895671277307, 0.05183675166335888, 0.0751238688826561, 0.045031658228253946, 0.05929844541242346, 0.039682476708549075, 0.030524044123012573, 0.03135214363283012, 0.055701845631119795, 0.055775325672584586, 0.021400408986664843, 0.032279872757499106, 0.022129463322926313, 0.026957302798109595, 0.040600743450340815, 0.04134583745326381, 0.035358883906155825, 0.05724113041651435, 0.022470929179689847, 0.01288676357944496, 0.027282077753625344, 0.041543475090293214, 0.0697479143855162, 0.04079534570337273, 0.035345020587556064, 0.031226650171447545, 0.06521155897644348, 0.03613837274315301, 0.05539140525797848, 0.10703370309784077, 0.04046963935252279, 0.09236785568646155, 0.049276342178927734, 0.04132478643441573, 0.023212811538542155, 0.059457502502482384, 0.06871348668937571, 0.06515016852063127, 0.04788802136317827, 0.02478708302078303, 0.011552949799806811, 0.03462959393800702, 0.009382663229189347, 0.016531825604033656, 0.08798474635113962, 0.0242526476358762, 0.03004498779773712, 0.023814791638869792, 0.07183947207522579, 0.039529653658973984, 0.038090985544840805, 0.033214466748177074, 0.022286466519290116, 0.04685569023422431, 0.17278165672905743, 0.021715443253924605, 0.023360400591627695, 0.1113377588626463, 0.04899156898318324, 0.02084588551952038, 0.06261233516852371, 0.01773775991750881, 0.08654659031890333, 0.0555548002012074, 0.06537123947055079, 0.03847794505418278, 0.027446988533483818, 0.0175202716854983, 0.012542548993224045, 0.05265881380182691, 0.0559210389474174, 0.03170618147123605, 0.013025727021158673, 0.029217348419479094, 0.0026625153213899466, 0.027019192348234355, 0.07340929994825274, 0.008739178520045243, 0.0959001446608454, 0.06793601278332062, 0.03415808896534145, 0.03173398603394162, 0.032880604194360785, 0.017988776526181027, 0.03726884919160511, 0.06790218569221906, 0.0473668518679915, 0.027896214232896455, 0.013114380271872506, 0.02472786705766339, 0.036063805455341935, 0.02352717045141617, 0.047293067545979284, 0.01662411723373225, 0.017457237372582313, 0.032930706584011205, 0.03440725391556043, 0.06305747534497641, 0.03044039294763934, 0.040772932843538, 0.05706907460989896, 0.055491172170150094, 0.00884009854416945, 0.02577846244093962, 0.05895566595427226, 0.028021117686876096, 0.05057766102254391, 0.04553464139462449, 0.03261071477027144, 0.05145289433130529, 0.082485320745036, 0.06725955259753391, 0.02216368004155811, 0.050661776040215045, 0.054834876136737876, 0.04733370755275246, 0.032163381547434255, 0.07713172715739347, 0.02767805435723858, 0.005330804087861907, 0.07564752828329802, 0.03471361989795696, 0.03894213987223338, 0.008247001023846678, 0.024303328900714405, 0.04213022817566525, 0.13532237615436316, 0.1339611437288113, 0.09129448750172742, 0.1658008375670761, 0.13605690939584747, 0.2090343090821989, 0.15937849937472492, 0.07423554037814029, 0.18294263805728406, 0.12203620353830047, 0.10213236688286997, 0.1467779598897323, 0.08304910064907745, 0.1852254694676958, 0.11085678037488833, 0.16147433925652876, 0.19167912629200146, 0.13036978722084314, 0.10890452380408533, 0.09834435608354397, 0.11442467017332092, 0.18841714976588264, 0.23192675958853215, 0.13350380264455453, 0.179139056999702, 0.1811883642221801, 0.2122675348073244, 0.14745289867278188, 0.16657071188092232, 0.1971518123173155, 0.17378980497596785, 0.20216684555634856, 0.20267937274184078, 0.1889043251867406, 0.09573379225912504, 0.18145141104469076, 0.13511172495782375, 0.13740567374043167, 0.1499058451736346, 0.15986524434993044, 0.06234156258869916, 0.10929277836112306, 0.11056812203605659, 0.08866888034390286, 0.18359649984631687, 0.11797248487710021, 0.21621050604153425, 0.14400424232007936, 0.11839859638712369, 0.1408541965065524, 0.2136920575867407, 0.11479285705718212, 0.21943337138509378, 0.10843497439054772, 0.09341884811874479, 0.17209914803970605, 0.12154317257227376, 0.1262431195937097, 0.20426710863830522, 0.17226040188688785, 0.09228392620570958, 0.1478891182341613, 0.14994543133070692, 0.11023628554539755, 0.15776581247337162, 0.1134249972528778, 0.1005606391117908, 0.18692605633987114, 0.18470428884029388, 0.10118840698851272, 0.15859047212870792, 0.20516222779406235, 0.18401150882709771, 0.14443174906773493, 0.2171726559754461, 0.13110734842484817, 0.10424319814774208, 0.1040764078788925, 0.2675253275083378, 0.15316090488340706, 0.25817530578933656, 0.11041093515814282, 0.2043479582061991, 0.1809543650597334, 0.17741262854542583, 0.14556082285707816, 0.22636188397882506, 0.10190949993557297, 0.28702591080218554, 0.12966216425411403, 0.17929358698893338, 0.1835439112619497, 0.1599073686520569, 0.12605710770003498, 0.16463818901684135, 0.12281890958547592, 0.11013829978764988, 0.12852828134782612, 0.283471557777375, 0.12674862606218085, 0.1732455287128687, 0.14887412631651387, 0.06636386198806576, 0.13993428961839527, 0.20345614902907982, 0.2580143488012254, 0.08978041718364693, 0.30604074359871447, 0.11354190777637996, 0.11786677336203866, 0.08582871829275973, 0.34209329809527844, 0.20300565054640174, 0.10277999463141896, 0.16685583017533645, 0.13896315969759598, 0.1383748443913646, 0.1367663877317682, 0.059887844254262745, 0.2591452334308997, 0.12875678861746565, 0.13482047652360052, 0.13561369880335405, 0.08858450557454489, 0.10832556698005646, 0.049398098926758394, 0.24783303262665868, 0.15256721642799675, 0.21517194458283484, 0.33898479770869017, 0.16134539851918817, 0.0740393165324349, 0.20564775564707816, 0.10832534433575347, 0.12286625118576922, 0.24489712610375136, 0.232247575186193, 0.16175046272110194, 0.10546358578721993, 0.14314614149043337, 0.12295335705857724, 0.11302322076517157, 0.1050492818467319, 0.1401075068861246, 0.15454999753274024, 0.12783780199242756, 0.11227146227611229, 0.14480187295703217, 0.20308983977884054, 0.1375820822431706, 0.12892023922177032, 0.1049948824220337, 0.147837613185402, 0.12513251043856144, 0.17436385620385408, 0.0772945024073124, 0.1561134503572248, 0.08184918886399828, 0.17399820004357025, 0.13458325644023716, 0.13631982263177633, 0.1660844567231834, 0.14856349298497662, 0.13398383860476315, 0.16477924160426483, 0.11717305082129315, 0.1101278280839324, 0.2157874224940315, 0.055389108310919255, 0.08851657679770142, 0.15704811114119366, 0.07642037118785083, 0.10338682652218267, 0.09209740223013796, 0.07954239350510761, 0.07599563265102915], [0.007542980256403098, 0.03936463712307159, 0.03017772647581296, 0.03446278140472714, 0.027926651564484928, 0.02890245887101628, 0.01315936462560785, 0.0049560533716430655, 0.03493594136671163, 0.04698902448581066, 0.0298071851284476, 0.04137246942264028, 0.021108305227244273, 0.018623006653797347, 0.008919369192881277, 0.04778225047630258, 0.022898330171301495, 0.059172629116801545, 0.021368530033214483, 0.0698233388538938, 0.010005320491472958, 0.04193196713458747, 0.06943572254385799, 0.013870584225514904, 0.017126888888014946, 0.01778207726601977, 0.007780313053444843, 0.009388710805069422, 0.03229060421290342, 0.05759168016084004, 0.06559378729434684, 0.05463385801704135, 0.03977205022238195, 0.029734044619544875, 0.09238992715836503, 0.02654669475305127, 0.08169476277544163, 0.042436301009729505, 0.039919737610034645, 0.02346754259633599, 0.01931023725774139, 0.004775093648277107, 0.04963655839674175, 0.010805359397636494, 0.054505911757587455, 0.047614632712793536, 0.02669815225090133, 0.003762238329727552, 0.099115603370592, 0.014600697977584787, 0.028955529851373285, 0.11285838234471157, 0.041181566775776446, 0.062231420452008024, 0.0010520737646402267, 0.009179871376545634, 0.04114010669582058, 0.07122963448637165, 0.06438721102313139, 0.010831925501406658, 0.041521028833813034, 0.06309867196250707, 0.06053102282749023, 0.03698583117511589, 0.009063642701221397, 0.034936060110339895, 0.06099881335103419, 0.09757811087183654, 0.03566709412552882, 0.032781957925180905, 0.04904546003672294, 0.029943944391561672, 0.034207156058982946, 0.022524185696966015, 0.04848601056437474, 0.03936240325856488, 0.05603165234788321, 0.05119520581502002, 0.028879539495392237, 0.052050397425773554, 0.0520351388695417, 0.058555737414280884, 0.03897090922691859, 0.11417945715948008, 0.03189066825143527, 0.05824175328598358, 0.018104000519088004, 0.03548960208718199, 0.05236024037003517, 0.05511331510206219, 0.029276803725224454, 0.044588362288777716, 0.034126295358873904, 0.050060595604008995, 0.08169813212589361, 0.04265465940989088, 0.11515957448864356, 0.027275546854070853, 0.026652424821804743, 0.06318687621387653, 0.027296087646391243, 0.004927997406412032, 0.024008009786484763, 0.03969956094806548, 0.07857760152546689, 0.0043674449170794105, 0.04087442524905782, 0.014256814574764576, 0.03443713278102223, 0.05916136331507005, 0.07768199997371994, 0.037405482289614156, 0.01198636589833768, 0.014198331482475623, 0.022299378033494577, 0.04080041828274261, 0.02808371227729367, 0.022809597139712423, 0.08651422525872476, 0.033506386826047674, 0.028203572837810498, 0.01441041131329257, 0.05550995592784602, 0.021060188082628883, 0.12537335220258683, 0.1376824057660997, 0.026031198976852465, 0.021645783417625353, 0.008086550551524851, 0.008991415033960948, 0.037729429750470445, 0.00782815421189298, 0.05055825757153798, 0.0721600947144907, 0.05230292059422936, 0.02116546173056122, 0.007069580024108291, 0.036667843160103075, 0.03164211557304952, 0.027344013687979896, 0.018394966937194113, 0.006865617433504667, 0.046423426319961436, 0.01636288496229099, 0.10103240012540482, 0.05200931955187116, 0.006927423028173507, 0.009821640796872089, 0.07375350061920471, 0.024579756645835005, 0.027400257349654566, 0.028783160487364512, 0.05301692603097763, 0.06644438501098193, 0.026183329973719083, 0.055702224126434885, 0.014813815887464443, 0.04412349211634137, 0.014398750317923259, 0.0904682619147934, 0.03533469731337391, 0.07830878079403192, 0.09886964820907451, 0.04359335376648232, 0.0019409240917411807, 0.03491998890240211, 0.06016055755026173, 0.014803869253228186, 0.018227837135782465, 0.026186708601017017, 0.01796541371732019, 0.06495651250588708, 0.050238503245054744, 0.05924339660850819, 0.008146421459969133, 0.055405643361154944, 0.03871869404974859, 0.03687176307721529, 0.020922757175867446, 0.027735062431020197, 0.017057460972864646, 0.05449284995847847, 0.038219985653995536, 0.01703725600236794, 0.0037193976231719716, 0.044833920401288196, 0.028849473237642087, 0.05217963131144643, 0.045826639398001134, 0.03208235386409797, 0.020540968580462504, 0.015917110249574762, 0.03702924310346134, 0.07352097090915777, 0.061878863198217005, 0.028517545833892655, 0.02978648291900754, 0.04081359140400309, 0.018747375761449803, 0.04293771453376394, 0.06530912171001546, 0.02396715455688536, 0.03142095185467042, 0.01750007413647836, 0.055688178981654346, 0.0907978719624225, 0.010024176608567359, 0.014692814274894772, 0.031302493953262456, 0.03714662860147655, 0.025549346610205248, 0.023675058218941558, 0.04954940428433474, 0.05982495094940532, 0.03179517610988114, 0.06584544215002097, 0.06563191142049618, 0.004724382233689539, 0.032096959330374375, 0.07623815909028053, 0.1441810664255172, 0.06528005920699798, 0.03730900680238847, 0.01638349440327147, 0.07202589215012267, 0.06833116931375116, 0.018732365824689623, 0.0105719103521551, 0.020230526351951994, 0.05969287834886927, 0.04125282408494968, 0.03712696168804541, 0.04801626448170282, 0.061226225952850655, 0.04131145746214315, 0.011007448065356584, 0.025532000763632823, 0.004317954799262225, 0.01888676964881597, 0.04130327528400812, 0.02302353419509018, 0.01684809183643665, 0.028847254216088913, 0.027847223209391814, 0.027725594482035376, 0.038703550526406616, 0.05611365595541429, 0.036706965474877506, 0.05047497747000307, 0.05026017395721283, 0.11179574561538175, 0.0748560723150149, 0.08269970494438894, 0.039905863159219734, 0.03877556482621003, 0.015352419359260239, 0.0323060111986706, 0.025396046730747912, 0.045781494554830715, 0.030260394305514637, 0.03923346252122428, 0.05005483282729983, 0.06167540341266431, 0.013487644373526564, 0.012245167636137921, 0.01691110202955315, 0.005343730445019901, 0.07605541264638305, 0.013539937954192283, 0.0066826668989961036, 0.07448075339198112, 0.020100320252822712, 0.0924477627268061, 0.03376111788384151, 0.06390448106685653, 0.025275104489992373, 0.01805437495931983, 0.05857522250153124, 0.049966736187343486, 0.007995116102392785, 0.05451350392831955, 0.020517386838037055, 0.017698346309771296, 0.0180836619620095, 0.010304005245416192, 0.0965557133895345, 0.04467752019991167, 0.016371866804547608, 0.014981019903643755, 0.02141012555512134, 0.013380173040786758, 0.12327506323345006, 0.046739844692638144, 0.032009846036089584, 0.07216572761535645, 0.023408274682878982, 0.07378085618256591, 0.02117410218488658, 0.03837394790025428, 0.059762024247902445, 0.06660215076408349, 0.062130410442478023, 0.041529600639478303, 0.024443240436085034, 0.03074820982874371, 0.023672688912483864, 0.0736211756884586, 0.017114929178205784, 0.044108352303737774, 0.04453296467545442, 0.04696429241448641, 0.0417093784926692, 0.03242985338147264, 0.01735663925501285, 0.039405533170793205, 0.015984167002898175, 0.03150132644805126, 0.05247529181360733, 0.015577228878100868, 0.03493023425107822, 0.029189913075242657, 0.03406300129427109, 0.031232171750161797, 0.04349055147031322, 0.027212480999878608, 0.06305009839707054, 0.028034634051437024, 0.027752617934311274, 0.030574996271752752, 0.08777770941378549, 0.04195889596303459, 0.02203025116614299, 0.04465361933398526, 0.07838158548111096, 0.02716334340220783, 0.039071347782737575, 0.09923713747411966, 0.03687601929414086, 0.02346408975427039, 0.028005753374600317, 0.017934115494426806, 0.009364757061121054, 0.03300551135907881, 0.03662171868199948, 0.023770385232637636, 0.04120793899346609, 0.028578711790032685, 0.06027090006682556, 0.02660141330125043, 0.06567306350916624, 0.04038040722662117, 0.03220288606826216, 0.12196177354780957, 0.09587620297679678, 0.13673459412530065, 0.10789572988869622, 0.12964861263753846, 0.12724397995043546, 0.1470829825848341, 0.10583540177321993, 0.13513480575056747, 0.10921065229922533, 0.07630054402397946, 0.11526355679961853, 0.08401418948778883, 0.09314495851867832, 0.09205041686072946, 0.07177558800322004, 0.16827946237754077, 0.19045910972636193, 0.14994923112681136, 0.14684877562103793, 0.13295633514644578, 0.12557809590362012, 0.15920706326141953, 0.1652897204621695, 0.19102563557680696, 0.19166925572790205, 0.10412673291284591, 0.09268595502362587, 0.12073417223291472, 0.18915051041403785, 0.18823467049514875, 0.11694857341353782, 0.17709571664454415, 0.10006725191487931, 0.10012088692747056, 0.12616408086614683, 0.1744137582136318, 0.13847577647538856, 0.14561204588972032, 0.1824897201731801, 0.2106401533819735, 0.04855887462326791, 0.12654144811676815, 0.1342749534524046, 0.3060057736001909, 0.19319221697514877, 0.1814799540443346, 0.06711965033900924, 0.20868489111308008, 0.16829152969876304, 0.09951407730113715, 0.22045768360840157, 0.22834132541902363, 0.17426849022740498, 0.14137764810584486, 0.15158795256866142, 0.1388095796573907, 0.13338461372768506, 0.1407342209131457, 0.0907694996567443, 0.15012468968052417, 0.12221954370033927, 0.05923508826526813, 0.10967185255140066, 0.0605210038338555, 0.17608488182304427, 0.21830266487086192, 0.1799614159972407, 0.10253127125906758, 0.09808470087591559, 0.10443620849400759, 0.057468238737783395, 0.11558479542145506, 0.08793465138296597, 0.19134844013024122, 0.15938271477352828, 0.20373684412334114, 0.10009448131313547, 0.13499774591764435, 0.14286654477473348, 0.2429212024435401, 0.13866214459994808, 0.19352689589140937, 0.18798850011080503, 0.12948847201187164, 0.2040974685223773, 0.12060212931828573, 0.08438577540800907, 0.11095743044279516, 0.15921378711936995, 0.08578814507927746, 0.19442428601905704, 0.12544713652459905, 0.16718497266992927, 0.17270327109145, 0.11920373755856417, 0.24229883740190417, 0.10661192573024891, 0.17087182874092832, 0.15734721149783581, 0.07496058897231705, 0.2187622620840557, 0.16377291904063895, 0.1752168362145312, 0.15566171990940347, 0.07130518511985429, 0.07177483843406662, 0.17824245354859158, 0.09385889716213569, 0.24319649470271543, 0.13987548183649778, 0.1174608631117735, 0.08755945120356046, 0.09189186443109065, 0.19489891914417967, 0.17470606049755588, 0.10711576978792436, 0.1430617889855057, 0.1913750238600187, 0.13048250460997224, 0.18985587725182995, 0.08559535737731494, 0.14484282466582954, 0.26580701814964414, 0.19671581540023908, 0.3172250872012228, 0.12141112965764478, 0.17572171927895397, 0.13241293461760506, 0.13309401838341728, 0.1252149185165763, 0.04736421353300102, 0.16670466953655705, 0.36419148731511086, 0.16809251537779346, 0.1029136183205992, 0.13958239287603647, 0.14301145653007552, 0.12636536615900695, 0.08550944636226632, 0.14641270448919386, 0.08997331620776094, 0.09859275291091762, 0.09533161501167342, 0.19824162649456412, 0.21049887815024704, 0.12861155031714588, 0.15659945318475366, 0.16595444729318842, 0.12019521716865711, 0.2157358729164116, 0.1026446936884895, 0.18229153705760837, 0.21474238950759172, 0.10512245760764927, 0.10224579673376866, 0.17935009411303326, 0.18335595494136214, 0.07283771265065297, 0.22552319773240015, 0.17335723678115755, 0.1384604733902961, 0.17122581833973527, 0.07849200963391922, 0.1074651135422755, 0.09895143288304098, 0.1325266167987138, 0.09159877547062933, 0.09963498057913966, 0.13979573064716533, 0.1387307487311773, 0.25377534970175475, 0.12176275922683999, 0.15575431025354192, 0.11134084619698115, 0.1427260710624978], [0.05841947910084855, 0.018296428279427346, 0.028730636840919033, 0.02258003416500287, 0.08449858927633613, 0.01813253795262426, 0.04279609791410621, 0.03818742021394428, 0.04061684063344728, 0.033623393828747794, 0.03634206259448547, 0.052297506626928225, 0.048730199414421804, 0.03412931218917947, 0.03982058296969626, 0.016672024721628986, 0.06522796044009738, 0.07633095723576844, 0.05362216601497494, 0.08941660897107795, 0.018321626048418693, 0.07957737092510797, 0.045019275494269095, 0.04603612171194982, 0.026758989806694444, 0.03167149348882958, 0.02642633695359109, 0.01956617987161735, 0.02176712641812628, 0.01462035468648537, 0.013311109705682611, 0.007414710698867566, 0.029336960360524245, 0.015795676335983444, 0.11455610452685505, 0.0809275230858475, 0.03327186444948893, 0.018485826221876778, 0.010773115864139982, 0.026675908229663037, 0.0873373264039401, 0.03707878146087751, 0.02270228258566931, 0.06796069661504589, 0.023014014295767993, 0.06551526064868085, 0.05958335219474975, 0.041861700592562556, 0.02275654100230895, 0.0004503638524511189, 0.03785054082982242, 0.07629820625879802, 0.0291201883010217, 0.042656704026740044, 0.0680778594687581, 0.04684046136389952, 0.006426466852644808, 0.09934520901879296, 0.06373828451614827, 0.05512379793799482, 0.08911725628422573, 0.020535812509479, 0.052358225439093076, 0.018090220692101866, 0.04560040310025215, 0.08678180660353974, 0.04546317628410179, 0.03618372909841128, 0.030789215343247633, 0.042920210980810225, 0.056040944036794826, 0.01895586359751178, 0.0514784316328587, 0.018990147109434474, 0.019813483886537142, 0.07067461934639141, 0.036280100684962235, 0.027004675939679146, 0.014223164671420818, 0.028427595680113882, 0.015654076414648443, 0.03467214868578594, 0.043111900304211304, 0.023943917913129553, 0.03362172399647534, 0.04168036793998908, 0.04663191044528503, 0.028075572772650048, 0.009499863190285396, 0.045619090378750116, 0.035420003478066064, 0.0620296935812803, 0.018176484227296896, 0.07847502187360078, 0.04521106129686814, 0.04121687445149291, 0.04439034986717161, 0.04710770874226, 0.036029651819262654, 0.0943803449627012, 0.06289756478508934, 0.020643481439037714, 0.02296812916029012, 0.0368578403868014, 0.018389827564533334, 0.03703423404658679, 0.03320973184600007, 0.031221484823618084, 0.03167938251863234, 0.03042073716642335, 0.014497393804049352, 0.027659261322696693, 0.04982687474694103, 0.07673176893149503, 0.04474712994124275, 0.04598138832079712, 0.013944402871857164, 0.028341962970444, 0.021330763993319124, 0.040005403716349974, 0.0904784664453473, 0.05361311552405823, 0.03320287440146785, 0.01263992618987686, 0.055076255957828835, 0.022271193120104726, 0.06532996863825247, 0.04476260000956245, 0.011203638514416525, 0.05244609943474643, 0.023461100754502695, 0.03847839034278877, 0.11014984018402174, 0.032195824533118866, 0.017946167972695548, 0.007531742285209475, 0.014892993767716689, 0.07790960924467072, 0.025545582066115458, 0.03846133578917943, 0.10545911805820651, 0.035133534474880435, 0.018233516420878004, 0.011512485125422245, 0.04244188567099627, 0.05128356962813996, 0.037321901618270203, 0.021995555762259755, 0.06145985404145904, 0.0165274116807268, 0.027950391013291664, 0.0274820049162372, 0.01942545011843322, 0.012828928011003882, 0.09167807394987904, 0.05554271803703159, 0.010910112614510581, 0.04961245344020426, 0.029849535785615444, 0.021765642122772988, 0.022248639252211433, 0.018207860375696328, 0.00890750596227008, 0.01690374920144677, 0.012851313040300738, 0.12912802572827786, 0.05727297226258088, 0.03751091549929697, 0.05674333115166519, 0.01371580747218104, 0.07806308538420126, 0.024608663297840394, 0.021685202591470443, 0.06618855186388828, 0.057879058294929564, 0.03894306755682919, 0.086106236994965, 0.0346488971990766, 0.038410160996136256, 0.02835634208167903, 0.03664873285742942, 0.025440365934628062, 0.033198517994605936, 0.027535736408026423, 0.06098373662098311, 0.04675379335822072, 0.08769171676249243, 0.04559118933684658, 0.04346786401583813, 0.042015922590508126, 0.01977182528207777, 0.04786548233823851, 0.0881515143555589, 0.04778484799317084, 0.03509924354148097, 0.07258210214786232, 0.022466094087576494, 0.098093903507106, 0.053436258021974936, 0.07531471957918257, 0.028083903380320407, 0.067657774197869, 0.053664268052671105, 0.03587509214412421, 0.011772481720981887, 0.07155833911383525, 0.043482706969371065, 0.04442900462890975, 0.039717843756079674, 0.06615829450311139, 0.06462792662205175, 0.02535192976210965, 0.014064861788938288, 0.02839495602529496, 0.03346881931065582, 0.017841770059021655, 0.0011953219495808298, 0.020600722600647714, 0.05592784073087387, 0.08353312194230966, 0.031470393732888624, 0.03411782374314498, 0.05065487406682223, 0.06251105427509174, 0.008319418866449269, 0.018676539621083066, 0.03374067171534989, 0.021119817793078255, 0.011493069614516571, 0.02213573818153236, 0.031671244869357906, 0.0370227901294129, 0.041718837164808065, 0.02717888211918762, 0.03886140162649099, 0.024378092857659794, 0.1184281190217007, 0.014241353783290833, 0.037740298503194936, 0.04770799117977731, 0.04884754780505318, 0.042461077609914355, 0.025446418148931116, 0.0672973798646126, 0.050457106553949416, 0.04282844442059286, 0.07667269397643395, 0.004855345787291299, 0.09197730047162622, 0.03934297383239027, 0.02661434336914681, 0.014004230179125443, 0.05994922357785981, 0.03866734856273979, 0.013436713561532088, 0.017581947868166026, 0.019882353335560765, 0.023170542517618742, 0.030798199040873442, 0.0306035355606582, 0.024404960458923597, 0.03537272867106367, 0.01622762854822213, 0.032982805350911804, 0.018303734723303933, 0.049881827071658336, 0.03889342900947668, 0.028334105481917504, 0.08170521221472882, 0.019339995524205733, 0.01587353504874045, 0.08634350160718895, 0.06041676548193209, 0.036500114074442536, 0.07415448300889693, 0.03488241396553349, 0.04458256240468472, 0.045494613659684546, 0.06260590816964395, 0.03097586548392428, 0.0033799928496591747, 0.03314291257993318, 0.055359685866278596, 0.030049134547880385, 0.026910295164270792, 0.03229470457881689, 0.008798144936008612, 0.04680188823840581, 0.029626679970533587, 0.066827607806772, 0.0019612959295045584, 0.008657740800117608, 0.03977400207077153, 0.03347094185301103, 0.026722715483629145, 0.03786258959735278, 0.06182706871186383, 0.07748429183266126, 0.021257018634059932, 0.04384833715448622, 0.015539329251623712, 0.016685849077475723, 0.09509554525720887, 0.06096429606259335, 0.050343038456048816, 0.03173355187755078, 0.03731908887857571, 0.0766370486235246, 0.09768273142981343, 0.021415914306999184, 0.05073432097560726, 0.01908808648295235, 0.022344981152855325, 0.057061745901592076, 0.03325559286167845, 0.056786568675306626, 0.04075816039403435, 0.043678103320416994, 0.061006524265394546, 0.04588776268064976, 0.019128049279970583, 0.09098656300920993, 0.03832191963738296, 0.0726199516793713, 0.0057611514057498425, 0.04470305750146508, 0.005998499973429716, 0.021802751361974515, 0.08119658872601576, 0.0694591373030562, 0.020959148387191817, 0.021770803759864066, 0.04395155134261586, 0.0032062776472230325, 0.05982908471196424, 0.0516154951765202, 0.0111963849485619, 0.04624017521564383, 0.02628666661621537, 0.005419468006948591, 0.01570143285789527, 0.057209885999327525, 0.012045116163790226, 0.01342163683148101, 0.03178516082698479, 0.05160125336260535, 0.06889692333061248, 0.05614459980279207, 0.020099615212529898, 0.07880434248363599, 0.05014112975914031, 0.041574266797397286, 0.1660461025312543, 0.11239230618230067, 0.12554269545944408, 0.18979804910486564, 0.13109268358675763, 0.1157556007092353, 0.16920224879868329, 0.10975850571412593, 0.17769065190805122, 0.09854892166913487, 0.1455399685073644, 0.16950292250839993, 0.08643182460218668, 0.10035526458523236, 0.1097102661151439, 0.20604152436135337, 0.2354276631376706, 0.23757169808959588, 0.08683816529810429, 0.1513903186423704, 0.17592261865502223, 0.19520432775607333, 0.1541980414185673, 0.21718245232477784, 0.09785960748558864, 0.15169823571341112, 0.15635644434951246, 0.12339041524683125, 0.1061437047610525, 0.1351595637970604, 0.15119158633751795, 0.1496626136940904, 0.09300104124122299, 0.14893720886902884, 0.2292862575268373, 0.2088359181652777, 0.17725196841638535, 0.15341246325988322, 0.08482474833726883, 0.09491503267781809, 0.12675300473347306, 0.17674131144303828, 0.13634705945150927, 0.17749255785020068, 0.10225163743598387, 0.1601953961653635, 0.13033575232839212, 0.15286030538845807, 0.07951991385198198, 0.13699062023079023, 0.10612259808112867, 0.15816436061868444, 0.10269107791827992, 0.12070561439031735, 0.130357333982829, 0.18056905682897195, 0.08042815417866223, 0.13694422115804628, 0.11217957697226666, 0.15300014085369185, 0.17880605533719063, 0.10021939218859188, 0.15689297259086743, 0.13716787478188053, 0.09766563234734349, 0.25768162915483117, 0.13470422651153058, 0.16001146228518337, 0.09923152683768421, 0.10428779380163178, 0.1596820674603805, 0.11491493292851374, 0.1712718463386409, 0.1580011029727757, 0.08504858749802224, 0.19524864881532267, 0.1784039448830299, 0.1305487783974968, 0.11561198029085062, 0.11015562893589959, 0.15341847465606406, 0.13300184364197776, 0.08917371887946501, 0.13980732299387455, 0.1664345129393041, 0.10784690399304964, 0.12444439111277461, 0.10597940068691969, 0.18960322049679235, 0.14745099877472967, 0.0904945784714073, 0.11695570545271039, 0.22004074504366145, 0.17464958305936307, 0.09871438349364325, 0.1193588538444601, 0.09139469228102826, 0.20090911304578185, 0.2026178635424003, 0.20134162186877802, 0.10950018637231551, 0.15493168408283964, 0.20267477142624557, 0.1088622584939003, 0.1580696922610514, 0.1528293578303419, 0.1774519623722881, 0.08834413136355579, 0.11177673921338283, 0.1614941842854023, 0.09243582899216563, 0.12767257023369893, 0.16853300970979035, 0.18983401358127594, 0.14411140844458714, 0.07970751394168474, 0.15198911307379603, 0.16207433596719056, 0.09760759639902972, 0.10580669550108723, 0.16987254173727706, 0.21393068775068969, 0.14227744279196486, 0.13832964759785682, 0.11054211718146689, 0.1370639295782894, 0.15534145350102335, 0.21032224700320512, 0.14592664228985086, 0.17212754260981455, 0.1660412785713561, 0.11561690072994679, 0.1932232387480326, 0.13209110969910398, 0.14388368785148486, 0.12477240554289892, 0.10077618106151931, 0.13483307819114998, 0.05870073080586735, 0.14444210944930092, 0.2518180984770879, 0.10777180606964976, 0.14787850552238524, 0.18966495234053582, 0.18070727441227064, 0.22313262132229283, 0.10239220020594075, 0.15380974975414574, 0.17915102042024955, 0.1319706888170913, 0.11385978446924128, 0.08411996037466452, 0.10520709955017082, 0.16669942997395992, 0.12179301658761688, 0.18533265043515712, 0.11591071699513122, 0.16067661956185475, 0.18281071388628334, 0.10804082718095742, 0.11894135124748573, 0.10241486539598554, 0.1654939298168756, 0.10232354412437417, 0.16425083245849237, 0.2379875085898675, 0.19237664120737463, 0.15287828020518646, 0.12468502507545054, 0.16274823574349284, 0.18535225797677413, 0.15027515270048752, 0.1932018352090381, 0.12159956837422214, 0.18811131070833653, 0.2007056458387524], [0.05825664818985388, 0.045015557334409095, 0.02530304635001812, 0.04053502627357375, 0.0381829673278844, 0.016869198516360484, 0.061781389522366226, 0.04035045414639171, 0.04170516680460423, 0.005418761575128883, 0.021076337216072716, 0.037848251304239966, 0.0372005975805223, 0.08821930212434381, 0.006839942834631074, 0.07258205761900172, 0.018895701396104414, 0.04563261230941862, 0.047332991380244493, 0.030189444987627212, 0.024243712177849375, 0.054734496952733025, 0.03531654067046475, 0.1142533305392135, 0.029480280209099874, 0.033223925420315936, 0.054548358893953264, 0.011738868925021961, 0.028024705970892683, 0.07219781065941788, 0.057074128635576926, 0.051549080380937085, 0.07040304524707608, 0.019122026751574595, 0.03432566219998989, 0.031038298657222185, 0.09125479744398035, 0.04222560899506789, 0.05002103542210534, 0.026457956155354623, 0.0374893746629823, 0.08655173340230249, 0.06474410241935402, 0.02567677707702387, 0.0699200555391144, 0.08911262528272346, 0.026474285259610042, 0.02556985771661857, 0.02306905011209892, 0.025444341990805697, 0.10009972829720937, 0.01695438964816276, 0.03954307911044452, 0.009532430485705845, 0.04385634863865562, 0.018895118810178246, 0.03915134759154171, 0.02141194010619074, 0.021561508838203736, 0.025866269643302076, 0.0354297998273978, 0.02181772048061248, 0.014728038458997617, 0.033564318873686716, 0.019361848062544595, 0.04064550608745776, 0.02041024297795957, 0.005360377281249384, 0.08801720046903938, 0.020859448268311098, 0.0245495920535177, 0.05886890518013388, 0.03615244757384062, 0.03303977631730959, 0.059877929161302745, 0.007640219691893435, 0.04283582136849873, 0.12468921078834683, 0.020703959053207655, 0.07140660702134483, 0.03447568364208564, 0.044176633600727655, 0.05398990018875338, 0.0987773398810532, 0.02085801777866436, 0.02348221114516491, 0.04211730367387645, 0.04380551152280532, 0.06427155472920276, 0.06231696781469509, 0.03508696841890924, 0.010951518888759892, 0.06188745355757419, 0.03561918107152451, 0.04443116798938718, 0.010569451987976208, 0.02610871259093983, 0.07547120883828029, 0.01834613547543995, 0.030086052684055176, 0.01306727152041276, 0.04427735046192538, 0.04383985069580376, 0.055579502586624585, 0.03557591015123762, 0.08133496216032654, 0.05400011585152242, 0.03611543666920625, 0.004015294452983653, 0.02002416476898361, 0.012661464243137743, 0.07653882537852041, 0.072847753908718, 0.012586454449774465, 0.04526182419795077, 0.022198598089744337, 0.024767718532530125, 0.08291900216136128, 0.015753438856336288, 0.06509210288641043, 0.07620362695888616, 0.03253871531342156, 0.0031836929338169284, 0.005240099262664444, 0.03529997222358361, 0.019037689089600462, 0.03349006699863821, 0.007148782488002325, 0.02077845398162026, 0.02040059320279397, 0.019934372321586125, 0.07329374755499884, 0.016902834504435305, 0.012490413118939614, 0.06146690444438718, 0.05615380985545926, 0.02802639064611867, 0.026739925888250582, 0.04588628209603485, 0.03736441183718853, 0.029227254235593136, 0.04004237751360051, 0.062180984095903113, 0.06050710340787191, 0.052202396691427566, 0.013569045913754962, 0.00977377598246676, 0.013285225450090365, 0.033483517545391805, 0.0078759104872006, 0.06928734495886602, 0.009004101120808627, 0.021836830783286132, 0.01749636525346432, 0.05468427210871596, 0.038417586183641106, 0.028690807630482595, 0.0330201428005239, 0.047677266265964136, 0.051567166519816965, 0.055129297252278775, 0.02308629762410419, 0.035386035378905945, 0.03642079704150092, 0.041656121975393035, 0.0445275469974149, 0.025207550497725606, 0.07896558890934102, 0.04918617123621516, 0.024926877667894587, 0.03190695839293767, 0.07912168483017012, 0.014999078211985761, 0.04457286253455095, 0.0335455981985433, 0.032484909606864676, 0.0039393643965013325, 0.07226735731819645, 0.049888780995388515, 0.056732469820417464, 0.060581897050724365, 0.05656871493556537, 0.07373894710326567, 0.02918186077295104, 0.059976597694912925, 0.0591874460951658, 0.017285929279751144, 0.011821865155070554, 0.012738775621983223, 0.07506001449655741, 0.036114115646341816, 0.05738711457524914, 0.033987714123213664, 0.026028940992546268, 0.04380743368528783, 0.07760594467981718, 0.03970444427977782, 0.013689436182175996, 0.03363340540090576, 0.0537307088234229, 0.032279227089020424, 0.021325830566638615, 0.007868508491810644, 0.024557124852435663, 0.059305106187821366, 0.09292373913922347, 0.022113213999546133, 0.054498909594258294, 0.01794820331269875, 0.010798545554280281, 0.02337184636417078, 0.009004062158055604, 0.07113090658094734, 0.03849196422379464, 0.08300561079522595, 0.038461031508632004, 0.055271826713578776, 0.06758432384231128, 0.01542847558084759, 0.02060386374068912, 0.06167767809529323, 0.09638827003072947, 0.031790489447303116, 0.0314843869273318, 0.02349882783164503, 0.049017199053196236, 0.053023486616439186, 0.06302410096395761, 0.0902962320833467, 0.03789514390518889, 0.04440030206751544, 0.0662400049623102, 0.028357243791106157, 0.028980579190829303, 0.027165736828465015, 0.02270085951749934, 0.037690574608859606, 0.04021301952889189, 0.00940326988711604, 0.05747002731368411, 0.029853035011910833, 0.02840110842953436, 0.04263337832526304, 0.019623623957158998, 0.10239539144095033, 0.06380105536663905, 0.016397524705098476, 0.057090066256932914, 0.040415065523120575, 0.031751367132528685, 0.03722233508597128, 0.005191979798837565, 0.013445128588500666, 0.04208552491036244, 0.014638479788118275, 0.031646765128243715, 0.022141983354231343, 0.07561825797893107, 0.01284074021896231, 0.0748002108593937, 0.043806747198686935, 0.041906812039087527, 0.05152583631570451, 0.045162665846874006, 0.02628021549753612, 0.07232341915369034, 0.06618597661145031, 0.043315115181030706, 0.0613174878526479, 0.0027265580274615786, 0.0322043814958306, 0.02823684331815457, 0.01977098665520316, 0.013880061451345682, 0.03250865833251737, 0.02400786692305701, 0.03526793370838277, 0.08613821613835171, 0.05012939640437253, 0.053217873646644875, 0.037939895410090685, 0.029020805450272746, 0.03776252953684889, 0.015482788730878383, 0.08759057687711902, 0.05997094624035526, 0.08228111881180666, 0.06955768709303811, 0.07724414768745191, 0.018190653681813274, 0.019086060419795103, 0.02154523168428568, 0.07756353836157359, 0.02781768202112289, 0.04022345041448716, 0.020548623833747115, 0.025492919266980607, 0.00503700869558088, 0.03892111482855398, 0.010595710100460565, 0.09587430307874456, 0.07698052941123024, 0.014267477381508797, 0.029384298250079155, 0.0407172717677895, 0.02476205594575731, 0.04838333072257228, 0.0666043178352993, 0.030333135910041165, 0.025344166897411924, 0.04602362765581347, 0.031247504521161318, 0.03453038363659289, 0.04011235090729315, 0.05112668332003523, 0.05830613459693268, 0.05547219916479662, 0.062286940519697964, 0.06672795221675187, 0.04241840411850717, 0.05204449364100583, 0.04890206968411803, 0.03387894124898594, 0.023380978491331916, 0.04672625596867874, 0.019660399229906034, 0.05112228238431271, 0.04354279866674915, 0.039936413668328896, 0.01283042436625692, 0.007337673450820148, 0.06420427162083797, 0.010429892972751986, 0.05092152030556463, 0.07847179353120737, 0.010628272757458035, 0.06857434884295799, 0.04303040877857711, 0.010736737640399951, 0.052468690410023555, 0.013282615873322356, 0.03830061628832482, 0.004711634455816238, 0.04974888244760223, 0.007350289033638546, 0.10360148531617597, 0.020001425364171155, 0.014769383506063605, 0.02497513582056854, 0.0528171250334708, 0.004613439505192218, 0.011172078684467124, 0.14825271122390404, 0.1596808503381908, 0.20098154665902257, 0.17348000284982845, 0.12089566356735304, 0.12770731758791953, 0.1419871739926748, 0.17791478050639853, 0.14810214430326596, 0.13057355128694326, 0.052185605600243434, 0.1076176916831173, 0.14376924867974594, 0.2706580812809989, 0.09024973653140478, 0.12277521193027496, 0.14122651715297252, 0.18460935330949724, 0.13470421166857705, 0.16506119834957644, 0.11383048447896726, 0.09892083413433284, 0.17426969250664115, 0.21096546639455482, 0.13532253942685202, 0.10094625904457644, 0.10302187540219165, 0.0878216593991965, 0.10952728218398988, 0.18734695797320455, 0.1485395958297886, 0.15767745237099007, 0.17471645056502894, 0.10204946156591177, 0.12310657344642095, 0.13544760615332052, 0.1829686577548273, 0.09501137828920037, 0.13942663092166185, 0.11922011675778776, 0.1403689506696537, 0.1219830360787455, 0.1087232468125876, 0.08387707770452835, 0.17219492961885408, 0.21023330802563578, 0.11915514915017411, 0.06578806671313941, 0.092584162048297, 0.15815959603060037, 0.15372683701571077, 0.15468420751858503, 0.28940832358784974, 0.07813128133420832, 0.23073239164659753, 0.3138361737364903, 0.06867614923976362, 0.10226949350908399, 0.12888483877759427, 0.12898689892608672, 0.15187329350737855, 0.22152507008286193, 0.12020108013530262, 0.1377909374423325, 0.2325376807129942, 0.10172301306738518, 0.13217838626587763, 0.1529307648888789, 0.17222664901055396, 0.125999650626909, 0.10506321195862256, 0.16593877313425764, 0.09063269215403125, 0.09113807245739736, 0.13718258414883167, 0.09057299379492179, 0.10945993970381096, 0.22414942301111296, 0.0660810963017866, 0.1364695286611095, 0.12790778651833534, 0.13529194809962064, 0.12476538482587785, 0.1781566909630783, 0.19338937592692673, 0.0709005662065465, 0.15160094015300274, 0.11842862368212081, 0.1833861306658946, 0.1276572374626994, 0.13356198702240363, 0.14202171354554594, 0.17924114683410153, 0.08828672624076717, 0.20651378261391073, 0.09486677081440575, 0.11097511582192965, 0.12184926396002993, 0.14877154666464776, 0.17645525804255158, 0.16529208049178123, 0.1668462564703077, 0.1606036812881939, 0.13088725710986182, 0.10138181809452362, 0.1806761635816656, 0.08976494340458885, 0.06529243080876768, 0.1012440086924471, 0.13659826159710065, 0.17105050821555778, 0.19499642250593752, 0.2156695249141194, 0.10281778479111381, 0.17874744051368907, 0.16973172663711011, 0.13682994525879622, 0.126494959986303, 0.09473161087953486, 0.11158018882269971, 0.13282556872582063, 0.08708612425834872, 0.10503751880605705, 0.08925887290388346, 0.12235650705406442, 0.17967867257539183, 0.09526193476631306, 0.10668215516488999, 0.06134390830993652, 0.11805166461272165, 0.11742794886231422, 0.10352628349210136, 0.10031757090473548, 0.08683748994371854, 0.1107536960626021, 0.0961838974035345, 0.09759840861079283, 0.13747188815614209, 0.12940118060214445, 0.1320871021016501, 0.1087878952967003, 0.16993644065223634, 0.14549551386153325, 0.20524865831248462, 0.16399372281739488, 0.16192728682653978, 0.08843260278808884, 0.11775696519180201, 0.18774311640299857, 0.16164763073902577, 0.14665890455944464, 0.07595349350594915, 0.09047048835782334, 0.10706888831919059, 0.07218819984700531, 0.12063148868037388, 0.09226348745869473, 0.13679818133823574, 0.22665874304948375, 0.18513561022700742, 0.177991162345279, 0.14843326091067865, 0.14382136228960007, 0.16587337508099154, 0.13486012205248699, 0.18698443367611617, 0.1128684903960675, 0.24380095914239064, 0.13506844290532172, 0.16065389499999583, 0.12138967416831292, 0.11857661535032094, 0.10884612420341, 0.13629081950057298, 0.09678104426711798, 0.14686875423649326], [0.00559812150640937, 0.015822384375496767, 0.049467723511043005, 0.06219990515091922, 0.03820441910647787, 0.025008480515680276, 0.012878668603661936, 0.05114768609928433, 0.01414001259036013, 0.007627500672242604, 0.01560056200105464, 0.03764777124160901, 0.03228836663765833, 0.04904204986814875, 0.07346646016230807, 0.014132160667941207, 0.03237998847907875, 0.025631313110352494, 0.034220295783597976, 0.03914493914635386, 0.06424696737667546, 0.04068478425324429, 0.019885268120560795, 0.06554833074915223, 0.07825172448065132, 0.008461630131932907, 0.02185080727940658, 0.02082426490233047, 0.030901229547453113, 0.062296981777762994, 0.024961029448604677, 0.025333415032946505, 0.03340087198012043, 0.05709333170671016, 0.03455103389569558, 0.03541932070220355, 0.06929775729076937, 0.03660220761958044, 0.00875352516231942, 0.00975343649770366, 0.06761361641110852, 0.053313673779484816, 0.06849985948065296, 0.04464761907001957, 0.046585051240981556, 0.04043620931042824, 0.03347968806338031, 0.03435472841374576, 0.05647655874781776, 0.044680767095997, 0.04077775309269782, 0.041849202825687826, 0.05096849454275798, 0.00901172947123996, 0.08063262328505516, 0.02316397636604961, 0.011581509497773368, 0.031819692958379164, 0.06846572068752721, 0.010895391187659698, 0.05145864226506092, 0.08171479334123433, 0.04684909254137892, 0.04003714166174177, 0.07535992379416712, 0.029185859093558975, 0.022177708488015924, 0.0687733334780205, 0.04058325845107902, 0.07561252117739059, 0.12151479284511879, 0.04142813049838878, 0.0851991395757068, 0.08305830328026786, 0.07361192852840759, 0.07888493972131982, 0.034398192292428575, 0.01668608656473225, 0.011801011733041378, 0.06490603904239833, 0.010579073932603933, 0.05882541532628238, 0.1143384697206784, 0.009452115264139138, 0.023480919808207545, 0.025289372279075906, 0.012297449156903895, 0.07023442929494195, 0.02014798839809373, 0.07484292887966149, 0.040641517043695785, 0.01905170825921232, 0.05331706168362871, 0.09099873423110694, 0.055988270105444826, 0.030217689272831194, 0.03756580474146176, 0.026468416726856958, 0.0732222045189701, 0.024014379268919583, 0.029524809069698676, 0.003711097861014423, 0.021796921791974455, 0.008026078503462486, 0.008924632875277894, 0.04050563722557854, 0.02914972948929062, 0.015817423118278384, 0.009036981045937864, 0.07348989718593657, 0.04902718465018552, 0.03788465364777949, 0.052095349310548045, 0.046578854307881556, 0.0690980305080302, 0.049699110313667916, 0.04287709962227382, 0.05912379579967819, 0.043784564404631965, 0.03325282836158294, 0.05195448226004373, 0.0597562354960246, 0.029583965661004186, 0.022079973205109127, 0.017551504970469978, 0.06365936453221366, 0.035594011133071035, 0.07137304710340686, 0.06095517506764736, 0.06597637184313498, 0.013241894230304752, 0.016156862911884673, 0.0051557291317294585, 0.02207439967605751, 0.0408046485244995, 0.057899151943274774, 0.02666196698555723, 0.054671473772032186, 0.046378303741221316, 0.0833036944095511, 0.06325136884697713, 0.05557112002861686, 0.05474650861287955, 0.018661242102098186, 0.10130246024345979, 0.022395875785150565, 0.06990463371039368, 0.03402352645935025, 0.033814318740041927, 0.03174190474965144, 0.007992846985871438, 0.051362715967115946, 0.01077139222616097, 0.027060127358708996, 0.06599798318347894, 0.0408528955449583, 0.02707732106500771, 0.07488790302886628, 0.043421312802820466, 0.10572565297479741, 0.024053445922618266, 0.08315116821904667, 0.047475257379119284, 0.03433250851230696, 0.017463456570112612, 0.017405700782546774, 0.042481653654249385, 0.028590517504198942, 0.01518888619102654, 0.03329639614094049, 0.03095677002420416, 0.004912623817290296, 0.02868395204131957, 0.04375370219349861, 0.021191828382143285, 0.08106969631626271, 0.046875820989953354, 0.04642979023628868, 0.0457250839099288, 0.009672249252616894, 0.02971963767777197, 0.01975064995349385, 0.03775564982788637, 0.05034501627960708, 0.04410802575876005, 0.01851931563578546, 0.03393947823497001, 0.0636044233397115, 0.03782107014558278, 0.01655697142268764, 0.09591394860763103, 0.015169516136666061, 0.07663330077775754, 0.03026790298463311, 0.014685171081509907, 0.03116212785243988, 0.023198050221253652, 0.031190010340651497, 0.01404137281497242, 0.07259100049850531, 0.05151734243554529, 0.026470824996067677, 0.05876228824490681, 0.051619873847812414, 0.1058884801750537, 0.05134310471476056, 0.0318462210270809, 0.028718884932459332, 0.024072320593404584, 0.04719180891697761, 0.03259023891587276, 0.016229929206019733, 0.03072990475629922, 0.10281475682859309, 0.04155139751674142, 0.06635934230871499, 0.09080806907149963, 0.056815349162206985, 0.019689116634253878, 0.04046604735776782, 0.0485773800755851, 0.017912964285642374, 0.016002460943127517, 0.04583717047353275, 0.04071133087563794, 0.048119564016815275, 0.03248806002375204, 0.022149109827296343, 0.07717928398051299, 0.027986105014861096, 0.039727287585265, 0.02943179013527697, 0.015278927257895702, 0.008431223413936095, 0.02456531445204746, 0.006726567717123544, 0.019557600644475315, 0.046836943583912216, 0.01667364631430246, 0.024017685536819045, 0.04028167561045848, 0.0485457534523448, 0.022622451615461614, 0.04565596769680269, 0.05755136298830621, 0.017653923205216415, 0.10383645669207908, 0.032659581484040245, 0.043729801327572204, 0.027246172649029177, 0.07197706625447609, 0.030786589995841496, 0.017999443043663632, 0.032714422486606054, 0.0065583580908423755, 0.04367962101241574, 0.010132444822374964, 0.11033411545213312, 0.07632650434970856, 0.015074865405040327, 0.041718699867487885, 0.060494234567158855, 0.034920797843369655, 0.040836123007466085, 0.036496303146122955, 0.08638438652269542, 0.0425573861139128, 0.05549390698433854, 0.05120279798575211, 0.03831059075309895, 0.051701639968086965, 0.02143642912415089, 0.052601315910578705, 0.02404454386123689, 0.020841128352913074, 0.055230971483979374, 0.0653411602252163, 0.04474243585718796, 0.039285026941797696, 0.06406906715710647, 0.01731110107357381, 0.022361876144714188, 0.0175243442208739, 0.02383069586358033, 0.07083444827003404, 0.02016772581555415, 0.03551390742359217, 0.09794688405236229, 0.0326149079046445, 0.036381385289132595, 0.03058424343180377, 0.019468184837023728, 0.029333108614082448, 0.08683812076924369, 0.02541358924645465, 0.05946270495769568, 0.04156673399847932, 0.037172626034589484, 0.04125444196688477, 0.06333816301776096, 0.07368087404756807, 0.03809616944636218, 0.05663093659677543, 0.026639379721018486, 0.030261173560575116, 0.02600579711725004, 0.03826459986157715, 0.02118646450981032, 0.01662967035372276, 0.052153760043438524, 0.03625205863500014, 0.015493397731916048, 0.04651531533454545, 0.010236540310870623, 0.008434963838226395, 0.06402222279575653, 0.03381097165402025, 0.012376550967019284, 0.016479229598189704, 0.027809585189970676, 0.06693504110444337, 0.05865567130967975, 0.054801286532892846, 0.049800554479588754, 0.062197463485063054, 0.017952017951756716, 0.04516380504355766, 0.04263045055267867, 0.011454103150754236, 0.06852343009086326, 0.06282646703766659, 0.012999230493733194, 0.04500801340327598, 0.013621409070765367, 0.045536040342994966, 0.039478805410908535, 0.052390390119398944, 0.07854532552300952, 0.009789649593585636, 0.023086438632162753, 0.025601671732147224, 0.015054905343276914, 0.03219123806047719, 0.09792841941816732, 0.029959486819279846, 0.04636353129171766, 0.05559079807426315, 0.06285297655267641, 0.01144015262980247, 0.11511818491271697, 0.036536123079713434, 0.04667673245421611, 0.14717520185513422, 0.08719991034013219, 0.18586635851534083, 0.11544540524482727, 0.08398376143304631, 0.07480463405954652, 0.1315361019806005, 0.18096603162121028, 0.11490721459267661, 0.08111024726531468, 0.14529875566950068, 0.1362253472325392, 0.1531516428804025, 0.18254030495882034, 0.22790184040786698, 0.07858854820369743, 0.12883385323220864, 0.08053600307903253, 0.10951922988169827, 0.10271008432027884, 0.17109940090449527, 0.11329225671943277, 0.11816243757493794, 0.14358351880218834, 0.11867479406646453, 0.09053087691427208, 0.18284497142303735, 0.14390028227353469, 0.2071966030052863, 0.1381989850779064, 0.10125227621756494, 0.1117592616355978, 0.15302552230423316, 0.11945519945584238, 0.13747859717113897, 0.17299613740760833, 0.17897001060191542, 0.35100091074127704, 0.07655752007849514, 0.12418276921380311, 0.15115263842744753, 0.11145150783704594, 0.14592348074074835, 0.12066902650985867, 0.16748402849771082, 0.16911132086534053, 0.16409587202360854, 0.12263784781680442, 0.10220566880889237, 0.12479922675993294, 0.10786064114654437, 0.12731999071547762, 0.14948010473744944, 0.2012548054335639, 0.11135668362840079, 0.08297663734992966, 0.13891799258999527, 0.11683581149554811, 0.2794637525221333, 0.0882594300492201, 0.1347973512019962, 0.15674889204092324, 0.09391765299369581, 0.10828429614775814, 0.17895006167236716, 0.12913596670841798, 0.08362152657355182, 0.13800133630866185, 0.15027610264951363, 0.24026431376114488, 0.24764102417975664, 0.17893107753479853, 0.1696693417034112, 0.19328366441186517, 0.21152440749574453, 0.12180554404039867, 0.06871175748528913, 0.11008375193341635, 0.13454297266434878, 0.18017407099250704, 0.15772775514051318, 0.3395614761393517, 0.18508279899833724, 0.07263123232405633, 0.10664885499863885, 0.09535747143672779, 0.12020117661450058, 0.19112613721517846, 0.11338298427290283, 0.1484824949875474, 0.1768480916507542, 0.160089714336209, 0.1592975013772957, 0.12285208358662203, 0.21911328309215605, 0.12769507215125486, 0.10665467343642376, 0.11043219768907875, 0.19039470615098253, 0.0947647329303436, 0.10853457060875371, 0.12690297793596983, 0.13442893425235525, 0.12640382425161079, 0.10154903880902566, 0.14040794310858473, 0.14545910409651697, 0.07760068285278976, 0.1609095500316471, 0.19140304735628888, 0.17153803986730054, 0.17844966117991135, 0.11149426296469755, 0.15432885236805305, 0.18736429454293102, 0.1343079938669689, 0.15246937167830765, 0.20138052524998784, 0.13333995128050447, 0.1495843764860183, 0.14896903216140345, 0.09317299685790204, 0.13490383455064148, 0.14208688895450905, 0.104313242045464, 0.12952989869518206, 0.09244069748092443, 0.12145121305366047, 0.15934060531435534, 0.11819881765404716, 0.12043529452057555, 0.08447485539363697, 0.07570382760604843, 0.21510307327844203, 0.11410760984290391, 0.11280693666776642, 0.12513156048953533, 0.2084112464217469, 0.11412160674808547, 0.23448765889042988, 0.10703826730605215, 0.16605738317593932, 0.11493422876810655, 0.0869692731066607, 0.24427954049315304, 0.2293178581749089, 0.18815468181855977, 0.14859205082757398, 0.12893275183159858, 0.1273477025097236, 0.15023044572444633, 0.09179220141959377, 0.09653877015807666, 0.20955434680217877, 0.18106118979630992, 0.08058223145781085, 0.15233568119583651, 0.12926670344313607, 0.12210270739160478, 0.20579955453285947, 0.16769580775871873, 0.19509658275637776, 0.1573663589078933, 0.08307754716952331, 0.15264189132722095, 0.09411930193891749, 0.07458248699549586, 0.14252496388508007, 0.10477005620487034, 0.1284986102837138, 0.1512234244728461, 0.1243023737333715, 0.1658225676510483, 0.18974292237544432, 0.10305444084224291, 0.2302054371102713], [0.04810966376680881, 0.07045373393339105, 0.06732941095833667, 0.043910707245231606, 0.03819604025920853, 0.030969028448453173, 0.016389951088058297, 0.02069478425255511, 0.03944634387153201, 0.026216494698019233, 0.06009170108882245, 0.013083306548651308, 0.02486046101694228, 0.02052657277090475, 0.017971263696381357, 0.04260053829057142, 0.04346195280959364, 0.047793872508918867, 0.04174474182946142, 0.01039657239743974, 0.04552759841317311, 0.04303604539018124, 0.04051861367770471, 0.03138036008749623, 0.019335208671691362, 0.03090856938797515, 0.05490555085998494, 0.007002322890912183, 0.02775085718894843, 0.07626314720255323, 0.027878825712832622, 0.039733291559969075, 0.10692144584027119, 0.05845456413226202, 0.044692674855468795, 0.0034521662473707693, 0.07951123814564198, 0.047810671021579765, 0.03937574336305261, 0.015232312034640927, 0.028565137909026816, 0.0735396878735628, 0.023053882468957454, 0.010022274855145952, 0.06600123379030265, 0.05465326517878566, 0.07253182906424627, 0.06842840550234541, 0.030289792630355805, 0.05700790308765136, 0.045424840645864606, 0.05565703475440387, 0.04997041352908127, 0.03339647104439791, 0.017282530243392102, 0.04531242753728293, 0.03996817387815099, 0.06386631241184659, 0.021091785019962117, 0.048501591954845935, 0.010475373637746088, 0.025381426421517972, 0.02324368673725985, 0.07259837002493441, 0.0038726580760339857, 0.06740326207363978, 0.03193508578988258, 0.05296051167533733, 0.04074129508808255, 0.024055178837443236, 0.010105824912898242, 0.017004189612634946, 0.026874583018070552, 0.03476551457424648, 0.033415625875932164, 0.0589306704205228, 0.08870590609149076, 0.04215693807054777, 0.009929134394042194, 0.025191919012286235, 0.0629599200328812, 0.03103875136730494, 0.04864133836235851, 0.008481093882437563, 0.05485735950060189, 0.011141409431729699, 0.00963194785072119, 0.0783208035863936, 0.028986000579607207, 0.09783732079085894, 0.07851653019315563, 0.05238598918367643, 0.005046087480877759, 0.011693080268742051, 0.030883236177032813, 0.02642457064212067, 0.013625171759485966, 0.006374554550347966, 0.030876499331498053, 0.01482957910411642, 0.026940155476040673, 0.06874661616166122, 0.006957057448744308, 0.05775047007773537, 0.08399878250202164, 0.041401442867936566, 0.041332712571602315, 0.1543264923384413, 0.056081120201270096, 0.025463149868301116, 0.08761939447140321, 0.026523361630097497, 0.09014740920974873, 0.04361950333986897, 0.03261518992076162, 0.03040720781427808, 0.024789853086986113, 0.017850492149591446, 0.0634954018460121, 0.01563765083119506, 0.06226419369340874, 0.039909340121084824, 0.14891347498632967, 0.03104942345089512, 0.034095473965862766, 0.04086489607288968, 0.051815685801557265, 0.06802838048315607, 0.046398041158681735, 0.045722590293735266, 0.022140012952149846, 0.024461920293106232, 0.11744489951524884, 0.057930251641664654, 0.014822704033576883, 0.051360200086492114, 0.06407000968465582, 0.02047394707915373, 0.08517790673067793, 0.030015901174920145, 0.023750228501739912, 0.042192167820758186, 0.023803787444194313, 0.06862167560029775, 0.048335536412196234, 0.0032873635427677073, 0.03777384357817937, 0.018377836313447915, 0.029883926908951253, 0.08739315075217746, 0.02400953304459108, 0.024935332585300785, 0.04806705706869252, 0.025872731894196477, 0.04594298960000742, 0.037820008874405175, 0.06780368785257451, 0.027818891721835826, 0.04956701915943995, 0.03444453941483516, 0.051445602730382234, 0.019587071328714956, 0.0835417902271729, 0.01898462367535103, 0.04163853678619489, 0.025597899766580667, 0.014449854606937151, 0.03273257170803845, 0.0739389484806452, 0.04859118031163234, 0.03558933560270816, 0.028683907512458973, 0.07790219518938102, 0.019189181839465164, 0.040084850625135005, 0.003107097495558264, 0.03596104397729505, 0.055755276553099975, 0.02691559409868205, 0.02083502975438023, 0.0179672041485901, 0.04389668065414298, 0.04663690138841048, 0.02145853213733062, 0.023538157947768923, 0.07025045226328075, 0.040062612170004286, 0.06424606195650995, 0.059758810748462565, 0.06115938813309185, 0.04754943503940012, 0.03452541866863612, 0.04605373658705503, 0.028688785278063733, 0.05273330687487032, 0.00943176464716089, 0.021713437599828467, 0.030085672333370894, 0.024656919595145155, 0.031097377323021647, 0.0003337463613206637, 0.017800523346522823, 0.046404546083067544, 0.04761936390423216, 0.020017754468426574, 0.04867714327701833, 0.03274225673521869, 0.02229825739050284, 0.08321894856635481, 0.025515133602311835, 0.047713345775264315, 0.05260611018456984, 0.005475387442857027, 0.022966058568272274, 0.09966776124201715, 0.022200865350896493, 0.06800138857215643, 0.04461243013793137, 0.06579182198038325, 0.02189633061789209, 0.06678477846435271, 0.0931088233483024, 0.05204536937526427, 0.028392870590323582, 0.018532757785578724, 0.1116287030163221, 0.023059595150698442, 0.010910801884165267, 0.03408784839848522, 0.03551867943315301, 0.050464093874325044, 0.0321655634616036, 0.05596361224888824, 0.016376969069824554, 0.09059695774340071, 0.036968910208088346, 0.026101007242687047, 0.0066176468772027874, 0.03562574536772445, 0.026330362416047137, 0.07321062701521441, 0.07096346322214231, 0.08767079561948776, 0.03921782918041572, 0.01301309474001755, 0.026313328271498904, 0.023452803543477785, 0.012336528798186919, 0.03279651886259671, 0.043348760445951484, 0.05639919727400411, 0.00381794926852308, 0.01857660387031501, 0.04264248076651711, 0.03182339256454725, 0.04301251930883154, 0.01896441313874675, 0.010596427200653125, 0.042441544283065014, 0.011404443266656017, 0.06858871682197787, 0.012961239026481053, 0.09670941217336804, 0.005809184131067013, 0.028346113431325648, 0.07688709301874042, 0.03118092274235096, 0.13404319557594135, 0.02622468429763103, 0.011013070761691779, 0.03281906530901324, 0.01704123948002234, 0.02557146075560013, 0.025534216074447613, 0.07356852773227729, 0.016864035023900215, 0.017228687429451384, 0.07070814215694554, 0.058315619244240224, 0.0540597882354632, 0.05140133362147026, 0.033569699444342405, 0.04262377493432723, 0.027235029301664326, 0.03247026332246605, 0.012674362769757863, 0.07683448216994293, 0.014580427141481778, 0.08912264427635819, 0.021807903722219635, 0.032926565399975516, 0.00867243161337683, 0.09879650955554098, 0.04737691910122521, 0.023781615782354493, 0.03616148322180379, 0.0964900926919654, 0.01982397043320816, 0.10022795657278039, 0.046385257664951496, 0.052933230326743796, 0.051761141658062115, 0.04123165061173495, 0.044729637520504184, 0.016755644355725963, 0.010739520694187377, 0.0067736569872067776, 0.03314093475637492, 0.012292911851545796, 0.04269520293746609, 0.058809158581425436, 0.044503534809337, 0.08854638886987232, 0.029165114210627507, 0.054430550371762365, 0.013154554580978584, 0.004600824386216118, 0.036033462747582234, 0.037256985960993916, 0.041588623644202016, 0.027169373352080584, 0.0066276394318265375, 0.014246951432141941, 0.020034760782436933, 0.02983610291266814, 0.028811764714191668, 0.01815359453757992, 0.012351202913123416, 0.02708070711378241, 0.007265494023158681, 0.025392827665200457, 0.02573080357251456, 0.05406094598583877, 0.04829458841413725, 0.03715336359164212, 0.065716672106646, 0.04141155463003088, 0.042148433058173396, 0.09212883218424395, 0.026860875550482888, 0.04396875803649891, 0.004028823341286625, 0.06092941141105257, 0.0281327719494584, 0.04034170793602243, 0.029340782421058975, 0.012901317095384002, 0.029770706714771222, 0.056851625340641476, 0.025617509163566865, 0.044344236521283165, 0.019807281387329567, 0.13473210157826543, 0.2837395027745515, 0.09721120790345594, 0.16621684102574363, 0.09457495834794827, 0.14496419549686834, 0.09365698846522719, 0.10061127584776841, 0.14347834163345397, 0.13719223206862807, 0.15245084767229855, 0.1685935095883906, 0.1523067374364473, 0.12493940361309797, 0.16133674507727847, 0.10487146326340735, 0.17173188884044066, 0.21990559995174408, 0.126002129400149, 0.08474768372252584, 0.18507865781430155, 0.11411526138545014, 0.07103490977897309, 0.19259743014117703, 0.10280425543896854, 0.21199259877903387, 0.12170573259936646, 0.10934973819530569, 0.11825589623185806, 0.16518996097147465, 0.15537155501078814, 0.14041962451301515, 0.320464264950715, 0.11098018469056115, 0.09779053580132313, 0.10818119699251838, 0.1709172927075997, 0.10541185067268088, 0.20899016613839194, 0.1252282178029418, 0.2547807520022616, 0.3737452731002122, 0.11426810669945553, 0.13291901996126398, 0.18284041463630274, 0.16756538272602484, 0.12391621945425868, 0.13668602798134089, 0.1040813654253725, 0.17856459016911685, 0.18984507158165798, 0.18055342719890177, 0.11775047882110812, 0.14079409738769755, 0.14158697827951983, 0.14135660079773515, 0.15917771874228492, 0.14727368485182524, 0.09269308706279844, 0.1315081081702374, 0.09356674330774695, 0.08688691697898321, 0.06781455289456062, 0.14186335407430306, 0.0949257418687921, 0.1783123193308711, 0.1557657541707158, 0.18063730472931638, 0.09010875815874897, 0.10974211909342557, 0.14035621541552246, 0.16821505880216137, 0.07502833963371813, 0.10400092403870076, 0.1292865930008702, 0.1540739246411249, 0.1693428709404543, 0.12146788911195472, 0.13003579108044505, 0.06357832200592384, 0.1329372322652489, 0.07945401855977252, 0.17574104480445385, 0.18284703459357843, 0.176211180514656, 0.07758114952594042, 0.1469252465176396, 0.24922829994466156, 0.1643388660158962, 0.2009496936807409, 0.1839824760099873, 0.3081386169651523, 0.07955667984788306, 0.12285165314096957, 0.10692438474507071, 0.06966310174902901, 0.12375740727293305, 0.15260561514878646, 0.1643391777179204, 0.09088528211577795, 0.14235109352739528, 0.15569430019240826, 0.1483977268799208, 0.15290147974155843, 0.1569341914728284, 0.10449670837260783, 0.08640692554763518, 0.2074400126002729, 0.14605720090912655, 0.12790419452358037, 0.16497298667673022, 0.07196873193606734, 0.2466476001427509, 0.1541309364256449, 0.14976200211094692, 0.15095233276952058, 0.2208680467447266, 0.16404913156293333, 0.10992594907293096, 0.112361692590639, 0.2291063906159252, 0.12514877831563354, 0.27930401265621185, 0.12531674117781222, 0.11440215341281146, 0.26171048171818256, 0.17712696106173098, 0.1148518874833826, 0.10695390737964772, 0.12997227808227763, 0.11882769875228405, 0.1172340998891741, 0.18078760447679088, 0.10612912898068316, 0.10120389561052434, 0.12373244142509066, 0.1935035627684556, 0.11369580694008619, 0.15094603935722262, 0.1263111300067976, 0.13832538767019287, 0.15902391605777666, 0.06651552728726529, 0.20160615298664197, 0.1397151779383421, 0.10073770070448518, 0.09674617816926911, 0.12361637694993988, 0.10247014797641896, 0.172043694765307, 0.08727663356694393, 0.09969326143618673, 0.16079668421298265, 0.1275638010702096, 0.08558242174331099, 0.12237410337547772, 0.1764717188780196, 0.15034736366942525, 0.14295288623543456, 0.2567967219511047, 0.15111798013094813, 0.1577236139564775, 0.2616899093845859, 0.12895086023490876, 0.10000249210861512, 0.12334938932326622, 0.13690168125322089, 0.2400238875998184, 0.1251015777233988, 0.10588330740574747, 0.14975845464505255, 0.1112310157623142, 0.08684399115736596, 0.10418925143312663, 0.1423024234827608, 0.11610613932134584], [0.026268393085047137, 0.04177299910224974, 0.022111911530373618, 0.06502390693640336, 0.04373892974399496, 0.03309028317744378, 0.10009883771999739, 0.018976988831127528, 0.029422613479255233, 0.013505963361239992, 0.08034219121327624, 0.03661590766569134, 0.036960497964173555, 0.045046356462989934, 0.04543735325569287, 0.053633053321391344, 0.021279318316373974, 0.01789183348591905, 0.05400059082603548, 0.003071257328883803, 0.02634328691783594, 0.053369308880064636, 0.018129866220988333, 0.014008047601237195, 0.020388607517816126, 0.06450612534536049, 0.040191404477809556, 0.056864842990762554, 0.06315388774964958, 0.02520972313504899, 0.007046902310321457, 0.05902806617086753, 0.06930792471393943, 0.040050370444078, 0.08834037609631196, 0.06550305974087678, 0.03238162491470575, 0.04265013230906334, 0.029496442330128048, 0.030456187705567572, 0.057859491571434774, 0.052849456697003916, 0.02549296750657959, 0.028359791213006247, 0.036508526318357326, 0.03157551895128563, 0.021448611478263047, 0.04713392881967593, 0.0964097106771078, 0.050538364303065464, 0.029718802761635743, 0.02670660902367672, 0.05691694175766315, 0.0696994224563241, 0.016822524848976173, 0.027625918482954148, 0.01936652544827666, 0.030407066806219518, 0.05357123241992667, 0.027774526133725885, 0.03304142759589013, 0.01956880521902349, 0.023655684453842696, 0.0662660766101908, 0.02311892058060039, 0.049266646019532345, 0.019161392119713128, 0.09494749421719462, 0.02692586542252684, 0.05857066571479663, 0.0390667613100959, 0.06220060276973527, 0.020032677202834748, 0.01637010234844638, 0.028677565860562027, 0.04060887738887686, 0.034527407624409534, 0.035434256424196064, 0.0562136455118889, 0.03743183595361188, 0.02855118738807505, 0.021983666556479875, 0.011455455714894924, 0.03587216808227822, 0.008486542174068745, 0.045146884076530114, 0.010103434269694844, 0.03651259699836373, 0.031711168703623116, 0.07591418936499394, 0.07846970809623599, 0.017400466786057223, 0.025522605174046475, 0.0655891266069375, 0.03868587999022566, 0.044674061791738495, 0.04072933166753501, 0.011067202085541794, 0.07548164343461394, 0.05910084488277789, 0.034178969290223904, 0.04305252849007957, 0.029946148570161313, 0.04746242564579006, 0.02730832937231753, 0.023759484938636888, 0.046395035460591316, 0.052707398499478586, 0.04514993430348113, 0.04510641476372257, 0.0475528043898521, 0.05713472870411351, 0.005091094099043403, 0.029418234807963017, 0.03160349420795683, 0.05953096399025526, 0.03986816205724608, 0.04357476296718232, 0.01499091829828103, 0.053329726433730684, 0.05186382892134134, 0.1219171704724431, 0.013241552842373494, 0.01902832133055199, 0.06127144872152712, 0.03181960390065797, 0.04425710467330646, 0.028100640665797982, 0.09626162252970971, 0.031301803755923174, 0.02299273321114015, 0.029638118321599904, 0.022064549521019217, 0.012325056122790556, 0.04095569413038902, 0.023790280356479343, 0.05023068100854289, 0.08030449011130258, 0.06727665910148062, 0.02779336184175918, 0.01058184121575323, 0.04901781503576785, 0.0605017710768152, 0.011834304477815749, 0.02778027035674313, 0.07075911285937764, 0.07740619563264772, 0.0063670774125057505, 0.03725605085492134, 0.0328113061550539, 0.06816702109063044, 0.06038558785803616, 0.011650672095129266, 0.04421660567459185, 0.035036609988310374, 0.014519685137202032, 0.03992465433839243, 0.035427428665570915, 0.0403769042895874, 0.05667991463269573, 0.06726761974277906, 0.052569218023563735, 0.023796445748303086, 0.010471370678715175, 0.056376802967861295, 0.024413886640104465, 0.0851826935831923, 0.026281206264684442, 0.05869855631317478, 0.04099150646652561, 0.043025970735470764, 0.02001406784984283, 0.11201625253306702, 0.04918203005217947, 0.06996204625465907, 0.023655513759877067, 0.041768998926272616, 0.06011332356138155, 0.009811657982936595, 0.049346412051818334, 0.05962957315205131, 0.07439568100380711, 0.05488288195920177, 0.039567295389133506, 0.04370799331809394, 0.04290006167138927, 0.05211028874327894, 0.005739710759371519, 0.04349859264038969, 0.02239128931250889, 0.08631157441413961, 0.05288454172841739, 0.06241240058443509, 0.02336515590286581, 0.018614625951158814, 0.03379507856152486, 0.023102990380721167, 0.06654026306932792, 0.024116873573802877, 0.03463140848907642, 0.03196977748302743, 0.01438114843040239, 0.05323443838278763, 0.008943507546064211, 0.019363887113286182, 0.04652947551221587, 0.035346423246664926, 0.0422617924050428, 0.07612918212544173, 0.08492024047882296, 0.018867633370973635, 0.03118386164715048, 0.036594478151528165, 0.03267679188866168, 0.03135236256639473, 0.04097883800568525, 0.01780794482328929, 0.031242569239111617, 0.03933323314413428, 0.030382221557374578, 0.02514846812118776, 0.029230755317257717, 0.04961448321409989, 0.029324644419830292, 0.05661487281031441, 0.03830333997029811, 0.03295111935585737, 0.053188402962405235, 0.02569355518062366, 0.0786418269854039, 0.011243849930906435, 0.033763203318812884, 0.088522469450254, 0.09036232033395208, 0.02181422310968628, 0.016047010212787427, 0.08453332920907997, 0.051684266290976666, 0.06386941458913498, 0.015215965304378187, 0.05102463059301954, 0.035208357803639956, 0.026628520245139953, 0.046170647110557184, 0.011464840172266122, 0.05433857972093392, 0.026305272258468904, 0.015589821268804371, 0.05970148355117999, 0.01701601573586231, 0.026888015891017858, 0.07018669435638003, 0.09383635813719593, 0.07886997802415863, 0.049643319362076, 0.03059808448597323, 0.06606049428228289, 0.03612660970247816, 0.043386457837186754, 0.09467070281971246, 0.018819800097844563, 0.061843622315791436, 0.01403226759066456, 0.011200211647519609, 0.03409518081753049, 0.05524147658434231, 0.006618678462473326, 0.017931362126546446, 0.009473428817727836, 0.034487817756598815, 0.02091694430419011, 0.07096506626112387, 0.07413053390337154, 0.02939031706773676, 0.038237737826420926, 0.026786337948578876, 0.021192501881159842, 0.04521558839769568, 0.03184538240020629, 0.03004223071911838, 0.01262955282072653, 0.020504017047642265, 0.05856758580193855, 0.0950844278850127, 0.03929766942746937, 0.08153010989190079, 0.03296183225756977, 0.11715546934283338, 0.04841184774704743, 0.027510425461514387, 0.020453038923733402, 0.034823862224584445, 0.04217478672217112, 0.0011556245863175718, 0.04416644762386568, 0.04862029476498719, 0.05423697970400099, 0.05167078517843038, 0.05129409328219481, 0.021325119960238226, 0.07730766068561934, 0.032656275216140784, 0.07650032275705598, 0.022814100120740477, 0.06261844304390252, 0.048499469412490726, 0.059896750026382506, 0.02064510674244957, 0.045953216394991614, 0.03967711098084692, 0.060278570163063705, 0.017950119909073692, 0.03648915626399685, 0.0649446010356769, 0.012993708915018942, 0.0075331880816520425, 0.01683152895566309, 0.024592276677140035, 0.06617279606871307, 0.004354400280135451, 0.04193669090454932, 0.07810399998561479, 0.019077034048677888, 0.020038506772834808, 0.04311218603106681, 0.07175661870860495, 0.07324289559619501, 0.03424442300456576, 0.02015476049564313, 0.04453153604117688, 0.0016563265762670198, 0.0289853827416664, 0.04347710375441238, 0.012946302376803942, 0.03642725001554936, 0.033243651705561206, 0.03351814615598414, 0.03901217263774015, 0.029462860147759784, 0.047204751972458325, 0.05586726663750596, 0.05500037135789171, 0.08155457107932307, 0.04313952675147448, 0.03957152563089039, 0.07199677027529106, 0.016821496974444017, 0.039331181105808355, 0.07906397542683408, 0.02114547198289074, 0.08411430520936847, 0.01371543361528893, 0.12353686324786395, 0.07681687842705287, 0.11168926226673648, 0.14021375274751335, 0.12219580981764011, 0.1317474211100489, 0.1756936957826838, 0.11275638156803325, 0.2805210161022842, 0.09340036122011952, 0.13068499218206853, 0.12446430293493904, 0.14382332155946642, 0.11447619006503373, 0.19449012936092913, 0.18762989435344934, 0.17589466937351972, 0.0945826544193551, 0.14000443741679192, 0.11396936257369816, 0.11532089512911625, 0.12195499031804502, 0.14976473321439698, 0.17842303292127326, 0.11646141283563338, 0.1653639055439271, 0.11009092107997276, 0.14584316551918164, 0.12683949462370947, 0.18021558673353866, 0.18049602949758992, 0.2707302774069831, 0.12039570094202645, 0.18769083952065557, 0.20106748735997826, 0.14644786744611338, 0.1324984894017689, 0.09490131036727689, 0.17439817311242223, 0.12103073444450274, 0.12104502820875496, 0.14486446569208056, 0.13453623396344483, 0.0984287828032393, 0.12397622951539233, 0.10231771826511249, 0.10412920426460914, 0.04238672925566789, 0.21731710759922862, 0.1459006968070753, 0.13065463834209368, 0.10953956472803839, 0.15398419898701832, 0.1199738345167134, 0.10435751857585274, 0.31397442100569606, 0.11965209123445675, 0.13578149839304388, 0.20339544134913012, 0.10221265241852961, 0.18177890597144142, 0.12852256681071594, 0.13605815620394424, 0.1893239057972096, 0.1218504439748358, 0.17480777925811708, 0.06985617146710865, 0.14534114714479074, 0.09376383546623401, 0.12090033167623915, 0.092808491026517, 0.1296333986101672, 0.09730845151352696, 0.1217325241304934, 0.18180280312662944, 0.1212977220711764, 0.13535363541450351, 0.16992161254165694, 0.14174625801388174, 0.10262845549732447, 0.16371446748962626, 0.1806614245288074, 0.09213563025696203, 0.1306772738462314, 0.09277643766836263, 0.17238796222954988, 0.12863112817285582, 0.09432789738639258, 0.12993588316021487, 0.24629653460578993, 0.22283338737906888, 0.07068005928886123, 0.13733242376474664, 0.0814282352803275, 0.06267559583648108, 0.1586073634098284, 0.13580975937657058, 0.1613977347733453, 0.1532856302219443, 0.13801904395222664, 0.09516862453892827, 0.1287111613783054, 0.10543329131905921, 0.24896649993024766, 0.152305475785397, 0.07996239713975228, 0.14059445966267958, 0.11843998596305028, 0.11562994768610224, 0.1991834564250894, 0.16412493452662602, 0.16277795133646578, 0.11628909356659278, 0.10560455673839897, 0.10523801000090316, 0.14268283353885636, 0.11779323394875973, 0.15154419554164633, 0.1310947467572987, 0.14230496162781492, 0.21783724921988323, 0.1952993671875447, 0.14934660721337423, 0.11097846290795133, 0.2764818031573668, 0.09654928639065474, 0.24052557942923158, 0.13320160011062399, 0.22084360040025786, 0.17235202743904665, 0.182364163629245, 0.11338863943819888, 0.16036655026255175, 0.11306990927550942, 0.2516430406831205, 0.08389441427425481, 0.13120125979185104, 0.2031857697875239, 0.16053915896918625, 0.14802384772337973, 0.09251381387002766, 0.1260350362281315, 0.13477602187776938, 0.101734649942955, 0.1226313243387267, 0.17971664085052907, 0.1333716558292508, 0.12878976966021582, 0.13811111479299143, 0.1356067374581471, 0.16934860032051802, 0.13345321785891429, 0.09198095183819532, 0.10894117105635814, 0.15316648583393544, 0.16361194720957428, 0.14749861496966332, 0.07885362108936533, 0.14812008943408728, 0.13378829753492028, 0.1880508108297363, 0.08660293417051435, 0.20652684441301972, 0.10684866341762245, 0.1253649510908872, 0.16743905434850603, 0.18069930374622345, 0.2232973781065084, 0.1466033622273244, 0.16345413692761213, 0.13203678448917344, 0.08400636725127697, 0.1743711144081317, 0.16407679882831872, 0.1524307651561685, 0.12002867180854082], [0.06403172228601761, 0.013722392177442089, 0.09020166762638837, 0.06279029475990683, 0.041925562400138006, 0.017007618334901053, 0.034776502070599236, 0.053397766532725655, 0.023296893159567844, 0.12185595813207328, 0.01072250046490808, 0.03334190834721085, 0.08243793461588211, 0.016925659256230574, 0.11507476927363314, 0.056584285193821415, 0.032140660696313716, 0.048401958629256114, 0.018020139686996117, 0.05590056309301872, 0.018934261534013785, 0.03749776464246679, 0.07342579046962783, 0.054517526368726976, 0.06704041123157367, 0.05158455875061918, 0.09507550726993941, 0.018260309807374142, 0.04063150176079944, 0.02292745946760988, 0.02239622644992778, 0.0520188709924696, 0.012513611727626994, 0.05816667020553723, 0.0411032071133377, 0.022644808814220596, 0.02638673595356522, 0.029899287510488648, 0.010391912637714995, 0.009639929648983525, 0.02884609089960577, 0.02824651721311966, 0.027082111628260463, 0.05485497720655985, 0.025304252339992672, 0.06505527009721845, 0.030109816252661403, 0.04319503939768765, 0.016053782310336828, 0.025076385172724258, 0.03589618769183289, 0.04648069414542988, 0.016909122350625694, 0.04111108501092531, 0.05204444911214523, 0.013144256354280515, 0.026964718708768487, 0.05503846950887237, 0.08099063532426953, 0.007638573979420471, 0.08349775118404068, 0.06508765000035055, 0.05172198223590385, 0.04306708571675699, 0.014980667383497348, 0.06163504542200826, 0.009895440889522433, 0.04214615095406771, 0.01729983341647312, 0.017346612839901354, 0.06891582583193667, 0.03555481460352894, 0.019405523453315254, 0.02908953760197619, 0.026447035452292766, 0.03912105683411937, 0.04566529649309814, 0.06310926240985282, 0.06290134973824024, 0.04913806522381492, 0.03870132779411506, 0.05374726613808889, 0.023950552713358775, 0.01935131698701298, 0.04470253799809143, 0.04081434839463327, 0.04238027999235783, 0.07225226945593022, 0.03202030660759192, 0.03483362146653235, 0.01765233500918839, 0.03751401025510859, 0.018718838327913545, 0.05344046599930152, 0.0226356451457832, 0.040277552980114706, 0.0226517349074129, 0.03961045127653051, 0.051107895851600915, 0.06358622587868012, 0.03520909624057822, 0.04897709710348863, 0.015038694982649758, 0.03145117952954024, 0.02685166178707732, 0.05896029695577454, 0.060424116454669274, 0.0693770038196817, 0.06735459202900529, 0.020017194146930706, 0.05169881980691571, 0.09233076314558275, 0.03300164476968348, 0.027965953850070946, 0.027476056602608878, 0.009696510060166474, 0.07579677418107167, 0.022164240363053977, 0.04677839555370156, 0.010314402734366013, 0.02543844562751474, 0.022940745766391046, 0.06480679163360037, 0.0570502982736798, 0.05083455173007678, 0.02309093419171404, 0.012595133866852848, 0.03622912998253014, 0.031088260038814042, 0.028236744983587414, 0.027106899360660464, 0.020577357936417684, 0.05675644861184992, 0.026578145116218366, 0.042785244004335254, 0.03333093198307324, 0.05154824546480086, 0.034024517226498574, 0.06631523647229187, 0.03182289161486551, 0.039428565723937936, 0.04691223817644641, 0.013753524344792822, 0.025425749336136505, 0.02430021188047249, 0.03826533087703865, 0.005989912397126318, 0.06332703080261126, 0.05754796395194717, 0.04643037653295323, 0.03692663005494978, 0.010310396992281312, 0.05791078139736783, 0.026702462273533456, 0.02998329120600829, 0.023427913765772246, 0.013738385459873825, 0.04467752391065005, 0.049346185696776956, 0.07751077166176401, 0.026768099669425283, 0.018735692501650192, 0.008784180499787908, 0.05581201003224123, 0.021564902308455203, 0.1238929976534564, 0.02531370544602396, 0.05789635033579543, 0.025270872392866295, 0.006394437150447629, 0.041562696715118363, 0.026951139261655044, 0.04530230464297347, 0.023187129518191796, 0.03426499533816241, 0.038758380396757275, 0.035163302018190734, 0.00828058598926873, 0.08095052224234678, 0.042259506590198725, 0.09285477877710946, 0.06306091891019605, 0.03555746778147295, 0.04644603584893048, 0.008808086004137294, 0.08784436169662513, 0.048184724582824856, 0.009118199832300888, 0.02108009433868574, 0.007139737563193194, 0.056649030157132074, 0.07023719008429907, 0.030430529805016704, 0.029979350401845295, 0.04348684073192999, 0.045901151024736464, 0.03219693033315707, 0.03999774846306536, 0.06655414123088121, 0.0484073614643421, 0.0267386382620316, 0.0329935405170545, 0.08661784391733818, 0.05082849951577373, 0.0368465745850699, 0.0397300112672383, 0.011417698951845523, 0.01783504063496366, 0.04526724558672868, 0.05452253586554434, 0.04769339684571605, 0.008312417630804703, 0.027214048786845524, 0.019837555446429178, 0.04037221762700938, 0.05271341731713619, 0.03709412907483056, 0.0862810350372456, 0.016689318617864046, 0.03301957876828965, 0.03346860779856797, 0.03232732939068228, 0.062015666990191676, 0.04960583719366696, 0.036910736962454394, 0.08532379069947638, 0.025596910854801536, 0.008038220967137022, 0.05694438637874555, 0.0406857119378401, 0.05322328761394601, 0.025314560771221295, 0.06500368341221474, 0.03789451679040212, 0.030401129624806345, 0.05988943616102915, 0.08698763384018093, 0.06909514355356805, 0.08501901291310787, 0.017055230819096323, 0.02757510548690334, 0.11149099751492031, 0.008647178183309734, 0.01011777441817685, 0.05248727749858517, 0.04294951468182262, 0.06793803884647787, 0.04326930982642807, 0.04513102809141856, 0.04239095578668639, 0.051975462774862535, 0.1062936928065028, 0.05471382071846165, 0.028158515196992084, 0.0527156734460732, 0.062157472857506946, 0.03326263955386821, 0.015584229186060838, 0.0473043519014027, 0.0334347844182048, 0.02682887228729669, 0.054108918411657214, 0.05307046456437092, 0.0990189980075229, 0.012446012278815033, 0.07638515628059395, 0.04621913903974928, 0.0064327273321396206, 0.0374893078696914, 0.025290771227446385, 0.0313387589994818, 0.011269604310655268, 0.08309093551361002, 0.040342746942769736, 0.039272989306482486, 0.05511429102625698, 0.09041200712090358, 0.05209161630773451, 0.04418798103870358, 0.05400135894888081, 0.04378110599645879, 0.05425344796094578, 0.04015739184978884, 0.07115719345165417, 0.022227758927328978, 0.06715687646646984, 0.029857263398298528, 0.032822030188981444, 0.006724280510752578, 0.04710325214546174, 0.02581598913820926, 0.042244793512509204, 0.043256162680336274, 0.014512887992168544, 0.011092188342445297, 0.04299765409086831, 0.01964966406376334, 0.043080273680971004, 0.007948265247250674, 0.028569635323947296, 0.03809523805102799, 0.011287638499197783, 0.021328576513042208, 0.01392392516208929, 0.06681567407213151, 0.03200824299710803, 0.007708328903390793, 0.06732880239724182, 0.05060377348854672, 0.02149551521142712, 0.010802179294842063, 0.017715578978823032, 0.010228661485598423, 0.015296368655981496, 0.04282544985471759, 0.06297741987509653, 0.034637976496014744, 0.0650410505477339, 0.04007769632153213, 0.028650100830418523, 0.014904312447470147, 0.01556012701257714, 0.03268804284743965, 0.025477367562416475, 0.04680808888224419, 0.045348124840529636, 0.012631988920475123, 0.02417430281639099, 0.05182304419577122, 0.028281240447540767, 0.005559212559091975, 0.060374930617399514, 0.03974773004301824, 0.05036764436226804, 0.030036089447094128, 0.05138866887136828, 0.05459086911287159, 0.04303680238081142, 0.04077048375620507, 0.052007352860528044, 0.007063455450406764, 0.02538872173317941, 0.02215114887803793, 0.050350322635495104, 0.05847163723956328, 0.02505475527868839, 0.06041387852746993, 0.05514906435564626, 0.025324381240352523, 0.047145398712018505, 0.03489380222163163, 0.05359581235097721, 0.15720056311693043, 0.04355891069280915, 0.16731413605157286, 0.10424725769553334, 0.17770631122402847, 0.1344018755480647, 0.10535164023167454, 0.1256066537462175, 0.08714381881873123, 0.2809554693521932, 0.10215133617748506, 0.0843808994977735, 0.13581471692305058, 0.12580151204019785, 0.24322322686202824, 0.15000704443082213, 0.12097159269615076, 0.0938364100875333, 0.15474662213819101, 0.11800295003922656, 0.08114145457511768, 0.10191669134655967, 0.15594406257150695, 0.16780288482550532, 0.20861582685029134, 0.11015462703653611, 0.2823245240142569, 0.1375639738398604, 0.16492966009536758, 0.09524974870146252, 0.12048423173837364, 0.14358158921822906, 0.16923224640777335, 0.16922994574997574, 0.26516155747231096, 0.10250992709188722, 0.05679235371644609, 0.10266968180076219, 0.20192242664052173, 0.12085695314453915, 0.12137043027905747, 0.17620555503526703, 0.08108238704153337, 0.13074102433165535, 0.13353406742680818, 0.1008039373846259, 0.10366731381509453, 0.1214014075230807, 0.14282406424172223, 0.19474058935884386, 0.15950090921251103, 0.1679659791989252, 0.08408407753449865, 0.16606768418569118, 0.11129197577247396, 0.11368716091965325, 0.11806171329226345, 0.17721290176268667, 0.11099233364802785, 0.13172154984204099, 0.1854143460514024, 0.1390385173726827, 0.18208305293228477, 0.15871871524723247, 0.0611130335892085, 0.21359464328270406, 0.09029693712363951, 0.18091728736180812, 0.13986590813146904, 0.20385542447911575, 0.14937100902898237, 0.1146523685019929, 0.13157034467440099, 0.11736774584278464, 0.1852501681423746, 0.2869250677758828, 0.12854437110945582, 0.07891824730904773, 0.17650076653808355, 0.1726844353834167, 0.15966755105182528, 0.11697305686539039, 0.290815019980073, 0.2157400586293079, 0.13387417886406183, 0.10045612245448865, 0.11824075641925447, 0.18658178887562826, 0.12523212149972096, 0.13429549610009417, 0.19182650197762996, 0.11831563911982812, 0.0914858651231043, 0.14415507641388103, 0.09362869779579341, 0.1145680902118329, 0.1492346913437359, 0.12090663993149064, 0.19494732201565057, 0.1893324256525375, 0.1263965808902867, 0.14103553286986426, 0.13756314263446257, 0.3249946312280372, 0.073098110005958, 0.29463541810400784, 0.1636287197470665, 0.17941859434358776, 0.16994211066048592, 0.1691990575636737, 0.07811063478584401, 0.16459603502880782, 0.060758509644074365, 0.19396307092392817, 0.1745395374018699, 0.15703678596764803, 0.15714352164650336, 0.11773144273320213, 0.10990048598614521, 0.1544648435083218, 0.11420441558584571, 0.11475174207589589, 0.10603305796394125, 0.11696556117385626, 0.20131828874582425, 0.15109859523363411, 0.12415810764650814, 0.11016116535756737, 0.1418008652399294, 0.10178837401326746, 0.1787925185635686, 0.13423943426460028, 0.152622313471511, 0.15266256756149232, 0.13191528007155284, 0.1424570128438063, 0.1281213024049066, 0.17316027078777552, 0.1438348990632221, 0.12048368997056969, 0.1975687508820556, 0.1488390821032226, 0.17651433299761266, 0.12313647457631305, 0.15247220668243244, 0.12944413610966876, 0.10794439251185395, 0.19301540771266446, 0.22508538997499272, 0.1933122519403696, 0.07866737170843408, 0.1467268110718578, 0.31531916290987283, 0.07350506668444723, 0.09843313178862445, 0.11703749754815362, 0.10678559570806101, 0.14086084614973515, 0.16458571917610243, 0.13526181690394878, 0.10374428195063956, 0.0710680392512586, 0.07656779140233994, 0.1856032374780625, 0.1183710181794595, 0.15289205446606502, 0.09914718175423332, 0.12593667197506875, 0.09639128315029666, 0.09051021552295424, 0.19118626601994038, 0.09641103169997223, 0.10758421340142377, 0.16608871665084735, 0.14319766138214618, 0.15626179083483294], [0.04308989562559873, 0.01509334488218883, 0.051614240946946666, 0.04979523699148558, 0.036741126532433555, 0.06781788513762876, 0.08430762725765817, 0.03140275439363904, 0.03683940914925188, 0.06126577500253916, 0.10013286519097164, 0.02544264618336456, 0.051960705168312415, 0.039239822726813145, 0.05864247963472735, 0.019513773113430943, 0.06344008957967162, 0.02454095159919234, 0.02121638048265595, 0.04770542334881611, 0.04649488771974575, 0.03617289003159385, 0.05205302462854888, 0.06344771143631078, 0.044466798499342985, 0.054572230073972605, 0.032669003048795275, 0.03317542235890869, 0.029576184242614545, 0.0664453869103454, 0.08249011501902714, 0.02225710530183278, 0.04155101902142633, 0.0007286920754268067, 0.01653408915444743, 0.01173411732452223, 0.061973067713552155, 0.018909163954958785, 0.013086558083159616, 0.030177602166077122, 0.053268287738319486, 0.0063667786980659, 0.027439444602350704, 0.026042592799058184, 0.002772321404336253, 0.02223177951236721, 0.03263240403612144, 0.04156177274126094, 0.07614458168973215, 0.09410954269696958, 0.013764432060270337, 0.06014077560394071, 0.051924384461017326, 0.043931064356002025, 0.03072809206059901, 0.02029354767728364, 0.011013148687197827, 0.02109098535584053, 0.042190961830783635, 0.05639520080876537, 0.04567659940221347, 0.051463792769936845, 0.04181061485724058, 0.028920814038428944, 0.055602305073989555, 0.011143590418214444, 0.03797834608121775, 0.11777874722611159, 0.038511527236551046, 0.06591818004380912, 0.11790914257289842, 0.04662316794565413, 0.02202691150159808, 0.021698954587918706, 0.06045321606507059, 0.04682860555476509, 0.021748825056420173, 0.041504356486257166, 0.044533599211717956, 0.06165479397168383, 0.03825062893156428, 0.06890111646498553, 0.032386367238359526, 0.05623361670586746, 0.029825640485796612, 0.033542377277626656, 0.07497104583308101, 0.017615682190808002, 0.10272373241605237, 0.05012941866880283, 0.03743282301002182, 0.033160393868456595, 0.016302526091749314, 0.06781484233215451, 0.027772895264206454, 0.07004481798503548, 0.04527628123469185, 0.019637056830106303, 0.07036166309262626, 0.032762138871476054, 0.10274451997247525, 0.00895642833711463, 0.04336390396929346, 0.031048386299517006, 0.07264999381732196, 0.08553807841963135, 0.06990866357227787, 0.01194235468574334, 0.028221681241120677, 0.024764057889115065, 0.06498668823041953, 0.014394132304005325, 0.05919942064792849, 0.04167566272371914, 0.04334789584390819, 0.037423360627144575, 0.013650491055159364, 0.028263174717721995, 0.049118494789581746, 0.05170766249648295, 0.05336160167644266, 0.10514802459510975, 0.0358525865158299, 0.01539791579489247, 0.014834441099083051, 0.013958827439637389, 0.06583905225852504, 0.035550896063796245, 0.02867644521757029, 0.029632520672748797, 0.03636941815784667, 0.043562094506341964, 0.08061740183620714, 0.005663996853400022, 0.047352042311104015, 0.039442150737158954, 0.05116627689858433, 0.03927901554561686, 0.022676541193504818, 0.04013467470940668, 0.03630668070400134, 0.0358681011130102, 0.008370037048734957, 0.025601842426112853, 0.04574852835503407, 0.017923589985002764, 0.08769569467403926, 0.10378311111708172, 0.02511013804905815, 0.042273689032299444, 0.05187727292650379, 0.015482758117286721, 0.05248401947028469, 0.025952254873118363, 0.02951543574454263, 0.034635453193914145, 0.007949628943606513, 0.06277916254475713, 0.0328180337237427, 0.06256988432141952, 0.042583706381265074, 0.02253201906569302, 0.027994971824227832, 0.05707761301891878, 0.014518451316689607, 0.0391932010097662, 0.05263229315460194, 0.031484783976338804, 0.06377332130796276, 0.04990085944882594, 0.03310557884105947, 0.011376882684999146, 0.029911709207226522, 0.03702069727296475, 0.008187835155695211, 0.059452478162711486, 0.05834884890646208, 0.03409697310416959, 0.049898877914529294, 0.0613372735097073, 0.018866293794417288, 0.011800546963058878, 0.018557217117631808, 0.04048704642627854, 0.05178193292522337, 0.03202215455530677, 0.0538762922224123, 0.037851706001674756, 0.04459185780433472, 0.056820766840246506, 0.060034826601622626, 0.029593878898594994, 0.05017861563828774, 0.0342858237127075, 0.016406040849687997, 0.014357165928231552, 0.03463658125838265, 0.05211720184888691, 0.04548482844256796, 0.043955173023277894, 0.012926064937346382, 0.014953098452679114, 0.0319961422792403, 0.04414687347889412, 0.043590544737526216, 0.01611846048035659, 0.08121704231598414, 0.013629220175062073, 0.019942873623222113, 0.03966973032220267, 0.05133110789756756, 0.023719856108073145, 0.09170606776024215, 0.09256807970814407, 0.0383149397384841, 0.05536138538445812, 0.05031745291489642, 0.02870656713639619, 0.08852653641952202, 0.051835746053257026, 0.057654925985843875, 0.051971295615658164, 0.06212030981259886, 0.018282355304108933, 0.01395101447997149, 0.05371914987335913, 0.02702368605241645, 0.05303025129251182, 0.0737752158602234, 0.058894720787066035, 0.05517396712093614, 0.04689787390816491, 0.04955202035489492, 0.09817930986173451, 0.09724977731821127, 0.01092009450076148, 0.03361709670571145, 0.015425047786266077, 0.05649216240271926, 0.047220084743457846, 0.018438087572576478, 0.02360539281653473, 0.02138638054020703, 0.04299469292163849, 0.03394652121642139, 0.009055517111846711, 0.0227668216029997, 0.08591454767156392, 0.057051990370382555, 0.01432105580533971, 0.041530120142851956, 0.05437730498670135, 0.08886842158972286, 0.03006205162819242, 0.09487314586294815, 0.023451230190403294, 0.027799677518487442, 0.027044646158174146, 0.02000676697207382, 0.039286080791498534, 0.05438731284812093, 0.03285913757281378, 0.08760574637562968, 0.038101256868685596, 0.02519959281926276, 0.05096124375995714, 0.0784978354931809, 0.0383731463807635, 0.08133405674016103, 0.013041672063991427, 0.052279810115578584, 0.04931648123601917, 0.03449049319897313, 0.005304166552377865, 0.01237381429746165, 0.023374013435386587, 0.04686817686888389, 0.02095899253617972, 0.026665416116884444, 0.030105133300821763, 0.03314173998660408, 0.07541950340964831, 0.07063091426971368, 0.015350016656157095, 0.0707345106638968, 0.022075917368056253, 0.040254487030324526, 0.025481317643425427, 0.06239412890863605, 0.01219880381540861, 0.057229601152357645, 0.04892406694125384, 0.044438485565478913, 0.07297748874407262, 0.01446182823201525, 0.12233609057147987, 0.012401507538015721, 0.018780336395138875, 0.0679354190651793, 0.05030808701121714, 0.05870341366971843, 0.04211429797578603, 0.059392549737822264, 0.021929740250925533, 0.0336077233805554, 0.03888007406203542, 0.08196778406272642, 0.006885186940053245, 0.01447742910386296, 0.022423368645831943, 0.03832734473689925, 0.02296052400197368, 0.047800295797060244, 0.0363315871800296, 0.047693400556454435, 0.0772743827837985, 0.022080151320551522, 0.047546729911118746, 0.025515584457025398, 0.03754434554139152, 0.07473061225027777, 0.04310538795834873, 0.025359117462357972, 0.05244598811259493, 0.020945960422977805, 0.03674154955660924, 0.006167712890601251, 0.032851901632966474, 0.07303453763597645, 0.037469147428055294, 0.0377869387739338, 0.0223892725261976, 0.0067375547496340005, 0.06479611212853342, 0.0005713181531064038, 0.05315047179465182, 0.013393353583524004, 0.05494083998200949, 0.009500438354734797, 0.06586793664610013, 0.014913534560037078, 0.10266934041283093, 0.030041293757676613, 0.06258262699702755, 0.028616327545023523, 0.03030372830835404, 0.0338469917915063, 0.07466797498636879, 0.09345257130917162, 0.0313424994237721, 0.04467362763534766, 0.06275971827562898, 0.09094667257159017, 0.10432068578666076, 0.20269507658667862, 0.15531633922364563, 0.10576293847407214, 0.13070581684587523, 0.1723808969836682, 0.164105994917918, 0.14496256277197972, 0.10233086912194267, 0.17584740940947086, 0.18749771785223857, 0.14383081725100055, 0.24692485167179257, 0.14178551762597635, 0.0912180908198934, 0.15426360274432227, 0.0666514145268593, 0.12384187852148898, 0.10363913446781226, 0.10221373595413752, 0.12857895519118756, 0.1318116910988465, 0.136916835908778, 0.17207820463227108, 0.12803500547306612, 0.06923730194102973, 0.1713162416126579, 0.1310229513910599, 0.11907933876500465, 0.1999957815860398, 0.12193346803542227, 0.12515896058175713, 0.18294149514986202, 0.12410333714797162, 0.06722097576130182, 0.20429611176950857, 0.0991737209551502, 0.11139867434394546, 0.11332408743328415, 0.1257302807061933, 0.06556568216183223, 0.1671676806290634, 0.1641764841042459, 0.1632464543217793, 0.1419597293715924, 0.09223797242157161, 0.0802157366706524, 0.17774154839571565, 0.22250860871281475, 0.08717500386410393, 0.13324268540600315, 0.20358216570457444, 0.19799343746853992, 0.09820259845582768, 0.1262462217709981, 0.1276563765713945, 0.18069056124659255, 0.18138568644644693, 0.13606017484562472, 0.10810928288265131, 0.22052060288842767, 0.11706994424457662, 0.1135056687053293, 0.12641710869502276, 0.09759547712747008, 0.11080343479989097, 0.2624900930095464, 0.11268984802882187, 0.11101645344751887, 0.19685501261847094, 0.15137603972107172, 0.14008098252816126, 0.16920103167649359, 0.07404802192468196, 0.10052592886495404, 0.15975427842931822, 0.17914385127369314, 0.1453165672137402, 0.17705362202832475, 0.17440413997974247, 0.16111052362248302, 0.21499519469216466, 0.15459188434761018, 0.16025420394726098, 0.09592629052349366, 0.21126636274857447, 0.20125695766182616, 0.1920578145654872, 0.11365736369043589, 0.14321715018013492, 0.12020695794490166, 0.15043250285089016, 0.15334958850871772, 0.1744635563227348, 0.1466934589552693, 0.21585608599707484, 0.0902305000636261, 0.13788288953946903, 0.1452078128932044, 0.191467777476646, 0.12716501543764025, 0.11872979463078082, 0.08838172114337794, 0.12912505713757128, 0.1261681626783684, 0.14122436492471024, 0.09274142314097844, 0.22204305947525427, 0.1333159502246417, 0.24545789288822562, 0.10043573565781116, 0.17204960226081312, 0.10611487232381478, 0.18949468882055953, 0.210192400845699, 0.10356538725318387, 0.1516143581829965, 0.11841611107229255, 0.22693307051667944, 0.16994929464999586, 0.16652760794386268, 0.1189275695651304, 0.12576830835314468, 0.16119202628033236, 0.11722829629434273, 0.20075954060303047, 0.1555009261937812, 0.10378160455729812, 0.11673067143419757, 0.1678579076542519, 0.09941334559698589, 0.2870382007677108, 0.08310566714499146, 0.18502792459912598, 0.10016125233960338, 0.17862906795926392, 0.17987801344133914, 0.13900825259042904, 0.1337948878062889, 0.08362426509847865, 0.15619621466612443, 0.16310310107655823, 0.09974078857339919, 0.12884783529443666, 0.16139717074111104, 0.19389973604120314, 0.184972723654937, 0.10025895608123392, 0.08803465578239411, 0.12469575653085485, 0.08884396782377735, 0.15851306612603366, 0.10408048969111405, 0.07395675260340795, 0.1193936902564019, 0.07251791379530914, 0.19406738720135763, 0.1237454438523855, 0.09822651045396924, 0.09982861432945356, 0.12932141456985846, 0.17436560767237097, 0.1099156703276094, 0.0790211906132754, 0.2508445194689557, 0.19653237133752555, 0.1517147707636468, 0.15676305221859366, 0.12449598521925509, 0.1421944409958087, 0.16070590470917523, 0.18303470889804885, 0.15923876781016588, 0.10395048026111908, 0.21338304213713855], [0.04407579428516328, 0.06570209632627666, 0.06917746999533847, 0.06675884040305391, 0.02652623188623693, 0.048776494586491026, 0.01506439648437663, 0.04372925955976825, 0.019627703914011363, 0.02081932962028077, 0.020921078066749033, 0.06612327255425043, 0.0814395678753499, 0.04323842535086442, 0.06306874114670791, 0.02650411959621124, 0.00835644090329879, 0.05926073688897304, 0.025519059563521296, 0.008652358374092728, 0.05141736401128583, 0.050647523094085045, 0.0633542453579139, 0.03941857641621027, 0.08723846491193399, 0.014394181471288903, 0.0492248705268139, 0.01566974871821003, 0.016634960011288058, 0.051703027784242295, 0.06374623291776516, 0.05695860963896848, 0.03399032648303546, 0.03872621942718979, 0.034187656128779054, 0.03753805583983194, 0.16142127569764853, 0.05113635350426193, 0.02797850171191385, 0.05061910254880786, 0.02829850465786876, 0.03257067219237797, 0.018401581328362226, 0.03748825773072895, 0.029650979740836192, 0.022139037027955055, 0.06416539792553522, 0.03422040710574947, 0.02306038368260488, 0.0577197451639222, 0.04540483234450221, 0.009247496800526278, 0.0826219204463996, 0.023565567316836677, 0.05194301607843954, 0.03538353805197403, 0.12974478013347834, 0.03578158895834349, 0.03359747432114091, 0.03036206111573847, 0.008117087145365076, 0.08878973909304477, 0.06061124528059736, 0.0914574928174261, 0.020267730214982294, 0.0359590624429984, 0.06807028956245631, 0.033162701947730966, 0.0543994024337735, 0.01023201506541227, 0.04861111439822707, 0.02661024671397172, 0.06357666701660492, 0.023624881614523474, 0.007974626332725165, 0.14567735488526523, 0.04178261733613908, 0.03141564920952078, 0.04723568839835934, 0.07494679244700819, 0.08003679744433612, 0.10130474605830386, 0.038684406827087514, 0.0031209100234264042, 0.0359635784116108, 0.03506755754642654, 0.013172540529922117, 0.03543712111422792, 0.03833760863926727, 0.023161907629400957, 0.05938785194302909, 0.019555648796085734, 0.02275852810271317, 0.023999005679797847, 0.008277417946374044, 0.07613137146108784, 0.03452557451964822, 0.023774467044859193, 0.010418245892651612, 0.026053587716887705, 0.03226560496841557, 0.08220936797442846, 0.042895582810160704, 0.023155872113420628, 0.044184908547322266, 0.06159398610179778, 0.062190509561332874, 0.04603163913998287, 0.007841354236006737, 0.013749048266618047, 0.0862846196105238, 0.024110207232297398, 0.02553684142185375, 0.01928503392264247, 0.03229053741961252, 0.03911517531378195, 0.05486353416927159, 0.012390004249027697, 0.023416438307322096, 0.0464992589695612, 0.058577782911015674, 0.03097587661613943, 0.06929760886123404, 0.03863776284561027, 0.07307392341317609, 0.0499121549364645, 0.04884854599367827, 0.009349980900879018, 0.015077440657478292, 0.03657432884210721, 0.07745565235381946, 0.06537155117257498, 0.04003599504358135, 0.046075077043497004, 0.044229088598513044, 0.04078799844137393, 0.02999086667841766, 0.04673920644563623, 0.045961513606016524, 0.09862426450126804, 0.05639636226987932, 0.03814761512330733, 0.037044408891233616, 0.012939149000885664, 0.04449271800694987, 0.02299901363585377, 0.029284095326147508, 0.036542023153742775, 0.04180067749985028, 0.04316446662414819, 0.07874992821598426, 0.044141036487417296, 0.09918161740642972, 0.028945831836608704, 0.03356145789439324, 0.06700557481963187, 0.04659147823986132, 0.03125663293758407, 0.008084669207164552, 0.018113828409695998, 0.09337722847703844, 0.033166108405566774, 0.028935770169482566, 0.034886796347564086, 0.03630254323070403, 0.023977798809937667, 0.015520377583015943, 0.02973854945594212, 0.022596841954509728, 0.0045512971610151, 0.05020400079956744, 0.02384660008829087, 0.0356592644675402, 0.01773656505974941, 0.030904673112672754, 0.014043127066543093, 0.024946646626631264, 0.08264777687145397, 0.02561886914918432, 0.01047786076014745, 0.056185503271990456, 0.08304398725158535, 0.04840621484618168, 0.03284550431999378, 0.04402691643917933, 0.06156409239338245, 0.0146033066266682, 0.02079468289593933, 0.03591169857827481, 0.011308570774417603, 0.009105099070438882, 0.06635842204559594, 0.053593507982441224, 0.03175284029566683, 0.04281491877918597, 0.003766668255593686, 0.023837263870518655, 0.045567826527985744, 0.026598550466587767, 0.09934295288985595, 0.04539787471003365, 0.012097546114091529, 0.015507609859923832, 0.02791787566820858, 0.07233509313664399, 0.013142086500010919, 0.06582057278137654, 0.021594398967863526, 0.027992554278171156, 0.036831074830843136, 0.01097483531339094, 0.016850806241563987, 0.1376587906270288, 0.02551738787587965, 0.022502509418700356, 0.0349191725399578, 0.03526828622852918, 0.04239400972437579, 0.05917929360293783, 0.0038411569221352693, 0.041892466324497946, 0.020131861529080197, 0.0566085014725104, 0.028850126327597536, 0.0647029429092072, 0.14865247649140656, 0.03485948531306349, 0.013780032932118047, 0.04740354364912491, 0.03461807209532708, 0.017254413978662342, 0.0354031530150678, 0.11174173952895217, 0.0392166157689644, 0.01316265326749999, 0.018147794653486926, 0.07226994741358794, 0.07090469996910542, 0.07211217423900962, 0.03385396055819001, 0.0706801780324895, 0.03609628554841038, 0.012938703712279676, 0.015657776020816527, 0.040338787584914826, 0.03786329834838398, 0.025484043180767912, 0.02753191063675331, 0.0075292802102922, 0.07701982613070868, 0.03016394293808844, 0.036048060792381875, 0.10393181524705142, 0.021091770177008584, 0.026007834312622435, 0.06718361604725942, 0.040646430061315186, 0.01996491540921852, 0.04939203558024019, 0.036074006275157444, 0.06612735436647199, 0.03129762175376527, 0.05043890167144127, 0.06255593936657533, 0.0794724164006766, 0.021654154843417928, 0.03410124787478708, 0.03400052730285097, 0.024148993725248147, 0.00990282247585128, 0.04271607584087178, 0.0456407388264779, 0.0413513070816407, 0.030739628746232484, 0.06803282594773918, 0.04234038955473807, 0.019730391177290585, 0.0308372267318191, 0.05267196836939547, 0.022161956403579097, 0.05007536063203588, 0.04844732982746791, 0.027864266630786005, 0.10949435309157707, 0.026298689408577047, 0.0918864541745279, 0.04493081149121281, 0.03296236289315857, 0.009759750319062732, 0.0320885879045818, 0.026825909262697678, 0.034922014965559356, 0.0424148343881825, 0.011754374245356303, 0.04350628129031975, 0.015467032935703173, 0.05902857083128765, 0.04271495890861843, 0.06633307028096169, 0.012271165069250856, 0.024745893824729137, 0.03086327425990021, 0.039395766507368535, 0.04808116900676396, 0.027610999459284358, 0.06593857426196337, 0.10971542404149659, 0.003839861178676074, 0.07777700971928425, 0.06054818499251269, 0.020344846780062653, 0.03702045236423146, 0.009984748157876311, 0.06582533736946061, 0.03364399584825151, 0.01693676178547321, 0.012290388549445197, 0.04063944274093956, 0.03304307516373228, 0.03155237136525102, 0.06524997996166348, 0.016736033103370573, 0.01125751101426431, 0.07006183543126099, 0.03241788625018671, 0.011192351375939324, 0.06867200805572793, 0.04668750101700425, 0.0179402474896051, 0.03584095335099846, 0.025472803354205098, 0.04057833801198285, 0.009746999294293346, 0.07489055991754867, 0.01806793770811055, 0.029550389044743497, 0.027534782748261932, 0.013941336874268018, 0.014483355153060984, 0.02432479366689222, 0.050263992307009175, 0.05271851958241314, 0.0203232131752884, 0.07489985902793705, 0.1280602830229327, 0.05804039377835579, 0.021233889601717237, 0.01462243084461079, 0.126626557612326, 0.04456453192688059, 0.014733243697264697, 0.040935971555882134, 0.1266416083672084, 0.15998370596207678, 0.10195587674388662, 0.20453776989597827, 0.16090960940346122, 0.18125226313713938, 0.22307886014459655, 0.11447503973613493, 0.13302821957040578, 0.08700640275492333, 0.095880359003786, 0.1408727205125615, 0.14867861493257806, 0.1035307883284986, 0.1077800068014767, 0.16346339893061668, 0.11767604140914045, 0.14193770242854953, 0.25325513386633247, 0.09917097500874661, 0.15555633493931964, 0.15742248011520132, 0.12105955203878693, 0.284482006682083, 0.15157719142735004, 0.10494881731574424, 0.19445931538939476, 0.129819885478355, 0.11622261197771877, 0.08679713195306249, 0.18100405926816165, 0.09593886992661282, 0.07575188166811131, 0.11776924031437375, 0.21127560990862548, 0.13062000973150134, 0.3250727942213416, 0.08366403679247014, 0.10311502235708758, 0.09320806333562359, 0.15429775638040155, 0.14509411586914212, 0.14209631423000246, 0.1493944163667038, 0.16711196018150076, 0.07019187454716302, 0.12539373157778755, 0.16704997600754723, 0.13599056139355525, 0.22750363365048543, 0.17462154472013935, 0.07970811508130282, 0.1761840921244584, 0.08818323374725878, 0.12636118044611067, 0.07713682571193203, 0.24826080654747784, 0.1348360170959495, 0.11463737711892463, 0.156625977542717, 0.11627608371782117, 0.20220076170517132, 0.21755110676167533, 0.1905779869412072, 0.1802230378962122, 0.1527714406256564, 0.13835103629389778, 0.19706207182025537, 0.13234799669589847, 0.12555722671095282, 0.10395027988124639, 0.06724050166667439, 0.14040194655535743, 0.19871667522238567, 0.1260354815167375, 0.2190059536951594, 0.20057297952007502, 0.09699279384221882, 0.12528159306384623, 0.1440336907398887, 0.12436584962415509, 0.22752533404855058, 0.12580315960804, 0.08439989105681889, 0.1340291096130386, 0.20415363425854594, 0.1374141193809919, 0.1521864501410164, 0.20653172774473205, 0.14002382231410593, 0.12919548695208505, 0.15484424424357712, 0.131029526819475, 0.14329050405649468, 0.13420053088339046, 0.1440705606364645, 0.09559290294419043, 0.10834432105184533, 0.12125397988711484, 0.1760169307817705, 0.11133425592561252, 0.15715135872596875, 0.11501985034556128, 0.12133701879065484, 0.1343170925974846, 0.15296129684429616, 0.2255446309573017, 0.2764592121820897, 0.09087389014894143, 0.14664400223409757, 0.20670279278419912, 0.11341989869833924, 0.23197700298624113, 0.10906980751315132, 0.09043813814059831, 0.10509696483495645, 0.1972303760703653, 0.09211881319060922, 0.15973234054399654, 0.17183527001179755, 0.14666530187241733, 0.08331689721671864, 0.220612911216449, 0.13360761426156387, 0.3354398551164195, 0.1510197197785601, 0.16924613941228017, 0.08761597317061387, 0.0725257137673907, 0.1395163417328149, 0.3168651455780491, 0.10391309086116962, 0.12396836275001988, 0.13753146777162328, 0.135278366797138, 0.1595608302159235, 0.15940110519295558, 0.10795553214848042, 0.19480932707665488, 0.10367912880610675, 0.12036887230351567, 0.1000639345147647, 0.13021939841564745, 0.07843933199183084, 0.23572409176267684, 0.057043221895582974, 0.15011619951110333, 0.1973092812113464, 0.15067215717863292, 0.17000072548398748, 0.21318505197996274, 0.10642169101629406, 0.23214241286041215, 0.12619327695574611, 0.12464643339626491, 0.20866477891104296, 0.2549925015773624, 0.10141805716557428, 0.11735319974832237, 0.1273988958564587, 0.2592146093957126, 0.10845054464880377, 0.13301156577654183, 0.1074713550042361, 0.16135549172759056, 0.0992678920738399, 0.07902118319179863, 0.18015550245763734, 0.2057984413113445, 0.14816492999671027, 0.09940363088389859, 0.11288247245829552, 0.190040449379012, 0.07913181514595635, 0.13409812934696674, 0.1340870268177241], [0.03061931362026371, 0.03450461255852133, 0.03752687538508326, 0.04196805035462603, 0.02288119212607853, 0.03230085698305629, 0.007853468869143398, 0.04702346013800707, 0.02753886641585268, 0.03533250426698942, 0.060937289308640175, 0.012576612643897533, 0.046159288540366106, 0.04014713907963596, 0.062495832826243713, 0.013247484457679093, 0.05482410386321135, 0.03697167099744547, 0.038564646456507035, 0.05819507590786088, 0.05227752058999613, 0.06893887693877332, 0.019750115607166663, 0.019638713674794417, 0.026870588408201, 0.04123123500903603, 0.037365740281529725, 0.05160872678970918, 0.02640595572302118, 0.02373257651925087, 0.03972732098191045, 0.0387623583083041, 0.021327928989194334, 0.04210941093333531, 0.0007734881091892021, 0.02108170108840568, 0.028507421084214002, 0.01450501194995013, 0.019937196193495765, 0.010865554068004712, 0.020299636998970527, 0.04106959153432399, 0.06520635652123019, 0.01376558888296131, 0.004338886610639747, 0.06585726456250995, 0.005763477574873832, 0.016170865383173805, 0.05328101557097398, 0.005424596711236518, 0.044353049524943344, 0.0551587493828265, 0.03503233892843127, 0.046568924371968023, 0.03929667123884428, 0.05214336997596547, 0.012109670951758744, 0.02866313479898963, 0.010891693436860805, 0.09590210393071175, 0.03387716009456199, 0.05972822313196957, 0.052379603002918884, 0.06662830404820852, 0.04261092093656771, 0.01461280797229847, 0.04215253713482525, 0.018944473486044444, 0.0468171616375912, 0.04051093987072818, 0.02909032984462101, 0.04633308468328323, 0.01515262763859937, 0.03076708635489922, 0.009266738834412536, 0.012183947874291334, 0.08028148353332654, 0.005426973903013277, 0.01475610091802082, 0.03269431399530731, 0.054525582381756976, 0.06566967189428397, 0.0107037946327182, 0.028182889182062354, 0.03507028493913822, 0.00621351731751929, 0.044103624823037535, 0.10422120089060627, 0.021546485913859215, 0.030103474600764457, 0.027468757580209058, 0.00907619983991026, 0.00851151266033412, 0.025136066833510995, 0.03769837087020278, 0.02137980511179194, 0.05759208092058543, 0.05870441185834352, 0.02925778433564119, 0.030195079743862152, 0.02232278166047763, 0.060065647994633764, 0.06393332092557102, 0.051648769367602654, 0.048123983506229706, 0.037500740654650144, 0.04804315249202773, 0.046540373950847425, 0.03985174203990027, 0.07408797915559262, 0.06085293680371251, 0.07640109761268832, 0.11603259248659015, 0.024907103143050335, 0.0028896470666950336, 0.049159565242007375, 0.030925850296625867, 0.10753863069112413, 0.05433296537376009, 0.03340471630508546, 0.04467709717573598, 0.05791174990008585, 0.018163183085562196, 0.05884841819352005, 0.025597588064556476, 0.040802681833156385, 0.0011098316394964058, 0.011976460082223639, 0.04660531929403078, 0.0686022758600302, 0.03323511700727977, 0.09177561441902071, 0.04101181904843543, 0.017824737769842613, 0.026431578371557407, 0.003442193174123531, 0.034380944780423306, 0.016554900830669794, 0.009928578710969305, 0.0017650007680458657, 0.013100091146043269, 0.05450971897516865, 0.026423657800478395, 0.013374711761571234, 0.06368338785250671, 0.019927030625694897, 0.05423539892944973, 0.044764718841179274, 0.010693910153349862, 0.0763123293290846, 0.027263301417406183, 0.0178515422885539, 0.03341787087265402, 0.033868321115733124, 0.04814823318156414, 0.04739123884064611, 0.0488077056070324, 0.03407223732210696, 0.005464814157676301, 0.018889207603933755, 0.031964059235178865, 0.010760596760519547, 0.022225033389986493, 0.0636033620685339, 0.08259286536485888, 0.06412283575627953, 0.07099236245267093, 0.050811270557460375, 0.03643832285888493, 0.010516477486817166, 0.002034887756963144, 0.04839657434786204, 0.014041152026038617, 0.010896972889895551, 0.014199161760188872, 0.03090311831329018, 0.04707454958406743, 0.028489477808761876, 0.040562437498010695, 0.06748207815689966, 0.012682465167017654, 0.06746014027157798, 0.024975028209155425, 0.06939127531950362, 0.03067452384129865, 0.015268134575308068, 0.03368698846315965, 0.03335046530992258, 0.08994828356662765, 0.04286695817427244, 0.04779966868227348, 0.04023948451504111, 0.017677297146292403, 0.016543785313842818, 0.024339293377124704, 0.04470650848816149, 0.02151992444851203, 0.05724156086216681, 0.06515758257592097, 0.05176159065740649, 0.02492114457709249, 0.020154428384557832, 0.028551432296808343, 0.009858953199000098, 0.11378347684512846, 0.016689661861164495, 0.07316856208490208, 0.01842771420342615, 0.040798551781335846, 0.011607189662754536, 0.004786317704201792, 0.03976803520345129, 0.014944851336622378, 0.006265860065468587, 0.034574185192468576, 0.0635710934875533, 0.008391427600145107, 0.019933555959141813, 0.026461676170583814, 0.022341227740980685, 0.012597650675161276, 0.03914015971531626, 0.020897440663247835, 0.03294593174359761, 0.06485178804723546, 0.021580021711997688, 0.05432093144918326, 0.07554364987299778, 0.017599204657017253, 0.06851725542219356, 0.03953086335968692, 0.0371441164315911, 0.07653505526832305, 0.014365405622811522, 0.010957585018331883, 0.01745630597724812, 0.08121584745822474, 0.055246337651624344, 0.03767465183045715, 0.01295602543905261, 0.02857518287783023, 0.07371739513473585, 0.01705842947558267, 0.014779621433262946, 0.03345792087202426, 0.015343374434451107, 0.035087736541754566, 0.04897849234112073, 0.057743026336538605, 0.008805409634078387, 0.011998955505987396, 0.12831262807594612, 0.049985015284619294, 0.044460152566898614, 0.01917288056574762, 0.07730716344667599, 0.06177962321089581, 0.043857413620571606, 0.04215675624436699, 0.017538140746182762, 0.02554474900534842, 0.06037230712536257, 0.0784010074858088, 0.026827350884559564, 0.051488420940586366, 0.11017847966286354, 0.03130137331027072, 0.012446916771295946, 0.007930052015581168, 0.0363292642578017, 0.05570181594521273, 0.012081693839718355, 0.10767937899800017, 0.04919901039102115, 0.038846584648126736, 0.044984984560869634, 0.0176941624522442, 0.027737839918700047, 0.05070575571153313, 0.043080618779640645, 0.04731725042802282, 0.038486876801471226, 0.05499876831891015, 0.060835225449409336, 0.07808310110704042, 0.020731639306177385, 0.04022114604595117, 0.023772162676323205, 0.049876442790264264, 0.06043475885235239, 0.0284225453651743, 0.026994566032954026, 0.032312564362655394, 0.047391494881594554, 0.03949066864151973, 0.08099427926936187, 0.05068040394689888, 0.03544796760252211, 0.02905707420723047, 0.06243021212867461, 0.018012150467257015, 0.0736087818222586, 0.05988697594148107, 0.06415934942197055, 0.09652557477238588, 0.06604182184673846, 0.015356182047980838, 0.019057088829868007, 0.04807903904293198, 0.021716062947234605, 0.020854737485933583, 0.03747786395251751, 0.022031471999071073, 0.08076186088146642, 0.03158932289807126, 0.01837664702179609, 0.02507535358745372, 0.011279790287517244, 0.014977405644458486, 0.08361469881492667, 0.09914374561049044, 0.03709254458954092, 0.0671556667657569, 0.03316789698146749, 0.012391923628456425, 0.025024256719916593, 0.015146170026127947, 0.025601410125091206, 0.024841656850185245, 0.04621533182216808, 0.07348741841269657, 0.01616834579181159, 0.026325462386012077, 0.03306742502900306, 0.04204019081953447, 0.009407964898855425, 0.04699331781012006, 0.024973052240966354, 0.03744699431990739, 0.01763745123753324, 0.03480152729025576, 0.03027769191248808, 0.025559968598827254, 0.07097820969647728, 0.02459367191477213, 0.008622624227427877, 0.04787162361026276, 0.043162429428775795, 0.00703333909768844, 0.023016083032416645, 0.01608069444046123, 0.026811697134689894, 0.07575723255285993, 0.1693171332590282, 0.15467341669136658, 0.1366670586867258, 0.10802766890265048, 0.14589440339477733, 0.08908032701583579, 0.1472143575665541, 0.09843474967055954, 0.07313903945032507, 0.12033746461383998, 0.11924132733838633, 0.14540765841957182, 0.12928221432957798, 0.13903715182095766, 0.13432522653602064, 0.09330564833362587, 0.09003460276289843, 0.2378413500264287, 0.12771981535479426, 0.14482715050689876, 0.13728234363952652, 0.17964793281862512, 0.10693908669054508, 0.12722523330012336, 0.08171686393325217, 0.14984728972194716, 0.16973282501567155, 0.14652062760433182, 0.14382528082933277, 0.15299864171538502, 0.10610997414914891, 0.1388849670183845, 0.13065486098639667, 0.09664569137385115, 0.12819879746530205, 0.13224875670857728, 0.1084161238395609, 0.15421790129039437, 0.15921503392746672, 0.15293164062313735, 0.14813531830441207, 0.25093004456721246, 0.2160969574470073, 0.1453673598007299, 0.11340892233420163, 0.06992077542236075, 0.11784744783653878, 0.12091784636140801, 0.12807846564101055, 0.14957226463593543, 0.1444390369579196, 0.14598954672692344, 0.18082643364323303, 0.16911050450289622, 0.1092019394855015, 0.112434816401219, 0.1645634399028495, 0.10149498077225871, 0.16769744048360735, 0.11117443442344666, 0.10274053463945165, 0.19217017572373152, 0.1330929942196235, 0.11087128936196677, 0.1743206928949803, 0.166533159208484, 0.17613640171475708, 0.12014386797090992, 0.10029451979789883, 0.07329619664233178, 0.1306446935632266, 0.17927310371305794, 0.11025187064660713, 0.0754723369027488, 0.22196507459739223, 0.13988697028253227, 0.14612196071539074, 0.10283104697009549, 0.1426479229121469, 0.1518214025418274, 0.1523141737561673, 0.15110754553461447, 0.15060551231727004, 0.1022528694011271, 0.12231411557877436, 0.19181125826435164, 0.18831566849257797, 0.25519023940432817, 0.1778885826934129, 0.10675566489226185, 0.11992438521701843, 0.057215693304897286, 0.1500731846317649, 0.1710514581645839, 0.11274881908320822, 0.16666112031089142, 0.15102378674782813, 0.12758844037307426, 0.1047865096188616, 0.13806033704895526, 0.15931198809994385, 0.11426841098000295, 0.15132008178625256, 0.1367440342437476, 0.1298652307013981, 0.17018765764078125, 0.12264167729881592, 0.11993736537988298, 0.08282429669634439, 0.10290132093359716, 0.13636170944664627, 0.16312613734044135, 0.21808319695992395, 0.06276098734815605, 0.06416691932827234, 0.12399038969306275, 0.22199722443474457, 0.09862776743830182, 0.2195340659818612, 0.11682234893669374, 0.15849354764213786, 0.13279340404551476, 0.1463156018871814, 0.19388406188227236, 0.10016362721216865, 0.1287356374086812, 0.08010340519831516, 0.18772015435388312, 0.135121981438715, 0.12031120000756346, 0.2064422841067426, 0.11581341401324607, 0.15161395742325112, 0.11007389621227048, 0.11830707473563962, 0.132105537049938, 0.14612950093578547, 0.054628907892038114, 0.09644801291869953, 0.05320967291481793, 0.1514626483549364, 0.14973871351685375, 0.16763560473918915, 0.2248955040704459, 0.10385560410213657, 0.14672988356323913, 0.12013523679343052, 0.10405202090623789, 0.11003264022292569, 0.09739988410728984, 0.14320727961603552, 0.1329678829642944, 0.10906145835178904, 0.14422305714106187, 0.1485360780498013, 0.1390270734555088, 0.12573921616422012, 0.15189566183835268, 0.07488315328373574, 0.13260334002552554, 0.12525410391390324, 0.21548143500695005, 0.12091375712770969, 0.29590220481622964, 0.21306433423887938, 0.20414791972143576, 0.11968979975790717, 0.11061978293582797, 0.1106236717896536, 0.18362952541792765, 0.1707987123518251, 0.11376818860298954, 0.07873400914832018, 0.08355483718332835, 0.09329682419775054], [0.014809516997047467, 0.03585252343327738, 0.051776864056591876, 0.02196174165874254, 0.02762882584647741, 0.04009393080195878, 0.07113643558113836, 0.06399307865649462, 0.03463405795628205, 0.06710920089972205, 0.05774427314463537, 0.05019051597628277, 0.03889567029546015, 0.0506516049063066, 0.05034017747675534, 0.015497878448513802, 0.044896954714204185, 0.02594171452074079, 0.0755552644841373, 0.06029784002748784, 0.018250845569127705, 0.09299926008679904, 0.02405705461569596, 0.044444489540182985, 0.03871878681820817, 0.056889905317802913, 0.01695738421403803, 0.026315040777262766, 0.017450064515287522, 0.0806002804893069, 0.1164398311811965, 0.052148346076137386, 0.05787796362710651, 0.03520617217873223, 0.028012169241264928, 0.021452730397868436, 0.06560695299413055, 0.05168401025002822, 0.06380455088219605, 0.028239797065907624, 0.007495220734199393, 0.026886438827204984, 0.029043322210782208, 0.03906103564077057, 0.038971796093392186, 0.024136737156368326, 0.04914560915494803, 0.009871217189356685, 0.026325421567889862, 0.023203493874461856, 0.003179899863425817, 0.0196817860705778, 0.07075989953591488, 0.010498053670744412, 0.037726928712800145, 0.04332017291744705, 0.023807999132259283, 0.02098742606904125, 0.011949896761507262, 0.06796374684199691, 0.04351876050350256, 0.04088776164280716, 0.034548065304988995, 0.08922132023144513, 0.03202317871910054, 0.010930641346931225, 0.07743836031295359, 0.08025849179830402, 0.016044438671087846, 0.0908015455934219, 0.013681432119483361, 0.02031234256719472, 0.0062508440987585345, 0.0757631474698428, 0.06304214257397689, 0.07594907030579634, 0.05882460638531484, 0.028466717994888313, 0.04059857266838662, 0.06248603647691198, 0.03985064737207722, 0.027830845865537412, 0.031485956569667906, 0.02635219083458651, 0.08923294968553819, 0.009730996735015651, 0.050415275400155224, 0.037108753094798885, 0.0487520445312839, 0.05930508763412945, 0.02020380532485433, 0.05286868574330583, 0.04876289101957809, 0.028834992081101518, 0.04841972193389665, 0.08466677478281781, 0.046714678464923054, 0.05550576279347297, 0.03876332310028374, 0.018917965826403815, 0.024669747617735993, 0.018707726521824952, 0.060335537418723106, 0.027065428148489445, 0.06071260409953538, 0.05269869310723152, 0.055616650788579136, 0.09094366687349975, 0.05957059467618819, 0.09279960751882754, 0.03441215580096468, 0.09680722723715007, 0.059541424561757594, 0.03140837616228964, 0.036645534200943075, 0.041777708029258065, 0.08280456298962235, 0.031697672748123296, 0.05810934671899304, 0.03885264799464494, 0.04675491771195084, 0.02755433648417238, 0.03999126209237147, 0.07675643792026676, 0.0379604974295944, 0.031694514909759164, 0.009482345722062746, 0.07491890253731981, 0.04389311834529508, 0.042756853144965135, 0.0470756628055824, 0.08354973120731302, 0.016059628578659613, 0.05440932865894865, 0.047364102210849524, 0.06502159143565223, 0.06265634452574886, 0.032949160085991025, 0.028108230981160887, 0.0367821932741208, 0.06810387174482457, 0.020875176232948434, 0.034940995392389596, 0.015397575334645808, 0.1319628962664865, 0.052780440673814155, 0.04653710850107018, 0.023338227074418683, 0.1748179763671942, 0.024564060222473927, 0.012109923281968804, 0.04469429644814227, 0.03878897914546542, 0.0209969756542705, 0.03813790041022003, 0.04721203244116623, 0.04179924515483435, 0.10006819444242865, 0.0713368080323562, 0.01578914172569057, 0.004793237767444225, 0.09664214390795678, 0.005884014417461003, 0.02942139450169634, 0.03369544523593504, 0.014768538385396823, 0.021988930238876492, 0.056242329519591294, 0.023118183999031316, 0.05645680648740381, 0.010842061383300461, 0.0026990626156475628, 0.017539990549266804, 0.04961472070135642, 0.03430101176491007, 0.06744681872078218, 0.03677335429529194, 0.05743053763580974, 0.08243604213930666, 0.02007161583605921, 0.008783847461018013, 0.04414272858412005, 0.02652797778864624, 0.04300878259527963, 0.04567821728414856, 0.03647472520242445, 0.021956431592116132, 0.02906931593315676, 0.04367268564237747, 0.015306392288039206, 0.044316487619653344, 0.05232071358477697, 0.07839374186005443, 0.037790523347212, 0.04525585361989215, 0.060930127583560534, 0.041895264221238904, 0.01671641628490761, 0.05506247056473512, 0.03981513189501129, 0.018134538040612824, 0.059286340983817354, 0.03010091790201841, 0.018626949313329533, 0.044067359776818193, 0.058460857544559985, 0.04847179472562857, 0.03654139974969439, 0.059727941115852445, 0.025144423416350037, 0.04010980905150063, 0.03305580670712516, 0.018532815302023664, 0.057277157975477166, 0.07483391178539023, 0.06744916390744038, 0.020329116960056126, 0.07952248910441995, 0.03773388634726871, 0.030510731849062722, 0.05526718457986135, 0.11125723583973013, 0.027920430511585437, 0.02250376364827389, 0.021438117510115262, 0.03875829133903608, 0.024065197831077967, 0.04687511966039892, 0.04671056696679443, 0.03183093649568036, 0.10322497153538279, 0.030290696195152123, 0.035457485646475106, 0.01059545220414293, 0.029314465864445083, 0.08014025283046067, 0.04217199624690693, 0.04366510831459891, 0.026328707426728215, 0.038986345898592845, 0.06827090692240745, 0.03076274664636003, 0.012842064952565124, 0.09320269760792144, 0.06324162444798276, 0.015612983697792515, 0.03796354023506865, 0.04684523708419874, 0.018104412411048543, 0.014741167051397497, 0.05483326196554117, 0.02234240404504817, 0.0470445222890703, 0.009202655310218688, 0.023761755910527427, 0.10092337121022865, 0.05308255786076188, 0.050583820848260075, 0.013114761550241383, 0.027013819199055433, 0.09485335278441198, 0.03699507833516691, 0.053068230699864216, 0.07763353030895814, 0.03721761873748619, 0.012205867205921095, 0.03753680532099679, 0.07725875315372832, 0.07464272712240927, 0.014914301755197812, 0.003948984021917568, 0.01238094726431882, 0.05269436638627667, 0.056403828275506385, 0.08111757968435995, 0.029380956730165053, 0.05294714559568092, 0.10964885339490138, 0.008961384955910034, 0.024453329933749046, 0.008149990262609208, 0.034952584028360434, 0.01199806492877542, 0.05414283456047997, 0.0514697336620884, 0.05351364176021889, 0.031576717519783415, 0.03201861080015078, 0.011876727494382067, 0.016216448093473446, 0.0783612803206779, 0.05597889678028878, 0.03172900622303132, 0.03288880121544935, 0.054718039828003384, 0.043037310751969926, 0.04386961452837568, 0.0721178442472592, 0.02751785250438843, 0.012215394526720047, 0.01720043943350902, 0.08099256490822881, 0.037907879159320146, 0.014368056017701747, 0.06172436289489269, 0.08645469759358093, 0.03559037089871708, 0.017178529378725216, 0.01533034695967217, 0.06108482826675754, 0.08396049510338344, 0.0657486957788933, 0.040613827513880096, 0.06008872878737748, 0.06346334848785773, 0.07139231325709261, 0.04332564625656232, 0.04256619169609621, 0.03258025331888348, 0.036443009521462955, 0.06480827592895366, 0.01484892225562362, 0.030009086403879337, 0.02117528591043083, 0.07029666579910554, 0.036717774855787866, 0.035122806730214506, 0.04479739560338203, 0.03163969988236204, 0.07560786048998125, 0.0448746643087361, 0.021593385936284903, 0.05525683161977213, 0.04013312733150087, 0.02127356481651077, 0.03597367904148996, 0.031969922201824374, 0.035003859011339955, 0.020023090510221664, 0.0398569148092065, 0.04734041285701096, 0.03452857279626187, 0.02324872406461509, 0.04419415941811167, 0.05793435200757813, 0.06978017554502003, 0.06955154211027548, 0.06963179053855129, 0.0794177720672451, 0.04433749410964083, 0.029435435935738496, 0.01743360553518869, 0.08358653431059793, 0.17041094019077718, 0.2199924609158188, 0.1407788388314657, 0.20840973244048655, 0.12732459203107283, 0.15244669164530933, 0.18202409672085196, 0.10516230351640843, 0.15862202824791893, 0.1733297624741681, 0.12632713071070611, 0.08664370034239255, 0.11816851576440968, 0.12487912637880072, 0.1808782503940165, 0.09314876573625952, 0.07219682360300794, 0.13650077307829633, 0.11490992343169637, 0.09570899710524827, 0.1330815503024496, 0.1599927750066854, 0.1333475805586204, 0.07422334689181298, 0.20652050647186115, 0.1101230263884645, 0.10093064425745979, 0.12607877841219306, 0.1921904957271181, 0.17221890098880976, 0.08243524061981589, 0.2069156407378614, 0.14108365372521803, 0.1814439895679243, 0.07083551696268842, 0.09737466592923738, 0.0695236076717265, 0.2612929791212082, 0.10942676570266485, 0.0567348743788898, 0.12567689060233533, 0.14817061484791338, 0.05974589737888891, 0.1382969188853167, 0.1484344038181007, 0.09163227601675317, 0.09385050347191282, 0.11212577126570977, 0.1233243418391794, 0.10380800275015645, 0.12203068938106298, 0.17475434462539852, 0.08494283887557685, 0.1739269687095657, 0.15760847716592252, 0.10379926025052555, 0.1158409625350032, 0.08806033409200609, 0.16788962704595178, 0.165189441468101, 0.0953040219610557, 0.18546457460615784, 0.2432299655629322, 0.20929815742420033, 0.11919213779037818, 0.10139721765881404, 0.1939760585082695, 0.16520550154382363, 0.18816293450072408, 0.12967614631634206, 0.17491718666860834, 0.15208105032797903, 0.10953175733448006, 0.1919601479312405, 0.13126894365996122, 0.1661581519874744, 0.09826992609305307, 0.2309702054481022, 0.21747855440480635, 0.16552187909837812, 0.08717745295143686, 0.15756473498186097, 0.11947799823246896, 0.21023957175202668, 0.0926908606197685, 0.13347586820600554, 0.17807051277486607, 0.16029194957809523, 0.08943158551119268, 0.11246396796195768, 0.13989505969220772, 0.1947511130128987, 0.10299875008058734, 0.12944573914865032, 0.2658269670791924, 0.12183543032733724, 0.1421087674680166, 0.14822548924712464, 0.1016267342492938, 0.10705547771067359, 0.2032433752901852, 0.15505824994761497, 0.125248359690886, 0.14971744356444106, 0.1269081432837993, 0.2150852172053419, 0.1658454554853961, 0.1646639860700816, 0.18156829930376261, 0.15493312384933233, 0.15186260658083484, 0.12327023185207509, 0.08105673841782846, 0.21039343380834907, 0.12504602054832503, 0.1941791843273677, 0.12333708451478742, 0.29822521610185504, 0.16427870752522722, 0.11487483468954451, 0.18117285333573818, 0.13810869539156556, 0.15382638870505616, 0.09600806777598336, 0.15627566899638623, 0.10670482035493478, 0.11737481108866632, 0.1322465154225938, 0.1602790955803357, 0.09652281398302875, 0.15306197659811005, 0.1590871173539199, 0.07523878302890807, 0.17561216343892738, 0.225471529411152, 0.12940883956616744, 0.1302809818298556, 0.14667031879071146, 0.22484140150481835, 0.18955049832584336, 0.08719376535736956, 0.24936497386079282, 0.1003637102257926, 0.19564344169339165, 0.16895972978090867, 0.14952482655644417, 0.12216055780299939, 0.3863937553251162, 0.12347726878942922, 0.07897177842096426, 0.11313676193822175, 0.13926095387432724, 0.1615570590365678, 0.12474930990720168, 0.13092439417960122, 0.1009437431639526, 0.1357322940020822, 0.14309962367406115, 0.1019019226077944, 0.11720504480763339, 0.11275941695203073, 0.10198808595305309, 0.11264052489423193, 0.1587074197595939, 0.15560240746708587, 0.0857545183680486, 0.16676275001373142, 0.14501129218842834, 0.1797011448070407, 0.13760287722107023, 0.1353241127799265, 0.22887869970872998, 0.17479813133832067, 0.17498975386843085, 0.1393094754894264], [0.04684145955252461, 0.016501815007359255, 0.025081249950744677, 0.08106572582619265, 0.07888375228503719, 0.02216458731709281, 0.006007084302837029, 0.06715490977512673, 0.04840238907490857, 0.023211471961985808, 0.06213687083800323, 0.007111552649803343, 0.06321948618278839, 0.04291418845241424, 0.018619162328832317, 0.05832404633110855, 0.014493104190478334, 0.037184010579949245, 0.02024867742875358, 0.05994364633806981, 0.02392920112470165, 0.04059954488184303, 0.07287958462256938, 0.03519207508361433, 0.038879495186847635, 0.06540973467053846, 0.011808200360974297, 0.09650999709265307, 0.017139661249530036, 0.04301096450944897, 0.04480044583033305, 0.07865505205700174, 0.0009445621935810777, 0.020564346232276876, 0.06318660904071294, 0.010757049294625176, 0.031006807475932874, 0.04602776883984916, 0.009428681023564423, 0.04015282022010069, 0.05279461569443811, 0.02492332278052345, 0.025285952833655756, 0.04101178936252836, 0.016539571770408656, 0.06082093168515712, 0.04193109882180579, 0.03703234157001134, 0.07079774906742387, 0.03545859515725169, 0.02289602951350389, 0.05478709666931536, 0.010274999331159052, 0.02246991243737284, 0.01662421000219183, 0.08255632943473756, 0.010205698508798378, 0.07161193701904267, 0.04075756667589303, 0.02803777333610924, 0.02358387238928117, 0.05636027533910237, 0.09166913107037544, 0.010424065258121118, 0.03429243624850642, 0.017878758699225727, 0.04417819211084861, 0.015460848990187515, 0.08927431699703448, 0.051850696618203074, 0.051133774541085586, 0.06616313330596313, 0.0011949441500291869, 0.04869581200182438, 0.031252124390448444, 0.12360139298834838, 0.01382246151479194, 0.06699409379507415, 0.03954614789108746, 0.011690255469147814, 0.0627642082690727, 0.040412505113636144, 0.04159483913099393, 0.03372320898051839, 0.02218828409240814, 0.07122761584469117, 0.02180389426939655, 0.06533580191899091, 0.029137248420738615, 0.019383374055905733, 0.008891917150322115, 0.055610717317904346, 0.05551681337237824, 0.007478418510800111, 0.01527983082269202, 0.01047472240315983, 0.025891404329740908, 0.05278615150018595, 0.048383093235315755, 0.08131856069667265, 0.039859720127424225, 0.026962733463733457, 0.01725647714920342, 0.023226964294735808, 0.07096154848113656, 0.013323279072210426, 0.023359736369457096, 0.047915536488289945, 0.05120289446495008, 0.06175714726850856, 0.018006012905971147, 0.019501852366374806, 0.031283832649933174, 0.029665525835298467, 0.030986596939328592, 0.07015391369350255, 0.04627074798918329, 0.02377932811214123, 0.04099410398339387, 0.048946438982966356, 0.008500671738147503, 0.03527869856043253, 0.047967189966584556, 0.11779040636611171, 0.01293343539146008, 0.020682876493083313, 0.031214746122714132, 0.050046973483404145, 0.0033396260459994664, 0.046272128383861855, 0.029986187437316403, 0.08122023355099373, 0.02625251483550528, 0.04928840578941163, 0.026769331634568516, 0.03332133230287582, 0.023968045134097338, 0.010485617131053004, 0.05168163908820134, 0.05511695162567776, 0.028370151594572235, 0.050793299451470375, 0.00903063011719496, 0.02583042391052004, 0.1400814575026743, 0.052730097086168826, 0.002506434475435526, 0.05235081880528014, 0.06750490661943331, 0.024449357588309795, 0.03324857214465737, 0.03169416981108952, 0.03397702348593157, 0.049156993700307794, 0.035238307173131034, 0.01241764182850602, 0.04179831004876178, 0.11067008570535108, 0.008124160740408115, 0.029927665382274427, 0.002045035234914394, 0.024335974121640902, 0.07578400924103335, 0.0263729969447013, 0.050785358471330255, 0.003016068676515715, 0.04618318198481575, 0.037866474740440026, 0.06594915728783235, 0.06665433116722852, 0.02171089203329757, 0.01879049825220136, 0.016528678897884674, 0.030564637745555956, 0.04959872741892468, 0.008308820069942158, 0.03786667512031272, 0.06386310633388348, 0.04770792067574803, 0.05168849282199517, 0.07114070293027908, 0.0525457438925514, 0.03358615285833366, 0.05124742703628726, 0.06310646451311186, 0.01642604544031201, 0.05727048235712573, 0.012444346157280961, 0.06421401601983234, 0.022806040396972094, 0.02490575243427884, 0.035946386560681276, 0.060537486933753826, 0.0023294526636163937, 0.011571926515898667, 0.03465564332145732, 0.02948663484858116, 0.03521654369251337, 0.11313689552480355, 0.014347857540997211, 0.009975700450013392, 0.033763422252377495, 0.05942123374552466, 0.02605099020001944, 0.007785170873830793, 0.02943049323221203, 0.04441043609404005, 0.05229828217125032, 0.029304016425157897, 0.030942995763325598, 0.030917376825527754, 0.037562264697044156, 0.05313448222295847, 0.039126166520873085, 0.11891676389495842, 0.03821391117526218, 0.02522963495721342, 0.04146212828345597, 0.046307061275001615, 0.05441138069727458, 0.020352275678305887, 0.030472039979940746, 0.005347346559574362, 0.09662628421210684, 0.05298857970046811, 0.030126355013635475, 0.03272240799560677, 0.07669762271689251, 0.04732297238660976, 0.026026790619653184, 0.08732091751880944, 0.01370204156046384, 0.020181778381811455, 0.047409959515789524, 0.021622928979923017, 0.029742859478574246, 0.015333468618337065, 0.04616845035343431, 0.030859207290632185, 0.02105454961565556, 0.08029123535379767, 0.055310785755864345, 0.037725344227510504, 0.018988629417435732, 0.008659382801852189, 0.06017847670591436, 0.09045567509019747, 0.03975184525188524, 0.058241705046384595, 0.07253953255712986, 0.038741971511626616, 0.05894665628147777, 0.01129979395045666, 0.007155596331358538, 0.017289426650677342, 0.03503751911921427, 0.028812968848797027, 0.016988136958389077, 0.05046196391049307, 0.06346573078189977, 0.029816487949574366, 0.024209322909882758, 0.005094399903100566, 0.028042786543664988, 0.027342598041286692, 0.03845546911179554, 0.02131670215021586, 0.057064773864112794, 0.040421837620669976, 0.01670164940151153, 0.05103548079205211, 0.0730029221449513, 0.049529095413163304, 0.1336359791457653, 0.024530734081054106, 0.03499089740216732, 0.060096127999713644, 0.006461489265348064, 0.03773059492232278, 0.03596500333514996, 0.04572167745209299, 0.0691625454055611, 0.028552387811942026, 0.05330935076926835, 0.006103859896029462, 0.047344342528958805, 0.04784592674695887, 0.048154530304600485, 0.08629162548459135, 0.04360079379694071, 0.014894918713252991, 0.04599807180056814, 0.023833970590203535, 0.008967540143203223, 0.02400627316092141, 0.005087161180199473, 0.016165221350092907, 0.05660843838995788, 0.06856893116491847, 0.047110777522902936, 0.01875224796094699, 0.042050488118547946, 0.012060416465828894, 0.01028210168442456, 0.015763060800964013, 0.03294984286185354, 0.049679473086143844, 0.04651786090107635, 0.07684896147111431, 0.0531177430821117, 0.03249012319429312, 0.01282539631574764, 0.03646583798399661, 0.039030540792737156, 0.024712975864531472, 0.05746317357989028, 0.05473829303809907, 0.04638084559701383, 0.009583194314473076, 0.07548807785497047, 0.01839435466536088, 0.053228211763780564, 0.016890540828171652, 0.02559076401666971, 0.04300553940993268, 0.07061363707180135, 0.04165005862887483, 0.04869344826147426, 0.01868473664217163, 0.08610182121628895, 0.03741585751413368, 0.0011695850798787433, 0.04488529928494245, 0.04018920772068668, 0.03755422352696769, 0.007293014250535634, 0.011031231115339324, 0.04348216149082873, 0.04212765663396567, 0.04491485160542652, 0.03630157843872439, 0.026019673423434142, 0.017218486609635875, 0.05196432684897445, 0.028140095091657713, 0.02582728091510944, 0.034111033091903664, 0.03033084638445871, 0.0022976636955718277, 0.0631150660046842, 0.045893336209701374, 0.013952503413747763, 0.13694852561457083, 0.08191979679395445, 0.09966523051843978, 0.19827981741400436, 0.19603688386268914, 0.1196131507458631, 0.1486884112819098, 0.21572177211055532, 0.15282361360732466, 0.09873837712802924, 0.09649588144384325, 0.0883152469759807, 0.13390405772952363, 0.18364015297265723, 0.16821396042359993, 0.19616416218923405, 0.07731272955425084, 0.08801144882454537, 0.0865374322165735, 0.12551257910672575, 0.08781957396422513, 0.1275285193696618, 0.18556314666057006, 0.13367310137255117, 0.11242277134442702, 0.1928431700798683, 0.19982921396149322, 0.12506429222412407, 0.08069606206845492, 0.1115769827447366, 0.21780443144962192, 0.19809287041425705, 0.15414528956171125, 0.09576051699696109, 0.10349629330448806, 0.14235346839996055, 0.17069792869733647, 0.12307932920521125, 0.21160675620194525, 0.15197775821434334, 0.09941767973941751, 0.15049810870550573, 0.16912019695155323, 0.0918291306879837, 0.10875532985664904, 0.0904782660654746, 0.1295180688612163, 0.24137363157933578, 0.09503537934506312, 0.07658354719751514, 0.073151848919224, 0.19546826515579596, 0.21164899924769998, 0.15643426595488563, 0.15656966337701306, 0.21954599971650168, 0.09775172889931127, 0.15523489593761042, 0.07280862788320519, 0.13685672194696963, 0.10621984911267646, 0.14591824117815122, 0.0959535496076569, 0.06886526331072673, 0.2673692093230784, 0.15189218858722597, 0.12763552222168073, 0.07395543900202028, 0.1350012785405852, 0.1791779455379583, 0.14157397585222498, 0.16615010710665956, 0.12329490826232359, 0.28405248129274696, 0.11743904397008009, 0.18424899608362466, 0.08534822220099159, 0.17524039198178798, 0.1563717474346049, 0.13625596824567765, 0.1412293521570973, 0.10435673932079226, 0.0968978508899454, 0.14930875768186525, 0.09810067931539379, 0.13785915565676987, 0.09356567461509258, 0.16494901530677453, 0.1432864074013196, 0.1108626507630106, 0.08616284059826285, 0.1252295239828527, 0.158530343323946, 0.1372261333744973, 0.11757577725802548, 0.17340326478006318, 0.1146111347770784, 0.1860953407594934, 0.11887509972439148, 0.16075246705440804, 0.1592408012947999, 0.12282567055081017, 0.11119288421468809, 0.14991345960879698, 0.11682024865876883, 0.10886458883760497, 0.09578078505001031, 0.1732305670157075, 0.1043612441571895, 0.11574242758797482, 0.20450216165045276, 0.09437368789804168, 0.16114142665173858, 0.14043926174053922, 0.08937416554545052, 0.17216332897078246, 0.10804502773680724, 0.07896403039922006, 0.10314889397704974, 0.10983486528857611, 0.06351431919028983, 0.18379302055109292, 0.2496011252515018, 0.22389074001694098, 0.07639542760443874, 0.14042507187696174, 0.10921635199338198, 0.12594010069733486, 0.06731666828272864, 0.11999301903415471, 0.23226145334774628, 0.15919020166620612, 0.17677424795692787, 0.11599618272157386, 0.15888455556705594, 0.105002118361881, 0.17167082492960617, 0.05708689357561525, 0.11553769872989506, 0.3676453832304105, 0.18675864266697317, 0.09361358766909689, 0.06705328007228673, 0.2328326547285542, 0.2329662413103506, 0.17033852142049, 0.07059805939206854, 0.13009351532673463, 0.12164305822807364, 0.16539899428607896, 0.15772802231367677, 0.2526399231282994, 0.08627145391074009, 0.16451785719254985, 0.15578656399156898, 0.07934187262435444, 0.13798542466247454, 0.22529068286530674, 0.15355431736679748, 0.12290014507016167, 0.0814539729617536, 0.11460856694611721, 0.23208730097394437, 0.1458682501106523, 0.2044953784206882, 0.10265698365401477, 0.09109603721299209, 0.0991132804483641, 0.16860243020346388, 0.1324819543515332, 0.13473012746544555, 0.06501611438579857, 0.10355139034800231, 0.13872806215658784, 0.17104108294006437, 0.12982528831344098], [0.02170832420233637, 0.011777744475693908, 0.03648140453151427, 0.03263502010668162, 0.03604934841860086, 0.010917758590949234, 0.0826751250133384, 0.007171866527642123, 0.042988091518054716, 0.021328674847609363, 0.017492205515736714, 0.01038345493725501, 0.019477945934340823, 0.026709941266744863, 0.049966402220888995, 0.034614750984474085, 0.042079220365849324, 0.06116552198363934, 0.041642340293037705, 0.02599901574285468, 0.06920252490090206, 0.08230125327827409, 0.04136389761697501, 0.028517475329863373, 0.015179294859990478, 0.02153744841052685, 0.04696250754932407, 0.029804220248479396, 0.010258234215143602, 0.02471031155437231, 0.07323773024836555, 0.05717359126720112, 0.03285664024588186, 0.042242615309078246, 0.021848918513569515, 0.004880267106273095, 0.04845194969675504, 0.023520112627011258, 0.02441627821099246, 0.08559158726711757, 0.024220392042479943, 0.03560174802260008, 0.010536812333157286, 0.06288934921030886, 0.023769806357449852, 0.0523077371326508, 0.017796981446736027, 0.024649527804285754, 0.09779420943232253, 0.051078484539175406, 0.04117051990760956, 0.07139073248254135, 0.04165167651080992, 0.01123835154430708, 0.02766198686003918, 0.05637749687593896, 0.05951408755208831, 0.021028173687227536, 0.06927883994649164, 0.030117888964014128, 0.02259834665892413, 0.06532205734401941, 0.057921817133319564, 0.028067136408935767, 0.057649556547403336, 0.08694898278918117, 0.027969764778390527, 0.04188746795989573, 0.052561952397809364, 0.025605610680941027, 0.037336592431529425, 0.022735983511665836, 0.06766921069356613, 0.04532738552370574, 0.06780326482839882, 0.03620894356572535, 0.022195041347004008, 0.06945894434466027, 0.05944755772361532, 0.05173518133233301, 0.008257547870016424, 0.018989141499332618, 0.07359574228757992, 0.052010429062647745, 0.02186861511290772, 0.034189492944278754, 0.017219052497239318, 0.11895940770045854, 0.07638946815859526, 0.03027143746294314, 0.03264607068558689, 0.04264809511369094, 0.10746214495156892, 0.04913797616609372, 0.047696291221654974, 0.039882144119474106, 0.05471855933137704, 0.048806596096255817, 0.022493429241876584, 0.06145465900772251, 0.052034378168173134, 0.03226411325158551, 0.04530285754299257, 0.06138279684819281, 0.05141302986885421, 0.033037546163541265, 0.0414174584147986, 0.04069053218699992, 0.05578386037086602, 0.022108623816166073, 0.03860782089759596, 0.059097475532325916, 0.021926699300820474, 0.05340171104762703, 0.013193685244914377, 0.064132736006286, 0.03191301802871749, 0.006922374568603118, 0.023088334819476586, 0.036312128067947924, 0.019857372644764837, 0.01006553649858688, 0.017794474842958152, 0.035098096923320554, 0.01287485860302695, 0.019667811429826543, 0.07415010433760472, 0.01666421547270147, 0.08491234402754344, 0.062379790615523234, 0.0669662409927696, 0.04370447924884502, 0.04719389806268737, 0.03959920402849093, 0.06736327515682206, 0.05364805583667476, 0.038017943370505236, 0.03613885884988122, 0.0327983148599742, 0.028883997947559692, 0.030163987466949038, 0.04722222212876659, 0.01086315785869374, 0.04418437791173346, 0.045221098844194785, 0.054617501082248054, 0.038302783359540626, 0.08649606490507722, 0.041405272349948063, 0.0384196679078741, 0.02084890420519514, 0.011678936789394356, 0.038467814738396555, 0.04990777626517229, 0.01171563506431994, 0.04194629429548513, 0.03972035592596512, 0.050204754079459235, 0.038382686689146794, 0.06743728954461403, 0.036314573444542475, 0.03238141340261791, 0.0020712877812911756, 0.054380425717681646, 0.0318251291901106, 0.06678111967630684, 0.06190666033944581, 0.062220681575126946, 0.027725913605536334, 0.06808709920733236, 0.08056126578594558, 0.02421388155198656, 0.03179872357577551, 0.1199900133360643, 0.018465732573531568, 0.020238259530742653, 0.06692717433907092, 0.02135519178409595, 0.028381968440953642, 0.027425102598499507, 0.02144973954273155, 0.04342411812103819, 0.059508788617677055, 0.023569146324007306, 0.014005392567923991, 0.02610204253869597, 0.0482604718854418, 0.041103990079136565, 0.06622047905693762, 0.07802088686730713, 0.010519588940951508, 0.03887809994921554, 0.035540877070161514, 0.027500141150085256, 0.02117720436217496, 0.052381016794242896, 0.021742321987403557, 0.059008239695685916, 0.05261845210043248, 0.018910447870439384, 0.040593221783638, 0.015952425346767996, 0.024441305286018178, 0.018442080327076837, 0.029848203630535863, 0.015866735120653175, 0.016864667704794556, 0.05037147013354115, 0.023233751235238742, 0.04726196413685102, 0.05224428721703589, 0.016100706452562008, 0.0269388437300222, 0.02542188831284875, 0.062081443538772874, 0.08541923831216991, 0.017107381536334287, 0.016871402694960125, 0.040939084865385666, 0.024326246420969255, 0.006887859135531471, 0.04980095895007253, 0.044929085997864604, 0.024411094309471082, 0.040658638390596025, 0.07603874400956556, 0.049620097561273724, 0.03555126713763457, 0.0657454451720696, 0.025118839730566833, 0.03804494641372003, 0.031217436408041976, 0.05815445816551801, 0.04429746637470089, 0.06158264608529862, 0.06295845058048144, 0.03995029182988219, 0.053579232771880925, 0.058281228120904416, 0.009260412953153718, 0.02079258261801442, 0.023804041629773565, 0.015452857915079221, 0.05124064009578433, 0.031137815094552934, 0.008013144724827725, 0.03720142136444338, 0.05666635559464339, 0.04081555438460782, 0.07180276545113884, 0.009322886016889242, 0.03977052510890644, 0.03489376882498618, 0.04506971927185077, 0.03530986505211331, 0.036505542884697206, 0.010747670403361553, 0.03548158689227421, 0.09233693039277568, 0.01937941098731244, 0.010432549861434381, 0.026672173371480312, 0.027659435727400705, 0.026843386840482708, 0.042965756583726034, 0.0688380487554241, 0.07789732670062222, 0.034673840782488696, 0.032169864207389764, 0.09275711214286275, 0.021124129671079572, 0.026333622299716808, 0.10467186264577322, 0.032259801373584196, 0.04380728896649089, 0.008666874782647938, 0.030846117660985328, 0.052530407410813496, 0.04802169329195749, 0.025264217183575965, 0.026827985420823097, 0.046178246702766046, 0.0506193808541866, 0.05092179861094337, 0.03960360867495183, 0.028097853901272174, 0.0140462904710148, 0.021701887926610652, 0.043494180572452024, 0.020042172982357442, 0.0517518722335808, 0.018041574767266866, 0.05311824403179344, 0.12427291047060862, 0.06245897777262144, 0.034431874664733186, 0.026471474375284743, 0.02273814501677407, 0.034982114084414206, 0.029950955831736792, 0.02375035095610656, 0.04248775410815142, 0.029439222744258586, 0.05902641860302538, 0.0637210592685733, 0.1099692756542936, 0.0391889299498871, 0.023531562110292725, 0.02212511062680278, 0.017442370299249887, 0.029225348771433346, 0.04215745757392142, 0.04122328660741914, 0.028282641251280438, 0.016415412319474854, 0.02024147117481334, 0.050300531947868876, 0.024607646555523388, 0.03190041636116803, 0.028605241714103613, 0.05435078433947638, 0.05879456424736418, 0.038371888440451585, 0.06664481683401391, 0.032828605617396533, 0.010819669860211434, 0.015429120321641676, 0.04683460952946916, 0.01923178668221226, 0.02809088327921927, 0.05700812573195435, 0.03383041221241001, 0.04595478232658934, 0.019824989030894358, 0.012381864744384075, 0.029203184531070292, 0.00709412887772487, 0.03602748845878523, 0.06898336869198829, 0.03185999157722108, 0.04121323421713896, 0.011673445824271766, 0.008270246944448445, 0.04288128162443172, 0.05716186904464848, 0.047465698517044075, 0.06770291161956266, 0.039576843118993565, 0.02380965783231659, 0.03297413706604857, 0.035918177527491935, 0.06893647238030098, 0.16561123367864639, 0.08975423421361484, 0.13667186780367047, 0.12792427703971043, 0.06907834875164554, 0.12981048988876864, 0.13623612321680412, 0.11866442626342177, 0.12882898474344984, 0.09843097213888541, 0.09853603798546828, 0.06814200329245068, 0.18258845550008118, 0.10212769877398387, 0.09863284372841008, 0.14988212613388896, 0.1203728502150625, 0.1373576419427991, 0.10731301779742353, 0.14372299803653732, 0.10153868584893644, 0.130352821724955, 0.14483949984423816, 0.13349602493690327, 0.20240114157786593, 0.15739555499749258, 0.12098194565623999, 0.17342762206681073, 0.1051918113080319, 0.07742149129626341, 0.1561678943107836, 0.18015556182945147, 0.09781236978597008, 0.16216826217714697, 0.10446688887896016, 0.20366509328596294, 0.1374391297576949, 0.17373185808537528, 0.10245520112221129, 0.22578683827305213, 0.2185492657008581, 0.12617835978744552, 0.11373205343261361, 0.16274480702122673, 0.08918111809180118, 0.13545856025302783, 0.1485583870089613, 0.10888273434829898, 0.2653621748322621, 0.20813426206586882, 0.19684540922753513, 0.2100268573849462, 0.3636301861843094, 0.08110644004773349, 0.13641892903251573, 0.11527388749527745, 0.13059819058980793, 0.21215414948528633, 0.19984960817964748, 0.0737330989795737, 0.09505190697382204, 0.13633744121761993, 0.1046255452092737, 0.095468882645946, 0.12931537348777056, 0.15939635544782504, 0.15230992867145687, 0.1806210813811049, 0.1260723514133133, 0.053392326590255834, 0.11127906982437707, 0.13327162916539237, 0.17605604196432978, 0.1033041141636204, 0.15147821861319244, 0.21177059272304177, 0.1502173245535232, 0.212386560451705, 0.17179016227601096, 0.14648439595475793, 0.2037735062185675, 0.11734646846889518, 0.14379069674760103, 0.10955918711260892, 0.10995810633176006, 0.0935387569188606, 0.08791677304543555, 0.11448894016211852, 0.15162946830969304, 0.14787847583647817, 0.17881994834169745, 0.11329064625897445, 0.30047775304410607, 0.21294291887897998, 0.1053354465693701, 0.16534883994609118, 0.16393547906773165, 0.1283976188278757, 0.10262668176437728, 0.1336203792016022, 0.13904791296226904, 0.10054187019704841, 0.10326034229365177, 0.16794261639006436, 0.1369344544946216, 0.15646959218429402, 0.1854770872159861, 0.12871545099187642, 0.16208812507102266, 0.08933215256547555, 0.12486794963479042, 0.23180814954685047, 0.17714083922328427, 0.16314325126586482, 0.1378506506443955, 0.1377367161330767, 0.19216118089389056, 0.19343981228303164, 0.10843301512068138, 0.09583951861714013, 0.0826257053995505, 0.0637618477048818, 0.1719521582708694, 0.10983225292875431, 0.07063355631544255, 0.15071052621351555, 0.12195666015031748, 0.16149600996868685, 0.13523912202799693, 0.22168831288581714, 0.28390149876940995, 0.08906468254281208, 0.09736803855048493, 0.12508802610682324, 0.1644624484470114, 0.13678002840606496, 0.13380900345509872, 0.12708095979178324, 0.1275687586166896, 0.13704794371733442, 0.2036568702897057, 0.12301394599489868, 0.10668329065083526, 0.2176912539289333, 0.09773249985300936, 0.16038511879742146, 0.11341416931827553, 0.23360757564660162, 0.1319731230614707, 0.10663227541954257, 0.18078364140819758, 0.08166791929397732, 0.11892483104020357, 0.20285782957216725, 0.0997054623439908, 0.09612727895728312, 0.10913564343354665, 0.12321282672928646, 0.14912751037627459, 0.14602064271457493, 0.11351699387887493, 0.11164468145580031, 0.1330413407413289, 0.22772964730393142, 0.08166083178366534, 0.15104695659829304, 0.1355362482718192, 0.13928249099990353, 0.10920847038505599, 0.22288953827228397, 0.3159825241891667, 0.13464665069477633, 0.13914850365836173, 0.17567411792697385, 0.26184941176325083, 0.1038950344081968], [0.07918925737612881, 0.025475601250946056, 0.09407281380845234, 0.03964171053667087, 0.039233982024597935, 0.03666240692837164, 0.01699664197076345, 0.06561820395290852, 0.07885641156462952, 0.018121596840501297, 0.04270488425390795, 0.05225706328928936, 0.033202440245077014, 0.05010053799196612, 0.03300730364571791, 0.0240308419597568, 0.0137969520437764, 0.018943063405458815, 0.04905192043224815, 0.01592337397596566, 0.051733552318182774, 0.01531169400550425, 0.01502360062659136, 0.05223488791671116, 0.010204987902397988, 0.11002966421074234, 0.01559406635351479, 0.03321711250464432, 0.04306366070522927, 0.056706457544351, 0.07025935061392374, 0.0390282957960153, 0.06576605461305007, 0.02113778147759149, 0.0313145019026706, 0.07541072380263358, 0.05042742064688355, 0.004650685577871627, 0.027781596945715137, 0.03073158201004844, 0.06316436687484384, 0.016288764818455093, 0.013742265964538092, 0.045010829853708856, 0.06104552041506395, 0.02100797984894598, 0.028227954244357534, 0.03245565043471288, 0.0838715338613838, 0.006074923094274709, 0.01782693823770387, 0.034261399632669054, 0.027263301417406183, 0.014746197884960566, 0.01752683598169824, 0.037656936765415594, 0.023249338191817515, 0.040195593901444227, 0.006768045423086733, 0.005321384378476068, 0.020317109010647982, 0.034240367167512886, 0.048651464967406355, 0.03882636112393811, 0.024237700781668536, 0.04402093472890556, 0.09002029415569268, 0.01400513838234474, 0.013731004801229574, 0.026949705061269924, 0.03143054782412946, 0.025677654666651506, 0.04988184191461187, 0.018268182138854172, 0.017286183465330396, 0.05312446322932374, 0.019869098578055855, 0.03949557423766237, 0.020609170096577145, 0.054805360923637636, 0.037666176503989846, 0.0394331113784574, 0.03063890075281961, 0.05248054992989637, 0.0362783158197999, 0.019540705652616452, 0.05767902352090459, 0.012964947909495095, 0.005944038857705891, 0.023586230563523713, 0.05423943621281069, 0.04106646709260531, 0.03223770021577366, 0.02002063214604277, 0.04289456977858208, 0.03338937240187079, 0.055067465218598954, 0.025976513825298753, 0.07381672417977825, 0.00995053236692911, 0.03766946050745901, 0.02462074175127782, 0.015554649035038892, 0.058318717710790224, 0.026416785512992647, 0.060855675328639336, 0.041603633580962196, 0.05290373366733547, 0.07736195620964281, 0.03601750657253433, 0.04716569274023641, 0.010693444455682766, 0.02092602262564469, 0.07315196766285226, 0.07620002754265442, 0.03140041291771922, 0.02621280807943549, 0.06045017325959634, 0.045918539544800296, 0.04672028539062012, 0.05602198958513327, 0.018334277810936328, 0.012080974884156603, 0.057348329937667586, 0.027187613486603368, 0.015917364435154013, 0.032522710898774676, 0.0274863427694072, 0.030281450890470296, 0.014321108683361672, 0.013143523483449826, 0.0037817755992364255, 0.03956501328502782, 0.07178752173786052, 0.033750902221072465, 0.08054597012232989, 0.04861535577219911, 0.0605891923623858, 0.024283203711092938, 0.09100695722736418, 0.03259879216784611, 0.045999155336176045, 0.03844661529001314, 0.018040600698441267, 0.034869051596615463, 0.005300791171976016, 0.030142960567900445, 0.004209470434943796, 0.0525010369165102, 0.013350791414268315, 0.12023054339806549, 0.0398989871609956, 0.06331650714855641, 0.08568362100049853, 0.050171921466244385, 0.036762103336513974, 0.016503733459103387, 0.11324976134346798, 0.05389757330704015, 0.03483317246718798, 0.0644262257264927, 0.03548121952917427, 0.08033473262912594, 0.011326395306241466, 0.05577391930273734, 0.01781169637979474, 0.04957039964210708, 0.040287672163685784, 0.0218918795872014, 0.013523053166863974, 0.11923803220270202, 0.04858409280132037, 0.04984858998795971, 0.04047370261105243, 0.03666277429147158, 0.02008881881920388, 0.03490682691335678, 0.03055462246265961, 0.03571977918909397, 0.0333579869766254, 0.08839130226988345, 0.048929154363577254, 0.040579800042905845, 0.0424984039273113, 0.054505993393831886, 0.03191481402609497, 0.0043857745731656905, 0.09129023499554023, 0.017141969328804407, 0.039379205481964163, 0.02682237663975684, 0.01512188417109428, 0.046959134488133714, 0.027401290790294297, 0.02173544042307185, 0.05703060909581836, 0.04979171179002151, 0.011110389514215058, 0.018342131588724442, 0.02521810198231833, 0.028224165580468252, 0.016065875606727786, 0.03382807444722857, 0.05449380732898135, 0.060604276513913646, 0.045487715397030115, 0.06252514023799449, 0.009104168602789287, 0.013582387873611879, 0.01061565624695504, 0.03423953225137666, 0.04908626331598498, 0.0991268469078932, 0.01963720154890325, 0.015415872985613532, 0.06467142389738001, 0.01909929847897729, 0.0059505683657334885, 0.003907425143552246, 0.029055703089397866, 0.09644461388234049, 0.02101148093061056, 0.026130821170227136, 0.029207618863438256, 0.026480061023903545, 0.07013694077613764, 0.012827500304410933, 0.030034293449716642, 0.013724928467127029, 0.034290091061848216, 0.008653912245790707, 0.07407817538478412, 0.01965495372132864, 0.028500025582616217, 0.14733454096131027, 0.040746371378190815, 0.06314955360721797, 0.06184024554386269, 0.04573462421831209, 0.014387603259820025, 0.04364566404547077, 0.07063658427796327, 0.01663275768805761, 0.028709799189527985, 0.026390066341264173, 0.015386149971163832, 0.041402188726351596, 0.06172082285047509, 0.03137563260679599, 0.03808906338235829, 0.005602719111266197, 0.07346168815274723, 0.025340150023112074, 0.026336145601817407, 0.024227644680649973, 0.012890655216324376, 0.08650523785036057, 0.03671297316031996, 0.03339993687404785, 0.0960425182711333, 0.015148814854910597, 0.031117387479753233, 0.0659646830172278, 0.07261817052494735, 0.05779172235634178, 0.0787207914981991, 0.09896953386487439, 0.009353461573482491, 0.03145677532302216, 0.021905457178945653, 0.025908085954142734, 0.03311012449557893, 0.05757175720646046, 0.0661642910563387, 0.007506859001296107, 0.035973627091152593, 0.03628426042268984, 0.004710358889497002, 0.05394428037106991, 0.09928957762895152, 0.05064691082225181, 0.09353929126518779, 0.051015747085330077, 0.10064974136184901, 0.03868325649818871, 0.0596913235494867, 0.07145564813981764, 0.03608599196013529, 0.01110140117816627, 0.02888657876610523, 0.0698888704937417, 0.042598452855600044, 0.024866810090315994, 0.035570644613471813, 0.04405813117045909, 0.05114985317050014, 0.05821650171128567, 0.049736544242477976, 0.1309316375409253, 0.018677923726500012, 0.039013348941807635, 0.08750888126087375, 0.017527611526020337, 0.03835609182715416, 0.014192176295182435, 0.025244015923817642, 0.011997479559795465, 0.024388560850638896, 0.03340354000101797, 0.054850160668138415, 0.02441774766339222, 0.09714028084999882, 0.0646023522131145, 0.006356213762046536, 0.027011527818103787, 0.0031323678558692336, 0.029776593801216222, 0.0809905091591645, 0.032232234298135154, 0.020361775168566965, 0.026620618227752857, 0.05468894763907883, 0.05892160508665256, 0.032445479300804436, 0.02652150626090588, 0.015370842247648397, 0.08805979232420214, 0.007180549191616592, 0.03823412727797404, 0.06907084563863464, 0.002871387450795737, 0.025741473800735548, 0.02668907392944675, 0.034924456631415524, 0.04643628402845934, 0.03064189531869488, 0.010691650313674472, 0.029408362388494425, 0.059866385054192506, 0.04840203655476216, 0.01873906370747136, 0.05443408670544159, 0.0223799993909779, 0.028345061436994, 0.061257073321030475, 0.04112550494028255, 0.09033928407006897, 0.03795681266637985, 0.0933330632688012, 0.02271402336191386, 0.06703045903122984, 0.014369344571605325, 0.1874112428049557, 0.14238141768146306, 0.1989143536775373, 0.12002766248770058, 0.30933231697417796, 0.11697037029080093, 0.20467594295041636, 0.10315222622011788, 0.22782152518630028, 0.10430913796881214, 0.09759246400790289, 0.15309482405427843, 0.10345556423999369, 0.16542615689104423, 0.07919550625956617, 0.15067288448335603, 0.1113472954602912, 0.1145681570051238, 0.15571169613394886, 0.09530496448860504, 0.2000691057764925, 0.141962252673693, 0.10739105462562293, 0.09443064773222432, 0.17636171774938703, 0.14884053671266884, 0.18638755398569629, 0.10895576167968102, 0.15915153577225283, 0.10590103731374256, 0.1999328177771531, 0.06609504867810756, 0.12326701093115844, 0.17443718039430678, 0.09995259009883739, 0.2583394985413179, 0.14633111277362332, 0.10929228854365647, 0.16347200784366578, 0.2672614494804293, 0.14202316815499216, 0.1005174609599635, 0.13670422544237226, 0.09973809457733296, 0.22781383653637022, 0.056612215921632014, 0.2615855337353423, 0.09417939363629557, 0.13832854921929538, 0.16402336419560015, 0.15582006453769282, 0.09328431900939904, 0.1072261345689185, 0.1082485394726973, 0.09485632879659534, 0.18929904385004193, 0.15079943550517783, 0.12192779802717268, 0.24072336178505793, 0.15576504170894623, 0.14492833492113277, 0.14493053167825565, 0.10676695295842364, 0.11249873015913181, 0.10088772585731931, 0.15082693949807435, 0.18468998023308814, 0.07990837621036917, 0.1466799815534614, 0.09064217680133879, 0.12069346543285064, 0.1545545840053819, 0.1051424807519652, 0.1568570378003642, 0.08536486857337877, 0.24360984127270058, 0.09182688198052347, 0.15724608645541593, 0.11837250989628956, 0.19894677068805322, 0.15298477839678526, 0.1377599305124022, 0.10548221369390376, 0.2336045031552203, 0.07306064639124088, 0.09490628275671043, 0.14850878185825422, 0.1303558942163363, 0.17495234962552786, 0.11771829929784872, 0.13075108785415068, 0.1343573021586053, 0.08689950380357914, 0.2173310748185031, 0.09667399688623846, 0.08338346786331385, 0.15098423027666286, 0.1360285741975531, 0.13662169862072915, 0.17235048377187923, 0.16910790698602796, 0.04933277508825995, 0.16963557398412377, 0.24936417234130204, 0.19798487308435142, 0.15891615621512756, 0.11056968796765432, 0.14669313241029158, 0.259566773311235, 0.14016526081832126, 0.18778028315864503, 0.09214535981300287, 0.06796396206482314, 0.15971323766279966, 0.1313417186611332, 0.143675752915442, 0.14277214359026402, 0.13122474134434015, 0.15289098577341065, 0.16706619935575873, 0.16350898164091632, 0.1110387104563415, 0.214486749318894, 0.08900148124666885, 0.1148466850281693, 0.13253834273200482, 0.1286679832264781, 0.08681340725161135, 0.153046183695551, 0.10097518053953536, 0.12999859463889152, 0.07040798795060255, 0.10313327918993309, 0.12495702219894156, 0.1453377481084317, 0.2822607883717865, 0.12421042905771174, 0.09896799761918373, 0.18642239039763808, 0.16000248229829594, 0.18065909418510273, 0.22008767846273258, 0.08133246112265624, 0.11439778216299601, 0.1774159533670172, 0.1521821753703989, 0.09333439913461916, 0.10935114085441455, 0.15854436991503462, 0.12295207314309664, 0.3738511330448091, 0.13520107953809202, 0.10663801222108305, 0.16890488506760448, 0.10642344248481095, 0.08015116240130737, 0.08474742397083901, 0.20506398228462785, 0.1339748883037828, 0.1100421545561403, 0.11809268311480992, 0.15300999657483771, 0.36542861780617386, 0.10398182857898064, 0.1483264658600092, 0.13846848858520389, 0.2106760733295232, 0.12794894602848217, 0.17505289579275995, 0.18023900891421363, 0.1723274475079961, 0.1348432753002271, 0.14040938287507743, 0.08250095037510619, 0.1487242867005989, 0.15876183402724564], [0.03232231247238815, 0.011086033155152109, 0.03630298851931002, 0.06534858170198277, 0.030749668148928322, 0.09621167599107139, 0.05130306955834385, 0.05080275070213247, 0.03731060241989326, 0.02442384255118668, 0.05482873857545201, 0.05799842532724142, 0.03397212902200408, 0.03534290175593924, 0.03028802075277781, 0.05519619444385171, 0.03307475373730995, 0.09309789151302539, 0.044882208239869215, 0.038967031505308114, 0.03429112635785714, 0.08979913414805196, 0.03674909348774236, 0.02599110815936001, 0.02481454434018815, 0.08741888843360357, 0.02094732040859526, 0.04306441027438268, 0.06062118263798766, 0.0775111946859397, 0.06520497612655163, 0.0703079390223138, 0.025723315302457195, 0.022939619557291735, 0.024014080554479733, 0.061915172773296945, 0.06820554597652517, 0.050023183939629234, 0.05802466766908765, 0.01424578069418203, 0.09706225886475295, 0.012258877886779374, 0.04988540051272139, 0.023090466638677754, 0.08367356596863829, 0.019557557970983908, 0.08677753925439902, 0.018914054708147887, 0.07375874760327861, 0.02500166945537785, 0.05275762334349565, 0.004840601632167818, 0.015463773979718098, 0.04081503859197255, 0.019717147552000824, 0.04406097359606065, 0.047108573344303295, 0.030767390635446645, 0.022829787267255597, 0.02893757544370601, 0.031385462352773175, 0.0445828110241564, 0.07398157002171502, 0.06114372510637622, 0.029821374992025085, 0.03523247018165421, 0.02467611153406324, 0.01710418287984794, 0.03093784340308048, 0.06961997554753907, 0.03239705416490324, 0.03924440919945482, 0.04810001213627402, 0.016042323550209403, 0.07557875345810317, 0.05695838699466549, 0.02538527816795977, 0.01552175055621774, 0.04691765956522431, 0.12040316694765352, 0.03627728423452936, 0.056653679712326266, 0.01700115422863746, 0.05771680996986106, 0.01767589263181435, 0.028219358318892773, 0.014553394412359921, 0.028493351819633972, 0.04959101650456432, 0.03724859227077104, 0.02740360072493786, 0.05107957920699846, 0.019237725718994625, 0.08188246676581912, 0.04000963395810686, 0.030989031183707993, 0.03476195597613696, 0.00788609553637798, 0.008267841458291514, 0.017650171648710966, 0.02775967019260861, 0.06545067895785905, 0.04381283652037382, 0.07866229541832581, 0.02252985013910802, 0.03227505621907767, 0.05657929053995758, 0.017752831081452314, 0.020043495860591065, 0.03277321171481162, 0.015728443322586827, 0.035202275903429836, 0.013125656278134556, 0.06914237383170985, 0.03573267771571409, 0.04180438452749513, 0.03746064241568092, 0.029707050853176042, 0.04373980176751502, 0.01025877041683998, 0.0024646114388815477, 0.045113891901564784, 0.012542197400762234, 0.02480172744981246, 0.03865089143801015, 0.017915268654178362, 0.015985001919034403, 0.03512353032419924, 0.037421983943204395, 0.0712512903555762, 0.02855034876120044, 0.00731578009435907, 0.04414452087075915, 0.07918876755866222, 0.05214787110162433, 0.057043522465392016, 0.010436814427521313, 0.01627715020731557, 0.02963740029372275, 0.007220633051474579, 0.00783774368755985, 0.030812234908808023, 0.0185977866203757, 0.059399733727332205, 0.06780692361644469, 0.02409664633887587, 0.03359765985806007, 0.012257821254024748, 0.04358239224529825, 0.01595818070200039, 0.03722603840287775, 0.034307063979213126, 0.004100207279407186, 0.006782656919313013, 0.03494472097372636, 0.025605388036638033, 0.030085019243415445, 0.03719791471667122, 0.05354880842787679, 0.04775224544573575, 0.017712738408590667, 0.01256310833923635, 0.00815274084743578, 0.0556929250160465, 0.01881737327494193, 0.08889865668606944, 0.06954294061870314, 0.042343840541434474, 0.022651016879535746, 0.02095463984005619, 0.025490700245427433, 0.06505140350782312, 0.015056516731419833, 0.04081486047653016, 0.058945019845850766, 0.050501461009844206, 0.04956875207426492, 0.061524172269855626, 0.09899064796627499, 0.057060254184762016, 0.032833347941050306, 0.028387881502567325, 0.005759156420026557, 0.003902209700754611, 0.07300575714907609, 0.04653711963328533, 0.0336864912242163, 0.06142361868114676, 0.058536608557915315, 0.05558169934374746, 0.060578579650609754, 0.07435095176333562, 0.04008492483990267, 0.06272727157920599, 0.042520568167674355, 0.02196754710894311, 0.0571840852353489, 0.023537159759143833, 0.03272245252446737, 0.08441356141702272, 0.06342666412820108, 0.039539019562653266, 0.04175036359811202, 0.027361257489246782, 0.04326005895563867, 0.035414058875176124, 0.04959595920809079, 0.026885956431215163, 0.017125567865150515, 0.02797234930767445, 0.009073431629076367, 0.04065479777636938, 0.04025221976917237, 0.01382075735818944, 0.01521254771432723, 0.028512922253867146, 0.0708693366323132, 0.06628434828598984, 0.043256036515231244, 0.07615163951413706, 0.004934919325023657, 0.010966960198857123, 0.06462227887823246, 0.005863982923983713, 0.012896269563498208, 0.022475218793260865, 0.014345836116262944, 0.06142559650470503, 0.015967387043929193, 0.022845767562102992, 0.09716446744278073, 0.08368713242816739, 0.05473542834806722, 0.03295242553576827, 0.021632183561450802, 0.029817287613695953, 0.01551360363009735, 0.024050106258073356, 0.06347289992845617, 0.14473827090114355, 0.002952617369373911, 0.020510937574726995, 0.07129084682674147, 0.02172722299292218, 0.0384394313005032, 0.1029916328843683, 0.022725220514985267, 0.06680732491076924, 0.04279197528376244, 0.0569944590824889, 0.015622948885720689, 0.061273103710846044, 0.04057154365000315, 0.05626602258416824, 0.007435717652697349, 0.06679055237327702, 0.06999018849455751, 0.10564156764303334, 0.06643254033406265, 0.0702413461112883, 0.05894983267353382, 0.023472518696507905, 0.07587590196635574, 0.011662894339679042, 0.061313947808230296, 0.02777986774162855, 0.0481620965001639, 0.06982892722589895, 0.045347204577410594, 0.07200227701105177, 0.035227212065365165, 0.08064635301707312, 0.04843415299546905, 0.06185524434840772, 0.03484600791125558, 0.049416370602557436, 0.01663061102590291, 0.014085169732425129, 0.019651933180284686, 0.07720327019342221, 0.009566373537381878, 0.023224274009407964, 0.03628558886703104, 0.015854363518883474, 0.0461742725019576, 0.02205715216405224, 0.031875361455604434, 0.06145817678770982, 0.04127249099838082, 0.04890134237939492, 0.01951987356733298, 0.046531516418326646, 0.042581780508044176, 0.03317083217552863, 0.014597794324799906, 0.06590349294128828, 0.018743006367003545, 0.008100720933725825, 0.043603536032605916, 0.04164478195889387, 0.05083847398054786, 0.022848400330985896, 0.014993883178249234, 0.06488038299721666, 0.058221863728249446, 0.10135867050848901, 0.0397181257721968, 0.03543569619068876, 0.014440124123211717, 0.04945684733684175, 0.030406831174332183, 0.059113609822816215, 0.018781818835122976, 0.05520652142877225, 0.02118024531228002, 0.02216098419012269, 0.023863459828135092, 0.051560394422267564, 0.03493990072456654, 0.022560207689821254, 0.02595150530396495, 0.022670062244287692, 0.009216263515554601, 0.025163767495541833, 0.027208189530938398, 0.023209481150843203, 0.061940498562762514, 0.07349005303694867, 0.026380418421467766, 0.00685294618961052, 0.006187527305883123, 0.03378869980224408, 0.0785983148671221, 0.015395404552691616, 0.036897014651913196, 0.02204074142355239, 0.016398175939684734, 0.01653804851230234, 0.0071285302055912325, 0.032138089154614136, 0.12525438593002036, 0.044316235289443284, 0.04001022767624818, 0.014909934216120746, 0.10294224295648746, 0.016509288434463087, 0.01759654962370405, 0.020689535413112026, 0.034439652372384444, 0.042413865885464475, 0.011605356557993218, 0.03443352223257534, 0.14752957737073302, 0.1738009075052105, 0.2466011862270534, 0.11952129512792453, 0.13404588215053082, 0.19248944765422493, 0.12631490011699498, 0.15988439175998792, 0.16203561070142314, 0.13181235903175548, 0.1283285694080405, 0.13923450373113155, 0.10990418188157491, 0.27888591634109616, 0.10463963117217645, 0.10053358040750027, 0.14813888061325997, 0.13819257292198017, 0.2035968899144791, 0.13765841955319047, 0.08980584316304885, 0.23084488639142364, 0.15644945029634982, 0.3379196079913527, 0.15543466724921018, 0.1654524586047046, 0.13974864879855886, 0.11454231542302296, 0.1601203650352545, 0.111444101203233, 0.1451898826053366, 0.08602500893175602, 0.09028334097820334, 0.10564343785517849, 0.07850895286537707, 0.13754050713032484, 0.12275356348254718, 0.14692966971779242, 0.09922974568326026, 0.07129397126846015, 0.2176819770829752, 0.1570593472570181, 0.24648970080306754, 0.24576125317253172, 0.13146807672455907, 0.08204514553654008, 0.2134446255513467, 0.08441848185611889, 0.2022029584622942, 0.14959441032260656, 0.18681289366213605, 0.11858111276524141, 0.09096325957216322, 0.13741526228841394, 0.09840613987762481, 0.14937077154172584, 0.11979735179920681, 0.17794088926166296, 0.1106881198938936, 0.12027392935124226, 0.0957649847259745, 0.09649088678997941, 0.15710711188148707, 0.2298895048443228, 0.05597243638476357, 0.1221279775199946, 0.16355869069229811, 0.1491085856105201, 0.08016855834284797, 0.1654900112771429, 0.07621038050274365, 0.2018803617102094, 0.09469325668760575, 0.13830781361320987, 0.165194621658884, 0.16539552103495225, 0.11351125707733445, 0.09561163475154899, 0.0739872622943949, 0.30576819728594273, 0.15915261930786073, 0.26183157053310424, 0.1755089603830129, 0.23822364513762295, 0.1579811392002739, 0.06220604271220509, 0.22639450879069045, 0.1029903267044574, 0.16573174361838028, 0.18016780726611614, 0.23853493155911565, 0.11160221576574259, 0.10681619445676915, 0.17415955779142678, 0.30962594028096646, 0.11790661927079782, 0.10108693313668482, 0.27082230371888727, 0.06649929651757702, 0.16150424780789763, 0.07822487357771024, 0.09083320561330765, 0.10415996628580615, 0.14757628814550117, 0.1390092767542228, 0.10575755048193969, 0.17610217386391014, 0.13309725414728746, 0.17358807439450175, 0.17891765950480476, 0.10954276338452473, 0.11970811596256681, 0.07492101023672149, 0.15759899251861498, 0.1167594370781444, 0.20841310179093853, 0.22045983583666384, 0.13786121882731095, 0.0947562130750157, 0.11019522993592545, 0.08594955477747135, 0.14811695757089183, 0.10413103736937046, 0.13963655481347814, 0.12103280503652059, 0.1675098403939046, 0.13659014250151813, 0.26270775008015335, 0.09796318903681822, 0.14425039786146954, 0.1386125839781016, 0.200254108349327, 0.079716308391653, 0.1436916200327687, 0.15601446270011365, 0.14935404353309423, 0.16888796410057694, 0.12477445387048647, 0.06918099519680254, 0.12561560404719785, 0.20149238174781203, 0.22307083010673523, 0.11234247838729061, 0.09992872262955643, 0.1326950843213126, 0.1649739217828028, 0.05997389627736993, 0.10458139484398998, 0.14642333204392344, 0.1513335295021534, 0.2404423846746795, 0.14763793093152344, 0.07771737073198892, 0.10253889311570674, 0.11512652665260248, 0.06368450849549845, 0.14428763883188367, 0.15096327202627435, 0.19116092909825966, 0.17572868062416092, 0.20295797497965395, 0.13168935547582805, 0.09259818121790886, 0.22698883549310267, 0.20378996705403551, 0.16789483692264184, 0.19608591013820842, 0.09154591229162179, 0.12191335583338514, 0.08820888979244046, 0.1069681640365161, 0.17767555662430823, 0.17485446034697816, 0.09916819937643595, 0.14790076995268464, 0.16547252627788112], [0.07999638008186594, 0.0431757955084322, 0.02046327128482517, 0.042574526014504954, 0.06647105779848062, 0.019318204213050194, 0.03665993186587002, 0.03323025593999773, 0.011534592777024955, 0.04627598755178042, 0.010171152462135069, 0.0442127427959349, 0.027980529630440287, 0.03054197626624955, 0.030627156265836675, 0.051548071060096845, 0.07960621078382246, 0.012562947849801276, 0.03459220453805756, 0.0316739240224706, 0.03647672157967463, 0.01548868973259232, 0.03691685968078673, 0.02187153175327694, 0.013714624674321385, 0.06475571703049354, 0.02556849216489354, 0.07882757170591503, 0.03892744905897416, 0.010970665371132782, 0.04040117622935213, 0.06936808320460841, 0.06898575098603033, 0.02081358354189433, 0.03641524206614122, 0.035943173061241396, 0.012981309482711367, 0.04770747167640366, 0.03486090281512588, 0.046781905912212096, 0.04515668042586185, 0.022089919839345384, 0.03457795530266594, 0.032551584154134616, 0.06500259987660684, 0.0698753930919338, 0.017021463099808898, 0.02401250534603605, 0.04962880295352079, 0.03513584626489319, 0.024722718408156652, 0.02629288395837648, 0.04589572592522018, 0.028869954658148345, 0.028498160936578643, 0.02140915148629574, 0.06397511868271977, 0.02761856379947858, 0.034471256731194444, 0.04125850151467603, 0.04855941268033348, 0.019750351239053998, 0.04170908534433693, 0.039634552522329614, 0.07208869268652052, 0.032367628009524196, 0.01943092716828687, 0.02066559187369421, 0.0160886688172468, 0.010263472850056132, 0.019586601920309477, 0.06848796285339631, 0.028628094296436757, 0.050226788443978876, 0.046264610427897424, 0.02293152272613952, 0.0628855568356812, 0.06588335847482085, 0.00987983630693634, 0.05539266319829039, 0.010315993713447824, 0.038845675517222844, 0.012542219665192533, 0.030448653051280417, 0.03364872703969013, 0.052749663809663616, 0.016416707367170602, 0.05474010387843009, 0.0032926650283116032, 0.011199077089258935, 0.07454628503182903, 0.08488425373798236, 0.011324011156830238, 0.009422843104403, 0.006820681783210603, 0.05164426824194379, 0.04603697147103958, 0.06829982841736637, 0.045793866156600416, 0.05435945262433961, 0.047803223569644615, 0.015248257077473681, 0.07182268469478004, 0.07943650387460366, 0.03777248173719272, 0.09566228633048013, 0.05203141328820493, 0.033141205640276894, 0.09507867624051869, 0.0034430195091772475, 0.06025427966960706, 0.10025310795754194, 0.026272638169757556, 0.064485961192986, 0.06232562867808156, 0.005201095227675978, 0.047431340790353715, 0.02480618033587234, 0.04937816112942528, 0.050002908465103246, 0.041250430658692494, 0.03132050587737467, 0.029580440459540114, 0.055545857321703807, 0.0775435077957809, 0.011810381347459042, 0.00862806602526689, 0.05320455580658745, 0.038122281912365, 0.05406159536505584, 0.06593515296117403, 0.045669341197935864, 0.05394856256316416, 0.07592752575874329, 0.01946278200193774, 0.07325235797907226, 0.02209497572039254, 0.019587407150538638, 0.048887441953411326, 0.05226586144999601, 0.04008646108559333, 0.0156981507097953, 0.027897023173864, 0.061900140572106466, 0.0013924262839282164, 0.03734357604116667, 0.018161233092541806, 0.03607929036661517, 0.03271278976171743, 0.036976379924453795, 0.004593156609189464, 0.05448215189971961, 0.09085207842872478, 0.035892057640012354, 0.05674700849340297, 0.15197159838862717, 0.09574342533596791, 0.07361180978477933, 0.02940341226349119, 0.01595516016095644, 0.0470835629676003, 0.002046691151917912, 0.024902102923078928, 0.009164248240267625, 0.0485097667115042, 0.019552106896298937, 0.046650037402287126, 0.03756802005227655, 0.02283340709254844, 0.01120187127526151, 0.03454074772889726, 0.022070262202760205, 0.03259461387642659, 0.03333003769512288, 0.027499625357449986, 0.02307883903995389, 0.0436784558405634, 0.022409277116821613, 0.01929734986333642, 0.04768444654473569, 0.033569825609447435, 0.030599613310187124, 0.006536599712489988, 0.0437844233965734, 0.03826092251983937, 0.07678841706365347, 0.020899720911984332, 0.031001606876088772, 0.03840955614577979, 0.03129474222077988, 0.015996924521459732, 0.035883545206161216, 0.03041659227164928, 0.04862999092438258, 0.04733892856165767, 0.03373353596543893, 0.024466120848956052, 0.035776200966211036, 0.03326187885249965, 0.03199883256456815, 0.01655983054661192, 0.033920523783308454, 0.04533378283667844, 0.005715712022720254, 0.05415974068455398, 0.02242263206426287, 0.07604653656017035, 0.026763811911223456, 0.04186388621747028, 0.005538349396374542, 0.03726304188603535, 0.037709555035689846, 0.04479362178244628, 0.023543334427813534, 0.05428890777693596, 0.03478043545328546, 0.03915907705959398, 0.018391914854873903, 0.08534829641575925, 0.022811170492786914, 0.057309393159812316, 0.013249658022687072, 0.08798516937531531, 0.020105188741581514, 0.020180943465675227, 0.01636099990719231, 0.03629425715189427, 0.03210294104064815, 0.037406354313134216, 0.05536119242606219, 0.03898475399182644, 0.024823053063300904, 0.07334330817684531, 0.025086265013669617, 0.04240787304297555, 0.015507337120652664, 0.04049413022585213, 0.04230271813867148, 0.07977147964993492, 0.06024268361215945, 0.09892315705656074, 0.033319803478661925, 0.027670059571391903, 0.06819666989031248, 0.02932697290816577, 0.02995754239236703, 0.06138761338661425, 0.03564216538507026, 0.030801045177213382, 0.03013356683368329, 0.02359286907449132, 0.024878780932340305, 0.08211193882743828, 0.10396990226581693, 0.05932862855843268, 0.04009811280411668, 0.018910186263383366, 0.042658930469769984, 0.04516989065450616, 0.03714799786393996, 0.1011522940825671, 0.04845934519835282, 0.0314676552079618, 0.032328954694094136, 0.07245568471262231, 0.09867100496194325, 0.03622160460508894, 0.07996672386070713, 0.010395019453426357, 0.03093815510510467, 0.08420115133048967, 0.03132080644718371, 0.048937625979306176, 0.029219406023912597, 0.03278488940850366, 0.009819621227507014, 0.027113042488053907, 0.03745545480342116, 0.054378703935071826, 0.04839452973101288, 0.05502631684066728, 0.0542061249143444, 0.03781194543989841, 0.042737998883239925, 0.04126133651880082, 0.040350921699428, 0.08909746320568956, 0.09246692497981712, 0.049581988278077915, 0.020780763916263822, 0.03378015026100911, 0.02029883547947975, 0.02402822588919662, 0.02503677118511405, 0.008764153644733597, 0.025857671862468123, 0.018380211186013184, 0.008661509982630378, 0.027044974558521062, 0.037226839922368526, 0.033150397139252163, 0.037725744987255894, 0.011478512387839146, 0.03155705060635228, 0.09723060022224672, 0.04446334009116981, 0.07584476144984365, 0.009995285727200098, 0.023544393843621947, 0.051594856049632654, 0.021785527969768737, 0.02344373078813078, 0.013667368421010906, 0.04987542604794726, 0.08577204047469422, 0.0853797560557723, 0.07512588010285981, 0.017031307688739616, 0.03359975271450821, 0.015100492691999534, 0.05093390303954948, 0.024178013554774225, 0.03469149276497774, 0.011618168809945928, 0.0300731003517285, 0.011486095281725284, 0.03783039894187823, 0.015260539621522184, 0.0517467365716584, 0.02569251988461474, 0.08035575767280534, 0.0952627659717109, 0.06650844719843008, 0.021216708883002866, 0.027374777564546093, 0.03062988365854835, 0.021302360146364663, 0.040246004282380454, 0.07571020265459083, 0.03055651864997344, 0.029094879209878854, 0.042854430721490644, 0.06632974545937032, 0.02807084529194981, 0.012424459382600617, 0.03777910169446841, 0.03252702277677599, 0.013148017187631922, 0.05052805216109846, 0.051453922205837443, 0.08689726251759566, 0.048549653438385576, 0.15458421054063365, 0.08083807944785804, 0.11786571209086105, 0.08023686561500654, 0.14179233054164797, 0.11079157528001815, 0.10473026224644855, 0.12592456012498587, 0.11849719812744297, 0.16035152919357643, 0.08044612157391384, 0.12717070028884336, 0.23493345215683803, 0.08259238296886906, 0.1613475804333575, 0.18869126943172887, 0.13817624567309394, 0.14815517817623913, 0.14413380646146834, 0.266469904454425, 0.13130029197782278, 0.11580662336200476, 0.1475278110592626, 0.1366492619854398, 0.0755687418859452, 0.1315859000897035, 0.09333799112937413, 0.16073389851953834, 0.27894784114323556, 0.09819463521125726, 0.13768418692052364, 0.29093786026351154, 0.20463690598262474, 0.07987920980667695, 0.18710963398916647, 0.09632763656554744, 0.1535821775905788, 0.1005854936374817, 0.08326701004989445, 0.11260620056418702, 0.11209368822164834, 0.13332953152712435, 0.16606738732662052, 0.13584060303401202, 0.15566623216727749, 0.08368755545234308, 0.2036913504707627, 0.14039808738743886, 0.18068406003294513, 0.17667906009592116, 0.1381001903791912, 0.11834536213427782, 0.08114537311485037, 0.17485039337771013, 0.1373074430739507, 0.11832187316031195, 0.25308651791419834, 0.11759767061448656, 0.2018257396412082, 0.160169035079889, 0.15767109958687797, 0.14429789531277493, 0.21473756554769352, 0.17763833049684763, 0.21377366414526477, 0.173744801140856, 0.08038417450734414, 0.11841366198495962, 0.16905062802834436, 0.09327705338364467, 0.08621139932074584, 0.1650540588889271, 0.08599423948908225, 0.1230339023459237, 0.08455711504211649, 0.10849521451746114, 0.1565247485996224, 0.14370285614859313, 0.12907502154121175, 0.09705732358270325, 0.08334703583386727, 0.12203014761325903, 0.11661949029075913, 0.06251520288060419, 0.1409371240879409, 0.10539935290580615, 0.09844113956205547, 0.12638478074222803, 0.11802052409620956, 0.1661506711388938, 0.11575239463127218, 0.18057028879411519, 0.07962867559399456, 0.23095102835213766, 0.14013097359566018, 0.15483410650631413, 0.1239306022762321, 0.11996098051895387, 0.0732781327678822, 0.15446712932316586, 0.11592826878768392, 0.09683265321655199, 0.16293663735268638, 0.19147450133459643, 0.18105097784427926, 0.17959853546926752, 0.16092347272206098, 0.10689784554415382, 0.17809709650464356, 0.1336797361727804, 0.18629117868840694, 0.20985644543543458, 0.09342923818621784, 0.1337559102103114, 0.10843994677998126, 0.14570687751984224, 0.09462618880206719, 0.13771054800599813, 0.16423031949670985, 0.1191879075486213, 0.08332175828400068, 0.08456133786239661, 0.09732698294101283, 0.11549669507076032, 0.13725077267736197, 0.05392290651798248, 0.07533426774898544, 0.12162876446382143, 0.13532826880691573, 0.10730998241342604, 0.237674277741462, 0.09489835661952384, 0.17313868913333863, 0.13936926290625706, 0.098198457271792, 0.14260386902606115, 0.13602674851426855, 0.1165502033836674, 0.15598596422933042, 0.16967314149951562, 0.15817599749425426, 0.18434651428833604, 0.11039515709853731, 0.09750344339408912, 0.09340142991277389, 0.09220207473845221, 0.12123774169594981, 0.07141957234125584, 0.07633138025994413, 0.2432917122496292, 0.08835782398818992, 0.10161108977627009, 0.2053042154875584, 0.14887725817970932, 0.11547987058293074, 0.21129520260728896, 0.20738831459311768, 0.10787953622639179, 0.1945036364486441, 0.11852444979012944, 0.1659649857901968, 0.13341366138774902, 0.18651517370017245, 0.09515767043922096, 0.10300036796252243, 0.11524066154379398, 0.15339371660957113, 0.1483030288363807, 0.10279134206939489, 0.10023540773545392, 0.1183140509238001, 0.1446678114007227, 0.13566195324528962, 0.1685764847206883, 0.1403449199278839, 0.19529326673364267], [0.05933557134994771, 0.04502869334828574, 0.04310484247980639, 0.05308370076818392, 0.013971443950140383, 0.03525611500663217, 0.012615886171261081, 0.011326243165967753, 0.02574805293988902, 0.12214243455673568, 0.035341038965270855, 0.023047835820761975, 0.0293141523070517, 0.02157519218599191, 0.013094640071358299, 0.03256460513512138, 0.08561758470023051, 0.06148127242340706, 0.022984855313552544, 0.0679056292574387, 0.03407772550417576, 0.0135231579952233, 0.0317359378823312, 0.06960262413485907, 0.04705096784164198, 0.024239385456894524, 0.022108388184278738, 0.040205690820585005, 0.031711190968053415, 0.022823139479442034, 0.049701622483553365, 0.008360956871911185, 0.020543642167467624, 0.05124094066559337, 0.019613211625255644, 0.038373023926396854, 0.013491657537088031, 0.08159974560840055, 0.07754642443615012, 0.07716447813436389, 0.042995101102860644, 0.07575482057291083, 0.05449495394714177, 0.007120344780560117, 0.052000239375047386, 0.04419077522470616, 0.021226462558843195, 0.04467114144063089, 0.03156329577905126, 0.06450433676945977, 0.036339164507808164, 0.0555423840705771, 0.06594518679776229, 0.01430373315088218, 0.03200825412932318, 0.035195733871660195, 0.018087480311805848, 0.04782137279107701, 0.055598542385268956, 0.011935393340536393, 0.029202123259892687, 0.029491828026948497, 0.07164355251006782, 0.028238893501111306, 0.037958256143610924, 0.08162531259586103, 0.06521166287711821, 0.06118939687439706, 0.02129621701897122, 0.05811791110318154, 0.003642624301392061, 0.05970010686723981, 0.026807439062395133, 0.05602454628387932, 0.04589684656821191, 0.03216281380446162, 0.034145806421292946, 0.0376399601373123, 0.07078640162944794, 0.04472513268410694, 0.05321261181961745, 0.038590009353356436, 0.05091547551273834, 0.010328037842555204, 0.05756242469942663, 0.05474633420817554, 0.05140102563018445, 0.048781381628941745, 0.04365819149825256, 0.06621016320423223, 0.0031934009211909142, 0.0810399955662433, 0.022297585746855475, 0.017750617626006715, 0.029377902792475652, 0.055178071197588, 0.06321058041066863, 0.021011887256463524, 0.036138728974037804, 0.04520984788541682, 0.03424257505685091, 0.04245586031174753, 0.03271783636591863, 0.05110062280436978, 0.05970167650957592, 0.03049767190532293, 0.025912056444212794, 0.01626717759791063, 0.09283635125029832, 0.011310951213090448, 0.06873713893583044, 0.09819669838179834, 0.036767109122592956, 0.047689979255665094, 0.03771667594264727, 0.016822183461044915, 0.15421493269968778, 0.015105151524039684, 0.04877618659520522, 0.03676347630971577, 0.034548844560049474, 0.05459930362121668, 0.01708359570329776, 0.02760942796157906, 0.0416500660503516, 0.05609760330116842, 0.0444612175488146, 0.0485214740911033, 0.04397565629915334, 0.05450674667372368, 0.05427319651062135, 0.044559073430718854, 0.04007671668659896, 0.01035329591104528, 0.06313257326837629, 0.05057469243183732, 0.05742118657508399, 0.005604481711998233, 0.024683866977284197, 0.07154627179261297, 0.026542284540482797, 0.046035086415940896, 0.06280181289184839, 0.033117464336100966, 0.01608510094229132, 0.01690586061158683, 0.026798191902344115, 0.03763788583455607, 0.04391138631035574, 0.038634775701211765, 0.058603810030035675, 0.058189201809000224, 0.04242233007971663, 0.047476277832174674, 0.0322107342799427, 0.04629326474969275, 0.012820352494600229, 0.045903173377155326, 0.06615058358875103, 0.026915265698335133, 0.041856787574943155, 0.0017708770701574394, 0.021489945393113885, 0.05537672186619602, 0.016446866393380333, 0.05128419303218834, 0.02164072939194739, 0.05651569961628411, 0.053080301731824875, 0.06514206426800229, 0.022769972019887064, 0.026341591110394802, 0.02776826611807337, 0.019066198692598846, 0.017919474776135758, 0.017687112049316056, 0.07002928483416326, 0.03929325735953171, 0.028307434549788013, 0.03152518278511707, 0.03569099870219361, 0.040494690547348, 0.037873577093705535, 0.04483029500988778, 0.06617739738430828, 0.01972158373973798, 0.05061569609097205, 0.007948380280140555, 0.05026035578339361, 0.057426867715548724, 0.03843415834126063, 0.03185176487022545, 0.055612450232729316, 0.013902388036513003, 0.021006747883802745, 0.019223767776566092, 0.018936840497190133, 0.021597497434413526, 0.03711573299369775, 0.06544304225826636, 0.04514372623816598, 0.06288550488534383, 0.022597836432396434, 0.01903778927953681, 0.02672286020242609, 0.019644860512926243, 0.04860882487264462, 0.030109131621429697, 0.043656083798850887, 0.039069993363227695, 0.022394829356926493, 0.03549713859683834, 0.1293488295050338, 0.025486050690233242, 0.09446410374948755, 0.0365826742927311, 0.08764108002651483, 0.013170970887586009, 0.015070608260430163, 0.05733480800699908, 0.05602431992883794, 0.04965449981682468, 0.017776624335965607, 0.023990467270778026, 0.0813130168535281, 0.022620377312705386, 0.10179651537328027, 0.08771976252319291, 0.03667823693831451, 0.05848708504345268, 0.0464172368083382, 0.022001774959790055, 0.012049672022840241, 0.0714593959855847, 0.04533595361863263, 0.04253673214407172, 0.0312879218836315, 0.01519025638117455, 0.035973697595181875, 0.053862718341406435, 0.03379830319317989, 0.05207624642935116, 0.04947107801854145, 0.10622925954521634, 0.03441824883338995, 0.008709390567673836, 0.02678353077499196, 0.005780790952485404, 0.03847432708425913, 0.019669030407385435, 0.06450204353313893, 0.01266437531739939, 0.03473371354630217, 0.010535836408962496, 0.05191078831558116, 0.05450213051517494, 0.03171553624270018, 0.0418248195637716, 0.005775866802650853, 0.03265039369580336, 0.009030774835991906, 0.036191714607411996, 0.0604831802775152, 0.03877780240145512, 0.02372208811721066, 0.04926658293697983, 0.03492270887363702, 0.13327513210242614, 0.012264288143342128, 0.03274067224992905, 0.03603310280595906, 0.04357946447271388, 0.034042247134493664, 0.07493646175134927, 0.011277318008069415, 0.036153809414827265, 0.051402432000031695, 0.034456098364898935, 0.024699426103325095, 0.020993472717236727, 0.030194556529750116, 0.043293689377605915, 0.02890200059482595, 0.08720646350411698, 0.03356225570314564, 0.056515384203521535, 0.0628979284374509, 0.04944020838593133, 0.02292373203090392, 0.027892280850210227, 0.05538413221074734, 0.061555650463560596, 0.040674349656910636, 0.03768852628127206, 0.03630187900853343, 0.030269160924945027, 0.07253027055412531, 0.10948356968583539, 0.04872527155384887, 0.043453752077766694, 0.01583684512297623, 0.009863887553365203, 0.0040012381759879645, 0.05849635817867238, 0.029627180920215324, 0.03326913334603887, 0.03068984176934464, 0.08849322883179411, 0.025539130947436206, 0.02344487926166039, 0.027570281527005136, 0.07337013681535609, 0.015031639941298636, 0.031738101242808625, 0.02665409650944639, 0.030589794696425088, 0.007390972641587723, 0.020890577652608044, 0.04145265476836357, 0.04133301314141136, 0.03264579609094653, 0.07520601720898412, 0.01674679424468195, 0.04049365896207746, 0.05391901024268009, 0.01435174639482284, 0.07852798153180629, 0.07328199935727753, 0.0028504658439487685, 0.04626194611773826, 0.03175097008352168, 0.03596381218812894, 0.02472917509294348, 0.06343864239170216, 0.0027838135611091275, 0.04307610652176663, 0.011137832279928261, 0.04887201270321384, 0.02422548132017255, 0.06954730444704182, 0.052992201381130144, 0.018209923546237405, 0.025891378354572225, 0.03129189608443994, 0.020126193376199808, 0.015430217772518517, 0.03165423855534755, 0.009470382301515201, 0.05748768671764992, 0.042726592073449865, 0.007814325217623264, 0.04761287753353827, 0.14436393161304295, 0.10417166995466687, 0.15939493052428588, 0.08278219465864822, 0.10785566133563407, 0.12264185541425832, 0.10714150746935047, 0.21655938966432586, 0.12332472775597125, 0.2435301642981358, 0.1907623661099933, 0.11685921883326955, 0.13998267764691263, 0.14010645303642377, 0.09390173392603174, 0.08693476323969662, 0.1460577204125002, 0.15145574638154358, 0.07205744826933369, 0.10071883531054482, 0.1401211624033749, 0.1282889980939217, 0.09285022199037485, 0.1506192865781486, 0.09273114439565688, 0.11823011402157135, 0.09387698330101557, 0.1293921857723035, 0.09381967465742491, 0.07324285106733441, 0.24973560241051018, 0.1763841009233147, 0.17188159486977383, 0.17731165193254128, 0.13201106165070087, 0.17860241001471877, 0.18939233181299642, 0.20873682660749182, 0.26703081966843456, 0.19553694350179285, 0.20286954066250473, 0.23533908039098606, 0.15644850034732372, 0.08507576494594105, 0.14859622169751674, 0.16760680940933526, 0.09789333809749223, 0.10108137445058674, 0.1296817124239169, 0.1323169600800611, 0.21201187977567315, 0.14922439033398405, 0.18887058715336025, 0.10946915717795491, 0.1343548679142259, 0.09621448130928911, 0.06620001804549247, 0.1328181175631471, 0.11732924322132021, 0.23444743448635563, 0.19736694608582184, 0.10915983744780533, 0.12344735281658359, 0.12959290703292936, 0.132152856385801, 0.17149395629530773, 0.10162079706788063, 0.2639184007421136, 0.1031094414065592, 0.14055212755920365, 0.08822494244668633, 0.17552227451233193, 0.18538761389208958, 0.12990126939257607, 0.09841609949944541, 0.14140013518044725, 0.09313002650742419, 0.13066346989944577, 0.17300156992860138, 0.13039093842962757, 0.20913803164148703, 0.1540862294496037, 0.13643589452840388, 0.1772784927743487, 0.16701139917131513, 0.11923679281608202, 0.15419023402500898, 0.1393476070370525, 0.14700038154842332, 0.15937504096655175, 0.1310577878030017, 0.28462452872190624, 0.08563169292756356, 0.15964772086590528, 0.17674393864581361, 0.14655215403763577, 0.14500456833047792, 0.1326678623445332, 0.1284499847679399, 0.17193960113218054, 0.21149587933905423, 0.146848360018339, 0.07417165630613454, 0.08631066157249734, 0.1317908664350398, 0.15324270440032706, 0.07894658992881887, 0.16477845492772758, 0.15190762525890023, 0.1966753980377689, 0.21219137561274692, 0.16577857313677669, 0.08403656524023972, 0.10836429224582389, 0.08947491951403208, 0.15592865558573976, 0.17029918759362772, 0.06065260517061688, 0.228855277528055, 0.18460813618730754, 0.12934501486597583, 0.1599914242979139, 0.13374434754950926, 0.155874909250997, 0.11134423781186342, 0.1432176399976015, 0.08155801464454271, 0.13801653549307957, 0.09305908461101353, 0.15142188960453495, 0.15671816712711006, 0.14787855005124584, 0.1470771196181886, 0.12874556734459475, 0.13749355886830017, 0.165122514590621, 0.08931285672588274, 0.10020803732913919, 0.0779650773620233, 0.13290049595525488, 0.20173926459392533, 0.1157193245308008, 0.13733643136220053, 0.12710168055491522, 0.09114387605222873, 0.1557962119113654, 0.06897114551975392, 0.09232461074134335, 0.20309755811467767, 0.1206604547041934, 0.1483345404267311, 0.2291298721684143, 0.1173444943560753, 0.09771004246431403, 0.09179391578072682, 0.11305029431241564, 0.1397650651051663, 0.17638603050727397, 0.0819287693593651, 0.08359722123714164, 0.14218896394595504, 0.12105233836336993, 0.0863988435594365, 0.1264459188678302, 0.1891256039380096, 0.1438504396355711, 0.11648494633845985, 0.12340649016550742, 0.11844624968944117, 0.1724377306527458, 0.12743036291794851, 0.11467851436464116, 0.1339746656594798, 0.13815628190059215, 0.16493819479364902, 0.08802701908280142], [0.038540456152986735, 0.027233604378125165, 0.025962273866753094, 0.03389772500668187, 0.031188414723146707, 0.043762162677012384, 0.051254084100946784, 0.06180177260830533, 0.08576848558732308, 0.05937029643973801, 0.08577598870033398, 0.041101099413936026, 0.0442096665938152, 0.03515314201649744, 0.02588637998997001, 0.033509989953017794, 0.016692205572326202, 0.09580237412592396, 0.013581682833319064, 0.02365919110161485, 0.11824348752270453, 0.06448804662795737, 0.036090634093852714, 0.043722353875637054, 0.10205279380897991, 0.07996015585376881, 0.06265819247346371, 0.040757099122856744, 0.06488365586847067, 0.022081821152823977, 0.010010795685957419, 0.043755713413702324, 0.09301118639996275, 0.06928149683517404, 0.05202778789680451, 0.029452622220560443, 0.04275401071936358, 0.05395288557338063, 0.1407367442152463, 0.01822356236516498, 0.04360568455012981, 0.046969268514658324, 0.01574819558300078, 0.03156827930069994, 0.022282839272520505, 0.043697005821741186, 0.04607820519595407, 0.07117459681467153, 0.054494712749146856, 0.030861563609505538, 0.02008250870858319, 0.027269056772638578, 0.06072785523429047, 0.04098581790458411, 0.04364340420579538, 0.057195688714273274, 0.044810498220613226, 0.02702229638089193, 0.021412979112938046, 0.00540695493327803, 0.03603311393817421, 0.07911064167274162, 0.017286504444200546, 0.023479125666199252, 0.06486096841399558, 0.030586260218115058, 0.046813636436127126, 0.0547303631901741, 0.01790613281627884, 0.0639740722544957, 0.05131521109433379, 0.04822497496206779, 0.032891079608816653, 0.050900896021630615, 0.04154602065682411, 0.043565204105107114, 0.02383359766099602, 0.006553969678861904, 0.021840689951204695, 0.006563119432030362, 0.057515001462888904, 0.036486952085397206, 0.06691184898954816, 0.07097556765074842, 0.021312566532287747, 0.03889243453158997, 0.040267474614665844, 0.029326011826924514, 0.020520826692518312, 0.017470234233769588, 0.03425193724979181, 0.016573103857808746, 0.011398482893127948, 0.04059322920511477, 0.05322400749719236, 0.005418812133939355, 0.06609723801375367, 0.03912272666639183, 0.04990692650608253, 0.04292226301913615, 0.004960668602507212, 0.018655559106264263, 0.029304567469807807, 0.027535864428500645, 0.02028681083174888, 0.008429546160186874, 0.05961004353594035, 0.011878846325998893, 0.0017282013754993386, 0.0738692979211919, 0.020724934001918882, 0.024768050643615425, 0.06210175983142108, 0.020414267273736186, 0.014390305605047615, 0.035615503729786724, 0.013515912778530037, 0.08373952805413865, 0.023870380355219822, 0.015837828468647785, 0.018293405883014202, 0.11887101791216992, 0.054823606624267995, 0.03282689125626348, 0.018168331735068932, 0.026056443130073603, 0.02975183946546167, 0.04789904967765324, 0.02031362833804451, 0.01876179754617624, 0.026584297520457767, 0.013745142714469694, 0.07375735978712328, 0.01173823624412762, 0.008721560861886246, 0.05797573416202795, 0.020061320392414927, 0.015612069000781048, 0.11117464222479612, 0.08017103711608797, 0.021269013595883735, 0.06774496170692146, 0.04422069861902855, 0.033326516204397194, 0.02063254218228394, 0.0014499075928142702, 0.03855513583403081, 0.0694341269263532, 0.09294563249568455, 0.03322193646454252, 0.07803771135513671, 0.045452990307239816, 0.026805808192875702, 0.05138307678862475, 0.05846912878041621, 0.07760595952277072, 0.030231986747821793, 0.047524317051284015, 0.08011899029952474, 0.075024562102044, 0.04253957828041166, 0.03810267066000961, 0.03167928232869599, 0.023760913572914433, 0.021651306851708796, 0.017663118414930068, 0.0242690917730215, 0.01770225186191965, 0.018468656635377556, 0.020590764834196307, 0.029984090870129876, 0.013566135767177911, 0.05509824208274949, 0.05529597990971524, 0.01705125847365707, 0.05097489556646906, 0.04887112954747863, 0.029843123629689217, 0.05628397884720471, 0.044348793308017775, 0.05115803905937355, 0.017295107791142073, 0.046704143678653054, 0.11480265340651385, 0.04573627178615425, 0.025792871238081716, 0.004080504186276812, 0.014382517692865804, 0.02689032582566142, 0.020154630619799718, 0.03714203841809649, 0.02758289989287732, 0.022422372312576044, 0.018372106933384202, 0.058586425220710225, 0.011976279183727456, 0.06155929069791455, 0.04305166759877466, 0.014933779420971405, 0.011211203782295343, 0.040502327246940695, 0.008768780935497489, 0.04276831561583094, 0.00659919940517284, 0.03787943263887428, 0.04122791389818303, 0.021952967617835384, 0.0010260329622724385, 0.012807530038116965, 0.015939022159727756, 0.041190160845872015, 0.04977614153176546, 0.03407689058803953, 0.04594698235450778, 0.0922320426616352, 0.011915205068362411, 0.004787298266819562, 0.05585978949966375, 0.03231235656130593, 0.024176059851015452, 0.033838060044217855, 0.04408239197800867, 0.14515228540403768, 0.018365455434832256, 0.01148543198723928, 0.04425504521350376, 0.04998065887775738, 0.020599659474100918, 0.06540347094414756, 0.030371725733857602, 0.021584285350400023, 0.0636716173903551, 0.03477840196865145, 0.04337753351137508, 0.03063164997001877, 0.008756812876526965, 0.04792393017851282, 0.09764490416273475, 0.03803571038588416, 0.024115508022077847, 0.08545135846361518, 0.02720932872762205, 0.05176257400307804, 0.058048935898113996, 0.02782465820928337, 0.015229254386213142, 0.050426270317984745, 0.08109065456665121, 0.059872763813473284, 0.024901906253944617, 0.01767899109836435, 0.022409199191315565, 0.021718083444284275, 0.027704890417226125, 0.04216975125018507, 0.0106238319312979, 0.04091222283022944, 0.041047872582566924, 0.11793253506766632, 0.042389504887978546, 0.015185296051640762, 0.07832796531147324, 0.01625830522243632, 0.06480820913566276, 0.017287263290199917, 0.041150181350531057, 0.033816797513281927, 0.021503901480173226, 0.0668879592558369, 0.07899695207015611, 0.04977987824531738, 0.0548458487901371, 0.09159720953903161, 0.008516071302437922, 0.023944875283632427, 0.053569970768876374, 0.08224552540923469, 0.04637745027139317, 0.06485956575488672, 0.03281516532297246, 0.011948272385780001, 0.03543224149325397, 0.0727490037388634, 0.034115797679987736, 0.008881246922101127, 0.08873915430740453, 0.05577690273639746, 0.060233458716538735, 0.050260789939784445, 0.0476718968275236, 0.01020812347633182, 0.009294295705331024, 0.0030738502073290874, 0.024988190198200755, 0.033524899699841626, 0.03034880821360275, 0.024974902044050395, 0.031546411919407547, 0.05916798327234574, 0.027683882071869448, 0.018714118268690072, 0.03079438811255386, 0.05424741801107302, 0.02400013559963554, 0.04621299034624826, 0.04669913418183569, 0.04926488712953869, 0.025524061638861895, 0.07998109926120378, 0.03277202798926737, 0.013583214440586744, 0.06481980890384875, 0.01385585630487185, 0.033694647427182645, 0.03675606225442607, 0.0275982196762925, 0.03412902275158558, 0.015473961811949266, 0.017996713795582764, 0.03282980418589432, 0.03938581059628632, 0.033968481366173364, 0.03595628681068774, 0.039964767420315184, 0.023018365136522334, 0.033321180162602104, 0.04555996347335167, 0.0317625179013703, 0.02073582130833529, 0.023402448823617306, 0.07077702088281512, 0.03162188091664575, 0.06675332624581642, 0.0423861949093407, 0.05610169253486674, 0.02321865966223413, 0.0059544558280322235, 0.03795381810050458, 0.04744429868878797, 0.007299717699424946, 0.03716967228683643, 0.01820227571442956, 0.07626901016919874, 0.04285437134967651, 0.01267213261598954, 0.054438309525721706, 0.03467005954007618, 0.04633333701349329, 0.09914828755427152, 0.044835549415438436, 0.05399123976530973, 0.05185349080420565, 0.11097082620835863, 0.16820374847156927, 0.07756533435895108, 0.13521488348487765, 0.12036588886985555, 0.1886729383841157, 0.11375567599316128, 0.20577412855345756, 0.1240814734774176, 0.1369478873675689, 0.28069847845472395, 0.11021313795936294, 0.16793142480310053, 0.09884509796393104, 0.09733205180964433, 0.1717574632493779, 0.08767855848418549, 0.13434850028716028, 0.13050576351815835, 0.10502362580155022, 0.17842962319264188, 0.19254729064414278, 0.11684636483551003, 0.10859199799597263, 0.16661463218042627, 0.17846652277512476, 0.2598580514313653, 0.111826277570799, 0.14915635023498908, 0.0970915514335502, 0.07615472684847191, 0.14554143795976415, 0.18044266907963902, 0.16897155961487442, 0.13574084354331717, 0.1465947978431359, 0.10649523042957298, 0.12532301974715665, 0.2084640131215565, 0.20141040411544964, 0.09189461037749425, 0.15294496959540993, 0.11332828798913397, 0.21408457949291915, 0.1532333088107407, 0.12459273159038275, 0.1790660445112735, 0.13379914773395285, 0.12363087851554155, 0.15540792024694383, 0.15990800689905882, 0.10345565329771489, 0.1504218901391141, 0.1507197436876595, 0.11485746843391098, 0.13907365064369515, 0.09898465883452445, 0.19386378640774637, 0.11609675115323626, 0.13234306883532554, 0.09801566629903391, 0.1825434813508764, 0.10240917312330566, 0.11639583666692488, 0.10764054241008125, 0.11411061554099433, 0.14874539338052273, 0.19883528526406735, 0.1770642792689614, 0.2555681113153696, 0.1926853449549526, 0.1700659008929506, 0.0837287817557808, 0.23440002609277144, 0.2093073897412978, 0.11106714955531061, 0.1371811592252925, 0.0715192873030901, 0.1735560581437312, 0.12583458214066923, 0.1739621168235317, 0.13771241821814328, 0.22316811082419008, 0.20197753852698952, 0.09531970354146324, 0.12672907789237797, 0.08501401083776727, 0.19652677554404363, 0.14589008409529924, 0.06726237275870517, 0.10108121117809787, 0.0518975224258611, 0.11022334248991683, 0.16831198328873143, 0.1341067234170623, 0.17332988121779636, 0.16996906546410173, 0.12394634322845377, 0.13797504943795502, 0.13502855988917872, 0.13538593368139118, 0.09622192505048588, 0.10056875820737332, 0.08084792774752714, 0.1430183881893754, 0.12681411317316815, 0.11941314936848357, 0.09005927175167017, 0.09985093813156709, 0.16216330463066697, 0.09548259753501043, 0.16622199153061956, 0.2115839722682722, 0.13287146313814446, 0.12174661009339616, 0.17573619115864858, 0.12159052901552059, 0.1517711888300255, 0.15319437574362382, 0.16088691452750936, 0.1159970139269717, 0.21637135912897065, 0.15303656546166167, 0.13172978768125176, 0.08009900426259264, 0.0804811435227748, 0.1143670424062293, 0.2111612746375613, 0.12081656546797603, 0.2352682498167269, 0.12077432984369807, 0.06984696883591823, 0.19823470967821777, 0.14419840299524367, 0.06817201574449427, 0.14524909114697948, 0.2031238449853845, 0.09994839696446434, 0.1667386302142404, 0.12968773866305128, 0.12966450944077224, 0.1544685394037515, 0.0793842640996445, 0.19677169912029058, 0.09606357300071977, 0.09429792946320958, 0.08939684557844885, 0.18540616758400574, 0.22763560235034674, 0.22246749373152852, 0.23164045385783538, 0.08154064838890918, 0.13040291669312865, 0.10351598990382627, 0.14402174216229469, 0.16904317686567083, 0.15151247614994645, 0.10961046951706521, 0.1931199021055363, 0.17797066422645003, 0.12633201404241845, 0.11933222558582202, 0.16172810923308134, 0.16289616061840206, 0.16838965646456927, 0.07389929553028196, 0.136599552934058, 0.1347358271596022, 0.10263895688694902, 0.11255809455178678, 0.08890466808225028, 0.16464561049360782, 0.13303703628480434, 0.19815636856947094, 0.08267816039733589, 0.13183226343244314], [0.03270129018346779, 0.018496004777261987, 0.06975045253057033, 0.01217593917317572, 0.009486978578934213, 0.02887032758735586, 0.02964426515973173, 0.050847509628511034, 0.07616082730237395, 0.021346926114347298, 0.045873071867390536, 0.051985860263812356, 0.08873221522662789, 0.012742199705826351, 0.021710543223889545, 0.04503402939008083, 0.04045788744406309, 0.014476222186203813, 0.014249073046812555, 0.0837634400522802, 0.015722105381428264, 0.039315551475738175, 0.015734168991912156, 0.023475927009712905, 0.00951959968006122, 0.06075853932998143, 0.013501815683412133, 0.016500644269399345, 0.03473373952147085, 0.01339229416771559, 0.050992736796615645, 0.010307459942850983, 0.01870955034974031, 0.03854985916404985, 0.019329739043314476, 0.01837796804466052, 0.10218767172773369, 0.03214668693544809, 0.06297138621448539, 0.06535624066600576, 0.0918750325217843, 0.026188717965851538, 0.020937180815963075, 0.018763040643534623, 0.0635043224610854, 0.024432338286715094, 0.07298567463294603, 0.041769503586692736, 0.038364314823411405, 0.030000167644175235, 0.04506985656917095, 0.010911550525634084, 0.02288623873027973, 0.0413220033806283, 0.046919533488107845, 0.02469830917107174, 0.03259155993873719, 0.014099407835601596, 0.05745257200032938, 0.06392486044205725, 0.05591325752902776, 0.033991951786447316, 0.049769443648983724, 0.025274868858105037, 0.044260462891543284, 0.06015837563609239, 0.008600407109042862, 0.04685508167312946, 0.14067287498619407, 0.009274871845263988, 0.013202377649577102, 0.02641426406626124, 0.036897437676088884, 0.06496479487395845, 0.09869168119621463, 0.08016230203793384, 0.03725183545611799, 0.015013230040494818, 0.06108578192652203, 0.05900787975406274, 0.030881297316227574, 0.013464721287164139, 0.027194966314709745, 0.04787596517417114, 0.05163212670595385, 0.07146135525545105, 0.047659488118370064, 0.023606201757502276, 0.050187254237243906, 0.01220879868924385, 0.014446561326622032, 0.06529624544782564, 0.028027945445501246, 0.02881693006202113, 0.0733910060080234, 0.05466368864290416, 0.013250704450911144, 0.03727941737452056, 0.032007998088374734, 0.024739066066103987, 0.016976283004623838, 0.041092100873356685, 0.03657110049971379, 0.006401436066880706, 0.016377299325540662, 0.018495947260817047, 0.01185391758554033, 0.02340720599022461, 0.02068085228529526, 0.045902872807346284, 0.04195324450847693, 0.05352245476387907, 0.05300578639435116, 0.058693483733804896, 0.025094354423345067, 0.036967095657018945, 0.055400711789843626, 0.02300908829056425, 0.003837231656689255, 0.08538043141015805, 0.05662935211148579, 0.053378463271656074, 0.04444387726834975, 0.010585851596260909, 0.053531620287685655, 0.030790903729212005, 0.03979377659561578, 0.05595437622105237, 0.02824765455443412, 0.04526382799667772, 0.04269846838724334, 0.002949309941868705, 0.02003839359531412, 0.026031553352368064, 0.039829436791478656, 0.01565199469041545, 0.01929374488099711, 0.041656916073407046, 0.012386522648739628, 0.04220606824674178, 0.039920208873809315, 0.05031567547121085, 0.03774561970203649, 0.05692155049473513, 0.06127684784587473, 0.034289449104107916, 0.018023776210611686, 0.04463978570129257, 0.0778212639852427, 0.06006102812534664, 0.015470639773411676, 0.07120025285985321, 0.03386065844097175, 0.02913312207965646, 0.01901627256302163, 0.022160867301863618, 0.02890520481741987, 0.040315985097549856, 0.0463918961759191, 0.02453362845699303, 0.02652400915394537, 0.04771062951476779, 0.0783999684790615, 0.02010783635341795, 0.040621868683956563, 0.0184375291064498, 0.041279649012722075, 0.07111587809049524, 0.014437684312724741, 0.027529923536349088, 0.06880057029775344, 0.050265780882909894, 0.04005257833341602, 0.05722994996176567, 0.07512271113228053, 0.0546213862253353, 0.015016479719633935, 0.020161573411314748, 0.05385036158259027, 0.02552271278545959, 0.016828217121656053, 0.01100929044696386, 0.030956283917475957, 0.043903567784582265, 0.052202040460542776, 0.03558201431587804, 0.057155167451128364, 0.0343539231835166, 0.01186443010738003, 0.020803785337193403, 0.021212346910033375, 0.04318704275647178, 0.007457737174263457, 0.02393979342741659, 0.025322000801679678, 0.06580188550287858, 0.03121522480796557, 0.02145910544641083, 0.009426236574654467, 0.025906653609126806, 0.02471062140102731, 0.04695959090895485, 0.07712302918662317, 0.014750606242159847, 0.058214356904500164, 0.013662509209098062, 0.0267233889826457, 0.05662439827574417, 0.05193602504732553, 0.023165104430518113, 0.010195390077569755, 0.016063385701272637, 0.008921175394789316, 0.05433986363641452, 0.005593607393166167, 0.010721476301114308, 0.05028930325352121, 0.06589967830223031, 0.07291458430700004, 0.00787901080911979, 0.049042754908441566, 0.0210648543361458, 0.041697574633872136, 0.048122168955160305, 0.05973288010864053, 0.02844477454345906, 0.06393287563696504, 0.027129167501698248, 0.035064830153714865, 0.02112557129294146, 0.019435456124483608, 0.02294399637321476, 0.02902117652411107, 0.021129799679329153, 0.039016803639242426, 0.0686407859029714, 0.011657552731776377, 0.033379260639776476, 0.07740162400295958, 0.02187075249821646, 0.03935020606149919, 0.023862201887823176, 0.014889228295942303, 0.03456713107880205, 0.08326347742695361, 0.013075505648885155, 0.021769612612843048, 0.006551411588588962, 0.050238929979968816, 0.020588423358276486, 0.021150616921659093, 0.06631354437558912, 0.04579491258482449, 0.05312880479323212, 0.008979292051662924, 0.0398612749268068, 0.013693189594050637, 0.01208474035593099, 0.034446068239049055, 0.018571985856397077, 0.06539368943776935, 0.018267081904923543, 0.016640685680613387, 0.06647640126175247, 0.07083038872224279, 0.027162308106198907, 0.03265307655965444, 0.013533308720070636, 0.027958747596130706, 0.052524073180393316, 0.024868645050446503, 0.024405494805250783, 0.03142224690236617, 0.024684508935024496, 0.041413569560972974, 0.04391360533190891, 0.03934115557058249, 0.04555847175652161, 0.03915193759894464, 0.020976783671358135, 0.04429428627190646, 0.044565121934283525, 0.02826544012350496, 0.04280292196199298, 0.017223935828951653, 0.017509020726720337, 0.025034275713551324, 0.022321612777886912, 0.03827625158010051, 0.09046333405422047, 0.027489893946039956, 0.020221969389240257, 0.03222961451683659, 0.005879327754882979, 0.04993372174794786, 0.02851014847692568, 0.013677601709787268, 0.07167556876083836, 0.010794639074447332, 0.028887294938613195, 0.04275975123164244, 0.05196173304284457, 0.07630719366716221, 0.06071214396797586, 0.023487474827561527, 0.050617673914530315, 0.04555703199002892, 0.07743367736111395, 0.019347632223798428, 0.06873601087136194, 0.0545589085231768, 0.022190137606230564, 0.045031955087324604, 0.048449812311446294, 0.006179885504025151, 0.059032441131421365, 0.06201297299412545, 0.10214988156803884, 0.05643037860863842, 0.060155629689688794, 0.05614996924123261, 0.02828275813953951, 0.06824376658187248, 0.008436674488621065, 0.031180733494693413, 0.014158168305584695, 0.03026198250154266, 0.024788153568806592, 0.026810995805135462, 0.03474657867627684, 0.0009356478983590932, 0.029583106625068467, 0.04260079804225825, 0.048246623409795575, 0.03279839649621863, 0.002165375176446105, 0.045148635545047, 0.08015594183234498, 0.04050889525387902, 0.026765873226395342, 0.039465079389628954, 0.00837022907944629, 0.03227809902455192, 0.040753325301920995, 0.03741526750673074, 0.04732817855256144, 0.040721880504861474, 0.04676094766182359, 0.03815157077042386, 0.03478876235021744, 0.009035532930283807, 0.02208278780017281, 0.17032900708727539, 0.07671259925700724, 0.2221290595480241, 0.1214189815800637, 0.1065617788117379, 0.10270534199662507, 0.14153637865092605, 0.18555443384684622, 0.1557026122463867, 0.03798773053858895, 0.13024706568103284, 0.13775414176052436, 0.22263379418291152, 0.12178756922367029, 0.1254746108315885, 0.15150354069191962, 0.13331011694390327, 0.10485002261702903, 0.11871985727339052, 0.21171144355321303, 0.10794189147418365, 0.2124417168670334, 0.15404569334350526, 0.12286153854802251, 0.07192000251961872, 0.20365271426271647, 0.11567161927814595, 0.10307812277460471, 0.11480294284410775, 0.08365760237211362, 0.09645893733249977, 0.11710088438121602, 0.1123703460325487, 0.13973621040349826, 0.07737516643828712, 0.1284434093395248, 0.1442615152336657, 0.13759032008238137, 0.12074321159161627, 0.19148452032823116, 0.1897130731958896, 0.16301206924254075, 0.16527711879462004, 0.06823228555731475, 0.13819496263749897, 0.06786837344407104, 0.09098313428694382, 0.10297761371475644, 0.14656125276815146, 0.10427554836496711, 0.1712052311631851, 0.0890699666342698, 0.13885410851798952, 0.11698701666318811, 0.11433446954470128, 0.14662537432741374, 0.16723193577490747, 0.061568626915686764, 0.14613858482334763, 0.23021898872684687, 0.13266462658066303, 0.12294424348510802, 0.19133683294057846, 0.093310442607617, 0.15661735378671438, 0.18169243092415854, 0.1533303817268461, 0.14391690638149157, 0.16050616308348253, 0.11309707930195145, 0.15955796552589163, 0.1484432353754528, 0.27393576165195554, 0.1279003353556618, 0.24089959217235446, 0.20326178055256605, 0.17254648497328162, 0.10351976001402363, 0.10184882194153033, 0.16956711828242987, 0.09748745011165738, 0.08221852607675828, 0.1354051404632628, 0.1671068838913925, 0.11118489128421061, 0.1844677366898395, 0.1362273213453591, 0.16789160115877166, 0.21656203171005473, 0.13353788206586614, 0.14653683610958979, 0.17259386368095875, 0.07783096385537647, 0.15794079605257139, 0.16863977507455274, 0.12145085682277568, 0.06324587695416994, 0.12705845787422732, 0.1992552963201888, 0.10186225481447764, 0.12983382301172242, 0.14521760924253613, 0.167247045901604, 0.18368572084000334, 0.08305416951770894, 0.09201281223795377, 0.13356866635149345, 0.09783443383639678, 0.11101785610662773, 0.16078393411589786, 0.11309573601465672, 0.18190777249401435, 0.1272325954050757, 0.12334145576460287, 0.0984760353458114, 0.15357831842266023, 0.07429871198837645, 0.14103781868470833, 0.13440463633742183, 0.17123738100053743, 0.15796276362380013, 0.20540755213005468, 0.11395022258511744, 0.136314716655761, 0.17184215714223683, 0.19909969763830304, 0.16985857451800257, 0.21790027240058407, 0.08037906853132881, 0.125744336983189, 0.21471193176694214, 0.17784656229196116, 0.13003497471800074, 0.1389219705015421, 0.1266032541752793, 0.10327015348593704, 0.11735751904780045, 0.08510333573212847, 0.06896746446727775, 0.15507091098697856, 0.18903529940871522, 0.19320789113407955, 0.1414230527007021, 0.17746293131494895, 0.13029974332312122, 0.11101569645688869, 0.1690889525343664, 0.23181169701274484, 0.21247576660243794, 0.16714792465791106, 0.17055991891538724, 0.18884391436586156, 0.07749213633360341, 0.12107230213587172, 0.046959249521023594, 0.09431036043679342, 0.14399198204046115, 0.11353243055054918, 0.09349012398160994, 0.12158462894149125, 0.11247341550188139, 0.15860298473853618, 0.16989188210573047, 0.11704087432008237, 0.14835735404631123, 0.09789672229089774, 0.11560537517652847, 0.14561508869519457, 0.07795488767442293, 0.14759412937564775, 0.13198196946177632, 0.10967298803734593, 0.09062069904757664, 0.11835885437903926, 0.1999370925477706, 0.1867803727509454], [0.06051129283150658, 0.050573367698234506, 0.016530909051652998, 0.03374747349880636, 0.017084671817428898, 0.07466603798093274, 0.042612305041984655, 0.035220187637605704, 0.047420379269169644, 0.047400344992638566, 0.05400011585152242, 0.09666908386861905, 0.055119794051279314, 0.060328776453388855, 0.04926936970150564, 0.0291096089858911, 0.029985823784954846, 0.05389499063312542, 0.05229646390944254, 0.03069946000323398, 0.015793247657711618, 0.01566647584695602, 0.01277877738175448, 0.05743953617638908, 0.033289130515186116, 0.07928682010970078, 0.007233943933897535, 0.027660890336846933, 0.07367072888882831, 0.04274921644537244, 0.024169350836018566, 0.01625856868486153, 0.04068368587468285, 0.014180694342940114, 0.03235775002394803, 0.06636612553847954, 0.03372775834577624, 0.014383773777808528, 0.05563422113482375, 0.03626923935371451, 0.08341288659721613, 0.025351031763420906, 0.04311403397878166, 0.020782765859621577, 0.06140336918178946, 0.07580897508887574, 0.01948213164723711, 0.033709245471982285, 0.01450799538361025, 0.02695720631891163, 0.05435818726255093, 0.013640659453812987, 0.022412525868276134, 0.03718301981280092, 0.10207217128481716, 0.0554495191317983, 0.05111477556056343, 0.013776785108348122, 0.020817019685637206, 0.07745989743852988, 0.04460769523575436, 0.02660491067217663, 0.0384208405012032, 0.06663851600023918, 0.07138432032661512, 0.011593065664783353, 0.031685816938988864, 0.04951610040734522, 0.016676167761033867, 0.007572179129056167, 0.01700497628917219, 0.009433480863663135, 0.04842247530177701, 0.05084292686660774, 0.03489070375508163, 0.08763237463426776, 0.035453444652375765, 0.013881661707273452, 0.08155350980814546, 0.0415757028531516, 0.05682494884240441, 0.04873160949500743, 0.05446844814287033, 0.03849976048513781, 0.057830848381854594, 0.028014519994030707, 0.03759950937819667, 0.08141988611896522, 0.02194911958213197, 0.053724849567515776, 0.07251290429849178, 0.08695923184859566, 0.06840489426394925, 0.036695465896627866, 0.06681185201159678, 0.05663189025653992, 0.018672806618269533, 0.021864774498681072, 0.02713759273319738, 0.04602496723236982, 0.027967848182015587, 0.05787790796603076, 0.050450208291294985, 0.09290956411859952, 0.011276781806373037, 0.0781397418177221, 0.07460657710907981, 0.0805891482741572, 0.0349420343991369, 0.004495016391956597, 0.023026755116006825, 0.04497088004427496, 0.04001226116088219, 0.0568773593113292, 0.02683359049115097, 0.027910292774322443, 0.04102570463146549, 0.013324973024282372, 0.02778624650090933, 0.010976070061587961, 0.053030922936159186, 0.03766105568502098, 0.09253037860617042, 0.09494613608694635, 0.06854375009424984, 0.05386416924011428, 0.025415876916667912, 0.043252136529190466, 0.019923319887311663, 0.055761473486199975, 0.040456217611790635, 0.07341928183450364, 0.03351909981574863, 0.03306704282294959, 0.02054627864708891, 0.04224371739837807, 0.025614776204747614, 0.05454982463561464, 0.04851388563110959, 0.021916266559856012, 0.03202013220288791, 0.10393951873993501, 0.026304288912797347, 0.01397245605403441, 0.036788234356208704, 0.03469935581961181, 0.021934352698735893, 0.0143941156056826, 0.029677010570594575, 0.06649180824751966, 0.03291472443379462, 0.039261467463802546, 0.005063174039605656, 0.025560463982401416, 0.022197371690708678, 0.046070041571510956, 0.0225166862946935, 0.04287239440600388, 0.0498032892937772, 0.03428785719734151, 0.013374851841945201, 0.02075769611110445, 0.04443422192707658, 0.036250711636967026, 0.0654401553038042, 0.03610939558711834, 0.021611073170788586, 0.05552211972826626, 0.0493272089806851, 0.05866999847057741, 0.035116769358864985, 0.015833952602406498, 0.023482649012294132, 0.11781482302467339, 0.05809607340779621, 0.02713722537009744, 0.05508584821654949, 0.022427101648645476, 0.08522463234839961, 0.021447785838972777, 0.04737417686556, 0.04216621491650585, 0.020131707533437293, 0.042535863831290044, 0.0354665175836999, 0.03966040152590722, 0.0310646764410194, 0.058591405031620525, 0.03438352003286127, 0.09507034934358671, 0.051100047639920376, 0.03979978799179662, 0.044815889923484065, 0.0928668089909479, 0.07316073242691346, 0.032089018350234255, 0.06386999346432276, 0.015812821802683175, 0.025255459840991534, 0.01370494521324872, 0.03133301106572617, 0.08341360648046248, 0.05649704202369321, 0.0565686407207977, 0.03933953026717063, 0.06494531349744648, 0.04025324022222776, 0.0076643186184810475, 0.012307348479225766, 0.05386007629567757, 0.025007385847857222, 0.06723682803567499, 0.04602947206876706, 0.024501443367626052, 0.024159547065210063, 0.02143449954019161, 0.04912413511192426, 0.04636609912267886, 0.00858334606164135, 0.02244333427370293, 0.07529024354880676, 0.05601980767096393, 0.10218813185929321, 0.029779675569443498, 0.021894094898016192, 0.03466093112365343, 0.0065185618132090895, 0.021815410545968916, 0.02879484189179493, 0.07718926586676389, 0.040819517453201115, 0.05909786887059454, 0.011128323512821225, 0.05250269561656751, 0.01288635168748442, 0.015031223410915118, 0.025546311226207763, 0.04258821121766232, 0.02112144124112092, 0.060934350403840654, 0.022902384152985178, 0.030630128567281645, 0.04725888793473132, 0.015324387513828697, 0.01813379960367456, 0.04651243951229844, 0.022055827430449426, 0.06246413569897413, 0.050156247307313606, 0.03807167486229446, 0.041730692973942496, 0.019705560771399178, 0.10061998866149224, 0.029910403027315624, 0.02302561220858479, 0.04622553264198359, 0.03174043900799006, 0.018793188537529204, 0.029055990671622567, 0.01172370870335726, 0.04444109421456233, 0.035082500689895824, 0.0666003325022757, 0.05141404290043283, 0.023821350368962158, 0.03505222106468864, 0.06534188010846265, 0.08446032414212823, 0.052279524388723075, 0.021521386479435023, 0.08941100575611927, 0.05207525195146445, 0.06022880173986778, 0.02961368310934631, 0.041239439451601356, 0.010456985073687974, 0.047245833557099104, 0.00812263469924801, 0.013849842125637224, 0.06914118639542721, 0.008376201512874104, 0.07733569160336629, 0.1062891137553379, 0.0391788367414847, 0.0687908630061429, 0.047922939411364496, 0.044956560304854065, 0.020807644505111966, 0.03740089952771086, 0.03545979743648786, 0.0407990935491398, 0.041736589337233454, 0.06733337402692996, 0.06054288234736305, 0.0329780036554439, 0.03606859972933307, 0.032679630603524856, 0.03886675993271638, 0.043980524787912145, 0.09302997015765868, 0.033735454417183064, 0.007610051388837746, 0.05408244229329284, 0.045682492054766044, 0.026162124959228095, 0.0728964907466434, 0.033656938903732225, 0.06380325212376192, 0.021219143127382267, 0.04757216331199743, 0.008101303519651992, 0.029154521907912567, 0.025008408156281803, 0.012176806558272801, 0.10973019278026186, 0.025849792109511327, 0.049372739740647376, 0.034262835688423365, 0.022111492216936313, 0.030015518968866672, 0.042497962349443696, 0.015316362114390358, 0.06044036206731107, 0.06405970125342719, 0.017122734716394916, 0.04763417717185803, 0.03874068759614602, 0.018151073090848513, 0.02290196112880949, 0.07611364897456951, 0.02119320135534508, 0.06093971984228119, 0.022323841076286044, 0.027233773216721602, 0.048539333874941804, 0.021149355270608794, 0.054688628515577875, 0.03692949845572002, 0.05321477146935649, 0.021125669627508614, 0.03445780159381684, 0.05795001874503214, 0.030491217075905297, 0.06726779785822146, 0.020700756685982924, 0.03381260066817049, 0.012692776381300064, 0.02338012131076539, 0.03785543158301152, 0.04495577362831682, 0.044210750129423104, 0.06283827460720204, 0.2092654287116602, 0.1089900489023421, 0.14572002837667242, 0.09688230289611965, 0.18519514531362802, 0.15175128442933783, 0.08926560418331064, 0.10082682521897368, 0.11938391617150046, 0.1673857681453228, 0.15176464308751747, 0.16970091266557574, 0.1285766693763435, 0.22351818188326433, 0.14788387867156416, 0.12471634370740503, 0.09128173740464263, 0.17522744892630726, 0.17134236521087587, 0.08130070462357253, 0.08617628089268692, 0.08863236667821184, 0.10147012624656782, 0.11002792016370222, 0.19711713917786255, 0.12345263690804131, 0.1568304095417261, 0.12437498546205461, 0.15156543580815196, 0.17584046290721744, 0.09706055192509666, 0.08561401496990584, 0.11173030303325504, 0.11111385290860198, 0.12171838621725328, 0.2075846423394978, 0.1222592857084237, 0.07901435543317348, 0.13209790777182207, 0.16477832134114578, 0.18761614977847785, 0.20020094088977203, 0.10430009861011058, 0.09057200673851185, 0.22810805356130004, 0.1614569581579417, 0.18350640311837196, 0.21873057237826288, 0.10162873804802075, 0.16380487591959536, 0.1241360732819885, 0.09891260371659882, 0.18276746151968837, 0.17114631948061287, 0.1761107234051451, 0.1543696111184545, 0.10779537667986006, 0.13765546580543742, 0.10448392858961597, 0.16704537469195202, 0.10616168699925765, 0.13620658573927358, 0.11176812287885696, 0.15708091406850144, 0.15851435746299103, 0.15210335928713903, 0.14803466823650524, 0.13822086359141394, 0.0897444378642831, 0.0993561111681629, 0.1269945886451751, 0.14698200597194955, 0.1310521474806592, 0.09981881055864505, 0.11012850343831815, 0.14653370424639434, 0.15983646386303008, 0.08871629615896381, 0.22418889042455703, 0.11376021793694235, 0.07327482278924435, 0.09608617139747366, 0.12256027854164131, 0.11657769995508716, 0.10649336021742783, 0.12562109594000503, 0.16742694249842316, 0.34199171292129904, 0.23364129883702844, 0.18606200348585844, 0.20923191332258284, 0.15205577277811244, 0.19623855507234111, 0.14813901419984177, 0.2263974625384435, 0.1620944926980883, 0.1651544269407168, 0.13122285628924146, 0.09893052658298984, 0.14873939682729542, 0.07867173553677276, 0.16146719979587942, 0.09392010950250551, 0.2139279863331467, 0.10594143983325921, 0.20779355691047385, 0.20663855248130858, 0.21804028598126024, 0.11196170467883348, 0.15326078311773017, 0.11819443898275495, 0.11155394648085348, 0.1709682188811712, 0.1786370831541717, 0.11421250499552116, 0.18072520470013842, 0.18348269892157987, 0.16120902146212757, 0.1098243119486142, 0.0825699997949414, 0.14022009068867192, 0.1390806119889021, 0.12471496331272647, 0.2891796827316284, 0.13490674376953393, 0.09591543290298432, 0.10494941845536232, 0.1510498658171855, 0.17036658944562078, 0.2576884865993634, 0.12828936916776001, 0.1579066869453527, 0.2616486756596714, 0.1190908568969462, 0.09970969258574769, 0.11633077258011326, 0.13499649910954759, 0.12122335145249963, 0.2315804289537482, 0.12884094816399738, 0.08284086885396391, 0.11266483023064211, 0.11587650398723781, 0.1281573559390381, 0.1760638493578881, 0.11647182516753674, 0.1399603983736597, 0.1751256559509784, 0.10230649699224159, 0.1417163643054664, 0.1427733013406396, 0.1418170885881409, 0.13311941467691213, 0.18093073507770896, 0.1087380971875973, 0.0890092589543201, 0.14235125679988414, 0.1003524889529217, 0.10778734664199874, 0.15531994606135413, 0.13342335383640602, 0.13039835990639403, 0.18927355849882588, 0.12626544339582324, 0.15393828973174095, 0.14470509689999744, 0.07639089308213443, 0.12856096553150564, 0.11163954579387791, 0.11174250394105911, 0.08973913150839508, 0.10169462591875345, 0.10909140401054174, 0.20333286345703527, 0.12541466014226899, 0.1100843382300809], [0.037175646575633436, 0.026952493681164924, 0.03736385151569266, 0.019047973401029594, 0.03413936086872127, 0.007619732241437305, 0.08175950031727552, 0.007127200369723141, 0.022613905784965027, 0.042233939602738246, 0.03958324414270464, 0.0353735635871999, 0.045979829810676165, 0.019005626454600133, 0.030391045693249907, 0.03878900140989572, 0.03175119272782467, 0.04965118241671007, 0.014482517453870969, 0.05289603388519026, 0.017844536414486356, 0.0275360072919284, 0.0766780374397058, 0.05888795982173178, 0.033479109188192524, 0.043221886589890346, 0.05024598409363534, 0.03368960453371983, 0.051361866208026186, 0.08646925853099674, 0.08257265668362379, 0.030247380746004637, 0.03410996439924929, 0.04368305344542023, 0.02941049049695721, 0.020191300136502832, 0.015917592645564582, 0.06797959169489332, 0.02853423673514044, 0.028596105876204092, 0.05564293394854758, 0.03837897224002518, 0.03958398629038129, 0.04547086122329347, 0.05926500423811376, 0.04486828554945532, 0.03608392507885583, 0.03631906714872457, 0.006962102197576314, 0.040602799199405126, 0.06934430479304865, 0.14503211685223505, 0.03940183356462512, 0.06672234158031642, 0.014795405986660626, 0.02516935401217779, 0.01671051806624746, 0.062287192849908024, 0.07063381606712937, 0.020542150450637564, 0.014970854335842887, 0.03303579469502438, 0.03751114185433835, 0.022124233037175145, 0.05707409523893148, 0.02403220751148183, 0.03707719697558787, 0.02463664968672674, 0.015284331020666286, 0.061302173635340296, 0.0182439417403657, 0.008116419212456094, 0.04960647172993049, 0.04324383189668879, 0.036192197003401816, 0.02609715549624525, 0.04704687118646689, 0.04620393243385479, 0.03303571305877995, 0.040608651033835486, 0.046674146069562994, 0.04072223302500788, 0.09662315234891139, 0.02140473199688131, 0.04319464605941903, 0.06707777094561607, 0.04133804119192064, 0.024105715383484494, 0.11091155087342486, 0.04557516636850778, 0.026669527615013067, 0.021456370632222388, 0.021135619972483255, 0.016839996860653628, 0.02486943543772213, 0.019460242001514416, 0.02920521430496592, 0.044785788413719274, 0.02660668069438543, 0.042644599598133937, 0.0739202018303331, 0.03247201479098294, 0.030475370367639698, 0.06553064537001774, 0.035144677822245285, 0.04495230037719011, 0.024780229286989197, 0.070152882108232, 0.036357146746013314, 0.10327950454666279, 0.03232767448935192, 0.055133438436314464, 0.04556300256808754, 0.021264065326249693, 0.042596033454174176, 0.05328608072886709, 0.07866680767619982, 0.01866406968474621, 0.009689996786619304, 0.03894466317433398, 0.02539334716857411, 0.03563963466149289, 0.06507855869131163, 0.03811808506725356, 0.045008614542894065, 0.03463689667114522, 0.008880816476448672, 0.02914071981649613, 0.03227663328289054, 0.05338392918929458, 0.054655384010402486, 0.07251749077113345, 0.012988449871045304, 0.10210435080807656, 0.06464516671258025, 0.03583154291845858, 0.07930089122965, 0.04311118784244172, 0.09529258546535857, 0.032663518577464856, 0.015836576094443444, 0.05872234956768807, 0.04301125765778124, 0.03676781045214739, 0.08895056249457411, 0.03660294234578032, 0.030044588893360924, 0.036680834455182776, 0.016793996692285873, 0.013128628579579527, 0.02242092326923739, 0.025857740511128213, 0.024500380241079256, 0.028581405786098912, 0.043127600438310765, 0.055557468222104944, 0.039159641091828234, 0.01873859429906588, 0.07327855579205789, 0.05280628596665338, 0.07181742286775261, 0.015580097278871108, 0.024757998253335245, 0.07763725589029491, 0.028951190142834093, 0.0467829003900988, 0.006893961908644997, 0.02578756117145531, 0.002528738564251398, 0.019492660867399536, 0.03414187303860672, 0.09126548437052406, 0.010880891477427213, 0.02047042187768966, 0.034320225968258455, 0.087836643360788, 0.035796628581010737, 0.05807307796203531, 0.05665071483235806, 0.021334916309569962, 0.041000660858117044, 0.02863633770175511, 0.06979344514547847, 0.026291664980817586, 0.02122835132468026, 0.0242433745006565, 0.05997154366923496, 0.04548593053186778, 0.05452185680042021, 0.014802860860072542, 0.05372470484871883, 0.024502502783434466, 0.022188794318935834, 0.06500041054096073, 0.02993962880282197, 0.06764249337720685, 0.07403860407066531, 0.058515308919595554, 0.03969518969825003, 0.0682839761429932, 0.01980586017452879, 0.0397740094922483, 0.04937468045682181, 0.059118326171301305, 0.10133264338946901, 0.12657816958380863, 0.019485937009449117, 0.05061569238023367, 0.05518087280506734, 0.05383387477195356, 0.04780420691531617, 0.0619026564527303, 0.036273410223657265, 0.061311995959840715, 0.058251664668205194, 0.09722693401272409, 0.0380439556465717, 0.018221927784907166, 0.003299313048046315, 0.030646882551081944, 0.04679872297856491, 0.01479079724958865, 0.04115259704121854, 0.038189999177120626, 0.060810137147200294, 0.017249744014407042, 0.022043934513931163, 0.05614535308268387, 0.048693132848711684, 0.040979235054692253, 0.04396873577206861, 0.021013449477322865, 0.018441874381096568, 0.06501882322481833, 0.05560128833167255, 0.048773667003843, 0.007152882390073501, 0.030605433603341226, 0.13942165853222832, 0.05863381134986412, 0.055437949049519375, 0.022380040209100116, 0.013273521781229647, 0.019625453351181932, 0.009047876701515634, 0.0064507234856137075, 0.025617588944442105, 0.0054014417037251405, 0.04077700723428279, 0.06912430995726027, 0.02897760503401514, 0.022578835596505087, 0.021710992223233916, 0.037145014430279844, 0.007399522182822693, 0.026762040033645462, 0.05553607210458722, 0.022812161259935237, 0.032115078865899704, 0.06922620683326386, 0.08461088364128955, 0.09541235325741582, 0.026328659187129233, 0.020830780958931427, 0.024902572331484407, 0.017589579001651146, 0.05057134163507726, 0.005116591974001494, 0.04125120249227621, 0.017907194087456446, 0.04532076927716844, 0.005348415252228733, 0.044244937162147835, 0.017133254659711383, 0.04366048102383502, 0.05042292694270145, 0.013264936987980036, 0.02646226617798675, 0.01841310873714974, 0.03156025668431539, 0.018046550867438782, 0.07075196597725153, 0.03754495039174799, 0.032313688716385514, 0.015844274021219462, 0.04960075348208193, 0.04308994386519771, 0.024480744868924376, 0.03166337810398545, 0.023756085902277846, 0.024426898344245274, 0.04212612780975178, 0.058416458559804596, 0.0530720416281838, 0.09053886984474957, 0.040609122297610156, 0.10248234146274626, 0.05871648660104256, 0.04221498515107669, 0.07240321487188339, 0.052487878638203256, 0.010929154268524144, 0.025373773023602553, 0.056766920315567404, 0.05288807806209661, 0.039319429197348654, 0.010446293508721283, 0.03474253026070073, 0.025039162756002042, 0.10648102572304197, 0.06100532569689676, 0.031289272592402995, 0.05473453406011686, 0.031308817051467486, 0.04522439026914071, 0.05006965722714085, 0.0216951937545673, 0.006706434642183012, 0.023902083048596978, 0.03204909822670743, 0.04183267890766729, 0.09438874607440084, 0.012610980575118447, 0.02305761732714018, 0.05028372230299283, 0.008301450543513056, 0.01857778574049007, 0.03377902219654061, 0.0655805399583187, 0.09167281212285161, 0.02769187129160855, 0.019685648949234746, 0.08314713835716248, 0.018939413894258905, 0.03131329962343443, 0.036470873455982655, 0.07808265581843443, 0.06151351502921898, 0.0028991852877879865, 0.03905695011781063, 0.048033345010480843, 0.0130025488215324, 0.04862222805968486, 0.0499513514660066, 0.07386227720417082, 0.004631247338693356, 0.046451527741737664, 0.049698472066666, 0.04115837095014285, 0.05159881169674918, 0.013698057155124843, 0.039775968762114644, 0.15902940795058385, 0.1289535764954053, 0.14410946401767433, 0.12579889968037605, 0.275054564117454, 0.10077324215671979, 0.17999883508309722, 0.08987225795863196, 0.10357731356634758, 0.14227068924810737, 0.1769535063067451, 0.1481566476286389, 0.1398125773994252, 0.0700797360332217, 0.1128003241319675, 0.1643969613360241, 0.13113474851706997, 0.2069300235598348, 0.11991715669864789, 0.15278922248398885, 0.14529675187077373, 0.144274948106613, 0.1454918328090571, 0.16117823717650026, 0.09096558249439113, 0.20788668160093948, 0.09178560372674838, 0.12646211253013462, 0.16986287897452712, 0.17275488004088402, 0.10622078421874903, 0.07514829296269454, 0.133062120876275, 0.17916011915076524, 0.10627574025420472, 0.11121067349449731, 0.11961898402660154, 0.146454235073179, 0.13145400560460985, 0.15797917993040755, 0.12850490369601175, 0.09324508166173473, 0.1190589668112807, 0.11955973837757483, 0.155679086165037, 0.08683331165229902, 0.10826048062881455, 0.12296238157432526, 0.14098258805461228, 0.07396507207886316, 0.15073210786795244, 0.2484209174872376, 0.13165162468794733, 0.14871273888275027, 0.11852813826408237, 0.09844138447078876, 0.09470863398746587, 0.10786956176161766, 0.15229239914333448, 0.10410652423161082, 0.1559206997626461, 0.1493727753404528, 0.21326655463781208, 0.12848988262703642, 0.17101380159147084, 0.11525685520609841, 0.09099366536247544, 0.09922424636897631, 0.12023682938888669, 0.06907934322953224, 0.1401281385915354, 0.08103414002107456, 0.1429153187200427, 0.09328515763627365, 0.15403622353915125, 0.11233134617214091, 0.16053378582000732, 0.1339136462775059, 0.11831848896690644, 0.1426041213562712, 0.16500562633154914, 0.1376915638684295, 0.20938000146998093, 0.12979632971109822, 0.1255924193537794, 0.21942440624115989, 0.16548785904888064, 0.16948255797615275, 0.15827121504116803, 0.2556806505890563, 0.09524823472020216, 0.1010665314970538, 0.1601446481072344, 0.07947218633489683, 0.1184340265172068, 0.13427976256934926, 0.1285326897050254, 0.10742251426563598, 0.10812120919581503, 0.15839316474739462, 0.1203035113576334, 0.11254270240897313, 0.17393137706676498, 0.1277758475043811, 0.12890867656096816, 0.14275868103140965, 0.156234776659403, 0.11155966101796366, 0.12426095447153784, 0.21362268162192777, 0.17239573993720114, 0.1183536445023492, 0.13052964583039284, 0.09640493124607019, 0.08632603887235746, 0.13024077226873487, 0.16836476483149454, 0.13990384672069922, 0.1037604310840834, 0.13650656183017418, 0.11701951530994847, 0.17094877461204305, 0.12336190935457125, 0.11521064909175038, 0.09847538225585595, 0.10715268421336077, 0.07936743219033815, 0.1317727580317296, 0.19999812677269801, 0.1697567815426737, 0.09704323019832373, 0.30053492810111493, 0.12800986150978133, 0.2244877681368962, 0.14822296594502404, 0.10690618728403933, 0.28533936536405236, 0.10980431849020533, 0.2057742324541323, 0.25571514561306685, 0.13226636045146734, 0.14996472717029974, 0.11113296321127564, 0.12593665713211522, 0.14917233609594405, 0.15937523392494768, 0.1128995195904281, 0.07847363405744545, 0.09146164142293856, 0.13785223884042352, 0.1325667224591598, 0.1459350434015505, 0.11009908470441587, 0.16799533856101334, 0.12993509648367763, 0.17457228095736355, 0.1709248626139015, 0.07908467392553575, 0.16337012581061572, 0.16115831793285906, 0.21398213342763484, 0.10165611587581225, 0.19160900817951187, 0.16795355564681813, 0.1022950308106374, 0.07289249057066627, 0.14743164356332272, 0.20266298612114042, 0.1663043550797738, 0.09215631391271017, 0.15441038471180946, 0.22852972702821717, 0.12611397105501965, 0.1721223772619851, 0.14660879474831745, 0.18000128417043015], [0.037606674814014696, 0.04683398612542078, 0.013627526222990127, 0.06214687498868443, 0.026468400028534234, 0.05361682255170308, 0.013323905259312596, 0.00761418932597735, 0.04397322205477394, 0.09588941320544109, 0.048128146954695694, 0.035468031564960256, 0.0393201268161647, 0.020892446009384003, 0.03417882828216534, 0.02358910638577072, 0.013730471382586984, 0.04542684444459155, 0.024596846451458987, 0.015272662603820208, 0.0191336228090222, 0.06031715813151095, 0.055609682021895424, 0.04304525915358681, 0.024027580220717937, 0.027663222535920795, 0.05487762013217434, 0.010090068190038437, 0.03962212897022255, 0.017725087745930068, 0.03936140135920141, 0.016765806212788448, 0.08736270785448141, 0.06816172215621918, 0.04222081472107675, 0.03455537174886558, 0.05855662799149286, 0.021852029967703857, 0.044444708473747596, 0.008355855534318835, 0.05458345876832027, 0.02056723133136984, 0.05585458333371207, 0.031072589590621646, 0.011054522492486285, 0.07745237948256545, 0.0075891256074100966, 0.03758208375074901, 0.03260017627326306, 0.02305143338162452, 0.04803499628906138, 0.08329648073413409, 0.021075621043564752, 0.07491545897210017, 0.02757244303211337, 0.05313261201081332, 0.0224119135964429, 0.02475792403856758, 0.02395448238530662, 0.04199945062282495, 0.053220270783640444, 0.03704066104546655, 0.021694015595130622, 0.0434963328007143, 0.0591061549494043, 0.005332260552677326, 0.03959275105444249, 0.01557162009703461, 0.05155416038178373, 0.010085180219903123, 0.012908176395285409, 0.016375039485865273, 0.048771169676911086, 0.026254537187924143, 0.04517639186815359, 0.024552339855290484, 0.09332770496257581, 0.021884803209104575, 0.05100869297166355, 0.047904096281854436, 0.02908142592787044, 0.07004259154200554, 0.016491486167069525, 0.05691308258974459, 0.050040052956319414, 0.02367973189393524, 0.05434624610643368, 0.11873496740008704, 0.01924344582221238, 0.024152860314643476, 0.04973200600943528, 0.03508103123749606, 0.07569189387140796, 0.07617565541295335, 0.06945581990294158, 0.013239301351859467, 0.03334214954520576, 0.05904686106077861, 0.08479310316033661, 0.02313021421286976, 0.01848096144385636, 0.020285011123633012, 0.06393536925315857, 0.03703559959831182, 0.06928600167157128, 0.026481242894078605, 0.03564838087186217, 0.020948069977748673, 0.026244718574162107, 0.03475106866972055, 0.014606733493565116, 0.018809068642440252, 0.06967634166358039, 0.03931074978027027, 0.009576118864060845, 0.045993463063496165, 0.060684491545544006, 0.02807685854349984, 0.09526513342279941, 0.05533327654120512, 0.0725812189921271, 0.025114251402555965, 0.023396019969368353, 0.014869486240058905, 0.09204905873048119, 0.021970857087580953, 0.0696264322323259, 0.020739546889672056, 0.0380261403915938, 0.04711238056188449, 0.024502482374373358, 0.05979327608656604, 0.0157015812874306, 0.014087742201809306, 0.03256571835663635, 0.020556024901452474, 0.10405398017610423, 0.051866819776478224, 0.04329751885961741, 0.10465948362252675, 0.038466081823571585, 0.023114395335142035, 0.029296648754097987, 0.03432097924815025, 0.08516339774359949, 0.03022554676135769, 0.03001206241606269, 0.0329295117262518, 0.01486118995671859, 0.04693072507507168, 0.020853893292951398, 0.020147984687355347, 0.015182111310423352, 0.04264554212568328, 0.047508743082289584, 0.016734899472794496, 0.06224766606464982, 0.009865533265838167, 0.014468094741459936, 0.020687047363026068, 0.03983061309554614, 0.07931770829600282, 0.0075618539995048195, 0.04457583483599592, 0.014446126242546597, 0.018590493164083455, 0.05656015797285363, 0.12935875944094732, 0.07214404206024483, 0.020429403375601396, 0.049903516337508336, 0.03340459385071881, 0.0305615077377297, 0.04170659543888178, 0.007909412888693623, 0.030056134855840355, 0.03332031556055881, 0.06815657907282002, 0.028661477954301517, 0.09218969571520574, 0.04393622228235472, 0.03217692945327144, 0.022708718861395027, 0.09829881790210493, 0.024198177707148716, 0.025117867517110426, 0.09183212896459736, 0.041889516287483275, 0.058068925645784475, 0.04701212754298467, 0.07758509033010341, 0.029470537665474694, 0.0856748859223444, 0.07326453662244603, 0.004271671223250451, 0.027002195311069954, 0.06710334535455331, 0.03976639134634752, 0.07116396925994195, 0.06849667566712014, 0.02326006408111425, 0.05761969994637184, 0.09191067787469365, 0.024316299786732998, 0.024809974565869197, 0.026451532867213245, 0.0160244192375103, 0.021254085295367986, 0.04789908307429869, 0.032446993282064795, 0.08247240737546235, 0.05462746070406865, 0.0937653197615873, 0.05236767297901679, 0.03745981492102146, 0.04111757509235758, 0.007244140579132363, 0.00262599910456629, 0.05050013256550301, 0.02534844166802941, 0.0307210119717638, 0.010037061219918542, 0.053042396539240144, 0.05671248378348537, 0.041488300121272914, 0.04494293447351083, 0.03083601146499859, 0.01828825166739989, 0.06130807370936964, 0.04920387887977995, 0.02174053526687203, 0.04535195061180275, 0.054160857616807334, 0.08770183223532513, 0.006679412581434008, 0.0054521174024557695, 0.05270889392704703, 0.02077771925542038, 0.02102811060467502, 0.05421073736215476, 0.006800273185945116, 0.04109229012101423, 0.028795509824703913, 0.07102728792233393, 0.02732882563577732, 0.009015052437462145, 0.04284400354663376, 0.05951390201516915, 0.036458950853557326, 0.036485838863882236, 0.05698133791156579, 0.06878885178593919, 0.09091147992876358, 0.0032735537979533547, 0.11381287331460044, 0.1016291239648126, 0.03738281338883098, 0.02217279175965814, 0.014303789739642525, 0.010903154052357422, 0.040128262553480454, 0.020934522071911488, 0.026604365193634294, 0.026159271401411388, 0.03418643900658935, 0.02307189439306967, 0.023639744977117516, 0.004541955377135309, 0.09108936530537903, 0.024458101943309885, 0.04047032583912369, 0.012691074080066755, 0.07355226727668196, 0.0791809824295342, 0.05901727534364909, 0.037073556741233915, 0.01599633636942599, 0.03525387743138708, 0.051621480597532354, 0.05558489800023381, 0.036147820283076726, 0.03534844930982217, 0.029006370677961968, 0.026946467442030553, 0.013556836656789528, 0.07840882972232066, 0.033968540737987496, 0.0751969926932361, 0.03830623805697542, 0.019312571312184446, 0.07200539403129369, 0.0011004358179889095, 0.036250982520869, 0.03692536840389948, 0.018741655658232048, 0.06762290810002014, 0.023435552320734132, 0.06332395831122994, 0.028281951053941157, 0.06372343414113857, 0.03164729576383252, 0.07592405992909335, 0.05779738123237621, 0.0350914695445681, 0.019752952466660645, 0.11998749745544046, 0.05323721401509829, 0.036768222344107926, 0.009386005676788045, 0.009154655981546966, 0.015853456243348774, 0.01445403568141046, 0.038896928235772066, 0.08005915835383348, 0.05073258806078229, 0.04124009625229519, 0.046569707337766886, 0.06366627392708324, 0.02953127503133146, 0.03569843502191361, 0.06717903699609451, 0.022756938051315956, 0.015988495579222217, 0.017602440420887433, 0.0436779697338352, 0.042461905104573816, 0.011537171740201302, 0.042985152613255195, 0.04256859996530693, 0.06630415620747954, 0.009209052623191383, 0.02193307434936287, 0.09041096069267951, 0.048492812347831205, 0.002411315495010058, 0.03440874192165211, 0.011942927067138953, 0.023081815052137244, 0.0089890355229727, 0.020976230771339033, 0.06211108120623976, 0.034629898218554445, 0.04502063733525574, 0.009000341215141816, 0.05962937277217861, 0.014794640646869084, 0.03342958567372989, 0.005893723100598436, 0.04770419138367288, 0.05224037238804158, 0.015784772331244312, 0.018197757890447974, 0.08716447278857231, 0.10106354064191692, 0.18986282375408337, 0.13882204773835838, 0.09505561029072851, 0.15596723242197186, 0.11588574372581206, 0.18226812971988693, 0.11534691482665949, 0.2147187149967067, 0.2335802052402869, 0.09463528753258288, 0.15540027612587437, 0.0850960033130832, 0.12745620450004935, 0.1393380481749773, 0.2208916173549369, 0.1686732904636301, 0.1540086601744406, 0.11438768153311685, 0.1326901713036932, 0.12728223024168983, 0.1973212297889404, 0.22504302818560973, 0.23290541488677263, 0.15199736575596035, 0.19708058098331094, 0.08687930254382081, 0.1284947362728417, 0.1788995659444481, 0.06478338429587893, 0.10716599834267981, 0.1929688305244781, 0.27837226109113544, 0.1546286651864648, 0.13019658479606733, 0.2126347494777292, 0.16467167472001165, 0.15380320401163772, 0.13396941125392914, 0.12186052234028466, 0.07626071295817383, 0.08518033355358057, 0.09756471510627307, 0.16928484983509406, 0.16195913980482146, 0.2766880311537534, 0.17524083727039397, 0.19556244369596243, 0.22947304125409573, 0.1254262970178388, 0.16810977773275226, 0.1809425649116747, 0.17714793415507302, 0.17568762501468882, 0.08501051532221027, 0.17628014087677002, 0.12025719392113388, 0.09013742732349783, 0.14316399756353348, 0.20319048984674737, 0.14426728914259002, 0.09348962674266659, 0.17907606350490823, 0.1451905505382456, 0.12776195449987426, 0.15000665851403028, 0.2329772399389185, 0.13292639690916985, 0.11777067265938967, 0.1846839243080467, 0.10236931979306974, 0.15373669273685664, 0.15162091876845807, 0.12626820418518037, 0.1290930705727078, 0.20806536107556894, 0.08347268143552355, 0.18520923127653077, 0.16120553336804733, 0.11481987865408882, 0.1899417140521109, 0.07042998520773835, 0.1112854151870124, 0.10148899164050817, 0.08877518557710573, 0.141904795600567, 0.13008428300963715, 0.12967117392690852, 0.2013241220265627, 0.13199964741943404, 0.11898706754436716, 0.12913987040519714, 0.1851769330096431, 0.18214457697467878, 0.06606951137655415, 0.30738207162357867, 0.2548212435794994, 0.22532661765580997, 0.17609121976420283, 0.11219318796065636, 0.09306712207035162, 0.17653132817940786, 0.1023472408996895, 0.1352029645931907, 0.16826539125759155, 0.07357126625720412, 0.13722662319196388, 0.09069284322322346, 0.1660603072377853, 0.1295493429643102, 0.1458556781290099, 0.14851039974018931, 0.10799807947478257, 0.1125993431196548, 0.1804896173416637, 0.19015971251064911, 0.1548477471806109, 0.1639864794560708, 0.18417083309032023, 0.08663020809763111, 0.19498716050293297, 0.13602137536508963, 0.10791303677251562, 0.12200130033306777, 0.1668915868503973, 0.15725270641269162, 0.11369404805009253, 0.15441224008100107, 0.15019727172330022, 0.12852593616116792, 0.17816947074607015, 0.133119132660795, 0.11648269020952284, 0.17326507688267156, 0.11681972173391841, 0.15781035617692396, 0.10111216615769081, 0.2251162039465271, 0.27620180568192154, 0.1913448778213933, 0.12023684423184022, 0.09787359696929343, 0.1553721190430224, 0.16463409236166626, 0.125999427982606, 0.08872505350154825, 0.16989060561172664, 0.10018962464528158, 0.1531668272218667, 0.12981141015188769, 0.12152612544014119, 0.12993613549042493, 0.20039375085616484, 0.11570862276130356, 0.048431176983285695, 0.17840741813415661, 0.06610169832129031, 0.056239379482576624, 0.08172894609742798, 0.1214983023237437, 0.1911670295521617, 0.15822101617231965, 0.15595862350892276, 0.11546366949914955, 0.16235816292464733, 0.13550243602367118, 0.2619251701980829, 0.19189292419468984, 0.1217464468209073, 0.12118700848077424, 0.13913606526330113, 0.1172528465394862, 0.18515459436457604, 0.1161915976263117, 0.04640075741917826], [0.049991349515039474, 0.06264630326768383, 0.050469478155719116, 0.06405542648280971, 0.03798182304308284, 0.005308907020662446, 0.037684021444874816, 0.011940942749788519, 0.047770335295354016, 0.045302738799364306, 0.05662318115355447, 0.018495615149731748, 0.05905977071961388, 0.061215346067911014, 0.006344030480249785, 0.0353119690407766, 0.04994265720597468, 0.03403986484045163, 0.021482247466337867, 0.008080592033365974, 0.03583931320463307, 0.04308705319999717, 0.04022231492854189, 0.024554889132559765, 0.016687376046320423, 0.04644803593691904, 0.029797481547575444, 0.07851214410038665, 0.02769918144622352, 0.01761438343237387, 0.053018562466604635, 0.021696323674404994, 0.030086280894465744, 0.028146509102953132, 0.04893159231869504, 0.024363127449760213, 0.027568982768571004, 0.050620909678400494, 0.06767594939447008, 0.03785152788623236, 0.030638700372946914, 0.055692412934149615, 0.03457241145952139, 0.026859743775276, 0.063946828013286, 0.0630071280465927, 0.008197599036066094, 0.033252141874982044, 0.028784518617612775, 0.0199006046022987, 0.04252713617461268, 0.033813294576248154, 0.01532617516204482, 0.044055359248886816, 0.05352296313503757, 0.03503184168948792, 0.04871317825745791, 0.03763224922295194, 0.09738227294292301, 0.09360485259094276, 0.0781781850673724, 0.053866607195232064, 0.019400254204811063, 0.02192704068875173, 0.07080216484609991, 0.051719792900257744, 0.04335941768658813, 0.043879147415282205, 0.012171553080406738, 0.04887987575784791, 0.04694781302532647, 0.04782122436154168, 0.006379091855706065, 0.04518378365901299, 0.008213742603402352, 0.037499846366699785, 0.019205590724595822, 0.004472790924410219, 0.026951855434163008, 0.056981378729688004, 0.004765389603562653, 0.035950023084296845, 0.08751797256991267, 0.05607595114270225, 0.05438901607703883, 0.04225340984703507, 0.06337976781651378, 0.01154583909737994, 0.03056518322409829, 0.030395659996429458, 0.06697583696222864, 0.03989739896496758, 0.08579998233471997, 0.06003766902722418, 0.03199940030754078, 0.03204477521649096, 0.06454729227698408, 0.04324493769672699, 0.04081279730598908, 0.03165898087900132, 0.019432604422036093, 0.012293615964154014, 0.012855906006734585, 0.041922853561118245, 0.036253888029023074, 0.09381143681821413, 0.09990349703002721, 0.0671358143154066, 0.017414281865058, 0.02454727469739737, 0.022760424290027004, 0.03929197715478949, 0.02066103323159041, 0.030624330538557842, 0.019756668771151453, 0.046857196794007905, 0.023481765856558923, 0.06270548954489641, 0.01391211109876167, 0.02107083233568119, 0.029965336798341013, 0.035927658464061096, 0.04003179448773153, 0.011737005206668982, 0.07010284651187249, 0.01813383300032001, 0.057107143074972555, 0.025842125724011566, 0.023598078951181378, 0.013134427535987925, 0.030844722423353232, 0.06171642933622934, 0.04014560654468369, 0.07284344945219345, 0.06451445966376923, 0.017791931131796446, 0.038009345589671284, 0.044257490590098314, 0.06973002862650901, 0.04255141182511579, 0.010813078661158215, 0.03915028260962572, 0.025199162373610307, 0.030940008618927095, 0.0159435937894159, 0.04420563673193101, 0.0351738219615072, 0.048393950855825096, 0.021802955452585593, 0.018189473667007405, 0.08171477107680403, 0.04657448305806611, 0.03611878375522792, 0.06675374926999211, 0.013347194781090366, 0.0486819301295327, 0.052175393648212776, 0.012133172913308954, 0.043892988469451666, 0.06597978572244756, 0.04435437425854616, 0.050859606635640375, 0.05474518387927674, 0.04495117231272161, 0.0446117807587143, 0.0696719333063811, 0.053892051728325896, 0.008759147858654615, 0.0224882026668638, 0.04133677211939357, 0.0292360041567008, 0.03432966237596702, 0.050920807843795046, 0.011566526463866467, 0.09103791962843388, 0.05282007135974709, 0.05780501422123052, 0.02979241638968233, 0.0076972449278400745, 0.10465957268024795, 0.03383079441846348, 0.05088881385745481, 0.022612759166804608, 0.06479827177827246, 0.03356659726705402, 0.023805765267752577, 0.07921389667899348, 0.09134073072345927, 0.02319626721146051, 0.01672180984314764, 0.029327978518267628, 0.032478126377100125, 0.01943403491168283, 0.06180994365422521, 0.04067396745085716, 0.05116200954944361, 0.016754048738221172, 0.033695990714477375, 0.06727326006512158, 0.02567487161286408, 0.07905763006419875, 0.03224449828849174, 0.0234391665799194, 0.028600874175026547, 0.018468541602487676, 0.07929218583740294, 0.04147865591221489, 0.0489113057119539, 0.041000375131261535, 0.009200077274726937, 0.023840546018618625, 0.08265242271590978, 0.0210632828384405, 0.006147780195533414, 0.050965102927875705, 0.03454449928540271, 0.023223518874146976, 0.021706654370063916, 0.03270504545071162, 0.03965790048823692, 0.015054250397952273, 0.060962065908825025, 0.04366295237559825, 0.0399493381701177, 0.051508147225831635, 0.016302505682688206, 0.058190867930534296, 0.05561724821745884, 0.05740867767599411, 0.03432625591813121, 0.06796235902584158, 0.05708700860850513, 0.07186802249634638, 0.07056948670651764, 0.05821329563332256, 0.03999184467829764, 0.025014894526975695, 0.012340781304374104, 0.01566180773806991, 0.024222364299930632, 0.06465543061494827, 0.06321573091554455, 0.04634144868759904, 0.05821393016958609, 0.041109062658506446, 0.028978172776987776, 0.03571736720914487, 0.01742420809023315, 0.01861386524979025, 0.05534712130611297, 0.03715114085935056, 0.023689515255682636, 0.015431175143021392, 0.03593772940803319, 0.0294030337681761, 0.06986172273172997, 0.014983858618506929, 0.04290688571927603, 0.008361406798940152, 0.006784668139516725, 0.020167052316537593, 0.0591433810768649, 0.045224175046314485, 0.02284243902977323, 0.03237903853005264, 0.026609242959239054, 0.03724288886587601, 0.033963698224397376, 0.05985416559269652, 0.03964558454754297, 0.007271616741491016, 0.036522983355098404, 0.006793412958359113, 0.025601124398235697, 0.02762907817668747, 0.06117336648458149, 0.05764625770098064, 0.01933524206833681, 0.0765853060875088, 0.1035656915337313, 0.0014982007655817142, 0.03723706671735272, 0.09475527054746635, 0.015364067367045209, 0.06966587738133967, 0.04633008640666958, 0.014768891833227826, 0.05306215622113086, 0.02201639155828161, 0.03481724597804714, 0.029674982652068138, 0.043258481891825795, 0.0734741339692846, 0.06600921929930337, 0.08946510832174681, 0.0021943296042081784, 0.04848524244152941, 0.05571301866439171, 0.018683111338759772, 0.02788355133816367, 0.05682324190274812, 0.018205205342383124, 0.021851317505934276, 0.032328335000784136, 0.04985752915672492, 0.06332603632472456, 0.030438262983807363, 0.05642517615342513, 0.004699998044088716, 0.016071543759608176, 0.08377604171982966, 0.04704534978372976, 0.05788808652141597, 0.048282851348631084, 0.04879859203356318, 0.0134616756986361, 0.015039308182167588, 0.03825860701908823, 0.01108971791836666, 0.010919643646047916, 0.026952922271448188, 0.004240716707499814, 0.006717151718476089, 0.03535110990924295, 0.02869036605261499, 0.01708507443254348, 0.039640337563469075, 0.036686122257378884, 0.009549755923217162, 0.05666393619321752, 0.03836879368463997, 0.032040270380093716, 0.062135301195667125, 0.003876587516060681, 0.019048340764129534, 0.058166733288089745, 0.026358102040831, 0.006905119635121082, 0.04791533239767887, 0.03835830713796895, 0.012662675799219869, 0.05614002817310393, 0.04284073438611813, 0.037609209248330444, 0.024123621551552787, 0.00343456018526922, 0.011144173004140612, 0.05035612623032648, 0.03292325542133767, 0.01210803173307795, 0.035410136624705046, 0.02459992450894788, 0.1274792110780254, 0.19753378088353202, 0.14662592351669446, 0.14488540909951553, 0.08257077162852511, 0.07351264401222579, 0.1313428912544623, 0.12632269266759977, 0.14289029350038618, 0.10348399591748603, 0.2747104153968394, 0.11184737682924606, 0.10657687409548089, 0.2108159681665711, 0.11517783132148907, 0.17688579275272787, 0.16491974500240758, 0.1664770528441295, 0.0983692031877581, 0.12419369362760335, 0.06530952989123762, 0.15261725202435628, 0.1308995916042477, 0.22357293753884733, 0.18039429589407519, 0.0960130401654169, 0.1762221346143633, 0.18638271518284455, 0.1393720682244748, 0.28801106731407344, 0.12299813082790934, 0.14641764719272032, 0.11569195412448607, 0.11390046158339828, 0.0944325105228927, 0.12340925837634131, 0.12766253639711067, 0.07997253487701528, 0.14570249884855002, 0.1187738410953898, 0.09970025246730074, 0.08366828187718056, 0.1638783040107228, 0.10766165651148185, 0.1436987446504645, 0.19026491936529055, 0.08911207609344274, 0.16761201928602532, 0.10703170672059059, 0.07326127859414555, 0.1438277299166657, 0.16499216377269477, 0.15183222305495292, 0.10895305284066126, 0.15917543292744085, 0.10896266365307383, 0.12117670747102238, 0.15142963762627915, 0.19955298659624532, 0.1587841726723127, 0.10392008189228363, 0.15401922835735604, 0.09667477614129893, 0.10401791922049597, 0.1841680277721025, 0.11581455692066811, 0.14248760417103767, 0.145650889899116, 0.19119747244985774, 0.1307032787008211, 0.2563774975715205, 0.11546193287358619, 0.1620553369866684, 0.1352437530294992, 0.10113506141351536, 0.1453174726339057, 0.1784480581409298, 0.11803377885371447, 0.15083504375070333, 0.1297956469352357, 0.09329593362053856, 0.1696111127967015, 0.12371052580419928, 0.10106566318427213, 0.15074991941219196, 0.24029364343732595, 0.2372641520923935, 0.1027799204166513, 0.15044149768073112, 0.12042040703818202, 0.25250986916944385, 0.1097297178057488, 0.14970764721510932, 0.14296188106527552, 0.1405996546964161, 0.11314042814774439, 0.10562360024778172, 0.08703525745659135, 0.13284441927680746, 0.20125293522141874, 0.08917780811316334, 0.13618697819765657, 0.1533461597864516, 0.23784452641848475, 0.11652391651296057, 0.1422748452750966, 0.15457024332135916, 0.1290681937825866, 0.11312188187730499, 0.14691408461658284, 0.20197868143441156, 0.10648689611116424, 0.13880545331630856, 0.1246206511859782, 0.12065871065715328, 0.10357387742260471, 0.15717809088528156, 0.132688048761338, 0.10924620859441347, 0.08795240355539136, 0.20009040541481227, 0.11781042951042764, 0.09702776384074241, 0.11920734439627267, 0.2013782097492367, 0.06777892980608158, 0.14120475738309324, 0.07645100704394281, 0.18554395472165197, 0.10896664898609743, 0.1209157015546225, 0.19346617336850613, 0.2129629420232959, 0.09984498610720038, 0.21370785048929974, 0.05738667670811992, 0.14308714075013995, 0.19175583467585966, 0.10401023799204268, 0.08338768326211721, 0.12000777292996645, 0.1471931766718626, 0.13721661904128268, 0.14723614702234045, 0.13773493497865275, 0.1668978060479276, 0.10154153569601476, 0.09889487380860373, 0.11178342596394941, 0.15445485420059413, 0.264249398605898, 0.13276045268867165, 0.12326758238486946, 0.18214907438959926, 0.10616441810270771, 0.09138209803495556, 0.1682757813250646, 0.1278047467349097, 0.24390290054725483, 0.1528048372711055, 0.1683447416871786, 0.12438974677934311, 0.10942733715637587, 0.12155201897257939, 0.09329876120318659, 0.13816895778290927, 0.12128592934459448, 0.1420121843693778, 0.17960727796889842, 0.1307123774313368, 0.10512668042792939, 0.16072367172455415, 0.13243276480352506, 0.11106087840744294, 0.1916069450089708, 0.24011910514673218], [0.02263488815515302, 0.019874534809787292, 0.0660936460189987, 0.06749318810761906, 0.04341688589192927, 0.048036332154879346, 0.04346534071373753, 0.05919775452639442, 0.01717828261462273, 0.06747502775397152, 0.02176475896703778, 0.032861223007785156, 0.020264804297767114, 0.0173894718682277, 0.0160452680211165, 0.029173611801525112, 0.021399138058768585, 0.07052267203107476, 0.029239278883324005, 0.033456800229032524, 0.051827010975102894, 0.021191166015341878, 0.04835448715311941, 0.04558317785267718, 0.03257354059314821, 0.03529555644490756, 0.056388818338746205, 0.03788998968957458, 0.011414662640163442, 0.06304888127488084, 0.012573744243127294, 0.0595208856248064, 0.051094136433675885, 0.04786342287843581, 0.03337074078444857, 0.013914044393459335, 0.041673165396787226, 0.011832390664494596, 0.023770097650412936, 0.03553219394234475, 0.0334408700291533, 0.0112936545338016, 0.036134231559117325, 0.042970142676495016, 0.05349507322534919, 0.0228098902880447, 0.059937189653282985, 0.023145365157688502, 0.05769300558313262, 0.0787943383329548, 0.042857599692069925, 0.03128249678411521, 0.02724028927332256, 0.03663423871330451, 0.02126539377059089, 0.04828072509553749, 0.029838058471796103, 0.007667243144169333, 0.06254710780922323, 0.023346845264313743, 0.061436209216481075, 0.08493378467392176, 0.03517549921525642, 0.012573032709042309, 0.060225517736398615, 0.05384869917179458, 0.054523181534023024, 0.032629606139380485, 0.040274614075315185, 0.02023764911427861, 0.06955755350645632, 0.04504990021814592, 0.07710739213507622, 0.03473858203506097, 0.05412522339611314, 0.07275736032170244, 0.00596814520577027, 0.06690663169138134, 0.03819438526988961, 0.03946160984924063, 0.04966034794051666, 0.06313568286714144, 0.0704740613582544, 0.04406282525451388, 0.05713795333576854, 0.02580211468739435, 0.03477579331956804, 0.028868485205748584, 0.025493088105577044, 0.09756858911714517, 0.015864831511862576, 0.015078502856340492, 0.05497333862876985, 0.0422512353543425, 0.02688535714696627, 0.12839677277952433, 0.018866323480324354, 0.006660486887994921, 0.039811395181459375, 0.015086209132277872, 0.044231040446902625, 0.04967290136846714, 0.03857006784528494, 0.04716578550869599, 0.0724250562780071, 0.0577041415090207, 0.0344889495318057, 0.021222007817414124, 0.06015417508024257, 0.04470379222766496, 0.039227154265972786, 0.037215522170299664, 0.025591743651602883, 0.017095419971155934, 0.033145487832371145, 0.050082618836313486, 0.051540853673941456, 0.04070492985192686, 0.02517341541533824, 0.024622478376841173, 0.05774414697953034, 0.04592560479068197, 0.09881296296953224, 0.03838856078800745, 0.02118483549566008, 0.04471818989259191, 0.0361569227243308, 0.10325271301553585, 0.05003803802537732, 0.06134686205768958, 0.059955747055937536, 0.03936312685254961, 0.057385133040952496, 0.0009710092638215428, 0.008408402372879209, 0.03265853134507779, 0.06938050675671548, 0.05111858648888301, 0.023737873598292936, 0.066597875993466, 0.0411850956879789, 0.035088148433715105, 0.022550557914655656, 0.039390074234688655, 0.032412208820460364, 0.1327390639926307, 0.10320669985958375, 0.02809694291499909, 0.0768356176558882, 0.02627050820592558, 0.024910465072025545, 0.04156046285061166, 0.03432706114836037, 0.030596858086937573, 0.10285607218975201, 0.03473905329883564, 0.029783698009850923, 0.016291904103127308, 0.0029512685159716057, 0.05511490329809021, 0.019399923949094955, 0.0400396798067959, 0.03338760609040037, 0.006558139157277765, 0.00701602525623457, 0.0326663201849442, 0.024945687400759198, 0.06393515403033234, 0.032287732101394795, 0.05458822335640434, 0.026910564192803577, 0.08152769049047492, 0.05065681478299666, 0.03448550225584768, 0.013103364944981877, 0.03662716975668445, 0.01945701180375181, 0.02136332757800119, 0.034048707530018874, 0.05790831746708136, 0.02383386112342123, 0.03519832025631331, 0.09618688083719462, 0.037276689981808886, 0.0407474586245371, 0.008108756537694717, 0.03220214020984713, 0.08517473033862188, 0.01607766462257132, 0.04947577210259624, 0.01898786871606717, 0.041954743646783754, 0.026632689259713516, 0.07767054863506928, 0.02448612172884168, 0.1223486551316455, 0.06062797699996736, 0.01624522115889704, 0.06759012001566589, 0.041512412499287166, 0.040755310546956025, 0.06578663436812349, 0.08402008956181817, 0.05641765448672231, 0.04004464848549105, 0.07232456206111237, 0.018761010869638994, 0.04343233740655705, 0.04683322171331383, 0.06377058278303593, 0.04208530968753621, 0.0386848521156935, 0.02801851831463864, 0.015000621879153186, 0.028254452627152205, 0.012946713341079885, 0.06372297400957905, 0.04131373956624884, 0.014052060669200728, 0.0330456615483854, 0.05632921645883471, 0.007737091764283832, 0.013838720115018077, 0.043324158250470646, 0.014010014292580308, 0.04953444629791193, 0.009597534462955082, 0.023963477215147577, 0.01750876097503351, 0.01652902956266189, 0.033998527214862406, 0.019492829705995973, 0.05037006747443229, 0.09739030298078433, 0.0517437939561205, 0.03815643925918266, 0.031373127858387306, 0.0444184364459943, 0.046669466828461736, 0.009685026252554962, 0.04962777136825025, 0.0463548036350403, 0.025684988941065967, 0.028811404772568494, 0.041965771961258724, 0.021362242187024094, 0.03199305494490545, 0.03764305489312392, 0.06550363861606456, 0.010590584643068723, 0.013306403561728075, 0.025842387331067584, 0.015942959253152367, 0.03507819623337127, 0.06850928475614637, 0.03913090142305009, 0.030501230503432453, 0.036192438201396726, 0.050668477633735165, 0.0626562925754115, 0.11631852714344859, 0.03879794428939931, 0.02815380441461457, 0.026337208728364203, 0.04519950605754275, 0.15559436258627102, 0.02018085626332322, 0.057870152522809803, 0.06403916602721438, 0.020353318395791575, 0.021304529072949663, 0.12270306775462814, 0.04148291212914046, 0.027067457922385074, 0.03381651178642642, 0.023170050844782963, 0.013129098915669601, 0.038272199453786016, 0.031344963354058564, 0.03521345635817852, 0.05810427785036154, 0.08153602480888367, 0.06974861942580901, 0.03875286252878141, 0.04019687410618644, 0.009218521499860799, 0.06229856255231425, 0.06151522196887527, 0.006220902150744223, 0.08083199383690953, 0.09338947391370311, 0.021057145277154632, 0.018168428214266896, 0.02119485263392562, 0.052698630024679005, 0.04480860574403778, 0.01704661077383207, 0.012660447500820737, 0.06363830238115042, 0.04066424160555471, 0.02320431394764455, 0.01924197636981262, 0.01601559139089659, 0.01244739823960117, 0.0171980756931589, 0.010176709292863961, 0.033346877025906, 0.026169216180278454, 0.03947612254705746, 0.06154995448014233, 0.026919395750155672, 0.014272708594944561, 0.04002496672910638, 0.026954009517794475, 0.03255420764617156, 0.013444358610286145, 0.011691224899550434, 0.07038593874312937, 0.013677985771209933, 0.01664974173763767, 0.013488273343682522, 0.020893494292977266, 0.012524873818620108, 0.03637270216131583, 0.08232859399868175, 0.04214854066958651, 0.01469995002480573, 0.004930002596665872, 0.02561589684773935, 0.01275337644983665, 0.008405070129811065, 0.019723027216969058, 0.02215742559201317, 0.03258646509493701, 0.019290820819151122, 0.009442765131097985, 0.04090690905286465, 0.023229977414302994, 0.032041164668044075, 0.013965811049274635, 0.017791298450902104, 0.02861543882318074, 0.040398018390988, 0.01446817359465058, 0.08016024628886953, 0.05595633549091872, 0.03370179059857037, 0.04835902167542372, 0.0141662011264998, 0.043766730595962144, 0.05674303800333291, 0.050477901531849056, 0.1227503945119679, 0.08705179992830381, 0.15925030078506097, 0.14013524836627766, 0.102008777030278, 0.09148663695668802, 0.22365326760336757, 0.18922770861536264, 0.08792964930762537, 0.08830706850858405, 0.11384474113583565, 0.18256663635838777, 0.18552250665379688, 0.16722310421755537, 0.1115060260053724, 0.14911560632754117, 0.13323484832653776, 0.18646504904609174, 0.13750872836681083, 0.15291316114598885, 0.14859075949061662, 0.06574675877345726, 0.13538921397412196, 0.12025126416119747, 0.10658509709173813, 0.15275839366950095, 0.13087131577776745, 0.22154351987410337, 0.18964449875056744, 0.28786257840692997, 0.126963893417269, 0.15332512732129544, 0.13559259212343022, 0.18588200298836455, 0.14423175511183217, 0.09034988936036825, 0.15569793671602383, 0.1717882030061446, 0.08901686596800573, 0.11791285331128165, 0.14809426269493997, 0.0969599538075272, 0.11433039515395649, 0.11277432669885457, 0.13400070019997656, 0.14190328161930665, 0.09974813583539799, 0.1072198485780973, 0.12412908225087449, 0.14523896825267002, 0.22008704021573067, 0.08162984711816534, 0.07138573782867752, 0.11353452340699732, 0.10796709480928257, 0.06999830759014003, 0.10765510334749706, 0.15968844993039966, 0.12639276625122875, 0.12624264461919665, 0.1072136071161367, 0.1477666787104681, 0.11807047063484788, 0.11410966559196822, 0.12775373150361702, 0.1429369003744796, 0.14345410309033468, 0.16107145696878433, 0.11764930182835087, 0.06361165185808204, 0.11432217957917601, 0.14992350828833878, 0.24421880312729627, 0.1146544910443481, 0.15186189411906525, 0.1341952319489792, 0.11488541029393673, 0.09982959396438673, 0.1316662598401308, 0.13281192805152386, 0.1268604231881909, 0.11675643880153075, 0.18317461857805029, 0.16844662372022867, 0.1778513120370917, 0.1005507240188308, 0.16412762110121548, 0.10099987921421416, 0.09049057829543017, 0.2565830131061375, 0.24084078439045697, 0.1256507373182103, 0.13408862985670567, 0.07189797557657585, 0.1693174449610524, 0.22648239391855896, 0.07134406623663381, 0.1159361949248705, 0.12616434803931043, 0.17516411404358223, 0.0991426027030684, 0.07206318507087417, 0.15939788427203894, 0.17661980702541769, 0.15968012303346768, 0.19007659197086468, 0.14042070804862306, 0.18071413185680285, 0.13072665635263547, 0.09486828479566611, 0.1428686673170887, 0.12417928854119964, 0.1902343874098733, 0.20121287408983335, 0.18037128931609914, 0.18301468575373292, 0.12463521212339401, 0.12557900132378563, 0.17128256295109168, 0.07325016864342615, 0.10452558533870615, 0.14509665401419625, 0.21762968535767868, 0.15018268109997734, 0.10288327190210111, 0.08407774701481685, 0.1050508106709458, 0.21217311877990142, 0.10518991883145645, 0.10126349006895907, 0.10207252751570195, 0.12563150085043162, 0.07993514547706582, 0.1015639262914192, 0.168903089070227, 0.11624171485891566, 0.10520027921302244, 0.2005022528464906, 0.16094253107439727, 0.13287104753544554, 0.1318633891060017, 0.10651371732819825, 0.1170197750616353, 0.11801075001130812, 0.11600309211644344, 0.3003284626174718, 0.16878204478416592, 0.10516107897274196, 0.18358502624323592, 0.1692195111536421, 0.09555489014019258, 0.1451023091794923, 0.11670451815007254, 0.15938243275741115, 0.17190256796311587, 0.21700498997233808, 0.15829165378818288, 0.17493449355242774, 0.10397600271971896, 0.14885499374940991, 0.12013026440399699, 0.1249354553874582, 0.166711853526067, 0.08955346842412837, 0.10237272625090554, 0.10594240462523885, 0.1093033465440385, 0.10572664745268412, 0.13084075413644314, 0.0864783424185589, 0.12093963581719436, 0.15283798158634454, 0.1250666077248752, 0.07585440936964005, 0.11163159739226103, 0.08512790082022548], [0.009325224709755275, 0.0021735067957706633, 0.02440573229250731, 0.02070633021503454, 0.041268565037171356, 0.025532895051583182, 0.06897099709021859, 0.05465812995680608, 0.05780463572591543, 0.041964718111557886, 0.04093479896255303, 0.05351294414140284, 0.06639874292886816, 0.06656384852249175, 0.03554726325091906, 0.045240969848237, 0.10629064257955179, 0.013111027619743254, 0.033508694905322045, 0.046504030979122035, 0.03513142677547876, 0.03651484570582397, 0.050208828470204026, 0.010289700348948827, 0.030098400166025385, 0.05013119240175001, 0.05008350570278708, 0.03921116469427943, 0.0638424300996121, 0.035626695316750556, 0.028939074582012836, 0.045295543677639216, 0.05263890569040086, 0.015538503612333443, 0.031423241380252875, 0.004121934116483317, 0.005660784745487035, 0.029817176291544456, 0.03254219227528665, 0.011262022344453726, 0.04909992254397366, 0.08991792230517603, 0.036964331156923436, 0.025805916338867974, 0.019243438400735613, 0.019686726918735076, 0.03595131071051583, 0.08459095697617158, 0.025000253808684647, 0.01482512157963356, 0.04488530299568083, 0.06979865502216853, 0.016802494283183478, 0.028230193674971815, 0.07518368598539382, 0.04507494770223275, 0.03233962306694593, 0.07813962307409383, 0.04826102107472252, 0.05007053667213768, 0.017143076984211802, 0.041850935740512796, 0.03495506651233882, 0.02779699094389798, 0.037465269706444815, 0.03333713633765001, 0.02327399419300491, 0.02138724328688113, 0.0205373840071843, 0.01921681014209753, 0.042640925967134535, 0.01339425065452815, 0.06418980716262013, 0.0428629617090337, 0.059979855723213404, 0.027984611442661844, 0.029830084095010534, 0.05728214520786423, 0.013638475684274454, 0.035449095666990615, 0.007815430089976871, 0.016257407223747578, 0.04682261642301455, 0.04281043620721903, 0.014364891685545444, 0.0652864713629242, 0.05073609470855445, 0.03238466400944162, 0.008356443686352577, 0.009263144984288374, 0.03893408385920338, 0.07454342034179717, 0.03368119228980504, 0.021688566375814844, 0.020739131286973134, 0.03802097504376434, 0.03404421753657516, 0.050129967858083546, 0.01056465771398507, 0.03362178336828947, 0.05497100828506518, 0.049881010709214024, 0.013552146283473121, 0.03270052206062246, 0.03465573237917852, 0.012337296921032248, 0.021883608351345174, 0.02558097694418393, 0.060646345154964365, 0.057549040066078305, 0.009707658045954304, 0.04540781577816233, 0.04212550811644178, 0.0033645411031102412, 0.024613221939944196, 0.026407662662677467, 0.05124928611621726, 0.02347439447476063, 0.03500331353279762, 0.04811312217498198, 0.018059759240713902, 0.02869580413971562, 0.02478288246493321, 0.011412814692448592, 0.004664521993618109, 0.007154564746087999, 0.011604760056798114, 0.08480176402372308, 0.020402942100190558, 0.051681486947927624, 0.05866212057298981, 0.03698719672684092, 0.04083960368006956, 0.03134729740850162, 0.0324586561328033, 0.04297550469345879, 0.029243787430459633, 0.03819802550424356, 0.019286920833110344, 0.028996212531637866, 0.07849575005820952, 0.04818898451048881, 0.10121668281499296, 0.003506768371153157, 0.0444700045773061, 0.05313558431225829, 0.024497667691321112, 0.08748927371925674, 0.008122643976093968, 0.06296653999015689, 0.05925072902755346, 0.03882199729559943, 0.059663515276042745, 0.07845365544199012, 0.044656194586423226, 0.04071364637638908, 0.0399164053669665, 0.05951534920313861, 0.061238367488840595, 0.02236544773040805, 0.02487211830157321, 0.06844554169219919, 0.019349109097674955, 0.05171142147446517, 0.07888487292802893, 0.028824961955251638, 0.03673856612294912, 0.07505539833800867, 0.040263426199089736, 0.03914350309059955, 0.024024708109209314, 0.07940708514070138, 0.04139696029596962, 0.031625179763068445, 0.06244365242309868, 0.0724611098121386, 0.01727024955471279, 0.06400086378562264, 0.022667486991849728, 0.02748391780187376, 0.06165479397168383, 0.04571620040223934, 0.056612401458551176, 0.04866651943302713, 0.013494830218405696, 0.031541554562863894, 0.055600112027605064, 0.03581196506274864, 0.09734215243952349, 0.05396870074036997, 0.02772603420453379, 0.026514856617723126, 0.03613420558394864, 0.024562264225096442, 0.026129247817152645, 0.07452261794242077, 0.054220166348386556, 0.032131754924193956, 0.015105195125215687, 0.03991000434325542, 0.03296279704954941, 0.03993124460976105, 0.05092473751574289, 0.0757024397898931, 0.04885203037702013, 0.03715863284014631, 0.03403503345907666, 0.008925765578169376, 0.0036386417514222558, 0.04624965615221299, 0.05360923409170937, 0.023154111368057784, 0.05575968119956087, 0.053871290147071704, 0.07816761688445695, 0.023248557081387844, 0.06449687818530947, 0.02808617991831852, 0.062235587611212395, 0.03551528039679397, 0.019312606564199086, 0.010249951847072225, 0.033390448516001925, 0.026897747302427888, 0.042118995770579204, 0.05537272911169566, 0.01738117465720279, 0.08946605084929615, 0.057833100800053217, 0.04328201539465226, 0.0506021852925187, 0.04560418805340305, 0.09261213359422982, 0.09505673093372025, 0.05281772988382727, 0.03301456927147228, 0.0715428579133004, 0.12892286642454565, 0.12395763129461557, 0.007210777794171008, 0.023216577938001137, 0.0333666849473957, 0.023100693433661945, 0.0269010201736819, 0.03338677859574091, 0.013590224953077268, 0.02581374970759498, 0.03547816930222325, 0.03870873071718961, 0.030759805886191316, 0.0931963967741467, 0.04881787303020246, 0.048578571222606115, 0.05291892543027643, 0.002621283219923498, 0.026349660111009143, 0.00875084508152213, 0.05475099489558488, 0.03935679262212943, 0.028067791354260407, 0.046879884248482995, 0.0643876934191212, 0.02251399044325808, 0.05412340513430536, 0.018588498642202467, 0.04974425144609995, 0.027680468192556873, 0.04651960865885485, 0.06840217800345272, 0.016174672600755002, 0.015804648901394103, 0.015555688969470793, 0.08030583339859731, 0.0201817023116746, 0.01126914139604196, 0.004658207244574442, 0.019587447968660854, 0.024060767209448386, 0.03585084617952816, 0.013409124221652746, 0.027701942235580646, 0.022835833915451076, 0.031098956242203712, 0.09027753738337196, 0.03363134223036468, 0.08407203989918344, 0.006781744077670737, 0.05371185085095931, 0.05435945262433961, 0.04349598028056789, 0.03317739647172857, 0.022932340943953022, 0.04719571261375677, 0.049769042889238335, 0.032074605842353776, 0.03281683144450653, 0.09025553270475939, 0.08455763454549015, 0.016997729217109736, 0.01793825111235492, 0.01060417429471272, 0.017320301849395037, 0.06018016880261712, 0.045739678243990056, 0.04945180444337893, 0.029508615407394245, 0.02560362914664438, 0.04546460491837934, 0.05476374128193129, 0.02796256223518867, 0.023896533639344852, 0.006687342429358978, 0.0735158723546192, 0.032316353026544675, 0.008804892913758522, 0.014283398304542061, 0.040640196020831354, 0.03437000552366953, 0.05810611095512286, 0.047660248819738626, 0.03734074845851865, 0.02066646204184508, 0.062044710939517245, 0.03523867824696936, 0.06195736757945269, 0.04489647973969113, 0.045045083679724485, 0.010254765602439875, 0.04964552725141402, 0.0661606396897696, 0.040965661173686385, 0.05282702899421565, 0.012126462970627472, 0.03519949284964241, 0.03700848152220715, 0.020762913409271277, 0.017822685731516685, 0.008544549364160048, 0.02625252596772043, 0.03866858794935979, 0.041422853828407824, 0.013212333560659317, 0.08268042394774966, 0.09001250902656466, 0.007453235120919999, 0.018599903596623335, 0.024634274814161472, 0.02280061900819419, 0.027716102413251065, 0.09182990994304419, 0.009237181875505485, 0.06778540133382194, 0.05354444831027649, 0.1062193741381634, 0.18218423734651878, 0.14222663536202163, 0.14463009545579553, 0.12203895690618083, 0.23855016042944044, 0.09678009431809187, 0.16011807922041044, 0.18041816336335614, 0.126143419474829, 0.14992993528721854, 0.1929787901462987, 0.15332333132391796, 0.14422409614780918, 0.12629455042770132, 0.17733164539095014, 0.1466566781164147, 0.1426166042801924, 0.19277784624136984, 0.19728899089386687, 0.15938725671730936, 0.08811545339995064, 0.12004762626020238, 0.24955950560979545, 0.17285903304582462, 0.13534094468923286, 0.15658109245123342, 0.2133484135265462, 0.14584300224669278, 0.10431506772874855, 0.0889721886778716, 0.14692480122903362, 0.08031927369302139, 0.21255366242257878, 0.06687474902719259, 0.18347309553064406, 0.1836998513317667, 0.12932074663694948, 0.06213051063241437, 0.1641465607099235, 0.15823394438484684, 0.15514689206611365, 0.104543545312481, 0.11124205149826594, 0.16003215336240828, 0.15973798086633906, 0.1541735653881915, 0.11846084773424082, 0.12091580545529723, 0.14089672156842425, 0.19128604035358876, 0.1427198518649675, 0.12697463971562684, 0.21640422142809257, 0.0849397070123814, 0.1847806855221279, 0.22329893661662936, 0.08285464311484247, 0.141035414126236, 0.13609141926281154, 0.20577945717377588, 0.30015717493370175, 0.08683061023475602, 0.0755737439612858, 0.14473242277745157, 0.1366688695270568, 0.08374309036298655, 0.1579016403411515, 0.060247830406297, 0.10931549550150521, 0.13788380980258808, 0.18542645790148526, 0.09599264594726264, 0.1876443810760975, 0.13781704619759694, 0.0705583173839841, 0.1754665540647693, 0.06970342263230123, 0.14409321098355576, 0.1352671455242671, 0.1392766577191651, 0.14052526181330904, 0.17209086567163467, 0.10849254278582521, 0.14307446486782283, 0.10246386198559776, 0.17426008911570534, 0.1286108823842369, 0.0890009172144346, 0.10472385751199909, 0.2566743269562721, 0.13142096519004554, 0.09344743564724922, 0.0820517358079087, 0.12184238425106741, 0.11598799683270045, 0.13229160831542686, 0.06812125284341164, 0.137177107098978, 0.1999329068348743, 0.12736389617202803, 0.15712351334514096, 0.13746581738814712, 0.1082746556494385, 0.12232435721671209, 0.10499128300580196, 0.18346565921092406, 0.10617031075526029, 0.23666540218982846, 0.17155696463305503, 0.17093560891225934, 0.09070672138477676, 0.18990238022524863, 0.11721738672349602, 0.08213113818783313, 0.12856132176239043, 0.16854446846991777, 0.0883051537675783, 0.2744709688704461, 0.14661493973108009, 0.1174984899989795, 0.0878649934020359, 0.14282835385529324, 0.07578374206786975, 0.11196471779840067, 0.1344605497433804, 0.1863599757780321, 0.13374664820730686, 0.0978968855633866, 0.09324365673819557, 0.10867514822166413, 0.15634081471944228, 0.12033307109959424, 0.23796009365469217, 0.10316995612811297, 0.12655865109991282, 0.15567420283332467, 0.09652035005274229, 0.16197530378121883, 0.15086619911016896, 0.1511959353229031, 0.1728758352692239, 0.1143112700083293, 0.1703492083470337, 0.1107288860657718, 0.10322142406948842, 0.11912156696780585, 0.16071340040070936, 0.1785522111458704, 0.17967552586924285, 0.09676551853772253, 0.15290857467334718, 0.12686689471593127, 0.15166353288805112, 0.1549834563047625, 0.183055964007508, 0.2372164319967851, 0.1760164409643039, 0.0826774701999966, 0.14744669431820512, 0.07694314001128078, 0.12978697865037248, 0.12272841951926239, 0.08769369087531231, 0.10622136309393682, 0.20911204162985086, 0.29093349643517286, 0.12024370167637244, 0.10121163621079177, 0.11423559320974164, 0.1515851027215831, 0.11561644801986404, 0.11281795013928786, 0.12105950008844957, 0.206310641951859], [0.009715645410324214, 0.02072052378935041, 0.034964484366355464, 0.0228200484343688, 0.03497943493130151, 0.06438160038669594, 0.08762948025832884, 0.02913186042860616, 0.008353750617970945, 0.05930707658990286, 0.03268659937020857, 0.024370207538595423, 0.051044342035311274, 0.11243156579439528, 0.03083144354604883, 0.023075627395883203, 0.07469651798601262, 0.03329567996843252, 0.08545437158318236, 0.04256007639924064, 0.03130685036012437, 0.04431374909472652, 0.03751222167920787, 0.034742407806334086, 0.07394445521640591, 0.056286145918420516, 0.013736345481447643, 0.07168342810473405, 0.04986353684216738, 0.03909452505467925, 0.042949737326125614, 0.014600653448724188, 0.054500460682902485, 0.016150378396559972, 0.04903925939288456, 0.026668264108593576, 0.045268277171999216, 0.0835255000856705, 0.027531276100489777, 0.037320309711503796, 0.013615989537356654, 0.11215396545594558, 0.016817687901493628, 0.034961077908519655, 0.11847437708638608, 0.01911366831336636, 0.0522036509210011, 0.020354743319330737, 0.0625497498549521, 0.08333121324540116, 0.024717432461329736, 0.01260348581126891, 0.004675328591474681, 0.01476066234317841, 0.020126833478570916, 0.03469232397037558, 0.029694671829929575, 0.03068270416406449, 0.0427946841227822, 0.004202815689495765, 0.026434821556904353, 0.046080895481281914, 0.043906792416237295, 0.03815708863839973, 0.09736619060277008, 0.06044903406291269, 0.03479111495835241, 0.054872959444765, 0.021151971341168974, 0.05800748695037328, 0.03822106918960344, 0.04311634576879442, 0.010568710767984157, 0.03161146116326563, 0.019665061772684567, 0.048552900334470905, 0.02167907245166134, 0.042567215859889984, 0.0418910376902204, 0.06678583231405355, 0.027312997481203638, 0.015284584278560942, 0.02782702194963349, 0.03013612724316772, 0.05177625178475864, 0.014298997321020579, 0.020382223192427773, 0.08243111427873373, 0.023232092535181437, 0.035733486656681634, 0.03497236597468145, 0.021786752513435204, 0.022106113501649816, 0.060642730895779096, 0.03618611139245331, 0.015547048515145434, 0.025353612581966445, 0.008740827015571995, 0.019093073715339415, 0.052185353270033374, 0.044276760454522446, 0.01717053644824773, 0.1083108205057215, 0.0651686628407333, 0.004914600249321666, 0.03267274718382396, 0.05550068279262632, 0.07863226812332869, 0.03144071524729952, 0.051352270238567144, 0.03063810851017479, 0.053300396757549606, 0.008117615925584687, 0.016916102249524556, 0.023119534707802814, 0.035157576348865405, 0.04882677138084546, 0.04990623259800486, 0.028520460618892685, 0.02275258349982323, 0.059296359977452084, 0.06653646327322349, 0.041875081515172496, 0.0389651316072559, 0.005219991235207999, 0.010489753676665714, 0.06969387861317955, 0.08418975194217637, 0.016236473093158565, 0.033866736630443484, 0.0610844831680879, 0.04095064381544944, 0.04832924299989827, 0.01114158383643371, 0.051023561900365166, 0.014947064792067977, 0.019653502822620794, 0.01549061096739024, 0.04164278558164369, 0.07593548158183694, 0.011057080118916929, 0.05559049379371572, 0.03937790672353003, 0.02555936745920917, 0.0464441062649712, 0.022726632450940087, 0.057564588059904054, 0.015625999112671707, 0.014892830495227827, 0.06618078899919055, 0.03626388104748912, 0.05865892191650346, 0.03773712582187727, 0.0264538669216563, 0.014631562971771928, 0.02762631182122277, 0.017823179259721655, 0.030479956840281375, 0.043582340294960886, 0.07064019853714854, 0.020336161796876695, 0.037843097088625655, 0.012322543952905107, 0.06181365439260844, 0.021347172878449783, 0.025039971696969587, 0.045316943505895324, 0.03159250300086569, 0.03711165860295296, 0.026494002268009353, 0.062399977032328025, 0.021440414457174484, 0.04321378975873813, 0.061195586386020295, 0.021434219379443675, 0.01940524329256732, 0.01329071084910538, 0.01284954209040734, 0.04791031176864635, 0.03071372408157913, 0.026608888583723456, 0.0472552848077612, 0.03949607889808249, 0.03333880988066085, 0.04524246898654383, 0.012440217960829614, 0.06524143784190528, 0.01302549510000972, 0.029641495093528647, 0.09227552509400994, 0.027248239530308638, 0.007627766453879303, 0.026645669422578067, 0.0452476974169258, 0.02933841125923209, 0.0287531962749199, 0.028993340420129243, 0.017615641372685786, 0.040853118189261295, 0.0740166513423901, 0.049497962318127975, 0.01659959296375746, 0.01157542945293244, 0.12577344401506707, 0.04031454533105716, 0.02920883969636634, 0.022491792806249578, 0.010522786669753259, 0.03005315513291862, 0.09066968821571209, 0.029613167316711042, 0.04603195455274545, 0.06495788547908887, 0.04839744266064372, 0.0218042152482667, 0.06262520400923677, 0.03453193843597546, 0.06150702123704832, 0.08882367008482106, 0.05685021897079423, 0.047365675563924015, 0.030329085639095865, 0.056193006385001354, 0.04053126358485315, 0.004214518894514185, 0.014667115556221688, 0.05819506477564573, 0.003533318936206342, 0.039939359994605184, 0.0038194702074179077, 0.0648512908082921, 0.04035206831758842, 0.035541129400371574, 0.03452452438068576, 0.06658220183453523, 0.04946814653521869, 0.04460359858057927, 0.04017830557131674, 0.0606166369834682, 0.026943810553348158, 0.049099262032541446, 0.024389777972828597, 0.006861060182927758, 0.024903615048970096, 0.05331947366357781, 0.02976414056320209, 0.012569220853038132, 0.08591337507823482, 0.021892994664085563, 0.049005298715201207, 0.026246989546052646, 0.010173912323807599, 0.03796083139604889, 0.03552475762262475, 0.05988146920572035, 0.02389050554484129, 0.026036076742457226, 0.012097030321456259, 0.03669823781820014, 0.0202597836687346, 0.07248226102092303, 0.053459977061720565, 0.025681729057396296, 0.09150300131295808, 0.046686183704878204, 0.0431740922795143, 0.08383453037822619, 0.026429107019794174, 0.07939808288938366, 0.057441421231487766, 0.03629093975177966, 0.03384914401976857, 0.044876196843688376, 0.04927394875267055, 0.05610726606391836, 0.01875565627415199, 0.024790587813185994, 0.046268836958915927, 0.010727279895945685, 0.014762937953491928, 0.06374416974722408, 0.023587484793097246, 0.054729747207602486, 0.05332603424903937, 0.078864849783713, 0.01450221034247079, 0.035678081621881574, 0.06043312241672538, 0.041087028293986805, 0.028777240004274063, 0.022524527084897272, 0.10065046866657212, 0.031389696305268444, 0.021977124524710234, 0.05195700556214433, 0.02071795595838921, 0.010284657455486013, 0.007267401342687663, 0.024904420279199257, 0.07651790423551574, 0.012569633672683267, 0.051779457862721756, 0.012452300125005422, 0.018976285646203905, 0.05923008618992753, 0.03513043971906882, 0.033887869285536, 0.029271415733092, 0.012491897414292907, 0.025860729510895908, 0.03418290267291013, 0.011338502517901361, 0.0410438946710201, 0.01722605466056848, 0.03306254540802911, 0.07431401507346891, 0.040741480625001714, 0.10933479134109803, 0.05443967878818512, 0.05036546986957546, 0.03112884623988066, 0.060669871236314066, 0.07508467606385238, 0.038308497896650806, 0.03236956872569863, 0.016808067812235095, 0.03563702972314786, 0.031325938398367725, 0.036240325280232355, 0.04182429263892118, 0.006816544773755595, 0.03567178449884523, 0.046394586461246945, 0.03626117962994613, 0.049938849988393486, 0.02937857629149221, 0.01218486720972578, 0.04134907321713399, 0.015205154995783232, 0.018146440233977046, 0.07940084367874078, 0.035078266737400554, 0.04586288960126694, 0.028481846675276756, 0.02801119517243933, 0.014746643173566554, 0.04219249436573591, 0.021638567886839155, 0.06392210707417689, 0.07600837532663718, 0.05011814915633295, 0.02488197773345746, 0.09230193812982179, 0.05549640431127045, 0.09218783292453736, 0.0960820895852521, 0.10573764608125202, 0.2648651140043512, 0.2149427100084722, 0.11653372770524584, 0.16622832947177812, 0.13021430728258565, 0.1819069412886165, 0.05703558890672866, 0.1700822132988833, 0.15194133360637352, 0.13295154087245464, 0.06298970241914503, 0.17817343381466344, 0.11237599377636798, 0.1768199642538093, 0.10511159256566316, 0.09364974510390311, 0.10243047276162542, 0.10085299334605224, 0.2908634673804045, 0.1766704660258256, 0.13438373745884746, 0.09269037822377868, 0.2122819918440655, 0.13173870829632506, 0.11267956928350031, 0.14471845555817708, 0.0783873297041282, 0.09237334015779197, 0.14537491486407816, 0.1573733944678679, 0.16194104624446481, 0.21869959513423964, 0.10638796040439047, 0.11931970555451699, 0.124536283838097, 0.0829973655345384, 0.17850524804089218, 0.16824035119498149, 0.19344003492733464, 0.21475059766089544, 0.08235365632572211, 0.13814344274578616, 0.0847652652009856, 0.15062709397170693, 0.1805132324807346, 0.1084826722217258, 0.05596397219051141, 0.14622934948420152, 0.2079398193745874, 0.179107278236188, 0.15346425032475963, 0.0893278035800904, 0.1670329659827985, 0.10087139118695632, 0.10261137867928483, 0.15700307762017474, 0.14579958660760894, 0.19216742977732792, 0.1449451519874856, 0.30795367376413196, 0.14326665143016726, 0.049188312332262285, 0.13026879576500505, 0.08361892905668356, 0.12665372021729127, 0.08520545525243506, 0.18548707652371377, 0.17992831621086225, 0.09263870248105377, 0.08348939460120164, 0.1643326022895053, 0.11756270061596297, 0.1735149580053985, 0.0961754443414975, 0.2163090484100394, 0.11773110134527087, 0.11623704675002955, 0.07936429290566593, 0.06739048971212469, 0.1978326734388247, 0.23370380251435563, 0.16592939238762483, 0.20079676673049107, 0.16304917662637308, 0.12133259559050202, 0.19390533183468506, 0.09176137260510586, 0.1580962908337824, 0.18661512614926323, 0.17600894527276978, 0.18615587032400072, 0.16254429356195033, 0.12864749995060265, 0.19234009785577655, 0.12593483144883066, 0.11443402865552343, 0.14089866599533707, 0.1918605962418951, 0.14714183489559218, 0.14693323202664033, 0.1446928663062863, 0.22582642443012446, 0.14785677543841302, 0.11508109237183817, 0.11486886782222427, 0.15672465349780396, 0.1727067443425767, 0.17604458320420235, 0.12054248290951364, 0.14608099416363984, 0.14932668796973303, 0.21277173509588465, 0.10993593838065863, 0.13653673755470663, 0.07077746617142111, 0.14232206071028486, 0.12543405988253653, 0.10194008384132758, 0.175730075861793, 0.08314118633279577, 0.13654543552547693, 0.1535786598105915, 0.13425258512143046, 0.11275263372226618, 0.2575212955707684, 0.12979922408703715, 0.17083102546166629, 0.06009242468280718, 0.11437482011388056, 0.23570507793920115, 0.04917771817417815, 0.14423702436033636, 0.07443642491125502, 0.10776282608276233, 0.18263507721712813, 0.1869438827270642, 0.23279762535821646, 0.09692504318081774, 0.1265227608382702, 0.13806446339003742, 0.12091593904187903, 0.10421117447549477, 0.1392834706348367, 0.10601705726003274, 0.19953750539571047, 0.12934768659761176, 0.14345349452923983, 0.11020481106243096, 0.07160530221881345, 0.08815695429802872, 0.09448751108720899, 0.16927538003074005, 0.11080395430326462, 0.1625519376830198, 0.11584736726945266, 0.07318052550544962, 0.1873462158255279, 0.11064590653404593, 0.11892952141351998, 0.23143441881984472, 0.09954941837349907, 0.13871767208911479, 0.11191441502887756, 0.1436696227756329, 0.14811991131864488, 0.17105697974329814, 0.11955475856666453, 0.15196772437775508, 0.20571260451106355, 0.12369442119961604, 0.12240781172295101], [0.018205370470241178, 0.03507943190925289, 0.004417392847244628, 0.03591973232687451, 0.0187682022806257, 0.0166290191191365, 0.021438134208437987, 0.02388738481386099, 0.034548031908343546, 0.07619034993695095, 0.006054890209270525, 0.028033524540660437, 0.050764782426995225, 0.018567896622698754, 0.06981649625231512, 0.06973937968723476, 0.01685907191131264, 0.024810566428641323, 0.0800707061716821, 0.011575765274756122, 0.02639214992086636, 0.02818255336023867, 0.011085991409345297, 0.09459277731366456, 0.040745109727140516, 0.04900549538433552, 0.025246027144021355, 0.02962077433039667, 0.014728162768733455, 0.019356961020093877, 0.011012903778464533, 0.09077356662601233, 0.04814216612430755, 0.027666807109199, 0.06446869141655043, 0.04018742656626273, 0.04208165832096711, 0.04575812061375473, 0.011626498489931691, 0.08588633863837458, 0.04039927262056153, 0.007537238352597342, 0.028008460358250886, 0.017410901382390875, 0.0485228247998748, 0.1258900057291612, 0.03541552090609912, 0.014035437488928437, 0.04496351793932263, 0.03291911423730198, 0.04184186298516579, 0.005816730845253915, 0.034066392909153365, 0.01371854970784625, 0.037411207958939485, 0.02362086102948524, 0.028025457395415287, 0.04489737773837987, 0.02595110454421956, 0.023304424103116617, 0.013052101094217505, 0.01269288584808237, 0.016343746829079464, 0.07284385021193884, 0.025305376693722792, 0.07080131879774854, 0.03024219684448326, 0.04786572353623342, 0.03306787031760905, 0.03219149410142563, 0.02617449099489022, 0.05177307168196421, 0.03336313006002456, 0.05103948096802924, 0.032038615390774794, 0.04559775363304652, 0.005461569580802461, 0.042318581545259804, 0.022032600063539576, 0.013204211682023015, 0.036223615825292654, 0.03402786431252025, 0.023985060724953655, 0.047987821671995334, 0.02304805846506497, 0.02318073034984991, 0.034923599450849, 0.07893242232967168, 0.04881310473138001, 0.04664717271225527, 0.11280885140877217, 0.04033541823446285, 0.005975580597805674, 0.058012099398183636, 0.027772312678280286, 0.07679558621020988, 0.056297630653716624, 0.03212428520782851, 0.023340240149991587, 0.003177874496032018, 0.024089979997370392, 0.02443257391860243, 0.055090750101953745, 0.04308208081056364, 0.014061733636481222, 0.02721864453633316, 0.05990462792397011, 0.05720790817576926, 0.039557940617669374, 0.036682188874692656, 0.02350200793443946, 0.03813630108197685, 0.007427604587064707, 0.01860653097537579, 0.021813677631143946, 0.0586692043725634, 0.026847435256058816, 0.03444611647864804, 0.03277194264228456, 0.04707565909484401, 0.05587899999227375, 0.0684708786138799, 0.030123152646410745, 0.004508614392761956, 0.028329966153251007, 0.08715928517631255, 0.028055015282006934, 0.005902905322727747, 0.036140417360002175, 0.08423322695307434, 0.02124667680618586, 0.010596813117444981, 0.052031131272087805, 0.04539872817986179, 0.08494326932122931, 0.02388615841482533, 0.01119689610277419, 0.03129410768451635, 0.041652748914202675, 0.026670681654650252, 0.09652184919104911, 0.011041557172575267, 0.04370634946099017, 0.02982632697239751, 0.025941391686501447, 0.03208966401871294, 0.10037122076028027, 0.04864391732553486, 0.0491059562045848, 0.03475449368124828, 0.04593399105942808, 0.052025657932972535, 0.07408445395412855, 0.01454109145925031, 0.0827584088256117, 0.05136981089890469, 0.05040292606281582, 0.03712224533956032, 0.01883475993963657, 0.07460302222170867, 0.07103749245288782, 0.017584474881005008, 0.0659214380721096, 0.03132996826025192, 0.031456452488782816, 0.07101162118487991, 0.010269749564031372, 0.032836639365996234, 0.020095563086215407, 0.025882956833811477, 0.06215158020495437, 0.03589023937820457, 0.033023616051650606, 0.06009878488839604, 0.07379917238722555, 0.048634640479576774, 0.02679395238374127, 0.05339849754818715, 0.008186437135009328, 0.03787534711591434, 0.011417145124141825, 0.036354820113047026, 0.10234393834252842, 0.007728367354502552, 0.06185138146975078, 0.037012793400208466, 0.034621189115568995, 0.07190797972725704, 0.055628113259444945, 0.0766957450832706, 0.027714360221580137, 0.05910268169827759, 0.03687829397676978, 0.09544340471620671, 0.1375782082322985, 0.04433464797330089, 0.06286776013439521, 0.008651232164993417, 0.0029942671608296223, 0.022026978294888977, 0.05710682766220998, 0.04801363727892749, 0.03924767835997045, 0.029406080284388736, 0.02581907647254411, 0.06518844107631594, 0.0137222789999214, 0.04147264451603405, 0.06416942778741941, 0.07819498729077168, 0.021063251297164243, 0.025484514444542583, 0.06286614225246012, 0.033089682037825696, 0.00734539039513038, 0.010821354535437422, 0.00960702282100101, 0.06334285339107737, 0.012902277248940663, 0.013825110054312972, 0.10465843719430268, 0.03799875143158715, 0.03047211419470841, 0.04034160032460932, 0.0415662293380592, 0.04012921250250656, 0.01825051902414998, 0.09086329970159568, 0.038091753667686135, 0.03307968901935965, 0.02584313875559019, 0.02846930623491062, 0.02009794166951906, 0.012392093394737458, 0.022740356616850477, 0.046663715183967724, 0.04367213274235837, 0.027566468743316364, 0.02173172040784266, 0.03416215222387109, 0.02667524771823082, 0.038012228833395056, 0.010361889981140848, 0.08115434568026103, 0.029488703585229814, 0.02861319197108969, 0.0685154742677696, 0.05022208693844732, 0.030322955499286763, 0.031478772580157965, 0.05253347619145643, 0.04199009585136082, 0.036231029880582355, 0.05024821795814205, 0.042462580458959565, 0.04362549247161951, 0.07694601954426616, 0.05404889350757003, 0.07448337317327969, 0.057342763830092736, 0.03928332371287979, 0.010886598593060626, 0.015274158031388652, 0.05145674978848547, 0.034867103458964266, 0.024679824127815664, 0.02342678199056536, 0.02800790189212421, 0.04391212103655562, 0.046877991771907546, 0.041126859359792434, 0.0352626162202796, 0.0061959808317624265, 0.029033290229563136, 0.10864397801924497, 0.031233010377036408, 0.033668527539703064, 0.02317102120287018, 0.03187584756233264, 0.03447668183071073, 0.0232102121663047, 0.01944764775544172, 0.01572194025357021, 0.022335453832056373, 0.06563741073478013, 0.030307121778605506, 0.023466852398996707, 0.05211640032939613, 0.03666271863039583, 0.05830838330439292, 0.04383166480693035, 0.006381767761922674, 0.020360641537990887, 0.031834383771638386, 0.04261420122929849, 0.05447585848742165, 0.00012365561673277625, 0.014496572803182062, 0.05063600867288187, 0.02200699040258769, 0.01054243966791546, 0.05916872542002238, 0.05467230126669165, 0.03553167814970948, 0.09473869838984683, 0.023664154214202426, 0.02884743233153131, 0.010661447686288739, 0.06271660691709258, 0.044878133849124424, 0.016363866452593356, 0.05097523324366193, 0.03230757713026833, 0.011352093097229954, 0.019010704600077588, 0.015723723263363354, 0.03132791622192599, 0.014626885586039862, 0.03411699624848552, 0.04167706909356639, 0.0372506368876202, 0.019977949377789628, 0.043477886720211245, 0.02971971745864721, 0.042030531767522916, 0.040358985133934766, 0.01564620037243003, 0.11697454116074368, 0.026475875311007258, 0.021707964260713197, 0.020238292927388102, 0.07259889694978483, 0.06273871549637988, 0.03959782734455075, 0.1045595905452501, 0.05019057905883528, 0.05073840278782882, 0.07582692021969706, 0.0476934079779312, 0.025392113348061685, 0.021259857348923106, 0.10153617738978937, 0.032542711778660305, 0.06417908312869258, 0.062071921784081496, 0.01831061814300483, 0.08479691779939458, 0.03033838474948425, 0.05189836105273571, 0.05377048422815278, 0.06468035193393007, 0.011620570585364476, 0.10742986152763478, 0.14994471886893734, 0.11359917931258678, 0.15018507081549615, 0.14156165620079264, 0.15039572201203555, 0.17634092277148739, 0.1280866886372678, 0.11264776083407924, 0.17434050823794678, 0.08515262175933458, 0.16157267382368445, 0.11753368264180608, 0.17459797410992905, 0.17018750921124592, 0.18259985488839447, 0.1018241306883283, 0.19083612074609846, 0.23524843447376043, 0.12885987292975187, 0.15331635513575748, 0.11369367697625421, 0.07561171223642305, 0.16165748646017164, 0.12535779678728431, 0.09726978561957367, 0.10789129926706664, 0.09453433318412863, 0.11081948745413683, 0.14680145628517494, 0.10968620568746701, 0.18783490522764623, 0.13988958264235407, 0.1425347157055512, 0.17801593523472548, 0.15196235122857615, 0.19854179554386064, 0.13368071580771357, 0.173660522850696, 0.2001955232117325, 0.1513537159189582, 0.08757343326578848, 0.1113823990453966, 0.09242463740520179, 0.20440768625121564, 0.22966708318563178, 0.12517355120508, 0.07834365431335755, 0.19851841789204627, 0.1721033634385094, 0.1121807198796887, 0.17234744096640497, 0.14580297080101445, 0.11468041426269338, 0.1231494992680382, 0.18288093589944765, 0.07280764824827202, 0.12431851544533856, 0.07497059312299825, 0.13812788733048365, 0.12809158681193367, 0.11510951662785374, 0.09678079193690792, 0.15741605311632156, 0.12193798771477304, 0.14204224135028198, 0.1321668829768896, 0.12309509242186323, 0.1452451280783862, 0.12096054953872226, 0.11365325219230726, 0.16999738581944257, 0.12416918048984371, 0.11716514694853686, 0.13760210538748652, 0.09607833431800827, 0.1941104614525102, 0.12567558442242444, 0.13686846272321418, 0.17592668562429026, 0.15168404584983364, 0.12377059523714706, 0.16641088295727968, 0.12098714811145328, 0.1522765468689613, 0.15603824111167341, 0.09970344370231032, 0.2129326030262746, 0.12452374154236168, 0.1091586500115227, 0.32498578482773155, 0.14609712845413014, 0.07564364685094915, 0.1024400167807471, 0.15188810677500442, 0.16561455850023776, 0.10424578082165681, 0.14170104637742043, 0.1747206659638323, 0.12929143180372193, 0.16590608895057812, 0.09758283093106002, 0.1352634050999768, 0.2481280214851722, 0.12833743065129966, 0.09919251955579966, 0.14451000111876056, 0.10813898363267072, 0.17004417080897838, 0.14735607808688655, 0.06451786612160504, 0.1932094051153399, 0.12148628695285879, 0.06413793846149929, 0.11392409156542271, 0.15850635711103678, 0.13643868500366807, 0.14229834167053923, 0.07635016401764005, 0.14369803218869492, 0.1385086090886034, 0.09351834043627605, 0.13371613109484315, 0.0981053251598496, 0.09293106413679197, 0.19311887794174254, 0.18418229185044765, 0.12636447558179498, 0.16757783596403897, 0.12994027667446062, 0.1252020793617703, 0.08061057407758199, 0.19383717299206182, 0.11059889890020713, 0.16473437135573477, 0.15686149068642408, 0.1659012501477264, 0.1255655536078848, 0.2773011935641989, 0.1466504589188844, 0.14959525637095794, 0.13979016453959048, 0.07484229063265957, 0.21176893031224608, 0.22198959515662864, 0.12585384829435498, 0.19189381477190182, 0.1552629194338806, 0.14875486318487674, 0.14162738079903647, 0.10653909877873957, 0.21521728980587795, 0.217746558773797, 0.10845381752005778, 0.10667406575521454, 0.21904320950852707, 0.13646063773194328, 0.09517892554868013, 0.20261238649254665, 0.21565986215136945, 0.2685022016521543, 0.25690694572404027, 0.1670270288013853, 0.1193054934265092, 0.049829932395368814, 0.15040636440971866, 0.15932396636344492, 0.15452403720701113, 0.1830796236754395, 0.09462054847972468, 0.1383465388789773, 0.20043942262418568, 0.20824632636504248, 0.19077185075730085, 0.12901808397145942, 0.08486657578032464], [0.026570410082058515, 0.0036342999555927236, 0.03858114439935889, 0.06369332520989701, 0.0070714980120101245, 0.026829441885638516, 0.009508364491921384, 0.02611041025375016, 0.09267868197639473, 0.038452997760032304, 0.041738897416507825, 0.03934909283998422, 0.04971824659151025, 0.04717767471447587, 0.04515242420893628, 0.07221790801850148, 0.05765995774709154, 0.05572937930992339, 0.03711983335961122, 0.09285132779041305, 0.02742183529335307, 0.06833458319306374, 0.06355842502671294, 0.05256647949863691, 0.06268691358854994, 0.04822925344342366, 0.0030262824839155655, 0.08968522932264023, 0.030953530549595598, 0.03887221100740135, 0.06359205915941857, 0.027025042327295523, 0.03702559173689224, 0.02986998009873787, 0.03589096668292768, 0.053063399318489246, 0.037264489074004814, 0.038141032273415476, 0.05246600754617248, 0.010994765689247288, 0.035168445101589896, 0.08433317198068835, 0.044687131012324244, 0.01700084438198246, 0.05475864643813111, 0.03383425653737504, 0.07357145179412328, 0.027842176605190616, 0.03086122036620509, 0.04677961267589126, 0.08916821956518106, 0.07261513514094986, 0.09287626395234838, 0.04824136529350653, 0.03133602789603174, 0.06445915481890552, 0.029578560970549006, 0.11940470372792333, 0.01849187658081064, 0.104995921428781, 0.015588336973451078, 0.04289325246645603, 0.020537949894787744, 0.024736592858971562, 0.014998864844528725, 0.03732770521310158, 0.08389227688894607, 0.021495637665793765, 0.021201659983489662, 0.025182178324030247, 0.017321606173936743, 0.030759779911022633, 0.031248870072886348, 0.056092118829838, 0.021673721566912718, 0.025129103632934857, 0.0297358536045067, 0.08204566503991373, 0.011209003314434085, 0.011488283689686796, 0.037491949915420264, 0.05061565898358822, 0.03039312556211371, 0.054270060936687514, 0.03704974122229032, 0.030306854605441913, 0.03736489423317835, 0.046733499330002815, 0.06667668465524912, 0.026731233483587857, 0.02008776496950304, 0.014644926268374547, 0.029750177054665983, 0.03797879508056212, 0.04786362696904689, 0.050265977552044205, 0.08742026882828213, 0.03694148785143625, 0.02333891170565039, 0.03189285758708138, 0.01306724276219029, 0.07494449178921059, 0.022467131238954607, 0.04553911283437628, 0.003985254634244484, 0.05850360896147322, 0.019919397636840586, 0.04898222534393426, 0.00974132371993619, 0.03533239294483792, 0.04491646577662323, 0.060866232379339635, 0.025553196501277853, 0.021903002525505144, 0.017242402318515815, 0.05046444639447145, 0.04122042933886405, 0.02049484410235891, 0.06462130666477606, 0.003926650015273481, 0.03161929453199264, 0.044884067319799215, 0.06929720068001188, 0.0941760465502739, 0.041782791740843095, 0.00998073592199944, 0.021363570631365292, 0.03810843343671877, 0.03847970023343805, 0.037803896848345175, 0.030213112077035476, 0.04930054732540157, 0.05704682131181471, 0.025386870074726176, 0.0939239835133776, 0.018348011253692675, 0.0729099681484513, 0.017516822554171085, 0.05733835918363184, 0.0368343143054517, 0.033364328628522344, 0.023756427290209103, 0.018432779361319263, 0.0767972189350985, 0.09839614314842038, 0.0180818696753704, 0.01937735523824813, 0.03948884295823518, 0.028585057152668014, 0.018629904916451778, 0.03910781320882961, 0.015575421748508234, 0.05581213248660788, 0.051866797512047924, 0.04030645221064333, 0.008974838237918448, 0.030341021229105536, 0.04823337607376743, 0.024248758782050572, 0.014460078618867556, 0.04976731739589013, 0.01958160170033807, 0.033014803047990426, 0.13271246541989967, 0.020195676952425856, 0.04685312982473988, 0.052579901239369065, 0.022800145889050327, 0.009622894576750696, 0.01624692067707656, 0.03712100595294032, 0.029804218393110204, 0.02470226667355746, 0.04450920481758658, 0.021740394258813467, 0.08103335334453732, 0.013528085855796235, 0.026815007113327738, 0.010659173003659816, 0.05922158859902993, 0.028958637594769243, 0.03179140228894539, 0.06835738196969032, 0.04971845439285971, 0.04333557990321424, 0.04741738841403276, 0.03976057290856261, 0.009962027306755772, 0.030332608985190745, 0.01961846232006792, 0.010397140140412375, 0.08125470631057397, 0.07616559189045802, 0.03001202716404805, 0.022142927737149876, 0.018524981933296658, 0.020170735224382952, 0.03086462867941009, 0.014602479132008739, 0.07610705128172413, 0.028777323495887686, 0.015129473558772588, 0.04123888284084387, 0.08079325372818857, 0.04731515386083629, 0.008530299201083835, 0.022108501361799426, 0.07263771869475022, 0.04270950041245669, 0.036395051938598044, 0.04272245831089094, 0.08478765579639003, 0.031077007224666886, 0.019963835584349, 0.03924233860743698, 0.021159303760214243, 0.063002192764543, 0.05153056379640475, 0.027694253585650586, 0.09113590538618155, 0.018333550506213214, 0.0418614037334919, 0.025335982863907702, 0.030359578631760087, 0.03685824114654679, 0.012947885006724391, 0.05637008282064926, 0.02147574254195206, 0.06566228010342456, 0.04817348475626204, 0.04347071757365484, 0.04450379085028544, 0.026462470268597826, 0.06788274884456769, 0.013538483344746055, 0.06373434371198528, 0.03288592539320234, 0.0365155692998087, 0.03625398821895942, 0.020263058395357803, 0.065384516492486, 0.04358725702331867, 0.023750473410473205, 0.07695987544138916, 0.024162554618669674, 0.060711446349159814, 0.07890224660513923, 0.040703579143155366, 0.028381419251672924, 0.04085764900082722, 0.017959558172151446, 0.004168630512140226, 0.02511355563910911, 0.04449147490959149, 0.013578717025666265, 0.048859808084671386, 0.054240579120232724, 0.009145903277385514, 0.02648497775226133, 0.030754052386328112, 0.05103691313706804, 0.009178490054182475, 0.018172237287217285, 0.022645176177320536, 0.05131181576871313, 0.0073440763299004175, 0.015243850575643592, 0.05637226844555698, 0.026286837310181, 0.018126539544027764, 0.011439864119893173, 0.013135517565388, 0.022544385101355147, 0.05459072068333626, 0.01922200888657244, 0.05012539251765702, 0.03484143999230582, 0.029404785236692987, 0.05644973753078375, 0.018478055935702287, 0.014088099360378692, 0.03138947366096545, 0.029549368591688108, 0.007080647765178583, 0.016885139848454855, 0.020345110242487863, 0.05870807064638939, 0.05194284538447391, 0.009324112415924901, 0.056964788018376566, 0.03537002354278229, 0.034794198581948876, 0.022292240428214427, 0.028915654256707057, 0.027719531135517173, 0.06509791390271857, 0.012609140976564959, 0.09157891559880227, 0.057335234741913155, 0.03497293371765409, 0.028535633828141727, 0.0223523785098223, 0.03065528922888916, 0.03893131193763111, 0.03844581005978398, 0.01846309423854109, 0.0161982654753956, 0.05152978454134427, 0.019605153756856453, 0.05401459144195542, 0.025986228538386058, 0.08041351902647875, 0.0443422141688643, 0.026812339092430193, 0.01370724494336173, 0.08196928320103325, 0.03145907227008138, 0.030830194882582873, 0.06909001531312242, 0.022819983496447094, 0.06345237954519689, 0.01768587637343444, 0.020919484304613434, 0.030627981905126944, 0.013631007823278196, 0.03438387255300768, 0.017027138674166054, 0.03088911955273943, 0.045000855388934724, 0.037368037228588946, 0.017267882103624288, 0.04978571152605582, 0.010515869853406912, 0.032760175890871324, 0.02233614959550323, 0.018011493666563183, 0.01787411285476992, 0.031733741125208326, 0.0585143478383543, 0.062338445568457246, 0.012929264521517325, 0.07416911073960364, 0.02415510160062695, 0.009162804763036547, 0.07472046709153801, 0.03952869999920949, 0.026064595622301567, 0.012191771966172382, 0.04944151085510384, 0.06442143145250157, 0.027047538678743877, 0.04306434348109178, 0.12236845563165843, 0.12989602982997894, 0.09715330554172397, 0.1740953471744433, 0.09120766364503652, 0.10424021471408196, 0.17341267521260306, 0.09622032943298109, 0.24451708712149411, 0.11956914881011471, 0.2060428899130784, 0.1198287149600219, 0.147054543485865, 0.15832136938115582, 0.12352241363259964, 0.1874405873240903, 0.22539318830240518, 0.15741905139293522, 0.10699088117689826, 0.15251753706252202, 0.1322278133011423, 0.14237988885724917, 0.13919433869887143, 0.13286275032442063, 0.1193106068240013, 0.12383738852804527, 0.14056259184144437, 0.2023105847183615, 0.09341448429040611, 0.09112293264479376, 0.21316352969733998, 0.12837829330237582, 0.14254466048441827, 0.10585230789729394, 0.17521463945740834, 0.1827327735372819, 0.17751182400388643, 0.09257767567760311, 0.19013835350051522, 0.1772106159478426, 0.21314680168870836, 0.16267474828055128, 0.11636394658125937, 0.23792404012056068, 0.1809243080788292, 0.11298817655188031, 0.15620230027707294, 0.14051450067199767, 0.1442243781639263, 0.1243891975900624, 0.13943190017016605, 0.15414410212542862, 0.18999366438947618, 0.11763376867747866, 0.0990212541364599, 0.1682325586443767, 0.0960425627999939, 0.1495380070991814, 0.10218043578788638, 0.2377314231125638, 0.1251682819565758, 0.12965276866452768, 0.12392834614729509, 0.07595715971547179, 0.17465900833485648, 0.1026497180282604, 0.16597121983068064, 0.12634274549782276, 0.1382146295509301, 0.0871502680820413, 0.18031807732768357, 0.15137609909288585, 0.11135838314658031, 0.14765626197913662, 0.10310890706023201, 0.09718829780467786, 0.20222560880938545, 0.12990382238058373, 0.18418735329760239, 0.10797684662975371, 0.14937621890567243, 0.18575374502688646, 0.1748135086381808, 0.1569474017014727, 0.16640748392092064, 0.08943936321884394, 0.08012252292246558, 0.08629978910903446, 0.09654850713559426, 0.12596548214787617, 0.1398141507524997, 0.09435330852284096, 0.12639966822462156, 0.18971430516103283, 0.12847775593400002, 0.07442402362357825, 0.1556238703778945, 0.12113789314753376, 0.12016239939839579, 0.1596821119892411, 0.11908221829799004, 0.18057803681585938, 0.22258473822148517, 0.1358970211003907, 0.15821647422853857, 0.09492278812103905, 0.18161425308790058, 0.1544437071424909, 0.1256914812256582, 0.07174553844379261, 0.11614796676440164, 0.1582413213327527, 0.058210594215779565, 0.12708605092484504, 0.08953458818723448, 0.07773216173518449, 0.14714931574417278, 0.09275877455365844, 0.19650169095257297, 0.19058874808251858, 0.19365552492672578, 0.16351462196325883, 0.15563767432468012, 0.2811436780029908, 0.1314715648186393, 0.14180497673805803, 0.07802633423125371, 0.1434736215742305, 0.13805757625959814, 0.1221170456847176, 0.0781051503145136, 0.18080470355926082, 0.08477035633404739, 0.152325305971317, 0.20395129511598498, 0.1298305278760381, 0.14265446865465492, 0.07123146759113297, 0.15066479507368058, 0.20529784786049277, 0.12343176029389724, 0.1575283845886588, 0.1956998894456774, 0.18603599863126874, 0.204292475245893, 0.11092852379078977, 0.07403029943816364, 0.12121561827370897, 0.12721757433610037, 0.09262651641620323, 0.13463151088217273, 0.1862012452329509, 0.1298779362696223, 0.09625959646655247, 0.08381277060834691, 0.11922593519557267, 0.08408219247939996, 0.12458097597118467, 0.19690748245920986, 0.14109992160229012, 0.16122371598612517, 0.14078725478611887, 0.19416379218455404, 0.2748621697537601, 0.07990196405444294, 0.1575558292097412, 0.14781358244363219, 0.11860598955536261, 0.11750142148230225, 0.1286458078538999, 0.1313071939512156, 0.17009987641358748, 0.13557160418713465, 0.17173914704471827, 0.10418528094305657, 0.18356855056481436], [0.05946428944298532, 0.02534587198169902, 0.02639879399794154, 0.026537208250374533, 0.10267109930282459, 0.0905813577992376, 0.039594940390088595, 0.03529119261656888, 0.0368932519631926, 0.009682778472779319, 0.059401822873041965, 0.0351305992808193, 0.03627819707617164, 0.039773122625774704, 0.035785069630946964, 0.05730895900342148, 0.03460508451098576, 0.10547772370046005, 0.05234285556070972, 0.08711224785656668, 0.06356977988616563, 0.10678043036023155, 0.034872265096055344, 0.03549215507518966, 0.026322098601667676, 0.05869758781045675, 0.05562733029364608, 0.022459420324594248, 0.053365943240351044, 0.07314370755921118, 0.060874288392369635, 0.024740947410464287, 0.04441458098881412, 0.03260344543377869, 0.020401710135047324, 0.08447377185802907, 0.041352761691086926, 0.010188715386902913, 0.007658986287424341, 0.046793680085102096, 0.014100453336141072, 0.01729991134197917, 0.02223224892077269, 0.012673918408836471, 0.02551706875237869, 0.05302287434460595, 0.10192995352554135, 0.02510218408133369, 0.0758538676018361, 0.02246723699499853, 0.008282197377411649, 0.036336711709736846, 0.06059322964574676, 0.025097488141909707, 0.006405466392607195, 0.06010949036863167, 0.016596475943515543, 0.02587582293926971, 0.011117951071355492, 0.09325671853730455, 0.06920944913872518, 0.014611102888011374, 0.03750466290512122, 0.03517044890031684, 0.05545165651710704, 0.04484319724724628, 0.00872808897838695, 0.045019538956694305, 0.06156971416203305, 0.06577319407369941, 0.030719995229446795, 0.09417212058906443, 0.03755789715796709, 0.04367634071968496, 0.05151777288119774, 0.068453905696515, 0.017392479421687312, 0.02973967195430305, 0.04429247914231382, 0.08586989264586009, 0.05147251671587583, 0.032746075085015036, 0.019103588092548307, 0.01845045917434618, 0.07857422475353815, 0.05571330068050884, 0.030810008465778083, 0.05943602474872023, 0.005503288020918262, 0.03411313708056696, 0.049684215409797616, 0.043307356027071364, 0.012037396900268504, 0.062181674293242395, 0.034239654705743305, 0.04828283650567755, 0.07578682198072784, 0.0114921335807594, 0.051963803634862415, 0.011019149878848111, 0.061474674730561674, 0.060350076091708615, 0.04080024016730022, 0.021654796801158227, 0.04384982516057789, 0.0525835229200311, 0.03273026733950246, 0.058897270064335316, 0.07465199654689059, 0.03421615459956229, 0.04426608466019388, 0.019177478170604445, 0.011728092940757051, 0.03199927043169737, 0.05901590237044729, 0.006276773810895975, 0.052620214701164514, 0.07314638671232387, 0.07958446585689671, 0.024205198424169794, 0.08497746748616919, 0.013796886178170098, 0.09762996473000385, 0.08175377835868858, 0.03036326710571302, 0.08696827862877399, 0.013123333355906652, 0.04096051066881046, 0.0301114768080879, 0.00883595550476457, 0.015198225191852544, 0.018380051624262705, 0.06014029320795089, 0.01918119076435687, 0.03682459959236439, 0.11615610812441446, 0.06914345736731775, 0.04153946749283932, 0.05334208319254685, 0.030421592491620686, 0.008316684979945421, 0.05597907118499279, 0.018711917800828815, 0.042592567624524236, 0.008081848118308699, 0.006323652960418258, 0.030749523430131376, 0.01986917464819271, 0.007734464561508503, 0.038071556118666194, 0.02418169089651201, 0.06607871400774457, 0.003789316747315752, 0.06391473012627102, 0.006921970561961643, 0.037550201086560264, 0.02121221517882077, 0.027556449749681633, 0.020313233144406695, 0.017034831034834497, 0.013750471334788017, 0.061592498095706105, 0.011979340542893624, 0.008719237939658342, 0.030320038858917542, 0.05326502228854224, 0.007016901918177609, 0.04093743358680513, 0.020882603275822476, 0.05134382830874529, 0.0673282532079611, 0.07277040727785788, 0.046832731895847246, 0.035514323026291095, 0.053039368576719426, 0.07069438273902051, 0.04528564713837113, 0.05461700013256632, 0.05999207147397101, 0.037715648068115115, 0.03873924411891494, 0.06534610292874277, 0.028631521163333673, 0.027495840404299088, 0.03173699544277042, 0.06939141632756218, 0.06842804927146062, 0.05896440474316478, 0.09116055211052299, 0.020896640999126248, 0.059004143040510826, 0.04847534961299971, 0.03863968500809278, 0.025206047648680396, 0.09698276000563055, 0.019318102167744655, 0.014154824930301402, 0.0660326043725945, 0.03432513527513947, 0.04533327817625832, 0.01989536132896319, 0.027763763137045316, 0.009207985785906203, 0.013706926747545367, 0.013733325868088286, 0.001477122380038054, 0.01494657033617841, 0.031296549350372516, 0.02342476149351569, 0.02977057683892781, 0.03681405738461763, 0.04226349192322232, 0.06401687933248468, 0.048211898320005275, 0.011884215764439432, 0.04558702217764221, 0.002542082147556357, 0.016246822342509404, 0.022315501191769727, 0.019390604429645464, 0.05093926505651325, 0.08968466529040597, 0.11009333305992186, 0.04267757693014573, 0.052753471027244814, 0.02538129654567456, 0.03331434498250019, 0.03263074904680252, 0.024689076853974257, 0.01064933027009829, 0.01778400684997905, 0.02387594275205629, 0.032209880810114555, 0.04541621317912359, 0.027241921998211183, 0.02598366998427082, 0.05702509493858088, 0.0450853822985664, 0.036648769964813255, 0.04905310044705402, 0.055413825539289974, 0.048503313737455755, 0.013572604511864483, 0.03727864925167523, 0.039525052343378775, 0.04499139300605748, 0.06313373844022863, 0.008432832019025227, 0.022134010832814965, 0.09397996371262707, 0.029185706953285262, 0.06503251584945247, 0.045432481056195684, 0.0310984497264144, 0.007456921275661443, 0.051713621942326427, 0.02181562020268757, 0.03467836417257786, 0.031929527103784494, 0.057593093952164054, 0.049940456738113426, 0.05704304378014058, 0.02373642269958509, 0.0832092115888372, 0.0357936933869496, 0.012949645752087235, 0.05978293054795358, 0.04849048571486492, 0.023732858535367996, 0.05803984087833669, 0.012948658695677295, 0.024500508261553477, 0.061779875541105866, 0.06807989295339212, 0.05312647444952745, 0.01658753120864276, 0.028788945528503973, 0.03682680748170242, 0.04788375772477593, 0.012785567105311202, 0.041377375018782914, 0.008156108342518564, 0.05505661501956638, 0.016222038320847787, 0.06739716161973774, 0.021543493203353137, 0.06633428740315139, 0.04001213499577716, 0.05284226528601721, 0.0972547719720751, 0.014884254051139578, 0.025182979843521025, 0.07234402859467082, 0.015022983716335148, 0.045954251691000536, 0.08355183890671469, 0.04616727033862844, 0.0035998580415252945, 0.0380206076806644, 0.05146219344169367, 0.014654915576102212, 0.009515048459434183, 0.0327114464744227, 0.023480366908188444, 0.04067691006639507, 0.009931435051839799, 0.020951597034581937, 0.03167399452649988, 0.07113580475561321, 0.005216544886934571, 0.017255619968636893, 0.1140722242416814, 0.03308975254185498, 0.018058922469208483, 0.02092243990773568, 0.031661626635468565, 0.06503543991129845, 0.055675911280559376, 0.013491567551682238, 0.01615908749954542, 0.04364282533060759, 0.0841976261290256, 0.043549563342821784, 0.016278018520097248, 0.016089481468952727, 0.06948412541532889, 0.004849258320973604, 0.01979731248866301, 0.020038903821841814, 0.09085432713618502, 0.03772996780753601, 0.046702091640327126, 0.05570027969952207, 0.053904939122730866, 0.059266889293212444, 0.007951961142680375, 0.046084146088105626, 0.07419170913635753, 0.011569164798856946, 0.05773687764303759, 0.020980143744964153, 0.03092436229053419, 0.004986474004908814, 0.04997673291654792, 0.045223566485219635, 0.005233631445662468, 0.0652307880227454, 0.01596553724084515, 0.017053154660970904, 0.05560762627283111, 0.045011679612798616, 0.06978114033699967, 0.22066693956730887, 0.17669794033281505, 0.17413953464711085, 0.11725790056516416, 0.19259239837992936, 0.14311589155113325, 0.07323097670450807, 0.12645706592593342, 0.12588449899340048, 0.23723963153315708, 0.19987951673101634, 0.18296178546734154, 0.20547670545056462, 0.19660786259919405, 0.18640500929905102, 0.20426077069714665, 0.1628469116985798, 0.14621103327954188, 0.24466582835884765, 0.18603700795210898, 0.13092899549519643, 0.21163961850106716, 0.1736919305403717, 0.1195496303262189, 0.09029568289406598, 0.20740091626066715, 0.10043131245765835, 0.1445493646315299, 0.09841612176387571, 0.10001565780839883, 0.16632455633953214, 0.13042972306720912, 0.1258897830848582, 0.12386924892780371, 0.1305083610350266, 0.17929600639035925, 0.13449068093905225, 0.16928087192354724, 0.09409584265085869, 0.12080996777513064, 0.08892526268027723, 0.06791369640268385, 0.17787192889954895, 0.054956462190602906, 0.21916308120125905, 0.1438913171296008, 0.23654195334529504, 0.10253386135445908, 0.12312914957874455, 0.1270520011894405, 0.1555990826454945, 0.14327825861983, 0.09631783279473893, 0.10819653718499467, 0.09683379612397403, 0.20512366580078378, 0.06257178421947174, 0.12676824844675139, 0.08479590105707757, 0.2059907020884566, 0.12925617978908122, 0.16787393804406747, 0.12693002179730684, 0.07176215513027273, 0.14365918817929924, 0.11778914471506141, 0.2201951266033575, 0.22198668593773618, 0.11794337042374536, 0.1492236036574468, 0.15077690390171483, 0.17225189687451348, 0.11009407520759851, 0.28393489541485906, 0.21491970343049616, 0.12448333902284503, 0.1303276332328096, 0.14617784443544224, 0.18689681572141126, 0.1757599547272548, 0.11541873987880535, 0.11055453331209719, 0.07663876298465766, 0.1259683765238151, 0.15264621062669903, 0.1309120745281689, 0.14994121593190357, 0.1778575757634826, 0.13567241752753034, 0.16709198156604543, 0.17432891589123756, 0.11751290992833674, 0.1430092449299991, 0.11993431515293196, 0.09373184147989377, 0.17432637774618343, 0.1828455354552716, 0.19957333628553897, 0.134817760263104, 0.16564276011195034, 0.1360172193381004, 0.13825507659930736, 0.26017756084911525, 0.0972386376815848, 0.0916372929350473, 0.12825322657590732, 0.15497711836360395, 0.11127996040158905, 0.14294905675342306, 0.10738769269664772, 0.14441959268879145, 0.13038078584941104, 0.12983992346562445, 0.1280626727384515, 0.09739715300383978, 0.10251363783027045, 0.08043139736400917, 0.16737088066292927, 0.1526643190300092, 0.20792721770703793, 0.1810780810774304, 0.13249262643512338, 0.08387955647776835, 0.1521951035829261, 0.12060779932653531, 0.14293192798504606, 0.11590610825805925, 0.09123482625000179, 0.1174015284050256, 0.1251704341848381, 0.13451432576403022, 0.12122489511966705, 0.12163516919827089, 0.07352790998993441, 0.10863987394259311, 0.19204349111532792, 0.12211105655296706, 0.10962010259390809, 0.15627464483259246, 0.10683567583328113, 0.09055361631908454, 0.21834090031916276, 0.07557683129562065, 0.1602301435195841, 0.15273393248207867, 0.221906385559123, 0.0874225546431262, 0.10899493223405443, 0.09868199616903439, 0.18170825351262465, 0.07410812846501358, 0.14889165584463626, 0.11912353365914896, 0.17966181098017842, 0.07908828818472102, 0.14113922574324533, 0.10867178629268892, 0.17016873287502676, 0.11456387481302954, 0.12175594631116837, 0.13706449361052364, 0.1880682958289981, 0.09849371330346912, 0.19702592922840267, 0.13939955737441778, 0.13769649172900245, 0.1307277102023363, 0.10715532625908963, 0.1420213424717076, 0.09153860955848359, 0.1516566754435189, 0.15342521335696802, 0.17284375964663923, 0.1388487798976712, 0.1408429307048209, 0.16175451484741643], [0.0248083585393033, 0.0416331784799695, 0.05390506157709751, 0.08008761971723288, 0.05376331879233476, 0.07229621201986447, 0.04363219406513963, 0.036003398345201276, 0.0165293152895174, 0.01685884370090207, 0.03735496058652643, 0.03395252148038708, 0.03157987535814755, 0.03613612032495439, 0.0309558980006841, 0.08674787561176345, 0.07576377087389119, 0.014650351367890835, 0.05064594231953379, 0.017387787193001714, 0.02830146397172939, 0.048941882196231745, 0.03753201104700565, 0.01689725355390692, 0.007057739985611988, 0.043203663153690286, 0.05031826556660235, 0.00891257854163996, 0.045189071461209096, 0.0711560134368483, 0.030103699100436643, 0.019603754808485974, 0.028922916171723045, 0.09208894174662419, 0.010975013428833336, 0.02696256648050621, 0.02981779041874688, 0.050331023085163906, 0.02850017586752074, 0.07187410810729489, 0.03144407346553635, 0.021256265354168136, 0.04261868009052705, 0.03596145586925559, 0.024015791204874404, 0.006527924469992286, 0.06192172964802012, 0.03980869376391638, 0.04308333132939879, 0.016088678094092757, 0.031685130452387966, 0.01815774870919995, 0.05783410641015507, 0.04673225252190605, 0.04551888931018766, 0.02390347457549069, 0.03327236539917067, 0.03474980330793187, 0.013752030772593571, 0.012926694835186936, 0.04379130310553592, 0.022729708653059788, 0.05218461112235673, 0.02598105576907983, 0.003068522282774211, 0.03400181121833157, 0.0472596894542221, 0.017683449550531805, 0.12507395498687401, 0.04667318869906012, 0.045635729329660535, 0.008603067708463641, 0.01084941142835305, 0.03145734306599479, 0.029754733841400594, 0.01908072994410759, 0.06506726320367306, 0.051770069694612175, 0.04203711461741477, 0.048826344645931385, 0.08848790763295256, 0.051900847247452475, 0.04375241456727963, 0.05751848584623076, 0.012102314412913984, 0.10004175172070973, 0.0317397228354821, 0.0349407950125169, 0.05116718602948822, 0.029848366903024726, 0.048991205330821685, 0.047272205774788745, 0.022246128937695175, 0.05096913650049828, 0.07171559278503992, 0.07467530740541406, 0.026326597871957347, 0.0076482641088659875, 0.03228760222555138, 0.04277323605492711, 0.02138418007234577, 0.052633539962698705, 0.02353146377572557, 0.050333568651694804, 0.017738639362505637, 0.04846799492952414, 0.028233063931111246, 0.02673769573448226, 0.056065327298711054, 0.025589014403522015, 0.021740748634329066, 0.011343011992721586, 0.08990221103886142, 0.013146772234904347, 0.11714925756677985, 0.0220905580863473, 0.08613548503490165, 0.01347408069705125, 0.03151490032905713, 0.018173981334257405, 0.03151684104523156, 0.04637429985450581, 0.05939368893450592, 0.007033666106508463, 0.01679757384408731, 0.053709461135440506, 0.056016497692326084, 0.05660748473019339, 0.03310414649604354, 0.017190105027111713, 0.014795791903452482, 0.02180552328354679, 0.006173930232762359, 0.00889662793269963, 0.041675825996208005, 0.06645292713074014, 0.014927660413377453, 0.022649786769761704, 0.029099283856339753, 0.02961489652079763, 0.0845417303207796, 0.05086897253931966, 0.052753552663489245, 0.028593794086191338, 0.03203540931281168, 0.024684247327968478, 0.102731562074041, 0.037380393987405114, 0.02648255649546627, 0.03013991405168781, 0.022872557237860747, 0.025865878160402644, 0.034255295468028635, 0.04674194868130144, 0.038587241142522544, 0.06833079081843607, 0.06810941558796912, 0.016360396912205033, 0.07202949898783118, 0.10292814957210794, 0.050998095102841035, 0.007668071102671092, 0.019010313117178157, 0.009703656942292582, 0.04280127439415082, 0.026308994129067287, 0.08530353748938069, 0.09527479618554935, 0.03351260602357797, 0.012581052542373072, 0.0329729347868124, 0.011031607755285222, 0.022397209795599338, 0.02363740721193608, 0.011476375930215, 0.030498809246637393, 0.0463957256579306, 0.03699351982504595, 0.031045918658492155, 0.015336132928496227, 0.06194717047037557, 0.03997125750174746, 0.004584872849591193, 0.0911389036627952, 0.05368984988308512, 0.01614105702174129, 0.07163766727899201, 0.06654513897956349, 0.039698265900369734, 0.008804045010037953, 0.03709873781190254, 0.027319648979755584, 0.066610492503969, 0.006093177144066431, 0.03254925009969156, 0.06985758154769428, 0.016843273442646023, 0.05445936796604656, 0.019377119606360793, 0.055294618068728596, 0.02323581255041063, 0.018709223804762587, 0.07408982710330747, 0.00920619813769008, 0.07465523231076077, 0.08014882463612594, 0.027304260547680315, 0.02468963160936255, 0.05993249927996658, 0.11894958166521974, 0.04772338332259096, 0.12444886626326479, 0.047410705374204554, 0.04406055057188496, 0.010594159939500969, 0.14128243055893108, 0.03387895609193947, 0.048116016550920904, 0.02404962757282192, 0.05674319385434501, 0.053106685081729665, 0.07640905343578197, 0.031469510577153414, 0.038170488114701584, 0.07588312306324951, 0.08009674813365564, 0.051594340256997384, 0.03344351949635893, 0.011932970228372142, 0.008205131834984059, 0.0904077100858558, 0.028516388083517086, 0.03386374948604498, 0.02011736924032448, 0.025380430088262074, 0.03993197562522255, 0.015169648795563262, 0.04857373241975438, 0.02062956802546978, 0.09456979300011881, 0.04210197461361531, 0.03275676201155875, 0.02658423258253606, 0.07186682763858698, 0.05451456148875877, 0.03261899342760444, 0.06581470239325427, 0.03865602338919416, 0.02186859284847742, 0.05007888212276157, 0.029000787872064393, 0.009125426495302236, 0.012870441896666307, 0.09403008836670779, 0.02232499511592323, 0.08421152655500919, 0.060733606878784485, 0.025387962887180038, 0.018131014694517944, 0.0683992613630835, 0.020860978947894182, 0.02086071363009978, 0.013810575092065847, 0.031204734550556168, 0.047139866001089104, 0.030709388083778322, 0.036195788998156786, 0.020202506566420197, 0.03332997832330875, 0.0191915196046466, 0.005930699680902762, 0.016063174189184792, 0.04166671242273878, 0.0609095738036558, 0.028343471385596786, 0.038809584875707515, 0.023390468704747036, 0.07239009370096028, 0.048241550830425695, 0.029138743848307058, 0.01412796382282977, 0.042467641906114295, 0.039767155758454464, 0.07630547930602916, 0.0655974906112533, 0.06991431131609716, 0.009516221052763285, 0.014472631119133439, 0.07446247429470532, 0.04711730842245743, 0.07031064786133356, 0.005962862969681737, 0.013070705808786443, 0.030589711204811465, 0.006069344462957815, 0.0318976555718109, 0.025055783153220546, 0.032808330142870545, 0.05073547130450606, 0.0547590026690159, 0.027007282733393367, 0.011744582534447545, 0.056486533212591894, 0.055276877028518356, 0.09129258018219844, 0.033518598866066895, 0.02932198938651709, 0.003764494226743409, 0.036575738922692835, 0.02297429455211386, 0.028478848398663104, 0.00777770440436143, 0.017719529059831984, 0.020060834285686724, 0.06642926746280864, 0.018738837352429982, 0.03349824917677324, 0.028173410100862384, 0.04158402603934519, 0.03505886699713301, 0.09972938176360913, 0.04852347788983025, 0.07792695323587395, 0.0728766382962931, 0.03916363755706698, 0.05355676054023206, 0.04224333890306298, 0.02678372744412627, 0.05626379243039992, 0.044489497086033225, 0.04728979467472527, 0.02072526611300418, 0.08787344646407291, 0.01010397974823718, 0.08044216592679732, 0.053770762533531524, 0.049408485283493064, 0.03413931262912229, 0.02169737381336745, 0.02357399254833581, 0.0935660679533612, 0.028348774030746426, 0.06410976653569378, 0.08922332403017208, 0.07109195867087692, 0.015627910142939072, 0.02176171801693272, 0.016152873868122697, 0.01150821035480476, 0.016135945479618385, 0.09022201731568202, 0.057697053998708725, 0.14413125347346067, 0.17744976561516523, 0.13253351877210662, 0.18211021553725004, 0.21597380546154454, 0.2550152409821749, 0.13539337000111118, 0.18434339726809412, 0.08174948874511756, 0.17729208891978487, 0.17279681138461456, 0.2280206879368052, 0.13875776290660724, 0.08941172563936561, 0.14922348491381854, 0.12648345669731498, 0.18030382809229195, 0.15615242795320228, 0.101068876683712, 0.12840453564422205, 0.09500841711997055, 0.1130344123521354, 0.10370758274802938, 0.13067976746242493, 0.1148532827210147, 0.1954949676292017, 0.2501819300232455, 0.056289185013156384, 0.1379150096909143, 0.2350007649511099, 0.09888572312775068, 0.16259003954473883, 0.11948380182730034, 0.2159134391695261, 0.06154426962893922, 0.21237571025267243, 0.1666386629221961, 0.16333092557033524, 0.09730549034429714, 0.2047663216944784, 0.1309317711275071, 0.15471313643502071, 0.07423050861689262, 0.10862070426810533, 0.12057684434694238, 0.1657858313410543, 0.11815624064183794, 0.08458317184704356, 0.1741472678259015, 0.16042118717450649, 0.11628169435425662, 0.08818056201562285, 0.13165555807063356, 0.10087213333463296, 0.14962546178139746, 0.1606937186443247, 0.08638563333079219, 0.10554217180470005, 0.10797997107147239, 0.08754947673878632, 0.13756790722254664, 0.14762877282919362, 0.1925201280391775, 0.13749121368164197, 0.12144209205871448, 0.2004367212066427, 0.11242207372561097, 0.10401459439890459, 0.27507920342031866, 0.12205408929730766, 0.19285293674329296, 0.09408722631633282, 0.11768511045374908, 0.09477809158852324, 0.1631921884836629, 0.112097257951973, 0.14504446618957445, 0.17559907195391133, 0.11084636062150821, 0.21241164504317567, 0.19283279485534877, 0.1843661515158601, 0.05723214300815016, 0.1427606848301366, 0.10901053217821755, 0.1713210655725561, 0.11952679444220848, 0.13759352616034448, 0.11601991660427302, 0.14077376254135743, 0.10229903840809129, 0.1650241354946047, 0.14712424599565566, 0.19916450197342783, 0.21402706304797903, 0.11923587997443974, 0.1619714594562538, 0.14120072009973228, 0.12267999438336119, 0.14006046956637874, 0.18442809116095304, 0.13297056953888386, 0.098287693108432, 0.11185390030732378, 0.10214805588475429, 0.15021054132375866, 0.17980667820665985, 0.10417019308079034, 0.12379006919218227, 0.1555581606226042, 0.08947712369263172, 0.17899527330882847, 0.19486590841552243, 0.29977241589222103, 0.19657831027870998, 0.22236435004742816, 0.13203760085161775, 0.13053482602117583, 0.1115989577374421, 0.09419539434020407, 0.10679156257538125, 0.07772532655508257, 0.1369849799084477, 0.1262646121904254, 0.11417940520914271, 0.10659199906513095, 0.137688402319327, 0.11572489063837565, 0.25941757194232196, 0.11917209238163196, 0.06432593188947067, 0.10016079962952062, 0.1339608765556477, 0.13277434569317847, 0.10951978649245575, 0.10188500906224363, 0.13140117953298613, 0.13323953869985417, 0.10520620155148208, 0.07033632617094554, 0.20874972513411194, 0.1427718615741469, 0.13894850970245898, 0.1262967026559636, 0.14787334017455578, 0.11213138190214522, 0.20686268107965589, 0.10416490898933262, 0.13537285703932866, 0.21961211023153737, 0.10983717336785048, 0.08681130697368644, 0.10391394433099777, 0.23757349408697337, 0.10396540485089645, 0.06772363238269463, 0.15944245766149834, 0.060796656034654006, 0.2802200603764504, 0.1926526756142266, 0.0910657798522152, 0.19806953729130328, 0.09043109515914693, 0.08474734233459458, 0.3268212347757071, 0.11761535599362105, 0.22688612225465477, 0.20214655523886904, 0.12906477990327403, 0.07993364633875899, 0.1526869396911934, 0.08969789036200382, 0.0836509675718844, 0.20195848017465323, 0.20411173260072246, 0.1712127565406263], [0.010695062337617856, 0.019210973150620703, 0.043494985802681185, 0.02779553076834418, 0.03636952576925978, 0.03747709582967218, 0.0077223573498486076, 0.024440611377940513, 0.07445852606906556, 0.05536895158002153, 0.05535916265216656, 0.04153545247390866, 0.024199814142775722, 0.05484403052832931, 0.04889670766715426, 0.011765348754124716, 0.0340730462630745, 0.05574420742050279, 0.05566105348407291, 0.013918414715590188, 0.03040365107153775, 0.06796234418288805, 0.04585928276355844, 0.011921404784516199, 0.04886097325652372, 0.011229599767830223, 0.01900807739730226, 0.018455364770488814, 0.06410295362002216, 0.013308176366990665, 0.02926765118900221, 0.0295732286394923, 0.017549402837175876, 0.03358618254424073, 0.006931607349542901, 0.04033194127259776, 0.04192382577457465, 0.07427933451253921, 0.02597619099105941, 0.05182513334148098, 0.07228970338474028, 0.06090643451898359, 0.01980300476134289, 0.043100196635350585, 0.02665462343429681, 0.03155767029966228, 0.03525623746099882, 0.04760486233863048, 0.021400626064860262, 0.013222551078797551, 0.026959818678733427, 0.02731222935835831, 0.0792612976511009, 0.032538132727495395, 0.02165452406188706, 0.028675248504441697, 0.02724816346017178, 0.06766788224922493, 0.009901595149131026, 0.06823008137871511, 0.06802698524552397, 0.03064841694140341, 0.061544551645056345, 0.06595467144506983, 0.05264187428110745, 0.0575224600470392, 0.024806876099319197, 0.028651253014686517, 0.018557764451543335, 0.03477631282294169, 0.050056795807904564, 0.01889737308374606, 0.06631261669099331, 0.019160944975737948, 0.022932496794965118, 0.0069235044884408126, 0.03461861015239265, 0.03412023572309408, 0.040422249512630515, 0.04093804585863836, 0.012472629405237967, 0.04653000985854305, 0.025950249219022226, 0.06134021983598359, 0.050413130593369715, 0.026974943648383487, 0.017092562702600844, 0.046267033540061675, 0.0171958845021436, 0.04461688302399125, 0.03857842442812398, 0.06676095552393235, 0.006068550364943803, 0.03756849131605122, 0.08103038475383073, 0.038048994829296134, 0.02257482243294362, 0.04880324901023414, 0.02477301561157219, 0.062298302800627425, 0.022909332510607783, 0.01699779229966225, 0.1048548762628343, 0.04241179529344663, 0.045933145011076704, 0.06785071032936685, 0.045730460769846104, 0.028265540313441306, 0.0029946294216642855, 0.06817755216616206, 0.027569340854824986, 0.1031925471033901, 0.04689841567596886, 0.03221405539079569, 0.050596626606420614, 0.041338278679177165, 0.043399875867180526, 0.03849283995805308, 0.04209820821415633, 0.027426015440141782, 0.03823432394710835, 0.018661206850083545, 0.0341555322665954, 0.05456526872876566, 0.02968749155115802, 0.08207567007048056, 0.05361438830732368, 0.06438819807954133, 0.0382231805997435, 0.0570570481067989, 0.038131380642880686, 0.00282243539004412, 0.00999640080408426, 0.013144508684490575, 0.03083502440858865, 0.01585089212312596, 0.04989446584659163, 0.02137814084562706, 0.012719268270302564, 0.029386877213255502, 0.015984202254912816, 0.07316715200431645, 0.05984256582451053, 0.04980043202522211, 0.020876484268228523, 0.08018156819161959, 0.06593547950615175, 0.07807962785591371, 0.02975952626002254, 0.047835377117735334, 0.04306803195504472, 0.10085904927109368, 0.032124511562869884, 0.05945466007688083, 0.018202817482233513, 0.027692886178556364, 0.04336788930231705, 0.008126228549372172, 0.026949888742819894, 0.04589491327351425, 0.05840457677550148, 0.013114028679410694, 0.02382943050179165, 0.09946567442966625, 0.06879907858092338, 0.04374288910184987, 0.03988867872976698, 0.07627160026459023, 0.04572162179101724, 0.04167603008681908, 0.06302171866991557, 0.013080487315164646, 0.030927063708077185, 0.03225131120416336, 0.06141279445728287, 0.03446836235525552, 0.023336681551882066, 0.05838266857608687, 0.02595695637864992, 0.0400509010796668, 0.08278407229227014, 0.012122669668315211, 0.02780536793579813, 0.030946643419156317, 0.07925418045488186, 0.020988084725104272, 0.02631036153616151, 0.04554540995741263, 0.038729874504497275, 0.06203689983522054, 0.05404687486588955, 0.06277465770835988, 0.08905654118279926, 0.08545706557924859, 0.05147357798705343, 0.01893088105134666, 0.058452812663745135, 0.041786428264458664, 0.025474545545876026, 0.020886299171252176, 0.039852799600339495, 0.006244322012207704, 0.041702862436068244, 0.028864408959634602, 0.05685933996574022, 0.027786506252596155, 0.02228836456197314, 0.021362748702813406, 0.09004683335660957, 0.03203218097041827, 0.03376863583980594, 0.01599767965672072, 0.07263341423822567, 0.13004646316403523, 0.042955385069944896, 0.04164959478657693, 0.06960006372537464, 0.07511923788115382, 0.03700289686094038, 0.06564136638189666, 0.07609345513628796, 0.033840631585917436, 0.06525475939270109, 0.027337928077031393, 0.07242053659865633, 0.014603619256376987, 0.03649449230579194, 0.0501528631139081, 0.05044601144618355, 0.02157814036763739, 0.03294540110800881, 0.04686498563387431, 0.056875745140132494, 0.0479593232012121, 0.0326508055877639, 0.0686248519923538, 0.026209724455839023, 0.01234683537404635, 0.02368062803725479, 0.05828422639751807, 0.016683602225384675, 0.06678977311821654, 0.020637752058974, 0.022955510794417933, 0.04715534349088557, 0.015531286226178054, 0.07814786091330461, 0.03291269465989899, 0.019336219847900793, 0.02719827629334759, 0.015209024368232349, 0.05131513316882774, 0.02295344205776928, 0.02848491545591969, 0.03079651065490907, 0.03742390239494853, 0.049178549379576, 0.05898461342439987, 0.033482827348052524, 0.04612510892911814, 0.05026385129895061, 0.03879426323692314, 0.02561050328949932, 0.05417468011728488, 0.0279505598518881, 0.04728292980871629, 0.022908506871317513, 0.0471760085929418, 0.015219501638057409, 0.030371169123100117, 0.0645255102426745, 0.03223462772439234, 0.050623870847630315, 0.05721721099689603, 0.018701937769947108, 0.057068710957537405, 0.01579156483785482, 0.021120968121977057, 0.03050439576327335, 0.04388555586047005, 0.045660034666070715, 0.006580716681128251, 0.01968201428098837, 0.017509864919702522, 0.062135230691637844, 0.020761742671311367, 0.02430932545394171, 0.04899561739875935, 0.03736677557753865, 0.034525641312939115, 0.08571437560021877, 0.04179668474534992, 0.025731452951731626, 0.02065676588244969, 0.04182719443633687, 0.021161799231776968, 0.03982804155384656, 0.06935419020010158, 0.02448196755722165, 0.014524397774948739, 0.01528862805571407, 0.034979093543370254, 0.083052165718982, 0.01265027729459689, 0.0055014999088598415, 0.08536113557056524, 0.048272513231495395, 0.0066755645457305945, 0.03319435825687833, 0.04933292722853366, 0.12702976644504815, 0.02496531535143731, 0.04244398594892118, 0.019809769437415525, 0.04037410639284644, 0.006136816355137853, 0.029260303927003406, 0.03956712469516788, 0.020009401596325915, 0.020890327177767176, 0.060318690666463226, 0.05759801439126022, 0.02353139512706548, 0.026667195415939204, 0.052786188607569784, 0.051605795306386426, 0.0395762605330674, 0.057493635031278245, 0.018102237918355968, 0.027501083677634597, 0.021401306985353585, 0.02709306758333696, 0.07862809725338593, 0.023925653658807278, 0.06297636602539569, 0.041636384557932615, 0.04869534444878809, 0.050341190508333966, 0.025035158869286533, 0.010653882418409921, 0.1238210687006358, 0.034324367152294144, 0.020236081327311695, 0.027577484070206992, 0.014463101942965295, 0.02861621993361041, 0.02283301560964901, 0.05094887215818744, 0.030432806343014818, 0.03482345404336229, 0.008921483386075124, 0.016907272547541652, 0.13583885156549513, 0.08863186201779172, 0.15697379247285426, 0.09783731336938217, 0.12116812082240358, 0.0927305655204691, 0.06579683889867738, 0.11407591271563433, 0.1818225294118747, 0.126690783072263, 0.1453279220731929, 0.10199233845924027, 0.10950923315249383, 0.14683908317238092, 0.12736506876535714, 0.11073840039898641, 0.2258660551160574, 0.17646524735027924, 0.17200030881213024, 0.08511164036463015, 0.1853684664820321, 0.1333805319154635, 0.130359812756069, 0.14626492804381996, 0.1399968526675366, 0.08099007129203528, 0.09334808433777653, 0.11156081134686247, 0.14401889231521636, 0.08221126045100391, 0.17872378084575757, 0.11716300214175135, 0.15697780007030815, 0.1266590488376096, 0.20102885115193203, 0.11739460416720249, 0.15492807724513113, 0.2440479162032716, 0.17373387672705576, 0.12067770221619867, 0.1138499955413863, 0.1944041292881593, 0.18444432935211807, 0.15749267244245857, 0.16202458238694817, 0.11280244667432271, 0.22360241564456373, 0.15425760619109496, 0.22142596368212253, 0.1434484776109457, 0.140821571694687, 0.13649731467012316, 0.14540736156050116, 0.13882225553970784, 0.12465560634154826, 0.1378833645139821, 0.1615481384214945, 0.13356106675928459, 0.10147051216335967, 0.15386420855065808, 0.11908704967936501, 0.08809151171590202, 0.1421434702933766, 0.13701828749617562, 0.09982882213080302, 0.22899416304426268, 0.15779459296027198, 0.1137735098018311, 0.12377475126413628, 0.17826360475737602, 0.16137447586515918, 0.10751881534815766, 0.08966423396486789, 0.09552386094583198, 0.0966375129064545, 0.1497735796147026, 0.17274232290219516, 0.11373505913070403, 0.14975181984482333, 0.08427827531704679, 0.16578266979195178, 0.1925843980279751, 0.14648392098024487, 0.2022534393472597, 0.12794063397450373, 0.10608139404212125, 0.17732345208059996, 0.10701421429985203, 0.07567722903331742, 0.14362202142365277, 0.14410628762561828, 0.12875180138507858, 0.11108563645393588, 0.10562355571892112, 0.24161586858099326, 0.13866253051673993, 0.11339773816871457, 0.1775840943446383, 0.10350182230467908, 0.17641815065871924, 0.12070923607097939, 0.13097843737341464, 0.14709795912494883, 0.09026871324749663, 0.181293778878171, 0.09687500758445822, 0.10290455669746734, 0.1351644322858192, 0.13263587577966973, 0.17466123477788642, 0.08037210718612187, 0.18642044597072527, 0.10622452464303933, 0.14971270866226405, 0.10732368245953694, 0.10817797607160173, 0.1296001355512999, 0.1548815000569448, 0.11022981401765719, 0.12167731576482765, 0.11537337981280871, 0.20911031984724104, 0.18128989002434537, 0.18352302722632885, 0.1365814742166549, 0.19428844330832362, 0.21820479043526575, 0.14888105797581375, 0.10092559765325859, 0.18103298818459734, 0.15055210737045854, 0.14646003866801038, 0.11284682710538618, 0.15418210008647293, 0.11173988415976055, 0.24723080947296694, 0.12945964699611068, 0.1464175432920456, 0.16483577841427177, 0.10756746312836185, 0.09525515153654851, 0.15707347774878144, 0.09729481826070696, 0.16029469552449882, 0.20671546866651624, 0.23476029426092282, 0.14940780471079051, 0.16857220995007083, 0.13087474450003356, 0.1397684047697112, 0.18884464167058468, 0.16692293516825885, 0.10873137332964689, 0.13165270822355524, 0.0371044337953208, 0.09350668129627593, 0.09359113028040156, 0.15442418865859509, 0.14025844488060102, 0.1251868059625849, 0.13258251536171883, 0.16515766270458698, 0.1269219323876314, 0.14802556950598955, 0.13440160837490112, 0.07728872849838808, 0.1606103012454696, 0.2673191291978583, 0.24071368417935446, 0.09277320932596922, 0.19592867873143405, 0.15815386665053666, 0.1451954190270044, 0.08207184058846906, 0.1281880066380836, 0.10967689915560186]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.01646311386139132, 0.039041027339408174, 0.028869297857454512, 0.028744114242726937, 0.0441304349078564, 0.04828509634535294, 0.02895127920055529, 0.03943557159800548, 0.07523617066908628, 0.0715822733764071, 0.061766939907101914, 0.060380348295439035, 0.03573933106963523, 0.038282493042061105, 0.013187086624384392, 0.05159521970199421, 0.013401695323409513, 0.03522013939800672, 0.04758264243719168, 0.05242950872343499, 0.037107053576619364, 0.06185678059409838, 0.01976222003577277, 0.0911028501286637, 0.02489081300154794, 0.02724663463595789, 0.01599827708560042, 0.025343287452415098, 0.08790284293354489, 0.016382882131438237, 0.0554097029089462, 0.05903132048842963, 0.07914409769000486, 0.06546902484842576, 0.10824022741871886, 0.05678868379618507, 0.06411205235053785, 0.01739135135721881, 0.008386235349462368, 0.029169552253733855, 0.08741899975575507, 0.05111725804454181, 0.021824292198289186, 0.06020458175044041, 0.0481495690473821, 0.11163200557348318, 0.03730926655407529, 0.01712475892418297, 0.024671840474184137, 0.023154437913035508, 0.04122889724385459, 0.01691012981609674, 0.014097221283009276, 0.027697146106220316, 0.039568705469719134, 0.030206466144591104, 0.02109147702867631, 0.018627363060659263, 0.02360610342293512, 0.01745375855534803, 0.06954595373827033, 0.038670098219881766, 0.0251014734749333, 0.07766654103761539, 0.1099058442923706, 0.05209089271374978, 0.059131773887202144, 0.03353646236064378, 0.04932801421091426, 0.04486351725063287, 0.05240983809926547, 0.00463555550595629, 0.008947745209297864, 0.015433312528330134, 0.04032209297292866, 0.010981125014950521, 0.03661470167571679, 0.09408020559931174, 0.06426066742278636, 0.060634214751189575, 0.06061002073693089, 0.023013270292722154, 0.014915026276867138, 0.07432945916661993, 0.023581618115713354, 0.04868210082349833, 0.10793291148729622, 0.021939072757959366, 0.08358551756828092, 0.010122390576725593, 0.016611406099400483, 0.04901213018456474, 0.026349307590862736, 0.03798155586991925, 0.06026275128533598, 0.05949248363322113, 0.017964871949516237, 0.00261247207163251, 0.026871028130699415, 0.03356581801199354, 0.07493306271499023, 0.006511521150969202, 0.06442617377615534, 0.06655601144302636, 0.0632932705048006, 0.03930876082449686, 0.018004923804255668, 0.025578689273970667, 0.026182422698184382, 0.012649115833482938, 0.026438448803673964, 0.07619307361892425, 0.08164097191183828, 0.02169359813706251, 0.03392334023374133, 0.01306878550167312, 0.049164660085807554, 0.023258509281731676, 0.01692027311946731, 0.06864745781058446, 0.016386268180212937, 0.05711942932975944, 0.006982745962886838, 0.07964449818246067, 0.02366169028391596, 0.038003126392140985, 0.020696121973742265, 0.061405213418765925, 0.03599826268327888, 0.04585619542922359, 0.07072708176565357, 0.05097472858324181, 0.02662476497789612, 0.011354815851518651, 0.017263139779970516, 0.02250685283797793, 0.0747445497836452, 0.034787827244144864, 0.017741654337442014, 0.04174477893684525, 0.019671245718200225, 0.01584326284501003, 0.028752808502758853, 0.02851775920134969, 0.08494412279105745, 0.02452824974170653, 0.06188437735545449, 0.036866924274363555, 0.05126864503836259, 0.05291569708788302, 0.029620598070323467, 0.029694831391680054, 0.057038713348447345, 0.0055739474373694975, 0.06247245517442934, 0.03128441523585934, 0.07424121038638987, 0.0882953277323395, 0.09631785505916923, 0.040903027620515786, 0.01889232276880648, 0.03493742937280331, 0.03511616450850852, 0.04684082501626108, 0.03768833332287613, 0.02339159676921554, 0.04112873699341435, 0.01592783984960988, 0.024053419947449584, 0.029843077245459426, 0.00498272801451094, 0.027840926086355466, 0.046159299672581255, 0.021824540817760862, 0.026883872851612978, 0.05088402329420205, 0.014808226587774698, 0.031195806514006108, 0.043461121604195796, 0.026075659188791178, 0.0383912065444747, 0.031547476901323535, 0.03282216377556324, 0.03131160752673168, 0.05764072870078962, 0.01009878100376227, 0.06266942858928815, 0.11737396504031494, 0.04458904506464023, 0.02576774397311965, 0.009576615175319603, 0.08181656405213289, 0.01577418745000614, 0.04782686839462258, 0.02848157393600559, 0.02924719017755706, 0.006414348972612061, 0.04487329875701107, 0.033596357388887554, 0.07281089885509573, 0.0029574114114439, 0.047082809687708504, 0.019346875233168248, 0.0770477754122112, 0.032297981160809286, 0.020180158644507173, 0.04336456819146406, 0.12005679178400896, 0.05214886929024942, 0.039030414627632126, 0.05422776594059542, 0.03339401082484983, 0.10049138189060614, 0.005397426220952184, 0.026726134929049294, 0.008705541604285827, 0.023701795944361947, 0.08365557630895637, 0.042869993558269925, 0.059077508049085736, 0.06536145054269582, 0.02003322082600789, 0.011912768040929222, 0.005075218632555334, 0.014476545020443154, 0.027891759491467383, 0.025710175577842165, 0.030512464763887692, 0.0840993360907305, 0.018588955063023604, 0.05250425041595008, 0.02489181304554222, 0.08656517369672656, 0.03723079928022344, 0.008736405670788372, 0.007658056283617043, 0.03948459416278638, 0.009939992942236131, 0.06559918270795606, 0.04501985808019526, 0.09606360268662684, 0.05627213045954704, 0.028710476399282925, 0.06222913463716395, 0.02572863464592956, 0.05569339256908279, 0.043002504025935195, 0.12558333546621725, 0.024907255283324048, 0.021362320112530142, 0.020477028847381007, 0.0205693204770796, 0.034852368116844445, 0.01936211709107738, 0.040217067944468, 0.04373148600279819, 0.019778602945734747, 0.06637316851993091, 0.017283322486036923, 0.03936071116186213, 0.010640285345289158, 0.04409538327308837, 0.045644071069546044, 0.02057498862995999, 0.06960698054172099, 0.052473236064543016, 0.01959333134436747, 0.019161317904945463, 0.026369191582489293, 0.024951581908680964, 0.04627905633242335, 0.06608443596633151, 0.0214273749224958, 0.038450095962616615, 0.04073026677360758, 0.04605746958986856, 0.060651462263194844, 0.05199208688281942, 0.013485563576978166, 0.01141820639531943, 0.024158675041690003, 0.06521811956190504, 0.05299645759805571, 0.04157254130404908, 0.015098038966243621, 0.03974216764618177, 0.033631049082032405, 0.06913776509463787, 0.017404656209691893, 0.02403975886409171, 0.010162389553443063, 0.017643228857195936, 0.07466937764547765, 0.05259337864117697, 0.06251279832213186, 0.04035068050143309, 0.01667816970439162, 0.04596214072080329, 0.027290454745525494, 0.0658916705287993, 0.07824527521734126, 0.030823710367258172, 0.040569276388850994, 0.03400851652259007, 0.05757376471592579, 0.03514377982355654, 0.06793139662477188, 0.03654281725175679, 0.041637553440523334, 0.07996902451850474, 0.01636828965274617, 0.025785791149246506, 0.014690489497297676, 0.04717271345725749, 0.040066144792945124, 0.021776624053018168, 0.028024041748722084, 0.027290206126053818, 0.022572506932192482, 0.007646910153198405, 0.08203481484088115, 0.035248968124506064, 0.021342651343729813, 0.039299762283917516, 0.014265731479099486, 0.03178359489538707, 0.02955475287308218, 0.04912987562420312, 0.02290528038429329, 0.02089581721520517, 0.02935194432211574, 0.02783342668408295, 0.03846586660074536, 0.053079210774740204, 0.11116493493318558, 0.036411898690857925, 0.014633597384090535, 0.08790548497927375, 0.015197979355434654, 0.06803453288739547, 0.018499422367312945, 0.06540337446494959, 0.11381231670384295, 0.03317813861940522, 0.0022162229606692563, 0.04213422835164238, 0.09930898479069583, 0.017110956832766533, 0.06706863510771655, 0.04130951303523034, 0.08202133001759648, 0.03788139561947901, 0.12974068347830325, 0.08935197532991879, 0.1272118152701296, 0.2143642949522473, 0.07778201921610162, 0.1373662953847088, 0.10467057873029262, 0.1792473957175389, 0.18152366654248908, 0.10305910895112902, 0.19355821452336386, 0.21362556115491316, 0.12513153080362827, 0.11939269577851519, 0.09207179071381688, 0.15625067346263677, 0.10346010618377477, 0.1393112269579433, 0.11685657678754069, 0.16576619411353022, 0.12947107607033104, 0.11899149074451998, 0.13612156530143693, 0.17231061559868976, 0.10157142940443009, 0.15752554958453402, 0.0890252819226589, 0.18521368416259065, 0.2168295462615788, 0.09379624505527318, 0.18837190844351426, 0.18895548884756863, 0.16871738887857646, 0.17419378564227372, 0.12802748009562492, 0.13947061059297994, 0.19316926976898685, 0.13950368069345132, 0.07759816697216593, 0.06797290494432673, 0.1897045533405617, 0.15861503721680492, 0.09766114235389978, 0.1389999405364506, 0.13814160221954808, 0.22702552727423608, 0.14894820749759674, 0.11928532185265794, 0.07842855600756593, 0.10296824781107716, 0.08711959511856548, 0.11324944221996702, 0.15233949583489448, 0.14111941040027887, 0.17728925391566008, 0.11718444278812967, 0.1648612489225343, 0.10215459420578554, 0.13884177402360365, 0.06282669710344635, 0.16314302862156183, 0.1476879813708365, 0.15678084891987965, 0.14127987757092342, 0.21938194055110216, 0.2793414465850219, 0.09282344530220143, 0.20825613755732775, 0.13014365482376888, 0.18171956384321675, 0.16766324231866747, 0.23919838189613074, 0.09435569823835976, 0.06407486333046108, 0.10244451419566758, 0.23170358093921095, 0.09785284652025439, 0.1441455917665735, 0.13652012828970328, 0.17158181173726916, 0.17867071728687733, 0.21384345571277663, 0.18595114146592095, 0.11762259935494512, 0.11973779444815591, 0.12049506709445268, 0.19707936386112124, 0.13586708286311477, 0.16821492521557957, 0.09264134452678263, 0.08590666606323794, 0.2417821393464692, 0.1260634753271006, 0.12501587450969964, 0.18537033669417724, 0.22731638979166746, 0.14195707248291, 0.19684153521666303, 0.15821598441107199, 0.18576233909698203, 0.14110389951383695, 0.13722853793296963, 0.12834117107558995, 0.12941329245222732, 0.17910328548168764, 0.13629283814225346, 0.13778280350379646, 0.1331454937462695, 0.09014179857331328, 0.14068097923882306, 0.18329967046156526, 0.24434360268060118, 0.14269743900513276, 0.09460779096116312, 0.11532488046213984, 0.07950435843667947, 0.10980324979755096, 0.11847349393065087, 0.14125244779279456, 0.12408502094331197, 0.12239048999617808, 0.1530771460966207, 0.05947018580627628, 0.21446688944706693, 0.19291981909191236, 0.11958470422541723, 0.10411501440103166, 0.1324559940258041, 0.29508557519875467, 0.2184644530643709, 0.19593587756389752, 0.22600394615437835, 0.10360066153225489, 0.20345061260741204, 0.1083999227557797, 0.18472551426384598, 0.16719226056011394, 0.13108385202940553, 0.15459467482287437, 0.10594420062261634, 0.10171790709136985, 0.09001826809253544, 0.10622270638123155, 0.11072294888435863, 0.20682310976553708, 0.11339945252984762, 0.15210047975415364, 0.11883590690558776, 0.1992395776323974, 0.11583069863263518, 0.05796969679067843, 0.1152656644990202, 0.08785338621237315, 0.16880027193110436, 0.10552199280937202, 0.13370747765293345, 0.12981423031305894, 0.2878073923056945, 0.1596258720383048, 0.17480644339229912, 0.1048584608361125, 0.24041955621214584, 0.09945472775143571, 0.19594512472394854, 0.09522484964691103, 0.09295193332945928, 0.24316406284924597, 0.07960656701470725, 0.12117922335164621, 0.1278885648935102, 0.2200503187486902, 0.09766349496203475, 0.22768237249692902, 0.08937846258049831, 0.23587405012222007, 0.24122236703988165], [0.06670302347629331, 0.036512815931928344, 0.00957249254497583, 0.035192416471545584, 0.03570243148715235, 0.026200152606179472, 0.02980905719596194, 0.040470574458595365, 0.028956056776223704, 0.0417213085165713, 0.014285166471381672, 0.048304184383596294, 0.03462296284851618, 0.12046901771100238, 0.023703675433353055, 0.029349305987125263, 0.03509671652864199, 0.09684508419013582, 0.08433939117821865, 0.035045619661104865, 0.005924519446125487, 0.0511858918616781, 0.019278237705293577, 0.05591179178736638, 0.02719457112107193, 0.021199502189119812, 0.05349147009837907, 0.030080918877501972, 0.036726116595673375, 0.070112204994075, 0.06340137915685773, 0.03813532515778206, 0.050790189852705225, 0.05282420141156763, 0.028677690170297865, 0.03950177117076237, 0.06062748347176239, 0.02450341562507674, 0.016686800881871022, 0.020812611328437924, 0.04145497769059148, 0.026853524577745702, 0.026974941793014295, 0.06806767720263451, 0.03212582887499593, 0.05319308962498326, 0.06629010735196061, 0.0691156713583041, 0.02410895671346225, 0.06977947792620398, 0.02540141616918845, 0.030943036581447814, 0.03805010062933434, 0.046203780293581076, 0.09138108129263856, 0.061032699813949876, 0.007854354807932395, 0.04316349441069178, 0.041055516703636386, 0.011750513222068548, 0.010199351290793857, 0.0560990022495389, 0.06443849342758767, 0.012542062886495842, 0.009665849156590411, 0.04808863501239102, 0.01578117848112015, 0.03001949873578269, 0.05335289999493398, 0.07512454423704185, 0.025109399612119887, 0.07246174805914052, 0.03300946700619534, 0.0038322657610478927, 0.04096080010640435, 0.08149295797920786, 0.022557214979315177, 0.03270653716754168, 0.04189260733255651, 0.03062704865442356, 0.02963999409985263, 0.06478279799921438, 0.0614035361650167, 0.03704920316522475, 0.026393639782327227, 0.003361898129696783, 0.022646495344815776, 0.02343709784327075, 0.0898313730431255, 0.04332914177211933, 0.05848136679560412, 0.03575150229153223, 0.03419567503442522, 0.08150794936227612, 0.06473438028478995, 0.1115223384113051, 0.04231485596392304, 0.03299431977211498, 0.043506333240657113, 0.0370598381414311, 0.08652114949654788, 0.08076568294200115, 0.024180401414923836, 0.023670410519116558, 0.04687742402893491, 0.02992467452713754, 0.024355372006539255, 0.016419913445133716, 0.026839375532290433, 0.16068635653937235, 0.02356312565098051, 0.07127322081942111, 0.01883745764644118, 0.01660286583501147, 0.05079320297227241, 0.05261876380245667, 0.12890039419289678, 0.07811196323018521, 0.028245981011423282, 0.03646833160019014, 0.00886622956386418, 0.014084960075706476, 0.0578338355262531, 0.03285833234258462, 0.038873654484632425, 0.014089650449022884, 0.008005728814168833, 0.033590746752452105, 0.021546428397414275, 0.04174199217231944, 0.0561176375776995, 0.054286057929857634, 0.05656907487718854, 0.05429036609712057, 0.05571090354351327, 0.09882952770567499, 0.0821943765913602, 0.048963708759401925, 0.06332618475425988, 0.05547868553549051, 0.03570742985175457, 0.04830589132325258, 0.008488635030516889, 0.02739466155617265, 0.020894941480946727, 0.034467976438463666, 0.030523125715262722, 0.05404620693298057, 0.058534474883344956, 0.07904726226115599, 0.03146120965539012, 0.01987407282285858, 0.007429850511471159, 0.04471495783946011, 0.012212750625621993, 0.02463330816681264, 0.0561355864192592, 0.011960537303821184, 0.005966344569969806, 0.02922411309555173, 0.008833311603666516, 0.045397585272439755, 0.040200217481469736, 0.06386842753272504, 0.014939118245820282, 0.05457945117086638, 0.10508667124668136, 0.020666983400587924, 0.043666032288456336, 0.09738719338201918, 0.08286210912046954, 0.04205511912005022, 0.08508197672199458, 0.053589125600410625, 0.015838331273698714, 0.052375999875948764, 0.05538130091736093, 0.0357179349521175, 0.030595678072131705, 0.008070601797953714, 0.023055160818330478, 0.011207673942408292, 0.05995422565320041, 0.049714658307493664, 0.04060768253111746, 0.08807683203485794, 0.020233593277225737, 0.04444104226422496, 0.059100273429066874, 0.047113942782743834, 0.027570248130359687, 0.028089925908716395, 0.06913706747582182, 0.030739402391191106, 0.0544868014549138, 0.05404202493082266, 0.019965115789091215, 0.01700606539088767, 0.02657551049196627, 0.049764716168283485, 0.05097373781609349, 0.028851740498794243, 0.04782614480063785, 0.012234702426212607, 0.039571380912093446, 0.030272658295871224, 0.03357817477080971, 0.019877577615261544, 0.04138428070291411, 0.03883091419993434, 0.027138882214785554, 0.02202003921411233, 0.06885240189149044, 0.043402811061241664, 0.022693566061207093, 0.06569828910869546, 0.04361080536909867, 0.02250778237794293, 0.02488538419129327, 0.06331289288937114, 0.03430078912060708, 0.06581220135558397, 0.03139431246381719, 0.04747860075440258, 0.05373069769120775, 0.01574937930854503, 0.05000332777854055, 0.01600290066562593, 0.03532190268742852, 0.03546116298821289, 0.04375952063128352, 0.015713468637841288, 0.021490377694135532, 0.022293143993010744, 0.021528930410568137, 0.05300809447362553, 0.007801712417858653, 0.009378392169310246, 0.054559045820496976, 0.0059837173193955095, 0.024305121187353507, 0.035832374123856425, 0.07082091149641201, 0.0021809032250530436, 0.00683733001096698, 0.05516309094673488, 0.030765622468607035, 0.05863855367351789, 0.07127713935915381, 0.024086842568067368, 0.023417197153321467, 0.017568014045536984, 0.029124958455213346, 0.043795763413072564, 0.01825251540140016, 0.027042479086958338, 0.062160307861631736, 0.009767038209247403, 0.015333796090999385, 0.018093957405653782, 0.021494097709364723, 0.02390489578829147, 0.014177522589307046, 0.026181687971984502, 0.06253317769733258, 0.07079227943904698, 0.03408044547541067, 0.06661501960479654, 0.04614749952452257, 0.0449652508541476, 0.06112041424785275, 0.09051559609360993, 0.022853010923427064, 0.06811760147684254, 0.018444167617417406, 0.02569333439168986, 0.028099610935896635, 0.027371439755370375, 0.03476187433989253, 0.037753608921775594, 0.07371314262854867, 0.013326763455552282, 0.014221883538994007, 0.017438765316910576, 0.05461036162159871, 0.06240798480575904, 0.04514001921052113, 0.054597195921815, 0.06446987885283306, 0.010963157619698904, 0.02214569780335296, 0.06894900725455955, 0.06807465339079499, 0.03826879299595021, 0.046854614120093174, 0.0501385433744872, 0.0329798182065133, 0.04777334470418282, 0.04907912756607402, 0.05415047497081105, 0.03154078272928018, 0.03642516829131637, 0.0456712373852497, 0.0399102306982968, 0.01868630999524612, 0.05318094808899332, 0.05482817825395614, 0.019363182072993368, 0.02741275882726768, 0.03242296625103336, 0.010662060885806568, 0.04876258302829228, 0.012604174153239, 0.10226440979749896, 0.0030922962878321414, 0.08063022614805959, 0.0005530118630758807, 0.02599077419290552, 0.059196889924351126, 0.025445336468692403, 0.028381087140587624, 0.0021153405077711795, 0.03241632031858899, 0.052889643993694335, 0.03138909145491198, 0.1144935488991905, 0.016702361863281112, 0.05279879769659601, 0.024796215147944167, 0.008602616853750078, 0.04874827071034815, 0.06540765665704384, 0.013655020939040696, 0.07712909995461814, 0.08925785616156645, 0.02852813071513083, 0.054986975592328236, 0.020266776555217803, 0.036943157683708705, 0.042438345626578666, 0.032578609461779706, 0.08844548647175543, 0.020379000416141935, 0.023407317312376108, 0.06969896232476458, 0.03715236540301703, 0.12123990876716562, 0.04924185457639396, 0.09314921844634227, 0.08906399976694956, 0.049198535416508093, 0.04923001732095145, 0.23205813457025215, 0.15836123755434528, 0.12040462155709974, 0.08712315742741339, 0.12501954071922228, 0.1352113953907974, 0.10325865761842579, 0.1325475750491023, 0.1098053871828597, 0.16751016693888232, 0.12482775491662323, 0.1053754186432343, 0.1497705516521819, 0.22247409884585068, 0.17755267181200907, 0.10896543186390772, 0.25657446356490254, 0.15306668181438, 0.1843407255364582, 0.16928470140555874, 0.16440580773632973, 0.14971716154832393, 0.18843064201064408, 0.12064183421898633, 0.14980788168031722, 0.18822097044903785, 0.16691981814801693, 0.1026049887877889, 0.13037182070547715, 0.1535694720223546, 0.12897546985186636, 0.12091357901226729, 0.1268332457402721, 0.11423030169680715, 0.13092998997308314, 0.1199960766825825, 0.16181122977286577, 0.13968143990496174, 0.16430563264293596, 0.2545093634398654, 0.07876807372667827, 0.14545401296345517, 0.08209287305362523, 0.12198259821161628, 0.16143080487381667, 0.20763307489687577, 0.29747374705038965, 0.1263189225574024, 0.09698129797470756, 0.2466982146142982, 0.10586824922938831, 0.07738445812719874, 0.14599898684537038, 0.22519803314935416, 0.1771849227952771, 0.06018649561156053, 0.10691428411519155, 0.16619276575511321, 0.14189854671712965, 0.15500005072681233, 0.146675291180145, 0.10814845343702473, 0.19710415159352124, 0.12226003527757712, 0.0994735857238993, 0.15871962066739798, 0.2371671682340093, 0.07484557834686711, 0.13358900119783357, 0.16121571563417092, 0.08677644829731435, 0.11499981977976859, 0.152741071942728, 0.13691455009393394, 0.16097232088213786, 0.1499938193592243, 0.08182403005775996, 0.10602628957713023, 0.22614373709075153, 0.08404835054534487, 0.168828725873027, 0.12501710647484288, 0.2070297978934832, 0.1436997391283512, 0.08824810487567447, 0.09445254851016216, 0.22000806085998192, 0.0853303364419844, 0.19168556813383475, 0.2420525037450716, 0.19009648152859882, 0.19998692034278065, 0.10232782631646842, 0.10611459030769765, 0.21603636851068586, 0.26056139962747693, 0.12216947841807269, 0.28150733036454767, 0.17291087948251516, 0.08576356514822692, 0.1199784358323086, 0.15771274891449139, 0.1954701353679411, 0.13229205360403284, 0.187092742708046, 0.12029812336550094, 0.11000718455761671, 0.1422312663635239, 0.13189496006816626, 0.2795328909996897, 0.1378973020473495, 0.11709246100508608, 0.230422752792947, 0.06194827627041377, 0.1790501773939468, 0.15928090695524588, 0.1909091480774805, 0.1481856359168887, 0.21341856132494286, 0.14121430140221491, 0.2642507938435301, 0.13179609115468338, 0.12085089721949771, 0.13088937965221703, 0.1380741409957409, 0.12143928674049675, 0.1336075845756568, 0.11709475424140692, 0.14985529007390141, 0.19488116697175428, 0.13872929412173107, 0.19444019766524434, 0.18034406733931974, 0.22721936140442267, 0.16148734168382362, 0.15338053606683388, 0.18937079468742013, 0.15492858190555125, 0.2138243379886262, 0.2106401088531129, 0.1091706653824076, 0.08995156385935843, 0.17059383506421, 0.0739994557807222, 0.12754747382132336, 0.17881928040878847, 0.10039344808319584, 0.302833003224805, 0.10922870875219814, 0.1480784104205668, 0.08150090638082474, 0.10667537193512544, 0.14360187953570858, 0.10881473877816461, 0.11325731640681624, 0.14904845680575818, 0.12400539591908455, 0.11717729590600356, 0.17047178145730868, 0.11819868406746536, 0.08277244283817708, 0.26060435513500124, 0.19337500794790685, 0.15817838720977306, 0.10180726167163812, 0.1811583517701365, 0.15000400162534788, 0.09721167545649223, 0.21587830589851364, 0.1816120118019171, 0.19329234753968194, 0.14199814293533564, 0.2161755063571036, 0.15287697402527556, 0.11270757793681696, 0.16366655443562195], [0.06284887989750132, 0.056408177260891534, 0.019578920691856183, 0.06075564495404251, 0.05464707195642404, 0.010195582108281087, 0.048982277294271626, 0.06125549254647922, 0.055369278124999255, 0.016718156621209346, 0.03179812614689581, 0.023117963210097514, 0.021360017599363346, 0.0565594343788689, 0.136428517580498, 0.01712785924610216, 0.06728466687491164, 0.04379878024337813, 0.06543074487126432, 0.05236081182374619, 0.045059841286274604, 0.06019173517415766, 0.026555248005024623, 0.0833073235116899, 0.02283942962094443, 0.049037359494832344, 0.04534980580501724, 0.06498009053757414, 0.015387895873573143, 0.0529113184165908, 0.04484614357352257, 0.03784664826525841, 0.03633327185525559, 0.03037831229448784, 0.046038388973101974, 0.03569172229617834, 0.0456612554989988, 0.019486289529595524, 0.01952080496266717, 0.027577979453781154, 0.03553223104972858, 0.02269095555675449, 0.0454188886214979, 0.06295792365563102, 0.010255251709168078, 0.08288421027828008, 0.0619163342344109, 0.06765008554793894, 0.03478980877844151, 0.10282015224220231, 0.0225923556718044, 0.03333098764414899, 0.022900593721715268, 0.023980607838893775, 0.02385856907494599, 0.033897045941557735, 0.01767972767993342, 0.041346724319737405, 0.03133743426587898, 0.07177542473073117, 0.016701701351848897, 0.009114407457673224, 0.03275997551099863, 0.04425770210218616, 0.02843887261406053, 0.06601647750358097, 0.026447022464708425, 0.03786003289860673, 0.07869045250117779, 0.09057265240699053, 0.023996951786102727, 0.005072224530522362, 0.023960044782143086, 0.02429540461889701, 0.01938107339810813, 0.04857066734984983, 0.02126723986293655, 0.04942280131217558, 0.06844709278084338, 0.025956935969588812, 0.02314363038749434, 0.02672380087460624, 0.05242690378508996, 0.08334178884979337, 0.03450356984103564, 0.09298147822846659, 0.045706719465670176, 0.01679425829934189, 0.06069751252653077, 0.031033676932565868, 0.020621595504053403, 0.04566171563055832, 0.01439938763724058, 0.023727800798951648, 0.04455720692931209, 0.026105070501216687, 0.06305124130449258, 0.05399473157012835, 0.019232261656725314, 0.043581523932516575, 0.019470097722660284, 0.06418451564968564, 0.05596884810074698, 0.061288013457669877, 0.06193803463247605, 0.008178327316272771, 0.012892258255305933, 0.11159542511450127, 0.02579465424787486, 0.03080018243053928, 0.03499365448078606, 0.018965051385748666, 0.06447123698308133, 0.048732689319876954, 0.02411633922747569, 0.041846115491352975, 0.012404828648868715, 0.02156241054763086, 0.04088969864824321, 0.07237495388835669, 0.017324660111626144, 0.04503555450355634, 0.017473969091952313, 0.039760832660249434, 0.09314503273344599, 0.02784750522550894, 0.014269513649196597, 0.022121520487417, 0.03004969115863787, 0.06601724191568792, 0.04354869503004011, 0.038918376303627156, 0.024868691434676293, 0.029947701514174696, 0.08136075921356678, 0.03280450437159743, 0.01198139072585036, 0.015666848776163533, 0.030645468759757932, 0.06736124909366481, 0.04538866465736646, 0.06503990764031187, 0.06351356962113641, 0.06807148442021571, 0.13299143873155117, 0.051718108225031756, 0.08791648360784166, 0.044853279323433526, 0.021518850189750083, 0.01518011307780398, 0.023881640590843745, 0.02883033510443056, 0.0384209295589244, 0.05442643516289536, 0.06132595946837682, 0.05681666276359465, 0.0970320831402205, 0.05909892272029538, 0.024052113767538685, 0.03957790810090955, 0.040966451560962014, 0.006480775364252622, 0.05288701308018062, 0.03962825168855488, 0.03188582573784515, 0.039411659599863924, 0.044458534684963524, 0.023917272956168745, 0.06576176499947906, 0.01556205474116723, 0.018500004953239113, 0.023010149561741855, 0.03916384535841644, 0.051417156209936365, 0.08378781960345805, 0.04341053310781717, 0.06491657011792995, 0.06833911771536805, 0.02153503828594694, 0.05210039220401086, 0.008340890126419254, 0.011806007314589806, 0.029269154038047418, 0.012653409157792339, 0.024010017295950092, 0.009905767874442972, 0.012813116554752924, 0.022481612395495176, 0.06916748810908757, 0.06298311214777641, 0.04413706970808562, 0.013454100226226728, 0.08370322961127385, 0.08009289638721384, 0.06011699348164257, 0.0878798883059062, 0.011578742214624071, 0.03629038685176056, 0.0596081065305043, 0.07780162675771862, 0.015000699804659234, 0.034112662106053904, 0.04285457544028759, 0.027421646045695525, 0.05800564271339681, 0.061962636827956885, 0.021287986601237208, 0.03762650128919631, 0.07801785148330964, 0.01981543387955753, 0.052254309921409, 0.035466009212541394, 0.03424193309911061, 0.05047092534368858, 0.041883297089952976, 0.04038939092424698, 0.03689719276735559, 0.04086049513716716, 0.013319666668394348, 0.03099760113400407, 0.009132924969890155, 0.05642800373607315, 0.02579741874797037, 0.04791706902324222, 0.04983617014659103, 0.0901324994629249, 0.030321411832119338, 0.03128539116005413, 0.021916819459875114, 0.06919792358530685, 0.09556102770147845, 0.05954944346740376, 0.0511326205014484, 0.056105859694071114, 0.031755808886373416, 0.05235897500824649, 0.06845285926829092, 0.008956349483923987, 0.039166194255813025, 0.09553288546158001, 0.016764472202339675, 0.02378704088187078, 0.05172509925614577, 0.04421720681420993, 0.030129570368444547, 0.017969389773497824, 0.0342453877965454, 0.018364286552241538, 0.019128752464894205, 0.04731828943477012, 0.02959901641588658, 0.04325115318351891, 0.06967555498704314, 0.020086790900677443, 0.033883709547808394, 0.018638957262737677, 0.024297315649164375, 0.01388213575410191, 0.013289272010297282, 0.01749530027154833, 0.07702113973209634, 0.056306124533875845, 0.028296638156461995, 0.004847232721658656, 0.046666654088767245, 0.025928923605533782, 0.028183334470668342, 0.06568248136318289, 0.06526338314870372, 0.0390487902041059, 0.03387831042346079, 0.035729608935071155, 0.09132149425568059, 0.05349312508769799, 0.018920619004347827, 0.019107853586319834, 0.05940968592767604, 0.04186356338323094, 0.05532595154363662, 0.008236261219281005, 0.028553063166327775, 0.01928368135850178, 0.06420300996978767, 0.10762209261883982, 0.05346838188415859, 0.06644442211836576, 0.009074569898075424, 0.06015592654875945, 0.06698673911159858, 0.026299969613319263, 0.03652179962955415, 0.016413230405305512, 0.0204289599423646, 0.04714654161944054, 0.031055236322572455, 0.03618451206421014, 0.055512520048068836, 0.04771287822222803, 0.060452874677139334, 0.010808561764861224, 0.0784348494198639, 0.03713326252182014, 0.033113159879576415, 0.012417222515068715, 0.07970582926645875, 0.0249802566395374, 0.059525854303501546, 0.05455885286210105, 0.05770031944848597, 0.014683861190860625, 0.05571491856244393, 0.020276684226701036, 0.08039118038141169, 0.06017071755195502, 0.06343755885609426, 0.03141169356240425, 0.050975604317500256, 0.044502005985123105, 0.05183487774047535, 0.03756857666303404, 0.06637665661401115, 0.060106640521553345, 0.019892635791620705, 0.07146505115088075, 0.017858681749203242, 0.029705102715524845, 0.024024075428314973, 0.05258354889519978, 0.01412480134604266, 0.056472165233572014, 0.0213790611087461, 0.035739935919991694, 0.04243048999342136, 0.02426443108561216, 0.02341882987821009, 0.03448421091889031, 0.045686084049521014, 0.02058762554952409, 0.04807152479770593, 0.11345650884322822, 0.014360783898155205, 0.029273913060023915, 0.029076934079057537, 0.042875811996054836, 0.021671890317520592, 0.06325306836515665, 0.04048539143695962, 0.002248948426313291, 0.04481911826587748, 0.012669571278820513, 0.05594331079919357, 0.0237363985797856, 0.1403901760932058, 0.19236203574109823, 0.13668411324033514, 0.11736755288438872, 0.2483674234827049, 0.11653598383418284, 0.13669340492924675, 0.13946985360234976, 0.14293600979726762, 0.11628438092884608, 0.17064390034647658, 0.056805549102136865, 0.13078884832793847, 0.16697061073500663, 0.18538087519118562, 0.09233511955244467, 0.22622531396336854, 0.18917857843916863, 0.20308109727920964, 0.1579026348190382, 0.15557282546069473, 0.13421682844636962, 0.11630749140749685, 0.2058755949838087, 0.10684490072890185, 0.10398896061815321, 0.09685021243058145, 0.11445733951404691, 0.10171277885092422, 0.12032224316499196, 0.21152586210519075, 0.1370446040527895, 0.17367664229823276, 0.14771499554626644, 0.10101161256898195, 0.11021368714864366, 0.20919073896948248, 0.18841382494429126, 0.1099990209331736, 0.0927219120785594, 0.20128192350966856, 0.11986888741375878, 0.11926276798476465, 0.16212119517149404, 0.07262391474796459, 0.2105831861263141, 0.21365616732509807, 0.16261929500615224, 0.09978683141525835, 0.19022809399757534, 0.08217214926844463, 0.1311285441624932, 0.1517342744045891, 0.16126049682497978, 0.18974090373376384, 0.18227547698188573, 0.07631593616679311, 0.11260004073847085, 0.08878124150214717, 0.14120395586360246, 0.11140682312543504, 0.09549914000672288, 0.15570663468679413, 0.2296255822875537, 0.0940531691594515, 0.2733231335878372, 0.15908791887341067, 0.06943223444977775, 0.13002707826672122, 0.1733445905847475, 0.24306602514116094, 0.12701526487944648, 0.08287341202958487, 0.12852298241341487, 0.07155557090300135, 0.16930236452026293, 0.16413872363045812, 0.12598869652720168, 0.1338108885101974, 0.11394296438083984, 0.10093919379869476, 0.14665574301034212, 0.09020086610689759, 0.196773020143155, 0.16868327977135777, 0.16769626789027825, 0.14196672040270641, 0.12690333416685462, 0.12138263860833831, 0.07047857361612841, 0.1276787745882757, 0.13168494711862877, 0.16300337127177045, 0.16157475183717906, 0.17521472851512954, 0.09965913748601452, 0.17396413546521217, 0.12074357524397783, 0.12311097438214347, 0.20914891152642667, 0.22546816006070003, 0.17574558674823493, 0.1514240269898437, 0.11107720565632917, 0.10860692258575, 0.10667733862646855, 0.08959893981227651, 0.26425901683978736, 0.16934437007876113, 0.11009470603312366, 0.2154907860676758, 0.09059875374077819, 0.11654430330963805, 0.14375943748746067, 0.21559617103775963, 0.098238117643632, 0.11981540083070286, 0.10275929613271728, 0.13091026368783787, 0.22536893491633236, 0.16821244644233957, 0.2721315115923062, 0.1462763868039474, 0.17326911416603252, 0.25761501397937536, 0.11319528028252535, 0.1401473008445464, 0.12645371141843498, 0.0981724524172023, 0.18978663487359881, 0.1596538510057144, 0.1194616561406292, 0.2168277502642013, 0.21388831111835316, 0.18579370225779712, 0.10200587523286231, 0.3508131770649925, 0.1200853793125134, 0.15683907782658935, 0.17863467859569937, 0.14269264473114163, 0.117194728954928, 0.148819430032745, 0.14522094890708104, 0.1969596405979246, 0.18081697868183255, 0.16742523555876687, 0.11328851629514247, 0.08172743953764439, 0.09839448073762469, 0.06771831860532984, 0.12193248097901233, 0.07604874073877, 0.1619406306417659, 0.11185577051946893, 0.14263060118537396, 0.1938945855363272, 0.13574709242675453, 0.11829194976598956, 0.09204240166582167, 0.14219867123756558, 0.09308017644798383, 0.14949963806429878, 0.2787744457600638, 0.05619686555291992, 0.10534239307162352, 0.19786302727879956, 0.11100526186055504, 0.13088014733511955, 0.11928400825127028, 0.1104093469621148, 0.11903861712198704, 0.0812830266659148, 0.13315030286321416, 0.1390465919394046, 0.1860719927935861], [0.017990906490013003, 0.03469991614110768, 0.04264904135197867, 0.006098500662119477, 0.05995195097057149, 0.027134909869346302, 0.010779964959510835, 0.02255864361359272, 0.03974934421421494, 0.042264004005119205, 0.061988044253666885, 0.08037097912165336, 0.03387022472452372, 0.05289120621455368, 0.07346581449382938, 0.06067708491173107, 0.026627136139723007, 0.02993584013893269, 0.038707209314452484, 0.023612554541614372, 0.01917811641760636, 0.02407392177701695, 0.06388769368641078, 0.016740840364946052, 0.027127519933856092, 0.08534087493899278, 0.022128993914520834, 0.022646951765636913, 0.05155511033080984, 0.029774660506518558, 0.043188423151150346, 0.04455211579625029, 0.012182081372884568, 0.02018599749135319, 0.02055148666840978, 0.05306336963258218, 0.010351498985983199, 0.01877311158750672, 0.03212065981642809, 0.06531537059345283, 0.06085582746891305, 0.07967583907884546, 0.02912814041337697, 0.07552933384431526, 0.03461686610535253, 0.05375487315177452, 0.06433123082388192, 0.07819664970156737, 0.02429121519526234, 0.01849048876465531, 0.0196641025468125, 0.053263671579770744, 0.0043490999541973, 0.06984559586271644, 0.04323197979829274, 0.052504588093142956, 0.05626046018733177, 0.041417105894652195, 0.037983147776685655, 0.02093280400004005, 0.010310708694305504, 0.03975075429480057, 0.01904986216686666, 0.04026770839118399, 0.025497863825876266, 0.03042457035917323, 0.035649931960506365, 0.025749915730557404, 0.01246888619789388, 0.028578771161846817, 0.023288827869691886, 0.051975863534607925, 0.0258550873331842, 0.044532222527777776, 0.04068970098160207, 0.04020833657705225, 0.0018194281392425182, 0.02935441938461736, 0.02989753604197176, 0.02212643164966721, 0.032158390604308806, 0.026989307916664984, 0.02995213399117347, 0.017766453202057164, 0.030965367805038113, 0.06110954920586664, 0.03048217586183455, 0.06349331641104072, 0.11276858989731409, 0.05162325433047954, 0.030922751830075867, 0.014234369245968992, 0.04642148189304862, 0.04192195185169112, 0.07516547368140891, 0.035441303116385825, 0.07880429795477539, 0.02086627788230544, 0.050299507784075104, 0.019713121400855016, 0.09969486447516829, 0.01453238699468784, 0.03342514391988516, 0.03635106855654158, 0.00653861325190519, 0.05553553404752165, 0.04674439776863437, 0.019756588990276214, 0.06601362765650265, 0.04461051539692562, 0.013775585612165742, 0.0408349912322592, 0.049915494601009414, 0.005004974354960723, 0.03679986381030176, 0.03697722597280517, 0.027685440581990406, 0.07002113605267368, 0.05006233222957235, 0.060490757605293766, 0.05994340142933652, 0.06219741153472569, 0.007116514834706322, 0.03266178937337827, 0.009977048375731101, 0.029477558382495772, 0.037705870272475295, 0.013942914865765488, 0.057995824099634774, 0.07044483558274806, 0.03691915291710757, 0.01656103653658647, 0.04888764975476079, 0.02843548842065502, 0.0027397418170949095, 0.03879606294503901, 0.007032116409391165, 0.03233008646930102, 0.08964803288108669, 0.024978380861284677, 0.0219273134280229, 0.053590710085700266, 0.044955825578654185, 0.03666287819214631, 0.019735615896934178, 0.04043927066959441, 0.07746461749775335, 0.02633973017509561, 0.05880521406652406, 0.008088782560662366, 0.010222052660537884, 0.05635302826703992, 0.16412874916568398, 0.021498101596080232, 0.04701055418991018, 0.043855428375536576, 0.044068658535252325, 0.033507422122056596, 0.006133651559139253, 0.035821323544951156, 0.07430729121551849, 0.026744395472633187, 0.05226749417488463, 0.030856967860017903, 0.05313028166710865, 0.04687301938247401, 0.023192087064671796, 0.04364347842056304, 0.06382657040376216, 0.07119628979125991, 0.08511401523719542, 0.022120754219940864, 0.08207048987969756, 0.053594049750245176, 0.03839244964183308, 0.09005290412460454, 0.08334006706718355, 0.03879848234646488, 0.010101474999828497, 0.025486779850325547, 0.0032556937821937026, 0.03748393472051248, 0.05618288349069189, 0.039841830657678656, 0.07584413804579526, 0.10225912570604123, 0.011742939605028369, 0.02943798706837697, 0.04563533228065353, 0.026141971939068753, 0.026564120380498935, 0.04316706785175484, 0.034323658401262946, 0.01889498336822726, 0.01995672024349915, 0.03955169544497039, 0.01876426518720109, 0.04422686957695987, 0.0541000460361829, 0.0852818667772226, 0.12896978500066325, 0.05830881746078376, 0.051472628038027324, 0.01914412419864675, 0.029239534924272448, 0.04213093692669645, 0.05355125751520973, 0.11712361636455171, 0.014616321113862796, 0.07839833575417288, 0.05856902185769286, 0.03427260606258642, 0.021454452180478256, 0.024366919824387878, 0.008207934370147996, 0.032113141860463656, 0.018521497549954802, 0.03446582421020139, 0.027878944456460886, 0.04527362805674784, 0.03752133525267709, 0.016343618808605243, 0.04768203085404821, 0.06499040639027953, 0.0421706529596122, 0.03086638756940374, 0.02905714100052137, 0.03639670321717858, 0.04719766446214635, 0.04089754314918537, 0.04944661312038079, 0.06481033909949474, 0.04080339800566435, 0.06594869715627283, 0.030267633956100326, 0.04993844180717133, 0.01435136140571558, 0.07533502473961562, 0.02922916155512212, 0.05182284010516014, 0.01719048166705761, 0.05248082823527511, 0.03783696694881655, 0.04777685877343174, 0.04827478791412432, 0.02665843621798558, 0.04730507549538743, 0.023602388973813504, 0.043424478062661365, 0.05177473038202152, 0.015571640506095719, 0.05388762852817308, 0.02943950104963733, 0.04542703740298748, 0.020130967241129838, 0.0422351010638522, 0.047651409840909764, 0.04773055617988575, 0.0012984459203835286, 0.03988546894106548, 0.006640083392994711, 0.03746845351997763, 0.021242619113763794, 0.06306434763246216, 0.017876038727990817, 0.015089368826011196, 0.043227233763900585, 0.004019989928565337, 0.011521420583449071, 0.006097604518799926, 0.0837397358554881, 0.031183579631033354, 0.01894817680295091, 0.06243062030989677, 0.04463465746084694, 0.03012395231053233, 0.016424845016445033, 0.03663699950266164, 0.04509037695243023, 0.013530373526009498, 0.034967467800015584, 0.03155937352858018, 0.037530819899984635, 0.04906825881334953, 0.015337363965954864, 0.01629363887332147, 0.04828931545489468, 0.06843041672254913, 0.04906200621917378, 0.05167894509213511, 0.034467412406229414, 0.020858125390077475, 0.027430084264778998, 0.026216001169814263, 0.031030327991175, 0.018920891743618995, 0.014109664316492854, 0.045860344034736045, 0.008537313424312742, 0.057365944812772796, 0.04000007138529327, 0.033458659308962524, 0.036451744599617086, 0.021992512956785504, 0.02804584048135439, 0.040364629167015664, 0.0752427832048852, 0.04266381009074394, 0.016051904676714912, 0.04064972890773788, 0.030556683777831495, 0.01454640338124591, 0.010218714851362165, 0.055615274104638956, 0.01860758853581501, 0.016700630803825334, 0.07008574000792578, 0.07915338937891647, 0.13555416371673346, 0.05845783700351603, 0.04057552898302674, 0.07239815342472866, 0.03245440362661611, 0.005205020725043141, 0.03135120110528078, 0.0043117685345350765, 0.03984725946793333, 0.05596040988166351, 0.0031931240073390654, 0.023552607563033234, 0.019818168693745974, 0.035182868741685525, 0.0675349636003375, 0.027812232801807113, 0.049269673982053064, 0.05105680269480217, 0.04868510652158875, 0.011055905670218635, 0.027326326453476213, 0.02457224796671653, 0.01639425925532123, 0.03234316682210192, 0.03064823325985344, 0.05074963148217648, 0.07566688349470496, 0.022518530531669967, 0.04208050428132992, 0.02226946391601814, 0.0731812824960798, 0.029491547866200563, 0.040263103364850394, 0.04093206785910297, 0.12724194646580145, 0.08265293479780667, 0.10112720206961967, 0.10755652387160808, 0.17627136869123206, 0.1744448542012833, 0.1515204319730401, 0.12479361612349749, 0.14571680745575577, 0.16390266129747033, 0.17315274541033432, 0.14683301240438595, 0.12657331593800336, 0.1460468108416535, 0.13372637273278087, 0.15317960700485855, 0.137985632463824, 0.15313246578443795, 0.12278610665816814, 0.11581748840399086, 0.09515251251286827, 0.13037686730967835, 0.13041225291090086, 0.20530653098830953, 0.23093560652341694, 0.15244482143316418, 0.1372336587519385, 0.10295252912328579, 0.1323969487566501, 0.15786713047418743, 0.10709175388910808, 0.1529977362952195, 0.12326365642366, 0.14543722558300942, 0.14768565102713183, 0.10731378963100724, 0.11648881292785518, 0.0695965088380035, 0.11119112532469444, 0.15814948797924444, 0.13155167223885655, 0.1167695970798377, 0.04928907743305899, 0.14999800507212058, 0.17002870445139706, 0.1038246120151598, 0.09356486567412503, 0.17835635837400332, 0.1561415777541697, 0.08719086355995387, 0.09298091419623233, 0.1608505641343072, 0.1088063970382791, 0.1270267236395739, 0.10499506053747609, 0.11348109619575553, 0.12898554821731523, 0.20509625086560845, 0.08658045451738872, 0.23251117119798437, 0.09927230785251595, 0.10310611658496782, 0.09819099126616493, 0.18258410651469603, 0.07673515312490053, 0.11403560667531565, 0.07346943617449142, 0.16145247558597475, 0.05734012178436387, 0.13288583111716434, 0.18768862792057917, 0.15437587484484538, 0.14229613007046282, 0.11982095951680094, 0.12204579950775951, 0.10443732913699932, 0.15194571227766573, 0.07508449052693322, 0.1544470913358964, 0.09356476919492707, 0.1736743564833887, 0.15559464460238814, 0.1455585370422341, 0.1252206033677794, 0.10979726066580042, 0.13919561519287527, 0.08317942920257337, 0.1737956827855669, 0.21042579144705087, 0.10375089448643848, 0.1216260036744643, 0.09509478826657869, 0.08690383052453399, 0.1806977452361025, 0.19038257945794612, 0.1305901605519466, 0.12825217272620648, 0.10241940733976662, 0.0856217481486965, 0.1540538718109019, 0.1923017733497545, 0.09464423783356324, 0.1376035006251186, 0.12953570229001343, 0.13447494740830734, 0.11892319089383818, 0.13647372921695933, 0.25552292936481535, 0.11330025707138702, 0.16253345820587128, 0.12010874212137423, 0.1897161011584103, 0.20332833635620773, 0.13983904238557443, 0.14654679573141038, 0.11773335005273111, 0.13693619112018496, 0.2519898908212781, 0.11817482401966117, 0.13136701105395332, 0.13867140660295263, 0.2318426890997216, 0.12956028222106397, 0.16914320352952927, 0.1735031875432469, 0.166344549797941, 0.09779429849004373, 0.1020720525411889, 0.24393699481151998, 0.23907503695227206, 0.18322331830859184, 0.18285455997101963, 0.11318965480313636, 0.08692263654666021, 0.08524588745785877, 0.17378394200932235, 0.13485271541867405, 0.15477512060897425, 0.16221665020566434, 0.1362097472883761, 0.09849919035332277, 0.12334011247730814, 0.2630593202775344, 0.13729602884268388, 0.10346926428610459, 0.1829648282728158, 0.12231565924594179, 0.15264242567354813, 0.10988916081259958, 0.06808587466366589, 0.12909627665067092, 0.12067932009813376, 0.2506924979388714, 0.11461375455837697, 0.25569489982444793, 0.13040287216426805, 0.15807114687049761, 0.17737167683662847, 0.1449921150924638, 0.19459558854578063, 0.08927148199290968, 0.25051972595974803, 0.0843436733703129, 0.11451988772023469, 0.1668726175557822, 0.11870300309965387, 0.10591070749796927, 0.19120522047160193, 0.20890863379463553, 0.21896510588703677, 0.1179322975804098, 0.10524134966544807, 0.20318560651503503, 0.1621361865545623, 0.13156005850760266, 0.1500447010039352], [0.034184962132712826, 0.03311401334940456, 0.03991816054622177, 0.06649561546510085, 0.03450780379353091, 0.03620370400312822, 0.014855909575999249, 0.04101093589270022, 0.09474374499404803, 0.0223713682134985, 0.024827825072861742, 0.029498794938263018, 0.011784555535996333, 0.04086734144948423, 0.03598475188482553, 0.017964942453545518, 0.024007928150240332, 0.05892182030947879, 0.027895548155356664, 0.04640346254745964, 0.016803260550659616, 0.05324831654434092, 0.021711474619223736, 0.030763973045395687, 0.07241796134621836, 0.037342306968639605, 0.05148616852238774, 0.060122797076473944, 0.03320631054521073, 0.01435889698768733, 0.06498345246654935, 0.1228261529468, 0.06453578898799606, 0.004009144831798039, 0.057245323550887406, 0.04373939358629286, 0.023895960330264643, 0.012061571433150675, 0.013528513518394902, 0.007073523147482774, 0.0060891013617947465, 0.028390545812726486, 0.03403708920814097, 0.021385903710324783, 0.04927971152937971, 0.09834672353463247, 0.023844572169764433, 0.036220966358087026, 0.015009828221081989, 0.027983433283225168, 0.05522422907233704, 0.061253689127624966, 0.049963901183218695, 0.009887452597467927, 0.02830035075021442, 0.013613469945994439, 0.007485381711376249, 0.03766429144889116, 0.0293324777885573, 0.1256624038796872, 0.00991277096545673, 0.02895145174989011, 0.05059438160969876, 0.09401662580785342, 0.038203973817871884, 0.04783524353115354, 0.06744375365087762, 0.02883126278902637, 0.02831451092788484, 0.049313846611767076, 0.017692114124656655, 0.020210111724736635, 0.045115109023754485, 0.09083555079996586, 0.0211423159998958, 0.03059989718167344, 0.010277899273205549, 0.03790164140809793, 0.030759542423766106, 0.04596222235704772, 0.019281330605736002, 0.04739129821246024, 0.008051804124988848, 0.06907739880261943, 0.06925345107447356, 0.025023124944709707, 0.05568996384681668, 0.07040221404167823, 0.03758379440114368, 0.05475742931594141, 0.0472770631313324, 0.04386815991892945, 0.0631146207160782, 0.040080397739075124, 0.05220931350777391, 0.005998968454150599, 0.10133049116120674, 0.06093791271268856, 0.014490300727629801, 0.05012518842704594, 0.029396450918284245, 0.053989261941751465, 0.0372935961058829, 0.03267345222411677, 0.013858690381312044, 0.029488581130863167, 0.07672218780498952, 0.009294414448959287, 0.0416337313799886, 0.046241522213676944, 0.07300999481230974, 0.04780655952345114, 0.031305087759392336, 0.01995407263166271, 0.011137235778733157, 0.06106243767135311, 0.022051949708838947, 0.06650621333392337, 0.025443367921980098, 0.022813981377112214, 0.07909229578217492, 0.0764341454487294, 0.01606368812645087, 0.0441725740529364, 0.032274247278110124, 0.0660401742788963, 0.06690701018669643, 0.026765138500195462, 0.03196626712451689, 0.0313696323428303, 0.035205122039769776, 0.02440753571136156, 0.02784547545161331, 0.019278324907645583, 0.03408532509638462, 0.04176758884568699, 0.05382607851061039, 0.06125277628598269, 0.01458745806303341, 0.02185354951507179, 0.02920708451711107, 0.01861350716353627, 0.03426864670473151, 0.028071863889636006, 0.03971330552303698, 0.07641723932465538, 0.017727514568832703, 0.015381223038275493, 0.027449116641946603, 0.05860769146238454, 0.040056162906694226, 0.07337054499657825, 0.01195617162011331, 0.05474372555909213, 0.07464681635610759, 0.03373309438757133, 0.05221200379310176, 0.08215523572289385, 0.029351580669754185, 0.0583314492541831, 0.05848507753398735, 0.00848830291943159, 0.024939460781752132, 0.08588031239924021, 0.05055223133240361, 0.06605415634112433, 0.06338004241115414, 0.03432445621001534, 0.0668347769533284, 0.03494840573694091, 0.09390372288180515, 0.05986244053929113, 0.07473790756193921, 0.054137275874381885, 0.09984532749513164, 0.040745406586211175, 0.08056188918999396, 0.048524531739531085, 0.013917426731495652, 0.027492530425661243, 0.03597812079533469, 0.0712540808308404, 0.05097286950331181, 0.015246507464325987, 0.06361432358971797, 0.05308674728439655, 0.014745748885616194, 0.07730331170023419, 0.08694856718648225, 0.034102609715773724, 0.06451206252677366, 0.022370791193679906, 0.014541789078066358, 0.11207601026399061, 0.040907317234086804, 0.024110099620884284, 0.009496027214481728, 0.06524971278849989, 0.03548429573129397, 0.05381058988859877, 0.028172847923997324, 0.06491369058494456, 0.014406515037990175, 0.042978072524419986, 0.018800778852892108, 0.00627426952632959, 0.0090996507788077, 0.08481538985506631, 0.029148193243599962, 0.024145054776454344, 0.0942491703608539, 0.050204282815684564, 0.03291313252702821, 0.03787946603551973, 0.054741280182497576, 0.04348469592514448, 0.061810674669686705, 0.027555086053325795, 0.04773111650138162, 0.013202200461819302, 0.022649165221082512, 0.015267966664396226, 0.03315599293273408, 0.00694367838150356, 0.034441763782524504, 0.04680667880165856, 0.06054418481653556, 0.03812277544056997, 0.06347966089379042, 0.04356419107352849, 0.020354936277726665, 0.03388883778825402, 0.058720713132061064, 0.006489002071248251, 0.04753941604576539, 0.08958016347605735, 0.039743332818034105, 0.018221823884232435, 0.00547920672033797, 0.10383774060755968, 0.06467703453381546, 0.042795789922820404, 0.04897992839687504, 0.006391886017809156, 0.02238622044387739, 0.045658268354600295, 0.020691919562523253, 0.0285660711597302, 0.014391433669516118, 0.06012658202962484, 0.06712909045745619, 0.031740234917378984, 0.013228758216428105, 0.0113934474211419, 0.03230040798371192, 0.043521610350580886, 0.03667653370939661, 0.044881610810989514, 0.07100620350684039, 0.05514754666364752, 0.052657225605798885, 0.01510545116616413, 0.035643894589156844, 0.010089365005114814, 0.05132879610755481, 0.07506090507376939, 0.055067465218598954, 0.03630843588325661, 0.036064874147996306, 0.039491703937528655, 0.02027364884270355, 0.01240349742147373, 0.01689884731604252, 0.05581527919275686, 0.09987767771235667, 0.03378477013029624, 0.015371329282061197, 0.06989284840528853, 0.02112904825480655, 0.035003606681129895, 0.01563036479637958, 0.035411157077760436, 0.06613974081119522, 0.033784721890697256, 0.04304344089177903, 0.04180484094831627, 0.021792420666315593, 0.03395727864699438, 0.03675022155221086, 0.018036832443613093, 0.0054620519767922815, 0.02641164799570106, 0.03187433729181066, 0.03322166929137893, 0.044103428153903224, 0.04415733776113484, 0.01803538154490525, 0.0553421786025865, 0.02722515131608816, 0.01623578846192686, 0.008076234698819462, 0.005133874274179107, 0.0387116325146053, 0.04855862971453462, 0.026757614978123456, 0.00707176240211993, 0.018014686756941956, 0.018972715915879235, 0.10223864985164255, 0.08267154786153696, 0.014175455708027584, 0.07490345844416879, 0.052956025392632, 0.03567662701243535, 0.030732069972145837, 0.006292943353400915, 0.029386743626673706, 0.010343831672798842, 0.030892349750502035, 0.007857667569624027, 0.04674531432101503, 0.023125755760702305, 0.022941309798625298, 0.038709962682332844, 0.033593143889447674, 0.029343650821829215, 0.049002200248651206, 0.017364856685162522, 0.0212142004238558, 0.044904346505063586, 0.02463639735651668, 0.039322587035712786, 0.04440450262336526, 0.04450048458238598, 0.027506128426466603, 0.04578290834615473, 0.0589759302965831, 0.014521211178362137, 0.021109479675942566, 0.04155812137469184, 0.06237770518055186, 0.02183441880333703, 0.04453145811567083, 0.046010217047296464, 0.009028440781548852, 0.10675576879293658, 0.049887103741639294, 0.02088031375024002, 0.034819327702280134, 0.01843529153120471, 0.04059986771608237, 0.018937975983135402, 0.13443457457469776, 0.15674777881940827, 0.10056018640170805, 0.22321381227811798, 0.13610912690637633, 0.17232726939255372, 0.1263645794824697, 0.11712811377947219, 0.12261610288987868, 0.13690387801034376, 0.1054635709442664, 0.15610847796779126, 0.1603698602411896, 0.08551914623240009, 0.11027743021259084, 0.08497581249685027, 0.12683153880061582, 0.17215516534633934, 0.09815295619773678, 0.07746936724288389, 0.13865540589904413, 0.1388492400292307, 0.09417377557838336, 0.1615886893705465, 0.1464498118730262, 0.12680927437031642, 0.20755130506586283, 0.1925012923311442, 0.10506088903639466, 0.10008448458393104, 0.16159547260031104, 0.24290564702823758, 0.11245788977248594, 0.11565414170036092, 0.1468834636034444, 0.17452226020395756, 0.13714129105210304, 0.11511433316627517, 0.1332225583610125, 0.15062704944284633, 0.12352878868114203, 0.10523454417125322, 0.067661715002032, 0.15720143885118887, 0.133196419919841, 0.18972721853060648, 0.06973202500375919, 0.1703569118399173, 0.0938833286636509, 0.11334267823258415, 0.13827728165779263, 0.19842769776005298, 0.14276877423981205, 0.14604605385102332, 0.11346376704750583, 0.135853664833121, 0.1312143958057277, 0.16618461697362363, 0.25712109985761344, 0.3084287670208141, 0.10351739256293513, 0.1279029477154836, 0.12280158785870299, 0.18293906090548262, 0.12068172465660609, 0.10804153222125024, 0.154895571176894, 0.12079977808753029, 0.16596519359154627, 0.13126521807862446, 0.1131175403133966, 0.18657956243259832, 0.09862145918305032, 0.192901176342275, 0.17011807387461886, 0.12832580861868337, 0.07278692006366327, 0.11601637655985542, 0.09634224203182384, 0.1859792837058194, 0.08261641371063888, 0.20388680248288438, 0.0911242759320885, 0.1782775274477899, 0.21102886064909399, 0.12698848819127306, 0.12980283092474565, 0.13250675692688674, 0.1940575908520259, 0.14786283136345446, 0.12840803858125582, 0.1594660579576157, 0.10535943278227933, 0.13696666370378807, 0.16777348093455657, 0.1438961856183596, 0.1766303603653796, 0.08600880042649806, 0.23161954013630748, 0.1749938356806524, 0.1730910432524979, 0.14169114612741396, 0.06018113730533514, 0.1468853635014966, 0.10446089974720962, 0.1636617601616308, 0.20960221532732248, 0.0854095681279432, 0.11554766577319242, 0.13658006413606927, 0.09387536541908048, 0.12010970691335388, 0.29469689761754125, 0.09201066000969149, 0.06632352626184002, 0.13892870920244604, 0.05223548905632924, 0.2718272904166952, 0.08307282711029984, 0.19122936995700002, 0.12110983254387975, 0.15824773348867893, 0.0949880229018163, 0.08155860836268403, 0.12054474645992741, 0.16689989890437573, 0.19790145568549633, 0.1295948217739351, 0.1573100744280964, 0.16765251086326316, 0.11805802481831051, 0.11347118852427229, 0.1741809761733748, 0.1446915601263754, 0.06483381323050708, 0.18020423187408596, 0.1524069273727946, 0.16691821510903537, 0.08300325818709098, 0.0740306185616646, 0.20866531325737014, 0.14093394769588485, 0.17085578350815922, 0.12598458502907306, 0.18292421795194969, 0.18739651859505102, 0.09486829221714288, 0.11589594083488919, 0.11372596040018834, 0.08294387153000571, 0.24516297824447975, 0.20844724058406428, 0.11921080280444585, 0.18779953446937725, 0.13277672056574374, 0.17479630565503612, 0.14279350260039791, 0.13989580183988437, 0.09892867863527499, 0.19892033538781106, 0.13560428837081417, 0.09134522813837975, 0.07625791506143287, 0.13980861433083192, 0.10322457819711417, 0.12061315021128394, 0.19222540635382757, 0.15026419860078022, 0.10337605795939453, 0.1707200743840076, 0.22014712449163198, 0.13700993091333658, 0.1662737934384495, 0.1807557960273698, 0.19473359832772985, 0.16132926422869787], [0.009388098533236189, 0.030686197824252304, 0.03517175508022774, 0.06800011949962936, 0.05732835874368902, 0.06620575484703295, 0.01040606724927784, 0.03332290565595031, 0.03841942670987919, 0.006905163236297085, 0.027873734579770826, 0.03890077998221386, 0.032682521268725395, 0.013135745775798569, 0.03285104816313833, 0.0486076337256236, 0.04393961018649861, 0.019874263925885316, 0.030633091591880657, 0.031092050558072515, 0.05574090115260333, 0.0455137016979279, 0.07800366904120892, 0.013017958590353373, 0.0674955704016611, 0.03995730141468812, 0.0037569257119685062, 0.09551950453897007, 0.06195411697262898, 0.057272842386737466, 0.05854972972883843, 0.05593087611487135, 0.04327874252339825, 0.06246190925594419, 0.030533745848515537, 0.12286930141272023, 0.023563936447317246, 0.030271938412624877, 0.006202794675118639, 0.0071175598714035004, 0.0238402194736409, 0.03836267096630763, 0.022817710669187363, 0.06399066667654552, 0.07866998406825587, 0.04539266483334359, 0.051972995133837685, 0.01383512533720932, 0.003641773846538854, 0.029481673591362778, 0.1772739359876141, 0.015453627893293742, 0.04264019866241142, 0.008475946160615422, 0.03842144906229805, 0.08964973982074298, 0.014013313139003003, 0.021281949229887687, 0.012238508716109209, 0.03791310758970212, 0.025423751103517134, 0.045977625632076524, 0.023530641847173683, 0.010105555884365458, 0.022528107947437093, 0.04576529347104952, 0.03811187700193841, 0.02126817125827074, 0.048805434635141864, 0.0742572036688216, 0.04735400900244713, 0.07006334941252135, 0.023165930069808383, 0.045641124743269756, 0.04124926919757854, 0.01972348734852858, 0.006204714054547367, 0.01910324855998624, 0.051270563490106724, 0.03923372227291111, 0.03827509382972494, 0.05832721530168783, 0.009102469084609766, 0.054694803184247576, 0.043422114322311245, 0.028903590646223165, 0.06149756627564784, 0.006577826943612308, 0.0496922528691357, 0.038161192715051584, 0.04274160572094843, 0.022474621364381164, 0.04232633327774238, 0.003926519211745472, 0.028352291810733732, 0.06798638234613463, 0.12497176125179976, 0.06803828073316254, 0.07252386581967585, 0.015365477447630838, 0.05144953240233008, 0.028924843900313135, 0.0211296345514711, 0.040847333148121834, 0.009508455405011773, 0.0909763659001328, 0.03903449643985368, 0.017183909949380904, 0.015417759896081407, 0.03705080991494469, 0.02014731304370798, 0.037853724643355235, 0.03585853111871984, 0.03515801050525624, 0.013861199768143706, 0.027427857821749058, 0.021732661080022808, 0.04253295461239759, 0.06601475572097115, 0.008422813025390496, 0.041917205817298964, 0.08426084226812236, 0.031737733879708685, 0.05261576552584302, 0.04117708791454788, 0.00712728478902136, 0.08605882117990404, 0.059879558175452985, 0.12092506003682502, 0.04904626155621372, 0.034359359415248036, 0.03831443507806398, 0.04470151383429766, 0.034137416441808455, 0.0378350967366714, 0.036648884997703135, 0.0436802926560631, 0.08132598959491588, 0.030217273670132272, 0.031216319475788623, 0.08488989406032488, 0.014087992676650174, 0.01464558956286055, 0.018096770145348273, 0.08204380224924535, 0.03137521700409707, 0.05740158274420537, 0.014877763042022707, 0.06689091300358996, 0.030934032474760897, 0.03363905314472504, 0.020091063815925736, 0.05847863569215406, 0.04667487337428611, 0.0391225559724262, 0.024887569816200994, 0.017574118210177403, 0.021454183151945472, 0.04772829634021036, 0.025444848506595008, 0.05021477678383235, 0.0635165604762733, 0.020538745848170947, 0.03810006572166458, 0.08793034692644142, 0.04080938713741489, 0.04981824728020001, 0.01281234935959219, 0.04774165128765162, 0.05197397847950924, 0.031213098554871976, 0.0026819649247045163, 0.0038293370607789257, 0.03820352481852751, 0.12498362077167258, 0.025077309146581683, 0.016046568634919822, 0.019263795511506032, 0.04064416280016303, 0.029566903685918078, 0.04047581402119249, 0.040566574971308, 0.05238909878244158, 0.003458751184552966, 0.07108837409759872, 0.02540073895943351, 0.014358676198753528, 0.026702942814154085, 0.042995598341804, 0.02094015868351562, 0.028389514227455948, 0.07265520369401202, 0.055873879173304886, 0.016515240458829794, 0.016905129596125335, 0.04706038198492024, 0.03343711105117109, 0.015579190003336407, 0.03367045341292396, 0.045703583891736344, 0.035851733046001755, 0.017360945566906594, 0.03713618658366613, 0.020213380885252263, 0.0301830291209626, 0.02353864776523551, 0.04381253966130316, 0.03753684984985739, 0.06348871509544551, 0.014307493984233588, 0.06671961047686636, 0.07920778880361468, 0.04899825573374983, 0.07155479906941764, 0.01975166112970328, 0.015143415730562992, 0.04883174377027899, 0.07066713107633404, 0.020512982191576157, 0.004214792561469949, 0.025197334834956564, 0.040382808074355125, 0.04226626755553298, 0.04142045298067387, 0.00494310289468558, 0.03956700595153961, 0.04019947533379309, 0.032553350465605035, 0.004696975183833274, 0.06318539934, 0.11799699801485986, 0.07052270171698183, 0.028926771628903225, 0.03174908873916138, 0.031146435139817186, 0.12029542194795795, 0.037105721421539783, 0.017566533460922074, 0.010953580203931779, 0.026758268068078905, 0.00602216706283798, 0.04262219415977597, 0.04557628701149952, 0.040531167105655186, 0.04826775977562647, 0.04962610524671618, 0.015069270539243007, 0.038560241810046136, 0.010472790963831358, 0.018160093895858154, 0.06178861432999838, 0.010191550391027704, 0.04349846647528466, 0.04798359514097683, 0.0817924590955954, 0.039899276598589495, 0.04910521034616977, 0.023284801718546078, 0.025589895703888033, 0.02782775667583337, 0.06047508344636299, 0.06176848357426934, 0.07784781802911311, 0.02892007560149068, 0.006413423607227742, 0.012911303620057879, 0.024745491209614556, 0.0442876366287237, 0.057423780381213874, 0.1036672767077107, 0.07284332328708842, 0.04343917258665897, 0.039097363769542426, 0.0715676011168398, 0.10636281644110568, 0.045296115131350234, 0.10588944496703334, 0.01947989221662283, 0.05444491464004386, 0.03943478121072985, 0.10325867988285609, 0.03754043071239721, 0.05036720278440043, 0.02752473963482771, 0.015928886277833953, 0.027917248553421814, 0.048562689262325875, 0.05295252616633661, 0.06515174929518253, 0.09330236804089509, 0.07773453660774976, 0.020449378280318342, 0.02036607220361475, 0.027295950349071063, 0.10093281875015236, 0.01039076973029296, 0.046843459640513174, 0.05650153572787531, 0.032346027801395394, 0.013720893966819858, 0.07911778113339096, 0.02675782463484211, 0.06589619020815007, 0.05863791171577759, 0.035450253417366184, 0.060793865559389815, 0.04523352239630185, 0.03352070656546857, 0.06859630899270996, 0.026171377685386688, 0.08815126202534884, 0.03374699110281654, 0.045830472590751015, 0.1067786714702379, 0.06012474521412514, 0.040643524553161114, 0.030643188511021435, 0.03708863347128499, 0.04266357631422579, 0.021018245606683195, 0.07735908409813419, 0.030205126568034757, 0.025802498748817015, 0.06274044470046647, 0.04136901472520549, 0.06452671252191067, 0.04761476258863695, 0.05071149251307361, 0.07122504059225321, 0.005997406697133556, 0.04904937857645564, 0.009993464682338526, 0.04066817127750255, 0.05870221139048226, 0.04793456886545755, 0.02017161838011816, 0.037982320282026194, 0.05388897923694458, 0.05795558485260699, 0.03380376168934163, 0.040654207768966444, 0.02587473198218504, 0.06226155906915665, 0.010192103291046806, 0.01747327889461303, 0.067115145502612, 0.027721566475520376, 0.028841326311521698, 0.03444476948061492, 0.10905535047641024, 0.08427956665400416, 0.019503733710735105, 0.08741741898120381, 0.09445035175303929, 0.09434711158974096, 0.15362682519480586, 0.1396605558693409, 0.1839294718229212, 0.07222973043099046, 0.13112686690874398, 0.1775885620736517, 0.09243897569831461, 0.06769446597900242, 0.0987586154951714, 0.1962463030940853, 0.17602665291633457, 0.14025952841620892, 0.18131525663193315, 0.1303215921507217, 0.0791783255408518, 0.05505896020622458, 0.09531694275210612, 0.10085778019856662, 0.14296594803454354, 0.14124695589998737, 0.12499579199356958, 0.15711184678366408, 0.14687669521663338, 0.1312734410748817, 0.18756838515400887, 0.18326973222428933, 0.1001430103497114, 0.13851088006049395, 0.19678151031257585, 0.18016546207945794, 0.22463878034614027, 0.16327550198184326, 0.24149567034328356, 0.0866988419147674, 0.07374101027380675, 0.16337514272890985, 0.10577891691355035, 0.10339390661101788, 0.1978468187735416, 0.11188006843440235, 0.11130302635137923, 0.16413989622378722, 0.147726513678208, 0.11595031799515709, 0.10612253128783777, 0.10788142870296724, 0.17396055831341073, 0.30203035566955805, 0.11086148559115827, 0.11421672039432451, 0.11668151899357326, 0.2042086867731996, 0.18471711315214634, 0.10460432720719837, 0.11946676211664453, 0.12295946493395604, 0.21393897011876106, 0.09075766240130179, 0.11271711453446187, 0.14396174694411457, 0.09404639335116372, 0.1618857413996011, 0.2571555058239028, 0.16299912618706003, 0.10248021892039105, 0.1446958348969929, 0.1514361536828801, 0.07850488589610904, 0.13078405405394733, 0.09094081702642143, 0.14878294605296105, 0.12078378480509855, 0.1257796335266903, 0.1588177919620648, 0.07023180951364338, 0.15705271245678887, 0.20164679299341515, 0.11346652041538619, 0.16821862111100927, 0.1983843563357368, 0.13032025628490373, 0.08207159567973576, 0.13296403863932937, 0.24454199359752238, 0.15327041619457304, 0.09274478506995365, 0.13319919555215165, 0.10511057582334615, 0.12859174981713295, 0.14572586165741086, 0.16359440283849835, 0.1667166774859652, 0.11933925372431986, 0.26646800455637276, 0.23063077678671107, 0.1588939511566423, 0.1030239905230701, 0.17156079411506653, 0.10514757930650376, 0.11191186946234666, 0.08376026366022415, 0.12166852131485939, 0.18576938949991018, 0.21271200705086812, 0.12522119708592072, 0.14674849662696943, 0.10836419576662593, 0.10353878125897609, 0.1391123016946949, 0.1356842473614961, 0.21181451302254573, 0.14287794416304678, 0.10357798149925657, 0.1390903489664197, 0.17278832121519372, 0.1897087093675509, 0.1752929508802481, 0.19987610285170376, 0.18588795501273125, 0.12285632867133245, 0.16913420869968832, 0.1896146050421521, 0.06588102813111618, 0.20368136116303504, 0.115738227032125, 0.22509652219014242, 0.12289541016798466, 0.22681453468976542, 0.07458754102117382, 0.17542282672366127, 0.1099987314955797, 0.11970796753303148, 0.13216622988693416, 0.15871590992901474, 0.18564610392786562, 0.19595665769884363, 0.08843602408887818, 0.18030672246823087, 0.15604799293214455, 0.1715088140917942, 0.13805420690914616, 0.23713559727184474, 0.0905165979929734, 0.16040811053244397, 0.19238939130445942, 0.10798741481266916, 0.138786944153253, 0.09752199708600529, 0.1404806735808961, 0.13837990583851933, 0.13805137190502137, 0.17002546868752688, 0.09288292843848467, 0.14706344925798476, 0.15275451965862885, 0.11078365656430833, 0.14060372166568413, 0.10405959823401645, 0.251080374000594, 0.08738609292777255, 0.1608904471504502, 0.1768648048164323, 0.06661530162091367, 0.14224201266188174, 0.0855237475479953, 0.05221346211328637, 0.12455635151127353, 0.13069112232187763, 0.09769965981831774, 0.11890578753082082, 0.10243961602100171, 0.2059443772304803, 0.1337820486514829], [0.031256028087227605, 0.03539076657034457, 0.03190736657415982, 0.062622940458823, 0.033310129583696835, 0.03851468878565356, 0.07082775409799069, 0.04005627422884572, 0.04249506055202801, 0.015440289644175209, 0.053767422868986614, 0.0559618941770168, 0.051498885222827084, 0.017440722731407732, 0.0059107725519425, 0.06670933915302157, 0.0590843988902634, 0.1118556666187942, 0.05007357205613516, 0.057053252021432854, 0.02295304129802389, 0.0256626948248595, 0.042447054729564115, 0.02386754349572584, 0.04230585000186693, 0.018339780835958663, 0.007281518846866675, 0.038193498403416015, 0.02024998546403367, 0.030237528735597152, 0.01367020713587408, 0.0724486936815083, 0.023797397552698385, 0.01855460104707163, 0.07958672940731049, 0.047664423400419764, 0.05267600936349481, 0.06758799005183391, 0.03350423830852378, 0.02062563278741436, 0.05445587245048955, 0.04281851077394094, 0.07320767326746136, 0.07693261635722592, 0.016684106885804795, 0.050903077935799956, 0.039675945808994584, 0.034599774444359355, 0.028148440542281605, 0.06265412550419569, 0.02171797583287116, 0.05918039569223765, 0.01842354889959097, 0.07350605374085717, 0.04738698262372054, 0.04723719866888132, 0.03851288165606093, 0.04208005528198555, 0.03583536497899331, 0.009066289385373238, 0.05914171124459244, 0.04988886634237133, 0.02315884812560398, 0.014500704710371792, 0.02908771191869164, 0.017405164580850396, 0.028338521260593552, 0.057323690634802915, 0.02459382034430746, 0.04705666382506024, 0.04577475214318838, 0.026175337043241598, 0.05018141724576708, 0.03133629877993371, 0.01209360623761313, 0.03329892315377947, 0.10529997933190316, 0.04121394667890854, 0.09999571630032733, 0.028878697157779243, 0.038479703944176435, 0.02591996959381504, 0.050239423508173786, 0.004705153187387623, 0.02519690438930411, 0.05424493552709464, 0.006948270884095109, 0.04347208312537987, 0.040847852651495486, 0.07057361304759979, 0.05288710213790182, 0.08904045142116956, 0.013647277555719484, 0.02938678258942673, 0.05803803745948244, 0.05146234929270577, 0.05509497663297225, 0.018464522872818634, 0.010493626759853214, 0.018589047831483185, 0.06362765998346731, 0.03740267326065805, 0.02749025388766313, 0.03230414469726384, 0.0876237805641722, 0.06776042806450278, 0.0444229969434673, 0.05437643667391967, 0.007650385259694303, 0.029514860580093227, 0.11501875196699984, 0.032121609765454195, 0.06598457257496193, 0.009256571411242476, 0.04301355089410208, 0.04125289458897896, 0.07142552436562255, 0.017883927757793572, 0.0657762294576969, 0.04044599823828321, 0.02646372635354055, 0.06157054165669251, 0.05363923170079943, 0.07922644639620557, 0.014779916436964413, 0.013406805010163225, 0.020220108453941066, 0.0817529545747675, 0.04064604414452333, 0.037028857186669484, 0.013792407316941535, 0.015966956598276738, 0.024510774019290693, 0.059450745247886516, 0.06867494696052745, 0.018130133394151926, 0.02886849262722535, 0.05919847812037915, 0.08083403474302031, 0.05648160164128058, 0.04035422796732746, 0.009570331967552193, 0.034653446564334445, 0.031479863537242636, 0.06496167785371654, 0.02650883780006552, 0.027545701595954597, 0.02183016073104227, 0.031707172238384373, 0.07319321623072028, 0.027769796797656454, 0.009566548869770486, 0.03001217559358338, 0.060723999777110294, 0.018230588648293633, 0.01281566026591463, 0.05493005286552943, 0.08991715789306909, 0.02069558948278427, 0.04667486595280934, 0.03747419403225649, 0.02628269427077612, 0.028891721849504393, 0.02970228626509197, 0.09060513621079735, 0.09565911735990085, 0.052523924750857987, 0.0224106964742532, 0.025633027471485548, 0.008129108082357561, 0.06588623058632948, 0.05502523330505937, 0.011869853351527127, 0.05656585766701028, 0.002891488752538862, 0.020649888028856367, 0.05757387603807729, 0.048444283311255276, 0.014714744738739682, 0.0367549045040505, 0.019712549947143998, 0.08421876249485649, 0.022854437702335417, 0.04216130189888645, 0.03251465117500629, 0.07852420400013216, 0.050601836483110674, 0.11494688238599338, 0.07789355659042485, 0.02823125309078023, 0.017707294755382463, 0.04157832634518854, 0.012476928295654943, 0.04106554311874788, 0.05198097693210002, 0.02086297346977517, 0.024891323228075635, 0.0831100606592372, 0.04350700488430448, 0.023146949642978143, 0.03640387978521176, 0.03985420597018674, 0.035245194303570315, 0.018640354355738964, 0.05588350111793261, 0.021785637436551042, 0.012456959884730168, 0.041963215262512676, 0.07039297430310398, 0.037122493959032, 0.03618360664404463, 0.019830529163300525, 0.011137419460283127, 0.029345483926590532, 0.052292549080448225, 0.013418508679023944, 0.009586546966602327, 0.023579412081744522, 0.04172170927631669, 0.03291441644250881, 0.03711522833327763, 0.04599958207109012, 0.02548323609516956, 0.029074477570247836, 0.028875042080471758, 0.02905423734773649, 0.07131124846637249, 0.06012367652147077, 0.025892350568028633, 0.04123875296500046, 0.06796718298573978, 0.01777528661477845, 0.02081952443404589, 0.05137784835824277, 0.0545332561887335, 0.07906955637736246, 0.04333744269388262, 0.036476658497122116, 0.030498642263410147, 0.04747218488773797, 0.04664155094360467, 0.03614438042859547, 0.05941776049439795, 0.03710913530085236, 0.02250228491902817, 0.05250335241726134, 0.016500618294230662, 0.03840693265374284, 0.042134959367103875, 0.02647867877385579, 0.01965753639524337, 0.030560114355466794, 0.06635110446950421, 0.023518481757491827, 0.0659126733080484, 0.05773811702965759, 0.05917327849601861, 0.061806166122551076, 0.06683678075205535, 0.015359445642388891, 0.041985349816968665, 0.02868543262593448, 0.08018916036235169, 0.0038560232997042476, 0.05593895068159327, 0.0529139085119823, 0.04809160360309761, 0.0453209548140876, 0.0439568539877655, 0.05533655312319752, 0.015532841953245224, 0.02307762191776419, 0.08301948153530248, 0.06768599065253511, 0.05674397310940549, 0.009115902885241667, 0.09595957584679127, 0.013687375794688705, 0.04002820249297656, 0.06587345080333762, 0.041500957449898124, 0.001827819742175052, 0.06388811671058647, 0.034159254137193784, 0.02613055028632516, 0.05828033012221567, 0.056881437412812375, 0.045490068005165085, 0.09602163423551247, 0.031007872457848862, 0.034288068709429353, 0.04091834183782339, 0.02400568871962605, 0.06370752249495126, 0.07882793535827659, 0.06393687581294216, 0.027818709895655047, 0.0255651153929648, 0.034318114558118396, 0.04069947877724189, 0.02578485233243555, 0.02152917531930143, 0.06136216514278203, 0.007785071611579042, 0.03376549655513372, 0.04745205042127054, 0.0266060238936916, 0.03231825292459689, 0.02945171308965655, 0.03636713605374098, 0.09491665055975318, 0.033387832445441745, 0.023000112014415208, 0.02060377097222954, 0.04515201973845251, 0.08678482714458369, 0.024768150833551772, 0.05157667714229319, 0.008658839178679045, 0.004320380230637966, 0.014712385636812542, 0.046539030663552694, 0.012764390849042684, 0.06914350931765512, 0.01151225598732708, 0.048488567263120785, 0.09922184923198074, 0.029572384446510114, 0.05198712562560104, 0.041934408800443634, 0.048482793354196474, 0.06760310017853044, 0.08378140002605505, 0.09656931695644744, 0.031808712883503176, 0.06888116753543727, 0.03246310901886318, 0.0035680122527992353, 0.014933931561245117, 0.04796579101821408, 0.04958356534189079, 0.046182399019016884, 0.05269398789096158, 0.07740650733467191, 0.023017897583486047, 0.012724790776701411, 0.03202854815754108, 0.02364148160268087, 0.03492864976578858, 0.01904649838252226, 0.0275211569169187, 0.013258817980386084, 0.14907420933013782, 0.20416806160937995, 0.08761349439737387, 0.11176347703440115, 0.13908916153013706, 0.1997867928002961, 0.17455001652706414, 0.11258489350439049, 0.1798862512805499, 0.10276236120262183, 0.22633614629739895, 0.1672056340612471, 0.2734050073195249, 0.18367219890933484, 0.07814414275344461, 0.20022807380883023, 0.16984701185720041, 0.18260220007505268, 0.13741437171120197, 0.2315646508941427, 0.09699083457235247, 0.24080296454485506, 0.2310117954039015, 0.11780228815041482, 0.12869333499111235, 0.1386827911483124, 0.09243606647942215, 0.1332716885372065, 0.1672976603731513, 0.09073598426766694, 0.10505276994081214, 0.12174102914286777, 0.14233702240744606, 0.13259289058623835, 0.2002756009460427, 0.1456948250415735, 0.11137390145449899, 0.18727397517068312, 0.08710386900929734, 0.14308286597952247, 0.14728771144291386, 0.09977054127375595, 0.17645861255005002, 0.17963414371479303, 0.15449843311216682, 0.13357285206438974, 0.06432726033381186, 0.0976133554650005, 0.09486813636613078, 0.2032054218580015, 0.24140946246916428, 0.2999957726569846, 0.09895492097712122, 0.11687899706885219, 0.0918665794597473, 0.10681845800718293, 0.16646955715259537, 0.11720445851096883, 0.14598773588659242, 0.14257531118346378, 0.11384059995179996, 0.2167316569830291, 0.15907991852145642, 0.08531098865205422, 0.17040359292877838, 0.11453070081188343, 0.13691919593838975, 0.2028371236519888, 0.13688980689039454, 0.2077472023665905, 0.16950645513134077, 0.08815823079203255, 0.1374069502344355, 0.09352853754535317, 0.09929473555530421, 0.07483363719074987, 0.2235940590617247, 0.12839138478739187, 0.20193247532006353, 0.19418970798142254, 0.16042555100284517, 0.18002602737396955, 0.22999389533651993, 0.08425447464105673, 0.10845176919247024, 0.12570534454425797, 0.14146300993161276, 0.14616905740695074, 0.15495308762183413, 0.11917942480067722, 0.20650882506743073, 0.20926271245116368, 0.12865127006080002, 0.2257605959312059, 0.14610723650548607, 0.19925603846786544, 0.20869338128250092, 0.11940877069719136, 0.12851802486693487, 0.09327684558229521, 0.18158648192184046, 0.10409634196548723, 0.1809379635960795, 0.17793367558624595, 0.22040516923880205, 0.1426380968769081, 0.12365892427624203, 0.17251212353585288, 0.13330597575986758, 0.1449698061333038, 0.17823044559918344, 0.11766188123147003, 0.22379369678674266, 0.12718003650661558, 0.14815667731454596, 0.11810438678367063, 0.09646082238759845, 0.11289968286291696, 0.19661332480609417, 0.20300858945120126, 0.08183016761904582, 0.27758662356063724, 0.12831339990952983, 0.21803178096888587, 0.1690649366355501, 0.06449931242968887, 0.1794409181457013, 0.14382501365616918, 0.09356412352644838, 0.10086532041896135, 0.08722446058527566, 0.09604618448065594, 0.075819008925464, 0.15398994321003556, 0.16063606861280277, 0.1486412255326286, 0.16000402596546337, 0.18494615476811305, 0.17747951089404523, 0.21327216527424753, 0.15432128246175125, 0.12540842610178515, 0.1297389913816005, 0.0816984660923481, 0.11720186099410057, 0.10985242450260557, 0.1624786134925671, 0.2323499767226167, 0.08415078176767565, 0.13442344235954806, 0.12791249173460528, 0.11223784298636019, 0.11219108768273145, 0.2042263647308573, 0.13245718146208674, 0.16093809303129092, 0.19735478970687836, 0.26375937333796173, 0.09917273389874026, 0.1297052830341272, 0.1015191970509477, 0.06297445128438994, 0.08650148258311674, 0.09770334829227068, 0.17262745328480378, 0.22554461611434817, 0.14785728009883314, 0.23400613863486797, 0.14379926113178954, 0.05073006104794331, 0.11566989007405937, 0.10461145182489417, 0.08001968351891264, 0.09001050522783771, 0.18679052533116192, 0.06075276542105712], [0.06878788699395955, 0.02074651565635577, 0.04580871282087173, 0.01705001537629869, 0.004130600545977359, 0.014479892106464831, 0.05788218273664825, 0.0789678747241851, 0.02514260144380387, 0.05603401608823333, 0.02155584439606173, 0.08570414880523458, 0.03759897874260787, 0.0407333615294192, 0.019124997197650373, 0.033306938348687254, 0.05841232850798406, 0.04555567014904227, 0.05460771586513147, 0.03307434555608779, 0.009251949686586158, 0.006393091543941409, 0.04790873470483348, 0.029853057276341133, 0.07535914453910664, 0.03726600676600356, 0.012679900119110243, 0.01671615467785159, 0.081413251318736, 0.03388040327990893, 0.04635217643226497, 0.01591140498931054, 0.0034600480876179063, 0.017524537179269828, 0.01965019469935214, 0.012622120211744914, 0.015130550600588322, 0.008120165202853968, 0.033609129750402644, 0.0422951667860616, 0.04458039162273053, 0.06738469353877008, 0.029578627763839904, 0.009699935071694199, 0.03477325888525229, 0.01671183908911189, 0.022341997719195206, 0.04329889183281921, 0.05154350685188547, 0.03629463564720936, 0.03281605590018444, 0.074753136432264, 0.03370848477061372, 0.02621409385028528, 0.018787522240018006, 0.044421605416573584, 0.03202191706805024, 0.04566262476146221, 0.013965421421744395, 0.01855342103226576, 0.08360173349501565, 0.08349948038812727, 0.04983191392966546, 0.10236944595817477, 0.029071173157717567, 0.05655673667206429, 0.006541348993778229, 0.042026308947242796, 0.019216314758523367, 0.07653084729099646, 0.05170285337953828, 0.02102335900417529, 0.01650442365644267, 0.006783699636798701, 0.05066238831204828, 0.03228533867513761, 0.06521027506096289, 0.03515317541314289, 0.046624789538327605, 0.0813315185951069, 0.025025130598805845, 0.0770736466802191, 0.03534468662110157, 0.03607382073823828, 0.04730709413706791, 0.058164358415524475, 0.025535023160045967, 0.06655421544564888, 0.029563254174718168, 0.01717501159873791, 0.020812774600926787, 0.07087571910233237, 0.040054407727438956, 0.012929893491673283, 0.020805919011763763, 0.02266283001517877, 0.05397424458351452, 0.026059207630169112, 0.04220868431730196, 0.02361785533139482, 0.015305402448575478, 0.06359943610732444, 0.010036124258476775, 0.02694974773476133, 0.0714312017953489, 0.08363199085579254, 0.04451931286894251, 0.018534446171543095, 0.06799786337069236, 0.07492269491194747, 0.01973784419533331, 0.03166811671690084, 0.032091014727484435, 0.03556742369255517, 0.06755858616088517, 0.0431988132186234, 0.047565446875523776, 0.034348446133662947, 0.017803627379180398, 0.1175811281427741, 0.03375634587428067, 0.03614012792240828, 0.03327262144011911, 0.06068821341614239, 0.050737823912641034, 0.004246890448484919, 0.08759601681958884, 0.047231717908289284, 0.0509634219633881, 0.033790974484873004, 0.06178068077133503, 0.058425408860784955, 0.04268014105036855, 0.04774384062329773, 0.016991454358503688, 0.028813827884732746, 0.0077655290078837425, 0.04699570381490048, 0.03609653045714367, 0.041943878604797646, 0.05151967277924996, 0.04740750300697982, 0.03352328552864492, 0.013987016063765623, 0.062359203438973054, 0.03279858203313779, 0.021123068399901967, 0.08178695978131145, 0.10625034396070987, 0.0306615659428644, 0.00875936586453463, 0.028526115784188733, 0.08102044739644043, 0.04367687877675053, 0.037642732058884576, 0.09835230448516086, 0.08636331695015542, 0.013290862061694497, 0.060899488016730174, 0.014126292135188123, 0.018411715354886837, 0.05152668978553265, 0.02194356460677227, 0.01080520540199359, 0.0656164599058684, 0.05381455295719206, 0.024819921200105455, 0.023543384522781707, 0.01359287813102128, 0.042879530155914836, 0.03304028468846809, 0.10207585233729333, 0.08191275381250307, 0.006445255712606013, 0.026642570956028067, 0.014610051821364323, 0.04622214844857808, 0.030295434808067512, 0.033802670732256956, 0.011220643900742289, 0.04821136768441647, 0.0018786690338856715, 0.017003842658596113, 0.069448910508072, 0.03847443098493386, 0.015926062405924313, 0.10188630039920099, 0.04126980813452974, 0.01774111071426887, 0.029550259168900084, 0.0012371546108624898, 0.07012793110334314, 0.051590187940746546, 0.032837099497555755, 0.06005233386531472, 0.06507708923891187, 0.08346027272637002, 0.02475241359206848, 0.03273480928328354, 0.0669265806209296, 0.032757949447841384, 0.0069283994162105955, 0.026664371544029564, 0.03766282941796817, 0.03398774751985911, 0.021414044094854034, 0.041786038636928424, 0.025406423810636625, 0.09963730350136757, 0.018391436169622466, 0.019139216747134924, 0.0538236628199229, 0.03814303607214242, 0.013980772746435832, 0.02802269660605816, 0.05164904025150463, 0.028843883010267746, 0.08097739540971816, 0.04743873258121312, 0.03430283744819462, 0.057097435783362016, 0.03390658996067941, 0.04671420720114838, 0.1391798519762233, 0.05923541109950747, 0.03269837354309857, 0.012527118815341964, 0.03743512737855781, 0.02855337857909035, 0.04315059217333328, 0.08583495975472033, 0.03781541126954835, 0.02627395177114522, 0.01762039482855471, 0.02371839407715015, 0.043971904742647894, 0.06796347224735655, 0.053685853417846374, 0.023898622785054613, 0.07120624199160375, 0.01425276337613468, 0.0991752720437944, 0.026214143945253454, 0.0411981983052101, 0.06838612534920685, 0.02784117285045795, 0.08155898685799912, 0.054173767275642604, 0.026875781586568337, 0.06131776244728826, 0.06178064737468958, 0.07180204556789249, 0.051592425515991636, 0.025209498635376804, 0.04621448948455509, 0.05287877153023146, 0.06805184719269164, 0.0476817228627624, 0.010548864811426029, 0.02627213722007582, 0.03705264301970601, 0.017411569315299857, 0.02535439925850369, 0.05413838167442009, 0.05377035806304775, 0.011482650788821047, 0.03229516099963803, 0.056011161650530994, 0.025870386707538273, 0.02682964041014202, 0.04329522191255819, 0.019443393393885344, 0.03427317751629744, 0.027670282215694897, 0.13040738442214206, 0.03158317049383186, 0.031242391123669222, 0.09665336518082768, 0.03043400120077422, 0.031210786764859222, 0.03504504820739385, 0.09149276709649712, 0.03542454171110876, 0.0777195006958209, 0.07441037552780472, 0.055087629370973445, 0.029433083327603526, 0.036393515692907386, 0.0668693239276763, 0.05651953280903399, 0.018021616560872644, 0.0234184959117556, 0.008423837189184269, 0.022597318784391973, 0.17464553093304858, 0.053002576605649665, 0.030271211107901763, 0.08463225749437697, 0.02219358673755778, 0.01211821492688614, 0.02142925441148691, 0.03244819185056258, 0.03336918227432761, 0.07556561002274975, 0.03975452440499794, 0.2002307603834197, 0.040835996842361055, 0.015396163398690987, 0.03228800298529677, 0.017423946483177133, 0.01612012660189066, 0.018467246554791927, 0.02436086204397725, 0.015101906483323546, 0.0627616404381115, 0.0550732762349071, 0.089727153244894, 0.03790856935665943, 0.056586363207316026, 0.034452409890946, 0.044115595665061846, 0.00618850833234319, 0.03396843312657438, 0.0832305260701105, 0.014542888384312391, 0.022553726885234937, 0.03837475313048344, 0.012299394511501305, 0.032682109376764856, 0.10367689494160004, 0.008091733525361633, 0.040758305112831295, 0.0682118245458696, 0.010894381866819458, 0.04609607611200772, 0.021793259293190204, 0.015775248721183743, 0.04424636950716376, 0.007306538964257925, 0.029770719702355564, 0.031017666951811407, 0.07297794145415537, 0.0527559535112232, 0.044243605007068254, 0.029478756950993557, 0.034294013312319294, 0.09144051990006119, 0.029797195820719935, 0.042382447063573636, 0.004877842138739652, 0.041145060531562194, 0.038049306531320326, 0.16321172181051224, 0.10601091969874687, 0.09457547785132192, 0.13972705230116844, 0.09667171107139438, 0.15477114269742742, 0.16243966558249667, 0.2027879934757948, 0.1664386986522004, 0.18614493106724694, 0.13709898863453418, 0.16013508924515918, 0.18342441064305604, 0.11763854810851626, 0.15571798954624683, 0.1550084221526049, 0.25913282472174615, 0.1631293137324974, 0.11150556587381288, 0.14788816828513518, 0.1618447303189896, 0.11071957953390665, 0.11562870829948224, 0.18161434214562178, 0.1667074451688677, 0.10884548595640808, 0.16121996071888134, 0.1673370535718277, 0.17858185252407566, 0.14795536233577877, 0.13738927227677777, 0.09848474073805846, 0.18476097407983616, 0.07846035703551024, 0.10633011741447262, 0.1894859760068357, 0.2679249888751656, 0.11952082015341148, 0.16590007755439728, 0.1371032337192446, 0.15534324949840084, 0.18446136906277388, 0.09688546444522217, 0.13600899634184316, 0.14482253434835002, 0.11153007159009576, 0.12997880898183212, 0.23709829692961648, 0.1597526902332902, 0.07101380309904926, 0.11588137247599661, 0.13209194090450183, 0.1546062671695836, 0.13502879737643525, 0.18361698312219232, 0.17124147765571252, 0.10742454775027, 0.09068288360140286, 0.09606289764633402, 0.16207772016059607, 0.24360970768611878, 0.1743496663402766, 0.11197528598131612, 0.17222663416760042, 0.0920597456570249, 0.19237214379245415, 0.15883362939348444, 0.11707735087838955, 0.11304593048407696, 0.15312615752918646, 0.17458209214964882, 0.1633983719511889, 0.1137338939588517, 0.17698489915346727, 0.22366376157151535, 0.13166185148293152, 0.28314245981164277, 0.15979355288436636, 0.12897843844257295, 0.24345180834643543, 0.13312907743966207, 0.15265640773577616, 0.11629521628492512, 0.2163208634010516, 0.14185614039888605, 0.16968779149465263, 0.09466230170801282, 0.18760623468551785, 0.16093830083264038, 0.11224554647924379, 0.1413992149173282, 0.13586712739197537, 0.1419626534334384, 0.10064032350783236, 0.15924244886264205, 0.21944181702565402, 0.14718900580191985, 0.10764215287053958, 0.19376920710783452, 0.1440611798898317, 0.10761122757685371, 0.15671261586248875, 0.24264634063001722, 0.08355939397006296, 0.2166844712337479, 0.1440114708384499, 0.20726752263726667, 0.1910759977181442, 0.23362512001767755, 0.18712150835199282, 0.12478797580115497, 0.11120415743789636, 0.08235091780079529, 0.0747876834066119, 0.16432084667030722, 0.15735316352220252, 0.12371757620712742, 0.150931567477528, 0.23281536268768832, 0.19688628672156483, 0.16418956074630842, 0.15154216205701232, 0.08490657011861913, 0.13728638092288747, 0.0956247336580418, 0.10145330175873823, 0.17010557610774413, 0.23513107124017552, 0.10688277252484113, 0.34050572547130287, 0.11125451215775684, 0.10180234865401872, 0.08868651377269998, 0.19415257091168314, 0.08385300243389793, 0.10712690942455083, 0.10068071860587224, 0.1640996866626665, 0.10471682195202447, 0.11300566155114211, 0.12905032286653295, 0.1642675159382634, 0.2283272542990744, 0.06257260058191605, 0.13360831188037992, 0.15005596680566669, 0.10272692365106195, 0.12457451928639784, 0.1655054182629101, 0.07737187872407958, 0.14817529037827626, 0.10008474433561787, 0.16590050800004974, 0.185847730608657, 0.13125889498041943, 0.21949795307591558, 0.24981605121865869, 0.0745895819272846, 0.2033757299068384, 0.14105527399806306, 0.09051249391632155, 0.11959932453464717, 0.07020082484814338, 0.10428872890770435, 0.17753431107848883, 0.124237591662677, 0.07363424490904436, 0.11367764658643864, 0.19883391971234232, 0.10421301500173286, 0.14682551671285182, 0.1732658190303482, 0.1530281049781479, 0.1380658586276695, 0.21036033402197063, 0.12159884106949903], [0.01918037625728175, 0.035644425224745646, 0.008480506658088416, 0.05887690553208813, 0.03880057149217464, 0.009591814359737327, 0.035738767037400976, 0.10224611585726961, 0.012094331686967053, 0.07299768258235417, 0.031243990451912396, 0.02233378585515311, 0.06867897682241164, 0.008758841722737998, 0.026031139605038334, 0.02093051818519598, 0.041038955678232014, 0.05713924838346429, 0.02094886778650107, 0.02752867487288313, 0.01993629448406864, 0.08641741951578297, 0.013879826747142943, 0.06011913457768969, 0.015284359778888756, 0.014349917928484501, 0.04897993210761342, 0.01563817961141467, 0.05964960000710562, 0.016454235919809435, 0.03664044306788128, 0.0698422190907877, 0.038039057471905835, 0.01627316487429198, 0.010791816130222287, 0.015299914266506676, 0.023908862567623146, 0.009445922969462117, 0.04008681731647812, 0.05759930572821759, 0.04686852567829192, 0.06690390800940804, 0.017875266894407105, 0.021714033173338976, 0.02928626796347089, 0.05216623183514457, 0.013432904488581698, 0.031063613314472605, 0.06686530148726888, 0.03268620232120156, 0.02892825777962571, 0.020228097673680168, 0.04774910616106354, 0.06515100714750588, 0.021470352694450412, 0.03941132563340943, 0.02300747040862916, 0.010588922232273035, 0.05695568186638411, 0.04778456597705372, 0.0769345904700458, 0.09373728884384036, 0.022702449568896554, 0.06900473512359895, 0.011200955650565447, 0.056132198515115306, 0.010716117067204323, 0.011207327916054055, 0.06179187977977563, 0.047211568598868325, 0.041140804314636625, 0.030507076771755237, 0.006894522693983163, 0.09057437418960035, 0.032207550466409884, 0.028230078642081935, 0.022717285100952722, 0.02159574782126583, 0.04873813668382354, 0.025910831900546327, 0.0279184248574893, 0.029039142063993495, 0.008013733804546064, 0.0032806387571326923, 0.018582676493679173, 0.008950050505518448, 0.04667946355766617, 0.07626402293681167, 0.02744328336120816, 0.05535804571991321, 0.012527087274065707, 0.022050871739338618, 0.03329770974232815, 0.024719553148315754, 0.04025263537187129, 0.06001737870974466, 0.027030356104660314, 0.022107224867795594, 0.04634024269762449, 0.045566460976260714, 0.014345802719617495, 0.062347818893613294, 0.008022868714760989, 0.005991756634102785, 0.015177622244664235, 0.03016084447153844, 0.05703206370526459, 0.023307659866986796, 0.08682868807227351, 0.023665152402827516, 0.037821615624125116, 0.05207289934332948, 0.055035690165823326, 0.015456688324775314, 0.010524862827878678, 0.07684466443606652, 0.10639287342200987, 0.04256472224369645, 0.03308755207399372, 0.07974236519658007, 0.09035643510287628, 0.048026324293459766, 0.029064055961498525, 0.017916819742822554, 0.02391310208622599, 0.048645624265191145, 0.010835294851858635, 0.009662746979302028, 0.016144732508109882, 0.03884510777425021, 0.04988017950381618, 0.05472967299283482, 0.015906651533441618, 0.017231422243639827, 0.030719689093530178, 0.03362706374900881, 0.019636865727079567, 0.03795851218455937, 0.027405658329371363, 0.022581700286536943, 0.06263164585107006, 0.03435913306020666, 0.054927403398323804, 0.0768963253358379, 0.05417547050456051, 0.052469848160399124, 0.031986319954739884, 0.06989369445363991, 0.10950864685582928, 0.05837221171532292, 0.023586542265547905, 0.019996545743197203, 0.05964142896118574, 0.020930249156663194, 0.07246968161780387, 0.012096868904336588, 0.023341130727203563, 0.07279290919541381, 0.06253521860344335, 0.0507304395432584, 0.06106308333983179, 0.018310772138647735, 0.03454280347796157, 0.02571711465861881, 0.048233105189865455, 0.018895725515903905, 0.02040594965365017, 0.0396865882066777, 0.03345046970935073, 0.10986375709762797, 0.09142241891822778, 0.03697077670949511, 0.025010489880514797, 0.05813685813336633, 0.031400175430462696, 0.07288333246833645, 0.0152200127922697, 0.06652416588622145, 0.04138765005336609, 0.04654285643482581, 0.01870465959655121, 0.021862138019059785, 0.043518923775991425, 0.014803646608925192, 0.02079892798064975, 0.03350505467096809, 0.06073624150303658, 0.039833336777519435, 0.03708008393005002, 0.03351059480337426, 0.0659634436306078, 0.024487741466145962, 0.04733480964205228, 0.04273445512808394, 0.04013219593616668, 0.02813284987496445, 0.05094417807413265, 0.052664398463093676, 0.041781975378398784, 0.04893189288850408, 0.03813561830611434, 0.10381621832493693, 0.04512578481808305, 0.03462448425125331, 0.04954036863637157, 0.0180648058449151, 0.024836250304360874, 0.06098339152231347, 0.010714381369325565, 0.09136222332017496, 0.020769748589373194, 0.03902811025909614, 0.11311299094813876, 0.02249093562568305, 0.05042910161137115, 0.011700729955919087, 0.032369739419664256, 0.01643395302380668, 0.06363378270179965, 0.0044679340317088645, 0.012551532690849854, 0.04469973639061209, 0.034071328191203065, 0.03411230587516911, 0.07111794868251309, 0.06346366018988192, 0.01683468493865803, 0.06364309665514156, 0.0280464360548649, 0.02179015711590182, 0.05431227429653518, 0.0016853835131769301, 0.03760032574064098, 0.04695620300481096, 0.06906641501700506, 0.012366880782792578, 0.03436324455833528, 0.02730483014602214, 0.03425642353249714, 0.015185140200628666, 0.01460760458940058, 0.013832382173859514, 0.004163604780842434, 0.08147106462274678, 0.01212298879181617, 0.060465476344688796, 0.07874877788708545, 0.05659399619617034, 0.026953254382533487, 0.037549169501289725, 0.027674467928591184, 0.022399961308110505, 0.04711402812972665, 0.038564909918932244, 0.030840930048725568, 0.020679870794992894, 0.02330032002646476, 0.007106890570867108, 0.04598824576532934, 0.11842133579193614, 0.01749348572047893, 0.0431348734855419, 0.07088846919941716, 0.11579672311199829, 0.05810223694425076, 0.020416020597622264, 0.0352290859882487, 0.04121347170439549, 0.016389182965212967, 0.0565494302281877, 0.01075278380085365, 0.03361021699674893, 0.0452621284784982, 0.027942117922066245, 0.026920165728370193, 0.010476186289452016, 0.07820253493264318, 0.024021670869842637, 0.042892966739600524, 0.021290706572472118, 0.006304176686171559, 0.07583819344290532, 0.0318413525383221, 0.036773016618099064, 0.051186400232836604, 0.042768041021190584, 0.03486990877718199, 0.038852414218126796, 0.033386993818567134, 0.030375651695067063, 0.07132464423193596, 0.030624662649643142, 0.10078323146444745, 0.002460871710354695, 0.05007268518966157, 0.031401229280163534, 0.04235639396938495, 0.017088616332330275, 0.05191385338548571, 0.06261148169869557, 0.003182107288921543, 0.06340514184557833, 0.04793981584953144, 0.04600919288350269, 0.06510796258226037, 0.05091952763905283, 0.012286465371289523, 0.05319909359968733, 0.019432329827395733, 0.045112366788089275, 0.06273530903854407, 0.018397577441646717, 0.0540660964907147, 0.029182862672314513, 0.03932669111236464, 0.01836992501921486, 0.05618715826130938, 0.042175521448371, 0.07380333583569154, 0.04788749443832785, 0.05395903797762003, 0.023761256816214882, 0.03069336511543952, 0.006683019882984809, 0.07651314706890844, 0.04755274501803797, 0.008047764986258699, 0.02087033928546589, 0.03428726347920019, 0.0345924828434363, 0.049302187471766956, 0.04044979432364926, 0.038002451037755236, 0.02170928899431601, 0.0649567499931436, 0.043380019706091844, 0.011948469054914312, 0.031459643723792396, 0.05918290415138472, 0.055420909338863567, 0.03138401145406533, 0.009682217223598855, 0.08047317285672761, 0.024521197483409196, 0.02471663465257734, 0.08467405525152571, 0.0882172241108492, 0.03071309140068479, 0.02929371356003685, 0.02643001058459049, 0.003960123194701737, 0.03419374545046594, 0.17313549789832905, 0.15309743641410023, 0.17263744259253144, 0.11058795964345336, 0.17352534807287157, 0.062116847693687305, 0.10497920084162615, 0.22289042884949595, 0.13037541270023212, 0.2206882243626751, 0.17005601548589766, 0.10768228821689263, 0.12857574911322445, 0.07332014574785717, 0.16435399098554626, 0.14952190249459818, 0.22978947818046436, 0.1074094302020967, 0.14919709414243698, 0.11669907078612596, 0.12764381943270564, 0.14705507783219218, 0.15659139346098527, 0.10830109094968066, 0.0940580821770709, 0.13935425668023527, 0.214659818157088, 0.09594762726919726, 0.133674823155161, 0.15622750361217186, 0.12009813683107495, 0.13537897233618423, 0.09915351969539188, 0.20449101459234953, 0.13240986212622374, 0.15372622845461592, 0.16586285142693669, 0.08712184382602572, 0.18322411982808262, 0.13578363577835262, 0.11109486877103336, 0.12582793249748647, 0.12318959750700742, 0.11281827668426558, 0.12339358421741053, 0.1274742090026848, 0.08546756696887314, 0.12671215692535043, 0.10638762643793598, 0.12236413633218035, 0.08318374108057469, 0.16999967163428664, 0.08049945230595767, 0.1596765310387127, 0.09951925007044338, 0.0878191583615262, 0.13772083417279646, 0.18095099570928141, 0.1620987823116593, 0.13957336836028844, 0.14486738975392655, 0.14375563769135624, 0.22330684791086242, 0.10102234402438626, 0.06453904701629654, 0.10379672210547142, 0.11017719574738294, 0.18347628676565364, 0.11772235884563997, 0.2054305883939378, 0.2558967046206817, 0.1793077916954644, 0.11113150118035264, 0.1331675355322659, 0.09469940167036839, 0.14137683174340054, 0.15962256205966696, 0.16356830892618746, 0.13114518311340362, 0.10038257561973296, 0.13728943857131526, 0.10286308548529632, 0.12579066184116527, 0.10885002790018916, 0.09704218377009965, 0.09569140820531175, 0.10564400188741274, 0.28181184839922935, 0.10848189296666533, 0.08995372350909747, 0.11211646473384462, 0.16732295276597142, 0.14156922610709444, 0.1612252596532926, 0.10693671181797981, 0.13228317751782015, 0.08872986261849292, 0.10970434377668425, 0.17950984882190824, 0.09776038234122097, 0.20251690177246928, 0.1597273236257024, 0.08703697923920117, 0.07855426098103635, 0.11167018164996989, 0.1972667858353816, 0.15095430688234046, 0.1295575956464745, 0.18147285911254585, 0.10485804523341358, 0.10897119835135527, 0.0990263897983823, 0.14628109202021733, 0.08251013816334307, 0.16774896037532017, 0.1278908210224472, 0.14491459034616128, 0.12255272347829305, 0.12905657174997032, 0.22410750651033595, 0.13619085220852867, 0.09226828173268586, 0.216447236307431, 0.11728683690307662, 0.09599496886949055, 0.15964086342137307, 0.08529429775080644, 0.10735597330494784, 0.1729053133749403, 0.14763266168301925, 0.15869958268012851, 0.12566397723276168, 0.22982407710514963, 0.10157212702324614, 0.0779599862289615, 0.1743339773383923, 0.12076514947693795, 0.10026504911365919, 0.18384174996754155, 0.13137570902472362, 0.21862563269678503, 0.12103121684049256, 0.1391214449540712, 0.13842900632880628, 0.13906928681535646, 0.09122886680415832, 0.1108605504850857, 0.1647280779434368, 0.1881459096330218, 0.16300728981150314, 0.1261256673024036, 0.10142640632693656, 0.12871202226961032, 0.12042084490531124, 0.1713040703907609, 0.12919802509713918, 0.11166580297867768, 0.20479146565776318, 0.1805314002558589, 0.17409257154213265, 0.12752028153045103, 0.08011174693820067, 0.14111552154645324, 0.12389916490064934, 0.11955860289162956, 0.16513101960299537, 0.1733495926600881, 0.1781914383172989, 0.27545321616344154, 0.2212559079634957, 0.2561865875031799, 0.15019986924016848, 0.1265275402693078, 0.19498273730278015, 0.13587095687398687, 0.16061824222560972], [0.03341639028803911, 0.07627331462572329, 0.07619521842570975, 0.0604151698644273, 0.044993214978603646, 0.04456389739061706, 0.025338248269690666, 0.03714260245033074, 0.019579798281483818, 0.037634720574715175, 0.03835147566860542, 0.03494968965242151, 0.018080890040437225, 0.0053309937993617496, 0.02722453162277816, 0.05396181360993069, 0.018271067237947136, 0.013352327659958974, 0.048833276305231266, 0.07325589802348986, 0.04333828132075723, 0.021688059860025533, 0.06386362583725713, 0.011392924207029864, 0.020483329681155737, 0.07093203326803632, 0.11138632500660606, 0.05949686972599011, 0.059469117113621905, 0.027765624072344508, 0.0433704014722025, 0.034573071970953606, 0.03482389933196828, 0.05868893065780867, 0.00657279147162626, 0.04273290032870136, 0.0638759825960733, 0.07075266359606758, 0.04191253399767447, 0.06822259310865775, 0.0938955666788388, 0.07743732872768305, 0.0253298304596683, 0.049581127386773005, 0.02571403660112992, 0.037160221036174335, 0.04445664591912646, 0.023603218323842157, 0.08570889855036512, 0.06377513214829378, 0.02438423784042243, 0.02843521197064547, 0.06433001370169222, 0.023460238007828593, 0.03071198003453901, 0.04494682332733646, 0.04013320525700692, 0.036089465211261995, 0.04655137629015371, 0.031259022653102875, 0.05194219229451846, 0.04667987173888832, 0.0060800332448707195, 0.013241008291515755, 0.03867887411615811, 0.062465434457408264, 0.017219275141542312, 0.06459589552832767, 0.006076648123780615, 0.016625807475065812, 0.014833915101917228, 0.037479719321709126, 0.016317365334543865, 0.04207101963402238, 0.0220689133493579, 0.04740338779811282, 0.014069186654523946, 0.03477900681900792, 0.03178428138198797, 0.07096445027855225, 0.011646943730738712, 0.049969949686783366, 0.028763391528627835, 0.039006795777822845, 0.0065309895398968365, 0.032416134781669825, 0.05062752963567618, 0.04084469852386974, 0.016179784142877907, 0.07123479241272435, 0.048149984650081024, 0.017237075553566683, 0.04223196920065675, 0.018100067136401776, 0.0866541126742959, 0.026940643438138068, 0.06393649731762707, 0.014326953096315265, 0.02814886913256487, 0.008024007911444642, 0.05584657556028105, 0.07932915963465348, 0.019592386961448938, 0.016745983448345214, 0.0329401578346733, 0.07484960078727454, 0.02656909648067085, 0.020722852277685888, 0.07900670389062725, 0.02580449883680558, 0.028057050622010138, 0.022355901855917182, 0.038817974855192006, 0.08304184244479984, 0.03577208946808241, 0.04111397567612585, 0.0386550845723832, 0.05474866084114183, 0.02358890229515964, 0.02231029688118724, 0.056170192765421234, 0.09435411004233174, 0.02696649986319244, 0.019436144466453698, 0.031086747912922874, 0.06846467425930314, 0.08647956696222536, 0.029838483351340983, 0.01051797291438561, 0.03447636270720977, 0.04410132416523993, 0.009211800424964167, 0.047462485017604195, 0.04715885756013449, 0.04837831380427815, 0.021250868085189722, 0.046631238801637664, 0.07550749985966831, 0.040231320890598, 0.03305820755485911, 0.0512994293239899, 0.02883650791773107, 0.046813395238132216, 0.035686679402715527, 0.018725703193922527, 0.01645481479499722, 0.0077920598596392665, 0.03834910450677853, 0.027178329219168518, 0.02713821242650738, 0.029261402305564843, 0.021095480915391818, 0.032132671476574615, 0.03941573027987033, 0.033555127374711446, 0.07535861019277945, 0.04434837770531885, 0.02587473383755423, 0.04764775476360228, 0.001754060235725774, 0.006657599005848169, 0.06166741419292521, 0.02104234128637472, 0.04845376795856282, 0.007889385105954716, 0.006552130544150714, 0.0326730254892027, 0.040739703181316145, 0.019366338055988308, 0.027068242743553128, 0.03541746533301193, 0.02501229329936905, 0.03345478529809043, 0.018758031146717258, 0.03683259252284188, 0.06813237021560781, 0.02751328458543867, 0.07703807554207742, 0.037854333204450086, 0.048538691917201504, 0.036561497108777985, 0.06624571207794361, 0.02882938144466607, 0.08813990716589615, 0.028913553978782147, 0.023945893881318625, 0.06251588565646671, 0.06254565319977701, 0.0536687394924229, 0.00897425565199228, 0.04894185622106306, 0.056110015721060336, 0.0872467843873892, 0.027281971997581422, 0.029217682385933585, 0.019427279512456153, 0.040836019106791355, 0.014666503284388455, 0.053978441428625956, 0.010662162003427511, 0.08260542250354774, 0.08102371284621768, 0.0641994847683236, 0.03509615620714612, 0.021966476560919546, 0.019165282828907948, 0.046178142802091315, 0.033021790368366055, 0.07433645019773394, 0.023624902023584582, 0.02166968613892095, 0.09227012968040071, 0.032618934055790305, 0.06898446707054973, 0.01939624660735717, 0.013005478449485963, 0.027949003197136335, 0.03992780846601818, 0.030987624813860748, 0.01784183314157417, 0.01599730116140563, 0.029361556989897508, 0.027265551980235614, 0.03826657397439703, 0.04629337978258263, 0.01083513436242356, 0.0520189155213302, 0.044174017530167475, 0.04103986851987429, 0.015867529218667187, 0.03864303209411446, 0.052165545348543674, 0.07906484373961575, 0.02184511315135751, 0.06887678886414506, 0.06104219559347257, 0.03294749396445695, 0.017149244231404737, 0.03163890207360964, 0.021338443366403226, 0.027596143518167082, 0.01746888352499809, 0.029467969834513497, 0.03354993234097492, 0.04534029518254101, 0.0218030203905073, 0.030869057445670478, 0.028923493191541638, 0.01904437769553624, 0.0747409206815064, 0.03213608535588719, 0.03143061461742036, 0.024177672166842967, 0.012936572820763104, 0.009650364245317178, 0.030452115170191973, 0.02066545457637403, 0.054663128321408294, 0.018162468768423423, 0.04069871807587333, 0.016870252366061322, 0.053106121049495414, 0.01791772145224968, 0.04005758783023339, 0.03805927357461769, 0.03391797079530079, 0.045038174284854904, 0.0007176921712925832, 0.09127009310759604, 0.040097934688674286, 0.019207383011234924, 0.07647068137885071, 0.08004149523912929, 0.05514386190043297, 0.02074424653983442, 0.06024561880622059, 0.044904391033924185, 0.0534630681067938, 0.04191754349449184, 0.03834902658127248, 0.010456519376020879, 0.03170873074850533, 0.043673995533026755, 0.04947134148096666, 0.01970113386050798, 0.03981942150858231, 0.018173361640947405, 0.0345132956863381, 0.06934782999451272, 0.03528462089889217, 0.024794157543510664, 0.012232948174641933, 0.02357969595323084, 0.030879389996698592, 0.06277807900914922, 0.028397735368344, 0.03179872357577551, 0.0793430526391603, 0.026169229167862795, 0.053705282844020985, 0.013924343547842, 0.03819438898062799, 0.03256509495258797, 0.02925967681221664, 0.051346188338357024, 0.043432144448161125, 0.06361592662869953, 0.019409406741033308, 0.0191444229130866, 0.01835360333643621, 0.03330505329358857, 0.031462107654078864, 0.028100048803025857, 0.045630129825440235, 0.011065406088164309, 0.0652594275015872, 0.06532308150781319, 0.024737147614359856, 0.023908181647129823, 0.016976954648271203, 0.024776982390903868, 0.05365469063690398, 0.042512189320405014, 0.02951740985736251, 0.019234998326282948, 0.02655962667631684, 0.007706852029514266, 0.04771969855937641, 0.03552377427695319, 0.04564433453197125, 0.07292053633136675, 0.030118963222776074, 0.04800732902367599, 0.027814550157927442, 0.03649251077149529, 0.050933049569721334, 0.010117173278558766, 0.03427795323659666, 0.04572143996483646, 0.036760704388143495, 0.016577475107624196, 0.04299517902836669, 0.0821162952343002, 0.06763157638488337, 0.022725124035787303, 0.055134336435003206, 0.053386419094749726, 0.02667916069185594, 0.061433812079485506, 0.03320049952890258, 0.06463417550548911, 0.041232311123167165, 0.1311373311909847, 0.1774098677560687, 0.19154895358951762, 0.20180552353849635, 0.12818664108635858, 0.16393420257372782, 0.10607683725538664, 0.15158544410951436, 0.11382347118342295, 0.12222891702549532, 0.14119151746854186, 0.0979923183331266, 0.13563614134909585, 0.08440996200079098, 0.1145579747390002, 0.14779545919736847, 0.17120701231760904, 0.06265889009227976, 0.2082781051285565, 0.11946251703193411, 0.11072127163060941, 0.14394050667760894, 0.14126816648058593, 0.10832837971975096, 0.13885232736356556, 0.20798658952116966, 0.16184471547603607, 0.14975152298575267, 0.20834762952290475, 0.13008964131586254, 0.15670843014959246, 0.06673409719951451, 0.14107238792348653, 0.13135175249772146, 0.120043062051991, 0.2684211591258645, 0.12534141016658396, 0.15007740003056824, 0.1764707244001329, 0.14308176760096103, 0.11539001134224236, 0.2573080617003143, 0.12703729182248935, 0.11755252577131614, 0.10772610461572185, 0.09847692592302337, 0.10276630942826159, 0.10058157509774901, 0.07880198987550102, 0.1382581639336422, 0.1409520412562415, 0.0655133459076751, 0.15716304013039917, 0.10874407889787108, 0.1848427439108491, 0.10783870326122269, 0.17936325981281698, 0.1509567114408128, 0.22641704039415345, 0.16996078309603035, 0.13094808353343979, 0.14501458732411265, 0.108703817386413, 0.09077657232410274, 0.14391395263373852, 0.1652472696150653, 0.09225799556588754, 0.1153414897271432, 0.12502222729381174, 0.1302129268879071, 0.11273046577116475, 0.09467553420108743, 0.1050565400510095, 0.24676966859260574, 0.11974517881753854, 0.14631165366154164, 0.12790751934517175, 0.1668201180291362, 0.12675411795498803, 0.21165566373383626, 0.10846522432984784, 0.15317920624511316, 0.14403645152924582, 0.13780440000118688, 0.10963484164676629, 0.1131620914384257, 0.1104488292185124, 0.07947223086375743, 0.12573651474667713, 0.1180351221410092, 0.13932031084550545, 0.1060609330306761, 0.22301711345789954, 0.12373589241178706, 0.1273106099688448, 0.14982845401391387, 0.1775919907959178, 0.22632072446867824, 0.1351340487599373, 0.17977291048737243, 0.10866000840906054, 0.2721982158254832, 0.15135373076191172, 0.1188470094348304, 0.1481563804554753, 0.19612616422818974, 0.14264989702496678, 0.11767676871386357, 0.13472187478328124, 0.06335599682643078, 0.09098753522266634, 0.12824139674194157, 0.09232982803951018, 0.12691838492173702, 0.18153334414819255, 0.20189121190924197, 0.11705409939168021, 0.14211847475962713, 0.10351585631724447, 0.15955849987221882, 0.1408238723524846, 0.2703448059037328, 0.08286924858111888, 0.20016049384139478, 0.05408799726865254, 0.13360017794184387, 0.17798135115299374, 0.18495655967853963, 0.12859176466008648, 0.11820325569715351, 0.22044806537451223, 0.1766043109819293, 0.11574728865525685, 0.09461673384066671, 0.08389006528886966, 0.12495866976678371, 0.14381074957782403, 0.14474066061666235, 0.11416103705414571, 0.2253023345838301, 0.14608667901484296, 0.13090309454128146, 0.15436698391567916, 0.10593992585199885, 0.08186251783627085, 0.2207747587817721, 0.19838003703625873, 0.1298063190188259, 0.10137296427274123, 0.08415540534770116, 0.08946377245592885, 0.11247009068029001, 0.13891371781937778, 0.16497053758939728, 0.08809746374026872, 0.3310237202094868, 0.11723968083970249, 0.0903021395788528, 0.15372728230431676, 0.14010103535838425, 0.16704795736586675, 0.19702730962308124, 0.1075183181092143, 0.1533771667163819, 0.07128979297704063, 0.17079464538255706, 0.1335596715216525, 0.12207144070998766, 0.12200776443933137, 0.14290573017206043, 0.14645600138464943, 0.09307266591349617, 0.17488067300291732, 0.07770669864839874, 0.20593073655618355, 0.2808074257336557], [0.015088465261214878, 0.04258637440216262, 0.013681888540304499, 0.0014254850202632952, 0.02983968563057715, 0.026355482259532437, 0.026324289792682976, 0.03889916210027877, 0.05681941613147501, 0.03565285231161397, 0.062234990182332695, 0.03982701739005279, 0.028513762736110948, 0.011788992651418084, 0.030607153530581854, 0.031225618586177006, 0.007221280111480155, 0.07076848618453369, 0.02445943966449704, 0.026454399412614293, 0.041483171880827285, 0.02963533712318167, 0.019747102487599477, 0.017642191705817822, 0.05900039890548214, 0.028575346150319092, 0.030680423915327992, 0.0278747364791343, 0.05884255893761292, 0.039352606909233145, 0.002898636098507268, 0.04862361587584019, 0.026549431422608905, 0.06130677124019712, 0.03827797336271033, 0.00641800080302346, 0.05956658336799592, 0.03735865648195613, 0.06797620008001104, 0.0771192590764258, 0.06367406647768803, 0.02307084054336883, 0.05393122228269931, 0.021694831957574934, 0.016374733349948656, 0.033385802671546116, 0.01285331776671228, 0.08145183557644486, 0.07344395082327537, 0.050883648509625345, 0.03915241999493446, 0.024459345040668268, 0.05213388903939631, 0.03459415638644714, 0.05555913063290063, 0.04245860625815112, 0.03882623866957147, 0.02968593304103706, 0.03939456793887075, 0.035817063617287204, 0.02461666736053303, 0.031007540346763562, 0.022459275605797302, 0.04783942553331144, 0.014613486109738005, 0.03559000353561714, 0.012166724482085556, 0.006852321394035243, 0.009640925982239423, 0.08329173098900355, 0.01864636204118142, 0.041725126866367646, 0.05481360618432518, 0.02579615709692007, 0.06214229593751952, 0.03017746115801856, 0.0571823152131401, 0.04197487069177441, 0.058127269585384056, 0.02028499628067948, 0.03906025638571009, 0.02790407172142295, 0.050045678435708396, 0.0752883956010919, 0.033267693579546176, 0.07683065268793143, 0.044519643124658614, 0.06324442234472372, 0.03804763298830949, 0.005338707032933598, 0.019920457052649, 0.0319428931834409, 0.11086594589869492, 0.017754573273123242, 0.03720959983184002, 0.07353463384788483, 0.05219888633291703, 0.024183880232158117, 0.04566153380437754, 0.0390071149013238, 0.054457839141832665, 0.014900464411766734, 0.03816232820099685, 0.01083646002371097, 0.05971057486021891, 0.028954921290278435, 0.042701103011495434, 0.040958466051961295, 0.048057654057629406, 0.038926625275053084, 0.011848168724100105, 0.05378016925533302, 0.02320627507288009, 0.05095134722068906, 0.011535680023371242, 0.016139223916979972, 0.03044886270799907, 0.02876211317925481, 0.022251702466746792, 0.03834431765426416, 0.026696667955548037, 0.03437086270423606, 0.042992117669200525, 0.0426781595160719, 0.06949458227609284, 0.04837979067815468, 0.06476909795310348, 0.05440705397631973, 0.043957755697192624, 0.041113055413006805, 0.08325311704538763, 0.04757608185173012, 0.01978099266125355, 0.0240686209872365, 0.08299551016534679, 0.05554015391680878, 0.04483415417780634, 0.02213861771451775, 0.033377423824276775, 0.021015790953242686, 0.04912999807856977, 0.09394373206305318, 0.06522929630591534, 0.040286640578415245, 0.08451657893601805, 0.004711515248345677, 0.036848734234808944, 0.0509864619380096, 0.020636711196857505, 0.036905115193803795, 0.035605143348220736, 0.03661649767309427, 0.02621538889798103, 0.032167378012673, 0.023307396404561587, 0.021028158844274003, 0.016752204501244705, 0.017047419714799616, 0.10109252150868997, 0.03843649239570368, 0.028596623524208553, 0.06555751853738911, 0.03721840170328505, 0.010678412254492287, 0.047993640109780245, 0.034431436797603965, 0.020827817934332415, 0.01922627809108235, 0.02800637492327951, 0.056122019959730096, 0.015610102309437934, 0.023210445942822844, 0.021472905682458077, 0.026989226280420553, 0.02842347304977011, 0.017565184607519768, 0.0915019994135946, 0.01742318763717776, 0.04978797136573121, 0.059237811947241426, 0.03497540506941732, 0.07374316992354579, 0.009653436736698495, 0.03305262289359234, 0.01301509111726773, 0.03986605064710602, 0.027973308533546515, 0.034949474429595284, 0.02825731546181487, 0.013431429470074363, 0.05353569096769206, 0.017743468888511416, 0.032436996552860364, 0.097189373918809, 0.007656442576262634, 0.05494453587743919, 0.04514605287113227, 0.0354838689963799, 0.026217483609798364, 0.0559316627914086, 0.061971093600732274, 0.025417613542231265, 0.027491053551784717, 0.03355962850037031, 0.028720898008032236, 0.05104634583403822, 0.01993839476199355, 0.02297697741596494, 0.016920853850024287, 0.005959351683486602, 0.03934594613383524, 0.038796745720901527, 0.12709822214674205, 0.03516278251481708, 0.0544961191189941, 0.045641432734555565, 0.03637013061961625, 0.08822295349091291, 0.015526695115113398, 0.05000248544092756, 0.0603209987457376, 0.06822338720667176, 0.008338897459907457, 0.013316726835910231, 0.03698694068589248, 0.019520394926075824, 0.0427878229675116, 0.012576799108501291, 0.033867794190882705, 0.02921139825048158, 0.02951299407868646, 0.06175436792545952, 0.05436153063783422, 0.04524019801465329, 0.029943853478471283, 0.028983783413423225, 0.07699877882259898, 0.043860074219992384, 0.030657452589366585, 0.009305421426688554, 0.028676268957497086, 0.016370404773624614, 0.03861075238091871, 0.03902888951415662, 0.020749944378621876, 0.03053961252589943, 0.05792295633000322, 0.024939867107605096, 0.034709252358879894, 0.05579916345595848, 0.00984660107860691, 0.05001410376280546, 0.028521848435048014, 0.03684125709696673, 0.056722417430137284, 0.03760067455004901, 0.047792529221624136, 0.06235431268578395, 0.030962467862991616, 0.045710882914136164, 0.11670232881442644, 0.03298193703813013, 0.021663839870598167, 0.010299386303813662, 0.01873993758636061, 0.013292737839947222, 0.10649023577570915, 0.03728695017343853, 0.05909023959247861, 0.017241151799680665, 0.03282052362919785, 0.05122682130604517, 0.057249854362453334, 0.027556600034586154, 0.035604360382421874, 0.02766256387985777, 0.041102565155597404, 0.057004789778147824, 0.04237664346874226, 0.09844200045336038, 0.058074157786904834, 0.031829585786908865, 0.02817665328620933, 0.04357158286438789, 0.0756766353151761, 0.017018071484926622, 0.06089661590522155, 0.08604269431089051, 0.0483964073646348, 0.03232741844840348, 0.02197973502916284, 0.031233114277711138, 0.0459909991332097, 0.028522217653517146, 0.031876704742899165, 0.10751922352937981, 0.0377050724637229, 0.024427981879853178, 0.002241796441921906, 0.05036531401856337, 0.025148354943667073, 0.034917458178824745, 0.04857272309891414, 0.04702722653746605, 0.026491627395444084, 0.03420314475079067, 0.024252528892247938, 0.016189582347578835, 0.06529087972012348, 0.02892177326430101, 0.062104283133521676, 0.09157679305644706, 0.06897165018017404, 0.034334534575464204, 0.029207477855379693, 0.020009893269161694, 0.040876584898796864, 0.06818498106440529, 0.06441824763896875, 0.04089414782356471, 0.04874230013228953, 0.01970673336472828, 0.03168587260006461, 0.04707312094978988, 0.02253162758279359, 0.021736466442234814, 0.05710271616408136, 0.02335319804842584, 0.029167398170102388, 0.012524820012913551, 0.017992596731346566, 0.04474734145333059, 0.05873711088497657, 0.03744579946214799, 0.014358169682964217, 0.025682539853733033, 0.0650064367800951, 0.0480503735889215, 0.006995541052674525, 0.021155507674848195, 0.10883194176130928, 0.052538611853378825, 0.03303833284007851, 0.05429370947240386, 0.043833668605657294, 0.089891991665354, 0.0032658338386681862, 0.06700671030557714, 0.04375736469228286, 0.030020502490515355, 0.03706932649947703, 0.050624364375835285, 0.1219147362280637, 0.08552459359634668, 0.11141846742248163, 0.092421802401077, 0.09994131687562913, 0.10698706653784029, 0.07695115520618856, 0.10380073712440208, 0.1301567314658314, 0.15058652817970142, 0.17083426122553647, 0.09265531916753389, 0.08004404080566019, 0.12250437997863628, 0.13161806477000937, 0.08406881897826679, 0.1159081565856468, 0.1807195643777959, 0.05904392215597909, 0.15455384185770527, 0.13414717046543956, 0.1167147078376729, 0.1319185900501907, 0.13611239235615358, 0.18002770462771878, 0.09572786249918863, 0.14370665594469756, 0.1711638638516888, 0.2080022043082863, 0.1210817793617025, 0.14836418180493638, 0.09818027465371415, 0.1033881475450471, 0.14398634171811864, 0.11918735835934058, 0.18669636163394898, 0.23857166786910966, 0.11521372900460847, 0.15048774832393974, 0.15793022786965594, 0.12932420504512265, 0.2185252052731812, 0.15212329337373376, 0.09642630509915762, 0.11732340994058177, 0.1307855680352077, 0.12728776666335762, 0.22175118763698265, 0.19665668107336387, 0.11504204798256978, 0.15055495721753687, 0.11933442234294489, 0.12483824888477102, 0.10815170404384844, 0.15969104744726792, 0.16831947898026556, 0.19089103967417032, 0.13090141728753224, 0.13796419923892245, 0.07016973628196865, 0.14726960303960368, 0.13198591768741608, 0.12210658882395364, 0.09390148901729845, 0.1429888210259378, 0.18631866783834994, 0.27520637784618884, 0.11061785335186869, 0.14269392122514546, 0.16874729742994532, 0.07576743708341382, 0.16961926157819107, 0.08529589336831123, 0.16583319520577788, 0.16875807341421023, 0.1014869284699671, 0.10190286513534375, 0.13943396334070712, 0.17142140393843874, 0.1204472356766928, 0.14485229447018355, 0.1132289737870451, 0.11976612222497351, 0.1718069941853173, 0.34496683452744037, 0.17368574102874845, 0.10417402256280184, 0.1523792155785486, 0.1396184612531215, 0.07167143499827944, 0.20095514104468748, 0.09022471873322502, 0.19438032119069248, 0.10447171283885837, 0.10765689192339778, 0.13218205247540027, 0.24875762988813221, 0.09984390257159248, 0.12156314376625232, 0.20995233091525733, 0.09576207550708205, 0.15224473841954023, 0.09114689659327269, 0.16231626126682386, 0.10762429679743946, 0.10292102495441213, 0.11988614976871759, 0.07088176018442027, 0.13816714694257826, 0.09241999156074598, 0.14387749833986163, 0.22764020366594195, 0.1403939610463567, 0.10397540900157765, 0.09909230735502206, 0.13731455284869298, 0.2692488022148609, 0.16945777024375275, 0.12630970508325845, 0.16632283455692232, 0.08722052720258944, 0.14893180603394285, 0.17597378231585026, 0.15292132477043197, 0.14499208540655673, 0.07648971004527994, 0.12312246282817796, 0.15697527676820755, 0.15355934912804514, 0.13180895999539644, 0.14995142788393423, 0.1379295260994695, 0.16583224525675178, 0.11683581149554811, 0.16100556909805164, 0.2815152861876413, 0.180299568164628, 0.12515927228378132, 0.1179084375326056, 0.06975281998165883, 0.15850370022235438, 0.2503262332174927, 0.1961254220805131, 0.09260529099265113, 0.18130145268514752, 0.11227397815673612, 0.10454310002387501, 0.11204002352315001, 0.1336607223493047, 0.12633582868147641, 0.11747597323847003, 0.0845185604703147, 0.18472463852958754, 0.08955090801464394, 0.10517177332076244, 0.15133770037209615, 0.13501825887942687, 0.14311212144093588, 0.26075462519656867, 0.118920177774271, 0.16283662553178146, 0.16729706665500998, 0.17091732239350677, 0.1648902817396447, 0.14058497501537204, 0.1784400874748826, 0.1521036116173491, 0.17777418805053458, 0.1755866632447578, 0.17672997142653912, 0.04507880687015131, 0.1741167952422984, 0.12906056450447068, 0.1985101355239749, 0.08468535073916428, 0.12276459179702215], [0.044433895382098854, 0.02700413973798277, 0.03052298470720416, 0.059670780901797116, 0.07150373188778758, 0.02378449345997069, 0.05397264154453296, 0.014934758128219983, 0.03377799432200845, 0.10442627113661729, 0.00996718430542387, 0.02799635778501397, 0.061700380392721854, 0.00970181827142369, 0.037531231791945174, 0.04441532684722915, 0.027574031228141394, 0.0810486935370136, 0.030968557184678502, 0.038614622681052424, 0.01208929064887343, 0.07023822909104638, 0.02656101634784136, 0.027203090976399835, 0.016150085248227697, 0.05535196381970309, 0.051192482133046724, 0.08742430611164309, 0.02807755059620831, 0.09201772525557317, 0.051167705532861874, 0.06161529316159431, 0.05793369149614591, 0.0324418798845727, 0.04541881811746862, 0.01325300047028577, 0.019643142441054806, 0.02939200359833194, 0.02151938453607727, 0.05199620209168643, 0.05657219189743046, 0.041667484256322496, 0.051821422603097744, 0.0530377581162611, 0.05183891873457469, 0.059648642636602744, 0.013911176920373691, 0.03001455232151784, 0.04708128828497138, 0.021077940255054273, 0.03472756114206277, 0.03021623837412335, 0.029572692437795922, 0.02937609751825221, 0.037100422487128526, 0.12145329848863184, 0.0529938712134026, 0.023599260821356438, 0.03848364845907781, 0.07636081383679993, 0.0513297497673193, 0.02308495619217865, 0.062312923109857365, 0.016266455859295093, 0.08157080184901133, 0.06361051637213677, 0.022123466769699007, 0.04802851362910587, 0.04824437841307372, 0.05265445368422661, 0.0065355551396351075, 0.014539234234689502, 0.02329986175027443, 0.012850108905695379, 0.03409872457268648, 0.036094745591981336, 0.008352447221113835, 0.0316750966157997, 0.014236867500585504, 0.04162454359175172, 0.0375601532869041, 0.020518227320280857, 0.023618721788807306, 0.030268242517195176, 0.05599953219643794, 0.06003615875670221, 0.027016663480026182, 0.02609294195281109, 0.03437318191572558, 0.004857420090047526, 0.05624361343507189, 0.037484272397705354, 0.016600644958089106, 0.05281565558107104, 0.029618425433000084, 0.012144378415541723, 0.05875785762327723, 0.04737396906421054, 0.00975383725744905, 0.03388698984053917, 0.032262736567645334, 0.06878921543830074, 0.01473022872232832, 0.05893097470107023, 0.015190512422122993, 0.034527949392213486, 0.07112398976460099, 0.07286827429197729, 0.04510804748861119, 0.009426281103515066, 0.04789187682035845, 0.028805599322367925, 0.07844191466574557, 0.039148267678683624, 0.05576287985604722, 0.03264241560827941, 0.014390956839633873, 0.038656969627481885, 0.04762764627230354, 0.022503544714709278, 0.03580586089810822, 0.03497117111692205, 0.041930646111723036, 0.028859948652097955, 0.030927705665817484, 0.031261512558558024, 0.033600925307837315, 0.016003802375053056, 0.060498271850519814, 0.03823085811745841, 0.041467635019216686, 0.030648487445432693, 0.0332724915642757, 0.014240448363125324, 0.020566791608871426, 0.04746558719489258, 0.13756204425590113, 0.05740902648540214, 0.027069304014730733, 0.06462772624217905, 0.025841058886726387, 0.012509708958532428, 0.0357724902278278, 0.014694345882162452, 0.01642340710532153, 0.03569772256014403, 0.013785772516712314, 0.007299632352442131, 0.0392887005727971, 0.04684679188358132, 0.051245419526821934, 0.05087452751467936, 0.032270692390738986, 0.017865374065877404, 0.0738098741567228, 0.027890889323316514, 0.04284084199753124, 0.10373510900535621, 0.03765060995647218, 0.04437977055204101, 0.030241159693105146, 0.050099910877179354, 0.026430838079249952, 0.023080727805790957, 0.04556791558570694, 0.05507918001967482, 0.020668669931183103, 0.045153593091527, 0.024188411043724045, 0.04298750151065178, 0.06501707175630145, 0.030763611248403322, 0.03932398227334488, 0.04189038088952657, 0.03677510205307044, 0.014575924160453724, 0.02514834195608273, 0.03964847892348189, 0.031641314053558744, 0.04693029091868084, 0.07499920291593298, 0.009710344620543765, 0.009067525061254855, 0.010601538742776029, 0.025301582463725936, 0.026870593974308576, 0.012924523125548149, 0.0780057099473197, 0.041744979316717945, 0.05240336286078673, 0.074284648289904, 0.03410257260838989, 0.05716501946153585, 0.029123982531018555, 0.062021426056162454, 0.014783587284910027, 0.020266858191462234, 0.09394628505106084, 0.07370520906988531, 0.06991276764892973, 0.020253022703400347, 0.0302493808339932, 0.015623932231392246, 0.045203817935544066, 0.05233012772805523, 0.05372841558710206, 0.028400336595950648, 0.05018942872993648, 0.030290937393147033, 0.05989811186736915, 0.03475416342553217, 0.10888155433349311, 0.01919842899951618, 0.08160592027707025, 0.06671915776678361, 0.07931968983029947, 0.03228846311685629, 0.03807233908446506, 0.07165115210227668, 0.033609626989346, 0.0296410182636464, 0.015383181380457245, 0.02121840097970562, 0.05451068747788668, 0.08477251598378643, 0.0586580498929834, 0.04730624808871653, 0.003219691038793826, 0.02924869488197146, 0.029064465998089872, 0.03340007046062965, 0.038034697354305536, 0.06044063666195143, 0.027478874908410944, 0.03162995919410605, 0.0327004033169942, 0.049334593350067735, 0.038918491336517036, 0.04115511663258076, 0.015539465621259296, 0.04331810232542921, 0.02435546848573722, 0.017067027256416623, 0.03773588643525727, 0.04815236694412306, 0.012359110496618086, 0.028428037257981487, 0.06435097195208073, 0.023689379813731648, 0.014461411701631732, 0.04693450631748419, 0.0489707072119927, 0.009000255868159002, 0.06710309302434325, 0.07362962132901885, 0.02197280336986296, 0.011754287043004297, 0.04189254053926561, 0.03899656156136189, 0.020683249422290828, 0.0068899487450835295, 0.016237699492194224, 0.004330481788201723, 0.02183671203965787, 0.011624095786828548, 0.024719898246985395, 0.010691506522562122, 0.036355907359393314, 0.022726586066710297, 0.044213574001332745, 0.0392191613354953, 0.017113036701630335, 0.06932704985956661, 0.04738090072351042, 0.031945375667419285, 0.006726741657985258, 0.018465702887624502, 0.02459853854816174, 0.0011627581329776149, 0.030642464917036705, 0.034753551153698936, 0.06267584074521437, 0.032382051649619825, 0.026978854766639415, 0.09154453189694323, 0.022108200791990384, 0.008227975140471244, 0.027644240253721364, 0.06346774200210348, 0.01716022059554234, 0.05744559210143052, 0.031978965271264315, 0.03504678112221882, 0.04812131177459378, 0.022336349975375924, 0.01307039874518523, 0.026325004109821748, 0.08512045707902871, 0.01960173060069792, 0.04123355793126393, 0.0341158718947554, 0.08178053278243169, 0.05397755827289075, 0.030387299702852033, 0.0570937435986707, 0.057888056835508905, 0.02950320515083149, 0.019685511651914567, 0.04796569082827773, 0.019286312272015493, 0.06099882819398772, 0.046198948912206106, 0.05396300104621332, 0.016458460595458746, 0.04349817332695238, 0.025702360762807075, 0.03578032359655481, 0.044263127201702446, 0.07015469294856302, 0.054634429470752366, 0.02551961431890959, 0.023215036126202904, 0.044978776495554484, 0.035110687458654866, 0.06229882230400108, 0.05846677246154286, 0.06732610097969882, 0.02279527368955314, 0.05258704441075679, 0.004286376879463205, 0.07734375874861144, 0.037961562411510386, 0.032243919413303956, 0.057685647188918665, 0.05234631767962128, 0.021450850908877328, 0.03645048294856679, 0.03945325697713997, 0.021468775630637538, 0.06671474940958433, 0.006349155937641626, 0.06884813454234973, 0.012398758808558341, 0.03045808018214302, 0.02996948725922266, 0.024154762068064883, 0.04682578539359383, 0.0007085943104812031, 0.016638904526189435, 0.020746168702316936, 0.04518507870670874, 0.05914221590501256, 0.14871264982502908, 0.06222653712029569, 0.1585397240705788, 0.1335966750048101, 0.21308043884346262, 0.13006445282371715, 0.13635514886118472, 0.081845797249116, 0.08084560482529923, 0.1454616867704317, 0.08598981628892943, 0.10676724239601754, 0.19905179942725226, 0.10159251381992362, 0.15305473323678598, 0.11395156587241217, 0.06448980551795103, 0.14637567132012919, 0.1795549417147413, 0.11580988139030524, 0.17234473954886198, 0.194061242218595, 0.2540752070490271, 0.11797142360592261, 0.11401358715374954, 0.09417723398655653, 0.1704065763624385, 0.1258119021076709, 0.14845323952613398, 0.15678933908930048, 0.11492531557451002, 0.18102417147019878, 0.205980519822333, 0.11185349212610163, 0.13126063160598278, 0.13068622414721176, 0.1094620770891197, 0.186288952245377, 0.21542464586673304, 0.11269511727732606, 0.22883037105202675, 0.2972492919070646, 0.23847545584430918, 0.14327751647215337, 0.14545235055265948, 0.23588939773617312, 0.08863707189448178, 0.0891321363451425, 0.14910281170159578, 0.2515153615968302, 0.12974062410648912, 0.1483657700009644, 0.10359405641793273, 0.12147694331360981, 0.13292424468090758, 0.21392575989011675, 0.1436373541946523, 0.21437830670038238, 0.16153072763700038, 0.10392882439191453, 0.19728191080503166, 0.08292770013213158, 0.11745205381885171, 0.10383054177509621, 0.134990606456995, 0.1216756681969855, 0.10088244918733835, 0.20491823932388797, 0.19702448946190998, 0.15558959799818695, 0.1411147793987766, 0.11000859463820234, 0.11072801775299013, 0.10334767823223956, 0.0928853775258176, 0.11115605884697288, 0.12010579579509795, 0.11729718986316584, 0.14593149593565613, 0.12308936304179952, 0.20477591024246067, 0.1187888250569813, 0.1439581994782202, 0.0888135249260813, 0.18435870035318658, 0.206005530199036, 0.11206176845007576, 0.08048420859267935, 0.18440484709572047, 0.13635943847475573, 0.15509678225498646, 0.1881882714224048, 0.11763707123463973, 0.16796448006061837, 0.1219655510794837, 0.12668788869632408, 0.1741999009391293, 0.0705483800265938, 0.1275252242339775, 0.12266754114534706, 0.08106607463560067, 0.1464554076665081, 0.048282116622431204, 0.08222443357226439, 0.10127752408152446, 0.12678505067015067, 0.1285419220221229, 0.1398450240958482, 0.21497995097888634, 0.23606666713021696, 0.08160251381923445, 0.10641091503202915, 0.11575988290132955, 0.15912504110019654, 0.15722074953373522, 0.13142902491381392, 0.08212897111661732, 0.17340310150757432, 0.1367511588614434, 0.055941195678315125, 0.08766965271206573, 0.1931603194680065, 0.07439018911099993, 0.14056925632758066, 0.0864261991227977, 0.16804568585939705, 0.1045397158304695, 0.17038376274285838, 0.14060967369005084, 0.1749351021135226, 0.20850454922765493, 0.12944698595674708, 0.1803332319832407, 0.09446106836549006, 0.18832071509677917, 0.13575481076259166, 0.20301022217608988, 0.17722658696584404, 0.1918266058783047, 0.14583739161025733, 0.114822097675642, 0.18275892682140693, 0.1284422367461957, 0.11889541972777806, 0.09604106366168708, 0.11513888341141865, 0.14021361916093156, 0.06185774538607802, 0.15391166147310287, 0.1948503530002199, 0.14376187173184007, 0.14083357964409515, 0.1311272379825823, 0.06434758033719845, 0.2440251619555056, 0.10125900749699213, 0.0936021660163533, 0.15369957051007077, 0.14234739763196558, 0.11836861362098716, 0.1586261545890011, 0.14140774961560965, 0.1455748494481668, 0.16830000502523035, 0.1083588003530167, 0.16930430894717574, 0.10376725884270854, 0.11423122195992619, 0.07961847848491743, 0.10621243505738676, 0.18537673400714993, 0.12941235734615475, 0.16625835676677525, 0.06873255988466553, 0.13205986528191715, 0.14565558027243242], [0.03750887088244781, 0.0693027074157726, 0.01261385268662707, 0.05335241759894416, 0.08669196220580488, 0.0737493445922155, 0.04211349274555687, 0.014161022791085998, 0.008291374033433385, 0.060105252705398016, 0.0373041308921529, 0.01521311174656148, 0.05447109761007596, 0.0321634817373706, 0.04055016237543896, 0.02772230491245864, 0.023324083595070988, 0.03379284098627977, 0.015487941091123503, 0.058043336393893696, 0.020550217595882714, 0.004710837574748439, 0.03190228657331318, 0.02415978640783578, 0.056791169990901835, 0.0653127433906775, 0.022148781426949427, 0.03851288536679931, 0.017620272374188062, 0.05907907026994508, 0.03271365065302234, 0.008355222853424493, 0.022367542442225385, 0.029709186383115593, 0.046347281968337484, 0.0241562630617409, 0.029008743695158046, 0.04057847530930303, 0.028421667775546666, 0.03692277088703122, 0.03301526317954995, 0.06949944334337488, 0.016342659582733177, 0.03193770186044276, 0.025254942192987073, 0.10398413665825501, 0.015875080571277067, 0.06220306298928335, 0.04660218000935856, 0.01728286977595417, 0.02804708172334358, 0.025559039058862254, 0.010470163761056028, 0.07731170539045706, 0.04126345906115603, 0.037473166157724336, 0.014236896258807974, 0.003006570113939233, 0.013186444666644093, 0.032439590358990245, 0.03932735533453524, 0.055872743687359616, 0.010130113550985698, 0.03597720053221565, 0.03378334149601869, 0.06418315751943737, 0.08426965898252092, 0.03203008440323174, 0.04239945708832238, 0.02228791741799796, 0.04465038357011508, 0.008781514334259555, 0.01100825886169332, 0.0561634726182092, 0.016777901364548597, 0.010623265116009861, 0.041285170591436327, 0.03996368759544566, 0.025150948749796953, 0.03853462287224829, 0.03224327003408689, 0.004510079670581035, 0.018167374364566058, 0.032432213411084376, 0.03167207236401737, 0.04245129610353615, 0.07474128433386795, 0.018875095665862318, 0.07602525176480412, 0.035357804081286304, 0.06869902223115787, 0.029556541448982898, 0.043087698868475854, 0.0323575125366915, 0.013526686907425756, 0.036559753061737865, 0.0376604545454029, 0.02481929594068788, 0.05420164605311584, 0.04811403872736264, 0.022425181341532152, 0.022400543894036673, 0.033092906669480726, 0.06601785047678277, 0.05402511509601027, 0.020730156866193283, 0.011751664478651946, 0.00847928860821412, 0.02349918406252982, 0.03312574670417234, 0.10239251190796494, 0.07323432379052974, 0.012910543846373912, 0.040913491902756505, 0.03345871125929989, 0.10677637823391706, 0.012474855848267907, 0.04318440071074292, 0.058830651178141125, 0.04391998409118969, 0.009426461074326653, 0.030949615720601287, 0.03832647642411757, 0.10097207094077021, 0.01131958888436202, 0.013953128673165338, 0.012172363876743475, 0.038889432544237934, 0.04752453969558701, 0.06808942955103703, 0.03437204642978031, 0.039873627974884585, 0.021613329299725592, 0.033578319489606656, 0.05899690710066352, 0.0640174953150563, 0.06131305723101832, 0.04366375389508903, 0.11612010654062033, 0.033751351220416836, 0.10880537287448533, 0.045405997516354546, 0.02532932394387899, 0.05756925245805178, 0.04321342610637657, 0.016672310448484495, 0.023149031367211137, 0.05333146305929404, 0.033504872844787315, 0.02821315953042358, 0.01980953380552819, 0.03537530021276325, 0.04597051585733425, 0.07507862013881095, 0.0919659530336503, 0.07703437222517096, 0.04106716100068297, 0.04043331493448932, 0.07005114108324051, 0.0777406370616518, 0.05424999697424937, 0.04548060562228784, 0.014045517709746491, 0.029051624987914693, 0.020947956800227985, 0.03724091475305613, 0.011532122352946317, 0.03793009163928218, 0.04770926396304276, 0.048258913375320844, 0.022665444230369758, 0.07085130244377069, 0.05230398186540697, 0.051511382989701815, 0.038258759159361944, 0.07175327162258327, 0.0776633943314664, 0.013784458915324649, 0.062395041750278324, 0.08667486312333494, 0.025981488070101477, 0.025733380680321716, 0.02316450514626922, 0.029833792978024576, 0.053030785638839006, 0.024843662504281383, 0.025118839730566833, 0.01060689890437061, 0.005979378074698616, 0.04069702968990896, 0.01714657621050719, 0.00948270566368592, 0.00606764819167438, 0.09958834401913919, 0.012466851785575273, 0.015339242527261376, 0.03654158899735194, 0.011191421835974324, 0.06870550860185176, 0.042972669689334, 0.05849997243785765, 0.04490292529226281, 0.011547547892405419, 0.05209021735936403, 0.016752252740843687, 0.054383130845963024, 0.03729860560270026, 0.11343895705067553, 0.036436834852793254, 0.02595297475636471, 0.016516696923645213, 0.029690252340515144, 0.08497142640408128, 0.030159117122821044, 0.06204646240803413, 0.04494842636631802, 0.02260005916468799, 0.02349970913201105, 0.029027631353528704, 0.02272739129693946, 0.010964217035507318, 0.04394458999740891, 0.03448877883784007, 0.039424469068762846, 0.04692674716352485, 0.010261214865749935, 0.04442172416020185, 0.03626569559855852, 0.015504902876273263, 0.08640846179332584, 0.06166173305246048, 0.08688198911841027, 0.03885984311637003, 0.01877989481727127, 0.02203678021032829, 0.030808153096586466, 0.013416277597571025, 0.03341349962283857, 0.012772078571288148, 0.017663571125012822, 0.07050827436614782, 0.08126056185574271, 0.0993682378611993, 0.06361657971865498, 0.03226461791200563, 0.0396629730676068, 0.036729511921294034, 0.04382318576972466, 0.03485731824184768, 0.047745844422024675, 0.009749736891535576, 0.018840426237147767, 0.047165299401967786, 0.033071722064050846, 0.02380965783231659, 0.03433366626268253, 0.03959977548220195, 0.018290010557393543, 0.08247961362940259, 0.014744628242624458, 0.12960403924807906, 0.0668978966132272, 0.04851190409681294, 0.047966121273930185, 0.09938460221746936, 0.007573529373985366, 0.032938521399046294, 0.06765220809029415, 0.0460045210638782, 0.03427172661758959, 0.06085828768846113, 0.028526143614726607, 0.00750481995055452, 0.0020754475190187804, 0.03052156163903419, 0.023887826391728595, 0.04630281247955281, 0.029734870258835144, 0.05984414659906179, 0.01573844376252964, 0.04075907694641501, 0.01387978314596694, 0.04578210682666395, 0.024530964146833867, 0.04353326577984262, 0.034620454389369115, 0.016129069481394254, 0.048488084867130965, 0.07209469666122459, 0.030960558688093442, 0.015179776328295702, 0.07588560183648951, 0.0482654071674915, 0.03540892321325373, 0.043051240863860585, 0.010505784066481283, 0.02543389255151851, 0.012698528953478672, 0.011248518967477139, 0.0842344069678802, 0.045566256885649636, 0.012180661087768385, 0.010860870188480476, 0.028311982059676666, 0.04287355586711783, 0.011576607612369116, 0.005317887007549871, 0.030175000938470475, 0.019480921946524177, 0.00707946867805731, 0.02256378484162269, 0.06254245454329066, 0.06519059330457821, 0.035695893166121095, 0.025128736269834917, 0.030973928478488233, 0.018965281451528426, 0.03673459192214068, 0.05000609227863606, 0.06804547214414924, 0.043108148747705854, 0.04405473584483843, 0.06334801131743006, 0.018337188885197975, 0.05983414244838059, 0.018821646190190222, 0.04561859313980676, 0.027210276821278967, 0.0764659910055343, 0.027000965201295912, 0.04368753230664879, 0.03345209872350097, 0.027971529234491754, 0.006820966118539218, 0.04530160702415742, 0.06707953725708649, 0.0031005946584627964, 0.055650411086389795, 0.05701213332940824, 0.055974429051275365, 0.05450473916425835, 0.039831362664699554, 0.01858823703514645, 0.0347289266937878, 0.057670429450809024, 0.02520660240406869, 0.028003235638607293, 0.036553188765537925, 0.07059383657178842, 0.08009516735910438, 0.023375776036118623, 0.02826590025506448, 0.2428693708498031, 0.11766347684897482, 0.1295347820268944, 0.14935312326997519, 0.1486809304333292, 0.2456569517380558, 0.18608953716466203, 0.1334480376681313, 0.17767485900549218, 0.15009138209279627, 0.14512482594000176, 0.08352496573934332, 0.18439574836520478, 0.06140394434623886, 0.11700429386110045, 0.12934418366057798, 0.07670592734939419, 0.163242713897489, 0.07344346842728555, 0.17378000862663612, 0.09605789557099342, 0.15471278020413592, 0.1698449783725664, 0.15331531612901017, 0.15900485770544037, 0.12546815414680168, 0.09354437497677281, 0.15501375077292323, 0.095458744908683, 0.1275675860233605, 0.09221191561664455, 0.14774168317671865, 0.14108240691712126, 0.12583823350723833, 0.11518691520905122, 0.07955165550811216, 0.1728948936215602, 0.2064861005055718, 0.11196724852197804, 0.13972399465274066, 0.0926845968933776, 0.13906539796153083, 0.10968115166178904, 0.10946474882075563, 0.12804588535800576, 0.24785050278296694, 0.22425560950068757, 0.1363186797243543, 0.10622921501635574, 0.1277188357198611, 0.14603438728954643, 0.11095489971921779, 0.07136507643735968, 0.11069998683524318, 0.12643477180972695, 0.1989401804166846, 0.12134535310906358, 0.08768325627897866, 0.07184777670772746, 0.149523178988602, 0.09506266811513342, 0.10959116625599563, 0.11918473115656525, 0.15261204214766622, 0.09345183658297174, 0.1354082129546441, 0.19389221066376194, 0.12571194965858012, 0.15076258045155555, 0.13355334842344746, 0.13710642495425418, 0.1155544415814802, 0.09272353738197125, 0.15898799611022696, 0.134581831516698, 0.15699123294325545, 0.12446128981537186, 0.08307578827952966, 0.18055571301374584, 0.20518551638815552, 0.13783076108666137, 0.10531241772696376, 0.11594606548896991, 0.10961949403281324, 0.21632889343891293, 0.12742521241307259, 0.16795517352875322, 0.1463864918332547, 0.2920087496750057, 0.08601651876233518, 0.21142343088285998, 0.1672348301508464, 0.17708638042677194, 0.14143917214823887, 0.10993648014846258, 0.26163359521888196, 0.08256646717200056, 0.11717547022271901, 0.15533630299614742, 0.1388194947503507, 0.1291248938650824, 0.07636777518200688, 0.1974784760386683, 0.19421676668571308, 0.2127976657357067, 0.08761953547946177, 0.10225923702819273, 0.05642047093715519, 0.12941847264301032, 0.13202070957049727, 0.19572791294194758, 0.2219883631914854, 0.1681442282279022, 0.14902436669217423, 0.2754022157751024, 0.2049815296777524, 0.16833165020216256, 0.16318003210471943, 0.19964214821811765, 0.239543495408725, 0.15477602602913976, 0.07782723085256293, 0.09654153836891055, 0.26331648929044604, 0.11392392087145709, 0.19770825980231166, 0.09178216016152874, 0.07448925098287873, 0.06137601361842826, 0.16455962526379153, 0.16491423826664686, 0.1626238666358404, 0.04725738508568611, 0.10222474200418219, 0.07774099329253659, 0.1263644904247485, 0.18278047878993675, 0.13161684764781967, 0.18047931633191183, 0.1317238504998386, 0.13108612300129607, 0.13038007338764146, 0.14726773282745853, 0.16676978557370603, 0.13575265853432938, 0.10704923624871299, 0.11818764833151363, 0.2160149352857843, 0.15127301478059962, 0.12196474955999292, 0.1804715534672141, 0.12353950529359281, 0.27107436675578356, 0.12619753688341007, 0.19721244578249753, 0.1213594687578734, 0.12408706927089952, 0.0748226979339961, 0.1011362711142283, 0.12583094561705366, 0.19059311191085726, 0.2153062287834473, 0.10984449836541899, 0.13439368223771453, 0.1174385764170438, 0.1433745151734911, 0.08395684373681433, 0.15404533711262047, 0.12799421703675762, 0.12222454577567987, 0.12893162376713008, 0.11012829563696869, 0.14329883095342666, 0.14548274892149493, 0.09789079253096133, 0.16262762190308422], [0.05465788875881117, 0.01322475989582017, 0.054054396532592364, 0.029188386106397957, 0.027286254189675674, 0.0415420167701086, 0.08782813834841363, 0.029425040302157868, 0.027390121467760764, 0.059871249832212925, 0.04900589614408091, 0.06813764688558877, 0.01056083565345034, 0.07980181864695624, 0.04002699650300201, 0.05432041565654799, 0.06505404555355199, 0.05395294494519476, 0.027215384652663488, 0.041785467183217406, 0.00583938397539896, 0.05445636226795614, 0.030497549450956285, 0.06453669440816157, 0.07328347623115405, 0.007439202963723801, 0.09245132503565401, 0.021252307851682417, 0.05342083619325422, 0.014555792477040086, 0.052920283560524695, 0.024206068592320662, 0.07107291516149417, 0.017508009550510906, 0.003986250503658084, 0.05508537324203644, 0.03933002706617117, 0.003235381200283882, 0.09941370924934745, 0.02282540674059419, 0.01501833323345636, 0.043501835825736634, 0.02069335005216999, 0.052067600408918224, 0.06386428634868935, 0.023123139690142125, 0.013465728752635187, 0.05327743841917254, 0.009176237635983853, 0.10999860533047467, 0.061691407827311195, 0.03596558963181451, 0.03303989135019947, 0.025321399662061594, 0.059114296309417114, 0.00957939544605324, 0.024786943868093658, 0.05889439053134993, 0.1378196437144652, 0.013252952230686788, 0.044492525048553944, 0.02678008720977232, 0.003689595987452776, 0.02317402875632979, 0.026900725169980433, 0.0634969084057957, 0.048892399499891326, 0.06763760262401775, 0.04127329993934836, 0.0577730165241519, 0.01742843091051327, 0.01889476814540103, 0.09559049838571809, 0.03751068172277883, 0.06678056306554936, 0.0075166252008784795, 0.04595672675350215, 0.07085050834575668, 0.046425593391177244, 0.03479876650089864, 0.026182081310253125, 0.08168512969859876, 0.04436519848241005, 0.04897991726465989, 0.022006470899214037, 0.06441541263484396, 0.032005556422518566, 0.06474903027992696, 0.007693604693486122, 0.02166231846786104, 0.05627534024824854, 0.015274349134415388, 0.03937991423299536, 0.03992226833361201, 0.018624381482368335, 0.022467426242656074, 0.05356509114790242, 0.05510578601388261, 0.018489839385438245, 0.016114068821480032, 0.01677458953054156, 0.09085296900593676, 0.023108142740966287, 0.0366377156751696, 0.019961824364145286, 0.03833387563645374, 0.033888496400322765, 0.04242395538312849, 0.06034852871380281, 0.030709697930433322, 0.023398441226163413, 0.05725270792027004, 0.07112332183169201, 0.024136130450642668, 0.07640486772288568, 0.02833911683410406, 0.04173829256615136, 0.06552418868523091, 0.021393638744484633, 0.022868492123961914, 0.05816401702759322, 0.040910946336225607, 0.03886281170707662, 0.04352186639152933, 0.003685182296067069, 0.04239452551701106, 0.03319774987176061, 0.016560756375838537, 0.027966503039351664, 0.018568848427094053, 0.06166608574858401, 0.02313120312464889, 0.034104769365512766, 0.018303855322301388, 0.0686695367039647, 0.04597227103658952, 0.09175533894449472, 0.09445923526072875, 0.044471410947153345, 0.06365390232531354, 0.013686699512618361, 0.0377138594922144, 0.01263630543689942, 0.020704155722341966, 0.011929450593015645, 0.014791633093409473, 0.037042572075733915, 0.018098300824931357, 0.020214794676576275, 0.02977513177029323, 0.028846397035522386, 0.04302617482608184, 0.038145162325236015, 0.0224312131467741, 0.017819034364947584, 0.060006803105352446, 0.01830476630857447, 0.022911534833838232, 0.05912924316362478, 0.06557564178365283, 0.032592264979030006, 0.025315525563200936, 0.06702193175442517, 0.046342669520527124, 0.08550592858227901, 0.024453354053548537, 0.011561598603293533, 0.03298008537967689, 0.03981246016337536, 0.07059327996103093, 0.0782165837881621, 0.02635244316479657, 0.023032412136672065, 0.03959240595577285, 0.03870960274070967, 0.08198732481105253, 0.06702636237605475, 0.04759641669807024, 0.05487267000717111, 0.019798026805801783, 0.040150103959604166, 0.06875578168546781, 0.04804395401151851, 0.022735410202585626, 0.07082554249791428, 0.020898934235447086, 0.035578919560066424, 0.07461763510946184, 0.03808038767601829, 0.04539077235676814, 0.0579409088823013, 0.04994837174308486, 0.017204771720571443, 0.03295428461569827, 0.028456021791498642, 0.024523247666365933, 0.06561935428180732, 0.04524870673776604, 0.005578984764724737, 0.08733059512451291, 0.042673127754824236, 0.042093198717338964, 0.07129370409529656, 0.009473271111346548, 0.050010812337859534, 0.0016378675081796246, 0.06987500717514195, 0.020042659089085646, 0.06997104108450003, 0.02932380393758649, 0.045647722436115146, 0.113734710321296, 0.008656961545057129, 0.02798229037580313, 0.08513087683240883, 0.029015018553764094, 0.08074203069554642, 0.04244589697918855, 0.04220318871375639, 0.08039732536417432, 0.010513925426494097, 0.05279872348182835, 0.02791943603369873, 0.046678691724082455, 0.030083792844379786, 0.01904761160403723, 0.07967393175931647, 0.015628370274498593, 0.0018361183447268559, 0.032523237823625095, 0.09379232651554048, 0.04531564474746119, 0.007786577243678039, 0.035182271312805824, 0.025876685685943812, 0.033156594072352163, 0.05318180155882146, 0.03704934046254493, 0.013109790088492446, 0.0421297309367219, 0.01848822706961073, 0.03833963470242452, 0.03884954952809494, 0.012438376506906934, 0.01988397863897262, 0.0898099027108401, 0.035404192021815106, 0.045702953066211194, 0.1017259965010453, 0.06725956001901068, 0.08132679111440666, 0.00800780311692506, 0.05299629061482847, 0.0757894640264567, 0.019821821915684268, 0.03392375212570187, 0.018152600059693214, 0.10044123497209512, 0.034480841568438336, 0.029031533194938675, 0.02423399932013126, 0.03079461817833362, 0.02102725899021607, 0.07778240513289347, 0.03557290074240882, 0.03467261994956061, 0.059043985238531604, 0.03357755878823809, 0.03278510834206827, 0.08915785918361507, 0.03994784645328764, 0.012806999402528163, 0.02135829952749191, 0.017889128357637674, 0.05698616929294076, 0.022329674357024487, 0.034831847733585164, 0.04648614893085323, 0.047904864404699765, 0.03477816819213331, 0.023760366239002906, 0.04781830029969569, 0.02918305563071044, 0.019179268601874355, 0.05114991254231427, 0.0445355584815843, 0.10070385134895332, 0.032016811092034914, 0.05463835914270021, 0.033473257353762165, 0.02700816774449777, 0.021379120480560232, 0.06927336289663799, 0.04916572135698516, 0.04901604130282067, 0.03359281734446995, 0.019832456891890615, 0.01678785542026162, 0.05824769046739675, 0.011809922143584117, 0.02860640688595595, 0.006611834005525452, 0.0077514356235042214, 0.05202947628276888, 0.029112343800079543, 0.009627706476749154, 0.02464238648826722, 0.05391939244873356, 0.050614267456694506, 0.01096734611564898, 0.04203893287922256, 0.07283705213922076, 0.029201110228314064, 0.05428155680419877, 0.0275204481658875, 0.03390604819287546, 0.009065553731488762, 0.08830635604681447, 0.010123445354111027, 0.043792609285446815, 0.016751549555920064, 0.0667516489920672, 0.062486207170877606, 0.02969267916341778, 0.009081713997147745, 0.04352785552327987, 0.060118678156868555, 0.04698349548561964, 0.01744042401696788, 0.0887393398443237, 0.032654382739565335, 0.014907921140547842, 0.0648304884089157, 0.11296705502900295, 0.05650899802276399, 0.06329869560431689, 0.01921951898111729, 0.047039189958013594, 0.03201210216502659, 0.017889428927446716, 0.06703022896545008, 0.012975772133358987, 0.04987135536794085, 0.02204552827606676, 0.010760655204649083, 0.02290330441610422, 0.034182561284978874, 0.08894302969565615, 0.02927075336629059, 0.02843470731022535, 0.04430830173077993, 0.012940448687004391, 0.1263218020903878, 0.08326035298523493, 0.19768759841099381, 0.21287250390741974, 0.15846875990973786, 0.1711358255124651, 0.14356517291162163, 0.07441329216817394, 0.15222682297462597, 0.19221341324737296, 0.15587007044814527, 0.1462341586011462, 0.14840865129372105, 0.20077110326383263, 0.1869858882855624, 0.10350211916374974, 0.14495438430458307, 0.10696755547542125, 0.13805983238853514, 0.19474232598440722, 0.14080306253163144, 0.1546143862651661, 0.1770881615811959, 0.12405700486851856, 0.16811621957458556, 0.11842399268061854, 0.23134608840337023, 0.1183463195047807, 0.14031679253093898, 0.08473847366985865, 0.162440259300638, 0.1007542060688138, 0.24169450654881075, 0.11809975578216836, 0.09546813307679258, 0.1934276707470417, 0.1078952252282761, 0.09013008006149903, 0.2369714342057705, 0.12489389511756599, 0.18001615680987015, 0.14093264151597396, 0.1783909572986886, 0.13725860975682735, 0.1035097187559586, 0.12608786229975522, 0.07041990684228949, 0.16388735821237788, 0.2741400006925687, 0.21684755076421425, 0.16931327409110963, 0.16926669690292329, 0.23398377030389383, 0.13566192355938256, 0.12923508795211092, 0.21912247088039294, 0.09807251481106505, 0.12935147155076265, 0.17679210403002799, 0.14163021580316126, 0.1626436522928998, 0.15112078544916585, 0.18478414393030107, 0.15347100386861712, 0.22081735805841163, 0.23174956440925598, 0.15129349805647507, 0.10594483144814149, 0.18583778582978994, 0.17178547190269455, 0.12913235987070948, 0.1613160688430071, 0.1304763596272096, 0.1765818684361875, 0.2932591794524342, 0.11651914450339973, 0.16054378997068852, 0.16679702239343897, 0.10263933538226411, 0.09307294792961329, 0.15296407247660682, 0.17434248235076666, 0.08890015582437627, 0.1437199700740166, 0.1598183554597199, 0.0972435729636345, 0.2174792520236224, 0.17066819826141, 0.10371869269874878, 0.12472082627937198, 0.22395998239517212, 0.1250451893429272, 0.1652603314141743, 0.19694982940563932, 0.1474914903519675, 0.1425915939034894, 0.12454208743292838, 0.27005643700249493, 0.12583909439854324, 0.1266267357277684, 0.09430800782865845, 0.17991461616475135, 0.09461176145123318, 0.07133641469408758, 0.07787997528794222, 0.07400140762911178, 0.187568444525823, 0.060949924372835085, 0.1547607229440473, 0.1604156062239781, 0.1483485076460056, 0.08050567892496474, 0.20125930284848437, 0.1726009140838869, 0.1821013691369444, 0.1299356308300048, 0.16109815944219008, 0.17164017423056066, 0.10396904879598878, 0.13596339878858998, 0.23293450707569718, 0.18764861131785437, 0.21903115703025833, 0.06927448353962973, 0.13000411621760577, 0.1366549319936894, 0.18836355186067522, 0.11354461661539972, 0.0959247320133727, 0.13417745009064674, 0.1100251371099148, 0.12759235891280696, 0.1812195492675528, 0.10069032199680805, 0.1338579852017574, 0.2393904497148469, 0.137482218851801, 0.14126360969385132, 0.12051963218254969, 0.1529577048495412, 0.12351053926977329, 0.14591546554584056, 0.0815868767676875, 0.15514766389969736, 0.08052075194427744, 0.18944695388199762, 0.14353204343933612, 0.13011150498641655, 0.08928796509280801, 0.14086918788962066, 0.16856167145306244, 0.23576545907417312, 0.10863431525649503, 0.1847543244366534, 0.15946307452395558, 0.24105201446218416, 0.17462331103160977, 0.16572074498981237, 0.19898726226529106, 0.17037757323123515, 0.10456728661665693, 0.1760487986030057, 0.22447576018748805, 0.1707838842412457, 0.20299618074204773, 0.1186558099288959, 0.1227180368732661, 0.1456451159901917, 0.15127347491215914, 0.10893524129642174, 0.1313929565367289, 0.1950878550997004, 0.1433418458327651, 0.17677816649666056, 0.17145702702691779, 0.1528502715518698], [0.07849554967833683, 0.0700552377384156, 0.012953527184436098, 0.07115892265574075, 0.02987830142956227, 0.022573586757062003, 0.01561992092319997, 0.012377259718050482, 0.050436586170690134, 0.0034820768860299722, 0.06462386707426049, 0.018589893879834563, 0.022199457125680055, 0.04316135331464466, 0.011572448802326107, 0.03980335772212129, 0.07062646880513057, 0.10313286358723417, 0.022149684991745744, 0.07298364114831202, 0.06651852556387894, 0.029129344547982328, 0.03318543022032827, 0.06554855339345522, 0.06956161305424757, 0.044338098959997296, 0.05589643304119818, 0.047314690018538386, 0.05402048038376961, 0.0237587520678062, 0.024033394947764464, 0.012206930332467891, 0.07713936385698617, 0.015484366722375853, 0.09220545151038095, 0.031146171677391976, 0.04594533107592724, 0.04157109040534124, 0.0203220628463896, 0.01774513686541468, 0.04645159453502856, 0.010350246611778857, 0.020922261792293284, 0.14407679467694834, 0.009277939698222326, 0.04380999780551065, 0.049292662006337196, 0.04182572498393711, 0.0330150516674621, 0.026836948709387798, 0.031276637528208084, 0.044975381169933826, 0.03229758411180228, 0.04177993076154962, 0.07698521978454664, 0.03745492787857074, 0.008108854872261873, 0.062196936560212635, 0.02633361487824004, 0.08362838401808403, 0.07817489735316485, 0.07533124720794149, 0.09824105654843152, 0.05724438844481483, 0.033981105298153125, 0.01651960799790686, 0.0620029354467988, 0.04756845999509096, 0.049422682568547316, 0.057194761029677466, 0.007564257166450261, 0.03289256390416995, 0.027815540925075766, 0.020649279467761517, 0.020773856376763433, 0.02204304764745757, 0.030478784246952273, 0.047154293351923116, 0.05256464639387559, 0.04206364639685489, 0.0963886411045678, 0.0135569535450486, 0.02260313165606931, 0.06072821517591365, 0.05864046099304687, 0.016785315419838298, 0.05872558533155825, 0.05311203596647829, 0.015619382866134401, 0.038978519951342605, 0.02298888888617512, 0.058964182098861784, 0.04842514332267456, 0.011074986286985222, 0.022907072670932394, 0.015124954807106405, 0.008835122443997534, 0.02172984091885155, 0.0534449188853614, 0.049865759574458934, 0.08397004654398188, 0.0580190792970825, 0.0364036274550017, 0.06903704823344015, 0.03979909037298057, 0.03539225828717463, 0.04848210315685719, 0.01806656102417037, 0.03230358437576797, 0.036307103728177026, 0.06068914481147658, 0.019354994328750763, 0.05056223919382319, 0.019223105409764685, 0.01884427241748199, 0.02977269010443706, 0.02226696287834784, 0.03558385855285451, 0.05722946014429908, 0.05937863446888514, 0.03158319275826216, 0.05183661065530032, 0.1038669738045428, 0.06712398448144086, 0.07366013102000579, 0.03303231031168252, 0.019304442939755972, 0.10106600457220338, 0.06027024326613173, 0.04035848418425303, 0.06896593564306386, 0.06641170082730241, 0.00447278860519873, 0.07112088016583584, 0.02414261867670575, 0.010873171286220895, 0.027134395932080224, 0.03960622845625039, 0.019151436208630912, 0.02372275419475045, 0.02515039399440866, 0.008058362855081214, 0.0250547088944586, 0.014720260751346359, 0.07918127928860486, 0.06738982920069247, 0.0426180715294322, 0.05435644321551081, 0.0669351227406878, 0.024631682863400783, 0.04174937654170208, 0.056978098436957225, 0.021640990999003407, 0.019340891667525284, 0.02189782419009134, 0.02957934579171706, 0.013628914966830052, 0.033964098984142765, 0.07894988506450318, 0.0404649675328983, 0.053209899269859307, 0.02800371246848954, 0.03755821628146805, 0.0441594491712749, 0.06461119861342013, 0.024847855638654437, 0.016089930468297098, 0.04689215566031635, 0.056246162712341174, 0.022880403594172094, 0.03845928004011512, 0.038800667971372604, 0.035136172809870914, 0.07096115514286794, 0.009387304435222177, 0.05584409307630267, 0.051444489508867264, 0.06348862603772432, 0.053786637072335, 0.08626216222182848, 0.020286233811930288, 0.059696885946323164, 0.02015013320487924, 0.02108404070895631, 0.06642396852839738, 0.028406527962943073, 0.062206335860537365, 0.02776331970380852, 0.020843414167757146, 0.05092673389299307, 0.018115624407073483, 0.020588171028066427, 0.05915086563618388, 0.06446131446864456, 0.018120823151548393, 0.014740368314960506, 0.031750918133184314, 0.015445310273207724, 0.03430415104958229, 0.04051318115671165, 0.04798146888788324, 0.019868684830726124, 0.020041323223267682, 0.053463535659830086, 0.05419735643954482, 0.032282039828714915, 0.023945903158164583, 0.033697975959512405, 0.03428863645240199, 0.015551900305581512, 0.02553209909819998, 0.04984599247109145, 0.06911126300110482, 0.08035868173465133, 0.013769864581263391, 0.07243601037771441, 0.007398007273877738, 0.010971785086439922, 0.01640747690544231, 0.0041955254800996045, 0.021413249996840023, 0.028194780243211426, 0.05947551813733298, 0.0427011994906934, 0.04033186334709171, 0.010876659380301135, 0.023434787908627186, 0.0152852355131472, 0.05056142283137888, 0.01935313153808238, 0.04545373987639323, 0.02874628688005032, 0.03482391417492181, 0.05675615917425603, 0.06241418173885904, 0.014555473353539128, 0.01538863338282681, 0.05627432721666992, 0.025527115576551296, 0.0545836294622859, 0.00833751799291349, 0.029386797432380263, 0.06384867898304947, 0.025475046495557763, 0.031954511505318806, 0.07413640429149382, 0.018113561236532405, 0.03562596801202744, 0.024849243454809766, 0.03700073350046296, 0.05834394702105783, 0.009453128295717761, 0.00795002784798271, 0.037923519921605475, 0.03193228418240324, 0.04530919548415113, 0.08963164626038633, 0.015311181923607364, 0.040364447340834886, 0.051654576673172414, 0.013467218614096055, 0.029825425262970384, 0.06470345499110408, 0.04906424379441887, 0.07917315277154557, 0.005350372202883591, 0.02295068868988892, 0.04764865276229102, 0.06161256205814425, 0.044062391098123044, 0.016046125201683026, 0.020710831340693403, 0.09221187108778395, 0.023851841506257188, 0.06934605626156554, 0.06302365567535162, 0.040080282706185244, 0.037047117730253376, 0.03582315664971247, 0.009570043457642896, 0.025702030507090967, 0.012766997642756905, 0.013613181436085142, 0.04051139629154932, 0.032507537689525634, 0.0325762642751215, 0.06931121242814697, 0.05770195217337459, 0.07588986918563023, 0.08284520299639553, 0.04124299062823411, 0.055454955363529734, 0.01705241436866345, 0.002050608763966011, 0.024275934374600183, 0.10820349853020161, 0.068509455450112, 0.03094752100878395, 0.09351226224680431, 0.09078023853362538, 0.04791552906681318, 0.054845147460582666, 0.04935501725412905, 0.04007594114227686, 0.057606567643233575, 0.023339598192251287, 0.08652403645101003, 0.06212481464899611, 0.034179785652668215, 0.014743903720955132, 0.021889345152885653, 0.05752035605837591, 0.00991185255770688, 0.0583647791063413, 0.015380447493953397, 0.022165522423165385, 0.08728936139959842, 0.0778829216142185, 0.027081950211140793, 0.023420748329954222, 0.03478214981441852, 0.0860739461495541, 0.02763746444543358, 0.06759464711649343, 0.07884657810791396, 0.021475610810739454, 0.024172239645849913, 0.05678632005583495, 0.027466746360005345, 0.014725291584909428, 0.04583765286952257, 0.022487762944365386, 0.03782205349125434, 0.012226568487676559, 0.029212034642114304, 0.022409496050386224, 0.019314109413244296, 0.007647346164958435, 0.030292293668026105, 0.04585056994983461, 0.06618474464630708, 0.020037117101310287, 0.029996813136676792, 0.02204550415626727, 0.05153196274477523, 0.04803787211130839, 0.055679087672615424, 0.007523004887843854, 0.009261991872335784, 0.038439160416601226, 0.037973989674355835, 0.027673456752381753, 0.14882094401400536, 0.1657099393196404, 0.15858950733672827, 0.19610223738709465, 0.11849728718516417, 0.08829384343698621, 0.07830083239241503, 0.1136792941542808, 0.11593184593948536, 0.1384323459933512, 0.22657188208540902, 0.18853307323297486, 0.2030935653601773, 0.1588737647398375, 0.08848289071465842, 0.13307148677995428, 0.15398436225950718, 0.14625109441112727, 0.08318644249811769, 0.12189329558168538, 0.17387858068104833, 0.07747840660158545, 0.19582980981795117, 0.08879059256287292, 0.12248641258338466, 0.16022284078644589, 0.1433468033792451, 0.163243381830398, 0.1373130685533397, 0.21070638264063746, 0.095039832231123, 0.18987742922035977, 0.18770263966871426, 0.12853389198426157, 0.2355399649241008, 0.09579819583450444, 0.3280794422607869, 0.2728214714443311, 0.11024879815522581, 0.09659984891186468, 0.16950315999565646, 0.07130207552108914, 0.10193798356340267, 0.19329118978930637, 0.1431388090713881, 0.17597035359358415, 0.1418717997148633, 0.13801209744997323, 0.1849630757351406, 0.09149979523499496, 0.10141966020455584, 0.08054162113694474, 0.10800746764289215, 0.1439394082990475, 0.15678239258704707, 0.15345834282925352, 0.10956073820125312, 0.10024193863500841, 0.10896701263845898, 0.09238075421308167, 0.17883165943203494, 0.2051312950788997, 0.13957684161141515, 0.1878534143907018, 0.08992836432298645, 0.13260414154501632, 0.1630866402410902, 0.20241791411535814, 0.09924063298967667, 0.14953760633943602, 0.1786597038153559, 0.12203197329654358, 0.13565453176852316, 0.07204356268630363, 0.10655984180630185, 0.15446954872459173, 0.13470168836647645, 0.0898075575241819, 0.14013487729243934, 0.09271471324609593, 0.18349504825891927, 0.15956874151015654, 0.12695681332843378, 0.13198437402024865, 0.11736890359316021, 0.09689704194897786, 0.19630224618595093, 0.12176528995041735, 0.12823287688661367, 0.1446271120221354, 0.09700166992843151, 0.13854728982551023, 0.20183834130875766, 0.12447358720237389, 0.1430964472820051, 0.0917451640998479, 0.35287652572151273, 0.15604033396812156, 0.177496075630188, 0.15387143706902862, 0.15709888888522983, 0.13136309251422063, 0.14678598992759362, 0.2354286576155573, 0.1562418567482382, 0.11307241773465648, 0.15308740257751197, 0.20047969155712053, 0.10428236870211549, 0.07451139666954987, 0.19010645599337295, 0.1794741812045686, 0.1185110688675195, 0.15410580730531365, 0.12454217649064958, 0.16954777791397646, 0.1341080741258338, 0.14484614948742092, 0.1266586480778642, 0.18331084720557556, 0.21884412097278982, 0.09815252575208433, 0.27951944328378886, 0.1927246936247684, 0.14413267839699984, 0.1304676171275787, 0.13140505354385823, 0.2941904857289046, 0.17561691318405792, 0.08884479160769843, 0.22563498001545668, 0.2165144748869352, 0.09113466599956155, 0.12533547298517078, 0.13238292216556147, 0.14165838772896677, 0.19563118141377345, 0.12872466846602038, 0.10776879295008257, 0.24095908273011446, 0.176044880063273, 0.18696967978030443, 0.1775499852374196, 0.18789046240272, 0.1461634467705153, 0.1673514215508476, 0.1218927167064976, 0.179183897562325, 0.22455021244240925, 0.1107204775325954, 0.1493340649176389, 0.1070324340253137, 0.0941611961752642, 0.10249903978547081, 0.08498473311192356, 0.1861010998254642, 0.15343167004175484, 0.1407487373217009, 0.1401368365623057, 0.10873421575524844, 0.1184885595284868, 0.08962841791799292, 0.14246808568714187, 0.116915421676822, 0.21665082225808874, 0.10776486698887311, 0.10613260965328664, 0.1012498493946623, 0.1589675573632121, 0.11534650664543733, 0.15387447987450287, 0.10084557929076254, 0.1214538402564358, 0.10851467362954281, 0.167645905748941, 0.14155741111608222], [0.027885373310709838, 0.027549729602469597, 0.03926760131435003, 0.023260329398908652, 0.020465037596295588, 0.04168750368990004, 0.03308422354166396, 0.03035301990166772, 0.09356393798952922, 0.01502807113865856, 0.0436685407476034, 0.04078142301295884, 0.07332607550779358, 0.011220943542866735, 0.06428680586395785, 0.005949969081484596, 0.05748178664362058, 0.03971778067352716, 0.052057514621992595, 0.06924765490111895, 0.04273591715900693, 0.04070770548423752, 0.03819372475845739, 0.11338106953189708, 0.04268605225661304, 0.021520698137464933, 0.024164871974790003, 0.02526443982787896, 0.02843973536073463, 0.10236485948553309, 0.03386340438737534, 0.027323621325194836, 0.09960360257537104, 0.03264788523665629, 0.09570008391165175, 0.039920335038914345, 0.033589529630262405, 0.036280282511143014, 0.026348170249548275, 0.05391941100242548, 0.0419630111719016, 0.002703679701880901, 0.03737359962542541, 0.0517778102948796, 0.010715699609136209, 0.05823827632411849, 0.020016609705635346, 0.03437613195274025, 0.04885086520516779, 0.0404995590361068, 0.02595773748907959, 0.03573872621927876, 0.020216939483361784, 0.05673587627825327, 0.04062811014591716, 0.03672644685138948, 0.05970419981167652, 0.06825911419582553, 0.03710662684170529, 0.034874035118264146, 0.0777244359778706, 0.07611165259731933, 0.010417676294309786, 0.027950554285780527, 0.038299406587611884, 0.03789210109971464, 0.037005334816058166, 0.05060808907728642, 0.03019981835677754, 0.05853453796589747, 0.05898042771150358, 0.04400481528136879, 0.013581703242380172, 0.04582176719850395, 0.004195271758362651, 0.0357148142211372, 0.05409036100900266, 0.015648664302716497, 0.06170330074382946, 0.02478372294717701, 0.029851085018890444, 0.0631299386441242, 0.05895164351386484, 0.03735809244972188, 0.02696745537832612, 0.062350527732633054, 0.0474758288328303, 0.03439136082306504, 0.007675204533370561, 0.07073986154864542, 0.05521212093299255, 0.057697592055774294, 0.011462436541478382, 0.01637576122448081, 0.050986803325940855, 0.017876129641081207, 0.0833903624152299, 0.02335268225579057, 0.011608473578235134, 0.01654490224609617, 0.028839086880907416, 0.017700550488370936, 0.030148033147270326, 0.05480398795043584, 0.032273950419039465, 0.030979635594121646, 0.030131091771181673, 0.027175562863703817, 0.042779232608154416, 0.035515057752490975, 0.024243530351668596, 0.01528226321170223, 0.03266571162384935, 0.04014517238829285, 0.04454856833035592, 0.04451105276530143, 0.03347196972754318, 0.03745316898857709, 0.05813660580315627, 0.048979776256601326, 0.06574750834261067, 0.08664560766192153, 0.0077453059475374175, 0.01914794625918148, 0.026989936886820942, 0.07425524439895526, 0.05222936633799691, 0.05334621324436739, 0.035458665661280975, 0.006976565728109563, 0.050671219869400375, 0.04394743613374885, 0.036437135422602296, 0.044904231472173706, 0.06014695027261041, 0.037672050602850504, 0.08959230501204729, 0.02044918161118403, 0.022220522987481672, 0.026639038333087228, 0.013414989971352043, 0.06321488486719318, 0.010370915424573468, 0.04207353551464621, 0.05455621823784895, 0.02044768803898478, 0.07421704605803825, 0.051035792494076304, 0.03692169477290008, 0.030531953561876435, 0.09002052422147244, 0.03437876657699235, 0.02822131573338993, 0.03385572686966043, 0.036661828053183854, 0.0285886231722543, 0.025721224301378243, 0.019176019850419834, 0.04211550396576058, 0.00584221897952375, 0.0207852613311843, 0.05070833096397109, 0.035521325189620256, 0.0889025603828486, 0.029620690838783048, 0.08842103270580992, 0.06591955301701091, 0.012074356782250106, 0.05706085161364172, 0.038515167470905, 0.01578752198838629, 0.0148126080421207, 0.05505185043148231, 0.027420026308391243, 0.057982869911938906, 0.04360473089036532, 0.0320531763281906, 0.04302238616219256, 0.04052166019391734, 0.04334231489337981, 0.01659810310229659, 0.037473017728189006, 0.013048694636381697, 0.030541109808837064, 0.026601109020703007, 0.037555295930360444, 0.030592661241826136, 0.06385171436704695, 0.042397731594974175, 0.040048426017165184, 0.026988400641130283, 0.02668391043698648, 0.026402185612823814, 0.020829363456869032, 0.010672447242541239, 0.0027531136947800405, 0.06868100288556889, 0.05948230507783592, 0.014408792503672885, 0.04147210645896848, 0.007984764997672755, 0.018292235145054292, 0.027819639435620047, 0.07284258113941178, 0.0055729455380060244, 0.025288914002885576, 0.03013071142049739, 0.008336453938682098, 0.05332374472345691, 0.042429105888004415, 0.04234584062942304, 0.04788978767464869, 0.029301854920049664, 0.09467511859838851, 0.02744911478657741, 0.013982091913931072, 0.053903722000541165, 0.029224358004285023, 0.01923857918882277, 0.05910389510972891, 0.0675180129474029, 0.09210227814037353, 0.08153412491083145, 0.039292897417908534, 0.02326797908608569, 0.07480881235096604, 0.11433182749897242, 0.044022971924277954, 0.05497366888448596, 0.050195540316053666, 0.02838786294887541, 0.04274529419490136, 0.06775467642000876, 0.04530864258413203, 0.07898528550867923, 0.05017429262807127, 0.005732672416343121, 0.021563176815107, 0.0035418179186308407, 0.05765998001152184, 0.02861046086763963, 0.05687940021743998, 0.013850961840944365, 0.02442657179926755, 0.0910821145225782, 0.006872758285680902, 0.03754542536626104, 0.03383238632522989, 0.03867036910378374, 0.02311733795067994, 0.05059962488303427, 0.025493487009953242, 0.0074936381042789435, 0.05014056572690606, 0.06334889447316527, 0.01877764610981103, 0.04102495877305046, 0.02986109659104841, 0.03266913663537707, 0.010005206386267673, 0.02207301185990218, 0.02297240022016922, 0.06821676724939607, 0.02199681184720248, 0.02132046669430565, 0.0869317352771759, 0.01127939045545645, 0.013459498422889737, 0.053081047590239905, 0.05490424839081243, 0.008200481352105271, 0.04361811552371364, 0.03897048991348129, 0.014594647618650924, 0.027258438494754955, 0.046318226886796765, 0.0390103246900253, 0.018258393210999202, 0.03066619323362829, 0.0347820422030054, 0.020196561963530257, 0.0505129494558787, 0.02272388093842892, 0.03353533429617528, 0.048772386799100786, 0.04370814545836765, 0.04425366110808682, 0.03607050333812367, 0.0388943084544735, 0.026880039658863097, 0.014116078327788273, 0.012320156092755497, 0.027235279776505195, 0.01337576375590288, 0.06200233430718072, 0.07653109219972976, 0.014587587011192227, 0.0232214334391756, 0.05732614343287423, 0.013530224168789573, 0.05092822932056151, 0.05724590242607519, 0.050068755517713726, 0.02629694721690612, 0.03141157852951437, 0.052712344913743436, 0.013505387269105995, 0.02920149428973673, 0.04403416722198017, 0.017184871030622162, 0.049721578834578395, 0.02069335190753918, 0.06610153504880145, 0.027968718350166455, 0.02831698970112484, 0.049640629076748155, 0.07830537433619611, 0.006004401902828249, 0.0612525091128191, 0.05518343692529015, 0.08891087243682705, 0.038280184962786734, 0.0644039612961933, 0.04567311130813323, 0.014796315117564518, 0.0254395384399686, 0.05221313185757026, 0.07260541300638579, 0.022858176271256525, 0.037590058127534576, 0.006646106849075295, 0.06306615847279318, 0.04626790185284335, 0.016261051168839913, 0.01864259935246082, 0.016216340482060332, 0.010657572747732047, 0.03297928014944773, 0.04424605409440119, 0.03011413740750868, 0.030114669898466673, 0.060951371560804546, 0.050997571888729, 0.042823138064704835, 0.028806172631448135, 0.008187746097974014, 0.03376720349479001, 0.01843754023866495, 0.03870279724651482, 0.05664651427650824, 0.03233367475331761, 0.037658806977560744, 0.0872182117018383, 0.11026572654373012, 0.12014501087833196, 0.18251480476465076, 0.11450736768892966, 0.11097316397354007, 0.1643029015394859, 0.18086561904055998, 0.1533948743599467, 0.1965428949915804, 0.15789156197570264, 0.14175672229612246, 0.19631781644420698, 0.11712729741702788, 0.13507062481949106, 0.14079320681048557, 0.1472637549159117, 0.13812576478812844, 0.09305689527536742, 0.13848934293491766, 0.15010407281806692, 0.2778193017002195, 0.11334649287164211, 0.2919074019882828, 0.09599767028703354, 0.15293818636564538, 0.05718504260585178, 0.13115391077008098, 0.20763834414537996, 0.2863678929861635, 0.12145172513555735, 0.08345349691808224, 0.14080186025239527, 0.13185912917833775, 0.29343192174565047, 0.1465714944060892, 0.08939985869801603, 0.14190660644089803, 0.14703636086778715, 0.10637282059178688, 0.1160291266569402, 0.10641359418514185, 0.16723016946343705, 0.17273205157835037, 0.23825582466088235, 0.22713195125106722, 0.1556891348445788, 0.20967070071492344, 0.15362654317868873, 0.20076227170648053, 0.12926734169013798, 0.12436023898771964, 0.13754078914644197, 0.14663856971310452, 0.13003215455682948, 0.13267167698359117, 0.19094509771093726, 0.1860884833149612, 0.14242498175008222, 0.10052346493466757, 0.2162555989343673, 0.13786662166239694, 0.04948181318468414, 0.13480647961841896, 0.16114068450406194, 0.19336625060532242, 0.17522771609947085, 0.11382230601157062, 0.21028746996307746, 0.12274268359760754, 0.12127088601118885, 0.22601898206630722, 0.11649808977381326, 0.08802255877526477, 0.15932113135932013, 0.17058663623174652, 0.10309234974556603, 0.16126787377288565, 0.1719063232303597, 0.10331528348615393, 0.19397932395804673, 0.14605721575208008, 0.12040704095852561, 0.10450565867358819, 0.09827233065152541, 0.11887621294590645, 0.09393183543579653, 0.19194727909052745, 0.10308135111699812, 0.20854670321568847, 0.19428890343988314, 0.12599205103470013, 0.21815132611664012, 0.1826995995361358, 0.24619891250040382, 0.17679939192021266, 0.2105122071225196, 0.16690729069523513, 0.09971565945306793, 0.16432743694167584, 0.09903766302159056, 0.09744151859194972, 0.16005312645575032, 0.16492357448441908, 0.10276199012878351, 0.10066715214634314, 0.09113951964536682, 0.10406400659121573, 0.14827326871454716, 0.12031017584376968, 0.09916994342347607, 0.13299584708875045, 0.07647051068488508, 0.17579303967067972, 0.16773010982433334, 0.11080989890615456, 0.10884575312957168, 0.1654618393513374, 0.10545648343395442, 0.21866561961360276, 0.1787907225661911, 0.14112732169451192, 0.131004961731378, 0.15902787912636995, 0.143955409002956, 0.1591775703127496, 0.19323395536048338, 0.09033362148329616, 0.13942766992840916, 0.13468966557411477, 0.15009078837465495, 0.11286489840131253, 0.11231370532186702, 0.15782775211846456, 0.19014337041880935, 0.11157509768963791, 0.1826651193550788, 0.13957183953607455, 0.09120373026235029, 0.20209037465974689, 0.13213051774073392, 0.15792849124409258, 0.1120886267744936, 0.1697126534418203, 0.1703321686363779, 0.26607089617755264, 0.12679248698987067, 0.17360904748784378, 0.13499139313353226, 0.13394210021942854, 0.16413658624514937, 0.12712778931017965, 0.10506843667826615, 0.10700576123781502, 0.13294882461195812, 0.14024021773366258, 0.09380766670801677, 0.08311414247145876, 0.057265164869022556, 0.08598346350481734, 0.08099014550680295, 0.07336701237363741, 0.10429354544612579, 0.1285562603152357, 0.0838662646128796, 0.14345414761919528, 0.1556257257470861, 0.11662428456475027, 0.238511435163673, 0.07745239432551898, 0.06944155582459643, 0.14093452657107264, 0.13618620636407286, 0.11516171929542907, 0.14665195805719122, 0.07769760733935982], [0.035244793543824926, 0.019224047937314026, 0.08457451840513386, 0.0697611914074514, 0.06957379911909811, 0.05298564450640697, 0.07719489876762964, 0.02135373531928053, 0.04741970762552228, 0.0522668373741908, 0.01766781435435405, 0.043475682541611604, 0.04214644410239998, 0.014344302653626073, 0.08222052987548523, 0.0709154611104168, 0.011748906472348608, 0.04135072449571453, 0.021799495189043228, 0.04504181822994724, 0.05120571091538295, 0.02194130291172769, 0.049143271389766596, 0.0809126504464075, 0.05867874468094669, 0.03861359851725865, 0.04998313765099738, 0.059664123837137595, 0.04097936121979728, 0.048608739525661804, 0.027055648497480433, 0.053512958984356374, 0.05956227891147137, 0.08504929995979182, 0.009703339674160816, 0.029942480505269486, 0.047189144606818445, 0.03266053885454312, 0.040544340226915665, 0.012419891463650856, 0.05029102503613103, 0.035243632082710974, 0.022645964709226973, 0.026962421761709265, 0.028773187877959572, 0.031566950856358744, 0.0255873575588339, 0.07392870684270747, 0.0430264716851525, 0.05813514377223328, 0.038296296988846734, 0.018672750957193784, 0.05606641454505734, 0.02654801392054651, 0.07644896613783203, 0.024687180666660424, 0.033579592272872105, 0.034185040058218874, 0.0135250393395836, 0.052773223287658766, 0.05259703742922284, 0.06075164477806538, 0.0262740668040351, 0.02907201549533056, 0.06268552577239461, 0.025173946050927043, 0.026471600540389773, 0.09802112850593403, 0.04104540865228046, 0.008016710744414013, 0.04836047999560833, 0.007783869332342874, 0.008799595834716456, 0.04318516883358825, 0.04962985680322163, 0.01337478133791592, 0.04452926878002472, 0.0419518789567519, 0.02908392696554074, 0.0826887137372978, 0.05160339074791409, 0.03008431234775344, 0.13043076207395643, 0.01812174898077501, 0.08994187883217819, 0.030625892759417184, 0.057806394615909085, 0.020155857018835377, 0.02775820259557804, 0.01073389614248299, 0.025359084065712523, 0.06783652788726613, 0.017586860885785427, 0.038019030616851524, 0.05901838856516406, 0.042467905368539505, 0.02903096545196604, 0.0009767008987182635, 0.05583913924056105, 0.038502769893966615, 0.037333275031414814, 0.09359453673823737, 0.08375952151254751, 0.09629755732021295, 0.032804749280330725, 0.031202782702166587, 0.024009837325138506, 0.061345010399236344, 0.04906219175609294, 0.013015875938435784, 0.02291538658028003, 0.05624683806672692, 0.021022596447437536, 0.05824369771289639, 0.05096724402392283, 0.022154176840558648, 0.1009218127001077, 0.04817753688257653, 0.02054442884400487, 0.020300967298680916, 0.06091714742069598, 0.049779210312408395, 0.005338897672118037, 0.08429965659161098, 0.035399854168645106, 0.05642701296892483, 0.03501470178889576, 0.02427718118269695, 0.06274664905504324, 0.05901113778236322, 0.056312792730750516, 0.027145422391186003, 0.06593521975446492, 0.033114837133325636, 0.010276381581206806, 0.05088447600428481, 0.0336071036872454, 0.06367313137161545, 0.0081189851880481, 0.017572092147020157, 0.029712318246311042, 0.04710879598860629, 0.02649139176355675, 0.04339690727647394, 0.034912649061880074, 0.018618897011037916, 0.06431713001802564, 0.009281594775529811, 0.04719294069218449, 0.04744967554870527, 0.08040241649723612, 0.0682205002522096, 0.02417390947812237, 0.08843964576954022, 0.057964817169704475, 0.11995286884484813, 0.029368358773353975, 0.01312178690568544, 0.04595466729369946, 0.01708887237327872, 0.01747671874909429, 0.02101826230500592, 0.06969367081183009, 0.036540004512062296, 0.06427191096008755, 0.032285000997944735, 0.041626688398537226, 0.02698663061892148, 0.01889216135168681, 0.025148406894004438, 0.03134547543595545, 0.010758861990325386, 0.07013950860709883, 0.020272025394660886, 0.020175349527562503, 0.0502195896115154, 0.04630671988707036, 0.07674301246879622, 0.04403001490572933, 0.06191883898281958, 0.028731256534229033, 0.002756935291472473, 0.03711212244525086, 0.046001448572496884, 0.04175700210907962, 0.019244024697400164, 0.055321747277048416, 0.02123411039065104, 0.017863147622847464, 0.016635830179438926, 0.02993482896272326, 0.04970992340531666, 0.0873447404592298, 0.034550347409094684, 0.02235404092061799, 0.07242720850626938, 0.04307135306589771, 0.03618172158894595, 0.012774882961821277, 0.02388898970821174, 0.03603165932872798, 0.039729562267893925, 0.04241440394253004, 0.034489457902964205, 0.03066356417548377, 0.02654226598679088, 0.041174739017151296, 0.025343135312141385, 0.017667326392256655, 0.01633095962461084, 0.019243061760789715, 0.012412589658197248, 0.008153467224474298, 0.01830443234211998, 0.058181435233564116, 0.047533371252939105, 0.04936059078318067, 0.05366083190892823, 0.02529307188524399, 0.050733775497064926, 0.002284352813148871, 0.01233958922966849, 0.03505569060507696, 0.06603403671761043, 0.05907977159949951, 0.053986393540981226, 0.039627750738873146, 0.011013173734681914, 0.07059598880005069, 0.013506842806236818, 0.027796987233159598, 0.04330759351432789, 0.05238947727775667, 0.029625531497003976, 0.04466307429538574, 0.007907188301032875, 0.04003811758593656, 0.02613303833641112, 0.06809125523432158, 0.0245765487125027, 0.05066631427325774, 0.019405534585530404, 0.052631358048529364, 0.05827383261930663, 0.05375890301365871, 0.04786144505487755, 0.03773063202970661, 0.022751533360860776, 0.05135425919434056, 0.031956014354364015, 0.027260149145149626, 0.020438754436327145, 0.06867895455798134, 0.03666399512439966, 0.03788236041145865, 0.060991454956820235, 0.04900153973721899, 0.0698458704573568, 0.041707775453687645, 0.019045824883505702, 0.03132754143734928, 0.030188758501026314, 0.02674246032256633, 0.02006164508202346, 0.04164441088505555, 0.03444953777943738, 0.026495917009015102, 0.024492550583090633, 0.027727692904591095, 0.06899105734191835, 0.05142231413628906, 0.0023371176575892605, 0.040664790794835426, 0.032261463784379885, 0.011095162499259459, 0.03228675246646162, 0.015563101169391302, 0.05122914051753469, 0.03249148874601815, 0.00488404834868561, 0.005693560769941541, 0.022013792186044157, 0.07151479730964638, 0.038290248485282063, 0.020933540581609122, 0.03044406843400793, 0.03986989497207105, 0.07202698310720734, 0.043067835285910405, 0.013051238347543404, 0.0739239199901931, 0.030531250376952812, 0.08725201652850956, 0.03682156420836691, 0.05051299027400091, 0.01625429020350566, 0.034472199258743785, 0.03817512282694224, 0.052280555973993614, 0.03282902864157222, 0.018190297450928483, 0.013638985910802148, 0.033894095904543065, 0.027271131075394806, 0.04767401194840204, 0.02947497570858104, 0.03826986539934296, 0.050727073903544806, 0.08209060208173469, 0.029110336290614214, 0.01449324890927528, 0.01890973355330061, 0.047967189966584556, 0.030127067475405056, 0.0013158548495084688, 0.016698764302418567, 0.04395539937831927, 0.04387216751638334, 0.03493438656732906, 0.057784968812484294, 0.021609442301269155, 0.08009988741832785, 0.018485742730263155, 0.031029177662276197, 0.08212535685743205, 0.004452265438885661, 0.05167071838513948, 0.03918059934221674, 0.08280137175461277, 0.05151089317223523, 0.06267350298003294, 0.02031096588325454, 0.023302887857425958, 0.04265748699253891, 0.06075659490306862, 0.028660210737143643, 0.01591589312738506, 0.012367233302938985, 0.04173544642981142, 0.05047511476732325, 0.055672374946880154, 0.012436568449629704, 0.017417224480595905, 0.009761711444298271, 0.015545415790256811, 0.0930256508581806, 0.024264379135274794, 0.03324520650494378, 0.006298524303929298, 0.021797830922878347, 0.014603131294279592, 0.036481616043602116, 0.15100658376468346, 0.2203557125176303, 0.20984218135708943, 0.2128916810033843, 0.06962313709664159, 0.09737991291331127, 0.16206194210099056, 0.1138738555891905, 0.12054689126671292, 0.12513777968706563, 0.10937364277197048, 0.10799484371091239, 0.14988502050982788, 0.10289228899637237, 0.16515697992872447, 0.2346320659853518, 0.11569694135687314, 0.15139447466935962, 0.15190254896879196, 0.20655566942878067, 0.11696144225425087, 0.17300675011938438, 0.09539463819237426, 0.11361821540049277, 0.08450267108855769, 0.1208798038715031, 0.1752182759810239, 0.15176237211562693, 0.1240740594221279, 0.10980468956404366, 0.09496844504610635, 0.1391829244676046, 0.14053002640139312, 0.12924751150421798, 0.12617196247447282, 0.07982700713910162, 0.11404116536141373, 0.09846663975622505, 0.10851940111024305, 0.11249064074945636, 0.25283495953772217, 0.1685988827375695, 0.08640281404950656, 0.15781408175826073, 0.17397283343598247, 0.115321570483502, 0.13905744213843718, 0.20815925759961829, 0.11550531882676296, 0.12594278727192432, 0.11543628424988128, 0.11101537733338773, 0.11634567490546033, 0.1081495666585397, 0.11857483419589698, 0.13414918910712004, 0.10360679909354076, 0.10998811136232689, 0.10949565927148797, 0.14483503211522475, 0.15476566564757377, 0.204751493583899, 0.1577199625899084, 0.10696359240682796, 0.160017384623643, 0.13482029840815812, 0.11328925844281912, 0.23768417799146846, 0.11060292876209132, 0.17218023509485647, 0.1780470460653305, 0.18684204522287473, 0.1202042713703122, 0.0975252031639684, 0.09900225515593775, 0.09638449992053211, 0.18637695611687377, 0.20066304656211287, 0.13847776543116197, 0.12354976177448407, 0.13875230069970712, 0.20908459700876847, 0.228692346427124, 0.12355875660432503, 0.12599412904819474, 0.07903748817625456, 0.1318093459121883, 0.08725384221179411, 0.12049019860569388, 0.10463373109814711, 0.054327165489667095, 0.168022901925724, 0.11179060253198259, 0.14895920612616464, 0.11495863800519146, 0.0804316125868354, 0.1382945736986585, 0.07343788747675717, 0.1586740231141448, 0.13607985660200939, 0.11964306671870872, 0.1939624475198798, 0.1454131057835184, 0.166327198385261, 0.08806763682514429, 0.15221523062791675, 0.22779293765779585, 0.13862981664715335, 0.07505855988711119, 0.08613962621893734, 0.1254797910223715, 0.20268351392587647, 0.08959046448580921, 0.13752266590017825, 0.1820215882617049, 0.10577309847576544, 0.1712566174683161, 0.13151581166312099, 0.11339456919813529, 0.10450545829371549, 0.20210686518112198, 0.1263721048599109, 0.13142771873390302, 0.13115588488290086, 0.1994123644544743, 0.1585603557759896, 0.10480533790541813, 0.07625182945048437, 0.1497059699613601, 0.11387833816115744, 0.21460610150825232, 0.11839423998026177, 0.2668028319021687, 0.16131307056639344, 0.18574813439045101, 0.10900721477810293, 0.15415657020639628, 0.10903365007834509, 0.1903918563039042, 0.0932212735642679, 0.1272634242195636, 0.08444170365692116, 0.12951128563145176, 0.08459500168100931, 0.13315089658135548, 0.18435766134643927, 0.15819573862245306, 0.07970429302076809, 0.16145045694429427, 0.16525050537893549, 0.0852199642395135, 0.1571952344966121, 0.14398067170986906, 0.20856421790085733, 0.15515104809310287, 0.26192784192971885, 0.11117242320324294, 0.13127516285749152, 0.11945982303586788, 0.1519814837956801, 0.10617315318086185, 0.09662074779043905, 0.1526535875746049, 0.2479151141596958, 0.27403176587540656, 0.11413411935791373, 0.11266024375800043, 0.12907754484331235, 0.10196328337769955, 0.11089589897892438, 0.09007010710774921, 0.06966980334254913, 0.15954822854837403, 0.09773504541954026, 0.12244358324096538, 0.14897669112542644], [0.04601906344760209, 0.050548910221550614, 0.03310776075522881, 0.02815606610965915, 0.03370495585841127, 0.03319098148494959, 0.06500927920569666, 0.025375459554197732, 0.04210774852253962, 0.06452935456763953, 0.02264018894493347, 0.016295926543534733, 0.05463363908347674, 0.05331465712515637, 0.007738889153188211, 0.04725899183540605, 0.03717871164553799, 0.03318456561828498, 0.06524715980049223, 0.04355167846370023, 0.011355633141647559, 0.03695671301102266, 0.020811922986467835, 0.0320252678648103, 0.0601373914105352, 0.03163641216815449, 0.08922333145164885, 0.013539280225813854, 0.01533992994154687, 0.02988948930578772, 0.035510697634890676, 0.0426105906808516, 0.046058805455686525, 0.03402063208341133, 0.031506050218013115, 0.018411459313938394, 0.05429439595900476, 0.012659776784857968, 0.01426224709575763, 0.04328351824369747, 0.028081172276870348, 0.048254449357045814, 0.06575239909579977, 0.021256760737742297, 0.02968999444419751, 0.05515093827852979, 0.056407513038720936, 0.036153902183286846, 0.0175383318492095, 0.04282596935809124, 0.018555148380983155, 0.01035152959957486, 0.06589101001736708, 0.04879293315752875, 0.03862956953526009, 0.028051037370460108, 0.0791722621943336, 0.02998462336108787, 0.08662724692840129, 0.02089650370180607, 0.0489707962697139, 0.025821121089393273, 0.003624135083555302, 0.04823384362680372, 0.021996843388478737, 0.02422336063318653, 0.05230673523328733, 0.08213809953304008, 0.03835388764855452, 0.012241979184182128, 0.010945796930172946, 0.027065899412264116, 0.03287909763457719, 0.03329606588522438, 0.017816462823248003, 0.037243512269924395, 0.03482151703792624, 0.053218155662762, 0.036895890298183076, 0.030767967655265238, 0.03249766712542623, 0.04487698352022562, 0.024232329487858806, 0.03201506333425641, 0.060371327490429394, 0.040545913579990156, 0.020539044562610798, 0.027060756328864954, 0.044492825618362986, 0.047510075237369165, 0.012629961929633282, 0.03870206623105332, 0.02107512565999059, 0.015941222627589013, 0.04310294629249256, 0.04128562330151908, 0.028394809451128822, 0.06565248375409283, 0.014971820055507123, 0.06004533170198556, 0.05093569903692696, 0.03647707409982104, 0.057918592501664534, 0.008077780221356079, 0.025876784020510968, 0.037336889290600084, 0.07864281404181384, 0.045715384039795026, 0.043182478548260406, 0.07511646224884316, 0.03381750997505151, 0.05784400294942316, 0.017191119914059527, 0.051741426505031995, 0.01255232586117927, 0.02933972114988137, 0.040254245832329616, 0.08272386927274056, 0.03510349604766816, 0.017394481365045067, 0.021219610680418555, 0.046610777790192515, 0.05010721361031756, 0.03343024989590049, 0.03106703832600033, 0.06878174201119691, 0.03484321743599139, 0.027562650393520016, 0.07536874050856568, 0.03969517114455812, 0.024184919238905422, 0.05787993773992639, 0.040166145481634885, 0.026272899776813574, 0.04481639829464257, 0.04861025350692216, 0.02748974737187382, 0.01890315441414714, 0.04651800561987329, 0.016744094682508148, 0.07495212848880328, 0.1375226807431318, 0.053592142430716194, 0.055082512262742966, 0.05764894056483172, 0.02314237986865919, 0.036624913627747446, 0.0231785632786341, 0.035405349772190675, 0.03848147396638524, 0.14346094569191337, 0.05545292187889572, 0.0630626110068988, 0.02673955666978145, 0.03675668194773607, 0.03127003241388593, 0.029223359815659933, 0.06021682718710508, 0.05858076263393741, 0.020826999716518912, 0.028649713058257475, 0.051594110191217624, 0.07049556137644686, 0.03642999967269134, 0.010948709859803785, 0.047117787107708864, 0.009863792001851834, 0.024208621580328327, 0.06541082562762313, 0.02520574151276378, 0.08189201820641756, 0.015818456558918115, 0.047378321760334074, 0.02193911172071239, 0.08397674071602523, 0.02659831483470043, 0.022480276529677212, 0.06177229079185054, 0.051486020092852414, 0.028008226581732742, 0.02367591911024647, 0.07794916571583599, 0.10558238878729753, 0.017655411211308092, 0.04491740830417257, 0.03645820128440391, 0.0271330953182769, 0.04687185421062168, 0.006486047395810601, 0.0368899308523396, 0.020644329342758283, 0.06794333778088912, 0.07539132406236604, 0.011205527280253591, 0.012362493762339, 0.018600638322823215, 0.006084916576583055, 0.030970496045483742, 0.049469779260107316, 0.026517309415794443, 0.08795893445494585, 0.020354479856905527, 0.0323464248504024, 0.01940922491485253, 0.05974301413516514, 0.020011820997751784, 0.029760555989923887, 0.022481217201857362, 0.07230376708321273, 0.02280721855640877, 0.06376048957463354, 0.08423692284850404, 0.03830580390058458, 0.028373825225571636, 0.030707712685398292, 0.08406214707065374, 0.013586439072241774, 0.04848663025768474, 0.014813890102232108, 0.031128597620408982, 0.062272001086967066, 0.01859832467744127, 0.012989465685677715, 0.040559535700595006, 0.012450117283151485, 0.03331707608595025, 0.04819073968974408, 0.04484614357352257, 0.06091001909226179, 0.04460476375243161, 0.018782646329782438, 0.018984927955898456, 0.04805014352314174, 0.07453923462890089, 0.0436754909605952, 0.03193746066244785, 0.012919640721520409, 0.03914354761946015, 0.0541106253513135, 0.04917359554383438, 0.020001093253085855, 0.02738981718721334, 0.09207889306708239, 0.031778782067704014, 0.06824235650128685, 0.04685663276177365, 0.02943151368526742, 0.1075892080552876, 0.016965243557933718, 0.03077351335377898, 0.06991990710957907, 0.025895558501360938, 0.020732077173306607, 0.01466346326196799, 0.04581948509439826, 0.005267948354230612, 0.03794561736867763, 0.034596675977809355, 0.02096802076266613, 0.039720014538033865, 0.028306469757808372, 0.05863438651431352, 0.04938370497256983, 0.034794988969224505, 0.052324773132568225, 0.0313386922061909, 0.02579039803094929, 0.018133218873117585, 0.019581662927521393, 0.019559261199901812, 0.02589637671917444, 0.04349458875367418, 0.06163302678032778, 0.027446444910310674, 0.050257851034984924, 0.03619755902036559, 0.055089039451559074, 0.030021283600945026, 0.02124051326973131, 0.0363811403803993, 0.05160147229616996, 0.02098612916597631, 0.05458220453874674, 0.025669756360002793, 0.04261062036675867, 0.05132856604177505, 0.09356078386190347, 0.09210032629198395, 0.011150431164423935, 0.015957230752974283, 0.01046422101353528, 0.02562429795943899, 0.0951204146258533, 0.04221957904519513, 0.04032485747302417, 0.03082462506426964, 0.08290547280921601, 0.0345076961821178, 0.015584273714921437, 0.02816251537296921, 0.06916178099345416, 0.03575370275939349, 0.013544400117098121, 0.04124648614379112, 0.053480003916774876, 0.08024941533221863, 0.04516064720519353, 0.05259780926280655, 0.05678459827322513, 0.018786362634273246, 0.06110913360316772, 0.07190754928160459, 0.049715185232344083, 0.04030744297779165, 0.022890192522027064, 0.035978862943011336, 0.09712905957712792, 0.03477571168332361, 0.013420882623904618, 0.04031377720821183, 0.020944446441717446, 0.022555621217179578, 0.02197272544435691, 0.039929893900989555, 0.021378656638262328, 0.01812868064007489, 0.040359961058129556, 0.017614557837077882, 0.12612554855877534, 0.0551563596673077, 0.017901501814776566, 0.005492373347806279, 0.0422933299705619, 0.0777068396564573, 0.0681908885599114, 0.007419209969157237, 0.04977527692972217, 0.09243738008080982, 0.02841866578819463, 0.06128357912530191, 0.0420992769068107, 0.07139203866245225, 0.03528646513586864, 0.047488133641309105, 0.01437700539099751, 0.03820702033408452, 0.028853260046162177, 0.030290007853182033, 0.0518912809639005, 0.055747368969605304, 0.06963207255466841, 0.0835304576321505, 0.08033732272451743, 0.23865858820499852, 0.160044651129283, 0.10426880966406316, 0.10746469051809981, 0.1188654443831183, 0.17224055685801432, 0.13909354020142928, 0.10895504179643467, 0.13314711162820458, 0.13066535495454445, 0.15741496958071366, 0.1452411650097929, 0.12284102558624, 0.08100988663500175, 0.23128015600377694, 0.10249328071950004, 0.13604415929876268, 0.16826871607918292, 0.19430275191552937, 0.09921255012159236, 0.13222279638284817, 0.09814698190893978, 0.17468149540945888, 0.3422986652003601, 0.15300846775062382, 0.273080570041202, 0.11957203576457687, 0.12774016504408792, 0.1250194665044546, 0.1308965784846805, 0.1040144385478925, 0.1473610504763201, 0.08511619715136476, 0.12313126469962299, 0.17956550989765674, 0.13206166127929464, 0.15402219694806263, 0.13207298645284027, 0.19187833357136697, 0.17297460028203204, 0.14493725553620607, 0.15276667603757232, 0.09732480102684349, 0.14753101713722572, 0.0824223569361493, 0.20848284882958978, 0.1309622882399708, 0.11021804355550557, 0.11366715261829086, 0.1870985611458309, 0.1406306616263464, 0.1943001543986611, 0.1369901600992307, 0.10260238384944387, 0.12865885481005535, 0.209932797588408, 0.12495086237322539, 0.15016552264569327, 0.13063979538856074, 0.12678098370088264, 0.19615678524132818, 0.1507041437434964, 0.12493055721279234, 0.1228059442655649, 0.10238313116133213, 0.12210512679303065, 0.17933395982254297, 0.12422327563399449, 0.15243098780047148, 0.15148350270465016, 0.17710414744215086, 0.08483734258334152, 0.09867198459687643, 0.1261566297034733, 0.21540459303651005, 0.11489563708892092, 0.09881403908366337, 0.13458235102007166, 0.0799990443920251, 0.12422985106240958, 0.19296415499411523, 0.10404629894765094, 0.09776196311577223, 0.13163973548216745, 0.16729904076782987, 0.132133026199881, 0.09164887043880299, 0.13246242102468386, 0.11184913571923971, 0.07201690474175848, 0.10324871283955872, 0.1309789123479277, 0.10837852663826197, 0.07925484838779084, 0.09033523194375448, 0.11080037715146318, 0.14020036440342665, 0.11578801029827446, 0.23391035705571994, 0.20110060198931023, 0.25716607400681823, 0.18488512054318562, 0.06966480126720853, 0.13900843070587143, 0.14444492961047217, 0.16543797188205644, 0.1211713046359364, 0.12935656268382445, 0.15803378715645522, 0.2261919470038265, 0.19886514928657562, 0.09937724011251703, 0.2448971409467049, 0.1507319149095565, 0.07093117237673141, 0.26433599239680916, 0.22243898041779175, 0.16354684601537883, 0.0965048317448236, 0.16890852159122005, 0.17293148150201887, 0.19849826116114855, 0.1166999019915238, 0.09315450995927677, 0.19646692875539884, 0.1788851831224747, 0.09565955522703007, 0.25271912512835115, 0.0954144164279569, 0.12299380410695449, 0.16777959623141214, 0.23554608022095636, 0.10527646809350699, 0.22189031064044684, 0.19942297716625035, 0.1738686952739954, 0.09900936493068002, 0.07265711843501776, 0.12198082447866909, 0.15657537791412324, 0.3291639278177172, 0.12236010647029616, 0.13541967171477154, 0.08457994350465015, 0.09482644250965677, 0.12296050394070335, 0.15436575195053592, 0.09910565859172493, 0.09627269537304528, 0.19851645862217993, 0.09396270135766827, 0.13773598882835358, 0.09309823290095665, 0.1193698302085977, 0.0779028185934294, 0.10619518754538149, 0.19911514915293083, 0.1919279684079811, 0.10207456842181273, 0.20901105017401278, 0.10746251602540724, 0.14492959657218307, 0.1569699333049357, 0.12903724622447044, 0.1931479256018065, 0.05633222957840189, 0.18150714633520693, 0.14088346681091934, 0.11868398185470141, 0.23198967886855826, 0.09405508390045725, 0.1419945212546736, 0.10354497077059932, 0.18831709341611713, 0.17725107783917338], [0.01519532432212145, 0.0341568829753669, 0.04779192437126767, 0.10015832085628062, 0.031930332334013656, 0.05074889304523822, 0.053410631662700325, 0.03524099003698211, 0.01631492552405689, 0.02287875973706832, 0.02184783497796161, 0.014598372272303095, 0.05931597865128424, 0.06816365916165523, 0.09156106694717892, 0.04117452750506345, 0.03126068506389856, 0.037514800642384216, 0.041458911073277704, 0.02269415792397922, 0.01662545866565779, 0.017816338513512164, 0.029685912631975953, 0.012044313716614852, 0.015555953359580599, 0.005907850345465704, 0.054036529327277094, 0.036358274810481817, 0.07728555210633203, 0.036492276994977146, 0.03370619524503127, 0.03053710221138317, 0.03941379327443428, 0.056071583603625186, 0.021791012441099156, 0.0635249244805891, 0.03524771389493253, 0.03377919289050624, 0.057664280757308006, 0.09355433459859341, 0.03210846633010078, 0.004677734077631612, 0.06658173428149894, 0.03433245285123121, 0.02330201954464428, 0.05477425751450937, 0.020979904402338434, 0.028112283107475378, 0.08798983006272465, 0.0145720121145132, 0.006197056945893564, 0.05954364358331077, 0.013619977653434034, 0.021768751721538138, 0.028904620376124512, 0.04804588359547779, 0.0454566453845473, 0.017476108332630247, 0.056275232636835426, 0.05941198287473526, 0.02710030908929184, 0.018221295104012825, 0.07760717664496042, 0.027879950066562742, 0.043349944171495736, 0.06960156286368147, 0.012062587247783085, 0.01633450523513602, 0.015697594099037815, 0.06589459459064528, 0.020550354893202893, 0.045721681162831374, 0.03131037185085006, 0.07329824496991932, 0.02281747689266922, 0.008166509542206768, 0.06695317177218385, 0.0948997147497721, 0.029182430371292867, 0.07071819083648734, 0.03208099202311132, 0.09475358587224036, 0.013311220100149512, 0.04594554629875347, 0.027742474630940706, 0.05418862507212907, 0.03810766160313506, 0.0353381297463784, 0.03313329063530546, 0.015803710084583145, 0.08618252977612428, 0.06621564767556265, 0.012459232711989898, 0.006474401243394823, 0.03725425856828224, 0.023524767748313025, 0.02269033586344449, 0.008157449774444103, 0.0215216128344764, 0.044615387596422806, 0.1221538265235722, 0.05886779566935729, 0.0015331321492340066, 0.04655172881030012, 0.008004713927221019, 0.0610589644202264, 0.04632049414794892, 0.05215577126364224, 0.08848461991874501, 0.10767143059638329, 0.05240085440163966, 0.049634925671853125, 0.09561038052197546, 0.06081649364205077, 0.024172451157937758, 0.07322017845581286, 0.03609750267060008, 0.0454858154989779, 0.04570896446239203, 0.02196608136728173, 0.08979928999906406, 0.10167291809921153, 0.05677009299688507, 0.033058582339435816, 0.03665421732875984, 0.08875846498995088, 0.01303315963014029, 0.05199284016271122, 0.03193235468643252, 0.018289244289917406, 0.08375207034987397, 0.04925793320580851, 0.022968687626416795, 0.048710658666095696, 0.025418689656362403, 0.027159749552083667, 0.08697615281562321, 0.010042547546618152, 0.017846671944425907, 0.01238487786395126, 0.01898496691865148, 0.011246173780818935, 0.03983757815149147, 0.05754405654442962, 0.016936266401899047, 0.06746884566382505, 0.073366262804484, 0.034762764917104505, 0.018605642253533006, 0.03603145152737852, 0.04182390672212932, 0.014070253491809126, 0.012566609420900932, 0.08946890069637448, 0.03669189987704158, 0.08925300251576118, 0.005453568301163614, 0.0315865917946212, 0.01722324563161237, 0.06201859476277605, 0.03139575965178665, 0.004767887858179165, 0.03970779507653788, 0.00943942453886848, 0.035729675728362054, 0.06891400757012889, 0.03052733369258931, 0.08344128116732463, 0.03230801499739755, 0.026080969255417585, 0.022317235961963888, 0.006187584358485765, 0.05935399516602047, 0.021176315640332177, 0.01958115455636289, 0.029976747318869457, 0.020996020139136817, 0.015534509002463892, 0.058960178212146275, 0.05847040898515843, 0.042230054459651, 0.005594508638750995, 0.029804242512909696, 0.04572403748170473, 0.0805309861607384, 0.010428276946186088, 0.05180339212529361, 0.030823573069937993, 0.07536220960901119, 0.04114465235034004, 0.04820096648472827, 0.06544499410665594, 0.033123431203421205, 0.012030664693156723, 0.06705584048177116, 0.02688843334908597, 0.014973577090131585, 0.019239800021750852, 0.061503217730205506, 0.01682580514170695, 0.02453214787237812, 0.02908065409428673, 0.05398758097726386, 0.040186183468904346, 0.058032523302244954, 0.012525005549832713, 0.0422466971212998, 0.021156496586627327, 0.054876232316019014, 0.049454698819317855, 0.011844590644614073, 0.07573542825412005, 0.012781832247128477, 0.05219078579102643, 0.01947728913364699, 0.07462622175808065, 0.07510619092499837, 0.021353397642087657, 0.04718169344414491, 0.035833509609801695, 0.045723681250819936, 0.04703457379946485, 0.03187007736414671, 0.020431733719306067, 0.027592668411671184, 0.049820351268863305, 0.024306475606863387, 0.06701546022668481, 0.04469762498047203, 0.006281477635639021, 0.010371075914008543, 0.01921374692756217, 0.010601105514069786, 0.04083239742612932, 0.08370842464501038, 0.07515532852266915, 0.07293086702702567, 0.016873022432264406, 0.0721511518349871, 0.03765708148421254, 0.018566681355878245, 0.007068884260661434, 0.024446155221085064, 0.03864620848617051, 0.004012993795186048, 0.01857498227764154, 0.009224739769706503, 0.028722334063786548, 0.026922562865365762, 0.13404184486716986, 0.030425297663896345, 0.05381436370953452, 0.01606885347428033, 0.05599807387625333, 0.0197124608894228, 0.09241201347322203, 0.04340302257332951, 0.0456531772215385, 0.03816613170783967, 0.016135587393364403, 0.023578970503876917, 0.06407904904335737, 0.015882179213804193, 0.02760798262897879, 0.07631449640030041, 0.04346642424934544, 0.03149763055262156, 0.04883661225903779, 0.020780993982043583, 0.042652162082958966, 0.05764775683928747, 0.07376078108791262, 0.022454347745224368, 0.020612988446373492, 0.02322845972230425, 0.019280506821814924, 0.04442671139258891, 0.03608087485190481, 0.048210083768935874, 0.02478131096722791, 0.018885044155467767, 0.04717458738014102, 0.015264550002029864, 0.085049040208105, 0.019240929941588547, 0.0783989294723142, 0.01720282729365863, 0.05312123117619194, 0.04130214721953962, 0.011816932656074641, 0.03727942479599733, 0.0647981307702139, 0.03946603676013183, 0.013638780892506475, 0.00961898531386396, 0.051207929936936125, 0.07176306055043824, 0.01502378430814133, 0.0362280983972596, 0.018455236750014592, 0.015155716828303412, 0.05062796008132864, 0.029889528268540744, 0.015334814688685583, 0.03229496433050372, 0.031097202918317635, 0.03884387209836859, 0.03747716262296308, 0.03590198015444912, 0.017041152277670335, 0.010303349372406956, 0.04375685632112436, 0.07668577803997323, 0.01793176845239941, 0.049804788432084024, 0.028068043684470467, 0.03695859064464457, 0.047867534376564436, 0.01465583027311368, 0.02350900638703024, 0.028855425262008794, 0.06058256498363335, 0.04087526387593243, 0.0252750543950242, 0.029422073566820472, 0.026847561421163846, 0.06908780371304601, 0.05138490618264768, 0.029247774618852418, 0.020153125915385317, 0.03208105139492545, 0.013102532811899437, 0.020670725680247415, 0.029580564769275952, 0.054790269350633025, 0.01861438104242552, 0.07987245626281947, 0.04727331528556533, 0.028233097327756695, 0.05707003569114022, 0.029661182416020893, 0.002383214537076128, 0.01711086035356857, 0.09960455252439715, 0.040819138957886025, 0.01764438104146393, 0.08457713818643242, 0.02225450964033371, 0.07920625255792402, 0.024749060939939227, 0.056669261102797464, 0.040660760932951234, 0.0739451899426058, 0.07033199202851392, 0.20037668145960197, 0.1567592821083963, 0.09594386458047666, 0.10540196526562795, 0.0736216655059252, 0.12547665915917605, 0.13034574163611978, 0.07524219690822065, 0.13048299442743883, 0.11164589857799001, 0.1896271324949339, 0.17778270790586248, 0.13462192233419046, 0.1989303989103064, 0.1335087008192204, 0.12078533589374274, 0.17412164888810366, 0.11149745419970714, 0.15466244774870574, 0.10800535252201371, 0.09350382402772084, 0.1557714241789654, 0.13671718334080651, 0.17771707236533985, 0.09778358929906972, 0.1408711026306264, 0.16466204164316878, 0.08325411152327433, 0.18374688865151256, 0.19457088987110183, 0.17345300351735204, 0.1469755789730698, 0.08039608597755432, 0.17115325113991275, 0.10927348994300701, 0.09497528764768504, 0.10664208661182784, 0.18423511792207137, 0.18365872150752693, 0.06832464583567344, 0.13085528538795188, 0.12261411393410526, 0.07927840415504761, 0.18666578514967114, 0.14236832619644701, 0.08245366814662702, 0.18806948326528072, 0.08453822738374583, 0.14699313818709925, 0.2262839287868701, 0.1359276717994362, 0.08578427848988213, 0.1269478036556393, 0.1130157547595445, 0.13050699548330158, 0.1327388413483277, 0.13827884016791359, 0.17443079792428762, 0.11870036847540177, 0.10725605054176413, 0.13654444104759023, 0.09355096524814144, 0.12738203426124528, 0.06725806088070385, 0.08804727971437387, 0.09345920610940084, 0.10793899709824473, 0.11730805490515195, 0.10557670393609442, 0.17488181591033936, 0.1614485718891956, 0.18149267445551232, 0.1409225186216645, 0.07111167753464542, 0.1382880873279646, 0.27371311734896153, 0.11821559019153938, 0.16097479965537786, 0.08945339723140933, 0.2485308444011025, 0.19791733764577657, 0.30601120612118393, 0.1273400435457006, 0.1591659037512727, 0.13965087826363742, 0.20890438870992512, 0.1595566890318878, 0.1581696595530957, 0.13405676203547046, 0.14516938448650762, 0.1541413413360715, 0.13658641692018136, 0.12865560420323163, 0.27236968162469566, 0.09503916429821402, 0.1882241468410939, 0.0875604382599704, 0.1000103069236502, 0.19274626043625176, 0.11529318333487026, 0.13642497011460364, 0.07791049240040593, 0.1202808684320189, 0.1665684557519853, 0.19356664532097057, 0.17385967075824738, 0.21286091156071052, 0.23779526265570894, 0.15808845375431702, 0.17215034138644114, 0.18262525118188933, 0.12838038615882397, 0.24569362867623568, 0.20647566590923816, 0.13522030116291717, 0.2251384238479659, 0.09283540872274898, 0.1501360593829304, 0.26325866114348173, 0.12931032688356936, 0.10700585771701299, 0.09852509872871451, 0.11757837477489375, 0.1614337883074768, 0.18794029019773006, 0.07088095124345273, 0.07041676013614051, 0.12527673941804096, 0.14552269130945206, 0.13850605610059574, 0.11361060096533038, 0.06572113983565941, 0.07347940321778879, 0.16569594241445884, 0.17048898444045335, 0.12249698076630011, 0.09790165015147068, 0.12667426286498085, 0.12231444212375209, 0.15519976266659796, 0.08909211974241771, 0.16216671850997955, 0.07493770855944604, 0.12352563455351628, 0.20258691598428413, 0.1963127253111452, 0.16812055371701717, 0.17533569858642295, 0.14561522228177637, 0.2459158276906237, 0.08971794319222681, 0.15053101553348824, 0.15875453129410744, 0.1757492232718505, 0.1340375404106453, 0.1250622735824436, 0.19573618046706542, 0.11434681888204068, 0.1797774969600141, 0.1844160386826843, 0.12363087851554155, 0.10047713265521452, 0.13131626299582422, 0.13967906503239647, 0.1309062709333375, 0.1869621395599097, 0.1415879133855924, 0.1474909411626868, 0.19483730604406446, 0.1005238582729362, 0.14245763624785468, 0.1226323188166134, 0.18468077760189772, 0.1862455514492467], [0.03079991711274488, 0.020855568691331428, 0.06641159692662768, 0.031104067784326617, 0.01898220056318678, 0.01821340792957926, 0.04482636533793993, 0.029687614005524665, 0.055825598756200634, 0.0484285646234639, 0.03407021868042648, 0.06290857083513401, 0.015450656519533368, 0.021048599446658045, 0.04919363353110384, 0.05115768282848876, 0.00840694126964081, 0.038350648173945956, 0.06773205575882457, 0.05228250411164481, 0.039175408019218594, 0.05863600810698699, 0.02228463526989799, 0.033562355893081985, 0.04064789209223818, 0.014898822410032153, 0.03882453544065356, 0.031010525635792874, 0.042239780304953456, 0.059686135937226936, 0.024898047086026054, 0.06988371998886578, 0.11257304882747121, 0.04346376736066304, 0.0247441534884274, 0.01854366550105624, 0.020420564396772534, 0.020874582514807116, 0.020967026284779422, 0.021384781211963855, 0.041523314648657106, 0.024202688109653536, 0.05417954860604368, 0.04790399980265647, 0.016792061542219017, 0.059489748819032684, 0.03455114521784708, 0.03237962111597881, 0.03478158207144588, 0.04630001087207347, 0.07351590946200304, 0.01522175220088684, 0.025990104404627346, 0.024367940277443267, 0.05063575263193343, 0.0536489538353635, 0.07116134205716662, 0.019148115097777918, 0.02413100406556623, 0.029168975233915262, 0.025073422148125246, 0.0675886134558823, 0.04441768687684089, 0.05593378904450219, 0.007100090642779833, 0.045603527541970834, 0.06816467590397224, 0.03257508054957725, 0.011941159827983938, 0.04955686286848504, 0.031038951747177634, 0.031101865461096168, 0.09077522903680801, 0.06112112670962233, 0.048900373876676895, 0.02161535721825203, 0.09714967643958516, 0.04511915743933059, 0.06589570781216025, 0.03111674181127455, 0.045332966474234127, 0.03345120443555061, 0.01903627344290726, 0.015706566664448474, 0.027593254708335735, 0.05262648955977056, 0.00851708526170114, 0.08689447204233147, 0.025554921994626056, 0.07680521928705275, 0.03909404265868943, 0.037174325552769005, 0.06749181513441727, 0.025436762807657942, 0.03173311772115994, 0.04380582322482951, 0.02849579534085933, 0.028146227086836006, 0.07801261934218928, 0.054549093620153144, 0.02022724049311364, 0.0324145243212115, 0.008982516683317954, 0.02439985633827746, 0.027834118736791424, 0.025795164474402554, 0.021240747046249453, 0.013315616397449048, 0.0224590102880029, 0.04449155654583592, 0.022030685322533827, 0.03844715334707871, 0.008222269880207023, 0.07314632734050974, 0.047573398987879045, 0.0193885820772266, 0.046312534614116885, 0.02598557544843061, 0.06592250676476397, 0.03811523893091362, 0.04482659540371969, 0.029713639269175474, 0.049196609543287195, 0.044379388345987536, 0.054488757014041767, 0.044365064895828255, 0.07797764192218892, 0.04062140484165866, 0.030766399868298322, 0.032575336590525694, 0.09751344012329355, 0.06981703802011907, 0.07712863982305862, 0.007933162542030914, 0.016068580735009164, 0.047348587613669224, 0.059813043189933524, 0.020677944921771996, 0.054750954077462666, 0.012934310198033927, 0.03129113909380976, 0.031486197767662816, 0.013785845803795382, 0.02290911172167398, 0.04144552643992938, 0.007959678550832905, 0.04679175792261958, 0.04138508593314327, 0.03261613615904935, 0.0813278226996772, 0.022648964841209818, 0.023214268003357574, 0.019828183976642322, 0.03524975851178169, 0.04238520414219238, 0.039364941403619014, 0.05148773816472385, 0.023864062823122367, 0.005797974918095861, 0.04770183135406114, 0.03472439217148349, 0.003004464733749046, 0.06257479733903892, 0.039494067677878775, 0.014363184745889157, 0.03987525327829644, 0.05375324413762428, 0.048455389551236294, 0.029749490568065085, 0.0880787022470031, 0.008459485325147398, 0.07818973288522102, 0.013334157101780875, 0.07945337289129384, 0.03278424745076336, 0.02288923515152419, 0.06677113036857918, 0.03717055544257164, 0.034592891024658456, 0.0352333125192672, 0.060280429242993705, 0.016579272960370872, 0.006810580689489143, 0.01366051561490167, 0.024943444259406533, 0.022733987134415656, 0.09763642883626744, 0.024333558430953417, 0.028660166208283044, 0.0345665225177072, 0.04763763186929282, 0.013417570789897582, 0.003838263241959794, 0.03146629336697515, 0.008366169531655032, 0.03301441713119857, 0.05725966926547699, 0.03544050530763343, 0.0459048394986894, 0.03348672362335492, 0.0088435179895896, 0.019322221087350044, 0.019319464008731302, 0.023085249340510927, 0.0409130503248889, 0.06875129911350086, 0.038348477391991764, 0.020342382849776186, 0.010192784211540129, 0.01836522907979088, 0.008967249777924735, 0.042498351976973936, 0.03633288222772535, 0.031308620382333174, 0.04856426632613875, 0.022496633464470506, 0.04959127996698953, 0.009085020265047206, 0.05234817675955128, 0.01557585404952988, 0.019838126900140196, 0.09157322332612239, 0.014279537281254306, 0.06389144153217785, 0.031194025359582156, 0.023358150028798264, 0.021097655408084393, 0.007811404866515659, 0.01774056894646492, 0.004056230854985188, 0.0765702108037658, 0.04409277091326658, 0.035801241028821096, 0.028244157183507923, 0.016689031035639346, 0.049331528280163184, 0.019192063227819744, 0.05349287275748793, 0.06544146890519187, 0.047008709952933714, 0.012900632464152295, 0.022770309697079938, 0.015249425032379804, 0.02404697810561629, 0.052007044869242236, 0.03370650694705546, 0.014930875768186525, 0.012314324667386245, 0.09475555998506024, 0.05599525000434369, 0.046324846844072454, 0.01286054164665984, 0.008907061601348687, 0.038495986664202064, 0.0015645759026483574, 0.037308717364794575, 0.03637895846622996, 0.09205603491864167, 0.037440667510963976, 0.0196389827033272, 0.01509340239863377, 0.06003962829709053, 0.024997966138471384, 0.09189459553454071, 0.046412602096097544, 0.03941366710932925, 0.01136331251473166, 0.012643689806282055, 0.03953835534048267, 0.03001494194904808, 0.018952447862830013, 0.04975588832166977, 0.03248193359468132, 0.04395374809973873, 0.08003596623893827, 0.07203632674645633, 0.036027703681611456, 0.08571174839744344, 0.010765107163024368, 0.06939315295312554, 0.011162126484123291, 0.011724456417141482, 0.021220950256974902, 0.04847941658226773, 0.032068739164969884, 0.08010546836885624, 0.022461745102191344, 0.01288737214053981, 0.02837831521901535, 0.013432338600978255, 0.02214406878920272, 0.04065440072736237, 0.04932100462610833, 0.01784986503480468, 0.10846774021047167, 0.023090436952770688, 0.04471515079785604, 0.048862045659916475, 0.06610828859265894, 0.02997566192789236, 0.0488723763555754, 0.023553162318421528, 0.0688141664431896, 0.03533763992891181, 0.12655244674533606, 0.003834903168353776, 0.03429785392654594, 0.029588804463855922, 0.0470903128007194, 0.07041546137770638, 0.015510788107349072, 0.03831997892120853, 0.052022273739567026, 0.038112882612040266, 0.06280983550823294, 0.028812460477638524, 0.0265639070130419, 0.03853833732136991, 0.04698482764069922, 0.058169601688859984, 0.01251992925972445, 0.02383116527198581, 0.04643359745386988, 0.04827105862204917, 0.020256024690752383, 0.06816884677391499, 0.01416952316503739, 0.04449939362530131, 0.053085786203155294, 0.04281930858269334, 0.07748920485028066, 0.04350729061115999, 0.039415021528839134, 0.05482511318405159, 0.06570077530341223, 0.11364865829818882, 0.02656675314938184, 0.07449072043527849, 0.0718861902714707, 0.02840332374034915, 0.003925583177988301, 0.06084502179874107, 0.04221502967993729, 0.011985179389739642, 0.025244882381230127, 0.034730117840808816, 0.007828761845303234, 0.04018297368020285, 0.022936626846785657, 0.031345078386948444, 0.01766898323694477, 0.09639707932365127, 0.18741373642114922, 0.1295382107491605, 0.14044692070456222, 0.12384637593640946, 0.1115460203436669, 0.1420487425639294, 0.0712180495611392, 0.10635532817104831, 0.171498142008204, 0.0684400052705314, 0.16912436782149598, 0.10332037461921573, 0.12342879170319065, 0.19479907059576362, 0.21885652968194336, 0.13405213103396818, 0.10274544765707105, 0.06154674840217922, 0.17004479421302676, 0.19059576879953966, 0.16128764458699152, 0.19682220969116315, 0.1404748106142506, 0.081668787606759, 0.15614709933288395, 0.13558039121562615, 0.16526309220353141, 0.18596984358737245, 0.16930049430811778, 0.12464022904168814, 0.08523345648427494, 0.16293604363454506, 0.24478630861267447, 0.13354368566069752, 0.09207949420670047, 0.09972291023586877, 0.15165492397500202, 0.11639096075668931, 0.09989481390221044, 0.10308049022569321, 0.17539389780722558, 0.10554561536991969, 0.19138073839712888, 0.13472742604790255, 0.11306394240818918, 0.1437142852228135, 0.08538618305465207, 0.2063394818105735, 0.07164989045122638, 0.09128495832555927, 0.18336380686378106, 0.10498352014110424, 0.16292364976834506, 0.0920919474447146, 0.18530228175222874, 0.1783705927664414, 0.22713119426043704, 0.04502381743805017, 0.119728480494814, 0.21502784918993711, 0.09970513579901308, 0.1730390335433185, 0.21350565977627411, 0.185485607071314, 0.11052931513404474, 0.1325246278429404, 0.1302835496608168, 0.12556495988974348, 0.08160671437508427, 0.19661080150399357, 0.16771137801697478, 0.12514922360423952, 0.1445194857660681, 0.2197810824145563, 0.13020523823797703, 0.08902142275474034, 0.13814865262247622, 0.16989835363347083, 0.14351902616908774, 0.18744340748526156, 0.17208050529006869, 0.18190285947639495, 0.08995279582450166, 0.07885769548011012, 0.0931295144255273, 0.14139629085548222, 0.1868243227363564, 0.2020290881046094, 0.17344881780445576, 0.26971991755999625, 0.11926748062251136, 0.1217474858276546, 0.14019438269315287, 0.18196258752141148, 0.1001890902989544, 0.2637910778867081, 0.12299378926400095, 0.13197687832871452, 0.16438538383226842, 0.24020661920076236, 0.0812474406848196, 0.15909382636891678, 0.16258760530035943, 0.14959626569179818, 0.1442770558060147, 0.1449997295276262, 0.1534242188790813, 0.15662884223274887, 0.1452024100581184, 0.2173703641165048, 0.18765000655548647, 0.11411730229156092, 0.11370587788405828, 0.12273449770873412, 0.14422804437344894, 0.14824190555373207, 0.20041240844875574, 0.10057744875666685, 0.2349905381561257, 0.12401125888573006, 0.15672864625230432, 0.1280539302388206, 0.10949617135338485, 0.16670955286826938, 0.1670917440787889, 0.1312727137701586, 0.24398841080255806, 0.1816037145908922, 0.17175329237943515, 0.09746511146659032, 0.14826857834123075, 0.15178229135926813, 0.15128313767490909, 0.13489531469531357, 0.14519516669679433, 0.1538062616600655, 0.12883472896646708, 0.08187778381397948, 0.1732188113965094, 0.12753442686516792, 0.0922496612474788, 0.08348241841304116, 0.26612584479153156, 0.1451280023320578, 0.09674875342170708, 0.09112584928516299, 0.10540386516368017, 0.13044802442891523, 0.07337896837270819, 0.18250996596179903, 0.06817436093115248, 0.12092223987565376, 0.11457107364549302, 0.0786901185347233, 0.15384228550828993, 0.22064780700020492, 0.11596849319175817, 0.1651963879703544, 0.17668505664914846, 0.16018591151805595, 0.11391899301088415, 0.1345851711812429, 0.18330387101741508, 0.13817504339385778, 0.13534036581404507, 0.1695795269915834, 0.2012768917484209, 0.10191755965934135, 0.16613174637313932, 0.2122329655685462, 0.10866867669392377, 0.15334342868300155, 0.07242294115712866, 0.10133360818144865, 0.12640523433219641, 0.2054629460326396], [0.014480944100796478, 0.05654677333950531, 0.020428301286301576, 0.021879971827729605, 0.02009370957239298, 0.024486502079525962, 0.0338061142974766, 0.006721269246554584, 0.043303511702106334, 0.06433025861042552, 0.04993535818357486, 0.043114174986840226, 0.03841741548967548, 0.06387247223756276, 0.012297497396502877, 0.049985657242359594, 0.04807821896974929, 0.030746558550163172, 0.03730848358827643, 0.02165080590202706, 0.03132596437353641, 0.01218674855408608, 0.0545934554975247, 0.06235941866179928, 0.03088087800279027, 0.02120822056895122, 0.057628453578217886, 0.029141962913854513, 0.05470341580803506, 0.04651276605727617, 0.06951772244065069, 0.00932962564547779, 0.052024797041667625, 0.011221368422411615, 0.032647703410475515, 0.062176739011192694, 0.08641954205813818, 0.01849025869887555, 0.035188215915695764, 0.05090752711112145, 0.025911358825396746, 0.01551623083287268, 0.031659630258218385, 0.053627223751391284, 0.015502117967116646, 0.047407907477463596, 0.05790227267425507, 0.0859004320227541, 0.048711289491620846, 0.02945527168776607, 0.04402184014907107, 0.05990743695292622, 0.028650186177401338, 0.009191904373437865, 0.07361908283201046, 0.046656200938741677, 0.02018997725826921, 0.0548035315296147, 0.034461675604688935, 0.0718945542757865, 0.017671317291387822, 0.03763364446058404, 0.023771906635374762, 0.07737979001831263, 0.034073933129548095, 0.029156124946894124, 0.0758178363321349, 0.0957526131242048, 0.062150058802217245, 0.046358254621736705, 0.05899720767047256, 0.05568047548877075, 0.006462634028139291, 0.03568475352949463, 0.07795815312420018, 0.007187822702690028, 0.03997637832071632, 0.013801089517073706, 0.02917724832514068, 0.031501148332608864, 0.027492623194120824, 0.019901792038581334, 0.051509431141312234, 0.01345031527307583, 0.014536361195496283, 0.04427313877386041, 0.01850557848229073, 0.009165060891973553, 0.02199714395828778, 0.030830426803731825, 0.01710456137516303, 0.02537154286983423, 0.06316582890576683, 0.03698122985952068, 0.02261205041577341, 0.015819779437151738, 0.03888222257955931, 0.007557276339866803, 0.027476214308990166, 0.08166607876773924, 0.1526340690907091, 0.06864139446406625, 0.04813772065972444, 0.05290933317155577, 0.025404590705875307, 0.058777988379006274, 0.035272542445454746, 0.034953905051224865, 0.04831386941077653, 0.022716884341207333, 0.08345161928446032, 0.04432171605003532, 0.03754125449631829, 0.021631042509397957, 0.03692264472192619, 0.0570811938814586, 0.04604033711075317, 0.07561643971712328, 0.05382873539929278, 0.07742992951534688, 0.046573666695621796, 0.05438870437501464, 0.018571991422504652, 0.038396516611101106, 0.04320669482694939, 0.022437167026509997, 0.039480089326389134, 0.03712801182700787, 0.030044414488656912, 0.029673808203369845, 0.051679698372026905, 0.021181182273721788, 0.004568376762108528, 0.02163741570257116, 0.04004622183856554, 0.039102158043533564, 0.057461733813397586, 0.10826099271071143, 0.023531435945187695, 0.08493399247527122, 0.03391228965483606, 0.05723566820961423, 0.08499783943989314, 0.02538847125833854, 0.09946040518116206, 0.02897404643590562, 0.019789510661212262, 0.05713268408726435, 0.05614729008811992, 0.03425558861636091, 0.025744637205207255, 0.0038647335622954415, 0.08774899572017603, 0.017278335253649857, 0.06444063823437318, 0.06818175272201188, 0.002929210031652474, 0.06968269444769248, 0.04501857045397628, 0.022719504122505896, 0.005808422038171557, 0.04994640505174175, 0.0009702905401809403, 0.04735306647489779, 0.033616336004342884, 0.04277411549992394, 0.06123881277744658, 0.036486157987383194, 0.04919663922919426, 0.03780508799536619, 0.0071447396385337925, 0.03155192236590665, 0.0575832567847101, 0.020553303074848372, 0.03393138511455618, 0.026804455628735013, 0.05623260738502722, 0.05552719230763614, 0.043290613175486214, 0.036232751663192175, 0.05069210019428283, 0.013098110539431218, 0.05005076585803181, 0.04237120723701082, 0.024274283096019644, 0.0372129914467223, 0.06897366882185452, 0.030309988324006554, 0.056760140796541236, 0.06110392001573928, 0.018044352254946716, 0.046158323748386465, 0.029022172857366968, 0.031748016335768625, 0.037757969039375894, 0.028297979588387534, 0.03428487376368139, 0.04279476204828825, 0.03362015435413923, 0.026293134433217347, 0.03644709133368451, 0.0377700957324123, 0.06704968807753175, 0.05829272027767729, 0.041623749493737705, 0.01730122123262845, 0.013294464260980021, 0.009853951123659499, 0.018754194243228994, 0.015488250010093907, 0.09379476818139665, 0.08885186427505687, 0.04402427439345047, 0.043273091068840586, 0.013535362613765756, 0.013605042859126115, 0.05684002557245549, 0.010505525242479052, 0.091145234182477, 0.007926135331217665, 0.01622436124307569, 0.05127956574142445, 0.02177392820158275, 0.049055308336392045, 0.04311480210162699, 0.02724002581089735, 0.037159946441533975, 0.03584183650673367, 0.03358839043357875, 0.03465539470198564, 0.02924211945355637, 0.055706424682284705, 0.03889724364853464, 0.039404831841238774, 0.020740070103784092, 0.06758741117664613, 0.02117984084179625, 0.06901837579789571, 0.016115107828227337, 0.033670664925011806, 0.016825107522890903, 0.07734614104265347, 0.016316140790877398, 0.010442192215123214, 0.053609757305821404, 0.07041537974146195, 0.06306115639745258, 0.09041053766850382, 0.034477832159609534, 0.033648838361841626, 0.016676796731189825, 0.04202659838483669, 0.027087622074759565, 0.008951690651883837, 0.016877143207238987, 0.06710013185511343, 0.021819612957187928, 0.04024402645882219, 0.03923123607819434, 0.023190292922663502, 0.016041353192122187, 0.07126133161364123, 0.005483288532559527, 0.03858292555378284, 0.01700002987490734, 0.014833308396191569, 0.019821443420369178, 0.0023326733526118915, 0.09654136025346816, 0.07792718330165371, 0.02333807307877578, 0.016354558065359015, 0.030432227467827033, 0.05552393056859728, 0.012964808756805724, 0.09125761760515161, 0.08284826806630008, 0.014139614613668527, 0.007984560907061677, 0.05027133214753121, 0.021522917159018107, 0.04674838681239635, 0.014357361669681268, 0.05051455991633702, 0.023988079410628416, 0.05242101484327577, 0.06692663999274373, 0.04365690387203358, 0.05896360693441238, 0.07144691306166351, 0.01910950115416199, 0.041674608874018304, 0.026274940682924353, 0.051043618441326544, 0.030586070970457513, 0.015350884968938772, 0.08750058404984884, 0.02812059330608463, 0.010647521285136463, 0.0438376724923728, 0.027017641259590164, 0.022577521995117422, 0.06259462010348216, 0.019916263918275945, 0.021012757424614392, 0.04042109918373171, 0.05291065048368182, 0.05086213735921774, 0.04190270425169729, 0.0981485478405375, 0.117694201762788, 0.03195777695509605, 0.04054044395161327, 0.07322288729483262, 0.05685703188646585, 0.05225340821198188, 0.03990495402831584, 0.048227687511825934, 0.07110724691301584, 0.011311983726045582, 0.015214526465570088, 0.09621902325307019, 0.042739687269204296, 0.013711453848372912, 0.059277665277477354, 0.03353753847477492, 0.010724232452048454, 0.02074669006105978, 0.10391119838459417, 0.039811532478779554, 0.03824390878435224, 0.042991431182599626, 0.03102066708379425, 0.07402245493722148, 0.0238758741033962, 0.06019177599227987, 0.01828867654694477, 0.06533952750032768, 0.01182674384835991, 0.021516501292353496, 0.048606869313516654, 0.10028021861216985, 0.014881609222356929, 0.04174060064542573, 0.03259695535234641, 0.06019795066094957, 0.016774984724179376, 0.026022384117823094, 0.014605898577428889, 0.03888633778842632, 0.03179985906172078, 0.0282069366221549, 0.14943504153052345, 0.17089700239012018, 0.11865058520925231, 0.09315732269897126, 0.21560417138971388, 0.18597944697830826, 0.13481295114615932, 0.08670279756188393, 0.09150647456408478, 0.10746940315584652, 0.1299231479060836, 0.1345531252445653, 0.1366685875109397, 0.11969370345468633, 0.11118016380351037, 0.18930523336166516, 0.15351505775470287, 0.21714653237722814, 0.17038155114278197, 0.07179155159974471, 0.15898104960797355, 0.23244694573804736, 0.10849204554688185, 0.17107816063798964, 0.16096063947770745, 0.13247954979306087, 0.23653675831155851, 0.15310009330278262, 0.16309847007505596, 0.15039604855701327, 0.2976957679493353, 0.11235316531383432, 0.09354241570690647, 0.11734463536413386, 0.1662148817558773, 0.16651712881866843, 0.22973853716393933, 0.12432235977030359, 0.15273126075044274, 0.11155207626870833, 0.09983170908526517, 0.07973073574248701, 0.1360659784404561, 0.0817417555663269, 0.08958080914453603, 0.13917167350882664, 0.08473989117192104, 0.1452311163302511, 0.13775957428151742, 0.10806289123138413, 0.175128401897382, 0.20265776140149683, 0.1584611157886684, 0.09690662307548337, 0.09589683468220755, 0.19923746993299574, 0.11415820205002092, 0.17493286082753912, 0.19252578320447356, 0.20793352596228942, 0.13861601270036772, 0.15754220337839797, 0.1446436470723711, 0.1367650370229967, 0.10230896092252806, 0.10245898607536219, 0.09745546354679391, 0.1441219766275026, 0.18477143836207688, 0.18059397814795375, 0.21230161422863603, 0.19538474385626614, 0.1082810974912718, 0.19866761926095933, 0.12251162333996035, 0.21918044745689258, 0.11362676494172774, 0.08288153112516738, 0.11162194205098785, 0.11089557243394665, 0.11290116715827025, 0.1075770368333906, 0.18223507446236908, 0.07729692923021503, 0.07707207332714461, 0.14259092597058043, 0.07849713045288809, 0.08937196136685088, 0.07549952919362113, 0.15552464523352683, 0.09769016774953343, 0.14693811535835266, 0.24995943414978683, 0.11935805232496932, 0.14715903787873685, 0.1324819543515332, 0.11199657819815911, 0.12858345260610804, 0.07747433963231742, 0.16708418901544064, 0.20715483493404463, 0.09225012880051509, 0.15608619869453833, 0.11250640396610834, 0.13787876319838688, 0.09385144599946216, 0.15912517468677834, 0.16013500018743798, 0.1192809951317031, 0.12671037577092648, 0.2043771542957984, 0.10652877550455742, 0.13771160185569897, 0.2007320217671804, 0.16535997216124088, 0.1607184618478641, 0.2106085082050413, 0.13415380526566878, 0.12763426057063043, 0.11260046376264654, 0.22023107623681426, 0.17527855321532115, 0.15031513961730525, 0.11664011457469314, 0.1357258521602489, 0.18710538890445605, 0.1439217006554827, 0.0875740715127904, 0.14142616972094402, 0.20325737219536677, 0.11947989070904441, 0.20070051017683, 0.12226130435010418, 0.21198954113060609, 0.19782127405051142, 0.0914562756952364, 0.1943880840553902, 0.16356694337446243, 0.10917550418525934, 0.13934515794971958, 0.2524529315996915, 0.09772521938430145, 0.1219048211351037, 0.11882835926371627, 0.16256060596788302, 0.19653108000056818, 0.1849495538044721, 0.11181990994373336, 0.11635814298642799, 0.28042112302500755, 0.09514001474599354, 0.11227080918615684, 0.23660589678911492, 0.1436369534349069, 0.1523062030901201, 0.22349808452418074, 0.10017892287578434, 0.17610906099434942, 0.14869799982989207, 0.15916275704512373, 0.222248456266243, 0.14513889705995098, 0.09936248621670529, 0.13222089648479596, 0.16965766029898077, 0.1703508707578294, 0.1300094003090635, 0.10988418100168929, 0.12056557854521088, 0.19954060757299885, 0.12265044206287712, 0.24445750750601292, 0.11119110306026414, 0.062344390171347186, 0.15602222556481138, 0.19212760613299906], [0.014599985515815206, 0.03813984483713284, 0.029044813927612267, 0.01333914433416794, 0.03069318143388955, 0.01124321168390452, 0.008554695450584404, 0.09050363267306238, 0.04526815842837095, 0.03273787806392647, 0.06489632432931103, 0.01081959750081296, 0.017471675855631474, 0.02652330782439094, 0.049959344396484084, 0.03704745169670787, 0.02354781885514967, 0.021031246178608853, 0.07176017359597608, 0.05912397762585897, 0.016669865071889944, 0.026139331748709083, 0.021148768973944243, 0.029216932816780172, 0.00838153384393081, 0.07688591300393455, 0.0008361823677205393, 0.027814151253551245, 0.02600074865767965, 0.04428433036082424, 0.05989958874124568, 0.11587617744226009, 0.08568563964217901, 0.01955994768650271, 0.042895285951090045, 0.02310683656105539, 0.08873424128978513, 0.06432942740502767, 0.04181704927759711, 0.10027520911535248, 0.02608775619592052, 0.0326928334106924, 0.02722710501984693, 0.02650113616255112, 0.029401209940260742, 0.08462048703222536, 0.02412007965176599, 0.030281068684416823, 0.033592078907531686, 0.03481084495433606, 0.008533517338946695, 0.019047758178203367, 0.022759693274565507, 0.01308215529206791, 0.004032745591757703, 0.11770246186642908, 0.011177408232470043, 0.042828830337384716, 0.01706731298327213, 0.014393900382856373, 0.05867861851584166, 0.0029944005154902698, 0.04691961883509066, 0.022990189499978442, 0.017935102550836746, 0.046210652581066824, 0.042035211008624174, 0.04839301203901414, 0.02549138487665914, 0.027037113359256182, 0.012919321598019451, 0.014242564411688363, 0.05036002992710564, 0.0292767053906573, 0.04612679731508251, 0.04533717074082233, 0.056386005599051714, 0.017597289916011505, 0.021065936016384512, 0.029881832197133917, 0.020611706386262085, 0.051546865070122294, 0.036201755865477026, 0.023795191518729553, 0.04562437818094622, 0.0401978129229974, 0.04109918467293028, 0.07460885550244711, 0.04078590929566417, 0.04236187844071537, 0.06490419109468348, 0.0452278449665755, 0.0493636595638236, 0.09423365947441198, 0.014337251323013334, 0.06139801087556407, 0.12323259754339233, 0.09199946842272766, 0.09889333756291308, 0.02257097810797859, 0.009912367422657553, 0.040374050731770694, 0.03882116980093997, 0.002619546362438996, 0.02964989806059748, 0.02915812689025188, 0.022586604027310386, 0.033070356512325816, 0.05340363692084793, 0.10849378959392197, 0.032090647364384495, 0.012754953513649525, 0.09236876852810383, 0.04232693441736046, 0.027424308500485495, 0.0763062882469967, 0.021404431427072268, 0.044344915586407296, 0.03903732773324009, 0.04383107108878903, 0.07461763510946184, 0.05634900211589411, 0.04192266802419908, 0.024264655585284345, 0.007559049145129393, 0.03251651025493629, 0.04083515079400968, 0.027149173947691452, 0.020868051615252625, 0.048984318200382404, 0.05594769689196255, 0.08375233752303757, 0.008489046922477428, 0.028151494479971007, 0.041727483185241, 0.1102556184923742, 0.003480442305772158, 0.012230647516844328, 0.05253926865407266, 0.03573272595531307, 0.0586648442549631, 0.03225246524380054, 0.08383011459955014, 0.05809458169096615, 0.03250360059610102, 0.10224861689493991, 0.0892076944001019, 0.02586702106782468, 0.03680538538901601, 0.02942125720437616, 0.02583697521913564, 0.06681860555545427, 0.028307863140071277, 0.07204993031336926, 0.025983124505728483, 0.038304616464301944, 0.017067398330254946, 0.040441322707920335, 0.006949026483198395, 0.057866927891154774, 0.0811271979182493, 0.016086288378573954, 0.06057589307602029, 0.046626214461866766, 0.10060904940473847, 0.06000385677907616, 0.07330628985073417, 0.013542880569730187, 0.05421476722403895, 0.01783848234481411, 0.03170645977661479, 0.029328536984394304, 0.023519821334048174, 0.0070526646231883205, 0.01722231423627818, 0.03302339340734761, 0.028842827305197716, 0.009374917062814347, 0.036762003146577626, 0.07081531570293009, 0.08163444101228379, 0.028540611783682834, 0.01667058495513629, 0.08257400739239529, 0.03373428182385396, 0.02745384226727765, 0.06249195139389485, 0.019822966678475495, 0.052747596928384155, 0.021459556301124394, 0.05000487515644636, 0.005211041398069938, 0.030431635605054908, 0.02427073191938689, 0.05137361069500912, 0.0409805523668183, 0.015641389400116168, 0.036427802915568464, 0.03254270435718354, 0.024382822193729226, 0.025805886652960908, 0.008205389731301693, 0.04502634816162754, 0.026192590121354442, 0.02320841060281964, 0.02811904407280963, 0.08791436106548645, 0.095601274369983, 0.045877855009166524, 0.04120020581467543, 0.03731290307769086, 0.016708686816855334, 0.06636323116254061, 0.06880909757455811, 0.05850853682204615, 0.036807192518608645, 0.03917308509699069, 0.012858926547778537, 0.03620906230935361, 0.13082159188343212, 0.0052728627633769065, 0.06917542908922769, 0.050118616709369235, 0.04949847440002486, 0.03119820736174006, 0.03557453346729744, 0.05840001998876687, 0.04266678239218891, 0.046836472320137545, 0.03495607212244067, 0.0025534806081850547, 0.024263588747999165, 0.04077133722603321, 0.055661543301539496, 0.033233231952181086, 0.05977139757305849, 0.04676466582168359, 0.009155488114629406, 0.050163717023679055, 0.01977532450837316, 0.03494997166853864, 0.06937259546248242, 0.00880187237271457, 0.011084109137300402, 0.05520481448911596, 0.09334002461400814, 0.051464319694787264, 0.03001665074407356, 0.007683581989113009, 0.040736719747656025, 0.03074311498494353, 0.030782528592681047, 0.02903997512476053, 0.04094253956282046, 0.02416955121589126, 0.06717724099871702, 0.004201657939120196, 0.029518447008740623, 0.04319049374316819, 0.023040321575535927, 0.09263303247280419, 0.02617243524582591, 0.037214583353488706, 0.07071397543768398, 0.06334018165944144, 0.03258596785599366, 0.12410773066221736, 0.03246670101361815, 0.03596679191105068, 0.0350448812241666, 0.029458349745254964, 0.03858418720483314, 0.03338522008561995, 0.03239647157897707, 0.033607489604037255, 0.06585840004845522, 0.02092278315103613, 0.006013817437633406, 0.056156273785745725, 0.007601312599945231, 0.026820476741704624, 0.1147218632104341, 0.03467918053502217, 0.09157325301202945, 0.04012583573057782, 0.022853291084174998, 0.09068212661077268, 0.030898500299372245, 0.025746199426066596, 0.024549471454520244, 0.042160767552559264, 0.03907583035470452, 0.019324944769323338, 0.05445715636597015, 0.04870897399086971, 0.024026752726058476, 0.06640375984716229, 0.019512773069436662, 0.014982814973336644, 0.02053840446023969, 0.0328204457036918, 0.02827444794093026, 0.0008698192254996684, 0.05923621261899825, 0.031827518905629404, 0.041394232903257944, 0.038541168614756316, 0.06420597113901749, 0.032389695770689286, 0.025565538417140488, 0.018696562765398994, 0.03861326455080416, 0.04905644011159893, 0.03896011097822338, 0.042085810637217946, 0.06240854141651653, 0.06432934576878324, 0.025511150124657433, 0.04591774915752467, 0.05624864890705794, 0.049793864018283784, 0.051148888378520496, 0.084161639388185, 0.04193534761725459, 0.06735683331498876, 0.03323979253764264, 0.03032078286196338, 0.0446322751668049, 0.06501080802991055, 0.06538001165608875, 0.06449236592743546, 0.06870944940601476, 0.022243854255066253, 0.05281198195007164, 0.08087372480076738, 0.025573635248292703, 0.010358193158026552, 0.057016289356397465, 0.03384136260137893, 0.04911457253911067, 0.02699182936339639, 0.037766451787319966, 0.04935718061460648, 0.026073486551467795, 0.02722554465435678, 0.009963447591871955, 0.0244935098089627, 0.04370225280581508, 0.022954974592721555, 0.041716770283528604, 0.021633163196383975, 0.06485601828899235, 0.0856573786586523, 0.13404252764303237, 0.19730441272258759, 0.12070957003743388, 0.15243588597513735, 0.09307864020229317, 0.11778709638747387, 0.2266170343500562, 0.12145732835051604, 0.13424482225673273, 0.13566030567744747, 0.13903002720326185, 0.1635688284295611, 0.16957292187726125, 0.13984005170641467, 0.11468353870441206, 0.06792147411033511, 0.13119613897288218, 0.2162900345865637, 0.190771019551903, 0.06918845378095284, 0.17616801720578223, 0.10425821921671741, 0.10493044173927046, 0.11552534939255565, 0.1457139872945845, 0.10623273279634304, 0.22563615260878578, 0.07582636360893957, 0.09990340055082925, 0.2528392936801538, 0.22638143214862794, 0.12961732369149104, 0.07874466638895683, 0.12532103079138324, 0.17185334872920066, 0.13914385781390592, 0.19866162270773202, 0.2328896219842136, 0.2524884953163564, 0.15129949460970238, 0.09965210934751667, 0.06795278532081284, 0.268242004676722, 0.09218039660481736, 0.25381023064255714, 0.16609020094620064, 0.10624184636981227, 0.13680431147804484, 0.11320354780764319, 0.15680490934755653, 0.11549144066520967, 0.05898624243855011, 0.11880350473802537, 0.09599675744539127, 0.17225912539288402, 0.22130573575850576, 0.14692158030811697, 0.06605716946069151, 0.14513042173348367, 0.14769387402338907, 0.09014256298542023, 0.22883200377691537, 0.12014172316412441, 0.12532122374977916, 0.2068730117753148, 0.10971175041049719, 0.13666762271896005, 0.13996685505844653, 0.1309685519663617, 0.08961931918747723, 0.11186483956407756, 0.10654675774276257, 0.09264875858207233, 0.18509764195187017, 0.14945153205189854, 0.18368674500379711, 0.09758871616213582, 0.10807366721564904, 0.13272732321638614, 0.06454194881371222, 0.13287358568049967, 0.12704431253951043, 0.11631246379693039, 0.1546169540961273, 0.09792960685444996, 0.13371041655773297, 0.20233584742527455, 0.22030511288903654, 0.11394786997698247, 0.20600472867954522, 0.18986963666975498, 0.12429677051841281, 0.1291207823669538, 0.19462796102743596, 0.1390699399053119, 0.26084944198373705, 0.18881010211771354, 0.15489429468289018, 0.18057356908684596, 0.11316679665469564, 0.13754509360296652, 0.17693685251288116, 0.06374549077008851, 0.11340328943333589, 0.22317115362966433, 0.1353097744868137, 0.16602331859758124, 0.12795510585419834, 0.20658571156673133, 0.14236262650229037, 0.09937410824932158, 0.14796302129980177, 0.16152450843947008, 0.12789512547897175, 0.18382603127975017, 0.14698466286063194, 0.12655265454668552, 0.10796307236887515, 0.12475230818381533, 0.24521201936295256, 0.13284563639899716, 0.14314278698293492, 0.13310048991115764, 0.09950172054232098, 0.17123220080975443, 0.09681754308985546, 0.1390378939686343, 0.07995916879735887, 0.10762962541775778, 0.1978434791089967, 0.1650080012041144, 0.14470885216724128, 0.10309076897101477, 0.16030517464969307, 0.20278426789445803, 0.08417588120209984, 0.1840475623612292, 0.15744717878988013, 0.1896147386287339, 0.12900203873869032, 0.10298402587068267, 0.2267126229708083, 0.12082124841981567, 0.132477575680241, 0.15473307052161545, 0.21555323037318885, 0.19223404495278373, 0.18718039034865797, 0.05012701039959211, 0.13037073716986924, 0.14443743391893804, 0.10550964347203262, 0.15790284262038767, 0.19953685230575502, 0.15946798754157498, 0.10013648687163368, 0.13032788556301966, 0.10570473183179274, 0.10591493773972616, 0.15461820090422407, 0.0982590981584508, 0.11697347246808931, 0.14415900979656726, 0.2126866701291874, 0.1768086984520778, 0.1877577812410891, 0.17244559741811827, 0.12358589694486, 0.09549111739033833, 0.09129821308306418, 0.12502362253144383, 0.1406962377950549, 0.11956741218455136, 0.14325209049275145, 0.21894396952120587], [0.0665361070423387, 0.0333826633868739, 0.023747523373458534, 0.036991953893448226, 0.04246131509717088, 0.03089913669100497, 0.006780507010262227, 0.025152273483399767, 0.04174300891463645, 0.005483564054884482, 0.017272214390686713, 0.09314268012531102, 0.029560680777649395, 0.017520987858006265, 0.04755997724714689, 0.021106956373841967, 0.0353473138238769, 0.01255569892236963, 0.07900095224613324, 0.06463704761699773, 0.05748469215177465, 0.011104306686320342, 0.043989267287543043, 0.03764824250538368, 0.039099048444768414, 0.03242246530135162, 0.050058517590514384, 0.04647031149943359, 0.04785815362993162, 0.00666267158521805, 0.034186246048193425, 0.08568306438974105, 0.0508308966527693, 0.04652233234082814, 0.03165430905937683, 0.03371885257365648, 0.022039839714125264, 0.06357424019370228, 0.06305349001195282, 0.03260632496676408, 0.05248903267784044, 0.03248990797146689, 0.02467866081133252, 0.09446353229577653, 0.03341559990076348, 0.011458528206276242, 0.053513281818595715, 0.06802354168030433, 0.03646085817308631, 0.09484089212492108, 0.06710386485792696, 0.062040373086347245, 0.024176234255719464, 0.028986777979298495, 0.031185368206934072, 0.007702082339164917, 0.01992416408029385, 0.021999195996613707, 0.04020399501314387, 0.03154180318233557, 0.055863296147435904, 0.06800962641136721, 0.05941532625001855, 0.04528809993644245, 0.03183626882673707, 0.10789239764562808, 0.011702904448611662, 0.0493630398705136, 0.02406090821750695, 0.055940872844075784, 0.03543627135513816, 0.13374212110647932, 0.007327695739149931, 0.03175726349581964, 0.021419656586658675, 0.039339055292657577, 0.0756133152754046, 0.02985436160088284, 0.016958792439254466, 0.014790514305786928, 0.045047929816064425, 0.007718204569755471, 0.032693928078515455, 0.038852102516102605, 0.019477682471915614, 0.01850911481596995, 0.055384885490639135, 0.079411419283133, 0.05035146554291714, 0.012239029147167457, 0.02922850846516667, 0.08287396864034235, 0.003398151116016379, 0.036030145347467624, 0.022528720219270326, 0.02370136178797111, 0.053292144075385295, 0.004830446268897504, 0.05864860235305969, 0.08785884841927327, 0.0339510334742954, 0.033430739713367075, 0.012902281887363642, 0.05392330727772787, 0.06116246433521155, 0.03900084375345614, 0.016547373597859405, 0.043518051752471365, 0.01748782869981369, 0.02009114730753936, 0.03645992306701373, 0.029647367337020114, 0.03413102283957414, 0.021914097633271012, 0.013977829203213332, 0.049961767508648336, 0.02038389488006942, 0.011741763300960883, 0.01310118859692011, 0.03235575364669785, 0.026752423655125313, 0.02540865767514333, 0.032494973129360005, 0.013164335159672191, 0.003835696570604341, 0.015629425979568623, 0.06814816311816685, 0.07824910469935276, 0.028053124660800677, 0.030440287191595417, 0.025539533562550787, 0.02588754887256073, 0.007613809902977664, 0.04130128261749633, 0.0009528010764370265, 0.009203313038597116, 0.05658029615005944, 0.05958078065305017, 0.033219160832231864, 0.06486166603281163, 0.06478774070274085, 0.05478795756062027, 0.04639681661501527, 0.07615509792231023, 0.006014210775902029, 0.051677368028322235, 0.016168143556569703, 0.029768025706289336, 0.05906981568841729, 0.029213021698524244, 0.06611170247197151, 0.036649241228587925, 0.08993332929094322, 0.0372477388009429, 0.04505927725404035, 0.052812675858149305, 0.10019066365202889, 0.02799409794533858, 0.034713809145614505, 0.008853437720972579, 0.08999699071864597, 0.03929508675355464, 0.021417968200694304, 0.10628857940901071, 0.023203673845273443, 0.029248208775243256, 0.0367921083670808, 0.028086283818993252, 0.11567808338440955, 0.04877863197179977, 0.026618662668624893, 0.04247301505529322, 0.060442098692874424, 0.027657138780341484, 0.037556913812295534, 0.018325629935134202, 0.026050017986563034, 0.030334137809404638, 0.032840658095665276, 0.06376753997756168, 0.022623601944360416, 0.06983085680985823, 0.04924949869746342, 0.037860255542909727, 0.008930957828852115, 0.019007912269444205, 0.030038820550544187, 0.05423774411610793, 0.05932478052272927, 0.05237439683696721, 0.023226808443723712, 0.041481839725747705, 0.02579403640993405, 0.017514996870886534, 0.051330892674741335, 0.08026105220778845, 0.1248957504867576, 0.028011373287881725, 0.03645709548436571, 0.04569308250211179, 0.020235096126270946, 0.04066427871293854, 0.0176370838744333, 0.03688064287416637, 0.018294897599844262, 0.019120963625027798, 0.04358875987236388, 0.03178637423843611, 0.0267956277821213, 0.023003516616881825, 0.036002285123686306, 0.011105025641882094, 0.02374568284722045, 0.060224864646443166, 0.025860211862891447, 0.04884333240624983, 0.06577654115972109, 0.00461727455331129, 0.03607960949011613, 0.0709056128107477, 0.008640489577373955, 0.025232134139514528, 0.0228516973220394, 0.021222757386567537, 0.09224486697348766, 0.04011847733636387, 0.01886462025140645, 0.04201191870379262, 0.018301168747711927, 0.05070380386314355, 0.030565127563022543, 0.08881937304977328, 0.01992370765947271, 0.0371404428005917, 0.032287687572534196, 0.07089485166943632, 0.02027428894507466, 0.09600788966054097, 0.03218998754164204, 0.021517646055144724, 0.09115070381085388, 0.020380160021886695, 0.041010794884641655, 0.009877813954517478, 0.022308992556645535, 0.015096168754098471, 0.03175473277224228, 0.051668484520632774, 0.04089375819603447, 0.031028107114252634, 0.008958661273936741, 0.036637741650338285, 0.03694596671266481, 0.09271290982724167, 0.01841458561102627, 0.017483908304711804, 0.0051626088406919735, 0.06455144088249654, 0.05488075941684656, 0.06523864736664109, 0.049827475886559114, 0.04074604112247471, 0.04257787310052663, 0.03079669433645904, 0.0408988864364801, 0.023612571239937097, 0.047955163463484496, 0.10111529802088626, 0.010086929833050817, 0.046783913421677426, 0.0027835234277517884, 0.049084790152846836, 0.025307797950517852, 0.05154689104529098, 0.05493718490470201, 0.007730514480499551, 0.015153795593505492, 0.0617761276953388, 0.013939562213636236, 0.06459727592300624, 0.03157575643854216, 0.03714904058142565, 0.008862125487212325, 0.04886968235950917, 0.020702819856524002, 0.0582352186756907, 0.011724605774361407, 0.05304516103933565, 0.03926323748601135, 0.05985177216643933, 0.05933505184657406, 0.05559301709581632, 0.03525032625475433, 0.012736979624605738, 0.02226272892585257, 0.015807461641088594, 0.04673649760661647, 0.008719668385310797, 0.05522152023331728, 0.01659339603065746, 0.04231003571476322, 0.019113844573439565, 0.03768987699004356, 0.019889116156264208, 0.02761459516477771, 0.05963955874904059, 0.021012275028624572, 0.05371515711885877, 0.017953993919945788, 0.03728564399352763, 0.014872918673063396, 0.04470705025596544, 0.06619585459702648, 0.06642422828008421, 0.033038047113223, 0.056453611541655846, 0.04971615744580049, 0.02112167130690068, 0.07134642626624554, 0.04715492788818665, 0.041727535135578364, 0.026117761226487346, 0.017698917763482314, 0.023261149472091347, 0.02098491575452499, 0.05579690361628309, 0.02711629495024681, 0.040854643302736804, 0.009577699638612103, 0.08498971292283386, 0.06901970424223691, 0.0314811103453394, 0.07955806766403839, 0.03822745908109937, 0.01797926775907399, 0.039171162934508175, 0.0033960666087295976, 0.018857822178688366, 0.03866275095788296, 0.0405373825924471, 0.014012506981089246, 0.02546157094911905, 0.015250239539454924, 0.05465467897010967, 0.025763443227333482, 0.051882909538107924, 0.0033301077701253234, 0.027269984457234386, 0.03328021732158959, 0.014968371851864504, 0.012197622872918146, 0.025340563770441804, 0.1510821343981661, 0.07552951938123442, 0.0949590271920897, 0.14286402147263288, 0.12334237602772191, 0.2383853294304572, 0.115456663625082, 0.12199675096780993, 0.14593550353311002, 0.09441076559596695, 0.10487196792382747, 0.14499790384434164, 0.1573164717410691, 0.09842316474532709, 0.10009862249717116, 0.07907731924206018, 0.08830119069898501, 0.0937048569903709, 0.14088422380154952, 0.16498116514412686, 0.1714827647083439, 0.11670769454212859, 0.19795290136244148, 0.11933608475374058, 0.06339020241284743, 0.13498198270099238, 0.11217765480978414, 0.10452188202179968, 0.09967947233235464, 0.08538036461686715, 0.12485151848522946, 0.216581535350997, 0.13656734372489154, 0.19177044014213607, 0.11492098885355517, 0.06707838692818768, 0.06860334455268458, 0.13926500600064173, 0.07594393464387394, 0.15033660252811387, 0.18648097553523257, 0.2873946988256648, 0.143541453871876, 0.1550563203636557, 0.1147029161802493, 0.0909168085490819, 0.12713694741250947, 0.19898202270269394, 0.11703616168233566, 0.16815433627925813, 0.17505712603451684, 0.12951651035109535, 0.09717757377075031, 0.14648098207544535, 0.14090797252720222, 0.20286243088776246, 0.05924711476836819, 0.09944349163561128, 0.102737313718535, 0.12462287762900814, 0.12898868008051068, 0.22076833178289235, 0.14550679450621828, 0.19167618738720194, 0.18681807385291904, 0.13274173572426662, 0.13594480056781322, 0.14139111066469923, 0.08076955695287324, 0.1292335442849435, 0.21286799164954573, 0.19775120046688244, 0.12608094548340887, 0.12307497279834934, 0.107488550565904, 0.09292200251366012, 0.12750434019835666, 0.17726286314427853, 0.15923099010251462, 0.1413800526643172, 0.16685198585037142, 0.16843022225657478, 0.1454712456325069, 0.14422896463656798, 0.17242508445633575, 0.20198506390443072, 0.1421071495860815, 0.20973559410776943, 0.14456299046287313, 0.09114094456890598, 0.17468872392782941, 0.172391390951816, 0.066793921723729, 0.1345636192127131, 0.09766429648152553, 0.16378730186261237, 0.1297738723224029, 0.09889413908240385, 0.14605991716962308, 0.16124569840030745, 0.11975498258834705, 0.15744841075502336, 0.134949357889127, 0.14714636199641973, 0.1188804060802795, 0.1331600101548247, 0.18507197848521173, 0.14389473100891337, 0.07531178067438304, 0.1390343316597864, 0.1093467028113082, 0.24370265426114202, 0.0974507286446169, 0.18686125200474635, 0.1790908767725341, 0.14290268736658618, 0.0590886699501425, 0.19696146628120914, 0.10273947336827405, 0.11426224373281002, 0.2014331880491227, 0.14113118086243048, 0.26745770301204175, 0.1432900142390281, 0.08594948798418045, 0.07459735221345909, 0.16732130519812927, 0.09251746523659676, 0.08517962851328775, 0.1775451167486608, 0.14520981669193134, 0.14459212718065828, 0.06583685550140217, 0.14051648962777108, 0.13028907123953104, 0.13265322719234973, 0.21929077513050288, 0.14667643408756703, 0.08482157936668955, 0.14293589105363935, 0.172374262183439, 0.1449438903364353, 0.159447266778443, 0.1987863628892228, 0.08646675749332644, 0.13818823877954856, 0.19278142339317128, 0.12558999995235354, 0.16325607255566865, 0.14443289197515696, 0.14776293828617781, 0.12008903810055926, 0.13356847339309752, 0.12575888307765126, 0.1301233348203823, 0.11351404013112187, 0.17413466615835205, 0.1997905332245864, 0.12180546240415424, 0.07657989583094604, 0.22563527687452734, 0.17580044630449265, 0.08826121862512082, 0.16156670695636421, 0.118243472679751, 0.13274553552037105, 0.15123860881431028, 0.11870546702994034, 0.10682832857128233, 0.152816103072837, 0.09416098095243797, 0.08780022617429495, 0.13446066848700866, 0.13768022385193035, 0.1253704132977873, 0.0944783678278327], [0.023804421980457846, 0.061062604654580355, 0.07928564009489492, 0.0032750905074863113, 0.024809826136333868, 0.03073207553825341, 0.0453774136985885, 0.01917078028782271, 0.039235358708538115, 0.014241945646062959, 0.03208376023394521, 0.026496186037547886, 0.09696125256596133, 0.013599541689472971, 0.06272854807320982, 0.0146759656672657, 0.04149559172219597, 0.04162194978562184, 0.044951740055694245, 0.018553287445683964, 0.021991175235598348, 0.04636321587895509, 0.05197270198550541, 0.03767518617678434, 0.01086586205929052, 0.05946563644101843, 0.05153273086762056, 0.09570838112267666, 0.005235614371486008, 0.05425156661658548, 0.027599954446486663, 0.07009926193859428, 0.006798413642172818, 0.019504364536260255, 0.0951169191102963, 0.041973059851443395, 0.01263112431843183, 0.08090152565273456, 0.054928987883613445, 0.034280702893738635, 0.008990349124360364, 0.04657717334339395, 0.02474001044902252, 0.03427416457270738, 0.02280638178490335, 0.025475059483142104, 0.06484716446720995, 0.03849521483061835, 0.04100685036974028, 0.02801405429636361, 0.05688714823918417, 0.03755795652978122, 0.012881107486464316, 0.01851458629971603, 0.101411392679438, 0.04317252634791657, 0.07403407696983777, 0.03689894423587248, 0.007143895909393905, 0.06161617631732952, 0.0797004635387566, 0.06728555745212361, 0.049533926794538274, 0.05811542861920316, 0.03922633048205171, 0.039328553903033026, 0.03088970584940398, 0.0349235103931278, 0.010978536774928216, 0.03152919038257096, 0.04308741685235873, 0.03307464241515845, 0.017092562702600844, 0.026589800545480102, 0.0023539282301499043, 0.03356286797497887, 0.051986491089337505, 0.014816119328315835, 0.05071020859759301, 0.045033391143078916, 0.031362593072117306, 0.051346592808840796, 0.021683367631339934, 0.024023696932999883, 0.020281274410081096, 0.10292820894392207, 0.0268737981969025, 0.018923875177279115, 0.007989943333086558, 0.05299688804370817, 0.041612650675233454, 0.07183327514212579, 0.053330850787460804, 0.02289387171913404, 0.03890525142196566, 0.05263079401629511, 0.02435296930343611, 0.045872990231146105, 0.032573329081060365, 0.062386952340602875, 0.0618382306129206, 0.06380607970640995, 0.03465460060397163, 0.052090851895627566, 0.024604358841315843, 0.049734169369912706, 0.0421543850825401, 0.05882705547264777, 0.031549911145702936, 0.05085041884740349, 0.010483839687367436, 0.01932757568283705, 0.011386542664695298, 0.016439235259895213, 0.021394148971012328, 0.01685980849288171, 0.01761243158398429, 0.011792632885772036, 0.037356389220803976, 0.01970556262676837, 0.019495310334605165, 0.06915249672601931, 0.00656028257253638, 0.07953440057463013, 0.05276066243823152, 0.10898532142164186, 0.050346801144769415, 0.050310320875723846, 0.011260929531999864, 0.012292656738281948, 0.019457770649751183, 0.012129244169045705, 0.026282239705324173, 0.03814420495473314, 0.010194627520832, 0.02815292311424855, 0.06869053206173703, 0.010925608657998964, 0.08456714145722799, 0.058138101230724715, 0.06748854968464002, 0.039556875635753386, 0.06405655454727821, 0.04101773025467992, 0.07573016642709263, 0.005789051056126482, 0.04391849237435963, 0.057877588842529804, 0.04232670064084232, 0.04161771954386495, 0.056985223054653034, 0.07573425566079095, 0.08509100865921937, 0.06247968369279988, 0.013530752021324588, 0.045641844626516104, 0.014760431349714054, 0.05383540359616745, 0.05870909109944478, 0.03133035417704377, 0.028221642278367653, 0.005475783564179437, 0.03735065613000188, 0.02559585886046989, 0.0052410162788874, 0.052346247175592, 0.060191527372808196, 0.01926787917909678, 0.022058695831219666, 0.014286224959505489, 0.032798437314340845, 0.011330367651680717, 0.08649653987959027, 0.022740228596376255, 0.038634924130747095, 0.03601291638915427, 0.055134759459178895, 0.050203811551909894, 0.057762960423133336, 0.01632997071283171, 0.017751292980392464, 0.04011313016235363, 0.008351463875442278, 0.02330751329282066, 0.02802803264785325, 0.03629457627539523, 0.06162712299556006, 0.03644374053692445, 0.06125398227595724, 0.05336322326911613, 0.13905597268603742, 0.02957455893920269, 0.04169616455328651, 0.07745153343421407, 0.03322949523862917, 0.034021786123048514, 0.02913650627306197, 0.03417092069867067, 0.01877495025837561, 0.09936959599144757, 0.05594986767391674, 0.013395440873864572, 0.022019439929863438, 0.030789250595262274, 0.03899324787198566, 0.060499477840494365, 0.01715072667138884, 0.019746479083551094, 0.030705753415531944, 0.016283846234728117, 0.08040125132538378, 0.027728887762350496, 0.017639577490626834, 0.04062258485646453, 0.020611728650692385, 0.02113855145580601, 0.033120399530162103, 0.021584565511147957, 0.06370267627062276, 0.01632970910577569, 0.05269835914077703, 0.021487169760803226, 0.016866322694113478, 0.017225015653821174, 0.05156310697202571, 0.01797559412807459, 0.0699822475144174, 0.03562028316082433, 0.10163267143070698, 0.058335416033514775, 0.04073564734426327, 0.030349641274369787, 0.07399872105452232, 0.03375860942469444, 0.021026934300607536, 0.05299958575051278, 0.022852062829770148, 0.022546836044057272, 0.027112658426631242, 0.1173282264790032, 0.04149768457864411, 0.053311354567995295, 0.05074158289062325, 0.06687654502457008, 0.05454424739582464, 0.04746530517877545, 0.039583314646733925, 0.010243435790471267, 0.02086494572722586, 0.03263920210883953, 0.04990701185306534, 0.059670276241376996, 0.020320528456068132, 0.046478931544697843, 0.0690522845252417, 0.06502625212306157, 0.01944448991707759, 0.029011317092226818, 0.03551895402779337, 0.09257277008146048, 0.015265547262970358, 0.08256018860265613, 0.021257159642118495, 0.046500346215907484, 0.04440946759132203, 0.03049653456400847, 0.02922732659499161, 0.03432916884776205, 0.041748159419512376, 0.035637367400340736, 0.04733275760372635, 0.04204434313578531, 0.007776020656820037, 0.017771557322703302, 0.07708584758802317, 0.01892222946480615, 0.020652275889005978, 0.005749679194195778, 0.05103723597130738, 0.020129766817262862, 0.024426479030807968, 0.04190882325929124, 0.05621284028165974, 0.024208437898778357, 0.04376610719191376, 0.043982843999401666, 0.029026189731666818, 0.021711903209507, 0.04249322744726669, 0.0464503031980712, 0.021098000506754033, 0.029071030294289812, 0.02685378618480172, 0.028141957882326096, 0.031201710298773833, 0.03225933382054791, 0.04181358715868555, 0.04712904177722521, 0.015413856199302245, 0.019262396563135553, 0.035029600403504446, 0.0822808887460269, 0.01622554311325075, 0.0630170431395527, 0.00814644650745322, 0.08497791277477518, 0.02661809678102145, 0.055697244315524586, 0.057117447795462795, 0.02522657174267806, 0.016871725529199466, 0.06986205669818446, 0.1002882634929847, 0.004749162080770475, 0.029329583412618376, 0.05602499528322369, 0.03341967058076989, 0.012486297910072608, 0.01796272899809992, 0.028774857710232027, 0.03096025626291521, 0.026658267379389144, 0.033420023100916296, 0.05422618516604416, 0.05711072022677399, 0.06696701282635331, 0.02362323404668132, 0.03919905284419656, 0.04482258409552742, 0.01827504329412477, 0.02134654019755544, 0.012184749393782113, 0.044300112131168135, 0.0016515023844476673, 0.061737205760437064, 0.024106368473439943, 0.07900162017904222, 0.0437535723176552, 0.010214092199021252, 0.04375351665657945, 0.013337034779397072, 0.03547956825059373, 0.04914608412946109, 0.029332770936889574, 0.03215248681954108, 0.016598303482169285, 0.016173841395357158, 0.040520097973058, 0.06850305071566254, 0.02692027705052169, 0.03395488150999881, 0.03921768075088039, 0.1412698585772887, 0.08830538383335806, 0.1492350030457601, 0.1616284388001077, 0.09346451988676563, 0.15567838854622096, 0.21208278456469998, 0.1257554691983387, 0.10401523264590651, 0.20678376109572127, 0.13762436981778592, 0.20889183157123625, 0.2936089981812984, 0.0979925855062902, 0.25112879171501845, 0.12488865555496886, 0.10275925902533345, 0.17103746125940233, 0.15454293228685856, 0.11560592436580919, 0.1543517253594473, 0.09561858867527917, 0.1627685854327865, 0.31055404047947377, 0.1064364226476755, 0.1021403078630101, 0.10345861446694471, 0.1684530358761549, 0.13082056771963835, 0.10611266814521514, 0.1531076038372703, 0.16552490706089884, 0.1023806152807083, 0.12822722172131762, 0.19247968099080026, 0.1371743017807603, 0.1856012039934285, 0.2108748204773292, 0.07027184838079847, 0.2218879951396957, 0.23605425842106342, 0.07544423177023418, 0.15741946699563414, 0.08138689765473828, 0.20494354655966163, 0.08602405898272991, 0.1349689209018834, 0.13588848640210927, 0.16546966158784926, 0.14167051442200318, 0.1898363884538412, 0.123568322887877, 0.15629546949639916, 0.1693059565150179, 0.21419927099486813, 0.14429437753278762, 0.172852220130153, 0.1453116987249814, 0.1300141797401011, 0.10636899853125215, 0.16694886580808088, 0.11815751713584177, 0.14463533501839265, 0.23733974725473672, 0.19973368471255526, 0.12753151764627546, 0.1488080751732923, 0.09986929144361056, 0.15027800254756585, 0.11691224528476596, 0.199423274025321, 0.15576486359350383, 0.09960237803170457, 0.17432446300517768, 0.13854697812348604, 0.18550062814028934, 0.14450453891186044, 0.08222904230933636, 0.11379313218640164, 0.22976859414484352, 0.07788983100908808, 0.08837559842504561, 0.13918216747697443, 0.27274508960545063, 0.08613077981863171, 0.19817066233372316, 0.08807134756352752, 0.18226444866741076, 0.06543772848090157, 0.13477137603331357, 0.11372711815056391, 0.1413640074315481, 0.2659851039061323, 0.11920713659492321, 0.11579914993490092, 0.09829642818658613, 0.0623538822401315, 0.09463183654588647, 0.16288079816149548, 0.1786935012205504, 0.1571184370550327, 0.16590518353041261, 0.17270147509407252, 0.14828116516582668, 0.10584766205283813, 0.11212845784029923, 0.16197571938391775, 0.1904079015366733, 0.10865643867873587, 0.24332169501576573, 0.10800815041875467, 0.12279315706109628, 0.0872121038264595, 0.11435631837230176, 0.0885469009517692, 0.10693267453461885, 0.06008243166434113, 0.11541764892172068, 0.15945385704981163, 0.05996931351546664, 0.08640011263196357, 0.1359997343388386, 0.11839329003123567, 0.23352023970801383, 0.15341405145591125, 0.18274688918609172, 0.14070251636439934, 0.13558085134718567, 0.08295812076539733, 0.1396352337906137, 0.160213875642512, 0.07389920647256076, 0.2157173489104025, 0.1278647271101363, 0.1562493821256794, 0.18957113003125414, 0.19425691687501967, 0.14464487903751433, 0.15555301011772826, 0.33454734832048416, 0.16111004864796996, 0.11854589043650776, 0.19257808977272362, 0.11531662777997553, 0.19712263107066974, 0.12684688641456887, 0.11787492214352824, 0.08984880609204993, 0.14134969882434234, 0.15773734368849546, 0.17001328262267634, 0.11485652590636164, 0.08945044348365627, 0.15203999471850693, 0.06267665710765868, 0.12054336606524885, 0.07550747759523802, 0.1753788915812038, 0.14825746096903458, 0.11498101375764236, 0.14187116146786138, 0.1341937031247653, 0.13198419590480626, 0.0892015865247231, 0.129487729864195, 0.11218197410926223, 0.09784927678992972, 0.15434994420502335, 0.1594938142807223, 0.0844515890639741, 0.10662351807695813, 0.07862811951781623, 0.18655781750567257, 0.10183486214373261, 0.15417846356285736, 0.1630805546301417], [0.03898277987900656, 0.04939375365211163, 0.03406451898626983, 0.0037356884604378138, 0.028097002286813222, 0.03398969565751031, 0.06898912775795907, 0.06245186799787916, 0.0248104384081671, 0.03233455790905282, 0.0835666447528638, 0.05762130669609178, 0.02617198995721992, 0.07606727958773263, 0.015865529130678624, 0.017105622646340635, 0.04291960613045376, 0.02216308261267841, 0.03858857700834051, 0.10417315425002016, 0.036568209834513254, 0.0161205607582815, 0.01751632160448935, 0.04825298732612282, 0.04395089083118364, 0.0277235313114943, 0.04572615631332155, 0.019669408902700525, 0.09924143450916745, 0.015821397319086827, 0.029373030592978466, 0.09187084680888802, 0.11403074560803361, 0.08374351338716224, 0.03052681975532323, 0.03510620488668792, 0.07174173122621141, 0.08841894727083854, 0.06013408514263574, 0.0779822283948306, 0.0594054668181343, 0.053330887894844636, 0.019301921493024565, 0.005719926029996714, 0.024110355661832727, 0.0277752311740187, 0.041018138435902074, 0.02405920127785066, 0.0643459772982169, 0.044976472127018496, 0.020597544353222474, 0.009742360871314304, 0.010054537870018976, 0.027778483636211604, 0.03282889876572881, 0.03775045850488823, 0.041037682894966565, 0.010510492993489606, 0.0320762608316727, 0.016066953576228116, 0.07473769976058975, 0.018611045088618994, 0.058919794246321544, 0.010504101246624487, 0.05586554114415776, 0.010482331272214651, 0.02861478758859448, 0.013192652731959242, 0.008285932235594373, 0.07638798386324197, 0.008684553667990258, 0.07638972048880532, 0.06624045767239295, 0.10986423949361779, 0.08068287410424091, 0.04569773947878275, 0.04059368933667429, 0.04227100987918675, 0.04057441205077339, 0.04987298809282947, 0.051259468382340856, 0.05237299788859673, 0.014925633422535611, 0.04501961317146197, 0.04750500636873767, 0.043561281854636036, 0.027578936824284028, 0.0424581461265916, 0.04610276286257431, 0.038644805827061646, 0.016004258795874193, 0.027973481082881335, 0.03518532896123361, 0.02614527449622983, 0.0478433514945209, 0.031776247633388266, 0.0719381777162198, 0.02529318877350306, 0.048707927562645636, 0.02819152592564933, 0.00989373951597372, 0.0320030479633715, 0.012982008029212011, 0.03996554296463728, 0.10953698205412365, 0.03589903382817283, 0.06402250481187366, 0.07028744090348482, 0.0113900168435066, 0.022783206368330866, 0.08746860490646213, 0.06172221066663042, 0.030664384248666465, 0.014316781034722226, 0.049623069862718694, 0.039643068666919135, 0.023098787969502155, 0.06156053379527293, 0.04611280783137772, 0.038118263182695955, 0.034641579622984864, 0.028694388493022416, 0.025616971106501296, 0.04807201461517252, 0.03357939931447618, 0.004581514631354366, 0.015693931600253563, 0.0977951668028254, 0.032409466584795155, 0.023591852332174312, 0.05116792817716487, 0.04333088952989783, 0.04191668260318693, 0.030769511322432663, 0.06903919304022565, 0.00920363772820565, 0.01163347931651515, 0.020699595224868972, 0.08660468563903123, 0.0030783228066866286, 0.02260888144519413, 0.07021021301625296, 0.041107845536316745, 0.041442721121711656, 0.020846904117206577, 0.02908320151618682, 0.03214455697161611, 0.0665372796356678, 0.022078871115809307, 0.037197298734099604, 0.08019097862415947, 0.018195718839706387, 0.04374321193608921, 0.060035052956664, 0.02872949764423538, 0.011139100424770731, 0.056409509415971115, 0.027171499605174176, 0.026646446822269354, 0.05182220927963499, 0.10974566655931994, 0.0548948045616271, 0.007195198259069002, 0.02686427644221112, 0.05017304953071289, 0.039529768691863865, 0.05231958180957008, 0.043133901272085495, 0.05712936668714974, 0.04218188907543663, 0.059716096438933164, 0.06660706378170289, 0.04868344411079306, 0.03129519864160102, 0.020959970315743703, 0.04939366830512881, 0.08021552144782618, 0.054777437617303804, 0.005323249024513643, 0.06752590939868242, 0.03177019541908521, 0.038632538125966676, 0.0503330825449666, 0.041725445989868604, 0.049648087660898454, 0.041819836042122915, 0.032409180857939646, 0.06932128337211907, 0.030963111676101107, 0.025285129049734678, 0.143801502417773, 0.03278074822446797, 0.02591865970316576, 0.03851162371574901, 0.06418140605092049, 0.07716962121776305, 0.07502856227802113, 0.12897875014459714, 0.03463564244157169, 0.041953251929953694, 0.05370894534280524, 0.09256974954041652, 0.06403215273167007, 0.035565906000556424, 0.04081893486727495, 0.05494887373060919, 0.03838444557914045, 0.05617195165541489, 0.02811142407153966, 0.07712511462159455, 0.03451223070442211, 0.011568944009923143, 0.028706483644782566, 0.06984893552726135, 0.05594961534370668, 0.017333907271677162, 0.03558392905688379, 0.09472114659729414, 0.04104529361939058, 0.03211401017324533, 0.036242403293726966, 0.03899131086654961, 0.02147871484339703, 0.03732500750629697, 0.0380286859581247, 0.06199460112839006, 0.0629240223497618, 0.022956876346142963, 0.022065659031795803, 0.04244006740918849, 0.0518212556198705, 0.03976249507104512, 0.039803201871109195, 0.03269914537668228, 0.013066922711004736, 0.0237048164854059, 0.03227151246392168, 0.06707394146360457, 0.039470931224059314, 0.032825406960910186, 0.020455770027183462, 0.03220864884497132, 0.01255408104043454, 0.030639342330687214, 0.03022235367097892, 0.03001804041559808, 0.03255925053963438, 0.026644873469194863, 0.03443870613409672, 0.02828227759891888, 0.05095067186630331, 0.11734732936020009, 0.02484616168658249, 0.0630554641247727, 0.0896872924931813, 0.050576614594319835, 0.06165241538838018, 0.05220290506258607, 0.07912788176327012, 0.04636775411199778, 0.036821883331867866, 0.03896062677085865, 0.014130093786661746, 0.034841547603718936, 0.05402697788667865, 0.03435793820244726, 0.024344254634343088, 0.028451182988646906, 0.03261896003095899, 0.07240641352836974, 0.05078761088952888, 0.027134939555253368, 0.07213807519292459, 0.035502663886290975, 0.08037437073653564, 0.045242157284519635, 0.0379306853574235, 0.016040881928347517, 0.03627014477388002, 0.038887907430762425, 0.030075176509853918, 0.10125750093720853, 0.04470593703445047, 0.007558441511719138, 0.04149799999140669, 0.029919937769591343, 0.04956957956892438, 0.07922754477476701, 0.015982684562914073, 0.03908324069925584, 0.017549684853293, 0.039123505921452306, 0.046511341133737005, 0.06576163883437403, 0.0027207398215978174, 0.018903146992670372, 0.03779761085752398, 0.06155330527690239, 0.05113040890137199, 0.05823583465826232, 0.0180384688792401, 0.022954833584662993, 0.02531837726564845, 0.12596389395184815, 0.08378417565836571, 0.059218174719717354, 0.04566837269521784, 0.03762152147828601, 0.038902379310457036, 0.0399065125384368, 0.04831322003155947, 0.09645352707593702, 0.012337393400230212, 0.02484749384166207, 0.10037547326646745, 0.017949631946976297, 0.04112118935154285, 0.03772613461478613, 0.027688769114320166, 0.018327219986531418, 0.0404971025272971, 0.01185245926535572, 0.013367512929107761, 0.023844887582527008, 0.02777276353299385, 0.09882909726002254, 0.06380121863912791, 0.023473756227758713, 0.07243673026096076, 0.042514553060755134, 0.005303166508383583, 0.016193471201404463, 0.04918148828437552, 0.03826379463134799, 0.044415649681468494, 0.05383542214985937, 0.06652007665252313, 0.05296664181514643, 0.023896717320894822, 0.023460770498786587, 0.04345712142821867, 0.05097527406178415, 0.03660513168142643, 0.08229706014390104, 0.033016728921211325, 0.05395015818066895, 0.06302165929810144, 0.01726175567455357, 0.012857625006290618, 0.06623705121455714, 0.02435156664432725, 0.03198118800355587, 0.19598157901782542, 0.1461329445010051, 0.0979232021200005, 0.1885236331145279, 0.12964956258656457, 0.16784417792223394, 0.12310057689319365, 0.16196816432056949, 0.0966176604561042, 0.2401380447554402, 0.14197187090758234, 0.22253428702242672, 0.10419282858492807, 0.17886455141706392, 0.2641766087617725, 0.10954610304906964, 0.20793478761333972, 0.19731164124095812, 0.15261245775036514, 0.32747292949352413, 0.15208799683023244, 0.13446016382658854, 0.07801215921062976, 0.1455446588806808, 0.13125236408086494, 0.22189316048752517, 0.13961461692815647, 0.20466984249651432, 0.14652200799901038, 0.1117689095553942, 0.12523887504357845, 0.20855109672993422, 0.2340233267750591, 0.21463271492393687, 0.09607084604795091, 0.15632334456313401, 0.11920934819499962, 0.1232198771322146, 0.16928372177062556, 0.1291957838111557, 0.19568124669604003, 0.28792156430426985, 0.13417178008239716, 0.08329808377311565, 0.16645455092657357, 0.14723065512953326, 0.07891786139225587, 0.19158316659741104, 0.196037047135178, 0.09490089476457797, 0.1412624222575687, 0.11576612436329015, 0.05767707167251501, 0.21548394346609712, 0.12624754279386252, 0.25551135186105967, 0.14954410755308345, 0.1267160606221296, 0.08360395251656882, 0.07171305463998578, 0.12435459866537713, 0.20853606081800535, 0.1363358530215919, 0.20332398737082258, 0.18355348496697843, 0.12965388188604265, 0.16132190212374553, 0.15478917688596994, 0.1332080567954108, 0.16480723541462794, 0.16246898041572422, 0.11019931174814701, 0.155796256440226, 0.20408630662132055, 0.15006451634690166, 0.13068184547591954, 0.17275857593631372, 0.17069760215235874, 0.17250210454221815, 0.13574543001595885, 0.1966604363406077, 0.17933363327756524, 0.11269348455243744, 0.12541427422547713, 0.0816192566708196, 0.15606244996888563, 0.05657108238665387, 0.18655682302778587, 0.1110523882380221, 0.14437933859881014, 0.11754159393603913, 0.1757822191575542, 0.15472443192265928, 0.1526309669134207, 0.12534283509012312, 0.14067939104279503, 0.2119856225908734, 0.12121524719987065, 0.21827207354363054, 0.18914161948487163, 0.08373921635211445, 0.1574728125706315, 0.12487888889154419, 0.19795716129010543, 0.18440033483784646, 0.16205685096792877, 0.12164212312200107, 0.13694149005459622, 0.1179620873881504, 0.1317222771467641, 0.15235071710776538, 0.11979447226622142, 0.23192870401544496, 0.09458031665417366, 0.13700715528102592, 0.1448866113787517, 0.1870226245955564, 0.08900899178115651, 0.09447637145058252, 0.17953147500520572, 0.10646688780980185, 0.11933923888136633, 0.15545574424322695, 0.11610117435338907, 0.05621156007691752, 0.10533935768762603, 0.0904016244749073, 0.2740907814586535, 0.1932296805898659, 0.08368718437850475, 0.1538688098662533, 0.14761964441277087, 0.09492225377471186, 0.11408308186219074, 0.18043978954665363, 0.19039513659663498, 0.12512373825302348, 0.08154498995281756, 0.21031535987276584, 0.10758120028185658, 0.13697362504899502, 0.17826915602199733, 0.1523898431332782, 0.10520306968828663, 0.1659735947032459, 0.09011212008772418, 0.08438986464170739, 0.1636992979911156, 0.14315865410026163, 0.19972405163571239, 0.1920147254713811, 0.13589329551905394, 0.2054341507027857, 0.13036024320172146, 0.11822390966699459, 0.06459426280343905, 0.10429818386910483, 0.13411271997028962, 0.08255835549789481, 0.15504837938351557, 0.22599789022933692, 0.1599170611007139, 0.06188714185555, 0.12038225322612561, 0.1241933299752418, 0.15790233795996755, 0.2174252682016231, 0.24247174296760932, 0.12029389312374406, 0.09211292053805664, 0.16843227058416232, 0.1588910716236569, 0.12093114564777352, 0.1587153458967805, 0.09117311667068861, 0.13239910098491237], [0.07972484308993444, 0.011118931633973261, 0.03775081473577302, 0.041113764164038, 0.051438533773762174, 0.03676042608276475, 0.02848256099241553, 0.044947194401174784, 0.04323165325331502, 0.019338347956363577, 0.04786443962075282, 0.02860829194105463, 0.07460433582309633, 0.037164948516874574, 0.15293753327568993, 0.07281242767930962, 0.018136547405447345, 0.07600088705657981, 0.03210590592061635, 0.0427847690298222, 0.04842572961933911, 0.047104476689128205, 0.04675713302276563, 0.03365620788827073, 0.04575514831230976, 0.03200278079020791, 0.022348862585204188, 0.020493033262027893, 0.01976484538317891, 0.0477962325385306, 0.034058637465932406, 0.05027378494560253, 0.012400695813994389, 0.05983787174045574, 0.019919234364351723, 0.01301879165112041, 0.03106325337284943, 0.02516965087124845, 0.031424733097082935, 0.052648390337708406, 0.05911778440349735, 0.0241869378805859, 0.049691306630847976, 0.056142492103390396, 0.04291867844585795, 0.014144761407806072, 0.043638673014356755, 0.01902717471239157, 0.054415436534327455, 0.02658033074112609, 0.032360959812649526, 0.022821840721007902, 0.058728286749101244, 0.04354665783466771, 0.03340163268148899, 0.010776999151858035, 0.06781926553230733, 0.017361511454510037, 0.09188865835312754, 0.07752974837785587, 0.08458323864033446, 0.033463260624557734, 0.045812649914296344, 0.05142058493220247, 0.05000771016057115, 0.033083232774515636, 0.04152683985012118, 0.0556211964430986, 0.017172115367429797, 0.04046613641548902, 0.02738355346082244, 0.06838606597739272, 0.039878826719359495, 0.05066857411293313, 0.026877891141339205, 0.06756657166988589, 0.011998128939012531, 0.033911803548107855, 0.042145816987613216, 0.017914413328981027, 0.0038670036065013846, 0.014669710290036164, 0.018669871424208395, 0.015876021243457217, 0.027697606237779837, 0.03892640634148847, 0.03599298230255954, 0.03745013731531799, 0.039539995486848056, 0.052547161394613795, 0.08914084915886633, 0.047826864683884196, 0.0424308573565213, 0.028204157279105857, 0.07877726893639192, 0.034252382538397796, 0.01180570303404238, 0.03353651802171953, 0.03207045723684132, 0.03562202720786445, 0.009639217187213944, 0.0383248993603047, 0.0651847080735024, 0.052057180655538104, 0.07673331259866245, 0.0703194719972089, 0.03923978190869093, 0.062424215575447306, 0.04446882085176185, 0.04307559443986975, 0.05623839242616668, 0.04718570846307557, 0.08637798178824596, 0.0631208844424691, 0.016774546857050154, 0.015938506367092486, 0.020735943762701936, 0.02393063718045596, 0.11166188443894498, 0.003052432753065659, 0.04325521644204855, 0.05699484499928076, 0.020813908231502865, 0.03141846937069204, 0.024041695869527757, 0.04130233275645878, 0.028368246130412444, 0.03838860531686805, 0.028855074597231578, 0.06212710417457856, 0.01344046233498375, 0.011095231147919549, 0.04466047677851748, 0.042133237584494054, 0.03187619266100228, 0.05968662204395514, 0.05791774645331316, 0.03125395749520976, 0.056855584698496386, 0.01412232906659483, 0.034131026550312527, 0.020036493697261903, 0.038870452117407694, 0.05925266603298951, 0.038164625148056075, 0.04574213475279976, 0.006551442666022922, 0.14419300016015768, 0.007039698375592707, 0.09256230579921976, 0.05837980017531663, 0.023296043400478084, 0.04473402732401155, 0.09220216379617341, 0.04244520307111088, 0.015485875137528637, 0.029938498882984277, 0.057658380683278665, 0.07644791970960796, 0.04339488492405508, 0.04229918551573064, 0.014047969580133213, 0.019566311602829956, 0.04650863600545563, 0.03087551041971892, 0.04019586107460782, 0.020126599702052772, 0.06430157460272312, 0.03205931388947647, 0.018292318636667915, 0.032036689517553896, 0.042650874456739984, 0.028748255426762626, 0.07386392477201298, 0.014847894381091464, 0.04045117100758944, 0.06076729667256586, 0.018388679091003723, 0.029697428908548318, 0.023459022741008084, 0.09247243913705461, 0.05834988049173262, 0.0163303046792862, 0.04489223094424233, 0.0777381360239815, 0.08436188567429781, 0.015606337765348144, 0.012480922905524494, 0.03014440033439314, 0.012991230141778942, 0.08750587556278333, 0.0920674714143388, 0.037348871264839545, 0.014848762693873141, 0.02922173822298646, 0.09261536193662323, 0.14483905455563217, 0.05819015175802633, 0.027767171450250316, 0.03314887573651504, 0.02168654402339598, 0.006132034141046461, 0.03223161831556354, 0.006717431879224023, 0.02809819528920343, 0.03866266932163853, 0.006714585742884083, 0.005766218882854446, 0.020212280651321635, 0.018481688748579472, 0.012249732772033894, 0.04027789436804596, 0.021018199222453404, 0.06354735218337737, 0.014029555968591012, 0.011359509935573442, 0.027688483387464657, 0.042239928734488785, 0.0338209646724863, 0.04914050688967109, 0.026507763541303575, 0.04053222837683279, 0.010124089167220518, 0.018303534343431238, 0.0193034187759622, 0.009842144481808646, 0.025318462612631265, 0.04358100442914292, 0.06086877423513215, 0.08569720972445793, 0.054261247933027335, 0.02262092093587853, 0.04663362851715647, 0.09428823701455258, 0.03526281660015229, 0.058740992317325436, 0.014578337995772017, 0.013305475877132267, 0.04992331683752127, 0.043907126382691786, 0.08114044525427744, 0.01332038747932529, 0.037249204542604275, 0.02300683772773482, 0.03593095359974541, 0.0007130939866328845, 0.02631991112139076, 0.01425955124432221, 0.041921888769138604, 0.03626159894338343, 0.04193652763206046, 0.02347295099752955, 0.05950958642642945, 0.06668654779787175, 0.06101925209804904, 0.014476526466751238, 0.09940510775777511, 0.04562940252071712, 0.018243515005451627, 0.03100543635810027, 0.003352786179675604, 0.01702710156678222, 0.056094029860105366, 0.025027945193869527, 0.03842633610474877, 0.03635948080045637, 0.032285472261719406, 0.01734002071316354, 0.035364668947295286, 0.06532397950650193, 0.033433596981922165, 0.03278789510659408, 0.06433280417695642, 0.06481244679889642, 0.025233277046936564, 0.03182362634106539, 0.030846709523757454, 0.03707359384861775, 0.018524119186622556, 0.0198535079107387, 0.020223180945322383, 0.031431664756382816, 0.05640592113195453, 0.04905189074634109, 0.045956363101140596, 0.030151695646054577, 0.008759402971918462, 0.0828538193309214, 0.013961278382339515, 0.07540961800259538, 0.0255548236600589, 0.04028352355817333, 0.010696388926589862, 0.020838994678342715, 0.03065984601562377, 0.0467141812259797, 0.07146735180867836, 0.01421685456080013, 0.005230273691267939, 0.041419514163862914, 0.026850338908843696, 0.019829540251521394, 0.02306018886883976, 0.046491807806887664, 0.06645006244070828, 0.04555550687655341, 0.06771524611394852, 0.030782036919845268, 0.027026947791455314, 0.057697146767168306, 0.05936247791396454, 0.05122663205838762, 0.022586177292396314, 0.03183981629263144, 0.036496522079687566, 0.02737468108534813, 0.02318019043741515, 0.035078908695140854, 0.019827820324280765, 0.021401410886028316, 0.020495584394666366, 0.023306429757212754, 0.09511438838671893, 0.03967673619627021, 0.023167206563812215, 0.007577341229989543, 0.05486890731845051, 0.019531920479494147, 0.027425777952885255, 0.042985712934751064, 0.04974700481398031, 0.009722733848320786, 0.05648072961776052, 0.0185841978964163, 0.04258331304299645, 0.021211511993897147, 0.007170172111727879, 0.030695762252435088, 0.044158640230307356, 0.046998520265333354, 0.034043991181533784, 0.02473298602126306, 0.02207735898991814, 0.059787119971588254, 0.03659923160739709, 0.05790043214801699, 0.06347534159431234, 0.05855387091287412, 0.04973010240064468, 0.013229579217295395, 0.06787796941353008, 0.010894431961787632, 0.230846177728381, 0.12856727378675714, 0.09176673833280802, 0.09072705623111688, 0.18645531206857413, 0.11570657443371601, 0.1847961964085698, 0.1675941186840646, 0.16571342741372064, 0.11611779103986919, 0.15205051837256178, 0.15070550929522142, 0.20234751398675144, 0.10519476505578496, 0.26715790503658354, 0.1870414603035897, 0.1268167997477576, 0.20641832757974043, 0.09913237590808421, 0.25661830964963883, 0.23773026536218822, 0.0942713457334321, 0.17019346123561263, 0.11417173882364295, 0.1315978041384369, 0.0969712641381193, 0.11359647789504379, 0.13408478553174064, 0.1514702182612382, 0.20666387456003577, 0.13885483582271263, 0.08660241466714069, 0.06635200988966972, 0.15889046306256205, 0.07991336344275624, 0.12140250590164214, 0.07862527709221467, 0.15022948093246669, 0.09165564624709077, 0.16384496673708782, 0.25067810027394444, 0.085370263986988, 0.12428585352608934, 0.10396407640655525, 0.21343129657907411, 0.08968442038167268, 0.08932927303249016, 0.12972855678526685, 0.11944160331040621, 0.12858881091233343, 0.13054717535851523, 0.16088655829662457, 0.22835455049062148, 0.18657407053979114, 0.26021063094958663, 0.10018802160630003, 0.11705622935551219, 0.14958413899876177, 0.21471761661814526, 0.16114491474581882, 0.1510012403014116, 0.11117726200609468, 0.1795582813792862, 0.10147254564799368, 0.192707164096646, 0.12284988682949916, 0.12751956906868145, 0.12094080841052346, 0.09191178367473185, 0.11155172745930031, 0.0962210344732739, 0.12119578808778897, 0.18929185986053199, 0.19757350062718615, 0.08393918804358691, 0.24629429331980646, 0.13911068381275982, 0.14505748345982283, 0.13406424288405105, 0.11787845476646908, 0.2028060721931979, 0.13770176097750664, 0.07025968458037823, 0.06113964700489305, 0.13599819067167118, 0.14390898024430498, 0.12972710217582062, 0.1268276499467902, 0.14098708546953276, 0.1378617383306846, 0.12541215168312192, 0.11724853466148488, 0.11869993802974932, 0.13716999732423574, 0.18711031676502898, 0.09696293724118732, 0.1055649334739428, 0.09688807680504397, 0.12695081677520648, 0.09799098246730864, 0.2430614089826122, 0.09116241490119137, 0.09607444546418265, 0.11956433969317004, 0.18478605867130682, 0.1291168638272211, 0.09969120568712242, 0.15870123024797067, 0.18340401642490178, 0.08865797077305615, 0.16697096696589142, 0.16604717122390866, 0.17756537738023326, 0.16459459526231512, 0.09753266916959547, 0.11317374315694906, 0.10314749131794088, 0.11195555227459408, 0.16571813262999058, 0.29436726530548185, 0.17153502674773335, 0.13866597408195958, 0.10462294027092867, 0.09812423508265056, 0.11320759993395768, 0.12257497306563891, 0.07228087182738818, 0.15689923631725833, 0.15838235907722265, 0.15189245576038957, 0.10068598043289967, 0.09685184515547007, 0.12741937913233414, 0.12669394462136552, 0.11395531371817924, 0.17477600049460307, 0.13919508084654808, 0.14670297328848392, 0.10343966001528315, 0.08012368809431791, 0.18585086247185245, 0.11058718038839288, 0.10512982713407837, 0.13425821060081944, 0.10392278330982663, 0.16015906061511487, 0.1794803113443777, 0.22809012327343225, 0.1208552387834061, 0.15227387513732538, 0.14051675680093467, 0.08448805820080452, 0.2119465114083141, 0.18161808256991208, 0.08942381522501819, 0.08944734130636789, 0.115015219344059, 0.10572433195193298, 0.2317735506221652, 0.1978070693439804, 0.12079966676537879, 0.08374771394301206, 0.16534256137674674, 0.21794901665998623, 0.07568505126982927, 0.139614409126807, 0.07817977326340042, 0.1811725861625746, 0.13560399151174352, 0.12625209958059713, 0.13756489410297945, 0.09941954995156266, 0.13715769251575693, 0.20274673006497324, 0.23293372039915994, 0.1607902126852423], [0.06115008902270347, 0.03395467370864935, 0.025510107407171745, 0.03348988146171905, 0.0931531518290285, 0.06304006456048228, 0.09067984079592861, 0.07662232441361994, 0.03655005319160409, 0.029737933473370504, 0.01385847237543203, 0.004503074260355788, 0.05421457426564302, 0.0675956935447175, 0.041126172873191535, 0.058401470887474716, 0.07174541227868758, 0.04976894269930199, 0.09006479333038442, 0.011368312734703068, 0.03265769642894156, 0.048819847143022344, 0.026364709010522347, 0.019530239515006542, 0.04708269836555701, 0.017087684936996084, 0.039478597609559074, 0.010094029403262539, 0.021224720367172267, 0.04734391208330635, 0.02617248348542489, 0.05303206584358122, 0.052108284944552, 0.06568892320501618, 0.01339725635261857, 0.029092984877934214, 0.012882665996585274, 0.02216530905570835, 0.011886608263012022, 0.04896177546470426, 0.040166316175600514, 0.009432653369003674, 0.011050339562643785, 0.020440624648472294, 0.04565280985843856, 0.023451315537386108, 0.08778257048106752, 0.02112420574121643, 0.05224349682976026, 0.033597656147321686, 0.09639916475862265, 0.01615623950783629, 0.015161628034547903, 0.052690826341859065, 0.04132114991080016, 0.02927500958321616, 0.03885471116518602, 0.008403089523199014, 0.024605715116194915, 0.014110664360487135, 0.025182105964631774, 0.028168801363790408, 0.022988358250586316, 0.034453894186299294, 0.051967347390018404, 0.07829686190234497, 0.005968742170807673, 0.02300312142324401, 0.007917082057247171, 0.062094000677461736, 0.005780944020443712, 0.03152644814690575, 0.07370016246568412, 0.0280541599568096, 0.060087879028287716, 0.06554861276526935, 0.041823576466413215, 0.03631783889431972, 0.034271993790753186, 0.05420494118880015, 0.04540494737739209, 0.0468742179509718, 0.021152205117687117, 0.027822253650811035, 0.01692242905846797, 0.04483272183279041, 0.05329867868567817, 0.04166707607510034, 0.010778061350720236, 0.03779901351663284, 0.03836159856291488, 0.029163846993469633, 0.024529528091079555, 0.05568027881963644, 0.020666918462666217, 0.008724281760805752, 0.033657525200396776, 0.004605672465913813, 0.05421260757429991, 0.022860276549181435, 0.061899450374767184, 0.015953644324326888, 0.06667576439213008, 0.037930622274870984, 0.015850658346607815, 0.06275225969147868, 0.03089400845055934, 0.029326815201784484, 0.04379241632705089, 0.07024162070592865, 0.01856875194789609, 0.1102777493360918, 0.049032884344342165, 0.03514409523631912, 0.04840636327571701, 0.02031984753557481, 0.03709380624059122, 0.018364052775723394, 0.02486011591827264, 0.06538796005770564, 0.024755875710980035, 0.04287111049052328, 0.024451431891066022, 0.022230914910323918, 0.03741402812011074, 0.022706100935465656, 0.011785058341047261, 0.07394837375613861, 0.023627690643479582, 0.04110943373234477, 0.010344180482206866, 0.0645575116504915, 0.04563510592561215, 0.01098702137824148, 0.03908479178790003, 0.02873190776881529, 0.06434268216253258, 0.03638610905909445, 0.04064296794240363, 0.03620583767769858, 0.019420123353484087, 0.03765526693314314, 0.04273599508451298, 0.024355902642128058, 0.06349251489154994, 0.032240854343399405, 0.05732150500989519, 0.0865676450484898, 0.007752140199954738, 0.035854119050782174, 0.02369017205637647, 0.022156548002385534, 0.14457774435868487, 0.05410826161096338, 0.07849778354284354, 0.05193056284042541, 0.02129612610588083, 0.06694248484564014, 0.006643426768278005, 0.041472440425422974, 0.019698857322509866, 0.020711191282316577, 0.04956232136464678, 0.05516654935490806, 0.02424457863526186, 0.05567580366914626, 0.0728528450417798, 0.023009069736872334, 0.046445583138847724, 0.03363448522577528, 0.04940882296068594, 0.06578457861905918, 0.05508660520717967, 0.04703559425252024, 0.06388527428498492, 0.10027389551396482, 0.036004418798256665, 0.06726539329974912, 0.043262051622150466, 0.017278081068070605, 0.05442813468107488, 0.0023864704780862667, 0.06823333198553883, 0.021327504109649453, 0.09188630574499257, 0.06271867008763365, 0.0011523655143719225, 0.036548576317727566, 0.03344475888297893, 0.06009656957758125, 0.03394907420442905, 0.012703792635875288, 0.023195847898023203, 0.035301185635034926, 0.02637875786604127, 0.025431070534978062, 0.021867030627618078, 0.0569002211705083, 0.07143386610550806, 0.03250999790907372, 0.03580497403163463, 0.0338036355242366, 0.09426168297068216, 0.05682026589056477, 0.04399623976496514, 0.07252624811371788, 0.026996529013558757, 0.014500418055831688, 0.08864976261975244, 0.053568033763440326, 0.06724394523189403, 0.021601536573143676, 0.049043189064832404, 0.07335283735301346, 0.023434995709976647, 0.06933615601155907, 0.03207790468877647, 0.0584051704936428, 0.043612508598016575, 0.021811623737448826, 0.031124482411541976, 0.031457391305593774, 0.027544952026801184, 0.02939511505246628, 0.024400552101724315, 0.0299862764950376, 0.03284526312199887, 0.04009744858194608, 0.04266578420356382, 0.05847215674293693, 0.039802237079129554, 0.06111556060204748, 0.08963068146840669, 0.026066896280099172, 0.10730961876106448, 0.051179572474211454, 0.06321452863630839, 0.014429050352191553, 0.061185934755485505, 0.022691376725560986, 0.020917003676004242, 0.08037585503188893, 0.024527361019863747, 0.016925432901189197, 0.012733192816085648, 0.09620386859751306, 0.02939321886515245, 0.0768183775653597, 0.09764979491592385, 0.062161614041542634, 0.04337036436481867, 0.009354065496154362, 0.025626045717217494, 0.06664593747700565, 0.05146626783243846, 0.05912712062126957, 0.05879577023733873, 0.061234293098095804, 0.03276970877777785, 0.017475735403422732, 0.02541995872888947, 0.05829259782331064, 0.05726722061808687, 0.031550987259834073, 0.060256398501223885, 0.017810095196182374, 0.021384070605563466, 0.018114292251993902, 0.06556450214702636, 0.050916926411446184, 0.05837225624418352, 0.01410928211043938, 0.07661804222152568, 0.028022835758747533, 0.012542526728793746, 0.03288729094492737, 0.0398562283226056, 0.036739909410243854, 0.046991922572487965, 0.03437438790570013, 0.052743808264494874, 0.018224005798401777, 0.04597375533194281, 0.0051826185335812625, 0.03262065954913851, 0.04732118009997066, 0.079417616216233, 0.029321445763343945, 0.023398639750666916, 0.013270082854432985, 0.013347577914828435, 0.024030020031204913, 0.04854361235629767, 0.024215928024204914, 0.0291604461017414, 0.00823967509859358, 0.005790555760540883, 0.034314856529817916, 0.02316362199053401, 0.05100981732539367, 0.03996277475380339, 0.01351470586087089, 0.004150125523665338, 0.05082770170702133, 0.01968907396076247, 0.01673948223469779, 0.0044385704950400395, 0.057863680995069444, 0.0867221230873838, 0.05583735437539872, 0.04161918899626471, 0.03388186531083193, 0.0542953830154147, 0.06940122751984745, 0.02825888881488936, 0.0850489734148141, 0.011878461336891633, 0.042118364945054054, 0.00751652779399592, 0.10042834386695176, 0.10679521394195035, 0.006680719225187204, 0.011403501666791271, 0.04790457496710587, 0.04594072976033203, 0.02579082105512498, 0.06797735040890984, 0.045106674515409395, 0.0628495923592709, 0.0737352660507895, 0.046265081691672094, 0.06039018917363137, 0.027321856869093608, 0.03724507820152212, 0.005492216105267289, 0.028222978144185618, 0.03627193706051912, 0.03688041280838661, 0.030576055687561166, 0.05859409531694837, 0.08847785895341076, 0.032496004714630544, 0.026943804987240583, 0.01136932576628169, 0.03098669898463413, 0.09814357545110397, 0.05316512178978883, 0.05842975413543172, 0.02955533731437754, 0.053893291114945896, 0.0601182699756464, 0.07404507559840567, 0.14180188940372318, 0.15767798671731725, 0.12068838914274238, 0.1600884081562981, 0.18073396204272285, 0.18439748499076813, 0.19420616881689057, 0.17284105822909623, 0.18591220839880407, 0.1268343738047406, 0.1459924114169553, 0.14253918343456462, 0.1564686867641285, 0.12512894812971354, 0.11498732943437062, 0.14073126716539264, 0.0878467588336207, 0.15609568334184587, 0.1777959626633674, 0.14850023231701925, 0.08546325509087183, 0.18242691963678226, 0.11447462413343601, 0.1444291218649596, 0.13077001261990517, 0.134393667394761, 0.23388133908156306, 0.1626415000646375, 0.16410822136094794, 0.18425923772156239, 0.12767558335326612, 0.11481780806207098, 0.10608630705974065, 0.16219241166254506, 0.19423478603130206, 0.12342680274741724, 0.1420960173709318, 0.17264573980355635, 0.10464047722052783, 0.12067944626323879, 0.19064242020249367, 0.056897044778452255, 0.0920313733513467, 0.11517815786646679, 0.17570757394423708, 0.11919547003344633, 0.12277606540010311, 0.08447911532130092, 0.12036310581606813, 0.14963332854676992, 0.23381852370221168, 0.14130904397461563, 0.12266955978702754, 0.27740568795707077, 0.2648507460253313, 0.14559309143805876, 0.18327764351852238, 0.08918787905713543, 0.1334100990789011, 0.12785788450855762, 0.18611672945553437, 0.09870060181128792, 0.12048259901348501, 0.11482486588647589, 0.1659182898583822, 0.259668180369772, 0.09539975901134312, 0.1434329221956432, 0.08435888739768416, 0.19365190324606374, 0.15721647476311773, 0.1279105176217854, 0.14297267189249396, 0.18277958821272478, 0.13195033912779763, 0.1600501875509508, 0.10636792983859777, 0.2011575989308767, 0.14772212016396224, 0.1351448247442022, 0.14776137977605686, 0.14791117486311123, 0.07532536197686568, 0.12475049734348431, 0.15474831423489377, 0.15348188375355676, 0.19408641586778685, 0.12530151230748743, 0.13945553015219048, 0.10010930200223811, 0.1738488650880754, 0.10868568671867251, 0.11194743317901157, 0.177128326613456, 0.11369130210368894, 0.130845429666806, 0.1760108006419614, 0.11729100035154261, 0.15276867983629927, 0.12908588658319786, 0.2385850265272893, 0.13730206992477179, 0.24467984010698274, 0.09091488638659939, 0.140931305650156, 0.15152188658248633, 0.1947543042479083, 0.10851244718651287, 0.11661157157504931, 0.13410494226263836, 0.13297628407599404, 0.18969444528920576, 0.11442338625784032, 0.11593160103075206, 0.09724033719976433, 0.09871091024251655, 0.13289858121424913, 0.1046178639808204, 0.184980605263263, 0.14239493961213157, 0.08181317243725061, 0.12843983218772337, 0.11522977423737757, 0.11111426108982414, 0.1274832632043399, 0.09928884290275164, 0.07890036155004054, 0.22325837082462385, 0.09396232286235318, 0.2085781257483177, 0.09898194257402793, 0.19596635014750063, 0.14429353148443624, 0.1548055189778097, 0.1924084496567957, 0.16479470796184614, 0.11672025168081746, 0.1561488359584473, 0.10449776222230867, 0.16791462257970124, 0.11181891546584666, 0.14855715504381806, 0.08614971942733973, 0.1343026800896041, 0.22114906838396564, 0.13261905871331692, 0.1094487778027542, 0.15767871402204037, 0.10302752314601094, 0.049650384607957676, 0.08805625227978453, 0.11504145426442847, 0.21923364460235462, 0.11580944352317601, 0.1271233512670733, 0.11343583260895684, 0.14515474933432415, 0.08841790084261447, 0.11774629310821183, 0.13238480722066015, 0.08348407340236008, 0.10537108450080268, 0.11668306266074069, 0.20894563727779314, 0.27768966334406286, 0.12111951757105999, 0.13075726252282038, 0.09315882183727808, 0.10346265917178243, 0.18893944361479953, 0.172713854117319, 0.1398604310816154, 0.10019149485742673, 0.16166087065357715, 0.15513657621340826, 0.17582173109985888], [0.020454339537536725, 0.03411983867408708, 0.09378632254083641, 0.026791009768203367, 0.10553989341133274, 0.06064361034077592, 0.07045740756439045, 0.054931592821958475, 0.03501705810776912, 0.018243628182972316, 0.01841046669142088, 0.0777963204018306, 0.008119344201986678, 0.07351312640821561, 0.023887366260169074, 0.08044086716836318, 0.010999183323292527, 0.03241278027417138, 0.023271270511031616, 0.04281366826035082, 0.13977655355120078, 0.024171909390133806, 0.08213990295189433, 0.01881523960037157, 0.018350148639001418, 0.03151092983898707, 0.0027435362790129147, 0.00370923275113455, 0.01787698125554016, 0.03480448845948558, 0.023847880293033086, 0.025276818851125427, 0.032245385154965334, 0.05044259385613259, 0.024176926308427937, 0.03224219391995575, 0.02589423005701974, 0.01626095654501114, 0.02552417296101339, 0.017838853418652434, 0.05326187929313164, 0.053525412222370505, 0.07071447267662734, 0.06393070856574923, 0.09763732683495618, 0.05197505459364038, 0.03924381919205189, 0.040772832653601654, 0.07233291864395142, 0.025872802398225758, 0.032938443473540246, 0.029026045012869872, 0.03748766772332601, 0.049013903917511925, 0.05594519214355387, 0.027415957483754028, 0.012534581110230647, 0.027061196051363368, 0.025964251690311357, 0.009571615883032791, 0.05850371657288633, 0.04149083455558866, 0.040105311636580154, 0.016243480822595302, 0.04337864673289005, 0.029293067891558167, 0.059520470022107475, 0.029152692513889633, 0.042991245645680465, 0.01657918019191129, 0.12392925898893736, 0.028591233676706906, 0.08747678337385878, 0.084322537004482, 0.04113930888706818, 0.04839818851905875, 0.03281996330770198, 0.010038110431196401, 0.05971171776764095, 0.06646935085882433, 0.04642356732802, 0.025505559897283092, 0.09337372554000467, 0.07259335310664028, 0.03498808837321121, 0.05004057245969307, 0.040869564181775786, 0.07776653801556677, 0.012206113042338984, 0.024908971499826293, 0.059398023076937534, 0.0400154895032756, 0.016783671562734526, 0.0698530841327738, 0.05808858884847723, 0.01530242087028455, 0.03221166567527689, 0.08627629271359183, 0.019919072947232053, 0.01583700839546509, 0.01655877669691108, 0.09058258234290406, 0.03823290273430757, 0.07746895164018497, 0.025994232601078693, 0.015650506684323773, 0.035777599914581515, 0.04561824804113712, 0.015347304106398951, 0.041133965423796326, 0.05432189253042452, 0.034535808736109175, 0.1298035730724223, 0.036978446805733256, 0.053318319623940624, 0.03920939096133225, 0.034579762432258576, 0.04016534025140572, 0.01056564940881799, 0.044073089156881906, 0.04779086681082845, 0.01840735894802492, 0.018523909529903904, 0.044913801466464065, 0.06724720326019451, 0.019215622705814894, 0.015779291570652276, 0.016171186362043954, 0.03616893067373894, 0.052676206032629125, 0.04471621577977203, 0.012207696599944029, 0.05786589259514585, 0.048939633488771506, 0.06738336509442888, 0.03516964367008768, 0.015641343015886378, 0.033251592685701326, 0.03414401042391546, 0.031647763316868804, 0.05960024718660861, 0.029186016799940262, 0.046148616456775926, 0.02646839631779585, 0.053578590814140625, 0.03833506678347476, 0.07570073285023682, 0.04616450212779455, 0.030244909394241404, 0.028660212592512835, 0.04330102550738957, 0.036036264355061576, 0.03833744536677841, 0.029729560192208737, 0.046625216273241676, 0.03755943711439613, 0.03470378273050301, 0.008426879066973925, 0.05139644657901954, 0.0527218035858823, 0.0815606270043645, 0.02787094039376825, 0.004851951853197534, 0.04994194103346672, 0.10700371291022748, 0.09548685746267438, 0.04620806248567533, 0.04795859589648899, 0.03419684762775432, 0.05078773705463391, 0.07939786024508066, 0.0884195335675031, 0.0076429967157309875, 0.030541189589712303, 0.07678247246076353, 0.039545606123283505, 0.027276238906779326, 0.052903919204254635, 0.01325029812505818, 0.013460450227285037, 0.04201654599455651, 0.027809468301711604, 0.028469302524172235, 0.007616853636136511, 0.023314396712521557, 0.030562181236746255, 0.059121528538526036, 0.061307383512030356, 0.0239012815291062, 0.05852225542184897, 0.05221071987762116, 0.029586103046312928, 0.03556832540198229, 0.08457477073534392, 0.020244998231646605, 0.09306888096034527, 0.0698752149764914, 0.06507871454232372, 0.03819765814114362, 0.005829640967931482, 0.0350306728068972, 0.01682299425738165, 0.02664297728188103, 0.01658706180023728, 0.07060891701257788, 0.016753295458329376, 0.03479544539004564, 0.022950657148612663, 0.04508831007115077, 0.026548229143372737, 0.02615902278193971, 0.038987793086562306, 0.027805200952570885, 0.030398982962651644, 0.09060428274096921, 0.08356091537280008, 0.039774499309714884, 0.025599569598853122, 0.014247606377466582, 0.0218656094148173, 0.05865628729225136, 0.03539058845490217, 0.033569491642992944, 0.04969059787981678, 0.023504870769102126, 0.05004971942980774, 0.03387328608368989, 0.025215777204721235, 0.023194096429506317, 0.0706142233684659, 0.0433371161489049, 0.04523347786744125, 0.023953539857757278, 0.03023717064934317, 0.019206950710213277, 0.023640733888896648, 0.03587181185139343, 0.09628693718696013, 0.01115224478780874, 0.04247783901519142, 0.07883121565100737, 0.08300701345433481, 0.036925431486452, 0.06363725595292635, 0.017639247234910727, 0.010870077458093874, 0.057374713287572376, 0.04489542217925191, 0.058126119256485254, 0.021545211275224574, 0.05032859255152289, 0.07491902128094807, 0.08121868246234953, 0.006141207550172112, 0.03266367442847695, 0.11251559175434522, 0.038731859749532305, 0.08364953522686847, 0.062029081309447065, 0.022650220926152542, 0.04174320558377076, 0.053880058621871285, 0.0452415004838258, 0.09201175096677616, 0.051686570659512654, 0.015389685377158457, 0.02648262514412636, 0.04378541045298334, 0.026650430299923755, 0.01389136250509182, 0.03219126032490749, 0.011191817957296735, 0.037294052526704036, 0.04332006530603394, 0.06336450926028192, 0.033013422653311864, 0.039775879704393446, 0.0417068997194292, 0.01539550752568175, 0.08216421570978127, 0.06918570783454925, 0.027426635133451782, 0.07005456238402985, 0.030621130026702303, 0.04334921315603424, 0.04240205089445226, 0.020039156152051874, 0.028457457847252954, 0.09905413127853535, 0.06572502868948504, 0.0207354428130202, 0.04687369102612138, 0.08958357735536993, 0.030418941169045866, 0.04795079592440743, 0.015247258888848592, 0.007588777725686668, 0.09194656813633628, 0.04028322669910267, 0.02254671730042901, 0.023776296438882127, 0.03743959139683284, 0.019231929545640014, 0.07354132059845142, 0.054451619944302365, 0.0441283531836234, 0.03746977083210368, 0.008006069274415495, 0.026274667943653185, 0.08525077821104787, 0.042323401794419624, 0.09574200783390552, 0.0313274041400291, 0.05112945153086912, 0.029349248470680322, 0.020888366052531637, 0.03443804191192612, 0.03350652041262947, 0.03724431378941517, 0.03739655054232571, 0.055299185987678356, 0.07000624857028015, 0.05601137687335722, 0.020028005383210257, 0.04098191791854333, 0.004526620750766597, 0.033689081319607794, 0.05491172181791626, 0.025890174219966866, 0.03655647276900709, 0.015448583144461736, 0.04839776549488306, 0.0526460674154805, 0.05472333876241464, 0.09005603598779999, 0.009744672661327058, 0.02494215663318755, 0.12476522155338898, 0.05774307457613759, 0.014062182635825593, 0.03447430695814546, 0.11908819258678705, 0.01674774790444644, 0.04207737983961124, 0.07899707823526114, 0.0635698541009333, 0.07100817761966027, 0.06286390838795342, 0.03950548933062237, 0.006445427334256237, 0.01633958709135186, 0.05824905601912178, 0.15134550776565447, 0.0709811040724162, 0.22817741468315944, 0.0822190307371784, 0.23458572628442198, 0.09456159968976863, 0.11907982116099447, 0.15607882174663246, 0.11788408024585806, 0.08194768670364283, 0.09252771429601125, 0.13157442648662254, 0.09076129892491736, 0.1853286279947497, 0.11096416914369911, 0.25686678069178015, 0.11718963040038943, 0.18423311412334442, 0.11224741669138893, 0.26392315048724413, 0.17578254570253193, 0.1506593922385946, 0.2972613740712404, 0.06010725279338658, 0.1679671517922543, 0.08715680640307255, 0.1547339907847345, 0.11977759582805447, 0.19175412773620337, 0.22089167672675103, 0.08717038028407842, 0.09393253305461258, 0.0946493141236715, 0.1594595270580612, 0.08990762871690094, 0.10395194229204208, 0.11808528390247375, 0.104327892040601, 0.18418048101011664, 0.13349034008570015, 0.1571384008275345, 0.18730896001216024, 0.1487464620731771, 0.11998590183793567, 0.20599801966454834, 0.21112997084856033, 0.12028006691252813, 0.12558486429043114, 0.3674084006343037, 0.18874972098274156, 0.08677831108798273, 0.13983530196128413, 0.09130788326729089, 0.20941425900673494, 0.15537876868620515, 0.14489072287688032, 0.07761117682093754, 0.12859151232987642, 0.17333194438833743, 0.11053286259993911, 0.136755938292481, 0.20470555464271456, 0.15353677299572155, 0.1106683565012645, 0.19029064220376313, 0.08734653645660728, 0.16778317338321358, 0.12959182349732146, 0.09724617048050277, 0.12477733340347186, 0.17083273240132257, 0.08534237407729961, 0.13995970075484365, 0.12980338011402637, 0.09601864338037558, 0.13564583379775286, 0.19332831201609224, 0.07802377382176928, 0.1945510003133677, 0.19693991431267932, 0.10984594555338845, 0.20180481107672676, 0.14923313283361495, 0.2361848170403391, 0.17954406182980165, 0.24156688683433458, 0.14463232189882547, 0.2020094360341318, 0.17202518560225144, 0.15541185362963006, 0.21549850440351292, 0.11011448426870629, 0.0905040705401916, 0.1371015713084489, 0.20852521061897278, 0.17440170573536307, 0.2067876499495469, 0.20407256204634905, 0.1152759135584347, 0.09040327204274945, 0.06814534295699559, 0.21724091871874407, 0.10280618502292782, 0.15081680176081136, 0.11981570511125028, 0.10971690833684988, 0.09873189075733535, 0.12909863668028265, 0.10275819033267908, 0.18242985854158178, 0.12130593022448011, 0.13047502376139164, 0.27374770143069327, 0.14825121208559722, 0.18063874449580908, 0.1591466524405405, 0.11172477403306402, 0.11675153320538811, 0.14385759393917397, 0.08918113293475471, 0.09507283553830348, 0.16083278227597475, 0.19270876713562757, 0.12643074936931953, 0.1482576984562911, 0.10566496755927801, 0.07969307174789719, 0.15679302014177665, 0.1244015246629715, 0.11241472646361217, 0.10256713183480315, 0.05763288791058585, 0.11934478272451088, 0.20300759497331455, 0.17383657512255013, 0.1838765715365298, 0.15772588492836803, 0.14298730704467744, 0.1678290677955374, 0.10048715907032602, 0.1555204001488164, 0.09546590663376264, 0.14005407225340605, 0.11088765371823683, 0.21796102460939437, 0.1735136518254876, 0.1547084015328437, 0.11904456172487698, 0.18812796450220048, 0.200702321017161, 0.10898589287535287, 0.1445606304332614, 0.12142499297624454, 0.09416639120900072, 0.06584958333405666, 0.10416011471534148, 0.09137719243881293, 0.09799086372368038, 0.25119220081251115, 0.0883361384330783, 0.15677903807954863, 0.2228635927895084, 0.1631738425930962, 0.1440545154036954, 0.22699932946125045, 0.14958479208871722, 0.15579888364300132, 0.08284720679512247, 0.17054693133104593, 0.16801251185825095, 0.16283557168208063, 0.22717156709404662, 0.08437716649495997, 0.13592678122222424, 0.12770751054631546, 0.10273648993461393], [0.025652673975855578, 0.09250044779037125, 0.015056757001730148, 0.06390663329511881, 0.030435682165261824, 0.022413626102206763, 0.05614683366729878, 0.043375670720706694, 0.05371749117330182, 0.03126353491097689, 0.02449707026244141, 0.05113909202918876, 0.03739140745892655, 0.06905373171321116, 0.02683042337594088, 0.05949423139099963, 0.005112782437208807, 0.05231584138527978, 0.031149522474152036, 0.03492275340249762, 0.045763167217955925, 0.015862180189287756, 0.09438712819246575, 0.09436562075279653, 0.03816670687228907, 0.024778065926511772, 0.04820518188353162, 0.025362624110130128, 0.04063639251398854, 0.07743231180938892, 0.031588914716849104, 0.025142560625681654, 0.04850915072893258, 0.06937395359273069, 0.020767924761457834, 0.034779084744513966, 0.05770395597210154, 0.015722895768703893, 0.07323275785893202, 0.01736896261718357, 0.02492837124009384, 0.025868728007480968, 0.07249243586556986, 0.0438433610543143, 0.04455318077816628, 0.042972665978595614, 0.07467941890354268, 0.029285189993970562, 0.045204344860394485, 0.022145248804008588, 0.05065407254733145, 0.04697086042142473, 0.05900411706534214, 0.08025391274713911, 0.05683812567440327, 0.003966034400946228, 0.012214299858896993, 0.014745247935934458, 0.023471418462577276, 0.055212670122273266, 0.030865073968016077, 0.06849562923889607, 0.07585968603962101, 0.012304053343541455, 0.01198600966745289, 0.026402933326608036, 0.06595477534574457, 0.06280979097937234, 0.01731772474158788, 0.04116440461075399, 0.014369915097631747, 0.045579485667985864, 0.039957078770385124, 0.020658558169088792, 0.08147061191266403, 0.09704390555270948, 0.03884545658365823, 0.06920048399479128, 0.03465687528660055, 0.003305006016489642, 0.012786303686880274, 0.008044467995205196, 0.03487237270746846, 0.0077877145849925, 0.05853484595718328, 0.07431612277287059, 0.04845038376515731, 0.06541714130435139, 0.05123834685946349, 0.027830066610476933, 0.05111705766466912, 0.038654446325381286, 0.06030709089827724, 0.018333828811591957, 0.02106632378854556, 0.012931289656989975, 0.022099374800745863, 0.03801152379310224, 0.04211282481264789, 0.04967886823578738, 0.051111224383930676, 0.007012795986156561, 0.05181751890631858, 0.06861205736640841, 0.0507216970436275, 0.0098942089243792, 0.014655870163551299, 0.14704020519275218, 0.05791155323095154, 0.033047999313566834, 0.03264415223384276, 0.03808818022662308, 0.09429145793546923, 0.031977681355783716, 0.013934182570665143, 0.03287293409812264, 0.020203167077852413, 0.027822851079690736, 0.07445387280313298, 0.05502436870301608, 0.05453610603581183, 0.04940328282827977, 0.027881901914952323, 0.02400377026788192, 0.008793242122919764, 0.029368831892497838, 0.0834783588652499, 0.02702509798837127, 0.013983755252411356, 0.015149494847719325, 0.06902684370288625, 0.07566810803837143, 0.020384082272357773, 0.06242541043320671, 0.02313187662366545, 0.027288078017591033, 0.05067867103207391, 0.023329907598963473, 0.025682011073513422, 0.007924969231680734, 0.013114634457451757, 0.030678703988087364, 0.07349447623710148, 0.005169192618268426, 0.05911201791604981, 0.06845801719464362, 0.051397934585111216, 0.10203532365267165, 0.06395976364728995, 0.048338727647205815, 0.057414774419157766, 0.04905581670755055, 0.02176970723667182, 0.07429319783113897, 0.03924568198272027, 0.03492293893941678, 0.06503788899863139, 0.06692122973618098, 0.08597093605203554, 0.02273214289743919, 0.0446491404727567, 0.030336419913510326, 0.011496087372506736, 0.04137529329454992, 0.04685729327320587, 0.04418130170961376, 0.02720625252550235, 0.05540383623156231, 0.030839022729196586, 0.07696635439060628, 0.012000016777165001, 0.050227430401719175, 0.08017928237677552, 0.026336405353504233, 0.10090585652505979, 0.05854534363606945, 0.03375810105353594, 0.016944064518611412, 0.0343564019567566, 0.03283555211964995, 0.02686818756046705, 0.012729314166790573, 0.04360273451311514, 0.06265940217417665, 0.03747884358745068, 0.05118429624417331, 0.04410109781019855, 0.01838416683312971, 0.04640435683541, 0.07667512079933658, 0.020118263528274838, 0.06347393893520348, 0.0324864087451715, 0.005740067917940905, 0.043808101618196815, 0.025409477748326026, 0.04383905659778975, 0.08624501861049794, 0.038618882608716376, 0.036062243234482594, 0.01469795828597853, 0.005387851124396548, 0.07803626416716725, 0.008597431096859509, 0.024287606502184644, 0.01947386783285765, 0.02816249310853891, 0.0315952675009612, 0.028124020172981545, 0.03523567625961732, 0.007355455309152603, 0.03491462688543834, 0.05776730198704172, 0.04840967696509324, 0.0690571752784308, 0.016595162342127878, 0.06772346911020577, 0.012558297366922488, 0.017608121561352164, 0.012364280482870527, 0.01994382171687903, 0.0477070857596118, 0.03983733695349656, 0.018533663205744233, 0.01155430885773967, 0.009699785714474274, 0.01509815214376431, 0.04518356843618676, 0.05099751622765325, 0.026706442040449474, 0.03041808584384853, 0.043492495897226036, 0.02102495462168008, 0.02267969903186895, 0.039243644787347876, 0.05703813447325956, 0.01691222638328327, 0.03458874984062277, 0.08627771763713099, 0.024736160557949916, 0.049177102191606537, 0.023030829506751616, 0.03924534801626578, 0.04315152356866747, 0.02115576371579664, 0.03996378407464363, 0.034411009182804264, 0.035137608865625225, 0.01631666029425105, 0.02432594214042183, 0.10157329961657524, 0.016851982545631472, 0.05281051620841026, 0.05634765882859938, 0.032876151308300905, 0.048013503692345694, 0.0358679675264284, 0.029900204062869307, 0.030088336643530056, 0.08259949274361134, 0.027238862494414207, 0.06153729344077874, 0.009341965705971234, 0.01651640748605132, 0.033782988975872286, 0.04830702309845947, 0.05048605031333864, 0.08430993533693254, 0.0741578968882095, 0.05034732435888145, 0.021253788436297327, 0.08244366399594583, 0.0770041297073476, 0.08737756565096788, 0.04170527070527896, 0.0645861956581939, 0.05354834829631727, 0.02827135132974945, 0.05464264133479446, 0.04336537342169322, 0.033688242692733184, 0.04914454046229366, 0.02105584466335131, 0.1440608681878075, 0.03752120908757206, 0.03265541061409749, 0.018190325281466357, 0.03388159071619157, 0.05725539078412112, 0.02125859013176523, 0.06621434891712852, 0.004012722911284072, 0.028488006500992924, 0.01744950975989923, 0.043105933436891064, 0.08670178824104369, 0.08818202404654585, 0.041542881372151896, 0.010449929104652256, 0.048517830146010965, 0.025440302852075547, 0.018285333171661478, 0.002781225089165673, 0.010554769523878349, 0.028807523340219632, 0.023945225948409643, 0.08499750547343865, 0.021909555689489935, 0.0341035448218463, 0.0503478661266854, 0.008334285012097098, 0.014623467995988904, 0.050329264195170254, 0.04803510761121288, 0.041744085028767586, 0.017146043719549198, 0.03408077573112678, 0.00999408808638691, 0.021186293815844692, 0.04015362173959147, 0.03671285812743008, 0.07618488773005083, 0.06330124859232455, 0.012383527155179763, 0.012005777698504971, 0.02250509580335347, 0.02172736029024236, 0.013064134091109736, 0.019485749617160764, 0.01943089191627223, 0.014182073809934082, 0.050324091425864026, 0.061309231459745206, 0.11959356546867639, 0.04394934716401622, 0.03365938056958839, 0.029778638418065384, 0.015150754643400433, 0.04540454290690832, 0.0882716903288383, 0.017974213733396027, 0.06294494349276647, 0.04485369492613245, 0.01475145321819582, 0.046445445841527544, 0.021627118403557688, 0.008547555989935063, 0.014619280427723425, 0.046657013590447605, 0.05931745552516077, 0.021987727959640324, 0.04676216849475168, 0.1302648920682259, 0.14805075799813494, 0.08717468474060297, 0.1405034278286621, 0.14740223967237398, 0.13725622004130855, 0.15404646517708898, 0.1043553366616834, 0.12295762440771796, 0.11650581553112715, 0.2126098281587474, 0.11085865058703348, 0.16892330517293885, 0.190929883683566, 0.11671089319861494, 0.1908790465677157, 0.06328613104415126, 0.11126966681331396, 0.06816924753366038, 0.13646828185301274, 0.11127398611279204, 0.14414608158404008, 0.18262977828271687, 0.16692977776983753, 0.09606591818737797, 0.06424969848012552, 0.18013973924098536, 0.07952102707349695, 0.056654859727132134, 0.13752035039942712, 0.10752352798590437, 0.09104279553866945, 0.11507738163345493, 0.1242734670813661, 0.12171792608569376, 0.13234082754934207, 0.13285583350807428, 0.15890564740402624, 0.19250467652454972, 0.10726785811129957, 0.08428018263657577, 0.1229414381668903, 0.2039433689787984, 0.16203265695367008, 0.08510500556440093, 0.12468146276660264, 0.23401456943247467, 0.10037392959930003, 0.1550188270630315, 0.1289283880032599, 0.13684502569958568, 0.11622602585703135, 0.136838183098007, 0.18590281280921772, 0.12680587533395737, 0.1850950889638625, 0.12323531380388886, 0.08416353186476044, 0.13024436426348984, 0.1666878821561113, 0.07173083649831824, 0.18333392799831927, 0.19336982775712386, 0.11440832066000439, 0.2020040331990458, 0.180022168206051, 0.14782073674723506, 0.21404212864581496, 0.16266510036075488, 0.09593130002031103, 0.07610960426973179, 0.15002899715909734, 0.13593585026683286, 0.11855639182613231, 0.23281971167307347, 0.2443950780434534, 0.10870783982682042, 0.185359857568983, 0.14775910880416632, 0.11059365191613324, 0.10550903491093777, 0.18691375153139234, 0.16849795065354556, 0.12681826920015737, 0.10287327517289668, 0.14174860320053995, 0.10997043340466917, 0.15772775514051318, 0.11848022521007806, 0.1960800917004235, 0.14675897575216368, 0.1767493860097602, 0.18944962561363354, 0.20061920047737658, 0.14133050688542426, 0.11802092485595495, 0.20971292891772464, 0.1271489998907782, 0.14572106738341972, 0.16287588514387608, 0.198612715175841, 0.1415937318233773, 0.14503036538371816, 0.14910486002918333, 0.14765439176699147, 0.15621761820511892, 0.0920127157587558, 0.3316234052181244, 0.112069991446333, 0.16408649127697572, 0.0973602979502175, 0.16670459532178938, 0.138640696532093, 0.21807688870467246, 0.061578234017360955, 0.1244980187038891, 0.10292924795066938, 0.13556306948885322, 0.11723701652954333, 0.21652715076925233, 0.30805692134890705, 0.14227996609406546, 0.15676964248996228, 0.1283890544436872, 0.14521422504913062, 0.1670387844205834, 0.12090486619854346, 0.0729717816284392, 0.10342838679207489, 0.17211014666827396, 0.3032955096568912, 0.12370180556899868, 0.10132121431524865, 0.09775945465662517, 0.07119977788534015, 0.1299025904154405, 0.20030522748129442, 0.09747320829774253, 0.1181364624062553, 0.12045652736560442, 0.08704707244760357, 0.18139859981602058, 0.2249277726514265, 0.0964677169395145, 0.10095163219375536, 0.12180664984043688, 0.15701983531471342, 0.1752391897025518, 0.1825292914872989, 0.10047781543107703, 0.1157854127814062, 0.12195576215162873, 0.11973388332989998, 0.11076310649514198, 0.07139468812965788, 0.17718119721394032, 0.08098852020339109, 0.1805681810947135, 0.26063896890264004, 0.09861600439762697, 0.15993128065019846, 0.13616110692964867, 0.11246619440498762, 0.32191792444791645, 0.20520071557257324, 0.13128832855727524, 0.09938539631548338, 0.17896628502057865, 0.07082532727508806, 0.08861571288434789, 0.052639551358879544, 0.12018599969451316, 0.182133860362228, 0.20768946327734739, 0.22118089167634025, 0.15257128339726478], [0.027218709474254865, 0.008304628790938295, 0.039611293614143506, 0.016543766760150902, 0.012819008279620903, 0.02371943865000503, 0.06851977130281739, 0.07200276682851836, 0.06339700790704228, 0.07638083698111586, 0.04396709562570322, 0.01537590555017232, 0.06362118103425018, 0.048312941726180725, 0.021057824342278764, 0.03364920943567995, 0.034147160840802826, 0.07790857023792341, 0.07563845181721263, 0.0456413585197879, 0.019935943819291424, 0.029476497111318167, 0.03433197416597977, 0.031802653247723356, 0.03183268054272048, 0.01943845254572807, 0.016064333794929553, 0.09376960195368156, 0.019064864682150073, 0.027920723659917712, 0.042748303603730164, 0.032823143410496414, 0.007394525209747371, 0.034657049691304564, 0.035087309806840494, 0.022330110368784517, 0.01413770636645495, 0.010092567372339545, 0.041792636329773813, 0.020083404851902742, 0.02277716157550458, 0.04581010063702706, 0.04933468240778893, 0.03561215664376505, 0.03551389629137702, 0.026614705166139174, 0.01702564139122842, 0.037003679826739244, 0.0073453685945423786, 0.048245688303723, 0.0498937645170372, 0.050823631027014926, 0.050223010912304744, 0.019050611736020073, 0.04206791003525723, 0.02788116533338325, 0.068216960207792, 0.043378093832870945, 0.04647340625524521, 0.04079615464434028, 0.0388052507332759, 0.026827439942280762, 0.10115178200067021, 0.024578218544775154, 0.0288338009340805, 0.012605955307662953, 0.012581645332829794, 0.061319031519815326, 0.02369496076426003, 0.04419231889187358, 0.015104640369827393, 0.015496040705329506, 0.024776409081823658, 0.036933528317604214, 0.024448704498354346, 0.013638116670335876, 0.0721523912216071, 0.03863136182189919, 0.0921254108834546, 0.04226125434797723, 0.04044422821607441, 0.050155085846199654, 0.10627144321915694, 0.04988053573470097, 0.014530702319461852, 0.004661994980779127, 0.05349512146494817, 0.054793998642708175, 0.021836211089976132, 0.028265540313441306, 0.045618125586770475, 0.014900927326380042, 0.04287209012545645, 0.06491409876616672, 0.06335214507998899, 0.03792789488215931, 0.04999504912120756, 0.017268518495257013, 0.0448003233759664, 0.06531571940286085, 0.018839674812625162, 0.0378898746566847, 0.027305967487336602, 0.03645459815743379, 0.053058909325045533, 0.06960643135244027, 0.03809107089182362, 0.06041342952812556, 0.006084737069613766, 0.021978352779115085, 0.08805990364635363, 0.023017686071398202, 0.015038917626952752, 0.10353666613809764, 0.024498133388988208, 0.03568622669263277, 0.01957347889401717, 0.055320288956863806, 0.0446721359185176, 0.011344821905368008, 0.013114686407789122, 0.036091379952267744, 0.08034452897845767, 0.013840872343280353, 0.034026068315142766, 0.014499668486678274, 0.055632106013945304, 0.06965152424527332, 0.051396739727351815, 0.04895619822491426, 0.05186790702282451, 0.03571401641238481, 0.046726589935133234, 0.07949310005642474, 0.005776714242529124, 0.034028146328637376, 0.035862048898707144, 0.012998172005609376, 0.04402102007588837, 0.06056571452063508, 0.07039942356641404, 0.01114915095968172, 0.035794917930616066, 0.036625852444558404, 0.01915970744448714, 0.02372868766542524, 0.024472219447488897, 0.025404505358892493, 0.02528051660192432, 0.03811764720012434, 0.06579746972420253, 0.014156568977341522, 0.056759001599857584, 0.024463321096845903, 0.03836211435555015, 0.02716994109505322, 0.01672844464337686, 0.05323004486854188, 0.03703910253534559, 0.03646996432507876, 0.06987631335505284, 0.02200886061473284, 0.04713762100436725, 0.011918515047000255, 0.028900035758852027, 0.03476579659036361, 0.01350780759821646, 0.03654385625850409, 0.032629595007165335, 0.03083799485466443, 0.003171111443407426, 0.016929548110056203, 0.019353469215275254, 0.06870452896691859, 0.028733636972901877, 0.04382407263619825, 0.0406137161917286, 0.032962941768346354, 0.05606753889878746, 0.026604090598993935, 0.05777102014690172, 0.027855084408656694, 0.05499987782968674, 0.020566626481013373, 0.03755885081773158, 0.022922691168787424, 0.019837343934341334, 0.005955686865490861, 0.028521379026642535, 0.048252935375785455, 0.06916241181897931, 0.02521493301173905, 0.009655399717303226, 0.012323411338002188, 0.09640354342991486, 0.03633175045251846, 0.04025866903248243, 0.03708688571350649, 0.03753784061700571, 0.046853296807967126, 0.03214058277080767, 0.06055799618479796, 0.014706643269164488, 0.05324010839103721, 0.0222560607289779, 0.046814449087833054, 0.027251848223386332, 0.012407969788910123, 0.034391512963338755, 0.04727550462121144, 0.02720860513363732, 0.017747567399055697, 0.05361033989174757, 0.017254291524295695, 0.027359541272744536, 0.029617853979289066, 0.03898590432072524, 0.023710712848696858, 0.016098858504847158, 0.08786946855252609, 0.04804835123650264, 0.021028906558058225, 0.038290352385956794, 0.09120863585849293, 0.00802900998678524, 0.04753947170684114, 0.03596553026000038, 0.04505883938691113, 0.011975079687545076, 0.030857613528496586, 0.06354107361403294, 0.04155885610089172, 0.0507953960186569, 0.06614615296712145, 0.018466430192347616, 0.02401397479843581, 0.06025232039974071, 0.023610832759004552, 0.06623528490308672, 0.04499722628679592, 0.015960344062477816, 0.029786705563310534, 0.059034311343566515, 0.09324737489805557, 0.018706351693253964, 0.013387302296905546, 0.007459386133632506, 0.042843769770115614, 0.045755077808280475, 0.01332179292148794, 0.023650890179851558, 0.06168108455312904, 0.04068928166816477, 0.020613975502783433, 0.046063280606176704, 0.03345500794239342, 0.03285524871898815, 0.07134481580578722, 0.0446807893604273, 0.06650642113527283, 0.005530593953153584, 0.04365186097857077, 0.052957223961129785, 0.004999860957468627, 0.04612935030309018, 0.02051416962785879, 0.0616212711611297, 0.010201886652794201, 0.023083297492121346, 0.06674594929791056, 0.045192043762654066, 0.05412224738392979, 0.00048154350565710047, 0.02207957615610212, 0.006217417303560069, 0.020785554479516577, 0.07139321867725812, 0.022675600521324668, 0.029133073840057477, 0.013363806829147507, 0.08098610080196522, 0.029597103530250024, 0.03946810735214967, 0.018612861495057587, 0.050186920270789415, 0.028802985107176937, 0.02728820047195768, 0.03300822390883695, 0.026329176835133694, 0.048866531942621805, 0.05052308719314169, 0.0307412187976297, 0.04326731344917789, 0.042467471212148666, 0.038545217030332424, 0.016582406678935513, 0.017708940467855427, 0.009316538798884721, 0.105018230387941, 0.06604459005757235, 0.04270575998816639, 0.014075228664296446, 0.04654178774217144, 0.07402222487144172, 0.016112382290884852, 0.010612081878207391, 0.043182511944905855, 0.02599100425868528, 0.012843825697927969, 0.06320094733382575, 0.06446023835451342, 0.004460384534468176, 0.012062057539878879, 0.09720074362121522, 0.015923654136713594, 0.04612808865203988, 0.03084742755163461, 0.016132166092575062, 0.054105994349811226, 0.06261000482481904, 0.0388771351572359, 0.06193443521624431, 0.08976092096418142, 0.02898291695601074, 0.04221715593303088, 0.016763967541919556, 0.05007647385355085, 0.051646301726577803, 0.033095682301791385, 0.02947404616861604, 0.055959682576940395, 0.029443315688695293, 0.018410487100481987, 0.03766631751204841, 0.03426138478971552, 0.07451079552993178, 0.049670077496557496, 0.027783272344095167, 0.042906933958875015, 0.054447660586447455, 0.034808347627404146, 0.09074864530703053, 0.04439054653630592, 0.026591641071718186, 0.025849643679975998, 0.06278891436522827, 0.039745054600643925, 0.03031452841241844, 0.008477721748931799, 0.043345353988115676, 0.021906618640059605, 0.016097877014544792, 0.12462605402106419, 0.0918961466231849, 0.16849434381583706, 0.05765378307842184, 0.1546240787138231, 0.07772262513753958, 0.15004657121608034, 0.22114443738246337, 0.25504118646495044, 0.14829332154477015, 0.1471652273903601, 0.12425960376276635, 0.14649027376435697, 0.14688926719827577, 0.1271738766808994, 0.15199732122709975, 0.08584727940615267, 0.13961786753498018, 0.23066490073688328, 0.12118873768486083, 0.21515060041565448, 0.09209669718984514, 0.10376416408689693, 0.13120513380272314, 0.17983249010285363, 0.18167769187130034, 0.1024563737155404, 0.17704878322547302, 0.07873311857110821, 0.14600786293158308, 0.12627498741494492, 0.09085575948120095, 0.10691158269764856, 0.15759402012918144, 0.11824315355625004, 0.12260891147889197, 0.12983852822799236, 0.15771932434290648, 0.1939288727589883, 0.20790112379472703, 0.10507202125154436, 0.17204886011313647, 0.1580051996279508, 0.154600597161334, 0.20383054768899456, 0.09500967877102084, 0.07982689581695013, 0.1288702036254108, 0.10553003769018687, 0.12548752420116216, 0.06287099589826539, 0.11290273308986798, 0.20946839125826955, 0.08522535965312272, 0.1364925055531785, 0.10432757291710004, 0.20770139701198786, 0.16162021580385044, 0.17311290692305192, 0.1179358153603971, 0.23929627117468044, 0.12553499196656048, 0.24910477688536048, 0.12551636405987665, 0.1109346910379827, 0.08395836513955146, 0.19539888919098303, 0.11684460594551638, 0.09414618252776563, 0.08916436781873927, 0.12162690167315304, 0.12168234752607532, 0.09716507600387558, 0.15775022737216204, 0.1602982875192538, 0.1168661579140462, 0.1729053579038009, 0.14912059355992824, 0.20802178216399625, 0.1825731821008958, 0.11510683005326428, 0.22591730783460662, 0.2331690554274246, 0.12118635539081879, 0.11751613084925339, 0.07911354347015731, 0.1508139815996401, 0.13329980109119788, 0.09966209123376757, 0.07763594971038401, 0.11536163161508739, 0.1278915483271703, 0.14651442324975505, 0.22338412032695487, 0.20583455421729013, 0.13431231316644698, 0.1685561498743482, 0.10536887290072627, 0.1425147519330494, 0.1410866668447852, 0.16048624383984134, 0.1749772412586026, 0.09317134186858311, 0.12399300947436132, 0.21429965388961136, 0.1764467085013166, 0.17093906732043251, 0.1424757149652578, 0.18469076690962538, 0.14501369674690068, 0.16646290750941262, 0.1293693424668163, 0.08118954574456438, 0.2215996410814114, 0.1466146725579165, 0.11329070563078858, 0.11069571948610246, 0.21238086075754836, 0.10457010677782819, 0.08521919240592979, 0.2078267902834341, 0.10981945088133216, 0.15681911405408755, 0.12876138993306085, 0.12805453879991546, 0.17535147664602846, 0.0731887410802301, 0.2292659375234507, 0.17440598050598055, 0.14685364410979673, 0.13594558724435046, 0.058267639396945015, 0.12876315624453127, 0.19745888334000483, 0.23630449577467516, 0.08763615958741866, 0.14499091281322762, 0.20541340025374666, 0.25630111573264003, 0.17518146545626223, 0.06894984588143416, 0.07385190940112807, 0.1401019110926427, 0.209647961310111, 0.08378415339393541, 0.06627006936469115, 0.1799168871366419, 0.06786210971768014, 0.13701398303965107, 0.10307893171557225, 0.08098255333607085, 0.1441249600611627, 0.13790977012831718, 0.11305098450975493, 0.1291685173055157, 0.14433155913138762, 0.10650154610630125, 0.13608343375381082, 0.11620509729254991, 0.11656543967546895, 0.13898016972234473, 0.13030608126427978, 0.09098204332985915, 0.12695697660092264, 0.09290036890888587, 0.333026658045128, 0.11911959285498597, 0.14507036714348942, 0.1552913585328497, 0.12679008243139833, 0.1157515263184905, 0.23643820110009983, 0.13778744934825227, 0.1280951194348745, 0.0985057806246914, 0.07248974186950363], [0.025686721855890937, 0.07147339289076626, 0.09783550252905115, 0.045263583087944426, 0.04275640785635915, 0.03141240231343545, 0.030275001627160236, 0.02617220518004615, 0.030375852074939758, 0.055553382699145004, 0.0760992884170264, 0.01749669921991881, 0.006558250479429262, 0.02951098285848275, 0.021121526588103734, 0.011822286323877051, 0.04784344797371887, 0.05740932705521118, 0.030243464061641134, 0.043583108417806216, 0.028678951821348164, 0.02700495795579627, 0.028827129026467446, 0.08407082277699374, 0.01676507519732695, 0.027640820808301214, 0.030403710443351883, 0.06308201816864312, 0.05513111922482494, 0.01488679219619371, 0.057268767995992675, 0.04902019732980989, 0.07091850391589105, 0.015724587865406647, 0.0676998242852278, 0.027187301784579176, 0.04466145270271227, 0.03017196555447299, 0.0435261003440246, 0.009670038580225082, 0.012016899709124118, 0.03007262908795383, 0.020682485010183882, 0.016791278576420154, 0.04267343203537166, 0.03219683756469749, 0.0502749204315478, 0.07700838963501155, 0.02484502434526803, 0.024415116749878507, 0.030634212234872393, 0.012050188743160106, 0.09692010047729127, 0.08460085722617805, 0.03822786355158314, 0.028885220635856967, 0.023066380235832185, 0.01998246163566364, 0.02974692459247308, 0.008225129004131304, 0.04684481777076144, 0.07358144852332771, 0.04299773201637436, 0.049074644994107075, 0.08220829928177409, 0.03934200532967225, 0.04743550052808132, 0.04111495531105902, 0.04475750887650065, 0.012967292168468703, 0.059678295147023164, 0.02121725250617601, 0.005014376438339241, 0.04244470954290591, 0.03078497768001398, 0.03598188719479367, 0.015616135970049072, 0.03517897617712151, 0.03453014614933636, 0.10701378385419957, 0.013656226929015247, 0.05690497091563884, 0.0948610933846794, 0.020721954278997146, 0.011798133127740584, 0.034484225761843845, 0.03016903778188862, 0.0284192038452602, 0.053012090938864276, 0.017897267862281296, 0.0396598968654871, 0.03361647330166306, 0.010298982761014486, 0.055440943615394644, 0.023713154514553025, 0.033797297583078034, 0.02253208585898392, 0.03470911135082133, 0.0462097063427791, 0.048929432668956, 0.038026214606361464, 0.0706936554342974, 0.054184476466616616, 0.04198409187665675, 0.02146010177966673, 0.05308341504132841, 0.03685146162752062, 0.0257723360118689, 0.014154098553262884, 0.018270087603013963, 0.037562353754765354, 0.02478310139849782, 0.033618747984291986, 0.04294543286960106, 0.065082106157206, 0.012241169315529987, 0.03941087292332668, 0.029581115813925862, 0.050745364133035764, 0.03558567681466229, 0.008778361134318402, 0.01990078828384867, 0.027626365626929328, 0.03552313231921289, 0.05086949575343169, 0.031178737117443234, 0.08298062268295325, 0.0801441416842863, 0.007044340509310132, 0.02714462829317199, 0.04437531766598113, 0.030789959346293472, 0.02466777164954692, 0.015547326820524177, 0.027733017814171035, 0.013414593850029632, 0.07710503210546449, 0.0577042750956025, 0.027963521461060736, 0.008953176802606322, 0.007551737598987529, 0.030724828466190957, 0.08978987956652418, 0.03745689828065224, 0.03301155986264348, 0.042910240226774476, 0.06946386478375643, 0.057699235912878066, 0.015277573766070418, 0.04109826812054962, 0.04175488698820118, 0.03864954072923865, 0.031134260207181796, 0.066016826312989, 0.03826589119853452, 0.02482369316567201, 0.006010468496242538, 0.12067929041222669, 0.02902567579440074, 0.024610077089164406, 0.02185978170018643, 0.01823939979658462, 0.054071336053311825, 0.05664683711074758, 0.07740371685940772, 0.034897101068054326, 0.09136752225458622, 0.031548408296657726, 0.09142052644165233, 0.009602408517821459, 0.026355881163908634, 0.05382880961406045, 0.006188942952576326, 0.027995170348731335, 0.02988790482049808, 0.033120677835540846, 0.035987802111776546, 0.05110449681524187, 0.053947445630910806, 0.017345111846225336, 0.0444388863252243, 0.0627701157645788, 0.04967477900208905, 0.039139399013947695, 0.0465109886135906, 0.010228984319837764, 0.05442633497295901, 0.015567755363008473, 0.02944007621408673, 0.02743602144619217, 0.003802978758358222, 0.06683727056952193, 0.030272730655269697, 0.07724697527009994, 0.021070127295388374, 0.020867370694759302, 0.042865128780249506, 0.059207762387814, 0.04386892804177478, 0.01356086188025074, 0.042537734043435194, 0.014168040725053288, 0.006525327880808618, 0.05063591590442229, 0.056703244044911116, 0.034995665700989775, 0.0038368865580196143, 0.06844683302915655, 0.021991060202708468, 0.022964915660850238, 0.09638690447900444, 0.047134589331108145, 0.01395604067511158, 0.047077622075448744, 0.06212223939655814, 0.04876226761552971, 0.025333979065180756, 0.04005274531664327, 0.04304546324419789, 0.05690618432709016, 0.030621224650531076, 0.03374397427251097, 0.0488934681925457, 0.06448302970966324, 0.01368706038192613, 0.03212998861272354, 0.04881728302279953, 0.02175388093746733, 0.034474481362849474, 0.011053354537580162, 0.030974746696301736, 0.06024315116519574, 0.023301151231862605, 0.06310908429441042, 0.019054398544540163, 0.07136419328162447, 0.04913494078209624, 0.0851668709947262, 0.020323341195762623, 0.038560861503356136, 0.019633143856481183, 0.029000201575399842, 0.0398252659215359, 0.040358101978199556, 0.03515808472002391, 0.021127792169863824, 0.047323926046374254, 0.021164504360058345, 0.02688231434149202, 0.05124963492562529, 0.023124046965676825, 0.011654734425974311, 0.037167130431043915, 0.070496637490578, 0.03974788218329195, 0.06196043636009563, 0.09077856870135292, 0.019395851413719356, 0.08348222545464523, 0.03209183851140551, 0.036409123058547266, 0.08305874114739709, 0.03836730196780991, 0.009367450129502686, 0.06451353940065019, 0.03384977484529372, 0.0170499467276386, 0.01263491762074409, 0.026720869391283486, 0.012126765395805705, 0.02354904525418533, 0.029662332744919695, 0.0650014569691848, 0.01973722450202331, 0.016442289197584614, 0.03549850785930175, 0.01991602828638861, 0.054186565612326376, 0.038172762797330506, 0.04995282091840636, 0.07109117199433967, 0.013664973139384529, 0.08499116011080332, 0.09653040615376085, 0.02661176440597046, 0.017424015131837223, 0.03663744108052924, 0.06773577391868457, 0.021505617696675472, 0.06603659712709486, 0.06766781545593403, 0.09845772656262852, 0.02434468136925716, 0.03439754662394989, 0.06336032354738563, 0.045467105956049636, 0.04713535374321509, 0.03974086888774764, 0.011290541224298067, 0.05028675026551355, 0.00907912761249463, 0.053281060099834576, 0.04440581251401454, 0.052067782235099, 0.04840706089453306, 0.00017799027745013518, 0.041050971049116924, 0.060237763173063286, 0.02309164479811443, 0.05958125562756322, 0.04327782226027921, 0.042496114401728846, 0.037489081514650024, 0.03780679493502248, 0.04665674641728401, 0.05710222263587639, 0.04290325661713723, 0.029030021069047507, 0.04583473622915335, 0.031988375703804195, 0.04512024468567688, 0.061540525493910536, 0.07568291388452053, 0.003954331659770105, 0.034990915955859236, 0.06575346778845415, 0.05258635421341751, 0.05248092842521146, 0.047572137336828746, 0.005206132555031218, 0.016974939717329107, 0.011482904974400299, 0.02824744675308466, 0.054468926828121766, 0.04588654926919844, 0.008821675655781291, 0.02279611973790452, 0.028354800269880798, 0.015639007106074132, 0.02491616105544381, 0.05537918950722087, 0.09296420845203102, 0.05311566135787871, 0.0027410832490204484, 0.06837288543465547, 0.0687944253149908, 0.013484005066857208, 0.054047743178671226, 0.03843987287837081, 0.019245748335379176, 0.0264714836521307, 0.07797588303219527, 0.08590684417868033, 0.17150645406218246, 0.17643716448219493, 0.15920293692033738, 0.12375265010632575, 0.08534813314327039, 0.13665003381902352, 0.08177666619303636, 0.1407166913850233, 0.19757112575462088, 0.1635485381120816, 0.07829439055058174, 0.12902620306704193, 0.0642294304270763, 0.09711641338071786, 0.1393926702439785, 0.17935426498297602, 0.11999094844213687, 0.0572896112134913, 0.1563155816984363, 0.1614590361714363, 0.1412375454674475, 0.10302438386133872, 0.2034344634739682, 0.1568143197800964, 0.08792792010353878, 0.06990711990511045, 0.1636282744584605, 0.14886937657138333, 0.12007711178739555, 0.11977727670455351, 0.14907039469107985, 0.16179475409444422, 0.11051854657125659, 0.1383947636350058, 0.11463004469987936, 0.08393692449317314, 0.1115310141176451, 0.1492499647429213, 0.09420693473657593, 0.11068288033129647, 0.17334039002889767, 0.1035978265281301, 0.134983838070184, 0.07630699328728952, 0.10854850072064437, 0.12095630445401184, 0.20917481248034164, 0.14587040233891457, 0.11399055831134319, 0.15352829766925424, 0.08871771366102621, 0.1589854431222193, 0.23035558842821047, 0.14433905482292175, 0.13694499299163, 0.20721117878565565, 0.14564652607077733, 0.08731044581509195, 0.14342998329084367, 0.10974989680107683, 0.186410857422743, 0.17421382362954319, 0.21642926149070263, 0.07144682400394231, 0.12577822344610468, 0.10399218896054663, 0.11710576029145159, 0.1241507678059861, 0.13957958755781874, 0.1306280991411768, 0.13400760217336938, 0.07997872438863851, 0.13712104526348412, 0.1433675389853306, 0.11575007170904428, 0.23267846612725407, 0.14550821942975745, 0.14827699429588392, 0.2325320997624658, 0.15383504214696586, 0.12380227752146311, 0.22062425123294815, 0.11201683882973157, 0.16187594505026937, 0.24088571401080117, 0.12239532879902981, 0.18380580033408478, 0.1792669142014347, 0.093780615425203, 0.09952295338734984, 0.06235690278117545, 0.09709126941743307, 0.1336286318837665, 0.09208558723912574, 0.11865598062286153, 0.20225188083713874, 0.1782396630733274, 0.10371770564233884, 0.1414269712404348, 0.0949331559240818, 0.2142243555863388, 0.19342151092132553, 0.13769171229796484, 0.1003053699969314, 0.11144105097628199, 0.10606275129248388, 0.16728591959690675, 0.09713746068882756, 0.15922281163511798, 0.13090376247419044, 0.2392923823208548, 0.17090008972445503, 0.13628179498482496, 0.10140347396372817, 0.12572705978527665, 0.1050643771304749, 0.12913715414470062, 0.1618316091480665, 0.13563673506723717, 0.2116020064568147, 0.14296087174443528, 0.13319469813723117, 0.14654045779025182, 0.1388353470247239, 0.09505414083832875, 0.14545858459314331, 0.14196936244843528, 0.13802269531879574, 0.134137908462435, 0.16358002001652494, 0.125605080393143, 0.08236720794229768, 0.19305536494357511, 0.13577309728134423, 0.05223964137258008, 0.11231787619180977, 0.16212325834203511, 0.16656005464028567, 0.18366724136285484, 0.15392188826808706, 0.15011869312729686, 0.33524740138091147, 0.1789067647769116, 0.09599762575817294, 0.09764857037225738, 0.10449880122905597, 0.17436390073271468, 0.09488065639743581, 0.11399362338124774, 0.17285159672610462, 0.16173173091374338, 0.15249405551003292, 0.09286012966185808, 0.0823726256203372, 0.13045857776887715, 0.1027377812715713, 0.2787642041221261, 0.14166270702844486, 0.07275928990566172, 0.0989443899015896, 0.0832638336578384, 0.1398801276809536, 0.13769598706858233, 0.18730149400653318, 0.1863918435992673, 0.11904845800017938, 0.0753863516729325, 0.21323070890503004, 0.0898199068615213, 0.08272418839624152, 0.19727376202354208, 0.20829998364206403, 0.17854260775493458, 0.1548017340246588, 0.32731366460211575], [0.05655555665725842, 0.04606338821758982, 0.03228158340789378, 0.04693574570410419, 0.022015051981725264, 0.014358520347741432, 0.012522574088507099, 0.0375849410193041, 0.011778610005421797, 0.03693829661642667, 0.06170961270981934, 0.035528783773770556, 0.025618115869292524, 0.008744360566197429, 0.0409142451826483, 0.05489456707437057, 0.06666653949650936, 0.0364351872849511, 0.030720572249265388, 0.09128532197792083, 0.038576272199861705, 0.08008143020560965, 0.03180349558533635, 0.039857011288404465, 0.032131294792634435, 0.025070874726225156, 0.03695793384395074, 0.04211390834825579, 0.08850899946992286, 0.04652964249544311, 0.038645447784801945, 0.09356150374514982, 0.03539442906912882, 0.03106551135715563, 0.05892747547477484, 0.023955417491379194, 0.017553154393681325, 0.03494119206152391, 0.027668423135764897, 0.02652388298884034, 0.011994254928140435, 0.008984744981717085, 0.07039853298920207, 0.00804877152404515, 0.03287941675807815, 0.0283172197669046, 0.042878576496150345, 0.06995121089858003, 0.05227866720815655, 0.012969840518053388, 0.02015302758081816, 0.025466645383858122, 0.048806926351971924, 0.05034529087424744, 0.030065094433666673, 0.05712961530662142, 0.043087769372505136, 0.06019614353135694, 0.01726299506117357, 0.04616023106791545, 0.0436281938891625, 0.09067310951650143, 0.02949192265077727, 0.06511102023068815, 0.050873410582426004, 0.04885527727310546, 0.03203457068593707, 0.035156303565599956, 0.01263834819837939, 0.02198270733060781, 0.04471113577892538, 0.03710481229063589, 0.061786566002410837, 0.04982304526492953, 0.045752001606160775, 0.054061112969066016, 0.05517709156265482, 0.05842613987624645, 0.05082239906187169, 0.06384173248079605, 0.042190984095213935, 0.06760747142834589, 0.027159417440998368, 0.025879405657178722, 0.052397815306903794, 0.05763402339653112, 0.0748637090146076, 0.09058906871359795, 0.024716831321711652, 0.06286262447247282, 0.08738290911423974, 0.04891270466032438, 0.012482211459428072, 0.04342114581959322, 0.028762886868207715, 0.07816275581717491, 0.03831718102446757, 0.06806861973018385, 0.042960513310390525, 0.023175373898993712, 0.0761624526057858, 0.04151600078330375, 0.057159163916367106, 0.04292969191737939, 0.0797719026741106, 0.02538873286539456, 0.05559538083616644, 0.04443418853043113, 0.04998669995984528, 0.02065631873847451, 0.03593992245441768, 0.009827072390180547, 0.03062947918806458, 0.015792336671438534, 0.012465753407013835, 0.028932187451573554, 0.022718134860042483, 0.028963250042579602, 0.04933460819302127, 0.051462712945067324, 0.01963968217751244, 0.04850008168432396, 0.018475617980584502, 0.03679074281535577, 0.059416535950731486, 0.09484369002166204, 0.0024557536744396202, 0.010060385993710952, 0.013701049865630921, 0.049363811704097316, 0.04272223566658795, 0.042049868425237946, 0.01914940086862771, 0.0051056633856205735, 0.03600439282308798, 0.02163347675377736, 0.03730863201781176, 0.05280307617795188, 0.04502181363932323, 0.04949414767907001, 0.05105181175167672, 0.0670172784884926, 0.04566938572679646, 0.029575646185548976, 0.05319587638950907, 0.026216982660116628, 0.02000116561248433, 0.020119703294767532, 0.0310033268033294, 0.057824584655463696, 0.009034106151375454, 0.02130672954081092, 0.014514917766064173, 0.042379233564133756, 0.010851135066332063, 0.04200215946184471, 0.049726810975698754, 0.020735910366056487, 0.04832241153053474, 0.034151290892623365, 0.03236720498534851, 0.025907581293722615, 0.006566725805896567, 0.04087747547600884, 0.03503552645270247, 0.02451223790558288, 0.039048189064487815, 0.03430289310927037, 0.11814124925876968, 0.04947795772750396, 0.08626838884083554, 0.032022666637203656, 0.019358649406058248, 0.010730854264693335, 0.03981752903200686, 0.02333835138415452, 0.004385438751342008, 0.11045246574212797, 0.061040581422275864, 0.03800007616518997, 0.019220246285840403, 0.05704433882783633, 0.008354948258784134, 0.025589802935428452, 0.05005326689570211, 0.043787169342976995, 0.030654127767775208, 0.08587459044065326, 0.04653248121030629, 0.017002549466269556, 0.02056897723377915, 0.0219461695451173, 0.03307560349639971, 0.012838836610171711, 0.044070194780942984, 0.10922633387963288, 0.09504948015091941, 0.04873121244600043, 0.004075376409673481, 0.020104075520066544, 0.06222025112947449, 0.060285787549219094, 0.06884319926030003, 0.02720795204368187, 0.02965487787150778, 0.02721332148212241, 0.037245415878714994, 0.02516560987714911, 0.027760866905737203, 0.036973856622353196, 0.033019344991771504, 0.036231052145012654, 0.02953961677121697, 0.0305072623086744, 0.03978322696639225, 0.047015448653837666, 0.04382677034300286, 0.02224058138381224, 0.016735131393943448, 0.056697870895732194, 0.01934172287292313, 0.03427268769883085, 0.029200546196079813, 0.02534483854105929, 0.08409153611864895, 0.008006447769730585, 0.03399196662940085, 0.052970055694459006, 0.028960192394151818, 0.028852566138084512, 0.026211394288111478, 0.0698494105017744, 0.03588751940696966, 0.008817412945063552, 0.04278334781702142, 0.04624728870112449, 0.03932224935851991, 0.052786849119002, 0.009119237911363598, 0.008524571676389314, 0.026493579243833665, 0.05943992844549939, 0.09761112160049379, 0.0330949921044521, 0.029797296010656282, 0.015508114520343952, 0.04802840601769276, 0.010656685881258454, 0.1090605158242397, 0.04219866532366723, 0.01894388347864151, 0.03679696201288607, 0.07370710896793753, 0.028727532808261458, 0.02812650451232912, 0.04501137533225119, 0.02154349691409152, 0.05975166386633646, 0.04371693990833592, 0.036947599437553436, 0.008770237400312908, 0.005691172445949633, 0.0936540421389509, 0.09269874222809449, 0.03432625220739283, 0.035602709103841335, 0.060059439929318614, 0.02017303959291894, 0.053657429161830805, 0.033647428281256, 0.04779819180839695, 0.028568490561156068, 0.02736903705226723, 0.03974016755819321, 0.00651069829473272, 0.02599757968710037, 0.04914370925689582, 0.03197108366293833, 0.04617704813426826, 0.0114567006676225, 0.0508338615327375, 0.03509477210172918, 0.02611076462926576, 0.048930557022686116, 0.047561554310959764, 0.043204524044995196, 0.04494583627092652, 0.03654226806247607, 0.033889275655383244, 0.07498923587263562, 0.030939782263885718, 0.07339528820011765, 0.05053825669165235, 0.04493189502682071, 0.04589015239616856, 0.044293722239672206, 0.007595925071655074, 0.015008281770860776, 0.031569199563818984, 0.03399093504413031, 0.05318753464962356, 0.04751861735712737, 0.044635618542088196, 0.05202406973694451, 0.02077073193504475, 0.020263644692022353, 0.09477927902480587, 0.05917301132285502, 0.054638466754113324, 0.0487761680415133, 0.07627116239746101, 0.009291758487961488, 0.028132200495747384, 0.04298491512599867, 0.026689723308663815, 0.04399413948704023, 0.07133277074899524, 0.03721864661201835, 0.06140751407656353, 0.020123057802265976, 0.05396170599851757, 0.04221046547172591, 0.05882055054826196, 0.059220048642600887, 0.08176501447451301, 0.016949255841609556, 0.08226741876569577, 0.036067972614546306, 0.053972162859281525, 0.01882826429209672, 0.055767510857549496, 0.05545807238377165, 0.04172866320004687, 0.024642976495670155, 0.03853271184198093, 0.031541246571578085, 0.033385787828592584, 0.04544215866189916, 0.047877493998385035, 0.016066749485617038, 0.04043625383928884, 0.021191668820392806, 0.038693461028742604, 0.07858963173930533, 0.0449788841069676, 0.02240921588963829, 0.03858015734294895, 0.029346018272917718, 0.01700040651485324, 0.03721897315699607, 0.053091738227522, 0.0241603133326862, 0.1464971312088892, 0.1682541996706277, 0.21447107515996322, 0.1728012939565815, 0.08939447812736034, 0.14303481933893636, 0.14013511477969587, 0.1864202826982364, 0.18688975047552958, 0.07233412092318758, 0.1601601589936763, 0.13182086404412985, 0.12789001950295642, 0.1355338140274398, 0.15361696947366, 0.1257657108362764, 0.10850115169887431, 0.056132176250685006, 0.13762420654529706, 0.2866580430418253, 0.1488410116871819, 0.167313972779084, 0.06692679584375583, 0.125458832771983, 0.08476770686684176, 0.1314956697751768, 0.13762068876530975, 0.16257345996564254, 0.12215212700539269, 0.1275881880428642, 0.1579556686920114, 0.19365295709576458, 0.12606381671503186, 0.1348572870483622, 0.1404694968368858, 0.09738570166518912, 0.08738592965528369, 0.18539233395131305, 0.13718433561734855, 0.0613081701885676, 0.1037179357081186, 0.13373480353038758, 0.15178577945334837, 0.10548527134233154, 0.09387637473992072, 0.07409233556245454, 0.07938553317217156, 0.2686721534701064, 0.29067614930681884, 0.09235014062142, 0.10264424839988351, 0.13416055880952626, 0.07050332424114458, 0.10995001692208461, 0.11474563420051709, 0.19907709182007238, 0.1920137309934944, 0.20481304731220007, 0.09311329107731581, 0.10294023915776052, 0.14277904556365684, 0.20046285964781418, 0.13755494932411239, 0.14301527116913348, 0.07861005564336665, 0.23149573506088927, 0.14555015077348799, 0.12124849541578442, 0.1298579279682599, 0.09861293190624565, 0.08272698629298247, 0.1143548934487626, 0.16533536254428327, 0.09828213442233391, 0.1689801982138306, 0.096967523713829, 0.11461299756774679, 0.10215005226200446, 0.13058837939752266, 0.08659517872729339, 0.141732172050979, 0.23478763498133048, 0.07247273184475489, 0.10093255157698877, 0.17313359800027683, 0.13585075561422855, 0.18245820858282968, 0.22669962054351345, 0.09064244397450238, 0.14431380695896223, 0.1561749743996188, 0.12482407386414707, 0.18734980782028288, 0.14522194338496774, 0.2164776940480806, 0.13063921651337296, 0.1393926702439785, 0.10227359016425908, 0.12451974878786132, 0.11645009508356452, 0.1821585590369068, 0.1571833749767393, 0.14621208712924272, 0.14080641703912988, 0.15362998674390838, 0.1454292400740087, 0.1846704469062388, 0.199716214556247, 0.15308891655877233, 0.07710803038207814, 0.16716833371901885, 0.06044633635610808, 0.14846995269181207, 0.18792510585626587, 0.14421704574488103, 0.1049426055396907, 0.15982001787051558, 0.11607817519688979, 0.17474578024121, 0.09462255969992839, 0.07279402241692878, 0.11355971932061948, 0.11722410315996967, 0.12360528926365077, 0.1664850235101767, 0.15058161516208202, 0.13079830328933895, 0.12201341960462742, 0.08456852185190655, 0.181913917476777, 0.2023117573116906, 0.08625903035863303, 0.1747984578832984, 0.20436330582015216, 0.1900558712077327, 0.14186259708367288, 0.11113789107184857, 0.0942576902161818, 0.10757099575130269, 0.14608235971536487, 0.13817274273606017, 0.12641575798625126, 0.10995933087542653, 0.10526114274398424, 0.13631734385853633, 0.1426462605013512, 0.18053114792564884, 0.10139430843992159, 0.1387942023575306, 0.1593871825025417, 0.13687569124158472, 0.11767505435273051, 0.08990419999463484, 0.11031024798285216, 0.11448709221440367, 0.12622078094864264, 0.10564818760030903, 0.11797598039265722, 0.10551336905336939, 0.09807410300709307, 0.26221232197713107, 0.09779443207662553, 0.08608346048276871, 0.11049406311940402, 0.1283176153083332, 0.08720371013623662, 0.1737646758556366, 0.1082587885321118, 0.24828182416968048, 0.16882082942174748, 0.17194478132296354, 0.16018632712075487, 0.14222455734852701, 0.09833832242293283, 0.15543275250820443, 0.08917497310903855], [0.06277632754063234, 0.04619887098670006, 0.019228430319344625, 0.025653495904407464, 0.08261471419245936, 0.007880947814555839, 0.08159038712619804, 0.0036336271523396135, 0.014937820415070746, 0.08311660640174523, 0.0634956022258848, 0.02609516839584103, 0.021015182392147835, 0.09539437101921067, 0.036072573930141516, 0.025941770181816537, 0.015962193865561858, 0.035986354923807085, 0.07580587291158736, 0.016624406671326142, 0.02732050616032211, 0.035444620516500436, 0.029353356258070562, 0.023719928467471618, 0.024034944181039464, 0.042911420241580345, 0.03962108996347524, 0.06434009948861785, 0.03366322118381504, 0.017925591928360518, 0.033322408417006955, 0.008683631549502024, 0.04061795014422387, 0.0462481273279991, 0.043377414767746814, 0.02412060657661641, 0.051747337711276487, 0.021950499976810534, 0.0457349322095979, 0.0388341759389732, 0.01390088147672941, 0.01767058070981875, 0.06023010420904029, 0.021997412986820564, 0.04983700877346564, 0.03016845519596245, 0.020374066989461426, 0.021472399166668765, 0.10622810921631753, 0.024324261175934225, 0.02456116213579662, 0.02171182157326257, 0.061496456764871255, 0.05441964080091566, 0.03801653328991961, 0.020772932402906008, 0.04290527525881771, 0.014289323426055489, 0.01098392291169148, 0.048869099773583, 0.03950790502130985, 0.054225765852606855, 0.051557596525526606, 0.03983419024734758, 0.037069734680699185, 0.02985569375596242, 0.08144907478708774, 0.04295049802749418, 0.01442684431822272, 0.05620135925710201, 0.012879776259069331, 0.0331354725494748, 0.028373088644002564, 0.042841086906264536, 0.03023572346137371, 0.0649793929187581, 0.038914713804842904, 0.03160619191476144, 0.020973124883312266, 0.013604694977402687, 0.07113429819582961, 0.023630770556337666, 0.02599948515126016, 0.025305406379629858, 0.03784173524763901, 0.020612530170183163, 0.059552671809797175, 0.07489709823857993, 0.051066239102510735, 0.03631572748417966, 0.04646949513698928, 0.0478354958613636, 0.030853633761580568, 0.0502202760981163, 0.049180278583662584, 0.03877567985909991, 0.013205656086938689, 0.00833063735626638, 0.0445628695160849, 0.060490193573059514, 0.012080017513653729, 0.028341315446596127, 0.05717149470001459, 0.012750778005283792, 0.05073127817013301, 0.013126915146131068, 0.07103777446900494, 0.09092228559893556, 0.024802348998491652, 0.05254617804894224, 0.0271510886886972, 0.026202672197541688, 0.04420779638167005, 0.004756292264573858, 0.01872568278486142, 0.051889726164517924, 0.03576070492272265, 0.013670520693267463, 0.04523947813140694, 0.08190729160560295, 0.047275259712478146, 0.06064974790206179, 0.03609626328398008, 0.026368011567683425, 0.05059116811025888, 0.03583908313885331, 0.03815835400018841, 0.03544505838362966, 0.0404072247329168, 0.05185061127122026, 0.04685937499743886, 0.0418712965620216, 0.05639655522827525, 0.018827843123290222, 0.0036537381947709946, 0.0055348626938211964, 0.02310914649569895, 0.03590411753975786, 0.015409877360070823, 0.003117066394224821, 0.06554907289682887, 0.014407967792067211, 0.019726951322809327, 0.0265005869732704, 0.04586414012010209, 0.05282512909616344, 0.04968078668753151, 0.010622122208587825, 0.0862525736738462, 0.01111867095460184, 0.029625310708070174, 0.017824949281930458, 0.024018603944568895, 0.022714153237757273, 0.10409368507680483, 0.05704886221792549, 0.010237273181701312, 0.0326674259849824, 0.018662639195099473, 0.03778965132369194, 0.008434966621280182, 0.023442129604518414, 0.08832856110529974, 0.017097601885325275, 0.022242620434553828, 0.025489071231277194, 0.00464512318103516, 0.04938064361340366, 0.07818139856681228, 0.040548403485445306, 0.009747587446327088, 0.06201231248269323, 0.10083253975608386, 0.07121451693819836, 0.020411996301845647, 0.07331112865358591, 0.0162320610252209, 0.018953852377308067, 0.026249733637087047, 0.042955889730365016, 0.07268755391123705, 0.053560849773930386, 0.06102195351559203, 0.019125123362755403, 0.06476733164163306, 0.07027811952866614, 0.050155649878433906, 0.03897778893588111, 0.03580207594495732, 0.1283238790347241, 0.10050030250567943, 0.045772002486046404, 0.06402674989658408, 0.09470115313888527, 0.029632539226440713, 0.039181768224807456, 0.006975407977733994, 0.02791695540508954, 0.06534789892612025, 0.023698422883171588, 0.013549752857215935, 0.0022157366220199037, 0.04243604125804268, 0.04211321072943974, 0.0700215961842332, 0.004917732112517115, 0.0374188186833635, 0.08924331006710418, 0.06381085913744755, 0.017937182419700548, 0.059735711402026936, 0.010419260779599426, 0.041036302500288, 0.01744759316352429, 0.04899707200820558, 0.022713578073307872, 0.04464906996872742, 0.026381550196674652, 0.03891165615641512, 0.037895036293775775, 0.06489676961791702, 0.04636266668967437, 0.024596729563199915, 0.027982867395621724, 0.023982704406080302, 0.038233043742366135, 0.03221973653126042, 0.04549980127194431, 0.06509871542220935, 0.0838959430984687, 0.03610594831116032, 0.04808849029359408, 0.021836741725564934, 0.008735412120586261, 0.04361618965049274, 0.07424902520142496, 0.05372901672672015, 0.04840752844756935, 0.006247916326174163, 0.00883682288986165, 0.02688797321752645, 0.050765977284754626, 0.028843317122664303, 0.040366970642935485, 0.05084117168735247, 0.027739157230826095, 0.06472836146713234, 0.06225882796570659, 0.03396010994038079, 0.015749225312902126, 0.056691607169341296, 0.07074219931382686, 0.05331994492735248, 0.010847555131476838, 0.016720130734029226, 0.025444152743148152, 0.04427693856996484, 0.012069634867657442, 0.036564090914907865, 0.011138719146401854, 0.018222625403723214, 0.07074839624692686, 0.03344293691043276, 0.03963481227401644, 0.06415280367946252, 0.03792542724113446, 0.037398194399429485, 0.008035352566366782, 0.0786551930650603, 0.0072918949990707915, 0.008818186634016456, 0.06571686506504193, 0.018554745765868574, 0.05009110158425756, 0.11791297205490991, 0.0785485167580191, 0.017062750630429946, 0.009996326589316595, 0.06533526757266372, 0.006098523390392074, 0.03936104512831662, 0.034441478055668995, 0.021126452593307476, 0.13189265941036865, 0.0287708575342549, 0.035339628884685226, 0.019018250386579894, 0.06547297307406552, 0.08181094599422067, 0.02713866142585175, 0.03456242586253211, 0.015591602423228323, 0.07488868970540352, 0.04569449258269742, 0.05474540652357973, 0.05939771137491334, 0.07166245501139201, 0.040107274617184885, 0.028676656729658134, 0.03628740712883882, 0.10312268874258734, 0.025457776719122194, 0.021699099306715652, 0.06735252143698744, 0.029255956796987448, 0.10841567112947814, 0.07425004194374196, 0.041031990622286685, 0.04241997747158166, 0.05022867720981594, 0.03231895054341294, 0.054304559671436436, 0.04168849816778675, 0.016932924881984945, 0.03119963970675599, 0.06600928609259427, 0.017526871233712882, 0.0398029792268062, 0.014282206229836447, 0.07463624817319214, 0.03493181131489109, 0.018102931826433633, 0.0333220002357848, 0.015111574812181061, 0.02046809153398499, 0.024447088471788447, 0.016491226415382698, 0.016396567334595602, 0.0411169962171698, 0.007060574989736779, 0.03036120207980275, 0.026222624837828334, 0.01511342090452672, 0.029670906405954156, 0.021786524303024635, 0.04633963784726802, 0.05056729321950115, 0.035571071348385885, 0.0439234128134558, 0.027335048544046003, 0.030985441044322215, 0.019217908520658966, 0.03495982367894612, 0.023033870456856675, 0.024354410925297998, 0.051545685055316426, 0.040506390505470335, 0.018282871096744202, 0.01347815044937306, 0.020026305865030736, 0.013578287507698406, 0.0366260082955705, 0.11697217370965518, 0.10612226411467418, 0.08520233823219314, 0.12385298105073161, 0.12556534580653533, 0.09442571987165138, 0.16933553852140903, 0.06818233159719966, 0.1505412274855189, 0.22460559150204062, 0.14205870218575, 0.18042726209387183, 0.12527273182058707, 0.22166480164742097, 0.22325332422042266, 0.08884248352842405, 0.1661828951910138, 0.1826818028348498, 0.17603723594220355, 0.10684678578400053, 0.1371104919235222, 0.12248758517671376, 0.1959591216291301, 0.12074469588696957, 0.09056790266185999, 0.20117726584430784, 0.14519694785121828, 0.17134917812654749, 0.1634988290606998, 0.16572518303291872, 0.16562950535444543, 0.13953917019534856, 0.20331802050350234, 0.1494539514533244, 0.20082624483620748, 0.12123388252803124, 0.17658554948866367, 0.14514308277284727, 0.20996427949285135, 0.16594362678006291, 0.10779885735246353, 0.10061617402243428, 0.09591362948413007, 0.10934969366644509, 0.15988774626748636, 0.1656838899361901, 0.09339898824691772, 0.1358235633233562, 0.16901694936677814, 0.10006026830524206, 0.12362743495032191, 0.11323694445309229, 0.2737584477290511, 0.13434627384413034, 0.18871914449846372, 0.12801778764696792, 0.1297256030375138, 0.11534914869116619, 0.06234925866010599, 0.12477984186261892, 0.1682603743392974, 0.13483996532158926, 0.19009915326023474, 0.07250416922033764, 0.1027277548564598, 0.1614682684885338, 0.18940343434223905, 0.1968319615116343, 0.13072796253254637, 0.12424154730979353, 0.21507320925593376, 0.17930997360963374, 0.133047248236835, 0.12402534484863281, 0.18070476595312357, 0.1748672846588306, 0.14385493705049157, 0.08036395840463229, 0.08802059950539842, 0.12279437418328598, 0.18643723335117102, 0.20951176236849278, 0.09066288272151724, 0.13839756895322353, 0.1289857114898041, 0.14281567797297612, 0.1514489037799649, 0.1642801918205805, 0.1335472776554525, 0.12397568032611161, 0.09419261870789342, 0.15125296195037663, 0.09386391408042982, 0.17245747178094462, 0.1275496557354927, 0.17056826065527275, 0.10616991741699167, 0.08291658275993541, 0.22219101403607056, 0.1813013487844728, 0.07791084863129072, 0.08028749492950737, 0.2269805976538919, 0.12724678526865318, 0.12636799336178228, 0.1276283382321708, 0.1633678696816787, 0.20164557587122545, 0.07067036684020422, 0.09363352175569162, 0.11020596881280653, 0.11145007549203001, 0.11953919572988525, 0.11720131180481985, 0.1077406136028003, 0.1458619418554008, 0.15944285842124373, 0.19841417582938448, 0.20708168885903433, 0.12134029908338562, 0.13757621927652508, 0.11455101339379326, 0.17981709796003997, 0.06734216105542146, 0.2193705560057424, 0.17493435996584594, 0.09825608503888361, 0.1283199604949914, 0.14475860574748367, 0.22125366667751223, 0.18951650796225294, 0.07979100555530749, 0.13922696351073682, 0.2019892941461876, 0.11019540062989108, 0.09505703521426767, 0.08152854396030307, 0.17063348059309646, 0.12034707542625256, 0.17870230309199542, 0.1623354383627884, 0.08594313520006835, 0.10082192704430781, 0.22641563031356782, 0.20340209099231288, 0.09397497648024, 0.11928370397072285, 0.14267774240579456, 0.11342648896970786, 0.10823454998899251, 0.09815563535084948, 0.12014920401270501, 0.059169267187826335, 0.11386636731913313, 0.2676253393292427, 0.10511912536458112, 0.07639544986886904, 0.1393728845869191, 0.06448300002375618, 0.080198429786833, 0.13221405388321728, 0.09477085564867593, 0.13223134592408314, 0.12974090612260625, 0.1031477510696277, 0.10575558379059657, 0.12462537124520168, 0.13652484834892675, 0.10578440138488077, 0.1157122444419656, 0.10297705710399896, 0.1693207400967367, 0.1229748125479091, 0.16105236893054098, 0.09685652068583295, 0.14862569980323315], [0.02127232357452158, 0.02840860041033011, 0.04983613674994558, 0.01597580856468994, 0.06341638538287953, 0.016493267321493477, 0.023273276165127754, 0.003829292531918327, 0.06934351069503464, 0.018911271654360462, 0.023777623027854133, 0.050785254570655525, 0.05095829372294247, 0.0660131304175593, 0.03899714043654967, 0.036611072573577985, 0.06779321614885703, 0.02741079770203214, 0.010869101533899084, 0.02516161712264875, 0.04630083465599455, 0.03443389701715205, 0.04910931813356001, 0.014620615365856793, 0.09158672299236059, 0.05450425305753015, 0.04148953579715453, 0.03612581189372577, 0.04253125509421807, 0.04599747066095006, 0.09963946315110661, 0.034070133333443664, 0.008646421192679554, 0.07287029293365777, 0.0569367830757983, 0.04992572510673199, 0.014937510568415746, 0.07268353889230639, 0.07973173022037372, 0.06606558541534469, 0.014757038807147183, 0.02677372143807588, 0.01998350435314933, 0.05543044593650848, 0.0555479835747974, 0.04285368115233723, 0.04463874669454526, 0.058545191495795734, 0.010422148661746178, 0.030908612061466556, 0.027955545228905976, 0.02963974362501176, 0.0238962571893353, 0.047961646123440005, 0.019791898521361873, 0.044787636361434124, 0.013677003353222972, 0.07774209909257479, 0.05127758049638942, 0.047215687518473715, 0.03488819900667295, 0.06325712049147114, 0.024405370495514944, 0.10179763601627201, 0.08967047542682849, 0.019468123609840404, 0.004339546194387367, 0.032812141071190126, 0.03812054157606326, 0.024473596131429076, 0.02423048710625153, 0.03557242947863415, 0.019462730051600374, 0.03780703613301739, 0.040822293085511774, 0.007920644366095075, 0.06771053347620182, 0.007036440811134526, 0.05867953135748394, 0.02572162135038525, 0.03530071066052187, 0.044578502856893465, 0.04345088738773484, 0.09444087452720851, 0.02546634481404908, 0.03817060685832985, 0.03573177229554858, 0.020166243375570048, 0.031664209309383295, 0.05444317801448051, 0.018722246641118545, 0.016962935478659347, 0.029261598974699154, 0.03346225872519426, 0.1014707273861859, 0.038520971065736376, 0.06513220112537965, 0.04008059811894782, 0.06165503516967874, 0.03105696552665904, 0.033764787804102525, 0.06594949125428684, 0.043134279767400585, 0.0030692704604007304, 0.047901996003929526, 0.01038823529597721, 0.05649591395922471, 0.025583930691936985, 0.023918601400509942, 0.0626102348905988, 0.024779127197689377, 0.04542230992228724, 0.05035440444771666, 0.02635570490383543, 0.10062182176625356, 0.03335490335302893, 0.02597839331428986, 0.016616810789855663, 0.01600377268914599, 0.07039969073957764, 0.04369136549939867, 0.021657650358974934, 0.14056498155696318, 0.029105768371664453, 0.05927496757067274, 0.031223306796164252, 0.04488778176892083, 0.010639885513228364, 0.022211966024769936, 0.08599107051850297, 0.04054056269524153, 0.02434917878417764, 0.016911118727875873, 0.013015456624998478, 0.02146916711353697, 0.08538907743059099, 0.014498558975901688, 0.02887694940000074, 0.020478407386690378, 0.004816916916752234, 0.02106992877088487, 0.016814620976219885, 0.01996865583350882, 0.02862700890545966, 0.036414826463442296, 0.0073186341160180746, 0.031197097850963473, 0.019295607671665493, 0.0576024227484595, 0.042708884429885074, 0.03380238871613983, 0.01642931831156602, 0.033682116263662465, 0.09223442495567724, 0.03860110075038392, 0.03327649174025282, 0.03205460496246815, 0.01983470188861247, 0.05636159265122842, 0.04807978119060863, 0.11290562004433013, 0.04910082425340079, 0.03309883642941713, 0.058681305090431124, 0.048618862419971265, 0.03152749457512982, 0.04435129063494969, 0.0763820466818288, 0.01909320730192121, 0.014668422663817182, 0.03354737564222887, 0.02783736192213837, 0.045084573357598856, 0.07827938432455994, 0.045173694161348976, 0.024701637703401502, 0.029240201001812238, 0.01840368346165633, 0.0038404054976126645, 0.06365644789184444, 0.018946082091133576, 0.022631875035585836, 0.011062932881031884, 0.07250767957884818, 0.031061665176821407, 0.0460745241434779, 0.02392961672740057, 0.02148136802134104, 0.03915494329703506, 0.08246897123171948, 0.08728630375117064, 0.03453454337432049, 0.04885062400717288, 0.017614941898500547, 0.02451225089316722, 0.044092310781707056, 0.04430770430190023, 0.038299900115816854, 0.05013835041609127, 0.024194537472794764, 0.018261725454067346, 0.062302547885337844, 0.07552731520263478, 0.010561216931819217, 0.027554672305996064, 0.033153495605802163, 0.045103427619324066, 0.044050034339306876, 0.04659981626900844, 0.06782008189475164, 0.06425199913792312, 0.03162772532959934, 0.043382442818256095, 0.03041998945263913, 0.023020535918476526, 0.027021693385904655, 0.01429136154911248, 0.00786410941145732, 0.05594940754235722, 0.04097308265045285, 0.018937541826744564, 0.027848726058437023, 0.0271309709205525, 0.012860061106039211, 0.029571239683718886, 0.10060028464067727, 0.03679596382426098, 0.05453459205455147, 0.036925312742823735, 0.013085422597214347, 0.04750910673465114, 0.034751139173749834, 0.017961827288672794, 0.051063990395050496, 0.036545362818287686, 0.040684149716980755, 0.03399849752895534, 0.04101314007129986, 0.007880552620918024, 0.01922336516145151, 0.07108928693924099, 0.03051857820537407, 0.015024010663182708, 0.09840115264523774, 0.03573562775272876, 0.03632871506852098, 0.0036992058721807553, 0.03453543766227085, 0.058716364146675915, 0.027871114798472263, 0.058741563771036454, 0.03909811333869584, 0.052890044753439724, 0.01384798397339182, 0.022941029637877364, 0.02695182389288675, 0.037758132311864756, 0.03839304707071278, 0.019029822324228007, 0.04535887484962586, 0.03908442071406171, 0.013580363665823825, 0.039222552950377576, 0.023655255863559432, 0.10017866312409751, 0.020631534716812894, 0.0058272034766559955, 0.02142992234439589, 0.03937042216421105, 0.036047682297066785, 0.06322382774669677, 0.028797810482501518, 0.01508462279161904, 0.057462075201328844, 0.032724786578910425, 0.010193475336564006, 0.023219906470330898, 0.021368993875512388, 0.029387129543465562, 0.00894803371920716, 0.03938487177947536, 0.04732864981633611, 0.03099153964285506, 0.039200195751618594, 0.06182015931699425, 0.01252087642569677, 0.030152406252454966, 0.021381961050792597, 0.03603561497584451, 0.047813116398174316, 0.04074417462106794, 0.03146593342535198, 0.014176584700180683, 0.029941536122350954, 0.030274246491899248, 0.055085595886339433, 0.05440954759251326, 0.08858566332492046, 0.03889800063916482, 0.03384744450158905, 0.05060927651356906, 0.038803343413746916, 0.05133817314344924, 0.04485882687731646, 0.029881275586376432, 0.03813380375504494, 0.053260116692399606, 0.07212189637357369, 0.03889539199008141, 0.02984455226396676, 0.025992716764449142, 0.09913000103551894, 0.04886989016085863, 0.024410354017163627, 0.0555094067385653, 0.023280962959688623, 0.019101278157904744, 0.03312610293505713, 0.003321279923511611, 0.04999146825866774, 0.039084580275812186, 0.04892668301181402, 0.04971491805918049, 0.06444744372856803, 0.037264214479364455, 0.053295769466785714, 0.03583807010727469, 0.02139603402611101, 0.07899261050624773, 0.02257539759739302, 0.06046720554877538, 0.018732239659584593, 0.006761643935533357, 0.011243779426877154, 0.006998243861744413, 0.04154009460762609, 0.03263184742536396, 0.013172306753403973, 0.06774539215257391, 0.03295935348432977, 0.04308957650209777, 0.03714640224643517, 0.021537305547099095, 0.03750579468032811, 0.05653591200825758, 0.07615394017193466, 0.027985045599052683, 0.024549864792788867, 0.053738779679406434, 0.011256178859184729, 0.02531831789383432, 0.07567814929643646, 0.11590909911319613, 0.10568407786195166, 0.19544077600585297, 0.1001370583253447, 0.13583959371317178, 0.09566945547703654, 0.12590529397130013, 0.16135943995323032, 0.20135011203819886, 0.14254942507250234, 0.17752196174114943, 0.17823972244514152, 0.1548064243979752, 0.15070346096763387, 0.18585807614726946, 0.19957816024543718, 0.17188051133416593, 0.09754472164786421, 0.14588707097573206, 0.10778189185657538, 0.12991537019843236, 0.13416441797744483, 0.11636976501904428, 0.08692263654666021, 0.32588232890702784, 0.18157159443944693, 0.163557740743272, 0.11471892430563457, 0.09228978175087832, 0.10221493081189692, 0.15998787683201954, 0.10738076103734784, 0.20090041507501155, 0.22697219654219225, 0.12481337209464982, 0.11605236330069602, 0.14286194345913827, 0.10902144174906425, 0.13319468329427764, 0.12895319057861343, 0.07340144802583382, 0.1356666287756525, 0.13726321107242256, 0.09939528914401308, 0.112105933658313, 0.08195296337362379, 0.15048659057356417, 0.0843745244492311, 0.11660063231829554, 0.20832266367506236, 0.11362223041942343, 0.2392833132762462, 0.07880247969296761, 0.176283287582919, 0.15792798658367246, 0.24507328227628022, 0.08461834964691661, 0.19094126822892576, 0.20059671340277418, 0.1049937320931349, 0.21422022924525663, 0.16270097577944398, 0.07675215572817251, 0.09386657096911222, 0.2844755648402497, 0.07342826182139106, 0.0830187913379632, 0.19451303203823045, 0.11019609824870713, 0.09795463207410648, 0.08745566185098141, 0.09899253302137367, 0.11954577115830034, 0.12335413164692, 0.1449808938195929, 0.12745664978865534, 0.14322356233606115, 0.1516318431822583, 0.168444516020827, 0.10343327012378722, 0.1515070436289534, 0.10016992062446661, 0.12649494514334947, 0.09522971813566983, 0.18694602011237293, 0.0698420632397756, 0.06309834541752934, 0.08008619479369372, 0.2553052129223943, 0.08754463793593459, 0.10697169665945694, 0.09113553431234322, 0.14720889535965398, 0.23643230844754726, 0.18063972413074225, 0.06971715236431919, 0.13958537630969658, 0.171386819856707, 0.14070593024371192, 0.09403970660059713, 0.1384938700357452, 0.17831346223829314, 0.203613736666739, 0.10549321232247166, 0.1129625947214663, 0.16090480028651655, 0.07156309628044255, 0.15461023023817688, 0.11482798290671781, 0.1691556122386828, 0.1486423090682365, 0.13342339836526662, 0.16682889021467417, 0.2321297221351415, 0.1860201166709885, 0.08883014161256142, 0.07457985237124376, 0.07130512574804015, 0.13067642779788002, 0.14181570819346234, 0.24364611745113507, 0.1908787793945521, 0.3029496985254809, 0.09942142758518457, 0.26398112706374377, 0.09227407048456371, 0.17366429296089336, 0.11688628495903686, 0.1447398294112645, 0.20465759705984965, 0.14093314617639408, 0.22060468822019175, 0.08092652118648402, 0.11645517879514955, 0.14184284111252055, 0.2995490888133645, 0.1281781360739842, 0.09147822100203484, 0.08481264390866272, 0.15817081730347127, 0.10007519289501943, 0.12618034874321893, 0.1520265915314667, 0.0935647617734503, 0.10885309297009371, 0.08759698903304525, 0.19190937018720433, 0.10053447098471224, 0.19485067954519764, 0.1175068540032953, 0.1889600307913497, 0.13264452922157943, 0.1077183491725009, 0.23155310307629406, 0.09255983444745652, 0.11902375190402381, 0.11266294517554343, 0.13331091846339405, 0.12947720621014014, 0.14314572588773444, 0.14713996468344703, 0.11214018377359025, 0.09692271283711307, 0.16848214290803298, 0.10829078251845203, 0.1431477296864614, 0.1746274225297384, 0.20015656045870855, 0.10471967922057956, 0.19304271874716505, 0.12195755814900622, 0.15496430889470503, 0.11867804467328824, 0.13120075513143092, 0.1127132998954039, 0.17087788466596976], [0.06489112187409773, 0.05040768322942313, 0.032396430760854855, 0.06933480530278757, 0.10470914814504795, 0.06795645153033547, 0.03831909576547332, 0.06045414003892802, 0.049702023243298754, 0.04092457216756884, 0.07031531597021967, 0.04868544790952001, 0.009126908007601742, 0.03259108496422414, 0.012430366878106724, 0.037405768016469665, 0.021735965492553078, 0.05022491452109534, 0.013501883404387627, 0.04613439319655299, 0.01882000233308645, 0.045586142732645385, 0.01465345076212543, 0.030894613300915807, 0.03336808760650456, 0.03481671905319672, 0.011895918505615555, 0.055471735322498716, 0.0733819740707986, 0.0170703966068686, 0.03402264330361504, 0.019169475963281002, 0.04218654976284597, 0.026224290959362406, 0.04431622786796652, 0.04906704540189821, 0.06383337589795701, 0.043281915204715915, 0.0542041767766932, 0.002120175367963384, 0.046151874485076405, 0.03933485102606937, 0.010984798645949923, 0.0412117870291695, 0.05924040204263292, 0.05594020120042842, 0.05229199246969074, 0.04620399180566892, 0.021507185483642388, 0.02281318356835982, 0.06735229137120768, 0.029156147211324424, 0.05299085809383541, 0.015337447457568487, 0.07064446588628925, 0.09980083574191667, 0.052986750306445174, 0.03509079419018235, 0.027394392527639866, 0.02035513851296855, 0.02727568044065265, 0.0433699153654743, 0.06967697248910554, 0.03233301795262378, 0.055326990550383925, 0.011179123521287693, 0.03472858159511816, 0.037698318919865415, 0.02502138275303878, 0.03102611630311003, 0.016083225164038595, 0.041103025287156925, 0.028680755240202416, 0.023634889475943055, 0.009948964579962194, 0.09122537128860131, 0.03381654889381025, 0.04681394813815132, 0.014029057801963063, 0.04428964042745065, 0.028752155412803404, 0.02965126361232251, 0.03266214189352468, 0.024207641945395153, 0.05665753888024483, 0.009384452732774662, 0.013589362206403166, 0.015317440083890688, 0.0775309580785688, 0.0784113233385142, 0.017105322076531593, 0.013217253999755485, 0.023862339185143355, 0.037058108937344514, 0.03799674392212182, 0.03343814634718001, 0.009705002084956504, 0.03444025722274091, 0.036693732981802896, 0.026777100065373816, 0.01633503215998644, 0.06190559535752982, 0.043685461714630947, 0.05298931442666799, 0.05736304672609549, 0.03317716269521043, 0.03518162193358876, 0.09187609379296191, 0.09679251787019894, 0.03748793860722799, 0.010788901345222257, 0.012841734696849016, 0.05601105403911788, 0.044457202529883943, 0.033092112571466714, 0.051374260074226186, 0.08260888833319768, 0.05444462520244997, 0.02995270915562287, 0.03209003509255126, 0.029917848623881582, 0.046221910961321555, 0.055202662260853685, 0.052305826102383435, 0.0233809154087794, 0.028188043397676665, 0.03757287369808182, 0.017589783092262223, 0.02500679955119267, 0.0253369791971636, 0.02160979296604637, 0.026539516329648905, 0.0403105303121265, 0.04805169090104755, 0.06376666424330324, 0.050479278215789236, 0.07554068128229119, 0.03195350960595533, 0.07339044939726591, 0.008518379381712293, 0.03754397817829158, 0.03700136803672649, 0.043201755834161304, 0.039226052176672965, 0.05302198747813236, 0.049503276095492765, 0.04928769703838043, 0.006022321058480884, 0.003669733332571923, 0.06215433357283473, 0.03754788187507074, 0.022573833521164488, 0.05530598034965806, 0.024534431831853, 0.02867204984795535, 0.06239780253963545, 0.13481664704158902, 0.03244754989282228, 0.013353054964682087, 0.07503597633331083, 0.024699839850654826, 0.033004988144966774, 0.01686784966295818, 0.0361585814243881, 0.05671731516486034, 0.04566673997032922, 0.05463727189635392, 0.1193043653620407, 0.02917685498687206, 0.05485827976372093, 0.03143240690405946, 0.034337336182943545, 0.0031437259622180136, 0.04490026840358041, 0.015300589620892424, 0.04366698594822083, 0.054895888097235, 0.03775183518882841, 0.03185442175890785, 0.03935726017516572, 0.04264672585122753, 0.030886026652297005, 0.009925982121785637, 0.024098451613099314, 0.079454797814833, 0.06760704098269343, 0.02410215307463659, 0.05607992163277231, 0.057717745075933635, 0.09018680240842514, 0.045966448888066225, 0.07641050062375143, 0.044241816431167535, 0.008902093850338133, 0.05793332413304597, 0.07250633629155345, 0.021636035307892598, 0.03521605387504678, 0.0347858271561563, 0.00883752700246987, 0.01215836882693111, 0.03761197003768757, 0.02042264983174391, 0.06328265779302455, 0.07533702853834257, 0.05411565340182278, 0.012599900310306111, 0.008134887557389447, 0.042573702230583876, 0.10054274593130685, 0.029875332838855684, 0.013657241815963062, 0.0880971149308607, 0.013577357967733406, 0.11038798053050414, 0.02000292264710879, 0.04175135436526034, 0.05519625010492746, 0.03175229110638611, 0.008755653270782204, 0.021917017984378617, 0.017450942104915157, 0.018283848876308184, 0.027458128170110285, 0.011074802605435252, 0.016002696575014852, 0.021635834928019904, 0.021446349783218466, 0.008583218041167129, 0.034605351684149355, 0.042842682523769327, 0.05599711279501207, 0.055394741211785004, 0.025265159711125307, 0.05546309672354255, 0.02322228505363455, 0.0443261244072346, 0.013326587195479078, 0.019247193667979445, 0.010192907593591372, 0.042926957103190944, 0.029359623695199843, 0.008452635302091949, 0.03350045706611127, 0.02785085787763819, 0.022845758285257034, 0.0331452317914227, 0.017952405723917764, 0.040743788704276085, 0.01833293637901079, 0.08426958476775326, 0.01409820091794245, 0.023808897130948026, 0.04809856123756617, 0.012722725750791142, 0.03183844703016803, 0.07543857660493813, 0.045719031695625745, 0.07506106834625825, 0.020989387194276787, 0.006053744982636999, 0.013828962728439365, 0.03551067908119876, 0.028417164794518612, 0.020635631371987984, 0.021197585592744872, 0.04752786080644, 0.027534933033166453, 0.07125923133571632, 0.003928526257368503, 0.04334460441896226, 0.09567156317643821, 0.030878007746650837, 0.10876387939788401, 0.06224854550964665, 0.046242190146585926, 0.03347273413965013, 0.03805558881140314, 0.03949893616663758, 0.04372547831735574, 0.05206554465985391, 0.020778531907126307, 0.006109972409831244, 0.016989268733595964, 0.020732808188768104, 0.013091167747916188, 0.10072633100207895, 0.02206649394793203, 0.05562445076066069, 0.028045688341080677, 0.04121743477298878, 0.025824499716691207, 0.060714741484844126, 0.05865567873115651, 0.050489928034949116, 0.028818269638577476, 0.03688322183734272, 0.049929658489418216, 0.0067495469284040155, 0.0410766938875895, 0.00813198112155078, 0.056957681954372674, 0.0397726810479071, 0.03141889981634449, 0.04186562655377202, 0.01706712930172216, 0.04137398711463902, 0.02126611736457562, 0.06364239161484875, 0.07634534747921862, 0.0940905288734939, 0.020204363790981006, 0.04322949731431436, 0.04637801801436581, 0.029641790097230114, 0.09065074860700406, 0.034656288989936, 0.007583389733554213, 0.0357335608714493, 0.025507099853712134, 0.05389231890148949, 0.04320038657169789, 0.03660460475657601, 0.05576030831434764, 0.02996542585606221, 0.043252652321825735, 0.03528085449943319, 0.03970097845012788, 0.011049051936424803, 0.027109587790619116, 0.04390760135720484, 0.08745316823478788, 0.04483911914576311, 0.0321833119232906, 0.01796765314793447, 0.05859924953256268, 0.05125706011313014, 0.01690573259111261, 0.05012816072849091, 0.023245174743351527, 0.07332211986067705, 0.04271296253136825, 0.016408714436693117, 0.0501465993875172, 0.011259740240348037, 0.08795755406026728, 0.02337126192287542, 0.019292605684313457, 0.008888857646525139, 0.04527544631855562, 0.05295352064422332, 0.04277436040865723, 0.10347422925406136, 0.14527540770359337, 0.1830663689179346, 0.14912469021510333, 0.2204556204378605, 0.1533541304524988, 0.11842812644317746, 0.17838923551607877, 0.2056370093487203, 0.12700726452749223, 0.13460191403282806, 0.10958836835925467, 0.1299475645646453, 0.17063175881048664, 0.1548859232570976, 0.14332605293020606, 0.1170443401497323, 0.11040476791094989, 0.1751891095773317, 0.12915653904201463, 0.09855255077127367, 0.0821001609438099, 0.17867359681986272, 0.12526959995739162, 0.12471377587644383, 0.2038211075705476, 0.09656899783294648, 0.14065944211324677, 0.13199572887970135, 0.1404409241513349, 0.07873558250139467, 0.17652714246651158, 0.09526859183097258, 0.15819064748939127, 0.09795478050364181, 0.09012810594867915, 0.22107332479208708, 0.14529241772834212, 0.1331797512830235, 0.12421595805790275, 0.09090509003726766, 0.10961808395222761, 0.0894531374797225, 0.08782857621554285, 0.1225992784020491, 0.16250369808403775, 0.12485260202083737, 0.11902971134986728, 0.10579874709947035, 0.15907767723547295, 0.17905182496178895, 0.14009039296070114, 0.11603835897403769, 0.14450756687438115, 0.1537364107207395, 0.17838516854681075, 0.13835220888722688, 0.09236345475073904, 0.09017180360388011, 0.1954976690467447, 0.17879848543088883, 0.11042257203371264, 0.12369392396067269, 0.2443742533796467, 0.19036502024391666, 0.1307536705280654, 0.22233503521420062, 0.15629104629624635, 0.08170908622560091, 0.1053246260562446, 0.16172177129192278, 0.07024770631687716, 0.1457018606015481, 0.1262268962454982, 0.19854032609146088, 0.12259682931471616, 0.11295688018435612, 0.13682090590009466, 0.12915158149553463, 0.15402624907437712, 0.1065155430114828, 0.11560129336430691, 0.13021715712966397, 0.0781199338962324, 0.11061312587116845, 0.24092184175970033, 0.18170101015130058, 0.07062410877551883, 0.16849067760631442, 0.17955029587028548, 0.1195311063202098, 0.16429988841991872, 0.16545999882509932, 0.13067161868093535, 0.17435992282116786, 0.22098782937973738, 0.17849180032499135, 0.26002586586400867, 0.17192692524986342, 0.12958980485564098, 0.09085553683689795, 0.13661291159223765, 0.137814597110264, 0.1262009804486297, 0.16386507893912494, 0.1639692616299726, 0.09054701120476238, 0.12887582910479978, 0.16135712445247918, 0.0729061831953004, 0.2154249427258037, 0.09584710336639546, 0.16365413088351488, 0.10744831874035299, 0.18487608118448406, 0.18533680646214634, 0.1733632481773384, 0.2163122099591419, 0.12184084800537676, 0.11063054407713935, 0.06433173548430204, 0.1529069122625515, 0.21219440357526764, 0.11581402999581769, 0.16856266593094915, 0.0610584115202073, 0.11708936624927446, 0.13410779210971668, 0.10023535578511655, 0.0693486315140035, 0.176370489934925, 0.16871039784746245, 0.09581283840816468, 0.22324949473841116, 0.20167690934613347, 0.10616965024382807, 0.15662707592127845, 0.1464375961222686, 0.18039603251963854, 0.140249643009156, 0.1570332533447072, 0.10006281387177296, 0.19603363325586542, 0.09424248361028731, 0.20684768969658762, 0.12303163879550993, 0.1182456842798274, 0.1441019683261402, 0.13273309712531045, 0.12697366008069366, 0.1396303207729943, 0.07709185898420401, 0.11707735087838955, 0.12297183653572574, 0.12239141025929712, 0.17747887264704332, 0.17020622617565095, 0.10956884987535886, 0.1319580277777277, 0.24359433038625866, 0.11416252877097577, 0.09710224578157067, 0.08389197260839865, 0.1505551501759328, 0.2995320491027087, 0.14408901042770594, 0.07281633137608878, 0.257289448636584, 0.11839354978292249, 0.1948568393709138, 0.17250838311156258, 0.09638447765610181, 0.11047924243030138, 0.17781263130018488, 0.14676611521281302, 0.13468513847328722], [0.01897277899843175, 0.03744376226677559, 0.02618039849039633, 0.0558021246251883, 0.03976582731411327, 0.0335586785513442, 0.10125577173312195, 0.0419951016374398, 0.04988276959920768, 0.031876853172434494, 0.0354893349140184, 0.0463194365875097, 0.010995528245985042, 0.07079761548084207, 0.04274610313586891, 0.0165453827867168, 0.048722306673880666, 0.015275577388820238, 0.02620989329443546, 0.01028497657898697, 0.018414511396258604, 0.04785689940035809, 0.04432631736563053, 0.04425805091159418, 0.054723134671803564, 0.01768981532222824, 0.034848074792535044, 0.016180186757992487, 0.0333139664871851, 0.028038788223057054, 0.04567767922708299, 0.05651536564982962, 0.03499469348753337, 0.029287935940374155, 0.021236192114884034, 0.017982633398787584, 0.003026266249435139, 0.024734414655540604, 0.0261916253293748, 0.05031189793953672, 0.015688309831602965, 0.02706897746975301, 0.03399232657102402, 0.057297433450003155, 0.0537822324258741, 0.054613886823062785, 0.06560566907864995, 0.10610350262140855, 0.04734660979011096, 0.06947870773728937, 0.009221129221259616, 0.0338383606140269, 0.03079895603150362, 0.0795071192260366, 0.0718536545173265, 0.03233738178096246, 0.06806666788179427, 0.057506489029037766, 0.05015816575905774, 0.020296720358601306, 0.003951200724259252, 0.024262742699647788, 0.08194724141503684, 0.03616412155679427, 0.03177074089762755, 0.030044076811464038, 0.03246554326324258, 0.05206993817409966, 0.04704066683189012, 0.028146729891886935, 0.013614451436296804, 0.09885440449579619, 0.04515568965871353, 0.02409640514088096, 0.08427837179624476, 0.02658000976225594, 0.007390866885543801, 0.10252061401843093, 0.04876612307270989, 0.018964956761919893, 0.02704026748688193, 0.032083589539979585, 0.01824198061513016, 0.042360078732599504, 0.05838946293806657, 0.03527598972141277, 0.02371536425926024, 0.012288040579733206, 0.032165262891794555, 0.0428751997242216, 0.039555487819598056, 0.06280582048930228, 0.06715477618854493, 0.042724410159280524, 0.018929027537524235, 0.021536619060498197, 0.054917054148972966, 0.015937497046252247, 0.0391665764618665, 0.019524183589965105, 0.06682791950879619, 0.07379118687822483, 0.03733219520654529, 0.04516037632129155, 0.04098417404748034, 0.026045941740449052, 0.042223230411764234, 0.10322773232473992, 0.05118518682138529, 0.02029895236773882, 0.015652757247153204, 0.025178482428600546, 0.06161369754408952, 0.015240540597005747, 0.02824013659846969, 0.08715279138414189, 0.05024730882723816, 0.013621221678477013, 0.020720358661492355, 0.0617550581227988, 0.06257520552026108, 0.060245255153859034, 0.004012839335700846, 0.02462885528075276, 0.02971789363073185, 0.05434620899904985, 0.025931326308636926, 0.017591853684280068, 0.04500934184761718, 0.019583627763495315, 0.06352292810333893, 0.04090697955689393, 0.05367019781260751, 0.07272447575815022, 0.03035868619917892, 0.052573314678738825, 0.06556014574016444, 0.0662945825024508, 0.015068888333189534, 0.08494607463944703, 0.02569185566244414, 0.022851027533761226, 0.037642019597114995, 0.049708876977092586, 0.03494039054203313, 0.047716088010929525, 0.034797478874679655, 0.07925524172605947, 0.005836075852130307, 0.023900392807263415, 0.04692514783528168, 0.07443278838763945, 0.0404873655497795, 0.026336819100833964, 0.03988449301687069, 0.037451187454280443, 0.03736537662916817, 0.01647303823119728, 0.021055588622402865, 0.029410316092253197, 0.03555564951966517, 0.05792682663013693, 0.08417495351750404, 0.04403224134875927, 0.10481313045602292, 0.011494197678985074, 0.03807446533755865, 0.021901592444919515, 0.08118746030959301, 0.00997654835373396, 0.017066442815121263, 0.09467980155022815, 0.05839827594172675, 0.03365159544046037, 0.03324865007016342, 0.0457138849014882, 0.06767816099454649, 0.06299745044088922, 0.035031170045840554, 0.08047991155763157, 0.02797361095872475, 0.007227152354971622, 0.011390162489988143, 0.035026156838284805, 0.033955226608668454, 0.04920023122394923, 0.03089809397351928, 0.011496680162963457, 0.028923511745233554, 0.0231097773212241, 0.026406258148199413, 0.024942622330854647, 0.017995030975725967, 0.05518865422345698, 0.06793297739932314, 0.028510569645732176, 0.045625758575624786, 0.05131561185407918, 0.045792730670655146, 0.102420030743815, 0.044734238836099394, 0.01757773061399348, 0.009200273943861248, 0.008948019803938223, 0.0604969248524867, 0.03059523834963329, 0.02517942866688827, 0.009121626699197805, 0.009158814791589975, 0.006168650315885316, 0.029446518055920023, 0.0859599671093747, 0.035331721301190555, 0.0218314594894764, 0.026198332489002496, 0.05973742205242161, 0.01133918900450226, 0.08556083266739734, 0.03989199241914321, 0.027081432563136332, 0.029407020956568886, 0.07426301468512975, 0.021046582660346758, 0.041815383156063035, 0.03587800878449343, 0.01585108879226027, 0.04175978516286705, 0.009338734580524033, 0.013408850554696983, 0.05055235007603187, 0.0505821769911563, 0.0429792859358713, 0.06668211717624217, 0.04080097860423848, 0.020239797631802503, 0.03866866587486584, 0.0072499344332754845, 0.04145307779253926, 0.07529707872890867, 0.014592521365557332, 0.02451839030982228, 0.02925376746134134, 0.03009718860994326, 0.05566759922658093, 0.032065273335319944, 0.06919686973560601, 0.016514485323568806, 0.07203982226201333, 0.03937790301279165, 0.01685294548224192, 0.09998445049859583, 0.08841324015520513, 0.06634654026129283, 0.047841028572293, 0.09548026719130576, 0.027253653497609776, 0.03986630297731608, 0.0393934287421871, 0.04117342170502525, 0.0625523399503436, 0.06302237918134779, 0.01785268705134513, 0.03993029094999656, 0.05204986679018475, 0.009782258730410831, 0.011196745817869669, 0.0029879920703024254, 0.04521269031101838, 0.06651787247392349, 0.04662396946514491, 0.07014842922217213, 0.021949514775769785, 0.057028134033316746, 0.02932653318566736, 0.049683788674883544, 0.030671557105961256, 0.0341556213243166, 0.014660280376119772, 0.01645760527026141, 0.025345237445435487, 0.020037243266415317, 0.01621413630346069, 0.047514424222754315, 0.10642126057064161, 0.06493415901786648, 0.010835982266144129, 0.0262226099948748, 0.027238996080996003, 0.0740406227123458, 0.019537670268618967, 0.028769278615072835, 0.028964263074158225, 0.03876101131027099, 0.0709040839865338, 0.06692197930533439, 0.06008597541949712, 0.008384500579268206, 0.04358026970294304, 0.02553047193941893, 0.023033503093756735, 0.018239171586174052, 0.03378646222699899, 0.06272293743677437, 0.03586952974728774, 0.04053419135743752, 0.07220900966785848, 0.07995789230335504, 0.04040029307361692, 0.06682147024548613, 0.05873227579286322, 0.024266625987365842, 0.0238070881459862, 0.05126488606038038, 0.011233881959924474, 0.07960893446579576, 0.06064266781322658, 0.01827703781600576, 0.007539923999502207, 0.06519058588310145, 0.05712397127354052, 0.03950958969653584, 0.023678934085182846, 0.0655929338245187, 0.024464755297231022, 0.0282382088698796, 0.03330127947265282, 0.0636836550256703, 0.039355683111352846, 0.00728933458958636, 0.019590993579186033, 0.048460773832630366, 0.017222460810444318, 0.01404813841872965, 0.007887171650509117, 0.03760362829780206, 0.04798781425051857, 0.028114275773987174, 0.005938405956840143, 0.043590567001956515, 0.015489574743696721, 0.14427790185436606, 0.08999890545965172, 0.043677461362676695, 0.025139972385659348, 0.03748557486687787, 0.021322034481272567, 0.06363353037158959, 0.04481689553358592, 0.04375942786282394, 0.04024941074021626, 0.040229858859675005, 0.008273540224763565, 0.12789649103069678, 0.11534855497302487, 0.10778448195196688, 0.08643408815260045, 0.08847688673995435, 0.12685883499216288, 0.12958511448232457, 0.21638986829202622, 0.10609936143737286, 0.135188908316195, 0.12291380800888874, 0.09298789780586958, 0.08164378465153277, 0.1827324618352577, 0.13102535594953224, 0.06472993482020684, 0.14657269668532535, 0.1203254640859086, 0.14302010997198522, 0.09476987601374276, 0.07953843043651432, 0.19235771644162014, 0.1268548719235696, 0.21002863853937015, 0.11391095555154607, 0.10834575339686126, 0.07977732035215013, 0.07411640341160819, 0.27164415805600584, 0.1025130292691756, 0.18393301928881556, 0.16402245877543464, 0.20483246189542115, 0.10119809201569296, 0.19844378752168268, 0.14367668802151456, 0.10185953113250434, 0.06647800430073403, 0.25815782079007477, 0.19990534347016364, 0.1187240207218565, 0.23061412299284711, 0.11382131153368391, 0.19045136170461774, 0.1349837044836022, 0.10523412114707753, 0.20244936633389443, 0.18069507350446656, 0.11814876721473411, 0.15544844151008874, 0.12297161389142275, 0.0613504206557991, 0.06863691931357607, 0.22479841631138697, 0.14326421718578786, 0.09543230218696408, 0.2931373188039288, 0.15471536287805066, 0.1260973617900163, 0.17576782149262726, 0.13988507038448006, 0.1555925072170794, 0.1569454127456993, 0.14382391527760774, 0.10795371388667263, 0.09534766024444252, 0.16373333288356662, 0.17010005452902988, 0.11839160535600968, 0.10595866508083418, 0.12700013990979642, 0.31078757951036096, 0.13820662919897586, 0.08379006831091829, 0.2703936689067632, 0.13118466536980122, 0.2018145628971979, 0.17415403621271253, 0.11150283477036282, 0.14097855077125132, 0.203583991387859, 0.1423417721525766, 0.16237278323387727, 0.17669127584667876, 0.18032625579508021, 0.14518743351800367, 0.11340038021444343, 0.11738221772247925, 0.09836228637141176, 0.14873151521896943, 0.0806545685918536, 0.17786777287255973, 0.21879626729059964, 0.1774326220038347, 0.18520761339459568, 0.10519220464630052, 0.1788575158570893, 0.14125448127742857, 0.10244046206935309, 0.12402923370245844, 0.15993156266631559, 0.17473037325544283, 0.0962288270238787, 0.19232761493185535, 0.09776353646884672, 0.0785600052040536, 0.15433548716828227, 0.22368234494933859, 0.2273424985469319, 0.05972372200631071, 0.06548757854034193, 0.08740193035919219, 0.1396143200690858, 0.17761293420335278, 0.0780579645652324, 0.20951201469870284, 0.1683765946654603, 0.16555975831579417, 0.13524833950214088, 0.15586346533382311, 0.15807730669621378, 0.12893315259134397, 0.06299435568507761, 0.1227007967827376, 0.11362910270690918, 0.17688632709905505, 0.15170967963058501, 0.14327809534734115, 0.10760361314169131, 0.12398782928357832, 0.12311405429500155, 0.11359830357832834, 0.17873540287837386, 0.15765192249091342, 0.08074427940300666, 0.13364696293137968, 0.1705268191290088, 0.16147708520293236, 0.1354149664985016, 0.2783822949277237, 0.085857120284345, 0.1510783494450152, 0.12831896601710469, 0.11850415205117315, 0.08809425024082884, 0.16688223578967154, 0.1657968299696222, 0.14997189631685615, 0.09339860975160263, 0.10071925091324374, 0.17423688957933336, 0.1393711776472628, 0.09512666350929067, 0.06975407421123236, 0.19232567050494254, 0.13209694297984242, 0.07591658650198951, 0.13934281276306137, 0.095752702181926, 0.10578675399301574, 0.09679800976300612, 0.10386251349700615, 0.1803429244318977, 0.14020742964930832, 0.29243373312056065, 0.22634552704403177, 0.14092409197473899, 0.14964857226004824, 0.2305411105044186, 0.0996087233943399, 0.12022016817354597, 0.1786884100874886, 0.11707741025020368, 0.11309387322398834, 0.14756704098545015, 0.12554000888485461], [0.025759088675840758, 0.006390233811544022, 0.013385392194322776, 0.034358598713879474, 0.07301501915208064, 0.041846998647088185, 0.017873452343337703, 0.030391797117772512, 0.01727402523101773, 0.0603742923703976, 0.015208691329462454, 0.04129872591875028, 0.00812827409390593, 0.044153864510008134, 0.06598413470783271, 0.04135862094699405, 0.014311313261714531, 0.02781801413220819, 0.0429304637509631, 0.003995043562099454, 0.017553024517837912, 0.0219961216498632, 0.013569871553045232, 0.02556220060796477, 0.03345997291035019, 0.03584055259125307, 0.01359625304758083, 0.0158164676031447, 0.07135552499676123, 0.03302845114376396, 0.056968539574882016, 0.08285870266263373, 0.0465127141069388, 0.05173164128791541, 0.019164110235578846, 0.02940194281109143, 0.06759722979040816, 0.035883786404156126, 0.10852749794139527, 0.03754966674023308, 0.0304263255384285, 0.015237260304274969, 0.047762049216544256, 0.011405074092181167, 0.048765718602226116, 0.05171310986042954, 0.03402569353056606, 0.04585075548675377, 0.04661707120249048, 0.053944232131470926, 0.038288359719445, 0.009690030183264753, 0.024545400774513837, 0.05068248567113187, 0.009446881267649587, 0.040795316017465666, 0.02988477295730263, 0.03355487504450139, 0.03804432300967164, 0.09284612533519976, 0.04113873372261878, 0.019026100453629624, 0.0514215756993508, 0.028017091535730287, 0.052102477638982236, 0.046296734290081076, 0.07804965993273072, 0.056396852087345906, 0.020072858933417592, 0.013998275371704949, 0.042784728211699985, 0.044913871970493346, 0.041989194141933694, 0.026399510170449503, 0.022024048666935414, 0.027849609214172233, 0.042078763945028186, 0.039968648852664046, 0.02135567418008577, 0.046774755319347605, 0.02149394556909101, 0.09425378651940264, 0.06109711823228281, 0.020638868991227355, 0.046823217562632635, 0.032796978994156234, 0.03887749138812069, 0.024608858111605514, 0.05722722256905399, 0.0029008316960243974, 0.03987056661571842, 0.027609539283730555, 0.046362340144696645, 0.06285467607085593, 0.003105863211203541, 0.02692062214919133, 0.045867494627600536, 0.05698022469005082, 0.049380851414753124, 0.03826629195827991, 0.1607866058475338, 0.023299854328797664, 0.07725825591478497, 0.0009373537363899231, 0.04390266978589352, 0.029976903169881552, 0.024850801964930724, 0.024581363395554945, 0.029743143350060564, 0.02648476995091187, 0.019681607955135405, 0.03740588676009793, 0.009062609260581667, 0.03260633609897923, 0.026342004857724532, 0.05229143956967164, 0.08382790299947374, 0.06909891366376542, 0.05822843544592615, 0.059573982580332085, 0.0478755978110712, 0.04403923237987328, 0.009507562972430605, 0.052767723973374814, 0.010234753590339096, 0.0552666205476271, 0.03918931586667895, 0.0199808103570831, 0.02690105357032735, 0.03924481738067698, 0.04085983462573495, 0.04889861127594486, 0.0731117655232083, 0.030184982824721374, 0.03288873071142007, 0.027823895652545616, 0.020106431838939898, 0.01685555969743291, 0.06581426452612504, 0.04686055130150635, 0.06640315870754421, 0.06560435547726229, 0.02440242787997704, 0.03524362466123421, 0.06557530781719834, 0.032825692687765695, 0.04016211561975069, 0.009177939009532565, 0.02090155401674565, 0.04502294170379173, 0.022046999583835714, 0.030595262469432782, 0.025069034199987072, 0.12226669234223664, 0.03264778875745833, 0.006864551987746381, 0.07998376357136294, 0.009823708605836146, 0.026601750978443306, 0.10380769104813226, 0.03412519326957408, 0.021598486346192658, 0.030521340850100387, 0.0311540235998109, 0.049468035213067196, 0.03982611568062566, 0.06560644833371043, 0.034641386664588936, 0.02538088650908321, 0.04000554472440854, 0.020498655030678492, 0.03571651002857834, 0.02453173783578677, 0.021069075301056728, 0.050956657287315466, 0.008949973507696996, 0.02439502681227168, 0.05557336502533872, 0.04488941820454784, 0.07641766977030784, 0.06447502193623222, 0.022199097184056882, 0.03786161738389637, 0.01979168886464322, 0.014877863231959054, 0.052625621246988885, 0.03735787722689565, 0.023627887312613893, 0.015878145641181618, 0.023893689358374104, 0.025317325271316804, 0.0738369848113507, 0.08307440046337433, 0.019614853626990225, 0.04467292259505484, 0.049770809200708754, 0.013534072204492986, 0.030250451382016763, 0.03887234830472153, 0.05156629078555852, 0.03044506662263302, 0.019279747975815553, 0.05293011330650188, 0.038353861673385836, 0.013038090273767011, 0.018080134905176237, 0.010977972742693964, 0.03741720080142841, 0.08502178854541853, 0.012528043716883985, 0.018865432903112378, 0.023445113038178533, 0.03870394386467524, 0.029636732360813767, 0.042804513868759386, 0.04221065100864507, 0.037726813679910265, 0.04207994767057244, 0.09234280078089796, 0.03436003848037217, 0.06677609533653595, 0.07704891831963323, 0.07682485651457682, 0.02966037718579173, 0.07646441765245982, 0.005341779988157214, 0.08143384591676295, 0.04506118828430772, 0.030997987050795928, 0.04106042972125579, 0.01823026581405429, 0.01148772707892931, 0.06578399232239462, 0.015052108374220552, 0.022628937986155506, 0.04719668853795156, 0.030680917443532962, 0.028400284645613283, 0.027426167580415495, 0.035433499433565885, 0.029825026358594187, 0.03602696153393481, 0.040490196843165904, 0.0247782143560471, 0.07393332300125621, 0.04811465470993426, 0.016024825563363265, 0.031089575495570898, 0.008454217004327802, 0.02996464289026335, 0.019643611849460285, 0.03268837681389414, 0.022586453742405865, 0.013848620365024544, 0.0478911124082515, 0.025737143369042315, 0.031865928758634254, 0.03897981870977674, 0.02963938553875778, 0.03717520128702745, 0.08985906999441795, 0.04589468320773449, 0.017833021993283182, 0.023117720156733412, 0.11189690776518546, 0.03811438175034709, 0.03625507917604409, 0.010727936696639517, 0.05164541114936583, 0.01378448952891631, 0.025616312450438272, 0.03110151294094976, 0.04941336119372863, 0.025941994681488723, 0.04780544630193617, 0.06141974838101305, 0.11396686895750463, 0.01609478596947156, 0.06481233547674492, 0.06240122384042479, 0.04724709149741102, 0.06607129995245486, 0.01006469787171227, 0.03546558247762732, 0.03633353902841918, 0.011099947496404639, 0.053364017367130145, 0.04172204324277118, 0.04005845985375345, 0.011157932422065642, 0.011220330343348905, 0.012148014011472696, 0.026328366038796958, 0.04080312712176237, 0.05275930801872164, 0.020656435626733582, 0.037375610845629126, 0.02368485085753491, 0.05078870555735193, 0.059570115990936756, 0.03911165382305626, 0.04369228205177933, 0.026620080170687288, 0.016740703067625873, 0.013258072121971054, 0.030495853643515147, 0.07069699509884231, 0.07155504397815093, 0.09782109002117068, 0.06521964838611893, 0.057095829033642076, 0.04104659608856309, 0.033891320272232406, 0.013121496540406952, 0.05900251773709897, 0.009252265099348733, 0.02037214297160972, 0.047074627509573475, 0.04730279710202012, 0.005370976077756495, 0.04769617247802671, 0.06902922599692829, 0.07316562318010256, 0.013215666731412057, 0.05699234396161046, 0.09718683577375486, 0.048133323434740305, 0.014721066909260117, 0.047787560542928986, 0.024708432065381203, 0.07993565013748594, 0.0314285477361409, 0.010652693126758095, 0.03768972113903146, 0.018664394374354742, 0.07822019804734737, 0.06923658205778338, 0.04323799119447358, 0.05183321532967966, 0.044858544861199334, 0.020284647471271455, 0.06515524481073953, 0.050482844235375524, 0.008698649835423566, 0.050672333090915345, 0.0437484811845934, 0.047732003367855214, 0.08017704109079204, 0.00889359811480972, 0.0075668890076485695, 0.026323070815124083, 0.0256921747859451, 0.13003285217564553, 0.12458544370019808, 0.18670131918042898, 0.1778737545828335, 0.20993714657379314, 0.09870828303974122, 0.0901162538502831, 0.10986869237967767, 0.12656574603170156, 0.13674094690941274, 0.1593596488237381, 0.11111858038930222, 0.1137350220233202, 0.2029155835043639, 0.1478305776254274, 0.1640091446461156, 0.21642314619384706, 0.08778015850111842, 0.1453340076841414, 0.15777534164953977, 0.10141997190658003, 0.1231668506807182, 0.15257140214089304, 0.14588724909117445, 0.13617249147500843, 0.1099529632483609, 0.1368925825227052, 0.10444958199514076, 0.15060601697769016, 0.12546678859507665, 0.11751839439966716, 0.2097380580380559, 0.13776994950603694, 0.122260547359474, 0.1105614575499203, 0.17463542288169265, 0.11076200811658055, 0.07071019790600985, 0.22131473058834672, 0.1817110291449353, 0.26008295186329633, 0.14511341170873493, 0.18543710029916838, 0.0971431381185539, 0.2131078389356844, 0.17366157670039684, 0.13371785287745297, 0.13125689118169248, 0.23685025633312762, 0.09199866690323688, 0.15926783031318337, 0.12670292460825294, 0.08148319873725995, 0.14893208805005997, 0.09730800622492097, 0.14925193885574117, 0.1711985666770488, 0.08184869162505493, 0.08790075749857351, 0.12201984660350718, 0.09017893564305268, 0.07956439076224342, 0.137123242020607, 0.14426544861635193, 0.10731433139881119, 0.14307324774563313, 0.16656109364703298, 0.14073653641389683, 0.18295567017048597, 0.11266223271377385, 0.16715565783670172, 0.18217791424831375, 0.13826269103446975, 0.12305006632232107, 0.10007911885622889, 0.13985614146804437, 0.16129356692545116, 0.20339012757176533, 0.22877862851601094, 0.12584688694914803, 0.11969992265221663, 0.15972719003912061, 0.14115121884969994, 0.29645786562468857, 0.20305118872784078, 0.07911320950370282, 0.15852149692364037, 0.10026905671111308, 0.1573887123959139, 0.09050008520716801, 0.18327639671042562, 0.13985195575514808, 0.22909827152034268, 0.1455609267577529, 0.1903705418226309, 0.17837314575444907, 0.15574178280076012, 0.20026328129461035, 0.13595594762591645, 0.18023326469119638, 0.35454330034554005, 0.227234382473398, 0.1620237363385968, 0.146927680762019, 0.1441362258628942, 0.13976184418424964, 0.10344872163841501, 0.11364791615051217, 0.14695053891045973, 0.16860857518622652, 0.10009045887272805, 0.16782896389486268, 0.12796629744116217, 0.1122944762755651, 0.10725262924097478, 0.1574052919750102, 0.16812622372526675, 0.19088729924988002, 0.17867283982923254, 0.0955491978675127, 0.1758367521688342, 0.15506956027820706, 0.0768254799186252, 0.1828369710710831, 0.13495536928530782, 0.16580619587330148, 0.13599240191979334, 0.08029312040889636, 0.1431749961921014, 0.13698319875402376, 0.23005258437478915, 0.2416072745108977, 0.18108554708305746, 0.1971071943989955, 0.09770706645213068, 0.14017422596225515, 0.13125421945005655, 0.16437836311524734, 0.2080844045849517, 0.20443986577447504, 0.17253213183721527, 0.17881945852423087, 0.08959919214248657, 0.15093610942130908, 0.1438686074106954, 0.1980885214288719, 0.13228363764937967, 0.12657526036491618, 0.20365369389764965, 0.17657815769780427, 0.10395804274594411, 0.1540470588952303, 0.180996103445068, 0.1871444407152012, 0.2247403803630732, 0.14696826139697805, 0.15527412586379796, 0.17172408144688234, 0.12830309889977798, 0.2749197604134679, 0.23657261888729408, 0.22264060709858313, 0.15677986928494647, 0.1440907025244087, 0.1332367185386829, 0.2090475638397038, 0.161369206616655, 0.09985706827137619, 0.20183512038784102, 0.17148931045085192, 0.2912858087802306, 0.2977238211315125, 0.2450156767736189, 0.09339008247479796, 0.16058242617873475, 0.145826882799156], [0.026132311031688005, 0.01227219108841382, 0.019640498539956752, 0.026135570915357675, 0.028957676513527986, 0.04753275527036749, 0.014235276521503692, 0.02417843286821153, 0.02797672426822828, 0.009457185060455231, 0.08542035895516165, 0.02909991282649571, 0.06134711809863802, 0.025298780856246594, 0.02308436804014491, 0.016928930272115394, 0.023523149866377935, 0.04220728907966986, 0.04716172225016635, 0.02377850247285096, 0.048268616956193, 0.02135156453732634, 0.007851931695768144, 0.012720862960122759, 0.020622113152057864, 0.06348105613142252, 0.03419240216317121, 0.010166079882765189, 0.06452910965890624, 0.05371536492020823, 0.015640281744708773, 0.07212927332147956, 0.06178081806865521, 0.059671857015928254, 0.08067238013609312, 0.021738559298682958, 0.04889409901807085, 0.021228432960924692, 0.0026600469846016495, 0.03443453897489235, 0.08305989147629589, 0.04994220820663031, 0.03391855338122696, 0.035969304080936126, 0.04687517532147467, 0.014039178840903332, 0.06517968373373151, 0.032210155404754914, 0.029476079653250054, 0.023052865726640448, 0.05383273928600829, 0.06335282043437473, 0.011724233772838488, 0.010149976205866551, 0.02492749921657378, 0.026682561583584175, 0.013169770463719033, 0.017021425992425065, 0.015896055519988295, 0.0395500330341747, 0.023964827923919074, 0.027851572194776963, 0.02615398359921528, 0.02323366959899431, 0.0511543097672984, 0.03152233664877713, 0.017326647212030366, 0.03792197996517643, 0.012678626408160198, 0.05671514809364453, 0.014963870726205641, 0.039807654757169075, 0.025304601149400696, 0.05352198721084278, 0.0114138973003719, 0.008170236978912726, 0.05893036985071376, 0.024466490067425184, 0.071973986341618, 0.030451957463810686, 0.10255320172291249, 0.056586006976431236, 0.06780497918953188, 0.032595270677120425, 0.014046995511307614, 0.10032597943791188, 0.009546262263029348, 0.012596690521604614, 0.04623999338946305, 0.013196011877880665, 0.05448974778119009, 0.04986252752132714, 0.0170845604952774, 0.04010016484244261, 0.03403186077775899, 0.04923932756355498, 0.07202111271908507, 0.032020922590163536, 0.05560280231293291, 0.07475994192645885, 0.024185921138268895, 0.05327386868884787, 0.0400119271944277, 0.025252387349610217, 0.03931971492420416, 0.05414091981947422, 0.07040106371277943, 0.028539327868202236, 0.01638197856664192, 0.01559018677653512, 0.03554309609171469, 0.023054741504893173, 0.029406757494143676, 0.0326382336061215, 0.02511125127057312, 0.0282369917476899, 0.025426417269045487, 0.022590804583160207, 0.05212812626268715, 0.06768472158000804, 0.011207115476281615, 0.026152829559578095, 0.03417465741222259, 0.03410837991395965, 0.021510237565962598, 0.05841539728862699, 0.012741063292196486, 0.07017329116933979, 0.016268057042907458, 0.07577068026876077, 0.08531913001206703, 0.03565562052244786, 0.028727471581078134, 0.015457203189725988, 0.07111712489859201, 0.03963181399740279, 0.09655671528889798, 0.02204887907282682, 0.04369870533992071, 0.03283214566181414, 0.07474327328964137, 0.023388329464069102, 0.021140236131031998, 0.032077589276013896, 0.08331534612807445, 0.0474373633187497, 0.01839612283220049, 0.028330815912340768, 0.014857232454232872, 0.023859891953179613, 0.05840735240781214, 0.013611698068416445, 0.031165530599537306, 0.01574089841597015, 0.00023198785527256405, 0.03604384168284014, 0.037837256386410445, 0.014524220587190939, 0.020021647032990586, 0.01401837551384233, 0.05373960346332751, 0.06494236717117019, 0.0316571032453794, 0.05893600275157951, 0.01698553387541324, 0.014909673536749324, 0.06683677333057858, 0.05188430106500164, 0.021148483247088734, 0.04139125318033621, 0.006198599685376394, 0.050805808350560255, 0.021596784972643945, 0.0573762124258792, 0.01803837611078052, 0.019633939809864387, 0.030906765969120897, 0.02822706737788394, 0.02292047400260344, 0.06101347447838634, 0.013513445137505187, 0.04915020675980486, 0.07722170514171012, 0.056218380414065905, 0.0532850380113814, 0.017537582280056085, 0.05687206037691794, 0.037388783966889605, 0.06321250257315114, 0.04534506719210185, 0.05920334660913795, 0.016352570964954793, 0.0228715497723897, 0.05142052184964996, 0.04790716135175899, 0.06359383289236575, 0.054730997726437636, 0.057842002861434594, 0.042584374314174056, 0.04688510896812659, 0.05212917269091122, 0.055696372292004526, 0.009496298098383704, 0.019513210936565883, 0.02192576605011709, 0.049133987122331746, 0.015556890321022365, 0.041546150532667525, 0.05283666949253529, 0.07532527291914448, 0.0522445729438914, 0.01068579476850573, 0.02930563801783137, 0.017485236749053, 0.010550481765676523, 0.011614201102929655, 0.09402427735039964, 0.021270698271109723, 0.07731365723884664, 0.0510259219299769, 0.0467501902312506, 0.06588842734345235, 0.06704947285470553, 0.06591045428649522, 0.02708988933591172, 0.04188525635981932, 0.008834895161271561, 0.023013836180325598, 0.043707288277801126, 0.04589971125824377, 0.005396664128056727, 0.03672802762594074, 0.06735756804118864, 0.027959799590462353, 0.023467329228878953, 0.022011853325238917, 0.03209556409274228, 0.028806920345232356, 0.024748634205025155, 0.02979296557896305, 0.010124820182682015, 0.03175293677486479, 0.04231466671626549, 0.01657825992879225, 0.00260049867847556, 0.048406055284431204, 0.032436514156870544, 0.08665112924063578, 0.025994533170887735, 0.03727653413079679, 0.04969705827534199, 0.046780744451098144, 0.031216438219416887, 0.021009213669458404, 0.08610064120148309, 0.04123393271584064, 0.060974333609919995, 0.06349391012918204, 0.03494799755571876, 0.038362318446161225, 0.017203892275574617, 0.09264538923162036, 0.025240733775717672, 0.03833604270766955, 0.04031276788737159, 0.005638865413857275, 0.029283458934514783, 0.028810950207116548, 0.03387750890397001, 0.015623574145138264, 0.06949653412448242, 0.004374138161438168, 0.038703813988831826, 0.03226334883947857, 0.05876661125512328, 0.0409786264935974, 0.01617205467482563, 0.09459193126531318, 0.021949802357994486, 0.019068892688665073, 0.03459921783360187, 0.07719123997958377, 0.04515854692726862, 0.04231858525599819, 0.06472986802691594, 0.0608663733873982, 0.04007125447969884, 0.07177244871854782, 0.022508886322611943, 0.046329655961017124, 0.03444530382694211, 0.02150874955987092, 0.012522229917522054, 0.011082808523497079, 0.04877496947301552, 0.01153292943854467, 0.07013049893430434, 0.0373158828006126, 0.08268710327683948, 0.04145786464505363, 0.06004478251270484, 0.031521394121227786, 0.04266773976269178, 0.05253853763861116, 0.010978530281136045, 0.03657630666566547, 0.060769790288759395, 0.04273379461665172, 0.018673585873330012, 0.05507863825187087, 0.05678935915057082, 0.037746677262475714, 0.13755016989307478, 0.016487250359205063, 0.09543416497763246, 0.03011073094967287, 0.009855892767518526, 0.035756393044721335, 0.03632414714957122, 0.009847506498772418, 0.09131440674536861, 0.040948769892565906, 0.01531290927232476, 0.034295230434508994, 0.043546902743401006, 0.027270650534774177, 0.08936217243899591, 0.020426306764420588, 0.033908853511093184, 0.03268904474680312, 0.05162883157026954, 0.04252261278452352, 0.04038168000988662, 0.010622335576044861, 0.03845797386020422, 0.04591817589243874, 0.017113211106334347, 0.0230794123490341, 0.03633254083979409, 0.04641955973056611, 0.01856440296251094, 0.04827530741749797, 0.12606957578100264, 0.05264903971692547, 0.050740833321469836, 0.03305332051240839, 0.03719848617038224, 0.0940161879407242, 0.11992958025075495, 0.04323226552514825, 0.010001348146033706, 0.013379810316109797, 0.12514604721218348, 0.10523326025577262, 0.06697849385091104, 0.22966770658968017, 0.0671805880847387, 0.15462577081052586, 0.1484878087649122, 0.08997560202260502, 0.15440250310348347, 0.11185962226591073, 0.17523568676551804, 0.1546341273933649, 0.17746659752447158, 0.13068463595118374, 0.13364412792725489, 0.1962736586574465, 0.10404921558802016, 0.10975152952596545, 0.18551504064816982, 0.10919315245701, 0.17051065515261143, 0.14677197817945853, 0.11644179045106284, 0.13933208130765706, 0.09340054675703868, 0.17536973347887397, 0.13343101280042902, 0.1212180673610419, 0.16672414349159226, 0.11517391278175637, 0.08604278336861171, 0.19431774329859763, 0.11489804164739326, 0.23913448298117146, 0.16779096593381837, 0.12308107325225137, 0.132452565303538, 0.12388545001158491, 0.08479886222630739, 0.09987506535253488, 0.21949220885289833, 0.1371349234250374, 0.1239055251062382, 0.1379123528022319, 0.1717185153393075, 0.10835845896508545, 0.13811239128699526, 0.13490561570506543, 0.17855862330179662, 0.1508544583339244, 0.22301338787656277, 0.1083615908282809, 0.12562443560454994, 0.25245803757570684, 0.061135179275879636, 0.11418348702136427, 0.11859230435220525, 0.08815736990072764, 0.09179916276480071, 0.1704883313504979, 0.10705086897360161, 0.161368761328049, 0.15797903150087222, 0.10539780923863873, 0.11952704677241854, 0.11967687896685675, 0.08583427697885782, 0.15547734074061736, 0.051729745100601576, 0.12617678643437102, 0.14895694999722764, 0.1565690548159182, 0.10962975793518126, 0.1104229134216439, 0.10377586033428088, 0.1628112737671472, 0.08628418174339458, 0.19397203606786206, 0.13240909029264003, 0.14223502163076773, 0.17878735321573913, 0.1301208115182817, 0.11842210020404309, 0.13090591470245272, 0.11414797525503673, 0.24440520093776286, 0.06191304652020335, 0.2417532549588941, 0.12414785116561688, 0.16271817876258865, 0.15968500636518002, 0.1200517600227613, 0.13111635809764266, 0.10652095326804556, 0.15087837033206597, 0.13970978994620964, 0.19246060779551044, 0.1524412294384092, 0.12004827192868106, 0.14764999825274572, 0.13862463645637035, 0.12895914260298014, 0.1794097331003286, 0.11399064736906439, 0.11739710520487279, 0.23036732920445502, 0.17084773862734437, 0.17993471352383494, 0.10540054776356556, 0.13752585713518783, 0.12316777094383724, 0.13672700937604532, 0.09347399711259641, 0.08020186593057588, 0.09198724525049329, 0.09019250952405855, 0.08036481187446043, 0.17871727963211015, 0.15867991576669738, 0.12695025274297222, 0.09652396431192756, 0.12058879292453639, 0.09819643120863475, 0.12114716999349184, 0.14437970967264846, 0.08495115835103206, 0.16279997827950865, 0.11796876671724021, 0.0681265740422532, 0.1569163502426818, 0.1665837291511707, 0.18973780155647546, 0.1860828578355722, 0.15020930935861543, 0.1636721205431968, 0.11839838858577423, 0.38284471607767045, 0.09137403088971041, 0.14440093509620056, 0.09148275552433915, 0.1205574520281516, 0.17439345305319875, 0.10995982811436988, 0.15606377099175006, 0.20190468931104988, 0.1445042123668827, 0.15191629354376346, 0.0959374153171666, 0.13063866732409224, 0.13540353742428124, 0.17372684116708115, 0.22211524075828493, 0.10028525779489428, 0.12308321805903688, 0.12371944641927257, 0.1268135491409339, 0.25084327266085893, 0.0561788536288077, 0.09556706878356636, 0.07336191381909885, 0.17278003884712234, 0.12597257707966492, 0.07779794570524246, 0.14982817199779674, 0.08289624791359529, 0.07254301322973333, 0.23910018091555685, 0.1859940227586776, 0.1057383585430216, 0.09353276778711006, 0.11780754255596548, 0.11012870381819084, 0.1803334546275437, 0.1767220749752596, 0.08443699101917446, 0.10864730284083635], [0.04952042341756169, 0.014896917873556959, 0.028303133804001845, 0.03571438377548475, 0.03130124714516569, 0.02448424966132734, 0.024255644057120662, 0.026153920516662765, 0.014952180044929264, 0.016531855289940722, 0.03349432321556378, 0.025480440053797793, 0.010889872391999234, 0.046434911055257544, 0.014190433175826911, 0.031575938264722936, 0.045261839040904306, 0.07165029121097177, 0.018626262826728635, 0.008928383504098747, 0.05069111313787289, 0.0846449556411244, 0.05070457198598888, 0.06506505902507342, 0.03283050922618713, 0.08355043624760583, 0.034015774726867676, 0.018607026358949952, 0.08883431990398094, 0.04577465195325203, 0.0801787331874948, 0.040286180446855724, 0.031163563908194192, 0.016794653492979705, 0.021392204544099513, 0.058041488446178846, 0.08914894599001855, 0.048441941835335456, 0.02497473506082315, 0.02590619718830567, 0.12514408794231713, 0.055417272815248, 0.041225346067221835, 0.05019678341341205, 0.02049409824394388, 0.04032522483612411, 0.07510688854381442, 0.03529610563418828, 0.009046526920428732, 0.04396115844429005, 0.034238300286233425, 0.022171259224705864, 0.045154320396250114, 0.07454411053913645, 0.08418411904131062, 0.026939042254525702, 0.027582883194554597, 0.025601410125091206, 0.05137069776537828, 0.021042495282017626, 0.03255900934163947, 0.06722579972120002, 0.010371386688348139, 0.05246411878033541, 0.032490509111084975, 0.0323315744753927, 0.05184410263609607, 0.018679587992664892, 0.03653851650597062, 0.0526214132696623, 0.0383503067860147, 0.04215697888866998, 0.028836023666372057, 0.061859081251895986, 0.033182450497406535, 0.03577831979782786, 0.01190968348964816, 0.03848117710731458, 0.06991846734308638, 0.03886553909978829, 0.027969627481070347, 0.04449208718142472, 0.03722988643858116, 0.02253513794130413, 0.06153234702651389, 0.016798735305201262, 0.00852207620482659, 0.039915859888424166, 0.05757796527177561, 0.033498022821731865, 0.0240248658155906, 0.035296673377160914, 0.03547798376530409, 0.04290598772058729, 0.1060943296761252, 0.030030254310986493, 0.023212204832816496, 0.045527754264185205, 0.03767731614061631, 0.049687840801198035, 0.006711521600664128, 0.005704638715542387, 0.02614512421132531, 0.043805370514746755, 0.08532718973583542, 0.025269026300520636, 0.021256118780001998, 0.047325362102128565, 0.02612339041661471, 0.03224977866921108, 0.05425540352007374, 0.03603177065087948, 0.013709887916775187, 0.04465371952392161, 0.04326585512899328, 0.05779081322543789, 0.01436374413970043, 0.06807671656133607, 0.02505103711882839, 0.025383253960171714, 0.007821106592018623, 0.03784062573686242, 0.05328308616299182, 0.015145747929636855, 0.06940715727978386, 0.07622197284945287, 0.010203333840763662, 0.017860340449260548, 0.03642936142568942, 0.018745895176834892, 0.002108701301040128, 0.06970498856389895, 0.03022188426257344, 0.08760633267229423, 0.08777270733844489, 0.054818111020722426, 0.017257080144190695, 0.04878324441961013, 0.12251750857103616, 0.005279169163259212, 0.029739831516053528, 0.03757691469218116, 0.0631357348174788, 0.030749777615710627, 0.13648895808728412, 0.0695358679513447, 0.03301073236798402, 0.06360093524563126, 0.011667153339658398, 0.025083899417950306, 0.03597507798986044, 0.03209121510735713, 0.04273894883226603, 0.025465085018367972, 0.016341568625648506, 0.006881459503347287, 0.02352445419091964, 0.03417685416934546, 0.02342944630072452, 0.020472941469051875, 0.039606117134098895, 0.025266289630963, 0.04221959017741028, 0.02500490336387884, 0.10094638520968147, 0.0393177371006459, 0.014815037648077123, 0.06697968870867044, 0.07763143003103323, 0.027951428164669778, 0.05901221760723274, 0.08893183810869232, 0.08732706250157207, 0.03944331961974967, 0.02371159971517045, 0.07302189143956639, 0.02733901532337768, 0.031062041816767305, 0.057702724006958306, 0.013278164842631668, 0.03866381222906057, 0.023104649080778472, 0.02829974218911957, 0.017620020043978002, 0.02875481415685499, 0.06772195512894541, 0.038354859862010926, 0.05136736923304852, 0.023921336214698385, 0.02510224159777863, 0.08023115107789636, 0.013639392236655112, 0.019297344297228847, 0.051390290464041755, 0.039889432009658776, 0.047043449885677546, 0.0444655776664149, 0.028484266076702625, 0.08033338934183121, 0.08040672837523744, 0.13961676915641874, 0.03464074841758702, 0.009552744922984857, 0.0635931352735497, 0.08831756247673184, 0.019537406806193758, 0.02250704579637386, 0.040615638354211114, 0.03058223592233844, 0.10209465835941955, 0.0301731808212935, 0.02659871373907663, 0.055555241779075004, 0.05491671276104171, 0.047014791853143834, 0.031145392422331497, 0.0656112797150854, 0.029721320497628767, 0.025471376575296745, 0.08298392524011433, 0.011186474494024878, 0.027483155245136004, 0.03959047266107518, 0.01940175519848708, 0.046119913895381615, 0.003901898462572717, 0.040523073985241354, 0.054551078865188174, 0.12761017045704648, 0.08851815015077591, 0.05161522429261822, 0.02778476777166361, 0.015716401976533234, 0.0375717938732123, 0.038423760852310807, 0.009253522111976054, 0.06727164960466325, 0.026153033650189172, 0.012716299679595977, 0.06813276355387643, 0.06930325660505332, 0.019303340850456152, 0.019765574543271214, 0.035712142489501275, 0.011995224358543055, 0.030096014161244966, 0.040608020208310336, 0.04486871599510778, 0.03863661993818823, 0.052038155699847266, 0.033077173138735816, 0.07361952812061645, 0.032449713253299706, 0.07321527285967022, 0.03338045920827426, 0.025959340528061148, 0.034174620304838754, 0.002122018909176404, 0.013894985113438452, 0.019867020564561244, 0.011094090095866704, 0.044573133418452926, 0.01748697894072393, 0.031075986771611497, 0.038452656372101046, 0.03288087507826276, 0.03762447893677745, 0.023810431521269493, 0.03181878382747527, 0.050893734296550974, 0.09872483293293044, 0.02321780990314437, 0.03552506932464894, 0.03294994676252827, 0.004375579783300054, 0.04700108438555617, 0.002849136703844124, 0.03701821849972475, 0.03740836553333793, 0.08819872979074717, 0.04021694177936297, 0.0404947128117783, 0.016336418120772578, 0.033309417121927254, 0.016293239968945272, 0.029204173442849424, 0.01868901697889669, 0.03398978471523151, 0.034854605692089535, 0.03919513801520225, 0.037897240472375415, 0.02368600860791048, 0.04191548403468914, 0.03892805390933063, 0.02315744732186431, 0.0627915860968642, 0.005489775830938015, 0.07456978884874843, 0.028543530279421248, 0.11186941861524247, 0.02085344800434541, 0.07644338518730365, 0.03070286831643898, 0.02144487476471113, 0.06580492830835283, 0.05590897904767189, 0.018517623539082706, 0.06492629967397079, 0.0255685459706001, 0.05231747782090679, 0.03477835372905247, 0.028755450548487715, 0.0371007156354608, 0.037484940330614336, 0.057213362961192615, 0.015573362288705539, 0.06972101895371452, 0.04994142524083145, 0.010921210505330237, 0.02242016256786883, 0.08161573146935552, 0.029801121781929396, 0.0384108586149523, 0.038404535516747274, 0.02477163892763201, 0.018259270800626837, 0.01762230214808369, 0.002326537182852917, 0.020791103888768703, 0.0427041643706616, 0.036253016005503014, 0.01946190070157172, 0.0356417794682784, 0.020033684668305796, 0.01802694889192935, 0.002345268294448033, 0.035350519901840016, 0.04746498234453611, 0.0689083598263096, 0.021233242077869363, 0.03155047888867557, 0.09097348636714742, 0.03347231853695121, 0.05871525834663771, 0.04910217867291067, 0.07515738427173346, 0.04744227262563072, 0.0761462960508652, 0.0367952736269217, 0.03362910465511959, 0.024725991279410664, 0.0632387374935206, 0.17869051778689027, 0.14022442483110353, 0.1099011761834845, 0.12667454488109797, 0.24197103077312931, 0.12132110714446753, 0.17197345790918916, 0.2117832240764983, 0.14850884123006836, 0.11540619016159326, 0.13098654162604362, 0.1251224914449267, 0.13395030837273225, 0.12120364001020789, 0.16053001570980996, 0.09785211179405451, 0.15454217529622838, 0.18701783032156527, 0.15865840832702816, 0.15184558171313256, 0.18716830818448216, 0.13456562301144004, 0.16962001856882125, 0.24159712193068117, 0.2856194518972188, 0.14303762465715408, 0.09061428689165041, 0.09860894657322206, 0.2167137266951613, 0.2265905396779999, 0.16381649795221165, 0.11790914257289842, 0.14490992965875193, 0.18689136835746467, 0.07482464236090891, 0.1162030415434856, 0.2210482253576629, 0.16429683077149093, 0.10648135226801969, 0.16817838186398149, 0.1711411541327834, 0.10311799836927094, 0.14771851332625374, 0.11245884714298882, 0.09203221197822131, 0.08081337335170247, 0.1503550077904947, 0.10583946874248795, 0.1849620367283933, 0.13616401614854112, 0.1359333418076858, 0.16296758491080254, 0.23963191488292068, 0.15100748918484896, 0.1231186704535503, 0.15017361205536872, 0.1324813606333919, 0.0928817706881091, 0.1704539402271621, 0.14901275950251147, 0.14571020234143361, 0.12333752980339341, 0.12359259853838012, 0.12922352529130876, 0.18769536662148312, 0.10311055462807417, 0.14554189809132367, 0.08137568380334415, 0.16257590905297548, 0.13309197005582973, 0.10669388109818101, 0.1963851589243859, 0.10962034008116461, 0.12259461771463975, 0.11581570724956691, 0.21205293538514525, 0.09769208249053918, 0.0966920013888739, 0.29586696764454246, 0.10803322016727179, 0.09315257295384072, 0.12790380860678852, 0.14675896090921015, 0.11812010547146201, 0.20844949671300128, 0.16751148796174675, 0.1815262937452644, 0.08631757096736692, 0.133661761356052, 0.1149991741112899, 0.11441373833804391, 0.1753620893578045, 0.15880204358836636, 0.1653926118160598, 0.22072669729823247, 0.08583867791458033, 0.11640283511951566, 0.1362792865256779, 0.08462162251817062, 0.15434047440066934, 0.10217712580924854, 0.18151712079998106, 0.1046326030336786, 0.24238905287347734, 0.1835437331465073, 0.22434411803260446, 0.13221495930338278, 0.11114142369478941, 0.11262053143582307, 0.19569126568967476, 0.14898089168127626, 0.1424657553434372, 0.05991508478473406, 0.10290952908690087, 0.17172281979583204, 0.1080587797332555, 0.1724825266865082, 0.11853651711135171, 0.08007520358660258, 0.1061969093279913, 0.10369748211815022, 0.13691756321350113, 0.12553606065921485, 0.22205865941941738, 0.1294237864203751, 0.21494692540727556, 0.09968627040507272, 0.1845324519672431, 0.15953096619341522, 0.19805175543297082, 0.2118237453396432, 0.17063751787645742, 0.10959918887238018, 0.17810246965382248, 0.14388060051715001, 0.20894182263873518, 0.11136184897623025, 0.17986958264373243, 0.3534648410277441, 0.08139962548739277, 0.09648831895901822, 0.14404546120204031, 0.14380182896275073, 0.12051081546815112, 0.21142908604815602, 0.1343320542946458, 0.10682777196052484, 0.18914464744739234, 0.13790813740342855, 0.09310140187153593, 0.11527831811690703, 0.08815837922156788, 0.08291233767522499, 0.12422629617503844, 0.051153671520296484, 0.08860440255375579, 0.08996575372293591, 0.14375168946571648, 0.11378021139535122, 0.1072150246181991, 0.1289579551666975, 0.14138287282548845, 0.161217778804712, 0.20378177374368533, 0.09786212336621247, 0.13718540431000292, 0.190111888514366, 0.19124538550386205, 0.12670415657339618, 0.26688114332500845, 0.13255594647489488, 0.22220974584342912, 0.20649036043323576, 0.14415874262340367, 0.07256710334331729, 0.1332051624194719], [0.008957510017353343, 0.02081172075122595, 0.05108188728627283, 0.06346575304633006, 0.02590145857539028, 0.016236794072028715, 0.02818405435391469, 0.04237040200678166, 0.031002508585515898, 0.06250894657569006, 0.06310838667559437, 0.06309709860943258, 0.02467149908625288, 0.04947114852257073, 0.038415689996327274, 0.03609828192566056, 0.016805075101729017, 0.02033202617894858, 0.03792008006712422, 0.061855934545747004, 0.04305773836676963, 0.02022278760705376, 0.08107603425742127, 0.06639349594479427, 0.02102835180266993, 0.03811166177911218, 0.014890606835251674, 0.10152008762815967, 0.009381910876982147, 0.05185732399695553, 0.050569890736369416, 0.026120306793018244, 0.01403697930072667, 0.04194640561763663, 0.031087462230061647, 0.05774126744654495, 0.006347784819809021, 0.07532455303589813, 0.0674619956407696, 0.04014979596831836, 0.06068882197723724, 0.02625731096486561, 0.04018554893264081, 0.027049924683524296, 0.07970824124640785, 0.014380198481376283, 0.02099927074596053, 0.054459779858007096, 0.07325172715354711, 0.04227781908411998, 0.04956740507623181, 0.02948850506072631, 0.0229253962970688, 0.040444729165756144, 0.03148252042592503, 0.021757125978183467, 0.039184773922897875, 0.02129364733264083, 0.0414746260503307, 0.01985062652238412, 0.007949102018756093, 0.040767841710476205, 0.02314139095688006, 0.01181078025183524, 0.037808498163940385, 0.05449286109069362, 0.032370002882089466, 0.036027918904437684, 0.05886435952561442, 0.038043580861995, 0.05015354588977061, 0.04708828673756216, 0.004011793371319072, 0.019956267533416394, 0.05749113770434633, 0.05543834609852638, 0.030309717440104578, 0.08523660319042392, 0.04423600170412101, 0.008315126469824463, 0.017073020098905545, 0.046545238728867844, 0.04732486486318521, 0.07346294980379753, 0.014190585316100623, 0.008729067685635528, 0.050439031547284685, 0.01673204777034698, 0.015448034882865613, 0.03825379790214356, 0.028709520884149242, 0.10730361478636041, 0.02792294639220927, 0.03889738836733159, 0.020095770887564868, 0.008821842639008537, 0.01382621956508956, 0.027604962087934837, 0.04537100154266227, 0.026004127284977585, 0.011792054010584252, 0.021698579803342, 0.03278388008766342, 0.010587845190457301, 0.02558900883741444, 0.03783173480769619, 0.0728318867913913, 0.051388420251896605, 0.026621948527463246, 0.01606706118764123, 0.025572073027433362, 0.04551098172669299, 0.03697074331284966, 0.03311707099783234, 0.06200760355568491, 0.012550224655569764, 0.0363831107824808, 0.02769030907074921, 0.06458055533585139, 0.057226261487812735, 0.0065992300187645014, 0.06883985217427835, 0.01566910490510054, 0.06554005580255762, 0.020045718592882622, 0.07063182711135596, 0.05188175549847074, 0.014321310918603558, 0.025665813700470608, 0.03189926974300761, 0.07066811813274398, 0.004054089295095764, 0.0342888776503969, 0.0863097413093783, 0.03573850728571415, 0.01634280244616093, 0.07377369445748627, 0.033979969812207855, 0.039098807246773504, 0.015995731519069523, 0.01412265653925715, 0.04373523755930364, 0.08627989955130033, 0.03357372559548821, 0.03887273422151338, 0.053990649757906795, 0.03220495294954162, 0.04586131253745407, 0.017973306457861327, 0.020297377159295138, 0.02882554825191619, 0.019378509277885314, 0.02760704381216783, 0.04617581616912503, 0.06125216401414946, 0.07900507116573863, 0.03978519365773536, 0.07025748782325536, 0.029578386565844994, 0.022398241380869877, 0.04823635579668917, 0.06235656139324419, 0.036741861258633435, 0.04256157553754747, 0.06085660672397353, 0.01922549883602187, 0.013842044936609454, 0.0377031243260717, 0.03549035536707379, 0.07757151644909754, 0.027097822894575074, 0.0674471007368993, 0.02365097367146518, 0.05340683928807266, 0.06940917592146434, 0.01962940899829846, 0.06018986867275089, 0.025296467210864648, 0.011097708065790357, 0.032642838632455096, 0.027600609391811304, 0.00816184143332066, 0.03201198713213671, 0.0537364641786553, 0.025411932401766535, 0.09924375743139535, 0.01660406811424764, 0.024131742502504494, 0.03161203632771503, 0.04098730962141417, 0.029865818505641073, 0.021402349702839274, 0.010633067959133768, 0.03787382571317721, 0.03540911617164966, 0.03501690225675702, 0.06012746518536005, 0.08388334143091924, 0.048466555163031444, 0.03867167157295626, 0.02785721437248867, 0.05433938495116308, 0.015978578630893026, 0.042946857793140225, 0.046970096009317786, 0.0844278626027517, 0.08203886696719564, 0.06802796488045715, 0.01592799941136036, 0.023843470080464613, 0.023752560700813774, 0.03188070491887629, 0.040707594162086025, 0.03458172170212492, 0.04011625831481069, 0.029716444587393198, 0.07113823157851584, 0.05736411170801148, 0.031851078383624554, 0.016175455566553865, 0.040332820717594586, 0.024156240797310602, 0.029317684929992538, 0.09757204010384157, 0.0680840564018581, 0.05705238741938956, 0.05537347125937231, 0.004209452808936476, 0.036957881893613376, 0.019991534391010646, 0.010159124103665818, 0.03695860919833649, 0.03477269485301804, 0.03842656245979015, 0.0708632064925041, 0.07322201898205094, 0.02556427862145938, 0.06407025459338911, 0.044276541520957835, 0.035472918607410975, 0.04702867001469713, 0.06244885487831198, 0.024668669648235664, 0.027070064716099296, 0.05089572325232439, 0.07964894364704378, 0.04794696644239593, 0.017223857903445605, 0.05391909187892452, 0.030778224136156496, 0.052382564172148705, 0.0848867918830365, 0.041479887877358124, 0.0906070064229425, 0.05596915238129441, 0.025153956303256564, 0.020165870446362533, 0.0767981911485549, 0.025505010708002374, 0.03550755463948008, 0.03083510418946389, 0.015159561153268442, 0.07772977201966569, 0.04957202123478055, 0.019892073614755645, 0.03839201177470386, 0.07492746692150831, 0.08280503796413541, 0.07114788691978902, 0.024132030084729195, 0.009714570223877672, 0.02595103589555947, 0.014761514885321958, 0.02677403128473088, 0.046909206503187306, 0.009263400097552221, 0.05444127069495153, 0.029800099473504815, 0.04719091833976563, 0.01944312436535256, 0.03540596575476229, 0.017377664298692252, 0.036304302120697685, 0.040097003293340094, 0.04471784850466065, 0.045830483722966164, 0.009317002641182626, 0.011285031705483561, 0.057139608325087465, 0.009230537798430305, 0.0049988905993814114, 0.031239418822224252, 0.01777428471541498, 0.0672214433143381, 0.05421959489467554, 0.01583706591191003, 0.02757398298854241, 0.01917041292472277, 0.038103987972135656, 0.06314061814919114, 0.04346691777755041, 0.002801437944981444, 0.0434546574979322, 0.021307334391167387, 0.048270160623360425, 0.03587362640246283, 0.017846545779320877, 0.032159225520445034, 0.034997157417819835, 0.04793919615622144, 0.045312182628549635, 0.03282479097833857, 0.0545109694940038, 0.020212490308040287, 0.03562096222594846, 0.02100422829244053, 0.03708601740072481, 0.03118100437859539, 0.06354051700327545, 0.04934555487125181, 0.027241370953561272, 0.01613223103049677, 0.051850974923581816, 0.05923205288127065, 0.015141451822273666, 0.048632139441906475, 0.041321008902741596, 0.022028228813724127, 0.022456227234215476, 0.07907521896413527, 0.0308847223277553, 0.02721009685046738, 0.015906304579402786, 0.026873415990849026, 0.045652494445675984, 0.03306789258203935, 0.08783178229350597, 0.13397159316809848, 0.03199773418600671, 0.10533351698541082, 0.010547342481004307, 0.060979176123510115, 0.016179657977772877, 0.03467594477115199, 0.03051387484447332, 0.020857609597442206, 0.009353325203846907, 0.04107979606487788, 0.03394620209292043, 0.02865396556444466, 0.070159301685635, 0.041457085389993154, 0.1267085352446884, 0.0630480055406224, 0.12021875067148358, 0.20625916658900678, 0.09262486884836107, 0.11208662297576666, 0.08636027414468117, 0.1287523060454987, 0.08565079580876045, 0.18596616253489628, 0.12660611886531115, 0.11278240868705325, 0.11091276799561456, 0.10599817702313885, 0.23921613406855613, 0.12058082967996597, 0.13114013650920242, 0.1308136954321526, 0.10485661288839765, 0.18313423090148717, 0.18632528779562563, 0.23241647315444425, 0.21083104860736057, 0.10644112044246867, 0.12205333230667748, 0.12515590293332934, 0.1580088955233805, 0.21101934631587937, 0.13360086071770638, 0.21719885378843173, 0.1533944290713407, 0.2538199973059818, 0.08855039646732621, 0.08670700553921051, 0.1987764032674022, 0.1399409689474851, 0.12349114695098251, 0.1570288449875079, 0.12570546328788623, 0.2659158763708547, 0.27448343695141375, 0.17180594033561647, 0.1361974424798973, 0.09881754202069715, 0.15657429437851533, 0.08294002720504068, 0.12496969808125868, 0.20803563063964248, 0.16893750987946987, 0.13761105568846688, 0.16093540645670146, 0.1469513404299505, 0.14838788600172848, 0.1212083526479546, 0.16224203165620565, 0.12057945670676418, 0.19909450260456651, 0.16195921401958913, 0.17387786821927875, 0.1663043996086344, 0.1106027580681257, 0.20207867841236293, 0.2069414674770087, 0.10997762481565587, 0.17385033454047516, 0.23019998974632472, 0.1893900756840594, 0.12123667300329544, 0.13089999236399308, 0.12121258288971148, 0.1551796356216073, 0.29136029072105885, 0.11966696387389675, 0.11705276352586225, 0.08758056530496106, 0.2012491354253143, 0.13899833749746904, 0.2904351591132581, 0.11524409768753685, 0.11018044635420665, 0.06391044793417677, 0.23417364136548713, 0.20301497192122042, 0.18833101610653102, 0.0936317999730818, 0.20885230478597805, 0.1168250355112832, 0.21088142559165135, 0.14259527495596558, 0.1497800659853965, 0.18722321226960048, 0.25952550990041345, 0.26224408589769155, 0.07465640490408987, 0.07189480660599656, 0.11990543818683363, 0.072082035621861, 0.08114018550259061, 0.1526577732875012, 0.10048283977084793, 0.08962114487076178, 0.07377923830063082, 0.13758928107563406, 0.11911510286154225, 0.1460015249904245, 0.19269349373644218, 0.13890451518818736, 0.19240557012381032, 0.1284336278331466, 0.11075967777287588, 0.10415826676762663, 0.1150438142940402, 0.13186880678404123, 0.1262177381431684, 0.20783673506230116, 0.21510329592274502, 0.15122124255867675, 0.37933293264359236, 0.1716538445907645, 0.07056136761093512, 0.11741245281882584, 0.14180533296894282, 0.08414096315391362, 0.1466759739560075, 0.177487748733256, 0.1136578460864257, 0.1868709592963569, 0.10504911115276627, 0.14997158461483195, 0.13815191807225347, 0.17015691788401455, 0.1107402631896548, 0.15200272406218573, 0.1752683412632905, 0.12882289913250133, 0.061337770748650655, 0.2131400629878044, 0.2514662017347291, 0.12134202086599544, 0.16743960353778675, 0.1468191490857862, 0.0889076292514801, 0.14503667363896966, 0.19268267322331667, 0.131463312136475, 0.13639838638482615, 0.15222195448586717, 0.17889825976453722, 0.08430061396211386, 0.11565282067749649, 0.1368921817629598, 0.21724774647736922, 0.17173252708744258, 0.2823936624918133, 0.11637858915491961, 0.08866242365911603, 0.11172221362357959, 0.13900488323997706, 0.1257822013576515, 0.12551090185297653, 0.17843701498350129, 0.3507502132561058, 0.11435422551585361, 0.15211946389172226, 0.12038638698868454, 0.09601485100574791, 0.059624381829053164, 0.13525207992643118, 0.24475025507854298, 0.12153142437455244, 0.1406463803141378, 0.26050754939205945, 0.06981844067922793, 0.1153056365728844, 0.1601444254629314, 0.2567997499136254], [0.03626913545303978, 0.06815338041633368, 0.041870316927088425, 0.04583443565934431, 0.022516144526889548, 0.0378675656975247, 0.03160715670674108, 0.06746707935235463, 0.04022489760245662, 0.06736037335940637, 0.016631251128274016, 0.003968799364884035, 0.025542914045217913, 0.019427834267844446, 0.12891122954897583, 0.03621530377131421, 0.047175385188893415, 0.05432640107756015, 0.012187968459329568, 0.056309211868210696, 0.10762883131974377, 0.029635203536599874, 0.016656920161040034, 0.03881905839079991, 0.023587573850818444, 0.032345845975214615, 0.06632288059336133, 0.04221946030156687, 0.036755312685272656, 0.003809941031249764, 0.030863313222653233, 0.02111188237904571, 0.009149108427664032, 0.02841189554601442, 0.06185993472172413, 0.024900908065319527, 0.04261597125150729, 0.08899512846255675, 0.04549338911601808, 0.046313339844346046, 0.01245756566277123, 0.020873454450338613, 0.04350134600827005, 0.0788909659604542, 0.06635747209656984, 0.018879771196225192, 0.025025061950145755, 0.045605364357470535, 0.023322174420172814, 0.01848864081694046, 0.03564514139725361, 0.03232213435694575, 0.03981505396950524, 0.005611673586827237, 0.0199916549900081, 0.01880492374766618, 0.06269906254601665, 0.03569484302715864, 0.014218017877283273, 0.029361608940234873, 0.07954080530907959, 0.05472993645526003, 0.06980681864661165, 0.05794899829197675, 0.015232433561322978, 0.052171538191032596, 0.059070335191790946, 0.02148913645214634, 0.010094311419379665, 0.06351211501169018, 0.0729843536100816, 0.03562755991879385, 0.039474846053053625, 0.0335531681048451, 0.029300650785444304, 0.05252311580989044, 0.002294893629368744, 0.052692399694933556, 0.03351572304381989, 0.028508150244306307, 0.03324436416733079, 0.027682997060765047, 0.03270986198913306, 0.026290470123058185, 0.01609881397598656, 0.040029226656770334, 0.02305775647982955, 0.009639619802328525, 0.07883326397859491, 0.08945344176026992, 0.041415680971113034, 0.03787316891248338, 0.08631193806650117, 0.16463121282868087, 0.020875341360806488, 0.04424433602252975, 0.026855199976125732, 0.021743112374679185, 0.07923437253339216, 0.0856713013490662, 0.012728394831356127, 0.023038035760691855, 0.024298900134454016, 0.058243630919605494, 0.008065340898610884, 0.01358769701255369, 0.08516686357324943, 0.007970986098371213, 0.03455730875430163, 0.06010440665704664, 0.028804254179704003, 0.015266616883309325, 0.0666838166944217, 0.021689714849344455, 0.03385722229722887, 0.02619104830955621, 0.034456729190424085, 0.025839990194072016, 0.058903901153826155, 0.09793383709620684, 0.08045488633797504, 0.028179892760817893, 0.043825979955727234, 0.08348672286956571, 0.009896537412714679, 0.0825610569154378, 0.04689529865572695, 0.014617343422287377, 0.05178734318178613, 0.03211283757991623, 0.038658702542306855, 0.048018015950219706, 0.014824993559159338, 0.05818807003379334, 0.0637208366242703, 0.0708088738610968, 0.028752697180607356, 0.04448635780136101, 0.02658015633642208, 0.004507035937422188, 0.1417272590333596, 0.03095153602771461, 0.030702838630531915, 0.07071646905387752, 0.03123572292679455, 0.04756435220770072, 0.06100244616391137, 0.05311641092703212, 0.034121211647288874, 0.02866243161406601, 0.04302988185372669, 0.056781002567731775, 0.035421346765360795, 0.01573953286424512, 0.06060017243726179, 0.08829612925183028, 0.02390643574472051, 0.03579448377422523, 0.05730137425416615, 0.018136154067178722, 0.07985189135069959, 0.01816474901715992, 0.04268394455721136, 0.06264696377911605, 0.025073411015910096, 0.05429714190540835, 0.06265235919272527, 0.054545984021387994, 0.06110750458901748, 0.04462398537725676, 0.05760338382970076, 0.05115786465466954, 0.03551080895704217, 0.018257981319038663, 0.06142242011264898, 0.09283595049055293, 0.04954616852046456, 0.018668290649657138, 0.011404002616473008, 0.025380858678545337, 0.05934862572757993, 0.02509242855012417, 0.026021111334557645, 0.01680385241343174, 0.07741110122879036, 0.10805926212924533, 0.0784085996565409, 0.01493186839070404, 0.027950624789809808, 0.07454685648554005, 0.049777625827118754, 0.011101295422122348, 0.07053365581668913, 0.020095620602660347, 0.06788030717871152, 0.08033433929085732, 0.024277969714603387, 0.032888957066461444, 0.012028508754156064, 0.033791445748647675, 0.007280980325958808, 0.035008274790016, 0.03720815264387056, 0.07959081121953204, 0.06269748919294216, 0.029739898309344426, 0.03375857602804899, 0.05637245769321453, 0.0186820649105357, 0.04368258218164556, 0.044986557913944125, 0.007653685497643892, 0.034397973358863965, 0.022036143818695564, 0.035618212568806484, 0.023532892410003114, 0.03471187585091684, 0.029011268852627836, 0.027765438535425346, 0.0699806964257732, 0.040259570741909556, 0.0238684600481065, 0.0253748250179342, 0.11650440545054153, 0.02198920297814766, 0.04709300679678563, 0.053335945631260984, 0.007222950871437206, 0.07887501720688306, 0.05327955354005098, 0.04159092430199962, 0.019406319406698458, 0.06258472727495246, 0.021639556798618287, 0.0327375181223033, 0.05610705084109213, 0.09281677339458838, 0.08519013732438907, 0.07039293719572015, 0.012150617094448535, 0.06206704587384593, 0.055599585102754645, 0.04144797181652393, 0.036769988655578345, 0.02713463341933675, 0.03324915101984516, 0.053108336360310204, 0.09685415323474444, 0.0744270441646222, 0.037978821055730805, 0.006957323694223305, 0.02154681245883694, 0.026212893426418304, 0.008238094324042322, 0.05451427947264165, 0.010971414940286195, 0.026332369925512467, 0.021121433819644153, 0.03802680832450278, 0.03518902485666331, 0.031211399036692455, 0.05531008442630991, 0.03999268701591063, 0.024094319705909584, 0.009183536658383673, 0.09451842153794132, 0.032236494225799106, 0.04929036877001636, 0.11944826037506573, 0.11286721390206367, 0.06344014153000899, 0.02800749000016367, 0.10634036647388712, 0.027662547181535047, 0.04987847998563666, 0.07367038750089705, 0.024784114430076443, 0.08129715715767816, 0.03015455476997886, 0.033168186419061385, 0.06608444338780828, 0.028278646641410887, 0.046094439676380716, 0.033439255857956596, 0.00674023714964278, 0.02305642432474997, 0.0443888470181264, 0.08456301511614583, 0.10342563342419453, 0.021918806560279336, 0.099063549132552, 0.06671657509286888, 0.03431673416343983, 0.03087179040448973, 0.025381003397342283, 0.11571476032258943, 0.031358036285382695, 0.04320757056120783, 0.06427678687032312, 0.04284573646145873, 0.02430263499263674, 0.06889441487146541, 0.06313598714768887, 0.01356736866000574, 0.06299586966633797, 0.06597991930902936, 0.008461560555588221, 0.04892068274784833, 0.029174053379392717, 0.07003962295129895, 0.05744299458456226, 0.054485955406562425, 0.03846609666652512, 0.059745611652033404, 0.073037602705881, 0.017911344548338093, 0.08610069315182045, 0.03073696258070413, 0.041517255012877285, 0.017732086198520847, 0.09159625216852874, 0.04135157425480429, 0.019086761749349535, 0.016652090635034256, 0.03287886385805905, 0.020684344090113882, 0.004621610087269801, 0.041429429256822914, 0.033144797635031864, 0.048326871838071384, 0.02596098438516492, 0.05171405980945565, 0.04558666223601904, 0.05934864799201023, 0.030418989408644848, 0.024070782492344733, 0.08078543149167672, 0.07827807814464904, 0.05766362766735256, 0.030131687344692182, 0.019150269181409385, 0.05471092263178434, 0.04192670159682166, 0.008862895465426845, 0.039062820505932905, 0.05585427534242626, 0.03946601820643991, 0.04015708385850303, 0.040324326837435365, 0.037733251811005175, 0.019366532869753428, 0.02498317142453743, 0.1379996887408197, 0.22018451389158145, 0.0858065058127977, 0.08652982520288788, 0.10488597967196256, 0.05852376940310933, 0.13775684317806736, 0.15686922386521474, 0.1720593689242378, 0.230191781593021, 0.13840231869835407, 0.07170296143158339, 0.16139227256644517, 0.1429811175330542, 0.1916342560434714, 0.07446578427334316, 0.11917635230929591, 0.21845648239832371, 0.09787462855456397, 0.16098394291475415, 0.16764359024818987, 0.07811387054971419, 0.17158475064206868, 0.10143313018488698, 0.11261218227446079, 0.14731257339008152, 0.16897684370633215, 0.20145899994531646, 0.1131670044560451, 0.114065849193139, 0.15122980694286525, 0.10649020608980209, 0.10050226177554578, 0.09693593790871091, 0.1320393820060417, 0.14861064904835075, 0.09741247835336253, 0.1507856315583922, 0.13695848523639143, 0.17623179737711325, 0.12866925972048193, 0.18491541501134634, 0.20804382394999266, 0.21986159059451893, 0.16120116953970864, 0.11662617704132572, 0.16966784256510437, 0.12348653079243377, 0.07550694324891083, 0.16248358588200063, 0.13175565894925967, 0.0731592629745137, 0.1511818790459074, 0.17923774779774249, 0.10235096648102626, 0.09254838310880587, 0.18051456834655255, 0.09750854937010445, 0.1071243490150664, 0.21007484465371817, 0.26625572063494474, 0.12561397132230923, 0.17557536775711924, 0.21043781423941255, 0.2510756836272776, 0.0902800977928564, 0.18895446468377486, 0.18604748707730323, 0.08030536584556103, 0.1344048441387713, 0.17697741830488667, 0.31586039636749774, 0.1604358816985041, 0.1475201520952396, 0.12297887209570035, 0.1571973570389673, 0.17382787715177983, 0.1593305863207206, 0.105351625388721, 0.24649728555232286, 0.12367577844997868, 0.17844750895164907, 0.163595367630478, 0.14992186072049662, 0.0976985614397563, 0.223121429735329, 0.191505181719549, 0.1047830363677349, 0.1455600213375874, 0.15393187757581472, 0.1284251970355399, 0.12700165389105678, 0.19329685979755595, 0.2809056267142296, 0.22589534026337788, 0.18810109875630587, 0.20862361940089613, 0.09105888530029915, 0.17068693006876856, 0.19683375750901178, 0.14268345694290474, 0.1300066988915205, 0.1672875671647489, 0.17496901826234534, 0.21650873066391796, 0.15541084430878982, 0.2650792384520173, 0.10809999861521646, 0.16868235950823873, 0.13211724814027548, 0.1604392658919096, 0.1720704120816663, 0.20097813277971, 0.14403849985683337, 0.2307680741068907, 0.11573037510970607, 0.09864790190476924, 0.05646166013320908, 0.12342531845206395, 0.3242610627785325, 0.21717645577155054, 0.17112012166762725, 0.15123748074984178, 0.17088952154153958, 0.05025278958783019, 0.21832584956428036, 0.20749714312842116, 0.1029954401019495, 0.1524166643503122, 0.16262515797279775, 0.06985359621467069, 0.11214641039259732, 0.14220109063899145, 0.15062425896758214, 0.18196252814959735, 0.20910473889671266, 0.16945132840191945, 0.09858193981926888, 0.15390250337077305, 0.1142706596874632, 0.18872223183279857, 0.06324852642137557, 0.09850253001786768, 0.2417148562381044, 0.12277945701498538, 0.1084506262850482, 0.15307103079976514, 0.11720977228833362, 0.08610110875451937, 0.13152296596672386, 0.10298716515535489, 0.1988275520852767, 0.15706479462096468, 0.125969905348029, 0.1577932422515005, 0.2337685920065269, 0.10906931027420796, 0.12625306437257677, 0.10669915776816197, 0.15790658304467797, 0.175291555642616, 0.14252622553613037, 0.19367188186151907, 0.24284738843562081, 0.06929464027052745, 0.16076535073807463, 0.17078358738217503, 0.1325902930693701, 0.19818669272353873, 0.08758310345001519, 0.17931203678017482, 0.2178868098417297, 0.09261563653126359, 0.15199885005131364, 0.22316184709779918, 0.20098162087379023], [0.009818218568398152, 0.050501104778959416, 0.027901954745175317, 0.011052358204324264, 0.053074082534294575, 0.047231157586793415, 0.013860281360393856, 0.03454466255789157, 0.0436159781384049, 0.026606777173583396, 0.0293119388516061, 0.013096451839373913, 0.02258440355944913, 0.034320363265578635, 0.03349792263179552, 0.012694148426817264, 0.018915822874987498, 0.020956369044142775, 0.03459954808931798, 0.018970229721162468, 0.052190277419867925, 0.10119264465174638, 0.007444385009875987, 0.02123782855051104, 0.05518380057765171, 0.03699931599840056, 0.011856713626912097, 0.05159098574949894, 0.014819227071711794, 0.009488961040915456, 0.026345472542743664, 0.05250341178907547, 0.04594728663505521, 0.011861724051414058, 0.017988796935242135, 0.05786413741589058, 0.04412894690176472, 0.03351782703248318, 0.03063691736315377, 0.04176859445578884, 0.05978652996418532, 0.052194797099218704, 0.03828929482551757, 0.023577337778988294, 0.07902321667643264, 0.010221907941740938, 0.02094383045914583, 0.04675214579037856, 0.03301005701359827, 0.02347966186789563, 0.026131264603463933, 0.038622804859187454, 0.019675342373375315, 0.04217677196720615, 0.09231308518792503, 0.03832953407254536, 0.059331637967261486, 0.043719162640627474, 0.039920357303344645, 0.020577567593136337, 0.03281715056800749, 0.04847516036534216, 0.009868966626527254, 0.06629405557760037, 0.037937876768410206, 0.06175452006573323, 0.02345547341974452, 0.07093417807482183, 0.010736625390563859, 0.10169720859266818, 0.031789502390893176, 0.07195119498646818, 0.01200799115395057, 0.03321327189041767, 0.049474529005237855, 0.05487620634085033, 0.08550963932066225, 0.04219855029077735, 0.29769475862849504, 0.3038655681302771, 0.40149803389795125, 0.3322049818234518, 0.965834726812318, 0.8065568329766393, 1.4491056790575385, 0.8511766511946917, 0.6769862794317305, 0.7681907073128968, 0.571341795148328, 0.298920608474873, 0.2525590290315449, 0.1181092849583365, 0.6433715019375086, 1.030989889986813, 0.6734597717877477, 0.5467958247754723, 0.35633071849588305, 0.5833109747618437, 0.14551345899235457, 0.03745835660083685, 0.014147296769806417, 0.06442399928346276, 0.15022550302091986, 0.032109342064359225, 0.023516863875556737, 0.06236935601918958, 0.04563482762023341, 0.0342975310923066, 0.017689798623905517, 0.05832652881508693, 0.038689605571562424, 0.030708493795827962, 0.020332399108156096, 0.05365054574212991, 0.024275695031974465, 0.030992840256658383, 0.06671533570624888, 0.026555166368780192, 0.02880027997889556, 0.036433840286917984, 0.041015544629772194, 0.10806424936163239, 0.0462804849667009, 0.010194436417805264, 0.05648722712066956, 0.08558344590710476, 0.024947370220615994, 0.019340939907124266, 0.0204165883405949, 0.004744308898807503, 0.1255992619553581, 0.051596577832242474, 0.07588969107018784, 0.05695380052202381, 0.03291517714387737, 0.029205256978457328, 0.02763381493423367, 0.029049437507637776, 0.05377815803512931, 0.04260518784576561, 0.10099265811732039, 0.013283358020999003, 0.050089249925804324, 0.01903388743812684, 0.044202579083503224, 0.03491457493510097, 0.008926675636757864, 0.060916152942809276, 0.015878370140853804, 0.01972500504052732, 0.06418909470085055, 0.025753316622285638, 0.04809420854144264, 0.048186925050686114, 0.05903527984628454, 0.04460502721485682, 0.028752418875228614, 0.0006656000721250166, 0.05212074189330451, 0.021973256079945713, 0.056740952568361536, 0.02596091573650483, 0.06753280395059846, 0.03385645417438354, 0.042882213019765913, 0.07260193975525908, 0.03638690686784685, 0.13018876255955547, 0.0162048167840112, 0.04137437303143088, 0.030563166437787004, 0.08037727253395133, 0.007914611633168533, 0.07719469096628018, 0.02920123082731152, 0.08674146345583722, 0.07896714741946198, 0.05512291107152123, 0.02353848634811584, 0.03020701162313344, 0.0246260573840118, 0.07742655274341814, 0.020779058831976727, 0.023621712643944193, 0.09071749736904167, 0.020946546719642356, 0.03483005173620768, 0.042730896529974416, 0.03318392737128306, 0.04699285396782216, 0.015485984604310943, 0.03680233516206499, 0.046632444791612215, 0.029520860844058916, 0.05136723193572834, 0.013364244696276728, 0.059200318646617234, 0.03152146462525707, 0.01945652940776199, 0.028624452206713613, 0.11365226513589732, 0.019571167104004417, 0.017110973531089257, 0.03933901447453536, 0.021356310571718495, 0.08293782302644104, 0.020105283365410287, 0.058224086460541, 0.052011635052622296, 0.020489192647801246, 0.004895982547168387, 0.05572874848439824, 0.021809031786688138, 0.0372216671530623, 0.030657408060505986, 0.0185351530672051, 0.03347968064190354, 0.007044822441457654, 0.02459616182022728, 0.02060701786831487, 0.08132194489007816, 0.04059880644490477, 0.01737998907628935, 0.03833866991044488, 0.02390196987107629, 0.043839602076332085, 0.012108199643989792, 0.02996009909111308, 0.010150654343306087, 0.03967106247728225, 0.03035621855815407, 0.07912065324489959, 0.03893280736519955, 0.07688183861318976, 0.0034476588598408853, 0.04366199871583376, 0.03967330005252734, 0.012135736105847172, 0.02087792589009041, 0.02360501432121964, 0.06764510573702864, 0.02863758822059026, 0.07763958623399958, 0.06173261928779539, 0.08135910422424786, 0.03260290737671312, 0.02960370864457218, 0.05634388871840201, 0.017290281975874677, 0.03359290640219115, 0.0352965435013175, 0.05631927167996764, 0.029415937860903796, 0.07004944156506099, 0.14161289407638833, 0.3227975475601852, 0.47768177872058004, 0.42940590356010944, 1.06596440076828, 1.0775791900232434, 1.3854441326111555, 0.9252282057423145, 0.635293135419488, 0.6365810881834477, 0.6936719559598714, 0.14074051432544366, 0.24821638158755377, 0.15514883649302647, 0.7964446255937219, 1.0777590866200626, 0.8267279318533838, 0.5294471431989223, 0.32160951755940914, 0.48328137199860066, 0.055997357703745365, 0.057004674745257944, 0.029173454095143825, 0.15405741927679628, 0.10899977845838293, 0.03464369474386331, 0.06265510513912886, 0.03137624487862922, 0.03974345156166237, 0.01882060903881211, 0.0221810333096073, 0.03419632812438067, 0.034216792846564204, 0.030482973670586944, 0.03984382332419045, 0.07165898918174207, 0.03545442799804732, 0.023755204601911828, 0.05925874793319963, 0.05241138918790966, 0.03753956611035392, 0.014932602189219324, 0.019397606592974626, 0.06796341287554242, 0.018416233178868424, 0.05310752741934266, 0.07276602860656567, 0.009474307335040066, 0.04803882577107288, 0.04034722951473668, 0.02475684421369806, 0.06063172113499604, 0.04378585203085095, 0.05718590349715669, 0.002761530809038959, 0.047891160647850484, 0.05060058225353714, 0.02152147553715622, 0.061938260987517424, 0.01807428492611507, 0.019511873215378728, 0.0230539826588938, 0.022730265263817273, 0.026344593097746838, 0.032566397421760485, 0.015016647630545776, 0.03045717290660832, 0.08004720977623947, 0.01682218902715249, 0.011213322613912169, 0.020334024411567952, 0.026575736847007647, 0.012378084429656155, 0.05941159324720502, 0.03213344702089671, 0.009655121411924483, 0.034783856754074804, 0.015299503302230733, 0.037900947500020266, 0.019239195171394385, 0.030575549171771854, 0.0271494949265616, 0.09427188750123605, 0.09406013050465845, 0.03540526071446948, 0.010161473001062404, 0.050249542691744864, 0.019559415195544716, 0.028102032192691695, 0.027486760227475315, 0.06097692370531149, 0.061185177764855325, 0.007310906039492693, 0.06716331830830313, 0.05532938397664111, 0.04684754145273473, 0.08161631776602007, 0.044586603398784064, 0.16958029882516712, 0.13054974318947643, 0.11915626979316585, 0.13488544413121417, 0.17692629917291924, 0.09738591688801534, 0.07042252662358806, 0.14552923705196008, 0.3161601646570489, 0.1297436817549169, 0.18479122401913628, 0.15809823526069522, 0.1631971015012823, 0.09842122031841427, 0.10131453498615883, 0.13047052634647116, 0.1090731323347427, 0.1818201396963559, 0.16473975934786722, 0.14985019894083962, 0.2594214311102405, 0.13572721771197394, 0.16499977820785716, 0.11583344457903877, 0.15670183987822384, 0.09883320133667439, 0.08155218136380427, 0.1476838401868008, 0.2180851117009297, 0.15935026807710528, 0.12861149094533175, 0.15084074344485998, 0.14693490928038955, 0.1253537298180163, 0.06179587624501437, 0.17483078583609313, 0.1976983595523052, 0.11219879117561504, 0.11342156110913493, 0.09022007288876921, 0.12260389456059784, 0.13960226759081706, 0.09269744346966036, 0.11807648203102872, 0.186619074374903, 0.14312255603726953, 0.10372002114308998, 0.14786015963181853, 0.17995003145188093, 0.12397553931805305, 0.05661486167809926, 0.08263311203336343, 0.07165742325014435, 0.1777325090370141, 0.14932759338989854, 0.13997755682794377, 0.17326319182757288, 0.11444911651778966, 0.14202667109202594, 0.0743116030935198, 0.13033058698056266, 0.22310836793622002, 0.09319973643869162, 0.1544463195023127, 0.17202564573381096, 0.17537059437017888, 0.1382077721063979, 0.18096778308972716, 0.09991001308662817, 0.23950980190420523, 0.16977961000520736, 0.19555800565285608, 0.11962837219471112, 0.11526666639838368, 0.15628586610546336, 0.1534419265226461, 0.15709038387285545, 0.24101419461658224, 0.3198255429742858, 0.5203963257372379, 0.5694338225293905, 0.6355809699743986, 1.5783267701044679, 1.2496981979347765, 2.2705610375851393, 1.5858494164422154, 0.99455964169465, 1.2320524198003113, 1.5174385998398066, 0.5399301869329065, 0.4885572107741609, 0.47934089438058436, 1.2448935932479799, 1.6767593007534742, 1.5063142217695713, 1.1671647266484797, 1.1699256347492337, 1.2693812604993582, 0.33164394786581397, 0.17119123425800353, 0.1268007990438491, 0.3164104762254283, 0.2887349878437817, 0.1241277092776727, 0.1983690235647373, 0.12931316188769415, 0.15815242688404396, 0.10253340864437632, 0.11235684636631049, 0.19133181602228433, 0.12762918428052217, 0.09922067663865164, 0.07822991276043467, 0.10166552630835213, 0.1008771057240665, 0.09310324981925078, 0.1464864145964384, 0.09640984426368959, 0.12550825980724767, 0.11007598164724186, 0.11658195988275111, 0.2128086643642746, 0.08150960435159504, 0.1616676984122023, 0.1685997733147815, 0.14650406286818907, 0.12349244570941664, 0.14165360829792917, 0.14231029024813324, 0.09593287337338552, 0.18461426632711664, 0.16860977746546268, 0.14432367752306163, 0.1911007854505442, 0.09723697527078912, 0.110950825328473, 0.13509081123629585, 0.148782471078448, 0.18072946462780237, 0.12522075179731473, 0.199874856043607, 0.09319736156612635, 0.1344245852669701, 0.06455964903580025, 0.13926595594966784, 0.1171054263249971, 0.09292347196605988, 0.1109856840048451, 0.06670775095699355, 0.13059964519925416, 0.1006316181155853, 0.10304867435479537, 0.19111794390482828, 0.15063892380567268, 0.11066431921790354, 0.10485378530574962, 0.09578928264090791, 0.08155410352628678, 0.1357238186756149, 0.2036319044418633, 0.2801297855330631, 0.14750682312296703, 0.11743062801542692, 0.16713878139853477, 0.19535541418008506, 0.18058419664157555, 0.1127480249851942, 0.23952320509124547, 0.09084824152523652, 0.08997019918751903, 0.10481415461981669, 0.10712240458815359, 0.1241099571052473, 0.135256280482281, 0.09901525016175583, 0.14304739132057875], [0.01987532519706292, 0.07809386966982856, 0.019007060654985253, 0.06999001037911512, 0.03729691350599751, 0.020721954278997146, 0.0525240768911317, 0.09056907525518909, 0.04655550263123587, 0.009393876152898883, 0.06419670171453618, 0.049611206632107496, 0.02824129620421445, 0.11081364675192162, 0.05444029106001835, 0.06821488961577415, 0.018316293717361987, 0.02244107443402754, 0.029671986230823677, 0.06382593957823701, 0.008432775430264883, 0.05493267635756638, 0.050464795203879476, 0.037978546461090446, 0.029020311922067776, 0.05963325791526586, 0.0759862815903034, 0.010834843069460476, 0.01927237659401726, 0.062405142380157486, 0.0563641419284977, 0.0423875678825425, 0.03805498396104667, 0.08158400465617888, 0.012609053774212953, 0.06623361507081427, 0.029315911197045352, 0.008712230210221605, 0.03881554432155099, 0.017247510149900336, 0.019334108437760733, 0.06656718818703666, 0.05131129997607786, 0.020640592629206367, 0.012899287321488373, 0.049695058187353425, 0.09480886845267378, 0.04665199667215347, 0.030125978373689577, 0.031016162247397006, 0.10143238061573356, 0.016656105653964914, 0.024995225758175366, 0.03431895689573139, 0.02855979444575496, 0.05722034286009148, 0.031251975960913114, 0.043297374140820466, 0.0368124691885896, 0.03797757424763404, 0.051107814215356484, 0.03959213507187087, 0.04626722278771922, 0.04036102232930716, 0.03838390010059811, 0.023476923342968803, 0.02662433824298205, 0.05160857836017385, 0.04036909689602908, 0.1406207020045258, 0.10008703015046194, 0.06428301348933019, 0.0325423369940836, 0.6444014247972518, 0.43097046960610896, 1.1370474239811301, 1.6607641777954996, 3.6745593370869756, 5.79338762909174, 6.349600832909346, 11.520369071513414, 15.690169371664524, 17.129969112575054, 18.705799654126167, 19.57610685378313, 19.08390786498785, 14.824743960052729, 18.95265720784664, 14.91806885227561, 12.747943550348282, 12.807971779257059, 11.503516025841236, 12.643791139125824, 11.444379799067974, 16.727418713271618, 15.15883818268776, 17.511641532182693, 9.808867760002613, 11.656814999878407, 7.438660869374871, 3.457201262935996, 0.7111665734555572, 0.13125065714120865, 0.18162663211114705, 0.024528761823603418, 0.05514353535545524, 0.014097860457695788, 0.053713338857050985, 0.034144670935347676, 0.024508193200745154, 0.03087224868068006, 0.005106406460981816, 0.05066150515631307, 0.04394657153170556, 0.07181703695096076, 0.05241862512775697, 0.020866517224931158, 0.07897824994870462, 0.017069179484678898, 0.07540627833805047, 0.09205334834405221, 0.04444995916855987, 0.059546441480051726, 0.004367520059531671, 0.06120816578913946, 0.038700808290741406, 0.041284814360551536, 0.07004248021985404, 0.00966433795838384, 0.017273720950470306, 0.047867007451714016, 0.014953152258385671, 0.04901676860754378, 0.060457969520939514, 0.001535447302103421, 0.004375536645966349, 0.12369038391625509, 0.00662458688566403, 0.07659607465029694, 0.02454115754517261, 0.0017912552857524133, 0.02300876545632491, 0.02620953706355067, 0.013426750228973106, 0.03364808137121145, 0.06893532205140218, 0.03206676134141162, 0.07997803419129923, 0.024260855789179914, 0.029215583963377867, 0.10756780451629311, 0.007375494687948958, 0.01786219210771378, 0.01317202195423306, 0.04069990180141758, 0.09208304909407161, 0.03750522322661709, 0.013266262649267446, 0.021539110821322538, 0.04185739984677639, 0.00890075983988936, 0.0429792859358713, 0.014173420368024381, 0.03842501879262272, 0.03042744803678943, 0.03945323100197129, 0.027828196398331784, 0.11064543898100965, 0.11492418751004152, 0.035550517568481155, 0.058332477128715254, 0.029939918240415864, 0.018163515196647495, 0.017654472394497134, 0.056982365786097944, 0.018188763060607016, 0.03349092788994312, 0.03635668661445379, 0.04403696511872113, 0.025762940422282554, 0.035235702234786004, 0.0035714576733880676, 0.06392005874658935, 0.07140842528315261, 0.03286242157628294, 0.0474003375711618, 0.07392021667328663, 0.04692471367889084, 0.02153802171960706, 0.06158822332508862, 0.03593433408241253, 0.01005375119348173, 0.0067493535061657894, 0.028007812834403012, 0.06284149552811868, 0.04135034600039944, 0.013896338605263736, 0.046057258077780716, 0.007812094136170344, 0.06851570433354937, 0.007949760674819117, 0.04690472393122036, 0.05755585298174992, 0.06898116451338865, 0.09906944178510457, 0.026412397564854473, 0.027669912997225765, 0.04247528231644537, 0.008819708036753582, 0.10940056788967922, 0.07261905368068255, 0.02328527669305913, 0.02590077023342019, 0.03159423591569066, 0.04194808658212423, 0.007978173798619537, 0.0204562709768652, 0.025468997991993092, 0.02158864361263113, 0.02851134333468508, 0.011657766099233413, 0.04133345471927896, 0.043356738533475436, 0.031077858839125838, 0.06175504327984527, 0.002537961604502925, 0.03273650880146306, 0.009318374686699826, 0.009720659545564558, 0.07311351699172519, 0.06105191772803664, 0.053089734428795055, 0.05695406398444902, 0.049702780233928934, 0.03337917529279366, 0.056393809281871654, 0.045892245252616704, 0.04686839951318689, 0.07191643278929405, 0.027669707051245496, 0.028673513734247535, 0.01865868725872133, 0.05248998633760493, 0.10443830135045573, 0.05766875961853657, 0.15727958700153977, 0.08089948474662378, 0.06617033955990337, 0.05364134682167787, 0.6337644893210381, 0.46776751696597785, 1.7803303431719542, 2.2405212745070457, 4.533487809821963, 9.024875778704882, 9.964887388050556, 15.26345606893301, 20.69259714335203, 21.438455320894718, 22.851572893559933, 22.625308334827423, 21.566113270819187, 19.472725801169872, 23.066510260105133, 17.625359930098057, 16.35093681514263, 16.11166175454855, 13.533308207988739, 14.282567203044891, 13.252558372914791, 18.598833493888378, 16.664714477956295, 20.33622946590185, 12.612027693539858, 14.488781187683344, 10.569737982004881, 6.134741837158799, 1.527823442593217, 0.2940269757527858, 0.15904040657915175, 0.043166596587980166, 0.05570796834945213, 0.03942022398405243, 0.010919679825747153, 0.07596024704980664, 0.06431902249460109, 0.010594268478598678, 0.038748201841372065, 0.024126074349624105, 0.020238983124727383, 0.027544872245925944, 0.021092209899506997, 0.00887194410097436, 0.10111386567587033, 0.04787894489709288, 0.014309738980955444, 0.02339160975679988, 0.037018096045358106, 0.036140677111689, 0.02846808169124415, 0.07506051915697753, 0.024015058334043715, 0.011192927468073322, 0.04273221013136208, 0.012348142481641844, 0.048496370945940726, 0.01739821622322779, 0.021499266767932568, 0.050533889152575284, 0.04930062154016923, 0.03895775094861165, 0.037553967486019246, 0.006882964671603986, 0.013942069745098706, 0.06046790316759143, 0.024851171183399856, 0.05745595619373489, 0.02398246320808539, 0.027927265691687353, 0.03596203103370499, 0.023063331864250358, 0.04087453657120932, 0.013137395199009916, 0.039784989567124285, 0.019016612095583696, 0.022192146971065085, 0.02621026993438136, 0.010352838562539546, 0.06813089334173128, 0.021584014466498047, 0.006321711316559231, 0.10745343213784508, 0.025002109177876264, 0.011881961490871618, 0.020218188146827742, 0.023614780984644312, 0.04626310015737545, 0.024539396799809765, 0.005056244699517265, 0.032980638279695995, 0.027129750087624416, 0.04458066250663251, 0.025239752285415307, 0.0766520548495464, 0.09666706522693858, 0.036292954682721756, 0.03456843725871295, 0.012964079596713418, 0.02817516156937927, 0.021589658499578945, 0.02376846121478593, 0.08528429360012524, 0.1431197952479124, 0.18961876106914133, 0.19552644953364506, 0.18062605377053842, 0.13743780873483047, 0.057982914440799505, 0.1998052722774446, 0.2064256154699251, 0.12648715259274468, 0.111428211821476, 0.15343725099228323, 0.1415943997562863, 0.1151606506027747, 0.27270029357168823, 0.16609512880677357, 0.15652887494070455, 0.14219797361874953, 0.15812000987352803, 0.15007370413513854, 0.1735885493690148, 0.17063772567780688, 0.16796879936009645, 0.17191585240652785, 0.25660438695922494, 0.09485999500611797, 0.19614917080616578, 0.19794311985606328, 0.10708436209824868, 0.1607052664621733, 0.10874586005229503, 0.20865480444626883, 0.08797376256552525, 0.08581377143855207, 0.2616764616686851, 0.18154217570554465, 0.12004522170173004, 0.12589258840307593, 0.08724446888663806, 0.13203022390371189, 0.13233095698524266, 0.11007263456122018, 0.1327828803914599, 0.12789089523721486, 0.15432876331033185, 0.054847199498908594, 0.10071947355754673, 0.17728474165778607, 0.10628929929225706, 0.14392618322744966, 0.11545214394573122, 0.3009691141778603, 0.09590674235369079, 0.1530774132697843, 0.1772063411772251, 0.17405638442141935, 0.1549991749925539, 0.16922860988415778, 0.15505363378906623, 0.11739157620468177, 0.1319870160659775, 0.12857902940595523, 0.162851290369872, 0.20095153420697898, 0.0908106443239376, 0.08851764549035579, 0.12334564147749916, 0.18567258375696838, 0.13699112489121035, 0.23163524398114532, 0.31702731968834996, 0.22112238075351343, 0.13888766843592748, 0.16718932165531442, 1.0934086656197906, 0.8576474664732814, 1.917102460283786, 3.3755683433264494, 7.421965040266514, 11.282031610608101, 12.795415353029966, 18.865696974098682, 24.840984642505646, 26.857656128704548, 31.121268644928932, 30.187516249716282, 26.57880049198866, 23.763126879930496, 29.470194540917873, 24.052399657666683, 23.363413028419018, 23.53949747979641, 19.27441444247961, 20.495577715337276, 20.41234128177166, 26.748980060219765, 24.86343763768673, 27.123427167534828, 18.36464636027813, 21.05049803853035, 15.7740992680192, 10.236246027052402, 2.353362157009542, 0.4526605666615069, 0.2549317048396915, 0.13748028926784173, 0.18765293061733246, 0.0780280634353403, 0.10258912167046219, 0.11719041707692668, 0.19203244795789942, 0.10244342323858291, 0.16394724952988327, 0.1300521331722848, 0.11260979998041876, 0.10770487177069299, 0.15157064568484202, 0.11373032422852702, 0.17514207225758582, 0.28789348143618554, 0.17066727799829096, 0.1397476691636257, 0.1282999076647684, 0.10088588533108123, 0.15814862708793953, 0.1399641833268106, 0.14558998926077038, 0.10590177946141921, 0.14481521677225828, 0.08380451050470583, 0.1403550131362863, 0.1588650222402066, 0.08448666296317242, 0.12099169005523436, 0.17834292550105602, 0.21098845812957734, 0.06854898965684697, 0.1725140234339051, 0.07522141677327454, 0.16449338116217405, 0.08808388243778609, 0.12717024015728384, 0.14705804642289877, 0.22278069489402696, 0.1221206525224261, 0.11521476801135577, 0.1080788993567694, 0.09139114481513388, 0.1213198751793243, 0.14686911046737805, 0.10751625493867323, 0.20605746569344774, 0.07789861061610281, 0.11150778489536606, 0.09242822939995676, 0.11506703609484248, 0.19743522367207333, 0.1274757378268987, 0.15369538479717448, 0.08562619361327961, 0.1025465149723459, 0.13427257857983932, 0.17477436776971444, 0.10383405955508351, 0.11464572628028691, 0.11755393585190177, 0.1400231395382434, 0.09448461671127006, 0.18257971300045028, 0.21600430773105472, 0.14327895623864606, 0.13679274881724268, 0.08077749793301336, 0.10227025792119093, 0.11620805846177973, 0.10672442047507502, 0.15476286032935604], [0.015762044058647007, 0.10712977411458269, 0.09586852916982025, 0.08638388928375207, 0.04841425601625815, 0.010696728459151927, 0.01362862552923616, 0.06937956422916614, 0.054528116816072725, 0.04019036547106225, 0.03552806760126259, 0.04918776685371995, 0.030280656792456284, 0.05316138136549853, 0.013461189591907896, 0.04491135237913113, 0.08443219674518332, 0.03504194231936708, 0.049038428187486716, 0.09022629208629951, 0.01137451152317226, 0.016537978008273058, 0.044802453339798376, 0.029526419530157, 0.03784425483900122, 0.03930497587134596, 0.0600922651210567, 0.023158382427936886, 0.028936471499036998, 0.02243375314719742, 0.06359526523738168, 0.07071800529956818, 0.05801700128358789, 0.03210865928849671, 0.04682420090830419, 0.0441278893413255, 0.034639620353118517, 0.06170317457872443, 0.039808367218938656, 0.029867896519135684, 0.003714957260854135, 0.017578495026100427, 0.01214083373270114, 0.008514392193319509, 0.03683561306388583, 0.02425434344331734, 0.05358541486202739, 0.06682052771793678, 0.044158799792057835, 0.012538770533865318, 0.05291530746035278, 0.05550361056521069, 0.05181703279959038, 0.04569028089463245, 0.0290783367381664, 0.1305402140133083, 0.02450932312058285, 0.01254930253708153, 0.051442300173221156, 0.04985666826542001, 0.07862593760364689, 0.07101002556737512, 0.06766807520762086, 0.044527791906148195, 0.029897806925873738, 0.08708771987585351, 0.3637330775381997, 0.617509555304423, 0.4803648206871003, 1.514611670281738, 4.389481237158179, 3.8162962440401316, 8.35147401317954, 13.170170243829489, 20.37522677332163, 29.122573994100094, 38.174370378255844, 41.49818882346153, 58.215140998363495, 57.61774845421314, 64.84687954187393, 62.40462139248848, 59.308615922927856, 44.69510167837143, 58.30482758581638, 54.207758232951164, 65.8171346783638, 66.06577053666115, 63.21132190525532, 57.88034476339817, 51.404743641614914, 53.244456723332405, 41.21150940656662, 44.814198687672615, 48.686855882406235, 58.50091226398945, 56.872528642416, 53.42229098081589, 53.78827594220638, 51.54764637351036, 44.637891948223114, 24.494751021265984, 12.64040932059288, 2.765458356589079, 0.5348249827511609, 0.030618586315540597, 0.0975203346752096, 0.054909640093683265, 0.06319045336567797, 0.030741870032215957, 0.04047878261189908, 0.02846957340807421, 0.018609143335197587, 0.019550511278794147, 0.026071182182931807, 0.03266502513724845, 0.03433253077673726, 0.04700895486166701, 0.06960085040191188, 0.07345468970015645, 0.02374882584263105, 0.019118985801469535, 0.02232320654002251, 0.07508620488806628, 0.0075580439988698345, 0.14487371285213158, 0.04344166249211412, 0.019207408986403607, 0.06267302058404312, 0.05529989844944794, 0.047319005607278086, 0.03267773812694941, 0.04276001840480603, 0.020958087116014212, 0.08430373098235577, 0.026020890545623843, 0.025588019925635308, 0.04699325101682916, 0.051056735901511274, 0.009672684336692328, 0.031000050221337005, 0.0276958881659084, 0.052751715847989544, 0.06775682122679427, 0.00538764471457398, 0.0775445690669585, 0.02150087722839089, 0.022532562688866165, 0.04263486262061633, 0.021803927666042, 0.022823751751275267, 0.06310777069302276, 0.08929903793614358, 0.0872663474001456, 0.02490477836545324, 0.03424440816161223, 0.024836920092639048, 0.0582433860108722, 0.020693344486062415, 0.031666710347053595, 0.0245300049209618, 0.030338520191435236, 0.015170593178481795, 0.02284618873090949, 0.04758495051646605, 0.10771469780593179, 0.10854221472982317, 0.07500408624764532, 0.030718319831066765, 0.04840716479520779, 0.05713487342291046, 0.014034712967259111, 0.02319871258805506, 0.05006116705772001, 0.024627460043120664, 0.05784555774880573, 0.03946923170587979, 0.04005844130006153, 0.037815659889020026, 0.10009261852246709, 0.09648992199799977, 0.0125444182776846, 0.051700801341212355, 0.008211418753489852, 0.08523156400769949, 0.01578446990606608, 0.08075525576714426, 0.021458825285662897, 0.0039856243165559135, 0.027040521672461182, 0.012509335101640318, 0.05026637089031283, 0.00902170857443707, 0.053775341584696434, 0.08260143717052415, 0.015522583616984775, 0.006009564931446221, 0.03969339741161093, 0.03194409546267707, 0.05434558188426308, 0.04609212417562958, 0.07502115564420819, 0.05086531375127379, 0.07226841858937405, 0.08360654261196032, 0.09658556256908923, 0.008926768405217445, 0.007733871307209483, 0.04108223401999567, 0.07194145058747381, 0.023037358550936915, 0.01729931576846866, 0.04487296850129496, 0.029697712780034635, 0.06421854312065989, 0.047463494338444434, 0.010885092033277033, 0.04119580116821453, 0.0552987555420259, 0.039480000268667936, 0.03440073043748271, 0.01910587576276157, 0.03585665348509792, 0.041262423765147105, 0.084367154922802, 0.0596559787663864, 0.020672078244388103, 0.06804121221648529, 0.04337670230597723, 0.05266650245175697, 0.0228858027185197, 0.04708357409981545, 0.05113424209412187, 0.01084078674466582, 0.0094115337014955, 0.016045505508373026, 0.06589554453967139, 0.03422794361540582, 0.09792659373488277, 0.03733533820195589, 0.039937434121384285, 0.09083934317459352, 0.26704969990532845, 0.7480031030718237, 1.0669947392307222, 1.462566931731999, 4.527405286207795, 4.190478315576911, 9.689475316554308, 14.738096259534359, 24.92760479450226, 34.163803383708, 44.096823781728745, 54.24828685820103, 69.03139740228653, 68.74775022268295, 78.15606817603111, 75.1530285179615, 72.50462383031845, 59.43259947001934, 72.18613252043724, 68.60835090279579, 74.1795663535595, 74.23638090491295, 71.54360219836235, 67.82714322209358, 59.67499986290932, 60.35475678741932, 44.78338994085789, 49.36244063079357, 56.2888989597559, 66.05463713407516, 65.94831883907318, 62.04014115035534, 64.11115542054176, 60.52767790853977, 55.09284093976021, 31.691355854272842, 17.267293743789196, 3.8751484360545874, 0.8302302751690149, 0.013201926794863539, 0.12508496845839545, 0.1027138766949065, 0.13634723756695166, 0.054881935720914043, 0.03140357446682174, 0.02015766414842801, 0.04003943489806261, 0.060185950133018196, 0.045508198672905564, 0.033143168620881625, 0.03715672923135571, 0.010421326733194292, 0.045481644629035145, 0.11411201077862643, 0.047764067858224735, 0.010750947913038544, 0.03167360489896964, 0.11137747118482366, 0.03543148821336217, 0.13722159143071622, 0.044475518734543584, 0.03163798923196737, 0.01645938456931617, 0.0268009619685472, 0.042803022151929326, 0.02355360204091994, 0.025371242300025187, 0.032898783101700246, 0.022420387067541014, 0.06534397296491079, 0.008800118121143896, 0.03940113223507069, 0.0059181063625146635, 0.09045474740560167, 0.029282046998559963, 0.033157744401250966, 0.044042560912203044, 0.026057613868033513, 0.01319393479207065, 0.01190985603898298, 0.04818253524717875, 0.04459869669517502, 0.02384536997851683, 0.045527342372224666, 0.03819271172687877, 0.03301737458969001, 0.0479951986199012, 0.024052822518569883, 0.01732636334054405, 0.09375126348459162, 0.05466446789796464, 0.018329878730583005, 0.015012590865808306, 0.014825061280134832, 0.03392160731891636, 0.012485102124628611, 0.02526762920751935, 0.06041993445251137, 0.052967324591008946, 0.014473160827037646, 0.13243571855127811, 0.034683548074099235, 0.03183094391715713, 0.012166114065621514, 0.07319178388570435, 0.03728448624315206, 0.0533817992254626, 0.044464353122748435, 0.03684137212985661, 0.0462104150938103, 0.10211241795332171, 0.14890985330566764, 0.24043949029874057, 0.21915429417276755, 0.15464267693459988, 0.09687618759926409, 0.1455916665145196, 0.12425276858266443, 0.16938555927481502, 0.1325995402294211, 0.15597696939948946, 0.19558898289687932, 0.10246091565932147, 0.09402035138919018, 0.11530870906426571, 0.14773672563023865, 0.10179563963902183, 0.13482436537742615, 0.18198246223619208, 0.11389867300749756, 0.09800048195756972, 0.10512247987207957, 0.10974752934998833, 0.17134622437879443, 0.14574204047676176, 0.22130060009658337, 0.14214434602763504, 0.2321815537288785, 0.202217964688316, 0.17931230395333841, 0.12642525747651234, 0.1584725597058423, 0.12713391944998875, 0.299171187216416, 0.13548886956414208, 0.1515892439056188, 0.1561915985075757, 0.17701399134239182, 0.17240350280189887, 0.16642447910271585, 0.09789847375941463, 0.11266886751400307, 0.08809240971459076, 0.15000524843344465, 0.12222997087519616, 0.1348389411577955, 0.2065655548358336, 0.1355244778096676, 0.15160787181230262, 0.1598567987093702, 0.13445701712043956, 0.19643676787381992, 0.12180515812360682, 0.22946769779082388, 0.1060474111000076, 0.23610156291397288, 0.13319886900717393, 0.12035462306812406, 0.12507729465141892, 0.09205842463416047, 0.2589461300522089, 0.1782356109470129, 0.22267225227551535, 0.08575223997468129, 0.21743867138866335, 0.36834680184256285, 1.0668453597463667, 1.5267831296660006, 2.3040263168513775, 3.230570498853922, 6.995981773361564, 7.011672556400299, 13.161183726042509, 19.088731706142426, 31.045686900615692, 42.592435106635094, 53.26851703226566, 66.04384571313858, 81.24054506421089, 82.7324590086937, 93.33291739225388, 86.85779124498367, 87.39977896213531, 74.60825175046921, 84.40635278820992, 81.12845867872238, 86.79783046245575, 84.87208619713783, 84.13024440407753, 82.94028505682945, 72.62725844979286, 73.63277569413185, 57.55629815161228, 65.07227584719658, 68.01046818494797, 80.68541765213013, 77.47625425457954, 76.63386225700378, 75.3547140955925, 72.3800665140152, 65.69577679038048, 40.33526882529259, 21.466062739491463, 5.248048966750503, 1.1263590725138783, 0.1965264489990659, 0.30398713191971183, 0.16579636983806267, 0.3861381596652791, 0.1406446288456209, 0.1787503794184886, 0.11892443028045818, 0.13899245968787, 0.13364528567763045, 0.22694960556691512, 0.08179198412108235, 0.1504980493336916, 0.1035504403989762, 0.2823446807451546, 0.19413521949900314, 0.09216258506057784, 0.1224909842130728, 0.1694276835769415, 0.19016492238733917, 0.07737473599263467, 0.3100417507812381, 0.1737761197728105, 0.1081978804722894, 0.10217049100901932, 0.1697036437690258, 0.17756420478690416, 0.15127671067602932, 0.09524893233901821, 0.158394456084352, 0.2101334001054056, 0.13603126077214256, 0.16281272837659344, 0.13157884968677536, 0.12640505621675402, 0.10205380312982015, 0.10657840291969478, 0.10088745126267895, 0.1378737314371392, 0.16865708195837215, 0.10712702074670233, 0.14500170364044607, 0.1391259572119452, 0.14342697017127648, 0.09759333974216133, 0.12214362941449508, 0.20840796612901613, 0.0890961718687322, 0.19915564073016867, 0.15432108950335532, 0.09652989407186396, 0.13062928657745942, 0.1340857206378132, 0.1720627976465039, 0.04757997812703252, 0.08837755769491196, 0.0904619536595419, 0.12476965959649533, 0.08403525906032883, 0.17488180106738582, 0.2438343854737468, 0.26761373213957995, 0.4021666495827958, 0.11239282568567432, 0.09149333855020814, 0.12600396992638707, 0.1855530237662606, 0.0863517468678765, 0.0900790945161134, 0.16512086702277884, 0.16898662521271035, 0.14368773117894307], [0.08151096248184331, 0.032413759909104556, 0.06951763338292949, 0.03102872309682425, 0.054768097688793205, 0.04610193907865323, 0.1019107764295768, 0.05399334375397302, 0.025741668614500668, 0.02729028776229825, 0.04972864408046007, 0.06841851267381571, 0.02076337539619999, 0.019277354549558368, 0.06180255186336581, 0.04192598171357531, 0.06613006320549175, 0.03959255809604656, 0.056008352621574886, 0.058919278453686275, 0.03406150957744103, 0.10943371962639503, 0.06443320191465318, 0.020371903628984, 0.004810963037016336, 0.018449776398483664, 0.020555661249090917, 0.039649347236263566, 0.016633867198834196, 0.021898399354540743, 0.02253924758406356, 0.06740511002135463, 0.018393337923043873, 0.03984860646596644, 0.006097619361753459, 0.0559131165209692, 0.024162341251212638, 0.010347417173761642, 0.025430324676563032, 0.045316887844819576, 0.035643000301206484, 0.03412165322515648, 0.040184116587624885, 0.015859026061662007, 0.013560135503212223, 0.004513008370850002, 0.039604476987733506, 0.03793343130382709, 0.07401630253298208, 0.02334917189728003, 0.04001572327979375, 0.017074682509701233, 0.06092673967941664, 0.05822746694320813, 0.04974416980985552, 0.03754116543859709, 0.025923392749973573, 0.03934875887352973, 0.07309874825295992, 0.01961406880582217, 0.5312600021716207, 0.46133033582009375, 2.5729708978906274, 3.5109584033489227, 5.138743557035923, 5.68321586586535, 10.12574415653944, 10.72098221629858, 17.46236577630043, 24.719047285616398, 27.238908670842648, 37.81225360929966, 50.525505021214485, 54.88201305270195, 71.54636844992638, 76.90024316310883, 82.58251145482063, 86.2446865439415, 80.73515698313713, 85.16004234552383, 84.74894240498543, 83.76136779785156, 74.7822368144989, 63.81113111972809, 75.48164248466492, 69.19038087129593, 72.36477613449097, 69.20104309916496, 64.58227694034576, 60.889209508895874, 64.88211885094643, 58.76442052423954, 64.72790032625198, 62.59975992143154, 68.262257874012, 65.59095561504364, 67.1969698369503, 66.8371519446373, 67.16794699430466, 69.85880300402641, 68.65515679121017, 62.39815413951874, 57.875538021326065, 35.52867494523525, 13.657357301563025, 5.881194742396474, 0.25588910502847284, 0.025973370829888154, 0.01012125601846492, 0.0785932459984906, 0.0464488856960088, 0.027635688857117202, 0.020695637722383253, 0.017347540524497163, 0.027053197554778308, 0.07795379671733826, 0.0665363074222114, 0.09891653709928505, 0.03276413153798785, 0.06389982037944719, 0.09186315073748119, 0.02751360741967801, 0.034736359302769415, 0.03065763070480898, 0.026433238926983904, 0.10651880103978328, 0.10663885084795766, 0.03739864710951224, 0.023348533650278114, 0.03465942827460822, 0.05403971685154829, 0.07582748425193131, 0.11470475670648739, 0.07570235073217191, 0.012094900357624283, 0.03244361651013605, 0.056750062431092374, 0.02911787280027056, 0.02366748831263976, 0.08978204990853556, 0.016881544142961502, 0.011038275024475297, 0.06042049477400724, 0.015004540418885881, 0.014890351721987827, 0.04242171038640663, 0.02193377753428649, 0.05120961090142373, 0.01391761319609941, 0.034143876837333664, 0.04333894554292783, 0.049327075394103304, 0.012909444540127879, 0.06822893104981631, 0.03717030311236158, 0.06468317209510133, 0.0047007299872348085, 0.0059966928438370815, 0.048573212916380726, 0.01690808334387839, 0.05836883494339418, 0.006863719854663941, 0.06015922910592053, 0.02778288642730331, 0.04217813751893118, 0.08257654553744942, 0.04628692309779581, 0.02062053794361418, 0.023126536871131975, 0.04210602302919142, 0.006033597064742935, 0.05118792163557373, 0.05874741560546681, 0.018436052232573275, 0.028199439075251576, 0.03456666352576576, 0.10064878399134614, 0.06573831313289702, 0.0624902370327618, 0.020734149620693643, 0.0916470967058558, 0.017092531161324587, 0.04819199020857923, 0.03965244941355195, 0.061253789317561314, 0.027157118638569955, 0.06710553469019942, 0.06726976454956457, 0.037774552329210564, 0.016701972235750873, 0.05751339842390735, 0.03425282040552702, 0.052901440431014635, 0.025262129893235397, 0.03141670305922162, 0.0905067942221649, 0.008004945848369971, 0.0707355051417835, 0.0615866128646303, 0.030575840464734938, 0.014005651391926222, 0.006485699514087173, 0.006202996910360525, 0.026641986514732707, 0.031169582725851797, 0.038758128066547215, 0.01953919909283286, 0.028609464534383733, 0.017821919464040548, 0.0405572350427974, 0.03742659268027637, 0.057120063866022974, 0.04510303057031706, 0.07150578021537513, 0.023443174177373294, 0.015430583280249266, 0.033572386018931866, 0.027868515426234808, 0.0711720586696174, 0.041454573220107704, 0.07729227596428245, 0.07228534697787836, 0.07350795363890938, 0.040800537026370876, 0.030823172310192604, 0.010129866786883213, 0.03060340568481479, 0.036746017285622656, 0.03529174551658798, 0.009624869617255172, 0.01829291049944004, 0.03191088435414713, 0.01732739863655297, 0.06287095879088156, 0.1118236206821166, 0.030819340972811915, 0.4133776214439422, 0.43994009611196816, 2.753097382374108, 3.3609004179015756, 5.136152571067214, 6.147147221490741, 11.198130212724209, 11.970271579921246, 18.276582285761833, 28.79743304103613, 30.943377390503883, 44.9486468732357, 57.54350423812866, 63.03349904716015, 80.37680581212044, 85.89588806033134, 93.68181467056274, 97.1524116396904, 90.60752883553505, 97.24666178226471, 96.11246064305305, 94.79664444923401, 82.85998776555061, 75.05761563777924, 85.1630137860775, 79.58753496408463, 82.28674292564392, 78.91691654920578, 75.07959365844727, 70.23791626095772, 75.06339892745018, 67.55030527710915, 72.61457473039627, 73.45087185502052, 80.47319144010544, 77.13508576154709, 75.99106594920158, 78.80689725279808, 76.13716810941696, 81.19582146406174, 79.82954397797585, 74.15498927235603, 68.36441919207573, 46.56800597906113, 18.73987052589655, 7.5664617866277695, 0.46877330518327653, 0.06961544102523476, 0.05407247896073386, 0.11484476286568679, 0.05078826397948433, 0.04308223295083735, 0.05766583555669058, 0.1284140648203902, 0.044494257963378914, 0.08608294097939506, 0.01663865590671776, 0.045481496199499816, 0.038058312493376434, 0.0331954269495327, 0.0034328729589105933, 0.01855202022852609, 0.048112357762875035, 0.0038817087988718413, 0.010907490977842826, 0.05639201699523255, 0.040465030615450814, 0.10774251350085251, 0.01673524828220252, 0.014503505390166538, 0.013491540648828959, 0.012223368903505616, 0.07252009570947848, 0.07937358459457755, 0.027768054605985526, 0.03991228273662273, 0.011054478891310282, 0.05653788612107746, 0.05037833128881175, 0.0438452423986746, 0.005484463445100118, 0.03427560433920007, 0.053792522303410806, 0.010287508230248932, 0.0300821081691538, 0.014065055675018812, 0.044668243353953585, 0.009525953391857911, 0.03477980091702193, 0.054680709799868055, 0.019259494765719865, 0.04462782228074502, 0.039403685223078355, 0.026433025559526868, 0.071305956953438, 0.08798254959401675, 0.04789793645613827, 0.02599565381387947, 0.053131817912799306, 0.026826063258340582, 0.033347622884321027, 0.007905961901997216, 0.030905259409337305, 0.04812174222024623, 0.07788105140207335, 0.03679586363432463, 0.04977537340892013, 0.05235919765254948, 0.023626594120287336, 0.04218823814881034, 0.03068171710765455, 0.04264552357199136, 0.08301338108140044, 0.03846417079330422, 0.015380545828520553, 0.04674955198424868, 0.1561989457695745, 0.11731330931070261, 0.17223214090336114, 0.09173877420835197, 0.21902737207710743, 0.22236203454667702, 0.1643352591781877, 0.12238850846188143, 0.0770139557425864, 0.2698264899663627, 0.1565948370262049, 0.297527537913993, 0.2031609375262633, 0.13291504204971716, 0.1811493866262026, 0.18172217620303854, 0.19312190590426326, 0.07488206974812783, 0.15447397192474455, 0.200534209725447, 0.17681886587524787, 0.18194007076090202, 0.20932382089085877, 0.08340214029885828, 0.07709704659646377, 0.09783415182027966, 0.13683928147656843, 0.1120937401719857, 0.14960484491894022, 0.14684509456856176, 0.126180155784823, 0.1453924592351541, 0.19556965737137944, 0.1089764156495221, 0.14141496329102665, 0.19265251234173775, 0.1152473631373141, 0.13877931487513706, 0.07993108592927456, 0.09027122912812047, 0.0902750511886552, 0.14681944594485685, 0.13928764150477946, 0.11058318021241575, 0.13317062286660075, 0.1276181114371866, 0.23888561117928475, 0.13372236513532698, 0.42778478586114943, 0.08676527897478081, 0.19244051043642685, 0.07632628170540556, 0.139520215743687, 0.16603121504886076, 0.17577358055859804, 0.13288563815876842, 0.15047810040414333, 0.15673299523768947, 0.23950393893755972, 0.1362723103375174, 0.8100126881618053, 0.9017156017944217, 4.413321632891893, 6.163395149633288, 8.870155680924654, 11.123755853623152, 17.134770154953003, 18.989501930773258, 28.81072662770748, 38.57177585363388, 41.56408868730068, 56.978649348020554, 68.61028119921684, 74.49970677495003, 91.65116563439369, 98.32811415195465, 105.30412182211876, 110.3762036561966, 104.15796652436256, 109.40602451562881, 108.17861437797546, 105.82762733101845, 95.93624129891396, 89.22792926430702, 100.86484283208847, 95.04907250404358, 92.60862305760384, 89.34820801019669, 86.42806470394135, 83.17675396800041, 87.00985908508301, 78.2758529484272, 84.91892248392105, 82.83250004053116, 92.36819475889206, 87.46080368757248, 89.88008826971054, 90.40002956986427, 89.60055246949196, 92.11126774549484, 88.8414216041565, 86.01061150431633, 79.76563140749931, 55.79399451613426, 24.014629684388638, 9.958136100322008, 1.0141109582036734, 0.22779439226724207, 0.16609880985924974, 0.20938829868100584, 0.13891998154576868, 0.10517793314647861, 0.14492110640276223, 0.23235843720613047, 0.07602301047882065, 0.24049086176091805, 0.18132653727661818, 0.13584513013483956, 0.07759818181511946, 0.07655990979401395, 0.1504580772598274, 0.18306354875676334, 0.10531733074458316, 0.17872064898256212, 0.10568804835202172, 0.23269773228093982, 0.20156904560280964, 0.18706986971665174, 0.13509683747543022, 0.10447589855175465, 0.1322288968367502, 0.21229117963230237, 0.20985784067306668, 0.19293325196485966, 0.09832272247876972, 0.16247736668447033, 0.09561642160406336, 0.12176428062957712, 0.2416471129981801, 0.19629138114396483, 0.14553045417414978, 0.11722749477485195, 0.1765472991974093, 0.10631818367983215, 0.1575659224181436, 0.13035725976806134, 0.13753203180385754, 0.11958031813264824, 0.1565604904317297, 0.146387085551396, 0.11205668473849073, 0.13416190951829776, 0.11213248028070666, 0.16209401772357523, 0.14817013987340033, 0.21846100949915126, 0.154539295763243, 0.10086612935992889, 0.19133048015646636, 0.1462507975520566, 0.21897168131545186, 0.07908556450274773, 0.0901236011122819, 0.15799856482772157, 0.19174255023244768, 0.1051472156541422, 0.14694626413984224, 0.16285118646919727, 0.06517550544231199, 0.07883924568886869, 0.14115463272901252, 0.11087175691500306, 0.23346413334365934, 0.10342017863877118, 0.08720990706933662, 0.1193702309683431], [0.04771928666741587, 0.04765696852700785, 0.04889349787845276, 0.0829591004003305, 0.06251924758544192, 0.01314084247496794, 0.0313813397224294, 0.05147815332747996, 0.05583293859672267, 0.014034212017577374, 0.008518007380189374, 0.09280912927351892, 0.03737546983757056, 0.012918300217279466, 0.04609367897501215, 0.03394363426195923, 0.039854554779594764, 0.05435209794086404, 0.015223277314362349, 0.019183539661753457, 0.02998656222189311, 0.038443223675130866, 0.03029147359484341, 0.06244758580578491, 0.02416869960143231, 0.04971023881807923, 0.049822451546788216, 0.0037517487680815975, 0.006868451509944862, 0.09425517433555797, 0.06600967943086289, 0.046400646097026765, 0.02565057555329986, 0.01641466275032144, 0.09613867834559642, 0.08401706159929745, 0.04118822755117435, 0.0421004940290004, 0.01200788725327584, 0.04473237604543101, 0.043438122447696514, 0.08260433154646307, 0.03983000082371291, 0.029273798027134035, 0.036366742715472355, 0.007566041103928001, 0.0548854646331165, 0.03475556237390265, 0.027099891631223727, 0.050339951121713966, 0.02642632396600675, 0.05002582969609648, 0.08546856886823662, 0.08269678830401972, 0.051904609936173074, 0.020793742223759182, 0.06924074550624937, 0.04015281279862393, 0.38431209046393633, 2.047470258548856, 3.604027284309268, 12.251212354749441, 23.542066141963005, 20.068634524941444, 32.055562511086464, 35.55839695036411, 41.184261068701744, 41.69245719909668, 56.422017216682434, 52.69947096705437, 61.92379519343376, 72.1625205874443, 73.99061769247055, 73.57226774096489, 75.08774802088737, 69.92794409394264, 71.40465125441551, 50.72785556316376, 60.09644664824009, 61.37494884431362, 47.21394471824169, 44.0912988781929, 42.585481479763985, 31.49896077811718, 46.30338057875633, 41.302529722452164, 46.4524731785059, 42.864656299352646, 44.256468415260315, 52.14971266686916, 43.07601995766163, 52.759743332862854, 52.75324188172817, 48.009014055132866, 48.07158909738064, 54.954589158296585, 51.73777297139168, 41.797464564442635, 56.6517186909914, 56.15777179598808, 64.76643785834312, 64.94723975658417, 72.29580983519554, 71.1934357881546, 58.54662761092186, 28.15453603863716, 14.825623612850904, 6.592380730435252, 0.3181524155661464, 0.058850678033195436, 0.04472456865187269, 0.14817057031905279, 0.028467296870076098, 0.0425665701914113, 0.07479935738956556, 0.008959780061559286, 0.0984263708232902, 0.04661425104131922, 0.04711790585133713, 0.07769550706143491, 0.07930748150101863, 0.043365814999560826, 0.03571836539776996, 0.1339633998577483, 0.045477236271835864, 0.049912054746528156, 0.06779468560125679, 0.040435526534565724, 0.004156094710197067, 0.012692364489339525, 0.12797806790331379, 0.01162065593234729, 0.04176913993433118, 0.014895053227519384, 0.05184051435207948, 0.038710137087036856, 0.02361440063396003, 0.05819271958898753, 0.005659797225234797, 0.028018188058922533, 0.1010901021072641, 0.0352847025351366, 0.06882572910399176, 0.04414399394590873, 0.02837493102560984, 0.09978722475352697, 0.022730565833626315, 0.06007878029777203, 0.05448313524539117, 0.009368718274345156, 0.00147148623227622, 0.030422349482250866, 0.024794754972390365, 0.04184497629466932, 0.05522773200937081, 0.0326799534377642, 0.04840259316551965, 0.020924200653098524, 0.02332246756850509, 0.03997477157099638, 0.018386662304692436, 0.07097901121596806, 0.04606821217748802, 0.0830742742982693, 0.01684096350800246, 0.04053348631714471, 0.004510129765549209, 0.009748373195179738, 0.06364018743624911, 0.02895768207963556, 0.008968251677288208, 0.020258830008970108, 0.05712006015528459, 0.055368728935718536, 0.04219558170007076, 0.0524992446298711, 0.06934629374882206, 0.0545148880337365, 0.04311263874114957, 0.062023240607231855, 0.03181059793860186, 0.05826400658406783, 0.031011008031782694, 0.0770574901252985, 0.02538344506319845, 0.04551712299871724, 0.016522841906407848, 0.07124194671632722, 0.04148482687014621, 0.003691077499752282, 0.02014977697399445, 0.0309308226860594, 0.0670863279083278, 0.05098586821986828, 0.06180530894198455, 0.027650923293549567, 0.034816963961930014, 0.045013983981334604, 0.032705494450055994, 0.04051165975397453, 0.04154878144618124, 0.04009524069260806, 0.04675846146710683, 0.11643669189652428, 0.0339682735648239, 0.0064391668547614245, 0.08200732569093816, 0.056011265551205724, 0.08339438485563733, 0.021408824941318016, 0.01824403636419447, 0.049168816112796776, 0.053840776745346375, 0.015858701372053474, 0.06801771582104266, 0.035817156385746785, 0.021046152214694303, 0.03018003084434895, 0.061843173316447064, 0.059487637408892624, 0.03337042166094761, 0.06002117479511071, 0.04764950252138078, 0.05018733587348834, 0.03428627642279025, 0.08012345802853815, 0.0343135095317848, 0.029809313236910384, 0.07722810987615958, 0.05462454035296105, 0.042379036894999444, 0.04562404050375335, 0.06718366799759679, 0.09705672244308516, 0.6141655566170812, 2.687616446055472, 4.394379649311304, 14.775145221501589, 26.37506492435932, 22.436036691069603, 35.05183093249798, 37.63611026108265, 45.466650277376175, 46.23751871287823, 63.994912058115005, 61.78445287048817, 70.09551510214806, 81.49573177099228, 82.64187186956406, 82.96736240386963, 83.68862450122833, 79.64748814702034, 79.49178010225296, 62.187527641654015, 74.58220034837723, 72.75563076138496, 55.18961414694786, 53.506232276558876, 54.1963854432106, 41.14954613149166, 58.695659413933754, 50.54674968123436, 56.18446156382561, 54.32539992034435, 53.034012615680695, 60.505582094192505, 51.18444286286831, 63.012178391218185, 63.81080433726311, 57.308650240302086, 59.844554364681244, 62.17727579176426, 64.6610315144062, 51.14111378788948, 65.25971218943596, 66.33839830756187, 72.11339682340622, 74.95113775134087, 82.51239761710167, 81.59116744995117, 74.4445489346981, 37.74462103843689, 19.63990543037653, 8.430207688361406, 0.6597710063215345, 0.18172461044741794, 0.028454244347813074, 0.02198844598751748, 0.06045123082003556, 0.06418641554773785, 0.05756934893724974, 0.0247832164313877, 0.029373898905760143, 0.02763878361292882, 0.028189640870550647, 0.030415753644774668, 0.043592470610747114, 0.04067126974405255, 0.054073172868811525, 0.10054093509097584, 0.01489775186200859, 0.006323555553535698, 0.0429800837446237, 0.05381489434512332, 0.01564561593113467, 0.029375383201113436, 0.046416598561336286, 0.07449701384757645, 0.028409147744241636, 0.03702951027662493, 0.01504474348621443, 0.07811501345713623, 0.026731688049039803, 0.035362245835131034, 0.05829072018968873, 0.035702386958291754, 0.03008457581017865, 0.04896117061434779, 0.03501220817270223, 0.05169195123016834, 0.03394888866750989, 0.1092763917404227, 0.037573025838355534, 0.050470439236960374, 0.030165994976414368, 0.02165356112527661, 0.020992057070543524, 0.042065119559993036, 0.05558854194532614, 0.043379136550356634, 0.02265295945107937, 0.028128521298640408, 0.042181380704278126, 0.014023164221725892, 0.019951343383581843, 0.015134637978917453, 0.04993789261789061, 0.02388030472502578, 0.020674581137427595, 0.028772460573236458, 0.015726309648016468, 0.033117349303211085, 0.03874534086207859, 0.04186687707260717, 0.023437814015778713, 0.048866565339267254, 0.08668923852383159, 0.01732546905259369, 0.050787469881470315, 0.05522274848772213, 0.06900569249410182, 0.08555720356525853, 0.15264496381860226, 0.17773797124391422, 0.16202140599489212, 0.11859707636176609, 0.1194520750141237, 0.16699827800039202, 0.08911822849768214, 0.12118555387132801, 0.1400805075536482, 0.21802263770950958, 0.08240938419476151, 0.2070651834947057, 0.12582698254846036, 0.05985298928862903, 0.09435112660867162, 0.1276241079904139, 0.19822853500954807, 0.1278638662188314, 0.15059203491546214, 0.10164695035200566, 0.20170267671346664, 0.20316501933848485, 0.150386460009031, 0.12283675081562251, 0.10566529410425574, 0.09548926944262348, 0.1479788587312214, 0.23604931571753696, 0.10535352528677322, 0.26834442105609924, 0.21282224566675723, 0.20482263586018234, 0.14224413520423695, 0.10139465724932961, 0.3454350703395903, 0.10704319516662508, 0.11608017899561673, 0.14058803266379982, 0.16783580649644136, 0.08056850172579288, 0.19554939673980698, 0.14103269786573946, 0.12637776002520695, 0.1485349499853328, 0.10302741182385944, 0.09195513994200155, 0.0982813180598896, 0.15715141809778288, 0.10498617702978663, 0.16440013772808015, 0.11486909046652727, 0.12650849675992504, 0.18084305775118992, 0.17626627755817026, 0.15644265222363174, 0.09717728433315642, 0.15598152618622407, 0.19854059326462448, 0.9903470927383751, 3.653695131652057, 7.264149058610201, 20.148272551596165, 32.92170323431492, 30.836850106716156, 46.186297461390495, 50.27515545487404, 58.188797011971474, 59.92703653872013, 77.37669959664345, 74.79974627494812, 83.71401473879814, 94.87290635704994, 97.06035777926445, 96.41210496425629, 95.779530107975, 92.33765959739685, 92.83661842346191, 72.72338569164276, 82.89400354027748, 84.50763255357742, 65.63899263739586, 66.43314242362976, 61.66003234684467, 51.273103505373, 71.22884228825569, 60.241595059633255, 66.62267625331879, 62.26115249097347, 63.65981563925743, 74.47132229804993, 62.9412741959095, 72.16203421354294, 74.04881536960602, 68.68137538433075, 68.28744292259216, 77.30065807700157, 74.59931463003159, 61.501265466213226, 79.98353451490402, 75.99400699138641, 84.79658424854279, 88.59828785061836, 91.73036858439445, 91.43517002463341, 84.93981376290321, 46.21206007897854, 23.463174775242805, 11.303593553602695, 1.8689105962403119, 0.38688511645887047, 0.1276773793506436, 0.21654698095517233, 0.13931536814197898, 0.19109950895654038, 0.1808447201619856, 0.07909352774731815, 0.1605791607289575, 0.09296649426687509, 0.07692739163758233, 0.11872125251102261, 0.16203719889745116, 0.10292776365531608, 0.24360054958378896, 0.32650879060383886, 0.10849909594981, 0.07444766844855621, 0.17894060671096668, 0.12262503092642874, 0.07948189362650737, 0.09401911200257018, 0.17183999007102102, 0.14693041186546907, 0.15831872733542696, 0.0737665401538834, 0.16321374045219272, 0.1325234552496113, 0.12100236213882454, 0.14401745254872367, 0.13328483939403668, 0.14992417622124776, 0.16950022109085694, 0.13736816559685394, 0.1340678200358525, 0.18833888287190348, 0.1005164219532162, 0.2236483248998411, 0.1194480006233789, 0.174786331190262, 0.13550305942771956, 0.14895570318913087, 0.18136547034373507, 0.24079091206658632, 0.15813241858268157, 0.13090322812786326, 0.22439287713496014, 0.16910250415094197, 0.20537292351946235, 0.06988349734456278, 0.11223871872061864, 0.14384166745003313, 0.09777745173778385, 0.2388067208812572, 0.11680736497510225, 0.16039898211602122, 0.12963694607606158, 0.1257514170720242, 0.08412413124460727, 0.1654838366084732, 0.1363037180271931, 0.2044699079124257, 0.2239196837763302, 0.1333844059263356, 0.11844472828670405, 0.16535026486963034, 0.14297721383627504, 0.19305704219732434], [0.07685975971980952, 0.03527461303747259, 0.026006813859567046, 0.07641096075531095, 0.00922487521165749, 0.03545663959812373, 0.04851230485655833, 0.024303837271872908, 0.07377265545073897, 0.03629331091360655, 0.025682951745693572, 0.015389210402645404, 0.04566718896967359, 0.042135556795983575, 0.01766525580023881, 0.011932713259739103, 0.05892043249332346, 0.07262318744324148, 0.027545606972125825, 0.055534172206535004, 0.07870374436606653, 0.0611079424561467, 0.04781209223438054, 0.019081757818639744, 0.05716281528293621, 0.0891831515764352, 0.055940757811185904, 0.023802000723662786, 0.003967427783209132, 0.0531736045377329, 0.014205891184246866, 0.029242403325042687, 0.03422268549911678, 0.03412095189560205, 0.03983523296483327, 0.011179927823832259, 0.018825468250724953, 0.047086791309993714, 0.04243921022862196, 0.05388257450249512, 0.052520789176924154, 0.036761142255272716, 0.01637531222513644, 0.033802025063778274, 0.03847530300845392, 0.04119691067899112, 0.05356693909561727, 0.06762477831216529, 0.0882777759397868, 0.01903145319374744, 0.012626667721633567, 0.06602729801670648, 0.041123304472421296, 0.033630440520937555, 0.04385407024528831, 0.23221582610858604, 2.4632061878219247, 7.9599320981651545, 18.87686837464571, 26.111220382153988, 35.678744092583656, 50.571569949388504, 60.08583761751652, 58.09923581779003, 65.07351458072662, 63.171101063489914, 69.48039650917053, 71.2807247042656, 72.81705066561699, 71.3629674911499, 73.19116339087486, 69.20008555054665, 60.96643656492233, 51.09828628599644, 46.038907170295715, 45.2509206533432, 42.89028972387314, 26.881408654153347, 36.6525786370039, 45.275106355547905, 57.71055847406387, 39.35210198163986, 20.042319037020206, 14.127424377948046, 14.832581989467144, 17.929983884096146, 21.277326866984367, 22.30943888425827, 19.79651402682066, 24.833164662122726, 19.599523097276688, 19.990628510713577, 28.558568358421326, 29.739810973405838, 30.986185893416405, 29.412897415459156, 25.571117363870144, 32.29002133011818, 36.09693445265293, 31.55139036476612, 39.892239198088646, 47.19536751508713, 57.485435754060745, 63.41233491897583, 71.29198729991913, 69.08141791820526, 53.876875787973404, 42.27288365364075, 20.797416418790817, 13.056253306567669, 5.878480738028884, 1.437823015730828, 0.6430483411531895, 0.06714532864862122, 0.049896963173523545, 0.08061277825618163, 0.04624671724741347, 0.04519001398875844, 0.020086898512090556, 0.07849900808651, 0.015063561568240402, 0.08642160522867925, 0.022108588564151432, 0.063683855405543, 0.031058345921337605, 0.051803967289743014, 0.01981210534722777, 0.035432671938906424, 0.040592906370875426, 0.053002379936515354, 0.06452905770856887, 0.039849771637818776, 0.026422086302773096, 0.012906544598081382, 0.03321535361465067, 0.05363280841265805, 0.0706142901617568, 0.05824753090564627, 0.024056256806943566, 0.06703283390379511, 0.03118607695796527, 0.017638957797316834, 0.031982201035134494, 0.03613840613979846, 0.0501504066050984, 0.02737842336500762, 0.06441034376621246, 0.131022313144058, 0.04502144627622329, 0.09934898655046709, 0.059188499944866635, 0.036581969252438284, 0.05667929865012411, 0.023723607664578594, 0.010019101246143691, 0.02853070225683041, 0.016042750285123475, 0.0175522749486845, 0.027054218007833697, 0.0335828911192948, 0.05695466883480549, 0.02826257357810391, 0.06684298510663211, 0.13757323584286496, 0.014147780093480833, 0.066768911347026, 0.06449366468586959, 0.034697411392698996, 0.09038530464749783, 0.008811050884105498, 0.022806995912105776, 0.008798604139883537, 0.05774133423983585, 0.0726063629554119, 0.04792345891473815, 0.014832048600510461, 0.014388953968591522, 0.038614303557551466, 0.031117387479753233, 0.08362687003682368, 0.0790310834418051, 0.04885019356152043, 0.022229026144486852, 0.050024471565848216, 0.010714448162616463, 0.04855793209571857, 0.06528194426209666, 0.05838296172441915, 0.018504070067137945, 0.021033554257883225, 0.06567925302078947, 0.07080847310135141, 0.020447636088647414, 0.012083075162081514, 0.020526450316538103, 0.0562749060918577, 0.015733812761027366, 0.05185327187064104, 0.06631596377701499, 0.027730032525141723, 0.03168028422805946, 0.05596580529527273, 0.0059237805453449255, 0.025155128896585666, 0.010844612515938934, 0.03652340266853571, 0.05365221557440236, 0.043713025079341605, 0.008448945900454419, 0.011055742397729773, 0.04325448542658705, 0.011186727751919534, 0.010704924552555894, 0.04552961705485359, 0.060287119704298675, 0.1185085010365583, 0.03610463099903427, 0.07740226967143826, 0.05264500985504128, 0.03440766209678259, 0.09961722840671428, 0.046088676899671555, 0.0011271132439105713, 0.049524768692208454, 0.04642357103875838, 0.049640810902928934, 0.03925181954400614, 0.036898023972753435, 0.01919882790389238, 0.06807215977460146, 0.03277328964031767, 0.3074875456513837, 3.1530168978497386, 10.567011628299952, 22.446499429643154, 32.95295275747776, 43.110506907105446, 57.70824819803238, 65.17037898302078, 63.93703356385231, 73.27374055981636, 71.31806150078773, 77.51306667923927, 81.63519188761711, 81.13821655511856, 80.75018897652626, 85.07729798555374, 79.92890104651451, 71.25707477331161, 61.94716393947601, 59.05961148440838, 57.07034982740879, 51.28337815403938, 33.64126682281494, 41.18678793311119, 57.30191320180893, 63.42150762677193, 49.04154025018215, 28.2853402197361, 24.30700309574604, 31.081642471253872, 30.293302573263645, 32.028234377503395, 36.04501783847809, 34.74163077771664, 36.16248473525047, 31.498045027256012, 30.445334315299988, 39.327992275357246, 35.979148373007774, 37.17458702623844, 40.731705352663994, 38.04876811802387, 39.771139696240425, 47.12126009166241, 41.3788828253746, 51.678507551550865, 55.225890800356865, 66.9921912252903, 70.95817521214485, 81.30002707242966, 82.66974717378616, 68.0598047375679, 53.47128555178642, 30.227488204836845, 16.993716023862362, 7.717877961695194, 1.795251548755914, 0.6873171532060951, 0.05857208692759741, 0.02940169048088137, 0.011742849619622575, 0.007394990443572169, 0.08787550221313722, 0.008208801755245076, 0.07143673079553992, 0.041625849771662615, 0.053660204794141464, 0.028952427674084902, 0.037360908900154755, 0.027684036067512352, 0.06785837671486661, 0.07394534579361789, 0.028373274180921726, 0.07017120573436841, 0.017214720210176893, 0.08423225473961793, 0.02778751000732882, 0.011457529089966556, 0.0066824108580476604, 0.055548907548654824, 0.042352564487373456, 0.021226920835033525, 0.04793481377419084, 0.035790969704976305, 0.03690256220579613, 0.04908766597509384, 0.030700031456945, 0.01718542949674884, 0.0884364842204377, 0.05401288821303751, 0.01103718313970603, 0.013254008863441413, 0.07461241038981825, 0.05520888516912237, 0.033735959077603184, 0.06200316180184018, 0.04524507763562724, 0.04040141371660866, 0.046350933334906586, 0.02691534362384118, 0.015667457337258384, 0.03300420146842953, 0.02276446899486473, 0.0098244488981436, 0.025224822129530367, 0.034192420716863126, 0.03412221725739073, 0.030094765497779008, 0.048299434638465755, 0.05345097109966446, 0.0696302394499071, 0.04096618067706004, 0.05245482338068541, 0.055262724272324704, 0.02496264918590896, 0.0178776139364345, 0.07218162441859022, 0.01753586420818465, 0.04095861819223501, 0.018902701704064384, 0.031504751459578983, 0.18139592808438465, 0.14888972626067698, 0.09392793173901737, 0.14172011957271025, 0.1398859906475991, 0.15640823141438887, 0.08067607603152283, 0.12409737770212814, 0.17480154521763325, 0.1904594065854326, 0.15670369524741545, 0.15782761853188276, 0.1960216846782714, 0.21558091248152778, 0.21163682802580297, 0.18076004111208022, 0.18823706021066755, 0.17110345303080976, 0.07969934289576486, 0.14615140913520008, 0.1002581619832199, 0.15071676025399938, 0.16352615493815392, 0.09480334687395953, 0.08037068968405947, 0.20742898428579792, 0.12126349422032945, 0.2414612495340407, 0.13706214842386544, 0.11975440371315926, 0.11158507957588881, 0.11440839487477206, 0.06591759374714456, 0.07772369383019395, 0.11839821047033183, 0.1213706232374534, 0.12129225986427628, 0.1711938763037324, 0.10475653427420184, 0.1611227245302871, 0.1879993503098376, 0.08340324609889649, 0.21165512938750908, 0.13255420984933153, 0.16499364806804806, 0.1579378719907254, 0.15914168005110696, 0.1356066038715653, 0.14826578786596656, 0.12030763027723879, 0.12785092316335067, 0.14823690347839147, 0.10366596310632303, 0.15579803759464994, 0.18571591033833101, 0.6261258898302913, 4.996596509590745, 16.390823274850845, 32.788527980446815, 45.37118799984455, 57.633829191327095, 72.40945413708687, 77.16966390609741, 79.43121135234833, 85.49313247203827, 81.69792652130127, 88.8663862645626, 91.22594565153122, 91.74930676817894, 91.26193732023239, 93.85485738515854, 90.09932890534401, 79.55507710576057, 70.12402877211571, 64.98838394880295, 65.26247844099998, 62.57056228816509, 45.00312454998493, 55.02768963575363, 65.49279928207397, 73.00704807043076, 58.89177069067955, 34.69793692231178, 26.796065233647823, 34.6910896897316, 33.88590529561043, 35.90058758854866, 36.94268926978111, 36.043231934309006, 41.88371613621712, 36.14789351820946, 35.51685757935047, 45.39259985089302, 47.90293514728546, 47.982643470168114, 48.97514261305332, 41.66395492851734, 49.4509606808424, 53.42573739588261, 50.242275819182396, 58.24516698718071, 68.16287040710449, 79.63180258870125, 81.96272671222687, 92.10535526275635, 94.42888498306274, 78.41891527175903, 61.60896688699722, 38.4960725158453, 23.726971819996834, 10.809298027306795, 3.012910815887153, 1.3572338526137173, 0.23469344159821048, 0.10406584711745381, 0.2075092401355505, 0.14174990938045084, 0.1450707679032348, 0.12084602130926214, 0.22169289935845882, 0.1346801660838537, 0.1812697184504941, 0.15224356582621112, 0.14758384320884943, 0.16891754610696808, 0.20842896890826523, 0.1829928220831789, 0.14426022389670834, 0.18462814448866993, 0.12775341980159283, 0.1838504776242189, 0.1351624433300458, 0.07094771484844387, 0.10251639861962758, 0.1505748022464104, 0.11350909000611864, 0.14107666269410402, 0.11539964441908523, 0.16035154403652996, 0.17747146601323038, 0.2092082833405584, 0.08887476695235819, 0.11952798187849112, 0.2152333498816006, 0.18922294402727857, 0.07180880653322674, 0.09609383036149666, 0.22945258766412735, 0.19777647801674902, 0.17166828678455204, 0.21443144447403029, 0.1855764162610285, 0.16549952561035752, 0.14737090619746596, 0.1321227548760362, 0.11089978783275001, 0.07680614697164856, 0.12009346130071208, 0.208722933602985, 0.08457822914351709, 0.11367707513272762, 0.12430700473487377, 0.17257265310036018, 0.20957411761628464, 0.18736566009465605, 0.16269883839413524, 0.14558495749952272, 0.15245212416630238, 0.1813123919419013, 0.19873180019203573, 0.19582949811592698, 0.18365656927926466, 0.12606147152837366, 0.14642668655142188, 0.24588489497546107, 0.1747997195343487], [0.0567788948683301, 0.010575997730484232, 0.06494141722214408, 0.05406923206464853, 0.052904182666679844, 0.04693059890996665, 0.03933823521947488, 0.027945053116127383, 0.03227018773031887, 0.049683595716487616, 0.0336801384401042, 0.019723609802895226, 0.040546967429690994, 0.016593470245425124, 0.06667369380011223, 0.03906033431121614, 0.013491871832229663, 0.03970885634771548, 0.009217052047461038, 0.027583606788539328, 0.06778821407351643, 0.05421380985353608, 0.08463571590255015, 0.02017682825680822, 0.008659634204377653, 0.007421173877446563, 0.05495335630257614, 0.02533378981752321, 0.017997474496951327, 0.017546198614581954, 0.013623795075545786, 0.03983411232184153, 0.06113345378253143, 0.015516044368268922, 0.011483244506962365, 0.0168267235494568, 0.13992879772558808, 0.036431328117032535, 0.07738361207884736, 0.021879205560253467, 0.05573033296968788, 0.1113561715465039, 0.03450097232416738, 0.00823037969894358, 0.04344051216321532, 0.027411666014813818, 0.03403655857255217, 0.019523263326846063, 0.07403369847452268, 0.05614002817310393, 0.06633113327552564, 0.08100676961475983, 0.08750401277211495, 0.1459227385930717, 1.5249184984713793, 12.279547434300184, 29.40319463610649, 46.552020236849785, 64.83457580208778, 66.39550924301147, 71.09279438853264, 67.16258928179741, 74.11104843020439, 64.94502827525139, 61.86460196971893, 67.42476001381874, 61.47532805800438, 54.76873353123665, 55.703502371907234, 39.74399775266647, 33.39119844138622, 35.21899156272411, 21.695486828684807, 22.67507616430521, 24.229445457458496, 18.130445927381516, 22.530596517026424, 30.974011346697807, 49.97012302279472, 40.84082789719105, 79.2306125164032, 38.70603404939175, 10.829482544213533, 18.351453468203545, 13.113326244056225, 14.043173398822546, 17.14348878711462, 12.38302443176508, 15.204031057655811, 16.14805430173874, 16.37851383537054, 22.471883967518806, 17.76944249868393, 23.1428861618042, 19.99975372105837, 17.563632242381573, 16.709723062813282, 21.25088408589363, 17.216940745711327, 20.644107945263386, 19.02472034096718, 32.70719334483147, 30.351595245301723, 32.594977766275406, 43.847070783376694, 58.36209051311016, 60.23559518158436, 62.253815084695816, 64.26972851157188, 46.643834710121155, 34.68905679881573, 20.89102629572153, 5.585272321477532, 2.8939964342862368, 1.945632160641253, 0.2930767595535144, 0.040398048076895066, 0.03506472996377852, 0.02894384288083529, 0.03984977534855716, 0.055909027287270874, 0.04037006168800872, 0.08790696927462704, 0.044137411096016876, 0.03560951830877457, 0.05740568682085723, 0.056154552003135905, 0.0429520194302313, 0.019150758998875972, 0.025540554015606176, 0.04822277078346815, 0.022417516811401583, 0.03331724306917749, 0.022823623730801046, 0.006509552140414598, 0.10280210321070626, 0.02386653231951641, 0.06157152871310245, 0.04295223465305753, 0.06838953180704266, 0.033931815560208634, 0.12496759038185701, 0.02467215588694671, 0.06731540663167834, 0.03646119585027918, 0.02743485070823226, 0.01106190686186892, 0.06452441186411306, 0.015255206362780882, 0.032993651839205995, 0.0654847732221242, 0.03624140139436349, 0.0723782044951804, 0.03613419445173349, 0.05604463993222453, 0.036686296662082896, 0.03870503853249829, 0.019518558110576123, 0.05839934463438112, 0.022094224295869935, 0.031516113740508445, 0.0203523610252887, 0.059906204987782985, 0.035552239351090975, 0.06183909521496389, 0.046347385869012214, 0.0636295227741357, 0.07848016495699994, 0.05132737860549241, 0.06753307854523882, 0.03609597755712457, 0.056223464125650935, 0.11718629073584452, 0.022883769233885687, 0.05160719796549529, 0.01361409613309661, 0.04159660173172597, 0.05211139083257876, 0.05990590070723556, 0.06541161972563714, 0.025161292433040217, 0.008739950353628956, 0.031885955613688566, 0.05745771137299016, 0.03054379081731895, 0.0295884111255873, 0.05921474970818963, 0.025001699141284917, 0.02721519354963675, 0.02995614158862736, 0.05632659296679776, 0.046439742436632514, 0.06802581265219487, 0.04175317633780651, 0.08860005356837064, 0.019401951867621392, 0.021296107552188914, 0.024184047215385363, 0.028119693452026695, 0.01725243986584246, 0.045181865207268856, 0.029746935724688228, 0.037595876565319486, 0.04194532579276711, 0.07403428477118723, 0.012331221514614299, 0.08246997313108295, 0.009246070021617925, 0.012749988545692759, 0.04675996060541365, 0.03030857082194416, 0.02598876668344019, 0.036236729574739, 0.06819155649282038, 0.029337524392758496, 0.023564350194646977, 0.04919814207823947, 0.01607150108611677, 0.07105509619577788, 0.03938667148759123, 0.03550212211848702, 0.023112812705221586, 0.03417000414629001, 0.03721548135217745, 0.047439715926884674, 0.027074365461885463, 0.019186265199095942, 0.07546601380454376, 0.059589738375507295, 0.13819086598232388, 2.2884207917377353, 16.34102124720812, 37.0673643797636, 56.54812105000019, 70.50320282578468, 73.6170369386673, 79.1466598212719, 77.76966691017151, 82.13690936565399, 76.81971788406372, 70.04666492342949, 76.41137659549713, 69.7085590660572, 63.746397793293, 66.67012050747871, 50.42253814637661, 46.83703154325485, 47.28889189660549, 34.031467884778976, 35.89429512619972, 36.27628102898598, 29.1370702162385, 32.95708693563938, 36.91423639655113, 50.187513157725334, 46.59435756504536, 79.05699223279953, 46.62101313471794, 17.94944453984499, 24.94171343743801, 16.053999848663807, 23.48822683095932, 27.568808868527412, 21.873366683721542, 23.219862431287766, 29.488197974860668, 26.888548471033573, 23.53412266820669, 24.86270047724247, 33.13877418637276, 27.925244942307472, 29.75614819675684, 23.027064576745033, 31.478232890367508, 32.05023519694805, 31.978992819786072, 32.48397432267666, 43.8969811052084, 41.80582411587238, 43.28080236911774, 54.554094448685646, 66.4643843472004, 69.59477797150612, 72.04778954386711, 73.37820455431938, 56.19545437395573, 41.41091890633106, 27.10289876908064, 7.507874630391598, 2.8140952717512846, 2.0493383333086967, 0.24465105962008238, 0.07818212587153539, 0.03459157371253241, 0.03012250512256287, 0.0761167734162882, 0.03802168008405715, 0.01752204912918387, 0.05022081415518187, 0.02192094765632646, 0.07557683129562065, 0.07098444373696111, 0.021462183503899723, 0.05859910852450412, 0.012949714400747325, 0.04596680140821263, 0.03429743832384702, 0.016273083238047548, 0.04240818103426136, 0.020708124357042834, 0.06537089066114277, 0.051819047730532475, 0.041635605302872136, 0.017859639119706117, 0.04970766356564127, 0.054354558160412125, 0.03557226991688367, 0.0697033187316265, 0.06620035201194696, 0.027527762031240854, 0.0799964542966336, 0.08898858272004873, 0.035362453636480495, 0.0695881003048271, 0.01233189408594626, 0.06017077321303077, 0.02294985006301431, 0.041953311301767826, 0.036363254621392116, 0.044252559018787, 0.04894762641924899, 0.06251549973967485, 0.027980242048215587, 0.06291599973337725, 0.0471629505045712, 0.0573541038465919, 0.018386159499641508, 0.03442283530603163, 0.008541285769751994, 0.03052942283829907, 0.06518412919831462, 0.028995179090998136, 0.040608947892906144, 0.04037054779473692, 0.018507010827306658, 0.03844176906568464, 0.034639620353118517, 0.027086137779406272, 0.0009683567816409777, 0.05045557030825876, 0.062406930956058204, 0.016477311146445572, 0.19001831853529438, 0.22097119042882696, 0.13555582612752914, 0.23633933218661696, 0.1261620325385593, 0.1016690069809556, 0.10420951948617585, 0.21285090741002932, 0.1020989405515138, 0.13637692347401753, 0.10191770808887668, 0.09099861548747867, 0.1395964194671251, 0.13165952113922685, 0.13867474626749754, 0.18918953253887594, 0.29788652958814055, 0.10335791987017728, 0.17128921259427443, 0.10342224180931225, 0.2033556770766154, 0.12014253952656873, 0.10063938840175979, 0.12432751769665629, 0.14323117677122355, 0.14791608788073063, 0.10269723032251932, 0.16632411105092615, 0.1390509112388827, 0.1202399686735589, 0.1436984329484403, 0.14335192419821396, 0.17246155359316617, 0.12400092076859437, 0.15894207201199606, 0.08810225801425986, 0.18963541486300528, 0.14474141760729253, 0.1254862328642048, 0.096720663132146, 0.12707322661299258, 0.20516589400358498, 0.10178339420235716, 0.11547472749953158, 0.16471145383547992, 0.12579480302520096, 0.23501630552345887, 0.14304621872724965, 0.2198233996750787, 0.10326815710868686, 0.18759568134555593, 0.16277774353511631, 0.23581160581670702, 0.4245390178402886, 3.541056588292122, 21.58757831901312, 48.42909671366215, 68.43047484755516, 83.74140366911888, 85.29621943831444, 88.75062167644501, 87.667056620121, 92.30622008442879, 85.40750026702881, 80.37268683314323, 86.82778805494308, 78.93924415111542, 73.48891541361809, 76.48434028029442, 58.75762268900871, 51.71144798398018, 51.050006076693535, 36.6701602935791, 38.31100344657898, 36.947245225310326, 33.266876712441444, 38.61829675734043, 48.29943247139454, 68.89531150460243, 58.98396134376526, 91.04262068867683, 51.618455573916435, 26.94953139871359, 33.169506937265396, 22.94298078864813, 25.596416406333447, 28.510664328932762, 20.067025311291218, 27.21815038472414, 28.134891092777252, 27.549475505948067, 36.166421324014664, 32.08702102303505, 38.37504141032696, 35.100339129567146, 32.070252522826195, 28.719371929764748, 35.35250499844551, 28.861752189695835, 36.907997131347656, 32.9843732714653, 51.767802760005, 45.6605538725853, 53.087008371949196, 65.81175416707993, 79.87022459506989, 80.82751482725143, 84.23772543668747, 84.22316461801529, 68.34324672818184, 50.62818691134453, 33.044204860925674, 11.076810322701931, 4.062774768099189, 2.9693309543654323, 0.6466430076397955, 0.2704586216714233, 0.0843349976639729, 0.09520704552414827, 0.1910206038155593, 0.1465820922749117, 0.07920229691080749, 0.15122700162464753, 0.09879008255666122, 0.1692658953834325, 0.1992730633355677, 0.13058106182143092, 0.14851114188786596, 0.06516452165669762, 0.12608593271579593, 0.18310295679839328, 0.10728736917371862, 0.14992101467214525, 0.10324720627977513, 0.11559369377209805, 0.20741083135362715, 0.18276560615049675, 0.2039043023250997, 0.19489287806209177, 0.16415224556112662, 0.13105073740007356, 0.19704132137121633, 0.1380168175091967, 0.1456569755100645, 0.11172593920491636, 0.1292145304614678, 0.10884682924370281, 0.21320114174159244, 0.08420560421654955, 0.16408257273724303, 0.19077725359238684, 0.1585046947002411, 0.15578096819808707, 0.14464263775153086, 0.12542010750621557, 0.18213491421192884, 0.11176526561030187, 0.1819545277976431, 0.13599605328636244, 0.15945885912515223, 0.20993958081817254, 0.1139308896381408, 0.14107787981629372, 0.1422650637687184, 0.15014941804111004, 0.14795071649132296, 0.1876292857923545, 0.11524236848345026, 0.14987519447458908, 0.10274820844642818, 0.15220491477521136, 0.13706787780392915, 0.19307709502754733, 0.17284718836890534, 0.16802405967609957, 0.06633307028096169], [0.016631614780635573, 0.021130181885382626, 0.02164724730391754, 0.03642348361609038, 0.02796964417939307, 0.03493004871415906, 0.019898476493835915, 0.025916570557455998, 0.017319160797342192, 0.053612970805261284, 0.014366937230079202, 0.04254819832567591, 0.029968565140734427, 0.03849805725621991, 0.024130805541062728, 0.04604198467859533, 0.029542064003180712, 0.01433972638551495, 0.0570315961522283, 0.05230055685387924, 0.04239799876813777, 0.07336091191973537, 0.036555392944137566, 0.10966146248392761, 0.023408163360727485, 0.039603879558853805, 0.04161073222348932, 0.04739508316561114, 0.012390199990477413, 0.05384454314480536, 0.05880542186787352, 0.03033818993571913, 0.024998266708280426, 0.08015603831154294, 0.015071114776219474, 0.0416573687834898, 0.10439041798235849, 0.004696042396972189, 0.021273802303767297, 0.05725158356653992, 0.019915182238037232, 0.0168633299836074, 0.05771246840595268, 0.03695428247738164, 0.020577613977366127, 0.02560732504207408, 0.021915544821240474, 0.04501926065131556, 0.027088366077805404, 0.060129591438453645, 0.14156008284771815, 0.827105714706704, 3.151021054945886, 13.295911196619272, 32.57613077759743, 62.12910197675228, 67.51010343432426, 71.59711092710495, 66.80020272731781, 64.80130478739738, 67.08561301231384, 58.779551312327385, 61.81722231209278, 53.537873178720474, 47.977749332785606, 43.943087831139565, 41.02933958172798, 40.793714225292206, 37.749769762158394, 20.53455412387848, 15.55353345349431, 18.105910643935204, 15.173989869654179, 12.320084609091282, 15.118126217275858, 16.282109208405018, 20.35141535103321, 33.64295773208141, 34.42591331899166, 29.03011165559292, 59.757045060396194, 56.648029088974, 30.647483468055725, 45.39214767515659, 45.07939025759697, 37.439991384744644, 30.500900633633137, 46.50606170296669, 56.6622631251812, 45.35865247249603, 34.30441863834858, 23.697523400187492, 25.552409067749977, 23.046354241669178, 25.733594745397568, 14.822471681982279, 23.619798570871353, 17.40331694483757, 16.719460040330887, 19.23759251832962, 16.74241840839386, 15.588350035250187, 20.39027016609907, 24.867676310241222, 37.24064268171787, 49.81941930949688, 45.3763747215271, 57.12070472538471, 56.08298420906067, 67.15801432728767, 60.70026084780693, 61.547740772366524, 44.49191518127918, 19.086417630314827, 9.54110562801361, 6.9695936143398285, 3.5978910885751247, 1.3777250843122602, 0.1648671118891798, 0.07940904441056773, 0.06929373485036194, 0.020471702082431875, 0.09322640180471353, 0.02551046920416411, 0.04878899606410414, 0.026879494180320762, 0.03489157206786331, 0.0213478111254517, 0.020785242777492385, 0.030990561863291077, 0.038952470567892306, 0.03442075729253702, 0.018970329911098816, 0.023311064469453413, 0.020118653155805077, 0.025979959245887585, 0.05175794671231415, 0.013102666398481233, 0.04114319403015543, 0.05259939003735781, 0.04038409941131249, 0.0033070230347220786, 0.058895373877021484, 0.04192116888589226, 0.029277323228598107, 0.015372852540167514, 0.027513570312294178, 0.02952373481093673, 0.05765636575233657, 0.10833625390660018, 0.020281155666452833, 0.048206068750005215, 0.006433985272451537, 0.016715744641260244, 0.06191723223309964, 0.06153383874334395, 0.016550553700653836, 0.018001699172600638, 0.05695145904610399, 0.03317794566100929, 0.023655359764234163, 0.050823939018300734, 0.008602743946539704, 0.03602179618610535, 0.1427911128848791, 0.0745211039611604, 0.017454265071137343, 0.0381563205155544, 0.047101916279643774, 0.04007529547379818, 0.01575003425386967, 0.04822559094463941, 0.026573384238872677, 0.0683261820813641, 0.018681265246414114, 0.03923558135284111, 0.02432455246889731, 0.034803987509803846, 0.011251917076151585, 0.013205749783082865, 0.031824283141759224, 0.04508295176492538, 0.015527531886618817, 0.04387612316349987, 0.027636531194730196, 0.02870808482839493, 0.012141756778873969, 0.057076893135672435, 0.02183338721806649, 0.0077599754240509355, 0.022340094110404607, 0.06324629997834563, 0.02541851525165839, 0.051849527735612355, 0.04408798035001382, 0.05736453844292555, 0.021509233811229933, 0.042447514861123636, 0.03342187104863115, 0.05594644266238902, 0.012113090397178894, 0.09610215725842863, 0.029136010889487807, 0.05637606453092303, 0.02548745891544968, 0.0659608535352163, 0.02736704067501705, 0.06898525374708697, 0.04895712590951007, 0.0698768773872871, 0.0436883264046628, 0.03895952468155883, 0.019651589936984237, 0.02242796810605796, 0.017102045494539198, 0.03534478310029954, 0.08537511763279326, 0.08175559662049636, 0.01516671452918672, 0.028406602177710738, 0.08807105812593363, 0.01794218635041034, 0.036378676450112835, 0.04547015247226227, 0.04354899559984915, 0.03512263974698726, 0.06728128268150613, 0.9799008001573384, 5.025215623900294, 20.35878885537386, 43.71019832789898, 71.89875394105911, 78.19600403308868, 79.93109732866287, 77.78738915920258, 73.14355194568634, 74.73668485879898, 67.06520810723305, 70.35150736570358, 59.78227190673351, 53.64028908312321, 52.265093475580215, 51.579652056097984, 48.741162568330765, 46.55406832695007, 29.650633558630943, 25.996001064777374, 25.75718577951193, 17.371976226568222, 18.751794286072254, 21.0159844905138, 21.433781571686268, 28.941696099936962, 36.57408244907856, 45.62040142714977, 36.972772255539894, 63.99206981062889, 47.658425867557526, 25.512817092239857, 29.206541888415813, 29.512778855860233, 29.139701575040817, 35.486649200320244, 35.25100104510784, 58.13332758843899, 42.57169961929321, 34.08025346696377, 37.07160495221615, 32.83982142806053, 31.0783214494586, 38.157598078250885, 23.81113350391388, 24.643720127642155, 22.925030551850796, 21.057938039302826, 32.6848429441452, 25.004548765718937, 28.878421895205975, 30.151805765926838, 35.93227028846741, 47.77895539999008, 60.334146693348885, 57.05205000936985, 63.1885839253664, 63.35261732339859, 75.3109784424305, 69.95176881551743, 70.32327488064766, 53.12464155256748, 26.10607735812664, 13.381766639649868, 8.172268979251385, 4.150090282782912, 1.5215424983762205, 0.1785131890210323, 0.09764118600287475, 0.013205016912252177, 0.034427410646458156, 0.09435219530132599, 0.03506040695356205, 0.03947095348848961, 0.031053870770847425, 0.043581112040556036, 0.02229488247394329, 0.04230317455949262, 0.029308085249795113, 0.03968066957895644, 0.07278365461388603, 0.10544352553552017, 0.01741646192385815, 0.04583831709169317, 0.023095208962331526, 0.08330053286044858, 0.09861523256404325, 0.04329837604018394, 0.035833773072226904, 0.05900176445720717, 0.035990325413877144, 0.010383192402514396, 0.015023119158286136, 0.04822247021365911, 0.029874726133130025, 0.04556342559226323, 0.028415734304871876, 0.05374771513743326, 0.08659746454213746, 0.029399282211670652, 0.03819680838205386, 0.041116038846666925, 0.011015376985596959, 0.04169895873928908, 0.034483513300074264, 0.03706752308062278, 0.005462982444441877, 0.058325007412349805, 0.017589981616765726, 0.00963974040132598, 0.09540168117382564, 0.08522147822077386, 0.045706155433435924, 0.0410376754734898, 0.10495724811335094, 0.05202948741498403, 0.07893335743574426, 0.02956810039904667, 0.04886285460088402, 0.03579406075004954, 0.06005176983308047, 0.035212443326599896, 0.057728944084374234, 0.022723209294781554, 0.022036950904293917, 0.17395978647982702, 0.1493170697358437, 0.09708962184959091, 0.08947595852077939, 0.11737566455849446, 0.16234146460192278, 0.13465199415804818, 0.2902615559287369, 0.19094049639534205, 0.15283906512195244, 0.1832534940331243, 0.11653941997792572, 0.0833049560606014, 0.14444479602389038, 0.1662663125898689, 0.14008306054165587, 0.08461602672468871, 0.12351364144706167, 0.1882018824107945, 0.1665869797579944, 0.19390092347748578, 0.12359889937215485, 0.12762609694618732, 0.13726856937864795, 0.07309183885809034, 0.15232932841172442, 0.16667600779328495, 0.15807074611075222, 0.10367174443672411, 0.10422209146781825, 0.1256423510494642, 0.22516905970405787, 0.15212621743557975, 0.13245762675069273, 0.18888543010689318, 0.2164856350282207, 0.1112596775055863, 0.12465869367588311, 0.17109579406678677, 0.14649070421000943, 0.12390472358674742, 0.14439409249462187, 0.20132064877543598, 0.13304037594934925, 0.1866029400844127, 0.10052409576019272, 0.1317641936475411, 0.13892297982238233, 0.21125361265148968, 0.16358971246518195, 0.22113326063845307, 1.5898004919290543, 6.825533844530582, 26.221298575401306, 55.21219253540039, 85.06921201944351, 89.86735135316849, 90.2109745144844, 86.33727997541428, 82.48820051550865, 84.79626506567001, 77.19253867864609, 79.44600015878677, 71.00976884365082, 65.01362979412079, 62.677488550543785, 60.27400352060795, 57.92696826159954, 55.315269604325294, 35.56243993341923, 25.960140489041805, 29.47066381573677, 25.911294110119343, 22.210079915821552, 25.64210705459118, 30.00349022448063, 35.000085309147835, 53.44666287302971, 55.57813189923763, 48.286171182990074, 75.49192473292351, 70.3769887983799, 50.36810986697674, 65.72440445423126, 63.5078351944685, 53.232202380895615, 46.421592235565186, 62.52276465296745, 76.19283512234688, 57.090659737586975, 50.26458442211151, 39.80521246790886, 40.0251180678606, 35.126808509230614, 42.009219601750374, 23.83662823587656, 36.385285779833794, 29.198917597532272, 25.682082809507847, 32.62598790228367, 26.32632303982973, 28.513622470200062, 30.609058029949665, 39.75311726331711, 56.61082908511162, 69.78214591741562, 67.15285420417786, 74.98283565044403, 74.82338860630989, 86.72090739011765, 80.0070932507515, 78.58348444104195, 62.948714196681976, 34.60354618728161, 19.292985945940018, 11.146395038813353, 6.071368837729096, 2.393875583074987, 0.38407941232435405, 0.17006609385134652, 0.2055342961102724, 0.10820306808454916, 0.15529585594777018, 0.05876413248188328, 0.07430081226630136, 0.08612827135948464, 0.2072886738460511, 0.10175333722145297, 0.09816511999815702, 0.15631106944056228, 0.11358811389072798, 0.15790257544722408, 0.21250505174975842, 0.0933700667519588, 0.1329768481082283, 0.11902940706931986, 0.10898658307269216, 0.1592479259124957, 0.16979448264464736, 0.15702448115916923, 0.1786111228284426, 0.12974225683137774, 0.17062720202375203, 0.11267948022577912, 0.165382785780821, 0.19879112747730687, 0.11542495907633565, 0.1259243523236364, 0.22169919277075678, 0.2555249776924029, 0.14284285542089492, 0.15679333184380084, 0.11365989441401325, 0.09716731728985906, 0.08462569690891542, 0.14166126726195216, 0.20031389576615766, 0.10535831956076436, 0.17778486013412476, 0.08547597550204955, 0.08448203196167015, 0.18248556414619088, 0.10811880463734269, 0.24896424380131066, 0.17804048547986895, 0.31280886323656887, 0.17755500215571374, 0.1534588326467201, 0.1792544312775135, 0.1574108432396315, 0.0918901500699576, 0.18250104534672573, 0.13111052481690422, 0.11467930846265517, 0.06932484568096697, 0.10959053543047048], [0.062136622218531556, 0.040781623392831534, 0.032919952864176594, 0.046225354526541196, 0.09945736979716457, 0.056262449143105187, 0.03382598159078043, 0.033185077700181864, 0.04030830386909656, 0.001948254771377833, 0.053814601196791045, 0.009254893229808658, 0.04176205984549597, 0.019754321729124058, 0.046566104210796766, 0.040000846929615363, 0.031976820464478806, 0.10098806422320195, 0.026395895911264233, 0.06975677562877536, 0.030563210966647603, 0.011564547712623607, 0.0478254917106824, 0.04471355889108963, 0.03758967221074272, 0.04917977021250408, 0.01794845564290881, 0.10686150257242844, 0.049276501740678214, 0.01656716482102638, 0.029785406804876402, 0.018932174243673217, 0.03577120260160882, 0.027404443062550854, 0.020305648395151366, 0.07666902034543455, 0.057510422411723994, 0.021450082786032, 0.07082761308993213, 0.07018657561275177, 0.00498879646329442, 0.048194224073085934, 0.036929468769812956, 0.04042757813294884, 0.005629350152958068, 0.04830204328754917, 0.012981502441107295, 0.04061242114403285, 0.09944372912286781, 0.8367628371343017, 4.968121787533164, 11.63583442568779, 35.888071060180664, 60.240591913461685, 74.35884833335876, 63.76716747879982, 64.30529460310936, 58.34778808057308, 57.17488221824169, 45.55551990866661, 46.90035134553909, 35.64716398715973, 28.933004066348076, 33.75754438340664, 25.44903751462698, 30.11332333087921, 19.63109750300646, 15.072564762085676, 22.835476957261562, 31.196168325841427, 22.560440115630627, 23.186618015170097, 26.431125216186047, 26.65109161287546, 45.68371742963791, 39.49440814554691, 46.30832031369209, 41.011985912919044, 29.88768383860588, 44.42833699285984, 36.36787511408329, 51.456462666392326, 50.392914935946465, 52.498784735798836, 38.44328194856644, 49.5004378259182, 54.895266741514206, 69.5610661804676, 50.27476787567139, 83.80646377801895, 59.606242552399635, 44.20622371137142, 45.141068547964096, 44.70226049423218, 39.18906792998314, 42.99494370818138, 39.92182441055775, 36.03967912495136, 47.10385702550411, 27.57937990128994, 25.51216922700405, 21.23164001852274, 18.255943693220615, 15.666358899325132, 19.438968412578106, 17.08094224333763, 23.11208501458168, 41.386182233691216, 39.671737030148506, 40.23831322789192, 48.206079080700874, 51.05547398328781, 55.02870798110962, 58.49186114966869, 49.28875878453255, 37.87749610841274, 26.475997008383274, 10.351225957274437, 5.57711748406291, 2.3593993205577135, 0.4128858743933961, 0.1861842500511557, 0.06711065550916828, 0.027572611870709807, 0.03984066177508794, 0.06876826460938901, 0.04404321029142011, 0.03534095361828804, 0.05459646119561512, 0.04544678595266305, 0.05942955322097987, 0.033601133109186776, 0.12950739677762613, 0.06866892072139308, 0.04242774775775615, 0.035357221495360136, 0.010336726536479546, 0.03241407161112875, 0.09235186240402982, 0.0686285701522138, 0.06688163615763187, 0.07277129785506986, 0.029533015367633197, 0.04720828088466078, 0.0024396268054260872, 0.05985608775517903, 0.011812115189968608, 0.01320639266850776, 0.06285614552325569, 0.005798718921141699, 0.002463742894178722, 0.04520427806710359, 0.0431586222111946, 0.02072223443974508, 0.02693792717764154, 0.032117809969349764, 0.0868324952898547, 0.005990929603285622, 0.04810685844859108, 0.02744357094343286, 0.08076820624410175, 0.03716988008818589, 0.06497843554825522, 0.04302940687921364, 0.04533053965133149, 0.046422643354162574, 0.005377850220611435, 0.09346515071229078, 0.05428687058156356, 0.0385021093825344, 0.03335681809403468, 0.0439121692761546, 0.06539172274642624, 0.05727863856009208, 0.04329967479861807, 0.053874778241151944, 0.018789197638398036, 0.06815769971581176, 0.020157217004452832, 0.015105410348041914, 0.05601613403996453, 0.07738885164144449, 0.015258358635037439, 0.043738272943301126, 0.027697192490450107, 0.028499600703071337, 0.08628812254755758, 0.06068300353945233, 0.014141385563561926, 0.021929972172074486, 0.04254617597325705, 0.039296637842198834, 0.06777899659937248, 0.019346435510669835, 0.009616137322154827, 0.027581053800531663, 0.03599827381549403, 0.03893209861416835, 0.05004458005714696, 0.008884642247721786, 0.018583214550744742, 0.029423518899420742, 0.029426927212625742, 0.03770198884012643, 0.0564738944376586, 0.0374627946439432, 0.08307513518957421, 0.05057938651589211, 0.042294654704164714, 0.05448604446428362, 0.06312671030173078, 0.1086265523917973, 0.02826416548487032, 0.007708500525041018, 0.0408046039956389, 0.06696851196466014, 0.009874357401713496, 0.08524446253431961, 0.03582377634302247, 0.02765596433164319, 0.03673545281344559, 0.02940985967143206, 0.032928250075201504, 0.050321267553954385, 0.07740338289295323, 1.0737470956519246, 5.963719664141536, 18.971751183271408, 50.51084540784359, 73.1106761097908, 83.29630315303802, 72.3106138408184, 72.08128094673157, 67.2873517870903, 65.06323993206024, 53.036714270710945, 55.95547065138817, 46.101839393377304, 39.72630210220814, 40.89331828057766, 32.90204308927059, 38.49829539656639, 26.279923729598522, 27.427825033664703, 31.482425965368748, 34.906496331095695, 27.57191140204668, 29.20025322586298, 30.756087340414524, 26.032927483320236, 38.59754987061024, 37.217372730374336, 37.115276008844376, 42.028146386146545, 36.36037051677704, 40.77276974916458, 41.10041856765747, 56.959999948740005, 49.508128613233566, 52.65894614160061, 36.6134787350893, 36.88408121466637, 36.92258074879646, 47.76647686958313, 39.82318550348282, 57.488118410110474, 42.87693724036217, 30.458643101155758, 37.80622333288193, 36.29993095993996, 38.05611692368984, 32.26955942809582, 39.61696296930313, 37.021497040987015, 42.90565989911556, 31.66927333921194, 18.347741067409515, 26.39585930854082, 23.393678404390812, 25.35856816917658, 30.535699166357517, 31.93518877029419, 34.427957609295845, 50.26621833443642, 52.784020230174065, 48.25821988284588, 57.120681926608086, 61.79041475057602, 62.911445796489716, 68.26399818062782, 58.2539027184248, 46.72340244054794, 32.7265191078186, 14.898943528532982, 6.93887178786099, 2.9126263596117496, 0.5406124878209084, 0.2064198415610008, 0.012217903913551709, 0.06684738604235463, 0.02713150897761807, 0.04490863240789622, 0.009096026315091876, 0.05190888470679056, 0.0413363008556189, 0.03638560439867433, 0.02454888144711731, 0.03138724721793551, 0.038135581198730506, 0.09194571466650814, 0.048411061070510186, 0.06172332759888377, 0.05818062629259657, 0.016742268999223597, 0.054992656732792966, 0.06408376168110408, 0.0264300309936516, 0.06493408480309881, 0.03594780406274367, 0.047788328665774316, 0.0349624620139366, 0.045323348240344785, 0.02194065167714143, 0.011776379851653473, 0.044726965788868256, 0.015222941492538666, 0.040508090023649856, 0.023497664515161887, 0.03384976371307857, 0.031173965107882395, 0.029700386367039755, 0.017291803378611803, 0.00870077794388635, 0.04802841714990791, 0.0832665350753814, 0.0315519780269824, 0.04145700375374872, 0.036513676823233254, 0.02913086038461188, 0.005584991986324894, 0.05300244301906787, 0.0599311448604567, 0.033793716720538214, 0.04160867647442501, 0.01820323865104001, 0.01717837352771312, 0.009405630844412372, 0.05266161540930625, 0.07554738287581131, 0.019505307063809596, 0.02441178079607198, 0.032033717216108926, 0.17231687932508066, 0.17151914478745311, 0.0989740015938878, 0.11975357250776142, 0.179107278236188, 0.24883932550437748, 0.12493224930949509, 0.14023177209310234, 0.19688738510012627, 0.11454723586211912, 0.20775916578713804, 0.23666935041546822, 0.15269128867657855, 0.08845753895002417, 0.11105952769867145, 0.18780241400236264, 0.09357532995636575, 0.317631695070304, 0.14142869302304462, 0.11596900527365506, 0.17151191626908258, 0.14779679506318644, 0.17492402927018702, 0.13714387372601777, 0.08515689652995206, 0.07911643042461947, 0.1359991851495579, 0.1780386597965844, 0.14748834364581853, 0.08953909302363172, 0.20078017230844125, 0.12281322473427281, 0.16815921961097047, 0.1523758313851431, 0.10978623977280222, 0.1601767385727726, 0.13838173152180389, 0.0661963592574466, 0.12636536615900695, 0.2352358476491645, 0.09383991302456707, 0.23618505452759564, 0.11815349469543435, 0.1262359504471533, 0.15516317478613928, 0.1466089134919457, 0.11334639639244415, 0.15843077679164708, 0.13732685765717179, 1.6345359664410353, 8.317206501960754, 26.41786202788353, 64.15807530283928, 87.83234775066376, 94.83928576111794, 83.31294625997543, 80.22478356957436, 77.71187201142311, 75.96781119704247, 63.25764141976833, 64.45337265729904, 52.23983243107796, 45.68176433444023, 50.878236293792725, 41.517681777477264, 47.31283441185951, 32.70441189408302, 28.3409084379673, 37.421057000756264, 43.528898656368256, 33.36830846965313, 36.73188418149948, 42.1536460518837, 39.15205791592598, 65.25109425187111, 57.3082360625267, 63.50560091435909, 57.745881378650665, 48.544910699129105, 62.15284310281277, 52.9426921159029, 69.66844081878662, 67.22523272037506, 72.02884376049042, 53.5294946283102, 65.5625407397747, 72.27523773908615, 88.7636549770832, 63.41095559298992, 100.5587312579155, 75.75308471918106, 57.751953452825546, 58.95791374146938, 59.591518342494965, 52.00650595128536, 56.94194711744785, 58.21177817881107, 53.466269820928574, 64.12152126431465, 42.59909234941006, 40.32176434993744, 32.17537008225918, 28.06594379246235, 27.394460923969746, 33.785795867443085, 31.546591222286224, 38.58720302581787, 59.565869718790054, 59.22089762985706, 57.72626303136349, 65.86007237434387, 70.1071348786354, 74.8921649158001, 78.92650723457336, 69.74392756819725, 55.85734471678734, 39.13006089627743, 19.869889989495277, 9.721954073756933, 4.842933230102062, 0.9276204742491245, 0.6101181800477207, 0.10770875320304185, 0.17057934834156185, 0.14909469260601327, 0.22451132390415296, 0.15816376690054312, 0.11128595695481636, 0.11314616494928487, 0.1630706395371817, 0.11103436889243312, 0.214707360137254, 0.1767976107657887, 0.2047276558005251, 0.13639663491630927, 0.18830790562788025, 0.13120269955834374, 0.07530230344855227, 0.25437844858970493, 0.1159763228497468, 0.15868148911977187, 0.14216536364983767, 0.18703255453146994, 0.08730528046726249, 0.08978890735306777, 0.1270198661950417, 0.1140523272624705, 0.06559608053066768, 0.1230712175311055, 0.10080938474857248, 0.13357343093957752, 0.08835737869958393, 0.17491592501755804, 0.072158654947998, 0.06855375424493104, 0.08060356820351444, 0.14897303975885734, 0.16103816422400996, 0.13837472564773634, 0.18768631241982803, 0.15461796341696754, 0.08964066335465759, 0.10787018516566604, 0.15739923604996875, 0.15489600162254646, 0.14151923503959551, 0.17133708111941814, 0.16025855293264613, 0.1229496240557637, 0.11339310716721229, 0.10424664171296172, 0.10289694968378171, 0.19111784000415355, 0.12464817002182826, 0.24914568406529725, 0.15608024667017162], [0.021093265604577027, 0.06762736840755679, 0.11025571497157216, 0.04247468488756567, 0.00855241241879412, 0.016605110831733327, 0.014850107836537063, 0.0545060564763844, 0.07124720112187788, 0.03798334073508158, 0.007919311283330899, 0.026928659608529415, 0.05021335186029319, 0.0678760175651405, 0.06574472528882325, 0.05616883092443459, 0.06803311538533308, 0.04885150716290809, 0.044554000851348974, 0.0542946519999532, 0.049547137023182586, 0.024115619344229344, 0.061514509507105686, 0.05790650291601196, 0.04899010695226025, 0.011067514715250582, 0.12241106232977472, 0.028398954345902894, 0.07263567778863944, 0.03975574523792602, 0.061063706743880175, 0.02556104100222001, 0.02474823901138734, 0.025394339791091625, 0.02314994049811503, 0.012545483259600587, 0.03406511270441115, 0.02086935408442514, 0.07781232852721587, 0.06807888363255188, 0.049197986227227375, 0.06760011674487032, 0.04041159227199387, 0.02901241918152664, 0.042857736989390105, 0.05675506079569459, 0.04459664094611071, 0.4722458735341206, 4.0384043008089066, 19.352300763130188, 34.21617977321148, 49.61066611111164, 65.26636943221092, 68.07041376829147, 59.103024154901505, 63.93454849720001, 58.95318679511547, 39.996608197689056, 35.483632162213326, 28.089325837790966, 20.580924935638905, 21.171316355466843, 11.49842144921422, 18.834990821778774, 7.865295801311731, 14.152337741106749, 27.972626499831676, 17.922357693314552, 25.194890052080154, 29.773262478411198, 57.253724187612534, 45.4145322740078, 34.35351960361004, 55.3518882393837, 57.589014396071434, 51.9488288462162, 53.051351085305214, 35.478418841958046, 32.433858811855316, 34.902833327651024, 22.496461048722267, 13.021138440817595, 13.475915137678385, 10.47581747174263, 9.796462375670671, 15.242172461003065, 25.75770065188408, 20.67480269819498, 33.70483361184597, 21.104206256568432, 23.96548692137003, 37.26726025342941, 33.95851559937, 35.431202575564384, 53.18551428616047, 60.23890480399132, 41.73364698886871, 48.28863725066185, 52.5803055614233, 67.56361976265907, 45.93013420701027, 40.976708605885506, 33.21328438818455, 27.081948593258858, 19.29441846907139, 13.766469396650791, 24.099348038434982, 28.45006138086319, 25.28983175754547, 49.18160833418369, 53.52129466831684, 49.86138045787811, 60.396307557821274, 51.74646310508251, 55.74693784117699, 58.31974558532238, 54.809607937932014, 54.54095095396042, 38.6873010545969, 13.15638743340969, 8.468565680086613, 1.4491525827907026, 0.7635687303263694, 0.07071436135447584, 0.08755834540352225, 0.04534173494903371, 0.013087673160043778, 0.0179516450225492, 0.09695938977529295, 0.14277306385338306, 0.035824054648401216, 0.08481081822537817, 0.0625535793369636, 0.026850405702134594, 0.10040639856015332, 0.015343098912126152, 0.003379612730896042, 0.03879310177580919, 0.06238031754037365, 0.036078770863241516, 0.01441143826014013, 0.006617504941459629, 0.035213716109865345, 0.05527650224394165, 0.03562217934813816, 0.042098824196727946, 0.02330591953068506, 0.03869170213874895, 0.05391593775129877, 0.008649127248645527, 0.0792763706704136, 0.018369800709479023, 0.037136075261514634, 0.01272991252335487, 0.03849030923447572, 0.04369673493783921, 0.03143492649542168, 0.0864299840759486, 0.018815898256434593, 0.050223148209624924, 0.05120365145558026, 0.016050804442784283, 0.017892056130222045, 0.019730066487682052, 0.04150126544118393, 0.038305740818032064, 0.06599923741305247, 0.0673480611294508, 0.0889338122215122, 0.01013097165923682, 0.06052317090507131, 0.03042804546566913, 0.047231283751898445, 0.048029571189545095, 0.04586464478052221, 0.014083366313570878, 0.05011075365473516, 0.07703633891651407, 0.03724854403117206, 0.04957380981068127, 0.026495826095924713, 0.03490781025902834, 0.018165624751418363, 0.02131286895746598, 0.0520975943072699, 0.046973146236268803, 0.028748951190209482, 0.024036938702920452, 0.027423312167229597, 0.04750177431560587, 0.07023175756330602, 0.03774492579395883, 0.041185455629602075, 0.03710880133439787, 0.06836058804765344, 0.028618993710551877, 0.03695525098009966, 0.0789899833034724, 0.043898988733417355, 0.021694854222005233, 0.016013338972697966, 0.0698222330538556, 0.08721993348444812, 0.04168149971519597, 0.0661184337513987, 0.052150008486933075, 0.013627135667775292, 0.06409599227481522, 0.01813121507439064, 0.07799742015777156, 0.014600643244193634, 0.0169909645410371, 0.019429828789725434, 0.05473506840644404, 0.058736676728585735, 0.0491090101422742, 0.04841920985199977, 0.03735442995093763, 0.05316899580066092, 0.10224339217529632, 0.03402942653337959, 0.026299424134776928, 0.05791452553239651, 1.1184039618819952, 7.445755563676357, 26.27621702849865, 44.125584438443184, 66.19552597403526, 73.71583923697472, 76.34014561772346, 68.73719438910484, 71.90666511654854, 66.82380706071854, 48.60025852918625, 43.99414949119091, 38.18269953131676, 32.83208504319191, 30.596522502601147, 19.391968734562397, 31.064262203872204, 15.249292328953743, 29.050432965159416, 35.0354690104723, 23.590764328837395, 33.397487103939056, 40.62791012227535, 45.28390668332577, 41.63582883775234, 37.042574509978294, 40.734965577721596, 51.62310652434826, 44.58511658012867, 47.24323734641075, 33.05902786552906, 31.621384508907795, 32.725405767560005, 22.61862449347973, 14.584870431572199, 15.906660854816437, 11.594691183418036, 9.296312313526869, 11.075759679079056, 16.334405802190304, 14.672015905380249, 16.69131115078926, 16.73415955156088, 14.250797107815742, 22.348766773939133, 23.21245662868023, 26.17997009307146, 30.77492482960224, 40.72269983589649, 30.14386609196663, 35.96893072128296, 41.44980601966381, 45.80119572579861, 34.50937204062939, 39.39648739993572, 29.19502280652523, 24.55669529736042, 24.65865332633257, 18.011147528886795, 25.67909236997366, 34.66745875775814, 29.31292288005352, 53.039149940013885, 57.248564064502716, 53.284244388341904, 70.93196421861649, 61.415511667728424, 65.23955807089806, 70.24353995919228, 66.68120071291924, 65.3677099943161, 51.36469379067421, 18.97685620933771, 11.326882503926754, 2.046977709978819, 0.7801577495411038, 0.05291267283610068, 0.030985403936938383, 0.0421024866955122, 0.0200102903181687, 0.02219623620476341, 0.02568341929872986, 0.10768463340355083, 0.012559340084408177, 0.038727959763491526, 0.023175145688583143, 0.07176880477345549, 0.01129972994021955, 0.030941496625018772, 0.012673780183831695, 0.032617913602734916, 0.056727423216216266, 0.03963657858548686, 0.039824946798034944, 0.004241824826749507, 0.02700798591831699, 0.0958453444764018, 0.05443806090625003, 0.03601454540330451, 0.05140243571077008, 0.03462457701971289, 0.027673644144670106, 0.013047319807810709, 0.016074068917077966, 0.03740529304195661, 0.01135176655225223, 0.05188530296436511, 0.007382382282230537, 0.04734673224447761, 0.024800688443065155, 0.04589874646626413, 0.04330385309003759, 0.06134370793006383, 0.015089898533915402, 0.01943462120834738, 0.014730159145983635, 0.01750510033161845, 0.031254970526788384, 0.07933830289402977, 0.07649871229659766, 0.0320613881922327, 0.050392510020174086, 0.045733021179330535, 0.0425512114452431, 0.07780452113365754, 0.012581249211507384, 0.01953031744051259, 0.02966705465951236, 0.0785819579323288, 0.11049456777982414, 0.26382103096693754, 0.1353415977791883, 0.23276183899724856, 0.09801027088542469, 0.08842941897455603, 0.14569152990588918, 0.09170330697088502, 0.27489057916682214, 0.08309089840622619, 0.16691817058017477, 0.1250794023508206, 0.15557644714135677, 0.21431986999232322, 0.23480743548134342, 0.12138252728618681, 0.15408400300657377, 0.12429453665390611, 0.1675725370296277, 0.161138680705335, 0.16494935669470578, 0.1952130999416113, 0.10773562637041323, 0.14634597057010978, 0.23995580297196284, 0.09454972532694228, 0.18039578018942848, 0.11924020669539459, 0.1475171686615795, 0.12134010612498969, 0.15455207554623485, 0.19795328727923334, 0.08317172570968978, 0.20234985917340964, 0.1092527098080609, 0.0791262935672421, 0.10637960382155143, 0.10985925968270749, 0.19318106991704553, 0.07425200121360831, 0.19528542965417728, 0.18593203858472407, 0.21241510345134884, 0.13872635521693155, 0.11374366062227637, 0.14374503982253373, 0.25166732375510037, 2.035363158211112, 11.6814623773098, 34.8424431681633, 55.23814134299755, 82.74686023592949, 85.64263924956322, 84.13799598813057, 75.59951215982437, 82.06463724374771, 78.97734850645065, 59.289157167077065, 50.70119999349117, 43.068469762802124, 35.2016606926918, 34.576111659407616, 22.856429032981396, 36.129574701189995, 19.833890721201897, 28.313481509685516, 41.59218057990074, 30.28168849647045, 38.59652392566204, 45.69092184305191, 71.49576276540756, 60.388692766427994, 47.65410549938679, 73.16188216209412, 73.35996553301811, 69.78799760341644, 68.12202259898186, 50.341249108314514, 46.66047401726246, 48.76813732087612, 32.946371510624886, 20.6073335185647, 20.54185353219509, 14.690419267863035, 14.682561289519072, 19.117382168769836, 32.793946489691734, 26.931402571499348, 43.09612087905407, 27.00520221143961, 32.26415231823921, 46.48895502090454, 42.926440984010696, 45.524532571434975, 66.91082239151001, 77.58693471550941, 56.02551229298115, 66.07537642121315, 67.65520244836807, 86.76570698618889, 64.54546451568604, 56.343931406736374, 46.458678245544434, 41.39502055943012, 32.24627427756786, 24.123199358582497, 38.22265438735485, 42.529727071523666, 39.06831040978432, 63.65408934652805, 66.15153193473816, 64.9710188806057, 82.35356613993645, 70.9273512661457, 77.37943544983864, 79.49523791670799, 76.796113550663, 76.95043087005615, 60.351397767663, 25.29288489371538, 14.611041527241468, 3.8770198356360197, 1.396715990267694, 0.24552863440476358, 0.14540038537234068, 0.09992404709919356, 0.12627172196516767, 0.07742917994619347, 0.1921898574801162, 0.28951528191100806, 0.07986956930835731, 0.2866310585523024, 0.13146166456863284, 0.1969281883793883, 0.2133563396637328, 0.08799972289125435, 0.13825285015627742, 0.11283583589829504, 0.23136516159866005, 0.13466879638144746, 0.17085173138184473, 0.0871314101095777, 0.20397229789523408, 0.2029586280696094, 0.11617094365647063, 0.14218862255802378, 0.19235943822422996, 0.12048314820276573, 0.139510745939333, 0.0836966690258123, 0.14830230153165758, 0.17065482476027682, 0.22688448952976614, 0.14816858136327937, 0.11567671783268452, 0.21195575856836513, 0.1213411006028764, 0.2286833367543295, 0.08142164500895888, 0.16245290549704805, 0.1408375278697349, 0.13303964864462614, 0.12152721639722586, 0.09966672965674661, 0.10854934676899575, 0.1477423362666741, 0.16346414107829332, 0.1465618168003857, 0.09822887790505774, 0.11484101501991972, 0.0976492086192593, 0.16306783421896398, 0.14524276804877445, 0.15042951941723004, 0.16203638253500685, 0.19609011069405824], [0.04219013062538579, 0.06497542242868803, 0.021328691545932088, 0.03529423913278151, 0.05986306023260113, 0.028744958435709123, 0.03611745902162511, 0.038701427984051406, 0.045585912666865624, 0.009034987451741472, 0.016049620717240032, 0.023667376990488265, 0.03042219363123877, 0.03033714536286425, 0.011052547451981809, 0.03344405013194773, 0.037618400747305714, 0.04699808239820413, 0.09631994791561738, 0.06758389339665882, 0.02918603906437056, 0.04356076977273915, 0.06026269191352185, 0.074043984641321, 0.02726009719481226, 0.05204845299886074, 0.03931927334633656, 0.012746843694912968, 0.05543996026972309, 0.013533808742067777, 0.023091396178642754, 0.022434103811974637, 0.016694747428118717, 0.010022778587881476, 0.11778676984249614, 0.06346600537654012, 0.026601454119372647, 0.0451045482623158, 0.05558179211220704, 0.026485718044568785, 0.0746070891909767, 0.07719348868704401, 0.0931991872494109, 0.006843546425443492, 0.11537622965988703, 1.0886688949540257, 10.87625803425908, 22.514705769717693, 45.60877785086632, 66.42899304628372, 67.24994659423828, 67.17742368578911, 62.04746715724468, 43.74397091567516, 55.95799371600151, 62.58331440389156, 32.55446054041386, 28.603362254798412, 19.01718344539404, 21.90522987395525, 19.13006018847227, 19.967774637043476, 19.660960100591183, 12.58117239922285, 20.302259288728237, 19.07043758779764, 18.332959860563278, 33.32813702523708, 28.65211933851242, 32.89616860449314, 84.36488181352615, 72.86014795303345, 59.4311897456646, 52.69448183476925, 32.365067303180695, 27.834112532436848, 14.62804751470685, 16.126268170773983, 7.585206180810928, 4.584589367732406, 1.7753670969977975, 3.277593213133514, 1.9346653553657234, 1.7214678204618394, 1.441116607747972, 1.740202121436596, 0.7681708771269768, 0.7869827770628035, 1.18060068693012, 2.2367452271282673, 3.3430819865316153, 4.12076155655086, 5.3622304648160934, 6.080801831558347, 11.369687207043171, 15.917936749756336, 24.559493847191334, 30.412790961563587, 41.70267105102539, 47.75004655122757, 36.53789699077606, 57.3782093077898, 49.70458947122097, 41.62720330059528, 34.64462958276272, 34.1452793776989, 29.906243942677975, 34.742451533675194, 58.87027524411678, 77.84884706139565, 63.248054534196854, 41.6175252199173, 35.807378590106964, 36.588012501597404, 49.985352605581284, 43.2877179980278, 54.01498317718506, 59.95049647986889, 66.59031718969345, 56.40700802206993, 47.924745976924896, 26.67876172810793, 10.78106364235282, 1.9706798228435218, 0.8260134514421225, 0.051106014507240616, 0.03466187365120277, 0.07712041682680137, 0.052435560937738046, 0.05404775802162476, 0.05038099559897091, 0.006027916388120502, 0.021972439717501402, 0.05005862891266588, 0.052298181981313974, 0.06771062253392301, 0.004480288007471245, 0.051879399179597385, 0.08027594711165875, 0.025088187176152132, 0.04345533285231795, 0.061564036732306704, 0.0556302691984456, 0.02390910747635644, 0.09280609388952143, 0.0172321588252089, 0.036012337513966486, 0.01312930300628068, 0.027809523962787353, 0.05529644746275153, 0.02047560948994942, 0.025434111485083122, 0.017468994847149588, 0.014930785782780731, 0.024456372739223298, 0.06798950678785332, 0.04770081090100575, 0.03648329700808972, 0.050782282269210555, 0.11719741552951746, 0.02663270410266705, 0.06463223850005306, 0.0623414883739315, 0.009140471684077056, 0.04222165334795136, 0.030895722811692394, 0.02127257776010083, 0.036273053992772475, 0.019695564042194746, 0.04531019367277622, 0.03986729003372602, 0.03550760287907906, 0.011773028127208818, 0.0418737975996919, 0.008945221907197265, 0.01937509725394193, 0.014813304733252153, 0.058583475183695555, 0.017307592570432462, 0.058260982332285494, 0.018563228513812646, 0.04829312638321426, 0.017046210014086682, 0.03894453700922895, 0.013524350069928914, 0.10594146209768951, 0.06961116625461727, 0.027490650936670136, 0.010222043383691926, 0.03398393659153953, 0.07305332139367238, 0.030235250342229847, 0.038973195041762665, 0.041579992466722615, 0.03939947724575177, 0.024253994633909315, 0.0038814743265902507, 0.029983883068780415, 0.0185565770152607, 0.06907611488713883, 0.016204590428969823, 0.022441580949816853, 0.02957205975690158, 0.014057489479455398, 0.06764347301214002, 0.05705186791601591, 0.013470088870235486, 0.03967790507886093, 0.04848828895774204, 0.044345739370328374, 0.0388801445660647, 0.059389681337052025, 0.032043825267464854, 0.03158848427119665, 0.03689363416924607, 0.07753650192171335, 0.04185083555057645, 0.027161328471265733, 0.02370002035604557, 0.05225923036050517, 0.27407953049987555, 1.796308010816574, 13.722160924226046, 27.50464741140604, 54.088383838534355, 75.49465298652649, 77.97738656401634, 75.56130141019821, 70.95303788781166, 56.23166263103485, 63.624781519174576, 73.71234342455864, 42.234490513801575, 38.776014894247055, 27.410032488405704, 31.461029313504696, 31.479241736233234, 27.01413743197918, 23.673833571374416, 27.492279075086117, 29.34796839952469, 19.776694290339947, 28.459878154098988, 28.623474575579166, 32.13068827986717, 30.113025046885014, 63.845420479774475, 52.89284639060497, 40.808309242129326, 42.764907851815224, 27.322927862405777, 23.244449011981487, 14.326229710131884, 14.040512591600418, 8.224512375891209, 4.839412719011307, 2.419327567331493, 2.8195719653740525, 1.4568260335363448, 1.1951531935483217, 1.1522599076852202, 0.8675681997556239, 0.41349253559019417, 0.5288273608312011, 1.3382772635668516, 1.311638792976737, 1.6852327273227274, 2.1035082265734673, 2.2724395617842674, 3.622302641160786, 7.614836515858769, 10.118890274316072, 15.81932159140706, 22.895348444581032, 29.838181994855404, 34.75434489548206, 32.35936760902405, 42.89283938705921, 41.36825479567051, 35.89643441140652, 30.361767299473286, 30.537996143102646, 35.87191052734852, 38.32187846302986, 57.385748103260994, 83.61795589327812, 69.008309841156, 50.1490668207407, 44.7587064653635, 43.693927600979805, 60.33268377184868, 53.788184747099876, 62.47670352458954, 67.76912033557892, 76.29124984145164, 69.76785108447075, 59.316614493727684, 37.12357856333256, 14.893452823162079, 3.002782934345305, 0.47758645727299154, 0.04123032958887052, 0.033562530297786, 0.03315804868179839, 0.03367795281519648, 0.06354899232974276, 0.06276185566093773, 0.006030387739883736, 0.022580613040190656, 0.03572998000890948, 0.021786030774819665, 0.04906790258246474, 0.03603142555220984, 0.018032485313597135, 0.03801527163886931, 0.012656855506065767, 0.055401951176463626, 0.01381989832225372, 0.03569175569282379, 0.015088147993083112, 0.09739883767906576, 0.023308876989176497, 0.02085885269480059, 0.03713943347975146, 0.013729685633734334, 0.07162892477936111, 0.025600983390177134, 0.012216527229611529, 0.0428127665509237, 0.004884848012807197, 0.018414624573779292, 0.04998683354642708, 0.06072152471460868, 0.037710093092755415, 0.0845209947146941, 0.018107457071891986, 0.03744211469893344, 0.04874117948929779, 0.04001705914561171, 0.07485101828933693, 0.05981557391351089, 0.04730980668682605, 0.07233848475152627, 0.02318568789632991, 0.030402279953705147, 0.0587330327834934, 0.07648061131476425, 0.039452871060348116, 0.057604741959949024, 0.024822207014949527, 0.034908552406704985, 0.05442283574666362, 0.14621961250668392, 0.1449499759473838, 0.06730192922987044, 0.17153388384031132, 0.23980752186616883, 0.17327091016341, 0.09836026772973128, 0.10248113176203333, 0.14313797786599025, 0.16250075917923823, 0.160599896335043, 0.07182741217548028, 0.12421420658938587, 0.11999030277365819, 0.11199072265299037, 0.20883752120425925, 0.1948937983252108, 0.13022066006669775, 0.14905767427990213, 0.18505728396121413, 0.12575787375681102, 0.09222797569236718, 0.09456435305764899, 0.19007158989552408, 0.07483006003894843, 0.18262314348248765, 0.13394132838584483, 0.10447289285366423, 0.282280856044963, 0.15015456854598597, 0.10192889967584051, 0.11593852526857518, 0.15923211816698313, 0.14517582632834092, 0.15949014807119966, 0.23849608754971996, 0.10848985621123575, 0.1911374623887241, 0.14458295423537493, 0.12033857041387819, 0.13674260932020843, 0.1880567183252424, 0.14423493150388822, 0.11633003785391338, 0.3667205187957734, 2.4551130970939994, 17.622019909322262, 35.74453756213188, 66.31285607814789, 84.54480975866318, 86.83648958802223, 83.76694589853287, 80.93523904681206, 63.13977554440498, 71.64810419082642, 78.42143833637238, 47.96674892306328, 42.75646470487118, 32.34416842460632, 34.393862038850784, 30.812404118478298, 30.743851996958256, 31.135460883378983, 25.53123850375414, 32.87075936794281, 29.696428701281548, 29.388422928750515, 49.05773878097534, 40.79844497144222, 46.25965632498264, 101.54941409826279, 87.83823743462563, 74.72979202866554, 65.6559245288372, 43.348921313881874, 36.935986429452896, 20.893011689186096, 22.08498302847147, 11.783720590174198, 6.439081756398082, 3.1113644829019904, 4.856696566566825, 3.310579718090594, 2.9624967835843563, 2.706102691590786, 2.842045621946454, 1.258660729508847, 1.418347517028451, 1.8367498344741762, 2.948674075305462, 4.071574145928025, 5.163664044812322, 6.969975018873811, 8.243736494332552, 14.427913203835487, 20.808084346354008, 33.65058772265911, 37.35417678952217, 50.692300871014595, 62.564057037234306, 50.132066532969475, 70.68452909588814, 64.18706774711609, 58.61390300095081, 47.6463159173727, 48.30050781369209, 41.046089082956314, 46.547673270106316, 66.41146838665009, 86.90829813480377, 76.70022949576378, 57.764979153871536, 52.30459235608578, 54.82678681612015, 70.50137892365456, 63.34034398198128, 74.80774864554405, 79.70589101314545, 88.11398103833199, 81.01027742028236, 68.36288407444954, 43.84502649307251, 18.5726111009717, 4.787286641076207, 0.9640903829131275, 0.27512016997206956, 0.1155298542289529, 0.12768046668497846, 0.11816590340458788, 0.2447828056756407, 0.2805721352342516, 0.1682489601080306, 0.08581278438214213, 0.14865973469568416, 0.11752448001061566, 0.14542670192895457, 0.08798682436463423, 0.21090149326482788, 0.1258699083700776, 0.12759149802150205, 0.09341507800854743, 0.27228558144997805, 0.23553855484351516, 0.13515678816474974, 0.232829418964684, 0.12808466999558732, 0.07915829497505911, 0.20965805451851338, 0.086769531480968, 0.12492320995079353, 0.14569779363228008, 0.16725676803616807, 0.14554629160556942, 0.060992360376985744, 0.09920641998178326, 0.16798613592982292, 0.18298694427357987, 0.1552494865609333, 0.2120363261201419, 0.1335989311337471, 0.1237813860643655, 0.14984206500230357, 0.11138670350192115, 0.25836580025497824, 0.1747623152914457, 0.12652185541810468, 0.21813410829054192, 0.09366655474877916, 0.18907682999270037, 0.16368684475310147, 0.14425140718230978, 0.10241976357065141, 0.15661218843888491, 0.07243092666612938, 0.12145186614361592, 0.15934596362058073], [0.04440994256583508, 0.037138498373678885, 0.025034498357854318, 0.03297414077678695, 0.03838187032670248, 0.07827584428014234, 0.02150126685592113, 0.047651962740928866, 0.0161688968364615, 0.07264246843988076, 0.026574755356705282, 0.04775980793056078, 0.028445314455893822, 0.06658723359578289, 0.045861401595175266, 0.09132817358477041, 0.02574158883362543, 0.04435851915332023, 0.019049435431952588, 0.023779175971867517, 0.08861982438247651, 0.04899181760265492, 0.053574345729430206, 0.03595556321670301, 0.11634668422630057, 0.05301859957398847, 0.03624318997026421, 0.02937799370556604, 0.014158893754938617, 0.06777379414415918, 0.016953098311205395, 0.024605247563158628, 0.02644101292389678, 0.08374824828933924, 0.025401228776900098, 0.1231496105901897, 0.06865759554784745, 0.04152647248702124, 0.035892035375582054, 0.07360309697105549, 0.026662735108402558, 0.03842189435090404, 0.06846147560281679, 0.33310200087726116, 3.1748574133962393, 20.59577453881502, 45.033028945326805, 58.29058215022087, 66.88862398266792, 61.3275957852602, 62.470456659793854, 49.59151513874531, 44.17220413684845, 46.201055869460106, 77.48807922005653, 60.4567015171051, 21.471287459135056, 18.136831484735012, 19.391736947000027, 24.966003634035587, 19.77225612848997, 25.105881728231907, 36.56444236636162, 32.55536109209061, 33.189493864774704, 51.22325778007507, 43.679640367627144, 56.485542207956314, 58.719594329595566, 62.79719352722168, 40.78582584857941, 29.571527503430843, 21.99515014886856, 10.905569661408663, 10.337602738291025, 3.0211017513647676, 2.0994937419891357, 0.6321087875403464, 0.34595982811879367, 0.3936847031582147, 0.22644439595751464, 0.10884645816986449, 0.029499332995328587, 0.14132234326098114, 0.010355256108596222, 0.13080078206257895, 0.22824918036349118, 0.11536261867149733, 0.04643616528483108, 0.0631372191128321, 0.031199201839626767, 0.24821191385854036, 0.05973669845843688, 0.20718990883324295, 0.3434563265182078, 0.6777788931503892, 0.5623434623703361, 1.2853668839670718, 4.787030629813671, 5.3452126029878855, 12.157571129500866, 28.04934248328209, 36.57110720872879, 39.89266097545624, 49.73713472485542, 45.102891996502876, 29.263687022030354, 30.12382786720991, 27.790910750627518, 21.988192722201347, 13.897995539009571, 26.648538149893284, 21.134901009500027, 28.230178579688072, 26.631862744688988, 24.293644912540913, 36.17064289748669, 39.94352124631405, 41.27442643046379, 55.168171897530556, 58.6487091332674, 63.28447178006172, 46.22262351214886, 22.274526357650757, 12.226564027369022, 3.021346125751734, 0.5387186456937343, 0.059102099112351425, 0.06840588132035919, 0.09458825021283701, 0.058014014139189385, 0.02912550393375568, 0.020887469909212086, 0.0659945396182593, 0.04867116527748294, 0.05660475362674333, 0.012371031243674224, 0.03170945434249006, 0.010362809316575294, 0.055072504401323386, 0.040510464896215126, 0.09683051583124325, 0.04254229454090819, 0.04592258053889964, 0.00534448975486157, 0.03730331452970859, 0.02274785601912299, 0.02040875126112951, 0.09547671230393462, 0.03698129665281158, 0.007791040334268473, 0.0450514327530982, 0.05466506161610596, 0.026943038719764445, 0.03393089529708959, 0.03824971237918362, 0.047474890016019344, 0.022228341513255145, 0.0023254728967003757, 0.11701634633936919, 0.09970871295081452, 0.047537764767184854, 0.03273931783041917, 0.040774888402665965, 0.01474038501328323, 0.04879300366155803, 0.060771200369345024, 0.02420789242023602, 0.035824559308821335, 0.10450355097418651, 0.01815779509342974, 0.023300793145608623, 0.024814204807626083, 0.08394271324505098, 0.016474602307425812, 0.050096389386453666, 0.015849016344873235, 0.0295977510540979, 0.06165637474623509, 0.016833016961754765, 0.09533439064398408, 0.043735185608966276, 0.04262785674654879, 0.053033390577184036, 0.018425940470478963, 0.05478576822497416, 0.042128016575588845, 0.031420729210367426, 0.07172259865910746, 0.011303820101602469, 0.028188583310111426, 0.0802681694040075, 0.061215702298795804, 0.014692280856252182, 0.03339405535371043, 0.03972720223828219, 0.07338015580899082, 0.059903670553467236, 0.06840375877800398, 0.03140208646073006, 0.053572234319290146, 0.0863031436165329, 0.032384333753725514, 0.0478968454990536, 0.016282584583677817, 0.027834166976390406, 0.039651573679293506, 0.017084137471101712, 0.06669687849353068, 0.05627453872875776, 0.022944289521547034, 0.11898402473889291, 0.033863708667922765, 0.04112979455385357, 0.022722726898791734, 0.020640245675167535, 0.023598351690452546, 0.07535551543696783, 0.052463892425294034, 0.2849887154297903, 5.033134398981929, 25.5117379501462, 53.3284892141819, 67.28827133774757, 75.81607013940811, 68.98317039012909, 68.54274362325668, 56.02748818695545, 56.75517953932285, 50.832334756851196, 78.2932560145855, 66.26716732978821, 34.13105294108391, 27.762182392179966, 29.15540613234043, 30.461658239364624, 22.42689438164234, 25.251005440950394, 33.594825714826584, 27.58800733834505, 30.372184440493584, 43.64659734070301, 33.064374178647995, 43.95565755665302, 42.3919540643692, 44.7525317966938, 35.339654088020325, 25.481122992932796, 16.287740506231785, 9.362262524664402, 7.395130880177021, 2.785518430173397, 1.8879734608344734, 0.8113102591596544, 0.23059550992911682, 0.38707148458343, 0.0714794933446683, 0.07916891510831192, 0.15382055542431772, 0.02417225819954183, 0.09677227950305678, 0.017099839460570365, 0.09711076563689858, 0.07399858004646376, 0.04579645254125353, 0.16089221346192062, 0.004821324810109218, 0.15611456357873976, 0.1348061382304877, 0.2892181259812787, 0.23652509175008163, 0.5576133099384606, 1.0611128923483193, 1.2558910343796015, 3.2774096354842186, 4.930578852072358, 9.780377838760614, 17.37717814743519, 26.088835783302784, 33.02231043577194, 37.96772226691246, 39.094867184758186, 29.671705327928066, 36.99256919324398, 37.84003011882305, 36.86684913933277, 23.062275387346745, 34.1649205237627, 30.54086498916149, 37.26883336901665, 37.91392095386982, 29.46693241596222, 42.98308074474335, 50.55009350180626, 50.88480234146118, 62.12188236415386, 66.14023134112358, 73.33892226219177, 56.065805330872536, 30.010348856449127, 17.03110981732607, 4.111559875309467, 0.6220563082024455, 0.102563005493721, 0.035671023797476664, 0.03949956699216273, 0.08245036558946595, 0.05999568573315628, 0.019944847736041993, 0.06389115209458396, 0.08412330003920943, 0.015987139304343145, 0.025470747605140787, 0.014888400801282842, 0.03768173191929236, 0.021778666814498138, 0.03503754509438295, 0.037269825115799904, 0.060197253042133525, 0.03195344652340282, 0.06448439526138827, 0.03550209985405672, 0.05734429636504501, 0.036271732969908044, 0.05135127576068044, 0.04318932114983909, 0.010067447528854245, 0.03576755123503972, 0.01912092095153639, 0.05952093757514376, 0.0632922982913442, 0.01616630488570081, 0.07028332198387943, 0.08719723860849626, 0.047446706957998686, 0.10337072191759944, 0.07423666102113202, 0.03945426258724183, 0.0349519272276666, 0.040668301153345965, 0.029176142525102478, 0.0319417651189724, 0.09678180867922492, 0.042620442691259086, 0.02928976533439709, 0.01841761728428537, 0.012645185233850498, 0.05638145994453225, 0.026900576740445103, 0.030876959463057574, 0.10252595748170279, 0.006990293140916037, 0.15129219187656417, 0.08995576441520825, 0.14464299398241565, 0.12164754080004059, 0.19826313393423334, 0.17130819673184305, 0.14897517714416608, 0.16728198621422052, 0.13152971951058134, 0.21236160944681615, 0.14858672220725566, 0.08436466130660847, 0.11767201896873303, 0.10438228404382244, 0.1377680792938918, 0.204709354438819, 0.08189313142793253, 0.1135043847898487, 0.15869392751483247, 0.13723398529691622, 0.2015485177980736, 0.14370165386935696, 0.1712830230826512, 0.12173647977760993, 0.17064142157323658, 0.19973402610048652, 0.14567785954568535, 0.10594791878247634, 0.15525649243500084, 0.1706619790638797, 0.08974722091807052, 0.19058937148656696, 0.15997304872144014, 0.15539739659288898, 0.1425426418427378, 0.22363897383911535, 0.20032208907650784, 0.12122824220568873, 0.10790606058435515, 0.13191547302994877, 0.1666827464941889, 0.11149201425723732, 0.42801271425560117, 0.6086207635235041, 7.703177025541663, 33.5968966037035, 63.99713113903999, 77.52782508730888, 83.49011555314064, 78.06247919797897, 78.71339946985245, 69.25800204277039, 63.562172278761864, 61.04724682867527, 87.32847958803177, 71.19065433740616, 36.8370321393013, 28.717259243130684, 33.7903518229723, 37.639324888587, 30.112365782260895, 38.53495962917805, 50.35599611699581, 45.1163736730814, 45.59913396835327, 69.2314338684082, 60.08444309234619, 73.33924904465675, 74.84821647405624, 79.39632922410965, 53.02454352378845, 39.4530663639307, 28.239125199615955, 14.371457733213902, 12.891803830862045, 4.352636514231563, 3.7055124761536717, 1.5225353138521314, 0.909211115213111, 1.0147416056133807, 0.6551470106933266, 0.21590315300272778, 0.2663043758366257, 0.5209411808755249, 0.26741863635834306, 0.1971994581981562, 0.4913887119619176, 0.3610394080169499, 0.17937275930307806, 0.2784499491099268, 0.3247356216888875, 0.4807582776993513, 0.4573885817080736, 0.4687380976974964, 0.8648594794794917, 1.3403305783867836, 1.5734642185270786, 2.66925108153373, 6.865279236808419, 7.191581502556801, 17.72137887775898, 35.83661422133446, 46.98278032243252, 52.227080315351486, 62.985587418079376, 57.96468883752823, 40.37826731801033, 41.85019813477993, 39.04689095914364, 35.285176411271095, 24.75553672760725, 42.12556175887585, 34.51812297105789, 44.25588324666023, 42.209571450948715, 39.5194336026907, 52.46523253619671, 59.59768921136856, 60.91416656970978, 73.35185676813126, 75.49221351742744, 82.9502709209919, 65.27923554182053, 36.40409097075462, 21.739173084497452, 5.095680467784405, 1.311508531216532, 0.26070689025800675, 0.15692823944846168, 0.19351888069650158, 0.12993010925129056, 0.1432427394320257, 0.081161433190573, 0.19003713940037414, 0.17841528489952907, 0.12473078590119258, 0.11052150774048641, 0.1458953385008499, 0.11071701170294546, 0.1451934449141845, 0.14141819905489683, 0.2838461345527321, 0.0983818196982611, 0.19595345162088051, 0.09891733119729906, 0.08407174304011278, 0.13770511548500508, 0.18049168051220477, 0.16748607682529837, 0.24922319396864623, 0.12009697908069938, 0.1392490795115009, 0.1082599388610106, 0.18034728826023638, 0.07956632776767947, 0.12432100164005533, 0.09030700064613484, 0.18826428218744695, 0.1630598635529168, 0.23038122220896184, 0.13755935768131167, 0.17997709015617147, 0.20084600080735981, 0.1570132450433448, 0.15974442270817235, 0.12193056623800658, 0.1649548634304665, 0.11590568523388356, 0.13537719118176028, 0.21428377192933112, 0.19096290925517678, 0.1739797947811894, 0.1351196362520568, 0.18799810350174084, 0.15933790389681235, 0.12707635847618803], [0.032541943655814976, 0.0436259154957952, 0.0578603710164316, 0.011856249784614192, 0.03114475417532958, 0.025346948095830157, 0.06165368075016886, 0.012420962939359015, 0.02151259388483595, 0.05776021076599136, 0.020144301779509988, 0.014111941782175563, 0.007030958195173298, 0.010338375959690893, 0.07139546738471836, 0.017555059857841115, 0.04575632090563886, 0.04689463443355635, 0.03814673196757212, 0.1855195825919509, 0.011678109294734895, 0.04153357112954836, 0.04590830903907772, 0.06095156080846209, 0.0346546080254484, 0.009432907554582926, 0.039418992018909194, 0.04694773509982042, 0.02932946095825173, 0.01748890666931402, 0.053666093735955656, 0.02065254120680038, 0.0324721112701809, 0.04405581938044634, 0.054820266959723085, 0.02845420724042924, 0.04501789509959053, 0.03718045569257811, 0.03479953091300558, 0.034884625565609895, 0.07034813374048099, 0.05436362720502075, 0.48624530201777816, 7.800361085683107, 38.63992899656296, 61.69636979699135, 62.07262180745602, 69.17623043060303, 58.16741555929184, 56.39584802091122, 48.81814643740654, 45.260811522603035, 37.90442906320095, 53.76658670604229, 34.27264854311943, 38.78871001303196, 15.01552602276206, 19.462401755154133, 25.453460477292538, 37.27615937590599, 70.33800289034843, 50.810090750455856, 50.18196165561676, 61.174205616116524, 63.783909380435944, 45.5961587280035, 60.50619386136532, 36.78367540240288, 30.928159207105637, 15.787430852651596, 6.725935013964772, 1.8166899983771145, 0.8430143923033029, 0.5056484264787287, 0.05237920595391188, 0.06043742687324993, 0.03638457281340379, 0.05442114364996087, 0.057535751911927946, 0.031909340686979704, 0.03899212351825554, 0.005310904789439519, 0.016410304488090333, 0.08832021194393747, 0.1406233143643476, 0.057468283266643994, 0.05028122126532253, 0.05184549416298978, 0.14699638879392296, 0.10940089443465695, 0.0280089000807493, 0.09462197340326384, 0.06262988696107641, 0.061286955897230655, 0.03423899048357271, 0.06448397223721258, 0.09042897261679173, 0.3643824567552656, 0.11095603520516306, 0.31086541595868766, 0.34096731164027005, 1.3907387922517955, 5.152678834274411, 7.169578308239579, 18.84002935141325, 31.043752804398537, 49.927504509687424, 38.56194958090782, 40.53623244166374, 35.1766200363636, 63.075171411037445, 47.24642537534237, 23.139587938785553, 24.59952849894762, 18.243337869644165, 26.17379542440176, 16.86612267047167, 27.12219413369894, 31.34361371397972, 34.55728366971016, 51.21123902499676, 59.43620167672634, 60.400646924972534, 63.74047011137009, 48.924415335059166, 28.77394650131464, 13.172900397330523, 2.7124846866354346, 0.9220514574553818, 0.22043132252292708, 0.0802049161575269, 0.01231961525263614, 0.07516159967053682, 0.06226302852155641, 0.044691183138638735, 0.045996331464266405, 0.049819490377558395, 0.03828273052931763, 0.03658907902718056, 0.031053698221512605, 0.01838769017922459, 0.055522468537674285, 0.009413088500878075, 0.04594896759954281, 0.0701617136655841, 0.04851172969210893, 0.03425586321100127, 0.05005508144677151, 0.03092392442340497, 0.030365603015525267, 0.09376268513733521, 0.03889556639478542, 0.030067185434745625, 0.06377693556714803, 0.053936428448650986, 0.05835472671606112, 0.08813085296424106, 0.03740542662853841, 0.06539668029290624, 0.0840686185983941, 0.07096168206771836, 0.05983771960018203, 0.034222462854813784, 0.040108721805154346, 0.009038375355885364, 0.04123206621443387, 0.03222489445761312, 0.03735917969606817, 0.035051723825745285, 0.03930269005650189, 0.017121346900239587, 0.050251884167664684, 0.03531968737661373, 0.0149779780258541, 0.06614933678065427, 0.04436943243490532, 0.02285546372149838, 0.006858299857412931, 0.014916724867362063, 0.016629677775199525, 0.06394485390046611, 0.02132614783477038, 0.059371743627707474, 0.04077684767253231, 0.05649153157719411, 0.08564099203795195, 0.038571808181586675, 0.07083714226610027, 0.03622684416768607, 0.02102063717757119, 0.004628842780221021, 0.03984765651694033, 0.014333203835121822, 0.04558029460895341, 0.029385862326307688, 0.02347654299228452, 0.05021852091886103, 0.15667313360609114, 0.05385391275922302, 0.02016693357290933, 0.045323359372559935, 0.036819597517023794, 0.030700359857291915, 0.03476063495327253, 0.024797808910079766, 0.065023632341763, 0.05172162600501906, 0.04347356370999478, 0.054339592752512544, 0.06867959280498326, 0.05103330629935954, 0.057588136405684054, 0.01625002099899575, 0.04326854170358274, 0.027059871317760553, 0.11548078342457302, 0.0423930783290416, 0.17032587522407994, 0.15001618769019842, 14.335219077765942, 47.145791575312614, 69.72805202007294, 70.98187074065208, 77.95640408992767, 68.297079205513, 64.84361931681633, 60.62577344477177, 59.086859822273254, 46.27294421195984, 54.71448764204979, 47.291114777326584, 52.21444979310036, 22.773336991667747, 25.463689528405666, 24.67613998800516, 34.78214420378208, 46.84647023677826, 39.602432548999786, 38.57977822422981, 46.67802907526493, 43.810326755046844, 39.81820397078991, 45.62673568725586, 34.47498768568039, 25.7185285538435, 13.355079721659422, 6.271441401913762, 2.67347218003124, 0.6750118697527796, 0.5939355015289038, 0.10163172890315764, 0.03316079833894037, 0.019419351519900374, 0.08150440931785852, 0.0714547056122683, 0.0369217578554526, 0.02780439201160334, 0.07693050123634748, 0.08468786661978811, 0.015360980960394954, 0.0965088393422775, 0.11627387953922153, 0.05221182196692098, 0.07644862474990077, 0.4106038890313357, 0.11261025269050151, 0.07453366109984927, 0.01455657265978516, 0.03238950281229336, 0.025571329024387524, 0.041493613898637705, 0.07749264099402353, 0.07161887609981932, 0.10123013795237057, 0.09032360248966143, 0.11852417519548908, 0.15920085890684277, 0.8749494224321097, 2.898229882121086, 5.9544985089451075, 15.194319728761911, 23.104437924921513, 35.80889470875263, 35.246562883257866, 40.01891300082207, 37.90971837937832, 52.586533427238464, 52.393876165151596, 26.695606224238873, 28.496348597109318, 27.291463650763035, 30.320664905011654, 27.256896905601025, 38.79216402769089, 40.72269223630428, 44.87780727446079, 59.26546923816204, 68.32626923918724, 71.28816470503807, 75.43221473693848, 58.833687007427216, 38.28983098268509, 16.807111836969852, 4.241675343364477, 1.8219287297688425, 0.3163340943865478, 0.039829652014304884, 0.018175280092691537, 0.011060735196224414, 0.04310617834562436, 0.006721922800352331, 0.06663029300398193, 0.005740609685744857, 0.026938563569274265, 0.0616683678526897, 0.04911916643322911, 0.02300136624398874, 0.040657937061041594, 0.06429834626032971, 0.04039900544739794, 0.020052342260896694, 0.08263665207778104, 0.0900246282981243, 0.06452349160099402, 0.04619390601874329, 0.038979688833933324, 0.04159265350608621, 0.06434644485125318, 0.05797519981570076, 0.04660473670810461, 0.02091969952743966, 0.015991119071259163, 0.0684279008419253, 0.04041545143991243, 0.019224727002438158, 0.04159148833423387, 0.04081415172549896, 0.04570153927488718, 0.026332104607718065, 0.016145274275913835, 0.021286275950842537, 0.10607019503368065, 0.006669397762379958, 0.024723627539060544, 0.01450902233045781, 0.009056902144948253, 0.03146955139527563, 0.06676716729998589, 0.024772381075308658, 0.03646648365247529, 0.032036010452429764, 0.09530207753414288, 0.13607853557914495, 0.0810440254281275, 0.0964196925633587, 0.07876619609305635, 0.15155118657276034, 0.10133987932931632, 0.10189389256993309, 0.14830115862423554, 0.1323659863555804, 0.12413543503498659, 0.0850700207229238, 0.1579885755199939, 0.15154777269344777, 0.09261096842237748, 0.1487337565049529, 0.14631986181484535, 0.16391204204410315, 0.1543534322991036, 0.09501306296442635, 0.2648834598949179, 0.10317447580746375, 0.24465794675052166, 0.1823188184062019, 0.15915149124339223, 0.21282482834067196, 0.14352922327816486, 0.11519806968863122, 0.33920557179953903, 0.14381000743014738, 0.14581091178115457, 0.18827306921593845, 0.11083459758083336, 0.14945595525205135, 0.1900002991897054, 0.15010885224910453, 0.3065645811147988, 0.11423577132518403, 0.08751487781410106, 0.09462782152695581, 0.1939804817084223, 0.14119568833848462, 0.5200543440878391, 0.7676830189302564, 19.045410230755806, 57.26397983729839, 79.99941766262054, 78.89012798666954, 86.64108127355576, 76.7904594540596, 75.51499709486961, 69.22100722789764, 64.73147973418236, 53.07910859584808, 65.12955397367477, 43.71291138231754, 50.86966015398502, 24.264420680701733, 31.212363056838512, 35.48586644232273, 52.93090894818306, 90.49999460577965, 68.61501574516296, 67.65681356191635, 79.51080948114395, 81.25971883535385, 60.78335478901863, 76.41981974244118, 48.71355704963207, 41.57003916800022, 21.696847155690193, 9.417374767363071, 3.418805985711515, 1.4986003981903195, 1.140808747150004, 0.3576828818768263, 0.2221244730753824, 0.14100997330388054, 0.2635388367343694, 0.36485692660789937, 0.1760908041615039, 0.18212185241281986, 0.293344288947992, 0.36676047602668405, 0.22818538534920663, 0.3304148622555658, 0.29700937040615827, 0.3335559874540195, 0.21363001404097304, 0.41713297774549574, 0.39929815975483507, 0.28844750951975584, 0.19244678900577128, 0.18769591581076384, 0.11948628060054034, 0.2314286449109204, 0.1646093640010804, 0.2120213644229807, 0.6337914441246539, 0.5095320555847138, 0.7083448092453182, 0.814716835739091, 2.042460939846933, 6.823331862688065, 10.611384697258472, 25.485724546015263, 40.2576769888401, 63.030949383974075, 52.65326924622059, 56.78998947143555, 48.19646939635277, 79.2049790918827, 59.878418147563934, 34.69029553234577, 37.26995050907135, 30.726055651903152, 40.99948078393936, 31.1100060492754, 44.26596790552139, 47.93679893016815, 53.42608317732811, 70.40294900536537, 79.00634855031967, 82.42827773094177, 83.32336530089378, 66.08663141727448, 45.16991280019283, 21.94022599607706, 6.51001445017755, 2.693655272014439, 0.5857199861202389, 0.16688291856553406, 0.08174347734893672, 0.08553092411602847, 0.24009140819543973, 0.20868177409283817, 0.17611352872336283, 0.1318586542038247, 0.10593445622362196, 0.1914208143716678, 0.26380363502539694, 0.08406931621721014, 0.15702390228398144, 0.2273953691474162, 0.12073645804775879, 0.17114683898398653, 0.15472300699912012, 0.21779107279144228, 0.17149726627394557, 0.15523994254181162, 0.08130605550832115, 0.18920796748716384, 0.14901464455761015, 0.2447307069087401, 0.24005483515793458, 0.08267643861472607, 0.2416601896402426, 0.23066859663231298, 0.12411170115228742, 0.1915998649201356, 0.09104169716010801, 0.1360151858534664, 0.23129465756937861, 0.1499238793621771, 0.11631400004262105, 0.0998156786954496, 0.2115501748630777, 0.12492696521803737, 0.09237270191079006, 0.09982327828765847, 0.2282002431456931, 0.16128256829688326, 0.12092640332411975, 0.13551165349781513, 0.14848950086161494, 0.1475355145521462, 0.14300664741313085], [0.08470878034131601, 0.0624739023623988, 0.00620471544607426, 0.021221195165708195, 0.06279166773310862, 0.057463373959762976, 0.03823246115643997, 0.05945307930232957, 0.04714654161944054, 0.029036453634034842, 0.060633858520304784, 0.030853195894451346, 0.041407339231227525, 0.01138062867539702, 0.017514996870886534, 0.05757031372922938, 0.02330152416107012, 0.04223802883643657, 0.03233078408811707, 0.06429875444155186, 0.1007346430560574, 0.04091868322575465, 0.0798623778973706, 0.0474871168989921, 0.04854525992413983, 0.03448496419878211, 0.03979622197221033, 0.02138243602530565, 0.04338761187682394, 0.014680318363389233, 0.011267388999840477, 0.07929168859845959, 0.08161058838595636, 0.046895777340978384, 0.0686024985043332, 0.04813734587514773, 0.02089619756588945, 0.08581792004406452, 0.050145263521699235, 0.035414118246990256, 0.4797024093568325, 1.765459009911865, 21.695555225014687, 47.622392401099205, 58.46921816468239, 63.99650037288666, 63.20411369204521, 50.940560549497604, 45.97784444689751, 46.76004767417908, 29.715651869773865, 14.54302802681923, 22.421719059348106, 33.62401194870472, 13.337038289755583, 23.865666277706623, 37.11336471140385, 42.048015519976616, 58.30009303987026, 42.42854990065098, 50.385224148631096, 40.0350621342659, 45.702245235443115, 37.434048503637314, 25.66027007997036, 27.49547280371189, 16.979383192956448, 9.548399336636066, 2.0850443048402667, 0.7024896203074604, 0.14380119071574882, 0.05820974816742819, 0.04930202791001648, 0.09003291066619568, 0.1103446316847112, 0.07510919662308879, 0.019413477421039715, 0.1635429126326926, 0.07135769206797704, 0.026226161171507556, 0.046754420473007485, 0.060839080906589516, 0.07106688150088303, 0.05207330752455164, 0.09827625661273487, 0.08011192505364306, 0.02249598594062263, 0.08639310675789602, 0.16745361528592184, 0.02880259733501589, 0.08878109307261184, 0.15574392018606886, 0.0476971484022215, 0.1139653475547675, 0.04148537977016531, 0.12309535959502682, 0.0176835831371136, 0.03950952290324494, 0.043148966869921423, 0.010731494367064442, 0.048207653235294856, 0.20868610823526978, 0.0179396500607254, 0.05021431665227283, 0.25382578605785966, 2.633235426619649, 5.53930951282382, 11.615977641195059, 23.466199412941933, 33.5978427529335, 56.55938744544983, 43.692685067653656, 45.60930222272873, 38.88922221958637, 29.194891713559628, 20.40411662310362, 10.410380233079195, 25.335448309779167, 21.802441589534283, 26.40842143446207, 34.40360091626644, 41.320358365774155, 48.37062165141106, 58.856238797307014, 63.29326070845127, 64.34023752808571, 47.584386840462685, 38.779392912983894, 25.840737596154213, 10.565215274691582, 2.0968892192468047, 0.04567373100144323, 0.04225081233016681, 0.042393486510263756, 0.034826890187105164, 0.012504429505497683, 0.048842961332411505, 0.08061064829234965, 0.054456807556562126, 0.03435289159824606, 0.00939114133871044, 0.02229225341579877, 0.05687969707651064, 0.042626420690794475, 0.06321179011138156, 0.016939021625148598, 0.09349806496175006, 0.055378376855514944, 0.01554789270812762, 0.02964811876154272, 0.017163059310405515, 0.05930858686042484, 0.07941395742818713, 0.06290937977610156, 0.048827365098986775, 0.04225420765578747, 0.038014796664356254, 0.07058574716211297, 0.0589566975395428, 0.0212008770176908, 0.023724815509922337, 0.010428265813970938, 0.1053889851027634, 0.007295992581930477, 0.02474096225341782, 0.019196480861864984, 0.07293652219232172, 0.015408289164042799, 0.07728476542979479, 0.05506371737283189, 0.05645829820423387, 0.011648324125417275, 0.08672494324855506, 0.025977582517953124, 0.008527071786375018, 0.05201676700380631, 0.03430882657994516, 0.029185781168052927, 0.049477479042252526, 0.02014857283938909, 0.05010415967262816, 0.05988603712467011, 0.05034701636759564, 0.026194644015049562, 0.024947826641437132, 0.05067169855465181, 0.11578108606045134, 0.023248776014952455, 0.02580165455583483, 0.010024727653217269, 0.00654278504953254, 0.05685172924131621, 0.005546490292545059, 0.03209862545190845, 0.009138882560364436, 0.06134885843493976, 0.04524596079136245, 0.016185956956178416, 0.0715590367326513, 0.011669608920783503, 0.0245719010126777, 0.025124984713329468, 0.08309833472594619, 0.034992222135770135, 0.02485418430296704, 0.03299255346064456, 0.07375607587164268, 0.04406789412314538, 0.03967075448599644, 0.002881050909309124, 0.022445082031481434, 0.07441145164193586, 0.02832823694916442, 0.013084443889965769, 0.036837435036432, 0.01922489213029621, 0.49659018754027784, 4.293512161821127, 33.01381789147854, 61.790315955877304, 67.14299753308296, 73.21194067597389, 70.20861223340034, 59.26692835986614, 56.31221070885658, 58.86847034096718, 41.316379979252815, 26.457623094320297, 26.290694251656532, 37.14966036379337, 18.032969757914543, 35.888166055083275, 33.46602402627468, 33.791601955890656, 43.838145062327385, 35.45956805348396, 49.28889937698841, 32.74603106081486, 35.27937412261963, 27.80802123248577, 23.28584399074316, 23.182808719575405, 15.562349930405617, 8.381329961121082, 2.336000413633883, 0.5954613571520895, 0.2561333012999967, 0.012449909481802024, 0.05259105942968745, 0.020563242287607864, 0.0335716698464239, 0.007705531006649835, 0.24928137834649533, 0.11134728803881444, 0.09220683932653628, 0.05851151654496789, 0.08453594899037853, 0.08128988411044702, 0.05360752715205308, 0.06812080013332888, 0.1149249222362414, 0.03587650593544822, 0.09355027505080216, 0.17325577035080642, 0.251360698021017, 0.2183789576520212, 0.08342118380824104, 0.05692278245987836, 0.1269887702073902, 0.18814255512552336, 0.1157119327399414, 0.11139299691421911, 0.05901145690586418, 0.01378746183036128, 0.061990901522221975, 0.14543118450092152, 0.045617632058565505, 0.13171504862839356, 0.00177540846152624, 0.024908889863581862, 0.17351421585772187, 2.4328740779310465, 4.705222444608808, 9.176008868962526, 19.02134232223034, 24.264481477439404, 50.439770221710205, 37.58040525019169, 41.08146518468857, 39.60825763642788, 29.772958494722843, 26.979855671525, 18.818218521773815, 29.26202841103077, 28.904902674257755, 33.89054484665394, 44.09073270857334, 51.4968279004097, 57.00704142451286, 66.55839130282402, 71.21945679187775, 74.89075899124146, 60.33943220973015, 49.9496915191412, 34.5772971957922, 15.500850230455399, 3.4356502443552017, 0.020678137880167924, 0.055677907657809556, 0.044788441591663286, 0.08833862462779507, 0.032180558555410244, 0.019742003933060914, 0.05583420024777297, 0.0071561752065463224, 0.08573959377827123, 0.01528799537481973, 0.06355596851790324, 0.028229596246092115, 0.03994238424638752, 0.04639751052309293, 0.02632425082992995, 0.10537901805946603, 0.028004348860122263, 0.03589808758988511, 0.030470654019154608, 0.05242794279183727, 0.05221602623350918, 0.02792533425235888, 0.03792680392507464, 0.01562113619002048, 0.01247142248757882, 0.026662395575840492, 0.04133717287913896, 0.07651119522051886, 0.020095950858376455, 0.016045563024817966, 0.025604664442653302, 0.015540189215244027, 0.043006841879105195, 0.05370195802242961, 0.042900677653960884, 0.062240741826826707, 0.030878874204063322, 0.017466697900090367, 0.04403769242344424, 0.10870562080526724, 0.035254215108579956, 0.059957754565402865, 0.008169946613634238, 0.005602864293905441, 0.026734270722954534, 0.1517928298562765, 0.15835924859857187, 0.18623401847435161, 0.15234624937875196, 0.11983623291598633, 0.11652099245111458, 0.1462521482608281, 0.12019881658488885, 0.15564773784717545, 0.10322877133148722, 0.18672888254513964, 0.18548185180407017, 0.11360021831933409, 0.09150596990366466, 0.09399954898981377, 0.1678552952944301, 0.08530432416591793, 0.139708379865624, 0.11982173135038465, 0.153138343594037, 0.18470390292350203, 0.1550624950323254, 0.19394733739318326, 0.14552422013366595, 0.19425415608566254, 0.18429051182465628, 0.1731409304193221, 0.0912839786906261, 0.18590671650599688, 0.129331567150075, 0.18780193902784958, 0.2309975610114634, 0.15496457606786862, 0.1084123834152706, 0.17227582371560857, 0.1404091008589603, 0.15785433584824204, 0.1956326063373126, 0.13773364364169538, 0.1643439126200974, 0.9169679239857942, 6.530149094760418, 42.302115485072136, 75.09139582514763, 76.3911996781826, 82.30112135410309, 80.45965656638145, 68.66809889674187, 63.47414620220661, 64.3845583498478, 43.816338032484055, 29.434993229806423, 36.046351566910744, 44.46971297264099, 22.006935216486454, 35.4770927131176, 51.38738617300987, 58.59101302921772, 76.05829194188118, 58.23132053017616, 65.58839455246925, 51.36567793786526, 59.08060535788536, 48.051298186182976, 34.59824167191982, 37.71248236298561, 23.955295868217945, 13.385882768779993, 3.8854755694046617, 1.3993591046892107, 0.5313861672766507, 0.22614596353378147, 0.23233669227920473, 0.11936148104723543, 0.25687800196465105, 0.36849300493486226, 0.34342494851443917, 0.46910554985515773, 0.30543577449861914, 0.6071508361492306, 0.38189729035366327, 0.17166965233627707, 0.21035809273598716, 0.23255078704096377, 0.26633510075043887, 0.3580693033291027, 0.13381664757616818, 0.25172832829412073, 0.4202555789379403, 0.6819252425339073, 0.15784796822117642, 0.504001333611086, 0.24167044612113386, 0.41352717904374003, 0.3808926302008331, 0.2659276913618669, 0.1817753436625935, 0.09476042105234228, 0.2207680349238217, 0.14465287938946858, 0.1444997001090087, 0.3020620602183044, 0.20002802048111334, 0.21854825638001785, 0.4958599142264575, 4.426149744540453, 8.147612102329731, 15.575422178953886, 30.010481849312782, 45.027291253209114, 68.17507535219193, 54.38696041703224, 62.43321105837822, 54.6908263117075, 42.95232519507408, 34.44596104323864, 21.750823259353638, 35.82057148218155, 33.76210793852806, 40.67934416234493, 50.14553681015968, 59.76424187421799, 69.2976263165474, 78.99898454546928, 82.31954276561737, 85.38848608732224, 69.59825858473778, 56.78207829594612, 40.772815346717834, 18.603649735450745, 4.5193060208112, 0.13559646613430232, 0.14799987635342404, 0.10015011270297691, 0.1702842555823736, 0.12236259266501293, 0.12498906813561916, 0.20746549795148894, 0.17447992810048163, 0.18686178635107353, 0.0566747863922501, 0.18490769667550921, 0.21358251658966765, 0.10352235010941513, 0.20314784604124725, 0.22280303353909403, 0.3007235820405185, 0.14938506530597806, 0.13921345642302185, 0.1264099989202805, 0.13381307042436674, 0.17068693006876856, 0.22635898960288614, 0.18571758759208024, 0.10028875331045128, 0.14361145324073732, 0.17366148764267564, 0.1297239851555787, 0.12017391753033735, 0.15354728180682287, 0.0969762439490296, 0.12532012537121773, 0.19269980199169368, 0.19255900173448026, 0.18583193770609796, 0.15991915395716205, 0.1468399737495929, 0.1074070182221476, 0.14161817816784605, 0.19296229962492362, 0.2706962573574856, 0.08339637381141074, 0.20088334567844868, 0.08364721230464056, 0.15663743630284443, 0.2006978532881476], [0.03897926952049602, 0.01475622058933368, 0.13454187428578734, 0.03416908388317097, 0.009892229245451745, 0.04260034533217549, 0.05000682700483594, 0.01727209564705845, 0.03466219648544211, 0.03685152099933475, 0.0530583415820729, 0.02095394222124014, 0.055953177652554587, 0.056810358219081536, 0.005795301794933039, 0.024949733960966114, 0.030437142340815626, 0.07088656930136494, 0.031735692973597907, 0.09795401609153487, 0.060055046415072866, 0.02546265077398857, 0.051253397614345886, 0.03546529675077181, 0.016667915078869555, 0.05029540741816163, 0.04238713372615166, 0.050477085169404745, 0.03214109114196617, 0.09859923186013475, 0.08266420059953816, 0.044525198100018315, 0.09434614679776132, 0.10226645070360973, 0.10525333535042591, 0.01270950438993168, 0.015151587704167468, 0.011935282018384896, 0.1710945917875506, 1.3044424541294575, 8.754963912069798, 32.530681416392326, 62.23567105829716, 65.46801701188087, 66.55732735991478, 59.314463809132576, 56.38111621141434, 42.50604674220085, 29.65093944221735, 20.26727646589279, 30.34753516316414, 36.28841757774353, 33.33825968205929, 23.505964279174805, 41.1819089949131, 72.15337827801704, 49.257611855864525, 61.1881622672081, 41.896532848477364, 31.12765610218048, 14.940893277525902, 12.090874258428812, 7.900262475013733, 6.235994528979063, 3.3937197318300605, 1.6447391314432025, 1.4326007897034287, 0.23994660034077242, 0.021639861079165712, 0.0677470768277999, 0.03176477774104569, 0.04568363867292646, 0.034406671329634264, 0.056918411210062914, 0.052266110069467686, 0.11726171520422213, 0.07484233516152017, 0.09402000257978216, 0.09801014472031966, 0.0368925209477311, 0.09908703810651787, 0.1203034668287728, 0.07041460790787823, 0.02947171396954218, 0.08446559339063242, 0.07120969297830015, 0.0026788743434735807, 0.16456900601042435, 0.10906230440014042, 0.10046934010460973, 0.13797165040159598, 0.09764139380422421, 0.07534120682976209, 0.11631862362264656, 0.1258692701230757, 0.1459402235923335, 0.046845734323142096, 0.02969704113638727, 0.0193955100257881, 0.1451048770104535, 0.05149116688698996, 0.10905609262408689, 0.035357266024220735, 0.038705650804331526, 0.08735813622479327, 0.029963835804664996, 0.09462296788115054, 0.49755159532651305, 1.6939355665817857, 7.264215080067515, 6.947677815333009, 26.313787512481213, 36.13623194396496, 37.62920223176479, 49.22750227153301, 35.477484092116356, 48.866267055273056, 36.347006633877754, 24.86858256161213, 19.430622160434723, 17.591066770255566, 22.491762600839138, 28.299179077148438, 40.60800679028034, 46.41203574836254, 53.91607828438282, 66.66292369365692, 66.1043156683445, 65.95530286431313, 57.66085334122181, 29.79720499366522, 11.250605396926403, 1.971625853329897, 0.07631962464074604, 0.07539221463957801, 0.09871383430436254, 0.016643309172650333, 0.019438413582975045, 0.020613966225937475, 0.05575800023507327, 0.06306860756012611, 0.05065130804723594, 0.009797705606615636, 0.022863670019432902, 0.028296202144701965, 0.08084498142125085, 0.08661486790515482, 0.04306875554902945, 0.029306157521205023, 0.033518368800287135, 0.00900182551049511, 0.019219281493860763, 0.04494719811191317, 0.11062329329433851, 0.04993457150703762, 0.03928540914785117, 0.0724438251927495, 0.024763761030044407, 0.0022444628393714083, 0.06139265628007706, 0.03335084009449929, 0.08987573120975867, 0.047947782804840244, 0.020284717975300737, 0.04698185162851587, 0.017730043437040877, 0.041350728206452914, 0.03686129879497457, 0.04137149720918387, 0.012755317166011082, 0.07073870379826985, 0.006518715808851994, 0.07459488086169586, 0.01907454785396112, 0.04309099029342178, 0.030129008191579487, 0.017321823252132162, 0.020821238795178942, 0.020223893407091964, 0.024134924460668117, 0.025359336395922583, 0.05087844234367367, 0.04030848198453896, 0.043206806149100885, 0.04513218955253251, 0.0277250805447693, 0.024260740756290033, 0.044986294451518916, 0.04051196032378357, 0.02222807248472236, 0.06117205659393221, 0.006046342523404746, 0.025114438794844318, 0.07125415504560806, 0.024595089416834526, 0.014996888876339654, 0.09368447019369341, 0.05282122168864589, 0.03106410127657, 0.006761860549886478, 0.010199766893492779, 0.02281107401358895, 0.15676803945098072, 0.10560525435721502, 0.003818287409558252, 0.11463038608781062, 0.021210990635154303, 0.049433306412538514, 0.0506988574488787, 0.034465772259864025, 0.017970950138987973, 0.05345334226149134, 0.03300376731203869, 0.12735902768326923, 0.22165932459756732, 1.5855606319382787, 12.587214075028896, 42.031429409980774, 72.76927202939987, 71.463213711977, 75.70323139429092, 67.70613491535187, 66.05247884988785, 49.058726727962494, 39.94359724223614, 34.66257221996784, 36.042639166116714, 33.448628559708595, 34.549691677093506, 34.109834879636765, 46.32399067282677, 58.33484597504139, 48.72999496757984, 45.08388541638851, 35.42674161493778, 23.705867752432823, 11.811279561370611, 9.81760824099183, 6.400984050706029, 5.148645825684071, 2.973104864358902, 1.878528711386025, 1.3492177077569067, 0.4689588421024382, 0.07753890648018569, 0.027447962602309417, 0.04799549547897186, 0.10677355065126903, 0.06228396450751461, 0.03290961103630252, 0.18203102838015184, 0.16442434658529237, 0.209841305622831, 0.24542979517718777, 0.30566355446353555, 0.04518170564551838, 0.08130946938763373, 0.06799747003242373, 0.12209251770400442, 0.09641004464356229, 0.11708230842486955, 0.2447496762033552, 0.07809651913703419, 0.4450849903514609, 1.3492364692501724, 0.6830582348629832, 0.41679245070554316, 0.5290483427233994, 0.3108099033124745, 0.30713455053046346, 0.25563843722920865, 0.2977489057229832, 0.41882765712216496, 0.22786970541346818, 0.23820841626729816, 0.26031453162431717, 0.3178907046094537, 0.09271973016439006, 0.16408515541115776, 0.0554035505047068, 0.20866517967078835, 0.04044492212415207, 0.023304466776608024, 0.20616865425836295, 1.0061356611549854, 4.090490005910397, 6.552464347332716, 21.452104188501835, 27.338501326739788, 35.97439102828503, 40.04822462797165, 38.5246317833662, 36.99780911207199, 37.02295236289501, 27.05784648656845, 31.713736653327942, 26.046629548072815, 31.46857000887394, 37.38243207335472, 50.70471100509167, 57.87541262805462, 61.84622995555401, 76.56584590673447, 76.71397715806961, 75.33778980374336, 69.86005693674088, 38.8734682649374, 15.330479722470045, 3.063713377341628, 0.1017037320707459, 0.19716269220225513, 0.043185933245695196, 0.06113582494435832, 0.036048175825271755, 0.0341748986102175, 0.05218309714109637, 0.029923535330453888, 0.03318808339827228, 0.028778505366062745, 0.02586773167422507, 0.0493972343247151, 0.05477770850120578, 0.044841275084763765, 0.04583010893838946, 0.02427782499580644, 0.046512717817677185, 0.034975880043930374, 0.03632023603131529, 0.024093952342809644, 0.1124431136122439, 0.031185587140498683, 0.03208313682989683, 0.055957122167455964, 0.03691404694109224, 0.06850457211839966, 0.04922363856167067, 0.033273085282417014, 0.05625999634503387, 0.06268194862059318, 0.061918720239191316, 0.0807502462703269, 0.06970380854909308, 0.04282116766262334, 0.03997946565505117, 0.07047697057714686, 0.002008928358918638, 0.06933999291504733, 0.036726413454744034, 0.07791516050929204, 0.039681812486378476, 0.03520170444971882, 0.09190620272420347, 0.08636011829366907, 0.16878756636288017, 0.22695104533340782, 0.12757131160469726, 0.07430908721289597, 0.08783181197941303, 0.11093029010226019, 0.06616695536649786, 0.17818250285927206, 0.08197346891392954, 0.15572098782286048, 0.1168126861739438, 0.1272143385722302, 0.13561062631197274, 0.1394658163189888, 0.18420253763906658, 0.15244354493916035, 0.22633099579252303, 0.11948228042456321, 0.1590039225993678, 0.14952034398447722, 0.10922855290118605, 0.1248438298352994, 0.14470799127593637, 0.10533138702157885, 0.11387217091396451, 0.22750385629478842, 0.18677106621908024, 0.14563526026904583, 0.20796500786673278, 0.18753669544821605, 0.0735729064035695, 0.2082960057305172, 0.1630308010498993, 0.1497446358553134, 0.12791498535079882, 0.08838532055960968, 0.1998085228842683, 0.38344615255482495, 2.295518098399043, 15.928321592509747, 51.18990696966648, 85.76317638158798, 79.44356068968773, 85.71779921650887, 77.38341003656387, 75.57292878627777, 60.63307665288448, 45.15867680311203, 32.46570870280266, 45.028347596526146, 48.136200830340385, 45.379053577780724, 36.35076843202114, 58.138058334589005, 88.26589688658714, 65.90519115328789, 75.59690549969673, 53.624603524804115, 38.68345566093922, 19.806733578443527, 16.434961706399918, 10.564629156142473, 8.442329987883568, 5.454991087317467, 2.9721551528200507, 2.32443003449589, 0.9973644255660474, 0.19106632011244074, 0.19145811471389607, 0.2355414640624076, 0.14105061331065372, 0.16410124517278746, 0.17278318555327132, 0.17240007407963276, 0.31017242814414203, 0.5653971922583878, 0.2908329799538478, 0.41784466768149287, 0.13896094809751958, 0.3146164974896237, 0.44205349520780146, 0.2975738776149228, 0.3698077640729025, 0.2710179635323584, 0.312886432511732, 0.09426184624317102, 0.44043890840839595, 1.3575949519872665, 0.43234293814748526, 0.4145868174964562, 0.5611799529287964, 0.30244488967582583, 0.3137893887469545, 0.26487081369850785, 0.2450428987503983, 0.30070051609072834, 0.36944319144822657, 0.22751527052605525, 0.4306769650429487, 0.2687200071522966, 0.18777893244987354, 0.23385180160403252, 0.14084741327678785, 0.4980154969962314, 0.22980598354479298, 0.41684778523631394, 0.7793156197294593, 2.9746378445997834, 9.5878098718822, 9.031308833509684, 34.34835188090801, 44.8019215464592, 50.89808262884617, 63.56317542493343, 52.02529214322567, 65.14919131994247, 52.58749857544899, 40.49472726881504, 33.098313957452774, 27.23018053919077, 35.315164402127266, 43.19342985749245, 59.788207188248634, 66.97140634059906, 74.31989282369614, 87.09897190332413, 88.89740779995918, 86.2089304625988, 79.26946923136711, 47.49077886343002, 21.061625741422176, 4.350231718271971, 0.40176375245209783, 0.42166200815699995, 0.13693521148525178, 0.10158112927456386, 0.0775150686968118, 0.20774561417056248, 0.17786094511393458, 0.14219510892871767, 0.14371787721756846, 0.21324721426935866, 0.1782076171366498, 0.15282388078048825, 0.12548746482934803, 0.1744350726949051, 0.13710220955545083, 0.15312357485527173, 0.11649419349851087, 0.13492275931639597, 0.10175030183745548, 0.17060205806046724, 0.299823327222839, 0.16262836405076087, 0.09047503030160442, 0.21660816360963508, 0.1890878434642218, 0.19490818114718422, 0.11741189620806836, 0.24710228433832526, 0.21733370202127844, 0.19482854870148003, 0.10363811030401848, 0.15084771963302046, 0.22043127799406648, 0.11962172255152836, 0.08954030272434466, 0.2505978592671454, 0.06276317668380216, 0.11987221965682693, 0.13250472344225273, 0.22857646748889238, 0.16355094267055392, 0.19178835558705032, 0.18278813775395975], [0.06692021299386397, 0.017032708492479287, 0.0005380571815294388, 0.029937788276583888, 0.03211834431567695, 0.04328991926740855, 0.036895753000862896, 0.0555561286455486, 0.02540507681260351, 0.01976819989067735, 0.010096486839756835, 0.013899981622671476, 0.052871201623929664, 0.05819856400194112, 0.12552384490845725, 0.022091409700806253, 0.02459004652337171, 0.008763472724240273, 0.032071689201984555, 0.006566844085682533, 0.06192762230057269, 0.04688840781454928, 0.07398747009574436, 0.015288756076188292, 0.06180824413604569, 0.01637191504414659, 0.013547384478442837, 0.03933228690584656, 0.01811065201763995, 0.08814605957013555, 0.06992642316618003, 0.07387093806755729, 0.025510202031000517, 0.043006485648220405, 0.0307665371656185, 0.021687983789888676, 0.07729807213763706, 0.23746131104417145, 1.004049216862768, 17.824169062078, 46.83520384132862, 62.97937475144863, 67.11468145251274, 64.64534595608711, 47.84017391502857, 48.60998220741749, 41.650879830121994, 22.364273741841316, 17.369852140545845, 12.221074271947145, 14.57197867333889, 24.159472212195396, 20.133753530681133, 28.301253765821457, 38.8847004622221, 55.47012649476528, 30.51706686615944, 17.587531059980392, 10.420665331184864, 4.534261068329215, 4.360052291303873, 0.4092306486563757, 0.029505381498893257, 0.045165270785219036, 0.049802346766227856, 0.06723502461682074, 0.031557035763398744, 0.04399902652949095, 0.0512911951955175, 0.06017785330186598, 0.04280589426343795, 0.07441314373863861, 0.03856803807138931, 0.009988203782995697, 0.048139991631614976, 0.08349418887519278, 0.17965771432500333, 0.09296889140387066, 0.1604973612120375, 0.05217386482399888, 0.0958316889591515, 0.061982192419236526, 0.043527254383661784, 0.08560792935895734, 0.06379211990861222, 0.13661224365932867, 0.18283516023075208, 0.706845314707607, 1.0495343198999763, 0.4192261310527101, 0.027141637438035104, 0.2688300231238827, 0.3019821457564831, 0.25128404900897294, 0.2000419728574343, 0.08072351411101408, 0.101685297122458, 0.09963216041796841, 0.07221711392048746, 0.7230193249415606, 1.0275951283983886, 0.18772441428154707, 0.02602242493594531, 0.012571230217872653, 0.019221383627154864, 0.08040635730139911, 0.044071812662878074, 0.12513295572716743, 0.11873864103108644, 0.04037532722577453, 0.4958779038861394, 0.18828276166459545, 4.47901108302176, 11.626271288841963, 24.735046327114105, 36.52021273970604, 47.802308946847916, 38.7192839384079, 32.039056196808815, 25.096927508711815, 24.180376790463924, 19.64506935328245, 20.284709930419922, 29.382850527763367, 31.657110191881657, 38.62653851509094, 41.79039694368839, 52.32528604567051, 66.4949195086956, 63.57874318957329, 65.62211394309998, 52.25560538470745, 29.110165759921074, 8.595155887305737, 0.4058072401676327, 0.04174419635091908, 0.06339179803035222, 0.07296487223356962, 0.041054091780097224, 0.06766935912310146, 0.038327018191921525, 0.03973497623519506, 0.04141721721680369, 0.055521756075904705, 0.062058240291662514, 0.05215016433794517, 0.019832091384159867, 0.061410341659211554, 0.06171634769998491, 0.044111176175647415, 0.011884660125360824, 0.04279187509382609, 0.05053704328020103, 0.03507432593323756, 0.019898708414984867, 0.01632821553357644, 0.027350234740879387, 0.0691802753135562, 0.038855464445077814, 0.03933583437174093, 0.019474225919111632, 0.04491740830417257, 0.012019204077660106, 0.03483970707748085, 0.048908396493061446, 0.0740691286046058, 0.0728044644347392, 0.023942500411067158, 0.06153071801236365, 0.027563702387851663, 0.013601559403468855, 0.0625906273489818, 0.0377372742514126, 0.06843965646112338, 0.0036294402798375813, 0.10492961795534939, 0.039272403009817936, 0.023507620426244102, 0.01238957658642903, 0.027755695991800167, 0.04001489949587267, 0.017608642920095008, 0.0037026086192781804, 0.05224748587352224, 0.05350141116650775, 0.06771658197976649, 0.043920885800616816, 0.025022304871527012, 0.056926389297586866, 0.07470297467079945, 0.03064849486690946, 0.0673197333526332, 0.030839206410746556, 0.02695847910217708, 0.026917518116533756, 0.050968190262210555, 0.041499283906887285, 0.013265984343888704, 0.049619663404882886, 0.03157152619678527, 0.030436930828727782, 0.026386559693492018, 0.05437002451799344, 0.034974811351276, 0.02975647232233314, 0.06197642593178898, 0.01773101008438971, 0.030607749104092363, 0.012220329808769748, 0.04160465774475597, 0.06136554562544916, 0.031034189014462754, 0.1198448269860819, 0.2539909881306812, 1.7381964228115976, 25.23404885083437, 55.902379900217056, 71.48219749331474, 73.87414634227753, 71.71788364648819, 58.042839244008064, 59.583800956606865, 50.46339735388756, 35.730751901865005, 28.324043042957783, 18.09741050004959, 27.169509194791317, 39.24470454454422, 33.657279163599014, 34.98756118118763, 39.92445006966591, 48.85011412203312, 26.70536410063505, 15.186941474676132, 9.33500848710537, 3.5895975586026907, 2.706238771788776, 0.3883137210505083, 0.10043689340818673, 0.044766039864043705, 0.0376541462901514, 0.08203669247450307, 0.09646180202253163, 0.18174493045080453, 0.17674016853561625, 0.3141965309623629, 0.4400025849463418, 0.3512905858224258, 0.5227233446203172, 0.1983397384174168, 0.564454011619091, 0.7187186682131141, 1.0419033793732524, 0.9307301917579025, 1.6427587252110243, 0.3189812757773325, 0.01517077129392419, 0.06633407218032517, 0.22284613747615367, 0.15241506131133065, 0.20121254754485562, 0.04212065818137489, 0.7004046603105962, 2.7355363871902227, 1.884490353986621, 2.112125214189291, 1.3557202275842428, 1.1787360557354987, 1.4641333976760507, 1.6090310225263238, 1.7418112163431942, 0.829434396000579, 0.4488700028741732, 0.6393001391552389, 0.6397375906817615, 1.8589275819249451, 3.4574691485613585, 2.2720500826835632, 0.35189047863241285, 0.22653191001154482, 0.08563768948079087, 0.1256355975056067, 0.03614869601733517, 0.002483462221789523, 0.11754104474675842, 0.018740369887382258, 0.3379635134479031, 0.4143490333808586, 3.482540203258395, 10.034446455538273, 20.720573142170906, 31.600314639508724, 45.5169253796339, 40.4155433177948, 35.76266638934612, 25.987366028130054, 23.890182562172413, 29.91377893835306, 31.735382191836834, 40.430195331573486, 40.8567338436842, 47.42316909134388, 52.25077584385872, 61.009176671504974, 73.95758226513863, 69.79500442743301, 75.93314185738564, 59.94803801178932, 34.590353295207024, 9.600968565791845, 0.6393490021582693, 0.07435746781993657, 0.03898111746821087, 0.06450418833992444, 0.040606287293485366, 0.0475534686120227, 0.02723159130255226, 0.08791023472440429, 0.07726109834038652, 0.017475726126576774, 0.045546159526566043, 0.017513633174530696, 0.06657149264356121, 0.03246878273785114, 0.055089592351578176, 0.02369366386119509, 0.05032579094404355, 0.02372674694925081, 0.039028462779242545, 0.06878769403556362, 0.019635706121334806, 0.0230015963097685, 0.04728426938527264, 0.01958131597348256, 0.06476095659309067, 0.01580384367116494, 0.03568746236851439, 0.07050622603856027, 0.08538179696188308, 0.03168975774315186, 0.011692585812852485, 0.02874473579140613, 0.03655156346212607, 0.037750213596154936, 0.03431585842918139, 0.042500782510614954, 0.03675227359053679, 0.03387819910130929, 0.04637649661162868, 0.01215136851897114, 0.012631130812224, 0.054686825096723624, 0.15309360693208873, 0.10644424488418736, 0.10867810939089395, 0.21194441855186597, 0.11696703804773279, 0.12221106837387197, 0.07465964808943681, 0.12617058207979426, 0.1713078108150512, 0.11967780665145256, 0.14965440554078668, 0.09922842466039583, 0.13623379287309945, 0.11072309731389396, 0.24800972314551473, 0.19602777028921992, 0.10602650479995646, 0.20273849222576246, 0.12702900945441797, 0.1677183690480888, 0.11378547322237864, 0.13010582013521343, 0.18152721400838345, 0.11469737975858152, 0.1536629826296121, 0.18695155653404072, 0.14056631742278114, 0.082067870098399, 0.20349580940091982, 0.1544950489187613, 0.10062716522952542, 0.17923268635058776, 0.09297696597059257, 0.13235816411906853, 0.14517535135382786, 0.15488568576984107, 0.3284160507610068, 0.7027240202296525, 3.601065343245864, 30.82208599895239, 68.63043531775475, 81.11429303884506, 83.35651472210884, 83.23630437254906, 66.98671191930771, 68.24714988470078, 57.61584475636482, 37.16895952820778, 29.35478713363409, 20.31074233353138, 24.025915078818798, 33.554867058992386, 30.642441138625145, 41.05755306780338, 52.66667112708092, 67.2090531885624, 40.22097855806351, 24.348451271653175, 13.872448559850454, 6.698060184717178, 5.7641624473035336, 0.6845248374156654, 0.5478114983998239, 0.148678585246671, 0.16108882322441787, 0.24370076920604333, 0.2732528076739982, 0.20584668091032654, 0.17216589680174366, 0.3445693402318284, 0.28722070972435176, 0.26897070463746786, 0.32024357991758734, 0.20010915206512436, 0.347266067401506, 0.5134371179156005, 0.5657724221237004, 1.111900967080146, 1.245723373722285, 0.3014057344989851, 0.16471891984110698, 0.19789853162365034, 0.40328910341486335, 0.3747360105626285, 0.5852995149325579, 0.4134734475519508, 0.9305464953649789, 3.1079667527228594, 2.3251883313059807, 1.936065936461091, 0.9366628609132022, 0.5992485664319247, 0.7439612480811775, 1.2675586645491421, 0.744973715627566, 0.7054654543753713, 0.21195464534685016, 0.299974309746176, 0.6213012174703181, 1.8927048007026315, 2.149843890219927, 1.4794732932932675, 0.2137992237112485, 0.26992961880750954, 0.1633053066325374, 0.18589675688417628, 0.14620460628066212, 0.34238579333759844, 0.25430755864363164, 0.23551060556201264, 0.8595658885315061, 0.8945683040656149, 6.122689358890057, 16.145554035902023, 32.71149091422558, 48.01840715110302, 63.368758857250214, 54.9984198063612, 48.745665326714516, 36.237595304846764, 35.72766646742821, 27.736334279179573, 30.765822418034077, 42.41264395415783, 47.15224742889404, 56.930475533008575, 60.509055107831955, 71.63654521107674, 83.68466511368752, 79.0233564376831, 85.26015177369118, 69.25265952944756, 43.15131291747093, 13.689392432570457, 1.9067486096173525, 0.2348598459502682, 0.14300692942924798, 0.18501881102565676, 0.21420724166091532, 0.1286960660945624, 0.15237192768836394, 0.2823697356507182, 0.14609871665015817, 0.08328358962899074, 0.08542465599020943, 0.17056236800272018, 0.19146780716255307, 0.12322317968937568, 0.2979521354427561, 0.16773039184045047, 0.18791406269883737, 0.22230886708712205, 0.07879427896114066, 0.15016898105386645, 0.16803666134364903, 0.10061503853648901, 0.13776343344943598, 0.1993876212509349, 0.1525931470678188, 0.12013573403237388, 0.14802824123762548, 0.13270946714328602, 0.2351594064384699, 0.09101434901822358, 0.09193222984322347, 0.19688207132276148, 0.14328124205349013, 0.09283163119107485, 0.10744851169874892, 0.1116845199430827, 0.22429259814089164, 0.146439362433739, 0.20610993553418666, 0.19279059633845463, 0.053447275204234757, 0.16256572678685188], [0.04237952671246603, 0.010739056851889472, 0.11727950448403135, 0.04008443502243608, 0.034748441466945224, 0.08402924024267122, 0.011151630660606315, 0.039824868872528896, 0.029535241810663138, 0.032468830977450125, 0.05808467401948292, 0.026744321257865522, 0.07751361408736557, 0.03650335725978948, 0.027873172402905766, 0.03300172640592791, 0.06127588676463347, 0.01881069765659049, 0.022194694392965175, 0.033582416144781746, 0.06402441213140264, 0.01766607030731393, 0.006799921593483305, 0.05057785027020145, 0.025026579642144497, 0.03438261090195738, 0.037123132206033915, 0.07031870016362518, 0.056344475015066564, 0.10992501396685839, 0.053998464572941884, 0.05703891001758166, 0.11566693632630631, 0.012559256592794554, 0.031097961764317006, 0.054406348936026916, 0.342313923756592, 2.983648111112416, 22.8556614741683, 52.48610861599445, 65.25286495685577, 64.85539108514786, 66.46427035331726, 55.07751636207104, 47.21921503543854, 31.10622525215149, 24.57834653556347, 15.899162907153368, 15.659794751554728, 27.987449504435062, 17.785105258226395, 21.492433324456215, 28.897451274096966, 36.758710741996765, 44.31158825755119, 14.349207077175379, 7.613408267498016, 2.4267457192763686, 0.18798302306095138, 0.039088424600777216, 0.11029852204956114, 0.004897004855592968, 0.029892478305555414, 0.036746336409123614, 0.11318716118694283, 0.08500107520376332, 0.07434104409185238, 0.1034789567347616, 0.05642933589115273, 0.14157350087771192, 0.5751723458524793, 0.24981216236483306, 0.320261005545035, 0.29137985373381525, 0.5143067368771881, 0.724160629324615, 0.3523593081627041, 0.5715082737151533, 0.6237376586068422, 0.24718507833313197, 0.022562523190572392, 0.0983741607342381, 0.1546468774904497, 0.18773657066049054, 0.1777358041726984, 0.17636824864894152, 0.4254000575747341, 1.794271795079112, 3.57021052390337, 2.4890830367803574, 1.7647510604001582, 2.227700287476182, 1.9625083613209426, 1.2079767929390073, 1.114773612935096, 1.1667322623543441, 1.8752036523073912, 0.5082544928882271, 0.5353880650363863, 0.6814389873761684, 1.4844913990236819, 2.4465158209204674, 0.44057938212063164, 0.10646446840837598, 0.1718987978529185, 0.10232069427729584, 0.00798482808022527, 0.0565805039514089, 0.044922280503669754, 0.17769666330423206, 0.051446638026391156, 0.1847350731259212, 0.056279559357790276, 0.3023522696457803, 2.8867658972740173, 6.808564905077219, 16.566115468740463, 36.10199198126793, 38.82032431662083, 57.10588552057743, 46.14689737558365, 25.65594781190157, 14.475293811410666, 18.462175726890564, 19.4398195669055, 27.338687516748905, 31.564134880900383, 40.72894670069218, 48.051830157637596, 55.411225855350494, 65.65161556005478, 58.37110362946987, 58.97618316113949, 35.222612768411636, 17.199815064668655, 5.730597423389554, 0.6889149674680084, 0.08501684584189206, 0.029516686263377778, 0.03658944267954212, 0.02840917371941032, 0.006156725394248497, 0.03901974625478033, 0.024053379129327368, 0.041500167062622495, 0.02410622561001219, 0.09802559623494744, 0.016511210596945602, 0.0642599920684006, 0.1413064613007009, 0.014801197521592258, 0.024311522211064585, 0.03325064273667522, 0.07834392148652114, 0.04704819220933132, 0.044936088161193766, 0.03846928048005793, 0.04091706905455794, 0.025938677281374112, 0.02580991837021429, 0.016246705454250332, 0.04695186886237934, 0.026751486693683546, 0.017421263619326055, 0.07186176619143225, 0.026574124531180132, 0.045100143615854904, 0.02247207023174269, 0.022227126246434636, 0.05799510792712681, 0.020135885824856814, 0.045824171756976284, 0.02589031522802543, 0.036198828092892654, 0.06838537578005344, 0.02948619883682113, 0.03848336644296069, 0.017031688039423898, 0.05195596284465864, 0.021776056310045533, 0.019655950054584537, 0.014950399818189908, 0.016409079944423866, 0.04099866819160525, 0.017421276606910396, 0.011320577796141151, 0.09554962831316516, 0.03908065802534111, 0.040123019280144945, 0.045582402308355086, 0.09380925490404479, 0.03163778885209467, 0.01510275531472871, 0.04899076375295408, 0.011557023262867006, 0.04030488998978399, 0.07277349461219274, 0.023634199278603774, 0.0474468368338421, 0.05403403200034518, 0.0197970712906681, 0.024590972352598328, 0.036287856128183194, 0.04356466233730316, 0.034845941117964685, 0.036970572618884034, 0.04261614194547292, 0.032142564305104315, 0.041431381105212495, 0.013680658430530457, 0.07900387630797923, 0.04874579935858492, 0.2760404034052044, 4.179230444133282, 32.46267646551132, 64.30372908711433, 74.44872871041298, 73.65296021103859, 73.70924279093742, 64.00146290659904, 55.68904034793377, 42.57606938481331, 36.9727798551321, 23.708525709807873, 21.932024136185646, 27.083231024444103, 18.086480386555195, 21.243339590728283, 26.326547227799892, 33.19908834993839, 28.057933822274208, 14.06337596476078, 6.469768434762955, 2.1030838368460536, 0.3755196591373533, 0.006775074953111471, 0.02377398093813099, 0.07836744014639407, 0.09172351565212011, 0.07570163084892556, 0.3626697580330074, 0.3122540336335078, 0.407691701548174, 0.800777580589056, 1.0745488526299596, 1.2807567813433707, 2.4968253588303924, 1.3923456310294569, 1.8698351341299713, 2.061185147613287, 1.9740220997482538, 2.504791156388819, 2.9998095938935876, 4.197062412276864, 3.6711195716634393, 1.1805125791579485, 0.09185872011585161, 0.03692177640914451, 0.13234330632258207, 0.3019084653351456, 0.1393804544932209, 0.5311245750635862, 1.6568429069593549, 3.5104033956304193, 7.289508422836661, 5.470065353438258, 4.143574107438326, 4.62051454000175, 4.6785360015928745, 3.644890529103577, 5.609298432245851, 2.829424599185586, 3.7877388764172792, 3.046570122241974, 3.5350001882761717, 2.5780775863677263, 5.859549203887582, 4.107743455097079, 1.0203977208584547, 1.04539776686579, 0.5465664120856673, 0.3804894658969715, 0.3169248142512515, 0.3403873083880171, 0.2893789345398545, 0.21242668095510453, 0.10242452073725872, 0.17417869035853073, 0.008953388314694166, 0.06329350057058036, 1.582118016667664, 5.49855574965477, 13.609466571360826, 30.259543284773827, 33.760645017027855, 45.92167966067791, 42.742895632982254, 26.18092004209757, 18.07176947593689, 26.978197060525417, 28.48592195659876, 37.59382613003254, 44.438896626234055, 53.181171119213104, 56.59926250576973, 62.334644347429276, 74.23258870840073, 67.42821022868156, 67.91201546788216, 40.65061390399933, 19.935151487588882, 6.440935581922531, 0.4480549762956798, 0.12444299587514251, 0.033141242747660726, 0.027705725333362352, 0.029197069234214723, 0.01445077765310998, 0.036491289938567206, 0.027843347343150526, 0.04356190525868442, 0.034054848802043125, 0.04318051927839406, 0.014490641187876463, 0.012430198039510287, 0.05711079444154166, 0.030909749402781017, 0.033474819574621506, 0.03603616416512523, 0.024764471636444796, 0.011754191491490928, 0.030556251476809848, 0.024882866455300245, 0.02518119683372788, 0.033919562702067196, 0.07855282121454366, 0.029029707511654124, 0.0832861648814287, 0.020665573320002295, 0.024343004115507938, 0.017964686412597075, 0.014756505388504593, 0.015307446137740044, 0.03274718088505324, 0.04982165002729744, 0.002253793722957198, 0.031627198404748924, 0.042062236316269264, 0.02624074993946124, 0.03777633348363452, 0.014064578845136566, 0.014127661397651536, 0.16916312277317047, 0.0964146459591575, 0.16669944481691346, 0.1036389044020325, 0.12417472433298826, 0.20406269148224965, 0.10175076939049177, 0.08437894764938392, 0.10212495282758027, 0.11305761188850738, 0.20250437431968749, 0.11692501764628105, 0.27117431920487434, 0.2002673631068319, 0.2105136023601517, 0.11983670789049938, 0.16604228789219633, 0.1721515881945379, 0.14916133746737614, 0.0860084590385668, 0.19455423607723787, 0.0845468882471323, 0.21515503845876083, 0.20999506377847865, 0.11211161850951612, 0.08298478613141924, 0.098170968121849, 0.18561343458713964, 0.08126551198074594, 0.12610171077540144, 0.1297659907140769, 0.16003019409254193, 0.21010273456340656, 0.08991497597889975, 0.2164065814577043, 0.10953585398965515, 0.5795178876724094, 5.9180304408073425, 40.0649057328701, 75.91880902647972, 83.34385380148888, 83.85343685746193, 85.72951018810272, 71.61493197083473, 63.224799782037735, 47.70265929400921, 38.19543644785881, 26.254575289785862, 25.59241522103548, 39.73360151052475, 25.529826879501343, 29.6158255264163, 42.208062931895256, 50.03034219145775, 54.98263545334339, 19.790569245815277, 10.937477499246597, 3.3469492290169, 0.5956978944595903, 0.18523528065998107, 0.17112901259679347, 0.24192001554183662, 0.18319817434530705, 0.3224399214377627, 0.34397906565573066, 0.22325688652927056, 0.29140045575331897, 0.4512081836583093, 0.5993145878892392, 0.7594447047449648, 2.3751245392486453, 0.8164978120476007, 1.164673485327512, 1.4562473958358169, 1.540394474286586, 2.16932853218168, 2.5869047502055764, 3.5537813929840922, 3.643187745474279, 0.630184190813452, 0.11344844169798307, 0.234800711623393, 0.8737216726876795, 0.39325036865193397, 0.37180369603447616, 1.2034302181564271, 2.4129966320469975, 9.40580913797021, 11.566244959831238, 8.958996813744307, 4.690058408305049, 4.55810003913939, 5.524895461276174, 4.119712812826037, 2.355346600525081, 2.3322716262191534, 4.56670087762177, 2.2949398169294, 4.2661963775753975, 3.434003032743931, 5.835394850000739, 8.482137601822615, 0.5761295382399112, 0.7146101980470121, 0.5028165690600872, 0.33145689696539193, 0.23576424195198342, 0.26880737277679145, 0.3557067207293585, 0.42614713311195374, 0.24017656221985817, 0.41938109148759395, 0.2981291228206828, 0.6246342323720455, 4.0913972072303295, 9.41147368401289, 21.68169926851988, 46.76244534552097, 51.039423644542694, 73.5717585682869, 61.841183826327324, 36.00200034677982, 24.82580255717039, 28.42920619994402, 29.613625444471836, 40.04819802939892, 47.849137634038925, 56.94818638265133, 67.69461393356323, 74.99402225017548, 85.43623432517052, 77.81531006097794, 78.56007769703865, 48.86469013988972, 29.733940288424492, 9.356209449470043, 1.0427314974367619, 0.17238604748854414, 0.3140003961743787, 0.2582056447863579, 0.1566917763557285, 0.086717254598625, 0.1241746946470812, 0.11286311724688858, 0.21701632998883724, 0.27496746566612273, 0.24754145764745772, 0.11999632901279256, 0.12310140809859149, 0.296035761712119, 0.13281871128128842, 0.15480410889722407, 0.12705936329439282, 0.13022794795688242, 0.16442915570223704, 0.15094798378413543, 0.12915113620692864, 0.10928455536486581, 0.1062184241891373, 0.21676110540283844, 0.12650426651816815, 0.18464871682226658, 0.1827522920211777, 0.0869923538994044, 0.17658062162809074, 0.09351705652079545, 0.12396537931635976, 0.10166933352593333, 0.06656732177361846, 0.22004981408827007, 0.07866793574066833, 0.12935720093082637, 0.08995056938147172, 0.1541941228788346, 0.14672632125439122, 0.1443188387202099], [0.020457688478927594, 0.06083309548557736, 0.04042503256641794, 0.06283149879891425, 0.07022508565569296, 0.035884291064576246, 0.022888198000146076, 0.03104316900135018, 0.046019512446946464, 0.02173556473280769, 0.04300124979636166, 0.04958700890711043, 0.015885440952843055, 0.10116512581589632, 0.03538756791385822, 0.03481703075522091, 0.023131479574658442, 0.026779233739944175, 0.0041688007422635565, 0.03935823609936051, 0.02262037174659781, 0.03357127650815528, 0.0529065612499835, 0.07680097420234233, 0.021664435444108676, 0.026207774462818634, 0.02984846338222269, 0.05125006166053936, 0.06290349454502575, 0.02895249632274499, 0.03856159622955602, 0.06561680871527642, 0.01580270818521967, 0.06128972781880293, 0.10699699647375382, 0.4803679377073422, 5.362322134897113, 23.690759763121605, 59.55923527479172, 71.09493747353554, 63.632962480187416, 52.18612231314182, 43.56995925307274, 41.863554418087006, 35.425730869174004, 20.93208499252796, 14.31960666552186, 17.304054871201515, 24.100575372576714, 29.571014530956745, 53.372939229011536, 66.93296000361443, 40.68210281431675, 18.937663212418556, 7.748330952599645, 0.6477514200378209, 0.19103278988040984, 0.03448328694503289, 0.15991817432222888, 0.054205234337132424, 0.10902620633714832, 0.08033899255678989, 0.08315460436278954, 0.2289363942691125, 0.10822575553902425, 0.42928576469421387, 0.3826349851442501, 0.8587443607393652, 1.3182040094397962, 0.518037008587271, 2.795072067528963, 2.061908058822155, 2.8298822371289134, 1.5782518428750336, 1.5430653747171164, 2.9658491536974907, 4.051853204146028, 1.8276127497665584, 3.738381424918771, 2.6526010874658823, 0.3366139327408746, 0.042062477514264174, 0.12935678532812744, 0.20130852208239958, 0.12648443633224815, 0.15796570252859965, 1.0342441778630018, 3.7058549327775836, 2.7002191822975874, 2.8747390676289797, 5.056362077593803, 3.383611086755991, 5.057592261582613, 4.890378434211016, 13.471908252686262, 3.5889831790700555, 2.491018082946539, 2.6948970928788185, 1.4663429791107774, 4.820115929469466, 10.788803827017546, 5.874280063435435, 1.1490920651704073, 1.5332424268126488, 0.6334249419160187, 0.43323737452737987, 0.3469760360894725, 0.10430342343170196, 0.07547340559540316, 0.09260355436708778, 0.061615838640136644, 0.08881282730726525, 0.04112354938115459, 0.034100053017027676, 0.02687620832148241, 0.31523583456873894, 2.2254047356545925, 6.7747177463024855, 21.155986078083515, 32.050546780228615, 37.820894345641136, 58.59162479639053, 56.778814271092415, 23.155651576817036, 21.87099941074848, 26.39981869608164, 17.482438199222088, 16.47842187434435, 20.716642253100872, 34.004523530602455, 46.14392213523388, 58.47802609205246, 63.63566033542156, 57.36752808094025, 39.22090262174606, 25.08855275809765, 9.88419871777296, 1.5871867071837187, 0.08165642342646606, 0.06174292400828563, 0.11331431334838271, 0.0772743827837985, 0.0075323550208850065, 0.05085068602056708, 0.03522259219607804, 0.04545125368167646, 0.0037943770348647377, 0.02127563169779023, 0.07562437327578664, 0.052337808956508525, 0.08277032771729864, 0.031167608613031916, 0.023719221571809612, 0.04266608848411124, 0.04017270235635806, 0.05945403296209406, 0.05518765974557027, 0.034883304542745464, 0.0018920857883131248, 0.05642174000968225, 0.07067928745527752, 0.02234449319075793, 0.009322201385657536, 0.09472260120674036, 0.051441402174532413, 0.054194517724681646, 0.035867800543201156, 0.025084315020649228, 0.06922047745320015, 0.05629162296827417, 0.06449166088714264, 0.07754658028716221, 0.029772510133625474, 0.040726574588916264, 0.02006255050218897, 0.06699440549709834, 0.06947846282855608, 0.031926866504363716, 0.01693219757726183, 0.03872127301292494, 0.049212343074032106, 0.03192285890690982, 0.04064667497004848, 0.05804986729344819, 0.04889986179478001, 0.0578536657121731, 0.055830808632890694, 0.04361592247732915, 0.019857704755850136, 0.00991834820524673, 0.04199533912469633, 0.025379274193255696, 0.0883239894756116, 0.037611172228935175, 0.03392049780813977, 0.03181210449838545, 0.008541124352632323, 0.00195538194020628, 0.027186529950995464, 0.10187143518123776, 0.07742254514596425, 0.008165788731275825, 0.08706279855687171, 0.018986649738508277, 0.054852535540703684, 0.020448315153771546, 0.053853734643780626, 0.019726951322809327, 0.0195416908536572, 0.020784322514373343, 0.0680076597200241, 0.4543797665974125, 7.320563681423664, 32.23948784172535, 69.07436549663544, 79.4271531701088, 72.288658618927, 60.88149592280388, 54.394518211483955, 51.869314312934875, 48.51226285099983, 32.59243570268154, 25.32913114875555, 23.81944365799427, 22.850056774914265, 32.67653279006481, 39.14187066257, 50.04632033407688, 34.752862975001335, 15.303915347903967, 5.506250811740756, 0.8866871113423258, 0.027470648201415315, 0.0643829362525139, 0.13381747878156602, 0.18549049040302634, 0.43402155744843185, 0.2707125252345577, 0.39655081811361015, 0.40129634784534574, 0.4104610701324418, 1.682294060010463, 1.7707827617414296, 2.424366334453225, 3.3122402289882302, 4.103390788659453, 6.956473393365741, 7.927390644326806, 6.0792500898242, 5.358154708519578, 5.563808223232627, 6.333951372653246, 8.402854856103659, 6.322915339842439, 8.039925880730152, 6.141571495682001, 2.5442176032811403, 0.13328454253496602, 0.1357767783338204, 0.19547812087694183, 0.48404050001408905, 0.15969046857208014, 1.6767363832332194, 2.7312331181019545, 3.8218783820047975, 5.613222671672702, 6.24260094948113, 7.77160232886672, 7.3638310097157955, 7.400003643706441, 9.548822063952684, 6.981804734095931, 7.867596102878451, 6.335919667035341, 6.058582998812199, 5.798396235331893, 5.942750014364719, 7.694222806021571, 3.296606680378318, 3.880009325221181, 1.8795278202742338, 1.3275352399796247, 1.0425841365940869, 0.8665356645360589, 0.5851951986551285, 0.42248294223099947, 0.35682196088600904, 0.34813411301001906, 0.16414712474215776, 0.09656214038841426, 0.03194576158421114, 0.17725867743138224, 1.5237309434451163, 5.711733810603619, 17.691204696893692, 28.85956920683384, 36.307655945420265, 42.44119942188263, 43.378780111670494, 21.48730169981718, 20.18761944025755, 30.566027238965034, 25.98022811114788, 31.728591956198215, 31.219466775655746, 44.17159616947174, 54.97602000832558, 66.89838945865631, 75.97945377230644, 65.55076897144318, 47.52134062349796, 28.196411691606045, 11.13843446597457, 1.9284449703991413, 0.10460429009981453, 0.06415891897631809, 0.05667543948220555, 0.01769648166373372, 0.01650504706049105, 0.030740860711375717, 0.04948348672769498, 0.028655281021201517, 0.004693881819548551, 0.048265718869515695, 0.013729674501519185, 0.02688051277800696, 0.01077733219062793, 0.06384854539646767, 0.06776496258680709, 0.028557996593008284, 0.06422828751965426, 0.01795820746337995, 0.03522101884300355, 0.05131288075062912, 0.0401805505680386, 0.05322498342138715, 0.05446305643999949, 0.03332583342853468, 0.04130342371354345, 0.03617194750404451, 0.040257218133774586, 0.06100292484916281, 0.10326092859031633, 0.01416134748069453, 0.04002911162388045, 0.06339652551105246, 0.11252903947024606, 0.026310816101613455, 0.0736026739468798, 0.03745756250282284, 0.023387262626783922, 0.017959053511731327, 0.11387574806576595, 0.17103303805924952, 0.10160643651033752, 0.15153524524066597, 0.110630046838196, 0.15767703676829115, 0.19991153298178688, 0.11746424730517901, 0.16377486346755177, 0.20481361134443432, 0.23379343911074102, 0.16179157770238817, 0.14986510126618668, 0.15660675591789186, 0.11278249032329768, 0.13288262503920123, 0.2659091673558578, 0.1288216671673581, 0.08012025195057504, 0.09055350499693304, 0.1093060479615815, 0.08608234726125374, 0.17132073902757838, 0.1804249465931207, 0.17805403709644452, 0.07596053648740053, 0.14273117703851312, 0.2466774344793521, 0.1052999719104264, 0.20345782628282905, 0.15180912741925567, 0.08658781662234105, 0.12858039495768026, 0.11352281231665984, 0.2266430392046459, 0.7803409709595144, 9.392374008893967, 38.705585673451424, 81.16555988788605, 88.98484110832214, 83.20688635110855, 72.29504227638245, 61.435612589120865, 58.2316093146801, 50.062898844480515, 31.693725027143955, 25.106345303356647, 25.357433930039406, 36.06754682958126, 42.852496951818466, 69.53956693410873, 87.32383623719215, 53.372133672237396, 25.17282083630562, 10.145277008414268, 1.1266461946070194, 0.4825614590663463, 0.25566191878169775, 0.31475397292524576, 0.2170224007568322, 0.3509088547434658, 0.2345809171674773, 0.3063906216993928, 0.27559906302485615, 0.21184572775382549, 1.8283009878359735, 1.263259551487863, 2.3497984232380986, 3.718324676156044, 4.922422589734197, 8.857904188334942, 9.54565018415451, 9.81515072286129, 5.335020124912262, 5.276931216940284, 8.661108948290348, 12.923888359218836, 9.158912636339664, 11.531633567065, 12.0030970685184, 3.3951539173722267, 0.7564773608464748, 0.3333738644141704, 0.4372127924580127, 0.7860071794129908, 0.9757387766148895, 4.822042426094413, 12.076922357082367, 11.382902897894382, 11.785545442253351, 17.08448175340891, 13.155636973679066, 14.73212393000722, 16.462717317044735, 25.90996228158474, 13.78914088010788, 12.314447611570358, 11.376398596912622, 6.42202447168529, 13.16621370613575, 23.82201611995697, 20.551514513790607, 4.376981807872653, 4.70045275054872, 1.8984956899657845, 2.0591296954080462, 0.7629827305208892, 0.5646073096431792, 0.3125566814560443, 0.30122782685793936, 0.27111708477605134, 0.2976885245880112, 0.17578477214556187, 0.37404818809591234, 0.1372754416661337, 0.8751977153588086, 3.663725880905986, 9.498680904507637, 27.664425037801266, 42.252053171396255, 50.4684928804636, 76.53629869222641, 74.45262730121613, 33.20193439722061, 32.36915208399296, 38.084717988967896, 28.376567624509335, 28.288706839084625, 33.47610488533974, 50.961622819304466, 64.76408198475838, 78.08335527777672, 84.69207465648651, 76.66693568229675, 58.59009347856045, 36.91272407770157, 17.07985170185566, 3.5567217227071524, 0.21541789232287556, 0.13711847743252292, 0.22556101757800207, 0.1607459064689465, 0.191909444401972, 0.14781923760892823, 0.20525956788333133, 0.07827752895536833, 0.1465540094068274, 0.14045091345906258, 0.24815044918796048, 0.15165002580033615, 0.15724360768217593, 0.15353462076745927, 0.0904573523439467, 0.11851267190650105, 0.17944738967344165, 0.21030793839599937, 0.14720586739713326, 0.16086830146377906, 0.09167494950816035, 0.15820281871128827, 0.24721489782677963, 0.225553328928072, 0.08070104930084199, 0.15820347180124372, 0.15638871293049306, 0.1261680290917866, 0.2490633650450036, 0.08540749753592536, 0.09438171051442623, 0.18930621299659833, 0.19676322379382327, 0.1493526779813692, 0.20456739643123, 0.19587775255786255, 0.06473284403909929, 0.14433206379180774], [0.04132729118282441, 0.007244984772114549, 0.02496110366337234, 0.022618724178755656, 0.054512075294042006, 0.06405157473636791, 0.05206999754591379, 0.05032678171119187, 0.040764309087535366, 0.04359932063380256, 0.026705963355198037, 0.07399144800729118, 0.05266391235636547, 0.05282436097331811, 0.028504474757937714, 0.013478682940331055, 0.0409836063045077, 0.04957714947522618, 0.03830550333077554, 0.011623526188486721, 0.0514643345377408, 0.04130855937546585, 0.02409811579127563, 0.04497389316384215, 0.02230580874311272, 0.08906837843824178, 0.06241812254302204, 0.014293779095169157, 0.04571831552311778, 0.04592525969201233, 0.06255132320802659, 0.0157381431927206, 0.11192435980774462, 0.07508499518735334, 0.17306941706920043, 4.694554517045617, 33.50901111960411, 60.57035341858864, 59.725404158234596, 58.86384978890419, 53.901855647563934, 45.59251852333546, 32.5105918943882, 32.83914506435394, 20.864900797605515, 18.285304717719555, 28.639749102294445, 31.56691823154688, 41.06583662331104, 39.79483902454376, 38.68099719285965, 23.071573488414288, 6.231279456987977, 1.932566799223423, 0.02136477476597065, 0.15117563016247004, 0.07491260912502185, 0.06080414430471137, 0.07791352036292665, 0.04181840369710699, 0.05641046678647399, 0.18424576031975448, 0.2544508525170386, 0.35968534473795444, 0.8869517908897251, 2.4153862288221717, 3.4205626789480448, 3.8876533275470138, 2.5823924923315644, 4.249175665900111, 5.8562676049768925, 5.9393667709082365, 4.572905469685793, 5.202174503356218, 5.672687105834484, 3.3281608996912837, 4.492863714694977, 4.84409786760807, 6.1540718749165535, 2.821414154022932, 1.8945336900651455, 0.1578593676094897, 0.12476845731725916, 0.23978697921847925, 0.14645696617662907, 0.18762412044452503, 2.6668175496160984, 5.881968000903726, 4.128868896514177, 0.3849407489178702, 4.118535351008177, 8.73013699427247, 5.48974022269249, 3.2470055669546127, 12.70451283082366, 4.665231015533209, 5.940377041697502, 5.307093998417258, 6.241146102547646, 1.0523072211071849, 5.504535203799605, 0.5927461653482169, 3.5435929521918297, 2.2820824943482876, 0.9175096917897463, 0.9711410827003419, 1.5268520009703934, 1.52748680440709, 0.46357853861991316, 0.07696848435443826, 0.5174732732120901, 0.155424440454226, 0.06285772629780695, 0.04337209356890526, 0.06871811769087799, 0.07507906542741694, 0.10617537962389179, 0.10534105720580555, 1.3126804120838642, 7.238516584038734, 18.295305781066418, 40.870162323117256, 42.73150384426117, 50.53948067128658, 39.92217019200325, 48.55872295796871, 41.94205820560455, 17.464102283120155, 16.611747220158577, 20.151306688785553, 42.3970115929842, 48.95837791264057, 59.64235581457615, 60.20521581172943, 64.11880820989609, 55.74226029217243, 31.576923094689846, 16.200434491038322, 2.086835908703506, 0.09121464725467376, 0.01163370938229491, 0.01594528032001108, 0.0457938476029085, 0.05342189746443182, 0.007320833192352438, 0.07879937751567923, 0.10004185562138446, 0.029116256773704663, 0.023902387329144403, 0.022355100336426403, 0.06767910352209583, 0.08042305562412366, 0.094687846431043, 0.07734792219707742, 0.031043669951031916, 0.03827108994300943, 0.0946469912014436, 0.022233712807064876, 0.035878780618077144, 0.030085314247116912, 0.04012699719169177, 0.044381073021213524, 0.039873067653388716, 0.0446136843675049, 0.024091850209515542, 0.028441436734283343, 0.0643707427661866, 0.020059617163497023, 0.006403785891961888, 0.03835238851024769, 0.11527223250595853, 0.05416422325652093, 0.025910395888786297, 0.017760501177690458, 0.0034265526437593508, 0.04633275813830551, 0.005237952600509743, 0.03874224239552859, 0.06808359627029859, 0.09461214736802503, 0.04571751029288862, 0.02961142141430173, 0.03641786926891655, 0.01741243206197396, 0.0023840561789256753, 0.03988677512097638, 0.04494729459111113, 0.050020386042888276, 0.009267374298360664, 0.0542501454037847, 0.048064455841085874, 0.03407889809750486, 0.08313490776345134, 0.022523877705680206, 0.017064611565729138, 0.019804262701654807, 0.0806050599203445, 0.05265919600788038, 0.025406340319023002, 0.05920112016610801, 0.06251327329664491, 0.05799647347885184, 0.029899378423579037, 0.030960881522332784, 0.05769879433501046, 0.04647236353775952, 0.03576121700461954, 0.04391009126265999, 0.051988465202157386, 0.03303375749965198, 0.15214220329653472, 7.931343857198954, 46.3983640819788, 74.6759869158268, 72.38601699471474, 67.39484041929245, 64.20805782079697, 55.22597819566727, 42.01148048043251, 42.53146357834339, 30.873955115675926, 28.479435704648495, 29.859808534383774, 22.829459980130196, 31.59808985888958, 31.001709960401058, 36.41219213604927, 22.445351891219616, 6.008025761693716, 1.601088736206293, 0.2004298340762034, 0.09911948480294086, 0.05966997938230634, 0.1042373500240501, 0.08662667547469027, 0.053499292334890924, 0.15436771122040227, 1.1867772554978728, 1.9375421572476625, 2.739935126155615, 3.419639803469181, 5.617389148101211, 7.141388570889831, 6.561912540346384, 7.829924924299121, 8.527939394116402, 9.589268993586302, 9.193333089351654, 6.892976425588131, 8.141593225300312, 5.163485454395413, 11.262528207153082, 8.818181119859219, 10.064963568001986, 10.09491166099906, 6.182554196566343, 4.81097124516964, 1.9436613726429641, 0.4585065826540813, 0.5094056529924273, 0.5078593734651804, 0.26113211119081825, 2.5330663891509175, 4.42012564279139, 4.7740790247917175, 2.657603994011879, 2.8823322476819158, 3.951132958754897, 4.488104470074177, 5.401769718155265, 8.763842135667801, 7.5875340308994055, 8.322254531085491, 7.609676392748952, 8.10420323163271, 7.6493144407868385, 6.347367027774453, 4.534077728167176, 5.930587342008948, 3.544210894033313, 4.0285690035671, 3.7319685565307736, 5.249291500076652, 2.770878290757537, 3.081471724435687, 1.6930705192498863, 1.7785728187300265, 1.0516743175685406, 0.3468003252055496, 0.271468922146596, 0.20524511084659025, 0.08987931578303687, 0.08655909550725482, 0.043061556716565974, 1.106406224425882, 4.885161314159632, 16.58083587884903, 36.83572120964527, 47.26267330348492, 38.15072804689407, 32.76719592511654, 46.102397963404655, 30.416845344007015, 18.552998453378677, 20.60520563274622, 26.944428272545338, 51.30167797207832, 57.075103372335434, 68.03987100720406, 67.29912355542183, 73.4613136947155, 64.63465332984924, 37.977939918637276, 19.232905469834805, 2.3191207693889737, 0.13867563684470952, 0.06233941778191365, 0.012519713109213626, 0.0381265752366744, 0.023386876709992066, 0.049850590075948276, 0.05643585565849207, 0.04169974541582633, 0.01689299362624297, 0.019247948803240433, 0.015379350970761152, 0.01988622549106367, 0.05576301344262902, 0.06397842123988084, 0.05862587408046238, 0.03364739859534893, 0.027233934633841272, 0.055272858298849314, 0.031631343299522996, 0.014501124951493694, 0.05955674991128035, 0.020160894346190616, 0.07375463610514998, 0.08506639904226176, 0.057899545281543396, 0.037041035830043256, 0.020214909709466156, 0.08400356935453601, 0.016014507855288684, 0.018897874033427797, 0.014000911851326237, 0.050825512371375225, 0.05310367196216248, 0.04592947880155407, 0.016931876598391682, 0.046729736641282216, 0.020543506725516636, 0.12704726628726348, 0.16885283082956448, 0.2100081107346341, 0.18047873745672405, 0.20951612619683146, 0.10471605753991753, 0.16736933699576184, 0.11880576828843914, 0.09567157801939175, 0.12144600317697041, 0.11223678171518259, 0.15350831905379891, 0.1266859145835042, 0.21070529910502955, 0.10077084501972422, 0.2526401309296489, 0.13428204838419333, 0.11031976973754354, 0.20377010718220845, 0.22431811317801476, 0.20688632590463385, 0.11276240038569085, 0.2102718106471002, 0.15299206628696993, 0.1282321644248441, 0.2123772242339328, 0.12390515403239988, 0.1164544366474729, 0.2079785891692154, 0.11485729773994535, 0.18542374164098874, 0.15936580864945427, 0.15450138685991988, 0.1328118093078956, 0.33947832591366023, 10.450432933866978, 55.710516795516014, 88.61265107989311, 83.89999195933342, 77.9622633755207, 73.0706262588501, 62.11022838950157, 47.23627232015133, 46.33037053048611, 30.574003010988235, 28.436575904488564, 39.40193250775337, 43.09175491333008, 57.73085318505764, 53.63006383180618, 53.30380193889141, 30.03964528441429, 8.8421331346035, 2.8467450197786093, 0.6235162017401308, 0.37280755466781557, 0.150790722691454, 0.3060843818821013, 0.1140497594315093, 0.2163303628913127, 0.1658168827998452, 0.9333676064852625, 1.4872960047796369, 2.5597810931503773, 3.72293240390718, 7.664848482236266, 10.85582273080945, 13.028719034045935, 13.752808179706335, 13.678114637732506, 15.239312164485455, 18.806821033358574, 13.368994574993849, 14.588036611676216, 16.796814389526844, 14.625040926039219, 13.46950488165021, 18.225281238555908, 16.93744484335184, 12.534388359636068, 9.127193838357925, 2.267688154242933, 0.8597921545151621, 0.7868206326384097, 1.0269019030965865, 1.0321572585962713, 6.401366405189037, 5.817245598882437, 6.854119235649705, 12.24793503060937, 15.758192371577024, 17.618702687323093, 13.806528747081757, 12.909277193248272, 26.637229956686497, 12.724737245589495, 14.507204499095678, 15.844125710427761, 15.03450220450759, 8.25374610722065, 17.453497052192688, 8.037652652710676, 9.516244512051344, 6.0833818931132555, 7.657640744000673, 6.523677567020059, 7.173859253525734, 3.909203396178782, 2.416725419461727, 1.0359279625117779, 1.1589445802383125, 0.6819279736373574, 0.27253405249211937, 0.1823916082503274, 0.3036321181571111, 0.2867724228417501, 0.2806583431083709, 0.5667120404541492, 2.2335040010511875, 9.751892667263746, 25.201663188636303, 51.25850088894367, 56.23843006789684, 64.98264625668526, 56.79276332259178, 63.748392686247826, 53.54461781680584, 29.088643714785576, 28.193155266344547, 33.25966089963913, 59.58599343895912, 65.30058279633522, 77.3746021091938, 76.81972548365593, 84.36110481619835, 74.61386784911156, 46.86551861464977, 26.794385723769665, 4.257985018193722, 0.2522639214294031, 0.2009646999067627, 0.06343603003188036, 0.1509612236986868, 0.22140291257528588, 0.12618269392987713, 0.15678868599934503, 0.18762416497338563, 0.1375530197401531, 0.10135142714716494, 0.1259369688341394, 0.19260369386756793, 0.14699629973620176, 0.294083853950724, 0.13872224371880293, 0.15513313264818862, 0.2207551957690157, 0.15520231565460563, 0.0897594218258746, 0.1175678956496995, 0.1432899697101675, 0.1412577912560664, 0.20915940549457446, 0.21324761502910405, 0.13797257066471502, 0.08993657989776693, 0.06817450936068781, 0.13185999006964266, 0.18658885412150994, 0.1333424894255586, 0.16602486226474866, 0.21865349292056635, 0.11020754216588102, 0.17407079692929983, 0.0887192424852401, 0.07578567165182903, 0.10632326739141718], [0.045781424050801434, 0.11433910796768032, 0.12242769385920838, 0.05641422947519459, 0.031100028645596467, 0.05126652991748415, 0.08155399220413528, 0.034919948084279895, 0.055759900133125484, 0.03714202728588134, 0.07282631326233968, 0.05512380535947159, 0.03593116511183325, 0.03205678687663749, 0.08279708956251852, 0.1065618010761682, 0.0363174678204814, 0.0016089348810055526, 0.031878356021479703, 0.0779524831159506, 0.06456676623201929, 0.04881757246039342, 0.03317050934128929, 0.019326987530803308, 0.05029641673900187, 0.03487394977128133, 0.024656051282363478, 0.06611496792174876, 0.35113476449623704, 0.24753606965532526, 0.09347628292744048, 0.07784169531078078, 0.12169796231319197, 0.017856217818916775, 5.700456965714693, 42.0247607678175, 70.08729994297028, 63.29966716468334, 64.60311502218246, 57.33377069234848, 47.38083556294441, 40.244001522660255, 26.554555892944336, 16.25939592719078, 20.08485585451126, 24.28151026368141, 41.072835847735405, 58.50191920995712, 45.19281417131424, 46.821444779634476, 17.819991186261177, 4.99300760217011, 0.8251098124310374, 0.046023278846405447, 0.05377704852435272, 0.10202538629528135, 0.055266902563744225, 0.05869205509952735, 0.25809322425629944, 0.3256428526947275, 0.8744003518950194, 1.0876799980178475, 2.168916491791606, 3.2767164101824164, 2.529770778492093, 2.664980348199606, 3.7066980125382543, 5.337555063888431, 5.3842640575021505, 5.979088889434934, 10.215349048376083, 6.6751298401504755, 5.603320403024554, 3.993442738428712, 3.530319551937282, 6.843955731019378, 6.95640167221427, 6.862760446965694, 7.0795464143157005, 3.450783407315612, 1.121577622834593, 0.10866106968023814, 0.2498637861572206, 0.5157235858496279, 0.4404992895433679, 6.3364421389997005, 21.012513376772404, 27.576872035861015, 27.221771590411663, 14.814218524843454, 5.8289912436157465, 5.304461689665914, 4.408430820330977, 5.116708539426327, 4.043238591402769, 3.618653886951506, 4.187288861721754, 3.3700709883123636, 6.525469645857811, 4.92926649749279, 1.0199685813859105, 3.41620787512511, 2.679016082547605, 2.8523093461990356, 2.374412314966321, 1.3942164368927479, 1.5341498656198382, 1.9396585249342024, 2.44906073436141, 1.1766600608825684, 1.580037153325975, 0.6885545211844146, 0.5269857065286487, 0.12350590826827101, 0.17570288357092068, 0.09810721021494828, 0.07132333805202506, 0.029531065374612808, 0.07371038926066831, 0.4390903963940218, 3.2567978790029883, 9.43210942670703, 21.919777393341064, 47.91024215519428, 52.93632745742798, 89.38818946480751, 97.86390826106071, 76.45160123705864, 40.656613782048225, 23.95914316177368, 28.111841529607773, 29.90773156285286, 45.04115670919418, 54.24701012670994, 57.37350136041641, 62.55381278693676, 63.16090241074562, 35.421315506100655, 10.77873531728983, 0.4561500856652856, 0.10700664439355023, 0.04456373040738981, 0.03473763579677325, 0.04126891384657938, 0.09111322535318322, 0.10096176993101835, 0.23272290593013167, 0.31683068023994565, 0.24606314400443807, 0.05566241161432117, 0.10019188077421859, 0.10615309292916209, 0.03243983897846192, 0.08012817066628486, 0.046040789820835926, 0.04560497844067868, 0.035925821648561396, 0.08848666082485579, 0.05610615655314177, 0.08861112641170621, 0.03316334761620965, 0.04197475194814615, 0.05734444108384196, 0.059357216086937115, 0.08128501562168822, 0.06831435224739835, 0.027909663804166485, 0.042408299777889624, 0.04439023483428173, 0.030315157382574398, 0.07905112885055132, 0.017247293071704917, 0.0746117572998628, 0.02646436645591166, 0.052804549341090024, 0.04990129731595516, 0.03798660989559721, 0.07614604372065514, 0.09956705922377296, 0.039880351832835004, 0.010455780939082615, 0.03865309932734817, 0.07677319561480545, 0.04254704057530034, 0.06008236116031185, 0.05610064239590429, 0.034128510669688694, 0.02506670200091321, 0.05880062759388238, 0.0694912945618853, 0.015769467390782665, 0.012125231933168834, 0.052437876438489184, 0.09248006841517054, 0.09976381741580553, 0.028806771915697027, 0.013861075458407868, 0.14634298713644966, 0.05692708320566453, 0.03744250803720206, 0.08255273001850583, 0.05070792649348732, 0.04547896547592245, 0.006890736813147669, 0.19881793385138735, 0.11706250050337985, 0.11315599840600044, 0.05845905041496735, 0.04923392472846899, 0.20143958536209539, 10.993138812482357, 57.672476917505264, 79.69377726316452, 72.95751392841339, 72.76339754462242, 67.20877960324287, 57.297501638531685, 50.85366301238537, 37.61266551911831, 29.534954465925694, 22.38700982183218, 25.37014614790678, 37.12088830769062, 48.85684736073017, 40.14659754931927, 37.85299502313137, 16.50954980403185, 4.0375398471951485, 0.5147111776750535, 0.07764219859382138, 0.05417646127170883, 0.1361860876204446, 0.12488635489717126, 0.2631175937131047, 0.6838678882922977, 1.6220105323009193, 2.474084054119885, 3.4848583163693547, 5.554316807538271, 5.7063300255686045, 7.627565832808614, 6.414713189005852, 7.393774352967739, 8.254481367766857, 8.978475518524647, 6.770157516002655, 8.188851289451122, 10.149821564555168, 7.729175230488181, 9.408071916550398, 7.159324558451772, 10.897427648305893, 7.531039612367749, 7.067955136299133, 8.730327934026718, 6.572636514902115, 4.959869105368853, 1.9711721339263022, 1.1671463213860989, 0.18228585220640525, 0.9758635167963803, 5.896583441644907, 21.24106541275978, 29.86441768705845, 28.871757052838802, 17.96732258051634, 6.398966833949089, 2.9144754353910685, 3.1447338173165917, 4.606604911386967, 5.74742054566741, 4.171321643516421, 9.271263107657433, 6.712278546765447, 3.9148415811359882, 5.487991366535425, 3.2373251114040613, 1.8219774146564305, 5.692647434771061, 4.587256349623203, 5.506490673869848, 3.982422617264092, 3.4471700387075543, 5.968714971095324, 6.146681271493435, 4.962277701124549, 5.231403959915042, 3.659718045964837, 1.4851466263644397, 0.9967994433827698, 0.395462354645133, 0.12406291978550144, 0.09287482418585569, 0.07205802714452147, 0.065782582241809, 0.21417488402221352, 1.782646318897605, 7.80696228146553, 18.09791587293148, 46.14873267710209, 55.393055230379105, 88.22176605463028, 81.81096285581589, 55.10251522064209, 36.31875514984131, 27.90252786129713, 37.81283497810364, 36.629327684640884, 51.068150103092194, 58.64820376038551, 67.21513286232948, 71.16927668452263, 71.18902802467346, 41.86814837157726, 12.555112447589636, 0.3528205677866936, 0.045252428608364426, 0.020845521867158823, 0.051637741053127684, 0.06272077036555856, 0.09513866403722204, 0.12709667847957462, 0.17036886041751131, 0.2717126434436068, 0.0911490636644885, 0.0641584514232818, 0.036217660090187564, 0.14573006221326068, 0.06485954349045642, 0.026084264391101897, 0.06125528845586814, 0.042846983269555494, 0.03396764273929875, 0.046684602930326946, 0.053317622005124576, 0.07000606303336099, 0.0173988785900292, 0.02287777268065838, 0.016152528769453056, 0.0648202616139315, 0.07321007040445693, 0.04806664517673198, 0.04927611953462474, 0.06912771641509607, 0.045441271795425564, 0.015103475197975058, 0.056485008099116385, 0.051108103652950376, 0.08976215292932466, 0.020880644005956128, 0.01944636198459193, 0.04718001619039569, 0.11720956448698416, 0.2698463201522827, 0.22312153363600373, 0.11035329254809767, 0.08488409788697027, 0.21411175694083795, 0.22520272352267057, 0.12467335851397365, 0.16582316136918962, 0.18469020287739113, 0.14024456671904773, 0.13084881386021152, 0.4151933896355331, 0.10407064139144495, 0.2797377831302583, 0.24094686697935686, 0.21081478073028848, 0.12954350968357176, 0.25029025389812887, 0.1159351559181232, 0.08129994763294235, 0.22428998578106984, 0.13348426931770518, 0.1988945234916173, 0.18033063446637243, 0.12303002091357484, 0.1460825972026214, 0.079446122108493, 0.46066747920122, 0.34507590055000037, 0.2077646873658523, 0.25230711442418396, 0.15178226167336106, 0.41716019972227514, 13.699584435671568, 69.04390633106232, 95.23918390274048, 84.1275617480278, 82.10249081254005, 75.97522839903831, 63.432181254029274, 54.7259896248579, 37.80780404806137, 25.97425863146782, 29.469516277313232, 33.76366205513477, 54.64018262922764, 75.96788719296455, 60.92630311846733, 59.891873225569725, 24.13697361946106, 7.073356071487069, 1.3922921963967383, 0.3231412509921938, 0.2715506771346554, 0.23844903538702056, 0.17640391626628116, 0.12111438933061436, 0.4787559335818514, 1.468773304950446, 3.0815332336351275, 3.3502082666382194, 7.982098683714867, 9.23598675057292, 13.023613058030605, 10.411912500858307, 15.199247114360332, 11.899938303977251, 16.904407516121864, 16.069322526454926, 20.928955860435963, 18.13189174979925, 15.602945052087307, 15.155397467315197, 18.442352190613747, 17.568271793425083, 17.24269386380911, 15.020539853721857, 18.337449319660664, 16.526561491191387, 5.3415638487786055, 1.2321376777254045, 1.0704709589481354, 0.580927018309012, 1.4803242101334035, 5.550350295379758, 14.420081824064255, 17.870146594941616, 17.74786725640297, 11.086032427847385, 7.866526935249567, 15.118644889444113, 12.706395629793406, 13.955525401979685, 13.799304384738207, 16.9670794531703, 18.02067741751671, 11.43318559974432, 18.04998904466629, 15.191727317869663, 7.450716197490692, 9.855310767889023, 13.67674671113491, 11.110684555023909, 10.234750807285309, 8.255799897015095, 8.215414714068174, 9.532008916139603, 9.545585587620735, 7.389232646673918, 7.2877386678010225, 2.9117735428735614, 1.9732712837867439, 1.0257855942472816, 0.3091159067116678, 0.11894423078047112, 0.3293344733538106, 0.1172342112113256, 0.18878071306971833, 0.6557814578991383, 4.819555459544063, 13.425212558358908, 29.622296579182148, 57.64852300286293, 59.724211022257805, 94.42225813865662, 102.79884025454521, 87.90517464280128, 54.329553097486496, 38.406355530023575, 40.70202894508839, 43.38176295161247, 59.80188265442848, 70.1853346824646, 75.20292744040489, 79.81065139174461, 81.9877141714096, 49.31139037013054, 18.1804683431983, 1.4441110845655203, 0.22430631302995607, 0.20370625279610977, 0.1217252436617855, 0.1477909172535874, 0.2182945012464188, 0.32750255602877587, 0.35725736408494413, 0.41056752379518, 0.39076761750038713, 0.14388928364496678, 0.13319852761924267, 0.2512351266341284, 0.18496472330298275, 0.1901059810188599, 0.23402537510264665, 0.13343251193873584, 0.12625814066268504, 0.17603466811124235, 0.1196502655511722, 0.3153643448604271, 0.1610550851910375, 0.15808052761713043, 0.1601589418714866, 0.16570749023230746, 0.11871941198478453, 0.2028554250136949, 0.0647077223402448, 0.23031380551401526, 0.08318955209688284, 0.1456427262746729, 0.11099862706032582, 0.10616542000207119, 0.1372361820540391, 0.09831867035245523, 0.15195279236650094, 0.24773941811872646], [0.20182955428026617, 0.0870733815827407, 0.04633113283489365, 0.04453121691767592, 0.055175314118969254, 0.05024414356739726, 0.04012930156022776, 0.020549805703922175, 0.09819552578846924, 0.039427920055459253, 0.1522539707366377, 0.07545785018010065, 0.09884690880426206, 0.04217953646730166, 0.1105863120756112, 0.14422653039218858, 0.031903811686788686, 0.04542677394056227, 0.042122071972698905, 0.033980530133703724, 0.04986420477507636, 0.011099112580268411, 0.09921845761709847, 0.07428720127791166, 0.012530387048172997, 0.11434267769800499, 0.08656697711558081, 0.21519223490031436, 0.33086389128584415, 0.3546021378133446, 0.23851317178923637, 0.15775310690514743, 0.12095636382582597, 6.211112989112735, 45.603819116950035, 69.00527760386467, 68.27759385108948, 63.03913414478302, 36.75218269228935, 33.58628377318382, 24.600672237575054, 23.578365594148636, 18.72062835842371, 13.85693684220314, 20.465519428253174, 52.0647644251585, 55.83140350878239, 42.30727940797806, 29.771622866392136, 12.147727757692337, 1.7210253817029297, 0.14595015352824703, 0.08223177341278642, 0.04196961999696214, 0.08271066646557301, 0.03751052587176673, 0.12850003520725295, 0.40665892884135246, 1.2988805025815964, 2.2962117986753583, 3.4187359269708395, 3.7304172897711396, 4.281605975702405, 6.746356068179011, 5.982493031769991, 5.456334315240383, 5.839045979082584, 6.4092557318508625, 8.34722014144063, 8.798835407942533, 6.533182756975293, 6.423581913113594, 4.0687209740281105, 4.225052185356617, 2.545435200445354, 10.651996918022633, 7.185866609215736, 7.940392596647143, 9.932410530745983, 2.1653225971385837, 4.330733064562082, 2.5554474256932735, 0.4089579242281616, 0.9745981846936047, 10.88592091575265, 34.07655626535416, 62.76708014309406, 60.803562104701996, 60.93724653124809, 46.48670554161072, 33.78106892108917, 10.003797300159931, 2.9219501093029976, 5.07074193097651, 3.9361361134797335, 5.06262319162488, 6.694565797224641, 4.9900879338383675, 2.5157483434304595, 4.981967769563198, 3.594354190863669, 1.9290988915599883, 3.5306019242852926, 2.6280104694887996, 0.9780191292520612, 2.140656695701182, 7.427800577133894, 3.5734602995216846, 4.636105578392744, 2.936149947345257, 2.464373675175011, 1.736830158624798, 1.289839600212872, 0.5983024172019213, 0.3547009325120598, 0.09975217311875895, 0.22041771153453737, 0.19751271873246878, 0.09615461225621402, 0.03283333309809677, 0.23648982489248738, 1.6818436654284596, 9.469164088368416, 17.90531560778618, 38.62988993525505, 55.27178853750229, 58.47026310861111, 76.70140743255615, 59.16025288403034, 37.08025708794594, 20.210528410971165, 29.1438452526927, 42.10258439183235, 35.45799493789673, 47.78311237692833, 56.95086903870106, 52.76876024901867, 57.105091363191605, 41.33681148290634, 14.011542946100235, 0.8199351432267576, 0.15137324924580753, 0.029994696160429157, 0.03026192312972853, 0.24909394152928144, 0.3835001215338707, 0.26725120784249157, 0.733243270078674, 0.3723717952379957, 0.25283228780608624, 0.21937006618827581, 0.02350259052036563, 0.12233556364662945, 0.03381111266207881, 0.06703793987981044, 0.04981854042853229, 0.23105188622139394, 0.07758592895697802, 0.08112963958410546, 0.01617357978830114, 0.031479128811042756, 0.03820920595899224, 0.039504372398369014, 0.022837025062472094, 0.1294923311797902, 0.055084991035982966, 0.1179668222903274, 0.00337405149366532, 0.06058160390239209, 0.09619096264941618, 0.039115323743317276, 0.03729675394424703, 0.030737415290786885, 0.01871270633273525, 0.047785664355615154, 0.102708013728261, 0.09023265229188837, 0.1028935654903762, 0.03640009854279924, 0.0450774598721182, 0.008549333433620632, 0.0796185304352548, 0.04447897714271676, 0.04030229618365411, 0.06802036528824829, 0.061662304506171495, 0.0792179859126918, 0.09433215731405653, 0.038892085722181946, 0.024357461152249016, 0.016102598929137457, 0.01114730301196687, 0.04136329276661854, 0.01823822720325552, 0.024191496522689704, 0.05245923173788469, 0.06986302891164087, 0.09254338845494203, 0.122254350426374, 0.033134526311187074, 0.014450776725425385, 0.05288735446811188, 0.07634894689545035, 0.19287171307951212, 0.07316508883377537, 0.13571056391810998, 0.09803491018828936, 0.03508843044983223, 0.402856728178449, 10.186116266995668, 57.44788996875286, 77.90589720010757, 73.49093690514565, 67.65634998679161, 51.93661630153656, 49.20272380113602, 39.560817182064056, 35.877268239855766, 28.35642870515585, 18.60305316746235, 16.00440301001072, 29.499316178262234, 46.59906171262264, 38.92957225441933, 29.76751908659935, 12.388871368020773, 1.6133801266551018, 0.08900296554202214, 0.006870772576803574, 0.09712761238915846, 0.33412910357583314, 0.6029918999411166, 0.6381796149071306, 1.373528209514916, 2.554368758574128, 4.381199581548572, 3.0336520029231906, 8.145183082669973, 8.412991762161255, 8.768373392522335, 7.964733615517616, 7.630020976066589, 8.721154276281595, 6.244213012978435, 11.667628269642591, 7.12165622971952, 9.896411262452602, 8.933224696666002, 8.667170573025942, 7.949682148173451, 4.9991485476493835, 6.874166959896684, 8.080373760312796, 9.57137955352664, 6.782312588766217, 4.886591462418437, 3.731993967667222, 2.155748773366213, 1.1260138847865164, 1.6471364465542138, 12.463265676051378, 40.2524446696043, 70.14200180768967, 70.41260808706284, 69.42741215229034, 54.78827208280563, 36.37013219296932, 8.857091031968594, 1.7223367863334715, 3.8893442368134856, 3.632957744412124, 3.9495619805529714, 1.985742214601487, 1.6031228145584464, 3.2449565269052982, 1.4940634416416287, 1.4239984075538814, 4.0966053027659655, 2.9058138001710176, 3.735699481330812, 2.5650065252557397, 3.555573709309101, 7.7898309007287025, 5.589690059423447, 5.154164554551244, 8.177729286253452, 7.9379265289753675, 7.31344903819263, 3.5902905464172363, 3.7828418891876936, 1.2545849732123315, 0.3150441823527217, 0.3051660186611116, 0.04600592001224868, 0.1120876768254675, 0.02955889776785625, 0.03007389444974251, 1.0148001462221146, 5.982513455674052, 18.841849453747272, 42.86620281636715, 60.96055448055267, 61.66297718882561, 68.22857648134232, 55.35846188664436, 39.28131937980652, 23.76957133412361, 34.22016195952892, 51.43378168344498, 42.67115168273449, 55.67696839570999, 64.89501535892487, 63.735169395804405, 67.62672677636147, 49.59810018539429, 18.2026781514287, 1.7427110555581748, 0.14657529420219362, 0.021986555366311222, 0.04213678876112681, 0.18234206247143447, 0.26310111803468317, 0.21686473890440539, 0.36263603484258056, 0.14072743768338114, 0.2379885030677542, 0.15896824013907462, 0.052197680342942476, 0.04861402732785791, 0.05450281700177584, 0.07798024686053395, 0.03285439524916001, 0.047761451787664555, 0.024938720489444677, 0.0475403437303612, 0.0657624848827254, 0.03576413364498876, 0.02920135699241655, 0.043880765297217295, 0.039629379753023386, 0.05836806682054885, 0.0881614739773795, 0.04098414065083489, 0.0480933105427539, 0.015410222458740463, 0.058260466539650224, 0.046231974483816884, 0.05051759901107289, 0.049412938169552945, 0.050311166924075224, 0.06325322421616875, 0.04550790923531167, 0.32141510455403477, 0.3877082176040858, 0.1360182583448477, 0.15008988295448944, 0.14918357221176848, 0.2118924236856401, 0.1348659850191325, 0.06341363201499917, 0.22500679653603584, 0.15497063199291006, 0.268752631964162, 0.20227142900694162, 0.19091078080236912, 0.19884622452082112, 0.1707168683060445, 0.25591502082534134, 0.265032690949738, 0.2927021827781573, 0.08299669760162942, 0.09315353774582036, 0.14107446593698114, 0.24991864571347833, 0.21026994043495506, 0.19885352725395933, 0.10286671458743513, 0.14387778035597876, 0.1623740597278811, 0.38993472000584006, 0.4277865670155734, 0.5375649919733405, 0.2913092606468126, 0.23393723764456809, 0.6872640154324472, 14.668085966259241, 68.69044929742813, 90.5101552605629, 80.29004886746407, 78.09016451239586, 55.005388632416725, 51.62599436938763, 38.43043103814125, 35.951459258794785, 28.070376254618168, 22.643499858677387, 34.093062579631805, 68.83250087499619, 73.14537584781647, 55.82167983055115, 40.92299088835716, 16.67328681796789, 2.855529198423028, 0.3027008118806407, 0.1761735387844965, 0.2999390132026747, 0.29114747245330364, 0.5619178258348256, 0.559745233040303, 1.2732277228496969, 1.9086945801973343, 5.196118103340268, 9.409967064857483, 12.597016599029303, 12.242432925850153, 18.95305998623371, 17.051020748913288, 15.708807371556759, 16.219522766768932, 14.999663773924112, 16.405651979148388, 18.396429754793644, 21.810806840658188, 17.3184921965003, 16.46876849234104, 19.222754314541817, 8.869057539850473, 22.05712292343378, 15.904216635972261, 21.577136479318142, 21.10562738031149, 12.443853467702866, 13.655540999025106, 7.388846017420292, 2.291266364045441, 1.7240456258878112, 14.932970702648163, 33.2852753251791, 55.6702845543623, 58.37821304798126, 54.53413411974907, 41.87887139618397, 34.04190972447395, 15.295920576900244, 8.815572559833527, 13.708086479455233, 12.201612666249275, 15.126880947500467, 16.660882383584976, 13.2087904214859, 14.47231762111187, 16.372120678424835, 8.364345822483301, 10.566612649708986, 12.619763128459454, 8.77894727513194, 5.392215130850673, 6.51202074252069, 14.921050742268562, 7.783627733588219, 13.639398515224457, 12.548648994415998, 10.53818542510271, 8.755037058144808, 5.2125845197588205, 2.852481761947274, 1.0321627208031714, 0.27230116655118763, 0.2656375413062051, 0.273117974284105, 0.2615909662563354, 0.19624802487669513, 0.48434299940709025, 2.5625214586034417, 13.722178023308516, 25.101525261998177, 48.252960965037346, 64.12900686264038, 65.89401975274086, 84.73248168826103, 68.96003723144531, 50.18044553697109, 31.684018447995186, 43.1106398999691, 55.901992321014404, 49.77879948914051, 66.01283937692642, 74.64442580938339, 72.61872410774231, 76.07640936970711, 56.653101816773415, 23.216852992773056, 2.6305361464619637, 0.5077810026705265, 0.08012244128622115, 0.145691218203865, 0.3396970219910145, 0.4822894767858088, 0.4617574269650504, 0.8859030471649021, 0.5191030888818204, 0.3716650331625715, 0.3018258494557813, 0.1605484209721908, 0.3250955929979682, 0.16193539107916877, 0.3775844327174127, 0.11279575250227936, 0.2748405880993232, 0.23351177922450006, 0.15312618721509352, 0.1255617686547339, 0.16522433725185692, 0.20793909206986427, 0.11276028526481241, 0.1509875847841613, 0.31240851909387857, 0.30652400047983974, 0.15877431695116684, 0.12192763475468382, 0.15811419143574312, 0.1807219095644541, 0.13513704703655094, 0.15185999422101304, 0.13454936997732148, 0.12395166442729533, 0.22387291362974793, 0.1408724088105373], [0.117863997729728, 0.1426449543214403, 0.08840338443405926, 0.09771544529940002, 0.07022777965175919, 0.008063213717832696, 0.060329845146043226, 0.06072438940464053, 0.07480637810658664, 0.07895336573710665, 0.07256977507495321, 0.02642550018208567, 0.02207031229772838, 0.007381096975223045, 0.039652835330343805, 0.03807819834037218, 0.03789676549786236, 0.0967465789290145, 0.05188586328586098, 0.07647439953871071, 0.09082017350010574, 0.05082523406599648, 0.2508970635244623, 0.02814169627527008, 0.07988447163370438, 0.1769848249386996, 0.009925875438057119, 0.28742536436766386, 0.2981860900763422, 0.1420178692205809, 0.1826671528397128, 0.19345567940035835, 10.58393782004714, 51.34455867111683, 67.01413884758949, 62.80520349740982, 54.79585647583008, 42.646073028445244, 30.445947982370853, 50.79397201538086, 35.48427052795887, 16.791661866009235, 22.959675192832947, 38.43071602284908, 41.287060752511024, 56.159455105662346, 50.42672172188759, 28.673666082322598, 8.700304795056581, 1.3707623141817749, 0.24527812987798825, 0.05484289504238404, 0.10514005392906256, 0.0802991095406469, 0.2200055672437884, 0.4525013908278197, 1.2027539731934667, 2.0246902434155345, 3.2301985938102007, 4.180944627150893, 2.938373303040862, 7.606115508824587, 5.569498417899013, 5.894973753020167, 3.4204764710739255, 3.441618774086237, 4.623535852879286, 7.796738930046558, 12.982034739106894, 3.2386835385113955, 6.72755847685039, 6.548114055767655, 3.819212825037539, 6.321818148717284, 4.917666669934988, 3.724570353515446, 8.08637173846364, 4.204358495771885, 3.033291734755039, 3.5611772211268544, 4.882862437516451, 4.059985242784023, 6.321244379505515, 9.127771407365799, 38.72608557343483, 56.75201430916786, 62.204531729221344, 57.154082134366035, 65.80094754695892, 67.30594038963318, 58.36667686700821, 28.1380183249712, 9.186895284801722, 4.303435804322362, 6.2798702996224165, 2.4963489593937993, 5.862727258354425, 4.08756036311388, 1.4476619940251112, 1.4291782421059906, 1.2089603464119136, 0.8365901838988066, 1.1578251840546727, 3.0547251971438527, 2.9854188160970807, 0.3364556474843994, 2.2652016626670957, 3.6805943632498384, 5.212926976382732, 4.239769270643592, 3.994572227820754, 6.200146302580833, 1.5234558144584298, 2.184654059819877, 1.1062588635832071, 0.7385461824014783, 0.3716816275846213, 0.29199058189988136, 0.23820075730327517, 0.1700207040994428, 0.06565282514202408, 0.05158672953257337, 0.21450087981065735, 1.857965758536011, 10.512203369289637, 23.97591356188059, 24.386916607618332, 23.487159088253975, 27.48233500868082, 31.126176081597805, 28.930106721818447, 30.92966392636299, 38.50878283381462, 24.570993930101395, 39.22544717788696, 48.24035704135895, 61.00354917347431, 48.930703997612, 59.26950842142105, 29.357739575207233, 4.8131475783884525, 0.3360451210755855, 0.029789369873469695, 0.055287868235609494, 0.3667024400783703, 0.39920883486047387, 0.3312218142673373, 0.6051109987311065, 0.17935693671461195, 0.11510061827721074, 0.06427806336432695, 0.056894599401857704, 0.04529480524070095, 0.1054382933943998, 0.08904805101337843, 0.06772811495466158, 0.11190274846740067, 0.13644873368320987, 0.0490500724845333, 0.04601114473189227, 0.0222839469279279, 0.0717558765609283, 0.05378048095735721, 0.0008184162220459257, 0.021579353779088706, 0.11004416577634402, 0.08389914175495505, 0.04871176075539552, 0.09124811811489053, 0.1243656047154218, 0.12017935747280717, 0.03969936056819279, 0.014564591565431328, 0.04673925468523521, 0.07265386782819405, 0.06028768002579454, 0.09864623949397355, 0.08406546447076835, 0.05050214378570672, 0.1182198130118195, 0.09782164663192816, 0.015604270884068683, 0.0455656668782467, 0.028588274362846278, 0.07885615923441947, 0.011192287365702214, 0.033449434413341805, 0.06415825104340911, 0.04108125067432411, 0.02058912654320011, 0.044829730977653526, 0.053237978427205235, 0.04198242946586106, 0.10633071855409071, 0.05976210588414688, 0.026656582704163156, 0.04138359421631321, 0.062237732417997904, 0.08007312557310797, 0.07644354845979251, 0.09046712642884813, 0.06357787671731785, 0.10596734820865095, 0.11817064572824165, 0.0893033052852843, 0.11977760324953124, 0.06652546464465559, 0.42180663789622486, 15.805145502090454, 63.84445533156395, 76.46612405776978, 70.64643234014511, 61.506649777293205, 53.284707963466644, 41.39163114130497, 54.49383348226547, 30.781162194907665, 21.471175365149975, 28.12031127512455, 27.652436681091785, 37.509330064058304, 53.564217165112495, 44.53044131398201, 28.522646985948086, 8.534985166043043, 1.3001077179796994, 0.09101748088141903, 0.13018542289501056, 0.3331983316456899, 0.32962008146569133, 0.9662405925337225, 2.4987444933503866, 3.034506719559431, 2.0491813542321324, 4.834020808339119, 6.469041248783469, 7.743145180866122, 7.469121934846044, 7.304926095530391, 9.13635229691863, 8.121288064867258, 5.418881149962544, 5.131525844335556, 6.630670800805092, 15.86553756147623, 9.615114256739616, 8.546393103897572, 7.869801409542561, 8.621456176042557, 7.767734136432409, 5.764648346230388, 4.163751499727368, 5.860151946544647, 4.323591347783804, 3.1345411017537117, 1.689317983109504, 1.5631114365532994, 1.9916662154719234, 5.682289665564895, 13.557224124670029, 43.57290409505367, 67.13621109724045, 73.01546841859818, 67.49353632330894, 76.57115802168846, 77.1776282787323, 65.67072853446007, 31.356531120836735, 8.785567469894886, 4.2163406778126955, 4.534968305379152, 1.7093740194104612, 0.5858770839404315, 1.7103770468384027, 0.09796483660466038, 1.6567774792201817, 0.42416182870510966, 1.4972574077546597, 1.567520268727094, 3.6875439528375864, 3.5619849152863026, 4.318037470802665, 4.448569491505623, 6.6608791798353195, 8.109440300613642, 5.767346676439047, 7.211227398365736, 6.404638979583979, 5.82434456795454, 5.005416786298156, 4.29520164616406, 3.6295151291415095, 1.4417157880961895, 0.9670152165926993, 0.2780236297985539, 0.2992453722981736, 0.21809202851727605, 0.019268127798568457, 0.1243738796620164, 1.9738559774123132, 10.467623211443424, 23.94486352801323, 31.25058140605688, 26.573963351547718, 34.41602624952793, 35.49899473786354, 33.7118062376976, 36.58202402293682, 41.631295680999756, 29.334038347005844, 43.601812943816185, 55.290589928627014, 70.15194967389107, 58.30730885267258, 71.75576001405716, 41.268460750579834, 5.313916057348251, 0.6035051692742854, 0.08854385814629495, 0.07811474628397264, 0.2786737511632964, 0.2895394462393597, 0.11368425912223756, 0.48494678107090294, 0.06113111230661161, 0.0900495718815364, 0.019578430874389596, 0.0413003586436389, 0.031055830040713772, 0.0615778926294297, 0.02927677589468658, 0.06086196503019892, 0.10756932591903023, 0.13635075534693897, 0.06641403859248385, 0.06443206642870791, 0.058707528878585435, 0.0797734982916154, 0.01950216592376819, 0.043488777737366036, 0.06849315788713284, 0.050339101362624206, 0.08208827173803002, 0.06436516923713498, 0.07098480738932267, 0.1166480036044959, 0.05811163624457549, 0.057011573007912375, 0.015531832632404985, 0.042042695567943156, 0.09116972505580634, 0.05341410491382703, 0.3718442766694352, 0.293429012526758, 0.17462543357396498, 0.30840282153803855, 0.19595018617110327, 0.06611846343730576, 0.15402032673591748, 0.11987008969299495, 0.23246361437486485, 0.1890781955444254, 0.2929195133037865, 0.10100278843310662, 0.13256562408059835, 0.11901857171324082, 0.1476473710499704, 0.17560725042130798, 0.14803143247263506, 0.2703094499884173, 0.12773311464115977, 0.20207458175718784, 0.17315333912847564, 0.12528364139143378, 0.44737905787769705, 0.19474517583148554, 0.2856104273814708, 0.20339076581876725, 0.24863802536856383, 0.45768122537992895, 0.5018339061643928, 0.4347081627929583, 0.254556504660286, 1.164430060889572, 20.50084613263607, 74.56906825304031, 84.67878296971321, 77.21143126487732, 73.17015811800957, 59.985181018710136, 43.217851147055626, 62.05326944589615, 47.603913992643356, 24.388533420860767, 32.55857191979885, 56.79890759289265, 56.84852913022041, 75.33238649368286, 66.8076579272747, 37.955695912241936, 12.098978273570538, 2.333487323485315, 0.4675854532979429, 0.20047408092068508, 0.4513116687303409, 0.16781962767709047, 0.7156649976968765, 1.2462333776056767, 3.473362270742655, 3.6721635656431317, 8.940602000802755, 11.726054884493351, 11.23344361782074, 16.870057359337807, 18.11438038945198, 17.269419729709625, 13.16059285774827, 13.379563707858324, 14.371050205081701, 19.717917144298553, 25.513622649013996, 13.395751789212227, 15.30469335615635, 16.892949230968952, 14.068117160350084, 17.298087291419506, 12.87402743473649, 12.765530906617641, 18.577942214906216, 12.57775828242302, 9.89421023055911, 9.81334201991558, 13.276185505092144, 10.020188670605421, 10.162448287010193, 13.641202468425035, 52.18926854431629, 63.55583801865578, 71.24931558966637, 65.07447972893715, 74.26088199019432, 74.29349943995476, 64.5749281346798, 35.18447421491146, 15.33780287951231, 11.475941855460405, 14.53745847567916, 9.538866598159075, 15.143011081963778, 10.968840066343546, 5.6566681154072285, 5.8813852071762085, 4.562721066176891, 3.898522169329226, 4.194127069786191, 8.816908188164234, 7.4933223612606525, 5.981755396351218, 6.992233749479055, 12.575181070715189, 11.8494295142591, 12.261500302702188, 11.79053457453847, 15.49343017861247, 8.899796940386295, 5.8192262426018715, 4.913706807419658, 2.35200016759336, 1.4471325161866844, 0.589183084666729, 0.6738113716710359, 0.6127538729924709, 0.24772669770754874, 0.16558914736378938, 0.3103623882634565, 3.1860556500032544, 15.515705533325672, 36.15811496973038, 38.842610120773315, 35.64373277127743, 39.7525928914547, 44.51485835015774, 43.77942681312561, 42.40463778376579, 49.75311666727066, 36.69775441288948, 55.109620839357376, 63.73504400253296, 80.50849914550781, 68.7236139178276, 79.89401891827583, 48.05086500942707, 10.242030266672373, 1.2970720371231437, 0.19722136639757082, 0.1274317581555806, 0.6799795688129961, 0.6587228563148528, 0.48549819679465145, 0.8763589686714113, 0.3666248411173001, 0.4179682501126081, 0.20395404106238857, 0.18872175685828552, 0.16260130534647033, 0.1692124459077604, 0.22754489706130698, 0.19174502900568768, 0.23921975574921817, 0.2981368114706129, 0.3103777358774096, 0.14150304137729108, 0.1955891164834611, 0.15808708820259199, 0.15897454839432612, 0.1484038570197299, 0.16465545137180015, 0.19091198308160529, 0.2997024462092668, 0.24031614535488188, 0.2075840486213565, 0.286399211618118, 0.30810293450485915, 0.16153390402905643, 0.1563495275331661, 0.22970531863393262, 0.2383778931107372, 0.18322355579584837], [0.061024710594210774, 0.09088274397072382, 0.034546629249234684, 0.06353221237077378, 0.02551601119193947, 0.08329813572345302, 0.07279929908690974, 0.06967803376028314, 0.11861052407766692, 0.07349338528001681, 0.07455573257175274, 0.025243516829505097, 0.05124831019202247, 0.011076311020588037, 0.04065580709720962, 0.01578730676556006, 0.027467286272440106, 0.102802207111381, 0.02798149813315831, 0.04092067960300483, 0.04877045350440312, 0.0342758640908869, 0.11832350588520057, 0.03180723600962665, 0.054656782958772965, 0.04365161606983747, 0.05344094097381458, 0.13566691079176962, 0.16849412117153406, 0.2569982298882678, 0.5852372338995337, 9.45966174826026, 48.186760917305946, 70.47242447733879, 65.68956032395363, 52.575977593660355, 44.06350716948509, 27.585018798708916, 37.30740509927273, 108.1053239107132, 90.91277405619621, 24.654120169579983, 37.724508717656136, 46.25658608973026, 38.66128385066986, 27.010637819767, 17.138834036886692, 4.0949576161801815, 0.4581176972715184, 0.10686271227314137, 0.07407444980344735, 0.030596915603382513, 0.11591049435082823, 0.22904399083927274, 1.1493962863460183, 2.8957904130220413, 1.1785204173065722, 2.89063123986125, 4.205960109829903, 4.764800872653723, 3.146710186265409, 6.815664824098349, 6.316876038908958, 5.693552261218429, 3.8655439764261246, 4.222275959327817, 7.315572174265981, 2.2769546695053577, 15.02740228548646, 8.577233199030161, 5.711123468354344, 7.674288125708699, 5.398198384791613, 4.3815334886312485, 1.8847704702056944, 3.2115933671593666, 4.711360540241003, 6.865111570805311, 2.486995761282742, 5.065834019333124, 7.999253813177347, 20.108114406466484, 23.536776825785637, 40.15399195253849, 51.460319459438324, 51.72638118267059, 43.2879725843668, 53.286330476403236, 50.34331239759922, 49.28955294191837, 59.64101068675518, 51.138708516955376, 23.06698903441429, 17.137517407536507, 16.99858546257019, 21.599042303860188, 10.482766348868608, 14.965351615101099, 13.47531097009778, 11.771281957626343, 5.124646313488483, 8.35628455504775, 4.955299375578761, 2.5947062065824866, 4.341006288304925, 6.807192703709006, 5.627635773271322, 6.753021385520697, 2.5254183495417237, 5.8815523982048035, 7.0737474504858255, 4.998563379049301, 2.5901754247024655, 6.720080953091383, 3.2080103969201446, 2.365300878882408, 1.0932577424682677, 0.826722647761926, 0.16671684075845405, 0.06220643605047371, 0.1801028841873631, 0.16233138623647392, 0.0639651293749921, 0.10171439673285931, 1.8216042034327984, 8.326861783862114, 22.541452534496784, 35.38125805556774, 31.1801540851593, 21.885263845324516, 28.562879227101803, 44.79788236320019, 31.160870119929314, 22.71632295101881, 34.11950156092644, 33.42627055943012, 38.27631890773773, 47.9712288826704, 59.237483739852905, 62.783392667770386, 29.959676675498486, 5.152418073266745, 0.5466161062940955, 0.008049033131101169, 0.19326527399243787, 0.14137977064820006, 0.22753582801669836, 0.2896470279665664, 0.09508426461252384, 0.1546222233446315, 0.060059981697122566, 0.08422189435805194, 0.07697541601373814, 0.025495455556665547, 0.05261871556285769, 0.07050837084534578, 0.11484475544421002, 0.06824877607868984, 0.01993359677726403, 0.12859554961323738, 0.017168567901535425, 0.09019758581416681, 0.005363961854527588, 0.06180604366818443, 0.014398005387192825, 0.03931516555894632, 0.05352852924261242, 0.03847878739179578, 0.06347635091515258, 0.0846697433735244, 0.06402237122529186, 0.04427129453688394, 0.0439699343405664, 0.09215327852871269, 0.035073105100309476, 0.02662507482455112, 0.020180848841846455, 0.02859985743270954, 0.03172244563756976, 0.08459488293738104, 0.03301358963653911, 0.04656857927329838, 0.039835103088989854, 0.026921945027424954, 0.08890899480320513, 0.04767227903357707, 0.017713766283122823, 0.05576591895078309, 0.12546554178697988, 0.00927836828850559, 0.05446311210107524, 0.09389192273374647, 0.006866688445370528, 0.06814763619331643, 0.04370638285763562, 0.02729846066358732, 0.050845721052610315, 0.08295607985928655, 0.11920213451958261, 0.0664555469120387, 0.019434806745266542, 0.01715997754217824, 0.01791740047337953, 0.060837025157525204, 0.018726892485574353, 0.06679346159216948, 0.8986324234865606, 12.727133966982365, 61.49300470948219, 79.85491901636124, 71.80247470736504, 59.53583613038063, 53.023293390870094, 35.773172825574875, 48.169205859303474, 114.57737982273102, 93.37612867355347, 24.73209958523512, 29.096893072128296, 44.909691363573074, 41.23957850039005, 32.65385180711746, 19.129114039242268, 5.203813640400767, 0.2766294905450195, 0.03627360689279158, 0.01707131686998764, 0.28214139165356755, 0.5977207515388727, 0.8767434011679143, 2.940022414550185, 4.731356017291546, 4.706545723602176, 3.8093616161495447, 6.229728190228343, 8.357910867780447, 5.532106999307871, 7.17933950945735, 8.255856893956661, 9.881257675588131, 6.0334905702620745, 7.333449739962816, 8.238817658275366, 5.5198973044753075, 8.84318282827735, 9.587179105728865, 4.547121003270149, 5.543098384514451, 4.858363727107644, 2.8495411947369576, 0.9840965468902141, 1.64250259520486, 1.3095170818269253, 1.6631797794252634, 2.055858545936644, 6.08706864528358, 10.804942511022091, 23.500872552394867, 27.50813752412796, 45.014523938298225, 57.61664651334286, 60.93940481543541, 51.905294582247734, 57.87514664232731, 57.300777062773705, 61.79688960313797, 65.54583683609962, 57.94681079685688, 27.89368573576212, 21.884226500988007, 18.829726204276085, 21.867754384875298, 12.930978778749704, 17.18102127313614, 17.004651837050915, 15.974325723946095, 9.173658695071936, 11.711564362049103, 7.11271483451128, 4.424987956881523, 4.011733056977391, 7.878784602507949, 7.693184986710548, 6.59350642003119, 5.788564262911677, 5.374828213825822, 5.915319286286831, 7.915492057800293, 9.084399584680796, 10.223919488489628, 5.620334940031171, 5.232314961031079, 3.616929966956377, 2.6212425576522946, 1.3724363618530333, 0.5410953587852418, 0.21360360842663795, 0.42579835338983685, 0.11586272972635925, 0.08746370673179626, 1.3416774873621762, 6.96070066653192, 19.00483600795269, 31.48147601634264, 29.0177908167243, 28.451298214495182, 30.502031072974205, 41.122974157333374, 34.62178900837898, 27.19922360032797, 39.68513511121273, 42.16242358088493, 43.97396117448807, 57.58400246500969, 68.25727254152298, 76.2092350423336, 47.417085617780685, 10.65234174951911, 0.657650304492563, 0.062326704792212695, 0.10694387354305945, 0.12691808806266636, 0.12504245823947713, 0.27924835158046335, 0.07490014104405418, 0.05151211400516331, 0.07854153314838186, 0.04148009938944597, 0.045825585548300296, 0.10097791906446218, 0.13480020104907453, 0.07805000132066198, 0.050449555201339535, 0.05299528500472661, 0.07856010910472833, 0.1532153191510588, 0.027332246936566662, 0.03893182030878961, 0.006194275283633033, 0.05493339995155111, 0.07825424036127515, 0.04766411169839557, 0.02601120180770522, 0.03193382413883228, 0.030078859417699277, 0.07155451705330051, 0.016837787115946412, 0.039840120007283986, 0.05216604629822541, 0.1111829245928675, 0.03292358567705378, 0.032375509617850184, 0.2106594343786128, 0.2836029476020485, 0.2138945006299764, 0.2047153064631857, 0.08642307468107902, 0.12843806587625295, 0.16322282433975488, 0.10450233385199681, 0.21717511990573257, 0.11869400826981291, 0.17596679128473625, 0.11535041034221649, 0.2354931057197973, 0.08988520843558945, 0.21251861820928752, 0.1927884144242853, 0.13844683271599934, 0.18784348445478827, 0.15866413770709187, 0.09092317617614754, 0.23626568145118654, 0.19305358378915116, 0.34987545863259584, 0.12019521716865711, 0.18216976546682417, 0.11182276721228845, 0.2118546632118523, 0.22091736987931654, 0.2849229017738253, 0.3670160716865212, 1.509657686110586, 17.449805550277233, 71.89661085605621, 89.50142338871956, 82.32838869094849, 69.36808973550797, 60.55612698197365, 42.72497199475765, 51.758668050169945, 110.68813651800156, 93.37473034858704, 31.985368877649307, 50.7115164399147, 62.5090853869915, 54.48277607560158, 40.48553176224232, 24.32421427220106, 6.486904565244913, 0.7187903893645853, 0.21699094853829592, 0.20251801499398425, 0.2833695273147896, 0.3726813895627856, 0.7482139323838055, 3.9336771704256535, 6.188661893829703, 6.092511378228664, 8.24258990585804, 12.659352254122496, 16.238099969923496, 9.590244591236115, 17.152091525495052, 13.473962992429733, 16.854472495615482, 14.462312757968903, 14.473923984915018, 19.933756962418556, 14.217324703931808, 27.948064617812634, 18.898713402450085, 17.378582172095776, 17.45517086237669, 14.826154634356499, 10.584658831357956, 9.359001349657774, 9.294099882245064, 12.63583056628704, 15.815988220274448, 9.882497359067202, 10.744170472025871, 11.09874939545989, 28.75035736709833, 31.125017143785954, 48.453669995069504, 67.9124790430069, 63.25185053050518, 58.52892056107521, 63.0258234590292, 61.310458704829216, 66.04159623384476, 75.00100627541542, 64.21213880181313, 33.916421458125114, 27.971097081899643, 23.732700012624264, 26.609563641250134, 14.530015625059605, 20.142312571406364, 17.98089735209942, 17.106165289878845, 8.002439942210913, 11.69063413515687, 9.800130128860474, 7.586020287126303, 9.372160043567419, 13.188482411205769, 12.171939108520746, 16.362858675420284, 9.991308320313692, 16.062169410288334, 18.9638552069664, 14.351858384907246, 10.333860889077187, 14.898201618343592, 9.944231696426868, 7.272769846022129, 4.407565416768193, 1.8763668648898602, 0.9090489707887173, 0.5397584836464375, 0.5590580042917281, 0.3906198113691062, 0.2377394976792857, 0.3936054417863488, 3.2242189021781087, 11.116221807897091, 30.52820596843958, 49.72367964684963, 45.05002923309803, 34.1274431347847, 41.04303024709225, 60.70453181862831, 40.79581171274185, 36.38328328728676, 49.277625381946564, 50.38709744811058, 52.34847240149975, 70.22534653544426, 76.83630779385567, 84.7285071015358, 58.15326511859894, 12.931269463151693, 1.234222815837711, 0.2824676100863144, 0.3446994535624981, 0.4790471226442605, 0.41826276399660856, 0.7878342282492667, 0.2840871544321999, 0.2641143277287483, 0.22799141763243824, 0.22562801867024973, 0.15290383977117017, 0.24901129596401006, 0.2183185171452351, 0.26285517029464245, 0.2986413531471044, 0.21866858820430934, 0.23302684508962557, 0.3733613749500364, 0.26196307910140604, 0.18850328342523426, 0.19232369639212266, 0.2380245566018857, 0.1462639929377474, 0.1811948951217346, 0.11919729571673088, 0.13456281769322231, 0.1487390257534571, 0.26193095894996077, 0.14773430622881278, 0.16476524469908327, 0.14698786893859506, 0.303340929094702, 0.17826016119215637, 0.15264662622939795], [0.03831411224382464, 0.056356412460445426, 0.018879370436479803, 0.0893029935832601, 0.035504682527971454, 0.08973625197540969, 0.03329048122395761, 0.05019352167437319, 0.1652223037672229, 0.05252122333331499, 0.04445305392437149, 0.033240838965866715, 0.05086159930215217, 0.13177740387618542, 0.049321524129481986, 0.043242221436230466, 0.05587500723777339, 0.05763557077443693, 0.06762641103705391, 0.022491618401545566, 0.08345360824023373, 0.11597907621762715, 0.06441006175009534, 0.08348800678504631, 0.04880692264123354, 0.18013285211054608, 0.03827657812507823, 0.13905953499488533, 0.03727459341462236, 0.1252595809637569, 5.883708307519555, 35.63898682594299, 59.53745484352112, 66.892811357975, 54.02701713144779, 52.637101113796234, 43.01680773496628, 35.86704678833485, 17.468177564442158, 16.52130827307701, 15.43520875275135, 30.782627016305923, 47.48014323413372, 31.23379770666361, 29.428539276123047, 15.186381954699755, 3.537703030742705, 0.4002312768716365, 0.18017898401012644, 0.07425971212796867, 0.1863707962911576, 0.08912550154491328, 0.6995751766953617, 2.3797355918213725, 2.2765155555680394, 6.290541077032685, 4.21235516667366, 2.4722031550481915, 4.1883941274136305, 5.716928131878376, 7.915982231497765, 4.004038944840431, 6.53365203179419, 4.795779185369611, 6.694789510220289, 4.409872842952609, 3.990211011841893, 4.120157863944769, 8.605551179498434, 8.001245856285095, 7.891669236123562, 6.706639174371958, 5.5535459239035845, 5.424011824652553, 3.053645105101168, 2.0602245116606355, 4.960403926670551, 9.471946489065886, 25.61360288411379, 37.20521338284016, 33.297997042536736, 33.714629486203194, 54.76656384766102, 65.50169080495834, 50.1489832252264, 42.12213434278965, 41.19938425719738, 46.99243560433388, 47.78479188680649, 46.35414585471153, 49.56203632056713, 46.67548321187496, 43.995885998010635, 33.89300711452961, 46.66991651058197, 52.54081428050995, 49.86538544297218, 49.93859991431236, 35.82602418959141, 35.44805467128754, 28.83542150259018, 19.838328883051872, 17.92930942028761, 19.970605485141277, 14.868818745017052, 16.636100113391876, 9.094927869737148, 11.358546204864979, 14.808577727526426, 3.5700682690367103, 5.789565984159708, 3.0873979814350605, 5.386154931038618, 4.599507367238402, 5.0946378987282515, 8.354796934872866, 2.6576816523447633, 3.0519052734598517, 1.0235901433043182, 0.5779407941736281, 0.15798286098288372, 0.26777923107147217, 0.05928049657086376, 0.050756808050209656, 0.06221656265552156, 0.1876530790468678, 5.321478601545095, 19.36999261379242, 48.02442982792854, 42.95812748372555, 37.04936854541302, 48.039119839668274, 28.63615069538355, 20.994481444358826, 15.184502955526114, 28.2003615796566, 41.82260401546955, 46.14509627223015, 51.877468675374985, 57.347400560975075, 69.05611127614975, 39.297411516308784, 7.430194923654199, 0.07698012123000808, 0.23144762904848903, 0.24789421528112143, 0.19665874424390495, 0.2251138142310083, 0.01165170275271521, 0.07498770704842173, 0.07508920316467993, 0.061413659059326164, 0.0538725963269826, 0.04132881629629992, 0.021344927881727926, 0.05099311158119235, 0.015841004860703833, 0.044411048365873285, 0.07322141784243286, 0.05497286736499518, 0.10263206233503297, 0.041939689181162976, 0.06402759594493546, 0.014523001609632047, 0.08220666655688547, 0.06262578288442455, 0.10139495410840027, 0.0716210060636513, 0.09433677347260527, 0.010244272561976686, 0.027418684876465704, 0.023701658647041768, 0.0877539161592722, 0.08764704689383507, 0.043986250457237475, 0.05401762311521452, 0.07997696549864486, 0.04794658423634246, 0.04528715740889311, 0.03077923716773512, 0.03716973908012733, 0.041272064263466746, 0.05100296730233822, 0.016094964084913954, 0.06209437175130006, 0.09630160944652744, 0.03221504244720563, 0.07914872127003036, 0.03720074601005763, 0.025295018167525996, 0.08915779239032418, 0.13297291472554207, 0.04508076985075604, 0.007762373024888802, 0.044852154969703406, 0.03666299322503619, 0.03615041037846822, 0.058746647482621484, 0.03730675067345146, 0.11324853679980151, 0.02053952881396981, 0.16144449007697403, 0.06306169816525653, 0.15165375138167292, 0.022732124343747273, 0.16153512115124613, 8.427563980221748, 45.63424788415432, 70.6967568397522, 75.12958377599716, 64.6943861246109, 62.442030385136604, 54.71882700920105, 49.99948024749756, 28.17731011658907, 32.26845748722553, 33.47716882824898, 30.988665260374546, 42.36669301986694, 35.3724729269743, 30.275397934019566, 14.68053599819541, 2.7822845662012696, 0.18555079732323065, 0.13576128229033202, 0.19105903222225606, 0.33756869088392705, 0.9509668371174484, 2.825515796430409, 4.685464929789305, 4.350862009450793, 8.68861947208643, 4.381694030016661, 3.532214700244367, 5.706874821335077, 10.058768950402737, 6.552321380004287, 8.25697498396039, 7.885309802368283, 8.573703188449144, 7.661341745406389, 7.299774521961808, 7.637058673426509, 5.7252083625644445, 7.940862821415067, 1.9826819538138807, 3.508149404078722, 4.376561930403113, 3.8676711497828364, 3.0950961308553815, 1.2504696752876043, 1.1072433670051396, 4.223609212785959, 10.974351670593023, 26.15679133683443, 40.04510499536991, 37.97114968299866, 37.49741770327091, 60.65565884113312, 68.73034715652466, 56.57482601702213, 48.23695242404938, 47.550086081027985, 53.76572795212269, 54.71202537417412, 53.43077212572098, 54.10359062254429, 52.77458913624287, 47.672823294997215, 36.61421589553356, 50.960498079657555, 53.456040769815445, 51.15565940737724, 53.955698758363724, 41.93092480301857, 39.18571650981903, 32.21057139337063, 23.00182443112135, 23.388142101466656, 24.8746033385396, 19.86207950860262, 15.286777317523956, 10.52695607766509, 11.025658417493105, 9.071702565997839, 6.358264843001962, 7.430933034047484, 3.7603972060605884, 11.47809823974967, 8.191892076283693, 9.17960062623024, 5.089916652068496, 4.4611249677836895, 3.2877802290022373, 3.8586005615070462, 1.405406123958528, 1.2009446765296161, 0.19984735205071047, 0.24343582248548046, 0.2350347998435609, 0.0668645890254993, 0.0948937181965448, 3.86301901191473, 17.73419748991728, 39.63335528969765, 35.24766482412815, 33.10019485652447, 54.01068180799484, 31.76650632172823, 24.08509500324726, 27.46525302529335, 34.731758907437325, 51.464358642697334, 55.51669679582119, 62.23688319325447, 64.17461201548576, 79.07859787344933, 56.64905123412609, 13.87021142989397, 0.15176667657215148, 0.19861121603753418, 0.1703024233574979, 0.07765210626530461, 0.1460199005668983, 0.017835300386650488, 0.014223056132323109, 0.06038286417606287, 0.10651866745320149, 0.03527767439663876, 0.022253923343669157, 0.0224485422950238, 0.035749209055211395, 0.04898774692264851, 0.018896092879003845, 0.07795427911332808, 0.05705074356228579, 0.0406924617709592, 0.07816692668711767, 0.056099080175044946, 0.09632075685658492, 0.10206299091805704, 0.07300050274352543, 0.07047623585094698, 0.03629045364505146, 0.012974387100257445, 0.0836693134624511, 0.02783153235213831, 0.03591130895074457, 0.03384270217793528, 0.059402706028777175, 0.08112987707136199, 0.12486794963479042, 0.1596185693051666, 0.13542088883696124, 0.12281044910196215, 0.18280363379744813, 0.1848396862624213, 0.18813422822859138, 0.10656809448846616, 0.22238165693124756, 0.2933548274450004, 0.21132522990228608, 0.1436334801837802, 0.19553986756363884, 0.1207000705471728, 0.16857501526828855, 0.17594587756320834, 0.23517886555055156, 0.20242291619069874, 0.26087238918989897, 0.1783373297075741, 0.13569361326517537, 0.1941997863468714, 0.25301824032794684, 0.12866848788689822, 0.30066815845202655, 0.1218243277980946, 0.3224249300546944, 0.15478603017982095, 0.2554536424577236, 0.1369160640751943, 0.3511133015854284, 10.595665890723467, 57.753640562295914, 81.31543144583702, 85.23909330368042, 72.54048630595207, 69.15216252207756, 57.11164981126785, 50.76325446367264, 27.289542853832245, 23.824026212096214, 22.07441009581089, 40.82957290112972, 64.83357265591621, 44.79980506002903, 39.86173443496227, 20.153863951563835, 5.180997289717197, 0.707942743320018, 0.43898441770579666, 0.6470169313251972, 0.5668465176131576, 0.6813575292471796, 2.9500021040439606, 7.1359676867723465, 5.954830991104245, 12.686787731945515, 9.692339412868023, 7.485572202131152, 14.368603136390448, 15.88906304910779, 19.096825271844864, 13.86561082676053, 19.382017068564892, 17.211313247680664, 20.135951712727547, 14.361113738268614, 10.735368244349957, 10.804587230086327, 16.07441995292902, 17.373241558670998, 17.250245958566666, 16.708740815520287, 13.733375072479248, 13.682657293975353, 8.554144687950611, 5.76122235506773, 7.81516176648438, 12.14418064802885, 30.82599598914385, 44.17519457638264, 42.19852164387703, 42.746019065380096, 68.40616375207901, 73.02087932825089, 65.37818223237991, 51.86310924589634, 52.98602879047394, 56.479257345199585, 58.63535664975643, 60.90384632349014, 63.80290076136589, 58.42024639248848, 53.639943301677704, 40.10946214199066, 53.913182839751244, 52.586997002363205, 52.932216078042984, 58.18006508052349, 47.71535061299801, 40.19138194620609, 33.993409126996994, 28.30649558454752, 26.036294102668762, 27.42175105959177, 21.99108626693487, 22.535047978162766, 17.05962348729372, 15.9725721180439, 27.811517044901848, 10.505248792469501, 14.947433676570654, 10.68116795271635, 17.813993208110332, 11.954485327005386, 13.746277280151844, 17.383776493370533, 11.069479566067457, 7.222973518073559, 5.108178472146392, 2.3769237427040935, 1.0815360839478672, 0.4370249400380999, 0.2257506363093853, 0.19218672561692074, 0.22942042298382148, 0.5921761959325522, 7.041938407346606, 27.58270662277937, 61.87462203204632, 55.969385504722595, 50.946640223264694, 59.2262477427721, 40.16345724463463, 32.78217472136021, 28.808480948209763, 42.049755826592445, 58.601975440979004, 63.592221066355705, 74.02233839035034, 74.61331307888031, 86.0580937564373, 67.81218722462654, 16.84437833726406, 0.24185687361750752, 0.43933120847214013, 0.36179892194923013, 0.3387473104521632, 0.4515784262912348, 0.27858585119247437, 0.2133898698957637, 0.2830859675304964, 0.2626839419826865, 0.1401226466987282, 0.17814210033975542, 0.12251102962181903, 0.21482613345142454, 0.17825376387918368, 0.11587596964091063, 0.22136728948680684, 0.23197813105070964, 0.1664821885060519, 0.1251950438017957, 0.132236689387355, 0.10461743353516795, 0.21016721235355362, 0.1903534575831145, 0.25533881736919284, 0.16522168036317453, 0.16048566496465355, 0.15468940255232155, 0.12182126272819005, 0.070912848750595, 0.19036686077015474, 0.18327486788621172, 0.13523217552574351, 0.23817531648091972], [0.03355219218065031, 0.028014785311825108, 0.03883095130731817, 0.02894838667998556, 0.04591313670971431, 0.01148654520875425, 0.0436432001151843, 0.01642992687266087, 0.058473789467825554, 0.05092755025543738, 0.019404673694225494, 0.07650536936125718, 0.06649350034422241, 0.03474172503047157, 0.11917765106773004, 0.0444073487597052, 0.24938572430983186, 0.13365281105507165, 0.04499247654166538, 0.008044483765843324, 0.026950339597533457, 0.05694626030162908, 0.056095039180945605, 0.07365892874076962, 0.09178757783956826, 0.01720219646813348, 0.1034218558925204, 0.06436470910557546, 0.059143043399672024, 2.0694563537836075, 34.26381781697273, 61.609962433576584, 68.00126507878304, 62.23753295838833, 43.75719800591469, 27.84377921372652, 21.510147973895073, 16.329074688255787, 21.26624286174774, 24.56617198884487, 21.622707433998585, 36.71133868396282, 32.57564440369606, 27.780761495232582, 10.195079036056995, 2.101256134919822, 0.10392388168838806, 0.05887825995159801, 0.028560636783367954, 0.012044116119795945, 0.2618153620278463, 1.4513316471129656, 3.430478721857071, 1.8417593906633556, 3.320757234469056, 5.056015821173787, 5.252292389050126, 2.944832956418395, 3.356010317802429, 6.04600234888494, 2.2186192497611046, 5.000036275014281, 6.982855852693319, 5.973981963470578, 3.190223313868046, 5.325627978891134, 6.082466142252088, 3.4538726415485144, 3.9569157734513283, 6.650693351402879, 9.38307685777545, 11.22869672253728, 11.41435096040368, 28.503250926733017, 25.952746085822582, 27.944916486740112, 35.372009351849556, 53.279331251978874, 50.23212656378746, 65.29234483838081, 45.21724686026573, 37.23925955593586, 57.40445829927921, 74.53486248850822, 50.76247550547123, 35.61886690557003, 40.9334821254015, 42.90884032845497, 40.168427377939224, 45.31848482787609, 40.574188604950905, 59.96905468404293, 44.81962479650974, 35.225261226296425, 66.13888621330261, 61.969263553619385, 60.87652198970318, 54.27736669778824, 54.472243040800095, 49.90160129964352, 45.01106232404709, 42.49244727194309, 40.91061495244503, 39.300249963998795, 36.62460073828697, 32.59440399706364, 29.02699962258339, 26.748510785400867, 19.14518717676401, 14.965856038033962, 7.684289189055562, 7.647589333355427, 13.26931357383728, 11.467912886291742, 3.658459600992501, 2.8396346513181925, 4.05929890461266, 6.199254775419831, 4.02565598487854, 0.8114108943846077, 0.7099245151039213, 1.069258467759937, 0.05110792553750798, 0.03624482640589122, 0.054642689574393444, 0.007667027921343106, 0.17548662173794582, 1.4337473781779408, 15.7693400233984, 50.3002455085516, 44.74317669868469, 15.177729818969965, 23.89279682189226, 25.224262475967407, 15.52186120301485, 16.135978549718857, 16.46546646952629, 30.159821435809135, 42.00070045888424, 54.39763784408569, 61.10793337225914, 64.989113509655, 44.39384624361992, 13.82359268143773, 0.04851919198699761, 0.17975808237679303, 0.3495725733228028, 0.0722539318667259, 0.07978100882610306, 0.032201412905124016, 0.07796409030561335, 0.07891669622040354, 0.03841434670903254, 0.06879015796585009, 0.019786072662100196, 0.032098313749884255, 0.039098900015233085, 0.09397190398885868, 0.06441355726565234, 0.10301445392542519, 0.05392756349465344, 0.023091882285370957, 0.048660263128113, 0.03289410757133737, 0.031611190279363655, 0.04151773369812872, 0.08424525716691278, 0.07327505285502411, 0.0744529599614907, 0.03162889050145168, 0.009872030768747209, 0.03314680514449719, 0.005421702799139894, 0.027829298487631604, 0.057914692515623756, 0.030023237304703798, 0.05210544622968882, 0.040498816888430156, 0.07197476559667848, 0.03419220920477528, 0.035126465518260375, 0.04645978413464036, 0.03066677581955446, 0.07142823320464231, 0.08053768033278175, 0.07308547123102471, 0.05419931942014955, 0.019732389409909956, 0.04349516391812358, 0.010842600368050626, 0.08255310109234415, 0.046392074291361496, 0.10728639696026221, 0.11252539552515373, 0.03168599505443126, 0.05847269108926412, 0.04430844644957688, 0.019162000680807978, 0.07369927188847214, 0.04486475663725287, 0.06081259736674838, 0.03496219855151139, 0.011516412014316302, 0.013801795485051116, 0.147708494332619, 3.5400045197457075, 41.7089407145977, 71.63921266794205, 74.18768271803856, 73.44003483653069, 53.68713676929474, 41.02913439273834, 36.395096853375435, 28.66123504936695, 24.20960672199726, 25.845437943935394, 17.25584875792265, 30.056736767292023, 36.75122134387493, 23.725140318274498, 10.546102300286293, 1.348984851501882, 0.2786336455028504, 0.09486101174843498, 0.1225967105710879, 0.3977097856113687, 1.3678704318590462, 3.5282505629584193, 5.802459167316556, 7.7910910081118345, 5.3990077413618565, 6.900168489664793, 8.250505831092596, 7.319883992895484, 9.129968639463186, 10.167870596051216, 6.685469085350633, 9.524708557873964, 11.015576608479023, 10.851348470896482, 8.785343281924725, 6.317691095173359, 4.606103813275695, 3.922655861824751, 4.46956573985517, 5.00289942137897, 8.554050642997026, 12.446042150259018, 15.57419864460826, 29.24813825637102, 28.757552281022072, 29.681848883628845, 39.109511598944664, 55.100676119327545, 53.88628788292408, 69.95061367750168, 48.838680535554886, 39.39174145460129, 62.48746454715729, 73.76982674002647, 57.1507915109396, 41.84897840023041, 46.13101422786713, 48.468257412314415, 48.210239857435226, 52.46889553964138, 48.920520544052124, 62.5247747451067, 46.784518361091614, 39.60461363196373, 70.69815516471863, 60.54528996348381, 61.95206567645073, 57.18913905322552, 56.65067374706268, 51.88806250691414, 49.02574069797993, 48.09143163263798, 44.81357932090759, 44.37293216586113, 40.423633083701134, 33.95623952150345, 30.062919035553932, 27.382787950336933, 20.279775895178318, 14.78130279108882, 8.233974818140268, 4.967716159299016, 3.676600302569568, 5.1465739868581295, 5.285553429275751, 6.930959187448025, 6.129186535254121, 5.04436707124114, 5.383167816326022, 4.338748259469867, 2.7326312055811286, 2.3947884840890765, 0.6593201367650181, 0.4451914440141991, 0.12746052379952744, 0.1111365997348912, 0.163574869511649, 1.1593642202205956, 14.236429128795862, 39.04061749577522, 40.994518250226974, 21.444248110055923, 26.083888448774815, 27.4616090208292, 22.712779641151428, 22.820507660508156, 27.945649847388268, 41.40296593308449, 51.675627306103706, 61.58947013318539, 66.65800675749779, 74.5108249783516, 60.004989355802536, 20.9524841979146, 0.23625423753401265, 0.12252887827344239, 0.19849741511279717, 0.1289975710096769, 0.047746649652253836, 0.01849630720244022, 0.17731595638906583, 0.044383369968272746, 0.04128453976591118, 0.08170055894879624, 0.03661795599327888, 0.07782852961099707, 0.030641446319350507, 0.09590677203959785, 0.05364570693927817, 0.05034562855144031, 0.07412406237563118, 0.06046829650586005, 0.044138168086647056, 0.03458551778749097, 0.06298922744463198, 0.03715420221851673, 0.0668929168023169, 0.04861737441387959, 0.03531559072143864, 0.06710275905788876, 0.02942393079138128, 0.017889597766043153, 0.03335275483550504, 0.03254811461374629, 0.013451325521600666, 0.033323807365377434, 0.20762611355166882, 0.14201259997207671, 0.16762865823693573, 0.16336656350176781, 0.10976038334774785, 0.16575120273046196, 0.115392215520842, 0.1826165828970261, 0.18473775970051065, 0.11885653118952177, 0.1517433434491977, 0.18360089336056262, 0.15887429908616468, 0.1792497854330577, 0.19202182040316984, 0.15012428892077878, 0.3359337692381814, 0.2845508186146617, 0.13645964325405657, 0.1764085324248299, 0.17227027245098725, 0.15780818910570815, 0.2481942655867897, 0.18433512974297628, 0.22135770093882456, 0.15059601282700896, 0.14873227220959961, 0.17658964614383876, 0.33556931535713375, 5.336061269044876, 53.04685212671757, 84.54528093338013, 85.88166162371635, 80.88404059410095, 60.60449078679085, 43.42630796134472, 32.46524512767792, 24.83248069882393, 32.65107035636902, 36.65247604250908, 33.36777649819851, 50.73904976248741, 44.680461063981056, 38.69460806250572, 14.999743569642305, 3.3216045890003443, 0.3510358213679865, 0.2881059137871489, 0.24351036379812285, 0.4545628692721948, 0.8182055235374719, 3.640513401478529, 6.778528466820717, 9.57826478406787, 12.600257825106382, 12.28642601519823, 12.307412289083004, 11.270640771836042, 12.694509867578745, 14.457409121096134, 9.067976865917444, 17.21763800829649, 15.16152273863554, 15.315016452223063, 11.904809642583132, 14.45318279787898, 16.16060122847557, 11.238153465092182, 11.045359410345554, 12.073432244360447, 13.20476358756423, 14.269257467240095, 17.2031968832016, 32.61638201773167, 30.202173963189125, 32.88367107510567, 39.969021677970886, 54.70750741660595, 53.11866447329521, 72.94267952442169, 52.324518486857414, 44.091918244957924, 68.74674707651138, 76.01728454232216, 61.56912602484226, 47.26624131202698, 50.79941712319851, 54.671006575226784, 51.1550210416317, 59.17579784989357, 57.240649089217186, 63.56218367815018, 51.526435911655426, 40.28763838112354, 70.66410139203072, 60.52357792854309, 64.11259174346924, 61.41249842941761, 56.85890257358551, 52.751459777355194, 55.44266156852245, 51.06794111430645, 47.95329764485359, 46.63746625185013, 40.95538415014744, 37.78039991855621, 33.85643407702446, 34.801500365138054, 26.749031357467175, 20.300783067941666, 17.60904550552368, 16.64730381220579, 23.503304421901703, 22.673769034445286, 12.026895191520452, 10.219287537038326, 12.494115270674229, 15.517896115779877, 10.931053943932056, 4.711077930405736, 3.6493935249745846, 2.734977579675615, 0.5795722722541541, 0.44099468796048313, 0.2938618033658713, 0.34566584858112037, 0.6970157171599567, 2.1367752039805055, 21.428017280995846, 66.7218205332756, 59.76561740040779, 25.326201505959034, 36.339110657572746, 38.46581853926182, 25.27715753763914, 25.390157774090767, 28.48436214029789, 45.54501727223396, 61.26293085515499, 72.19245538115501, 77.20015347003937, 82.24531754851341, 70.86606815457344, 23.616190664470196, 0.4064258054131642, 0.4308136092731729, 0.4959801124641672, 0.297443259623833, 0.23953666765009984, 0.1359717405284755, 0.4227329866262153, 0.16673586942488328, 0.11755226601962931, 0.13804098183754832, 0.18803786777425557, 0.15724234603112563, 0.09688438090961426, 0.2206600969657302, 0.22263938997639343, 0.19617600686615333, 0.13022882369114086, 0.13329423498362303, 0.13930445857113227, 0.15673594898544252, 0.10372416232712567, 0.2404593353276141, 0.235683377541136, 0.166676260123495, 0.19603110995376483, 0.2089178512687795, 0.14223876205505803, 0.13544165412895381, 0.0865984070696868, 0.11803685134509578, 0.14328193967230618, 0.203982851235196], [0.05256804543023463, 0.06874946600873955, 0.03136646337225102, 0.030416954068641644, 0.055280320593738, 0.039561718149343506, 0.018647963224793784, 0.07368203179794364, 0.08725509644136764, 0.09691251572803594, 0.03813683542830404, 0.027629976175376214, 0.07381892093690112, 0.030218459251045715, 0.05199985716899391, 0.016285083765978925, 0.10534182903938927, 0.09321185571025126, 0.024215078265115153, 0.017663491344137583, 0.0451332545344485, 0.00988404150120914, 0.08605676543083973, 0.04012314173451159, 0.13572451629443094, 0.034240088862134144, 0.07005074032349512, 0.023607083057868294, 0.45987403427716345, 25.204940512776375, 68.7031178176403, 62.100155130028725, 60.14679774641991, 46.134221255779266, 38.837712183594704, 29.754157103598118, 18.230492658913136, 19.124582782387733, 21.016254276037216, 29.11686100065708, 41.82946264743805, 48.09917941689491, 32.012833803892136, 12.436932139098644, 0.9496305556967854, 0.32726364384870976, 0.05146701369085349, 0.10700831422582269, 0.02336413544981042, 0.39511580136604607, 0.4403925983933732, 1.8182154977694154, 6.95178871974349, 7.670842660591006, 3.908863076940179, 8.457121644169092, 3.972432240843773, 1.9539444521069527, 2.6030726451426744, 9.25386194139719, 6.249343687668443, 6.249631522223353, 5.783185651525855, 7.675599055364728, 7.232785541564226, 5.638103736564517, 8.706102333962917, 14.044454880058765, 17.74845242500305, 19.09348715096712, 31.047841385006905, 46.1069805175066, 46.549208387732506, 54.61703807115555, 61.33730806410313, 59.52115371823311, 65.12029767036438, 64.10603329539299, 61.90174117684364, 60.8544185757637, 58.98538626730442, 55.00758111476898, 58.423989191651344, 68.31087246537209, 58.38001795113087, 37.997277081012726, 36.72501415014267, 37.886159643530846, 41.92353419959545, 34.238077998161316, 52.13205501437187, 64.36393305659294, 49.13532681763172, 52.56503038108349, 65.85788369178772, 61.88409872353077, 61.0209446400404, 64.03679341077805, 59.64539185166359, 57.92743943631649, 68.57469230890274, 57.03680142760277, 51.70615866780281, 53.05762454867363, 58.72358791530132, 53.977068811655045, 52.079036459326744, 47.36326150596142, 38.81242834031582, 29.787950590252876, 22.952497377991676, 11.162539422512054, 13.135586399585009, 5.804215148091316, 11.227898765355349, 3.0865762755274773, 1.5941150416620076, 1.7347532138228416, 2.0248498348519206, 1.6615357738919556, 1.9347996544092894, 0.5356535164173692, 0.5237352778203785, 0.2002541528781876, 0.0625350108020939, 0.04302073117287364, 0.06721641155309044, 0.08570259771659039, 2.0097233215346932, 14.508233293890953, 36.08533747494221, 58.877719044685364, 42.449615970253944, 26.08918536454439, 24.02212668210268, 25.067969262599945, 22.326106689870358, 20.150014758110046, 30.123284496366978, 45.94398446381092, 50.08304536342621, 50.94198167324066, 63.372862637043, 51.51758998632431, 8.548180907964706, 0.33924659772310406, 0.08137701966916211, 0.0019903549537048093, 0.12846096855355427, 0.04063456683070399, 0.01741758627758827, 0.07855339266825467, 0.07476610175217502, 0.03643386997282505, 0.06759252457413822, 0.06501034789835103, 0.029291817372723017, 0.07378225884167477, 0.029225840444269124, 0.03584326143027283, 0.022675633917970117, 0.07376436566119082, 0.014127785707387375, 0.043647693819366395, 0.046392360018217005, 0.05105326636112295, 0.05119130953971762, 0.01232155411344138, 0.04867803385423031, 0.10649126736097969, 0.018285822989128064, 0.02245461306301877, 0.013971657317597419, 0.04034407909784932, 0.06058392311388161, 0.02939665315352613, 0.0564057281735586, 0.03094573057751404, 0.020225900916557293, 0.036306320762378164, 0.08425802952842787, 0.024694136445759796, 0.045300490091904067, 0.04559481101750862, 0.047153098494163714, 0.06831395890912972, 0.058120096728089266, 0.034454250417184085, 0.03623415432230104, 0.012795637121598702, 0.024326647180714644, 0.033281475261901505, 0.018325377604924142, 0.02343597348954063, 0.06859489149064757, 0.048494556394871324, 0.0716837694926653, 0.02318156712135533, 0.04499096627114341, 0.01894615445053205, 0.1115547851077281, 0.007471988728866563, 0.026443497263244353, 0.02236152362456778, 0.8906098664738238, 31.981496885418892, 79.99858170747757, 69.46503773331642, 69.33734178543091, 55.99210828542709, 50.6564611941576, 41.24482981860638, 25.332488268613815, 24.738114662468433, 21.631969437003136, 25.508967898786068, 32.17501290142536, 40.94423934817314, 26.274414025247097, 9.360438622534275, 0.8147696172818542, 0.34293887147214264, 0.15412076900247484, 0.5019441596232355, 0.6401745672337711, 1.5292514534667134, 3.8958145771175623, 8.082819879055023, 11.133373137563467, 9.253491461277008, 12.456273101270199, 10.899210702627897, 10.138954147696495, 7.272325269877911, 8.02001304924488, 10.649765487760305, 7.591236457228661, 9.349043983966112, 7.69955107010901, 11.229321788996458, 6.889309622347355, 6.535774692893028, 5.870506865903735, 14.077987130731344, 19.515294916927814, 22.606905922293663, 32.346501499414444, 49.45954442024231, 50.75033895671368, 57.755092084407806, 62.453874349594116, 60.289753675460815, 65.01220107078552, 65.09350150823593, 60.2224250882864, 61.962188333272934, 63.959649950265884, 60.15835292637348, 61.16682641208172, 67.40744814276695, 60.041399002075195, 43.51944096386433, 43.18203806877136, 44.99700307846069, 50.24853028357029, 42.80513249337673, 57.05013871192932, 64.82044816017151, 51.59111984074116, 54.64362524449825, 66.77442491054535, 60.52978679537773, 60.26822783052921, 63.40182088315487, 60.72651743888855, 58.201070353388786, 70.35200893878937, 59.375621527433395, 54.85845051705837, 53.07194598019123, 60.32648250460625, 56.68951906263828, 54.12610821425915, 47.378848269581795, 39.43184830248356, 28.129647374153137, 22.16545131057501, 12.713192515075207, 10.20434008911252, 4.694547392427921, 5.728737898170948, 4.843592019751668, 3.494700975716114, 5.388893159106374, 4.936165502294898, 4.673833278939128, 3.0311154015362263, 3.1593521079048514, 2.641662899404764, 1.970216603949666, 0.21634955483023077, 0.28010036679916084, 0.13606130291009322, 0.03828033339232206, 1.3158816215582192, 13.0701501108706, 32.35784009099007, 48.89578007161617, 34.655542597174644, 30.495584718883038, 22.291064970195293, 19.098419286310673, 27.329615503549576, 31.101642698049545, 42.7949034422636, 53.12167391180992, 59.308262541890144, 55.73672778904438, 68.25215801596642, 61.1345699429512, 15.020840037614107, 0.34143281634896994, 0.06532952334964648, 0.043449955992400646, 0.07786718066199683, 0.0679589896753896, 0.07936718728160486, 0.04985907282389235, 0.038757371075917035, 0.12208915577502921, 0.07935975838336162, 0.019231814512750134, 0.03791722279856913, 0.045204344860394485, 0.037903481934336014, 0.020398717424541246, 0.009579876914358465, 0.010808363240357721, 0.03696096180647146, 0.06452784058637917, 0.01919049729622202, 0.040161154538509436, 0.037388980636023916, 0.03225130378268659, 0.007870352728787111, 0.05807246569020208, 0.06691354850772768, 0.04877036815742031, 0.021627446803904604, 0.008698290821484989, 0.0442375305283349, 0.03789356313063763, 0.17118388699600473, 0.25408055051229894, 0.11664784033200704, 0.17940502788405865, 0.28553401585668325, 0.1397550164256245, 0.12795267160981894, 0.15617452911101282, 0.1968600443797186, 0.17380644392687827, 0.08778648902080022, 0.16225262952502817, 0.12868080753833055, 0.10439178353408352, 0.12407801506924443, 0.13468026998452842, 0.21417522541014478, 0.2034016457037069, 0.30662341858260334, 0.12210397646413185, 0.1596330411848612, 0.1460512340418063, 0.23899630992673337, 0.14226449973648414, 0.2373393761808984, 0.1732580116367899, 0.15211481804726645, 0.13741302100243047, 1.672110368963331, 40.4573904722929, 90.96755191683769, 78.4332101047039, 79.52897250652313, 63.1208411604166, 53.29432524740696, 42.41875022649765, 29.894299283623695, 29.254083037376404, 34.1705784201622, 41.26667484641075, 57.91383616626263, 63.89093443751335, 43.520957082509995, 16.4246566593647, 1.522919568233192, 0.7240284676663578, 0.2090179966762662, 0.5829232768155634, 0.48483997117727995, 1.3816907652653754, 4.062759093940258, 10.995633378624916, 19.064654298126698, 17.433470226824284, 10.353147704154253, 15.946347825229168, 9.707515798509121, 8.587109819054604, 10.794998444616795, 17.61885467916727, 18.334002904593945, 14.55587798729539, 15.142469611018896, 17.353832200169563, 16.890638954937458, 11.646063476800919, 13.61885966733098, 20.242606289684772, 24.427221044898033, 23.129771165549755, 35.6500556319952, 50.755320489406586, 52.23539046943188, 63.04685913026333, 61.09953202307224, 59.74062614142895, 63.350649029016495, 63.43184307217598, 59.791038036346436, 63.83415788412094, 63.86261835694313, 60.35009823739529, 64.87417727708817, 69.76378530263901, 62.303413823246956, 48.753827288746834, 48.0060426145792, 51.42898254096508, 53.88496555387974, 48.55747662484646, 62.826087176799774, 66.78843095898628, 54.490413665771484, 57.37816371023655, 70.73276370763779, 65.12411266565323, 63.29415366053581, 66.24479413032532, 64.00559708476067, 63.659397661685944, 71.3844895362854, 57.96409226953983, 56.313996613025665, 54.348099902272224, 59.899659007787704, 58.35548646748066, 56.365909427404404, 52.25205257534981, 46.49736776947975, 36.46594025194645, 32.76521623134613, 16.761176101863384, 21.566951125860214, 14.361322727054358, 21.220206432044506, 9.235079549252987, 8.554380275309086, 8.257526904344559, 8.938528262078762, 6.552110491320491, 6.296146251261234, 3.0219495808705688, 3.6640006536617875, 1.6938373656012118, 0.191914624592755, 0.2955351088894531, 0.30641205492429435, 0.3860190894920379, 2.7826726203784347, 19.02237206697464, 49.05122213065624, 77.30429828166962, 56.14110589027405, 38.33943732082844, 35.52997827529907, 37.384939938783646, 33.395024836063385, 33.573706448078156, 45.35831429064274, 60.821527540683746, 69.74432274699211, 68.34781408309937, 74.99805003404617, 71.53545543551445, 20.282361656427383, 1.0254940786398947, 0.26219902269076556, 0.1671663744491525, 0.2658334979787469, 0.30044705781619996, 0.18628858117153868, 0.12354453705484048, 0.11321648344164714, 0.161274345300626, 0.17482701572589576, 0.11282954248599708, 0.0947064149659127, 0.14040921960258856, 0.087649718625471, 0.24696995940757915, 0.15864435205003247, 0.20307104859966785, 0.11872695220517926, 0.13480529218213633, 0.19805798947345465, 0.24588312866399065, 0.1545660724514164, 0.12597106309840456, 0.1379180228104815, 0.16443457338027656, 0.11999874841421843, 0.1121878222329542, 0.149513709184248, 0.16716342070139945, 0.22774926968850195, 0.08588734053773805], [0.051529342963476665, 0.052520826284307986, 0.0422592245740816, 0.08521747062331997, 0.03934309628675692, 0.0704159437736962, 0.018285294208908454, 0.08693710842635483, 0.09370593310450204, 0.05713693659345154, 0.11646348342765123, 0.0634981477924157, 0.0662944266514387, 0.04129262546484824, 0.06607601259020157, 0.0561752690555295, 0.12699001701548696, 0.07912099463283084, 0.04814130152226426, 0.09452317128307186, 0.04256093357980717, 0.05480579136929009, 0.06839262656285428, 0.018836017879948486, 0.027701940380211454, 0.02218676825577859, 0.056305274774786085, 0.1996295465505682, 7.424001730978489, 50.74840106070042, 71.2290246784687, 66.6524438560009, 54.52562637627125, 35.41134104132652, 19.728208892047405, 13.527707308530807, 30.44878263026476, 20.848077200353146, 34.37169782817364, 42.545564621686935, 39.2329365760088, 25.860821418464184, 10.204740017652512, 0.6185093766544014, 0.10568618556135334, 0.051024675121880136, 0.04112714137590956, 0.08703525003511459, 0.34789226192515343, 0.8645722386427224, 4.544449271634221, 5.580331161618233, 4.915054310113192, 7.657927628606558, 7.635207222774625, 5.996379386633635, 11.393304839730263, 8.966422565281391, 11.767625603824854, 10.132229458540678, 5.201645856723189, 7.658740784972906, 13.397239409387112, 16.441512554883957, 16.96737013757229, 19.91998840123415, 19.071906208992004, 32.51654237508774, 44.932125359773636, 50.399560779333115, 61.247515082359314, 57.729990631341934, 64.91172686219215, 63.25999729335308, 59.94826599955559, 58.051457181572914, 59.22331050038338, 61.94925382733345, 64.75378453731537, 65.54813951253891, 62.516430392861366, 70.64602196216583, 63.674258664250374, 65.10814592242241, 65.37433683872223, 48.375173807144165, 29.052547551691532, 36.469968035817146, 36.172493398189545, 34.197902753949165, 62.68768720328808, 58.336403891444206, 54.450553804636, 58.36448438465595, 58.586335480213165, 62.72881619632244, 56.775196865200996, 55.741044357419014, 54.17472280561924, 58.789996951818466, 57.420033663511276, 53.09049278497696, 56.32459044456482, 62.179483473300934, 61.70760579407215, 68.64989787340164, 62.382681369781494, 61.96906976401806, 58.75843584537506, 53.67442265152931, 40.46332575380802, 34.71736527979374, 25.16479566693306, 19.076655954122543, 13.746167086064816, 12.826985958963633, 9.229977373033762, 3.854535729624331, 3.756523788906634, 6.644905786961317, 1.9526035990566015, 3.8183174980804324, 1.195358857512474, 1.1519203009083867, 0.04772545020387042, 0.11740304238628596, 0.13173459679819643, 0.09534219061606564, 0.06199261588335503, 0.8845930674578995, 8.31999460235238, 28.39379969984293, 54.02941480278969, 45.48976443707943, 40.22100895643234, 28.000289015471935, 25.470791347324848, 17.52854872494936, 10.849485620856285, 21.41060471534729, 36.4432592689991, 49.541133642196655, 51.66007474064827, 60.24534925818443, 48.677793368697166, 13.212657663971186, 0.3165700676618144, 0.055092642578529194, 0.05544819439819548, 0.06742182318703271, 0.11004475207300857, 0.02230397007224383, 0.08107486908556893, 0.0965188212285284, 0.01558958934765542, 0.051318899568286724, 0.11104544173576869, 0.045815841149305925, 0.04680480487877503, 0.026503412700549234, 0.06378799356753007, 0.03203303444024641, 0.0538181969022844, 0.04606626032909844, 0.06545645286678337, 0.04576964245643467, 0.029393263394013047, 0.07229377777548507, 0.04580973327392712, 0.015249903717631241, 0.029644513779203407, 0.025561595757608302, 0.022530072783411015, 0.036192427069181576, 0.03088750167080434, 0.06344009700114839, 0.028417910652933642, 0.028956893547729123, 0.0325713957863627, 0.10745493127615191, 0.03978975786594674, 0.060793431402998976, 0.04486018871830311, 0.02751514552073786, 0.0891256722388789, 0.03202822532330174, 0.040521734408685006, 0.002404492606729036, 0.033959015272557735, 0.010025005030911416, 0.03257844247855246, 0.1296347493189387, 0.026356155758548994, 0.04535891937848646, 0.07843520565074869, 0.020953771527274512, 0.03516769553243648, 0.05102519833599217, 0.07859730554628186, 0.015618457036907785, 0.05704261704522651, 0.04227508798066992, 0.08391882351133972, 0.220553420658689, 10.921625699847937, 59.493624195456505, 78.20684105157852, 75.14383301138878, 63.39514844119549, 47.427675649523735, 28.220042623579502, 24.571421407163143, 38.26903469860554, 22.727748937904835, 29.252025447785854, 28.43881968408823, 39.74400535225868, 28.8560201972723, 7.333970787003636, 0.7764532451983541, 0.0527044967020629, 0.09109310572966933, 0.2660645137075335, 0.9867837151978165, 2.243430968374014, 3.9527863450348377, 8.511594571173191, 8.713780771940947, 10.56340467184782, 10.967521537095308, 12.963009160012007, 14.455986097455025, 12.916143424808979, 13.43116208910942, 9.026149660348892, 9.590266440063715, 8.140072356909513, 7.434500567615032, 11.316771246492863, 12.699652891606092, 11.239586938172579, 15.448711328208447, 21.920178271830082, 32.08815336227417, 46.09811559319496, 51.26197010278702, 62.93277025222778, 60.58861903846264, 68.75273555517197, 65.03065288066864, 58.93722005188465, 58.53150062263012, 60.45323230326176, 62.007645294070244, 65.67325919866562, 64.06650021672249, 64.44926887750626, 72.8888288140297, 65.25560840964317, 65.26801094412804, 64.77492660284042, 50.598179921507835, 37.0292030274868, 44.0322994440794, 42.127104476094246, 40.650173127651215, 63.20914842188358, 59.97909374535084, 57.51580372452736, 61.24041706323624, 62.518607676029205, 62.38960459828377, 58.83362241089344, 59.00588616728783, 58.13541367650032, 64.38442155718803, 61.702061891555786, 57.387309819459915, 57.28826813399792, 60.756399035453796, 61.80281728506088, 69.04684737324715, 65.5744569003582, 64.6162623167038, 61.27447463572025, 56.102781146764755, 42.41649694740772, 34.513384625315666, 26.018157675862312, 20.389493107795715, 14.23621254041791, 11.747695673257113, 7.410080702975392, 3.722896780818701, 2.856553243473172, 5.359475612640381, 3.4443384781479836, 5.8288240525871515, 4.787301365286112, 2.3164566373452544, 1.4667319832369685, 0.743211085209623, 0.2352395880734548, 0.2242532346281223, 0.08488122577546164, 0.6493415159638971, 8.822516687214375, 27.6529648527503, 47.49412268400192, 39.39437471330166, 30.96760679036379, 27.512482590973377, 20.943714268505573, 20.078969970345497, 24.655279107391834, 36.77610240876675, 46.11505128443241, 59.88691069185734, 60.735705345869064, 68.54116290807724, 59.743521586060524, 18.50787777453661, 0.45980139286257327, 0.06353048316668719, 0.011920799006475136, 0.046905877970857546, 0.11472250887891278, 0.003981065674452111, 0.0229929651322891, 0.059950307113467716, 0.011479146924102679, 0.017249645679839887, 0.03056008652492892, 0.06305885573965497, 0.08076353071373887, 0.04422315141709987, 0.057103551080217585, 0.06615456150029786, 0.007684362635700381, 0.04884092413703911, 0.025676895820652135, 0.04488993399718311, 0.0451696160598658, 0.07949209815706126, 0.01266415638383478, 0.045592948226840235, 0.04453086068679113, 0.02242810354800895, 0.008660144430905348, 0.03166056536429096, 0.02423991980322171, 0.04823053735890426, 0.17834794241935015, 0.18319691269425675, 0.18734916957328096, 0.21077286422951147, 0.2183810356655158, 0.44445060251746327, 0.14582343923393637, 0.1583609258523211, 0.23309950134716928, 0.1439930804190226, 0.2571508154505864, 0.08559068184695207, 0.21910002833465114, 0.1350429723970592, 0.13925924693467095, 0.16034225234761834, 0.31714223383460194, 0.15670137974666432, 0.12904916511615738, 0.1240543182939291, 0.12520285119535401, 0.12834142340580001, 0.19408258638577536, 0.13706964411539957, 0.12269002821994945, 0.14292553067207336, 0.1529372512595728, 0.34979456453584135, 14.693920779973269, 69.12073820829391, 87.88479253649712, 85.2426727116108, 73.59271064400673, 53.6662682890892, 31.946572959423065, 23.749158829450607, 41.3724497705698, 32.04296998679638, 48.731739073991776, 57.194169983267784, 53.51636253297329, 35.512734800577164, 13.262778874486685, 1.1348818964324892, 0.266620886977762, 0.21918262937106192, 0.4415000311564654, 1.0236249351873994, 1.7760535539127886, 4.0246732626110315, 14.86001556739211, 16.337527334690094, 16.474893763661385, 17.183540537953377, 18.570895493030548, 15.773631893098354, 21.96827609091997, 19.092476405203342, 23.42022567987442, 21.666809767484665, 12.745497431606054, 17.22066454589367, 26.16109650582075, 26.00786592811346, 23.789522163569927, 27.69526608288288, 23.834950625896454, 39.462406262755394, 48.83938729763031, 53.764173835515976, 63.46722297370434, 61.609278470277786, 66.21646285057068, 65.82069128751755, 61.295802891254425, 58.88258658349514, 59.40058618783951, 62.96433515846729, 65.11674106121063, 68.16129729151726, 65.38212642073631, 71.0332515835762, 66.9575446844101, 66.48895382881165, 67.51660868525505, 55.371138006448746, 41.219359785318375, 49.26631338894367, 45.194919258356094, 48.062427788972855, 63.80752891302109, 60.98532535135746, 57.06602565944195, 60.965520814061165, 64.3488858640194, 65.30803799629211, 62.159872725605965, 60.579096749424934, 60.64276613295078, 63.95747646689415, 60.93027390539646, 59.81692984700203, 58.498328402638435, 60.88635206222534, 64.57786917686462, 73.06532934308052, 68.15684393048286, 67.36740589141846, 64.6991814672947, 60.392082184553146, 45.88060386478901, 38.52236330509186, 31.29669763147831, 22.603923082351685, 19.004815109074116, 20.562319234013557, 16.78036317229271, 10.21070759743452, 10.905793849378824, 14.825169537216425, 6.945444010198116, 7.727967370301485, 5.852985056117177, 3.381728050298989, 0.8642037177924067, 0.5810714105609804, 0.25291707075666636, 0.30796471692156047, 0.41362407384440303, 1.6392750246450305, 12.65961728990078, 40.38902074098587, 68.98742616176605, 59.36169907450676, 54.312461614608765, 44.77185755968094, 35.94999633729458, 29.09699946641922, 22.97733284533024, 34.90781486034393, 52.64490969479084, 68.8156145811081, 71.4699013531208, 77.24473267793655, 69.01030093431473, 22.52166699618101, 0.9069834253750741, 0.21690266265068203, 0.15438975300639868, 0.17304860724834725, 0.37801648140884936, 0.119730736623751, 0.21723303711041808, 0.19296592130558565, 0.07219043371151201, 0.20462682761717588, 0.11100852731033228, 0.16941485926508904, 0.1303051906870678, 0.23488779523177072, 0.2199032696080394, 0.15771758771734312, 0.11733765175449662, 0.13404583762167022, 0.13461812253808603, 0.11872117087477818, 0.1430382183752954, 0.15835994621738791, 0.15885155968135223, 0.10688113979995251, 0.11602040642173961, 0.08639015301014297, 0.18390309589449316, 0.1765288197202608, 0.17876492551295087, 0.11074067137087695], [0.014300945458671777, 0.04311911397962831, 0.06599725587875582, 0.025625366652093362, 0.05782501510111615, 0.03265556646510959, 0.047854153453954495, 0.015337146887759445, 0.0664466040325351, 0.0859946699347347, 0.08460608194582164, 0.008861817495926516, 0.011551224306458607, 0.0464322207699297, 0.0794906954979524, 0.02593623004941037, 0.062297397380461916, 0.07088502563419752, 0.00803973958682036, 0.020302076809457503, 0.02677718726772582, 0.06659723774646409, 0.016867543527041562, 0.024402431590715423, 0.02172329703171272, 0.016357116619474255, 0.020905817655147985, 3.125158455222845, 32.24980428814888, 64.76361081004143, 64.96677070856094, 57.962070778012276, 39.22269992530346, 28.16173855215311, 27.20821961760521, 23.342101871967316, 18.649946451187134, 41.84807024896145, 63.29678691923618, 51.09377212822437, 27.615504562854767, 7.626822497695684, 0.16727763722883537, 0.08656296209665015, 0.08160615776432678, 0.18178135505877435, 0.23465274221962318, 0.6109340081457049, 1.6378280147910118, 2.337940684519708, 5.234553040936589, 7.609789911657572, 8.653379213064909, 4.888114230707288, 17.439679093658924, 13.319394886493683, 14.085961002856493, 13.153762724250555, 6.146332640200853, 9.829069375991821, 7.930313162505627, 11.876631304621696, 14.41008361056447, 30.02561453729868, 26.170054525136948, 35.8926460146904, 45.34919857978821, 50.30349053442478, 57.41241127252579, 57.00494393706322, 52.917476668953896, 54.30010847747326, 53.61664675176144, 59.272856041789055, 59.81590010225773, 60.27251400053501, 60.78295201063156, 61.6622020304203, 65.01899510622025, 67.46343433856964, 64.45618450641632, 63.74587722122669, 66.12158194184303, 65.60615479946136, 64.34827789664268, 58.006737381219864, 32.34918415546417, 34.941139072179794, 29.44131799042225, 40.29168136417866, 63.37793916463852, 57.678017020225525, 61.592711359262466, 58.50604198873043, 62.04712517559528, 60.327671840786934, 65.47983437776566, 63.23523782193661, 60.490610897541046, 54.26996469497681, 53.02902348339558, 52.77821034193039, 55.879090949893, 54.73333463072777, 64.42094519734383, 60.3362175822258, 57.579146325588226, 56.42587400972843, 58.04056316614151, 59.67158764600754, 62.86414213478565, 53.48392367362976, 54.11309391260147, 42.58779175579548, 40.972806215286255, 34.93010066449642, 22.176922895014286, 22.533640153706074, 11.47683385759592, 4.732415685430169, 1.3023300049826503, 5.104731107130647, 2.5426763109862804, 1.9345158571377397, 1.1323797306977212, 0.5313650902826339, 0.08018778738914989, 0.029197831790952478, 0.025389833099325188, 0.04578178399242461, 0.318866124143824, 5.1941916067153215, 23.642688542604446, 53.440066426992416, 47.98732101917267, 29.725195057690144, 56.455314829945564, 37.46374391019344, 21.533459722995758, 16.269106306135654, 21.13414864987135, 36.27969704568386, 41.98117710649967, 54.766449853777885, 61.27599835395813, 44.276398345828056, 6.161412606015801, 0.10338750187656842, 0.04030858959595207, 0.03216541503206827, 0.038992854533717036, 0.06479990450316109, 0.012377845087030437, 0.04945264678099193, 0.04697674194176216, 0.03673887040349655, 0.06057476872229017, 0.05784982138720807, 0.05499646023963578, 0.029626451760123018, 0.0502766013960354, 0.07209184681414627, 0.025227423357137013, 0.024573893679189496, 0.037026437785243616, 0.020106391020817682, 0.011747230146283982, 0.053062779625179246, 0.019023658787773456, 0.003709145780703693, 0.03435001948673744, 0.022363994976331014, 0.022889771353220567, 0.044347038128762506, 0.021367880653997418, 0.013779005057585891, 0.05465246365929488, 0.06528336918563582, 0.012659047624765662, 0.06864505325211212, 0.044178470416227356, 0.004473261724342592, 0.13098357303533703, 0.04756099027872551, 0.05398722845711745, 0.014149593716865638, 0.07964328106027097, 0.03336999121529516, 0.03203204738383647, 0.02514735489967279, 0.12446619541151449, 0.055321654508588836, 0.06799145121476613, 0.009548700218147133, 0.006611083508687443, 0.07992617291165516, 0.05463390996737871, 0.018932645507447887, 0.021001339482609183, 0.021346879730117507, 0.0485115589981433, 0.015342830811277963, 0.06192127322719898, 4.311921698972583, 39.18072357773781, 75.41839107871056, 72.07578644156456, 65.37853941321373, 48.77373442053795, 37.27837085723877, 34.38197247684002, 25.227133221924305, 17.77138039469719, 28.972257860004902, 57.70230911672115, 55.070627331733704, 31.24082162976265, 7.937328536063433, 0.3949367953464389, 0.03684371360577643, 0.1461830543121323, 0.568068033317104, 0.4310525511391461, 3.3500059274956584, 3.929742481559515, 6.5263996459543705, 8.600978124886751, 8.2233477383852, 8.080404158681631, 13.084756527096033, 19.333220086991787, 12.172534726560116, 12.299042288213968, 12.58044758811593, 10.290994439274073, 8.835854921489954, 7.583806905895472, 9.338270612061024, 12.91980167850852, 23.184378035366535, 28.50616917014122, 36.57125540077686, 47.98394300043583, 52.07831829786301, 59.04075689613819, 58.7634439766407, 56.29199579358101, 56.42385631799698, 58.322492837905884, 61.09445549547672, 62.09479361772537, 61.312328204512596, 61.612930074334145, 64.359350502491, 65.97427144646645, 67.91502490639687, 64.09740775823593, 63.93174424767494, 66.22296810150146, 65.48563286662102, 63.597092404961586, 58.76307159662247, 38.362304493784904, 39.74808633327484, 34.69604082405567, 44.480546191334724, 62.05435238778591, 59.518011286854744, 62.71958649158478, 58.003332763910294, 62.74761378765106, 60.823575630784035, 67.14309632778168, 65.04220426082611, 64.47842851281166, 57.65144884586334, 55.87862737476826, 55.44417388737202, 57.94599764049053, 55.736834183335304, 67.27779909968376, 62.29872867465019, 60.003891214728355, 60.92963173985481, 60.5178402364254, 62.251121029257774, 65.95316737890244, 53.89513000845909, 52.289453968405724, 42.51035951077938, 40.32722465693951, 33.35855819284916, 22.62650717049837, 20.45224104076624, 9.163885619491339, 5.333970906212926, 4.208771483972669, 4.354762025177479, 5.253082271665335, 7.555923527106643, 3.8695109635591507, 1.1519378749653697, 0.8748747920617461, 0.10839550697710365, 0.14141402818495408, 0.03844585458864458, 0.25770888081751764, 5.349553395062685, 24.690054841339588, 47.227927967906, 42.77678981423378, 32.47109301388264, 48.909554332494736, 29.22861110419035, 16.513275504112244, 23.215756751596928, 37.09193766117096, 46.711835861206055, 49.21324923634529, 62.22358010709286, 69.38118383288383, 52.384657859802246, 7.820026455447078, 0.18631042999913916, 0.05060950657934882, 0.008990348196675768, 0.033754390315152705, 0.04254702202160843, 0.02143779282050673, 0.04846472576900851, 0.037542594072874635, 0.024848861248756293, 0.02631806317367591, 0.0069938605520292185, 0.07558428987977095, 0.08121896447846666, 0.012103477729397127, 0.0740169853088446, 0.02957553671876667, 0.048741275968495756, 0.058708493670565076, 0.050101265296689235, 0.06017969011736568, 0.007784147637721617, 0.04142730300372932, 0.02946436856291257, 0.006641705449510482, 0.056686820316826925, 0.029824575503880624, 0.06997311909799464, 0.04183639706752729, 0.03855902839859482, 0.12366711016511545, 0.16893560998141766, 0.15604227839503437, 0.11799283456639387, 0.12075894512236118, 0.10906185911153443, 0.23779594543157145, 0.16664661874528974, 0.11492736390209757, 0.18910066777607426, 0.14249413507059216, 0.09191501943860203, 0.1345053903060034, 0.16922994574997574, 0.2087678632233292, 0.21582886402029544, 0.1975875865900889, 0.12635061226319522, 0.11453537634224631, 0.23491666477639228, 0.1389014723827131, 0.13199844514019787, 0.11348459171131253, 0.19748071732465178, 0.11781342036556453, 0.09750207784236409, 0.09326592858997174, 6.1013606283813715, 49.30034816265106, 85.38017213344574, 80.63863456249237, 75.66103845834732, 55.90902954339981, 42.98180781304836, 39.43911351263523, 32.36623764038086, 28.01778517663479, 56.35092683136463, 77.16739162802696, 66.96731775999069, 38.26071314513683, 11.228432636708021, 0.7598756847437471, 0.37337045883759856, 0.21860225504497066, 0.6869649596046656, 0.2673455496551469, 3.1628039851784706, 5.583251304924488, 10.702693797647953, 15.423577576875687, 14.868914689868689, 19.537324234843254, 13.03473886102438, 31.531403437256813, 23.842301331460476, 24.815239124000072, 24.76217307150364, 14.98405421152711, 17.968255430459976, 16.035031266510487, 20.09992964565754, 22.158478684723377, 36.63719706237316, 34.93724808096886, 42.304532155394554, 52.1149293333292, 55.117235630750656, 62.81099058687687, 63.44287008047104, 59.67057690024376, 59.28602233529091, 57.280258163809776, 59.42752294242382, 61.51390738785267, 61.03105969727039, 64.09464910626411, 64.73913252353668, 68.53218019008636, 70.26978895068169, 67.32715085148811, 64.88962724804878, 67.73751363158226, 68.31720292568207, 67.12184026837349, 62.41812966763973, 43.104108050465584, 44.85436633229256, 40.6148312240839, 50.51043123006821, 62.68164552748203, 61.85133308172226, 64.76035818457603, 57.16158293187618, 64.50405433773994, 60.88755279779434, 72.0265942811966, 66.27485051751137, 64.4765742123127, 58.321721479296684, 57.607280015945435, 55.23742318153381, 57.876275181770325, 57.58144900202751, 68.22309717535973, 64.97145965695381, 63.84152188897133, 64.22906309366226, 64.16758239269257, 66.15389540791512, 69.46436136960983, 55.34464202821255, 54.78405810892582, 45.38451388478279, 46.142280623316765, 41.99752002954483, 28.751630298793316, 28.090068697929382, 16.420870162546635, 9.94578106328845, 7.0308629516512156, 12.210151758044958, 10.882673989981413, 10.320063829421997, 6.30098101682961, 1.5571690304204822, 0.31608746387064457, 0.0986754875339102, 0.15799755550688133, 0.16149489674717188, 0.6774026539642364, 8.231254164129496, 32.338217943906784, 70.23273333907127, 62.90878213942051, 43.75459134578705, 70.72820395231247, 49.923716112971306, 31.56546860933304, 25.973876751959324, 35.23172467947006, 50.218177512288094, 56.88605971634388, 73.54062303900719, 79.42782953381538, 63.47509615123272, 10.491860210895538, 0.26834744901861995, 0.11258267448283732, 0.16215900017414242, 0.17557907849550247, 0.14349441655213013, 0.11125797056593001, 0.14126139809377491, 0.10102488216944039, 0.0997491971065756, 0.15957139839883894, 0.1173980774183292, 0.18068171484628692, 0.15409434854518622, 0.1493704301537946, 0.22108190401922911, 0.09013293733005412, 0.12433221549144946, 0.15589007874950767, 0.10714377844124101, 0.17896352423122153, 0.14417569327633828, 0.15032607887405902, 0.09759511347510852, 0.13936855044448748, 0.17862758366391063, 0.15584504522848874, 0.1640080165816471, 0.08235807210439816, 0.10637174447765574], [0.018427411778247915, 0.02264242652017856, 0.0952790115843527, 0.05436176070361398, 0.041005481107276864, 0.10917983090621419, 0.019697521456691902, 0.027436414784460794, 0.024384484604524914, 0.14219006232451648, 0.025596988780307584, 0.03369045058207121, 0.0568829588155495, 0.028343987178232055, 0.0350220416294178, 0.018511658527131658, 0.033322857416351326, 0.03347394012962468, 0.06457303737988696, 0.08526637073373422, 0.07981027913047001, 0.06838757253717631, 0.051681557451956905, 0.03603859098802786, 0.03357918409164995, 0.02567781979450956, 0.41953418171033263, 17.405068650841713, 57.134186401963234, 68.00074070692062, 63.22380803525448, 53.11756633222103, 36.16009086370468, 22.067912444472313, 14.151550233364105, 30.57633228600025, 41.947727501392365, 49.157821610569954, 43.81711319088936, 24.594368375837803, 10.09208271279931, 0.8527877053711563, 0.07128303201170638, 0.05320007694535889, 0.11985926917986944, 0.20905075507471338, 0.4859971278347075, 2.025536885485053, 4.1960967890918255, 4.566528461873531, 6.851692590862513, 8.82072888314724, 8.374975752085447, 12.778545208275318, 11.691706627607346, 15.482403170317411, 14.435691386461258, 19.856811091303825, 15.600902661681175, 13.8412313349545, 19.09045111387968, 22.236940674483776, 32.64293499290943, 41.98852591216564, 48.68139557540417, 47.58216015994549, 55.904667377471924, 52.42562726140022, 53.16027984023094, 51.50802589952946, 50.14631576836109, 56.90856210887432, 58.85825648903847, 57.539373859763145, 61.78548261523247, 60.593718364834785, 60.10858699679375, 60.65136507153511, 62.039236798882484, 60.037865191698074, 61.45680405199528, 63.06654207408428, 65.05311727523804, 64.58926096558571, 62.29840189218521, 63.256520479917526, 42.70659238100052, 33.1670218706131, 26.38228263705969, 52.27457396686077, 60.36711372435093, 57.42984093725681, 56.79351948201656, 60.445127338171005, 61.661981642246246, 63.401756286621094, 63.543359488248825, 60.161195173859596, 66.03417903184891, 60.57145535945892, 59.52844172716141, 53.7531354278326, 55.977095291018486, 58.82742494344711, 59.4598364084959, 61.14546775817871, 56.08266122639179, 53.403440192341805, 53.774900659918785, 57.08983518183231, 62.52240747213364, 62.433173060417175, 56.42716594040394, 56.03405803442001, 54.72938284277916, 44.24807466566563, 47.24193401634693, 39.76536400616169, 27.379050850868225, 20.589938051998615, 10.44060381129384, 7.589954501017928, 4.1672078892588615, 2.3736062832176685, 3.3400457119569182, 0.9935277595650405, 1.485418549273163, 0.09640499803936109, 0.06098391102568712, 0.05020826814870816, 0.015010958140919684, 0.06605488364584744, 5.183878010138869, 20.026855766773224, 38.54525327682495, 39.478494599461555, 34.99126598238945, 42.84402720630169, 61.58324606716633, 30.42551837861538, 14.984618481248617, 20.774458050727844, 42.237663343548775, 57.510518208146095, 58.94773408770561, 54.979071244597435, 18.462846390902996, 1.211913381703198, 0.07976862238137983, 0.02716692612011684, 0.017110830667661503, 0.006631409542023903, 0.06765844955225475, 0.012726166532956995, 0.053767092613270506, 0.038120166791486554, 0.012764250768668717, 0.029430478389258496, 0.08851331134792417, 0.06768164908862673, 0.05458826417452656, 0.03444171554292552, 0.011405549994378816, 0.02340513910894515, 0.05134807339345571, 0.0385503564029932, 0.09161821231828071, 0.04176243834081106, 0.03098510151176015, 0.02049910031928448, 0.018652497747098096, 0.0454968586564064, 0.052455342884059064, 0.040433968024444766, 0.014150693023111671, 0.03256972966482863, 0.025863683258648962, 0.026393971893412527, 0.1514029351528734, 0.024718187596590724, 0.03576141367375385, 0.06902089909999631, 0.06602964320336469, 0.003174050116285798, 0.01074577236067853, 0.04620082283508964, 0.058948337245965376, 0.03818940916971769, 0.050807723091566004, 0.013083031026326353, 0.043203729946981184, 0.005036583816036, 0.047125601922743954, 0.10890486519201659, 0.014783649439777946, 0.02631634324643528, 0.0251361985647236, 0.04413888425915502, 0.05487948663358111, 0.03799054327828344, 0.08418714700383134, 0.047844720756984316, 0.8020595961716026, 22.277835980057716, 66.56209230422974, 76.87809035181999, 68.71850699186325, 61.696282401680946, 43.69350962340832, 30.7336438447237, 19.140764214098454, 31.71200394630432, 34.504409506917, 48.889753594994545, 45.991348922252655, 30.31047385185957, 8.622202835977077, 0.8258587878663093, 0.06583589070942253, 0.1646264482405968, 0.2825402811868116, 0.5259079299867153, 3.718757852911949, 4.70801766961813, 9.785793498158455, 7.124086674302816, 9.207057002931833, 11.109431572258472, 12.326464466750622, 14.09774037078023, 10.813198518007994, 11.142754834145308, 11.20530802756548, 9.548866711556911, 16.455229818820953, 12.516365926712751, 15.488638635724783, 19.92750819772482, 31.2478094547987, 38.275334760546684, 49.693729653954506, 52.25271753966808, 59.030976220965385, 55.87021462619305, 56.82143658399582, 56.51257395744324, 54.51309084892273, 59.28098760545254, 59.518201276659966, 60.0083027780056, 64.75056231021881, 62.79720492660999, 62.809588462114334, 63.13983254134655, 63.39396670460701, 60.91842234134674, 63.324787616729736, 63.92175078392029, 64.3235032260418, 65.17069816589355, 64.9069695174694, 63.08804132044315, 46.845831871032715, 39.239966198801994, 32.33493112027645, 52.234075739979744, 60.7418230175972, 56.39171004295349, 59.277168810367584, 58.44517685472965, 61.387085393071175, 65.24936154484749, 65.05955412983894, 62.10959382355213, 66.60851061344147, 62.77603626251221, 60.60227170586586, 53.10863301157951, 57.91227824985981, 57.47052915394306, 61.62570498883724, 63.35477940738201, 58.8310157507658, 56.909379065036774, 59.118724912405014, 60.14785408973694, 66.27757877111435, 62.78134077787399, 57.912977412343025, 57.32590891420841, 57.602959647774696, 47.61857360601425, 51.00354216992855, 41.36415861546993, 30.62561374157667, 19.211339727044106, 9.17010398581624, 4.929393790662289, 5.394427562132478, 7.348388163372874, 8.591156601905823, 3.9651905419304967, 3.5920605389401317, 1.5234131854958832, 0.23210316809127107, 0.03837175485386979, 0.04113392089493573, 0.06693294082651846, 4.233612176030874, 21.471124067902565, 36.957972049713135, 45.45091912150383, 36.7324997484684, 40.36185599863529, 47.150199338793755, 27.972077429294586, 20.311080515384674, 30.769569016993046, 48.761434480547905, 66.2179447710514, 66.16532519459724, 66.26191601157188, 23.55508804321289, 1.5132739045657218, 0.06470320266089402, 0.022707078715029638, 0.0676146628393326, 0.03433701705944259, 0.05016218448872678, 0.04156257426075172, 0.02908624246629188, 0.10673820957890712, 0.04025546295451932, 0.0184781858115457, 0.030661777454952244, 0.037686808209400624, 0.05829644214827567, 0.07459380474756472, 0.04622328393452335, 0.012925342271046247, 0.028609407017938793, 0.06865328366984613, 0.009093887074413942, 0.04555140279990155, 0.04328491719206795, 0.04613974037056323, 0.10472096313606016, 0.05449027470604051, 0.05193314551434014, 0.04515050575719215, 0.04611138290783856, 0.010346382805437315, 0.1451777559123002, 0.16679215390468016, 0.31103032117243856, 0.12231932545546442, 0.11416911162086762, 0.14840779040241614, 0.08421479200478643, 0.11069404965383, 0.0885410379851237, 0.2572536771185696, 0.09023702354170382, 0.12769719469361007, 0.21011233795434237, 0.10961346779367886, 0.18992563913343474, 0.12578604568261653, 0.15291279007215053, 0.1550298256915994, 0.13697844900889322, 0.14589609549148008, 0.16448778536869213, 0.1780359583790414, 0.10882136615691707, 0.10177599499002099, 0.16941842157393694, 0.13103066972689703, 1.2790377298370004, 31.421437337994576, 80.33700674772263, 83.77965241670609, 78.1911326944828, 71.32210448384285, 51.3149506598711, 34.1642289608717, 22.606366351246834, 42.930829748511314, 54.572968035936356, 62.45627202093601, 57.12263502180576, 35.738571882247925, 14.159692246466875, 1.2970899674110115, 0.2391956656356342, 0.26376884314231575, 0.363749434472993, 0.2137070192839019, 3.3744186675176024, 7.260013930499554, 13.828281629830599, 15.370719563215971, 16.963935121893883, 18.3288199827075, 17.97638699412346, 21.074896529316902, 22.600474767386913, 24.245134815573692, 21.330833695828915, 25.678773187100887, 22.572785653173923, 21.170582994818687, 26.931410171091557, 28.188361823558807, 39.81398619711399, 49.73244197666645, 55.820289105176926, 57.83223554491997, 64.95224788784981, 61.50833688676357, 60.261540189385414, 59.48922023177147, 56.71099931001663, 58.16615402698517, 60.049819350242615, 60.33059008419514, 66.39165624976158, 64.41662102937698, 65.41584581136703, 67.11877003312111, 67.01131939888, 64.00223806500435, 65.58170691132545, 67.57045939564705, 66.88236191868782, 68.1361198425293, 66.95844143629074, 66.32228717207909, 51.8207985162735, 45.16046650707722, 38.41820329427719, 56.95990115404129, 60.944948717951775, 59.08375158905983, 59.14561986923218, 60.433180779218674, 61.86366342008114, 68.12011510133743, 67.97890707850456, 65.01659363508224, 71.20773062109947, 65.39465814828873, 59.95508663356304, 56.30059853196144, 58.9135929197073, 59.46371600031853, 63.7984474003315, 65.98276019096375, 61.507755517959595, 59.433496221899986, 61.68284252285957, 64.8829548060894, 68.8922868669033, 64.80929955840111, 57.644856199622154, 57.49819926917553, 57.17667952179909, 50.355312153697014, 52.0621083676815, 47.025224044919014, 33.358957171440125, 26.379706375300884, 17.791587710380554, 15.241718385368586, 14.15202520787716, 8.523231446743011, 13.193186558783054, 5.939396219328046, 4.3123415764421225, 0.7990511076059192, 0.1509862786042504, 0.09089126382605173, 0.24937295936979353, 0.3143667499534786, 8.313691690564156, 28.546032831072807, 51.47927664220333, 51.82788133621216, 49.69446301460266, 58.82960982620716, 80.2613528072834, 45.238027945160866, 23.06511003524065, 32.06593215465546, 57.221353724598885, 77.08241298794746, 73.85464578866959, 77.46499925851822, 32.07899585366249, 2.333491360768676, 0.15685396530898288, 0.08596286148531362, 0.15460953261936083, 0.09202109460602514, 0.17760683374945074, 0.13306209119036794, 0.11889323039213195, 0.23615807003807276, 0.2599085768451914, 0.10927825453109108, 0.2109165588626638, 0.10726781358243898, 0.1638565887697041, 0.11293461575405672, 0.0929969445860479, 0.12908000877359882, 0.18191074108472094, 0.15142255753744394, 0.2707722532795742, 0.1286502310540527, 0.1363351257168688, 0.10846917997696437, 0.14838819770375267, 0.1708243164466694, 0.19734681904083118, 0.17956822615815327, 0.07509023474995047, 0.11950506435823627], [0.03493257943773642, 0.05886813705728855, 0.015328824629250448, 0.04261670226696879, 0.03597820985305589, 0.017759464026312344, 0.012852897525590379, 0.0559874351893086, 0.02080684484099038, 0.0048532019081903854, 0.08030658296775073, 0.015569425195280928, 0.011564799115149071, 0.038669786517857574, 0.08145795087330043, 0.049153724539792165, 0.0366240601579193, 0.04549466189928353, 0.06661596213234589, 0.07409448036924005, 0.02938725199783221, 0.06641467683948576, 0.04721401768620126, 0.03971596612245776, 0.06024249436450191, 0.1548529719002545, 7.556399926543236, 47.62360453605652, 68.21393206715584, 63.204064294695854, 60.44989988207817, 40.896760895848274, 23.568389229476452, 27.15679507702589, 25.910199768841267, 29.515805393457413, 25.5169265717268, 32.73002251982689, 32.07193203270435, 14.04514454305172, 1.8159103277139366, 0.016398431980633177, 0.06382612511515617, 0.19021025276742876, 0.14720613457029685, 1.5456130192615092, 2.49106178060174, 4.477267926558852, 4.943155702203512, 4.236935572698712, 4.334070710465312, 5.8212624583393335, 7.150079654529691, 21.057516261935234, 17.371628545224667, 14.283280614763498, 21.652222350239754, 16.567327603697777, 29.71135050058365, 24.19110931456089, 24.604036957025528, 31.40844013541937, 42.69322469830513, 49.143321588635445, 51.95561148226261, 47.74766027927399, 52.03690432012081, 52.541866824030876, 58.78349170088768, 58.201986104249954, 60.81695258617401, 59.87645365297794, 58.77437599003315, 62.90441617369652, 63.330008536577225, 59.23697456717491, 60.95684967935085, 60.1901838183403, 58.591746389865875, 57.5533989071846, 58.903135880827904, 57.38993547856808, 59.54813227057457, 59.900054186582565, 60.49599900841713, 61.175698935985565, 53.0770643055439, 28.275363855063915, 31.090136915445328, 54.86767262220383, 56.56607508659363, 56.39824949204922, 58.79847809672356, 57.859046906232834, 61.359753459692, 60.71265198290348, 58.75385709106922, 58.15166920423508, 60.79820819199085, 62.07613281905651, 59.93870571255684, 59.09720666706562, 52.59182654321194, 57.510996982455254, 58.98933805525303, 60.61977356672287, 57.023764327168465, 48.764196932315826, 50.550519078969955, 56.09485097229481, 59.44331869482994, 61.807886213064194, 58.85207802057266, 58.98488089442253, 59.86124686896801, 65.89263662695885, 67.02346354722977, 59.371358156204224, 50.015940964221954, 38.96197311580181, 26.884357295930386, 9.544299356639385, 3.8218995183706284, 9.617966953665018, 3.871534592472017, 1.3112256838940084, 4.644429506734014, 1.517119298223406, 0.2522693539503962, 0.0374948628450511, 0.02834908758813981, 0.05751497177698184, 0.05455076716316398, 5.103840529918671, 18.590033166110516, 33.69106315076351, 50.382549092173576, 57.598696276545525, 71.37071907520294, 60.13198234140873, 37.131774723529816, 17.6295568048954, 27.56435550749302, 39.806314408779144, 50.57000823318958, 55.71330964565277, 47.21161164343357, 5.945904795080423, 0.015777052140037995, 0.08405152693740092, 0.03854890550428536, 0.008358735067304224, 0.05807892608572729, 0.02255952676932793, 0.010522505581320729, 0.05467007853440009, 0.05269460758427158, 0.003175668693984335, 0.05782905238447711, 0.0362151738954708, 0.0413288868003292, 0.061505648263846524, 0.017233646831300575, 0.04237684384861495, 0.029382012435235083, 0.07441677284077741, 0.0812001881422475, 0.09646819191402756, 0.04839927947614342, 0.055000790671329014, 0.06782373326132074, 0.05070774466730654, 0.12622279959032312, 0.025275648113165516, 0.06001875539368484, 0.05135487146617379, 0.045711354177910835, 0.033340999216306955, 0.024959593392850365, 0.08760193173657171, 0.0495256221620366, 0.024129933517542668, 0.03323882403492462, 0.11676405323669314, 0.031231570610543713, 0.02466316662321333, 0.04462851989956107, 0.06897877479786985, 0.004209524240650353, 0.04388787136122119, 0.05698585759091657, 0.030266917783592362, 0.025655492281657644, 0.0386612815054832, 0.020236404161551036, 0.052382278445293196, 0.032689749787095934, 0.010904835016845027, 0.03294689653557725, 0.021678447192243766, 0.06365934226778336, 0.024261811304313596, 9.174835681915283, 53.22624810039997, 77.12115570902824, 72.33677163720131, 68.80826577544212, 50.738795176148415, 33.75037796795368, 33.70960235595703, 29.664288125932217, 27.539635933935642, 28.457740768790245, 36.480273082852364, 33.30582842230797, 13.027921076864004, 1.6319185006432235, 0.049288884474663064, 0.09992277802666649, 0.38374508963897824, 1.069772271439433, 3.75190157443285, 6.380660366266966, 6.115319179370999, 10.761325601488352, 8.926560804247856, 12.83200453966856, 11.898021306842566, 10.055441278964281, 10.71389464661479, 10.862703211605549, 12.676253747195005, 14.73889896646142, 18.44653196632862, 21.097191832959652, 22.39751435816288, 25.42167518287897, 32.63961397111416, 44.2822690308094, 54.08673092722893, 56.883852034807205, 56.22585654258728, 57.22961828112602, 57.270823270082474, 60.04850082099438, 60.81774294376373, 62.23766975104809, 60.345758870244026, 59.046684578061104, 62.953627333045006, 63.24563406407833, 61.28229841589928, 62.40847818553448, 62.20110051333904, 60.5548008531332, 60.47681003808975, 61.45172372460365, 59.31352525949478, 60.29565095901489, 61.2991277128458, 62.314448431134224, 62.262414023280144, 53.56609806418419, 35.05661107599735, 34.542240276932716, 55.443193539977074, 57.247397527098656, 58.09171222150326, 58.95569086074829, 58.40324990451336, 63.86821165680885, 62.21783101558685, 61.35055035352707, 59.68585968017578, 62.926504388451576, 63.36940482258797, 62.450914308428764, 59.27369959652424, 52.89546065032482, 56.8742423504591, 62.10547864437103, 62.08591729402542, 58.62819783389568, 52.403109669685364, 53.76473240554333, 58.18665012717247, 63.11109848320484, 63.13115380704403, 58.50188881158829, 59.37872976064682, 60.25785058736801, 68.43323349952698, 69.5765009522438, 61.32585167884827, 54.00547228753567, 40.11593699455261, 26.641584523022175, 7.523509366437793, 3.9661279041320086, 8.307793457061052, 5.825899159535766, 5.704714162275195, 6.396262804046273, 3.3403838938102126, 1.1068097152747214, 0.2894582552835345, 0.010847831581486389, 0.07659083508769982, 0.16209642228204757, 4.943254496902227, 19.222454130649567, 31.41443621367216, 49.95805487036705, 58.515393286943436, 68.252834379673, 56.432599648833275, 37.28144109249115, 25.165732316672802, 39.03679110109806, 47.8046952188015, 57.24454768002033, 63.33256959915161, 55.892207846045494, 7.940935017541051, 0.05069585546152666, 0.06303350397502072, 0.05611875450995285, 0.017719848183332942, 0.02101509704516502, 0.02654711777722696, 0.05253586219623685, 0.009891872086882358, 0.008108602542051813, 0.05806658788060304, 0.040565892195445485, 0.0455719973979285, 0.04867350304266438, 0.04452025910723023, 0.014045440711925039, 0.033585009950911626, 0.011135058502986794, 0.04958999976224732, 0.02361917264352087, 0.06257875298615545, 0.04795328954060096, 0.06599492553505115, 0.07180718122981489, 0.018819939250533935, 0.04942758445395157, 0.027483947487780824, 0.07629692976479419, 0.08105307962978259, 0.24732457241043448, 0.11326547260978259, 0.08887025469448417, 0.11564309854293242, 0.1221455738414079, 0.04674312127463054, 0.14236599585274234, 0.1424652655259706, 0.06542379836901091, 0.11589404093683697, 0.14996765123214573, 0.2830712730064988, 0.21513964631594718, 0.13097166898660362, 0.1672455616062507, 0.13161022769054398, 0.13406258047325537, 0.0754933396819979, 0.135154873423744, 0.21961835911497474, 0.1460867829155177, 0.16414221172453836, 0.13930110406363383, 0.11705552431521937, 0.0977592023264151, 0.23868284159107134, 12.18824403360486, 63.752029091119766, 87.47939229011536, 81.15305095911026, 77.52546161413193, 56.71357177197933, 36.43014617264271, 37.49587118625641, 37.10069999098778, 40.35451099276543, 36.32487282156944, 43.99226859211922, 42.2557769715786, 18.677859753370285, 2.958785332739353, 0.12338372849626467, 0.20226568478392437, 0.4669840761926025, 0.8335308730602264, 4.620919218286872, 7.8685759752988815, 14.730753153562546, 13.23628669604659, 11.452339421957731, 12.489840500056744, 15.730973482131958, 13.45282282680273, 29.97873455286026, 25.303908102214336, 20.71918621659279, 27.951195649802685, 25.917185693979263, 37.33386687934399, 33.2378538697958, 34.71438243985176, 39.94417481124401, 54.32959109544754, 59.544047489762306, 64.86402422189713, 59.98697072267532, 60.514724403619766, 58.54552946984768, 62.95681156218052, 61.79618664085865, 63.97231847047806, 60.861007422208786, 60.74096046388149, 64.06626462936401, 67.07039102911949, 61.96523576974869, 64.38414797186852, 64.4302698969841, 63.69684465229511, 62.49791398644447, 63.252557292580605, 61.72422610223293, 63.701734989881516, 64.10521253943443, 65.54927185177803, 63.919630497694016, 57.6629888266325, 39.4770734757185, 40.632439479231834, 57.178898602724075, 58.528563380241394, 58.277488052845, 59.75819259881973, 58.052813708782196, 65.805134922266, 65.08125856518745, 62.86261461675167, 61.60528488457203, 65.9548468887806, 66.44557535648346, 64.90779787302017, 60.00396341085434, 54.094121530652046, 58.920968323946, 63.94162371754646, 65.91953158378601, 61.90013386309147, 54.70906913280487, 56.81700602173805, 61.81463085114956, 66.16121381521225, 64.39769044518471, 59.73736211657524, 60.00563532114029, 60.6915745139122, 67.71124944090843, 72.3094891011715, 64.59464907646179, 55.99456675350666, 44.29698184132576, 33.1792838126421, 15.480302833020687, 10.714064687490463, 19.296647049486637, 12.894324995577335, 7.57086337544024, 11.520624607801437, 3.8614705950021744, 1.171993080060929, 0.21617976628476754, 0.15612864954164252, 0.2346606831997633, 0.3736351086990908, 7.958856280893087, 26.765965148806572, 44.18223179876804, 61.22841350734234, 63.27578544616699, 76.10730171203613, 73.25946852564812, 50.088847652077675, 28.46668168902397, 39.99539226293564, 55.9242857247591, 68.61960589885712, 72.43360564112663, 66.84399157762527, 12.17759795486927, 0.14592159568564966, 0.1347676059231162, 0.18883011041907594, 0.101157318422338, 0.1261230104137212, 0.0990546285174787, 0.15721341711468995, 0.1023630412237253, 0.1293684815755114, 0.14040783920791, 0.160550766158849, 0.12003120253211819, 0.10660702755558304, 0.21471877436852083, 0.15371095505543053, 0.0999411907105241, 0.14124141947831959, 0.22654942469671369, 0.15719196904683486, 0.15034262876724824, 0.19245400268118829, 0.1791863318067044, 0.14675101992907003, 0.07686611992539838, 0.21249127748887986, 0.2093930632690899, 0.19437833223491907, 0.1860928619862534], [0.051847598151653074, 0.03488654030661564, 0.0748448065132834, 0.0689877473632805, 0.050489534696680494, 0.015310113230952993, 0.013961597505840473, 0.03311249194666743, 0.09785754431504756, 0.023992762362468056, 0.03271754321758635, 0.0500832348188851, 0.03840315141133033, 0.027995960736006964, 0.012504866444942309, 0.0857837960938923, 0.06879737906274386, 0.027973104442935437, 0.0553712819237262, 0.04183643417491112, 0.05984446943330113, 0.04800315815373324, 0.07962865332956426, 0.018813423193932977, 0.026009839966718573, 0.6343450862914324, 18.71046580374241, 64.03888329863548, 71.45457297563553, 59.93238665163517, 52.09665611386299, 43.37464593350887, 25.19611168652773, 20.045489966869354, 23.347461484372616, 39.54177260398865, 46.54295392334461, 41.12045109272003, 13.451589792966843, 1.8166986666619778, 0.019385247978789266, 0.07214326280518435, 0.059143321705050766, 0.293498863466084, 0.33311271748971194, 2.3344042617827654, 7.864801352843642, 2.3833864834159613, 12.404191195964813, 8.691306877881289, 12.0165378972888, 13.316147960722446, 16.574266031384468, 11.16965739056468, 12.558006942272186, 26.123366430401802, 23.067294918000698, 27.717040814459324, 37.743982672691345, 37.54247568547726, 42.962645441293716, 45.62521956861019, 49.652859047055244, 49.97142635285854, 54.03614044189453, 58.67464654147625, 63.50728042423725, 61.962385922670364, 60.31035237014294, 55.75833722949028, 57.92925573885441, 56.44340246915817, 60.04784345626831, 59.903268814086914, 59.67599540948868, 57.78766393661499, 54.67231750488281, 51.852823197841644, 53.98844160139561, 54.74402345716953, 56.28502316772938, 56.51139982044697, 60.43347716331482, 59.270781353116035, 58.68525177240372, 59.52119171619415, 61.2366096675396, 31.627447083592415, 32.44203597307205, 61.251143887639046, 56.64801388978958, 57.01108060777187, 56.49824112653732, 58.23266185820103, 60.282944440841675, 60.592251643538475, 56.61372072994709, 54.88233983516693, 55.18451102077961, 61.5502942353487, 59.21836316585541, 58.988160118460655, 61.77362345159054, 60.08216701447964, 57.65752092003822, 59.95627596974373, 58.77826698124409, 46.79791644215584, 48.169635236263275, 56.20118446648121, 59.29417669773102, 61.63683079183102, 56.437083408236504, 55.94428405165672, 58.00938203930855, 62.49648906290531, 63.59048455953598, 61.30271092057228, 63.368983045220375, 56.80353954434395, 39.029856473207474, 20.640583634376526, 8.885957133024931, 5.8625771664083, 6.985510960221291, 5.358852921053767, 4.582238243892789, 5.321992048993707, 2.347022434696555, 0.22490932286018506, 0.03193527503754012, 0.025441347424930427, 0.09289587891544215, 0.22631321393419057, 4.839601758867502, 23.468089811503887, 43.24618622660637, 68.23629006743431, 83.63272190093994, 72.89686918258667, 42.98558481037617, 19.365170672535896, 14.123639781028032, 30.82229308784008, 45.16707435250282, 53.63789901137352, 51.28767192363739, 24.0196568146348, 1.0823207418434322, 0.04370285023469478, 0.009639638356020441, 0.08518494971212931, 0.041118758817901835, 0.031643826223444194, 0.07853750328649767, 0.0016409438262598997, 0.042573609462124296, 0.09398362250067294, 0.029053999860479962, 0.03292839108326007, 0.09311738031101413, 0.037958189350320026, 0.024195127480197698, 0.055898655773489736, 0.018337537694606, 0.005774023029516684, 0.0140459583599295, 0.030834412136755418, 0.04042862827191129, 0.027113523028674535, 0.06177053932333365, 0.03602420445531607, 0.026131930681003723, 0.020567440988088492, 0.05709494958864525, 0.035078519067610614, 0.04387059416330885, 0.009763670714164618, 0.046081997570581734, 0.022287765277724247, 0.0844414513267111, 0.0425858252128819, 0.0158134804587462, 0.07421893111313693, 0.027774258960562292, 0.020445734335226007, 0.07086351077305153, 0.027844772266689688, 0.035035726832575165, 0.026438035056344233, 0.031808894709683955, 0.046017905697226524, 0.029825634919689037, 0.07907457329565659, 0.05745580776419956, 0.01801316720957402, 0.012982726057089167, 0.06058714403479826, 0.014674139056296553, 0.08557905239285901, 0.0267057722521713, 0.8829431247431785, 24.77780543267727, 74.55554857850075, 80.77807947993279, 68.1211106479168, 59.40819337964058, 51.039355248212814, 31.91520944237709, 26.77851017564535, 26.93406242877245, 38.649272695183754, 38.66507224738598, 37.022895365953445, 12.80176766216755, 1.6683065355755389, 0.04864834794716444, 0.027971143317699898, 0.19824553019134328, 1.0899116657674313, 2.26487725507468, 5.270017012953758, 9.968237858265638, 6.178199155256152, 13.215816244482994, 8.51929010823369, 12.446293886750937, 8.933700621128082, 11.604189723730087, 10.526694841682911, 12.89612989872694, 23.564325347542763, 26.4274413138628, 32.00660213828087, 37.43823207914829, 38.668963238596916, 48.07545728981495, 50.72927288711071, 55.77359341084957, 54.21766050159931, 56.93880468606949, 59.2380765080452, 62.42914907634258, 62.35864765942097, 59.51975159347057, 57.451898753643036, 57.3952741920948, 57.338140457868576, 61.350519955158234, 61.08600854873657, 62.54440829157829, 59.263861924409866, 57.52755269408226, 55.85140563547611, 54.53730694949627, 58.184313252568245, 58.133274391293526, 58.8836657255888, 61.93364046514034, 60.02001374959946, 61.57126151025295, 61.254890486598015, 60.44084116816521, 35.642247051000595, 35.15593394637108, 62.12027885019779, 58.101477697491646, 57.83851280808449, 57.15279400348663, 58.24618153274059, 63.25490176677704, 62.672309428453445, 57.47039616107941, 55.7092210650444, 57.334511652588844, 63.65222364664078, 61.73878692090511, 61.007599756121635, 63.10741268098354, 59.84977528452873, 59.21769440174103, 63.44488397240639, 61.69026352465153, 49.72171135246754, 51.37138143181801, 59.10327114164829, 62.3308939486742, 63.547242879867554, 58.065315037965775, 56.29111424088478, 57.75539226830006, 65.05088299512863, 65.47621697187424, 64.65977758169174, 66.57846942543983, 59.542527571320534, 46.042851358652115, 26.502240300178528, 12.397652696818113, 9.442334678024054, 6.547044413164258, 7.512859962880611, 5.603839550167322, 8.178219459950924, 6.4200818259269, 1.2646442209370434, 0.08583285947679542, 0.0869192523532547, 0.02266828108986374, 0.2782966510858387, 4.237995715811849, 21.54599715024233, 49.51876424252987, 73.08390274643898, 87.83078223466873, 76.69949993491173, 43.3164444565773, 22.754750289022923, 19.04019881039858, 39.88909296691418, 54.21309694647789, 61.678461357951164, 59.25603814423084, 28.254406079649925, 1.4045525947585702, 0.033354484039591625, 0.006158536698421813, 0.12111193282180466, 0.034899991733254865, 0.07827749184798449, 0.03178133505571168, 0.06411649781512097, 0.02287750550749479, 0.027763555335695855, 0.020225778462190647, 0.0854370350134559, 0.072023784450721, 0.001809625759960909, 0.026965779979946092, 0.031963231740519404, 0.050351391328149475, 0.08940555097069591, 0.08644426299724728, 0.02593752695247531, 0.01688468528300291, 0.041195908779627644, 0.07143083814298734, 0.08633898192783818, 0.07277937984326854, 0.0374386711337138, 0.03779281287279446, 0.04625446526915766, 0.12552417145343497, 0.0760671311581973, 0.31252343324013054, 0.16304384800605476, 0.10873027495108545, 0.18597763613797724, 0.08599370514275506, 0.21674123068805784, 0.1635893265483901, 0.14322276081657037, 0.1250467775389552, 0.18430361815262586, 0.1514461133047007, 0.12447640736354515, 0.08491097847581841, 0.1531773805618286, 0.13383316778345034, 0.18557221570517868, 0.13654583628522232, 0.1141802067286335, 0.11917428171727806, 0.1755604802747257, 0.18407876224955544, 0.21587067662039772, 0.19356240023626015, 1.5952972532249987, 34.64176453649998, 86.52043014764786, 86.93489670753479, 78.98401334881783, 68.48418116569519, 60.24721495807171, 34.913852736353874, 28.369564600288868, 33.106890097260475, 53.79047602415085, 60.983520448207855, 51.650913432240486, 17.367348074913025, 2.801037272438407, 0.12641287845326588, 0.38448548584710807, 0.29806176549755037, 1.057753397617489, 2.5355108454823494, 7.5627080630511045, 18.133445866405964, 10.383035000413656, 23.475926890969276, 16.736257039010525, 22.649602331221104, 25.36704171448946, 28.71882665902376, 19.389876946806908, 19.428712762892246, 32.95270197093487, 30.013405792415142, 34.74050983786583, 42.26996921002865, 43.14531683921814, 51.446548998355865, 54.329165518283844, 56.77920185029507, 56.86228819191456, 57.576908245682716, 60.41882894933224, 64.41610425710678, 62.857807874679565, 60.55972918868065, 58.696020394563675, 57.663858979940414, 58.41037832200527, 62.99535669386387, 63.84779915213585, 65.8717605471611, 61.21863283216953, 59.40943971276283, 57.60183110833168, 56.88832439482212, 62.05081857740879, 60.373919159173965, 60.697099417448044, 63.81025716662407, 63.45839984714985, 61.742620915174484, 63.517403081059456, 64.05911341309547, 40.39606176316738, 39.68736179172993, 63.20689134299755, 60.90258099138737, 58.828523084521294, 57.98621088266373, 59.74477931857109, 64.06596824526787, 65.48468291759491, 60.86714029312134, 58.1498908996582, 59.861037880182266, 67.17049285769463, 64.7238801419735, 63.21747377514839, 65.9379529953003, 61.73524551093578, 59.66027185320854, 64.33652132749557, 65.48300340771675, 52.93141432106495, 53.36279757320881, 63.10074023902416, 64.02158662676811, 66.03905037045479, 56.966079622507095, 56.44884377717972, 57.894943580031395, 67.33534321188927, 69.74875330924988, 66.96828290820122, 67.23451182246208, 61.21583238244057, 47.52876542508602, 26.369401328265667, 15.724654421210289, 15.37361215800047, 15.814558546990156, 14.633440375328064, 11.520739551633596, 16.1934694647789, 7.039522211998701, 0.6966199446469545, 0.19356786244316027, 0.1445603187312372, 0.16659944783896208, 0.7407161628361791, 6.49624208919704, 31.91789209842682, 54.42259110510349, 77.29131817817688, 88.15762549638748, 78.9825390279293, 53.730515241622925, 28.896712213754654, 24.429694712162018, 44.68793146312237, 62.164683267474174, 71.85459271073341, 69.24167051911354, 35.97399204969406, 1.9944780645892024, 0.14312746905488893, 0.09007141328766011, 0.25991611706558615, 0.15447055804543197, 0.10911412115092389, 0.15096052607987076, 0.11503184345201589, 0.10497053255676292, 0.25475198635831475, 0.15006231958977878, 0.1848920076736249, 0.1991370425093919, 0.11897846605279483, 0.10871645616134629, 0.12486432795412838, 0.1787980252993293, 0.15965520171448588, 0.13829347532009706, 0.08335851685842499, 0.0744558394944761, 0.15905640728306025, 0.17003360262606293, 0.1361303374869749, 0.08622489898698404, 0.17445217177737504, 0.14438488986343145, 0.16231198649620637], [0.028414379885361996, 0.005937590522080427, 0.03937522014894057, 0.023528001656814013, 0.024025394595810212, 0.04854897808399983, 0.010884913917834638, 0.039856758958194405, 0.029047242605884094, 0.05917477763432544, 0.011413464999350253, 0.0515907297085505, 0.06043807996320538, 0.05789689581433777, 0.018868943261622917, 0.036576989441527985, 0.055588085524505004, 0.0638413020351436, 0.006249976249819156, 0.005681266165993293, 0.01121997504014871, 0.08129824069328606, 0.03337600632221438, 0.00862823208080954, 0.03578175223083235, 6.735617369413376, 43.7077284604311, 66.83885425329208, 59.63161379098892, 47.923811227083206, 40.87245360016823, 24.07445177435875, 20.195562914013863, 28.420764952898026, 40.58405287563801, 45.45029975473881, 46.869215816259384, 18.169692121446133, 2.233724151737988, 0.09604933860828169, 0.10435456482809968, 0.09901666766381823, 0.28602692065760493, 0.23912915436085314, 2.297276216559112, 3.19242553319782, 5.22328189574182, 3.3689483860507607, 10.640935711562634, 9.032266382128, 21.146123707294464, 10.410657618194818, 15.491159800440073, 17.655446715652943, 33.604002222418785, 45.4257682710886, 51.968450993299484, 60.89436963200569, 52.14614845812321, 57.339648976922035, 59.02508273720741, 58.7447489798069, 57.42269732058048, 58.59703190624714, 62.06750728189945, 59.03403505682945, 57.79759280383587, 56.150586381554604, 55.40427602827549, 56.12624488770962, 57.692783027887344, 57.4976596981287, 59.32123504579067, 57.94671580195427, 56.32890701293945, 55.33691704273224, 52.67262160778046, 48.82489487528801, 53.72983507812023, 53.67906220257282, 57.27984018623829, 55.95905005931854, 58.28476846218109, 57.58415825664997, 58.85000333189964, 56.07911981642246, 61.20695985853672, 32.77500830590725, 45.35675257444382, 63.99466887116432, 57.948486506938934, 63.418999761343, 58.371939584612846, 58.40917378664017, 56.41450121998787, 59.98453885316849, 55.63454747200012, 50.490904077887535, 49.33206886053085, 52.09002926945686, 54.11557137966156, 58.699356615543365, 57.87337973713875, 57.76345543563366, 59.0487402677536, 59.02454316616058, 59.21049378812313, 47.30178840458393, 45.89608043432236, 55.202248468995094, 57.21315756440163, 57.091301903128624, 56.92528501152992, 55.716486275196075, 60.33367931842804, 64.5854003727436, 61.27685330808163, 62.27294325828552, 59.83380854129791, 66.33234143257141, 58.40089023113251, 40.53418815135956, 26.973753198981285, 26.23268846422434, 6.408660113811493, 5.805364586412907, 5.050961617380381, 4.070715392008424, 2.496508313342929, 1.699331752024591, 0.05269185050565284, 0.05169526120880619, 0.10165058687562123, 0.055447107151849195, 0.33798589662183076, 2.135200663469732, 17.16485694050789, 34.77505758404732, 44.451253563165665, 64.79038417339325, 62.52068616449833, 42.06914998590946, 37.025433629751205, 27.41673342883587, 39.73282255232334, 51.17213152348995, 51.62911780178547, 37.786464393138885, 5.72378296405077, 0.018673459708224982, 0.04908880888251588, 0.07902427794761024, 0.035129081588820554, 0.06003691574733239, 0.0238931809872156, 0.10798739254823886, 0.032438098642160185, 0.046933589765103534, 0.0053008078702987405, 0.10895981380599551, 0.02208105488534784, 0.027718545934476424, 0.05867068866791669, 0.02870677493774565, 0.07236284945975058, 0.02987312680488685, 0.1125746221805457, 0.07927530197775923, 0.0318276524922112, 0.036450193510972895, 0.07395170599920675, 0.05391975610109512, 0.08282200346002355, 0.02953323801193619, 0.018254738133691717, 0.025140243269561324, 0.0210657393472502, 0.019822437898255885, 0.0412581749696983, 0.06992854570853524, 0.008727054610062623, 0.03457222592260223, 0.047756549902260303, 0.019846464929287322, 0.045300820347620174, 0.02194519362092251, 0.034155168614233844, 0.042311994984629564, 0.06772442648070864, 0.025460591314185876, 0.03935977605578955, 0.013801648910884978, 0.030025187297724187, 0.040553932485636324, 0.04601606146025006, 0.06066443871532101, 0.02243029844976263, 0.06061907493858598, 0.02953494680696167, 0.04917032638331875, 0.045215072605060413, 8.295443169772625, 51.38615123927593, 77.65837088227272, 67.17173159122467, 58.7304313480854, 48.52529615163803, 33.56723539531231, 27.341662757098675, 25.735547840595245, 33.6238219588995, 45.584174171090126, 44.45084698498249, 17.282983101904392, 1.9540006178431213, 0.050977693463210016, 0.0859152156044729, 0.11349363849149086, 0.9871074103284627, 2.2795753413811326, 4.845591662451625, 9.912382755428553, 10.852610003203154, 9.342159703373909, 18.263985961675644, 10.837371870875359, 9.398664571344852, 7.213403256610036, 15.949425660073757, 21.263366416096687, 36.48736350238323, 45.541323870420456, 53.37880231440067, 59.103084951639175, 55.296437814831734, 59.48374092578888, 60.512159541249275, 59.9131178855896, 57.07003064453602, 58.39661546051502, 59.85191456973553, 58.855741024017334, 58.38832810521126, 57.038549333810806, 56.04492165148258, 56.76447004079819, 57.0721585303545, 57.577823996543884, 58.574347123503685, 59.61447291076183, 58.014937341213226, 57.222554460167885, 55.222923159599304, 53.011992797255516, 55.967421010136604, 56.52859389781952, 58.2459307461977, 58.16195145249367, 60.128505527973175, 57.872760370373726, 60.897177681326866, 57.873531728982925, 60.49569122493267, 36.73070624470711, 47.22833454608917, 64.2684517800808, 59.13861684501171, 63.324992805719376, 59.5502145588398, 56.61780931055546, 58.01025219261646, 61.51185929775238, 57.63669803738594, 53.339941799640656, 52.81229071319103, 54.48961190879345, 56.43112912774086, 60.149848982691765, 60.09753718972206, 60.807703882455826, 60.4511272162199, 62.35150784254074, 59.997271969914436, 49.98276114463806, 47.49438866972923, 56.64817728102207, 60.81678919494152, 60.53505711257458, 55.701100900769234, 56.140581518411636, 59.92074027657509, 65.18807083368301, 64.096609801054, 64.85675901174545, 62.76862286031246, 70.21444872021675, 61.54770277440548, 44.30882200598717, 28.98682437837124, 16.49771723896265, 5.67048417404294, 9.015898760408163, 8.998783528804779, 6.952685471624136, 5.762852467596531, 4.1855827532708645, 1.7629798804409802, 0.11751349622500129, 0.04737231778563, 0.03891082124027889, 0.35856977803632617, 3.085356066003442, 19.04226779937744, 45.102899596095085, 56.44733905792236, 66.05203807353973, 63.276439011096954, 37.797696590423584, 31.79789263755083, 35.18624871969223, 47.229588478803635, 57.654237896203995, 59.88355927169323, 45.21616771817207, 6.843318790197372, 0.018633112849784084, 0.08842252442263998, 0.03409639422898181, 0.017310037947027013, 0.055933688854565844, 0.010977466226904653, 0.0700392147700768, 0.10085887857712805, 0.05050562074757181, 0.02393613463937072, 0.028513694087450858, 0.003418305991544912, 0.07360560543020256, 0.06226259807590395, 0.034847180504584685, 0.02552740872488357, 0.05895279755350202, 0.04296550796425436, 0.04315280748414807, 0.051558078921516426, 0.03685364354168996, 0.010102324758918257, 0.026464216171007138, 0.10765520724817179, 0.01385766900057206, 0.017512187841930427, 0.056136569764930755, 0.0602501310640946, 0.14944725728128105, 0.13762187620159239, 0.09581665304722264, 0.22347316320519894, 0.20491890725679696, 0.10592425169306807, 0.1558688681689091, 0.09083564727916382, 0.09981086957850493, 0.11080897122155875, 0.19720821554074064, 0.24081408191705123, 0.13050931098405272, 0.22208554000826553, 0.13026612403336912, 0.17635928350500762, 0.18995539925526828, 0.1492730900645256, 0.2362877083942294, 0.1401533864554949, 0.16167624795343727, 0.2314736190601252, 0.11517614664626308, 0.1641428648144938, 11.78523575887084, 63.00187334418297, 83.70253175497055, 76.1011004447937, 66.99787572026253, 55.550761967897415, 36.67756229639053, 29.411757476627827, 39.35468964278698, 54.62764710187912, 60.03741301596165, 60.67385986447334, 24.435637593269348, 3.0090219620615244, 0.24787935748463497, 0.22363702941220254, 0.19069005124038085, 0.8935869473498315, 2.811859091743827, 8.376133739948273, 13.68701471015811, 13.347148597240448, 13.435481507331133, 21.787645183503628, 15.380932465195656, 33.356677293777466, 20.992389656603336, 25.798405967652798, 24.59860324859619, 39.09269370138645, 48.635946214199066, 56.4965046197176, 63.73451963067055, 57.055716812610626, 62.259241193532944, 63.31248387694359, 60.112846568226814, 58.081669360399246, 59.90580327808857, 62.72898718714714, 59.90089774131775, 58.72506983578205, 55.68539634346962, 55.8733456581831, 56.234383285045624, 57.32307806611061, 60.39668373763561, 60.64830623567104, 62.568506598472595, 60.22270627319813, 60.24353675544262, 57.7889596670866, 54.44145709276199, 59.79192338883877, 59.519170224666595, 61.251615062355995, 60.30640058219433, 64.07938912510872, 61.949318423867226, 63.52088749408722, 61.11747846007347, 61.65444664657116, 41.91878065466881, 50.42568817734718, 65.61326041817665, 63.52981701493263, 65.64712420105934, 60.62668539583683, 57.277898490428925, 60.97315840423107, 62.93985307216644, 61.907794252038, 54.54105354845524, 54.524919614195824, 56.71754255890846, 58.93364444375038, 63.01529422402382, 62.52017319202423, 63.7490576505661, 61.448535695672035, 63.90693157911301, 63.09309884905815, 53.673240914940834, 51.53961360454559, 59.91544336080551, 64.25160348415375, 60.1359037309885, 56.769295781850815, 56.12651847302914, 62.787378653883934, 68.58573451638222, 66.16155579686165, 68.93865197896957, 65.81038624048233, 71.56378671526909, 63.073894679546356, 44.7844310849905, 32.919461354613304, 34.5269612967968, 13.89147698879242, 14.257485698908567, 12.988529540598392, 12.349093202501535, 9.321158230304718, 5.078816972672939, 0.7725485390983522, 0.18557395233074203, 0.22437643114244565, 0.4476174060255289, 0.7207928225398064, 4.213718343526125, 24.32925470173359, 47.98699423670769, 56.13058425486088, 70.40702238678932, 71.22923746705055, 55.151536390185356, 47.302932143211365, 39.96835671365261, 55.33318184316158, 65.50380349159241, 69.9460843205452, 52.29704976081848, 8.448720294982195, 0.11770836936193518, 0.2518870588392019, 0.12070880562532693, 0.18884520570281893, 0.13529055286198854, 0.1286540605360642, 0.17200553353177384, 0.1829898831783794, 0.1338873742497526, 0.07044121390208602, 0.16201362828724086, 0.17719725728966296, 0.22367753583239391, 0.14905798598192632, 0.18619437294546515, 0.13429092447040603, 0.10657141931005754, 0.2217299325275235, 0.21628587855957448, 0.1586507642059587, 0.08196528302505612, 0.23661790473852307, 0.19422945741098374, 0.1902681848150678, 0.15541632135864347, 0.1939313070033677, 0.11413528452976607], [0.05013744499592576, 0.04670382826589048, 0.028603300997929182, 0.12079551073838957, 0.09468925651162863, 0.07482664615963586, 0.0046481715526169864, 0.02220824229880236, 0.09541176696075127, 0.043244388507446274, 0.010664893106877571, 0.017935195319296326, 0.03001736506121233, 0.03867120401991997, 0.05031806147599127, 0.03959338187996764, 0.03104143608652521, 0.0783344145747833, 0.047388889943249524, 0.04498679169046227, 0.06272598024224862, 0.06440621742513031, 0.02478346690622857, 0.023734361384413205, 0.335281451116316, 11.343101933598518, 56.21505372226238, 62.94027864933014, 61.03787653148174, 41.79037034511566, 28.35924245417118, 22.48312756419182, 24.367119669914246, 40.68599000573158, 46.792117953300476, 48.635026663541794, 22.6954772695899, 2.759868619032204, 0.08438723743893206, 0.07506941008614376, 0.03495486613246612, 0.1872819458367303, 0.3631705592852086, 2.788539743050933, 3.0210485542193055, 5.915629919618368, 9.201977625489235, 5.934959482401609, 10.117377005517483, 8.64999359473586, 11.205178834497929, 17.45706506073475, 35.98704054951668, 46.889692917466164, 55.438702180981636, 62.31990873813629, 61.409747377038, 56.98885940015316, 61.69937923550606, 62.30915151536465, 63.48221696913242, 60.46477608382702, 61.871627792716026, 57.61199176311493, 59.353856295347214, 58.273513466119766, 59.90151710808277, 58.53008709847927, 57.845242246985435, 56.21976546943188, 55.376180335879326, 54.80627931654453, 59.0033745020628, 57.09913708269596, 54.54229608178139, 51.95250324904919, 49.96373176574707, 47.91664861142635, 52.62169674038887, 53.87073531746864, 57.501968666911125, 57.48288229107857, 59.22289252281189, 57.72758536040783, 58.48868452012539, 55.42653143405914, 59.96393255889416, 32.92378932237625, 46.45697593688965, 60.720194578170776, 57.003997787833214, 60.51429882645607, 57.92326346039772, 58.64032298326492, 56.35007947683334, 58.09228599071503, 55.63474126160145, 51.869553700089455, 49.04289297759533, 49.498659521341324, 50.021070688962936, 50.34341499209404, 58.39915752410889, 58.56145441532135, 59.87569749355316, 58.111387565732, 59.13558080792427, 45.22369131445885, 45.96160791814327, 53.20779249072075, 57.228470742702484, 56.827238872647285, 52.48652659356594, 53.0881293118, 59.14890669286251, 60.23160919547081, 58.697563111782074, 56.18161931633949, 59.16108503937721, 60.02688758075237, 64.46073666214943, 61.999293342232704, 46.35103762149811, 28.41595061123371, 12.88545722141862, 9.552546814084053, 5.616798754781485, 5.230685323476791, 8.974081054329872, 3.3057447150349617, 1.4523178129456937, 0.12673333782004192, 0.0785349280340597, 0.023724409184069373, 0.07105302560376003, 0.4311436868738383, 4.0096023213118315, 22.534960582852364, 33.634119406342506, 50.48061802983284, 40.33875323832035, 65.64002618193626, 75.3776952624321, 33.12684282660484, 31.997691616415977, 51.408235654234886, 51.610240414738655, 50.535160303115845, 14.069486986845732, 0.10308537355740555, 0.04955591291945893, 0.05862017067556735, 0.035093621772830375, 0.02793736261082813, 0.021208320758887567, 0.043014634429709986, 0.02842580524884397, 0.04519312358752359, 0.05571379420871381, 0.05858600219653454, 0.009186856841552071, 0.013057782234682236, 0.027589697965595406, 0.04514630891208071, 0.0032399741667177295, 0.030358556323335506, 0.08762656361795962, 0.06081443789298646, 0.09260514998459257, 0.027243760669080075, 0.012246093465364538, 0.04694659590313677, 0.06497270616819151, 0.01952721897396259, 0.019205171411158517, 0.033111311931861565, 0.017260451350011863, 0.04426796600455418, 0.07952866377308965, 0.04026502552733291, 0.11193952188477851, 0.0631002378941048, 0.010187145744566806, 0.049401130600017495, 0.08155868257745169, 0.08789595580310561, 0.020375914937176276, 0.058325534337200224, 0.01719839852739824, 0.03463138622464612, 0.007262850122060627, 0.034087243548128754, 0.04145996121224016, 0.02373854338657111, 0.07959943497553468, 0.061670497816521674, 0.040252442413475364, 0.12213380337925628, 0.0033903121811817982, 0.03409707700484432, 0.3195368772139773, 15.789119862020016, 66.98693990707397, 71.8881069123745, 67.97976583242416, 50.32731145620346, 40.46464428305626, 30.313015915453434, 25.688458867371082, 37.285313084721565, 45.82032769918442, 46.23231299221516, 23.209981061518192, 3.5431336518377066, 0.03421560912101995, 0.05766973554273136, 0.05466211157909129, 0.5407476774416864, 2.063829330727458, 4.8028273321688175, 7.0365464966744184, 8.778113219887018, 16.003498658537865, 9.49076497927308, 14.285487346351147, 8.076991941779852, 13.076453972607851, 17.903655096888542, 31.531017757952213, 45.33431477844715, 56.12828157842159, 62.00788468122482, 64.48507815599442, 60.884417966008186, 64.66945186257362, 63.60008664429188, 65.60345694422722, 63.92736688256264, 63.54688569903374, 58.47898744046688, 60.4592739790678, 57.45312988758087, 58.239991664886475, 58.27216453850269, 58.03674057126045, 56.63634091615677, 56.11301779747009, 56.37738101184368, 60.85019700229168, 58.85750412940979, 58.41486968100071, 56.44371025264263, 52.90149852633476, 48.71996350586414, 55.5951663851738, 54.49172839522362, 59.70025330781937, 59.94851678609848, 62.02725224196911, 59.72153976559639, 62.00226478278637, 57.84531444311142, 61.456595063209534, 34.79144990444183, 48.54487270116806, 63.76822382211685, 59.022495076060295, 60.349315479397774, 60.05131646990776, 58.931212574243546, 57.23142698407173, 59.359791576862335, 58.199740424752235, 54.2524666339159, 50.78409254550934, 50.74592359364033, 52.323207557201385, 52.764648869633675, 60.68726174533367, 61.72598160803318, 60.66168911755085, 60.5455369502306, 61.9179967045784, 47.409512624144554, 48.10859151184559, 56.12624488770962, 60.61297573149204, 57.56005235016346, 53.00434000790119, 53.272351026535034, 60.96405789256096, 61.81814186275005, 61.98481611907482, 58.0979210883379, 62.060116678476334, 62.8457473218441, 67.67573654651642, 63.40113691985607, 50.34379497170448, 28.987584337592125, 12.90551919490099, 6.040555816143751, 7.121402118355036, 8.848512042313814, 7.920250352472067, 7.761986944824457, 3.8339945068582892, 1.323479670099914, 0.17766386037692428, 0.03840167082671542, 0.06893894373206422, 0.6371309305541217, 4.0946142096072435, 25.00834286212921, 34.12274658679962, 51.97332613170147, 44.795146510005, 57.845755219459534, 67.26009964942932, 37.058731243014336, 38.680134639143944, 57.01225094497204, 59.297980293631554, 58.126791939139366, 17.190604358911514, 0.2876734494930133, 0.06295810919255018, 0.047589681707904674, 0.03628658705565613, 0.024659216542204376, 0.033606409779167734, 0.0349433851079084, 0.05786497233202681, 0.052806593957939185, 0.0886250268376898, 0.03555574599886313, 0.019341032675583847, 0.06515402768854983, 0.03591802167647984, 0.03703349189891014, 0.022310634558380116, 0.0888359229429625, 0.06189283783896826, 0.06944361899513751, 0.05924633551330771, 0.041799007667577825, 0.03722404573636595, 0.028944202822458465, 0.04112829912628513, 0.022543737577507272, 0.002855557208931714, 0.07355407811701298, 0.1505100424401462, 0.10231765889329836, 0.17821119428845122, 0.2503923140466213, 0.23023490037303418, 0.16267179453279823, 0.09287797831348144, 0.0977695627079811, 0.2422678453149274, 0.15763405157485977, 0.07569219073047861, 0.17267747403820977, 0.13928666186984628, 0.11548008580575697, 0.09800822255783714, 0.16934673010837287, 0.13480673194862902, 0.12761386635247618, 0.17943517392268404, 0.10437572345836088, 0.23694961506407708, 0.20365526725072414, 0.09450760844629258, 0.16538475989364088, 0.4746731714112684, 21.46277591586113, 78.92890110611916, 79.68292504549026, 78.11485558748245, 57.779976949095726, 42.93001279234886, 35.99500112235546, 35.467228442430496, 53.96841287612915, 60.4982902854681, 61.43946938216686, 29.858902283012867, 4.62136379443109, 0.223022278805729, 0.18940586858661845, 0.1488073033397086, 0.6898312526755035, 2.1065748995169997, 6.918070754036307, 14.643001612275839, 15.321838986128569, 19.901283904910088, 12.828258890658617, 20.83564806729555, 17.10469476878643, 19.005502872169018, 24.243552200496197, 39.27194148302078, 50.29836840927601, 58.19434851408005, 66.99954763054848, 66.908238530159, 62.21870876848698, 67.21168264746666, 65.78007146716118, 67.406285405159, 64.90684032440186, 64.2119488120079, 58.722371980547905, 59.67754952609539, 59.207978323102, 58.54210585355759, 58.5449481010437, 58.625876158475876, 57.90133863687515, 57.20635212957859, 58.4736867249012, 62.42775455117226, 61.258998066186905, 60.06206229329109, 59.90964487195015, 54.077657014131546, 52.57115565240383, 59.130044505000114, 58.79269860684872, 63.4249996393919, 64.66394975781441, 64.16781038045883, 61.40225037932396, 64.28868189454079, 60.448292568325996, 62.63352490961552, 39.43627506494522, 50.05633279681206, 64.38990846276283, 60.786710008978844, 65.34586116671562, 62.22594358026981, 61.219028010964394, 59.64881166815758, 62.62381263077259, 59.699721336364746, 56.01677656173706, 55.080875381827354, 54.230260625481606, 53.781622499227524, 54.75654758512974, 63.70480902493, 64.5101948082447, 62.21623130142689, 62.38218739628792, 64.73695144057274, 50.45845001935959, 51.18210978806019, 58.18486422300339, 63.094044998288155, 58.535262420773506, 53.17663416266441, 54.14661951363087, 61.48580029606819, 65.65021723508835, 64.82176288962364, 61.22877448797226, 64.33545738458633, 65.62098920345306, 69.73483845591545, 67.3343400657177, 50.62340296804905, 34.27105262875557, 17.415423095226288, 18.619614578783512, 12.875361163169146, 12.652918249368668, 14.322668351233006, 14.335922040045261, 5.777305467054248, 0.7442674285266548, 0.1272148432326503, 0.15419593371916562, 0.11895551884663291, 0.947017720900476, 6.3027407974004745, 33.57694387435913, 48.08826640248299, 61.527495458722115, 49.627708196640015, 74.19335201382637, 82.36565709114075, 42.49291084706783, 44.92613688111305, 66.1282467842102, 67.7048809826374, 67.89211213588715, 22.780281119048595, 0.6385708751622587, 0.12139071317506023, 0.21323752182070166, 0.1479528984054923, 0.10736816679127514, 0.12460938538424671, 0.11096750138676725, 0.14838147384580225, 0.17850646516308188, 0.1450002341880463, 0.13734812760958448, 0.09959583971067332, 0.13389519648626447, 0.13843204913428053, 0.23193873785203323, 0.059292070363881066, 0.15776110725710168, 0.18275965412613004, 0.129494720895309, 0.1326845309813507, 0.1363705558469519, 0.11660829128231853, 0.08459382166620344, 0.2463803082355298, 0.05803479427413549, 0.11614928036578931, 0.16319702728651464], [0.07712011254625395, 0.04501041796174832, 0.057912855700124055, 0.037834673712495714, 0.025656965444795787, 0.040031924363574944, 0.03842078484012745, 0.05268940883979667, 0.033853333443403244, 0.012548624399641994, 0.0238157193234656, 0.07476078055333346, 0.05725149450881872, 0.006934318971616449, 0.03497252182569355, 0.044247712794458494, 0.011383911751181586, 0.08172915389877744, 0.02839481872797478, 0.01971007302927319, 0.0206926617101999, 0.04275138351658825, 0.03213680894987192, 0.09464989299885929, 1.9560223468579352, 35.92992581427097, 59.11236025393009, 59.88672450184822, 47.50488370656967, 40.36311753094196, 18.790177926421165, 18.09607297182083, 24.960839711129665, 34.53268378973007, 50.44292405247688, 32.3600971698761, 5.2094473131001, 0.24742056179093197, 0.04943542524415534, 0.10043387286714278, 0.024378335911023896, 0.45210309501271695, 2.144517763517797, 3.83809519931674, 2.280623847618699, 9.68455458059907, 12.678044401109219, 11.110495515167713, 22.498860619962215, 15.238919835537672, 20.775901973247528, 28.28794877976179, 47.62383632361889, 57.50138349831104, 63.25862556695938, 57.95339584350586, 55.96751220524311, 60.029110461473465, 57.86092780530453, 57.83952355384827, 60.65842129290104, 61.53264798223972, 61.00101850926876, 63.71887966990471, 60.13722985982895, 56.256843879818916, 56.50502376258373, 54.511415138840675, 56.948980540037155, 55.187277272343636, 56.454045698046684, 56.58996440470219, 58.22651758790016, 57.13206231594086, 55.097845271229744, 49.070202112197876, 50.4172146320343, 48.7810680270195, 52.90855474770069, 55.343749076128006, 58.81198637187481, 55.81400044262409, 60.02123348414898, 56.230670884251595, 56.92745469510555, 55.259446799755096, 58.69324654340744, 32.820495665073395, 49.44987773895264, 62.198444455862045, 52.37972192466259, 56.98780685663223, 58.649499490857124, 57.15854689478874, 52.064870819449425, 58.24200555682182, 59.78707864880562, 55.68394862115383, 52.58803054690361, 49.24119673669338, 47.88465432822704, 48.98548565804958, 53.05035933852196, 55.53736008703709, 61.58389203250408, 57.584960013628006, 54.38108213245869, 42.86328837275505, 45.07623642683029, 54.91674318909645, 57.182535007596016, 54.900985434651375, 52.76143044233322, 54.81625758111477, 58.08912456035614, 61.48539371788502, 58.2567335665226, 53.432922810316086, 55.55471755564213, 58.31482484936714, 60.276032611727715, 61.54096193611622, 59.81554672122002, 42.2859625518322, 26.191196590662003, 15.047733094543219, 12.633312251418829, 7.912734830752015, 4.418277041986585, 5.238436432555318, 5.432597938925028, 1.2517808424308896, 0.09681121999165043, 0.05845071609655861, 0.11955829118960537, 0.020642908129957505, 0.1689053006703034, 6.151777748018503, 38.52250009775162, 41.136721819639206, 52.55375258624554, 85.81938296556473, 86.95673793554306, 40.420049875974655, 30.63900612294674, 44.7001364082098, 51.40712231397629, 53.41735124588013, 30.697606578469276, 2.090029399842024, 0.09000577774713747, 0.08541261835489422, 0.08442849342827685, 0.054529300541616976, 0.053335901102400385, 0.04224897922540549, 0.012164436811872292, 0.03263178063207306, 0.03135745369945653, 0.015885587527009193, 0.045639265663339756, 0.05577508818532806, 0.07340514392126352, 0.07325472543016076, 0.060044040365028195, 0.07401303708320484, 0.04850029690715019, 0.07715365019976161, 0.03143372792692389, 0.007586872725369176, 0.05968898949504364, 0.04649975249776617, 0.06272520840866491, 0.06392421477357857, 0.04906790258246474, 0.035757654695771635, 0.08482715289574116, 0.02367045875871554, 0.12453972740331665, 0.013533669589378405, 0.016430468640464824, 0.03837597767414991, 0.008844110780046321, 0.04081214050529525, 0.04646324254281353, 0.018253361449751537, 0.06902318491484039, 0.015488476365135284, 0.06369175185682252, 0.0606302257074276, 0.015270428739313502, 0.01693648719083285, 0.06060094056010712, 0.030145840100885835, 0.024496727019140963, 0.026579197110550012, 0.08084122615400702, 0.022765259382140357, 0.02323501288628904, 0.055820893539930694, 2.4885608023032546, 43.14630098640919, 68.86168330907822, 66.99937283992767, 56.30273401737213, 47.29202292859554, 23.770939260721207, 23.758287839591503, 27.652797661721706, 32.724136635661125, 44.289739429950714, 31.18099194020033, 5.763438586145639, 0.2122961074928753, 0.045086684767738916, 0.11230607604375109, 0.2596055727917701, 1.9949525641277432, 5.207262430340052, 6.239416245371103, 7.488962095230818, 9.024966973811388, 15.297804325819016, 13.94895650446415, 11.310664974153042, 8.694929033517838, 22.39482030272484, 33.60843278467655, 48.0526053160429, 60.39201378822327, 65.05470559000969, 62.51264199614525, 59.87627886235714, 61.13463073968887, 61.736104264855385, 59.61957223713398, 62.969936057925224, 62.82582499086857, 62.10832469165325, 63.349870070815086, 60.02294719219208, 55.784514024853706, 56.66547775268555, 54.51231189072132, 56.85918375849724, 56.07122763991356, 57.38826356828213, 57.669296488165855, 59.61240582168102, 58.653477877378464, 58.15125122666359, 50.973687171936035, 53.21665741503239, 51.5267550945282, 54.76830415427685, 57.14618615806103, 60.705770552158356, 57.947183176875114, 61.005498468875885, 57.63491593301296, 58.98497588932514, 56.92905820906162, 61.262395083904266, 36.24423734843731, 53.478413969278336, 62.56318308413029, 54.96610254049301, 58.27015444636345, 61.16276443004608, 58.984481915831566, 53.776245787739754, 58.981985449790955, 60.861254408955574, 57.85786896944046, 54.92065317928791, 52.256817519664764, 48.871480375528336, 50.404774099588394, 54.64899815618992, 58.220354318618774, 62.27195531129837, 58.75746309757233, 57.3182675242424, 44.21266436576843, 47.618448212742805, 57.23735846579075, 61.40134982764721, 56.355182603001595, 52.592366114258766, 54.43618677556515, 61.177173256874084, 64.81322854757309, 59.84229728579521, 56.10930919647217, 57.142025381326675, 61.327770575881004, 63.09763580560684, 64.508386105299, 62.51041151583195, 46.92677512764931, 27.901260629296303, 12.501843106001616, 6.8428067676723, 8.240852449089289, 8.756518978625536, 6.9649488385766745, 8.027739934623241, 4.618719136342406, 0.3365522751118988, 0.3267227369360626, 0.16877503891009837, 0.07980749607668258, 0.22021445212885737, 6.7300003208220005, 38.62451322376728, 42.283257097005844, 46.940158009529114, 72.12002366781235, 86.91521376371384, 43.14302556216717, 32.712543457746506, 50.59491969645023, 58.25139105319977, 61.79324559867382, 34.51979488134384, 2.241068445146084, 0.02156523256417131, 0.06125141815573443, 0.08066117370617576, 0.02321925523574464, 0.012772153713740408, 0.0946529654902406, 0.03166554888593964, 0.04139860415307339, 0.03269837354309857, 0.07560593090602197, 0.04604627800290473, 0.021296875675034244, 0.07684044903726317, 0.02401927558821626, 0.08230258172261529, 0.015848246366658714, 0.08580181543948129, 0.05425407136499416, 0.058208148839185014, 0.0297830170893576, 0.04977775570296217, 0.06076119621866383, 0.13248581351945177, 0.11692856511217542, 0.030573550939152483, 0.04175260117335711, 0.18951181758893654, 0.22418906853999943, 0.25003543007187545, 0.19964376610005274, 0.08510141356964596, 0.18399733380647376, 0.1217958219058346, 0.1365394241292961, 0.10221130170975812, 0.09924181300448254, 0.2247195556992665, 0.1747603708645329, 0.14187246764777228, 0.15642871469026431, 0.1210047815402504, 0.14351622085087, 0.15110524487681687, 0.23742188815958798, 0.1235645379347261, 0.09895284296362661, 0.1952577178599313, 0.1795360169489868, 0.1550269016297534, 0.22370852791937068, 3.990808529779315, 55.2333801984787, 79.1457250714302, 75.76484128832817, 65.4562908411026, 54.71751227974892, 29.305682368576527, 25.587935261428356, 35.788668394088745, 49.35143642127514, 64.02557641267776, 41.40451245009899, 7.416335167363286, 0.6346212245989591, 0.14280978532042354, 0.4017470986582339, 0.19055257580475882, 2.4267352698370814, 8.765415251255035, 13.255742602050304, 11.756460852921009, 20.9610603377223, 21.26184269785881, 20.685387030243874, 33.21049913764, 23.47721502184868, 26.37539930641651, 35.442822352051735, 51.728467270731926, 62.31750726699829, 68.96152675151825, 63.7747822701931, 60.70626072585583, 64.26319286227226, 63.508226573467255, 62.69161619246006, 66.31300806999207, 65.519580245018, 63.53170931339264, 68.05130079388618, 62.35811188817024, 56.87164708971977, 57.71516002714634, 54.5969295501709, 57.87554942071438, 55.81677049398422, 58.132468834519386, 60.02518147230148, 61.88711196184158, 61.76528289914131, 60.336916744709015, 52.79912821948528, 57.214502692222595, 53.4399676322937, 57.870168909430504, 59.52292822301388, 63.9594903588295, 60.34551948308945, 63.341791704297066, 59.675657227635384, 60.25951109826565, 59.83914725482464, 62.03044407069683, 39.112281650304794, 55.20326301455498, 65.63618838787079, 57.60903552174568, 60.6160269677639, 64.55554157495499, 61.581931337714195, 54.86612610518932, 61.05741888284683, 62.48955063521862, 60.34455433487892, 57.048614993691444, 54.804436415433884, 52.540331706404686, 53.62069733440876, 57.68524803221226, 61.0255765914917, 65.51072672009468, 60.97514569759369, 59.780945777893066, 46.61309435963631, 50.05704715847969, 60.708445608615875, 64.28184986114502, 56.02251045405865, 53.221543952822685, 55.24901255965233, 62.688678950071335, 67.14547500014305, 64.0675337612629, 58.56370009481907, 59.16821725666523, 64.622782766819, 65.40429443120956, 67.35592290759087, 64.84608918428421, 46.08813352882862, 32.02264107763767, 21.175990104675293, 22.96974465250969, 17.678479179739952, 13.363879099488258, 14.349325820803642, 13.07814298197627, 4.723502788692713, 0.32779270608443767, 0.2011538585065864, 0.3783163981279358, 0.16517482115887105, 0.5848080350551754, 9.145795740187168, 51.73657603561878, 53.3794254809618, 62.44779847562313, 89.81321945786476, 90.1641458272934, 50.856687650084496, 42.65054538846016, 60.544678196311, 66.0587029159069, 69.07773971557617, 40.08518144488335, 3.039104947820306, 0.21371438138885424, 0.3348575660493225, 0.24450917582726106, 0.2788983250502497, 0.13321752659976482, 0.14559021190507337, 0.1611010983469896, 0.14432030817260966, 0.16555024398257956, 0.10744421466370113, 0.11132690124213696, 0.1342780259437859, 0.15047165856231004, 0.15746119053801522, 0.3368992736795917, 0.18456708057783544, 0.20948250690707937, 0.11489499142044224, 0.25790632178541273, 0.0868316121341195, 0.15523563808528706, 0.1592941171838902, 0.24792816111585125, 0.13840448576956987, 0.15387167455628514, 0.12070145094185136], [0.042472796121728607, 0.030183893723005895, 0.01331430372374598, 0.054498634999617934, 0.040270346726174466, 0.057593335150158964, 0.01576887552801054, 0.02054757183941547, 0.03202671876351815, 0.06773164015612565, 0.019213260820833966, 0.044511520318337716, 0.03421562767471187, 0.03363543888553977, 0.10648328927345574, 0.015646458268747665, 0.018520781377446838, 0.04530324717052281, 0.07301278528757393, 0.011431881393946242, 0.05651035244227387, 0.01277214907531743, 0.026191816432401538, 0.05940487309999298, 10.358391422778368, 56.32343910634518, 65.41104286909103, 54.110635444521904, 42.14662782847881, 32.35962599515915, 28.89275662600994, 30.950237922370434, 34.04413640499115, 52.269406244158745, 38.86239565908909, 9.861485436558723, 0.5990424274932593, 0.13069892971543595, 0.055416775576304644, 0.21491375140612945, 0.5484337743837386, 1.0232647857628763, 2.90304493624717, 4.172756066545844, 4.667233508080244, 5.79578910022974, 24.17170375585556, 10.589501671493053, 14.388528317213058, 19.876241348683834, 52.94315569102764, 54.335598573088646, 62.38887503743172, 59.88058403134346, 58.536702543497086, 54.51738081872463, 55.237149596214294, 52.308414950966835, 52.7338021248579, 54.19420816004276, 57.56785333156586, 56.07559360563755, 57.884893119335175, 57.175064608454704, 60.174973234534264, 57.941798865795135, 59.10308875143528, 56.45623438060284, 58.04888091981411, 55.128194242715836, 54.698019325733185, 56.06185354292393, 58.464198634028435, 55.36841355264187, 51.11484579741955, 49.79518041014671, 48.75831484794617, 49.109279215335846, 52.3800715059042, 56.65758177638054, 55.993601605296135, 57.056298181414604, 58.309683725237846, 55.48735097050667, 60.27283698320389, 55.70216864347458, 60.69629766047001, 33.30786511301994, 50.50737999379635, 58.87014605104923, 52.99495451152325, 51.638571694493294, 56.33353516459465, 56.53993248939514, 55.55198170244694, 54.114632830023766, 57.169706895947456, 56.17792211472988, 53.85075978934765, 50.53359858691692, 50.41659526526928, 45.86120590567589, 49.02306564152241, 52.02373042702675, 54.70602169632912, 53.70890200138092, 48.182455748319626, 40.35668447613716, 46.66058041155338, 55.65288528800011, 56.029566675424576, 57.26685248315334, 52.48079650104046, 52.73969940841198, 60.37970244884491, 57.95168973505497, 55.48962704837322, 48.74481797218323, 56.93590544164181, 55.7624714076519, 61.51397958397865, 57.96613655984402, 67.24731713533401, 57.205892354249954, 48.39690864086151, 22.214799262583256, 13.239229638129473, 7.730875639244914, 7.810488967224956, 6.062691053375602, 4.196607386693358, 5.095135672017932, 1.1727436585351825, 0.17553671670611948, 0.15975309099303558, 0.008361368763871724, 0.06407688197214156, 0.3320195636479184, 12.911554221063852, 41.790605932474136, 50.29824301600456, 68.8840489089489, 49.60123881697655, 20.43186843395233, 26.309054866433144, 38.89000877737999, 45.63581719994545, 55.315440595149994, 32.79285974800587, 3.758062468841672, 0.20730035525048152, 0.04842913607717492, 0.051112935034325346, 0.09242915708455257, 0.014330417998280609, 0.026025068837043364, 0.05697601300198585, 0.037720813415944576, 0.05047384569479618, 0.03200027233106084, 0.021224545962468255, 0.04074018186656758, 0.007506198026021593, 0.016005032484827098, 0.06624368601478636, 0.02840580065821996, 0.01217526196342078, 0.05795121360279154, 0.07647275197086856, 0.03077787532674847, 0.0417108182591619, 0.030415868677664548, 0.009206744543917011, 0.0312680916977115, 0.09159320936305448, 0.06413543000235222, 0.11051865789340809, 0.026298921329726, 0.03935164953873027, 0.10598662920529023, 0.02651233517099172, 0.014400603831745684, 0.023520496688433923, 0.059809428930748254, 0.04672457871492952, 0.028823286556871608, 0.04083064595761243, 0.020716493927466217, 0.09132290433626622, 0.027367812508600764, 0.04929109607473947, 0.06157623021863401, 0.052783286810154095, 0.09788319293875247, 0.035967445001006126, 0.0773637744714506, 0.06016371538862586, 0.052003842502017505, 0.13764191418886185, 0.08714620111277327, 14.327994715422392, 64.8308140039444, 74.0195645391941, 61.17044761776924, 48.85424830019474, 39.02153491973877, 32.918218821287155, 28.772648870944977, 25.776844024658203, 46.73615835607052, 38.35911266505718, 10.351567938923836, 0.4795407102210447, 0.0989480412681587, 0.05234526011918206, 0.5300922773312777, 1.7213236656971276, 6.254177978262305, 6.143488017842174, 8.258502501994371, 10.700797699391842, 11.327013596892357, 14.355414994060993, 9.552069939672947, 13.173109386116266, 20.670267641544342, 47.87637457251549, 54.271944388747215, 64.26576912403107, 61.936060935258865, 60.0232207775116, 58.580092415213585, 58.38339976966381, 56.00690469145775, 56.35747008025646, 58.01149472594261, 59.749361872673035, 58.647063821554184, 60.32745525240898, 60.535399094223976, 61.221558675169945, 57.507713958621025, 59.0104915201664, 57.03699141740799, 57.24998898804188, 56.32813185453415, 56.023084223270416, 57.932116985321045, 62.10221841931343, 57.83836841583252, 53.589299619197845, 51.8582759052515, 50.44352062046528, 51.504172906279564, 55.00420309603214, 58.434100449085236, 58.69069688022137, 59.834986478090286, 58.47713313996792, 57.774170860648155, 60.289951264858246, 57.63876512646675, 62.58275583386421, 36.60821221768856, 53.673043325543404, 61.36363685131073, 55.117414221167564, 55.01573547720909, 59.073963314294815, 59.604312255978584, 55.26822432875633, 55.338440760970116, 57.98051118850708, 58.488570526242256, 56.45249158143997, 53.22521075606346, 51.982833221554756, 47.5451235473156, 49.79600876569748, 53.62535588443279, 56.15428738296032, 55.380261316895485, 51.06371574103832, 43.71628940105438, 48.59771266579628, 57.334067076444626, 59.106592163443565, 58.61991807818413, 53.656761199235916, 54.55939516425133, 61.56357832252979, 59.86445389688015, 58.278624191880226, 51.17873936891556, 57.42057703435421, 58.81569877266884, 63.63407962024212, 62.339565083384514, 68.43060404062271, 61.27928137779236, 48.68829980492592, 25.62994010746479, 12.925668563693762, 7.051290655508637, 7.206872832030058, 7.576592043042183, 8.11600349843502, 7.469091536477208, 4.401860497891903, 0.4170653532491997, 0.33956527593545616, 0.05462494111270644, 0.06179142706969287, 0.3118937060935423, 15.407625082880259, 44.32007320225239, 46.768749207258224, 72.4045979976654, 59.14069153368473, 28.904809579253197, 35.59490919113159, 45.85399769246578, 52.68259987235069, 62.374158427119255, 41.48415997624397, 5.481861345469952, 0.16810142114991322, 0.033017292953445576, 0.030009080837771762, 0.06472387147368863, 0.03602253462304361, 0.04636617704818491, 0.09138687746599317, 0.019491991079121362, 0.07183003195677884, 0.03661289454612415, 0.052097471852903254, 0.04130175759200938, 0.04466818398213945, 0.022497639074572362, 0.061645583919016644, 0.046771118795732036, 0.031168833156698383, 0.08986174172605388, 0.059428525346447714, 0.03972907245042734, 0.010272008476022165, 0.009145512722170679, 0.04194658002234064, 0.045828843576600775, 0.04650847644370515, 0.021799309652124066, 0.22197539045009762, 0.19484069023746997, 0.11487212585052475, 0.30398380709812045, 0.13533088116673753, 0.10333898026146926, 0.09885903549729846, 0.2511247247457504, 0.13873037765733898, 0.21402440615929663, 0.10858514055144042, 0.21090076596010476, 0.16763146355515346, 0.1567797060124576, 0.12227153856656514, 0.12572556064696983, 0.1322483114199713, 0.14891203521983698, 0.1909489420359023, 0.15390986547572538, 0.12456010677851737, 0.14778437151107937, 0.17214850086020306, 0.22813741292338818, 18.392531163990498, 75.34872561693192, 82.10455790162086, 71.65921479463577, 56.97283186018467, 44.951264932751656, 41.23276926577091, 40.94448633491993, 49.41850282251835, 68.08042243123055, 50.33946320414543, 13.575107865035534, 1.0040069441311061, 0.2464732844964601, 0.1464457152178511, 0.7786085607949644, 1.4259940129704773, 5.622112769633532, 9.194566123187542, 13.732807952910662, 14.676471166312695, 13.97041680291295, 33.29023785889149, 19.2142940685153, 24.14834450930357, 24.671014063060284, 59.470916613936424, 59.12431061267853, 67.97415733337402, 64.46427047252655, 61.781534627079964, 59.450268521904945, 58.82906645536423, 56.330271139740944, 57.32540734112263, 59.57998976111412, 62.89904326200485, 61.49723768234253, 61.735203713178635, 61.77721045911312, 63.16749885678291, 60.67863620817661, 59.82567697763443, 57.420280650258064, 59.47613373398781, 56.03219993412495, 56.04058228433132, 58.948585242033005, 63.350512236356735, 61.462127566337585, 56.28011383116245, 54.81646656990051, 53.13313029706478, 55.37527598440647, 58.845116794109344, 60.40302939713001, 60.37998743355274, 61.72854267060757, 63.185490891337395, 59.04597021639347, 63.53138253092766, 59.16515462100506, 63.075976967811584, 39.57130081951618, 55.33768840134144, 64.39230993390083, 59.00274373590946, 56.46385297179222, 61.89243547618389, 61.15996018052101, 54.78137165307999, 55.30447818338871, 59.8317414522171, 59.278190955519676, 58.417430743575096, 55.469700917601585, 53.94319362938404, 50.85637606680393, 53.29794265329838, 56.65588706731796, 59.16525341570377, 58.124390468001366, 53.96377332508564, 44.80667509138584, 51.88203223049641, 59.801020100712776, 61.94909043610096, 58.59730549156666, 53.64902101457119, 54.63148109614849, 63.94904851913452, 62.065888568758965, 61.4605126529932, 53.361482843756676, 61.767239794135094, 61.57574526965618, 67.53624603152275, 63.03709365427494, 72.26042613387108, 60.91794736683369, 51.98789834976196, 27.46822826564312, 17.511250153183937, 17.057630494236946, 16.46242093294859, 13.51075641810894, 13.734282273799181, 12.72756714373827, 3.587501496076584, 0.2533787162974477, 0.20924211043165997, 0.2843763248529285, 0.17733664746629074, 0.7005020300857723, 18.78382846713066, 58.057666048407555, 63.529691621661186, 78.38734656572342, 55.58352380990982, 31.353590078651905, 41.93371005356312, 54.83981251716614, 59.96732957661152, 71.58666908740997, 49.46466654539108, 6.684338171035051, 0.3820802742848173, 0.08410003370954655, 0.13461246737278998, 0.22300549142528325, 0.12139174476033077, 0.19110940920654684, 0.16484238352859393, 0.25451740832068026, 0.10060406959382817, 0.18255048722494394, 0.09702947820187546, 0.11707659388775937, 0.08250047540059313, 0.20200697210384533, 0.16452780197141692, 0.17834533005952835, 0.062460855406243354, 0.20025869482196867, 0.1715593840344809, 0.10119713464519009, 0.11541781961568631, 0.11008267581928521, 0.1474081916967407, 0.09674642307800241, 0.22932449297513813, 0.14766672626137733], [0.11563538762857206, 0.023920132080093026, 0.04133137670578435, 0.06820138994953595, 0.06810662511270493, 0.04652671101212036, 0.051084726001136005, 0.06669379115919583, 0.027490107313496992, 0.06458774674683809, 0.07519162696553394, 0.027615955150395166, 0.03815727417531889, 0.04794671411218587, 0.01509768273535883, 0.03425426759349648, 0.05806245040730573, 0.036438129900489, 0.040970997215481475, 0.03110253524937434, 0.035132914781570435, 0.02819595469190972, 0.038638916885247454, 1.1047428636811674, 24.860046319663525, 65.55681064724922, 59.93362918496132, 49.68603506684303, 29.292764961719513, 21.99275817722082, 20.906611159443855, 26.920708045363426, 43.28255407512188, 43.36526423692703, 15.85661944001913, 1.2939206999726593, 0.05844360261107795, 0.07324527046876028, 0.10382185864727944, 0.1737295722705312, 2.562969597056508, 4.207058250904083, 6.442616516724229, 3.55211921967566, 6.725996285676956, 7.962095607072115, 14.452057108283043, 14.471144434064627, 27.78778161853552, 40.02983741462231, 56.39704875648022, 62.334822937846184, 60.82844316959381, 58.42419818043709, 60.05455769598484, 56.435130313038826, 55.933447033166885, 49.96854990720749, 48.415390849113464, 48.94971817731857, 50.324845388531685, 54.27677772939205, 54.093855544924736, 56.80551923811436, 54.70744661986828, 59.05858173966408, 58.02335388958454, 52.17926748096943, 53.56302782893181, 54.17847320437431, 55.769968405365944, 57.34084591269493, 58.14199112355709, 56.32460564374924, 52.94101640582085, 48.06500405073166, 44.40096326172352, 47.426843494176865, 52.97888897359371, 55.77819496393204, 57.56829410791397, 50.948733910918236, 57.08518423140049, 53.46041813492775, 58.77472177147865, 54.152569994330406, 60.01485362648964, 34.56032730638981, 51.07731521129608, 58.544248938560486, 50.6490857899189, 48.56506861746311, 55.85672155022621, 58.16564105451107, 56.73138901591301, 53.45697931945324, 53.1117944419384, 58.12809906899929, 58.274197429418564, 54.20599512755871, 51.215061619877815, 47.424932196736336, 45.53428664803505, 47.79067397117615, 51.38393975794315, 47.274065092206, 44.23566833138466, 41.8066980689764, 46.14132307469845, 54.64902475476265, 58.99020440876484, 55.49461618065834, 51.05596035718918, 55.23032136261463, 58.454885333776474, 59.15667727589607, 53.30048851668835, 47.73664087057114, 56.784532964229584, 61.05450063943863, 61.54791556298733, 62.46909253299236, 59.88688409328461, 61.18289195001125, 55.45272342860699, 46.54392667114735, 28.258716948330402, 16.861010044813156, 9.378060176968575, 5.64179808832705, 8.606027103960514, 5.573203694075346, 1.6249642800539732, 1.72407032456249, 0.20780776161700487, 0.04375351294584107, 0.15794646606082097, 0.11199847809621133, 1.9591046939603984, 24.244792833924294, 45.14022879302502, 33.12420956790447, 21.64980188012123, 16.508155278861523, 21.77583921700716, 38.31286534667015, 44.519752487540245, 56.86497084796429, 51.8995226919651, 10.765019953250885, 0.4140527086565271, 0.06470702472142875, 0.029227332161099184, 0.014433658161578933, 0.06933116135769524, 0.05747068782511633, 0.04904376051854342, 0.07575182971777394, 0.04431555251358077, 0.030226595044950955, 0.01407845700668986, 0.07189283991465345, 0.04407512264151592, 0.01614756565686548, 0.002006299068852968, 0.06497602356830612, 0.05549389956286177, 0.07374270979198627, 0.007259673730004579, 0.08185795362805948, 0.04284155074856244, 0.05199847677431535, 0.04076447236002423, 0.013020505084568867, 0.0672760208544787, 0.010862422204809263, 0.018930749320134055, 0.03097018248809036, 0.05463596942718141, 0.022851198227726854, 0.0727797880244907, 0.022514784541272093, 0.07476229453459382, 0.046282986004371196, 0.018324327465961687, 0.05254069357761182, 0.044616775412578136, 0.006540993690578034, 0.018487646339053754, 0.02009392479521921, 0.028723315554088913, 0.039080687711248174, 0.027262366311333608, 0.016188196386792697, 0.07082433279720135, 0.02641263690748019, 0.06574658065801486, 0.017699851014185697, 0.0673666073998902, 1.4217534405179322, 31.18883091956377, 74.32376101613045, 67.60718062520027, 57.379736825823784, 37.35717482864857, 27.759051360189915, 29.2210229113698, 37.21346653997898, 45.87223671376705, 43.56815814971924, 15.96208468079567, 1.4047037553973496, 0.12891088816104457, 0.014486289419437526, 0.11903434977284633, 0.48409720009658486, 4.492634776979685, 7.6005777809768915, 8.303544335067272, 9.419202469289303, 10.65189242362976, 7.207225738093257, 11.387346759438515, 17.892939671874046, 29.640972577035427, 44.7461823374033, 59.03585135936737, 65.13310298323631, 62.77873411774635, 62.48663619160652, 63.09749901294708, 61.02694071829319, 55.843768045306206, 51.700656563043594, 49.83176864683628, 49.986313953995705, 52.33183689415455, 55.764344707131386, 57.46617838740349, 57.69327700138092, 57.99036405980587, 60.57132236659527, 58.35376895964146, 54.25296440720558, 54.61632750928402, 54.06765975058079, 55.252500772476196, 57.88332760334015, 59.51185941696167, 58.13210025429726, 55.83642303943634, 49.387371093034744, 47.01846040785313, 49.48961980640888, 55.302236303687096, 58.07213567197323, 59.34128277003765, 56.146102622151375, 58.103457391262054, 55.902653485536575, 59.74402695894241, 57.05247178673744, 60.096005871891975, 37.598032504320145, 53.29276353120804, 60.9001225233078, 52.78208613395691, 50.73151856660843, 57.36539639532566, 59.515723809599876, 56.93576104938984, 53.831472024321556, 54.836525693535805, 57.98055298626423, 58.88021931052208, 55.00617899000645, 53.65249402821064, 49.98576678335667, 47.33033247292042, 49.4351801276207, 51.315486431121826, 49.849000722169876, 45.62398083508015, 44.365552961826324, 49.10712853074074, 55.9169977158308, 61.54992565512657, 56.010761484503746, 51.40879042446613, 54.53910045325756, 61.03424772620201, 62.79834866523743, 55.664246678352356, 50.85918411612511, 58.13664861023426, 63.36928702890873, 64.24045488238335, 65.0281298160553, 59.6101563423872, 62.990568950772285, 56.909671649336815, 48.7886144220829, 28.481844775378704, 11.885308139026165, 5.289687607437372, 6.115433648228645, 11.075164061039686, 12.167654838413, 9.219596330076456, 3.771212613210082, 1.2810657522641122, 0.11189796903636307, 0.2196273539448157, 0.06611857475945726, 2.2848603827878833, 25.849494226276875, 43.644404858350754, 42.47064024209976, 29.271406307816505, 20.554256066679955, 26.07559349387884, 44.324135184288025, 50.9601940959692, 62.99868531525135, 60.598304718732834, 13.951976392418146, 0.31997097423300147, 0.0471747024130309, 0.027990017988486215, 0.012558139660541201, 0.0790037724073045, 0.02971061872813152, 0.013571174022217747, 0.03268130785727408, 0.009586024680174887, 0.006570089590240968, 0.021068197711429093, 0.03557998454198241, 0.05041064810939133, 0.028886873769806698, 0.07404503849102184, 0.032817324972711504, 0.029567209821834695, 0.03941913673770614, 0.012192063259135466, 0.02540734963986324, 0.047181867848848924, 0.006682215116597945, 0.03209258065908216, 0.0255102502705995, 0.04961317332345061, 0.0132033517184027, 0.2509455702966079, 0.0994662829907611, 0.11676560432533734, 0.19687643100041896, 0.1319787633838132, 0.11974552762694657, 0.15698919945862144, 0.13238238781923428, 0.13382874458329752, 0.15497843938646838, 0.18557040486484766, 0.06230657032574527, 0.12580088863614947, 0.15098446776391938, 0.12005089170997962, 0.18847885192371905, 0.1608323963591829, 0.08712351365829818, 0.13804328249534592, 0.11784704707679339, 0.12390918389428407, 0.141409486241173, 0.1343675289535895, 2.1619509905576706, 40.11686414480209, 83.97165611386299, 75.48682540655136, 66.43016338348389, 42.75072321295738, 33.507479801774025, 28.835071921348572, 38.41058850288391, 58.19652579724789, 54.65535141527653, 20.47535330057144, 2.0813563652336597, 0.18980153719894588, 0.203638301754836, 0.45263901469297707, 0.6664357299450785, 4.86786131747067, 10.983162447810173, 16.48168209940195, 11.122381277382374, 15.566128827631474, 17.04084489494562, 24.901179112493992, 24.846838228404522, 33.15805435180664, 42.24705643951893, 60.75443834066391, 64.05805706977844, 64.93719309568405, 63.67215737700462, 64.8827800154686, 63.29351529479027, 58.81460063159466, 54.09794792532921, 53.16225953400135, 53.18060874938965, 54.46779727935791, 57.779581770300865, 60.243301168084145, 62.75943495333195, 60.284110978245735, 62.68986068665981, 60.679392367601395, 52.77414456009865, 54.97203782200813, 53.387541845440865, 56.76813304424286, 58.85590821504593, 61.5447161346674, 61.42659567296505, 57.44297683238983, 52.818355187773705, 49.74464692175388, 52.511483654379845, 58.30611191689968, 60.63544772565365, 62.31114260852337, 57.63090714812279, 62.27431118488312, 58.54256182909012, 61.21224157512188, 58.86195369064808, 61.0970963537693, 40.75067013502121, 56.669437140226364, 63.92572537064552, 55.524144396185875, 53.490341529250145, 60.202293768525124, 61.78321413695812, 59.339861646294594, 55.429833456873894, 55.11589050292969, 60.19883215427399, 61.94653697311878, 59.49831314384937, 57.05026790499687, 51.56018950045109, 49.9430038779974, 52.622608691453934, 54.87164720892906, 53.329925537109375, 47.80882939696312, 47.01839581131935, 52.422815412282944, 59.913516864180565, 64.28904667496681, 57.31039434671402, 53.32172177731991, 55.7221669703722, 64.36891838908195, 65.68384543061256, 58.50270576775074, 54.14764165878296, 61.742586717009544, 65.62679529190063, 66.9055862724781, 67.52296194434166, 61.27377547323704, 65.23634344339371, 56.88845358788967, 51.51567108929157, 32.39537447690964, 24.016755670309067, 22.490003295242786, 16.337842717766762, 16.55485477298498, 17.674624286592007, 8.272348009049892, 5.070257456973195, 1.3358345883898437, 0.22973893792368472, 0.40234901010990143, 0.232455124205444, 3.2880863500759006, 34.608687311410904, 59.93744798004627, 44.11720208823681, 29.395992122590542, 25.855718292295933, 33.842074647545815, 52.23040133714676, 60.05008153617382, 68.50466206669807, 70.19250109791756, 18.07201076298952, 0.5821746576111764, 0.12148229419835843, 0.11822099302662537, 0.19100381643511355, 0.28357623028568923, 0.16840924916323274, 0.18044897733489051, 0.1729866082314402, 0.17830341355875134, 0.15888731635641307, 0.1654553975095041, 0.1935543108265847, 0.11899469682248309, 0.20238827273715287, 0.23617960716364905, 0.17512210848508403, 0.1576752556138672, 0.1800874772015959, 0.08652457821881399, 0.1453199959360063, 0.11040251920348965, 0.08825150391203351, 0.17146783269708976, 0.18843080528313294, 0.15761981718242168, 0.1330614381004125], [0.0484236516058445, 0.03819199184363242, 0.010609223681967705, 0.014050892714294605, 0.06974519812501967, 0.03911226609488949, 0.019895070036000106, 0.039712945581413805, 0.022788356873206794, 0.06539457259350456, 0.007319751048271428, 0.024907765509851743, 0.021027533584856428, 0.06248504942050204, 0.040327139577129856, 0.12751456699334085, 0.048651453835191205, 0.03313739471195731, 0.04168408609984908, 0.04998590215109289, 0.05390224883740302, 0.01697597501333803, 0.069028758443892, 3.4976063948124647, 49.97558332979679, 68.93524736166, 62.0641178637743, 46.92164920270443, 27.555199898779392, 19.757721908390522, 29.269612804055214, 41.175095960497856, 37.535503059625626, 29.865975603461266, 4.88792946562171, 0.17709868523525074, 0.12108019116567448, 0.045408313017105684, 0.03708820302563254, 0.89042789186351, 4.471610505133867, 9.912006575614214, 6.277588522061706, 8.206357900053263, 11.904099080711603, 10.43176643550396, 14.716789852827787, 42.85980015993118, 54.985390305519104, 57.0443744212389, 65.54632321000099, 59.43291485309601, 63.17034490406513, 59.72905956208706, 60.3977020829916, 59.608446434140205, 57.579720094799995, 53.51934157311916, 46.0581037402153, 47.401065677404404, 48.91987457871437, 48.201405331492424, 51.49232894182205, 49.75947752594948, 52.411514818668365, 55.99070616066456, 60.542379319667816, 56.11904427409172, 56.665698140859604, 54.66935746371746, 53.64918440580368, 54.097001776099205, 60.35815380513668, 54.362360537052155, 51.44138127565384, 45.804786533117294, 45.31543359160423, 43.45851883292198, 50.58834604918957, 53.579249158501625, 58.34858223795891, 54.14377346634865, 55.79024791717529, 53.07975836098194, 55.635132640600204, 54.74653512239456, 57.97602742910385, 33.403334990143776, 49.74203646183014, 58.78023907542229, 49.87254425883293, 46.537391021847725, 51.37329272925854, 57.5495383143425, 58.44056770205498, 53.63682746887207, 52.722022756934166, 55.59324748814106, 57.110699862241745, 55.77588468790054, 51.634053736925125, 47.74100683629513, 47.26320907473564, 47.55999594926834, 46.39360673725605, 46.50806799530983, 47.08127103745937, 44.44275721907616, 44.78060469031334, 55.66767789423466, 52.96575307846069, 55.27434580028057, 52.379322946071625, 53.21416474878788, 57.78618581593037, 56.875534281134605, 50.60231409966946, 48.75210218131542, 58.611186146736145, 60.570900589227676, 61.083892062306404, 58.668836653232574, 61.790213361382484, 60.50470054149628, 65.0335331261158, 59.620769172906876, 55.68924933671951, 30.512062534689903, 10.66565528512001, 6.081216959282756, 6.957249501720071, 6.6462319158017635, 10.42237713932991, 2.2792592458426952, 0.779060380300507, 0.05443829097202979, 0.016219279386859853, 0.06410446017980576, 0.05054845008999109, 7.189209954813123, 35.510215535759926, 28.451966978609562, 19.82205055654049, 28.537471890449524, 31.62370428442955, 33.91093075275421, 37.5276754796505, 45.18487259745598, 54.806666895747185, 31.146463192999363, 0.643874203087762, 0.022616221285716165, 0.011025147359760012, 0.006176230890559964, 0.006594786873392877, 0.037622018717229366, 0.014333855997392675, 0.0764154878561385, 0.04447514394996688, 0.06199524308613036, 0.05512134885066189, 0.024897575822251383, 0.019497494104143698, 0.018183389911428094, 0.022777055819460656, 0.0987934296426829, 0.008702833692950662, 0.05378853697038721, 0.012322832462814404, 0.04528698671492748, 0.03100502261077054, 0.013918062195443781, 0.07028626831015572, 0.0750343213439919, 0.015130878073250642, 0.051209536686656065, 0.036830351236858405, 0.020551764973788522, 0.04496773333812598, 0.04463411940378137, 0.020096407279197592, 0.01290591191718704, 0.027998370860586874, 0.02029238807153888, 0.044645900998148136, 0.01855563634308055, 0.03797552592004649, 0.03727366201928817, 0.047804199493839405, 0.05017738738388289, 0.03231138805858791, 0.047986318822950125, 0.046073173434706405, 0.03347336496517528, 0.03656499262433499, 0.030959486284700688, 0.04283717949874699, 0.04661973551264964, 0.052257434363127686, 5.542874671518803, 61.776682287454605, 76.70043468475342, 70.21155327558517, 53.050674721598625, 33.31925310194492, 24.290977455675602, 26.115231066942215, 24.336233027279377, 33.803856298327446, 32.28272572159767, 5.343683185055852, 0.21789745223941281, 0.083420263545122, 0.11333231785101816, 0.467451658914797, 2.53966283518821, 5.789979686960578, 8.191532045602798, 7.406009221449494, 11.455162670463324, 13.03347447887063, 17.207967527210712, 23.071915470063686, 40.43627120554447, 56.515488401055336, 60.20326271653175, 65.72723910212517, 61.586912870407104, 62.95356273651123, 61.149020567536354, 61.59958899021149, 61.060097739100456, 59.780550599098206, 56.00622072815895, 47.829310297966, 48.79678398370743, 50.580617263913155, 50.06007179617882, 54.171853959560394, 52.573602721095085, 55.2802012860775, 57.106128707528114, 61.17348365485668, 56.305542066693306, 56.83404050767422, 55.10189205408096, 54.35773238539696, 56.543553695082664, 61.13804675638676, 57.536235228180885, 52.439040541648865, 48.267521783709526, 47.18700036406517, 44.39212113618851, 51.86407059431076, 55.835716277360916, 61.32050536572933, 56.77783012390137, 59.53343465924263, 54.5410231500864, 57.05589160323143, 54.98388558626175, 59.197566881775856, 35.55124953389168, 52.605125829577446, 60.0947405397892, 52.117368802428246, 46.704445257782936, 53.56514051556587, 59.95270796120167, 60.316500440239906, 53.908072113990784, 53.33498306572437, 57.0271385461092, 58.91880623996258, 56.62023738026619, 52.61758916079998, 51.19136989116669, 49.71421055495739, 48.65282490849495, 48.3788026124239, 48.93075339496136, 48.56259495019913, 46.42729192972183, 48.7074925750494, 57.80257433652878, 54.82180528342724, 56.71309679746628, 53.13561536371708, 52.45985582470894, 59.596492275595665, 59.30700100958347, 52.786258310079575, 50.81339657306671, 61.36102259159088, 62.32093088328838, 61.51978947222233, 61.00186966359615, 62.60774329304695, 62.82166041433811, 66.28187254071236, 62.56111979484558, 57.12716057896614, 30.536949299275875, 11.988260764628649, 3.8814976578578353, 5.682520503178239, 7.949472684413195, 11.08484499156475, 6.688345056027174, 2.3614580975845456, 0.17902351944940165, 0.1393900133552961, 0.06930435498361476, 0.08319534827023745, 7.358280932530761, 39.36540886759758, 38.026638105511665, 25.985112749040127, 30.007489509880543, 36.177037954330444, 40.190595388412476, 44.02599938213825, 52.402228116989136, 61.796061247587204, 39.89421509206295, 1.3032434997148812, 0.09624064201489091, 0.0052906803375663, 0.03200403501978144, 0.09513441895251162, 0.044568220400833525, 0.022096447028161492, 0.034232311154482886, 0.04442694516910706, 0.017884252447402105, 0.07870807850849815, 0.015391020315291826, 0.08966585926827975, 0.017411432017979678, 0.02411478999420069, 0.044491768057923764, 0.03209783506463282, 0.06161546385555994, 0.022718331529176794, 0.0032126206906468724, 0.04613990735379048, 0.04417097843543161, 0.04198710128548555, 0.040588646443211474, 0.014298973201221088, 0.052678053980343975, 0.16133169847307727, 0.08200665033655241, 0.15874740667641163, 0.18811641668435186, 0.1738215540535748, 0.08559653739212081, 0.08779050403973088, 0.15679330215789378, 0.09794516969122924, 0.1627989689586684, 0.1414591062348336, 0.17886392801301554, 0.1449156887247227, 0.20325505669461563, 0.14194340212270617, 0.21723213169025257, 0.13143030140781775, 0.12072960060322657, 0.157577826466877, 0.15365291910711676, 0.12099712257622741, 0.09742162903421558, 0.14364672009833157, 8.409297410398722, 73.05893048644066, 83.62645223736763, 77.93348371982574, 61.845112815499306, 40.54221712052822, 30.355710424482822, 39.9764920771122, 53.83337192237377, 49.178747087717056, 39.63767185807228, 7.749084262177348, 0.505091993836686, 0.41003234626259655, 0.4332150804111734, 0.3107303153956309, 3.541026902385056, 11.32905313745141, 18.42158630490303, 15.517803970724344, 18.351100087165833, 21.4082982391119, 19.955624788999557, 25.90824667364359, 45.82299515604973, 56.33707657456398, 61.39704845845699, 68.76806393265724, 64.20540556311607, 65.4947903752327, 61.05572037398815, 62.4470841139555, 64.29895654320717, 62.405841127038, 57.0560397952795, 49.889080971479416, 51.01691745221615, 54.15000893175602, 51.89851574599743, 56.62757858633995, 54.68914680182934, 58.50713633000851, 59.823837876319885, 64.13675084710121, 57.70198993384838, 58.460889011621475, 55.46047501266003, 54.91692177951336, 57.1473640948534, 64.56856727600098, 60.25928311049938, 54.854962304234505, 51.6595883667469, 50.343213602900505, 47.89193473756313, 53.45957837998867, 59.21952970325947, 63.23627896606922, 60.213263779878616, 61.270591244101524, 57.25193828344345, 58.45476754009724, 58.371517807245255, 61.082049161195755, 38.301762342453, 54.25025515258312, 62.6068427413702, 55.37640832364559, 51.680745631456375, 54.680490866303444, 63.01834926009178, 63.13010886311531, 55.676577016711235, 54.881306290626526, 58.83945889770985, 60.47972448170185, 59.91399183869362, 54.65101584792137, 53.107227087020874, 51.42653167247772, 50.97735397517681, 51.65860801935196, 50.69404877722263, 51.160317957401276, 49.46230687201023, 49.747667759656906, 61.51747539639473, 56.703627705574036, 58.62961135804653, 53.750486969947815, 52.68711403012276, 61.77080400288105, 61.75001911818981, 56.46825693547726, 52.963199615478516, 66.06880277395248, 65.45470252633095, 66.96800172328949, 62.917970046401024, 65.70022255182266, 64.12627100944519, 69.17507529258728, 63.409397676587105, 61.07448376715183, 33.61214138567448, 17.359560392796993, 15.264126732945442, 16.125534810125828, 16.107599772512913, 19.367108568549156, 4.763715080916882, 1.0468334960751235, 0.1649539134814404, 0.26537458354141563, 0.19029349205084145, 0.188542157120537, 10.243391543626785, 48.11371363699436, 42.657255828380585, 29.699658527970314, 38.82234200835228, 43.30348715186119, 47.11403667926788, 53.554903864860535, 59.989596381783485, 68.58726963400841, 46.379186511039734, 2.4306336231529713, 0.33162414736580104, 0.16783945786301047, 0.0800892079132609, 0.19171995925717056, 0.1889593480154872, 0.09650201900512911, 0.11252705051447265, 0.22170633223140612, 0.1481200597481802, 0.13920073601184413, 0.16308147489326075, 0.23013190511846915, 0.1842016915907152, 0.11578650373849086, 0.18079336354276165, 0.056323706012335606, 0.1640763832256198, 0.24655077955685556, 0.16864198667462915, 0.12789030151907355, 0.15772391081554815, 0.10553037165664136, 0.16796443553175777, 0.11267691239481792, 0.18947047996334732], [0.02827009895554511, 0.01649193887715228, 0.03145042253891006, 0.011405487839510897, 0.04688435568823479, 0.03921226678357925, 0.05988132819766179, 0.15631299902452156, 0.036632038245443255, 0.015383088611997664, 0.08028118667425588, 0.1172827031405177, 0.06957703488296829, 0.04774289067427162, 0.05819686077302322, 0.026150384182983544, 0.02684606228285702, 0.082876172818942, 0.012609104796865722, 0.0679132882214617, 0.02188067686802242, 0.013734892727370607, 0.08792038730462082, 12.406852953135967, 57.05327354371548, 65.40999412536621, 49.357409700751305, 34.82591785490513, 24.747864939272404, 19.641142264008522, 38.489225283265114, 81.23228430747986, 57.66763977706432, 13.326870985329151, 0.5270132550504059, 0.03959264715376776, 0.13548095826990902, 0.058230643335264176, 0.4660818027332425, 0.3583044157130644, 4.815407982096076, 6.023042555898428, 6.067802729085088, 14.574933014810085, 31.168477311730385, 15.718763787299395, 41.39700785279274, 59.84475955367088, 55.357150956988335, 63.57284590601921, 56.483057141304016, 58.18533159792423, 58.73440973460674, 60.421348214149475, 59.470084458589554, 60.55507443845272, 59.00368228554726, 58.17782700061798, 48.81140939891338, 43.26075844466686, 45.01882530748844, 46.41633711755276, 46.81498132646084, 49.714267551898956, 54.757900312542915, 57.949079275131226, 56.90346658229828, 55.42516350746155, 56.079670786857605, 56.36578023433685, 54.91355516016483, 55.48074312508106, 57.297038063406944, 54.601059928536415, 51.086905896663666, 45.066831931471825, 42.53788523375988, 42.79491864144802, 43.4343521296978, 48.146593272686005, 52.17586666345596, 54.7244469076395, 56.924490854144096, 52.79158182442188, 53.43874029815197, 52.12988153100014, 59.42294418811798, 30.791085362434387, 46.90956585109234, 58.78353729844093, 49.39962163567543, 44.25257742404938, 45.51517367362976, 55.493909418582916, 54.68492902815342, 56.50601550936699, 51.62341050803661, 54.81453627347946, 56.74094170331955, 54.8159421980381, 51.79192766547203, 50.28699941933155, 48.221969828009605, 49.471794962882996, 49.54997576773167, 49.547274112701416, 49.60242435336113, 46.09984070062637, 46.49019755423069, 53.39574180543423, 57.02769331634045, 53.37747238576412, 52.9212536662817, 52.392246052622795, 56.51556819677353, 59.600926637649536, 50.36561720073223, 48.20306584239006, 58.95909547805786, 55.2378411591053, 58.38683098554611, 60.342130064964294, 59.49354439973831, 59.202924594283104, 58.79403233528137, 59.96416054666042, 59.06896658241749, 56.46085113286972, 33.753999173641205, 12.240305989980698, 9.668291453272104, 11.365867462009192, 13.540565818548203, 10.340894311666489, 6.647181864827871, 0.5476846802048385, 0.06971392402192578, 0.03551981491909828, 0.17565100744832307, 0.43942284886725247, 16.6898026317358, 35.46617969870567, 34.67243269085884, 23.466157615184784, 17.109554708003998, 31.709154099225998, 38.00353154540062, 51.70927830040455, 53.34719941020012, 48.18949677050114, 9.18294919654727, 0.07015357230557129, 0.06597518440685235, 0.04328424925915897, 0.031535724992863834, 0.05679862486431375, 0.08324233363964595, 0.01784668864274863, 0.032553658456890844, 0.09010849098558538, 0.04213824708131142, 0.03653070169093553, 0.024332361717824824, 0.01651905695325695, 0.04097763943718746, 0.04633753385860473, 0.07586839143186808, 0.08447318556136452, 0.04491092564421706, 0.040026554925134405, 0.012315949970798101, 0.067403922585072, 0.0936431103036739, 0.08444978564511985, 0.08756313967751339, 0.030177869339240715, 0.035925947813666426, 0.03616552421590313, 0.06061627333110664, 0.03048794977075886, 0.03418999018322211, 0.051921927952207625, 0.017523318201710936, 0.08552664192393422, 0.1276511073228903, 0.05476380065374542, 0.04725256483652629, 0.0761177456297446, 0.0792441688827239, 0.02925774908362655, 0.04235302461893298, 0.04507337805989664, 0.042550406215013936, 0.0513112257613102, 0.032389580737799406, 0.020810492496821098, 0.035702309032785706, 0.09063359015271999, 0.1110113771574106, 16.848624609410763, 67.41946309804916, 73.85304987430573, 55.47798827290535, 43.79541635513306, 29.974980354309082, 23.975060507655144, 42.37675867974758, 70.05846709012985, 56.355885565280914, 13.032914008945227, 0.7622937799897045, 0.03207091736840084, 0.13616196782095358, 0.3656585648423061, 2.3564490163698792, 5.6823148392140865, 10.153527315706015, 8.644178956747055, 7.928200950846076, 8.098619431257248, 21.13069273531437, 21.391812823712826, 42.70973861217499, 59.04348514974117, 56.8541756272316, 65.05358085036278, 58.77873815596104, 60.75896389782429, 61.2258068472147, 63.324263244867325, 62.12489180266857, 62.5201465934515, 60.7882147282362, 60.353844836354256, 50.664053186774254, 46.113219782710075, 47.81765252351761, 47.88675181567669, 49.41805824637413, 51.71873599290848, 57.048975974321365, 59.577656686306, 58.52683447301388, 56.55954323709011, 57.40112587809563, 58.31931620836258, 55.369728282094, 55.55562190711498, 60.59889368712902, 58.31782288849354, 51.75690874457359, 48.68410483002663, 47.41874612867832, 44.499377980828285, 45.06427466869354, 51.189583986997604, 55.10493569076061, 56.43680602312088, 59.452833384275436, 55.3035282343626, 55.51384314894676, 52.82620556652546, 61.984664127230644, 32.33549349009991, 50.12472152709961, 60.9597185254097, 50.86411625146866, 47.009891867637634, 49.26920123398304, 59.47950795292854, 57.489106357097626, 58.72554861009121, 51.5897823125124, 55.84920555353165, 57.381864711642265, 56.537542417645454, 54.04327265918255, 53.25176753103733, 50.67590855062008, 52.837958335876465, 51.190511137247086, 51.944766864180565, 51.13154210150242, 49.11668501794338, 47.94294320046902, 55.39733000099659, 59.00458283722401, 54.695781245827675, 52.0400657504797, 52.06485942006111, 58.25543023645878, 61.844881027936935, 52.63485163450241, 51.252911388874054, 61.32006838917732, 59.035691767930984, 62.62106917798519, 60.62454991042614, 62.112785652279854, 61.02502182126045, 61.04722782969475, 59.80259321630001, 61.32614426314831, 58.84351707994938, 31.771862134337425, 11.912793014198542, 3.7857271218672395, 6.0820947121828794, 9.2905717715621, 9.787098728120327, 4.954277230426669, 1.7934715817682445, 0.04400978396006394, 0.061997202355996706, 0.1395151246106252, 0.3597852971870452, 19.86293826252222, 38.60285818576813, 29.195009507238865, 24.50136836618185, 25.15824481844902, 39.20174404978752, 42.471593990921974, 57.79432877898216, 59.719126895070076, 57.36278973519802, 12.449479065835476, 0.07435667372192256, 0.06162243262224365, 0.02974654795252718, 0.053857990860706195, 0.046549509788746946, 0.03200384948286228, 0.029525356403610203, 0.05988132077618502, 0.022498034268210176, 0.07646890022442676, 0.01169792092696298, 0.04985864237823989, 0.0432081754115643, 0.03860002463625278, 0.03310479216452222, 0.07141363515984267, 0.03644159201940056, 0.01433286986866733, 0.024361568939639255, 0.08406317865592428, 0.0408789671928389, 0.03956361804739572, 0.05619163341179956, 0.05155844257387798, 0.0243255729219527, 0.14418171951547265, 0.08524656281224452, 0.10147017819690518, 0.09658380367909558, 0.17601195839233696, 0.1340172055643052, 0.15983671619324014, 0.21502014569705352, 0.12612114020157605, 0.14030831720447168, 0.15855950972763821, 0.21141112607438117, 0.1610717983567156, 0.14280997827881947, 0.1941206437186338, 0.16350228746887296, 0.1158719694649335, 0.2265496621839702, 0.15409568441100419, 0.14890358957927674, 0.13669943116838112, 0.24570186651544645, 0.24615551170427352, 23.562309555709362, 78.47208201885223, 81.06240302324295, 66.3894371688366, 50.156172439455986, 36.24919228255749, 29.622613862156868, 50.57737223803997, 92.54601001739502, 71.96792542934418, 19.1578271985054, 1.0879286471754313, 0.14097093633608893, 0.34175775828771293, 0.26650080748368055, 1.899046185426414, 4.922980684787035, 14.632469527423382, 14.06838409602642, 14.142659660428762, 22.291843928396702, 36.54705069959164, 22.012416422367096, 46.353454291820526, 58.74610550701618, 57.41363860666752, 66.20529145002365, 60.10306589305401, 62.01663561165333, 63.31735521554947, 64.27089884877205, 62.38480165600777, 63.8395231962204, 61.70409098267555, 62.091768980026245, 53.37151050567627, 47.7517906576395, 50.48757925629616, 50.70830941200256, 53.02534908056259, 55.30805379152298, 59.687379598617554, 62.55260445177555, 59.80846390128136, 57.12882108986378, 58.60734835267067, 59.50325287878513, 58.01800757646561, 57.9402257502079, 62.34997272491455, 58.874436020851135, 55.03840506076813, 51.72341734170914, 49.041620045900345, 46.15042358636856, 47.3670195043087, 53.248093128204346, 57.25835233926773, 59.271552711725235, 62.66259714961052, 58.29608425498009, 59.1528432816267, 54.62092526257038, 62.177545577287674, 34.893907606601715, 52.139776200056076, 63.082227632403374, 54.1591702401638, 48.67207467556, 51.84181898832321, 61.18090845644474, 59.99702878296375, 60.1511637121439, 52.57557101547718, 56.33835330605507, 58.741340562701225, 58.43095801770687, 56.97995647788048, 56.016677767038345, 52.984774857759476, 54.90955017507076, 54.035920053720474, 53.931269869208336, 54.49349910020828, 50.85477635264397, 51.16189107298851, 58.52319806814194, 62.47156620025635, 54.55732047557831, 52.199964970350266, 52.478144243359566, 61.725890412926674, 65.02831220626831, 53.97906370460987, 53.53419877588749, 62.90305584669113, 62.38798588514328, 63.3144673705101, 64.5798222720623, 66.25847339630127, 65.13065591454506, 64.1422301530838, 63.61058168113232, 63.37271064519882, 62.47851602733135, 37.92021721601486, 17.668637707829475, 19.74613443017006, 23.472961150109768, 23.868212141096592, 21.964109614491463, 13.460491765290499, 1.1039559496566653, 0.14647688542027026, 0.22097172477515414, 0.4060533957090229, 0.6202138820663095, 24.300796128809452, 50.76521135866642, 46.692000925540924, 35.09522460401058, 25.512959584593773, 44.57114093005657, 53.24035294353962, 67.24094107747078, 66.1858668923378, 66.38917878270149, 15.874901209026575, 0.21876319719012827, 0.175750128692016, 0.11956721180467866, 0.11979614951997064, 0.14412812161026523, 0.12589416175615042, 0.07757804734865203, 0.1436311795259826, 0.3121449676109478, 0.18671216937946156, 0.13342845981242135, 0.13512140256352723, 0.1543505972949788, 0.18032257474260405, 0.18879945972003043, 0.1280664576916024, 0.12721999373752624, 0.14844207762507722, 0.11593672184972093, 0.14435512974159792, 0.15869348222622648, 0.1419764425372705, 0.19019005150767043, 0.19002159882802516, 0.1252680562902242], [0.06119471065176185, 0.08470139597193338, 0.05132757156388834, 0.024217629397753626, 0.05962044473562855, 0.05771270960394759, 0.018700477594393305, 0.03994313010480255, 0.04608171926520299, 0.03476911399047822, 0.04324749068473466, 0.026166666903009173, 0.018099631124641746, 0.07122179740690626, 0.042391820388729684, 0.013770346049568616, 0.023178431547421496, 0.02058050835330505, 0.049442716845078394, 0.06406508924555965, 0.06825903998105787, 0.02934827069111634, 0.6535351253114641, 28.846710696816444, 67.67946794629097, 57.66415536403656, 51.00815512239933, 33.13120499253273, 27.430904768407345, 25.828475654125214, 31.4889445155859, 33.57032082974911, 23.57546254992485, 3.5194549849256873, 0.0893242412712425, 0.09034436036017723, 0.14559280942194164, 0.1156662312860135, 2.3950416455045342, 5.582160763442516, 5.221040491014719, 4.602665472775698, 6.233640080317855, 24.97320804744959, 32.36002877354622, 52.39584065973759, 64.53446790575981, 55.72117142379284, 62.14425176382065, 59.10197541117668, 60.54938614368439, 55.476080775260925, 56.98499880731106, 58.733288794755936, 58.469765335321426, 57.20089942216873, 57.07153916358948, 58.00383433699608, 55.31504921615124, 42.925882413983345, 42.619508653879166, 42.874877750873566, 47.042676508426666, 51.3289263099432, 56.322082579135895, 56.72736883163452, 58.88290956616402, 54.621434435248375, 55.025223568081856, 52.32008792459965, 51.010267809033394, 53.94045777618885, 56.40263445675373, 54.083546698093414, 50.72367958724499, 44.01368044316769, 42.141072526574135, 41.58404141664505, 44.74692329764366, 43.30319456756115, 51.368702575564384, 54.20242331922054, 60.1316137611866, 54.79594387114048, 56.924498453736305, 50.17466224730015, 58.27744625508785, 31.113353669643402, 47.4363923817873, 58.072329461574554, 52.33434475958347, 44.84811186790466, 41.95923708379269, 51.77361644804478, 55.73413632810116, 56.63941875100136, 53.26296553015709, 54.26298446953297, 56.06382563710213, 57.62823969125748, 53.803471326828, 53.706625923514366, 51.21424466371536, 51.681285202503204, 53.84141229093075, 53.483558893203735, 54.20107439160347, 51.63867808878422, 48.998803943395615, 50.467261746525764, 56.038348004221916, 56.416435316205025, 49.37472157180309, 52.04950824379921, 56.54430225491524, 54.81987498700619, 53.021279498934746, 42.634445652365685, 52.055386528372765, 58.507520109415054, 57.61768765747547, 59.95884083211422, 57.8694811463356, 56.54440484941006, 56.61533184349537, 59.48413610458374, 59.69905637204647, 57.63989366590977, 53.42052027583122, 31.094901859760284, 10.0090866163373, 2.5822438253089786, 8.70461281388998, 8.557038232684135, 7.71504663862288, 3.2884665671736, 0.32295215176418424, 0.08568806646508165, 0.09009393746964633, 0.05288029664370697, 2.6643569441512227, 34.894146993756294, 51.47159345448017, 41.27991333603859, 27.12930355221033, 28.508376851677895, 31.9828762114048, 47.94152967631817, 47.12212264537811, 57.08856225013733, 27.81099647283554, 1.4501660596579313, 0.05197987113206182, 0.05757117462053429, 0.004508557340159314, 0.010964447101287078, 0.02815241845382843, 0.023414534698531497, 0.029644868154719006, 0.06051698510418646, 0.060333080909913406, 0.03441844179178588, 0.01319526694715023, 0.016015129403967876, 0.060068482998758554, 0.05385472541092895, 0.006023788655511453, 0.04809607504284941, 0.06350332798319869, 0.04659789410652593, 0.07897848001448438, 0.09647022539866157, 0.086447068315465, 0.028407175486790948, 0.03249869871069677, 0.03422663372475654, 0.0529920789267635, 0.036203885829309, 0.01176429675979307, 0.043787443937617354, 0.05011299122998025, 0.03882902172335889, 0.05145246017491445, 0.07395818494842388, 0.0362313304503914, 0.05533818213734776, 0.035406485258135945, 0.0682220958697144, 0.03414282669837121, 0.05864011218363885, 0.006692211381960078, 0.032945464190561324, 0.005231165196164511, 0.018310291598027106, 0.0067594963456940604, 0.07035737347905524, 0.008703770654392429, 0.051060160913039, 1.3867877167649567, 37.15390093624592, 76.84266865253448, 64.7301498055458, 59.14018616080284, 41.81411147117615, 29.972419291734695, 30.089426413178444, 32.806767001748085, 44.27741289138794, 29.29191380739212, 3.74123293440789, 0.1367386759375222, 0.0635101631633006, 0.21131020883331075, 0.9115951310377568, 5.871544210240245, 7.391857355833054, 8.669061921536922, 10.139448121190071, 8.45619734376669, 18.885199427604675, 29.518712237477303, 47.452062740921974, 65.47923400998116, 58.519603461027145, 61.300655230879784, 61.25226482748985, 62.635212019085884, 57.299105152487755, 58.39021660387516, 60.87933383882046, 60.64727269113064, 59.182352498173714, 60.58431386947632, 60.727334395051, 57.09974505007267, 46.36488027870655, 45.03511123359203, 44.77169416844845, 49.395210072398186, 54.63773936033249, 56.86753951013088, 59.151087775826454, 59.27737779915333, 56.0924457013607, 55.370032265782356, 53.134213238954544, 52.579082027077675, 54.87067446112633, 57.21752353012562, 56.448900774121284, 52.26305678486824, 45.92679798603058, 44.900678247213364, 43.41972291469574, 45.968607142567635, 44.686411544680595, 53.97888131439686, 55.963750407099724, 60.85291765630245, 57.54083678126335, 59.75728064775467, 51.019949689507484, 59.937691166996956, 32.82745309174061, 48.484824523329735, 59.695321172475815, 54.550089463591576, 45.84505297243595, 44.37101326882839, 53.231191635131836, 58.44477027654648, 56.64429768919945, 54.35981087386608, 54.72309798002243, 55.32874748110771, 58.666856959462166, 54.484770968556404, 54.97354254126549, 53.45043607056141, 53.81252624094486, 54.634623527526855, 54.913881942629814, 55.98888985812664, 54.2717619985342, 50.38123436272144, 53.081973642110825, 57.44237646460533, 57.835833951830864, 50.29545396566391, 53.7004778534174, 60.70318289101124, 56.39350354671478, 55.38204342126846, 44.85209785401821, 53.919186517596245, 59.38349470496178, 62.471676394343376, 62.5521294772625, 61.434514448046684, 59.523414596915245, 59.89483706653118, 61.861455738544464, 62.794746458530426, 61.750201508402824, 58.76624822616577, 33.39791268110275, 13.187409918755293, 6.143981516361237, 9.551662411540747, 11.674902029335499, 9.019959792494774, 5.19478864967823, 1.2380859022960067, 0.1873316548881121, 0.05069001475931145, 0.11793982295785099, 2.815571492537856, 34.964412823319435, 41.395879313349724, 32.57074646651745, 28.894774317741394, 35.060532465577126, 44.70530413091183, 55.22650636732578, 52.73276098072529, 63.962910175323486, 35.37607133388519, 1.6506188409402966, 0.12440109421731904, 0.043900755044887774, 0.06999765450018458, 0.016719386730983388, 0.02958755208965158, 0.07261541715706699, 0.027895344064745586, 0.0527073725243099, 0.08396502962568775, 0.04737958712212276, 0.04718792377389036, 0.0387635531660635, 0.01475815481171594, 0.05399039371695835, 0.08072353637544438, 0.09441187881748192, 0.019557012492441572, 0.04704436272731982, 0.07925924190203659, 0.014922284481144743, 0.021228644473012537, 0.022759680286981165, 0.02097990069160005, 0.03436143000726588, 0.1591838340391405, 0.16521311597898602, 0.15769164223456755, 0.10165616782614961, 0.1582153610070236, 0.15474843297852203, 0.13768316275672987, 0.1669663656502962, 0.159987639344763, 0.15415710455272347, 0.19947330962168053, 0.12215779701364227, 0.09976451503462158, 0.18807335727615282, 0.07675467903027311, 0.1468310976633802, 0.10564667361904867, 0.23127730615669861, 0.17320687766186893, 0.18095158942742273, 0.11294732132228091, 0.1449841889552772, 2.1455586701631546, 47.817504331469536, 84.48792681097984, 72.90173292160034, 68.51054415106773, 47.07440100610256, 38.89554128050804, 36.90819852054119, 41.513532400131226, 46.07169561088085, 33.73087741434574, 5.085156932473183, 0.3187903360230848, 0.22244157793466002, 0.3690878511406481, 0.6011276843491942, 5.747200632467866, 12.993026599287987, 13.844431713223457, 11.869441140443087, 13.785958550870419, 29.85303159803152, 37.88861811161041, 58.56042467057705, 68.46484780311584, 57.3747742921114, 61.72182843089104, 62.54847787320614, 66.45610839128494, 61.05504021048546, 61.126848757267, 62.79834106564522, 61.57386057078838, 60.1725185662508, 61.513603404164314, 62.42277301847935, 60.17685793340206, 48.0212190002203, 45.94811864197254, 47.026287987828255, 51.32252745330334, 58.062176406383514, 60.15934847295284, 62.00888402760029, 60.65518766641617, 56.55887447297573, 55.52141614258289, 53.87093670666218, 51.713442876935005, 55.36262646317482, 59.17411834001541, 59.69740726053715, 55.957826524972916, 49.57233376801014, 46.30375295877457, 44.86650288105011, 49.31877337396145, 46.78183190524578, 55.77091835439205, 58.418946862220764, 64.32790338993073, 61.09552323818207, 61.96080520749092, 53.04468624293804, 59.97867576777935, 35.21406702697277, 51.545077711343765, 62.555952072143555, 56.9274964928627, 47.928302586078644, 46.61860406398773, 56.178089305758476, 60.26038125157356, 58.36905553936958, 55.230640545487404, 56.66870377957821, 58.31214219331741, 62.26356156170368, 57.48609311878681, 59.27645444869995, 55.69155961275101, 56.94758601486683, 58.82570743560791, 58.595717176795006, 59.09352846443653, 57.2827660292387, 53.46482589840889, 54.6780513972044, 61.568502858281136, 60.59751056134701, 50.34407235682011, 53.069685101509094, 62.921811640262604, 58.681649565696716, 59.71457093954086, 47.411640509963036, 57.35205911099911, 63.12162011861801, 65.61858013272285, 65.26032015681267, 63.51917378604412, 61.64827577769756, 63.352989703416824, 64.54364821314812, 65.00364392995834, 61.510928347706795, 60.36903642117977, 34.8741714656353, 13.645795471966267, 10.321354810148478, 18.329340554773808, 16.283384039998055, 17.16687273234129, 8.624325022101402, 1.1307335877791047, 0.14988916169386357, 0.21758374641649425, 0.22852424997836351, 3.4839207166805863, 47.11182899773121, 69.70562562346458, 55.376925095915794, 37.148007452487946, 39.369478449225426, 44.57752838730812, 62.89048612117767, 60.22614508867264, 71.99352845549583, 42.46927231550217, 2.302972823381424, 0.25092909461818635, 0.17061020684195682, 0.19796087202848867, 0.0952255398442503, 0.13978550385218114, 0.09991853294195607, 0.11867881650687195, 0.26354043977335095, 0.26774375641252846, 0.14046301046619192, 0.1266565700643696, 0.11478263026219793, 0.08373407326871529, 0.09801268286537379, 0.15566305577522144, 0.18260694982018322, 0.18377604021225125, 0.14328579884022474, 0.14707296359119937, 0.27966914931312203, 0.11882098973728716, 0.11494122722069733, 0.11974506749538705, 0.1290010442608036], [0.04079079633811489, 0.0806731593911536, 0.010010367095674155, 0.015725320736237336, 0.08346678878297098, 0.032362117563025095, 0.030882560822647065, 0.03929594393412117, 0.041440446439082734, 0.06591924873646349, 0.014229682583390968, 0.010186374838667689, 0.056077617264236324, 0.062140889567672275, 0.08581639121985063, 0.06695794378174469, 0.004465661668291432, 0.09695412794826552, 0.043072447733720765, 0.04886537790298462, 0.05214054981479421, 0.06717517782817595, 2.455692565999925, 44.5543572306633, 57.72139169275761, 61.0593605786562, 34.45300206542015, 24.678286872804165, 22.425344064831734, 26.76478151232004, 40.828254371881485, 41.45019739866257, 15.850078091025352, 0.1197802007663995, 0.03963930968893692, 0.06459778058342636, 0.18061723705613986, 1.6051486996002495, 5.297973062843084, 8.539456576108932, 11.97647949680686, 16.685734950006008, 27.04307097941637, 28.15645683556795, 42.802142053842545, 62.834507524967194, 60.47261506319046, 62.51835308969021, 57.48024523258209, 62.52004399895668, 55.945777371525764, 53.7822000682354, 50.19474036991596, 58.97372469305992, 60.032959654927254, 57.28607565164566, 58.1335973739624, 57.28873550891876, 53.69569391012192, 44.14821982383728, 40.27370072901249, 41.77652768790722, 48.744035214185715, 53.071786388754845, 56.384475231170654, 58.80924291908741, 58.467979431152344, 54.224686324596405, 53.344630748033524, 52.01296180486679, 50.73327027261257, 53.469769433140755, 55.006228387355804, 52.84029521048069, 49.97639648616314, 41.57009996473789, 40.94233185052872, 41.75385430455208, 43.42651315033436, 43.63980710506439, 49.99230623245239, 51.608610302209854, 57.588835805654526, 54.84697513282299, 55.40696628391743, 49.10994037985802, 58.64012539386749, 35.015778467059135, 45.48016995191574, 59.98116463422775, 49.75763842463493, 46.472289115190506, 40.1943875849247, 47.517818212509155, 53.617950081825256, 58.46655450761318, 54.505935832858086, 53.027169182896614, 52.55410596728325, 55.77667884528637, 54.505377262830734, 53.665987104177475, 52.92040251195431, 54.822223260998726, 55.656175911426544, 53.275687247514725, 53.699311316013336, 53.180426359176636, 51.049603298306465, 49.76977877318859, 53.723398223519325, 54.68861863017082, 53.11695456504822, 50.08778750896454, 57.14661933481693, 56.10834024846554, 52.85449504852295, 43.593510389328, 42.165794000029564, 45.882598757743835, 51.64967089891434, 52.02901594340801, 52.50575356185436, 51.13622345030308, 52.57443107664585, 53.99790309369564, 57.18634620308876, 59.28200975060463, 62.419056817889214, 48.96877035498619, 29.930967316031456, 6.194822788238525, 3.6952321277931333, 7.421699529513717, 1.8843586673028767, 3.57082252856344, 0.8708129881415516, 0.1590431822114624, 0.17013193719321862, 0.06361229010508396, 0.21175637317355722, 8.577647376805544, 42.96424135565758, 30.877530723810196, 44.37884084880352, 36.92040726542473, 20.712570771574974, 39.668203219771385, 38.860172778367996, 54.56483647227287, 49.47399124503136, 7.591523341834545, 0.051703521312447265, 0.07564965824712999, 0.07083705320837907, 0.06452266781707294, 0.06277830165345222, 0.016490213383804075, 0.04290533463063184, 0.05161291250260547, 0.04396144788188394, 0.02378456025326159, 0.029402811123873107, 0.05391986000176985, 0.014794095168326749, 0.0281570290462696, 0.04311997116019484, 0.044620011176448315, 0.10546613877522759, 0.07837868368369527, 0.05708200653316453, 0.05641557276248932, 0.023128490574890748, 0.04265503419446759, 0.046060434469836764, 0.05847739630553406, 0.034508794560679235, 0.02593105542473495, 0.0756406263099052, 0.033742764571798034, 0.052469837028183974, 0.04794365646375809, 0.021648390211339574, 0.08753381742280908, 0.04536750231636688, 0.037250514433253556, 0.05914429762924556, 0.030178648594301194, 0.07991526334080845, 0.05300076947605703, 0.019393554466660134, 0.01748446491546929, 0.0471412835031515, 0.059597393628791906, 0.04566399773466401, 0.02119751508871559, 0.10542637450271286, 0.0672079436480999, 4.504464967176318, 53.261548206210136, 66.48466005921364, 65.97304031252861, 45.320665910840034, 30.134976468980312, 30.880652256309986, 34.578152149915695, 36.46184787154198, 40.21750554442406, 15.83146383985877, 0.01254009805052192, 0.04349330483819358, 0.04023453810077626, 0.6467936933040619, 3.0378636019304395, 8.025323264300823, 11.191277280449867, 10.570761077105999, 9.914572387933731, 20.56992832571268, 30.177089609205723, 46.541069224476814, 62.81287908554077, 63.43148969113827, 63.94771099090576, 57.81386353075504, 62.9608241468668, 59.9603645503521, 55.40363386273384, 53.34379479289055, 61.078481152653694, 61.949687004089355, 58.749487325549126, 58.19360375404358, 59.47384625673294, 58.434176445007324, 46.6134287416935, 42.3922124505043, 43.09535712003708, 51.10729940235615, 55.56180037558079, 59.1655346006155, 61.034627705812454, 58.31536442041397, 54.69206124544144, 54.32183191180229, 53.01537461578846, 51.81724190711975, 54.72909405827522, 57.04887717962265, 55.1064708083868, 53.560014590620995, 43.68565924465656, 43.412233516573906, 43.089068457484245, 45.59157237410545, 46.25685207545757, 52.98172742128372, 54.06464271247387, 60.48704668879509, 56.94711484014988, 58.16184505820274, 49.91098299622536, 58.70283342897892, 36.903836354613304, 47.479117289185524, 62.52607807517052, 51.65481202304363, 49.571326822042465, 43.14865306019783, 49.413946866989136, 53.94846774637699, 60.28337761759758, 55.69252476096153, 52.95580141246319, 54.494350254535675, 58.485131710767746, 57.2719594091177, 55.82810528576374, 54.804865792393684, 56.76935277879238, 58.512828424572945, 56.72639228403568, 57.05436788499355, 55.80948628485203, 53.26639674603939, 51.881412863731384, 56.779072657227516, 56.257588639855385, 52.66876481473446, 49.815007746219635, 59.3498133122921, 58.983246982097626, 54.11312811076641, 45.22553041577339, 44.99590873718262, 49.02214229106903, 54.51315924525261, 54.604301154613495, 54.25869069993496, 53.145000860095024, 54.68172200024128, 56.00129619240761, 58.27803522348404, 60.64212016761303, 64.27026808261871, 52.12647311389446, 30.652303509414196, 8.026870731264353, 7.117956653237343, 12.007472533732653, 6.592544596642256, 7.721705781295896, 3.1958149513229728, 1.0483208787627518, 0.1089055924967397, 0.021937523524684366, 0.12077566570951603, 10.915413983166218, 46.113622561097145, 32.134754061698914, 43.28554071485996, 44.10882733762264, 23.973396196961403, 43.87475609779358, 45.657567232847214, 58.477026745676994, 57.62820169329643, 11.726964935660362, 0.031525431404588744, 0.03734321981028188, 0.011762372741941363, 0.07867680440540425, 0.0451673376664985, 0.04045103371026926, 0.036252500212867744, 0.011510302283568308, 0.030010073460289277, 0.020485023633227684, 0.010561555536696687, 0.05182707405765541, 0.016538581003260333, 0.037822981175850146, 0.07461332323146053, 0.014105180816841312, 0.10564121141214855, 0.024187561284634285, 0.05246341745078098, 0.06212276261067018, 0.09678065092884935, 0.07027723637293093, 0.03143796930089593, 0.08120818849420175, 0.2602046343963593, 0.13016848708502948, 0.15043744555441663, 0.09911492801620625, 0.2023799903690815, 0.18135586695279926, 0.1077230618102476, 0.22808516572695225, 0.1809647848131135, 0.15393030422274023, 0.15710475185187533, 0.16210149857215583, 0.279096775338985, 0.11980596071225591, 0.1325278339209035, 0.17257623025216162, 0.1341366913402453, 0.21732463297666982, 0.2589302777778357, 0.10290526915923692, 0.19862784014549106, 0.1636433252133429, 7.242238484323025, 67.09754437208176, 74.2444820702076, 76.32913380861282, 50.62745735049248, 37.772245556116104, 30.7143921777606, 38.076168447732925, 51.4663041383028, 55.32330997288227, 22.264413200318813, 0.2781617286382243, 0.18855253234505653, 0.1965674155508168, 0.48810230393428355, 4.234400633722544, 13.445512019097805, 14.77280929684639, 19.725644029676914, 26.105492189526558, 34.24722410738468, 35.82957699894905, 51.45785719156265, 66.65581807494164, 64.87332612276077, 65.20327001810074, 58.10620464384556, 65.16740754246712, 60.98293907940388, 57.76725523173809, 55.38838528096676, 62.92689956724644, 64.67350244522095, 59.69849020242691, 61.57734498381615, 60.88282585144043, 59.78701025247574, 49.56205531954765, 43.75441275537014, 45.70272780954838, 53.734649419784546, 58.305283561348915, 61.0290952026844, 63.0557506531477, 60.990363880991936, 55.94444364309311, 54.90224316716194, 53.796570897102356, 52.64305539429188, 55.702157244086266, 59.42217282950878, 57.67682008445263, 56.07436627149582, 46.9584996253252, 44.63853031396866, 47.44399577379227, 47.8220184892416, 48.23471434414387, 55.56657671928406, 56.57752767205238, 62.12145298719406, 59.91815261542797, 60.21506108343601, 52.356771156191826, 58.89007218182087, 39.984688237309456, 50.17275854945183, 65.20251765847206, 54.35603007674217, 52.58085273206234, 45.66737450659275, 51.64755441248417, 57.43674136698246, 62.15506598353386, 57.233566269278526, 53.63417901098728, 53.69574710726738, 57.949960827827454, 59.284502416849136, 56.701636612415314, 57.10232891142368, 57.76060178875923, 60.6519540399313, 58.43582555651665, 57.84068629145622, 59.10556621849537, 56.80585362017155, 55.194804668426514, 59.12203073501587, 56.89401648938656, 53.25864516198635, 50.906149595975876, 61.60367377102375, 63.69382381439209, 55.97500920295715, 48.68739925324917, 47.71008029580116, 50.77049307525158, 55.86673021316528, 58.43666911125183, 58.16361956298351, 56.353715881705284, 57.25819654762745, 58.270021453499794, 62.00310833752155, 64.4525595009327, 67.39129140973091, 55.05112297832966, 33.14293876290321, 10.874115899205208, 10.256380196660757, 19.48859754949808, 9.263120144605637, 9.116316922008991, 4.928771574050188, 0.9680907963775098, 0.2921559027163312, 0.25683293875772506, 0.40889107156544924, 13.620569575577974, 60.205648988485336, 43.15184868872166, 55.664683654904366, 44.339794144034386, 31.355381682515144, 53.08068931102753, 56.27620004117489, 65.1210880279541, 68.90123158693314, 16.574144437909126, 0.3085270867450163, 0.22890256717801094, 0.14206723688403144, 0.17902785359183326, 0.1773234669235535, 0.12574562832014635, 0.1245082454988733, 0.14111274591414258, 0.16984013956971467, 0.10923643450951204, 0.11568609115784056, 0.1126293778361287, 0.09171324432827532, 0.16005876677809283, 0.2105935019790195, 0.15970930428011343, 0.22430678800446913, 0.1695290461066179, 0.16485928965266794, 0.14344583556521684, 0.1142433931818232, 0.18516005657147616, 0.11444838179158978, 0.09693237559986301], [0.07825193228200078, 0.010031030342361191, 0.0307104994499241, 0.046517834925907664, 0.029101510299369693, 0.039974430183065124, 0.01222397653691587, 0.03258410877606366, 0.03313457084004767, 0.030791786884947214, 0.03006668634043308, 0.054231079629971646, 0.02579079879069468, 0.09013674454763532, 0.049169387566507794, 0.06615819802391343, 0.03596186405047774, 0.06689151414320804, 0.03587555227568373, 0.01376985159367905, 0.07443649912602268, 0.11193926955456845, 11.75857923924923, 54.20894376933575, 62.08157032728195, 48.47588360309601, 45.30213810503483, 43.14412750303745, 18.366888239979744, 28.690540976822376, 36.17712914943695, 37.05187261104584, 2.1744269086048007, 0.10889219673117623, 0.01528995835542446, 0.05631014697428327, 0.4652066028211266, 1.7141350451856852, 8.707006685435772, 8.075404576957226, 6.03826928883791, 18.82434569299221, 31.43635343760252, 37.576586455106735, 62.50036485493183, 59.10960540175438, 60.931493639945984, 59.13642056286335, 62.074806690216064, 57.45134398341179, 60.56398116052151, 52.248533964157104, 49.3540620803833, 54.36074182391167, 61.19537428021431, 57.06347979605198, 56.0130375623703, 56.59310303628445, 59.44117560982704, 49.31519776582718, 40.70897117257118, 41.001901254057884, 49.951371029019356, 55.664820447564125, 55.08539713919163, 54.40787449479103, 56.884384006261826, 52.3554640263319, 54.168981313705444, 51.910097524523735, 51.73834294080734, 52.324142307043076, 56.950884237885475, 52.08052217960358, 47.279077023267746, 39.810250997543335, 41.087157279253006, 38.85680615901947, 43.29813323915005, 46.395240649580956, 50.338669046759605, 50.61686731874943, 55.35153105854988, 52.837555557489395, 59.0604018419981, 49.94051121175289, 57.74735189974308, 34.65873062610626, 45.84428921341896, 58.12665514647961, 52.95553542673588, 48.30360844731331, 40.33122584223747, 43.91785338521004, 50.28958708047867, 55.94258934259415, 53.97695101797581, 49.49398197233677, 50.10847359895706, 53.266100361943245, 54.67696465551853, 55.051499158144, 54.58987332880497, 54.88889828324318, 54.65367190539837, 52.74526610970497, 54.625644609332085, 55.625940933823586, 53.48620355129242, 52.50093162059784, 54.64566193521023, 53.89209397137165, 50.586784332990646, 51.041053757071495, 54.91391234099865, 54.8673952370882, 53.45213457942009, 48.86689782142639, 47.02523164451122, 40.80654613673687, 41.50988459587097, 46.434625536203384, 45.87871916592121, 45.75552597641945, 49.45502646267414, 51.17356404662132, 54.31895926594734, 55.11164233088493, 60.76678387820721, 57.754035741090775, 45.982233211398125, 20.597953721880913, 13.246662989258766, 10.957694314420223, 7.005474139004946, 4.381388621404767, 1.159568578004837, 0.8681549120228738, 0.1295656108413823, 0.11405839803046547, 0.01639306625293102, 1.5340364654548466, 21.59247625619173, 36.506883054971695, 24.42382212728262, 13.511808011680841, 26.26368150115013, 29.70521952956915, 42.69857481122017, 40.566798001527786, 50.32866798341274, 23.717343136668205, 0.6098804553039372, 0.047124592601903714, 0.04415764946315903, 0.04148088235524483, 0.05890809799893759, 0.04457369002921041, 0.04093556337465998, 0.024710634388611652, 0.062244697473943233, 0.05947994504822418, 0.09542324798530899, 0.017142551914730575, 0.07214592711534351, 0.06088631860620808, 0.017472798353992403, 0.045903563004685566, 0.05913535846048035, 0.01944514486240223, 0.044512381209642626, 0.07718719527474605, 0.052843556622974575, 0.02369205711147515, 0.08133824245305732, 0.03624870783824008, 0.048323383743991144, 0.035171862691640854, 0.021211660423432477, 0.028711828963423613, 0.03147042712953407, 0.018418886356812436, 0.06093166011851281, 0.03142504850984551, 0.032660178912919946, 0.037721088010584936, 0.0406805094826268, 0.047644685982959345, 0.01685670817096252, 0.02796049535390921, 0.04584249167237431, 0.008161844216374448, 0.059664168365998194, 0.025912171477102675, 0.11703395750373602, 0.035793322313111275, 0.05658002526615746, 0.16889075457584113, 14.78157352656126, 62.91517719626427, 69.45068210363388, 59.06350627541542, 48.8056755065918, 47.303266525268555, 26.476050205528736, 30.460174418985844, 37.531129494309425, 36.61654517054558, 2.969752731733024, 0.002724692453739408, 0.13149020756827667, 0.24580836470704526, 1.3895187014713883, 5.710797635838389, 8.087522126734257, 7.552023036405444, 8.57979141175747, 14.762857630848885, 30.320870094001293, 41.024206057190895, 65.174171179533, 60.97126230597496, 61.98887050151825, 62.0474823564291, 62.08391100168228, 59.16762448847294, 62.40481898188591, 54.667096585035324, 51.0603529214859, 55.96699923276901, 62.05189771950245, 58.02240394055843, 57.566633597016335, 57.909777984023094, 60.23274913430214, 50.091944485902786, 41.88766032457352, 42.157366052269936, 53.4324174374342, 57.06128351390362, 55.93141034245491, 56.313172057271004, 57.49022729694843, 54.53863687813282, 54.62601698935032, 53.57498958706856, 52.62885935604572, 52.77718059718609, 58.6742589622736, 54.23680007457733, 50.46520225703716, 41.982286646962166, 43.54761645197868, 41.41750015318394, 44.70552831888199, 47.60099574923515, 52.82885022461414, 52.46134154498577, 57.830225452780724, 54.8865994066, 60.13086900115013, 50.01462243497372, 58.92152689397335, 36.90431512892246, 46.87566787004471, 60.516096130013466, 53.96966300904751, 50.00463657081127, 42.00190119445324, 45.59441462159157, 51.3835483789444, 57.34125629067421, 55.22698514163494, 51.18612997233868, 49.94756743311882, 54.850493744015694, 55.74996627867222, 55.85840865969658, 56.424076706171036, 56.97461776435375, 55.67437693476677, 54.31482508778572, 57.16819457709789, 58.168483301997185, 55.296688601374626, 56.0582285374403, 55.46846978366375, 54.740843027830124, 50.980701595544815, 51.70325182378292, 57.43207521736622, 57.36060105264187, 53.98386284708977, 51.125648617744446, 48.060163110494614, 43.25541593134403, 43.26263174414635, 48.11552233994007, 47.55863942205906, 48.26738499104977, 50.19010841846466, 53.643442913889885, 55.409922525286674, 59.60848443210125, 62.03918360173702, 61.6399048268795, 44.89861875772476, 21.005774438381195, 4.176825173199177, 18.329709134995937, 11.454069279134274, 7.366282353177667, 6.74313954077661, 2.7608178555965424, 0.41682178038172424, 0.11604826664552093, 0.016596973182458896, 1.3502942374907434, 27.36135520040989, 34.084076061844826, 26.341892704367638, 21.5915073081851, 32.435743510723114, 40.412537679076195, 51.038998067379, 48.13530407845974, 57.214400097727776, 33.3273808658123, 1.2659044470638037, 0.05146284653164912, 0.033324898322462104, 0.016170071285159793, 0.025258350506192073, 0.058351171828689985, 0.018376220286882017, 0.023079633137967903, 0.044744027763954364, 0.06661700113909319, 0.04163429912296124, 0.012134316748415586, 0.07707343145739287, 0.03739740772289224, 0.037682013935409486, 0.05709757679142058, 0.009366397207486443, 0.04079379090399016, 0.04010333010228351, 0.062080218995106407, 0.0760981826169882, 0.040224062686320394, 0.027160436038684566, 0.032199757915805094, 0.1018287987972144, 0.130627520265989, 0.1719796028919518, 0.16116683778818697, 0.14463641855400056, 0.17288622533669695, 0.13505796378012747, 0.14709928014781326, 0.11416586101404391, 0.1392004094668664, 0.15715799352619797, 0.13761889276793227, 0.09290916335885413, 0.20298997638747096, 0.1294935483019799, 0.13670624408405274, 0.14279130584327504, 0.16180964157683775, 0.2572819381020963, 0.087257849809248, 0.19924820138840005, 0.31659019470680505, 21.36603120714426, 71.52882099151611, 77.05015271902084, 65.08636549115181, 57.314908504486084, 53.15315142273903, 26.121584326028824, 36.434086561203, 46.51759788393974, 47.9348686337471, 3.5662998212501407, 0.29135307704564184, 0.32291118521243334, 0.42944164539221674, 1.5208111563697457, 6.541339019313455, 19.18975878506899, 18.111141063272953, 12.67583766952157, 24.652398861944675, 36.696530878543854, 46.26318633556366, 69.37287747859955, 62.156502306461334, 66.12505495548248, 63.685202077031136, 64.03164088726044, 59.18100357055664, 65.73692098259926, 58.584868758916855, 54.37699355185032, 57.75672599673271, 64.54737961292267, 59.575312212109566, 57.9405677318573, 59.78154614567757, 63.17699074745178, 53.15858133137226, 44.044344797730446, 44.78688955307007, 54.891808927059174, 60.59247963130474, 58.21263313293457, 57.59947143495083, 60.10096840560436, 55.68127356469631, 56.049846187233925, 55.729724764823914, 53.28262947499752, 53.38171675801277, 61.54744818806648, 56.19050323963165, 52.91694089770317, 45.78697308897972, 45.808122754096985, 42.119702473282814, 47.20530018210411, 50.11011131107807, 54.798820316791534, 55.28991736471653, 60.46506106853485, 56.90427973866463, 63.72152432799339, 51.76990024745464, 58.21453683078289, 39.18122135102749, 51.29760459065437, 62.01282441616058, 58.16488869488239, 53.76893877983093, 43.50581109523773, 47.582939118146896, 53.66893574595451, 59.6661539375782, 56.82588994503021, 50.62965363264084, 51.70809656381607, 55.507672280073166, 57.53274701535702, 57.87680335342884, 57.230974808335304, 58.48471373319626, 57.43036910891533, 53.570570424199104, 59.027039632201195, 60.29715567827225, 58.51585306227207, 57.771264016628265, 57.10314966738224, 54.86676827073097, 51.459616497159004, 50.5841738730669, 59.39887247979641, 59.25988733768463, 56.86697714030743, 54.38096433877945, 51.29577308893204, 46.3202440738678, 46.09572932124138, 49.58177246153355, 50.084500685334206, 49.94964212179184, 54.51350122690201, 56.53528913855553, 59.508356004953384, 60.227661207318306, 66.60707429051399, 62.159101366996765, 51.237374022603035, 26.41928505152464, 20.97557555884123, 25.006809644401073, 15.569086968898773, 14.841255974024534, 7.334221098572016, 3.819989408366382, 0.13979331124573946, 0.3194843034725636, 0.0899405281234067, 2.4793911818414927, 32.412693947553635, 51.177192851901054, 33.70718568563461, 21.26083195209503, 38.42798016965389, 46.04389250278473, 58.26574668288231, 56.71483710408211, 62.0204696059227, 42.85837523639202, 2.9659125627949834, 0.09432999024284072, 0.11481646477477625, 0.13569269300205633, 0.1884098321897909, 0.11486019211588427, 0.187203396926634, 0.07743602254777215, 0.14156869176076725, 0.1926081912824884, 0.12768493441399187, 0.08368854250875302, 0.18526735628256574, 0.12981194449821487, 0.12053366619511507, 0.1771460787858814, 0.14199616882251576, 0.0913841463625431, 0.1338951668003574, 0.13328466127859429, 0.18155920057324693, 0.22930497449124232, 0.18847376079065725, 0.08812012893031351], [0.0899876025505364, 0.028930912812938914, 0.05753708777774591, 0.04795738619577605, 0.054655257845297456, 0.07215735618956387, 0.01793751638615504, 0.07596965748234652, 0.0681625830475241, 0.006608623752981657, 0.05610339947452303, 0.013205628256400814, 0.015179930323938606, 0.046988145040813833, 0.06401438571629114, 0.0668609599233605, 0.04292087891371921, 0.0406310008111177, 0.05097273220599163, 0.05088528123451397, 0.016117219238367397, 0.40718104457482696, 25.673616863787174, 58.71250011026859, 53.0091467499733, 35.78243672847748, 38.333870619535446, 23.228138387203217, 23.339932188391685, 45.656180307269096, 44.9553345143795, 19.083757773041725, 0.15939684526529163, 0.15145527140703052, 0.03600163203373086, 0.23200599127449095, 1.993496767245233, 4.898039773106575, 4.721301281824708, 8.847027271986008, 12.545115184038877, 25.529912374913692, 32.92010352015495, 52.95432709157467, 63.738410621881485, 55.407806038856506, 57.80368387699127, 59.524144157767296, 60.221649929881096, 59.18076038360596, 57.26845979690552, 53.235299214720726, 45.05409501492977, 51.997006461024284, 58.40305231511593, 58.78829464316368, 53.92436943948269, 55.98907224833965, 56.21788837015629, 49.38658833503723, 42.102029621601105, 40.151689276099205, 51.27229794859886, 56.34730562567711, 56.13196738064289, 55.418437868356705, 53.973022028803825, 55.15687130391598, 51.79795794188976, 52.85100683569908, 54.304075464606285, 54.316671788692474, 56.382529735565186, 49.642542600631714, 45.91662213206291, 40.86715668439865, 41.269182711839676, 38.256392776966095, 44.90635134279728, 49.18542332947254, 52.88416005671024, 51.52285270392895, 55.938633754849434, 53.354715406894684, 56.34928151965141, 49.521728083491325, 57.639943063259125, 36.013114750385284, 45.15506699681282, 58.0366113781929, 50.6243035197258, 49.41851422190666, 40.890236645936966, 40.926946476101875, 45.68297266960144, 54.584637209773064, 54.059862568974495, 54.43558260798454, 51.086149737238884, 51.760837733745575, 52.95142404735088, 51.70022338628769, 50.40732376277447, 52.854156866669655, 52.007847279310226, 51.16160608828068, 51.22098550200462, 54.666180834174156, 54.72380854189396, 55.82688555121422, 55.12196637690067, 52.56323307752609, 54.247340708971024, 46.779495030641556, 54.07894894480705, 60.652808994054794, 55.553342029452324, 55.326923578977585, 55.92058852314949, 51.9119518250227, 43.072413951158524, 42.52327881753445, 44.61342126131058, 45.05895875394344, 49.24642525613308, 53.19853238761425, 53.409314677119255, 53.697688803076744, 55.96452936530113, 60.062803253531456, 59.769025817513466, 35.08543252944946, 11.94680878892541, 13.943643439561129, 5.758267538622022, 8.292747214436531, 3.829298196360469, 2.158139320090413, 0.05808654794236645, 0.0991612825600896, 0.05374990818381775, 0.06178573108627461, 8.067728988826275, 38.82193922996521, 40.26934616267681, 26.058927588164806, 13.613974079489708, 17.951352037489414, 32.97750324010849, 46.266921535134315, 48.963997811079025, 38.87703247368336, 8.864306844770908, 0.08525168363121338, 0.0227559769700747, 0.03180875370162539, 0.07710856472840533, 0.05181228676519822, 0.04644939777790569, 0.03078161389566958, 0.04904572349914815, 0.1067621809488628, 0.028791116310458165, 0.06449137144954875, 0.050818395175156184, 0.028816351186833344, 0.09936172180459835, 0.045688529426115565, 0.0958060625998769, 0.08168173066223972, 0.08956037039752118, 0.034096449890057556, 0.0067235337246529525, 0.03450277945376001, 0.046124585715006106, 0.07049261505017057, 0.0663662888109684, 0.010242753942293348, 0.07702255723415874, 0.03221616680093575, 0.05680755290086381, 0.026087576225108933, 0.05715360523026902, 0.04223005074891262, 0.057657564320834354, 0.03699007625982631, 0.06807921759900637, 0.06636411431827582, 0.01482933790612151, 0.01231753723914153, 0.06269130710279569, 0.033515236937091686, 0.049700947129167616, 0.061901298322482035, 0.04590471704432275, 0.11795626152888872, 0.11280358958174475, 0.8297498384490609, 31.983419582247734, 68.8988909125328, 60.60729123651981, 41.504485085606575, 46.39703795313835, 30.712492279708385, 21.9949259608984, 36.172527596354485, 43.53094294667244, 20.619399771094322, 0.11533220545970835, 0.03545856547134463, 0.0487979463650845, 0.489176043192856, 2.911427761428058, 7.420046143233776, 7.10319634526968, 8.570776395499706, 8.276471737772226, 23.774053193628788, 36.406819224357605, 57.036052867770195, 64.76739540696144, 58.552144914865494, 60.35931654274464, 60.655149668455124, 62.58251644670963, 60.71188062429428, 59.79896821081638, 56.07485644519329, 47.993723675608635, 54.42533075809479, 60.21866329014301, 59.82660412788391, 54.385299906134605, 57.1296988427639, 59.298899844288826, 51.033397167921066, 42.95342333614826, 42.55067154765129, 53.20025749504566, 58.092909157276154, 58.127563297748566, 56.11552946269512, 53.62456552684307, 55.35948783159256, 54.700557589530945, 54.63125690817833, 56.30496069788933, 53.63198272883892, 57.989364713430405, 53.089881017804146, 48.65092881023884, 42.16918341815472, 43.37774656713009, 41.11080341041088, 46.754351779818535, 50.855992287397385, 56.05438694357872, 55.08713364601135, 57.33986556529999, 56.18729241192341, 56.42391711473465, 50.578071400523186, 56.786995232105255, 38.75706151127815, 47.22075015306473, 60.15141449868679, 52.695534378290176, 51.58030942082405, 43.07165779173374, 43.547977432608604, 46.774863079190254, 58.669163435697556, 55.806241258978844, 54.78270538151264, 51.43731169402599, 51.73327021300793, 53.75725440680981, 52.01796993613243, 52.24281147122383, 53.596219047904015, 51.60923346877098, 53.02540987730026, 52.82942019402981, 56.61353833973408, 57.31897048652172, 58.600356727838516, 56.5605615824461, 52.76930741965771, 54.27170120179653, 48.69959279894829, 54.82819274067879, 62.04452231526375, 58.5065321624279, 58.3292830735445, 57.39889919757843, 54.925657510757446, 44.78652097284794, 44.24466244876385, 46.37730561196804, 47.594608291983604, 49.351577013731, 57.81036391854286, 54.65879783034325, 57.389711290597916, 57.628083899617195, 62.98254378139973, 59.00899060070515, 40.38656607270241, 10.654219798743725, 8.391638807952404, 10.580298565328121, 8.667607549577951, 7.144446931779385, 3.5521987779065967, 2.816927069798112, 0.31844998709857464, 0.19662975595565513, 0.11216783619602211, 8.842264227569103, 39.578695222735405, 34.00103151798248, 23.936198092997074, 22.007134705781937, 26.57962504774332, 41.122031807899475, 52.355175241827965, 56.19670830667019, 46.80494226515293, 12.885611113160849, 0.0784508723882027, 0.045885669824201614, 0.08914762496715412, 0.04105045896722004, 0.06293939964962192, 0.018306720012333244, 0.07077332498738542, 0.08688267931574956, 0.025465834587521385, 0.044721592639689334, 0.041273188617196865, 0.028246841902728193, 0.038286797498585656, 0.05676352870068513, 0.027653582037601154, 0.045165337578509934, 0.005585890912698233, 0.10029391123680398, 0.008480944525217637, 0.016057964312494732, 0.0757892413821537, 0.042826648423215374, 0.03383662769920193, 0.17784947151085362, 0.08009916011360474, 0.24319005286088213, 0.11271600873442367, 0.1756836025742814, 0.1091723723220639, 0.13836901111062616, 0.114302794681862, 0.18214067327789962, 0.10275548891513608, 0.13340385019546375, 0.127707302744966, 0.1360339325037785, 0.17109408712713048, 0.13809192285407335, 0.11258433689363301, 0.14530855201883242, 0.12274378939764574, 0.16033831896493211, 0.1783508516382426, 0.12269574275705963, 1.829459450673312, 41.719678938388824, 76.6432173550129, 70.31272664666176, 50.04776045680046, 51.67295224964619, 31.520078144967556, 34.83290188014507, 57.48262010514736, 59.44173417985439, 26.020399555563927, 0.40062835556454957, 0.3019465523539111, 0.10548277030466124, 0.7753259525634348, 4.454540871083736, 11.716202963143587, 12.627492863684893, 17.433627918362617, 19.762515351176262, 31.427283324301243, 41.9927778840065, 60.953737646341324, 69.27745699882507, 61.18826486170292, 63.33751693367958, 65.6626045703888, 63.281568735837936, 60.84450110793114, 61.634737104177475, 58.126404359936714, 49.56686206161976, 55.76633580029011, 62.26326137781143, 61.35326340794563, 54.84328553080559, 57.97016054391861, 61.34149543941021, 53.108154237270355, 45.663776099681854, 44.975112453103065, 55.321573466062546, 60.940977931022644, 58.726042583584785, 56.64201021194458, 53.537641391158104, 58.10210086405277, 56.234968453645706, 55.8355300873518, 58.13709318637848, 56.40360340476036, 62.15545356273651, 55.21097660064697, 50.467520132660866, 46.65597885847092, 46.160709634423256, 42.27094955742359, 48.85099567472935, 53.83293494582176, 57.00842075049877, 56.90210245549679, 59.046300798654556, 57.547665014863014, 59.545521810650826, 52.64655500650406, 58.62149879336357, 41.32497511804104, 50.277021154761314, 61.714076846838, 56.24436154961586, 52.515215054154396, 45.55113114416599, 46.07375890016556, 49.303832575678825, 59.94479298591614, 58.28235559165478, 56.241663694381714, 51.90640412271023, 50.801883190870285, 55.14565050601959, 53.626283034682274, 51.79527148604393, 55.433025285601616, 52.33655244112015, 53.301909640431404, 54.01771903038025, 57.8043108433485, 59.15704965591431, 59.84239988029003, 59.68103773891926, 51.819278597831726, 56.854662001132965, 48.822216019034386, 56.20407611131668, 65.86815074086189, 61.216105967760086, 61.13837353885174, 60.27315616607666, 57.697559371590614, 47.054216489195824, 46.856577694416046, 51.0836760699749, 49.24998566508293, 53.46107929944992, 59.72663149237633, 57.409580424427986, 61.87635473906994, 61.52564115822315, 65.00894084572792, 65.63031390309334, 42.45420232415199, 19.408596642315388, 26.65819153189659, 17.580681927502155, 18.48384216427803, 9.987197890877724, 6.1776999570429325, 1.7894240864552557, 0.27442620252259076, 0.5184447742067277, 0.18065685289911926, 12.170223500579596, 52.98853665590286, 54.53324876725674, 37.836534306406975, 22.24565740674734, 27.934740632772446, 48.425612300634384, 61.130112782120705, 64.63757917284966, 55.78241653740406, 17.690480835735798, 0.24626054044347256, 0.1896503468742594, 0.13496762956492603, 0.18536704155849293, 0.13908717257436365, 0.11792083882028237, 0.13358537951717153, 0.23365771514363587, 0.147793440555688, 0.10999567384715192, 0.19541601795936003, 0.1717618716065772, 0.09773647034307942, 0.14904584444593638, 0.17468634905526415, 0.17692448833258823, 0.168464123562444, 0.23971248243469745, 0.12305089752771892, 0.21261024376144633, 0.14818636322161183, 0.09910855296766385, 0.214062433806248], [0.019808526340057142, 0.0262892938189907, 0.047565617569489405, 0.03121811918390449, 0.023736194489174522, 0.03598197625251487, 0.04726848019345198, 0.05258836172288284, 0.04383096347737592, 0.03352022045874037, 0.03951063241402153, 0.050799908276530914, 0.021604000503430143, 0.033532896341057494, 0.022394467559934128, 0.09307932297815569, 0.035002345030079596, 0.022118657652754337, 0.042219823953928426, 0.09203812689520419, 0.014558468847098993, 2.7846421021968126, 40.767165049910545, 62.595002576708794, 52.05280266702175, 36.13304391503334, 18.312459960579872, 18.20403277873993, 34.1171532869339, 36.45647116005421, 41.015983298420906, 5.2678250055760145, 0.071602392999921, 0.06700861762510613, 0.16658312059007585, 0.47670947620645165, 2.8114741249009967, 5.43142095208168, 6.970921643078327, 3.5304328333586454, 21.3134553283453, 31.10048186033964, 43.86909060180187, 61.43391788005829, 58.703673183918, 56.06732904911041, 54.298793748021126, 57.33913600444794, 59.45480927824974, 61.53658077120781, 58.534696251153946, 52.36236825585365, 45.253694504499435, 52.28224195539951, 57.750133350491524, 57.223531007766724, 54.78574901819229, 54.607166200876236, 56.52786433696747, 52.684461772441864, 42.32973240315914, 41.66681617498398, 51.19407534599304, 55.162297412753105, 54.42310027778149, 51.87206916511059, 53.87364596128464, 56.025124713778496, 57.31949105858803, 54.55235794186592, 54.35018979012966, 52.698851600289345, 54.99427042901516, 50.909569412469864, 44.907118901610374, 39.47237692773342, 38.946241959929466, 39.67908963561058, 47.43777550756931, 52.47440904378891, 56.53579831123352, 55.7383731007576, 56.46737918257713, 52.84129075706005, 51.5629443526268, 48.197195157408714, 57.59423911571503, 33.92958775162697, 43.305831626057625, 60.29284290969372, 51.74124218523502, 53.708039447665215, 45.80315262079239, 41.71244032680988, 38.105400279164314, 50.74607938528061, 53.97024057805538, 56.78132213652134, 53.06928612291813, 53.42338912189007, 49.896273985505104, 50.95486298203468, 50.02890966832638, 51.98256343603134, 52.726172134280205, 50.63661865890026, 50.96495524048805, 51.316470578312874, 52.80366137623787, 53.4134716540575, 51.75029709935188, 47.75402873754501, 44.01301547884941, 49.637716859579086, 47.73324005305767, 53.56898210942745, 53.33544284105301, 56.74142047762871, 54.606410041451454, 57.43325315415859, 49.928123876452446, 43.99865224957466, 40.521827414631844, 45.49568831920624, 55.00413089990616, 58.733999356627464, 55.113230645656586, 56.42295956611633, 51.52448281645775, 58.194097727537155, 56.3448129594326, 56.5424707531929, 17.671491354703903, 18.91219697892666, 11.303270570933819, 2.878288789652288, 8.263543881475925, 2.4772882321849465, 3.7127273390069604, 0.1045372370572295, 0.08493078639730811, 0.1311147995875217, 1.0743224085308611, 18.192633390426636, 46.710764318704605, 29.027594290673733, 19.61794450879097, 20.710190199315548, 22.67556633800268, 32.792738154530525, 47.94539026916027, 47.52699851989746, 19.921381026506424, 0.9182895999401808, 0.05619382645818405, 0.10260240611387417, 0.019820220732071903, 0.02807245389703894, 0.02827752414304996, 0.03081242786720395, 0.02959737626952119, 0.07009147680946626, 0.03923023417883087, 0.045262206404004246, 0.03296568771474995, 0.037586247199214995, 0.06675636162981391, 0.04379233098006807, 0.03486694389721379, 0.049771428894018754, 0.019240273140894715, 0.034383226884528995, 0.063619407301303, 0.08523257332853973, 0.06390776878106408, 0.0416219794715289, 0.07068776278174482, 0.03824724102742039, 0.040262921538669616, 0.04247649572789669, 0.03416784449655097, 0.035342612318345346, 0.039491407078457996, 0.07624128353199922, 0.014425654098886298, 0.03423159498197492, 0.02381000478635542, 0.04171609863988124, 0.009462661182624288, 0.044736617419403046, 0.0227912104310235, 0.044376920704962686, 0.057370995127712376, 0.01563034067658009, 0.008389156628254568, 0.014300027978606522, 0.011908380092791049, 3.709218939766288, 52.485192865133286, 69.98742610216141, 61.136785224080086, 39.97812978923321, 23.85519403964281, 19.93700958788395, 29.3382029235363, 37.19536051154137, 41.585048362612724, 6.071373587474227, 0.07663505224627443, 0.03668278259283397, 0.32693635672330856, 2.3584745451807976, 6.174232168123126, 7.925880225375295, 7.763071786612272, 5.937876300886273, 19.0316416695714, 33.56370158493519, 47.14693911373615, 63.80857765674591, 61.9502379745245, 57.64157697558403, 56.22473940253258, 60.04044525325298, 61.963244676589966, 63.765731155872345, 60.4175978153944, 54.166469648480415, 46.130816638469696, 54.320076406002045, 58.66365373134613, 59.30541269481182, 55.23625284433365, 56.939804032444954, 59.05595988035202, 54.4304034858942, 43.3424236625433, 43.15254405140877, 51.83907553553581, 58.513557985424995, 55.81393584609032, 52.880139872431755, 53.91877233982086, 57.061872482299805, 57.19793178141117, 54.81599539518356, 56.72267988324165, 53.94362300634384, 56.38465002179146, 53.10506120324135, 48.62817943096161, 42.206664606928825, 41.799368262290955, 42.191666811704636, 49.47062462568283, 53.541304394602776, 58.9930884540081, 57.88026496767998, 58.68811681866646, 55.40074981749058, 53.73386286199093, 49.678070694208145, 58.231202736496925, 35.819427743554115, 45.42855352163315, 62.240523397922516, 54.14924517273903, 55.213526263833046, 45.04750616848469, 42.9726655036211, 40.066330656409264, 51.96479558944702, 55.330795571208, 57.51167714595795, 54.08523000776768, 53.98379445075989, 51.12600199878216, 51.70241206884384, 51.92286103963852, 52.304915338754654, 53.115529641509056, 49.97166574001312, 50.97615323960781, 52.099327370524406, 53.74423250555992, 54.82464753091335, 52.79214799404144, 47.57524833083153, 48.701880276203156, 49.8088064789772, 47.913357987999916, 54.4082772731781, 54.62572440505028, 58.04045297205448, 56.74422472715378, 59.99898187816143, 52.33819015324116, 46.62136271595955, 43.80869664251804, 47.23120719194412, 56.39845848083496, 60.32471939921379, 58.75647895038128, 58.89273203909397, 54.79716740548611, 60.530991330742836, 60.3242102265358, 54.43893402814865, 20.406746082007885, 10.336604341864586, 12.00418096035719, 9.243578743189573, 10.81511551514268, 8.41570196673274, 5.573506727814674, 1.2868712469935417, 0.15317739540478215, 0.16234658542089164, 0.9009515459183604, 20.636918731033802, 43.363713920116425, 28.02397884428501, 20.553032532334328, 27.28567086160183, 31.86308763921261, 40.69566808640957, 53.37516590952873, 55.04171848297119, 26.892247572541237, 1.2575526139698923, 0.08482832548907027, 0.14017182140378281, 0.032210407734964974, 0.05239809361228254, 0.028722755232593045, 0.017338352736260276, 0.01194405884234584, 0.03421049943426624, 0.09854094358161092, 0.08612598554464057, 0.005546220800169976, 0.04678206918470096, 0.10066606118925847, 0.07030193504760973, 0.0590360405476531, 0.05023056968639139, 0.04373352690890897, 0.06485305711976252, 0.07607831532368436, 0.07591571076773107, 0.013297443056217162, 0.004705797000497114, 0.21662312530679628, 0.14029788260813802, 0.13359247444896027, 0.10675544966943562, 0.17968468397157267, 0.21123170445207506, 0.12254804794793017, 0.11771206525736488, 0.09661128540756181, 0.1437909045489505, 0.10199302865657955, 0.08792261374765076, 0.10278498928528279, 0.22004547994583845, 0.11712688181432895, 0.14158644393319264, 0.1628444329253398, 0.14267207239754498, 0.1751662217429839, 0.22017915558535606, 0.095038592844503, 5.047831060364842, 62.33674183487892, 78.26662704348564, 68.6505438387394, 49.70841586589813, 28.956120125949383, 27.793669402599335, 45.25628976523876, 51.639491245150566, 53.150206580758095, 8.133218474686146, 0.29737545701209456, 0.36579408100806177, 0.37595440924633294, 2.4415881978347898, 10.025615729391575, 15.265833791345358, 17.162109687924385, 9.049753043800592, 27.29921903461218, 39.300018176436424, 52.547627314925194, 67.19333723187447, 65.17294004559517, 59.66672770678997, 59.35189940035343, 62.42277301847935, 64.89888355135918, 66.32125362753868, 64.04059320688248, 56.93891108036041, 49.66927416622639, 56.34919032454491, 61.78620457649231, 61.87316291034222, 56.61866046488285, 56.408710330724716, 61.981225311756134, 58.87086421251297, 46.68296121060848, 45.80857113003731, 54.85284201800823, 59.52626444399357, 57.61695049703121, 52.511681243777275, 55.37954315543175, 59.41273793578148, 61.248810812830925, 57.32750482857227, 59.78259488940239, 56.88540235161781, 59.279836267232895, 55.91801606118679, 51.01274527609348, 44.257935136556625, 44.02656555175781, 43.57454180717468, 52.13722653687, 56.611186265945435, 60.266042947769165, 59.34867337346077, 60.18490970134735, 56.429195031523705, 55.52435718476772, 49.237229749560356, 58.66233520209789, 38.54561805725098, 48.081164583563805, 66.13786786794662, 56.4332228153944, 57.897052466869354, 48.47490705549717, 45.505651384592056, 42.13938161730766, 55.242184326052666, 59.27172750234604, 60.704448223114014, 55.23846052587032, 55.345899760723114, 50.889787673950195, 52.7469228208065, 52.91240394115448, 52.862071841955185, 55.1276470720768, 51.704600751399994, 52.17897869646549, 53.80562201142311, 55.28977297246456, 56.64826087653637, 53.25186252593994, 48.40057544410229, 48.48584666848183, 51.21087804436684, 48.297551572322845, 53.91548931598663, 56.85309648513794, 60.3390484303236, 59.66978274285793, 62.873816415667534, 55.00985339283943, 49.476708099246025, 45.88652774691582, 49.630178064107895, 59.31365825235844, 62.93066516518593, 59.81441058218479, 61.511718705296516, 57.56952904164791, 62.9881788790226, 62.11158871650696, 59.840036407113075, 23.03442858159542, 28.543306477367878, 27.495081424713135, 13.850596882402897, 21.309051364660263, 9.595841690897942, 8.566444627940655, 0.7429933687672019, 0.2722932997858152, 0.4033314948901534, 1.7444907850585878, 27.417407892644405, 65.59661731123924, 40.888975113630295, 29.639401361346245, 31.228829473257065, 34.776334315538406, 47.56777033209801, 61.505654230713844, 64.22436654567719, 35.15596814453602, 2.110384670086205, 0.1500788249541074, 0.21077230019727722, 0.09967739431886002, 0.1242216577520594, 0.15110646199900657, 0.12958389736013487, 0.1531582628376782, 0.18295898014912382, 0.2109171377378516, 0.21409269858850166, 0.13551103009376675, 0.11222967936191708, 0.17463548225350678, 0.15601392835378647, 0.12652828241698444, 0.1449830608908087, 0.19257310254033655, 0.2301237266510725, 0.1628778295707889, 0.15718321170425043, 0.10396645870059729, 0.08123447536490858], [0.03330075996927917, 0.03677855303976685, 0.027105142326036002, 0.08812635554932058, 0.03862633377138991, 0.04305765301978681, 0.03776253324758727, 0.04927235313516576, 0.0445659679826349, 0.05290483575663529, 0.05808455898659304, 0.011876552161993459, 0.07119653469999321, 0.03377248016477097, 0.00861855354742147, 0.03328185004647821, 0.07729524455498904, 0.04763169839861803, 0.026964943208440673, 0.0923882499046158, 0.08193999805371277, 6.25960361212492, 55.23728258907795, 56.47204153239727, 51.91120706498623, 44.389761462807655, 32.019992619752884, 29.925995282828808, 41.97774589061737, 44.481002166867256, 27.587452568113804, 0.6290962023194879, 0.07493979399441741, 0.11817090547992848, 0.21639050653902814, 0.37564870377536863, 3.251334959641099, 5.641133598983288, 4.087289627641439, 13.876563739031553, 26.355205290019512, 36.700896844267845, 55.11738382279873, 60.543416664004326, 57.79130794107914, 51.54385797679424, 49.25521418452263, 57.738840356469154, 57.14908540248871, 59.490006789565086, 58.45425836741924, 49.568872153759, 45.27340404689312, 52.77273863554001, 58.1362534314394, 57.96317271888256, 55.315691381692886, 54.92090776562691, 56.07768729329109, 50.782914608716965, 41.30113519728184, 40.704916790127754, 46.96576863527298, 53.888658955693245, 54.96038384735584, 51.90516538918018, 55.43516457080841, 55.47857724130154, 54.25703018903732, 53.949938267469406, 54.112736731767654, 52.97608092427254, 52.711808905005455, 46.648474261164665, 43.47299985587597, 39.34986010193825, 39.735930785536766, 38.31060826778412, 51.34670175611973, 55.26284001767635, 57.59759433567524, 50.344258546829224, 54.81196381151676, 48.47257398068905, 52.383191138505936, 47.67922215163708, 55.205474495887756, 31.24856561422348, 35.837024599313736, 61.918137297034264, 51.810744255781174, 55.62886297702789, 49.70741271972656, 50.43284319341183, 38.99038039147854, 39.56078678369522, 47.269155755639076, 52.17847712337971, 53.583786115050316, 54.07480336725712, 50.7191464304924, 52.62984350323677, 51.52703247964382, 51.12984359264374, 50.257778987288475, 51.225678250193596, 49.02015499770641, 50.95088839530945, 49.85894858837128, 52.91611634194851, 47.3376926779747, 51.973227337002754, 47.033568397164345, 56.17917984724045, 54.42252270877361, 54.588239416480064, 51.18761569261551, 52.85538800060749, 58.03493566811085, 54.249871373176575, 54.792174473404884, 45.849377140402794, 40.67403204739094, 44.73759859800339, 55.858439058065414, 57.40023672580719, 56.640315502882004, 56.97418458759785, 53.78647103905678, 53.4045497328043, 55.70211164653301, 59.63819123804569, 41.681734174489975, 11.809801440685987, 7.30766954831779, 7.723950985819101, 6.978386342525482, 4.785017212852836, 6.709461947903037, 0.6271979073062539, 0.07253656396642327, 0.051989404018968344, 0.06421363010304049, 6.886443151161075, 38.6892731487751, 34.67106096446514, 43.62130209803581, 25.424116551876068, 18.42532340437174, 42.63115122914314, 45.05294747650623, 53.14867526292801, 37.09379196166992, 6.999864215031266, 0.1420892044552602, 0.020673132094088942, 0.009681528881628765, 0.034720533003564924, 0.0545377721573459, 0.018478814781701658, 0.010407372501504142, 0.03144493806757964, 0.024622114724479616, 0.04352511699835304, 0.06033822399331257, 0.021598734965664335, 0.061898292624391615, 0.024732421989028808, 0.035424961024546064, 0.05938657915976364, 0.0916518984013237, 0.061660434294026345, 0.026467071584193036, 0.03906287616700865, 0.013164986394258449, 0.08648709233966656, 0.04261638314346783, 0.0253106644959189, 0.02890049960114993, 0.0675636030791793, 0.023930037896207068, 0.06413137787603773, 0.06056137666746508, 0.024324283440364525, 0.051681316253961995, 0.039769716167938896, 0.07640304203960113, 0.024525880435248837, 0.01242774524143897, 0.05490209616255015, 0.025580668952898122, 0.03369403515534941, 0.1037551395711489, 0.03252115238865372, 0.010380129187979037, 0.09743802307639271, 0.10577780369203538, 10.075551699846983, 66.94062039256096, 60.65739534795284, 57.94412434101105, 51.88436910510063, 35.59780463576317, 32.5880279392004, 45.34871220588684, 42.33202748000622, 29.85359776765108, 0.8460323803592473, 0.25080325605813414, 0.01692308400379261, 1.0190370376221836, 3.9917119313031435, 6.957990461960435, 6.706889010965824, 7.708616908639669, 10.459105968475342, 26.907382160425186, 37.967023104429245, 58.90375144779682, 61.929886266589165, 60.191764533519745, 54.16829735040665, 52.56232872605324, 58.14060799777508, 60.988604575395584, 60.252622067928314, 60.659679025411606, 51.47198103368282, 45.9911285340786, 53.81164848804474, 60.066986829042435, 60.389156341552734, 55.93212850391865, 55.87755583226681, 58.653375282883644, 52.67564244568348, 42.14106872677803, 41.845896765589714, 49.12958912551403, 57.57349982857704, 55.7390608638525, 52.674403712153435, 55.763881132006645, 57.29229971766472, 56.31494656205177, 55.21661929786205, 56.96774773299694, 53.16184915602207, 54.767145216464996, 49.2526151239872, 45.92478409409523, 40.44042058289051, 42.503056302666664, 41.1871413141489, 53.11291538178921, 57.839865535497665, 57.786827981472015, 51.537436321377754, 56.55950903892517, 50.14687053859234, 53.349889665842056, 47.50640742480755, 54.93431344628334, 31.07453305274248, 38.58725622296333, 62.41519242525101, 54.52118821442127, 58.679863661527634, 51.4995751529932, 51.92760318517685, 41.31793789565563, 42.67649419605732, 49.96141768991947, 54.56578642129898, 55.59631012380123, 54.697574749588966, 51.398815959692, 52.622635290026665, 50.05947522819042, 52.03716650605202, 50.987852811813354, 51.60422533750534, 50.20355969667435, 50.87621100246906, 50.746170580387115, 53.09064857661724, 49.783674627542496, 50.2580601722002, 48.51216405630112, 57.65719793736935, 55.48914447426796, 55.017179399728775, 52.26815611124039, 52.36260764300823, 58.76735016703606, 57.928978353738785, 57.47041516005993, 47.352694272994995, 44.021447226405144, 45.755024403333664, 57.4933697283268, 59.34005543589592, 58.25394071638584, 59.5299768447876, 55.97825042903423, 56.558483093976974, 59.65889632701874, 63.00050921738148, 44.02617037296295, 14.102008491754532, 6.44932790659368, 6.210092268884182, 8.46977211534977, 8.47877573221922, 5.455133579671383, 2.8782182559370995, 0.230028405203484, 0.27184070844668895, 0.05992552680254448, 7.750753797590733, 39.33904588222504, 29.589785523712635, 37.990236058831215, 28.307116851210594, 23.06336782872677, 46.55724115669727, 50.20362049341202, 59.43724662065506, 43.46226163208485, 8.297183476388454, 0.1293641622760333, 0.027904110684175976, 0.07675197019125335, 0.043570061461650766, 0.02695010211027693, 0.07168589945649728, 0.07956945220939815, 0.024435392224404495, 0.11152965598739684, 0.02858843763533514, 0.014998502119851764, 0.02686987409106223, 0.05433157013612799, 0.09414586340426467, 0.029019681096542627, 0.04153389025304932, 0.06705661973683164, 0.022010155662428588, 0.012422830368450377, 0.04738592135254294, 0.05065812467364594, 0.030643283134850208, 0.19306088652228937, 0.12098461738787591, 0.13930503744632006, 0.12914689112221822, 0.10603307280689478, 0.12879389600129798, 0.0671742798294872, 0.11249970237258822, 0.14366506598889828, 0.19480903021758422, 0.1435529868467711, 0.1333859792794101, 0.1599036727566272, 0.1684098577243276, 0.08648833172628656, 0.089748000173131, 0.09832712341449223, 0.15189817029749975, 0.15331259986851364, 0.28263741347473115, 0.3160853561712429, 14.993110075592995, 78.16009595990181, 68.35966184735298, 68.10509830713272, 57.2524930536747, 45.09792946279049, 41.060383915901184, 52.62928493320942, 55.803626999258995, 37.78729274868965, 1.1125191464088857, 0.38346746703609824, 0.22051536332583055, 0.7833913760259748, 3.36998644284904, 12.385132368654013, 11.782087627798319, 13.611599206924438, 23.898922093212605, 32.7566134929657, 44.66805852949619, 61.74251452088356, 66.33826151490211, 62.392458245158195, 55.043154805898666, 53.19361165165901, 61.54868692159653, 63.660883381962776, 64.21884924173355, 63.126278668642044, 53.58456127345562, 49.14744816720486, 55.49630329012871, 63.00164915621281, 61.726893559098244, 57.00846254825592, 56.31501115858555, 62.613260596990585, 55.25082506239414, 44.79853592813015, 43.987739235162735, 50.445105135440826, 59.563365653157234, 58.17949131131172, 52.75725066661835, 56.53120815753937, 59.624910950660706, 58.40202257037163, 57.37228162586689, 60.19028261303902, 56.03923335671425, 57.71794147789478, 52.24929392337799, 47.50601224601269, 43.992257192730904, 44.668807089328766, 43.91965828835964, 55.93293786048889, 60.99769748747349, 59.34960812330246, 53.47436338663101, 56.51742249727249, 52.802681028842926, 55.22904843091965, 49.57451105117798, 54.80636291205883, 34.53458368778229, 41.166888400912285, 65.6625285744667, 57.43528604507446, 60.75861431658268, 55.70966564118862, 57.02509805560112, 44.18474726378918, 44.257395565509796, 52.05087997019291, 58.225335851311684, 57.95332744717598, 57.253708988428116, 54.07884635031223, 54.11507360637188, 52.065273597836494, 52.413950487971306, 51.98495350778103, 53.217177987098694, 50.127863958477974, 52.45898187160492, 52.62237310409546, 54.883415177464485, 49.6257247030735, 51.88846528530121, 50.134278014302254, 60.54241731762886, 58.0433864146471, 57.98203870654106, 53.22013422846794, 53.83139982819557, 59.268778860569, 61.609517857432365, 60.4183691740036, 50.64230315387249, 46.00342087447643, 49.906248450279236, 61.19729317724705, 62.136549577116966, 60.099991858005524, 62.69901439547539, 59.74460832774639, 59.466242864727974, 58.81895899772644, 66.33802592754364, 48.64307463169098, 17.424023933708668, 13.852313440293074, 17.08998765796423, 14.928409047424793, 15.751347988843918, 14.498851597309113, 2.9002613481134176, 0.4698091058526188, 0.31787559448275715, 0.23619171901373193, 10.281221363693476, 52.692798525094986, 48.50003510713577, 51.987077593803406, 33.16612511873245, 28.37587036192417, 55.332300290465355, 57.912316247820854, 66.83228060603142, 50.84373414516449, 10.533585771918297, 0.23529311176389456, 0.14110878284554929, 0.11340305936755612, 0.15773734368849546, 0.22037344984710217, 0.1524829529807903, 0.1952788096969016, 0.17519878718303517, 0.19328584632603452, 0.16556722432142124, 0.14040521200513467, 0.13066263869404793, 0.13368242274736986, 0.24808301765006036, 0.21638712234562263, 0.1777792940265499, 0.208675168978516, 0.1909704940044321, 0.09207823997712694, 0.10777458170196041, 0.11477601030492224, 0.16095915518235415], [0.06365217312122695, 0.03110726273007458, 0.01792921917513013, 0.06952273935894482, 0.044350262760417536, 0.039751103104208596, 0.020637045163311996, 0.07557119097327814, 0.04493194697715808, 0.027900620734726544, 0.021259836939861998, 0.03225620195735246, 0.02247657877887832, 0.040138040349120274, 0.00697172831678472, 0.05200815438001882, 0.06874405575217679, 0.0315568242513109, 0.04596973660227377, 0.04634360833733808, 0.37387084448710084, 20.008559748530388, 57.851998284459114, 53.09249147772789, 46.46467052400112, 32.101106867194176, 18.003559336066246, 26.38134028762579, 38.35897967219353, 41.79978623986244, 10.675047431141138, 0.05355867528123781, 0.016021567535062786, 0.04029349431220908, 0.6942012556828558, 5.302774105221033, 3.356063039973378, 5.239717913791537, 6.3011277839541435, 17.423560358583927, 34.7033554315567, 45.48714637756348, 59.72279749810696, 57.86760784685612, 58.5220543295145, 52.82114043831825, 46.20407670736313, 48.20093035697937, 56.591909900307655, 57.89118178188801, 54.51858155429363, 43.32993373274803, 46.63726106286049, 50.85549831390381, 55.790627896785736, 57.89690427482128, 55.04331819713116, 53.632887080311775, 55.00967100262642, 50.253910794854164, 43.216897398233414, 37.16207429766655, 46.90909467637539, 54.575335308909416, 55.63764810562134, 52.52136692404747, 57.769120931625366, 51.56446047127247, 53.14634218811989, 48.48409116268158, 52.31803223490715, 50.94958506524563, 50.50962947309017, 44.298288971185684, 41.33537515997887, 38.046978414058685, 40.48272371292114, 39.84096094965935, 54.002341255545616, 54.58053342998028, 56.45606338977814, 52.4186622351408, 55.453209802508354, 49.75696586072445, 58.308927565813065, 45.80062955617905, 60.37196606397629, 28.5656625777483, 30.870692990720272, 58.87710727751255, 52.3741552233696, 57.93666914105415, 50.8219613134861, 55.24821080267429, 47.54725523293018, 39.00801904499531, 40.153919756412506, 44.25691679120064, 51.33259691298008, 55.40175296366215, 55.66304214298725, 53.73729407787323, 55.64036875963211, 52.56781183183193, 52.5608354061842, 50.90489946305752, 50.067933574318886, 49.62077356874943, 50.15023335814476, 48.58374461531639, 50.028100311756134, 48.38962063193321, 55.465764328837395, 52.887222692370415, 52.34692968428135, 54.34706635773182, 55.739509239792824, 49.9679609388113, 53.46587464213371, 57.3292451351881, 55.52746921777725, 47.13508374989033, 39.90092933177948, 44.48388621211052, 54.19584967195988, 57.92819179594517, 55.915508195757866, 57.731149569153786, 56.31044380366802, 51.953821778297424, 54.314889684319496, 56.65534369647503, 52.05290146172047, 44.36065122485161, 27.218817248940468, 8.204149268567562, 9.55927150323987, 8.116035796701908, 2.538272109813988, 4.075095131993294, 0.3419717639917508, 0.14388900162884966, 0.09973120744689368, 0.5614264053292572, 22.677411139011383, 40.27312695980072, 33.524179905653, 27.825300805270672, 23.7839687615633, 31.329940147697926, 41.402544155716896, 44.28632341325283, 49.19817544519901, 16.53615977615118, 0.6923042074777186, 0.06471726635936648, 0.024764484624029137, 0.028574604002642445, 0.017856408921943512, 0.03692055928695481, 0.08431164227658883, 0.01950161673448747, 0.10234649875201285, 0.008839416695991531, 0.023064567540131975, 0.022914154615136795, 0.04126250169065315, 0.10359943698858842, 0.0503900720650563, 0.04434504546225071, 0.03433664227486588, 0.04284575130441226, 0.05573927584919147, 0.02813690014590975, 0.045057191819068976, 0.019410501408856362, 0.022420010427595116, 0.02119974153174553, 0.00454675336186483, 0.03801147555350326, 0.027954786382906605, 0.03411539692024235, 0.08676252560690045, 0.023363705004157964, 0.06439695542212576, 0.07775715726893395, 0.08218652466894127, 0.05316712187777739, 0.007299308590518194, 0.018246734070999082, 0.04635859229892958, 0.05467467613925692, 0.01898336016893154, 0.03339965485793073, 0.05316243150446098, 0.038420788550865836, 0.258993033785373, 26.524833887815475, 67.54155814647675, 59.818271175026894, 53.38634870946407, 38.96277867257595, 25.034515857696533, 31.789185404777527, 38.198913261294365, 41.325974464416504, 13.420321270823479, 0.09309179105912335, 0.050180641701444983, 0.1062837999779731, 1.0922814323566854, 5.824148878455162, 6.946133673191071, 5.853798687458038, 5.6343799363821745, 15.41992312297225, 33.094225376844406, 47.74197958409786, 62.099710553884506, 60.36824606359005, 61.38809613883495, 52.88689211010933, 49.86770711839199, 52.027389630675316, 59.37318965792656, 60.18072992563248, 57.422689720988274, 46.49687759578228, 48.36179852485657, 53.06155353784561, 57.405685633420944, 59.38225977122784, 55.41265457868576, 54.2859960347414, 57.34997682273388, 51.863637417554855, 45.443273931741714, 39.364006742835045, 49.35044847428799, 54.72368314862251, 56.81801296770573, 53.80490005016327, 59.366737604141235, 55.13171285390854, 54.94512766599655, 51.72697775065899, 54.7640597820282, 53.77194441854954, 53.155112117528915, 47.450759410858154, 44.23336565494537, 40.81057392060757, 41.600277945399284, 42.39608444273472, 55.686695873737335, 56.58708035945892, 57.044636607170105, 52.336867824196815, 58.25807869434357, 52.46052838861942, 58.877369463443756, 47.39699989557266, 59.87713381648064, 31.640704572200775, 33.651621267199516, 59.63225215673447, 53.926064148545265, 59.90632005035877, 54.24564599990845, 57.011012211441994, 47.5955468416214, 40.39654813706875, 41.80531494319439, 47.236234322190285, 53.040316477417946, 56.47929534316063, 57.168274372816086, 56.199174374341965, 57.530919313430786, 54.32696543633938, 53.0408750474453, 51.78290314972401, 51.40562139451504, 49.8230405151844, 50.82387641072273, 49.10253457725048, 49.22753266990185, 49.14783954620361, 55.96185050904751, 55.278362184762955, 55.07909707725048, 56.75094276666641, 58.73726338148117, 50.10933235287666, 53.88593830168247, 57.94493369758129, 56.88895136117935, 49.07093167304993, 41.57635822892189, 47.1234829723835, 56.33656360208988, 60.515940338373184, 59.149005487561226, 60.86182437837124, 59.13382910192013, 55.61491772532463, 57.12699718773365, 60.345473885536194, 55.46618990600109, 42.0654071867466, 16.81193757802248, 4.051088970154524, 5.4076095297932625, 9.201615694910288, 9.265978541225195, 4.770273054018617, 0.9752192138694227, 0.07230225310195237, 0.04560961686365772, 0.7773615745827556, 27.05059077590704, 37.63926789164543, 39.01529185473919, 32.46319703757763, 27.852402850985527, 40.18089450895786, 46.20909623801708, 51.67388319969177, 58.05167376995087, 21.473447643220425, 0.5987779260613024, 0.09836259065195918, 0.04625149296771269, 0.015798669046489522, 0.0565940926753683, 0.03837140233372338, 0.03026497521204874, 0.017672155918262433, 0.06794439163058996, 0.035409457559580915, 0.02464139943185728, 0.02796152879454894, 0.012632862799364375, 0.004463304421733483, 0.01745348210533848, 0.12210502289235592, 0.008246823836088879, 0.039985302646528, 0.03627595950092655, 0.06101342252804898, 0.0363892631867202, 0.04188582410279196, 0.18226686806883663, 0.1093196812144015, 0.09026812695083208, 0.2277757940464653, 0.09817568818107247, 0.20099126879358664, 0.238559199788142, 0.14771217538509518, 0.09459055087063462, 0.2862008800730109, 0.19508941360982135, 0.15516103740083054, 0.1455996817094274, 0.14380597014678642, 0.0946553552057594, 0.12895510531961918, 0.14031668863026425, 0.16957051731878892, 0.15634246228728443, 0.14088919619098306, 0.6377164553850889, 32.85229995846748, 77.11598798632622, 67.30932220816612, 62.90728121995926, 44.41641703248024, 26.96691546589136, 35.542620196938515, 48.74471537768841, 54.67944972217083, 16.542167253792286, 0.15807865740498528, 0.1903984762611799, 0.22827373060863465, 1.9814810995012522, 9.523284584283829, 15.32763747498393, 16.607310958206654, 12.60949607938528, 23.52783590555191, 41.942582577466965, 54.016807079315186, 62.34280250966549, 61.3810171186924, 64.19584527611732, 56.14915765821934, 51.93119399249554, 53.37331920862198, 61.83252789080143, 62.352609783411026, 59.72118258476257, 48.23356680572033, 49.90365318953991, 55.299895629286766, 58.66333834826946, 60.735929533839226, 54.56952542066574, 55.073252990841866, 61.13511711359024, 55.06329372525215, 48.01385119557381, 41.565977185964584, 51.263888999819756, 58.49741265177727, 59.715327098965645, 52.99891009926796, 62.10922524333, 56.62460334599018, 57.63802796602249, 54.21311594545841, 56.740105748176575, 55.15822783112526, 56.289541125297546, 49.91999231278896, 45.819073766469955, 43.91051597893238, 45.87941072881222, 46.23843066394329, 59.05800797045231, 57.96978056430817, 59.668171629309654, 55.17048977315426, 59.68410797417164, 55.623034089803696, 60.35903535783291, 48.23219507932663, 59.592377096414566, 34.11059483885765, 36.18243746459484, 59.6981368213892, 55.28675973415375, 61.94577321410179, 56.541254818439484, 59.45036731660366, 51.45976088941097, 42.490725964307785, 44.42721225321293, 48.72520722448826, 55.93335583806038, 59.091871753335, 60.7901868224144, 58.41566003859043, 59.55052614212036, 54.27412927150726, 54.64339345693588, 53.40985804796219, 52.548983842134476, 51.97673834860325, 50.62692537903786, 50.260651633143425, 50.65083369612694, 49.944200813770294, 58.52817580103874, 59.645429849624634, 57.81340375542641, 60.7503117620945, 61.946916952729225, 50.879573822021484, 54.99188795685768, 60.550233498215675, 59.98760148882866, 51.73286363482475, 44.14833001792431, 50.02692997455597, 59.347632229328156, 63.732330948114395, 59.87545430660248, 62.586840614676476, 62.62423820793629, 58.47167283296585, 60.48171937465668, 62.88037106394768, 58.847476467490196, 53.00225771963596, 36.83992758393288, 17.163868993520737, 21.203398033976555, 19.96122568845749, 12.630435805767775, 9.475439451634884, 0.837999195791781, 0.35984647984150797, 0.20343124255305156, 0.9546889155171812, 33.02288040518761, 55.315904170274734, 44.05061446130276, 37.484479397535324, 37.52617076039314, 43.849430456757545, 54.7076366096735, 56.64422169327736, 65.054462403059, 25.343629270792007, 0.8893597929272801, 0.15965107537340373, 0.12623375369003043, 0.14430335751967505, 0.14054378581931815, 0.10030888035544194, 0.18120331107638776, 0.07837728844606318, 0.16297772264806554, 0.07942099298816174, 0.13321785314474255, 0.08056119899265468, 0.0898149493150413, 0.2566024870611727, 0.14131900359643623, 0.227576898469124, 0.1085893039999064, 0.15893175615929067, 0.10217285846010782, 0.181746949092485, 0.15964613266987726, 0.1984748092945665], [0.04753327106300276, 0.006924975796209765, 0.056491468494641595, 0.05113119557790924, 0.09902847523335367, 0.04806240009202156, 0.08504413461196236, 0.009182233261526562, 0.06955497825401835, 0.04289434713427909, 0.09383551951032132, 0.08014450533664785, 0.10894946084590629, 0.04642170082661323, 0.0008400534795782733, 0.03179784784151707, 0.038721796227036975, 0.08297642212710343, 0.0484850235079648, 0.03475129502476193, 1.6464382340200245, 39.55553166568279, 65.47992557287216, 42.47913658618927, 39.020664766430855, 21.24889489263296, 21.346859335899353, 33.484992608428, 43.66069458425045, 33.19610171020031, 2.4611082253977656, 0.06848576609627344, 0.29819745977874845, 0.1378292025765404, 1.7114364774897695, 6.379914656281471, 5.257149953395128, 4.575972380116582, 9.821762368083, 20.536205135285854, 40.802905932068825, 53.19399543106556, 61.005027294158936, 59.182911068201065, 60.23664012551308, 53.02173547446728, 48.246417716145515, 45.63483685255051, 49.36042673885822, 49.52716179192066, 45.04612684249878, 43.665543124079704, 49.841066747903824, 55.04904828965664, 59.9237497150898, 56.98267713189125, 52.39199906587601, 55.775098130106926, 57.0387165248394, 50.48952095210552, 41.700128987431526, 39.40360441803932, 44.88607183098793, 53.599186688661575, 55.19518464803696, 54.915204271674156, 54.305473789572716, 51.15681454539299, 49.41240414977074, 48.95107090473175, 49.684355556964874, 48.990459591150284, 46.225116178393364, 40.266245529055595, 40.170521065592766, 39.11326579749584, 42.51379832625389, 40.347272381186485, 52.31810063123703, 54.1119159758091, 57.40236461162567, 53.60534995794296, 57.02202782034874, 52.27874614298344, 56.58453829586506, 51.031808853149414, 59.734801054000854, 25.731767043471336, 30.534986704587936, 53.52776572108269, 45.27216911315918, 53.260089084506035, 51.25447690486908, 55.6840094178915, 50.707728043198586, 45.550754964351654, 37.7392291277647, 41.1825055629015, 41.66594602167606, 49.26323935389519, 48.99445317685604, 55.604829266667366, 52.71726541221142, 55.406217724084854, 53.11876706779003, 56.08963765203953, 52.1382524818182, 52.53526657819748, 50.83757847547531, 49.48902323842049, 45.5814915150404, 51.70265145599842, 53.38978372514248, 49.7666135430336, 50.01241475343704, 50.73857098817825, 54.56479847431183, 55.41094087064266, 50.61462923884392, 55.072189047932625, 54.97722074389458, 48.91015850007534, 40.64457982778549, 42.76842266321182, 51.628540232777596, 57.765526324510574, 54.24490503966808, 54.92910772562027, 58.36537353694439, 56.157585605978966, 54.15370613336563, 56.45926661789417, 54.5924723893404, 57.29739524424076, 32.40249529480934, 12.121654506772757, 4.578040419146419, 7.727947421371937, 5.044145258143544, 3.9117409475147724, 0.8373187948018312, 0.08585261544794776, 0.012987426634936128, 0.1057297051011119, 5.898595908656716, 34.25748735666275, 27.696008943021297, 15.911712683737278, 12.433731760829687, 20.809969045221806, 39.80218783020973, 47.6175856590271, 56.794720217585564, 27.236514799296856, 1.4265276468358934, 0.04732483146653976, 0.02868983727239538, 0.035049612415605225, 0.029968481649120804, 0.0037807358967256732, 0.060770717973355204, 0.06164803300634958, 0.08038376632612199, 0.03615684479882475, 0.07875746101490222, 0.03230142101529054, 0.09492913348367438, 0.022868328851473052, 0.05888429732294753, 0.05107511889946181, 0.012827614409616217, 0.04631113195500802, 0.036461978816078044, 0.04474246554309502, 0.03831826456007548, 0.021349770395318046, 0.04873506048170384, 0.05848600521858316, 0.035651330908876844, 0.02824817034706939, 0.04394011484691873, 0.016768765526649076, 0.03326042424305342, 0.03486426474410109, 0.00953309099713806, 0.03366482051205821, 0.03749356037587859, 0.062395813583862036, 0.015843036489968654, 0.1033683396235574, 0.05577218638791237, 0.029216363218438346, 0.05904743622522801, 0.02286422848555958, 0.029919941480329726, 0.16544387937756255, 1.8963499926030636, 47.893154472112656, 70.16258910298347, 52.21067659556866, 44.25495229661465, 26.760968416929245, 23.688365891575813, 34.832149520516396, 39.63900938630104, 35.49889214336872, 3.130775741301477, 0.057402836973778903, 0.17778287117835134, 0.24874305410776287, 3.1740770302712917, 8.900612946599722, 10.127456914633512, 4.9104085844010115, 7.183201052248478, 22.565771229565144, 44.42762263119221, 52.93620966374874, 61.04033499956131, 61.523646265268326, 61.21413767337799, 56.33763134479523, 50.178363248705864, 47.45304688811302, 52.91409105062485, 52.0822586864233, 47.11707651615143, 45.31135641038418, 51.46239414811134, 57.08611138164997, 60.302179008722305, 57.427792847156525, 52.64569245278835, 57.39864461123943, 58.25005352497101, 52.72824302315712, 44.50014553964138, 40.939174219965935, 47.25614905357361, 56.12027160823345, 57.22251646220684, 55.83420395851135, 56.86924181878567, 53.218044340610504, 52.11588688194752, 51.329823061823845, 52.036949917674065, 50.3032473474741, 49.77890968322754, 42.60620176792145, 41.50833807885647, 40.89641511440277, 43.957819640636444, 42.79401049017906, 53.93845908343792, 56.21443435549736, 58.37538979947567, 54.479284062981606, 58.876700699329376, 53.60044442117214, 57.286543026566505, 51.51695542037487, 59.93936687707901, 26.995792016386986, 31.89247526228428, 54.39942754805088, 48.03495526313782, 55.32098449766636, 53.159383088350296, 56.94632828235626, 53.59942227602005, 47.411914095282555, 40.20626574754715, 43.04233096539974, 42.60769508779049, 51.24693810939789, 51.839987486600876, 57.14357189834118, 56.24346099793911, 55.96977688372135, 55.25850065052509, 57.310922518372536, 52.49201349914074, 53.75320762395859, 53.08430291712284, 50.04250533878803, 47.18651778995991, 52.97301068902016, 53.75255785882473, 51.68748266994953, 52.938459143042564, 51.357975751161575, 57.091567888855934, 55.72579577565193, 50.04335269331932, 55.96242427825928, 57.22353480756283, 50.96904382109642, 42.55770117044449, 44.676961451768875, 54.15302217006683, 60.75456753373146, 54.61598552763462, 56.43633484840393, 60.596735402941704, 57.81961642205715, 57.5962720066309, 57.95800119638443, 59.13997337222099, 61.242446154356, 31.93137377500534, 11.532826703041792, 3.0608651926741004, 4.498378643766046, 6.139531005173922, 7.8508527763187885, 3.4303419291973114, 0.17394043126842007, 0.024320372322108597, 0.07523372158175334, 7.303995145484805, 37.39579975605011, 27.192925438284874, 18.538099452853203, 17.548541352152824, 27.565499246120453, 44.914346113801, 53.07184338569641, 63.365510031580925, 34.473748952150345, 2.0302403206005692, 0.04255842883139849, 0.0161512133126962, 0.03470261384791229, 0.07276431424543262, 0.11341661840560846, 0.024541831044189166, 0.013696658206754364, 0.07116375403711572, 0.0414261341211386, 0.04140171375183854, 0.03757575323106721, 0.0635550482547842, 0.03295287453511264, 0.016903352152439766, 0.0336138535203645, 0.027074599238403607, 0.07997133259777911, 0.06268033816013485, 0.02370618389250012, 0.057420385055593215, 0.04711814704933204, 0.11994072730885819, 0.1765564424567856, 0.11146908189402893, 0.2008201740682125, 0.2004135216702707, 0.12120637111365795, 0.12276542300242, 0.07646676283911802, 0.24254352349089459, 0.09982052491977811, 0.18329134356463328, 0.11741724709281698, 0.19053072697715834, 0.19489022117340937, 0.13640233461046591, 0.19000875967321917, 0.09585641731973737, 0.15467231831280515, 0.10103893102495931, 0.20078508532606065, 3.2641345728188753, 57.39630773663521, 78.52738425135612, 58.75974677503109, 53.53488273918629, 32.37576752901077, 30.11328913271427, 43.88792619109154, 54.94708076119423, 45.35201422870159, 3.6269602412357926, 0.19722078752238303, 0.5730322294402868, 0.4193229367956519, 4.8649160005152225, 17.92610429227352, 12.806296069175005, 11.72010250389576, 14.680451452732086, 26.10140360891819, 47.51464918255806, 56.41439102590084, 63.478873148560524, 63.5631488263607, 64.94516506791115, 59.60937738418579, 50.94689100980759, 49.20033372938633, 53.67688111960888, 53.32637272775173, 49.40410539507866, 47.27042108774185, 53.96356053650379, 59.45094868540764, 63.23243737220764, 57.00732260942459, 51.572793424129486, 58.77466857433319, 60.983528047800064, 55.57142145931721, 46.208233684301376, 43.9363431930542, 49.664976596832275, 59.66080382466316, 58.78240875899792, 56.92019708454609, 59.21428598463535, 55.602435395121574, 54.30909499526024, 54.33406725525856, 55.26070073246956, 53.87108489871025, 52.107318341732025, 43.70514079928398, 44.13761079311371, 44.38295602798462, 47.98042818903923, 44.45169813930988, 57.28635683655739, 59.577994868159294, 60.39173640310764, 57.362037375569344, 61.22552566230297, 56.596325263381004, 59.35210458934307, 54.1815510392189, 60.70519678294659, 29.98919539153576, 34.1291606426239, 54.57671083509922, 47.800036668777466, 57.36778266727924, 55.76520346105099, 60.36753550171852, 56.49754956364632, 50.100030452013016, 42.61803053319454, 44.63488630950451, 45.79755552113056, 52.18971312046051, 53.62212985754013, 59.515970796346664, 59.61263760924339, 59.53233651816845, 56.384543627500534, 59.231746047735214, 54.1553970426321, 54.74786885082722, 54.11973215639591, 50.70411443710327, 47.161526530981064, 53.72004680335522, 57.20234714448452, 54.598753452301025, 54.446149840950966, 54.55373726785183, 59.84502553939819, 59.27861653268337, 51.21474243700504, 57.09508650004864, 59.55389276146889, 53.9858615398407, 45.409505143761635, 47.29753263294697, 58.062864169478416, 63.83487984538078, 58.04485693573952, 59.25894118845463, 63.24921727180481, 61.921431720256805, 59.79714050889015, 62.74460814893246, 60.58871403336525, 64.03574466705322, 35.77112473547459, 17.89110817015171, 12.351186890155077, 16.70732919126749, 13.300599195063114, 12.135777398943901, 3.038983829319477, 0.1947677371208556, 0.24206538742873818, 0.16283386474242434, 9.6024732850492, 49.12018083035946, 39.99960243701935, 26.476960256695747, 20.296381004154682, 32.76297055184841, 53.65893468260765, 59.82508420944214, 70.65604582428932, 41.54632844030857, 2.985228826291859, 0.22661209164652973, 0.11839398022857495, 0.08823916941764764, 0.17460499482695013, 0.20582394150551409, 0.10888909455388784, 0.17843358626123518, 0.32371795910876244, 0.2151794105884619, 0.0843867847288493, 0.15076930430950597, 0.16640280839055777, 0.08047632698435336, 0.20206926797982305, 0.1172663239412941, 0.11852413066662848, 0.1649126352276653, 0.29537810012698174, 0.11665544734569266, 0.16950964636635035, 0.147877496201545], [0.02721896922594169, 0.017090299152187072, 0.07849676680052653, 0.015196095228020567, 0.06451230001403019, 0.06875061633763835, 0.04591662851453293, 0.07293713075341657, 0.07061476513626985, 0.06439699995098636, 0.017252584584639408, 0.04341255917097442, 0.017859076942841057, 0.027305648363835644, 0.0728121456631925, 0.024246361645055003, 0.04700234974734485, 0.060556697426363826, 0.0925941884634085, 0.08164109807694331, 2.0297748455777764, 47.71425247192383, 57.904291078448296, 44.52969655394554, 30.436389595270157, 16.818306036293507, 25.610545948147774, 31.892121881246567, 44.76330801844597, 18.969450406730175, 0.43428335746284574, 0.045153392711654305, 0.036052387513336726, 0.059317911945981905, 1.1165710352361202, 4.244704255834222, 4.209331003949046, 5.444976724684238, 15.561253689229488, 36.713261380791664, 59.661852568387985, 60.045609176158905, 61.251983642578125, 61.87758967280388, 57.9927047342062, 58.65328408777714, 50.28442695736885, 42.518373280763626, 41.589353531599045, 41.13677501678467, 43.1520576775074, 48.37909519672394, 54.995672553777695, 54.44818653166294, 58.218572214245796, 53.918825536966324, 55.718568563461304, 55.26231184601784, 54.850151762366295, 51.92196808755398, 44.225435480475426, 40.07321588695049, 41.995756924152374, 49.41712349653244, 55.45979484915733, 52.85194158554077, 53.96469287574291, 50.12130171060562, 45.423773378133774, 44.30323250591755, 47.90313273668289, 43.63760322332382, 42.219629511237144, 37.846618965268135, 40.40954723954201, 37.74825744330883, 41.64378181099892, 39.05370019376278, 46.56736001372337, 48.04048016667366, 54.769527688622475, 50.09297803044319, 53.77547062933445, 48.74782741069794, 57.52974897623062, 51.42753101885319, 59.768630638718605, 25.98762821406126, 28.38754713535309, 56.247359588742256, 49.12820599973202, 56.06289088726044, 49.13761809468269, 54.43423368036747, 50.764512196183205, 46.062161922454834, 38.4639148414135, 40.726047456264496, 40.12589246034622, 40.953674241900444, 44.557963237166405, 48.27321767807007, 51.49817682802677, 51.69225141406059, 50.970951318740845, 53.99088107049465, 52.225313410162926, 51.80295467376709, 51.89444616436958, 53.199239149689674, 47.692966014146805, 51.4591833204031, 54.37425009906292, 49.10973899066448, 41.733160614967346, 46.60126939415932, 53.714453503489494, 56.676949337124825, 53.48054185509682, 53.28977309167385, 54.859738647937775, 47.35487535595894, 40.26619233191013, 41.66473388671875, 50.070703625679016, 56.305678859353065, 56.39905124902725, 53.25589790940285, 57.07314267754555, 58.35022754967213, 53.62718738615513, 53.44435639679432, 55.74873134493828, 58.49724166095257, 53.73099401593208, 30.782754309475422, 8.882731106132269, 5.65800279378891, 9.300384745001793, 4.8587636556476355, 2.5162064563483, 0.25157298194244504, 0.045155570915085264, 0.13389644329436123, 1.2545341509394348, 20.131471753120422, 47.82300263643265, 30.97465541213751, 19.793044812977314, 28.8252342492342, 42.64665439724922, 43.383419662714005, 52.45395474135876, 33.27974662184715, 4.639367228373885, 0.1579320980818011, 0.042029407413792796, 0.06557609449373558, 0.0684436121082399, 0.03606172002037056, 0.09824831475270912, 0.019553134770831093, 0.08059795756707899, 0.024882970355974976, 0.04443398443982005, 0.08064100955380127, 0.0434957131074043, 0.03111615551461, 0.06751307024387643, 0.07225193548947573, 0.025344968416902702, 0.05420177221822087, 0.0362139122444205, 0.05155207123607397, 0.027847950514114928, 0.011976075093116378, 0.004335793710197322, 0.04592394980136305, 0.06276108382735401, 0.045983618474565446, 0.058491782838245854, 0.031819807991269045, 0.07502291453420185, 0.04975526491762139, 0.03130964825686533, 0.04386155851534568, 0.03697210144309793, 0.04426839645020664, 0.015489369725401048, 0.0562552540213801, 0.02336038574867416, 0.0307361944578588, 0.039433512138202786, 0.08239487520768307, 0.09173534548608586, 0.09687747151474468, 4.540567304939032, 58.24278451502323, 65.37438243627548, 50.05269639194012, 36.004052236676216, 20.729552060365677, 29.23175923526287, 30.948419719934464, 40.03330282866955, 21.524794287979603, 0.40187489648815244, 0.00951924530454562, 0.06432178328395821, 0.6069750362075865, 3.777042212896049, 6.447862610220909, 8.694953732192516, 4.728032145649195, 18.77195220440626, 40.79159773886204, 59.227125495672226, 62.122801914811134, 62.20554247498512, 62.86434352397919, 61.7120211571455, 59.2785519361496, 51.46550618112087, 44.56769451498985, 42.72977113723755, 43.3200428634882, 44.98710460960865, 51.65530979633331, 56.64241299033165, 56.27468392252922, 59.34444040060043, 53.88020060956478, 54.90326531231403, 54.98536750674248, 57.61871360242367, 52.78742104768753, 47.25827693939209, 41.55358985066414, 44.2305614054203, 52.63251096010208, 56.98409825563431, 54.28983002901077, 56.13623075187206, 51.1625674366951, 47.79613807797432, 46.54607355594635, 48.63345354795456, 46.461680084466934, 43.653554767370224, 40.204753428697586, 42.08816036581993, 40.41492775082588, 44.07581850886345, 40.45485220849514, 48.41112367808819, 51.76842212677002, 56.45433448255062, 52.80753716826439, 56.41782224178314, 51.45887553691864, 58.82823050022125, 53.559167236089706, 60.28732940554619, 27.912665717303753, 29.63142178952694, 56.48775368928909, 50.79167693853378, 57.25123152136803, 50.85568830370903, 56.80347494781017, 53.06186132133007, 47.86212533712387, 40.010112673044205, 42.0137869566679, 41.21488742530346, 43.506852239370346, 46.35701850056648, 50.746930539608, 53.537307009100914, 54.4528678804636, 52.133738324046135, 56.38713888823986, 54.12683017551899, 55.05689486861229, 54.761536717414856, 53.56617026031017, 47.08338372409344, 53.51485401391983, 57.3170629888773, 53.19427661597729, 45.23376077413559, 48.85120086371899, 54.27579738199711, 59.2451099306345, 53.92799064517021, 54.93892639875412, 58.059330359101295, 49.07745212316513, 42.891239672899246, 43.119090646505356, 51.55193634331226, 57.72349298000336, 59.35732550919056, 56.250445023179054, 59.749635457992554, 60.8496118336916, 55.54201103746891, 55.276279896497726, 58.18473502993584, 61.944044306874275, 53.53788837790489, 28.01337171345949, 7.532316343858838, 3.4417581791058183, 11.23286984860897, 5.971165839582682, 6.0087434481829405, 0.9213871462270617, 0.12870973645476624, 0.04978431999916211, 1.3223502994515002, 24.228090830147266, 42.56521336734295, 27.251630388200283, 22.032847926020622, 35.441287234425545, 49.785791113972664, 49.05563749372959, 57.36514560878277, 42.2222475707531, 6.041624033823609, 0.14414562145248055, 0.06319128457107581, 0.09124212156166323, 0.05886171376914717, 0.07790634379489347, 0.03393765255168546, 0.0416282209334895, 0.0314075004280312, 0.03391498736164067, 0.06418197008315474, 0.07323805679334328, 0.07977298620971851, 0.019120399592793547, 0.05165718903299421, 0.12015074025839567, 0.02599603230919456, 0.017283964443777222, 0.02708572217670735, 0.05346310521417763, 0.04680645986809395, 0.04062449217599351, 0.13826033100485802, 0.1451728874235414, 0.16831894463393837, 0.15445369645021856, 0.2085093583445996, 0.1830290092038922, 0.22157200350193307, 0.11646506420220248, 0.224105280067306, 0.10219837349723093, 0.15199681656667963, 0.23342708533164114, 0.13123480486683547, 0.28177583939395845, 0.1396008426672779, 0.25471196975558996, 0.12973706179764122, 0.12882263195933774, 0.2619105053599924, 0.16337937297066674, 8.505746684968472, 71.6028182208538, 71.94182842969894, 59.73474405705929, 43.700334057211876, 29.318295791745186, 35.55189549922943, 42.43603929877281, 58.27709287405014, 27.169661186635494, 0.8024678961373866, 0.12661578162806109, 0.24774442019406706, 0.8419036644045264, 5.001899600028992, 12.424829788506031, 12.674328200519085, 12.36436078324914, 21.47036600857973, 44.68320831656456, 62.15178295969963, 63.8790562748909, 64.24091085791588, 63.93530085682869, 63.97858053445816, 62.38283336162567, 54.47609983384609, 46.42662696540356, 43.981625363230705, 45.722585543990135, 48.27947974205017, 54.64076779782772, 60.50874352455139, 59.003800079226494, 61.601378694176674, 54.4021862000227, 56.14416852593422, 56.72851637005806, 59.78694185614586, 56.23143084347248, 49.47442062199116, 44.28514167666435, 46.78770259022713, 54.92898993194103, 59.08770717680454, 56.93730376660824, 58.56992416083813, 55.209950655698776, 49.68262664973736, 49.39586363732815, 51.55678868293762, 50.76837658882141, 47.61727787554264, 41.924643740057945, 45.98745033144951, 41.43459923565388, 46.923590898513794, 42.80933126807213, 49.807951524853706, 53.435734659433365, 58.19356195628643, 53.56224127113819, 58.05380545556545, 54.688056260347366, 62.84344084560871, 56.1992921680212, 60.749297216534615, 30.488663390278816, 31.949460804462433, 56.52211144566536, 53.829883709549904, 59.27748419344425, 52.617885544896126, 57.798694744706154, 56.06065660715103, 51.4590959250927, 41.823542565107346, 45.25269515812397, 44.2542265355587, 45.90706944465637, 48.62162098288536, 53.859978094697, 57.04227313399315, 57.94399134814739, 55.744011998176575, 58.980184346437454, 55.239212885499, 56.05588786303997, 57.056564167141914, 57.69599765539169, 49.0026531368494, 53.67336630821228, 60.08704975247383, 55.526982843875885, 47.1253676712513, 51.68072663247585, 57.003431618213654, 62.586437836289406, 56.19487300515175, 56.32783927023411, 61.60291001200676, 51.24901659786701, 44.01316747069359, 45.95826409757137, 54.15955401957035, 61.417168378829956, 61.53773590922356, 57.05473266541958, 60.87192803621292, 61.66103169322014, 58.71300548315048, 59.675813019275665, 60.641052424907684, 64.47724297642708, 59.16816785931587, 33.359884321689606, 12.08344565704465, 13.75207956880331, 21.54609404504299, 16.12120494246483, 7.908858563750982, 0.6226886773947626, 0.18039834802038968, 0.26381634059362113, 1.7831761529669166, 30.755477473139763, 63.63748423755169, 44.32598188519478, 28.648253045976162, 39.451071470975876, 57.53849230706692, 54.89321105182171, 65.18987193703651, 51.10251925885677, 9.183328226208687, 0.4621498746564612, 0.19181830866727978, 0.20404778915690258, 0.14447065244894475, 0.1585710427025333, 0.12521205382654443, 0.21515361353522167, 0.1817658293293789, 0.10523892284254543, 0.19303261069580913, 0.16847771970788017, 0.1101577292138245, 0.132610984146595, 0.10338952793972567, 0.21180992654990405, 0.13014647498494014, 0.14895773667376488, 0.20135881000896916, 0.11874703472130932, 0.1063519885065034, 0.12976686644833535], [0.06388374546077102, 0.024962120405689348, 0.033613593768677674, 0.022244759675231762, 0.04601035805535503, 0.05963881289062556, 0.05338102739187889, 0.10155223746551201, 0.02139458869351074, 0.02222030034317868, 0.0404282943054568, 0.08711212911293842, 0.030788708827458322, 0.0756294718303252, 0.019020293148059864, 0.07000308702117763, 0.04459337920707185, 0.13465034659020603, 0.037616612171404995, 0.04476435518881772, 12.185670621693134, 62.636636942625046, 53.08422692120075, 45.95466949045658, 26.94308314472437, 20.987510718405247, 23.935033455491066, 39.64461028575897, 38.49124677479267, 7.698369808495045, 0.09200853004585952, 0.10568312049144879, 0.15523874026257545, 0.39135513128712773, 2.830107850022614, 5.34867231734097, 10.321319662034512, 5.738555146381259, 26.56442016363144, 58.419608026742935, 61.657520681619644, 56.63038283586502, 59.77098271250725, 58.580316603183746, 61.98324300348759, 54.91345636546612, 54.72150206565857, 45.016203448176384, 43.49098429083824, 42.77507230639458, 48.553958013653755, 54.74892899394035, 56.20525024831295, 56.812575459480286, 56.62706941366196, 54.624873250722885, 57.187448143959045, 54.221752882003784, 57.697046399116516, 50.943262204527855, 44.55373026430607, 39.95118923485279, 38.99395599961281, 46.64448067545891, 53.916116282343864, 55.714191198349, 52.48552344739437, 45.645898059010506, 41.83947131037712, 40.45664571225643, 40.00574290752411, 37.47346378862858, 38.66844266653061, 37.51942612230778, 39.30487051606178, 41.18972137570381, 42.28129640221596, 40.99435105919838, 42.16824106872082, 43.29991154372692, 47.037573382258415, 45.93234568834305, 48.97988475859165, 50.167507231235504, 55.2383579313755, 49.70688834786415, 60.54190434515476, 30.13483017683029, 31.4315352961421, 57.65222780406475, 51.79051414132118, 56.63100600242615, 51.64225369691849, 51.18210218846798, 48.39781679213047, 46.24936267733574, 40.230082869529724, 39.02050897479057, 40.123658180236816, 40.70462800562382, 40.186822190880775, 41.96212872862816, 41.13200627267361, 44.25310179591179, 45.88089644908905, 48.70498090982437, 48.08355085551739, 48.48544389009476, 52.266089022159576, 52.48190984129906, 49.05107393860817, 50.11988818645477, 53.28145533800125, 50.145555809140205, 41.10495552420616, 42.98976078629494, 50.71049049496651, 55.63155323266983, 54.92555871605873, 52.76743412017822, 54.34544384479523, 46.796696707606316, 40.27210481464863, 41.173739433288574, 45.87026461958885, 54.41511310636997, 54.93725448846817, 53.35682049393654, 54.2838491499424, 55.57981140911579, 55.36099635064602, 57.87548862397671, 54.08068925142288, 54.54037718474865, 55.130534917116165, 45.02534195780754, 18.88739950954914, 4.546707300469279, 3.2899689115583897, 6.8690804578363895, 5.4444219544529915, 1.2873398093506694, 0.1551951316650957, 0.1009437208995223, 0.005483263948917738, 9.029506780207157, 30.80017827451229, 36.67097344994545, 23.109911531209946, 19.68266073614359, 29.620731063187122, 33.23781207203865, 46.67540341615677, 44.175414964556694, 14.561231900006533, 0.4653727251570672, 0.014505052768072346, 0.08930144991609268, 0.030128922844596673, 0.025665902758191805, 0.061455616378225386, 0.06281539419433102, 0.03560107266821433, 0.039541004807688296, 0.016199592064367607, 0.026513704433455132, 0.03349059021275025, 0.04493766522500664, 0.029079043633828405, 0.08585626681451686, 0.03040373085241299, 0.019705191552930046, 0.020922553085256368, 0.029933480109320953, 0.04665663138439413, 0.024855343908711802, 0.02712149183935253, 0.008678292724653147, 0.1002485140634235, 0.031504580765613355, 0.06258425972191617, 0.03854756221699063, 0.05306610815750901, 0.06516099645523354, 0.024195086662075482, 0.03610322091844864, 0.029265164994285442, 0.03965669449826237, 0.03710396253154613, 0.04205356803140603, 0.03917214628017973, 0.007791184125380823, 0.06394579642801546, 0.09242666346835904, 0.07731706369668245, 0.05680227623088285, 19.11596294492483, 71.39895915985107, 60.04231095314026, 51.58694386482239, 36.62693381309509, 27.414155267179012, 25.793110951781273, 34.93660591542721, 41.48545190691948, 8.982022628188133, 0.045871509646531194, 0.054355337415472604, 0.30492645339109004, 1.538499800954014, 5.353152751922607, 9.01807414367795, 6.903152754530311, 7.37009022384882, 28.40065073221922, 59.74965825676918, 63.88127535581589, 58.52583512663841, 61.75137184560299, 61.112979501485825, 61.5118782967329, 58.35445672273636, 56.36164605617523, 47.88552068173885, 44.85669940710068, 44.692559614777565, 49.42100688815117, 57.26799622178078, 57.658679857850075, 59.45088408887386, 56.918813958764076, 55.770800560712814, 57.09031395614147, 55.66966898739338, 58.81110101938248, 54.74135600030422, 44.982187673449516, 41.54728218913078, 41.750362291932106, 48.20819556713104, 57.30423867702484, 56.37031339108944, 54.66734737157822, 47.892056331038475, 43.164528608322144, 41.910888478159904, 42.66845762729645, 39.966859593987465, 40.18616862595081, 39.31686267256737, 41.62420906126499, 41.33553095161915, 43.962424993515015, 43.405526876449585, 44.789416417479515, 44.57503192126751, 49.589831829071045, 48.239635080099106, 49.44674290716648, 50.154979303479195, 56.25136457383633, 51.374535262584686, 61.891006752848625, 32.060304656624794, 32.488499879837036, 60.00865615904331, 53.90251301229, 57.85131432116032, 54.21608738601208, 53.41103218495846, 51.0823917388916, 46.89335212111473, 41.41176626086235, 41.11409403383732, 42.49736800789833, 42.683497220277786, 41.04209169745445, 44.33450102806091, 43.82560573518276, 46.49268262088299, 48.64773318171501, 49.61256600916386, 50.52982538938522, 51.3015715777874, 55.37266552448273, 53.99629198014736, 49.680384770035744, 52.30581969022751, 53.960459902882576, 51.91540203988552, 43.295336589217186, 44.54526051878929, 54.33846361935139, 58.992199301719666, 54.333326295018196, 53.9901515096426, 56.056450232863426, 47.68166162073612, 43.185093104839325, 42.50624433159828, 47.074773386120796, 55.117045640945435, 57.52689532935619, 55.33802278339863, 55.078226923942566, 56.60250373184681, 57.755597457289696, 59.12149116396904, 57.503469586372375, 56.618896052241325, 59.14340078830719, 45.86439773440361, 20.31797904521227, 4.910397185012698, 4.8835373762995005, 4.48189465329051, 7.340806620195508, 4.912969172000885, 0.4696010076440871, 0.11244174806051888, 0.043691922110156156, 11.641208287328482, 35.268822088837624, 39.44278031587601, 25.709652230143547, 25.56038673967123, 36.241258308291435, 38.816619515419006, 51.06919124722481, 51.62878341972828, 18.384758681058884, 0.6425797194242477, 0.008826793691696366, 0.017738978895067703, 0.11434542364440858, 0.04323982800997328, 0.06450767643400468, 0.05025432212278247, 0.07721308880718425, 0.013342691800062312, 0.07239784914418124, 0.006059402930986835, 0.03906799327523913, 0.018620637347339652, 0.01472611444114591, 0.018975460006913636, 0.021118971744726878, 0.0485097667115042, 0.03630471030191984, 0.07070537394611165, 0.04619868916051928, 0.01101783349440666, 0.11144464297103696, 0.11641311386483721, 0.21229204052360728, 0.11040156183298677, 0.1797892525792122, 0.17688533262116835, 0.25209880841430277, 0.22290984343271703, 0.1199152493791189, 0.16632403683615848, 0.14843489363556728, 0.14161868282826617, 0.23956011951668188, 0.17915961449034512, 0.11755688217817806, 0.11887607935932465, 0.11996688059298322, 0.29079667408950627, 0.12400255349348299, 0.3112257434986532, 25.637285113334656, 79.89180743694305, 66.12865716218948, 62.067184299230576, 39.65820215642452, 33.69098335504532, 33.38647909462452, 50.31300142407417, 53.99638317525387, 10.939896069467068, 0.20641742215957493, 0.3164715401362628, 0.5722437123768032, 1.585156072396785, 8.917857371270657, 14.371655322611332, 19.327467195689678, 9.852085690945387, 32.80139409005642, 61.923137828707695, 66.37807577848434, 61.560363695025444, 64.57540690898895, 61.47969402372837, 65.49876496195793, 59.60572578012943, 60.22438958287239, 51.07033498585224, 47.891379967331886, 47.491774410009384, 52.627685219049454, 59.28439602255821, 60.94146430492401, 59.165048226714134, 58.22085589170456, 56.81396618485451, 57.86112539470196, 56.50058940052986, 62.492563873529434, 57.41805016994476, 47.86268390715122, 44.18239898979664, 43.9913946390152, 51.404067277908325, 58.78764107823372, 58.75190019607544, 57.4028167873621, 49.84273485839367, 46.396285593509674, 44.042672887444496, 44.086754322052, 41.72037810087204, 43.03125835955143, 41.35053254663944, 44.44685719907284, 44.890654385089874, 45.97193956375122, 46.983376890420914, 47.37117648124695, 47.87041649222374, 51.75627797842026, 50.95889076590538, 53.15863452851772, 53.93351174890995, 59.45244200527668, 54.42773602902889, 62.36649043858051, 34.18322794139385, 35.208401530981064, 61.24759487807751, 57.751531675457954, 60.844387114048004, 58.492161333560944, 55.50087444484234, 52.54663176834583, 50.671299397945404, 43.332783579826355, 42.1282634139061, 44.043341651558876, 44.73999626934528, 44.224903509020805, 46.75969049334526, 46.54709570109844, 48.72839145362377, 50.778404250741005, 51.72652177512646, 52.602028995752335, 52.795708402991295, 56.52866989374161, 55.98479367792606, 51.21433585882187, 52.67532706260681, 57.86954194307327, 55.23776136338711, 46.113656759262085, 47.485360354185104, 56.22117519378662, 61.19290441274643, 57.075437754392624, 55.63677795231342, 58.63985560834408, 50.64448043704033, 43.85917693376541, 46.22841440141201, 49.948027208447456, 58.944416865706444, 58.669068440794945, 57.86891117691994, 57.352982461452484, 61.37774549424648, 60.1823790371418, 62.94135399162769, 59.26412791013718, 60.03207430243492, 60.56305781006813, 49.42659638822079, 21.765391677618027, 9.838899448513985, 9.532698579132557, 14.576040655374527, 15.023992918431759, 4.140354730188847, 0.45591598260216415, 0.16928998549701646, 0.09926312006427906, 13.674302492290735, 46.01010091602802, 49.13758769631386, 31.53109185397625, 30.344065949320793, 41.53106465935707, 46.53330244123936, 59.940066039562225, 61.07872813940048, 23.9207861199975, 0.799773900071159, 0.13847798807546496, 0.16793216695077717, 0.27008695411495864, 0.18871452833991498, 0.19861586188198999, 0.14845708385109901, 0.14987911301432177, 0.1490175983053632, 0.124307442602003, 0.09945168494596146, 0.199953731498681, 0.10567936522420496, 0.24817468773107976, 0.12247012244188227, 0.15415514528285712, 0.1893028584890999, 0.09187073548673652, 0.1200727182731498, 0.19625881570391357, 0.08667594665894285], [0.05982961905829143, 0.066533427889226, 0.00608065061896923, 0.03330645224195905, 0.01029944010952022, 0.017732589003571775, 0.03516519449476618, 0.08675333781866357, 0.09945883182808757, 0.04341998806921765, 0.015528416897723218, 0.06709330409648828, 0.048023901181295514, 0.03472672622592654, 0.016343728275387548, 0.010434118576085893, 0.012152756335126469, 0.05783831809822004, 0.0493600081972545, 0.22765449743019417, 21.877525560557842, 60.36003850400448, 49.759903103113174, 33.25718343257904, 20.522624664008617, 17.7654717117548, 29.128948152065277, 41.644553169608116, 24.359066002070904, 2.0676697371527553, 0.08336099563166499, 0.038937390127102844, 0.1619790293625556, 0.8624748105648905, 3.9092684676870704, 4.460817184299231, 6.936298850923777, 10.825154576450586, 45.6858529150486, 57.79141053557396, 58.46314609050751, 58.114374205470085, 55.91025307774544, 55.54151326417923, 58.10498870909214, 58.20081576704979, 54.791403114795685, 45.895624458789825, 43.686217814683914, 49.92788068950176, 55.013330206274986, 56.32206737995148, 57.358514964580536, 52.741728499531746, 53.487510681152344, 54.37395751476288, 52.86717876791954, 56.31419040262699, 54.26908694207668, 52.39143669605255, 43.6432459205389, 40.18508568406105, 39.91424381732941, 40.73767863214016, 46.10181279480457, 46.739285588264465, 45.51641620695591, 39.092507511377335, 40.08687235414982, 39.21459496021271, 39.996376410126686, 37.56660059094429, 39.21199209988117, 37.487754821777344, 40.259170308709145, 39.98895540833473, 42.66251854598522, 41.699536219239235, 39.79600556194782, 39.69706267118454, 40.889678075909615, 39.56324525177479, 42.81461678445339, 43.05374555289745, 55.28398968279362, 49.69301149249077, 61.73133932054043, 33.3039703220129, 32.44639053940773, 60.95795921981335, 47.16382920742035, 52.28043705224991, 47.52933159470558, 47.33639694750309, 43.72233487665653, 42.6354867964983, 37.53204144537449, 39.18338343501091, 40.77262155711651, 38.76240782439709, 41.222422420978546, 40.747561901807785, 38.5541258007288, 40.89540436863899, 39.97552692890167, 44.906210750341415, 44.60386857390404, 47.51063659787178, 49.690822809934616, 54.359351098537445, 51.727464124560356, 51.76786355674267, 51.48820996284485, 49.85275872051716, 41.050420850515366, 39.80842709541321, 47.626526579260826, 54.165895879268646, 54.132400676608086, 54.95800517499447, 51.42682045698166, 46.605255380272865, 44.36348967254162, 41.80140495300293, 42.44064085185528, 51.91339574754238, 54.90013048052788, 54.314699694514275, 52.52067156136036, 50.6656339019537, 58.667233139276505, 56.67708232998848, 55.44504404067993, 61.95832394063473, 57.98664405941963, 56.83844827115536, 32.67473928630352, 11.86804661527276, 10.349346958100796, 2.6191590819507837, 5.596194360405207, 4.302798863500357, 0.387113846372813, 0.026337626186432317, 0.00873214110470144, 2.0920176431536674, 24.0082935243845, 40.67529357969761, 22.281884662806988, 28.739837631583214, 40.89052923023701, 36.27050533890724, 38.571608662605286, 49.945967718958855, 25.007216222584248, 1.2953909835778177, 0.017180620379804168, 0.046534763314411975, 0.03968848439399153, 0.02910902268922655, 0.022412729958887212, 0.031687319788034074, 0.06293644590186886, 0.06624149667914025, 0.05002497993700672, 0.05214848708419595, 0.020965970579709392, 0.047870321141090244, 0.03637603069364559, 0.04107174747332465, 0.04829291116038803, 0.08029707605601288, 0.03104746047029039, 0.05205696914345026, 0.04499221307924017, 0.04539271307294257, 0.08472036526654847, 0.04408443288411945, 0.041229027119698, 0.05325689948222134, 0.08183424200979061, 0.04238795008859597, 0.03313358007289935, 0.07983851042808965, 0.02158291423256742, 0.04303969304601196, 0.06553492014063522, 0.02264488117361907, 0.017839426727732643, 0.025036687693500426, 0.03449705749517307, 0.06417052616598085, 0.04500074406678323, 0.01736114780214848, 0.01687363655946683, 0.2714775310596451, 28.099161610007286, 66.9513738155365, 57.68379271030426, 39.168518632650375, 27.381879799067974, 22.762167491018772, 28.733894750475883, 40.74861444532871, 29.52723518013954, 2.1731283282861114, 0.12474396644392982, 0.05636007866996806, 0.3247178695164621, 2.191649484448135, 6.925751566886902, 9.282503854483366, 6.025063097476959, 11.61783954128623, 43.77975359559059, 60.16257829964161, 60.10086581110954, 59.467299208045006, 58.43363307416439, 57.39694990217686, 60.85532292723656, 60.61984196305275, 57.48006284236908, 48.93007703125477, 45.65095938742161, 51.00835271179676, 56.64643697440624, 58.684905990958214, 58.28951820731163, 53.81645902991295, 53.44031721353531, 54.212226793169975, 53.663920015096664, 57.220840752124786, 55.07888428866863, 54.502231031656265, 45.691818594932556, 40.89223153889179, 41.461102813482285, 43.402456641197205, 48.92031155526638, 51.222410425543785, 47.51449719071388, 41.196405217051506, 42.4135635048151, 39.7518215328455, 40.61316691339016, 39.74386855959892, 40.632944852113724, 40.896118730306625, 42.10324935615063, 43.82322706282139, 44.44044694304466, 42.24912352859974, 42.90159031748772, 40.751464292407036, 42.79178000986576, 41.339319348335266, 45.43334886431694, 46.22177995741367, 56.01856246590614, 51.85940444469452, 63.67777727544308, 35.18883638083935, 34.09928284585476, 61.77023023366928, 50.004921555519104, 55.280273482203484, 47.712671756744385, 51.41831271350384, 46.24604545533657, 44.39806781709194, 40.130877792835236, 41.748295202851295, 42.570457085967064, 41.27038724720478, 42.05069437623024, 42.114033177495, 41.91711634397507, 43.01257476210594, 42.509804740548134, 47.43368312716484, 47.61035844683647, 49.46560509502888, 52.05792099237442, 57.053889110684395, 52.57600799202919, 54.37102787196636, 54.268969148397446, 52.64021314680576, 42.84870855510235, 41.63566544651985, 50.389700308442116, 57.05143444240093, 57.80355468392372, 56.65805295109749, 53.995927199721336, 47.98345662653446, 45.25090925395489, 42.858876809477806, 44.862167313694954, 52.58838012814522, 58.191456869244576, 56.99334315955639, 55.80279864370823, 53.728938326239586, 60.43489068746567, 58.778411373496056, 58.200511783361435, 61.908706203103065, 58.689009770751, 57.68398270010948, 35.464131608605385, 11.329103484749794, 4.5556007232517, 2.3443654272705317, 6.219504363834858, 8.557306118309498, 0.8700476260855794, 0.258885778603144, 0.05007656662201043, 2.571335560642183, 28.37618764489889, 41.24749727547169, 21.573555171489716, 29.26395870745182, 45.987043753266335, 41.416170224547386, 44.844426065683365, 57.44998745620251, 31.356755308806896, 1.9180034869350493, 0.06154699331091251, 0.07579921584692784, 0.08067056187428534, 0.02114066286594607, 0.03187463415088132, 0.032521208049729466, 0.05700369882106315, 0.00529683088643651, 0.11351539826137014, 0.06151626097562257, 0.02660796275449684, 0.0404798624367686, 0.05106705546495505, 0.03710356177180074, 0.05948781552433502, 0.08243067641160451, 0.044781981196138076, 0.038794552674517035, 0.04251730642863549, 0.03366253098647576, 0.22044140088837594, 0.12104907291359268, 0.07616572547703981, 0.10908566720900126, 0.13690521387616172, 0.11427488250774331, 0.1571384008275345, 0.17047185567207634, 0.2639400417683646, 0.10526471989578567, 0.1680106416461058, 0.20191611838527024, 0.21958479919703677, 0.12451835355022922, 0.14313928404590115, 0.15279946412192658, 0.10678785183699802, 0.20064725365955383, 0.15464028721908107, 0.762504490558058, 35.79797029495239, 77.02521845698357, 63.73525679111481, 46.22519597411156, 32.327483519911766, 28.65683488547802, 38.85544963181019, 54.98964607715607, 35.87589651346207, 3.2939055003225803, 0.3304491494782269, 0.3301798983011395, 0.6257289892528206, 4.356184573844075, 14.938717894256115, 13.824328891932964, 16.015855595469475, 14.726489782333374, 49.16339971125126, 62.58604645729065, 61.498073637485504, 64.547318816185, 61.306290328502655, 59.63761746883392, 61.208171993494034, 62.708418890833855, 59.044978469610214, 51.871765181422234, 47.60340102016926, 55.25745950639248, 61.52593374252319, 62.30347082018852, 60.468477085232735, 54.77228254079819, 53.99946480989456, 52.97077640891075, 53.64330992102623, 62.13727913796902, 59.5810005068779, 58.63040171563625, 47.93535500764847, 44.84967738389969, 43.08994621038437, 44.526595920324326, 50.694880932569504, 53.1687305867672, 47.920277416706085, 43.64537760615349, 44.6284456551075, 43.313849195837975, 43.34586627781391, 40.82866095006466, 42.030426263809204, 43.178242072463036, 44.671079367399216, 46.12556912004948, 45.92281959950924, 45.48981003463268, 45.31078644096851, 43.33410210907459, 43.97249065339565, 44.062557220458984, 45.67143268883228, 48.59920218586922, 58.52797821164131, 56.48694433271885, 67.13602870702744, 37.242873162031174, 36.86186000704765, 64.6876148879528, 52.357903495430946, 56.41065962612629, 51.19325838983059, 52.64655500650406, 48.53714771568775, 47.42106780409813, 41.74041822552681, 43.574321419000626, 44.87345650792122, 41.89464055001736, 44.96906317770481, 45.280680656433105, 43.42066526412964, 44.77554716169834, 44.612604305148125, 50.81502288579941, 49.15819399058819, 52.74365119636059, 54.29900273680687, 59.20730955898762, 55.907464027404785, 57.09181107580662, 55.63071347773075, 55.02226732671261, 45.94779945909977, 43.664300590753555, 52.55464933812618, 59.86222721636295, 58.192786797881126, 59.16499882936478, 55.39638005197048, 51.95953667163849, 48.429909870028496, 44.61728945374489, 47.13037960231304, 55.7731868326664, 61.04275926947594, 58.98167006671429, 58.49086180329323, 56.43011838197708, 61.29855394363403, 59.42105948925018, 59.720377027988434, 67.41523772478104, 62.122467532753944, 60.92915676534176, 37.46249757707119, 14.41569210961461, 15.25348350405693, 9.255870133638382, 14.67459786683321, 10.511118527501822, 1.252119499258697, 0.21678433462511748, 0.18401023233309388, 3.3070665691047907, 36.02490931749344, 55.48756755888462, 31.66435070335865, 34.68624494969845, 51.350102573633194, 48.42762619256973, 52.17036075890064, 64.45366904139519, 38.8059838861227, 2.844567261636257, 0.20583649864420295, 0.11656382179353386, 0.1165636139921844, 0.12528145947726443, 0.04857660082052462, 0.10926514078164473, 0.18251614063046873, 0.11144741118187085, 0.19110606954200193, 0.16177292010979727, 0.0788982241647318, 0.12918282591272146, 0.163875246362295, 0.1406275891349651, 0.1424849621253088, 0.15925732150208205, 0.13745383912464604, 0.1013852319738362, 0.1836505875689909, 0.19249906588811427], [0.024457482249999885, 0.029221523000160232, 0.03808985376963392, 0.03482010324660223, 0.1309163196128793, 0.02076694512652466, 0.021206183373578824, 0.09888353379210457, 0.002763989173217851, 0.054723056746297516, 0.04119455064937938, 0.06015998238581233, 0.06767217928427272, 0.01841204932134133, 0.05301138589857146, 0.02190376693761209, 0.07204712499515153, 0.03485735163849313, 0.12580023554619402, 1.1628677509725094, 28.42206258326769, 60.751501098275185, 49.95607137680054, 37.274035289883614, 18.79828669130802, 25.630741864442825, 39.78379301726818, 41.940705478191376, 15.43185543268919, 0.1396018371451646, 0.028667569131357595, 0.04827731863770168, 0.4922631400404498, 2.4800784699618816, 4.679309260100126, 8.60641848295927, 7.881294842809439, 28.400713428854942, 54.47744496166706, 60.816055834293365, 55.22226959466934, 55.429518073797226, 53.17066848278046, 53.16570594906807, 55.95908045768738, 54.0010417252779, 52.56070241332054, 43.542061150074005, 42.44024567306042, 49.02665264904499, 55.848578587174416, 55.67514069378376, 56.46132230758667, 52.900814563035965, 52.55648083984852, 50.26659831404686, 56.621742099523544, 54.79392997920513, 51.994555592536926, 46.21308982372284, 40.16039080917835, 39.091511964797974, 40.14068886637688, 39.75493736565113, 39.374099001288414, 40.548000410199165, 40.30671335756779, 38.25293876230717, 39.84215788543224, 38.66626538336277, 39.45102207362652, 39.066258519887924, 39.834923073649406, 37.01115399599075, 41.365876123309135, 39.81797598302364, 40.35894155502319, 37.08032928407192, 41.27201735973358, 41.569708585739136, 43.69411759078503, 38.690082505345345, 45.014155358076096, 39.56381902098656, 50.79253949224949, 48.498648181557655, 58.918418660759926, 36.488917618989944, 35.06859563291073, 59.35796007514, 49.6715996414423, 50.318138748407364, 44.188398867845535, 44.6266483515501, 41.68162398040295, 41.876777708530426, 38.85244399309158, 38.82833808660507, 39.18467536568642, 40.25837995111942, 40.27014032006264, 40.69591127336025, 39.09543335437775, 39.9825831502676, 37.580051869153976, 41.39792360365391, 39.57467123866081, 43.077346086502075, 46.551678255200386, 52.92579062283039, 53.08257780969143, 53.19450840353966, 50.68829208612442, 45.39620205760002, 40.42665012180805, 38.35156247019768, 42.93832294642925, 53.397018536925316, 54.00519110262394, 53.060254007577896, 48.824883475899696, 44.64833378791809, 44.501676857471466, 41.1676711589098, 41.92038036882877, 41.59040987491608, 51.00216284394264, 53.1525244563818, 53.09471815824509, 54.22834172844887, 50.23566037416458, 56.85144357383251, 60.635307133197784, 56.92730650305748, 56.653504595160484, 48.88875424861908, 48.95499609410763, 27.751871645450592, 14.488706141710281, 2.0818560384213924, 6.227638777345419, 8.825586922466755, 1.1761435260996222, 0.3381807846017182, 0.10870571728446521, 0.4325948527548462, 10.77451279386878, 36.69827498495579, 29.63525578379631, 19.479975812137127, 24.588647782802582, 38.06343913078308, 41.264318972826004, 45.58222867548466, 39.803734347224236, 5.280609894543886, 0.1746127725346014, 0.022815001830167603, 0.034383698148303665, 0.08433291222900152, 0.027180177166883368, 0.03121241577900946, 0.058151986813754775, 0.03523184306686744, 0.05888759616937023, 0.06541973882121965, 0.04952850540576037, 0.03488691138045397, 0.06403921797755174, 0.04814099353097845, 0.02077261327940505, 0.09362135795527138, 0.017067079206753988, 0.014916733216523426, 0.02017373906710418, 0.054472563351737335, 0.06157287200039718, 0.017698301780910697, 0.0356033584830584, 0.026545763357717078, 0.00926344462641282, 0.008223818185797427, 0.02227858862170251, 0.032160145783564076, 0.013247353654151084, 0.07468499985407107, 0.02027217939030379, 0.027208940955461003, 0.1273588347248733, 0.027827049780171365, 0.03424389607971534, 0.01878866329207085, 0.04696385454735719, 0.022723597066942602, 0.0800907590019051, 1.7712477617897093, 35.67311279475689, 69.74471792578697, 53.843296989798546, 46.41520477831364, 20.994667634367943, 28.592739924788475, 38.40629853308201, 39.97806139290333, 18.800817355513573, 0.19527285767253488, 0.051106611936120316, 0.29614657920319587, 1.2285272777080536, 4.7083064541220665, 8.563459888100624, 8.507288452237844, 6.786569785326719, 28.110486902296543, 56.15280166268349, 62.408732771873474, 57.80127100646496, 57.67449080944061, 55.423419401049614, 55.7989988476038, 59.2655224353075, 57.3812111467123, 55.523768216371536, 46.06960192322731, 43.72589908540249, 52.26244881749153, 57.592985183000565, 56.990956887602806, 56.41691789031029, 53.02684620022774, 51.67832896113396, 51.59759469330311, 57.339356392621994, 57.296266704797745, 54.31919105350971, 47.74590477347374, 41.476119607687, 41.29052236676216, 41.934625804424286, 40.01406066119671, 40.901624634861946, 44.07399840652943, 42.324306294322014, 40.93010030686855, 42.14486092329025, 40.72048835456371, 42.41314172744751, 41.41768254339695, 40.844889879226685, 39.859405159950256, 44.64430220425129, 40.74356831610203, 42.70783491432667, 40.74083246290684, 42.86918565630913, 43.373171612620354, 43.61156702041626, 41.33601352572441, 46.35725788772106, 41.247238889336586, 52.85804785788059, 52.276344671845436, 60.951028391718864, 38.66564981639385, 36.232408583164215, 62.20495730638504, 51.25395253300667, 53.95963914692402, 46.313579231500626, 47.48750723898411, 45.81287629902363, 43.74061569571495, 41.02040246129036, 41.286118403077126, 41.44264720380306, 43.36717173457146, 40.649470165371895, 42.82312072813511, 40.37699058651924, 41.31572641432285, 39.95552480220795, 43.305231258273125, 41.60068832337856, 46.27065673470497, 48.355992436409, 54.94602061808109, 55.6106049567461, 55.76613441109657, 52.83103130757809, 48.7580868601799, 42.027846202254295, 40.18266521394253, 45.25165021419525, 55.35278499126434, 57.05478586256504, 56.24595746397972, 51.953616589307785, 46.7391411960125, 45.81001505255699, 43.625953048467636, 42.78775982558727, 42.80653841793537, 52.34138198196888, 56.064570397138596, 56.74954064190388, 55.17879992723465, 51.64904773235321, 57.92443759739399, 61.78545221686363, 58.03590461611748, 58.38779613375664, 53.57598513364792, 49.93095092475414, 30.097867660224438, 13.2896757312119, 3.954546363092959, 5.122264316305518, 6.358469082042575, 2.724882233887911, 0.46961614745669067, 0.07202846740256064, 0.5486751801799983, 14.764751829206944, 42.16356731951237, 30.99791206419468, 18.228435069322586, 29.22255802899599, 43.33260118961334, 47.64405503869057, 52.700626105070114, 47.364314049482346, 8.118992988020182, 0.19019696832401678, 0.12252524174982682, 0.077815883414587, 0.03169211406202521, 0.019430864085734356, 0.01496097171184374, 0.04918640130199492, 0.010653666267899098, 0.014093841728026746, 0.04453256020497065, 0.06390635127900168, 0.03034663928701775, 0.03173960038111545, 0.010195019931416027, 0.04286135867005214, 0.008894336551747983, 0.03692008802318014, 0.007933464039524551, 0.0178302519270801, 0.03969596895331051, 0.10813510220032185, 0.19388147920835763, 0.1679480043821968, 0.10264939890475944, 0.22885496582603082, 0.08604452741565183, 0.15200376306893304, 0.13260843115858734, 0.08450799970887601, 0.1718059997074306, 0.17530681419884786, 0.1499818856245838, 0.21191271400311962, 0.10432077484438196, 0.16046638396801427, 0.14585382275981829, 0.15919431316433474, 0.1914693953585811, 0.189852062612772, 3.0760240042582154, 46.847093403339386, 76.1623227596283, 63.10775466263294, 52.920109927654266, 28.891113214194775, 37.523051127791405, 50.13902395963669, 55.32991781830788, 23.029707334935665, 0.43917568400502205, 0.15196046617347747, 0.3484343859599903, 1.4557375106960535, 6.394134918227792, 14.473949633538723, 16.55726384371519, 17.018289305269718, 32.597953006625175, 58.96866336464882, 66.12477377057076, 61.29667304456234, 60.72837173938751, 58.471874222159386, 56.58755153417587, 61.256554797291756, 58.185589984059334, 57.60175511240959, 47.29931093752384, 45.85663855075836, 54.691373482346535, 58.95318679511547, 57.933078333735466, 59.07009892165661, 53.37089493870735, 51.993157267570496, 51.809706911444664, 60.14952979981899, 60.22304445505142, 57.23983593285084, 49.946226105093956, 42.728422209620476, 43.293638080358505, 44.237724021077156, 43.4003097563982, 43.2358355820179, 45.40815621614456, 45.318222641944885, 43.389955312013626, 44.29743781685829, 42.16999277472496, 43.58024910092354, 42.6245091855526, 44.37629498541355, 42.26151466369629, 48.019398897886276, 42.2312530875206, 44.453354850411415, 42.08502173423767, 44.4532560557127, 46.848134547472, 47.23079301416874, 43.60985331237316, 49.13568779826164, 43.168423399329185, 54.81923662126064, 55.04853151738644, 62.85585477948189, 41.70198708772659, 39.14439372718334, 63.01852025091648, 54.261384755373, 54.937094897031784, 48.04220147430897, 49.852310344576836, 48.02402704954147, 46.840010583400726, 44.135361313819885, 43.50599728524685, 43.033963814377785, 45.679845437407494, 43.4017688781023, 43.64939019083977, 43.67606855928898, 44.478403106331825, 41.796066239476204, 46.66621930897236, 43.98455120623112, 48.676197454333305, 50.75834892690182, 57.91923567652702, 59.44978974759579, 57.810717299580574, 56.226392313838005, 51.3570562005043, 43.469344452023506, 43.71372453868389, 47.27446027100086, 57.92288348078728, 59.56631429493427, 58.77164013683796, 55.58514632284641, 50.268308222293854, 49.47456881403923, 45.686210095882416, 45.92788092792034, 44.64101158082485, 55.01104272902012, 59.81934271752834, 60.687341541051865, 58.0659344047308, 54.30010847747326, 58.16865809261799, 63.87292340397835, 58.668342679739, 59.82323370873928, 52.6079186797142, 52.785460352897644, 31.906819492578506, 18.393899090588093, 5.695144850760698, 16.905203573405743, 19.06706716865301, 2.5255083572119474, 1.0707612871192396, 0.15423753851791844, 0.6472823827061802, 17.589453756809235, 54.37667056918144, 44.380740746855736, 28.04866421967745, 35.63030049204826, 50.65532125532627, 54.76713761687279, 60.32288409769535, 56.01881705224514, 12.396258171647787, 0.2947940299054608, 0.2245457743993029, 0.08827125246170908, 0.24751947523327544, 0.10696017110603862, 0.1261917332885787, 0.12856181157985702, 0.12470190151361749, 0.10564261407125741, 0.18348345591221005, 0.16621085931546986, 0.11059538112021983, 0.12661153654335067, 0.16213250550208613, 0.11670707855955698, 0.13650298467837274, 0.09192947647534311, 0.100430815218715, 0.12290589671465568, 0.13342584745259956], [0.04111950096557848, 0.08211395746911876, 0.055577276143594645, 0.037233920011203736, 0.05612687731627375, 0.047226912502082996, 0.01899969112855615, 0.020352782194095198, 0.02390478261077078, 0.04039144296257291, 0.023255412670550868, 0.026243835418426897, 0.056245279556605965, 0.021717248528148048, 0.032765790238045156, 0.03494256132398732, 0.02894652760005556, 0.018367958327871747, 0.16710596362827346, 3.9724861504510045, 45.68750202655792, 55.82934781908989, 50.5335757881403, 30.948072038590908, 25.02824429422617, 24.667508751153946, 43.017560094594955, 35.15881799161434, 7.186317835003138, 0.019479482180031482, 0.17576253740116954, 0.0836422918655444, 0.5212528828997165, 1.9112913846038282, 5.897203758358955, 7.583054546266794, 11.497511398047209, 46.72824718058109, 59.02008220553398, 55.08220911026001, 53.72682183980942, 53.00719365477562, 50.771982595324516, 49.60750088095665, 48.70700240135193, 51.21437385678291, 45.111791118979454, 40.91183088719845, 40.889035910367966, 49.96456392109394, 56.10927499830723, 55.7377765327692, 53.00642229616642, 49.9384593218565, 49.901916682720184, 55.51041193306446, 54.653994888067245, 52.523023635149, 48.76471370458603, 42.44497261941433, 40.604784563183784, 38.69806967675686, 39.61113788187504, 37.094164341688156, 39.93079952895641, 41.06699176132679, 40.86353927850723, 37.75546945631504, 38.81280831992626, 38.637766912579536, 40.222194492816925, 38.50826606154442, 39.65875692665577, 38.007566928863525, 41.07198089361191, 37.52610996365547, 38.810247257351875, 44.31084729731083, 51.216665133833885, 50.454228445887566, 52.531645372509956, 46.85332886874676, 50.38477957248688, 45.083855018019676, 50.78196085989475, 48.878270611166954, 58.78298632800579, 36.25067800283432, 30.795544423162937, 61.48782938718796, 50.05243420600891, 51.42715863883495, 45.4370878636837, 47.418054565787315, 45.54104648530483, 43.66505675017834, 40.9976264834404, 40.475135520100594, 39.81370121240616, 42.44770847260952, 38.57175685465336, 38.9883778989315, 39.43304143846035, 38.83749559521675, 37.72073931992054, 37.88163408637047, 38.10901388525963, 40.3349344432354, 42.13959440588951, 47.45480619370937, 48.42290684580803, 46.77754573523998, 44.24707151949406, 40.24622820317745, 37.81283877789974, 39.70104105770588, 38.064214289188385, 44.613212272524834, 46.23087286949158, 48.27700227499008, 44.65988136827946, 44.71088223159313, 42.300648763775826, 39.110142365098, 40.43683737516403, 41.73785716295242, 46.876256838440895, 54.01041202247143, 52.150632217526436, 49.604350849986076, 55.93393720686436, 48.05504098534584, 53.423172533512115, 54.77274231612682, 55.71665346622467, 55.32671079039574, 54.382434859871864, 33.12590427696705, 20.958960950374603, 8.116816654801369, 2.750538932159543, 7.7929054107517, 0.9039964887779206, 0.3604865673696622, 0.038242454174906015, 0.02257314888993278, 5.617091339081526, 26.80746842175722, 34.24500122666359, 22.72800162434578, 23.38075339794159, 37.2152828425169, 44.87680412828922, 44.46475803852081, 41.95866331458092, 20.300767868757248, 0.5667612596880645, 0.019235740473959595, 0.05491220421390608, 0.035098590451525524, 0.020732639350171667, 0.05084560973045882, 0.07458780819433741, 0.0754870982200373, 0.012982611024199286, 0.014462044382526074, 0.03636709152488038, 0.08721847887500189, 0.05562854741583578, 0.03530292597133666, 0.04295759295928292, 0.024553167349949945, 0.03429133786994498, 0.008231354695453774, 0.07118144683772698, 0.031240120151778683, 0.026803041837411, 0.10743637758423574, 0.046890730736777186, 0.031109908486541826, 0.03216319972125348, 0.06863554634037428, 0.0562259057915071, 0.03737808219739236, 0.005292783862387296, 0.018871318134188186, 0.005921516994931153, 0.05721572299080435, 0.07386319746728987, 0.02806225122185424, 0.035319371963851154, 0.019903868196706753, 0.021386131920735352, 0.017821479741542134, 0.12542261596536264, 6.863855738192797, 57.6461823284626, 60.038799941539764, 57.036182060837746, 38.37595336139202, 30.068189352750778, 29.843138828873634, 42.16028429567814, 38.71540054678917, 7.824767176061869, 0.04012431061710231, 0.024994676568894647, 0.08677315316163003, 2.020543715916574, 6.836598850786686, 7.113010743632913, 6.670898292213678, 10.96573943272233, 48.14815878868103, 60.75472712516785, 59.45152625441551, 56.02609746158123, 55.2850878238678, 52.722493931651115, 50.40785193443298, 51.22309438884258, 51.5968157351017, 48.283659517765045, 42.46498614549637, 41.58184513449669, 51.3756600022316, 57.71376930177212, 58.267441391944885, 53.83183300495148, 50.55443286895752, 49.87482413649559, 55.74987508356571, 56.581886038184166, 54.07978489995003, 50.942388251423836, 43.475534319877625, 41.893386617302895, 39.617000967264175, 41.52063801884651, 38.831917494535446, 41.16036415100098, 41.94376051425934, 43.2221183180809, 40.94115011394024, 40.5833575129509, 40.20561218261719, 41.52001105248928, 40.947290584445, 40.57548813521862, 40.47762058675289, 42.4723045527935, 39.79740008711815, 40.92599652707577, 45.64113311469555, 53.18873271346092, 52.35758811235428, 54.431452229619026, 49.77060712873936, 51.1128319054842, 45.6479499489069, 54.248799830675125, 51.248933002352715, 60.32002665102482, 38.09164501726627, 32.618730291724205, 62.94126279652119, 51.384559124708176, 53.72376300394535, 47.96832203865051, 49.07835267484188, 47.507638558745384, 46.5972226113081, 43.303935527801514, 43.119090646505356, 40.93402549624443, 43.85112516582012, 39.809042662382126, 40.67901737987995, 41.59143581986427, 40.45769065618515, 40.02061910927296, 40.48732906579971, 40.395833775401115, 42.43672326207161, 44.467349499464035, 48.12400348484516, 49.94628690183163, 49.95017409324646, 46.37424677610397, 42.82818205654621, 40.893694460392, 41.12589240074158, 41.18908300995827, 46.77861347794533, 50.240569710731506, 50.06738640367985, 46.99077509343624, 46.28570772707462, 45.04844851791859, 44.37581621110439, 42.24947310984135, 44.07658986747265, 48.14467057585716, 55.53069904446602, 54.76039677858353, 54.78486366569996, 55.251231640577316, 50.914072170853615, 54.026093780994415, 57.103309258818626, 54.61684428155422, 54.52219516038895, 53.946514651179314, 38.301857337355614, 21.53082836419344, 9.635964687913656, 6.284568747505546, 6.709211636334658, 3.6711561447009444, 0.8714179275557399, 0.22795773897087201, 0.051947391038993374, 6.038711965084076, 32.399626448750496, 37.68895402550697, 29.094575196504593, 31.412319727241993, 41.94826327264309, 49.66197095811367, 51.27146199345589, 49.88128378987312, 25.024982169270515, 0.8974499744363129, 0.0339900964172557, 0.040308856769115664, 0.02663291190401651, 0.03532180249749217, 0.07827036723028868, 0.024795998069748748, 0.03751299351279158, 0.03897868693456985, 0.011305146690574475, 0.05628921469906345, 0.05988643417367712, 0.06187690392835066, 0.06983237079111859, 0.060753151337848976, 0.0036126167196925962, 0.06806833771406673, 0.010906644001806853, 0.06987027227296494, 0.07753896585199982, 0.08975230462965555, 0.27797975402791053, 0.15731451247120276, 0.1556003888254054, 0.12122036059736274, 0.15284713968867436, 0.15359108336269855, 0.19160822150297463, 0.16331306949723512, 0.11419708316680044, 0.12922932888614014, 0.17384162172675133, 0.3289001091616228, 0.1745641470188275, 0.19530652149114758, 0.1378578197909519, 0.19276186038041487, 0.1201087272784207, 0.3216579055879265, 10.556753128767014, 67.1587210893631, 68.55454578995705, 65.7573714852333, 44.18556421995163, 36.652362048625946, 33.52964401245117, 54.093828946352005, 47.41610907018185, 10.168395917862654, 0.2736788894981146, 0.3844270046101883, 0.16970664204563946, 2.5376475183293223, 9.211476165801287, 15.896448902785778, 15.32168224453926, 15.089049227535725, 50.11048749089241, 62.88946017622948, 62.044837698340416, 58.29405136406422, 57.85669103264809, 55.47947399318218, 53.472908064723015, 52.98333093523979, 55.725180208683014, 50.36594018340111, 45.2862511575222, 44.117490872740746, 54.32099975645542, 61.32063075900078, 60.04437044262886, 54.12733554840088, 50.07016025483608, 50.26741907000542, 57.63819135725498, 58.77145394682884, 57.210068330168724, 53.970225378870964, 45.405192375183105, 43.634802773594856, 41.31024330854416, 43.30089949071407, 40.66802076995373, 44.63485971093178, 45.07374756038189, 45.38327895104885, 42.463637217879295, 43.176577761769295, 42.60776348412037, 43.89119401574135, 43.60240191221237, 44.23274628818035, 43.22307966649532, 45.039032623171806, 42.34314188361168, 43.6849220842123, 48.31974618136883, 55.986613780260086, 55.94886660575867, 56.0975906252861, 52.30674684047699, 53.83686013519764, 49.34419400990009, 56.07309713959694, 53.30453909933567, 60.1575967669487, 40.23601435124874, 33.91629606485367, 63.1684336066246, 54.29271027445793, 56.693277060985565, 50.53415335714817, 50.57325705885887, 49.87644664943218, 48.45748119056225, 46.56739421188831, 45.06160341203213, 43.70190717279911, 47.6235019415617, 42.42595463991165, 42.70675577223301, 44.56264078617096, 43.61234597861767, 42.753907442092896, 41.539576202631, 42.29117587208748, 45.63925601541996, 46.97339862585068, 52.201078310608864, 53.357838839292526, 51.11415423452854, 49.164889231324196, 44.00548428297043, 42.39120550453663, 42.86792032420635, 43.636919260025024, 49.72940593957901, 52.50845901668072, 53.86308632791042, 49.96685519814491, 50.48651911318302, 47.05927401781082, 43.49057011306286, 45.403987839818, 45.46356104314327, 51.33346326649189, 59.21263687312603, 57.16748021543026, 57.301575019955635, 59.01613041758537, 55.176702439785004, 55.81531137228012, 57.04027824103832, 57.27661795914173, 55.574609488248825, 55.48212245106697, 35.69388248026371, 25.118548348546028, 14.615260250866413, 10.251924935728312, 17.379471324384212, 5.767719531431794, 1.0475883493199944, 0.3015704615972936, 0.10774600159493275, 7.953484794124961, 43.465149477124214, 46.85178615152836, 35.88567338883877, 33.303742334246635, 48.736025243997574, 57.533791959285736, 58.34379829466343, 57.16859735548496, 34.376394376158714, 1.413517501205206, 0.10771971472422592, 0.10931761804386042, 0.141463573963847, 0.12069449701812118, 0.18477828096365556, 0.15524139715125784, 0.1572497229790315, 0.18858290102798492, 0.1236662121664267, 0.11698240050463937, 0.14610189304221421, 0.15279790561180562, 0.18972165242303163, 0.23073300020769238, 0.11842147679999471, 0.1800352448481135, 0.09055015791091137, 0.12844061886426061, 0.20894523651804775], [0.01191145165648777, 0.035694824473466724, 0.04470958840101957, 0.01650842939852737, 0.04778805036039557, 0.052281498501542956, 0.009573868301231414, 0.050270979627384804, 0.02673951214092085, 0.04694860712334048, 0.08392861986067146, 0.012348104446573416, 0.0766918042791076, 0.06034665850165766, 0.05375121807446703, 0.03006451741384808, 0.013297362347657327, 0.020718878076877445, 0.1031738449819386, 12.48879175633192, 54.97436709702015, 54.09851409494877, 46.82937875390053, 25.95394492149353, 19.904927909374237, 25.12614794075489, 38.181445598602295, 27.07407921552658, 2.4197008972987533, 0.07785319117829204, 0.065252124768449, 0.41737239458598197, 3.237934266217053, 4.762102542445064, 4.751176228746772, 7.935943985357881, 23.89111541211605, 60.15128530561924, 57.95804299414158, 56.690248623490334, 52.784415408968925, 47.81356394290924, 47.101174369454384, 43.28316204249859, 46.06511816382408, 42.85433605313301, 40.45771345496178, 39.249587282538414, 39.66186136007309, 47.46859945356846, 54.48072038590908, 53.146665170788765, 52.46234469115734, 53.81834372878075, 53.22058640420437, 52.131260856986046, 53.70304651558399, 49.228114038705826, 44.75750952959061, 40.14758549630642, 42.49432437121868, 37.65365771949291, 39.53585632145405, 39.05195988714695, 39.850202053785324, 38.29651482403278, 40.354279205203056, 38.113794028759, 39.322383776307106, 37.461954206228256, 40.01317910850048, 39.0862150490284, 37.82620646059513, 37.920076623559, 38.56387987732887, 37.58992373943329, 45.53106442093849, 51.24886080622673, 55.43699987232685, 53.653937950730324, 54.831954538822174, 50.6414519995451, 54.67423640191555, 50.109719932079315, 53.1538961827755, 47.14606136083603, 59.37934912741184, 30.652742385864258, 29.901252910494804, 56.2367657572031, 48.605931624770164, 56.26305274665356, 49.05661404132843, 50.289875864982605, 47.99279272556305, 48.59609015285969, 44.9599664658308, 43.29362288117409, 39.16926719248295, 39.743416383862495, 40.16528494656086, 39.33012396097183, 36.45276255905628, 39.8040459305048, 39.36292380094528, 39.66282270848751, 37.22877971827984, 37.981222942471504, 37.8564490377903, 38.764026537537575, 38.26743118464947, 38.37431184947491, 36.48654654622078, 38.58779579401016, 37.08458885550499, 37.134225592017174, 38.72389309108257, 38.450938537716866, 37.51925513148308, 41.0194107145071, 40.01187577843666, 39.00503620505333, 39.72415141761303, 38.90906475484371, 41.27887599170208, 45.037204921245575, 52.129835933446884, 52.908197566866875, 55.91031767427921, 53.58499825000763, 47.872787564992905, 46.594699546694756, 50.117068737745285, 53.49804371595383, 52.372669503092766, 53.40452313423157, 54.38698321580887, 50.37806153297424, 23.292144052684307, 12.031695283949375, 3.4060816559940577, 2.249723430722952, 4.053367897868156, 0.604939057957381, 0.08259001551778056, 0.06889155018143356, 0.6960670743137598, 18.994643054902554, 36.960407719016075, 19.623927287757397, 11.619093474000692, 38.1557247787714, 44.28470849990845, 44.61939454078674, 43.125812485814095, 32.65385940670967, 2.6065190602093935, 0.06656038269284181, 0.02587001748906914, 0.07049222171190195, 0.06577104184543714, 0.0305661331731244, 0.012810672105842968, 0.05979814086458646, 0.047621549529139884, 0.06542577248183079, 0.03429867028899025, 0.03819388432020787, 0.0516538716328796, 0.02381986236287048, 0.06009547862049658, 0.05475223428220488, 0.02937750945420703, 0.030746909214940388, 0.045426985452650115, 0.10429367161123082, 0.034549271294963546, 0.05069032275059726, 0.06282332033151761, 0.07230660208733752, 0.11726972297765315, 0.05658421097905375, 0.027341408749634866, 0.034173896710854024, 0.029200902426964603, 0.016182454019144643, 0.02280946540849982, 0.019387120046303608, 0.057023232147912495, 0.05093112740723882, 0.06804107120842673, 0.025249927130062133, 0.05064189390395768, 0.0950198907230515, 0.1452421594876796, 18.96900963038206, 63.7263310700655, 61.23390041291714, 54.39049802720547, 32.486311197280884, 26.39995738863945, 30.011579990386963, 39.210399985313416, 34.16405037045479, 2.962965820915997, 0.06988726003328338, 0.0434064772707643, 1.025790343992412, 5.0323739647865295, 8.737083971500397, 8.75165143981576, 4.677008958533406, 25.325758829712868, 60.91184489428997, 61.58816300332546, 56.98213376104832, 55.56302011013031, 50.64095422625542, 49.066360518336296, 45.26213005185127, 48.05627591907978, 46.09366603195667, 43.173036351799965, 41.38545647263527, 41.47553823888302, 49.93654042482376, 59.12416622042656, 56.773103177547455, 53.39592419564724, 52.7455472946167, 52.58558347821236, 54.98537890613079, 54.38507951796055, 51.350368559360504, 46.600410640239716, 41.87323249876499, 44.12123367190361, 40.81237502396107, 40.50194688141346, 40.20743228495121, 41.3053073734045, 40.12012057006359, 41.272792518138885, 40.191530138254166, 43.187870755791664, 39.68011558055878, 42.564172223210335, 41.12676255404949, 41.15054167807102, 40.266321524977684, 41.344076693058014, 37.98127993941307, 46.75161972641945, 52.29848228394985, 57.45260551571846, 54.808931574225426, 57.71376930177212, 52.42202125489712, 56.8694394081831, 52.941487580537796, 56.03082060813904, 49.84271585941315, 60.01420386135578, 31.738935001194477, 31.49068482220173, 58.43642592430115, 50.687463730573654, 57.61958375573158, 50.645137801766396, 52.24011741578579, 50.46545684337616, 50.600288808345795, 46.271876469254494, 46.20939262211323, 41.13844312727451, 41.78728871047497, 40.76895095407963, 40.26115000247955, 38.80400039255619, 41.355198696255684, 42.29108847677708, 42.6381466537714, 39.51872684061527, 40.259804874658585, 40.37922866642475, 40.813427567481995, 39.70991738140583, 40.89673049747944, 39.85538497567177, 40.71882404386997, 39.3695392459631, 39.880060851573944, 40.10566994547844, 41.30622312426567, 39.9935607612133, 41.711858958005905, 41.16122670471668, 41.05552777647972, 41.248439624905586, 40.960088297724724, 42.965867668390274, 47.282652631402016, 53.850577399134636, 55.72804145514965, 59.079666808247566, 53.491002693772316, 53.725028336048126, 49.44738507270813, 51.744905188679695, 52.36234925687313, 53.90052191913128, 55.27840778231621, 54.56070229411125, 49.80386674404144, 27.168965823948383, 10.821643564850092, 7.496469542384148, 8.514486216008663, 7.665254585444927, 1.5342407044954598, 0.061070775700500235, 0.08165692066540942, 1.0417505563236773, 23.77636916935444, 38.391521126031876, 23.094336166977882, 14.6792621165514, 41.901772767305374, 52.223280519247055, 50.99995136260986, 50.69819435477257, 39.262031614780426, 3.9732769830152392, 0.10912820711382665, 0.05340019335562829, 0.05304110891302116, 0.050585312565090135, 0.020753083663294092, 0.024197225902753416, 0.06336657985229976, 0.017532463316456415, 0.008248382346209837, 0.09257780926418491, 0.06148595166450832, 0.07930550738819875, 0.029222419143479783, 0.04191848973277956, 0.05701211848645471, 0.04320679872762412, 0.028904818900628015, 0.023086178880475927, 0.08847196630085818, 0.1562661398202181, 0.14074033621000126, 0.13719925278564915, 0.2853015158325434, 0.2872455568285659, 0.10154671588679776, 0.08558489309507422, 0.16416694008512422, 0.1580294975428842, 0.17858284700196236, 0.13556528108892962, 0.13509404700016603, 0.24243267631391063, 0.131222203199286, 0.08676215453306213, 0.18021487427176908, 0.12025976175209507, 0.14376282168086618, 0.34575092839077115, 25.341845266520977, 72.99592986702919, 68.68567675352097, 61.07136033475399, 38.1867653131485, 29.445009492337704, 36.32659412920475, 51.47417351603508, 40.107965022325516, 4.214954702183604, 0.25985086744185537, 0.27090296032838523, 1.0199603880755603, 7.356512602418661, 11.857070904225111, 14.482451677322388, 17.43458166718483, 27.4844191968441, 63.85554313659668, 61.86550252139568, 60.45406065881252, 59.450644701719284, 52.05398440361023, 51.002140045166016, 46.959479972720146, 49.661708772182465, 47.74117402732372, 44.62409868836403, 43.05719956755638, 43.183360397815704, 52.22161240875721, 61.552577912807465, 57.658147886395454, 54.695351868867874, 53.32622833549976, 53.82732644677162, 56.40366420149803, 57.91288621723652, 52.738992646336555, 48.63907724618912, 44.50912065804005, 46.05358578264713, 40.828554555773735, 42.36448533833027, 43.472825065255165, 43.36045749485493, 43.19172374904156, 43.38558554649353, 42.40406781435013, 44.03163067996502, 42.14202247560024, 43.95935855805874, 44.186700358986855, 42.06649012863636, 42.382188588380814, 43.51224035024643, 40.698373541235924, 50.04396826028824, 53.62368017435074, 57.95221030712128, 57.36193858087063, 59.33057114481926, 57.490504682064056, 58.91940280795097, 54.80355866253376, 58.96219231188297, 52.910735830664635, 61.65392987430096, 34.264300391077995, 33.8405205309391, 58.984223529696465, 52.48372234404087, 60.19578091800213, 53.156157061457634, 53.653854355216026, 52.703867331147194, 52.975685745477676, 48.50499764084816, 48.75524841248989, 43.60747464001179, 43.59146609902382, 43.90114188194275, 42.05151133239269, 39.688209146261215, 45.1250334084034, 44.958074167370796, 45.664444863796234, 41.10897570848465, 41.55881457030773, 41.55106298625469, 42.78228811919689, 42.679697424173355, 43.32812123000622, 41.93385064601898, 41.0585106164217, 42.263251170516014, 42.77597665786743, 43.430609330534935, 43.36209900677204, 42.62119576334953, 44.414646327495575, 46.24993644654751, 42.74033837020397, 43.92548717558384, 42.872407883405685, 44.40732792019844, 50.4185825586319, 56.41661770641804, 59.32324133813381, 60.591522082686424, 56.01427249610424, 53.72104234993458, 50.12249484658241, 50.99071025848389, 53.99240478873253, 53.824704587459564, 55.78051283955574, 56.42498105764389, 50.714674070477486, 27.244042195379734, 15.866698399186134, 7.809571316465735, 8.380744792521, 12.141236755996943, 2.2481322661042213, 0.21349007467506453, 0.2915030799340457, 1.0267729475162923, 28.83095294237137, 50.03248907625675, 29.79558628052473, 19.243791885674, 48.91457386314869, 57.6755927503109, 58.744745180010796, 57.06415235996246, 46.48764029145241, 6.3562267273664474, 0.21103703911649063, 0.1621337523101829, 0.16412791796028614, 0.2114894226542674, 0.10893318554735743, 0.15858953702263534, 0.12759786564856768, 0.17687448242213577, 0.17778011038899422, 0.15985074278432876, 0.09644442092394456, 0.12978476705029607, 0.11441261769505218, 0.09196028302540071, 0.13622721744468436, 0.10105914712767117, 0.1537588532664813, 0.15827833965886384, 0.3899771114811301], [0.05734275640861597, 0.03125108538370114, 0.04256524545780849, 0.08015824249014258, 0.053506487456616014, 0.027707371045835316, 0.062114747415762395, 0.058440248103579506, 0.08566016171243973, 0.01524324015917955, 0.025152913585770875, 0.022270584559009876, 0.049408232953283004, 0.0374770253256429, 0.0061563733379443875, 0.04728351610538084, 0.048237632290693, 0.10756393792689778, 1.0698821092955768, 26.383156590163708, 59.62090216577053, 47.3941158503294, 33.1987539678812, 20.140203684568405, 21.860318183898926, 23.383551947772503, 33.30096088349819, 17.822749838232994, 0.3213349526049569, 0.05489179886353668, 0.06478621930000372, 0.25492680666502565, 2.7700033877044916, 7.357862005010247, 5.357755729928613, 7.970754392445087, 42.961710691452026, 61.16004757583141, 57.82854974269867, 50.908353477716446, 48.717820420861244, 45.40269210934639, 42.736918553709984, 43.642558157444, 44.67695005238056, 44.21883903443813, 42.150427624583244, 39.55321379005909, 39.062177538871765, 43.44543233513832, 53.892295360565186, 58.60201343894005, 55.26901848614216, 54.6069610118866, 51.17302447557449, 51.95523150265217, 53.00967112183571, 49.18707624077797, 49.99294839799404, 44.96401324868202, 47.94370695948601, 44.63081672787666, 40.99873222410679, 38.456752225756645, 40.16905814409256, 39.94788721203804, 41.76037855446339, 40.78906327486038, 41.54646523296833, 40.003991201519966, 40.020402520895004, 38.615975081920624, 39.12963151931763, 37.442248463630676, 39.98963177204132, 38.78640353679657, 50.08537083864212, 52.87071257829666, 53.64272855222225, 49.243924990296364, 54.61945854127407, 50.01307211816311, 55.3053293377161, 51.02558098733425, 56.37708842754364, 49.161758199334145, 57.77114622294903, 27.442754432559013, 32.24100016057491, 56.57424084842205, 50.05747653543949, 53.75712141394615, 50.63486695289612, 53.04537020623684, 50.481480583548546, 49.692775905132294, 46.55020393431187, 43.2334341108799, 39.263635128736496, 41.33313328027725, 39.239457026124, 38.309361934661865, 37.11536720395088, 39.19211536645889, 38.19255240261555, 37.72089131176472, 36.55345715582371, 38.341751396656036, 38.950220346450806, 39.34601090848446, 38.03553722798824, 38.62750746309757, 37.81137965619564, 37.65314854681492, 36.92656293511391, 38.31428647041321, 38.797882720828056, 41.14008463919163, 40.31311221420765, 42.14789316058159, 40.944311544299126, 42.311048805713654, 40.409889221191406, 41.99033081531525, 43.27358655631542, 48.57101149857044, 53.39429408311844, 54.37022231519222, 51.32805235683918, 52.66037866473198, 51.378642842173576, 49.46119733154774, 53.08575823903084, 56.3989182561636, 57.61791184544563, 57.80958116054535, 58.912741765379906, 53.125431910157204, 32.991604283452034, 13.132634907960892, 8.123012222349644, 6.548436088487506, 3.724937508814037, 1.5659583150409162, 0.09338535499409772, 0.01708230993244797, 0.2508530393242836, 7.801730912178755, 40.65906085073948, 43.83964978158474, 24.61271569132805, 24.951773397624493, 31.648163571953773, 43.817394375801086, 45.03761529922485, 37.0509834587574, 10.923771634697914, 0.3771716798655689, 0.04172423999989405, 0.04650170434615575, 0.07210078227217309, 0.07610829066834413, 0.06308312396868132, 0.028029926979797892, 0.05299829070281703, 0.04197801368718501, 0.0614755096466979, 0.03360421673278324, 0.08465360166155733, 0.0429174056625925, 0.08898209634935483, 0.0376082444563508, 0.04832589591387659, 0.016163763029908296, 0.04695516028732527, 0.007399720707326196, 0.03375627908098977, 0.04519823698501568, 0.016305249773722608, 0.026260435406584293, 0.08548563826479949, 0.05975424654025119, 0.03833487753581721, 0.028772614568879362, 0.051330146816326305, 0.02760433497314807, 0.0332099025399657, 0.039974797546165064, 0.06284524337388575, 0.028737065695167985, 0.01554337117340765, 0.07201087108114734, 0.02144169651728589, 0.07568185261334293, 1.3381790625862777, 34.64296147227287, 65.84612712264061, 54.392622113227844, 39.21580329537392, 29.327704086899757, 25.6023782864213, 23.45947567373514, 36.548669412732124, 21.74941923469305, 0.3816079121315852, 0.04558433189231437, 0.018102315843862016, 2.206570808775723, 8.888828828930855, 5.924583664163947, 4.852058440446854, 7.4910657573491335, 45.03374710679054, 61.82174026966095, 59.87652204930782, 53.23518522083759, 51.805994510650635, 46.945785507559776, 44.415888860821724, 46.580480709671974, 44.959480091929436, 45.35019792616367, 43.9924243837595, 42.18714885413647, 41.48699462413788, 45.87496116757393, 56.17162965238094, 59.277856573462486, 54.30728629231453, 55.83547689020634, 51.17436200380325, 51.86763480305672, 54.68039207160473, 51.28413811326027, 51.21045246720314, 47.067534774541855, 48.947738483548164, 45.172375068068504, 42.41102524101734, 40.219853818416595, 41.799763441085815, 41.28641478717327, 44.27053526043892, 42.84727223217487, 43.53462494909763, 41.67190410196781, 42.55927428603172, 41.01208470761776, 41.61393441259861, 38.35119009017944, 40.92987611889839, 41.228775680065155, 50.72484992444515, 54.22331839799881, 53.8436845690012, 50.86747147142887, 56.18357241153717, 53.664676174521446, 56.70050427317619, 53.09199370443821, 58.15089024603367, 52.416823133826256, 58.79536986351013, 28.664001300930977, 33.16176675260067, 57.11541920900345, 51.27144679427147, 56.29457585513592, 52.09251433610916, 54.74113181233406, 52.1326819807291, 52.68473535776138, 48.443045765161514, 45.053069069981575, 41.730356365442276, 42.90679603815079, 40.98395861685276, 40.04896178841591, 39.02079775929451, 40.03166511654854, 39.633894860744476, 40.46425670385361, 39.13400128483772, 40.92262230813503, 40.11529102921486, 42.244601771235466, 39.34566892683506, 40.02261020243168, 39.98916819691658, 39.240300580859184, 38.436050936579704, 40.27108646929264, 40.13485997915268, 41.72259338200092, 41.93279430270195, 43.95094580948353, 42.673446759581566, 43.693669214844704, 42.59087339043617, 44.10444997251034, 44.87145021557808, 51.077387407422066, 55.47947019338608, 57.221175134181976, 53.94721761345863, 52.89189264178276, 50.0215532630682, 50.76678827404976, 53.641915395855904, 56.994703486561775, 58.5905646532774, 57.990155071020126, 60.29685549438, 53.780113980174065, 33.726036474108696, 14.30989058688283, 10.963139422237873, 11.655240934342146, 5.945580862462521, 3.4834678284823895, 0.44259241316467524, 0.05708836302801501, 0.022678439236187842, 9.129414819180965, 43.4723424911499, 41.562469974160194, 26.35313630104065, 31.683771461248398, 38.01816835999489, 48.54114130139351, 51.54886230826378, 44.20600712299347, 12.983388416469097, 0.30183291470166296, 0.0513897932250984, 0.04354688790044747, 0.06381650688126683, 0.058930985833285376, 0.04929903705487959, 0.010900475826929323, 0.054059632384451106, 0.07754957856377587, 0.029847587647964247, 0.03865148886688985, 0.04578086001856718, 0.03242933758883737, 0.06138490825833287, 0.027655719422909897, 0.038875376267242245, 0.042099822385353036, 0.04942398503771983, 0.03555236180545762, 0.1457608019700274, 0.13074004469672218, 0.10310429832316004, 0.0933901863754727, 0.16002087271772325, 0.18556595197878778, 0.1100669645529706, 0.1554154307814315, 0.1734796169330366, 0.07613620284246281, 0.07707887882133946, 0.1290360142593272, 0.18946969328681007, 0.14349055738421157, 0.08297297856188379, 0.13481482135830447, 0.12416956640663557, 0.2194545671227388, 1.9914688635617495, 43.32619093358517, 71.97712853550911, 62.24127195775509, 45.64847432076931, 31.429006531834602, 30.89792612940073, 32.52085514366627, 46.062754690647125, 27.67780601978302, 0.45295579300727695, 0.17653668648563325, 0.13136012392351404, 1.694943462498486, 7.768589565530419, 15.634030234068632, 13.226045295596123, 10.372703354805708, 46.439196690917015, 65.10199785232544, 62.35433109104633, 55.521340146660805, 53.77458527684212, 48.9192134141922, 47.25855052471161, 48.57514187693596, 48.95187646150589, 47.84281477332115, 47.41528071463108, 43.8133741915226, 42.73286037147045, 47.88690760731697, 58.27372245490551, 63.7816447019577, 55.57208642363548, 55.87805360555649, 51.28776691854, 54.64591272175312, 56.766852512955666, 53.57215113937855, 55.67442253232002, 50.11696234345436, 52.22619876265526, 48.29152129590511, 44.53092008829117, 41.775520741939545, 44.367456659674644, 44.53406631946564, 47.065657675266266, 46.01258598268032, 45.911549404263496, 44.45593111217022, 45.18845960497856, 42.64836050570011, 45.41424348950386, 40.23515559732914, 43.44707004725933, 42.75155156850815, 53.75711761415005, 56.72109156847, 57.840363308787346, 54.37724433839321, 57.79056318104267, 56.015872210264206, 57.66014277935028, 54.73217949271202, 60.562658831477165, 54.720134139060974, 58.322614431381226, 31.47403221577406, 36.22393123805523, 58.265530094504356, 53.248093128204346, 58.519079089164734, 57.35536493360996, 56.63972653448582, 54.65354651212692, 54.82896789908409, 51.848742216825485, 48.28978858888149, 45.003135949373245, 44.38848093152046, 42.462729066610336, 41.976738944649696, 41.234813556075096, 42.453020587563515, 42.185663133859634, 42.58784495294094, 39.75521095097065, 43.92944276332855, 43.76934975385666, 43.08795511722565, 42.36423075199127, 42.56904736161232, 43.55120725929737, 42.47411705553532, 40.34887209534645, 41.279240772128105, 42.88910798728466, 45.21868698298931, 43.938938453793526, 47.50841371715069, 44.37097907066345, 46.72095537185669, 46.368999257683754, 46.353762075304985, 47.59265899658203, 54.29314725100994, 59.481806829571724, 59.50400523841381, 54.87277194857597, 53.59119571745396, 52.373543456196785, 51.70313403010368, 54.60929408669472, 59.378133192658424, 61.79349638521671, 61.58697746694088, 61.05321250855923, 56.2136971950531, 35.199073031544685, 16.705522388219833, 11.950248554348946, 14.798532016575336, 10.434495639055967, 4.980390854179859, 0.38026367488782853, 0.1908903568983078, 0.35355125670321286, 12.177192326635122, 53.22303727269173, 54.707967191934586, 36.91994749009609, 34.189980179071426, 44.49411906301975, 57.300974652171135, 58.44594441354275, 51.432132571935654, 18.031339645385742, 0.8111482334788889, 0.10915253471466713, 0.23766722733853385, 0.2136135977343656, 0.13220853230450302, 0.15528827119851485, 0.11677117785438895, 0.13617341173812747, 0.17993480258155614, 0.09774976962944493, 0.21765981655335054, 0.19141514436341822, 0.18586027290439233, 0.16738940466893837, 0.15561238193186, 0.13005980697926134, 0.1736787796835415, 0.3067006019409746, 0.10237352034891956], [0.05766042901086621, 0.0620483066450106, 0.01221545575390337, 0.052643970848293975, 0.09896071715047583, 0.007217041056719609, 0.05902314202103298, 0.024601304903626442, 0.062013073184061795, 0.022134179671411403, 0.042946434768964536, 0.029794913716614246, 0.042927439499180764, 0.03659366549982224, 0.021632177995343227, 0.028288361354498193, 0.03330996260046959, 0.02366102420637617, 2.5354125257581472, 41.56802527606487, 51.962261125445366, 49.77229043841362, 38.54912906885147, 20.725543275475502, 22.982012294232845, 29.445951841771603, 31.378074064850807, 10.54957341402769, 0.05371131650463212, 0.046444885520031676, 0.0551853071374353, 3.4707617852836847, 8.203765489161015, 7.196032963693142, 6.831076322123408, 15.368265844881535, 56.60451762378216, 58.69750991463661, 55.92524707317352, 51.89425237476826, 49.179328456521034, 43.671683594584465, 46.57839462161064, 50.20416386425495, 54.755738228559494, 51.545438691973686, 51.27416364848614, 48.24373885989189, 40.75919687747955, 39.28024023771286, 48.2234213501215, 54.55528378486633, 55.87939493358135, 49.742264449596405, 53.02803173661232, 50.04738047719002, 54.57812815904617, 52.18649469316006, 53.35214674472809, 52.570190504193306, 53.43569666147232, 51.52511738240719, 48.268798515200615, 40.15682280063629, 40.25714121758938, 40.52042528986931, 41.787106320261955, 43.7409158796072, 43.33808809518814, 40.97075812518597, 38.95759955048561, 38.93707685172558, 39.170566722750664, 38.43130499124527, 39.88555535674095, 38.984289318323135, 51.79470531642437, 49.37151834368706, 47.81212002038956, 46.60810522735119, 51.136968210339546, 45.956542789936066, 52.289909943938255, 49.29785929620266, 54.22433294355869, 45.65200053155422, 53.81965085864067, 23.404994197189808, 33.469440042972565, 58.281538635492325, 47.81980320811272, 54.25221584737301, 49.98032167553902, 52.82886162400246, 48.65025244653225, 49.231655448675156, 44.66738976538181, 41.47453889250755, 38.58204670250416, 39.541229233145714, 39.34217691421509, 38.12424726784229, 37.29810319840908, 38.97361949086189, 38.01628366112709, 38.68004344403744, 37.212269604206085, 37.11654134094715, 37.62005612254143, 38.452576249837875, 37.63327941298485, 40.008501559495926, 37.432144805788994, 38.44892844557762, 37.95878514647484, 38.45483712852001, 37.95129954814911, 43.16852979362011, 48.725522607564926, 49.4059406965971, 51.83660566806793, 50.43978922069073, 47.76103176176548, 45.38011372089386, 46.51040107011795, 49.392747804522514, 53.690024614334106, 53.444052413105965, 50.51231972873211, 51.75100386142731, 52.26651459932327, 56.947240233421326, 53.42891402542591, 56.05493791401386, 55.87684907019138, 52.944033443927765, 58.172290697693825, 62.05438658595085, 44.19785276055336, 19.083560183644295, 17.751748748123646, 12.099555842578411, 6.550981476902962, 2.1666335267946124, 0.7231139042414725, 0.1739769449341111, 0.04519366906606592, 2.94718146789819, 27.03699890524149, 39.20214302837849, 20.93296654522419, 20.78127108514309, 52.7241962403059, 40.0363464653492, 42.794983237981796, 47.78032332658768, 21.165631860494614, 1.898993938229978, 0.07750974749797024, 0.0638103841629345, 0.01567936324136099, 0.01848094103479525, 0.053681767894886434, 0.03507264867948834, 0.008601887693657773, 0.04382073297165334, 0.01868247680249624, 0.04065766617713962, 0.024186141927202698, 0.021524774383578915, 0.0694713975826744, 0.03462995387963019, 0.05084430355054792, 0.05266510350338649, 0.02129098487785086, 0.056037144240690395, 0.049716265057213604, 0.05827480483276304, 0.047963460674509406, 0.05773954566393513, 0.08345526322955266, 0.07734265294857323, 0.022894736321177334, 0.017613505842746235, 0.009579684883647133, 0.01468803855459555, 0.050568580845720135, 0.04201298739644699, 0.04052747863170225, 0.011731381582649192, 0.025353161727252882, 0.08656269492348656, 0.01823990445700474, 0.057046320362132974, 3.9201515587046742, 49.44339528679848, 57.82107174396515, 57.33600877225399, 43.56866352260113, 24.908936396241188, 22.443482391536236, 26.050319150090218, 36.3097420334816, 12.196362297981977, 0.08305972820380703, 0.08130401460221037, 0.08502741402480751, 3.2466080132871866, 15.177132301032543, 8.915588892996311, 4.936438137665391, 16.086968779563904, 57.75068812072277, 62.732532396912575, 58.044830337166786, 53.44724804162979, 50.178355649113655, 45.85691973567009, 47.239346355199814, 51.59547060728073, 56.07056267559528, 53.984615206718445, 53.101147413253784, 49.00437444448471, 42.34985992312431, 42.09282651543617, 49.572124779224396, 57.783484160900116, 58.56627635657787, 50.94936467707157, 51.20700225234032, 50.90676136314869, 56.28171354532242, 54.29264187812805, 55.82812048494816, 53.431817069649696, 56.04461766779423, 55.26171527802944, 49.62177291512489, 40.63149333000183, 42.937931567430496, 42.83413253724575, 44.25377435982227, 44.443577975034714, 45.21511897444725, 42.67027013003826, 40.01289412379265, 41.21757388114929, 41.63644440472126, 40.68092867732048, 41.05027265846729, 39.80427771806717, 53.118273094296455, 52.46628127992153, 51.229896023869514, 48.906913474202156, 51.40011169016361, 46.60477660596371, 53.51669691503048, 50.12612745165825, 54.855030700564384, 47.237374261021614, 54.56210061907768, 25.176189355552197, 34.766025468707085, 60.941065326333046, 50.35774402320385, 57.6086213439703, 52.11549550294876, 54.01979371905327, 53.11240240931511, 50.384126007556915, 46.321467608213425, 44.46735329926014, 41.01179212331772, 41.74711346626282, 40.35581052303314, 41.013148650527, 38.18900339305401, 39.81220029294491, 40.43614201247692, 41.21881641447544, 40.09248465299606, 39.55659180879593, 39.155929908156395, 39.975116550922394, 38.74503515660763, 40.7956787198782, 39.51186440885067, 39.232473000884056, 39.40162852406502, 41.20558552443981, 40.459537357091904, 42.9956466704607, 50.03228008747101, 52.65751741826534, 53.342692852020264, 53.931045681238174, 50.04533238708973, 47.739847898483276, 48.76744195818901, 52.71931350231171, 55.55365361273289, 54.50882747769356, 50.240079537034035, 51.614450588822365, 53.28068017959595, 56.654671132564545, 53.77590760588646, 57.13045120239258, 55.75204476714134, 56.45192541182041, 58.82497027516365, 61.87367968261242, 45.36713741719723, 20.945978946983814, 12.246896736323833, 12.560490109026432, 6.252792002633214, 4.684372963383794, 1.0268392064608634, 0.03256794479966629, 0.03207892885257024, 3.0693679489195347, 30.658839158713818, 41.53976619243622, 24.183933399617672, 25.03924660384655, 56.480834260582924, 46.563066244125366, 50.11061288416386, 55.05186773836613, 26.6859832406044, 2.259022956714034, 0.05160873792192433, 0.05445129339932464, 0.0409409810526995, 0.07212979282485321, 0.05652248284604866, 0.03640005401393864, 0.028753725055139512, 0.02715059516049223, 0.024560629644838627, 0.0035103362461086363, 0.022504997468786314, 0.061538492009276524, 0.03470059520623181, 0.03321436284750234, 0.04841702051635366, 0.07478862593416125, 0.02687529176910175, 0.02349050835618982, 0.23660184466280043, 0.17226644296897575, 0.07913453140645288, 0.12470672547351569, 0.22798412974225357, 0.16697892278898507, 0.16054027219070122, 0.14621936017647386, 0.09778079140232876, 0.08982997038401663, 0.15230103774229065, 0.13162570889107883, 0.11263474356383085, 0.09766044473508373, 0.10181469056988135, 0.21744506870163605, 0.11446116157458164, 0.14358739281306043, 5.660754796117544, 60.138050615787506, 66.86878144741058, 63.41853618621826, 49.02539871633053, 33.02766054868698, 34.30202856659889, 43.434656113386154, 45.36503612995148, 15.257446691393852, 0.36759577807970345, 0.1555110639310442, 0.2588686201488599, 6.563897458836436, 15.761640686541796, 13.22119865566492, 14.630725421011448, 18.536761924624443, 61.265514716506004, 63.68548706173897, 59.75454479455948, 56.741032898426056, 53.65451171994209, 48.19429211318493, 50.432463213801384, 54.31287579238415, 59.77387435734272, 56.344926953315735, 56.2935347110033, 53.414117619395256, 46.32826544344425, 43.53517211973667, 51.48835815489292, 60.25807477533817, 60.646565929055214, 52.97386184334755, 54.67664547264576, 50.56511029601097, 59.39083211123943, 56.588573679327965, 58.38852569460869, 57.0692440867424, 57.88049295544624, 56.1323207616806, 52.12683029472828, 43.3247622102499, 45.38963980972767, 45.06241276860237, 46.37635946273804, 46.92631155252457, 48.62421624362469, 45.93060538172722, 42.62606330215931, 43.01821365952492, 43.8351546227932, 42.81521715223789, 43.247272968292236, 41.333650052547455, 55.46654708683491, 53.9708561450243, 52.11592108011246, 49.168860018253326, 52.23605163395405, 47.941389083862305, 53.71298298239708, 52.334242165088654, 54.14215475320816, 48.849099576473236, 54.248423650860786, 27.926012501120567, 37.72195145487785, 60.49020051956177, 53.0402746796608, 59.44673091173172, 55.00026270747185, 57.003397420048714, 55.62793582677841, 52.34017364680767, 48.88365872204304, 45.79906404018402, 42.245741710066795, 43.523331955075264, 42.99450673162937, 43.79046522080898, 40.0568463653326, 43.02004136145115, 42.097211480140686, 43.37582387030125, 42.38433927297592, 41.33003644645214, 42.563039883971214, 42.393910959362984, 41.18369109928608, 44.07151713967323, 41.24130740761757, 42.64845930039883, 41.071593314409256, 42.74259924888611, 42.12653450667858, 46.972771659493446, 51.702636256814, 55.598217621445656, 55.265910252928734, 54.492085576057434, 51.97871044278145, 50.551883205771446, 50.834846422076225, 54.95988987386227, 58.195306062698364, 56.79950036108494, 51.39837898313999, 53.841864466667175, 54.40989978611469, 58.3911095559597, 56.138126850128174, 59.06444102525711, 58.571235090494156, 58.35768274962902, 62.02194392681122, 66.3070347905159, 47.988149374723434, 21.461217999458313, 22.120205238461494, 24.161744490265846, 15.544848069548607, 6.276831412687898, 1.1087029636837542, 0.38116541400086135, 0.18602643976919353, 4.326731404289603, 38.722684755921364, 54.0886802226305, 29.9350368976593, 30.104768089950085, 64.62826207280159, 51.5854961425066, 55.69810286164284, 61.44918166100979, 34.163130819797516, 3.7036375142633915, 0.22741865774150938, 0.17714987858198583, 0.1288803858915344, 0.18944646406453103, 0.12626476061996073, 0.14287402562331408, 0.14417269499972463, 0.25599425251130015, 0.08712186609045602, 0.14144755841698498, 0.12923195608891547, 0.11276042627287097, 0.1670967461541295, 0.18149004725273699, 0.14880060916766524, 0.14972559234593064, 0.09376343470648862, 0.13843053515302017], [0.17872826341772452, 0.0324270072451327, 0.07101901297573932, 0.018797274060489144, 0.06867365562357008, 0.03321061871247366, 0.03530587600835133, 0.031301080161938444, 0.058710694138426334, 0.020721980254165828, 0.007960920720506692, 0.03835562427411787, 0.05619841664156411, 0.06440100012696348, 0.04678770208556671, 0.03257583754020743, 0.07127514298190363, 0.15951996756484732, 7.861307440325618, 50.125591680407524, 52.18767262995243, 41.313370540738106, 25.462222807109356, 25.59611812233925, 35.569279566407204, 35.03505863249302, 31.901533976197243, 4.642945686355233, 0.04372509982204065, 0.06238040659809485, 0.22482341184513643, 2.5748168863356113, 18.358973264694214, 3.5247863363474607, 3.5670322319492698, 22.653411626815796, 61.65203757584095, 58.51445473730564, 54.95180010795593, 49.160762652754784, 49.151263162493706, 51.33199654519558, 55.28244696557522, 55.43734945356846, 52.248689755797386, 55.30508615076542, 55.36816656589508, 53.7114554643631, 47.14398667216301, 38.67160029709339, 46.291069239377975, 49.04371753334999, 53.84436093270779, 54.88643981516361, 51.722455993294716, 50.13146996498108, 50.896802097558975, 50.854354575276375, 52.30716481804848, 54.45389002561569, 53.62533688545227, 50.767924413084984, 52.34433822333813, 43.000924587249756, 41.4331629127264, 41.96209833025932, 44.98722240328789, 43.27457830309868, 44.054763838648796, 40.2246605604887, 41.02641373872757, 40.42127341032028, 38.85054029524326, 38.761488273739815, 38.60533945262432, 40.000730976462364, 45.531281009316444, 49.28190775215626, 56.0283013433218, 53.3783995360136, 53.66534873843193, 50.34593425691128, 52.43474297225475, 50.67080922424793, 54.58570495247841, 45.7228135317564, 53.77978339791298, 25.24266678839922, 37.343126982450485, 57.819361835718155, 47.07612231373787, 51.24035306274891, 47.04584553837776, 47.8014349937439, 42.873513624072075, 42.18851678073406, 38.898356929421425, 41.736409440636635, 41.09020471572876, 42.244970351457596, 39.666326120495796, 38.82868766784668, 37.768635749816895, 37.10494056344032, 36.81934788823128, 39.32173781096935, 37.202253341674805, 37.64118678867817, 38.01418997347355, 38.9684783667326, 41.38697259128094, 44.24650155007839, 44.91001054644585, 41.67778618633747, 37.85477712750435, 37.584680020809174, 43.74552883207798, 49.60899420082569, 51.569517999887466, 51.918381080031395, 53.25506955385208, 53.504062592983246, 50.90029031038284, 49.884810000658035, 50.748385861516, 51.2319403141737, 53.26321631669998, 50.91850273311138, 51.789624989032745, 53.62231604754925, 54.85791094601154, 53.77601020038128, 56.58938683569431, 54.05701272189617, 54.59542103111744, 53.46900947391987, 56.05700880289078, 54.08209137618542, 54.401259049773216, 26.162491030991077, 20.43572712689638, 14.030367136001587, 4.513327991589904, 5.46362517401576, 1.100093456916511, 0.04719721546280198, 0.1274061095318757, 0.46739074343349785, 19.676611460745335, 43.53963688015938, 32.721400782465935, 24.149917624890804, 46.964556500315666, 39.27846573293209, 42.30781137943268, 46.9208512455225, 31.251259669661522, 4.683534633368254, 0.16829249449074268, 0.06321086984826252, 0.032299253944074735, 0.12960277759702876, 0.11296433876850642, 0.04255319669027813, 0.057279117245343514, 0.08931405158364214, 0.01952966249518795, 0.08285227566375397, 0.06196645146701485, 0.1088311402418185, 0.022211275827430654, 0.014748817666259129, 0.016180249840545002, 0.07343399862293154, 0.005383710404203157, 0.05226297820627224, 0.010797399863804458, 0.024354603883693926, 0.0973142625298351, 0.03316734037071001, 0.043176463441341184, 0.05159644795639906, 0.014119353054411476, 0.05997384803777095, 0.04191017767880112, 0.047711568331578746, 0.029304526651685592, 0.07382320312899537, 0.04841159170609899, 0.0772840974968858, 0.010760541099443799, 0.008492849501635646, 0.035002563963644207, 0.08070510884863324, 10.509338323026896, 57.787831127643585, 59.80081491172314, 49.4657114893198, 35.2723179012537, 30.601942911744118, 37.18796990811825, 40.07070802152157, 34.401530027389526, 5.679444093257189, 0.11132074883789755, 0.1315894623985514, 0.414607894490473, 6.876429263502359, 16.760551035404205, 5.864839944988489, 4.699745988473296, 23.481972366571426, 62.49678164720535, 60.61211317777634, 57.74224117398262, 51.074985936284065, 50.11962220072746, 53.93652118742466, 58.04385378956795, 57.792668268084526, 54.99745845794678, 57.77809984982014, 58.39220389723778, 54.92672145366669, 47.94122189283371, 41.113679856061935, 47.48730204999447, 51.138681918382645, 56.69117957353592, 57.42740526795387, 51.712439730763435, 49.50440861284733, 51.205337941646576, 52.524003982543945, 54.24122303724289, 55.607443526387215, 54.60167549550533, 53.4268469363451, 51.735018119215965, 46.23887524008751, 43.271196484565735, 42.95379191637039, 46.18821635842323, 45.244939774274826, 45.95029592514038, 40.70048622786999, 42.120105251669884, 42.93080314993858, 41.07372120022774, 39.96019475162029, 40.33764369785786, 42.86923885345459, 47.115134820342064, 51.83462597429752, 57.15410113334656, 53.5312045365572, 56.36014513671398, 51.643401235342026, 52.82441586256027, 50.28689682483673, 55.921363681554794, 46.72300726175308, 53.18532809615135, 26.18610106408596, 38.877511247992516, 59.436479061841965, 49.30135890841484, 54.3542555719614, 49.75290387868881, 50.673222094774246, 45.4861356317997, 43.950394839048386, 41.49650551378727, 43.55975680053234, 43.41355964541435, 43.63940432667732, 40.549904108047485, 40.458853393793106, 39.509535133838654, 40.738738775253296, 39.65088754892349, 40.88075615465641, 39.34650868177414, 39.71745237708092, 40.24784691631794, 40.861312597990036, 43.68162386119366, 47.48388223350048, 48.092879354953766, 43.90771932899952, 39.33873049914837, 40.48570655286312, 44.35879312455654, 52.36584506928921, 54.378148689866066, 54.55619193613529, 54.86656688153744, 55.66973738372326, 53.86425666511059, 52.99481391906738, 52.08895392715931, 54.730116203427315, 55.75892619788647, 52.791498228907585, 53.17032650113106, 55.74561931192875, 55.804569348692894, 54.713085517287254, 56.93791173398495, 55.81362046301365, 55.31365089118481, 55.519018471241, 57.1905791759491, 54.76304143667221, 52.794481068849564, 30.52534282207489, 14.516596645116806, 5.172161338850856, 5.254907123744488, 6.208033729344606, 1.5790621493943036, 0.18934710533358157, 0.055905297995195724, 0.5444372200872749, 20.52191600203514, 40.811094492673874, 27.7546226978302, 27.61190425604582, 52.44684152305126, 44.777720645070076, 48.004640489816666, 54.414250552654266, 39.0880161523819, 6.215572999790311, 0.062254260046756826, 0.04386900967801921, 0.06669843700365163, 0.07078181515680626, 0.062327127816388384, 0.01381995398332947, 0.06115764037531335, 0.04588057126966305, 0.03705328126670793, 0.011186823303432902, 0.02023679935518885, 0.04439998294401448, 0.050421312771504745, 0.035345354554010555, 0.03402081390959211, 0.02841858600731939, 0.059162955221836455, 0.04060488834511489, 0.2343622804619372, 0.14279396273195744, 0.18011918175034225, 0.11764760231017135, 0.21204923948971555, 0.11761902962462045, 0.11165672651259229, 0.24652719410369173, 0.12674690427957103, 0.13161123701138422, 0.12721873208647594, 0.15882683132076636, 0.16036528861150146, 0.16042897972511128, 0.1010714445146732, 0.09516699181403965, 0.1287966567906551, 0.27075040445197374, 15.094679575413465, 68.8165645301342, 65.1053112745285, 56.96889907121658, 36.751901507377625, 36.82592153549194, 47.07373984158039, 47.61378966271877, 43.76968793570995, 7.438369235023856, 0.11028882960090414, 0.3663646738277748, 0.4610914533259347, 8.480845671147108, 31.95906288921833, 12.711589951068163, 7.05665216781199, 25.628805868327618, 64.97842848300934, 62.31355547904968, 60.13129837810993, 53.9754880964756, 54.641767144203186, 56.85838960111141, 61.38385556638241, 61.02776147425175, 56.73387788236141, 59.64003033936024, 60.88815696537495, 56.695180758833885, 49.993020594120026, 43.162119537591934, 50.71534663438797, 53.61792728304863, 57.86221593618393, 59.08074975013733, 52.523164227604866, 50.92737525701523, 52.191544622182846, 53.12367640435696, 56.57938577234745, 58.55432979762554, 57.136846259236336, 55.55144213140011, 55.8455653488636, 49.025558307766914, 45.12558437883854, 46.57127760350704, 50.235698372125626, 48.228186294436455, 49.96025115251541, 44.16499972343445, 44.576494842767715, 44.71301011741161, 43.051663264632225, 42.926893159747124, 41.343894302845, 44.28677178919315, 50.131526961922646, 53.26719470322132, 59.83457989990711, 56.89535781741142, 59.20578584074974, 54.898971542716026, 53.85714344680309, 52.900917157530785, 57.968948408961296, 48.31451766192913, 55.00101126730442, 30.061059035360813, 40.98658047616482, 61.473952531814575, 51.32838673889637, 56.218853518366814, 51.57371677458286, 52.80865430831909, 47.87483565509319, 46.260214895009995, 43.75222787261009, 45.85048668086529, 46.383218094706535, 46.87582366168499, 42.69278012216091, 43.3843620121479, 41.36315926909447, 42.61572405695915, 42.130490094423294, 44.248048067092896, 42.502892911434174, 41.11693248152733, 41.93886257708073, 43.17304775118828, 44.432087391614914, 50.53741358220577, 49.725894927978516, 46.06666088104248, 41.156108379364014, 41.8756377696991, 47.073709443211555, 55.26384316384792, 54.89324904978275, 57.54087097942829, 57.04513058066368, 57.10466958582401, 54.83837239444256, 55.166971161961555, 55.42890630662441, 57.289423272013664, 58.78226816654205, 54.29921932518482, 56.07457526028156, 56.96881167590618, 57.9065253585577, 58.74449819326401, 59.94828499853611, 58.75655494630337, 60.2750788629055, 59.54962559044361, 60.65992221236229, 58.12341392040253, 55.23207686841488, 30.86346197873354, 25.314040258526802, 24.15415059775114, 15.077376253902912, 13.004930410534143, 4.450316922739148, 0.3159568161936477, 0.23004623159067705, 1.0905999038368464, 28.673250004649162, 58.13639782369137, 44.33219455182552, 34.82696279883385, 55.61327621340752, 48.826289400458336, 55.422632843256, 61.63979843258858, 46.44415162503719, 9.139756914228201, 0.2969244687119499, 0.25877136911731213, 0.23878475331002846, 0.3605479281395674, 0.16729123337427154, 0.1186736288946122, 0.20196086989017203, 0.16432077245553955, 0.12321664136834443, 0.11225752474274486, 0.22699667257256806, 0.2034200806519948, 0.1467085987678729, 0.1270911272149533, 0.15777868131408468, 0.1310042492696084, 0.15590794966556132, 0.13077491079457104], [0.018718194514804054, 0.03393011233129073, 0.055203545416588895, 0.028138146954006515, 0.0448882085038349, 0.040387375993304886, 0.04742968580103479, 0.01124811171393958, 0.04411147674545646, 0.02431547600281192, 0.05982415685139131, 0.04961880993505474, 0.006592663403353072, 0.04153928195592016, 0.05891685534152202, 0.026588991604512557, 0.07987404445884749, 0.06932568430784158, 12.96658381819725, 55.0802294164896, 47.96449564397335, 44.56047870218754, 22.636398039758205, 21.404015868902206, 35.14556810259819, 34.22535628080368, 29.404594860970974, 3.183263512328267, 0.01642043294850737, 0.11638530559139326, 0.5625988799147308, 2.422674475237727, 16.905691847205162, 8.167645577341318, 3.4238782385364175, 27.18738153576851, 62.5409846752882, 57.28366278111935, 52.98034809529781, 52.629607915878296, 53.82527835667133, 53.376659229397774, 57.30273775756359, 53.67929019033909, 41.95996664464474, 52.22581498324871, 55.42845793068409, 53.67725349962711, 50.63612088561058, 43.02422873675823, 42.76928901672363, 49.648287892341614, 53.20633336901665, 53.47549192607403, 53.900578916072845, 48.65934535861015, 48.32081772387028, 47.90633976459503, 48.641657307744026, 45.622726902365685, 50.3710775077343, 51.183838695287704, 50.68569302558899, 46.63336247205734, 40.98112016916275, 42.40540534257889, 43.50610747933388, 43.889354914426804, 45.134559497237206, 41.02999694645405, 40.6942355632782, 39.9440798163414, 39.00454983115196, 38.781828582286835, 37.84559302031994, 39.52515609562397, 43.964260295033455, 44.01661388576031, 47.75597043335438, 49.359640181064606, 51.7606857419014, 49.880812615156174, 54.05575878918171, 50.43828450143337, 56.11076071858406, 48.6588703840971, 57.392162159085274, 26.722278892993927, 38.57928805053234, 57.47893810272217, 47.63326741755009, 48.52994330227375, 42.19175800681114, 40.594821497797966, 40.39088264107704, 41.861392334103584, 43.062211498618126, 44.131063744425774, 39.61003594100475, 38.35016794502735, 40.07249392569065, 39.84014019370079, 37.470218762755394, 38.92516449093819, 40.35923033952713, 39.123962223529816, 40.33771589398384, 39.08877611160278, 38.804064989089966, 44.06879648566246, 50.69577008485794, 49.27878051996231, 48.9156112074852, 43.06458257138729, 42.67429791390896, 42.826160565018654, 47.447613179683685, 49.057525992393494, 51.739794462919235, 49.03090842068195, 50.24012133479118, 51.459016129374504, 53.421747609972954, 52.42504969239235, 51.15008510649204, 52.880949229002, 51.783416122198105, 47.749043405056, 53.16322848200798, 52.91091822087765, 51.94073908030987, 52.58285902440548, 53.636333495378494, 50.34536428749561, 51.30419343709946, 50.1301172375679, 59.55586865544319, 61.7976039648056, 54.13250707089901, 37.59230241179466, 20.53183726966381, 9.8104646243155, 3.8027233723551035, 2.895647920668125, 1.5083613619208336, 0.06044517118425574, 0.11844342952826992, 0.1574374714982696, 8.245534747838974, 38.86467933654785, 50.24302817881107, 20.219942405819893, 37.558184042572975, 36.28855437040329, 40.07223553955555, 48.267529383301735, 42.515508234500885, 11.401937026530504, 0.1822645525680855, 0.0338662022841163, 0.04863497815676965, 0.01239685334439855, 0.03705269868078176, 0.08614672857220285, 0.06304976443061605, 0.03960160487622488, 0.030305333202704787, 0.0666698272107169, 0.04385280488349963, 0.11382589800632559, 0.024904268138925545, 0.032773983548395336, 0.07318027317523956, 0.03989945471403189, 0.0734043943521101, 0.028559122802107595, 0.02217629469669191, 0.03225303298677318, 0.0362938972102711, 0.04062736428750213, 0.05619804927846417, 0.01602291638846509, 0.024017034302232787, 0.03426471332204528, 0.044570172249223106, 0.08639077641419135, 0.04774192959303036, 0.05311819950293284, 0.004969180572516052, 0.04461265278223436, 0.009043571317306487, 0.03473468947049696, 0.04654692340409383, 0.20337930705863982, 17.233078479766846, 64.10670205950737, 54.174263030290604, 49.98006708920002, 26.02962166070938, 31.01386170834303, 39.66036804020405, 36.24124690890312, 33.7812665104866, 2.3432603990659118, 0.04230640290188603, 0.3855514177121222, 1.0049088019877672, 9.422076065093279, 17.00063355267048, 9.179343190044165, 5.825374312698841, 28.958762884140015, 63.16576614975929, 59.54510763287544, 55.77242687344551, 54.178028628230095, 55.71807838976383, 56.7804291844368, 59.041034281253815, 55.87786361575127, 43.159934654831886, 52.940765619277954, 56.721239760518074, 55.79272918403149, 51.93568155169487, 45.824792459607124, 45.17681322991848, 51.41831651329994, 54.47271801531315, 55.505665987730026, 53.71405452489853, 47.958583161234856, 48.818503618240356, 47.362873926758766, 48.863926380872726, 48.56827184557915, 52.61776775121689, 54.53938543796539, 52.72373266518116, 47.29075379669666, 43.35470460355282, 43.71217802166939, 45.59699848294258, 47.133503034710884, 46.65025636553764, 42.1346128731966, 40.905139446258545, 40.60149013996124, 40.79283267259598, 40.64250513911247, 40.06174050271511, 40.53880490362644, 44.91474509239197, 46.59160651266575, 49.90477792918682, 51.900415644049644, 52.423107996582985, 51.29513092339039, 55.30801959335804, 53.200979456305504, 57.928575575351715, 49.69353586435318, 57.97630861401558, 28.01482893526554, 41.11997991800308, 58.25263358652592, 50.5441278219223, 50.98649628460407, 43.50021779537201, 41.923914179205894, 42.74978466331959, 43.562443256378174, 44.348472878336906, 45.55754519999027, 41.21434025466442, 41.5067345649004, 42.08050757646561, 41.63997821509838, 39.3112313747406, 41.07513852417469, 41.701010540127754, 41.864063590765, 41.96237951517105, 41.036392003297806, 39.7933305054903, 43.83623756468296, 51.15532502532005, 52.74904690682888, 50.436597391963005, 46.07963338494301, 43.97933788597584, 43.485843166708946, 50.441708117723465, 52.42204025387764, 54.81693014502525, 51.70123793184757, 52.21494756639004, 52.685252130031586, 54.168244153261185, 53.97373639047146, 54.71858762204647, 56.21502332389355, 53.85215811431408, 49.177071377635, 52.81010963022709, 55.65976291894913, 53.62187907099724, 55.8411879837513, 54.13883753120899, 53.78145530819893, 54.476658403873444, 52.58858151733875, 60.66664785146713, 62.85939618945122, 56.7235766351223, 39.179857224226, 21.251729540526867, 4.439204894006252, 3.005828708410263, 6.55697375535965, 3.7620707787573338, 0.3739768825471401, 0.07832765360944904, 0.048055115912575275, 10.041572023183107, 40.76082319021225, 46.68380096554756, 22.161685712635517, 41.603845953941345, 39.27873931825161, 44.497782066464424, 53.714787885546684, 50.80048866569996, 14.120624642819166, 0.28846261964645237, 0.04746959479234647, 0.004270848830856266, 0.04864007300056983, 0.038040582585381344, 0.06435385148506612, 0.07025607032119296, 0.06965766922803596, 0.038290077791316435, 0.0364041358261602, 0.023929505405249074, 0.06881625929963775, 0.006996694628469413, 0.040431890010950156, 0.02120666020346107, 0.0571023302472895, 0.030264227498264518, 0.01240636118382099, 0.10242050571832806, 0.12974970799405128, 0.15616952703567222, 0.13201309513533488, 0.21016885992139578, 0.10944993555312976, 0.14274409040808678, 0.12242188284290023, 0.16033600346418098, 0.24634732719277963, 0.16792637819889933, 0.16028111422201619, 0.06814926891820505, 0.1766090904129669, 0.1597638669773005, 0.1499249183689244, 0.14298184483777732, 0.385231344262138, 23.80988147109747, 73.95295411348343, 61.72883525490761, 57.97017954289913, 31.658164635300636, 34.119619354605675, 45.14335982501507, 46.78519852459431, 39.60048325359821, 4.37728151679039, 0.11932126406463794, 0.6155689875595272, 1.2287223734892905, 9.564338531345129, 26.88283357769251, 15.92253165319562, 6.38461927883327, 30.552186481654644, 65.2917292714119, 62.21993990242481, 56.60775125026703, 56.992765590548515, 58.03754612803459, 59.05898071825504, 60.59945605695248, 58.516206443309784, 44.839847311377525, 55.176968425512314, 58.919258415699005, 57.91163228452206, 55.16003653407097, 49.69945214688778, 47.14883141219616, 53.655773252248764, 56.82886518537998, 57.611816972494125, 54.3880395591259, 49.140312150120735, 48.70849572122097, 48.538667634129524, 49.6420182287693, 49.098028019070625, 53.91704723238945, 56.59745380282402, 55.08931092917919, 49.276914820075035, 44.01751443743706, 47.48401142656803, 47.19063296914101, 48.51867690682411, 48.79477009177208, 45.66078186035156, 43.72917450964451, 42.57240258157253, 43.220199421048164, 43.1145840883255, 41.02698750793934, 42.96840973198414, 47.74301692843437, 47.9440413415432, 51.87945976853371, 53.071641996502876, 54.943725541234016, 53.785422295331955, 57.3266726732254, 55.590070858597755, 60.15374757349491, 54.264903366565704, 59.777316972613335, 30.742238983511925, 42.74136811494827, 59.68212828040123, 53.49600702524185, 53.377852365374565, 47.69473671913147, 44.18755151331425, 45.68088658154011, 45.85801787674427, 46.89846284687519, 48.05031403899193, 43.56110952794552, 44.19181488454342, 43.255822509527206, 44.15437929332256, 40.98107077181339, 43.1467417627573, 44.383689388632774, 43.753842785954475, 44.60073374211788, 43.69774639606476, 42.45717756450176, 47.472703233361244, 55.36911651492119, 54.32817377150059, 53.75869832932949, 46.581149473786354, 48.363709822297096, 46.910891979932785, 50.90858146548271, 53.04615296423435, 55.51615722477436, 52.779612466692924, 52.2549632191658, 54.932208359241486, 57.22388818860054, 56.362987384200096, 54.84101325273514, 58.70626084506512, 54.81593079864979, 48.676231652498245, 54.151308462023735, 57.37309478223324, 57.14191518723965, 57.46881164610386, 58.21468122303486, 55.74589669704437, 56.316200494766235, 54.86678346991539, 62.8426618874073, 64.22834873199463, 56.217569187283516, 38.795222863554955, 25.629847012460232, 15.075501054525375, 12.126977071166039, 11.326369531452656, 3.9627693593502045, 0.6577798537909985, 0.20376722764922306, 0.34492761944420636, 11.955443825572729, 54.00827653706074, 59.66100141406059, 28.881494030356407, 47.477240189909935, 45.93807578086853, 53.536322861909866, 60.117410123348236, 59.07750852406025, 19.110407643020153, 0.4492571664741263, 0.16061202302807942, 0.2046766405692324, 0.10486778963240795, 0.12075543476385064, 0.10807456521433778, 0.14069188880966976, 0.11606440093601122, 0.0968299072701484, 0.15092524437932298, 0.11527922353707254, 0.20404200040502474, 0.07966834338731132, 0.16121332591865212, 0.11921356359380297, 0.26413935294840485, 0.1768986022216268, 0.11141975133796223], [0.05813667259644717, 0.027252703548583668, 0.05796795645437669, 0.14666577684693038, 0.03773004573304206, 0.0517667671374511, 0.03677629320009146, 0.022947297075006645, 0.02621522748086136, 0.06325024820398539, 0.030721444272785448, 0.03225484753784258, 0.03297515009762719, 0.032626875035930425, 0.04242846021952573, 0.06966185494093224, 0.051322046274435706, 0.8158856292720884, 31.541858576238155, 50.58860443532467, 45.836176648736, 32.52729959785938, 19.662626311182976, 17.403130754828453, 38.1015282869339, 42.87684224545956, 22.47555647045374, 1.1326332483440638, 0.07002323633059859, 0.3079035342670977, 0.38435563968960196, 9.044126495718956, 9.341108109802008, 4.260965483263135, 5.349524421617389, 28.38973581790924, 62.22054786980152, 59.10286456346512, 55.636907145380974, 54.110019877552986, 56.053190007805824, 56.57292991876602, 53.993396535515785, 55.31276933848858, 54.179058372974396, 51.79556027054787, 54.00869831442833, 53.59613925218582, 50.145726799964905, 45.12967295944691, 46.090041026473045, 50.5178864300251, 53.50745961070061, 54.394518211483955, 49.4803749024868, 49.71065014600754, 50.464989468455315, 47.95001082122326, 47.59470708668232, 47.44228206574917, 48.424901738762856, 51.116232722997665, 51.586256101727486, 45.64506970345974, 39.875945672392845, 39.97085697948933, 43.03431339561939, 43.16287949681282, 44.43643055856228, 40.22892393171787, 38.03389571607113, 38.76734375953674, 39.90838073194027, 38.54290880262852, 39.21608828008175, 37.71801106631756, 39.95761848986149, 38.535104021430016, 39.78906713426113, 38.22302296757698, 40.072041749954224, 40.443236231803894, 44.40034009516239, 43.167933225631714, 50.44762060046196, 48.91181901097298, 55.65163515508175, 29.914234913885593, 42.37473338842392, 54.15344774723053, 47.826095670461655, 48.364127799868584, 45.03569260239601, 47.797076627612114, 48.23387458920479, 51.726871356368065, 50.76267309486866, 52.12453901767731, 47.867274060845375, 42.380775064229965, 38.21625933051109, 39.86764311790466, 38.72773468494415, 40.13927534222603, 39.52635683119297, 39.33452412486076, 38.57473209500313, 38.722950741648674, 38.875041380524635, 48.58086816966534, 54.60528150200844, 51.214358657598495, 50.893929451704025, 47.85757698118687, 47.16878794133663, 46.30322478711605, 50.01935318112373, 52.303809598088264, 51.388005539774895, 50.47358840703964, 48.51900368928909, 50.70150397717953, 48.41398112475872, 49.47541616857052, 53.50886173546314, 53.51216375827789, 46.31775140762329, 48.59396606683731, 56.03426322340965, 51.657042503356934, 50.858291164040565, 46.511366218328476, 48.05545896291733, 49.02146212756634, 52.395650669932365, 54.33587595820427, 55.26155188679695, 31.526600494980812, 34.26417879760265, 49.22685630619526, 30.260759219527245, 8.646695371717215, 3.1603300804272294, 4.849260365590453, 1.9549665972590446, 0.35762021492701024, 0.1413413867703639, 0.14595318149076775, 4.18856986798346, 26.914316788315773, 58.32359477877617, 43.25728543102741, 28.325289376080036, 33.411360159516335, 41.82130828499794, 44.45406921207905, 41.36007763445377, 17.54868194460869, 0.4540411097696051, 0.06790965169784613, 0.030024979496374726, 0.0492223472247133, 0.040876102502807043, 0.05000421835575253, 0.034749213300528936, 0.015309974078263622, 0.044895188402733766, 0.027416734883445315, 0.039187838992802426, 0.05920148381846957, 0.06600719323614612, 0.03494302145554684, 0.02670632329682121, 0.10606665498926304, 0.03698462889587972, 0.029275863053044304, 0.009206274207826937, 0.06235610126168467, 0.051227370495325886, 0.01677759337326279, 0.03700708257383667, 0.034219664958072826, 0.02534640076191863, 0.011740968275262276, 0.040673269832041115, 0.0279016931381193, 0.021312128665158525, 0.01568158968439093, 0.016277777322102338, 0.00909109659914975, 0.029878160421503708, 0.03745555499335751, 0.03357375899213366, 1.3825079589150846, 40.01338429749012, 58.70062194764614, 52.92666457593441, 41.87716908752918, 27.49928779900074, 21.631435565650463, 34.92179051041603, 45.276641473174095, 24.612352810800076, 0.9943678707350045, 0.10724118532380089, 0.34101264202035964, 3.32280698698014, 11.01275335997343, 10.07437851279974, 8.21555720642209, 5.021147467195988, 29.6121796220541, 62.12146818637848, 60.45031785964966, 58.47682535648346, 55.61340160667896, 59.016852378845215, 56.674034893512726, 54.18125085532665, 55.23265063762665, 55.62868818640709, 53.319111317396164, 56.36997140944004, 56.2058962136507, 53.22636969387531, 46.621085330843925, 48.021120205521584, 54.033039808273315, 54.780315309762955, 56.38980254530907, 50.45704409480095, 50.29836840927601, 50.68190462887287, 48.25184762477875, 47.45109759271145, 46.293083131313324, 48.65931116044521, 53.179104030132294, 55.262995809316635, 47.53371275961399, 41.953241005539894, 42.97920875251293, 45.49984909594059, 44.84613977372646, 46.056785210967064, 41.30724146962166, 40.54681867361069, 40.157863944768906, 42.203499376773834, 39.361563473939896, 41.62509821355343, 41.21432505548, 42.19105124473572, 40.65515846014023, 42.44145020842552, 41.1666452139616, 42.60184720158577, 43.99239398539066, 48.300124034285545, 45.361433923244476, 52.15564414858818, 50.55594518780708, 58.014352172613144, 30.838964693248272, 45.10740615427494, 55.37470981478691, 50.749875381588936, 50.41954390704632, 45.432056933641434, 49.628403559327126, 50.369625985622406, 52.87195511162281, 51.74976132810116, 52.54455707967281, 49.87992346286774, 43.05303879082203, 39.701964408159256, 41.76821753382683, 40.50903730094433, 41.24938577413559, 42.11183309555054, 41.79757855832577, 40.16615889966488, 40.35586751997471, 40.33773109316826, 49.81279246509075, 55.98415531218052, 52.93580308556557, 52.59953252971172, 49.861160069704056, 49.19692151248455, 49.64335575699806, 52.000984847545624, 53.83071966469288, 53.279297053813934, 49.979941695928574, 48.61047998070717, 50.637652203440666, 50.56368537247181, 53.12447056174278, 56.13545939326286, 53.57410043478012, 48.02033744752407, 48.59900839626789, 58.168954476714134, 53.73378686606884, 52.81018942594528, 48.416393995285034, 50.78012555837631, 51.34852945804596, 55.194968059659004, 56.38248793780804, 58.20403419435024, 32.22708910703659, 37.80913397669792, 50.446655452251434, 31.393909715116024, 9.382688328623772, 2.112683071754873, 4.749016994610429, 4.442022442817688, 1.2609127024188638, 0.30920404416974634, 0.12018218505545519, 4.067612383514643, 33.51523518562317, 66.32535740733147, 41.74064241349697, 30.595884136855602, 38.613831996917725, 45.9695190936327, 49.857652857899666, 48.79532106220722, 23.539818562567234, 0.9606965712737292, 0.0691451271995902, 0.02845498649548972, 0.01579382467753021, 0.035084786504739895, 0.06915729100001045, 0.03773260243178811, 0.0130349723258405, 0.03388058510608971, 0.11648624509689398, 0.025620663291192614, 0.05136732470418792, 0.09146043172222562, 0.02261462195747299, 0.04201982999802567, 0.06365318244206719, 0.04466213547857478, 0.0218017364750267, 0.14919200300937518, 0.23745721438899636, 0.13032910268520936, 0.19755125103984028, 0.17591402458492666, 0.18481905455701053, 0.14602163719246164, 0.08953463271609508, 0.09407578982063569, 0.1053938981203828, 0.13603719795355573, 0.10322466725483537, 0.18418530497001484, 0.09190764249069616, 0.13093764893710613, 0.18954874685732648, 0.21031090698670596, 2.2102824971079826, 47.72216744720936, 65.21051242947578, 59.22863021492958, 46.77023492753506, 31.339080557227135, 27.228159047663212, 50.21811671555042, 54.865373745560646, 30.770750753581524, 1.3888118206523359, 0.18460841820342466, 1.0616700374521315, 2.6569295302033424, 20.070751011371613, 22.05914631485939, 12.637830208986998, 9.439295791089535, 33.2175325602293, 62.862010449171066, 62.12367586791515, 61.233984008431435, 57.877947092056274, 60.71544103324413, 58.635007068514824, 55.09528040885925, 55.981981828808784, 56.38363927602768, 56.63274630904198, 57.925178557634354, 57.63774678111076, 55.14438897371292, 48.4591569006443, 49.54285494983196, 56.87108851969242, 57.42028824985027, 56.465809866786, 50.565243288874626, 48.7109237909317, 50.494874864816666, 48.6925707757473, 47.684614062309265, 46.85467019677162, 49.38972316682339, 55.10266721248627, 55.76990380883217, 49.975131154060364, 43.77771310508251, 45.57109907269478, 47.77754187583923, 48.00584502518177, 47.61188216507435, 43.40984344482422, 42.325491830706596, 43.25644187629223, 46.09550513327122, 41.31495885550976, 42.78643749654293, 42.63612896203995, 42.90073536336422, 43.40214125812054, 44.49685491621494, 42.7879574149847, 42.22781427204609, 44.39874418079853, 48.81019726395607, 47.02438808977604, 54.87950898706913, 52.30026438832283, 58.72654415667057, 32.32390031218529, 46.350281462073326, 57.803626880049706, 52.92584002017975, 52.37563334405422, 47.96700730919838, 51.81021988391876, 53.006889671087265, 57.99787625670433, 55.00403970479965, 54.70601789653301, 52.93250486254692, 45.813457667827606, 42.76877224445343, 42.86626361310482, 43.13935115933418, 43.957819640636444, 43.57332967221737, 44.536714777350426, 43.44629488885403, 43.56267124414444, 41.63324497640133, 53.80470626056194, 58.30717585980892, 55.76436750590801, 55.90866096317768, 53.061203956604004, 52.300492376089096, 50.702556520700455, 54.45979490876198, 57.05247558653355, 55.43368265032768, 51.30423903465271, 49.63513299822807, 50.633628219366074, 51.543200612068176, 53.416621685028076, 58.72393749654293, 54.25362937152386, 47.87542462348938, 50.6477976590395, 59.26949322223663, 57.62386232614517, 55.46544134616852, 50.843471959233284, 55.04077613353729, 54.64104138314724, 57.70494617521763, 59.16971057653427, 62.54487566649914, 35.75769625604153, 40.104138627648354, 51.00027434527874, 33.98184634745121, 12.961075063794851, 7.296053571626544, 15.132053419947624, 7.269417000934482, 0.6902153883129358, 0.3279725433094427, 0.3462474251864478, 5.603884197771549, 39.81471195816994, 67.72736817598343, 47.584789618849754, 37.23115839064121, 44.46390688419342, 55.76550364494324, 57.89312727749348, 57.81115047633648, 31.34907592087984, 1.706497692503035, 0.17105959210311994, 0.0704978100839071, 0.1273387818946503, 0.132734700164292, 0.1577309612184763, 0.145814934221562, 0.1008485998318065, 0.1414774075965397, 0.1686363315093331, 0.10832550760824233, 0.24077338253846392, 0.1861355354776606, 0.11588869747356512, 0.10845731303561479, 0.2224335033679381, 0.12379135310766287, 0.15407876344397664], [0.08420678423135541, 0.05543611965549644, 0.029798125360684935, 0.06998248500167392, 0.03677632659673691, 0.008400137630815152, 0.03637305097072385, 0.02921074516052613, 0.04284994072804693, 0.01525970841612434, 0.14164011605316773, 0.20316559821367264, 0.049521707333042286, 0.04177755217824597, 0.02083257324557053, 0.10892124439124018, 0.056322177188121714, 7.3836778197437525, 47.684131488204, 49.06603753566742, 49.082961827516556, 34.601406902074814, 18.099105209112167, 29.791586995124817, 41.08626052737236, 36.38719327747822, 18.323530666530132, 0.1085796115512494, 0.1666844979627058, 0.3949294035555795, 2.6907052053138614, 12.767547648400068, 14.157356321811676, 7.991467081010342, 3.8217076286673546, 27.83789522945881, 58.34740050137043, 55.357975512742996, 58.770674988627434, 55.07544167339802, 56.84288263320923, 55.01926548779011, 57.33875222504139, 53.624337539076805, 55.67786514759064, 52.77479812502861, 55.017806366086006, 52.08975948393345, 50.15857771039009, 46.49666480720043, 50.420391261577606, 50.64353808760643, 54.28638741374016, 51.386067643761635, 49.40011940896511, 50.68223521113396, 52.878004387021065, 52.08915911614895, 52.60552480816841, 52.230731919407845, 50.33949740231037, 50.261628180742264, 51.48963488638401, 50.08377492427826, 42.018525302410126, 39.07554902136326, 42.76252917945385, 43.19906875491142, 44.2230112105608, 38.785628378391266, 37.61113420128822, 37.884795516729355, 38.5417764633894, 37.99876660108566, 37.62392811477184, 37.61921636760235, 38.16328637301922, 38.32798093557358, 39.82733868062496, 39.407081231474876, 41.37255236506462, 39.36881348490715, 43.34655784070492, 42.29004733264446, 50.44020339846611, 50.29080681502819, 56.53987929224968, 31.40021737664938, 42.68962249159813, 55.694679245352745, 49.54773008823395, 51.658372431993484, 47.649317756295204, 52.97111079096794, 50.33868804574013, 53.462359830737114, 51.53045989573002, 52.113234624266624, 53.61247077584267, 46.264295876026154, 42.71041497588158, 38.56302112340927, 37.30968497693539, 37.31125429272652, 41.12338073551655, 39.55212324857712, 38.51879149675369, 39.16269354522228, 42.306736037135124, 49.823933467268944, 54.10820737481117, 52.063670083880424, 52.57129244506359, 49.67856466770172, 49.58265781402588, 51.31286837160587, 52.53126539289951, 48.93442399799824, 44.964761808514595, 48.287896290421486, 48.693570122122765, 47.67184294760227, 45.34158758819103, 45.07292680442333, 49.74463552236557, 49.041620045900345, 49.916245713829994, 53.230728060007095, 53.03352624177933, 52.834458723664284, 47.469986379146576, 43.01449365913868, 43.78711760044098, 46.114496514201164, 52.60889522731304, 56.741982847452164, 52.56526596844196, 36.92270614206791, 50.611008033156395, 46.342503279447556, 42.51334995031357, 15.161593034863472, 4.00498129427433, 4.374886220321059, 4.15696743875742, 0.30358720337972045, 0.3770933981286362, 0.16684146219631657, 1.4472164679318666, 16.266267858445644, 32.738568261265755, 50.20399287343025, 27.778232730925083, 21.541097313165665, 39.40754860639572, 39.479900524020195, 51.61517255008221, 25.38136124610901, 1.4339454425498843, 0.07102407442289405, 0.013597035085695097, 0.06645447821938433, 0.02770410374068888, 0.04691471694968641, 0.04771499334310647, 0.05140084380400367, 0.022744427296856884, 0.0912692173733376, 0.03210083334124647, 0.018424344852974173, 0.08069825140410103, 0.04597015220497269, 0.018785614920489024, 0.030673713044961914, 0.024337493669008836, 0.06556465799803846, 0.1113510804134421, 0.03221319449949078, 0.055609177361475304, 0.0523126056214096, 0.07517834994359873, 0.027014093793695793, 0.036620779865188524, 0.017200791953655425, 0.03292621659056749, 0.04875116879702546, 0.14779021963477135, 0.09314552997238934, 0.07346928032347932, 0.03022571745532332, 0.04176952956186142, 0.05303603633365128, 0.03532813672791235, 10.447948817163706, 56.157790794968605, 54.232928082346916, 54.25233744084835, 39.951793402433395, 22.441901676356792, 25.135284550487995, 41.66655018925667, 40.55412568151951, 20.486562699079514, 0.10208223480731249, 0.48589515674393624, 1.077257632277906, 4.967722333967686, 15.55245716124773, 9.954427499324083, 11.721657570451498, 4.42211008630693, 28.84524777531624, 59.14695359766483, 56.51639275252819, 60.71985639631748, 55.98048850893974, 58.88609379529953, 54.3472221493721, 58.26509691774845, 55.75630433857441, 56.3356364518404, 54.52945277094841, 55.123554691672325, 53.872262835502625, 52.59487397968769, 47.93656714260578, 51.80888615548611, 54.179271161556244, 55.38263238966465, 51.69854387640953, 48.989441245794296, 51.99537254869938, 54.359126910567284, 53.66809979081154, 52.30425037443638, 51.2797037512064, 50.29482699930668, 50.732639506459236, 53.83795827627182, 50.26143059134483, 43.75851273536682, 41.47391192615032, 46.13067224621773, 45.005845203995705, 47.62241519987583, 40.90445168316364, 39.437316209077835, 39.990114346146584, 39.99148227274418, 38.99991787970066, 41.09725333750248, 39.608820006251335, 39.84191469848156, 41.11891217529774, 41.08368046581745, 40.92323027551174, 42.77150809764862, 41.283656135201454, 44.961896762251854, 44.60204467177391, 52.94417403638363, 51.97894603013992, 58.974131271243095, 32.52244345843792, 43.67571897804737, 56.049504205584526, 51.575647071003914, 53.051377683877945, 50.18795393407345, 53.44678446650505, 52.96870931982994, 55.39603427052498, 53.79481539130211, 54.410158172249794, 55.09208098053932, 49.115932658314705, 44.34102147817612, 42.03669972717762, 39.508619382977486, 39.47477079927921, 42.25439764559269, 42.38889902830124, 41.252159625291824, 41.26463055610657, 44.11600895226002, 50.82266807556152, 57.21389852464199, 53.78497391939163, 53.30418951809406, 50.24002633988857, 51.71862579882145, 53.57111759483814, 54.18599300086498, 51.33144177496433, 45.67435473203659, 48.908361196517944, 49.717216193675995, 47.96544939279556, 45.939170122146606, 45.58838054537773, 51.369895711541176, 49.75259989500046, 48.74786540865898, 54.40445847809315, 55.14063097536564, 54.872198179364204, 48.88572961091995, 46.31417199969292, 46.11724756658077, 49.172211438417435, 55.287211909890175, 58.18816624581814, 54.727114364504814, 40.92115558683872, 52.050815373659134, 49.13283035159111, 42.44107402861118, 17.178051732480526, 5.153102036565542, 5.8372847735881805, 5.069440500810742, 1.4234119327738881, 0.9119387750979513, 0.19865075766574591, 1.8781247455626726, 17.92196251451969, 42.54789389669895, 46.973619014024734, 34.08437244594097, 28.425934575498104, 46.12381361424923, 46.847933158278465, 58.00778992474079, 33.412431702017784, 2.682746769860387, 0.009889028733596206, 0.05870408160262741, 0.04005667498859111, 0.043907193175982684, 0.03532051858201157, 0.07067494589136913, 0.035225397514295764, 0.03323195174743887, 0.057354983291588724, 0.02440071722958237, 0.033678709805826657, 0.067009352351306, 0.08586660493165255, 0.030637952659162693, 0.05306186307279859, 0.02057589776086388, 0.04855891544139013, 0.20505437889369205, 0.1664809713838622, 0.12357610801700503, 0.2944630914134905, 0.09866238862741739, 0.14854994136840105, 0.09209522031596862, 0.12975475459825248, 0.1190574602514971, 0.21298870939062908, 0.19451898406259716, 0.3617808729177341, 0.22320275427773595, 0.1583026078878902, 0.18810952955391258, 0.21429891174193472, 0.19528704753611237, 14.09560963511467, 65.83618685603142, 62.27941431105137, 62.00339712202549, 46.41335427761078, 27.50493999570608, 39.60000067949295, 51.10849253833294, 49.402224496006966, 24.190507046878338, 0.1654632791178301, 0.7703140808735043, 1.0810715588741004, 4.845911795273423, 21.55816599726677, 26.188627928495407, 15.856520645320415, 7.667131209746003, 32.115618288517, 57.78620861470699, 57.40535885095596, 61.43175579607487, 57.39066883921623, 59.80268821120262, 55.486697405576706, 59.208491295576096, 57.5487669557333, 57.90018729865551, 54.43625897169113, 56.66313327848911, 56.44249051809311, 55.604973658919334, 51.2812464684248, 54.78720434010029, 55.69461464881897, 57.417871579527855, 53.12996506690979, 49.3476290255785, 52.247933596372604, 56.3147147744894, 54.965015798807144, 53.64218518137932, 53.22859637439251, 49.69322048127651, 52.91013926267624, 56.198479011654854, 54.52774666249752, 45.98655737936497, 44.09723415970802, 48.41452069580555, 46.85961373150349, 49.9865647405386, 42.88094222545624, 41.57557547092438, 42.13163383305073, 42.24860295653343, 40.117149129509926, 42.09904298186302, 41.07208728790283, 41.59076705574989, 42.73368492722511, 43.152832835912704, 44.24540340900421, 45.328778475522995, 43.63944612443447, 49.59666006267071, 47.112828344106674, 55.56765206158161, 53.97053696215153, 59.071698635816574, 34.00798134505749, 45.23210026323795, 59.73408289253712, 53.964867666363716, 55.501239225268364, 52.04047232866287, 56.93779394030571, 53.880212008953094, 57.46134504675865, 55.62163196504116, 57.1676018089056, 56.771138682961464, 50.67479521036148, 46.824986189603806, 43.41294027864933, 40.99973537027836, 42.23480589687824, 45.465476140379906, 45.263691768050194, 44.71998654305935, 44.50528286397457, 46.514805033802986, 54.56337735056877, 58.83632406592369, 54.874763041734695, 55.11566251516342, 52.29052931070328, 54.055823385715485, 55.7539826631546, 56.34134754538536, 50.815672650933266, 45.212386921048164, 49.25754725933075, 50.32136857509613, 50.284670144319534, 46.40554189682007, 45.50087884068489, 51.920113787055016, 51.033199578523636, 50.356281101703644, 55.68089738488197, 57.28743977844715, 56.80948622524738, 51.466649919748306, 49.108884036540985, 50.55144242942333, 50.983916223049164, 59.49083134531975, 60.131419971585274, 60.09567528963089, 42.77087353169918, 53.2526870816946, 50.02696417272091, 45.618885308504105, 18.29058263450861, 7.809041244909167, 10.57440223172307, 10.610440447926521, 1.3454864267259836, 0.9635183948557824, 0.40598271356429905, 1.9359162007458508, 22.678801864385605, 47.561637461185455, 61.056871712207794, 34.49481122195721, 31.788368448615074, 53.09461936354637, 54.982639253139496, 64.12896126508713, 41.668374091386795, 4.068283997476101, 0.1986919913906604, 0.13094613910652697, 0.11406380086555146, 0.0910263198602479, 0.16277765447739512, 0.13678918650839478, 0.14936012914404273, 0.1448364570387639, 0.2031855471432209, 0.08107577450573444, 0.10790236468892545, 0.1584729307796806, 0.12850408733356744, 0.15224601491354406, 0.09406201555975713, 0.10746854968601838, 0.22078166075516492], [0.032636960822856054, 0.023300544526136946, 0.027277867920929566, 0.08381092266063206, 0.058799265752895735, 0.024298185817315243, 0.043936697256867774, 0.049163031071657315, 0.039250034678843804, 0.07021396086202003, 0.006997536966082407, 0.07688061406952329, 0.017827619158197194, 0.06076640980609227, 0.1130929974897299, 0.024766516253293958, 0.14016033295774832, 15.258342493325472, 49.51086446642876, 45.064449459314346, 36.37441836297512, 19.505405947566032, 28.105816952884197, 47.34139747917652, 42.68340602517128, 40.21793112158775, 11.19374429807067, 0.058866593390121125, 2.369588236324489, 6.23018036596477, 8.141614124178886, 10.381506532430649, 4.523628763854504, 8.543974533677101, 0.3962560370564461, 16.64267186075449, 61.598772034049034, 54.1463877260685, 57.54790440201759, 54.1415885835886, 55.90287007391453, 54.14221554994583, 53.130029663443565, 52.86389574408531, 58.3014989644289, 53.00777122378349, 55.34859761595726, 51.0287082195282, 52.543272748589516, 50.24767532944679, 53.07581417262554, 51.91887505352497, 53.216159641742706, 47.95919872820377, 48.27970013022423, 53.56608286499977, 52.03338950872421, 49.0887451171875, 52.714373767375946, 52.25589416921139, 45.30164793133736, 49.7112201154232, 51.88055031001568, 48.73908407986164, 44.562310203909874, 39.58625681698322, 44.429001957178116, 43.38050901889801, 43.926547318696976, 38.55924412608147, 38.88421028852463, 37.18716435134411, 37.566201612353325, 36.653802171349525, 38.80420558154583, 41.835812106728554, 46.85034602880478, 47.4703473597765, 50.045670568943024, 50.01034766435623, 51.64687044918537, 50.956185311079025, 52.574032098054886, 50.24115867912769, 53.94640065729618, 49.55357417464256, 59.8704993724823, 24.166306145489216, 36.676346361637115, 55.944930016994476, 49.23044331371784, 54.92744721472263, 50.776629745960236, 54.39777843654156, 52.0095419883728, 53.16965773701668, 48.57443131506443, 48.68318147957325, 50.726601630449295, 49.65795457363129, 45.35876266658306, 40.06962887942791, 37.9766745865345, 36.219622269272804, 37.660014778375626, 38.9153154194355, 38.24956454336643, 38.236345052719116, 41.49230293929577, 50.30468747019768, 52.79455706477165, 49.966213032603264, 47.3682202398777, 51.16176947951317, 50.98088018596172, 51.59871183335781, 46.957488879561424, 47.381591722369194, 48.53213958442211, 51.562689766287804, 51.219469383358955, 52.86468990147114, 50.1278867572546, 47.69462272524834, 48.337365835905075, 48.285973593592644, 48.645901679992676, 51.203312650322914, 52.6224073022604, 50.61465963721275, 50.20327091217041, 49.42303217947483, 48.18575017154217, 46.930392533540726, 50.25107614696026, 55.50006128847599, 56.63201294839382, 62.060101479291916, 58.9827948063612, 53.74768652021885, 50.8307084441185, 24.490903727710247, 5.371768902987242, 2.630112231709063, 1.7110890336334705, 10.783591456711292, 33.81354197859764, 0.8334859879687428, 0.02567140578321414, 14.463347252458334, 40.37982143461704, 36.409862861037254, 24.68123361468315, 21.662014424800873, 25.750640630722046, 39.92592439055443, 44.52868960797787, 35.80765217542648, 4.945538649335504, 0.2983040321851149, 0.0630514342628885, 0.0530695628549438, 0.046128945832606405, 0.06771954314899631, 0.017243667680304497, 0.07203047862276435, 0.0813200969423633, 0.03646617566118948, 0.07656708636204712, 0.05203846740187146, 0.046558230023947544, 0.11944126192247495, 0.013008064834139077, 0.04463689874683041, 0.043332444329280406, 0.035545871724025346, 0.07090481129125692, 0.0481476877030218, 0.016654226164973807, 0.044926848422619514, 0.01757569898472866, 0.07680097420234233, 0.07490820818929933, 0.05532862698601093, 0.09339676922536455, 0.0065769544562499505, 0.04153925969148986, 0.016265023514279164, 0.05075550187029876, 0.05766308961028699, 0.06161369012261275, 0.07627637969562784, 0.15598630561726168, 21.056193932890892, 55.703726559877396, 53.62653002142906, 44.81025069952011, 33.05063411593437, 29.80472669005394, 42.6995475590229, 45.965236723423004, 45.238825902342796, 13.66959074512124, 0.2021260719629936, 2.7043863711878657, 10.603534318506718, 8.507552538067102, 10.43274013325572, 8.363392073661089, 11.071725245565176, 2.95357224997133, 19.739484786987305, 59.94620271027088, 53.84389355778694, 57.567104771733284, 53.86815905570984, 58.58672305941582, 55.93539632856846, 55.82061968743801, 55.12181058526039, 57.25890330970287, 53.36197681725025, 55.74118115007877, 53.05587664246559, 53.91929671168327, 52.29085609316826, 54.439143016934395, 54.26995329558849, 54.09654580056667, 46.74243941903114, 49.344289004802704, 53.46619762480259, 53.91707383096218, 51.608507707715034, 54.785357639193535, 53.633582442998886, 45.26099011301994, 49.9557825922966, 54.26898814737797, 51.99927493929863, 47.11934119462967, 41.46361827850342, 45.30711583793163, 45.31286872923374, 46.62163630127907, 39.24913510680199, 40.36420427262783, 38.26492331922054, 39.896061792969704, 39.081841483712196, 39.715358689427376, 43.350388035178185, 47.215954810380936, 50.10026603937149, 53.293823674321175, 51.65193557739258, 52.02466517686844, 52.85701811313629, 53.826205506920815, 51.865848898887634, 56.14017494022846, 51.494947001338005, 60.96664935350418, 25.65306756645441, 38.34662273526192, 58.302042335271835, 51.36252410709858, 56.68611444532871, 53.565117716789246, 56.79208695888519, 55.03977298736572, 54.81463126838207, 48.98233562707901, 51.963176876306534, 54.82696920633316, 51.10449895262718, 48.59742008149624, 42.15267330408096, 40.05001053214073, 38.24025124311447, 38.67741018533707, 41.52080900967121, 40.217520743608475, 41.52376905083656, 44.00593265891075, 51.47659778594971, 55.79719014465809, 51.98297381401062, 49.891292452812195, 54.76013459265232, 53.888563960790634, 53.39929461479187, 48.93793120980263, 47.19058357179165, 48.162183836102486, 52.764485478401184, 53.151278123259544, 53.99226039648056, 51.267259418964386, 49.14665400981903, 47.86404423415661, 49.233737736940384, 49.13635656237602, 53.161218389868736, 54.756733775138855, 52.73829348385334, 52.27411799132824, 50.79736143350601, 49.77310359477997, 49.42989461123943, 51.23205430805683, 58.51582646369934, 58.38111229240894, 62.389163821935654, 60.40072672069073, 55.97484581172466, 50.64213976264, 25.45704558491707, 8.003352843225002, 8.831198271363974, 3.371526785194874, 11.302404217422009, 31.84847742319107, 1.1389774829149246, 0.0199092803086387, 15.276402924209833, 38.78168039023876, 39.94782641530037, 32.84565791487694, 23.85047659277916, 32.389541789889336, 45.63278116285801, 50.59273861348629, 43.880455791950226, 8.090943843126297, 0.3834757494041696, 0.0724204994912725, 0.024794066630420275, 0.0504006513801869, 0.06574636543518864, 0.02598700964881573, 0.056731805598246865, 0.0431082044087816, 0.050210550252813846, 0.08996203556307591, 0.039447612944059074, 0.06671707233181223, 0.08594151731813326, 0.03734148318471853, 0.06655391858657822, 0.06086986519221682, 0.01913914253236726, 0.1286459859693423, 0.15047648252220824, 0.12451882852474228, 0.17595889483345672, 0.09759728054632433, 0.17442849726649, 0.1246219128370285, 0.16796752286609262, 0.1546737432363443, 0.12107343020034023, 0.0697231711819768, 0.1939763850532472, 0.10268557860399596, 0.1473589427769184, 0.13907400687457994, 0.13186012365622446, 0.39775113807991147, 27.422697208821774, 65.67460432648659, 59.593783020973206, 49.59041699767113, 30.476802326738834, 39.35862623155117, 60.461667850613594, 51.92984126508236, 53.12332682311535, 14.128435123711824, 0.16101987770525739, 2.3949578125029802, 11.962709035724401, 14.612009525299072, 20.310660637915134, 9.789662640541792, 22.844387479126453, 2.839807542040944, 17.36052554100752, 62.88174659013748, 54.30095583200455, 59.38218377530575, 56.20596081018448, 61.401536017656326, 57.85024277865887, 57.28048615157604, 57.60308124125004, 60.63556931912899, 54.70501855015755, 57.220023795962334, 55.07577605545521, 56.64057768881321, 53.69903773069382, 57.067541778087616, 56.45115405321121, 55.91736629605293, 48.23912970721722, 49.64408151805401, 56.54620975255966, 56.13442204892635, 54.8972312361002, 58.483098819851875, 55.54519146680832, 46.06203272938728, 51.18801847100258, 55.320467725396156, 53.82791541516781, 49.38123062252998, 43.411914333701134, 48.55798579752445, 47.85202547907829, 48.727194517850876, 41.797103583812714, 41.766477227211, 41.341230645775795, 40.88565409183502, 40.6784588098526, 42.86391153931618, 45.92294119298458, 51.3242943584919, 53.276321813464165, 55.79616419970989, 55.6267274916172, 53.89772146940231, 55.82107946276665, 55.89602664113045, 54.59827467799187, 59.282264336943626, 54.86913174390793, 62.054200395941734, 27.275396212935448, 39.59884934127331, 58.955668061971664, 53.19770783185959, 58.89259144663811, 54.6621910482645, 57.374960482120514, 56.918882355093956, 56.891124844551086, 50.429446175694466, 54.23712305724621, 56.443626657128334, 52.83106170594692, 51.30216434597969, 44.18692074716091, 41.383111998438835, 39.50520716607571, 42.01323978602886, 43.23282614350319, 43.224865570664406, 43.41717705130577, 46.86261177062988, 54.32963669300079, 57.75489829480648, 53.26478563249111, 49.85731087625027, 56.04878984391689, 55.623900443315506, 55.31650833785534, 49.65005099773407, 48.67136411368847, 50.361179038882256, 54.229591861367226, 54.98076215386391, 55.14110215008259, 52.338437139987946, 49.38397407531738, 48.4789652377367, 50.582786947488785, 50.025090873241425, 54.19434875249863, 58.0730552226305, 56.78167551755905, 54.83529455959797, 54.11073423922062, 53.54073062539101, 52.59568713605404, 54.862637892365456, 62.11044877767563, 61.22050233185291, 64.3687891960144, 62.656015902757645, 57.10043281316757, 52.87456937134266, 28.96507054567337, 7.7318664360791445, 6.77923190407455, 5.0102439522743225, 18.07501070201397, 42.17432454228401, 1.3427579356357455, 0.12474405550165102, 20.02912424504757, 52.972486317157745, 46.06507636606693, 33.87269340455532, 31.300949603319168, 37.295329347252846, 55.92236302793026, 57.39737547934055, 53.42318393290043, 10.916426628828049, 0.731884902343154, 0.20450694108149037, 0.16929547738982365, 0.10120650797034614, 0.21957758552161977, 0.05177509032364469, 0.15994551504263654, 0.10809915998834185, 0.1072210879647173, 0.18183400301495567, 0.23837799701141194, 0.1556589888059534, 0.20029430306749418, 0.15969113650498912, 0.15394482063129544, 0.09784915062482469, 0.0862476829206571], [0.021675838543160353, 0.0679565331665799, 0.022410492383642122, 0.042765094694914296, 0.019723210898519028, 0.027810351457446814, 0.028806974150938913, 0.09229075396433473, 0.08654034143546596, 0.0463621063681785, 0.054903409763937816, 0.007030477654552669, 0.0334955143625848, 0.05510438706551213, 0.015553541379631497, 0.044650123818428256, 1.2334727123379707, 26.58731583505869, 51.48116514086723, 48.01271505653858, 34.238419979810715, 18.736190423369408, 36.0127841681242, 49.56421360373497, 46.72877915203571, 32.8061780333519, 4.952346459031105, 0.04757609298394527, 6.360875777900219, 15.284474641084671, 5.413061762228608, 14.268657099455595, 8.969260063022375, 8.252483624964952, 3.59395544975996, 14.978971034288406, 55.60587041079998, 53.11611481010914, 60.58010749518871, 53.210155963897705, 52.871350944042206, 51.62148781120777, 51.38821452856064, 49.795765578746796, 54.52312231063843, 53.55164743959904, 49.632689729332924, 52.00903281569481, 54.33584176003933, 51.365761533379555, 54.20310728251934, 52.48741194605827, 50.17712451517582, 46.873186603188515, 49.85878899693489, 51.779335141181946, 48.230561167001724, 49.16670933365822, 49.48181502521038, 51.88840068876743, 50.88982567191124, 49.181000366806984, 54.777913838624954, 51.60052053630352, 48.74362103641033, 42.13945001363754, 45.14469355344772, 43.66869695484638, 41.39472797513008, 37.38114394247532, 38.25890064239502, 36.93961143493652, 36.850532814860344, 39.239400029182434, 48.24626952409744, 51.372673362493515, 52.0574764162302, 48.59817624092102, 52.96093873679638, 52.276549860835075, 54.0221343934536, 49.6895232796669, 53.65364156663418, 51.36121317744255, 54.09653440117836, 49.29063968360424, 53.16763624548912, 21.30427122116089, 32.44151160120964, 52.43969790637493, 47.458666786551476, 50.535829067230225, 48.04896891117096, 52.10937023162842, 50.692703649401665, 49.23857867717743, 45.65079599618912, 43.20501923561096, 51.1208950728178, 50.52987098693848, 48.506604954600334, 44.105365723371506, 34.890373796224594, 35.31152419745922, 38.315133824944496, 37.20595434308052, 37.23609432578087, 39.136516749858856, 39.201584458351135, 47.7179154753685, 52.41587698459625, 50.34850671887398, 47.577228024601936, 48.31060007214546, 46.13547898828983, 47.50513069331646, 45.88640235364437, 51.11044563353062, 51.42054319381714, 53.558566868305206, 52.86608822643757, 54.58974413573742, 50.285939276218414, 50.68991839885712, 46.425699815154076, 46.84697940945625, 48.78779746592045, 53.964575082063675, 54.54269886016846, 52.40472078323364, 51.584318205714226, 52.06696830689907, 51.321607902646065, 50.14167621731758, 45.63094966113567, 50.75295701622963, 50.273779928684235, 52.302008494734764, 52.581456899642944, 60.810010358691216, 55.00690095126629, 39.81668025255203, 12.574178874492645, 9.163358397781849, 7.740813530981541, 5.144173940643668, 34.10160072147846, 8.035880997776985, 0.175353747617919, 4.894239027053118, 39.65971827507019, 26.024763621389866, 22.30407927185297, 25.974057242274284, 31.918625459074974, 39.196078553795815, 45.59351406991482, 47.220343574881554, 17.889206372201443, 0.40946659224573523, 0.0595580004301155, 0.022190404779394157, 0.02728972744080238, 0.022519191043102182, 0.05776766935014166, 0.060176621336722746, 0.05919150193221867, 0.030170125028234906, 0.023056192403601017, 0.020896273636026308, 0.09281913342420012, 0.04396578573505394, 0.055345329019473866, 0.005297692241583718, 0.009135649579548044, 0.01560353244713042, 0.02461394924466731, 0.02265328042994952, 0.039792459283489734, 0.06379078404279426, 0.045019609460723586, 0.03610658284742385, 0.08111631061183289, 0.08744835169636644, 0.0757944883662276, 0.01626753011805704, 0.022684651012241375, 0.008696089425939135, 0.05013014597352594, 0.05342842465324793, 0.020919358139508404, 0.018416383463772945, 1.6281178733333945, 33.72141592204571, 58.72581459581852, 53.28154273331165, 39.27987165749073, 18.682265616953373, 35.47116503119469, 53.03222291171551, 52.44580797851086, 40.41939251124859, 5.263895066455007, 0.06291614816291258, 7.741328403353691, 17.470867820084095, 7.6982529647648335, 11.51838842779398, 13.15928477793932, 10.788655634969473, 2.3402989329770207, 14.81926940381527, 57.61023625731468, 55.84301948547363, 60.45597195625305, 55.00304415822029, 56.894510462880135, 53.64793807268143, 53.78210507333279, 52.304470762610435, 56.80159404873848, 53.60202893614769, 52.09123380482197, 54.11413885653019, 56.065683737397194, 54.05613876879215, 56.142021641135216, 51.81346870958805, 50.674791410565376, 47.549744099378586, 49.60827223956585, 53.59666742384434, 51.101576909422874, 49.61565904319286, 51.957157999277115, 52.81170554459095, 50.78941226005554, 48.67226846516132, 54.75033491849899, 55.0683930516243, 50.84021553397179, 44.96961034834385, 46.99663057923317, 45.67278541624546, 44.52002227306366, 40.07489159703255, 40.519908517599106, 38.17337103188038, 39.192107766866684, 40.31952627003193, 48.43806803226471, 52.56738245487213, 53.920550644397736, 51.656499132514, 55.10970823466778, 53.418730571866035, 55.92544846236706, 51.417256370186806, 54.49974596500397, 52.92530044913292, 57.28289142251015, 51.36780582368374, 54.206454902887344, 22.75989331305027, 33.38302128016949, 52.56073661148548, 49.71185088157654, 53.49482148885727, 48.839014917612076, 52.310687229037285, 50.033203437924385, 49.722532108426094, 46.33287839591503, 44.85720477998257, 53.362732976675034, 51.49832122027874, 49.80754874646664, 45.61059795320034, 38.51227484643459, 37.37053491175175, 40.10381184518337, 39.85100761055946, 39.190196469426155, 40.34501910209656, 40.931217446923256, 49.468432143330574, 54.53605681657791, 49.68953847885132, 45.18782123923302, 49.368136525154114, 47.602652460336685, 46.633981838822365, 44.89924572408199, 50.63233248889446, 53.2975322753191, 54.27246496081352, 54.90937538444996, 56.41012765467167, 52.46177092194557, 53.84963884949684, 47.366799116134644, 48.154037073254585, 49.979899898171425, 54.43981558084488, 55.982042625546455, 54.973189160227776, 53.34002919495106, 55.58927670121193, 54.121791645884514, 52.2022220492363, 49.18886214494705, 53.25708344578743, 52.32006132602692, 53.72619487345219, 56.0747766494751, 59.167320504784584, 56.921367421746254, 41.95835553109646, 12.844886798411608, 7.076754039153457, 10.015159640461206, 6.3252398651093245, 47.98044718801975, 10.927963759750128, 0.35763900610618293, 6.508693071082234, 39.50611911714077, 30.80117952078581, 27.90896661579609, 29.474644102156162, 36.15094855427742, 44.69086490571499, 50.18147528171539, 55.998077765107155, 23.885508812963963, 0.7895156973972917, 0.02102547041431535, 0.00649282227641379, 0.018938462089863606, 0.0061633639052161016, 0.12395247336826287, 0.040339451807085425, 0.03825358267931733, 0.05088112891826313, 0.022274666371231433, 0.027621333865681663, 0.006899223735672422, 0.0025546191091052606, 0.0626054331951309, 0.08317346233525313, 0.04798620750079863, 0.02120645240211161, 0.1567715869168751, 0.17176325200125575, 0.15184148505795747, 0.14824545301962644, 0.1499682301073335, 0.17072420072508976, 0.10845304568647407, 0.2502288931282237, 0.2195947291329503, 0.0745595249463804, 0.09816563208005391, 0.09245071647455916, 0.1340104965493083, 0.1500384372775443, 0.1941581815481186, 0.10855386644834653, 2.425371380522847, 41.34371191263199, 68.35180386900902, 61.61147855222225, 46.873425990343094, 28.39954499155283, 48.327752351760864, 57.89178974926472, 54.70311105251312, 45.78173317015171, 6.5394429210573435, 0.18520642595831305, 10.046805292367935, 24.255588054656982, 14.76785721257329, 27.773560881614685, 18.16980041563511, 24.032693915069103, 8.137665186077356, 18.75941287726164, 59.236343801021576, 55.06036028265953, 64.05712231993675, 59.02874194085598, 58.9622987061739, 56.49102911353111, 56.344299986958504, 54.43647935986519, 58.63319456577301, 56.91589571535587, 51.03315778076649, 55.52162513136864, 59.89065729081631, 56.41143098473549, 57.60050877928734, 54.03872810304165, 52.17240124940872, 48.20525832474232, 51.734185963869095, 55.877381041646004, 52.870416194200516, 54.59496505558491, 53.81464272737503, 55.917377695441246, 52.47803024947643, 49.09973792731762, 57.80651092529297, 55.88490083813667, 53.38200934231281, 45.35808630287647, 49.91757184267044, 47.564988881349564, 45.35997100174427, 42.09441103041172, 42.80966944992542, 40.27067229151726, 40.72868071496487, 42.757122069597244, 50.82327224314213, 54.96007986366749, 56.695309951901436, 51.73947148025036, 57.20133639872074, 55.360091999173164, 57.89941594004631, 51.73868112266064, 56.37240327894688, 55.23401476442814, 58.70382517576218, 52.852477356791496, 54.19060975313187, 25.304069593548775, 35.79109646379948, 52.356349378824234, 51.96831040084362, 54.71694231033325, 50.58982416987419, 54.892625883221626, 51.42971970140934, 50.66647365689278, 47.15638920664787, 44.115131199359894, 55.60341574251652, 54.60558168590069, 52.20794454216957, 47.771359607577324, 38.45101073384285, 38.849924728274345, 43.219994232058525, 42.176273837685585, 42.4504367262125, 43.59708219766617, 42.309627681970596, 52.128498405218124, 56.52722977101803, 51.125785410404205, 46.11894987523556, 49.340105429291725, 47.154565304517746, 47.408638671040535, 44.85170267522335, 51.66445970535278, 55.36417298018932, 57.52806566655636, 56.934822499752045, 60.61529740691185, 54.39680568873882, 54.40043829381466, 48.44806149601936, 47.1853094547987, 50.79538933932781, 56.19569756090641, 58.71989831328392, 56.7739999294281, 55.56720368564129, 58.44028651714325, 56.049580201506615, 55.146543458104134, 51.74526996910572, 57.4485207349062, 54.48023021221161, 57.22421497106552, 57.032169476151466, 64.06558826565742, 57.21443049609661, 43.436020240187645, 15.803512539714575, 14.735524747520685, 16.121305637061596, 10.666747726500034, 39.00619134306908, 9.940603841096163, 0.32729888102039695, 7.7201013173907995, 51.90138079226017, 35.24443119764328, 34.37162943184376, 36.00130498409271, 42.566049322485924, 50.304075703024864, 58.48945967853069, 65.18747806549072, 31.42689384520054, 1.0476694512180984, 0.16179070196812972, 0.0983781460672617, 0.07753890648018569, 0.18524185608839616, 0.24758292885962874, 0.18231231719255447, 0.1483296274091117, 0.2184220467461273, 0.09114341592066921, 0.1147263532038778, 0.26040082855615765, 0.2847356133861467, 0.23230381513712928, 0.1758609907119535, 0.09883768390864134, 0.170202411536593], [0.05356238973035943, 0.016444504508399405, 0.014527448001899756, 0.07705172363785096, 0.019244241775595583, 0.048343225062126294, 0.036654807336162776, 0.024440965753456112, 0.03150806514895521, 0.028426590070012026, 0.015013162319519324, 0.0314655957481591, 0.04511224804446101, 0.031114530211198144, 0.06508636608486995, 0.05203267493925523, 3.025977839715779, 42.439565509557724, 47.58657172322273, 46.704726442694664, 41.41071371734142, 57.22020998597145, 56.10027328133583, 57.16335743665695, 43.521686643362045, 26.19431622326374, 3.2887624762952328, 0.2749753324314952, 2.261523697525263, 5.325402365997434, 6.95057705976069, 7.715390520170331, 6.7880536057055, 4.229028197005391, 3.296144767664373, 19.756669364869595, 53.53831395506859, 57.29085199534893, 57.72379696369171, 51.89109854400158, 50.848514288663864, 47.63838194310665, 48.09514783322811, 50.504891127347946, 54.431957602500916, 56.86848185956478, 50.132769495248795, 45.158809795975685, 53.586168587207794, 52.599524930119514, 49.263330549001694, 50.55459626019001, 51.623942479491234, 49.201127886772156, 52.22884342074394, 50.426702722907066, 45.938508957624435, 41.06138326227665, 46.98262073099613, 52.136413380503654, 50.975659266114235, 44.887181371450424, 51.6518709808588, 51.42509914934635, 48.75847063958645, 45.42034216225147, 46.08806513249874, 46.25714085996151, 41.9990399479866, 37.69521988928318, 37.744746431708336, 36.35032005608082, 38.60359914600849, 43.265375196933746, 51.66778452694416, 48.55274587869644, 48.20153072476387, 51.34744271636009, 56.234546676278114, 52.09811143577099, 51.46694630384445, 48.92627723515034, 51.68859601020813, 46.86945140361786, 52.60346531867981, 41.97512023150921, 50.51998011767864, 18.76237291842699, 29.664499014616013, 48.34743909537792, 39.7257549315691, 43.56854572892189, 40.90928502380848, 41.87908038496971, 38.629335165023804, 43.71592082083225, 43.41563053429127, 45.45508749783039, 44.22105051577091, 48.38968902826309, 51.58283248543739, 47.4551709741354, 39.47043903172016, 36.69994309544563, 36.98150038719177, 37.87137843668461, 37.00075775384903, 39.7537974268198, 41.29773437976837, 50.729379281401634, 51.062336415052414, 50.26700869202614, 42.35687434673309, 46.560869961977005, 46.85085900127888, 45.316147953271866, 46.28286547958851, 52.685799300670624, 51.0778471827507, 50.38109377026558, 49.43461015820503, 49.845037534832954, 52.10748553276062, 52.015279680490494, 48.87811481952667, 49.439166113734245, 47.461246848106384, 53.46441172063351, 53.66058759391308, 52.407817617058754, 55.97654052078724, 52.621932327747345, 52.782587707042694, 53.58129344880581, 52.5931640714407, 51.321539506316185, 49.71704140305519, 54.404808059334755, 56.913984417915344, 57.20505639910698, 57.11101524531841, 43.76537136733532, 20.23483380675316, 14.842327516525984, 5.9244373720139265, 5.437100697308779, 4.065055595710874, 5.766769107431173, 0.038932744282647036, 2.345276903361082, 28.890446349978447, 44.222391843795776, 27.106430679559708, 20.236659608781338, 26.024908013641834, 35.62543295323849, 43.406032249331474, 43.40594485402107, 26.366579979658127, 1.4618121972307563, 0.04758250142913312, 0.016790421395853627, 0.017488466946815606, 0.052270514715928584, 0.054761314459028654, 0.019365440057299566, 0.038301373278955, 0.057047882582992315, 0.03473310498520732, 0.06934656092198566, 0.02247070282464847, 0.04828847311728168, 0.012433135088940617, 0.007448076266882708, 0.041192205462721176, 0.03757756407139823, 0.05265999381663278, 0.025050001822819468, 0.06721363592077978, 0.01404113811076968, 0.029285162163432688, 0.06366497516864911, 0.030352852918440476, 0.011237123289902229, 0.043139901536051184, 0.01893369379104115, 0.02136899758625077, 0.03166147449519485, 0.050998451333725825, 0.03235647724068258, 0.012984313325432595, 0.08339925334439613, 4.396404940634966, 47.583615481853485, 56.69229291379452, 52.40188993513584, 48.718652576208115, 53.09848755598068, 56.861117854714394, 60.859069526195526, 51.739536076784134, 31.15972638130188, 3.5337985027581453, 0.42433142429217696, 5.084815425798297, 6.258734883740544, 4.483756078407168, 15.875355284661055, 14.461226966232061, 6.9956716150045395, 2.630772446282208, 21.781493313610554, 56.43190048635006, 57.76173792779446, 59.60071384906769, 53.578451201319695, 53.41646209359169, 49.361756667494774, 50.50329141318798, 53.67362089455128, 56.21899791061878, 57.37727835774422, 49.7668681293726, 46.81677483022213, 53.10418725013733, 53.568134754896164, 49.78143274784088, 50.11754371225834, 51.82029314339161, 50.15049934387207, 54.75061610341072, 53.35971213877201, 48.78566578030586, 43.9701271802187, 49.87959288060665, 55.34373767673969, 51.43604256212711, 45.90271107852459, 52.15803422033787, 55.795438438653946, 49.896076396107674, 46.210555359721184, 47.947024181485176, 48.10616344213486, 42.020368203520775, 39.2389440536499, 39.80412192642689, 39.08999964594841, 39.29228939116001, 45.37482440471649, 54.06610183417797, 50.604225397109985, 50.73319807648659, 53.55809189379215, 56.51239916682243, 51.955254301428795, 53.220780193805695, 50.51990792155266, 52.555903270840645, 47.72252082824707, 52.948973178863525, 43.372058272361755, 49.8788633197546, 21.06264028698206, 31.27298690378666, 49.63875040411949, 41.66973061859608, 44.70565751194954, 43.29231195151806, 43.27292159199715, 39.89912062883377, 45.78806363046169, 44.308898001909256, 45.86896128952503, 45.23893229663372, 50.44571690261364, 53.70255634188652, 49.8801476508379, 41.37405328452587, 38.87693747878075, 38.51205065846443, 40.1981645822525, 38.36698964238167, 42.26016953587532, 43.63694965839386, 52.69089102745056, 52.97029763460159, 52.21681706607342, 45.11269547045231, 46.84965826570988, 46.52009814977646, 45.72527579963207, 46.65877930819988, 53.460980504751205, 53.492974787950516, 51.83305665850639, 52.03750088810921, 50.94897709786892, 54.907699674367905, 52.616213634610176, 48.782880529761314, 50.26092141866684, 49.60521340370178, 54.602321460843086, 53.666450679302216, 54.84069786965847, 57.11990676820278, 55.73956623673439, 55.59717647731304, 56.40695862472057, 54.51519213616848, 51.22262701392174, 51.79402515292168, 55.649393275380135, 59.27816055715084, 60.15072673559189, 52.81417541205883, 45.85056647658348, 19.877590276300907, 11.215906608849764, 9.897184520959854, 7.031494192779064, 6.3219967391341925, 5.541212260723114, 0.09897679949062876, 2.0260016480460763, 33.717023357748985, 42.2504610568285, 25.386040695011616, 25.922725796699524, 31.1984596028924, 40.02006433904171, 50.46667277812958, 50.23895859718323, 33.66573750972748, 2.101725172251463, 0.05035350644902792, 0.08253821360995062, 0.09157127889920957, 0.037636052729794756, 0.051273250064696185, 0.04183303884929046, 0.028539003178593703, 0.003941704017051961, 0.024605967446404975, 0.062245892331702635, 0.06244958960451186, 0.02659851892531151, 0.06534335698233917, 0.008394740361836739, 0.06913134551723488, 0.020652958664868493, 0.1482310998835601, 0.09891514928312972, 0.11414200096623972, 0.19414458540268242, 0.12385354508296587, 0.17110179062001407, 0.1920974304084666, 0.12959885905729607, 0.09402924231835641, 0.0800608133431524, 0.08939309773268178, 0.13442718278383836, 0.12793946138117462, 0.12980535422684625, 0.09751219331519678, 0.2081475910381414, 6.424346622079611, 59.52972985804081, 63.285144343972206, 59.86194223165512, 54.17102940380573, 66.89676314592361, 66.96162566542625, 63.57817322015762, 53.100531846284866, 36.15335762500763, 4.184245225042105, 0.3633142984472215, 8.691726755350828, 14.256375208497047, 14.832855574786663, 18.992175087332726, 17.55879320204258, 10.145963821560144, 8.611638452857733, 24.914370104670525, 55.598061829805374, 60.39940819144249, 61.85853369534016, 56.3604187220335, 56.3280064612627, 52.0564428716898, 52.40924634039402, 56.39932103455067, 57.84455068409443, 59.59513574838638, 51.68970935046673, 48.0993390083313, 56.19286671280861, 53.80020350217819, 51.2029592692852, 52.152706906199455, 54.54340562224388, 50.60853436589241, 55.73800832033157, 56.02904990315437, 51.55614271759987, 46.269030421972275, 52.26282499730587, 58.32179367542267, 50.39039187133312, 43.86438645422459, 53.3957190066576, 55.95473349094391, 53.117406740784645, 48.84070582687855, 50.392941534519196, 51.22203804552555, 45.86244463920593, 42.433254048228264, 40.190773978829384, 41.41673259437084, 41.168594509363174, 48.84034864604473, 55.35155765712261, 52.89729595184326, 52.74676322937012, 56.957161501049995, 57.41286724805832, 54.093030989170074, 54.460760056972504, 51.11150577664375, 53.357512056827545, 48.502687364816666, 54.297790601849556, 44.775155782699585, 50.571201369166374, 23.601105473935604, 33.596296235919, 49.183633625507355, 42.6370333135128, 45.33968009054661, 44.09546725451946, 43.5669270157814, 40.091603100299835, 47.34490469098091, 45.94070143997669, 47.0225565880537, 48.20897452533245, 49.939048290252686, 55.62246032059193, 53.16336527466774, 44.60075654089451, 41.60925306379795, 40.43524906039238, 43.05565685033798, 39.50944773852825, 44.503219574689865, 47.8238195925951, 54.73058357834816, 54.79503192007542, 55.497956201434135, 48.175304532051086, 46.997854113578796, 46.27856031060219, 45.58314062654972, 49.141554683446884, 56.36240981519222, 56.896235570311546, 55.85815407335758, 54.18881244957447, 54.28349196910858, 57.47607685625553, 55.28579838573933, 50.112687572836876, 51.82274781167507, 51.85172125697136, 55.09311072528362, 55.866148844361305, 56.470202431082726, 60.60416400432587, 57.07655869424343, 59.11245904862881, 57.56946064531803, 59.3174884468317, 53.7358083575964, 55.827645510435104, 57.485941126942635, 62.952939569950104, 62.15393364429474, 55.76203063130379, 42.930058389902115, 24.889116659760475, 22.112145870923996, 17.86474708467722, 10.610642787069082, 7.371045872569084, 8.557632900774479, 0.11618704826105386, 3.418445480056107, 39.049991592764854, 56.40880912542343, 36.75700843334198, 33.864748030900955, 35.423948764801025, 47.85797975957394, 57.60633006691933, 58.31889443099499, 40.386923253536224, 3.610830819234252, 0.20898372429655865, 0.1682904313202016, 0.14679730025818571, 0.13186941534513608, 0.1506531730410643, 0.08736376170418225, 0.11431869890657254, 0.16105974587844685, 0.12145623739343137, 0.19963886792538688, 0.24733053927775472, 0.1206617831485346, 0.20056903129443526, 0.10385333313024603, 0.14299679169198498, 0.0815766945015639], [0.07726469775661826, 0.03641308983787894, 0.006757727251169854, 0.08737865660805255, 0.004477923339436529, 0.1105405438283924, 0.05498609614733141, 0.02047772275545867, 0.06620833752094768, 0.04023956986202393, 0.021434262052935082, 0.10564277734374627, 0.08265987387858331, 0.025665503853815608, 0.05658656358718872, 0.0396734855894465, 4.91016112267971, 43.04110363125801, 44.12240780889988, 35.80167129635811, 17.334394343197346, 34.46294613182545, 46.00645311176777, 37.6807426661253, 31.50406390428543, 23.787892051041126, 0.7440472184680402, 0.23682552797254175, 13.772445525974035, 6.039084820076823, 6.287849871441722, 10.146771278232336, 15.644655413925648, 7.147215083241463, 6.6957432590425014, 33.68658319115639, 55.73013134300709, 55.21128058433533, 57.002994641661644, 55.936764255166054, 52.81502276659012, 47.26202353835106, 44.10727322101593, 50.548246800899506, 52.45278440415859, 54.02627617120743, 56.440446227788925, 51.83557592332363, 48.007110357284546, 50.6048371642828, 52.66702450811863, 51.625496596097946, 50.68734593689442, 50.99687732756138, 49.89788129925728, 50.351455360651016, 45.75465202331543, 39.717672765254974, 46.807218343019485, 52.11231127381325, 51.79530568420887, 46.39880105853081, 50.532291457057, 51.16288281977177, 51.19557626545429, 48.28826867043972, 44.30789865553379, 44.37089167535305, 39.04713034629822, 37.24502384662628, 37.65322834253311, 36.51946797966957, 40.10335586965084, 48.93856577575207, 52.726901695132256, 49.03937816619873, 52.929145842790604, 48.07435154914856, 47.67034962773323, 53.524471297860146, 49.999803230166435, 49.21919211745262, 51.73541709780693, 48.45909230411053, 50.815638452768326, 44.984174966812134, 52.25081004202366, 20.547009855508804, 32.92878985404968, 48.768148720264435, 43.16810421645641, 49.61100049316883, 49.403562024235725, 49.41565677523613, 47.64770284295082, 46.908121928572655, 44.67163413763046, 48.21051724255085, 47.5937457382679, 49.21126574277878, 48.3429591357708, 49.246189668774605, 41.37329712510109, 35.97964994609356, 36.207052543759346, 36.78294584155083, 37.53783233463764, 38.88288415968418, 40.02548664808273, 45.82109145820141, 53.1915407627821, 45.82362972199917, 52.01535567641258, 50.21162286400795, 51.52218014001846, 48.385695442557335, 49.58908326923847, 51.2271373718977, 48.1217198073864, 45.18884718418121, 45.34779645502567, 47.118531838059425, 48.0774749815464, 48.852280005812645, 47.8774993121624, 47.656153589487076, 45.188273414969444, 50.12732058763504, 49.56158794462681, 51.195355877280235, 49.86060909926891, 49.85892578959465, 51.259344443678856, 52.506175339221954, 53.419030755758286, 55.58060176670551, 54.85093832015991, 53.43467451632023, 58.337543830275536, 57.12919346988201, 42.41938479244709, 41.96774482727051, 23.664372079074383, 7.637435803189874, 5.427758423611522, 6.407024301588535, 16.066430881619453, 17.400926873087883, 0.7071300619281828, 0.1266447699163109, 21.472609788179398, 39.333103001117706, 41.18117183446884, 27.459462136030197, 25.565964840352535, 31.44697956740856, 42.086423859000206, 49.44513939321041, 29.325118325650692, 3.013903987593949, 0.10308887649443932, 0.0369533622142626, 0.07553495190222748, 0.018176712437707465, 0.042800072114914656, 0.023297913612623233, 0.014300722814368783, 0.033412905904697254, 0.06890268239658326, 0.04051707001053728, 0.07305956285563298, 0.02249522523925407, 0.13496780768036842, 0.07780360829201527, 0.025883628477458842, 0.036982599121984094, 0.09366426893393509, 0.015491771500819596, 0.041619036855991, 0.058562071644701064, 0.05949809798039496, 0.01880331699794624, 0.10023318871390074, 0.06658443569904193, 0.02660543759702705, 0.06665801221970469, 0.029363130342972, 0.07138305125408806, 0.04054422890476417, 0.07357550392043777, 0.007939519964565989, 0.07290794208529405, 7.328623048961163, 51.41514368355274, 50.73379084467888, 42.42123909294605, 24.647269137203693, 44.65097464621067, 51.913646534085274, 44.61423821747303, 34.45228390395641, 25.47086164355278, 0.8867121068760753, 0.3107516001909971, 18.25304824858904, 6.655452596023679, 10.381385888904333, 16.458195559680462, 10.393512938171625, 4.4593974854797125, 6.5901920478791, 35.347124487161636, 55.9661290794611, 55.23121431469917, 57.95799359679222, 57.2322591394186, 54.919714629650116, 48.0145313590765, 45.58085314929485, 51.44542045891285, 54.010339826345444, 56.6044682264328, 54.63821053504944, 50.42773626744747, 48.5738081485033, 50.9515343606472, 52.76219800114632, 54.036547020077705, 54.46246236562729, 53.07527460157871, 53.7370090931654, 52.696716114878654, 45.867540165781975, 42.387884482741356, 48.831381127238274, 54.44778375327587, 51.97658255696297, 47.195751294493675, 49.61817070841789, 51.733483001589775, 54.14687789976597, 48.70902009308338, 46.39902904629707, 45.31318411231041, 40.71954220533371, 40.874053314328194, 39.836431592702866, 38.418815061450005, 42.4631280452013, 51.45488575100899, 54.06158767640591, 51.286843568086624, 53.48333090543747, 47.68475845456123, 48.9403934776783, 52.56183475255966, 51.05737768113613, 48.97564798593521, 53.1658161431551, 48.99368181824684, 51.110859811306, 45.84103278815746, 51.82665400207043, 21.17403130978346, 32.415505796670914, 49.632784724235535, 43.760359436273575, 51.220917105674744, 48.126226365566254, 51.40298813581467, 48.93699645996094, 49.66478280723095, 47.947803139686584, 50.68403251469135, 48.580944165587425, 50.21915026009083, 51.00234903395176, 50.88728740811348, 44.95457835495472, 37.905831187963486, 38.214545622467995, 38.883651718497276, 39.19639013707638, 41.1876504868269, 41.73906169831753, 48.923746570944786, 53.4935637563467, 49.20021593570709, 55.467196851968765, 50.45338109135628, 52.19457685947418, 49.86070029437542, 51.54329560697079, 52.97777563333511, 51.09142005443573, 46.30570985376835, 47.607238814234734, 49.00386907160282, 52.7300251275301, 52.34346807003021, 49.37045820057392, 49.228524416685104, 46.764478236436844, 50.29262691736221, 50.12276463210583, 52.32485666871071, 51.37837305665016, 51.13697201013565, 54.227422177791595, 55.39180889725685, 55.58958448469639, 57.98178032040596, 57.25336700677872, 56.293595507740974, 58.32294501364231, 58.626347333192825, 45.1661092042923, 41.617548018693924, 26.46652601659298, 10.28202312067151, 8.400403037667274, 2.6529815420508385, 7.483868468552828, 17.646179012954235, 0.9053973073605448, 0.14715673722093925, 24.20820079743862, 41.41788013279438, 36.808936446905136, 32.612358033657074, 29.725006967782974, 36.78469754755497, 48.687764033675194, 55.91015048325062, 38.157195299863815, 4.527943432331085, 0.1421062886947766, 0.018504222207411658, 0.04366813627711963, 0.05651282008329872, 0.008530640589015093, 0.03278298208897468, 0.017014839431794826, 0.036704449594253674, 0.07480090105673298, 0.05424229348136578, 0.04809922174899839, 0.11038613258278929, 0.038505282063852064, 0.028291120288486127, 0.0518138860934414, 0.05298996009514667, 0.35654718813020736, 0.120766863838071, 0.1556207236717455, 0.14546710444847122, 0.13647870160639286, 0.11662244403851219, 0.1631597417872399, 0.18034034175798297, 0.12337019172264263, 0.12817675567930564, 0.1021869370015338, 0.14862623414956033, 0.12541756936116144, 0.11692406769725494, 0.18879726296290755, 0.1231803280825261, 11.626992300152779, 61.58912055194378, 58.62850181758404, 49.52919088304043, 26.08499798923731, 44.58594113588333, 53.68240602314472, 44.292277693748474, 42.26371854543686, 30.411305241286755, 0.8565233799163252, 0.36914576834533364, 21.077769175171852, 10.377785582095385, 11.2725131213665, 19.351688995957375, 22.600045390427113, 18.539663068950176, 10.537577457726002, 37.66859471797943, 56.633662059903145, 56.988665610551834, 59.32778209447861, 60.12233845889568, 57.11056686937809, 51.36419981718063, 48.590873032808304, 53.43538507819176, 56.40362620353699, 58.88094127178192, 56.74257181584835, 52.008223459124565, 50.734816789627075, 51.582980677485466, 54.50096569955349, 54.96616713702679, 56.3551028072834, 55.220084711909294, 56.342415288090706, 56.29748649895191, 48.83940249681473, 44.76680003106594, 49.79220137000084, 57.055348232388496, 53.73603634536266, 46.59261345863342, 50.665056332945824, 54.46639895439148, 55.862436443567276, 51.43524840474129, 48.75991836190224, 48.933641240000725, 42.77093432843685, 41.63713596761227, 40.6515296548605, 41.284712478518486, 45.91770127415657, 53.55284437537193, 58.29682141542435, 51.58327326178551, 52.62261629104614, 47.05334633588791, 51.97857744991779, 52.071706652641296, 49.25646811723709, 52.132837772369385, 53.310595974326134, 50.5918038636446, 52.80050754547119, 47.443034425377846, 51.96976572275162, 23.972987718880177, 35.21198853850365, 49.02442216873169, 43.41919094324112, 51.071041747927666, 51.536064594984055, 53.10120441019535, 51.54329560697079, 50.61389587819576, 49.241686910390854, 52.63771288096905, 49.58661340177059, 51.91443309187889, 51.82034634053707, 54.220673739910126, 47.1032452583313, 40.7100161164999, 39.16886821389198, 41.360567808151245, 41.39885075390339, 44.58190955221653, 44.86356183886528, 52.19229698181152, 56.659284085035324, 50.76929233968258, 56.54336750507355, 53.701986372470856, 54.62067827582359, 51.86664305627346, 52.120712623000145, 54.17924076318741, 51.73139691352844, 47.569525837898254, 49.750171825289726, 50.98263569176197, 53.521374464035034, 53.271511271595955, 50.34471832215786, 50.43485328555107, 48.15367229282856, 51.491568982601166, 50.24493187665939, 54.376157596707344, 52.130033522844315, 52.56306208670139, 53.116908967494965, 57.52006709575653, 57.68977738916874, 59.12114918231964, 60.586779937148094, 59.70878764986992, 60.53401216864586, 59.87884372472763, 49.23461548984051, 45.28791926801205, 26.133376993238926, 8.75967375934124, 10.747057367116213, 15.790257900953293, 22.418470233678818, 21.00575353950262, 1.0353378066793084, 0.33692438795696944, 27.126273214817047, 54.62355852127075, 51.65589116513729, 36.08444832265377, 36.45118184387684, 42.08614267408848, 55.66408708691597, 63.580225110054016, 46.458663046360016, 6.6548859514296055, 0.2932157786563039, 0.18362346949288622, 0.14117248880211264, 0.1225186737428885, 0.12545660632895306, 0.1250877886195667, 0.1284573765587993, 0.09156066618743353, 0.2432137422147207, 0.20229721121722832, 0.15654897229978815, 0.2663750876672566, 0.2380872383946553, 0.3100628574611619, 0.15393129870062694, 0.0789563640137203], [0.07476326674805023, 0.04897515267657582, 0.042563601600704715, 0.020770325609191786, 0.020908893857267685, 0.01775202399585396, 0.0664740263891872, 0.045268080502864905, 0.03830725479929242, 0.0613385574251879, 0.023708024418738205, 0.014424912878894247, 0.017254569829674438, 0.01605898476555012, 0.0487210598657839, 0.04054294498928357, 9.64969240128994, 37.47959665954113, 44.880999103188515, 30.106003023684025, 20.883835181593895, 32.763240337371826, 43.751441314816475, 26.209325417876244, 33.50000940263271, 20.572274699807167, 0.010460120647621807, 0.46394655480980873, 24.888457395136356, 5.5891243647783995, 2.4545659264549613, 18.72898980975151, 10.865190178155899, 4.928787248209119, 25.62119297683239, 58.95770475268364, 56.57871700823307, 57.19798117876053, 57.06772416830063, 53.414801582694054, 53.746987357735634, 51.26956209540367, 41.454217582941055, 46.357603669166565, 50.86079902946949, 51.881903037428856, 53.6059845238924, 56.88494637608528, 54.45127956569195, 51.823025196790695, 54.61705707013607, 50.65791271626949, 50.31865932047367, 47.652619779109955, 46.97340242564678, 45.28278574347496, 40.900921672582626, 36.97955869138241, 46.47814080119133, 50.81849589943886, 50.477346405386925, 49.258580803871155, 50.51062501966953, 51.9306468218565, 49.00463283061981, 47.521291226148605, 44.33081142604351, 39.269893392920494, 36.3193479180336, 36.2767294049263, 38.75940218567848, 38.18347468972206, 42.94387824833393, 50.003473833203316, 53.84556546807289, 50.204372853040695, 48.75470124185085, 49.194687232375145, 45.87154895067215, 47.02206261456013, 52.62759402394295, 50.14865644276142, 54.57122012972832, 50.69293923676014, 53.917746394872665, 47.109419927001, 52.82131902873516, 22.95759480446577, 29.97664276510477, 49.65968728065491, 46.8382702767849, 52.89193443953991, 49.09236632287502, 52.01527588069439, 51.973261535167694, 54.38811555504799, 52.7717050909996, 53.17831747233868, 51.91076248884201, 49.602120369672775, 51.67564630508423, 48.22224721312523, 41.42214350402355, 37.86114178597927, 37.397939041256905, 37.207364067435265, 36.362828984856606, 37.75618761777878, 39.125675931572914, 42.59729124605656, 50.45097582042217, 53.21031555533409, 54.193660989403725, 52.890532314777374, 51.56701773405075, 53.203502520918846, 50.37094831466675, 51.070004403591156, 47.43877865374088, 42.470248863101006, 43.14132705330849, 48.36466357111931, 52.143530398607254, 52.3345385491848, 48.6988290399313, 42.453579157590866, 47.23365806043148, 47.74732209742069, 47.146889716386795, 49.29723612964153, 47.293550446629524, 50.14135703444481, 50.03811277449131, 50.81272780895233, 50.79238370060921, 56.796411126852036, 55.32679818570614, 55.87475538253784, 52.49615527689457, 46.728969141840935, 37.24700354039669, 27.003380209207535, 16.814044564962387, 13.231087625026703, 9.412872958928347, 5.759097319096327, 8.148103225976229, 14.169777855277061, 0.9373624983709306, 0.08045845606829971, 14.022239372134209, 43.1136417388916, 49.25732687115669, 39.54597517848015, 19.762904830276966, 21.920423358678818, 36.578596606850624, 47.129387855529785, 35.719363912940025, 5.727188056334853, 0.49968066858127713, 0.10137367673451081, 0.12302544186240993, 0.022868237938382663, 0.025258100031351205, 0.05234034339082427, 0.06525104123284109, 0.0720196877955459, 0.01542007632451714, 0.04453889072465245, 0.023957968624017667, 0.04372604234958999, 0.073914071690524, 0.045420410024235025, 0.03429692253121175, 0.04264442890416831, 0.05938565147516783, 0.012936534785694676, 0.05479343832121231, 0.026939446725009475, 0.08222558390116319, 0.004412076750668348, 0.08246596553362906, 0.06787897873437032, 0.047386804508278146, 0.04832942482607905, 0.08279427682282403, 0.0503893855784554, 0.022252465023484547, 0.030527443159371614, 0.03902595803083386, 0.09178628650261089, 13.577729724347591, 46.4241760969162, 52.211482152342796, 38.02137918770313, 23.76763343811035, 34.99296449124813, 48.793858140707016, 28.242484219372272, 35.55800937116146, 22.157239951193333, 0.020223997307766695, 0.5286481173243374, 29.95990466326475, 8.40778699144721, 6.828470611944795, 14.77010764181614, 8.810642324388027, 4.155404297634959, 22.67021432518959, 60.98828539252281, 57.72137649357319, 58.91369171440601, 58.22962962090969, 55.57522125542164, 55.1667545735836, 52.18528635799885, 43.59648562967777, 48.80977548658848, 52.884779423475266, 53.72469015419483, 53.76851700246334, 57.03160710632801, 54.08673092722893, 51.51702381670475, 56.81059576570988, 53.02176207304001, 51.60066872835159, 50.753485187888145, 49.28084380924702, 46.6830600053072, 43.94219107925892, 40.173496305942535, 47.947563752532005, 50.86195416748524, 53.866354152560234, 50.45843102037907, 50.29974013566971, 54.20893996953964, 51.23284846544266, 50.04552997648716, 47.799299508333206, 40.9069861471653, 39.05350640416145, 38.89128930866718, 41.51453174650669, 39.75418880581856, 46.407441794872284, 52.16822527348995, 55.10323718190193, 50.646509528160095, 48.815972954034805, 49.57060866057873, 46.18731960654259, 49.49578307569027, 53.07356469333172, 50.14987997710705, 57.3120928555727, 52.158854976296425, 56.14590883255005, 48.54411654174328, 54.056818932294846, 25.074111633002758, 32.157625034451485, 50.25157392024994, 47.46960639953613, 54.17107120156288, 51.39493256807327, 55.358651876449585, 53.812803626060486, 56.60079002380371, 52.52393178641796, 53.7191728502512, 54.291023164987564, 52.64810912311077, 52.833474576473236, 50.219138860702515, 42.653782814741135, 39.7731763869524, 39.54822465777397, 39.31334026157856, 38.18261593580246, 41.01958550512791, 42.50359587371349, 44.54708822071552, 54.393017292022705, 55.21882317960262, 55.14243967831135, 54.85896348953247, 53.15170370042324, 54.62113805115223, 51.18341691792011, 52.94284410774708, 49.525030106306076, 43.94757159054279, 45.94526879489422, 49.11831133067608, 54.604525342583656, 53.726046681404114, 48.63356754183769, 46.36716775596142, 49.34329345822334, 48.320927917957306, 47.33974076807499, 48.99132214486599, 47.604958936572075, 49.640870690345764, 50.53533889353275, 51.7281860858202, 51.92059636116028, 57.24567621946335, 57.51133136451244, 59.263603538274765, 55.85883803665638, 46.03994831442833, 38.95746275782585, 26.820393428206444, 17.951352037489414, 12.8411715477705, 10.800250712782145, 4.443502463400364, 6.788841588422656, 18.011930286884308, 0.7855185493826866, 0.09113246924243867, 14.907784704118967, 49.340979382395744, 49.236910566687584, 42.35640697181225, 25.068894512951374, 26.924040466547012, 42.16230198740959, 55.376119539141655, 45.558172166347504, 8.13926300033927, 0.33675155660603195, 0.08637997074401937, 0.07601218254421838, 0.07247803820064291, 0.0432110957626719, 0.05476255013491027, 0.04729376145405695, 0.01956195519596804, 0.026620490207278635, 0.016426468464487698, 0.059681924249161966, 0.05656109678966459, 0.0398611636046553, 0.09237043093889952, 0.035975430510006845, 0.06054996985767502, 0.13361913239350542, 0.11905685169040225, 0.12740057311020792, 0.13189576158765703, 0.14680709660751745, 0.09781192449736409, 0.2369737793924287, 0.198915348155424, 0.1902013024664484, 0.14192193921189755, 0.10473266680492088, 0.12478367134463042, 0.1314176106825471, 0.118272995314328, 0.13333039241842926, 0.21677191107301041, 19.747287668287754, 55.516598001122475, 61.831391751766205, 43.37016597390175, 31.879593953490257, 42.33083054423332, 53.03408861160278, 35.03303714096546, 46.145556047558784, 24.824751913547516, 0.08877188301994465, 1.161408273037523, 34.45392921566963, 9.340429846197367, 8.57501981779933, 29.776355512440205, 19.633571170270443, 10.731124822050333, 28.90602931380272, 62.32719674706459, 60.95953233540058, 60.09094074368477, 60.575323551893234, 58.622881919145584, 58.70789475739002, 56.38225615024567, 46.829804331064224, 50.357310846447945, 56.04877084493637, 54.83369864523411, 57.4286288022995, 56.153607219457626, 53.99598799645901, 54.13321003317833, 60.01093603670597, 55.729056000709534, 53.40663202106953, 52.283032312989235, 50.88960148394108, 49.12591092288494, 44.42415341734886, 41.62520080804825, 50.9740025550127, 55.38184963166714, 54.940389320254326, 51.34593799710274, 52.428743094205856, 56.17192603647709, 51.860567182302475, 51.764892116189, 48.58876034617424, 42.30885252356529, 39.61407892405987, 40.57696245610714, 43.58050748705864, 41.4607722312212, 47.181764245033264, 54.89005722105503, 57.94963024556637, 51.390217021107674, 49.32414248585701, 52.18917354941368, 47.53940485417843, 51.72138065099716, 53.69349382817745, 52.04840250313282, 58.05197015404701, 53.77260558307171, 56.88097558915615, 50.00065818428993, 52.47083343565464, 28.16649589687586, 34.691044092178345, 50.0860396027565, 50.37119910120964, 57.04339787364006, 54.28921826183796, 55.986226201057434, 57.844212502241135, 59.11552168428898, 55.339656695723534, 57.04862259328365, 55.17594628036022, 53.039484322071075, 56.373953595757484, 52.87440598011017, 44.99375805258751, 42.338585928082466, 42.02683165669441, 41.88917264342308, 39.524380937218666, 43.368988037109375, 44.793463200330734, 46.99951842427254, 56.986256539821625, 57.848791256546974, 57.98679605126381, 57.11638055741787, 56.21972367167473, 57.676618695259094, 54.2172235250473, 54.94394592940807, 51.945108845829964, 46.03242851793766, 48.69947500526905, 52.665827572345734, 58.116445094347, 55.46332485973835, 50.837316289544106, 47.22242586314678, 50.71677155792713, 50.29867239296436, 49.041851833462715, 49.8112041503191, 48.408779203891754, 49.315045773983, 50.37575505673885, 52.23993502557278, 51.71663470566273, 59.33130070567131, 59.95480164885521, 60.41514694690704, 55.61616785824299, 48.57557885348797, 39.114553928375244, 30.499870888888836, 20.090002678334713, 17.11642663925886, 17.968861497938633, 11.937703527510166, 14.61750403046608, 21.34919051080942, 1.3898643641732633, 0.08064592999289744, 17.842438481748104, 56.60813122987747, 59.97418820858002, 47.1886532753706, 30.48024494200945, 32.13709093630314, 52.496527656912804, 62.434939965605736, 56.28515616059303, 11.196085922420025, 0.7240741245914251, 0.1757538245874457, 0.13634208706207573, 0.12073737831087783, 0.16684031928889453, 0.18089255900122225, 0.17613165196962655, 0.1796649576863274, 0.11346675790264271, 0.13814967678627, 0.10377808677731082, 0.10403622058220208, 0.17717910435749218, 0.2015193662373349, 0.17489713383838534, 0.10539425435126759], [0.004389910191093804, 0.01734957029839279, 0.06304252849076875, 0.030181344445736613, 0.04515136664849706, 0.032516558494535275, 0.03994110033090692, 0.02915905828558607, 0.006555751760970452, 0.04417254065629095, 0.12201358287711628, 0.02893120596127119, 0.03013231631484814, 0.0710805221751798, 0.07612073648488149, 0.10734352748841047, 15.972509421408176, 40.88369719684124, 40.95868997275829, 28.704742714762688, 21.391005367040634, 17.80109480023384, 31.69883955270052, 24.47339426726103, 34.06337857246399, 10.943115446716547, 0.2219341864110902, 0.20526462933048606, 6.538309631869197, 5.805411133915186, 9.483463671058416, 19.73319422453642, 6.625258466228843, 11.821832545101643, 43.5855308175087, 57.107827216386795, 55.27700565755367, 56.14929065108299, 54.66754496097565, 56.86168782413006, 54.25590164959431, 48.3712562173605, 40.13949193060398, 41.94139704108238, 46.52662619948387, 51.07667684555054, 52.57789649069309, 52.39897929131985, 51.73078894615173, 50.759192481637, 49.75364103913307, 50.02062991261482, 46.40221327543259, 42.494696751236916, 40.38091957569122, 38.474964648485184, 38.61957348883152, 37.81473107635975, 38.37003707885742, 47.90355831384659, 53.26838403940201, 52.49702163040638, 51.20841957628727, 52.55495712161064, 48.92424054443836, 45.6597825139761, 39.559289664030075, 37.521508410573006, 37.51373402774334, 37.27329432964325, 38.3989155292511, 38.337712213397026, 48.27288709580898, 48.7644287198782, 47.804854810237885, 50.2859278768301, 49.372228905558586, 52.80958525836468, 48.448817655444145, 46.72298066318035, 51.1379561573267, 49.916108921170235, 52.68396019935608, 50.650814697146416, 53.53423297405243, 47.43276357650757, 58.10166768729687, 24.608606211841106, 30.957586728036404, 51.737366393208504, 48.995365127921104, 52.71376959979534, 47.082239985466, 49.3210456520319, 48.92412655055523, 48.466893285512924, 48.6406047642231, 50.73121838271618, 48.311553820967674, 48.73479790985584, 50.89249312877655, 45.96544571220875, 39.176828786730766, 37.04511657357216, 36.03042662143707, 36.883849427103996, 36.71896107494831, 36.80857926607132, 36.82723626494408, 38.81974294781685, 44.919836819171906, 45.11575810611248, 47.60908931493759, 49.67932842671871, 48.00714835524559, 50.25650605559349, 51.18625156581402, 45.307632610201836, 42.20639482140541, 40.47847934067249, 44.41630683839321, 47.307298108935356, 50.25587148964405, 50.08945941925049, 47.616381123661995, 48.60242821276188, 48.09704013168812, 46.00406304001808, 46.100862845778465, 47.096211835742, 51.357227191329, 53.989547342062, 54.76135052740574, 52.225461602211, 48.97463344037533, 49.78318065404892, 49.8992720246315, 47.46373191475868, 52.40579232573509, 43.47114935517311, 33.90341855585575, 25.013003312051296, 20.22772628813982, 12.620063312351704, 8.824023306369781, 0.833509499207139, 13.365984186530113, 9.95400382205844, 0.08402947772992775, 0.047001069542602636, 4.989377846941352, 34.70074877142906, 61.493057906627655, 63.12605828046799, 33.67067724466324, 26.839930079877377, 36.229433342814445, 43.63673686981201, 40.22201970219612, 11.294398996978998, 0.5858073220588267, 0.07929763320134953, 0.07558519529993646, 0.007479672276531346, 0.004691927188105183, 0.014014957923791371, 0.04225774770020507, 0.03653623440186493, 0.061355879151960835, 0.035018342023249716, 0.028361615040921606, 0.03543183331203181, 0.07665063734748401, 0.038888400958967395, 0.03274590439104941, 0.05611073560430668, 0.01737937309371773, 0.04655221120628994, 0.07188728122855537, 0.018170845760323573, 0.036542045418173075, 0.046197353294701315, 0.0771591866214294, 0.11137393856188282, 0.08165565901435912, 0.039052608553902246, 0.06922933869645931, 0.022123162489151582, 0.009503849450993584, 0.030111586274870206, 0.05484555564180482, 0.30074703390710056, 22.898101396858692, 51.03726156055927, 49.40429538488388, 33.75174209475517, 24.631192199885845, 25.50095032900572, 37.9028445482254, 26.93156596273184, 39.97314065694809, 12.751688249409199, 0.20851943671004847, 0.15535798855125904, 8.72659083455801, 9.891215991228819, 6.910773245617747, 11.60492118448019, 4.242573045194149, 8.957191910594702, 45.919984951615334, 60.07498160004616, 56.180095598101616, 58.53667974472046, 56.56387880444527, 57.45805062353611, 55.84326647222042, 50.421341210603714, 42.6285407692194, 45.24004563689232, 49.11535128951073, 53.28620508313179, 55.52109315991402, 55.75648292899132, 52.74328261613846, 51.81615896522999, 51.21189258992672, 52.05479755997658, 48.4417462348938, 44.13421757519245, 41.82884708046913, 40.40092550218105, 39.76922079920769, 38.139134868979454, 40.650697499513626, 49.76085305213928, 54.45172034204006, 53.42077486217022, 50.6736096739769, 54.39153917133808, 51.3510487228632, 47.61336788535118, 41.755780801177025, 37.18653738498688, 40.222965851426125, 39.621982499957085, 41.325864270329475, 40.012118965387344, 49.96071472764015, 50.51323167979717, 52.17159189283848, 52.457150369882584, 52.08188630640507, 51.923499405384064, 49.4432432949543, 48.60297158360481, 52.74264045059681, 48.61740700900555, 54.496193155646324, 52.18358784914017, 54.03659641742706, 48.961220160126686, 57.06190288066864, 26.016899943351746, 32.87070997059345, 54.36735726892948, 51.80781841278076, 54.72549565136433, 49.2543326318264, 52.623706832528114, 50.73430001735687, 49.65557590126991, 51.61453418433666, 52.18265309929848, 50.7730807363987, 50.87751053273678, 52.75700367987156, 47.1610439568758, 40.94619244337082, 40.91662622988224, 37.46442407369614, 39.179279655218124, 38.91687713563442, 38.45766797661781, 40.278705060482025, 41.69567942619324, 46.820517629384995, 46.979801282286644, 50.773586109280586, 51.63843870162964, 51.9853562861681, 51.82384595274925, 52.8398734331131, 48.91973398625851, 45.29081471264362, 41.35751277208328, 46.80450528860092, 48.249168768525124, 53.46935145556927, 50.589664578437805, 50.33837266266346, 50.760731399059296, 49.14071872830391, 47.78636500239372, 47.403938323259354, 47.62021891772747, 51.91482447087765, 56.26511603593826, 55.47336392104626, 53.003374859690666, 50.2908144146204, 51.01664386689663, 52.442771941423416, 49.756832867860794, 53.27456250786781, 47.79709942638874, 37.933391109108925, 27.609696574509144, 21.181678399443626, 14.457219131290913, 9.232332296669483, 5.256326822564006, 15.687652006745338, 14.668684434145689, 0.647729808697477, 0.07585083221783862, 6.076734149828553, 41.56566180288792, 58.532097190618515, 51.71767204999924, 33.552533984184265, 33.458413034677505, 41.832434087991714, 49.74665321409702, 48.894529938697815, 15.449854116886854, 0.5570371658541262, 0.167308792588301, 0.06344146997435018, 0.014064798706385773, 0.07130258760298602, 0.01860003532783594, 0.05536806471354794, 0.14101156149990857, 0.06074104690924287, 0.055590141273569316, 0.03591750959458295, 0.05936550587648526, 0.03805732914770488, 0.04277177031326573, 0.049547010858077556, 0.008579023979109479, 0.08332221099408343, 0.11398430200642906, 0.1479442894924432, 0.07454788807081059, 0.09584298444679007, 0.14595028711482882, 0.11424590906244703, 0.26119750924408436, 0.18135785590857267, 0.15121843724045902, 0.2214745298260823, 0.15019731625216082, 0.1840817159973085, 0.1392840495100245, 0.17075569747248664, 0.5758805922232568, 31.925818473100662, 58.97564738988876, 57.05460727214813, 39.688106551766396, 31.789546385407448, 26.072109080851078, 41.79329998791218, 32.423755154013634, 47.394336238503456, 14.147549998015165, 0.4693142120959237, 0.2822703472338617, 12.029604446142912, 10.30179250985384, 18.361085951328278, 27.37439800053835, 13.941372111439705, 17.517635710537434, 46.84156849980354, 61.465231999754906, 57.95828238129616, 61.3089881837368, 58.91937240958214, 60.34954346716404, 58.89056995511055, 54.54357661306858, 43.59612464904785, 46.4539361000061, 51.753051951527596, 56.77645839750767, 57.54814758896828, 57.1283271163702, 51.07996366918087, 52.71546810865402, 51.37128263711929, 54.43491384387016, 50.069879069924355, 45.47268055379391, 44.539055451750755, 42.51716114580631, 43.10895279049873, 41.412970796227455, 42.77039095759392, 51.77627630531788, 57.054823860526085, 55.9487222135067, 52.620328813791275, 58.11201833188534, 52.324286699295044, 49.961102306842804, 42.94971093535423, 40.04571296274662, 40.63709802925587, 42.0950797945261, 43.013015538454056, 42.32927642762661, 51.6202262789011, 52.420508936047554, 53.23989316821098, 54.76315163075924, 53.52043591439724, 54.50784333050251, 51.66764013469219, 49.64883506298065, 53.21861431002617, 51.85113608837128, 55.76570503413677, 53.23044307529926, 55.62928095459938, 50.596139430999756, 57.75170646607876, 28.499770313501358, 35.95454089343548, 54.599900990724564, 52.89960242807865, 57.08045728504658, 52.799310609698296, 55.737639740109444, 52.29549944400787, 50.598290115594864, 53.83477784693241, 55.13255260884762, 51.495744958519936, 51.00552186369896, 56.720270812511444, 48.72538201510906, 43.185058906674385, 42.62335404753685, 38.84703308343887, 40.50149470567703, 39.8065309971571, 40.721715688705444, 41.119185760617256, 42.46716342866421, 49.299185425043106, 49.590208008885384, 53.02528068423271, 54.14009526371956, 54.06067952513695, 54.941673651337624, 56.41601733863354, 51.29420757293701, 46.28098838031292, 44.250381141901016, 49.35494743287563, 51.368592381477356, 57.13461957871914, 53.30822490155697, 53.1431769579649, 51.34391650557518, 51.80681146681309, 50.409584641456604, 48.80276866257191, 48.61073836684227, 53.57156977057457, 57.152915596961975, 59.68434356153011, 54.97898764908314, 52.373201474547386, 50.56216545403004, 53.54421503841877, 50.743932500481606, 53.44488076865673, 48.601979836821556, 41.07129693031311, 28.359707929193974, 22.227984555065632, 15.050272308290005, 13.087256792932749, 4.623996578156948, 17.648521587252617, 15.157235618680716, 0.9043029660824686, 0.18601842457428575, 7.428151108324528, 46.51336491107941, 73.00869718194008, 67.9659041762352, 45.57205282151699, 37.43111506104469, 49.58136968314648, 57.01836481690407, 57.091267704963684, 21.53609298169613, 1.0110593657009304, 0.30339575896505266, 0.15706960373790935, 0.2570814988575876, 0.23380295344395563, 0.13472049438860267, 0.1261280124890618, 0.16070295096142218, 0.16869364015292376, 0.16634848318062723, 0.15604719141265377, 0.15995140769518912, 0.13645156868733466, 0.2163712403853424, 0.11056087867473252, 0.15906736138276756], [0.01610403684026096, 0.027252312065684237, 0.00453963802101498, 0.03015534886799287, 0.028606078485609032, 0.019744026285479777, 0.05067995865829289, 0.06757205614121631, 0.01266654424398439, 0.03651360260846559, 0.021239580019027926, 0.06394136580638587, 0.03128858981654048, 0.03403525610337965, 0.07320973643800244, 0.8322974829934537, 19.65567458420992, 43.25531713664532, 43.660971969366074, 32.83164046704769, 23.080491609871387, 26.864847242832184, 33.26243095099926, 26.51484042406082, 37.36595615744591, 5.953698651865125, 0.17478296183981, 0.017615171964280307, 5.590598685666919, 3.7776463804766536, 5.945909069851041, 5.885246274992824, 6.724396096542478, 16.875168085098267, 56.005563363432884, 55.854897648096085, 51.93755105137825, 49.993560165166855, 51.48244567215443, 48.55821378529072, 44.96332548558712, 42.54614979028702, 44.178751185536385, 46.75715982913971, 48.879395350813866, 50.064160376787186, 51.239517107605934, 52.734394893050194, 51.53991378843784, 50.05776531994343, 51.632115840911865, 50.911628901958466, 49.41664092242718, 46.976731047034264, 43.46665419638157, 39.29282896220684, 37.6636777818203, 37.221316918730736, 37.418701127171516, 37.16547131538391, 43.41980271041393, 47.161382138729095, 48.10451813042164, 47.39082522690296, 42.88435824215412, 36.52547545731068, 36.40077754855156, 35.35266079008579, 38.6883269995451, 37.109872698783875, 39.90629844367504, 37.52500802278519, 48.34837764501572, 52.08539351820946, 53.03013302385807, 51.37429587543011, 49.697312861680984, 51.530121713876724, 50.68150945007801, 46.75169572234154, 49.25422623753548, 50.048543214797974, 53.968040496110916, 47.17551738023758, 53.415633738040924, 48.30906495451927, 55.38839288055897, 28.166387602686882, 31.3083953037858, 53.45384068787098, 48.34552779793739, 50.11501304805279, 44.60901349782944, 44.203157275915146, 44.1702776402235, 47.07453019917011, 45.253436118364334, 46.41009405255318, 45.49140214920044, 46.407286003232, 43.20261016488075, 39.52734477818012, 38.13149727880955, 37.6334086060524, 37.63775937259197, 37.944513112306595, 38.70499670505524, 38.47831226885319, 38.210403844714165, 38.0496496707201, 39.382606744766235, 39.866829961538315, 41.51626445353031, 42.23541006445885, 44.16677042841911, 44.29054118692875, 41.138659715652466, 38.65126758813858, 39.36460331082344, 41.54586486518383, 45.80677002668381, 49.30100932717323, 49.34195213019848, 47.873061150312424, 50.73907636106014, 50.04649892449379, 49.079564809799194, 46.74318037927151, 45.45177787542343, 49.65391159057617, 53.385543152689934, 49.810599982738495, 53.40071193873882, 53.08921605348587, 58.034722879529, 50.558836832642555, 51.31142444908619, 55.80928109586239, 55.835552886128426, 57.17344209551811, 55.80282524228096, 53.847602158784866, 41.585116758942604, 25.707661136984825, 9.364753291010857, 3.4010545257478952, 6.1010433454066515, 2.5960596464574337, 0.26083718170411885, 0.12615940533578396, 1.9065079162828624, 28.20701502263546, 61.99704386293888, 59.48035150766373, 26.067330837249756, 22.599281631410122, 35.63518323004246, 45.34124940633774, 49.13922540843487, 17.73118045181036, 0.6104920443613082, 0.07765434755128808, 0.10803278972161934, 0.024084413889795542, 0.05803644184197765, 0.07151366924517788, 0.04577583938953467, 0.052558167444658466, 0.011733583905879641, 0.0424891530565219, 0.03374680185515899, 0.027935985926887952, 0.041864557861117646, 0.01607644935575081, 0.03795791846641805, 0.02706321840378223, 0.04854658465774264, 0.03254827046475839, 0.02995669077790808, 0.07087205289280973, 0.04417487099999562, 0.030809520503680687, 0.010207900832028827, 0.06276008934946731, 0.07160477529396303, 0.029644853311765473, 0.05249704416200984, 0.04136537078011315, 0.006460429849539651, 0.018850604792532977, 0.011172434915351914, 1.1079099937342107, 24.829355366528034, 50.780874118208885, 50.109092965722084, 38.12506802380085, 24.043798819184303, 24.459325522184372, 33.762807101011276, 27.664392739534378, 42.199179008603096, 7.37465662881732, 0.17914425203343853, 0.3229393274523318, 8.597191628068686, 6.024703541770577, 6.54286558739841, 10.093061160296202, 4.048780119046569, 17.179223969578743, 57.582687735557556, 56.41670510172844, 54.76651445031166, 52.76773050427437, 53.27638640999794, 49.12072420120239, 49.208389297127724, 44.45344224572182, 46.360578909516335, 47.89641469717026, 51.91806189715862, 50.88960908353329, 52.91265092790127, 53.8825336843729, 52.26648040115833, 49.65162791311741, 51.35332480072975, 51.700075194239616, 51.75092786550522, 48.23899291455746, 43.835709393024445, 41.340364292263985, 39.54213358461857, 38.468318805098534, 38.76814551651478, 40.1870159804821, 46.60012185573578, 49.745034500956535, 50.97179867327213, 49.97458778321743, 45.84643229842186, 38.66895563900471, 37.58017346262932, 36.16018205881119, 41.403486505150795, 38.8070098310709, 41.63889907300472, 40.40217563509941, 49.5012129843235, 51.672169491648674, 52.7764168381691, 53.940693363547325, 52.28159599006176, 52.13021971285343, 50.81325218081474, 48.21684010326862, 52.08378620445728, 51.07528991997242, 55.37443242967129, 50.18257722258568, 55.00002332031727, 50.61931438744068, 56.511851996183395, 30.21498877555132, 32.63909339904785, 54.83864977955818, 50.23956276476383, 50.61902940273285, 46.44654169678688, 48.52129116654396, 46.875580474734306, 49.29693214595318, 47.785373255610466, 49.44113440811634, 49.27389778196812, 49.38016667962074, 47.025626823306084, 41.61063238978386, 40.56036874651909, 38.87465380132198, 39.985125213861465, 38.57207603752613, 40.509367883205414, 39.866161197423935, 40.30941501259804, 40.35588651895523, 41.93890057504177, 42.70332835614681, 43.32985393702984, 44.376211389899254, 48.070300966501236, 46.67644836008549, 45.81459380686283, 41.04065157473087, 41.26627206802368, 42.05352522432804, 48.81162218749523, 51.82102270424366, 51.44594103097916, 52.29619100689888, 52.641577273607254, 51.431163623929024, 50.714905858039856, 48.025212585926056, 47.18858867883682, 50.10118179023266, 55.41994258761406, 51.62721410393715, 55.67240484058857, 54.1965564340353, 58.6871250718832, 52.144518345594406, 53.12744960188866, 54.72047992050648, 57.05374471843243, 55.437782630324364, 58.57974663376808, 56.745045483112335, 44.10193830728531, 19.518167562782764, 11.651369892060757, 8.608024846762419, 6.755906855687499, 4.107793802395463, 0.3940434573451057, 0.15733131469460204, 2.1362636564299464, 32.700357511639595, 64.56963121891022, 57.48792842030525, 32.77054354548454, 27.61434942483902, 40.928960368037224, 52.2029098123312, 55.769934207201004, 23.327917233109474, 0.9857734444085509, 0.056402292029815726, 0.057240722235292196, 0.03358607122208923, 0.0265576655510813, 0.08545733275241219, 0.037963811118970625, 0.059075129465782084, 0.017401429722667672, 0.06260977475903928, 0.010323571041226387, 0.03043260225240374, 0.07362296426435933, 0.0957104962435551, 0.023752009656163864, 0.05202673404710367, 0.1330638723447919, 0.08687830064445734, 0.24673551495652646, 0.14609571837354451, 0.13208254531491548, 0.10619601132930256, 0.13038411067100242, 0.13182343187509105, 0.15893047966528684, 0.10918557512923144, 0.12437357538146898, 0.27826031553559005, 0.12178195858723484, 0.07198185310699046, 0.11603289676713757, 1.9283466506749392, 33.00440959632397, 58.55084918439388, 57.35756881535053, 47.044014036655426, 34.43860083818436, 37.52355270087719, 44.43958818912506, 39.93969865143299, 50.47736540436745, 8.059281092137098, 0.23016828519757837, 0.3616360353771597, 11.405562981963158, 10.404927525669336, 11.624778918921947, 14.784865099936724, 13.644161559641361, 21.018370762467384, 58.83532091975212, 59.82645593583584, 56.01282477378845, 55.967679396271706, 55.00472366809845, 51.41908407211304, 49.50891897082329, 47.27251097559929, 47.78578743338585, 50.69103553891182, 53.431885465979576, 54.02186460793018, 55.92047072947025, 55.2194045484066, 53.314996138215065, 50.803357511758804, 53.94602447748184, 55.96751980483532, 53.64395968616009, 51.218234449625015, 46.117927730083466, 43.12370739877224, 41.36592552065849, 41.222266629338264, 41.07650265097618, 42.08080016076565, 47.20140539109707, 51.6351442784071, 52.38260596990585, 52.33514651656151, 48.308776170015335, 40.76908014714718, 39.92758870124817, 37.76590369641781, 43.16050082445145, 41.35193087160587, 42.87474475800991, 41.958036348223686, 52.11654044687748, 55.57871326804161, 57.562146037817, 55.275516137480736, 55.12021467089653, 54.59216460585594, 51.993594244122505, 48.942927941679955, 53.44850577414036, 52.321577444672585, 58.009902611374855, 51.06404632329941, 55.93400940299034, 54.55900378525257, 56.95295512676239, 32.597250044345856, 34.750282913446426, 56.13198257982731, 53.99286076426506, 53.60604532063007, 48.98804672062397, 51.59667134284973, 49.047897309064865, 52.00165741145611, 49.360153153538704, 51.30446322262287, 51.07885792851448, 51.47596322000027, 47.60948069393635, 42.87051938474178, 42.03697331249714, 41.84685431420803, 42.67509587109089, 40.631641522049904, 42.10461728274822, 41.60176746547222, 42.54547722637653, 42.945382967591286, 43.22426900267601, 45.34362807869911, 45.34346468746662, 46.630147844552994, 49.61573503911495, 49.1431125998497, 47.99474962055683, 42.58166268467903, 44.65326592326164, 45.71634627878666, 50.58549240231514, 53.95244613289833, 53.34642805159092, 54.81850706040859, 55.38334675133228, 54.58779104053974, 53.411750346422195, 49.225078001618385, 46.551518663764, 50.87271139025688, 57.45359726250172, 54.164676144719124, 59.206097424030304, 57.8729123622179, 62.474461644887924, 55.43445400893688, 55.025155171751976, 57.722900211811066, 58.0547022074461, 59.95431907474995, 61.101747304201126, 57.15470530092716, 46.61582641303539, 31.491205394268036, 19.607614763081074, 9.264984894543886, 8.689711913466454, 4.07538534142077, 0.3581345232669264, 0.313949603587389, 2.6497659645974636, 37.74549499154091, 71.20045781135559, 67.87617579102516, 36.74061991274357, 31.515778675675392, 49.136614948511124, 59.62800398468971, 63.77188682556152, 29.98355459421873, 1.5174896595999599, 0.24736463354201987, 0.13590435351943597, 0.13164884905563667, 0.13714486820390448, 0.22690034180413932, 0.11519873020006344, 0.17392576643032953, 0.11290938273305073, 0.11008735877112485, 0.12846619327319786, 0.07485074369469658, 0.1580781230586581, 0.16834299021866173, 0.12692168005742133, 0.12229657120769843], [0.03206426030374132, 0.07543296596850269, 0.010781074470287422, 0.07186110568000004, 0.03412641410250217, 0.03964392213674728, 0.04269821976777166, 0.1308350544422865, 0.05527355591766536, 0.03949541838665027, 0.09379864219226874, 0.044664354500127956, 0.041886384424287826, 0.0751782237784937, 0.0679415046761278, 2.1820592740550637, 26.129396706819534, 39.3323278427124, 40.66952548921108, 27.41117052733898, 13.741732724010944, 19.04110126197338, 27.58349698036909, 30.404100827872753, 33.15239645540714, 3.391094785183668, 0.16101975896162912, 0.6263717485126108, 5.947260847315192, 8.03726602345705, 5.669035026803613, 6.448124796152115, 5.5950472969561815, 40.218216106295586, 60.40771834552288, 53.56205888092518, 52.13943041861057, 45.616920813918114, 43.62319439649582, 46.4289790391922, 48.1207774579525, 46.84766337275505, 49.03984174132347, 49.03387226164341, 52.083497419953346, 52.40079939365387, 52.77808874845505, 49.62751820683479, 51.00102290511131, 48.030889481306076, 49.46881592273712, 54.11772966384888, 51.305751353502274, 48.45684662461281, 44.55947935581207, 40.63089296221733, 38.330097422003746, 36.92095063626766, 38.245947137475014, 35.790211111307144, 36.503436639904976, 38.46788562834263, 39.41458962857723, 39.11178767681122, 38.88193041086197, 35.9160565584898, 36.75953149795532, 36.5631428360939, 38.514163345098495, 36.63994811475277, 39.31497797369957, 35.376759096980095, 42.403224259614944, 49.438539147377014, 48.844562619924545, 49.063666462898254, 50.60201771557331, 49.75223131477833, 50.74659235775471, 45.96252366900444, 50.19541673362255, 52.133799120783806, 52.14755438268185, 47.30779968202114, 50.7314957678318, 47.82407037913799, 55.39755418896675, 28.142574280500412, 30.947950445115566, 54.13415238261223, 48.89639563858509, 50.15385836362839, 45.289796367287636, 43.592267856001854, 42.593601644039154, 43.39580699801445, 43.09499613940716, 43.21750536561012, 41.2461331486702, 40.13996310532093, 37.67055921256542, 38.65996152162552, 39.178603291511536, 39.26797069609165, 37.44437254965305, 37.437240332365036, 37.58349068462849, 39.14448492228985, 36.83722212910652, 37.75101229548454, 39.03196156024933, 38.00397612154484, 36.88603810966015, 38.167348355054855, 38.319575786590576, 36.549330577254295, 38.48609805107117, 37.878913432359695, 37.944520711898804, 42.15603992342949, 44.65649954974651, 45.04304900765419, 47.144214659929276, 45.8023888617754, 47.400491908192635, 48.498716577887535, 51.5386750549078, 48.77391301095486, 48.24069902300835, 50.90843327343464, 51.463990062475204, 50.72868011891842, 50.41536033153534, 49.93641123175621, 51.616365686059, 50.50085574388504, 54.603100419044495, 54.513489827513695, 56.29690133035183, 54.487077444791794, 57.07560494542122, 58.363929614424706, 46.00136138498783, 20.211229473352432, 7.72097859531641, 6.89725499600172, 2.4138496862724423, 3.155064038001001, 1.4076219988055527, 0.06688017412670888, 0.9202603285666555, 17.702963165938854, 46.76431104540825, 34.85764615237713, 21.82830300182104, 23.961060158908367, 33.01898941397667, 46.45360551774502, 46.90895028412342, 21.761282198131084, 1.0958779393695295, 0.11535865560290404, 0.062440876790788025, 0.04309381416533142, 0.05284114464302547, 0.06154713060823269, 0.05360629889764823, 0.060374255263013765, 0.12044515024172142, 0.03249469111324288, 0.03408290940569714, 0.019294334888400044, 0.0037127468203834724, 0.055138329189503565, 0.0823613598186057, 0.014927931297279429, 0.048108617338584736, 0.08610199191025458, 0.05071388222859241, 0.021213842337601818, 0.07083956166752614, 0.08056777442106977, 0.04080924241861794, 0.05745953334553633, 0.012524018493422773, 0.03979953195084818, 0.04230908947647549, 0.07086144018103369, 0.0651228278002236, 0.041057672642637044, 0.05168792878976092, 2.856703335419297, 31.088083125650883, 47.681817412376404, 48.34332771599293, 35.49915052950382, 26.065347343683243, 29.64859876781702, 32.0335578918457, 34.15356293320656, 38.512122854590416, 3.5466931108385324, 0.16304758843034506, 1.506759391631931, 8.966908939182758, 8.532076422125101, 7.438938254490495, 10.171129871159792, 4.493862586095929, 44.01176534593105, 60.135622546076775, 56.00477680563927, 53.424168080091476, 48.23204688727856, 46.053236201405525, 48.03282357752323, 48.847435265779495, 49.16505642235279, 49.96966324746609, 51.27949096262455, 53.72668884694576, 54.48204651474953, 54.85459752380848, 52.879847288131714, 51.07709862291813, 48.966631069779396, 49.62986268103123, 54.07732643187046, 52.84598730504513, 49.99697998166084, 46.19469881057739, 41.910983473062515, 39.30520869791508, 38.55778120458126, 40.338920429348946, 37.29181833565235, 39.13291074335575, 41.08076222240925, 42.028172984719276, 40.81603802740574, 40.604708567261696, 39.14369836449623, 37.5785281509161, 38.364698365330696, 40.5120163410902, 38.09291414916515, 41.6570620983839, 37.56447270512581, 44.09936584532261, 51.10800616443157, 49.93539668619633, 50.592195242643356, 50.46346955001354, 51.86078377068043, 52.037645280361176, 48.128947019577026, 51.022712141275406, 54.016548693180084, 53.960931077599525, 49.527378380298615, 54.14911977946758, 50.16660287976265, 57.169824689626694, 29.160562455654144, 33.02910827100277, 54.2013555765152, 50.46362154185772, 52.42395155131817, 47.22830034792423, 45.12184917926788, 43.997155129909515, 44.66184586286545, 43.33176903426647, 45.26045434176922, 43.680594116449356, 42.123141288757324, 40.054292902350426, 40.78196905553341, 40.8875235915184, 40.596124827861786, 38.79807651042938, 39.67519864439964, 41.07104994356632, 41.94325894117355, 39.307119995355606, 39.78318504989147, 41.12328574061394, 38.48351038992405, 39.3977527320385, 40.24608001112938, 40.76752983033657, 38.85617919266224, 39.777622148394585, 38.99170272052288, 40.032349079847336, 44.54906031489372, 47.23447881639004, 47.21664257347584, 48.15582677721977, 47.06473432481289, 48.80206950008869, 51.70909970998764, 53.35656210780144, 50.634752959012985, 49.26490746438503, 52.823397517204285, 53.623129203915596, 52.68433257937431, 50.96690073609352, 51.277720257639885, 53.67276594042778, 54.456166103482246, 56.995911821722984, 56.23535603284836, 56.709133610129356, 57.86174476146698, 56.930182948708534, 56.451739221811295, 47.608021572232246, 24.76530410349369, 9.761577397584915, 13.553412929177284, 6.575854467228055, 3.2422102242708206, 1.0094090667553246, 0.04854772014368791, 0.916113801067695, 21.395445428788662, 54.33888919651508, 43.87122228741646, 29.125233851373196, 27.606548443436623, 39.657149612903595, 51.68939396739006, 53.08069311082363, 28.269609063863754, 1.3962142984382808, 0.11506821610964835, 0.03714831327670254, 0.01446217796910787, 0.07165389804868028, 0.027791589964181185, 0.017886682981043123, 0.0653115707973484, 0.05353556109184865, 0.005725697155867238, 0.0480852100008633, 0.045246654699440114, 0.08512065003742464, 0.02366243799770018, 0.053782974573550746, 0.0704173835401889, 0.2117998481844552, 0.17922723898664117, 0.13142633833922446, 0.09964187513105571, 0.17464471457060426, 0.16503869643202052, 0.10762800011434592, 0.23760966636473313, 0.15364091115770862, 0.14257002709200606, 0.13635155686642975, 0.12105926260119304, 0.21608597366139293, 0.1453762804158032, 0.1986016274895519, 3.9174214052036405, 38.390593975782394, 57.04392224550247, 55.79106107354164, 40.08684575557709, 26.17339264601469, 29.454068206250668, 38.98718096315861, 44.46113683283329, 42.94242672622204, 4.143769796937704, 0.2703434106661007, 1.4792698854580522, 7.570449197664857, 15.118419751524925, 15.72583805769682, 16.45079355686903, 10.927834566682577, 45.342697128653526, 62.70541325211525, 56.91913694143295, 56.93498209118843, 50.86609974503517, 47.72999122738838, 48.830662965774536, 53.25000822544098, 51.723063960671425, 52.583987563848495, 52.811906933784485, 57.354544177651405, 56.20121866464615, 55.815246775746346, 53.27919825911522, 53.412787690758705, 50.20066425204277, 49.36641521751881, 55.863937363028526, 55.31143181025982, 53.52249160408974, 49.030729830265045, 45.73465749621391, 42.25628234446049, 41.07489913702011, 43.4865765273571, 40.12982904911041, 41.5594757348299, 41.57419614493847, 43.914498165249825, 43.086435198783875, 42.096010744571686, 42.20335118472576, 38.147676810622215, 39.67546463012695, 41.95906229317188, 40.520577281713486, 41.90868079662323, 38.83675083518028, 46.4439882338047, 54.44721378386021, 51.106155663728714, 52.95101746916771, 54.687858670949936, 54.26842957735062, 53.13311129808426, 49.529069289565086, 53.58484625816345, 57.29217812418938, 57.84459248185158, 52.047292962670326, 53.77510204911232, 52.81010203063488, 58.649697080254555, 32.108702659606934, 36.06960631906986, 53.976973816752434, 53.09585429728031, 51.89398638904095, 50.57470478117466, 47.33252115547657, 45.63091926276684, 47.135862708091736, 47.74438105523586, 47.659265622496605, 45.92617101967335, 42.33137771487236, 41.48118853569031, 42.39470511674881, 43.305865824222565, 43.781968876719475, 42.29467548429966, 42.19543240964413, 42.85205617547035, 43.494476303458214, 41.100182980298996, 41.9079664349556, 44.54051457345486, 41.773917227983475, 41.36178754270077, 42.53573454916477, 43.824511393904686, 40.919023901224136, 42.31095761060715, 41.71188935637474, 42.37304247915745, 47.408072501420975, 50.81658460199833, 48.77446398139, 51.33602432906628, 49.99393254518509, 51.037607342004776, 53.25503535568714, 55.802597254514694, 52.08505913615227, 51.372836753726006, 53.85202132165432, 56.070349887013435, 54.31511387228966, 54.792398661375046, 53.10938157141209, 55.639669597148895, 56.54851622879505, 58.41744214296341, 59.097605645656586, 59.99825231730938, 60.297729447484016, 60.255597308278084, 60.8847713470459, 48.471061661839485, 30.20975075662136, 11.159081608057022, 15.541590694338083, 8.953984882682562, 8.315785378217697, 2.96536301728338, 0.21917949750786647, 1.4177691168151796, 25.61184737831354, 57.3584009706974, 47.017362266778946, 34.48592729866505, 34.52335149049759, 46.687558963894844, 57.64553636312485, 62.027180045843124, 35.215298160910606, 2.4868570687249303, 0.41533208219334483, 0.13182203663745895, 0.2294992539100349, 0.23726462706690654, 0.17891184106701985, 0.12874580483185127, 0.15570834162645042, 0.2667396602919325, 0.11615967785473913, 0.08388424685108475, 0.11547928428626619, 0.11977690563071519, 0.22414528182707727, 0.2155849349219352, 0.12686554400715977], [0.04434824782947544, 0.037633136089425534, 0.022191890930116642, 0.08499564268277027, 0.0441043187311152, 0.015107265717233531, 0.010487119980098214, 0.07862704340368509, 0.08561356225982308, 0.022154354956001043, 0.053801713802386075, 0.04361094266641885, 0.046106247245916165, 0.07240432809339836, 0.034550302880234085, 2.9904989060014486, 26.963421553373337, 36.38216994702816, 37.01230153441429, 16.54850911349058, 8.645892664790154, 12.606145609170198, 24.626011177897453, 31.087330766022205, 32.59148195385933, 1.347201915923506, 0.07526576009695418, 1.4865183527581394, 3.8163458788767457, 2.336894553154707, 3.872786625288427, 14.105062577873468, 16.48682702332735, 45.81651270389557, 57.31590785086155, 53.11954602599144, 49.73049648106098, 45.1559067517519, 52.41256356239319, 52.655435130000114, 55.067652091383934, 52.39155828952789, 51.61772981286049, 52.71788477897644, 53.651426285505295, 50.92875458300114, 49.61338296532631, 49.173385575413704, 47.90864624083042, 47.31688119471073, 48.45690742135048, 47.516317293047905, 48.41937303543091, 50.90893864631653, 45.41118085384369, 39.580427929759026, 38.93634349107742, 35.34755386412144, 37.285449877381325, 37.000814750790596, 37.35386900603771, 34.78150583803654, 36.62044756114483, 38.70265603065491, 39.05107453465462, 37.06128850579262, 37.010580226778984, 36.08075492084026, 37.35829956829548, 36.42308235168457, 37.725074887275696, 37.63483352959156, 38.326305225491524, 40.98308086395264, 44.85898308455944, 45.600387901067734, 48.46162676811218, 50.05884826183319, 50.583763495087624, 44.42938193678856, 50.902213007211685, 49.26420450210571, 51.77471078932285, 51.17503076791763, 54.18749772012234, 48.330378010869026, 49.24023538827896, 30.0759257376194, 29.740690626204014, 54.34645839035511, 48.253261148929596, 48.901217579841614, 44.913061782717705, 46.57350428402424, 44.973953515291214, 46.89537741243839, 46.91863976418972, 44.94527265429497, 43.17497804760933, 38.95969703793526, 37.700858786702156, 36.46671921014786, 37.27014809846878, 37.67631970345974, 37.264209017157555, 36.362392008304596, 38.43285530805588, 43.64157021045685, 39.77987922728062, 38.702078461647034, 38.79176504909992, 37.56351515650749, 38.64400997757912, 37.440644949674606, 37.87131763994694, 38.612657859921455, 36.39931082725525, 36.356422528624535, 38.964925557374954, 39.48005251586437, 40.43589882552624, 42.43343643844128, 42.97623351216316, 43.65477830171585, 48.42945769429207, 49.81955610215664, 51.865104138851166, 46.97610028088093, 47.61182136833668, 51.28600761294365, 52.17384897172451, 50.12766256928444, 47.72065132856369, 48.72109204530716, 48.740862384438515, 52.705524042248726, 53.52662578225136, 49.42338936030865, 54.38330501317978, 55.02042442560196, 57.32468917965889, 59.56055760383606, 54.32615987956524, 26.051706075668335, 16.10065944492817, 12.989385444670916, 6.638863161206245, 4.233753243461251, 1.8603671109303832, 0.34016184392385185, 0.3948558121919632, 18.754640333354473, 31.558254696428776, 35.84447979927063, 27.42032613605261, 16.836003586649895, 32.27824576199055, 44.873787090182304, 50.516928881406784, 27.372868582606316, 0.5040259135421365, 0.05360871087759733, 0.0709387645474635, 0.028400171468092594, 0.03487298497930169, 0.048020116228144616, 0.02975617731863167, 0.03560226381523535, 0.04865908682404552, 0.027922859189857263, 0.023708256339887157, 0.010887014195759548, 0.04054278913827147, 0.030400120303966105, 0.032280043451464735, 0.024573433547629975, 0.05776112731837202, 0.020625118850148283, 0.03218960904632695, 0.018626312921696808, 0.04796024346433114, 0.043298865857650526, 0.09671641062595882, 0.03430717159062624, 0.0462941182195209, 0.007900289110693848, 0.025679728969407734, 0.043922722616116516, 0.050349762313999236, 0.052514317649183795, 0.03998685373517219, 4.0502306912094355, 33.88711363077164, 43.927919045090675, 44.65670853853226, 21.035798527300358, 13.09349985793233, 16.310995258390903, 29.584228321909904, 36.33945643901825, 37.34037972986698, 1.3875673874281347, 0.15556638361886144, 1.6554252267815173, 8.046561274677515, 5.029232483357191, 6.210103193297982, 8.826413378119469, 17.111971378326416, 51.030258536338806, 57.95685365796089, 56.885991320014, 50.132503509521484, 47.783237770199776, 53.02588865160942, 55.8633141964674, 56.4555998146534, 54.84293594956398, 53.719598427414894, 55.49666807055473, 54.62622217833996, 51.43519900739193, 50.99710911512375, 51.08966834843159, 48.876891285181046, 48.237036019563675, 48.60006853938103, 49.79303352534771, 49.979531317949295, 53.55712674558163, 47.67166815698147, 42.380946055054665, 41.31845086812973, 37.76233568787575, 38.94149601459503, 39.261978417634964, 38.84496979415417, 37.259725257754326, 38.557743206620216, 39.37879174947739, 40.77738270163536, 39.39950443804264, 39.257323667407036, 37.924841567873955, 39.523795768618584, 38.54585364460945, 39.2293381690979, 38.56067284941673, 38.823386952281, 43.25291186571121, 46.62438355386257, 47.68918141722679, 49.907962158322334, 52.51837648451328, 51.03639140725136, 46.24144770205021, 54.10142093896866, 50.37276081740856, 52.45418652892113, 51.75832986831665, 55.126461535692215, 50.0771214812994, 51.17924854159355, 30.94515949487686, 32.182578295469284, 55.374782010912895, 50.05847208201885, 52.353332340717316, 45.479941964149475, 47.25481532514095, 46.98779605329037, 48.04223567247391, 49.120974987745285, 46.39732673764229, 42.94019244611263, 43.109503760933876, 40.568314120173454, 37.45546795427799, 38.49782422184944, 39.554144740104675, 38.70978444814682, 37.971465066075325, 39.003634080290794, 45.33080756664276, 41.91623859107494, 40.97622603178024, 41.24585956335068, 40.18459551036358, 40.441769510507584, 39.13544900715351, 39.823979660868645, 41.469207778573036, 38.11771161854267, 38.08107018470764, 40.845497846603394, 41.944041699171066, 42.86854349076748, 44.99161496758461, 45.38811609148979, 45.54219402372837, 51.316394582390785, 52.325780019164085, 52.977433651685715, 48.87309528887272, 48.69238838553429, 52.75644890964031, 54.37158264219761, 52.26732775568962, 49.584979489445686, 49.75089378654957, 51.78509183228016, 55.515089482069016, 55.27140095829964, 54.458085000514984, 57.017821446061134, 57.049352154135704, 59.10200580954552, 60.98260089755058, 54.64951112866402, 25.56261721998453, 8.300980422645807, 15.437296740710735, 7.832541558891535, 3.2063467986881733, 1.5837686718441546, 0.3480034653330222, 0.3204909525811672, 20.3513203561306, 39.634339436888695, 42.27494694292545, 32.02576830983162, 19.611277766525745, 37.5968811661005, 50.367498099803925, 59.44564796984196, 33.66267867386341, 1.395164248533547, 0.03449864198046271, 0.04512221508775838, 0.030515258949890267, 0.04360975151939783, 0.025930649098881986, 0.03152479315758683, 0.058542311962810345, 0.030977398018876556, 0.050745594198815525, 0.05036058653786313, 0.0411405222985195, 0.011294696323602693, 0.03051171705010347, 0.06609292613575235, 0.03090955829975428, 0.146305953967385, 0.10549022888881154, 0.09917219955241308, 0.14386164606548846, 0.18660617584828287, 0.1261987688485533, 0.20400805457029492, 0.11152992316056043, 0.147223100066185, 0.09650495048845187, 0.1413105134270154, 0.11053283291403204, 0.17937262571649626, 0.24403767456533387, 0.0939414017193485, 5.272789914160967, 40.815289467573166, 53.230393677949905, 52.2646526992321, 26.247655861079693, 17.39305939525366, 19.86792739480734, 36.72001361846924, 44.9488140642643, 44.213659912347794, 1.7337522050365806, 0.3741853666724637, 2.4226573761552572, 7.338643586263061, 6.890012584626675, 10.995877515524626, 21.843013912439346, 19.945099353790283, 51.66103608906269, 61.053220108151436, 59.004822224378586, 53.90653319656849, 48.75565879046917, 57.405404448509216, 58.29287722706795, 58.92357498407364, 56.3935187458992, 55.6551081687212, 57.55017288029194, 55.523012056946754, 51.93503558635712, 53.123923391103745, 50.21577604115009, 49.33717958629131, 48.540290147066116, 49.55775775015354, 52.3900231719017, 52.45713897049427, 54.86486077308655, 50.89448042213917, 44.15048450231552, 43.782561644911766, 38.88524383306503, 40.92283509671688, 40.198088586330414, 41.55905395746231, 38.26114632189274, 40.43902225792408, 41.591454818844795, 41.67510733008385, 41.45711302757263, 40.12037515640259, 38.903406858444214, 42.18086019158363, 40.73124177753925, 40.59332437813282, 41.65165118873119, 41.02555498480797, 45.044880509376526, 48.8914331048727, 48.367961794137955, 52.38857164978981, 55.04624783992767, 52.91608974337578, 46.166789308190346, 55.8164095133543, 52.630953043699265, 54.852819219231606, 54.070023223757744, 56.59527271986008, 52.84778080880642, 52.83420793712139, 34.377587512135506, 34.93621073663235, 55.892739817500114, 52.37572833895683, 54.0355970710516, 48.82535845041275, 51.050401255488396, 49.691696763038635, 50.20898200571537, 53.08532506227493, 49.54219378530979, 47.13246189057827, 45.610559955239296, 42.475564777851105, 38.86066295206547, 39.68785956501961, 41.13693080842495, 41.7688824981451, 39.6984875947237, 40.67025125026703, 45.84048941731453, 43.81338179111481, 43.105130195617676, 42.15920515358448, 41.00954644382, 43.27626161277294, 41.57234184443951, 42.304292768239975, 42.48961262404919, 40.62403813004494, 40.18145687878132, 43.31577189266682, 43.42056646943092, 43.924788013100624, 47.74471923708916, 47.80052684247494, 48.65197755396366, 52.18718245625496, 54.89862576127052, 54.37487706542015, 49.55644302070141, 50.577744618058205, 53.97877871990204, 57.99035266041756, 53.890262469649315, 52.04980082809925, 52.905093133449554, 53.565220311284065, 57.1141766756773, 58.60979542136192, 56.27054214477539, 59.130815863609314, 60.070364847779274, 61.93308189511299, 65.82378432154655, 57.41518512368202, 28.852038010954857, 20.747469998896122, 29.703982695937157, 14.113037399947643, 9.970094058662653, 3.1612648302689195, 0.7373445562552661, 0.5272531765513122, 23.8676193729043, 43.49444970488548, 49.56677466630936, 39.96818572282791, 25.023967623710632, 44.93795804679394, 58.34564879536629, 65.00121966004372, 42.255567982792854, 2.74534294847399, 0.11958592134760693, 0.13710007217014208, 0.18609139253385365, 0.12983653927221894, 0.13940598437329754, 0.15094602451426908, 0.13589574460638687, 0.1408579369308427, 0.06865109433420002, 0.23140375327784568, 0.09761033492395654, 0.11452658931375481, 0.24486223031999543, 0.17071918380679563, 0.12070263095665723], [0.01227278851729352, 0.016785538064141292, 0.05487588350661099, 0.018008282022492494, 0.009273126870539272, 0.027426651831774507, 0.05232527408224996, 0.09224685592926107, 0.022372409075614996, 0.02619744191179052, 0.058649448401411064, 0.0032773846714917454, 0.029555738074122928, 0.08457914198515937, 0.04322902605053969, 5.146778700873256, 30.164039209485054, 40.95834419131279, 38.226997554302216, 25.13512685894966, 16.47127825766802, 22.446541227400303, 26.13796904683113, 34.68989655375481, 26.687170676887035, 0.4159052576869726, 0.45152193401008844, 2.7876494033262134, 9.963648654520512, 7.616482302546501, 6.9502227287739515, 10.901237893849611, 23.08578472584486, 55.56055784225464, 55.654135420918465, 54.88510988652706, 49.08709220588207, 48.98789472877979, 53.18546108901501, 53.87599043548107, 51.97103105485439, 52.39466272294521, 51.97180241346359, 51.645502522587776, 49.36270661652088, 49.5476008951664, 49.52214606106281, 48.76088730990887, 49.16246496140957, 51.286630779504776, 49.09242331981659, 49.331487491726875, 50.322443917393684, 48.07607665657997, 43.683379366993904, 37.44833193719387, 36.47292047739029, 36.53388060629368, 36.13600395619869, 36.42684035003185, 37.50326558947563, 37.19584308564663, 38.049379885196686, 37.58320949971676, 39.46087494492531, 37.8002804517746, 38.76265861093998, 36.41815781593323, 37.704681381583214, 36.77813909947872, 37.344696298241615, 37.29701265692711, 37.05540642142296, 37.90300413966179, 42.330952137708664, 46.13278493285179, 51.392018124461174, 49.61996801197529, 49.19871121644974, 44.248998016119, 50.03972768783569, 47.22935289144516, 49.45013992488384, 48.784905821084976, 51.73035576939583, 44.290400594472885, 48.212219551205635, 34.08468782901764, 35.45840911567211, 57.1651167422533, 48.960198014974594, 49.41466122865677, 45.639723390340805, 46.714605912566185, 44.983293414115906, 46.72880195081234, 46.42414949834347, 45.28543800115585, 42.91767105460167, 40.68064749240875, 37.09429733455181, 36.77227221429348, 35.36658704280853, 37.44094133377075, 39.07736912369728, 37.537885531783104, 37.52634175121784, 41.21851243078709, 39.80641320347786, 37.97111928462982, 39.40345622599125, 37.194174975156784, 38.268449530005455, 38.332985267043114, 38.934751376509666, 36.53112195432186, 37.798999920487404, 36.30806252360344, 37.081473022699356, 37.57103115320206, 38.28038848936558, 38.90141196548939, 38.58850255608559, 44.807818830013275, 47.42628492414951, 50.74278116226196, 50.90560622513294, 47.873045951128006, 49.32041868567467, 50.99785387516022, 51.56764470040798, 51.106843426823616, 48.71068440377712, 47.27442607283592, 44.12649258971214, 47.475575879216194, 46.42223820090294, 47.1763913333416, 45.95651239156723, 51.186832934617996, 53.37279103696346, 57.0685563236475, 54.4405223429203, 35.652863681316376, 10.014372132718563, 16.125190928578377, 6.426873961463571, 1.3742150226607919, 0.3217985574156046, 0.1494531350908801, 0.2852460922440514, 16.24961905181408, 38.41832108795643, 45.99410757422447, 40.69254085421562, 27.464517764747143, 33.82178373634815, 40.51235072314739, 50.536627024412155, 34.728122502565384, 1.0213279584422708, 0.05448672724014614, 0.006071296311347396, 0.04818202316528186, 0.038846651441417634, 0.0411511238780804, 0.040534885265515186, 0.03951960497943219, 0.039327496342593804, 0.036161898824502714, 0.01682438021816779, 0.10285862517775968, 0.049649512584437616, 0.036197533045196906, 0.0804710725788027, 0.05916712980251759, 0.042994036120944656, 0.007008074071563897, 0.07670126666198485, 0.004490518977036118, 0.03732933422725182, 0.019931939932575915, 0.060771408170694485, 0.06641526313615032, 0.08424419589573517, 0.04880768705334049, 0.08724258383153938, 0.1681952879880555, 0.0213899502705317, 0.10381209940533154, 0.07388943238765933, 5.8384560607373714, 36.15700542926788, 49.03057023882866, 45.31261034309864, 31.252361610531807, 19.34163473546505, 23.519326262176037, 34.10950809717178, 42.87710063159466, 30.221708714962006, 0.365690536564216, 1.0979441972449422, 2.0192638970911503, 9.993482753634453, 8.94896725192666, 9.23259163275361, 13.594697713851929, 26.805693916976452, 55.42242765426636, 57.963681891560555, 55.94181418418884, 52.67281539738178, 50.22491455078125, 56.42023891210556, 55.61521030962467, 54.39697667956352, 54.413486793637276, 55.83333380520344, 52.0415248721838, 52.29907885193825, 49.297958090901375, 48.58262747526169, 48.410751298069954, 50.381716936826706, 51.574130952358246, 48.863402009010315, 50.946830213069916, 51.931414380669594, 49.8375329375267, 44.37951721251011, 40.23748107254505, 38.66036430001259, 37.55517840385437, 38.28978158533573, 37.5251068174839, 39.461627304553986, 38.9533855766058, 38.751270622015, 39.72464919090271, 40.401818454265594, 38.79290498793125, 38.98124188184738, 37.0058760792017, 39.997626543045044, 38.26816834509373, 40.311075523495674, 39.10891503095627, 39.136224165558815, 37.8820026665926, 43.85183572769165, 48.23689162731171, 53.49960923194885, 52.730184718966484, 50.734087228775024, 46.56502693891525, 52.60120443999767, 50.68958781659603, 51.580081433057785, 52.07304038107395, 53.922625333070755, 46.48501843214035, 49.52760636806488, 34.83400002121925, 34.59210880100727, 57.50888429582119, 49.544640854001045, 51.77795201539993, 47.025018855929375, 49.468390345573425, 48.058810383081436, 48.47815588116646, 48.64287704229355, 47.244992852211, 45.20431235432625, 44.004340544342995, 39.93251323699951, 39.94900435209274, 37.98486314713955, 39.200683906674385, 40.66184230148792, 40.4399836063385, 39.135118424892426, 43.82207192480564, 42.26002134382725, 40.43806090950966, 40.859743282198906, 40.54494917392731, 40.773510709404945, 40.03336362540722, 41.451447531580925, 37.95982249081135, 39.13708671927452, 38.829592019319534, 38.593484088778496, 39.21509653329849, 39.968368113040924, 41.2749508023262, 42.177105993032455, 45.552179887890816, 50.07820822298527, 52.00541540980339, 51.92679762840271, 48.16647760570049, 48.96545693278313, 52.904158383607864, 52.95066408813, 53.55558782815933, 50.66516652703285, 49.81392860412598, 47.7701398730278, 49.92756150662899, 49.25265692174435, 49.072850570082664, 48.55702444911003, 52.08166591823101, 54.770188853144646, 57.958004996180534, 56.015606224536896, 38.13995562493801, 11.353065948933363, 15.307633448392153, 9.075926039367914, 4.006237601861358, 2.5180315459147096, 0.3619874274590984, 0.12703061249339953, 18.47688663750887, 39.422352612018585, 53.33093248307705, 41.76312580704689, 26.773948520421982, 38.413704335689545, 46.246083453297615, 55.80564849078655, 42.44802005589008, 2.631730707362294, 0.03657308945548721, 0.03468165930826217, 0.04435320166521706, 0.0736236544616986, 0.033055149906431325, 0.12084592483006418, 0.05155494705832098, 0.016174798765860032, 0.06232613333850168, 0.0852982682408765, 0.05688563054718543, 0.05976577951514628, 0.03451887663686648, 0.030671623899252154, 0.028244719360372983, 0.07282142250915058, 0.1108405421837233, 0.148281758883968, 0.08469588923617266, 0.14150396164041013, 0.15427846054080874, 0.12494770082412288, 0.17028464149916545, 0.21007168310461566, 0.16302017349516973, 0.19192094769096002, 0.20464872097363696, 0.11255387173150666, 0.2028394243097864, 0.28524585475679487, 7.931532897055149, 45.227643102407455, 56.553372368216515, 52.775675877928734, 37.15884827077389, 25.551603510975838, 30.402772799134254, 37.36442483961582, 48.31120803952217, 35.76274238526821, 0.41406449396163225, 1.454410906881094, 5.014468850567937, 17.925190441310406, 13.225020300596952, 18.35296768695116, 16.77730243653059, 26.793255284428596, 61.71638332307339, 59.1706757247448, 59.06781144440174, 53.046738132834435, 53.50064657628536, 57.549595311284065, 58.24745066463947, 55.83788976073265, 56.19651071727276, 55.66603258252144, 52.956888154149055, 52.71728441119194, 51.11842520534992, 50.46688936650753, 49.05566029250622, 50.64774826169014, 54.30499881505966, 51.062226220965385, 52.3271669447422, 52.458541095256805, 53.036284893751144, 47.41508312523365, 42.09357887506485, 40.58138161897659, 40.67551776766777, 40.643132105469704, 40.39011508226395, 41.110670417547226, 41.08898498117924, 41.60582184791565, 41.56507283449173, 43.83989676833153, 41.415756046772, 42.20104090869427, 39.27499271929264, 41.38627342879772, 40.708492398262024, 41.533880308270454, 41.26927010715008, 40.763201862573624, 40.82622908055782, 44.561333656311035, 50.70354826748371, 54.810945466160774, 53.73142719268799, 51.13384857773781, 45.83885170519352, 54.35315743088722, 52.396053448319435, 53.13952535390854, 54.68597777187824, 55.28123863041401, 48.156985715031624, 49.20570284128189, 38.3730199187994, 39.098989963531494, 58.76403674483299, 53.280729576945305, 53.48937638103962, 49.3903349339962, 52.69508980214596, 49.837156757712364, 50.53356058895588, 50.80354370176792, 50.51504038274288, 47.98986688256264, 45.9411384165287, 42.67677538096905, 41.726864352822304, 40.21572723984718, 41.07602007687092, 44.30551998317242, 41.434211656451225, 42.1479881554842, 44.23057280480862, 44.59357492625713, 41.4750062674284, 43.008436784148216, 42.30402298271656, 43.40090252459049, 43.674529641866684, 43.56980726122856, 41.336446702480316, 42.14890770614147, 40.39294973015785, 41.98487050831318, 41.46977014839649, 42.48700976371765, 44.081354811787605, 44.738685339689255, 48.522393107414246, 53.128065168857574, 54.181509241461754, 53.43594744801521, 50.450196862220764, 49.63754966855049, 53.72298404574394, 54.66134749352932, 56.073385924100876, 53.8491752743721, 52.455273270606995, 49.149454459548, 51.86005041003227, 51.873919665813446, 50.750620141625404, 50.40836490690708, 55.944010466337204, 57.398701608181, 60.305260643363, 57.17507600784302, 41.7418659478426, 14.044942203909159, 25.511194579303265, 15.81908505409956, 7.816196735948324, 2.8230471163988113, 0.4021772474516183, 0.2547425462398678, 21.534588262438774, 48.85297916829586, 56.91512055695057, 49.77101370692253, 38.03442768752575, 46.092442497611046, 54.33304890990257, 66.04178622364998, 52.42205165326595, 5.221192007884383, 0.13126134406775236, 0.0767711472872179, 0.17107154068071395, 0.1976211168221198, 0.08817944137263112, 0.19846084207529202, 0.1624609503778629, 0.1510832624626346, 0.16987289796816185, 0.1424585861968808, 0.11780451459344476, 0.2465315579320304, 0.1141478045610711, 0.1678457364323549, 0.19773894018726423], [0.020170391981082503, 0.043269280140521005, 0.05176422528165858, 0.10263894204399548, 0.027385759494791273, 0.036798160581383854, 0.008478223626298131, 0.04412877620779909, 0.044218576076673344, 0.027307333039061632, 0.02250639270641841, 0.0473519569641212, 0.05585124366916716, 0.06433936476241797, 0.051403957113507204, 5.454061087220907, 34.13870573043823, 45.20642504096031, 37.22949028015137, 20.729850344359875, 11.823210921138525, 20.52315093576908, 34.43953938782215, 38.288379460573196, 24.379999078810215, 0.10893826183746569, 1.0564182442612946, 5.4791805893182755, 12.87133052945137, 8.940390162169933, 5.616118116304278, 10.050346702337265, 37.97831989824772, 57.929939702153206, 53.48216816782951, 54.83953893184662, 48.673666790127754, 49.96549867093563, 54.43927600979805, 52.17009857296944, 51.02466523647308, 51.995239555835724, 50.14998637139797, 50.300956070423126, 47.88362838327885, 49.32487964630127, 50.032242089509964, 50.55257096886635, 48.86002779006958, 50.67613273859024, 49.119937643408775, 50.375884249806404, 46.775653436779976, 44.14706468582153, 38.597367480397224, 37.890145629644394, 37.264338210225105, 35.988085493445396, 38.29547367990017, 38.58211889863014, 39.30526189506054, 42.12640531361103, 38.51649262011051, 36.69917933642864, 39.64819349348545, 38.35395634174347, 38.385346457362175, 36.416835486888885, 36.4988236874342, 36.18446655571461, 36.267317309975624, 35.139484629034996, 37.420741617679596, 37.35260367393494, 44.418092742562294, 48.27582433819771, 51.2898226082325, 48.14445398747921, 45.32762713730335, 46.923085525631905, 50.41720703244209, 48.157320097088814, 50.72768837213516, 48.945432007312775, 51.343680918216705, 45.0349098443985, 47.09530368447304, 33.36076207458973, 36.35911278426647, 52.67344996333122, 47.900366485118866, 47.92399741709232, 46.724226996302605, 45.166561380028725, 46.18937149643898, 49.13641355931759, 46.30735136568546, 47.66242325305939, 42.1318694204092, 40.30072867870331, 39.87805835902691, 37.5576938688755, 35.59387184679508, 37.6105984300375, 35.63978858292103, 37.75094009935856, 36.738936603069305, 36.648794040083885, 37.68738850951195, 39.60162699222565, 38.93948972225189, 39.093468859791756, 37.02488265931606, 37.83284090459347, 39.326491355895996, 38.35864149034023, 36.073159128427505, 35.504736229777336, 36.5188068151474, 37.02895984053612, 37.452401518821716, 37.57804177701473, 40.08227080106735, 46.14197663962841, 49.199558570981026, 51.75269477069378, 46.168700605630875, 47.95652747154236, 49.189378917217255, 50.84756813943386, 52.02170893549919, 52.51423090696335, 51.15454986691475, 48.52251090109348, 45.65165854990482, 42.461406737565994, 43.371997475624084, 46.890680864453316, 48.7634901702404, 51.44022613763809, 54.669087678194046, 57.339177802205086, 58.74769002199173, 38.25912103056908, 11.235447060316801, 12.479560151696205, 6.33055672980845, 0.996982071083039, 2.5967626087367535, 0.5930198694113642, 0.04237895154801663, 11.17462182417512, 41.34839326143265, 30.847029760479927, 33.81054013967514, 30.666444450616837, 39.77025434374809, 47.22829654812813, 48.33497576415539, 38.8708958029747, 1.9023664947599173, 0.07701146954786964, 0.025703700339363422, 0.049728143130778335, 0.06741031247656792, 0.03677243032143451, 0.08768220985075459, 0.03175803904014174, 0.05112158847623505, 0.009587957974872552, 0.03159375351970084, 0.021810581019963138, 0.025331362994620577, 0.06922083368408494, 0.0952702245558612, 0.006962641182326479, 0.043501709660631604, 0.020693758233392145, 0.09264609427191317, 0.048805505139171146, 0.04526042153884191, 0.06378335514455102, 0.03465283058176283, 0.005989169785607373, 0.047139891976257786, 0.02006164508202346, 0.04158285344601609, 0.008451958092337009, 0.01184840435598744, 0.047274409953388385, 0.027530619299795944, 6.735528074204922, 40.84298238158226, 53.15642684698105, 43.85842077434063, 26.634260416030884, 13.534889873117208, 21.430390253663063, 33.67629334330559, 41.6324470192194, 26.45175240933895, 0.047067558552953415, 1.8259899993427098, 6.850230619311333, 15.092637185007334, 14.541173726320267, 10.784621201455593, 10.873094704002142, 34.683060720562935, 60.16004763543606, 55.39264105260372, 55.5355703830719, 49.427717328071594, 53.17337013781071, 55.056685879826546, 54.14569616317749, 51.37378290295601, 52.23982863128185, 49.992754608392715, 51.70183829963207, 48.778826147317886, 50.58757849037647, 49.873197823762894, 51.0968803614378, 49.91889417171478, 52.08824336528778, 51.145217567682266, 51.23388960957527, 50.144757851958275, 47.76779159903526, 39.974732771515846, 39.95491303503513, 39.10710632801056, 38.193304762244225, 39.913411661982536, 39.90594506263733, 40.70275850594044, 43.63683946430683, 39.094772189855576, 38.493986427783966, 40.587985664606094, 41.128651052713394, 39.90513190627098, 37.72282920777798, 38.0403857678175, 38.391049951314926, 37.68352031707764, 37.837708443403244, 38.18480461835861, 38.52243930101395, 45.658862963318825, 50.47345161437988, 53.17464306950569, 49.24192629754543, 47.70913414657116, 47.80480541288853, 52.553528398275375, 49.05243806540966, 50.2115772664547, 49.81385260820389, 52.70089589059353, 46.45313434302807, 46.911629140377045, 33.771656826138496, 36.955863162875175, 53.80392350256443, 51.231054961681366, 50.56276202201843, 48.77571031451225, 47.50305600464344, 48.87010104954243, 50.7559360563755, 49.5269376039505, 46.677337512373924, 44.53521005809307, 43.21389175951481, 41.009147465229034, 38.33010122179985, 36.96064330637455, 39.79097843170166, 37.9611524194479, 39.64062809944153, 39.29565221071243, 39.06050942838192, 40.43241061270237, 40.942510440945625, 39.366640001535416, 39.61711496114731, 39.112205654382706, 40.1925864815712, 39.12816099822521, 40.33698633313179, 38.02114740014076, 37.168887332081795, 38.99539612233639, 38.83551970124245, 38.20695362985134, 40.284518748521805, 42.20676340162754, 46.504617780447006, 51.39242470264435, 53.459316194057465, 48.12462665140629, 48.7055204808712, 50.31009078025818, 52.511149272322655, 54.34248760342598, 54.456515684723854, 53.17663036286831, 50.48599474132061, 46.79292730987072, 45.56731827557087, 44.06798332929611, 46.96187384426594, 50.795298144221306, 53.87666679918766, 56.433276012539864, 58.75374689698219, 59.40942071378231, 38.64412397146225, 13.720319923013449, 11.975938975811005, 5.97128838300705, 4.720444902777672, 2.187824514694512, 0.15014365897513926, 0.09478734617005102, 12.050968799740076, 44.037630558013916, 35.52149713039398, 39.30989384651184, 41.02702550590038, 47.54551112651825, 51.897303611040115, 53.43515709042549, 48.08413602411747, 4.186483779922128, 0.07006757223280147, 0.0136418515285186, 0.04155361282755621, 0.0466943065111991, 0.07722551978076808, 0.06218975999217946, 0.00939761936024297, 0.0701172070694156, 0.028020028585160617, 0.023676935852563474, 0.03078347483096877, 0.053369331144494936, 0.007665022267246968, 0.046390270872507244, 0.024839083453116473, 0.1392069848952815, 0.1416968903504312, 0.3714447340462357, 0.17985620914259925, 0.18985224072821438, 0.1542294936371036, 0.15407242550281808, 0.06766508435248397, 0.1298466621665284, 0.08694959877175279, 0.07680070702917874, 0.08344905145349912, 0.19784607662586495, 0.12128420014050789, 0.18631814833497629, 8.502181526273489, 49.04661297798157, 59.72011864185333, 51.033165380358696, 31.07361540198326, 20.526585951447487, 27.91851170361042, 43.76194015145302, 51.18736110627651, 30.972276739776134, 0.23889669886557385, 2.5754362531006336, 10.600002408027649, 21.636969968676567, 17.288471907377243, 12.15713795274496, 13.032017257064581, 40.238085240125656, 60.77368810772896, 58.15473943948746, 58.81281852722168, 52.00994096696377, 54.881872460246086, 58.520203828811646, 55.2266925573349, 51.472342014312744, 53.36548402905464, 50.36083705723286, 53.193330466747284, 48.868873715400696, 51.23954750597477, 50.554687455296516, 53.094235584139824, 52.24599950015545, 55.11863775551319, 53.605258762836456, 54.43442367017269, 54.08112622797489, 49.29598979651928, 41.41211964190006, 42.450045347213745, 41.270117461681366, 40.13177074491978, 42.8304049372673, 42.06152759492397, 42.83355496823788, 46.971817910671234, 42.15668208897114, 41.080408841371536, 42.37939573824406, 43.74299816787243, 43.31907011568546, 39.39463309943676, 38.89334499835968, 40.33754490315914, 39.73649315536022, 39.03092421591282, 40.49564301967621, 42.02569551765919, 47.60196469724178, 53.26184079051018, 55.40557935833931, 51.43631614744663, 46.89481124281883, 49.14623223245144, 55.07347717881203, 51.497743651270866, 54.30996134877205, 50.592229440808296, 53.86605016887188, 48.49796801805496, 48.3373012393713, 36.29008188843727, 39.710453152656555, 57.60718122124672, 53.210695534944534, 52.648420706391335, 50.77089965343475, 48.86618345975876, 51.45936571061611, 52.66478642821312, 51.70661084353924, 51.92206688225269, 45.86154788732529, 44.53718975186348, 43.36619898676872, 41.687240079045296, 39.22124460339546, 41.83014661073685, 40.358968153595924, 41.37892082333565, 41.16555467247963, 41.32651023566723, 41.61227390170097, 42.973345667123795, 41.926486641168594, 41.55263230204582, 41.587286442518234, 42.38181620836258, 42.36876770853996, 41.56265236437321, 40.14445446431637, 40.59495069086552, 42.05825217068195, 41.67408898472786, 40.988199189305305, 43.13376545906067, 43.94691042602062, 50.78984543681145, 54.18693155050278, 56.12787500023842, 48.6431810259819, 51.71723507344723, 51.90383166074753, 53.83572019636631, 56.24778136610985, 55.43474659323692, 55.11915072798729, 53.928302228450775, 50.401988849043846, 48.49248491227627, 46.79627113044262, 51.20837017893791, 53.88705924153328, 56.43046796321869, 60.28957508504391, 61.39360584318638, 64.22750517725945, 41.525433361530304, 14.377212524414062, 23.69240127503872, 17.278980016708374, 9.150969162583351, 4.544134363532066, 1.2603245652280748, 0.33676651830319315, 14.279390573501587, 52.26675398647785, 41.83551952242851, 46.061854138970375, 41.62283733487129, 52.30929270386696, 59.14318419992924, 60.959767922759056, 56.266799345612526, 8.528990037739277, 0.14519377145916224, 0.09300708974478766, 0.1615087897516787, 0.12862329109339043, 0.1830853382125497, 0.20383004302857444, 0.106867617869284, 0.21569058706518263, 0.15046870481455699, 0.13024635321926326, 0.07904071651864797, 0.18530799628933892, 0.1894226114382036, 0.16296417103148997, 0.15188077435595915], [0.027690778479154687, 0.005715888282793458, 0.036700089476653375, 0.04210321028949693, 0.030470397978206165, 0.045272956413100474, 0.08722649406990968, 0.02762306306976825, 0.05452429104479961, 0.03174572309944779, 0.08404948603129014, 0.0014902224461366131, 0.003947571622120449, 0.02319970149983419, 0.04141789999266621, 4.926911098882556, 30.14193769544363, 45.204943120479584, 37.633157819509506, 25.398741513490677, 22.20036193728447, 26.151030845940113, 34.470275938510895, 39.67186622321606, 17.158509381115437, 0.10984838721924461, 0.18904487311374396, 9.03373310342431, 29.93395395576954, 10.97886772826314, 10.366223752498627, 21.535448916256428, 46.975678503513336, 57.1084313839674, 52.3608673363924, 50.659140050411224, 50.3484383225441, 49.887682646512985, 54.10861015319824, 54.3318747729063, 47.954870760440826, 45.129688158631325, 49.18981969356537, 46.32662393152714, 47.60167971253395, 46.16484761238098, 48.52256029844284, 47.775622978806496, 49.7649834305048, 48.11088278889656, 46.31133355200291, 43.49417231976986, 43.22635129094124, 38.56796085834503, 36.08962744474411, 36.62432335317135, 36.765493378043175, 37.8665716946125, 39.27388317883015, 40.683075562119484, 40.91489352285862, 38.513692170381546, 39.466335251927376, 36.84408836066723, 37.056063786149025, 36.53406299650669, 37.113911882042885, 35.147570595145226, 35.690268874168396, 37.25226625800133, 36.266485154628754, 35.951330065727234, 35.58954007923603, 36.673078536987305, 43.3345390856266, 49.35392528772354, 52.15630531311035, 46.890669465065, 46.24300181865692, 47.64861859381199, 51.8913721293211, 48.89703020453453, 49.81885313987732, 49.12454679608345, 51.71145178377628, 44.50894206762314, 45.00703454017639, 35.12359768152237, 38.07643823325634, 55.12808784842491, 49.04099687933922, 49.16848383843899, 44.56148944795132, 43.94811116158962, 45.46865276992321, 46.14508867263794, 43.809460401535034, 42.47166998684406, 39.08042795956135, 38.78717489540577, 38.16621981561184, 35.04135109484196, 36.376721039414406, 38.523560240864754, 36.14342115819454, 37.191062942147255, 37.86572054028511, 37.995612770318985, 36.017625108361244, 38.25342133641243, 37.19718061387539, 35.958295091986656, 37.15589962899685, 37.69974164664745, 37.04359285533428, 36.7901274561882, 37.37256780266762, 37.2858564555645, 37.19160631299019, 36.63950353860855, 37.55098722875118, 38.21933716535568, 41.50996819138527, 44.185286834836006, 49.4380109757185, 49.8677983134985, 50.68250499665737, 49.29568961262703, 50.900841280817986, 47.173207104206085, 49.38003748655319, 52.297798320651054, 53.5306041687727, 48.64776358008385, 44.2889528721571, 40.45609854161739, 44.610324427485466, 52.61140689253807, 55.07865630090237, 53.578690588474274, 54.013334065675735, 53.864853233098984, 58.92666041851044, 46.72878675162792, 22.506954185664654, 12.44123350828886, 4.401704231277108, 3.349147173576057, 2.2853436693549156, 0.20772924239281565, 0.10999695034115575, 6.229351535439491, 41.886972561478615, 40.58148421347141, 21.974819339811802, 17.547796592116356, 32.690614834427834, 45.88613636791706, 50.08268818259239, 42.31628492474556, 5.889385677874088, 0.02473842781910207, 0.0630155811086297, 0.04065997796715237, 0.08220286676078103, 0.03223021936719306, 0.06976106524234638, 0.06562744369148277, 0.025383137071912643, 0.04224817028443795, 0.02078583278489532, 0.03323713935969863, 0.02989054501085775, 0.14725746150361374, 0.04669717120123096, 0.024625313380965963, 0.009361091779283015, 0.03642064119048882, 0.05788126618426759, 0.05503601671080105, 0.033231922061531805, 0.04094548217835836, 0.054364655079552904, 0.011332848280289909, 0.003177886092089466, 0.05032469627622049, 0.023267287033377215, 0.039739510757499374, 0.07389994862023741, 0.054812589442008175, 0.014377904317370849, 6.272893873974681, 36.29513941705227, 50.98526895046234, 43.00185173749924, 26.53738271445036, 22.600149884819984, 22.917096577584743, 35.68334184587002, 45.889947563409805, 20.02787221223116, 0.1155308709712699, 0.430305267800577, 11.5298106148839, 25.87990589439869, 11.55150555074215, 16.494103632867336, 16.73324190080166, 48.30527275800705, 59.48583081364632, 54.374485686421394, 53.11351954936981, 52.563449665904045, 50.907528921961784, 56.24750018119812, 55.246592089533806, 50.12018457055092, 47.510313615202904, 49.719180688261986, 46.33466050028801, 49.30489271879196, 49.10905882716179, 49.11937527358532, 50.612474754452705, 51.0078739374876, 49.223166704177856, 48.63500006496906, 46.27340018749237, 46.08885549008846, 39.941047579050064, 37.23412983119488, 39.13502722978592, 37.97357015311718, 39.73702512681484, 40.98129115998745, 41.478809863328934, 42.42123909294605, 39.129148945212364, 41.87670171260834, 38.957147374749184, 39.18917432427406, 38.50835345685482, 39.12989750504494, 36.5866369754076, 38.55569131672382, 39.00703489780426, 39.467209205031395, 36.72065578401089, 37.754177525639534, 37.68024489283562, 45.83268083631992, 50.736093521118164, 53.632982075214386, 48.98325517773628, 47.370462119579315, 49.81090396642685, 52.26025253534317, 48.96234109997749, 52.44992695748806, 51.38830952346325, 51.26535192131996, 45.65640069544315, 46.28577992320061, 36.828786581754684, 39.41565737128258, 55.494380593299866, 49.61685597896576, 50.785608664155006, 47.56039872765541, 46.200231313705444, 46.568887531757355, 47.17060424387455, 45.19405670464039, 44.0364146232605, 41.63628861308098, 40.425726771354675, 38.19650039076805, 37.78228081762791, 38.318409249186516, 40.66078595817089, 38.195569440722466, 38.62904638051987, 39.69954773783684, 39.37814198434353, 38.4380192309618, 41.36920474469662, 39.86358493566513, 37.303521707654, 39.58801992237568, 39.19860161840916, 40.131519958376884, 39.3637977540493, 38.31903621554375, 39.20317657291889, 39.05891731381416, 38.21774125099182, 38.99790778756142, 41.0525069385767, 41.42246648669243, 47.704798579216, 51.468166038393974, 52.19740390777588, 51.703658401966095, 51.27955175936222, 52.44131661951542, 48.72380509972572, 50.99354110658169, 54.639878645539284, 54.12823610007763, 50.09674362838268, 45.415714010596275, 41.643599420785904, 46.997629925608635, 55.37601314485073, 57.14601896703243, 56.18715561926365, 55.90446598827839, 55.95546305179596, 61.30483880639076, 46.43802635371685, 19.79396626353264, 9.948873147368431, 9.636256322264671, 6.652170997112989, 1.6835471615195274, 0.34039526421111077, 0.10336558625567704, 6.345811011269689, 45.35706415772438, 42.44996935129166, 26.42363391816616, 21.90420962870121, 37.84252658486366, 53.1680466234684, 57.82215468585491, 49.804717898368835, 8.690682761371136, 0.08176850999007002, 0.048151891969610006, 0.028394809451128822, 0.017476013708801474, 0.06643127126153558, 0.06221203184395563, 0.048600984082440846, 0.036357194985612296, 0.05323010424035601, 0.027131238093716092, 0.027347121431375854, 0.04731700551928952, 0.0633688953530509, 0.038501678936881945, 0.04214380947814789, 0.13003072963329032, 0.13201447553001344, 0.15182705770712346, 0.0957961252424866, 0.20479807077208534, 0.13189175399020314, 0.16553513385588303, 0.07630282241734676, 0.13246791291749105, 0.12547179067041725, 0.200889119587373, 0.13398795010289177, 0.16161371459020302, 0.16098980588139966, 0.17694062262307853, 8.57740418985486, 43.35226513445377, 60.77137403190136, 50.17792247235775, 36.25874117016792, 32.65732102096081, 35.46602010726929, 45.280388072133064, 52.407004460692406, 21.743411757051945, 0.40366673783864826, 0.5103958561085165, 16.685301773250103, 39.45799469947815, 17.102270498871803, 20.080444291234016, 25.04441812634468, 50.77715411782265, 61.50363653898239, 57.299302741885185, 55.12203477323055, 54.416891410946846, 53.471844121813774, 57.542546689510345, 56.90315879881382, 50.890490636229515, 48.8888568431139, 52.962470054626465, 49.427075162529945, 50.38912653923035, 49.92221899330616, 49.92167942225933, 52.459346652030945, 54.014481604099274, 51.89995966851711, 50.63300125300884, 48.75269114971161, 47.54682965576649, 42.82523721456528, 39.39335256814957, 41.084600016474724, 40.893306881189346, 42.22145341336727, 43.89027826488018, 44.393500462174416, 45.560892820358276, 41.41250342130661, 43.49924124777317, 40.907077342271805, 41.59086965024471, 41.60913906991482, 40.92585973441601, 37.726112231612206, 39.30072493851185, 41.28357253968716, 40.25660924613476, 38.79058711230755, 38.57349336147308, 40.442001298069954, 47.004568353295326, 54.31773193180561, 55.14214709401131, 51.082805916666985, 46.39343574643135, 51.43772967159748, 55.386040806770325, 51.12254798412323, 53.85250769555569, 52.40188233554363, 54.07517574727535, 48.373612090945244, 48.234805539250374, 36.97098255157471, 43.24949584901333, 58.20971868932247, 52.829906567931175, 53.70003707706928, 50.47945149242878, 48.31828325986862, 49.29393030703068, 49.09917555749416, 47.02583961188793, 46.485227420926094, 43.641395419836044, 42.702575996518135, 41.11185975372791, 39.3116569519043, 40.89353486895561, 42.43411660194397, 40.10684408247471, 40.32504357397556, 42.897190153598785, 41.78661234676838, 40.535841062664986, 43.43002796173096, 40.89059762656689, 38.27829860150814, 41.402148976922035, 40.33559560775757, 40.080215111374855, 41.850897297263145, 40.63036859035492, 41.8205027282238, 40.89740686118603, 40.8405315130949, 41.283819526433945, 43.49364414811134, 44.75272558629513, 50.622935593128204, 53.59461173415184, 53.41737784445286, 52.877506613731384, 53.91600228846073, 54.39046382904053, 49.331263303756714, 50.36991477012634, 54.1246946901083, 57.495341822505, 51.35895989835262, 48.308407589793205, 44.27862882614136, 50.1695591211319, 57.97959543764591, 60.286881029605865, 57.76761241257191, 58.6177483946085, 59.00265634059906, 61.666241213679314, 52.53943495452404, 26.50489255785942, 17.958425357937813, 17.4144047498703, 14.09954147413373, 6.102276379242539, 0.831770320655778, 0.24129831843310967, 7.337535945698619, 53.60207453370094, 51.115332171320915, 33.26117321848869, 27.136289477348328, 46.38377666473389, 60.17661094665527, 63.327135890722275, 58.669900596141815, 12.068917136639357, 0.13533900026232004, 0.23482113552745432, 0.17865621572127566, 0.2297045022714883, 0.18696959072258323, 0.18254431255627424, 0.13495222257915884, 0.1568231513374485, 0.11413141051889397, 0.06640619409154169, 0.10415689379442483, 0.1265177587629296, 0.22597740695346147, 0.09719540015794337, 0.21476021589478478], [0.07446611081832089, 0.05196031183004379, 0.028128469348303042, 0.044620103944907896, 0.021052568081358913, 0.02648952340678079, 0.03660900940303691, 0.06900161068188027, 0.08603479043813422, 0.030445012816926464, 0.04366372791992035, 0.04812046201550402, 0.00997994553472381, 0.06587994459550828, 0.09564862339175306, 6.043278845027089, 28.12713000923395, 45.60069568455219, 35.788710191845894, 26.14114947617054, 11.77007932215929, 23.86085193604231, 29.174790792167187, 40.79060599207878, 11.527269501239061, 0.03293399429821875, 0.0915838879882358, 2.930018501356244, 15.929056853055954, 9.94775315746665, 18.0787668004632, 21.79286800324917, 51.51419296860695, 54.769698679447174, 53.31865154206753, 48.558726757764816, 49.33522269129753, 51.482031494379044, 53.47252428531647, 53.41571353375912, 53.22345905005932, 48.48987065255642, 46.09019681811333, 46.64708353579044, 47.064886316657066, 48.865263909101486, 47.06419475376606, 49.367425963282585, 49.65047277510166, 44.18976679444313, 42.53160797059536, 41.777245849370956, 36.895579397678375, 35.61861231923103, 37.89053700864315, 36.07671193778515, 37.90301933884621, 40.03490254282951, 40.06389878690243, 41.99246250092983, 41.2820640206337, 39.32344771921635, 37.769604697823524, 38.04821714758873, 38.04031737148762, 40.2243185788393, 36.76955156028271, 35.16369692981243, 35.57045750319958, 35.55312663316727, 36.82292349636555, 34.88270960748196, 36.10541559755802, 38.02113980054855, 47.280456349253654, 49.66041684150696, 48.2870527356863, 48.16233202815056, 45.54321616888046, 44.68850903213024, 53.21009136736393, 50.25043398141861, 54.25022095441818, 50.071114003658295, 49.050374776124954, 41.061121076345444, 45.49018621444702, 35.62019303441048, 37.677387446165085, 54.66092951595783, 47.57603108882904, 47.04654090106487, 43.020732924342155, 41.265983283519745, 42.83097870647907, 40.258398950099945, 37.36781805753708, 36.354450434446335, 36.7822352796793, 37.1965878456831, 38.09400849044323, 36.630889400839806, 37.049444541335106, 37.42789663374424, 37.496828734874725, 36.14859648048878, 36.523089185357094, 36.337446346879005, 35.99258825182915, 38.605875223875046, 39.62374560534954, 38.32896128296852, 40.05408011376858, 41.393238455057144, 38.496900871396065, 37.44485892355442, 40.20326390862465, 41.244434639811516, 39.1684540361166, 36.60589814186096, 36.89389608800411, 37.024799063801765, 40.1362507045269, 45.21076060831547, 49.47396844625473, 50.67402005195618, 50.379254668951035, 49.14501629769802, 51.18207938969135, 50.33016510307789, 47.83165857195854, 53.46186965703964, 52.83935286104679, 48.72279815375805, 45.34606754779816, 39.73457045853138, 46.8319246172905, 56.3539856672287, 56.764492839574814, 55.155214592814445, 58.95301580429077, 56.08288921415806, 58.84132079780102, 50.52869684994221, 30.361535511910915, 9.462366253137589, 4.885720834136009, 2.613279609940946, 1.3949325797148049, 0.3125179116614163, 0.14524929894832894, 2.7727656019851565, 38.69182661175728, 45.45862890779972, 34.582525715231895, 27.857526876032352, 40.08405290544033, 45.472053587436676, 48.715384751558304, 43.05370755493641, 5.035841753706336, 0.01486295162976603, 0.03410981968045235, 0.08407057786826044, 0.061557850931421854, 0.028224089510331396, 0.026228695605823305, 0.09455489067477174, 0.06038389205059502, 0.05180615662538912, 0.01079789060895564, 0.05497086727700662, 0.017656782329140697, 0.01839764980104519, 0.03510048663883936, 0.06307744653895497, 0.028292279894230887, 0.05593288362433668, 0.032565974397584796, 0.05436700026621111, 0.036021792475366965, 0.057233412080677226, 0.04829828059882857, 0.06271876656683162, 0.09002152612083592, 0.019962329024565406, 0.05334816509275697, 0.00604353766902932, 0.06580046057933941, 0.04766709513205569, 0.11497155879624188, 7.562675764784217, 34.93352048099041, 51.64313904941082, 43.51822882890701, 31.017709001898766, 18.454790823161602, 26.226813979446888, 33.191032782197, 45.92489808797836, 12.134898696094751, 0.09978906527976505, 0.1458430616185069, 3.6388298543170094, 21.23438537120819, 7.834180695936084, 11.354575417935848, 19.355712980031967, 54.19634364545345, 56.62019558250904, 54.536558389663696, 50.76543554663658, 50.93619078397751, 54.293116852641106, 55.43171435594559, 55.00601179897785, 53.30251760780811, 49.40494515001774, 47.17189237475395, 46.841321513056755, 46.818807721138, 49.01611961424351, 48.56907360255718, 49.85947676002979, 51.85977682471275, 46.407399997115135, 44.9853453040123, 43.14335614442825, 39.38525140285492, 38.3170261234045, 40.28386898338795, 37.27699153125286, 40.78783594071865, 40.22007420659065, 42.600239887833595, 44.6125853061676, 44.251562878489494, 42.00866863131523, 39.35583338141441, 39.40763220191002, 38.85205261409283, 41.05708189308643, 37.666292041540146, 37.743975073099136, 37.062683030962944, 37.95762240886688, 38.99740241467953, 37.01381765305996, 37.411238327622414, 40.74684374034405, 48.53845864534378, 52.83400274813175, 48.74495856463909, 47.13855296373367, 46.54979735612869, 46.1644372344017, 54.71242055296898, 50.91361999511719, 53.430547937750816, 52.42408834397793, 48.516457825899124, 43.4320342540741, 46.19392745196819, 37.20085121691227, 39.10169541835785, 54.65285874903202, 49.358268454670906, 51.01527974009514, 45.578797459602356, 43.29172298312187, 42.912822514772415, 42.646065428853035, 40.098651722073555, 38.81458282470703, 38.902430310845375, 39.145947843790054, 39.93692100048065, 37.89062060415745, 37.528918012976646, 37.33020767569542, 39.57998335361481, 37.1487408131361, 38.58040139079094, 39.09398563206196, 38.70075613260269, 40.9190770983696, 41.34578660130501, 40.81661559641361, 42.57792368531227, 41.67812056839466, 40.29024124145508, 39.06850419938564, 42.98379510641098, 43.32917757332325, 41.56348451972008, 39.40876454114914, 37.997550666332245, 39.08069394528866, 43.108903393149376, 47.311447486281395, 51.8808276951313, 52.19701632857323, 52.318670600652695, 52.105756625533104, 53.69849815964699, 51.09778091311455, 49.28018644452095, 54.11572337150574, 55.02184554934502, 51.4140759408474, 47.282447442412376, 41.96254290640354, 49.064054042100906, 57.95504875481129, 57.897542640566826, 58.75628516077995, 58.536539152264595, 60.63629887998104, 57.064334750175476, 54.22132730484009, 27.004193365573883, 6.129405023530126, 5.647293543443084, 7.492931457236409, 4.645264511927962, 0.2642731770174578, 0.066716063010972, 3.0454563070088625, 42.05792918801308, 46.94132834672928, 36.34538412094116, 23.961759321391582, 40.434789285063744, 50.513543263077736, 53.62753316760063, 50.64354568719864, 6.508841263130307, 0.029799166222801432, 0.008959190981840948, 0.01124883066950133, 0.020820476238441188, 0.020270407512725797, 0.05801999956020154, 0.014076562674745219, 0.012200062683405122, 0.0399170027958462, 0.04483790573431179, 0.052474679541774094, 0.03990664241428021, 0.006997965556365671, 0.0184784956582007, 0.03553665053914301, 0.09817479018238373, 0.18469581351382658, 0.14114462857833132, 0.21279037784552202, 0.1560872228583321, 0.13202526635723189, 0.15901668753940612, 0.11770735261961818, 0.20473810523981228, 0.14653704391093925, 0.1673165406100452, 0.14728644979186356, 0.12592315004440024, 0.12932662444654852, 0.17217636108398438, 9.437719825655222, 42.78477318584919, 58.948482647538185, 48.74400481581688, 36.763091906905174, 21.737134493887424, 34.21896122395992, 41.651780381798744, 53.88857915997505, 14.322609454393387, 0.233040782622993, 0.20491432078415528, 4.725928483530879, 24.64104127138853, 13.801840748637915, 24.93748616427183, 23.403609171509743, 55.57386852800846, 58.36516074836254, 57.90785528719425, 53.81780795753002, 53.91745761036873, 57.15467110276222, 58.125101029872894, 54.836730882525444, 53.02240803837776, 50.44135093688965, 47.47538968920708, 46.372901648283005, 47.38193370401859, 49.812408685684204, 51.432801336050034, 52.15773403644562, 53.577413856983185, 48.049668073654175, 48.78478042781353, 45.92729575932026, 41.69116906821728, 41.36072359979153, 43.63847337663174, 39.32944759726524, 42.60905161499977, 43.08599442243576, 43.05444851517677, 48.52301627397537, 47.80217595398426, 45.090139880776405, 40.336484760046005, 41.94495365023613, 41.21763467788696, 43.25275607407093, 39.792414754629135, 39.45656217634678, 38.7398674339056, 39.219025522470474, 40.96896082162857, 38.12401168048382, 40.005275532603264, 42.488658875226974, 51.74200974404812, 54.494726434350014, 51.17988310754299, 46.887720823287964, 46.33778393268585, 48.276181519031525, 54.73998047411442, 52.71345041692257, 57.157733738422394, 53.01277935504913, 49.34429660439491, 45.42451433837414, 46.35695770382881, 38.0314714461565, 43.14662016928196, 59.75461699068546, 52.10786931216717, 50.95816880464554, 48.59852582216263, 44.91246901452541, 47.76428438723087, 44.642421305179596, 40.10465919971466, 41.25405192375183, 39.78869095444679, 41.58704325556755, 42.17227265238762, 41.2995582818985, 39.806812182068825, 40.68674236536026, 41.84490881860256, 39.503516256809235, 40.71221619844437, 40.99727310240269, 40.973611772060394, 44.397186264395714, 43.044048473238945, 42.34369285404682, 44.31473828852177, 44.856824800372124, 42.14622505009174, 40.622776597738266, 44.28062751889229, 46.467261984944344, 43.699372708797455, 41.62948697805405, 41.48023098707199, 41.41477569937706, 45.92064991593361, 49.28877018392086, 53.69137354195118, 54.44914408028126, 52.935715690255165, 54.43868704140186, 55.09529560804367, 53.99835906922817, 50.12362338602543, 56.724378392100334, 57.51287028193474, 54.05359670519829, 49.84151892364025, 44.232259914278984, 51.37535981833935, 60.935867205262184, 60.56678161025047, 60.62650300562382, 60.57275868952274, 61.04020580649376, 60.26313990354538, 56.560987159609795, 35.26203565299511, 14.682684782892466, 14.184548612684011, 10.64187616109848, 5.301203364506364, 0.635344967013225, 0.1446829957421869, 3.534907568246126, 47.60213188827038, 57.69673101603985, 46.78087055683136, 39.408528953790665, 52.29017972946167, 57.5425960868597, 62.08823136985302, 60.385675728321075, 9.903913009911776, 0.21399515069788322, 0.11278346253675409, 0.16621589107671753, 0.22461020766058937, 0.12471159396227449, 0.19191667292034253, 0.23910559859359637, 0.1483746460871771, 0.1658001696341671, 0.0693697678798344, 0.14691616263007745, 0.19249879871495068, 0.10202168297837488, 0.14584196323994547, 0.19106474675936624], [0.13374985428526998, 0.1275317996623926, 0.03256552910897881, 0.045154472536523826, 0.07935491215903312, 0.038423909281846136, 0.04549342251266353, 0.08349740237463266, 0.06633827273617499, 0.00459985681118269, 0.03508982568746433, 0.009430804493604228, 0.03518831239489373, 0.036147738646832295, 0.09347231985884719, 4.205841366201639, 30.10194294154644, 43.39375890791416, 39.992044642567635, 27.306374050676823, 15.000514928251505, 28.271187879145145, 33.24548006057739, 41.49096541106701, 8.155793063342571, 0.04828980156162288, 0.33022923627868295, 1.3106664014048874, 5.073640700429678, 9.08290246501565, 16.758379451930523, 24.026707336306572, 53.795172572135925, 53.64153541624546, 51.62247955799103, 47.09715038537979, 48.864063173532486, 50.114154294133186, 55.54027833044529, 52.844938561320305, 49.24611747264862, 51.08237273991108, 51.649781093001366, 50.83132781088352, 51.501129269599915, 49.40384320914745, 52.69639313220978, 47.365093007683754, 48.47472086548805, 44.661526679992676, 42.17006117105484, 37.53535106778145, 37.81467407941818, 33.58624957501888, 35.7250902056694, 36.58645458519459, 38.53809826076031, 40.898090824484825, 40.45127660036087, 37.78567023575306, 39.01661038398743, 36.917394027113914, 40.45737907290459, 35.78744865953922, 37.82366059720516, 40.01226715743542, 37.8140015155077, 36.23761810362339, 36.706433147192, 36.28802999854088, 36.59571848809719, 36.375459507107735, 35.08139334619045, 40.16978770494461, 49.36534747481346, 51.290335580706596, 51.57180167734623, 43.7275405973196, 41.15597918629646, 46.36973261833191, 48.99678625166416, 47.44799315929413, 46.59391298890114, 43.79651449620724, 44.6510012447834, 41.58912554383278, 46.615416035056114, 36.139872148633, 36.099981889128685, 53.95423583686352, 47.6500853151083, 48.05330827832222, 42.08051137626171, 42.02532693743706, 39.36331517994404, 41.14723205566406, 39.06273990869522, 37.78125487267971, 35.86543947458267, 36.89047247171402, 36.84398576617241, 36.039998307824135, 36.511461809277534, 36.396495178341866, 36.953461691737175, 37.70932473242283, 36.245194897055626, 36.392866373062134, 37.40081548690796, 38.53749789297581, 38.421387523412704, 41.162541434168816, 42.67104908823967, 42.263878136873245, 41.86712242662907, 41.89346261322498, 42.44764007627964, 43.91734421253204, 41.867437809705734, 38.51726017892361, 35.14415077865124, 36.89047247171402, 41.28725454211235, 45.48420533537865, 46.19009345769882, 46.55029892921448, 48.23355160653591, 47.95513674616814, 51.76071614027023, 48.47207620739937, 49.883582666516304, 55.57052090764046, 52.007862478494644, 48.32286961376667, 42.96097353100777, 41.9550497084856, 45.286194160580635, 51.55938394367695, 54.47637341916561, 57.0731008797884, 54.41550828516483, 56.67288735508919, 57.81509846448898, 52.478391230106354, 44.20297868549824, 23.17988097667694, 3.60762189142406, 5.103773083537817, 1.7991831502877176, 0.021933723728579935, 0.017813629674492404, 0.5252904631197453, 31.421671025454998, 48.282766565680504, 34.26428519189358, 24.308543913066387, 34.12389412522316, 49.190621450543404, 53.146406784653664, 37.693544179201126, 2.8623384330421686, 0.10498318617464975, 0.03239733247028198, 0.06832329512690194, 0.09151638223556802, 0.04378776306111831, 0.009090717176150065, 0.014844029647065327, 0.05200859966862481, 0.057813819803413935, 0.05691247773938812, 0.041722314126673155, 0.045223406923469156, 0.10142355647985823, 0.022521949977090117, 0.03669467922009062, 0.07620366406627, 0.09185202594380826, 0.03427363764785696, 0.011969721381319687, 0.017727403246681206, 0.022566634688701015, 0.05865417959284969, 0.10402073196019046, 0.0378581589757232, 0.0445122327801073, 0.009244907632819377, 0.027642036075121723, 0.05221080522460397, 0.03275990500696935, 0.08504992336384021, 5.6487977877259254, 37.84031890332699, 50.59744656085968, 46.16026505827904, 32.60818965733051, 17.10743062198162, 32.71335281431675, 37.21564382314682, 46.035073176026344, 9.396084509789944, 0.052040230002603494, 0.48479098943062127, 1.816083574667573, 8.423580843955278, 6.331696668639779, 4.683606829494238, 23.63070208579302, 54.7773552685976, 56.34090676903725, 53.70224095880985, 49.834147319197655, 50.638594552874565, 51.15486524999142, 58.24314549565315, 53.076555132865906, 50.35511076450348, 50.869154781103134, 51.37665934860706, 51.85954883694649, 52.24753841757774, 50.29995672404766, 53.63852597773075, 49.282599315047264, 50.12674681842327, 46.88832879066467, 43.04159760475159, 40.30490085482597, 40.34691900014877, 35.07458031177521, 38.76534126698971, 38.33710044622421, 40.11766970157623, 41.977514103055, 43.29635113477707, 40.838836804032326, 41.07446976006031, 39.77006435394287, 40.88987946510315, 37.76567570865154, 39.123928025364876, 41.69213801622391, 39.031391590833664, 38.10005396604538, 37.74893760681152, 37.519638910889626, 39.209275245666504, 37.50009275972843, 37.00020678341389, 41.87029145658016, 51.72034710645676, 53.32426764070988, 50.111163854599, 46.59417897462845, 41.600878313183784, 47.221665903925896, 50.764949172735214, 47.19873793423176, 47.597268149256706, 45.625789538025856, 45.3321298956871, 43.2280346006155, 47.25352719426155, 37.22995385527611, 36.989707946777344, 56.14330217242241, 48.77302385866642, 48.948760628700256, 43.7782184779644, 43.679005801677704, 41.667435541749, 42.36627124249935, 40.82801878452301, 39.27029237151146, 38.409330770373344, 38.75763528048992, 38.57004314661026, 37.777580469846725, 38.24817381799221, 38.57613421976566, 38.34613636136055, 39.832768589258194, 37.139929085969925, 37.87355192005634, 38.94232057034969, 40.29538996517658, 40.6377287954092, 43.92169877886772, 44.67316545546055, 44.69111569225788, 43.767776638269424, 44.9371524900198, 43.949931263923645, 45.74041038751602, 42.94631391763687, 40.78691639006138, 38.01224447786808, 38.8988471031189, 41.82375155389309, 47.82590188086033, 49.20984461903572, 48.27560015022755, 49.420068338513374, 51.156373769044876, 53.00457179546356, 50.97943626344204, 48.77588510513306, 57.17811964452267, 54.31642860174179, 51.022993326187134, 44.52471882104874, 44.48483996093273, 47.177717462182045, 53.78081314265728, 56.800552904605865, 58.15370589494705, 55.107014179229736, 57.614123448729515, 59.683659598231316, 55.17514452338219, 47.26379804313183, 20.020304918289185, 0.7756895455531776, 8.199724406003952, 4.1609501000493765, 0.4675184522056952, 0.0719206036592368, 0.8011757279746234, 33.99643376469612, 51.15934140980244, 39.61201183497906, 30.10256990790367, 39.453282952308655, 55.12580797076225, 58.19504387676716, 47.57797658443451, 5.589543767273426, 0.04780220682732761, 0.009523219505354064, 0.09313331422163174, 0.05247931425401475, 0.019073247240157798, 0.006832337212472339, 0.02487972902599722, 0.03125601324427407, 0.028331431894912384, 0.03161393993650563, 0.007157469790399773, 0.06316680111922324, 0.09355168513138779, 0.03856595263641793, 0.10718878227635287, 0.28596974560059607, 0.19202858878998086, 0.14764594612643123, 0.08619818167062476, 0.267245537834242, 0.10930260439636186, 0.2032663076533936, 0.23022612818749622, 0.1747768762288615, 0.25858488224912435, 0.10171465648454614, 0.09472824152908288, 0.18046616547508165, 0.11053052483475767, 0.33967561845202, 8.929030671715736, 46.999757811427116, 57.67984092235565, 51.92629225552082, 40.23372307419777, 24.32418007403612, 38.23481373488903, 43.86121742427349, 53.292786329984665, 11.112640500068665, 0.07792966949637048, 0.7101888977922499, 2.6913637574762106, 9.262611921876669, 17.256350331008434, 25.37783693522215, 26.279340460896492, 55.547562539577484, 57.25527070462704, 55.30058339238167, 52.88944557309151, 52.968420535326004, 53.03918033838272, 59.143792167305946, 53.94189789891243, 49.4829435646534, 51.70403838157654, 53.75571168959141, 53.0111188441515, 54.378429874777794, 52.20958985388279, 55.57489827275276, 51.056849509477615, 52.39291101694107, 48.906180113554, 45.79245239496231, 42.29483127593994, 42.72236533463001, 37.287387773394585, 41.23668685555458, 41.92465893924236, 43.05091470479965, 44.68868002295494, 46.67254976928234, 41.989069283008575, 44.53970901668072, 42.40580812096596, 43.29794704914093, 40.47058716416359, 41.05317950248718, 43.135330975055695, 41.450573578476906, 40.424586832523346, 39.113638177514076, 40.269023180007935, 40.21408572793007, 39.740277752280235, 39.19391646981239, 44.085496589541435, 53.87211464345455, 56.1472387611866, 49.757991805672646, 44.266279488801956, 44.126450791954994, 48.69211860001087, 50.57222731411457, 48.52034881711006, 47.50434033572674, 45.722311958670616, 45.74326403439045, 45.23740477859974, 49.37429219484329, 38.62440302968025, 42.047054171562195, 58.13907667994499, 50.591670870780945, 51.2337452173233, 46.24729558825493, 47.62460768222809, 44.49770987033844, 44.55197095870972, 44.43311333656311, 42.16510623693466, 40.545899122953415, 40.61927318572998, 41.50692455470562, 40.47358140349388, 41.529662534594536, 39.92475785315037, 40.78306719660759, 43.15074294805527, 39.63189236819744, 39.160637855529785, 42.971065789461136, 42.70891785621643, 41.733468398451805, 46.2730810046196, 47.21303276717663, 46.977787390351295, 45.38660757243633, 48.2834505289793, 46.26865804195404, 49.81370061635971, 47.29894995689392, 42.4147642403841, 40.42613334953785, 40.799562111496925, 45.02970032393932, 50.305781811475754, 52.268171310424805, 49.915808737277985, 52.84556172788143, 51.85864828526974, 57.359696701169014, 50.909827798604965, 50.78694999217987, 60.104528814554214, 57.83481180667877, 53.18930648267269, 46.69408321380615, 46.00923456251621, 50.689489021897316, 55.7323694229126, 58.91994617879391, 60.393134728074074, 58.28850746154785, 59.786022305488586, 62.944253236055374, 56.25848539173603, 48.17767560482025, 28.385854326188564, 10.767606664448977, 16.880578994750977, 6.202374408021569, 0.8931453397963196, 0.07826222587027587, 0.7299634523224086, 40.55578239262104, 61.076706647872925, 47.9965241253376, 36.38132259249687, 45.639981776475906, 63.03879976272583, 64.09024894237518, 56.49221085011959, 11.263515204191208, 0.24902515928260982, 0.13500590954208747, 0.1207743892155122, 0.24337547103641555, 0.1242823431675788, 0.13522043474949896, 0.07627496219356544, 0.12301662514801137, 0.09412494226126, 0.1427829047315754, 0.15318606368964538, 0.1344368455465883, 0.31418082711752504, 0.11948121915338561, 0.18331147060962394], [0.048514204754610546, 0.06367703506839462, 0.04091283510206267, 0.03573839225282427, 0.01017560070977197, 0.057873321493389085, 0.009945951460395008, 0.014774827159271808, 0.0279010734448093, 0.08713402989087626, 0.06923116437974386, 0.023293176855077036, 0.014497134052362526, 0.027191546869289596, 0.34366433566901833, 7.189624132588506, 33.54730166494846, 46.900035962462425, 33.901055082678795, 22.739461809396744, 12.708965241909027, 23.123140521347523, 28.836379051208496, 37.99478441476822, 5.144233787432313, 0.041458877676632255, 0.3272223210660741, 2.4814715702086687, 5.581588419154286, 2.6346921734511852, 3.8996901316568255, 24.796185046434402, 57.41908751428127, 53.26067805290222, 51.586522087454796, 50.976970195770264, 47.4665779620409, 51.99922554194927, 52.84618869423866, 51.37843005359173, 50.71482606232166, 51.396262496709824, 52.292155623435974, 49.873095229268074, 48.800838366150856, 49.15751002728939, 49.73259016871452, 49.253812059760094, 50.59555806219578, 44.31450270116329, 43.13664190471172, 39.27751578390598, 37.964082062244415, 35.66964738070965, 36.60204894840717, 36.8549519777298, 36.53252027928829, 36.01523123681545, 36.67186640202999, 35.672672018408775, 36.151484325528145, 36.850901395082474, 39.87552009522915, 35.323463156819344, 35.602801367640495, 35.56926056742668, 35.61064414680004, 34.38000038266182, 35.772074684500694, 37.22287103533745, 35.45940086245537, 34.719857946038246, 36.83069407939911, 42.70954102277756, 49.392645210027695, 49.69746485352516, 43.70986394584179, 41.174427196383476, 46.913996413350105, 45.83143450319767, 46.45133703947067, 46.16406485438347, 45.46833358705044, 43.98242712020874, 44.78950381278992, 40.93507044017315, 49.644997268915176, 39.83300797641277, 35.32453089952469, 53.10626193881035, 47.12553106248379, 49.22782525420189, 44.39526356756687, 47.53497049212456, 48.170235604047775, 47.56220743060112, 46.388526409864426, 45.18283970654011, 40.5683521181345, 37.506647408008575, 36.249199882149696, 36.13289952278137, 35.54013133049011, 36.39336794614792, 37.046176716685295, 36.273765563964844, 35.49198791384697, 35.685595124959946, 38.69641296565533, 38.90662908554077, 40.59115469455719, 44.15748372673988, 45.036365166306496, 45.3862389922142, 46.40618786215782, 45.79747952520847, 45.66001430153847, 43.36369872093201, 41.75912082195282, 37.41281524300575, 35.57833068072796, 36.76700569689274, 40.46958401799202, 41.0561965405941, 45.61348579823971, 43.88722322881222, 43.95500399172306, 47.72184066474438, 52.27858655154705, 51.68797664344311, 51.2430015206337, 54.221179112792015, 51.55932314693928, 53.17097246646881, 49.16863203048706, 49.263486340641975, 45.52996248006821, 47.46712513267994, 49.976221695542336, 55.954790487885475, 54.51377861201763, 56.357549875974655, 62.49688424170017, 59.689917862415314, 39.09105598926544, 24.058996103703976, 2.791415238752961, 4.078028099611402, 4.510367950424552, 0.3397653886349872, 0.32047884073108435, 0.16375417239032686, 24.690788201987743, 52.10509926080704, 40.160041227936745, 22.519415616989136, 32.293585538864136, 47.746980115771294, 54.40061688423157, 44.31418351829052, 7.696509808301926, 0.1420017349300906, 0.030061791876505595, 0.13672430795850232, 0.036150217420072295, 0.03692769503686577, 0.03910572406311985, 0.031931894554873, 0.08676120458403602, 0.02845354116288945, 0.0630395079497248, 0.02756743910140358, 0.04392173927044496, 0.05580021359492093, 0.05192256248847116, 0.10326012707082555, 0.032599779224256054, 0.04187789425486699, 0.008303946942760376, 0.028403175310813822, 0.005131375091877999, 0.020024892073706724, 0.028168890421511605, 0.05060974777734373, 0.06445053106290288, 0.03271240013418719, 0.014441582443396328, 0.11354722155374475, 0.018414939986541867, 0.04381787199235987, 0.4933196911588311, 9.93972323834896, 41.15451246500015, 53.72833035886288, 40.38005702197552, 30.901461839675903, 14.94302686303854, 25.459861233830452, 36.47649988532066, 43.23099464178085, 5.795657057315111, 0.03244968727813102, 1.2237953441217542, 4.958719667047262, 5.63193429261446, 7.231249948963523, 5.010319948196411, 22.639671564102173, 56.50323785841465, 53.95862080156803, 53.300093337893486, 52.31574475765228, 49.04671937227249, 52.56266310811043, 54.71396327018738, 52.79866464436054, 49.79861922562122, 51.4680140465498, 52.92766012251377, 51.1641139537096, 50.80254055559635, 50.690070390701294, 51.07397519052029, 49.93214786052704, 53.24244283139706, 45.75991854071617, 44.25408214330673, 42.48319856822491, 39.7371581196785, 37.436750158667564, 37.87776209414005, 38.550504595041275, 40.221354737877846, 39.014611691236496, 39.57556799054146, 36.979718282818794, 38.398577347397804, 39.62058797478676, 40.269178971648216, 36.01276136934757, 38.35044912993908, 36.86897322535515, 37.45166055858135, 36.26685373485088, 37.32937932014465, 39.347105249762535, 36.13203316926956, 35.80906569957733, 38.61180670559406, 43.82285848259926, 51.371575221419334, 49.754982367157936, 46.51106223464012, 43.44261288642883, 48.16875748336315, 47.12582364678383, 48.11103098094463, 46.45680874586105, 46.974090188741684, 44.87002149224281, 45.67893348634243, 42.33714580535889, 48.70693780481815, 42.249093130230904, 38.149021938443184, 55.54829590022564, 49.8248416185379, 49.50354985892773, 47.323074862360954, 49.646813571453094, 50.07426783442497, 49.5997378975153, 47.6135540753603, 46.62680022418499, 41.54887430369854, 38.532710149884224, 38.47743831574917, 38.55396620929241, 39.17379654943943, 38.157373890280724, 37.915391474962234, 38.28728511929512, 38.48016656935215, 37.24665775895119, 40.9568926692009, 41.68304890394211, 42.03999035060406, 44.94283318519592, 47.9400135576725, 46.10823065042496, 48.92723098397255, 47.61806063354015, 48.202161490917206, 45.45902028679848, 44.31231401860714, 41.176946461200714, 37.34661519527435, 37.68104664981365, 42.116966620087624, 43.98778483271599, 47.47074633836746, 46.641459837555885, 47.3616161942482, 49.434116184711456, 53.79151716828346, 53.124557957053185, 50.83200417459011, 56.031941547989845, 52.82917320728302, 55.615126714110374, 51.561720818281174, 51.319172233343124, 47.63693422079086, 50.28196468949318, 53.08955803513527, 59.677716717123985, 56.44220173358917, 60.21665699779987, 60.289282500743866, 58.664599880576134, 41.77859477698803, 27.949491441249847, 8.924281876534224, 7.6230597496032715, 3.2166437711566687, 0.8011887897737324, 0.1254290429642424, 0.17797600768972188, 27.23725575953722, 58.11114817857742, 44.463507905602455, 26.1370000988245, 37.20990613102913, 53.773692324757576, 59.29909363389015, 50.72862312197685, 10.739237386733294, 0.2002490617451258, 0.04751322194351815, 0.02382037630013656, 0.037638153007719666, 0.011284415722911945, 0.01835875755205052, 0.05787159600004088, 0.07848666617064737, 0.08805073070107028, 0.0484087344375439, 0.02266552772198338, 0.02922664010839071, 0.025716888303577434, 0.011796825092460494, 0.06240851915208623, 0.20730443706270307, 0.18760342936730012, 0.11784212663769722, 0.19226591277401894, 0.13284054526593536, 0.19464219541987404, 0.0880696257809177, 0.14314198546344414, 0.1093602915352676, 0.1317556737922132, 0.10546996825723909, 0.14989184826845303, 0.10709200621931814, 0.23427956068189815, 0.6498454639222473, 15.531683675944805, 48.14498595893383, 59.918832778930664, 46.805056259036064, 34.21117544174194, 18.85089486837387, 30.780176147818565, 42.57478125393391, 48.34359370172024, 6.522682970389724, 0.15038423356600106, 1.1861390084959567, 5.094869211316109, 8.351402767002583, 10.261577367782593, 8.48359102383256, 28.81435353308916, 59.82752367854118, 56.80637039244175, 56.13658033311367, 56.106124967336655, 51.86097376048565, 54.96224954724312, 56.63738206028938, 52.8517971932888, 51.44274540245533, 51.623292714357376, 55.03900922834873, 52.99190707504749, 53.04803006350994, 52.88059964776039, 53.354415223002434, 52.53308929502964, 55.181634575128555, 49.09803181886673, 47.56815791130066, 44.35179390013218, 42.86948204040527, 39.18018780648708, 41.15431107580662, 41.731025129556656, 41.64681784808636, 41.33980952203274, 41.87791384756565, 39.19370748102665, 39.67984579503536, 41.311645433306694, 43.114724680781364, 38.13115529716015, 39.542114585638046, 38.25841806828976, 38.17225009202957, 39.11122910678387, 39.03430983424187, 41.212672144174576, 37.929241731762886, 38.03890764713287, 40.338988825678825, 46.47784061729908, 52.10022792220116, 50.137675032019615, 46.63088120520115, 46.08852490782738, 50.081867426633835, 48.60927164554596, 49.62514713406563, 46.59525811672211, 47.07764983177185, 45.119295716285706, 46.96855388581753, 42.86429151892662, 51.34397730231285, 43.86301852762699, 40.93320474028587, 56.923556104302406, 52.37453520298004, 52.612489834427834, 48.264048770070076, 52.174848318099976, 53.812777027487755, 51.98945626616478, 49.57315072417259, 49.441240802407265, 44.76017318665981, 42.45621621608734, 39.965556263923645, 40.98785720765591, 41.344205886125565, 40.8142065256834, 40.832422748208046, 39.6923965215683, 40.084090903401375, 39.20022793114185, 42.69848361611366, 44.38816174864769, 44.070198610424995, 48.69491524994373, 49.87240366637707, 48.81701409816742, 50.66686123609543, 50.25640346109867, 49.741534888744354, 46.95203237235546, 46.279981434345245, 41.56047888100147, 40.029776617884636, 39.751829132437706, 45.37115380167961, 45.10760374367237, 49.03076782822609, 49.06462401151657, 49.12563733756542, 51.05084963142872, 55.33061318099499, 53.95657271146774, 49.90271084010601, 56.80562183260918, 53.49397033452988, 59.37641568481922, 53.4524841606617, 53.99498865008354, 50.58549240231514, 50.88060736656189, 55.73169305920601, 61.830054223537445, 57.99816504120827, 61.24276153743267, 61.74647770822048, 56.95868901908398, 45.208442732691765, 28.7674393504858, 7.439589444547892, 12.854851763695478, 12.788769509643316, 0.8947159023955464, 0.6643700657878071, 0.49950967775657773, 30.240863487124443, 65.91112643480301, 49.67615559697151, 33.89716789126396, 42.74590127170086, 60.992043390870094, 65.96626907587051, 60.315770879387856, 14.749174565076828, 0.6613014929462224, 0.20099523186217993, 0.3104055515723303, 0.15198915760265663, 0.12766364961862564, 0.1373160965158604, 0.1282612417708151, 0.19572126329876482, 0.1484130448079668, 0.17335469863610342, 0.10075492595206015, 0.09951154657755978, 0.11622714650002308, 0.21051753574283794, 0.3294514655135572], [0.07279063080204651, 0.01959304561751196, 0.02076890810712939, 0.06812739782617427, 0.022464520734502003, 0.011293865118204849, 0.11456227919552475, 0.10428665831568651, 0.03341930692840833, 0.03835691932181362, 0.099167657608632, 0.038953309194766916, 0.10221687523880973, 0.023446007326128893, 0.6473710248246789, 8.91318742185831, 39.256586506962776, 48.47095146775246, 30.39598636329174, 20.120079964399338, 15.047507006675005, 23.98586332798004, 36.82990752160549, 38.797582536935806, 2.7150937216356397, 0.12294866668526083, 1.0340172587893903, 3.5186677146703005, 5.010053962469101, 4.625658988952637, 2.5337807508185506, 25.036695040762424, 53.96125786006451, 54.08553019165993, 52.62728624045849, 48.186304941773415, 47.71848924458027, 47.820574566721916, 52.221604809165, 53.50982308387756, 48.37258614599705, 49.097762033343315, 52.17112451791763, 49.54078406095505, 46.30371876060963, 43.764356821775436, 46.251399368047714, 49.38187278807163, 48.85136425495148, 46.74208603799343, 41.529662534594536, 37.352018505334854, 36.773510947823524, 36.17191202938557, 35.68072758615017, 35.45681320130825, 36.69536434113979, 35.44113524258137, 35.85977777838707, 35.03299154341221, 37.06509210169315, 35.27693085372448, 37.112247571349144, 34.705912694334984, 37.3723816126585, 35.79995758831501, 37.20794543623924, 36.24687820672989, 35.93032479286194, 35.196713358163834, 35.81311248242855, 34.834448397159576, 38.20397078990936, 44.34643618762493, 50.44024899601936, 44.3153690546751, 46.024707332253456, 47.36189737915993, 50.84479048848152, 47.45769023895264, 47.68522962927818, 48.0447169393301, 46.118129119277, 45.85814706981182, 48.08406762778759, 39.851839765906334, 46.18268385529518, 40.15574745833874, 33.29143859446049, 54.45536434650421, 48.332828879356384, 48.581210151314735, 47.643933445215225, 47.95157253742218, 49.49119672179222, 50.790719389915466, 49.70385991036892, 50.0518224388361, 46.26847565174103, 41.82609222829342, 33.07744927704334, 36.12610548734665, 35.90988948941231, 35.80727979540825, 37.41426296532154, 37.5467162579298, 37.66900509595871, 37.6517616212368, 37.964750826358795, 38.978988602757454, 37.592218816280365, 44.15017671883106, 45.29500588774681, 47.605688497424126, 49.27545569837093, 47.73598350584507, 46.776322200894356, 46.4562463760376, 43.67033466696739, 39.75776821374893, 38.884225487709045, 36.268613040447235, 35.75623333454132, 38.78254674375057, 39.196507930755615, 39.43288564682007, 42.15159796178341, 47.12325498461723, 52.197734490036964, 50.36940939724445, 45.681775733828545, 49.07513424754143, 56.69893115758896, 55.1507156342268, 51.414547115564346, 51.55961573123932, 50.30886344611645, 47.22052976489067, 49.12499517202377, 51.748085618019104, 56.436433643102646, 54.39102999866009, 51.82424493134022, 56.018608063459396, 51.49763345718384, 24.490153267979622, 5.488296300172806, 5.921834511682391, 2.351129539310932, 1.3024301058612764, 0.08032696234295145, 0.012256794307177188, 21.669140942394733, 49.19609695672989, 38.51989723742008, 35.23145489394665, 37.743416503071785, 52.776063457131386, 52.297558933496475, 48.42057757079601, 10.189829617738724, 0.19617018842836842, 0.044571834660018794, 0.011004274456354324, 0.05781405357993208, 0.07046272134175524, 0.07211667907540686, 0.07266766435350291, 0.005530465932679363, 0.0019617994303189334, 0.13219993823440745, 0.05123693677887786, 0.06645842644502409, 0.040987647298607044, 0.0713257203460671, 0.08053446683334187, 0.07194805570179597, 0.018056432563753333, 0.032406060126959346, 0.03836130170384422, 0.024727197269385215, 0.0256794488086598, 0.06628500879742205, 0.05761587788583711, 0.049529407115187496, 0.053690536369686015, 0.065491326386109, 0.0027200278236705344, 0.06718553820974194, 0.07188386734924279, 0.7756226928904653, 12.737799994647503, 44.15490746498108, 54.053406715393066, 34.66473050415516, 22.563044875860214, 14.949562512338161, 23.663600720465183, 39.321730211377144, 41.92078314721584, 3.2203032122924924, 0.13631346984766424, 1.2971935118548572, 7.617664989084005, 7.54000143148005, 7.947283051908016, 2.977674356661737, 26.38463471084833, 55.73906846344471, 55.994965732097626, 53.2084346562624, 50.917613580822945, 50.22116415202618, 50.314589738845825, 54.373072162270546, 53.42849604785442, 49.167666882276535, 49.85284611582756, 53.250794783234596, 52.12116859853268, 48.63447189331055, 45.644351541996, 48.38724575936794, 52.14916169643402, 48.77716563642025, 48.32069993019104, 44.13765259087086, 40.070320442318916, 38.572475016117096, 38.01424317061901, 37.3919353634119, 37.546932846307755, 37.51676246523857, 38.27606052160263, 37.35256187617779, 37.33678512275219, 38.566976711153984, 36.583999916911125, 37.3298466950655, 36.689003482460976, 38.66477586328983, 36.96058630943298, 36.630562618374825, 35.750096663832664, 37.151814848184586, 36.59025438129902, 37.93373689055443, 36.4932531863451, 40.0381475687027, 45.201188921928406, 53.14222700893879, 46.101326420903206, 45.73126807808876, 50.01288592815399, 53.108549416065216, 49.91420142352581, 49.419486969709396, 49.289537742733955, 48.10769096016884, 48.31283055245876, 50.35107158124447, 43.635213151574135, 46.16633713245392, 41.510754749178886, 35.22836945950985, 55.64168728888035, 50.303612127900124, 49.08273383975029, 50.43525606393814, 50.14010690152645, 51.26688323915005, 52.50815883278847, 50.11305995285511, 52.47247874736786, 47.77436904609203, 42.62572892010212, 35.4529982060194, 38.144864961504936, 37.44060695171356, 37.99812823534012, 39.28316228091717, 39.697898626327515, 37.713265120983124, 38.79767373204231, 39.33343358337879, 40.066847428679466, 41.14951193332672, 46.85077540576458, 47.41999626159668, 50.91130971908569, 51.61837577819824, 50.449330508708954, 48.101873472332954, 48.531018644571304, 45.7593409717083, 42.07599341869354, 39.19562637805939, 38.37810404598713, 39.90765877068043, 41.68318569660187, 41.75536662340164, 41.488921120762825, 43.42694252729416, 48.822094425559044, 53.75747099518776, 53.69502514600754, 45.819571539759636, 49.81576770544052, 59.12762023508549, 56.38699449598789, 53.979880660772324, 54.16322462260723, 53.66059519350529, 50.149063020944595, 50.70224113762379, 53.04734230041504, 58.26168470084667, 54.85520549118519, 55.75110241770744, 58.0492153018713, 49.88103300333023, 22.34184354543686, 10.57646457105875, 9.479661025106907, 3.2121412502601743, 1.7235699389129877, 0.18490707327146083, 0.06392157272784971, 23.984900079667568, 55.940305665135384, 38.764395117759705, 37.28529028594494, 42.97028303146362, 58.364769369363785, 58.49587373435497, 54.58125539124012, 13.216540105640888, 0.13211134064476937, 0.04179253985057585, 0.01152644492321997, 0.012530025251180632, 0.0366308990487596, 0.05565141298575327, 0.027896217943634838, 0.013116705977154197, 0.0403428879508283, 0.010387814127170714, 0.06566688884049654, 0.06234102082089521, 0.03346986573887989, 0.0269642734201625, 0.013398476257862058, 0.1331490560551174, 0.11335688293911517, 0.08219079201808199, 0.11639854550594464, 0.09578645505825989, 0.11067341794841923, 0.1625699273427017, 0.26940420793835074, 0.23476347065297887, 0.1476999744772911, 0.13642971985973418, 0.12363043322693557, 0.19420242839260027, 0.1528740648063831, 0.9264625457581133, 16.807835698127747, 52.340006455779076, 62.35838547348976, 42.74667263031006, 30.0128985196352, 23.275728933513165, 34.139651879668236, 48.08346726000309, 49.38818044960499, 3.9383103093132377, 0.20369932113680989, 1.7696687090210617, 7.664147894829512, 10.307090375572443, 8.955709990113974, 4.589044153690338, 28.06921161711216, 54.82731118798256, 57.2760745882988, 55.63770890235901, 51.138142347335815, 52.5752442330122, 51.749947518110275, 55.8368144184351, 54.27500322461128, 49.548927024006844, 49.571832194924355, 55.71609869599342, 55.9251444786787, 51.372905150055885, 48.24256852269173, 50.15440933406353, 53.68369035422802, 52.644913494586945, 52.296916767954826, 45.10360635817051, 41.754143089056015, 39.74537707865238, 40.229577496647835, 38.39984267950058, 39.617076963186264, 40.00389240682125, 39.25037384033203, 40.55642455816269, 38.74142535030842, 41.569913774728775, 37.97136627137661, 39.61995340883732, 38.300238624215126, 40.983654633164406, 39.55158747732639, 39.63042564690113, 37.812413200736046, 39.500875398516655, 38.70502710342407, 39.74849671125412, 38.52879635989666, 43.13378445804119, 47.59471468627453, 55.25146342813969, 49.61766913533211, 50.281634107232094, 51.29537791013718, 54.63645122945309, 51.31680876016617, 50.58793567121029, 51.54780596494675, 49.86516125500202, 50.91744638979435, 50.48413284122944, 45.85460565984249, 47.83917456865311, 44.183288142085075, 38.265869468450546, 56.788925528526306, 52.82056666910648, 51.93948894739151, 53.03415700793266, 50.379520654678345, 53.51258933544159, 54.46454845368862, 51.62076584994793, 53.87412093579769, 50.70637531578541, 45.46314686536789, 36.37055017054081, 40.046381726861, 39.49150510132313, 38.37774306535721, 41.207827404141426, 41.687350273132324, 40.03872133791447, 41.564244478940964, 41.20118536055088, 43.4482441842556, 42.160846665501595, 48.953818157315254, 49.68761198222637, 53.45525801181793, 55.77235087752342, 52.436099499464035, 51.34648136794567, 52.044367119669914, 48.80777299404144, 44.261552542448044, 42.37564153969288, 39.81749340891838, 41.31258398294449, 42.54219800233841, 43.65852490067482, 43.70862141251564, 45.92202924191952, 50.743005350232124, 57.04972833395004, 53.816508427262306, 47.89648689329624, 51.17847338318825, 59.0032073110342, 59.52304981648922, 56.87671601772308, 56.27174288034439, 55.796209797263145, 51.86512693762779, 52.71203689277172, 54.99590814113617, 59.93140250444412, 57.856501042842865, 59.20994661748409, 57.437980100512505, 48.58524553477764, 29.179396145045757, 11.105410438030958, 9.436923768371344, 7.2515603341162205, 2.6949958875775337, 0.26129381032660604, 0.12017969886073843, 27.452504709362984, 61.393792033195496, 49.394153729081154, 46.061751544475555, 47.995866760611534, 66.49356678128242, 63.44967171549797, 65.03930121660233, 17.85891629755497, 0.5489681800827384, 0.2696736966026947, 0.08950777439167723, 0.08431172391283326, 0.11947347855311818, 0.1366461449651979, 0.15442948759300634, 0.0922151142731309, 0.10323697948479094, 0.11222454369999468, 0.13142348849214613, 0.11250958777964115, 0.1333225701819174, 0.14712338510435075, 0.19261239183833823], [0.0778001721482724, 0.07063218334224075, 0.01237826718352153, 0.05381025592214428, 0.07066825914080255, 0.06830424419604242, 0.037124865120858885, 0.05295435184962116, 0.030903409606253263, 0.03035285662917886, 0.08233989690779708, 0.04301003682485316, 0.02671595080755651, 0.07855372663470916, 0.3419984219362959, 9.291719309985638, 39.823782071471214, 51.85919165611267, 38.948898017406464, 28.818713799118996, 13.360093552619219, 20.938320457935333, 34.26863215863705, 33.13660830259323, 2.3247525421902537, 0.04572560341330245, 4.347834046930075, 9.330945555120707, 6.211601737886667, 6.843255143612623, 5.366749847307801, 24.211694709956646, 54.002314656972885, 53.74248459935188, 55.60558922588825, 53.52770112454891, 49.69351306557655, 50.70818401873112, 53.02419014275074, 53.601451367139816, 49.3127316981554, 49.948798567056656, 50.16171254217625, 46.672424376010895, 44.1770488768816, 40.54979391396046, 39.927755892276764, 41.27742446959019, 43.77699874341488, 42.2225933521986, 39.583163782954216, 36.82173416018486, 36.62437655031681, 36.324815824627876, 35.308594554662704, 35.516131818294525, 36.222228929400444, 36.94783799350262, 35.011241510510445, 35.080450996756554, 35.37120759487152, 35.927250757813454, 37.090398743748665, 35.94846501946449, 37.14788965880871, 34.50643099844456, 36.7350722104311, 37.27147422730923, 35.90923972427845, 35.74479214847088, 36.36469088494778, 36.19705908000469, 36.62965066730976, 43.692031502723694, 49.12914074957371, 48.15860442817211, 52.16637097299099, 46.49731457233429, 47.71218158304691, 45.8913154900074, 49.15287807583809, 46.95960156619549, 48.49970072507858, 46.63333587348461, 46.983069106936455, 45.7058360427618, 45.7926119863987, 43.18894989788532, 33.175996989011765, 49.70297835767269, 50.239608362317085, 50.85696503520012, 50.934651866555214, 50.08939862251282, 54.34918284416199, 53.85604150593281, 52.534601613879204, 49.962990805506706, 49.67244699597359, 42.61452332139015, 35.22303454577923, 35.237120389938354, 35.10193884372711, 37.49021328985691, 35.98942682147026, 36.80631458759308, 37.23764844238758, 37.94540226459503, 35.67139908671379, 37.66529269516468, 37.203815057873726, 40.73429301381111, 41.98064513504505, 46.98772765696049, 49.528149738907814, 49.6878095716238, 47.41841174662113, 45.843890234827995, 43.81110571324825, 41.68143779039383, 38.88356812298298, 37.3313058167696, 36.716665998101234, 36.96215562522411, 39.052719846367836, 39.222962111234665, 37.90589578449726, 47.03000798821449, 51.278655007481575, 52.0159712433815, 46.49330958724022, 50.12804254889488, 49.47755925357342, 57.491283640265465, 53.93934823572636, 55.968682542443275, 52.99077093601227, 53.594889119267464, 50.01191318035126, 53.62652242183685, 53.33021432161331, 57.76176452636719, 52.56173595786095, 46.21210187673569, 49.62904952466488, 39.16616275906563, 16.02375917136669, 9.90934006869793, 1.3303790311329067, 0.7423117803409696, 0.3214517963351682, 0.055408122134394944, 18.684024922549725, 55.54587543010712, 47.70444139838219, 24.818096570670605, 30.917875058948994, 46.160922423005104, 48.55175793170929, 46.7963395267725, 14.43434625864029, 0.3279308939818293, 0.003347107590343512, 0.04296970852010418, 0.01880392555904109, 0.02182329772040248, 0.05660614886437543, 0.05012414199882187, 0.02852361289114924, 0.04601905602612533, 0.07308764572371729, 0.05922833472141065, 0.06384824111592025, 0.020689010343630798, 0.03879710937326308, 0.0775543060444761, 0.04282488953322172, 0.05587278450548183, 0.05138707325386349, 0.03880972959450446, 0.05859022130607627, 0.006882017505631666, 0.00633585386822233, 0.023619886960659642, 0.041626903621363454, 0.0175689176103333, 0.03187142065144144, 0.012236013244546484, 0.05478294064232614, 0.13140983297489583, 0.48234448477160186, 12.935078758746386, 44.94591861963272, 56.770823299884796, 42.988309264183044, 30.725189298391342, 16.4359762519598, 23.212416730821133, 39.93161268532276, 37.738776952028275, 2.5410542730242014, 0.00613967872595822, 3.7872667517513037, 6.065126247704029, 8.873172719031572, 10.273941904306412, 7.774408953264356, 27.783491648733616, 51.460004076361656, 54.15069289505482, 54.74320650100708, 54.60169069468975, 51.022351160645485, 51.892527267336845, 54.15990740060806, 53.73916357755661, 48.92052434384823, 51.05587676167488, 51.595721393823624, 47.95349143445492, 45.49014061689377, 43.1636318564415, 40.85675284266472, 42.69862800836563, 45.84211193025112, 44.57702301442623, 41.21860362589359, 38.56492482125759, 37.559445574879646, 38.89206446707249, 37.56011053919792, 37.38288804888725, 37.40296997129917, 37.22456954419613, 36.35701909661293, 37.51002922654152, 37.54982449114323, 37.55778506398201, 39.255951941013336, 37.4431262165308, 38.44704754650593, 37.67242111265659, 38.91015149652958, 38.94974157214165, 37.434607073664665, 37.192864045500755, 38.14154773950577, 36.8823105096817, 38.38769853115082, 43.78526709973812, 50.96117824316025, 50.72753258049488, 53.71342375874519, 49.181285351514816, 48.529168143868446, 48.457606583833694, 51.51275284588337, 48.37745748460293, 50.81806652247906, 47.52229057252407, 47.695059701800346, 46.16013206541538, 47.219891399145126, 42.538610994815826, 35.13490207493305, 52.129288762807846, 52.57579520344734, 52.44992695748806, 51.83496795594692, 52.18288108706474, 54.97815169394016, 55.40165036916733, 55.85123084485531, 53.87892387807369, 50.682440400123596, 47.6638063788414, 36.357091292738914, 36.95113241672516, 37.97231622040272, 38.38851548731327, 38.60055550932884, 38.73727597296238, 37.701801136136055, 39.07786309719086, 37.19841554760933, 39.445101991295815, 40.28641864657402, 43.38400483131409, 45.724052265286446, 48.70859831571579, 50.57797260582447, 51.777499839663506, 48.87122578918934, 48.085545748472214, 46.896023377776146, 42.4639867991209, 40.916003063321114, 39.289705529809, 38.86825114488602, 38.06730352342129, 40.55045887827873, 40.85980407893658, 40.62641300261021, 50.959160551428795, 53.17163743078709, 54.75588262081146, 48.23117293417454, 50.24647079408169, 52.54082567989826, 58.49781543016434, 56.27265103161335, 57.64861419796944, 56.58991880714893, 55.78895978629589, 52.663752883672714, 54.616889879107475, 55.86204506456852, 60.731658563017845, 53.41977171599865, 51.43010728061199, 51.787994876503944, 35.90248368680477, 13.962241541594267, 9.04870430007577, 3.9901891630142927, 0.8121197938453406, 0.3445809177355841, 0.054793148883618414, 20.445479303598404, 57.300332486629486, 44.810930863022804, 33.34145151078701, 37.30906181037426, 54.41113471984863, 53.804022297263145, 54.91585023701191, 17.43092816323042, 0.43618007912300527, 0.058793150456040166, 0.03625005112553481, 0.04893536985036917, 0.011072777469962602, 0.005897010814805981, 0.042748567066155374, 0.06970104775973596, 0.02519325673347339, 0.05663338197336998, 0.04150373308220878, 0.03907843529304955, 0.052866403639200144, 0.08935676960390992, 0.04388422370539047, 0.11124448574264534, 0.1023952652758453, 0.08586697600549087, 0.13703471864573658, 0.23605338268680498, 0.1439919523545541, 0.09034780392539687, 0.2644496300490573, 0.1358019668259658, 0.04794833199412096, 0.11672086766338907, 0.14630967954872176, 0.0729792179481592, 0.22784809407312423, 0.7186977099627256, 17.51135654747486, 52.31622353196144, 63.71473789215088, 49.917302057147026, 40.35802200436592, 21.686471812427044, 29.16258964687586, 47.61899158358574, 42.49422177672386, 3.046503863297403, 0.21424984093755484, 5.705345403403044, 15.121350344270468, 12.253005858510733, 11.31461676210165, 8.542624656111002, 28.21488820016384, 55.12129761278629, 55.340146869421005, 56.499236673116684, 59.17981043457985, 53.7786852568388, 54.87698212265968, 57.27772369980812, 54.130238592624664, 49.38165619969368, 52.25286953151226, 54.54109154641628, 48.95112790167332, 47.37935744225979, 45.67788854241371, 42.789511531591415, 46.6290383040905, 47.6900477707386, 47.69561067223549, 43.98999251425266, 40.35409301519394, 39.5888976752758, 39.99535046517849, 39.41568396985531, 39.93963025510311, 40.676714703440666, 40.01617714762688, 37.452572509646416, 39.10039208829403, 39.32358071208, 38.64771097898483, 40.20664192736149, 38.86662483215332, 41.12067148089409, 38.36976729333401, 42.68383540213108, 39.73094545304775, 39.23283778131008, 39.19900439679623, 40.41611708700657, 39.023408219218254, 39.51632916927338, 46.59616246819496, 54.11780185997486, 52.5248209387064, 55.241496562957764, 51.73065595328808, 51.61086358129978, 50.50812095403671, 55.47004669904709, 50.56301660835743, 53.310820162296295, 48.50405529141426, 50.228820741176605, 47.36718289554119, 48.19991581141949, 46.385824754834175, 38.898022547364235, 53.54400224983692, 54.0283090621233, 52.201199904084206, 54.24550540745258, 52.33424976468086, 56.622110679745674, 56.987252086400986, 56.77024573087692, 54.60056975483894, 52.565816938877106, 49.67449888586998, 39.5775780826807, 39.39354255795479, 39.00670811533928, 41.01369962096214, 39.98141661286354, 41.12454727292061, 39.46345120668411, 42.0915649831295, 39.25891578197479, 41.63679018616676, 41.094103306531906, 45.63566140830517, 47.80979074537754, 50.40823191404343, 53.17580960690975, 54.19087953865528, 50.46302877366543, 49.647809118032455, 47.720347344875336, 45.962861850857735, 42.96217426657677, 40.919339284300804, 40.83885960280895, 41.68579235672951, 43.4822903573513, 43.908581882715225, 41.77258349955082, 53.390509486198425, 55.53343869745731, 56.811614111065865, 51.747219264507294, 51.29443556070328, 50.91134011745453, 60.36231458187103, 54.94822829961777, 58.862215876579285, 60.12867271900177, 59.94568593800068, 54.05255176126957, 59.40499395132065, 58.628182634711266, 65.0799286365509, 54.86655168235302, 56.9401840120554, 53.09788338840008, 38.416098207235336, 18.727612383663654, 17.212422788143158, 5.845086704939604, 1.5326756634749472, 0.8268039871472865, 0.19406722392886877, 23.179645389318466, 66.82889878749847, 57.570133209228516, 36.89248636364937, 43.01057226955891, 61.62997215986252, 62.66641214489937, 62.56298169493675, 22.136703953146935, 0.7630328403320163, 0.1039500795013737, 0.20383685594424605, 0.10289847108651884, 0.12838103924877942, 0.14687473594676703, 0.15118076582439244, 0.20020784286316484, 0.2221224395907484, 0.10971947616781108, 0.12197700983961113, 0.13540809421101585, 0.1477320649428293, 0.10489983556908555, 0.1709239126648754], [0.045213662524474785, 0.018484171232557856, 0.1070563608664088, 0.016562728633289225, 0.06677924204268493, 0.030256256832217332, 0.04615567057044245, 0.08176727060345002, 0.07676381486817263, 0.12912783276988193, 0.0149434301238216, 0.02452786753565306, 0.04279876593500376, 0.02164413956052158, 0.2746538637438789, 7.452884456142783, 37.251817882061005, 46.14317737519741, 36.01552002131939, 17.764251977205276, 9.859538041055202, 22.956409268081188, 37.4260613322258, 29.26815938204527, 1.9822807190939784, 0.10769895685371011, 11.154152322560549, 6.436349228024483, 9.355974812060595, 15.085407122969627, 2.8664968349039555, 25.010191462934017, 34.889929220080376, 43.67622435092926, 53.88661086559296, 53.27323257923126, 50.692711248993874, 52.06199437379837, 54.28362876176834, 50.56259103119373, 45.715536922216415, 48.97844843566418, 51.20956711471081, 48.18114101886749, 46.151088550686836, 41.40468344092369, 38.13858389854431, 36.30362816154957, 36.41578294336796, 35.4215282946825, 34.84541840851307, 36.20167963206768, 35.80471113324165, 36.12063378095627, 35.0885521620512, 36.50318965315819, 35.7578444480896, 34.28588703274727, 36.805410236120224, 37.862190529704094, 40.289363488554955, 40.51865078508854, 39.42003473639488, 37.10002362728119, 36.58050790429115, 36.92949257791042, 35.2208686619997, 34.33540977537632, 34.721966832876205, 35.70915766060352, 36.36037811636925, 33.8834810256958, 34.9171357601881, 39.27424035966396, 43.57912816107273, 46.81715860962868, 44.33821722865105, 44.657992869615555, 45.168533474206924, 46.67862184345722, 47.03041836619377, 48.93735744059086, 47.90479704737663, 47.789351642131805, 48.22928063571453, 45.96349261701107, 45.26954345405102, 40.4633903503418, 33.08549344539642, 47.329371124506, 46.3487995415926, 49.46263365447521, 48.35356816649437, 47.788553684949875, 43.84996622800827, 45.24591252207756, 44.760921746492386, 48.61184410750866, 49.476005136966705, 46.14877447485924, 35.38372032344341, 36.51127941906452, 34.89093616604805, 35.58406077325344, 34.69256781041622, 36.356319934129715, 36.98309250175953, 37.44412936270237, 37.066859006881714, 35.85384249687195, 35.86315959692001, 37.24879704415798, 38.08323226869106, 40.227776393294334, 43.46294939517975, 47.4336489289999, 48.81393626332283, 48.220803290605545, 46.48964278399944, 44.46412727236748, 40.6432119011879, 38.341834992170334, 35.19430048763752, 36.05039454996586, 35.74331782758236, 38.63348074257374, 38.552039712667465, 43.21624383330345, 47.4975311011076, 52.00399808585644, 47.43589460849762, 53.75547610223293, 53.71383033692837, 46.771355867385864, 39.050523564219475, 50.46242080628872, 53.91393519937992, 51.693068370223045, 52.492309883236885, 49.05542850494385, 54.10493955016136, 51.165041103959084, 63.571588173508644, 50.70637911558151, 47.17114381492138, 36.7744342982769, 22.640418224036694, 14.461675342172384, 1.5985167492181063, 1.6574708232656121, 0.16967771312920377, 0.04260975947545376, 12.703168652951717, 49.1215031594038, 38.62361267209053, 27.05699533224106, 26.85322366654873, 38.53970177471638, 48.897797763347626, 46.22432582080364, 18.961928710341454, 0.37757335987407714, 0.043876290146727115, 0.032042381790233776, 0.038536945794476196, 0.06536795175634325, 0.02202368872531224, 0.02521830978366779, 0.03702378089656122, 0.021825978728884365, 0.03679601948533673, 0.032374374131904915, 0.024539411642763298, 0.025620423948566895, 0.022167368515511043, 0.041688505589263514, 0.04192296488326974, 0.07186920251115225, 0.12383882829453796, 0.00937433447688818, 0.06257043351070024, 0.05870482375030406, 0.058303833939135075, 0.10247002181131393, 0.058052112290170044, 0.02776687644654885, 0.056543582104495727, 0.07395652995910496, 0.07219257109682076, 0.025837927023530938, 0.44446514861192554, 11.495138425379992, 44.25173006951809, 52.915949150919914, 42.10692755877972, 23.949286490678787, 11.121624168008566, 21.684511117637157, 41.99305906891823, 35.02851538360119, 1.6731718182563782, 0.16907670709770173, 13.593832310289145, 6.987242717295885, 7.419301858171821, 6.47985546849668, 5.274371104314923, 24.616946764290333, 36.97838455438614, 45.20103693008423, 55.14817737042904, 56.11318878829479, 53.02857890725136, 53.91735501587391, 54.64931733906269, 50.172507762908936, 47.27164842188358, 49.391813054680824, 52.20169007778168, 50.50194628536701, 47.531778663396835, 42.13781610131264, 39.64116007089615, 38.56644853949547, 37.796359062194824, 37.47927367687225, 36.709985956549644, 38.173899203538895, 36.46419994533062, 36.775046065449715, 38.023602068424225, 38.095839992165565, 36.70632675290108, 36.39311335980892, 37.440093979239464, 38.794846683740616, 41.75673075020313, 42.02554352581501, 40.54196633398533, 38.34447205066681, 38.3550126850605, 37.599370032548904, 37.37044371664524, 36.25142656266689, 35.987287536263466, 37.830044254660606, 37.94525407254696, 35.26591144502163, 37.014885395765305, 40.14424927532673, 45.27319885790348, 47.53193825483322, 47.615351378917694, 46.13160319626331, 47.593510150909424, 48.44821348786354, 48.4065905213356, 50.289199501276016, 50.14044128358364, 49.23514366149902, 48.705600276589394, 47.70564213395119, 46.57281652092934, 42.1218341588974, 35.618004351854324, 46.119041070342064, 48.024737611413, 50.28049036860466, 49.90393437445164, 48.688683584332466, 46.37746140360832, 47.18268379569054, 46.685047298669815, 51.161191910505295, 51.8441216647625, 47.99784645438194, 37.14060924947262, 37.74487562477589, 37.57491834461689, 37.05585099756718, 36.016089990735054, 37.55626894533634, 37.56137207150459, 38.68622571229935, 39.21459876000881, 38.29657942056656, 39.13722351193428, 40.16355603933334, 40.78972063958645, 42.05845735967159, 45.393830984830856, 48.08915935456753, 49.88765984773636, 49.135828390717506, 48.47273737192154, 47.68860764801502, 40.73267050087452, 39.857406467199326, 37.435944601893425, 38.421524316072464, 36.66780062019825, 39.694714397192, 39.87917549908161, 46.75047218799591, 50.07681369781494, 54.738392159342766, 49.40909452736378, 55.36977007985115, 53.9903225004673, 50.35550594329834, 41.13196827471256, 50.69557249546051, 57.01858900487423, 54.94527205824852, 54.96517539024353, 52.181391566991806, 55.596424117684364, 54.872429966926575, 62.64527007937431, 53.91141973435879, 50.19887074828148, 36.83280676603317, 17.179457657039165, 7.3258900456130505, 3.032233016565442, 1.114711391273886, 0.1721297245239839, 0.0757197466737125, 14.233110956847668, 55.439481139183044, 41.962888687849045, 27.966030053794384, 31.664595790207386, 45.184363424777985, 57.998849004507065, 54.47262682020664, 22.449904046952724, 0.7043296121992171, 0.011560439925233368, 0.06003847054671496, 0.04309683841711376, 0.022574610920855775, 0.04727735256892629, 0.04555198167508934, 0.1116958748025354, 0.0661815756757278, 0.03307949606096372, 0.007891926961747231, 0.03297832277894486, 0.04148799584072549, 0.019286828064650763, 0.03923761483747512, 0.08335890277521685, 0.18125952134141698, 0.27700285019818693, 0.22901130665559322, 0.15506823925534263, 0.09576395314070396, 0.17445640201913193, 0.23718459386145696, 0.25697403587400913, 0.1528439187677577, 0.11728639161447063, 0.19866923714289442, 0.23933290358399972, 0.11900271201739088, 0.6170118413865566, 14.689653608947992, 49.61084470152855, 58.10932047665119, 48.306845873594284, 28.483250699937344, 16.584003008902073, 33.67179058492184, 49.78298306465149, 39.00281712412834, 2.3837170656770468, 0.2304825105238706, 15.863829553127289, 12.774235289543867, 17.769877575337887, 21.160942912101746, 5.426956666633487, 27.545622512698174, 39.080245569348335, 48.84773164987564, 55.25797247886658, 57.35937371850014, 53.754621148109436, 55.7807332277298, 56.61991439759731, 50.8800145983696, 46.366780176758766, 50.46381913125515, 52.920881286263466, 52.18394882977009, 50.09415976703167, 45.21140657365322, 41.30844600498676, 40.66598027944565, 38.9202019572258, 40.43896526098251, 37.84007951617241, 39.69079680740833, 38.013939186930656, 38.89529809355736, 38.9568167924881, 38.9360661059618, 40.04305310547352, 37.89282828569412, 39.70868244767189, 42.23652720451355, 42.72557616233826, 44.839486330747604, 42.66157619655132, 41.0390442609787, 40.92539615929127, 40.74717812240124, 38.21262672543526, 36.8599297106266, 39.21111434698105, 39.066912084817886, 40.76151095330715, 37.133112251758575, 38.84603753685951, 43.85577231645584, 47.25869111716747, 50.23883320391178, 50.0718929618597, 47.50545747578144, 49.18396420776844, 52.87855915725231, 49.597720205783844, 53.15859653055668, 51.71680569648743, 51.943687722086906, 50.83001308143139, 49.61008474230766, 46.21119372546673, 43.51043164730072, 38.59684310853481, 48.16849149763584, 46.039883717894554, 49.57486443221569, 49.75870996713638, 49.30965766310692, 46.30538307130337, 46.064358204603195, 49.03987593948841, 55.02931594848633, 52.57259577512741, 50.443174839019775, 39.92829546332359, 40.636778846383095, 39.15804639458656, 37.92646788060665, 38.286517560482025, 40.014653429389, 40.641323402523994, 39.97338004410267, 41.103295013308525, 40.23861721158028, 40.79174593091011, 41.020896434783936, 42.77071014046669, 44.27181199193001, 48.487792164087296, 50.79519934952259, 52.807157188653946, 51.35444954037666, 51.61963351070881, 50.47986567020416, 44.00237984955311, 42.38793767988682, 38.70569206774235, 40.339528396725655, 38.48771296441555, 42.37084239721298, 42.63631135225296, 48.26011598110199, 52.99396276473999, 56.85759164392948, 52.43653267621994, 57.94337198138237, 57.639479488134384, 50.168175995349884, 44.64213252067566, 51.191890463232994, 58.52632910013199, 56.384167447686195, 58.093091547489166, 55.50902880728245, 59.07316155731678, 56.77956283092499, 69.21214610338211, 54.42095339298248, 56.10849604010582, 36.45899422466755, 24.162054173648357, 20.809461772441864, 5.424872478470206, 3.8951391633599997, 0.33277976035606116, 0.14553205721313134, 15.196108482778072, 63.253153860569, 51.590527072548866, 38.103652372956276, 37.949950620532036, 53.30306097865105, 64.34901505708694, 62.2071497887373, 28.243474066257477, 1.3359191338531673, 0.15942718426231295, 0.10743708262452856, 0.18884864926803857, 0.1301293313736096, 0.12909749377286062, 0.12201990597532131, 0.18662876682356, 0.18360614776611328, 0.17938948731170967, 0.1272184945992194, 0.11763426591642201, 0.152280020120088, 0.13434519030852243, 0.12293925625272095], [0.021664194246113766, 0.008254064414359163, 0.019196399225620553, 0.0767027583788149, 0.04210660932585597, 0.07855107716750354, 0.05286543513648212, 0.05514075972314458, 0.05163430862012319, 0.040549401674070396, 0.035344723728485405, 0.06862766473204829, 0.022317304610623978, 0.08967466113972478, 0.1130531812668778, 10.875483825802803, 40.79918213188648, 44.8504563421011, 36.16063803434372, 23.306117802858353, 22.61039413511753, 26.936313807964325, 38.744225800037384, 28.522751480340958, 1.3199447910301387, 0.1969824542175047, 17.98731330782175, 6.902544312179089, 3.3169070910662413, 5.729573853313923, 4.926650812849402, 16.556745171546936, 17.932309359312057, 22.291161864995956, 44.83725965023041, 52.796882539987564, 53.3976075053215, 52.507710456848145, 53.04966397583485, 49.73824426531792, 48.73257502913475, 47.47434854507446, 51.59734770655632, 50.891562178730965, 46.36958822607994, 43.08117628097534, 41.392037719488144, 38.33339564502239, 36.47270008921623, 37.94322118163109, 37.840273305773735, 37.45376944541931, 37.1774672716856, 36.93206124007702, 35.83488531410694, 34.1401382535696, 35.981739833950996, 37.97498747706413, 42.90205769240856, 44.306059554219246, 46.58906064927578, 43.38629990816116, 40.83792105317116, 38.67176368832588, 36.40173129737377, 35.18025264143944, 36.106825321912766, 35.869360864162445, 33.54616552591324, 35.856840535998344, 38.80401559174061, 34.86394241452217, 32.60918140411377, 35.05126856267452, 37.041898146271706, 38.60191963613033, 41.64686344563961, 42.45490908622742, 45.76439090073109, 46.846303045749664, 46.6766307502985, 47.897208854556084, 47.71064266562462, 48.61038878560066, 49.30920548737049, 47.271830812096596, 45.25592498481274, 44.89092417061329, 31.058877892792225, 41.65572077035904, 42.593464851379395, 41.298912316560745, 41.87254473567009, 46.84195227921009, 47.16663345694542, 48.92864070832729, 46.26179561018944, 50.1235131919384, 48.33569012582302, 45.47384329140186, 36.96709156036377, 36.093328446149826, 36.29755228757858, 36.366849169135094, 36.47046960890293, 35.48329398036003, 36.396536976099014, 37.777090296149254, 36.95217736065388, 36.85372844338417, 35.29295079410076, 36.73214256763458, 37.122469022870064, 36.6565266251564, 37.84953720867634, 37.07726664841175, 40.55958218872547, 43.12572509050369, 45.15713408589363, 42.87783779203892, 39.26434949040413, 40.08134365081787, 37.27160342037678, 36.88343144953251, 37.14417725801468, 37.855810672044754, 38.551541939377785, 38.51366937160492, 41.133529990911484, 44.65722531080246, 47.27077826857567, 45.89189685881138, 52.53466621041298, 50.359875708818436, 52.4330710619688, 46.7961685359478, 47.35350742936134, 59.11726199090481, 51.47843688726425, 49.738996624946594, 50.64836382865906, 53.82091239094734, 56.29173740744591, 59.71227966248989, 47.89603851735592, 37.71446965634823, 21.498640291392803, 5.735566131770611, 4.358541872352362, 0.9680834342725575, 0.3710548096569255, 0.021909017632424366, 8.789415713399649, 47.05315634608269, 37.31026254594326, 28.222945667803288, 25.200618244707584, 40.637603402137756, 53.1876003742218, 47.41987846791744, 19.09347765147686, 0.41888204170390964, 0.0408796982083004, 0.06695798831060529, 0.010765772312879562, 0.03856990828353446, 0.024552356553613208, 0.03206420464266557, 0.0808061077259481, 0.035224744424340315, 0.04955962736858055, 0.09266365348594263, 0.08579830508097075, 0.11870755246491171, 0.03676509790238924, 0.014775719591852976, 0.0683370248589199, 0.039538054770673625, 0.05846744039445184, 0.051260785694466904, 0.029522601180360653, 0.024576018076913897, 0.09090471154195257, 0.024040959287958685, 0.08621179265901446, 0.07836813776521012, 0.08033265461563133, 0.0321318773785606, 0.08615778657258488, 0.06528848258312792, 0.14863957796478644, 12.5576326623559, 46.78925670683384, 50.542440712451935, 40.92657409608364, 26.034641191363335, 21.525069773197174, 31.16936646401882, 43.45830984413624, 32.85585656762123, 1.3708747643977404, 0.08790844614850357, 16.28716103732586, 5.394755294546485, 6.015570731833577, 7.444604700431228, 5.336493020877242, 17.8257991746068, 17.79121533036232, 23.546620197594166, 48.77611309289932, 56.16933077573776, 56.01662456989288, 54.85789194703102, 55.43059341609478, 50.69608926773071, 47.650313302874565, 48.80433797836304, 52.62307606637478, 52.11177550256252, 48.460882008075714, 44.32679884135723, 43.05999621748924, 40.00010021030903, 38.093902096152306, 39.379304721951485, 40.093316808342934, 39.185606315732, 38.28669235110283, 39.24243986606598, 37.71458365023136, 36.66190713644028, 38.3042474091053, 39.704039096832275, 44.38821494579315, 46.57627813518047, 47.933808490633965, 44.67772901058197, 41.15919001400471, 39.450083523988724, 38.8765574991703, 38.03232640028, 37.456121519207954, 36.818154752254486, 35.99445395171642, 37.15526506304741, 40.60917712748051, 35.709742829203606, 34.772944897413254, 36.74625501036644, 39.72606271505356, 40.92829540371895, 43.49657379090786, 43.01306873559952, 47.0355898886919, 47.95670606195927, 49.318100810050964, 49.63397026062012, 49.95616637170315, 50.15736557543278, 50.9979222714901, 49.509815722703934, 47.915542870759964, 44.73028399050236, 34.397240057587624, 41.99416100978851, 43.3710703253746, 41.841154620051384, 42.72152557969093, 46.85717046260834, 47.40516945719719, 49.24811236560345, 49.3761844933033, 51.16303861141205, 49.43617947399616, 46.53807118535042, 38.999648094177246, 38.394564762711525, 37.560688108205795, 37.926916256546974, 38.050493225455284, 37.46917001903057, 37.67173334956169, 39.402339085936546, 39.65163230895996, 37.62959361076355, 37.530023753643036, 39.0177883207798, 39.45237100124359, 38.13932865858078, 39.94571752846241, 39.32157441973686, 42.86781772971153, 45.61525270342827, 47.10466258227825, 44.160743951797485, 41.6449673473835, 41.28080628812313, 38.07316280901432, 38.4029471129179, 38.85038450360298, 39.754743576049805, 40.25383539497852, 41.42654366791248, 45.242914482951164, 46.86532482504845, 48.249263763427734, 47.60353401303291, 54.50647160410881, 50.9856603294611, 51.6517797857523, 48.737560361623764, 51.10783897340298, 59.7693146020174, 54.51494514942169, 50.68868346512318, 53.026158437132835, 54.180943071842194, 59.119112491607666, 60.38753002882004, 52.20436133444309, 36.91474936902523, 20.68333514034748, 5.878437990322709, 3.337594368495047, 1.1664173542521894, 0.20621181756723672, 0.008110855887935031, 10.501618087291718, 51.0970513522625, 46.53776340186596, 33.13951134681702, 28.910457976162434, 43.25716383755207, 56.76794305443764, 55.952218025922775, 24.244813732802868, 0.5721443833317608, 0.07023553509498015, 0.027465291750559118, 0.03897243062965572, 0.03804416715865955, 0.035543482008506544, 0.05398629335104488, 0.05900677395402454, 0.024980321577459108, 0.06595703147468157, 0.07759889427688904, 0.040672935865586624, 0.03691635873110499, 0.02216034223238239, 0.01592329419509042, 0.13631689856993034, 0.2640609524678439, 0.11303588922601193, 0.17748384503647685, 0.09180651744827628, 0.20692613470600918, 0.19302677741507068, 0.2187486956245266, 0.20410894212545827, 0.22612586617469788, 0.13109885825542733, 0.10698201251216233, 0.10096239333506674, 0.18828415690222755, 0.32311459304764867, 15.688756797462702, 54.01035502552986, 58.424391970038414, 48.09735171496868, 34.61689107120037, 32.08336941897869, 38.46668489277363, 49.50566254556179, 38.94724130630493, 1.3786553218960762, 0.5653725529555231, 20.470331870019436, 14.700770862400532, 10.767011046409607, 13.977416027337313, 9.673620667308569, 18.352207727730274, 19.137650281190872, 25.23433193564415, 50.76382823288441, 56.44229292869568, 56.305173486471176, 56.31115436553955, 55.98371833562851, 51.37584999203682, 50.32569654285908, 50.66462695598602, 56.0360187292099, 55.29491789638996, 50.97539708018303, 47.865172773599625, 47.04701967537403, 41.42408899962902, 40.353257060050964, 42.0022963732481, 42.118752524256706, 40.41792958974838, 39.475990533828735, 41.296210661530495, 40.8062307536602, 36.637877225875854, 40.31539969146252, 41.893652603030205, 46.26336872577667, 48.56365129351616, 51.145027577877045, 47.93005049228668, 43.3670387417078, 41.66036792099476, 40.755750462412834, 40.61765447258949, 39.14687119424343, 40.4837154597044, 37.553905472159386, 40.13857237994671, 43.57530936598778, 37.81903624534607, 36.633830443024635, 39.22546997666359, 40.62308818101883, 43.27626921236515, 46.220940202474594, 47.476142048835754, 50.566151440143585, 49.706960543990135, 50.79168073832989, 51.90381646156311, 50.131036788225174, 52.17299401760101, 52.06719629466534, 51.2628972530365, 49.47532497346401, 46.18540070950985, 37.433482334017754, 42.08800457417965, 42.170254960656166, 42.44037106633186, 42.18724384903908, 48.3447640389204, 49.889586344361305, 53.048444241285324, 48.870511427521706, 53.78050155937672, 51.55257470905781, 49.61252421140671, 42.463568821549416, 42.03845143318176, 39.85457941889763, 40.156534016132355, 41.03386513888836, 39.72021482884884, 40.92332147061825, 40.646802708506584, 41.15186020731926, 39.503584653139114, 39.47179935872555, 41.64628207683563, 40.693581998348236, 39.93334539234638, 42.04679198563099, 41.34198300540447, 44.42858397960663, 47.867479249835014, 50.340907126665115, 46.67197600007057, 43.19682687520981, 43.39772209525108, 40.16845777630806, 41.26672804355621, 42.057370617985725, 42.541122660040855, 42.63813905417919, 43.389370143413544, 46.3262515515089, 48.86071175336838, 51.88039071857929, 52.7741863578558, 57.29694686830044, 53.132807314395905, 55.011331513524055, 51.0488623380661, 52.03527420759201, 63.06373402476311, 57.15152107179165, 54.80018824338913, 54.434944242239, 57.72642642259598, 62.38810367882252, 65.28549000620842, 53.8231048732996, 45.187809839844704, 20.943022705614567, 10.197156574577093, 11.675565093755722, 1.7493050079792738, 0.9672535350546241, 0.1424757149652578, 11.811424903571606, 56.08442433178425, 51.44399553537369, 38.5177693516016, 37.31936305761337, 53.4569451212883, 66.63520038127899, 63.37120212614536, 29.37758021056652, 1.1402445961721241, 0.19017226964933798, 0.19811390287941322, 0.23320162086747587, 0.15295439487090334, 0.11500410197186284, 0.16699713509296998, 0.18673872342333198, 0.11056081930291839, 0.15004955464974046, 0.1725400282884948, 0.15414313733344898, 0.23859072622144595, 0.09969760300009511, 0.09905246886773966], [0.06485844511189498, 0.025115123426076025, 0.05392048340581823, 0.031718720056232996, 0.045262788989930414, 0.06142135141999461, 0.10579833149677143, 0.031979826162569225, 0.040281890833284706, 0.06893238314660266, 0.010198424533882644, 0.02694235779927112, 0.022610234009334818, 0.03822667240456212, 0.06255064785364084, 10.302895400673151, 43.79746064543724, 48.73790994286537, 43.130547031760216, 24.588189907371998, 17.99290470778942, 24.748079627752304, 40.836803913116455, 25.057799108326435, 1.1105242534540594, 0.2926526666851714, 13.225973099470139, 8.151521142572165, 3.9714749297127128, 3.873454676941037, 1.5733213699422777, 15.329144094139338, 36.58961221575737, 38.876086324453354, 48.66515904664993, 52.21471957862377, 53.22112217545509, 52.003249526023865, 50.29873698949814, 47.27298215031624, 47.23537936806679, 47.13863655924797, 49.64972421526909, 48.19727495312691, 45.309065133333206, 43.12335021793842, 39.732757955789566, 37.592123821377754, 35.93734301626682, 36.92919239401817, 38.063218742609024, 37.319211065769196, 35.72245314717293, 33.53231146931648, 33.60069639980793, 35.187977626919746, 35.02137556672096, 37.83153377473354, 43.02776634693146, 47.375933825969696, 48.70031476020813, 42.30734020471573, 39.00158978998661, 36.95889160037041, 36.94237008690834, 35.63020169734955, 36.21892310678959, 35.87168633937836, 34.517936781048775, 36.45092345774174, 36.137360483407974, 33.51256012916565, 36.119961217045784, 35.89619502425194, 36.08717657625675, 36.2258805334568, 38.79970282316208, 42.23443351686001, 43.57465200126171, 46.43852412700653, 48.14269848167896, 44.58534836769104, 46.22886277735233, 46.22028283774853, 47.40339495241642, 46.186631843447685, 47.41561509668827, 43.76146897673607, 31.70099213719368, 42.49251566827297, 43.115849420428276, 47.41440676152706, 49.06137138605118, 48.21952275931835, 49.36227723956108, 49.768049865961075, 51.46207496523857, 46.76510140299797, 46.67992137372494, 39.02857594192028, 35.03805287182331, 37.62126445770264, 35.12187637388706, 36.27795673906803, 35.7117947191, 35.785237178206444, 37.043140679597855, 37.14743748307228, 37.05179661512375, 37.164935544133186, 38.75241816043854, 35.072596818208694, 36.10946998000145, 35.90831257402897, 37.87923641502857, 38.06536942720413, 37.03269883990288, 38.93841817975044, 40.090710148215294, 42.666379138827324, 39.88852679729462, 39.34762202203274, 36.104800030589104, 38.945212215185165, 37.040097042918205, 38.28252777457237, 39.15734723210335, 39.940481409430504, 41.73725679516792, 41.87148459255695, 43.5832167416811, 47.00438596308231, 48.74760702252388, 54.41292442381382, 53.264333456754684, 46.58203102648258, 53.94448556005955, 53.296669721603394, 54.94407132267952, 48.53543020784855, 47.1187674254179, 52.93845534324646, 54.36183996498585, 57.262000143527985, 61.87168098986149, 34.54974107444286, 16.91576700657606, 6.481639472767711, 1.0685921972617507, 0.9946714981924742, 0.03439068175794091, 0.014779532375541748, 5.283134859055281, 41.09884925186634, 38.80995087325573, 26.46171547472477, 25.542964674532413, 44.63606804609299, 56.81786097586155, 51.00001975893974, 20.16234129667282, 1.099695428274572, 0.05016549075662624, 0.015331768172472948, 0.08635099729872309, 0.03841250989353284, 0.05574656373937614, 0.03221338745788671, 0.0007545773746642226, 0.012103020380891394, 0.032885468972381204, 0.04498958958720323, 0.04084712163603399, 0.035908503632526845, 0.022301224125840236, 0.036706060054712, 0.06347497794195078, 0.05937709822319448, 0.08215094610932283, 0.013466324326145696, 0.040283898342750035, 0.0496147466765251, 0.1079723121074494, 0.042799073926289566, 0.012963438566657715, 0.03137112034892198, 0.022090986676630564, 0.03501470178889576, 0.04161464334174525, 0.05033861154515762, 0.1294647975009866, 13.100481983274221, 49.04000513255596, 54.72220882773399, 48.33413600921631, 27.594442293047905, 20.76492816209793, 25.48321098089218, 43.22581171989441, 29.10021409392357, 1.226576913613826, 0.15199660876533017, 11.333049573004246, 7.289839955046773, 3.6969814589247108, 5.225542774423957, 4.526129979640245, 19.622802548110485, 38.245168179273605, 43.14149424433708, 50.90028651058674, 52.92635679244995, 54.18164603412151, 51.12203501164913, 51.147660836577415, 48.0901663005352, 48.71503137052059, 48.106737211346626, 50.240877494215965, 49.84792537987232, 47.695504277944565, 44.79344040155411, 43.13808582723141, 39.30545188486576, 37.356452867388725, 39.35197278857231, 39.56507295370102, 39.265641421079636, 36.890468671917915, 36.255560740828514, 36.05419434607029, 37.006905823946, 37.714260667562485, 39.36648041009903, 43.77945341169834, 48.912890553474426, 49.44469101727009, 45.06562739610672, 40.79575851559639, 39.0293624997139, 39.087936356663704, 37.840470895171165, 37.491151839494705, 36.86673894524574, 37.033356204628944, 37.33759067952633, 39.655477702617645, 35.46785540878773, 37.58908398449421, 36.81472733616829, 37.21057869493961, 38.80946829915047, 40.68168483674526, 44.467949867248535, 45.637185126543045, 47.77216896414757, 49.88759525120258, 46.42001152038574, 48.40399146080017, 47.785817831754684, 48.639966398477554, 48.17690424621105, 49.01769272983074, 43.901841044425964, 32.29297377169132, 42.6773339509964, 43.449019342660904, 47.57918871939182, 50.385155752301216, 51.340352296829224, 52.69168138504028, 52.597921416163445, 54.062127247452736, 49.371928721666336, 48.29192027449608, 41.302214339375496, 36.97888992726803, 37.583832666277885, 36.95416085422039, 38.45984525978565, 37.94296659529209, 38.087529838085175, 39.76660653948784, 39.168853014707565, 37.843753919005394, 38.92255023121834, 39.23093028366566, 36.40242666006088, 38.73645901679993, 39.331799671053886, 39.55240823328495, 39.16966237127781, 39.299102425575256, 41.02251514792442, 43.525596633553505, 45.24139076471329, 40.73014743626118, 40.96220098435879, 37.42626652121544, 39.40071277320385, 39.31145936250687, 40.519220754504204, 41.06810510158539, 42.643834948539734, 44.58713047206402, 44.88448351621628, 45.9383949637413, 49.0792266279459, 52.100604102015495, 56.67107105255127, 56.96864068508148, 48.85110206902027, 54.870492070913315, 56.1282853782177, 57.33952738344669, 51.48315243422985, 49.04193922877312, 54.11696970462799, 58.08196574449539, 60.82341603934765, 60.87872587144375, 38.38523626327515, 18.473246432840824, 7.445192718878388, 3.1338894367218018, 1.9660610519349575, 0.34128406026866287, 0.0416194784338586, 6.10587241128087, 47.78332136571407, 45.31390607357025, 32.533003091812134, 29.567438922822475, 51.32836394011974, 62.48995341360569, 57.86529377102852, 24.574748128652573, 1.412900509312749, 0.035979675594717264, 0.05850655899848789, 0.032173834697459824, 0.030811811884632334, 0.021542110953305382, 0.09773701953236014, 0.028767169060301967, 0.07456797058694065, 0.0725266859808471, 0.03862271209072787, 0.03587629813409876, 0.049009428767021745, 0.03613920765928924, 0.02878887502447469, 0.12641191366128623, 0.1919031806755811, 0.14974830206483603, 0.2028026879997924, 0.17225721065187827, 0.08643041452160105, 0.28870476759038866, 0.17853548313723877, 0.0921170246147085, 0.16984246991341934, 0.17723782308166847, 0.1251833772403188, 0.14689983538119122, 0.127871124423109, 0.2838461345527321, 15.813311263918877, 55.45576326549053, 62.40603491663933, 53.860403671860695, 34.20141376554966, 27.49178320169449, 34.59527023136616, 52.0829426497221, 32.99286961555481, 1.6532735922373831, 0.3760545398108661, 17.801047302782536, 13.976200092583895, 10.126329325139523, 9.227880835533142, 3.719552722759545, 18.21266781538725, 42.77960166335106, 45.442175790667534, 52.144586741924286, 53.47199611365795, 54.569126442074776, 52.72240273654461, 52.02016241848469, 49.31891396641731, 48.68440121412277, 48.877499252557755, 53.535224720835686, 51.802529096603394, 48.24972353875637, 48.403565883636475, 43.46783213317394, 42.33941428363323, 39.54394608736038, 41.70187309384346, 42.180749997496605, 40.62026493251324, 38.36148373782635, 36.54338389635086, 37.086830735206604, 39.19770486652851, 39.41285692155361, 40.88968187570572, 47.60775938630104, 50.478341951966286, 52.74706721305847, 46.23030290007591, 42.35551781952381, 42.01099030673504, 41.39735363423824, 39.45823408663273, 40.484483018517494, 39.17643740773201, 38.06238278746605, 39.329010620713234, 40.260895416140556, 37.795545905828476, 40.65366894006729, 40.77788047492504, 40.45163378119469, 40.086936950683594, 43.393846303224564, 45.838376730680466, 48.68544615805149, 49.97071199119091, 52.01332278549671, 48.04163530468941, 49.303205609321594, 50.227251425385475, 49.91711586713791, 50.14861084520817, 50.40427252650261, 43.82800720632076, 36.30727596580982, 43.659729436039925, 45.96080996096134, 49.10071827471256, 52.20422454178333, 52.46930971741676, 54.56577882170677, 55.35002253949642, 54.937455877661705, 51.57764196395874, 51.063290163874626, 44.411507695913315, 38.01442176103592, 40.64810983836651, 38.36033619940281, 40.91541029512882, 38.82259279489517, 39.89106886088848, 42.25076504051685, 40.51104359328747, 39.95408087968826, 41.95802114903927, 41.822486221790314, 37.5879630446434, 40.53081393241882, 41.73308461904526, 43.46252001821995, 42.666671723127365, 41.94593779742718, 43.32625932991505, 44.93096262216568, 47.91842691600323, 44.39165376126766, 43.93447749316692, 38.155530989170074, 41.871108412742615, 40.09832873940468, 43.1523160636425, 45.69574758410454, 44.94327396154404, 46.16979494690895, 46.85815081000328, 47.57391840219498, 50.81759534776211, 53.00993710756302, 60.46859867870808, 56.24944567680359, 51.72606959939003, 56.42791070044041, 57.08970218896866, 59.84312944114208, 54.13280725479126, 51.57931387424469, 58.244623616337776, 59.10955220460892, 62.6247625797987, 62.273460030555725, 41.85533165931702, 21.201289147138596, 10.077149514108896, 6.770140891894698, 2.6209986582398415, 0.7710017845965922, 0.2997399988817051, 7.038733754307032, 53.484854623675346, 50.71600019931793, 39.00364927947521, 36.60053662955761, 56.48401468992233, 70.09540870785713, 65.82788050174713, 31.391232758760452, 2.5213364185765386, 0.11999048088910058, 0.09475006067077629, 0.22138915315736085, 0.18831393186701462, 0.1546839255024679, 0.1126406659022905, 0.12714891083305702, 0.14607526478357613, 0.2731745853088796, 0.11151478334795684, 0.1060520569444634, 0.10250947438180447, 0.11616293588303961, 0.13048186636297032], [0.06312282886938192, 0.05045607496867888, 0.02977517815452302, 0.015162716208578786, 0.040891654207371175, 0.04486564350372646, 0.056136569764930755, 0.01765614222676959, 0.06400937621947378, 0.008826485700410558, 0.03638445778051391, 0.07001989666605368, 0.05622984288493171, 0.0162327697762521, 0.20799856778467074, 9.795768912881613, 44.567789509892464, 49.259754940867424, 38.447628915309906, 28.955540657043457, 28.994186483323574, 45.87443299591541, 49.85233694314957, 25.38820657879114, 1.6988406283780932, 0.3890553640667349, 7.719643441960216, 7.039449065923691, 2.6801313227042556, 4.410764845088124, 2.81398958992213, 12.701989766210318, 44.32482674717903, 53.64014469087124, 49.994795098900795, 49.99876968562603, 49.292452186346054, 51.061755046248436, 49.30034816265106, 48.00865687429905, 47.66191028058529, 49.63741287589073, 49.61066231131554, 49.05121833086014, 46.08922407031059, 44.77416403591633, 38.96066218614578, 36.524719297885895, 35.10967142879963, 36.21298402547836, 36.344399973750114, 35.1481519639492, 34.548490941524506, 33.828946352005005, 33.05132947862148, 35.55686943233013, 36.65522329509258, 39.12057280540466, 44.19937647879124, 48.51876050233841, 47.929959297180176, 44.97125186026096, 38.64968307316303, 34.891342744231224, 36.02634944021702, 35.786669701337814, 36.29175379872322, 35.560456439852715, 35.29868848621845, 36.612262800335884, 34.82301861047745, 34.222392439842224, 34.68327350914478, 34.458374977111816, 34.7217920422554, 35.028382390737534, 39.657354801893234, 40.37828251719475, 45.68891555070877, 44.96784724295139, 47.7900318056345, 49.338604509830475, 47.79496394097805, 47.96021327376366, 49.099126160144806, 45.024771988391876, 48.97779867053032, 46.69265829026699, 30.006568059325218, 42.989141419529915, 49.28581394255161, 47.72746816277504, 47.57228448987007, 49.173807352781296, 45.16082748770714, 45.42510710656643, 41.95929408073425, 40.963082537055016, 37.408426478505135, 37.342629209160805, 36.10224276781082, 35.28434805572033, 35.118680745363235, 36.737196296453476, 36.42649456858635, 37.13585950434208, 36.25912494957447, 36.399367824196815, 35.95020532608032, 37.40463428199291, 36.77269399166107, 37.27092705667019, 35.92062771320343, 37.22824774682522, 35.79990439116955, 35.81563174724579, 36.62279963493347, 35.9804555028677, 36.56813956797123, 37.82121352851391, 38.87335427105427, 37.97966502606869, 38.89748677611351, 36.86820946633816, 40.05088448524475, 40.08228600025177, 41.168096736073494, 46.657434180378914, 45.50325371325016, 43.18988844752312, 44.51044678688049, 47.10587851703167, 50.82795359194279, 52.36587546765804, 53.01914021372795, 53.65518808364868, 52.74545229971409, 55.13095669448376, 56.787405610084534, 51.702115684747696, 47.0535097271204, 49.67892184853554, 55.40406323969364, 54.0872211009264, 58.40078383684158, 46.00932575762272, 16.591583602130413, 5.56848862208426, 0.8299807354342192, 0.9233845327980816, 0.10660037049092352, 0.06716676187352277, 3.9480197383090854, 39.9450259655714, 53.56066055595875, 45.87490797042847, 28.101507984101772, 41.732636243104935, 50.37903048098087, 52.862432822585106, 22.876119576394558, 0.8814609667751938, 0.022887277737027034, 0.07520258848671801, 0.03136234816338401, 0.07620399803272448, 0.03599333853344433, 0.0023663362435399904, 0.01910171973577235, 0.018224048471893184, 0.11073740592109971, 0.03545232400938403, 0.10673769007553346, 0.03168387251207605, 0.016210837457037997, 0.03634741347923409, 0.0398996291187359, 0.07825680077075958, 0.03158599807647988, 0.039244368381332606, 0.03314172143291216, 0.019981936566182412, 0.04312728873628657, 0.11921822428121231, 0.0750652614806313, 0.04043757486215327, 0.012483141927077668, 0.07699031091760844, 0.026617790645104833, 0.02131050336174667, 0.1923269173130393, 12.424124926328659, 53.04630495607853, 54.419642463326454, 45.41423209011555, 31.61147654056549, 22.71823424845934, 35.66250376403332, 50.561101511120796, 28.04851032793522, 1.5378158376552165, 0.3178718243725598, 8.900288064032793, 6.773002138361335, 3.3078524144366384, 8.564482033252716, 4.625424826517701, 14.294828195124865, 46.71838290989399, 54.30386267602444, 49.86134625971317, 49.48536403477192, 49.509773924946785, 51.21391788125038, 49.82941277325153, 49.26981300115585, 47.89470858871937, 51.160865128040314, 52.2097684442997, 50.960995852947235, 48.99031139910221, 46.46818533539772, 43.68648000061512, 38.436575308442116, 37.20380365848541, 38.32277901470661, 36.38745926320553, 37.28653661906719, 36.42331413924694, 35.39630904793739, 34.51651945710182, 36.479186341166496, 37.50742256641388, 41.20139054954052, 46.34570270776749, 49.99148927628994, 50.38355603814125, 48.26470233500004, 40.1174683123827, 37.32225090265274, 37.052917554974556, 37.756468802690506, 37.43516564369202, 36.961608454585075, 36.11759014427662, 38.568565025925636, 37.69889049232006, 36.10430605709553, 35.62940374016762, 35.65415181219578, 36.99853487312794, 36.77094228565693, 42.66920618712902, 43.169289752840996, 46.804311498999596, 47.228224352002144, 49.1758668422699, 51.472873985767365, 48.67911569774151, 49.124645590782166, 49.70291756093502, 47.90819026529789, 51.486663445830345, 47.15385854244232, 33.46788972616196, 43.88778939843178, 50.017707869410515, 49.14331018924713, 49.72166955471039, 49.12543594837189, 48.16414453089237, 48.610194995999336, 45.56313470005989, 42.897919714450836, 39.476769492030144, 39.93313640356064, 38.15980575978756, 37.30289474129677, 37.280312553048134, 39.670646488666534, 39.412526339292526, 39.56695385277271, 38.47122564911842, 38.31923000514507, 37.2266860306263, 38.25529083609581, 39.27283063530922, 38.214811608195305, 37.54162073135376, 37.621184661984444, 37.3670656979084, 37.254245951771736, 37.64659769833088, 37.72617682814598, 38.69259417057037, 39.05574448406696, 40.70990212261677, 41.45720802247524, 40.87115786969662, 39.777929931879044, 41.43142260611057, 41.866434663534164, 43.47402960062027, 47.66295522451401, 47.599016055464745, 46.106007769703865, 45.534712225198746, 48.92467752099037, 52.65058659017086, 54.75779391825199, 53.02446372807026, 54.4057884067297, 55.08352763950825, 56.568533554673195, 60.00571131706238, 53.87535586953163, 50.009124130010605, 51.098438277840614, 57.83520698547363, 56.63127578794956, 60.73241852223873, 45.4130769520998, 20.198712944984436, 6.311123622581363, 3.494937513023615, 2.9452618584036827, 0.16286407015286386, 0.05580403936619405, 4.170578783378005, 45.40040083229542, 51.248693615198135, 42.20397815108299, 30.361670404672623, 47.481879740953445, 56.18418797850609, 58.70373398065567, 26.249645054340363, 1.5080743585713208, 0.03967487711634021, 0.02304144778463524, 0.029312194892554544, 0.048498207761440426, 0.038736910064471886, 0.08428626824752428, 0.040279790555359796, 0.014217962216207525, 0.04377020013635047, 0.05357609719794709, 0.00981062083155848, 0.03295062211691402, 0.009210360658471473, 0.054651907048537396, 0.16951978410361335, 0.18260497570736334, 0.1387444042484276, 0.18566225306130946, 0.15602422936353832, 0.14801758399698883, 0.20198467798763886, 0.2915858442429453, 0.1314010311034508, 0.11394228902645409, 0.11927403378649615, 0.15205283387331292, 0.1820077991578728, 0.15744688193080947, 0.35676107509061694, 16.583757922053337, 62.20152989029884, 60.42786106467247, 51.277959644794464, 38.871336579322815, 38.06068427860737, 54.960832223296165, 62.2247314453125, 33.34496632218361, 2.5420588441193104, 0.529517320683226, 10.521985944360495, 13.72042441740632, 9.749156814068556, 11.001215279102325, 5.819752039387822, 16.409447975456715, 47.56129167973995, 53.85709024965763, 50.776424556970596, 50.374580919742584, 51.396897062659264, 51.57728858292103, 51.12857066094875, 50.490767285227776, 49.76923920214176, 53.670189678668976, 53.85580971837044, 53.38203214108944, 50.67474201321602, 49.65247146785259, 45.25902181863785, 40.84624640643597, 39.16450224816799, 41.92005358636379, 39.781026765704155, 38.184713423252106, 39.278845712542534, 36.97033278644085, 36.40883691608906, 38.4229302406311, 39.43210668861866, 42.97489978373051, 48.37178818881512, 51.702096685767174, 54.04285468161106, 50.30800089240074, 42.77707479894161, 38.99294525384903, 38.78054805099964, 39.41131420433521, 38.78301031887531, 37.025768011808395, 39.71505090594292, 40.7041872292757, 39.196473732590675, 37.83140458166599, 38.70022416114807, 38.753531500697136, 39.716582223773, 37.802833914756775, 45.24140976369381, 44.9018257856369, 48.61640006303787, 48.15851703286171, 51.54334120452404, 54.36041124165058, 51.3210379332304, 51.04495234787464, 52.0624503493309, 50.12455813586712, 52.26087190210819, 48.760294541716576, 35.32671198248863, 45.10223463177681, 50.73263570666313, 52.88833603262901, 53.0135241150856, 52.000034898519516, 49.60444964468479, 49.08151030540466, 46.02593466639519, 44.176539704203606, 40.89960694313049, 41.968926563858986, 39.173758551478386, 38.277926221489906, 39.0275613963604, 41.782158985733986, 40.59975363314152, 40.975302681326866, 40.574952363967896, 41.0899843275547, 40.03258466720581, 40.46646058559418, 40.56264482438564, 41.07688643038273, 39.68463733792305, 40.81119328737259, 38.851554840803146, 39.81975048780441, 39.982894733548164, 39.24181289970875, 41.70251905918121, 40.55933520197868, 42.140327766537666, 42.64880508184433, 42.94842280447483, 42.13015191257, 43.28549511730671, 43.649071007966995, 45.27771681547165, 51.2346875667572, 49.709825590252876, 47.92502336204052, 47.01388545334339, 50.84484748542309, 55.13035252690315, 56.950010284781456, 56.732456758618355, 57.654796466231346, 55.13575203716755, 59.5202911645174, 62.32140585780144, 56.47887356579304, 51.755358427762985, 54.51652966439724, 60.32394424080849, 60.266069546341896, 61.437713876366615, 48.836757838726044, 20.266548804938793, 10.43174173682928, 8.311100229620934, 5.742302695289254, 0.2839193993713707, 0.15601658524246886, 4.996921392157674, 50.08245639503002, 66.237141340971, 58.64487513899803, 40.96389949321747, 54.87646535038948, 63.01386550068855, 65.86936667561531, 32.97397702932358, 2.237247512675822, 0.08459612974547781, 0.1394352546776645, 0.1405941034317948, 0.17960563040105626, 0.09302732069045305, 0.12881233094958588, 0.14585029013687745, 0.13699275761609897, 0.22816809330834076, 0.27165719016920775, 0.14987819275120273, 0.11563831911189482, 0.1275450989487581, 0.15728035883512348], [0.041217163889086805, 0.05677508394001052, 0.10366971837356687, 0.09599433062248863, 0.035694297548616305, 0.03287890838691965, 0.008768301322561456, 0.01411167460901197, 0.008408017383771949, 0.021938946592854336, 0.04082526909769513, 0.0446591000945773, 0.007324488733502221, 0.03060504954191856, 0.24658692214870825, 10.0431945361197, 38.075438886880875, 52.40197733044624, 45.61762757599354, 30.067940466105938, 38.737553358078, 61.45949050784111, 42.28398285806179, 27.12200604379177, 1.5462469914928079, 0.1651286892592907, 4.138534627854824, 18.737584948539734, 1.3504985952749848, 6.065875757485628, 4.455160712823272, 6.115485420450568, 37.24896423518658, 54.11431364715099, 53.09642046689987, 53.983680456876755, 52.6736855506897, 55.87237671017647, 50.903421342372894, 50.21990641951561, 50.36092825233936, 51.88617020845413, 49.25897978246212, 48.145650923252106, 43.83426547050476, 41.35479971766472, 35.02344645559788, 35.43083779513836, 34.648759961128235, 36.12482875585556, 34.43596377968788, 33.942860439419746, 37.08441786468029, 36.50936812162399, 36.17625139653683, 36.762552335858345, 36.02958686649799, 37.98100635409355, 43.40217545628548, 48.041753098368645, 47.31690399348736, 46.1290193349123, 38.991030156612396, 35.88255375623703, 36.077232509851456, 36.69723764061928, 34.49628174304962, 34.15461927652359, 35.11104315519333, 36.38053223490715, 37.07798480987549, 34.88284260034561, 34.14548836648464, 34.25005115568638, 34.60228465497494, 35.22117264568806, 35.33530332148075, 40.91088853776455, 42.520147785544395, 45.33888213336468, 43.152137473225594, 45.97271852195263, 42.01529547572136, 44.78389911353588, 45.53371287882328, 46.42195701599121, 49.23444449901581, 51.4875677973032, 29.654984325170517, 45.02615511417389, 49.271313920617104, 46.56455956399441, 48.050542026758194, 41.999119743704796, 39.09156136214733, 35.61962306499481, 34.629852175712585, 35.46304106712341, 34.69069831073284, 36.0539473593235, 36.537205427885056, 36.57667391002178, 37.744187861680984, 37.005256712436676, 35.52661545574665, 35.92187784612179, 36.40666723251343, 36.13365948200226, 36.387474462389946, 35.80498851835728, 37.786471992731094, 37.51197852194309, 36.50052219629288, 36.10758528113365, 39.72613871097565, 38.548901081085205, 38.998188972473145, 35.4830963909626, 34.81376230716705, 34.34953361749649, 35.93808777630329, 36.06342405080795, 37.86092899739742, 39.0381096303463, 37.44123391807079, 37.4402117729187, 43.922781720757484, 48.59808124601841, 46.66506037116051, 43.61052207648754, 44.96635392308235, 48.80818337202072, 52.762935161590576, 52.565482556819916, 54.505840837955475, 51.77337326109409, 54.13096435368061, 55.01271463930607, 54.935210198163986, 52.73173503577709, 45.58350920677185, 46.59653104841709, 56.60167537629604, 55.81998512148857, 61.55334547162056, 43.643796890974045, 26.863802298903465, 5.258642798289657, 2.2820067359134555, 1.0070777731016278, 0.08821277122478932, 0.062476292077917606, 1.9797006575390697, 39.77356016635895, 46.796328127384186, 37.27344252169132, 27.149011194705963, 41.43863461911678, 50.09720720350742, 61.05594836175442, 21.372680850327015, 1.2479384173639119, 0.042777291891979985, 0.02168092039937619, 0.06750147047569044, 0.007424305276799714, 0.009696917313704034, 0.06007351476000622, 0.06945555272977799, 0.04085753025719896, 0.05930082028498873, 0.05683297145878896, 0.05848286964464933, 0.02257669264508877, 0.07790839212248102, 0.018831941633834504, 0.08451940651866607, 0.04787639933056198, 0.041863604201353155, 0.10179579549003392, 0.043348797553335316, 0.036345086846267805, 0.03335338566103019, 0.04815274915017653, 0.01578474635607563, 0.028936547569173854, 0.04124759936530609, 0.012587296787387459, 0.015238657397276256, 0.019657725642900914, 0.20895203459076583, 12.927939891815186, 45.06461285054684, 58.53716231882572, 49.49675962328911, 37.13367462158203, 44.62790608406067, 67.14007169008255, 50.69054156541824, 30.685224942862988, 1.5086129796691239, 0.09852061615674756, 3.4842548612505198, 19.596553556621075, 3.3250906644389033, 11.066265888512135, 5.419289153069258, 7.147562764585018, 42.254625633358955, 54.03395175933838, 53.091860711574554, 53.86147901415825, 54.07777100801468, 56.50752402842045, 52.23334237933159, 52.140813544392586, 52.52988986670971, 51.835347935557365, 51.10234446823597, 49.26083028316498, 46.238434463739395, 43.2230606675148, 37.58021526038647, 37.084345668554306, 36.57723627984524, 37.50344417989254, 36.28376662731171, 36.32769227027893, 38.97495701909065, 38.035016655921936, 38.97976756095886, 37.991805374622345, 36.86847165226936, 40.01029886305332, 44.482415691018105, 49.06360186636448, 49.49454814195633, 47.89179414510727, 40.93013070523739, 37.628423273563385, 37.88856491446495, 37.033177614212036, 37.08927780389786, 35.86510129272938, 36.57693989574909, 37.600810155272484, 38.01279544830322, 37.08846464753151, 36.67617157101631, 35.86746856570244, 35.97782604396343, 37.48559653759003, 38.669229224324226, 42.84294046461582, 43.669506311416626, 46.673598513007164, 45.50064705312252, 46.03556714951992, 46.57174877822399, 47.93862283229828, 48.928222730755806, 49.051613509655, 51.26614227890968, 52.830385342240334, 31.875121593475342, 45.96194230020046, 51.49473801255226, 47.91355557739735, 49.162453562021255, 44.679944291710854, 40.89533217251301, 38.34137141704559, 37.82829634845257, 37.85700760781765, 36.41978792846203, 37.803400084376335, 39.11548487842083, 37.731230556964874, 39.413666278123856, 37.80596874654293, 38.26541729271412, 37.29749143123627, 38.777994588017464, 38.72998036444187, 37.69527308642864, 37.82119832932949, 39.40863534808159, 38.70030775666237, 37.8327839076519, 37.45351865887642, 40.517438650131226, 40.515842735767365, 39.021702110767365, 37.645328566432, 35.977510660886765, 36.55806250870228, 38.22784870862961, 37.776516526937485, 39.98767867684364, 39.882059544324875, 40.544800981879234, 39.43816736340523, 44.906674325466156, 50.896699503064156, 48.5863246768713, 47.22730100154877, 47.5451235473156, 50.630679577589035, 54.54529792070389, 55.46683967113495, 56.86479605734348, 53.96195322275162, 56.37866914272308, 56.11240603029728, 57.462788969278336, 54.943835735321045, 47.4529442936182, 48.121377825737, 57.240459099411964, 58.21970455348492, 62.39375397562981, 47.94768914580345, 26.878714598715305, 7.356687393039465, 4.612755831331015, 3.2000130135565996, 0.28820788487792015, 0.1330707297893241, 2.303996393457055, 44.11623694002628, 51.86018720269203, 41.87038265168667, 36.68254002928734, 49.171816259622574, 56.16762846708298, 66.51739910244942, 26.559330336749554, 1.6514215478673577, 0.050882891518995166, 0.0022997470432528644, 0.0210633051028708, 0.06301430461462587, 0.035841714052367024, 0.04137838433962315, 0.022533098890562542, 0.071082867361838, 0.04849576980632264, 0.10428521112771705, 0.045790619260515086, 0.04861309593252372, 0.04034446501464117, 0.020989029108022805, 0.13447531848214567, 0.1318014643038623, 0.1991108150104992, 0.258569861180149, 0.09430700592929497, 0.0801438745111227, 0.08953340075095184, 0.11648504281765781, 0.1427482909639366, 0.08727030304726213, 0.1611627559759654, 0.16036849468946457, 0.10259656541165896, 0.18178211204940453, 0.37985338596627116, 16.796711795032024, 55.35623140633106, 65.00793769955635, 56.462416648864746, 41.078341752290726, 49.354358464479446, 69.68533471226692, 51.56966619193554, 35.48068352043629, 2.2211674880236387, 0.3044490743195638, 5.28626399114728, 24.81524672359228, 4.767149621620774, 12.844320628792048, 9.678055979311466, 8.632197249680758, 44.02606777846813, 55.45330099761486, 54.84241917729378, 55.84576673805714, 57.13096037507057, 61.188226863741875, 54.98429976403713, 53.082866594195366, 54.26004342734814, 54.80545096099377, 54.165398105978966, 52.150605618953705, 48.4315399825573, 47.0222982019186, 40.13383403420448, 41.04479715228081, 38.17965969443321, 39.18556451797485, 37.28152088820934, 38.56507681310177, 41.63438491523266, 41.61106936633587, 40.23834742605686, 41.13451413810253, 39.647528529167175, 41.32551088929176, 47.473630383610725, 50.55256336927414, 53.03038381040096, 50.98596811294556, 43.54712627828121, 39.724071621894836, 40.432380214333534, 40.376899391412735, 38.68634730577469, 37.21146024763584, 38.19768212735653, 40.836632922291756, 40.701599568128586, 38.6692064255476, 37.692712023854256, 38.15541319549084, 37.80454762279987, 38.15749928355217, 40.54885916411877, 44.46497842669487, 45.881827399134636, 49.80339176952839, 48.512479439377785, 50.76616130769253, 47.06643283367157, 50.38910374045372, 52.62979030609131, 50.875922217965126, 53.385999128222466, 55.958837270736694, 35.24587132036686, 48.204046189785004, 52.41561099886894, 50.51689848303795, 51.51399917900562, 45.393306612968445, 43.15481632947922, 40.3660623729229, 39.224907606840134, 40.927573442459106, 39.9650888890028, 39.904561936855316, 41.632428020238876, 40.56366316974163, 41.36448159813881, 40.965955182909966, 39.03286211192608, 39.030707627534866, 39.863546937704086, 41.18575058877468, 40.5734970420599, 39.40986268222332, 41.14975892007351, 40.98955571651459, 40.568572506308556, 38.83480913937092, 43.33643138408661, 43.03982689976692, 42.28017546236515, 40.354389399290085, 38.922265246510506, 37.17957615852356, 41.37606717646122, 39.393325969576836, 42.55487412214279, 41.9028253108263, 42.31095001101494, 40.21250881254673, 48.048706725239754, 54.45114277303219, 51.93835660815239, 49.188873544335365, 50.4866749048233, 52.41264335811138, 56.895813792943954, 56.83158203959465, 59.75118577480316, 55.31031847000122, 59.051787704229355, 58.88446368277073, 60.88857874274254, 57.22370959818363, 50.922750905156136, 51.73241525888443, 60.974799916148186, 60.478930324316025, 65.54970502853394, 47.5003619492054, 30.085767209529877, 8.455285392701626, 5.779381105676293, 8.382537346333265, 1.008709785528481, 0.20293876819778234, 2.4942745082080364, 50.378175526857376, 58.95828232169151, 49.44145359098911, 39.727749824523926, 53.521701246500015, 63.69467876851559, 76.54717370867729, 33.73943455517292, 2.5813546730205417, 0.19311041745822877, 0.13553083059377968, 0.15378910320578143, 0.11658239032840356, 0.12497472984250635, 0.21134243288543075, 0.11836091754958034, 0.10201707424130291, 0.1627030983217992, 0.24345277313841507, 0.0922818407707382, 0.13183205563109368, 0.27728062123060226, 0.10408409652882256], [0.07700618545641191, 0.04814728694327641, 0.031305340089602396, 0.06093407951993868, 0.04953977120749187, 0.06133954448159784, 0.08848480545566417, 0.017089647917600814, 0.00352911652498733, 0.011264424119872274, 0.05299542972352356, 0.05422247442766093, 0.013183541941543808, 0.10103156149853021, 0.1759972341824323, 8.434107229113579, 42.203852757811546, 47.51205772161484, 44.19676601886749, 24.687761664390564, 37.15493448078632, 39.21932950615883, 31.041330434381962, 33.44455897808075, 1.9014887418597937, 0.17884672502987087, 3.9294019248336554, 11.517156343907118, 2.0317412400618196, 12.625699359923601, 4.109407290816307, 3.5416507814079523, 29.210828058421612, 49.48203541338444, 55.144556164741516, 51.44911006093025, 50.3129406273365, 48.615586906671524, 48.62958535552025, 49.54934500157833, 48.33160534501076, 48.57063151896, 46.8340715020895, 43.57513837516308, 40.32535135746002, 36.37035258114338, 33.436940386891365, 33.40613543987274, 34.147901237010956, 33.854697570204735, 34.90656092762947, 42.49478414654732, 46.1380248516798, 46.93426452577114, 45.871537551283836, 43.308309093117714, 43.11690956354141, 43.61972138285637, 46.505396738648415, 47.09246143698692, 45.00136524438858, 47.241918817162514, 41.48162171244621, 34.591588228940964, 36.115203872323036, 34.8725413531065, 35.703594759106636, 34.52973514795303, 34.46643814444542, 33.877249360084534, 35.476119965314865, 35.52844695746899, 35.03254696726799, 34.07279446721077, 34.10869114100933, 35.23525469005108, 35.911542400717735, 34.58841919898987, 34.24641475081444, 37.208127826452255, 37.744788229465485, 39.20312337577343, 40.393234714865685, 41.26884452998638, 41.62137821316719, 44.29917052388191, 46.3221325725317, 52.099376767873764, 33.64220917224884, 45.08479356765747, 50.78133389353752, 45.45817293226719, 43.849403858184814, 39.193996265530586, 36.44854478538036, 40.73712006211281, 37.65392370522022, 36.9959320127964, 36.8096774071455, 36.61885544657707, 36.4448893815279, 35.4810407012701, 36.47174634039402, 35.25228537619114, 36.15831255912781, 35.79312175512314, 36.65556147694588, 36.67369030416012, 37.2794272005558, 36.24683640897274, 35.73898985981941, 37.11833864450455, 37.53635801374912, 39.52412635087967, 42.67131507396698, 43.42711351811886, 46.90086431801319, 45.760195925831795, 40.39297252893448, 35.76149605214596, 33.965617418289185, 36.61667436361313, 38.41245800256729, 37.17157378792763, 39.60906319320202, 37.9094447940588, 44.64097738265991, 47.715502604842186, 47.23009005188942, 47.15390034019947, 42.701246067881584, 42.21776761114597, 44.8393115401268, 47.073477655649185, 47.54929192364216, 47.44727499783039, 50.83820164203644, 52.98332333564758, 55.289457589387894, 54.323910400271416, 44.905940964818, 48.35274741053581, 54.92109775543213, 54.3990133702755, 59.094242826104164, 48.61673444509506, 28.28401979058981, 5.392551887780428, 1.696756083983928, 2.1030643628910184, 0.4317571461433545, 0.10439330493682064, 2.102896459400654, 39.666588306427, 46.590154990553856, 34.405318424105644, 16.923651583492756, 25.892895497381687, 44.16222207248211, 53.480815440416336, 26.18679452687502, 0.5289250868372619, 0.033441504565416835, 0.06857923959614709, 0.09987283148802817, 0.05172370030777529, 0.019929394366045017, 0.05702041569747962, 0.04009290292742662, 0.03856562980217859, 0.04103087369003333, 0.05966467302641831, 0.09776633436558768, 0.06105560991272796, 0.030804867237748113, 0.05891654363949783, 0.026258221951138694, 0.025007220719999168, 0.037496803561225533, 0.0243211682754918, 0.05642776995955501, 0.05774732337158639, 0.08464522281428799, 0.034222648391732946, 0.01190388267787057, 0.04243258656060789, 0.04284907612600364, 0.08978976082289591, 0.03541095298714936, 0.06833427149103954, 0.18472325813490897, 11.28836302086711, 48.57108749449253, 53.697988986968994, 49.50636550784111, 30.764097310602665, 41.94626457989216, 50.78488290309906, 39.6299734711647, 36.12969249486923, 2.265354604460299, 0.15185687720077112, 4.04388883151114, 15.974739901721478, 3.989583095535636, 13.100109603255987, 6.619460927322507, 4.367787726223469, 34.89168092608452, 50.497207939624786, 56.87031336128712, 52.659269124269485, 51.5194670855999, 51.4920287579298, 50.96356451511383, 51.11321568489075, 50.87911784648895, 51.6716793179512, 49.457336738705635, 45.6554963439703, 42.494081184268, 38.904026225209236, 37.05788388848305, 35.6536578387022, 35.55403858423233, 34.991125389933586, 35.72430744767189, 43.15091393887997, 46.70231357216835, 49.00082163512707, 47.42506518959999, 45.58399558067322, 44.90760147571564, 45.43904855847359, 46.022081673145294, 49.18742962181568, 48.37572857737541, 48.928572311997414, 42.752604112029076, 36.39194682240486, 35.890609323978424, 36.96535885334015, 38.12091864645481, 34.27063845098019, 35.63745550811291, 34.81930620968342, 37.914354130625725, 36.85242511332035, 36.20540723204613, 35.86459591984749, 35.70931725203991, 37.105791717767715, 36.87542907893658, 38.18883620202541, 38.37834723293781, 40.34394755959511, 39.83515106141567, 40.96219338476658, 42.92526304721832, 42.788679376244545, 44.162742644548416, 48.11620630323887, 49.50717106461525, 53.94280605018139, 34.73406918346882, 45.78473120927811, 51.143956035375595, 48.00841748714447, 45.546134412288666, 40.52894443273544, 38.782736733555794, 40.45925237238407, 39.31890696287155, 38.55020061135292, 40.06541110575199, 37.94878788292408, 38.304612189531326, 37.61430323123932, 38.47714953124523, 38.15972216427326, 37.52703711390495, 36.38946935534477, 38.31236757338047, 39.57133121788502, 40.305820405483246, 38.46685588359833, 38.7309493124485, 39.27991345524788, 39.509595930576324, 41.6300455480814, 44.46261115372181, 47.39794224500656, 48.26076574623585, 47.03125052154064, 41.98374956846237, 38.35297219455242, 37.19786457717419, 38.96262668073177, 40.75285121798515, 40.14526002109051, 40.202557146549225, 39.13342371582985, 45.376636907458305, 50.83369888365269, 49.608876407146454, 48.469895124435425, 45.79410530626774, 46.00912056863308, 47.75700777769089, 50.189040675759315, 50.90106546878815, 48.839649483561516, 52.9453481733799, 54.46142882108688, 57.67820701003075, 57.87620298564434, 46.235029846429825, 50.65691336989403, 57.330062091350555, 57.82421797513962, 61.506144404411316, 48.73578205704689, 28.117058649659157, 8.619545828551054, 2.5294637074694037, 3.5919864429160953, 0.13230057345936075, 0.058182181091979146, 2.399899447336793, 42.69521199166775, 51.998944357037544, 40.9689836204052, 22.27230917662382, 32.54600219428539, 51.91690295934677, 59.91199314594269, 31.848802305758, 1.3547864276915789, 0.005929611970714177, 0.032601593775325455, 0.08749376371270046, 0.054405417540692724, 0.00907119127077749, 0.08406530861975625, 0.03240891368477605, 0.12301817623665556, 0.055223397866939195, 0.02911167586717056, 0.10334286169381812, 0.0504012265446363, 0.0463652048347285, 0.052424187524593435, 0.14113282843027264, 0.09737203130498528, 0.10666742353350855, 0.1947277205181308, 0.1274828179157339, 0.19843436224618927, 0.302710875403136, 0.1506285188952461, 0.06896454040543176, 0.11560592436580919, 0.15566468850011006, 0.20719758264021948, 0.1641842321259901, 0.2009714237647131, 0.5020888487342745, 14.672183096408844, 57.98692524433136, 61.33496358990669, 56.58818230032921, 37.112745344638824, 47.44210347533226, 47.650518491864204, 42.405333146452904, 42.094954401254654, 3.0636644549667835, 0.2803047245834023, 5.544719472527504, 14.554829243570566, 5.070406123995781, 22.13086936622858, 12.184379640966654, 5.9224985260516405, 37.97051891684532, 51.749457344412804, 59.33358058333397, 55.777807384729385, 55.234447941184044, 52.708677873015404, 53.812184259295464, 54.330666437745094, 52.236177027225494, 54.32001940906048, 52.29969061911106, 48.58491115272045, 44.63543348014355, 40.00447377562523, 38.608945459127426, 36.5693175047636, 37.36251354217529, 38.10503929853439, 38.54987382888794, 46.468154937028885, 50.269071981310844, 52.831407487392426, 50.00609569251537, 48.558966144919395, 49.073245748877525, 48.8649333268404, 49.45648938417435, 51.54909409582615, 49.78308565914631, 51.45519733428955, 45.80203928053379, 37.58107401430607, 38.004359900951385, 37.86109618842602, 39.82329949736595, 36.26840405166149, 38.0305252969265, 36.788774728775024, 38.52690786123276, 38.31600397825241, 37.86042742431164, 37.18676537275314, 37.74493262171745, 39.20216202735901, 38.75524900853634, 38.6587455868721, 38.613087236881256, 41.010811775922775, 42.292467802762985, 43.31838235259056, 45.41207380592823, 46.781330332159996, 46.53429418802261, 51.78438887000084, 51.30831241607666, 55.39175570011139, 38.79309117794037, 47.60967828333378, 53.205945789813995, 50.757121592760086, 49.024942740798, 42.30024978518486, 40.86888939142227, 45.414171293377876, 42.344304621219635, 41.195348873734474, 41.58161334693432, 40.92305928468704, 39.955900982022285, 38.545093685388565, 41.47639699280262, 40.421714186668396, 39.3323240429163, 39.62586969137192, 41.815961971879005, 40.95786541700363, 41.505093052983284, 40.422458946704865, 40.92948853969574, 41.77040621638298, 41.84642493724823, 43.63165274262428, 47.272036001086235, 49.431688115000725, 52.05105856060982, 51.593946889042854, 44.13568049669266, 39.78030100464821, 37.934154868125916, 40.121264308691025, 42.91482500731945, 41.01667866110802, 43.51885199546814, 41.97636276483536, 47.484683990478516, 53.04102323949337, 52.08751380443573, 51.06855668127537, 47.478372529149055, 47.88012497127056, 48.665246441960335, 52.65136934816837, 53.38939614593983, 51.012490689754486, 56.14596202969551, 57.929673716425896, 60.654268115758896, 59.69389244914055, 48.836149871349335, 53.05928885936737, 60.05223222076893, 59.38469544053078, 63.06262828409672, 50.824700966477394, 31.877021491527557, 8.994503058493137, 5.311953462660313, 5.103172715753317, 0.6861680117435753, 0.2534324477892369, 2.847253242507577, 49.44987393915653, 61.8314753472805, 48.454236164689064, 26.684081442654133, 38.497140258550644, 58.79271760582924, 65.63303455710411, 40.28400957584381, 2.754732482135296, 0.11937581191887148, 0.2488388802157715, 0.14543504366884008, 0.08789476836682297, 0.08919042462366633, 0.12036015948979184, 0.0946011338965036, 0.18010899948421866, 0.12366874289000407, 0.13697277900064364, 0.21857062471099198, 0.14881647628499195, 0.15136290370719507, 0.14781761972699314], [0.0065143399206135655, 0.03231971866625827, 0.04874032601946965, 0.03384212701348588, 0.03972915408667177, 0.0024720929832255933, 0.019740053940040525, 0.026116555236512795, 0.045533687734859996, 0.12393449113005772, 0.033519574790261686, 0.0782733951928094, 0.01205774380650837, 0.05164298432646319, 0.19561745168175548, 9.49934396892786, 39.06525917351246, 48.41851428151131, 33.95910456776619, 27.646134719252586, 37.720967307686806, 26.757219918072224, 30.747484602034092, 36.26298174262047, 2.620903900824487, 0.027350488926458638, 1.3662263075821102, 12.08384083583951, 5.300536975264549, 8.363592512905598, 3.5653631715103984, 3.295308337546885, 28.90524085611105, 51.36964872479439, 52.82611437141895, 48.44244159758091, 48.99685464799404, 44.89800699055195, 42.99323000013828, 42.34127998352051, 42.05776199698448, 42.79483504593372, 40.76562613248825, 37.65219859778881, 34.641103371977806, 34.28336016833782, 33.894804418087006, 33.32803063094616, 33.633690029382706, 35.857741087675095, 43.0270291864872, 47.6541168987751, 47.83245652914047, 46.49824172258377, 48.36464837193489, 47.7835151553154, 46.639616936445236, 47.05789469182491, 48.09493884444237, 45.92840529978275, 47.17479541897774, 47.88146249949932, 42.737442925572395, 35.672816410660744, 34.74585995078087, 34.36222493648529, 36.250347420573235, 34.39063981175423, 35.33289045095444, 35.47520041465759, 35.700927302241325, 33.65081571042538, 35.93547731637955, 36.14652939140797, 34.76881071925163, 35.94396226108074, 33.72893951833248, 34.212797954678535, 34.43037047982216, 34.60488751530647, 33.94121132791042, 34.047905802726746, 34.868084192276, 37.45555154979229, 38.163506761193275, 43.22428040206432, 46.40144571661949, 52.93844014406204, 37.31058172881603, 42.75428742170334, 50.28965547680855, 45.148519948124886, 46.965293660759926, 45.12622654438019, 44.42848898470402, 45.27418300509453, 47.89560154080391, 43.695523515343666, 43.14515724778175, 39.27549809217453, 36.84118911623955, 34.97565262019634, 36.25876396894455, 35.03077246248722, 36.706178560853004, 35.82870304584503, 36.79562956094742, 35.41679374873638, 36.14300698041916, 35.92541545629501, 37.950497791171074, 36.3857227563858, 39.190435856580734, 40.4037069529295, 44.10065397620201, 46.23765550553799, 49.2636801302433, 51.42935112118721, 48.94433006644249, 45.719952285289764, 38.62229414284229, 34.33882959187031, 35.814377814531326, 35.29522307217121, 36.79850220680237, 34.56597380340099, 42.0138743519783, 49.52194847166538, 50.773361921310425, 48.33227410912514, 45.72614975273609, 42.67106048762798, 38.18475902080536, 39.20972742140293, 40.42309731245041, 40.63873574137688, 43.50417338311672, 50.01899980008602, 52.72541977465153, 47.79057517647743, 44.38343100249767, 51.126051396131516, 57.01825462281704, 57.912377044558525, 59.987563490867615, 50.07030464708805, 26.42800558358431, 9.966921228915453, 4.642755221575499, 2.5508216489106417, 0.19983446836704388, 0.061333904159255326, 2.111286884173751, 37.933983877301216, 46.66400782763958, 38.11623729765415, 29.98878501355648, 35.58103993535042, 53.46628122031689, 48.65888178348541, 31.858497485518456, 0.977086991770193, 0.07217291902634315, 0.09556376622640528, 0.011454651412350358, 0.07684988915571012, 0.07430484954966232, 0.04642124069505371, 0.03297942857898306, 0.04064116452354938, 0.055915179691510275, 0.04436845651071053, 0.03917020185326692, 0.06113150935561862, 0.10029052704339847, 0.02686828960577259, 0.07598685304401442, 0.041959864465752617, 0.04398983503051568, 0.03137829691695515, 0.022953518127906136, 0.04266912386810873, 0.05231554081547074, 0.020924078198731877, 0.02551936198869953, 0.030832707052468322, 0.006787943793824525, 0.06784544850233942, 0.035160986517439596, 0.04211771556583699, 0.14791019522817805, 11.886339783668518, 47.02784210443497, 53.56262885034084, 41.292669251561165, 31.24842692166567, 47.14420326054096, 36.933763548731804, 37.87242718040943, 39.99112509191036, 2.855664328671992, 0.11275461525656283, 2.8212854359298944, 9.476307705044746, 8.813595715910196, 8.969704639166594, 6.101882150396705, 7.137516103684902, 30.331443026661873, 53.00731144845486, 55.78469641506672, 51.039450243115425, 50.565543472766876, 48.05847980082035, 45.17093874514103, 45.62860518693924, 44.15197782218456, 44.73850294947624, 41.56914621591568, 38.74627768993378, 37.53746755421162, 36.165083795785904, 35.49135334789753, 35.75016126036644, 35.94925917685032, 35.68966090679169, 44.23326686024666, 48.76827031373978, 50.02704776823521, 48.314726650714874, 48.201063349843025, 49.435829892754555, 48.30480918288231, 49.084428548812866, 49.60478022694588, 48.12890522181988, 48.96378502249718, 48.95061492919922, 45.17081715166569, 37.24537342786789, 35.77968567609787, 37.271250039339066, 36.993188560009, 36.155489310622215, 36.56659685075283, 37.3507721722126, 38.22893925011158, 36.11406393349171, 36.240255162119865, 37.278427854180336, 35.82536682486534, 37.108132392168045, 34.97927002608776, 35.86449712514877, 36.85171075165272, 36.53736501932144, 36.77482567727566, 35.049505457282066, 37.577487006783485, 39.312299117445946, 40.48068322241306, 46.059076488018036, 48.42549450695515, 53.7237174063921, 40.29907576739788, 45.01226685941219, 53.12226668000221, 48.50646436214447, 47.619614750146866, 45.725184604525566, 47.223098427057266, 46.88418701291084, 46.71164587140083, 45.048756301403046, 45.17696902155876, 40.73700986802578, 38.88547942042351, 36.70742489397526, 37.46454566717148, 36.00301869213581, 37.64075741171837, 38.18391166627407, 38.049353286623955, 37.87716932594776, 38.49562793970108, 38.210935816168785, 38.197233751416206, 38.94132882356644, 41.167481169104576, 41.937642842531204, 46.78727701306343, 49.28602673113346, 52.35440768301487, 52.38531142473221, 51.52245372533798, 46.383328288793564, 39.70321834087372, 36.73992834985256, 37.454939782619476, 38.07740718126297, 39.92533542215824, 37.07126297056675, 44.53769892454147, 50.99174000322819, 52.635121420025826, 50.15416994690895, 47.784651294350624, 44.123578146100044, 40.372157245874405, 40.300941467285156, 42.24395200610161, 41.980363950133324, 46.81866332888603, 52.81307727098465, 55.376446321606636, 50.71134924888611, 46.55577443540096, 53.17363992333412, 58.847396671772, 59.99902367591858, 62.98000931739807, 51.79905228316784, 27.553932666778564, 8.312575500458479, 3.9259289111942053, 2.5825276225805283, 0.23833501181798056, 0.13035734882578254, 2.474287818185985, 42.61303000152111, 52.89356455206871, 40.90912163257599, 29.33737836778164, 38.97750288248062, 59.21922191977501, 56.62315562367439, 36.49149388074875, 1.60065472824499, 0.06878402040456422, 0.07731767967925407, 0.013058359254500829, 0.048006527504185215, 0.036371136229718104, 0.020750311741721816, 0.08706091350177303, 0.019459344002825674, 0.04415723014972173, 0.0045345617309067165, 0.025284565017500427, 0.018517233911552466, 0.06205902696819976, 0.015802919697307516, 0.1191368032596074, 0.16353883082047105, 0.12910751276649535, 0.11991830702754669, 0.06504216376924887, 0.13252198579721153, 0.12726168759400025, 0.15431826934218407, 0.14887421537423506, 0.18805107800289989, 0.11848474488942884, 0.18471273448085412, 0.10612957426928915, 0.18233562062960118, 0.3779835003660992, 15.67795967683196, 55.85297875106335, 59.43656645715237, 47.45287209749222, 37.79415138065815, 47.23983272910118, 36.17147505283356, 41.692385002970695, 45.94706989824772, 3.711120025254786, 0.23386087064864114, 2.3625757126137614, 20.327432937920094, 14.576672371476889, 20.203665979206562, 7.9613427724689245, 6.5980058535933495, 34.16692301630974, 54.4064761698246, 57.130147218704224, 51.86997927725315, 54.46990616619587, 50.153649374842644, 46.4717685431242, 47.51079238951206, 45.24507276713848, 48.060748279094696, 44.452959671616554, 41.266412660479546, 39.591223150491714, 38.111738339066505, 38.24269451200962, 37.57376700639725, 38.40341828763485, 38.07491831481457, 49.06311549246311, 51.685597971081734, 53.18180948495865, 50.04955016076565, 50.661609917879105, 50.881557315588, 50.80610856413841, 51.36364504694939, 51.93784363567829, 50.50755098462105, 51.256779581308365, 52.129056975245476, 47.48185694217682, 39.103124141693115, 38.373494893312454, 37.44902729988098, 38.622955307364464, 37.81178243458271, 39.53505836427212, 39.15236569941044, 40.45563116669655, 37.40188702940941, 39.53282788395882, 38.9930060505867, 39.418176636099815, 39.824150651693344, 36.591375321149826, 37.9817321151495, 38.22258599102497, 38.66429328918457, 38.40590335428715, 36.56326062977314, 38.598670810461044, 41.87712348997593, 43.236853927373886, 48.34224097430706, 50.667552798986435, 56.973994597792625, 43.154394552111626, 46.76459223031998, 56.202176213264465, 49.69507098197937, 50.76990030705929, 49.40614968538284, 49.60533879697323, 49.12213392555714, 50.78513368964195, 47.92964391410351, 48.14344324171543, 42.59730264544487, 41.86353921890259, 37.6660792529583, 40.919992849230766, 38.577627539634705, 39.53068479895592, 40.760029032826424, 39.496741220355034, 39.28505077958107, 40.83205796778202, 39.25160877406597, 41.0746331512928, 41.305265575647354, 43.29199656844139, 44.24053966999054, 48.821950033307076, 50.8641542494297, 55.20474873483181, 56.27350598573685, 53.298068046569824, 50.06485193967819, 42.190542072057724, 38.49642589688301, 39.19664852321148, 40.123357996344566, 40.55980637669563, 38.25863465666771, 46.51098623871803, 53.49317617714405, 54.280186146497726, 51.68760806322098, 51.46744787693024, 45.94372607767582, 43.516883701086044, 42.57257357239723, 43.871416077017784, 44.4240166246891, 47.932771146297455, 53.558874651789665, 57.73158274590969, 52.976772487163544, 49.57677572965622, 56.024455949664116, 62.08783619105816, 62.664573043584824, 64.1245611011982, 51.76305681467056, 30.20042985677719, 13.793311156332493, 9.50623869895935, 7.674589259549975, 0.5959062895271927, 0.20689852681243792, 2.724706493318081, 46.14417292177677, 59.25203315913677, 51.29349321126938, 42.41281494498253, 47.48445600271225, 68.16439032554626, 63.99372652173042, 44.25026714801788, 3.024322078563273, 0.17454672139137983, 0.2616621827473864, 0.13885562249924988, 0.10709270383813418, 0.07808909023879096, 0.11903078004252166, 0.1630534217110835, 0.13171372760552913, 0.18322544085094705, 0.13971485139336437, 0.18953877239255235, 0.13950382912298664, 0.20079243258805946, 0.08452036388916895], [0.02297580667800503, 0.03854964023048524, 0.04988086599041708, 0.02827620683092391, 0.047339670709334314, 0.06250418940908276, 0.0384344960184535, 0.0705545769596938, 0.008335113434441155, 0.026899404147116, 0.11086104772402905, 0.029811795720888767, 0.06874174767290242, 0.05252383940387517, 0.2736584359081462, 10.819441583007574, 42.56473459303379, 48.73041294515133, 40.167424231767654, 27.974805682897568, 17.58311189711094, 31.271763369441032, 42.46369041502476, 37.204449623823166, 4.22781178727746, 0.18822466634446755, 1.5824540611356497, 4.194660941138864, 7.823674734681845, 7.708143834024668, 4.1526304464787245, 7.885112687945366, 23.758684918284416, 44.6609491109848, 53.320270255208015, 50.20748108625412, 46.42378091812134, 40.95407322049141, 37.57565550506115, 36.78431756794453, 36.86889722943306, 37.570282593369484, 35.994583144783974, 35.421779081225395, 35.89492969214916, 34.96185176074505, 34.76210407912731, 33.543273881077766, 35.79181842505932, 43.127286806702614, 48.99328663945198, 47.112383767962456, 46.35040305554867, 47.28973165154457, 46.698380783200264, 47.96730749309063, 47.600577771663666, 46.43431015312672, 47.89524435997009, 44.625063836574554, 45.16000293195248, 47.53613322973251, 42.53701128065586, 36.28174513578415, 35.19142784178257, 36.804133504629135, 38.309703916311264, 35.72076603770256, 36.36144585907459, 34.6711103618145, 35.479585379362106, 36.27139449119568, 36.23362451791763, 34.60822373628616, 33.80101025104523, 34.16223406791687, 34.16382998228073, 34.461460411548615, 34.80014003813267, 32.99528248608112, 33.846003636717796, 37.467038333415985, 33.857999593019485, 38.54167386889458, 39.18724402785301, 44.842495769262314, 43.54534797370434, 50.86103841662407, 35.25994576513767, 39.15591470897198, 49.31591212749481, 47.17232935130596, 49.03886899352074, 46.984262242913246, 47.176714316010475, 49.47782143950462, 46.436719223856926, 47.514687180519104, 46.735178008675575, 44.19904209673405, 40.23625373840332, 36.95791505277157, 35.83754897117615, 35.16582101583481, 34.848560839891434, 35.40131717920303, 35.950961485505104, 34.48272027075291, 36.366001814603806, 36.69767841696739, 37.690918520092964, 37.583361491560936, 39.34805899858475, 39.51518923044205, 41.41126088798046, 45.612623244524, 48.37365388870239, 50.13582453131676, 49.39836010336876, 49.618653282523155, 43.87149967253208, 36.61220580339432, 35.25836504995823, 35.84105238318443, 37.526413947343826, 36.1671394854784, 36.92411586642265, 47.86281690001488, 51.37809947133064, 52.85335510969162, 49.62573990225792, 48.432657122612, 46.547570675611496, 46.9045577198267, 45.21431341767311, 42.12572135031223, 39.29893523454666, 40.40205404162407, 42.00098164379597, 41.873502284288406, 46.55834309756756, 54.127829521894455, 59.08996805548668, 58.598863407969475, 57.76397980749607, 49.93723198771477, 31.16814862936735, 10.323197711259127, 1.5616115857847035, 2.8888472355902195, 0.24856410745996982, 0.04553017366561107, 1.8648804374970496, 37.068530917167664, 45.27069479227066, 39.41565357148647, 27.057147324085236, 42.08988167345524, 52.18707226216793, 51.666587591171265, 28.4053073823452, 2.127732876688242, 0.08001629932550713, 0.009846434095379664, 0.06572855389094912, 0.018642573377292138, 0.017861728265415877, 0.03516122771543451, 0.05546285552554764, 0.037699870008509606, 0.020164757224847563, 0.019049478105443995, 0.10004326570197009, 0.04450779473700095, 0.026463314461580012, 0.041123059563688, 0.018862562646972947, 0.03538706696417648, 0.04703856284322683, 0.03042743875994347, 0.017184550051752012, 0.12757168267853558, 0.05066995079687331, 0.11362320263287984, 0.042205834470223635, 0.020688492695626337, 0.10265241944580339, 0.03308378567453474, 0.020154370868112892, 0.019670026740641333, 0.23899331165011972, 13.140393141657114, 47.54217870533466, 53.755023926496506, 45.16806609928608, 32.27769859135151, 22.175703160464764, 27.5167041644454, 43.8868660479784, 41.81764908134937, 4.7120611276477575, 0.29957141261547804, 1.8682981166057289, 7.439005700871348, 7.921210750937462, 9.378694742918015, 3.3996215276420116, 7.876995373517275, 26.27363696694374, 46.43546149134636, 55.39376959204674, 50.70471100509167, 48.36307145655155, 41.45660765469074, 40.221567526459694, 39.289093762636185, 38.86588007211685, 39.36432972550392, 37.22972206771374, 37.690405547618866, 36.48222617805004, 36.98674790561199, 36.96198843419552, 35.17695061862469, 37.88956806063652, 43.005229756236076, 50.42889900505543, 47.61515758931637, 46.47525295615196, 48.3821502327919, 48.81094582378864, 47.568891271948814, 49.909721463918686, 47.779498770833015, 48.05794782936573, 45.000297501683235, 46.38877719640732, 49.43098895251751, 43.84813852608204, 36.23903162777424, 35.878571569919586, 38.61811436712742, 39.610621109604836, 37.80377246439457, 37.44262844324112, 34.91077870130539, 36.74024373292923, 38.28098505735397, 36.52212403714657, 36.262575164437294, 35.970393642783165, 35.152191147208214, 35.27981109917164, 36.9064886122942, 37.841002866625786, 35.594825595617294, 37.4113105237484, 39.12734404206276, 36.388682797551155, 40.7179044932127, 40.737177059054375, 45.61626724898815, 46.09122656285763, 53.54836441576481, 38.661956414580345, 41.42508454620838, 51.33415102958679, 50.61216697096825, 50.66813416779041, 49.19184498488903, 48.79943244159222, 50.32745584845543, 48.0037247389555, 49.6879805624485, 48.217459470033646, 45.93203030526638, 43.56651283800602, 37.99582175910473, 36.87268182635307, 35.856867134571075, 36.27986803650856, 38.3197695761919, 37.69921347498894, 36.15479774773121, 37.60592848062515, 37.95110195875168, 38.812280148267746, 38.799794018268585, 41.71561695635319, 42.616882994771004, 43.15037816762924, 46.623733788728714, 50.920490026474, 50.33642716705799, 50.84146946668625, 52.28050924837589, 46.05334259569645, 37.85977005958557, 36.153749004006386, 37.45813921093941, 39.82019506394863, 37.01049283146858, 40.34856431186199, 48.80998067557812, 53.50242868065834, 55.043641179800034, 52.59341485798359, 49.505392760038376, 48.67734119296074, 48.11515375971794, 46.87985144555569, 43.80979858338833, 41.35486051440239, 44.133096635341644, 44.24107924103737, 44.66498829424381, 48.91472585499287, 56.40896491706371, 61.69768452644348, 59.77579325437546, 58.804170191287994, 51.61703445017338, 33.45993675291538, 9.087807051837444, 3.244082573801279, 4.143379842862487, 0.503516859607771, 0.15199600020423532, 2.0272712549194694, 40.00725142657757, 50.93421868979931, 45.910759046673775, 35.35296097397804, 45.721221417188644, 60.35990551114082, 55.69442845880985, 34.874277859926224, 2.939925044775009, 0.05880916229216382, 0.02572641005826881, 0.028771573706762865, 0.023693975563219283, 0.03289024840341881, 0.02333404692762997, 0.06176551127282437, 0.036269254196668044, 0.02768372251011897, 0.051384438629611395, 0.040273868216900155, 0.022045925325073767, 0.07969026642967947, 0.04651546747481916, 0.1295128441415727, 0.1634302397724241, 0.09341158991446719, 0.11739232577383518, 0.2245752970338799, 0.2340722639928572, 0.08191478729713708, 0.16638616943964735, 0.09385490440763533, 0.08471125169307925, 0.2721281273989007, 0.11713177998899482, 0.18748909409623593, 0.16100553941214457, 0.5078700603917241, 16.409098394215107, 56.894407868385315, 60.935498625040054, 51.25102289021015, 39.968121126294136, 28.224188201129436, 40.54762043058872, 56.23209960758686, 48.790787905454636, 6.4900455716997385, 0.4178388195578009, 2.9710418125614524, 7.991269491612911, 16.493930742144585, 15.112633612006903, 10.988594256341457, 13.16738499328494, 29.469331987202168, 49.03785064816475, 56.221376582980156, 54.55535218119621, 50.74775129556656, 44.09774713218212, 42.07923084497452, 41.075404509902, 40.01329690217972, 41.7669939994812, 38.810289055109024, 39.97754842042923, 39.16135221719742, 39.14097771048546, 38.701326102018356, 36.569199711084366, 39.56933632493019, 46.88469618558884, 53.209289610385895, 48.22904884815216, 47.94236943125725, 49.885752350091934, 49.216897040605545, 49.31723065674305, 50.81203244626522, 48.9442502707243, 47.69214145839214, 45.837947353720665, 47.7812884747982, 53.23044687509537, 45.81283450126648, 38.200782760977745, 37.29822479188442, 40.89263051748276, 43.26793245971203, 38.288554251194, 39.8726512491703, 36.296621337533, 38.28767269849777, 40.8750906586647, 38.41033771634102, 38.70053194463253, 37.64852039515972, 36.4267947524786, 35.71684464812279, 38.97956997156143, 38.77623148262501, 36.489183604717255, 38.06733772158623, 42.119565680623055, 36.82433322072029, 43.031056970357895, 43.58247958123684, 48.568021059036255, 49.33438293635845, 54.43490244448185, 41.245266795158386, 42.42524787783623, 52.46976189315319, 53.09309184551239, 52.67873927950859, 53.154340758919716, 51.11259251832962, 54.78855326771736, 49.43971328437328, 51.0958506166935, 50.49746632575989, 47.84451328217983, 44.59865905344486, 41.0078327357769, 38.636547178030014, 38.518802896142006, 38.28375890851021, 40.184489116072655, 40.57390742003918, 37.68628656864166, 41.14599712193012, 41.11358106136322, 41.96095459163189, 41.31543383002281, 43.025380074977875, 44.38407316803932, 45.46407401561737, 49.22652952373028, 53.46173286437988, 55.538370832800865, 52.79807187616825, 53.59474092721939, 47.838684394955635, 40.01742348074913, 38.61260466277599, 39.476032331585884, 42.32396811246872, 39.254587814211845, 41.773480251431465, 51.48337662220001, 55.10993242263794, 58.43943916261196, 54.87988516688347, 51.92358300089836, 51.306644305586815, 51.55581213533878, 50.189451053738594, 47.556055560708046, 44.14071522653103, 44.683299511671066, 46.47160895168781, 47.41158351302147, 52.212158516049385, 59.136621952056885, 64.50657740235329, 64.75789591670036, 61.03540666401386, 53.12043897807598, 35.870003029704094, 15.365661084651947, 3.6634755693376064, 6.303165424615145, 0.7377210923004895, 0.28585815627593547, 2.2636332968249917, 45.73138207197189, 58.65518398582935, 53.41691806912422, 41.024316251277924, 54.03108671307564, 65.0471743941307, 65.55238768458366, 38.92996743321419, 4.222264559939504, 0.28092358668800443, 0.08400241160416044, 0.24058833543676883, 0.10207901388639584, 0.14902460417943075, 0.13322267710464075, 0.3798234328860417, 0.10702363215386868, 0.1638091803761199, 0.1452239026548341, 0.16284284472931176, 0.20735494763357565, 0.14412015094421804, 0.07825564302038401], [0.056291964356205426, 0.060763225992559455, 0.05644308046612423, 0.07452750869560987, 0.021676033356925473, 0.03693439291964751, 0.04038771738123614, 0.02991153480252251, 0.02177978374675149, 0.05278214390273206, 0.025597391395422164, 0.02376090986217605, 0.045935026355437, 0.09570093738147989, 0.12126526795327663, 8.395245764404535, 43.97696681320667, 48.25796529650688, 43.71331036090851, 35.85369810461998, 24.541786797344685, 30.869201570749283, 37.49484904110432, 36.498238518834114, 5.457287589088082, 0.18954917730297893, 0.8951907581649721, 2.319723987020552, 6.390104284510016, 4.623906332999468, 5.858249673619866, 9.406672641634941, 24.102722257375717, 46.6451608389616, 51.30836181342602, 49.468432143330574, 47.228121757507324, 43.31310823559761, 40.41680485010147, 36.137463077902794, 36.426954343914986, 38.18426884710789, 36.89892701804638, 35.666463151574135, 34.55055043101311, 35.470382273197174, 36.04388929903507, 35.736094415187836, 40.375090688467026, 47.68834166228771, 49.0353237837553, 46.88882276415825, 48.07856932282448, 46.91449038684368, 45.84548994898796, 45.7631179690361, 46.681403294205666, 48.990710377693176, 49.48677375912666, 47.332718744874, 47.33615756034851, 47.353990003466606, 43.07140700519085, 35.73740154504776, 36.161895766854286, 36.242371648550034, 38.91697213053703, 34.748755395412445, 33.391947001218796, 36.51706650853157, 35.66592738032341, 36.38163037598133, 34.35179449617863, 34.41653162240982, 34.30917598307133, 34.82068173587322, 32.59447239339352, 36.1205729842186, 34.444019347429276, 34.96421903371811, 34.3287069350481, 36.80620439350605, 37.18133546411991, 42.846717461943626, 42.74983786046505, 46.27920247614384, 48.107174187898636, 51.4654415845871, 33.765953332185745, 37.75858148932457, 45.43885096907616, 43.00648748874664, 49.03183177113533, 45.79016111791134, 48.411788642406464, 48.377377688884735, 44.863326251506805, 48.543668165802956, 46.0442990809679, 44.89166893064976, 41.15562580525875, 36.6840523481369, 36.13595835864544, 36.22892417013645, 37.359435707330704, 36.80554702877998, 35.56047923862934, 35.33900812268257, 35.598659589886665, 37.390358448028564, 36.89304493367672, 39.21138413250446, 39.527663961052895, 39.46049876511097, 36.87048554420471, 41.475819423794746, 47.37162105739117, 50.29075741767883, 47.562872394919395, 49.34092618525028, 46.32758907973766, 38.370546251535416, 35.894340723752975, 35.13456389307976, 34.56698834896088, 34.723330959677696, 33.20647515356541, 42.10180163383484, 52.116878628730774, 53.10762606561184, 54.19754438102245, 52.507737055420876, 52.846044301986694, 52.646680399775505, 51.15794688463211, 46.12942211329937, 43.742599189281464, 42.031490206718445, 43.73650811612606, 43.66686925292015, 47.46587499976158, 55.853259935975075, 56.079002022743225, 58.42537611722946, 58.68633471429348, 49.350832253694534, 32.856126353144646, 11.178842447698116, 2.946517216041684, 1.4230771944858134, 0.5121151451021433, 0.020618547132471576, 1.9705721223726869, 38.63172143697739, 46.225135177373886, 35.70474989712238, 29.186055287718773, 31.05416614562273, 45.682315304875374, 54.630086570978165, 27.577555999159813, 2.0387898618355393, 0.03789878042880446, 0.06236612767679617, 0.05719304666854441, 0.11046214334783144, 0.08298724264022894, 0.04717073934443761, 0.02977191084937658, 0.03378353445441462, 0.015776122600072995, 0.033894381631398574, 0.028631315217353404, 0.039359056172543205, 0.05256014526821673, 0.09968773985747248, 0.010907061459874967, 0.05275349329167511, 0.09182274079648778, 0.10358302810345776, 0.013444956966850441, 0.07402581686619669, 0.11383701537852176, 0.01318963219091529, 0.04683039413066581, 0.05744249363488052, 0.0520995869737817, 0.0039006753104331437, 0.039262636346393265, 0.032032488961704075, 0.3260525775840506, 10.951721984893084, 50.53994424641132, 54.779688343405724, 48.52376103401184, 39.520117565989494, 29.6803080663085, 39.49935548007488, 43.68742614984512, 42.16804347932339, 6.3802257645875216, 0.24512554431566969, 0.6620882288552821, 4.098391681909561, 5.65898266620934, 5.323667284101248, 7.507883179932833, 11.59051425755024, 26.281814128160477, 48.31670634448528, 53.71742494404316, 51.667324751615524, 49.311154782772064, 46.70608676970005, 40.79004742205143, 39.587940126657486, 39.74956065416336, 38.84134478867054, 38.67310121655464, 38.47556881606579, 36.353876665234566, 36.55502267181873, 38.08245711028576, 36.96075350046158, 42.40857437252998, 49.68005418777466, 49.616388604044914, 46.62647344172001, 50.73719926178455, 49.4784864038229, 47.118231654167175, 48.73096391558647, 49.285559356212616, 50.9671401232481, 50.08371412754059, 48.36558312177658, 47.610567435622215, 49.71530869603157, 45.930928364396095, 35.85939399898052, 36.95681311190128, 37.77337409555912, 40.879980996251106, 37.618912383913994, 35.682467892766, 37.91190706193447, 38.02275851368904, 38.39467115700245, 36.17548383772373, 36.87415614724159, 36.82825081050396, 36.50299586355686, 35.15866219997406, 36.67038068175316, 37.510428205132484, 36.24649442732334, 35.891380682587624, 37.569967210292816, 38.59677091240883, 44.840823858976364, 44.916808381676674, 48.99785399436951, 50.36290034651756, 54.77979093790054, 37.589843943715096, 39.09807801246643, 45.91306172311306, 45.67825332283974, 51.98457732796669, 46.34439177811146, 50.686718970537186, 50.14646016061306, 47.504363134503365, 49.73363131284714, 48.883613124489784, 46.3585764169693, 45.23060314357281, 38.32144908607006, 37.009577080607414, 38.25256638228893, 39.15649227797985, 38.25684875249863, 37.94071711599827, 37.04937234520912, 38.009744212031364, 39.34384882450104, 40.6192883849144, 42.5631158798933, 39.755868315696716, 41.311767026782036, 39.00963395833969, 43.49985681474209, 50.38300506770611, 52.55244545638561, 49.60664212703705, 51.850619316101074, 47.01873019337654, 40.403919741511345, 38.02518658339977, 37.7645243704319, 36.609101369977, 37.115739583969116, 36.289663910865784, 45.08917473256588, 53.94887052476406, 55.42920649051666, 56.32584437727928, 54.591275453567505, 54.98181849718094, 54.41297382116318, 53.31381060183048, 48.63497346639633, 45.45799434185028, 42.895791828632355, 44.460411071777344, 46.704179272055626, 48.69628317654133, 58.47964100539684, 58.42114694416523, 61.75833307206631, 59.87199269235134, 50.589535385370255, 33.833525106310844, 10.155627653002739, 2.7446623099967837, 4.915250474587083, 0.4443778720451519, 0.00509889407112496, 1.9776162318885326, 43.075905963778496, 52.00193479657173, 41.92762278020382, 34.55184996128082, 39.04042750597, 50.58550380170345, 63.815896064043045, 32.01624222099781, 2.7536683017387986, 0.048448947709403, 0.06752682966180146, 0.02975578583573224, 0.09708555488032289, 0.07234704913571477, 0.057309793919557706, 0.05647556798066944, 0.02309150750079425, 0.022489803850476164, 0.051741114803007804, 0.031725789012853056, 0.08867524054949172, 0.06368389251292683, 0.028401266135915648, 0.08363545668544248, 0.17958976328372955, 0.20476216566748917, 0.20649985992349684, 0.08467648949590512, 0.1553695957409218, 0.1602193378494121, 0.0915997996344231, 0.1593108451925218, 0.21634913922753185, 0.12870189937530085, 0.16004668461391702, 0.16325856617186219, 0.13675437978236005, 0.4886755387997255, 13.84642280638218, 54.78754252195358, 60.217523351311684, 54.69152547419071, 47.40991160273552, 35.890506729483604, 42.685408517718315, 48.06637957692146, 47.826019674539566, 7.572920490056276, 0.3465052176034078, 2.038853745907545, 7.1850126050412655, 12.715338449925184, 12.70738547667861, 11.063975561410189, 11.379063203930855, 28.42009048908949, 49.73088786005974, 56.46755397319794, 55.47573119401932, 51.049097925424576, 48.96909713745117, 44.68703471124172, 40.51936134696007, 43.229383528232574, 42.54360772669315, 41.6099788248539, 40.58056466281414, 38.455243706703186, 38.12927819788456, 39.78214390575886, 40.1645477861166, 44.58242252469063, 51.87583476305008, 51.7887282371521, 48.05225573480129, 53.83929580450058, 52.650221809744835, 50.14466665685177, 50.216121822595596, 51.333596259355545, 53.66764381527901, 52.575206235051155, 50.535487085580826, 50.26482380926609, 51.28001533448696, 48.4599244594574, 38.70288021862507, 38.91864784061909, 39.18664366006851, 42.45957903563976, 38.848929181694984, 36.266751140356064, 40.90556122362614, 39.07306395471096, 40.39978936314583, 38.36262747645378, 37.87184581160545, 38.292973414063454, 39.933117404580116, 36.41759164631367, 40.575013160705566, 38.08972992002964, 38.778682351112366, 39.22183737158775, 39.80226382613182, 41.320951133966446, 46.24694600701332, 47.666956409811974, 51.64506934583187, 53.83346691727638, 55.35200223326683, 40.06296783685684, 41.06918044388294, 49.913107082247734, 47.41473734378815, 52.655769512057304, 47.89076820015907, 51.27093382179737, 52.105407044291496, 48.690226301550865, 52.44109623134136, 50.21120108664036, 49.13643255829811, 47.59298577904701, 40.92974312603474, 39.53222371637821, 39.18087176978588, 41.228448897600174, 41.696397587656975, 39.74197246134281, 38.66127245128155, 39.29123304784298, 41.85271359980106, 42.542330995202065, 43.93140345811844, 42.41079345345497, 45.47956198453903, 39.992774203419685, 45.53502760827541, 51.77385203540325, 55.023053884506226, 49.85604174435139, 52.98541322350502, 50.40533646941185, 43.00467498600483, 40.20150080323219, 38.73452492058277, 37.7147014439106, 39.93105411529541, 36.48653894662857, 46.487123519182205, 57.10968531668186, 58.6911528557539, 58.908033818006516, 56.952658742666245, 57.9262463003397, 56.85006804764271, 56.49408794939518, 51.82612583041191, 48.72881703078747, 46.608025431632996, 48.31236317753792, 49.83251340687275, 51.51069335639477, 61.54722020030022, 62.139893397688866, 62.35373452305794, 62.23910607397556, 51.373908296227455, 38.48281882703304, 13.637157585471869, 7.750640753656626, 7.2701389621943235, 0.7518982503097504, 0.24042533012107015, 2.3655421659350395, 47.47874490916729, 59.45847988128662, 48.344577848911285, 40.06737180054188, 43.29499080777168, 57.86854639649391, 70.634675770998, 39.971970319747925, 3.8794642919674516, 0.1985414541559294, 0.18927199998870492, 0.1421887264586985, 0.19799979025265202, 0.19281741755548865, 0.1299625707906671, 0.23913807497592643, 0.1379991989233531, 0.20117281295824796, 0.11518841434735805, 0.11817314676591195, 0.31351773301139474, 0.13607613102067262, 0.19357556593604386], [0.073248075786978, 0.04250794052495621, 0.01882227516034618, 0.025800481962505728, 0.054842794852447696, 0.04541578273347113, 0.07508415656047873, 0.0477839054656215, 0.07235928715090267, 0.046754683935432695, 0.017744756514730398, 0.05141404290043283, 0.021629539660352748, 0.020108116514165886, 0.11004367595887743, 5.741084860637784, 33.584931045770645, 46.12304985523224, 40.35149775445461, 24.64175183326006, 10.31697079539299, 14.160786587744951, 35.95602661371231, 39.48328614234924, 7.594103403389454, 0.034177488705608994, 0.027564906522457022, 1.6711797751486301, 4.366470146924257, 6.548108356073499, 3.613884192891419, 7.412922950461507, 23.699126914143562, 42.00053706765175, 53.88422079384327, 50.57916574180126, 49.06418703496456, 46.127085238695145, 44.654048681259155, 40.60442358255386, 37.766868844628334, 35.09437344968319, 36.510280072689056, 35.677775144577026, 37.76797838509083, 38.85461367666721, 36.175400242209435, 40.705372765660286, 48.61853554844856, 47.71644115447998, 46.02998524904251, 48.29937167465687, 43.48444864153862, 43.36725912988186, 42.64396034181118, 40.8301542699337, 43.33326615393162, 43.49466249346733, 46.91430799663067, 49.794899225234985, 49.543801099061966, 48.5860662907362, 42.32160083949566, 35.42277082800865, 36.64388470351696, 35.91270513832569, 35.465461537241936, 34.34138685464859, 35.81845499575138, 34.8223802447319, 35.26221424341202, 36.685127690434456, 35.46579971909523, 34.98626545071602, 34.46628235280514, 35.346695110201836, 34.07049939036369, 34.32608127593994, 36.222126334905624, 34.36850979924202, 36.02551728487015, 36.442347317934036, 37.946880385279655, 43.42244356870651, 43.346436247229576, 44.86464858055115, 45.58021858334541, 52.148907110095024, 35.50758607685566, 37.7447160333395, 43.266385942697525, 43.04515801370144, 46.50060519576073, 45.89100010693073, 48.72732371091843, 46.6049437969923, 48.82988780736923, 48.481575697660446, 48.92897889018059, 45.85203319787979, 41.73714280128479, 36.29015028476715, 34.37053509056568, 34.659076407551765, 37.17641472816467, 35.87422080338001, 37.30628415942192, 34.99382704496384, 35.297609344124794, 37.1475400775671, 36.190759018063545, 37.743845880031586, 37.65549302101135, 37.48777762055397, 37.34808571636677, 40.623623952269554, 46.901666074991226, 49.26489606499672, 49.43006940186024, 45.91373808681965, 43.163141682744026, 34.761351719498634, 38.435081988573074, 36.069480925798416, 36.951223611831665, 35.495156943798065, 36.21888890862465, 35.61973325908184, 44.313005581498146, 51.33781023323536, 53.30210343003273, 51.685263589024544, 53.400525748729706, 54.281436279416084, 54.337570667266846, 51.12712673842907, 48.77007521688938, 43.45550559461117, 44.37838487327099, 41.17518335580826, 46.872320249676704, 52.77203567326069, 58.133608773350716, 56.69725924730301, 57.44941368699074, 53.788887709379196, 28.140457794070244, 8.36115874350071, 4.264383874833584, 2.698427103459835, 0.28318229829892516, 0.03722163746715523, 2.7848940761759877, 36.390210315585136, 51.15151382982731, 41.56121984124184, 34.38400536775589, 37.037019208073616, 50.505457296967506, 49.46182429790497, 31.14454809576273, 3.4591574454680085, 0.0377055808348814, 0.052032459716429, 0.05323740697349422, 0.019811650781775825, 0.022913223219802603, 0.039789145594113506, 0.035610765116871335, 0.027999300400551874, 0.021442182624014094, 0.002094472706630768, 0.027263312549621332, 0.08411619768594392, 0.05098477726278361, 0.0808716171013657, 0.02667479871888645, 0.10225602352875285, 0.045224876375868917, 0.018808233726304024, 0.059176128343096934, 0.05483314693265129, 0.021246823380351998, 0.021029285053373314, 0.0637420397833921, 0.05839060955622699, 0.0700861556106247, 0.09674500557594001, 0.031033849481900688, 0.03427994961384684, 0.19727310893358663, 7.65095547772944, 43.025912046432495, 53.66963870823383, 47.18020252883434, 33.242565616965294, 17.314715199172497, 22.00743868947029, 42.96824254095554, 43.214226141572, 8.123389352113008, 0.2038338131387718, 0.23386726796161383, 2.50845012255013, 7.635863637551665, 7.005590982735157, 7.394760875031352, 13.607107847929, 25.669224299490452, 45.519995614886284, 54.177994430065155, 53.655902445316315, 49.87079635262489, 47.32355743646622, 46.55659519135952, 41.7184592038393, 38.97873781621456, 37.62871205806732, 36.00624851882458, 38.51208485662937, 38.606688380241394, 39.79562558233738, 37.04610452055931, 41.00428372621536, 50.49594260752201, 49.11163508892059, 46.322341561317444, 49.330982118844986, 47.19590328633785, 45.40735825896263, 44.60296422243118, 43.557788506150246, 45.65409041941166, 45.91354049742222, 48.539594784379005, 51.13594226539135, 50.85891053080559, 50.178853422403336, 45.36363400518894, 37.19982147216797, 37.33061045408249, 37.8726589679718, 36.976777240633965, 35.58481693267822, 35.65646208822727, 35.764212906360626, 36.298274248838425, 37.719363793730736, 36.08564145863056, 37.81648278236389, 36.1017107963562, 37.053688913583755, 36.45247757434845, 35.604568272829056, 36.97102814912796, 36.206030398607254, 37.03801475465298, 39.72279489040375, 39.43075776100159, 44.80933494865894, 43.89650993049145, 47.772594541311264, 48.44876065850258, 53.62136609852314, 38.951728865504265, 38.60028572380543, 44.66169387102127, 44.41514030098915, 47.30773128569126, 46.43641144037247, 50.825669914484024, 47.97339856624603, 50.18520288169384, 50.9535900503397, 49.97303746640682, 47.22663223743439, 44.41737458109856, 37.66111671924591, 36.34552091360092, 36.2679822742939, 39.09385643899441, 38.119763508439064, 37.954795360565186, 36.51638254523277, 37.21632398664951, 38.88166442513466, 38.20349581539631, 39.206326603889465, 39.74027395248413, 39.06820021569729, 39.15188692510128, 42.51926243305206, 48.82507726550102, 51.05850242078304, 49.871981889009476, 49.14463631808758, 44.89254288375378, 37.50414714217186, 40.12367717921734, 36.7425350099802, 37.70221531391144, 37.56623961031437, 37.77009107172489, 37.9134725779295, 47.11609996855259, 52.50779785215855, 54.13148112595081, 54.09627981483936, 55.27731344103813, 56.154549568891525, 56.131997779011726, 52.86439351737499, 52.83538207411766, 45.73068290948868, 46.39710254967213, 43.940636962652206, 49.887682646512985, 57.412966042757034, 59.56493876874447, 58.824366107583046, 58.76066252589226, 53.61570440232754, 29.244000278413296, 8.653973881155252, 3.9632307970896363, 2.6892914436757565, 0.16103871341329068, 0.10020255285780877, 2.2976922942325473, 42.51177303493023, 56.92921780049801, 44.368220418691635, 38.22152204811573, 39.946561083197594, 56.36191584169865, 56.50837138295174, 35.022029131650925, 4.405512101948261, 0.09136551103438251, 0.055586527014384046, 0.03184146014973521, 0.05324528116034344, 0.08967862420831807, 0.03938299043511506, 0.026391311293991748, 0.03469564508122858, 0.012106851718272083, 0.018966901188832708, 0.036051318820682354, 0.09816081554163247, 0.026975179280270822, 0.02275355571327964, 0.18580499774543568, 0.19406661536777392, 0.1576430760906078, 0.08174807866453193, 0.12610276462510228, 0.2253018892952241, 0.19683531601913273, 0.10810799896717072, 0.1441839904873632, 0.12905269773909822, 0.12207980471430346, 0.16051469778176397, 0.17623049119720235, 0.13784561888314784, 0.21015735663240775, 9.445077180862427, 48.05857099592686, 59.470384642481804, 52.37834259867668, 36.90341837704182, 18.298054933547974, 20.37818681448698, 47.33401067554951, 50.030440986156464, 10.326046608388424, 0.3677283553406596, 0.6355284852907062, 5.5202768091112375, 12.865562438964844, 13.383827079087496, 7.025838196277618, 9.735243860632181, 25.45489300042391, 45.87037481367588, 57.09210745990276, 57.670641615986824, 52.50324569642544, 50.742404982447624, 50.257144421339035, 45.64742937684059, 41.204069405794144, 39.54871483147144, 39.22648072242737, 39.606847912073135, 41.61161653697491, 41.79547727108002, 39.280749410390854, 44.814909249544144, 52.81683146953583, 49.10777449607849, 47.07902155816555, 51.86185151338577, 49.638587012887, 48.94402988255024, 45.75836822390556, 46.918833553791046, 48.897060602903366, 48.65617632865906, 51.89299464225769, 54.78711314499378, 54.06138628721237, 53.434123545885086, 46.813024431467056, 39.245430305600166, 40.61248295009136, 39.83376793563366, 39.24718201160431, 36.676087975502014, 37.85571187734604, 38.603207767009735, 38.61615367233753, 40.86109600961208, 38.01987826824188, 39.35464024543762, 38.156123757362366, 38.41105207800865, 38.89286622405052, 37.566665187478065, 40.38900934159756, 36.82886257767677, 39.611487463116646, 42.117266803979874, 42.69806183874607, 47.5654486566782, 46.36153265833855, 50.117095336318016, 51.29914730787277, 54.48010861873627, 41.19317539036274, 42.492158487439156, 46.1096365749836, 45.26185266673565, 50.30338034033775, 47.753413170576096, 53.852017521858215, 50.68961821496487, 52.08034738898277, 53.74722674489021, 51.5808679908514, 50.19976370036602, 47.56359055638313, 39.717425778508186, 38.44585061073303, 37.85902909934521, 40.88557429611683, 39.83927384018898, 41.073307022452354, 37.475587874650955, 38.88325273990631, 42.729725539684296, 39.35280494391918, 42.23604083061218, 41.52951054275036, 41.87354788184166, 43.254621773958206, 45.90679965913296, 51.42333224415779, 53.90287019312382, 51.30769304931164, 50.96381530165672, 46.94286346435547, 39.307864755392075, 42.52324841916561, 39.66342307627201, 40.17915800213814, 39.421410262584686, 40.67329868674278, 39.545834586024284, 49.009488970041275, 56.468967497348785, 56.9642823189497, 54.884642511606216, 58.38737055659294, 57.424946799874306, 57.750262543559074, 55.9331164509058, 55.2811474353075, 47.57277086377144, 50.34183047711849, 47.015827149152756, 52.51635119318962, 59.333508387207985, 61.68031565845013, 62.05163933336735, 59.70109686255455, 55.25794968008995, 31.659306474030018, 11.047805529087782, 7.560450509190559, 9.50553573668003, 0.29111493669915944, 0.4106610344024375, 3.4913804288953543, 45.685909911990166, 64.4337049126625, 52.44292393326759, 46.84937708079815, 50.59459291398525, 65.08998289704323, 63.09055678546429, 41.88030391931534, 5.601687915623188, 0.22536614444106817, 0.1540196588030085, 0.10358132858527824, 0.1003937449422665, 0.28898942575324327, 0.14178223733324558, 0.13814468955388293, 0.09302376580308191, 0.0764870605780743, 0.13218800449976698, 0.09935076770489104, 0.2984934876440093, 0.1802677003433928, 0.1418739222572185], [0.04993692782591097, 0.04028068855404854, 0.03325625708384905, 0.04737385403132066, 0.02824018483806867, 0.02887201411795104, 0.008099640181171708, 0.04945530366967432, 0.017442134667362552, 0.07344438126892783, 0.01711608136247378, 0.08886911178706214, 0.047086999111343175, 0.019825248782581184, 0.08774232381256297, 3.4229285269975662, 27.880160361528397, 46.84199407696724, 42.20043294131756, 28.77726372331381, 23.452658839523792, 32.95977719128132, 35.76836608350277, 39.00730088353157, 10.86437227204442, 0.09614411828806624, 0.22267986671067774, 0.9914514678530395, 6.204525092616677, 2.012513796798885, 10.127570908516645, 22.30662513524294, 28.57759203761816, 44.67669166624546, 50.51680348813534, 51.847009509801865, 50.51172696053982, 47.38650105893612, 47.81794510781765, 44.332376942038536, 41.788941621780396, 37.440291568636894, 36.17650978267193, 34.96885858476162, 36.604803800582886, 35.54349794983864, 35.51051951944828, 44.68709550797939, 48.742758482694626, 44.9896314740181, 47.008219957351685, 46.41171656548977, 40.95159575343132, 41.88017092645168, 36.665558740496635, 35.72624534368515, 38.31522881984711, 40.235793963074684, 40.527101531624794, 46.2003643065691, 47.34084650874138, 46.17461308836937, 40.49328714609146, 35.300018414855, 35.47653794288635, 35.53740307688713, 34.56908583641052, 35.49829937517643, 34.36867319047451, 35.643747970461845, 38.578828275203705, 37.10336744785309, 34.69532646238804, 35.90255208313465, 34.52294871211052, 34.608979895710945, 35.45417994260788, 38.242173939943314, 37.77468502521515, 39.032387137413025, 35.59242032468319, 37.16397799551487, 35.44170141220093, 40.490950271487236, 43.490387722849846, 48.756863325834274, 47.082790955901146, 48.09941880404949, 34.93184857070446, 38.608728870749474, 51.08254373073578, 48.010461777448654, 51.669084057211876, 47.86409743130207, 49.97459538280964, 47.65820927917957, 48.17773640155792, 46.88728764653206, 49.449319168925285, 45.609693601727486, 38.484604731202126, 35.46852417290211, 35.74334442615509, 35.78555256128311, 35.13292618095875, 34.54784117639065, 35.317847058176994, 36.86716832220554, 36.76656112074852, 36.26732490956783, 37.434246093034744, 37.71904841065407, 38.72816406190395, 35.36762438714504, 36.51316411793232, 43.21620963513851, 47.371472865343094, 48.85940842330456, 49.492177069187164, 46.21463254094124, 40.94002917408943, 37.25757457315922, 39.41366247832775, 41.66138246655464, 42.204133942723274, 40.9824500977993, 39.11740757524967, 35.164369493722916, 36.82118698954582, 41.68991133570671, 48.19955103099346, 51.68700009584427, 50.60574531555176, 52.51484267413616, 51.93155877292156, 55.48751816153526, 51.91171623766422, 47.388032376766205, 44.32570070028305, 41.23810797929764, 43.610689267516136, 50.353100672364235, 56.69447399675846, 58.28652396798134, 57.63084255158901, 51.83138854801655, 27.54639007151127, 7.777164755389094, 1.6835706727579236, 3.0665209516882896, 0.7276146439835429, 0.043072562766610645, 2.07988821901381, 39.21332202851772, 47.40150265395641, 40.671353191137314, 30.146810933947563, 38.94292093813419, 48.83232727646828, 54.53199103474617, 23.537555783987045, 1.9771520630456507, 0.018249056993226986, 0.017468805599492043, 0.019858537816617172, 0.05310059947078116, 0.012490911285567563, 0.01286411601540749, 0.06301685760263354, 0.09312887617852539, 0.018602246927912347, 0.052730278912349604, 0.031571978906868026, 0.013424880016827956, 0.08813604799797758, 0.046407050831476226, 0.003641598282229097, 0.06481200151029043, 0.03442917324719019, 0.05247719913313631, 0.04910819377982989, 0.024998496774060186, 0.07225603214465082, 0.020645188378694, 0.018081138659908902, 0.02397074284090195, 0.0020153611558271223, 0.027109674992971122, 0.037600340583594516, 0.011094169876741944, 0.012072113640897442, 5.199066270142794, 33.419765308499336, 52.73272678256035, 46.963997930288315, 30.522886253893375, 18.399895168840885, 24.042113609611988, 39.275330901145935, 46.118056923151016, 11.918917335569859, 0.060140745918033645, 0.27066838229075074, 2.4102840526029468, 7.0161529909819365, 4.789974996820092, 13.814361076802015, 17.83695537596941, 27.760159000754356, 45.68419620394707, 51.24851122498512, 54.08823184669018, 52.47245974838734, 48.1128016859293, 48.354172334074974, 46.70414887368679, 42.90896192193031, 38.41442249715328, 36.83091066777706, 38.45760717988014, 38.63687016069889, 36.957193091511726, 37.082920745015144, 46.02135211229324, 50.2230678498745, 46.90947465598583, 47.08666294813156, 49.23283338546753, 44.50598582625389, 44.467748478055, 37.38525912165642, 38.31669174134731, 41.4416478574276, 42.254925817251205, 43.7162210047245, 48.56698751449585, 51.00288860499859, 49.15842957794666, 43.14338654279709, 37.07369104027748, 37.839536145329475, 36.29193238914013, 37.302522361278534, 37.231245785951614, 35.54086089134216, 37.342165634036064, 39.17942024767399, 38.59089642763138, 37.76034839451313, 36.82632051408291, 36.38278171420097, 37.19559229910374, 37.02435068786144, 39.75632809102535, 40.09949907660484, 40.300648882985115, 38.048657923936844, 40.41351802647114, 38.68476279079914, 42.96306721866131, 45.07896848022938, 49.80549305677414, 48.21568116545677, 50.221601128578186, 37.34989441931248, 40.80859422683716, 50.12157529592514, 50.153607577085495, 51.69676557183266, 49.04058650135994, 51.19087591767311, 51.01957730948925, 49.76836144924164, 47.633977979421616, 50.61526000499725, 48.36320444941521, 41.86668545007706, 36.53534732758999, 37.52424046397209, 38.46234932541847, 36.698495373129845, 37.03406296670437, 37.06261843442917, 37.46960699558258, 37.354393377900124, 38.215214386582375, 39.51580099761486, 40.36249436438084, 38.96740682423115, 38.0971547216177, 38.29042375087738, 45.396479442715645, 49.57715570926666, 50.69369539618492, 50.514314621686935, 47.682778760790825, 43.2589877396822, 39.97646547853947, 42.02459737658501, 43.81598085165024, 45.40390804409981, 42.73532263934612, 40.935161635279655, 37.65797048807144, 39.44561116397381, 45.013931170105934, 52.56871238350868, 53.68496708571911, 53.7298920750618, 52.80572846531868, 53.666116297245026, 57.270017713308334, 53.28285366296768, 49.67671036720276, 45.01216806471348, 43.95902417600155, 47.04113759100437, 53.67872782051563, 59.86342415213585, 60.06556190550327, 59.83583763241768, 54.07284267246723, 29.163231812417507, 9.526528660207987, 2.4198645260185003, 4.489962570369244, 0.3168863710016012, 0.034132930159103125, 2.5504934415221214, 42.20447212457657, 54.68426786363125, 46.99676737189293, 39.773419573903084, 48.282116800546646, 53.894731029868126, 60.124629735946655, 30.726228542625904, 2.9152757674455643, 0.06851444268249907, 0.023637689228053205, 0.043696579086827114, 0.022231497496250086, 0.009935272883012658, 0.045228524031699635, 0.04556174091703724, 0.057295151345897466, 0.03549218476109672, 0.007167676176322857, 0.005851077903571422, 0.0029317873713807785, 0.05411587975686416, 0.03221112761821132, 0.126034353452269, 0.12443760788301006, 0.15295926335966215, 0.14524714672006667, 0.182027050468605, 0.08652215139591135, 0.21356219658628106, 0.09425833588466048, 0.1783482392784208, 0.1813849146128632, 0.10295197993400507, 0.3138880943879485, 0.1906419897568412, 0.17271518998313695, 0.22395196720026433, 6.107756160199642, 39.10664655268192, 60.16027942299843, 52.8105466067791, 39.522785022854805, 33.02615582942963, 43.02928626537323, 47.15060591697693, 51.43353849649429, 14.405657798051834, 0.12443571540643461, 0.5164734518621117, 5.162034882232547, 14.548952858895063, 8.323426768183708, 16.629841849207878, 25.38312055170536, 31.943244338035583, 47.183721140027046, 51.91759452223778, 57.40730054676533, 55.67194886505604, 50.51459960639477, 51.01298086345196, 49.59215730428696, 45.683044865727425, 40.03062777221203, 39.922173991799355, 40.283489003777504, 39.85051363706589, 38.188433423638344, 39.8757366836071, 48.43941316008568, 52.650426998734474, 45.54400272667408, 48.29896129667759, 51.91374912858009, 45.69361589848995, 46.34483255445957, 39.722072929143906, 39.614238515496254, 41.76657982170582, 42.70339675247669, 44.73927430808544, 50.04828862845898, 53.42655435204506, 51.65928818285465, 45.62612012028694, 39.6780750900507, 39.319176748394966, 38.12239296734333, 38.900424018502235, 39.160501062870026, 37.32793539762497, 38.87885257601738, 41.77550554275513, 40.55893622338772, 40.06530091166496, 38.86191688477993, 38.296465426683426, 38.675590083003044, 39.26973760128021, 42.312637120485306, 42.72416263818741, 43.37558068335056, 38.944946229457855, 41.00177966058254, 39.74644102156162, 44.52071763575077, 48.32228444516659, 52.714974135160446, 50.75655162334442, 51.97968319058418, 40.34227944910526, 42.898219898343086, 50.06810836493969, 51.92105993628502, 54.27720330655575, 51.470035538077354, 55.11625528335571, 53.43513809144497, 51.36036962270737, 50.594946295022964, 53.243426978588104, 50.71002312004566, 43.26877601444721, 38.35024394094944, 39.336291030049324, 40.063374415040016, 39.18179132044315, 38.20740960538387, 40.02117767930031, 41.55229791998863, 39.29886303842068, 40.703579261898994, 41.87252953648567, 42.59691886603832, 42.45574124157429, 39.25297290086746, 40.52377671003342, 48.17508414387703, 51.357382982969284, 52.62529514729977, 51.105608493089676, 50.61951197683811, 45.84993951022625, 42.33837693929672, 44.510294795036316, 46.013934910297394, 47.55482442677021, 44.48452837765217, 43.37273083627224, 40.065878480672836, 41.448343098163605, 47.72440552711487, 52.49562330543995, 56.67666435241699, 55.38271978497505, 53.2272132486105, 54.523969665169716, 58.86108733713627, 57.139528915286064, 51.27971135079861, 48.319673985242844, 44.68039646744728, 49.02840815484524, 55.24957112967968, 62.74603687226772, 62.26762354373932, 62.956336587667465, 53.671356216073036, 32.44978755712509, 10.656050350517035, 5.195507761090994, 6.838786108419299, 1.4459412801079452, 0.14017403300385922, 2.6561377476900816, 47.02035650610924, 60.245744436979294, 53.08610022068024, 40.525129437446594, 53.44710364937782, 61.986928805708885, 70.68404272198677, 38.71383123099804, 3.764872890897095, 0.23696465097600594, 0.1510300801601261, 0.17138506838819012, 0.0922383509168867, 0.15438958973390982, 0.1409497405984439, 0.22906278201844543, 0.1481437639449723, 0.11711465122061782, 0.14002451993292198, 0.14031692611752078, 0.10135006901691668, 0.22083286894485354, 0.1442815235350281], [0.06934535122127272, 0.015621375532646198, 0.01526005815321696, 0.020390462887007743, 0.013898264478484634, 0.020247625434421934, 0.014747096811333904, 0.02810594145557843, 0.060590836219489574, 0.022451842996815685, 0.012415423734637443, 0.043196408660151064, 0.022801782324677333, 0.021250331883493345, 0.05567699481616728, 1.8705649324692786, 23.16456589847803, 44.87660273909569, 49.20096069574356, 37.62616999447346, 21.803154051303864, 33.3173494040966, 41.07164651155472, 40.9384560585022, 12.721095141023397, 0.017233311009476893, 0.2821389870950952, 2.142513133585453, 4.455074742436409, 5.8550953678786755, 12.560906186699867, 20.949961133301258, 32.777345180511475, 49.399728029966354, 52.65950471162796, 48.471088260412216, 49.44523438811302, 51.84421665966511, 49.450432509183884, 47.18875586986542, 44.587324261665344, 41.24072223901749, 39.27620865404606, 35.185085982084274, 36.852436512708664, 34.40846085548401, 40.63739061355591, 47.735755518078804, 47.49142102897167, 45.202792435884476, 45.47476664185524, 43.861555606126785, 42.313613668084145, 37.84520924091339, 35.311596393585205, 33.25607389211655, 33.774134293198586, 35.34570716321468, 37.85701900720596, 40.926707088947296, 41.56055107712746, 40.96858464181423, 35.703499764204025, 35.24612210690975, 33.6858194321394, 34.687031507492065, 35.819169357419014, 35.919191390275955, 34.451394751667976, 36.97771959006786, 39.6448078751564, 37.024137899279594, 35.52493594586849, 35.06379649043083, 33.30058470368385, 36.26898542046547, 40.35562053322792, 41.34501904249191, 43.31683963537216, 41.38597324490547, 42.04603582620621, 39.805303663015366, 38.59226815402508, 40.56478410959244, 43.109374567866325, 48.75776007771492, 46.33089870214462, 48.28261837363243, 35.711414739489555, 42.87111975252628, 51.37037828564644, 45.25972098112106, 45.15604354441166, 44.86089438199997, 44.93214435875416, 46.74357555806637, 48.45728360116482, 47.983741611242294, 48.06016691029072, 44.37781870365143, 35.88549479842186, 35.15512838959694, 34.38134931027889, 34.81516443192959, 35.621367171406746, 36.48559659719467, 35.67899487912655, 35.63913881778717, 35.4800109565258, 35.726515129208565, 37.300721257925034, 35.62319107353687, 37.27448746562004, 35.1080185174942, 37.899683117866516, 43.36953900754452, 47.86541976034641, 47.49862164258957, 47.952613681554794, 48.0231036990881, 44.84483264386654, 46.1635784804821, 48.12912181019783, 46.69317126274109, 50.84368854761124, 50.201636999845505, 48.699102625250816, 41.84206277132034, 35.672235041856766, 37.29216791689396, 40.29184855520725, 48.07152830064297, 51.86428338289261, 52.45868928730488, 53.90825070440769, 54.362919107079506, 54.60947647690773, 50.29817461967468, 47.37987421452999, 46.10718570649624, 49.033275693655014, 49.918586388230324, 53.0120649933815, 55.842430517077446, 56.60896718502045, 52.72244453430176, 27.14046735316515, 7.108073383569717, 1.87885454390198, 1.2933020456694067, 0.060760506021324545, 0.00465630641883763, 2.134993337094784, 40.38532353937626, 50.521230250597, 41.77289508283138, 26.998482272028923, 31.01835686713457, 49.23808090388775, 54.0843902528286, 25.76676696538925, 1.818599752150476, 0.016773929019109346, 0.07570160858449526, 0.018340723363508005, 0.0315312832390191, 0.028384120669215918, 0.0511411848856369, 0.024050692554737907, 0.08398460748139769, 0.01569228774314979, 0.018850691994884983, 0.031863060357864015, 0.06922806220245548, 0.031577578411088325, 0.11119097689515911, 0.09190264783683233, 0.028350948523439, 0.07272634597029537, 0.03377399414603133, 0.017159124072350096, 0.09569497051415965, 0.028245292669453193, 0.04413544069393538, 0.06300957713392563, 0.046029943332541734, 0.06086939392844215, 0.04881067419773899, 0.04845469935389701, 0.05847219013958238, 0.05458821964566596, 2.666663657873869, 26.758720837533474, 52.2649946808815, 53.86696211993694, 41.41068331897259, 25.57573601603508, 39.44252572953701, 40.90842247009277, 46.598343551158905, 14.267660602927208, 0.010335625374864321, 0.1613630764768459, 4.42202459089458, 5.813407329842448, 6.5298370365053415, 11.760729923844337, 15.015979148447514, 34.03904087841511, 50.402794405817986, 54.435103833675385, 50.811477676033974, 52.553638592362404, 52.88322910666466, 51.746603697538376, 48.68085600435734, 45.41089586913586, 43.90171945095062, 40.6181750446558, 37.61032484471798, 37.873578518629074, 35.92035032808781, 42.03180938959122, 49.35812026262283, 47.8182452917099, 45.65159775316715, 48.45378018915653, 45.87202772498131, 44.557853043079376, 40.53699620068073, 38.54086831212044, 35.55892892181873, 36.30798652768135, 37.237925827503204, 40.07829241454601, 43.39676834642887, 44.32319663465023, 43.27602222561836, 39.089266285300255, 37.71961838006973, 35.28807945549488, 37.26763643324375, 37.5992788374424, 37.634107768535614, 36.22120298445225, 38.22565242648125, 41.116791889071465, 38.36543932557106, 37.382701858878136, 36.249310076236725, 35.94966195523739, 37.19184190034866, 41.54368378221989, 43.51694069802761, 44.359112307429314, 43.79575073719025, 42.82693572342396, 42.48518966138363, 41.11293889582157, 43.251585736870766, 46.19773104786873, 50.64035005867481, 48.02248053252697, 48.69975998997688, 39.10074546933174, 43.38044822216034, 52.56582073867321, 48.544842302799225, 47.80346028506756, 47.08325073122978, 47.456607297062874, 47.53558225929737, 50.93856945633888, 49.05035577714443, 50.77982917428017, 46.1507161706686, 37.78745613992214, 38.081989735364914, 36.05183087289333, 35.93532532453537, 37.86073140799999, 38.10397915542126, 37.65987038612366, 35.90825937688351, 37.45583653450012, 38.03793489933014, 40.19244208931923, 37.407225742936134, 38.40942196547985, 37.604233771562576, 39.5514240860939, 46.83559902012348, 49.212987050414085, 49.020337387919426, 49.54059027135372, 50.12309901416302, 49.11304101347923, 48.00066590309143, 48.87232393026352, 51.037204563617706, 52.47632034122944, 53.441042974591255, 50.769717916846275, 42.14231126010418, 38.70365157723427, 37.93440565466881, 43.39014530181885, 51.17139056324959, 54.65777948498726, 53.200911059975624, 52.690499648451805, 54.39669169485569, 55.984056517481804, 52.44131661951542, 48.84942255914211, 48.87792482972145, 49.80377174913883, 51.244054064154625, 54.16549310088158, 56.38046644628048, 58.61040338873863, 54.683390110731125, 29.11950185894966, 9.035847689956427, 3.52858969476074, 2.9989118920639157, 0.32720982329919934, 0.1953301069443114, 2.7865348756313324, 42.90118373930454, 55.23744598031044, 44.45534214377403, 29.773190282285213, 35.50539739429951, 55.661955401301384, 62.250684052705765, 31.27326048910618, 2.420773389749229, 0.023767746897647157, 0.022378442736226134, 0.039984794275369495, 0.09199557214742526, 0.025504185068712104, 0.043089869650430046, 0.04982662612746935, 0.06740014505339786, 0.03460767831711564, 0.07559312143712305, 0.036390725217643194, 0.048307078759535216, 0.017007494025165215, 0.004469390960366582, 0.14174465497490019, 0.10434129522764124, 0.1242325895873364, 0.08516818459611386, 0.0689371551561635, 0.11040439683711156, 0.0946310350263957, 0.12404484848957509, 0.1787917170440778, 0.11083739547757432, 0.17805920244427398, 0.1331330553512089, 0.10568144323769957, 0.11371472428436391, 0.1149077266745735, 3.1641123024746776, 30.723302699625492, 59.463697001338005, 58.85216161608696, 48.745296746492386, 30.38100566715002, 43.060281202197075, 50.567830950021744, 53.28892953693867, 16.962487399578094, 0.11615487615927123, 1.0641249432228506, 6.251635439693928, 11.451205182820559, 13.29729052260518, 18.027868531644344, 24.15499985218048, 35.50194337964058, 53.60631510615349, 56.05369158089161, 50.970153361558914, 53.10933597385883, 54.340348318219185, 53.359449952840805, 52.89572283625603, 48.069579005241394, 45.623585656285286, 42.7930111438036, 39.38754267990589, 40.496266186237335, 37.96911679208279, 43.308628275990486, 52.306435257196426, 49.207781329751015, 46.48887142539024, 50.20108982920647, 49.03041824698448, 48.004100918769836, 42.565304562449455, 40.777686685323715, 36.71778693795204, 37.97209583222866, 38.268647119402885, 41.88338555395603, 45.34236654639244, 46.264717653393745, 45.36640785634518, 40.03627426922321, 39.4616387039423, 36.844950914382935, 39.531015381217, 39.809008464217186, 39.701535031199455, 36.781862899661064, 40.299790129065514, 42.56231032311916, 41.334277018904686, 39.87605966627598, 38.4391325712204, 37.62259058654308, 38.72121803462505, 44.67514894902706, 45.05089558660984, 47.72329978644848, 45.64654402434826, 46.60556696355343, 43.61261576414108, 43.61499443650246, 44.209119156003, 47.753618359565735, 53.536003679037094, 49.94743064045906, 48.89283522963524, 40.07595174014568, 46.0181450843811, 55.15292711555958, 51.67799457907677, 49.77310359477997, 50.59228263795376, 48.7284142524004, 50.35365164279938, 53.71955282986164, 51.636721193790436, 52.64744035899639, 49.23091448843479, 39.977981597185135, 39.37584310770035, 37.95834816992283, 37.80202455818653, 40.306728556752205, 40.52389070391655, 40.12352138757706, 38.97145740687847, 39.21409718692303, 39.51385170221329, 42.113075628876686, 38.81641812622547, 39.8859391361475, 40.19493095576763, 42.56513737142086, 48.6997751891613, 53.10609094798565, 50.28511852025986, 50.62114588916302, 53.54850120842457, 50.191286355257034, 50.81533446907997, 53.987685441970825, 53.05249482393265, 54.78042930364609, 55.28352990746498, 54.4303160905838, 45.61059795320034, 41.383480578660965, 41.324766129255295, 44.50057111680508, 53.032386302948, 58.16545486450195, 55.58177590370178, 54.80585753917694, 56.17822229862213, 59.39030773937702, 55.67537248134613, 52.764504477381706, 52.4019393324852, 51.811766400933266, 55.09162500500679, 58.053395077586174, 58.722140192985535, 61.225058287382126, 57.08388090133667, 30.25682833045721, 9.187560249119997, 4.838162111118436, 5.868563745170832, 0.9903477458283305, 0.23284432129003108, 3.3379311254248023, 47.18831889331341, 62.30252847075462, 54.67755742371082, 37.95227609574795, 43.01637075841427, 61.720335111021996, 69.86332476139069, 39.57589477300644, 3.7804211815819144, 0.0632178905652836, 0.1978835550835356, 0.13044612453086302, 0.19984000478871167, 0.15134415705688298, 0.20128312578890473, 0.11566497705643997, 0.1360182583448477, 0.08664422726724297, 0.10387690374045633, 0.14310461090644822, 0.09321136589278467, 0.08423877821769565, 0.19372190261492506], [0.04470955129363574, 0.0038254175933616352, 0.05812526578665711, 0.021915388970228378, 0.05269373556075152, 0.07053119188640267, 0.02390041136095533, 0.05846703592396807, 0.024598763047833927, 0.03563795740774367, 0.052160899504087865, 0.05277758711599745, 0.04796758330485318, 0.07679140791879036, 0.016825456332298927, 0.822172510670498, 19.18938260525465, 45.93301065266132, 46.402699649333954, 33.80105584859848, 17.424662299454212, 33.918290957808495, 50.66470295190811, 40.83294332027435, 20.548324584960938, 0.07060240095597692, 0.06589108423213474, 2.11320364382118, 5.3639052249491215, 1.9863354577682912, 16.973831690847874, 15.000590924173594, 36.568238362669945, 51.30136638879776, 52.24097236990929, 52.37454280257225, 50.492207407951355, 49.8372707515955, 52.04744875431061, 49.40289705991745, 47.09385596215725, 44.89758141338825, 44.29679565131664, 36.49729236960411, 36.143801137804985, 35.895549058914185, 44.17747065424919, 48.62278752028942, 46.838422268629074, 44.70168672502041, 46.88719645142555, 44.122567400336266, 40.890483632683754, 36.61556862294674, 35.9770242869854, 34.18842226266861, 34.286741986870766, 34.51906532049179, 34.6059400588274, 36.596759632229805, 36.27279281616211, 36.513433903455734, 36.98369286954403, 36.06635369360447, 35.63512623310089, 34.8206627368927, 35.487302765250206, 35.27781240642071, 33.96312855184078, 34.578931108117104, 34.33078922331333, 37.224033772945404, 35.5451774597168, 34.487272426486015, 35.08001022040844, 38.39691303670406, 41.20560832321644, 45.11035859584808, 50.59352897107601, 42.33268104493618, 44.765568897128105, 43.635486736893654, 40.87437629699707, 42.55322881042957, 43.0274623632431, 47.4690630286932, 49.42464329302311, 48.024319633841515, 35.83874210715294, 45.28298333287239, 50.43228842318058, 42.556831017136574, 46.388963386416435, 40.10956473648548, 43.7022415548563, 42.27984867990017, 45.672017857432365, 46.309505850076675, 45.267096385359764, 38.786346539855, 35.032337978482246, 36.84262923896313, 35.87991289794445, 35.51344156265259, 35.29380954802036, 34.541544914245605, 36.71383135020733, 36.13794565200806, 35.91080904006958, 36.67085565626621, 36.87361277639866, 35.201877281069756, 34.75663997232914, 34.50303018093109, 38.206965029239655, 44.926980435848236, 48.03666517138481, 47.9351270198822, 47.45057702064514, 50.084439888596535, 47.41216868162155, 46.184830740094185, 44.814035296440125, 47.28243984282017, 47.507896944880486, 43.218888491392136, 49.10826466977596, 51.30305729806423, 41.991915330290794, 35.03188580274582, 35.30721142888069, 39.222034960985184, 49.30065594613552, 53.9882630109787, 52.86893427371979, 54.77545917034149, 55.56783065199852, 54.23099398612976, 48.184640631079674, 50.4401084035635, 52.49171331524849, 53.456245958805084, 54.75250840187073, 54.84157182276249, 59.73364591598511, 50.29169976711273, 23.32751825451851, 6.862132530659437, 1.8713238229975104, 3.552817194722593, 0.14923546317731962, 0.02384017308941111, 3.382939947769046, 40.85460975766182, 50.52612818777561, 41.1606415361166, 34.679082334041595, 44.55300450325012, 50.13289488852024, 51.47893086075783, 25.18016394227743, 1.318737999536097, 0.04177625341981184, 0.04561719419143628, 0.057963232684414834, 0.04605626359989401, 0.08613519559730776, 0.029130353868822567, 0.08191505447030067, 0.007535935419582529, 0.0600376875809161, 0.08798887269222178, 0.09172715217573568, 0.0633974012453109, 0.06787784324842505, 0.01321312302025035, 0.06725257640937343, 0.027899906417587772, 0.0672983966069296, 0.02702499408769654, 0.0654800383199472, 0.03901390555256512, 0.01650348483963171, 0.01960128531209193, 0.0733774395484943, 0.025432760776311625, 0.07940220923046581, 0.037951521153445356, 0.014079630527703557, 0.07007313091889955, 0.013328744989848929, 0.9769268659874797, 22.88951575756073, 52.25171439349651, 53.15824314951897, 39.92168001830578, 19.96126178652048, 33.22252929210663, 55.79172223806381, 45.6230802834034, 21.552333310246468, 0.11262980828178115, 0.1856962137389928, 1.686552562750876, 4.440821232274175, 5.662879832088947, 7.983455210924149, 15.629605371505022, 36.74522526562214, 51.39117456972599, 53.5594180226326, 52.76173822581768, 53.60118918120861, 50.94602845609188, 53.195902928709984, 50.705094784498215, 50.05294717848301, 46.37776538729668, 44.88250382244587, 37.268282398581505, 38.55339623987675, 37.19434596598148, 46.13857962191105, 49.84772019088268, 48.026979491114616, 44.286300614476204, 47.50020615756512, 46.50210611522198, 43.19310687482357, 38.48958246409893, 37.7007257938385, 37.14388467371464, 35.480637922883034, 37.062040865421295, 37.50741496682167, 38.20916511118412, 37.83881038427353, 37.91109390556812, 37.44743898510933, 36.52740195393562, 36.26233197748661, 36.26749590039253, 36.45023189485073, 37.28620603680611, 36.03093199431896, 36.73553578555584, 38.338817954063416, 38.57500948011875, 37.119261994957924, 36.860438883304596, 36.186412051320076, 39.29113805294037, 43.29992674291134, 45.55528052151203, 52.25396767258644, 46.3909924775362, 45.96788138151169, 45.10734535753727, 43.27390193939209, 44.87376049160957, 45.83932667970657, 49.58603583276272, 48.89262244105339, 49.34823699295521, 37.615355774760246, 48.579203858971596, 52.66499161720276, 45.38956381380558, 47.6505146920681, 42.793360725045204, 45.885710790753365, 46.94457337260246, 48.78543399274349, 48.01369160413742, 48.15703511238098, 40.88251546025276, 36.854359209537506, 39.27456334233284, 38.545789048075676, 37.888473719358444, 37.1319343149662, 36.38164557516575, 36.97692923247814, 39.01951722800732, 37.24304035305977, 38.26208487153053, 37.993667274713516, 37.84519404172897, 36.4934241771698, 36.936826184391975, 39.51081186532974, 47.15913265943527, 50.60649387538433, 49.49705220758915, 47.745008021593094, 51.485599502921104, 48.82346235215664, 48.8530969619751, 48.18081043660641, 50.191844925284386, 48.108169734478, 45.040807127952576, 50.197898000478745, 52.64922246336937, 43.05328957736492, 37.410786151885986, 37.46791988611221, 42.53449961543083, 50.76426900923252, 56.38355188071728, 54.76676903665066, 55.87908335030079, 58.92536088824272, 56.35496221482754, 50.7635622471571, 52.64873988926411, 55.37970654666424, 55.08371762931347, 57.75301739573479, 57.238323614001274, 59.259435161948204, 52.78460919857025, 26.507974192500114, 8.12995919957757, 3.781041973270476, 2.240925715304911, 0.17157021939055994, 0.0545048393541947, 3.4468546556308866, 43.933227360248566, 55.83127811551094, 47.89672248065472, 33.038657158613205, 46.29671573638916, 55.36207549273968, 59.98878322541714, 30.46646688133478, 2.1042966842651367, 0.1151850821042899, 0.05708943172066938, 0.02190442002756754, 0.04027006471005734, 0.048531496795476414, 0.025413214461877942, 0.0938611532910727, 0.04680826699768659, 0.030472004727926105, 0.07730738609097898, 0.06127809465397149, 0.0876443825836759, 0.05682887109287549, 0.024015345916268416, 0.11895502160768956, 0.10296893058693968, 0.20999072963604704, 0.1619456327171065, 0.13685451034689322, 0.15746236313134432, 0.19105802290141582, 0.09924019512254745, 0.1458559453021735, 0.11070573847973719, 0.27651445765513927, 0.18725473870290443, 0.13843197491951287, 0.2003957101260312, 0.1444562547840178, 1.1404363671317697, 26.285129450261593, 60.1395021378994, 59.559550657868385, 45.43241411447525, 27.642051838338375, 42.26673938333988, 60.0960286706686, 51.336461305618286, 26.930802203714848, 0.2502432611072436, 0.5315222474746406, 5.651209708303213, 12.292069662362337, 8.927043378353119, 22.548913434147835, 18.558348566293716, 39.762631952762604, 53.47182512283325, 56.562488079071045, 54.56243880093098, 53.75792697072029, 52.04438991844654, 55.94504401087761, 53.89675252139568, 52.247394025325775, 48.22182923555374, 47.92713604867458, 40.458063036203384, 39.585538655519485, 39.649576619267464, 47.93672293424606, 52.035741582512856, 47.993716076016426, 46.1106663197279, 49.145251885056496, 48.74091938138008, 45.66909201443195, 40.57214051485062, 40.34604884684086, 37.647999823093414, 37.0099912583828, 39.47080381214619, 39.231211468577385, 41.24620534479618, 39.59279626607895, 39.50953133404255, 39.68068554997444, 39.74501229822636, 38.66592340171337, 38.431696370244026, 38.78307491540909, 39.9002605676651, 38.969694301486015, 38.70601885020733, 38.93177233636379, 40.24254620075226, 38.35419952869415, 37.575324922800064, 38.24702247977257, 40.265816152095795, 46.32560558617115, 48.48944887518883, 53.74067969620228, 49.04695875942707, 48.773552030324936, 46.58203102648258, 45.0678426772356, 46.59515552222729, 46.524931490421295, 51.803251057863235, 52.54020631313324, 50.97453072667122, 40.01333490014076, 51.990626603364944, 53.36239479482174, 46.90719097852707, 51.28735274076462, 45.76722554862499, 48.32415394484997, 49.136538952589035, 51.38647802174091, 51.58888176083565, 51.427751407027245, 43.15718360245228, 39.38402406871319, 40.76922073960304, 39.91362065076828, 39.312675297260284, 39.23547863960266, 39.352652952075005, 39.5663420855999, 41.6429952532053, 39.605688974261284, 40.6426153331995, 39.42971661686897, 38.65211874246597, 37.582407742738724, 38.30718845129013, 42.46507354080677, 50.54917775094509, 52.601155042648315, 52.276986837387085, 49.86444689333439, 53.71075250208378, 53.99655416607857, 51.761430501937866, 51.305983141064644, 52.22403287887573, 48.09721112251282, 47.42536157369614, 52.938246354460716, 55.12293912470341, 46.06664568185806, 39.34173233807087, 39.8651884496212, 43.78299102187157, 52.396653816103935, 58.01226228475571, 57.47427195310593, 55.46360224485397, 60.03971189260483, 58.222394809126854, 52.257022708654404, 56.04384630918503, 58.150073289871216, 58.26197728514671, 59.99883368611336, 60.70133239030838, 62.73648798465729, 54.515211135149, 27.187799513339996, 10.295245461165905, 4.706824058666825, 9.39485052600503, 0.6322515767533332, 0.1440077749430202, 4.436541236937046, 48.73066373169422, 61.964513808488846, 54.72443550825119, 47.882040068507195, 57.44287423789501, 60.91136991977692, 69.73040029406548, 36.76424704492092, 2.6730036176741123, 0.38357288169208914, 0.21944249980151653, 0.15467755787540227, 0.12508974788943306, 0.14446554647292942, 0.1489745537401177, 0.24224816355854273, 0.1980995200574398, 0.15455523709533736, 0.20557279873173684, 0.1796609500888735, 0.25366150424815714, 0.13456639484502375, 0.11641059056273662], [0.07958171248901635, 0.0367425106378505, 0.008690808117535198, 0.01952642858668696, 0.05721640947740525, 0.03745378868188709, 0.021585105423582718, 0.05691598809789866, 0.027653854776872322, 0.02939751404483104, 0.06881712761241943, 0.0417199355433695, 0.10177445874433033, 0.009871381389530143, 0.09280282843974419, 0.2521355595672503, 10.9528942219913, 43.31752359867096, 54.21840526163578, 36.40499532222748, 28.58743730932474, 21.805530823767185, 24.162437953054905, 45.39593227207661, 25.810664109885693, 1.1725913104601204, 0.1435526751447469, 3.2697520963847637, 2.7321156207472086, 5.638380171731114, 3.410880798473954, 15.421825870871544, 40.946146845817566, 49.013691544532776, 52.993537187576294, 51.91208101809025, 49.380288273096085, 49.268460273742676, 51.551799550652504, 50.80723710358143, 50.91197468340397, 46.70135222375393, 43.64619456231594, 38.58395040035248, 35.28641514480114, 37.72932305932045, 45.986196398735046, 51.290422976017, 48.272134736180305, 44.25374776124954, 44.463815689086914, 46.258808970451355, 41.93872198462486, 41.17348104715347, 35.86337998509407, 34.693316370248795, 33.87828290462494, 35.294060334563255, 33.43823231756687, 33.587074130773544, 35.636098980903625, 36.643649116158485, 34.49384227395058, 37.33043186366558, 35.949494764208794, 35.893569365143776, 34.91424411535263, 36.68794333934784, 34.77831020951271, 34.80869337916374, 35.89579604566097, 36.78825035691261, 34.9714158475399, 36.1355821788311, 34.44697178900242, 38.729649782180786, 42.8282580524683, 49.795370399951935, 41.497444063425064, 43.89836423099041, 45.84287948906422, 45.90963810682297, 44.32033158838749, 45.25274455547333, 45.86068153381348, 46.96568503975868, 45.87053060531616, 44.035092294216156, 40.34879229962826, 45.90219810605049, 49.14473131299019, 44.66808892786503, 40.33924341201782, 37.45138697326183, 39.14128169417381, 38.954362124204636, 39.90832753479481, 38.54765094816685, 37.497489899396896, 35.15480540692806, 36.531289145350456, 35.47950938344002, 35.87169013917446, 36.486766934394836, 36.60638831555843, 36.062576696276665, 35.90591870248318, 35.12688830494881, 36.14959582686424, 35.522245690226555, 37.676042318344116, 36.55082769691944, 34.556808695197105, 35.45784294605255, 36.55533045530319, 44.73368860781193, 46.51586517691612, 47.95503415167332, 46.42761491239071, 43.352059945464134, 46.31857976317406, 45.413141548633575, 49.17980723083019, 49.938808903098106, 49.41745787858963, 48.42541851103306, 49.25949275493622, 49.097237661480904, 50.68736493587494, 40.916063860058784, 34.92177151143551, 38.04930008947849, 44.02400828897953, 51.81569918990135, 55.56550897657871, 52.62602470815182, 54.74867060780525, 54.202871695160866, 52.16382510960102, 55.054318606853485, 58.1854759901762, 57.40922324359417, 57.68709093332291, 58.21018606424332, 58.30515816807747, 42.70633399486542, 17.653972394764423, 2.7975041745230556, 3.8793709594756365, 2.0450246147811413, 0.3082025604089722, 0.23324591224081814, 2.530254302546382, 40.17358750104904, 51.34973019361496, 43.76095600426197, 31.548521518707275, 29.535896815359592, 42.18982011079788, 56.502299308776855, 20.51081109791994, 1.1463608429767191, 0.03643552496214397, 0.025396167329745367, 0.08805306846625172, 0.0356652832851978, 0.06907046714331955, 0.05168796960788313, 0.08032825367990881, 0.05098540808830876, 0.007746652945570531, 0.015970094027579762, 0.04228686215355992, 0.054887720762053505, 0.03429314499953762, 0.032737455039750785, 0.02371249585849, 0.04062436972162686, 0.006733937707394944, 0.03974705839937087, 0.023848624296078924, 0.07286909807589836, 0.05867192434379831, 0.05241347462288104, 0.04503273805312347, 0.026591952773742378, 0.050997590442420915, 0.055001985529088415, 0.06437973017455079, 0.025890504475682974, 0.027496139118738938, 0.3042574814753607, 15.231123603880405, 51.559475138783455, 58.61170291900635, 42.72433362901211, 29.86658927053213, 25.712393783032894, 35.76139725744724, 50.86201496422291, 28.531597405672073, 1.0483379778452218, 0.18271855398779735, 1.0077806166373193, 3.3718352811411023, 6.892383182421327, 5.540459426119924, 12.378525473177433, 40.158411115407944, 52.73694835603237, 53.34888651967049, 53.10103341937065, 50.73632150888443, 50.86010366678238, 52.50948116183281, 52.179788053035736, 50.97930707037449, 49.10021290183067, 45.925544053316116, 39.259390756487846, 34.556576907634735, 40.745859593153, 47.94868849217892, 52.57964439690113, 47.86110319197178, 45.19105486571789, 45.656461492180824, 49.34356704354286, 44.92476895451546, 42.11229287087917, 37.8878353536129, 35.9424689412117, 36.563154235482216, 36.58136285841465, 36.48415647447109, 35.38310095667839, 36.26467265188694, 38.25503624975681, 36.521280482411385, 38.834660947322845, 36.964815482497215, 37.36763946712017, 36.96148306131363, 37.10331045091152, 36.80805869400501, 37.67161935567856, 37.489711716771126, 38.16350296139717, 36.69546693563461, 36.79276071488857, 35.98100267350674, 40.22318623960018, 44.897858798503876, 50.08906044065952, 45.10383054614067, 46.36736914515495, 48.84422443807125, 47.935336008667946, 47.30942979454994, 46.989509761333466, 47.27289475500584, 48.72834965586662, 48.675958067178726, 46.32837563753128, 41.80673226714134, 48.212930113077164, 51.35992504656315, 47.84612439572811, 42.87725642323494, 38.276767283678055, 40.141562819480896, 41.76952086389065, 42.17379257082939, 41.71524457633495, 39.91340406239033, 35.907237231731415, 38.23326341807842, 37.07726664841175, 37.47148409485817, 38.613395020365715, 38.57473209500313, 38.29124070703983, 37.18569003045559, 37.03704960644245, 37.948191314935684, 37.81958721578121, 39.43928450345993, 37.55919098854065, 36.95030406117439, 37.47590705752373, 38.20978827774525, 46.801917627453804, 49.32744450867176, 50.812910199165344, 47.0037741959095, 45.42414955794811, 48.02265912294388, 46.916629672050476, 50.91430015861988, 52.24390961229801, 50.078755393624306, 48.65620292723179, 50.20784966647625, 51.71761505305767, 53.86258475482464, 42.00619116425514, 36.618669256567955, 39.50711466372013, 45.312355756759644, 55.47822006046772, 58.93006503582001, 53.7752578407526, 56.28903955221176, 54.69770394265652, 54.33662831783295, 57.3950158059597, 60.874743685126305, 59.15554493665695, 60.24064131081104, 60.04322670400143, 59.62013080716133, 45.353055372834206, 22.008633725345135, 5.44353517703712, 6.458152458071709, 4.310865830630064, 0.23489717597840354, 0.12510709930211306, 2.7890206547454, 42.83955864608288, 56.73082284629345, 45.92909686267376, 37.93210677802563, 40.139339938759804, 48.69641236960888, 63.88266608119011, 27.379902005195618, 1.5693527203984559, 0.037348481637309305, 0.05080702176201157, 0.04320235697377939, 0.08562640883610584, 0.003048454609597684, 0.05386950899264775, 0.05158449195732828, 0.03845946928777266, 0.049367585525033064, 0.022422248002840206, 0.04791743638634216, 0.0626329223450739, 0.0542921732267132, 0.12252064043423161, 0.25044263165909797, 0.14137525839032605, 0.12160496378783137, 0.11182525340700522, 0.14817818475421518, 0.24967664619907737, 0.13079327152809128, 0.191676217073109, 0.22770618059439585, 0.16637315216939896, 0.30130124010611326, 0.11971425352385268, 0.1790569903096184, 0.11349510052241385, 0.18140695639885962, 0.4764703562250361, 16.49614032357931, 59.406912848353386, 69.26583722233772, 49.44603614509106, 38.347511887550354, 31.972707957029343, 34.952751249074936, 58.709414675831795, 33.26550118625164, 1.4458392793312669, 0.26884590508416295, 6.4837003871798515, 11.539510544389486, 11.444917470216751, 7.656872235238552, 17.4894792214036, 40.537322983145714, 53.1632474809885, 55.6350452452898, 55.660275891423225, 51.91926263272762, 52.08396099507809, 54.08114902675152, 54.49671372771263, 54.001448303461075, 51.78810507059097, 48.275744542479515, 42.07597441971302, 38.001460656523705, 41.035886630415916, 50.977426171302795, 55.6732901930809, 49.151133969426155, 46.1909294128418, 45.912757739424706, 51.16575546562672, 46.418392807245255, 45.42691580951214, 39.88041043281555, 38.26482832431793, 38.47788669168949, 37.15403012931347, 37.63281583786011, 35.98126105964184, 39.15843777358532, 39.19554278254509, 37.30631835758686, 40.953032076358795, 39.39545765519142, 38.75327691435814, 39.06087800860405, 39.103568717837334, 38.47717992961407, 39.151712134480476, 39.99962143599987, 39.557222574949265, 38.508159667253494, 39.899827390909195, 38.39628227055073, 41.77480258047581, 47.1828243881464, 51.16524629294872, 45.76489247381687, 49.1386516392231, 50.413882210850716, 50.076027140021324, 51.6943185031414, 49.27104413509369, 49.5319951325655, 50.29627092182636, 52.03940458595753, 46.67176701128483, 43.6454764008522, 51.428522765636444, 53.798945769667625, 50.922887697815895, 45.026253908872604, 41.79463751614094, 44.32709522545338, 44.70363602042198, 44.736002683639526, 41.96352705359459, 41.06607601046562, 37.61108100414276, 41.210468262434006, 39.146077036857605, 39.26235839724541, 39.17484149336815, 41.808955147862434, 40.138971358537674, 38.65760184824467, 39.417808055877686, 38.66421729326248, 39.501646757125854, 40.22842615842819, 39.67305935919285, 37.32353523373604, 39.49167609214783, 39.07632797956467, 49.9403440207243, 52.462682873010635, 52.72270292043686, 49.450873285532, 48.04848253726959, 50.19390061497688, 49.10308174788952, 52.014432325959206, 53.5533307492733, 53.34136672317982, 50.188318714499474, 51.063039377331734, 53.27190265059471, 55.481799468398094, 45.43868377804756, 38.678823709487915, 42.521983087062836, 46.98188737034798, 56.6487130522728, 61.364001631736755, 56.73762448132038, 58.0799176543951, 57.254924923181534, 56.75565831363201, 59.892234206199646, 64.06224444508553, 61.31595320999622, 63.81290182471275, 62.247245237231255, 62.06039406359196, 46.568382158875465, 21.451427824795246, 4.856299487873912, 8.2433270663023, 5.45599470846355, 1.002676896750927, 0.5664940865244716, 3.220780799165368, 48.937311843037605, 64.41751778125763, 54.908007457852364, 43.160079047083855, 43.88503834605217, 54.65818986296654, 72.50442624092102, 35.24662747979164, 2.328669656999409, 0.15267807844793424, 0.24408106051851064, 0.11929411630262621, 0.18407227587886155, 0.17590905219549313, 0.1572487730300054, 0.14043587754713371, 0.1083066793216858, 0.14413650787901133, 0.13034801260801032, 0.15673127345507964, 0.14956552593503147, 0.1633314450737089, 0.22220349695999175], [0.11879237994435243, 0.041671109647722915, 0.0605216903204564, 0.023927922775328625, 0.08712613343959674, 0.030928805899748113, 0.04792197833012324, 0.06813645944930613, 0.030072437984927092, 0.02867533199605532, 0.027001644266420044, 0.013028156627115095, 0.13574896263889968, 0.03153664896672126, 0.06208090919244569, 0.061937745194882154, 7.9002411011606455, 38.41368533670902, 49.42929804325104, 39.378943741321564, 25.510981790721416, 20.649190172553062, 35.854826644062996, 44.69321317970753, 30.360192283988, 2.7545997267588973, 0.10282963688950986, 0.18894129898399115, 2.327975006774068, 3.7475320464000106, 3.349507204256952, 11.828324496746063, 35.19781909883022, 52.85389848053455, 53.117475137114525, 49.02402698993683, 50.69025278091431, 49.589121267199516, 51.415128484368324, 49.56142835319042, 49.54866863787174, 50.0856976211071, 46.50715984404087, 39.39645320177078, 34.272720739245415, 37.98571430146694, 44.07155133783817, 48.57481509447098, 49.46454495191574, 47.590869292616844, 46.133928671479225, 45.86192026734352, 44.48851056396961, 41.82766154408455, 39.117848351597786, 37.48995490372181, 34.54476714134216, 34.12628039717674, 36.52929425239563, 35.63846245408058, 35.08451297879219, 35.38054369390011, 35.450376346707344, 34.24237176775932, 33.97992745041847, 37.498329654335976, 36.297331899404526, 36.84686601161957, 35.364231169223785, 35.37258692085743, 34.521668180823326, 36.575511172413826, 37.78161205351353, 33.16120818257332, 34.38268303871155, 38.619516491889954, 48.0114421248436, 43.46178285777569, 38.61324682831764, 49.40391920506954, 44.039918035268784, 46.89927980303764, 42.79396869242191, 45.44459626078606, 43.969226628541946, 49.52525809407234, 44.07983869314194, 44.96489480137825, 38.72496843338013, 46.80721074342728, 49.6389289945364, 44.66882608830929, 42.237089574337006, 37.80778504908085, 35.21176815032959, 34.34441149234772, 35.85879743099213, 34.03523728251457, 35.58314122259617, 36.77163764834404, 34.52112101018429, 35.08449397981167, 34.97305355966091, 33.920692428946495, 36.758007779717445, 36.81416116654873, 35.39046496152878, 35.3674153983593, 36.25316686928272, 36.35063923895359, 35.49939751625061, 36.36011213064194, 34.831146374344826, 36.36664018034935, 36.19782283902168, 43.279282450675964, 46.17758072912693, 47.57421858608723, 49.068898782134056, 47.52648934721947, 50.99931299686432, 48.22782911360264, 48.42278905212879, 48.43251273036003, 49.90737698972225, 50.34548208117485, 50.423476696014404, 51.04968309402466, 49.300667345523834, 51.58179134130478, 39.21486474573612, 35.178535133600235, 38.17517213523388, 48.49313847720623, 52.142280265688896, 53.03243190050125, 52.622027322649956, 55.55157892405987, 54.56550903618336, 55.40872558951378, 56.11823111772537, 57.68020570278168, 57.20119580626488, 49.95330132544041, 54.44760136306286, 40.24313136935234, 14.617822263389826, 3.547967942431569, 4.989621983841062, 2.0413174387067556, 0.05292190515319817, 0.07357862836215645, 2.366607771255076, 39.874383956193924, 54.31526206433773, 42.99978084862232, 19.825466573238373, 28.548056222498417, 41.96383483707905, 52.001535817980766, 24.096082113683224, 1.2175191496498883, 0.0587762777286116, 0.047688420745544136, 0.05998273154546041, 0.05353966887923889, 0.04021412161819171, 0.04377061202831101, 0.012610844205482863, 0.039132456222432666, 0.04493438493227586, 0.026546904409769922, 0.11218512823688798, 0.009857869663392194, 0.038585634392802604, 0.018213949697383214, 0.010959474711853545, 0.04913812459562905, 0.06390376860508695, 0.04700395278632641, 0.05986319010844454, 0.06329791634925641, 0.03287280793301761, 0.061981743419892155, 0.015509171153098578, 0.04034042402054183, 0.06349139424855821, 0.11941027725697495, 0.02587032548035495, 0.05168863011931535, 0.020174401433905587, 0.07308042462682351, 9.955315701663494, 43.73856760561466, 57.828846126794815, 44.50780212879181, 31.43951866775751, 23.226415179669857, 35.029533728957176, 50.89071102440357, 33.18429574370384, 2.442554058507085, 0.02509999474568758, 0.6490086182020605, 2.2444863617420197, 6.381047945469618, 4.960588216781616, 16.910327598452568, 34.425111562013626, 54.19576607644558, 54.257417768239975, 52.612311244010925, 52.20856010913849, 51.50839827954769, 51.95670202374458, 50.50551049411297, 49.95448686182499, 52.40291588008404, 47.60133393108845, 39.66698728501797, 36.19889818131924, 39.78214010596275, 46.18336021900177, 50.00935971736908, 49.29727412760258, 47.19289004802704, 46.73767447471619, 49.3237891048193, 46.89364090561867, 44.61736924946308, 39.73880723118782, 40.27798309922218, 36.28260388970375, 36.5191487967968, 37.258019149303436, 36.50969870388508, 35.86660221219063, 36.92131161689758, 36.46762736141682, 36.50900334119797, 35.49187771975994, 38.65061402320862, 37.84215420484543, 36.92294932901859, 37.19861313700676, 35.68804979324341, 38.276622891426086, 37.71583378314972, 39.13291834294796, 35.31524799764156, 36.006598100066185, 41.427607610821724, 49.484759867191315, 47.01834261417389, 41.31886504590511, 50.63122294843197, 46.662503108382225, 48.96441958844662, 44.87634435296059, 48.6516697704792, 47.42402784526348, 50.30846446752548, 46.766784712672234, 45.54184444248676, 41.09034910798073, 49.715988859534264, 51.34677395224571, 46.15314044058323, 42.818804159760475, 39.05419036746025, 38.54847550392151, 36.346493661403656, 37.08479784429073, 36.22262790799141, 38.02000746130943, 37.567865923047066, 36.90845690667629, 36.95136800408363, 37.86043122410774, 37.30233617126942, 38.61783318221569, 38.0123470723629, 36.43743418157101, 37.035981863737106, 37.9982004314661, 38.3505517244339, 37.017328664660454, 38.027014285326004, 38.45394417643547, 37.395434975624084, 38.16005654633045, 45.125736370682716, 49.556002244353294, 50.44246047735214, 51.90670430660248, 52.25317731499672, 52.490094602108, 49.46902111172676, 50.049812346696854, 51.31371192634106, 52.05569811165333, 53.350265845656395, 52.163692116737366, 51.82314679026604, 52.5642704218626, 52.28442683815956, 40.41293665766716, 37.42144837975502, 40.23111641407013, 49.217299818992615, 56.4165873080492, 54.43532042205334, 54.220449551939964, 56.99919864535332, 56.96729175746441, 57.436539977788925, 57.45963513851166, 58.962982669472694, 59.931961074471474, 52.167541310191154, 56.29513822495937, 41.724291890859604, 12.992206793278456, 2.630256861448288, 3.6333771469071507, 2.7876845514401793, 0.2021223315387033, 0.010777236639114562, 2.7297697216272354, 43.318146765232086, 60.36600038409233, 52.15743765234947, 28.132972195744514, 34.43802706897259, 48.91803167760372, 59.50968973338604, 29.505635239183903, 1.490783505141735, 0.0580897465988528, 0.06537176639540121, 0.008011614972929237, 0.012961584125150694, 0.030866664019413292, 0.021472775806614663, 0.04940128274029121, 0.04677234705013689, 0.04559548637189437, 0.02840850949723972, 0.007192273733380716, 0.0372539802629035, 0.03183600536431186, 0.02443763351038797, 0.2576628973474726, 0.17816645762650296, 0.2631129033397883, 0.09524832377792336, 0.14977507875300944, 0.18390008277492598, 0.2514244633493945, 0.18804177147103474, 0.09439840141567402, 0.10392295400379226, 0.2379395955358632, 0.3414764249464497, 0.1942071781377308, 0.10557486340985633, 0.10724528197897598, 0.10915892460616305, 11.465600710362196, 51.13465033471584, 63.960979878902435, 51.39861837029457, 35.690515860915184, 29.011570550501347, 45.041810274124146, 57.767859399318695, 38.5436687618494, 3.3567028306424618, 0.277526123682037, 1.3996442081406713, 7.227116720750928, 13.191931676119566, 6.708236513659358, 14.524684511125088, 38.9954949170351, 54.60872411727905, 55.56650072336197, 52.20903888344765, 54.53884206712246, 52.457047775387764, 54.203684851527214, 52.22788207232952, 51.14968612790108, 55.10593123733997, 49.83364574611187, 43.23994316160679, 38.29998403787613, 41.45075976848602, 48.56315352022648, 52.68112555146217, 51.72233060002327, 48.062385991215706, 48.41701336205006, 49.65664364397526, 49.64995600283146, 46.53399020433426, 41.982560232281685, 41.83020740747452, 38.035761415958405, 38.94514761865139, 39.13914620876312, 38.44156824052334, 37.56625100970268, 38.36687184870243, 38.6012926697731, 38.068785443902016, 37.46161602437496, 41.40138901770115, 39.86275278031826, 39.44219894707203, 38.21827322244644, 37.78859607875347, 40.01743488013744, 39.71034295856953, 41.46408185362816, 36.446736082434654, 39.093734845519066, 44.094878286123276, 51.34107045829296, 48.18111442029476, 43.30438770353794, 52.52681203186512, 47.849095836281776, 52.1851609647274, 47.1788763999939, 51.39717064797878, 49.31811600923538, 53.56546729803085, 49.539100751280785, 46.0131711512804, 42.14856192469597, 51.80233910679817, 53.27216863632202, 47.16501094400883, 46.76208436489105, 40.997846871614456, 41.02990195155144, 37.40061029791832, 38.923010006546974, 37.897315844893456, 39.00401405990124, 39.16637934744358, 38.74032340943813, 38.965928703546524, 39.36188645660877, 38.930427208542824, 40.42976215481758, 39.88597333431244, 38.766564801335335, 41.058472618460655, 38.91606777906418, 39.483639523386955, 38.27916495501995, 39.21907491981983, 39.47985112667084, 39.66057322919369, 41.17701105773449, 47.33376368880272, 52.950037121772766, 51.67969308793545, 54.17227953672409, 55.7623004168272, 54.651798605918884, 51.239783093333244, 53.11331816017628, 53.19127097725868, 55.01766577363014, 54.98721040785313, 56.55989661812782, 54.51216369867325, 53.317610397934914, 54.98606286942959, 42.30591908097267, 39.56332124769688, 43.063883408904076, 51.62699371576309, 57.28641763329506, 56.30738876760006, 54.13676284253597, 59.89064209163189, 60.505977272987366, 59.799363389611244, 60.95917895436287, 60.288252755999565, 63.10682371258736, 51.67164511978626, 58.713583052158356, 42.768312469124794, 18.6216626688838, 5.627071978524327, 12.128308899700642, 5.599146327003837, 0.4226594843203202, 0.27001282840501517, 3.247161121107638, 48.28321874141693, 67.73354664444923, 56.09940692782402, 31.21868971735239, 40.71146383881569, 55.05069740116596, 68.0913582444191, 36.842249259352684, 2.5640888744965196, 0.2109896604088135, 0.15696361020673066, 0.1971300080185756, 0.14986643713200465, 0.11170469893841073, 0.12035604057018645, 0.16603333759121597, 0.153916455747094, 0.1190963042608928, 0.0673903561255429, 0.2202731411671266, 0.16176521661691368, 0.18578145682113245, 0.10027859330875799], [0.05165186412341427, 0.03424202586757019, 0.025475562288193032, 0.018216747594124172, 0.006322131557681132, 0.021186651902098674, 0.10533540946198627, 0.02667430519068148, 0.015195171254163142, 0.02297973263921449, 0.025549791898811236, 0.022947618053876795, 0.04887032802798785, 0.018416461389278993, 0.030250019080995116, 0.010865334206755506, 3.976729097776115, 31.489655077457428, 50.836278945207596, 41.63572624325752, 23.280127197504044, 22.83796962350607, 32.397456765174866, 43.69112715125084, 37.52841264009476, 5.383559670299292, 0.02242220718471799, 0.3855466382810846, 1.0408236435614526, 4.054828444495797, 4.778656829148531, 3.96547956392169, 31.53547491878271, 51.44971422851086, 54.91084970533848, 49.97026361525059, 50.44248327612877, 52.070787101984024, 51.134137362241745, 50.18098510801792, 50.16469158232212, 48.5419050604105, 45.43661288917065, 36.1092571914196, 36.492117047309875, 37.59829469025135, 39.75856237113476, 44.36683729290962, 47.637663781642914, 48.18253934383392, 44.560706689953804, 46.99895605444908, 48.821547254920006, 45.25569699704647, 41.41792573034763, 39.42975081503391, 36.56637266278267, 35.38943141698837, 34.93029065430164, 34.277436286211014, 34.28586423397064, 35.67449972033501, 37.071703746914864, 35.78043043613434, 36.3872616738081, 35.49676425755024, 36.782497465610504, 37.586104944348335, 35.89897647500038, 35.244100615382195, 35.45605704188347, 35.93111515045166, 38.18578876554966, 34.27525520324707, 35.246160104870796, 41.83600589632988, 44.746573716402054, 39.473152086138725, 47.136873453855515, 49.52487051486969, 48.22499826550484, 48.19022633135319, 46.461946070194244, 47.74988695979118, 47.591762244701385, 48.78780886530876, 44.02337372303009, 44.200489819049835, 41.342526376247406, 46.333516761660576, 50.57063899934292, 43.313138633966446, 40.255587100982666, 36.2098453938961, 34.73495453596115, 33.93538624048233, 34.014874175190926, 35.30355982482433, 36.572387740015984, 36.890468671917915, 36.233753710985184, 35.931419134140015, 35.60211360454559, 33.9939296990633, 35.19296295940876, 37.13421419262886, 35.29485069215298, 36.57010406255722, 35.187951028347015, 37.116210758686066, 36.486774533987045, 35.90238109230995, 36.820202842354774, 36.75695523619652, 36.115203872323036, 38.03482286632061, 47.082353979349136, 46.74691557884216, 49.12276089191437, 53.50801058113575, 45.693471506237984, 47.17943117022514, 44.176718294620514, 45.649344474077225, 43.44657227396965, 43.43175686895847, 45.34360148012638, 51.17730684578419, 50.500927940011024, 51.064593493938446, 48.56202118098736, 39.757342636585236, 34.71075363457203, 40.185157880187035, 51.9839009642601, 53.57878938317299, 52.214723378419876, 54.724294915795326, 56.98239214718342, 58.734470531344414, 56.26877523958683, 52.87293925881386, 54.31428551673889, 56.418475806713104, 54.7787269949913, 33.732526525855064, 7.2595389559865, 1.0372058814391494, 2.8668934386223555, 3.5633129440248013, 0.2574939251644537, 0.0123880783758068, 2.8750157402828336, 40.63148953020573, 52.370439022779465, 43.098765537142754, 33.1117994338274, 33.16198334097862, 48.62648472189903, 51.95239305496216, 28.875083774328232, 1.4726678584702313, 0.04430107321240939, 0.05505458524567075, 0.05833891897054855, 0.0392254027974559, 0.01668413657171186, 0.008689608621352818, 0.08882032299879938, 0.01539186914669699, 0.03144328307826072, 0.03689064702484757, 0.025828373727563303, 0.056599065064801835, 0.013804247355437838, 0.08753075235290453, 0.018529347617004532, 0.095041071617743, 0.011372499375283951, 0.04332620286731981, 0.03041784279048443, 0.03494108073937241, 0.06711820315103978, 0.04882183980953414, 0.02927025612734724, 0.08808604208752513, 0.05407521006418392, 0.02576566781499423, 0.03437164195929654, 0.06952550756977871, 0.06357924969051965, 0.08367863483726978, 5.505024427548051, 39.44267012178898, 56.62602826952934, 46.7911110073328, 27.683862894773483, 23.722849041223526, 38.704267144203186, 48.188406229019165, 41.324070766568184, 5.27660395950079, 0.006643360438829404, 0.2986546227475628, 2.808031984604895, 3.0394355300813913, 4.711625101044774, 7.474420750513673, 33.558974638581276, 54.37881365418434, 56.9713993370533, 50.93631237745285, 51.53463967144489, 53.86549539864063, 52.79073067009449, 51.822261437773705, 50.87664037942886, 51.61623649299145, 47.73343004286289, 37.850099578499794, 37.04250231385231, 39.52677480876446, 43.227650821208954, 46.51345990598202, 48.747637420892715, 49.655963480472565, 47.905047833919525, 48.510214760899544, 49.02058057487011, 45.96345841884613, 42.890673503279686, 39.69441421329975, 37.75070831179619, 36.39959201216698, 34.589000567793846, 35.39246365427971, 36.64832666516304, 37.420407235622406, 38.56504641473293, 37.04124458134174, 37.500833719968796, 35.85193119943142, 39.33976784348488, 38.323466777801514, 36.93597503006458, 37.292620092630386, 37.90808446705341, 37.49900981783867, 39.237564727663994, 35.687567219138145, 37.1641755849123, 43.139867931604385, 47.64477699995041, 40.37123769521713, 48.18029746413231, 50.24861767888069, 48.92223045229912, 49.33207646012306, 47.98651926219463, 49.46670703589916, 48.3582267165184, 49.48436088860035, 46.081860065460205, 46.060911789536476, 43.01671274006367, 48.05873818695545, 51.80212251842022, 45.971369594335556, 43.73618133366108, 39.170319736003876, 36.97681523859501, 37.12277300655842, 36.7437357455492, 37.1353617310524, 38.38223062455654, 38.532797545194626, 38.434952795505524, 37.38115154206753, 37.732108309865, 36.02220766246319, 37.58529178798199, 37.45074860751629, 37.08572879433632, 37.928956747055054, 37.88998603820801, 39.4074460119009, 37.72071652114391, 37.86564074456692, 37.168682143092155, 37.70512595772743, 37.46171861886978, 41.30486659705639, 50.46972021460533, 49.808464497327805, 52.21528194844723, 52.97024063766003, 48.09107065200806, 49.55805413424969, 46.5352251380682, 48.180920630693436, 46.70196399092674, 46.9426354765892, 48.52909214794636, 54.31813471019268, 50.97480811178684, 53.86524461209774, 49.58864249289036, 40.66922150552273, 36.876652613282204, 41.996915861964226, 54.08085644245148, 55.939895287156105, 53.79712946712971, 56.70589238405228, 60.07148198783398, 59.847985580563545, 58.74424360692501, 56.938766688108444, 54.283906146883965, 56.92265935242176, 56.12761281430721, 36.110742911696434, 9.604099597781897, 3.613039688207209, 7.923715291544795, 4.167752685025334, 0.5641775764524937, 0.015636760253983084, 3.112932136282325, 44.19432274997234, 60.36368250846863, 46.418427005410194, 30.376715697348118, 35.05754582583904, 54.60734099149704, 58.81143160164356, 33.57526056468487, 1.8520588567480445, 0.11371652770321816, 0.04749668689328246, 0.012507003830251051, 0.05683881958248094, 0.02447462029522285, 0.029001364891882986, 0.031158762212726288, 0.08062078602961265, 0.024744116381043568, 0.019185571291018277, 0.020315389083407354, 0.058354774955660105, 0.03326332604046911, 0.04160132921242621, 0.23639224731596187, 0.22615384514210746, 0.1028604805469513, 0.21998806740157306, 0.12704757798928767, 0.09451868871110491, 0.32448967394884676, 0.06424861494451761, 0.10271457431372255, 0.14421435917029157, 0.12919778760988265, 0.16530021443031728, 0.19816091051325202, 0.27045390161219984, 0.1810626740916632, 0.27806269645225257, 5.60298222117126, 42.79053747653961, 63.277236968278885, 55.426577031612396, 32.936655431985855, 32.944380417466164, 42.77454413473606, 54.807670041918755, 48.24402764439583, 6.801612228155136, 0.14991826872574165, 1.7226020595990121, 4.3782818131148815, 10.410482827574015, 8.182103801518679, 5.734202954918146, 34.12376493215561, 56.06062240898609, 58.912073001265526, 53.52406471967697, 53.92816923558712, 57.27116145193577, 54.71455603837967, 53.89231815934181, 53.841606080532074, 53.50036159157753, 49.21234108507633, 39.35811325907707, 40.272864773869514, 41.945481821894646, 44.71649073064327, 49.2159166932106, 50.21817371249199, 50.76932653784752, 47.76186391711235, 50.72724759578705, 52.214936167001724, 48.547749146819115, 44.48159493505955, 42.59397402405739, 39.268514066934586, 39.39560204744339, 37.55560018122196, 37.65269637107849, 37.579854279756546, 39.61841829121113, 39.86121006309986, 40.28429456055164, 39.10005770623684, 37.895583137869835, 41.913685128092766, 40.16530014574528, 38.50132383406162, 39.83907625079155, 39.54244516789913, 38.32901068031788, 41.157301515340805, 36.56943529844284, 38.20902831852436, 46.07699252665043, 49.080165177583694, 42.90089875459671, 49.66603673994541, 53.811515495181084, 51.63887567818165, 50.71392551064491, 50.531155318021774, 51.965122371912, 50.75962945818901, 52.38871984183788, 46.64359912276268, 45.722524747252464, 43.33930402994156, 49.952776953577995, 55.37688709795475, 48.07379677891731, 45.48365816473961, 39.55713137984276, 38.3342619985342, 41.371450424194336, 38.500639870762825, 40.56745156645775, 40.46066589653492, 41.356965601444244, 40.38506895303726, 40.9156496822834, 38.87085780501366, 37.3361049592495, 40.197104439139366, 40.373468175530434, 38.71150575578213, 40.26077002286911, 39.43886272609234, 42.56986811757088, 39.93000917136669, 39.7967579215765, 39.397536143660545, 40.73604092001915, 39.77766774594784, 42.68174931406975, 51.58274129033089, 52.89185084402561, 54.34280298650265, 55.12569397687912, 52.32157364487648, 50.991515815258026, 48.00048731267452, 50.65841428935528, 49.31329406797886, 48.7293566018343, 51.771720349788666, 56.73115722835064, 53.10767166316509, 55.353282764554024, 53.43512289226055, 44.3922009319067, 38.70602644979954, 44.25195425748825, 56.90264202654362, 58.6574524641037, 55.200078785419464, 56.963712349534035, 61.87204957008362, 63.031515553593636, 61.83184392750263, 56.052589640021324, 56.8094140291214, 57.67099879682064, 56.86984218657017, 38.130182549357414, 10.06427675485611, 3.9212729735299945, 10.475347246974707, 10.885464940220118, 1.28363631432876, 0.11082489771069959, 3.390669208019972, 48.564521446824074, 64.98759359121323, 57.02815309166908, 43.91364701092243, 44.38764877617359, 62.62612670660019, 65.91400668025017, 40.19532613456249, 2.630221238359809, 0.23538121953606606, 0.1389677164843306, 0.19397108611883596, 0.17300467210588977, 0.19492027815431356, 0.11541672123712488, 0.24691912229172885, 0.1236922838143073, 0.10721231577917933, 0.08495644986396655, 0.11565548498765565, 0.15725539298728108, 0.2606334176380187, 0.16277855989756063], [0.04893528821412474, 0.01229456869623391, 0.05483694301801734, 0.04463593024411239, 0.014267596125137061, 0.058654773310991004, 0.06374639619025402, 0.08569743236876093, 0.05830854657688178, 0.030661914752272423, 0.08396704084589146, 0.11697973619448021, 0.0547000204824144, 0.0649157611769624, 0.08449815883068368, 0.04621794789272826, 1.645852115470916, 22.553657479584217, 52.11196929216385, 41.22333437204361, 33.408711701631546, 23.615263514220715, 32.55308121442795, 42.06805184483528, 42.357562109827995, 10.080430638045073, 0.05722830981540028, 0.12152119015809149, 2.221146826632321, 1.892533334903419, 3.420330653898418, 10.138700511306524, 27.608070261776447, 51.464256048202515, 52.90054477751255, 48.38774353265762, 48.387572541832924, 48.31238217651844, 48.77460837364197, 49.878137558698654, 48.980591520667076, 46.73289813101292, 43.17267917096615, 36.337488144636154, 36.35703809559345, 36.13968215882778, 36.65056474506855, 40.68381652235985, 47.02970780432224, 48.581388741731644, 43.228904753923416, 47.17752367258072, 47.81015172600746, 48.37207317352295, 43.9451739192009, 40.46512305736542, 35.390255972743034, 35.50125181674957, 35.74253506958485, 35.70190005004406, 36.46565146744251, 37.314229533076286, 35.12743927538395, 35.01071333885193, 34.76296283304691, 36.85221612453461, 34.978073090314865, 36.54920518398285, 37.278051674366, 37.73804359138012, 35.37987492978573, 36.833555325865746, 36.29668213427067, 35.08206970989704, 34.22521568834782, 42.381101846694946, 41.59423626959324, 40.901427045464516, 46.28400161862373, 46.76258593797684, 47.23087660968304, 47.480584010481834, 47.56824150681496, 46.85503877699375, 46.7416300624609, 48.355475664138794, 45.0935672968626, 47.76457317173481, 42.19670534133911, 46.03864498436451, 49.377210438251495, 44.90669712424278, 41.59143581986427, 37.14277133345604, 36.421577632427216, 33.62229824066162, 35.328300297260284, 35.21870277822018, 34.54929269850254, 36.3656560331583, 36.70843943953514, 36.866020783782005, 35.38545683026314, 34.680119678378105, 36.58068649470806, 36.581503450870514, 36.63241691887379, 36.03240631520748, 34.10488374531269, 37.13920332491398, 35.88583678007126, 35.92925705015659, 34.83932353556156, 37.122727409005165, 33.873673751950264, 35.210666209459305, 41.68222814798355, 45.96454136073589, 46.11151747405529, 46.644666865468025, 45.285422801971436, 41.16226024925709, 39.028184562921524, 40.58420866727829, 40.7233040034771, 43.14500145614147, 42.802031859755516, 47.569620832800865, 51.174115017056465, 48.87841500341892, 51.29009239375591, 45.95555864274502, 37.29470618069172, 34.678915143013, 41.48241586983204, 51.79117910563946, 52.892872989177704, 54.215836599469185, 54.05683793127537, 55.19394971430302, 52.74450995028019, 52.518661469221115, 57.6109354197979, 60.34946747124195, 52.64501988887787, 28.152164965867996, 3.4360247617587447, 4.12893776781857, 3.5883987229317427, 1.8622335232794285, 0.23458925890736282, 0.060316694289213046, 3.8391883531585336, 41.30010165274143, 56.17178924381733, 54.529046192765236, 37.76484355330467, 36.78329162299633, 47.14696191251278, 48.986842185258865, 23.306005708873272, 3.1573534151539207, 0.08291765145258978, 0.08172240777639672, 0.05360590927011799, 0.16266008344246075, 0.08974007403594442, 0.08775059875915758, 0.006613726018258603, 0.028532923133752774, 0.05467905109981075, 0.08017220970941707, 0.0407600306061795, 0.04705379171355162, 0.05422817041107919, 0.03707575720909517, 0.03622653988713864, 0.03916464687790722, 0.049937310031964444, 0.023018723222776316, 0.009229957067873329, 0.03519890284223948, 0.058247983615729026, 0.032998264287016355, 0.026183689915342256, 0.011043080430681584, 0.05332695822289679, 0.06405037245713174, 0.0022909294011697057, 0.07737732608802617, 0.027387312438804656, 0.02868349005439086, 2.3007459053769708, 30.25942549109459, 59.62608888745308, 46.697704419493675, 36.372450068593025, 27.289149574935436, 33.92666570842266, 47.030558958649635, 47.29383923113346, 9.964653700590134, 0.017851664742920548, 0.04983451515727211, 1.5028479765169322, 3.1794052943587303, 4.033483564853668, 7.2676971182227135, 30.313867069780827, 53.08580003678799, 54.55993473529816, 51.13814614713192, 50.39287693798542, 51.260750368237495, 51.526701897382736, 50.730443224310875, 50.49489006400108, 48.57197284698486, 45.95368154346943, 37.679583728313446, 38.34749288856983, 37.764752358198166, 38.76390874385834, 42.82676853239536, 49.33004356920719, 50.09251065552235, 44.91408012807369, 48.22607360780239, 49.40837636590004, 51.00499369204044, 45.692399963736534, 42.4807059019804, 37.40862786769867, 37.58226715028286, 36.496258825063705, 35.86717218160629, 37.18710355460644, 38.84687349200249, 36.82524897158146, 36.61771550774574, 35.71682944893837, 38.34322951734066, 37.07727424800396, 37.28145629167557, 37.61998772621155, 38.56703370809555, 38.31466645002365, 39.42345455288887, 37.821870893239975, 36.20323374867439, 35.720427855849266, 43.84644381701946, 44.142075553536415, 41.50186322629452, 47.628061696887016, 48.045028522610664, 49.47526417672634, 48.138009533286095, 49.09232072532177, 48.21923777461052, 48.693672716617584, 48.53069946169853, 48.42664584517479, 46.34025759994984, 43.42647135257721, 47.66422815620899, 51.01214870810509, 47.40033991634846, 43.89430604875088, 39.476317316293716, 38.59773226082325, 37.10743322968483, 37.35462136566639, 37.05304674804211, 37.4046266824007, 38.825355246663094, 39.7598011046648, 37.54207290709019, 37.24214360117912, 36.164502426981926, 37.97631360590458, 38.195945620536804, 37.9073891043663, 38.47136244177818, 35.76096788048744, 39.529636055231094, 37.11505942046642, 37.32516534626484, 37.402339205145836, 36.83587700128555, 37.22314462065697, 37.30423226952553, 44.78110246360302, 47.84618519246578, 49.84688803553581, 50.59081591665745, 47.44178809225559, 43.31768698990345, 43.31122353672981, 42.46083676815033, 43.349023908376694, 45.0671549141407, 46.23783029615879, 50.24206303060055, 51.37426167726517, 49.70364712178707, 52.68053278326988, 47.19805397093296, 39.211840108036995, 37.08730190992355, 44.17006105184555, 53.17420609295368, 54.71103362739086, 56.407885774970055, 56.068651378154755, 57.48322807252407, 54.17429342865944, 52.70759493112564, 59.01679538190365, 60.39983756840229, 54.34871546924114, 31.943289935588837, 5.75703545473516, 4.614532710984349, 6.311601446941495, 2.30118905659765, 0.6013004563283175, 0.03311079984996468, 4.039670582860708, 47.09119230508804, 60.01570478081703, 56.82014085352421, 45.927789732813835, 41.00691318511963, 53.311317935585976, 57.28488251566887, 31.490758918225765, 3.4376368252560496, 0.05632043685181998, 0.05229426715231966, 0.03781371546210721, 0.03291911423730198, 0.08315064129419625, 0.010545012137299636, 0.061468032508855686, 0.028998778507229872, 0.02662834398506675, 0.06019529748300556, 0.12108809503843077, 0.039923953008838, 0.10037673491751775, 0.04896237289358396, 0.11333561298670247, 0.0943632607231848, 0.09548278307192959, 0.12827635189751163, 0.07667145458981395, 0.11968327627982944, 0.21529350837226957, 0.243343900074251, 0.13970083964522928, 0.14095924008870497, 0.19015246914932504, 0.28294442512560636, 0.19381769903702661, 0.2078026853268966, 0.2307852919329889, 0.1220546978584025, 2.535995556972921, 34.67943571507931, 67.75151208043098, 52.934678345918655, 43.767339661717415, 33.198309391736984, 44.95158791542053, 54.96003046631813, 53.30437570810318, 12.670564502477646, 0.21720642369473353, 0.8377253729850054, 5.371436420828104, 6.264779409393668, 10.054098051041365, 16.301737055182457, 34.65962737798691, 55.17362080514431, 57.67081260681152, 53.272487819194794, 53.33417370915413, 53.663749024271965, 52.853119522333145, 53.451940789818764, 52.212622091174126, 51.09886385500431, 48.97994935512543, 41.26694083213806, 39.92412708699703, 39.4552930444479, 40.09284183382988, 45.303498432040215, 53.43394495546818, 50.95197893679142, 43.93028251826763, 49.81387160718441, 50.74458986520767, 53.55187922716141, 48.551590740680695, 44.25995662808418, 39.056766629219055, 38.36308345198631, 38.645955473184586, 38.650500029325485, 40.59623882174492, 41.22574344277382, 39.414547830820084, 38.70860271155834, 38.54175366461277, 40.81798732280731, 38.63231040537357, 38.70821513235569, 40.27394771575928, 41.68899558484554, 40.20004168152809, 39.962178245186806, 39.630729630589485, 38.543482571840286, 37.64933355152607, 45.134996473789215, 46.54121361672878, 45.926896780729294, 49.32630077004433, 48.95810052752495, 50.061466321349144, 50.143788903951645, 52.04617962241173, 50.505772680044174, 51.061857640743256, 50.91401897370815, 49.503530859947205, 47.96151280403137, 44.13711681962013, 50.60407340526581, 53.132165148854256, 50.31607545912266, 45.59084661304951, 42.583877965807915, 39.700942263007164, 39.09795641899109, 40.02713955938816, 38.52490536868572, 39.12984810769558, 40.56860290467739, 41.279951333999634, 39.28967893123627, 38.77266347408295, 38.31961378455162, 40.493667125701904, 40.135566741228104, 40.11519983410835, 40.01580476760864, 35.84900915622711, 41.10087454319, 39.31529335677624, 39.28057461977005, 38.74560132622719, 40.14230377972126, 39.02321822941303, 38.68565574288368, 47.76904173195362, 51.848073452711105, 51.313350945711136, 52.13485546410084, 50.57780161499977, 44.130592569708824, 46.069795712828636, 45.03893382847309, 45.98667897284031, 48.46665009856224, 49.0517883002758, 51.99154615402222, 55.133217573165894, 51.69445529580116, 55.39698801934719, 52.18570813536644, 40.3404251486063, 39.12939213216305, 45.49398981034756, 55.2454749494791, 57.676181718707085, 58.36394481360912, 57.51059040427208, 55.62045782804489, 56.62739239633083, 56.04921542108059, 60.72848953306675, 62.16057188808918, 55.65902195870876, 32.148030549287796, 6.411565532907844, 8.496166449040174, 9.690296072512865, 5.121063105762005, 1.4279270404949784, 0.10071478318423033, 4.508058149367571, 51.3597122579813, 68.00990581512451, 65.85466906428337, 49.30721439421177, 48.72083365917206, 61.513390615582466, 64.65927600860596, 38.43631312251091, 4.348823418840766, 0.18451337877195328, 0.1373970796703361, 0.20452285272767767, 0.19883761560777202, 0.1484203030122444, 0.17143045814009383, 0.20173485623672605, 0.06233951426111162, 0.12729509908240288, 0.18164520064601675, 0.17495834617875516, 0.13253574521513656, 0.20423340029083192, 0.09393973188707605], [0.012703712855000049, 0.04521650495007634, 0.10536148110986687, 0.033601808463572524, 0.06113173942139838, 0.043088526363135315, 0.031592105951858684, 0.019560357723094057, 0.014643410431744996, 0.021387054039223585, 0.024384039315918926, 0.03404676681384444, 0.08179131618817337, 0.08177303709089756, 0.055994826980168, 0.09410707134520635, 0.46829981496557593, 20.737936310470104, 53.30334596335888, 51.11872158944607, 41.00802272558212, 24.961620569229126, 31.227395050227642, 38.19665998220444, 47.630805149674416, 16.064796969294548, 0.08476061935652979, 0.09853077615844086, 1.9554663891904056, 2.715958650223911, 0.5828231759369373, 0.8018164685927331, 19.07074347138405, 48.85640658438206, 55.031310841441154, 48.67084354162216, 46.39997519552708, 45.37632532417774, 45.987617522478104, 46.45039848983288, 45.53891099989414, 43.084231317043304, 38.566129356622696, 36.82201534509659, 36.30791813135147, 36.60137638449669, 37.83171236515045, 43.54228533804417, 46.21016778051853, 51.972858756780624, 44.076339080929756, 47.46680974960327, 48.65953914821148, 47.9381250590086, 44.491599798202515, 40.052894577383995, 36.21801495552063, 34.17055942118168, 34.10264566540718, 35.37908837199211, 34.322722256183624, 36.30657680332661, 36.61247558891773, 35.98668336868286, 36.00596733391285, 37.490517273545265, 37.11636275053024, 36.30867049098015, 38.19865867495537, 35.85204519331455, 36.35046064853668, 37.174598425626755, 36.37983687222004, 34.630125761032104, 34.34940442442894, 41.49842441082001, 41.8849016726017, 42.21720524132252, 47.044914588332176, 49.334504529833794, 48.327889144420624, 47.88464292883873, 46.67201019823551, 46.95322930812836, 47.35693484544754, 48.243613466620445, 44.74577195942402, 47.930164486169815, 43.25676865875721, 44.368349611759186, 49.47932995855808, 44.27116222679615, 42.32658997178078, 39.93266902863979, 37.572117894887924, 37.88165308535099, 36.21075354516506, 35.474087074398994, 36.31692744791508, 36.82603932917118, 35.99485673010349, 37.18380153179169, 34.430891051888466, 35.49159653484821, 36.38253092765808, 37.494632452726364, 35.021531358361244, 36.16321809589863, 35.823611319065094, 36.23340792953968, 37.442187666893005, 35.99826894700527, 35.75367607176304, 37.27349191904068, 36.26979857683182, 36.23638316988945, 36.463664174079895, 39.91009064018726, 40.65984360873699, 40.37450172007084, 38.29303041100502, 37.963018119335175, 35.94322890043259, 35.6738917529583, 36.047107726335526, 38.55142414569855, 43.40861991047859, 46.92592017352581, 48.82685177028179, 49.41894739866257, 49.294982850551605, 49.28735665977001, 40.70741705596447, 38.908270597457886, 36.97863154113293, 41.234410777688026, 50.41033320128918, 53.15445855259895, 55.38720354437828, 52.87140794098377, 55.94891220331192, 59.50148597359657, 57.870727479457855, 54.991454780101776, 53.334694281220436, 30.378991775214672, 5.251365713775158, 3.3058266481384635, 8.049306627362967, 1.596809928305447, 0.20547456806525588, 0.11426876721088775, 3.9270291896536946, 39.55685779452324, 48.83735440671444, 40.579831302165985, 22.79771078377962, 26.937375850975513, 53.755658492445946, 41.388857290148735, 19.45067558437586, 3.7075087940320373, 0.04431592358741909, 0.09514108343864791, 0.032532280893065035, 0.04779577240697108, 0.05769592222350184, 0.06167109153466299, 0.04603866356774233, 0.0391367643896956, 0.03025329380761832, 0.01374826622850378, 0.05750868207542226, 0.018453130905982107, 0.03236041062336881, 0.10660762869520113, 0.05342460630345158, 0.04048757335112896, 0.07231586409034207, 0.041013848822331056, 0.10806656486238353, 0.0906118749117013, 0.037658406217815354, 0.005271416503092041, 0.033825254286057316, 0.033607901495997794, 0.05231845374510158, 0.07681632923777215, 0.07457542917109095, 0.024452734360238537, 0.03088568897510413, 0.07436214335029945, 0.5106271093245596, 24.622154384851456, 59.75114397704601, 54.886151030659676, 44.582684710621834, 24.833738431334496, 36.46608084440231, 44.90958496928215, 52.91690289974213, 17.791564911603928, 0.07290837253094651, 0.18437462684232742, 1.5291463653557003, 3.127414584159851, 2.8236398845911026, 2.605347535572946, 21.79436892271042, 51.79436333477497, 55.98416671156883, 50.86131580173969, 48.46480339765549, 48.5878673940897, 48.472167402505875, 48.6153095215559, 48.24512958526611, 45.404618605971336, 39.80973422527313, 38.60517606139183, 38.15998055040836, 37.987834587693214, 39.08049635589123, 44.14970554411411, 47.69911788403988, 52.82505802810192, 45.28671473264694, 46.775995418429375, 49.66669410467148, 48.94232377409935, 45.40215253829956, 42.18567833304405, 37.55123421549797, 36.142832189798355, 34.453150257468224, 37.437472119927406, 35.57818628847599, 38.00954282283783, 37.59941942989826, 37.734122201800346, 38.15204657614231, 39.53746743500233, 37.72997662425041, 37.9701579362154, 39.50153276324272, 37.55730248987675, 36.93320117890835, 38.97244915366173, 38.28370191156864, 35.375892743468285, 35.74041098356247, 42.73597240447998, 43.05222563445568, 43.665201142430305, 48.52054640650749, 51.214495450258255, 49.61327277123928, 48.028829991817474, 47.636379450559616, 48.20893652737141, 49.27863612771034, 48.872293531894684, 47.3326351493597, 47.59590782225132, 44.88923326134682, 47.605935484170914, 51.27605974674225, 47.003082633018494, 44.58906076848507, 40.14804907143116, 39.7719756513834, 39.899090230464935, 38.3767931163311, 37.240285500884056, 37.45171755552292, 39.262966364622116, 37.74696171283722, 38.70157688856125, 37.25148729979992, 36.92339390516281, 37.704913169145584, 38.825872018933296, 36.51112362742424, 38.504549860954285, 37.24672995507717, 39.15373742580414, 39.04744192957878, 37.912750616669655, 37.48593471944332, 37.83752225339413, 38.45943868160248, 38.14014561474323, 39.238689467310905, 41.67214348912239, 43.533675000071526, 43.78780156373978, 40.559851974248886, 40.47167770564556, 38.563788682222366, 37.802765518426895, 38.085550144314766, 41.91952161490917, 45.31587436795235, 49.417359083890915, 52.98509784042835, 49.47715267539024, 50.79745262861252, 50.8029243350029, 44.303194507956505, 40.798319578170776, 38.29374477267265, 45.25712572038174, 53.20175461471081, 56.56484015285969, 56.236682161688805, 56.12293906509876, 58.127065524458885, 63.259434923529625, 58.00030052661896, 58.82054351270199, 54.18682895600796, 32.00019188225269, 4.537291405722499, 6.524542970582843, 8.220951966941357, 3.319117147475481, 0.2874468272784725, 0.044921709049958736, 3.9666665252298117, 45.58897711336613, 57.70669788122177, 49.86288517713547, 29.72177144140005, 33.21803793311119, 62.20999963581562, 50.28104513883591, 24.60345558822155, 4.456834048032761, 0.13040676101809368, 0.029052693680569064, 0.02139489668479655, 0.06460655276896432, 0.06066471330996137, 0.02904029424826149, 0.015480740403290838, 0.06431143032386899, 0.05727644922444597, 0.02230810197943356, 0.025129491405095905, 0.05402320035500452, 0.04934826742100995, 0.045467220988939516, 0.3066867683082819, 0.21128172520548105, 0.15446162258740515, 0.0891357209184207, 0.1895515521755442, 0.2737848088145256, 0.11688340542605147, 0.08360140695003793, 0.14207210537279025, 0.1942517515271902, 0.14053539955057204, 0.12675083766225725, 0.2292205032426864, 0.10601158021017909, 0.1177137202466838, 0.23764474026393145, 0.7195460144430399, 29.230414107441902, 69.11186188459396, 62.85461604595184, 53.81388656795025, 33.41815419495106, 43.85219670832157, 50.83730489015579, 59.138784036040306, 21.204838156700134, 0.2557326009264216, 0.45656343223527074, 5.441526984795928, 10.194286778569221, 4.669336695224047, 2.2897435957565904, 20.832746922969818, 53.99201340973377, 60.10196015238762, 52.602826952934265, 51.75607658922672, 50.89037664234638, 50.61754748225212, 51.69498726725578, 49.32376250624657, 46.680897921323776, 42.79279075562954, 41.816064566373825, 40.56293360888958, 39.46097373962402, 41.42460577189922, 47.45852619409561, 50.175946578383446, 55.114112198352814, 44.51871134340763, 47.5017374753952, 52.35823027789593, 51.36708766222, 49.21911992132664, 43.5785885900259, 38.82236860692501, 36.22298888862133, 37.024327889084816, 38.44574421644211, 37.20543757081032, 40.79368382692337, 39.529541060328484, 39.18926551938057, 39.52529288828373, 40.923199877142906, 39.85066182911396, 38.232039883732796, 42.84837417304516, 39.36331897974014, 39.521850273013115, 42.33003258705139, 40.00527173280716, 37.1919596940279, 37.65051908791065, 44.65984337031841, 46.36731594800949, 47.37930424511433, 50.30559942126274, 53.10786545276642, 52.24267087876797, 51.35728798806667, 48.86966027319431, 48.750905245542526, 50.49234800040722, 50.73626451194286, 46.60681709647179, 48.50671514868736, 47.44621865451336, 51.0777597874403, 51.87658712267876, 48.60341235995293, 46.564042791724205, 43.255537524819374, 42.83705458045006, 43.15678842365742, 40.49753151834011, 40.00370241701603, 38.77612888813019, 41.02174758911133, 40.01889780163765, 42.0132701843977, 38.50543141365051, 37.85091273486614, 40.35627029836178, 40.48580154776573, 38.50382409989834, 40.13780102133751, 38.095418214797974, 41.63087770342827, 40.86207635700703, 39.30298961699009, 39.559187069535255, 40.82616828382015, 40.34828692674637, 40.688737258315086, 40.500312969088554, 42.66803964972496, 45.502444356679916, 44.161078333854675, 43.21994483470917, 42.65266567468643, 40.57287387549877, 38.31055127084255, 40.71522183716297, 44.34861347079277, 47.391710579395294, 51.63750395178795, 54.467337504029274, 52.229823768138885, 51.513391211628914, 53.202514573931694, 45.85596598684788, 43.17698813974857, 42.369755655527115, 45.093457102775574, 54.48283687233925, 59.60940398275852, 59.63487781584263, 56.98248714208603, 60.328701585531235, 64.05813306570053, 59.888358414173126, 60.668809935450554, 57.42210075259209, 33.202743753790855, 8.22007991373539, 7.730603953823447, 16.957437470555305, 7.531251451000571, 1.2340152519755065, 0.1651692995801568, 4.830020572990179, 49.28136818110943, 63.13984014093876, 53.02817612886429, 33.35764244198799, 39.8797682672739, 67.39583596587181, 61.99686527252197, 33.948750123381615, 4.6779456082731485, 0.2549122605705634, 0.20801534032216296, 0.08743056983803399, 0.17439458111766726, 0.13654157635755837, 0.07856514086597599, 0.15670874185161665, 0.12674420286202803, 0.12851000967202708, 0.13487457908922806, 0.08215096837375313, 0.12355950617347844, 0.1484972785692662, 0.10018177272286266], [0.07164115537307225, 0.029522181866923347, 0.1027833046100568, 0.05102256371174008, 0.15527278999798, 0.03569137348677032, 0.09219098705216311, 0.006787844995415071, 0.04466803184186574, 0.023106535991246346, 0.04124233382754028, 0.02660114612808684, 0.067014755186392, 0.07129616060410626, 0.015513469115830958, 0.06400184342055582, 0.2233238282497041, 10.862959697842598, 47.0758069306612, 50.25063157081604, 43.99543382227421, 36.14699296653271, 24.173411764204502, 36.79440222680569, 46.85575693845749, 25.26870109140873, 0.78526770346798, 0.06322213564999402, 0.1914940049755387, 1.6667949291877449, 6.491745030507445, 1.90072450786829, 12.354443315416574, 42.26631000638008, 52.71190010011196, 50.26184856891632, 45.52336983382702, 45.71648307144642, 41.873817667365074, 43.63441899418831, 39.59974229335785, 40.14965258538723, 36.13082483410835, 37.871401235461235, 38.295074701309204, 39.28779423236847, 43.73074762523174, 44.91362415254116, 50.360586270689964, 46.52543306350708, 43.13019745051861, 43.240326941013336, 48.57798792421818, 48.89818534255028, 44.812937155365944, 41.653083711862564, 32.99313560128212, 33.781293109059334, 34.49975475668907, 36.24260723590851, 34.94278818368912, 36.55097968876362, 34.570202976465225, 35.3523226082325, 35.61355859041214, 36.532729268074036, 37.14304491877556, 35.52145913243294, 33.897984847426414, 36.01406469941139, 35.77271305024624, 36.72646567225456, 36.60411983728409, 35.174222365021706, 33.4364578127861, 38.83412517607212, 40.898725390434265, 44.70272786915302, 45.780201852321625, 48.31817306578159, 46.81733340024948, 44.88167926669121, 45.85348851978779, 47.01726347208023, 45.09829044342041, 50.12474052608013, 44.64458718895912, 49.360103756189346, 41.08546257019043, 43.87882187962532, 53.75445395708084, 46.4382429420948, 45.32479628920555, 42.25679911673069, 43.448616564273834, 41.49577975273132, 41.775247156620026, 38.79583083093166, 36.72638587653637, 37.60886952280998, 37.78907485306263, 37.84044049680233, 35.034222677350044, 34.684698432683945, 35.41930541396141, 35.311098620295525, 35.846018716692924, 34.66344617307186, 36.3650556653738, 35.27121216058731, 37.290081828832626, 35.80654263496399, 36.55441090464592, 35.32087929546833, 35.64906768500805, 35.730922892689705, 35.26568725705147, 36.46091312170029, 36.577388271689415, 37.457896023988724, 34.41355258226395, 36.43738478422165, 33.70611794292927, 34.19265903532505, 38.730231150984764, 40.85598148405552, 42.91153438389301, 45.23775056004524, 50.1442638784647, 50.08256658911705, 46.409413889050484, 51.04070797562599, 50.95533415675163, 41.63943864405155, 36.09172873198986, 37.61860080063343, 40.257840380072594, 50.930133908987045, 55.26428014039993, 55.78040264546871, 54.56427790224552, 55.44692113995552, 53.597522377967834, 55.67038714885712, 50.86627833545208, 34.287076368927956, 3.4426993411034346, 5.086418939754367, 3.949358928948641, 1.9077789480797946, 0.43261073471512645, 0.03783542699238751, 4.251652657985687, 39.508953765034676, 50.65825089812279, 48.13482530415058, 38.54161687195301, 33.04138921201229, 57.844402492046356, 45.904379189014435, 19.372751265764236, 1.8294618255458772, 0.06083058331569191, 0.09523153639747761, 0.0482766284403624, 0.0697787209355738, 0.09558995661791414, 0.08799263538094237, 0.010464217302796897, 0.07481191452825442, 0.018732677526713815, 0.026988617719325703, 0.025698653735162225, 0.03415409992157947, 0.06001043220749125, 0.015176188044279115, 0.017080666075344197, 0.0045239879818836926, 0.11060043514589779, 0.04079328995430842, 0.056798535806592554, 0.03151315999275539, 0.09222116277669556, 0.07549263464170508, 0.020273134905437473, 0.046020076479180716, 0.09281107370043173, 0.036542423913488165, 0.0385119576822035, 0.03824277700914536, 0.013779296350548975, 0.05515839686268009, 0.25052492099348456, 15.558206252753735, 54.599748998880386, 58.02978694438934, 48.86546149849892, 37.38239407539368, 31.395693719387054, 45.17616726458073, 52.34861299395561, 26.500256806612015, 0.7988345192279667, 0.08931172866141424, 0.5689643695950508, 3.8809492997825146, 2.668884163722396, 1.9922608835622668, 15.854041278362274, 45.59074021875858, 56.840032786130905, 50.811272487044334, 47.28861451148987, 46.00003145635128, 44.75732333958149, 46.05679281055927, 43.00382003188133, 42.70693056285381, 38.702629432082176, 40.461999624967575, 37.672671899199486, 41.375067830085754, 44.734380170702934, 47.56108269095421, 52.10456728935242, 47.71865263581276, 44.053973481059074, 41.88093088567257, 50.62825530767441, 51.501798033714294, 46.10289193689823, 42.68872193992138, 35.01013956964016, 35.41957899928093, 35.82200400531292, 36.87833972275257, 35.76617360115051, 38.1163626909256, 36.58948302268982, 36.298642829060555, 36.03529796004295, 37.98089995980263, 37.38054357469082, 37.24540762603283, 36.49638421833515, 38.60683657228947, 37.49923400580883, 37.75817111134529, 36.30898207426071, 38.159767761826515, 33.16866718232632, 41.02440744638443, 44.587426856160164, 46.38420604169369, 46.42407350242138, 50.03736801445484, 47.465191036462784, 46.91395081579685, 46.72768481075764, 48.904690593481064, 47.532257437705994, 50.09943388402462, 45.39904050529003, 48.77634488046169, 41.976548954844475, 45.416082590818405, 55.21110199391842, 48.65460701286793, 47.45823360979557, 44.37892824411392, 46.432626843452454, 43.943946585059166, 42.625922709703445, 39.452579990029335, 40.40843389928341, 39.53506596386433, 39.212877452373505, 40.45729547739029, 35.79365752637386, 35.711346343159676, 37.20110580325127, 37.70712845027447, 37.94269300997257, 37.00775317847729, 38.0553113669157, 37.632188871502876, 39.02625806629658, 38.192309215664864, 37.922478094697, 38.02894078195095, 37.775505781173706, 38.06891843676567, 36.54383987188339, 38.60747113823891, 38.59616294503212, 39.20066870748997, 37.444528341293335, 37.99597755074501, 35.20977705717087, 34.90742728114128, 39.612824991345406, 42.108504474163055, 45.14446556568146, 47.13826797902584, 52.265203669667244, 49.79052945971489, 47.92452558875084, 52.907563000917435, 52.55112312734127, 43.160440027713776, 38.00766572356224, 39.506449699401855, 43.67671072483063, 52.9424337297678, 58.43970514833927, 57.71926000714302, 57.1998430788517, 57.44600906968117, 55.54062411189079, 57.615099996328354, 53.52600261569023, 33.02254222333431, 4.212846765294671, 4.6560008358210325, 6.5299410559237, 3.2463672012090683, 0.44577952183317393, 0.1849354529986158, 4.233787916600704, 44.02352951467037, 54.57007639110088, 48.7151263654232, 32.336416840553284, 34.73083555698395, 63.506813049316406, 56.08055233955383, 26.047965176403522, 2.6554278982803226, 0.04405648731335532, 0.012092361284885556, 0.06973696028580889, 0.009750139506650157, 0.0347207148297457, 0.0597760879463749, 0.00944860676099779, 0.016540165488549974, 0.024971677412395366, 0.05206368186918553, 0.016977372106339317, 0.07512007650802843, 0.04024417488835752, 0.06556848005857319, 0.11735960448277183, 0.17417552880942822, 0.23535935586551204, 0.15023114334326237, 0.1753066063974984, 0.1376720008556731, 0.14638156397268176, 0.1348327219602652, 0.16721701860660687, 0.12514089670730755, 0.14338958077132702, 0.10486498431419022, 0.17377812357153744, 0.13507648778613657, 0.14582735777366906, 0.14791865571169183, 0.41664601012598723, 18.148272670805454, 61.37881703674793, 63.43412294983864, 55.71403540670872, 46.447438448667526, 35.354283303022385, 48.33235390484333, 57.42908477783203, 31.232739463448524, 1.0467335139401257, 0.19671578571433201, 1.9928448647260666, 6.016629924997687, 16.13706149160862, 5.477082626894116, 15.271595232188702, 45.14217808842659, 58.42378780245781, 52.952085211873055, 49.937923550605774, 48.74255709350109, 45.8155133575201, 48.760834112763405, 44.72015753388405, 44.39557895064354, 39.797567278146744, 44.41443733870983, 40.759858042001724, 43.88184651732445, 48.638533875346184, 49.38942678272724, 55.681087374687195, 48.98235082626343, 43.927379474043846, 43.48773166537285, 51.86132334172726, 54.336841106414795, 48.23712341487408, 45.35766452550888, 37.36677311360836, 36.5200911462307, 37.144739627838135, 38.703134804964066, 37.036700025200844, 39.74318839609623, 39.305299893021584, 38.807572200894356, 37.563328966498375, 40.11556461453438, 39.57936018705368, 39.63362507522106, 37.62455128133297, 40.883598402142525, 38.703564181923866, 40.72928488254547, 38.59853781759739, 39.543117731809616, 35.717786997556686, 42.646973580121994, 45.95689237117767, 48.78407746553421, 48.44366133213043, 52.5084438174963, 49.24559310078621, 48.31658475100994, 48.684325218200684, 50.75651742517948, 48.076654225587845, 52.6940106600523, 47.11267255246639, 48.84000286459923, 43.901943638920784, 48.70804354548454, 57.63195589184761, 50.90834587812424, 49.042228013277054, 45.407590046525, 48.73583145439625, 46.39076068997383, 45.211649760603905, 41.69737033545971, 41.519722267985344, 41.232875660061836, 40.86914777755737, 42.66919478774071, 40.16711264848709, 37.70034961402416, 38.380440920591354, 40.08233919739723, 39.98028427362442, 37.98741281032562, 40.69622665643692, 39.23553943634033, 42.17367857694626, 38.745418936014175, 40.27929022908211, 40.05972661077976, 39.50453460216522, 39.425852224230766, 37.45837099850178, 40.27755752205849, 41.029316782951355, 41.415011286735535, 38.17935571074486, 39.933022409677505, 37.19929710030556, 37.79444016516209, 42.943608462810516, 44.0751763433218, 48.466080129146576, 49.62455436587334, 56.14890307188034, 52.18668848276138, 48.73408354818821, 55.762653797864914, 55.36495953798294, 45.43269529938698, 40.49468167126179, 42.135798409581184, 45.90256288647652, 55.49083538353443, 60.73091000318527, 61.10552430152893, 58.08337166905403, 60.788013339042664, 58.07762637734413, 59.93072994053364, 53.82594332098961, 37.620979472994804, 5.8318643644452095, 9.65580627322197, 12.126559093594551, 4.799823118373752, 1.2686778232455254, 0.3017566219205037, 5.122946854680777, 49.00471642613411, 62.70690657198429, 60.847544744610786, 50.47352381050587, 48.47874104976654, 67.07499638199806, 69.06346768140793, 34.849187806248665, 3.311441084370017, 0.17742316704243422, 0.1966782330418937, 0.0785881103365682, 0.145437715400476, 0.14911370642948896, 0.23694026400335133, 0.14940345572540537, 0.09282667364459485, 0.09334366113762371, 0.17224898765562102, 0.0970430817687884, 0.2671143558109179, 0.2094208641210571, 0.12725505279377103], [0.04352394811576232, 0.04507156721956562, 0.03503843196085654, 0.08198805211577564, 0.0631285211420618, 0.04706160652858671, 0.06388024994521402, 0.04367631103377789, 0.05190287331060972, 0.015163327552727424, 0.010618198102747556, 0.026034514521597885, 0.033866384110297076, 0.013828094415657688, 0.04864208422077354, 0.03768838898395188, 0.12197680945973843, 7.425915878266096, 38.04049216210842, 48.9297616481781, 41.24705269932747, 27.105948105454445, 20.934549160301685, 33.48569177091122, 48.13492029905319, 31.654323041439056, 1.4914947794750333, 0.1240483662695624, 0.6152685661800206, 6.0217605996876955, 12.232535406947136, 4.527336414903402, 15.827342960983515, 39.82028625905514, 54.26538974046707, 51.44894666969776, 44.893280044198036, 41.951671689748764, 40.8103459328413, 39.870869144797325, 38.71006943285465, 36.426661759614944, 38.490513414144516, 39.440789222717285, 41.99066139757633, 44.941514655947685, 45.87915614247322, 49.388039857149124, 45.859761983156204, 45.120025277137756, 51.464351043105125, 45.26536747813225, 48.481017127633095, 46.18268005549908, 44.543033838272095, 36.44665628671646, 34.735634699463844, 36.58752232789993, 35.38243219256401, 34.343586936593056, 35.742706060409546, 35.79020731151104, 37.55355589091778, 35.29722176492214, 34.50583443045616, 35.890704318881035, 35.32137706875801, 36.167021691799164, 36.977841183543205, 34.48981449007988, 36.99197642505169, 35.949616357684135, 37.010245844721794, 33.662587478756905, 34.12087708711624, 35.98932422697544, 39.78752061724663, 43.682497814297676, 45.67157328128815, 48.49235191941261, 48.98817591369152, 47.43256218731403, 45.52890993654728, 42.25257374346256, 45.799805000424385, 47.363645285367966, 49.44168537855148, 50.35979211330414, 39.815464317798615, 47.90574699640274, 49.52485151588917, 47.59330876171589, 45.464275404810905, 44.15635138750076, 45.710589587688446, 48.289704993367195, 45.28918839991093, 47.05648876726627, 39.113748371601105, 35.63762649893761, 40.93744531273842, 40.025102868676186, 37.35993728041649, 36.13714009523392, 36.39130085706711, 36.621842086315155, 36.67851224541664, 34.33695629239082, 35.7548426091671, 36.52290299534798, 37.02211640775204, 37.32283607125282, 37.83777303993702, 35.91551698744297, 36.953891068696976, 36.58525384962559, 35.36448575556278, 36.02205187082291, 33.99889223277569, 35.04281781613827, 34.762081280350685, 35.342329144477844, 32.44410686194897, 35.843309462070465, 36.08774274587631, 40.362296774983406, 44.29439418017864, 48.49403142929077, 48.55512835085392, 51.369489133358, 45.75188957154751, 47.82993346452713, 52.13428549468517, 48.25006552040577, 39.34417940676212, 36.48275814950466, 37.4863450974226, 39.95561599731445, 44.86759342253208, 50.67993253469467, 51.115442365407944, 52.15089440345764, 52.66817204654217, 56.77502207458019, 50.07229574024677, 31.99827678501606, 5.709603549912572, 4.649774394929409, 5.860887207090855, 3.5562773840501904, 0.3177728515584022, 0.09462486777920276, 4.2421275191009045, 37.49256916344166, 49.13194499909878, 39.63422164320946, 40.19847236573696, 39.059073105454445, 51.952381655573845, 58.02758306264877, 14.724437892436981, 1.0935807251371443, 0.10324195929570124, 0.00551233387341199, 0.09557532146573067, 0.038880894135218114, 0.0233790563288494, 0.05495077362866141, 0.01517120081189205, 0.023787619757058565, 0.025438028169446625, 0.07611849519889802, 0.11050919551053084, 0.03157051316520665, 0.06639567785896361, 0.048012138140620664, 0.04161045391811058, 0.05403605435276404, 0.03452273580478504, 0.06037178391125053, 0.0481372642389033, 0.05102530965814367, 0.02682655307580717, 0.07725435963948257, 0.09389820872456767, 0.01676137744652806, 0.026090114370163064, 0.024723217502469197, 0.06621564025408588, 0.05047286977060139, 0.019620260172814596, 0.08045360984397121, 0.0761937267088797, 9.056299142539501, 44.501315876841545, 53.633084669709206, 48.03375452756882, 34.39692087471485, 28.143845312297344, 41.4287893474102, 53.56829434633255, 36.10269494354725, 1.529730821494013, 0.09774052989087068, 0.7563730445690453, 5.573238842189312, 12.353795450180769, 4.7852803487330675, 14.518993366509676, 43.195983320474625, 58.0655924230814, 54.77787584066391, 47.28807874023914, 43.54554556310177, 42.74362899363041, 41.999967098236084, 41.57634302973747, 39.43398758769035, 38.981492668390274, 40.993583500385284, 41.619417518377304, 47.27432727813721, 48.733239993453026, 51.127654910087585, 48.347860872745514, 44.897805601358414, 52.57157362997532, 46.19252532720566, 49.345052763819695, 48.54746796190739, 45.72879061102867, 38.899755254387856, 35.90581610798836, 36.96824669837952, 36.620812341570854, 36.304217129945755, 37.3102967441082, 37.81885385513306, 38.83279524743557, 37.741436809301376, 38.377458080649376, 37.57280945777893, 37.012939900159836, 37.97030232846737, 38.66561181843281, 35.49057058990002, 38.30012463033199, 38.53328011929989, 38.04738499224186, 34.69167485833168, 36.2867646664381, 38.38584803044796, 42.22082644701004, 45.21906316280365, 48.81988674402237, 50.56797914206982, 48.52281108498573, 47.52409927546978, 47.288363724946976, 43.545233979821205, 48.417450338602066, 49.24093835055828, 48.21234114468098, 52.274475172162056, 42.6679902523756, 47.853184416890144, 51.63621202111244, 49.921280443668365, 47.42846980690956, 46.87923967838287, 46.70151561498642, 49.369603246450424, 48.953954949975014, 48.744225203990936, 40.91555468738079, 37.15457729995251, 42.05197870731354, 41.50419630110264, 38.1547824293375, 37.86474019289017, 37.580960020422935, 38.5221391171217, 37.13215470314026, 36.297708079218864, 36.97178050875664, 38.00318196415901, 37.92416900396347, 39.50922355055809, 38.35697717964649, 38.29880230128765, 39.428458884358406, 37.213409543037415, 37.436373978853226, 38.3602450042963, 36.21649503707886, 36.296370550990105, 36.402806639671326, 35.79857066273689, 34.18649576604366, 36.81869812309742, 39.87778477370739, 43.207036927342415, 47.291175574064255, 49.99778553843498, 51.342316791415215, 53.170273303985596, 47.353070452809334, 50.629144459962845, 54.38487812876701, 50.79162374138832, 40.95564253628254, 38.596485927700996, 39.545902982354164, 42.92980760335922, 47.81293697655201, 54.39201794564724, 53.51832702755928, 54.24264416098595, 55.69456905126572, 58.13158728182316, 53.70577096939087, 32.565563544631004, 4.927835399284959, 5.852309642359614, 6.240789871662855, 3.3397659519687295, 0.49071344663389027, 0.05232600880844984, 4.590847631916404, 40.31362138688564, 54.83833819627762, 47.11631275713444, 45.34685790538788, 47.911591082811356, 56.728710159659386, 65.70439472794533, 20.591174885630608, 1.8010475439950824, 0.1959739497397095, 0.031594217361998744, 0.039036025264067575, 0.13817204511724412, 0.04685747509938665, 0.054199727601371706, 0.04257905682607088, 0.10562964132986963, 0.03928007681679446, 0.0062171816716727335, 0.027344416303094476, 0.02404592054517707, 0.0737675568962004, 0.020814288582187146, 0.1705890556331724, 0.13079180207569152, 0.10592658203677274, 0.16904184099985287, 0.1575136900646612, 0.12073248755768873, 0.18006798840360716, 0.15078128257300705, 0.19456557609373704, 0.16938024549745023, 0.16386727569624782, 0.15045169478980824, 0.12345640701823868, 0.2891548059415072, 0.10975235330988653, 0.20641049050027505, 0.33973323879763484, 11.59491727128625, 50.382214710116386, 61.0692248493433, 52.33217507600784, 37.628997042775154, 30.060813948512077, 45.02428561449051, 59.15912054479122, 41.193403378129005, 1.9151980499736965, 0.2421619853703305, 2.2491396870464087, 8.975000604987144, 16.824279315769672, 8.209969606250525, 18.997369408607483, 45.126807913184166, 60.685635432600975, 56.285235956311226, 50.501418113708496, 46.114367321133614, 44.877165108919144, 44.486359879374504, 43.77922162413597, 41.91303536295891, 42.43214450776577, 44.70559671521187, 45.20663782954216, 50.28508052229881, 51.83921992778778, 54.386500641703606, 48.89668822288513, 45.89400574564934, 54.381963685154915, 49.32686693966389, 52.843874618411064, 50.806925520300865, 48.86875592172146, 40.960981249809265, 37.8381872177124, 40.23222215473652, 37.82139211893082, 37.660596147179604, 39.179804027080536, 39.31544914841652, 41.56555160880089, 38.631960824131966, 40.36776088178158, 38.398364558815956, 38.1423494964838, 39.15033660829067, 40.78184366226196, 36.71462170779705, 40.46923063695431, 41.04779899120331, 41.04802317917347, 36.81110993027687, 36.73771306872368, 39.62709702551365, 43.561706095933914, 47.97728955745697, 51.206854060292244, 52.32487566769123, 50.79827718436718, 49.77248042821884, 47.63788416981697, 44.46396388113499, 49.835819229483604, 50.761373564600945, 47.99074463546276, 51.27048544585705, 43.7189606577158, 49.420231729745865, 53.465585857629776, 52.46406979858875, 49.11590985953808, 47.26801201701164, 49.879269897937775, 52.632795944809914, 47.83722527325153, 52.17365898191929, 42.99925647675991, 40.36234997212887, 43.925072997808456, 42.4618399143219, 40.92714786529541, 40.76092578470707, 39.94132876396179, 41.00419633090496, 40.45527018606663, 38.20163391530514, 40.395731180906296, 40.08744612336159, 41.09396651387215, 40.900492295622826, 40.37257142364979, 40.40476329624653, 41.29494532942772, 39.83052670955658, 39.43309463560581, 41.01990848779678, 36.8486063182354, 37.72682659327984, 38.6671507358551, 37.07828879356384, 35.4564256221056, 39.50536295771599, 40.66397778689861, 44.10414218902588, 49.159409925341606, 53.90239901840687, 53.715483248233795, 54.98260125517845, 47.55219116806984, 50.4052908718586, 56.42612099647522, 53.021150305867195, 43.664976954460144, 41.32491052150726, 41.067793518304825, 44.23105537891388, 48.73899668455124, 55.61784356832504, 56.89886122941971, 57.68326833844185, 57.3342152684927, 62.05418139696121, 55.27420520782471, 34.73685443401337, 8.85843900963664, 16.448164097964764, 16.974010281264782, 9.490903671830893, 0.9929098770953715, 0.21321543550584465, 5.305203124880791, 44.21974338591099, 59.9216066300869, 51.968272402882576, 51.493643671274185, 53.849023282527924, 67.25667983293533, 76.85513198375702, 26.57394055277109, 2.720228908583522, 0.19136960618197918, 0.11749261218938045, 0.23130203451728448, 0.21511313680093735, 0.11393880093237385, 0.18789870024193078, 0.12728901347145438, 0.18394758022623137, 0.10128901252755895, 0.1525572271202691, 0.16192618844797835, 0.13306796899996698, 0.1049599569523707, 0.14558564027538523], [0.015030603717605118, 0.0426322799467016, 0.0490085975616239, 0.016200658901652787, 0.014728442001796793, 0.052336031512822956, 0.00724704284039035, 0.011030792320525507, 0.02965863313875161, 0.051314468946657144, 0.035077613647445105, 0.027102335152449086, 0.019963247432315256, 0.04862080684688408, 0.02812853428622475, 0.09619437652872875, 0.03657992092485074, 4.761897828429937, 33.658669888973236, 51.24774746596813, 42.83113069832325, 19.74767904728651, 19.557835534214973, 35.948886796832085, 45.74037618935108, 38.733472377061844, 5.9824982564896345, 0.11562334999325685, 0.7925241265911609, 8.530907034873962, 14.167923554778099, 6.1756551917642355, 7.027760893106461, 35.15830881893635, 50.647478476166725, 53.49525846540928, 46.48733630776405, 46.7648696154356, 40.46832628548145, 40.72468712925911, 38.93985830247402, 39.42005753517151, 39.8013860732317, 44.53267939388752, 44.699539840221405, 48.38835909962654, 49.098567590117455, 50.988411381840706, 50.09871192276478, 50.21281599998474, 47.37298518419266, 47.02300876379013, 45.97187116742134, 42.88110941648483, 36.42818167805672, 33.466894179582596, 34.62262496352196, 36.42443127930164, 37.19485133886337, 38.6088352650404, 39.328737035393715, 39.199775755405426, 37.42230713367462, 36.5653695166111, 35.68136975169182, 35.707014575600624, 35.882283970713615, 37.0226825773716, 37.7763569355011, 35.16197942197323, 35.99681742489338, 37.58582755923271, 34.92252767086029, 34.10172611474991, 35.27313865721226, 34.666653200984, 36.799718141555786, 40.29445521533489, 42.51680016517639, 48.78135301172733, 49.577706679701805, 51.02723769843578, 47.505590468645096, 47.21877805888653, 42.542691975831985, 47.87169702351093, 51.81868962943554, 40.506392642855644, 42.521314322948456, 43.438094928860664, 52.71653205156326, 45.84439940750599, 48.64633485674858, 47.163164243102074, 47.972011640667915, 49.562245309352875, 50.90186722576618, 48.58660966157913, 46.03838659822941, 35.40709286928177, 38.0199770629406, 37.54314444959164, 36.12418659031391, 35.33058017492294, 36.16295590996742, 36.86193600296974, 37.59020872414112, 35.0244951993227, 34.19692240655422, 36.561850905418396, 36.28533594310284, 37.21496745944023, 36.910774782299995, 35.1905120909214, 36.44801281392574, 35.07814832031727, 36.51971496641636, 35.33198989927769, 36.173735931515694, 35.689212530851364, 34.8023971170187, 34.471374079585075, 34.88808631896973, 35.05583591759205, 36.892699152231216, 39.11961145699024, 41.942153200507164, 45.79633578658104, 48.07714439928532, 52.72786684334278, 48.651844561100006, 46.4461313188076, 50.69319002330303, 51.71761505305767, 44.89061638712883, 39.74620923399925, 36.519274190068245, 40.62793672084808, 38.65509018301964, 43.707511872053146, 42.62413680553436, 47.930825650691986, 50.99160701036453, 56.34228989481926, 55.93756981194019, 28.77440817654133, 3.9720935840159655, 1.9913675752468407, 3.126925597898662, 2.274879743345082, 0.32479704183060676, 0.07526155954110436, 4.843250513076782, 42.0716692507267, 44.99046362936497, 44.229474663734436, 25.860640928149223, 35.35085588693619, 53.01268056035042, 50.23308031260967, 19.233635030686855, 1.081455338280648, 0.05106627620989457, 0.05322044147760607, 0.026579952245811, 0.06375976969138719, 0.07802720996551216, 0.006590869725187076, 0.019052353927691, 0.03635892418969888, 0.03024163281224901, 0.03871738044836093, 0.017137781760538928, 0.04900863095826935, 0.029976745463500265, 0.018445792920829263, 0.04355349672550801, 0.026369976403657347, 0.089850869262591, 0.04334966215537861, 0.06608687763218768, 0.021365503926062956, 0.041412537975702435, 0.0628833229711745, 0.015239931108226301, 0.03454713019891642, 0.04662612540414557, 0.0570205307303695, 0.01131654793425696, 0.007780056084811804, 0.07875901210354641, 0.05426846160844434, 0.040697838630876504, 5.504217920824885, 40.765534937381744, 57.289981842041016, 46.455387622117996, 23.50157931447029, 18.484066352248192, 39.165224209427834, 52.15021423995495, 42.18363784253597, 5.604110285639763, 0.03531926435243804, 0.46762172947637737, 8.836669977754354, 13.792393505573273, 7.920990362763405, 8.297206275165081, 37.06370897591114, 53.731039613485336, 54.21590119600296, 47.99357548356056, 47.600516974925995, 42.68712982535362, 42.61642701923847, 40.664407163858414, 41.244898214936256, 41.26343362033367, 46.40065535902977, 46.797099485993385, 49.5716118067503, 51.16357818245888, 52.78220012784004, 50.87593361735344, 51.587498635053635, 49.761035442352295, 49.19125221669674, 47.50157028436661, 45.25411248207092, 39.72006283700466, 34.721176475286484, 35.184512212872505, 37.39526018500328, 38.689672127366066, 39.76270034909248, 40.362980738282204, 40.47701641917229, 39.06796082854271, 37.56341256201267, 38.00383172929287, 37.68667794764042, 36.815289705991745, 37.81362533569336, 37.97702416777611, 37.18951262533665, 38.168051317334175, 39.293664917349815, 37.990844026207924, 36.096611469984055, 36.58469147980213, 35.75929217040539, 38.42397138476372, 41.79043114185333, 46.52623102068901, 50.75067713856697, 50.73201633989811, 50.8127012103796, 50.36544241011143, 46.45207040011883, 43.36678795516491, 47.016872093081474, 49.73824426531792, 42.19945639371872, 43.331085070967674, 47.58768506348133, 53.57379265129566, 47.68254317343235, 50.1735071092844, 49.581316486001015, 49.94580052793026, 51.42694965004921, 52.82710611820221, 50.886082872748375, 47.24015191197395, 38.64456094801426, 40.14646455645561, 38.96012641489506, 36.03351205587387, 37.23332807421684, 37.33857862651348, 38.159828558564186, 38.122335970401764, 36.52192644774914, 37.01252192258835, 38.56799125671387, 39.033622071146965, 38.700364753603935, 37.98379920423031, 37.72409453988075, 37.82569728791714, 37.62203961610794, 38.74131515622139, 37.34356015920639, 37.23966233432293, 38.0507630109787, 36.2828166782856, 37.158700078725815, 36.11880227923393, 37.464192286133766, 38.546431213617325, 41.9373806566, 44.53859567642212, 49.13838945329189, 50.101436376571655, 53.496447801589966, 51.79432533681393, 47.207568660378456, 52.26644620299339, 54.426786080002785, 45.643006414175034, 41.807473227381706, 38.560118079185486, 42.77249224483967, 40.96526741981506, 45.122878924012184, 44.98555429279804, 50.810269340872765, 52.796479761600494, 59.72095459699631, 56.092274710536, 31.673821695148945, 5.473401099443436, 5.674772243946791, 5.250899288803339, 2.8131600469350815, 0.5767182691488415, 0.039689797995379195, 5.703663993626833, 43.64012248814106, 52.6389592140913, 46.604715809226036, 31.350409649312496, 41.237161830067635, 59.21445317566395, 57.70959712564945, 23.009496219456196, 1.4092478365637362, 0.09620326745789498, 0.009754246366355801, 0.012884567750006681, 0.09062865487067029, 0.04059197126480285, 0.057651037132018246, 0.027173854068678338, 0.020278187075746246, 0.0635920740023721, 0.015592990239383653, 0.030943092242523562, 0.03505497814330738, 0.11628471489530057, 0.003316263005217479, 0.09852293907897547, 0.16031301172915846, 0.2416194902616553, 0.12221114258863963, 0.16209195455303416, 0.13385739148361608, 0.12824783858377486, 0.1465074173756875, 0.12194938710308634, 0.16225509345531464, 0.22731186269083992, 0.13770238438155502, 0.1142554308171384, 0.12543457938591018, 0.12360049498965964, 0.20553680456941947, 0.17468363279476762, 6.351454658433795, 45.13098768889904, 64.80266511440277, 57.16299265623093, 30.0374224036932, 27.227438986301422, 45.732867792248726, 56.78947649896145, 48.52899715304375, 7.517803022637963, 0.18040208844467998, 1.753804322797805, 12.373320702463388, 18.483574278652668, 9.456706456840038, 8.186660706996918, 39.55803193151951, 55.42226046323776, 56.31769001483917, 49.5556640625, 51.19414374232292, 43.36219020187855, 45.522663071751595, 43.14273297786713, 43.89511540532112, 43.961687833070755, 50.549462735652924, 48.366992846131325, 52.77751497924328, 52.898910865187645, 53.17324474453926, 52.304170578718185, 54.737757593393326, 51.754784658551216, 52.60169841349125, 49.383263513445854, 46.85272470116615, 39.9023200571537, 36.693855822086334, 36.859777718782425, 38.14710684120655, 41.0104013979435, 41.12138584256172, 42.42053993046284, 43.37043575942516, 40.98674766719341, 39.42505046725273, 39.84224148094654, 38.84199075400829, 39.00585316121578, 40.82784779369831, 41.04912891983986, 38.939603716135025, 40.28250105679035, 40.68325415253639, 38.737408965826035, 37.55728729069233, 38.47105085849762, 37.53991462290287, 40.377157777547836, 43.28117094933987, 46.99683956801891, 53.4788965433836, 53.568925112485886, 53.79321947693825, 51.8880321085453, 49.419692158699036, 45.40203474462032, 46.96284279227257, 49.55335758626461, 43.89068104326725, 43.46335597336292, 47.17596955597401, 53.59529569745064, 50.2882419526577, 50.76747223734856, 51.868421360850334, 51.77996210753918, 54.15618360042572, 53.08283619582653, 53.218447118997574, 49.71163049340248, 39.72795881330967, 40.6961240619421, 40.708826780319214, 38.99010680615902, 39.535905718803406, 39.49463613331318, 41.30272351205349, 41.115712746977806, 39.70768690109253, 39.1692253947258, 40.58351330459118, 39.55763295292854, 42.0053818076849, 40.23253373801708, 38.51863190531731, 39.95454825460911, 39.4374606013298, 40.874053314328194, 39.282113537192345, 40.127378180623055, 39.94137056171894, 38.24448801577091, 38.557560816407204, 37.73134835064411, 38.43374826014042, 39.36342537403107, 43.60250450670719, 47.18053691089153, 51.16451293230057, 53.620359152555466, 55.929100066423416, 52.93005019426346, 47.25560948252678, 53.84027995169163, 58.11698466539383, 49.886052533984184, 44.42925654351711, 40.236284136772156, 45.50430625677109, 43.2982662320137, 46.34687304496765, 45.97860060632229, 53.813350796699524, 57.08157442510128, 61.41115330159664, 60.11061608791351, 31.410427428781986, 7.9155585542321205, 8.646544329822063, 9.340434595942497, 8.662151992321014, 0.8853399055078626, 0.20272639521863312, 6.647594617679715, 50.18198445439339, 59.406517669558525, 58.194739893078804, 38.16182345151901, 50.441647320985794, 67.81563743948936, 65.69140702486038, 29.384214654564857, 1.7332008783705533, 0.14907346718246117, 0.11706929115462117, 0.1195299337268807, 0.1797098873066716, 0.17042863299138844, 0.2500075550051406, 0.12272393694729544, 0.09253583339159377, 0.12040778310620226, 0.11446924356278032, 0.09248895934433676, 0.15715303597971797, 0.29719428392127156, 0.09901507204631343], [0.08734401315450668, 0.08083657288807444, 0.03698562337376643, 0.011552589858183637, 0.03457894978055265, 0.06274241139180958, 0.005313908168318449, 0.0686086731730029, 0.031257107912097126, 0.057390420843148604, 0.03639372349425685, 0.010582211361906957, 0.03471234340395313, 0.055734277484589256, 0.06391087095835246, 0.04094244308362249, 0.03250231296988204, 1.3170134858228266, 21.483277715742588, 49.755350947380066, 50.32238312065601, 42.566410303115845, 28.279049657285213, 31.527732834219933, 43.74026231467724, 46.147186160087585, 10.985456574708223, 0.16842470067786053, 0.24103763164021075, 3.010780792683363, 14.695825427770615, 5.258155949413776, 3.3715977938845754, 23.561437502503395, 46.2675940990448, 55.208620727062225, 49.22225095331669, 47.120408937335014, 44.32948149740696, 43.888971135020256, 43.113542944192886, 43.002167120575905, 45.92470049858093, 49.56748142838478, 50.15131250023842, 50.95804341137409, 49.00571197271347, 50.99343091249466, 48.99080157279968, 45.12730188667774, 43.22965331375599, 41.113045290112495, 37.704381197690964, 35.951246470212936, 33.73275451362133, 34.287076368927956, 36.272412836551666, 41.9994655251503, 45.79079948365688, 46.90375216305256, 46.28504656255245, 46.9905699044466, 45.00468246638775, 44.02125723659992, 41.05004467070103, 42.05572910606861, 40.20908899605274, 34.97789070010185, 35.68103536963463, 35.60299515724182, 36.2923351675272, 36.31994068622589, 35.34215435385704, 35.235938653349876, 35.50138480961323, 36.05639062821865, 36.45413428544998, 39.18218269944191, 39.518438056111336, 45.73912225663662, 46.37920171022415, 50.64236395061016, 48.230827152729034, 48.965677320957184, 46.32883541285992, 55.692733749747276, 38.05774323642254, 41.76010116934776, 45.70911146700382, 41.14624410867691, 53.702586740255356, 43.14166143536568, 50.57278208434582, 47.03591287136078, 50.69254785776138, 49.23189863562584, 50.782082453370094, 49.433352425694466, 45.84143556654453, 37.740954235196114, 35.67806772887707, 36.592876240611076, 36.52178205549717, 36.418439000844955, 36.24618664383888, 36.78840234875679, 34.75707694888115, 33.297970443964005, 36.103093922138214, 36.5303847938776, 36.83636337518692, 36.66677467525005, 38.54514308273792, 41.844114661216736, 42.04532906413078, 39.35192719101906, 37.63699561357498, 36.67114444077015, 35.93692123889923, 34.793501794338226, 36.12085036933422, 34.98426295816898, 33.799851313233376, 34.703796207904816, 36.12561531364918, 36.66997790336609, 39.739145413041115, 43.8085750490427, 47.52455145120621, 47.78511866927147, 50.0584264844656, 50.32622471451759, 47.51530274748802, 52.88663752377033, 48.8422105461359, 42.36523009836674, 38.16542945802212, 40.216209813952446, 37.745327800512314, 42.6062473654747, 42.02001482248306, 49.55344878137112, 50.99197939038277, 58.091290444135666, 51.539203226566315, 29.673409536480904, 3.110127174295485, 3.2445330871269107, 4.07192942686379, 2.4048769427463412, 1.0358921019360423, 0.043409764984971844, 6.853808602318168, 41.94462686777115, 50.16078919172287, 41.826080828905106, 30.157727748155594, 36.81574188172817, 51.921458914875984, 50.6612641364336, 13.722439259290695, 0.3653505438705906, 0.04852059835684486, 0.06109144080255646, 0.03632982829003595, 0.020842148805968463, 0.046714793497812934, 0.013277385587571189, 0.11141532071633264, 0.07111850529327057, 0.1233971762121655, 0.005185909494684893, 0.06742145953467116, 0.024329760490218177, 0.006110125013947254, 0.013458986340992851, 0.04710023902589455, 0.046630700744572096, 0.07802902080584317, 0.03284422040451318, 0.056066418255795725, 0.05248692126770038, 0.028402904426911846, 0.024486285001330543, 0.026589496264932677, 0.03679634603031445, 0.013718125755985966, 0.02862626304704463, 0.00922746901778737, 0.06842122893431224, 0.08886269220965914, 0.05319416944985278, 0.030904480154276825, 1.6830356139689684, 28.034861460328102, 54.569571018218994, 53.57055902481079, 39.28800322115421, 30.26701368391514, 40.095649883151054, 49.35031168162823, 48.77574451267719, 11.286186687648296, 0.19834524515317753, 0.4785211180569604, 3.863667589612305, 19.085547477006912, 6.6910372115671635, 2.5138161471113563, 25.8396128565073, 48.904812186956406, 57.00046017765999, 49.59748461842537, 49.818739145994186, 45.23491211235523, 45.42645983397961, 43.54989632964134, 45.50644934177399, 47.38456316292286, 51.14932134747505, 52.585195899009705, 52.92042151093483, 48.91821786761284, 51.94717973470688, 50.838285237550735, 48.15932638943195, 45.62612012028694, 44.69437591731548, 40.25288924574852, 39.76556919515133, 35.02916894853115, 36.7632856965065, 37.01693348586559, 43.83549280464649, 47.650818675756454, 48.24384905397892, 48.11848618090153, 49.09399263560772, 46.937216967344284, 45.70627301931381, 42.72665910422802, 42.32945881783962, 40.64856581389904, 38.16840089857578, 36.39079928398132, 37.009877264499664, 37.501175701618195, 38.3574103564024, 36.30329377949238, 37.03102692961693, 37.01310709118843, 36.6971692442894, 37.839072570204735, 41.451576724648476, 40.94342239201069, 47.19656445086002, 48.08230072259903, 52.091480791568756, 49.34079319238663, 50.41971109807491, 47.00829215347767, 55.9510400891304, 41.93737305700779, 42.223729491233826, 45.74421398341656, 43.87744255363941, 53.72075356543064, 46.33410193026066, 50.95403462648392, 48.37130941450596, 51.504868268966675, 48.93465958535671, 52.600554674863815, 52.77031056582928, 48.34862843155861, 39.812052100896835, 36.235178634524345, 38.427432999014854, 37.75118708610535, 36.955289393663406, 37.44584307074547, 37.845547422766685, 36.48302413523197, 35.4791484028101, 38.113444447517395, 38.41395892202854, 38.155435994267464, 38.532360568642616, 40.12588106095791, 42.18413941562176, 42.01892428100109, 39.64994139969349, 38.98360535502434, 38.13069932162762, 36.46502450108528, 37.418735325336456, 37.298106998205185, 37.381596118211746, 36.45135283470154, 37.273385524749756, 38.12323272228241, 39.136858731508255, 41.80959731340408, 46.5956836938858, 49.96417634189129, 51.10411137342453, 52.35704094171524, 48.997234627604485, 50.09267784655094, 55.416355580091476, 49.081502705812454, 43.922618329524994, 40.46020232141018, 41.61831557750702, 40.93060187995434, 43.082867190241814, 44.012616500258446, 49.84590768814087, 54.15242180228233, 60.07462441921234, 54.63017776608467, 29.050674252212048, 4.466865034773946, 6.699300343170762, 9.062183126807213, 1.3761529186740518, 0.7004806562326849, 0.08637516904855147, 7.18853454105556, 46.49441912770271, 53.69076557457447, 47.49112084507942, 32.30891011655331, 43.20821866393089, 58.476316183805466, 58.93256150186062, 18.720926642417908, 0.4915748425992206, 0.019189374797861092, 0.042406500069773756, 0.008228987244365271, 0.026723003065853845, 0.053874310688115656, 0.03625214027124457, 0.06494458619272336, 0.05191338212171104, 0.06489286592113785, 0.10416396646178328, 0.030837826016067993, 0.05202394357183948, 0.11327356944093481, 0.054773548763478175, 0.14571518957382068, 0.14634099818067625, 0.13753646984696388, 0.13257467828225344, 0.1015564231784083, 0.1450124054099433, 0.11565604159841314, 0.12551572581287473, 0.12040145258652046, 0.18073563929647207, 0.08690857284818776, 0.23802528390660882, 0.09562772451317869, 0.19350290967850015, 0.18705851485719904, 0.1131101485225372, 0.21692632231861353, 2.055614646524191, 32.94515937566757, 64.3203341960907, 60.7517708837986, 51.234698966145515, 36.52863688766956, 42.88552097976208, 53.046035170555115, 55.85534982383251, 13.325278870761395, 0.2917733107460663, 1.3975818688049912, 4.87260821275413, 18.72919499874115, 6.928931996226311, 4.477342022582889, 26.587948501110077, 51.49482920765877, 59.12017643451691, 53.41301187872887, 52.16086886823177, 48.25821228325367, 48.01417037844658, 46.81224927306175, 48.467349261045456, 49.700375497341156, 54.848153069615364, 53.773365542292595, 52.82796107232571, 50.74476845562458, 54.87572439014912, 54.01011563837528, 49.99969683587551, 48.08363825082779, 46.32520280778408, 42.28443123400211, 40.500210374593735, 37.03815534710884, 37.84927122294903, 39.28801082074642, 46.08645021915436, 49.702757969498634, 50.96531622111797, 49.78261448442936, 50.43798431754112, 49.4475332647562, 49.75934073328972, 47.254670932888985, 45.628764778375626, 43.578873574733734, 39.215579107403755, 39.20288398861885, 39.42397132515907, 40.176881924271584, 40.13309687376022, 38.47978658974171, 39.20682817697525, 40.94519689679146, 40.538086742162704, 39.66742426156998, 42.55353659391403, 43.41048941016197, 48.94462265074253, 51.50872126221657, 52.35083967447281, 52.0607328414917, 51.47896885871887, 49.125709533691406, 54.46036867797375, 45.84084279835224, 44.28452230989933, 47.86931075155735, 46.07169561088085, 54.3828110396862, 47.84334674477577, 52.16868504881859, 49.80146907269955, 53.818917497992516, 50.40051072835922, 53.550298511981964, 55.94994194805622, 49.99232143163681, 42.71910510957241, 38.7031614035368, 40.90860866010189, 39.91107478737831, 39.250282645225525, 40.76771602034569, 40.718311071395874, 38.10517229139805, 38.132679015398026, 39.96731556952, 40.770672261714935, 40.87574042379856, 40.6312957406044, 41.686373725533485, 45.043774768710136, 46.85840159654617, 42.827228307724, 41.4366739243269, 39.32264216244221, 37.49815486371517, 38.42289984226227, 40.04244513809681, 40.12967325747013, 37.707880809903145, 38.64541210234165, 40.04959635436535, 40.99239036440849, 43.28973188996315, 48.87475959956646, 53.39831046760082, 53.035384342074394, 54.73561450839043, 52.16274596750736, 49.44192476570606, 57.38170512020588, 53.541817367076874, 46.89808286726475, 43.02259102463722, 45.5217245221138, 42.175536677241325, 46.66576713323593, 47.34921745955944, 54.80527997016907, 55.06125323474407, 62.508283630013466, 56.24568767845631, 32.0513067394495, 6.240277849137783, 8.116271384060383, 10.493086595088243, 8.906749617308378, 1.8658156623132527, 0.25089501519687474, 8.39431956410408, 49.75320786237717, 61.77559554576874, 55.06014369428158, 43.93932983279228, 51.56434267759323, 64.12180244922638, 66.45448967814445, 22.847537510097027, 0.8153541327919811, 0.1786207262193784, 0.1562714239116758, 0.10897622269112617, 0.15304836560972035, 0.1641631402890198, 0.16269459330942482, 0.2068963597412221, 0.15774230123497546, 0.18574065354187042, 0.19792174600297585, 0.1145580192678608, 0.23464757687179372, 0.15386095794383436, 0.07850397305446677], [0.09244382934411988, 0.0887927002622746, 0.033643272254266776, 0.04065815970534459, 0.02642543153342558, 0.0412012967717601, 0.02597014248749474, 0.05276535652228631, 0.05035693146055564, 0.023464770674763713, 0.05589297092228662, 0.10270623257383704, 0.03587826853618026, 0.10663880631909706, 0.006866924541100161, 0.07602135548950173, 0.008903761827241397, 0.8315700595267117, 16.93375524133444, 48.47969479858875, 49.86135005950928, 35.79284816980362, 16.111435666680336, 32.5414614379406, 45.53331010043621, 47.591306269168854, 19.627113416790962, 0.193778216780629, 0.41594812413677573, 1.902972562238574, 3.3604344679042697, 5.9525691624730825, 1.4451103121973574, 10.479485224932432, 31.96755163371563, 49.418920800089836, 52.332904636859894, 49.57867182791233, 49.53733004629612, 47.44656443595886, 46.94952450692654, 49.484022706747055, 50.76846018433571, 50.79982370138168, 48.489129692316055, 46.72908693552017, 46.31704084575176, 49.13270875811577, 43.72758239507675, 42.3247242718935, 38.95120829343796, 36.701592206954956, 34.47018854320049, 34.87452104687691, 34.02930960059166, 35.79201601445675, 41.10045276582241, 45.39903670549393, 49.596907049417496, 50.550914257764816, 50.5284308642149, 50.04727028310299, 47.06098012626171, 46.762471944093704, 47.66883350908756, 47.88858711719513, 46.48553900420666, 41.003968343138695, 37.16770559549332, 34.8033394664526, 37.45224952697754, 35.20527809858322, 37.58849121630192, 35.951330065727234, 33.88924151659012, 33.85104596614838, 35.63133783638477, 37.03868731856346, 35.71964889764786, 39.6709618717432, 44.387633576989174, 46.87146909534931, 48.61712962388992, 46.867148727178574, 48.070867136120796, 38.12541760504246, 38.89201506972313, 53.0474790930748, 39.71760056912899, 39.91213113069534, 52.22583018243313, 43.058274909853935, 49.417400881648064, 47.46008791029453, 50.23040145635605, 49.40699324011803, 49.1133563965559, 49.05476354062557, 46.922006383538246, 39.893952906131744, 34.611149579286575, 35.977715849876404, 37.30878822505474, 36.286380887031555, 37.01473720371723, 36.342249289155006, 37.23246552050114, 39.01944883167744, 38.85933302342892, 36.47599831223488, 39.610423520207405, 41.39141075313091, 47.222463861107826, 47.396882101893425, 48.87687608599663, 47.968736216425896, 43.056637197732925, 41.572315245866776, 37.80483640730381, 36.21372498571873, 34.74867559969425, 34.69488948583603, 34.73083175718784, 35.1363155990839, 36.05918347835541, 35.93443997204304, 36.588339284062386, 38.66848826408386, 43.94216448068619, 48.043390810489655, 47.7591622620821, 51.84248395264149, 50.42687751352787, 50.495612025260925, 52.59915255010128, 51.630443930625916, 48.25508885085583, 43.61048027873039, 39.54304553568363, 39.29498344659805, 41.17310866713524, 47.32204511761665, 52.482715398073196, 57.734861969947815, 53.313803002238274, 23.064794652163982, 2.329685389995575, 6.564715364947915, 7.468326352536678, 0.10599399873171933, 0.28985337470658123, 0.0580835496657528, 7.760794758796692, 46.435765475034714, 51.811595410108566, 45.573584139347076, 28.231613002717495, 38.36621068418026, 51.3165807723999, 45.29111109673977, 10.740941595286131, 0.25764633261132985, 0.05653293599607423, 0.01060853441231302, 0.04085312561073806, 0.05238375531916972, 0.022919286566320807, 0.1212826935807243, 0.008301855941681424, 0.03491133917123079, 0.04343411113950424, 0.07911902794148773, 0.03894066670909524, 0.034920293182949536, 0.024800721839710604, 0.04232250379573088, 0.05505181703483686, 0.020023524666612502, 0.07159897912060842, 0.03241813858039677, 0.026878811404458247, 0.02762532476481283, 0.05827690511068795, 0.059917990292888135, 0.05543981555092614, 0.09660988274845295, 0.02174032932089176, 0.08065611225902103, 0.0809596135513857, 0.07757087820209563, 0.04251932507031597, 0.05055551904661115, 0.03852671157801524, 1.2863316759467125, 20.148291550576687, 54.381690099835396, 56.20712734758854, 42.7157536894083, 21.56031858175993, 32.80588924884796, 50.707435458898544, 52.807388976216316, 20.65479677170515, 0.1492394707747735, 0.3387524757999927, 0.6273876596242189, 8.8710742816329, 6.0022134985774755, 1.9275453686714172, 15.908066779375076, 32.9643939435482, 53.39907802641392, 52.505027800798416, 51.69716075062752, 51.48809216916561, 50.073386281728745, 49.34406481683254, 51.2037306278944, 52.41845704615116, 52.306306064128876, 51.559140756726265, 49.050804153084755, 47.484459802508354, 51.07711382210255, 46.7827058583498, 43.67328330874443, 41.1685337126255, 38.39340962469578, 36.1681692302227, 35.949623957276344, 35.80170549452305, 37.54369542002678, 41.793562173843384, 47.57073037326336, 50.761039182543755, 51.398983150720596, 51.64139874279499, 50.75553707778454, 49.57498222589493, 49.53698806464672, 48.501684218645096, 49.80841509997845, 46.49017475545406, 42.15097099542618, 38.67713280022144, 37.03146010637283, 38.64526391029358, 37.4839436262846, 38.29802334308624, 37.75016114115715, 36.02680541574955, 35.31884640455246, 37.969534769654274, 38.18145699799061, 38.57404053211212, 40.662222281098366, 48.004279509186745, 48.54047633707523, 50.844516903162, 48.464442417025566, 49.37047339975834, 42.29778751730919, 40.38300186395645, 52.01842971146107, 41.52827560901642, 43.090937957167625, 51.95137470960617, 48.46111759543419, 50.565953850746155, 50.470597967505455, 52.97380484640598, 49.64438170194626, 50.299960523843765, 51.61968670785427, 48.87722186744213, 41.46432124078274, 36.88276268541813, 37.0228573679924, 39.003162905573845, 38.499644324183464, 38.967095240950584, 38.27832140028477, 37.26852558553219, 39.857501462101936, 40.27810089290142, 39.11455012857914, 39.56417240202427, 41.88269019126892, 49.647869914770126, 50.71840547025204, 50.71761131286621, 49.63980674743652, 44.507688134908676, 41.81851923465729, 37.83594153821468, 38.47231239080429, 36.91006802022457, 36.88353404402733, 35.759907737374306, 36.07432946562767, 38.3051897585392, 38.93339104950428, 38.86226266622543, 41.63335137069225, 47.43719793856144, 50.924491211771965, 48.829804211854935, 52.97435961663723, 50.20843103528023, 52.91278012096882, 53.96291837096214, 51.7924140393734, 47.84468047320843, 44.73800137639046, 42.12777704000473, 42.04521507024765, 44.0669459849596, 49.626670852303505, 55.547049567103386, 60.69530591368675, 54.05887082219124, 26.693953312933445, 6.401820005849004, 4.760372210294008, 7.895030155777931, 3.1133399019017816, 0.6171444186475128, 0.08136508593452163, 8.65067470818758, 48.7311577051878, 57.008861526846886, 51.50267578661442, 36.9047749042511, 44.83212232589722, 57.24408030509949, 54.78551723062992, 13.023690953850746, 0.47077633207663894, 0.09666341386036947, 0.048470525653101504, 0.015344407875090837, 0.08139722092892043, 0.03708511940203607, 0.054834278707858175, 0.04064675289555453, 0.039290945569518954, 0.01551257668324979, 0.024009208354982547, 0.05872807894775178, 0.09460770190344192, 0.021004443515266757, 0.10223430828773417, 0.18614300148328766, 0.18210580718005076, 0.18845626094844192, 0.10072738485177979, 0.12587465811520815, 0.12306947348406538, 0.16280177427688614, 0.17800744506530464, 0.1892527486779727, 0.15923568047583103, 0.16454129421617836, 0.14350762678077444, 0.20837998716160655, 0.28184349357616156, 0.12229291984112933, 0.1955312438076362, 0.11185836061486043, 1.4890961581841111, 24.721319563686848, 61.35677441954613, 60.070855021476746, 47.15371794998646, 24.41719528287649, 42.88924477994442, 57.10773982107639, 58.77292826771736, 25.029412731528282, 0.5327513033989817, 0.9291573136579245, 6.116017866879702, 7.880469812080264, 10.376278012990952, 2.9751664912328124, 12.747022099792957, 33.807336911559105, 52.349961921572685, 55.15467122197151, 53.449436724185944, 55.55694803595543, 52.704570293426514, 51.88790291547775, 54.2920833081007, 54.78066109120846, 53.461478278040886, 52.551700696349144, 51.292246878147125, 50.06611347198486, 52.448483034968376, 48.85409630835056, 45.07149048149586, 43.443061262369156, 40.58982856571674, 37.5820429623127, 38.23213487863541, 36.696428284049034, 38.6946764588356, 44.19116511940956, 50.85726901888847, 55.47446206212044, 53.86429846286774, 54.03643682599068, 52.88390927016735, 51.554296016693115, 51.904352232813835, 50.957515239715576, 52.10042931139469, 50.162122920155525, 43.83603237569332, 40.96034288406372, 39.01784531772137, 41.06960602104664, 38.222521394491196, 41.453419625759125, 38.53923059999943, 38.11689466238022, 37.328626960515976, 40.21756254136562, 40.51245331764221, 38.883488327264786, 43.979018703103065, 49.230196326971054, 49.75122056901455, 52.91741967201233, 49.929571598768234, 50.04956915974617, 44.48888674378395, 44.80393923819065, 52.990098372101784, 42.01007455587387, 44.52799044549465, 53.4334471821785, 48.27855259180069, 52.62004762887955, 49.586488008499146, 54.40103106200695, 54.2201379686594, 52.49708242714405, 55.0818557292223, 51.03655859827995, 43.25145274400711, 38.44343014061451, 38.204616755247116, 42.97200433909893, 40.083448737859726, 41.882127821445465, 39.672303199768066, 39.64954622089863, 42.52768278121948, 44.24779728055, 40.63385300338268, 41.72028310596943, 45.013991966843605, 52.6893825083971, 51.753112748265266, 53.283731415867805, 53.04843284189701, 47.64120899140835, 44.83662508428097, 42.005697190761566, 39.53874036669731, 39.289583936333656, 39.55373056232929, 37.95402020215988, 38.76264341175556, 40.030384585261345, 41.533785313367844, 41.11042343080044, 44.30628754198551, 50.315190106630325, 53.87535206973553, 51.11899517476559, 55.04709139466286, 51.0545240342617, 53.14191162586212, 55.10177806019783, 55.2406720072031, 52.36231505870819, 47.53015615046024, 43.618019074201584, 42.92348474264145, 45.77609047293663, 52.45951384305954, 57.060637548565865, 63.35153818130493, 56.43549129366875, 25.949162878096104, 4.987723510712385, 13.838670272380114, 16.223330162465572, 3.1834952998906374, 0.7551092561334372, 0.1859980303561315, 9.645991399884224, 55.39966307580471, 64.16690602898598, 59.47216674685478, 39.23757612705231, 50.530323162674904, 65.13044312596321, 61.34254798293114, 18.08760892599821, 0.7583875895943493, 0.15449849248398095, 0.11791026321589015, 0.13853903714334592, 0.14784081926336512, 0.13337564858375117, 0.21813053113874048, 0.12278458525543101, 0.20569593587424606, 0.10297980305040255, 0.1653326314408332, 0.12483364756917581, 0.13064065627986565, 0.08444443476037122, 0.2313672989839688], [0.013690334180864738, 0.029789366162731312, 0.07238863167003728, 0.019041479608858936, 0.031129269264056347, 0.045938102557556704, 0.015369819939223817, 0.04001892564701848, 0.05772999422333669, 0.004157616112934193, 0.020688615149992984, 0.020063496740476694, 0.05781257299531717, 0.04904722263745498, 0.10194475937169045, 0.07087513280566782, 0.031594632964697666, 0.06719704892020673, 11.077935062348843, 43.7635550647974, 49.8789469152689, 32.58651942014694, 28.810063563287258, 36.06258809566498, 51.972763761878014, 44.59819167852402, 30.67725107073784, 0.8940346702001989, 0.17255556886084378, 1.7794029554352164, 5.952508365735412, 4.020870141685009, 1.4598960313014686, 4.63446406647563, 15.07681293413043, 40.916200652718544, 49.47956934571266, 52.33981266617775, 51.232426688075066, 51.03441931307316, 49.90636624395847, 50.963294729590416, 49.436403661966324, 51.65125161409378, 45.978657603263855, 50.76396122574806, 49.46746699512005, 45.20800955593586, 42.526964619755745, 39.5066586881876, 34.65364269912243, 33.42941679060459, 34.38850812613964, 35.97308769822121, 35.53048364818096, 41.82218983769417, 46.14440090954304, 49.16319452226162, 46.643124148249626, 48.30284848809242, 49.05225947499275, 50.2692049741745, 50.61543479561806, 48.96825358271599, 49.70306195318699, 48.634658083319664, 47.392139956355095, 47.43823528289795, 38.49480338394642, 35.09742848575115, 36.58375293016434, 37.28660501539707, 38.72659854590893, 37.76102475821972, 36.53712183237076, 36.713561564683914, 35.02454459667206, 37.09121949970722, 34.56691615283489, 37.26708926260471, 38.9170291274786, 46.019809395074844, 44.10036899149418, 47.63784617185593, 41.08371086418629, 43.62119570374489, 48.43828082084656, 50.3250277787447, 44.92046758532524, 38.5788244754076, 50.49897104501724, 43.12699422240257, 46.51998035609722, 47.35797978937626, 49.27078574895859, 47.04136937856674, 49.90869551897049, 48.818777203559875, 47.83589154481888, 40.28774857521057, 35.93744181096554, 34.3557994812727, 35.48368155956268, 36.63751244544983, 35.8670087903738, 37.0199391245842, 38.107159584760666, 40.90526103973389, 40.406826585531235, 40.92249311506748, 42.790077701210976, 46.268456652760506, 48.027348071336746, 51.6337725520134, 50.832764133811, 49.97548833489418, 49.06270131468773, 46.72794319689274, 46.56478375196457, 44.03234124183655, 41.61594830453396, 41.463367491960526, 39.44513238966465, 37.4588193744421, 35.70240922272205, 36.161534786224365, 36.55441090464592, 35.102394819259644, 37.67520636320114, 44.300758838653564, 47.49869383871555, 51.05603255331516, 51.936190724372864, 51.71320728957653, 52.18291528522968, 50.37689879536629, 47.70991310477257, 48.633920922875404, 44.428701773285866, 43.02227944135666, 43.78514550626278, 48.70707839727402, 54.417567774653435, 58.37380908429623, 48.06769050657749, 20.12435283511877, 3.22081143502146, 4.778821645304561, 10.224835239350796, 0.9491820610128343, 0.1485930898343213, 0.07858293756726198, 7.476666904985905, 46.94633647799492, 47.57655926048756, 31.657254584133625, 13.487554863095284, 38.30745443701744, 50.62252901494503, 48.62495720386505, 8.970998469740152, 0.019229842255299445, 0.061346895454335026, 0.011088848677900387, 0.0430737019632943, 0.05355633009457961, 0.07975456610438414, 0.03503115149214864, 0.037781175997224636, 0.0355241045326693, 0.08184262085705996, 0.01751462394167902, 0.06255294108996168, 0.03214994867448695, 0.06505280616693199, 0.08568632241804153, 0.005640886838591541, 0.011489652024465613, 0.04502163552388083, 0.046320442197611555, 0.009351270382467192, 0.033339485235046595, 0.027542862881091423, 0.03613734857935924, 0.07455964369000867, 0.014359788492583903, 0.03962558366765734, 0.06626303380471654, 0.04804120064363815, 0.03650002501672134, 0.12189216009574011, 0.01774535765434848, 0.022840492747491226, 0.12963543209480122, 14.215887431055307, 49.99170206487179, 53.850816786289215, 36.05867810547352, 24.63818572461605, 39.07044589519501, 57.72495210170746, 51.272282749414444, 31.919571608304977, 0.9562609624117613, 0.30140701099298894, 0.40567962045315653, 5.5748903285712, 6.826282404363155, 1.8603388499468565, 7.870045071467757, 17.9762938991189, 44.101736918091774, 50.00362582504749, 54.68698091804981, 51.92925609648228, 52.38816887140274, 51.46838262677193, 51.46142899990082, 50.254598557949066, 51.65651053190231, 47.81560443341732, 54.31546725332737, 51.78991377353668, 46.053536385297775, 46.10336311161518, 41.39719784259796, 36.5762597322464, 36.11034393310547, 36.03416942059994, 36.32216736674309, 36.71932965517044, 43.56450654566288, 48.55865456163883, 49.91449400782585, 49.08208787441254, 50.25732681155205, 51.252276822924614, 51.783055141568184, 51.04469396173954, 51.34141243994236, 50.437437146902084, 51.176679879426956, 49.59330104291439, 48.34575958549976, 39.88265611231327, 37.006894424557686, 37.51900814473629, 38.94984036684036, 39.6274808049202, 38.59839342534542, 37.09743596613407, 36.90277621150017, 36.40762098133564, 37.64988452196121, 36.606878489255905, 38.041540905833244, 41.53345473110676, 47.86907896399498, 48.06582100689411, 50.05515865981579, 44.38209727406502, 45.20728759467602, 52.473968267440796, 49.96912367641926, 46.06414161622524, 41.79876409471035, 51.853244975209236, 42.66007147729397, 48.668187484145164, 49.50044922530651, 51.57380037009716, 49.39224623143673, 50.15195466578007, 50.301073864102364, 49.29388850927353, 41.78495943546295, 37.600665763020515, 36.98190316557884, 37.20424823462963, 38.42231087386608, 36.683660969138145, 38.138724491000175, 38.63401271402836, 43.03555592894554, 42.040442526340485, 43.12996186316013, 44.499488174915314, 49.14672240614891, 51.02577097713947, 53.610145300626755, 52.00032748281956, 51.723972111940384, 49.684047773480415, 47.18104988336563, 48.183356299996376, 45.707363560795784, 42.398645505309105, 42.5077186524868, 40.36676533520222, 37.40053050220013, 37.616693302989006, 37.758551090955734, 37.52658113837242, 37.48501516878605, 41.185454204678535, 48.05017724633217, 48.82381573319435, 54.002512246370316, 53.03500056266785, 52.5779876857996, 52.91621133685112, 52.65796199440956, 51.998305991292, 51.34013190865517, 46.36736914515495, 43.47668565809727, 44.788550063967705, 50.69311782717705, 55.6608572602272, 61.42914533615112, 50.46376973390579, 22.9461707174778, 5.236913189291954, 6.740049831569195, 9.92663199082017, 2.083790609613061, 0.582484103506431, 0.055109511595219374, 8.478255160152912, 51.78810127079487, 56.066234707832336, 45.29142647981644, 20.1186740398407, 45.64468212425709, 57.87142664194107, 54.28418353199959, 12.186445780098438, 0.06254814681597054, 0.09719060588395223, 0.08215623762225732, 0.07844542502425611, 0.046420086655416526, 0.047445582604268566, 0.014009102378622629, 0.034654181290534325, 0.06640163730480708, 0.02337001325940946, 0.008453629779978655, 0.0273530864433269, 0.05043445620685816, 0.014569077848136658, 0.046482145044137724, 0.16895995242521167, 0.07668536985875107, 0.19651464885100722, 0.11646541301161051, 0.19450393330771476, 0.23425170045811683, 0.08771756576607004, 0.09998750814702362, 0.21935425844276324, 0.16503238817676902, 0.13342847465537488, 0.28791061020456254, 0.19110161665594205, 0.12042300455505028, 0.3178752976236865, 0.22118586406577379, 0.11000688027706929, 0.33497230208013207, 16.32970355451107, 55.85754610598087, 62.73966081440449, 43.587613105773926, 39.94221791625023, 47.09843471646309, 62.68948830664158, 54.583250284194946, 38.333604633808136, 1.1603551357984543, 0.5515689624007791, 3.238566694781184, 14.108084365725517, 10.749103557318449, 3.903294475749135, 6.57966423779726, 16.56597677618265, 42.858576625585556, 50.037113428115845, 54.77155297994614, 53.06615129113197, 54.377985298633575, 51.35993644595146, 52.62936092913151, 50.38427419960499, 51.569225415587425, 47.79847875237465, 54.769596084952354, 54.445796459913254, 50.61252035200596, 47.68729671835899, 43.64768788218498, 38.37300851941109, 37.01538696885109, 37.821563109755516, 38.466031327843666, 38.99462856352329, 47.88019336760044, 51.00264921784401, 52.223219722509384, 49.85560096800327, 51.64882734417915, 52.93756619095802, 54.31170165538788, 55.8327030390501, 53.19367624819279, 52.736454382538795, 52.51692496240139, 52.05142334103584, 52.03769467771053, 41.95626564323902, 39.300766736269, 40.32851658761501, 40.946796610951424, 41.436894312500954, 40.16108617186546, 39.918161407113075, 39.9132938683033, 38.13622422516346, 40.72788655757904, 38.39894972741604, 39.98451344668865, 44.030384346842766, 49.59065638482571, 49.220936223864555, 52.55092553794384, 48.20560410618782, 47.16043218970299, 54.18878585100174, 52.26360395550728, 47.634251564741135, 45.98879165947437, 55.40067382156849, 45.586917623877525, 49.08819034695625, 50.51763944327831, 52.24049359560013, 50.435533449053764, 54.87838804721832, 54.44490730762482, 52.410450875759125, 45.58108493685722, 39.576449543237686, 38.526459485292435, 38.6216975748539, 39.89226199686527, 38.703210800886154, 41.12103246152401, 42.13774010539055, 45.103499963879585, 45.39937488734722, 45.965658500790596, 47.20161437988281, 51.02818764746189, 53.93009193241596, 57.36434765160084, 53.83814826607704, 55.63465006649494, 52.40530975162983, 49.53553654253483, 51.494441628456116, 49.280885607004166, 45.94086863100529, 46.020204573869705, 41.64193890988827, 40.82817457616329, 41.251278072595596, 40.37587724626064, 38.99970129132271, 40.14264576137066, 43.140380904078484, 50.03482975065708, 52.99008697271347, 56.23712293803692, 55.610015988349915, 54.27586577832699, 55.020454823970795, 54.39068801701069, 54.333976060152054, 54.447206184268, 50.89730367064476, 45.69301553070545, 48.6605840921402, 53.426318764686584, 59.411901980638504, 64.22398656606674, 52.544876262545586, 21.15691512823105, 6.051656445488334, 9.269980676472187, 21.344830244779587, 6.757807228714228, 0.9603227069601417, 0.2667240158189088, 9.597832784056664, 56.61875165998936, 62.878509163856506, 46.65129750967026, 22.243043147027493, 52.7469228208065, 63.85400801897049, 65.16419291496277, 16.81678991764784, 0.18948870711028576, 0.23416270210873336, 0.16696940845577046, 0.20355717017082497, 0.14848440972855315, 0.1414764576475136, 0.09796969767194241, 0.1252682789345272, 0.0922125687066, 0.3161872975761071, 0.18572477158159018, 0.16393399477237836, 0.07382096926448867, 0.11134684275020845, 0.26002090831752867], [0.03169746123603545, 0.02920288396126125, 0.07668837555684149, 0.041195808589691296, 0.07618560761329718, 0.004245339823683025, 0.07480039639631286, 0.07855150761315599, 0.046099003884592094, 0.03382966635399498, 0.16316331893904135, 0.05432274228951428, 0.06663739535724744, 0.03882713666826021, 0.041899375719367526, 0.033539828000357375, 0.017123226389230695, 0.019882919223164208, 5.067419959232211, 34.23422880470753, 46.404466554522514, 39.46342460811138, 15.637836679816246, 23.41529544442892, 41.903839856386185, 37.00079955160618, 35.954590290784836, 1.9589658826589584, 0.3218333492986858, 0.3090364078525454, 3.044473584741354, 3.4579491103067994, 2.063834792934358, 3.8767538499087095, 3.0737246526405215, 22.09410633891821, 39.07442048192024, 51.51356600224972, 48.97528700530529, 50.47035478055477, 48.71779382228851, 52.67018213868141, 52.255882769823074, 54.35706362128258, 52.6316674053669, 51.857360154390335, 45.53035765886307, 44.77337367832661, 37.53415413200855, 35.09204417467117, 34.75513905286789, 35.52710562944412, 35.86296580731869, 40.41561171412468, 41.81995175778866, 46.51165120303631, 47.560573518276215, 49.8616274446249, 48.950310945510864, 49.18107256293297, 49.77311499416828, 49.65897671878338, 47.62858226895332, 51.290582567453384, 48.054034039378166, 52.83033214509487, 49.06992852687836, 48.7868133187294, 45.42144790291786, 38.66553582251072, 36.12364701926708, 37.087423503398895, 37.69710458815098, 36.97523072361946, 34.66904707252979, 36.082985401153564, 34.07528333365917, 35.659878104925156, 34.43676933646202, 36.83200120925903, 38.14833037555218, 42.67109848558903, 42.69109681248665, 47.15559884905815, 45.99310822784901, 50.908995643258095, 44.9515613168478, 51.16808474063873, 44.421599954366684, 36.56641826033592, 42.58816413581371, 43.23363550007343, 47.04035483300686, 45.28372809290886, 47.19818316400051, 48.747344836592674, 47.803790867328644, 47.38277725875378, 45.505563989281654, 38.761051297187805, 34.487538412213326, 36.67240597307682, 35.33375680446625, 35.82722872495651, 34.8833479732275, 35.299847424030304, 42.704650685191154, 43.19123737514019, 47.575168535113335, 47.98051558434963, 47.52624236047268, 48.48660662770271, 49.766951724886894, 52.39720098674297, 47.35244728624821, 51.526880487799644, 49.18852396309376, 49.83883626759052, 49.470636025071144, 49.71494771540165, 49.325286224484444, 47.3277448117733, 45.66329352557659, 47.59943023324013, 42.89603501558304, 38.31481084227562, 35.20421415567398, 38.61010819673538, 36.794580817222595, 39.32343631982803, 44.028188064694405, 48.08675028383732, 50.96468925476074, 53.70192177593708, 49.960235953330994, 42.566307708621025, 54.64424841105938, 54.39576834440231, 50.839691162109375, 46.86584919691086, 42.40603230893612, 46.646897345781326, 52.80059494078159, 60.80815985798836, 43.678903207182884, 19.9894904717803, 8.505566194653511, 3.214143980294466, 2.9601451847702265, 2.8003471344709396, 1.1922844662331045, 0.12332079437328503, 10.06280243396759, 42.639712169766426, 49.01738874614239, 37.020528092980385, 26.29389178007841, 42.03535079956055, 49.72064360976219, 48.09338852763176, 8.085349593311548, 0.11271767856669612, 0.01749295879562851, 0.08427175183896907, 0.03970312696765177, 0.007507976861234056, 0.02086377498926595, 0.10340256747440435, 0.03890852058248129, 0.03901166797732003, 0.013457796121656429, 0.05944343138253316, 0.049561000341782346, 0.02078643021377502, 0.025120951140706893, 0.1144144062709529, 0.05757214312325232, 0.027287475022603758, 0.08839931746479124, 0.030870385890011676, 0.07493540048017167, 0.06187035818584263, 0.027857808090629987, 0.03965986346884165, 0.019742742369999178, 0.028242897387826815, 0.06570450830622576, 0.04160937409324106, 0.03238404060539324, 0.0712615394149907, 0.0489622096210951, 0.08274316511233337, 0.027237678768869955, 0.03631882223999128, 7.508331555873156, 41.71567015349865, 53.34885232150555, 44.61636610329151, 24.47364315390587, 30.033905692398548, 49.26277957856655, 43.67502361536026, 39.76942218840122, 2.605725140310824, 0.12917807616759092, 0.048074786536744796, 3.5948032792657614, 6.725859018042684, 4.505576407536864, 3.007202809676528, 5.447404319420457, 27.195566296577454, 41.473528146743774, 52.15340606868267, 47.96980395913124, 50.34702479839325, 49.88767884671688, 52.74689242243767, 51.9232714176178, 53.929768949747086, 53.763554468750954, 53.104339241981506, 47.7065958827734, 47.36219756305218, 39.84444156289101, 37.45291069149971, 35.539971739053726, 36.58745773136616, 37.56933644413948, 41.966593489050865, 43.365644216537476, 47.271728217601776, 49.490265771746635, 52.27891333401203, 51.08678810298443, 51.9887875020504, 49.943034276366234, 50.68854667246342, 50.07756985723972, 52.75217413902283, 49.03936676681042, 53.23506362736225, 50.71215860545635, 50.941495299339294, 45.42228385806084, 39.68744158744812, 37.574082389473915, 39.33906868100166, 38.94739329814911, 38.661827221512794, 37.16257207095623, 38.41619700193405, 37.304616048932076, 36.3491041213274, 36.3280114531517, 39.460905343294144, 39.160235077142715, 43.308335691690445, 45.84153436124325, 48.11298407614231, 46.94480136036873, 53.64358730614185, 47.500145360827446, 51.24571077525616, 47.75394894182682, 39.83237341046333, 45.453993156552315, 45.82223139703274, 49.19341430068016, 47.22453474998474, 49.24679383635521, 49.05773498117924, 51.121111661195755, 49.624843150377274, 48.16779613494873, 40.4644200950861, 36.92214377224445, 38.19388993084431, 37.14966036379337, 36.89624436199665, 37.3891045153141, 37.75247901678085, 43.410998582839966, 45.28586357831955, 49.42524366080761, 48.170699179172516, 49.95799407362938, 49.56098757684231, 52.101470455527306, 53.2353638112545, 50.570635199546814, 50.241743847727776, 52.829511389136314, 51.7410521954298, 50.79315505921841, 51.272746324539185, 50.58487683534622, 47.908289059996605, 47.06112451851368, 47.675000578165054, 43.15546229481697, 40.00253967940807, 37.90698632597923, 40.84905445575714, 38.75404067337513, 42.67212063074112, 47.58854761719704, 51.516917422413826, 52.22166560590267, 54.70912992954254, 52.216463685035706, 44.55703228712082, 55.77895872294903, 56.003085896372795, 53.43183606863022, 48.12420107424259, 44.937175288796425, 48.30296628177166, 54.65461045503616, 62.626020312309265, 46.162750124931335, 19.0502492710948, 7.518567256629467, 3.4988736268132925, 7.710526306182146, 4.504663506522775, 0.690930699929595, 0.08833690284518525, 11.469752937555313, 48.128130063414574, 55.56725688278675, 40.00875614583492, 24.980503655970097, 44.66605223715305, 54.708430767059326, 55.759644359350204, 10.803374145179987, 0.15589656512020156, 0.09486193201155402, 0.04345939240010921, 0.06427749191061594, 0.02244671846710844, 0.05908053972234484, 0.08465587263344787, 0.0367158638255205, 0.05396140542870853, 0.0193845763351419, 0.05157473642611876, 0.07783773966366425, 0.06303247981122695, 0.05390402257035021, 0.03588203493563924, 0.1290598075138405, 0.20001976779894903, 0.18967428855830804, 0.12613158964086324, 0.21992262481944636, 0.15085181628819555, 0.12647820229176432, 0.08444465740467422, 0.15093281428562477, 0.07641822638106532, 0.2469213042058982, 0.10009053308749571, 0.12176133430330083, 0.11512107928865589, 0.13799458276480436, 0.19537392334314063, 0.13565935572842136, 0.12825481477193534, 7.841236442327499, 45.2513462305069, 61.1518894135952, 50.150142163038254, 26.435042805969715, 33.30903545022011, 55.441487431526184, 47.52200938761234, 45.85570000112057, 2.793736201710999, 0.4405158542795107, 0.8772450336255133, 8.781176805496216, 9.790499545633793, 6.633105520159006, 6.56438478268683, 4.524910245090723, 25.277847200632095, 43.277234360575676, 52.66058765351772, 49.30366538465023, 52.36194647848606, 49.681376516819, 55.74228309094906, 54.63682360947132, 55.83406716585159, 55.61740659177303, 55.631013661623, 48.84110100567341, 49.87624906003475, 42.71255046129227, 38.31837125122547, 36.96279399096966, 37.857311591506004, 39.68618385493755, 44.71381187438965, 44.9039650708437, 50.74482545256615, 50.72037756443024, 55.34558817744255, 54.47114109992981, 55.04505090415478, 53.636455088853836, 52.74464674293995, 51.46069563925266, 54.994395822286606, 51.546396240592, 56.79595895111561, 52.45315678417683, 54.346830770373344, 48.21125440299511, 42.08035558462143, 39.09192234277725, 40.263502076268196, 40.6365280598402, 40.882492661476135, 39.33821752667427, 39.74853850901127, 37.6568229496479, 39.18042339384556, 37.315882444381714, 41.322691440582275, 41.647399216890335, 46.478410586714745, 46.85802161693573, 51.84274233877659, 50.16333505511284, 56.51699312031269, 49.04974400997162, 54.85027715563774, 48.23016978800297, 44.09637160599232, 47.664000168442726, 47.4443681538105, 51.89331382513046, 47.570426389575005, 51.28334015607834, 50.48841901123524, 51.04986548423767, 52.602234184741974, 50.83022207021713, 41.34866684675217, 38.44161383807659, 39.69718046486378, 39.98757988214493, 39.27005298435688, 38.19476008415222, 38.64787437021732, 45.25080285966396, 46.3311342895031, 52.75821961462498, 52.658942341804504, 52.15606592595577, 51.60390615463257, 53.62011216580868, 55.866574421525, 50.85955649614334, 53.99868965148926, 55.274076014757156, 54.16996546089649, 53.58578860759735, 54.741728380322456, 52.39487171173096, 52.169684395194054, 49.44664031267166, 51.455562114715576, 46.25413902103901, 43.03660847246647, 39.68893110752106, 43.661572337150574, 40.22708483040333, 43.34046296775341, 49.73213039338589, 53.06564211845398, 55.619492679834366, 56.97128914296627, 53.30850228667259, 45.72377108037472, 58.05951274931431, 58.37431065738201, 54.7233297675848, 51.03274740278721, 46.856885477900505, 51.021047830581665, 56.89465865492821, 65.54481089115143, 49.2916352301836, 22.319493144750595, 17.03172728419304, 11.525013372302055, 7.941039986908436, 7.119120815768838, 2.3535165237262845, 0.30338557669892907, 12.105998396873474, 53.40713359415531, 60.53596906363964, 47.919076681137085, 36.41635291278362, 56.05594106018543, 62.7495326846838, 63.11299458146095, 13.885536957532167, 0.26818848098628223, 0.17796359898056835, 0.1321186582208611, 0.13014353608014062, 0.12049614320858382, 0.12196510579087771, 0.18652274360647425, 0.10139761841855943, 0.1874639798188582, 0.11564249740331434, 0.23302470770431682, 0.10881154012167826, 0.19366480177268386, 0.17984620499191806, 0.15555263904388994], [0.043019959339289926, 0.027684397864504717, 0.0490160338813439, 0.016209022905968595, 0.028439739071473014, 0.019336670702614356, 0.021494405700650532, 0.08343039386090823, 0.05200760147999972, 0.008971777806436876, 0.04063420317834243, 0.03546367515809834, 0.011284115153102903, 0.031752573122503236, 0.03371524944668636, 0.009371917858516099, 0.06830564685515128, 0.06596146951778792, 1.8478466640226543, 25.794174894690514, 49.23608601093292, 33.64395707845688, 20.89889757335186, 32.67987281084061, 38.31751249730587, 41.922584250569344, 39.544994831085205, 6.811124067753553, 0.028594265349966008, 0.20391724538058043, 1.031308004166931, 5.086566656827927, 2.01723575592041, 1.869757475797087, 2.0570868300274014, 10.659384671598673, 28.454531840980053, 48.48300442099571, 50.64589396119118, 52.071748450398445, 49.67764511704445, 51.8201145529747, 49.175950437784195, 49.41491961479187, 48.77935811877251, 47.697673961520195, 43.054528310894966, 38.405283987522125, 35.609154626727104, 35.21527536213398, 34.43887822329998, 38.171934708952904, 40.012506544589996, 45.20734079182148, 45.41940361261368, 47.416485249996185, 47.54317045211792, 48.60495127737522, 45.2347981184721, 49.4223178178072, 50.76669707894325, 51.417666748166084, 49.77665260434151, 51.92654684185982, 49.66501459479332, 49.08047296106815, 50.93715973198414, 48.230382576584816, 47.26029843091965, 41.00451171398163, 36.48480623960495, 36.639575734734535, 36.34782738983631, 35.4186936467886, 36.04140043258667, 35.731215476989746, 35.94968095421791, 37.30203218758106, 33.8635016977787, 36.333133578300476, 37.287456169724464, 39.140058159828186, 41.852371618151665, 43.98482859134674, 41.271789371967316, 46.41814202070236, 47.32109136879444, 48.60234081745148, 48.39625507593155, 38.06468166410923, 42.623745426535606, 43.73462341725826, 45.47262355685234, 46.29121743142605, 47.09753796458244, 47.943851351737976, 47.297247648239136, 46.673256531357765, 45.52263267338276, 38.00562523305416, 34.85437452793121, 35.00121384859085, 36.00100859999657, 36.52351476252079, 36.59039497375488, 35.864291936159134, 41.838240176439285, 46.875458881258965, 49.758899956941605, 48.14036540687084, 47.999005392193794, 48.998059183359146, 50.96237137913704, 49.339315071702, 47.9628237336874, 48.14888074994087, 49.032409340143204, 50.82601569592953, 50.83267293870449, 47.40742653608322, 48.34017388522625, 48.43060903251171, 51.715141385793686, 51.8584430962801, 47.28054754436016, 45.569142177700996, 41.152498573064804, 37.12729476392269, 34.82338719069958, 35.9457291662693, 37.7708700299263, 45.1382414996624, 47.48855218291283, 50.785289481282234, 53.919832482934, 52.13666796684265, 55.464768782258034, 53.536357060074806, 53.20091485977173, 50.01775346696377, 48.47054868936539, 48.0695828050375, 50.59855990111828, 58.63640919327736, 38.79640839993954, 11.97395358234644, 4.124553753063083, 5.830661254003644, 10.617053993046284, 1.4037859858945012, 0.14071084326133132, 0.04970031630364247, 11.03628359735012, 42.14662402868271, 46.95760667324066, 40.277033150196075, 30.396831817924976, 41.27939276397228, 53.50261107087135, 37.880695536732674, 5.9285615757107735, 0.08450299763353541, 0.0016820381665638706, 0.05687770069926046, 0.031668788360548206, 0.06314505619229749, 0.044352693294058554, 0.037105836454429664, 0.06216718385985587, 0.055218889319803566, 0.04395115429360885, 0.027200317199458368, 0.06905208414536901, 0.047688465274404734, 0.10362210960010998, 0.03802018465648871, 0.01820420158765046, 0.0847402993531432, 0.07052136585116386, 0.037360151909524575, 0.04167294275248423, 0.05901878190343268, 0.01862127744971076, 0.030365202255779877, 0.04452092332940083, 0.04202709191304166, 0.012291371895116754, 0.049000946019077674, 0.012698058617388597, 0.03362094103067648, 0.029649638308910653, 0.03357077555847354, 0.022252704366110265, 0.08702031802386045, 2.8622878482565284, 31.705063618719578, 56.56491234898567, 38.75751368701458, 21.075920574367046, 31.898585334420204, 43.3835868537426, 45.53712509572506, 42.84769780933857, 6.187714319676161, 0.10543640833930112, 0.07056570175336674, 1.9373455177992582, 8.146793246269226, 5.336900074034929, 5.753521593287587, 4.762252159416676, 14.144881591200829, 30.978012531995773, 49.36845950782299, 52.030140683054924, 51.38062633574009, 52.55241505801678, 52.74718500673771, 51.45054258406162, 52.57234878838062, 51.51565968990326, 50.15212945640087, 48.397486209869385, 40.941267907619476, 37.801788970828056, 36.58498406410217, 36.41170956194401, 40.84921024739742, 40.724056363105774, 46.444033831357956, 47.89454139769077, 49.00877460837364, 50.77909201383591, 51.102082282304764, 48.165698647499084, 51.13585487008095, 52.50965215265751, 53.4096110612154, 51.585955917835236, 52.88361668586731, 51.342350989580154, 50.88846154510975, 53.91081556677818, 50.74983738362789, 49.50389564037323, 43.73596854507923, 37.744685634970665, 37.72887468338013, 37.821768298745155, 37.399732545018196, 38.18337209522724, 36.57439403235912, 38.16853769123554, 39.00738827884197, 36.01308815181255, 37.455144971609116, 39.01939943432808, 42.091078609228134, 44.26845297217369, 45.35986080765724, 44.44151468575001, 46.76622994244099, 49.68740299344063, 50.56804373860359, 50.57324565947056, 40.378898084163666, 44.87754508852959, 46.1312498152256, 47.226674035191536, 48.7488267570734, 49.35291074216366, 49.81548652052879, 49.29893843829632, 48.02982173860073, 46.487115919589996, 38.716700077056885, 36.65019616484642, 36.577920243144035, 37.6535589247942, 37.15185284614563, 36.62895530462265, 36.891703605651855, 43.26500281691551, 49.575871378183365, 51.57738737761974, 48.91015850007534, 50.426505133509636, 49.897470921278, 53.55168543756008, 50.623338371515274, 49.71312001347542, 48.657156676054, 51.56402349472046, 51.17539554834366, 53.39433968067169, 49.74105231463909, 51.49948015809059, 52.819814309477806, 54.028400257229805, 52.75611832737923, 49.744209945201874, 46.54141500592232, 41.19896627962589, 38.498694375157356, 37.6129125058651, 38.29855151474476, 40.671938359737396, 47.50745616853237, 51.87013506889343, 52.95760631561279, 56.1253709346056, 52.18837559223175, 56.20927423238754, 54.329184517264366, 55.26641562581062, 52.59819880127907, 51.98146149516106, 48.89993704855442, 55.28241276741028, 58.82651299238205, 42.81437739729881, 11.98813347145915, 6.594272553920746, 5.944119840860367, 6.331020779907703, 4.078448927029967, 0.12367806426482275, 0.13169143348932266, 12.215756457298994, 46.58045031130314, 55.102572217583656, 40.19857496023178, 32.40868516266346, 49.368653297424316, 58.84900018572807, 45.22368751466274, 8.276077508926392, 0.0997489076689817, 0.01810701363865519, 0.08835890010232106, 0.014833698023721809, 0.005346763509805896, 0.021350204551708885, 0.04448717416380532, 0.03681217604025733, 0.04272325983038172, 0.0318406215228606, 0.0332116725621745, 0.0363453540194314, 0.03673906336189248, 0.1070489245466888, 0.023108036984922364, 0.10466258579981513, 0.1643472522846423, 0.16133953555254266, 0.14115614671027288, 0.09926490121870302, 0.20415059145307168, 0.12064390481100418, 0.16023630334530026, 0.10412152303615585, 0.10404561617178842, 0.1282320753671229, 0.18149295647162944, 0.08672624942846596, 0.13054643321083859, 0.13299886020831764, 0.11776456478401087, 0.09054442110937089, 0.11938560084672645, 3.474601716734469, 36.30083151161671, 63.871129900217056, 45.15151038765907, 30.22662755101919, 44.054102674126625, 49.76158641278744, 50.120249167084694, 48.08555714786053, 8.470924403518438, 0.15802400565007702, 0.8090906438883394, 2.8979997569695115, 12.375331744551659, 10.241024270653725, 5.141138378530741, 4.277566792443395, 13.519223313778639, 31.737508177757263, 50.49821488559246, 53.738669604063034, 53.3612434566021, 54.339018389582634, 55.00360652804375, 54.31459330022335, 52.91969574987888, 55.19030570983887, 51.718880385160446, 49.45736713707447, 43.38722325861454, 39.918693378567696, 37.49464005231857, 37.73230969905853, 42.373091876506805, 43.27148146927357, 50.13229452073574, 50.345143899321556, 50.38697585463524, 52.770591750741005, 52.4364110827446, 50.86145259439945, 54.24761049449444, 55.42987145483494, 55.597248673439026, 52.735614627599716, 55.180057659745216, 54.0903103351593, 53.81032235920429, 54.8069366812706, 52.47600495815277, 51.68605014681816, 46.27063013613224, 40.15112690627575, 39.58804652094841, 40.41872754693031, 38.56744788587093, 40.341964066028595, 38.69651556015015, 39.160166680812836, 40.78625902533531, 37.31802172958851, 41.02887220680714, 40.71660876274109, 44.61122117936611, 47.28377357125282, 48.930776193737984, 45.524825155735016, 49.81966629624367, 51.01488076150417, 53.43125469982624, 51.20746202766895, 44.426205307245255, 45.69264695048332, 47.86166936159134, 50.38765601813793, 49.46102254092693, 50.40170006453991, 52.16684974730015, 51.0950830578804, 50.21097309887409, 49.72307167947292, 39.94515135884285, 39.10033129155636, 38.0542816221714, 40.88444195687771, 38.86774577200413, 39.433242827653885, 39.09061521291733, 45.79076528549194, 51.13408416509628, 54.0295971930027, 51.521693766117096, 51.92238986492157, 54.31837409734726, 54.46711711585522, 52.88596495985985, 49.93174508213997, 48.87390464544296, 52.40916654467583, 52.956124395132065, 56.081205904483795, 51.55297748744488, 52.43672266602516, 55.07680959999561, 56.06876917183399, 56.010727286338806, 52.42840491235256, 48.98986682295799, 44.18100446462631, 42.02340044081211, 38.514968901872635, 41.14122457802296, 41.43372528254986, 49.18241769075394, 53.53498533368111, 56.23169302940369, 57.97575384378433, 53.46769854426384, 57.0149601995945, 57.04145237803459, 57.60756120085716, 55.75693130493164, 53.72846335172653, 51.883453354239464, 56.91209591925144, 62.81293608248234, 41.997463032603264, 14.975314680486917, 7.4843857157975435, 10.48022048547864, 21.902552917599678, 5.605316245928407, 0.27582129172515124, 0.18244511709781364, 14.22596924006939, 52.23319038748741, 62.010468542575836, 53.80049988627434, 43.12344901263714, 54.31840069591999, 66.74778833985329, 52.521507516503334, 10.290019791573286, 0.1391376237734221, 0.10998831916367635, 0.20920374139677733, 0.07301636243937537, 0.11135934051708318, 0.13308048160979524, 0.24529922171495855, 0.26127647375687957, 0.2071809585322626, 0.1120379677740857, 0.1395440089982003, 0.12056094754370861, 0.16489774774527177, 0.25366194953676313, 0.10001673392252997], [0.018304404511582106, 0.04263418726623058, 0.029498550029529724, 0.012967198472324526, 0.02761290677881334, 0.014538014329446014, 0.013874409996788017, 0.02602518943604082, 0.003729142022166343, 0.05412960206740536, 0.0653188735304866, 0.01600588595465524, 0.02706329818465747, 0.03141674016660545, 0.04759581555845216, 0.06749628286343068, 0.028703576281259302, 0.05158498548553325, 0.6939035654067993, 16.63173984736204, 42.66405366361141, 42.686643451452255, 31.096233688294888, 32.88302130997181, 36.55186504125595, 39.82770726084709, 46.32604256272316, 12.0728774741292, 0.07212449389044195, 0.05850728259247262, 1.1217118031345308, 5.081925205886364, 5.742725422605872, 2.1158976992592216, 2.7061074413359165, 7.360511887818575, 22.142173759639263, 43.51569816470146, 53.06647427380085, 51.013193652033806, 48.616187274456024, 48.08308728039265, 46.53125435113907, 46.1827826499939, 45.53917698562145, 41.37202799320221, 37.66665682196617, 37.11073525249958, 35.929739624261856, 37.08404928445816, 40.045416578650475, 42.24824197590351, 45.22191680967808, 47.320597395300865, 49.43093955516815, 49.056317657232285, 46.692285910248756, 43.482153564691544, 45.99815055727959, 44.533173367381096, 47.38754600286484, 48.27826760709286, 47.37219862639904, 46.68619483709335, 47.14987635612488, 51.98603644967079, 49.059045910835266, 50.14978878200054, 48.72030928730965, 46.559540033340454, 38.35359536111355, 36.11188285052776, 36.32674612104893, 36.21542349457741, 35.35262279212475, 38.40573996305466, 34.96066242456436, 35.69930098950863, 34.44176226854324, 35.69006748497486, 35.64735397696495, 36.873996555805206, 36.89867623150349, 42.02239349484444, 41.66198283433914, 47.8604382276535, 44.99153897166252, 50.053406953811646, 48.686377108097076, 38.51132869720459, 42.64379695057869, 45.75295731425285, 44.71737988293171, 44.176152125000954, 48.1682863086462, 47.43470527231693, 49.76833485066891, 46.57898738980293, 43.723357021808624, 36.64146043360233, 36.54640473425388, 34.963341280817986, 37.016618102788925, 35.167610719799995, 36.10343590378761, 34.90074723958969, 42.2184781730175, 48.261381313204765, 50.541076585650444, 49.8818651586771, 52.18942053616047, 52.201971262693405, 51.360377222299576, 51.651521399617195, 50.29071941971779, 49.737754091620445, 49.49576407670975, 50.29344007372856, 49.29416209459305, 49.375606924295425, 50.82634627819061, 51.81718870997429, 52.396817207336426, 52.762349992990494, 52.414087280631065, 49.504697397351265, 48.16904626786709, 42.79710352420807, 40.70782743394375, 35.91978035867214, 36.66765622794628, 41.825617253780365, 47.94230483472347, 47.65438288450241, 51.59324772655964, 51.01563312113285, 52.22316652536392, 51.110194846987724, 52.332467660307884, 53.66466477513313, 51.858997866511345, 50.03696143627167, 51.32023997604847, 56.89762629568577, 34.54352080821991, 5.541629763320088, 3.7189081823453307, 2.259928733110428, 6.080301208421588, 6.141515923663974, 0.3526938386494294, 0.07374167078523897, 13.51962799206376, 44.6944747120142, 47.711531817913055, 38.035400435328484, 31.1654032766819, 41.59711271524429, 46.55438371002674, 27.742328457534313, 4.057388557121158, 0.05970618876744993, 0.03460295825789217, 0.017881315397971775, 0.0562248445203295, 0.026490805466892198, 0.0635773794783745, 0.04784065378771629, 0.08729912064154632, 0.02832555222994415, 0.014385039139597211, 0.007394718631985597, 0.04014716134406626, 0.08440127145149745, 0.0285536772935302, 0.037990539567545056, 0.03318424649478402, 0.03818281889834907, 0.030013114410394337, 0.029754744973615743, 0.057531733182258904, 0.03723046160303056, 0.04041161824716255, 0.0263605362852104, 0.05013399771996774, 0.05057196132838726, 0.049216899860766716, 0.03808491106610745, 0.03885303020069841, 0.07342262149904855, 0.033848539169412106, 0.05570096989686135, 0.007419291605401668, 0.07689870020840317, 0.9092421666719019, 21.35369896888733, 50.859089121222496, 47.49148942530155, 37.10842877626419, 38.92425633966923, 44.731705114245415, 47.46872864663601, 49.66145038604736, 13.87185674160719, 0.08468864587484859, 0.13382163480855525, 0.9254263294860721, 7.233135597780347, 5.7914825063198805, 8.241845145821571, 3.5840211203321815, 9.481396581977606, 27.461014352738857, 42.01329678297043, 54.101177752017975, 53.3308070898056, 51.252010837197304, 48.48727159202099, 50.48179976642132, 50.45772805809975, 48.13294060528278, 43.901670053601265, 40.569917634129524, 38.23974207043648, 38.001126274466515, 38.931764736771584, 42.19722591340542, 45.1701407879591, 46.71430952847004, 48.23998466134071, 50.59092231094837, 50.98262049257755, 48.99031139910221, 46.382017359137535, 46.16456262767315, 46.48764029145241, 48.86977806687355, 51.330655217170715, 50.511141791939735, 49.28804062306881, 50.26694789528847, 54.25710618495941, 50.89859180152416, 51.75409309566021, 50.054744482040405, 47.22222067415714, 40.690922141075134, 37.74790406227112, 39.03630092740059, 38.15697871148586, 37.637348994612694, 39.24935169517994, 37.804437428712845, 35.9122833609581, 35.89495249092579, 37.58304990828037, 37.756708189845085, 39.97292786836624, 39.77411113679409, 44.16537590324879, 45.48453591763973, 50.12780696153641, 47.479048892855644, 50.79207591712475, 49.32770289480686, 41.960308626294136, 44.642736688256264, 47.399625554680824, 46.85011804103851, 47.346375212073326, 51.207507625222206, 49.1342780739069, 50.80389328300953, 47.74553619325161, 44.98563028872013, 38.56943517923355, 38.37076283991337, 37.11046926677227, 38.478703647851944, 37.43964560329914, 38.54868069291115, 37.294326201081276, 44.79294642806053, 50.47698922455311, 51.99958272278309, 50.96076026558876, 52.93155491352081, 53.27396593987942, 52.41980977356434, 52.89046011865139, 52.248655557632446, 51.41083091497421, 52.82232217490673, 51.10609866678715, 51.636025831103325, 50.31286843121052, 52.90224328637123, 52.35565781593323, 52.542938366532326, 54.091796055436134, 54.78728413581848, 50.392804741859436, 49.94534835219383, 44.39258851110935, 41.36005863547325, 37.69623063504696, 37.984593361616135, 42.646570801734924, 49.50934834778309, 49.452431201934814, 53.475814908742905, 53.39595079421997, 53.99199441075325, 52.94481240212917, 54.566964358091354, 55.76963782310486, 52.20917567610741, 52.96106792986393, 53.213628977537155, 57.862709909677505, 38.438684195280075, 7.195247830823064, 6.0720836743712425, 6.6726528480648994, 6.551709612831473, 3.642842201516032, 0.19548984681023285, 0.12364195135887712, 15.46000812202692, 50.0194975733757, 53.75568129122257, 38.41989040374756, 33.28806437551975, 46.33831590414047, 55.45763276517391, 35.41352592408657, 5.497390162199736, 0.04586642222420778, 0.059610028692986816, 0.040232189203379676, 0.04219344431476202, 0.04589333992043976, 0.033025590164470486, 0.008444008763035526, 0.03667624056106433, 0.03828726876236033, 0.01640673104702728, 0.024906056714826263, 0.026961868861690164, 0.0744679884519428, 0.02628923815791495, 0.017732062078721356, 0.10056883242214099, 0.11020333418855444, 0.13130639243172482, 0.10686705383704975, 0.16050095320679247, 0.12448215900803916, 0.11110721810837276, 0.07142159098293632, 0.10991581133566797, 0.17190418584505096, 0.236226674169302, 0.11050607106881216, 0.20979688066290691, 0.18191652983659878, 0.17117101815529168, 0.15008255053544417, 0.09728537814226002, 0.1652908930554986, 1.2380519416183233, 24.458556063473225, 57.58789345622063, 55.33526413142681, 41.868201568722725, 43.67258034646511, 48.37857462465763, 51.5296695381403, 56.82261072099209, 15.528689436614513, 0.26316054922062904, 0.4344903869787231, 3.5349785769358277, 13.773231133818626, 13.206111565232277, 7.74724611081183, 5.773666687309742, 9.167296886444092, 26.374614648520947, 45.90462237596512, 55.83982765674591, 55.10974243283272, 52.14385338127613, 50.48836201429367, 50.46534284949303, 51.746611297130585, 48.146988451480865, 45.37616953253746, 42.646760791540146, 40.50413556396961, 38.75432945787907, 42.06305891275406, 45.50704970955849, 48.152973130345345, 49.155138954520226, 51.2834769487381, 52.63912260532379, 54.61084060370922, 51.01521134376526, 49.08837653696537, 49.057784378528595, 48.616479858756065, 51.238703951239586, 53.60838979482651, 53.59731338918209, 51.20302766561508, 52.206941395998, 56.411013007164, 53.16239632666111, 52.94793963432312, 53.79586033523083, 50.47947809100151, 42.421223893761635, 39.463667795062065, 41.98014736175537, 40.75612284243107, 38.61603207886219, 41.976077780127525, 38.823804929852486, 38.17694664001465, 37.550911232829094, 38.7446703761816, 38.74065399169922, 41.26099035143852, 41.71717867255211, 46.50243669748306, 47.566174417734146, 51.934047639369965, 50.22060938179493, 53.5137140750885, 51.59619636833668, 44.11146059632301, 45.906343683600426, 49.06140938401222, 50.369128212332726, 48.79926525056362, 54.214293882250786, 51.2595534324646, 52.27844595909119, 50.13846918940544, 48.42690423130989, 40.46927623450756, 39.815859496593475, 38.716931864619255, 39.62235867977142, 39.37771260738373, 40.260697826743126, 38.54370675981045, 44.61725525557995, 53.27718436717987, 54.94682997465134, 53.05268481373787, 55.78748166561127, 55.718389973044395, 54.94102008640766, 56.459946781396866, 52.57060848176479, 52.05388940870762, 54.361015409231186, 52.977365255355835, 51.69531784951687, 51.124550476670265, 54.17754605412483, 55.71546033024788, 54.114777222275734, 55.288986414670944, 56.27916008234024, 54.161522313952446, 53.81643243134022, 47.12123729288578, 44.626633152365685, 40.31246244907379, 40.328733175992966, 45.22615358233452, 50.813981741666794, 51.7612025141716, 55.436764284968376, 54.38449814915657, 55.38809269666672, 54.73499894142151, 55.28226837515831, 58.921127915382385, 55.34099042415619, 55.55249087512493, 56.463932767510414, 60.259226113557816, 38.037999495863914, 7.739049950614572, 10.696135349571705, 12.937668319791555, 16.299255788326263, 12.239665724337101, 0.7035310612991452, 0.13192503189202398, 17.41767067462206, 55.65635070204735, 62.308254763484, 51.73260524868965, 42.86193184554577, 54.314692094922066, 62.39698000252247, 41.25438630580902, 6.679549003019929, 0.14586007164325565, 0.15486033400520682, 0.10286237302352674, 0.22452901670476422, 0.08462622383376583, 0.15020786959212273, 0.09136000429862179, 0.15680539916502312, 0.10674376084352843, 0.03757962353120092, 0.10122359963133931, 0.14371211815159768, 0.14567913603968918, 0.09573738425388001, 0.11372248714906164], [0.02985572715260787, 0.07342524128034711, 0.036219266839907505, 0.05895781076105777, 0.012920969165861607, 0.02392650527326623, 0.0467786738590803, 0.03349215243360959, 0.07257684032083489, 0.034878094666055404, 0.0693459968897514, 0.05492208219948225, 0.06420974124921486, 0.035074674742645584, 0.041530142407282256, 0.039957824628800154, 0.026413607265567407, 0.025121654325630516, 0.12318253226112574, 10.080044008791447, 42.795325219631195, 42.66351029276848, 28.15520480275154, 23.349984548985958, 30.29172945767641, 39.332536831498146, 42.27564990520477, 22.206679098308086, 0.8942020393442363, 0.06453065332607366, 0.5257672781590372, 3.8438447657972574, 2.7168036298826337, 12.310192789882421, 4.881228050217032, 6.434556674212217, 22.792235277593136, 43.36453087627888, 51.954809725284576, 47.57000081241131, 47.87281796336174, 46.049102023243904, 42.65292026102543, 40.622339621186256, 38.13787333667278, 36.057473570108414, 38.058966770768166, 38.97986255586147, 40.49476146697998, 41.50581881403923, 44.469048008322716, 45.41176222264767, 47.38533832132816, 48.73262822628021, 49.03279311954975, 46.94249868392944, 44.813032150268555, 42.1191743016243, 38.845980539917946, 40.93401409685612, 44.29527573287487, 46.36108808219433, 45.84618531167507, 43.47857415676117, 43.04822824895382, 45.348852798342705, 47.8558024764061, 50.544610396027565, 47.710760459303856, 47.633282616734505, 41.482317075133324, 35.968592539429665, 35.2232663333416, 36.05993203818798, 36.49337857961655, 36.039663925766945, 34.88699957728386, 34.95924890041351, 34.75349374115467, 37.1630622446537, 35.92500887811184, 36.63298308849335, 36.05890989303589, 37.95254208147526, 39.64479647576809, 41.30745425820351, 46.81608326733112, 46.68620623648167, 50.50334081053734, 40.60329504311085, 47.42645591497421, 43.204901441931725, 48.651388585567474, 43.43656361103058, 49.23583522439003, 47.642329931259155, 46.853085681796074, 44.083266109228134, 43.97864632308483, 37.68284395337105, 35.84433160722256, 34.76266264915466, 37.39154018461704, 35.68334944546223, 37.70975410938263, 34.75231200456619, 42.71378919482231, 48.025178387761116, 48.98212283849716, 47.395183593034744, 50.22613428533077, 49.524368941783905, 49.36881668865681, 47.760898768901825, 48.68803381919861, 46.74870528280735, 48.4366051107645, 47.80545137822628, 51.63964703679085, 49.05224047601223, 48.83987367153168, 47.36507400870323, 52.28765666484833, 52.82174840569496, 51.228387504816055, 51.328785717487335, 49.97851677238941, 48.18201497197151, 45.23066394031048, 43.92497040331364, 41.175137758255005, 41.2397912889719, 46.943486630916595, 46.45584359765053, 49.43011499941349, 48.69203120470047, 54.05998796224594, 51.22639261186123, 55.32726176083088, 53.60580213367939, 55.442190393805504, 52.15516537427902, 58.06627258658409, 47.58523039519787, 31.851591356098652, 2.602431667037308, 3.689190214499831, 5.809612283483148, 2.4096786975860596, 2.3885639430955052, 0.127620990970172, 0.11290393536910415, 10.99593736231327, 40.663020238280296, 42.34175115823746, 40.818359702825546, 32.60323092341423, 46.6151462495327, 44.033427983522415, 20.087036937475204, 2.7191169932484627, 0.1232834643451497, 0.020856819210166577, 0.04063649641466327, 0.08918283245293424, 0.07806981666362844, 0.08587227493990213, 0.025669301794550847, 0.03647879588243086, 0.09529849296086468, 0.060788908012909815, 0.06208499842614401, 0.035004408200620674, 0.009610005326976534, 0.05550661255256273, 0.03313993656774983, 0.03617046320869122, 0.07960969145642594, 0.0410718031344004, 0.06806362507632002, 0.03263390317442827, 0.018186801935371477, 0.026224016364722047, 0.01753440959873842, 0.04563919144857209, 0.03321684162074234, 0.038660825084662065, 0.01752351858158363, 0.04781589574122336, 0.04983291211829055, 0.02023462857323466, 0.07435329694999382, 0.06418982942705043, 0.03461072483332828, 0.09004077743156813, 12.821432556957006, 46.41969233751297, 49.06347647309303, 31.627813763916492, 30.04443682730198, 37.35105335712433, 44.297373220324516, 48.1897247582674, 20.730363316833973, 0.5766483291517943, 0.06919850246049464, 0.9431860421318561, 5.163577124476433, 6.299491971731186, 12.858230732381344, 5.6495558470487595, 7.050494598224759, 23.752012476325035, 44.347716718912125, 54.69718337059021, 48.9472559094429, 49.72660928964615, 49.60588596761227, 45.882496163249016, 42.928979247808456, 40.18045753240585, 37.31063112616539, 38.711916133761406, 39.536753073334694, 41.12170122563839, 42.84177012741566, 47.912962809205055, 48.76343697309494, 49.32908982038498, 48.673366606235504, 49.33715678751469, 48.928272128105164, 47.26457320153713, 44.9563642591238, 40.55624216794968, 42.85388007760048, 45.716684460639954, 48.60965922474861, 47.642424926161766, 45.377005487680435, 45.815574154257774, 48.37707370519638, 52.09252953529358, 51.42023541033268, 50.00198811292648, 48.91557700932026, 43.16957853734493, 37.24702253937721, 37.03186668455601, 37.359523102641106, 37.62738972902298, 37.971628457307816, 36.357718259096146, 36.03291168808937, 37.88101091980934, 37.00163930654526, 37.656815350055695, 38.2847810536623, 38.2153245806694, 40.65745733678341, 41.9821422547102, 44.7610205411911, 49.2474739998579, 49.95637536048889, 52.09635213017464, 43.49208243191242, 50.10881558060646, 46.54641933739185, 49.82308991253376, 45.54391913115978, 50.67462041974068, 50.5812556296587, 50.619264990091324, 46.28758482635021, 44.4083196669817, 39.39584523439407, 37.598401084542274, 36.08540587127209, 37.65172362327576, 37.06122010946274, 37.72052653133869, 37.48592332005501, 43.436586409807205, 50.2084044367075, 51.21000789105892, 48.690587282180786, 51.757759898900986, 51.80293947458267, 52.11960308253765, 50.0960748642683, 49.660610631108284, 47.71592818200588, 50.782804414629936, 49.79532100260258, 53.109130784869194, 49.30588446557522, 52.48671278357506, 49.4101432710886, 52.04254321753979, 53.368573263287544, 52.04915106296539, 53.07865262031555, 53.33385832607746, 50.73472559452057, 47.23618112504482, 44.46223497390747, 41.87438003718853, 43.35603453218937, 49.65761259198189, 48.073139414191246, 50.96924141049385, 51.20926313102245, 55.5714176595211, 53.20132903754711, 55.42175509035587, 55.63938841223717, 56.78167551755905, 55.34648112952709, 58.9097361266613, 49.83690597116947, 32.241980507969856, 3.9834561618044972, 3.4845633571967483, 5.545603400096297, 4.984765844419599, 2.3269120138138533, 0.22257647069636732, 0.08119995065499097, 13.409346509724855, 47.051704823970795, 49.65767718851566, 43.948988914489746, 36.32386967539787, 50.38716584444046, 51.72258138656616, 25.489353351294994, 3.1455797469243407, 0.10536094676353969, 0.02141071185178589, 0.04960330647008959, 0.04692964153946377, 0.08585258576204069, 0.027488433770486154, 0.08770108266617171, 0.04320725885918364, 0.06881135370349512, 0.060246850771363825, 0.06865975519758649, 0.012234968671691604, 0.09602945647202432, 0.09675788183812983, 0.04694241390097886, 0.11201110944966786, 0.19665571628138423, 0.10638861349434592, 0.2098072410444729, 0.15448694466613233, 0.10181330275372602, 0.1083785637456458, 0.0866108454647474, 0.13594724965514615, 0.1520652128965594, 0.1421014647348784, 0.12003728814306669, 0.11639586635283194, 0.15799936634721234, 0.20473941141972318, 0.21389484201790765, 0.2265063504455611, 0.18936053820652887, 0.3724010952282697, 14.645045902580023, 53.91970328986645, 54.47162747383118, 39.906807616353035, 34.65740829706192, 40.53810954093933, 50.61011128127575, 52.67358675599098, 27.076604180037975, 1.448359969072044, 0.11696801026118919, 2.142230523750186, 10.927719622850418, 8.224105797708035, 20.274370685219765, 11.402155514806509, 9.475353006273508, 26.121943406760693, 46.91398121416569, 58.08400623500347, 53.046472147107124, 53.08810271322727, 51.62682272493839, 47.749537378549576, 42.86969482898712, 41.975169628858566, 39.16276954114437, 40.30862085521221, 41.76862411201, 44.35205228626728, 45.731461867690086, 50.64041465520859, 48.512487038969994, 52.09583915770054, 51.63463890552521, 52.533195689320564, 51.6983462870121, 50.321433171629906, 47.336203157901764, 41.92997865378857, 44.25956144928932, 48.9986177533865, 50.923849046230316, 51.18548020720482, 48.02700608968735, 47.55802385509014, 49.63271252810955, 52.91091062128544, 54.18144844472408, 50.29204174876213, 51.188219860196114, 45.04526808857918, 39.13860283792019, 39.587449952960014, 39.8163078725338, 40.752843618392944, 40.24020552635193, 37.52566918730736, 37.85951927304268, 39.17888447642326, 40.55404968559742, 40.33414788544178, 41.04565590620041, 39.384810626506805, 42.55827493965626, 44.61305648088455, 45.93054838478565, 52.100965082645416, 51.439732164144516, 54.023658111691475, 46.339338049292564, 50.06256826221943, 46.6178897023201, 52.258079051971436, 47.84017391502857, 52.385429218411446, 51.46831043064594, 51.65594816207886, 49.983665496110916, 47.39820443093777, 41.80013582110405, 39.445470571517944, 37.64506638050079, 39.70976158976555, 40.1319645345211, 39.95791107416153, 39.48451727628708, 46.88716605305672, 52.05994628369808, 51.44596002995968, 49.33624103665352, 53.39577980339527, 53.83535921573639, 54.48621489107609, 52.120043858885765, 52.681820914149284, 49.31721165776253, 53.81808154284954, 51.049310714006424, 54.67182733118534, 52.36999824643135, 54.16559189558029, 52.76923522353172, 54.50230322778225, 55.06467305123806, 52.452830001711845, 53.82718205451965, 55.20376078784466, 53.67532320320606, 50.07323428988457, 48.59689570963383, 45.22625617682934, 46.09641708433628, 52.648489102721214, 50.79489916563034, 53.5934641957283, 53.65368336439133, 58.06061089038849, 52.99240104854107, 56.78493194282055, 58.69850546121597, 59.80784073472023, 57.75418393313885, 61.074099987745285, 51.12535983324051, 33.89078803360462, 4.693996896967292, 10.407462939620018, 13.163683041930199, 7.937067300081253, 5.914368387311697, 0.4893309739418328, 0.5488307343330234, 14.341879170387983, 53.388449996709824, 55.452111661434174, 56.3963457942009, 46.02316081523895, 59.59722563624382, 60.362504571676254, 30.646609514951706, 3.9896571915596724, 0.34316724515520036, 0.08593932056101039, 0.13692937820451334, 0.18786750035360456, 0.17918818717589602, 0.182961770624388, 0.16507290943991393, 0.06250359569094144, 0.19118531607091427, 0.2000945169129409, 0.398369258036837, 0.1260681211715564, 0.18051912513328716, 0.18725221540080383, 0.08072976299445145], [0.043565066807786934, 0.036892320567858405, 0.03933390849852003, 0.04330863623181358, 0.05051316838944331, 0.041358635789947584, 0.05180260544875637, 0.035668533892021514, 0.055731141910655424, 0.047258194026653655, 0.05058522350736894, 0.03649290039902553, 0.012755731841025408, 0.04925727640511468, 0.0658049134653993, 0.011684995497489581, 0.038483388707390986, 0.030226505987229757, 0.02833479938999517, 6.698560332879424, 33.27762633562088, 47.75832250714302, 37.392091155052185, 19.52820472419262, 32.52459794282913, 41.517647579312325, 45.59392064809799, 31.305583454668522, 2.526108962483704, 0.04357069970865268, 0.44916353712324053, 1.9190683797933161, 5.542236305773258, 12.015425506979227, 3.588421046733856, 7.344416426494718, 23.049190789461136, 41.719207763671875, 54.04161974787712, 46.436118856072426, 46.29791647195816, 44.99296389520168, 41.642030104994774, 38.63194182515144, 39.72642369568348, 41.30979873239994, 41.9606202095747, 43.286350071430206, 45.09903520345688, 45.452781021595, 48.23904991149902, 49.0295784920454, 48.07946227490902, 44.90087203681469, 44.060824513435364, 43.78466673195362, 38.82566303014755, 37.4237434566021, 36.108326241374016, 38.479896783828735, 39.738803431391716, 40.25884352624416, 39.759880900382996, 39.47618052363396, 40.9144451469183, 44.10090856254101, 47.817838713526726, 47.47882090508938, 48.22578862309456, 47.77338109910488, 44.90520380437374, 37.95471556484699, 36.7479345202446, 35.01533389091492, 34.926502257585526, 37.7756729722023, 37.45654709637165, 35.158202424645424, 34.75074268877506, 35.128978192806244, 36.361122876405716, 34.75512385368347, 35.71384660899639, 37.55139000713825, 40.02925604581833, 41.97646535933018, 44.88779313862324, 48.58843356370926, 51.50444269180298, 41.998861357569695, 45.43089419603348, 42.31889918446541, 46.156241074204445, 46.372293680906296, 49.785414934158325, 48.72674614191055, 48.100843727588654, 45.487598553299904, 41.79883249104023, 37.258566319942474, 33.858968541026115, 33.680879697203636, 36.614451482892036, 34.854222536087036, 35.303586423397064, 35.36567509174347, 42.910687029361725, 49.80397313833237, 51.177861616015434, 48.403824269771576, 48.075290098786354, 46.746942177414894, 46.43122471868992, 48.56477603316307, 46.473223865032196, 44.79584947228432, 46.26603238284588, 47.75824271142483, 46.83480106294155, 47.55676992237568, 46.08670100569725, 47.25392237305641, 48.39336343109608, 51.43878981471062, 49.575126618146896, 51.5423608571291, 51.84422425925732, 49.72886636853218, 49.834971874952316, 45.74221909046173, 44.77834761142731, 47.030197978019714, 47.43706114590168, 49.035069197416306, 49.49025057256222, 50.07033124566078, 52.37011983990669, 53.016408160328865, 53.56374979019165, 52.958955243229866, 57.4596693366766, 56.74825631082058, 57.24491626024246, 40.46353094279766, 15.912561938166618, 2.205423745326698, 2.0366384647786617, 1.5947035350836813, 3.619149522855878, 1.3476380612701178, 0.17499858542578295, 0.28471403173170984, 13.206270206719637, 41.80301606655121, 43.12363140285015, 32.87714682519436, 34.11687210202217, 45.36509692668915, 45.77042877674103, 13.382501900196075, 0.9646658739075065, 0.0765718064212706, 0.039354306427412666, 0.0439586462744046, 0.0021740808006143197, 0.01072184088116046, 0.025468302228546236, 0.09933186520356685, 0.033959323263843544, 0.04420059754920658, 0.029721838145633228, 0.011300640926492633, 0.07069457569741644, 0.08975143631687388, 0.04464191566512454, 0.032111316177179106, 0.02353515781578608, 0.024221223247877788, 0.033393365156371146, 0.019627766996563878, 0.0689914877875708, 0.029726025713898707, 0.0359993425081484, 0.06612981829675846, 0.010521880321903154, 0.026127052915398963, 0.042409368470543995, 0.12788197462214157, 0.0076666712266160175, 0.042789077197085135, 0.039610892854398116, 0.029989888898853678, 0.08361455038539134, 0.040725242433836684, 0.016911089041968808, 8.353944830596447, 42.346174120903015, 52.30004400014877, 40.543258264660835, 22.709215432405472, 34.24914300441742, 47.3293749243021, 49.91963513195515, 33.551606833934784, 2.7349616680294275, 0.041503655156702735, 0.2494315296644345, 4.343389710411429, 3.8485626876354218, 5.569644710049033, 7.56057352758944, 4.689618581905961, 22.434666864573956, 43.21169927716255, 55.33024460077286, 48.69933821260929, 48.669053837656975, 46.17720074951649, 43.4220901876688, 40.627131164073944, 40.507749170064926, 41.87909938395023, 43.547969833016396, 44.569317027926445, 46.872818022966385, 47.71836765110493, 49.785859510302544, 52.42463171482086, 50.81837050616741, 46.71430192887783, 46.31015561521053, 45.70825271308422, 40.57336784899235, 39.33264322578907, 37.78000853955746, 40.03581449389458, 41.268016174435616, 41.846196949481964, 41.3358349353075, 40.26421643793583, 42.74177849292755, 46.76105082035065, 50.01771166920662, 50.01000188291073, 51.41136668622494, 49.63355228304863, 45.91469943523407, 38.529237136244774, 37.5481715798378, 35.75868420302868, 37.366503328084946, 39.06014084815979, 39.07853566110134, 36.00234612822533, 36.03382743895054, 37.75480829179287, 38.07223565876484, 37.66339659690857, 37.990433648228645, 38.79845269024372, 41.478372886776924, 43.96958380937576, 45.72223976254463, 50.26468701660633, 52.982639372348785, 44.35985706746578, 47.41159111261368, 46.50198072195053, 47.335184812545776, 48.7639195472002, 51.53163783252239, 49.86161604523659, 50.36025948822498, 46.47511996328831, 44.63346138596535, 38.5315778106451, 37.035886868834496, 34.5155581086874, 37.02127665281296, 37.11893901228905, 38.186092749238014, 38.0294119566679, 43.19436840713024, 50.651586055755615, 52.088984325528145, 50.04926137626171, 51.7408812046051, 49.83050711452961, 48.5774065554142, 51.22293099761009, 47.80199356377125, 47.58176878094673, 49.349665716290474, 49.390802308917046, 50.3184275329113, 49.04633179306984, 49.201925843954086, 48.632978573441505, 50.04113741219044, 52.32440449297428, 51.13729499280453, 52.81155355274677, 54.516518265008926, 52.50915437936783, 51.97567820549011, 49.070441499352455, 47.39218935370445, 49.4132325053215, 49.25023265182972, 49.927204325795174, 51.22656360268593, 51.58311367034912, 54.03456352651119, 53.7966924905777, 57.23540537059307, 55.44117584824562, 57.60963588953018, 58.80479335784912, 60.17357110977173, 44.76723700761795, 20.649477057158947, 2.73109870031476, 6.109326425939798, 5.543891591951251, 3.8134699082002044, 1.4937386778183281, 0.17106965562561527, 0.1707710005575791, 12.573755197227001, 46.98078542947769, 46.84818014502525, 40.88848493993282, 40.10596252977848, 51.111729964613914, 54.46825325489044, 17.576207667589188, 1.2323024938814342, 0.12284866228583269, 0.033396048020222224, 0.023190216852526646, 0.03704399699927308, 0.024646536949148867, 0.06973856332479045, 0.06470692824223079, 0.0465128699579509, 0.03847095402306877, 0.046188826017896645, 0.028980441893509123, 0.05568976717768237, 0.08112235169392079, 0.0719715520972386, 0.03883783472701907, 0.10322635935153812, 0.11988109574303962, 0.11517183476826176, 0.1422904006903991, 0.14273871725890785, 0.17467563244281337, 0.15982176933903247, 0.09032895337441005, 0.1033547954284586, 0.15304011292755604, 0.24568675638874993, 0.18587006925372407, 0.07946687255753204, 0.17234613478649408, 0.12848519225372002, 0.16713342309230939, 0.17088870517909527, 0.23328141658566892, 0.16668636817485094, 9.869403261691332, 46.62256345152855, 62.86856509745121, 48.89901749789715, 31.234607063233852, 43.487427681684494, 51.88667178153992, 55.79478107392788, 38.69695633649826, 3.9323778776451945, 0.12710594048257917, 1.6624037898145616, 7.79558664187789, 12.826967909932137, 21.83380700647831, 6.534708850085735, 10.986937545239925, 26.489205099642277, 46.231712624430656, 58.56714650988579, 49.551081508398056, 51.897182017564774, 48.65597873926163, 46.03634990751743, 42.86885887384415, 43.010674864053726, 46.08638182282448, 46.43473573029041, 47.8071840852499, 49.7821357101202, 50.47996066510677, 51.592711955308914, 54.436399564146996, 52.267673537135124, 49.349160343408585, 49.102796763181686, 48.2030126452446, 41.746022924780846, 41.00085251033306, 39.25556056201458, 41.852139830589294, 43.05351756513119, 43.75933349132538, 43.84761415421963, 43.85274387896061, 44.53241340816021, 49.70114305615425, 51.95262484252453, 51.6141352057457, 54.32426378130913, 51.655552983284, 47.325974106788635, 41.44495747983456, 40.17436645925045, 37.47458092868328, 38.40432643890381, 41.40704691410065, 41.29020318388939, 38.28094705939293, 38.04196648299694, 39.31330606341362, 41.22385874390602, 38.42898711562157, 39.403547421097755, 40.32042682170868, 44.43687133491039, 46.28836378455162, 49.31294068694115, 54.00953806936741, 55.34283712506294, 46.293117329478264, 48.581346943974495, 46.45677074790001, 48.87137398123741, 52.038758620619774, 54.55451622605324, 52.08368360996246, 52.178287133574486, 48.69479365646839, 45.15812203288078, 40.90265437960625, 37.3603780567646, 36.234304681420326, 38.60054790973663, 38.66485945880413, 39.93112251162529, 38.6193834990263, 45.572349205613136, 54.544241577386856, 54.934575632214546, 51.321573704481125, 53.44800040125847, 51.86481535434723, 49.45758372545242, 52.95886404812336, 50.48995032906532, 49.59509454667568, 51.72123245894909, 51.67401239275932, 51.15667015314102, 51.99154235422611, 51.15528702735901, 51.79242543876171, 53.99773970246315, 56.01574681699276, 54.18039210140705, 54.19952027499676, 54.089060202240944, 53.80498364567757, 55.86754336953163, 51.07491374015808, 48.20759899914265, 52.39018276333809, 51.71634592115879, 52.22358450293541, 54.64870557188988, 53.10688890516758, 55.13015113770962, 56.4529437571764, 56.953927874565125, 55.8381025493145, 59.37796600162983, 61.119256764650345, 62.02649988234043, 45.352094024419785, 20.6034729257226, 4.1460738983005285, 6.943143708631396, 11.566965971142054, 10.51305452361703, 3.4097434720024467, 0.5393464432563633, 0.38871160126291215, 17.241593822836876, 54.698680490255356, 57.433393746614456, 44.99839760363102, 48.835344314575195, 57.0479766279459, 62.26890407502651, 21.717590242624283, 1.249355860054493, 0.21570465818513185, 0.1290946884546429, 0.17649634333793074, 0.08612459030700848, 0.06758134783012792, 0.10789535139338113, 0.15644991042790934, 0.09721206137328409, 0.1547554536955431, 0.13513079815311357, 0.12090704069123603, 0.1535650042933412, 0.16495435877004638, 0.14789147826377302, 0.10870216981857084], [0.05186002170376014, 0.030369137493835296, 0.039330583676928654, 0.017900948914757464, 0.04521903938439209, 0.037313778811949305, 0.04433485577465035, 0.011973156597377965, 0.033885375669342466, 0.06874057507957332, 0.06406683329259977, 0.05013630950998049, 0.10853788058739156, 0.026461160377948545, 0.05104051626403816, 0.0972028290561866, 0.0896974747593049, 0.04750653890368994, 0.040180431824410334, 2.303474871441722, 23.585199527442455, 46.54963776469231, 42.715841084718704, 31.455777995288372, 32.97991991043091, 35.50412066280842, 43.510462045669556, 40.884103775024414, 7.960785152390599, 0.03831607893516775, 0.4207781102741137, 4.336669771000743, 5.423520701006055, 5.394495008513331, 7.1526815649122, 3.445113399066031, 16.682052947580814, 44.73369620740414, 53.50061997771263, 48.18614915013313, 47.689056023955345, 44.99998591840267, 42.46995247900486, 41.17468178272247, 44.92455996572971, 46.01047709584236, 46.488324254751205, 48.79694737493992, 47.49900162220001, 48.445971608161926, 47.662028074264526, 45.86692839860916, 43.74049790203571, 41.40626035630703, 38.02812002599239, 35.82809887826443, 35.89336037635803, 34.99358005821705, 35.93861974775791, 36.14299938082695, 36.8667009472847, 36.93995341658592, 36.70022428035736, 37.81462088227272, 35.677387565374374, 39.487576112151146, 45.06511062383652, 48.308981359004974, 48.613272830843925, 48.82226921617985, 43.49602282047272, 38.41595761477947, 36.220146641135216, 35.79585760831833, 34.812151193618774, 36.10134981572628, 35.16979180276394, 36.091124564409256, 35.3735064715147, 36.893075332045555, 36.51465363800526, 36.45062707364559, 34.79989305138588, 36.906974986195564, 37.02439248561859, 40.11373691260815, 45.08067838847637, 47.20421724021435, 50.31771317124367, 39.03557896614075, 44.20300528407097, 44.12741594016552, 46.83190941810608, 47.11839124560356, 46.65893130004406, 49.82068844139576, 46.72355443239212, 46.22126318514347, 41.8591770529747, 39.16229836642742, 36.11655279994011, 35.143941789865494, 35.48902027308941, 34.85548406839371, 35.82171522080898, 37.06827253103256, 43.51086102426052, 48.300819396972656, 49.88944575190544, 51.06410712003708, 47.83696308732033, 47.97136567533016, 41.77086599171162, 38.516504019498825, 38.32666240632534, 41.62534140050411, 42.24785819649696, 42.55542129278183, 44.45486716926098, 42.92932502925396, 42.52473033964634, 43.40460732579231, 45.70513308048248, 46.888948157429695, 49.286159723997116, 47.88516350090504, 52.08090975880623, 52.62882895767689, 52.122574523091316, 48.23799356818199, 47.94694058597088, 49.718021750450134, 47.66841173171997, 51.00407414138317, 53.119986802339554, 54.87147621810436, 54.32618647813797, 51.15597479045391, 54.26950491964817, 56.52646981179714, 56.49419814348221, 52.72096261382103, 52.624839171767235, 29.42028421908617, 9.383383691310883, 0.49199519504327327, 1.8079470237717032, 2.529605249874294, 3.3975352020934224, 1.1801790283061564, 0.22058891016058624, 0.539835310773924, 19.492834322154522, 44.400112107396126, 41.86679184436798, 28.580219596624374, 40.66146992146969, 46.41961254179478, 41.87111221253872, 12.838312201201916, 0.26078342052642256, 0.046210333457565866, 0.021693410744774155, 0.007434091885443195, 0.09468020230997354, 0.023696513708273415, 0.028392059793986846, 0.05158485560968984, 0.021183327080507297, 0.04122667451156303, 0.015397453807963757, 0.07057002105284482, 0.03550099034328014, 0.04626151938282419, 0.020055616987519898, 0.05653217529470567, 0.062119348731357604, 0.029496546230802778, 0.019302585715195164, 0.029900499066570774, 0.04046086345624644, 0.03219000980607234, 0.04258019973349292, 0.05220099032158032, 0.007688166142543196, 0.02801873353746487, 0.07228145070257597, 0.06084347071009688, 0.048766097097541206, 0.07701287962845527, 0.01893262509838678, 0.015773610430187546, 0.09032260059029795, 0.03985983144957572, 0.02927793364506215, 3.9998800680041313, 28.675670474767685, 53.425547406077385, 47.21916563808918, 33.46568964421749, 36.45906642079353, 43.01486223936081, 51.217162907123566, 44.41108591854572, 7.184934234246612, 0.07042634868412279, 0.060847849381389096, 4.229554468765855, 9.273963812738657, 8.622021395713091, 8.87378353625536, 3.56641405262053, 18.388740867376328, 45.334557965397835, 55.9661290794611, 50.15677660703659, 49.73230138421059, 46.918875351548195, 43.89744088053703, 43.00640009343624, 45.68118676543236, 46.18106134235859, 49.79890041053295, 49.77703258395195, 50.93610338866711, 49.08290483057499, 51.079025119543076, 47.536896988749504, 46.6463615745306, 44.004743322730064, 41.45422138273716, 38.64525631070137, 36.80039830505848, 37.11921639740467, 37.17407405376434, 38.22504445910454, 39.094540402293205, 39.27814655005932, 39.17465150356293, 39.773453772068024, 38.08543615043163, 40.6502453237772, 47.52441085875034, 50.67222274839878, 50.64872860908508, 51.277385875582695, 45.85822306573391, 40.60624748468399, 37.458564788103104, 36.76570236682892, 38.17731522023678, 38.54971803724766, 37.19822935760021, 37.53074951469898, 36.81086294353008, 37.18592941761017, 37.98132933676243, 37.092739418148994, 37.15364255011082, 38.800086602568626, 39.46268744766712, 42.216688469052315, 48.129862770438194, 50.88259465992451, 51.29763498902321, 43.18891949951649, 46.14060491323471, 45.72317831218243, 47.810223922133446, 48.91430787742138, 48.86646464467049, 51.23996168375015, 46.97657145559788, 48.67003418505192, 45.15260472893715, 41.141479164361954, 37.624984458088875, 36.57392665743828, 37.105457335710526, 36.872229650616646, 37.46655195951462, 38.176711052656174, 44.49918419122696, 50.43532446026802, 53.09808857738972, 52.90580749511719, 50.37678860127926, 49.551157504320145, 44.23854857683182, 43.015998378396034, 41.17284648120403, 44.31371234357357, 45.54335296154022, 45.51856689155102, 46.58694036304951, 46.11710697412491, 44.76795896887779, 45.905150547623634, 47.552358359098434, 49.08803455531597, 51.458510756492615, 50.07400944828987, 52.45188005268574, 53.65685999393463, 53.65454591810703, 49.70811948180199, 49.986443147063255, 51.75273656845093, 50.24557024240494, 55.69630175828934, 53.58757831156254, 55.93598909676075, 56.048516258597374, 53.949740678071976, 54.27827104926109, 56.94011561572552, 57.16344863176346, 56.59206189215183, 53.48123721778393, 33.61525721848011, 11.224183514714241, 1.9849848677404225, 6.5357680432498455, 5.770265869796276, 3.557517542503774, 1.0054307989776134, 0.24888894549803808, 0.3432871465338394, 19.654069170355797, 49.061025604605675, 50.148154869675636, 33.69970768690109, 45.510537922382355, 53.665352538228035, 47.62239620089531, 15.902504827827215, 0.3481196262873709, 0.026636175498424564, 0.01653000548685668, 0.034528684118413366, 0.014057912503631087, 0.01607837522897171, 0.03683694521896541, 0.012165473963250406, 0.04202266500215046, 0.00869778152264189, 0.04686159772973042, 0.028848699548689183, 0.021580281463684514, 0.028917376039316878, 0.03135838509479072, 0.06425252606277354, 0.21327960159396753, 0.15808584139449522, 0.12190030145575292, 0.23714226175798103, 0.15739410038804635, 0.0944968473049812, 0.10701062972657382, 0.10719719823100604, 0.10644975904142484, 0.13825872796587646, 0.20098086388316005, 0.2781684079673141, 0.16399811633164063, 0.19541714602382854, 0.1331618061522022, 0.14134230703348294, 0.1736877002986148, 0.1297876168973744, 0.15815998194739223, 3.974894746206701, 33.69222968816757, 60.46738274395466, 54.39383044838905, 42.888735607266426, 43.76018464565277, 49.408372566103935, 55.4313799738884, 51.547726169228554, 9.715516269207, 0.19918433215934783, 1.4289191435091197, 9.225781448185444, 18.372848220169544, 13.436471354216337, 14.936173930764198, 5.618379944935441, 18.303158059716225, 48.512015864253044, 57.97861509025097, 52.410941049456596, 52.54666976630688, 50.1579849421978, 45.24446099996567, 44.516621455550194, 49.25679869949818, 48.29301081597805, 52.18562833964825, 52.89788492023945, 53.10196436941624, 52.705402448773384, 53.65801513195038, 49.62574750185013, 48.93766142427921, 45.51857449114323, 41.26278005540371, 40.79382061958313, 38.31736050546169, 40.21436311304569, 39.255324974656105, 39.03885819017887, 40.85215888917446, 40.64696229994297, 40.40794372558594, 41.473098769783974, 39.259371757507324, 43.02223764359951, 49.9363998323679, 53.220043033361435, 53.01347091794014, 54.05676193535328, 46.49952605366707, 41.80332005023956, 38.365940898656845, 38.33924353122711, 38.947252705693245, 40.50389997661114, 38.27601112425327, 39.34257969260216, 39.283519461750984, 39.56491716206074, 42.582833021879196, 40.25033578276634, 38.800572976469994, 40.94135910272598, 42.52507232129574, 44.41022336483002, 51.07057437300682, 52.6159780472517, 55.555108934640884, 45.39612226188183, 47.433952912688255, 45.07326498627663, 50.30596800148487, 51.06087349355221, 51.36081799864769, 52.55061775445938, 50.43214403092861, 49.85438883304596, 47.70810440182686, 43.24473090469837, 38.94845724105835, 37.75461830198765, 40.703811049461365, 37.857406586408615, 39.973007664084435, 40.37447892129421, 46.89324572682381, 52.679335847496986, 54.1397000849247, 54.45169374346733, 53.12252126634121, 52.62688726186752, 45.71836017072201, 44.06124249100685, 42.59066440165043, 45.089805498719215, 47.94771954417229, 47.31270521879196, 49.74806293845177, 48.028829991817474, 46.277313977479935, 47.766807451844215, 49.9186547845602, 50.98133236169815, 53.133373484015465, 51.48492693901062, 56.32638394832611, 55.53808964788914, 56.37915551662445, 52.59242691099644, 53.97317782044411, 55.323374569416046, 50.96038028597832, 57.3099459707737, 57.007163017988205, 58.840762227773666, 58.60602602362633, 55.78941576182842, 58.57913486659527, 58.91974858939648, 57.496892139315605, 54.47051413357258, 54.739060923457146, 34.05934698879719, 12.591619938611984, 3.1046604551374912, 8.40095305815339, 10.81477353349328, 10.468189381062984, 4.762350479140878, 0.32505064853467047, 0.6399961549323052, 23.574751988053322, 56.59017339348793, 55.343790873885155, 40.37848010659218, 52.97217093408108, 59.78978790342808, 55.663912296295166, 20.501602292060852, 0.4909574647899717, 0.11850677925394848, 0.1323431430500932, 0.07447983312886208, 0.24455247272271663, 0.1617907316540368, 0.14180715865222737, 0.09054361958988011, 0.16446120163891464, 0.10759048454929143, 0.10436188982566819, 0.14612271770602092, 0.14208534528734162, 0.20101213798625395, 0.12284187163459137, 0.2883951138937846], [0.0287330339779146, 0.08392749921767972, 0.036716902832267806, 0.018373593084106687, 0.011331198857078562, 0.047742860988364555, 0.10822702461155131, 0.03577274997951463, 0.03368674726516474, 0.034112606444978155, 0.017028554320859257, 0.07280491714482196, 0.04194174864096567, 0.08151842848747037, 0.02314309233042877, 0.040458147195749916, 0.03365542121173348, 0.02922193303675158, 0.008050753986026393, 0.5896775925066322, 18.867931254208088, 45.38096867501736, 44.8662368953228, 32.73702934384346, 25.38065068423748, 37.77643673121929, 44.98086154460907, 48.17887254059315, 11.287272479385138, 0.12865610886365175, 0.09212452030624263, 1.6809602128341794, 1.7937440983951092, 1.199957204516977, 8.76636615023017, 1.4709958294406533, 16.099101528525352, 42.25919298827648, 56.15300305187702, 47.42197975516319, 47.95840077102184, 43.55582021176815, 44.38811615109444, 43.782561644911766, 45.62589593231678, 47.64804482460022, 49.65868793427944, 48.098187670111656, 48.39266046881676, 46.32390707731247, 45.18828101456165, 42.73474507033825, 40.510956197977066, 35.50904139876366, 35.29568284749985, 33.73506098985672, 34.97959680855274, 35.867867544293404, 38.78301411867142, 37.39856220781803, 36.91634528338909, 36.354184448719025, 37.54755601286888, 35.40259391069412, 37.50666260719299, 37.840771079063416, 40.30556961894035, 42.62969210743904, 45.383522137999535, 45.9331626445055, 42.95278497040272, 37.91881509125233, 36.05700619518757, 35.57824328541756, 35.2975295484066, 34.93734687566757, 36.656218841671944, 37.16997027397156, 42.389035820961, 45.786171332001686, 46.081533282995224, 43.46386894583702, 43.97068575024605, 41.51244565844536, 39.467235803604126, 42.47556857764721, 45.63572980463505, 47.58917458355427, 50.12895829975605, 40.5778706073761, 41.65140800178051, 48.397041633725166, 42.5146608799696, 45.82106865942478, 45.63952960073948, 48.352036848664284, 49.4374980032444, 45.35294517874718, 44.18396830558777, 38.644754737615585, 35.361727103590965, 33.71564403176308, 35.410254299640656, 35.10316237807274, 35.21369844675064, 36.52997061610222, 44.23673987388611, 48.77376861870289, 50.54579973220825, 49.49549809098244, 48.51659081876278, 44.556754902005196, 40.713036954402924, 37.453070282936096, 36.97520412504673, 36.7186076939106, 36.938729882240295, 37.1976175904274, 36.77699536085129, 36.406921818852425, 36.852934285998344, 36.89887002110481, 39.09641370177269, 42.56802901625633, 45.3154905885458, 46.07263036072254, 46.75878994166851, 50.10886877775192, 51.0369423776865, 51.719822734594345, 49.08635884523392, 50.91829374432564, 51.099870800971985, 50.250927954912186, 54.56990920007229, 51.988510116934776, 52.31276951730251, 52.81506076455116, 49.55496110022068, 53.455269411206245, 55.6828086823225, 56.17188423871994, 42.57997937500477, 21.101479902863503, 2.392088253982365, 1.47911207517609, 7.26046278141439, 4.263514671474695, 1.396663268096745, 0.1456464666989632, 0.3073550871340558, 0.3481806308263913, 19.40159171819687, 44.23517055809498, 40.59197165071964, 38.73226784169674, 47.77103282511234, 48.8856840133667, 37.26514756679535, 8.46708470955491, 0.13047247077338398, 0.08021912828553468, 0.04746883409097791, 0.03380692323844414, 0.0637807724706363, 0.08737925774767064, 0.03864977821649518, 0.011353547706676181, 0.016477535646117758, 0.1231173865380697, 0.040199746217695065, 0.036660269543062896, 0.028725324918923434, 0.04640158491383772, 0.02146610389900161, 0.05021305871196091, 0.07955682827741839, 0.12023839532048441, 0.025089986884268, 0.12496730836573988, 0.04182510529062711, 0.01135609327320708, 0.060482345361378975, 0.024467467846989166, 0.07126451542717405, 0.038296801649266854, 0.03198044214514084, 0.04675412361393683, 0.021018724291934632, 0.027135203017678577, 0.03487055073492229, 0.029824182165612, 0.020626810946851037, 0.0649704277748242, 0.03940885799238458, 0.8413529314566404, 23.659394346177578, 51.306644305586815, 50.23919798433781, 37.46792368590832, 31.143943928182125, 38.97111162543297, 50.08425749838352, 50.24053171277046, 13.22057168930769, 0.07248751542647369, 0.1266205165302381, 2.362325401045382, 4.575656997039914, 3.9984883926808834, 9.294106531888247, 4.160263761878014, 15.883133467286825, 45.58056816458702, 56.72030881047249, 51.64623208343983, 49.529084488749504, 46.72426879405975, 45.60008391737938, 45.11273346841335, 47.43631638586521, 50.04157058894634, 50.41187211871147, 51.014675572514534, 51.197369769215584, 47.06726498901844, 47.338228449225426, 46.02846913039684, 42.389788180589676, 38.61608147621155, 37.76867754757404, 35.45622803270817, 35.08548952639103, 37.02775530517101, 40.16262888908386, 37.557291090488434, 39.23298977315426, 39.14625562727451, 39.30182687938213, 38.31218898296356, 38.579299449920654, 38.68591792881489, 42.34606392681599, 44.68098163604736, 45.271070972085, 48.28858405351639, 45.77139772474766, 40.336579754948616, 36.841375306248665, 37.710677459836006, 36.66984111070633, 37.55334310233593, 37.395624965429306, 39.34675186872482, 44.4065223634243, 48.33237670361996, 47.890950590372086, 44.622681364417076, 43.32339808344841, 42.78136096894741, 40.90224400162697, 44.64812859892845, 46.89897581934929, 51.39609530568123, 53.29242914915085, 43.5959080606699, 44.966623708605766, 47.69782975316048, 43.270159140229225, 48.06594260036945, 48.95295940339565, 50.35721965134144, 50.89097321033478, 48.00536245107651, 44.029981568455696, 40.82949310541153, 36.66240870952606, 35.583224818110466, 36.75157092511654, 36.7616555839777, 36.74164965748787, 38.419647216796875, 47.152334824204445, 50.661267936229706, 52.820832654833794, 50.9493912756443, 50.51252871751785, 46.93939045071602, 41.77587032318115, 39.470682218670845, 38.0566792935133, 38.50496403872967, 37.51898534595966, 39.32758189737797, 38.270516619086266, 38.32187846302986, 38.716126307845116, 39.38048645853996, 42.383313328027725, 45.33860854804516, 47.026990950107574, 50.02997741103172, 51.0909678786993, 52.165740206837654, 51.33516177535057, 52.81813099980354, 53.42415668070316, 54.185867607593536, 53.88212330639362, 52.00205259025097, 56.545886769890785, 53.38615871965885, 54.66494970023632, 54.64830659329891, 51.960338428616524, 55.913517102599144, 57.23582334816456, 56.7461284250021, 45.52639067173004, 22.745262198150158, 4.277620939537883, 3.401683629490435, 6.200308743864298, 4.525100234895945, 4.93024636991322, 1.289600688032806, 0.3206334449350834, 0.4995053436141461, 23.454539738595486, 50.40005475282669, 43.97048436105251, 38.95889148116112, 52.3149050027132, 53.716083616018295, 44.36590634286404, 11.156834978610277, 0.019807964163192082, 0.035535600400180556, 0.016449029753857758, 0.05388092322391458, 0.07762208639178425, 0.05636375972244423, 0.028192963836772833, 0.020823903105338104, 0.07726556606939994, 0.012391005220706575, 0.05751990705903154, 0.004593379717334756, 0.04265986928658094, 0.030014901130925864, 0.06274448198382743, 0.033824979691416956, 0.15013513911981136, 0.19811261154245585, 0.2107521879952401, 0.2804629801539704, 0.09361155418446288, 0.1069632510188967, 0.14086829731240869, 0.10467169937328435, 0.18526140425819904, 0.10634412916260771, 0.1233974656497594, 0.16507322114193812, 0.1614456478273496, 0.14648598415078595, 0.18641404865775257, 0.12705523695331067, 0.07348447208642028, 0.09315134841017425, 0.14180150348693132, 1.034362802747637, 27.708483673632145, 58.66149164736271, 57.198836132884026, 44.288857877254486, 35.18544316291809, 47.2931020706892, 55.607675313949585, 58.71807061135769, 15.493731312453747, 0.2550753252580762, 0.189926203165669, 5.192852653563023, 8.376955445855856, 9.161813780665398, 16.78731869906187, 3.7563556479290128, 18.908600471913815, 46.71352297067642, 58.19247901439667, 52.698141038417816, 52.04554885625839, 48.00270639359951, 48.664235696196556, 47.206641510128975, 50.10167196393013, 52.34410643577576, 53.9019962400198, 52.34368085861206, 52.752550318837166, 48.80565270781517, 49.979531317949295, 48.372669741511345, 44.362535923719406, 39.59230989217758, 39.2475201934576, 36.57757066190243, 37.2794272005558, 38.39630126953125, 43.07863801717758, 39.81274366378784, 40.693562999367714, 40.54466038942337, 40.33650755882263, 39.25294250249863, 42.26651519536972, 40.50319701433182, 44.26199331879616, 46.09617009758949, 47.56254181265831, 50.86304470896721, 47.180958688259125, 42.29924663901329, 38.55531133711338, 38.747467026114464, 38.81003446877003, 39.310976788401604, 40.97969524562359, 40.54150655865669, 47.143743485212326, 51.353207007050514, 52.22474344074726, 46.56476475298405, 46.144055128097534, 46.75219349563122, 43.515135794878006, 46.49302080273628, 51.527670845389366, 51.82350017130375, 56.28288388252258, 46.21667303144932, 47.66893610358238, 49.79579217731953, 44.66997742652893, 51.3971022516489, 50.38398541510105, 52.74506472051144, 52.08241447806358, 50.01078464090824, 47.08505563437939, 42.819567918777466, 38.968322575092316, 37.720340341329575, 39.97844137251377, 37.81348094344139, 38.05370785295963, 40.98029941320419, 48.0909338593483, 52.93776378035545, 55.04727378487587, 53.312663063406944, 52.94041223824024, 48.21216255426407, 43.761199191212654, 41.43260434269905, 40.45827202498913, 40.47262005507946, 40.55318333208561, 41.19857870042324, 39.16735589504242, 39.84472654759884, 40.429800152778625, 40.89196555316448, 42.549269422888756, 48.57561305165291, 48.96043360233307, 52.48565264046192, 52.949478551745415, 54.85456332564354, 54.94116447865963, 54.87578518688679, 53.5156025737524, 55.98110407590866, 56.07604578137398, 52.44888201355934, 57.56252221763134, 54.80058342218399, 57.74547480046749, 57.28633403778076, 53.964240700006485, 57.558813616633415, 57.88433834910393, 58.71940813958645, 45.64491771161556, 24.377118833363056, 4.180493401363492, 4.429338723421097, 13.945915717631578, 10.924995169043541, 8.232006523758173, 4.246757095679641, 0.9200164885260165, 0.6005032116081566, 25.593764148652554, 55.4366122931242, 53.5363532602787, 50.293744057416916, 57.37632840871811, 59.84281025826931, 53.44359263777733, 13.213303629308939, 0.18021888186922297, 0.1475490364828147, 0.12925367132993415, 0.1263764686882496, 0.22497574507724494, 0.22015310620190576, 0.14221767021808773, 0.12508703162893653, 0.15877179364906624, 0.22999517183052376, 0.16658004809869453, 0.228044941322878, 0.1683852926362306, 0.1300033592269756, 0.12767332722432911, 0.17035514552844688], [0.029189109700382687, 0.04757983340823557, 0.009034652557602385, 0.0647918002505321, 0.03847093175863847, 0.007773939860271639, 0.03363055926456582, 0.011391881489544176, 0.04149410371610429, 0.03810740185144823, 0.010871584945562063, 0.026088229315064382, 0.006463916552092996, 0.041095485066762194, 0.1053354910982307, 0.020008060164400376, 0.0384090440638829, 0.01885058438347187, 0.03835048861219548, 0.10536857604165561, 9.244938120245934, 44.73209269344807, 44.35307443141937, 33.758399337530136, 26.748497486114502, 39.22886699438095, 42.68236108124256, 50.70102900266647, 17.946131117641926, 0.16311429266352206, 0.5700124602299184, 1.3685966678895056, 11.190505921840668, 20.758257620036602, 5.462795868515968, 3.3910385007038713, 13.080756291747093, 46.98637492954731, 53.15006598830223, 52.43697725236416, 49.39454510807991, 46.32134221494198, 43.655089884996414, 43.15782956779003, 46.20917983353138, 50.59215724468231, 49.1209901869297, 48.49369324743748, 44.10659685730934, 42.49507673084736, 40.75841411948204, 36.643090546131134, 34.038516506552696, 34.97340314090252, 34.460415467619896, 36.020524352788925, 35.85629716515541, 35.67154347896576, 35.561315193772316, 37.03997164964676, 37.096968591213226, 36.00948974490166, 35.0537384301424, 37.555140405893326, 36.77272439002991, 35.004629865288734, 36.3362418115139, 39.62184950709343, 40.95562353730202, 42.3082559555769, 39.911884143948555, 36.503083258867264, 34.34428229928017, 36.1946652084589, 34.37385991215706, 35.42752057313919, 36.75894632935524, 44.12029132246971, 46.205163449048996, 49.64976601302624, 47.776892110705376, 47.791726514697075, 48.18129301071167, 45.970803424715996, 42.27932050824165, 43.17661575973034, 45.464343801140785, 49.101808816194534, 48.47763530910015, 44.09959003329277, 40.5701570212841, 44.54480454325676, 49.40240688621998, 45.71900613605976, 47.448152750730515, 46.65292762219906, 49.32346232235432, 46.74884207546711, 45.685248747467995, 39.36466410756111, 35.96289664506912, 34.973794519901276, 35.275049954652786, 34.00304540991783, 36.23991698026657, 35.54535984992981, 40.983362048864365, 49.639103785157204, 50.77357091009617, 49.42885346710682, 47.646464109420776, 47.53186225891113, 40.095429494977, 37.92185492813587, 36.70859523117542, 35.380600690841675, 35.775418505072594, 36.59005679190159, 34.84126143157482, 34.894842356443405, 33.921038210392, 35.85483804345131, 36.31443478167057, 36.155515909194946, 40.27038350701332, 42.15189054608345, 45.8039315789938, 48.953536972403526, 48.214833810925484, 48.75120162963867, 49.13469225168228, 48.73293600976467, 49.46316562592983, 52.06153839826584, 51.62361189723015, 49.65538591146469, 48.37669752538204, 47.068461924791336, 48.29060174524784, 52.7282240241766, 57.10178554058075, 53.222151920199394, 36.655371487140656, 9.368878919631243, 1.7830967134796083, 2.619696040637791, 4.800422536209226, 2.135447175242007, 2.6164400903508067, 0.4198858409654349, 0.21750671148765832, 0.8816313045099378, 20.722486339509487, 46.34194850921631, 36.04001730680466, 32.885255590081215, 46.74919545650482, 50.17701052129269, 33.50064776837826, 3.417703094892204, 0.08000020214240067, 0.0568450684659183, 0.034216759449918754, 0.05644883211061824, 0.05512766452739015, 0.013408714185061399, 0.05491569230798632, 0.036583186374627985, 0.019513990191626363, 0.007456853554685949, 0.060443523616413586, 0.04870338932960294, 0.03126887095277198, 0.010641682438290445, 0.04926717665512115, 0.009013300041260663, 0.01279149222682463, 0.05241127415501978, 0.029207034422142897, 0.050073872625944205, 0.04687079293944407, 0.06120654790720437, 0.05877981035155244, 0.037435661724884994, 0.028053247115167323, 0.022069341939641163, 0.03201014289516024, 0.08887332718586549, 0.04934244527248666, 0.10207329934928566, 0.06314306723652408, 0.04956000957463402, 0.03349588543642312, 0.06039738800609484, 0.017940872749022674, 0.17279143823543563, 14.317030403763056, 50.84137447178364, 48.89637663960457, 39.48165223002434, 29.959967359900475, 45.58953948318958, 50.51491878926754, 55.7821923494339, 18.17317083477974, 0.040220815790235065, 0.6912235810887069, 1.3728587329387665, 11.270098350942135, 9.307470414787531, 3.9335933374240994, 5.238694343715906, 13.57878701761365, 49.18005421757698, 55.649951845407486, 53.28357942402363, 51.47510066628456, 47.56316497921944, 44.57958787679672, 46.592932641506195, 48.50424148142338, 51.544477343559265, 51.84234336018562, 50.308073088526726, 47.8668674826622, 45.47642335295677, 43.86567458510399, 39.90023776888847, 36.29826284945011, 36.678310856223106, 35.18215253949165, 37.23871238529682, 37.96275973320007, 37.03053295612335, 38.86696681380272, 37.2392101585865, 38.05888697504997, 37.195497304201126, 37.08043947815895, 37.921839728951454, 38.09141702950001, 37.83845320343971, 37.180343717336655, 40.12846112251282, 43.47638167440891, 44.54258546233177, 42.9618588835001, 38.114781975746155, 37.213504537940025, 38.045203909277916, 36.446736082434654, 36.98541417717934, 37.371921837329865, 46.196477115154266, 46.33515067398548, 52.46152773499489, 50.93639977276325, 50.39756588637829, 48.86908270418644, 47.22413197159767, 44.77324068546295, 44.59675155580044, 47.415542900562286, 49.336469024419785, 52.27089576423168, 44.74734127521515, 41.29744179546833, 46.96779012680054, 49.21023979783058, 46.27709738910198, 49.0493868291378, 47.88104832172394, 51.15402549505234, 49.09009404480457, 46.10367089509964, 40.65960802137852, 37.28146389126778, 36.297210305929184, 37.906165570020676, 36.093096658587456, 36.703374311327934, 37.27995537221432, 42.52115473151207, 50.59519708156586, 52.50745587050915, 51.50001972913742, 50.76940633356571, 49.27372299134731, 42.992185056209564, 39.833224564790726, 39.49553668498993, 37.132477685809135, 37.95464716851711, 39.12031441926956, 36.080903112888336, 37.74929478764534, 35.68549633026123, 38.33088777959347, 38.04657183587551, 38.88788849115372, 42.76398450136185, 45.52591569721699, 48.36020641028881, 50.334458872675896, 51.582380309700966, 51.053137108683586, 51.664539501070976, 49.810558184981346, 51.73163630068302, 53.61952319741249, 53.93674157559872, 52.85486362874508, 51.44934944808483, 49.33824732899666, 51.05999194085598, 53.9607372879982, 59.14592765271664, 54.642238318920135, 38.29304181039333, 12.647875919938087, 3.5903482558205724, 5.471999924629927, 9.062457662075758, 5.598697951063514, 4.718396812677383, 1.2131466530263424, 0.222772145352792, 1.0007413756102324, 22.517614513635635, 51.168833300471306, 44.007684364914894, 40.08021131157875, 51.28211662173271, 58.45037877559662, 40.35700365900993, 4.873936241492629, 0.11449935249402188, 0.040036366117419675, 0.02116561387083493, 0.010499914606043603, 0.036610545648727566, 0.04174761023023166, 0.08562607486965135, 0.047777645449968986, 0.08190311331418343, 0.021391302834672388, 0.04220344104396645, 0.01029109187584254, 0.012045154198858654, 0.02749963092355756, 0.1109695051854942, 0.04486475663725287, 0.13111288484651595, 0.1509413935127668, 0.06115266056440305, 0.21463022130774334, 0.12970725714694709, 0.2211060980334878, 0.20149788848357275, 0.1031947587034665, 0.2388479546061717, 0.17550866352394223, 0.05489510513143614, 0.1463740534381941, 0.10573632505838759, 0.21798722242238, 0.1614918836276047, 0.1500789140118286, 0.17980497126700357, 0.18586696707643569, 0.20368406258057803, 0.30375679896678776, 16.665185652673244, 57.36675292253494, 57.8758230060339, 44.950124993920326, 35.724147856235504, 50.19395001232624, 53.28141734004021, 61.00851930677891, 22.32675265520811, 0.5065011838451028, 1.2901314720511436, 3.4011910809203982, 20.141472816467285, 31.42372291535139, 12.461314480751753, 5.997103247791529, 14.471815098077059, 50.44288605451584, 57.707172855734825, 54.74461242556572, 54.82679061591625, 49.8335013538599, 47.258007153868675, 46.660006642341614, 51.84173159301281, 53.636994659900665, 53.03441159427166, 51.76563687622547, 50.40205344557762, 48.160819709300995, 45.20211607217789, 40.608318373560905, 39.53525975346565, 38.30667927861214, 37.08608977496624, 40.1200407743454, 39.97547373175621, 39.49195347726345, 40.5969113856554, 39.60668072104454, 40.782626420259476, 37.76411399245262, 39.99954544007778, 40.562895610928535, 39.60844002664089, 39.91433881223202, 39.415045604109764, 42.899025455117226, 45.55887892842293, 46.81976906955242, 43.66126835346222, 40.1147248595953, 38.39132733643055, 39.07429128885269, 36.96221262216568, 39.31456759572029, 39.4669546186924, 48.46762664616108, 47.324138805270195, 54.90815944969654, 53.112869784235954, 52.68638826906681, 52.91558817028999, 50.80970697104931, 47.06729158759117, 47.97836109995842, 51.326023265719414, 52.9364338517189, 54.354050382971764, 48.84019285440445, 41.90331168472767, 50.329845920205116, 48.442764580249786, 47.680464684963226, 50.90339474380016, 50.96670314669609, 55.358617678284645, 52.20810033380985, 50.53235225379467, 43.11349354684353, 40.319959446787834, 38.444361090660095, 38.42532031238079, 37.35029719769955, 39.40630227327347, 39.16000708937645, 43.89128141105175, 53.07261474430561, 55.066785737872124, 53.037622421979904, 53.1598124653101, 50.84655739367008, 44.135969281196594, 41.3009338080883, 40.13493597507477, 38.74709464609623, 39.71602365374565, 41.66229821741581, 38.79394993185997, 39.323367923498154, 37.55277693271637, 40.67644491791725, 39.04827028512955, 39.866085201501846, 44.143644869327545, 47.59231701493263, 51.154082491993904, 52.93729640543461, 53.21606084704399, 54.15183663368225, 53.32305930554867, 51.479725018143654, 53.12802717089653, 53.747675120830536, 56.48757129907608, 55.52491195499897, 52.623459845781326, 50.969552993774414, 52.170653343200684, 58.596822917461395, 60.39539560675621, 55.24173215031624, 39.41246174275875, 12.952553071081638, 3.3944668667390943, 7.016176739707589, 11.779328025877476, 10.451776161789894, 8.687108103185892, 1.8880777177400887, 0.5062815675046295, 1.2461135652847588, 26.867619194090366, 58.83091315627098, 49.353773295879364, 47.46116705238819, 58.336840867996216, 64.90598917007446, 47.1280275285244, 6.154562048614025, 0.22195982019184157, 0.2170797242433764, 0.1707404834451154, 0.17918851372087374, 0.23509791208198294, 0.17354738985886797, 0.1725774770602584, 0.13891478651203215, 0.2346902058343403, 0.13993564032716677, 0.1440154784359038, 0.09626309940358624, 0.11095017965999432, 0.15792964899446815, 0.17893680691486225, 0.10069445575936697], [0.10189148058998398, 0.003913819209628855, 0.1126405323157087, 0.029284457123139873, 0.03187509057170246, 0.009967025671357987, 0.056455092126270756, 0.026611897992552258, 0.0038493857164212386, 0.04301361768739298, 0.026564647305349354, 0.07265096603077836, 0.021515167281904723, 0.03631884821515996, 0.07977915345691144, 0.07511589821660891, 0.021344846245483495, 0.05255425632640254, 0.032663058445905335, 0.07490426738513634, 3.5417293896898627, 38.736971989274025, 51.479485630989075, 40.05932383239269, 31.52765493839979, 33.271911442279816, 37.619307562708855, 46.8212965875864, 27.248586751520634, 1.3621716876514256, 0.3668411623220891, 0.2865816018311307, 21.57978303730488, 35.455042496323586, 7.489305501803756, 3.957503791898489, 12.32181066647172, 38.71284708380699, 52.292577400803566, 50.666249468922615, 47.84496545791626, 48.25131185352802, 43.95344987511635, 45.63283056020737, 46.133130714297295, 48.41877266764641, 44.98578988015652, 44.601250514388084, 38.96389961242676, 36.33369214832783, 35.004234686493874, 34.49391447007656, 36.02365158498287, 35.32112628221512, 35.4036046564579, 37.90735110640526, 37.17072643339634, 35.820841267704964, 38.260200172662735, 36.39134645462036, 36.13134540617466, 35.5852273106575, 35.87962031364441, 36.343225836753845, 37.982450276613235, 40.46404391527176, 41.33209593594074, 37.90344871580601, 41.03568144142628, 42.007247507572174, 40.557545498013496, 37.231298983097076, 33.68145726621151, 35.32074250280857, 37.44705520570278, 35.46485736966133, 41.54505170881748, 48.397288620471954, 52.24429339170456, 46.44755244255066, 47.782105430960655, 49.99350316822529, 48.31233657896519, 48.380979895591736, 45.161082074046135, 45.25201879441738, 45.561227202415466, 48.6446363478899, 46.43734239041805, 37.9711838811636, 48.271644562482834, 40.78138008713722, 41.387622356414795, 42.76391230523586, 47.0704036206007, 47.79839135706425, 50.96511863172054, 47.243343740701675, 44.601809084415436, 39.3979237228632, 36.64600118994713, 33.95380765199661, 33.809977769851685, 35.29452010989189, 34.44843091070652, 36.94342643022537, 43.495772033929825, 49.101508632302284, 49.46904011070728, 50.97193166613579, 50.23137800395489, 47.812925577163696, 40.25994926691055, 35.16288757324219, 36.2618950009346, 36.44523896276951, 35.6140411645174, 36.11792452633381, 36.830811873078346, 34.83360484242439, 34.75965701043606, 35.303415432572365, 37.96914719045162, 36.24882370233536, 35.17858073115349, 36.24674141407013, 39.58670139312744, 42.40783341228962, 45.62693327665329, 49.10983398556709, 47.28116691112518, 49.209848418831825, 50.448954328894615, 50.29254712164402, 49.26765851676464, 45.05440279841423, 40.90757891535759, 43.35795722901821, 49.905184507369995, 50.362334176898, 57.85149671137333, 50.878775864839554, 28.906920365989208, 5.99265368655324, 2.4509527953341603, 4.422390796244144, 7.137734116986394, 3.187463949434459, 2.726434925571084, 1.018900244962424, 0.03660450085590128, 1.6026470088399947, 22.77474671602249, 46.63012884557247, 28.335062451660633, 31.67600277811289, 43.625728860497475, 41.03198044002056, 28.591666482388973, 1.8873151461593807, 0.04851970777963288, 0.010973350090353051, 0.0417106178792892, 0.0316590291186003, 0.029544681929110084, 0.06384176216670312, 0.041951025486923754, 0.03512724848405924, 0.03803988125582691, 0.03533465649525169, 0.028064021244063042, 0.022672123559459578, 0.011340741948515642, 0.014292206669779262, 0.05961016970104538, 0.06512948486488312, 0.0656263304699678, 0.01759619339281926, 0.032730029852245934, 0.04891037802735809, 0.025215018358721863, 0.0458000222715782, 0.07445382085279562, 0.016853951092343777, 0.022372117782651912, 0.047517340863123536, 0.02974850907776272, 0.047314849580288865, 0.021213738436927088, 0.03462854750978295, 0.053614944918081164, 0.04589803400449455, 0.05056271416833624, 0.027020235065720044, 0.03549355402356014, 0.05252402865153272, 5.96852783113718, 45.94725228846073, 55.78173257410526, 44.693836346268654, 34.04296226799488, 37.980272993445396, 43.92933636903763, 53.85499656200409, 26.984120942652225, 1.0265075555071235, 0.2352892971248366, 0.17613006377359852, 23.187968842685223, 39.072596579790115, 7.121762149035931, 6.043901536613703, 14.483261983841658, 42.50708028674126, 53.21299821138382, 52.923985719680786, 50.33616878092289, 51.84430405497551, 46.10522501170635, 47.44990445673466, 48.54856610298157, 49.8346982896328, 46.73062585294247, 47.12666720151901, 41.02924458682537, 39.48278836905956, 37.358493357896805, 35.99999785423279, 37.321354150772095, 36.72237329185009, 36.714283525943756, 38.11159394681454, 38.30350264906883, 39.268916845321655, 39.66465421020985, 37.6103438436985, 38.8727805018425, 37.750328332185745, 36.98857560753822, 37.62659937143326, 39.36583064496517, 40.65977901220322, 41.63141347467899, 40.29552295804024, 43.28223869204521, 44.35394838452339, 41.92456014454365, 38.09980317950249, 36.24853491783142, 36.63005344569683, 39.86317075788975, 37.28030875325203, 42.27562330663204, 48.66419389843941, 53.94090995192528, 47.798440754413605, 49.32590179145336, 50.91823674738407, 50.604069605469704, 50.50063535571098, 46.68727017939091, 46.700052693486214, 48.187471479177475, 50.17138682305813, 48.245995938777924, 43.025817051529884, 47.6170688867569, 42.82437086105347, 44.597530514001846, 46.94361202418804, 49.7730465978384, 50.8424574136734, 51.45211189985275, 49.236002415418625, 46.99599601328373, 42.33656823635101, 37.09050513803959, 35.7811713963747, 36.74079090356827, 38.381136283278465, 35.65912954509258, 37.99709469079971, 44.0435354411602, 50.48825182020664, 50.05274198949337, 51.970149502158165, 52.051168754696846, 49.858861193060875, 42.5319005548954, 37.23039083182812, 38.59311930835247, 39.14174906909466, 38.44987839460373, 38.02877739071846, 37.88581386208534, 36.505511328577995, 36.502536088228226, 36.347409412264824, 38.74951891601086, 36.65844552218914, 38.343791887164116, 38.34928259253502, 43.29101622104645, 45.840417221188545, 47.97935664653778, 50.01260854303837, 47.96669952571392, 51.36200353503227, 53.72082956135273, 52.02294386923313, 51.000243946909904, 48.70588906109333, 42.76784889400005, 46.529483646154404, 51.25964842736721, 52.404766380786896, 58.88973020017147, 52.08157852292061, 29.693725146353245, 7.491218224167824, 4.251762377098203, 5.557013712823391, 6.841417942196131, 3.4828021517023444, 4.975197482854128, 1.4186586253345013, 0.10067899682326242, 1.5542699047364295, 26.598255448043346, 52.48260520398617, 36.7346466332674, 37.030380964279175, 48.64268705248833, 48.66257518529892, 34.07580390572548, 2.9570189025253057, 0.051475566942826845, 0.02491998311597854, 0.010347286370233633, 0.04063374304678291, 0.049940182143473066, 0.0848381886316929, 0.07907127073849551, 0.011837507772725075, 0.036114241811446846, 0.025842867871688213, 0.05691862272215076, 0.08513505512382835, 0.08668794718687423, 0.026019868237199262, 0.05139443164807744, 0.03305566940980498, 0.2288125891936943, 0.10204655234701931, 0.14409965282538906, 0.23314748861594126, 0.10080882071633823, 0.12771723268087953, 0.16797874413896352, 0.1289269037079066, 0.0842595064023044, 0.1771906076464802, 0.14403836627025157, 0.17998221097514033, 0.07643245335202664, 0.10868586483411491, 0.15926404536003247, 0.201181169541087, 0.16623702744254842, 0.14489193999907002, 0.12641831097425893, 0.1512635449762456, 7.466528099030256, 51.86190091073513, 64.61135298013687, 50.43260380625725, 43.59557747840881, 42.723953649401665, 47.35688924789429, 57.55922019481659, 32.30656944215298, 2.028756500221789, 0.7283671223558486, 1.2684340425767004, 31.93722166121006, 43.73112000524998, 16.79820891469717, 8.248274400830269, 15.028293337672949, 42.573759108781815, 55.01510851085186, 54.0232515335083, 51.57794214785099, 53.232897743582726, 46.93013794720173, 49.954285472631454, 51.11685588955879, 54.10676345229149, 47.936270758509636, 48.84866639971733, 42.35519103705883, 40.443999990820885, 39.71077613532543, 38.29703539609909, 39.71644543111324, 37.992679327726364, 37.782527804374695, 41.20220750570297, 41.7252342402935, 40.47190189361572, 41.58178053796291, 38.79674278199673, 41.16333179175854, 39.15327005088329, 39.03487980365753, 39.69718046486378, 41.13540709018707, 42.49286524951458, 43.93798090517521, 40.46389952301979, 45.799744203686714, 46.738548427820206, 44.97653737664223, 39.762563556432724, 37.39271052181721, 38.745890110731125, 42.160238698124886, 39.083471596241, 43.94183769822121, 51.332558915019035, 55.685324147343636, 49.06352587044239, 51.36313587427139, 52.78266750276089, 52.78451420366764, 51.6000721603632, 48.87041263282299, 49.70216900110245, 50.786361023783684, 53.51026386022568, 49.20566104352474, 45.1265799254179, 48.25841747224331, 45.43945513665676, 49.51857045292854, 47.45795622467995, 50.4655746370554, 50.19935332238674, 53.310261592268944, 52.12017685174942, 48.71937833726406, 44.3207723647356, 40.436643585562706, 37.11384728550911, 37.53405913710594, 40.32701946794987, 38.90141196548939, 40.7661809027195, 47.36095882952213, 52.79366031289101, 51.72290816903114, 54.699562042951584, 53.99943061172962, 52.62075059115887, 44.79651063680649, 38.686396703124046, 40.87854087352753, 40.54678447544575, 39.9039501696825, 40.24067670106888, 39.83482047915459, 38.18451963365078, 37.68858924508095, 39.012852385640144, 42.01911807060242, 39.6369194984436, 39.479265958070755, 39.7594553232193, 44.18161243200302, 47.79118314385414, 50.979139879345894, 52.9878830909729, 50.14544181525707, 54.21429008245468, 56.052479445934296, 54.7912473231554, 53.30380953848362, 49.793964475393295, 43.334284499287605, 48.22090968489647, 53.92889879643917, 53.698220774531364, 61.69865347445011, 53.993594124913216, 32.014513313770294, 8.184473924338818, 4.380284305661917, 10.576824601739645, 13.088556323200464, 11.745152659714222, 11.789219845086336, 4.430150929838419, 0.49189746903721243, 1.651283805258572, 30.277780406177044, 60.17410308122635, 43.9757052809, 45.02561554312706, 53.223542645573616, 55.198159888386726, 40.319454073905945, 3.575455192476511, 0.1935805383254774, 0.14254802983487025, 0.13420721021248028, 0.07967638084664941, 0.07193726487457752, 0.17694771755486727, 0.11957607304793783, 0.1374467441928573, 0.15154713444644585, 0.08420639831456356, 0.09343326804810204, 0.18821875884896144, 0.14152294577797875, 0.08660284511279315, 0.16419526044046506, 0.12554869201267138], [0.047708043130114675, 0.00792335877122241, 0.04123729835555423, 0.05851542024174705, 0.022863573540234938, 0.07841696366085671, 0.06008401243889239, 0.02315496669325512, 0.022083600451878738, 0.04554334678687155, 0.032557539889239706, 0.04860255743551534, 0.04356459183327388, 0.03588685889553744, 0.10825924124219455, 0.007612106210217462, 0.01740742813126417, 0.09995305765187368, 0.038625639863312244, 0.047975565103115514, 2.7492104284465313, 30.391069427132607, 48.665417432785034, 45.38780450820923, 34.49325330555439, 33.573311269283295, 36.59784257411957, 45.18922716379166, 30.2974671497941, 2.821992435492575, 0.19813086837530136, 0.25871814228594303, 3.73966908082366, 35.01628004014492, 9.692974928766489, 2.5337204290553927, 5.952321225777268, 32.04217962920666, 54.157061353325844, 53.4204138815403, 50.722125470638275, 48.18454183638096, 46.065593138337135, 45.82962580025196, 44.80807721614838, 43.65159407258034, 40.841648653149605, 38.08117277920246, 36.00510857999325, 35.81180915236473, 35.37271611392498, 37.57038898766041, 38.46651770174503, 42.225443199276924, 43.18698160350323, 44.514778554439545, 45.75935997068882, 39.91413362324238, 37.04454280436039, 37.14047625660896, 37.299539521336555, 36.98270872235298, 35.82659035921097, 39.634176045656204, 42.75533236563206, 44.8867329955101, 43.764159232378006, 43.27531546354294, 40.94302721321583, 41.49485640227795, 38.95588964223862, 36.39722093939781, 36.663328260183334, 34.61586892604828, 35.37386365234852, 36.250845193862915, 44.670015424489975, 49.9253386259079, 48.6631565541029, 46.67507663369179, 47.871818616986275, 48.027997836470604, 48.135763853788376, 50.09792156517506, 47.94950544834137, 46.28741383552551, 48.36220130324364, 47.63614006340504, 49.336727410554886, 38.0951864272356, 47.3936864733696, 43.358398005366325, 44.13069136440754, 47.034503147006035, 42.422534823417664, 39.941005781292915, 44.56937022507191, 50.593745559453964, 46.66118457913399, 42.585671469569206, 34.87556979060173, 35.38316175341606, 34.35607306659222, 34.07939471304417, 35.06462104618549, 36.303521767258644, 39.187092036008835, 44.846295565366745, 49.01732414960861, 49.88562695682049, 49.12503696978092, 48.36958050727844, 45.23367717862129, 36.22236952185631, 36.56795337796211, 37.24364832043648, 37.426931485533714, 37.320085018873215, 35.35102687776089, 35.09578317403793, 35.89966803789139, 35.128609612584114, 36.05473771691322, 37.385308519005775, 34.8347257822752, 36.32079944014549, 34.57299962639809, 35.37032604217529, 37.6936049759388, 39.40645806491375, 41.161777675151825, 42.00306013226509, 42.500947415828705, 42.73872725665569, 40.21004654467106, 39.390153139829636, 41.49528577923775, 44.792665243148804, 49.464324563741684, 52.51625619828701, 56.36997140944004, 48.92708659172058, 21.867587193846703, 4.4854408130049706, 4.177026087418199, 5.072951512411237, 6.247586281970143, 2.856556330807507, 4.08019445836544, 0.5595737078692764, 0.35534458234906197, 2.3663781210780144, 22.809790335595608, 45.67584045231342, 32.412823140621185, 36.22971452772617, 43.507262617349625, 47.93496362864971, 21.432143859565258, 1.06882267864421, 0.04045867783133872, 0.07773401710437611, 0.040688049703021534, 0.08638141793198884, 0.0683605732046999, 0.0873186020180583, 0.06501347976154648, 0.024608216153865214, 0.026067278486152645, 0.02937378201750107, 0.011841906853078399, 0.055387479296769015, 0.01827055515605025, 0.09234913872205652, 0.03445654365350492, 0.03886365404468961, 0.1689930967404507, 0.011131160372315207, 0.03930710212443955, 0.012424517826730153, 0.02913372136390535, 0.04331954951339867, 0.03160354986903258, 0.046993447685963474, 0.005775422905571759, 0.04500031362113077, 0.009338152922282461, 0.03501939958368894, 0.023217077032313682, 0.06960028636967763, 0.03351574530825019, 0.043443046597531065, 0.07400366375804879, 0.022298632175079547, 0.06826715165516362, 0.060158902560942806, 3.9464185992255807, 35.84864817559719, 54.52553518116474, 47.63577148318291, 34.850114956498146, 36.52803272008896, 40.369242802262306, 51.05854041874409, 33.442222103476524, 3.0573513312265277, 0.09958860377082601, 0.5103311408311129, 6.099145347252488, 40.85256926715374, 10.304676555097103, 3.9325386565178633, 9.034842643886805, 32.46945150196552, 57.44581148028374, 51.845071613788605, 51.536269783973694, 48.227715119719505, 48.47301095724106, 46.73997715115547, 47.23834700882435, 46.18385799229145, 44.48422819375992, 40.474193170666695, 38.67784336209297, 36.27099931240082, 37.3371385037899, 37.05292135477066, 39.93300721049309, 42.15588793158531, 43.31135652959347, 47.172743529081345, 47.04611912369728, 41.42480716109276, 38.43814082443714, 38.47779169678688, 38.91751550137997, 37.43035510182381, 36.61283656954765, 39.49580267071724, 44.47621062397957, 47.16737441718578, 45.725089609622955, 44.157168343663216, 43.59191447496414, 42.228540033102036, 41.38042934238911, 37.70456738770008, 37.95870155096054, 35.28610736131668, 37.26459659636021, 37.674017027020454, 44.962455332279205, 51.089022383093834, 51.726529374718666, 48.30104738473892, 49.27015118300915, 49.978391379117966, 50.3577896207571, 50.41794419288635, 50.21231822669506, 47.40186743438244, 48.92888769507408, 48.86221647262573, 51.98042795062065, 40.249385833740234, 48.81418704986572, 44.646099507808685, 44.72147226333618, 47.948764488101006, 43.964150100946426, 42.71391838788986, 46.14706076681614, 52.84401521086693, 47.24492445588112, 44.42408122122288, 36.06271728873253, 36.9419901072979, 36.47352084517479, 35.65576672554016, 36.882914677262306, 37.88402035832405, 40.908046290278435, 46.86893843114376, 50.81748515367508, 51.79819732904434, 51.965270563960075, 49.36276361346245, 46.03722386062145, 37.72929646074772, 38.01737040281296, 38.56860302388668, 38.13116669654846, 38.86019177734852, 38.288463056087494, 36.36528365314007, 37.621382251381874, 37.32458017766476, 37.95277386903763, 38.921699076890945, 37.3678370565176, 38.19515526294708, 37.66142450273037, 37.46582619845867, 41.3775072991848, 42.82775267958641, 44.14745606482029, 46.744293719530106, 44.998488798737526, 45.116533264517784, 42.66751907765865, 41.268555745482445, 43.47485035657883, 46.720119416713715, 50.95242351293564, 54.94014613330364, 58.56379508972168, 49.66312229633331, 23.816001042723656, 4.9620625376701355, 4.979960052296519, 6.88368639908731, 6.5666580107063055, 6.967785861343145, 5.428042458370328, 1.6898247809149325, 0.22391537931980565, 1.8074864172376692, 28.12394578009844, 49.7631823271513, 37.062633633613586, 40.81004194915295, 49.945606738328934, 52.7241962403059, 27.44577907025814, 1.359698495361954, 0.01948495366377756, 0.06152478454168886, 0.042800417213584296, 0.005401864727900829, 0.024532314855605364, 0.04258613320416771, 0.034461642208043486, 0.029319544009922538, 0.04211061321257148, 0.053552207464235835, 0.03148578958644066, 0.07032534980680794, 0.07891740868217312, 0.02771057897916762, 0.05536507385841105, 0.030533447134075686, 0.28736180684063584, 0.10650594704202376, 0.17264336493099108, 0.09001432728837244, 0.19476323970593512, 0.1493497539195232, 0.1532737261732109, 0.17686085659079254, 0.10622852481901646, 0.12835050729336217, 0.12315510990447365, 0.11543983913725242, 0.09456306914216839, 0.1229152997257188, 0.14939788961783051, 0.1291902325465344, 0.12374761834507808, 0.13902668753871694, 0.09254842763766646, 0.15913179464405403, 4.969893917441368, 41.08033284544945, 60.54874777793884, 56.608047634363174, 44.64758142828941, 44.73926290869713, 47.40426130592823, 56.24289482831955, 38.48525449633598, 3.8039509439840913, 0.449922694824636, 1.4876739657483995, 7.211423562839627, 44.3274562060833, 15.736638978123665, 6.0782616678625345, 8.62132128328085, 35.93497574329376, 57.95520454645157, 55.2031946182251, 53.69469076395035, 51.237271428108215, 50.94927728176117, 49.98884081840515, 48.4463781863451, 47.96889200806618, 45.25316633284092, 41.83303065598011, 40.88765278458595, 39.47838440537453, 39.324827045202255, 40.562055855989456, 41.27192996442318, 45.9429357200861, 46.896889731287956, 50.20009808242321, 49.54913221299648, 43.93939822912216, 39.73923660814762, 40.85989527404308, 41.477875113487244, 39.204164519906044, 39.29364591836929, 42.220701053738594, 45.27788780629635, 49.734976440668106, 47.77080863714218, 46.06589712202549, 45.11658266186714, 44.694052934646606, 43.95316109061241, 39.843514412641525, 40.391194224357605, 37.15074710547924, 38.65081541240215, 41.508292481303215, 47.48066760599613, 53.621191307902336, 52.66779586672783, 49.76479344069958, 50.69028317928314, 50.5829693377018, 51.39019042253494, 53.042159378528595, 52.12841100990772, 49.79565538465977, 51.142952889204025, 51.086005344986916, 53.35636451840401, 44.232328310608864, 49.147463366389275, 45.501448810100555, 48.67197588086128, 51.044458374381065, 46.4328396320343, 44.11516159772873, 48.11087138950825, 55.588098764419556, 50.117471516132355, 45.80544009804726, 38.62243473529816, 38.7698820233345, 37.64171876013279, 36.68074652552605, 39.55534167587757, 39.9308717250824, 42.232586815953255, 48.95480990409851, 52.56293289363384, 53.446419686079025, 54.12810690701008, 51.07510752975941, 48.54315139353275, 40.40506727993488, 41.85006894171238, 40.98032981157303, 40.644367039203644, 39.77665700018406, 39.01832029223442, 36.38482600450516, 40.534347742795944, 38.57954643666744, 39.953936487436295, 41.77761822938919, 38.39307144284248, 40.71698494255543, 39.43747200071812, 39.30091492831707, 42.94862799346447, 43.688455894589424, 43.742583990097046, 47.52682752907276, 47.09877669811249, 45.62861278653145, 43.72789777815342, 43.552985563874245, 46.91552013158798, 48.78106042742729, 55.003914311528206, 57.23625272512436, 61.64604149758816, 51.25934064388275, 26.11977182328701, 6.676114462316036, 7.829069970175624, 12.249102517962456, 13.331934213638306, 9.485052935779095, 9.724282398819923, 3.611833965405822, 0.42760839220136404, 3.1417020549997687, 31.40073224902153, 57.70162895321846, 46.975302323699, 48.832205682992935, 55.23392356932163, 63.32564257085323, 32.8205830603838, 2.111727660521865, 0.12213411508128047, 0.16310050355968997, 0.10090820171171799, 0.10937695275060833, 0.13142492825863883, 0.1494633173570037, 0.19991205248516053, 0.2237966950633563, 0.15592726034810767, 0.1897227656445466, 0.1479293723241426, 0.12577690242324024, 0.23756307433359325, 0.12855560722528026, 0.1364329704665579, 0.11824860092019662], [0.03143550537060946, 0.027049887576140463, 0.028854371412307955, 0.0073821684509312036, 0.06308008116320707, 0.0626562480465509, 0.023430654146068264, 0.026385581913928036, 0.04634033175534569, 0.012668255822063657, 0.03355412176460959, 0.039596625065314583, 0.06365051813190803, 0.07276733478647657, 0.06916933605680242, 0.03319399089377839, 0.05031023181800265, 0.04177353715931531, 0.06687169137876481, 0.014880228827678366, 1.0431869979947805, 15.594013631343842, 48.63673277199268, 45.15859700739384, 29.538729563355446, 26.974336467683315, 29.974505379796028, 38.22434909641743, 35.27119316160679, 7.810614360496402, 0.10474005117430352, 0.8301253651734442, 3.6617905972525477, 43.671322613954544, 8.004839513450861, 5.485097821801901, 5.468876492232084, 21.41165915876627, 53.980997800827026, 52.5442872941494, 51.23504854738712, 49.40537452697754, 47.68914721906185, 42.315920144319534, 42.19839245080948, 39.28494058549404, 38.541989251971245, 36.360769495368004, 35.60258477926254, 38.16227562725544, 38.6619184166193, 41.26165151596069, 46.91738583147526, 44.71768766641617, 49.99606803059578, 51.46918438374996, 49.01684157550335, 43.970579355955124, 36.788208559155464, 36.79517358541489, 37.15176545083523, 36.851794347167015, 37.36272253096104, 40.305527821183205, 46.893192529678345, 49.78524014353752, 47.429586946964264, 42.608968019485474, 42.2348552942276, 37.907476499676704, 36.45964398980141, 37.42058202624321, 35.702667608857155, 35.431932136416435, 36.87162168323994, 36.13068424165249, 46.44382864236832, 49.27925929427147, 50.920683816075325, 50.05248360335827, 47.13654287159443, 50.467356741428375, 49.78690065443516, 48.65856260061264, 47.48460799455643, 49.052441865205765, 46.95769026875496, 47.467326521873474, 44.925924092531204, 41.429374516010284, 45.004937052726746, 43.64291153848171, 52.69736208021641, 47.86885857582092, 49.56582851707935, 46.089079678058624, 43.47712263464928, 47.30551980435848, 46.699178740382195, 42.299679815769196, 36.45859904587269, 34.163696989417076, 35.760652497410774, 34.859470054507256, 35.387238934636116, 35.578790456056595, 36.17972441017628, 40.26146538555622, 47.25025177001953, 49.01615381240845, 50.07563576102257, 47.88800574839115, 45.32728515565395, 37.34935864806175, 35.35032771527767, 36.476389691233635, 36.24769136309624, 33.899322375655174, 37.04312928020954, 39.516028985381126, 40.91069094836712, 38.68117578327656, 38.38371254503727, 35.96287004649639, 37.031881883740425, 36.188821122050285, 36.93600922822952, 37.12124168872833, 35.60897223651409, 34.73553970456123, 36.50064758956432, 35.769399628043175, 36.9950732588768, 37.24017910659313, 38.27550955116749, 41.33181095123291, 41.158699840307236, 47.146255150437355, 48.85233700275421, 52.56112039089203, 54.55021105706692, 42.8855399787426, 17.514379285275936, 2.7476133266463876, 2.931939773261547, 3.651031474582851, 4.820655500516295, 2.4020508443936706, 1.508428214583546, 1.2953597540035844, 0.07144294257159345, 2.341428422369063, 24.843146726489067, 42.66483262181282, 37.647194266319275, 34.44405734539032, 51.24450244009495, 39.2594363540411, 11.274936441332102, 0.05483931417984422, 0.07004781626164913, 0.05918063689023256, 0.026752406956802588, 0.056720628854236566, 0.037510473921429366, 0.029892398524680175, 0.027155443240189925, 0.0705698058300186, 0.0229793764083297, 0.06183810444781557, 0.025784696481423452, 0.014038175086170668, 0.009460923629376339, 0.04944195614370983, 0.0325458993029315, 0.020390889621921815, 0.012645047008845722, 0.009860233403742313, 0.05944908654782921, 0.022343394812196493, 0.025295890191046055, 0.0026263500012646546, 0.03602032673370559, 0.004904973666270962, 0.026691257698985282, 0.07085609671776183, 0.044727470449288376, 0.03842536018055398, 0.07161166984587908, 0.03465903122560121, 0.006724445174768334, 0.030038373406569008, 0.02841881421772996, 0.048336271138396114, 0.02143482051906176, 0.04018432809971273, 1.4638637308962643, 20.314169749617577, 55.38985200226307, 51.25833369791508, 35.5839429795742, 32.465328723192215, 39.047677516937256, 45.03591299057007, 39.14993762969971, 6.438811970874667, 0.032053821996669285, 0.6177612917963415, 4.120196811854839, 45.370770022273064, 12.379135340452194, 5.521007319912314, 6.369994338601828, 25.686180889606476, 55.62712647020817, 55.42544849216938, 50.73292449116707, 50.534749925136566, 50.54426081478596, 44.18697774410248, 43.346451446413994, 40.30147343873978, 39.307119995355606, 39.21592488884926, 38.09979557991028, 38.9643669873476, 38.88210140168667, 43.42808626592159, 47.531288489699364, 47.41776578128338, 51.99535734951496, 51.674734354019165, 51.11131198704243, 45.83383597433567, 37.45419502258301, 39.47530277073383, 38.99853475391865, 37.41849213838577, 38.747417628765106, 42.69694469869137, 48.432489931583405, 50.06922170519829, 49.49417196214199, 44.250430539250374, 42.85739108920097, 40.10638430714607, 37.617540657520294, 38.0842924118042, 36.22254431247711, 38.31234857439995, 38.1500630825758, 38.194171115756035, 47.34709717333317, 50.87347514927387, 52.38211199641228, 51.15915521979332, 48.98028753697872, 51.375872790813446, 51.49682030081749, 49.94618810713291, 49.9528643488884, 49.96463231742382, 50.163460448384285, 48.49481798708439, 47.434416487812996, 43.12859393656254, 44.06790733337402, 46.01007051765919, 52.388575449585915, 50.022647604346275, 48.93134996294975, 47.340310737490654, 44.82296861708164, 47.64508478343487, 49.95930500328541, 44.31546404957771, 37.76194050908089, 36.14211782813072, 36.534803956747055, 36.61448188126087, 36.67645275592804, 36.82958833873272, 37.44387477636337, 42.77839332818985, 50.78866750001907, 49.92093846201897, 52.02998109161854, 51.613310649991035, 47.3558709025383, 38.44912223517895, 37.60834515094757, 37.82192029058933, 38.01605947315693, 36.32878661155701, 38.759782165288925, 40.95991350710392, 42.816368490457535, 40.332437977194786, 39.706121385097504, 37.31498949229717, 37.719105407595634, 38.02876219153404, 38.54736216366291, 37.885772064328194, 37.37260580062866, 37.28639982640743, 37.55322150886059, 38.045872673392296, 39.108098074793816, 39.6026985347271, 38.82691316306591, 42.393234595656395, 44.45808179676533, 49.376336485147476, 51.46082103252411, 55.196324586868286, 58.15994516015053, 44.40307594835758, 20.456415116786957, 5.06317226216197, 4.193942304700613, 6.5764933079481125, 5.716333938762546, 4.685358060523868, 4.36728092841804, 1.3825498754158616, 0.15683604986406863, 2.7811299031600356, 27.672870084643364, 48.246923089027405, 41.02101422846317, 38.234122171998024, 54.3476477265358, 49.710228368639946, 15.119751580059528, 0.172655951755587, 0.03803553227044176, 0.046854602987878025, 0.06393692776327953, 0.03789427559240721, 0.05642876072670333, 0.0558591364097083, 0.04519475631241221, 0.02349617465370102, 0.051428837614366785, 0.06280343077378348, 0.03671774888061918, 0.021875116326555144, 0.01921085440699244, 0.046802756551187485, 0.054439604573417455, 0.021843487847945653, 0.19687732157763094, 0.19923594110878184, 0.20204324828227982, 0.1767283387016505, 0.13143052405212075, 0.1766345906071365, 0.21347827452700585, 0.08966801891801879, 0.14183521183440462, 0.1319389694253914, 0.19766350829740986, 0.14979269733885303, 0.21599531290121377, 0.20138558669714257, 0.11180021334439516, 0.13625479565234855, 0.16461408406030387, 0.0882693896710407, 0.13458058470860124, 0.18107278214301914, 1.7091433005407453, 23.578821569681168, 61.935699954628944, 57.551594004034996, 41.50230400264263, 39.61955443024635, 42.257068902254105, 49.69034023582935, 44.49978455901146, 8.945751674473286, 0.177954426035285, 1.6140355914831161, 6.829281868413091, 54.40301075577736, 12.905398551374674, 8.93719358369708, 7.993584517389536, 25.315157398581505, 57.73165874183178, 56.24761797487736, 54.67388682067394, 52.30640105903149, 52.35660396516323, 46.39728493988514, 45.702545419335365, 42.2246528416872, 41.506894156336784, 40.476267859339714, 39.92184720933437, 42.34973073005676, 41.985657066106796, 45.5051726102829, 51.37954339385033, 48.00026312470436, 54.396482706069946, 53.68243642151356, 53.06699484586716, 48.391322940588, 40.69563388824463, 41.7531019449234, 40.983989015221596, 39.69476759433746, 41.47324316203594, 43.54015365242958, 51.64848916232586, 53.5053963214159, 52.370370626449585, 45.89561685919762, 45.726598128676414, 42.272298485040665, 41.54211826622486, 40.47038197517395, 38.25505904853344, 39.33423154056072, 39.929291009902954, 40.20777806639671, 48.82655918598175, 52.640927508473396, 55.267635360360146, 53.832714557647705, 50.86027845740318, 53.166397511959076, 55.44195860624313, 53.416294902563095, 51.947529315948486, 53.11510406434536, 53.02430793642998, 52.77495391666889, 49.69374865293503, 47.08387769758701, 46.04345552623272, 48.304265812039375, 52.31928236782551, 49.86709915101528, 52.43741422891617, 49.0868604183197, 47.51658707857132, 51.131067126989365, 51.12472526729107, 45.94998814165592, 39.536779671907425, 37.520444467663765, 39.0190726518631, 39.38952997326851, 38.815787360072136, 38.46565514802933, 39.53692406415939, 45.43941713869572, 51.73497252166271, 51.79140329360962, 53.27597223222256, 53.659470453858376, 50.40018394589424, 40.96877463161945, 38.83438356220722, 40.08780710399151, 39.594559371471405, 38.060802072286606, 40.988199189305305, 43.215476274490356, 45.69360449910164, 42.63314612209797, 44.34320256114006, 40.00517673790455, 39.87001419067383, 40.15949785709381, 41.7479532212019, 40.99972777068615, 38.65456201136112, 38.655781745910645, 41.71491399407387, 39.278477132320404, 40.16422480344772, 41.25347435474396, 41.12238138914108, 46.2966663390398, 44.1568149626255, 51.106740832328796, 53.43011096119881, 57.41634026169777, 58.554641380906105, 46.35541878640652, 21.728009283542633, 5.672163208946586, 9.377427510917187, 9.316767565906048, 13.265029303729534, 9.687044396996498, 9.084457531571388, 3.40589071623981, 0.2719189604977146, 3.4424015320837498, 32.318641394376755, 54.73528392612934, 49.32459466159344, 46.32321931421757, 61.47100389003754, 56.04995258152485, 20.039248801767826, 0.4703566920943558, 0.18556026712758467, 0.073431727651041, 0.2294468879699707, 0.1299829946947284, 0.1660544442711398, 0.1100062791374512, 0.09753076185006648, 0.15916658652713522, 0.10323862705263309, 0.1547028057393618, 0.14424423803575337, 0.19162166921887547, 0.1075187856622506, 0.14344065537443385, 0.1759632586617954, 0.11499151514726691], [0.03020687432581326, 0.06560814043041319, 0.034930861365864985, 0.1290808993508108, 0.059650134353432804, 0.018916245899163187, 0.0405658662202768, 0.06694786541629583, 0.061788963139406405, 0.009419086909474572, 0.021758764269179665, 0.026035837399831507, 0.06962178638787009, 0.025346521360916086, 0.026911549393844325, 0.01892915926873684, 0.04577999541652389, 0.0318493640224915, 0.09570354974130169, 0.032963357371045277, 0.11601595353567973, 7.539059557020664, 40.90618059039116, 42.90064796805382, 26.388614997267723, 21.44708275794983, 30.67244242876768, 42.25237235426903, 44.2217268794775, 12.451869137585163, 0.6316976377274841, 0.2530714374734089, 2.6022678008303046, 49.29436728358269, 14.590281341224909, 2.429868201725185, 2.236239854246378, 17.267816215753555, 47.493868097662926, 54.547995775938034, 54.76520732045174, 48.69640477001667, 47.22451575100422, 44.42843958735466, 42.307560592889786, 39.35655914247036, 37.92833358049393, 38.771941512823105, 40.653448551893234, 43.77802848815918, 46.24956786632538, 46.51780687272549, 48.66649277508259, 48.40244874358177, 50.36470524966717, 51.81221857666969, 46.70018568634987, 47.133529633283615, 38.511754274368286, 36.009599938988686, 38.743325248360634, 37.401541247963905, 38.577266559004784, 42.78258070349693, 48.71816620230675, 50.31143590807915, 49.048832058906555, 45.79585701227188, 39.713496789336205, 37.04423502087593, 35.15430003404617, 35.99362939596176, 34.98161070048809, 35.06072625517845, 36.26808486878872, 37.704468593001366, 45.806416645646095, 48.04992265999317, 48.42660404741764, 47.84297436475754, 48.60560864210129, 50.45518219470978, 49.35297913849354, 51.35107912123203, 49.17677499353886, 50.03655485808849, 46.30102090537548, 45.233156606554985, 43.02841991186142, 38.093575313687325, 45.03528982400894, 47.7172277122736, 47.519326731562614, 48.32519128918648, 47.838376611471176, 48.063852712512016, 48.6171942204237, 49.312526509165764, 46.033864840865135, 42.72456921637058, 36.158369556069374, 35.83230525255203, 35.82742251455784, 33.720503970980644, 34.73414897918701, 36.551363468170166, 36.58418230712414, 39.99730736017227, 43.63950692117214, 47.76217930018902, 48.17218869924545, 48.522358909249306, 44.980264976620674, 36.29208818078041, 36.644884049892426, 37.481264770030975, 36.87858670949936, 37.09306240081787, 45.9122371673584, 48.7646871060133, 46.86002030968666, 45.36603547632694, 45.16427770256996, 43.86956937611103, 40.56208245456219, 38.444824665784836, 36.8546099960804, 35.71618348360062, 36.08089931309223, 36.581830233335495, 37.81330235302448, 39.152164310216904, 38.12081605195999, 40.733935832977295, 41.21024027466774, 40.31500831246376, 44.39479619264603, 47.06048235297203, 51.59439906477928, 52.369831055402756, 53.11517246067524, 40.95816560089588, 14.411651026457548, 3.4041444724425673, 3.612917857244611, 6.652726242318749, 4.707822455093265, 12.783787027001381, 6.276520304381847, 0.857021271949634, 0.034078293247148395, 4.772354392334819, 32.6628003269434, 37.165216729044914, 31.1667750030756, 38.1680703163147, 52.65460677444935, 39.257262870669365, 6.988519448786974, 0.0696411490207538, 0.05410680329077877, 0.12840299197705463, 0.03907676917151548, 0.0753927712503355, 0.006987161741562886, 0.03177583574142773, 0.05296892020851374, 0.03468313247140031, 0.04149118707573507, 0.009731129393912852, 0.022384687908925116, 0.06604392212466337, 0.03940533279092051, 0.009873986327875173, 0.055171551430248655, 0.010632917674229247, 0.047136860302998684, 0.03968051001720596, 0.050525235710665584, 0.08828841091599315, 0.04324604720750358, 0.033735996184987016, 0.038024574459996074, 0.03564357917639427, 0.042477200768189505, 0.022945348937355448, 0.01300031124628731, 0.027748152060667053, 0.10381690852227621, 0.05676986664184369, 0.050173758281744085, 0.06891394077683799, 0.011241133670409909, 0.020521836013358552, 0.033508453707327135, 0.054345860189641826, 0.4347802698612213, 11.22531870380044, 49.7062461823225, 49.10568080842495, 33.907959312200546, 28.14208410680294, 36.20210900902748, 45.88058106601238, 48.77894774079323, 12.490179631859064, 0.4932195012224838, 0.17752139770891517, 3.060478325933218, 48.15660573542118, 15.267530400305986, 5.066352691501379, 3.9235953614115715, 19.43788167089224, 48.06347273290157, 55.53919158875942, 56.594816744327545, 49.92132604122162, 49.20128747820854, 47.13032640516758, 42.968801110982895, 42.200763523578644, 39.42797631025314, 40.27905084192753, 42.391992062330246, 44.12992000579834, 47.67946533858776, 48.60093869268894, 49.77737456560135, 50.10856479406357, 51.48112714290619, 53.06697964668274, 50.57131536304951, 48.75152841210365, 40.52851125597954, 37.21114866435528, 40.471981689333916, 39.910254031419754, 40.12392416596413, 43.39519903063774, 49.258314818143845, 52.77666762471199, 50.74789948761463, 47.156142219901085, 41.1539500951767, 38.6720334738493, 36.721096560359, 36.34942710399628, 36.37081615626812, 37.98558130860329, 38.23730260133743, 39.68174569308758, 46.76420845091343, 51.389111280441284, 50.94572827219963, 49.791752994060516, 49.745129495859146, 49.723356664180756, 50.68054050207138, 53.2324493676424, 50.832935124635696, 49.890289306640625, 48.50083686411381, 46.999860405921936, 45.61129331588745, 41.967399045825005, 45.284548848867416, 47.599506229162216, 46.87599465250969, 50.395692586898804, 50.25430977344513, 48.843027502298355, 50.02714276313782, 50.912871435284615, 48.02420563995838, 45.47338351607323, 37.62022331357002, 37.02487125992775, 35.931711718440056, 36.437878757715225, 35.60953840613365, 37.704476192593575, 38.320293948054314, 40.751806274056435, 46.61613419651985, 49.5661287009716, 50.482457131147385, 50.38846917450428, 46.89340151846409, 38.37023466825485, 37.811178267002106, 38.39888513088226, 38.024202436208725, 38.886463567614555, 47.85190388560295, 50.0026872754097, 48.16163286566734, 48.375500589609146, 46.21765337884426, 44.60593566298485, 41.71862259507179, 38.79760153591633, 38.8359946757555, 37.009174302220345, 37.71827705204487, 39.29077707231045, 39.33683820068836, 40.1904471963644, 38.884833455085754, 43.210183158516884, 42.0316231995821, 41.60313539206982, 46.33730135858059, 50.263395085930824, 54.47092451155186, 54.509237855672836, 54.29589070379734, 43.0106520652771, 16.269452087581158, 4.545200681313872, 5.497715994715691, 6.801171451807022, 7.332078963518143, 10.394603479653597, 2.2933828504756093, 0.710103758610785, 0.12158215016825125, 5.35671173594892, 35.481470078229904, 44.53512646257877, 38.52638728916645, 46.27601444721222, 58.24487820267677, 46.70539900660515, 9.87780461087823, 0.10224973753793165, 0.021939601538178977, 0.09507158130872995, 0.006444106775234104, 0.04306681112211663, 0.1525597949512303, 0.017778168003133032, 0.03205684253771324, 0.016431695039500482, 0.041534743722877465, 0.05210368362895679, 0.12938602594658732, 0.036329056456452236, 0.021621743399009574, 0.02395328010607045, 0.07159686399972998, 0.08226576377637684, 0.10456623276695609, 0.13654071546625346, 0.08876334832166322, 0.4959857231006026, 0.19487856945488602, 0.1174770641955547, 0.12680878455284983, 0.15820831060409546, 0.15646475338144228, 0.14105686219409108, 0.11988695128820837, 0.12395464043947868, 0.18645296688191593, 0.11958866729401052, 0.1305175488232635, 0.18396784085780382, 0.1618510385742411, 0.12921657878905535, 0.20549200853565708, 0.12094751000404358, 0.4721583891659975, 13.301207162439823, 56.738126054406166, 56.51765428483486, 39.91428941488266, 31.76621563732624, 41.161846071481705, 52.478991597890854, 54.32049438357353, 15.963560901582241, 1.1645001196302474, 0.7975234114564955, 4.212539456784725, 58.35580565035343, 18.369682990014553, 6.7611638735979795, 3.381121982820332, 21.134230345487595, 50.64798764884472, 55.6479075551033, 58.469206765294075, 53.125348314642906, 51.35459393262863, 48.62467221915722, 46.372001096606255, 43.590759336948395, 40.54898455739021, 42.94930815696716, 45.72764687240124, 47.53684379160404, 50.21615982055664, 51.06217302381992, 53.22528675198555, 52.32074148952961, 54.96425583958626, 55.558547750115395, 52.493305429816246, 51.05157919228077, 43.57646070420742, 38.74238669872284, 43.34556609392166, 41.79376356303692, 42.811899930238724, 46.16385966539383, 53.45892481505871, 54.474944695830345, 52.9639557749033, 49.28241312503815, 44.17111359536648, 39.73538741469383, 38.246266320347786, 37.85515330731869, 38.61109994351864, 39.41755346953869, 40.031722113490105, 42.1545048058033, 48.33464898169041, 53.54431763291359, 52.805063501000404, 51.77561514079571, 52.50508099794388, 52.686316072940826, 52.165440022945404, 56.057126596570015, 52.44864262640476, 52.367026805877686, 51.584694385528564, 47.79280945658684, 46.653980165719986, 44.92089316248894, 48.12501423060894, 47.1721925586462, 48.950979709625244, 51.720183715224266, 51.28234460949898, 50.84173925220966, 50.57368643581867, 53.363549932837486, 50.9841176122427, 46.82488739490509, 39.29435648024082, 40.113246738910675, 37.57171891629696, 37.58335009217262, 38.77378821372986, 40.521648824214935, 39.6326295286417, 44.105768501758575, 48.75253155827522, 51.98902688920498, 51.68508119881153, 52.954710870981216, 48.3061733096838, 41.65981315076351, 40.45309670269489, 40.10661989450455, 40.253219828009605, 39.81463976204395, 50.37786394357681, 52.93991446495056, 49.28471200168133, 49.99463930726051, 48.556891456246376, 48.204707354307175, 45.92223823070526, 42.4330298602581, 40.3770399838686, 39.20634180307388, 39.79477062821388, 41.46117500960827, 41.731272116303444, 41.7136562615633, 41.05273112654686, 45.3457635641098, 45.50512321293354, 44.14486080408096, 49.04147945344448, 52.815938517451286, 56.04074567556381, 57.100778594613075, 55.11996008455753, 44.259968027472496, 17.657067328691483, 6.449226262047887, 9.891036450862885, 13.392600808292627, 10.43908579275012, 20.922729894518852, 14.101326428353786, 1.6813718969933689, 0.31068946758750826, 6.477665361016989, 41.89342841506004, 50.72010777890682, 44.60407376289368, 50.577349439263344, 64.82431635260582, 55.65068140625954, 13.062047995626926, 0.19853784731822088, 0.13450148660922423, 0.2139337157132104, 0.08034032100113109, 0.16689690062776208, 0.19420268072281033, 0.06736892290064134, 0.11644166428595781, 0.11325266314088367, 0.16076266416348517, 0.08417354343691841, 0.24690524413017556, 0.13105581369018182, 0.11976637455518357, 0.07838894016458653, 0.12536300666397437, 0.1385642256354913], [0.004940317057844368, 0.013893310642743018, 0.03660779970232397, 0.03176051039190497, 0.01819167042413028, 0.008460305398330092, 0.012926829349453328, 0.003194370583514683, 0.01603241587872617, 0.042407887885929085, 0.059705505991587415, 0.055295441852649674, 0.06650617622653954, 0.07014802846242674, 0.11304465399007313, 0.07233446973259561, 0.0386278848600341, 0.06595066384761594, 0.06100853548559826, 0.05023140460252762, 0.1751119559048675, 2.443187437020242, 28.223707526922226, 42.842583283782005, 35.44848024845123, 21.02500330656767, 23.009146638214588, 37.911154702305794, 45.51676578819752, 20.379606038331985, 1.1578457267023623, 0.510262685129419, 14.083812218159437, 49.823754876852036, 26.387269869446754, 4.936647601425648, 2.3110872879624367, 12.325834650546312, 42.82272554934025, 59.136314168572426, 48.67834813892841, 50.36514222621918, 48.35585184395313, 44.240733459591866, 39.727381244301796, 41.314715668559074, 43.01700912415981, 46.138397231698036, 46.09821058809757, 47.03977346420288, 46.19869999587536, 51.24313071370125, 48.015633299946785, 51.98178067803383, 46.16806223988533, 48.99692304432392, 47.99315370619297, 48.24789583683014, 37.21874065697193, 37.40337274968624, 35.759983733296394, 38.025669157505035, 39.7114335000515, 43.5274775326252, 48.74357543885708, 49.4331244379282, 48.547722548246384, 48.30293968319893, 38.95946905016899, 35.35119026899338, 35.86068972945213, 35.65085358917713, 35.5323151499033, 36.19004085659981, 35.290826708078384, 38.43480460345745, 42.68027879297733, 43.8619089871645, 45.7307893037796, 46.751444935798645, 46.49943485856056, 48.18498261272907, 49.44213755428791, 50.070882216095924, 48.88203240931034, 49.21492874622345, 47.262057736516, 45.05648888647556, 46.37476734817028, 38.78097742795944, 46.9749641418457, 47.593665942549706, 50.87887845933437, 49.7054710239172, 48.80858235061169, 49.00068864226341, 46.75326123833656, 46.71331778168678, 45.882693752646446, 42.85305932164192, 35.091455206274986, 34.67722423374653, 34.484943151474, 34.20510716736317, 35.764152109622955, 35.74821196496487, 35.40627211332321, 42.49171771109104, 45.798467472195625, 47.85248525440693, 48.09651955962181, 47.3177095502615, 39.153254851698875, 35.94253733754158, 35.56270591914654, 36.94810777902603, 34.98235546052456, 40.562637224793434, 50.16094498336315, 49.99405033886433, 48.82614120841026, 49.52714279294014, 47.730903178453445, 47.359777092933655, 47.213055565953255, 44.1896566003561, 43.15123692154884, 42.16478705406189, 39.661025404930115, 36.38696908950806, 36.383169293403625, 37.5340211391449, 38.19900445640087, 39.400477185845375, 41.01643547415733, 43.5628954321146, 45.37257492542267, 50.70254132151604, 50.69107733666897, 51.904747411608696, 54.96423304080963, 36.27961345016956, 15.436055157333612, 3.8324109418317676, 2.2977364668622613, 4.8244191985577345, 5.025072181597352, 2.4425357719883323, 4.0753658674657345, 1.113238614052534, 0.03460439431364648, 6.325720064342022, 35.17386898398399, 35.55645905435085, 24.08025026321411, 30.584927424788475, 51.061052083969116, 36.562998443841934, 3.3734281081706285, 0.09363229721202515, 0.05060126131866127, 0.07625142869073898, 0.013204194056015695, 0.011440412381489296, 0.010075284608319635, 0.02583349825727055, 0.02136337396223098, 0.04750794898427557, 0.06712535003316589, 0.017550480806676205, 0.02814770952682011, 0.02153205670765601, 0.03326989033666905, 0.054945259471423924, 0.05475048652442638, 0.04400015459395945, 0.025468793901382014, 0.04047682334203273, 0.09360299722175114, 0.03411490710277576, 0.018945955926028546, 0.061122922706999816, 0.03838202988845296, 0.02339126465813024, 0.06844357500085607, 0.06052329707017634, 0.024442967696813866, 0.05155006372660864, 0.04202244606858585, 0.056171020260080695, 0.06869320379337296, 0.09637637340347283, 0.0035213923911214806, 0.01810515455872519, 0.038719914882676676, 0.05767975453636609, 0.08969901100499555, 4.102930063381791, 36.33474849164486, 47.72186726331711, 39.33971464633942, 23.923200890421867, 26.96124617010355, 43.522621393203735, 49.33992683887482, 20.948832593858242, 1.1369172809645534, 0.40995866584125906, 11.722142044454813, 52.777374386787415, 21.345419213175774, 4.619357027113438, 3.9404531568288803, 13.833739086985588, 44.91547465324402, 58.61247807741165, 53.15249405801296, 51.69075049459934, 49.281383380293846, 45.13905085623264, 40.75519949197769, 41.57592885196209, 44.90017667412758, 46.02072514593601, 48.603822737932205, 49.031991362571716, 49.1437129676342, 52.946708500385284, 50.20574077963829, 54.59715373814106, 47.922310307621956, 51.66510187089443, 50.450850427150726, 49.155138954520226, 40.66686563193798, 38.66288736462593, 38.31202179193497, 39.3770856410265, 40.45685850083828, 46.019896790385246, 50.154207944869995, 50.5524455755949, 49.72556434571743, 49.41498801112175, 40.07529437541962, 37.59226821362972, 37.99517959356308, 37.15993121266365, 36.49669200181961, 37.22354739904404, 36.55995860695839, 40.138192400336266, 45.24789601564407, 46.84680461883545, 47.47313641011715, 48.49729925394058, 48.906210511922836, 49.12148416042328, 49.36530187726021, 51.88187263906002, 51.47816710174084, 50.38670226931572, 48.94864663481712, 46.96641080081463, 48.292748630046844, 41.67493633925915, 47.41383299231529, 47.93863423168659, 50.59595704078674, 52.34759844839573, 50.85042558610439, 50.08772291243076, 49.33123670518398, 49.201694056391716, 47.47716039419174, 44.52427424490452, 37.971465066075325, 37.704837173223495, 35.68237669765949, 36.04675814509392, 37.1733520925045, 37.67807140946388, 38.9263766258955, 44.21386130154133, 47.672967687249184, 51.25777132809162, 50.0188934057951, 50.16658008098602, 41.75710313022137, 37.43410550057888, 37.69683480262756, 38.49678307771683, 36.7240110039711, 42.003861889243126, 52.72264592349529, 51.17249630391598, 50.79584151506424, 51.69749893248081, 49.35033068060875, 50.04518039524555, 48.68167296051979, 46.87043555080891, 45.039142817258835, 43.34694541990757, 41.23319484293461, 38.57112988829613, 38.77643667161465, 39.54823985695839, 38.6892731487751, 40.58480903506279, 43.197526037693024, 44.093316569924355, 47.7921748906374, 52.40146815776825, 54.340690299868584, 54.5108375698328, 55.258990824222565, 39.17881987988949, 15.21570973098278, 3.265578495338559, 6.181589523330331, 8.451826628297567, 5.426342524588108, 4.359603440389037, 5.564554408192635, 1.2214202340692282, 0.0510781988123199, 7.761213686317205, 40.648869797587395, 40.94544768333435, 29.070471189916134, 35.713094249367714, 55.88808126747608, 43.88961710035801, 4.741817805916071, 0.029941320899524726, 0.10032009420683607, 0.011163235994899878, 0.00905486216652207, 0.023512856278102845, 0.026222899432468694, 0.04468409562832676, 0.050693803423200734, 0.03860805096337572, 0.03900969386450015, 0.034960836710524745, 0.03953449988330249, 0.07596461087814532, 0.061230081410030834, 0.04383085957670119, 0.02799052635964472, 0.00370153528820083, 0.1442694413708523, 0.10251265819533728, 0.14077299070777372, 0.12855799694079906, 0.08805186618701555, 0.1405228127259761, 0.15499400964472443, 0.05854993753018789, 0.1652083217049949, 0.13064285303698853, 0.1377167078317143, 0.10928356830845587, 0.1844369969330728, 0.15418728027725592, 0.1922852679854259, 0.22018947143806145, 0.07835095704649575, 0.1026497402926907, 0.16768630826845765, 0.11485823284601793, 0.24673076521139592, 4.81752066873014, 40.16644008457661, 57.2283985465765, 48.1928101927042, 31.878511011600494, 33.5228917747736, 47.89615251123905, 55.876465290784836, 25.70342056453228, 1.7363716894760728, 1.0336654214188457, 19.13127612322569, 61.10190309584141, 30.664692744612694, 10.70702651515603, 6.608098112046719, 16.23750150203705, 45.91161400079727, 60.623345375061035, 55.25175981223583, 53.83149102330208, 50.97577325999737, 48.26220206916332, 43.24081711471081, 45.03534682095051, 47.49666474759579, 49.10664975643158, 50.230158269405365, 50.79688645899296, 50.61546139419079, 55.17999306321144, 51.397831812500954, 55.12911379337311, 50.00021740794182, 53.26978616416454, 53.663578033447266, 53.25158134102821, 41.858683079481125, 40.457333475351334, 38.95502328872681, 41.579466462135315, 42.399572655558586, 47.44241125881672, 52.74531930685043, 52.67431631684303, 50.539260283112526, 52.587236389517784, 42.639343589544296, 38.76471810042858, 39.81618247926235, 39.14910547435284, 38.94741229712963, 38.989099860191345, 39.02198329567909, 40.91056555509567, 46.1881023645401, 48.39598909020424, 50.18792733550072, 50.77878423035145, 50.66862814128399, 51.13943807780743, 50.984003618359566, 53.64296793937683, 53.91152232885361, 52.94250972568989, 50.61953857541084, 47.83928096294403, 50.06615526974201, 45.480413138866425, 47.57036939263344, 49.519053027033806, 52.30342581868172, 53.41392382979393, 53.07392567396164, 52.720092460513115, 51.8162539601326, 49.8846086114645, 48.71779002249241, 47.18327276408672, 38.70644062757492, 39.296332374215126, 37.84943841397762, 37.651928812265396, 39.00931857526302, 39.88098420202732, 39.451242461800575, 47.129919826984406, 48.68893437087536, 54.71259914338589, 52.61921927332878, 52.247599214315414, 43.96253518760204, 39.622111693024635, 39.34642128646374, 39.76047366857529, 40.19450157880783, 45.27779661118984, 55.00192701816559, 52.76395730674267, 51.003477573394775, 54.44418914616108, 51.781751811504364, 52.0779725164175, 51.14763803780079, 49.88877318799496, 46.55410252511501, 46.53220809996128, 43.61138083040714, 39.373764619231224, 41.0654566437006, 42.0186772942543, 40.95740184187889, 42.67117068171501, 45.47187119722366, 46.940948367118835, 50.105114579200745, 56.352499946951866, 56.67671374976635, 57.209296971559525, 56.86435908079147, 40.41933931410313, 19.85908716917038, 6.473350692540407, 8.420189525932074, 13.501456417143345, 12.03118896111846, 6.38202496804297, 8.911246675997972, 2.643028451129794, 0.2497825655154884, 8.513894397765398, 45.02404622733593, 49.21356461942196, 35.89095510542393, 44.055835381150246, 61.702909246087074, 51.75839826464653, 6.1866893246769905, 0.13015935866860673, 0.189187528740149, 0.16041992552345619, 0.11394313507480547, 0.18059853493468836, 0.057503527859807946, 0.15427688718773425, 0.10749075474450365, 0.08731826805160381, 0.13432766078040004, 0.12687732931226492, 0.15067518514115363, 0.17631984577747062, 0.1860166879487224, 0.10208703650278039, 0.1732666650786996, 0.13299859303515404], [0.0336900757974945, 0.0315456920361612, 0.012111709074815735, 0.06487440870841965, 0.05012043497117702, 0.012862899820902385, 0.048385939371655695, 0.09701382630737498, 0.011984904795099283, 0.0066880994199891575, 0.03305972524685785, 0.03058592996239895, 0.1002422280726023, 0.03784783941227943, 0.04210238279483747, 0.055700409575365484, 0.03757750098884571, 0.032585426088189706, 0.03145289017993491, 0.0350925976090366, 0.02718411426030798, 0.5894489516504109, 14.94647802785039, 39.31546814739704, 46.40252485871315, 29.199880845844746, 28.164818286895752, 35.904725566506386, 44.12530705332756, 30.35782691091299, 2.9950949968770146, 0.4402539652073756, 24.985544085502625, 48.71372424066067, 45.89964844286442, 9.123255349695683, 1.3079339917749166, 8.224776461720467, 37.34220363199711, 47.268099412322044, 53.41906875371933, 53.15291963517666, 49.04760852456093, 48.59115041792393, 45.454198345541954, 46.934876292943954, 48.25024791061878, 48.85474607348442, 49.27333541214466, 51.81091904640198, 51.88915304839611, 51.5716914832592, 48.392523676157, 50.642040967941284, 47.98602148890495, 46.84262104332447, 46.21968626976013, 42.90436036884785, 38.02937775850296, 36.27246603369713, 36.416432708501816, 38.37944537401199, 40.776949524879456, 45.01702040433884, 47.34222583472729, 51.69686436653137, 49.30158689618111, 48.73944506049156, 40.34765236079693, 34.58118438720703, 35.54868467152119, 35.19464246928692, 34.83758322894573, 39.299915581941605, 36.502148509025574, 35.940569043159485, 39.87604446709156, 43.55978719890118, 45.46185873448849, 46.57965995371342, 46.24513350427151, 48.48394297063351, 49.14454132318497, 47.02256798744202, 47.90260076522827, 48.945200219750404, 45.18812522292137, 46.668943762779236, 47.3393227905035, 38.53722810745239, 46.42533503472805, 48.14143314957619, 49.52709339559078, 48.50019469857216, 48.678298741579056, 47.89039961993694, 47.667720168828964, 46.47004723548889, 45.18632411956787, 40.135464146733284, 37.09739416837692, 35.87333545088768, 35.1162488758564, 33.62060733139515, 35.19541762769222, 35.46635828912258, 38.80682364106178, 41.580940783023834, 44.970883280038834, 47.48670928180218, 45.27902014553547, 42.697275280952454, 36.66493937373161, 37.31822311878204, 39.325134828686714, 36.80765211582184, 35.95398232340813, 42.25229635834694, 47.37460009753704, 50.68597041070461, 49.341974928975105, 49.884878396987915, 50.21945804357529, 50.372061654925346, 47.84402310848236, 47.69406035542488, 47.013091295957565, 48.985272869467735, 49.12904195487499, 44.84303534030914, 41.52325987815857, 39.187133833765984, 37.568276301026344, 40.08287876844406, 38.941678404808044, 44.63924087584019, 47.66375698149204, 51.66304238140583, 51.038207709789276, 55.80060236155987, 48.5852987319231, 36.17882005870342, 11.3378762640059, 2.140169134363532, 5.506965648382902, 4.7016615606844425, 4.851038670167327, 3.4712533839046955, 1.8780556367710233, 0.7804227259475738, 0.12083519337465987, 4.0960766561329365, 28.4514844045043, 37.5001535564661, 35.36350920796394, 38.80925551056862, 55.8215506374836, 26.72001041471958, 1.991013006772846, 0.041470399519312195, 0.053833214260521345, 0.08054386242292821, 0.1251084203249775, 0.008955081339081516, 0.039661637201788835, 0.027307757918606512, 0.1096731513098348, 0.04379419005999807, 0.08073997494648211, 0.05010113542084582, 0.04062779844389297, 0.02900984021835029, 0.02841351342794951, 0.03572746041754726, 0.07885550614446402, 0.03437073653913103, 0.04611196549376473, 0.05525885026145261, 0.03547441403497942, 0.05291252069582697, 0.040180168361985125, 0.019080626043432858, 0.07103106545400806, 0.02658433648321079, 0.0436587147123646, 0.07828190762666054, 0.018803931125148665, 0.04132187721552327, 0.03731477328983601, 0.034528327887528576, 0.02627088855660986, 0.11069656553445384, 0.023989079454622697, 0.0014692628042212164, 0.022543626255355775, 0.015962453617248684, 0.026033518188341986, 1.0453608375974, 19.81465995311737, 46.483977288007736, 50.226043090224266, 32.421680465340614, 27.30058316141367, 40.49531243741512, 50.12496471405029, 33.3531928807497, 2.8963268967345357, 0.5179312080144882, 28.064330779016018, 53.79930295050144, 43.369193226099014, 5.564266098663211, 2.7644219622015953, 9.659101646393538, 38.88534642755985, 51.311025470495224, 53.56403097510338, 53.9558469504118, 49.643762335181236, 48.77377241849899, 46.706227362155914, 47.883677780628204, 49.76217158138752, 50.375618264079094, 50.78707158565521, 53.34521971642971, 52.87817157804966, 51.60631902515888, 51.22719056904316, 51.40592157840729, 49.60353009402752, 48.01419697701931, 48.38410332798958, 46.347074434161186, 39.176938980817795, 38.34418326616287, 37.86391943693161, 39.29884783923626, 42.18793161213398, 47.53240562975407, 48.536893129348755, 52.03786186873913, 50.6388833373785, 49.76777248084545, 41.79193966090679, 37.22076594829559, 37.145982161164284, 35.27886115014553, 37.61414363980293, 40.908886045217514, 37.811546847224236, 38.51127550005913, 41.608048528432846, 44.68421906232834, 47.45106719434261, 48.39973948895931, 49.001642391085625, 50.38431219756603, 50.90149864554405, 49.44776505231857, 49.5164729654789, 50.86021766066551, 47.69300401210785, 47.57448077201843, 48.90076920390129, 42.21577271819115, 47.67934374511242, 49.89527843892574, 50.2058357745409, 49.94409441947937, 50.4365099966526, 49.37743462622166, 48.676771223545074, 49.01409052312374, 46.35218136012554, 43.20158042013645, 38.98049712181091, 37.92203351855278, 37.20115140080452, 35.53564377129078, 36.720131412148476, 37.320145815610886, 40.04134699702263, 43.88072557747364, 46.73218376934528, 50.0489117950201, 47.20227934420109, 45.72179518640041, 38.37346449494362, 38.82713355123997, 40.192043110728264, 38.12574438750744, 37.48809680342674, 44.49438884854317, 49.66420143842697, 51.54747158288956, 49.00671511888504, 51.652231961488724, 52.60943479835987, 52.11063176393509, 51.30933836102486, 49.51223239302635, 48.72945919632912, 50.5133380740881, 49.39318098127842, 46.205874010920525, 43.45080524682999, 38.77933591604233, 38.74521754682064, 41.535571217536926, 41.60105310380459, 46.38909637928009, 48.65850180387497, 53.551628440618515, 54.56415630877018, 56.22504338622093, 51.42675206065178, 36.28054440021515, 14.072166793048382, 2.6916701160371304, 3.6109298514202237, 5.959891369566321, 8.45919918268919, 4.214870156720281, 3.4203244792297482, 1.1418148619122803, 0.058253490351489745, 5.437641218304634, 32.828669026494026, 41.37323632836342, 37.59029991924763, 41.453617215156555, 59.769341200590134, 33.200349882245064, 3.060130407102406, 0.025381105442647822, 0.04284104608814232, 0.07740514178294688, 0.01447466924219043, 0.04819107736693695, 0.05429222888778895, 0.03949067977373488, 0.08959761878941208, 0.0028108924425396253, 0.052372637946973555, 0.04680646728957072, 0.04994184084353037, 0.03376398628461175, 0.08361268759472296, 0.03178029975970276, 0.04437966665136628, 0.038489055004902184, 0.1503761886851862, 0.12718785874312744, 0.10057491061161272, 0.2108880307059735, 0.15060762001667172, 0.16327866353094578, 0.222447426058352, 0.13560550549300388, 0.14478496683295816, 0.1208984837285243, 0.12199726304970682, 0.10186481522396207, 0.15702296717790887, 0.17329590569715947, 0.11007920998963527, 0.20391688914969563, 0.13259915431262925, 0.2517507708398625, 0.12281210409128107, 0.11447725133621134, 0.17008724506013095, 1.4849385875277221, 22.007451988756657, 52.64580264687538, 60.813946947455406, 39.962983801960945, 37.944083735346794, 47.54478916525841, 55.37206515669823, 39.900632947683334, 4.193981252610683, 0.799523766618222, 31.85810800641775, 55.89964024722576, 52.647941932082176, 13.423261363059282, 3.8398908404633403, 11.835746448487043, 41.93409003317356, 54.16846074163914, 56.28943473100662, 57.48401463031769, 53.04845184087753, 53.455508798360825, 50.186502411961555, 51.712131947278976, 52.924061715602875, 51.742066740989685, 53.0659195035696, 54.61787022650242, 55.9541255235672, 52.16871924698353, 51.56265936791897, 54.04630869626999, 52.509203776717186, 50.3654196113348, 51.131238117814064, 47.56963983178139, 41.498242020606995, 40.33877603709698, 39.29413229227066, 42.23522387444973, 44.908988401293755, 49.7561527043581, 50.84435731172562, 53.939397633075714, 53.871628269553185, 52.38053888082504, 43.282386884093285, 38.23330141603947, 38.66019330918789, 37.34697997570038, 39.15869615972042, 43.67837503552437, 40.00390760600567, 40.032029896974564, 43.682463616132736, 47.24078267812729, 49.00555998086929, 50.020170137286186, 51.09707415103912, 53.19213353097439, 53.30247201025486, 50.37177287042141, 52.39949606359005, 51.93014144897461, 49.64581422507763, 48.377487882971764, 47.87307634949684, 46.675099432468414, 47.982206493616104, 52.89250060915947, 52.45781533420086, 51.83770380914211, 52.90282845497131, 51.888457685709, 49.50055181980133, 50.46516425907612, 48.56421746313572, 43.92149738967419, 41.23021960258484, 40.46611100435257, 38.981184884905815, 37.23047062754631, 38.4029471129179, 38.46050262451172, 42.26216822862625, 45.626663491129875, 48.61010380089283, 51.864366978406906, 48.20391319692135, 46.696169301867485, 39.78976249694824, 40.34854531288147, 44.28058572113514, 40.65275698900223, 40.21275579929352, 45.89938625693321, 50.838026851415634, 55.63730992376804, 50.63365861773491, 52.62735843658447, 54.63999263942242, 54.39383424818516, 52.67234802246094, 51.345611214637756, 52.06537999212742, 54.07440058887005, 52.2192907333374, 48.65983173251152, 46.736789122223854, 41.37174300849438, 41.03965982794762, 43.810497745871544, 42.90478974580765, 49.28066901862621, 50.938151478767395, 56.290810257196426, 56.14163026213646, 58.94786708056927, 51.65034346282482, 39.098587185144424, 13.963915351778269, 3.8827803265303373, 11.641770657151937, 13.180783074349165, 12.742613386362791, 11.48352149873972, 4.870481751859188, 1.4664313243702054, 0.3620051499456167, 5.969720492139459, 39.20924864709377, 50.5979785323143, 48.28891083598137, 51.16615444421768, 67.92158335447311, 37.95672945678234, 4.279893217608333, 0.204404020041693, 0.1559804129647091, 0.1811587525298819, 0.20030626648804173, 0.14036285021575168, 0.15420368174090981, 0.16138731501996517, 0.19427057239226997, 0.12084650370525196, 0.1601305473013781, 0.14542134362272918, 0.1552132103824988, 0.13062567973975092, 0.19176738249370828, 0.08941808584495448, 0.12611547019332647, 0.15092085086507723], [0.010753078804555116, 0.025198308903782163, 0.058816216405830346, 0.053748568607261404, 0.05012402696593199, 0.06146362786239479, 0.0359274135553278, 0.03316084657853935, 0.04756549882586114, 0.06822888652095571, 0.018473992677172646, 0.01523970568086952, 0.03939455309591722, 0.06533853302244097, 0.08399618498515338, 0.06561101254192181, 0.1046849912381731, 0.04458067734958604, 0.02286400027514901, 0.03953606210416183, 0.03743283414223697, 0.08537377434549853, 9.094728380441666, 29.192676432430744, 44.706615060567856, 34.74028564989567, 30.81265300512314, 31.9303098320961, 43.15666303038597, 38.435838147997856, 5.989551153033972, 0.8759423566516489, 29.752268604934216, 39.25046123564243, 39.55034874379635, 10.463400688022375, 0.7995699578896165, 5.721305496990681, 26.65832832455635, 46.18474334478378, 54.664216339588165, 53.44740383327007, 51.15482345223427, 48.88311915099621, 49.53588992357254, 46.20785750448704, 49.45343814790249, 51.24067984521389, 51.35087013244629, 52.1192193031311, 48.55972230434418, 47.14891880750656, 49.61188584566116, 51.41763634979725, 48.32867190241814, 47.17421405017376, 45.43728165328503, 40.27306616306305, 37.245445623993874, 38.033325746655464, 37.256320640444756, 35.23888349533081, 39.819967076182365, 45.73741614818573, 49.485702216625214, 51.1256942152977, 48.90650309622288, 50.62373735010624, 42.93495632708073, 36.00750245153904, 35.54137386381626, 35.43598271906376, 35.391395911574364, 36.85593232512474, 34.980406165122986, 35.349765345454216, 41.109716668725014, 47.95085817575455, 48.80552351474762, 47.82941669225693, 48.06147024035454, 49.204110726714134, 46.74141347408295, 48.61896492540836, 48.9869599789381, 44.560809284448624, 45.815642550587654, 45.534058660268784, 46.203164756298065, 38.0650844424963, 45.15494920313358, 47.788177505135536, 49.250768423080444, 47.969302386045456, 47.6133868843317, 45.341443195939064, 47.11143381893635, 45.4598106443882, 42.412203177809715, 41.36796221137047, 36.79549656808376, 35.777238607406616, 35.089353919029236, 34.94936183094978, 36.007240265607834, 35.4495669901371, 41.212953329086304, 43.591154515743256, 45.24931713938713, 46.72806479036808, 44.381656497716904, 40.58664433658123, 35.811307579278946, 35.64753636717796, 35.81338606774807, 37.66441114246845, 33.12089994549751, 39.527834951877594, 48.095383420586586, 47.13233269751072, 46.402384266257286, 45.85192680358887, 47.02531524002552, 46.85910455882549, 51.37983597815037, 51.306739300489426, 48.602329418063164, 47.679845318198204, 48.62661391496658, 49.99588564038277, 48.49800981581211, 43.43524128198624, 39.59284566342831, 38.88269416987896, 40.922170132398605, 43.86368729174137, 48.131268694996834, 52.20854111015797, 50.8607192337513, 55.09856343269348, 46.72571651637554, 29.970384500920773, 10.791359189897776, 1.7064676503650844, 3.5090644424781203, 4.4253527373075485, 4.5636301673948765, 2.340656351298094, 1.0734329000115395, 0.6067251996137202, 0.03412273676076438, 7.777978386729956, 37.561467066407204, 34.41010236740112, 34.336948692798615, 42.29269199073315, 53.59563387930393, 21.899855062365532, 0.5310319550335407, 0.03311458851385396, 0.018358145280217286, 0.04368669367977418, 0.018662817310541868, 0.04034111050714273, 0.024944310716819018, 0.03401493238925468, 0.042264887160854414, 0.023932004587550182, 0.01795571941329399, 0.019225309588364325, 0.04998259217245504, 0.05247495042567607, 0.01091377140255645, 0.03316686168545857, 0.030549152834282722, 0.0692767693544738, 0.034418423238093965, 0.02829735432896996, 0.04033881727082189, 0.025853484294202644, 0.01961138037586352, 0.015328614972531796, 0.06543859679368325, 0.05448766976769548, 0.0212699282928952, 0.06622075365157798, 0.04019990206870716, 0.031372920057037845, 0.029188284061092418, 0.044196704984642565, 0.042495331435929984, 0.04360931365226861, 0.07773219884256832, 0.07528604299295694, 0.04032896154967602, 0.11718652822310105, 0.08166958912624978, 0.04811461389181204, 12.008913606405258, 37.528032660484314, 52.00707592070103, 37.31088571250439, 32.0456450432539, 38.749758303165436, 47.3441219329834, 42.0654109865427, 7.271010065451264, 1.0494083329103887, 30.411476232111454, 42.28886939585209, 47.030095383524895, 9.526241775602102, 2.3729686299338937, 7.733721686527133, 28.185042701661587, 50.092852637171745, 54.15656737983227, 55.65878637135029, 51.84074744582176, 51.099202036857605, 50.957161858677864, 47.52795226871967, 51.340139508247375, 53.5416691750288, 53.427055925130844, 53.13746586441994, 50.82400180399418, 48.46014864742756, 50.43682537972927, 53.365495428442955, 49.899165630340576, 48.24042543768883, 46.59020058810711, 43.90295438468456, 39.05286803841591, 39.318686574697495, 39.74687799811363, 37.469713389873505, 41.922610849142075, 46.84262104332447, 50.47331862151623, 52.431091368198395, 50.757790356874466, 53.513417690992355, 45.224375277757645, 38.239593878388405, 37.44582027196884, 37.977244555950165, 36.55426651239395, 38.801009953022, 37.781954035162926, 37.48757243156433, 43.25467497110367, 49.64255020022392, 49.97548073530197, 50.87775371968746, 49.56229470670223, 49.86689396202564, 50.30794769525528, 50.092088878154755, 50.12110412120819, 48.88924442231655, 46.99555903673172, 47.362322956323624, 46.28822319209576, 41.280414909124374, 46.25074200332165, 50.44540151953697, 51.96062721312046, 49.13138262927532, 50.439762622117996, 47.67311587929726, 48.25865685939789, 48.265762478113174, 44.018730372190475, 41.89549170434475, 37.96562097966671, 36.701189428567886, 35.742903649806976, 37.208093628287315, 37.653988301754, 37.438756451010704, 41.85782052576542, 45.99762238562107, 48.364712968468666, 48.85859526693821, 46.13060764968395, 41.79830051958561, 36.83632917702198, 37.83689148724079, 37.82777197659016, 39.503216072916985, 34.8535917699337, 41.51009738445282, 49.110248163342476, 49.49819594621658, 46.917013451457024, 45.67240543663502, 48.52892495691776, 48.951751068234444, 54.34680417180061, 53.01918961107731, 50.483262687921524, 49.86263819038868, 51.25986121594906, 50.7367242872715, 49.96611423790455, 45.80740079283714, 40.34455552697182, 39.85198795795441, 42.7688330411911, 45.026356503367424, 50.82970529794693, 53.781246319413185, 53.87800432741642, 57.318579107522964, 47.41792917251587, 32.7836262434721, 12.971849385648966, 2.3175816144794226, 3.845465141348541, 7.332850797101855, 8.751491848379374, 4.35621022246778, 3.0236454773694277, 0.7751078205183148, 0.11604604020249099, 7.061544405296445, 40.47170430421829, 41.2311277538538, 39.64742213487625, 46.699581518769264, 60.17330892384052, 26.093741320073605, 0.8624264819081873, 0.03605065088777337, 0.02260291643324308, 0.04646128698368557, 0.03860140132019296, 0.09613024012651294, 0.02750787061813753, 0.07237016703584231, 0.011407973106543068, 0.050302984745940194, 0.05199854727834463, 0.046106636873446405, 0.025251995866710786, 0.05235810298472643, 0.04428441570780706, 0.06418203687644564, 0.10592134247417562, 0.055298232327913865, 0.1236417138716206, 0.18852523615350947, 0.1387032150523737, 0.11569459617021494, 0.1312798383878544, 0.1684022878180258, 0.20836030540522188, 0.30976867012213916, 0.21209191298112273, 0.14272797096055, 0.12038674321956933, 0.1328748621745035, 0.13809873576974496, 0.2551997685804963, 0.2149636682588607, 0.18152936623664573, 0.18960945453727618, 0.22040323965484276, 0.11302471248200163, 0.17677127936622128, 0.24726448813453317, 0.19320355699164793, 13.267997894436121, 42.67852708697319, 58.135622665286064, 45.88043287396431, 40.56508049368858, 44.289131462574005, 52.229230999946594, 48.08879837393761, 8.081084322184324, 1.6163278184831142, 38.03033910691738, 44.54913631081581, 46.680802926421165, 13.96858150139451, 4.085886552929878, 9.75208455696702, 32.74791195988655, 49.999632239341736, 55.98137766122818, 58.71699146926403, 54.34897005558014, 53.343859389424324, 54.34581242501736, 49.498959705233574, 54.8954301327467, 55.72404786944389, 56.33178725838661, 53.052586019039154, 51.50289237499237, 49.577664881944656, 52.76762031018734, 55.19414730370045, 52.008421048521996, 50.662134289741516, 48.741762936115265, 44.68589097261429, 40.40968403220177, 42.33661003410816, 41.816965118050575, 39.575359001755714, 43.16602572798729, 50.3218549489975, 53.24397794902325, 54.076566472649574, 51.897311210632324, 55.625511556863785, 47.614675015211105, 39.805235266685486, 39.54303413629532, 39.67159263789654, 37.33373008668423, 40.78842870891094, 39.12528455257416, 40.0434634834528, 45.07382735610008, 52.032697945833206, 53.0819546431303, 53.67405027151108, 50.31985625624657, 50.647923052310944, 52.5422316044569, 51.49072162806988, 53.079967349767685, 49.015526846051216, 47.911925464868546, 46.1714668571949, 46.77386373281479, 45.174939930438995, 47.71627016365528, 50.81113949418068, 55.2136554569006, 51.202199310064316, 50.78286521136761, 49.18638847768307, 51.349167823791504, 50.35372383892536, 46.08627922832966, 44.93184417486191, 40.578698962926865, 38.32263462245464, 38.28102305531502, 39.64687496423721, 39.22651492059231, 40.28171069920063, 44.7820258140564, 47.18297637999058, 49.239809811115265, 51.8622200936079, 48.97290073335171, 44.13255326449871, 38.84857960045338, 37.905933782458305, 38.62939976155758, 42.14669242501259, 36.949585899710655, 42.4025858938694, 53.52659918367863, 51.86885453760624, 48.61568570137024, 46.824898794293404, 51.00080631673336, 50.732886493206024, 57.29766882956028, 55.89903227984905, 54.687790274620056, 51.141881346702576, 52.75014124810696, 53.3861131221056, 52.95009791851044, 47.84210041165352, 42.51263178884983, 41.98487050831318, 44.67527434229851, 47.931897193193436, 52.872722670435905, 56.664455607533455, 55.78286871314049, 58.08052942156792, 49.617125764489174, 33.67636173963547, 13.318501934409142, 4.061974436044693, 8.990824855864048, 10.952439196407795, 11.787188854068518, 8.642267659306526, 6.845432426780462, 1.834851955063641, 0.1903774734819308, 10.415111929178238, 47.99119681119919, 48.561899587512016, 45.73476389050484, 55.07210545241833, 65.38686096668243, 32.35902942717075, 1.171607756987214, 0.1393048741738312, 0.08394966716878116, 0.12021391186863184, 0.0845803962147329, 0.15834856167202815, 0.14661735913250595, 0.20291561319027096, 0.11261983381700702, 0.17968306608963758, 0.10957593738567084, 0.11117674992419779, 0.14207724103471264, 0.13451051112497225, 0.1346574563649483, 0.2509630849817768, 0.2030532222124748, 0.1715678148320876], [0.06823963281931356, 0.023843228882469703, 0.052401166103663854, 0.04059004168084357, 0.06891068274853751, 0.020563830439641606, 0.1278534613084048, 0.11008290588506497, 0.07971170707605779, 0.02481462597643258, 0.037892316322540864, 0.013306166074471548, 0.062149565274012275, 0.05992402395349927, 0.06234436790691689, 0.059341504820622504, 0.008707338529347908, 0.014266773268900579, 0.054572690205532126, 0.05720333654608112, 0.02259818709717365, 0.15356610267190263, 3.5462582716718316, 25.984098203480244, 42.07415051758289, 38.867331594228745, 22.20122829079628, 30.39571277797222, 43.45955617725849, 40.238366425037384, 11.207219325006008, 0.846080471528694, 21.424447372555733, 38.81007246673107, 33.384142220020294, 6.008598580956459, 3.2110195979475975, 4.015191346406937, 26.685962341725826, 50.95729485154152, 52.25268334150314, 53.30038972198963, 50.52520863711834, 54.29334484040737, 50.59113509953022, 55.12898460030556, 51.01094037294388, 50.77204339206219, 49.819381311535835, 47.044682800769806, 51.20629549026489, 51.68754726648331, 50.78513368964195, 48.61879013478756, 47.41959348320961, 47.182091027498245, 44.85736057162285, 39.22029085457325, 37.71692052483559, 36.471981927752495, 35.91018587350845, 36.80749252438545, 40.80620035529137, 46.34251847863197, 48.53934399783611, 53.061504140496254, 49.64944303035736, 51.08096681535244, 43.68625581264496, 35.891836658120155, 37.19814196228981, 36.91803239285946, 36.124007999897, 34.764756336808205, 36.33467249572277, 35.35258859395981, 42.1720864623785, 49.96299460530281, 50.08753292262554, 48.645479902625084, 49.84498433768749, 49.35748189687729, 47.712869346141815, 46.27050094306469, 41.791377291083336, 46.231898814439774, 47.184089720249176, 44.287296161055565, 45.12387827038765, 38.41534964740276, 45.092275366187096, 48.69661755859852, 47.1652427315712, 45.196378380060196, 44.008421525359154, 46.35167978703976, 44.04331885278225, 43.13454441726208, 40.04563696682453, 37.737644612789154, 36.61736212670803, 34.8235771805048, 35.23753076791763, 33.02695758640766, 36.32271833717823, 36.80558502674103, 39.36776094138622, 43.42053607106209, 44.64554853737354, 47.20650091767311, 45.11107675731182, 42.83166266977787, 38.84418323636055, 34.674837961792946, 36.351912170648575, 37.00918950140476, 35.57070828974247, 36.031019389629364, 44.41794075071812, 49.27763298153877, 48.22729334235191, 46.43945887684822, 46.81491672992706, 46.63919895887375, 46.7785868793726, 50.12431874871254, 50.1527564227581, 49.43530172109604, 50.81726476550102, 48.9428823441267, 48.9284735172987, 47.94367276132107, 43.84010575711727, 43.07866461575031, 40.39369449019432, 43.656359016895294, 48.55705104768276, 49.49387937784195, 52.44880221784115, 53.58632057905197, 44.64892655611038, 26.532119996845722, 9.829285964369774, 3.21697601582855, 2.2525229305028915, 5.497113252058625, 9.39050355926156, 3.5308804968371987, 2.4828036362305284, 0.40264782845042646, 0.035203801016905345, 8.184735160320997, 32.05252647399902, 28.165929727256298, 36.82046502828598, 38.5787408798933, 41.24100722372532, 14.426869209855795, 0.13634429866215214, 0.061887379342806526, 0.04428459382324945, 0.08451422632788308, 0.017727186168485787, 0.04481033865886275, 0.026727250005933456, 0.032264321052934974, 0.021799111127620563, 0.038749211162212305, 0.03317085443995893, 0.06005802242725622, 0.054698658641427755, 0.019308496921439655, 0.026434569226694293, 0.05624623692710884, 0.02610530427773483, 0.02698800544749247, 0.012072204553987831, 0.02815623680362478, 0.04975897565600462, 0.07826405155356042, 0.03152677098114509, 0.06519808899611235, 0.04503224823565688, 0.011713460571627365, 0.05605600221315399, 0.006755835238436703, 0.013104629379085964, 0.025485800215392374, 0.06162296325783245, 0.025171227935061324, 0.019997642266389448, 0.031238431765814312, 0.021300217194948345, 0.04062952022650279, 0.023860183246142697, 0.011721861683327006, 0.018659574125194922, 0.06770737934857607, 5.064344024285674, 30.658271089196205, 48.8596174120903, 44.09407652914524, 28.501381427049637, 33.546788692474365, 47.657388523221016, 45.773521810770035, 10.249413270503283, 1.161909846123308, 28.342625945806503, 47.73814558982849, 36.90488889813423, 6.216740012168884, 1.5630096732638776, 5.638193031772971, 28.89153689146042, 50.49765631556511, 52.131207659840584, 55.651057586073875, 51.86331443488598, 55.2180328220129, 54.29186671972275, 55.543508157134056, 52.68271766602993, 52.2138874232769, 50.53729958832264, 47.121206894516945, 50.827068239450455, 51.902585327625275, 52.787398248910904, 50.72284363210201, 49.23734374344349, 49.20153446495533, 45.89511148631573, 40.96900261938572, 38.81194956600666, 38.069249019026756, 37.642049342393875, 38.95885728299618, 42.51746892929077, 47.8951645642519, 50.120936930179596, 54.51092876493931, 50.872312411665916, 52.28472322225571, 44.59999278187752, 37.75582283735275, 38.443836718797684, 37.85170689225197, 38.70372757315636, 37.92767621576786, 38.899455070495605, 36.84686601161957, 44.67967830598354, 50.59724137187004, 53.09513993561268, 49.45692636072636, 51.55670128762722, 50.61782106757164, 50.17059646546841, 48.582540079951286, 45.773255825042725, 47.6373939961195, 49.03962895274162, 45.182528123259544, 44.903638288378716, 40.973106399178505, 47.70687326788902, 49.503268674016, 48.1941819190979, 47.43875965476036, 47.13813118636608, 49.35411907732487, 47.70260989665985, 45.4246511310339, 43.4003097563982, 39.541795402765274, 39.35973197221756, 36.592188477516174, 36.61610059440136, 35.71754761040211, 37.92542673647404, 37.5084713101387, 41.21394507586956, 45.26032134890556, 47.8385666012764, 49.573504105210304, 47.26053401827812, 44.941187873482704, 39.81833316385746, 36.716726794838905, 38.41815769672394, 38.62990893423557, 36.059669852256775, 37.499340400099754, 47.16585069894791, 51.92535750567913, 51.61389581859112, 48.95347997546196, 48.595573380589485, 48.78198757767677, 48.34875762462616, 51.38758756220341, 52.267931923270226, 51.29948548972607, 52.53508038818836, 51.19899608194828, 51.25068470835686, 50.25626666843891, 45.2919090539217, 44.4087528437376, 42.43023321032524, 45.77894791960716, 51.020618453621864, 52.17704080045223, 54.81552802026272, 54.450094029307365, 46.33850209414959, 29.75886695086956, 11.684835646301508, 3.1029101740568876, 2.0211229473352432, 7.535605067387223, 8.801917992532253, 5.6633932795375586, 2.278759810142219, 0.5136637401301414, 0.021292869932949543, 9.707309659570456, 39.80358615517616, 37.221161127090454, 41.980158761143684, 44.257505759596825, 49.44141559302807, 18.100364841520786, 0.38942863466218114, 0.11192719481186941, 0.037642294191755354, 0.017982648241741117, 0.01493482306614169, 0.0539465402107453, 0.07287036714842543, 0.013979637260490563, 0.01970611367141828, 0.04010561962786596, 0.02221743194240844, 0.0356435494904872, 0.025967133078665938, 0.03007220791914733, 0.043182100052945316, 0.043206668851780705, 0.06670279341051355, 0.013489370794559363, 0.15174559957813472, 0.1223686634330079, 0.15879171289270744, 0.28239615610800683, 0.17797076812712476, 0.22250577370868996, 0.20255032810382545, 0.2412591627216898, 0.2031934732804075, 0.14350237237522379, 0.150844810414128, 0.13221127825090662, 0.18106622155755758, 0.21483558841282502, 0.1635448422166519, 0.1255060185212642, 0.1160107807663735, 0.18492853618226945, 0.12491788133047521, 0.16766011045547202, 0.08659242535941303, 0.2779147122055292, 5.076013673096895, 37.01972633600235, 57.12100110948086, 51.45442217588425, 35.588016360998154, 42.31858380138874, 53.678283244371414, 50.84328196942806, 15.112641211599112, 1.0284990048967302, 30.70793442428112, 48.760499730706215, 38.48393976688385, 9.235040601342916, 6.593477921560407, 6.412223372608423, 30.179114900529385, 53.00590932369232, 52.28034965693951, 56.65311321616173, 53.744080513715744, 57.23939135670662, 55.50492502748966, 59.666655510663986, 54.67537634074688, 52.2029934078455, 50.119569003582, 47.448882311582565, 54.113629683852196, 53.807290121912956, 55.1849289983511, 52.80695199966431, 51.94833867251873, 50.666051879525185, 48.168734684586525, 42.643527165055275, 40.37270441651344, 38.851201459765434, 39.31034602224827, 41.25905625522137, 44.919931814074516, 49.86722454428673, 52.42099530994892, 55.91746889054775, 52.79093585908413, 54.604646936059, 46.587426736950874, 40.478395745158195, 40.627860724925995, 39.55049313604832, 40.10471239686012, 39.293091148138046, 40.8123180270195, 38.71592491865158, 46.97233088314533, 53.7650515884161, 56.45940341055393, 50.264253839850426, 53.49336236715317, 54.228991493582726, 51.09523884952068, 49.71839793026447, 47.09349878132343, 49.77577105164528, 49.75731164216995, 45.22753670811653, 45.01234285533428, 42.23856769502163, 48.36570851504803, 51.86806797981262, 49.91130977869034, 49.926767349243164, 48.135007694363594, 51.27856761217117, 48.81268613040447, 47.54552252590656, 45.34055024385452, 41.02485582232475, 40.26209615170956, 38.38409632444382, 38.40118780732155, 37.54529893398285, 39.854036048054695, 39.65502552688122, 43.15137751400471, 46.756950840353966, 48.16753014922142, 50.58916300535202, 49.45866286754608, 46.8619430065155, 41.701398119330406, 38.18318970501423, 40.417340621352196, 41.203985810279846, 38.50915901362896, 38.428496941924095, 48.149249330163, 53.63157995045185, 53.620530143380165, 50.07244773209095, 48.988506495952606, 49.08234626054764, 48.131853863596916, 51.45178511738777, 53.7291207164526, 53.84456232190132, 54.079807698726654, 52.62315586209297, 51.740102246403694, 53.1154802441597, 47.788724675774574, 47.30041287839413, 44.477202370762825, 47.54280187189579, 53.26035127043724, 53.601800948381424, 58.03473047912121, 56.583120971918106, 48.00003133714199, 33.112669587135315, 12.566954512149096, 5.653039310127497, 6.5833239164203405, 13.207230605185032, 15.426242183893919, 9.42787455394864, 5.864876993000507, 0.9568932722322643, 0.2650777838425711, 11.666901558637619, 43.71618680655956, 41.137253791093826, 47.40022212266922, 51.471494659781456, 53.52626480162144, 21.133536882698536, 0.6877517548855394, 0.1496920472709462, 0.12362166846287437, 0.1376149445422925, 0.08363892993656918, 0.1423179788980633, 0.17061124584870413, 0.12166035026893951, 0.07178879081038758, 0.09577697041095234, 0.10896054853219539, 0.23991645430214703, 0.12143792118877172, 0.14136173645965755, 0.1277057739207521, 0.1133036041574087, 0.14954888698412105, 0.09385807337821461], [0.017508167256892193, 0.023637794984097127, 0.040767452082945965, 0.04056778096128255, 0.03332210784719791, 0.06524271433590911, 0.06744295955286361, 0.030721024959348142, 0.046679229781148024, 0.030249078408814967, 0.037883915210841224, 0.033355493360431865, 0.01867290680820588, 0.0697549722099211, 0.015564660607196856, 0.06251350336242467, 0.008468732485198416, 0.03736563267011661, 0.01781501563527854, 0.11463452727184631, 0.08557626933907159, 0.02151545115339104, 0.3317493328358978, 13.997738286852837, 38.43456521630287, 35.62469959259033, 27.98304744064808, 25.53675390779972, 38.53939779102802, 39.64838728308678, 18.29163707792759, 0.18478547979611903, 0.8485435112379491, 6.167331263422966, 15.707934368401766, 7.819579979404807, 2.0437664072960615, 2.420754390768707, 25.785028785467148, 51.622604951262474, 49.82708729803562, 53.21099951863289, 52.393412590026855, 51.47313617169857, 51.83329604566097, 50.7954653352499, 48.54913987219334, 50.79773001372814, 50.69932669401169, 49.982977733016014, 50.71659676730633, 49.69024904072285, 48.69689494371414, 47.22751758992672, 43.67167979478836, 39.15240749716759, 37.48115077614784, 37.45284989476204, 36.81069575250149, 37.05608278512955, 35.211361572146416, 36.18927709758282, 41.05300851166248, 49.89806368947029, 49.18476976454258, 52.22370229661465, 51.085678562521935, 47.966995909810066, 42.629996091127396, 36.081674471497536, 36.926783323287964, 35.91002628207207, 38.45281943678856, 35.6048646569252, 36.340687572956085, 35.71491055190563, 38.739586248993874, 48.054976388812065, 49.08729739487171, 49.76231977343559, 49.82116341590881, 50.820156410336494, 47.05996558070183, 41.79073132574558, 44.80716526508331, 48.630235120654106, 47.31406934559345, 45.652954280376434, 45.41966199874878, 39.50572393834591, 46.23256757855415, 51.64462096989155, 48.71441960334778, 46.99641399085522, 43.81410755217075, 44.77169796824455, 42.85673752427101, 40.704335421323776, 37.94210784137249, 36.58336915075779, 35.24301767349243, 35.23290641605854, 35.04094831645489, 33.61698232591152, 35.96151351928711, 35.93353562057018, 36.91990569233894, 40.48237033188343, 45.55478274822235, 49.130022302269936, 49.00546498596668, 46.12014681100845, 45.77514432370663, 41.1441770195961, 37.50413954257965, 35.47398827970028, 36.36918984353542, 35.253611505031586, 38.80401939153671, 43.182186260819435, 47.0919256657362, 49.53940853476524, 48.561382815241814, 50.314924120903015, 50.36114104092121, 45.211957544088364, 47.28129230439663, 47.23404183983803, 50.05866967141628, 51.84341870248318, 51.10373139381409, 48.430183455348015, 47.94827811419964, 45.69209598004818, 43.15451994538307, 42.68236108124256, 47.15710736811161, 51.890049800276756, 52.811108976602554, 51.403930485248566, 42.97018803656101, 26.193831749260426, 6.021484639495611, 1.7771976487711072, 2.1074391156435013, 5.2890905644744635, 10.637911073863506, 3.1861425703391433, 1.72555758850649, 0.2605164551641792, 0.1342257490614429, 8.030775021761656, 29.195070303976536, 34.7552340477705, 35.42597025632858, 39.86480847001076, 37.41464674472809, 9.433348160237074, 0.012223785433889134, 0.04773920591105707, 0.03217978301108815, 0.0925556338916067, 0.03198858721589204, 0.09339329597423784, 0.020485877103055827, 0.04195792746031657, 0.031710100010968745, 0.01973735252249753, 0.0446609591745073, 0.06425816638511606, 0.010658449409675086, 0.012527618837339105, 0.06777375703677535, 0.01905085850012256, 0.08259062407887541, 0.05127825585077517, 0.019192373074474744, 0.07914388246717863, 0.06849893179605715, 0.04990678920876235, 0.006756985567335505, 0.041531392926117405, 0.01199252108563087, 0.03914752924174536, 0.11051640918594785, 0.018746127097983845, 0.014319540896394756, 0.03072704748774413, 0.04174366571533028, 0.025510886662232224, 0.04187331520370208, 0.006325593676592689, 0.013465084939525696, 0.005069823218946112, 0.01467049232815043, 0.10486971179489046, 0.10037770713097416, 0.004235790238453774, 0.9195630066096783, 19.594085589051247, 44.71115201711655, 42.70719654858112, 31.345726400613785, 31.926217451691628, 44.18277896940708, 45.14122813940048, 20.21111737936735, 0.1938661909662187, 1.6854505031369627, 11.730409450829029, 19.94480486959219, 9.632725361734629, 1.1344785243272781, 3.259018622338772, 27.88756236433983, 53.6010067909956, 49.98711571097374, 52.2240898758173, 51.93680629134178, 53.59116151928902, 52.772495448589325, 50.437558740377426, 49.94409441947937, 51.22198484838009, 50.885338112711906, 51.44650340080261, 52.38496944308281, 51.205011159181595, 49.70514424145222, 48.14085938036442, 45.22796608507633, 40.30585840344429, 39.05459314584732, 38.66465047001839, 39.346839264035225, 38.557177037000656, 35.88006108999252, 39.06098820269108, 43.5619492828846, 52.25229576230049, 51.80319406092167, 53.55253279209137, 53.17402370274067, 51.42778180539608, 43.75486113131046, 38.27480658888817, 39.06668409705162, 37.49571159482002, 39.12769362330437, 37.920733988285065, 38.0752032995224, 37.132682874798775, 40.071726366877556, 50.849646627902985, 50.64121261239052, 51.545275300741196, 50.55181100964546, 51.64431318640709, 48.76689098775387, 44.40111145377159, 47.47250184416771, 48.57334837317467, 49.342970475554466, 45.910048484802246, 45.690180882811546, 41.35756216943264, 48.09706673026085, 50.70993572473526, 49.81976509094238, 49.9866559356451, 45.05061440169811, 46.42259918153286, 43.3675517141819, 42.14872531592846, 40.425931960344315, 38.64092454314232, 38.28900642693043, 36.89393408596516, 36.67179420590401, 35.62504917383194, 37.597553730010986, 36.871576085686684, 38.3960846811533, 42.73065648972988, 45.94298891723156, 52.630979642271996, 51.5623439848423, 48.66072088479996, 47.8917333483696, 43.27281139791012, 39.41849961876869, 36.75696283578873, 37.1323598921299, 35.39729319512844, 39.769346192479134, 46.252558305859566, 48.69527243077755, 49.98389348387718, 49.78801019489765, 52.71870173513889, 49.6651665866375, 46.85438521206379, 48.31340052187443, 48.584192991256714, 50.375352278351784, 53.778768852353096, 52.18696586787701, 51.42675966024399, 50.86171858012676, 48.408779203891754, 45.36869153380394, 44.64283548295498, 48.49660009145737, 53.97727780044079, 53.191384971141815, 54.04765762388706, 44.28816631436348, 28.181235305964947, 5.686951065436006, 2.511629364453256, 4.502146616578102, 7.41474162787199, 8.449268415570259, 4.036925230175257, 3.8451580703258514, 0.15138724615098909, 0.12866179371485487, 8.65060156211257, 33.81872870028019, 38.31931360065937, 40.050527304410934, 45.5104923248291, 41.990638598799706, 12.21537172794342, 0.1671220682328567, 0.016636618711345363, 0.08127092965878546, 0.04663732812332455, 0.03475483877991792, 0.04930061040795408, 0.041827053428278305, 0.04168240513536148, 0.01266273331566481, 0.05994316394207999, 0.04181369848083705, 0.025795257242862135, 0.01844319725933019, 0.03791915238252841, 0.046764806829742156, 0.056185032008215785, 0.013994154596730368, 0.022769367169530597, 0.11243632296100259, 0.2417363043059595, 0.18537737225415185, 0.2050466457149014, 0.0986979746085126, 0.097134840907529, 0.15016587887657806, 0.11450115591287613, 0.14242741599446163, 0.13531580072594807, 0.10304750176146626, 0.10283138835802674, 0.1539945593685843, 0.18796935270074755, 0.11467264397651888, 0.16235379909630865, 0.1374321832554415, 0.12644287606235594, 0.12780759658198804, 0.18740478612016886, 0.23517174093285576, 0.08830760285491124, 0.9499001037329435, 20.382315292954445, 53.10389086604118, 48.91308054327965, 38.446469977498055, 35.9013095498085, 49.43225048482418, 50.09143531322479, 23.827176243066788, 0.32778593769762665, 1.2686063395813107, 10.308923777192831, 21.055131889879704, 12.732025254517794, 4.239648152142763, 5.440507214516401, 31.213318705558777, 54.627704098820686, 50.47101974487305, 55.19624099135399, 52.49042898416519, 54.083265513181686, 52.8541112691164, 51.24453663825989, 49.276580438017845, 52.03478783369064, 53.87605883181095, 53.53402778506279, 53.93987260758877, 51.8302296102047, 51.67098015546799, 50.66059537231922, 47.86698907613754, 41.68305650353432, 40.14213278889656, 41.477593928575516, 41.26462675631046, 41.107375994324684, 37.56731115281582, 40.50844833254814, 45.37398844957352, 55.29921926558018, 52.89579123258591, 54.2201379686594, 54.176888689398766, 53.93105328083038, 46.82827301323414, 39.92457166314125, 40.395199209451675, 39.48853746056557, 42.876979038119316, 39.491356909275055, 40.08774250745773, 38.89082953333855, 40.47658324241638, 51.41469530761242, 53.27470310032368, 54.79117892682552, 53.08918945491314, 55.90998329222202, 51.353396996855736, 47.22382038831711, 48.898903504014015, 51.8862272053957, 50.31236685812473, 47.83362306654453, 45.74564270675182, 44.45473037660122, 48.94319772720337, 52.878407165408134, 52.78615191578865, 51.30952075123787, 47.13031880557537, 49.26677316427231, 45.465586334466934, 44.22204606235027, 41.334687396883965, 40.148843228816986, 40.505579486489296, 39.16507601737976, 39.247383400797844, 37.699365466833115, 39.14639621973038, 41.02732188999653, 40.36541260778904, 43.32472041249275, 47.065004110336304, 53.84981743991375, 53.50070737302303, 51.44531026482582, 50.17432786524296, 46.29241816699505, 42.612494230270386, 38.58012020587921, 38.897395581007004, 37.13843956589699, 42.41552419960499, 47.63753838837147, 49.6506741642952, 53.464719504117966, 51.78796827793121, 55.39678283035755, 52.12684169411659, 48.052137941122055, 48.40400665998459, 48.87566015124321, 51.235797107219696, 55.537572875618935, 55.00950001180172, 52.517802715301514, 51.61337524652481, 51.018536165356636, 48.40858541429043, 47.42496259510517, 50.40284000337124, 56.19295030832291, 54.88627262413502, 55.72154000401497, 46.0154814273119, 32.592842280864716, 7.949500232934952, 3.214649590663612, 4.967263033613563, 11.955516021698713, 20.204121954739094, 10.264857541769743, 4.071838231757283, 0.5109610164072365, 0.4318518441868946, 12.009345833212137, 42.105810418725014, 45.4754202067852, 46.396570578217506, 51.515218913555145, 48.917435109615326, 13.187216129153967, 0.29262194177135825, 0.15215259336400777, 0.13926380372140557, 0.2384384672041051, 0.14096440543653443, 0.16051312442868948, 0.15143823169637471, 0.17440479306969792, 0.10023010880104266, 0.1717968564480543, 0.1565437178942375, 0.18212027905974537, 0.12308434612350538, 0.12496842158725485, 0.2328648787806742, 0.12186736494186334, 0.1369732094462961, 0.1509805937530473], [0.033838371746242046, 0.005437793952296488, 0.02818310440488858, 0.027823274103866424, 0.017234184888366144, 0.061948855145601556, 0.024133004153554793, 0.029378813778748736, 0.04106601438252255, 0.05933770131377969, 0.022216669385670684, 0.0323465139081236, 0.03163974812196102, 0.03290071639639791, 0.016878204478416592, 0.025222812764695846, 0.046172279835445806, 0.05480196930875536, 0.013831628893967718, 0.003796079104176897, 0.032970032989396714, 0.04806603290489875, 0.1002982899080962, 6.6143896244466305, 32.05121174454689, 54.55392345786095, 36.60057082772255, 34.80742424726486, 38.90862017869949, 42.7080363035202, 19.82714418321848, 1.2700426625087857, 0.3079079574672505, 0.04664199623221066, 9.768809359520674, 18.16403802484274, 1.6982977325096726, 4.444990558549762, 31.084097139537334, 45.21537736058235, 58.92739377915859, 57.07863338291645, 48.37661772966385, 49.261985421180725, 51.00760795176029, 54.434408470988274, 52.5057003647089, 54.78546783328056, 53.65224324166775, 50.83676151931286, 48.840926215052605, 46.95203997194767, 45.38172863423824, 40.95778562128544, 39.09989811480045, 36.54751047492027, 35.20138330757618, 36.50214470922947, 36.48465044796467, 36.3506468385458, 38.35431732237339, 38.70083972811699, 39.988108053803444, 46.20910383760929, 50.641835778951645, 49.832559004426, 49.641607850790024, 48.27095679938793, 45.7892719656229, 39.19355548918247, 36.08307659626007, 36.61028690636158, 35.42944706976414, 36.198476403951645, 35.92676438391209, 35.19032970070839, 35.087347626686096, 42.702541798353195, 46.5766467154026, 46.943923607468605, 45.86472071707249, 47.68637716770172, 46.74461290240288, 45.1142343878746, 48.95099110901356, 48.64104934036732, 49.13712032139301, 45.50968676805496, 46.77245780825615, 37.47130550444126, 44.42901335656643, 50.20469583570957, 46.00549936294556, 46.926531940698624, 44.47115309536457, 42.63666853308678, 40.819731429219246, 38.40592995285988, 35.807868763804436, 33.84149327874184, 34.53258879482746, 34.84933979809284, 35.52652806043625, 34.370888471603394, 35.84003023803234, 35.2308165282011, 35.158134028315544, 36.74590162932873, 42.30443716049194, 46.714469119906425, 48.80043938755989, 48.662810772657394, 47.747588083148, 45.97155578434467, 41.07218228280544, 38.30324426293373, 36.2288785725832, 35.84962472319603, 34.86873775720596, 38.534682244062424, 41.83910273015499, 44.451048374176025, 46.830473095178604, 47.42191515862942, 48.375781774520874, 51.1087167263031, 49.30238865315914, 47.43660517036915, 47.49413028359413, 49.47327308356762, 52.17832513153553, 50.02480588853359, 49.49757277965546, 49.81264427304268, 48.51630203425884, 46.757619604468346, 47.68463686108589, 51.46433964371681, 54.939830750226974, 50.37289761006832, 37.18609280884266, 23.965156339108944, 5.936682689934969, 2.0381935313344, 1.442676899023354, 6.91196353174746, 5.22269862703979, 3.6754696257412434, 3.9777771290391684, 0.3010917763458565, 0.3020175016717985, 15.383801311254501, 37.602843046188354, 28.346750624477863, 30.281768292188644, 40.64985014498234, 29.806212410330772, 4.496303955093026, 0.10161215846892446, 0.019677487180160824, 0.05108438832394313, 0.028703938078251667, 0.043366675890865736, 0.02604751323815435, 0.011455888943601167, 0.051766878459602594, 0.03367151468410157, 0.06036622522515245, 0.0665025768103078, 0.060101601338828914, 0.032991655461955816, 0.06951380390091799, 0.04745130085211713, 0.040153291483875364, 0.019471164559945464, 0.01004050292976899, 0.1383153983624652, 0.04677659955632407, 0.06402651240932755, 0.028601388112292625, 0.03927957215637434, 0.07740635148365982, 0.014185057243594201, 0.0449565528833773, 0.06060428393539041, 0.04128438391489908, 0.06425348343327641, 0.03882832039380446, 0.05742055946029723, 0.06922933127498254, 0.01728315735817887, 0.03272421512519941, 0.0133225100216805, 0.015288062168110628, 0.06190870866703335, 0.050436196543159895, 0.009304295217589242, 0.051335965254111215, 0.2234125297400169, 8.857015985995531, 40.33127523958683, 57.121806666255, 37.57971368730068, 33.641851991415024, 42.29099728167057, 45.69290913641453, 20.82964438945055, 1.2919854163192213, 0.3219838865334168, 0.06965275621041656, 13.566017802804708, 18.421445712447166, 0.6470306462142617, 3.994966456666589, 34.55010965466499, 46.61567062139511, 56.69959992170334, 54.56718094646931, 50.07198415696621, 48.085598945617676, 50.49368552863598, 54.607397988438606, 53.732392340898514, 55.42680881917477, 54.98258985579014, 51.055948957800865, 51.17950312793255, 49.963374584913254, 48.18398706614971, 43.93195442855358, 41.58098258078098, 39.64347414672375, 37.27005310356617, 38.01447115838528, 38.677246794104576, 37.3771807551384, 39.63311970233917, 39.96907487511635, 41.932661309838295, 49.285593554377556, 52.381751015782356, 50.81384114921093, 52.65875615179539, 51.93302549421787, 47.389096319675446, 40.69119572639465, 37.272948548197746, 38.70089292526245, 36.85901775956154, 37.107995599508286, 38.000613301992416, 37.66022376716137, 36.415273770689964, 44.85403195023537, 50.68266078829765, 48.05389724671841, 48.140916377305984, 49.677531123161316, 48.714332208037376, 46.75848215818405, 50.32671868801117, 49.92129564285278, 50.691373720765114, 47.99795284867287, 48.76964583992958, 41.11126698553562, 46.71509988605976, 50.74956379830837, 48.691890612244606, 47.63219967484474, 44.650685861706734, 44.62400369346142, 43.47801938652992, 41.167857348918915, 38.50954279303551, 36.71705737709999, 36.568743735551834, 36.569473296403885, 37.14380867779255, 36.62797495722771, 38.33893574774265, 37.74729609489441, 38.11517335474491, 39.88895617425442, 45.02292908728123, 48.14813978970051, 50.9477611631155, 50.25786258280277, 49.641934633255005, 48.12600217759609, 42.10133045911789, 39.80452090501785, 36.95036865770817, 37.32139214873314, 36.56137213110924, 40.9749872982502, 45.169924199581146, 47.439466416835785, 48.318955823779106, 49.89334814250469, 49.682151675224304, 52.82725811004639, 50.179761573672295, 48.94776128232479, 46.85671828687191, 50.65818250179291, 52.91361607611179, 51.59957818686962, 51.04298025369644, 51.68150559067726, 48.31674054265022, 49.43393759429455, 48.505719602108, 53.1499519944191, 57.05719493329525, 53.53876993060112, 41.1127071082592, 28.094751946628094, 4.963925862684846, 1.693250178359449, 4.534678095951676, 10.081731118261814, 8.107831086963415, 4.565765177831054, 2.892505726777017, 0.22588063089642674, 0.5346270371228456, 16.44314456731081, 41.225036680698395, 32.36383616924286, 34.54881012439728, 46.798847392201424, 35.02134136855602, 6.091927634552121, 0.05518638325156644, 0.09760269080288708, 0.07212992641143501, 0.00855912050610641, 0.03252254391554743, 0.021917266603850294, 0.04781467861903366, 0.05778701714007184, 0.028948739200131968, 0.007980453119671438, 0.062265640881378204, 0.07438328713760711, 0.05158825464604888, 0.06833371488028206, 0.06226583383977413, 0.030047627988096792, 0.0257869878623751, 0.015965591046551708, 0.18777467252220958, 0.12904569186503068, 0.12570633902214468, 0.09813159718760289, 0.09352560606203042, 0.12204421873320825, 0.16010752588044852, 0.08091207157121971, 0.1345346457674168, 0.16278083086945117, 0.09786402326426469, 0.21331228577764705, 0.11487354335258715, 0.16188764129765332, 0.0834908195247408, 0.16160197381395847, 0.1450633315835148, 0.16841092641698197, 0.1543841275270097, 0.2497407083865255, 0.08216230096877553, 0.20178533712169155, 0.3463843069039285, 11.666727717965841, 48.46436262130737, 65.73419272899628, 46.445071175694466, 44.20595392584801, 50.87541304528713, 54.30349409580231, 26.196943782269955, 2.3708801669999957, 0.5387158552184701, 1.3540524733252823, 14.418664500117302, 28.33595920354128, 3.1932959239929914, 6.208215169608593, 36.79832361638546, 46.70229457318783, 58.25125806033611, 57.75261461734772, 50.02628020942211, 48.44314455986023, 53.17364752292633, 56.50340884923935, 54.356014877557755, 58.55503275990486, 58.226665779948235, 52.49403119087219, 52.59105898439884, 51.882818788290024, 49.739794582128525, 45.47758609056473, 44.04385082423687, 41.10491372644901, 38.63843187689781, 39.504340812563896, 40.47638185322285, 39.343290254473686, 42.49345421791077, 42.40300387144089, 42.50642292201519, 49.510727673769, 55.488164126873016, 51.901574581861496, 53.13986353576183, 53.25830318033695, 48.933135867118835, 42.864800691604614, 39.352489560842514, 42.15693287551403, 38.59390586614609, 39.469671472907066, 39.25167717039585, 38.48700240254402, 38.31264115869999, 47.52434626221657, 51.362356916069984, 50.38515195250511, 49.720852598547935, 51.624938026070595, 51.03939704596996, 48.3011157810688, 52.307575196027756, 52.209852039813995, 51.461888775229454, 49.18197691440582, 49.336966797709465, 42.71145612001419, 47.37266980111599, 52.55927748978138, 50.014132261276245, 49.95255656540394, 48.85005712509155, 46.315695717930794, 44.44806933403015, 42.74274364113808, 38.423325419425964, 37.925278544425964, 39.294025897979736, 38.54234643280506, 38.805805295705795, 39.10496324300766, 40.51361985504627, 38.63496646285057, 40.57305246591568, 40.339828580617905, 47.27953679859638, 50.816314816474915, 52.997944951057434, 52.51409411430359, 53.00996370613575, 48.70727218687534, 43.44062179327011, 41.007141172885895, 39.599841088056564, 38.18586476147175, 37.7357143163681, 42.53454141318798, 45.626131519675255, 48.71557854115963, 50.580514669418335, 51.30562596023083, 51.09554283320904, 55.86921527981758, 53.98884057998657, 51.017609015107155, 48.52015882730484, 50.41651926934719, 53.0431093275547, 52.81990550458431, 53.16018484532833, 53.22356924414635, 51.381925866007805, 51.590097695589066, 52.68813997507095, 56.10128402709961, 59.148481115698814, 54.90856222808361, 42.89024032652378, 29.221078008413315, 7.394471615552902, 3.2631611125543714, 3.8559226552024484, 18.03691014647484, 12.000178825110197, 14.277218990027905, 9.118324164301157, 0.7361137785483152, 0.6925868173129857, 20.91214556246996, 51.97890803217888, 39.66158777475357, 42.610453739762306, 53.157247602939606, 40.01600235700607, 6.362260803580284, 0.1404956798069179, 0.17802785412641242, 0.1475134727661498, 0.11102567834313959, 0.15734505926957354, 0.07604909696965478, 0.13992637832416221, 0.07741033681668341, 0.11963214230490848, 0.09559987171087414, 0.14615261141443625, 0.153703281248454, 0.09294534305809066, 0.16142660431796685, 0.13782506139250472, 0.15837930142879486, 0.10388395414338447, 0.22250866808462888], [0.07814192373189144, 0.019625894929049537, 0.03683497110614553, 0.04474396468140185, 0.03345805816934444, 0.032187594115384854, 0.014698593749926658, 0.055214584863279015, 0.05900645483052358, 0.019618627447925974, 0.05727853837015573, 0.036296383404987864, 0.05030362670368049, 0.027712996525224298, 0.044423145373002626, 0.0372388849791605, 0.022481107735075057, 0.015420369472849416, 0.02971823501866311, 0.019272875688329805, 0.030204963295545895, 0.05269366505672224, 0.023821693612262607, 3.233691556379199, 24.308226630091667, 51.873551085591316, 42.674054726958275, 32.983689308166504, 44.64722044765949, 50.41160613298416, 26.164066046476364, 4.085864229127765, 0.18318474147235975, 0.4998388944659382, 5.748793222010136, 10.203346442431211, 2.5870702788233757, 4.550256310030818, 22.319732531905174, 44.97858166694641, 54.5867270976305, 45.88593877851963, 49.124850779771805, 53.88282626867294, 55.19552282989025, 53.301575258374214, 52.573268339037895, 50.122445449233055, 49.20525446534157, 47.17179358005524, 45.107007175683975, 41.99577212333679, 39.33008596301079, 36.841170117259026, 37.187187150120735, 36.0150982439518, 34.4853725284338, 35.33318683505058, 36.26502223312855, 36.629688665270805, 36.94822557270527, 37.50903747975826, 42.32371732592583, 46.458062678575516, 51.9869028031826, 49.20758754014969, 49.39625881612301, 48.0660679936409, 47.926657274365425, 43.27788792550564, 39.18975569307804, 36.05985224246979, 38.10634642839432, 38.6274466663599, 35.620774403214455, 36.090824380517006, 36.271922662854195, 35.01949466764927, 40.748572647571564, 42.237036377191544, 46.728824749588966, 48.582847863435745, 47.669555470347404, 46.115492060780525, 45.755009204149246, 49.14146348834038, 48.96104536950588, 48.09795208275318, 51.11298769712448, 37.835607156157494, 43.35685148835182, 47.7198001742363, 48.71422201395035, 46.14049851894379, 48.1266937404871, 43.86141501367092, 41.984000355005264, 38.177509009838104, 37.01151117682457, 34.56888824701309, 35.471685603260994, 33.964785262942314, 34.53746773302555, 36.05165608227253, 35.05153074860573, 35.06819665431976, 37.13508054614067, 35.673511773347855, 37.6966068148613, 41.226700991392136, 45.90476676821709, 49.853108301758766, 48.91000270843506, 47.37956263124943, 45.12526899576187, 40.40393114089966, 35.28867982327938, 35.16001112759113, 34.45862576365471, 34.20810140669346, 36.298232451081276, 37.01602913439274, 39.004439637064934, 43.746957555413246, 46.50518015027046, 47.611202001571655, 48.43886598944664, 50.887306407094, 50.10152757167816, 49.86970201134682, 48.20542551577091, 49.269995391368866, 51.66271559894085, 50.3942296653986, 50.79514615237713, 48.8038782030344, 48.4644728153944, 55.150514245033264, 53.82264129817486, 49.04165044426918, 31.118544191122055, 11.420598775148392, 1.7101792199537158, 0.7957403571344912, 4.997668527066708, 9.039608538150787, 6.362142059952021, 1.7664143024012446, 3.130610450170934, 0.2963382611051202, 0.7642579183448106, 17.309661470353603, 26.071411818265915, 22.140209265053272, 32.33001418411732, 38.979520574212074, 21.15841794759035, 2.1025561401620507, 0.039490256749559194, 0.03245032552513294, 0.0521602501248708, 0.00792817716501304, 0.016922091381275095, 0.05810315349663142, 0.024107624558382668, 0.06755235212040134, 0.048516761453356594, 0.051808902571792714, 0.010994632102665491, 0.08715008254512213, 0.015267859980667708, 0.04187254708085675, 0.0426819444692228, 0.04852721089264378, 0.04876403392700013, 0.027043039408454206, 0.06628123126574792, 0.012749511715810513, 0.023791588391759433, 0.04472431632166263, 0.010602350466797361, 0.05359110342396889, 0.050992736796615645, 0.01011538655802724, 0.047991473038564436, 0.03321587311802432, 0.01101979647501139, 0.029421045692288317, 0.03444633541221265, 0.023093520576367155, 0.0602422976953676, 0.035848267216351815, 0.03959713714721147, 0.04096667420526501, 0.06924777364474721, 0.028459671302698553, 0.025050788499356713, 0.02427307339530671, 0.004073281234013848, 5.025126803666353, 33.19478698074818, 59.332771226763725, 46.704779639840126, 39.90615405142307, 45.39436675608158, 52.9425173252821, 26.7779079079628, 3.1970285112038255, 0.29822284122928977, 0.5176793527789414, 9.16653597727418, 19.60400115698576, 3.453271798789501, 6.211532866582274, 25.361402817070484, 49.53691966831684, 54.462861344218254, 52.02550873160362, 50.33560261130333, 54.36984993517399, 55.97190476953983, 54.974655881524086, 53.75768378376961, 53.17056588828564, 51.810402274131775, 49.80169326066971, 47.779206186532974, 44.758793860673904, 41.5479851514101, 39.311596155166626, 38.459590673446655, 37.40557663142681, 38.18063244223595, 38.730618730187416, 38.95537666976452, 38.44374552369118, 38.49202573299408, 39.83615800738335, 43.74650537967682, 49.06395524740219, 52.487670332193375, 51.25011093914509, 50.526876747608185, 50.782253444194794, 50.01472882926464, 43.36279436945915, 40.24749353528023, 39.085990861058235, 39.18268047273159, 38.63806329667568, 36.826651096343994, 37.65880644321442, 37.246133387088776, 37.968615218997, 43.012947142124176, 45.32994121313095, 49.08811815083027, 49.321402832865715, 51.319696605205536, 47.61803783476353, 48.65488059818745, 50.65825089812279, 50.46603061258793, 49.453426748514175, 50.48291690647602, 39.553886353969574, 44.68556798994541, 47.606399059295654, 49.67713214457035, 47.76107355952263, 48.4652403742075, 45.78511878848076, 41.959313079714775, 39.87328581511974, 38.24763424694538, 37.00728200376034, 37.22684942185879, 36.623513996601105, 36.27093851566315, 36.81331381201744, 36.52131848037243, 37.83165156841278, 37.79951669275761, 37.69468791782856, 39.5353851467371, 44.56547163426876, 48.60237121582031, 51.07875153422356, 50.90113386511803, 50.0294454395771, 47.45818801224232, 42.74342380464077, 37.763696014881134, 37.17551037669182, 36.09959810972214, 35.20242065191269, 38.82771871984005, 39.91299748420715, 41.54593326151371, 47.17979595065117, 49.06822241842747, 50.4314486682415, 49.68794256448746, 52.258139848709106, 52.01154448091984, 49.55632522702217, 48.1572251021862, 51.39721244573593, 51.79008096456528, 51.9544031471014, 52.527218610048294, 49.97414320707321, 50.77086545526981, 55.44412449002266, 56.178131103515625, 50.74625797569752, 32.874167785048485, 13.904758226126432, 1.8050372111611068, 2.111085494980216, 5.67279065027833, 10.981254950165749, 6.930170254781842, 3.7116056866943836, 1.421647046227008, 0.39361280389130116, 0.8271763671655208, 21.599994152784348, 37.50223584473133, 28.40268362313509, 35.77617846429348, 47.59241960942745, 26.180144883692265, 2.7170330425724387, 0.02202000581746688, 0.07662432821234688, 0.03594279827666469, 0.020663090836023912, 0.019246458941779565, 0.0727092320448719, 0.058081182214664295, 0.08025082541280426, 0.0802406802540645, 0.013157544508430874, 0.014961395663704025, 0.0496135963476263, 0.0368145286483923, 0.008249649563367711, 0.0394428260915447, 0.02330271716346033, 0.04211669882351998, 0.04845644340093713, 0.13321060978341848, 0.13273584307171404, 0.22478939179563895, 0.09546432585921139, 0.0679279159521684, 0.20253184862667695, 0.12528652092441916, 0.1629688317188993, 0.13615347765153274, 0.16220232675550506, 0.14760710211703554, 0.16828964464366436, 0.18100548419170082, 0.06903674395289272, 0.1790501328650862, 0.26196177292149514, 0.17471429833676666, 0.08848126541124657, 0.16145976347615942, 0.14536921516992152, 0.0974086117639672, 0.13401002157479525, 0.1131102598446887, 5.576951717957854, 42.01833911240101, 66.28943413496017, 54.26974430680275, 44.73101355135441, 55.47694332897663, 60.56177727878094, 32.97923594713211, 5.044434042647481, 0.4138068499742076, 1.711292916443199, 11.6446328535676, 19.51076366007328, 4.7524425107985735, 6.641731057316065, 28.767397552728653, 50.46055130660534, 56.12818278372288, 51.69987380504608, 50.862501338124275, 55.84728665649891, 58.29081393778324, 56.28977291285992, 56.95203937590122, 54.35568429529667, 53.924939408898354, 50.50693541765213, 49.18962590396404, 46.09055019915104, 43.07465583086014, 41.35522149503231, 40.902498587965965, 38.62639792263508, 38.342769742012024, 40.00675745308399, 41.28970541059971, 40.73176234960556, 39.915398955345154, 42.622491493821144, 46.52264401316643, 50.87615020573139, 55.31837023794651, 51.69626399874687, 51.350094974040985, 51.766602024436, 52.764280289411545, 46.45181581377983, 42.729862332344055, 40.85847035050392, 41.07524871826172, 42.19346411526203, 39.57426846027374, 39.81864854693413, 40.074770003557205, 38.56130741536617, 45.30052699148655, 45.195280238986015, 51.23002141714096, 53.47024440765381, 52.031067833304405, 49.927128329873085, 49.62146133184433, 53.22012662887573, 53.442209511995316, 50.93748651444912, 51.94575861096382, 42.70710155367851, 44.27625015377998, 47.51073159277439, 51.880348920822144, 49.928602650761604, 52.163638919591904, 48.26028697192669, 45.739848017692566, 41.85628540813923, 40.21136127412319, 37.97599822282791, 39.78044919669628, 38.27674448490143, 37.419369891285896, 38.97011987864971, 37.79514692723751, 38.876242116093636, 40.874638482928276, 39.58558425307274, 39.722886085510254, 47.216528579592705, 49.12490397691727, 52.823097333312035, 53.33031311631203, 51.28427870571613, 50.21220803260803, 45.502417758107185, 38.686104118824005, 38.66395130753517, 37.47397296130657, 37.0069894194603, 40.59867449104786, 41.31400890648365, 42.28409305214882, 48.24325628578663, 50.78630782663822, 52.14278183877468, 53.84236603975296, 55.11201851069927, 52.283598482608795, 50.11966399848461, 48.4768221527338, 51.51352420449257, 53.518194034695625, 53.95169757306576, 54.07025121152401, 52.00286194682121, 52.33834594488144, 59.204288721084595, 57.20466122031212, 53.79665829241276, 34.34709034860134, 14.461786486208439, 2.6101352786645293, 1.7855211021378636, 10.357779655605555, 19.105146825313568, 13.949735462665558, 7.741335527971387, 4.440066972747445, 0.5995766550768167, 1.3091973052360117, 24.035604558885098, 38.673747181892395, 36.536939442157745, 47.11112603545189, 55.38871206343174, 29.900378957390785, 3.2651239447295666, 0.11121786490548402, 0.21278010652167723, 0.14771224959986284, 0.0922993480344303, 0.1635845025884919, 0.17424671561457217, 0.1759660936659202, 0.17704559199046344, 0.16302801057463512, 0.1828369265422225, 0.07126777345547453, 0.14063760812859982, 0.12670716969296336, 0.17692530469503254, 0.1895698535372503, 0.10209370098891668, 0.19186206569429487, 0.16247611987637356], [0.030365955535671674, 0.04905579815385863, 0.05726743955165148, 0.015363030215667095, 0.06409545792848803, 0.01923334704770241, 0.07114969776012003, 0.027349336742190644, 0.04678102275647689, 0.08441330908681266, 0.032390567794209346, 0.043410651851445436, 0.01805356045224471, 0.0766098489111755, 0.02998597963596694, 0.07518499958678149, 0.06514878070447594, 0.13966080819955096, 0.029311552934814245, 0.05119186615047511, 0.06540620204759762, 0.08138928737025708, 0.10064393034554087, 1.547317465301603, 22.141221910715103, 47.56297118961811, 38.67219686508179, 35.07017634809017, 60.78652001917362, 57.80205376446247, 29.43250436335802, 9.190600086003542, 0.09202786299283616, 0.348670388921164, 4.343447182327509, 5.361823886632919, 9.801991079002619, 2.4297302216291428, 25.017973445355892, 32.71352380514145, 41.88889145851135, 51.326186656951904, 55.27621529996395, 52.537527456879616, 55.00162683427334, 49.81434278190136, 50.508679524064064, 46.29094384610653, 44.31531585752964, 43.52121166884899, 41.78905941545963, 37.572839856147766, 37.140632048249245, 36.409330889582634, 37.27557420730591, 35.58488912880421, 36.33757933974266, 37.060710936784744, 35.70105269551277, 34.86714564263821, 36.66719265282154, 38.5086764395237, 43.288690745830536, 47.2480782866478, 51.45859055221081, 49.48780730366707, 50.89061602950096, 50.74545621871948, 50.440963357687, 45.113953202962875, 42.12512098252773, 37.14626334607601, 38.98430451750755, 37.34388694167137, 37.01367326080799, 34.76493112742901, 34.36304569244385, 34.96012665331364, 37.423230484128, 40.23463502526283, 45.215457156300545, 45.820506289601326, 48.57989922165871, 45.67205585539341, 47.87735112011433, 46.546635925769806, 47.53145568072796, 45.967398807406425, 52.87516213953495, 37.69140489399433, 43.19241151213646, 47.101003378629684, 45.79181782901287, 48.13044413924217, 46.49358317255974, 45.13697996735573, 46.20959401130676, 44.28356096148491, 38.19526545703411, 33.51701349020004, 34.305315390229225, 35.3163081407547, 34.658449441194534, 33.37263643741608, 33.38250070810318, 34.07748721539974, 34.74387265741825, 34.61205393075943, 35.87042100727558, 35.87612830102444, 40.68532504141331, 45.46348884701729, 48.22344794869423, 48.160565122962, 49.01631340384483, 45.89751675724983, 37.60052137076855, 35.04512809216976, 35.08474476635456, 34.11651112139225, 36.182585656642914, 33.83862063288689, 34.2896032333374, 36.54036685824394, 40.898535400629044, 46.36796951293945, 47.62975640594959, 48.25792349874973, 49.85624313354492, 49.83655259013176, 51.33116438984871, 49.38504941761494, 47.92829878628254, 52.521860897541046, 51.21055506169796, 50.461809039115906, 51.914300099015236, 52.68442377448082, 49.754518792033195, 47.04203054308891, 25.86100570857525, 5.578001411631703, 0.7859881804324687, 0.8940156118478626, 4.290297534316778, 6.56375496648252, 4.904218716546893, 2.716052932664752, 1.0966706718318164, 0.1278338092379272, 0.7216955709736794, 17.29053709656, 26.985296979546547, 26.963581144809723, 28.57666488736868, 36.082643419504166, 12.554067503660917, 0.67909344448708, 0.12010946942609735, 0.08987383131170645, 0.014480360587185714, 0.008684669628564734, 0.08587174059357494, 0.05056015004811343, 0.03530864050844684, 0.0792839628411457, 0.04337233476690017, 0.01782607549102977, 0.055628825721214525, 0.08347241426235996, 0.052643499584519304, 0.0375953644834226, 0.049031173693947494, 0.03422446294280235, 0.04137193878705148, 0.042240997427143157, 0.010738178334577242, 0.08347425478859805, 0.01480009264923865, 0.02190879498812137, 0.01881119118479546, 0.025763075864233542, 0.06919131104950793, 0.020095264371775556, 0.05364120952435769, 0.050735141048789956, 0.022056825619074516, 0.006843827050033724, 0.032297970028594136, 0.0629886708338745, 0.06578420012374409, 0.03962513466831297, 0.03629295097198337, 0.028877737931907177, 0.02563836722401902, 0.018090576922986656, 0.06515736735309474, 0.017604546264919918, 0.06639691724558361, 2.1597197977826, 27.541389539837837, 54.64033842086792, 44.857744351029396, 36.50363802909851, 58.25143665075302, 59.29522544145584, 32.28668510913849, 9.569958429783583, 0.22619026975007728, 0.3359066363191232, 3.277947069145739, 13.582099489867687, 14.634243082255125, 3.57105431612581, 26.903831250965595, 36.02034196257591, 47.972809597849846, 51.81064546108246, 53.82200673222542, 54.62415888905525, 57.345531061291695, 51.231165155768394, 52.857527285814285, 48.19378674030304, 48.40157479047775, 45.5036298930645, 44.26232010126114, 37.803905457258224, 38.353386372327805, 38.65347146987915, 37.84086987376213, 36.82982012629509, 37.76097536087036, 37.520512863993645, 38.39361861348152, 35.883750692009926, 38.35391454398632, 39.41992074251175, 44.64729264378548, 49.407764598727226, 51.86399079859257, 50.41056118905544, 50.02974562346935, 52.87147253751755, 52.15144917368889, 47.15719856321812, 42.28282772004604, 38.66959400475025, 39.51776169240475, 39.03180196881294, 37.96045325696468, 36.06655888259411, 36.68026775121689, 35.63694253563881, 38.97138141095638, 42.066554725170135, 45.56782744824886, 47.52233996987343, 50.58713771402836, 47.46619038283825, 49.95813846588135, 49.72358085215092, 49.59903873503208, 48.85756552219391, 52.893104776740074, 40.60116335749626, 42.93444715440273, 47.582483142614365, 47.64872498810291, 49.84710842370987, 48.4651567786932, 46.48190639913082, 47.90224738419056, 45.257243514060974, 38.744715973734856, 35.66184259951115, 36.35632373392582, 37.1874987334013, 35.90992368757725, 36.016192585229874, 34.9247657507658, 35.47988176345825, 35.902168303728104, 36.57752126455307, 37.2039670497179, 37.283701971173286, 42.78944693505764, 46.65442854166031, 50.23410625755787, 50.02587743103504, 50.64252734184265, 47.958795949816704, 39.55780774354935, 37.563602551817894, 35.816881880164146, 35.842709094285965, 38.112407103180885, 36.441986337304115, 35.37334308028221, 39.51061047613621, 43.390263095498085, 49.050538167357445, 48.58273766934872, 48.74915733933449, 51.483722403645515, 51.83264248073101, 51.369029358029366, 48.85663077235222, 49.172545820474625, 54.21298675239086, 52.345227375626564, 53.27460050582886, 52.51105807721615, 54.42729525268078, 52.679009065032005, 47.28507310152054, 28.380152732133865, 6.744739729911089, 1.4205244439654052, 3.074785745702684, 7.5002840626984835, 7.890002075582743, 8.979674354195595, 3.3622289216145873, 1.666402481496334, 0.14387844828888774, 0.9297146368771791, 20.599834620952606, 29.111394993960857, 32.04308018088341, 36.32786326110363, 42.53342047333717, 15.701006390154362, 1.1091056233271956, 0.09561155311530456, 0.06772361011826433, 0.046329919423442334, 0.023443780883098952, 0.06490715968539007, 0.05009325752325822, 0.03878125709888991, 0.07759890169836581, 0.020009576001029927, 0.014773941220482811, 0.043167891635675915, 0.037886223290115595, 0.043034442351199687, 0.044864867959404364, 0.0345812838349957, 0.05233804644376505, 0.028437881846912205, 0.03833308153843973, 0.142817429441493, 0.14582421106752008, 0.1790163799887523, 0.12291554463445209, 0.13379432377405465, 0.08798991912044585, 0.10059453299618326, 0.1488013067864813, 0.15867339971009642, 0.18211940332548693, 0.13149016303941607, 0.16102867957670242, 0.16176336124772206, 0.17766469158232212, 0.23126029613194987, 0.1974466527462937, 0.08609143857029267, 0.27559339301660657, 0.103685889771441, 0.25664508633781224, 0.21317736333003268, 0.14417095837416127, 0.3921195730799809, 3.459016140550375, 34.285370260477066, 64.18185442686081, 49.597815200686455, 45.69069005548954, 67.82113194465637, 64.26829218864441, 37.91937366127968, 11.620184015482664, 0.2462135921814479, 1.59739438444376, 8.56360998004675, 14.378721993416548, 13.837215900421143, 4.149835696443915, 30.305241532623768, 38.0081444978714, 50.21060831844807, 53.99652756750584, 55.20390138030052, 55.84300048649311, 59.05675023794174, 53.513212502002716, 54.666093438863754, 50.623562559485435, 49.31870877742767, 48.81723068654537, 46.84601426124573, 39.32256996631622, 40.502421855926514, 40.28393737971783, 40.269296765327454, 38.19909185171127, 40.67695789039135, 40.38726523518562, 39.0396523475647, 36.08519688248634, 40.58889761567116, 42.03499361872673, 47.35890693962574, 51.32017157971859, 55.152683928608894, 52.37881377339363, 53.05416293442249, 54.766518250107765, 54.6991478651762, 50.44819436967373, 46.26645416021347, 40.68562902510166, 41.6374247521162, 41.282557994127274, 40.415839701890945, 37.74748608469963, 37.158992663025856, 37.75860048830509, 40.8805737644434, 43.75516891479492, 49.564319998025894, 49.02917191386223, 52.586594223976135, 49.13721151649952, 51.031493470072746, 51.96031183004379, 51.83298446238041, 50.22150233387947, 55.07167227566242, 44.149682745337486, 43.64145241677761, 48.179598301649094, 50.00246688723564, 51.741363778710365, 50.16368843615055, 48.310843259096146, 51.038808077573776, 50.0742906332016, 41.89125873148441, 37.25032456219196, 38.50587218999863, 39.508148208260536, 37.90521942079067, 36.673044338822365, 36.90650001168251, 36.79319769144058, 37.05820307135582, 39.10912781953812, 40.359424129128456, 37.80472241342068, 43.75588707625866, 49.45192202925682, 51.00232623517513, 52.15434081852436, 52.30336122214794, 49.80184905230999, 41.378240659832954, 39.07177962362766, 38.25050689280033, 38.378168642520905, 39.82641153037548, 37.0933435857296, 37.10096977651119, 40.359389930963516, 44.06260281801224, 50.457367077469826, 51.4013846218586, 52.35519424080849, 54.2562360316515, 52.34171636402607, 52.90828496217728, 49.06118519604206, 48.926927000284195, 55.16474828124046, 54.117266088724136, 55.34173138439655, 55.08610010147095, 56.969157457351685, 55.92974603176117, 49.52923648059368, 30.123934261500835, 8.074723463505507, 1.1524719838052988, 2.4352824361994863, 10.37059921771288, 15.256052166223526, 13.661357536911964, 7.421912793070078, 3.38628685567528, 0.291304481215775, 1.4600513479672372, 24.6736017242074, 39.21700403094292, 39.388051852583885, 43.17669555544853, 49.898280277848244, 18.61151911318302, 1.1909732990898192, 0.2704647369682789, 0.18510280729969963, 0.10347632953198627, 0.08240412236773409, 0.19147159211570397, 0.1639704787521623, 0.16922841692576185, 0.14217070711310953, 0.1993554417276755, 0.1580726311658509, 0.2442375200917013, 0.1964848887291737, 0.1357399529661052, 0.11774328741012141, 0.2970106469001621, 0.1078716546180658, 0.1854200754314661, 0.14336425869259983], [0.032100057796924375, 0.04051508105476387, 0.032098495576065034, 0.019016756814380642, 0.04560342735203449, 0.00654045238661638, 0.033752360541257076, 0.07444021728588268, 0.0388800555083435, 0.010451043253851822, 0.025259313442802522, 0.07381028975942172, 0.03305815189378336, 0.0337632664013654, 0.02287677078129491, 0.1314138702582568, 0.018624644944793545, 0.058969703677576035, 0.0437170326767955, 0.03342380063259043, 0.019566823684726842, 0.01620010971237207, 0.11686292957165278, 1.5388077031821012, 18.362436778843403, 40.08543223142624, 44.56526264548302, 54.917852729558945, 74.25453633069992, 47.89167255163193, 29.43869423121214, 10.935045629739761, 0.36062439903616905, 0.3422558878082782, 2.301075062714517, 11.561971139162779, 6.357155777513981, 4.170441040769219, 11.967568974941969, 28.747583515942097, 49.61631640791893, 54.03142489492893, 53.10440003871918, 55.062678158283234, 52.08140753209591, 48.27823340892792, 44.17886517941952, 41.6592051833868, 39.20050911605358, 39.67372812330723, 37.960335463285446, 38.181669786572456, 38.63083988428116, 36.61744572222233, 37.85899870097637, 36.58364653587341, 38.42604987323284, 38.65870758891106, 37.55347229540348, 37.744187861680984, 37.50003956258297, 38.452207669615746, 42.366480231285095, 45.728501826524734, 48.19092929363251, 50.63957490026951, 50.24775892496109, 48.925099298357964, 49.19787526130676, 45.744221583008766, 42.274604961276054, 39.04122546315193, 38.455593287944794, 37.37865887582302, 36.357152089476585, 35.6102679669857, 36.61464527249336, 35.90875715017319, 34.84975777566433, 38.160873502492905, 41.22800052165985, 42.90401838719845, 44.90616135299206, 45.1213476061821, 46.54765047132969, 44.08134341239929, 47.135467529296875, 46.83556102216244, 51.72128565609455, 39.57487262785435, 40.73784202337265, 43.78805235028267, 45.826551765203476, 48.812070563435555, 49.77097570896149, 48.37324731051922, 46.85813941061497, 46.44449360668659, 42.21820078790188, 37.36624874174595, 34.40626837313175, 36.442560106515884, 36.008338406682014, 34.93028685450554, 35.53758926689625, 34.799228087067604, 36.302674412727356, 36.42238698899746, 40.285727083683014, 36.98685809969902, 40.73896296322346, 46.77840828895569, 48.24821121990681, 50.88493533432484, 49.71180148422718, 43.38085860013962, 42.24632687866688, 34.15111966431141, 35.22097125649452, 33.9253281801939, 35.133644342422485, 33.90684977173805, 35.470880046486855, 35.07397994399071, 36.03514216840267, 38.45447234809399, 42.013277783989906, 44.28717836737633, 49.568796157836914, 46.4859189838171, 51.29434056580067, 50.38227930665016, 50.06454035639763, 49.59525413811207, 49.6649955958128, 53.76733146607876, 53.0541667342186, 51.246634125709534, 50.58349750936031, 34.42168414592743, 13.497710768133402, 4.493209971114993, 0.045937794566270895, 2.6565474132075906, 6.093523548915982, 7.53228547051549, 5.809175306931138, 1.9009964307770133, 1.246632831171155, 0.1874262935598381, 1.7017849953845143, 25.687919296324253, 38.94525781273842, 29.308594912290573, 35.30497334897518, 36.121298745274544, 7.4333668034523726, 0.041450636126683094, 0.05976828426355496, 0.020239962759660557, 0.07212294280179776, 0.010108722071890952, 0.03216032389900647, 0.046380010680877604, 0.056294821624760516, 0.05138148117111996, 0.03845156170427799, 0.07758951353025623, 0.013221364570199512, 0.014590893279091688, 0.039818441873649135, 0.07752939956844784, 0.011237427570449654, 0.0659992077271454, 0.010264297561661806, 0.036597405924112536, 0.02782614807074424, 0.047991643732530065, 0.07166297451476566, 0.02293522047693841, 0.07503340850234963, 0.026512114382057916, 0.09476914870901965, 0.0285384280141443, 0.05407727694546338, 0.05243570565653499, 0.008778196934144944, 0.08228168284404092, 0.04352625990577508, 0.04982014717825223, 0.026135980951949023, 0.03848784159345087, 0.010659575618774397, 0.06584210248547606, 0.04261367430444807, 0.03782498126383871, 0.006994752984610386, 0.047807605951675214, 0.0695321497914847, 1.8545116251334548, 22.86053281277418, 50.44535592198372, 49.744833111763, 54.94651839137077, 75.37581816315651, 54.222319051623344, 36.059472262859344, 12.723166979849339, 0.3690952726174146, 0.5417461926117539, 2.1834932221099734, 17.574402764439583, 10.483758095651865, 5.2772902976721525, 17.484150007367134, 32.76645116508007, 52.47771106660366, 54.5038041472435, 55.15653312206268, 55.99658444523811, 54.982038885354996, 51.540799140930176, 47.462603375315666, 42.03944317996502, 43.13050903379917, 41.98692999780178, 41.186833530664444, 39.66682389378548, 39.89118665456772, 38.46452280879021, 39.27725739777088, 38.83859373629093, 40.32134257256985, 40.47596387565136, 40.790207013487816, 39.02056597173214, 39.990209341049194, 40.35993330180645, 45.109708830714226, 47.433618530631065, 51.63219563663006, 52.51973681151867, 53.33838388323784, 49.73015829920769, 51.41713097691536, 48.64936329424381, 46.60515658557415, 41.11695908010006, 41.34220339357853, 39.443190693855286, 37.90371470153332, 37.91791073977947, 35.754496827721596, 37.80705168843269, 36.07556439936161, 38.78130041062832, 41.88794530928135, 46.41686148941517, 48.89002338051796, 47.61147938668728, 47.30635195970535, 45.30862435698509, 50.276242196559906, 47.416914626955986, 51.669426038861275, 41.438961401581764, 42.15984731912613, 44.992048144340515, 48.53346191346645, 49.90916669368744, 53.22806820273399, 49.977832809090614, 50.03041058778763, 47.456660494208336, 44.32926870882511, 38.27652029693127, 35.91298632323742, 37.701527550816536, 37.22956247627735, 37.07562133669853, 37.5037557631731, 37.0316044986248, 38.52358303964138, 37.570179998874664, 39.96116369962692, 37.09816172719002, 42.902027294039726, 47.642603516578674, 50.904390290379524, 51.48110814392567, 52.53289170563221, 46.645867601037025, 43.30594941973686, 36.53390720486641, 37.28213645517826, 35.794740468263626, 37.03825794160366, 36.39921963214874, 37.35109895467758, 36.76194056868553, 38.466415107250214, 39.45785790681839, 45.11544272303581, 46.60385325551033, 52.642135843634605, 49.29237239062786, 52.51660957932472, 49.734581261873245, 50.32205633819103, 49.30024936795235, 52.17618964612484, 54.450701996684074, 54.30205777287483, 53.33516925573349, 53.13988633453846, 37.67467059195042, 17.00459484010935, 4.919736608862877, 1.7146036075428128, 5.065787471830845, 8.395235314965248, 7.752836085855961, 4.692123597487807, 2.1474502561613917, 0.44061206630431116, 0.20241939841071144, 1.6483418131247163, 25.434942170977592, 37.72522687911987, 32.41884581744671, 39.76336911320686, 41.34607918560505, 11.130346599966288, 0.0150614594349463, 0.03845648585411254, 0.09469742755754851, 0.04420836783538107, 0.041361953190062195, 0.020587861181411427, 0.05052986671216786, 0.011136225530208321, 0.05361449591873679, 0.030259770901466254, 0.05706917851057369, 0.04586354269122239, 0.11192093108547851, 0.031571967774652876, 0.0431456309161149, 0.11375953516107984, 0.06398736411938444, 0.017590323004696984, 0.03654598993307445, 0.13635508948937058, 0.12962418113602325, 0.14894604042638093, 0.14195211493643, 0.19998840463813394, 0.07401832859613933, 0.18077325134072453, 0.20069161924766377, 0.10980371735058725, 0.09967887861421332, 0.09337823037640192, 0.16422585176769644, 0.1445792434969917, 0.14389732852578163, 0.0855076800507959, 0.1640474543091841, 0.1285655816900544, 0.16931371937971562, 0.1691470033256337, 0.15990126819815487, 0.14095811202423647, 0.131044622103218, 0.32826100126840174, 2.4093001428991556, 28.146615363657475, 57.082049399614334, 58.11419941484928, 65.36229908466339, 77.93724551796913, 54.972083419561386, 40.79848676919937, 14.046383276581764, 0.5431488517206162, 1.3452101103030145, 6.249378360807896, 21.368274986743927, 12.812638878822327, 8.218080271035433, 16.809222623705864, 34.91836689412594, 56.11472770571709, 55.13024613261223, 56.00542277097702, 58.58581490814686, 57.307244315743446, 54.273547902703285, 48.84196735918522, 46.07864923775196, 45.17987586557865, 44.967170879244804, 41.34315334260464, 42.40677706897259, 42.7263019233942, 40.31921088695526, 40.642695128917694, 40.387086644768715, 42.34960913658142, 43.18858131766319, 41.32858492434025, 41.46066203713417, 41.842811331152916, 41.758509054780006, 46.62254445254803, 49.0398683398962, 52.661248818039894, 53.11231501400471, 55.57336315512657, 51.84434585273266, 52.480192333459854, 50.35993650555611, 48.52864757180214, 43.52361313998699, 42.4467509239912, 41.07375539839268, 39.52133730053902, 38.46390724182129, 39.435917884111404, 40.692544654011726, 37.9870518296957, 40.33760569989681, 44.74102981388569, 46.973018646240234, 49.81301285326481, 49.71346199512482, 50.29570855200291, 47.99208976328373, 52.22320832312107, 52.77368478477001, 53.21945406496525, 43.87370355427265, 42.92680196464062, 45.4815910756588, 47.60639525949955, 51.373345926404, 54.94355455040932, 51.1430174857378, 52.233460173010826, 49.28204454481602, 45.682607889175415, 42.07437850534916, 38.080405220389366, 39.94062200188637, 40.02522446215153, 39.625611305236816, 40.27397811412811, 38.42787377536297, 39.956242963671684, 40.260903015732765, 40.916234850883484, 40.00048778951168, 44.87067125737667, 50.517255663871765, 52.21055880188942, 53.65559086203575, 53.38804341852665, 48.17272067070007, 45.31383387744427, 37.3379098623991, 38.08135136961937, 36.219390481710434, 38.05858679115772, 37.169480100274086, 38.23621965944767, 38.97145740687847, 39.32758569717407, 41.207500621676445, 46.04174181818962, 48.2810452580452, 52.69041605293751, 51.54987305402756, 54.42794881761074, 51.63366995751858, 49.850851222872734, 50.61165779829025, 50.74107885360718, 56.242495849728584, 56.95801645517349, 55.23799695074558, 53.72135393321514, 38.674005568027496, 16.620885729789734, 5.988707598298788, 0.9760516067035496, 5.918377647176385, 14.588384293019772, 16.965994611382484, 14.535477831959724, 8.065214473754168, 2.875151108019054, 0.5649134900886565, 3.1459317030385137, 33.49881626665592, 47.758231312036514, 41.93759724497795, 48.710976988077164, 48.5732077807188, 13.617245703935623, 0.3436982666607946, 0.10100023544509895, 0.12655085854930803, 0.1213943051698152, 0.11065898317610845, 0.13199415552662686, 0.18608328828122467, 0.11700690622092225, 0.129698425589595, 0.11151319515192881, 0.16264335543382913, 0.20513107243459672, 0.21573806967353448, 0.09454186598304659, 0.14156976045342162, 0.1454950834158808, 0.1583911312627606, 0.07125028845621273, 0.1844419990084134], [0.0700080074602738, 0.04127542248170357, 0.03359864691447001, 0.06807195939472876, 0.03445643604209181, 0.04398564560688101, 0.021151331238797866, 0.03656824694189709, 0.00603159744059667, 0.040228367142844945, 0.03090501264523482, 0.0394125724415062, 0.08508828497724608, 0.04506293604208622, 0.02896487534599146, 0.08147499058395624, 0.024569956585764885, 0.06518645954201929, 0.011149999791086884, 0.011275162069068756, 0.08131385548040271, 0.020596065623976756, 0.05135589191922918, 0.4128516762284562, 17.064171843230724, 39.17441971600056, 41.060737296938896, 45.50848223268986, 57.514394000172615, 37.6592206209898, 30.425856560468674, 15.327226147055626, 0.8938744256738573, 0.4101931251352653, 0.9686828521080315, 4.647921044379473, 1.1838331259787083, 0.8485750970430672, 5.94481092877686, 22.53579843789339, 43.35999771952629, 52.13267058134079, 54.39160376787186, 54.461147636175156, 49.029460698366165, 49.74881149828434, 44.2198383808136, 40.613463297486305, 39.267510920763016, 38.91533441841602, 39.79716069996357, 37.37143166363239, 35.75374446809292, 38.66916082799435, 40.89494839310646, 41.30225233733654, 39.80609402060509, 40.3628895431757, 37.47403375804424, 38.15527640283108, 38.90266589820385, 38.93102377653122, 40.37553146481514, 44.9613381922245, 46.52840830385685, 46.085367277264595, 46.68356537818909, 48.279354348778725, 45.39582207798958, 44.60133410990238, 41.09365493059158, 38.00100088119507, 37.1485660225153, 38.2085495442152, 35.85681013762951, 36.777379140257835, 37.602998837828636, 36.4342537522316, 36.80612459778786, 35.75219415128231, 38.18032085895538, 40.76307646930218, 42.90907971560955, 42.011826261878014, 42.82650254666805, 42.226746529340744, 45.09637534618378, 46.52058072388172, 52.08983547985554, 38.797384947538376, 41.74858778715134, 45.75362987816334, 44.268654361367226, 46.93785533308983, 45.75817443430424, 48.54665860533714, 50.14356851577759, 47.50256963074207, 46.35693110525608, 39.35730770230293, 34.92177151143551, 35.64964905381203, 36.11496068537235, 35.37202075123787, 34.27244335412979, 35.494556576013565, 36.15848734974861, 40.497774705290794, 43.29876780509949, 44.315441250801086, 45.73637120425701, 47.639001309871674, 49.98558819293976, 49.19513180851936, 43.75138811767101, 45.34422464668751, 40.15881769359112, 35.75562156736851, 36.46798834204674, 35.300045013427734, 34.98182348906994, 34.68123681843281, 34.57492232322693, 33.08611661195755, 35.210461020469666, 35.45864090323448, 35.47181859612465, 40.471947491168976, 42.3850916326046, 48.03414590656757, 48.6007297039032, 51.44055671989918, 45.57518385350704, 54.95293624699116, 50.97116410732269, 49.58103910088539, 58.07641804218292, 51.68612614274025, 51.618884950876236, 29.487981386482716, 10.895853582769632, 6.051158672198653, 13.784297090023756, 5.285796616226435, 5.792261939495802, 4.066531816497445, 5.64458048902452, 2.6660941634327173, 0.2776418987195939, 0.366486445418559, 2.6819295762106776, 28.53858333081007, 33.2207015901804, 31.12925011664629, 38.58179211616516, 29.87788036465645, 4.360284553840756, 0.043791496063931845, 0.02292646313435398, 0.08540624330635183, 0.05128149161464535, 0.07962681280332617, 0.08473406531265937, 0.022277236057561822, 0.04822270399017725, 0.012349106345936889, 0.04941782521200366, 0.035361603877390735, 0.016326432523783296, 0.07487573922844604, 0.06607270261156373, 0.05790812450868543, 0.016616987049928866, 0.04845368261158001, 0.020291729415475857, 0.06669663358479738, 0.0714520932524465, 0.006894592734170146, 0.03851789857435506, 0.03023381985258311, 0.05600020012934692, 0.10900491412030533, 0.009282258070015814, 0.03822108774329536, 0.05291243905958254, 0.02884351935790619, 0.04919241640891414, 0.04101845384866465, 0.029342259294935502, 0.08933863893616945, 0.013482108879543375, 0.11755873754736967, 0.04685183477704413, 0.07380810784525238, 0.06140239325759467, 0.050479092678870074, 0.04088321227754932, 0.0788967843982391, 0.0798426812980324, 0.6255835283081979, 20.78085880726576, 46.82564355432987, 48.908885568380356, 49.492340460419655, 66.24630644917488, 43.86078044772148, 35.37526197731495, 16.94224588572979, 0.8245005388744175, 0.21795830834889784, 1.1280250456184149, 6.908701881766319, 4.6131419856101274, 2.9622718831524253, 8.65807006135583, 24.715135395526886, 43.827125653624535, 52.26986601948738, 54.8037638515234, 55.022153332829475, 52.21006862819195, 51.19340278208256, 45.25521822273731, 42.35407009720802, 40.96391089260578, 40.56014455854893, 40.399382784962654, 38.790233731269836, 36.87033735215664, 39.79874141514301, 42.11134672164917, 41.653383895754814, 41.49948835372925, 40.712250396609306, 39.01786431670189, 40.54015763103962, 39.55545946955681, 41.37471444904804, 43.42709071934223, 47.76428058743477, 48.83128233253956, 48.751991987228394, 50.73481298983097, 50.68867966532707, 47.873558923602104, 45.87346404790878, 42.69001007080078, 40.45319929718971, 39.756502881646156, 38.78787025809288, 38.442054614424706, 37.89352364838123, 38.61494913697243, 37.849183827638626, 37.789405435323715, 38.106791004538536, 40.28063915669918, 41.6085235029459, 44.49222296476364, 44.38850753009319, 43.73920977115631, 43.09764079749584, 46.933436170220375, 49.163027331233025, 54.37609300017357, 41.00672319531441, 42.98641316592693, 44.76149931550026, 45.04086412489414, 46.0988337546587, 46.86664715409279, 49.414589032530785, 52.19899982213974, 48.92201766371727, 48.40897299349308, 40.81059291958809, 37.48262129724026, 36.63820020854473, 37.807378470897675, 37.098408713936806, 36.552640199661255, 36.88061200082302, 37.40566402673721, 41.702648252248764, 42.79755190014839, 45.079359859228134, 46.096249893307686, 50.276815965771675, 51.7919884622097, 50.11247478425503, 47.13188052177429, 46.74049772322178, 42.35612578690052, 36.40384778380394, 38.44233579933643, 37.39206835627556, 36.35399825870991, 37.31631562113762, 36.19647391140461, 34.303951263427734, 37.65539422631264, 37.20577955245972, 37.6103400439024, 42.24941611289978, 45.48490829765797, 50.52876904606819, 50.916868820786476, 50.75060874223709, 46.75048738718033, 54.57252345979214, 50.90877145528793, 51.28585942089558, 58.782587349414825, 52.27332383394241, 51.573496386408806, 29.46430865675211, 13.129344284534454, 6.791073968634009, 12.245760597288609, 5.047952178865671, 5.252568824216723, 6.727482480928302, 1.88772136811167, 0.49412088410463184, 0.31204931961838156, 0.44099320366512984, 3.8115168130025268, 31.511619798839092, 41.35819673538208, 34.06368635594845, 45.70449471473694, 36.118452697992325, 6.26087749376893, 0.01797875938791549, 0.03591202883399092, 0.07644416444236413, 0.06512352541903965, 0.010585102027107496, 0.028290730660955887, 0.04510713093623053, 0.027567515171540435, 0.02611262556456495, 0.05432805235614069, 0.028155027102911845, 0.007585810526506975, 0.02489315447746776, 0.057532111677573994, 0.02897695936553646, 0.012205373677716125, 0.01756226054567378, 0.055707055507809855, 0.04765595178469084, 0.14910540921846405, 0.12412882992066443, 0.1141752491821535, 0.23140710778534412, 0.1793007116066292, 0.18098102300427854, 0.14034727995749563, 0.11956406509852968, 0.15147596248425543, 0.2504344086628407, 0.12948952586157247, 0.09410836268216372, 0.14656180195743218, 0.16312227817252278, 0.20547167368931696, 0.1903819857398048, 0.12558709073346108, 0.17596170015167445, 0.11899391014594585, 0.12613473634701222, 0.12571309256600216, 0.1375886279856786, 0.17604575579753146, 0.8901130431331694, 22.996664308011532, 55.84474079310894, 56.09682306647301, 55.350531712174416, 64.74784925580025, 49.42134507000446, 41.57741457223892, 21.87878519296646, 1.3548482931219041, 0.7499186752829701, 3.731346339918673, 16.66490826755762, 5.310323350131512, 1.8999151512980461, 10.644115190953016, 25.958031602203846, 45.521659925580025, 52.28321090340614, 56.120693385601044, 56.91342204809189, 54.936562925577164, 54.697855934500694, 48.68720926344395, 44.477768540382385, 43.35687428712845, 42.694018855690956, 42.76615038514137, 41.136094853281975, 38.79135847091675, 42.00469024479389, 44.16625365614891, 45.36803036928177, 43.76092940568924, 43.0140832811594, 40.52817687392235, 41.55764423310757, 41.37331232428551, 43.04991915822029, 44.5392682403326, 49.43657465279102, 49.62039738893509, 49.73683454096317, 53.184043765068054, 52.433561235666275, 49.47130098938942, 47.80217595398426, 46.00621372461319, 42.74397857487202, 40.91785356402397, 40.94641663134098, 40.07088661193848, 40.216688588261604, 40.50874091684818, 39.67570781707764, 40.192464888095856, 41.23463876545429, 41.97620317339897, 43.42544160783291, 48.15807245671749, 47.646866887807846, 46.30399614572525, 45.27492396533489, 49.3911898881197, 51.696248799562454, 55.64375437796116, 43.40787135064602, 43.417788818478584, 44.89274427294731, 45.731545463204384, 46.790058463811874, 46.932706609368324, 50.209217593073845, 53.32425244152546, 51.77591152489185, 50.11935621500015, 42.96847812831402, 39.49321120977402, 38.09188820421696, 39.06707167625427, 38.698605448007584, 37.60728120803833, 38.85713294148445, 39.495540484786034, 43.63607570528984, 46.01312555372715, 46.362748593091965, 48.445713222026825, 52.77696020901203, 51.81507982313633, 50.035190731287, 49.12232391536236, 48.85576441884041, 44.51311804354191, 38.02895598113537, 40.89357286691666, 38.33146534860134, 38.71600091457367, 38.390852361917496, 37.909817174077034, 36.71182505786419, 38.936035707592964, 38.988628685474396, 39.2165594547987, 44.361916556954384, 46.79187476634979, 51.24075964093208, 52.37959273159504, 53.03259529173374, 47.22803056240082, 53.637663424015045, 53.246694803237915, 51.71256132423878, 57.551635801792145, 53.09905372560024, 54.697255566716194, 35.31679451465607, 14.442686811089516, 12.377983052283525, 21.758185364305973, 15.53900683298707, 14.244118016213179, 12.643993478268385, 16.138448417186737, 8.317070659250021, 0.8885899186134338, 0.6906372250523418, 4.72496428526938, 38.25804568827152, 43.75495232641697, 43.32603134214878, 53.467299565672874, 42.083163633942604, 7.351306406781077, 0.09761041656020097, 0.12521580909378827, 0.2826697414275259, 0.1982615457382053, 0.1392179389949888, 0.162584028148558, 0.09912843510392122, 0.2549466962227598, 0.10245560188195668, 0.16751377377659082, 0.09264516658731736, 0.14244887890527025, 0.17293002689257264, 0.2412977395579219, 0.17898727295687422, 0.12788650172296911, 0.1535756466910243, 0.13724510266911238, 0.2054766015498899], [0.05750611424446106, 0.027875248561031185, 0.05721850604459178, 0.07786571120959707, 0.010635060625645565, 0.015631249807483982, 0.036548943680827506, 0.04200954754196573, 0.06369548485963605, 0.04035976067825686, 0.02817974989739014, 0.054365597607102245, 0.018858304574678186, 0.06404955609468743, 0.05096429027616978, 0.08010221034055576, 0.015012659514468396, 0.0547726804506965, 0.03697993481182493, 0.02242102345917374, 0.04215186549117789, 0.02554756916651968, 0.009529203070997028, 0.3614249388920143, 7.216048864647746, 38.12524661421776, 44.64938633143902, 42.5373000651598, 34.88057792186737, 29.920039102435112, 38.89852412045002, 23.791382163763046, 2.2581924637779593, 0.5499285785481334, 0.8070445724297315, 4.085220638662577, 4.1175369545817375, 0.6862817681394517, 2.1356782503426075, 9.767161197960377, 31.70579507946968, 46.27522028982639, 54.64329466223717, 54.2596672475338, 51.96665748953819, 48.28280456364155, 45.86188606917858, 42.768897637724876, 41.691887229681015, 42.645472660660744, 41.07057496905327, 39.60369028151035, 41.28047190606594, 43.96123565733433, 46.35434344410896, 46.3956206291914, 45.82900643348694, 41.61274127662182, 40.37768974900246, 37.27827586233616, 39.24997866153717, 38.25200781226158, 39.61509346961975, 40.48691488802433, 41.736717224121094, 42.33847573399544, 40.94026856124401, 40.36341391503811, 42.76863545179367, 42.12318308651447, 37.0452381670475, 37.076472491025925, 38.13030034303665, 36.086956188082695, 37.00250945985317, 35.04090651869774, 35.49221210181713, 33.81437413394451, 35.12880340218544, 36.06653608381748, 37.19408757984638, 38.86067055165768, 40.98772041499615, 40.19131734967232, 41.21426045894623, 39.25335668027401, 45.13684317469597, 46.802536994218826, 53.131374791264534, 40.635448917746544, 40.745023638010025, 48.77150394022465, 48.95118489861488, 50.32733045518398, 50.54392263293266, 47.465510219335556, 50.87905704975128, 46.375466510653496, 46.46261863410473, 40.2591323107481, 35.81064261496067, 35.704229325056076, 35.71268007159233, 35.17103053629398, 35.944710820913315, 36.35448843240738, 42.0895890891552, 45.89785113930702, 48.2466647028923, 47.506422623991966, 48.14149394631386, 50.48293590545654, 49.113755375146866, 44.697396755218506, 50.56369297206402, 42.29388512670994, 36.66770562529564, 34.42701146006584, 35.06173700094223, 33.403274193406105, 36.29297353327274, 35.226959735155106, 36.24324560165405, 35.87457038462162, 33.467433750629425, 34.81370151042938, 39.82695870101452, 35.225664004683495, 41.929693669080734, 41.59250736236572, 49.27883371710777, 49.85043704509735, 52.5815024971962, 36.37744300067425, 54.592202603816986, 41.875189393758774, 52.301161140203476, 47.177793458104134, 37.46519163250923, 29.016039110720158, 10.827954076230526, 2.7472257474437356, 8.01901275292039, 7.525434913113713, 4.640326676890254, 5.771211544051766, 1.0593607113696635, 0.20846267725573853, 0.3863145236391574, 0.7957724772859365, 4.470014115795493, 27.134862653911114, 45.77768638730049, 43.297149091959, 33.88782039284706, 17.496938221156597, 2.742741513065994, 0.06663530992227606, 0.046546455851057544, 0.0665077570010908, 0.06041806424036622, 0.037923037525615655, 0.04039838204334956, 0.019101109319308307, 0.02516507182008354, 0.006851772204754525, 0.037849294021725655, 0.03344450655276887, 0.016500061683473177, 0.022605970370932482, 0.04177168550086208, 0.0331707060104236, 0.026907027859124355, 0.05627762235235423, 0.008449511788057862, 0.0480546891776612, 0.09244693152140826, 0.041036168913706206, 0.06091448311053682, 0.07486974267521873, 0.015203329312498681, 0.023440582226612605, 0.017720273062877823, 0.03942597562854644, 0.004281848850951064, 0.02612422533275094, 0.07251377261127345, 0.05663037998601794, 0.08715575997484848, 0.06567447358975187, 0.020750380390381906, 0.04526749791693874, 0.04916843019600492, 0.023415909527102485, 0.04778648442879785, 0.028504777183115948, 0.009469253309362102, 0.01541582938443753, 0.04039286788611207, 0.2875518857035786, 12.143147103488445, 41.10154330730438, 51.40659034252167, 49.74006436765194, 45.69498382508755, 38.498967960476875, 43.15396897494793, 24.80724435299635, 1.9915715768001974, 0.2510070498101413, 2.5751332193613052, 7.441038591787219, 8.775819092988968, 2.858850695192814, 4.426263738423586, 15.078346151858568, 37.03647963702679, 49.60177078843117, 56.10790327191353, 56.12875275313854, 52.86824271082878, 53.21995563805103, 48.33973690867424, 43.74664977192879, 41.89720921218395, 44.260815382003784, 42.587814554572105, 40.572379902005196, 43.18772256374359, 44.521280005574226, 47.017860040068626, 48.32149788737297, 48.09867024421692, 44.310113936662674, 41.2451945990324, 40.04990413784981, 41.12631797790527, 42.12254852056503, 41.029050797224045, 42.95523963868618, 44.047464430332184, 43.26513580977917, 43.42537321150303, 42.54021070897579, 44.36147578060627, 43.085200265049934, 39.52641002833843, 38.23917970061302, 39.816003888845444, 38.819568157196045, 37.48933173716068, 37.15205043554306, 36.992265209555626, 36.58871166408062, 37.699889838695526, 37.73869715631008, 38.36419299244881, 39.94715765118599, 41.05705909430981, 41.15331172943115, 42.76447467505932, 41.83308005332947, 45.58923929929733, 49.84411038458347, 54.79605786502361, 43.17919582128525, 41.82201884686947, 48.766640201210976, 50.914296358823776, 51.48143112659454, 50.60231409966946, 48.46810922026634, 51.863534823060036, 50.0617703050375, 48.772427290678024, 43.015029430389404, 37.1651217341423, 37.4038515239954, 38.79822090268135, 35.847390443086624, 38.264110162854195, 38.697419911623, 43.67535799741745, 45.08561052381992, 51.878240033984184, 48.85122366249561, 51.41575165092945, 52.15993031859398, 51.37595258653164, 48.970411866903305, 50.16529195010662, 45.74452556669712, 39.35229577124119, 36.280909180641174, 37.042403519153595, 35.456722006201744, 37.80732147395611, 36.21228486299515, 37.916060239076614, 36.527550145983696, 35.86853630840778, 37.126542404294014, 41.4875265955925, 38.36426138877869, 43.10337848961353, 45.74117794632912, 51.48303084075451, 52.943269684910774, 53.268809616565704, 43.182581439614296, 54.565258249640465, 42.95489005744457, 53.646186366677284, 46.77343435585499, 40.97546987235546, 34.00834232568741, 14.225133284926414, 5.454338947311044, 12.026879992336035, 5.54337814450264, 1.7105622868984938, 1.4423057064414024, 0.2942944457754493, 0.2667102712439373, 0.594185694353655, 1.4328094222582877, 5.264379540458322, 32.02356442809105, 47.5470994412899, 46.69301547110081, 39.475029185414314, 23.72712381184101, 3.252700986340642, 0.05468648741953075, 0.01443370083507034, 0.032022239902289584, 0.04261516602127813, 0.12032738624839112, 0.05546081090869848, 0.03859347147226799, 0.03552845351805445, 0.010366960705141537, 0.05633214794215746, 0.056963615425047465, 0.0355197889439296, 0.01822475536755519, 0.056901130301412195, 0.07533979674917646, 0.026444463910593186, 0.06401402206392959, 0.02030505838774843, 0.014168784728099126, 0.15153396874666214, 0.1539493922609836, 0.22984651965089142, 0.18910138023784384, 0.08878295586328022, 0.12834599503548816, 0.14304973650723696, 0.25912561104632914, 0.17027036257786676, 0.12629649485461414, 0.2729973307577893, 0.22684466588543728, 0.1493989137816243, 0.11047345367842354, 0.1371921578538604, 0.15439073264133185, 0.12982620857656002, 0.14260220661526546, 0.14670135540654883, 0.1296943734632805, 0.1155572097923141, 0.06589404540136456, 0.1268276944756508, 0.4291240655584261, 13.093247171491385, 48.09456266462803, 59.32868264615536, 54.66881789267063, 50.23371867835522, 42.92154684662819, 51.82711757719517, 30.052707083523273, 3.52799407672137, 0.8577389584388584, 3.8190259225666523, 12.298352625221014, 12.629022281616926, 2.1622226759791374, 4.309932980686426, 17.926757857203484, 44.51603248715401, 52.87485435605049, 56.73423506319523, 59.441350400447845, 57.41420477628708, 54.07584071159363, 51.28194183111191, 46.388294622302055, 44.98700961470604, 47.646566703915596, 44.97092887759209, 42.983791306614876, 45.246740877628326, 48.40779885649681, 50.05469128489494, 49.935609474778175, 51.543971970677376, 45.07246322929859, 43.763121888041496, 41.2606293708086, 44.171094596385956, 43.06942731142044, 42.84359782934189, 43.72186750173569, 45.88790327310562, 44.44843791425228, 44.604484140872955, 44.516408666968346, 46.58803470432758, 45.92747434973717, 40.99232196807861, 40.19059158861637, 41.539059430360794, 40.33942200243473, 39.09138277173042, 38.86127471923828, 38.62346448004246, 36.88678286969662, 39.68690201640129, 39.79000188410282, 40.07482700049877, 43.28877054154873, 44.47508968412876, 43.87036733329296, 45.247554033994675, 42.88518279790878, 50.12667082250118, 52.07109488546848, 56.243498995900154, 47.11503982543945, 42.78544954955578, 48.14222350716591, 51.5406509488821, 53.64760749042034, 52.49109394848347, 50.34707419574261, 53.21574166417122, 52.075821831822395, 49.689964056015015, 44.32381980121136, 38.946849927306175, 39.826878905296326, 40.86942136287689, 38.494423404335976, 39.619744420051575, 39.22883279621601, 45.753284096717834, 47.530106753110886, 54.88076291978359, 49.85661171376705, 53.718785271048546, 53.599555268883705, 51.93574234843254, 50.05797050893307, 53.115176260471344, 46.61885865032673, 40.27324855327606, 37.27527402341366, 38.23526211082935, 36.783458814024925, 39.91965472698212, 39.202192425727844, 41.27986393868923, 38.8884736597538, 37.50720977783203, 39.681126326322556, 43.262510150671005, 38.96062798798084, 45.000229105353355, 47.939245998859406, 53.953145295381546, 53.74034911394119, 53.9469288289547, 42.2448905557394, 55.50385348498821, 48.24484460055828, 54.66284841299057, 49.264318495988846, 42.38671414554119, 39.02482554316521, 17.573549710214138, 6.126951780170202, 11.44696556031704, 13.316145110875368, 11.56565124168992, 13.8784902356565, 4.172676745802164, 0.9883073146920651, 1.2627091747708619, 2.631482295691967, 6.7725851107388735, 36.89720191061497, 54.81956720352173, 51.919589415192604, 48.498648181557655, 26.673802994191647, 4.276456302031875, 0.18296598602319136, 0.13253069861093536, 0.16917925706366077, 0.18541884346632287, 0.18948382377857342, 0.11974282620940357, 0.15020268940133974, 0.16887019708519801, 0.07334630645345896, 0.12878352077677846, 0.10616387633490376, 0.1230082759866491, 0.1640016192686744, 0.16754700714955106, 0.2116589737124741, 0.08161383157130331, 0.18513972172513604, 0.06311819786787964, 0.07234992124722339], [0.08149115456035361, 0.038328717710101046, 0.04996211260731798, 0.06323974681436084, 0.015282717777154176, 0.036607836809707806, 0.0057285539605800295, 0.06559713438036852, 0.04078569407283794, 0.05521611368749291, 0.01064672069333028, 0.05520564940525219, 0.0325528940447839, 0.07395565422484651, 0.017326901397609618, 0.03887784019752871, 0.01795000487618381, 0.0349855465174187, 0.04370482805825304, 0.030506566545227543, 0.03631570150901098, 0.02546953604905866, 0.019636114302556962, 0.07730336365057155, 3.085769056342542, 26.08396254479885, 41.71066202223301, 39.59654666483402, 29.197435677051544, 20.80230675637722, 37.52446085214615, 25.164892561733723, 2.532530380412936, 0.07205818299553357, 1.596890555229038, 3.5533515410497785, 5.436539752408862, 5.898978263139725, 0.35694491991307586, 2.3523943964391947, 11.993675474077463, 31.749686524271965, 48.30722205340862, 52.59641669690609, 50.36640755832195, 50.41344903409481, 48.12827445566654, 45.98603680729866, 43.54730486869812, 42.407229244709015, 43.272397220134735, 46.881109178066254, 48.15034367144108, 49.35984157025814, 49.77582424879074, 50.245258659124374, 47.48975291848183, 44.35406997799873, 38.1818787753582, 36.99437789618969, 36.81446515023708, 36.95147059857845, 37.628465071320534, 39.37401540577412, 36.90419353544712, 35.297001376748085, 36.04889743030071, 36.44697546958923, 37.744187861680984, 37.836089730262756, 38.40547777712345, 38.96088257431984, 36.79366886615753, 37.293665036559105, 35.62680847942829, 35.990999937057495, 35.552978441119194, 34.73073676228523, 35.43160915374756, 36.03788562119007, 36.65083833038807, 35.667329505085945, 37.25624464452267, 36.87018536031246, 39.973729625344276, 39.888978973031044, 44.508828073740005, 47.51006282866001, 53.87357756495476, 38.218584805727005, 45.215654745697975, 51.617984399199486, 50.34810774028301, 46.68797314167023, 46.3946782797575, 48.98548945784569, 49.05312962830067, 46.90405614674091, 46.736952513456345, 41.470594704151154, 35.46076498925686, 35.59300549328327, 34.86774981021881, 35.54434530436993, 37.36786365509033, 41.892288476228714, 44.376196190714836, 48.19724075496197, 47.54127435386181, 47.59816110134125, 50.98289027810097, 47.5065366178751, 46.850308030843735, 46.009124368429184, 45.03127723932266, 37.25063614547253, 35.54619200527668, 34.984848126769066, 36.56230308115482, 35.80575607717037, 37.41564229130745, 39.226359128952026, 38.173857405781746, 37.318747490644455, 37.49864123761654, 34.06185865402222, 37.41301283240318, 35.828182473778725, 39.34552073478699, 43.77347633242607, 49.0685909986496, 47.93201878666878, 55.58734640479088, 47.22890831530094, 37.88861811161041, 48.704255148768425, 42.836477011442184, 48.905420154333115, 29.159207828342915, 11.97640160098672, 3.1128977006301284, 0.7249029551167041, 3.1408471008762717, 2.463428950868547, 1.8894076463766396, 1.8378490442410111, 0.15052506350912154, 0.19079600024269894, 0.7191290461923927, 1.2663866649381816, 9.492674376815557, 26.697513721883297, 35.914844423532486, 53.638202995061874, 41.88487507402897, 12.512945160269737, 0.8102462568785995, 0.09608182241208851, 0.017819038075685967, 0.06452076049754396, 0.0469460133172106, 0.02996046645421302, 0.06265716830966994, 0.05175133417651523, 0.04077597193827387, 0.02317434973519994, 0.06448509288020432, 0.08289953562780283, 0.03920342409401201, 0.07632978464243934, 0.04298389838368166, 0.05578730764682405, 0.031239196177921258, 0.0577654911467107, 0.02237141645309748, 0.043891827008337714, 0.08454929280560464, 0.03759684135729913, 0.023798247311788145, 0.04162095901847351, 0.01829069333325606, 0.027777914037869778, 0.03979756154876668, 0.04800231210538186, 0.03567001818737481, 0.04611840362485964, 0.03773184544115793, 0.031505107690463774, 0.02527105236367788, 0.032027828274294734, 0.07494274774217047, 0.05986831463815179, 0.06849393714219332, 0.03560888006177265, 0.023916297031973954, 0.03361861439771019, 0.01141819990152726, 0.03932781546609476, 0.05534218602406327, 0.04731894994620234, 4.6115911938250065, 32.643675953149796, 47.19909891486168, 45.85329852998257, 34.34870146214962, 25.392460450530052, 43.13728787004948, 30.694310255348682, 2.961144056171179, 0.05004564503906295, 1.2054815143346786, 4.415831873193383, 4.701549941673875, 4.999613547697663, 1.1477026459760964, 4.52671087346971, 18.000779785215855, 37.00740359723568, 49.3539746850729, 53.944610953330994, 53.312716260552406, 51.35484851896763, 50.04420384764671, 48.35547186434269, 45.44485844671726, 44.41351778805256, 44.66496929526329, 48.03955681622028, 50.420775040984154, 51.85610622167587, 51.87107361853123, 52.498389557003975, 49.04656358063221, 46.81765258312225, 40.61779506504536, 39.65316742658615, 39.647057354450226, 39.262700378894806, 40.77159561216831, 40.60432478785515, 37.65598699450493, 38.295135498046875, 38.27767923474312, 38.278910368680954, 41.30884878337383, 40.07154397666454, 39.63222295045853, 40.49094647169113, 38.556447476148605, 36.95788845419884, 39.30223345756531, 38.04331161081791, 37.80799023807049, 37.94109329581261, 37.55191057920456, 38.139666840434074, 38.43122899532318, 38.55662226676941, 39.73233997821808, 39.08224046230316, 39.97064799070358, 42.063511088490486, 47.66111232340336, 49.030824825167656, 56.463051214814186, 41.4347018301487, 45.582973435521126, 53.19439820945263, 52.26114548742771, 49.50825780630112, 49.72282849252224, 49.56821098923683, 51.45127974450588, 49.451401457190514, 48.5275000333786, 43.40393856167793, 37.14191257953644, 36.22534096240997, 36.81374318897724, 35.87523154914379, 39.03246693313122, 42.78148256242275, 46.40142671763897, 49.753215461969376, 49.66103620827198, 50.01034386456013, 52.832486629486084, 51.13514430820942, 48.1609071046114, 47.37939924001694, 47.5824261456728, 38.005404844880104, 37.85742178559303, 37.51898534595966, 37.75134667754173, 37.41403117775917, 39.511955603957176, 39.64923083782196, 40.54727844893932, 38.532744348049164, 40.154691115021706, 36.281346157193184, 39.55588884651661, 37.77834042906761, 41.5089650452137, 43.58723692595959, 50.596705600619316, 48.48934628069401, 57.60215789079666, 44.44946005940437, 41.64646066725254, 49.766172766685486, 47.43113346397877, 53.21191526949406, 35.25016888976097, 19.387783259153366, 4.083885485306382, 1.4460970717482269, 2.767657726071775, 1.160813842434436, 0.6433108833152801, 0.2248902348219417, 0.022297530085779727, 0.2981760265538469, 1.5862131281755865, 1.5093038300983608, 10.79277841374278, 31.518780514597893, 42.41132542490959, 56.91290907561779, 47.98651546239853, 15.78798372298479, 1.2003989308141172, 0.1133991927781608, 0.04231874852848705, 0.0497362956230063, 0.057384465108043514, 0.051785803225357085, 0.05002508754841983, 0.0318642589263618, 0.047019370904308744, 0.05073370128229726, 0.06618253304623067, 0.0841042491083499, 0.045954377856105566, 0.03294911926786881, 0.05660385562805459, 0.026692727151385043, 0.03193257361999713, 0.019411809444136452, 0.0436537349014543, 0.04076215685927309, 0.20164799527265131, 0.13153452862752602, 0.16327193967299536, 0.13163050316506997, 0.16073394304839894, 0.14042679365957156, 0.19551153236534446, 0.1389826336526312, 0.13467744982335716, 0.1658788076019846, 0.14042991067981347, 0.12903099734103307, 0.17163377691758797, 0.112760552437976, 0.2906958607491106, 0.13229919306468219, 0.13272304844576865, 0.09743026763317175, 0.16805567516712472, 0.08429861016338691, 0.1509441394591704, 0.11825727662653662, 0.13367310137255117, 0.27054192032665014, 5.607792288064957, 33.594749718904495, 56.144138127565384, 51.76841452717781, 42.58289381861687, 32.439045533537865, 50.43063171207905, 35.37881098687649, 4.093580665066838, 0.21270706434734166, 3.804817534983158, 6.773415841162205, 11.72855420038104, 11.327394526451826, 1.633917549625039, 4.951075427234173, 17.43869874626398, 41.36461079120636, 55.18747866153717, 55.303881615400314, 55.40033183991909, 55.08368343114853, 52.66702450811863, 51.70601427555084, 48.18648733198643, 46.740828305482864, 46.49487890303135, 50.61883561313152, 52.604464665055275, 53.04094344377518, 53.34127552807331, 55.46889916062355, 51.288713067770004, 49.230515509843826, 42.26098649203777, 40.53250104188919, 40.48978753387928, 40.88962867856026, 40.905173644423485, 43.55787590146065, 40.34894049167633, 39.23607520759106, 39.78434018790722, 40.1075242459774, 41.690758690238, 42.23607122898102, 41.5199388563633, 43.449270129203796, 41.12052708864212, 39.27808575332165, 40.299413949251175, 39.937198385596275, 38.76396954059601, 39.030988812446594, 39.504074826836586, 41.52408063411713, 40.07281690835953, 40.0311179459095, 41.64259247481823, 41.05054624378681, 42.76151463389397, 43.706755712628365, 48.66862826049328, 51.000380739569664, 58.94902601838112, 45.06387189030647, 48.653094694018364, 55.212899297475815, 54.94340255856514, 50.89793063700199, 51.66546285152435, 52.15716026723385, 53.4422817081213, 51.42808958888054, 50.22318184375763, 46.48096784949303, 39.52815793454647, 39.134996831417084, 38.240623623132706, 37.87396989762783, 39.78098876774311, 44.80092599987984, 49.07587520778179, 51.7066640406847, 51.08827382326126, 50.69733940064907, 55.56911498308182, 51.74952954053879, 51.876199543476105, 48.971878588199615, 49.77325178682804, 38.687031269073486, 40.036137476563454, 37.887402176856995, 39.46666203439236, 38.83874572813511, 41.77465058863163, 41.538827642798424, 41.5557861328125, 40.702534317970276, 43.06250408291817, 37.99694649875164, 42.0612958073616, 39.029807075858116, 43.68863448500633, 45.54190143942833, 52.88354068994522, 50.01798905432224, 58.165139481425285, 46.261810809373856, 42.60995216667652, 50.14990657567978, 50.68653278052807, 55.96367061138153, 43.15230466425419, 19.513357020914555, 4.0307187382131815, 1.2059072102420032, 6.157884495332837, 8.253299631178379, 7.759547950699925, 6.797602493315935, 1.1637278110720217, 0.7625864236615598, 3.882056465372443, 2.825764683075249, 14.130539260804653, 36.519608572125435, 46.80004432797432, 60.13114258646965, 56.1312872171402, 19.104519858956337, 1.4060567202977836, 0.231168418249581, 0.12829174404032528, 0.11037626201868989, 0.11432816128944978, 0.10968106260406785, 0.11899149074451998, 0.10249112849123776, 0.15174372936598957, 0.12737404875224456, 0.22660144924884662, 0.1837852131575346, 0.09677392707089894, 0.15324910171329975, 0.21100330108311027, 0.17551889031892642, 0.20766768866451457, 0.13129586877766997, 0.1650859267101623, 0.15202228707494214], [0.03422396941459738, 0.034860847154050134, 0.1052140980027616, 0.05602993056527339, 0.026195430691586807, 0.013389810756052611, 0.06544747287989594, 0.0301133804168785, 0.05957038687483873, 0.0078476476483047, 0.04843616050493438, 0.036156529386062175, 0.09495308258919977, 0.026555791628197767, 0.03451207114267163, 0.023535668042313773, 0.012537712973426096, 0.043230079900240526, 0.04170895175775513, 0.03762349559110589, 0.04991763569705654, 0.0737899771775119, 0.08359282772289589, 0.05600742493697908, 0.6470522575546056, 12.156115807592869, 37.54864655435085, 43.882967457175255, 34.792677238583565, 20.504452139139175, 21.579437255859375, 21.65820322930813, 5.228068213909864, 0.05189594907278661, 1.1972933099605143, 6.775851985439658, 3.808570308610797, 3.761021322570741, 2.1403512870892882, 0.8911968162283301, 6.50630347430706, 19.652925431728363, 41.73935808241367, 52.83685639500618, 52.45071731507778, 50.577847212553024, 48.79054851830006, 47.83157877624035, 47.71393708884716, 47.84875005483627, 49.39509987831116, 49.274281561374664, 51.30756385624409, 52.07117088139057, 52.786414101719856, 52.09483981132507, 46.909030079841614, 44.20373484492302, 37.67502397298813, 36.842473447322845, 37.28613004088402, 37.94756434857845, 37.7520040422678, 36.73049345612526, 36.701573207974434, 36.40848733484745, 36.25570893287659, 35.538383424282074, 36.88383422791958, 37.674480602145195, 38.34299772977829, 38.72750669717789, 38.989544436335564, 38.20003800094128, 36.26211538910866, 36.83510564267635, 36.57917037606239, 34.96920816600323, 36.688281521201134, 37.2094501554966, 36.771443858742714, 36.52702197432518, 37.967520877718925, 38.93720984458923, 41.72871485352516, 42.614500522613525, 46.04235738515854, 46.514136269688606, 52.86580704152584, 39.57755908370018, 42.64709897339344, 51.91673956811428, 47.37642019987106, 47.81083568930626, 44.94731314480305, 46.23864725232124, 44.5661062002182, 46.0202007740736, 41.33273050189018, 36.770262122154236, 34.09851908683777, 35.29138147830963, 35.33269286155701, 36.73488222062588, 39.60076063871384, 43.06764520704746, 45.04450432956219, 47.46498204767704, 47.266085520386696, 49.049500823020935, 47.815847620368004, 46.53753161430359, 47.447578981518745, 45.06647475063801, 40.17408527433872, 35.25535561144352, 34.19283002614975, 34.13178630173206, 35.46910174190998, 37.213983312249184, 39.03637312352657, 42.65184871852398, 41.292437463998795, 42.62030281126499, 39.668598398566246, 40.179112404584885, 37.231948748230934, 39.29974839091301, 37.84841626882553, 43.112725988030434, 45.500821843743324, 49.71369378268719, 47.668381333351135, 52.37419702112675, 47.836507111787796, 50.86601234972477, 45.8250280469656, 26.321259811520576, 13.549986463040113, 2.2881992161273956, 1.5133368386887014, 0.47223854111507535, 3.4144967794418335, 0.9541090310085565, 0.3501723473891616, 0.12721703998977318, 0.026799926672538277, 0.2674798486987129, 0.7216943835373968, 3.351655276492238, 15.081343241035938, 27.890003733336926, 34.12300117313862, 39.14519548416138, 27.605178616940975, 5.72731202468276, 0.2227269930881448, 0.036520070425467566, 0.0468312587327091, 0.015876245743129402, 0.011904168404726079, 0.0655095609545242, 0.010648472161847167, 0.03871325039654039, 0.04020613610919099, 0.013969539413665188, 0.0354063628037693, 0.061944710250827484, 0.04352924705017358, 0.024116803069773596, 0.07212945885839872, 0.0014745065413990233, 0.052806375024374574, 0.06226144032552838, 0.02897269201639574, 0.0320582229323918, 0.08314098595292307, 0.033268450570176356, 0.05337497146683745, 0.04015098340460099, 0.0208633872171049, 0.01848192809120519, 0.03793414005485829, 0.015483206188946497, 0.018126211143680848, 0.027623651221801993, 0.0400138530676486, 0.06170874439703766, 0.040368495756410994, 0.03454017256444786, 0.06514687338494696, 0.05889952619327232, 0.024729548022150993, 0.04063379128638189, 0.0276298240351025, 0.06526608456624672, 0.021040532301412895, 0.06078295598854311, 0.06511741012218408, 0.07537270357715897, 1.127986335195601, 17.07350604236126, 42.997364178299904, 51.181900799274445, 38.29561807215214, 25.25324922055006, 33.20665754377842, 27.420666217803955, 6.121961222961545, 0.02957732715003658, 0.7580450142268091, 2.7644739719107747, 2.927350332029164, 2.633234951645136, 3.9388627046719193, 1.4469540445134044, 7.886203229427338, 23.089958801865578, 45.21590553224087, 54.11882780492306, 54.37049590051174, 53.190852999687195, 50.86847461760044, 48.34121122956276, 47.9171159863472, 50.35702966153622, 51.02280333638191, 51.37921281158924, 52.6276396214962, 55.21148197352886, 55.408885180950165, 52.54438228905201, 49.906145855784416, 45.928234308958054, 40.639746487140656, 38.57331097126007, 38.554072603583336, 38.375098407268524, 39.67016011476517, 38.84160317480564, 37.921463549137115, 37.48759903013706, 38.72953578829765, 37.75812931358814, 38.19869287312031, 38.48178908228874, 40.384677574038506, 40.62509827315807, 40.30995458364487, 38.22738133370876, 37.584338039159775, 38.15296232700348, 37.31256902217865, 36.502570286393166, 38.9300662279129, 37.57680304348469, 37.8643412142992, 37.4096842110157, 39.22515079379082, 40.89945115149021, 43.30222561955452, 43.75649884343147, 48.82827669382095, 49.06007185578346, 53.78475733101368, 40.59006415307522, 44.85323019325733, 54.384091570973396, 50.11181741952896, 50.29517278075218, 47.32008062303066, 47.0999888330698, 47.02970780432224, 48.08551914989948, 43.878715485334396, 38.98584343492985, 36.692913472652435, 36.2505754083395, 36.969333440065384, 39.03444662690163, 41.60126209259033, 46.25618331134319, 47.497014328837395, 49.84489694237709, 48.34851063787937, 50.84721475839615, 49.329481199383736, 49.17229503393173, 48.41510586440563, 48.20287585258484, 42.07061290740967, 38.061710223555565, 36.26801647245884, 36.980523839592934, 37.27381110191345, 38.543265983462334, 40.381668135523796, 44.6884710341692, 42.882336750626564, 43.16216513514519, 42.09563456475735, 41.84251494705677, 39.45171743631363, 41.17304407060146, 39.615226462483406, 45.361570715904236, 48.32726217806339, 51.67291805148125, 50.189819633960724, 51.773890033364296, 47.41674363613129, 49.961934462189674, 47.55756787955761, 34.00692880153656, 18.83468683809042, 3.5641833348199725, 2.4986737221479416, 1.3838000083342195, 3.4798967326059937, 1.7647914332337677, 0.3369820973603055, 0.21248795266728848, 0.03344081807881594, 0.7370307168457657, 1.1530879070051014, 3.8427549367770553, 17.99021255224943, 33.34159590303898, 40.30628018081188, 47.03368239104748, 36.85318507254124, 8.213055040687323, 0.17323108651908115, 0.02516005861252779, 0.015400698848679895, 0.058581193079589866, 0.032961824836093, 0.08748106556595303, 0.04372206443804316, 0.08787815910181962, 0.027718959681806155, 0.060897469375049695, 0.03634122396761086, 0.03589266991184559, 0.049736496002878994, 0.03972786646045279, 0.025804296601563692, 0.0372849426639732, 0.04970801979652606, 0.04216097164317034, 0.0497195639036363, 0.05792478572402615, 0.13547546637710184, 0.1558611201471649, 0.2512820006813854, 0.1600116552435793, 0.07491172596928664, 0.05947594858298544, 0.20431377488421276, 0.08640405343612656, 0.12144966938649304, 0.14736508775968105, 0.11238549326662906, 0.13842254964401945, 0.1508165049017407, 0.1674617492244579, 0.15171824401477352, 0.19280125357909128, 0.17411569686373696, 0.20139410655247048, 0.1366931971278973, 0.18856097798561677, 0.2928396878996864, 0.14512294088490307, 0.12441868311725557, 0.14998727361671627, 1.2069406360387802, 17.446934804320335, 47.52499222755432, 59.24992047250271, 47.95760281383991, 32.93005518615246, 32.94816881418228, 31.520429626107216, 8.930470794439316, 0.3918785532005131, 1.8309967056848109, 12.641825694590807, 9.685111250728369, 9.334336873143911, 4.894014839082956, 1.7280713911168277, 9.589341189712286, 24.86999798566103, 46.16798244416714, 55.57071089744568, 56.18261866271496, 55.21209754049778, 53.60217712819576, 51.19720257818699, 50.17977297306061, 52.838782891631126, 53.036216497421265, 54.16344881057739, 54.8792278021574, 56.60122700035572, 56.97217829525471, 54.724576100707054, 51.06997400522232, 47.59765952825546, 42.023746222257614, 41.45747020840645, 40.21560184657574, 41.332544311881065, 40.46460248529911, 39.560129418969154, 38.79635140299797, 39.423990324139595, 40.186085030436516, 39.667070880532265, 39.50947053730488, 40.18305279314518, 42.40553833544254, 43.34519371390343, 41.63542605936527, 40.365708991885185, 38.876910880208015, 40.30452087521553, 38.97521160542965, 38.61772298812866, 40.60589790344238, 40.15361197292805, 41.906685903668404, 39.92381550371647, 42.02017821371555, 44.5278612524271, 47.13200971484184, 46.34190671145916, 50.38370802998543, 52.386869341135025, 55.5950827896595, 44.84107464551926, 46.686643213033676, 55.51546186208725, 52.119975462555885, 51.99523575603962, 49.26585741341114, 48.96648667752743, 49.44808803498745, 49.96264882385731, 44.914296716451645, 39.614933878183365, 37.683467119932175, 37.65616938471794, 38.972205966711044, 40.774882435798645, 43.83053407073021, 47.655047848820686, 49.349829107522964, 51.534358486533165, 50.79916253685951, 52.854552045464516, 52.01226644217968, 50.98949812352657, 50.24207442998886, 50.345820263028145, 43.55622299015522, 38.59250754117966, 39.061018601059914, 38.31180140376091, 38.188691809773445, 40.19097916781902, 43.04787486791611, 46.18632785975933, 44.705585315823555, 45.6894551217556, 43.9323990046978, 43.89147900044918, 41.876040548086166, 43.038413375616074, 40.21852008998394, 46.78826116025448, 48.013668805360794, 54.069723039865494, 52.05227069556713, 51.821155697107315, 48.55497255921364, 50.469955801963806, 48.18581476807594, 34.15019251406193, 20.344102643430233, 4.4068629294633865, 2.9902915796265006, 2.2385102324187756, 12.990407589823008, 3.0276682740077376, 2.674629455432296, 0.9181433671619743, 0.07008067856077105, 2.614110577851534, 2.0759606547653675, 7.070969799533486, 24.071164950728416, 39.1683704406023, 46.051169112324715, 51.47006593644619, 40.22785238921642, 8.945199754089117, 0.38083388179074973, 0.13757341395830736, 0.14301666640676558, 0.10704995613195933, 0.13018018333241343, 0.24887986161047593, 0.15617286670021713, 0.12768952088663355, 0.11206493742065504, 0.13737140136072412, 0.07348161481786519, 0.1233888790011406, 0.1655476464657113, 0.13383876357693225, 0.10969887414830737, 0.07238513615448028, 0.15103325655218214, 0.15871743875322863, 0.10230173982563429, 0.13904917461331934], [0.09613689719117247, 0.042744344245875254, 0.02133397192665143, 0.04470810781640466, 0.03671354461403098, 0.06355933786835521, 0.10974515447742306, 0.06466009130235761, 0.023828484263503924, 0.09817415935685858, 0.05041987300501205, 0.06732121764798649, 0.05521558676264249, 0.04606145492289215, 0.07896052746218629, 0.02089430137857562, 0.03173481352860108, 0.13114843372022733, 0.022477281963801943, 0.0302549358093529, 0.04390133392007556, 0.050200130499433726, 0.021022277323936578, 0.033932335063582286, 0.10441481979796663, 3.406233172863722, 22.743645384907722, 40.63941590487957, 42.02399700880051, 25.78475520014763, 22.500986605882645, 24.181611724197865, 8.109787981957197, 0.25574394094292074, 0.33183295803610235, 0.7951980549842119, 3.4899305691942573, 1.8246591207571328, 2.3607743717730045, 0.6459671189077199, 0.4349303914932534, 9.102833345532417, 30.542472302913666, 47.61756666004658, 54.707477018237114, 52.44560658931732, 50.821049362421036, 49.14348877966404, 50.143378525972366, 47.73415960371494, 52.35637217760086, 52.54963740706444, 52.60590098798275, 51.71857260167599, 52.968086153268814, 48.584151193499565, 46.75897613167763, 42.161249443888664, 37.226625233888626, 37.87832826375961, 37.87765569984913, 37.06653982400894, 40.0438928604126, 41.72787509858608, 38.53411227464676, 35.41060768067837, 37.33734369277954, 38.25000151991844, 37.24284656345844, 37.95492075383663, 35.952960178256035, 37.86062501370907, 36.926809921860695, 37.222019881010056, 36.805737018585205, 36.91416420042515, 37.85125091671944, 36.157385408878326, 36.39726273715496, 36.50674246251583, 38.111669942736626, 36.53585270047188, 40.8696873486042, 41.92253865301609, 42.51424290239811, 42.514368295669556, 45.92216223478317, 47.84528464078903, 52.11769178509712, 38.71889255940914, 45.975990146398544, 50.914064571261406, 46.659372076392174, 45.484881699085236, 41.50127425789833, 41.38890668749809, 39.914559200406075, 38.04728999733925, 35.99861852824688, 34.04243789613247, 34.39646489918232, 34.17488358914852, 34.27117042243481, 35.58150351047516, 41.24469682574272, 44.49101082980633, 46.168123036623, 47.54874475300312, 47.95168653130531, 46.204544082283974, 44.159653410315514, 42.594665586948395, 40.587351098656654, 36.58297397196293, 34.61519256234169, 34.025893583893776, 33.7870080024004, 36.16289131343365, 36.07099324464798, 36.73208937048912, 42.88881540298462, 46.933360174298286, 47.0541100949049, 45.779259502887726, 43.87719936668873, 41.716095730662346, 40.63415698707104, 39.53138396143913, 40.58222517371178, 42.77273163199425, 45.20849213004112, 47.8440573066473, 49.40170392394066, 48.771253153681755, 49.25468601286411, 46.3879070430994, 35.93065157532692, 20.458229519426823, 4.678517477586865, 3.667037640698254, 1.544776945374906, 0.5984815419651568, 1.2256548693403602, 0.14945963630452752, 0.10123803440365009, 0.06840466419816948, 0.13019867765251547, 0.30847884714603424, 0.2611683279974386, 8.53890085592866, 15.878299176692963, 22.321381643414497, 33.83244216442108, 42.087700590491295, 15.830860622227192, 0.5675692507065833, 0.025963029002014082, 0.014719029713887721, 0.026152373138756957, 0.041296265699202195, 0.01976482311874861, 0.03283324775111396, 0.024668508231115993, 0.044900249849888496, 0.012399308925523655, 0.01684866329014767, 0.0588768906891346, 0.01863761954155052, 0.09391102561494336, 0.03064604949031491, 0.02147693925508065, 0.04384441861475352, 0.024100193804770242, 0.053256535829859786, 0.03150675896904431, 0.06745478938682936, 0.08649920418974943, 0.007836147142370464, 0.1153437903849408, 0.0846548262052238, 0.0063678631613584, 0.013796420480503002, 0.13172477076295763, 0.04376200682600029, 0.03244285951950587, 0.033329340076306835, 0.048276966117555276, 0.004562010990412091, 0.08641296662972309, 0.052685660994029604, 0.0828076280595269, 0.05433842015918344, 0.046580839552916586, 0.011877548495249357, 0.030126950587145984, 0.07490626376238652, 0.03925012002582662, 0.030258351544034667, 0.023510685496148653, 0.026925607526209205, 0.10944336754619144, 5.48378974199295, 30.500596649944782, 46.37084975838661, 48.5140335559845, 30.459507554769516, 24.18288465589285, 27.551601491868496, 8.448054380714893, 0.36194275016896427, 0.1449288395815529, 0.9987885178998113, 3.211109605617821, 1.6669172351248562, 3.521351320669055, 1.6565821459516883, 1.655198426451534, 10.869013722985983, 35.06406247615814, 51.16349458694458, 56.70527681708336, 53.16424302756786, 54.11742568016052, 52.21307806670666, 52.89539225399494, 50.608606562018394, 53.33437129855156, 54.58281710743904, 53.88286046683788, 53.5642209649086, 53.75521391630173, 51.46178998053074, 49.71255384385586, 44.6630048006773, 38.67770656943321, 39.85586754977703, 38.92600044608116, 39.613459557294846, 40.503580793738365, 41.35276682674885, 39.33080792427063, 37.91262902319431, 38.44096027314663, 38.4524280577898, 38.75274874269962, 39.6138509362936, 39.087628573179245, 38.595969155430794, 40.48386365175247, 39.80757974088192, 38.81447263062, 38.710654601454735, 39.790913835167885, 37.46535882353783, 39.07749831676483, 37.710419073700905, 38.43960374593735, 38.43513898551464, 43.35674129426479, 44.75650638341904, 45.27138635516167, 44.06438112258911, 47.80131720006466, 50.80985516309738, 53.187243193387985, 41.45076356828213, 47.82756619155407, 53.45046266913414, 47.64498978853226, 47.25702680647373, 43.39269116520882, 42.23740875720978, 42.517480328679085, 39.76275734603405, 39.044101908802986, 36.08252562582493, 36.153285428881645, 36.391555443406105, 35.86320139467716, 38.62712748348713, 42.34619311988354, 46.52588903903961, 49.40352402627468, 49.56139415502548, 47.243522331118584, 48.35091590881348, 47.43818588554859, 46.155982688069344, 43.70425544679165, 40.18209524452686, 36.8036737293005, 35.07105030119419, 36.238788440823555, 36.41989052295685, 37.43091367185116, 38.39901052415371, 44.942422807216644, 49.56471897661686, 47.23270431160927, 48.784871622920036, 45.614082366228104, 43.63286107778549, 42.90334962308407, 41.54817894101143, 41.88551343977451, 45.24627350270748, 47.446309849619865, 49.63705949485302, 50.852948650717735, 49.99453291296959, 50.18332198262215, 47.13638328015804, 38.70649002492428, 22.21501585096121, 6.871194094419479, 5.21993950009346, 1.6778098256327212, 0.4857952636666596, 0.6020439101848751, 0.2716748235980049, 0.01953414877789328, 0.03784217682550661, 0.034158244816353545, 0.10643548012012616, 0.5057584424503148, 9.485880341380835, 21.397713907063007, 28.639116436243057, 36.51016987860203, 46.6865786164999, 22.242524474859238, 2.0288355834782124, 0.08758190859225579, 0.06592789475689642, 0.03529783854901325, 0.04258630760887172, 0.04955664393492043, 0.042255766165908426, 0.09983156807720661, 0.03878417373925913, 0.014277927748480579, 0.008344461712113116, 0.00842771676616394, 0.03691552752570715, 0.04788088932400569, 0.06345924441120587, 0.03691898593388032, 0.02962643135106191, 0.019846752511512022, 0.0838814044254832, 0.01677293639659183, 0.029480252378562, 0.2147139355656691, 0.05986660398775712, 0.1594547476270236, 0.1428933659917675, 0.08334167010616511, 0.1546290807891637, 0.24855180265149102, 0.11255205346969888, 0.11275599565124139, 0.23960460384842008, 0.12262344273040071, 0.16789250657893717, 0.14142621424980462, 0.14676676830276847, 0.1634627755265683, 0.179550756001845, 0.2592803933657706, 0.19532228470779955, 0.15258853090927005, 0.17986640625167638, 0.16125294176163152, 0.1326580363092944, 0.12160831087385304, 0.09257781668566167, 0.22055247070966288, 5.318620204925537, 31.815688982605934, 51.98796674609184, 55.77244587242603, 39.011685848236084, 32.37491637468338, 34.17092800140381, 11.91995657980442, 0.6827546074055135, 0.978838341543451, 4.210351249203086, 13.510875161737204, 11.31014820188284, 7.316619968041778, 1.6811895067803562, 1.1169307096861303, 12.120463270694017, 35.20734138786793, 50.47803416848183, 58.603898137807846, 55.71224570274353, 55.05855917930603, 54.46424067020416, 55.074788108468056, 52.493818402290344, 55.517722740769386, 56.99430450797081, 55.518406704068184, 54.567693918943405, 55.51694378256798, 53.07388387620449, 50.494369491934776, 45.84413722157478, 40.79000562429428, 42.06094242632389, 41.50465987622738, 41.94771610200405, 43.76203514635563, 44.675057753920555, 42.351695224642754, 39.565608724951744, 41.161640882492065, 41.20037980377674, 39.27057355642319, 40.82478515803814, 39.275665283203125, 41.4792924374342, 41.14099659025669, 41.426691859960556, 40.40589943528175, 41.24177098274231, 41.451078951358795, 39.69801642000675, 41.35447673499584, 39.96319659054279, 41.263239830732346, 39.68787856400013, 45.66628776490688, 46.67029269039631, 46.39295317232609, 47.55454324185848, 47.991383001208305, 54.09224063158035, 54.47059392929077, 44.03046794235706, 50.77100604772568, 54.57707941532135, 51.2476372718811, 48.50992977619171, 44.78582561016083, 43.37542109191418, 43.598229736089706, 41.416846588253975, 41.47924683988094, 37.17125840485096, 37.74627394974232, 37.781847640872, 38.613805398344994, 39.77817691862583, 45.21246291697025, 49.46170650422573, 49.101603627204895, 51.693642139434814, 50.32075680792332, 51.09846867620945, 48.20306584239006, 47.559638768434525, 44.76277604699135, 42.139659002423286, 38.18502500653267, 37.237849831581116, 37.506423220038414, 38.989232853055, 39.36049573123455, 40.374224334955215, 45.87354764342308, 50.69389298558235, 48.62322449684143, 50.35963632166386, 48.42132233083248, 45.4697585105896, 44.47851710021496, 43.48384067416191, 44.1145346313715, 47.066505029797554, 48.91556940972805, 50.3759678453207, 51.80426560342312, 51.49082042276859, 49.34864357113838, 46.573732271790504, 40.89809462428093, 23.480752632021904, 7.802261933684349, 7.326156506314874, 3.339516115374863, 3.136349329724908, 3.479077876545489, 0.46496807655785233, 0.22281447745626792, 0.08553190375096165, 0.5743664922192693, 0.638288859045133, 1.2474893289618194, 15.023387800902128, 25.050142519176006, 33.960917070508, 43.85338984429836, 53.89294132590294, 26.665893718600273, 2.4683682108297944, 0.1472443700185977, 0.13827198272338137, 0.19096779258688912, 0.1515081716934219, 0.1395404466893524, 0.11338754848111421, 0.1573154327343218, 0.12731803144561127, 0.10865623829886317, 0.1154379392392002, 0.08610865639639087, 0.13738600682700053, 0.18861033080611378, 0.12981703563127667, 0.1640850811963901, 0.1370848878286779, 0.08173209280357696, 0.19617584359366447, 0.09185681279632263, 0.16685583017533645], [0.01075179210602073, 0.048371088996645994, 0.006473612247646088, 0.05882932273379993, 0.07754024976748042, 0.03615695612097625, 0.05949682148639113, 0.04439401236595586, 0.060239024824113585, 0.02223571475042263, 0.04210654995404184, 0.013554630622820696, 0.06279825058300048, 0.07323099896893837, 0.04497485424508341, 0.04520894246525131, 0.04164520498306956, 0.01832523659686558, 0.020297302944527473, 0.05621623931801878, 0.030098283277766313, 0.030962877899582963, 0.012725236992991995, 0.010749718730949098, 0.04518697860476095, 0.569884751457721, 9.403469413518906, 38.392668664455414, 37.82989986240864, 32.653958201408386, 27.020682580769062, 24.35262344777584, 10.832062605768442, 0.7159489137120545, 0.20388030126923695, 0.8187629655003548, 0.6549186073243618, 1.1205506091937423, 3.3256005495786667, 3.090838696807623, 0.9585197037085891, 1.6520179971121252, 16.294933520257473, 40.63599228858948, 53.18211726844311, 51.878772005438805, 51.011905521154404, 49.111695885658264, 52.3291352391243, 54.22033555805683, 52.87881754338741, 51.538105085492134, 52.35115885734558, 51.73052676022053, 50.63834756612778, 48.17872054874897, 43.17943140864372, 36.96728155016899, 39.11214865744114, 38.73949125409126, 38.614037185907364, 43.035001158714294, 46.91363163292408, 46.174548491835594, 48.75810965895653, 45.186267122626305, 38.76928165555, 36.66915714740753, 37.24370151758194, 37.31771394610405, 38.63394431769848, 37.73581691086292, 37.84680135548115, 36.57157078385353, 37.48629190027714, 33.943939581513405, 38.72336111962795, 40.12915648519993, 41.40825144946575, 39.714192152023315, 37.600631564855576, 38.826780170202255, 44.59694914519787, 43.808613047003746, 46.78028538823128, 45.667051523923874, 48.6066459864378, 47.62797810137272, 50.80147281289101, 37.825944274663925, 47.2940444201231, 51.17383763194084, 45.78879699110985, 43.13688889145851, 38.05091880261898, 37.632025480270386, 34.667420759797096, 35.697632879018784, 34.85597804188728, 34.554578214883804, 33.754196763038635, 36.08420513570309, 35.0610226392746, 38.37095282971859, 40.225701704621315, 43.877495750784874, 45.453932359814644, 42.647969126701355, 42.73717314004898, 38.19925904273987, 36.392927169799805, 37.007870972156525, 35.95391012728214, 35.167618319392204, 35.19291736185551, 34.14126679301262, 33.99711772799492, 34.44826751947403, 35.84830619394779, 36.18689462542534, 45.38805529475212, 48.65670070052147, 47.61729307472706, 48.77864755690098, 46.01561062037945, 43.51583115756512, 42.30624206364155, 42.31659650802612, 41.56716652214527, 42.90822096168995, 45.330442786216736, 47.815479040145874, 50.68352714180946, 49.302932024002075, 48.92100691795349, 37.64743745326996, 24.826946295797825, 6.3318676594644785, 0.42272247781511396, 0.5758678272832185, 0.7911579217761755, 0.06335002253763378, 0.08360950378119014, 0.0406856006156886, 0.04935174067213666, 0.028461020156100858, 0.07537374258390628, 0.1776739238994196, 1.0748379933647811, 16.39244768768549, 27.627344727516174, 25.74931640177965, 36.925506591796875, 36.409767866134644, 9.321830794215202, 0.17340109770884737, 0.02549861339502968, 0.0484601467178436, 0.03302596494904719, 0.04315255144319963, 0.09282747516408563, 0.037080603433423676, 0.06073551419831347, 0.06356015423079953, 0.0369545348075917, 0.051141748917871155, 0.017287946066062432, 0.03120407032838557, 0.023859101565903984, 0.023322929555433802, 0.01994823007407831, 0.07356878748396412, 0.05576935138378758, 0.06536997781950049, 0.03172735494445078, 0.159968699736055, 0.023033987345115747, 0.04456357084563933, 0.08501957694534212, 0.07363795564742759, 0.03682567570649553, 0.00380384452000726, 0.018935502776002977, 0.07465184811735526, 0.04303221961890813, 0.037440378073370084, 0.02773876203718828, 0.020347501813375857, 0.0638275351957418, 0.07934541266877204, 0.0738023933081422, 0.049112171691376716, 0.050221062774653547, 0.03910167564754374, 0.006559181874763453, 0.025843706498562824, 0.06048073490092065, 0.041571420661057346, 0.021894944657105953, 0.049194843231816776, 0.024074547036434524, 1.0461568948812783, 15.805876962840557, 43.99138703942299, 48.18823143839836, 37.66965106129646, 30.29405303299427, 29.232963770627975, 12.399768233299255, 0.6376399251166731, 0.10552110223216005, 0.22287662490271032, 0.38485721277538687, 0.7229933794587851, 1.1950927530415356, 4.57860991358757, 1.9459252199158072, 1.9563208683393896, 20.17427645623684, 42.69909158349037, 55.60791090130806, 54.5577422529459, 54.34763252735138, 51.42268627882004, 54.978334084153175, 55.444713458418846, 54.868390783667564, 51.53473846614361, 52.82456785440445, 54.46530841290951, 52.4714870005846, 49.540996849536896, 44.97732013463974, 38.53862643241882, 39.84137512743473, 39.797232896089554, 40.39129301905632, 44.82651762664318, 47.78712496161461, 48.41341495513916, 49.329420402646065, 46.21229186654091, 40.482203140854836, 37.98127233982086, 39.56207491457462, 39.55179266631603, 39.75496396422386, 39.48867805302143, 39.35672253370285, 37.69641302525997, 39.54419307410717, 36.647585704922676, 40.47856293618679, 42.965423092246056, 41.45137533545494, 40.40709637105465, 40.20172119140625, 40.527128130197525, 45.1328381896019, 45.44930420815945, 48.54234203696251, 47.99305871129036, 49.829937145113945, 48.28186981379986, 51.487658992409706, 41.526067927479744, 49.70868565142155, 53.340276181697845, 47.98836216330528, 45.39338260889053, 39.46633145213127, 38.57562504708767, 36.100548058748245, 37.64977812767029, 37.14928798377514, 36.045538410544395, 35.0318706035614, 37.27994777262211, 37.63859532773495, 40.102656707167625, 42.444395050406456, 45.07606543600559, 47.00129292905331, 45.73993541300297, 44.68292713165283, 39.84236307442188, 39.894150495529175, 38.90445180237293, 38.45064215362072, 37.25734278559685, 36.58289797604084, 35.83724118769169, 35.86135469377041, 37.61269211769104, 37.10703805088997, 39.16799806058407, 47.65147224068642, 50.51326967775822, 49.110324159264565, 49.83696676790714, 46.939147263765335, 45.11594049632549, 44.4650886207819, 44.036027044057846, 43.87865088880062, 44.18264597654343, 47.204608619213104, 48.88924062252045, 51.1570805311203, 49.60727669298649, 49.76599417626858, 39.024635553359985, 27.083952985703945, 8.774866294115782, 0.9769822598900646, 2.0676827989518642, 1.3095394056290388, 0.1414488349109888, 0.07681740535190329, 0.09115905297221616, 0.06815097585786134, 0.058882293524220586, 0.13427379570202902, 0.5657796061132103, 1.8193423748016357, 19.586854577064514, 28.568843007087708, 29.581066891551018, 40.931791216135025, 43.23089964687824, 12.508966773748398, 0.3045520547311753, 0.07892707886639982, 0.05048701881605666, 0.033942398586077616, 0.03592912049498409, 0.04377724682854023, 0.08365804023924284, 0.059943523883703165, 0.029708429392485414, 0.03574142021534499, 0.06546389660798013, 0.008861893566063372, 0.05829074616485741, 0.017677905707387254, 0.044192125933477655, 0.04968202607415151, 0.019101482248515822, 0.027145359308633488, 0.012579812228068477, 0.03017150727828266, 0.04200726172712166, 0.06874957733089104, 0.17048865789547563, 0.1922774754348211, 0.17297884536674246, 0.17437902570236474, 0.054426613278337754, 0.1300553244072944, 0.13394680543569848, 0.09621845179935917, 0.08080359926680103, 0.11734980071196333, 0.08140266829286702, 0.19508574740029871, 0.21060190309071913, 0.19988208456197754, 0.2542302565416321, 0.24083904776489362, 0.13299652986461297, 0.14808642561547458, 0.22259698365814984, 0.12048947130097076, 0.20623314689146355, 0.17811720870668069, 0.14050409576157108, 0.16532115783775225, 0.7342031935695559, 15.582456551492214, 50.78308939933777, 55.21592013537884, 45.32195784151554, 39.249389693140984, 36.98079742491245, 16.2904117628932, 1.5875479253008962, 0.3506636491511017, 2.3430749215185642, 2.2657716320827603, 4.2348043620586395, 13.053479455411434, 7.612417470663786, 2.081709271296859, 2.215653033927083, 21.02539848536253, 44.14956495165825, 57.05570921301842, 55.02002164721489, 56.476160511374474, 51.91262058913708, 57.63973027467728, 57.43280477821827, 56.163159906864166, 51.9503715634346, 55.78286111354828, 55.25021329522133, 54.95413698256016, 51.85310438275337, 47.13468857109547, 39.511226043105125, 42.2722414880991, 42.10591681301594, 43.71856547892094, 47.204240038990974, 51.55437961220741, 50.146300569176674, 52.919809743762016, 49.13516342639923, 42.481199875473976, 40.83745367825031, 41.313617527484894, 41.54946327209473, 41.83185271918774, 42.659098729491234, 41.10852353274822, 37.93919339776039, 42.839581444859505, 38.088335394859314, 43.00081059336662, 44.59632597863674, 45.03016009926796, 42.49762639403343, 41.289222836494446, 42.38957159221172, 49.631747379899025, 49.180153012275696, 51.24710530042648, 48.59290212392807, 53.74948002398014, 50.47934889793396, 51.753230541944504, 44.64240610599518, 53.27559605240822, 56.6798409819603, 48.75256575644016, 47.457097470760345, 43.03883135318756, 40.91997765004635, 37.93129742145538, 39.0475445240736, 37.80632592737675, 37.986436262726784, 37.2340652346611, 39.60076443850994, 39.456619173288345, 42.41995096206665, 44.22267682850361, 47.175608575344086, 50.41107036173344, 46.448544189333916, 46.79945155978203, 41.89642645418644, 38.92882749438286, 40.231378600001335, 39.991307482123375, 38.08342605829239, 38.131888657808304, 37.28937886655331, 37.21299536526203, 39.65793617069721, 39.484350085258484, 40.87185323238373, 49.35666114091873, 52.53073342144489, 50.962264984846115, 52.07122787833214, 48.78747448325157, 47.94877968728542, 47.259401679039, 45.96177130937576, 45.64267583191395, 46.300165951251984, 49.79295372962952, 51.14435501396656, 53.41382123529911, 50.198034793138504, 51.40086404979229, 38.46538536250591, 28.02234873175621, 8.207128308713436, 1.0507026384584606, 2.4648294132202864, 1.8041212228126824, 1.0174505040049553, 0.42478377814404666, 0.259652387467213, 0.37868064420763403, 0.3420918434858322, 0.6590599694754928, 0.76191047555767, 4.363541454076767, 29.489370211958885, 38.82262699306011, 36.39350473880768, 48.42803657054901, 47.64467440545559, 16.46238673478365, 0.5750672577414662, 0.11310400353977457, 0.22966451535467058, 0.12417165184160694, 0.14723015046911314, 0.17952535970835015, 0.12123439460992813, 0.1473085954785347, 0.16452922689495608, 0.09529478964395821, 0.21143695281352848, 0.03433598918491043, 0.11440976042649709, 0.15343348088208586, 0.09653652887209319, 0.14603699964936823, 0.1609259218093939, 0.0899474746256601, 0.10386529655079357, 0.07884078935603611, 0.22516249911859632], [0.013206525327404961, 0.05313999266945757, 0.019171151361661032, 0.021821236405230593, 0.0462493444501888, 0.029526365724450443, 0.03623776858148631, 0.024608984276710544, 0.06572194135515019, 0.03009496402228251, 0.010652876808308065, 0.003973439643232268, 0.011629686014202889, 0.01681487887253752, 0.0742658571107313, 0.06246512275538407, 0.026469262775208335, 0.03543064958648756, 0.02631905208545504, 0.0685092773346696, 0.02484569042280782, 0.02760444815066876, 0.09743431975948624, 0.05223000829573721, 0.01687944015429821, 0.10658196522854269, 2.2441491298377514, 14.920668862760067, 33.999310210347176, 35.16783110797405, 21.733393594622612, 24.570009782910347, 13.458444625139236, 2.0038873096928, 0.08876923355273902, 0.0915167607308831, 0.14303619973361492, 0.3818114090245217, 1.0431050648912787, 5.586775615811348, 1.8924289592541754, 0.06445305436500348, 5.280855456367135, 19.83702365309, 44.6342783421278, 51.769679859280586, 55.737666338682175, 51.023852080106735, 52.77001418173313, 51.665618643164635, 51.22141107916832, 55.179164707660675, 54.81150023639202, 51.802411302924156, 48.3580557256937, 41.79209545254707, 37.15567924082279, 38.416010811924934, 37.589809745550156, 38.057131469249725, 40.89397944509983, 46.083360984921455, 49.85112100839615, 52.50045284628868, 50.98640128970146, 50.595512464642525, 49.16561119258404, 44.03351917862892, 41.22522287070751, 42.219827100634575, 42.547278329730034, 41.06955282390118, 38.8877023011446, 34.75275658071041, 38.15957397222519, 37.42369785904884, 38.809749484062195, 41.70344240963459, 45.643405392766, 43.54477800428867, 41.5277436375618, 41.267457604408264, 47.20465421676636, 46.641235649585724, 48.97954657673836, 48.59521999955177, 49.69288229942322, 48.25184762477875, 56.758971735835075, 41.85084030032158, 45.692133978009224, 51.822322234511375, 46.18536651134491, 45.18030144274235, 36.934664100408554, 38.76009754836559, 34.09113988280296, 35.06410427391529, 35.632333382964134, 35.87809279561043, 35.41427828371525, 34.31149385869503, 35.935766100883484, 38.862144872546196, 41.16172827780247, 44.95736740529537, 42.62192152440548, 39.38613295555115, 36.718493700027466, 36.23466946184635, 36.53583750128746, 37.20517158508301, 35.14204949140549, 35.40778063237667, 34.239757508039474, 33.88859175145626, 35.16686975955963, 34.58531476557255, 33.86790566146374, 36.4300549775362, 46.308373510837555, 48.303141072392464, 47.541338950395584, 48.08034762740135, 47.080115899443626, 45.771181136369705, 44.96915437281132, 44.28594343364239, 42.81754642724991, 45.68280167877674, 45.15605874359608, 47.7595916390419, 50.329750925302505, 49.96929086744785, 43.37568327784538, 30.65818939357996, 8.694234620779753, 1.1967557575553656, 1.1997423972934484, 1.374680616427213, 0.46124101092573255, 0.11189385753823444, 0.006619050927838543, 0.04080669314134866, 0.06153086644189898, 0.2182864712085575, 0.13075044960714877, 0.22431643592426553, 4.563631117343903, 23.557751700282097, 34.863087460398674, 25.832773223519325, 32.64389634132385, 25.854753144085407, 6.86394028365612, 0.17723948549246415, 0.10414443313493393, 0.032170506165130064, 0.031582580486428924, 0.0578410937305307, 0.07605779494042508, 0.011799588664871408, 0.08589885124820285, 0.08109290327411145, 0.0683570999535732, 0.010291699509252794, 0.0038921805025893264, 0.09404879790963605, 0.028618082724278793, 0.027530209263204597, 0.009284648713219212, 0.0380303223937517, 0.016620304450043477, 0.058600355332600884, 0.03414604390854947, 0.057865929702529684, 0.040627000635140575, 0.008957998907135334, 0.024387002340517938, 0.028573412855621427, 0.02407921143458225, 0.0892038871825207, 0.028816091435146518, 0.017055173302651383, 0.013652120069309603, 0.03841125566395931, 0.019825124472845346, 0.033584928314667195, 0.04491586463700514, 0.033832735134637915, 0.030444038748100866, 0.03984996088547632, 0.02123056292475667, 0.047392656342708506, 0.055495246560894884, 0.031133844604482874, 0.01734142151690321, 0.017114379988925066, 0.03931046405341476, 0.030417377092817333, 0.10878758359467611, 0.08933125456678681, 4.283003825694323, 26.535442918539047, 39.46673043072224, 43.891646191477776, 27.758621983230114, 30.65374743193388, 17.153981924057007, 2.188782300800085, 0.07956991976243444, 0.1360314092016779, 0.10968484013574198, 0.4256941855419427, 0.42696676100604236, 5.123578095808625, 3.0015154648572206, 0.6194282742217183, 6.826876597478986, 25.30645776540041, 47.687015533447266, 54.756262600421906, 55.754191651940346, 54.27351750433445, 54.98223267495632, 54.857903346419334, 51.906685307621956, 56.699295938014984, 55.68055160343647, 53.93145605921745, 50.39576098322868, 45.36610387265682, 39.90329660475254, 39.70428228378296, 39.372795671224594, 40.071107000112534, 42.78079479932785, 48.37092183530331, 50.468755066394806, 54.38680462539196, 52.51609280705452, 52.67739035189152, 48.017631992697716, 44.965438172221184, 41.624950021505356, 44.11018766462803, 43.062177300453186, 42.4555816501379, 41.229144260287285, 37.36166998744011, 39.07279796898365, 39.56481076776981, 40.008269771933556, 43.94142732024193, 45.74882313609123, 45.410071313381195, 42.381907403469086, 43.2883145660162, 47.21668817102909, 49.021845906972885, 52.061507999897, 49.07715193927288, 51.20147354900837, 50.29279790818691, 52.99495071172714, 42.404348999261856, 48.236830830574036, 54.35242407023907, 47.42286890745163, 47.15125188231468, 39.13550980389118, 39.229710549116135, 35.80548629164696, 36.88380762934685, 36.71548046171665, 36.72201231122017, 36.763718873262405, 36.509326323866844, 36.865462213754654, 40.460654497146606, 42.671619057655334, 45.006848350167274, 44.19946387410164, 41.413373574614525, 39.3854945898056, 36.73968516290188, 38.192962780594826, 38.43256652355194, 35.822839960455894, 37.09576025605202, 36.005963534116745, 35.7237146794796, 36.147076562047005, 36.47727504372597, 36.88707925379276, 37.51375302672386, 47.06673301756382, 50.79528674483299, 49.97958451509476, 49.869375228881836, 48.581605330109596, 47.6321616768837, 46.96995601058006, 45.348484218120575, 44.1755935549736, 46.50613009929657, 46.35838262736797, 50.43103829026222, 51.56691513955593, 49.951481223106384, 45.040506944060326, 32.12878838181496, 11.994924657046795, 1.1439678026363254, 2.3456426337361336, 3.873488400131464, 1.104006771929562, 0.2346281029167585, 0.14741546474397182, 0.08428883607848547, 0.009001285598060349, 0.139891809085384, 0.31392831879202276, 0.23794364766217768, 5.885473312810063, 29.70843605697155, 41.0274662822485, 33.395188227295876, 39.06202934682369, 32.93584607541561, 9.045809805393219, 0.1642097471631132, 0.01967409556527855, 0.040059502571239136, 0.017596197103557643, 0.10535150664509274, 0.07678702182602137, 0.04395523981656879, 0.05163323621673044, 0.07344197671045549, 0.0881874343031086, 0.02527147353248438, 0.04865033319219947, 0.025655215831648093, 0.05747757124481723, 0.03394838029635139, 0.008829692706058268, 0.019017647391592618, 0.03600836331315804, 0.06499488896224648, 0.047051917790668085, 0.04182764714641962, 0.2001509943511337, 0.1311163284117356, 0.1162586358259432, 0.15482546790735796, 0.19591579504776746, 0.1450049245613627, 0.16476312215672806, 0.15583860338665545, 0.13839929073583335, 0.1582413658616133, 0.14308875863207504, 0.1102812671160791, 0.15590155235258862, 0.1538017048733309, 0.12206799714476801, 0.1327264920109883, 0.20390382735058665, 0.14161762897856534, 0.1748390682041645, 0.13350806257221848, 0.13595474534668028, 0.09214458055794239, 0.193092041881755, 0.10118416932527907, 0.22442749090259895, 0.2070576581172645, 4.143945062533021, 24.727712720632553, 46.93161606788635, 50.79789720475674, 34.77142117917538, 37.2168293595314, 21.03123117238283, 3.069422570988536, 0.28965228237211704, 0.37491368071641773, 0.5904872459359467, 2.0003663236275315, 2.2169580264016986, 14.236365482211113, 4.334684377536178, 0.3765968419611454, 7.343756686896086, 24.14911586791277, 47.647972628474236, 56.576345935463905, 58.34687992930412, 55.20160250365734, 54.83200393617153, 55.60929022729397, 52.07869827747345, 57.900962457060814, 58.57503868639469, 57.9049826413393, 53.04961457848549, 46.497584357857704, 40.22646926343441, 41.32244065403938, 40.756050646305084, 43.41339625418186, 44.46774087846279, 50.1425501704216, 54.89602670073509, 56.2870978564024, 55.77791377902031, 56.01111486554146, 52.15763904154301, 48.37487742304802, 44.4929563254118, 46.7402583360672, 46.172397807240486, 45.00012271106243, 42.16846905648708, 38.92496310174465, 40.5663838237524, 41.195185482501984, 42.147813364863396, 46.43382377922535, 47.678431794047356, 47.04822801053524, 44.628992825746536, 45.42240545153618, 49.3977103382349, 50.72022557258606, 51.49172477424145, 51.27266272902489, 52.00249716639519, 52.50271372497082, 52.595288157463074, 44.64574992656708, 52.10483327507973, 56.20781511068344, 51.48430377244949, 48.97181399166584, 40.02463549375534, 42.755108177661896, 38.21004666388035, 38.42304043471813, 39.87823694944382, 37.57513113319874, 38.45581367611885, 38.84387165307999, 38.63483726978302, 42.55112372338772, 44.038975685834885, 48.684188425540924, 46.31537653505802, 43.401514291763306, 42.348514795303345, 40.0004193931818, 40.84405392408371, 40.046754106879234, 37.64728546142578, 39.03911657631397, 39.127203449606895, 38.20060797035694, 38.77756141126156, 38.34829844534397, 37.81824968755245, 39.73104044795036, 49.146091639995575, 54.2417436093092, 51.50167264044285, 50.33135823905468, 49.90102753043175, 50.54415822029114, 48.68894197046757, 47.49905861914158, 46.370800361037254, 48.936350494623184, 48.350786715745926, 51.94401450455189, 54.97840628027916, 50.6179578602314, 45.29343657195568, 34.20062720775604, 11.921760533005, 1.9302071258425713, 3.0741203064098954, 5.139869721606374, 2.056066822260618, 0.22017026465618983, 0.21682052174583077, 0.1684089077753015, 0.14746109198313206, 0.4575111548183486, 0.7549737696535885, 0.5531188636086881, 11.180980782955885, 36.588039100170135, 43.96177902817726, 37.977879121899605, 44.68443565070629, 37.52783127129078, 10.613749120384455, 0.26469035306945443, 0.25449662818573415, 0.1819803100079298, 0.26731993071734905, 0.18921702168881893, 0.2754119230667129, 0.15580666135065258, 0.21897141414228827, 0.24548415007302538, 0.14531155029544607, 0.08292077589430846, 0.1233292771212291, 0.2407604394829832, 0.12611076497705653, 0.10399633014458232, 0.13731017417740077, 0.12656139704631642, 0.2213985487469472, 0.20431181561434641, 0.24724452436203137, 0.2016617843764834], [0.02698477153899148, 0.04605295733199455, 0.044198493560543284, 0.02031788641033927, 0.035749806484091096, 0.015095854269020492, 0.044754621922038496, 0.052308304875623435, 0.0413629254035186, 0.056809541856637225, 0.03748532624740619, 0.04348003523773514, 0.09059928808710538, 0.04818308814719785, 0.0328633381286636, 0.018117117979272734, 0.019161102682119235, 0.03211152026779018, 0.027352288634574506, 0.13723052688874304, 0.049656752235023305, 0.10890998601098545, 0.02870935575629119, 0.08711234433576465, 0.065808386716526, 0.1823139944463037, 0.5710972426459193, 5.646204901859164, 32.15428501367569, 35.372993499040604, 27.081637009978294, 17.389593981206417, 17.55341649055481, 5.389447454363108, 0.3288838412845507, 0.1051311481569428, 0.08209481005906127, 0.2610839606495574, 0.12479084049118683, 2.778812739998102, 5.187719604000449, 0.28176966472528875, 1.6180435451678932, 5.763123203068972, 25.717059932649136, 44.068473502993584, 50.403675958514214, 51.649583503603935, 50.75904428958893, 51.48089915513992, 53.0346167832613, 52.22596317529678, 51.13879591226578, 48.84021185338497, 45.05099058151245, 38.936936259269714, 39.64167684316635, 38.25838007032871, 37.6873467117548, 38.31777088344097, 43.06840516626835, 46.95800185203552, 51.27631813287735, 49.70959760248661, 51.433994472026825, 51.362014934420586, 51.08244873583317, 48.15879441797733, 48.065224438905716, 49.209977611899376, 48.66025730967522, 48.403839468955994, 45.290772914886475, 39.612429812550545, 36.46047994494438, 37.26903095841408, 37.022431790828705, 43.0573857575655, 44.51045818626881, 41.743731647729874, 38.342822939157486, 41.62606716156006, 47.933002933859825, 47.28086292743683, 51.4047322422266, 48.76763574779034, 50.44849835336208, 42.56672568619251, 59.614457711577415, 48.23972247540951, 44.49902079999447, 50.43984241783619, 47.12114989757538, 45.32969042658806, 40.892516523599625, 38.61110754311085, 35.19458927214146, 34.366746693849564, 34.208492785692215, 34.552545323967934, 32.99047574400902, 33.60289268195629, 35.69670952856541, 38.25703114271164, 41.65383227169514, 41.60350017249584, 39.59717743098736, 35.8906739205122, 38.36446277797222, 34.944672882556915, 35.44829025864601, 34.08832423388958, 36.28087118268013, 37.60068476200104, 41.399447321891785, 39.367445558309555, 34.23479497432709, 34.427931010723114, 37.00210288167, 35.3760789334774, 44.920444786548615, 47.78481848537922, 47.14308612048626, 47.39263392984867, 47.363945469260216, 47.08445906639099, 46.1128094047308, 44.164190366864204, 45.83262003958225, 44.60616745054722, 48.784408047795296, 46.43049895763397, 49.89487186074257, 46.30822531878948, 36.46745637059212, 11.19668249040842, 0.9637113532517105, 0.5310560599900782, 1.5989651251584291, 2.88503366522491, 0.9410456288605928, 0.13840515370247886, 0.24724709219299257, 0.055397921314579435, 0.04681513186369557, 0.05967750847048592, 0.0967874786874745, 0.16088407952338457, 9.918077699840069, 19.910314120352268, 26.985363475978374, 30.2217049151659, 31.722031608223915, 16.813166812062263, 1.2755784904584289, 0.058333338020020165, 0.09845276901614852, 0.08968327005277388, 0.06191001855768263, 0.035674422833835706, 0.0057894930978363845, 0.04108555513084866, 0.03868839216011111, 0.014562118358298903, 0.020283395097067114, 0.02143086116120685, 0.07641234857146628, 0.02834335078659933, 0.02050542156212032, 0.04333576172939502, 0.04246042823069729, 0.015248623512889026, 0.006775249357815483, 0.04804153461009264, 0.006558584445883753, 0.009613031434128061, 0.03697091029607691, 0.051977804250782356, 0.006622811297347653, 0.012519072079157922, 0.020296993097872473, 0.011225317575735971, 0.06727125626639463, 0.07546721608377993, 0.057718320240383036, 0.05768502378487028, 0.04750616040837485, 0.03119006971246563, 0.026660783260012977, 0.024286600892082788, 0.045966793986735865, 0.07007394728134386, 0.03857003815937787, 0.04337788974225987, 0.049767265445552766, 0.04319595966080669, 0.02429356780339731, 0.03956648644816596, 0.051967154431622475, 0.06793179738451727, 0.017701446631690487, 0.15566863672574982, 0.6459567882120609, 8.071236200630665, 37.317778542637825, 42.30531491339207, 33.265368193387985, 24.89750850945711, 21.433145105838776, 5.980442091822624, 0.178864581102971, 0.007372871195912012, 0.1667548090335913, 0.5554882739670575, 0.2039347600657493, 1.5664317458868027, 3.6740363901481032, 0.6077928235754371, 1.8033261154778302, 7.072888696566224, 28.96338153630495, 48.69886323809624, 54.4005560874939, 53.69458816945553, 51.81145861744881, 51.69412091374397, 55.3422861546278, 54.25571545958519, 53.46801772713661, 51.31080128252506, 48.38389813899994, 39.96207185089588, 41.222506016492844, 40.0585562735796, 38.690470084548, 39.0993395447731, 45.39761558175087, 50.74908882379532, 51.904420629143715, 53.84301580488682, 53.052270635962486, 52.521860897541046, 52.6699161529541, 50.042060762643814, 48.76239202916622, 49.33314800262451, 50.21533526480198, 49.87638585269451, 47.64728486537933, 41.43769986927509, 37.94351376593113, 38.907582834362984, 38.264410346746445, 44.25082951784134, 46.67856104671955, 43.90754073858261, 39.874718338251114, 42.83447451889515, 47.92797200381756, 49.27661843597889, 52.01918587088585, 51.35056994855404, 50.00035800039768, 47.753420770168304, 56.23139664530754, 46.292003989219666, 48.41553524136543, 52.97002784907818, 49.390946701169014, 46.097697615623474, 43.7214495241642, 40.33657215535641, 36.80591180920601, 35.75482740998268, 36.20146304368973, 36.58570982515812, 35.62895156443119, 35.34201756119728, 37.82942868769169, 41.13070294260979, 43.331788033246994, 43.73566076159477, 41.89513452351093, 38.32558326423168, 38.36752161383629, 36.87444493174553, 38.13506908714771, 36.11708477139473, 37.329139932990074, 39.36189025640488, 41.32025197148323, 38.02075982093811, 35.89412793517113, 35.24023622274399, 38.88572260737419, 37.03300662338734, 46.06743223965168, 49.544048085808754, 49.60414186120033, 48.74581731855869, 48.147262036800385, 49.02109354734421, 47.7519616484642, 45.61201527714729, 47.825316712260246, 46.79231554269791, 49.35755029320717, 49.01261240243912, 50.68018712103367, 49.29581880569458, 39.022963643074036, 13.943913225084543, 3.0049184197559953, 2.1193101536482573, 5.909424852579832, 7.570795454084873, 1.6065561678260565, 0.6406304833944887, 0.43245357752311975, 0.04814286745386198, 0.02386411291809054, 0.11526265137945302, 0.07179387452197261, 0.354215627303347, 11.07902180403471, 27.123123183846474, 32.332172468304634, 30.64917627722025, 36.896916925907135, 21.702425256371498, 2.6124194310978055, 0.026250995288137347, 0.04762038435728755, 0.05597853312792722, 0.023079167440300807, 0.03796086479269434, 0.07808693801052868, 0.024041719989327248, 0.01678223179624183, 0.09151552876573987, 0.04424777587701101, 0.013702345841011265, 0.019262934620201122, 0.0785400636959821, 0.017230685662070755, 0.09646733102272265, 0.04474892222788185, 0.0034120721829822287, 0.006680657534161583, 0.013507516305253375, 0.028363279307086486, 0.07371084197075106, 0.1088013281696476, 0.11242793669225648, 0.17472002771683037, 0.1671752505353652, 0.10778393276268616, 0.09830711511312984, 0.33237134164664894, 0.21228052239166573, 0.08337358245626092, 0.2382333524292335, 0.11973147877142765, 0.14985797664849088, 0.19293307384941727, 0.16191397269722074, 0.16711114381905645, 0.15774334024172276, 0.18880772724514827, 0.08847680510370992, 0.09143036731984466, 0.24070069659501314, 0.18497149168979377, 0.20209034497383982, 0.13738799578277394, 0.19012316915905103, 0.1941022978280671, 0.2643356955377385, 0.8290532883256674, 11.001284625381231, 44.49226476252079, 49.59763281047344, 39.568849951028824, 29.565554223954678, 24.139166101813316, 8.430640865117311, 0.6466393859591335, 0.3789230593247339, 0.3574323921930045, 0.9824936266522855, 0.26449445576872677, 5.863374648615718, 11.16822961717844, 2.8318274952471256, 3.0806317320093513, 7.455464517697692, 30.043842159211636, 48.40541638433933, 53.726802840828896, 53.76844860613346, 52.18274429440498, 53.954414427280426, 57.45901197195053, 56.47109538316727, 55.137917920947075, 53.08080330491066, 49.11517649888992, 43.24896387755871, 44.43011909723282, 41.1748755723238, 41.454149186611176, 40.9306550770998, 48.101033717393875, 51.670695170760155, 55.89039534330368, 54.8369512706995, 53.39650176465511, 54.91540186107159, 54.68913920223713, 52.136025801301, 51.564593464136124, 52.48221382498741, 51.19670860469341, 51.72222040593624, 49.50307488441467, 43.348020762205124, 38.93876776099205, 41.14179074764252, 39.98167499899864, 46.42200641334057, 48.30602131783962, 45.882024988532066, 41.6526847332716, 45.093639492988586, 50.9317260235548, 50.9188637137413, 54.49281893670559, 52.40998350083828, 52.60010249912739, 46.383271291852, 56.89050167798996, 51.3405042886734, 48.62616553902626, 56.41938015818596, 51.511316522955894, 49.316121116280556, 47.09984824061394, 43.79217132925987, 39.34819579124451, 38.14566291868687, 37.71865323185921, 37.9249631613493, 36.995419040322304, 38.21996033191681, 39.192605540156364, 42.34022743999958, 44.84558120369911, 44.34282258152962, 43.46709117293358, 39.96970944106579, 41.582639291882515, 37.99035005271435, 39.03962954878807, 37.23244272172451, 40.75047254562378, 41.154770851135254, 45.60523264110088, 42.10885785520077, 37.94626861810684, 37.883226200938225, 41.20123475790024, 40.23086942732334, 48.34358990192413, 51.044028997421265, 50.930578485131264, 49.285718947649, 49.89036150276661, 50.97740337252617, 49.704783260822296, 45.403501465916634, 50.89516058564186, 49.01685297489166, 51.259078457951546, 51.20352163910866, 51.289450228214264, 49.932934418320656, 37.76775799691677, 13.975839111953974, 1.7780634085647762, 1.4642179431393743, 6.1588045209646225, 5.8714615646749735, 2.3266624147072434, 0.994709258666262, 0.9277102444320917, 0.1617318348144181, 0.3312304231803864, 0.3405550337629393, 0.5523656727746129, 0.6900931417476386, 17.377670221030712, 28.379421271383762, 39.59300525486469, 39.91116598248482, 43.64688232541084, 24.79536049067974, 2.7968028746545315, 0.14271505759097636, 0.1698586338898167, 0.17493710591224954, 0.13699105067644268, 0.146203656331636, 0.14486287749605253, 0.12110047406167723, 0.07317592418985441, 0.11351545763318427, 0.17678002186585218, 0.22815111296949908, 0.1775549427838996, 0.1711834713933058, 0.11416920810006559, 0.30771695834118873, 0.12713595293462276, 0.1259247530833818, 0.09889465116430074, 0.10252762731397524, 0.1653393404558301, 0.13558331527747214], [0.021746266502304934, 0.026615712631610222, 0.02845756731403526, 0.005057903863416868, 0.060891947796335444, 0.014161005165078677, 0.06234721033251844, 0.034208877841592766, 0.029900257868575864, 0.031071383600647096, 0.05492529569892213, 0.03173128832713701, 0.026721821195678785, 0.07851120899431407, 0.037828936910955235, 0.021147989718883764, 0.04017692888737656, 0.03454949022852816, 0.046655614642077126, 0.10111310126376338, 0.04628031798347365, 0.05442850946565159, 0.036186745928716846, 0.0912330747814849, 0.015573193450109102, 0.08074839832261205, 0.14757940516574308, 2.7627946995198727, 20.958814658224583, 34.72121447324753, 29.263130351901054, 18.50145421922207, 16.51015017181635, 9.8566416464746, 1.011174547020346, 0.1405234361300245, 0.25382266903761774, 0.12487899279221892, 0.05007221763662528, 0.2177673389087431, 3.01751094404608, 1.2093726242892444, 0.10709511581808329, 0.875190650112927, 8.148138374090195, 29.482010006904602, 47.25546509027481, 51.61350063979626, 52.785847932100296, 51.5821523219347, 55.50065025687218, 51.42335124313831, 49.82302911579609, 46.108546033501625, 40.854879543185234, 40.62437631189823, 40.12433834373951, 38.407632261514664, 36.838403865695, 38.74573051929474, 42.08368420600891, 46.74808211624622, 51.86135374009609, 49.7478311508894, 48.18503960967064, 50.573363453149796, 52.6420484483242, 50.28833694756031, 49.2177177965641, 50.195230543613434, 50.23412525653839, 50.10568454861641, 48.68024043738842, 46.267187520861626, 39.436039477586746, 36.24730758368969, 38.81053224205971, 37.74838283658028, 40.18909826874733, 39.89355392754078, 38.18513140082359, 39.33868870139122, 46.27356357872486, 48.574461713433266, 48.08590292930603, 48.14323805272579, 50.703491270542145, 47.88391716778278, 45.70029214024544, 35.902685075998306, 49.140920117497444, 54.50268320739269, 47.90323533117771, 46.05344519019127, 41.94126024842262, 39.90004017949104, 36.203389540314674, 35.9241197258234, 35.125326588749886, 33.628123328089714, 33.88636887073517, 35.19603319466114, 36.189782470464706, 36.95721209049225, 40.06922610104084, 37.42399424314499, 37.14295752346516, 36.51845723390579, 36.7366149276495, 37.3112390935421, 34.996714890003204, 36.19507558643818, 40.78525207936764, 46.83845266699791, 46.971339136362076, 46.3606359064579, 40.72132810950279, 35.13522885739803, 35.52151992917061, 34.21729691326618, 42.12677389383316, 48.44222120940685, 47.789461836218834, 48.46729226410389, 48.95987123250961, 49.33011196553707, 48.25487606227398, 46.32576137781143, 44.535582438111305, 46.171641647815704, 47.75587163865566, 48.93435940146446, 49.82706069946289, 37.680928856134415, 19.32475984096527, 2.583464034833014, 1.6563671012409031, 2.074509132653475, 3.0736222956329584, 6.129158036783338, 0.32587179041001946, 0.8316214755177498, 0.39376595348585397, 0.11134426749777049, 0.030909274428267963, 0.03355208085849881, 0.2006409305613488, 0.5479998257942498, 10.749133955687284, 23.57150126248598, 26.981309093534946, 35.19376091659069, 27.182987071573734, 8.637406770139933, 0.0700699990557041, 0.08088372895144857, 0.0381748445215635, 0.09026503219502047, 0.046087059017736465, 0.06935018260264769, 0.046866388292983174, 0.02280608121509431, 0.05483224522322416, 0.0438849027705146, 0.07600226002978161, 0.04327615613874514, 0.003700019915413577, 0.0636453898914624, 0.043351331987651065, 0.03032648441148922, 0.038910665389266796, 0.101074279518798, 0.07363355471170507, 0.037524552462855354, 0.02023792556428816, 0.0441657796909567, 0.03295104885182809, 0.027204881407669745, 0.03739024970855098, 0.03278928292274941, 0.0702994414314162, 0.048449077585246414, 0.036625967477448285, 0.03553348156856373, 0.027014989937015343, 0.036491816863417625, 0.0439519187057158, 0.04473425738979131, 0.031068203497852664, 0.036281247303122655, 0.01302542459598044, 0.06037164661393035, 0.025377949459652882, 0.01618977345060557, 0.0038925487933738623, 0.0697377321193926, 0.048061246052384377, 0.015806064548087306, 0.0218959743870073, 0.10844371689017862, 0.026930438907584175, 0.04264377581421286, 0.16542173369089141, 4.054617555812001, 30.652789883315563, 41.237659603357315, 36.27540707588196, 20.75436282902956, 21.38438232243061, 12.320912014693022, 0.9671550372149795, 0.016383605725422967, 0.4157875233795494, 0.1444476458709687, 0.05960540511296131, 0.2598850062349811, 3.3710767468437552, 0.9743907395750284, 0.40598776016850024, 1.5011337934993207, 9.729370325803757, 32.27452576160431, 49.837810322642326, 53.253040462732315, 52.87110395729542, 52.41443686187267, 57.01352007687092, 52.89642959833145, 51.16537168622017, 49.927926287055016, 42.998488917946815, 42.86842569708824, 41.61613829433918, 40.100855603814125, 39.001654386520386, 40.75084112584591, 43.7408284842968, 48.70832473039627, 53.22942093014717, 52.59613551199436, 49.16046626865864, 52.329853400588036, 53.597890958189964, 51.88969261944294, 50.63634507358074, 51.57565847039223, 52.06115461885929, 51.277317479252815, 51.09466888010502, 48.441142067313194, 40.57457998394966, 37.47148409485817, 40.29578514397144, 41.303593665361404, 41.88249260187149, 41.84484802186489, 40.56867130100727, 42.600334882736206, 46.98080822825432, 51.580613404512405, 49.43893812596798, 50.2571976184845, 50.02866268157959, 50.667457804083824, 46.29823185503483, 38.83321322500706, 52.78971992433071, 53.73468741774559, 50.719613805413246, 47.27908082306385, 43.79721745848656, 40.96948519349098, 38.8747525960207, 36.49881228804588, 37.9773585498333, 35.5960339307785, 34.999880120158195, 35.88247776031494, 37.157655134797096, 38.580192402005196, 41.46927237510681, 40.98918333649635, 38.235915675759315, 37.708207592368126, 38.62267032265663, 38.430674225091934, 37.4286337941885, 37.8936680406332, 42.63425186276436, 47.33493022620678, 49.52252984046936, 49.1996193677187, 42.76333473622799, 36.261659413576126, 37.50292740762234, 36.25207632780075, 44.419988840818405, 50.1514682918787, 50.327588841319084, 48.94958138465881, 48.925194293260574, 49.214221984148026, 48.68617571890354, 48.26088733971119, 46.23161382973194, 47.34372295439243, 49.88411083817482, 50.261320397257805, 50.01068204641342, 38.91143202781677, 22.8012502938509, 3.886211304925382, 3.667851984500885, 4.070913456380367, 7.840394787490368, 9.577101096510887, 1.732712248340249, 0.3996792377438396, 0.1636694636545144, 0.061201634889584966, 0.02110772635205649, 0.05483942179125734, 0.3013263246975839, 0.6313403381500393, 13.46060385927558, 27.917400263249874, 31.187901869416237, 40.83083063364029, 33.77899423241615, 12.573464512825012, 0.1586899347603321, 0.16170260903891176, 0.0684166350401938, 0.09488430776400492, 0.02759959636023268, 0.02337056430405937, 0.06168541498482227, 0.07367026133579202, 0.011075937163695926, 0.023884646288934164, 0.035748578229686245, 0.029605974050355144, 0.08249772203271277, 0.0422450384212425, 0.006630090838370961, 0.01962049209396355, 0.08099514758214355, 0.010390730767539935, 0.05703955568606034, 0.016874833272595424, 0.01150428624896449, 0.03994515987869818, 0.11287661691312678, 0.135568383266218, 0.12791730085154995, 0.18328821170143783, 0.271635222597979, 0.13359890144784003, 0.14139355975203216, 0.13898521632654592, 0.16764905245509, 0.08710738678928465, 0.16642560716718435, 0.10766984240035526, 0.08576291205827147, 0.1367141999071464, 0.12575230764923617, 0.13739080110099167, 0.1617893364164047, 0.10893665879848413, 0.11875459720613435, 0.16250199114438146, 0.16144017077749595, 0.10425110202049837, 0.09526820591418073, 0.2280702634016052, 0.17386793828336522, 0.1808549469569698, 0.27677869191393256, 4.476701281964779, 31.585292145609856, 49.35758829116821, 43.70355628430843, 30.182939395308495, 25.32362524420023, 14.158751796931028, 2.0184177299961448, 0.2920839737635106, 0.8352024864871055, 0.5726080772001296, 0.1252118608681485, 0.45912464323919266, 7.895758766680956, 6.138958185911179, 0.3703698964091018, 1.332199014723301, 9.767852760851383, 32.55933567881584, 49.84544411301613, 53.86914320290089, 54.18863005936146, 54.78959821164608, 58.571276888251305, 55.57041071355343, 53.0839229375124, 53.02857890725136, 44.754823073744774, 45.13102188706398, 43.29884760081768, 42.254667431116104, 41.532413586974144, 43.021701872348785, 46.06639489531517, 50.83133541047573, 55.65560594201088, 53.563092425465584, 51.51868812739849, 52.86095090210438, 56.868322268128395, 53.355068787932396, 51.97504743933678, 54.255643263459206, 53.74803230166435, 52.622300907969475, 51.73388198018074, 49.97741483151913, 43.353697657585144, 40.86783304810524, 42.55409136414528, 42.302088886499405, 43.4359822422266, 43.264687433838844, 41.56793788075447, 44.61195074021816, 50.33537842333317, 51.754731461405754, 51.24940797686577, 52.120815217494965, 52.48959682881832, 49.73321333527565, 49.74233664572239, 45.24315766990185, 52.57662735879421, 56.99301637709141, 54.95984427630901, 49.894655272364616, 46.20561182498932, 43.48372668027878, 40.70373885333538, 38.52880775928497, 39.224626421928406, 37.761047556996346, 36.70886881649494, 38.241866156458855, 38.69892843067646, 38.46101179718971, 43.55216860771179, 41.95460893213749, 39.54423867166042, 39.81708683073521, 40.33792868256569, 41.070092394948006, 39.62136693298817, 38.80958989262581, 45.51954343914986, 50.00335983932018, 50.94010457396507, 50.89357987046242, 44.20436941087246, 39.6913705766201, 39.70308154821396, 36.892911940813065, 46.82475820183754, 52.07074150443077, 51.76545448601246, 50.9235754609108, 49.353089332580566, 51.02868162095547, 50.86623653769493, 50.69939509034157, 48.115833923220634, 48.78411166369915, 51.93771444261074, 51.799322068691254, 51.31851866841316, 39.7167494148016, 21.585686020553112, 3.800768139772117, 3.6249185632914305, 5.675551202148199, 6.1274742521345615, 12.646868973970413, 4.207663368433714, 1.2203598534688354, 0.9805736015550792, 0.2896311163203791, 0.09541969309793785, 0.23834779160097241, 0.430569383315742, 1.6239037807099521, 15.043289232999086, 35.91119661927223, 37.75551125407219, 45.72871461510658, 38.391084149479866, 12.944959178566933, 0.20771675946889445, 0.22062466683564708, 0.15136226546019316, 0.24473970173858106, 0.1405120367417112, 0.12999806029256433, 0.12022399765555747, 0.20667067263275385, 0.19694939895998687, 0.11472224170574918, 0.15712809981778264, 0.10870499740121886, 0.15152252482948825, 0.1512661573360674, 0.11167276432388462, 0.1563581809750758, 0.1404849483515136, 0.19749493687413633, 0.15014647913631052, 0.08289988443721086, 0.13781556190224364, 0.26477332517970353], [0.07362588832620531, 0.02276716670166934, 0.02105467763612978, 0.05393114064645488, 0.047192988931783475, 0.07841244398150593, 0.020541096600936726, 0.053329808069975115, 0.03881472053762991, 0.034571762080304325, 0.07756668506772257, 0.02214474414358847, 0.023375134078378323, 0.03330726489366498, 0.013062907692074077, 0.03362762407050468, 0.0868982495740056, 0.056495438984711654, 0.08379858816624619, 0.050102619716199115, 0.013452858984237537, 0.02049458991677966, 0.045795183468726464, 0.047564893975504674, 0.029611872269015294, 0.01201357488753274, 0.08911255106795579, 0.5113680101931095, 8.522974960505962, 33.09514492750168, 32.36092932522297, 28.779549300670624, 18.587316311895847, 18.60884215682745, 5.1306400168687105, 0.20942239294527099, 0.3906143788481131, 0.11816815211204812, 0.07489404801162891, 0.04260442343365867, 0.22443419991759583, 1.1107511725276709, 0.20964502240531147, 0.24230556125985458, 1.7616067291237414, 10.558897163718939, 30.46927873045206, 50.68058229982853, 53.721433728933334, 55.737658739089966, 53.020747527480125, 51.91708914935589, 50.155511274933815, 46.047361716628075, 43.30868527293205, 43.03424119949341, 41.8321643024683, 41.67964428663254, 38.61873373389244, 38.73413734138012, 38.678196743130684, 43.56161870062351, 48.63919883966446, 52.74724580347538, 50.039556697010994, 48.35981883108616, 53.60665328800678, 49.61923085153103, 49.364895299077034, 48.28109085559845, 48.43537397682667, 48.49727265536785, 49.79514621198177, 51.43878601491451, 45.31417965888977, 36.97265826165676, 36.96189343929291, 37.49428287148476, 37.42595113813877, 36.89546160399914, 36.44862078130245, 36.95698410272598, 40.01994654536247, 46.44141957163811, 47.27784588932991, 48.85372772812843, 48.623330891132355, 51.45426258444786, 43.0236853659153, 29.521571584045887, 46.14035792648792, 49.00342829525471, 49.57646034657955, 46.930795311927795, 45.22341772913933, 41.55457019805908, 36.768495216965675, 35.06270594894886, 35.56175597012043, 35.37919856607914, 35.23103691637516, 34.66540306806564, 36.810771748423576, 35.7329747825861, 37.2150282561779, 37.6092267036438, 37.340759709477425, 35.498774349689484, 35.61882510781288, 36.69027641415596, 37.06516049802303, 39.1507887840271, 46.232157200574875, 47.8429439663887, 48.15348990261555, 47.439808398485184, 45.81292949616909, 37.96899139881134, 34.61918234825134, 33.55792589485645, 37.14252434670925, 44.241204634308815, 46.38367407023907, 48.7234441190958, 48.461269587278366, 48.4524692595005, 46.69324725866318, 46.376443058252335, 46.36170744895935, 47.351459339261055, 49.69803862273693, 49.79995295405388, 43.44201251864433, 25.516400299966335, 5.5750503949820995, 0.38223565032240003, 3.557720356620848, 3.3946972293779254, 16.317701898515224, 13.125788625329733, 1.7407973832450807, 0.37624343123752624, 0.18666949588805437, 0.07701912851189263, 0.14930250879842788, 0.07975708198500797, 0.05077189962321427, 3.1153404945507646, 19.280359223484993, 28.93521174788475, 27.030744440853596, 29.063851945102215, 23.027811236679554, 1.935805412940681, 0.01971747409697855, 0.046655581245431677, 0.016747404661145993, 0.08753851521760225, 0.008124625510390615, 0.03544162966136355, 0.030222071654861793, 0.024393585190409794, 0.013256936636025785, 0.0643062723975163, 0.01443438917704043, 0.019098936681984924, 0.01981045221327804, 0.06354650613502599, 0.007234946297103306, 0.06541890761582181, 0.07792185468133539, 0.09211705430061556, 0.11015398136805743, 0.06298311956925318, 0.03575100876332726, 0.06589276148588397, 0.005161594417586457, 0.046353950165212154, 0.11021723461453803, 0.05849022803886328, 0.02187012167269131, 0.0815312602207996, 0.02149525174900191, 0.046922643086872995, 0.014773176808375865, 0.06101343366026413, 0.01483383068261901, 0.05302362020302098, 0.034663888582144864, 0.03940412680094596, 0.02510343460016884, 0.001386078486120823, 0.10543173280893825, 0.07076720969052985, 0.0333846337889554, 0.06412302129319869, 0.02102421804011101, 0.05620078038191423, 0.057378004712518305, 0.03407729134778492, 0.007075420262481202, 0.002099236135109095, 0.08167581574525684, 0.761500810040161, 14.42959651350975, 39.09148916602135, 41.083726063370705, 31.40598926693201, 19.91976611316204, 19.313960820436478, 5.267266910523176, 0.26041763077955693, 0.4047727456782013, 0.1508625180576928, 0.09581362508470193, 0.009828856327658286, 0.34316715609747916, 0.4448638600297272, 0.6794313888531178, 1.148706148378551, 2.399818701669574, 13.44254532828927, 35.11947110295296, 52.271146550774574, 54.585435166954994, 56.077991276979446, 54.84597958624363, 53.031466752290726, 51.61597430706024, 48.92235964536667, 45.490129217505455, 43.81845071911812, 43.83288234472275, 42.356722354888916, 39.964560717344284, 40.239928141236305, 40.71147903800011, 45.59494659304619, 50.2945040166378, 53.10418725013733, 51.174741983413696, 50.40093630552292, 52.885311394929886, 51.39930993318558, 50.63600309193134, 50.017776265740395, 50.32724305987358, 49.38734069466591, 50.97647242248058, 52.77705140411854, 47.090002968907356, 38.915482610464096, 37.99355328083038, 39.614667892456055, 39.34857577085495, 37.86220572888851, 38.27691927552223, 38.84978413581848, 43.08775752782822, 48.34026888012886, 50.32979652285576, 50.29907517135143, 51.39620169997215, 53.279160261154175, 43.66583950817585, 33.06962549686432, 48.25536623597145, 51.48981347680092, 51.67370840907097, 49.592643678188324, 46.6286089271307, 43.20374250411987, 38.53892661631107, 36.677581295371056, 36.71528287231922, 36.85757763683796, 36.86535581946373, 35.1321130245924, 38.73605623841286, 37.17664651572704, 39.53802980482578, 39.71704199910164, 38.51736657321453, 36.59010238945484, 38.26766297221184, 38.04843753576279, 38.23349520564079, 41.240334659814835, 46.61275237798691, 50.12783735990524, 49.11290802061558, 50.08832708001137, 47.46680215001106, 38.918226063251495, 35.9300322085619, 36.29865802824497, 39.58967283368111, 47.1914005279541, 48.947001323103905, 50.4503108561039, 48.68419982492924, 49.08001318573952, 49.310915395617485, 49.70284156501293, 47.52037927508354, 49.51683774590492, 49.97476637363434, 52.23808832466602, 43.62204305827618, 28.307597525417805, 7.6003569178283215, 2.1801952365785837, 5.2259184792637825, 7.264405069872737, 11.245269533246756, 10.893259271979332, 2.2570532374083996, 0.3964471846120432, 0.35827110812533647, 0.08823283889796585, 0.37433154007885605, 0.03971690122853033, 0.12783388345269486, 2.863342291675508, 20.963910184800625, 31.93047322332859, 29.136545844376087, 36.49671100080013, 27.806881293654442, 4.035663697868586, 0.01253487704161671, 0.02227508568466874, 0.02980364137329161, 0.05235075572272763, 0.041159944303217344, 0.12776257790392265, 0.01502186771176639, 0.03207408633898012, 0.05894530186196789, 0.03185459616361186, 0.022472203818324488, 0.06994666895479895, 0.033006023440975696, 0.0407394026115071, 0.016084809649328236, 0.019912133866455406, 0.07342686658375897, 0.039155785634648055, 0.007292093987416592, 0.01998485877265921, 0.03750318974198308, 0.017414767971786205, 0.10614478829666041, 0.17676044401014224, 0.18218359909951687, 0.13986182631924748, 0.12814175599487498, 0.15005071240011603, 0.08837955407216214, 0.1603203293052502, 0.1280338180367835, 0.18581328011350706, 0.1228965976042673, 0.10034603226813488, 0.10749480687081814, 0.30350535933393985, 0.07574518007459119, 0.07899579431978054, 0.27167422987986356, 0.2892699872609228, 0.23507668665843084, 0.14841889293165877, 0.14361065172124654, 0.18046018376480788, 0.12148912195698358, 0.08200960408430547, 0.11462035225122236, 0.04406184933031909, 0.3130849718581885, 0.907723376294598, 15.627622827887535, 47.556234151124954, 49.8034031689167, 41.23275026679039, 30.440478175878525, 24.31137666106224, 6.894397549331188, 0.5897963361348957, 1.615651692263782, 0.5683293286710978, 0.3067198977805674, 0.3288841381436214, 0.6387675739824772, 2.879625605419278, 1.4023735304363072, 1.3159272191114724, 2.817634781822562, 12.305040266364813, 35.75796604156494, 51.723664328455925, 56.051407903432846, 58.97442765533924, 57.898408994078636, 56.57399006187916, 54.00229565799236, 50.735382959246635, 47.272096797823906, 46.1203595995903, 47.090850323438644, 44.84785348176956, 41.87780365347862, 42.567181661725044, 43.29345569014549, 47.620393708348274, 52.363329604268074, 54.80866938829422, 51.80126756429672, 51.33187495172024, 53.556404784321785, 50.274577885866165, 52.702195420861244, 51.30616553127766, 50.67689649760723, 50.23324370384216, 53.49788412451744, 55.27017742395401, 48.73556166887283, 40.377127379179, 40.55878043174744, 41.62239655852318, 41.00185565650463, 40.15274941921234, 39.15556512773037, 39.945979714393616, 44.51287865638733, 50.49151964485645, 51.91138185560703, 52.27550491690636, 52.358519062399864, 54.52586956322193, 47.688250467181206, 37.14541599154472, 51.96038022637367, 53.882811069488525, 54.32145193219185, 51.90445102751255, 50.1373216509819, 45.434560999274254, 41.203856617212296, 38.68291608989239, 38.98154966533184, 39.52471911907196, 38.65798182785511, 37.76210010051727, 41.26185670495033, 38.61023738980293, 40.93633957207203, 42.02123075723648, 41.37976057827473, 38.98118108510971, 38.600034937262535, 40.171455815434456, 42.31352247297764, 41.831636130809784, 50.13164095580578, 52.68202230334282, 51.55044682323933, 51.320965737104416, 49.015663638710976, 40.64988054335117, 38.32272581756115, 37.84323334693909, 42.33810715377331, 47.84927062690258, 50.83432964980602, 51.08442842960358, 49.96193066239357, 49.815737307071686, 48.91631416976452, 50.2690339833498, 50.08556842803955, 50.95002964138985, 52.051715925335884, 53.52097928524017, 44.94759812951088, 27.73201771080494, 6.436063768342137, 1.0160540789365768, 7.969416864216328, 13.170678466558456, 27.144544534385204, 26.061405055224895, 6.74753163009882, 0.4748501884751022, 0.45644338242709637, 0.2194078266620636, 0.4255633003776893, 0.4648867668583989, 0.22270680667134002, 4.702795799821615, 25.416636653244495, 39.97793599963188, 39.50627490878105, 41.31178602576256, 31.43855731934309, 3.7698002764955163, 0.16223714832449332, 0.1741898967884481, 0.16340646136086434, 0.10796316142659634, 0.19187198078725487, 0.13961356307845563, 0.16533414542209357, 0.10055184466182254, 0.16443669592263177, 0.22355846565915272, 0.09887229025480337, 0.17126881837612018, 0.17191717342939228, 0.1237530360231176, 0.11124826327431947, 0.14002842362970114, 0.2667217003181577, 0.2541584463324398, 0.18205238739028573, 0.11903475795406848, 0.1439390075393021, 0.2096190323936753], [0.048244764329865575, 0.021530962039832957, 0.036217971792211756, 0.04950354697939474, 0.021383745915954933, 0.022444050446210895, 0.02281704273627838, 0.03223286883439869, 0.03068480629735859, 0.033475012533017434, 0.03498337944620289, 0.03714426486112643, 0.030553405340469908, 0.08012702033738606, 0.07318301912164316, 0.0383861376758432, 0.04923767628497444, 0.0662238484073896, 0.04745944963360671, 0.021229551748547237, 0.04881579130596947, 0.06146258885564748, 0.023353300093731377, 0.03963045957789291, 0.0255988218850689, 0.031286322555388324, 0.04437537703779526, 0.2286806798656471, 3.2650944963097572, 16.075932271778584, 29.300398752093315, 29.922907948493958, 21.31875604391098, 23.321170695126057, 11.101431101560593, 1.9181409920565784, 0.4283256927737966, 0.08126181608531624, 0.10279929789248854, 0.10613305494189262, 0.025990584945247974, 0.12491424480685964, 0.9776133229024708, 0.8601492759771645, 0.4301224322989583, 2.0827385410666466, 13.434319719672203, 37.3989649862051, 52.30814516544342, 53.92167918384075, 52.427112981677055, 50.88527351617813, 49.33624103665352, 46.3199894875288, 46.5502305328846, 43.14901404082775, 43.12182269990444, 41.391764134168625, 37.60096214711666, 40.04238814115524, 38.07455353438854, 41.2571981549263, 48.04708421230316, 50.50636924803257, 52.40027502179146, 49.65861573815346, 48.96765321493149, 49.3660694360733, 50.184838101267815, 50.83490341901779, 49.289381951093674, 47.15552665293217, 50.873315557837486, 49.32170681655407, 49.435822293162346, 44.54205349087715, 39.51005570590496, 36.79705448448658, 37.26941093802452, 37.199251502752304, 36.70668013393879, 36.255963519215584, 40.18900707364082, 38.8186714053154, 44.45779301226139, 46.65042355656624, 53.08736555278301, 48.613341227173805, 57.746120765805244, 38.67950767278671, 39.55164447426796, 53.35261411964893, 45.558593943715096, 47.00993746519089, 44.1752515733242, 42.495912685990334, 38.98615501821041, 37.483639642596245, 37.64088660478592, 37.41455934941769, 35.2177794277668, 35.948579013347626, 35.66980317234993, 34.095961824059486, 36.51179239153862, 35.97362346947193, 34.58251051604748, 36.84265583753586, 36.55215002596378, 36.99132665991783, 37.88584426045418, 40.57310186326504, 46.04708433151245, 47.27043628692627, 50.00456817448139, 47.98527292907238, 48.19098249077797, 40.419073328375816, 35.21073840558529, 35.825670808553696, 37.0477270334959, 45.21099999547005, 47.23666749894619, 46.43896110355854, 48.163965940475464, 46.942080706357956, 45.73492728173733, 48.289344012737274, 47.08488844335079, 50.71029290556908, 48.13647821545601, 43.505495712161064, 29.276815317571163, 10.262657459825277, 0.6987901031970978, 2.753992946818471, 4.73458394408226, 2.537412168458104, 5.300714140757918, 5.79021954908967, 0.553968355525285, 0.24997270375024527, 0.17900061677210033, 0.14852307562250644, 0.18716700200457126, 0.06358033322612755, 0.5302670679520816, 5.349949998781085, 24.946427084505558, 28.205983377993107, 31.55841238796711, 28.18786785006523, 11.802143901586533, 0.5306452664081007, 0.03539183526299894, 0.03505533437419217, 0.03857289171719458, 0.01194723894514027, 0.06042402739694808, 0.02789210087939864, 0.05126809213834349, 0.0641350811929442, 0.02456264272041153, 0.023573816288262606, 0.03909728955477476, 0.02112301459419541, 0.0711237448558677, 0.033672178906272165, 0.06278491418925114, 0.04821941256523132, 0.02677748412679648, 0.021701368423237, 0.038711239176336676, 0.02525776049878914, 0.03793456678977236, 0.018031774707196746, 0.033621419715927914, 0.04535654079518281, 0.03424385155085474, 0.011160457579535432, 0.022910184125066735, 0.0510763397323899, 0.019707805768121034, 0.0502531198435463, 0.02456843703839695, 0.04656897632230539, 0.09857224737061188, 0.06120334182924125, 0.07862783008022234, 0.02940322672657203, 0.029907833340985235, 0.041782264815992676, 0.035372105267015286, 0.01281234935959219, 0.02167521699448116, 0.035115771170239896, 0.0351677808794193, 0.06244420903385617, 0.04515118482231628, 0.014375390292116208, 0.018690250799409114, 0.04550148965790868, 0.05557915006647818, 0.2596606401493773, 5.369194066151977, 29.165285602211952, 36.84395916759968, 38.31395968794823, 24.1927470266819, 29.660847410559654, 11.077236849814653, 1.1744614038616419, 0.9373151196632534, 0.15981120115611702, 0.03473681572359055, 0.040658122597960755, 0.18688832555199042, 0.44799465453252196, 0.28604125895071775, 2.081572716124356, 1.942064508330077, 3.040506597608328, 16.26011598855257, 42.19025328755379, 55.943736881017685, 56.205444037914276, 55.3096991032362, 53.29825423657894, 50.75160428881645, 47.34595723450184, 47.14899480342865, 44.31808590888977, 43.399876579642296, 42.794998437166214, 40.0335194170475, 41.12226739525795, 40.96783988177776, 42.33117252588272, 49.97005082666874, 52.83388115465641, 53.29951956868172, 49.74284201860428, 49.54978197813034, 50.00709883868694, 50.9329267591238, 51.97199620306492, 49.64191563427448, 47.521994188427925, 50.70088841021061, 52.304246574640274, 50.30154123902321, 44.57952708005905, 40.053931921720505, 37.60075315833092, 39.07795809209347, 39.366100430488586, 37.98643246293068, 37.720667123794556, 41.30867779254913, 40.70553995668888, 45.35527445375919, 49.559140875935555, 54.169881865382195, 50.54475478827953, 57.47267223894596, 41.69217601418495, 43.6263520270586, 54.872885942459106, 47.45141297578812, 48.924464732408524, 47.36044965684414, 44.897456020116806, 41.520178243517876, 39.04792070388794, 38.83982867002487, 38.479767590761185, 36.42630457878113, 38.38726535439491, 37.88292221724987, 36.017754301428795, 38.23477953672409, 37.95941211283207, 36.57783284783363, 38.72193239629269, 38.3854528516531, 39.02091175317764, 39.506149515509605, 41.77887596189976, 47.28106431663036, 49.25839461386204, 51.02904260158539, 49.599984884262085, 50.059178844094276, 42.06269793212414, 36.178975850343704, 37.249116227030754, 38.937297239899635, 46.983669474720955, 47.963633090257645, 48.149234130978584, 48.50488364696503, 47.31053173542023, 48.24222654104233, 48.94796647131443, 47.42943875491619, 49.625162333250046, 50.25954969227314, 46.54548458755016, 33.12493532896042, 12.978432532399893, 2.103502289392054, 3.141633183695376, 7.09363273344934, 8.252953849732876, 8.438583388924599, 8.640288915485144, 2.3292624251917005, 0.3509548382135108, 0.3584963647881523, 0.2258450523368083, 0.46941309585236013, 0.19746701727854088, 0.5263825482688844, 5.426757177338004, 27.032494246959686, 32.42960684001446, 35.93101255595684, 32.20380015671253, 17.10135094821453, 0.9229025524109602, 0.09404245996847749, 0.09429268990061246, 0.021322125394362956, 0.08068025432294235, 0.058374067084514536, 0.04189847029920202, 0.02335573433811078, 0.03308832390757743, 0.0049836158086691285, 0.01378351360472152, 0.020214217656757683, 0.03099326142546488, 0.059692136201192625, 0.019309773415443487, 0.058522125546005554, 0.03611118045228068, 0.01537658275992726, 0.04890078205789905, 0.045793762255925685, 0.05512973883014638, 0.016505369894730393, 0.011934534304600675, 0.09787717412109487, 0.17956873081857339, 0.15322989493142813, 0.2457554792636074, 0.10662572225555778, 0.13308169873198494, 0.1448117138352245, 0.1823189074639231, 0.11251395160797983, 0.08243173026130535, 0.23318078136071563, 0.16301852592732757, 0.18150996649637818, 0.20357983536086977, 0.19203470408683643, 0.15409694606205449, 0.13575363816926256, 0.12891872524050996, 0.15815279795788229, 0.12408961483743042, 0.13586257060524076, 0.1406227651750669, 0.11364924459485337, 0.15508202835917473, 0.08106339548248798, 0.21775849250843748, 0.16801405552541837, 0.2967835497111082, 5.883565815165639, 32.387440502643585, 47.117125913500786, 44.94247980415821, 31.73121191561222, 36.16784244775772, 13.739222958683968, 8.460284024477005, 2.026438624598086, 0.21784136071801186, 0.27579694928135723, 0.21516044129384682, 0.3595101088285446, 0.8304252522066236, 2.5015238067135215, 3.0508862156420946, 1.1697084526531398, 3.413536143489182, 15.260801911354065, 41.64431378245354, 55.1062998175621, 58.54153208434582, 58.14814679324627, 56.27623803913593, 53.88837777078152, 51.00132308900356, 50.021283477544785, 47.59961262345314, 45.253762900829315, 45.65156735479832, 42.520626559853554, 43.32217454910278, 42.27017059922218, 44.51218329370022, 51.03982262313366, 55.52648887038231, 54.51908312737942, 50.88439576327801, 50.62985502183437, 52.04378955066204, 53.12850974500179, 53.74103307723999, 50.278221890330315, 46.912598088383675, 52.027963399887085, 55.08738823235035, 53.367794305086136, 48.659812733531, 43.08905325829983, 39.98300492763519, 40.35519115626812, 41.08823262155056, 39.65634025633335, 40.96998296678066, 43.867293298244476, 42.2658996284008, 47.015131786465645, 50.89471980929375, 57.068757712841034, 52.531960755586624, 58.73773455619812, 46.33580803871155, 45.59583194553852, 56.61644138395786, 50.427789464592934, 50.63267447054386, 49.483182951807976, 46.04197360575199, 42.85713650286198, 40.54256670176983, 40.517199262976646, 39.85890358686447, 38.533508107066154, 39.41856041550636, 39.78259228169918, 36.49741776287556, 40.406047627329826, 39.54448185861111, 39.08421255648136, 40.94870790839195, 40.0944035500288, 40.442567467689514, 42.07864947617054, 43.425361812114716, 49.43551830947399, 52.531386986374855, 51.636789590120316, 49.776975587010384, 53.07924538850784, 42.74152010679245, 38.44357073307037, 38.908433988690376, 41.88510686159134, 49.34154935181141, 50.429343581199646, 48.72633196413517, 49.57094304263592, 46.83540903031826, 48.05750325322151, 50.749050825834274, 48.93903315067291, 51.89441576600075, 51.17118537425995, 46.117129772901535, 32.80093051493168, 12.445933856070042, 1.3633164949715137, 4.5535041857510805, 10.085979290306568, 8.655733186751604, 13.341724388301373, 14.20440349727869, 3.9054092997685075, 0.5170659231953323, 0.9005954931490123, 0.3688541636802256, 0.7657324173487723, 0.19456737209111452, 1.0172577830962837, 6.828865315765142, 32.31375865638256, 39.62601028382778, 41.7610777169466, 38.08500297367573, 17.222361154854298, 1.02975994348526, 0.1717796386219561, 0.21182304772082716, 0.10449906840221956, 0.1813893674989231, 0.16756734199589118, 0.13444137264741585, 0.10259963048156351, 0.12924875831231475, 0.09986627832404338, 0.11039523131330498, 0.10226947866613045, 0.11553588046808727, 0.17936622840352356, 0.12992240575840697, 0.13348106323974207, 0.12136916120653041, 0.09739586166688241, 0.15690342203015462, 0.18755971686914563, 0.14628487697336823, 0.1161991452681832, 0.09860364021733403], [0.00721983385119529, 0.04456061709788628, 0.05467089118610602, 0.03772610863961745, 0.01327815556578571, 0.03235517106077168, 0.011252853109908756, 0.04372835413960274, 0.045418732770485803, 0.012795764214388328, 0.03671669874165673, 0.04460419229872059, 0.07400706279440783, 0.05100811780721415, 0.05540562480746303, 0.05872912166523747, 0.033012149870046414, 0.011862670289701782, 0.039025857840897515, 0.027227398168179207, 0.024799549246381503, 0.09674614106188528, 0.0487056120618945, 0.054798759520053864, 0.041822014245553873, 0.057919041501008905, 0.031406153429998085, 0.023304889800783712, 0.1746722185635008, 4.756968067958951, 23.671473897993565, 29.145258776843548, 21.68413683772087, 21.816671825945377, 21.520327627658844, 5.968293668702245, 0.757372984662652, 0.026700109665398486, 0.006051532918718294, 0.046616228864877485, 0.12506914586992934, 0.024610871187178418, 0.10045173636171967, 1.4463529642671347, 1.944603722076863, 0.3255027352133766, 3.3154622185975313, 19.316512383520603, 40.63551351428032, 56.691483557224274, 55.00460967421532, 51.42713963985443, 49.696165323257446, 50.22162392735481, 48.54967184364796, 48.81837822496891, 47.17405065894127, 47.584945410490036, 46.16975694894791, 42.82240256667137, 38.221731036901474, 38.336408883333206, 45.33746860921383, 50.6619480997324, 52.81031861901283, 52.4726003408432, 51.7140394449234, 51.09938062727451, 54.363629668951035, 53.184062764048576, 51.38712398707867, 48.91852185130119, 49.68328021466732, 51.79034315049648, 50.676831901073456, 48.83213348686695, 42.77101032435894, 37.74052485823631, 37.44424715638161, 36.17774851620197, 37.41434656083584, 36.66948772966862, 38.350376933813095, 37.71159701049328, 42.334390953183174, 43.15875671803951, 48.14326085150242, 48.12864303588867, 52.58661322295666, 42.8030464053154, 41.07726261019707, 53.124326169490814, 49.01377134025097, 49.38996635377407, 44.69166286289692, 44.3023319542408, 40.70740185678005, 40.888743326067924, 39.65711921453476, 35.46609990298748, 37.94539466500282, 35.58345280587673, 35.12699469923973, 33.821228966116905, 35.327836722135544, 35.5461236089468, 36.02841652929783, 35.47465704381466, 36.28212131559849, 37.01654210686684, 37.36901119351387, 42.63535760343075, 46.99712075293064, 46.28273628652096, 48.00746373832226, 46.38143599033356, 46.667940616607666, 42.044071331620216, 36.63457900285721, 34.47630621492863, 37.0351193100214, 45.25875583291054, 45.85427887737751, 49.00163099169731, 44.89041119813919, 46.60652071237564, 43.42850424349308, 49.457636922597885, 43.9004123210907, 48.15852843225002, 45.43799601495266, 34.58054982125759, 13.637691456824541, 2.094204188324511, 1.179043126758188, 4.771748799830675, 4.337172294035554, 8.906080853193998, 7.261409880593419, 9.070822913199663, 1.084571408573538, 0.5309309635777026, 0.0978785619372502, 0.12413038843078539, 0.47936532588209957, 0.3665263729635626, 1.2417021207511425, 9.96281174942851, 23.10474380850792, 27.032655738294125, 28.094189576804638, 24.790293462574482, 5.208550086244941, 0.08473013192997314, 0.08583949427702464, 0.08350011121365242, 0.021019828236603644, 0.057590767319197766, 0.016383900729124434, 0.012415511864674045, 0.07244170265039429, 0.008574036746722413, 0.04547316930256784, 0.08119580947095528, 0.06441723089665174, 0.06137636613857467, 0.00418392710344051, 0.03524926127283834, 0.04063398424477782, 0.0369631214562105, 0.06800109913456254, 0.05339634903066326, 0.07302762824110687, 0.07968407691805623, 0.03404921961191576, 0.05237263423623517, 0.08038270505494438, 0.027798751689260826, 0.056131200326490216, 0.06216656787728425, 0.03594017107388936, 0.047189567630994134, 0.02126434734236682, 0.06943105443497188, 0.03441006665525492, 0.05006896702980157, 0.08156852345564403, 0.026921403259621002, 0.04049018942168914, 0.03449172145337798, 0.02908545393438544, 0.03951946768211201, 0.05701590715034399, 0.011182474318047753, 0.0639912900805939, 0.016190962742257398, 0.019516940228641033, 0.07901719785877503, 0.038808942917967215, 0.10908653552178293, 0.05688872159225866, 0.03093685820203973, 0.025759259369806387, 0.06422390142688528, 0.9476251539308578, 10.268947072327137, 32.01437272131443, 37.65643157064915, 26.688472107052803, 26.99758742004633, 23.715654127299786, 8.964990992099047, 1.3217190583236516, 0.06739783697412349, 0.0801801506895572, 0.1959041878581047, 0.08689752969075926, 0.030256670579547063, 0.35450527269858867, 1.4564789459109306, 4.409097684547305, 1.8937011784873903, 3.7888543540611863, 20.06375178694725, 45.24124637246132, 56.911799535155296, 55.588224157691, 54.70929332077503, 52.470366060733795, 52.30587288737297, 49.41343009471893, 48.65100100636482, 49.86620619893074, 48.28830286860466, 47.44435675442219, 42.70229861140251, 39.50853958725929, 41.660056337714195, 47.29780621826649, 50.876503586769104, 54.19975586235523, 52.234163135290146, 52.510317116975784, 52.82019428908825, 56.15060918033123, 53.31233628094196, 52.07545705139637, 49.410242065787315, 50.72442814707756, 54.142192751169205, 52.4162607640028, 48.932809084653854, 43.68167705833912, 39.73639436066151, 40.27512565255165, 37.9409185051918, 39.41379927098751, 36.891772001981735, 40.94380237162113, 39.44724887609482, 44.08836543560028, 45.37981353700161, 49.51623737812042, 49.510013312101364, 54.39022444188595, 44.06971983611584, 43.03093917667866, 53.92968535423279, 52.22274474799633, 50.44910632073879, 48.04433315992355, 46.64183981716633, 42.5678276270628, 42.27569930255413, 42.025102749466896, 37.433467134833336, 38.64357680082321, 36.36858567595482, 36.100779846310616, 35.05258709192276, 36.96576543152332, 36.15016579627991, 37.392322942614555, 36.15644685924053, 38.91116984188557, 38.339513316750526, 39.56070698797703, 44.367620050907135, 47.44350180029869, 48.22950482368469, 48.60951103270054, 48.166454806923866, 48.57214003801346, 44.6630883961916, 38.16181965172291, 35.78829601407051, 38.842241540551186, 46.45722672343254, 46.654895916581154, 48.654766604304314, 46.40303023159504, 47.95060358941555, 46.41453221440315, 50.91093733906746, 45.88286854326725, 50.505240708589554, 46.74096129834652, 36.1335226893425, 15.997662171721458, 3.3640737226232886, 2.738450118340552, 4.463139334693551, 5.750010581687093, 10.102053377777338, 5.18484553322196, 8.19928077980876, 2.4607040220871568, 0.6013939075637609, 0.6406729342415929, 0.3631521243369207, 0.199485466000624, 0.45591426081955433, 1.4371056854724884, 11.164292078465223, 28.905406147241592, 31.572891511023045, 32.23458990454674, 29.46234606206417, 7.270163660869002, 0.15617261437000707, 0.012836653768317774, 0.030226661838241853, 0.04963061750459019, 0.06401019258191809, 0.005913253180551692, 0.02662196337041678, 0.016985663751256652, 0.008883241443982115, 0.012210813620185945, 0.11234765115659684, 0.04213593900203705, 0.03260148616391234, 0.010315901872672839, 0.06744206897565164, 0.017398980635334738, 0.009799334620765876, 0.025483332574367523, 0.15650638786610216, 0.04356873672804795, 0.050096745617338456, 0.04376499025966041, 0.0022428702368415543, 0.16783377301180735, 0.19159800955094397, 0.13025424967054278, 0.13498931512003765, 0.10207011553575285, 0.13714319095015526, 0.11491131866932847, 0.13293064199388027, 0.16036687680752948, 0.11252785203396343, 0.11417529371101409, 0.13880591344786808, 0.16831925633596256, 0.11248264781897888, 0.14056726737180725, 0.13648999709403142, 0.08833965621306561, 0.11945788603043184, 0.1887136822915636, 0.171198210446164, 0.14887221157550812, 0.20303729572333395, 0.11540007486473769, 0.19922247854992747, 0.20096035092137754, 0.10417867582873441, 0.16418904124293476, 0.2229162259027362, 1.3207184057682753, 13.46438655629754, 38.768658488988876, 46.14350415766239, 32.25727088749409, 34.79403756558895, 27.420538924634457, 13.406125232577324, 2.9715091874822974, 0.1339262182591483, 0.29210689128376544, 0.2238159760599956, 0.3415342827793211, 0.31976712110918015, 1.1867720307782292, 4.8841101955622435, 6.989856027066708, 1.7649104143492877, 4.2638785019516945, 22.795527800917625, 45.14299884438515, 58.6873834580183, 59.25195336341858, 55.81108219921589, 54.26468297839165, 55.0559601187706, 52.421899661421776, 51.46835222840309, 52.14195728302002, 50.48474080860615, 51.319970190525055, 46.13525100052357, 42.18049921095371, 42.711691707372665, 49.132636561989784, 53.91784518957138, 56.98772706091404, 53.843673169612885, 53.66971470415592, 52.46660426259041, 57.17458203434944, 54.798957109451294, 53.18574607372284, 50.50328001379967, 51.04938291013241, 57.45532616972923, 53.74727614223957, 53.23022648692131, 47.35316924750805, 43.41468818485737, 43.17522883415222, 39.90607425570488, 41.34079746901989, 39.72966872155666, 41.017655208706856, 42.08123333752155, 45.923347771167755, 46.512832939624786, 51.84224456548691, 54.35750059783459, 55.279502123594284, 48.144028410315514, 44.57834534347057, 53.28210890293121, 53.94575849175453, 53.79886597394943, 50.298364609479904, 47.77547478675842, 43.84170927107334, 44.57641504704952, 43.84077452123165, 38.11008542776108, 40.730462819337845, 38.48081633448601, 37.701964527368546, 36.33549705147743, 38.01518552005291, 38.50853584706783, 40.194566175341606, 38.14610369503498, 41.43754407763481, 41.38406954705715, 41.84512160718441, 46.893165931105614, 50.0897292047739, 49.58673499524593, 50.00606909394264, 49.40942510962486, 51.576103046536446, 46.05287902057171, 40.222802460193634, 37.7026978880167, 41.14462159574032, 49.514721259474754, 48.485219702124596, 50.087107345461845, 46.503751426935196, 48.58989268541336, 46.614800468087196, 50.923214480280876, 47.37738534808159, 50.68908244371414, 45.957819521427155, 36.374190375208855, 15.562044996768236, 3.341564442962408, 2.6196186197921634, 9.158311318606138, 12.163453213870525, 14.577030502259731, 13.124597389250994, 17.758360393345356, 5.6340887770056725, 0.7562960393261164, 1.7913740943185985, 1.378077040426433, 1.9606506172567606, 0.9493203973397613, 1.9972390914335847, 13.184867855161428, 32.64584943652153, 37.81693495810032, 39.62243087589741, 33.31796117126942, 7.02018172480166, 0.19224315852625296, 0.16380711720557883, 0.21334329270757735, 0.2251088566845283, 0.17165823810501024, 0.19772519561229274, 0.10494017871678807, 0.11480626766569912, 0.08144275168888271, 0.11356366012478247, 0.2387230659951456, 0.15518854139372706, 0.26739046443253756, 0.14153669035295025, 0.13154509681044146, 0.1314172989805229, 0.13345459825359285, 0.1482880226103589, 0.2184148330707103, 0.1414510910399258, 0.2716334711294621, 0.11714110878529027, 0.13307620683917776], [0.1334027518169023, 0.06542244766023941, 0.08118034311337397, 0.020177806036372203, 0.034999324489035644, 0.0447196741879452, 0.011430828471929999, 0.014263971661421238, 0.06294731094385497, 0.020091486840101425, 0.0832951300253626, 0.03079672773310449, 0.038581482076551765, 0.06081068262574263, 0.024562464604969136, 0.05590639637375716, 0.06613131743506528, 0.03523894542013295, 0.04886969349172432, 0.04262032023689244, 0.028725740521622356, 0.04987082473235205, 0.06294716993579641, 0.05400597881816793, 0.08169147506123409, 0.044800995019613765, 0.11365540442056954, 0.05575515780947171, 0.21828767348779365, 4.317078972235322, 16.255740523338318, 31.620689146220684, 30.62265370041132, 31.14271279424429, 24.890247099101543, 7.666910346597433, 1.6865289327688515, 0.10057833933387883, 0.09758419648278505, 0.16182960534933954, 0.08262394650955684, 0.18459548999089748, 0.1993568814941682, 0.42609274853020906, 2.8572714049369097, 1.5127693628892303, 0.7771198125556111, 2.49425170943141, 22.133276537060738, 48.96053619682789, 56.27982124686241, 51.272050961852074, 53.506076484918594, 49.180658385157585, 49.732943549752235, 48.62012006342411, 50.72277903556824, 49.26866926252842, 48.56155380606651, 44.89604629576206, 41.040343791246414, 37.59380333125591, 42.128852382302284, 47.53527447581291, 50.34691080451012, 51.3397291302681, 53.2333879172802, 50.576912462711334, 50.686829164624214, 50.026796981692314, 52.36675702035427, 48.44056449830532, 48.212417140603065, 49.88955594599247, 52.019284665584564, 48.84172037243843, 48.412278816103935, 42.10414230823517, 38.22200462222099, 36.99422210454941, 38.631033673882484, 37.512195110321045, 38.82219761610031, 38.64377439022064, 39.29474025964737, 40.17376609146595, 47.2169541567564, 45.84707826375961, 54.24154981970787, 42.38528162240982, 40.6927764415741, 49.72969472408295, 50.72828873991966, 51.726244390010834, 46.80409871041775, 46.69393502175808, 44.06199865043163, 42.14517630636692, 38.21488760411739, 38.080454617738724, 35.30946470797062, 34.5449723303318, 33.65567944943905, 36.52904726564884, 35.46471297740936, 34.327851980924606, 34.05940018594265, 36.3064856082201, 38.268707916140556, 41.067322343587875, 44.867604821920395, 45.00590220093727, 45.49923352897167, 47.723022401332855, 48.13215784728527, 46.635456159710884, 46.710806116461754, 41.282987371087074, 36.66598431766033, 36.20502345263958, 40.776151567697525, 48.0703541636467, 47.87841126322746, 48.11447739601135, 46.742826998233795, 49.79402147233486, 44.66259062290192, 47.07363344728947, 46.99765272438526, 41.689307168126106, 34.45628508925438, 20.16154143959284, 4.222767557948828, 0.5280950095038861, 3.6405335878953338, 1.550590752158314, 6.531185964122415, 9.425556678324938, 4.617865607142448, 5.316770654171705, 1.6498923674225807, 0.5636859184596688, 0.2097626676550135, 0.21568496158579364, 0.3434598888270557, 0.5114348628558218, 3.731463896110654, 13.801821749657393, 23.91080405563116, 26.767580062150955, 31.311862617731094, 15.632396321743727, 1.1125932424329221, 0.05448079748020973, 0.07134822226362303, 0.050160663085989654, 0.04055467092257459, 0.06652850745012984, 0.07485177527996711, 0.029199844866525382, 0.04109124369279016, 0.12585226009832695, 0.042872138365055434, 0.05305607432092074, 0.024938100796134677, 0.0320308451046003, 0.024134796440193895, 0.04806921671843156, 0.0480089877237333, 0.02123842412402155, 0.014562060841853963, 0.08229314160416834, 0.043462312751216814, 0.06377471654559486, 0.06484012890723534, 0.014060358807910234, 0.05463278561364859, 0.040345834277104586, 0.033630726247793064, 0.012400902687659254, 0.021152238514332566, 0.031169835056061856, 0.03644305405032355, 0.03956688720791135, 0.021250333738862537, 0.01972102156287292, 0.05694544764992315, 0.07027387444395572, 0.08230845211073756, 0.05306616010784637, 0.03544229759427253, 0.02215765751316212, 0.03823587503575254, 0.013040415051364107, 0.046939304302213714, 0.052454185133683495, 0.044331030003377236, 0.09433968269149773, 0.045419768066494726, 0.01914970143843675, 0.040985973755596206, 0.019999059768451843, 0.05211360985413194, 0.02110366494889604, 0.1935042455443181, 5.135584976524115, 25.10833829641342, 38.64340580999851, 34.20140616595745, 32.64507047832012, 32.060589641332626, 11.009778119623661, 1.8130799545906484, 0.062137802233337425, 0.03377613895281684, 0.12939837528392673, 0.07242561288876459, 0.06808853897382505, 0.4020435124402866, 1.886810960713774, 3.980532931163907, 1.92027434008196, 0.38795116706751287, 4.404313741251826, 25.083702318370342, 53.37842993438244, 56.26858904957771, 52.96963647007942, 54.28454831242561, 52.342476323246956, 50.03340482711792, 50.602287501096725, 52.847579419612885, 50.29403284192085, 50.12190207839012, 47.64996372163296, 42.054532170295715, 39.16727989912033, 43.48599895834923, 49.277078211307526, 51.43147900700569, 53.37904550135136, 53.652627021074295, 53.823272064328194, 52.45979502797127, 51.50195762515068, 51.4936588704586, 49.4555926322937, 48.95957104861736, 52.92007952928543, 53.55209581553936, 52.83149108290672, 49.35298673808575, 43.91073256731033, 39.149147272109985, 38.906708881258965, 37.66503430902958, 39.23075929284096, 40.02586282789707, 40.718098282814026, 41.48462735116482, 42.817003056406975, 49.0432957559824, 47.26336486637592, 53.960072323679924, 45.475234016776085, 42.61964924633503, 50.44775739312172, 53.06752681732178, 52.523008435964584, 48.5359051823616, 49.40006621181965, 45.69517381489277, 44.052430763840675, 39.65002119541168, 39.03245933353901, 38.26390877366066, 35.98259098827839, 35.22431127727032, 37.61500999331474, 37.58358187973499, 36.19841180741787, 37.35731542110443, 38.30727584660053, 39.896415174007416, 42.2298813611269, 45.51453910768032, 46.400959342718124, 48.20291765034199, 49.52919468283653, 48.95835891366005, 47.638583332300186, 48.84493499994278, 42.78868317604065, 37.846592366695404, 37.580838426947594, 41.32804915308952, 49.530714601278305, 48.56242775917053, 48.77708964049816, 47.14150920510292, 49.28962133824825, 45.0086684525013, 49.60867881774902, 47.33694411814213, 42.88246974349022, 37.62913003563881, 21.970077194273472, 6.66561515070498, 1.6162266489118338, 6.280464017763734, 5.470895608887076, 6.528187924996018, 11.572218239307404, 10.665551740676165, 6.923353895545006, 3.1611814722418785, 1.390329364221543, 0.977793694473803, 0.4446867242222652, 0.17422923061531037, 0.3839578782208264, 3.8025120086967945, 16.134424433112144, 26.42627477645874, 30.999977253377438, 34.697648137807846, 19.721519351005554, 2.2276770137250423, 0.058501423336565495, 0.03131274301267695, 0.03022612934728386, 0.019567593662941363, 0.04623668712156359, 0.013787085190415382, 0.027498237541294657, 0.08715650212252513, 0.151412226841785, 0.04637225894839503, 0.06010825469275005, 0.044344670677674, 0.007629874617123278, 0.03967475095123518, 0.046929871605243534, 0.04138035103096627, 0.05937000329140574, 0.01033317999826977, 0.02784004849672783, 0.029934843805676792, 0.05632311600493267, 0.009549404330755351, 0.015327904366131406, 0.21517282031709328, 0.1394189868005924, 0.19961842917837203, 0.06559787652804516, 0.16197739663766697, 0.26611696870531887, 0.1515531013137661, 0.1665159413823858, 0.16732557996874675, 0.08524924196535721, 0.19690212415298447, 0.16849928651936352, 0.12416284997016191, 0.17898314661579207, 0.07896139577496797, 0.14870407059788704, 0.16917912347707897, 0.09891056281048805, 0.21117941272677854, 0.15149028593441471, 0.1063523002085276, 0.22222788393264636, 0.1681841112440452, 0.10487121093319729, 0.13774769991869107, 0.13878130383091047, 0.1392996939830482, 0.16782762802904472, 0.21242221322609112, 7.263429947197437, 31.011901013553143, 50.283032432198524, 41.30039803683758, 42.5040328502655, 38.413096368312836, 14.336454961448908, 2.7506225276738405, 0.36982311168685555, 0.20169920346233994, 0.44191756343934685, 0.2421297167893499, 0.7709644397255033, 0.3873857099097222, 4.770093513652682, 9.17642304673791, 3.0297828605398536, 1.400116451550275, 3.4359364164993167, 26.211189217865467, 54.219944179058075, 59.76472444832325, 55.175699293613434, 57.81220681965351, 54.79268364608288, 52.69629053771496, 52.45303139090538, 55.21775923669338, 53.1298890709877, 52.98546642065048, 48.790692910552025, 44.8820136487484, 41.85167245566845, 45.93702703714371, 52.55293942987919, 53.362246602773666, 55.43334826827049, 56.58882826566696, 54.154515489935875, 55.221114456653595, 52.078667879104614, 53.335895016789436, 50.931498035788536, 50.01648813486099, 53.54790084064007, 55.34757547080517, 55.09928539395332, 52.03278534114361, 47.171364203095436, 41.10922269523144, 41.13329440355301, 41.309297159314156, 41.08407564461231, 42.32059769332409, 41.66267439723015, 43.03649827837944, 44.76579688489437, 52.1007788926363, 49.59693744778633, 56.14956423640251, 47.333528101444244, 45.261465087533, 49.194250255823135, 54.0921076387167, 55.86587905883789, 50.68316616117954, 50.50629325211048, 47.868079617619514, 45.56556276977062, 42.49988727271557, 40.59160687029362, 39.621743112802505, 37.23822981119156, 37.37120367586613, 39.7897244989872, 38.584976345300674, 37.437118738889694, 39.384913221001625, 41.094718873500824, 43.06842416524887, 45.100729912519455, 49.19217936694622, 49.069001376628876, 48.98153007030487, 51.39655888080597, 49.78107176721096, 49.442612528800964, 51.24621994793415, 45.161484852433205, 39.58195924758911, 39.79509741067886, 44.232278913259506, 51.75107605755329, 52.24558912217617, 50.58303013443947, 48.194048926234245, 50.495851412415504, 46.57761186361313, 50.42540319263935, 49.02483254671097, 45.24770602583885, 36.24788515269756, 21.839311011135578, 5.362972849979997, 1.5041460818611085, 6.865962725132704, 7.323259161785245, 12.351773958653212, 16.539482697844505, 12.740963324904442, 16.42589159309864, 4.963338319212198, 1.156157786026597, 2.1404303703457117, 1.9799846922978759, 1.2609029654413462, 1.3006769749335945, 5.542277628555894, 19.334403723478317, 33.721704706549644, 37.528564631938934, 40.35081759095192, 22.683678902685642, 1.9287854083813727, 0.15552382887108251, 0.10407543566543609, 0.20019629504531622, 0.14548794395523146, 0.12683461129199713, 0.18429811141686514, 0.11214992075110786, 0.2583615551702678, 0.257118190638721, 0.13275825593154877, 0.1662995756487362, 0.12104126552003436, 0.10631393117364496, 0.14461667742580175, 0.15054130170028657, 0.13398527837125584, 0.1399519230471924, 0.0883473597059492, 0.22442193963797763, 0.1985506567871198, 0.17726459976984188, 0.1887259871000424, 0.13952398585388437], [0.0741369609022513, 0.06847407727036625, 0.007579691055070725, 0.07390354803646915, 0.025468816165812314, 0.01591989701410057, 0.017924196690728422, 0.03879028532537632, 0.035432386212050915, 0.03681533758935984, 0.05015643284423277, 0.027292478953313548, 0.039755140387569554, 0.06389469213900156, 0.02326562833331991, 0.04224164309562184, 0.02932149585831212, 0.03287099338194821, 0.05181458000151906, 0.09788288123672828, 0.07569514447823167, 0.01555250701130717, 0.028174868421046995, 0.025261621522076894, 0.02368148707319051, 0.013463376144500216, 0.014597009503631853, 0.08177998359315097, 0.15416431822814047, 0.7032471452839673, 13.825712967664003, 25.26232123374939, 36.78615666925907, 26.897561587393284, 21.246953196823597, 18.634804263710976, 3.6191998701542616, 0.3439793031429872, 0.07046385682770051, 0.06426839318010025, 0.02962951868539676, 0.03809632900811266, 0.17983925848966464, 1.4929499826394022, 3.68014432489872, 2.167363087646663, 0.3550106752663851, 0.08712191804079339, 4.453217592090368, 31.472149416804314, 56.0045450180769, 56.38192556798458, 53.55532944202423, 53.349331095814705, 51.877939850091934, 51.3385283946991, 51.66938804090023, 52.797182723879814, 50.632891058921814, 49.122817888855934, 43.44304606318474, 39.156891256570816, 39.08605545759201, 43.41757982969284, 48.20061877369881, 48.21937456727028, 50.47832675278187, 50.46327196061611, 49.97754022479057, 48.93179073929787, 50.254366770386696, 50.15505149960518, 50.93810208141804, 47.93149061501026, 52.08679184317589, 51.43324211239815, 50.18401354551315, 47.48205453157425, 43.76164376735687, 38.400842025876045, 37.699031084775925, 36.12596869468689, 38.474915251135826, 37.7327124774456, 39.11018416285515, 43.10182437300682, 49.20809671282768, 47.716376557946205, 52.372411116957664, 41.16899348795414, 39.578900411725044, 50.43801091611385, 49.91521216928959, 50.83977855741978, 47.7044527977705, 45.3471352905035, 46.591097339987755, 45.793991312384605, 41.82937905192375, 38.76912586390972, 36.661496758461, 34.51046258211136, 35.00997997820377, 37.05240838229656, 36.7370481044054, 34.62577499449253, 36.65542088449001, 39.819340109825134, 43.17356452345848, 44.39191594719887, 45.002398788928986, 46.59314163029194, 47.53731116652489, 48.26203487813473, 46.76239974796772, 47.55032166838646, 46.5835053473711, 41.10161930322647, 37.75113008916378, 37.24034249782562, 44.3683648109436, 46.51641234755516, 47.5215458124876, 48.50560940802097, 47.18323856592178, 45.876055508852005, 49.95279975235462, 43.66968870162964, 45.22443987429142, 37.33923979103565, 22.15132176876068, 8.558284565806389, 1.4289585663937032, 0.6657024880405515, 5.909947324544191, 3.946360652334988, 3.0196217307820916, 13.581694811582565, 5.541800279170275, 5.523019786924124, 3.2696077041327953, 2.1075433725491166, 1.0728759923949838, 0.1339550581178628, 0.04799141737748869, 1.017944358754903, 5.543658379465342, 23.3323135972023, 25.49163892865181, 24.87528160214424, 22.19130702316761, 7.502545416355133, 0.08023174479603767, 0.019414024754951242, 0.009856543074420188, 0.047568923837388866, 0.03516366195981391, 0.030256579666456673, 0.005220850734986016, 0.022861582729092333, 0.06045136440661736, 0.07450465054716915, 0.02601255808258429, 0.07820119906682521, 0.039611404936295, 0.02746125632256735, 0.001637466168631363, 0.01620120066945674, 0.029430565591610502, 0.011571622235351242, 0.033468485344201326, 0.05553923736442812, 0.025145269464701414, 0.04407377193274442, 0.08180187694961205, 0.006954497039259877, 0.08637836770503782, 0.0042068641050718725, 0.0329172291822033, 0.0384164581191726, 0.0328688263107324, 0.046877060376573354, 0.05227602887316607, 0.027149168381583877, 0.016583187789365184, 0.016643897324684076, 0.016647454067424405, 0.0415315933059901, 0.04061446205014363, 0.07265784573974088, 0.0468647667003097, 0.03414441489439923, 0.016397710242017638, 0.019032011659874115, 0.023748135645291768, 0.08996849224786274, 0.0471529240894597, 0.08753239249926992, 0.046708733862033114, 0.0393976998020662, 0.029981016523379367, 0.03370684462424833, 0.040706273139221594, 0.0719009738531895, 0.389745858265087, 1.9136597262695432, 19.155418127775192, 37.1417073905468, 44.80625331401825, 36.256693080067635, 25.507330186665058, 19.60726898163557, 4.976402493193746, 0.33222347614355385, 0.10124201973667368, 0.1356509397737682, 0.06394872791133821, 0.07196734411991201, 0.3758033079793677, 0.7986622815951705, 1.9028519187122583, 3.4035631036385894, 1.2841729167848825, 0.3577400866197422, 7.1633855905383825, 34.38174068927765, 56.68084032833576, 57.1263512223959, 54.904219061136246, 52.98587679862976, 54.11378167569637, 51.936114728450775, 52.49053157866001, 54.77502219378948, 51.807681620121, 51.17676727473736, 45.1460424810648, 41.17941252887249, 40.95802880823612, 45.11811017990112, 50.053482949733734, 51.62490002810955, 52.48362734913826, 52.062940523028374, 51.07566989958286, 50.59339217841625, 52.959168031811714, 51.87999173998833, 50.92448741197586, 49.5934834331274, 53.030076026916504, 53.13961274921894, 51.571224108338356, 49.72204953432083, 45.88921420276165, 39.83865827322006, 39.874752536416054, 37.42204874753952, 39.43484254181385, 39.34798680245876, 40.39115622639656, 44.985900074243546, 50.1941742002964, 49.184800162911415, 54.04318146407604, 43.39117504656315, 42.12127938866615, 50.48105500638485, 51.254446506500244, 53.41028742492199, 48.86041156947613, 47.728604301810265, 46.78449176251888, 46.653326600790024, 42.53439322113991, 40.89967153966427, 37.16035678982735, 36.56955689191818, 35.92447690665722, 38.42577248811722, 37.80547857284546, 35.40368065237999, 38.44301596283913, 41.986196637153625, 45.42752377688885, 45.43851278722286, 46.546616926789284, 47.68919661641121, 49.496550634503365, 48.99539552628994, 47.259671464562416, 49.24093455076218, 47.90102005004883, 43.75994525849819, 37.98253767192364, 37.931324020028114, 45.4762789607048, 47.512646690011024, 49.779738038778305, 51.38748116791248, 47.30431906878948, 47.248530462384224, 49.984813034534454, 44.82139930129051, 46.84868551790714, 39.78625908493996, 25.344896502792835, 10.54219800978899, 2.312876754440367, 2.4255233723670244, 5.205001551657915, 4.955404819920659, 9.319487269967794, 10.318118333816528, 9.11007670685649, 5.829159859567881, 4.415156934410334, 2.252624575048685, 0.6154793361201882, 0.24887848121579736, 0.051427472062641755, 0.8845826773904264, 6.152854990214109, 21.947422809898853, 28.58870454132557, 29.908825904130936, 29.958181455731392, 10.704619344323874, 0.22677339002257213, 0.029192087567935232, 0.04033866884128656, 0.04551704136247281, 0.05065697434474714, 0.08369130329811014, 0.017868622817331925, 0.019134236936224625, 0.016803830149001442, 0.043513943965081125, 0.02421126362605719, 0.017326647212030366, 0.05461308159283362, 0.033449100446887314, 0.022221125982468948, 0.032198485132539645, 0.036605873829103075, 0.02073166713671526, 0.04020559434138704, 0.0295611668843776, 0.006252261136978632, 0.02761562860541744, 0.04377447490696795, 0.0319976043101633, 0.15141553682042286, 0.1954690073034726, 0.1790690576308407, 0.18330479128053412, 0.15538970794295892, 0.1083699103037361, 0.13475846266373992, 0.14421388419577852, 0.10405514534795657, 0.0841339053295087, 0.07848109264159575, 0.13465012394590303, 0.12011670536594465, 0.13466667383909225, 0.15361970057711005, 0.08301855385070667, 0.07963591895531863, 0.20684733346570283, 0.14507735817460343, 0.19382320577278733, 0.15223016263917089, 0.20152276527369395, 0.14257287693908438, 0.11627110390691087, 0.1290320066618733, 0.12619798217201605, 0.1232399299624376, 0.13962935598101467, 0.3161197918234393, 2.1624414017423987, 24.452295899391174, 45.11116035282612, 50.11043429374695, 42.15608172118664, 33.42684052884579, 27.257299683988094, 6.563703194260597, 0.7918634370435029, 0.29858355468604714, 0.34273961966391653, 0.22043816512450576, 0.45112541934940964, 1.1667594546452165, 1.8607806949876249, 8.843987435102463, 8.20734204724431, 1.384869294706732, 0.5392009229399264, 6.687857257202268, 34.85631242394447, 59.132240787148476, 61.01786680519581, 56.32657013833523, 57.31405355036259, 56.74644760787487, 54.40049149096012, 54.84890542924404, 56.60794883966446, 53.57766464352608, 54.67107497155666, 49.14839431643486, 43.31114374101162, 44.9200914055109, 48.345710188150406, 51.614682376384735, 51.86271786689758, 54.07266028225422, 54.47734996676445, 53.03750462830067, 52.3791329562664, 53.57556335628033, 51.95550888776779, 52.82815486192703, 48.44876445829868, 53.680160343647, 57.36078344285488, 54.86516855657101, 52.14457534253597, 48.44334214925766, 41.499013379216194, 41.15787908434868, 38.69319073855877, 40.59474550187588, 42.37996570765972, 41.6421364992857, 46.779692620038986, 52.151198387145996, 51.82968243956566, 54.66631002724171, 46.36868767440319, 44.17338967323303, 50.05903445184231, 52.81351424753666, 53.46704497933388, 52.310694828629494, 50.485390573740005, 50.53454853594303, 49.421459063887596, 45.555721297860146, 42.551412507891655, 40.43773792684078, 37.74105302989483, 37.98748880624771, 39.80159506201744, 39.61848668754101, 36.713485568761826, 41.4509991556406, 44.940956085920334, 47.24568821489811, 47.365412190556526, 49.332600831985474, 50.3118234872818, 50.70724926888943, 48.90406362712383, 48.93305987119675, 50.597674548625946, 50.246527791023254, 45.370025262236595, 41.35868310928345, 40.002668872475624, 48.40106941759586, 48.835678696632385, 51.52517817914486, 51.955417692661285, 47.46596999466419, 48.37584637105465, 50.89818522334099, 45.84278829395771, 47.10120476782322, 40.500708147883415, 25.297803729772568, 9.790409300476313, 2.249956405721605, 1.8659264501184225, 11.865629944950342, 10.480652712285519, 9.621970038861036, 25.026540085673332, 12.81642822548747, 12.441081516444683, 9.679909329861403, 5.457726465538144, 3.0145045928657055, 0.6076902884524316, 0.17107771534938365, 1.0603122040629387, 7.89498645812273, 31.47877626121044, 35.2183797955513, 34.92389939725399, 33.80696453154087, 11.304807588458061, 0.3315370489144698, 0.11564686123165302, 0.10698260623030365, 0.09583917722920887, 0.19590656273066998, 0.25495533482171595, 0.14834844827419147, 0.07816782468580641, 0.13925653067417443, 0.12526456819614395, 0.11869227906572632, 0.20572829351294786, 0.1567118737148121, 0.16539777716388926, 0.08122831553919241, 0.11152549996040761, 0.15837095968890935, 0.08800185285508633, 0.1021526349359192, 0.17295919329626486, 0.11444364688941278, 0.18260145792737603, 0.20202766318107024, 0.09444281895412132], [0.06738432988640852, 0.03681297013827134, 0.03121249370451551, 0.06974127958528697, 0.03512797578878235, 0.04512584790063556, 0.014020754097145982, 0.05959203161182813, 0.07621095195645466, 0.04156730916292872, 0.03639069924247451, 0.031141533254412934, 0.02192480311350664, 0.07539309037383646, 0.008997284494398627, 0.00961738505793619, 0.023208737147797365, 0.03648773876193445, 0.029808272374793887, 0.027420130209065974, 0.06021566943672951, 0.039022540440782905, 0.028397425521689, 0.03494373020657804, 0.0849772003130056, 0.01904706241475651, 0.035432367658359, 0.07255003394675441, 0.22778260696213692, 0.09403308664332144, 4.333667932078242, 14.102082587778568, 20.811222977936268, 23.268040046095848, 15.89653154835105, 14.140564072877169, 11.114117670804262, 2.1790531603619456, 0.03849574175546877, 0.08681204912136309, 0.10606394615024328, 0.08873549551935866, 0.2525044069625437, 0.45244047534652054, 2.277147271670401, 1.6807350749149919, 1.0761778964661062, 0.951349250972271, 0.3936855640495196, 6.970410570502281, 35.278769955039024, 53.06031480431557, 58.1910464912653, 52.09667131304741, 52.795047238469124, 50.79702705144882, 53.057620748877525, 51.28869786858559, 49.38120022416115, 48.287425115704536, 46.105665788054466, 40.083885714411736, 39.97190572321415, 38.466468304395676, 40.04793584346771, 42.784169018268585, 46.418924778699875, 45.41558101773262, 47.88688860833645, 49.23831649124622, 48.97540099918842, 50.87822109460831, 49.08006638288498, 47.63697601854801, 51.53825707733631, 52.01653741300106, 51.634353920817375, 51.24661132693291, 47.9283481836319, 42.3380159586668, 38.86444754898548, 38.45670662820339, 37.96623654663563, 37.25707300007343, 44.10841315984726, 48.01268845796585, 50.23007467389107, 48.99500034749508, 52.8329274058342, 41.527956426143646, 38.93944412469864, 54.05665174126625, 46.73414446413517, 50.28134152293205, 50.53130351006985, 51.70482873916626, 48.85007232427597, 48.081772550940514, 46.78793057799339, 40.28560169041157, 35.57664357125759, 34.94563043117523, 34.10747140645981, 35.154182240366936, 35.899519845843315, 34.584892988204956, 39.864496886730194, 45.524464175105095, 46.722984462976456, 47.63654284179211, 48.1973547488451, 47.98310324549675, 48.075692877173424, 47.691765278577805, 47.95957490801811, 47.81067989766598, 46.21419936418533, 42.55577087402344, 38.85264918208122, 43.444869965314865, 45.55515892803669, 48.18511560559273, 48.50868344306946, 48.93218591809273, 47.9614520072937, 47.70199052989483, 47.64788903295994, 49.84265886247158, 41.136934608221054, 28.545755445957184, 12.900082636624575, 3.700934434309602, 0.45986411918420345, 3.2313824677839875, 5.014716312289238, 5.289086289703846, 7.720369203016162, 6.447206670418382, 9.838780704885721, 4.038171088322997, 3.060812707990408, 2.4077348643913865, 0.3052921243943274, 0.4546500864671543, 0.26876216114033014, 5.983662893995643, 16.866375356912613, 22.2304867208004, 19.732770547270775, 25.040063560009003, 17.284727208316326, 2.727747755125165, 0.02386355074122548, 0.18439083534758538, 0.09453365040826611, 0.06550627324031666, 0.024266308719234075, 0.0577600474935025, 0.03300742610008456, 0.03651583276223391, 0.02920791201177053, 0.006777003145543858, 0.07218577302410267, 0.03050608043849934, 0.04578928339469712, 0.0414411626115907, 0.028684864882961847, 0.06244460979360156, 0.018097595784638543, 0.019366093147255015, 0.07478298561181873, 0.027363804911146872, 0.07501314787077717, 0.05701087909983471, 0.035516746138455346, 0.039634300192119554, 0.010865546646527946, 0.04738637406262569, 0.0340967949887272, 0.05646371588227339, 0.013733363903156715, 0.051720690898946486, 0.1466054847696796, 0.034925410291180015, 0.03409352582821157, 0.043035885828430764, 0.025709646797622554, 0.03300574142485857, 0.03249371889978647, 0.07311928347917274, 0.05357677997380961, 0.044164607097627595, 0.024823952917358838, 0.06391658549546264, 0.037984936352586374, 0.005659156195179094, 0.04038116050651297, 0.06997032120125368, 0.023532098311989103, 0.012510663545981515, 0.05977373162750155, 0.09496284183114767, 0.03417669460759498, 0.03335443579999264, 0.07188676172518171, 0.04753960900416132, 9.367369450628757, 24.551742263138294, 35.046032443642616, 32.587309777736664, 22.84400749951601, 20.53038764744997, 13.161378465592861, 1.7127598752267659, 0.14807199826464057, 0.12975784193258733, 0.15322269609896466, 0.19857456878526136, 0.26217102888040245, 0.6402153556700796, 1.5031871083192527, 3.099590577185154, 1.802640133537352, 1.2678207317367196, 0.7656735205091536, 10.67679438740015, 38.63674856722355, 56.31330884993076, 58.6373895406723, 54.49123442173004, 53.94708462059498, 53.83062086999416, 53.78805175423622, 53.572208136320114, 50.778928622603416, 49.635794162750244, 48.278719782829285, 42.318853586912155, 41.096007004380226, 40.555588603019714, 42.75291569530964, 45.683706030249596, 47.108249589800835, 47.35066518187523, 51.10038757324219, 51.131633296608925, 49.84041318297386, 52.69235394895077, 51.24303951859474, 47.10541874170303, 51.03630781173706, 52.604696452617645, 53.76328468322754, 52.188877165317535, 49.255046993494034, 42.95274697244167, 39.4437188655138, 39.20494727790356, 38.51173907518387, 38.51586565375328, 44.61958073079586, 51.80640868842602, 50.5763690918684, 51.04364521801472, 54.95964668691158, 43.63911934196949, 42.68325783312321, 53.49958263337612, 46.485896185040474, 51.14160776138306, 52.46259927749634, 52.35886484384537, 51.71908937394619, 49.10840146243572, 45.88535360991955, 40.8724308013916, 37.63807475566864, 36.248014345765114, 36.42019830644131, 37.421915754675865, 37.22799316048622, 37.393060103058815, 41.11128978431225, 47.00690142810345, 48.40316690504551, 48.23437236249447, 49.001710787415504, 49.2840850353241, 50.07714048027992, 48.983042389154434, 48.77931632101536, 49.16156820952892, 47.74481043219566, 45.34837402403355, 40.25478154420853, 43.57806421816349, 46.30213424563408, 49.4039686024189, 50.6579165160656, 50.44660225510597, 48.313962891697884, 48.54038894176483, 49.201462268829346, 49.83523406088352, 42.46523693203926, 29.52435303479433, 15.401994735002518, 4.534234469756484, 1.5312195103615522, 3.2124378718435764, 6.299538994207978, 4.632844403386116, 6.467716069892049, 10.529782176017761, 10.694414991885424, 5.6423908565193415, 3.462844672612846, 1.9728147145360708, 0.30827748763840646, 0.10586335847619921, 0.27077911072410643, 5.126743800938129, 15.435314197093248, 25.06864942610264, 26.078000664711, 28.769352547824383, 20.69496251642704, 4.051468949764967, 0.07631800675881095, 0.01716973121801857, 0.11847343455883674, 0.03785904213145841, 0.039518213452538475, 0.011305361913400702, 0.02518361623515375, 0.035545663922675885, 0.01437295975847519, 0.05732205790991429, 0.03142564222798683, 0.004741393649965175, 0.016059444897109643, 0.03701013280078769, 0.04797696034074761, 0.05256827178527601, 0.0323420869972324, 0.02299999883689452, 0.028271989576751366, 0.017090429028030485, 0.04818097673705779, 0.041028354098671116, 0.07485158974304795, 0.030312242597574368, 0.1410434441640973, 0.13767351483693346, 0.08353303288458847, 0.11914401693502441, 0.1032906367618125, 0.19123772653983906, 0.2610739861847833, 0.18779114820063114, 0.1245899114292115, 0.1363917367416434, 0.11823032182292081, 0.08382860061828978, 0.1474064847570844, 0.22041674674255773, 0.14925406139809638, 0.1271362794796005, 0.1647710334509611, 0.11103738943347707, 0.11123068921733648, 0.08141475045704283, 0.11521560663823038, 0.22065588156692684, 0.12270953186089173, 0.11990507453447208, 0.16098413587315008, 0.12563828408019617, 0.17530145589262247, 0.16413262317655608, 0.2819717663805932, 0.2539861493278295, 11.692219600081444, 32.6707760989666, 41.30691468715668, 41.05262093245983, 29.344554282724857, 24.33637361973524, 15.31397245824337, 2.752176644280553, 0.30921063444111496, 0.21296736522344872, 0.2857016818597913, 0.21387186512583867, 0.9611545654479414, 1.4359298860654235, 4.577768258750439, 5.2639748621732, 3.3160877600312233, 3.3395947236567736, 0.6753206031862646, 9.048771746456623, 39.070958867669106, 57.36335590481758, 61.91741153597832, 55.977710857987404, 54.41852152347565, 55.53601875901222, 55.81828661262989, 54.56690736114979, 50.271712839603424, 51.76885910332203, 50.49547903239727, 43.97890850901604, 43.13153497874737, 41.58271908760071, 44.478676691651344, 46.29876762628555, 49.427572935819626, 49.22402165830135, 52.31588535010815, 53.69989648461342, 52.02232450246811, 54.438413456082344, 52.4130043387413, 48.931676745414734, 52.66116142272949, 54.64706785976887, 56.61288097500801, 54.20532636344433, 50.97761616110802, 45.30823677778244, 42.83158667385578, 42.94933095574379, 40.882971435785294, 40.805546790361404, 47.31427073478699, 53.6844465136528, 53.10196816921234, 53.106155544519424, 54.66559186577797, 45.66186100244522, 45.82660496234894, 54.61458720266819, 47.07619071006775, 51.84938058257103, 53.618584647774696, 55.68927973508835, 53.247371166944504, 52.34907276928425, 48.00890386104584, 43.607265651226044, 40.18967963755131, 38.681555762887, 37.04525716602802, 38.46515737473965, 39.06525917351246, 39.035552367568016, 44.82689380645752, 49.200671911239624, 50.664577558636665, 51.21817745268345, 50.80140061676502, 50.40492229163647, 51.50036931037903, 49.59549732506275, 50.45753426849842, 51.4713616669178, 50.46658158302307, 47.15110369026661, 42.55884870886803, 47.71135322749615, 48.60310457646847, 51.35866731405258, 53.237613290548325, 51.29834935069084, 48.78782406449318, 48.621856570243835, 50.18948145210743, 50.963294729590416, 43.70830602943897, 29.164423048496246, 14.25812691450119, 4.247024031355977, 2.002080981619656, 7.723342068493366, 9.805419445037842, 10.115713644772768, 15.313529781997204, 14.777222760021687, 21.247639060020447, 12.663688771426678, 10.189189352095127, 5.604695454239845, 1.255212533287704, 0.6466278084553778, 0.8098446065559983, 6.697684954851866, 20.76778370887041, 31.31910502910614, 29.945537634193897, 35.495122745633125, 23.723939582705498, 4.1318056639283895, 0.12659664906095713, 0.2862407185602933, 0.1827919078641571, 0.09449597899219953, 0.11390553787350655, 0.16009127284632996, 0.10992242387146689, 0.10096024110680446, 0.09057080445927568, 0.1477028094814159, 0.18514334340579808, 0.10726912718382664, 0.08877071042661555, 0.09459077351493761, 0.15592156065395102, 0.20292128319852054, 0.1456836482975632, 0.10020644913311116, 0.16000816714949906, 0.0969874206930399, 0.11050526212784462, 0.1500342960935086, 0.14901093381922692, 0.1359751692507416], [0.0022246277831072803, 0.012965120458829915, 0.036763917887583375, 0.06272214333876036, 0.007709640185566968, 0.026961076619045343, 0.02757977730652783, 0.027162738551851362, 0.0631570047698915, 0.05082517469418235, 0.12202306010294706, 0.05602026038104668, 0.0878168577037286, 0.022485824083560146, 0.06060898915166035, 0.037092800630489364, 0.029461292360792868, 0.04350110481027514, 0.04262883267074358, 0.01986108338314807, 0.007772597964503802, 0.06842457602033392, 0.021905447902099695, 0.010493611916899681, 0.00955636289290851, 0.049359392214682885, 0.023824766103643924, 0.07337750634178519, 0.015140139148570597, 0.04941124978358857, 0.23888602678198367, 8.99876357987523, 14.759598355740309, 19.85175546258688, 21.252295710146427, 14.809916205704212, 15.298883467912674, 6.469051223248243, 0.37621671392116696, 0.0368429232185008, 0.1142530856304802, 0.14618559245718643, 0.08675157150719315, 0.581907246960327, 0.6684698082972318, 1.524786336813122, 2.077081357128918, 0.41191003925632685, 0.6205206562299281, 0.2931337268091738, 7.724222671240568, 30.417291820049286, 50.8213609457016, 57.238084226846695, 53.51557217538357, 54.183165952563286, 54.14302110671997, 51.924855932593346, 54.04341705143452, 50.2908980101347, 47.0793217420578, 42.33521170914173, 44.00007337331772, 42.38335892558098, 41.2785492092371, 41.0475368052721, 39.28161196410656, 42.79792807996273, 44.502087235450745, 46.65323160588741, 49.05374899506569, 50.439675226807594, 52.69242614507675, 49.097925424575806, 48.55276867747307, 47.74075224995613, 51.864408776164055, 53.23668994009495, 48.327478766441345, 44.19879510998726, 40.88952608406544, 35.99601946771145, 37.64414303004742, 37.08097904920578, 45.262407436966896, 49.50351946055889, 52.738057896494865, 47.9437031596899, 51.8063098937273, 42.44841143488884, 36.87920227646828, 47.82061256468296, 48.872510120272636, 49.43923071026802, 48.273901641368866, 47.01197795569897, 47.50279001891613, 48.84054623544216, 47.02541783452034, 39.65618446469307, 34.056968316435814, 34.41048614680767, 35.345023199915886, 35.933117642998695, 34.94239300489426, 37.48094938695431, 45.82603879272938, 49.00292672216892, 50.25630086660385, 48.621024414896965, 45.9050327539444, 48.80282945930958, 48.38142827153206, 48.548239320516586, 48.19283299148083, 46.13153100013733, 44.51493814587593, 41.21178299188614, 40.1131821423769, 44.7531283646822, 45.1050540804863, 47.62637458741665, 48.353427574038506, 49.033078104257584, 48.38988661766052, 48.01771178841591, 45.90614229440689, 47.45751164853573, 39.10372070968151, 19.957139007747173, 8.126465287059546, 1.7577164503745735, 0.8187316765543073, 1.8141393852420151, 2.8984977677464485, 2.099262191914022, 7.403352214023471, 7.239017682150006, 8.110756929963827, 3.466168544255197, 1.9725771085359156, 1.2865034979768097, 0.2628144412301481, 0.46246623736806214, 0.8305019605904818, 11.451868247240782, 29.779786728322506, 24.30400125682354, 21.693889014422894, 29.715414382517338, 11.165650505572557, 0.5006297864019871, 0.03733733086846769, 0.011573523061088054, 0.02166683814721182, 0.021417552597995382, 0.023977166129043326, 0.04529932492005173, 0.0695816361985635, 0.04361069775768556, 0.06980295947869308, 0.04054994715261273, 0.04615848702087533, 0.07435526364133693, 0.057046105139306746, 0.028066856248187833, 0.04418383243319113, 0.0058462836295802845, 0.038636953904642724, 0.03913829321390949, 0.04940869679558091, 0.013237400526122656, 0.06347609116346575, 0.08850305486703292, 0.03364817413967103, 0.016400493295805063, 0.11354664267855696, 0.06580444591236301, 0.026093134911207017, 0.06894670659676194, 0.03158092549711, 0.018456238649378065, 0.025737445794220548, 0.0270171681404463, 0.03719844906299841, 0.05791428804513998, 0.04639736580429599, 0.05867708598088939, 0.013278201022330904, 0.039532444134238176, 0.026815049786819145, 0.03378345281817019, 0.05815090327814687, 0.04291205848858226, 0.049521555192768574, 0.046062913243076764, 0.06818711844971403, 0.03441178101638798, 0.008251354647654807, 0.03167694085277617, 0.07940822804812342, 0.055146292434073985, 0.023449924010492396, 0.028853831499873195, 0.05891131149837747, 0.0032698841096134856, 1.7349612526595592, 17.0848161354661, 27.34540555626154, 30.71816347539425, 27.560675404965878, 17.194221764802933, 17.85017866641283, 7.087728325277567, 0.13231310091214254, 0.048215089555014856, 0.15591612813295797, 0.6338332418818027, 0.3369090997148305, 0.913546682568267, 0.7839172321837395, 2.704639295116067, 2.4249650398269296, 2.1677499543875456, 2.2544301906600595, 0.6695820204913616, 10.670659616589546, 34.43483144044876, 53.744114711880684, 58.003359362483025, 54.97999079525471, 53.53276625275612, 55.34741207957268, 53.76928836107254, 54.762840047478676, 49.78620909154415, 47.96588636934757, 44.73707042634487, 42.784305810928345, 43.589729592204094, 43.66298206150532, 41.41225643455982, 42.21399441361427, 46.06623150408268, 46.618759855628014, 47.59034872055054, 50.58928839862347, 51.6727090626955, 54.36324968934059, 50.323344469070435, 48.669988587498665, 48.61934870481491, 52.9730448871851, 54.073564633727074, 51.137610375881195, 45.68569712340832, 42.23645120859146, 38.38563524186611, 40.037228018045425, 38.731922060251236, 47.2138649225235, 50.27249179780483, 52.9185102134943, 49.25422623753548, 52.12677709758282, 44.156214594841, 39.58883307874203, 49.819791689515114, 50.61158560216427, 50.90276397764683, 48.56927119195461, 49.894814863801, 48.67489792406559, 49.89815108478069, 48.85309316217899, 41.716300919651985, 35.48503428697586, 36.35454922914505, 38.26751857995987, 38.02405804395676, 37.179948538541794, 38.99890713393688, 46.99299797415733, 49.81451377272606, 52.13555462658405, 49.11003157496452, 47.9975500702858, 50.56450992822647, 47.45498098433018, 48.67715500295162, 48.98980222642422, 48.7826107442379, 46.179412230849266, 42.34491638839245, 43.426596745848656, 46.55184544622898, 46.988848596811295, 48.26805755496025, 49.484596475958824, 50.32350406050682, 49.369766637682915, 49.08060595393181, 47.86811761558056, 47.29803040623665, 40.149580389261246, 23.30057580024004, 9.581342618912458, 2.522413660772145, 2.0820930507034063, 3.9688846562057734, 6.2169803492724895, 5.336597990244627, 9.657287243753672, 8.983959574252367, 7.035661144182086, 5.365611808374524, 2.1288189059123397, 0.7620149699505419, 0.11260501312790439, 0.3825769491959363, 0.8930782496463507, 11.399057731032372, 28.581714816391468, 26.795618757605553, 24.710531942546368, 33.33205081522465, 14.475129470229149, 0.9551194205414504, 0.10468159220181406, 0.08278496286948211, 0.0022639687995251734, 0.03938170280889608, 0.03235396136005875, 0.054589536957792006, 0.044958282087463886, 0.010322181369701866, 0.006185581023601117, 0.039643836789764464, 0.056137360152206384, 0.046511144464602694, 0.029843739612260833, 0.013340648110897746, 0.052762825798708946, 0.0540195972280344, 0.023191033214970957, 0.034798822161974385, 0.0751685313298367, 0.014970641896070447, 0.053040526327094994, 0.04322113702073693, 0.06026429866324179, 0.028581646984093823, 0.1365853927563876, 0.11663595112622716, 0.11693524444126524, 0.1708526219590567, 0.12628120661247522, 0.1460156257962808, 0.16558837553020567, 0.1364571347949095, 0.1300774107221514, 0.22341625532135367, 0.22970352263655514, 0.1656908809673041, 0.1679042770410888, 0.13284674962051213, 0.12603482842678204, 0.11571849332540296, 0.14017412206158042, 0.1445270556723699, 0.11200607026694342, 0.14759889396373183, 0.15256870072335005, 0.14975965692428872, 0.08538296213373542, 0.06679482714389451, 0.1689634405192919, 0.17917309189215302, 0.10092343058204278, 0.1538306486327201, 0.19769325357628986, 0.19055379292694852, 2.4268732499331236, 23.300581499934196, 35.60307875275612, 39.083916172385216, 34.85113710165024, 25.02003103494644, 21.89886711537838, 9.576973803341389, 0.7424914988223463, 0.14784216997213662, 0.1987021291279234, 0.6675260933116078, 0.4511117341462523, 1.048965894151479, 1.0418730997480452, 4.958104575052857, 4.943962208926678, 2.2290817508473992, 1.9946799287572503, 0.6471814506221563, 9.812848046422005, 32.68109634518623, 54.73748400807381, 59.523878172039986, 56.56256407499313, 55.120879635214806, 58.30689087510109, 54.34624940156937, 57.696548625826836, 53.88279967010021, 50.48473320901394, 47.77506060898304, 46.50527894496918, 46.10742889344692, 46.41928195953369, 44.824309945106506, 43.256909251213074, 47.877769097685814, 49.35820385813713, 50.85199110209942, 53.41116137802601, 53.694234788417816, 54.93530139327049, 51.425437331199646, 49.506171718239784, 49.616191014647484, 53.86165000498295, 56.61538124084473, 51.995566338300705, 47.63108633458614, 45.97814083099365, 39.611692652106285, 42.388397455215454, 41.46510399878025, 49.26247179508209, 53.98146517574787, 56.57197616994381, 50.85748180747032, 52.52031818032265, 45.55677764117718, 42.37510956823826, 49.670129120349884, 51.51538610458374, 50.656799376010895, 50.893465876579285, 50.08885145187378, 50.40822051465511, 50.67868620157242, 49.729367941617966, 42.5877271592617, 36.72084957361221, 37.288561910390854, 39.68601666390896, 39.479873925447464, 39.02522072196007, 40.20869001746178, 49.62202750146389, 52.78717786073685, 53.9706851541996, 50.530239567160606, 47.44933448731899, 51.81115083396435, 50.21687798202038, 49.30021516978741, 51.028035655617714, 50.60140214860439, 49.04868006706238, 45.29166966676712, 44.85939346253872, 49.10468526184559, 46.91619649529457, 49.62151072919369, 51.70727580785751, 52.03810505568981, 50.802012383937836, 49.90593306720257, 48.449083641171455, 49.20881487429142, 40.89714087545872, 22.91373185813427, 10.120242051780224, 2.7724689804017544, 3.189599197357893, 6.063707498833537, 8.109364304691553, 7.018122710287571, 15.667673628777266, 15.313601028174162, 15.446177814155817, 11.16816122084856, 7.243393147364259, 3.667039778083563, 0.6539943069219589, 0.8182272536214441, 1.1417149985209107, 15.338052716106176, 34.71459902822971, 32.605643793940544, 33.451117426157, 39.74052093923092, 15.417361110448837, 1.0267019388265908, 0.2695174003019929, 0.17059039149899036, 0.10508693841984496, 0.13637753203511238, 0.15537314320681617, 0.20543285936582834, 0.13860053149983287, 0.1248598305392079, 0.20705020695459098, 0.13124209275702015, 0.16617398941889405, 0.13796026585623622, 0.14384076202986762, 0.11182429603650235, 0.09740577675984241, 0.14776368043385446, 0.11018483244697563, 0.14028997131390497, 0.11624890626990236, 0.12175575335277244, 0.1925672692595981, 0.09773775425856002, 0.2438510095817037, 0.2178122240002267], [0.06397986100637354, 0.03921897950931452, 0.03256346593843773, 0.0473371733824024, 0.04560599889373407, 0.038004710877430625, 0.07543174884631298, 0.05661009709001519, 0.05155778577318415, 0.011701871007971931, 0.014869886072119698, 0.05150964636413846, 0.11847963891341351, 0.022069336373533588, 0.043070681422250345, 0.07155174884246662, 0.05593465735728387, 0.020427325362106785, 0.025930717747542076, 0.03533951756253373, 0.02685543931875145, 0.09800765110412613, 0.026378635411674622, 0.03299390788015444, 0.05838145887537394, 0.010706934845075011, 0.013467186145135202, 0.04694601702794898, 0.0508073705714196, 0.13979558221763, 0.1054622424999252, 1.954857709351927, 10.733795128762722, 18.70590604841709, 19.362260028719902, 18.93511924892664, 14.24217727035284, 7.620317721739411, 2.0262721460312605, 0.11502506022225134, 0.5053623137064278, 0.32380520598962903, 0.1273374757147394, 0.8719805942382663, 1.0068176058121026, 3.079691994935274, 1.337504955008626, 2.246378897689283, 1.9380985898897052, 0.503977881744504, 0.2673481323290616, 6.569038107991219, 25.830571241676807, 46.46118991076946, 53.96154664456844, 52.82900221645832, 53.15736539661884, 50.93780189752579, 49.724735990166664, 48.56965497136116, 49.87681902945042, 49.038773998618126, 50.65660558640957, 50.48513978719711, 52.094060853123665, 46.98513239622116, 43.2181703299284, 37.26658008992672, 40.68201921880245, 44.92887273430824, 48.91876883804798, 49.96524788439274, 51.6756197065115, 49.045332446694374, 47.3674488812685, 50.298091024160385, 51.93403623998165, 50.71681335568428, 48.493716046214104, 44.5782845467329, 40.60330644249916, 37.13455617427826, 37.928607165813446, 37.03746758401394, 44.986371248960495, 47.34673619270325, 52.89840929210186, 48.21457922458649, 53.329154178500175, 41.34743191301823, 39.692221730947495, 48.8301195949316, 45.35325676202774, 45.85759609937668, 46.43147550523281, 50.89824602007866, 51.98523089289665, 52.124615013599396, 44.23566833138466, 38.142034113407135, 34.1578035056591, 36.199874728918076, 34.521717578172684, 37.933330312371254, 34.36475180089474, 40.3437689691782, 46.55952103435993, 50.84261700510979, 45.69775007665157, 48.43450002372265, 47.103112265467644, 47.10558973252773, 46.4498171210289, 46.15111134946346, 47.95229829847813, 46.31386041641235, 43.88764500617981, 39.924883246421814, 41.87944896519184, 45.143314227461815, 47.95164093375206, 48.29809874296188, 48.52352924644947, 46.07930280268192, 47.00769938528538, 46.32563978433609, 49.79401007294655, 44.657118916511536, 30.46730663627386, 13.10825826600194, 3.9763396186754107, 0.9033290308434516, 2.446246985346079, 2.576652900315821, 6.853757305070758, 3.6186505621299148, 5.672235880047083, 10.157941728830338, 7.938796207308769, 2.424762938171625, 0.9490982873830944, 0.3660444519482553, 0.19515344611136243, 0.4033807141240686, 6.755255190655589, 19.979383014142513, 36.32374048233032, 34.30891379714012, 27.614678107202053, 22.1507366001606, 4.759144876152277, 0.0513694324035896, 0.0622621453658212, 0.03790313312492799, 0.045930347114335746, 0.04635077748389449, 0.009452825870539527, 0.04695262585300952, 0.037844484904780984, 0.00601675124016765, 0.04348700771515723, 0.04319431580370292, 0.020376913125801366, 0.04046201007440686, 0.004146857754676603, 0.026107456505997106, 0.014427580899791792, 0.03197926213033497, 0.043208231072640046, 0.042633111152099445, 0.04783533629961312, 0.01444903824449284, 0.06894171936437488, 0.027681253013724927, 0.014829453866695985, 0.028021323632856365, 0.03655702937976457, 0.0470749985834118, 0.05385212047258392, 0.05070381870609708, 0.057532011487637646, 0.036091806687181816, 0.08158262426150031, 0.09101777031901293, 0.05397797758632805, 0.05689726000127848, 0.05157076222531032, 0.057109035551548004, 0.06922311207745224, 0.03882239805534482, 0.03703467191371601, 0.010152489303436596, 0.024064114295470063, 0.012114537585148355, 0.006529930124088423, 0.030009160618647, 0.018494839605409652, 0.04489921084314119, 0.06044359783118125, 0.059445724618854, 0.04515778993663844, 0.029473808681359515, 0.011100951251137303, 0.075542848353507, 0.014199674769770354, 0.07838593446649611, 0.06323717898339964, 7.991145048290491, 20.442340672016144, 26.342489272356033, 31.625987961888313, 23.285665400326252, 17.217858396470547, 11.359673794358969, 2.126248818822205, 0.18160316540161148, 0.15374188777059317, 0.22257872682530433, 2.1355272084474564, 1.7341545084491372, 2.3078503366559744, 4.030393855646253, 3.3992329984903336, 3.462603623047471, 4.909989656880498, 2.0165612921118736, 0.5907018750440329, 9.82752475887537, 30.493352338671684, 49.73481684923172, 56.64242438971996, 55.231335908174515, 55.36571189761162, 52.9053895175457, 52.50871740281582, 51.27021946012974, 51.862375885248184, 50.14710612595081, 52.83046133816242, 52.35691174864769, 52.6112625002861, 48.71192313730717, 43.46847429871559, 39.18119095265865, 42.851372212171555, 46.02546349167824, 49.3848480284214, 49.260081723332405, 53.65231163799763, 49.59242329001427, 47.161845713853836, 50.49328275024891, 53.63534174859524, 52.5949689745903, 52.23512828350067, 45.29399134218693, 42.1040815114975, 39.65928889811039, 39.98931638896465, 38.58108915388584, 47.09600664675236, 50.63055418431759, 53.152452260255814, 51.213431507349014, 52.62670487165451, 43.388967365026474, 41.37605577707291, 48.61489154398441, 47.390133664011955, 48.99908132851124, 50.445181131362915, 51.01502135396004, 51.23996928334236, 52.51944422721863, 46.758048981428146, 39.612824991345406, 35.915220603346825, 36.864193081855774, 36.068629771471024, 38.904375806450844, 36.963975727558136, 41.34172081947327, 49.142816215753555, 52.4616227298975, 48.36513474583626, 49.51262377202511, 46.55773513019085, 47.53679059445858, 47.44260124862194, 48.22048790752888, 48.650317043066025, 47.00505472719669, 45.83642363548279, 42.19996176660061, 44.431787207722664, 47.29384683072567, 50.122206062078476, 50.23227095603943, 48.1706003844738, 47.80957415699959, 47.69075833261013, 48.393542021512985, 49.684032574296, 45.01023396849632, 31.22438371181488, 14.446668047457933, 5.589859625324607, 1.808004139456898, 3.0582851311191916, 4.4856431521475315, 7.984409909695387, 4.565299227833748, 10.40590027347207, 8.374512176960707, 6.974138645455241, 4.795063873752952, 1.7875054269097745, 0.15191984100965783, 0.15616071032127365, 0.4446166951674968, 6.19717818684876, 21.311779618263245, 38.31253096461296, 36.88787721097469, 29.990016147494316, 26.48419886827469, 6.535660699009895, 0.16880564508028328, 0.06476786598796025, 0.060885075508849695, 0.02993833189975703, 0.04061138584802393, 0.0680484704207629, 0.025563031813362613, 0.03448720548476558, 0.03316772999824025, 0.03852018438919913, 0.06100010468799155, 0.0027137722145198495, 0.0014084450776863378, 0.008242265193985077, 0.01905969747895142, 0.02774438380583888, 0.013423549717117567, 0.07085007047862746, 0.04900346932117827, 0.08827842902974226, 0.06585323470062576, 0.04321737804275472, 0.04814369123778306, 0.025590027435100637, 0.007680537792111863, 0.18799286393914372, 0.26492309058085084, 0.15059286612085998, 0.12919002474518493, 0.21878040017327294, 0.08176719638868235, 0.16708481241948903, 0.15879206912359223, 0.14765094820177183, 0.15115020418306813, 0.10057278806925751, 0.1984431195887737, 0.19335223885718733, 0.09913152985973284, 0.1201162749202922, 0.140480168920476, 0.11635186441708356, 0.09385917917825282, 0.07975967208039947, 0.2197128493571654, 0.09957312257029116, 0.1608878347906284, 0.1537167141214013, 0.13019631762290373, 0.1362407542183064, 0.1380764861823991, 0.08814630447886884, 0.15757157758343965, 0.22409753204556182, 0.13761332666035742, 0.2618329063989222, 10.598633531481028, 28.998254165053368, 35.53349308669567, 39.701132252812386, 31.215497888624668, 22.965220995247364, 11.460400689393282, 2.9251948976889253, 0.49920236924663186, 0.7067873678170145, 3.517786399461329, 2.4604437360540032, 1.4416431169956923, 1.6646295203827322, 5.845308993011713, 4.093224909156561, 5.769698275253177, 7.30194753035903, 1.291792814154178, 0.5488768662326038, 8.192807827144861, 29.3020573630929, 48.83585728704929, 57.95311085879803, 56.01636238396168, 55.90385042130947, 54.964373633265495, 52.37594112753868, 53.559414222836494, 55.22800728678703, 53.450637459754944, 55.860164165496826, 54.29792359471321, 55.82258798182011, 50.167894810438156, 48.173100650310516, 41.09154224395752, 44.8725825548172, 48.46740625798702, 51.39756582677364, 52.301066145300865, 55.56717328727245, 51.51418536901474, 47.95360542833805, 52.2037647664547, 54.62873384356499, 55.504396855831146, 54.29340943694115, 49.209711626172066, 44.54125173389912, 42.87255987524986, 40.87676636874676, 40.1584605127573, 48.15292753279209, 52.83935286104679, 55.896984189748764, 53.279452845454216, 53.22311706840992, 43.569776862859726, 44.67079818248749, 49.123574048280716, 51.986340433359146, 50.77504143118858, 52.52307303249836, 52.47488781809807, 52.70351015031338, 54.77124519646168, 48.579067066311836, 40.67787364125252, 37.836431711912155, 38.900450617074966, 37.36151419579983, 41.59768648445606, 39.39361095428467, 43.668769150972366, 51.325122714042664, 54.10062678158283, 49.156818464398384, 49.632305949926376, 48.863094225525856, 49.37236949801445, 49.34627249836922, 50.117805898189545, 50.727467983961105, 50.090675354003906, 48.18701930344105, 45.07106110453606, 46.1776415258646, 49.16328951716423, 50.932972356677055, 52.72531718015671, 50.45995473861694, 49.666184931993484, 50.193258449435234, 49.317295253276825, 52.43008442223072, 46.347431614995, 32.85828083753586, 14.604858309030533, 5.591193828731775, 2.1448150975629687, 5.103536071255803, 7.240981701761484, 13.921442180871964, 9.269692841917276, 11.780417617410421, 17.142823822796345, 17.770536839962006, 9.302263744175434, 3.5448236111551523, 1.0810234677046537, 0.38037793594412506, 0.7830808020662516, 8.792335856705904, 25.23447062820196, 46.7021007835865, 42.14168809354305, 37.494161278009415, 29.848027266561985, 7.162730125710368, 0.29367644456215203, 0.22588045278098434, 0.16623963980237022, 0.16307259880704805, 0.1107986479473766, 0.10995111530064605, 0.12625306437257677, 0.07099912341800518, 0.21770651248516515, 0.15563409717287868, 0.1261765489471145, 0.12579219066537917, 0.10625632567098364, 0.099421731865732, 0.1272427331423387, 0.13375332753639668, 0.14156257646391168, 0.15388795727631077, 0.15203521528746933, 0.12631953111849725, 0.10547689991653897, 0.159212005964946, 0.15821948734810576, 0.13087921222904697, 0.13074160320684314], [0.02570301014202414, 0.039083225856302306, 0.05232607189100236, 0.03029923274880275, 0.03085773412749404, 0.056981070738402195, 0.022522105828102212, 0.11641084289294668, 0.05870703163964208, 0.017589603121450637, 0.08611227065557614, 0.0267302724023466, 0.02380485057074111, 0.0350827047805069, 0.039508962581749074, 0.1118495142145548, 0.087324999331031, 0.0373196677537635, 0.03789303249504883, 0.008987611527118133, 0.02805177580739837, 0.022857421135995537, 0.046464749102597125, 0.007934616223792545, 0.023320027758018114, 0.07930386724183336, 0.029762116355414037, 0.027900429631699808, 0.07457113955751993, 0.06341954693198204, 0.11325764295179397, 1.0268026334233582, 8.688127398490906, 16.080733314156532, 13.627236317843199, 18.008229285478592, 11.722279787063599, 10.451931953430176, 4.331406578421593, 0.3589300165185705, 0.04950605914928019, 0.26672989362850785, 1.3942866143770516, 3.020470510236919, 1.059995989780873, 1.6708692605607212, 3.1959004467353225, 2.943693967536092, 3.6527321208268404, 1.2156948912888765, 0.23744358855765313, 0.30820380721706897, 5.344442669302225, 22.53362685441971, 42.31475740671158, 50.994103476405144, 53.31514433026314, 53.62156368792057, 53.00780922174454, 49.97330725193024, 50.41724503040314, 53.70206996798515, 50.62375634908676, 52.79490664601326, 52.30719521641731, 52.7718722820282, 49.46754679083824, 40.43589122593403, 39.207090362906456, 39.53105717897415, 47.67920695245266, 49.28999371826649, 50.18286980688572, 51.59916400909424, 47.81532324850559, 49.39991042017937, 50.94444394111633, 50.06772078573704, 48.66004832088947, 41.89430996775627, 40.311634093523026, 38.36344063282013, 40.80675132572651, 36.553206369280815, 44.70113195478916, 48.17337803542614, 50.06582088768482, 49.333186000585556, 55.90321585536003, 43.047882467508316, 38.09770189225674, 52.61887729167938, 49.33608904480934, 54.5772922039032, 49.42547544836998, 51.09341114759445, 48.848446011543274, 46.64124324917793, 38.89598585665226, 35.81036902964115, 36.13762266933918, 36.826575100421906, 37.554806023836136, 38.96692045032978, 35.15482060611248, 41.282455399632454, 48.15466023981571, 48.76774214208126, 49.65701222419739, 46.1659799516201, 48.37183378636837, 44.17766444385052, 44.05773147940636, 47.70747363567352, 46.50197692215443, 44.35856893658638, 40.97911387681961, 40.46709135174751, 41.648926734924316, 44.58763584494591, 44.07142214477062, 43.618319258093834, 45.960186794400215, 46.35331369936466, 44.9460706114769, 46.65071614086628, 47.644909992814064, 39.49129991233349, 22.510567791759968, 7.984517253935337, 2.3989504482597113, 1.6343928803689778, 2.3404069896787405, 3.3884042920544744, 4.569352185353637, 4.0843732841312885, 11.832472924143076, 6.253006216138601, 3.5048910789191723, 2.710661734454334, 1.2902962882071733, 0.1353643520269543, 0.3972749464446679, 3.5972460731863976, 13.406613506376743, 25.78202124685049, 27.005078718066216, 35.236056447029114, 32.075028866529465, 15.794545020908117, 1.601278844755143, 0.03835742027149536, 0.034045597931253724, 0.024636783273308538, 0.05261988073471002, 0.004431540501173004, 0.06439865494030528, 0.0410469263442792, 0.04867024130362552, 0.044908131458214484, 0.03647231322247535, 0.022309224477794487, 0.06590336677618325, 0.031646583302062936, 0.03956605229177512, 0.05201634397963062, 0.025527425423206296, 0.011014123683708021, 0.03834103736153338, 0.10165907704504207, 0.026219435458187945, 0.036714424059027806, 0.05092529041576199, 0.011707707071764162, 0.032332131086150184, 0.019900528532161843, 0.03029291892744368, 0.04105498606804758, 0.027069237221439835, 0.05929638966335915, 0.12844674900406972, 0.04199989591143094, 0.05630006860883441, 0.029994772230566014, 0.08992480201413855, 0.054886585276108235, 0.04021781380288303, 0.040803394294925965, 0.03820669007836841, 0.029291720893525053, 0.036317683043307625, 0.05728545147576369, 0.03700390618178062, 0.03436486986174714, 0.0412426826369483, 0.016862610100361053, 0.05252325310721062, 0.014182638769852929, 0.05236522760242224, 0.019495035739964806, 0.024226485074905213, 0.10226770493318327, 0.012016490600217367, 0.07873656213632785, 0.0726869898790028, 0.05556473013712093, 0.008009750326891663, 1.2620077561587095, 13.899407163262367, 26.630137637257576, 23.342221565544605, 28.522836975753307, 15.576505120843649, 13.109177816659212, 5.840717889368534, 0.3474051458761096, 0.05474519872223027, 0.3571602317970246, 1.2275358871556818, 4.888254348188639, 5.44714355841279, 6.319787632673979, 4.827233422547579, 4.240096053108573, 5.656558396294713, 3.691404783166945, 2.70928549580276, 0.6491124001331627, 7.312689078971744, 25.480598621070385, 45.8286302536726, 52.810861989855766, 55.46483337879181, 54.45310726761818, 54.13128353655338, 52.80741557478905, 52.59954012930393, 54.60905849933624, 51.86381980776787, 54.7952751070261, 54.65451925992966, 53.531117141246796, 51.73081934452057, 41.170961782336235, 40.53388796746731, 42.53131918609142, 49.1954205930233, 52.429761439561844, 52.82796107232571, 52.01863490045071, 47.291810140013695, 50.68600080907345, 53.249506652355194, 51.53660036623478, 50.641398802399635, 44.63232904672623, 41.653608083724976, 39.81501214206219, 41.49261452257633, 39.37277287244797, 46.54108442366123, 49.74933207035065, 51.158790439367294, 50.30508264899254, 56.119956225156784, 45.58386258780956, 41.01045839488506, 53.16287510097027, 52.44603976607323, 55.97828462719917, 51.787447705864906, 54.14154298603535, 51.38055793941021, 48.318602442741394, 40.78739136457443, 37.15310677886009, 37.0490949600935, 38.106498420238495, 40.26679269969463, 39.80446010828018, 36.90741956233978, 42.6252805441618, 50.403326377272606, 50.468755066394806, 48.26742298901081, 46.11437112092972, 49.80564124882221, 45.78225374221802, 46.74829110503197, 49.22269552946091, 48.12689512968063, 45.74949949979782, 44.37969580292702, 42.063226103782654, 44.43019509315491, 46.28023982048035, 47.75754734873772, 45.977559462189674, 48.739866837859154, 47.593734338879585, 45.76063670217991, 48.07453393936157, 49.16749209165573, 40.01986674964428, 24.432248175144196, 10.052694026380777, 3.3764306595548987, 2.947399956174195, 5.243230350315571, 4.54527192749083, 7.166113369166851, 5.965261906385422, 11.712835393846035, 8.043224103748798, 4.716242328286171, 3.290548142977059, 0.342563166632317, 0.03433352154388558, 0.5241747479885817, 3.1094211246818304, 14.680558796972036, 29.525375179946423, 34.13369759917259, 38.25364172458649, 36.40935368835926, 19.38251294195652, 2.4649954168125987, 0.047986136996769346, 0.05821126585942693, 0.027889119301107712, 0.05746309565438423, 0.026363065153418574, 0.06725230923620984, 0.03102429247519467, 0.02536313062591944, 0.05437442545371596, 0.06833123610704206, 0.04612115699274, 0.030684147641295567, 0.030361239187186584, 0.05816564975248184, 0.010823283191712108, 0.02575401980720926, 0.07374083215836436, 0.026654927714844234, 0.05486149697389919, 0.018670099634618964, 0.023808898986317217, 0.0384531758754747, 0.02681405530893244, 0.08699335579876788, 0.03757166399736889, 0.0962136426824145, 0.16069325851276517, 0.12266243516933173, 0.10808318154886365, 0.20193465723423287, 0.07857058080844581, 0.18976952094817534, 0.1480794939561747, 0.18171240953961387, 0.08910681426641531, 0.12967522605322301, 0.09824225140619092, 0.13359165808651596, 0.1432589182513766, 0.10325173338060267, 0.22377851244527847, 0.18629224738106132, 0.09865821033599786, 0.10963312728563324, 0.11151002618134953, 0.19194959459127858, 0.08979442151030526, 0.2354057994671166, 0.11277497236733325, 0.07922272081486881, 0.1577829709276557, 0.2015469889738597, 0.14872578583890572, 0.15097081224666908, 0.07133929422707297, 0.12911680445540696, 2.2678254218772054, 22.06863820552826, 35.1531220972538, 33.931309059262276, 33.95762264728546, 20.786573700606823, 16.93595342338085, 6.860763654112816, 0.9887005342170596, 0.2630328107625246, 1.2901657889597118, 5.131312580779195, 8.906965255737305, 10.80749312415719, 7.462760601192713, 6.938478033989668, 7.536392575129867, 10.29744554311037, 5.152127863839269, 1.6291568800807, 0.7001181913074106, 5.9365819953382015, 26.059172675013542, 45.46404741704464, 53.20550501346588, 55.733224377036095, 56.71275481581688, 56.47743344306946, 55.40900677442551, 54.5592887699604, 56.98453143239021, 53.43809433281422, 57.06069074571133, 54.67792600393295, 55.577577129006386, 52.54629358649254, 44.26035940647125, 43.35764564573765, 43.20634916424751, 50.945492684841156, 54.38751518726349, 53.56066815555096, 52.5656421482563, 47.711710408329964, 52.087551802396774, 55.97999073565006, 53.8815875351429, 54.18402470648289, 47.13941551744938, 43.2060793787241, 43.18948946893215, 42.39608824253082, 40.82215189933777, 48.974477648735046, 53.078588023781776, 52.07890726625919, 54.02425467967987, 56.73011228442192, 47.30358570814133, 43.46814751625061, 54.305910766124725, 55.73821350932121, 58.56648154556751, 53.71882326900959, 56.093460246920586, 54.79752078652382, 49.82990674674511, 42.22407527267933, 38.26102092862129, 39.26412150263786, 39.65354360640049, 41.68240673840046, 43.69432657957077, 38.85018691420555, 45.07546126842499, 51.32676042616367, 52.148333340883255, 49.60052065551281, 47.26612351834774, 50.32884657382965, 47.22680702805519, 48.31605277955532, 49.51977878808975, 50.049496963620186, 48.01583468914032, 45.85680194199085, 44.462272971868515, 46.30024954676628, 48.2766754925251, 48.722049593925476, 46.793197095394135, 50.779810175299644, 48.90813700854778, 48.433580473065376, 50.05775012075901, 52.69897699356079, 41.17177493870258, 23.61283164471388, 10.095909107476473, 4.815179519355297, 4.215403078123927, 9.570568297058344, 9.629310294985771, 11.400169171392918, 11.088153664022684, 19.278096444904804, 15.737318191677332, 9.58533525466919, 7.709841392934322, 2.5404809787869453, 0.5912011920008808, 0.8414101658854634, 4.4371976517140865, 17.66204696148634, 33.31842094659805, 38.72004009783268, 43.51846821606159, 41.38667240738869, 22.324098497629166, 2.4822749895974994, 0.10360745218349621, 0.187697340734303, 0.19764704746194184, 0.17680307297268882, 0.07265459513291717, 0.2576555055566132, 0.11651445413008332, 0.14125465939287096, 0.11965981699177064, 0.3062043129466474, 0.09497325416305102, 0.11429834179580212, 0.1943873567506671, 0.17875428311526775, 0.14330911712022498, 0.10965850131469779, 0.1778125570854172, 0.062230284966062754, 0.16887742560356855, 0.09353482353617437, 0.07512956115533598, 0.14434049458941445, 0.10924421963864006, 0.12406221474520862, 0.17443517659557983], [0.014513068890664726, 0.06899417436216027, 0.036178504378767684, 0.032177886823774315, 0.01873183333373163, 0.039613438420929015, 0.11535824742168188, 0.009468692060181638, 0.01629362588573713, 0.04130227338464465, 0.0915392923343461, 0.06947294124984182, 0.07279598168679513, 0.04317439284932334, 0.0314644676836906, 0.015449506190634565, 0.060767025788663886, 0.0367463178554317, 0.07272510658367537, 0.0930552848149091, 0.054039342066971585, 0.041475620528217405, 0.07293773189303465, 0.01578426396008581, 0.052774945070268586, 0.03153491976263467, 0.03199426464561839, 0.019123396014038008, 0.06700861020362936, 0.018300443298358005, 0.060073796776123345, 0.11995579290669411, 4.1205064952373505, 15.65493956208229, 17.80528597533703, 16.09640557318926, 17.96984374523163, 12.602243218570948, 8.29500524327159, 3.05125645827502, 0.24441735731670633, 0.12136165809351951, 1.2209896696731448, 3.0083883460611105, 4.371202792972326, 5.902452701702714, 5.221517365425825, 2.83701587934047, 5.181737774983048, 3.8433909276500344, 2.6426522713154554, 1.1233531963080168, 0.24847855267580599, 2.751330239698291, 18.530769646167755, 37.19868153333664, 47.35679805278778, 52.878578156232834, 52.19605877995491, 52.71136812865734, 49.86562483012676, 51.60271681845188, 53.63731004297733, 54.23321306705475, 53.604631796479225, 53.187687769532204, 51.38216905295849, 43.51154878735542, 39.05307322740555, 41.0539660602808, 48.08279849588871, 49.87751439213753, 51.4474381506443, 50.29453061521053, 49.65531371533871, 51.800610199570656, 51.27796344459057, 49.6150890737772, 46.485029831528664, 39.645617231726646, 38.5036189109087, 37.776774913072586, 41.25932224094868, 38.26919429004192, 41.34889103472233, 45.223896503448486, 51.030858904123306, 50.84856368601322, 54.74746987223625, 45.300720781087875, 38.717498034238815, 51.40819385647774, 48.64230327308178, 50.95216512680054, 45.34742787480354, 47.69216425716877, 42.084451764822006, 38.492386713624, 34.55110140144825, 34.97697874903679, 38.813017308712006, 38.54832351207733, 36.288250386714935, 37.51600630581379, 35.48706337809563, 38.47857065498829, 48.50260376930237, 49.109279215335846, 49.22274872660637, 46.62434175610542, 47.02023871243, 47.68250897526741, 49.570734053850174, 46.541361808776855, 44.54736180603504, 42.34786503016949, 41.161580085754395, 38.58246847987175, 39.02265585958958, 41.27044044435024, 42.38340072333813, 42.031892985105515, 42.91510999202728, 43.37103232741356, 47.22248665988445, 49.07359153032303, 44.18335273861885, 31.996753066778183, 15.748956017196178, 3.5987080447375774, 1.1340512847527862, 2.1735083078965545, 3.313847305253148, 2.77100320905447, 6.160382861271501, 4.022671245038509, 8.91661673784256, 5.56751349940896, 3.073352510109544, 3.2612462528049946, 0.3874165238812566, 0.1283460989361629, 1.5882740425877273, 10.165425427258015, 24.08701580017805, 31.00529506802559, 25.83560597151518, 27.418350242078304, 28.805551305413246, 7.00279338285327, 0.35120696062222123, 0.06619285632041283, 0.062265514716273174, 0.020284968450141605, 0.05188092800381128, 0.06434746901504695, 0.01205380856845295, 0.028611093548533972, 0.04187527818430681, 0.01814435665437486, 0.043570265552261844, 0.02757871046924265, 0.015055653984745732, 0.06041871733032167, 0.025744249433046207, 0.05121027883433271, 0.11320467587211169, 0.04525275515334215, 0.04374907490273472, 0.11485330498544499, 0.050940348592121154, 0.10727398082963191, 0.034985394377144985, 0.022426138712035026, 0.03151206903567072, 0.023034091245790478, 0.035986091461381875, 0.08444483552011661, 0.04182201795629226, 0.029977444937685505, 0.023337004386121407, 0.08496330730849877, 0.08346920818439685, 0.027936683545704, 0.040454139598296024, 0.0374949964316329, 0.019071809329034295, 0.05395288928411901, 0.056028813633020036, 0.0026541798433754593, 0.010392713229521178, 0.026199709172942676, 0.07083950971718878, 0.031195479969028383, 0.0638052485010121, 0.05741982102335896, 0.03208180838555563, 0.01982202044018777, 0.10504916310310364, 0.049033548566512764, 0.035298328366479836, 0.05358735186746344, 0.06619393985602073, 0.01668296583375195, 0.04923009153571911, 0.06520206690765917, 0.07568333690869622, 0.23213205247884616, 7.123156674206257, 22.86394502967596, 25.52796307951212, 25.631621517241, 20.77056135982275, 14.693780187517405, 10.44237831607461, 3.389681736007333, 0.2517695026472211, 0.19066138949710876, 0.7045477442443371, 2.682303381152451, 4.388365047052503, 7.826750669628382, 7.325115837156773, 5.706698130816221, 7.540485430508852, 6.013541640713811, 6.110136257484555, 2.5290967896580696, 0.4043784277746454, 4.115560110658407, 22.755593843758106, 41.46292671561241, 49.91303488612175, 53.24812352657318, 54.70211170613766, 55.45595705509186, 52.25075304508209, 54.71155419945717, 56.66704706847668, 55.927177369594574, 55.35834789276123, 54.674798771739006, 53.565254509449005, 46.41013965010643, 41.45155392587185, 42.64865688979626, 49.76561799645424, 50.95420181751251, 52.26986221969128, 51.742032542824745, 50.66003680229187, 52.41550460457802, 52.71382659673691, 51.68894939124584, 47.44743078947067, 42.391589283943176, 40.70040263235569, 39.50497157871723, 42.69725628197193, 41.22177645564079, 43.087293952703476, 47.43322715163231, 53.32236774265766, 52.20710478723049, 56.21725380420685, 46.96080230176449, 40.01419745385647, 52.764151096343994, 50.30712693929672, 52.770059779286385, 48.53826865553856, 51.00130409002304, 43.72209548950195, 42.051195949316025, 36.62395857274532, 37.12657280266285, 38.9421533793211, 38.56358729302883, 38.08126397430897, 38.02742086350918, 36.602170541882515, 40.97426153719425, 49.74063813686371, 51.02528840303421, 49.61117908358574, 46.3700670003891, 47.339923158288, 49.46848914027214, 51.260279193520546, 47.47639663517475, 47.38420218229294, 45.020166635513306, 41.022841930389404, 40.18404074013233, 41.763669177889824, 44.97834987938404, 42.85708710551262, 45.36285884678364, 44.89838697016239, 46.23211160302162, 48.29260803759098, 48.78193058073521, 46.04464866220951, 33.42194639146328, 17.243248634040356, 6.104202875867486, 2.5785482861101627, 2.874114951118827, 5.953551409766078, 5.851384392008185, 7.855387832969427, 6.777545269578695, 12.45061045512557, 7.210862617939711, 3.3475168235599995, 0.69029749953188, 0.1708340088953264, 0.14499349548714235, 1.301399648655206, 9.892637114971876, 25.095658376812935, 33.68894666433334, 32.0160598307848, 32.2567693144083, 33.38554434478283, 8.848641235381365, 0.5221134179737419, 0.08444075370789506, 0.022484742403321434, 0.02148264265997568, 0.015713121683802456, 0.13061447330983356, 0.02418844072963111, 0.025266441771236714, 0.03292096218501683, 0.02965755331388209, 0.06490409461548552, 0.03211403243767563, 0.04542016140476335, 0.007604078491567634, 0.0243642146961065, 0.036126208942732774, 0.0294235727051273, 0.04327720627770759, 0.023127635249693412, 0.16608145844656974, 0.021182866948947776, 0.13180931622628123, 0.07069814542774111, 0.02871935434086481, 0.008310070588777307, 0.024964758740679827, 0.11968968843575567, 0.2021198527654633, 0.23299300315557048, 0.13253917393740267, 0.06010488163155969, 0.15917914366582409, 0.20508814661297947, 0.06214855224243365, 0.14460938953561708, 0.1129713372210972, 0.14026602962985635, 0.22168501775013283, 0.1898927174624987, 0.11877335127792321, 0.10791484019136988, 0.1307301889755763, 0.21327412454411387, 0.1495819867704995, 0.21527388598769903, 0.2328784897690639, 0.13382322300458327, 0.09584500308847055, 0.2573603088967502, 0.12363257803372107, 0.15429279883392155, 0.09545054417685606, 0.10761695695691742, 0.083017240249319, 0.1675361124216579, 0.2048712465330027, 0.21494398650247604, 0.5307564104441553, 8.51654950529337, 30.960092693567276, 36.79434522986412, 34.90865081548691, 28.389595225453377, 23.670026175677776, 13.217353262007236, 4.501388557255268, 0.47599012730643153, 0.38192000007256866, 3.162641068920493, 8.2013526186347, 11.758500393480062, 13.891681227833033, 10.884571988135576, 9.6627352014184, 12.37619049847126, 8.152763675898314, 7.460403302684426, 2.354406863451004, 0.316174651379697, 3.5946550872176886, 21.720766872167587, 39.563233852386475, 49.10953760147095, 54.64067280292511, 54.78123486042023, 55.85877723991871, 55.88742770254612, 56.812651455402374, 57.95845717191696, 56.88728325068951, 57.80884400010109, 56.7766559869051, 55.48453912138939, 48.879254758358, 42.554843723773956, 44.64725464582443, 52.272647470235825, 54.68544580042362, 54.5395602285862, 52.89675638079643, 50.55332712829113, 52.71158091723919, 54.5254971832037, 55.320775508880615, 50.98633669316769, 43.7784768640995, 42.17348478734493, 42.210650593042374, 44.60859552025795, 42.82570078969002, 45.08540153503418, 49.924650862812996, 56.67377270758152, 55.38131766021252, 56.4466854929924, 50.085298642516136, 44.200250431895256, 54.176185727119446, 52.7342315018177, 55.72818964719772, 49.539222344756126, 51.931399181485176, 45.05863197147846, 43.00699666142464, 38.05429682135582, 38.33251789212227, 41.82803012430668, 40.6351525336504, 39.53632369637489, 39.96051773428917, 39.14705738425255, 42.104062512516975, 52.027233839035034, 52.92291797697544, 49.95018169283867, 46.278119534254074, 49.01982061564922, 48.5120614618063, 51.965965926647186, 49.73680414259434, 47.574739158153534, 46.71717457473278, 44.34678956866264, 42.222707346081734, 43.159410282969475, 45.719910487532616, 45.85914261639118, 46.820388436317444, 46.30518168210983, 48.26577387750149, 51.202130913734436, 50.320608615875244, 46.03514537215233, 34.2346315830946, 16.183586195111275, 5.926447464153171, 2.40802934858948, 5.460617635399103, 7.34612300992012, 8.47089970484376, 12.297317180782557, 9.489055071026087, 20.636964328587055, 14.144952837377787, 8.326927330344915, 5.786299584433436, 0.9560253750532866, 0.21354502328904346, 2.481894535012543, 12.166463602334261, 31.469200775027275, 39.32326152920723, 35.343925058841705, 38.84665310382843, 37.528230249881744, 10.516889467835426, 0.5988909699954093, 0.2264705195557326, 0.11427296776673757, 0.06739431919413619, 0.1454269394162111, 0.24095324944937602, 0.08132309521897696, 0.11992123851086944, 0.10905117218499072, 0.14939904736820608, 0.15440192422829568, 0.15462765586562455, 0.183653348358348, 0.16543527046451345, 0.07770455384161323, 0.1092018726922106, 0.16744212683988735, 0.12474669754737988, 0.11895014569745399, 0.23292560130357742, 0.10145752457901835, 0.21679882134776562, 0.18688375392230228, 0.0944062607595697, 0.23679023142904043, 0.0843324743618723], [0.028953529763384722, 0.018980762652063277, 0.02848817533958936, 0.048780235010781325, 0.0398798434616765, 0.014630862569902092, 0.032697980204829946, 0.04105481908482034, 0.019157391943736002, 0.058395630185259506, 0.045697617024416104, 0.03925411278032698, 0.08230494175222702, 0.06117892517067958, 0.1277651308919303, 0.046301818001666106, 0.0532337147888029, 0.018122038418368902, 0.02875432062865002, 0.05582583253271878, 0.02141113673133077, 0.027031745776184835, 0.07697493361774832, 0.0346397131215781, 0.02732862896664301, 0.06029844858858269, 0.021469315543072298, 0.0076768627695855685, 0.04860562250541989, 0.09724608142278157, 0.021042628868599422, 0.17774953390471637, 0.7361673912964761, 5.857706777751446, 17.30964247137308, 17.706113196909428, 18.5151581838727, 13.014959022402763, 7.798818843439221, 5.248613711446524, 1.2670319178141654, 0.26468928437680006, 0.17989955056691542, 2.018293524160981, 2.314659096300602, 6.6134382504969835, 6.557181319221854, 2.9369338927790523, 4.941229205578566, 4.044401329010725, 6.760322218760848, 2.25582851562649, 0.3652106045046821, 0.29942179564386606, 3.8620939990505576, 16.99145894497633, 28.616785034537315, 39.41047444939613, 51.4231688529253, 52.523198425769806, 52.012570425868034, 53.12513552606106, 52.72790104150772, 51.98281802237034, 56.05981305241585, 51.414425522089005, 52.18542695045471, 45.630771070718765, 42.51084588468075, 40.22180311381817, 48.75509262084961, 50.95700606703758, 52.77911849319935, 49.88334707915783, 48.7605757266283, 50.469328835606575, 51.318549066782, 48.02984453737736, 46.729459315538406, 37.35382720828056, 38.96716743707657, 34.896951243281364, 39.90015797317028, 39.11839172244072, 42.42960624396801, 42.102622389793396, 48.798968866467476, 46.60127319395542, 55.18872119486332, 44.527340680360794, 38.492949083447456, 54.14120480418205, 49.38139781355858, 49.884373024106026, 44.84868943691254, 38.87018524110317, 34.9205631762743, 35.103629752993584, 35.51364295184612, 37.225500494241714, 37.07674227654934, 37.062641233205795, 38.24994832277298, 35.88492102921009, 35.61280623078346, 37.675707936286926, 46.843388602137566, 48.792589008808136, 49.59371902048588, 44.64144475758076, 46.23374551534653, 49.30352099239826, 46.73712730407715, 46.4447595924139, 43.52506846189499, 41.40541300177574, 39.14158567786217, 36.35961815714836, 38.780551850795746, 39.74280081689358, 40.850695967674255, 40.74888803064823, 42.67059311270714, 45.25900661945343, 46.9458045065403, 46.43235705792904, 42.70525865256786, 24.421397857367992, 9.663740247488022, 2.6877758000046015, 1.61034076474607, 2.269709170795977, 5.935013629496098, 3.8591954670846462, 5.113523360341787, 5.749698048457503, 8.247437495738268, 5.159240607172251, 2.107383543625474, 0.8206228469498456, 0.21990224544424564, 0.8209841838106513, 8.681508153676987, 20.732945278286934, 28.041003830730915, 27.43428848683834, 24.271615594625473, 26.579596549272537, 16.25006552785635, 1.141923749819398, 0.09751052348292433, 0.0431219489837531, 0.0239279283414362, 0.056529017456341535, 0.03305045953311492, 0.0467252689122688, 0.06849251221865416, 0.022914661130926106, 0.03140533335681539, 0.011509155665407889, 0.02782012368697906, 0.025466903280175757, 0.060455583516159095, 0.05271884612739086, 0.041224540836992674, 0.031631421225029044, 0.030784543523623142, 0.025236112051061355, 0.019240219335188158, 0.025022384652402252, 0.00825591328975861, 0.04312732955440879, 0.005223719135756255, 0.0054441652901005, 0.055004716632538475, 0.012784417704096995, 0.11496080507640727, 0.021286309347487986, 0.015472275281354086, 0.02504247459000908, 0.12333151840721257, 0.07199277009931393, 0.02019254879996879, 0.057636164492578246, 0.07412536855554208, 0.03756999045435805, 0.03829968860372901, 0.05846328436746262, 0.05932567852141801, 0.06423585000447929, 0.0875911112234462, 0.03439330524997786, 0.04182016629783902, 0.06788899772800505, 0.04140379918680992, 0.08883659829734825, 0.021024260713602416, 0.05382302828365937, 0.050079290303983726, 0.04069833958055824, 0.03137326886644587, 0.057060298713622615, 0.0735917198471725, 0.06498854359961115, 0.03264008155383635, 0.03822345890512224, 0.017445179328205995, 0.1128548348788172, 1.2257349025458097, 13.89379296451807, 24.804538898169994, 26.139251478016376, 27.974271811544895, 17.334335446357727, 13.276176955550909, 8.712371047586203, 1.1322447191923857, 0.1340876947506331, 0.320356089505367, 1.5794189739972353, 3.30962335690856, 5.2666613180190325, 8.852194044739008, 9.988671261817217, 9.0810377150774, 8.284242320805788, 6.486399667337537, 5.626916186884046, 1.5713927359320223, 0.6375912996008992, 6.247240975499153, 21.259435527026653, 33.39044988155365, 43.003060072660446, 54.163030833005905, 52.980203703045845, 52.748442739248276, 54.421538561582565, 53.8315936177969, 53.488711416721344, 57.83559836447239, 51.619527116417885, 55.008192881941795, 47.60698042809963, 45.10450690984726, 43.41683506965637, 50.647349283099174, 52.3171316832304, 53.6162743717432, 50.40921986103058, 48.83822835981846, 52.07029692828655, 52.90165811777115, 49.77899327874184, 47.80841901898384, 39.9227287620306, 40.70774383842945, 37.662021070718765, 41.93972893059254, 40.257673189044, 43.201162442564964, 44.754678681492805, 50.88135592639446, 49.54698532819748, 55.80892391502857, 47.29789361357689, 40.549972504377365, 55.55518493056297, 52.142648845911026, 50.74833646416664, 47.13589310646057, 41.85092769563198, 37.66785375773907, 37.9295989125967, 36.98216535151005, 38.7708243727684, 38.11295427381992, 39.37732882797718, 39.76491943001747, 38.246376514434814, 37.70962491631508, 38.853458538651466, 49.07464787364006, 49.79625575244427, 51.093498542904854, 45.50204157829285, 46.622654646635056, 50.63028059899807, 48.18641133606434, 48.26254405081272, 45.33887453377247, 42.49664984643459, 40.957584232091904, 39.4425181299448, 40.157073587179184, 41.75712212920189, 42.660953029990196, 41.911462247371674, 45.18073841929436, 47.323580235242844, 47.966429740190506, 48.209715485572815, 43.98039422929287, 26.240616738796234, 10.339528284966946, 3.20314547047019, 3.755886135622859, 4.20997079461813, 5.10907094925642, 4.627928417176008, 8.939994033426046, 8.246554043143988, 5.997006352990866, 4.474515924230218, 0.906096410471946, 0.2791145571973175, 0.16520253295311704, 0.9358561760745943, 8.726828321814537, 22.974021323025227, 33.51118840277195, 31.855750232934952, 25.841227769851685, 29.688880406320095, 21.212010271847248, 2.6832400308921933, 0.09835190372541547, 0.0404568224621471, 0.0350567667192081, 0.028453980885387864, 0.010694559532566927, 0.053105939223314635, 0.026354996152804233, 0.0162045292017865, 0.03411515201150905, 0.07504551293095574, 0.004196244435661356, 0.014486769960058155, 0.07236569188535213, 0.031146041801548563, 0.020482429827097803, 0.019172763677488547, 0.0454921237542294, 0.0353444157371996, 0.05042533150117379, 0.040880006199586205, 0.017447498539695516, 0.02185420446039643, 0.01890515264676651, 0.021712129564548377, 0.034135223395423964, 0.0607937579479767, 0.34935984411276877, 0.08799503993941471, 0.11017807148164138, 0.15804526075953618, 0.11037112635676749, 0.14379998843651265, 0.10884578281547874, 0.18798542761942372, 0.27652318531181663, 0.13915307528804988, 0.14344120456371456, 0.08094528267974965, 0.1723326722276397, 0.11389691411750391, 0.3806331753730774, 0.14428394293645397, 0.1758505858015269, 0.16087455034721643, 0.1192784940940328, 0.1487813430139795, 0.1817496950388886, 0.24025113321840763, 0.08660357241751626, 0.16232500376645476, 0.10580880320048891, 0.12042566144373268, 0.21174776426050812, 0.11234511301154271, 0.19054754404351115, 0.21047995338449255, 0.11946450598770753, 0.2709129051072523, 1.8638011766597629, 18.296316526830196, 34.07825477421284, 38.695261627435684, 32.51994699239731, 22.08644025027752, 16.33434120565653, 7.914248099550605, 1.9710590899921954, 0.5557073559612036, 0.8112188859377056, 5.385020691901445, 7.742417519912124, 11.932444609701633, 16.90861389040947, 14.383043311536312, 13.998323455452919, 12.850488647818565, 12.764637004584074, 5.467054964974523, 1.6053953301161528, 0.6206164229661226, 5.017843544483185, 20.116606950759888, 31.806565672159195, 40.40046192705631, 54.55381326377392, 53.17877724766731, 54.57776717841625, 54.91091050207615, 54.94034372270107, 53.643469512462616, 59.349064752459526, 53.80564481019974, 56.27673581242561, 49.64699216187, 48.36241789162159, 44.41808134317398, 53.82470078766346, 54.60318401455879, 54.904895424842834, 49.46907810866833, 49.67284597456455, 52.84290947020054, 54.65399108827114, 50.8942524343729, 49.78908933699131, 41.83531433343887, 41.58840358257294, 39.33028735220432, 44.37348313629627, 41.95725739002228, 46.310953572392464, 46.13354109227657, 52.69241474568844, 51.02310732007027, 57.456013932824135, 48.294644728302956, 44.4134645909071, 56.93775214254856, 55.42961306869984, 51.9929064810276, 50.90433329343796, 42.70547904074192, 38.7143138051033, 38.335515931248665, 39.97572831809521, 40.037235617637634, 40.47835774719715, 40.925521552562714, 42.902927845716476, 39.63687390089035, 39.51236978173256, 41.2302727997303, 50.69407917559147, 53.553661331534386, 53.268767818808556, 46.60810522735119, 46.908216923475266, 52.017244175076485, 51.059798151254654, 51.13199047744274, 47.01482020318508, 44.51616548001766, 42.491425126791, 40.5545474588871, 42.92052090167999, 42.64559045433998, 45.18890418112278, 43.30149605870247, 47.02736333012581, 49.05309922993183, 50.47876372933388, 50.60624308884144, 44.42545674741268, 26.122247390449047, 11.379626523703337, 4.4987305998802185, 4.234574474394321, 6.369883194565773, 12.7961734123528, 7.710886336863041, 12.040412966161966, 13.845138475298882, 16.41347385942936, 12.163709700107574, 5.79896810464561, 2.0752883283421397, 0.5298723047599196, 1.2700286507606506, 11.140305865556002, 25.35634908825159, 36.31484515964985, 36.53772599995136, 34.378092885017395, 35.90131334960461, 21.899026706814766, 2.632209719158709, 0.1773056702222675, 0.14795116177992895, 0.12728147325105965, 0.11339074713760056, 0.15983889810740948, 0.1012066044495441, 0.1727795638726093, 0.21125656639924273, 0.15753224375657737, 0.14187748456606641, 0.1156251756765414, 0.10810621039127, 0.14370468183187768, 0.11693747088429518, 0.12481601414037868, 0.14281849813414738, 0.14749160909559578, 0.07380174763966352, 0.13801264663925394, 0.13546000001952052, 0.07274358606082387, 0.08057988627115265, 0.15351225243648514, 0.12443311788956635, 0.2184745908016339, 0.1365693029947579], [0.04787830665009096, 0.0187335662485566, 0.053444829827640206, 0.05775069643277675, 0.03119702363619581, 0.03892989072483033, 0.12253612905624323, 0.09282984261517413, 0.040560348352300934, 0.0666513699979987, 0.023806418357708026, 0.06509260754683055, 0.030727836019650567, 0.0812854386458639, 0.028581773149198852, 0.05094749547424726, 0.033257158793276176, 0.059985822590533644, 0.044843063660664484, 0.023114638388506137, 0.03446778719080612, 0.03493159238132648, 0.029558179739979096, 0.08140003366861492, 0.03883038356434554, 0.027207428829569835, 0.03578984906198457, 0.04197616573947016, 0.033662274945527315, 0.09891634414088912, 0.04862976828007959, 0.0461825288948603, 0.04050667252158746, 3.6389830335974693, 17.7641873806715, 21.482075080275536, 25.462572388350964, 22.724918089807034, 13.001907672733068, 9.39396707341075, 5.3525628335773945, 0.8393212873488665, 0.09661873657023534, 0.9863969078287482, 2.224495871923864, 5.120075158774853, 7.153925998136401, 6.817945651710033, 7.795149190351367, 6.240853993222117, 5.681147351861, 5.89067523367703, 1.78600890096277, 0.5714141100179404, 0.8671337168198079, 4.486747467890382, 14.503678288310766, 22.540671676397324, 38.36953930556774, 48.88716213405132, 56.15549571812153, 51.577284783124924, 55.94448544085026, 56.377460807561874, 54.50367875397205, 51.94644257426262, 50.98135896027088, 44.597735702991486, 41.86400279402733, 43.33429969847202, 49.87336501479149, 50.30141964554787, 52.73947902023792, 48.35784673690796, 49.77377615869045, 51.482324078679085, 51.341803818941116, 51.64765700697899, 45.937118232250214, 38.25487285852432, 38.4842399507761, 37.77766786515713, 38.25114145874977, 37.120755314826965, 39.60180938243866, 43.00120197236538, 48.67638744413853, 47.46764190495014, 55.70340357720852, 45.29185585677624, 39.30677801370621, 53.54431763291359, 47.763395234942436, 50.26416264474392, 41.61130115389824, 38.542924001812935, 35.934865549206734, 38.88669155538082, 39.25104260444641, 40.7338560372591, 38.714161813259125, 40.24221181869507, 36.35212495923042, 37.12152287364006, 35.70037253201008, 37.38583289086819, 40.681703835725784, 47.23768204450607, 47.95456677675247, 50.31740918755531, 48.63282658159733, 47.152695804834366, 47.859754264354706, 47.3176259547472, 45.426262244582176, 42.83533327281475, 40.87219141423702, 40.25929570198059, 38.62243093550205, 41.78759649395943, 42.01783373951912, 43.76370705664158, 44.3205975741148, 49.11928407847881, 47.77096822857857, 45.66883362829685, 31.76932767033577, 14.947567619383335, 2.1452012518420815, 1.0215460904873908, 4.096130328252912, 2.3258540080860257, 3.7278626393526793, 4.016567822545767, 9.122597984969616, 7.1321873646229506, 6.074620513245463, 3.958613807335496, 1.414847073610872, 0.16161202249350026, 0.659924898063764, 6.912709241732955, 15.209602508693933, 21.49317428469658, 29.617476537823677, 30.988328978419304, 30.06865292787552, 20.265931338071823, 5.1655306946486235, 0.0862304428301286, 0.046584542869823053, 0.02300855023349868, 0.03392100246855989, 0.04464361889404245, 0.013967101458547404, 0.02758789083600277, 0.07073028784361668, 0.010274673713865923, 0.01708607447653776, 0.05254800373222679, 0.05049115628935397, 0.06430901834391989, 0.0374912782717729, 0.04848418859182857, 0.01542224525110214, 0.05720611217839178, 0.051498324901331216, 0.012901716927444795, 0.07135471605579369, 0.01621534043806605, 0.01932683910126798, 0.024337345239473507, 0.07145290219341405, 0.061398292891681194, 0.04651197567000054, 0.04042212705826387, 0.044017799154971726, 0.01749074348481372, 0.03894551293342374, 0.08856897984514944, 0.06508867416414432, 0.05918392831517849, 0.04851884317758959, 0.04119700715818908, 0.024064761819317937, 0.05677537337760441, 0.04509409511229023, 0.013369667012739228, 0.023478316725231707, 0.07493643948691897, 0.05858015036210418, 0.06166964434669353, 0.02221298091171775, 0.05752816716267262, 0.024703878989384975, 0.040291932091349736, 0.044356608123052865, 0.10419358557555825, 0.011905905030289432, 0.0785559530777391, 0.06123489794845227, 0.039286448154598475, 0.037562884390354156, 0.07124593204935081, 0.018198260695498902, 0.09824310487601906, 0.012979791790712625, 0.010524023273319472, 0.06412020113202743, 5.487964292988181, 25.510010942816734, 27.996947094798088, 33.33184942603111, 24.35483492910862, 14.779165405780077, 14.183433372527361, 6.197054693475366, 1.3985370425507426, 0.1599566769436933, 0.48926697112619877, 1.7759895510971546, 3.687482443638146, 7.132024448364973, 8.64328695461154, 11.224002074450254, 8.176012728363276, 5.981337418779731, 9.134132266044617, 3.810085002332926, 2.365665421821177, 1.4735079696401954, 5.884707178920507, 16.76276631653309, 26.049614287912846, 41.4373654872179, 51.259412840008736, 54.6760793030262, 51.743362471461296, 58.3550076931715, 55.70456251502037, 56.42604120075703, 52.95697934925556, 52.39004597067833, 46.949744895100594, 43.83930020034313, 43.72022598981857, 51.18747889995575, 52.67692297697067, 56.16665191948414, 49.48773890733719, 49.856349527835846, 53.83666634559631, 53.34950588643551, 53.40839132666588, 47.61038884520531, 41.24028146266937, 40.17814725637436, 39.26601380109787, 39.30092632770538, 39.665691554546356, 41.92826874554157, 44.48656506836414, 50.86511939764023, 47.95463517308235, 56.4738692343235, 47.28377357125282, 41.251981034874916, 52.65940971672535, 50.157243981957436, 52.36422635614872, 43.58479745686054, 39.96621362864971, 38.303050473332405, 38.66818808019161, 40.80123782157898, 42.23641321063042, 40.48640191555023, 40.0848014652729, 38.15076224505901, 39.306295439600945, 38.164570704102516, 39.36635501682758, 42.182292714715004, 48.754127472639084, 50.08370652794838, 51.10418736934662, 49.34198632836342, 47.84434229135513, 49.33058314025402, 48.92650902271271, 46.50645308196545, 44.73002180457115, 40.66908471286297, 41.91748112440109, 39.46519911289215, 43.90834629535675, 43.50404419004917, 44.43588338792324, 46.5739868581295, 50.075126588344574, 49.352789148688316, 47.71410807967186, 33.294968605041504, 18.359461538493633, 4.658150095492601, 2.7441633492708206, 4.884096421301365, 3.2134669041261077, 5.034974925220013, 5.362427579239011, 6.544210240244865, 5.906179826706648, 3.2073820056393743, 1.6647504013963044, 0.3151720989262685, 0.04518630696111359, 0.7694469555281103, 5.704913176596165, 18.32561105489731, 25.364505350589752, 33.033383041620255, 33.00035521388054, 33.9361310005188, 25.295732840895653, 7.750205202028155, 0.16461344581330195, 0.052917645225534216, 0.00690627321091597, 0.014100515491008991, 0.053245700473780744, 0.044171813351567835, 0.021727367711719126, 0.06847813681815751, 0.045265661101439036, 0.016560832445975393, 0.016716047066438477, 0.030983546712377574, 0.03520152633427642, 0.031858021175139584, 0.017706227918097284, 0.02385050007433165, 0.05846816398843657, 0.021341218998713885, 0.01813152492104564, 0.007642566270078532, 0.023002228990662843, 0.03979708286351524, 0.02109123768605059, 0.0327604913036339, 0.030314828982227482, 0.09535790188238025, 0.048195704657700844, 0.13309728383319452, 0.15785145631525666, 0.19885708956280723, 0.16372874641092494, 0.21035700920037925, 0.15402681310661137, 0.1982844335725531, 0.128959305875469, 0.20717914769193158, 0.15969438711181283, 0.13312423863681033, 0.09890657747746445, 0.08269960104371421, 0.28904101985972375, 0.10928563890047371, 0.13860274309990928, 0.10117087003891356, 0.16824863356305286, 0.1080146071035415, 0.150046422786545, 0.11806333117419854, 0.18240610981592909, 0.09186208204482682, 0.2205889398464933, 0.1271028828341514, 0.09160948466160335, 0.12408681694068946, 0.12294606916839257, 0.1010565718752332, 0.16084636357845739, 0.18188749701948836, 0.14726133551448584, 0.3877899725921452, 7.7760998625308275, 34.14378225803375, 36.363531947135925, 45.50349310040474, 33.0035812407732, 22.49775867909193, 16.086062528192997, 6.5994160529226065, 1.9370094733312726, 0.3915552736725658, 2.556706820614636, 6.198262553662062, 13.73878313228488, 15.358204934746027, 15.949229970574379, 17.47349727898836, 14.232039414346218, 11.673789639025927, 12.41702500730753, 4.402315998449922, 2.2616258170455694, 1.8545194622129202, 6.363523760810494, 15.895238667726517, 24.618079103529453, 38.932452499866486, 50.38841597735882, 55.026637092232704, 52.699657157063484, 58.96105617284775, 58.43989513814449, 57.833717465400696, 55.48232764005661, 55.221673026680946, 48.60183164477348, 45.69338411092758, 46.938744485378265, 53.254036009311676, 55.13848789036274, 56.18493273854256, 49.24428977072239, 49.39109869301319, 55.69363810122013, 56.31878435611725, 56.20626859366894, 49.99243542551994, 43.185693472623825, 42.124710604548454, 42.46270626783371, 41.1230805516243, 40.97263902425766, 43.272568210959435, 47.51972571015358, 53.511677384376526, 50.925494357943535, 57.985796704888344, 50.82720883190632, 44.33988153934479, 57.34757915139198, 52.099574357271194, 55.06976097822189, 44.99334767460823, 42.414502054452896, 40.578337982296944, 40.81313878297806, 44.10678304731846, 44.521827176213264, 42.93014578521252, 43.27990561723709, 39.90595646202564, 41.451455131173134, 39.778556898236275, 41.39981210231781, 43.76282550394535, 49.76706571877003, 52.43305966258049, 52.814635187387466, 48.549079075455666, 48.75223137438297, 49.007387682795525, 51.54535509645939, 47.80320569872856, 45.513205379247665, 43.78646783530712, 45.56585155427456, 43.027249574661255, 46.02583587169647, 45.63034929335117, 47.54906393587589, 47.400294318795204, 53.11096988618374, 50.38317985832691, 48.91599878668785, 33.608580976724625, 16.133172400295734, 3.6472117295488715, 2.9294072091579437, 9.307770598679781, 5.542845223098993, 9.000865817070007, 9.472904987633228, 17.223618887364864, 13.559209518134594, 13.207125160843134, 7.184767043218017, 2.323270859196782, 0.43620243261102587, 1.1248733522370458, 9.127522520720959, 18.86294972151518, 28.36790218949318, 39.91359785199165, 39.99399393796921, 39.72741924226284, 28.24026133865118, 7.9511982668191195, 0.2168941279524006, 0.19102253339951858, 0.19419799034949392, 0.13719588343519717, 0.1494172151433304, 0.11194682461791672, 0.12528448743978515, 0.17217236832948402, 0.1359516876982525, 0.1142107015766669, 0.10832375613972545, 0.111199942039093, 0.08962744570453651, 0.1118361036060378, 0.09760384855326265, 0.10531456253374927, 0.12737490964354947, 0.12814450194127858, 0.11163195362314582, 0.18242778052808717, 0.13842922897310928, 0.11700464267050847, 0.09526235779048875, 0.0955357427301351, 0.09515483543509617, 0.14113490644376725, 0.08635425532702357], [0.04430693246831652, 0.04646694957045838, 0.07579042139695957, 0.03724321170011535, 0.0281390579402796, 0.013823990339005832, 0.12098734849132597, 0.008998904231702909, 0.008800592167972354, 0.0410257454495877, 0.05276736403175164, 0.08424352054134943, 0.011424851400079206, 0.050648922042455524, 0.03534772200509906, 0.04632132906408515, 0.11498980078613386, 0.022316360227705445, 0.029486842649930622, 0.019165117701049894, 0.05457021514303051, 0.02607023408927489, 0.023640524232177995, 0.08249819700722583, 0.0472471620014403, 0.05062056829046924, 0.016916527129069436, 0.027007369935745373, 0.05075336077425163, 0.042693566501839086, 0.042327991977799684, 0.04867874631599989, 0.10647833172697574, 0.6608160689938813, 10.050097815692425, 24.152170903980732, 25.594989582896233, 32.8954466432333, 31.056085042655468, 17.863225266337395, 5.234638061374426, 3.8651274237781763, 0.37643965508323163, 0.2624866791302338, 0.8123577560763806, 2.2236972022801638, 4.682427467778325, 6.93118242546916, 7.844936968758702, 6.584374085068703, 4.296330185607076, 7.549952147528529, 3.6086231376975775, 2.634956259280443, 1.806273094844073, 1.3248155359178782, 5.137862479314208, 12.364540323615074, 28.616460151970387, 41.7290910333395, 51.45613968372345, 53.80767770111561, 55.78748546540737, 53.70026886463165, 53.85553993284702, 51.92828334867954, 52.34359346330166, 46.70010209083557, 45.47641195356846, 42.71962568163872, 50.6616935133934, 50.94431854784489, 55.748119577765465, 48.02921377122402, 51.39343164861202, 50.78012935817242, 52.314133644104004, 49.683120623230934, 49.25602354109287, 41.431434005498886, 39.96185906231403, 37.62284517288208, 39.140905514359474, 36.88531614840031, 38.45835953950882, 41.480398178100586, 51.50088228285313, 50.058156698942184, 56.74843110144138, 47.46656656265259, 39.869736805558205, 57.45436102151871, 49.13667194545269, 50.494206100702286, 41.70557789504528, 38.39363381266594, 38.326692804694176, 40.14986917376518, 41.975872591137886, 44.06614802777767, 46.779426634311676, 45.96224628388882, 45.97284011542797, 41.73802815377712, 37.39209495484829, 35.660991445183754, 36.65801614522934, 44.40502144396305, 47.07389563322067, 48.082255125045776, 49.411552995443344, 48.153007328510284, 48.8249708712101, 49.11159709095955, 46.787778586149216, 44.03471611440182, 42.11839534342289, 42.10684396326542, 43.10546837747097, 42.79478184878826, 44.44247603416443, 45.05004823207855, 47.63906970620155, 48.17392900586128, 46.753116846084595, 38.025729954242706, 20.156426914036274, 5.292714145034552, 1.2561533390544355, 1.5608985302969813, 3.4774845745414495, 2.895919606089592, 2.7425332367420197, 3.82127920165658, 4.953642664477229, 5.043736780062318, 2.2780124377459288, 1.1323977797292173, 0.13863793574273586, 0.43670813203789294, 3.652181150391698, 15.575431678444147, 27.478651106357574, 28.88200130313635, 30.340982414782047, 32.816988453269005, 21.745313555002213, 10.138183739036322, 0.9014457568991929, 0.06766964856069535, 0.03818510100245476, 0.051102374272886664, 0.029466713749570772, 0.02658292454725597, 0.022946736753510777, 0.02349064565351, 0.04540317735518329, 0.07407373734167777, 0.03956313194066752, 0.011686045636452036, 0.01275035127036972, 0.024957123896456324, 0.0658816441136878, 0.02411794226645725, 0.05013405709178187, 0.06396210883394815, 0.023960412145243026, 0.0883732755028177, 0.0067776947344100336, 0.07151211073505692, 0.042091766372323036, 0.019542410736903548, 0.025975634380301926, 0.051585976252681576, 0.03488349750114139, 0.03583849313145038, 0.04072098250617273, 0.08248754718806595, 0.09124127551331185, 0.03980512774433009, 0.022350903491314966, 0.028602224883798044, 0.022250847141549457, 0.046214255708036944, 0.04786523000802845, 0.007343923261942109, 0.04345141802332364, 0.04505285767663736, 0.05141323395946529, 0.023195256035251077, 0.01698903681244701, 0.01311151558184065, 0.1370538808987476, 0.010255806464556372, 0.02786809425742831, 0.04296003833587747, 0.016910994418140035, 0.03157449478749186, 0.010433505376568064, 0.10092789088957943, 0.06595484956051223, 0.0801751263497863, 0.03044290882826317, 0.026285314052074682, 0.042581342640914954, 0.05443481029942632, 0.04944454994983971, 0.03559313168807421, 0.10005885822465643, 1.429179785773158, 16.28180332481861, 30.713732913136482, 30.655559934675694, 36.305984035134315, 29.898973032832146, 14.863219745457172, 10.100483112037182, 4.8330827336758375, 0.658227161038667, 0.12129427850595675, 0.5460095044691116, 2.114055035635829, 4.332809653133154, 7.892872346565127, 8.272707089781761, 10.162755120545626, 7.477135704830289, 8.688807561993599, 7.645335104316473, 2.7688940847292542, 2.219701479189098, 1.8232488026842475, 6.123321549966931, 14.29417748004198, 30.321979634463787, 44.431213438510895, 51.99696846306324, 56.2532264739275, 57.518140599131584, 56.28509156405926, 55.226327776908875, 53.89249674975872, 52.83768095076084, 48.74630369246006, 47.16825596988201, 45.11538192629814, 52.61378176510334, 53.80577400326729, 55.465893521904945, 48.245543763041496, 51.60868629813194, 52.14230306446552, 52.50910498201847, 52.23451651632786, 52.75552175939083, 42.80712738633156, 41.13064594566822, 39.59264427423477, 40.23360528051853, 40.036559253931046, 39.449878334999084, 45.626260712742805, 51.10671803355217, 52.08592168986797, 58.16550426185131, 48.7686350941658, 42.55087673664093, 57.51872576773167, 50.95760263502598, 52.995296493172646, 43.95982973277569, 39.26353633403778, 39.521044716238976, 42.602109387516975, 43.180711939930916, 45.407498851418495, 47.808601409196854, 48.208507150411606, 46.00873678922653, 43.14010351896286, 38.19223701953888, 37.86076180636883, 37.38058157265186, 46.62531830370426, 47.88442254066467, 50.50526350736618, 50.41546672582626, 48.52460838854313, 49.149401262402534, 50.81667959690094, 47.83603593707085, 46.09112776815891, 42.07932583987713, 42.754241824150085, 43.78253124654293, 44.38038356602192, 46.1965075135231, 46.26115724444389, 47.85069555044174, 48.292516842484474, 47.41596847772598, 42.15771943330765, 22.263731136918068, 7.81513374298811, 2.415111931040883, 3.541313074529171, 3.6387519584968686, 3.3737605903297663, 4.192223846912384, 5.670376354828477, 6.248727170750499, 5.522120660170913, 1.5258380491286516, 0.5593813431914896, 0.21127078594872728, 0.34954345144797117, 3.0382450064644217, 17.6572098210454, 30.90351562947035, 28.231666199862957, 34.04216431081295, 37.78609201312065, 26.649368405342102, 13.170137945562601, 1.8272638809867203, 0.07285913845407777, 0.05960279275313951, 0.004006038016086677, 0.03515339063596912, 0.03451860946370289, 0.013076150389679242, 0.03096683354669949, 0.0720370392082259, 0.05967759381746873, 0.062458436004817486, 0.011414280434109969, 0.010897087922785431, 0.024109413134283386, 0.054730515330447815, 0.012591588256327668, 0.03335438756039366, 0.062290866480907425, 0.10335550046875142, 0.017428106220904738, 0.10614193102810532, 0.015581117731926497, 0.0574604907160392, 0.03313411812996492, 0.07765241054585204, 0.02809562189213466, 0.0255473650759086, 0.07775476755341515, 0.13740310590947047, 0.09732606267789379, 0.17908419744344428, 0.13997984264278784, 0.09225763191352598, 0.1188703128718771, 0.1585897002951242, 0.10917532606981695, 0.12379611027427018, 0.1565506198676303, 0.15027164976345375, 0.15340597688918933, 0.09449072458664887, 0.11236434947932139, 0.07900432901806198, 0.10755361465271562, 0.2704315184382722, 0.11087462160503492, 0.12214871312608011, 0.12463619175832719, 0.1632063338183798, 0.12634207756491378, 0.07966377175762318, 0.21701312391087413, 0.15184700663667172, 0.155307047534734, 0.1457170894718729, 0.15204229537630454, 0.15807139920070767, 0.09353549889056012, 0.17257673491258174, 0.17763130977982655, 0.18963980837725103, 1.9115971494466066, 19.849960058927536, 38.12687672674656, 39.49110612273216, 46.38531558215618, 39.88945014774799, 26.320049576461315, 10.852029584348202, 5.687518659979105, 1.0224492545239627, 0.6216912309173495, 3.026101808063686, 6.412750594317913, 12.680148538202047, 15.692752283066511, 18.04929368197918, 14.91337800398469, 11.343333721160889, 14.207911659032106, 10.230873115360737, 5.174656379967928, 3.2191958092153072, 2.4378546606749296, 6.218837974593043, 14.166303891688585, 32.34674848616123, 43.38534235954285, 54.456610679626465, 57.49739371240139, 58.05496819317341, 57.76231549680233, 57.163669019937515, 55.897379368543625, 55.932348892092705, 49.84427757561207, 50.62571324408054, 47.35447637736797, 54.66431513428688, 54.86590951681137, 58.01647625863552, 48.13761055469513, 51.826137229800224, 54.355783089995384, 55.74345722794533, 53.67275454103947, 55.66210739314556, 45.50747148692608, 43.388420194387436, 39.74140249192715, 42.3419601470232, 42.07156665623188, 41.46315470337868, 46.859381943941116, 54.27031047642231, 56.33295759558678, 59.75820019841194, 50.88261365890503, 45.348191633820534, 60.658090710639954, 53.79391863942146, 55.61668083071709, 46.626169458031654, 42.08112694323063, 41.029309183359146, 44.15367253124714, 44.92422938346863, 47.70516715943813, 50.00238709151745, 51.136082857847214, 48.5708063095808, 46.747413352131844, 40.670103058218956, 39.31146316230297, 40.15762455761433, 47.83245652914047, 50.81068351864815, 52.93408937752247, 52.79008850455284, 48.70711639523506, 48.3620835095644, 52.90604688227177, 49.89317715167999, 46.47064760327339, 43.671751990914345, 45.68398341536522, 46.91372662782669, 46.769471168518066, 49.052031487226486, 48.79169225692749, 51.49984873831272, 49.75253149867058, 50.16908034682274, 40.530342757701874, 22.769466899335384, 6.897236946970224, 2.534301560372114, 6.040595714002848, 7.761966045945883, 6.703928019851446, 6.7860169149935246, 8.270183075219393, 10.574786961078644, 13.198264986276627, 7.476563835516572, 2.6597518287599087, 0.49098029325250536, 0.6603222142439336, 4.839602233842015, 19.036737196147442, 36.14001274108887, 37.10511915385723, 41.22062511742115, 43.99022810161114, 31.508450768887997, 13.96127924323082, 1.4559506555087864, 0.21807525597978383, 0.1672745795804076, 0.10071300945128314, 0.08432610673480667, 0.11675366316922009, 0.1658672300982289, 0.15727880032500252, 0.19635692762676626, 0.15968511026585475, 0.15652887494070455, 0.1234062304138206, 0.15062253718497232, 0.1891887458623387, 0.1456055892049335, 0.11820957137388177, 0.11021703423466533, 0.19373932824237272, 0.28886619955301285, 0.17559818137669936, 0.2536527765914798, 0.1234507815388497, 0.11667588609270751, 0.17589306633453816, 0.12518371862825006, 0.1703478576382622, 0.135223833785858, 0.222943180706352], [0.053502401933656074, 0.04503796277276706, 0.01713337896944722, 0.02503438518033363, 0.07234705655719154, 0.035428920382400975, 0.011301301437924849, 0.1447336992714554, 0.0438762047997443, 0.024235047603724524, 0.04718113683338743, 0.025476944538240787, 0.053191720362519845, 0.0964044191641733, 0.013126018075126922, 0.03650211787316948, 0.015678337222198024, 0.03208774185623042, 0.03220138321921695, 0.02635694429045543, 0.03721572626091074, 0.08936951970099472, 0.007320240401895717, 0.0320309118978912, 0.0465443852590397, 0.048943110450636595, 0.11238660648814403, 0.01911529547214741, 0.008812393243715633, 0.07565123160020448, 0.03894440713338554, 0.0547398367052665, 0.0402622832916677, 0.17728434089804068, 5.083091743290424, 20.25021158158779, 26.020543947815895, 24.29058987647295, 44.67259168624878, 40.66534571349621, 17.51853436231613, 8.489013332873583, 3.9690292859449983, 0.5397914350032806, 0.2765900973463431, 1.3474246789701283, 3.005900429561734, 6.246937466785312, 6.155734760686755, 6.887035919353366, 5.703520076349378, 8.475221022963524, 5.724109746515751, 3.736990224570036, 1.2576857255771756, 0.7808265730272979, 2.0567429484799504, 6.457058591768146, 15.488107614219189, 29.429006651043892, 42.96163469552994, 53.92303951084614, 58.10012497007847, 53.26060205698013, 54.69667039811611, 50.59236243367195, 50.44804237782955, 50.553330928087234, 45.20628824830055, 47.58420065045357, 54.56985220313072, 53.32295671105385, 54.00229565799236, 50.0157205760479, 51.33798882365227, 52.132932767271996, 52.1283920109272, 52.80790954828262, 51.01378262042999, 44.66306559741497, 39.86474767327309, 39.657218009233475, 39.54972557723522, 38.235554695129395, 40.346474424004555, 43.06001901626587, 52.16915622353554, 47.589626759290695, 53.84458512067795, 48.9677482098341, 39.593522027134895, 56.38076663017273, 48.94613116979599, 49.9893955886364, 40.53231105208397, 38.98461230099201, 39.21807557344437, 41.66012853384018, 45.575290247797966, 48.03889185190201, 49.83164705336094, 50.29215194284916, 48.311253637075424, 47.568180710077286, 45.30969209969044, 40.1817836612463, 35.34273952245712, 36.45408108830452, 45.07152087986469, 46.35921098291874, 47.36343629658222, 50.27456268668175, 49.66670170426369, 49.172401428222656, 48.4895134717226, 46.833398938179016, 43.92857640981674, 41.301613971590996, 45.81998571753502, 47.40347094833851, 47.22035117447376, 46.41473740339279, 45.93790479004383, 47.840356305241585, 45.30513234436512, 25.27395810931921, 5.930441999807954, 1.920326587278396, 1.9676018692553043, 2.8491255920380354, 2.299285833723843, 2.041086838580668, 4.640148086473346, 4.305842975154519, 3.72696066275239, 2.811961923725903, 1.077131882775575, 0.5735807062592357, 0.313305122544989, 1.950866379775107, 11.307050418108702, 24.80212412774563, 29.485749006271362, 27.305674888193607, 26.25777091830969, 26.848390325903893, 18.905402943491936, 2.9608329478651285, 0.025280629779445007, 0.03977029504312668, 0.017132957800640725, 0.01981467317818897, 0.02290976481162943, 0.03597757160605397, 0.06827423174399883, 0.037359439447754994, 0.09582777784089558, 0.045479900581995025, 0.04782232274010312, 0.08357328697456978, 0.055738893643138, 0.018523362195992377, 0.03215724398614839, 0.06831733568105847, 0.009217792339768494, 0.016314085041813087, 0.04553674909402616, 0.029681454179808497, 0.016676086124789435, 0.028396820671332534, 0.03543146594893187, 0.057727637904463336, 0.02553218073444441, 0.013682591725228122, 0.03798040183028206, 0.07067674931022339, 0.04323809509514831, 0.027291812875773758, 0.009889232824207284, 0.07860649333451875, 0.057447870494797826, 0.040476712019881234, 0.02201233757659793, 0.07685615288210101, 0.006159340537124081, 0.038601460692007095, 0.03505072934785858, 0.06584339382243343, 0.057036635334952734, 0.03437620245676953, 0.038770878163632005, 0.004417244881551596, 0.02540862242312869, 0.04491974978009239, 0.012223014527990017, 0.0416183948982507, 0.048480270052095875, 0.05329769534000661, 0.028078693503630348, 0.0474944418965606, 0.027027292890124954, 0.05817599900183268, 0.04943193343933672, 0.020731489021272864, 0.049715278000803664, 0.04169794570771046, 0.023052698743413202, 0.04108898756385315, 0.04324605091824196, 0.20792640134459361, 8.280502371490002, 26.800661087036133, 34.03607703745365, 31.96057140827179, 47.32198432087898, 36.92760027945042, 16.13617043942213, 10.078844223171473, 6.072694966569543, 0.45649723266251385, 0.2219821885228157, 0.41644839104264975, 1.0989057831466198, 4.05114121735096, 6.282526357099414, 11.213177405297756, 6.909808572381735, 8.61561018973589, 7.644949899986386, 3.2213282072916627, 2.603433388285339, 2.3937727510929108, 2.077779332175851, 7.691964302212, 17.556311935186386, 31.59593727439642, 46.406241059303284, 56.422754377126694, 58.24577875435352, 55.16764372587204, 55.5664399266243, 54.67802479863167, 52.72441282868385, 52.063096314668655, 47.33018048107624, 48.735717460513115, 55.937132835388184, 54.581620171666145, 55.45798994600773, 49.98182259500027, 51.442673206329346, 54.204706996679306, 53.120484575629234, 55.04577286541462, 53.71890306472778, 46.10427886247635, 41.83728642761707, 41.32557928562164, 41.094916462898254, 39.51288275420666, 42.60797247290611, 45.1432154327631, 53.100231662392616, 50.287801176309586, 55.389848202466965, 49.65803436934948, 43.2917457818985, 56.989300176501274, 50.342544838786125, 51.61830358207226, 43.02312299609184, 40.41506454348564, 40.83651892840862, 43.01029868423939, 47.10875876247883, 49.85784284770489, 52.74303562939167, 51.17365904152393, 49.849635288119316, 49.64445009827614, 43.83103184401989, 39.786540269851685, 36.72594889998436, 39.69792142510414, 46.52868568897247, 48.97457264363766, 49.39090110361576, 51.663372963666916, 50.249966606497765, 49.733578115701675, 49.33413214981556, 48.78881201148033, 44.459176138043404, 42.95064188539982, 47.00670003890991, 49.6016263961792, 48.50891903042793, 49.17059652507305, 46.58901125192642, 49.49886091053486, 45.583744794130325, 28.183923661708832, 8.037952836602926, 2.9071919387206435, 3.0797841399908066, 3.826687973923981, 4.911343809217215, 3.391983937472105, 7.569492598995566, 7.200933275744319, 3.608821677044034, 2.8119386499747634, 1.382436950225383, 0.28591764683369547, 0.2059534314321354, 1.9240958662703633, 12.355607002973557, 26.867402605712414, 32.594198808074, 31.316380575299263, 31.058923490345478, 32.21338324248791, 21.3628488779068, 4.562444156035781, 0.14609540667152032, 0.08290038167615421, 0.053798429798916914, 0.008792203116172459, 0.09303949933382683, 0.06203461773111485, 0.08523593525751494, 0.02755692843493307, 0.08028193624340929, 0.05419911532953847, 0.04275153194612358, 0.08352961158379912, 0.044185138613102026, 0.024403910319961142, 0.0627804093528539, 0.055807330791139975, 0.02869703239412047, 0.04467261831450742, 0.0467545948777115, 0.04749127292598132, 0.06002291142067406, 0.051899032696383074, 0.044222973301657476, 0.029818677285220474, 0.030441387425526045, 0.03229358022508677, 0.02268288841150934, 0.04676852870034054, 0.09636871443944983, 0.09451033212826587, 0.0879682632512413, 0.17759918962838128, 0.164110729820095, 0.1674312469549477, 0.11348587562679313, 0.24168877716874704, 0.15004336513811722, 0.11855553835630417, 0.13488495431374758, 0.19764569675317034, 0.16435222467407584, 0.26893730799201876, 0.07911808541393839, 0.07128534751245752, 0.1992050529224798, 0.14195172901963815, 0.07580743142170832, 0.08222785487305373, 0.24572899943450466, 0.1584675576305017, 0.10352644676459022, 0.16426656598923728, 0.19224388583097607, 0.16053161874879152, 0.28243014647159725, 0.0915528810583055, 0.15978215349605307, 0.15749803074868396, 0.1296022135647945, 0.25146554864477366, 0.10490185421076603, 0.339312826981768, 9.510443173348904, 30.692811235785484, 40.247645527124405, 37.725287675857544, 56.41340307891369, 50.58445505797863, 27.798778228461742, 12.436454314738512, 6.054024193435907, 1.0825994331389666, 0.5690419091843069, 2.856448511593044, 8.685005865991116, 15.893675051629543, 14.861754924058914, 18.386808671057224, 16.18369448930025, 16.919194422662258, 11.559075694531202, 8.660887610167265, 3.110844623297453, 1.7702434281818569, 2.756420779041946, 8.142377883195877, 17.915090583264828, 32.32498325407505, 46.72108456492424, 56.47325746715069, 60.68364053964615, 55.756661519408226, 58.470570892095566, 55.439104959368706, 53.932083025574684, 55.67963965237141, 48.57891507446766, 51.84756428003311, 58.66299256682396, 57.53584384918213, 57.11292274296284, 50.87971441447735, 52.34554275870323, 54.096093624830246, 55.26837632060051, 57.98423118889332, 55.9010461717844, 48.66414450109005, 44.05149981379509, 44.30874980986118, 44.65260475873947, 40.885004326701164, 44.44684199988842, 48.65396484732628, 56.500137224793434, 52.574374079704285, 55.86360678076744, 53.6961916834116, 47.70172454416752, 57.84036710858345, 53.97233426570892, 53.0368472635746, 46.318921744823456, 41.804410591721535, 44.08830463886261, 45.67851170897484, 50.18783614039421, 52.172823026776314, 55.06740130484104, 52.69695170223713, 52.426976189017296, 52.40023322403431, 48.364591374993324, 43.744822070002556, 39.50869157910347, 40.523818507790565, 48.22432950139046, 49.64308977127075, 50.38769781589508, 53.76895397901535, 51.49606414139271, 50.396790727972984, 51.422804072499275, 51.693094968795776, 47.59495407342911, 43.760215044021606, 49.27824854850769, 51.9563714414835, 50.85937790572643, 51.99327886104584, 47.66827493906021, 50.89147098362446, 46.30460411310196, 26.912156604230404, 6.621315702795982, 3.1416600197553635, 4.906855300068855, 7.738543152809143, 7.66328439116478, 7.214920800179243, 10.379778575152159, 12.401171308010817, 11.055969391018152, 7.18710201792419, 3.1844279123470187, 1.5659538027830422, 0.5832972598727793, 2.9927521850913763, 14.691977184265852, 30.36718960851431, 37.58674331009388, 38.75870302319527, 37.50797353684902, 37.57751740515232, 24.49317790567875, 4.205334093421698, 0.25405392225366086, 0.25308147130999714, 0.1845193753251806, 0.1492447845521383, 0.16288813058054075, 0.16413450823165476, 0.17937409516889602, 0.13687199534615502, 0.1798733082250692, 0.11445437834481709, 0.18340417969739065, 0.29529711697250605, 0.22494533186545596, 0.12681939726462588, 0.1711713001714088, 0.1967141084605828, 0.10115724420757033, 0.09358462906675413, 0.09279062753194012, 0.21312155382474884, 0.18993104196852073, 0.11154076593811624, 0.18774761381791905, 0.0876235579198692, 0.14789273991482332, 0.1661843349575065, 0.16343616211088374, 0.09215341211529449], [0.020421154404175468, 0.03182650587405078, 0.04132804817345459, 0.028170677142043132, 0.014227998835849576, 0.045281138591235504, 0.0630629004444927, 0.05860076722456142, 0.08445308820228092, 0.038638850091956556, 0.013512865334632806, 0.04736324131954461, 0.07098728616256267, 0.03979844841524027, 0.022271332272794098, 0.02117284238920547, 0.02730082440393744, 0.01826710045861546, 0.06755799986422062, 0.0068741901668545324, 0.08626206574263051, 0.05251629547274206, 0.052068888035137206, 0.04358666330517735, 0.09619167511118576, 0.03662474293378182, 0.05099898196931463, 0.026334822723583784, 0.02348357484152075, 0.03995302293333225, 0.12314804465859197, 0.05297300944221206, 0.029570076367235743, 0.07174525642767549, 0.7485373306553811, 8.35031222552061, 24.444259330630302, 21.50647547096014, 24.125849716365337, 37.15069770812988, 36.80778130888939, 18.595204688608646, 8.888189513236284, 3.313545221462846, 0.749531511683017, 0.3008714772295207, 0.33067758253309876, 3.3486543875187635, 3.552972748875618, 9.252170082181692, 5.388063378632069, 5.560638243332505, 8.873004578053951, 1.073852777481079, 2.7823809860274196, 1.037808742839843, 0.6427767151035368, 4.0944812167435884, 11.252546142786741, 23.28567110002041, 35.14642305672169, 47.82118633389473, 55.42135991156101, 52.335659489035606, 52.55522310733795, 51.593065336346626, 51.48214928805828, 50.16969211399555, 48.08090999722481, 47.737549021840096, 53.20514403283596, 54.26123656332493, 54.96889539062977, 50.259089916944504, 52.029335126280785, 51.9375092536211, 53.35105620324612, 52.10150085389614, 52.03606076538563, 46.19448222219944, 40.87825208902359, 39.1283243894577, 41.17057040333748, 38.26920948922634, 42.16078966856003, 45.41450947523117, 50.19721403717995, 50.06245046854019, 50.50660103559494, 47.45715446770191, 38.12654234468937, 55.84094859659672, 51.11063562333584, 50.03423698246479, 43.82395662367344, 41.32083334028721, 37.640787810087204, 42.652034908533096, 44.889119267463684, 47.908159866929054, 50.138738974928856, 51.61513455212116, 51.277796253561974, 51.5899533033371, 48.6597291380167, 47.719488590955734, 42.38047868013382, 36.52142867445946, 39.603416696190834, 44.26797419786453, 47.68469765782356, 47.6070374250412, 49.81727622449398, 49.85543757677078, 49.89110246300697, 48.26330780982971, 44.873308315873146, 43.7235964089632, 45.62101699411869, 47.642972096800804, 47.78546065092087, 46.95962056517601, 50.14376990497112, 44.8848444968462, 26.275375373661518, 10.32908359542489, 0.5372944939881563, 0.7147806545253843, 2.2292940644547343, 1.96216732962057, 2.321176459081471, 2.247843244113028, 5.453483518213034, 4.960365453734994, 2.8674562834203243, 2.618767465464771, 0.787778478115797, 0.05314464222465176, 1.6728605912066996, 6.696901246905327, 20.59376634657383, 28.445013351738453, 23.192602694034576, 18.125504292547703, 22.899072244763374, 19.21261265873909, 7.128481613472104, 0.050496663025114685, 0.06072339121601544, 0.03151359785988461, 0.014909407291270327, 0.050408610914018936, 0.06086362373025622, 0.04980283287295606, 0.05200053252337966, 0.033286076577496715, 0.0532776684849523, 0.04351763243903406, 0.04228437224810477, 0.024064496501523536, 0.03943823590816464, 0.02517160086426884, 0.016603982767264824, 0.024547731118218508, 0.031006890967546497, 0.07078355178236961, 0.06454492482589558, 0.03721871711604763, 0.03698239132063463, 0.06309778880677186, 0.04955090342264157, 0.018755878918454982, 0.09838884041528217, 0.025170513617922552, 0.00851986274938099, 0.01768224912666483, 0.030942478115321137, 0.028893230264657177, 0.03357700588821899, 0.04656313933082856, 0.08414011710556224, 0.07282426493475214, 0.07230115472339094, 0.013466572017932776, 0.04333728313213214, 0.02520108453609282, 0.030775201739743352, 0.02129936186975101, 0.03345652934513055, 0.025496394373476505, 0.038603479333687574, 0.08643612905871123, 0.05983045026368927, 0.02604285069537582, 0.010679434562916867, 0.01451042127882829, 0.10518894661800005, 0.027267208824923728, 0.035175651355530135, 0.03662744064058643, 0.04634933029592503, 0.03986919364251662, 0.030243304499890655, 0.09018241631565616, 0.026533248892519623, 0.13189898250857368, 0.015860963067098055, 0.11948264407692477, 0.0725952084758319, 0.07320158765651286, 1.515979003161192, 13.295600563287735, 31.503262147307396, 27.740204371511936, 31.822051741182804, 44.37059909105301, 33.16648229956627, 17.264345102012157, 11.688463501632214, 4.432093575596809, 0.54058707668446, 0.15392522793263197, 0.6313947821035981, 2.4355555465444922, 6.161400731652975, 7.673737155273557, 5.795681281015277, 9.41350657492876, 7.6892018504440784, 6.269084578379989, 5.074616298079491, 4.438313841819763, 2.186488648876548, 5.2743996027857065, 11.043698899447918, 25.26910576969385, 37.8824358433485, 50.157285779714584, 56.3562997430563, 54.827197194099426, 53.972353264689445, 54.00282762944698, 54.46466624736786, 50.622757002711296, 50.139449536800385, 49.50093559920788, 54.449201077222824, 56.16089902818203, 56.12891994416714, 51.25451870262623, 51.414391323924065, 50.94646543264389, 54.42566514015198, 54.053516909480095, 53.68330657482147, 48.48070174455643, 42.6649884134531, 41.807807609438896, 42.72042363882065, 40.76748423278332, 44.18123625218868, 46.48108184337616, 53.4368783980608, 52.0725654065609, 51.73469513654709, 50.41398100554943, 41.17315046489239, 56.62508212029934, 51.97439007461071, 50.80621115863323, 44.8989949375391, 42.404725179076195, 40.10679088532925, 43.68792772293091, 47.181281670928, 50.40972903370857, 52.52925530076027, 54.013402462005615, 51.56099125742912, 51.44496448338032, 49.391771256923676, 47.93448865413666, 42.8715605288744, 38.37764047086239, 42.029388919472694, 46.19105860590935, 49.829663559794426, 50.18138788640499, 49.9885406345129, 49.89886924624443, 51.445922031998634, 49.507604241371155, 46.76009327173233, 44.88137528300285, 47.28239044547081, 48.013953790068626, 49.70426268875599, 49.22773405909538, 50.51135838031769, 45.69712311029434, 30.688217282295227, 13.667205423116684, 1.5369509090669453, 2.107388055883348, 4.133873227983713, 2.122323866933584, 4.24191378057003, 3.899273816496134, 4.916296843439341, 7.655413588508964, 3.3472541626542807, 0.3122273460030556, 0.5734267551451921, 0.09920537355355918, 1.7189633985981345, 7.160870600491762, 20.45215554535389, 31.58368293195963, 25.216862373054028, 23.35964933037758, 27.11893390864134, 27.67703466117382, 10.569771230220795, 0.6041363510303199, 0.015345520168921212, 0.03774990560486913, 0.025414563315280247, 0.03277224692283198, 0.06338906692690216, 0.028474490136431996, 0.062027956955716945, 0.08064170717261732, 0.01976513296540361, 0.07503746805014089, 0.025518000147712883, 0.036261235291021876, 0.026725736024673097, 0.04522883944446221, 0.0664913332730066, 0.06450356493587606, 0.04337766338721849, 0.03708196527441032, 0.08980356476968154, 0.002711068245844217, 0.03776566140004434, 0.14227808103896677, 0.010058390544145368, 0.025182208009937312, 0.05024507125199307, 0.07673637024709024, 0.025780128562473692, 0.039565733168274164, 0.10130620066775009, 0.13085319253150374, 0.1320667820982635, 0.09506252710707486, 0.13516441744286567, 0.1476367434952408, 0.17383997415890917, 0.204062394623179, 0.21004941867431626, 0.11311870548524894, 0.16210976609727368, 0.08368124719709158, 0.18063360883388668, 0.15612722461810336, 0.09909583255648613, 0.13511726137949154, 0.09884578816127032, 0.12783596146618947, 0.12489009532146156, 0.08949588518589735, 0.20315531204687431, 0.12430567629053257, 0.17343872459605336, 0.09917408460751176, 0.15964525693561882, 0.11953544788411818, 0.11787006849772297, 0.2022273454349488, 0.12307762968703173, 0.2963890536921099, 0.3009028552332893, 0.2497869887156412, 0.1171215606154874, 0.2531824033940211, 1.8088044715113938, 15.160818826407194, 38.62754546105862, 34.25694018602371, 38.744089007377625, 49.50564734637737, 45.124140456318855, 26.822205930948257, 13.71826708316803, 5.140269650146365, 1.079544397071004, 0.9864772378932685, 2.5467546796426177, 11.031445506960154, 9.283049125224352, 17.829994149506092, 13.559779487550259, 14.988443925976753, 19.820013865828514, 6.493984060361981, 7.047485634684563, 4.003110844641924, 1.8064962141215801, 5.705485045909882, 13.766666036099195, 26.6812239959836, 37.0146232098341, 50.64381547272205, 59.31600272655487, 55.93300625681877, 56.89822666347027, 55.310561656951904, 56.619640812277794, 53.85053180158138, 51.846401542425156, 52.89642579853535, 57.34737776219845, 58.8473054766655, 57.35669106245041, 50.79619109630585, 52.27050818502903, 51.24788045883179, 55.24688467383385, 56.22216694056988, 56.31553553044796, 49.763273522257805, 45.23791775107384, 44.27962817251682, 45.87523475289345, 42.61320099234581, 47.95346863567829, 50.71315415203571, 56.35876581072807, 55.4558240622282, 53.863644897937775, 52.51199282705784, 44.250681325793266, 57.4998027831316, 55.38004852831364, 54.08389247953892, 48.28257277607918, 44.875690788030624, 41.74097299575806, 47.33806125819683, 49.6699733287096, 52.560945600271225, 54.56087328493595, 55.53478382527828, 53.57849299907684, 54.17253792285919, 52.266423404216766, 51.48245707154274, 45.839611664414406, 40.37404954433441, 44.79119852185249, 47.780973091721535, 51.89950369298458, 51.78185820579529, 51.25158526003361, 50.385790318250656, 52.8416745364666, 52.68287345767021, 48.34993556141853, 46.56424418091774, 48.64138752222061, 51.45770139992237, 50.49772851169109, 50.83936057984829, 53.030395209789276, 47.103997617959976, 28.476766347885132, 12.72573659196496, 1.1958352569490671, 2.9467810643836856, 6.021687928587198, 4.8003332410007715, 6.82154405862093, 6.815429711714387, 11.333640441298485, 12.391360234469175, 7.776817549020052, 6.115678260102868, 1.7637730878777802, 0.22865051898406819, 2.1392507711425424, 8.629591539502144, 24.816624149680138, 37.826742231845856, 30.412084199488163, 27.69521478563547, 33.94356720149517, 30.801620297133923, 10.030086189508438, 0.5764405278023332, 0.06694694515317678, 0.2236028015613556, 0.13735360465943813, 0.20740728388773277, 0.09249932714737952, 0.09459514476475306, 0.1423225802136585, 0.2884284808533266, 0.10927829905995168, 0.20260373305063695, 0.12642135377973318, 0.12009930942440405, 0.0828700649435632, 0.09628235813579522, 0.10623314839904197, 0.21778182563139126, 0.13431400526314974, 0.11258674887358211, 0.1905027628527023, 0.08409696121816523, 0.19471274397801608, 0.2087273122742772, 0.12324323251959868, 0.09302611841121688, 0.20426701958058402, 0.1465338675188832, 0.0807326499489136, 0.12591773236636072], [0.014245262118492974, 0.03818583943939302, 0.05126843723701313, 0.045159073852119036, 0.06985095416894183, 0.02096863117913017, 0.0326012078585336, 0.037167097034398466, 0.02201147668529302, 0.026538987549429294, 0.03189692084561102, 0.007930253323138459, 0.04532444661890622, 0.01205130567541346, 0.04107090142497327, 0.011725551084964536, 0.020665686497522984, 0.03624624390795361, 0.015869924500293564, 0.11382950484403409, 0.018259235548612196, 0.01965056020708289, 0.046994022850412875, 0.09107161313295364, 0.04051269876072183, 0.021959259174764156, 0.07150107499910519, 0.03364060423336923, 0.04650732240406796, 0.044282645685598254, 0.03630276216426864, 0.05280939185468014, 0.029884505784139037, 0.04224218486342579, 0.2008086262503639, 2.2430486138910055, 16.486228555440903, 34.73326362669468, 21.66282568126917, 27.370469011366367, 56.139224991202354, 38.637850508093834, 27.27613527327776, 12.87972617894411, 3.3465820737183094, 0.5908368271775544, 0.22815886099124327, 1.0936520900577307, 5.236745523288846, 6.886413227766752, 2.782610636204481, 6.561417616903782, 4.874930363148451, 5.24346973747015, 5.279733091592789, 5.442574778571725, 0.839228251716122, 0.9666980523616076, 3.8314039958640933, 12.594580929726362, 27.55030006170273, 39.46887731552124, 49.53650929033756, 53.085541650652885, 52.345656752586365, 52.19446286559105, 51.54757037758827, 50.467991307377815, 48.069666400551796, 49.51032109558582, 51.89527451992035, 54.0558347851038, 55.08426479995251, 52.96872831881046, 53.97233426570892, 55.589272901415825, 50.62291279435158, 52.59632170200348, 52.38880343735218, 47.3697629570961, 39.89605039358139, 39.341652542352676, 43.06607969105244, 42.18153275549412, 42.84608669579029, 48.56113202869892, 50.189443454146385, 50.777743086218834, 52.19906061887741, 49.50331427156925, 38.82559463381767, 52.06765986979008, 49.50774863362312, 51.11765004694462, 46.192806512117386, 43.09860974550247, 44.37131345272064, 44.45387162268162, 42.85224236547947, 43.920380249619484, 47.20910757780075, 50.59856370091438, 50.5395832657814, 51.623661294579506, 48.97981636226177, 49.519729390740395, 49.05656464397907, 44.83243390917778, 40.54754823446274, 43.183755576610565, 46.301419883966446, 47.41944149136543, 49.18001241981983, 49.87870752811432, 49.43494834005833, 49.249533489346504, 47.07302168011665, 47.74310812354088, 46.797878444194794, 50.11295735836029, 49.914676398038864, 52.40128576755524, 41.53899863362312, 28.644130267202854, 11.023530531674623, 1.5085204783827066, 0.29018944886047393, 2.0387331023812294, 2.98456481192261, 2.1326189395040274, 3.3557134587317705, 1.080804979428649, 6.646086098626256, 6.779447067528963, 1.562183692585677, 0.06583644732018001, 0.5408972944132984, 0.8966684038750827, 6.2684129644185305, 15.156773943454027, 25.444059781730175, 37.95404300093651, 27.065474577248096, 17.242631167173386, 26.578057631850243, 7.509195059537888, 1.9098048331215978, 0.03188525799487252, 0.1366229899576865, 0.06981361671932973, 0.09447434538742527, 0.03480745333945379, 0.0212042408020352, 0.05029953746998217, 0.03825062893156428, 0.045657774826395325, 0.033492033689981326, 0.04238567911670543, 0.03681276233692188, 0.05655440632835962, 0.09115811786614358, 0.05190772324567661, 0.07279360681422986, 0.02597740625787992, 0.06083385247620754, 0.08859635025146417, 0.014707995833305176, 0.006285690251388587, 0.016019680624594912, 0.10620246801408939, 0.03741253640328068, 0.03693136866786517, 0.05097513676446397, 0.09585120744304731, 0.05068767328339163, 0.059549343277467415, 0.05983306633424945, 0.061301657842705026, 0.04005052258435171, 0.022411160316551104, 0.03783813583140727, 0.02891024028940592, 0.029846357538190205, 0.05594137008301914, 0.06642014646786265, 0.02042991360212909, 0.022843739643576555, 0.028729020814353134, 0.041569995737518184, 0.029437072371365502, 0.04119010147405788, 0.00400973344767408, 0.03127937605313491, 0.0336300991330063, 0.05232706265815068, 0.03142812471196521, 0.026692790233937558, 0.05448161013191566, 0.058576944284141064, 0.023318630665016826, 0.04382342696771957, 0.03866014601953793, 0.03357902452989947, 0.01750482573697809, 0.04729631444206461, 0.04804156058526132, 0.08171667839633301, 0.028634400696319062, 0.030046978608879726, 0.0367331261804793, 0.1865814029588364, 3.899815999902785, 21.37951098382473, 39.55186106264591, 27.224775329232216, 33.21746416389942, 58.457689583301544, 34.25803452730179, 19.52461961656809, 12.085435800254345, 3.6206599418073893, 0.5012933257967234, 0.2235660355654545, 0.4535279591800645, 4.208275135606527, 6.748131047934294, 4.222863502800465, 6.995077896863222, 10.10998260229826, 11.81192647665739, 9.25808446481824, 7.877171589061618, 3.536264095455408, 1.7987504485063255, 5.1241266913712025, 15.1315176486969, 28.985524848103523, 41.91818408668041, 51.990413814783096, 55.98406791687012, 52.98366151750088, 53.59299682080746, 52.70465008914471, 51.71634592115879, 51.196598410606384, 50.2612330019474, 55.425623282790184, 55.85872784256935, 56.21020898222923, 51.12576261162758, 53.592050671577454, 54.44388896226883, 51.81686572730541, 54.15841028094292, 55.22205300629139, 49.06952574849129, 41.97478584945202, 40.809441581368446, 43.998219072818756, 44.43997576832771, 45.41644737124443, 49.31277349591255, 52.06163339316845, 53.54804143309593, 54.133780002593994, 49.715620279312134, 41.39015682041645, 52.658547163009644, 50.83318591117859, 52.681315541267395, 48.53649415075779, 44.95333582162857, 44.522693529725075, 46.51727870106697, 46.2431538105011, 46.43362998962402, 49.92026969790459, 51.48710422217846, 51.689861342310905, 53.18519130349159, 51.24041385948658, 49.88021984696388, 51.41249902546406, 46.05070173740387, 42.799759581685066, 44.91036772727966, 49.76537860929966, 49.9027868360281, 51.66890546679497, 51.87638193368912, 49.933869168162346, 49.4643397629261, 47.17120461165905, 47.91572526097298, 49.39859949052334, 49.997557550668716, 51.827406361699104, 52.799679189920425, 45.984205305576324, 30.95620170235634, 14.651784840971231, 2.8531177528202534, 1.0521239996887743, 3.0719805462285876, 6.02229637093842, 3.8072467921301723, 5.783946085721254, 5.39608902297914, 5.874700890854001, 5.612048534676433, 1.3791245967149734, 0.5277649022173136, 0.05274040551739745, 1.0222609271295369, 5.609530694782734, 16.173759922385216, 30.802290961146355, 39.0595518797636, 24.93100941181183, 20.70340946316719, 29.58884507417679, 11.055940892547369, 3.232157863676548, 0.06299889762885869, 0.04646782159397844, 0.011919372227566782, 0.09930062820785679, 0.10111825919011608, 0.0467514296178706, 0.03523321975080762, 0.028003367369819898, 0.12472171685658395, 0.05275574199913535, 0.023853815619077068, 0.09358400566270575, 0.022463661698566284, 0.07772592027322389, 0.012565847791847773, 0.07216192039777525, 0.009198793359246338, 0.05854932896909304, 0.04562360263662413, 0.048426779758301564, 0.01582612851052545, 0.026005355539382435, 0.03968051001720596, 0.02971009922475787, 0.05911142419790849, 0.013593031198979588, 0.016683934336469974, 0.11815783625934273, 0.013037266489845933, 0.10772342546260916, 0.19168714148690924, 0.15149706916417927, 0.10492415574844927, 0.16024856362491846, 0.1612338240374811, 0.11375680405762978, 0.15679310919949785, 0.15431451407494023, 0.2044433687115088, 0.08081254956778139, 0.0887863029493019, 0.19825399067485705, 0.11442228787927888, 0.17580089159309864, 0.0859599448449444, 0.21374852018197998, 0.08605231996625662, 0.11794652455137111, 0.31630613026209176, 0.07393289997708052, 0.11287197849014774, 0.1541435974650085, 0.18107466719811782, 0.1385785490856506, 0.15488121804082766, 0.17936987977009267, 0.1300637997337617, 0.13029849651502445, 0.23928270471515134, 0.13263905217172578, 0.1488763082306832, 0.10030997131252661, 0.1684682647464797, 0.2949916786747053, 4.4464601296931505, 25.493677519261837, 48.11517655849457, 33.379821851849556, 39.3432142585516, 63.9691798388958, 47.02835127711296, 33.304574489593506, 18.040575049817562, 5.329010747373104, 1.0276033217087388, 0.809839500579983, 2.481177323497832, 11.700286567211151, 14.711470138281584, 10.458223465830088, 16.19048662483692, 15.309258811175823, 12.53622556105256, 14.022439811378717, 12.83507477492094, 3.600950399413705, 1.8528458895161748, 5.42198795825243, 15.117296911776066, 30.015108101069927, 42.53773704171181, 53.06760661303997, 56.185704097151756, 55.259154215455055, 59.67776611447334, 56.3039081543684, 53.20682354271412, 52.65477016568184, 54.0733328461647, 56.15109175443649, 57.627088353037834, 57.64357566833496, 52.44631715118885, 53.78612905740738, 55.41621118783951, 50.63961669802666, 56.111167296767235, 57.827003225684166, 51.69084548950195, 44.22964945435524, 44.217486307024956, 46.58059850335121, 45.578873455524445, 47.43205301463604, 52.89253480732441, 54.84311453998089, 56.24351039528847, 54.38801296055317, 50.33474385738373, 44.08291272819042, 54.15997959673405, 52.446681931614876, 55.43100379407406, 51.2806499004364, 47.52104803919792, 47.73083858191967, 49.08562548458576, 47.06874690949917, 47.81753093004227, 49.53858397901058, 54.273616299033165, 52.18942813575268, 54.251999258995056, 53.24129909276962, 53.48696731030941, 54.29435558617115, 49.19479362666607, 45.76160565018654, 47.66170509159565, 49.805892035365105, 51.98044314980507, 51.480959951877594, 52.99104072153568, 49.46533150970936, 51.648717150092125, 48.79861928522587, 49.949911907315254, 50.70607893168926, 54.112626537680626, 53.75178650021553, 57.07000784575939, 43.50575789809227, 30.341360494494438, 12.521968726068735, 2.853180686943233, 1.3138987217098475, 4.937899634242058, 9.634350724518299, 7.3395949602127075, 8.09675658121705, 7.577559566125274, 14.821095205843449, 13.565554227679968, 5.030714878812432, 1.3484121509827673, 0.7027616025879979, 1.2463252851739526, 7.912105489522219, 20.047824941575527, 33.745852410793304, 45.23446373641491, 33.66327904164791, 29.796046055853367, 36.73777386546135, 12.828963752835989, 2.9553994769230485, 0.12805522157577798, 0.2026205204310827, 0.10693070784327574, 0.2968362421961501, 0.1849716846481897, 0.18624862394062802, 0.11052884758100845, 0.12305410360568203, 0.18699660489801317, 0.1474034716375172, 0.13893712515709922, 0.1092751300893724, 0.09949680752470158, 0.17034521559253335, 0.1448694826103747, 0.26362908189184964, 0.16802356985863298, 0.13545293477363884, 0.18832648900570348, 0.12371604738291353, 0.1475191576173529, 0.12928631098475307, 0.18710794189246371, 0.12364121663267724, 0.26224070170428604, 0.10635500904754736, 0.25544788339175284, 0.27216015849262476, 0.22259215969825163], [0.02617247049784055, 0.03237216624256689, 0.05076208100945223, 0.024457532344968058, 0.02357906698307488, 0.015524747905146796, 0.03406485295272432, 0.04831117912544869, 0.019218409470340703, 0.021366867622418795, 0.01976446874323301, 0.02711955483391648, 0.017891909556055907, 0.055293182012974285, 0.03655355983937625, 0.025535499989928212, 0.049380829150322825, 0.043578963523032144, 0.004364700362202711, 0.0677359446126502, 0.0166563524180674, 0.011177401738677872, 0.052848195045953616, 0.0771021303080488, 0.041832274437183514, 0.03242953425797168, 0.05593432710156776, 0.03618742499384098, 0.09134188105235808, 0.07378707538009621, 0.02876742324588122, 0.03962840011809021, 0.08883814938599244, 0.0866196547576692, 0.05763811263022944, 0.08747088329982944, 4.925780184566975, 22.91182816028595, 31.77510716021061, 24.964793398976326, 25.894316621124744, 42.09042504429817, 50.02633720636368, 30.959389731287956, 15.928265545517206, 3.2160749891772866, 0.18511729402234778, 0.32368349377065897, 3.3450493309646845, 4.090542728081346, 3.033197452314198, 6.022127754986286, 5.621112948283553, 12.061950210481882, 8.636145237833261, 6.873351903632283, 4.5740653574466705, 1.3366619939915836, 1.215859588701278, 8.45450358465314, 15.941691175103188, 25.50748597830534, 36.38960234820843, 49.82829563319683, 53.081570863723755, 53.394316881895065, 51.48412138223648, 52.24053159356117, 52.56537616252899, 51.54139190912247, 52.09567956626415, 58.00980381667614, 53.99382971227169, 55.80298863351345, 49.32566240429878, 50.284472554922104, 53.49912665784359, 51.622707545757294, 51.0558919608593, 46.11647620797157, 39.41080503165722, 38.33393521606922, 42.022769674658775, 42.369147688150406, 46.997090354561806, 50.816417410969734, 51.599179208278656, 51.9361375272274, 54.364537820219994, 50.59586964547634, 37.991938367486, 52.17463552951813, 50.50718240439892, 52.44700871407986, 49.75507356226444, 46.6367556899786, 44.77397784590721, 44.847469702363014, 41.046313270926476, 40.055459439754486, 43.17114405333996, 49.33206506073475, 49.781580939888954, 49.51757110655308, 50.62415152788162, 50.0465939193964, 50.33235378563404, 48.69044668972492, 46.02955587208271, 43.83982077240944, 44.64946232736111, 48.1922972202301, 51.200329810380936, 50.771082043647766, 50.26427663862705, 49.39063511788845, 49.43435937166214, 47.382682263851166, 50.52434988319874, 47.821912094950676, 49.51275676488876, 38.61120253801346, 29.92728341370821, 10.949088726192713, 2.0915828039869666, 0.36340543418191373, 0.5973819165956229, 2.684744275175035, 4.0543643943965435, 1.76300588529557, 4.625402027741075, 4.61815819144249, 1.320239631459117, 4.749153312295675, 1.0383628006093204, 0.1912089015240781, 0.4816956102149561, 5.291245523840189, 18.031271249055862, 23.467709831893444, 17.432229593396187, 35.08456237614155, 47.17123121023178, 25.053203254938126, 19.58095159381628, 5.865839766338468, 0.35452878393698484, 0.021841478483111132, 0.023238343273987994, 0.09155785344773903, 0.049738447851268575, 0.057260070025222376, 0.018894543645728845, 0.0775087827059906, 0.01835717492213007, 0.08878657012246549, 0.02221683822426712, 0.042723768201540224, 0.07379621121799573, 0.01466537985834293, 0.07280240126419812, 0.022612970678892452, 0.01603334541869117, 0.109381761867553, 0.0750383734703064, 0.1045843782776501, 0.011497685773065314, 0.04876159226114396, 0.017980900483962614, 0.03268062508141156, 0.06729832239216194, 0.026233816424792167, 0.05922180753259454, 0.05278405864373781, 0.0823367279372178, 0.08403030151384883, 0.0424222707079025, 0.06648567068623379, 0.03346709010656923, 0.031078025822353084, 0.0188748563232366, 0.056542765742051415, 0.04222592440783046, 0.03787575529713649, 0.01892289368697675, 0.010608787670207676, 0.018777915138343815, 0.01414076030414435, 0.027457128126116004, 0.02030414925684454, 0.09392450301675126, 0.05506417750439141, 0.05157371226232499, 0.0725875049829483, 0.03425806367886253, 0.016035657208703924, 0.05890042790269945, 0.040471836109645665, 0.024301824196300004, 0.07682238516281359, 0.055630903734709136, 0.025932311509677675, 0.058520611564745195, 0.05328915693098679, 0.05320946511346847, 0.02893069202400511, 0.021646338173013646, 0.04823016999580432, 0.08337754552485421, 0.047307539425673895, 0.08549841062631458, 0.16978213330730796, 8.885692097246647, 30.17992615699768, 36.20679795742035, 30.039964467287064, 37.35573470592499, 47.985174134373665, 46.75639986991882, 28.511156402528286, 13.585718795657158, 2.9451611638069153, 0.2646133181406185, 0.15857724705711007, 0.45697654131799936, 2.1767775574699044, 5.05447025410831, 6.448264438658953, 11.1473354883492, 16.4285571500659, 11.018059775233269, 8.150649089366198, 6.36335039511323, 2.1900576073676348, 1.4476891863159835, 8.663072492927313, 18.096479550004005, 29.493109211325645, 39.97671626508236, 51.54289282858372, 54.933675080537796, 54.91643160581589, 55.33809877932072, 55.01290462911129, 54.60096873342991, 53.26907180249691, 54.97943602502346, 58.940643668174744, 56.560379192233086, 55.04016436636448, 50.03580629825592, 50.99251516163349, 56.0704904794693, 52.89716295897961, 53.57654370367527, 47.68501304090023, 41.728665456175804, 40.24168744683266, 43.88270907104015, 44.81361731886864, 49.13478724658489, 53.46973143517971, 54.570832550525665, 53.916408866643906, 54.177823439240456, 50.35207852721214, 39.694399014115334, 52.912544533610344, 51.80835798382759, 52.52435356378555, 50.689770206809044, 47.68120564520359, 47.383719608187675, 47.25555248558521, 43.22822459042072, 42.771230712533, 47.51233130693436, 50.86809463799, 52.14484512805939, 51.53186962008476, 52.0727401971817, 51.887648329138756, 51.77678547799587, 50.65735414624214, 46.81204788386822, 44.0116361528635, 47.38019339740276, 49.759595319628716, 53.29690530896187, 51.38494290411472, 51.45579010248184, 50.182763412594795, 49.925388023257256, 48.80532592535019, 50.86542338132858, 49.53593172132969, 51.79701939225197, 41.663939729332924, 32.118342742323875, 13.698409348726273, 3.3799761068075895, 1.4691659901291132, 1.7821322777308524, 3.7455219542607665, 4.97455864213407, 4.709797874093056, 5.534697035327554, 5.8272989094257355, 3.544997926801443, 2.66165885142982, 0.683967157965526, 0.027016463100153487, 0.5946367420256138, 4.6648135129362345, 19.031193293631077, 31.10105372965336, 22.93363519012928, 40.84686577320099, 46.311588138341904, 28.17267056554556, 24.564133398234844, 6.677696127444506, 0.5379869474563748, 0.039720689892419614, 0.021965673186059576, 0.06119536003097892, 0.023944012536958326, 0.037955306106596254, 0.025003680675581563, 0.06210762650880497, 0.017947494561667554, 0.03698466971400194, 0.05058881550212391, 0.021049302631581668, 0.01570698783325497, 0.024907886108849198, 0.047869486224954017, 0.05893675974220969, 0.016994534271361772, 0.16337996668880805, 0.07953008127515204, 0.013883976280339994, 0.04934564021823462, 0.010008193530666176, 0.03770244155020919, 0.043708917291951366, 0.05661163704644423, 0.02870396405342035, 0.04700269113527611, 0.06308529103989713, 0.021552578946284484, 0.025483223107585218, 0.18816287512890995, 0.18211769638583064, 0.10265233780955896, 0.0790780910756439, 0.10813484244863503, 0.1627513676066883, 0.1287675794446841, 0.17505997588159516, 0.08910610180464573, 0.16615502012427896, 0.060983584480709396, 0.1906339151901193, 0.18320857925573364, 0.11869276146171615, 0.18636235065059736, 0.1645450940122828, 0.12511367473052815, 0.16681444802088663, 0.15127596852835268, 0.10572276602033526, 0.13925096456659958, 0.1236516512290109, 0.10581608366919681, 0.20377260079840198, 0.16431517666205764, 0.0881427941203583, 0.15377727337181568, 0.19802738330326974, 0.1716243219561875, 0.2203701250255108, 0.12004273550701328, 0.13482328184181824, 0.1741301835863851, 0.12491776258684695, 0.16147392365382984, 0.22464508860139176, 9.749629888683558, 33.76493878662586, 46.2645048648119, 35.728753209114075, 38.17983068525791, 51.28374673426151, 57.2779630869627, 38.0278692394495, 20.321172773838043, 5.020773187279701, 0.4824737075250596, 1.383318502921611, 6.268615303561091, 12.542518973350525, 11.323440838605165, 13.257700446993113, 11.393252592533827, 20.842330008745193, 17.85101842135191, 14.34130160138011, 10.848494824022055, 3.6187315452843904, 2.2063717944547534, 10.749446488916874, 18.068856932222843, 27.908373847603798, 39.741014912724495, 53.20876143872738, 56.62712261080742, 58.00449550151825, 56.287645027041435, 57.656304985284805, 57.4293127655983, 55.96641406416893, 56.93313159048557, 63.07810865342617, 56.7710816860199, 55.69209538400173, 48.975583389401436, 50.07046043872833, 55.673803165555, 54.493654891848564, 56.15044578909874, 50.4997044056654, 44.22965705394745, 42.93770357966423, 46.321304216980934, 46.65537089109421, 51.3178651034832, 55.830913335084915, 56.55788652598858, 57.373710349202156, 54.670303612947464, 50.537364184856415, 44.89715963602066, 54.401908814907074, 53.7735403329134, 57.04347386956215, 53.23934219777584, 50.57591691613197, 49.8018604516983, 49.29195821285248, 44.51330803334713, 44.59814988076687, 47.74917259812355, 53.436593413352966, 54.49691891670227, 53.94783318042755, 54.39008764922619, 52.92641378939152, 53.59099052846432, 51.8394935131073, 49.08785976469517, 47.6828433573246, 49.9052757024765, 51.34949080646038, 54.502831399440765, 52.587255388498306, 51.33465640246868, 51.08311749994755, 52.98671655356884, 51.76192447543144, 53.34955148398876, 49.67254959046841, 52.51630179584026, 40.54526835680008, 33.66079397499561, 13.095916528254747, 3.353634257800877, 1.6685547097586095, 2.1145326225087047, 6.23032190836966, 8.482877612113953, 4.842555625364184, 11.812130715698004, 9.505170956254005, 6.8699354119598866, 10.106085911393166, 3.2586828153580427, 0.6356548878829926, 0.9779818437527865, 6.719529507681727, 22.29367733001709, 31.26524291932583, 23.8071646168828, 44.32437837123871, 50.43932184576988, 36.242459043860435, 27.598293386399746, 7.577292630448937, 0.5906926130410284, 0.1731794627266936, 0.15762104914756492, 0.1780965324724093, 0.1375664526131004, 0.17346999869914725, 0.11784490969148465, 0.15701248805271462, 0.13100061274599284, 0.2137061138637364, 0.17584050743607804, 0.19035513483686373, 0.17451902444008738, 0.11805280009866692, 0.14248742605559528, 0.11176335086929612, 0.12228784355102107, 0.25570036203134805, 0.1294220646377653, 0.1777638276689686, 0.12452783819753677, 0.16712851007468998, 0.12588537472765893, 0.12665406160522252, 0.20466426154598594, 0.15107928455108777, 0.10311963109415956, 0.18316774629056454, 0.16919632646022364, 0.2459172229282558], [0.010829371585714398, 0.04353493932285346, 0.023598715342814103, 0.06334087927825749, 0.024084462129394524, 0.10059369436930865, 0.030802802211837843, 0.05786071240436286, 0.005860533328814199, 0.039510766000603326, 0.050592084662639536, 0.012169825731689343, 0.06295255792792886, 0.025827720637607854, 0.034645724517758936, 0.0609672275459161, 0.08550556492991745, 0.045775895050610416, 0.039556333867949434, 0.013522797125915531, 0.0032582701942374115, 0.02296925722475862, 0.0344957438937854, 0.040646303896210156, 0.04583735229971353, 0.026491263743082527, 0.014647880943812197, 0.015612503157171886, 0.0641117332270369, 0.016811017849249765, 0.09055213944520801, 0.011699214119289536, 0.032120507676154375, 0.08645117239211686, 0.07242921230499633, 0.04845312600082252, 0.2147048368351534, 9.358932003378868, 28.762742802500725, 32.93798916041851, 25.261682868003845, 29.561429545283318, 35.627222657203674, 33.4054134786129, 32.91803643107414, 19.21338591724634, 4.384978478774428, 0.43775521335192025, 0.786656232085079, 1.5207106992602348, 3.2063463237136602, 3.689977484755218, 11.857404336333275, 18.755157105624676, 7.603298909962177, 5.492446152493358, 4.539143806323409, 2.087952336296439, 0.06320456901448779, 1.7912217462435365, 8.257803339511156, 16.19420662522316, 24.837306439876556, 35.704176127910614, 43.26149560511112, 50.441115349531174, 53.09051938354969, 53.57049062848091, 53.290050476789474, 54.75373953580856, 54.0524909645319, 54.347852915525436, 54.8947461694479, 53.67286093533039, 51.520158648490906, 54.66728277504444, 54.6304627507925, 51.37827046215534, 49.824499636888504, 42.50095881521702, 39.261970818042755, 41.43595576286316, 42.53947354853153, 46.14516846835613, 51.13726459443569, 52.10021652281284, 54.159516021609306, 53.705440387129784, 49.846093878149986, 50.874352902173996, 38.15974496304989, 51.81308872997761, 49.78036880493164, 51.33047662675381, 51.55913695693016, 48.4430343657732, 51.01254388689995, 49.42419491708279, 48.20892132818699, 40.56685119867325, 38.05819161236286, 44.46208298206329, 48.14422219991684, 48.83716821670532, 50.85725761950016, 49.92495484650135, 52.626381888985634, 51.99066840112209, 47.80357047915459, 46.90890088677406, 46.41432702541351, 48.17826837301254, 49.82656292617321, 50.78914627432823, 50.273513942956924, 52.6393011957407, 51.42586670815945, 48.81301671266556, 49.80607442557812, 41.84997394680977, 36.1124300211668, 23.185945451259613, 11.075363550335169, 2.4935610964894295, 0.9855533530935645, 1.3212494272738695, 1.9393348298035562, 2.6518309162929654, 4.109134180471301, 6.3587744906544685, 4.018164211884141, 4.408890595659614, 3.2960419356822968, 2.5042508728802204, 0.47831931326072663, 0.8065312437247485, 3.2517890352755785, 13.770064003765583, 16.48963887244463, 20.20876530557871, 17.0055827870965, 22.97091118991375, 45.00123605132103, 22.8572915866971, 9.769854303449392, 1.3174049835652113, 0.0841363841027487, 0.009934738536685472, 0.03882095457811374, 0.010712777402659412, 0.09755102248163894, 0.08698242396349087, 0.05141772024217062, 0.03610335821576882, 0.09462673799134791, 0.012405632951413281, 0.04386727305245586, 0.04212799060042016, 0.0775362050626427, 0.03890827196300961, 0.05108701923745684, 0.02860607477487065, 0.048692928758100607, 0.0540833365812432, 0.013006917288294062, 0.02567804986028932, 0.019927843277400825, 0.05589155342022423, 0.07963741067214869, 0.027385336470615584, 0.050662625799304806, 0.03754728073545266, 0.02578504900156986, 0.030455996602540836, 0.060434306142269634, 0.02179430943215266, 0.05976278494927101, 0.06088306428864598, 0.034954662041855045, 0.06304770126007497, 0.027378369559301063, 0.020942333176208194, 0.06454074653447606, 0.021373624877014663, 0.052223121165297925, 0.041504872278892435, 0.06099030462792143, 0.03262888996687252, 0.03717112689628266, 0.061413647927111015, 0.0187524001012207, 0.11085230522439815, 0.05531227376195602, 0.01995717109821271, 0.04257811429852154, 0.03479254730336834, 0.039644115095143206, 0.0232874085122603, 0.04489565224503167, 0.033944740061997436, 0.04221783499815501, 0.05872250912943855, 0.02568904477811884, 0.04187725229712669, 0.031596492044627666, 0.04680223333707545, 0.040444339538225904, 0.04320732565247454, 0.0301982338714879, 0.06718916731188074, 0.0675921980291605, 0.0948735095153097, 0.4445573827251792, 13.44455162063241, 35.69653853774071, 37.12172046303749, 25.923599749803543, 38.09723071753979, 42.15605892241001, 41.78159661591053, 34.66601863503456, 16.692190803587437, 3.439812446013093, 0.2956700313370675, 0.17240593704627827, 0.444351778132841, 3.537414721213281, 3.468902735039592, 9.529230315238237, 15.906702652573586, 9.024086371064186, 8.111609034240246, 5.505880806595087, 2.9840311780571938, 1.3614903367124498, 2.6463817711919546, 8.693258073180914, 17.81845796853304, 27.687588594853878, 40.16204372048378, 48.47065128386021, 55.53177818655968, 55.766958966851234, 54.83574293553829, 54.83280569314957, 56.26636616885662, 56.07376970350742, 56.47390343248844, 55.572781786322594, 54.24075946211815, 51.261160746216774, 54.11842122673988, 57.473842576146126, 54.14159618318081, 51.56074047088623, 46.08532927930355, 41.35516069829464, 41.91210441291332, 43.79556454718113, 48.50574620068073, 52.626932859420776, 53.29411245882511, 55.34393526613712, 55.6454186886549, 51.62307612597942, 52.35175922513008, 40.77102944254875, 53.37302662432194, 52.02323645353317, 52.34416343271732, 54.95149992406368, 49.70591180026531, 53.110487312078476, 50.59015475213528, 47.761267349123955, 41.988575309515, 40.996053367853165, 46.142307221889496, 50.384202003479004, 50.91395437717438, 51.34032189846039, 50.60384161770344, 54.65458765625954, 52.135239243507385, 50.76942153275013, 48.687121868133545, 48.45335081219673, 49.76844124495983, 52.47010387480259, 50.76818659901619, 50.510583221912384, 51.19209565222263, 52.78095759451389, 50.079560950398445, 51.86415039002895, 43.25945891439915, 39.419643357396126, 25.325530841946602, 13.86810539290309, 3.51563167758286, 2.4138420866802335, 2.7522070426493883, 3.807673081755638, 3.0503606563434005, 3.844477431848645, 8.276047110557556, 4.21233806759119, 5.0579233188182116, 1.862009335309267, 1.2384458142332733, 0.34409953106660396, 0.5392912868410349, 3.208309393376112, 16.555219553411007, 23.503830693662167, 27.145984657108784, 19.30807303637266, 24.96934175491333, 49.89547982811928, 29.175220169126987, 12.740665040910244, 2.0369935082271695, 0.018514742150728125, 0.046739970857743174, 0.05447342053230386, 0.04693266950198449, 0.11407356752897613, 0.018689139433263335, 0.054485001746797934, 0.018529937624407467, 0.08379155260627158, 0.08992531409603544, 0.024869841763575096, 0.05462137138238177, 0.020017867645947263, 0.04027106289868243, 0.03335208319185767, 0.028529874762170948, 0.07422169932397082, 0.12260530464118347, 0.015847431859583594, 0.060154768798383884, 0.058737719446071424, 0.0362107692490099, 0.05676347303960938, 0.005424413029686548, 0.05251441783912014, 0.06626068861805834, 0.03067589866986964, 0.020484357555687893, 0.039285587263293564, 0.01700824544968782, 0.2717141277389601, 0.19361181242857128, 0.23620722990017384, 0.22278100659605116, 0.14498978474875912, 0.13315328629687428, 0.16775976604549214, 0.12964668305357918, 0.11840357619803399, 0.11650468746665865, 0.2313076303107664, 0.11581074970308691, 0.18576269532786682, 0.2017245106981136, 0.09168925069388933, 0.21377473283791915, 0.24609327520010993, 0.159871582291089, 0.13334628922166303, 0.1441279731807299, 0.1625928151770495, 0.08328646174049936, 0.09709452744573355, 0.147909942897968, 0.2385267976205796, 0.09068373707123101, 0.1234157670114655, 0.10980068196658976, 0.16838919633300975, 0.14770313602639362, 0.14122923341346905, 0.11932164255995303, 0.11359521624399349, 0.21615434030536562, 0.2118595762294717, 0.33818960131611675, 0.796787675935775, 14.524854552000761, 41.45922191441059, 44.18020270764828, 35.26405714452267, 40.34050494432449, 42.55026116967201, 42.26165145635605, 38.410668298602104, 22.94553805142641, 5.529788648709655, 0.6565499072894454, 1.9668016559444368, 4.920397298410535, 7.394467340782285, 11.371013335883617, 22.332518845796585, 29.090632908046246, 19.228746592998505, 16.58696684986353, 9.913787730038166, 4.684576252475381, 1.291643197182566, 2.6634252816438675, 9.606170486658812, 19.676328375935555, 27.183196060359478, 38.83855573832989, 48.191115483641624, 57.762748673558235, 59.5804837346077, 59.86587882041931, 58.051810562610626, 60.40564365684986, 58.55117216706276, 58.54009196162224, 56.112702414393425, 54.255255684256554, 51.616046503186226, 56.73082284629345, 59.02525752782822, 58.34771208465099, 54.75598521530628, 47.63268984854221, 42.93457254767418, 45.63299015164375, 46.59805856645107, 51.70156091451645, 57.11929500102997, 55.500768050551414, 58.66236560046673, 57.47833013534546, 50.222148299217224, 51.76683001220226, 44.40953180193901, 53.370435163378716, 52.3146466165781, 55.10373875498772, 56.31344184279442, 52.14035376906395, 56.465958058834076, 53.740607500076294, 51.368463188409805, 43.67313131690025, 41.289367228746414, 48.53617496788502, 50.95509856939316, 52.31561556458473, 55.33141113817692, 52.76907943189144, 55.66259376704693, 55.62512777745724, 52.21134155988693, 50.62716856598854, 49.92577940225601, 51.813111528754234, 54.134414568543434, 51.56807407736778, 50.56354098021984, 52.63657674193382, 54.0122739225626, 51.46929457783699, 53.1664203107357, 44.2502785474062, 38.58843795955181, 25.552716851234436, 12.550006471574306, 3.064940948970616, 1.7725012195296586, 3.771406877785921, 4.895339068025351, 9.417263623327017, 11.661587543785572, 12.363537177443504, 9.059713259339333, 12.62451097369194, 8.761249724775553, 5.12609688565135, 1.5103230066597462, 1.0461380146443844, 4.295560726895928, 18.360791467130184, 23.541971147060394, 30.685306638479233, 24.75018471479416, 31.66675217449665, 53.28757680952549, 33.2183913141489, 15.53063778206706, 1.881455504335463, 0.16559888434130698, 0.09411618491867557, 0.12220168762723915, 0.14803250116528943, 0.1659269878291525, 0.1483508083038032, 0.180012030468788, 0.1462539887870662, 0.2517255675047636, 0.1505974229075946, 0.09038116346346214, 0.16078537388239056, 0.1856617335579358, 0.11362758872564882, 0.11953489869483747, 0.09693842410342768, 0.13811338576488197, 0.18295589281478897, 0.1427345909178257, 0.09668406783021055, 0.13641483237734064, 0.1514882524497807, 0.28030742600094527, 0.11000006736139767, 0.0852498653694056, 0.11397342212148942, 0.14324213087093085, 0.11988215701421723, 0.1309528629644774, 0.08051633616560139], [0.056402956251986325, 0.015740672060928773, 0.04628090056939982, 0.03641635528765619, 0.03318026487249881, 0.08449402506812476, 0.02895959682064131, 0.014825804355496075, 0.022518690093420446, 0.06016286934027448, 0.06550819540279917, 0.06761772048776038, 0.05653350002830848, 0.014836226891929982, 0.041537177967256866, 0.06902344466652721, 0.10265176635584794, 0.02377965094638057, 0.006628274431932368, 0.030316368938656524, 0.04772986598254647, 0.04890688622253947, 0.06254169013118371, 0.024076038753264584, 0.03689574557938613, 0.020103774950257502, 0.0116170685760153, 0.06405987936886959, 0.12339526147115976, 0.0444868253543973, 0.01604984707228141, 0.05881977500393987, 0.0065895565876417095, 0.06374670047080144, 0.08327055009431206, 0.03842409852950368, 0.057141927536576986, 0.6415718828793615, 10.105576738715172, 34.97030630707741, 33.78779835999012, 31.08234543353319, 31.56362760812044, 19.34864155948162, 25.635413713753223, 27.404520884156227, 18.57797261327505, 3.896029028110206, 0.24914244830142707, 0.16940801666351035, 3.1657514395192266, 1.62612286163494, 9.709232356399298, 16.149475425481796, 7.558241877704859, 5.802003191784024, 3.339058239944279, 1.8542017042636871, 1.4488290064036846, 0.7314652623608708, 1.0035806545056403, 4.977184301242232, 13.193891420960426, 21.384591311216354, 28.420447669923306, 36.68861210346222, 46.431821286678314, 53.67007568478584, 54.76990766823292, 55.628057420253754, 55.02056121826172, 56.54365248978138, 54.575050324201584, 52.765017449855804, 52.06241995096207, 55.060630068182945, 55.15316270291805, 52.50514559447765, 48.95576745271683, 41.38002656400204, 39.7900664806366, 42.03014887869358, 47.820684760808945, 51.21160000562668, 52.798983827233315, 53.34147311747074, 55.11682525277138, 52.92568422853947, 52.08165071904659, 49.58698958158493, 35.85009589791298, 52.24240869283676, 50.9896045178175, 47.83512398600578, 54.390615820884705, 53.823435455560684, 52.00375109910965, 50.75306721031666, 50.661043748259544, 46.61357693374157, 39.43688303232193, 40.25430276989937, 44.25342857837677, 46.58108487725258, 47.425635159015656, 47.96481482684612, 48.693767711520195, 50.01669332385063, 50.53236365318298, 47.18262679874897, 47.82076835632324, 47.708925157785416, 49.79511961340904, 51.62603236734867, 50.42669512331486, 49.41430404782295, 49.27469193935394, 43.793752044439316, 43.76216433942318, 29.215665198862553, 18.647280894219875, 7.556209461763501, 3.045750791206956, 0.34534666570834816, 2.0514978049322963, 1.9623703812249005, 2.9687369987368584, 1.9154845783486962, 2.506458079442382, 7.388144480064511, 2.8117317985743284, 4.5094645489007235, 1.6368004074320197, 0.7211963727604598, 0.1898221392184496, 2.362342500127852, 12.912947796285152, 19.56791829317808, 22.399663142859936, 21.809765696525574, 20.755586363375187, 24.58127047866583, 33.5530811548233, 15.555047672241926, 2.6793813379481435, 0.12583372124936432, 0.05766226582636591, 0.034019504018942825, 0.034439711744198576, 0.0413542942260392, 0.11050033426727168, 0.06649295857641846, 0.036114653703407384, 0.025598795909900218, 0.011623745122051332, 0.0422865801374428, 0.034210402955068275, 0.07371309809968807, 0.003822987755484064, 0.0879554908897262, 0.06465828788350336, 0.0432737738447031, 0.040163815137930214, 0.07806833978975192, 0.053303573149605654, 0.07040398777462542, 0.023065576860972214, 0.05728340314817615, 0.03222010018362198, 0.028533759905258194, 0.08239886796218343, 0.05453017627587542, 0.030285272951005027, 0.017424417746951804, 0.05793528340291232, 0.047937318522599526, 0.034673106056288816, 0.02284038328070892, 0.0535169146314729, 0.042509298655204475, 0.05493515884154476, 0.08179900483810343, 0.028140603462816216, 0.05370173166738823, 0.03951207589125261, 0.04145769766182639, 0.02661135065864073, 0.09824716442381032, 0.048759829660411924, 0.009235048200935125, 0.041843362123472616, 0.01903808613860747, 0.013540061336243525, 0.07260417361976579, 0.07832638453692198, 0.018537429605203215, 0.03902976153767668, 0.0434398293873528, 0.06344748879200779, 0.012938510753883747, 0.051022252009715885, 0.031671267133788206, 0.04951700953824911, 0.08389168317080475, 0.07646637692232616, 0.048812299501150846, 0.03900537827576045, 0.059120448713656515, 0.020187502195767593, 0.056072455627145246, 0.09444019175134599, 0.04549926692561712, 0.0686457657138817, 1.9420305476523936, 16.026037149131298, 41.42989508807659, 36.80965840816498, 33.12317982316017, 37.10164234042168, 25.95849897712469, 38.03483046591282, 37.28179447352886, 17.820184975862503, 2.717772340402007, 0.25024738744832575, 0.09797118938877247, 0.38917962927371264, 1.952988209668547, 4.570794207975268, 11.624986957758665, 8.025660496205091, 4.824774954468012, 5.082094296813011, 4.071018900722265, 3.055256218649447, 1.1552246985957026, 1.688642450608313, 6.73129890114069, 14.843437056988478, 23.466615490615368, 32.91644811630249, 40.13962872326374, 50.84187604486942, 55.96481055021286, 55.69350890815258, 56.731746196746826, 56.293356120586395, 58.17616268992424, 55.11782459914684, 54.059828370809555, 53.70024226605892, 54.9117236584425, 57.23376385867596, 54.07561272382736, 49.91289049386978, 43.85231830179691, 41.243507489562035, 43.58790948987007, 47.24039129912853, 54.02384430170059, 54.51038159430027, 57.06334300339222, 56.485363617539406, 53.49680118262768, 52.65625588595867, 50.00141054391861, 38.66278097033501, 52.55288623273373, 52.20037914812565, 49.73980978131294, 55.77852174639702, 55.25686293840408, 53.22255089879036, 53.06359402835369, 52.74539530277252, 46.69745743274689, 40.241607651114464, 42.253208309412, 47.146821320056915, 48.97303372621536, 49.48354013264179, 50.58165080845356, 51.008117124438286, 51.623866483569145, 51.3119488209486, 49.38067205250263, 48.88689614832401, 48.66214960813522, 51.0784437507391, 53.85261029005051, 49.99502308666706, 50.48111580312252, 49.85169477760792, 45.748834535479546, 45.012361854314804, 32.48142845928669, 21.898072957992554, 11.060022823512554, 4.256479823961854, 0.8872581494506449, 3.4365876065567136, 3.0314485961571336, 4.735606089234352, 5.3868987411260605, 2.8064885549247265, 10.04852944985032, 5.55614260956645, 2.4486342072486877, 1.5950222429819405, 0.4029677831567824, 0.18551456567365676, 1.8735807831399143, 12.890331409871578, 23.14588040113449, 25.34315049648285, 23.464958779513836, 22.68126603215933, 26.014865152537823, 38.2398484647274, 19.9753400310874, 3.6304273176938295, 0.190317849337589, 0.06504511751700193, 0.016301366486004554, 0.021516887209145352, 0.04617451369995251, 0.02389341105299536, 0.05051842279499397, 0.014801280085521284, 0.049462869865237735, 0.03033833094377769, 0.10138719866517931, 0.021068186579213943, 0.03016177401150344, 0.028367717350192834, 0.02803542258334346, 0.019335082506586332, 0.02830941608408466, 0.03170945434249006, 0.08635680089355446, 0.02704364240344148, 0.007164976150306757, 0.03988204392953776, 0.020519097488431726, 0.03285574966866989, 0.046856736662448384, 0.10547091078478843, 0.05710496858227998, 0.05672471808793489, 0.05730960467190016, 0.0762257058522664, 0.022069542319513857, 0.12910448480397463, 0.1351455520489253, 0.10498072224436328, 0.13176137348636985, 0.2125546123716049, 0.19963751721661538, 0.13521446788217872, 0.15242258668877184, 0.11932256282307208, 0.15901106206001714, 0.1413079901249148, 0.2400160356773995, 0.19717481889529154, 0.0782187063305173, 0.15042735234601423, 0.13713373598875478, 0.17570674273883924, 0.0977471646910999, 0.10727968794526532, 0.19931030430598184, 0.1749860282870941, 0.17067116685211658, 0.17401564051397145, 0.1608964882325381, 0.15868571936152875, 0.11135240143630654, 0.09582077196682803, 0.16580572089878842, 0.3235277021303773, 0.15658613905543461, 0.10694900920498185, 0.20948957215296105, 0.0979319223552011, 0.13093291403492913, 0.3009271383052692, 0.12644477596040815, 0.12622836569789797, 2.2751901391893625, 18.263833969831467, 49.56640228629112, 41.51011638343334, 43.23095664381981, 42.42277801036835, 28.575171567499638, 38.21309030056, 34.412085860967636, 22.314384318888187, 4.64669038541615, 0.46420746424701065, 0.7315942773129791, 7.139911875128746, 7.171623073518276, 21.06836088001728, 25.924004428088665, 14.518926870077848, 11.887961346656084, 8.506022170186043, 6.899484526365995, 4.394523566588759, 2.5000594602897763, 1.5865764836780727, 5.968203898519278, 15.468824598938227, 24.054297655820847, 31.645000241696835, 38.93496036529541, 51.49876959621906, 58.25263738632202, 59.64056611061096, 59.960174560546875, 60.886929631233215, 58.909979313611984, 55.63651956617832, 51.79592125117779, 53.430091962218285, 56.7183443158865, 59.96537648141384, 57.08763130009174, 52.81282648444176, 45.53012207150459, 42.89147526025772, 45.007680505514145, 50.71052849292755, 56.417807042598724, 58.11339385807514, 58.15118283033371, 58.12017269432545, 54.779619947075844, 52.58624464273453, 49.607231095433235, 41.466004550457, 53.45388628542423, 51.072044894099236, 50.81275440752506, 58.01967188715935, 56.926196962594986, 55.196563974022865, 55.539981946349144, 55.30295826494694, 50.53802914917469, 42.527230605483055, 43.973573595285416, 48.61235707998276, 49.82693150639534, 51.71529337763786, 51.76255144178867, 54.28323358297348, 53.45871202647686, 53.68781313300133, 51.677341014146805, 52.53000766038895, 50.697738379240036, 52.87073917686939, 53.816618621349335, 49.726339504122734, 49.70012851059437, 51.19911387562752, 45.40035143494606, 46.764033660292625, 31.730391159653664, 20.382298193871975, 10.256132259964943, 4.635017411783338, 0.9573043033014983, 5.087888985872269, 4.648244027048349, 6.213959511369467, 7.317873425781727, 9.182221535593271, 15.193532221019268, 9.21943673864007, 9.844990521669388, 4.7842406295239925, 2.3056911025196314, 0.6604638160206378, 3.263958594761789, 15.977283865213394, 24.544957727193832, 30.633215233683586, 30.242109820246696, 30.282473154366016, 34.57401417195797, 41.42577610909939, 23.250507786870003, 4.264867398887873, 0.2696713217301294, 0.07013700014795177, 0.18535167910158634, 0.11777526655350812, 0.12839136994443834, 0.12359029045910574, 0.17191730701597407, 0.10047172239865176, 0.19229078956414014, 0.1630961397313513, 0.17868216120405123, 0.11002405357430689, 0.08105651577352546, 0.14730406837770715, 0.21687446103896946, 0.11214848840609193, 0.27172781294211745, 0.1653019807417877, 0.2656679099891335, 0.10855922475457191, 0.1658700205734931, 0.10419664322398603, 0.14946585550205782, 0.14091719000134617, 0.2271781425224617, 0.17906030028825626, 0.2309762465301901, 0.119383485725848, 0.17366657877573743, 0.2775375230703503, 0.1359933815547265], [0.0689767487347126, 0.058316940267104656, 0.027624217109405436, 0.01194470729387831, 0.04239184265315998, 0.03614211316744331, 0.05203131309826858, 0.030172141814546194, 0.016736526631575543, 0.04167454950220417, 0.12627503194380552, 0.028686709119938314, 0.03465096036961768, 0.024417996282863896, 0.007397658000627416, 0.030613291091867723, 0.0090959326189477, 0.004031034013678436, 0.006751593400622369, 0.03602912860515062, 0.03179208877554629, 0.02019817242398858, 0.03204734675819054, 0.03417718442506157, 0.08647859474876896, 0.0274129313766025, 0.048120113206095994, 0.007437111498802551, 0.07446368399541825, 0.07258921192260459, 0.029643578673130833, 0.06598863954422995, 0.048205148486886173, 0.03751450378331356, 0.060935374567634426, 0.02884762900066562, 0.056836726726032794, 0.061319695741985925, 1.5680457092821598, 17.856731414794922, 31.269270703196526, 32.98139043152332, 29.591523930430412, 31.535480618476868, 8.540873900055885, 18.223185651004314, 27.602657452225685, 14.1703687235713, 4.647356774657965, 0.28344774967990816, 0.7815005024895072, 0.9006400813814253, 2.804006338119507, 9.35438459739089, 6.763654639944434, 3.8884752709418535, 3.2719165552407503, 2.148680677637458, 2.6526412228122354, 0.6762950727716088, 0.25205810903571546, 0.906314542517066, 3.6965212086215615, 8.25218154117465, 15.229200907051563, 21.714806891977787, 27.915177382528782, 40.59662640094757, 49.56233270466328, 55.67409195005894, 57.277324721217155, 55.37587255239487, 51.9640888273716, 52.60927140712738, 53.86262655258179, 56.74266301095486, 54.55873019993305, 51.25616401433945, 45.78099600970745, 41.29249066114426, 43.59022356569767, 46.88515216112137, 51.50498986244202, 53.90109568834305, 53.64349231123924, 55.69371409714222, 53.12588028609753, 51.62211857736111, 50.234934613108635, 52.72367566823959, 38.8339351862669, 50.45713149011135, 51.92949928343296, 44.621017053723335, 54.12766233086586, 53.074514642357826, 53.466657400131226, 51.309072375297546, 53.37249845266342, 47.93813265860081, 40.47704681754112, 42.24988728761673, 43.657259568572044, 43.778093084692955, 46.35422185063362, 47.69552707672119, 48.53871323168278, 47.196891233325005, 48.79249021410942, 49.61635820567608, 48.46254251897335, 49.541494622826576, 52.910367250442505, 49.16623815894127, 50.75703799724579, 49.451086074113846, 41.8635506182909, 36.613463535904884, 26.43515110015869, 15.10366229340434, 8.157995995134115, 2.589585743844509, 0.9511216194368899, 0.812009124783799, 3.6742130806669593, 3.037993269972503, 4.163840319961309, 2.09579202812165, 0.7195369305554777, 8.191028572618961, 3.8404313614591956, 1.4742262498475611, 1.1277585849165916, 0.2959848800674081, 1.4599392539821565, 7.364485999569297, 15.222546514123678, 24.61764022707939, 14.681147765368223, 19.11322709172964, 21.68172776699066, 22.77028765529394, 15.615288689732552, 4.953095018863678, 0.7826845545787364, 0.08837268178467639, 0.05142587273439858, 0.08122336541418917, 0.000827972822889933, 0.011527929218573263, 0.04487471996981185, 0.05789280286990106, 0.043296453877701424, 0.022767021982872393, 0.039438811072614044, 0.03169449635606725, 0.04918552927847486, 0.024113558029057458, 0.04823591421882156, 0.024140121349773835, 0.09577774224453606, 0.03955189953558147, 0.033277515904046595, 0.08789213374257088, 0.04037571314256638, 0.053982352546881884, 0.07345199570409022, 0.011086842096119653, 0.025046200171345845, 0.038457417249446735, 0.0750234785664361, 0.05418893306341488, 0.02346441258850973, 0.06158341791888233, 0.03960115587688051, 0.04672889430366922, 0.03390006648260169, 0.01126771832787199, 0.05365812678064685, 0.004366225939520518, 0.01715281767246779, 0.0422239020554116, 0.033897101602633484, 0.01463966722440091, 0.058605669109965675, 0.03096743097557919, 0.04061043218825944, 0.021577552215603646, 0.06253429834032431, 0.03803418527240865, 0.07157790212659165, 0.06785692952689715, 0.019923930303775705, 0.005307546107360395, 0.016217056654568296, 0.007872263759054476, 0.03487925241643097, 0.06184575970110018, 0.03579351898224559, 0.03895651527273003, 0.04813261839444749, 0.047141394825302996, 0.0909381007659249, 0.02955992935312679, 0.04727715961053036, 0.06772135398932733, 0.04725699545815587, 0.06595931728952564, 0.05146974108356517, 0.0468138627911685, 0.01342428815405583, 0.08933633085689507, 0.016109467505884822, 0.07601839432027191, 3.355055619031191, 23.243592157959938, 37.36311390995979, 37.33126021921635, 33.668788745999336, 28.268681913614273, 14.507850464433432, 29.775840640068054, 30.458650700747967, 14.904468432068825, 4.309100825339556, 0.4026716959197074, 0.2945475181331858, 0.8103391737677157, 4.407742107287049, 9.857877530157566, 7.2225298918783665, 5.782284624874592, 6.043514907360077, 3.7247073836624622, 5.15178588218987, 1.366796395741403, 1.0220416076481342, 2.4009876139461994, 5.356706036254764, 10.958079993724823, 16.100072376430035, 24.24824684858322, 31.05919897556305, 45.54004333913326, 53.02155688405037, 57.00226508080959, 59.182979464530945, 54.81158763170242, 52.87131294608116, 53.115537241101265, 53.01313653588295, 57.98751801252365, 56.672131195664406, 54.316861778497696, 49.867950305342674, 45.476339757442474, 45.42468912899494, 47.99785025417805, 54.08977456390858, 55.47051027417183, 55.09494602680206, 56.81005239486694, 54.925931096076965, 52.47683711349964, 50.77631816267967, 52.961793690919876, 41.28185883164406, 49.980424270033836, 51.831582337617874, 46.03353425860405, 55.61467073857784, 53.79350446164608, 56.27543248236179, 54.56867426633835, 55.383897721767426, 49.12067860364914, 42.68666245043278, 43.85199151933193, 45.936270877718925, 45.750970020890236, 48.305295556783676, 49.85973134636879, 50.57315066456795, 48.94511282444, 51.52472220361233, 51.594942435622215, 49.57237556576729, 50.492883771657944, 54.00682881474495, 49.545814990997314, 51.434534043073654, 48.227259144186974, 44.85404334962368, 39.61049571633339, 30.557264909148216, 17.26027552038431, 11.550506204366684, 3.4487452916800976, 1.3477050326764584, 2.4888911470770836, 6.4849600195884705, 5.449423911049962, 3.551643770188093, 5.92765579931438, 4.5281315222382545, 9.883336164057255, 5.175293320789933, 1.5681117307394743, 0.9635363251436502, 0.19328066613525152, 1.8098012055270374, 8.474444914609194, 19.823515377938747, 27.631872184574604, 20.442547760903835, 19.640416502952576, 25.48766814172268, 28.19295197725296, 23.076066747307777, 8.049908895045519, 1.1591038154438138, 0.040142137004295364, 0.031244784549926408, 0.03058284448343329, 0.07195450496510603, 0.027292013255646452, 0.08478700270643458, 0.05232366733253002, 0.014320127193059307, 0.0327994874533033, 0.05583807796938345, 0.02694724298635265, 0.013503388108802028, 0.029740870522800833, 0.040978351898957044, 0.006941779874978238, 0.04778836948389653, 0.026444519571668934, 0.02456150352372788, 0.05506463392521255, 0.07831389419152401, 0.03754281671717763, 0.011907152766070794, 0.08402301362366416, 0.04753092216560617, 0.056796598801156506, 0.08983199644717388, 0.02771641968138283, 0.03341604518936947, 0.019460965595499147, 0.021282190427882597, 0.024451828940073028, 0.13345041254069656, 0.08407428118516691, 0.10141807200852782, 0.1394497265573591, 0.10420689970487729, 0.11732398139429279, 0.29090321680996567, 0.14012662461027503, 0.09310075620305724, 0.20369538775412366, 0.1271218224428594, 0.1012465987878386, 0.19609796261647716, 0.09693462430732325, 0.1655668532475829, 0.10637006722390652, 0.09557701356243342, 0.12633291946258396, 0.1755073425010778, 0.09556354358210228, 0.08994362287921831, 0.1773557800333947, 0.14049144956516102, 0.12290826416574419, 0.10862603288842365, 0.11040953249903396, 0.19825974974082783, 0.10084184628794901, 0.1757774842553772, 0.23144933598814532, 0.15548298106295988, 0.21597594284685329, 0.14240286574931815, 0.09815210272790864, 0.16018654976505786, 0.1918642030796036, 0.23071076546330005, 0.1883056346559897, 3.8238288648426533, 25.634266175329685, 43.956911489367485, 44.644632786512375, 42.03183978796005, 40.45694589614868, 16.55445959419012, 27.854794822633266, 35.0102611631155, 17.918850481510162, 6.274765748530626, 0.5663543846458197, 1.754669132642448, 3.3424312714487314, 8.86580016463995, 18.509545885026455, 16.900959201157093, 12.458571027964354, 11.024415884166956, 6.927950698882341, 6.189580969512463, 2.1658196579664946, 1.1157728405669332, 1.864778792951256, 4.23804416321218, 8.583975937217474, 15.89826425537467, 24.20645099133253, 31.55942313373089, 45.3237247467041, 54.18793089687824, 59.41021107137203, 61.08085222542286, 56.25855378806591, 51.855688244104385, 52.21739083528519, 53.20950239896774, 58.464867398142815, 59.69104640185833, 55.40435962378979, 49.40415099263191, 46.36450029909611, 47.36657112836838, 52.628217190504074, 58.565033823251724, 59.01657119393349, 58.644320368766785, 59.14274342358112, 55.61390317976475, 51.080499440431595, 50.72200007736683, 52.66334630548954, 44.89115595817566, 52.61779434978962, 51.10281944274902, 45.384928062558174, 55.741397738456726, 55.06004489958286, 58.34903061389923, 55.50241716206074, 58.0290611833334, 50.99894821643829, 44.741094410419464, 46.54123641550541, 47.416587844491005, 46.57334849238396, 49.71463993191719, 51.52949094772339, 52.86043792963028, 50.290681421756744, 52.9499801248312, 54.53268639743328, 50.85633046925068, 52.19076566398144, 54.02089186012745, 50.619283989071846, 50.69215647876263, 47.07994110882282, 43.66045519709587, 38.83190229535103, 29.438243955373764, 17.500116750597954, 10.443431809544563, 3.4418142260983586, 1.7392217740416527, 2.0687213307246566, 7.794793909415603, 7.240928029641509, 9.173801187425852, 7.206597346812487, 5.34859917126596, 16.3692594319582, 10.23417228832841, 5.559219494462013, 3.179234303534031, 0.7793690543621778, 2.169726323336363, 9.772239625453949, 20.58054495602846, 35.49971289932728, 22.349771820008755, 27.220462560653687, 33.12884911894798, 33.40681180357933, 25.309645794332027, 8.184630665928125, 1.065220709424466, 0.14631254423875362, 0.20438987470697612, 0.1539995169150643, 0.13584800966782495, 0.19317526632221416, 0.15067223139340058, 0.11433239153120667, 0.19008330098586157, 0.19414284877711907, 0.12721309176413342, 0.1697053061798215, 0.16876317939022556, 0.08604560352978297, 0.1592339141643606, 0.08412678813328966, 0.1539225858869031, 0.16441009734990075, 0.09655993620981462, 0.17105855309637263, 0.17946423642570153, 0.1593878652784042, 0.1417297378065996, 0.12383766312268563, 0.10961046951706521, 0.15043416526168585, 0.11244139182963409, 0.11764154638512991, 0.08194733047275804, 0.15418218914419413, 0.09777097278856672, 0.17470735183451325], [0.017279351995966863, 0.0155083696336078, 0.07149424724048004, 0.11851270159240812, 0.07226498986710794, 0.04387493201647885, 0.18117536179488525, 0.04637754303985275, 0.023807195757399313, 0.026223554377793334, 0.013397709062701324, 0.05149311131390277, 0.05890393826120999, 0.0672464314266108, 0.04663768435420934, 0.0550850058789365, 0.03125233961327467, 0.017548143041494768, 0.03696437197504565, 0.02732758624915732, 0.020351617022242863, 0.027883913135156035, 0.034793920276570134, 0.033887249592226, 0.021548404365603346, 0.014321681992441881, 0.020269748856662773, 0.021795277934870683, 0.037591056316159666, 0.05008068554161582, 0.050730035072774626, 0.03432149133004714, 0.0425103116867831, 0.04573953723593149, 0.05962271570751909, 0.047096546841203235, 0.011893889659404522, 0.12693863071035594, 0.17838979954831302, 3.6116715241223574, 18.198131695389748, 32.11494952440262, 28.41509945690632, 25.935802794992924, 17.168780229985714, 16.09436508268118, 24.519257806241512, 27.354523167014122, 14.217974469065666, 3.447480909526348, 0.23867289681220427, 0.5109267588704824, 2.17932912055403, 7.040920536965132, 5.2346518356353045, 4.074462940916419, 3.3038851898163557, 4.007350942119956, 4.0142295230180025, 1.5885611646808684, 1.3634431944228709, 1.3961728569120169, 0.5787801928818226, 1.7028193711303174, 3.9961543679237366, 9.596459157764912, 13.701476734131575, 21.465012095868587, 32.81168773770332, 40.3231018781662, 49.438299760222435, 53.05767394602299, 54.45737823843956, 55.60121186077595, 55.54399073123932, 58.19206863641739, 55.438743978738785, 51.707492396235466, 47.47699700295925, 46.78209409117699, 50.21510727703571, 53.428549244999886, 52.090561240911484, 54.59304615855217, 53.99550922214985, 54.27469924092293, 53.13489340245724, 52.67906606197357, 51.74936234951019, 56.92358650267124, 39.21787418425083, 49.90093253552914, 54.1930416226387, 43.42825345695019, 55.49738623201847, 51.289013251662254, 55.07352277636528, 51.96572653949261, 51.89975447952747, 49.34654988348484, 45.87451659142971, 42.31610253453255, 47.12369956076145, 44.9773733317852, 46.49993263185024, 45.46935573220253, 47.53479190170765, 48.18068124353886, 48.79337556660175, 49.32582959532738, 48.75626675784588, 51.158387660980225, 51.52442581951618, 51.22262701392174, 45.90391181409359, 37.17778645455837, 31.089886128902435, 21.07682302594185, 12.729864120483398, 6.02663716301322, 3.376636323519051, 0.2248281764332205, 0.8194558939430863, 1.649440904147923, 2.77332060970366, 3.422736399807036, 3.0388289876282215, 9.587661679834127, 3.630797085352242, 8.732588812708855, 4.5704517513513565, 1.4493914949707687, 0.5378554982598871, 1.7257346352562308, 5.23925481364131, 11.804400030523539, 25.109035558998585, 23.34265474230051, 20.781651064753532, 20.688288174569607, 22.130001112818718, 15.212269015610218, 5.129570374265313, 0.7235487434081733, 0.02347793080843985, 0.045329901404329576, 0.04153569367190357, 0.025734232294780668, 0.03227782071917318, 0.04238998728396837, 0.06251972255995497, 0.051025810607825406, 0.08111616960377432, 0.029383081127889454, 0.043755104852607474, 0.08780389238381758, 0.04655893506424036, 0.02657166616700124, 0.051167616475140676, 0.032993662971421145, 0.025929374460247345, 0.08614304751972668, 0.07909635532996617, 0.018375817671767436, 0.07203182933153585, 0.036459774637478404, 0.060362239892128855, 0.04297898536606226, 0.021625843764923047, 0.025167140556732193, 0.07963697280501947, 0.12956627877429128, 0.04815139473066665, 0.06173053014208563, 0.017665918167040218, 0.013740539543505292, 0.04830248486541677, 0.013598241075669648, 0.09615889444830827, 0.04152823879849166, 0.00969874206930399, 0.07319849290070124, 0.05343374956282787, 0.023763592726027127, 0.04738432944577653, 0.01742446969728917, 0.07617082403157838, 0.05378408037358895, 0.011671775064314716, 0.04805858916370198, 0.050465207095840015, 0.04447201208677143, 0.017318717364105396, 0.01511362685050699, 0.029080372078169603, 0.05603876954410225, 0.08234758555772714, 0.011372663575457409, 0.02393274859059602, 0.01810180561733432, 0.027015654159185942, 0.06389284419128671, 0.05585258695646189, 0.053724953468190506, 0.021408327702374663, 0.01780236758349929, 0.04145332641201094, 0.08234581924625672, 0.014655115955974907, 0.06419031182304025, 0.008335160746355541, 0.047779215092305094, 0.041117979562841356, 0.10898409687797539, 0.29984431515913457, 5.941634774208069, 25.00238288193941, 38.678428530693054, 33.40326279401779, 31.824884489178658, 13.532850332558155, 16.27737656235695, 31.300206743180752, 29.53496776521206, 15.004346072673798, 3.6178440554067492, 0.47262712963856757, 0.272165680071339, 0.8757370489183813, 3.3983478834852576, 5.9143550880253315, 6.11921064555645, 4.541819812729955, 4.27471362054348, 6.674092970788479, 3.5329525731503963, 2.5181676261126995, 2.980523253791034, 2.252986980602145, 3.5163598135113716, 5.21796265617013, 11.115349754691124, 16.9940485060215, 25.31489711254835, 36.086253225803375, 43.56645584106445, 51.407745480537415, 55.08259668946266, 55.24558134377003, 54.82073374092579, 54.81923662126064, 60.18866389989853, 57.97725856304169, 53.95660310983658, 50.89995212852955, 48.67835953831673, 50.183405578136444, 56.09407961368561, 54.030140563845634, 57.63241946697235, 55.64872071146965, 54.97963361442089, 53.737263679504395, 52.53621652722359, 51.0221041738987, 56.047368720173836, 40.67019425332546, 49.97684486210346, 55.17588548362255, 46.41857139766216, 54.052677154541016, 52.12630212306976, 55.18499739468098, 53.781348913908005, 52.19223238527775, 50.06712041795254, 45.80830514431, 45.82372471690178, 47.89043001830578, 47.48984791338444, 48.8281437009573, 47.702613696455956, 49.025558307766914, 49.83023352921009, 50.064897537231445, 51.1783441901207, 49.17186565697193, 52.86181725561619, 52.666222751140594, 51.69039711356163, 47.897535637021065, 42.30905011296272, 32.70925663411617, 25.050311610102654, 16.371075734496117, 8.702981751412153, 5.115994177758694, 1.6285487939603627, 2.323458236642182, 5.139125911518931, 6.6324391309171915, 7.485489556565881, 4.351398730650544, 6.075682081282139, 5.889390427619219, 3.0911809159442782, 4.247958781197667, 1.3493753992952406, 0.13700610143132508, 1.6699843830429018, 6.075212806463242, 13.622297532856464, 25.02144455909729, 24.684830121695995, 19.131202027201653, 21.708594225347042, 25.691865384578705, 20.283222310245037, 7.308641346171498, 1.1109120701439679, 0.016004950848582666, 0.06312023877399042, 0.03827899010502733, 0.05100806585687678, 0.032527920775464736, 0.053386003492050804, 0.03340303534059785, 0.073332799365744, 0.07042761775664985, 0.04198924609227106, 0.018807014748745132, 0.07256961180246435, 0.040380076970905066, 0.07209457049611956, 0.05255025243968703, 0.03359377842571121, 0.054320267227012664, 0.02862205135897966, 0.06414374205633067, 0.012161373597336933, 0.03038297112652799, 0.032749503807281144, 0.009942342767317314, 0.06263238057726994, 0.015999165807443205, 0.012370706554065691, 0.0382344686659053, 0.02726852984778816, 0.09541192281176336, 0.021298315441526938, 0.026273254152329173, 0.15457632893230766, 0.14418019069125876, 0.07113446146831848, 0.18042044917820022, 0.18142295710276812, 0.11551645104191266, 0.08201047239708714, 0.3564873116556555, 0.11274201358901337, 0.134893934300635, 0.08043676309171133, 0.14228343934519216, 0.18241461482830346, 0.1265047860215418, 0.17460940318414941, 0.1139677372702863, 0.16071200516307727, 0.11880015765200369, 0.10965292778564617, 0.1251700779539533, 0.10606623938656412, 0.09498313214862719, 0.0846557984186802, 0.1162648995523341, 0.13526248483685777, 0.09861164799076505, 0.13360688695684075, 0.2557422191603109, 0.10892730773775838, 0.12610999314347282, 0.119185183866648, 0.12306509481277317, 0.14424499502638355, 0.18817558069713414, 0.15162811760092154, 0.161237163702026, 0.25738313735928386, 0.1876388001255691, 0.2757605543592945, 0.39264922903385013, 6.53653702698648, 28.13339777290821, 44.60053615272045, 42.07285478711128, 38.67111772298813, 25.94241064041853, 25.539218075573444, 37.429762333631516, 34.08183038234711, 18.741570934653282, 4.6865378972142935, 0.8123296732082963, 1.3618281623348594, 4.614562159404159, 13.79786141216755, 14.277848806232214, 10.049486048519611, 9.796312283724546, 9.15335163474083, 10.972262732684612, 7.130163023248315, 3.944550999440253, 3.630356309004128, 1.5536081464961171, 2.392845838330686, 4.3892537243664265, 10.444057825952768, 14.922632407397032, 23.563297502696514, 36.32642313838005, 42.17848151922226, 51.94697454571724, 54.19746458530426, 54.977106750011444, 54.76398378610611, 55.21405063569546, 63.18873971700668, 61.332299932837486, 56.256558895111084, 53.49399693310261, 50.19447818398476, 54.267031252384186, 58.54174107313156, 56.032652109861374, 60.63637487590313, 57.174859419465065, 56.305017694830894, 53.024554923176765, 52.51506306231022, 51.35593146085739, 56.24181568622589, 43.5819324105978, 51.77898555994034, 54.04084458947182, 43.22133556008339, 56.5114264190197, 52.94745706021786, 56.214593946933746, 55.29406674206257, 54.83173035085201, 53.38592693209648, 51.30811482667923, 48.393241837620735, 50.51846019923687, 48.795974627137184, 50.592210441827774, 48.83661724627018, 51.48127533495426, 51.994589790701866, 53.85679766535759, 55.06414867937565, 51.02552019059658, 54.80311408638954, 53.20996597409248, 51.57997123897076, 47.48383663594723, 43.01472544670105, 33.50189410150051, 25.916477032005787, 15.866454262286425, 8.28655069693923, 5.078117810189724, 1.0712759220041335, 2.370090284384787, 3.9738721260800958, 6.080471724271774, 7.6912385411560535, 7.650290038436651, 18.294213339686394, 11.125630103051662, 15.139568466693163, 8.52007856592536, 2.318292176350951, 1.0576024744659662, 2.520174393430352, 7.650317586958408, 18.08507826179266, 33.27109068632126, 31.557268649339676, 29.424762278795242, 29.842975437641144, 32.435196340084076, 21.712772101163864, 7.8898947313427925, 1.0906631941907108, 0.12219036245369352, 0.18638672278029844, 0.15646717278286815, 0.12780743330949917, 0.1621337523101829, 0.0996260302781593, 0.1296301034744829, 0.1381522000883706, 0.13554573291912675, 0.14793021837249398, 0.11935553644434549, 0.3091703506652266, 0.17069135326892138, 0.1562053430825472, 0.15911827271338552, 0.1288871097494848, 0.1620453328359872, 0.24692321894690394, 0.17547829484101385, 0.090790546964854, 0.24110163445584476, 0.06045991765859071, 0.16472089395392686, 0.20576241746312007, 0.0590937610832043, 0.11278519174084067, 0.18854456167900935, 0.21684290491975844, 0.2610222139628604, 0.09178467604215257, 0.08205566919059493, 0.19627337664132938], [0.013186607939132955, 0.026932721011689864, 0.021929005524725653, 0.11812859564088285, 0.04393928735225927, 0.013595613872894319, 0.015807895797479432, 0.024047777769737877, 0.018696640690905042, 0.15806670882739127, 0.07451063967891969, 0.024204704895964824, 0.056366750577581115, 0.0225086302816635, 0.07675984437810257, 0.03829539899015799, 0.05559902478125878, 0.09192037032335065, 0.006966029550312669, 0.035533878617570736, 0.022278447613643948, 0.049504882845212705, 0.051969128544442356, 0.04491685911489185, 0.09818864607950673, 0.032079585653264076, 0.04189961691736244, 0.05825441432534717, 0.05719346598198172, 0.0686071888776496, 0.11210490207304247, 0.06663126521743834, 0.05725948743929621, 0.03784531611017883, 0.03528518122038804, 0.08131708382279612, 0.0487755928770639, 0.05793927615741268, 0.0469373153464403, 0.31505362247116864, 4.698759941384196, 18.57650589197874, 32.78917394578457, 25.36513801664114, 19.521925561130047, 12.36494405195117, 5.696250591427088, 18.483410887420177, 27.079032249748707, 14.94295846670866, 4.565156735479832, 1.2801460828632116, 1.4181385282427073, 3.2696326402947307, 3.469664119184017, 4.57176648080349, 2.9142930451780558, 2.3291714675724506, 5.2431396301835775, 1.4368138136342168, 1.1353333597071469, 1.6925978008657694, 1.6738363076001406, 1.900654211640358, 1.0590661084279418, 2.687454717233777, 4.726668493822217, 13.823591731488705, 18.184667117893696, 27.821124829351902, 32.3678145557642, 43.71273659169674, 47.185138463974, 54.83397603034973, 55.9366312623024, 59.24165591597557, 53.264101669192314, 54.99665290117264, 51.395080760121346, 55.75649052858353, 54.88622322678566, 54.78426329791546, 53.298470824956894, 55.03804408013821, 53.90861168503761, 52.36937887966633, 51.14727705717087, 53.64252336323261, 50.18804132938385, 58.43090482056141, 40.12830913066864, 45.25869883596897, 59.02287505567074, 43.263942673802376, 56.83496005833149, 54.56674017012119, 56.664713993668556, 51.844102665781975, 50.43321557343006, 49.5545469224453, 50.88974587619305, 50.59595704078674, 48.94955478608608, 47.9632493108511, 49.06998172402382, 48.47781389951706, 48.99628467857838, 47.84588120877743, 50.563886761665344, 51.43684811890125, 51.47416211664677, 51.36043041944504, 48.67210887372494, 37.618707194924355, 31.781614311039448, 25.53490910679102, 16.004140824079514, 7.520026853308082, 3.7871437333524227, 0.6898275716230273, 1.0274725849740207, 1.1413210071623325, 1.0563486604951322, 6.7411664966493845, 11.191795002669096, 8.201756346970797, 2.9507917491719127, 2.7849764842540026, 4.341136431321502, 3.7141358759254217, 5.282291304320097, 1.7518809135071933, 0.7756006065756083, 3.091192077845335, 8.801653906702995, 24.58057701587677, 33.90267379581928, 26.74928594380617, 24.56897623836994, 22.75612771511078, 15.547599121928215, 5.230207974091172, 0.6629262026399374, 0.021436200913740322, 0.0852447519719135, 0.057311226264573634, 0.04371812363388017, 0.03328137507196516, 0.1598699644091539, 0.0245359142718371, 0.054940877089393325, 0.06097965480876155, 0.011340248420310672, 0.040331774289370514, 0.03586513994378038, 0.028357136179693043, 0.024679529124114197, 0.030500714710797183, 0.009627152649045456, 0.029227300619822927, 0.030148250225465745, 0.06043587578460574, 0.06961486215004697, 0.0631123645871412, 0.05080821290903259, 0.014877311259624548, 0.056798090517986566, 0.019879312385455705, 0.042147319836658426, 0.10601523157674819, 0.004992094845874817, 0.11986447163508274, 0.02135082981112646, 0.08959514001617208, 0.030996022214822005, 0.03182558561093174, 0.042773974491865374, 0.06300243025179952, 0.02221389746409841, 0.06343451605062, 0.013550055282394169, 0.025657512778707314, 0.043961002593277954, 0.048069357726490125, 0.0544082562555559, 0.047516787963104434, 0.022477315360447392, 0.002278151473547041, 0.020387930308061186, 0.031222093384712934, 0.055814674342400394, 0.07849149013054557, 0.04673946248658467, 0.023085455286491197, 0.03048614635190461, 0.029623247537529096, 0.06660364248091355, 0.052862102893413976, 0.056299949865206145, 0.044607238814933226, 0.10804461955558509, 0.05073380518297199, 0.03806733700912446, 0.022241191800276283, 0.044237100082682446, 0.0885568383091595, 0.13762567599769682, 0.06222591742698569, 0.037421111919684336, 0.027565813797991723, 0.038352815245161764, 0.03950317382987123, 0.03666013966721948, 0.03244818442908581, 0.04872244768193923, 0.585569062968716, 7.363283364102244, 25.505681075155735, 37.374581694602966, 29.273857176303864, 24.509053453803062, 13.827701210975647, 13.9302415587008, 29.828954190015793, 28.08709915727377, 13.529715500772, 4.918617568910122, 1.3342921086587012, 0.4739480040734634, 0.7740606798324734, 1.477589663118124, 4.127370351925492, 3.6143909906968474, 3.5210748855024576, 4.211841719225049, 3.813425498083234, 4.461218062788248, 2.750036409124732, 3.4727068059146404, 3.0226867413148284, 1.1623697401955724, 4.861808242276311, 6.069771498441696, 14.703288227319717, 20.74536681175232, 30.607241727411747, 36.701333820819855, 47.23466120660305, 50.84341496229172, 55.18753945827484, 58.36476556956768, 60.78790694475174, 56.91707745194435, 56.804755479097366, 52.712983042001724, 56.899142414331436, 56.861539632081985, 56.35953716933727, 56.52238883078098, 58.641284331679344, 54.082072377204895, 52.733957916498184, 52.3904487490654, 53.91072817146778, 50.53102232515812, 56.62149891257286, 42.52737119793892, 46.515112817287445, 57.88473732769489, 46.422302797436714, 57.77582377195358, 54.68080244958401, 57.40926504135132, 54.02267016470432, 51.9050057977438, 50.73888637125492, 52.37497217953205, 51.00936345756054, 49.86913204193115, 49.30425055325031, 51.527910232543945, 49.58154447376728, 49.94072400033474, 49.577877670526505, 52.24248468875885, 52.564152628183365, 52.82651714980602, 52.025888711214066, 51.25964842736721, 42.21714064478874, 36.23966999351978, 28.042377457022667, 19.78458646684885, 10.32622804865241, 6.583256470039487, 1.8644172186031938, 2.530811922624707, 3.2875733776018023, 2.3820876656100154, 9.851712360978127, 9.813299272209406, 9.421119466423988, 8.030777871608734, 7.579903090372682, 3.8183801947161555, 3.8250972842797637, 3.031588476151228, 0.998418394010514, 1.4630067581310868, 5.14833471737802, 8.263666424900293, 25.378418304026127, 36.507688611745834, 27.095785550773144, 26.766808703541756, 25.91569997370243, 20.838207229971886, 8.359346240758896, 1.3226825441233814, 0.042546721451799385, 0.03935052518500015, 0.05677379260305315, 0.01610463426914066, 0.059651351475622505, 0.047321068777819164, 0.06350778829073533, 0.03608022918342613, 0.08704971449333243, 0.049783225331339054, 0.06020017710397951, 0.03932922554668039, 0.03426017879974097, 0.02381872502155602, 0.04378310979518574, 0.08806345853372477, 0.012478093467507279, 0.033625059950281866, 0.07064433229970746, 0.014602958744944772, 0.05731637305871118, 0.0730784801999107, 0.007459797097908449, 0.02201512619649293, 0.11057736177463084, 0.03127356874756515, 0.02711082161113154, 0.07512529380619526, 0.03959726702305488, 0.0509579783101799, 0.10972446340019815, 0.009934675454132957, 0.02698910939216148, 0.10618752115988173, 0.14003627555212006, 0.20398099586600438, 0.20516216842224821, 0.137043475988321, 0.11252680560573936, 0.1595294670551084, 0.1280395028879866, 0.17049296235200018, 0.19883288070559502, 0.2901461668079719, 0.09004374602227472, 0.20835947419982404, 0.17356156487949193, 0.24555981945013627, 0.24453099496895447, 0.10249003753415309, 0.12683038105024025, 0.11804479974671267, 0.14964888396207243, 0.21772637235699221, 0.16707658942323178, 0.16543938196264207, 0.12389241877826862, 0.23261235561221838, 0.1628782897023484, 0.12871303159045056, 0.1561618977575563, 0.19954408082412556, 0.22057733265683055, 0.292194583453238, 0.14475026400759816, 0.25592033460270613, 0.09492416851571761, 0.10799838375533, 0.25087168207392097, 0.15054495306685567, 0.14649680466391146, 0.17242202680790797, 0.6936821085400879, 7.839572606608272, 29.76068325340748, 43.65590684115887, 36.99346974492073, 31.706165559589863, 23.794587291777134, 14.252289477735758, 28.720810152590275, 34.803757444024086, 20.023171864449978, 6.42456273548305, 2.1504801185801625, 1.9304254953749478, 6.4205715246498585, 8.497774712741375, 13.879589326679707, 6.801829291507602, 8.700586929917336, 13.712837174534798, 4.264999916777015, 5.861081946641207, 4.3311928398907185, 4.336168197914958, 3.5319242533296347, 2.093510488048196, 4.309837985783815, 6.310391211882234, 15.959346927702427, 20.775995068252087, 30.743559412658215, 35.608246475458145, 46.84291362762451, 50.192616283893585, 55.87455399334431, 58.92759896814823, 62.781728357076645, 59.21215049922466, 60.34144230186939, 55.664923042058945, 61.38937667012215, 59.184221997857094, 59.68778237700462, 58.68946574628353, 58.20672444999218, 54.571577310562134, 52.9884834587574, 53.769618943333626, 53.47562491893768, 52.96973146498203, 55.520876571536064, 46.46211326122284, 48.53532001376152, 59.17775094509125, 43.65013115108013, 56.40195429325104, 57.97101549804211, 59.1738523542881, 55.81296309828758, 53.80759410560131, 53.29795025289059, 55.24805501103401, 53.31718862056732, 52.488460689783096, 51.85430131852627, 53.075422793626785, 52.059615701437, 52.77438774704933, 51.69993460178375, 53.36590960621834, 54.41029496490955, 53.97948168218136, 53.02805833518505, 50.22775299847126, 46.089870035648346, 38.94680052995682, 30.577124543488026, 20.628122203052044, 9.968267306685448, 5.719732856377959, 1.7070806049741805, 2.0946157537400723, 4.939012974500656, 2.735817809589207, 11.414400357753038, 16.17191892117262, 13.679977487772703, 9.016437381505966, 8.729076851159334, 11.109913196414709, 9.235043451189995, 8.10974333435297, 2.742525637149811, 1.4591721701435745, 4.999369410797954, 14.650215525180101, 35.156291127204895, 44.749662950634956, 35.91479882597923, 33.50529491901398, 33.10701549053192, 22.51842387020588, 7.9764654859900475, 1.0672337701544166, 0.1333500593318604, 0.16740819584811106, 0.15398286312120035, 0.12563435069750994, 0.17574220255482942, 0.25304712471552193, 0.11840481558465399, 0.09355240501463413, 0.19940129161113873, 0.20787013170775026, 0.1295037305681035, 0.1094719476532191, 0.18394052982330322, 0.11095109992311336, 0.10056580445962027, 0.24995474377647042, 0.1456124911783263, 0.12843561678892002, 0.21982737758662552, 0.1684923400171101, 0.17596386722289026, 0.14372733217896894, 0.10866253171116114, 0.09952868276741356, 0.2118323987815529, 0.1807473652297631, 0.19684024387970567, 0.21956143638817593, 0.17447174963308498, 0.13870331895304844, 0.30839961546007544, 0.08956187695730478, 0.07203924338682555], [0.02103575287037529, 0.10878305649384856, 0.07395644090138376, 0.02785693977784831, 0.05386926779465284, 0.06607873627217487, 0.03420133019972127, 0.026511162577662617, 0.016162488391273655, 0.015213691549433861, 0.008499491723341634, 0.06436222291085869, 0.04865940965828486, 0.008468689811707009, 0.10414861884783022, 0.007327957810048247, 0.07452799851307645, 0.0413208753161598, 0.011989524664386408, 0.026809910414158367, 0.04248573546647094, 0.023225227669172455, 0.03747345559531823, 0.01380168601826881, 0.04208253034448717, 0.10877411361434497, 0.01749813342030393, 0.021237372129689902, 0.04506344812398311, 0.015248826675815508, 0.042902239874820225, 0.04368634858110454, 0.0067339525503484765, 0.022751689211872872, 0.0198283658028231, 0.10700309692765586, 0.06774059787858278, 0.0331768361502327, 0.023764655852573924, 0.021794142448925413, 0.36702278070151806, 6.21927447617054, 22.623193748295307, 32.362684831023216, 22.581523284316063, 18.226204589009285, 9.873068165034056, 11.191943194717169, 13.325701598078012, 16.230416782200336, 13.414340391755104, 4.963475111871958, 1.3633723044767976, 0.3186541370814666, 1.8889811192639172, 2.564488328061998, 2.3800965724512935, 1.9325412693433464, 1.8496547732502222, 3.731495481915772, 3.2352359360083938, 2.830127323977649, 3.3993515046313405, 1.5934357093647122, 0.6868939509149641, 1.1512251757085323, 1.9453989481553435, 4.107239982113242, 10.01151468604803, 12.12459934875369, 15.8320034109056, 23.433836549520493, 32.976230308413506, 44.78862605988979, 54.29530553519726, 59.482031017541885, 57.59066730737686, 55.21799482405186, 58.7025560438633, 54.68759648501873, 56.80978260934353, 57.27523863315582, 57.33375929296017, 55.28417967259884, 54.411830082535744, 53.00800681114197, 51.23765140771866, 54.030664935708046, 52.161530032753944, 56.644974052906036, 43.922439739108086, 40.75484611093998, 62.646995186805725, 55.88533781468868, 59.81157973408699, 55.75930617749691, 55.05539394915104, 52.43810959160328, 53.208012878894806, 51.174912974238396, 51.70012079179287, 51.05420485138893, 53.2017470151186, 52.98126004636288, 52.78640270233154, 52.5776457041502, 51.93293809890747, 50.383320450782776, 50.81191845238209, 51.38136729598045, 50.87168924510479, 45.171303525567055, 32.19464644789696, 26.055146791040897, 25.810295529663563, 11.820691656321287, 5.487067541107535, 1.7013293760828674, 1.1260788375511765, 0.5198563984595239, 2.0748040918260813, 2.157936030998826, 3.750783484429121, 11.906530000269413, 8.166632931679487, 9.629636127501726, 10.489612631499767, 8.868866600096226, 4.059162586927414, 1.8330538203008473, 1.8270504986867309, 2.0530794700607657, 5.324141308665276, 5.478836232796311, 14.832000620663166, 23.63738402724266, 26.876700706779957, 23.691301234066486, 25.879651308059692, 16.41587533056736, 5.115941930562258, 0.608222734881565, 0.06973488227231428, 0.04429647931829095, 0.012151588380220346, 0.007547769891971257, 0.02394940052909078, 0.004523962934399606, 0.014780166911805281, 0.019090075438725762, 0.04967929497070145, 0.03355428503709845, 0.02431063163385261, 0.04508546022407245, 0.08370141877094284, 0.05640157585730776, 0.08398079284233972, 0.037471110408660024, 0.024863450016709976, 0.05472027369251009, 0.007471278122466174, 0.017202016497321893, 0.02939963473181706, 0.0201093967189081, 0.04174157285888214, 0.021430545748444274, 0.04627995062037371, 0.021576303552137688, 0.07261443010065705, 0.04930198709189426, 0.021448527986649424, 0.07787750393617898, 0.015931422567518894, 0.08298584740259685, 0.01608132712135557, 0.04137832125707064, 0.03239886129449587, 0.02487506833858788, 0.014192823819030309, 0.027890813253179658, 0.026514891869737767, 0.05814575277327094, 0.039990842778934166, 0.04689039305958431, 0.04542738250165712, 0.033891951097757556, 0.046886437412467785, 0.07882137477281503, 0.005949710257482366, 0.03806817934673745, 0.07765876332996413, 0.023563288923469372, 0.05355007750040386, 0.04586736104101874, 0.02284753201820422, 0.09232538257492706, 0.040877193459891714, 0.020424742688192055, 0.05247816021437757, 0.06473477362305857, 0.04422613485075999, 0.09706262993859127, 0.026012758462456986, 0.0387873241561465, 0.03747597889741883, 0.04790604441950563, 0.05880645345314406, 0.015869072885834612, 0.05982915150525514, 0.002455492299304751, 0.03810373935266398, 0.07085460500093177, 0.02685394760192139, 0.04151600078330375, 0.07545234344433993, 0.040911105897976086, 0.5693035013973713, 9.05650433152914, 29.647521525621414, 38.07738058269024, 28.651142790913582, 22.12458450347185, 10.831156354397535, 14.506196603178978, 25.08367571979761, 25.295938029885292, 13.794352300465107, 4.491763673722744, 1.0820492939092219, 0.13669539388502017, 0.6342907017096877, 2.319145705550909, 3.4740402968600392, 2.848758911713958, 5.663107819855213, 4.718191623687744, 4.982995614409447, 4.974566241726279, 2.6856581261381507, 2.255527856759727, 1.5031273802742362, 2.1084389369934797, 2.434807224199176, 6.06760561466217, 11.483581345528364, 15.413596462458372, 18.779390305280685, 27.617223970592022, 35.784260630607605, 48.39369781315327, 57.750433534383774, 61.817070320248604, 59.29249718785286, 56.33639261126518, 58.85717734694481, 56.53936631977558, 58.201119750738144, 59.23246040940285, 57.92718105018139, 55.10079391300678, 54.913600757718086, 53.28438118100166, 52.08753280341625, 54.02425467967987, 52.23119929432869, 56.280938386917114, 47.54882454872131, 43.4015104919672, 62.145870476961136, 56.32742129266262, 59.04003493487835, 55.27024582028389, 55.73484309017658, 55.000688284635544, 53.444857969880104, 54.303045719861984, 53.67091923952103, 52.76692494750023, 54.70556192100048, 55.26687540113926, 54.03145529329777, 54.039495661854744, 53.07201437652111, 52.813065871596336, 51.425410732626915, 53.543086498975754, 53.384034633636475, 47.679864317178726, 36.726040095090866, 31.57971404492855, 29.305233992636204, 15.36874271929264, 8.190366458147764, 3.106429260224104, 1.8546444992534816, 1.6344174603000283, 2.0213848957791924, 3.411635532975197, 3.111373269930482, 8.550622276961803, 10.93097984790802, 10.301118046045303, 8.714399188756943, 5.405231332406402, 2.343655340373516, 1.6883085435256362, 0.8218285697512329, 1.547496768180281, 5.761445593088865, 7.075567552819848, 17.402268201112747, 31.989062279462814, 33.44430819153786, 29.295118935406208, 29.31595891714096, 20.907595306634903, 8.698609136044979, 1.3226857502013445, 0.011882052403962007, 0.026079685339936987, 0.04190339815977495, 0.06867186704766937, 0.011743885843316093, 0.029495386625058018, 0.06317465304164216, 0.039091430298867635, 0.08204913086956367, 0.026223348431813065, 0.025018944797920994, 0.04765921723446809, 0.034666823776206, 0.08773829395067878, 0.02376440908847144, 0.04237184548401274, 0.040674843185115606, 0.02111028676154092, 0.03087516532104928, 0.005073829424873111, 0.03290140659373719, 0.04434635164216161, 0.10857400833629072, 0.023548021090391558, 0.08543134274077602, 0.026537941121205222, 0.040319302497664467, 0.026967954472638667, 0.04730994027340785, 0.06448251762776636, 0.013525011509045726, 0.058241152146365494, 0.023878597785369493, 0.02361569568165578, 0.09008260487462394, 0.19557669293135405, 0.17705926235066727, 0.18442558270180598, 0.11364122939994559, 0.19080840895185247, 0.10747123626060784, 0.15042708517285064, 0.14320147602120414, 0.14516371447825804, 0.12914136954350397, 0.12968263268703595, 0.20847382431384176, 0.11841113868285902, 0.17001102649373934, 0.11179788300069049, 0.13480998255545273, 0.10021021182183176, 0.10968607952236198, 0.14276513771619648, 0.10815412344527431, 0.12736569216940552, 0.14216278097592294, 0.12848485086578876, 0.12058328618877567, 0.23623546119779348, 0.1375470231869258, 0.07057513445033692, 0.1427812423207797, 0.15984312834916636, 0.20275587332434952, 0.20238258788594976, 0.1509358422481455, 0.08391055598622188, 0.08895016173482873, 0.24141982285073027, 0.1377901210798882, 0.10685565444873646, 0.16071570105850697, 0.18589571787742898, 0.6142266502138227, 9.580102935433388, 31.677971072494984, 45.11266507208347, 35.89206084609032, 29.647987000644207, 17.588948383927345, 17.872853949666023, 23.543960340321064, 26.202527582645416, 17.727910727262497, 6.610598852857947, 2.112037818878889, 0.7115863915532827, 4.044812181964517, 6.905712392181158, 8.57471488416195, 8.114256542176008, 9.397331792861223, 10.5828957259655, 7.443985333666205, 6.72606373205781, 10.043819602578878, 4.528306787833571, 1.4632099284790456, 2.061229795217514, 2.906020414084196, 6.289826240390539, 11.428110022097826, 13.560811132192612, 19.32276874780655, 25.826060883700848, 35.52372381091118, 46.23291715979576, 57.690400555729866, 62.96778917312622, 62.5569362193346, 59.340830594301224, 62.983125150203705, 57.728242725133896, 61.665872633457184, 59.713552594184875, 58.66572082042694, 55.22319674491882, 54.965642765164375, 53.05032514035702, 52.77863211929798, 53.1737919151783, 54.692916199564934, 56.59243427217007, 51.15482345223427, 46.624265760183334, 61.26504734158516, 53.71162265539169, 59.34787921607494, 57.73344084620476, 57.64816202223301, 56.151452735066414, 56.53486356139183, 55.03039129078388, 55.80307982861996, 54.61774863302708, 57.1358697116375, 57.6718195527792, 55.26946306228638, 56.651901081204414, 55.141288340091705, 54.658900424838066, 53.66449378430843, 54.81495425105095, 53.616722747683525, 49.35898281633854, 42.76005931198597, 32.75548115372658, 28.53850543498993, 14.072687365114689, 6.153418784961104, 2.699704309925437, 2.8988150507211685, 2.0585096161812544, 4.580556834116578, 6.470584440976381, 8.635459374636412, 19.05035186558962, 15.861855559051037, 19.01393461972475, 20.40990751236677, 16.09704963862896, 10.412411224097013, 5.519561022520065, 2.6094202045351267, 2.3761065490543842, 7.774238437414169, 9.890356287360191, 23.66245698183775, 35.87525814771652, 38.970157876610756, 35.74222348630428, 34.08840022981167, 22.6106259226799, 8.410519994795322, 0.9977073571644723, 0.1572076728916727, 0.2721360238501802, 0.20997680694563314, 0.175296290544793, 0.08962855150457472, 0.10491108652786352, 0.09990963459131308, 0.12676835234742612, 0.28219654806889594, 0.06463821278885007, 0.08928121154895052, 0.11516974191181362, 0.1879215583903715, 0.21033766883192584, 0.10111894938745536, 0.17113453417550772, 0.11146189790451899, 0.16339651658199728, 0.12198699172586203, 0.12592217040946707, 0.1133355610363651, 0.11631728033535182, 0.14089758245972916, 0.1647587286424823, 0.22227780078537762, 0.14907802396919578, 0.23561358597362414, 0.16864802775671706, 0.2102434160769917, 0.2548751828726381, 0.14416058314964175, 0.19323291635373607, 0.1768098265165463, 0.1464060548460111], [0.04984191065886989, 0.033846680089482106, 0.047519118306809105, 0.05984984258248005, 0.150880181172397, 0.05414263046986889, 0.06624194196774624, 0.04912117394269444, 0.025197097347700037, 0.01839724718593061, 0.011355711994838202, 0.01735377085424261, 0.030492181867884938, 0.03851523055345751, 0.0114599540575, 0.030774455881328322, 0.07163255388149992, 0.026225608271488454, 0.07099461116013117, 0.03256974079704378, 0.07549552159616724, 0.05056386078649666, 0.01881967022200115, 0.02882108608901035, 0.058447580522624776, 0.10943026863969862, 0.09014777286211029, 0.08739140670513734, 0.06979265846894123, 0.042785841433214955, 0.035761224426096305, 0.028328079242783133, 0.04630331713997293, 0.019052699026360642, 0.009898525440803496, 0.029190612549427897, 0.04182721670076717, 0.03043619424715871, 0.04633788266801275, 0.023393945666612126, 0.03436989791225642, 0.25816740933805704, 5.644884472712874, 21.00951723754406, 30.975533165037632, 24.007516466081142, 20.922074429690838, 10.190245695412159, 9.043380785733461, 14.997575785964727, 26.9521551579237, 17.456263303756714, 7.9561608005315065, 1.815413385629654, 0.24024285085033625, 0.8154544117860496, 1.9936943566426635, 1.938820551149547, 2.8605378046631813, 2.841268088668585, 2.8370892629027367, 4.0930444188416, 1.522600979078561, 3.1787902023643255, 0.18449733353918418, 0.6142670230474323, 0.806933487765491, 0.5290129571221769, 2.060474348254502, 4.242346482351422, 6.905084000900388, 11.558068748563528, 17.91357446461916, 28.65295149385929, 43.92041824758053, 55.60778930783272, 59.28147777915001, 59.864681884646416, 58.2167749106884, 59.18717443943024, 57.05296576023102, 55.590937212109566, 53.48279893398285, 53.20173181593418, 53.445382341742516, 55.79960681498051, 52.93296463787556, 53.082410618662834, 52.03658513724804, 55.89729957282543, 46.282158717513084, 42.34702907502651, 55.01158230006695, 53.742666989564896, 53.05345617234707, 56.50800280272961, 56.51183679699898, 55.14681704342365, 55.19072748720646, 54.047634825110435, 56.552772000432014, 55.710987970232964, 52.91629113256931, 52.849885895848274, 53.92357908189297, 53.138921186327934, 53.13699848949909, 52.00888082385063, 54.15014572441578, 50.831947177648544, 39.27147790789604, 24.546601139009, 26.83938290923834, 20.920689404010773, 8.216655347496271, 2.9184595216065645, 2.578987400047481, 0.48777433403301984, 0.7967159547843039, 1.7345076519995928, 1.6073186206631362, 4.085833830758929, 2.2051233239471912, 8.229407463222742, 9.547501634806395, 9.520674124360085, 6.009136727079749, 4.173734039068222, 1.7285986128263175, 0.8355897688306868, 1.186910248361528, 5.914914133027196, 11.597956158220768, 9.335640203207731, 12.730377092957497, 21.752149388194084, 22.267658226191998, 23.291397392749786, 19.631764367222786, 5.740590412169695, 0.5276796442922205, 0.0716109128552489, 0.006271346392168198, 0.06982935025007464, 0.023538675595773384, 0.060454711492639035, 0.025191494132741354, 0.049915646741283126, 0.02320031006092904, 0.06513259446364827, 0.01041857614836772, 0.056240722769871354, 0.009456578354729572, 0.01075596390364808, 0.05085133911052253, 0.0233536489031394, 0.05657757617882453, 0.0064593073511787225, 0.026140931076952256, 0.06400170983397402, 0.08301997877424583, 0.02409509525023168, 0.10068127521662973, 0.019677887939906213, 0.0020343003006928484, 0.05542693928873632, 0.011880344536621124, 0.033035906017175876, 0.04320487285440322, 0.052176013341522776, 0.042058095132233575, 0.06561637826962397, 0.05285583916702308, 0.023501265786762815, 0.00986252942311694, 0.0769607289112173, 0.016610248349024914, 0.07040391355985776, 0.025155922994599678, 0.039445045113097876, 0.062240122133516707, 0.026989675279764924, 0.030920966964913532, 0.009191782846755814, 0.035922574752476066, 0.019960206482210197, 0.024487810114806052, 0.0584194679686334, 0.05151661884156056, 0.03000226235599257, 0.06161426157632377, 0.06123740640759934, 0.032542103217565455, 0.098844177700812, 0.035167847672710195, 0.009730101519380696, 0.0741381557600107, 0.019846997420245316, 0.06786795041989535, 0.032993607310345396, 0.0818994471046608, 0.011631742690951796, 0.04718225376564078, 0.0409440349903889, 0.01760333099809941, 0.05318122639437206, 0.026073673943756148, 0.04965395804902073, 0.011475765513750957, 0.040339923070860095, 0.011156606760778232, 0.023732570953143295, 0.04175805595878046, 0.038198044057935476, 0.05450633849250153, 0.02159171981475083, 0.0876433881057892, 0.64470618031919, 9.680085070431232, 27.8407184779644, 36.256487891077995, 29.141622371971607, 23.019453585147858, 10.344976242631674, 11.410562563687563, 20.439880304038525, 27.906002774834633, 15.010209158062935, 7.589653367176652, 1.5142770507372916, 0.030400897703657392, 0.39308311825152487, 0.4940896248444915, 0.9690638410393149, 4.165169773623347, 4.493648372590542, 6.259302953258157, 5.011197701096535, 4.838111763820052, 3.9814344327896833, 1.3356751156970859, 2.1071538934484124, 1.3361346535384655, 1.4920172514393926, 3.141113086603582, 7.579137906432152, 8.765918724238873, 14.242196269333363, 20.41360281407833, 33.37936207652092, 46.70587778091431, 57.958297580480576, 60.289426892995834, 60.59831231832504, 59.71290282905102, 61.60759516060352, 57.800393253564835, 55.90107277035713, 54.75126966834068, 53.61666575074196, 53.595086708664894, 55.11836037039757, 54.505232870578766, 54.26874116063118, 52.258755415678024, 54.864609986543655, 48.13636802136898, 43.538348749279976, 56.97595149278641, 53.696719855070114, 53.76937955617905, 57.47623264789581, 56.46945387125015, 55.32938204705715, 55.85031509399414, 55.31139001250267, 57.68580660223961, 57.03633405268192, 54.836928471922874, 54.03249643743038, 55.028506591916084, 53.44269208610058, 55.308015793561935, 51.79608844220638, 56.33835710585117, 52.9083039611578, 44.76318262517452, 30.98753672093153, 32.85550698637962, 23.179643489420414, 10.6268859654665, 4.15897230617702, 2.573596676811576, 1.6559541109018028, 1.4954514359124005, 2.3077990394085646, 2.0880335569381714, 4.293963387608528, 2.9789095278829336, 6.93227106705308, 5.845219222828746, 4.797982117161155, 4.90785607136786, 4.009058475494385, 1.3697552494704723, 0.45075870933942497, 1.0514213936403394, 5.575387151911855, 12.974698282778263, 12.106973994523287, 18.03980179131031, 26.86845514923334, 28.488678708672523, 27.503864653408527, 25.08774720132351, 8.410714734345675, 1.1320915399119258, 0.08465269624139182, 0.05177555787668098, 0.021421023993752897, 0.004965652124155895, 0.023658272693865, 0.015539050018560374, 0.032840873318491504, 0.055968885208130814, 0.03207877300155815, 0.04443894198630005, 0.01695450282568345, 0.03952993938582949, 0.040093630232149735, 0.041239265046897344, 0.00890436296685948, 0.03677772554510739, 0.06287910015089437, 0.01760934610501863, 0.07633898727362975, 0.04852808291616384, 0.053091066583874635, 0.0515734005603008, 0.009812089356273646, 0.06333120909403078, 0.06785482924897224, 0.03019667350599775, 0.022899261566635687, 0.10738548109657131, 0.06543285999214277, 0.026667963538784534, 0.07652845757547766, 0.05322791861544829, 0.021175751608097926, 0.013662005476362538, 0.0657577277161181, 0.12353013196843676, 0.1394202484516427, 0.12143548694439232, 0.18122628796845675, 0.20295766327762976, 0.09320560682681389, 0.16982268425635993, 0.16103832749649882, 0.12598963163327426, 0.14080821303650737, 0.1599754235940054, 0.09567903660354204, 0.13812269229674712, 0.13709636143175885, 0.19243163435021415, 0.16448995243990794, 0.10328377931728028, 0.27303253824356943, 0.190255880006589, 0.208997854788322, 0.18259773234603927, 0.21582642977591604, 0.17740741866873577, 0.10643645233358257, 0.1679191496805288, 0.1208043126098346, 0.12744998530251905, 0.19318915932672098, 0.1617882528807968, 0.1777723475242965, 0.1764844689751044, 0.16339412686647847, 0.14644141076132655, 0.11429589270846918, 0.07748734205961227, 0.14060177723877132, 0.14079568558372557, 0.08872315360349603, 0.10100054714712314, 0.11772102297982201, 0.223134046245832, 0.751961125060916, 9.07813087105751, 30.258348248898983, 43.71698476374149, 35.54026432335377, 32.08763279020786, 18.251321241259575, 16.105749271810055, 22.250247560441494, 37.307222709059715, 22.520667649805546, 10.550494864583015, 2.2719916608184576, 0.5599451973102987, 2.2567155305296183, 4.784400695934892, 6.720307040959597, 5.30506775714457, 8.426193203777075, 8.86543158441782, 10.683183744549751, 6.5357680432498455, 7.890548771247268, 2.142939898185432, 2.6557050459086895, 2.3475855169817805, 1.610224514734, 2.353086434304714, 6.0976677015423775, 7.675195327028632, 12.98156451433897, 19.763315208256245, 32.9212586581707, 46.48426607251167, 59.11866411566734, 62.3471836745739, 63.42992417514324, 60.914994925260544, 63.32378827035427, 58.14104497432709, 56.895335018634796, 55.98839968442917, 55.06949879229069, 53.891573399305344, 55.78072562813759, 54.65679153800011, 54.02300454676151, 52.62091398239136, 55.501953586936, 49.984813034534454, 48.29488791525364, 56.77902325987816, 55.217614844441414, 55.88996596634388, 58.6038601398468, 58.58661666512489, 56.631184592843056, 56.85467720031738, 57.533191591501236, 59.39928285777569, 59.82087783515453, 55.499552115798, 56.506509482860565, 58.106922805309296, 57.98763960599899, 56.63088820874691, 53.617296516895294, 56.136257350444794, 52.95448288321495, 44.1943721473217, 35.924636498093605, 31.454674154520035, 23.250464089214802, 9.461437202990055, 4.734363555908203, 4.331678738817573, 1.6803207783959806, 2.667300123721361, 3.8451730320230126, 4.665106097236276, 7.994191534817219, 6.936238054186106, 17.175051793456078, 18.169931508600712, 18.476128578186035, 11.75372214987874, 7.169105708599091, 3.428653394803405, 1.4172644563950598, 2.0213126996532083, 8.162932880222797, 17.970202825963497, 16.682719811797142, 22.158862464129925, 35.58422036468983, 32.8512854129076, 33.274491503834724, 26.06253169476986, 9.079911075532436, 1.1155385593883693, 0.12481375801144168, 0.16382243513362482, 0.14896263484843075, 0.17924665356986225, 0.16226272273343056, 0.09553613606840372, 0.11175203311722726, 0.2959611313417554, 0.17653684975812212, 0.10025010968092829, 0.15444112446857616, 0.16801928024506196, 0.12675508274696767, 0.08870998790371232, 0.16339500260073692, 0.20540762634482235, 0.22025000100256875, 0.1487201900454238, 0.13750334037467837, 0.19241852802224457, 0.11003094070474617, 0.2526897063944489, 0.09987238619942218, 0.10707052846555598, 0.1795153258717619, 0.1394548622192815, 0.08878907116013579, 0.20211384136928245, 0.11584708525333554, 0.13984953635372221, 0.17867512564407662, 0.13417235895758495, 0.10150593487196602, 0.10143298917682841, 0.14840973482932895], [0.030028938854229636, 0.051376920673646964, 0.03968317432736512, 0.03283659112639725, 0.06916948448633775, 0.09260201069992036, 0.08886664785677567, 0.07446972507750615, 0.01826294814236462, 0.027970230476057623, 0.04734727401228156, 0.04453376248420682, 0.06893791956827044, 0.017308946989942342, 0.008141813650581753, 0.05788751506770495, 0.06492106011137366, 0.0303643562074285, 0.014092728506511776, 0.07138573040720075, 0.10941100990748964, 0.04136395327805076, 0.033272558357566595, 0.04558828382869251, 0.03374663858267013, 0.014615185627917526, 0.03043470253032865, 0.0416692097496707, 0.0620797328883782, 0.06270246158237569, 0.05494992386957165, 0.01885956993646687, 0.05043467514042277, 0.07576982679893263, 0.06081970714149065, 0.11810971540398896, 0.05530793219804764, 0.042849384117289446, 0.028539548657136038, 0.05247565917670727, 0.020960588153684512, 0.10852396531845443, 0.1876868912950158, 5.879214098677039, 19.214599952101707, 27.714941427111626, 26.145532540977, 17.275174520909786, 13.000241462141275, 17.139419205486774, 16.61314744502306, 17.259984835982323, 14.933046698570251, 8.837955258786678, 2.445151931606233, 0.6556644360534847, 0.6494797335471958, 1.0172716761007905, 6.0715635772794485, 2.5399824930354953, 6.917726397514343, 3.0311194388195872, 1.19475670857355, 1.788743210490793, 1.0804825904779136, 3.3811131957918406, 1.4254342555068433, 1.5925187710672617, 0.9634822374209762, 1.5356326173059642, 1.554975954350084, 3.1977423978969455, 6.175413429737091, 15.325653981417418, 27.18858227133751, 40.33336132764816, 52.108226493000984, 55.23977145552635, 57.28225685656071, 58.018786534667015, 55.38399651646614, 57.430331110954285, 55.14815077185631, 55.97972474992275, 53.18992204964161, 55.719168931245804, 52.99519769847393, 55.26024095714092, 54.53640639781952, 54.76931490004063, 51.42584390938282, 53.69235008955002, 54.15837988257408, 58.10003377497196, 61.26134254038334, 56.606265529990196, 55.21472319960594, 55.545085072517395, 55.12855142354965, 54.43756230175495, 54.79619465768337, 54.69259701669216, 57.46077887713909, 57.41066716611385, 55.18734186887741, 53.41711185872555, 56.3213986158371, 55.139950811862946, 47.8731257468462, 37.91132189333439, 23.48030425608158, 24.389836750924587, 14.092926029115915, 2.6534871524199843, 0.7894700998440385, 0.11730683036148548, 0.8222521282732487, 1.177172320894897, 0.7390737603418529, 1.7907319287769496, 0.926625580759719, 2.358017382211983, 2.1063200756907463, 4.497087188065052, 3.8630156870931387, 0.8416085864882916, 2.910415828227997, 2.838599681854248, 0.6522563158068806, 1.7601276584900916, 6.063764495775104, 16.263068430125713, 22.54574440419674, 15.150492880493402, 17.685824185609818, 19.677377119660378, 24.406531155109406, 17.942572608590126, 7.240352360531688, 0.8544011937920004, 0.023511247673013713, 0.026331726112402976, 0.04947458837705199, 0.08633943463792093, 0.020162291439191904, 0.07222766726044938, 0.07622137170983478, 0.014651391302322736, 0.09417871828190982, 0.01827600623073522, 0.007622756957061938, 0.08719884164747782, 0.04639125050744042, 0.02760433311777888, 0.03435019389144145, 0.045077125905663706, 0.07638577226316556, 0.07692188490182161, 0.06526258162921295, 0.03407859752769582, 0.043252411123830825, 0.005376674380386248, 0.022504700609715655, 0.10303240647772327, 0.09293620722019114, 0.055507343568024226, 0.03471415053354576, 0.03939559210266452, 0.045057317984174006, 0.050163717023679055, 0.05809921640320681, 0.030049605811655056, 0.06278630200540647, 0.05369382779463194, 0.0492176123225363, 0.0313814065157203, 0.022680648980895057, 0.05860069672053214, 0.08508202867233194, 0.02322902004380012, 0.08642069238703698, 0.0646457084803842, 0.02597803893877426, 0.10494155168998986, 0.03793702329858206, 0.03894992500136141, 0.04041887274070177, 0.019200670285499655, 0.02981938232551329, 0.020592347464116756, 0.021577147745119873, 0.03694557708513457, 0.07611874010763131, 0.011897251588379731, 0.07844050458515994, 0.02865688962629065, 0.08944905566750094, 0.03742557964869775, 0.051897299781558104, 0.005641147517962963, 0.018535711533331778, 0.021856388229934964, 0.053947972555761226, 0.06316717961453833, 0.04001310720923357, 0.0701059857965447, 0.04366369823401328, 0.05134317521878984, 0.05835392890730873, 0.03998823412985075, 0.055052559182513505, 0.09085906203836203, 0.04993867187295109, 0.052700455707963556, 0.05151475976163056, 0.047766053103259765, 0.06731201501679607, 0.03965832722315099, 0.5374938645400107, 9.914510641247034, 25.195137038826942, 32.601220831274986, 29.06340926885605, 18.08574702590704, 12.682738099247217, 18.09037707746029, 26.344297975301743, 26.22799761593342, 19.609579257667065, 10.19947350025177, 2.0744243497028947, 0.6269364338368177, 0.35507087828591466, 0.43786211230326444, 2.016768380999565, 1.7298656073398888, 3.134717079810798, 5.409947829321027, 6.024143546819687, 5.215119458734989, 7.619885969907045, 4.576304387301207, 2.8351634787395597, 1.8603637861087918, 2.6217932906001806, 2.400511926971376, 2.5292599434033036, 5.154123706743121, 7.785757519304752, 18.004247099161148, 29.16055105626583, 44.788249880075455, 54.375884011387825, 58.698190078139305, 59.54140663146973, 58.31128343939781, 56.35582096874714, 56.58822789788246, 55.61335600912571, 56.34281426668167, 54.17996272444725, 56.54914699494839, 53.779882192611694, 55.82305535674095, 54.9759516119957, 55.1692358404398, 51.500889882445335, 51.621738597750664, 55.84783762693405, 58.212971314787865, 59.54855404794216, 56.675114035606384, 55.7835640758276, 55.66833905875683, 55.91839984059334, 54.37468707561493, 54.740406051278114, 55.317868664860725, 59.626446068286896, 56.67381830513477, 57.01349727809429, 56.050188168883324, 57.644282430410385, 56.68808273971081, 49.73162122070789, 43.04500222206116, 29.814368672668934, 27.89162054657936, 17.479968331754208, 4.560498660430312, 1.3833853555843234, 0.9998135128989816, 1.6268528974615037, 1.8578403652645648, 2.5989900017157197, 2.2152246069163084, 3.7919647246599197, 5.476863663643599, 3.260136949829757, 6.084168925881386, 5.618916666135192, 4.110561003908515, 2.7072153193876147, 0.8924813847988844, 0.5099508643615991, 1.805344638414681, 6.438843794167042, 16.783722192049026, 25.67019894719124, 16.13017626106739, 22.88743916898966, 25.52683264017105, 26.70221406966448, 23.38397942483425, 10.236708652228117, 2.0135000813752413, 0.06550786143634468, 0.05658848946040962, 0.09049518703250214, 0.030959807263570838, 0.017608906382520217, 0.022627672624366824, 0.04568183525407221, 0.04677480726968497, 0.013385249330895022, 0.10145992171601392, 0.04826819022127893, 0.06672613395494409, 0.031115999663597904, 0.059909544652327895, 0.029939840314909816, 0.028325522544037085, 0.029724380001425743, 0.07429790304740891, 0.01556013814479229, 0.011197783896932378, 0.02922816336649703, 0.0447847197210649, 0.0337286526337266, 0.04582462446705904, 0.012024495590594597, 0.028760031455021817, 0.0292111941598705, 0.05796416036901064, 0.07276622898643836, 0.050677209001150914, 0.021427619831229094, 0.027118758880533278, 0.02510955360776279, 0.05764663248555735, 0.010406614583189366, 0.036552305609802715, 0.12637707724934444, 0.134901593264658, 0.18756477831630036, 0.12147292087320238, 0.22146231407532468, 0.1430222622002475, 0.17204145347932354, 0.15298004349460825, 0.12823363387724385, 0.07624638208653778, 0.19243797229137272, 0.12286778743145987, 0.14108055154792964, 0.11025782267097384, 0.10711334296502173, 0.22432667756220326, 0.23533109488198534, 0.11274991004029289, 0.10290054167853668, 0.11091658263467252, 0.21623609529342502, 0.1163750045816414, 0.178894326381851, 0.11268685717368498, 0.15584117121761665, 0.11223333814996295, 0.1648598091560416, 0.175244681595359, 0.24430159712210298, 0.16641475696815178, 0.16773364244727418, 0.13411880558123812, 0.1645773180644028, 0.16788596083642915, 0.2509217621991411, 0.16176790319150314, 0.2116981739527546, 0.19475575885735452, 0.10407913156086579, 0.25820766342803836, 0.16046813543653116, 0.18861527350964025, 0.5516428803093731, 9.454252738505602, 27.21392311155796, 39.30348739027977, 37.80912257730961, 28.237331695854664, 20.77885441482067, 23.83066065609455, 27.59206362068653, 26.613834612071514, 21.570357643067837, 12.066915594041348, 3.4081974299624562, 1.1710971593856812, 2.0054620876908302, 3.7799939420074224, 14.244162663817406, 8.891965560615063, 12.711387611925602, 9.240608252584934, 6.9003489799797535, 4.010710911825299, 7.887225849553943, 9.972080402076244, 4.37399041838944, 4.007334318011999, 2.76456659194082, 2.477304618805647, 2.493819957599044, 4.228014601394534, 7.691356334835291, 17.00927808880806, 29.64654117822647, 44.09436151385307, 54.448669105768204, 58.324689120054245, 60.224419981241226, 58.14319185912609, 56.270606741309166, 57.75034233927727, 57.30623356997967, 55.8676003664732, 54.34837728738785, 57.50703379511833, 53.89197617769241, 56.738665625452995, 55.85453286767006, 54.080210477113724, 55.74890613555908, 56.21101073920727, 55.4308670014143, 58.954965099692345, 61.142032742500305, 58.04332181811333, 56.015442833304405, 57.12097831070423, 56.64727292954922, 55.77114254236221, 55.466322898864746, 56.9674551486969, 62.272924259305, 60.77686473727226, 59.170390740036964, 57.82946549355984, 58.473021760582924, 56.57939717173576, 48.869740068912506, 43.8411583006382, 35.51167845726013, 29.885365962982178, 16.574769504368305, 4.173772037029266, 1.1662120465189219, 0.6106560293119401, 1.3361103110946715, 3.1896326830610633, 3.586496450006962, 4.51415634714067, 5.540822306647897, 9.106870628893375, 6.1506264097988605, 10.94270696863532, 11.374503448605537, 7.740443525835872, 9.142630510032177, 5.711990771815181, 1.5052804397419095, 2.4809481482952833, 7.740137642249465, 20.339552387595177, 34.27790366113186, 23.27163465321064, 29.236349388957024, 31.256474889814854, 33.6895964294672, 25.127439871430397, 10.324468743056059, 1.8232178105972707, 0.11612763191806152, 0.11719023896148428, 0.19336153054609895, 0.1267232742975466, 0.0935265856969636, 0.15916424134047702, 0.2893763518659398, 0.09898056960082613, 0.302595931570977, 0.2190892820362933, 0.09850206988630816, 0.2329723714501597, 0.1504746568389237, 0.2547968120779842, 0.1600005675572902, 0.14480871555861086, 0.15944143349770457, 0.1403195087914355, 0.1581519519095309, 0.10863463437999599, 0.14896358479745686, 0.214149413513951, 0.1545712526421994, 0.1950838029733859, 0.10854007734451443, 0.13967553240945563, 0.12406865658704191, 0.16952739853877574, 0.14729784918017685, 0.18488688685465604, 0.19213051535189152, 0.07714054387179203, 0.14940354478312656, 0.16196616052184254, 0.21405094536021352, 0.1282353705028072], [0.035112168043269776, 0.018276553564646747, 0.03674304869491607, 0.1001358189387247, 0.026758201274788007, 0.01946745382156223, 0.05499019651324488, 0.030567610047000926, 0.02675797491974663, 0.03422044792387169, 0.026175405691901688, 0.03184740104188677, 0.08745581028051674, 0.02496606120985234, 0.0364059726416599, 0.055033304161042906, 0.014578863065253245, 0.06473224289948121, 0.071342915907735, 0.08120719401631504, 0.03943473297113087, 0.07215912250103429, 0.061452781374100596, 0.07672488922253251, 0.03200879589712713, 0.028619965924008284, 0.10751061461633071, 0.020958769891876727, 0.053189883547020145, 0.034403825193294324, 0.06123527644376736, 0.01078422859791317, 0.0786291214171797, 0.037337212124839425, 0.0117423792835325, 0.04314149344281759, 0.026381060379208066, 0.030283489941211883, 0.051524604350561276, 0.08944754910771735, 0.009501449530944228, 0.02455099100188818, 0.05628573773719836, 0.10217011251370423, 5.714919464662671, 18.57950583100319, 29.415887854993343, 26.54224645346403, 20.26129938662052, 15.838435515761375, 10.641819164156914, 11.91037729382515, 24.38323650509119, 22.877774387598038, 9.32486493140459, 2.6369582768529654, 0.28681386436801404, 0.05410172700067051, 0.22405255789635703, 0.8978768577799201, 3.4549885941669345, 2.808144553564489, 7.8097394574433565, 4.745940109714866, 4.415452843531966, 2.372047654353082, 1.4608577359467745, 1.580017798114568, 1.6279749060049653, 1.744359692092985, 0.5900059780105948, 0.6386275158729404, 0.990582323865965, 3.9587969100102782, 10.099913142621517, 21.45318903028965, 36.74376234412193, 48.25314335525036, 53.56616646051407, 60.053824335336685, 58.38565684854984, 55.67579045891762, 57.5300719588995, 53.68724316358566, 55.684157609939575, 57.46721193194389, 56.76363788545132, 57.81650438904762, 56.03699907660484, 55.18369406461716, 54.3788668513298, 57.54805639386177, 54.43402849137783, 49.54756669700146, 54.66739296913147, 55.24758383631706, 56.99994720518589, 53.826840072870255, 56.327451691031456, 55.40032424032688, 57.407349944114685, 57.10147775709629, 54.1283842921257, 57.54706844687462, 59.45894345641136, 57.171884179115295, 54.14224974811077, 45.649405270814896, 34.5086956769228, 22.048603780567646, 19.054548740386963, 14.439011458307505, 1.9859041809104383, 0.4878569795982912, 0.36379699129611254, 1.2224850081838667, 1.644755161833018, 2.3003051290288568, 2.0657080924138427, 1.993906432762742, 2.5814078701660037, 2.814760711044073, 1.7781955702230334, 4.653073092922568, 3.3879243303090334, 3.3854497130960226, 2.3292429512366652, 0.9451201977208257, 1.9394948962144554, 7.400747453793883, 15.083743762224913, 24.311232268810272, 22.102308198809624, 25.73833119124174, 22.729398049414158, 22.805207781493664, 17.874850742518902, 6.726886862888932, 0.9709645109251142, 0.06614089114009403, 0.11261011910391971, 0.06646568464930169, 0.027792838627647143, 0.08927580871386454, 0.06612120938370936, 0.010212922388745937, 0.02176445097575197, 0.024111914171953686, 0.011876733060489642, 0.12992614618269727, 0.037341917341109365, 0.053011675336165354, 0.0467799132457003, 0.06317836378002539, 0.05635343644826207, 0.04179281444521621, 0.05579950855462812, 0.03633045169408433, 0.018428810726618394, 0.02984183229273185, 0.025562525297573302, 0.02486437213519821, 0.013703391341550741, 0.06636322374106385, 0.042357188067398965, 0.017115159243985545, 0.02512093444238417, 0.07397080145892687, 0.10449002162204124, 0.03079462931054877, 0.044787706865463406, 0.11764395094360225, 0.04772727217641659, 0.082372759206919, 0.036084897292312235, 0.09579531630151905, 0.07451678466168232, 0.04148284533584956, 0.09070827247342095, 0.08277632427052595, 0.06231839273823425, 0.09001350350445136, 0.023094253447197843, 0.004916835969197564, 0.009152531583822565, 0.04468703824386466, 0.03787673493206967, 0.08443982602329925, 0.04136574556468986, 0.017348958026559558, 0.05191163807467092, 0.03981337671575602, 0.03378654015250504, 0.006567109867319232, 0.0464192517392803, 0.07259413236170076, 0.048147817578865215, 0.041195682424586266, 0.06328863950329833, 0.01464967508582049, 0.04553060411126353, 0.02595751855551498, 0.033091125515056774, 0.036059029735042714, 0.036019784965901636, 0.021766295212728437, 0.05243455532763619, 0.02849961369065568, 0.09480207780143246, 0.05094779975479469, 0.05271290152450092, 0.04179303337878082, 0.023383479529002216, 0.07293273723917082, 0.05754936661105603, 0.017439668881706893, 0.04104254025151022, 0.024408582139585633, 0.014965701975597767, 0.5956166738178581, 9.02401702478528, 23.886909037828445, 33.84972743690014, 30.82546591758728, 23.158643916249275, 16.189941354095936, 14.184100236743689, 19.260978363454342, 26.64235208183527, 22.847336120903492, 10.603749956935644, 2.145659839734435, 0.21776284149382263, 0.15562922868411988, 0.5502845125738531, 1.5300281555391848, 3.452035915106535, 3.661500862799585, 11.63081394508481, 11.840010769665241, 14.137724675238132, 3.9848480746150017, 4.286485388875008, 2.857892671599984, 2.7523977449163795, 2.5365816755220294, 1.3139326823875308, 1.4045844180509448, 2.153670284897089, 6.151989111676812, 12.926590014249086, 23.995691500604153, 39.998724684119225, 51.233369037508965, 54.99294050037861, 60.18191546201706, 57.29253530502319, 53.99762950837612, 56.890273690223694, 55.00004231929779, 55.63696414232254, 56.90923847258091, 56.80244900286198, 59.23464149236679, 55.865909457206726, 56.17867827415466, 53.32880459725857, 55.04022516310215, 55.83907149732113, 52.08032079041004, 56.432470455765724, 57.920026034116745, 57.45442941784859, 55.414467081427574, 56.094558387994766, 56.01551502943039, 57.21138685941696, 57.021526247262955, 56.68855391442776, 59.8297655582428, 60.36311253905296, 58.88791389763355, 55.285779386758804, 49.698486998677254, 38.981211483478546, 26.706773824989796, 22.92716793715954, 18.634504079818726, 3.8533577928319573, 0.6293860555160791, 0.6613078457303345, 2.2822199994698167, 2.8312411392107606, 2.154995226301253, 3.8480050675570965, 2.6430650241672993, 4.3061588332057, 3.841981440782547, 3.43918832950294, 4.345664838328958, 2.8741367999464273, 1.1879348871298134, 0.5491920711938292, 0.4803455842193216, 1.1317488458007574, 7.737741395831108, 18.646501936018467, 29.663351476192474, 28.470775969326496, 28.310266882181168, 27.423077188432217, 25.63005030155182, 23.039484210312366, 10.061070676892996, 1.5448941453360021, 0.08084464745479636, 0.029410536881187, 0.04167821942246519, 0.02116060994012514, 0.03222027087758761, 0.045085708843544126, 0.05631743115372956, 0.015278269529517274, 0.021570230928773526, 0.04183006283710711, 0.014498588661808753, 0.03379334564669989, 0.005627992022709805, 0.024053293782344554, 0.026660864896257408, 0.03481136074697133, 0.00408617929679167, 0.060020503151463345, 0.02735168378421804, 0.0386688736762153, 0.07180268381489441, 0.050852856802521273, 0.10214535446721129, 0.04285195936972741, 0.03143845169688575, 0.029399413942883257, 0.035715916310437024, 0.05295451883284841, 0.016360109329980332, 0.09568824665620923, 0.07121199363609776, 0.04120842510019429, 0.028571744878718164, 0.012870156169810798, 0.033636511288932525, 0.041051442312891595, 0.045761734872939996, 0.1777321528061293, 0.17348694935208187, 0.10102972097229213, 0.2240166231058538, 0.10641317858244292, 0.1473782237735577, 0.1394734752830118, 0.11994972956017591, 0.13522190420189872, 0.11169390068971552, 0.08455090326606296, 0.15909461304545403, 0.2217862763791345, 0.112777903850656, 0.1362578829866834, 0.15730962913949043, 0.07405686832498759, 0.11285684609902091, 0.1339897164143622, 0.2522219158709049, 0.23904659785330296, 0.16116627375595272, 0.17183390446007252, 0.1831018435768783, 0.12932562996866181, 0.19581041007768363, 0.20837765681790188, 0.13691238302271813, 0.17965110921068117, 0.09334941278211772, 0.1505070144776255, 0.15811065881280228, 0.10869495614315383, 0.2360491524450481, 0.15924564009765163, 0.17083452839870006, 0.10030111749074422, 0.22543323459103703, 0.2268845637445338, 0.1260303458548151, 0.11999586888123304, 0.14824275160208344, 0.1394236771739088, 0.4616045148577541, 8.07659201323986, 25.156318321824074, 39.88576054573059, 38.75369109213352, 31.837275624275208, 26.29621345549822, 17.810035720467567, 19.246455542743206, 31.732441149652004, 28.8778006285429, 12.974090315401554, 4.163459865376353, 0.6254773715045303, 0.3944692719960585, 3.047232711687684, 5.66214457154274, 10.166577715426683, 8.019508626312017, 14.817861579358578, 8.347336035221815, 8.678665906190872, 6.201091501861811, 4.820252722129226, 3.6014032876119018, 3.0261089326813817, 3.956515844911337, 1.5684795984998345, 1.4867770951241255, 1.7159837647341192, 5.253302659839392, 12.112800031900406, 24.322099685668945, 39.623388424515724, 52.016336023807526, 54.6659604460001, 60.5490555614233, 58.426922634243965, 55.84517776966095, 58.297695368528366, 55.18350027501583, 55.007265731692314, 59.0577457845211, 58.523882031440735, 57.87106566131115, 57.42015525698662, 58.01082216203213, 53.96736033260822, 58.38871568441391, 56.95761747658253, 54.75028932094574, 58.669307827949524, 57.70811140537262, 57.90228858590126, 53.51406365633011, 57.79432497918606, 57.119146808981895, 57.319000884890556, 56.70233577489853, 57.55523040890694, 60.50519831478596, 60.87072350084782, 58.746854066848755, 55.145095735788345, 47.80944116413593, 39.20785032212734, 29.895481020212173, 21.96403931826353, 17.60973896831274, 4.876026604324579, 0.4928340594051406, 1.1490507423877716, 3.2731365272775292, 5.131510170176625, 5.293509252369404, 6.175581095740199, 6.089279651641846, 8.75965191051364, 7.975941114127636, 6.107611767947674, 9.745287671685219, 9.297160618007183, 7.615521904081106, 4.752290993928909, 1.7203128011897206, 2.8412210661917925, 9.7194604575634, 19.4267862662673, 33.56163449585438, 32.98871263861656, 35.172789841890335, 35.80240085721016, 31.765062399208546, 24.325487203896046, 9.846774525940418, 1.4487911271862686, 0.1437160515342839, 0.22769865521695465, 0.24398805457167327, 0.25594390521291643, 0.14642429683590308, 0.16041526483604684, 0.11294147319858894, 0.10197547686402686, 0.08748635707888752, 0.1264747735694982, 0.2603668678784743, 0.1774098677560687, 0.13852397154551, 0.1352562359534204, 0.12934672180563211, 0.3867874201387167, 0.12899828347144648, 0.1419772143708542, 0.14324107702123, 0.14907486242009327, 0.21808321180287749, 0.07787880269461311, 0.21727404819102958, 0.20811233902350068, 0.1350468909367919, 0.11134970744024031, 0.13969080580864102, 0.21534021914703771, 0.17543621506774798, 0.18969682016177103, 0.16272065753582865, 0.11478274158434942, 0.30778556247241795, 0.10746731772087514, 0.23803003365173936, 0.10917479914496653, 0.25848694844171405], [0.0044542469731823076, 0.08525022902176715, 0.01510973799668136, 0.05613192763121333, 0.05926939033088274, 0.03967443924921099, 0.027451515634311363, 0.03106745207333006, 0.04886676942987833, 0.021501263145182747, 0.04887761962891091, 0.07517881007515825, 0.002207985121458478, 0.12896515399916098, 0.004101786198589252, 0.009275262400478823, 0.035759409875026904, 0.014135427045403048, 0.09249256618204527, 0.0561132997245295, 0.07695445034187287, 0.0540085095417453, 0.10011543956352398, 0.043909660817007534, 0.06310597469564527, 0.073135514248861, 0.04722803314507473, 0.04478569564525969, 0.015905593973002397, 0.03524232961353846, 0.030172702136042062, 0.04770837338583078, 0.039447991439374164, 0.10312631784472615, 0.050401931584929116, 0.05733557612984441, 0.027124530934088398, 0.08903446228941903, 0.05651412626320962, 0.0699301042186562, 0.0388608672801638, 0.03991953351942357, 0.0588445553148631, 0.0282704106575693, 0.24268353707157075, 5.398077741265297, 17.093996442854404, 26.907190270721912, 27.15079329907894, 21.700759045779705, 12.695622257888317, 11.843533180654049, 14.89140473306179, 21.002783998847008, 26.490162648260593, 17.770854122936726, 5.019049979746342, 1.0446781804785132, 0.415913540055044, 0.7151671056635678, 0.8680480427574366, 4.028518656268716, 8.563721124082804, 19.256215319037437, 24.081884175539017, 1.4932413795031607, 3.8970067631453276, 2.288296823389828, 3.5367091465741396, 2.3235005093738437, 0.660503120161593, 1.0205665742978454, 0.5420491076074541, 0.8300699118990451, 0.8087959815748036, 4.860662603750825, 15.804503336548805, 27.901133336126804, 40.60810178518295, 49.89287696778774, 55.83427615463734, 57.58329950273037, 57.49742791056633, 56.267373114824295, 55.33883213996887, 60.375188291072845, 58.20250667631626, 59.04984600841999, 58.896372243762016, 53.500787168741226, 56.22687108814716, 48.328884690999985, 54.20533776283264, 45.447947680950165, 50.42952597141266, 63.310526981949806, 58.043439611792564, 58.412232622504234, 57.015560567379, 57.20852941274643, 55.209262892603874, 57.57536172866821, 57.82760739326477, 52.767308726906776, 52.907999977469444, 51.507277339696884, 43.065152540802956, 29.780632182955742, 14.964015036821365, 13.638788647949696, 5.77646903693676, 0.5293471610639244, 0.23103155137505382, 0.10697396020987071, 0.3245968697592616, 1.9164024665951729, 3.8846890116110444, 1.519468640908599, 2.855721563100815, 1.434952151030302, 2.7815241320058703, 2.634007972665131, 1.6914951475337148, 3.0921947490423918, 2.339246151968837, 1.7124307178892195, 1.1053689988330007, 1.4199518621899188, 7.209493741393089, 19.64393511414528, 19.846135564148426, 19.198380522429943, 20.46320155262947, 25.205464884638786, 28.00854977220297, 20.259526781737804, 7.366530289873481, 1.2839996698312461, 0.08887854448403232, 0.10464872990269214, 0.015065379830048187, 0.07766309005091898, 0.02866678245482035, 0.048499020413146354, 0.04768046492245048, 0.013883044885005802, 0.011264542863500537, 0.011929934844374657, 0.01846404604293639, 0.03091764956479892, 0.08677093414007686, 0.02263135367684299, 0.0519941945822211, 0.06855448897113092, 0.04562321300909389, 0.016704751578799915, 0.04881472632405348, 0.005441358580355882, 0.04732176639663521, 0.03158235042064916, 0.038358759848051704, 0.05250807989796158, 0.039614781708223745, 0.01852564986620564, 0.04089931317139417, 0.02025215253524948, 0.05820392972964328, 0.020614680543076247, 0.07430032244883478, 0.01922615192597732, 0.04843488772166893, 0.03891028689395171, 0.013853927648597164, 0.09669297360233031, 0.05046773781941738, 0.019409252745390404, 0.03325393045088276, 0.037575630776700564, 0.037309485487639904, 0.04750852414872497, 0.05541718004678842, 0.0436667929898249, 0.02889753657655092, 0.047591841357643716, 0.023332607161137275, 0.013477003831212642, 0.02462866046698764, 0.07633622648427263, 0.0290668056186405, 0.05049760184192564, 0.035703270114026964, 0.02439036612486234, 0.026730756653705612, 0.025517853573546745, 0.032407492471975274, 0.05310875938448589, 0.07028597887256183, 0.02848342188372044, 0.04897317856375594, 0.02239106110209832, 0.022689066790917423, 0.07691579186939634, 0.012855600798502564, 0.016619289563095663, 0.021940824226476252, 0.04548863937088754, 0.021212413703324273, 0.02430654611089267, 0.02454591100104153, 0.050354248596704565, 0.025469652937317733, 0.05701002934074495, 0.0499390466575278, 0.013416326764854603, 0.033817242801887915, 0.039883877034299076, 0.0875020980311092, 0.06017404608428478, 0.06114684583735652, 0.011780493205151288, 0.5606941133737564, 8.398625683039427, 21.661801636219025, 33.719671815633774, 32.114113569259644, 25.35352014005184, 14.267688151448965, 11.302806995809078, 20.192296989262104, 27.97920774668455, 27.55227405577898, 16.348846927285194, 5.032839914783835, 0.8555507508572191, 0.1134710326732602, 0.2225714983069338, 0.3061086649540812, 3.9594590244814754, 12.028036080300808, 17.884310334920883, 14.218768626451492, 5.006649820134044, 7.708056438714266, 2.2385710291564465, 4.342065481469035, 3.376866211183369, 1.8683167593553662, 1.4696225593797863, 1.1457087029702961, 1.4260234613902867, 2.0930424006655812, 7.300273245200515, 17.70369842648506, 31.00703537464142, 42.594931572675705, 51.876492127776146, 55.10630361735821, 58.54804873466492, 55.92742435634136, 57.46912322938442, 54.994772002100945, 60.735473558306694, 58.766293823719025, 60.437512546777725, 59.13504123687744, 58.27330067753792, 54.75781291723251, 48.298417925834656, 57.900791466236115, 51.49693049490452, 54.99450221657753, 61.306126937270164, 60.068358555436134, 58.973204120993614, 58.22891145944595, 56.426185593008995, 57.101181373000145, 59.12860818207264, 56.90807953476906, 53.931535854935646, 55.17555110156536, 52.174316346645355, 44.88269001245499, 33.004998564720154, 19.26914982497692, 17.10366692394018, 6.7021416407078505, 1.7308577103540301, 0.13018617988564074, 0.4401539533864707, 1.5264504100196064, 3.598815626464784, 4.596816636621952, 4.360689232125878, 3.3169013913720846, 3.864047806710005, 3.728975267149508, 3.686724384315312, 3.1322277383878827, 2.764028920792043, 1.2207399518229067, 0.824845964089036, 0.1492308618617244, 1.523188166320324, 8.086906559765339, 21.08986582607031, 20.706553794443607, 23.591339997947216, 22.968082241714, 30.89977853000164, 30.50666682422161, 25.13774871826172, 11.428051125258207, 2.2503731958568096, 0.09496460814261809, 0.03050323615752859, 0.051223433401901275, 0.018420949527353514, 0.10804835255839862, 0.018595087058201898, 0.08412494018557481, 0.030855270197207574, 0.05292242094583344, 0.018931125960079953, 0.02600710515253013, 0.019190070561307948, 0.07713734521530569, 0.030796352948527783, 0.019878852253896184, 0.04523890667769592, 0.03367133656865917, 0.025341827276861295, 0.012075133254256798, 0.05083654810732696, 0.028631213172047865, 0.0410568637016695, 0.018115681923518423, 0.03659858964965679, 0.026954631066473667, 0.0421935816120822, 0.057834061881294474, 0.04971993497747462, 0.008685165939823491, 0.06570115379872732, 0.03260564219090156, 0.017385011560691055, 0.030249004194047302, 0.07961321665789, 0.015330788537539775, 0.07762761539197527, 0.02112885529641062, 0.04689158791734371, 0.1036669872701168, 0.1962522996473126, 0.12736358447000384, 0.1938241854077205, 0.12960967957042158, 0.16271185566438362, 0.10119654092704877, 0.1297812641132623, 0.1794378159684129, 0.20365951233543456, 0.15536318358499557, 0.16846850223373622, 0.14260364638175815, 0.2517413010355085, 0.1592954678926617, 0.09170118442852981, 0.13404288387391716, 0.09290701855206862, 0.1320728231803514, 0.10944706344162114, 0.1946379354922101, 0.09227630434907041, 0.2337692747823894, 0.07970631908392534, 0.1135836387402378, 0.13894824252929538, 0.11714840409695171, 0.14445110427914187, 0.11673982211505063, 0.12307026016060263, 0.12242438388057053, 0.09794175581191666, 0.17695736547466367, 0.32064704108051956, 0.12376056882203557, 0.11836093981401064, 0.11341913428623229, 0.11755211016861722, 0.15151053172303364, 0.10612162586767226, 0.20796085183974355, 0.19228552031563595, 0.18915447348263115, 0.07676152163185179, 0.5102287244517356, 7.32018512673676, 22.927690409123898, 39.81010660529137, 41.351786479353905, 33.948107957839966, 22.759539932012558, 18.758480027318, 22.91128098964691, 29.681334011256695, 35.653144866228104, 20.852912440896034, 7.133282655850053, 1.6367235803045332, 1.2480958714149892, 1.4473812840878963, 5.37207193672657, 9.068093709647655, 14.214211720973253, 30.811062790453434, 42.76061028242111, 13.551168199628592, 8.359351940453053, 7.079635234549642, 8.077495414763689, 5.764277866110206, 2.109720418229699, 2.293340340256691, 0.958538583945483, 1.1935211811214685, 1.361326826736331, 5.73143195360899, 17.43490654975176, 28.890193663537502, 43.53169530630112, 50.4184115678072, 56.8684096634388, 59.135018438100815, 56.50031581521034, 57.78447970747948, 55.6443889439106, 62.422822415828705, 60.489315167069435, 60.15568166971207, 59.107466116547585, 56.4027788490057, 57.096165642142296, 50.78529328107834, 57.43521384894848, 52.70727574825287, 55.544157922267914, 62.25021667778492, 58.20718042552471, 58.49476419389248, 58.98253262042999, 57.75631941854954, 58.102385848760605, 60.05774572491646, 58.647398203611374, 54.680620059370995, 55.11050999164581, 54.16154891252518, 47.80175797641277, 33.97389717400074, 21.326823011040688, 15.709855165332556, 5.415828488767147, 1.3611015700735152, 0.7712287036702037, 1.0402740980498493, 2.1213112212717533, 6.108726058155298, 10.277987737208605, 5.314507400617003, 8.433541059494019, 5.904579637572169, 8.929117117077112, 9.625761285424232, 5.273322835564613, 7.737678699195385, 5.7329366728663445, 3.189803436398506, 1.633424407336861, 2.276084991171956, 10.432787630707026, 23.57514336705208, 26.815704479813576, 29.384015165269375, 30.716366171836853, 37.26179614663124, 37.22270004451275, 27.79278215020895, 11.063365694135427, 2.0673417672514915, 0.13735117041505873, 0.17740569688612595, 0.1015398658637423, 0.12062908412190154, 0.28337329742498696, 0.12623421382158995, 0.20059384871274233, 0.12707365705864504, 0.209704973094631, 0.10578178902505897, 0.09920544776832685, 0.11843232699902728, 0.31120983185246587, 0.16330155136529356, 0.1226871412654873, 0.21581549051916227, 0.12606773525476456, 0.08389257374801673, 0.1660770204034634, 0.1430197388981469, 0.1301351943402551, 0.14881223120028153, 0.18069844285491854, 0.09036372299306095, 0.15380826545879245, 0.16632866783766076, 0.15494251943891868, 0.12596019805641845, 0.12999973754631355, 0.16925032512517646, 0.2087979350471869, 0.13742269860813394, 0.17788179946364835, 0.1905230976990424, 0.12254022571141832, 0.21087574074044824, 0.13537058606743813, 0.17717539361910895], [0.029762157173536252, 0.020499608690442983, 0.03667018834676128, 0.017715883259370457, 0.007285663277798449, 0.020037310059706215, 0.064842904539546, 0.0025461862242082134, 0.0251312187538133, 0.04968453082256019, 0.005985853313177358, 0.06535000662552193, 0.02269161050207913, 0.03142267363728024, 0.05522048122656997, 0.056553415561211295, 0.04231576880556531, 0.030802689034317154, 0.05253248913504649, 0.0815125803637784, 0.032159169859369285, 0.022899615942151286, 0.023469063999073114, 0.016299206836265512, 0.05393134102632757, 0.011294605410512304, 0.027805453282780945, 0.045636430659214966, 0.037813158851349726, 0.03373744337295648, 0.016080664754554164, 0.04392517170344945, 0.024097648238239344, 0.06532535990118049, 0.04687807340815198, 0.08558146437280811, 0.023400958962156437, 0.08095774333924055, 0.09093283151742071, 0.09186257928377017, 0.04750695079565048, 0.027122371284349356, 0.05307131432346068, 0.042696650125435553, 0.10330629607778974, 0.39708831114694476, 4.7627361584454775, 12.645604591816664, 23.762167431414127, 29.21070646494627, 23.798119202256203, 17.470387145876884, 11.246408522129059, 13.207213506102562, 19.922948442399502, 25.348620302975178, 17.706806659698486, 5.482678776606917, 2.740845652297139, 0.5368505709338933, 0.5288437474519014, 2.743288208730519, 17.620737478137016, 17.63661302626133, 13.277813717722893, 1.9066476775333285, 4.189378749579191, 1.6403323179110885, 2.4000132037326694, 0.909748311387375, 1.8599192099645734, 0.49229971307795495, 1.6183204553090036, 0.5875758896581829, 0.6896592525299639, 0.740696273278445, 2.8717360412701964, 12.169369496405125, 20.807706266641617, 29.571920782327652, 39.496665224432945, 49.20883767306805, 55.71640267968178, 56.51652194559574, 57.29929134249687, 57.4566712975502, 59.714323952794075, 59.785095155239105, 58.94037388265133, 45.213450863957405, 47.918537110090256, 36.793722063302994, 53.4870433062315, 54.297558814287186, 54.24237057566643, 61.593053340911865, 59.6100689470768, 61.183974891901016, 57.608970925211906, 60.59572845697403, 59.175167083740234, 61.54072254896164, 59.517471715807915, 58.5456358641386, 47.44276084005833, 39.710126370191574, 21.3745104521513, 11.037996355444193, 5.977995973080397, 2.763933688402176, 0.20222872582962736, 0.4628807713743299, 0.04515123677265365, 0.28130151797086, 1.3795785536058247, 3.2227830542251468, 1.8795186770148575, 2.5670845387503505, 2.217058246023953, 3.150693797506392, 2.169273910112679, 2.713782317005098, 3.1361702643334866, 1.4926784159615636, 0.8408385934308171, 0.4332189989509061, 2.84325348213315, 8.475525006651878, 17.647244855761528, 20.858034566044807, 22.17750996351242, 17.535312362015247, 22.905153818428516, 24.584878385066986, 24.544811435043812, 8.151320703327656, 1.4567429129965603, 0.06132316528237425, 0.08381043284316547, 0.01877756632893579, 0.06396540396963246, 0.11665342870401219, 0.05494171200552955, 0.042683948267949745, 0.039623238480999134, 0.04563594084174838, 0.04527118268015329, 0.03435872116824612, 0.026662319505703636, 0.06015818638843484, 0.08001638838322833, 0.07476509985281155, 0.03003835114213871, 0.027237517351750284, 0.030796571882092394, 0.022310599306365475, 0.07702620117925107, 0.0639514738577418, 0.05373551794036757, 0.002197396993324219, 0.029315085557755083, 0.009166121235466562, 0.053242995345499367, 0.026736729087133426, 0.060455067723523825, 0.013482937301887432, 0.013901163492846536, 0.0018006737195719325, 0.0053220472091197735, 0.06514996814075857, 0.027255957866145764, 0.015342244514613412, 0.04048341361340135, 0.02136387676728191, 0.1330663956468925, 0.0461488873406779, 0.04045362009492237, 0.031206155763356946, 0.02070515947707463, 0.03281095363490749, 0.06699533318169415, 0.053385728897410445, 0.014978352810430806, 0.05705230949388351, 0.04669301888498012, 0.011484716742415912, 0.05021400866098702, 0.006340037725749426, 0.07083429984049872, 0.09447125063161366, 0.035826006496790797, 0.050564621487865224, 0.045196633946034126, 0.06313197955023497, 0.015950265697028954, 0.016506935826328117, 0.028898839045723435, 0.030912009242456406, 0.06093177886214107, 0.02783115385682322, 0.018293398461537436, 0.06350916126393713, 0.022433391350205056, 0.10055215636384673, 0.04214640699501615, 0.03834238807030488, 0.05994177241518628, 0.019242330745328218, 0.06884604168590158, 0.045814568366040476, 0.014810354696237482, 0.07326610255404375, 0.10088838636875153, 0.02330043320398545, 0.03537542637786828, 0.051310843555256724, 0.0840141301159747, 0.047442539798794314, 0.045983065574546345, 0.0022002936884746305, 0.05041536445787642, 0.6458039057906717, 7.49882779084146, 17.020310796797276, 29.121380858123302, 32.73226819932461, 27.073283158242702, 17.04103108495474, 9.096083957701921, 14.84049316495657, 29.628355354070663, 33.30927483737469, 17.09019474685192, 7.065513292327523, 1.609021166805178, 0.5700779473409057, 0.3638126654550433, 1.3644375535659492, 3.5849724942818284, 6.558150742202997, 4.149779174476862, 4.4677437376230955, 10.129811838269234, 3.1548082642257214, 4.247401161119342, 4.23168140463531, 4.152279440313578, 2.457461371086538, 2.873800517991185, 1.8265837174840271, 1.1952483071945608, 1.4544958085753024, 4.749045493081212, 14.068338498473167, 23.53230446577072, 34.309825748205185, 43.723151832818985, 50.98592631518841, 56.09480157494545, 57.251615300774574, 59.020625576376915, 57.474974915385246, 61.02458864450455, 59.74575586616993, 59.193440303206444, 53.30986641347408, 49.60889920592308, 38.9779132604599, 56.82701848447323, 58.65013025701046, 57.11732670664787, 60.16214892268181, 61.42967730760574, 61.33658990263939, 59.93038035929203, 59.41108502447605, 59.19321611523628, 60.12333020567894, 60.63218750059605, 58.10971945524216, 50.668248161673546, 45.29610402882099, 27.920635789632797, 14.677227325737476, 8.265325985848904, 3.5930249746888876, 2.0670862309634686, 1.006706461776048, 0.2708152087870985, 1.2379163363948464, 1.9440539390780032, 3.8416313845664263, 5.496868165209889, 4.242209689691663, 4.840281447395682, 5.996524253860116, 4.608231224119663, 2.2239349270239472, 2.1300730761140585, 1.41013105167076, 0.23311216238653287, 0.2907610510010272, 2.968679051846266, 9.157629255205393, 20.443600304424763, 24.859839230775833, 23.114003911614418, 19.569869488477707, 25.030402578413486, 30.124466232955456, 29.635189287364483, 12.514733914285898, 2.7151310071349144, 0.07046305530820973, 0.06326905422611162, 0.029939921951154247, 0.04035438752907794, 0.15312848787289113, 0.05926884856307879, 0.05909650702960789, 0.04781949886819348, 0.02687461270397762, 0.027754914881370496, 0.02146913371689152, 0.04107724307687022, 0.0625298306113109, 0.030036809330340475, 0.031107711729418952, 0.04900275314867031, 0.02611085925309453, 0.057874204649124295, 0.016179969679797068, 0.05783496730145998, 0.017750786464603152, 0.0340748830785742, 0.04889990632364061, 0.027142702419951092, 0.04081317951204255, 0.027184270111320075, 0.05739429856475908, 0.02578938871010905, 0.01627191621082602, 0.047944903271854855, 0.025793774802878033, 0.08356969497981481, 0.033573554901522584, 0.050491256479290314, 0.015003491207608022, 0.08308827862492763, 0.04797765053808689, 0.05447510520752985, 0.04800649039680138, 0.19693169131642208, 0.08548227633582428, 0.10446132277138531, 0.11384485245798714, 0.1713880369788967, 0.1100260647945106, 0.21255526546156034, 0.0845744219259359, 0.12356548046227545, 0.08580246852943674, 0.11687263686326332, 0.14501034223940223, 0.17935684765689075, 0.15885452827205881, 0.12367606788757257, 0.1624750066548586, 0.15392166562378407, 0.12483529513701797, 0.14838996401522309, 0.08721913938643411, 0.07559548888821155, 0.13306660344824195, 0.12090805743355304, 0.09883732025627978, 0.11484468865091912, 0.09216045509674586, 0.08698359655681998, 0.25878057174850255, 0.1139517588308081, 0.11258908663876355, 0.1759500039042905, 0.1415234207524918, 0.263006390305236, 0.14238305040635169, 0.13436129491310567, 0.19140135525958613, 0.11306280692224391, 0.12476965959649533, 0.18035381915979087, 0.21358621248509735, 0.1810853838105686, 0.1261892545153387, 0.14215855073416606, 0.13342323509277776, 0.2314947108970955, 0.5646188277751207, 6.560825798660517, 18.191666342318058, 34.49954576790333, 41.23801298439503, 35.719595700502396, 27.72562835365534, 18.21926426142454, 20.589816458523273, 29.70160212367773, 34.70234088599682, 22.816314585506916, 8.828149884939194, 3.536556917242706, 1.1042625457048416, 1.4261270058341324, 6.832504095509648, 26.8179976567626, 30.779689773917198, 26.446020416915417, 6.380409579724073, 8.208975959569216, 5.958959944546223, 6.074121790006757, 5.848394902423024, 6.666737515479326, 3.5738053685054183, 4.604957699775696, 2.567041078582406, 1.7042349139228463, 1.4354666671715677, 4.076833063736558, 13.60085528343916, 23.291414491832256, 34.181043058633804, 40.77650494873524, 51.141056790947914, 57.28950686752796, 58.122752755880356, 59.74959746003151, 58.99302765727043, 62.13073968887329, 59.363830760121346, 59.91847939789295, 53.558266684412956, 49.904481545090675, 41.96454539895058, 56.73521541059017, 59.54545721411705, 57.625211253762245, 60.780561938881874, 61.96898616850376, 61.884980276227, 59.40166153013706, 60.12327700853348, 58.66644278168678, 61.823966950178146, 60.81534147262573, 59.381701201200485, 50.5393210798502, 45.02014763653278, 26.529311947524548, 15.448278151452541, 7.08605688996613, 3.413130990229547, 1.3951262505725026, 0.999050703831017, 0.3807215206325054, 1.1710893223062158, 3.109332541935146, 7.069504503160715, 7.203804971650243, 7.974550388753414, 7.59672811254859, 7.507104221731424, 8.007620964199305, 6.5084646083414555, 8.619504980742931, 4.396176477894187, 2.0651328982785344, 0.831450306577608, 4.232286047190428, 10.283183008432388, 23.404494524002075, 28.639883995056152, 29.214396066963673, 26.894618645310402, 32.88943536579609, 36.599202901124954, 31.53397209942341, 12.273626402020454, 2.019665250554681, 0.15142217162065208, 0.1413459435570985, 0.0866614599362947, 0.21173038316192105, 0.3860293608158827, 0.1931843056809157, 0.19124214973999187, 0.1333001721650362, 0.10663527369615622, 0.11416458452004008, 0.15240481967339292, 0.12671384902205318, 0.23244480835273862, 0.19383880571695045, 0.21494754881132394, 0.16986561007797718, 0.13322174199856818, 0.1874795649200678, 0.1339415361871943, 0.16687413153704256, 0.15808227908564731, 0.17161841446068138, 0.0735766245634295, 0.08285620162496343, 0.17393939226167277, 0.11198730135220103, 0.12261113792192191, 0.15317925077397376, 0.189732636208646, 0.12867187208030373, 0.11783848269260488, 0.1217016062582843, 0.19651926500955597, 0.201084052096121, 0.07458488413249142, 0.22793183801695704, 0.13346909981919453, 0.1926850332529284, 0.10574224739684723], [0.03224080239306204, 0.008058574367169058, 0.013802274170302553, 0.06504291333840229, 0.0394936854718253, 0.058523687766864896, 0.027322188980178908, 0.04986870218999684, 0.02345336015423527, 0.031703261120128445, 0.0717767680180259, 0.04320107305829879, 0.01557437346491497, 0.07416137013933621, 0.028158504064776935, 0.013984842498757644, 0.023260112320713233, 0.029410477509372868, 0.04148313106270507, 0.06654674944002181, 0.042824091724469326, 0.056669802870601416, 0.02171043561247643, 0.019707373467099387, 0.07513770993682556, 0.04010672171716578, 0.07182894842117094, 0.032605623637209646, 0.06030464552168269, 0.014645546889369143, 0.05616892740363255, 0.0047794955116842175, 0.04698182936408557, 0.03062620817217976, 0.057037036094698124, 0.015060017813084414, 0.06570736557478085, 0.021701056721212808, 0.02424491260171635, 0.021034092314948794, 0.08536250854376704, 0.047854335280135274, 0.06295410901657306, 0.01269618562218966, 0.05121050890011247, 0.03264771083195228, 0.1464705474791117, 2.1702400082722306, 9.376478511840105, 24.08687710762024, 29.610650204122066, 28.64521700888872, 25.196221880614758, 20.393070615828037, 15.267497152090073, 26.392293199896812, 37.18366853892803, 30.598760582506657, 15.449817068874836, 4.364168420433998, 0.7990066974889487, 0.9353781142272055, 1.9710812950506806, 3.7226096587255597, 2.330728671513498, 3.088244148530066, 18.72554339468479, 0.9731452376581728, 3.0366277182474732, 3.007982005365193, 2.755139535292983, 2.118702423758805, 2.493386068381369, 1.434154906310141, 0.618591665988788, 0.19663275423226878, 0.1213311187166255, 0.7977934938389808, 3.773274002596736, 9.076419062912464, 15.561378132551908, 28.387254551053047, 38.612384274601936, 45.964586958289146, 50.349635258316994, 55.7435218244791, 57.07126557826996, 59.31024603545666, 59.96061913669109, 38.89449633657932, 35.49221210181713, 25.20527869462967, 48.684549406170845, 53.664949759840965, 45.765565037727356, 63.059649243950844, 59.87198889255524, 59.42835129797459, 59.071048870682716, 57.4079655110836, 56.39510326087475, 56.54974356293678, 49.25937116146088, 38.71725104749203, 25.590066947042942, 15.135058108717203, 7.493045451119542, 2.1867774333804846, 0.9956006670836359, 0.16112775629153475, 1.7615788243710995, 1.337364837527275, 0.3546360391192138, 0.41889421292580664, 2.4378648726269603, 3.015997912734747, 4.558787327259779, 3.960695620626211, 3.165019741281867, 4.17899533174932, 2.6292822137475014, 1.0230416664853692, 1.2681235279887915, 1.3666750397533178, 1.210650543216616, 4.951087776571512, 10.749131105840206, 17.54929941147566, 18.00195772200823, 19.567999988794327, 13.050635308027267, 20.992484651505947, 22.520221173763275, 22.29136135429144, 10.052556283771992, 1.6461772355251014, 0.1634229815681465, 0.07241596496896818, 0.0682353060983587, 0.014662812955066329, 0.06470217849710025, 0.01951403286511777, 0.046002610033610836, 0.07183616951806471, 0.10416493867523968, 0.022185527013789397, 0.014204295566742076, 0.040084702195599675, 0.024596031944383867, 0.0855645582487341, 0.0571998002124019, 0.047463186347158626, 0.029218418967502657, 0.01675478160905186, 0.03718091582413763, 0.09056426613824442, 0.030576285753340926, 0.0903903364087455, 0.019615608762251213, 0.09060371128725819, 0.053547331554000266, 0.05816642900754232, 0.014820911746937782, 0.10717576500610448, 0.014942440284357872, 0.019991313602076843, 0.053100543809705414, 0.07203286833828315, 0.041510356750222854, 0.043608193009276874, 0.0904796613031067, 0.03678904700791463, 0.025219378476322163, 0.13292798510519788, 0.04326601840148214, 0.07004425395280123, 0.006688018247587024, 0.039031527849147096, 0.055550146935274825, 0.010217599774478003, 0.06693812843877822, 0.02418568550638156, 0.021227881916274782, 0.05164965623407625, 0.048547070764470845, 0.037752714633825235, 0.023339253093581647, 0.013512448804249289, 0.07485812064260244, 0.0450406975869555, 0.04172101536823902, 0.008245078861364163, 0.049816161845228635, 0.02388596360106021, 0.031681720283813775, 0.048033909042715095, 0.03974783765443135, 0.05120879453897942, 0.0322001104359515, 0.03295321963378228, 0.05147210853465367, 0.019109688546450343, 0.05941174167674035, 0.03948598568968009, 0.050809340973501094, 0.018012976106547285, 0.08116128476103768, 0.01348304398561595, 0.03952138984459452, 0.08328653595526703, 0.07033189554931596, 0.015003117350715911, 0.019501807837514207, 0.03142658846627455, 0.01984403996175388, 0.05666508281137794, 0.04803198688023258, 0.06448248794185929, 0.09452892292756587, 0.01590369221958099, 0.06642433218075894, 0.03836078962194733, 0.2803840453270823, 3.8124643871560693, 13.229204826056957, 29.046445079147816, 33.528420478105545, 32.497733384370804, 22.11184188723564, 16.684410721063614, 15.894792191684246, 30.783141888678074, 39.675647020339966, 29.020152390003204, 17.322622574865818, 4.407951571047306, 0.7328577095177025, 0.2567987405927852, 0.6095464888494462, 1.9789365422911942, 2.0302165718749166, 3.2686064578592777, 8.599124774336815, 2.9880299884825945, 4.3057498801499605, 3.3873925963416696, 4.372325632721186, 2.997919670306146, 5.323326252400875, 2.330972570925951, 2.0784794446080923, 1.282246420159936, 0.6912270246539265, 2.445727838203311, 6.528782593086362, 11.999017987400293, 19.547304399311543, 33.578661382198334, 43.16805101931095, 49.014907479286194, 51.84301592409611, 58.35336238145828, 59.673001170158386, 59.63839642703533, 59.289088770747185, 47.52981036901474, 39.32338312268257, 30.14178190380335, 53.21071833372116, 58.234641551971436, 49.29914362728596, 61.77681528031826, 59.87057916820049, 62.13751472532749, 59.58518408238888, 59.110372960567474, 57.514033019542694, 58.28165642917156, 51.489277705550194, 42.80105911195278, 29.298476055264473, 18.2985071092844, 10.49760265275836, 3.2310962956398726, 2.112757880240679, 1.3064137171022594, 2.709799655713141, 2.7968361228704453, 1.4767109602689743, 2.043731971643865, 4.247842887416482, 5.5558372009545565, 7.318365974351764, 5.745361056178808, 4.209255957975984, 5.80784110352397, 2.1054439852014184, 1.5709164552390575, 0.9697562945075333, 0.12604348186869174, 0.7271905511151999, 3.527361173182726, 11.6827286593616, 19.186755046248436, 21.32065214216709, 23.52089937776327, 15.869659390300512, 22.584656216204166, 28.16436991095543, 26.607620045542717, 13.865650724619627, 3.1172603415325284, 0.23718374781310558, 0.020577476680045947, 0.006344446546791005, 0.06193644643644802, 0.021151043656573165, 0.01743619748594938, 0.09852727322140709, 0.01478134228818817, 0.08774219764745794, 0.06363621694617905, 0.0725183665053919, 0.011978045495197875, 0.05422805166745093, 0.007134200213840813, 0.007297892479982693, 0.050438422986189835, 0.011116639325337019, 0.028362212469801307, 0.049600015045143664, 0.05490058960276656, 0.0243263911397662, 0.04048877191962674, 0.043362568103475496, 0.02704455895582214, 0.022660928261757363, 0.06436749958083965, 0.05286170955514535, 0.013407454389380291, 0.04958500881912187, 0.04371330338472035, 0.03184223940479569, 0.02147289826098131, 0.06563311369973235, 0.04068990507221315, 0.1507958138245158, 0.0457827599166194, 0.09345237092929892, 0.043573571820161305, 0.06306347931968048, 0.029807982937199995, 0.08525826648110524, 0.12713259842712432, 0.11681781441438943, 0.10081253887619823, 0.16776559932623059, 0.105294613604201, 0.055004568203003146, 0.18244863487780094, 0.13150341779692098, 0.12286051438422874, 0.17647352971835062, 0.17013876495184377, 0.16131603915710002, 0.14464848587522283, 0.14655665145255625, 0.10989144662744366, 0.17420778254745528, 0.1610528290621005, 0.11142657167511061, 0.20421266468474641, 0.09835644566919655, 0.1911306197871454, 0.2655348280677572, 0.1764911037753336, 0.13561794388806447, 0.08729552122531459, 0.15012816293165088, 0.1880639320006594, 0.17330656293779612, 0.13711911567952484, 0.20839076314587146, 0.15163565782131627, 0.13358247029827908, 0.13541143387556076, 0.18110672797774896, 0.12414097887813114, 0.12385557856759988, 0.04999994358513504, 0.1597248003236018, 0.18354539555730298, 0.17522902227938175, 0.1755038247210905, 0.30423987773247063, 0.11618809468927793, 0.18398741871351376, 0.18503145722206682, 0.2044970853603445, 3.24505009688437, 13.252806309610605, 32.17303700745106, 41.00161626935005, 41.66120767593384, 36.00272610783577, 28.00200842320919, 25.041881762444973, 36.32871061563492, 45.45259863138199, 38.52595791220665, 19.11434043198824, 5.92915054410696, 1.2088664202019572, 1.8850883468985558, 4.954557940363884, 8.475047182291746, 8.312430158257484, 10.338532738387585, 33.332700580358505, 5.319741619750857, 7.430646624416113, 7.600496560335159, 7.777132457122207, 7.545182928442955, 6.402901997789741, 3.8604192389175296, 2.792783402837813, 1.213720659725368, 0.9503193281125277, 1.437562967184931, 4.860525811091065, 10.07540825754404, 18.24432961642742, 31.84332299977541, 40.27629978954792, 48.969537913799286, 51.13302022218704, 57.691943272948265, 58.791068494319916, 60.884417966008186, 61.945579424500465, 47.82568149268627, 43.00471678376198, 35.044729113578796, 54.27344910800457, 60.633669421076775, 54.9862452596426, 62.038036063313484, 60.38779981434345, 63.595838472247124, 61.81007869541645, 60.18645241856575, 59.62009280920029, 59.73756730556488, 51.39732263982296, 41.03266820311546, 27.929314523935318, 18.11123225837946, 10.96106568351388, 3.1376056373119354, 1.177553606685251, 0.8129373437259346, 3.513120962306857, 4.09350466914475, 1.7696784459985793, 2.529346151277423, 7.981031890958548, 9.827332869172096, 12.128505539149046, 7.499152673408389, 7.043624566867948, 11.972634103149176, 7.39037306047976, 5.161617379635572, 2.92187815066427, 2.8368223272264004, 1.894974703900516, 5.476252846419811, 14.127803407609463, 23.373476788401604, 24.86773330718279, 29.191580191254616, 19.710268154740334, 30.108641982078552, 33.76397743821144, 30.063306614756584, 13.72642619535327, 3.0220148898661137, 0.26014190807472914, 0.14009269361849874, 0.210936700750608, 0.17078274133382365, 0.05632701228023507, 0.14241724857129157, 0.15327277622418478, 0.1280432878411375, 0.1958262623520568, 0.16582742129685357, 0.2391740691382438, 0.1184128901513759, 0.2838187344605103, 0.1776109155616723, 0.13203096605138853, 0.17294901103014126, 0.13663787744008005, 0.20015184039948508, 0.15711310843471438, 0.18587857426609844, 0.09244791115634143, 0.1533763503539376, 0.08896526444004849, 0.2321332844439894, 0.19499324611388147, 0.1518996842787601, 0.12366672424832359, 0.14218848897144198, 0.14499809680273756, 0.12580934911966324, 0.10010699392296374, 0.15020743914647028, 0.2261878058197908, 0.12562633550260216, 0.20039385475683957, 0.17414426954928786, 0.14569941151421517, 0.12779322860296816, 0.15596600045682862, 0.1273524819407612], [0.020943277559126727, 0.0402493365254486, 0.05166987975826487, 0.00575449016650964, 0.027299059947836213, 0.06712905335007235, 0.060338680414133705, 0.0223465136878076, 0.01723219407722354, 0.010663869870768394, 0.04421988225658424, 0.053594680575770326, 0.06722512436681427, 0.039131881057983264, 0.015124371293495642, 0.05300191980495583, 0.05000290475436486, 0.06686951688607223, 0.015178130615822738, 0.035897612615372054, 0.09545328270178288, 0.0404680882638786, 0.05004070604627486, 0.01654712497838773, 0.040159351119655184, 0.02266506944579305, 0.02765207362244837, 0.07100926115526818, 0.020424293688847683, 0.09051248649484478, 0.050549529914860614, 0.09808919829083607, 0.041256319600506686, 0.02961932714242721, 0.06139049663033802, 0.01905607023218181, 0.05186198468436487, 0.04128783490159549, 0.04561713110888377, 0.028847599314758554, 0.06767227576347068, 0.08475220340187661, 0.031771998837939464, 0.011581765538721811, 0.10314485669368878, 0.029875882028136402, 0.044636768870987, 0.06268436802201904, 1.077427079435438, 6.133395759388804, 16.414188221096992, 26.58718854188919, 31.50054719299078, 30.91436594724655, 24.107403606176376, 18.07429824024439, 21.055209785699844, 26.23037438839674, 16.57557126134634, 11.161444131284952, 3.6177440732717514, 2.6503532705828547, 0.08670555092976429, 1.2786209397017956, 0.703570602927357, 2.518472084775567, 6.402012845501304, 3.5279513290151954, 3.687770515680313, 2.725214953534305, 2.5162368547171354, 1.384768362622708, 3.633383084088564, 1.8334739352576435, 1.4954320807009935, 2.0048645697534084, 1.0250229039229453, 0.3339787741424516, 0.07366636506048962, 0.7347672258038074, 3.8674571737647057, 8.004516530781984, 16.08030203729868, 23.01143791526556, 30.221623219549656, 38.99149753153324, 44.96911257505417, 44.78585980832577, 50.60454457998276, 36.71842910349369, 34.10639986395836, 21.226029619574547, 36.073269322514534, 64.02350932359695, 52.898576483130455, 55.506273955106735, 59.39230263233185, 59.256254732608795, 57.2442626953125, 48.95693399012089, 43.00823539495468, 36.40416696667671, 23.781194910407066, 14.675234332680702, 5.478325635194778, 1.2363113975152373, 1.0565435187891126, 0.07009041553828865, 1.6084400354884565, 2.5849331310018897, 3.982339259237051, 4.451763220131397, 3.0196578288450837, 3.0512486211955547, 1.7338382941670716, 4.079848201945424, 5.894859759137034, 3.1369755836203694, 4.391375910490751, 6.3270029705017805, 1.5031825960613787, 1.1598425195552409, 0.836137414444238, 1.6683214972727, 4.8767841886729, 12.840032558888197, 20.717556104063988, 20.36311872303486, 15.435010213404894, 13.659811969846487, 22.482496798038483, 28.16911395639181, 21.295698881149292, 10.977540649473667, 2.5459902081638575, 0.11192729129106738, 0.0005825830851335922, 0.030611791953560896, 0.027145537424075883, 0.03924517361156177, 0.06020225882821251, 0.015135480316530447, 0.025309209886472672, 0.03641219554992858, 0.032424487653770484, 0.05052008149505127, 0.07258800964336842, 0.016507061991433147, 0.046555728986277245, 0.03259084376622923, 0.011228754647163441, 0.021955251577310264, 0.07432246071402915, 0.05710032273782417, 0.0475117710448103, 0.020901631942251697, 0.021390336187323555, 0.03891524444043171, 0.03902710464899428, 0.04043580855068285, 0.034275548678124323, 0.009407754314452177, 0.03315400768769905, 0.004138888480156311, 0.06700768994051032, 0.0177675515806186, 0.05516498342331033, 0.14978496416006237, 0.032083830737974495, 0.06350648211082444, 0.03436099214013666, 0.01946099342603702, 0.026987979472323786, 0.05003270569432061, 0.057277777668787166, 0.027327419265930075, 0.05527731860638596, 0.001876718229141261, 0.049332815906382166, 0.03857001218420919, 0.07834730567992665, 0.025866117503028363, 0.07052800807286985, 0.04021750581159722, 0.03734180601895787, 0.018090623307216447, 0.04544067065580748, 0.039188514347188175, 0.05410198304161895, 0.012578684163599974, 0.06725135186570697, 0.02842839534423547, 0.04703122300270479, 0.011084873549407348, 0.056116268315236084, 0.05814458017994184, 0.04968138411641121, 0.00507086176185112, 0.04364668078778777, 0.05095431952213403, 0.025624006666475907, 0.020142531757301185, 0.022755501995561644, 0.08730119123356417, 0.028800116706406698, 0.02031517757131951, 0.019461043521005195, 0.03625209574238397, 0.03916393070539925, 0.049582400170038454, 0.013042446680628927, 0.03732433215191122, 0.04287399373424705, 0.05386872602684889, 0.04691220849053934, 0.0359146003756905, 0.035733419863390736, 0.014321457492769696, 0.02089555375277996, 0.024260486570710782, 0.02669840458111139, 0.06233572188648395, 0.06952270225156099, 0.10923450492555276, 1.908064882736653, 9.507416635751724, 22.25068263709545, 32.074960470199585, 35.741170942783356, 30.598486997187138, 22.24541611969471, 20.883628092706203, 30.235357582569122, 40.51292449235916, 26.570824719965458, 15.806118249893188, 7.2365691885352135, 2.690408583730459, 0.38472686195746064, 0.40516747918445617, 0.6873179844114929, 0.5310868739616126, 2.362497104331851, 1.8394916248507798, 6.217807279899716, 4.010439226403832, 5.263129407539964, 3.6095232143998146, 6.6653477400541306, 3.9104753779247403, 2.7921034768223763, 3.5299383848905563, 1.8228199006989598, 1.4909991435706615, 0.759266292443499, 2.974146483466029, 5.5713755171746016, 9.58065390586853, 20.08356012403965, 27.890571802854538, 34.02401648461819, 41.1277125030756, 46.72038160264492, 49.55433413386345, 54.714518040418625, 43.464104533195496, 35.61687961220741, 25.085100643336773, 42.16818407177925, 68.43669891357422, 56.29864923655987, 60.857268422842026, 63.43728058040142, 61.66752174496651, 59.89870145916939, 52.15194694697857, 44.65193219482899, 39.621211141347885, 27.593140862882137, 20.059389621019363, 8.988857511430979, 3.0752006359398365, 1.888940033968538, 0.7109368639066815, 2.825405839830637, 2.838168879970908, 5.402088901028037, 5.350804002955556, 3.2715767109766603, 5.121276369318366, 4.619123814627528, 5.501239355653524, 5.759397028014064, 5.279975803568959, 3.5404899436980486, 1.7685279389843345, 0.6008428777568042, 0.207119167316705, 0.4599734820658341, 1.6699788020923734, 5.902720112353563, 14.356424789875746, 25.93123733997345, 24.167670272290707, 18.884333074092865, 15.285740923136473, 22.056906335055828, 31.480166986584663, 26.154967434704304, 14.189309757202864, 4.125868957489729, 0.299424467375502, 0.05686641263309866, 0.01775783130142372, 0.02917182879173197, 0.033282633012277074, 0.046413418458541855, 0.08578576278523542, 0.035622676587081514, 0.051398999567027204, 0.06781594071071595, 0.03918420617992524, 0.04869747812335845, 0.03443294706812594, 0.010920356107817497, 0.09752058700541966, 0.0451512033760082, 0.061710354857495986, 0.06089480877562892, 0.03950996448111255, 0.021385803520388436, 0.0623104591795709, 0.04167717299424112, 0.0852979565388523, 0.03591785098251421, 0.048564088210696355, 0.03963377697800752, 0.008533514555892907, 0.03875073256494943, 0.00834509160995367, 0.0387494560709456, 0.03548212866007816, 0.07845007829018869, 0.02100648998748511, 0.03168985422234982, 0.005225107415753882, 0.005399141509769834, 0.09235457124304958, 0.032887031193240546, 0.0866279964975547, 0.010205525959463557, 0.08375243400223553, 0.1551834205747582, 0.1192546340462286, 0.1680602616397664, 0.13093490299070254, 0.11922609104658477, 0.13235599704785272, 0.13919280987465754, 0.136374207213521, 0.13478988519636914, 0.0997527148865629, 0.14102741377428174, 0.19921907951356843, 0.18474564130883664, 0.15909013047348708, 0.13806281582219526, 0.11886888794833794, 0.1323914123349823, 0.14382532535819337, 0.11882285994943231, 0.14849937142571434, 0.2496307814726606, 0.09319291610154323, 0.192164535401389, 0.10875004576519132, 0.1814568880945444, 0.13922791345976293, 0.13401738367974758, 0.2506171847926453, 0.08864452305715531, 0.1177128816198092, 0.12669617106439546, 0.1893971854588017, 0.13740413007326424, 0.186028458410874, 0.2764527703402564, 0.06644529043114744, 0.18473262403858826, 0.14472832612227648, 0.14489492343273014, 0.07997259424882941, 0.13958081952296197, 0.16770259098848328, 0.2188354526879266, 0.21630461036693305, 0.19831533660180867, 0.15054847084684297, 0.08879956512828358, 0.2183295603026636, 1.3914766651578248, 9.087792802602053, 23.434550911188126, 37.04596392810345, 44.71036545932293, 41.57828852534294, 31.136688217520714, 29.65373419225216, 28.380023539066315, 37.65901543200016, 24.285235963761806, 14.85644755885005, 5.200491193681955, 3.217402780428529, 0.3799769387114793, 2.5098159117624164, 2.114990260452032, 8.378447815775871, 14.784877449274063, 12.39306254312396, 10.937017723917961, 8.947335239499807, 8.21368295699358, 5.235359547659755, 8.235672377049923, 5.403138119727373, 5.651130862534046, 4.3501927703619, 2.4900719337165356, 1.33467921288684, 0.6436317879706621, 2.323023397475481, 5.009411796927452, 8.728281743824482, 18.86952906847, 25.08264597505331, 33.035792112350464, 39.858048632740974, 47.617521062493324, 46.669893711805344, 55.425410494208336, 47.41561509668827, 43.83948639035225, 31.326826214790344, 47.50435173511505, 70.38442119956017, 61.634197533130646, 62.603810504078865, 64.35791417956352, 62.32459008693695, 61.64570711553097, 52.7497498691082, 43.547274470329285, 38.6910742521286, 25.625201761722565, 16.282056011259556, 6.888587661087513, 1.7885148664936423, 1.2973102368414402, 0.5845259595662355, 3.3002908201888204, 4.703378118574619, 6.580821750685573, 9.201260413974524, 7.272232649847865, 7.3081587720662355, 6.641655061393976, 9.612107668071985, 14.155447874218225, 11.167415510863066, 10.277302823960781, 11.7784920707345, 4.600163782015443, 3.209141311235726, 1.9933158019557595, 2.404657267034054, 7.140031568706036, 16.054562218487263, 28.15862461924553, 28.026845790445805, 23.599878139793873, 21.17366272956133, 30.432616397738457, 38.92313539981842, 28.904566392302513, 14.914635736495256, 4.001199547201395, 0.24988798017147928, 0.17645911721047014, 0.12754312483593822, 0.20979530730983242, 0.18035343324299902, 0.12927096337080002, 0.19893704855348915, 0.14689697069115937, 0.17591058101970702, 0.12199152624816634, 0.2660919731715694, 0.2285757995559834, 0.10617201027343981, 0.19849167088977993, 0.19260407978435978, 0.11835391909698956, 0.13812496326863766, 0.18579843715997413, 0.15579186292598024, 0.26374206645414233, 0.1211289205821231, 0.10343902176828124, 0.16692689823685214, 0.14772545982850716, 0.16359524888684973, 0.14022047660546377, 0.13975982554256916, 0.1472094000200741, 0.13461683120112866, 0.10706126646255143, 0.10824095472344197, 0.19889008544851094, 0.1978067131130956, 0.09543642110656947, 0.10979719387250952, 0.12221683486131951, 0.2048768274835311, 0.13416423986200243, 0.1639902644092217, 0.13632308808155358, 0.22270340763498098], [0.0827906328777317, 0.03344527096487582, 0.0080232203072228, 0.11001655046129599, 0.04253171522577759, 0.07687048375373706, 0.03674208761367481, 0.026843982413993217, 0.020383967239467893, 0.04968936220393516, 0.034399695141473785, 0.045732319849776104, 0.029224717945908196, 0.01397616772010224, 0.038913429889362305, 0.022978098058956675, 0.04586483773891814, 0.04537445624009706, 0.03452942626609001, 0.020432928577065468, 0.03417570755118504, 0.037154324672883376, 0.03871093118505087, 0.0457852386898594, 0.09397355897817761, 0.015234097827487858, 0.05764294401160441, 0.05620245021418668, 0.05145980372617487, 0.019106107683910523, 0.024906830403779168, 0.05963613744825125, 0.05659320580889471, 0.012555790763144614, 0.0716639838356059, 0.03516199212754145, 0.01816541509469971, 0.04835763757000677, 0.045429441961459816, 0.026075275127368513, 0.04678766126744449, 0.009022783760883613, 0.02880376992834499, 0.030216407212719787, 0.015083794369274983, 0.11067226761952043, 0.10267978985211812, 0.02652035778737627, 0.028560326936712954, 0.5142541928216815, 3.217828832566738, 13.13926175236702, 30.01577116549015, 33.363972902297974, 34.48997028172016, 23.357675336301327, 11.912600174546242, 24.321362525224686, 39.8358616232872, 19.927050322294235, 9.946957100182772, 5.601124595850706, 3.1001524720340967, 0.39067027741111815, 0.6504143646452576, 0.7630318310111761, 1.3944604550488293, 1.5139323379844427, 4.816453400999308, 2.4635372450575233, 3.7367985723540187, 2.4430591939017177, 6.817300636321306, 3.537804912775755, 2.3703923681750894, 2.347186775878072, 0.5447445879690349, 0.6471882783807814, 0.5708240135572851, 0.2853491617133841, 0.09163553404505365, 0.2591620059683919, 2.0749890943989158, 6.293285004794598, 10.746210012584925, 17.550171464681625, 22.16409668326378, 22.225571684539318, 24.856875389814377, 26.32495131343603, 27.264889776706696, 25.48805572092533, 29.698415994644165, 47.21029311418533, 42.28807143867016, 46.2090240418911, 38.69114264845848, 41.35914668440819, 40.25316663086414, 28.071670085191727, 18.632220402359962, 12.30902910232544, 5.876552816480398, 2.7359512774273753, 0.7519811927340925, 0.6131135474424809, 0.6558110844343901, 1.0539560951292515, 3.2740627275779843, 1.5038760588504374, 3.4010573755949736, 1.951243153307587, 1.3592809927649796, 3.167023421265185, 3.759820112027228, 3.8792916387319565, 4.179872609674931, 4.298660410568118, 3.0083080753684044, 1.2435753014869988, 0.17831549572292715, 1.0184925980865955, 2.4497784208506346, 6.603912636637688, 13.749679047614336, 15.793097298592329, 15.872319247573614, 11.387729588896036, 12.387453094124794, 19.986218847334385, 23.365641608834267, 22.101213857531548, 10.396903306245804, 2.208516779355705, 0.1588659276603721, 0.07571079637273215, 0.023931397881824523, 0.02819594355969457, 0.020197122285026126, 0.04489535538596101, 0.05565077102801297, 0.032126359510584734, 0.014967387578508351, 0.020554453403747175, 0.07402754607028328, 0.053015515950392, 0.009037306663230993, 0.05614953137410339, 0.042634291166905314, 0.029031993326498196, 0.014882647301419638, 0.030034421470190864, 0.04536163563898299, 0.010867531891562976, 0.04969841640559025, 0.06694312309264205, 0.016976477818388958, 0.03095196090725949, 0.11793479119660333, 0.03074492768064374, 0.01933622726937756, 0.006406841685020481, 0.07886946594226174, 0.0808517646510154, 0.042923172150040045, 0.09182564259390347, 0.04994378898118157, 0.0479295779223321, 0.01236143341884599, 0.09930568965501152, 0.008345989608642412, 0.018201693128503393, 0.06271741585806012, 0.06573996812221594, 0.07674832624616101, 0.01125082704675151, 0.03908998682163656, 0.02648317618877627, 0.021905767025600653, 0.06409401816199534, 0.03554562310455367, 0.020185385219519958, 0.046467502470477484, 0.023443753052561078, 0.03754716941330116, 0.031530941851087846, 0.032127428203239106, 0.02843579826731002, 0.017715115136525128, 0.011470128902146826, 0.022815430420450866, 0.045943601871840656, 0.031152817609836347, 0.06450749089708552, 0.03747845024918206, 0.02834090726537397, 0.014535153350152541, 0.05014792412112001, 0.022065534722059965, 0.03931677230866626, 0.04884193345787935, 0.031855683409958147, 0.05903874567593448, 0.03739487328857649, 0.023822656548873056, 0.028344950114842504, 0.009763757916516624, 0.03316181137051899, 0.007314842205232708, 0.0289246082684258, 0.013583132804342313, 0.05224720385740511, 0.0711275298090186, 0.10849742611753754, 0.041345714998897165, 0.05243790612439625, 0.0027462917341836146, 0.023673265932302456, 0.043729400567826815, 0.010654465004336089, 0.009450629113416653, 0.08299902794533409, 0.028558135745697655, 0.04399444747832604, 0.06772171764168888, 0.969611486652866, 5.353533206507564, 18.343926072120667, 34.134883135557175, 37.60035417973995, 35.39370238780975, 23.849384151399136, 11.88271477818489, 21.403922773897648, 29.04759831726551, 17.81002812087536, 12.749560363590717, 9.275983404368162, 3.6661670124158263, 0.854765143012628, 0.5875412165187299, 0.45647951017599553, 0.9976610471494496, 2.0039975037798285, 3.254113798029721, 3.2891013706102967, 4.237363524734974, 2.959190485998988, 5.866222120821476, 6.508194347843528, 3.66477866191417, 5.00157424248755, 2.291249977424741, 3.0735346628353, 2.780820457264781, 1.3740017591044307, 1.4178626867942512, 2.1502528432756662, 3.080404931679368, 8.250939957797527, 13.007981646806002, 22.38324422389269, 27.906441651284695, 25.04989553242922, 31.080909110605717, 32.075165659189224, 31.112257428467274, 27.75007054209709, 36.78236447274685, 54.89030800759792, 50.25795757770538, 51.96896396577358, 46.68294981122017, 47.503420785069466, 45.860415548086166, 33.22244189679623, 23.600094728171825, 16.149733811616898, 9.234785065054893, 4.658616045489907, 2.1434269845485687, 1.0324129136279225, 2.498682984150946, 1.4529540413059294, 2.706264420412481, 2.4636039789766073, 3.811813909560442, 4.210351249203086, 4.696538960561156, 5.1961565762758255, 4.947489844635129, 6.65891183540225, 3.0439064651727676, 2.6694622077047825, 0.3144357103155926, 1.4760347153060138, 0.16825583239551634, 0.42281563219148666, 2.0117403008043766, 7.892127586528659, 18.246058523654938, 22.804977893829346, 22.56841018795967, 15.686175785958767, 14.750222358852625, 19.082102961838245, 27.625507526099682, 26.441337168216705, 13.66094620898366, 3.870785557664931, 0.25742166966665536, 0.02262104524561437, 0.10369739306042902, 0.0327034572546836, 0.035241843506810255, 0.03627877595135942, 0.03904517594492063, 0.031028843695821706, 0.013931030298408587, 0.022488579306809697, 0.0027678181913870503, 0.032339830868295394, 0.028625739832932595, 0.08182636782294139, 0.026212902703264263, 0.007271892727658269, 0.02788527312077349, 0.028505946065706667, 0.03150312615616713, 0.05634889821521938, 0.06782410433515906, 0.013714480883209035, 0.021455311216413975, 0.012278684880584478, 0.06559185028891079, 0.02461362826579716, 0.03739481391676236, 0.06053117867850233, 0.02940994130767649, 0.04776577479788102, 0.00665480806674168, 0.03028604478458874, 0.02906670171796577, 0.014982217544456944, 0.0030277201631179196, 0.06370698814862408, 0.033403532579541206, 0.027330243137839716, 0.022720569104421884, 0.029752865484624635, 0.052582665739464574, 0.002766836469163536, 0.18972582329297438, 0.11791771437856369, 0.10763045662315562, 0.19116276962449774, 0.16654622100759298, 0.1605165976798162, 0.16155708872247487, 0.11815370991826057, 0.14193419949151576, 0.16250884858891368, 0.10556616543908603, 0.17759550857590511, 0.10313199527445249, 0.06585195078514516, 0.11275015494902618, 0.09393872998771258, 0.1023521761817392, 0.14822792349150404, 0.10534723187447526, 0.16534517373656854, 0.0747172832780052, 0.14802080491790548, 0.10862246315809898, 0.16156333760591224, 0.23907714465167373, 0.13220375287346542, 0.1347070318297483, 0.1279350381810218, 0.2031882040319033, 0.12887804070487618, 0.11017032345989719, 0.22255425079492852, 0.22142560745123774, 0.12155990800238214, 0.10967056863592006, 0.12802191398805007, 0.10522643249714747, 0.1650946246809326, 0.23379247431876138, 0.07914383051684126, 0.103112053766381, 0.11093046079622582, 0.11548677997780032, 0.1556931424420327, 0.12446132692275569, 0.1822767237899825, 0.2817734645213932, 0.1080773260036949, 0.14103750698268414, 0.6953580561093986, 4.941386422142386, 18.658571988344193, 40.7116462290287, 46.62144251167774, 46.19023025035858, 33.92706848680973, 19.04567051678896, 32.47852921485901, 49.29062828421593, 28.261752985417843, 16.198103316128254, 7.241630991920829, 4.006767673417926, 0.9447820158675313, 1.4361088327132165, 1.5365975280292332, 5.146462367847562, 4.772101705893874, 12.667684257030487, 7.564802225679159, 8.950018845498562, 9.613664634525776, 15.703329015523195, 10.419507343322039, 6.268755896016955, 5.883250432088971, 3.487526010721922, 2.739136219024658, 2.133308365009725, 1.8182267784141004, 0.4575332114472985, 0.6181226880289614, 2.6491636969149113, 7.274930505082011, 12.294033206999302, 20.11218398809433, 24.12757482379675, 25.407201759517193, 29.534853771328926, 34.75564442574978, 34.689235389232635, 33.14319334924221, 40.93002051115036, 61.37614578008652, 55.66219478845596, 58.117718026041985, 48.990881368517876, 48.901251778006554, 45.93652926385403, 33.49507726728916, 22.466858737170696, 14.25038293004036, 7.6912822388112545, 3.561251317150891, 1.1840600450523198, 1.1255623027682304, 1.8919470976106822, 3.1913069682195783, 5.082825757563114, 4.656093930825591, 7.746284287422895, 7.070667715743184, 5.270562758669257, 7.652043644338846, 10.310134012252092, 11.055515315383673, 11.26377074047923, 9.709700681269169, 7.975599132478237, 4.422985939309001, 1.0963805811479688, 1.7315717157907784, 2.7630378864705563, 9.001647625118494, 17.807484157383442, 22.58754976093769, 25.963664799928665, 20.312195755541325, 20.05720093846321, 27.420514225959778, 32.585793659090996, 29.820450246334076, 14.092375058680773, 3.466442129574716, 0.3206536313518882, 0.16614427382592112, 0.20868107647402212, 0.08512039028573781, 0.17386776016792282, 0.12110366529668681, 0.15405268437461928, 0.11391201682272367, 0.058671727674664, 0.09460744957323186, 0.1982098477310501, 0.14706276648212224, 0.10761254117824137, 0.1937348605133593, 0.10048453186755069, 0.10674468852812424, 0.14175743475789204, 0.1134213013574481, 0.22099651250755414, 0.21396736468886957, 0.16847694787429646, 0.1852457449422218, 0.12265079829376191, 0.16418403916759416, 0.2887283975724131, 0.13868524023564532, 0.15223244845401496, 0.11378310577129014, 0.18766884226351976, 0.1256572682177648, 0.10552003353950568, 0.20596913527697325, 0.12496629904489964, 0.08830723920254968, 0.08911885190173052, 0.19435767084360123, 0.08273304221802391, 0.128756269114092, 0.1561814607703127, 0.13911786780226976, 0.16196295444387943, 0.11534139324794523], [0.052137291786493734, 0.015739558839413803, 0.013090783686493523, 0.00932490280320053, 0.0685344212979544, 0.03972739519667812, 0.025964142223529052, 0.06366323854308575, 0.042060781706823036, 0.07099011374521069, 0.0813102041138336, 0.023639763530809432, 0.01533053713501431, 0.023695374511589762, 0.04402528371429071, 0.039946659017005004, 0.01180856030259747, 0.05378398760512937, 0.05411894482676871, 0.06998896395089105, 0.049816150713013485, 0.06131347283371724, 0.06341648928355426, 0.006537641038448783, 0.02241939630039269, 0.0700566775049083, 0.05949273596343119, 0.02191129417042248, 0.02996068538777763, 0.013164431638870155, 0.025813343381742015, 0.0502914962999057, 0.021772718500869814, 0.014173220915836282, 0.06110014990554191, 0.1141090496093966, 0.054037045119912364, 0.044104188855271786, 0.04251225611369591, 0.05004823142371606, 0.09816160221816972, 0.021536914064199664, 0.06568513083038852, 0.06611493823584169, 0.04146448460232932, 0.05611151485936716, 0.018289392719452735, 0.031320980851887725, 0.058628312035580166, 0.11690642684698105, 0.1166292569541838, 1.6830083029344678, 10.56709997355938, 27.65670385211706, 37.90511302649975, 32.526554837822914, 40.22241488099098, 63.3371901512146, 47.66703620553017, 30.69025967270136, 22.310993000864983, 15.116702243685722, 11.964280251413584, 5.575255108997226, 1.4468484814278781, 0.38627919740974903, 0.17413181631127372, 0.27469863009173423, 3.022410306148231, 3.1607416458427906, 4.143207902088761, 2.447260580956936, 4.941141810268164, 3.4445512667298317, 1.2115715187974274, 3.736146669834852, 2.256613648496568, 3.5739257745444775, 1.8059454811736941, 2.4452561885118484, 6.2432692386209965, 1.6539561306126416, 0.10772661669761874, 0.48601927352137864, 1.6981241293251514, 2.2849235543981194, 6.345337461680174, 4.9568539671599865, 6.693895608186722, 11.13397540524602, 14.512740802019835, 13.083881624042988, 21.221954338252544, 16.826931573450565, 21.89801026135683, 25.21594662219286, 21.11600272357464, 15.884129963815212, 13.317828420549631, 7.625066041946411, 3.600350981578231, 1.9536004518158734, 0.2674678259063512, 1.6189140547066927, 1.0995415365323424, 1.5567141235806048, 2.0610875403508544, 1.185505986213684, 2.2356872214004397, 1.9203015323728323, 5.079593556001782, 2.766945739276707, 4.1862529423087835, 5.837896540760994, 4.479205347597599, 5.299686770886183, 2.864696681499481, 1.9235136662609875, 0.9156789619009942, 0.5493764206767082, 1.9989582616835833, 4.103413112461567, 7.943616723641753, 12.713917326182127, 16.716638691723347, 14.323807340115309, 10.032725147902966, 13.354505952447653, 21.837593503296375, 25.011297203600407, 22.81313795596361, 8.955846782773733, 1.960815314669162, 0.05861837838892825, 0.022649033489869907, 0.033775448755477555, 0.02609530940389959, 0.07831583861843683, 0.02003460864216322, 0.06724934064550325, 0.11651794964564033, 0.08692857372807339, 0.055136700175353326, 0.09138091802014969, 0.0305047612710041, 0.02715423353947699, 0.029890172081650235, 0.043087780504720286, 0.05769010749645531, 0.040036881910054944, 0.024992366634251084, 0.02205860862886766, 0.020298406889196485, 0.0117351201515703, 0.029135569311620202, 0.02660065445525106, 0.047648333638790064, 0.01551962337543955, 0.03323593336972408, 0.025352697884954978, 0.02734594512730837, 0.014365666302182944, 0.0797272624913603, 0.02208524430898251, 0.020660708541981876, 0.004623220547728124, 0.0254764547207742, 0.06187582039274275, 0.101711101597175, 0.04476048859942239, 0.03061866980715422, 0.09060777083504945, 0.025242171686841175, 0.039983692186069675, 0.0175004637640086, 0.0336701788182836, 0.0338264528545551, 0.04848235548706725, 0.04975588461093139, 0.044748024229193106, 0.016971872792055365, 0.09603248443454504, 0.051459822279866785, 0.061878117339801975, 0.05344609890016727, 0.07229846814880148, 0.09048704567248933, 0.06586156159755774, 0.02259599405078916, 0.11536995851201937, 0.08716901473235339, 0.06424847393645905, 0.019900163024431095, 0.035688720308826305, 0.09262169245630503, 0.08582915615988895, 0.06266126496484503, 0.07653465450857766, 0.019059222504438367, 0.014429263719648588, 0.025272262064390816, 0.041323302139062434, 0.07734886472462676, 0.045884604842285626, 0.02603846645797603, 0.018713481877057347, 0.04902267610304989, 0.08022329915547743, 0.012873733321612235, 0.022419184788304847, 0.048524943631491624, 0.04690062356530689, 0.04564515831589233, 0.030418709247896913, 0.024632499225845095, 0.0065261530562565895, 0.03400882451387588, 0.06772396634914912, 0.04922443265968468, 0.08473704132484272, 0.016639260757074226, 0.05692360624379944, 0.08826140416203998, 0.007080175109877018, 0.024218651706178207, 0.05153167701791972, 0.27928721043281257, 2.894792491570115, 15.603114143013954, 32.90491193532944, 41.96944333612919, 35.88451065123081, 34.34290297329426, 55.09956657886505, 54.9465411901474, 33.70649792253971, 19.616346694529057, 17.428876273334026, 13.84503873065114, 5.387808792293072, 1.4235393446870148, 0.3562795399921015, 0.23506991827161983, 0.383937869919464, 0.8959791564848274, 2.875076774507761, 2.685471698641777, 3.8044824404641986, 4.115248052403331, 5.07223192602396, 5.815547564998269, 5.566581599414349, 2.8583704959601164, 5.010189805179834, 7.13734463788569, 3.955428865738213, 6.830872558057308, 7.656124625355005, 0.8443856437224895, 1.2375644990243018, 2.2829721216112375, 4.4265335239470005, 8.485669512301683, 7.659647511318326, 9.739242196083069, 13.839636370539665, 18.010469265282154, 17.147649563848972, 26.423208341002464, 25.997372791171074, 28.561125621199608, 32.665859162807465, 25.60854535549879, 21.09940331429243, 17.68290214240551, 9.71548967063427, 4.777657957747579, 3.145427042618394, 0.6764967588242143, 3.2411279948428273, 5.0373004004359245, 2.5576448952779174, 2.078127725981176, 3.20618839468807, 3.8735252106562257, 4.727569995447993, 5.114259570837021, 4.8508496303111315, 4.845182234421372, 6.489300336688757, 5.065298723056912, 3.3641656301915646, 1.5900339419022202, 0.5572031694464386, 0.74460145435296, 0.6187865242827684, 1.2679778295569122, 4.260893762111664, 12.847939934581518, 19.70571029931307, 19.899592995643616, 18.2645046338439, 12.435271628201008, 15.52433392032981, 22.331333309412003, 29.34461507946253, 27.184590585529804, 13.264719620347023, 3.509537992067635, 0.07995109423063695, 0.009374904075230006, 0.011630399403657066, 0.048349147400585935, 0.017496684376965277, 0.005132749920448987, 0.07891219138400629, 0.08711644099093974, 0.03625877136073541, 0.06690623835311271, 0.027878343316842802, 0.04982536818715744, 0.026305311221221928, 0.026714408995758276, 0.024858420110831503, 0.043475983111420646, 0.0068279543665994424, 0.037409096548799425, 0.0961887881567236, 0.009138517980318284, 0.016849412859301083, 0.03118321968941018, 0.035629437552415766, 0.016877041161933448, 0.01329374066699529, 0.02813503178913379, 0.039418476226273924, 0.10400047875009477, 0.02740917982009705, 0.05023448080464732, 0.019391099813219626, 0.06851537778857164, 0.028307479078648612, 0.02514554034860339, 0.09002189719467424, 0.0816574772761669, 0.11063812882639468, 0.03755986756004859, 0.05673445877619088, 0.032421723153674975, 0.03178893464792054, 0.03235331198084168, 0.035802064812742174, 0.22358886402798817, 0.1984665566124022, 0.11438397079473361, 0.1199030336283613, 0.11917827447177842, 0.167908433068078, 0.13014855299843475, 0.1401579729281366, 0.09664662647992373, 0.15314600255806, 0.1988592863199301, 0.18480297963833436, 0.113326952123316, 0.23229073849506676, 0.19559733947971836, 0.1830108859576285, 0.19013222336070612, 0.14143856358714402, 0.15290306793758646, 0.22267470136284828, 0.16422778135165572, 0.16196878772461787, 0.15200855734292418, 0.12530314503237605, 0.15596367011312395, 0.19259434280684218, 0.16229313594521955, 0.1529151204158552, 0.0905128575686831, 0.12006775330519304, 0.18252886104164645, 0.20817908778553829, 0.0970169210631866, 0.15699412731919438, 0.20845672523137182, 0.1763414719607681, 0.14074821781832725, 0.08729683482670225, 0.09820487684919499, 0.11894928480614908, 0.11096201691543683, 0.1316799598862417, 0.1791117459652014, 0.20840337965637445, 0.13045611383859068, 0.22788861533626914, 0.2170609775930643, 0.14834203611826524, 0.11114970606286079, 0.21279647829942405, 0.31577733519952744, 2.2652047500014305, 15.416006483137608, 37.70765282213688, 50.23417845368385, 45.09413346648216, 47.604966536164284, 69.17982503771782, 55.37102781236172, 36.358428820967674, 28.278302997350693, 21.71757884323597, 14.816968627274036, 7.322211842983961, 2.1723868930712342, 0.6352470628917217, 0.6871879007667303, 1.2116477522067726, 7.3957169987261295, 10.079378094524145, 10.880315266549587, 10.917115341871977, 13.195636477321386, 11.396565064787865, 8.352169375866652, 10.869001373648643, 7.161080539226532, 8.899548053741455, 6.8924349546432495, 6.455308785662055, 9.423395544290543, 5.54817158728838, 0.534786272328347, 1.0036946483887732, 2.6772325532510877, 2.838637442328036, 8.060060050338507, 6.810219241306186, 9.233892112970352, 13.710235264152288, 18.702368438243866, 18.378270529210567, 27.853996865451336, 27.03179318457842, 31.74317367374897, 31.084741204977036, 25.21311577409506, 22.538788877427578, 17.792062684893608, 9.612340405583382, 4.356815814971924, 2.344207023270428, 0.7837097870651633, 3.091787933371961, 3.3691723365336657, 5.348781086504459, 5.3837700840085745, 4.033062262460589, 9.427352081984282, 7.106569139286876, 12.21862530335784, 7.3885605577379465, 8.924384471029043, 12.150627952069044, 9.850755762308836, 10.491645522415638, 6.598924454301596, 4.468449549749494, 1.9438969600014389, 1.5019081206992269, 3.1729641649872065, 5.6860253401100636, 11.389787178486586, 19.24760688096285, 23.25094286352396, 24.149429351091385, 17.95195620507002, 20.95172043889761, 31.09271887689829, 34.42141816020012, 30.60722842812538, 13.259156718850136, 2.900026710703969, 0.16705607646144927, 0.21175656613195315, 0.06877002349938266, 0.16260753938695416, 0.1512054496561177, 0.16193239280255511, 0.1876547117717564, 0.1331824972294271, 0.2378336020046845, 0.309139002347365, 0.2415435982402414, 0.19396268500713632, 0.12622950860532, 0.11049107226426713, 0.15558570914436132, 0.17738641588948667, 0.12380748739815317, 0.13526609167456627, 0.16797596850665286, 0.12066473689628765, 0.10124221269506961, 0.11058409305405803, 0.12660613370826468, 0.2157283475389704, 0.12940619752043858, 0.14011046063387766, 0.11094564513769001, 0.19220985093852505, 0.09014761701109819, 0.21248510282021016, 0.18478365411283448, 0.2017461962532252, 0.10025648472947069, 0.11894284296431579, 0.21060320927063003, 0.23644612723728642, 0.17459312046412379, 0.09054881462361664, 0.19820201065158471, 0.14511387184029445, 0.13112118205754086, 0.10645505055435933, 0.13080367643851787], [0.02435100446746219, 0.038771553518017754, 0.05514181357284542, 0.019632431394711602, 0.043219715807936154, 0.053668424079660326, 0.012853351163357729, 0.03031159136298811, 0.007885591803642455, 0.019517656401148997, 0.021311095224518795, 0.027241422903898638, 0.008208175568142906, 0.02616622718051076, 0.012128617981943535, 0.03910767591150943, 0.056211393093690276, 0.014051458601898048, 0.04216316097881645, 0.02397289135842584, 0.04270955236279406, 0.037099984619999304, 0.03823790109890979, 0.03397159838641528, 0.05305453065375332, 0.013682219723705202, 0.04032132485008333, 0.09298035016399808, 0.048203278274741024, 0.031205992490868084, 0.013972374417789979, 0.012683220302278642, 0.05033253335568588, 0.056590701060486026, 0.025764914535102434, 0.014645378050772706, 0.048468083987245336, 0.028614987968467176, 0.011028588141925866, 0.03169159455865156, 0.014599505902879173, 0.03371350911038462, 0.022468754686997272, 0.039578060241183266, 0.07136874264688231, 0.040766246092971414, 0.030058047741476912, 0.016213110284297727, 0.09552124858601019, 0.052879120339639485, 0.005627977179756272, 0.036098909040447325, 0.948036719346419, 4.750696029514074, 22.907238006591797, 34.65274974703789, 38.88859525322914, 32.41216577589512, 14.692093078047037, 10.25324346497655, 9.357073903083801, 10.094561129808426, 6.3130078464746475, 10.82439936697483, 8.271231818944216, 4.363768491894007, 1.4171168580651283, 0.42527879064437, 0.06829909369116649, 1.1885334737598896, 1.4556096238084137, 2.2306007193401456, 1.0621789726428688, 4.763031592592597, 6.470622913911939, 4.798079486936331, 1.9015738810412586, 4.3260906636714935, 8.115958850830793, 2.9899747716262937, 4.689568234607577, 12.250822875648737, 0.6270785699598491, 1.1196682252921164, 0.08947354654083028, 1.1277607223019004, 1.1586593580432236, 0.609755952609703, 0.7617057021707296, 2.0424200920388103, 4.300806345418096, 3.2304275315254927, 5.144521621987224, 5.01916017383337, 5.220422074198723, 4.523053094744682, 3.708312213420868, 3.9154148753732443, 1.5828792820684612, 0.36988236475735903, 0.46048259537201375, 0.8980741503182799, 0.22925667552044615, 3.0699146445840597, 6.666174670681357, 1.1462232191115618, 3.399215661920607, 2.059224215336144, 3.140040119178593, 2.9861858999356627, 2.566037932410836, 2.1027204813435674, 3.936921008862555, 4.039983591064811, 3.552322508767247, 3.089435384608805, 1.0523645742796361, 0.8131507260259241, 0.5556131922639906, 3.452219730243087, 9.210556615144014, 12.076766565442085, 7.6019438076764345, 12.97116257250309, 14.020139034837484, 17.37176913768053, 22.325548119843006, 26.93714026361704, 25.78117959201336, 19.39512636512518, 7.665729084983468, 1.09421149129048, 0.03400511006475426, 0.06338787949061953, 0.06283290887949988, 0.018172302225138992, 0.06199558076332323, 0.024700999456399586, 0.05797599020297639, 0.048900444380706176, 0.027739741672121454, 0.033763652318157256, 0.018855721900763456, 0.02479363618476782, 0.053695171081926674, 0.04229484395182226, 0.02790377115161391, 0.010052963589259889, 0.04243167000822723, 0.01310755158556276, 0.004507033154368401, 0.02378414836130105, 0.015427246398758143, 0.05074042514024768, 0.02620027506054612, 0.05531734263058752, 0.0370065890456317, 0.02621306040964555, 0.05432233781903051, 0.026582514510664623, 0.01671820857154671, 0.08613642014097422, 0.08017390180611983, 0.047778161242604256, 0.011295528456685133, 0.005584103728324408, 0.11217268242035061, 0.048898459135671146, 0.022427344702009577, 0.0625446809863206, 0.04050331801408902, 0.0670192897086963, 0.06688648238196038, 0.053261652938090265, 0.02249234756163787, 0.019845839669869747, 0.03335180117574055, 0.06727809886797331, 0.009309789893450215, 0.05249898116744589, 0.08693619558471255, 0.01573604477016488, 0.05467833863804117, 0.02697269865166163, 0.0904744588478934, 0.04626821355486754, 0.055113059061113745, 0.06615108824917115, 0.09657157308538444, 0.055277574647334404, 0.08527435624273494, 0.021526781893044244, 0.015025342818262288, 0.10208145555225201, 0.04256400978192687, 0.0563364338449901, 0.12054062011884525, 0.04518347937846556, 0.06263927512918599, 0.04297245075576939, 0.01588623876159545, 0.036683131402242, 0.06987961591221392, 0.07222489162813872, 0.07345940233790316, 0.031376556580653414, 0.04922303000057582, 0.025025060094776563, 0.03954486397560686, 0.09262305058655329, 0.035790350011666305, 0.08423246996244416, 0.021424797814688645, 0.027852787461597472, 0.05266199390462134, 0.0033222006504729507, 0.02863754183636047, 0.06996287746005692, 0.02130197794031119, 0.0564714824577095, 0.03545177482010331, 0.0673516234382987, 0.032484267649124376, 0.027050190001318697, 0.007394704252874362, 0.04530128418991808, 0.03263671220338438, 0.08635363934445195, 1.7498520598746836, 8.708674795925617, 29.740458838641644, 38.63563522696495, 42.98351392149925, 36.700896844267845, 16.85719884932041, 11.646406408399343, 12.427456397563219, 14.280388969928026, 15.732367057353258, 18.1509705260396, 12.143135704100132, 6.002376414835453, 1.7057943739928305, 0.29611074831336737, 0.07641243762918748, 0.44773181551136076, 0.20031356922117993, 0.6492207536939532, 0.8742969261948019, 2.970360699109733, 1.2617965112440288, 5.2197756338864565, 4.7039001155644655, 5.058281924575567, 5.142014231532812, 5.173965767025948, 9.284657388925552, 10.604603961110115, 3.65532239433378, 2.672167900018394, 2.3577269352972507, 4.423622405156493, 2.458568774163723, 1.2899020593613386, 1.800567819736898, 3.701459518633783, 6.077013909816742, 5.211897706612945, 7.677195444703102, 7.739143995568156, 8.292441330850124, 6.941406251862645, 6.230592643842101, 6.384414564818144, 2.5295743765309453, 1.034527737647295, 1.6302265226840973, 2.556676659733057, 2.800657767802477, 6.387739861384034, 9.379012025892735, 3.337257136590779, 4.253192525357008, 4.065290708094835, 3.5388964042067528, 5.5740543734282255, 4.458201974630356, 5.369873279705644, 3.0751308146864176, 1.7680774256587029, 1.5514555620029569, 0.5779556964989752, 0.9989669895730913, 0.7102106278762221, 1.2071322882547975, 4.2467281222343445, 10.542834475636482, 15.214066319167614, 14.641387648880482, 17.094195932149887, 18.250669576227665, 16.241041012108326, 18.869808353483677, 27.597949504852295, 29.115876853466034, 24.190463349223137, 12.209454495459795, 2.141337334178388, 0.08614312173449434, 0.05932695872616023, 0.04595190279360395, 0.020132800345891155, 0.03345098921272438, 0.040078011734294705, 0.023332124765147455, 0.016657473061059136, 0.03095867363299476, 0.061495332411141135, 0.04594483754772227, 0.008216149944928475, 0.030206338124116883, 0.045706648961640894, 0.07869713925174437, 0.05636160378344357, 0.02528400469600456, 0.01161983029305702, 0.007485984706363524, 0.043674374028341845, 0.038793209387222305, 0.017530099576106295, 0.02618306280055549, 0.04969809728208929, 0.027651711825456005, 0.07672926047234796, 0.025900118998833932, 0.03738165563845541, 0.04128723747271579, 0.006165350077935727, 0.07400378250167705, 0.03579073592845816, 0.05361197632737458, 0.044740654702764004, 0.08061298605753109, 0.016277105678454973, 0.049526709408382885, 0.04597696883138269, 0.08812501226202585, 0.13554867182392627, 0.0375916463235626, 0.017548848081787582, 0.023259759800566826, 0.0385020871181041, 0.09612196517991833, 0.12988183996640146, 0.11447337732533924, 0.176756510627456, 0.1855500997044146, 0.1278559400816448, 0.19562972680432722, 0.10441919104778208, 0.1791687577497214, 0.08558260728023015, 0.17963231803150848, 0.16770253161666915, 0.16924315597862005, 0.1257662897114642, 0.16105484770378098, 0.12507551349699497, 0.14075240353122354, 0.14923976763384417, 0.18678495922358707, 0.23318570922128856, 0.171029876510147, 0.13080193981295452, 0.1553606305969879, 0.129501934570726, 0.14400311425561085, 0.09426485194126144, 0.2837948373053223, 0.24447744159260765, 0.09446297568501905, 0.05836361393448897, 0.1041889916814398, 0.18391237274045125, 0.14423022628761828, 0.18234826682601124, 0.173335803556256, 0.18223038408905268, 0.20089594734599814, 0.17011679738061503, 0.11923673344426788, 0.11901348058017902, 0.09519598010228947, 0.14577111782273278, 0.12897095759399235, 0.1254028154653497, 0.37358348490670323, 0.19621744839241728, 0.15286588633898646, 0.09668124024756253, 0.19919384649256244, 0.11598193348618224, 0.11123217351268977, 0.21802851551910862, 1.5309054334647954, 8.668089173734188, 33.64950858056545, 46.1466009914875, 50.96446506679058, 43.13465841114521, 22.76632446795702, 15.956098102033138, 14.253358170390129, 14.736175462603569, 13.491217866539955, 15.983078554272652, 12.09067476913333, 5.957189239561558, 2.0781564619392157, 0.958821609383449, 0.6361448834650218, 2.8037804877385497, 5.806123595684767, 4.769823728129268, 7.894746595993638, 12.975337598472834, 14.178423341363668, 11.931189727038145, 7.6127836760133505, 12.117038704454899, 16.17926962673664, 9.041795320808887, 14.275776967406273, 19.63663000613451, 4.37292980030179, 3.7146243872120976, 1.5894494857639074, 3.7000600062310696, 2.7415930246934295, 1.361352950334549, 1.5456685912795365, 2.8780406154692173, 5.706795500591397, 4.809178691357374, 8.082965221256018, 7.716144779697061, 7.944833608344197, 6.04258680716157, 5.107710622251034, 5.06058887578547, 2.591082388535142, 0.8942528022453189, 1.4986881497316062, 1.3570920727215707, 1.6830109152942896, 6.346155842766166, 10.548457223922014, 4.901143731549382, 9.310840833932161, 6.2469184678047895, 7.652124864980578, 9.186259768903255, 6.352968402206898, 9.087539166212082, 11.276720445603132, 9.947198387235403, 9.507097452878952, 7.084865653887391, 2.97887010499835, 1.7458273633383214, 1.5835910313762724, 4.399513648822904, 12.488552369177341, 17.702507190406322, 11.935668736696243, 20.596752986311913, 23.376691415905952, 23.92854530364275, 31.188935413956642, 37.41077475249767, 36.11509367823601, 27.950466088950634, 11.49433571845293, 2.07835856359452, 0.1842167868744582, 0.11872403556481004, 0.12506629602285102, 0.12277478148462251, 0.09107473757467233, 0.11092481305240653, 0.22963478491874412, 0.2007531136041507, 0.11493652942590415, 0.14175004296703264, 0.11644477388472296, 0.13771514932159334, 0.13568737922469154, 0.12491409637732431, 0.18480765516869724, 0.17545261653140187, 0.12457419274142012, 0.2521212212741375, 0.14032788021722808, 0.1429725531488657, 0.2668100455775857, 0.16973655059700832, 0.1329573296243325, 0.1466525814612396, 0.12396936464938335, 0.11042965954402462, 0.18710538890445605, 0.08125986423692666, 0.10291478349245153, 0.17085250321542844, 0.27801338816061616, 0.13017846154980361, 0.11379601171938702, 0.18088259937940165, 0.12405899382429197, 0.10557716406765394, 0.0908923770475667, 0.15687413688283414, 0.14762761507881805, 0.15567332709906623, 0.20756221463670954, 0.12295392109081149, 0.09144454976194538, 0.12345720853772946], [0.034499154062359594, 0.1051251961325761, 0.03021993241418386, 0.011735732423403533, 0.03558086769771762, 0.049132172571262345, 0.0107579955329129, 0.03458644547208678, 0.01978994667297229, 0.06112206552643329, 0.06708213477395475, 0.05533153620490339, 0.006078378719394095, 0.03726887887751218, 0.050438330217730254, 0.04296029066608753, 0.020660064728872385, 0.03076955214055488, 0.035864323581336066, 0.004644693199225003, 0.052951067846152, 0.02788364410662325, 0.07306282088393345, 0.043112750063301064, 0.04372520743345376, 0.012930481643707026, 0.05059591043391265, 0.05939522146945819, 0.04845407594984863, 0.03453016470302828, 0.07795214914949611, 0.12159228048403747, 0.039467409733333625, 0.0234733610341209, 0.10565624732407741, 0.012502094523370033, 0.1240617991425097, 0.04416233983647544, 0.03406465628359001, 0.036219508037902415, 0.03262153157265857, 0.0310925403755391, 0.021840933004568797, 0.027651927048282232, 0.03921653042198159, 0.03119774723018054, 0.011832838736154372, 0.04889449606707785, 0.07950601342599839, 0.046070486860116944, 0.041576137009542435, 0.015185980682872469, 0.016165080342034344, 0.14938665350200608, 4.295408260077238, 20.313713774085045, 33.36150303483009, 44.04902994632721, 46.941111758351326, 35.52042178809643, 26.958289928734303, 19.770348630845547, 17.957682497799397, 10.74812225997448, 11.174148749560118, 8.305088002234697, 7.06976811401546, 3.8057983573526144, 0.9143098478671163, 0.6082598422653973, 0.20253913651686162, 0.6180275743827224, 1.2685407930985093, 1.4473760593682528, 1.653512860648334, 3.9732689084485173, 2.2921080188825727, 3.3448835648596287, 4.020333895459771, 4.508255263790488, 10.386197380721569, 10.23237593472004, 3.975563272833824, 2.807982824742794, 1.978302807547152, 5.100515708327293, 1.543018352240324, 1.1170215485617518, 0.3191006724955514, 0.13440756039926782, 0.3312955243745819, 0.878874552436173, 0.37118670414201915, 0.55019207065925, 0.057262730624643154, 0.02973998365632724, 0.10803098630276509, 0.23826496792025864, 0.026452280580997467, 0.29168549983296543, 1.3597407680936158, 4.401013143360615, 4.851505570113659, 8.252497874200344, 11.757909525185823, 2.0191710395738482, 1.4522716216742992, 3.1217581126838923, 1.5990519267506897, 3.975521237589419, 3.083570161834359, 3.6911133863031864, 1.6971408133395016, 2.129817777313292, 1.8838059157133102, 0.9198032249696553, 0.9651260648388416, 1.454591159708798, 5.097725708037615, 9.100697860121727, 36.091139763593674, 24.775540754199028, 23.25185101479292, 15.798206124454737, 15.495045091956854, 21.653673872351646, 27.17831712216139, 29.321671910583973, 20.488563291728497, 7.5006108451634645, 1.0583479469642043, 0.06971093316678889, 0.0434381038940046, 0.03362382427440025, 0.02171633383113658, 0.02390083624050021, 0.05929838975134771, 0.044066086993552744, 0.04020385029434692, 0.03574115675291978, 0.02631237090099603, 0.00976942699708161, 0.013578288435383001, 0.007305795425054384, 0.055616661920794286, 0.037264110578689724, 0.0334496570576448, 0.018133435951313004, 0.08075505538727157, 0.05200030987907667, 0.03365673481312115, 0.022895899637660477, 0.05838216020492837, 0.028917272138642147, 0.038218950357986614, 0.046896846033632755, 0.03459010797087103, 0.02802558541588951, 0.014989825485827168, 0.04940272992826067, 0.08595285733463243, 0.015008060054242378, 0.07279993733391166, 0.03278429197962396, 0.05098842491861433, 0.053015853627584875, 0.06161265111586545, 0.02666519161721226, 0.0762691511772573, 0.057895400386769325, 0.060254346462897956, 0.021365871289162897, 0.07738551197689958, 0.04726537059468683, 0.038382115235435776, 0.02667708267836133, 0.025282668830186594, 0.08096759906038642, 0.03067400804866338, 0.08871970261679962, 0.04805670781934168, 0.017655806404945906, 0.03471131552942097, 0.03747209375433158, 0.021201938288868405, 0.03180842715664767, 0.10322732414351776, 0.025024887545441743, 0.020251451205695048, 0.08119975027511828, 0.09412391809746623, 0.0714945218351204, 0.030441213020822033, 0.024125122545228805, 0.005060816793047707, 0.023183465164038353, 0.025700189980852883, 0.029579089750768617, 0.10141755250515416, 0.01805547519325046, 0.0677397073013708, 0.05630186089547351, 0.05278559488942847, 0.01780373127985513, 0.02722941124375211, 0.012627872783923522, 0.01928120072989259, 0.027862255410582293, 0.028511632772278972, 0.006448896410802263, 0.03902638105500955, 0.0767962021927815, 0.04171562737610657, 0.028092148641007952, 0.04761058429721743, 0.04690564048360102, 0.011762637132051168, 0.05737406390835531, 0.042484555451665074, 0.01419009457094944, 0.020148006951785646, 0.06473058791016228, 0.04109259811230004, 0.05277072596072685, 0.0777691652183421, 0.012350615688774269, 0.04224673051794525, 0.027311361045576632, 0.027671529023791663, 0.27385356137529016, 6.5615990571677685, 25.56994892656803, 38.6189541220665, 45.19692935049534, 39.15701285004616, 25.120305754244328, 13.094060327857733, 11.26738054677844, 11.311986353248358, 13.117648512125015, 19.748370610177517, 16.179719902575016, 12.055185623466969, 4.852764727547765, 1.1790162906982005, 0.23791500076185912, 0.061303516922635026, 0.1617003677529283, 0.3541042754659429, 1.0520852892659605, 1.0857894807122648, 1.5467718383297324, 2.421318660490215, 3.1907369988039136, 5.811871737241745, 3.8313557859510183, 4.9125592689961195, 8.557969182729721, 5.942025678232312, 4.389111706987023, 5.032242871820927, 4.313185131177306, 3.228618116118014, 1.801461603026837, 1.1774416314437985, 0.5019807920325547, 1.0146483918651938, 1.516907934565097, 0.9244119620416313, 0.9785332891624421, 0.6856710696592927, 0.37054397456813604, 0.42984632367733866, 0.38225165102630854, 0.35491763963364065, 0.7111503055784851, 2.7129354374483228, 5.473984843119979, 4.71213617362082, 8.21170611307025, 7.3397265281528234, 6.007882319390774, 3.4426390193402767, 4.211984686553478, 3.48019786644727, 4.044404653832316, 2.6778360083699226, 3.1735077733173966, 2.23194750957191, 0.57338074198924, 0.8626044786069542, 0.5256984068546444, 1.0574223403818905, 2.1050898917019367, 9.09266509115696, 12.42767108604312, 36.26209259033203, 27.649108059704304, 18.050912395119667, 12.610219940543175, 12.80634356662631, 20.898259207606316, 31.346290670335293, 33.82085278630257, 25.047131180763245, 11.33089603856206, 1.586093078367412, 0.053361056197900325, 0.040774187073111534, 0.05653014923154842, 0.07362312753684819, 0.024989674493554048, 0.057158243653248064, 0.042856037471210584, 0.06490039872005582, 0.08458220705506392, 0.020723304987768643, 0.019003542874997947, 0.015926019732432906, 0.03621164127252996, 0.011473952818050748, 0.041655880777398124, 0.05150533077539876, 0.06911737087648362, 0.025211838255927432, 0.03158617619192228, 0.02262177069496829, 0.043253064213786274, 0.07555771357147023, 0.032361371704610065, 0.03573323803720996, 0.021178551360208075, 0.02450074018270243, 0.030293397612695117, 0.013868959849787643, 0.022617460672336165, 0.027341967215761542, 0.03180431194778066, 0.014850777624815237, 0.02560107059252914, 0.04116322088520974, 0.033989473013207316, 0.009492309054621728, 0.06476025897427462, 0.014269554467318812, 0.020789682675967924, 0.0426756807428319, 0.00446947769887629, 0.08187566127162427, 0.02086179159960011, 0.03479862920357846, 0.03718218118592631, 0.13815831538522616, 0.20887845807010308, 0.21424650127300993, 0.1403719192603603, 0.09770177493919618, 0.10683135653380305, 0.12277783913305029, 0.14031609491212294, 0.1382495550205931, 0.16336203640094027, 0.19430658139754087, 0.28141263232100755, 0.09038465897901915, 0.16720909246942028, 0.1767768306308426, 0.23809719801647589, 0.10645383343216963, 0.14984534529503435, 0.10489193911780603, 0.14748623594641685, 0.1832308733719401, 0.11232740536797792, 0.23141320823924616, 0.08826861783745699, 0.15159320697421208, 0.12787762563675642, 0.18688887474127114, 0.08100180464680307, 0.20429051597602665, 0.09875432588160038, 0.1190105639398098, 0.20235544012393802, 0.0774118656408973, 0.092154094891157, 0.16931318503338844, 0.20851946639595553, 0.20418569503817707, 0.11977466434473172, 0.16868267121026292, 0.1157491366029717, 0.13737353874603286, 0.14265538891777396, 0.09872011287370697, 0.09766991453943774, 0.21177148330025375, 0.09850560993072577, 0.16387588460929692, 0.17930563946720213, 0.2051353917340748, 0.1343969180015847, 0.15706742182374, 0.13492258120095357, 0.06112136419687886, 0.40815159562043846, 6.958896238356829, 25.800330564379692, 44.97709974646568, 55.83483852446079, 58.28595779836178, 44.43758949637413, 36.10540419816971, 27.864294312894344, 25.696974210441113, 16.50891713798046, 19.428967349231243, 13.448486309498549, 10.241892524063587, 5.1704310066998005, 1.6241271374747157, 0.9765847655944526, 0.6938622426241636, 1.5368838189169765, 2.804661802947521, 5.360692022368312, 6.595806246623397, 10.074749942868948, 10.175623130053282, 11.277800537645817, 10.703238118439913, 10.346191227436066, 25.242963172495365, 23.690837658941746, 9.218687228858471, 6.725248200818896, 5.027942452579737, 8.551237843930721, 4.054829869419336, 3.5256952000781894, 0.9077122143935412, 0.6517192383762449, 0.8198202587664127, 1.4638810674659908, 0.9682579280342907, 1.0163967730477452, 0.4620204144157469, 0.4486210865434259, 0.36131272616330534, 0.7502016413491219, 0.16825835569761693, 0.8314227580558509, 2.922161710448563, 7.678197165951133, 7.315902756527066, 15.901116952300072, 21.68323438614607, 9.965655896812677, 4.965109499171376, 9.782424978911877, 7.804870493710041, 9.838306680321693, 11.119687221944332, 11.526139061897993, 6.166684348136187, 5.977005176246166, 3.868808476254344, 2.2080890648066998, 1.9879381405189633, 2.5278072338551283, 7.699299333617091, 11.769345961511135, 44.13441136479378, 32.23356015980244, 30.526015385985374, 24.303653575479984, 22.143872268497944, 31.265134625136852, 37.97629460692406, 39.92441587150097, 27.029587402939796, 11.663798075169325, 1.8139492766931653, 0.13596878678072244, 0.30458438268397003, 0.20388475415529683, 0.1577432660269551, 0.19142269942676648, 0.17584579152753577, 0.10212367633357644, 0.15570114279398695, 0.17907287226989865, 0.20387339929584414, 0.07664547942113131, 0.10005537755205296, 0.1871947880135849, 0.09069667270523496, 0.1304899260867387, 0.1415864736190997, 0.19819093780824915, 0.20503017003647983, 0.12418959697242826, 0.08556803149986081, 0.22286213818006217, 0.17247998854145408, 0.1304458870436065, 0.09802770393434912, 0.1305583817884326, 0.1748987814062275, 0.09639627780416049, 0.1454328914405778, 0.07356791174970567, 0.12417778940289281, 0.10578573725069873, 0.09828725524130277, 0.10321888592443429, 0.11285574029898271, 0.13653543137479573, 0.06653675271081738, 0.09373658380354755, 0.0978436364675872, 0.11512488650623709, 0.13922344573074952, 0.04508347497903742, 0.17535745835630223, 0.13718835805775598, 0.07586536346934736, 0.12866235774708912], [0.050964082474820316, 0.01411834095051745, 0.02229426463600248, 0.01112844411181868, 0.04561385081615299, 0.02306261012563482, 0.031203253965941258, 0.012336806175881065, 0.08399853017181158, 0.03237721284676809, 0.02780999337119283, 0.0877303232846316, 0.0314315348805394, 0.057196746274712496, 0.021939002253930084, 0.03732651406608056, 0.03418183026951738, 0.050441922212485224, 0.06617205392103642, 0.0038625217302978854, 0.03594987094402313, 0.017588289520062972, 0.0023411834672515397, 0.060325930317048915, 0.02671470956556732, 0.004856675159317092, 0.08591603196691722, 0.04367833709693514, 0.03880115407810081, 0.005737357223551953, 0.04023839355795644, 0.05723272930481471, 0.033446577144786716, 0.08598950458690524, 0.08987268098280765, 0.004307577255531214, 0.07144429328036495, 0.0491555316693848, 0.01685173763689818, 0.026742547524918336, 0.06217782625753898, 0.05780563020380214, 0.017059269957826473, 0.05607696788501926, 0.05419623579655308, 0.023445862607331946, 0.062487721152137965, 0.05804307293146849, 0.04921700376144145, 0.03538672928698361, 0.001587865888268425, 0.017469608974352013, 0.06851622383692302, 0.07702223068918101, 0.08960987164755352, 0.8882198540959507, 11.831552423536777, 26.24454002827406, 37.65361212193966, 39.91250351071358, 36.15961588919163, 35.36798916757107, 28.633967712521553, 26.243282295763493, 24.38284892588854, 19.27223525941372, 17.32890173792839, 11.192868445068598, 8.171673361212015, 3.616950628347695, 1.2933577364310622, 0.4561289196135476, 0.10609222197672352, 0.7472999626770616, 0.27237882488407195, 1.1489055189304054, 1.924407093320042, 1.385304608847946, 4.467040775343776, 5.6908805295825005, 2.4839939223602414, 4.756904421374202, 3.632677746936679, 4.762728558853269, 8.895681761205196, 5.416155271232128, 3.0847682850435376, 0.9846371866296977, 2.1639632200822234, 0.9171965648420155, 1.4004660327918828, 1.0500823217444122, 0.1809130422770977, 0.5689920368604362, 0.6497591966763139, 0.5058597901370376, 0.4518907517194748, 0.4968111397465691, 1.6159415454603732, 0.35033692605793476, 1.9094722322188318, 5.048206290230155, 5.570597983896732, 6.6786551009863615, 5.719469245523214, 3.8291915645822883, 3.2824735762551427, 2.1939861215651035, 1.3759464235045016, 3.051008046604693, 1.1410756828263402, 2.4656240455806255, 1.1277563287876546, 0.27023802569601685, 0.4207565583055839, 1.6591384587809443, 5.39492248557508, 10.82344276830554, 10.269071515649557, 17.53752764314413, 57.14780867099762, 24.38395656645298, 16.01821906864643, 16.940023005008698, 24.135888777673244, 27.808676697313786, 25.290358029305935, 18.1538013741374, 6.194856986403465, 0.622463955078274, 0.08579201909014955, 0.02838915985194035, 0.015020662649476435, 0.09221353349857964, 0.011620825698628323, 0.01881045645859558, 0.04090850467036944, 0.0524063128978014, 0.045175768464105204, 0.05668660880473908, 0.023537768320238683, 0.045782344313920476, 0.02871935248549562, 0.03010538377566263, 0.03882562639773823, 0.022704301227349788, 0.013882823168387404, 0.050475938551244326, 0.037689654345740564, 0.04799222260771785, 0.011987676716671558, 0.025414017836737912, 0.02090463021886535, 0.06117846132838167, 0.09356776747154072, 0.05019118390919175, 0.027022070025850553, 0.044306412964942865, 0.027620369073702022, 0.027479034470161423, 0.011322715181449894, 0.02381703849096084, 0.03145979957480449, 0.03815241310803685, 0.09508663206361234, 0.09793407458346337, 0.05300689590512775, 0.09645360129070468, 0.03218526748241857, 0.01922443199873669, 0.05480263724166434, 0.03978154229116626, 0.016882993186300155, 0.025078882499656174, 0.03280658980656881, 0.04518409907177556, 0.017021084604493808, 0.024150411227310542, 0.024954541222541593, 0.03673808001622092, 0.019798440553131513, 0.004588383208101732, 0.03965047530073207, 0.01176064261017018, 0.03709596589033026, 0.07928675331640989, 0.0332641906425124, 0.08456424708128907, 0.03674212843179703, 0.027845035729114898, 0.018554973976279143, 0.03055436085560359, 0.03306574777525384, 0.021859616572328378, 0.0500436635047663, 0.01929785452375654, 0.05724380956962705, 0.15156267501879483, 0.05009361746488139, 0.04585359420161694, 0.021527128847083077, 0.050181721526314504, 0.02493013013008749, 0.03940559625334572, 0.030137314679450355, 0.044928855932084844, 0.0675759524165187, 0.037501957776839845, 0.0374769140034914, 0.0449168479826767, 0.023323595632973593, 0.03148178569972515, 0.029813248474965803, 0.024856781819835305, 0.03924927026673686, 0.048923796057351865, 0.03321265961858444, 0.005331315705916495, 0.020961829395673703, 0.07959138267324306, 0.08896660030586645, 0.0644212459155824, 0.0656239630188793, 0.019050828814215492, 0.06052265140169766, 0.02419005675619701, 0.025602590139897075, 0.05533569223189261, 0.043665731718647294, 0.050067686825059354, 0.07913038280094042, 2.0873367693275213, 15.776532087475061, 33.77220019698143, 47.236903086304665, 43.87414813041687, 35.600924268364906, 24.746854193508625, 20.031778402626514, 16.17946721613407, 23.74419629573822, 20.930112898349762, 23.664106093347073, 19.836031906306744, 9.691272620111704, 4.067140258848667, 1.1414332198910415, 0.6171073706354946, 0.12088986739399843, 0.279829571954906, 0.1643512153532356, 0.7181463832966983, 0.43156059575267136, 1.1839382140897214, 1.7705699731595814, 1.4485230040736496, 1.540896522346884, 3.697488969191909, 5.043588588014245, 4.288482181727886, 5.541501995176077, 4.4144097995013, 4.594222800806165, 2.6585746044293046, 3.162701390683651, 1.6672691912390292, 0.9181957331020385, 1.3046441995538771, 0.7354973210021853, 1.5789019642397761, 1.1000954755581915, 1.6120423609390855, 1.9902728777378798, 1.0933441878296435, 2.617021696642041, 2.3904018569737673, 3.5379402805119753, 8.05575393140316, 10.30421582981944, 7.910155244171619, 5.896776281297207, 4.708368675783277, 2.8829504270106554, 2.924381741322577, 2.207943960092962, 1.8250889726914465, 1.2993958499282598, 0.10142805389477871, 0.37478615005966276, 0.11024145831470378, 0.48659470514394343, 2.2690271073952317, 5.904711680486798, 15.216398444026709, 16.180472262203693, 18.383269160985947, 63.170192912220955, 27.6554062217474, 14.998338595032692, 14.396931566298008, 23.380014337599277, 31.260306984186172, 28.916780836880207, 24.297378212213516, 9.70844104886055, 1.2585409171879292, 0.17482404713518918, 0.01944158626429271, 0.009470453733229078, 0.09813679222133942, 0.03514818447001744, 0.018215754971606657, 0.018549973756307736, 0.05914419001783244, 0.012832944885303732, 0.04574961189064197, 0.01988847419852391, 0.05987261167319957, 0.06851406418718398, 0.05622966476948932, 0.04380885118735023, 0.026785107838804834, 0.03859760152408853, 0.009244672000932042, 0.018027158548648003, 0.06783837583498098, 0.01617753914615605, 0.06557243570568971, 0.028196177336212713, 0.028256758851057384, 0.055403361257049255, 0.047146764263743535, 0.04118833887332585, 0.027111012714158278, 0.019285243579361122, 0.012372634282655781, 0.007218378777906764, 0.01682395533862291, 0.06634171630139463, 0.05841215039254166, 0.06363528926158324, 0.06580952220247127, 0.07115837346646003, 0.0648305552022066, 0.01336425768386107, 0.010824045748449862, 0.007444668881362304, 0.060581485158763826, 0.0133673273921886, 0.0956671177118551, 0.06341346132103354, 0.012686541413131636, 0.10468470922205597, 0.10022639806265943, 0.08650877789477818, 0.14327702665468678, 0.12746739608701319, 0.08194438414648175, 0.16872788284672424, 0.1405425093253143, 0.15639022691175342, 0.14357670588651672, 0.13814008823828772, 0.23596319690113887, 0.1713783000013791, 0.0818521945620887, 0.10658305618562736, 0.07681117131141946, 0.13922062556957826, 0.13779653323581442, 0.11350874119671062, 0.16929755540331826, 0.14543255005264655, 0.23830808670027182, 0.1453996283817105, 0.08606696253991686, 0.1025912219483871, 0.10496406102902256, 0.13993041560752317, 0.20130153105128556, 0.10897792963078246, 0.10629777461872436, 0.19168074417393655, 0.12783048441633582, 0.1546183048048988, 0.2561774739297107, 0.1270982073037885, 0.08586005176766776, 0.237753375840839, 0.12102021079044789, 0.0799992225074675, 0.09776669801794924, 0.17584012151928619, 0.22610245883697644, 0.14362412912305444, 0.2513547311536968, 0.1594474003650248, 0.13173933170037344, 0.23618555918801576, 0.19818606931949034, 0.16251071880105883, 0.0944298536342103, 0.18787181965308264, 0.10985756016452797, 0.1979063093313016, 0.24049234605627134, 0.21094214811455458, 1.9680828996933997, 16.63060560822487, 35.988898649811745, 51.14261090755463, 52.35875844955444, 47.80874200165272, 44.050192683935165, 39.245677292346954, 35.47602877020836, 34.58945274353027, 26.73895049840212, 25.54067149758339, 17.219990082085133, 10.556421596556902, 5.4239054303616285, 1.7412724765017629, 0.8538201812189072, 0.5262822099030018, 2.0092773204669356, 1.3202019897289574, 3.363962578587234, 5.31436063349247, 5.158279733732343, 10.51018187776208, 13.16896190866828, 9.40226772800088, 13.257871437817812, 11.8181305937469, 12.090929355472326, 20.523958392441273, 13.542482815682888, 9.854321870952845, 3.3919107913970947, 5.171337258070707, 2.6058989809826016, 3.057390279136598, 2.4319975124672055, 1.1549042095430195, 1.4296278054825962, 2.243670355528593, 2.2159952530637383, 1.6312473616562784, 1.4252179046161473, 3.0764191830530763, 2.1892606001347303, 6.196725536137819, 12.442427594214678, 12.03391246497631, 14.123829770833254, 15.023405849933624, 8.631964512169361, 10.766586419194937, 7.80116711743176, 5.903496695682406, 8.483954854309559, 5.1992766838520765, 5.685332352295518, 2.2718185326084495, 0.7339341205079108, 1.2000873475335538, 2.294877120293677, 7.543082591146231, 14.708743784576654, 16.427035331726074, 22.47901238501072, 66.8313230574131, 30.129620656371117, 22.88984254002571, 24.105809591710567, 32.54092566668987, 38.19162905216217, 34.582157135009766, 26.28701414912939, 9.228341560810804, 1.513978885486722, 0.18078732246067375, 0.08325078670168296, 0.10030651290435344, 0.1304383171373047, 0.13194233877584338, 0.08349988856934942, 0.1364054813166149, 0.20560312288580462, 0.11297316290438175, 0.19853795121889561, 0.17343930347124115, 0.2249254274647683, 0.1303860847838223, 0.08765775608480908, 0.21112804126460105, 0.07729632809059694, 0.14459705504123122, 0.13731921353610232, 0.14308380108559504, 0.25469691900070757, 0.08732855421840213, 0.16617911023786291, 0.07302428115508519, 0.13528740615583956, 0.15238901192788035, 0.2124657476088032, 0.10082309221616015, 0.10818989496328868, 0.10594469786155969, 0.14232479181373492, 0.09840533093665726, 0.20057023357367143, 0.11254013457801193, 0.15776317042764276, 0.16727640526369214, 0.17630341462790966, 0.18789448484312743, 0.1832972065312788, 0.13232169498223811, 0.10118243269971572, 0.1622366436640732, 0.14034472696948797, 0.10204405130934902, 0.2086646156385541, 0.12274692868231796, 0.08113137620966882], [0.01886519541585585, 0.008508595092280302, 0.03631516345194541, 0.05243485218670685, 0.06744491882272996, 0.035468443456920795, 0.09456746265641414, 0.06718006858136505, 0.04985046020010486, 0.03904731333022937, 0.024989674493554048, 0.01547528005175991, 0.07884337202995084, 0.015605846092512365, 0.01827719923312543, 0.08075567879131995, 0.06534435888170265, 0.01528559174403199, 0.01579749459779123, 0.05060947689344175, 0.051254588761366904, 0.06035128579242155, 0.06190719468577299, 0.028639156007557176, 0.01977980151423253, 0.04522400435234886, 0.03726503455254715, 0.045902631609351374, 0.06720882680383511, 0.03780669103434775, 0.03353655141836498, 0.021247359582048375, 0.025078656144614797, 0.057224599077017047, 0.07512029173085466, 0.07438563232426532, 0.02017028436966939, 0.03914264219929464, 0.015942417485348415, 0.021406663436209783, 0.06218149988853838, 0.03535713243763894, 0.018352085644437466, 0.03447559829510283, 0.11940071839489974, 0.02800876463879831, 0.07420697511406615, 0.04408182423503604, 0.0738777955120895, 0.03765615008887835, 0.05142175010405481, 0.04399986515636556, 0.024439761618850753, 0.08349470837856643, 0.1092749742383603, 0.04405296582262963, 0.22854655893752351, 3.8222177512943745, 17.796766832470894, 36.47876836359501, 36.55372694134712, 36.45790748298168, 28.804987035691738, 20.887473486363888, 20.737985707819462, 26.38017375022173, 21.719600334763527, 16.384401619434357, 11.837942730635405, 17.935058511793613, 13.169808313250542, 5.708249397575855, 2.9427055455744267, 0.9996760077774525, 0.4479510459350422, 0.42374863056465983, 0.21835871186340228, 1.2431611237116158, 2.6455322792753577, 0.8122865098994225, 0.8445266517810524, 2.543436507694423, 3.371705375611782, 2.3865540884435177, 3.941160631366074, 3.1790141528472304, 3.7534188805148005, 1.6867298469878733, 2.712608417496085, 1.1925643449649215, 0.8220177283510566, 0.9077933162916452, 0.3281616128515452, 1.5375991305336356, 0.6593516631983221, 0.6779637769795954, 2.1010872814804316, 0.13187409087549895, 4.033758575096726, 2.036182014271617, 4.438539454713464, 6.4421553164720535, 8.077117335051298, 6.895619658753276, 3.0666285334154963, 4.569933079183102, 2.1929214661940932, 2.578204167075455, 2.169309058226645, 1.806229397188872, 1.0059969685971737, 1.213797249365598, 1.7353618936613202, 3.0437699100002646, 5.28999206610024, 9.056205097585917, 14.553289376199245, 16.800076514482498, 14.099655468016863, 22.390235848724842, 41.8193855881691, 19.537939801812172, 20.64266212284565, 26.265843585133553, 28.193763233721256, 26.676504649221897, 14.613490495830774, 4.118202868849039, 0.421130214817822, 0.13731582934269682, 0.03616274487285409, 0.03129001102934126, 0.03986593561421614, 0.036644996143877506, 0.039585771155543625, 0.06272255894145928, 0.04960647172993049, 0.02108820601279149, 0.029834672423021402, 0.05586229053733405, 0.015159343147388427, 0.002324532688362524, 0.09810168121475726, 0.046132170464261435, 0.06593149417312816, 0.017325381850241683, 0.019708768704731483, 0.05089389385830145, 0.06836930828285404, 0.02915160897828173, 0.035860063653672114, 0.04565952258417383, 0.06432078138459474, 0.059940907813142985, 0.042637311707949266, 0.036801155147259124, 0.008575401370762847, 0.03971273035858758, 0.05223869513429236, 0.020963905553799123, 0.05376216475269757, 0.05779047554824501, 0.1039582653902471, 0.08190489446860738, 0.042124138853978366, 0.03578974887204822, 0.011422779880376766, 0.07271090929862112, 0.051099439078825526, 0.028590174260898493, 0.056631871702848, 0.03355868968355935, 0.020023754732392263, 0.05603982339380309, 0.10125412416527979, 0.06691072092507966, 0.014954258058423875, 0.010806183181557572, 0.025299702974734828, 0.03642682328063529, 0.030608739871240687, 0.021282452034938615, 0.025301098212366924, 0.035243735983385704, 0.011794271176768234, 0.03066771649173461, 0.06457023206166923, 0.009881057139864424, 0.03728942894667853, 0.03502501764160115, 0.09540589657262899, 0.08008218719623983, 0.04441021716047544, 0.021015282582084183, 0.023741990662529133, 0.03151079254166689, 0.007139014896893059, 0.0431213292904431, 0.018297274327778723, 0.033161863320856355, 0.0116377837730397, 0.060500913896248676, 0.05698159024177585, 0.0564541755738901, 0.051612897659651935, 0.0999211601447314, 0.031053436614456587, 0.01582854791195132, 0.055432201115763746, 0.03156938138999976, 0.09708533965749666, 0.028128458216087893, 0.05071920342743397, 0.0892348050547298, 0.05319116375176236, 0.09126253804424778, 0.01961819885764271, 0.043248900765320286, 0.06068763825169299, 0.06424379098461941, 0.09745859540998936, 0.04571741010295227, 0.019976945623056963, 0.02868164210667601, 0.08463264341116883, 0.039842621044954285, 0.016536734910914674, 0.06645018860581331, 0.019315948084113188, 0.03573767236957792, 0.04089404392288998, 0.015596140656271018, 0.6930272374302149, 6.5995400212705135, 22.853085212409496, 41.73394337296486, 40.31899429857731, 38.71921554207802, 27.808386012911797, 19.680411256849766, 15.211058780550957, 18.95539876073599, 22.245045639574528, 20.423560179769993, 20.198855437338352, 21.54446393251419, 13.493278305977583, 5.139029016718268, 3.5754008078947663, 0.9996288665570319, 0.27339399384800345, 0.08521207520971075, 0.10008236204157583, 0.2513282810105011, 0.24836987257003784, 0.36952880560420454, 0.10091850272146985, 1.6282725962810218, 1.8767301016487181, 1.6582850483246148, 1.4155905274674296, 1.6477547446265817, 0.9689655213151127, 1.2931804521940649, 2.0970675721764565, 2.466694163158536, 1.0140636982396245, 1.8408812815323472, 0.7927115634083748, 1.6076482529751956, 2.4766004690900445, 1.6593170491978526, 2.3860351787880063, 0.9341861656866968, 1.7820056970231235, 2.9603318497538567, 3.078946047462523, 4.305876223370433, 5.698168538510799, 3.751765969209373, 2.410931442864239, 2.8312019538134336, 1.817252249456942, 0.36326190282125026, 0.5186081060674042, 0.5207161023281515, 0.46140947844833136, 0.9282035054638982, 1.582506902050227, 4.022525902837515, 7.732617845758796, 10.35086877644062, 20.167731307446957, 23.057003170251846, 13.056243807077408, 21.434552930295467, 48.62854801118374, 20.190005712211132, 17.20331847667694, 27.486636377871037, 30.917274691164494, 32.06915818154812, 20.055720917880535, 6.271631391718984, 0.7367679965682328, 0.047067870254977606, 0.06916703539900482, 0.09006871187011711, 0.08926330352551304, 0.02847446045052493, 0.015014744021755178, 0.031310078702517785, 0.07770905125653371, 0.029803678480675444, 0.034092820787918754, 0.011148175035486929, 0.05916279194934759, 0.006156322779133916, 0.0226478182230494, 0.04198638511297759, 0.08724838000489399, 0.06636294172494672, 0.05429037722933572, 0.028419784575817175, 0.014886868266330566, 0.01142330123911961, 0.07547338333097287, 0.03699453285662457, 0.0518119156913599, 0.040648942231200635, 0.03889529180014506, 0.040955608783406205, 0.020938871057296637, 0.05821960017783567, 0.03363894924405031, 0.05852772133948747, 0.03446197988523636, 0.04921281062706839, 0.11130399856483564, 0.05597287796263117, 0.0069020768296468304, 0.04753200941195246, 0.0298620279863826, 0.0871663355792407, 0.009596075215085875, 0.0500807337812148, 0.02291164801135892, 0.036013105636811815, 0.028251001640455797, 0.09152191123575903, 0.10788107989355922, 0.022111484795459546, 0.10817027257871814, 0.11851510615088046, 0.19479583483189344, 0.17726673715515062, 0.1862533885287121, 0.11179200519109145, 0.13561199186369777, 0.13561893836595118, 0.12502853554906324, 0.17572571203345433, 0.13879935286240652, 0.08665592351462692, 0.12779728072928265, 0.22987608681432903, 0.18306847661733627, 0.2420327626168728, 0.16525198967428878, 0.08888646319974214, 0.1154825348930899, 0.19210033962735906, 0.09246521061868407, 0.09422346978681162, 0.1728260371601209, 0.10769916465505958, 0.11425390941440128, 0.18626459495862946, 0.11124671960715204, 0.10820823343237862, 0.11276452292804606, 0.13648618245497346, 0.13431906671030447, 0.16160485334694386, 0.10594491308438592, 0.1317218318581581, 0.23093017400242388, 0.1971117511857301, 0.13538182218326256, 0.11792028963100165, 0.15655864990549162, 0.14920415938831866, 0.14544470643159002, 0.09278074954636395, 0.20730275980895385, 0.10678005186491646, 0.2328322094399482, 0.10189282387727872, 0.16426401300122961, 0.1623211445985362, 0.22830267436802387, 0.12866764183854684, 0.24902328907046467, 0.1439886275329627, 0.10688378184568137, 0.20446115056984127, 0.2347433436079882, 0.12675543897785246, 0.8795468788594007, 7.991123199462891, 26.79903857409954, 50.473444014787674, 50.12089893221855, 49.581479877233505, 40.204419046640396, 29.787811897695065, 27.75415152311325, 33.50315183401108, 29.618985056877136, 23.682210221886635, 19.469212889671326, 24.326173067092896, 17.453949227929115, 7.589478576555848, 4.687977069988847, 1.4425141015090048, 0.6467231002170593, 0.8839608763810247, 0.7664988480973989, 2.718661017715931, 6.400286313146353, 1.9142508320510387, 0.901425036136061, 6.913121044635773, 9.075047336518764, 7.436063708737493, 9.759839940816164, 7.617268385365605, 9.227517955005169, 7.438687942922115, 8.121725991368294, 3.56766608543694, 3.6263779224827886, 4.101058663800359, 1.9216088997200131, 4.587037386372685, 4.745813766494393, 3.55317912530154, 5.831824466586113, 2.766957376152277, 8.349165637046099, 5.853154147043824, 11.744916122406721, 12.995335925370455, 13.568249233067036, 14.207466132938862, 11.016070581972599, 11.348406448960304, 5.410319259390235, 6.751034567132592, 5.376036074012518, 4.5438888017088175, 2.401320096105337, 2.018433641642332, 2.2831419249996543, 4.13474528118968, 7.321105627343059, 13.446051590144634, 20.18345296382904, 24.632898308336735, 22.069789543747902, 28.527381531894207, 53.48105862736702, 24.340785183012486, 28.351203985512257, 37.344437912106514, 39.53451119363308, 35.52321843802929, 20.331363826990128, 6.37563893571496, 0.8768183877691627, 0.28981484239920974, 0.14595683285733685, 0.1867715411935933, 0.24634373519802466, 0.1610083002015017, 0.14183075894834474, 0.11355860609910451, 0.15883367392234504, 0.07796538164257072, 0.15204061812255532, 0.2105530846165493, 0.16429932438768446, 0.12426322544342838, 0.14941786823328584, 0.17376200412400067, 0.15393818583106622, 0.06236382701899856, 0.13412028987659141, 0.13533065852243453, 0.16111424920381978, 0.1339604757959023, 0.1583042851416394, 0.24470237171044573, 0.16108241106849164, 0.1921558374306187, 0.13703848875593394, 0.14476978249149397, 0.1340231130598113, 0.2295833540847525, 0.10839575930731371, 0.1262342880363576, 0.14967733790399507, 0.21237378066871315, 0.2627820835914463, 0.2450273878639564, 0.10624342714436352, 0.13689157320186496, 0.0917907542316243, 0.1777980852057226, 0.08038891683099791, 0.2042207244085148, 0.24213455559220165, 0.1499996377970092, 0.13027348613832146, 0.12443752624676563, 0.2599719859426841, 0.21243316732579842], [0.06334071600576863, 0.05975579020741861, 0.004371641762190848, 0.031035647334647365, 0.04642197171051521, 0.053260369022609666, 0.06766368911485188, 0.030888514702382963, 0.04633932614524383, 0.05823993502417579, 0.06234206724911928, 0.06256900858716108, 0.03148459843941964, 0.027902778529096395, 0.045754929378745146, 0.030283128144219518, 0.03018009949300904, 0.021332782634999603, 0.03315956266305875, 0.022732081670255866, 0.049979794275714085, 0.02571644672570983, 0.029548145903390832, 0.024974508705781773, 0.017321882623946294, 0.030644210819446016, 0.0884219455474522, 0.012924574148200918, 0.06097538374888245, 0.06270178622798994, 0.03381697562872432, 0.07644519602763467, 0.02942590490420116, 0.037688656157115474, 0.06695618489175104, 0.021738759678555652, 0.010822989115695236, 0.060714626451954246, 0.06413321840227582, 0.038531906611751765, 0.05424143259006087, 0.04068118483701255, 0.0031085395812624483, 0.011433741401560837, 0.048990837967721745, 0.03661095382994972, 0.049511859033373185, 0.01940219121024711, 0.06320176369627006, 0.03445661786827259, 0.018020479219558183, 0.04096062570170034, 0.0034963177722602268, 0.029955629506730475, 0.03852716428809799, 0.06811850689700805, 0.07829990470781922, 0.046041980967856944, 1.0223085433244705, 7.219406934455037, 22.913042195141315, 36.43247924745083, 44.055105820298195, 37.71418087184429, 33.5024830698967, 21.529528833925724, 22.726893983781338, 24.64277397841215, 14.383791871368885, 11.750098094344139, 15.888934805989265, 20.556154064834118, 16.3524092361331, 11.326798908412457, 6.873332429677248, 3.575759888626635, 1.3891559396870434, 0.7328347919974476, 0.3037165745627135, 0.10633324185619131, 0.395079258014448, 0.7336640381254256, 1.1574086314067245, 1.0483978246338665, 0.607838302385062, 0.7502817339263856, 1.0195354046300054, 1.5052361483685672, 1.4418443874455988, 2.8114491887390614, 0.7729822502005845, 1.0430309688672423, 1.0104065132327378, 2.6271348539739847, 1.4563250541687012, 1.5375130414031446, 2.8269461821764708, 1.284280379768461, 1.6947508603334427, 4.298605788499117, 0.6907160708215088, 4.63596498593688, 8.35213327780366, 3.9104673033580184, 1.855249973013997, 2.0231897989287972, 0.8602341776713729, 0.685264669591561, 0.9559418982826173, 0.8260058518499136, 1.7493956093676388, 3.0691622849553823, 5.419955067336559, 9.63191220536828, 12.201605066657066, 16.35356057435274, 18.916397653520107, 18.55133794248104, 15.04983153194189, 19.89156022667885, 29.816462360322475, 29.629109613597393, 32.35957659780979, 25.24950072169304, 24.899493902921677, 9.715493470430374, 2.0622084802016616, 0.2014029084239155, 0.07090365354088135, 0.07267351247719489, 0.0062503310891770525, 0.061564326169900596, 0.10104754735948518, 0.031017895162221976, 0.018428409966873005, 0.11205327828065492, 0.03857015319226775, 0.016034466061682906, 0.032623238512314856, 0.01692843117780285, 0.01752171701809857, 0.06378986377967522, 0.020142964058322832, 0.005387574210544699, 0.02480916376953246, 0.009801373671507463, 0.04225366217724513, 0.10257463494781405, 0.05958865112916101, 0.031443472325918265, 0.06139182507467922, 0.0543766518967459, 0.09369749488541856, 0.026774654688779265, 0.08098990801954642, 0.06625151567277499, 0.04639342500013299, 0.006015819380991161, 0.019508023324306123, 0.030426537050516345, 0.04899096784356516, 0.04056411104102153, 0.038053492244216613, 0.0954400427872315, 0.020690077180915978, 0.023499271264881827, 0.019331872717884835, 0.04221535622491501, 0.019444094723439775, 0.006898838746565161, 0.02140749649697682, 0.008420695121458266, 0.03611926244047936, 0.12947287206770852, 0.025621321947255637, 0.02188666785514215, 0.04443556892510969, 0.033237937168451026, 0.05377252142352518, 0.0323860852222424, 0.037211447779554874, 0.011498657058837125, 0.013320482103154063, 0.03742208042240236, 0.05440852342871949, 0.02549673205066938, 0.04069645823619794, 0.05388457459048368, 0.039442243505618535, 0.024371300351049285, 0.009037683303176891, 0.026554390824458096, 0.035095135754090734, 0.037595587127725594, 0.07388979604002088, 0.030386577964236494, 0.07577568234410137, 0.08619640051620081, 0.08229504892369732, 0.06253675484913401, 0.01738128783472348, 0.0093597670456802, 0.035313898624735884, 0.017839430438471027, 0.05385740827478003, 0.043085888028144836, 0.0536631177237723, 0.05534329182410147, 0.006212886028151843, 0.013197596363170305, 0.029012883023824543, 0.03670494683319703, 0.011915277427760884, 0.03612319953390397, 0.08208330677007325, 0.007724676097495831, 0.06203354903846048, 0.03668083074444439, 0.08455716699245386, 0.08225795638281852, 0.021985570165270474, 0.032074557602754794, 0.024189522409869824, 0.025209699015249498, 0.02514689476811327, 0.06334571065963246, 0.006085617442295188, 0.045273854411789216, 0.04478236340219155, 0.039076327593647875, 0.016480873455293477, 0.023868031457823236, 0.08521531097358093, 0.14155899931211025, 2.3720063315704465, 12.753742039203644, 32.81633868813515, 44.18460287153721, 47.53968223929405, 35.56745186448097, 25.26933565735817, 17.522902227938175, 12.217448316514492, 14.042545482516289, 15.701018739491701, 26.798005029559135, 30.353337451815605, 24.370353296399117, 16.009726524353027, 12.495067119598389, 8.869777601212263, 4.280322594568133, 1.3352864678017795, 0.8744086045771837, 0.45594225462991744, 0.11607033069594763, 0.1827722112648189, 0.30774661456234753, 0.3456765948794782, 0.3250727051636204, 0.2785594901069999, 0.9464283369015902, 0.22552450391231105, 0.7755895040463656, 0.5305235541891307, 0.38828204618766904, 0.5900207615923136, 1.1800398607738316, 0.6423347513191402, 1.1203482700511813, 1.643694187514484, 0.9026693506166339, 1.9658735557459295, 1.0630316706374288, 0.7051845663227141, 1.3012002781033516, 0.9494039334822446, 1.7051962623372674, 2.0052606984972954, 1.568205300718546, 0.8372362679801881, 0.7692741241771728, 0.3311641642358154, 0.2580930758267641, 0.496785847353749, 0.9923184150829911, 2.2111775865778327, 3.7092187022790313, 7.8996326588094234, 13.416106346994638, 19.136992916464806, 23.970059975981712, 26.462446935474873, 18.670662939548492, 11.72800512984395, 18.041581995785236, 31.140951588749886, 30.02881396561861, 33.94536830484867, 30.727908052504063, 29.681807085871696, 12.999028377234936, 3.297635712660849, 0.3927252546418458, 0.01763889471476432, 0.07754809426842257, 0.016092186597234104, 0.026981721312040463, 0.11140109374537133, 0.05596225040790159, 0.07522172847529873, 0.00497005305987841, 0.10230577710899524, 0.029476634408638347, 0.019045839726459235, 0.05123334107338451, 0.04338068021752406, 0.035491427770466544, 0.0863814698823262, 0.038346755609381944, 0.05679967500327621, 0.03424346934480127, 0.05325181577063631, 0.030947504310461227, 0.05146765564859379, 0.0700549483008217, 0.040217843488790095, 0.04334885692514945, 0.0815186659747269, 0.03781899213208817, 0.012959776995558059, 0.06831394406617619, 0.029581852395494934, 0.027257781694061123, 0.05495043224073015, 0.032245362890535034, 0.06419999685022049, 0.01223106311954325, 0.043785403031506576, 0.08372135285753757, 0.05837351789523382, 0.10539005379541777, 0.029929246156825684, 0.045218460509204306, 0.003303099160802958, 0.044830732877017, 0.06413968993001617, 0.0645736014121212, 0.056196208752226084, 0.040640003062435426, 0.010610446370264981, 0.06769831772544421, 0.12408599315676838, 0.1540270060650073, 0.09415424225153401, 0.15127148595638573, 0.19452726643066853, 0.1109359972178936, 0.112123730359599, 0.13854846241883934, 0.1862536111730151, 0.12829649378545582, 0.13112717861076817, 0.09741905378177762, 0.17720504984026775, 0.11669384606648237, 0.0854977872222662, 0.22588373307371512, 0.08605348513810895, 0.1104674422822427, 0.13426039251498878, 0.14236979564884678, 0.17608434747671708, 0.17970647342735901, 0.1929444880806841, 0.19052807008847594, 0.14417518861591816, 0.09895256836898625, 0.2324512056657113, 0.08160954937920906, 0.2712133264867589, 0.1798400896950625, 0.13298818812472746, 0.15509543154621497, 0.09403039264725521, 0.19595070567447692, 0.1316567455069162, 0.13566599052865058, 0.12398308695992455, 0.17181811155751348, 0.14419166429433972, 0.11631684988969937, 0.12309461744735017, 0.16057022527093068, 0.21090716327307746, 0.13821318978443742, 0.16164402390131727, 0.21549998869886622, 0.0851768083521165, 0.16694387857569382, 0.14966740796808153, 0.1938761505880393, 0.10557098197750747, 0.09149646299192682, 0.1313231055974029, 0.09820964143727906, 0.0778151115810033, 0.1333398770657368, 0.21478080307133496, 0.20641521055949852, 2.622914230450988, 13.683437202125788, 37.376192808151245, 53.28993268311024, 60.9756700694561, 47.198734134435654, 41.41556225717068, 31.324109360575676, 30.78806072473526, 34.034340530633926, 20.08494134992361, 22.61955924332142, 25.96096694469452, 27.78347074985504, 20.90659786015749, 14.804770331829786, 10.083946399390697, 4.697890263050795, 2.2426365735009313, 1.0722943861037493, 0.81172289326787, 0.2740139840170741, 1.0622021276503801, 2.21508567687124, 2.950436230748892, 2.8216449916362762, 2.817801497876644, 3.9825748465955257, 3.0205968534573913, 3.9793625939637423, 4.865637011826038, 7.43938853032887, 3.485547504387796, 4.734876053407788, 3.138909204863012, 6.1651055328547955, 5.382334711030126, 5.134806018322706, 8.695915080606937, 4.610954253003001, 6.502933530136943, 8.522386942058802, 5.211618421599269, 11.47337794303894, 14.583441708236933, 7.016307832673192, 5.2291796542704105, 4.029965428635478, 3.180093769915402, 1.3976890943013132, 1.5272901649586856, 1.5732567734085023, 2.4436355754733086, 4.6955799870193005, 8.051711898297071, 13.721392415463924, 17.730070911347866, 23.529125936329365, 27.111279219388962, 25.649167075753212, 23.553666919469833, 27.634978517889977, 40.30052728950977, 37.99414224922657, 43.01343731582165, 36.67098864912987, 31.752912551164627, 13.260584492236376, 2.954023238271475, 0.4189314093673602, 0.23224471049616113, 0.10286933436873369, 0.13061245466815308, 0.15045251115225255, 0.21456430375110358, 0.11939611707930453, 0.1497562727308832, 0.18139238061849028, 0.18350859987549484, 0.12209770531626418, 0.16226919426117092, 0.11624582635704428, 0.2386524877510965, 0.17188227764563635, 0.17998286406509578, 0.14859222894301638, 0.18966628820635378, 0.10298224471625872, 0.13586166518507525, 0.17807288764743134, 0.08213194712880068, 0.15848974784603342, 0.19022246851818636, 0.11527763534104452, 0.16356502863345668, 0.10701518651330844, 0.12081363398465328, 0.1362354849698022, 0.11965899320784956, 0.16278001450700685, 0.09555982542224228, 0.09933957611792721, 0.10749743407359347, 0.1140646988642402, 0.15702376869739965, 0.1905466683092527, 0.24396478082053363, 0.18870505853556097, 0.19606694084359333, 0.1779354122118093, 0.13283209962537512, 0.17675489274552092, 0.15610813657986, 0.11386118712835014, 0.1328605684102513, 0.11067916959291324, 0.11596574724535458, 0.17467475670855492], [0.03651548766356427, 0.03325880265037995, 0.02838898730260553, 0.0258601116729551, 0.00987120698482613, 0.004162292107139365, 0.036226692027412355, 0.06412060931324959, 0.04021233304229099, 0.010556289998930879, 0.05883727113541681, 0.044193216890562326, 0.03829460860288236, 0.06152970869152341, 0.0749116220686119, 0.04403587416163646, 0.04813467043277342, 0.04263404625817202, 0.052446162517298944, 0.04586439987178892, 0.06451477878727019, 0.01477876425269642, 0.02656814282090636, 0.12638829852221534, 0.08849043093505315, 0.021812599661643617, 0.06402611907105893, 0.03391826023289468, 0.02444181180180749, 0.01767413559718989, 0.03857711824821308, 0.0072092517530109035, 0.03890896958182566, 0.03784900458413176, 0.018727469505392946, 0.04346352616266813, 0.03664545627543703, 0.04388221990666352, 0.033165844943141565, 0.03436764920479618, 0.01076656733857817, 0.03327882950543426, 0.027998131517961156, 0.0636740961635951, 0.06157022995466832, 0.0381754642148735, 0.07251516042742878, 0.06211802028701641, 0.06784273966331966, 0.1126815433963202, 0.030069400745560415, 0.008221146454161499, 0.03351563027536031, 0.009155874959105859, 0.060738007814507, 0.07343529738136567, 0.027076836813648697, 0.08841479124384932, 0.06666544111794792, 0.40628660819493234, 4.69409141689539, 11.121728662401438, 25.869148671627045, 41.76366537809372, 38.704035356640816, 34.9799881875515, 34.93300750851631, 32.26985961198807, 23.302002623677254, 19.40367590636015, 14.710882119834423, 12.308394536376, 29.860779382288456, 27.41790946573019, 21.33615531027317, 13.962373584508896, 11.807027589529753, 6.716655911877751, 4.353274879977107, 3.074135980568826, 0.7578120392281562, 1.2025128048844635, 0.6250380794517696, 0.7670502341352403, 0.23824446980142966, 0.10251141880871728, 0.16708159149857238, 0.24219380866270512, 0.2906398434424773, 0.21083559055114165, 0.22669389116344973, 0.43355397472623736, 0.17965602222830057, 0.18772318231640384, 1.6387385409325361, 0.7830727274995297, 1.3471030024811625, 0.19429341569775715, 0.5208774749189615, 0.9263104945421219, 0.4871703445678577, 0.8280518639367074, 1.5201276680454612, 1.2143509509041905, 0.2959937561536208, 0.9290162462275475, 2.1259849704802036, 1.4946245052851737, 3.924613706767559, 7.274839309975505, 12.398819234222174, 18.465496748685837, 24.339797236025333, 29.173092283308506, 25.577396526932716, 13.893876560032368, 12.992035802453756, 13.673208151012659, 18.089147843420506, 23.630595691502094, 26.871690675616264, 31.043931394815445, 26.631648056209087, 13.905355744063854, 4.736282452940941, 1.2767946626991034, 0.06205864476214629, 0.06093656942539383, 0.037914925851509906, 0.023591152857989073, 0.02964615763630718, 0.06753789508366026, 0.00906330131329014, 0.0030404347762669204, 0.019061747661908157, 0.014985029356466839, 0.04126546285988297, 0.03844550948997494, 0.0075268264845362864, 0.09079438386834227, 0.029539338465838227, 0.027377794394851662, 0.09258670019335113, 0.04703052167315036, 0.03525196269038133, 0.07155862112995237, 0.016257774586847518, 0.02584473437309498, 0.03705124407133553, 0.016572549102420453, 0.06443892387324013, 0.050176938384538516, 0.05157978674105834, 0.05481703861732967, 0.07718061984633096, 0.07135235602618195, 0.05046825361205265, 0.003526237455844239, 0.00947487322264351, 0.04905861089355312, 0.053066360487719066, 0.04071202849445399, 0.03331095336761791, 0.013985777604830218, 0.08365858942852356, 0.01818581673433073, 0.04812045459402725, 0.13621859368868172, 0.04682059778133407, 0.07280125835677609, 0.03917269175872207, 0.036929925190634094, 0.024911188666010275, 0.01314025803367258, 0.044706400876748376, 0.07533482435974292, 0.037476401921594515, 0.015031412658572663, 0.023035787053231616, 0.028415034830686636, 0.018471636358299293, 0.07141091889934614, 0.019935218369937502, 0.03885647005517967, 0.05655671069689561, 0.07553380899480544, 0.03947704652091488, 0.021894957644690294, 0.004986261565136374, 0.0954799258033745, 0.10961149368085898, 0.042408804438309744, 0.06602798821404576, 0.0073748967952269595, 0.031164521278697066, 0.010550259121373529, 0.05315760754456278, 0.050863391588791274, 0.05728621588787064, 0.08130518719553947, 0.024443490910925902, 0.01840221771999495, 0.0181186746340245, 0.02890216201194562, 0.03815045754890889, 0.02578162770078052, 0.027456053867354058, 0.021363815540098585, 0.06734732640325092, 0.030988873477326706, 0.016639453715470154, 0.04120255100133363, 0.029763123820885085, 0.042096987381228246, 0.012794451540685259, 0.06806187360780314, 0.08526303106918931, 0.02265259579871781, 0.06336354446830228, 0.05040803946030792, 0.02668326662387699, 0.06556439824635163, 0.06559035115060396, 0.12989616341656074, 0.07010591158177704, 0.05578825388511177, 0.06598161140573211, 0.049100453179562464, 0.007916291669971542, 0.07363696116954088, 0.08837057408527471, 0.05407552176620811, 0.025569158242433332, 0.07840291480533779, 0.03306036349385977, 0.7630101009272039, 6.547175981104374, 16.690036319196224, 34.571130126714706, 46.99466988444328, 44.12781111896038, 33.34184288978577, 28.714565187692642, 22.011618465185165, 11.500588282942772, 11.890096832066774, 16.69479936361313, 23.322971798479557, 33.784534335136414, 28.390303887426853, 23.94630365073681, 17.84806787967682, 15.268114618957043, 8.494608532637358, 4.949603006243706, 3.148093787021935, 0.9829002048354596, 0.756775347981602, 0.7606960250996053, 0.288661663653329, 0.12161012913566083, 0.1027720833371859, 0.142376653093379, 0.15868481394136325, 0.28373789973556995, 0.21536497719353065, 0.20595390640664846, 0.21811090875416994, 0.16360017674742267, 0.3001172177027911, 0.5115816299803555, 0.22554501687409356, 0.5730384041089565, 0.3179636725690216, 0.37136814440600574, 0.2597917628008872, 0.25218798487912863, 0.2300146160996519, 0.35439638479147106, 0.40544296440202743, 0.17682743025943637, 0.18118521751603112, 1.4036142826080322, 1.7668784712441266, 4.197167381644249, 8.160805944353342, 12.793957181274891, 20.34672450274229, 22.15726274996996, 25.749371498823166, 21.00510187447071, 14.108441546559334, 11.878537852317095, 12.691653370857239, 18.1436388194561, 25.037143416702747, 31.64569940418005, 35.42627424001694, 31.134826317429543, 17.648675478994846, 7.327145878225565, 1.6321510006673634, 0.13626456231577322, 0.05012860972783528, 0.05270608118735254, 0.04719127457065042, 0.028655011992668733, 0.042534257081570104, 0.017120448901550844, 0.009068834024219541, 0.01912127718242118, 0.04693436530942563, 0.04958356534189079, 0.037240528836264275, 0.022544153180206195, 0.07497798491385765, 0.0421686825575307, 0.04762301156006288, 0.01646685428568162, 0.07021380501100793, 0.024934035682235844, 0.0508096267003566, 0.027698817793861963, 0.07202107561170124, 0.031563177035422996, 0.027282730843580794, 0.05712364843930118, 0.006576170562766492, 0.054662441834807396, 0.008116251301544253, 0.008098739399429178, 0.02953841078124242, 0.037621707015205175, 0.0068101131364528555, 0.03880352895066608, 0.03961527152569033, 0.02807199562084861, 0.02506684115360258, 0.06772847118554637, 0.06160797187476419, 0.01771984632796375, 0.02678459946764633, 0.031107934373721946, 0.061591511039296165, 0.02772287822153885, 0.040066961155389436, 0.02107424250425538, 0.06407757216948085, 0.049042925602407195, 0.033424865614506416, 0.03637024565250613, 0.01203710560730542, 0.11607002641540021, 0.08747489089728333, 0.1731064502382651, 0.13263393135275692, 0.06560815527336672, 0.21724783553509042, 0.12810788437491283, 0.15971849206835032, 0.0993351751822047, 0.2351787022780627, 0.14516174036543816, 0.1178823436202947, 0.16545355698326603, 0.18379680550424382, 0.14994504541391507, 0.15496815321967006, 0.12115518518839963, 0.1293666855781339, 0.1788512521306984, 0.11014393268851563, 0.16704580513760448, 0.14456619654083624, 0.1709721819497645, 0.24364210985368118, 0.1981366571271792, 0.11517810591612943, 0.21929540613200516, 0.15608052868628874, 0.0865251051436644, 0.1599272433668375, 0.14379390282556415, 0.19649581314297393, 0.1640054042218253, 0.12501826422521845, 0.1823787097237073, 0.14531220338540152, 0.10334845006582327, 0.18188081769039854, 0.10684605105780065, 0.15364318212959915, 0.1959826477104798, 0.14463119383435696, 0.2267220927751623, 0.19433700945228338, 0.16132252552779391, 0.151812199910637, 0.14292805397417396, 0.3436469694133848, 0.15988137864042073, 0.20182798092719167, 0.18823535327101126, 0.1311928586801514, 0.09515116922557354, 0.108689738844987, 0.14762771897949278, 0.1386121238465421, 0.12206987477838993, 0.30130610859487206, 0.1064688025508076, 0.7651442207861692, 7.063747812062502, 19.673980101943016, 37.06218525767326, 58.00900585949421, 53.92710529267788, 45.463272258639336, 45.645571276545525, 42.4738434702158, 29.594191387295723, 26.134321242570877, 21.606191620230675, 21.060176119208336, 41.15410968661308, 34.93918217718601, 26.382134445011616, 18.87933824211359, 16.03027582168579, 9.802298862487078, 5.491271065548062, 3.986973585560918, 1.6949801542796195, 1.401943084783852, 1.176260132342577, 1.2140128877945244, 0.8836151543073356, 0.6617621588520706, 0.8395435754209757, 0.9781474911142141, 1.3542861607857049, 0.9282271354459226, 1.1045227129943669, 2.2283904254436493, 1.3473034417256713, 1.5583220310509205, 4.176921593025327, 2.23637237213552, 3.8342455308884382, 1.1776994238607585, 1.4471536525525153, 2.1908102044835687, 2.2230412624776363, 2.583273332566023, 3.774115419946611, 2.416784316301346, 0.8882781572174281, 1.4980234229005873, 2.5907546561211348, 2.4750401778146625, 5.1658750511705875, 10.527951624244452, 16.143179163336754, 24.065641947090626, 31.070111989974976, 39.87335421144962, 33.662321493029594, 21.403413601219654, 21.632664799690247, 21.883270852267742, 27.333424799144268, 35.11917471885681, 38.83301183581352, 42.58091792464256, 35.25595597922802, 20.044813603162766, 7.358927372843027, 1.5571750863455236, 0.18992888974025846, 0.23094195930752903, 0.17355730495182797, 0.16050801845267415, 0.1257600259850733, 0.17878664075396955, 0.12189390414278023, 0.09508716640993953, 0.12419977181707509, 0.10561030096141621, 0.08987650304334238, 0.127142142446246, 0.11136946341139264, 0.1535693829646334, 0.09709052726975642, 0.19196338369511068, 0.1754974274081178, 0.16924857365665957, 0.1431667583528906, 0.15886151930317283, 0.08488906285492703, 0.15798484993865713, 0.17782465409254655, 0.12175654002930969, 0.13958320923848078, 0.14598473760997877, 0.3112211124971509, 0.15449104132130742, 0.1814006778295152, 0.14437023986829445, 0.13508999487385154, 0.14395628473721445, 0.11799693864304572, 0.1024339756986592, 0.1216011046199128, 0.08730581481358968, 0.15270170842995867, 0.15727123041870072, 0.13602863356936723, 0.1940073919831775, 0.1330795613466762, 0.2134527001180686, 0.21470033942023292, 0.16096203471533954, 0.15784716670168564, 0.20786317036254331, 0.12202570957015269, 0.11213356381631456, 0.12593787425430492, 0.10859222064027563], [0.042287277756258845, 0.0057542999911675, 0.04342526102846023, 0.037841957891942, 0.013820143230987014, 0.054394734324887395, 0.02941127346275607, 0.011564446595002664, 0.09666659767390229, 0.05732180186896585, 0.025196600108756684, 0.06172034416522365, 0.05097499204566702, 0.022424897470045835, 0.009323276572104078, 0.021731423548772, 0.08570554404286668, 0.061285178453545086, 0.03426319563004654, 0.06429570421460085, 0.024718764616409317, 0.002541400299378438, 0.04886311435257085, 0.04515539651038125, 0.03055773391679395, 0.09403972144355066, 0.0338865185767645, 0.02156496724637691, 0.08305513430968858, 0.0461036052001873, 0.02078625951980939, 0.0162175204968662, 0.020415859180502594, 0.14822277298662812, 0.03480657018371858, 0.023940542996570002, 0.04194352608465124, 0.025144664614344947, 0.12089106225175783, 0.020905977216898464, 0.029100996362103615, 0.023445127881132066, 0.06591955301701091, 0.020583762670867145, 0.05569298067712225, 0.017383017038810067, 0.01200590850203298, 0.010274541982653318, 0.042122324302908964, 0.03591429609514307, 0.0692743128456641, 0.041642510987003334, 0.0302026162535185, 0.06225422665011138, 0.06073976299376227, 0.025542088405927643, 0.009273819850932341, 0.03729975964233745, 0.1021846586081665, 0.12145425585913472, 0.11809372212155722, 2.020201734267175, 6.684248400852084, 17.260877788066864, 33.022466227412224, 38.4270416200161, 39.819408506155014, 42.17934787273407, 34.16058875620365, 39.134362265467644, 34.86820958554745, 21.827125065028667, 15.761606488376856, 38.40944476425648, 41.729497611522675, 26.982137449085712, 15.359293576329947, 19.907659962773323, 18.051092885434628, 14.148044921457767, 13.677555117756128, 7.757203476503491, 5.429732892662287, 4.712285790592432, 3.1932698003947735, 2.3876676661893725, 1.0535004758276045, 1.266420150641352, 0.598105302779004, 0.8168183011002839, 0.42200737399980426, 0.49974763998761773, 0.4597094259224832, 0.7273304311092943, 0.3653355228016153, 0.4227541229920462, 0.5144067190121859, 0.5049496795982122, 0.44266713259276, 0.5821279319934547, 0.8004551322665066, 1.2345097004435956, 2.0017413748428226, 3.5531712882220745, 5.123740062117577, 8.650422971695662, 8.442086800932884, 13.744384981691837, 19.696932770311832, 17.904289662837982, 18.84644340723753, 12.984690796583891, 19.3162938952446, 18.905687928199768, 25.214827582240105, 31.464846208691597, 31.856895871460438, 33.193825632333755, 24.729361832141876, 25.827510505914688, 22.831148989498615, 18.120952136814594, 9.152021706104279, 2.2460654145106673, 0.21929125010501593, 0.028333877271506935, 0.01753711843775818, 0.04717750030977186, 0.0789765059016645, 0.04864891197939869, 0.05099180169054307, 0.013425581346382387, 0.03896465292200446, 0.06400844853487797, 0.014801928537053755, 0.06114903517300263, 0.03735724269063212, 0.04217586283630226, 0.044387833986547776, 0.03724926391441841, 0.057840752342599444, 0.043915824353462085, 0.0464866424590582, 0.005212125861362438, 0.013191666603233898, 0.0065112270749523304, 0.04075134376762435, 0.026149630903091747, 0.04746616235934198, 0.06494458619272336, 0.01620897095563123, 0.00824887309136102, 0.06591642857529223, 0.016897019777388778, 0.040274361745105125, 0.03855633069179021, 0.06831018137745559, 0.03247638604079839, 0.03194911980244797, 0.07926099337055348, 0.033255745001952164, 0.043336952876416035, 0.04490176012041047, 0.02706506635149708, 0.049459853034932166, 0.01902929911011597, 0.043546245942707174, 0.03811299393419176, 0.020291222899686545, 0.04020678548840806, 0.03706879215314984, 0.019111261899524834, 0.04113713439437561, 0.02486428122210782, 0.024281042205984704, 0.02550969922594959, 0.03661813410872128, 0.012334156708675437, 0.01154076651801006, 0.032775794388726354, 0.01674945669947192, 0.006662529649474891, 0.02225556905614212, 0.03243793165893294, 0.03789752248849254, 0.0334099298925139, 0.041974633204517886, 0.04668484041758347, 0.02064642405457562, 0.018764304149954114, 0.010768400443339488, 0.045882092672400177, 0.06133920309366658, 0.04616071717464365, 0.01821493118768558, 0.040948332025436684, 0.05887029299628921, 0.08072272743447684, 0.04766942176502198, 0.04154561618634034, 0.014310770566225983, 0.04013301229861099, 0.016593412728980184, 0.033838932067737915, 0.04985277941159438, 0.025850890488072764, 0.021920467115705833, 0.046505544960382394, 0.03839436438283883, 0.06054392877558712, 0.13925702049164101, 0.03678461267554667, 0.021814006031490862, 0.02912065956479637, 0.1010256985318847, 0.03203385822416749, 0.049439963477198035, 0.04096252559975255, 0.07240363047458231, 0.07075498651829548, 0.005017710536776576, 0.06566279218532145, 0.07296180716366507, 0.011723300522135105, 0.04608994226146024, 0.02708846626774175, 0.014539847434207331, 0.0232263241923647, 0.03980119065090548, 0.009816429992497433, 0.07318162388401106, 0.038509723817696795, 0.03347388446854893, 0.09674825618276373, 0.12034564308123663, 0.07028458363492973, 0.281522351433523, 3.02364120259881, 10.282252058386803, 23.229508213698864, 39.516971334815025, 45.85853464901447, 44.29314024746418, 40.55710852146149, 25.571824125945568, 25.363065227866173, 23.15499611198902, 14.256104473024607, 23.58458586037159, 40.56493990123272, 39.106923937797546, 30.17115242779255, 25.419904477894306, 27.34524216502905, 26.612421087920666, 18.228093087673187, 17.05946959555149, 12.501380480825901, 5.732662612572312, 5.917256707325578, 3.872916530817747, 2.877857512794435, 1.6481997957453132, 1.291334938723594, 0.29303341812919825, 0.4691033234121278, 0.3854447859339416, 0.48446269298437983, 0.5087025719694793, 0.5322796537075192, 0.18541603814810514, 0.3577692381804809, 0.531826646765694, 0.4476231650914997, 0.253776804311201, 0.6128448306117207, 0.9409657737705857, 1.5040395688265562, 3.042719503864646, 3.812951948493719, 5.354075627401471, 9.726382736116648, 11.317841839045286, 16.968010403215885, 23.742417991161346, 24.417240880429745, 27.588716000318527, 21.553066670894623, 26.84543788433075, 25.321358665823936, 23.346883915364742, 22.783224061131477, 26.355836056172848, 29.206562787294388, 28.094888739287853, 31.35463312268257, 28.466900177299976, 23.360933661460876, 12.003969121724367, 3.6598137533292174, 0.41812110284809023, 0.0958192950929515, 0.0075096680302522145, 0.11829127441160381, 0.050081494482583366, 0.034573654556879774, 0.06292567733908072, 0.038083352555986494, 0.03508595167659223, 0.05118241489981301, 0.026535948454693425, 0.012702233198069734, 0.031356199469882995, 0.020234545081621036, 0.03959658795793075, 0.0142754220723873, 0.04794741173100192, 0.04281186484149657, 0.07238662787131034, 0.05903015160583891, 0.056771132003632374, 0.0499487836350454, 0.07597152769449167, 0.047445571472053416, 0.07939617556985468, 0.15097995550604537, 0.023599511296197306, 0.006548078417836223, 0.01771758648828836, 0.09460919362027198, 0.055404819577233866, 0.037474242271855474, 0.04513750704063568, 0.06681919927359559, 0.033686468959786, 0.05422543930762913, 0.017259505111724138, 0.06560211419127882, 0.024109184923872817, 0.06772327615180984, 0.02244489278382389, 0.006319008507489343, 0.025924244364432525, 0.04940658909617923, 0.011430614176788367, 0.022872475601616316, 0.032898794233915396, 0.02402414036623668, 0.03084943691646913, 0.03237703102058731, 0.028932334025739692, 0.01662579448748147, 0.0778976606670767, 0.13460209214827046, 0.0938424956984818, 0.09333867390523665, 0.10150463611353189, 0.15648775995941833, 0.12265447934623808, 0.14305307617178187, 0.12971239280886948, 0.18860702082747594, 0.17098217125749215, 0.14581607712898403, 0.13115221867337823, 0.08510076047969051, 0.13619057019241154, 0.1265913204406388, 0.16295872366754338, 0.09405433433130383, 0.17477427871199325, 0.12847517326008528, 0.19266357034211978, 0.168044765596278, 0.06518539827084169, 0.13233689416665584, 0.12405780638800934, 0.20066021155798808, 0.1472660555737093, 0.1351159848854877, 0.22097334265708923, 0.13444730982882902, 0.09244812637916766, 0.09682575866463594, 0.07247885456308722, 0.28860042162705213, 0.12443017156329006, 0.14110262301983312, 0.18505594809539616, 0.17263285611988977, 0.31830978055950254, 0.12029932564473711, 0.1348995152511634, 0.11818173341453075, 0.15342172526288778, 0.09777978950296529, 0.1690423011314124, 0.16225893778027967, 0.15071929839905351, 0.09557473516906612, 0.10703332460252568, 0.1420957501977682, 0.11750384088372812, 0.1391210441943258, 0.10912399913650006, 0.218993381713517, 0.25701829756144434, 0.12965333269676194, 0.12217015377245843, 0.25158435164485127, 0.2218979102326557, 0.20840329059865326, 0.3017389291198924, 2.849451187066734, 10.802311152219772, 25.813171975314617, 47.06610605120659, 52.81039461493492, 54.598388671875, 55.39019778370857, 43.24100710451603, 51.31435789167881, 44.75159704685211, 27.766977734863758, 25.825014039874077, 49.446085542440414, 50.37198565900326, 36.73319511115551, 24.386046454310417, 29.12988480180502, 26.012326888740063, 19.524866603314877, 17.976766973733902, 11.324320491403341, 7.805998558178544, 7.563273282721639, 4.715930745005608, 3.2859487272799015, 1.8758623232133687, 1.6909820563159883, 1.0197751480154693, 1.5163439023308456, 0.6131928681861609, 0.7370402163360268, 0.7955098757520318, 1.5177316591143608, 0.8425837091635913, 1.042050621472299, 0.9784976067021489, 0.8894481975585222, 0.8591598446946591, 0.9123560995794833, 1.3967423513531685, 1.6917122108861804, 2.665791129693389, 4.22317698597908, 7.078239284455776, 11.53717651963234, 11.655402425676584, 18.347172997891903, 27.796105071902275, 25.079262256622314, 28.00309706479311, 20.398017950356007, 28.131619468331337, 27.968758307397366, 33.65232802927494, 39.60114821791649, 41.898463144898415, 42.63127662241459, 36.96469768881798, 37.24715553224087, 34.2107080668211, 25.453903153538704, 12.623729165643454, 3.5206060856580734, 0.3670278866775334, 0.1524526733555831, 0.11270650924416259, 0.23661069106310606, 0.24990602920297533, 0.14621607988374308, 0.15882959211012349, 0.19290827127406374, 0.11009866910171695, 0.2343298782943748, 0.0991279304435011, 0.17830463068094105, 0.16573263419559225, 0.1598836644552648, 0.11504599620820954, 0.09263637955882587, 0.17136623268015683, 0.1694661713554524, 0.22285014507360756, 0.08582718946854584, 0.06872947997180745, 0.15587421163218096, 0.1460543807479553, 0.1051583701337222, 0.21146700979443267, 0.2124885463854298, 0.08778486371738836, 0.08573624669224955, 0.14451276190811768, 0.16172419069334865, 0.11788831048761494, 0.08720153564354405, 0.18775184405967593, 0.1097560343623627, 0.20505679829511791, 0.11061895915190689, 0.12221763638081029, 0.19694617803907022, 0.12586146272951737, 0.09510964606306516, 0.1948708511190489, 0.17572345590451732, 0.11557249061297625, 0.18583422352094203, 0.10410010465420783, 0.13936923322035, 0.1461981050670147, 0.10400649756775238, 0.144307617447339, 0.1357810531044379, 0.08871963582350872, 0.10869884499697946], [0.02432283068628749, 0.1222484874597285, 0.009818106318562059, 0.025983046580222435, 0.010893865146499593, 0.0729791066260077, 0.06087627734814305, 0.007055815503917984, 0.02380557416472584, 0.0659235383500345, 0.1290183066157624, 0.04905512651021127, 0.019280382512079086, 0.09930297339451499, 0.021928682690486312, 0.08933524732128717, 0.058587401144905016, 0.0675476469041314, 0.01020842682919465, 0.032456103144795634, 0.03702147281728685, 0.055013266173773445, 0.08570775564294308, 0.05804573724162765, 0.03248099106713198, 0.04237302178808022, 0.06663308347924612, 0.09874134571873583, 0.08100737075437792, 0.024414311519649345, 0.016992597265925724, 0.029471238995029125, 0.023616829312231857, 0.06854091509012505, 0.052136397498543374, 0.029839622548024636, 0.056978625361807644, 0.005301184510244639, 0.0246915463503683, 0.04856629610003438, 0.034909736132249236, 0.025390987138962373, 0.04262277674570214, 0.020729010248032864, 0.010229077088297345, 0.028910112268931698, 0.03064056687435368, 0.012866506658610888, 0.027428876419435255, 0.060742178684449755, 0.05125933850649744, 0.04260962217813358, 0.06948319773073308, 0.02583529982075561, 0.02378405744821066, 0.01430908032489242, 0.04658165962609928, 0.021747966020484455, 0.040627928319736384, 0.01931513357703807, 0.05481293082993943, 0.028307555148785468, 0.18769925547530875, 1.5154783800244331, 6.004208391532302, 19.979949183762074, 30.15154168009758, 39.803597554564476, 46.632420122623444, 39.19389367103577, 36.989039182662964, 37.78869867324829, 15.263801850378513, 28.54859009385109, 60.54252751171589, 36.22722186148167, 25.49964129924774, 20.49316294491291, 22.241965904831886, 24.708362258970737, 15.285059809684753, 22.40313045680523, 24.96866539120674, 20.192203894257545, 17.451416663825512, 12.274399660527706, 13.936863653361797, 10.656260289251804, 11.453726347535849, 7.877392452210188, 8.813855051994324, 6.286865249276161, 4.801803287118673, 5.191893680021167, 4.798147883266211, 4.435370424762368, 4.49358900077641, 5.329088643193245, 6.7284576036036015, 6.962351677939296, 9.354483392089605, 9.206808116286993, 9.570921678096056, 11.773010864853859, 16.699778996407986, 20.101432465016842, 23.7565703317523, 15.292781945317984, 13.814883548766375, 15.668784119188786, 17.686833031475544, 22.431676425039768, 18.800087794661522, 22.264910973608494, 26.41537696123123, 36.185743287205696, 35.46707645058632, 29.558581598103046, 22.947614639997482, 15.629147496074438, 7.267673844471574, 2.362665720283985, 0.6510570645332336, 0.07018296877504326, 0.05811330978758633, 0.050220465345773846, 0.035228967244620435, 0.03914565531886183, 0.03906672791345045, 0.04778547881869599, 0.029662516426469665, 0.05064470664365217, 0.02966753891087137, 0.04450442167581059, 0.008913317906262819, 0.10290491292835213, 0.03636531037045643, 0.04184780387731735, 0.025354957724630367, 0.04504601136432029, 0.006574126409759629, 0.05309448788466398, 0.011316773361613741, 0.03811963615589775, 0.015598745594616048, 0.00439685391029343, 0.030632078560302034, 0.05631860745779704, 0.033470195994596, 0.02391320413153153, 0.055132061752374284, 0.05902447417611256, 0.0848505379690323, 0.06537229332025163, 0.03594175184844062, 0.07223270644317381, 0.08188884923583828, 0.06742545971064828, 0.028509888725238852, 0.02836718671460403, 0.03741325999726541, 0.014023446237843018, 0.030629245411546435, 0.06401219638064504, 0.028790355609089602, 0.023609461641171947, 0.020380100650072563, 0.04358445912657771, 0.005370782191675971, 0.024247716064564884, 0.04460621465113945, 0.02060258724668529, 0.014563521945092361, 0.055586582675459795, 0.024556584940000903, 0.014777099986531539, 0.04790158782270737, 0.06616609447519295, 0.011506172231747769, 0.07268843706697226, 0.07016911287792027, 0.01986883882636903, 0.0612975686090067, 0.02102206210111035, 0.002815615284816886, 0.013838440881954739, 0.10223262361250818, 0.06830698272096924, 0.03574871923774481, 0.04910246811050456, 0.09168895383481868, 0.09595513038220815, 0.02856232888007071, 0.04345597109931987, 0.07140334157156758, 0.0411083205108298, 0.0542363785643829, 0.035409951087785885, 0.024743960530031472, 0.07279920260771178, 0.024455374550598208, 0.05153764759597834, 0.07390025290078484, 0.07646048426977359, 0.07759697953588329, 0.030723529707756825, 0.00626267903498956, 0.04375060372694861, 0.03001429813593859, 0.028924188954988495, 0.02836390271113487, 0.04850865720072761, 0.11350977278198116, 0.031082445311767515, 0.08085445864708163, 0.05311461864039302, 0.011191616649739444, 0.02330594179511536, 0.01922498118801741, 0.011689977163769072, 0.009833829644776415, 0.007727915108262096, 0.020325350560597144, 0.028312644426478073, 0.044521112577058375, 0.031082951827556826, 0.048233977213385515, 0.04379792677354999, 0.004914504697808297, 0.019144003599649295, 0.07209998075268231, 0.02974768343847245, 0.008424753741564928, 0.008704156571184285, 0.03160535699862521, 0.02541248901252402, 0.071667635202175, 0.025839103327598423, 0.2877085085492581, 3.1115352362394333, 10.743249971419573, 26.09113086014986, 37.26482078433037, 47.742925733327866, 48.31433147192001, 41.397536024451256, 32.54107765853405, 28.694639056921005, 13.00992714241147, 34.353808388113976, 60.990527272224426, 28.058015517890453, 21.638778671622276, 24.649645909667015, 30.95219101756811, 30.031707510352135, 27.618335410952568, 26.919834092259407, 30.19989598542452, 25.264570713043213, 21.592915132641792, 16.313670314848423, 14.736618138849735, 13.5063705034554, 11.602938640862703, 9.613221008330584, 8.041139915585518, 7.179091572761536, 5.753115015104413, 6.155220363289118, 7.38751751370728, 5.998451225459576, 6.395014571025968, 7.426446424797177, 7.005413817241788, 7.452393332496285, 9.655409194529057, 13.240437973290682, 15.476683527231216, 17.430189102888107, 20.019155479967594, 24.573524594306946, 26.189560778439045, 22.443951666355133, 21.451218836009502, 19.811363629996777, 16.323078610002995, 15.666666682809591, 16.499275155365467, 18.699604086577892, 27.789691016077995, 41.30116939544678, 41.37411028146744, 36.42529383301735, 27.637231796979904, 20.747488997876644, 11.355149187147617, 4.160745861008763, 1.2240893533453345, 0.0395414018566953, 0.05521843660972081, 0.02239919689600356, 0.08450537250610068, 0.022389554542314727, 0.01702560799458297, 0.01572474186104955, 0.0020342713105492294, 0.027678896694851574, 0.048459211611771025, 0.021999824966769665, 0.019515450367180165, 0.06692432449199259, 0.005482703163579572, 0.03855970746371895, 0.06344710287521593, 0.013366803250391968, 0.01928920108184684, 0.035059620277024806, 0.023993127870198805, 0.009576731135894079, 0.019472591338853817, 0.047648496911278926, 0.035113210760755464, 0.07410170146613382, 0.03879539501213003, 0.02627752150146989, 0.03693884951644577, 0.07385173128568567, 0.11253673554165289, 0.050050231511704624, 0.022196957943378948, 0.022192258293216582, 0.05106419819639996, 0.08121750244754367, 0.02885441037506098, 0.058894331159535795, 0.050916711188619956, 0.020003740864922293, 0.06731513203703798, 0.05654950815369375, 0.07807870759279467, 0.009542994957882911, 0.05607922030321788, 0.007332708946705679, 0.03228044050047174, 0.06748268671799451, 0.03478121099760756, 0.028133271043770947, 0.02826132120389957, 0.07305698760319501, 0.028052063389623072, 0.024101668823277578, 0.14378560561453924, 0.19456550187896937, 0.2012068626936525, 0.1666981534799561, 0.2083709032740444, 0.1391616545151919, 0.10377532598795369, 0.13282491563586518, 0.1351646104012616, 0.13422908872598782, 0.3442670189542696, 0.1655771245714277, 0.09749686796567403, 0.1415065146284178, 0.18905968638136983, 0.1916691369842738, 0.1193540521489922, 0.1869688931037672, 0.1395256631076336, 0.15620207763276994, 0.14914492116076872, 0.25285063369665295, 0.12534166249679402, 0.1361936129978858, 0.08187215091311373, 0.22221872583031654, 0.17182550334837288, 0.2504090272122994, 0.16600663511781022, 0.11459262561402284, 0.06959460893995129, 0.11597504635574296, 0.09117175854044035, 0.12476265372242779, 0.2270533874980174, 0.15111217653611675, 0.28136106790043414, 0.13904297025874257, 0.15365590254077688, 0.16596085944911465, 0.13300877530127764, 0.1505962948431261, 0.10605469899019226, 0.09934767294907942, 0.07192331991973333, 0.1035567263897974, 0.14866115961922333, 0.18187287671025842, 0.17535576625959948, 0.16583194839768112, 0.1383997211814858, 0.07708669363637455, 0.10341870176489465, 0.08895302642486058, 0.17228285927558318, 0.1239143121347297, 0.17910518537973985, 0.2130576252238825, 0.10967666166834533, 0.14592276827897877, 0.10998448226018809, 0.12364821508526802, 0.4755457886494696, 3.327340381219983, 12.144400086253881, 31.493941247463226, 45.45892909169197, 58.86782817542553, 60.02594143152237, 51.37653775513172, 45.20609825849533, 49.561207965016365, 22.06010576337576, 39.15718384087086, 70.3395988047123, 43.30413691699505, 36.799759939312935, 29.439427591860294, 32.86805011332035, 33.72591108083725, 22.952803261578083, 28.447251431643963, 34.01421681046486, 25.940098464488983, 23.162759095430374, 17.457593232393265, 19.03289370238781, 14.587441943585873, 15.040867812931538, 11.274954490363598, 11.963417697697878, 8.67756586521864, 7.138216216117144, 7.515942547470331, 6.9819586258381605, 6.782789938151836, 6.510780109092593, 7.848282689228654, 9.005350526422262, 10.812861286103725, 12.003347855061293, 12.55814753472805, 13.868068344891071, 16.858984753489494, 24.32761698961258, 28.364244885742664, 32.3809390515089, 23.79362214356661, 23.65871798247099, 24.673029854893684, 25.394468642771244, 31.182190775871277, 26.54820643365383, 30.139203742146492, 35.47483943402767, 46.77624620497227, 48.635919615626335, 41.046689450740814, 32.01516307890415, 23.339269123971462, 11.996441725641489, 3.883191654458642, 0.7956197136081755, 0.09118869435042143, 0.24411036050878465, 0.05427601296105422, 0.21088157402118668, 0.1817971034324728, 0.13319788937224075, 0.14143225533189252, 0.1391408743802458, 0.13034532603342086, 0.10019903507782146, 0.13633370079332963, 0.1307502418057993, 0.19779618945904076, 0.12701501254923642, 0.12375023070489988, 0.2425776919699274, 0.18654054030776024, 0.08251233492046595, 0.14344666677061468, 0.1548106101108715, 0.15009611699497327, 0.11224689718801528, 0.11269381109741516, 0.11717777088051662, 0.1189582202641759, 0.09584634637576528, 0.1661713473731652, 0.1398558891378343, 0.20550190878566355, 0.21132638765266165, 0.20077405701158568, 0.1436565609765239, 0.12995274475542828, 0.10228893777821213, 0.21332426404114813, 0.17675458104349673, 0.12330154306255281, 0.14936725376173854, 0.13531379692722112, 0.22300396260106936, 0.13937690702732652, 0.15409887564601377, 0.1027898355096113, 0.14233251014957204, 0.13965739432023838, 0.15484609961276874, 0.11662375763989985, 0.18444024753989652, 0.09043760379427113, 0.08375145436730236, 0.13672487199073657, 0.15899903926765546, 0.11744467687094584], [0.021738954492320772, 0.028425977798178792, 0.007792646156303817, 0.037693799240514636, 0.023441864286724012, 0.12165088788606226, 0.04911362630082294, 0.005518293319255463, 0.04543656286841724, 0.01655837222642731, 0.043577553442446515, 0.03385703676030971, 0.09451880003325641, 0.04003856287454255, 0.04249498633726034, 0.031445079075638205, 0.07468552677892148, 0.05425128460046835, 0.03977671090979129, 0.03303726414742414, 0.013508779811672866, 0.019179242626705673, 0.015577340200252365, 0.08089682785794139, 0.055214803796843626, 0.054777381956228055, 0.022082631949160714, 0.012557811260194285, 0.020637753914343193, 0.1085585419787094, 0.041310908272862434, 0.041370283797732554, 0.037858797222725116, 0.03961441063438542, 0.0425456119410228, 0.03624015087552834, 0.10958231985569, 0.01603090004209662, 0.13636147195938975, 0.025477410235907882, 0.01858568961324636, 0.037594347741105594, 0.012338361902948236, 0.11319941404508427, 0.008227129092119867, 0.06793173801270314, 0.06820737165980972, 0.05001548786822241, 0.03783120417210739, 0.030879098703735508, 0.015787058146088384, 0.039075455570127815, 0.10332979247323237, 0.03549241853761487, 0.030414477150770836, 0.060783802036894485, 0.05484593042638153, 0.04186301419395022, 0.033466923123341985, 0.051075797964585945, 0.06409621491911821, 0.07188201198005117, 0.16643201932311058, 0.04237559704051819, 0.2026254334487021, 1.2616461818106472, 7.305176882073283, 18.94679982215166, 30.54059710353613, 41.8807028979063, 49.970673993229866, 45.578128695487976, 43.84514808654785, 25.158147923648357, 50.73255971074104, 64.18405070900917, 38.24221573770046, 23.509676679968834, 23.541279584169388, 18.902252912521362, 24.36889797449112, 37.8069718927145, 27.067292779684067, 21.287990994751453, 20.586183853447437, 28.367898389697075, 24.00549877434969, 23.488044440746307, 20.59198424220085, 22.407082244753838, 19.16785106062889, 19.129410423338413, 22.136781848967075, 18.78152009099722, 15.75670475140214, 18.311705701053143, 17.059629186987877, 14.650478661060333, 21.58029031008482, 35.54898865520954, 21.993919014930725, 17.17723097652197, 21.113035082817078, 23.37056804448366, 31.75588969141245, 30.95652848482132, 20.140665359795094, 18.262433744966984, 16.62365198135376, 25.71780849248171, 29.0550497174263, 30.61843402683735, 33.32642711699009, 40.47915570437908, 37.51429259777069, 29.148575998842716, 23.866954408586025, 14.620983693748713, 7.404134022071958, 2.2948581213131547, 0.8243567997124046, 0.02529344110371312, 0.030401736330532003, 0.03217859186406713, 0.04542469221632928, 0.04080594728293363, 0.037787795954500325, 0.0835579913109541, 0.03797639794356655, 0.03267682157456875, 0.08307789597893134, 0.01683964434050722, 0.017011865274980664, 0.018630049635248724, 0.026559734287729952, 0.04201105039101094, 0.05537276992981788, 0.03673279963550158, 0.03260763485741336, 0.01905720757349627, 0.05271993337373715, 0.04880550884990953, 0.05091197257570457, 0.029767235319013707, 0.025376377961947583, 0.02056458186416421, 0.020204796092002653, 0.017483611445641145, 0.10390947660198435, 0.04272803183994256, 0.043835282776854, 0.05645479897793848, 0.08094521588645875, 0.01955399195139762, 0.03682164584461134, 0.08110487411613576, 0.061329429008765146, 0.034323955260333605, 0.05860503457370214, 0.04136281037062872, 0.03164499139529653, 0.03618497219576966, 0.042789696890395135, 0.032884481915971264, 0.06214151668245904, 0.10511915505048819, 0.04868462041486055, 0.07999085108167492, 0.015841763706703205, 0.07312358793569729, 0.009273871801269706, 0.1134983214433305, 0.03708667791215703, 0.012689498871623073, 0.0744310740265064, 0.006530028922497877, 0.018767367364489473, 0.06497922222479247, 0.03078300171182491, 0.04024415262392722, 0.09967599908122793, 0.1326623110799119, 0.07258153811562806, 0.04895317768387031, 0.0660874490858987, 0.032378366886405274, 0.030897259057383053, 0.04981313017196953, 0.07014743474428542, 0.018698299390962347, 0.01940515237947693, 0.06708835397148505, 0.04724810452898964, 0.047742608658154495, 0.029024152536294423, 0.0323669415229233, 0.00967885622230824, 0.05234302625467535, 0.022352530650096014, 0.07323846497456543, 0.03223665749828797, 0.01808810186048504, 0.0199585459267837, 0.035344564166734926, 0.03267447267717216, 0.0441953691188246, 0.040540425397921354, 0.03302938996057492, 0.07700841932091862, 0.018121953071386088, 0.024290074143209495, 0.05130360761540942, 0.030362413635884877, 0.020754846264026128, 0.11659945230348967, 0.0994266671477817, 0.03237103817809839, 0.03792967603658326, 0.030054422350076493, 0.026161388377659023, 0.06636792153585702, 0.029796529743180145, 0.04081675666384399, 0.022250227448239457, 0.0398960000165971, 0.010777460211102152, 0.05051925028965343, 0.06095645898312796, 0.0447401685960358, 0.03445702233875636, 0.015280535862984834, 0.025877284970192704, 0.030797020881436765, 0.049735727880033664, 0.03893252905982081, 0.02049162874754984, 0.03462437292910181, 0.0888162263436243, 0.08316556588397361, 0.07002743688644841, 0.5578358354978263, 2.289745258167386, 10.50865625962615, 25.351475849747658, 39.92794208228588, 47.87920922040939, 52.61000096797943, 47.461873814463615, 38.00358094274998, 27.378579676151276, 55.449334010481834, 59.989672377705574, 29.843154028058052, 17.695800550282, 17.220556251704693, 22.798820324242115, 18.2269037514925, 35.72685331106186, 36.1441583186388, 27.862920686602592, 31.05142269283533, 33.481660187244415, 37.28632003068924, 28.393013142049313, 27.958749644458294, 33.28239127993584, 30.88993515819311, 26.07193809002638, 24.764175564050674, 22.31906946748495, 22.875114530324936, 22.816932052373886, 25.148876421153545, 22.236526496708393, 29.282345920801163, 35.629023760557175, 25.6210732832551, 22.93919999152422, 21.616827249526978, 24.306594617664814, 36.641977205872536, 33.880209401249886, 23.795164860785007, 16.55301947146654, 15.094463936984539, 19.132818840444088, 23.676447831094265, 29.462262466549873, 32.58812293410301, 41.00773774087429, 40.76748043298721, 33.89225095510483, 29.22356117516756, 19.490472748875618, 11.189234890043736, 4.56764180213213, 1.2363115162588656, 0.10271570979966782, 0.046583615185227245, 0.04389915200590622, 0.04712175388704054, 0.051559477869886905, 0.03772996409679763, 0.08447652522590943, 0.04134615286602639, 0.09084306133445352, 0.01286056391109014, 0.014471594895439921, 0.05707421398255974, 0.03934271779144183, 0.05663419833581429, 0.060507593225338496, 0.055937258584890515, 0.019490814775053877, 0.027573893930821214, 0.038176054222276434, 0.036820985333179124, 0.06528210011310875, 0.01258834785403451, 0.11535358673427254, 0.031894861385808326, 0.054857114591868594, 0.031613750688848086, 0.05726341711124405, 0.09035524766659364, 0.05248807530733757, 0.02987298579682829, 0.04956006152497139, 0.03185628083883785, 0.05015823626308702, 0.06877147068735212, 0.030899502198735718, 0.013946485523774754, 0.06824095384217799, 0.051539061387302354, 0.061369720206130296, 0.03939804861147422, 0.012087105951650301, 0.028329860397207085, 0.04297281811886933, 0.014340261659526732, 0.04403141014336143, 0.03809914174780715, 0.011718210316757904, 0.06829215461038984, 0.03575809998437762, 0.04705087878392078, 0.10108406844665296, 0.03238365468860138, 0.020241576930857264, 0.05662452815158758, 0.0628791372582782, 0.07504649998736568, 0.20276096445741132, 0.18269357329700142, 0.1840086589800194, 0.132502140768338, 0.3079442633315921, 0.14196066447766498, 0.13596553617389873, 0.13855064433300868, 0.11344247483066283, 0.11875987387611531, 0.13927644991781563, 0.19910447706934065, 0.08304023940581828, 0.10609540579025634, 0.17582257714821026, 0.18774158757878467, 0.12576749199070036, 0.13216530962381512, 0.1441748917568475, 0.07025789600447752, 0.18671981350053102, 0.09923793157213368, 0.17663641629042104, 0.1714265247574076, 0.10707543406169862, 0.11861373015563004, 0.11291886738035828, 0.14123273635050282, 0.13785238726995885, 0.10237601396511309, 0.15205054805846885, 0.17385506944265217, 0.1119092496810481, 0.16284444776829332, 0.08501504242303781, 0.19381948019145057, 0.1337910583242774, 0.31003655574750155, 0.15036223630886525, 0.11972128166235052, 0.11742431233869866, 0.13259023369755596, 0.15660770586691797, 0.1473605161299929, 0.10792885193950497, 0.15783603448653594, 0.17715151130687445, 0.07439801134751178, 0.14266807964304462, 0.15001290739746764, 0.1557090095593594, 0.1538709324086085, 0.19501763308653608, 0.1392491240403615, 0.19393445370951667, 0.16905678785406053, 0.15897411794867367, 0.08774369678576477, 0.16843354707816616, 0.20032188127515838, 0.15636158001143485, 0.22330862906528637, 0.17967698047868907, 0.5590769439004362, 2.6545301964506507, 13.318688124418259, 29.709213115274906, 47.62797810137272, 58.22793871164322, 65.53593456745148, 59.179848432540894, 51.80371083319187, 36.00207634270191, 61.169592663645744, 71.78191781044006, 47.78055891394615, 35.6678880751133, 30.698763616383076, 30.41048638522625, 32.46116414666176, 50.494479686021805, 41.74503117799759, 29.43998046219349, 30.814809389412403, 38.652669712901115, 36.44790641963482, 31.846535727381706, 29.19937737286091, 33.11054550111294, 28.4735669195652, 27.09149368107319, 32.01084651052952, 24.990269131958485, 23.402172848582268, 25.810599513351917, 25.875655822455883, 20.72773765772581, 31.512315161526203, 44.648113399744034, 28.471991904079914, 24.902894720435143, 28.21209914982319, 31.798202320933342, 44.111992567777634, 42.657525613904, 27.70932722836733, 28.47106095403433, 24.834390096366405, 35.31194977462292, 38.10100011527538, 40.67997872829437, 46.24330960214138, 50.76570153236389, 49.65432956814766, 39.58722196519375, 32.496730238199234, 20.719201415777206, 11.175801660865545, 3.854566365480423, 1.1784299346618354, 0.12196425232104957, 0.20677679975051433, 0.08769881911575794, 0.11232014716370031, 0.12692003248957917, 0.24170373886590824, 0.16708427807316184, 0.15729327220469713, 0.19201312243239954, 0.22859733668155968, 0.09691915794974193, 0.16224476275965571, 0.07124618437956087, 0.17532140482217073, 0.1316561221028678, 0.13571838615462184, 0.10062781831948087, 0.09583666134858504, 0.1281167901470326, 0.09592429414624348, 0.26619136158842593, 0.13382194651057944, 0.16183809551876038, 0.1675978145794943, 0.20401532761752605, 0.2340569460648112, 0.15667745290556923, 0.19772344414377585, 0.13398167153354734, 0.15364143066108227, 0.2956836571684107, 0.1440988216199912, 0.1249490663758479, 0.1830591997713782, 0.13110549305565655, 0.1765996651374735, 0.190101973421406, 0.14606448879931122, 0.2206510427640751, 0.12341031964751892, 0.16555831854930148, 0.16199531208258122, 0.15262112603522837, 0.2082653550314717, 0.23673883028095588, 0.15538678388111293, 0.19366808206541464, 0.13913529342971742, 0.12826569465687498, 0.09011885878862813, 0.19356271193828434, 0.12176284086308442, 0.09866332373348996, 0.15586594410706311, 0.13092899549519643], [0.04493815504247323, 0.008721234316908522, 0.05987952106806915, 0.02519285411835881, 0.05155161481525283, 0.012302107061259449, 0.06541278489748947, 0.02373777711909497, 0.052525438732118346, 0.031192370370263234, 0.0583914259186713, 0.032027921042754315, 0.016689305630279705, 0.05414022962213494, 0.03069913716899464, 0.050389296520734206, 0.015378971547761466, 0.06840801128419116, 0.06618025465286337, 0.06657627949607559, 0.00835804301459575, 0.0678225458250381, 0.05405229254392907, 0.07796653197146952, 0.01413685846273438, 0.003984665090683848, 0.0700239636353217, 0.03602054937800858, 0.09116686036577448, 0.06764506120816804, 0.02897510214097565, 0.03512193841743283, 0.026091194195032585, 0.029935352176835295, 0.026857947777898517, 0.024473902267345693, 0.012277789664949523, 0.0361592456465587, 0.0631608565163333, 0.01100998528272612, 0.0724959016952198, 0.08978521145763807, 0.01221693633851828, 0.0620774544950109, 0.051224832350271754, 0.0695607002126053, 0.027887850228580646, 0.033057940381695516, 0.006865695359010715, 0.04102002720173914, 0.04330948228016496, 0.026827755355043337, 0.03145268237858545, 0.020882475255348254, 0.0174933150265133, 0.09141311238636263, 0.024011549830902368, 0.009787074341147672, 0.0956508943636436, 0.050305463519180194, 0.07750674922135659, 0.04899386964098085, 0.05728425290726591, 0.026242532949254382, 0.030736715816601645, 0.04054191711475141, 0.11998765330645256, 1.352211709599942, 5.623369552195072, 13.502906039357185, 30.440793558955193, 40.851193740963936, 51.172785088419914, 42.920866683125496, 47.481723949313164, 56.25676788389683, 51.75450347363949, 45.42024336755276, 30.380819477140903, 23.086996860802174, 31.002523116767406, 29.110293053090572, 24.76871632039547, 25.751867964863777, 16.164174936711788, 19.867532216012478, 23.146425671875477, 32.95535422861576, 28.677078299224377, 18.58934350311756, 19.658818915486336, 22.26784821599722, 22.73049809038639, 18.68605401366949, 21.079315692186356, 15.592050086706877, 23.155169002711773, 15.804697126150131, 24.582826495170593, 66.2561023235321, 30.714154690504074, 19.68655362725258, 24.546625837683678, 27.085461504757404, 18.267458975315094, 28.007455430924892, 27.604834735393524, 26.6361603140831, 32.12781183421612, 37.4363549798727, 38.14922332763672, 37.45326787233353, 36.66370443999767, 30.06339780986309, 19.892441779375076, 10.57673055678606, 6.812612162902951, 1.6275963513180614, 0.4715764563297853, 0.023866046212788206, 0.059508937047212385, 0.038790055259596556, 0.08952492542448454, 0.025632378092268482, 0.012144824631832307, 0.0869044465071056, 0.027649544754240196, 0.015396736707771197, 0.029883576244174037, 0.040958937315735966, 0.012511462282418506, 0.02457494196278276, 0.06573871389264241, 0.012920522021886427, 0.0034344987261647475, 0.02408211694273632, 0.03467519891273696, 0.054943411523709074, 0.020498417543421965, 0.009843178850132972, 0.07017497584456578, 0.03255777737649623, 0.01810592268157052, 0.014908409102645237, 0.019181474635843188, 0.04638410362531431, 0.023656992489122786, 0.048720388222136535, 0.024513622010999825, 0.0143860595926526, 0.061185934755485505, 0.0514488422049908, 0.05661397852236405, 0.10288222547387704, 0.09073323832126334, 0.01995845315832412, 0.0024400213033004547, 0.057885852656909265, 0.0625993475841824, 0.041821914055617526, 0.0038678410737702507, 0.033897780667757615, 0.016057886386988685, 0.04959708727255929, 0.050817215160350315, 0.014591322797059547, 0.05565436302276794, 0.04412702102854382, 0.008102503015834372, 0.013661138091265457, 0.05366672827221919, 0.03550590707163792, 0.02972173795569688, 0.061820715927751735, 0.013876279281248571, 0.036383485567057505, 0.03386982025403995, 0.03201753097528126, 0.029074948834022507, 0.06888413612614386, 0.0724176422227174, 0.02982866844831733, 0.026967468365910463, 0.041927284182747826, 0.04203026830509771, 0.04747840037452988, 0.017389592467225157, 0.033241447526961565, 0.04449807260243688, 0.024029036685533356, 0.019499765076034237, 0.029868089477531612, 0.009662738630140666, 0.02402256886853138, 0.04612371740222443, 0.08008242468349636, 0.04047265989356674, 0.06675458047538996, 0.028349241583782714, 0.04987784916011151, 0.01660867128521204, 0.03708685973833781, 0.09430362915736623, 0.0408665733266389, 0.007745300845272141, 0.03492324693070259, 0.08209404564695433, 0.023393103328999132, 0.0697351642884314, 0.02562157613283489, 0.003676922192425991, 0.04319982625020202, 0.016463631509395782, 0.018419389161863364, 0.06536948058055714, 0.032501077294000424, 0.025664253334980458, 0.04312926284910645, 0.030253824443207122, 0.008172716679837322, 0.019720737691386603, 0.0486745383386733, 0.0650310018681921, 0.03418122170842253, 0.03923141790437512, 0.06401314632967114, 0.0382497606187826, 0.037050962055218406, 0.015413981436722679, 0.011598875753406901, 0.036056829267181456, 0.055778709865990095, 0.01223411520186346, 0.01388820652209688, 0.050612786872079596, 0.058357851157779805, 0.016005924917408265, 0.01964077313459711, 0.036907779503962956, 0.041322211181977764, 0.07367179016000591, 0.018722215099842288, 0.24753093399340287, 2.2402503015473485, 8.354435004293919, 19.62119523435831, 39.5799757540226, 49.13576379418373, 58.29498991370201, 46.381553784012794, 50.07788144052029, 61.9003314524889, 54.8407244682312, 42.118330746889114, 26.802207604050636, 17.549603395164013, 23.69363620877266, 28.485899157822132, 24.037722945213318, 23.714460991322994, 12.822252362966537, 23.16151086241007, 24.18133433908224, 29.358940310776234, 29.933180697262287, 22.20492359250784, 24.899319112300873, 26.85713365674019, 33.071578592062, 25.04788924008608, 26.166991889476776, 24.35504011809826, 23.65454960614443, 17.934011667966843, 26.113137379288673, 71.13839954137802, 32.51259058713913, 19.190526343882084, 23.06090746074915, 25.366557240486145, 23.458525724709034, 33.01794447004795, 27.12017074227333, 25.799289420247078, 28.71687736362219, 37.684170082211494, 39.444801807403564, 40.13902835547924, 41.26038618385792, 37.01414443552494, 27.09179386496544, 17.245435416698456, 10.359860993921757, 3.4256213949993253, 0.9501128923147917, 0.04308628136641346, 0.044306884228717536, 0.009892188427329529, 0.06295243176282384, 0.026191918477707077, 0.042137519776588306, 0.032478538269060664, 0.04780825904163066, 0.046817443653708324, 0.04100228245079052, 0.039521356447949074, 0.03728959592990577, 0.09354322464787401, 0.04837986489292234, 0.06196926049597096, 0.044729626388289034, 0.03064642056415323, 0.06083597872930113, 0.030519901083607692, 0.0188602712660213, 0.05195196266868152, 0.06141352547274437, 0.02212843730376335, 0.028873555929749273, 0.015539250398433069, 0.03513622847094666, 0.03153593650495168, 0.020599928502633702, 0.07919379931990989, 0.0037566717583104037, 0.003704281234604423, 0.00982571704298607, 0.026112688647117466, 0.023712187867204193, 0.036686159364762716, 0.02909555270889541, 0.03372848193976097, 0.009579381530784303, 0.07320661941776052, 0.08531934523489326, 0.0250581172076636, 0.033824979691416956, 0.040928271773736924, 0.03220440004952252, 0.042176950082648546, 0.045813570177415386, 0.09869183704722673, 0.027780565360444598, 0.047197890817187726, 0.03404490773391444, 0.039017055969452485, 0.07133234030334279, 0.00786854930993286, 0.03769712035136763, 0.048803597819642164, 0.03158757885103114, 0.0249187084773439, 0.1015710954379756, 0.12719351390842348, 0.15442111616721377, 0.18987725110491738, 0.21243873343337327, 0.2118976484052837, 0.14789523353101686, 0.11257434758590534, 0.10277344888891093, 0.07121161514078267, 0.10941897315206006, 0.16426831745775416, 0.09600253135431558, 0.13932645582826808, 0.0944446594803594, 0.13723471260163933, 0.06860796813271008, 0.14587170851882547, 0.10790476924739778, 0.17604440508875996, 0.12362708614091389, 0.19263133144704625, 0.11165778778376989, 0.15430114057380706, 0.05585919578152243, 0.06823010364314541, 0.18457745580235496, 0.14004035736434162, 0.16085225623100996, 0.15411244210554287, 0.09828322537941858, 0.0932585664850194, 0.21480054419953376, 0.19461340009002015, 0.13438590453006327, 0.15017380501376465, 0.13330254703760147, 0.09670418003224768, 0.1437859915313311, 0.07929528059321456, 0.12855709152063355, 0.14340081688715145, 0.12518726609414443, 0.15841321757761762, 0.2909288357477635, 0.11749080134904943, 0.15658759366488084, 0.09905355240334757, 0.1568358123768121, 0.14776602562051266, 0.057145734754158184, 0.09548912843456492, 0.1147465841495432, 0.09831913048401475, 0.13837677397532389, 0.12158226149040274, 0.13776004925603047, 0.14787874300964177, 0.23347329144598916, 0.09939686991856433, 0.13084511796478182, 0.1374699585721828, 0.1755807112203911, 0.15720375435194, 0.16015016968594864, 0.11788163858000189, 0.2783355989959091, 2.5675573758780956, 10.3570462949574, 24.015055261552334, 46.98246493935585, 58.64753119647503, 67.16999128460884, 55.67717358469963, 58.308851569890976, 68.06337654590607, 63.279904425144196, 59.105064645409584, 39.26665596663952, 35.10605402290821, 39.12316046655178, 42.212083116173744, 36.44434221088886, 37.3171553760767, 23.724672943353653, 30.941460393369198, 32.92842507362366, 45.81311948597431, 41.92961387336254, 26.265761889517307, 31.000290736556053, 31.097584515810013, 38.03677596151829, 26.9730806350708, 31.723080351948738, 27.979414835572243, 34.725610837340355, 24.42459538578987, 33.324743807315826, 79.70011532306671, 37.60285824537277, 28.987118862569332, 35.424461737275124, 38.16671758890152, 27.666136845946312, 40.69785676896572, 36.63724645972252, 35.93939870595932, 43.562967628240585, 48.565140813589096, 52.23224803805351, 48.6274004727602, 47.57923811674118, 39.33874569833279, 27.72624012082815, 15.958374179899693, 8.985091913491488, 2.8569598216563463, 0.8057408267632127, 0.13942666060756892, 0.15848648239625618, 0.21215469867456704, 0.21912653784966096, 0.10287841825629584, 0.13608132605440915, 0.17808468779549003, 0.10615462175337598, 0.12010880891466513, 0.09756912346347235, 0.09474292863160372, 0.13061586854746565, 0.1644427518476732, 0.2520039916271344, 0.09336338000139222, 0.07639773568371311, 0.08358628940186463, 0.13603289349703118, 0.0980096029525157, 0.1544727844884619, 0.15391241846373305, 0.21618665341520682, 0.11958478586166166, 0.07651122490642592, 0.1500965325976722, 0.10588807199383155, 0.14646642113802955, 0.08367989648832008, 0.19444790115812793, 0.12439588434062898, 0.044552683539222926, 0.1493150510941632, 0.16432310279924423, 0.1867617151583545, 0.22842886915896088, 0.12240902142366394, 0.18274702277267352, 0.06042825763870496, 0.13680733944056556, 0.17556582373799756, 0.1834445822169073, 0.115031331370119, 0.1562533006654121, 0.12187193657155149, 0.11582337363506667, 0.13342984020709991, 0.134896413073875, 0.09568131499690935, 0.11992014755378477, 0.1534716718015261, 0.1963133190292865, 0.21582494548056275, 0.15352915856055915, 0.111760144791333, 0.11783454188844189, 0.06818089925218374, 0.08645283480291255], [0.05397781802457757, 0.007581681402371032, 0.050002355565084144, 0.008981562095868867, 0.09377884169225581, 0.018493796887923963, 0.04590900665789377, 0.029211758192104753, 0.08607197945821099, 0.06162194651551545, 0.011481006931717275, 0.07904706930276006, 0.023188331797427963, 0.0726879175635986, 0.05376616863941308, 0.05071280240372289, 0.058103053306695074, 0.07402891904348508, 0.015851814241614193, 0.038079912701505236, 0.07383491421933286, 0.057682778788148426, 0.023052118012856226, 0.004532242519417196, 0.056349376900470816, 0.06745545731973834, 0.04655917626223527, 0.046170120185706764, 0.014516632127197227, 0.014835867877991404, 0.049094979840447195, 0.054100806737551466, 0.030065968312555924, 0.05419944558525458, 0.03452907745668199, 0.035753580305026844, 0.032660969300195575, 0.05996498679451179, 0.020911604551656637, 0.07995391439180821, 0.01131543471274199, 0.024393037856498268, 0.06818402369390242, 0.037437487408169545, 0.024404372306889854, 0.026194842539553065, 0.03213202209735755, 0.017450034829380456, 0.005595774000539677, 0.09857031036517583, 0.06722351390635595, 0.057737998286029324, 0.0683604618825484, 0.03468156653980259, 0.04723823025415186, 0.033276517715421505, 0.08649848430650309, 0.07784404049743898, 0.012124056556785945, 0.04729920139652677, 0.016443957174487878, 0.05004011603887193, 0.0190815908354125, 0.0471169373486191, 0.06546938850078732, 0.04324464454839472, 0.01127633651776705, 0.03506290799123235, 0.052568000901374035, 0.5408074054867029, 3.412058260291815, 10.858285948634148, 22.62582890689373, 40.81038013100624, 40.97114570438862, 50.74715852737427, 50.11556401848793, 51.965544149279594, 42.07540065050125, 47.87379451096058, 44.11383546888828, 46.13873541355133, 35.40320187807083, 33.587932884693146, 35.51017373800278, 27.50676579773426, 34.31003473699093, 30.534713119268417, 29.399674125015736, 29.452160708606243, 27.56647389382124, 27.67443560063839, 24.023521207273006, 21.512817330658436, 19.896228276193142, 14.10464745014906, 29.84232947230339, 31.613940708339214, 42.84630328416824, 85.90314567089081, 28.252038806676865, 21.618890538811684, 21.294595040380955, 28.363317735493183, 33.6042720079422, 35.903053656220436, 42.245080545544624, 40.57105377316475, 41.46667331457138, 33.481523394584656, 29.11100171506405, 22.094309628009796, 11.344286520034075, 6.002231547608972, 1.763703147880733, 0.22992971440544352, 0.029249954677652568, 0.03799399426497985, 0.036040728373336606, 0.01634998458030168, 0.024547866560169496, 0.07066840014886111, 0.08876239095116034, 0.06681093916995451, 0.06350539115373977, 0.033652612182777375, 0.10615755323669873, 0.0742190053279046, 0.03984852482972201, 0.03912531305104494, 0.03561405283107888, 0.03076547774981009, 0.04969507674104534, 0.05592805966443848, 0.014164865260681836, 0.02918469577707583, 0.06186707047163509, 0.028733666658808943, 0.04993224116333295, 0.048004130367189646, 0.020252733265806455, 0.040205609184340574, 0.050959937580046244, 0.042255970256519504, 0.061658081685891375, 0.04205115976219531, 0.007183604984675185, 0.147029978397768, 0.02933597887022188, 0.02622527059429558, 0.006398467940016417, 0.023926635149109643, 0.05616394388198387, 0.047986812351155095, 0.004376894776214613, 0.029361556989897508, 0.1520580585929565, 0.04282246642105747, 0.04627367576176766, 0.03566383238648996, 0.0118715853386675, 0.031785828759893775, 0.06789212216972373, 0.015542266301054042, 0.013788321793981595, 0.027289146710245404, 0.019313432203489356, 0.002318944780199672, 0.01673045215284219, 0.06319095802609809, 0.048980796709656715, 0.060702919072355144, 0.025854484338196926, 0.11293730975012295, 0.0518479692254914, 0.04863252535869833, 0.013057534542895155, 0.0068910383106413065, 0.06671492752502672, 0.021798953421239275, 0.06961413484532386, 0.04272930462320801, 0.013098604995320784, 0.043047808430856094, 0.040442298632115126, 0.07321657903958112, 0.036104508544667624, 0.06825725140515715, 0.03259229466493707, 0.05743663066823501, 0.02465607725753216, 0.054386195915867575, 0.04648039728635922, 0.06388262481777929, 0.06617002785787918, 0.034764212105073966, 0.06727900428813882, 0.016640030735288747, 0.05001080491638277, 0.04210105435049627, 0.04370977076177951, 0.01596426074684132, 0.019477192654449027, 0.007551777489425149, 0.003798965362875606, 0.050413175122230314, 0.057211470484617166, 0.05991578982502688, 0.049149271653732285, 0.06268568162340671, 0.05760876440035645, 0.05247933651844505, 0.02493326013791375, 0.04905322661215905, 0.000991767540199362, 0.035304799894220196, 0.03644688353233505, 0.023822001603548415, 0.04295549639209639, 0.01517392078312696, 0.04602085202350281, 0.06365700450260192, 0.007816434772394132, 0.11510446260217577, 0.027963070606347173, 0.03813997100223787, 0.08382962478208356, 0.03981843816291075, 0.0077055430665495805, 0.011336926381773083, 0.019309162998979446, 0.1236045768018812, 0.01434419504221296, 0.062275259115267545, 0.033862973941722885, 0.0599652057280764, 0.04633367097994778, 0.013917636388214305, 0.026104990720341448, 0.023468678082281258, 0.02404532682703575, 0.02217761386418715, 0.06667926732916385, 0.02187447065807646, 0.10457257070811465, 0.8338964846916497, 4.4520824030041695, 13.47331702709198, 29.2488906159997, 46.566212475299835, 49.61051031947136, 57.34242282807827, 56.59370720386505, 56.875268295407295, 43.858397975564, 47.12189465761185, 44.150324910879135, 45.64753957092762, 35.51615081727505, 28.18326059728861, 26.936296708881855, 23.756427839398384, 27.559265680611134, 31.943282335996628, 29.337450563907623, 22.54655186086893, 22.762948349118233, 24.05600756406784, 25.552927739918232, 20.22203989326954, 16.56266525387764, 13.509330544620752, 27.650548182427883, 24.361997544765472, 37.9144187271595, 86.27088233828545, 30.719504803419113, 18.9170778170228, 21.23613517731428, 28.992316983640194, 31.784956231713295, 37.5316196680069, 42.320061922073364, 43.30621160566807, 45.499005541205406, 40.32440520823002, 36.23105965554714, 28.604410998523235, 16.125008538365364, 9.424049109220505, 3.454448548145592, 0.6353135593235493, 0.03572585366782732, 0.041395624430151656, 0.06535399195854552, 0.03735260797839146, 0.02186597863328643, 0.11754895604099147, 0.05064973469416145, 0.08979716003523208, 0.010498256833670894, 0.11537656362634152, 0.03834766845102422, 0.04103335246327333, 0.06630969262914732, 0.04517982801189646, 0.023485522979171947, 0.03301067670690827, 0.05309773849148769, 0.049231026641791686, 0.04574715167109389, 0.06483500808826648, 0.02102270591421984, 0.04612902004737407, 0.057057244775933214, 0.048670389733160846, 0.0331298285163939, 0.021389287903730292, 0.023815171989554074, 0.050031781720463187, 0.024974801854114048, 0.058145674847764894, 0.018780210230033845, 0.03561698802514002, 0.029125420442142058, 0.035748452064581215, 0.02157888622605242, 0.05914165929425508, 0.02441751945298165, 0.011549205664778128, 0.06953001982765272, 0.060388875572243705, 0.03395610605366528, 0.021658997357008047, 0.06595892395125702, 0.0069819699547224445, 0.019283905858173966, 0.018192204770457465, 0.012464690280467039, 0.03597873306716792, 0.03693706094054505, 0.030617148404417094, 0.0462785145646194, 0.013291572668094886, 0.05822988263389561, 0.016823042496980634, 0.04518421410466544, 0.05596296658040956, 0.016061515489127487, 0.02900773808505619, 0.0227816051847185, 0.06309700955171138, 0.21678103948943317, 0.12941964523633942, 0.17526471958262846, 0.09009734392748214, 0.14225885941414163, 0.12691142357653007, 0.15071671572513878, 0.17343431623885408, 0.1275456926668994, 0.20599684707121924, 0.12847533653257415, 0.19308631250169128, 0.10424944703117944, 0.1216806480078958, 0.11804916357505135, 0.2232798040495254, 0.0977084987971466, 0.20019843243062496, 0.14968542731367052, 0.14194288261933252, 0.20813950162846595, 0.16039148642448708, 0.1065899062086828, 0.1260794760310091, 0.21457209630170837, 0.14772468799492344, 0.14541971089784056, 0.1336958704632707, 0.1355505271931179, 0.15793767903232947, 0.14401340042240918, 0.20284923550207168, 0.16031191335059702, 0.13410584768280387, 0.09925796213792637, 0.25149903434794396, 0.18482197861885652, 0.08203171266359277, 0.11569441063329577, 0.15250230819219723, 0.11803260626038536, 0.13515010883565992, 0.17581586813321337, 0.14425762637984008, 0.10722866529249586, 0.13746461510891095, 0.12189369634143077, 0.28532048512715846, 0.10589523371891119, 0.16995698329992592, 0.18605622957693413, 0.1469543535495177, 0.2223400818184018, 0.08877528947778046, 0.1368244385230355, 0.24793207965558395, 0.15919756377115846, 0.19513205741532147, 0.14629835437517613, 0.14453109295573086, 0.16857419890584424, 0.1578933431301266, 0.10725215426646173, 0.07992561630089767, 0.15664551086956635, 0.17581082152901217, 0.1733872343902476, 0.0813687892514281, 0.1532662007957697, 0.9375143714714795, 5.2551341615617275, 16.226605586707592, 33.88269826769829, 56.60908117890358, 57.634771540760994, 66.77031353116035, 60.89409224689007, 68.48151370882988, 56.318370178341866, 63.82652789354324, 58.42268206179142, 58.339842706918716, 48.145324140787125, 46.02274663746357, 46.53149373829365, 37.96403646469116, 48.82058210670948, 41.12322874367237, 43.31160731613636, 38.30207772552967, 40.09658083319664, 39.29147623479366, 36.28019481897354, 33.519578352570534, 27.295510433614254, 24.34451848268509, 45.151271000504494, 41.401111632585526, 50.25946609675884, 95.85076108574867, 34.70889173448086, 28.694255277514458, 32.734323889017105, 38.83475974202156, 46.053433790802956, 47.769243121147156, 54.46705251932144, 53.622528836131096, 55.478850826621056, 44.688315242528915, 38.81227634847164, 29.00284431874752, 16.140167824923992, 8.092449512332678, 3.2224061619490385, 0.6901405798271298, 0.17739928473019972, 0.13407071441179141, 0.14861136151012033, 0.1717902661766857, 0.10587761513306759, 0.21522180206375197, 0.19085675245150924, 0.18455608194926754, 0.18309834063984454, 0.20766863861354068, 0.10374688688898459, 0.16430364368716255, 0.11797657411079854, 0.11365068436134607, 0.07285106388735585, 0.10341182205593213, 0.13538551807869226, 0.14148292917525396, 0.10601211455650628, 0.27909656753763556, 0.1194333060993813, 0.12890297686681151, 0.27177174808457494, 0.14902604394592345, 0.07412123479298316, 0.1094437534629833, 0.15004728367784992, 0.1480171238654293, 0.19754252338316292, 0.17127943108789623, 0.06283445996814407, 0.2862582926172763, 0.1404075720347464, 0.10719178797444329, 0.1224340169574134, 0.11674550696625374, 0.11943904290092178, 0.14187016698997468, 0.11632401161477901, 0.1549719084869139, 0.20055834436789155, 0.11644253259873949, 0.1484286002232693, 0.11238020917517133, 0.1097771707281936, 0.12581156071973965, 0.16749818867538124, 0.099000340414932, 0.12638439482543617, 0.07195503188995644, 0.10546253935899585, 0.09259582860977389, 0.27083477179985493, 0.1411963562713936, 0.1349448604742065, 0.29216255235951394, 0.1874653750564903, 0.2009446916054003, 0.1125599276565481, 0.13385500176809728], [0.0448952700389782, 0.05627929960610345, 0.05301330063957721, 0.024948676400526892, 0.030463616603810806, 0.027724616702471394, 0.0336082762805745, 0.03566763589333277, 0.0319757146644406, 0.06597147366846912, 0.06107759603764862, 0.017110485568991862, 0.025740067430888303, 0.049676237322273664, 0.0317712158721406, 0.06063173968868796, 0.0404382316628471, 0.07746273244265467, 0.029350823679124005, 0.002609464750094048, 0.026359682815382257, 0.028049207976437174, 0.05214486169279553, 0.055115630602813326, 0.02058430814940948, 0.027522138407221064, 0.07602223864523694, 0.037837453055544756, 0.04607487666362431, 0.051931590714957565, 0.05791888936073519, 0.035074756378890015, 0.022884251629875507, 0.026601070057949983, 0.02107564330799505, 0.03243448067223653, 0.03281534343841486, 0.05542518410948105, 0.01402179681463167, 0.01386222578730667, 0.02065994412987493, 0.11372700682841241, 0.02397075582848629, 0.02552710815507453, 0.05333685105142649, 0.052984835565439425, 0.015289744987967424, 0.04212645064399112, 0.03531413240125403, 0.03739510335435625, 0.027964985347352922, 0.0224559786147438, 0.02786998487863457, 0.03960502246627584, 0.06594666367163882, 0.027096997255284805, 0.06696521682897583, 0.04016523263999261, 0.026981904993590433, 0.00963642949500354, 0.025611768651288003, 0.004305521042624605, 0.02150301090296125, 0.0579725577699719, 0.0081733632760006, 0.10139613412320614, 0.060942191194044426, 0.03681609457999002, 0.016043529540183954, 0.14386789494892582, 0.02339484737603925, 0.2116881252732128, 1.1547010391950607, 7.345475619658828, 15.454110838472843, 18.140572383999825, 31.68805953115225, 30.863575972616673, 43.10406245291233, 43.37323620915413, 50.82277446985245, 47.52370409667492, 46.0482432693243, 53.34772378206253, 49.05569829046726, 45.05867376923561, 51.32915809750557, 45.17860673367977, 45.54155945777893, 39.008866399526596, 39.297445714473724, 38.65837700664997, 41.76769696176052, 40.32976292073727, 41.0643395036459, 33.99177521467209, 33.1037362664938, 38.19104388356209, 52.64258801937103, 67.10961252450943, 34.75862726569176, 46.18489533662796, 44.74450662732124, 49.700778275728226, 45.96526712179184, 41.248044446110725, 38.76226723194122, 28.390959352254868, 15.679923221468925, 8.810230046510696, 3.9823440089821815, 1.0955980606377125, 0.08588192285969853, 0.046583192161051556, 0.08184383055777289, 0.04005258946563117, 0.020377592190925498, 0.024935364126577042, 0.04084580061316956, 0.06264977651881054, 0.024748862415435724, 0.05927043304836843, 0.07952215513796546, 0.01855729875387624, 0.017253939004149288, 0.04975274532625917, 0.03862825222313404, 0.03651394770713523, 0.049946527506108396, 0.009142012568190694, 0.011855039156216662, 0.09551894050673582, 0.05478515595314093, 0.05308581217832398, 0.023892325662018266, 0.08928886309149675, 0.01071831753506558, 0.016335395812347997, 0.05070550709206145, 0.040989012850332074, 0.005932915455559851, 0.04817298009584192, 0.011920114375243429, 0.06943154425243847, 0.005500593097167439, 0.08468489060760476, 0.005229952248555492, 0.06437999734771438, 0.041684984098537825, 0.07616818198584951, 0.026481840322958305, 0.06786110781831667, 0.009305686744482955, 0.03147375937260222, 0.06822952476795763, 0.009981279545172583, 0.03857472853269428, 0.03968872930272482, 0.0781308212026488, 0.05466762573632877, 0.011648011495708488, 0.008534560056432383, 0.023983429855434224, 0.060724667710019276, 0.062438101158477366, 0.007487691182177514, 0.02241296930151293, 0.01641213573748246, 0.021035159152233973, 0.013644637365359813, 0.028980835231777746, 0.030075139402470086, 0.017732156702550128, 0.04239557194523513, 0.05446698240120895, 0.025836422319116537, 0.03195579171006102, 0.03094497358688386, 0.025675428223621566, 0.06102824321715161, 0.07306037921807729, 0.07276720119989477, 0.037546701860264875, 0.06919058374478482, 0.016835503156471532, 0.020207371344440617, 0.02812875321978936, 0.024099713264149614, 0.061741153986076824, 0.03287737214122899, 0.029778343414363917, 0.03029064795555314, 0.05514276723260991, 0.06836124855908565, 0.09337965529994108, 0.032729124432080425, 0.028619451986742206, 0.008139874789776513, 0.024196960584959015, 0.01943464347277768, 0.07833106748876162, 0.01906444907945115, 0.037903745396761224, 0.050427049573045224, 0.06399671518011019, 0.09052966721355915, 0.05800183549581561, 0.03823578226729296, 0.10382902037235908, 0.08743818427319638, 0.031149151400313713, 0.02199693801230751, 0.08637271253974177, 0.0606610545219155, 0.013414185668807477, 0.05722145979234483, 0.08584675990277901, 0.05322763288859278, 0.03933740401407704, 0.06963417283259332, 0.022393102008209098, 0.0198634007392684, 0.031396524063893594, 0.018252691661473364, 0.03898449052940123, 0.03387257362192031, 0.05160335364053026, 0.016168444126378745, 0.026602240795909893, 0.021637855425069574, 0.0428740939241834, 0.046345389491762035, 0.022191334319359157, 0.058039377036038786, 0.03150514108710922, 0.04794906672032084, 0.026176409446634352, 0.015572354823234491, 0.017034844022418838, 0.0640147938975133, 0.0207745280204108, 0.04007588548120111, 0.028109308950661216, 0.01716238952212734, 0.01746065496263327, 0.07081572388415225, 0.05408421973697841, 0.2871751715429127, 1.8660765420645475, 10.155008286237717, 18.975683972239494, 25.481736660003662, 38.67704160511494, 38.18115681409836, 51.48123733699322, 51.43916219472885, 58.804401978850365, 55.48869609832764, 52.4712286144495, 54.435309022665024, 52.58521869778633, 48.24311949312687, 52.159181758761406, 47.13672526180744, 46.57114461064339, 40.407692939043045, 41.90489999949932, 39.59607549011707, 42.79725171625614, 37.64586813747883, 36.71713337302208, 32.12260611355305, 36.604777202010155, 39.51809227466583, 57.53823772072792, 71.01654767990112, 34.470249339938164, 40.78823111951351, 43.64674933254719, 51.83781400322914, 52.17668741941452, 48.54039654135704, 44.93842162191868, 34.63141389191151, 21.51580587029457, 13.382932227104902, 6.7314812913537025, 2.155532422475517, 0.3732977877371013, 0.08822682008030824, 0.11218381463550031, 0.08054179925238714, 0.007241982784762513, 0.016700102023605723, 0.036460646660998464, 0.049311597904306836, 0.03315519883472007, 0.05256202661257703, 0.03449474199442193, 0.045225080466479994, 0.04048730988870375, 0.08604532151366584, 0.01884721132228151, 0.02757678088528337, 0.06670345392194577, 0.03450204472756013, 0.03777059668209404, 0.035081046080449596, 0.009126507247856352, 0.05139059845532756, 0.0397938396781683, 0.05589579108345788, 0.05260235491732601, 0.040944305874290876, 0.043269350644550286, 0.07302698999410495, 0.1054272057081107, 0.01631661205465207, 0.038790930993855, 0.043385804747231305, 0.008509198087267578, 0.014554024310200475, 0.028228473747731186, 0.03323421529785264, 0.05930836050538346, 0.015079306231200462, 0.10345680362661369, 0.014339225435833214, 0.024190808180719614, 0.030350422384799458, 0.02006062277359888, 0.030399680581467692, 0.029980738218000624, 0.014242813958844636, 0.07584455364849418, 0.023501618306909222, 0.02122347170370631, 0.06798008893383667, 0.04761380892887246, 0.053306534318835475, 0.0654191302601248, 0.03579947471735068, 0.024151129255187698, 0.017137252980319317, 0.039595033158548176, 0.043690096426871605, 0.03239789650251623, 0.006111007705840166, 0.017312184609181713, 0.047535389894619584, 0.028476809347921517, 0.03610742889577523, 0.11943991121370345, 0.18378567328909412, 0.13181798451114446, 0.11364656544174068, 0.1671205839375034, 0.1478440550272353, 0.1454996402026154, 0.1448049009195529, 0.13327612658031285, 0.11805478905444033, 0.15632790134986863, 0.10454184579430148, 0.09401253657415509, 0.1413884834619239, 0.25039029540494084, 0.12903478229418397, 0.11649636056972668, 0.16110639728140086, 0.22168924799188972, 0.1021201437106356, 0.1468511059647426, 0.19956641946919262, 0.10934259131317958, 0.0773291384393815, 0.13618280732771382, 0.08800980867817998, 0.14312864164821804, 0.14538016926962882, 0.1099222457560245, 0.1641181216109544, 0.1384441609843634, 0.09349630607175641, 0.1598977652611211, 0.25942261854652315, 0.10909565651672892, 0.10209208310698159, 0.1550971533288248, 0.09707035569590516, 0.16334725281922147, 0.19424479018198326, 0.20783538435352966, 0.23462415469111875, 0.09074779925867915, 0.10595614920021035, 0.13009329268243164, 0.1963893891661428, 0.13006170687731355, 0.15848778857616708, 0.11161060203448869, 0.10571677688858472, 0.09645087018725462, 0.10057367122499272, 0.13184762588934973, 0.18142228916985914, 0.11917448951862752, 0.1404814751003869, 0.19249440520070493, 0.16642829374177381, 0.258520731003955, 0.09651732951169834, 0.11248843657085672, 0.11702779767801985, 0.09599519893527031, 0.20300318661611527, 0.11175843043019995, 0.13737521599978209, 0.09545942768454552, 0.11822663334896788, 0.11675730711431243, 0.20393145008711144, 0.1697742665419355, 0.342212991672568, 1.8638871470466256, 10.291781947016716, 21.895097717642784, 28.08959372341633, 43.23411427438259, 42.620238214731216, 57.356550469994545, 57.52972237765789, 68.73594045639038, 62.930182591080666, 61.05160899460316, 68.45692902803421, 65.60077428817749, 59.440886825323105, 67.41519212722778, 57.2683572024107, 60.49010932445526, 52.66965016722679, 52.73808069527149, 53.44952791929245, 53.28668385744095, 55.27220271527767, 53.74359793961048, 48.31060387194157, 46.63448341190815, 50.73872298002243, 62.542265206575394, 73.95717948675156, 46.99965141713619, 56.198102831840515, 59.59828577935696, 62.56248392164707, 60.02258621156216, 56.15569710731506, 48.55230130255222, 37.169377505779266, 22.5116678327322, 12.890901379287243, 6.088516842573881, 2.0496121561154723, 0.4550939204636961, 0.19957832351792604, 0.22417587315430865, 0.21506654476979747, 0.10987464440404437, 0.11098636678070761, 0.15128202445339411, 0.15804079303052276, 0.15377586329123005, 0.10940427862806246, 0.1281760580604896, 0.15432704152772203, 0.20282136043533683, 0.1934305948088877, 0.10544503951678053, 0.14843731303699315, 0.127407148538623, 0.14380919106770307, 0.12525428202934563, 0.11444936142652296, 0.10728178822319023, 0.09660335927037522, 0.11813899312983267, 0.24896406568586826, 0.18833941721823066, 0.15378515498014167, 0.17346112261293456, 0.2014045708347112, 0.18703705194639042, 0.17655605653999373, 0.1479739902424626, 0.28801706386730075, 0.15675298869609833, 0.16929280565818772, 0.04763828495924827, 0.15654230781365186, 0.16770898830145597, 0.17497712251497433, 0.15027138259029016, 0.12098450606572442, 0.15351517649833113, 0.11442694856668822, 0.11674874273012392, 0.12691056268522516, 0.14373093901667744, 0.09719701803987846, 0.14982480264734477, 0.08077440317720175, 0.09399612768902443, 0.143004005367402, 0.07223994980449788, 0.19432031112955883, 0.10054157333797775, 0.11815904596005566, 0.11850975526613183, 0.11391301130061038, 0.1911506726173684, 0.14060039684409276, 0.10213471206952818, 0.1381288075936027, 0.1567020031507127, 0.12411652511218563, 0.14216350828064606, 0.1880227873334661], [0.028178827778901905, 0.017861425840237644, 0.047997105939430185, 0.01564506488648476, 0.025414752562937792, 0.014986420883360552, 0.09564032618072815, 0.051578354396042414, 0.01827661293646088, 0.08010776160517707, 0.019348927271494176, 0.024908993764256593, 0.03565808816347271, 0.02543316710216459, 0.01677361175097758, 0.10796553629916161, 0.030347689425980207, 0.04580125794745982, 0.05282058715238236, 0.10173840521019883, 0.0034378831514914054, 0.03178277853294276, 0.08091173018328846, 0.026026369450846687, 0.01098462424124591, 0.06476918701082468, 0.033101430235547014, 0.03348895377712324, 0.03435410500969738, 0.024668808800925035, 0.022528109802806284, 0.052161886560497805, 0.03637028275988996, 0.03634274908108637, 0.04819030553335324, 0.10605711839161813, 0.06571883917786181, 0.04935919183481019, 0.04413661328726448, 0.05055573798017576, 0.030445934935414698, 0.02444428129820153, 0.014273893248173408, 0.012929152271681232, 0.058628137630876154, 0.049925112834898755, 0.06796581001253799, 0.034575135141494684, 0.0750591090763919, 0.07535254684626125, 0.02256734158436302, 0.02648516328918049, 0.012212001984153176, 0.04449146377737634, 0.0361451262870105, 0.023883612848294433, 0.034182000963483006, 0.046390627103392035, 0.017792836551961955, 0.13250266027171165, 0.11076647584559396, 0.01847705960244639, 0.023166588725871406, 0.033511930669192225, 0.0272229508482269, 0.03071862596698338, 0.01172028740256792, 0.013662210494658211, 0.012261276879144134, 0.024249760681414045, 0.03586418999475427, 0.012806140366592444, 0.09000428603030741, 0.041388266035937704, 0.4568816057872027, 1.5494808554649353, 2.773273349739611, 8.6436821334064, 7.969269622117281, 10.357017796486616, 16.996755860745907, 21.98910467326641, 19.36063751578331, 29.87120032310486, 41.91025771200657, 36.50092497467995, 41.24199517071247, 45.522552877664566, 44.89871755242348, 44.21761929988861, 38.10897208750248, 46.46383076906204, 47.332817539572716, 51.88393972814083, 49.66303490102291, 48.23759078979492, 41.94720692932606, 46.353359296917915, 50.32726965844631, 46.154732555150986, 45.054809376597404, 38.69059167802334, 31.348901130259037, 21.925959661602974, 18.852504082024097, 7.886213203892112, 5.961526706814766, 2.276375675573945, 1.1829443299211562, 0.10407497553387657, 0.014945262300898321, 0.030851403607812244, 0.0041938162212318275, 0.03886082646204159, 0.0980248095584102, 0.03114824226940982, 0.0335934481699951, 0.01762139487254899, 0.007971474060468609, 0.03356320936291013, 0.05394509673351422, 0.010503839639568469, 0.053098228308954276, 0.015447098849108443, 0.05170441931113601, 0.05448848241940141, 0.017017205027514137, 0.12434393400326371, 0.027545427001314238, 0.1875595239107497, 0.021340528801374603, 0.013776414962194394, 0.03125123381323647, 0.0627046509180218, 0.023703981569269672, 0.02830050103511894, 0.07869777007726952, 0.03518849793181289, 0.08690082482644357, 0.022322995027934667, 0.04459323077753652, 0.045944277226226404, 0.061909228170407005, 0.05736722501751501, 0.04458098534087185, 0.03244018407713156, 0.033107111376011744, 0.0503188963921275, 0.03449599251325708, 0.05538453668123111, 0.04641702900698874, 0.047465297757298686, 0.03494054268230684, 0.02326724807062419, 0.010927574421657482, 0.014730269540450536, 0.00903959340575966, 0.030510164106090087, 0.04492838466831017, 0.09607068277546205, 0.017237758329429198, 0.009927138016792014, 0.06800927760195918, 0.06516482593724504, 0.0255325147008989, 0.035802343118120916, 0.04897496342891827, 0.052487188440863974, 0.04355257275165059, 0.042638343293219805, 0.09212013421347365, 0.039092988808988594, 0.047930249565979466, 0.05849083659995813, 0.02773594002064783, 0.030445886695815716, 0.03197427860868629, 0.04066397072165273, 0.04583492918754928, 0.04463188553927466, 0.03387409131391905, 0.07174817306804471, 0.027823587661259808, 0.03790267670410685, 0.050159297534264624, 0.05536305521673057, 0.043325579463271424, 0.04327996706706472, 0.05434030892502051, 0.07621136755915359, 0.017020106824929826, 0.06228738580830395, 0.03127389900328126, 0.03402721864404157, 0.026520469109527767, 0.043145423114765435, 0.03090689398959512, 0.03910267383616883, 0.05531968781724572, 0.010491559878573753, 0.045928981562610716, 0.0049380043401470175, 0.052146256930427626, 0.018504587715142407, 0.07018049742328003, 0.015492749280383578, 0.03739550411410164, 0.05745494687289465, 0.04052398682688363, 0.044584068964468315, 0.019301240572531242, 0.09371148436912335, 0.039975832842173986, 0.045863375707995147, 0.06485063771833666, 0.07688491852604784, 0.07491885800845921, 0.02569262378528947, 0.028075188711227383, 0.05019816380809061, 0.048432472030981444, 0.027013216204068158, 0.025617498031351715, 0.07227279726066627, 0.1548253046348691, 0.06425327563192695, 0.03254364688473288, 0.026941157375404146, 0.032466044212924317, 0.08347498209332116, 0.0592617424990749, 0.05202212902077008, 0.027986815621261485, 0.02374273466557497, 0.06483008022769354, 0.044467143598012626, 0.055136009978014044, 0.03692339058034122, 0.016049362820922397, 0.01216052012750879, 0.05031315216911025, 0.02936830682301661, 0.045516818718169816, 0.05319688942108769, 0.026442870148457587, 0.07552466573542915, 0.04122978411032818, 0.017422328601242043, 0.03432438941672444, 0.06356436220812611, 0.7224355218932033, 2.1929715760052204, 5.175544107332826, 11.968612018972635, 12.068691998720169, 15.624810978770256, 23.72344370931387, 28.919028416275978, 29.392264522612095, 39.11269582808018, 47.53294140100479, 45.586609840393066, 51.87713049352169, 54.0904775261879, 53.65319699048996, 50.451826974749565, 46.85580633580685, 53.55114206671715, 54.515127539634705, 56.88123017549515, 55.2192335575819, 52.39750497043133, 46.94126754999161, 50.63547112047672, 55.30758261680603, 53.67227576673031, 49.75508876144886, 47.109826505184174, 38.6225563287735, 29.188226871192455, 24.435067623853683, 12.599782850593328, 9.018304981291294, 3.886007065884769, 1.3974377140402794, 0.24844392406521365, 0.037257216026773676, 0.028050816581526306, 0.07220049723400734, 0.051948838226962835, 0.032856206089491025, 0.022871247347211465, 0.02028884060564451, 0.03672622420708649, 0.0659809508942999, 0.04163832156336866, 0.043998562687193044, 0.020417562409420498, 0.06475750560639426, 0.030308340756164398, 0.001544498140901851, 0.06892646080814302, 0.005478888524521608, 0.044735674891853705, 0.0544087646267144, 0.12201697449199855, 0.011356984778103651, 0.030038265795155894, 0.01904279135487741, 0.016927909819060005, 0.03886756516294554, 0.025135500945907552, 0.019524920171534177, 0.07153405604185537, 0.04318186256568879, 0.041331588217872195, 0.08631865450297482, 0.01403845802997239, 0.03744773275684565, 0.05346522775653284, 0.05750548712967429, 0.03731224998773541, 0.026298364718968514, 0.009933066849043826, 0.05534314339456614, 0.01606089950655587, 0.06249246347579174, 0.04625086214218754, 0.033307008852716535, 0.01720273638056824, 0.049719664093572646, 0.025124576532107312, 0.03353729727678001, 0.03976888125180267, 0.06015001534251496, 0.00989652164207655, 0.05135622217494529, 0.06292160294833593, 0.07632106440723874, 0.0640207904507406, 0.011308671892038547, 0.0386707772850059, 0.06621754757361487, 0.027127801949973218, 0.051702879354706965, 0.05365110977436416, 0.019933591211156454, 0.06514204942504875, 0.013842864082107553, 0.07151112367864698, 0.04390109643281903, 0.041263559251092374, 0.0970291813428048, 0.1010158947610762, 0.17811241443268955, 0.1069643568189349, 0.12375910679111257, 0.19064727384829894, 0.14362536108819768, 0.2093702051206492, 0.11397376350942068, 0.13237809820566326, 0.10448021042975597, 0.12028062352328561, 0.1299008834757842, 0.13455373380566016, 0.1354326741420664, 0.20107150980038568, 0.10122257546754554, 0.08354022429557517, 0.1136456748645287, 0.29979806451592594, 0.08728798100491986, 0.22263251768890768, 0.3498436353402212, 0.1400699096848257, 0.09461631081649102, 0.0896227330667898, 0.16226343519520015, 0.09181645480566658, 0.12992136675165966, 0.11365807615220547, 0.12322853799560107, 0.15093394235009328, 0.22160051681566983, 0.14303058909717947, 0.11432882922235876, 0.20802899583941326, 0.15195142681477591, 0.14252410299377516, 0.18596858193632215, 0.1007626591308508, 0.13803180889226496, 0.14022253977600485, 0.10905080853262916, 0.11390171581297182, 0.15238285210216418, 0.177500142599456, 0.1425908665987663, 0.18402507528662682, 0.2277166151907295, 0.12112797805457376, 0.0864138720498886, 0.22677100030705333, 0.13938128569861874, 0.15852779033593833, 0.14027842349605635, 0.13111797597957775, 0.13608129636850208, 0.08553434541681781, 0.07882372738095, 0.23638911545276642, 0.24683891097083688, 0.17629557754844427, 0.14161988510750234, 0.09430443067685701, 0.08973691990831867, 0.07972603052621707, 0.12447374305338599, 0.10114402655744925, 0.11712106337654404, 0.14417306607356295, 0.11976748035522178, 0.06745988794136792, 0.1908928802004084, 0.1516273754532449, 0.6612890248652548, 2.863360340707004, 5.027298862114549, 11.662333253771067, 11.623205803334713, 15.860992055386305, 23.206614442169666, 31.293642595410347, 33.86875681579113, 43.33704315125942, 51.91889405250549, 53.02781514823437, 57.70454339683056, 60.868063643574715, 59.62185591459274, 60.09852133691311, 56.14142507314682, 60.86155839264393, 62.544556483626366, 67.52896562218666, 64.9777141213417, 61.95228226482868, 58.583136051893234, 61.51409737765789, 63.598395735025406, 61.119496151804924, 60.67642852663994, 53.69843736290932, 43.713333159685135, 31.732716634869576, 26.49963553994894, 12.908842116594315, 8.39419512078166, 3.2431188505142927, 1.3898724387399852, 0.25759093870874494, 0.10486575614777394, 0.16043067182181403, 0.1759993121959269, 0.2036877436330542, 0.1874617236899212, 0.19357690180186182, 0.11622874953900464, 0.11125520977657288, 0.13528409617720172, 0.1378531739464961, 0.23486844002036378, 0.13118341856170446, 0.1713804670725949, 0.13308373221661896, 0.14103303925367072, 0.2041210836614482, 0.16396994440583512, 0.25059310952201486, 0.1171861423063092, 0.2956861210986972, 0.1215195500117261, 0.09234683806425892, 0.11737562745111063, 0.07954434535349719, 0.1152387319598347, 0.25169751432258636, 0.1967000076547265, 0.07860670855734497, 0.11271670635323972, 0.163565844995901, 0.19154412962961942, 0.09548158821417019, 0.22967318363953382, 0.15860418701777235, 0.12820253788959235, 0.1616031612502411, 0.072588722105138, 0.11416908935643733, 0.17990888678468764, 0.17161268508061767, 0.1773675950244069, 0.15868616465013474, 0.14208432112354785, 0.1359130218042992, 0.09496466009295546, 0.09815364639507607, 0.09096387555473484, 0.14681206899695098, 0.10834931570570916, 0.16953315760474652, 0.1464008301263675, 0.09402228097314946, 0.23334917466854677, 0.12447685265215114, 0.16835838236147538, 0.13181112706661224, 0.17852561257313937, 0.113822929415619, 0.10547574958764017, 0.22049168881494552, 0.214372948394157, 0.1749895460670814, 0.1415487873600796, 0.19954436284024268, 0.11655453010462224, 0.15794833627296612], [0.050402447377564386, 0.04618717102857772, 0.04046724221552722, 0.04901750333374366, 0.02317844639037503, 0.04516611683357041, 0.013152148167137057, 0.07476980506908149, 0.03870535394526087, 0.03687689131766092, 0.09700685754069127, 0.08484647099976428, 0.0670840495149605, 0.021482529482454993, 0.008538850597687997, 0.03033574641449377, 0.1172716377186589, 0.020630113504012115, 0.02497669618605869, 0.036544720860547386, 0.007032002768028178, 0.12806057988200337, 0.03117818050668575, 0.037588265840895474, 0.07253956224303693, 0.00917005461815279, 0.022041730335331522, 0.055532669357489794, 0.023294507154787425, 0.05835969168401789, 0.080959635815816, 0.036924715313944034, 0.0013770341411145637, 0.05530831440410111, 0.051820446678902954, 0.07804419030435383, 0.10513187546166591, 0.02273279969813302, 0.05672714120009914, 0.0729560035688337, 0.05688466946594417, 0.055579721520189196, 0.019341422303114086, 0.09788245821255259, 0.0330175527051324, 0.039105672112782486, 0.08837638510158285, 0.015369736447610194, 0.07348458340857178, 0.028846901695942506, 0.038272359015536495, 0.05248636836768128, 0.057002908433787525, 0.012043127208016813, 0.01314671193540562, 0.02325125107745407, 0.02902242889831541, 0.03402302179893013, 0.01593102737388108, 0.07334226174862124, 0.07233527867356315, 0.004156187478656648, 0.06283463808358647, 0.018880500356317498, 0.01998101444769418, 0.06838131623226218, 0.0304821647296194, 0.03911333478754386, 0.05089144477096852, 0.03363949101185426, 0.057774055530899204, 0.04602972068823874, 0.04959093115758151, 0.04117397460504435, 0.017945197614608333, 0.04152957466430962, 0.059216935333097354, 0.09796364174690098, 0.061659699567826465, 0.09322903642896563, 0.3796878276625648, 0.5990422493778169, 2.1369027346372604, 2.9415333084762096, 5.066431537270546, 5.936374431475997, 7.754415376111865, 10.435950960963964, 10.461121760308743, 13.281911797821522, 11.24564191326499, 14.447951428592205, 14.327762927860022, 17.132475078105927, 21.055707558989525, 19.95928969234228, 24.878781214356422, 24.194749519228935, 26.131026819348335, 19.676303677260876, 15.8567856810987, 9.104312416166067, 3.656257619149983, 0.7811019395012408, 0.8284220471978188, 0.20549956359900534, 0.024877266951079946, 0.021125844032212626, 0.029083630106470082, 0.07530162067268975, 0.10969815426506102, 0.03100639187323395, 0.03319694093079306, 0.01587710477906512, 0.05901793214434292, 0.019779610411205795, 0.017771713173715398, 0.03547216903825756, 0.016693302095518447, 0.02517111846827902, 0.18222447659354657, 0.03454578691162169, 0.08075826888671145, 0.11668430204736069, 0.03556095587555319, 0.04520355447311886, 0.00174027403090804, 0.05948411962890532, 0.040279445456690155, 0.011285925065749325, 0.06591553799808025, 0.08329720061738044, 0.03893365341355093, 0.0164192529337015, 0.03239344361645635, 0.08359161060070619, 0.03788332891417667, 0.07605297840200365, 0.027852926614286844, 0.014842746659269324, 0.04129590204684064, 0.021591229997284245, 0.04428859770996496, 0.006574193203050527, 0.036121540833846666, 0.09107110847253352, 0.05098525223729666, 0.016254201145784464, 0.04050331059261225, 0.0661925743042957, 0.08381021019886248, 0.05988642304146197, 0.02250684170576278, 0.03224633139325306, 0.008780071784713073, 0.048991179355653, 0.02873419172829017, 0.03282523626694456, 0.042412270267959684, 0.020558370088110678, 0.11437743989517912, 0.0686146474617999, 0.014001155832374934, 0.033807212676038034, 0.05995985113258939, 0.013920535402576206, 0.03879450814565644, 0.015436893390869955, 0.027080278523499146, 0.03680255038489122, 0.053937723496346734, 0.004607281071002944, 0.07001829362707213, 0.060864269398734905, 0.006966373721297714, 0.06929944196599536, 0.05259263649350032, 0.059826735814567655, 0.05217479993007146, 0.015113599019969115, 0.0289443939254852, 0.0684882522909902, 0.025476701484876685, 0.05855850191437639, 0.021556295250775293, 0.011880177553393878, 0.025155240218737163, 0.018852200410037767, 0.04860516979533713, 0.02107427590090083, 0.0077262355353013845, 0.031066550363902934, 0.03635749555542134, 0.06251185579458252, 0.11202283538295887, 0.014237100349419052, 0.025952099022106268, 0.027685071363521274, 0.04204711505735759, 0.007102876015778747, 0.05518748534086626, 0.03478065067611169, 0.031083796020539012, 0.0457121148792794, 0.03285525614046492, 0.06675135955447331, 0.02390290126641048, 0.0335817185259657, 0.016791304551588837, 0.03422852991207037, 0.028890747780678794, 0.051344537059776485, 0.02377536875428632, 0.020751951888087206, 0.044029892451362684, 0.10229129780782387, 0.034869671289925463, 0.08488087696605362, 0.051661634497577325, 0.05627373720926698, 0.04307659633923322, 0.031254914865712635, 0.021722274723288137, 0.05709834491426591, 0.042057694372488186, 0.013414863806247013, 0.0426724932185607, 0.023609804884472396, 0.0486273748538224, 0.029630245990119874, 0.03697988657222595, 0.08044553527724929, 0.05118299748573918, 0.0512658768275287, 0.016215772739087697, 0.019176235073246062, 0.028360893302306067, 0.022329132589220535, 0.029726586035394575, 0.005461720793391578, 0.019066712629864924, 0.07852959941374138, 0.05425907344033476, 0.03954527957830578, 0.016750881623011082, 0.029937797553429846, 0.009715637061162852, 0.1732940206420608, 0.046032997270231135, 0.029818881375831552, 0.05471891556226183, 0.0541770883864956, 0.06467668572440743, 0.06076573074096814, 0.1977447883109562, 0.2740335470298305, 0.9955088188871741, 1.6420013783499599, 3.0422564037144184, 5.058693727478385, 8.952632155269384, 9.922420866787434, 12.18422194942832, 16.302379220724106, 16.16527497768402, 20.015099197626114, 16.44174814224243, 22.22939807921648, 21.78037617355585, 24.885105974972248, 28.36541522294283, 26.999291628599167, 31.660657301545143, 31.54800094664097, 33.63260708749294, 25.643879659473896, 20.572641380131245, 12.008060552179813, 5.87525281123817, 1.974366931244731, 1.4389191381633282, 0.3277936560334638, 0.06889509764732793, 0.03234758260077797, 0.03364498290466145, 0.0550310702965362, 0.03480701176158618, 0.02387561249634018, 0.018758624864858575, 0.03847538093395997, 0.018582457560114563, 0.051106359605910257, 0.02572392942965962, 0.057057831072597764, 0.034284168723388575, 0.04369482019683346, 0.1099343724490609, 0.04635334531485569, 0.06498706672573462, 0.05496398014656734, 0.03653961859527044, 0.02563334102887893, 0.029778115203953348, 0.024302861347678117, 0.023223016069096047, 0.04172687833488453, 0.018528765031078365, 0.035846237442456186, 0.05428750882856548, 0.02766219651675783, 0.10167415748583153, 0.02902483716752613, 0.01914921718707774, 0.06328298433800228, 0.03908838007191662, 0.043949161627097055, 0.06060500010789838, 0.09747138261445798, 0.056071067810989916, 0.06776252834242769, 0.038654305317322724, 0.028184980183141306, 0.03474011828075163, 0.00816870908238343, 0.04337256483267993, 0.03797319186560344, 0.03308009348984342, 0.026709392077464145, 0.014274378427217016, 0.0231258670828538, 0.05398057139245793, 0.06791552950744517, 0.05278811448079068, 0.015212385369522963, 0.05022852878028061, 0.006490193682111567, 0.07018361444352195, 0.06335252357530408, 0.03504516695102211, 0.04284099042706657, 0.06683934116153978, 0.005678039215126773, 0.04559580178465694, 0.023455824084521737, 0.01641464048589114, 0.09609991597244516, 0.030902081161912065, 0.021928124224359635, 0.007967220626596827, 0.007395939001071383, 0.02321929976460524, 0.0033484847381259897, 0.21120957360835746, 0.16722533066058531, 0.10260061011649668, 0.14025026641320437, 0.11631103145191446, 0.16563609562581405, 0.2116221928736195, 0.1968831697013229, 0.21892882970860228, 0.1097657268110197, 0.19274152553407475, 0.18224150146124884, 0.21264702460030094, 0.0626883607765194, 0.1434706975123845, 0.21290423814207315, 0.13648064603330567, 0.23144246370065957, 0.17424306424800307, 0.13429761864244938, 0.20939457725035027, 0.2657972218003124, 0.12044138013152406, 0.09834215190494433, 0.1570987404556945, 0.1121952362882439, 0.09521273037535138, 0.13727962737903, 0.1248700128053315, 0.13308729452546686, 0.131314808386378, 0.13768768985755742, 0.10441770675242878, 0.1444672979414463, 0.13842140673659742, 0.15846438123844564, 0.19479167880490422, 0.07551185626653023, 0.1651035007671453, 0.33252659894060344, 0.15604518761392683, 0.2644208644051105, 0.19213707593735307, 0.21964271640172228, 0.13028966495767236, 0.11077068382292055, 0.2192830716376193, 0.10127554254722781, 0.08637674240162596, 0.11469983626739122, 0.1818660637945868, 0.09501059903413989, 0.31638369953725487, 0.17495856882305816, 0.14186112763127312, 0.151080739160534, 0.13049169239820912, 0.2179964102106169, 0.11058453092118725, 0.15477354725589976, 0.15775493258843198, 0.16350926365703344, 0.13529635645681992, 0.15265199937857687, 0.08262667019153014, 0.167698405275587, 0.07853579634684138, 0.14646596100647002, 0.12995301192859188, 0.09411467835889198, 0.2000523777678609, 0.23327536066062748, 0.1713234552880749, 0.20785601605894044, 0.28263114974834025, 0.25026282412, 0.21355772885726765, 0.15133146633161232, 0.25209595856722444, 0.2609515911899507, 0.8666705572977662, 1.3639554544351995, 2.8599713975563645, 5.1297518145293, 8.365366067737341, 10.579101629555225, 13.145357575267553, 16.550507806241512, 16.578852385282516, 19.15459357202053, 17.495596893131733, 21.523164175450802, 23.06389980018139, 26.064636781811714, 29.00843381881714, 28.45240205526352, 33.96401770412922, 32.94636771082878, 36.88777841627598, 27.91412103921175, 22.33384497463703, 13.116774559020996, 6.345690842717886, 2.2550407703965902, 1.0729750245809555, 0.38753832515794784, 0.12667273404076695, 0.1889370835851878, 0.1297188049647957, 0.19784441421506926, 0.14931264653569087, 0.10602027818094939, 0.08985676191514358, 0.1565331348683685, 0.16306817560689524, 0.148514763568528, 0.16679286636644974, 0.10577676468528807, 0.09460468878387474, 0.15149264596402645, 0.41473592980764806, 0.10748260596301407, 0.1280188118107617, 0.1552110878401436, 0.20010089938296005, 0.0953087568632327, 0.11154830615851097, 0.10933502140687779, 0.07046449507470243, 0.14895809290464967, 0.13776151870843023, 0.16024020704207942, 0.14957938925363123, 0.121547677408671, 0.1818963879486546, 0.1978606524062343, 0.15128537896089256, 0.186722514918074, 0.09517983096884564, 0.11089821447967552, 0.1770684204529971, 0.17628823028644547, 0.19391385169001296, 0.10986426917952485, 0.0965383842412848, 0.24841121019562706, 0.07989996767719276, 0.08069995092228055, 0.16823065874632448, 0.12334988656220958, 0.1762637690990232, 0.1544442563317716, 0.0864967551024165, 0.10519126954022795, 0.16768332483479753, 0.13993080152431503, 0.11862244296935387, 0.16733917611418292, 0.14661664667073637, 0.06483458506409079, 0.298858861788176, 0.18294501292984933, 0.20414443162735552, 0.105232866917504, 0.12883973104180768, 0.10622879199218005, 0.1613304961938411, 0.15038545068819076, 0.16067886084783822, 0.27329083532094955, 0.10957268677884713, 0.1336408921633847, 0.14915038336766884, 0.14292556035798043, 0.11751488404115662, 0.2003991833771579], [0.044426151071093045, 0.06779941308195703, 0.0441197442705743, 0.05684877549356315, 0.007398414991257596, 0.10032568257884122, 0.021208712241786998, 0.0765380312805064, 0.022462878732767422, 0.03835330135188997, 0.041382885465282016, 0.0031838077347856597, 0.02808084202115424, 0.05889790831133723, 0.04054431425174698, 0.04374172764073592, 0.027421532868174836, 0.0272124828552478, 0.10624513408401981, 0.03257778567785863, 0.05542308383155614, 0.03252646616601851, 0.040192506567109376, 0.014392349294212181, 0.02277079394843895, 0.039985002076718956, 0.05269579130981583, 0.06605663511436433, 0.015831664932193235, 0.03761680512980092, 0.04300953216443304, 0.11676259120577015, 0.07852580703911372, 0.03937441491871141, 0.010264964566886192, 0.04861428707954474, 0.010156434746022569, 0.013888552548451116, 0.01405205139235477, 0.02617649850435555, 0.06284882052568719, 0.08500244817696512, 0.052439483188209124, 0.08483582860208116, 0.014855786193948006, 0.0319696067890618, 0.032995785513776354, 0.06959435660974123, 0.024627324601169676, 0.0326445195969427, 0.094649425445823, 0.07624217410921119, 0.03203532025509048, 0.02004608410061337, 0.048085187736433, 0.040674980482435785, 0.06890384014695883, 0.042065739253303036, 0.07214975659735501, 0.049078340889536776, 0.03566585473890882, 0.036997219431214035, 0.020754349025082774, 0.021496073677553795, 0.07842428865842521, 0.05443925205327105, 0.03820412224740721, 0.06407864828361198, 0.03721642759046517, 0.06393180694431067, 0.025928303912223782, 0.034863715554820374, 0.03078944169828901, 0.029158941397327, 0.038168447208590806, 0.02592384731542552, 0.014937235973775387, 0.039484991211793385, 0.03729083531652577, 0.03298300944152288, 0.03070223563554464, 0.054584393874392845, 0.08767990177148022, 0.04705710169218946, 0.017301781554124318, 0.14948826836189255, 0.28657094459049404, 0.1253202886437066, 0.14801937999436632, 0.2681649994337931, 0.3607396990992129, 0.539993061684072, 0.5030703241936862, 0.6532009213697165, 0.4666110430844128, 0.7195816375315189, 2.288546422496438, 1.5183583879843354, 0.9267588111106306, 0.9842275211121887, 0.48628689197357744, 0.23322311346419156, 0.05823135950777214, 0.032739280723035336, 0.06263022834900767, 0.014442839456023648, 0.04703729005996138, 0.05225975357461721, 0.07484741145162843, 0.05451472847198602, 0.06412943344912492, 0.02543836770200869, 0.01693320689810207, 0.04890501229965594, 0.10181074976571836, 0.06190386615344323, 0.056859313990571536, 0.07212564421934076, 0.0035405546441324987, 0.03420669221668504, 0.0451678237732267, 0.02501041195500875, 0.04048431903356686, 0.03309356718091294, 0.031002310061012395, 0.049678293071337976, 0.024702502305444796, 0.06798857910325751, 0.01632339713978581, 0.04662844832637347, 0.05520435435755644, 0.026172466787102167, 0.03976872169005219, 0.043949506725766696, 0.029314525236259215, 0.053072431255714037, 0.03977282205596566, 0.0720432584057562, 0.03900242823874578, 0.013227022518549347, 0.017425898331566714, 0.012708732556347968, 0.0064962231681420235, 0.015394126203318592, 0.036339899234008044, 0.032706136407796293, 0.04515325912507251, 0.04736574977869168, 0.04362719570053741, 0.05211748015426565, 0.007139411482057767, 0.05683357630914543, 0.051694856738322414, 0.03304327554360498, 0.036384335326147266, 0.09547229652525857, 0.030758304892515298, 0.05569144072069321, 0.04848296033742372, 0.032916338604991324, 0.032167214740184136, 0.015479247758776182, 0.058436366671230644, 0.048016969521995634, 0.03296787333965767, 0.04801712908374611, 0.03171602606016677, 0.03643143572844565, 0.0036628248653869377, 0.07647661113878712, 0.04614162171492353, 0.05231250914221164, 0.03668846002256032, 0.010334664293623064, 0.010310672514606267, 0.044472179069998674, 0.12035538005875424, 0.016688056966813747, 0.06629104987950996, 0.029940409913251642, 0.012390217616484733, 0.03245420324674342, 0.0358214682637481, 0.04591319608152844, 0.020953259445377626, 0.0226579986338038, 0.04093227566045243, 0.031145782049861737, 0.01641872600885108, 0.09193106467137113, 0.035473115276545286, 0.04195839872409124, 0.05277061463857535, 0.09113842868828215, 0.08596933301305398, 0.050122038010158576, 0.048997342892107554, 0.025067750284506474, 0.039885769510874525, 0.05632180240354501, 0.032859809216461144, 0.04489669867325574, 0.018386376577836927, 0.02988750406075269, 0.009442829141335096, 0.05191523378016427, 0.028074895562895108, 0.04601301123329904, 0.010785386348288739, 0.04589426389429718, 0.03449543961323798, 0.048503209836781025, 0.028341094657662325, 0.08020802575629205, 0.01403912410751218, 0.03431420343986247, 0.0315921022411203, 0.03227913432056084, 0.05236257813521661, 0.038608347822446376, 0.01051346436724998, 0.014949527794669848, 0.027109769616799895, 0.017138407019956503, 0.04288730044208933, 0.01812350416003028, 0.03552208589098882, 0.03594966314267367, 0.010211747940047644, 0.03552589310857002, 0.03729809723154176, 0.04447593062650412, 0.10433140239911154, 0.028677450827672146, 0.05919461895246059, 0.03065806671656901, 0.023201395451906137, 0.06147425541712437, 0.06360610059346072, 0.014794250091654249, 0.09987749217543751, 0.04888888171990402, 0.074238790984964, 0.02856719736882951, 0.052416843973333016, 0.05025237027439289, 0.033210462861461565, 0.06668041023658589, 0.04402276412292849, 0.019083889637840912, 0.0466893267002888, 0.044637592654908076, 0.054984003290883265, 0.0035117147854180075, 0.04185816796962172, 0.051775279571302235, 0.05398061592131853, 0.06361856125295162, 0.02348077694477979, 0.06846534961368889, 0.1200764141685795, 0.20245821273420006, 0.5999216053169221, 0.366769916145131, 0.49057107302360237, 0.5555557203479111, 0.8650983916595578, 0.7914317445829511, 0.8314294076990336, 1.0218332125805318, 1.248795271385461, 1.722121147904545, 3.5858072619885206, 2.1815527137368917, 1.6920695104636252, 1.6776149673387408, 0.7429166603833437, 0.31656157749239355, 0.1191742297669407, 0.07333026122068986, 0.0824126199586317, 0.03459157371253241, 0.014578053196601104, 0.027682379222824238, 0.05821483187901322, 0.05366587851312943, 0.02649615449627163, 0.04858065294683911, 0.025838116271188483, 0.007935178400657605, 0.07835425218218006, 0.006590356715605594, 0.02993966034409823, 0.053503904782701284, 0.024635035515530035, 0.030895962154318113, 0.1056307990802452, 0.05621397205686662, 0.022497397876577452, 0.00534861516825913, 0.013914562969148392, 0.05746451315644663, 0.05796218625619076, 0.02210969993029721, 0.06495512468973175, 0.048019459427450784, 0.07208259965409525, 0.07194631907623261, 0.05638945287500974, 0.055315951103693806, 0.05540992926398758, 0.10295258849509992, 0.046369869232876226, 0.1086379963089712, 0.022054743894841522, 0.053691226567025296, 0.043432040547486395, 0.034393301539239474, 0.028856699900643434, 0.048391965610790066, 0.07668974853004329, 0.023417150769091677, 0.03998616724857129, 0.03921616676962003, 0.08801990930805914, 0.03261054036556743, 0.061700829392066225, 0.07426110736560076, 0.09256020552129485, 0.10176920433877967, 0.05159274092875421, 0.03063745727558853, 0.037890479507041164, 0.041876502727973275, 0.05407834192737937, 0.0312618947646115, 0.004795902541445685, 0.10355608072131872, 0.061014246311970055, 0.04371101385913789, 0.015510291796090314, 0.07845790794817731, 0.047821068510529585, 0.06804744625696912, 0.03256607087678276, 0.04451270775462035, 0.01837539835833013, 0.029537696464103647, 0.05666006218234543, 0.02461552074237261, 0.02728302584728226, 0.08278396839159541, 0.17561228218255565, 0.3327801759587601, 0.139290135120973, 0.15258487954270095, 0.11995538472547196, 0.19266505463747308, 0.08437211989075877, 0.2101796804345213, 0.10250553357764147, 0.13021012156968936, 0.17055239353794605, 0.16148667375091463, 0.15091059438418597, 0.14242633245885372, 0.15705761063145474, 0.17016926722135395, 0.09576025724527426, 0.17837700492236763, 0.2216573801706545, 0.10578141795122065, 0.10389652612502687, 0.13707538833841681, 0.1405701765906997, 0.1115233996824827, 0.07767443748889491, 0.15857461985433474, 0.09522282358375378, 0.18492424656869844, 0.12267689962754957, 0.13122014002874494, 0.08099590457277372, 0.17181048227939755, 0.14923452807124704, 0.18124592519598082, 0.12057788335368969, 0.20598424540366977, 0.13763392867986113, 0.169500473421067, 0.061664953973377123, 0.13841123931342736, 0.11754361257771961, 0.13314115960383788, 0.12655069527681917, 0.19813860155409202, 0.13767507334705442, 0.1343710022047162, 0.10732113689300604, 0.12270124207134359, 0.15575784287648275, 0.06708829459967092, 0.25087420537602156, 0.1933148197713308, 0.09696819164673798, 0.05687729993951507, 0.10195195078267716, 0.09669900726294145, 0.1410960772773251, 0.16158998070750386, 0.1563857146538794, 0.1254711375804618, 0.11333803238812834, 0.23546567594166845, 0.09530236697173677, 0.08580183770391159, 0.15760285168653354, 0.18611655134009197, 0.20689920958830044, 0.23037875827867538, 0.15887554589426145, 0.11965120807872154, 0.15401450829813257, 0.22737757244613022, 0.1363879517884925, 0.1868757387273945, 0.15309973707189783, 0.1503208393114619, 0.10460395613336004, 0.11450874808360822, 0.16099480795674026, 0.06962174185900949, 0.18487453751731664, 0.21482672716956586, 0.10487118866876699, 0.21672049508197233, 0.11912896618014202, 0.20668377896072343, 0.48851318657398224, 0.33640651730820537, 0.46900717075914145, 0.4956486396258697, 0.7593401509802788, 0.6416155805345625, 1.0819265129975975, 1.0194217669777572, 1.1407978227362037, 1.5118943410925567, 3.1600724067538977, 2.2490658285096288, 1.6573557606898248, 1.6278014215640724, 0.8283017005305737, 0.3854589757975191, 0.1645867433398962, 0.14902228867867962, 0.24780377716524526, 0.06282560614636168, 0.09827663510804996, 0.12396174279274419, 0.14930718432879075, 0.3613710589706898, 0.20999277796363458, 0.10248266058624722, 0.10999390011420473, 0.10326320698368363, 0.21724048827309161, 0.16556397371459752, 0.12351015335298143, 0.1341096029500477, 0.129077841702383, 0.10863723189686425, 0.1399854978080839, 0.10964502391288988, 0.1105183684558142, 0.0771762931253761, 0.1552615687251091, 0.16040624032029882, 0.15545945498161018, 0.1418064461904578, 0.12381801847368479, 0.12050162025843747, 0.17776903754565865, 0.09036350777023472, 0.13626346393721178, 0.1697072951355949, 0.12643260473851115, 0.2180341409984976, 0.14156981982523575, 0.17685459286440164, 0.1197070992202498, 0.11738914196030237, 0.11644882601103745, 0.09742737325723283, 0.209691911295522, 0.15112532739294693, 0.16064846247900277, 0.11956468850257806, 0.10009947596699931, 0.13055624440312386, 0.18587190977996215, 0.1633387032779865, 0.10162318678339943, 0.13112156797433272, 0.24238411016995087, 0.1696699799504131, 0.16366573807317764, 0.1879164672573097, 0.14354405138874426, 0.15982254117261618, 0.10588750054012053, 0.11448391582234763, 0.16715653357096016, 0.16476567514473572, 0.15117147413548082, 0.1393173125688918, 0.14370625518495217, 0.20452577678952366, 0.13160470611182973, 0.2389272753498517, 0.09090807347092777, 0.16467401990666986, 0.0966055337630678, 0.11201280154637061, 0.15786140109412372, 0.08396643970627338, 0.1320296895573847, 0.2843560790643096], [0.04654434815165587, 0.08683242107508704, 0.043568050241447054, 0.03943740841350518, 0.034641189995454624, 0.05304736892867368, 0.03259639874158893, 0.023539790672657546, 0.04484414719627239, 0.03566139072063379, 0.020542044694593642, 0.024950804508989677, 0.011750202447728952, 0.08998112360131927, 0.0646793500345666, 0.05036085371102672, 0.07625692058354616, 0.02409508597338572, 0.06479397474322468, 0.010777465777209727, 0.08493854926200584, 0.010983821794070536, 0.06641731888521463, 0.02246679170639254, 0.05093884945381433, 0.012518406929302728, 0.01346716666375869, 0.03461497362877708, 0.06280051413341425, 0.06975302036153153, 0.0591073498071637, 0.04122512342291884, 0.08385523629840463, 0.034024862325168215, 0.04339048027759418, 0.006192575765453512, 0.027173544222023338, 0.05663877367624082, 0.03156269835017156, 0.04416234354721382, 0.030394348250410985, 0.034592200827319175, 0.007945341185404686, 0.03924962649762165, 0.08436109899776056, 0.013456565084197791, 0.09482863926677965, 0.06032557779690251, 0.05536426120670512, 0.047423351570614614, 0.014878186993882991, 0.014352063662954606, 0.0338222485879669, 0.007123375062292325, 0.016016862318792846, 0.042090697679668665, 0.06058798266167287, 0.017313273710897192, 0.049209793796762824, 0.04119389755942393, 0.0836641332716681, 0.034302830026717857, 0.06559056637343019, 0.02812039849231951, 0.0038727847049813136, 0.02891844658734044, 0.07230041999719106, 0.05841620251885615, 0.05616042610199656, 0.08919157495256513, 0.04697132797446102, 0.010528286911721807, 0.10748951535788365, 0.08017500018468127, 0.039345170589513145, 0.04029025112686213, 0.0218912821583217, 0.05217184247158002, 0.03524166539136786, 0.019759539027290884, 0.03774896678805817, 0.05890063570404891, 0.007822274546924746, 0.018862686956708785, 0.023051505741022993, 0.03322245225717779, 0.02830561814334942, 0.04887810573563911, 0.03740171217941679, 0.052266187994973734, 0.04042066873807926, 0.03198604907083791, 0.06023864261806011, 0.0708310714981053, 0.0864456953422632, 0.08987158260424621, 0.023575513951072935, 0.05258449884422589, 0.06360392610076815, 0.0655370055756066, 0.08783909244812094, 0.014231951699912315, 0.07167493051383644, 0.029392563919827808, 0.03523270024743397, 0.0774543164880015, 0.024112557985063177, 0.07851557282265276, 0.023900346423033625, 0.025983593914133962, 0.015377376857941272, 0.08845875607221387, 0.04645479319151491, 0.033829406602308154, 0.04210998238704633, 0.013585897304437822, 0.012499663989729015, 0.04033158504171297, 0.02528842418541899, 0.04713113092293497, 0.02143468507711077, 0.048572418818366714, 0.00965551846093149, 0.021426063176477328, 0.004599924532158184, 0.023000522051006556, 0.03324461278680246, 0.009578246044839034, 0.020173920893284958, 0.061036829865770414, 0.10405273336800747, 0.03042240143258823, 0.0172485361690633, 0.006273809394770069, 0.05049409890489187, 0.007326550976358703, 0.034903286868939176, 0.03204699794878252, 0.04146310420765076, 0.018505053412809502, 0.011302676266495837, 0.05150029159267433, 0.02724850670347223, 0.051857387079508044, 0.00919806234378484, 0.029345773364184424, 0.020808076806133613, 0.018283917524968274, 0.05909670740948059, 0.008188099545805017, 0.022856016621517483, 0.014369215623446507, 0.05224977168836631, 0.030545950467057992, 0.02735274134465726, 0.00785919175541494, 0.030447615899902303, 0.031229533415171318, 0.032656241819495335, 0.021968176079099067, 0.024301056073454674, 0.033962607267312706, 0.03736655293323565, 0.04124357692489866, 0.06058352977561299, 0.026543349522398785, 0.014538636805809801, 0.04877863197179977, 0.0424364345963113, 0.009080891140911262, 0.04559616914775688, 0.0657301717728842, 0.01752709944412345, 0.14614314161008224, 0.04575848797685467, 0.030984203513071407, 0.006027628342053504, 0.05735933227697387, 0.0445053048315458, 0.012976731359231053, 0.03127386560663581, 0.005936835850661737, 0.04100267578905914, 0.030723859963472933, 0.09222883658367209, 0.009449284898437327, 0.10475623741513118, 0.03343455806316342, 0.027403595158830285, 0.022494236327474937, 0.04937906654959079, 0.0588960789173143, 0.042389927912154235, 0.0527799211704405, 0.07047875173157081, 0.016243770260189194, 0.016772665512689855, 0.024551421447540633, 0.032754646890680306, 0.02194271484768251, 0.060499110477394424, 0.05159330496098846, 0.04363990497949999, 0.043639956929837354, 0.013680218708032044, 0.06700230936985463, 0.06590590492123738, 0.010363707315264037, 0.02402919068117626, 0.04002543799288105, 0.023142890095186885, 0.08434886098257266, 0.038054182441555895, 0.0494604430423351, 0.020635987602872774, 0.04036416532471776, 0.03158812061883509, 0.032817566170706414, 0.00966903204243863, 0.05654898122884333, 0.04886325907136779, 0.032915548217715696, 0.04195653964416124, 0.04832401085877791, 0.009482238110649632, 0.06051879965525586, 0.027946570808126125, 0.06439684409997426, 0.013382927336351713, 0.029147712702979334, 0.05920837094890885, 0.07877768453909084, 0.023650908733543474, 0.09101599658606574, 0.024062759875960182, 0.020785784545296337, 0.042411995673319325, 0.041548020744812675, 0.06638085716986097, 0.03958794935897458, 0.030913131740817335, 0.025053797908185516, 0.03906919926521368, 0.028379857030813582, 0.02760019193374319, 0.045849386224290356, 0.06722506499500014, 0.023148394975578412, 0.05851835914654657, 0.03826641070190817, 0.0200626989317243, 0.06240112736122683, 0.02159890009352239, 0.06455385286244564, 0.02320132865861524, 0.06579709122888744, 0.02569016913184896, 0.03194114913640078, 0.032375531882280484, 0.033296989859081805, 0.0738927349448204, 0.032836008540471084, 0.004655111097235931, 0.03451906217378564, 0.033509830391267315, 0.09976737972465344, 0.06088471556722652, 0.02879088067857083, 0.041081989111262374, 0.03395643630938139, 0.05580202072451357, 0.0893949308374431, 0.0700922634860035, 0.04349225098849274, 0.027555395899980795, 0.05405754694947973, 0.016655760555295274, 0.05042077100370079, 0.031042668051668443, 0.012755450752592878, 0.014734014603163814, 0.08603774418588728, 0.06023778914823197, 0.04709571192506701, 0.06585463735973462, 0.046956429359852336, 0.022156683444336522, 0.028340788521745708, 0.04858693522692192, 0.023199486277007964, 0.07086034180247225, 0.05012633133446798, 0.01958596367330756, 0.07748110801912844, 0.020545478982967325, 0.014805310875090072, 0.02787217978038825, 0.01868732117145555, 0.03727448951394763, 0.056234826406580396, 0.03194202858139761, 0.03330299012304749, 0.04706748433818575, 0.026928488914563786, 0.023317643608606886, 0.038500302252941765, 0.01985219059861265, 0.06861290341475978, 0.04966448912455235, 0.08048600459005684, 0.017604922904865816, 0.022897717899468262, 0.05136579587997403, 0.02769839105894789, 0.06211384570633527, 0.05777342841611244, 0.04872323064773809, 0.0386602202343056, 0.019052001407544594, 0.03538692224537954, 0.03709781012730673, 0.012037190954288235, 0.045658175586140715, 0.034038862941088155, 0.008782928125583567, 0.016768591121945065, 0.024474711208313238, 0.07071580112096854, 0.07184672285802662, 0.008003433722478803, 0.04593507830577437, 0.09043321770150214, 0.010951959538942901, 0.03436453960603103, 0.006893333402331336, 0.02077253164316062, 0.02527329921576893, 0.010979381895594997, 0.0759627555089537, 0.03336576839501504, 0.039174250268843025, 0.05350433522835374, 0.0290853964179405, 0.022159876534715295, 0.055423603334929794, 0.10328541946364567, 0.02609269147797022, 0.0057301467950310325, 0.03980480119935237, 0.05164069851161912, 0.03744594047020655, 0.018302127973583993, 0.09373173015774228, 0.22846752020996064, 0.12002035233308561, 0.10401094303233549, 0.17129569896496832, 0.13053064030827954, 0.10552035266300663, 0.1260310731595382, 0.09632655302993953, 0.1575059865717776, 0.11726062424713746, 0.061135268333600834, 0.08355039171874523, 0.23382116574794054, 0.16542318830033764, 0.2269841599627398, 0.18252405192470178, 0.10954710494843312, 0.19024977955268696, 0.08612444187747315, 0.18931326339952648, 0.08167364125256427, 0.15771864156704396, 0.058873502784990706, 0.14286201767390594, 0.1015164065756835, 0.08267457582405768, 0.08835358632495627, 0.1594378415029496, 0.21391940710600466, 0.09304398932727054, 0.09687108162324876, 0.18019556358922273, 0.11806416237959638, 0.08209742984035984, 0.18063417286612093, 0.12064360053045675, 0.16714042896637693, 0.13803586101857945, 0.12604932999238372, 0.09908992506098002, 0.12763434962835163, 0.09566469088895246, 0.10347385075874627, 0.15490882593439892, 0.27231743442825973, 0.13630468281917274, 0.11505441958433948, 0.12388864866807126, 0.12720800063107163, 0.07282917053089477, 0.1045446733769495, 0.1291015013703145, 0.08082152955466881, 0.16546050348551944, 0.17811052937759086, 0.09009780405904166, 0.12451860588043928, 0.16726562927942723, 0.12475186289520934, 0.13798331696307287, 0.20633811625884846, 0.22244303254410625, 0.1479899909463711, 0.09819162209169008, 0.14135358767816797, 0.09783540604985319, 0.23755771602736786, 0.14575330627849326, 0.10733472561696544, 0.15718956448836252, 0.16653969010803849, 0.17776321910787374, 0.21596433565719053, 0.1744404755299911, 0.11161800866830163, 0.16656968771712855, 0.15549518197076395, 0.19231338053941727, 0.135278589441441, 0.1251843717182055, 0.12242121490999125, 0.11989364546025172, 0.11368040737579577, 0.12253758366568945, 0.10609639284666628, 0.15268313989508897, 0.12081060602213256, 0.12371940189041197, 0.17922096041729674, 0.1326282910304144, 0.11558325175428763, 0.16446292342152447, 0.17474689346272498, 0.18200260412413627, 0.18657159176655114, 0.13537915045162663, 0.11988241676590405, 0.24512557400157675, 0.15631586371455342, 0.1423816551687196, 0.15454949287232012, 0.22400047397240996, 0.10969672192004509, 0.15191700600553304, 0.22147099720314145, 0.1730320425122045, 0.23675180302234367, 0.17351258313283324, 0.2021417609648779, 0.14004578988533467, 0.14114486606558785, 0.15870808769250289, 0.1136643547215499, 0.13597401150036603, 0.11404289456550032, 0.14424532157136127, 0.19372086360817775, 0.1321572350570932, 0.10855765140149742, 0.12145272703492083, 0.09110084632993676, 0.12115800534957089, 0.13698063092306256, 0.09863931525615044, 0.11381162650650367, 0.13710612809518352, 0.09551798313623294, 0.12501412304118276, 0.18243307946249843, 0.19077771372394636, 0.147775643854402, 0.11452727208961733, 0.12923010071972385, 0.14992475509643555, 0.12315124331507832, 0.11537731319549493, 0.1110672163486015, 0.1353351114084944, 0.1582984667038545, 0.15447465470060706, 0.1834234458510764, 0.1521541815600358, 0.14402905973838642, 0.13767272816039622, 0.11564887245185673, 0.147049808583688, 0.1341974435490556, 0.12422968778992072, 0.09055210233782418, 0.07918222923763096, 0.10436506621772423, 0.1819978840649128, 0.0996881331957411, 0.08671800416777842, 0.1517855271231383, 0.10653972960426472, 0.10577756620477885, 0.1352434858563356, 0.10443057559314184, 0.14350921497680247, 0.1103968640381936, 0.18538912787334993, 0.12240698051755317, 0.14251246611820534, 0.1032162067713216, 0.17399505333742127, 0.09879017161438242, 0.16677958192303777, 0.14086935116210952, 0.11589519126573578, 0.12397308280924335, 0.10292032733559608, 0.21744116500485688, 0.19286978349555284, 0.09929947045748122], [0.031042232039908413, 0.025312312063761055, 0.02143920475646155, 0.055096705837058835, 0.09426504489965737, 0.07053150358842686, 0.031344896560767666, 0.010902936046477407, 0.023557132808491588, 0.024943503631220665, 0.025618533327360637, 0.024375359898840543, 0.018312551437702496, 0.04079479651409201, 0.03886252969095949, 0.037099906694493257, 0.06363192733260803, 0.029431305883917958, 0.03177348684403114, 0.026755056424008217, 0.06798779242672026, 0.023117725722840987, 0.025842455979727674, 0.023939216407597996, 0.06276198182604276, 0.03992761550762225, 0.06367935799062252, 0.025895716207742225, 0.041863741498673335, 0.02555367704189848, 0.03594380759750493, 0.08747514322749339, 0.05584891332546249, 0.014881228871672647, 0.032962299810606055, 0.05538452554901596, 0.014359216111188289, 0.04093408650078345, 0.023323686546063982, 0.031233811896527186, 0.01676833322562743, 0.02224179665063275, 0.05877795869309921, 0.030755145198781975, 0.041505985500407405, 0.03885806196194608, 0.07923352648504078, 0.04422918507771101, 0.00983467847618158, 0.04939677419315558, 0.06533334541018121, 0.045375506379059516, 0.05921710602706298, 0.021867982432013378, 0.05806456181744579, 0.031007430879981257, 0.05330810396117158, 0.010860636411962332, 0.09317171294242144, 0.08587898395489901, 0.015312604064092739, 0.023586688839714043, 0.022351877560140565, 0.042212754997308366, 0.0662608518905472, 0.02619902639708016, 0.012021964867017232, 0.04169240186456591, 0.01226667136506876, 0.018026056459348183, 0.0216043418913614, 0.011167451393703232, 0.0912978568521794, 0.03763003020139877, 0.025727907341206446, 0.04907129048660863, 0.02391206864558626, 0.04149660475377459, 0.04038399179989938, 0.023018374413368292, 0.04142726960708387, 0.042287633987143636, 0.05787543661426753, 0.031720968763693236, 0.03284577149315737, 0.07528089248808101, 0.05999640190566424, 0.029041153284197208, 0.012136075638409238, 0.03948639758164063, 0.023701276440988295, 0.0238309686028515, 0.07209183197119273, 0.07769435673253611, 0.057906807196559384, 0.018364952629781328, 0.058117354492424056, 0.017339375044684857, 0.022580230834137183, 0.05730210155888926, 0.05485224610310979, 0.07967661091242917, 0.01571891229104949, 0.06670040369499475, 0.06587220399524085, 0.04684285479015671, 0.05491850504768081, 0.013761200007138541, 0.08271134181995876, 0.05402728958870284, 0.05149905220605433, 0.07635448331711814, 0.03644228221673984, 0.019859001658915076, 0.024512336240150034, 0.025133693816314917, 0.00924850333831273, 0.08491875618346967, 0.030621968653576914, 0.009909868240356445, 0.08101097759208642, 0.011211023811483756, 0.04945509586832486, 0.037936704175081104, 0.02162910550396191, 0.05360513743653428, 0.006698170363961253, 0.032110154716065153, 0.04343585518654436, 0.03829055647656787, 0.014011170187586686, 0.04606398564646952, 0.06062865235435311, 0.04731023342174012, 0.06121242942754179, 0.07853104660171084, 0.055770253093214706, 0.004886311899099383, 0.016984967987809796, 0.050897211258416064, 0.022407950527849607, 0.02030273732088972, 0.011624422331806272, 0.017016229103319347, 0.051574729004641995, 0.013985132864036132, 0.08788790350081399, 0.012832339107262669, 0.00677176868521201, 0.05127304597408511, 0.029140127953724004, 0.03817707838607021, 0.046380207350011915, 0.12715299264527857, 0.04324602865381166, 0.028345751634333283, 0.02561188182880869, 0.0456153759296285, 0.032405117599410005, 0.04139509008382447, 0.10655122547177598, 0.028663875091297086, 0.027546020719455555, 0.09608349224436097, 0.03843311933451332, 0.03546665859175846, 0.03304798075987492, 0.015791624209668953, 0.04731587374408264, 0.04784268356161192, 0.020924091186316218, 0.06546181859448552, 0.007728035243417253, 0.020137093670200557, 0.022047392922104336, 0.03054218406759901, 0.03843008766125422, 0.04783180738741066, 0.02510208203602815, 0.010831755735125626, 0.08495939619024284, 0.10761689758510329, 0.021207404206506908, 0.023613478515471797, 0.03302731936855707, 0.014795603583479533, 0.011852352581627201, 0.07055173453409225, 0.021014260273659602, 0.0391237953590462, 0.06354492536047474, 0.089614369062474, 0.03730370786797721, 0.013657273357239319, 0.06123170300270431, 0.04109562978555914, 0.08104308290057816, 0.021622363092319574, 0.032494490733370185, 0.0301644383216626, 0.06321083274087869, 0.026685660050134175, 0.0906194670824334, 0.044609465257963166, 0.03352279200043995, 0.036712746805278584, 0.04429095031809993, 0.02344825232285075, 0.028147420089226216, 0.039876347946119495, 0.05938755508395843, 0.05500241226400249, 0.01271733683097409, 0.011926204624614911, 0.031222390243783593, 0.0337972159468336, 0.04023896501166746, 0.031246183498296887, 0.03122880239970982, 0.020351618877612054, 0.03153356534312479, 0.04244419375027064, 0.07931329993880354, 0.054866191057953984, 0.008534438529750332, 0.058312316687079147, 0.02476347715855809, 0.06653250762610696, 0.016284478915622458, 0.04980801677447744, 0.03425796348892618, 0.031202730751829222, 0.0591302339307731, 0.015132690768950852, 0.07486248447094113, 0.03855202623526566, 0.023850244033383206, 0.03292618319392204, 0.03151157921820413, 0.03836139076156542, 0.045646297512575984, 0.02107444659486646, 0.06530722181196325, 0.06399866702849977, 0.025513994405628182, 0.033807602303568274, 0.03435619786614552, 0.008503537355863955, 0.046927715666242875, 0.03732242483238224, 0.03257619377109222, 0.05471347933053039, 0.011280992566753412, 0.06195394627866335, 0.02051219365966972, 0.07034601119812578, 0.02477412697771797, 0.03288158382929396, 0.020127983807469718, 0.030793119040026795, 0.07689058853429742, 0.03407508716918528, 0.07202366570709273, 0.03147178525978234, 0.055447968043154106, 0.05530491907848045, 0.01921216244227253, 0.054051702536526136, 0.03208925583749078, 0.026147367352677975, 0.02147674258594634, 0.01825681985792471, 0.057892209151759744, 0.0468950871436391, 0.030125583180051763, 0.04403306884341873, 0.027995203745376784, 0.05343870339856949, 0.017271286706090905, 0.053663121434510686, 0.0923353125108406, 0.033839310563053004, 0.049331747213727795, 0.08462183774099685, 0.0746215165418107, 0.04948773552314378, 0.06703637394821271, 0.08244534867117181, 0.00979897746219649, 0.05244410676823463, 0.021654232768923976, 0.026596572643029504, 0.021954745061520953, 0.10375980025855824, 0.040528272729716264, 0.04318936567869969, 0.032673960595275275, 0.04804177580808755, 0.03845162478683051, 0.07162133260862902, 0.05930189639911987, 0.054443782864836976, 0.04771141248056665, 0.056878409450291656, 0.009710785270726774, 0.03713815698574763, 0.031879792077234015, 0.038868181145517156, 0.05304083060764242, 0.058199736595270224, 0.011216687325941166, 0.007508087255700957, 0.05253224051557481, 0.014808311007072916, 0.006116244485383504, 0.038672703158226795, 0.06323760200757533, 0.08777123046456836, 0.08299294975586236, 0.03887457845848985, 0.07820028622518294, 0.0581552782387007, 0.008475107533740811, 0.050830354884965345, 0.11788383533712476, 0.04452312750800047, 0.01553396074086777, 0.01457237298382097, 0.03899019393429626, 0.02663265957380645, 0.007533087427873397, 0.031623743707314134, 0.06399549063644372, 0.049775069128372706, 0.05740786873502657, 0.03356410365086049, 0.02665491101652151, 0.08201732984161936, 0.0385517961694859, 0.0586705328169046, 0.07822219442459755, 0.05926895246375352, 0.039799264777684584, 0.015089549724507378, 0.06062795844627544, 0.08418512836215086, 0.07828371104551479, 0.0428015007491922, 0.011511226257425733, 0.06431134126614779, 0.04729181331640575, 0.04088490066351369, 0.2754212444415316, 0.13668478117324412, 0.13679402531124651, 0.13826638692989945, 0.25387171015609056, 0.24553485360229388, 0.1658043108182028, 0.072907244466478, 0.07906760452897288, 0.099723125458695, 0.12373494246276096, 0.24447135598165914, 0.07311407360248268, 0.1494283918873407, 0.10656966784154065, 0.1715960758156143, 0.11244378896662965, 0.12627319141756743, 0.09323932259576395, 0.17065139603801072, 0.14046375261386856, 0.15500362787861377, 0.15452363644726574, 0.10453390481416136, 0.12464956525946036, 0.10233155931928195, 0.2616906218463555, 0.12890664307633415, 0.18253211164847016, 0.1304749643895775, 0.16579887829720974, 0.12065991293638945, 0.15826607937924564, 0.15269606810761616, 0.09182582070934586, 0.1217190244642552, 0.07450155579135753, 0.1275227899895981, 0.08769602864049375, 0.15631387475878, 0.13446430501062423, 0.20239900419255719, 0.23531807761173695, 0.1534151053056121, 0.17740949668223038, 0.21801929804496467, 0.1977238300605677, 0.11610088491579518, 0.06926726244273596, 0.16853407840244472, 0.21342032763641328, 0.18512177659431472, 0.08680385581101291, 0.13143350748578086, 0.1701926300302148, 0.1378310876316391, 0.2652707719244063, 0.11061207202146761, 0.1936335870414041, 0.19921962870284915, 0.176769127137959, 0.2320226450683549, 0.15805976232513785, 0.12869306781794876, 0.1330743366270326, 0.09107290446991101, 0.15861748630413786, 0.1563630494638346, 0.12706810579402372, 0.15048995992401615, 0.10050100754597224, 0.15103857032954693, 0.18952859012642875, 0.11701984927640297, 0.1536898038466461, 0.14576492831110954, 0.22319916228298098, 0.13878119993023574, 0.15709906700067222, 0.13134434586390853, 0.08093396492768079, 0.21257438318571076, 0.125820733665023, 0.1349943468812853, 0.14683347253594548, 0.14351809106301516, 0.10957626393064857, 0.19409918080782518, 0.11341305609676056, 0.08935835779993795, 0.08740264282096177, 0.12490682333009318, 0.2120207855477929, 0.08596976345870644, 0.0955664602224715, 0.09744907365529798, 0.22485012916149572, 0.13958938390715048, 0.08303836177219637, 0.19082538929069415, 0.18258277064887807, 0.1574244542280212, 0.17209707002621144, 0.19244531955337152, 0.19059594691498205, 0.16581538366153836, 0.12137969228206202, 0.1492943600169383, 0.19105376297375187, 0.10966207846649922, 0.1938103963038884, 0.13683980097994208, 0.11562306055566296, 0.12055370418238454, 0.11557909572729841, 0.1859449371113442, 0.0721773125405889, 0.14134947618003935, 0.1077526512381155, 0.1239080929371994, 0.18761560058919713, 0.1490934903267771, 0.08255495646153577, 0.14633684215368703, 0.11240979860303923, 0.1725177193293348, 0.12012572988169268, 0.14512009103782475, 0.10553710293606855, 0.133024939277675, 0.15856240410357714, 0.10678881662897766, 0.18564540630904958, 0.15060370147693902, 0.14438796235481277, 0.1783437715494074, 0.12971625197678804, 0.14615847438108176, 0.13427695725113153, 0.16768676840001717, 0.14148013869998977, 0.2191224115085788, 0.13524969021091238, 0.15721648960607126, 0.12272521344129927, 0.11646719416603446, 0.21531887497985736, 0.13987551152240485, 0.15879416198004037, 0.16291382373310626, 0.1664868343505077, 0.1856806137948297, 0.12842018011724576, 0.2150306841940619, 0.0869392606546171, 0.07327478568186052, 0.12200312601635233, 0.1474399704602547, 0.10171799614909105, 0.1490702759474516, 0.20171015756204724, 0.1510212040739134, 0.13215897168265656, 0.129529423720669, 0.14958439132897183, 0.2213560533709824, 0.154486573592294, 0.10293436876963824, 0.16260572854662314, 0.19608056667493656, 0.16350485529983416, 0.186470347980503, 0.19130002241581678, 0.12473609967855737, 0.16240350814769045, 0.15810157492524013], [0.12021641290630214, 0.028009632951579988, 0.06278362285229377, 0.043575557065196335, 0.026595444578561, 0.02296678772836458, 0.038254892569966614, 0.03638114780187607, 0.022949326848902274, 0.02424329286441207, 0.055259982036659494, 0.01397430864017224, 0.04779553120897617, 0.05377936773584224, 0.02557709551183507, 0.046997006284072995, 0.00897870204425999, 0.05294600639899727, 0.030114421278994996, 0.06006408577377442, 0.03789806425629649, 0.048438542798976414, 0.051652513502631336, 0.02690055076527642, 0.0666896351322066, 0.08199283896829002, 0.0103103552464745, 0.04856905317865312, 0.025504819604975637, 0.0526684431679314, 0.04197671492875088, 0.08807693593553267, 0.06013529113261029, 0.02834621918736957, 0.019908061331079807, 0.02972825401229784, 0.06953764910576865, 0.057625744739198126, 0.07302793252165429, 0.026767778690555133, 0.040100780825014226, 0.06632154472754337, 0.045303380757104605, 0.0875206443015486, 0.06807833444327116, 0.03978259985160548, 0.0679655205749441, 0.01052484241881757, 0.0756185845239088, 0.030810769167146645, 0.019129635620629415, 0.015503334161621751, 0.11086642087320797, 0.012648457177419914, 0.016857337141118478, 0.03023629677045392, 0.025009948112710845, 0.009645721183915157, 0.0317587552126497, 0.04692835391324479, 0.061181563505670056, 0.040502557312720455, 0.03037763322936371, 0.07077115791616961, 0.08996828444651328, 0.024834632422425784, 0.05752115757786669, 0.04360579216154292, 0.027971852068731096, 0.0683580721670296, 0.043263714032946154, 0.09388276463141665, 0.08927295144530945, 0.052716782956849784, 0.049602805520407856, 0.02059144389932044, 0.08420026075327769, 0.024373719752475154, 0.031676822109147906, 0.06385551416315138, 0.024497775302734226, 0.004351135758042801, 0.024112407700158656, 0.014706873334944248, 0.03875587193761021, 0.057026341746677645, 0.04040924337459728, 0.07282818347448483, 0.0244767780895927, 0.07579885961604305, 0.05671341888955794, 0.006513352864203625, 0.10283378549502231, 0.02363984145631548, 0.04823702372959815, 0.012756363594235154, 0.03338439630169887, 0.035759031379711814, 0.05580933087912854, 0.049469089062768035, 0.02240794125100365, 0.008344912566826679, 0.03983007132774219, 0.0738344615092501, 0.05133481492521241, 0.0300839672490838, 0.0943256783648394, 0.0432601405918831, 0.034505295334383845, 0.006980611824474181, 0.03286343089712318, 0.020001004195364658, 0.038445034515461884, 0.010738806377048604, 0.10279547583195381, 0.028387434358592145, 0.016887640886125155, 0.023068213340593502, 0.06726885912939906, 0.0648835593892727, 0.025100608872890007, 0.07588566862978041, 0.006887139716127422, 0.03159048064844683, 0.014620277688663919, 0.04105951687961351, 0.039728404517518356, 0.03730868767888751, 0.048932082136161625, 0.062400585593422875, 0.037188589631114155, 0.046591867867391557, 0.06927254653419368, 0.03204838576493785, 0.05129618242790457, 0.0361792539479211, 0.020055197674082592, 0.057204664990422316, 0.029583297728095204, 0.010251808143948438, 0.05790970528323669, 0.03535975964041427, 0.040558018008596264, 0.027210755506530404, 0.01347462710327818, 0.06293440499575809, 0.026048121799249202, 0.017381250727339648, 0.051168818754376844, 0.02551508165197447, 0.050644665825529955, 0.017860360858321656, 0.054924353171372786, 0.03327718935906887, 0.009206610957335215, 0.03451348122325726, 0.012759727378579555, 0.013347964759304887, 0.044793042907258496, 0.02944655887404224, 0.04028556817502249, 0.03848234970064368, 0.006518649479403393, 0.014023322855791776, 0.018663056653167587, 0.06531027946039103, 0.04706900945166126, 0.12251235806616023, 0.03803303865424823, 0.07885417027864605, 0.015920789446681738, 0.0502412788773654, 0.043853947790921666, 0.030774025435675867, 0.06232426312635653, 0.04733227520773653, 0.04398592391225975, 0.042465278165764175, 0.017056941469490994, 0.026682585703383666, 0.03392211197933648, 0.02997307739860844, 0.024044239580689464, 0.09926571758114733, 0.06419169221771881, 0.05307966719556134, 0.05927504549617879, 0.06159841301268898, 0.09298095130361617, 0.0312802851840388, 0.1147587331070099, 0.01531529713247437, 0.059814560881932266, 0.04226455319439992, 0.10040931520052254, 0.013690618980035651, 0.028171415578981396, 0.02733202800300205, 0.05515723169082776, 0.026950128085445613, 0.042395334457978606, 0.024852866990840994, 0.046914735503378324, 0.02564130427344935, 0.01811732021451462, 0.059794752960442565, 0.05095759981486481, 0.03306932863779366, 0.1239627817994915, 0.017663780781731475, 0.020138080726610497, 0.012890910329588223, 0.03568687607184984, 0.01981904628337361, 0.029666258706129156, 0.06442155019612983, 0.02956736567284679, 0.02356500885071, 0.08925571877625771, 0.08178819174645469, 0.017101733792515006, 0.03955912063247524, 0.037969503391650505, 0.015703765056969132, 0.024987615033751354, 0.004020679198220023, 0.009521977335680276, 0.011378409653843846, 0.056526390253566206, 0.03071916216867976, 0.11675630521494895, 0.03265844970883336, 0.05670718113833573, 0.027388893213355914, 0.11694796485244296, 0.05107723773107864, 0.03891199754434638, 0.012293587205931544, 0.03540211771905888, 0.02359311212785542, 0.056735579419182613, 0.052923875555279665, 0.04194164102955256, 0.03331296829856001, 0.033402886911062524, 0.04522756295045838, 0.034093236390617676, 0.04078376448887866, 0.07308455838938244, 0.07377832545898855, 0.06641121843131259, 0.03422695655899588, 0.02587209179182537, 0.04263201277353801, 0.04627239926776383, 0.09132392107858323, 0.023111460141080897, 0.014727864054293605, 0.08333565870998427, 0.0262744657084113, 0.04520849346590694, 0.06495004839962348, 0.021110635570948943, 0.04205857010674663, 0.06551245533046313, 0.05867752384801861, 0.008662405198265333, 0.03801135309913661, 0.057555648891138844, 0.054068638346507214, 0.01428795972969965, 0.06745262231561355, 0.018718801220529713, 0.0918565975734964, 0.02762312244158238, 0.0360713827831205, 0.04815008484001737, 0.04395433439640328, 0.05745317685068585, 0.02173562410462182, 0.021760660456493497, 0.01049070177032263, 0.03073948773817392, 0.07132816201192327, 0.029440896287269425, 0.051904817737522535, 0.018494598407414742, 0.053591708274325356, 0.09895925511955284, 0.02729922693106346, 0.026159798326261807, 0.03288829655502923, 0.02680197314475663, 0.05526750741410069, 0.025557949957146775, 0.04742160010209773, 0.013265903635328868, 0.012586467437358806, 0.04308072639105376, 0.012039413686579792, 0.04005882721685339, 0.015121889737201855, 0.04813213228771929, 0.03463848857791163, 0.01638003042899072, 0.022560521247214638, 0.044945131230633706, 0.04379630147013813, 0.05136407409736421, 0.07713684797636233, 0.10511320302612148, 0.005545545445784228, 0.05471749806019943, 0.03522668142977636, 0.020508204615907744, 0.0339541987341363, 0.03889384832291398, 0.019052222196478397, 0.03918419133697171, 0.04175231915723998, 0.04379335885460023, 0.040521957052988, 0.019983261299785227, 0.025140050311165396, 0.004449692041816888, 0.08723487291717902, 0.022526490065502003, 0.009777080394997029, 0.026313229936931748, 0.051460271279211156, 0.05476993079355452, 0.07795825702487491, 0.07205964502645656, 0.020302908014855348, 0.03815396790741943, 0.07503689659642987, 0.03778949176194146, 0.04262142603693064, 0.04400729405460879, 0.00639723458334629, 0.016064908959378954, 0.03774872930080164, 0.040062842235784046, 0.07894779220805503, 0.05438018823042512, 0.21430213266285136, 0.02426501738227671, 0.024654086446389556, 0.0468364166590618, 0.06220837305590976, 0.0880769953073468, 0.017098462776630186, 0.23683340958086774, 0.11689155420754105, 0.14105963782640174, 0.10321429945179261, 0.1709515502443537, 0.0816535810008645, 0.08173835652996786, 0.23633913922822103, 0.15347591688623652, 0.2061832300387323, 0.22618062183028087, 0.09631140579585917, 0.18193346564657986, 0.14922372240107507, 0.1682712690671906, 0.11129495178465731, 0.1337299498845823, 0.1266296746325679, 0.12006009434117004, 0.18390656914561987, 0.1060435148247052, 0.16381299501517788, 0.1718424985301681, 0.1366106406203471, 0.14694951474666595, 0.1348381841671653, 0.17379497032379732, 0.11933142406633124, 0.11422335519455373, 0.1269229713943787, 0.0974617940664757, 0.15758725174237043, 0.23772469925461337, 0.08433381764916703, 0.07476236132788472, 0.17369755601976067, 0.14903827453963459, 0.15359130600700155, 0.12357652361970395, 0.13022805185755715, 0.08925391535740346, 0.12203050384414382, 0.15139686438487843, 0.21941226470516995, 0.2013062362675555, 0.1335397522780113, 0.18915619526524097, 0.06306569834123366, 0.1529225567355752, 0.09831973162363283, 0.09989914804464206, 0.11178963774000295, 0.17067230975953862, 0.12472283007809892, 0.1647595301619731, 0.11301671213004738, 0.16629543446470052, 0.10724802792537957, 0.22635979112237692, 0.19079870166024193, 0.2395271830027923, 0.0918043429555837, 0.17614319978747517, 0.1555500563699752, 0.23097920027794316, 0.21058141981484368, 0.16448076465167105, 0.18548762571299449, 0.10022786751505919, 0.19809468125458807, 0.11667359285638668, 0.11674639012198895, 0.24761068518273532, 0.1446299915551208, 0.21743804798461497, 0.1436689548427239, 0.209870605613105, 0.26510381838306785, 0.19500666414387524, 0.1330726148444228, 0.08576738720876165, 0.10226400903775357, 0.1223959744675085, 0.10570868747890927, 0.10230682353721932, 0.21327687049051747, 0.10065652459161356, 0.1347518723923713, 0.09166686751996167, 0.14692827448016033, 0.11650770058622584, 0.13032965187449008, 0.15855556150199845, 0.17631218681344762, 0.10038144013378769, 0.14339600777020678, 0.06763844867236912, 0.15901846869383007, 0.12951892975252122, 0.1517648360459134, 0.07920319490949623, 0.13634587201522663, 0.09119231603108346, 0.11836793826660141, 0.11811571195721626, 0.09813147102249786, 0.19078712415648624, 0.09410075566847809, 0.09041630415595137, 0.15190183650702238, 0.11401781739550643, 0.20855381299043074, 0.23018626001430675, 0.18495562457246706, 0.2431083720875904, 0.14154531410895288, 0.14710671646753326, 0.12213703172164969, 0.15357653726823628, 0.1252295685117133, 0.12271065250388347, 0.17318593425443396, 0.15485260082641616, 0.13644558697706088, 0.09808022572542541, 0.1476613085833378, 0.14185907930368558, 0.08323648551595397, 0.16088237258372828, 0.1402018338558264, 0.15830271178856492, 0.18824981030775234, 0.19065880682319403, 0.1723705217591487, 0.18034786713542417, 0.081983369163936, 0.12604493647813797, 0.1484030851861462, 0.12670152937062085, 0.09955295841791667, 0.2198560393298976, 0.11228027156903408, 0.116299446526682, 0.12329929435509257, 0.18166182475397363, 0.14821270946413279, 0.14391275035450235, 0.07241764964419417, 0.1603786027408205, 0.20602240663720295, 0.1538076568976976, 0.10657069200533442, 0.21914627897785977, 0.1537534801173024, 0.16240947501501068, 0.19345452164998278, 0.16955932573182508, 0.10408048969111405, 0.11905028368346393, 0.19005311041837558, 0.09149627003353089, 0.1195978773466777, 0.14106429851381108, 0.1462361920857802, 0.13538677972974256, 0.17605182656552643, 0.16306642413837835, 0.29332668520510197, 0.21916066179983318, 0.2665013715159148, 0.11474671031464823, 0.1263708432088606, 0.18802821985445917, 0.11467622112832032, 0.18506111344322562, 0.08391261173528619], [0.024891360335459467, 0.02926628749264637, 0.0037641442577296402, 0.052680072622024454, 0.024365125682379585, 0.05713892183848657, 0.004654795220631058, 0.0736337699345313, 0.04055635930853896, 0.08280157955596223, 0.056860427212086506, 0.010656761023710715, 0.04897480386716779, 0.06229381280718371, 0.060799717393820174, 0.03983368558692746, 0.0724837527377531, 0.03749365314433817, 0.02720133023103699, 0.03314505738671869, 0.05706706710043363, 0.04302194087358657, 0.0444698932551546, 0.038809332545497455, 0.008986798875412205, 0.02742644959653262, 0.0808355635672342, 0.04093027928320225, 0.010514751993468963, 0.02120684388501104, 0.019145829282933846, 0.061773411434842274, 0.03534254923579283, 0.02298206298291916, 0.02410138495179126, 0.02911765201133676, 0.0521830897196196, 0.051216561114415526, 0.022771352414565627, 0.02057556379440939, 0.0670146883931011, 0.03347337609739043, 0.04342437787272502, 0.016608508012723178, 0.029270319209899753, 0.005191114269109676, 0.003754176750589977, 0.043386747274780646, 0.05105783056933433, 0.045871246184105985, 0.00860941770952195, 0.03865291007969063, 0.011663527948257979, 0.058331972468295135, 0.012326446721999673, 0.02075380540190963, 0.022072030369599815, 0.04117516575206537, 0.022602586177526973, 0.03999043088697363, 0.038067986388341524, 0.03883215358655434, 0.0685319647891447, 0.1318545575486496, 0.03208169335266575, 0.03559459000825882, 0.057831505182548426, 0.05046999765909277, 0.0341623488930054, 0.0446131092030555, 0.020739658211823553, 0.0940918127889745, 0.058537551085464656, 0.025278228931711055, 0.045695839580730535, 0.0323699954606127, 0.026441454501764383, 0.029533106280723587, 0.03963963252317626, 0.012550553983601276, 0.06370160015649162, 0.011831090978375869, 0.011660203126666602, 0.039386656644637696, 0.017014023069350515, 0.02603882268886082, 0.045519605482695624, 0.05072841348010115, 0.06521635325043462, 0.03788446068938356, 0.03560892087989487, 0.07484376008505933, 0.027166460422449745, 0.11089469669968821, 0.08626369104604237, 0.026067465878441, 0.01658662578847725, 0.06699894744087942, 0.023684049338044133, 0.030772854697715957, 0.020218544377712533, 0.04830068886803929, 0.03942456183722243, 0.015020292503322707, 0.08899673892301507, 0.007934609730000375, 0.06955307093448937, 0.011753179387596902, 0.041180913685821, 0.014212079768185504, 0.04765693884110078, 0.025722170539665967, 0.049696620408212766, 0.043365688834455796, 0.03033721586689353, 0.030399658317037392, 0.07438179542077705, 0.010898999880737392, 0.042657991652959026, 0.032291691459249705, 0.039101931688492186, 0.01625267046620138, 0.026244210203003604, 0.03477634250884876, 0.02579306048573926, 0.04291011035093106, 0.04544209557934664, 0.02185533809097251, 0.03905189238139428, 0.03334192690090276, 0.039195423742057756, 0.049158188558067195, 0.03585051221307367, 0.040874955884646624, 0.079342013632413, 0.01727229046082357, 0.026471095879969653, 0.05980837137030903, 0.027866767668456305, 0.00642641768536123, 0.033002156851580366, 0.07849261819501407, 0.040178368653869256, 0.06577160587767139, 0.0770994288905058, 0.04995218638214283, 0.03675380241475068, 0.03045627861865796, 0.01368908551739878, 0.04344217086327262, 0.004623810555131058, 0.031002517862361856, 0.03560352175554726, 0.02025457564741373, 0.016958673695626203, 0.02482050193066243, 0.041378766545676626, 0.07481670880224556, 0.07242060339194722, 0.11816438942332752, 0.09146207929006778, 0.020327246747910976, 0.019676819247251842, 0.08786941660218872, 0.03807535962550901, 0.025611071032471955, 0.07289070941624232, 0.08566603952203877, 0.08390167247853242, 0.020680993293353822, 0.04649663176678587, 0.03524741703586187, 0.048867860386963, 0.010217554317932809, 0.018645475174707826, 0.08384986314922571, 0.01871138345450163, 0.04225811135256663, 0.06130848189059179, 0.04022939130663872, 0.04573294696456287, 0.005977972632535966, 0.036363506951602176, 0.04921886655210983, 0.007931024229037575, 0.035374617436900735, 0.016987747330858838, 0.052276771020842716, 0.05976795400783885, 0.09554881195072085, 0.02110494144289987, 0.022691120684612542, 0.012400490795698715, 0.043938808667007834, 0.014688408700749278, 0.01933137547894148, 0.04301862347347196, 0.03138432315608952, 0.018376103398622945, 0.06091483934142161, 0.10003012968809344, 0.024717857340874616, 0.027729414687200915, 0.07285024010343477, 0.06636618491029367, 0.04000296576123219, 0.031598291752743535, 0.01447718326744507, 0.02893097589549143, 0.0367517169797793, 0.020801351092814002, 0.02463132292177761, 0.025689167232485488, 0.03995574290456716, 0.06160117009130772, 0.05623821431072429, 0.02302637105458416, 0.041449548880336806, 0.04510546481469646, 0.038631770003121346, 0.005430832607089542, 0.06975965516176075, 0.05990799727442209, 0.02704993952647783, 0.05020463533583097, 0.04151776709477417, 0.013230477215984138, 0.06725330371409655, 0.01407361449309974, 0.03885532343701925, 0.031057577798492275, 0.03021637567144353, 0.05171348464500625, 0.01184982093036524, 0.033642697089817375, 0.018494880423531868, 0.02277849558595335, 0.01610865114344051, 0.02160203381208703, 0.09247389374650083, 0.02026319383730879, 0.012446339751477353, 0.05518485813809093, 0.02926043380284682, 0.0221470169708482, 0.06855414758319966, 0.05167586146853864, 0.02005551679758355, 0.03987084492109716, 0.052354024883243255, 0.021389547655417118, 0.05648647013003938, 0.07469655509339646, 0.05657571709889453, 0.010924481521215057, 0.015255380767484894, 0.055707834762870334, 0.01885151392343687, 0.06981019541854039, 0.03285275510279462, 0.015194816878647543, 0.04484483739361167, 0.06869249133160338, 0.05845046747708693, 0.025364468347106595, 0.025626170026953332, 0.039564482649439014, 0.0578354496974498, 0.03961764268751722, 0.07231653202325106, 0.06750211614416912, 0.012576508743222803, 0.008865370527928462, 0.099794787238352, 0.02329311377252452, 0.01999786305532325, 0.04083434185304213, 0.011384595454728696, 0.07242383173434064, 0.02426532722893171, 0.026736463769339025, 0.07447700554621406, 0.018925261138065252, 0.016817405885376502, 0.042854052226175554, 0.052409429918043315, 0.05069683138572145, 0.030957979724917095, 0.10433581075631082, 0.01927966262883274, 0.013031729140493553, 0.04366414352261927, 0.04484187993512023, 0.009228209310094826, 0.036984632606618106, 0.02806676162435906, 0.0226536607806338, 0.018049721693387255, 0.02743033845035825, 0.054938123721512966, 0.019883835775544867, 0.046151633287081495, 0.05133944963745307, 0.031640705492463894, 0.07593062793603167, 0.017644672334427014, 0.02302807057276368, 0.0390816116851056, 0.04342007712693885, 0.05035604088334367, 0.028008278532070108, 0.0293265461732517, 0.04602457760483958, 0.026567771747068036, 0.0549355262046447, 0.03379814363142941, 0.054918579262448475, 0.05137223401106894, 0.017731590814946685, 0.02555442290031351, 0.005690947946277447, 0.019897430065611843, 0.08052557590417564, 0.030773620965192094, 0.05411371268564835, 0.02883129804104101, 0.036651204209192656, 0.012474161012505647, 0.07137079097446986, 0.03456653736066073, 0.02026078185735969, 0.0417175903567113, 0.029174097908253316, 0.05281525482132565, 0.03271246692747809, 0.043450115554151125, 0.009189997981593478, 0.02339664893952431, 0.046691371317137964, 0.049534431454958394, 0.020398051347001456, 0.026595939962135162, 0.043653489992721006, 0.025960385100916028, 0.025165205406665336, 0.034251347242388874, 0.04840230001718737, 0.014499867011181777, 0.0708844096516259, 0.027196422779525165, 0.06984393345192075, 0.05071446481451858, 0.09958680035197176, 0.12704333290457726, 0.12478536344133317, 0.11520804415340535, 0.08260174145107158, 0.21548603632254526, 0.10180667537497357, 0.1998634566552937, 0.0971398207184393, 0.20257850002963096, 0.1212183567986358, 0.17723417171509936, 0.1484890258871019, 0.1944462239043787, 0.07715839994489215, 0.16192755399970338, 0.18507568922359496, 0.1981459785019979, 0.07048246246995404, 0.18705201364355162, 0.11759138462366536, 0.11981791671132669, 0.11233830751734786, 0.13533626915886998, 0.17489683697931468, 0.14193880080711097, 0.22130779892904684, 0.17236163082998246, 0.1272074514417909, 0.11880784630193375, 0.16264242032775655, 0.1387853708001785, 0.12335882944171317, 0.08349966592504643, 0.1283023864380084, 0.1600125606637448, 0.21613715216517448, 0.13151211576769128, 0.11457368600531481, 0.18706802919041365, 0.13317675300640985, 0.15109044645214453, 0.11830057352199219, 0.09421763650607318, 0.08889559903764166, 0.13005484943278134, 0.10075563841382973, 0.08479532218188979, 0.14278602175181732, 0.09685576369520277, 0.13235917343990877, 0.17367713211569935, 0.10529449486057274, 0.17889922455651686, 0.14427114831050858, 0.19352753413841128, 0.1592724910005927, 0.15855124220252037, 0.16786068328656256, 0.08607848809333518, 0.09493197590927593, 0.12416313940775581, 0.18092438229359686, 0.23287509073270485, 0.16901420342037454, 0.1408954747603275, 0.2168911148328334, 0.14638981665484607, 0.20506183005636558, 0.08802272204775363, 0.16377125662984326, 0.22894340014318004, 0.1309141525416635, 0.10716426913859323, 0.18858824449125677, 0.1617019114200957, 0.22235298034502193, 0.17194427666254342, 0.1237047222093679, 0.10979343118378893, 0.2171383539098315, 0.12936445913510397, 0.18495611438993365, 0.13988275488372892, 0.10291194106684998, 0.1302467391360551, 0.13390551233896986, 0.0997451895091217, 0.1743992863339372, 0.23765556077705696, 0.19881765183527023, 0.16868267121026292, 0.13607384520582855, 0.17412390501704067, 0.24510615941835567, 0.10783050252939574, 0.14236040005926043, 0.21586785645922646, 0.16472939896630123, 0.10367653128923848, 0.1691607033717446, 0.1748486715951003, 0.1584449814981781, 0.07904276484623551, 0.21472104534041137, 0.1786641715443693, 0.15298094891477376, 0.08596363331889734, 0.22146201721625403, 0.14032114151632413, 0.11383721575839445, 0.1264575557434, 0.19933763018343598, 0.1458517595892772, 0.19427803839789703, 0.07569922629045323, 0.13357579096918926, 0.12647933035623282, 0.12535698042484, 0.21238184039248154, 0.08937562015489675, 0.0653153557504993, 0.16070280253188685, 0.1658446539659053, 0.1057746124570258, 0.18965573486639187, 0.11252800046349876, 0.1586420662351884, 0.15825548151042312, 0.17564891459187493, 0.12536483234725893, 0.22931846673600376, 0.12557221809402108, 0.1302620570641011, 0.14910445926943794, 0.0929972785525024, 0.14541809301590547, 0.12249283958226442, 0.1260796986753121, 0.09207454408169724, 0.15284874272765592, 0.14938690583221614, 0.11447695447714068, 0.16096727427793667, 0.21685912826796994, 0.13386178499786183, 0.21230934740742669, 0.1388487798976712, 0.15531981247477233, 0.16689832555130124, 0.10685364322853275, 0.06386062756064348, 0.12872823077486828, 0.15155351691646501, 0.07975044718477875, 0.180614149721805, 0.15048241970362142, 0.15931961737805977, 0.11528873044881038, 0.22408592485589907, 0.1419213306508027, 0.11526004644110799, 0.09386435194755904, 0.14536560833221301, 0.09695092187030241, 0.08385321765672415, 0.11676762296701781, 0.18256970884976909, 0.1967928058002144, 0.10576116474112496, 0.08679117992869578, 0.14395160920685157, 0.12445507803931832, 0.1471878628944978, 0.12388332004775293, 0.27370824886020273], [0.03558460441126954, 0.024871049608918838, 0.06434367664041929, 0.01821728565118974, 0.04087918612640351, 0.031098490544536617, 0.04940235143294558, 0.04555191859253682, 0.049219467691727914, 0.037075712680234574, 0.023513082633144222, 0.031122805157792754, 0.018519117111281957, 0.03860184660879895, 0.07695030173636042, 0.036946085456293076, 0.05277861870126799, 0.11576809847611003, 0.04333995115302969, 0.023988918037503026, 0.026617298972269055, 0.016354199979105033, 0.015986293255991768, 0.018123958725482225, 0.00971280020166887, 0.06290355391683988, 0.02712369601795217, 0.016832614346640185, 0.06418536911951378, 0.08401013736147434, 0.052557273156708106, 0.02444193982228171, 0.05237132434558589, 0.04174822250206489, 0.04703776132373605, 0.0047227244613168295, 0.04471902109798975, 0.042652366173570044, 0.05912052663916256, 0.038740305390092544, 0.022853966438560747, 0.03667820354166906, 0.007383700985883479, 0.026241082050546538, 0.04276228566595819, 0.017625523069000337, 0.006153996610009926, 0.15127697784919292, 0.023800336457497906, 0.04605759204423521, 0.06804766890127212, 0.055330055620288476, 0.014404729245143244, 0.03919557959306985, 0.014502230751531897, 0.01353471972834086, 0.01874583394965157, 0.010982742896885611, 0.054649795638397336, 0.0328019884909736, 0.10323542839614674, 0.032215929313679226, 0.020286217113607563, 0.04988089196558576, 0.05103803378005978, 0.015113658391783247, 0.02987956308061257, 0.033203405037056655, 0.013377338964346563, 0.04555082392471377, 0.011635589798970614, 0.027115562079416122, 0.017792116668715607, 0.06558045832207426, 0.03336067355121486, 0.04360873106634244, 0.0859945808770135, 0.004866319368375116, 0.03346021781908348, 0.05846433821716346, 0.03954094914661255, 0.048647483345121145, 0.022696653395541944, 0.02144147943909047, 0.06171591354359407, 0.10899707704083994, 0.03500884624372702, 0.03088650162681006, 0.053688354455516674, 0.08135703363223001, 0.007106004632078111, 0.029697504978685174, 0.03185554982337635, 0.017639403085922822, 0.06906612557941116, 0.0461353431455791, 0.046932524783187546, 0.03148335905279964, 0.04366274086351041, 0.04126416039071046, 0.019496366039675195, 0.018890445135184564, 0.00790714933827985, 0.022042997552489396, 0.02183385477110278, 0.03913716886017937, 0.045091998545103706, 0.011308657049085014, 0.07618289877427742, 0.009368995652039303, 0.08953418742748909, 0.036138283685431816, 0.016562580203753896, 0.0349650743737584, 0.0627121317666024, 0.014083519381529186, 0.049382973957108334, 0.05720231980376411, 0.004789181002706755, 0.041252679366152734, 0.015266087175405119, 0.06876489525893703, 0.017013360702549107, 0.019151887063344475, 0.035831810091622174, 0.03926558267266955, 0.023231817940541077, 0.027373437987989746, 0.028677241170953494, 0.009710673020890681, 0.027097054771729745, 0.02600468575110426, 0.06494314642623067, 0.016632546175969765, 0.03809455898590386, 0.07895202244981192, 0.04338009763159789, 0.028858436526206788, 0.04463218981982209, 0.06962122235563584, 0.06041979715519119, 0.06764523190213367, 0.02656976255821064, 0.0725526908354368, 0.03475218931271229, 0.032408802362624556, 0.017289638162765186, 0.04042535540065728, 0.056566143393865786, 0.005606778659057454, 0.05805338507343549, 0.07194165838882327, 0.13391478918492794, 0.0382096809335053, 0.032198967528529465, 0.03580525975849014, 0.011841577525046887, 0.017164734708785545, 0.041603826539358124, 0.010765986608021194, 0.03323206678032875, 0.05825118969369214, 0.017377055737597402, 0.036600400489987805, 0.04546306867268868, 0.025829950791376177, 0.08344254281837493, 0.04485031073272694, 0.05715546431019902, 0.03412434351048432, 0.06917496895766817, 0.03568720261682756, 0.0266620838738163, 0.027335486411175225, 0.07200698964879848, 0.06935450190212578, 0.030764303301111795, 0.030304617030196823, 0.03127189149381593, 0.024835203876136802, 0.031013026673463173, 0.028103017393732443, 0.05033457426179666, 0.06265765070565976, 0.05732914913096465, 0.04154445472522639, 0.01704152520687785, 0.02639343569171615, 0.08684425833052956, 0.04315044003305957, 0.031622667593182996, 0.033113768440671265, 0.022322510776575655, 0.05629496263281908, 0.018603208009153605, 0.020179435050522443, 0.03975600870035123, 0.01881314117781585, 0.08725681822397746, 0.04626957168511581, 0.030769066033826675, 0.07826570654287934, 0.03827323474979494, 0.014988412622187752, 0.06332613280392252, 0.07016814066446386, 0.010180741010117345, 0.026924357007374056, 0.0556483516265871, 0.007810467905073892, 0.014974433343013516, 0.024124066840158775, 0.054858654548297636, 0.013273537551867776, 0.07374755601631477, 0.0331730957259424, 0.02881446242099628, 0.03328686325403396, 0.037744417422800325, 0.10410400092951022, 0.07238869104185142, 0.03152339420921635, 0.016251021042990033, 0.14619601221056655, 0.043157861509826034, 0.018647781398613006, 0.02136098795745056, 0.034295920631848276, 0.04100018217286561, 0.029540709583670832, 0.10810674473759718, 0.026859368990699295, 0.023488840379286557, 0.012101163156330585, 0.039133751270128414, 0.01725746420561336, 0.018074394392897375, 0.051661508332472295, 0.030848260612401646, 0.036834492420894094, 0.013211325167503674, 0.007330458383876248, 0.04892800032394007, 0.0198342974181287, 0.010977019082929473, 0.07960400660522282, 0.029237072849355172, 0.05280249359202571, 0.030981045674707275, 0.025326451832370367, 0.04153592002694495, 0.033101226144935936, 0.09014574679895304, 0.021156663569854572, 0.019130726577714086, 0.06579798180609941, 0.041406856835237704, 0.03447833310929127, 0.03037908041733317, 0.0827582307101693, 0.025325713395432103, 0.02267989570100326, 0.0388256115547847, 0.008671288705954794, 0.015519974040216766, 0.03536242766131181, 0.021599525352939963, 0.01619989263417665, 0.038792968189227395, 0.029028184253547806, 0.02142767178156646, 0.040675934142200276, 0.022664813404844608, 0.03395447703951504, 0.03929842641809955, 0.04352754011051729, 0.048959530467982404, 0.034911020047729835, 0.036935057141818106, 0.05415308733063284, 0.03671105470857583, 0.08670548413647339, 0.07083921285811812, 0.07028030144283548, 0.07053570414427668, 0.028141802031314, 0.009453523489355575, 0.02557537743996363, 0.017839241190813482, 0.05264251623884775, 0.04738341289339587, 0.03743922774447128, 0.027481218239699956, 0.06988685185206123, 0.04547842741885688, 0.04740934724395629, 0.03946534656279255, 0.06459720170823857, 0.028632142712012865, 0.020838063283008523, 0.015046765838633291, 0.034703493292909116, 0.07439769222401083, 0.04993108341295738, 0.010199965417996282, 0.04806277487659827, 0.035431755386525765, 0.02016511160036316, 0.024870062552508898, 0.019730285421246663, 0.03876048438542057, 0.06403228631825186, 0.04857132043980528, 0.018367680022493005, 0.04290367221983615, 0.03247472734074108, 0.027287354423606303, 0.040890700547606684, 0.018412435238133185, 0.06683939311187714, 0.016518600532435812, 0.04284768830984831, 0.05027790386520792, 0.044314068218227476, 0.012305400341574568, 0.06357734237099066, 0.012280708160687936, 0.09008444540086202, 0.045233930577524006, 0.05440612258098554, 0.03895869347616099, 0.10292834253050387, 0.06189078951138072, 0.005620803394776885, 0.04948344219883438, 0.02229486020951299, 0.031089276781131048, 0.02166314410715131, 0.06912052500410937, 0.041590389955672435, 0.018767469409795012, 0.01000990789179923, 0.04402806676807813, 0.0685801227518823, 0.04552640355541371, 0.027917263396375347, 0.07607788487803191, 0.08036987332161516, 0.031161511869868264, 0.032573110147495754, 0.009481062734266743, 0.053316152552724816, 0.1416436635190621, 0.08874782259226777, 0.21441867953399196, 0.12237091214046814, 0.12400713996612467, 0.12024586874758825, 0.18822298909071833, 0.14384478447027504, 0.13086058432236314, 0.15615818701917306, 0.09182183537632227, 0.11178744098288007, 0.1474165334366262, 0.211722026579082, 0.21100025827763602, 0.08569773664930835, 0.14508614520309493, 0.17716647300403565, 0.1264648139476776, 0.1258677412988618, 0.14298549620434642, 0.14031919708941132, 0.12255573659786023, 0.125803604896646, 0.08937446240452118, 0.24345773068489507, 0.10556449560681358, 0.1691460979054682, 0.15265425550751388, 0.1588795386487618, 0.2057296590646729, 0.07618796022143215, 0.13289935304783285, 0.15631665039109066, 0.10420222417451441, 0.07725378818577155, 0.17328651010757312, 0.1081645728845615, 0.21766428428236395, 0.1675683364737779, 0.06245138560188934, 0.1745550928171724, 0.07481083099264652, 0.16043003357481211, 0.1360792777268216, 0.14882631716318429, 0.1567878547939472, 0.23868168384069577, 0.13633159309392795, 0.15233289072057232, 0.12199524440802634, 0.1408840753720142, 0.2319263736717403, 0.2283734455704689, 0.18686994997551665, 0.04979204204573762, 0.15349083405453712, 0.06913272591191344, 0.1592984958551824, 0.10833943029865623, 0.16108822950627655, 0.13354319584323093, 0.11571981434826739, 0.1677343252231367, 0.1639913479448296, 0.12611474288860336, 0.11687754988088273, 0.19093841838184744, 0.09868833411019295, 0.16570527863223106, 0.09328951404313557, 0.13018383469898254, 0.11455459796707146, 0.09746586103574373, 0.1575126065290533, 0.11936662413063459, 0.22056810033973306, 0.18367865559412166, 0.12460892525268719, 0.19858746731188148, 0.17151357867987826, 0.1437014905968681, 0.08527800760930404, 0.16952374717220664, 0.12600112007930875, 0.2277900284389034, 0.1509371484280564, 0.12292736704694107, 0.15476677886908874, 0.11293733943603002, 0.11624807506450452, 0.17202015384100378, 0.1189934129070025, 0.1529372512595728, 0.19792930106632411, 0.08853928651660681, 0.1429824682418257, 0.1323471951764077, 0.11724116513505578, 0.17688849417027086, 0.1438500834046863, 0.16444343462353572, 0.06607017930946313, 0.19845300499582663, 0.1653623321908526, 0.1823823610902764, 0.11660800184472464, 0.1764862798154354, 0.17926937813172117, 0.10734651092207059, 0.18341071059694514, 0.11569123424123973, 0.06653816279140301, 0.13706176250707358, 0.19641993596451357, 0.10283709547366016, 0.11100765157607384, 0.13537857157643884, 0.12953957630088553, 0.15791501384228468, 0.07478583545889705, 0.12796313589205965, 0.14980474981712177, 0.12643736932659522, 0.14076439663767815, 0.14064596471143886, 0.20258529810234904, 0.1103745773434639, 0.11577064404264092, 0.12277711924980395, 0.17444951488869265, 0.07419748304528184, 0.09787990522454493, 0.12122076135710813, 0.12447360204532743, 0.14557335030985996, 0.2267487210338004, 0.11730146463378333, 0.1760860247304663, 0.17119585041655228, 0.12762603757437319, 0.1803451360319741, 0.07568556335172616, 0.17537872830871493, 0.08571344791562296, 0.13565891043981537, 0.14064013143070042, 0.182143998099491, 0.1079447116353549, 0.20485963934333995, 0.10564582757069729, 0.12062411173246801, 0.24429598648566753, 0.1815828008693643, 0.19234504055930302, 0.1931252158829011, 0.09938458737451583, 0.09636334129027091, 0.1269323076121509, 0.22349210281390697, 0.2198055139160715, 0.1180125460086856, 0.11262301763053983, 0.12744143576128408, 0.10870126439840533, 0.08309504701173864, 0.1260031238780357, 0.16882295196410269, 0.2080411373754032, 0.08314091173815541, 0.19071734743192792, 0.15164909069426358, 0.09090795472729951, 0.095419307181146, 0.14670019765617326, 0.11766050083679147], [0.048048562748590484, 0.06534221407491714, 0.012969878553121816, 0.05383678028010763, 0.11999971320619807, 0.019642903098429088, 0.059484642843017355, 0.025814295186137315, 0.09315160816186108, 0.0337589508126257, 0.03177370577759575, 0.021378582423494663, 0.007930979700176977, 0.008971136776381172, 0.03554633556632325, 0.03196182537067216, 0.07253453790326603, 0.035180642298655584, 0.07634073132066987, 0.04052298121678177, 0.04796635505044833, 0.026135903026442975, 0.036536512707243674, 0.02070600923616439, 0.048466132138855755, 0.021342044638004154, 0.06915312755154446, 0.056751932643237524, 0.04231129365507513, 0.026753219608508516, 0.016368169053748716, 0.05802286796097178, 0.05648559810651932, 0.03196761412255, 0.019382262689759955, 0.05044737699790858, 0.031250450847437605, 0.015335803600464715, 0.023520559770986438, 0.07631583226611838, 0.011767283904191572, 0.06883986701723188, 0.029972587581141852, 0.045470501281670295, 0.020093344064662233, 0.043223181637586094, 0.029922234716650564, 0.05006322651752271, 0.10341769244405441, 0.08412863608100452, 0.038912431700737216, 0.05333015687938314, 0.02089037912810454, 0.010743194325186778, 0.009371262913191458, 0.02729631214606343, 0.057901482286979444, 0.05750715696194675, 0.06676882971078157, 0.06016403451212682, 0.08065652044024318, 0.027035026068915613, 0.009969502589228796, 0.015615328884450719, 0.0265384550584713, 0.0458904752304079, 0.020696429965028074, 0.05589193933701608, 0.02940649959782604, 0.017042165309248958, 0.08060537904384546, 0.07929645318654366, 0.04762185752042569, 0.07152547681471333, 0.018511187263356987, 0.016367792413802817, 0.026704885385697708, 0.11960236734012142, 0.06121139784227125, 0.03366992648807354, 0.07304668659344316, 0.030633000678790268, 0.016221585610765032, 0.0362846240750514, 0.03724463291291613, 0.056582162651466206, 0.03556188727088738, 0.00846077295136638, 0.021113312868692447, 0.02940895425126655, 0.021297497223713435, 0.04139178752666339, 0.022594776928599458, 0.05546125990804285, 0.076200740004424, 0.008969171012722654, 0.08611255267169327, 0.04566715928376652, 0.024775776400929317, 0.010582773538772017, 0.026228302267554682, 0.03305924285086803, 0.07630435124156065, 0.034447225989424624, 0.047118659131228924, 0.037759586921310984, 0.029089552444929723, 0.02626657296787016, 0.030050166133150924, 0.09182368332403712, 0.0741459705750458, 0.05085993689135648, 0.013029896963416832, 0.02654041803907603, 0.04199179536954034, 0.045417070359690115, 0.04734470618132036, 0.03596851740439888, 0.02435147387586767, 0.052042938841623254, 0.03671920349006541, 0.07072898166370578, 0.01662169597693719, 0.04256396525306627, 0.10797926603117958, 0.027944960347667802, 0.02063919739157427, 0.0073151195829268545, 0.027879738554474898, 0.046017883432796225, 0.028165149997221306, 0.007093496660672827, 0.01749355436913902, 0.00399718465814658, 0.05087698402348906, 0.06999931691098027, 0.01825176954298513, 0.02405914376140572, 0.039055269153323025, 0.09738159758853726, 0.07806672190781683, 0.06047757706255652, 0.027194515459996182, 0.05564687475271057, 0.05198687700612936, 0.053100948280189186, 0.051658973898156546, 0.011691027302731527, 0.06797285299398936, 0.04555054190859664, 0.01769038677593926, 0.017093471833504736, 0.06577373584150337, 0.08469870197586715, 0.041671258077258244, 0.04031409262097441, 0.029867469784221612, 0.03245039231842384, 0.024854957991919946, 0.04901412656181492, 0.10369661380536854, 0.01708095551293809, 0.03261291152739432, 0.01959887333214283, 0.037042457042844035, 0.017974232287087943, 0.06629968847846612, 0.04870154138188809, 0.025882561640173662, 0.03460057225311175, 0.011101911404693965, 0.0299478777742479, 0.009308569988206727, 0.02048782152996864, 0.054246490326477215, 0.049592649229452945, 0.03621164498326834, 0.02638644651597133, 0.026457798448973335, 0.06009889249980915, 0.09247565263649449, 0.015794368300703354, 0.053811272664461285, 0.027567262841330376, 0.07230970426462591, 0.03903625161910895, 0.011425101874920074, 0.07382681738818064, 0.029177988617448136, 0.03031631884368835, 0.013015285003348254, 0.016833187655720394, 0.042852493716054596, 0.0537704137241235, 0.03737498373084236, 0.05268102999252733, 0.0432694582559634, 0.0416108695208095, 0.04330078430939466, 0.022982480440987274, 0.006714731389365625, 0.030910276327631436, 0.06180234035127796, 0.042603755500749685, 0.023441456105501857, 0.0637732470931951, 0.04274094520951621, 0.026251587150909472, 0.029629618875333108, 0.03205884633644018, 0.026301645011699293, 0.03692574689921457, 0.06422171209123917, 0.02775351778836921, 0.0743826711550355, 0.035665539326146245, 0.04269642748113256, 0.05539094883715734, 0.026210717078356538, 0.014455849304795265, 0.0120294967382506, 0.07717566972132772, 0.02598954593850067, 0.031369613789138384, 0.09592625341610983, 0.12683188018854707, 0.07775372112519108, 0.06852754901046865, 0.029181426616560202, 0.06571131380042061, 0.03329567254695576, 0.06296375693636946, 0.042253996143699624, 0.025823564610618632, 0.047553179174428806, 0.0733200047397986, 0.03870928361720871, 0.03546551939507481, 0.03185839967045467, 0.0490247095876839, 0.020134954429522622, 0.06548732621013187, 0.01456371026506531, 0.08128750181640498, 0.027161217149114236, 0.0740141503047198, 0.006961771941860206, 0.05774507095338777, 0.07184301954112016, 0.01630850965739228, 0.044348837836878374, 0.016711980097170454, 0.03524346509948373, 0.05414742845459841, 0.06760762727935798, 0.0415191994397901, 0.025812150379351806, 0.018607056044857018, 0.06258829700527713, 0.029349931246542837, 0.03522858132782858, 0.0732108719239477, 0.03019351566763362, 0.020907977304887027, 0.021232991603028495, 0.02276513692777371, 0.09314607174019329, 0.03157456529152114, 0.06811536019085906, 0.06747798150172457, 0.029172305621614214, 0.0521150347776711, 0.04881981003563851, 0.04502663759922143, 0.03228962828870863, 0.012789302891178522, 0.051465629585436545, 0.0152948184950219, 0.046628129202872515, 0.05441724366392009, 0.03992690304585267, 0.05437978747067973, 0.05858375719981268, 0.06415182404452935, 0.03320615469419863, 0.04084273554326501, 0.037123922593309544, 0.05595968628767878, 0.04446817147254478, 0.013202458358136937, 0.03390242280147504, 0.03577077586669475, 0.019953258124587592, 0.029205585378804244, 0.011522636777954176, 0.05969186902802903, 0.06548495875904337, 0.02379912490141578, 0.02337465910386527, 0.04603664863680024, 0.10198107265750878, 0.049608334520598873, 0.03652421532024164, 0.038014603705960326, 0.06832069761003368, 0.021567039693763945, 0.05981408219668083, 0.026501716893108096, 0.021059043319837656, 0.01617621812329162, 0.019961356811109, 0.035846419268636964, 0.010961582411255222, 0.10109474053024314, 0.010187445386691252, 0.035425948080956005, 0.03720588909345679, 0.041886670151143335, 0.017328949725197162, 0.01799590670998441, 0.04508259553404059, 0.030590434798796196, 0.0346663599339081, 0.004805343123734929, 0.02639948419528082, 0.029199765085650142, 0.042025915608974174, 0.032256094345939346, 0.05527389730559662, 0.027644390538625885, 0.04398069919261616, 0.02254865616123425, 0.02712588906433666, 0.0702239279053174, 0.06812498584622517, 0.0469540025369497, 0.07802734355209395, 0.03899257993907668, 0.04610582793247886, 0.007787110662320629, 0.1065963480505161, 0.03641603616415523, 0.05599704971245956, 0.05094236352306325, 0.038325734276440926, 0.009736898664414184, 0.10461597892572172, 0.018610256556712557, 0.0904152577277273, 0.020017229398945346, 0.02027410526352469, 0.057530987323843874, 0.1386288518551737, 0.09329394466476515, 0.10703293868573382, 0.1709597435547039, 0.22332465945510194, 0.1430915342643857, 0.16851616295753047, 0.06788396596675739, 0.2083795121870935, 0.1076338259736076, 0.12374753670883365, 0.12069718359271064, 0.18644967174623162, 0.15329247282352298, 0.10892599413637072, 0.23436366085661575, 0.11682313561323099, 0.2411149931140244, 0.14863049407722428, 0.139733390242327, 0.1247648207936436, 0.15855781763093546, 0.1585003308719024, 0.12837545829825103, 0.09600491364835761, 0.09613248883397318, 0.1299609974375926, 0.18106512317899615, 0.24283261969685555, 0.08722683545784093, 0.10872977029066533, 0.13566431327490136, 0.1519639542675577, 0.1338519886485301, 0.1203417764918413, 0.1719570267596282, 0.13400104158790782, 0.06677921235677786, 0.18275189126143232, 0.26383216318208724, 0.10864188516279683, 0.1641910450416617, 0.14242297795135528, 0.129846484051086, 0.21389654895756394, 0.12474769202526659, 0.12198458716738969, 0.17044688982423395, 0.16174682619748637, 0.14990477648098022, 0.13478903914801776, 0.1578015394625254, 0.12858936010161415, 0.14748452900676057, 0.1365206329501234, 0.12180797828477807, 0.09053907022462226, 0.15286011243006214, 0.1949372881790623, 0.2569722250336781, 0.2227913966635242, 0.1100573834264651, 0.10512244276469573, 0.11900110155693255, 0.1635850963066332, 0.13192636775784194, 0.13806714996462688, 0.22962032788200304, 0.24203288136050105, 0.16675157326972112, 0.15477868291782215, 0.13562207022914663, 0.2848440263187513, 0.11650920714600943, 0.1629879346000962, 0.05552032002015039, 0.09421293128980324, 0.17589296243386343, 0.17474303429480642, 0.1437805441673845, 0.21620369312586263, 0.07473787787603214, 0.10903539412538521, 0.1570755706052296, 0.089397476403974, 0.1608065696200356, 0.07977798086358234, 0.10296672640834004, 0.08973718708148226, 0.05339701325283386, 0.11008254223270342, 0.10966282803565264, 0.1865619290038012, 0.16854325134772807, 0.13897439581342041, 0.12124441360356286, 0.19913745811209083, 0.14522975077852607, 0.07805286601069383, 0.14260098949307576, 0.11093084671301767, 0.11577250683330931, 0.11099218521849252, 0.18849629239412025, 0.09670019469922408, 0.1385009501245804, 0.11772919402574189, 0.15301213396014646, 0.15182781469775364, 0.19710107910213992, 0.19969026907347143, 0.14501970814308152, 0.12496505223680288, 0.06908852359629236, 0.1406870796927251, 0.1368859625654295, 0.15107309503946453, 0.09906252496875823, 0.15201060567051172, 0.17575324571225792, 0.12030812751618214, 0.2353201704681851, 0.10137608129298314, 0.10410141083411872, 0.12809085950721055, 0.14473424846073613, 0.12682110420428216, 0.09444408802664839, 0.1424367373692803, 0.07935871195513755, 0.09929326610290445, 0.05811708360852208, 0.0818337373493705, 0.09529608098091558, 0.2519242255948484, 0.15380897792056203, 0.06829748323070817, 0.16713603545213118, 0.08934350000345148, 0.2123129542451352, 0.16264883248368278, 0.15400149102788419, 0.19830847915727645, 0.12856809014920145, 0.10107482870807871, 0.11470951387309469, 0.10067405411973596, 0.14660425280453637, 0.1412444029119797, 0.16051725076977164, 0.10364980655140243, 0.12210738292196766, 0.10908752257819287, 0.30242636566981673, 0.10066919305245392, 0.11381703676306643, 0.08788570674369112, 0.13208036340074614, 0.0920539940125309, 0.22493553551612422, 0.13680511299753562, 0.10244270335533656, 0.15706905454862863, 0.17814892809838057, 0.18150094198063016, 0.07473048608517274, 0.21049163478892297, 0.11872400587890297, 0.1744696419336833, 0.1524540685932152, 0.13840645988238975, 0.14229629334295169, 0.20610497798770666, 0.14258864015573636, 0.16266366059426218, 0.1456466448144056], [0.01317789790846291, 0.021974072442390025, 0.07082997311954387, 0.05899180854612496, 0.03784402477322146, 0.02705180973862298, 0.012370291879051365, 0.026114328793482855, 0.02255990340927383, 0.12312957260292023, 0.011521546748554101, 0.08248730970080942, 0.024932497581175994, 0.03194665216142312, 0.07795046447427012, 0.027916190992982592, 0.022063354663259815, 0.007279749752342468, 0.01780589092959417, 0.06499212817288935, 0.04988963817595504, 0.029611002100864425, 0.021090003865538165, 0.09022861500852741, 0.03747236463823356, 0.0215321698851767, 0.00608923773143033, 0.08644110144814476, 0.0821705833368469, 0.08004685354535468, 0.05263887229375541, 0.043543425781535916, 0.009642535515013151, 0.043688786536222324, 0.05440553999505937, 0.06767816841602325, 0.010367775212216657, 0.06955214324989356, 0.07629454004927538, 0.01306836247749743, 0.027478865631564986, 0.05313120564096607, 0.06040471671440173, 0.01628519137739204, 0.05020072421757504, 0.03141926717944443, 0.020393014019646216, 0.02344618729694048, 0.011575627049751347, 0.03926023178792093, 0.06976581498747692, 0.07628956765984185, 0.04549724828393664, 0.06392063020030037, 0.06335844591376372, 0.04887118891929276, 0.049913316397578456, 0.016080135974334553, 0.04738239244034048, 0.05622685574053321, 0.06352696538669989, 0.00831599478260614, 0.021866969400434755, 0.018994223355548456, 0.03782420571951661, 0.01975132716324879, 0.03166411283018533, 0.024026507817325182, 0.05902436656469945, 0.046873698447598144, 0.041623968427302316, 0.03950941900257021, 0.060714051287504844, 0.03499556551105343, 0.035811775815091096, 0.0451289166812785, 0.021577123625320382, 0.060864351034979336, 0.049374483787687495, 0.031161860679276288, 0.025709524343255907, 0.03210972798115108, 0.0468245756928809, 0.04573371879814658, 0.04421618636115454, 0.03431900142459199, 0.05423856790002901, 0.014661239601991838, 0.041247458357247524, 0.07001700971159153, 0.04871671088039875, 0.05354379893105943, 0.0301542133820476, 0.03035514244402293, 0.051306654131622054, 0.0659185808035545, 0.007864588096708758, 0.03802227751293685, 0.008897731877368642, 0.033712262302287854, 0.032549138777540065, 0.022174608166096732, 0.08152466994943097, 0.028055570037395228, 0.05289729182550218, 0.006696850268781418, 0.04866320945438929, 0.06355930076097138, 0.03011182190675754, 0.018524236074881628, 0.03916528141417075, 0.017934998650162015, 0.04764287514262833, 0.03786255620070733, 0.013499630058504408, 0.034278877210454084, 0.04956047341693193, 0.022097495311754756, 0.022798090139986016, 0.03546179010299966, 0.045065073427394964, 0.012771114706993103, 0.045397481371765025, 0.008101207968138624, 0.0787236932956148, 0.03969773155404255, 0.043412095328676514, 0.036579857842298225, 0.016106233597383834, 0.03710934310220182, 0.09037589421495795, 0.033113790705101565, 0.02602406693767989, 0.0702796335099265, 0.01989236490771873, 0.01484053413150832, 0.03284471393271815, 0.013506834457075456, 0.03118687105597928, 0.026727882686827797, 0.041174071084242314, 0.0341216049855575, 0.05256689510133583, 0.0644860057218466, 0.05872304718650412, 0.03507877881929744, 0.05768967334006447, 0.013758080203842837, 0.018142770313716028, 0.008532230640412308, 0.04323710432799999, 0.01941116563102696, 0.03016117843799293, 0.03308734427264426, 0.031222883771988563, 0.05067589539976325, 0.03880788906826638, 0.014512288707919652, 0.02531009118683869, 0.032340394900529645, 0.029346393057494424, 0.03848508822557051, 0.005875844763068017, 0.013335085714061279, 0.04918961851217318, 0.0945044394757133, 0.013614641611638945, 0.050370278986520134, 0.011576878496271092, 0.06083504362322856, 0.01746695394103881, 0.06302706213318743, 0.01725696140056243, 0.019001301589014474, 0.05155607883352786, 0.05830691385199316, 0.052974772042944096, 0.048614995830575936, 0.025631750977481715, 0.05259313002170529, 0.07119534726371057, 0.031970371201168746, 0.02310540421603946, 0.04099218553164974, 0.02893876844609622, 0.026169997290708125, 0.06351810414344072, 0.040926323636085726, 0.025762897748791147, 0.03253399896493647, 0.03138001869956497, 0.012340467746980721, 0.021525115771510173, 0.06984597435803153, 0.04666043118049856, 0.013842177595506655, 0.0456573814881267, 0.07368249192950316, 0.009238298807758838, 0.04820327456400264, 0.04806105680472683, 0.040764836012385786, 0.027477568728500046, 0.0647684077557642, 0.05224178989010397, 0.013398466053331504, 0.04320619387726765, 0.06066196736355778, 0.02868617477361113, 0.10140777099877596, 0.03968699267716147, 0.04837013904761989, 0.030900908568582963, 0.03315111331176013, 0.05254615949525032, 0.09955024957889691, 0.030909116721886676, 0.02909445989644155, 0.04360938415629789, 0.07480850807041861, 0.03494824246445205, 0.012051551511831349, 0.04848421456699725, 0.022691000085615087, 0.045361297961790115, 0.012627624164451845, 0.0757175350736361, 0.05299927775922697, 0.059061418287456036, 0.039716055180178955, 0.003719196779456979, 0.026631709624780342, 0.022309706873784307, 0.029512986657209694, 0.009877442880679155, 0.04737316754471976, 0.07003506616456434, 0.02456845930282725, 0.021514161671802867, 0.06931697149411775, 0.051580065046437085, 0.07352817716309801, 0.010655579153535655, 0.01947419994394295, 0.03904473065631464, 0.040716384901315905, 0.022069046935939696, 0.07002046069828793, 0.015307709600165254, 0.035556944567360915, 0.04772370244609192, 0.01346038528936333, 0.03237141667341348, 0.07047219114610925, 0.01779722821083851, 0.058537239383440465, 0.02395680345216533, 0.03827276348602027, 0.02754553461272735, 0.05007229185139295, 0.06316145765595138, 0.036247969401301816, 0.08761566146858968, 0.059960853031952865, 0.01980901801289292, 0.023311240729526617, 0.03291391178208869, 0.08942634594859555, 0.01968318501894828, 0.04696907184552401, 0.06618967992835678, 0.00959105922447634, 0.02944930110970745, 0.04556611216685269, 0.014245144302549306, 0.024266861619253177, 0.03383552932064049, 0.05344595047063194, 0.04014899815956596, 0.026068104125442915, 0.02863825429813005, 0.020290291504352354, 0.10272593659465201, 0.066805298847612, 0.07802985943271779, 0.017050128553819377, 0.025946679488697555, 0.04724769634776749, 0.028287307504797354, 0.03360062102728989, 0.023245278644026257, 0.060624600228038616, 0.01249006430953159, 0.06716279138345271, 0.020911806786898524, 0.09125267490162514, 0.011728664394468069, 0.007824529748177156, 0.02205948250775691, 0.05046600861533079, 0.026184938578808215, 0.047352157343993895, 0.01593513701664051, 0.02454251196468249, 0.06499596507637762, 0.01972221456526313, 0.09371124688186683, 0.027247558609815314, 0.0396963474486256, 0.013637164865940576, 0.06701028003590181, 0.009224775949405739, 0.03351459869008977, 0.021173968598304782, 0.006036042441337486, 0.04210790437355172, 0.055319450329989195, 0.021658665245922748, 0.02549309367168462, 0.07234801392769441, 0.032280010054819286, 0.05566353225731291, 0.04797129404323641, 0.013941697743575787, 0.02511911061446881, 0.046395206154556945, 0.062047430910752155, 0.025294546903751325, 0.04458638446521945, 0.023663439897063654, 0.03453449513472151, 0.02486876750481315, 0.08279559784568846, 0.014341379519464681, 0.030275357858045027, 0.020448610157473013, 0.03078635436395416, 0.03707593903527595, 0.022428558113460895, 0.025352005832246505, 0.02381542060902575, 0.09162768954411149, 0.019031727788387798, 0.017105312799685635, 0.04508841026108712, 0.07039439922664315, 0.012658716441364959, 0.030604374187532812, 0.026852962400880642, 0.04162344892392866, 0.09430365142179653, 0.03938579946407117, 0.1527968666050583, 0.11198390973731875, 0.19500751019222662, 0.17089979286538437, 0.19614621705841273, 0.0872008825535886, 0.0792761480261106, 0.09693698433693498, 0.20429379626875743, 0.19573763507651165, 0.14246568112866953, 0.19324633438372985, 0.09674649729277007, 0.1822486409218982, 0.1227480047964491, 0.1375071846996434, 0.08237077025114559, 0.09680719012976624, 0.05796582277980633, 0.28335260634776205, 0.10484464204637334, 0.15910761547274888, 0.08713995965081267, 0.15086127124959603, 0.12444917796528898, 0.10185889288550243, 0.08874545514117926, 0.16357993095880374, 0.22623476892476901, 0.1786418625852093, 0.15118293289560825, 0.1340696754050441, 0.12910574645502493, 0.15221125271636993, 0.1310633242246695, 0.13864823675248772, 0.06484399549663067, 0.15031257178634405, 0.1334897315246053, 0.15014889853773639, 0.12699203565716743, 0.19080401543760672, 0.11226845657802187, 0.17076534539228305, 0.12089694748283364, 0.1670626667328179, 0.22568031039554626, 0.17337774974294007, 0.11673163622617722, 0.07735045292065479, 0.1725084870122373, 0.17725208716001362, 0.12536226451629773, 0.21356688695959747, 0.13790464930934832, 0.18672956532100216, 0.10609867866151035, 0.12016942753689364, 0.06282215515966527, 0.19900045765098184, 0.1284255087375641, 0.10997582139680162, 0.11549739268957637, 0.19675655930768698, 0.1430005469592288, 0.14114418328972533, 0.10972336502163671, 0.09849295631283894, 0.14762633858481422, 0.13034783449256793, 0.11992244079010561, 0.13336043455637991, 0.12466011859942228, 0.14082884474191815, 0.09559269514284097, 0.12870181031757966, 0.07621536773513071, 0.2645758545259014, 0.12198172247735783, 0.14204537321347743, 0.06195388319611084, 0.11682052325340919, 0.1593337330268696, 0.1316867134300992, 0.16438284568721429, 0.12164962623501197, 0.1683080499060452, 0.18659299530554563, 0.11385697172954679, 0.1514308844343759, 0.14315274660475552, 0.12339630789938383, 0.11102342963567935, 0.10632408375386149, 0.1447045328677632, 0.13054845185251907, 0.1326333821634762, 0.13191585894674063, 0.0909902440616861, 0.14139971957774833, 0.1333245591376908, 0.1732307451311499, 0.1897199306404218, 0.17172770312754437, 0.1674096504575573, 0.10423438143334351, 0.15795494138728827, 0.17072356247808784, 0.14148472517263144, 0.08716953423572704, 0.15648679516743869, 0.12374410798656754, 0.13481787900673226, 0.10314816667232662, 0.13345900661079213, 0.17527996329590678, 0.1018749010108877, 0.20767736627021804, 0.09998393841669895, 0.16942986549111083, 0.08555596417863853, 0.09055323782376945, 0.14729243150213733, 0.10301052796421573, 0.1336046605138108, 0.18662600603420287, 0.20217604818753898, 0.0976430339505896, 0.09054731548530981, 0.12016909357043914, 0.15263259963830933, 0.13740629714448005, 0.17031336261425167, 0.11129268081276678, 0.20518808421911672, 0.11911753710592166, 0.07994565428816713, 0.07293880058568902, 0.11747189142624848, 0.13291524985106662, 0.17739328817697242, 0.16102467197924852, 0.13569048140197992, 0.1764690174604766, 0.21115533745614812, 0.08566951277316548, 0.22180331608979031, 0.18321163690416142, 0.1245266359183006, 0.1637479680357501, 0.17383283469825983, 0.13469429657561705, 0.13007764820940793, 0.16363581467885524, 0.13248720875708386, 0.16084517614217475, 0.212056660966482, 0.1518169793416746, 0.11234712423174642, 0.14529685577144846, 0.13517854793462902, 0.11263932261499576, 0.09096117413719185, 0.1235042087500915, 0.18154230929212645, 0.1665907201822847, 0.09843329506111331, 0.14595533371903002, 0.20024043798912317, 0.12688734830589965, 0.0820754622691311, 0.14183819526806474, 0.07735201885225251, 0.142919727077242, 0.24566725274780765, 0.17606543755391613], [0.016942322326940484, 0.032235102698905393, 0.04234743624692783, 0.01258094029253698, 0.0887030859303195, 0.04714453410997521, 0.07007779902778566, 0.06994349998421967, 0.04179640643997118, 0.08497556016664021, 0.013198832966736518, 0.06370121423969977, 0.05410153775301296, 0.01583598608704051, 0.03922600393707398, 0.07958492598845623, 0.03843932368909009, 0.020244526967871934, 0.0560635906731477, 0.023512882253271528, 0.022831004389445297, 0.05056209076428786, 0.0428641565667931, 0.08284407493192703, 0.022141328408906702, 0.07549233036115766, 0.04315962411055807, 0.005463566885737237, 0.02990664404933341, 0.026205702015431598, 0.03151653305394575, 0.010650188378349412, 0.02535336767323315, 0.022592325985897332, 0.04437222291016951, 0.05382757764891721, 0.06889470430905931, 0.07386149052763358, 0.02923305411968613, 0.007562863784187357, 0.013046203803241951, 0.03231371840229258, 0.07279377750819549, 0.05825076666951645, 0.013198473025113344, 0.018209346526418813, 0.040541538619436324, 0.09566283551976085, 0.01741215561196441, 0.011162034643348306, 0.034490203761379234, 0.023904719528218266, 0.03068392128625419, 0.03824440231255721, 0.04096208402188495, 0.020084796378796455, 0.023778034919814672, 0.025888059099088423, 0.03035914447536925, 0.03129888711555395, 0.024976484673970845, 0.1182471685751807, 0.052667359632323496, 0.03190107316186186, 0.05503826912899967, 0.05665542747010477, 0.00858475614222698, 0.029038466709607746, 0.0287043295611511, 0.024335458329005633, 0.06401190694305114, 0.008066606260399567, 0.017815607498050667, 0.03721526612935122, 0.014895120948494878, 0.03611389300203882, 0.017259952255699318, 0.03283533689682372, 0.050291971274418756, 0.0053352592931332765, 0.025127368862740695, 0.03401022717298474, 0.016188367080758326, 0.03416992251004558, 0.038102095495560206, 0.06783844262827188, 0.02765087876468897, 0.021589729003608227, 0.04224343167152256, 0.03336165318614803, 0.009688183163234498, 0.016887228994164616, 0.011103634114988381, 0.022700892914144788, 0.014483256818493828, 0.035938571745646186, 0.04681537306169048, 0.060092524872743525, 0.04431113302416634, 0.04249367644661106, 0.02810664092976367, 0.06094304466387257, 0.02005570975597948, 0.03632763895438984, 0.09260007369448431, 0.02569413962191902, 0.023568053511553444, 0.03801919760007877, 0.02541157246014336, 0.014034068226465024, 0.09397073881700635, 0.04503023701545317, 0.05005556013202295, 0.08856173648382537, 0.021636786732415203, 0.036974980976083316, 0.02994059173943242, 0.024170977994799614, 0.04034516263345722, 0.06644522363785654, 0.01784793730621459, 0.009818985763558885, 0.029918078689661343, 0.009223611705238, 0.04032560704217758, 0.05981612310279161, 0.04912679942208342, 0.021030665448051877, 0.03495542645396199, 0.028979881572013255, 0.026512752629059833, 0.04648424903280102, 0.027201641933061182, 0.07289576344192028, 0.02826424712111475, 0.05937220004852861, 0.058432570585864596, 0.060171801087562926, 0.05271875335893128, 0.02509776830265764, 0.0245288323276327, 0.03110286736045964, 0.01132721537942416, 0.09234464872861281, 0.010791090680868365, 0.04909663482976612, 0.02176642508857185, 0.03799129284743685, 0.019395185336179566, 0.023049498231557664, 0.03816113334323745, 0.06134806804766413, 0.012106903668609448, 0.03673927116324194, 0.011955667887377786, 0.03793419942667242, 0.03719147658557631, 0.031249612220562994, 0.03729792282683775, 0.0015884603021731891, 0.023189684361568652, 0.00949126169871306, 0.012329586934356485, 0.05060382543888409, 0.03526260508806445, 0.03419653592573013, 0.023679423902649432, 0.050143760672654025, 0.057006500428542495, 0.023584475384268444, 0.0537840915058041, 0.02197728037572233, 0.019727170256373938, 0.03439981759584043, 0.026314387687307317, 0.053789423836860806, 0.05312771383614745, 0.03980097913881764, 0.026953770175168756, 0.053919533456792124, 0.012998698930459796, 0.051486791926436126, 0.022447137780545745, 0.05135371000505984, 0.0491258309193654, 0.07836061238776892, 0.040671388487680815, 0.020432028723007534, 0.021980558813083917, 0.0516428062110208, 0.0789750661351718, 0.031212823960231617, 0.0080704719221103, 0.04536325352091808, 0.06497628331999294, 0.0030151460941851838, 0.03368613499333151, 0.040142047946574166, 0.05728191143134609, 0.02268084565002937, 0.021720988952438347, 0.024893334448279347, 0.05155657236173283, 0.0399523253145162, 0.013670415864908136, 0.054793965246062726, 0.02562768400821369, 0.01037884712786763, 0.034434524131938815, 0.0327888858737424, 0.015602671555825509, 0.03982427886512596, 0.05300660275679547, 0.07442884016199969, 0.034444736083969474, 0.023017021849227604, 0.0347672808857169, 0.027269572565273847, 0.0846114254090935, 0.04170621694356669, 0.02865041809855029, 0.0767390345572494, 0.12304745396249928, 0.08775505164521746, 0.030316098054754548, 0.06486343976575881, 0.0180006230584695, 0.0313002489565406, 0.0511531594383996, 0.025015907558554318, 0.10348014417104423, 0.08934468743973412, 0.04304114765545819, 0.04852006401051767, 0.06406234329915605, 0.050427097812644206, 0.007173320673246053, 0.07906936341896653, 0.005342883468983928, 0.06914359095389955, 0.0402146559645189, 0.05965380056295544, 0.0016337554302481294, 0.029194527378422208, 0.05546420252358075, 0.042186223217868246, 0.013470068461174378, 0.11635993156232871, 0.022929248043510597, 0.07819882419425994, 0.028237793267180678, 0.020400274079293013, 0.017326302113360725, 0.025849996200122405, 0.012754167764796875, 0.05731595374527387, 0.02372798633587081, 0.03646533703431487, 0.047623764839954674, 0.01185747432828066, 0.026933377812383696, 0.041980024907388724, 0.02023855638981331, 0.021931233823124785, 0.03219339399947785, 0.04546201853372622, 0.039570119261043146, 0.049793095895438455, 0.054579035568167455, 0.03089862275373889, 0.007288418501048, 0.039272414142033085, 0.038521601891261525, 0.015096920178621076, 0.040173763627535664, 0.04446704711881466, 0.01623083277081605, 0.10491939858184196, 0.056445165901095606, 0.05317140035913326, 0.06009289594658185, 0.026280465972376987, 0.03868901927489787, 0.04425994338816963, 0.05389889804064296, 0.03240949255996384, 0.08718600249267183, 0.03259550816437695, 0.09421912822290324, 0.08698051664396189, 0.034587503032526, 0.03368431302078534, 0.025116474134847522, 0.05098535984870978, 0.06839566936832853, 0.02529090295865899, 0.03592394772567786, 0.014237478844734142, 0.04283362090063747, 0.06314579091849737, 0.02843740501702996, 0.04239970941853244, 0.008786883772700094, 0.02355939635890536, 0.02004323610890424, 0.023773780558258295, 0.06440874814870767, 0.060097378518548794, 0.024513748176104855, 0.07894600363215432, 0.03896016292856075, 0.019722505858226214, 0.04105685256945435, 0.03826542364549823, 0.0014843389544694219, 0.04530309131951071, 0.04840616289584432, 0.020374016894493252, 0.02881194097426487, 0.01486201559600886, 0.06166656814457383, 0.033811940156738274, 0.018872741202358156, 0.04895745245448779, 0.01989765642065322, 0.057604445100878365, 0.10210046195425093, 0.10089294315548614, 0.05069455299235415, 0.020976243758923374, 0.06161633958981838, 0.04921361956803594, 0.059937809346592985, 0.03948763696826063, 0.03856313989672344, 0.06308570664259605, 0.03886293416144326, 0.024132636790454853, 0.008130310361593729, 0.05150582430360373, 0.04585101894917898, 0.03366465352883097, 0.019719626325240824, 0.0662772310897708, 0.031697639351477847, 0.007407802231682581, 0.06274463041336276, 0.028924131438543554, 0.06946047316887416, 0.0470031141594518, 0.030011079070391133, 0.03154716148856096, 0.1466702445759438, 0.16379607404815033, 0.145361096074339, 0.20042578194988891, 0.1661251561017707, 0.16253388865152374, 0.19876052130712196, 0.10709596928791143, 0.17185276985401288, 0.20509948662947863, 0.08357673796126619, 0.08342971850652248, 0.14729400485521182, 0.12330010329606012, 0.138950097898487, 0.17062626691767946, 0.1702220636070706, 0.18351382459513843, 0.2045188599731773, 0.11437097578891553, 0.08333266043337062, 0.1737569278338924, 0.13169260608265176, 0.17242484696907923, 0.07814105541910976, 0.17189682374009863, 0.14215761562809348, 0.08609716795035638, 0.1454291955451481, 0.10975898811011575, 0.10386290683527477, 0.12807666964363307, 0.171394256176427, 0.10282169590936974, 0.09885511695756577, 0.11830792820546776, 0.15561020001769066, 0.22003087447956204, 0.1510598254390061, 0.08956334640970454, 0.13605495012598112, 0.10948979630484246, 0.2538679103599861, 0.17688313586404547, 0.12596169719472528, 0.19362203922355548, 0.181927899539005, 0.26184071379248053, 0.17810803576139733, 0.13914137904066592, 0.17927881825016811, 0.11391385734896176, 0.1158299861708656, 0.1251472346484661, 0.26837553188670427, 0.18568328552646562, 0.1038136356510222, 0.17932242684764788, 0.15678608848247677, 0.15350512781878933, 0.07879903612774797, 0.15377369622001424, 0.17075921525247395, 0.21883125213207677, 0.10765968982013874, 0.13783977075945586, 0.08852951985318214, 0.08421273625572212, 0.1423779147444293, 0.18572048196801916, 0.21024862595368177, 0.19977741205366328, 0.07939944101963192, 0.14465485350228846, 0.1403971077525057, 0.0786241193418391, 0.18285864178324118, 0.14755541895283386, 0.12684589193668216, 0.13130772829754278, 0.12443130704923533, 0.1749493958777748, 0.0890675991831813, 0.11067726227338426, 0.10790743355755694, 0.1650742898345925, 0.09492090306594037, 0.16857894865097478, 0.15826941904379055, 0.10498731993720867, 0.15737815905595198, 0.12356668274151161, 0.12328984681516886, 0.07930555933853611, 0.16529907152289525, 0.12494271359173581, 0.18007762148045003, 0.12966203066753224, 0.1154367666458711, 0.09308081469498575, 0.10926839880994521, 0.26449056691490114, 0.1699690951500088, 0.22708761534886435, 0.12054150327458046, 0.14724263339303434, 0.084550806786865, 0.1165288221091032, 0.13266688270960003, 0.14296639332314953, 0.13081537268590182, 0.12599926471011713, 0.16534530732315034, 0.17120998090831563, 0.141057723085396, 0.11914544185856357, 0.13497223088052124, 0.1247499481542036, 0.17083728918805718, 0.19868758303346112, 0.1326936445548199, 0.11296861353912391, 0.10843799493159167, 0.12996044824831188, 0.1641802245285362, 0.09246730347513221, 0.15857669786782935, 0.15658683667425066, 0.19958825345383957, 0.10761864163214341, 0.15541008731815964, 0.1292602319153957, 0.12633223668672144, 0.22317847120575607, 0.13522603054298088, 0.1080711735994555, 0.14613845123676583, 0.1306244477746077, 0.18776987824821845, 0.1417602549190633, 0.094830598536646, 0.11300457059405744, 0.10775397226097994, 0.14803668687818572, 0.1481047269771807, 0.17541852226713672, 0.09829500326304697, 0.19295835139928386, 0.14928811113350093, 0.1882113076862879, 0.16222193429712206, 0.18881385738495737, 0.08693029551068321, 0.17626152781303972, 0.18883537966758013, 0.18624896532855928, 0.1977802481269464, 0.19479481066809967, 0.11259033344686031, 0.13388436113018543, 0.14585713273845613, 0.12644017464481294, 0.07332347799092531, 0.14047708158614114, 0.09148937548161484, 0.10650678566889837, 0.12498667842010036, 0.1301277134916745, 0.08648384915431961, 0.13024679850786924, 0.16839032439747825, 0.09564484586007893, 0.13766968535492197, 0.18061244278214872, 0.10620149580063298, 0.134917133837007], [0.061775615613441914, 0.12202922735013999, 0.0043019258009735495, 0.02283254434587434, 0.03702368812810164, 0.049028075227397494, 0.008285621461254777, 0.024707001575734466, 0.07983764211530797, 0.01991257544432301, 0.032191048812819645, 0.05055819077824708, 0.033147851572721265, 0.049649293650873005, 0.009772917874215636, 0.054089882323751226, 0.008851039656292414, 0.05571261419390794, 0.04024926231068093, 0.06892908058944158, 0.05217717851337511, 0.054618465874227695, 0.062413083360297605, 0.024986477692436893, 0.037637143686879426, 0.027029326374758966, 0.011283501025900478, 0.021286804731062148, 0.06120336409367155, 0.023648639617022127, 0.010643698296917137, 0.03782931911700871, 0.02444704579829704, 0.04342058178735897, 0.03908507009327877, 0.05877575451449957, 0.05349702507373877, 0.025928940303856507, 0.02190848514146637, 0.01620345123228617, 0.03086533000896452, 0.027923352718062233, 0.009768204308784334, 0.02934605723567074, 0.04715090173704084, 0.08054686812101863, 0.058553247508825734, 0.06020702712703496, 0.05884085570869502, 0.026456097075424623, 0.031391325319418684, 0.03403922288271133, 0.08362497013877146, 0.02950490095827263, 0.006216754472916364, 0.018346176293562166, 0.030434331456490327, 0.023906413480290212, 0.012452669343474554, 0.01377947446599137, 0.05359753042284865, 0.008033101075852755, 0.07042772165732458, 0.096527096175123, 0.042032780474983156, 0.06438594195060432, 0.022839103075966705, 0.04722264886368066, 0.03646837612905074, 0.04160084681643639, 0.03825136365776416, 0.012809891923097894, 0.061984107160242274, 0.012125503744755406, 0.0526695712323999, 0.04499637652770616, 0.014881354109093081, 0.0628149117983412, 0.017474395826866385, 0.06721584752085619, 0.033576000278117135, 0.0624924931616988, 0.041354034474352375, 0.02400690584181575, 0.033476667522336356, 0.012342658010311425, 0.07140032103052363, 0.0328694014751818, 0.003758034758902795, 0.041824025465757586, 0.02806249427521834, 0.028192056561238132, 0.012982673179067206, 0.01576825583470054, 0.05564316030358896, 0.026333249370509293, 0.054612944295513444, 0.030036352909519337, 0.07307505889912136, 0.020896281057503074, 0.01335740766080562, 0.03788243091548793, 0.024658580150571652, 0.021355434837460052, 0.09773798432433978, 0.0627901240659412, 0.007703235451117507, 0.10683880769647658, 0.08220305971917696, 0.07629362720763311, 0.023398580378852785, 0.031735325610497966, 0.030636429401056375, 0.03112469206826063, 0.04516012399108149, 0.06500176124973223, 0.06688642301014625, 0.07194266770966351, 0.04616306607204024, 0.047319680961663835, 0.02495649863703875, 0.033712607400957495, 0.031442934268852696, 0.03088598768954398, 0.01786512915714411, 0.0346229814022081, 0.03650637409009505, 0.02934458592790179, 0.054510824775206856, 0.025137708835245576, 0.024989134581119288, 0.026531369403528515, 0.009965701865439769, 0.05178671606699936, 0.0403366910177283, 0.02162666012736736, 0.01963853184861364, 0.04259615590854082, 0.038087805442046374, 0.05192316362808924, 0.07218565428047441, 0.05391669103119057, 0.05042278593464289, 0.03159370528010186, 0.023963723979250062, 0.12263990356586874, 0.07123740477254614, 0.01693430898740189, 0.02521907790651312, 0.03295661495940294, 0.02474178974807728, 0.06934975215699524, 0.06049366682418622, 0.017304770553892013, 0.013200180892454227, 0.05076480840216391, 0.04072058174642734, 0.028447921249608044, 0.018807129781635012, 0.02564239337516483, 0.02322442986042006, 0.06082498010073323, 0.04131919806241058, 0.03053449541766895, 0.03416170322452672, 0.021790073624288198, 0.04167370716459118, 0.016896927008929197, 0.035095744315185584, 0.0367313338938402, 0.04539703608315904, 0.056760723382467404, 0.03865653547109105, 0.06862540860311128, 0.08643783599836752, 0.023934223609103356, 0.07240104780066758, 0.01975104143639328, 0.03006108498084359, 0.0514054636732908, 0.03156764847517479, 0.012107930615457008, 0.02406380259344587, 0.10077594357426278, 0.037582978038699366, 0.05978414024866652, 0.020558845062623732, 0.018385281910013873, 0.08830843406030908, 0.024577563599450514, 0.06254669962800108, 0.04521472379565239, 0.0033446457473473856, 0.06799626775318757, 0.02639159887621645, 0.040856628547771834, 0.01724226873193402, 0.0772148476971779, 0.1294447891996242, 0.020795773853024002, 0.05551148104132153, 0.009555335018376354, 0.06340883774100803, 0.01823483187763486, 0.07084042998030782, 0.028256000005058013, 0.04885457223281264, 0.05557475655223243, 0.05240848367975559, 0.08360800464288332, 0.030964822326495778, 0.031385484617203474, 0.04029785071907099, 0.00867259766891948, 0.040562986687291414, 0.051037158045801334, 0.05049835512181744, 0.03874630194331985, 0.009230406994902296, 0.07366432415437885, 0.011255131503276061, 0.04937997568049468, 0.006015791086610989, 0.01511418902737205, 0.11553392119822092, 0.02503533884009812, 0.024443312795483507, 0.04000214939878788, 0.029780107870465145, 0.03198001912096515, 0.01245013398147421, 0.03783232481509913, 0.054387665368267335, 0.032523902045795694, 0.04110832422156818, 0.026211561271338724, 0.029679912368010264, 0.017259629421459977, 0.10857057961402461, 0.03964822659327183, 0.06677642188151367, 0.012263729677215451, 0.04765304256579839, 0.03626448960858397, 0.011800167540059192, 0.04555356987111736, 0.01257808302398189, 0.00788877097875229, 0.042702665232354775, 0.02961337326269131, 0.06289947210461833, 0.032402330834884197, 0.07233644384541549, 0.037413824029499665, 0.03826455162197817, 0.03978244400059339, 0.026361083619121928, 0.05108080746140331, 0.021093822215334512, 0.04623380387783982, 0.04164598052739166, 0.012701658033620333, 0.059295718019711785, 0.05083465192001313, 0.06491550142527558, 0.035589020189945586, 0.036666418236563914, 0.025537646652082913, 0.014099054387770593, 0.008559714224247728, 0.054754623997723684, 0.02454706689604791, 0.025113140036410186, 0.017698977135296445, 0.055551249024574645, 0.0773016270250082, 0.02068878398858942, 0.11938902956899256, 0.06367521680658683, 0.05038963790866546, 0.11014842268195935, 0.03342921831062995, 0.016920438247325365, 0.046416884288191795, 0.056861870689317584, 0.05439669359475374, 0.04870108867180534, 0.02552925667259842, 0.04417840733367484, 0.0423850000515813, 0.047831647825660184, 0.025042938432306983, 0.04451335713383742, 0.06120770194684155, 0.01725881862512324, 0.06168294734379742, 0.03601865319069475, 0.03587700688512996, 0.07449424563674256, 0.024068778693617787, 0.01951048725459259, 0.04223250725772232, 0.033489506677142344, 0.08074581564869732, 0.04896186823316384, 0.011540760951902485, 0.05388509038311895, 0.016842733530211262, 0.048211887187790126, 0.04976954012818169, 0.02984733717312338, 0.014790196109970566, 0.019985981271020137, 0.04591368589899503, 0.05674802894645836, 0.005480737399921054, 0.023899620973679703, 0.027726019361580256, 0.06840697227744386, 0.04542306320217904, 0.02038814182014903, 0.053151228785282, 0.04899985135125462, 0.03627777776273433, 0.04664498337660916, 0.05597282601229381, 0.028229343915882055, 0.015747718753118534, 0.057372783703613095, 0.026675893386709504, 0.07593954855110496, 0.08233268323238008, 0.06059629100491293, 0.014524028556479607, 0.02774657685222337, 0.05231611597992014, 0.02378484969085548, 0.03868261454044841, 0.029828685146640055, 0.09218856022926047, 0.0008705238599304721, 0.03879959185724147, 0.02647863053425681, 0.03290623426437378, 0.09398118083481677, 0.03743077839317266, 0.026619959571689833, 0.0461974015343003, 0.03235316355130635, 0.01498780684414669, 0.012609098303073552, 0.037941008631605655, 0.12839652044931427, 0.15254688158165663, 0.10138145444216207, 0.17537608626298606, 0.14906340365996584, 0.17953148984815925, 0.09604830702301115, 0.1600623587728478, 0.1578098366735503, 0.15378261683508754, 0.09932315981131978, 0.14490197383565828, 0.1721691622515209, 0.09323994599981233, 0.1551013538846746, 0.12203808117192239, 0.13646004401380196, 0.1672530424548313, 0.12172571121482179, 0.18520314566558227, 0.1233453891472891, 0.12767519743647426, 0.1523706957232207, 0.16424747795099393, 0.1143894181586802, 0.1314522244501859, 0.15297657024348155, 0.09287585577112623, 0.1302473180112429, 0.1776997506385669, 0.1471589636639692, 0.1209320584894158, 0.13412889878964052, 0.15304493688745424, 0.10027736134361476, 0.13864063716027886, 0.1230155341909267, 0.2024547543260269, 0.16190076246857643, 0.11902928090421483, 0.15138393617235124, 0.15250686497893184, 0.13757935113972053, 0.19080610829405487, 0.08513227949151769, 0.14051693491637707, 0.10772393754450604, 0.10661182182957418, 0.1864565143478103, 0.08057170038227923, 0.10217570088570938, 0.06413741153664887, 0.1174026119406335, 0.08599528591730632, 0.12183786457171664, 0.1390364542021416, 0.15449895261554047, 0.08604376300354488, 0.13904642866691574, 0.1417021150700748, 0.09553987649269402, 0.07466915500117466, 0.3464437380898744, 0.1513051794609055, 0.09028535961988382, 0.11807610353571363, 0.11864890053402632, 0.07520612853113562, 0.09197806488373317, 0.08350405201781541, 0.09295012991060503, 0.08270156031358056, 0.15915735421003774, 0.07481071224901825, 0.19544577808119357, 0.1256059412844479, 0.1400097511941567, 0.16394793230574578, 0.10589409823296592, 0.2514501416590065, 0.13407435093540698, 0.16880473966011778, 0.10189035252551548, 0.1557959447382018, 0.17190207814564928, 0.10593649712973274, 0.1911130012013018, 0.11049548804294318, 0.16984089656034485, 0.10709589507314377, 0.10629656491801143, 0.14201812155079097, 0.08253003514255397, 0.10587696204311214, 0.15141503216000274, 0.06557485510711558, 0.10520352239836939, 0.13786248047836125, 0.14499768120003864, 0.1360857195686549, 0.11540054241777398, 0.2626029885141179, 0.1264433955657296, 0.11858228535857052, 0.2660205488791689, 0.2769029274350032, 0.06058914041204844, 0.20465571200475097, 0.17385202663717791, 0.1783668078132905, 0.10376971535151824, 0.133883040107321, 0.25579969107639045, 0.13355248753214255, 0.07816783210728317, 0.12436940451152623, 0.12286788391065784, 0.15499356435611844, 0.12364129826892167, 0.12326324082096107, 0.14673515281174332, 0.13152207538951188, 0.12411334872012958, 0.1124582088959869, 0.08123389648972079, 0.15545872767688707, 0.09145334421191365, 0.11864064785186201, 0.12036746222293004, 0.1540828452561982, 0.11894247189047746, 0.12088802686776035, 0.10788862011395395, 0.07409417608869262, 0.1535760029219091, 0.0707144578336738, 0.07323919970076531, 0.171912765072193, 0.19710860447958112, 0.15207560296403244, 0.19161674135830253, 0.20839540899032727, 0.11270201182924211, 0.22679065237753093, 0.10987225468852557, 0.27044042421039194, 0.1974812219850719, 0.10334197853808291, 0.18552302615717053, 0.11207159448531456, 0.1226413730182685, 0.17368281696690246, 0.19768749451031908, 0.15325999644119292, 0.23928558424813673, 0.09396354740601964, 0.11901873498572968, 0.1499315828550607, 0.13459217705531046, 0.09718465385958552, 0.14174780168104917, 0.14718913938850164, 0.12579144851770252, 0.15625968313543126, 0.08702159451786429, 0.09201275286613964, 0.12290147351450287, 0.1151864328130614, 0.22499860322568566, 0.19216330343624577, 0.06107901353971101, 0.15651550143957138, 0.1238892127003055, 0.15122682350920513, 0.11739182853489183, 0.23367784218862653], [0.028355958020256367, 0.04189940540527459, 0.027626354494714178, 0.0201174972607987, 0.014328861343528843, 0.0512441875616787, 0.02924254247773206, 0.027655765807139687, 0.015348044398706406, 0.048797964918776415, 0.018538346157583874, 0.062237287129391916, 0.035434612655080855, 0.021499893882719334, 0.027318224056216422, 0.06197150178195443, 0.040147016625269316, 0.11172235463163815, 0.03833101465716027, 0.030755891057197005, 0.02835810653778026, 0.04746517530293204, 0.09126511329668574, 0.01960017023520777, 0.016968625895970035, 0.03492797812214121, 0.07682843366637826, 0.06857222630060278, 0.022738861189282034, 0.011412853655201616, 0.07611824286868796, 0.041689997306093574, 0.04627329726645257, 0.027915252176171634, 0.04192057516775094, 0.05357264992198907, 0.07881482903030701, 0.04839231442019809, 0.028616420313483104, 0.05644282813591417, 0.02179445971705718, 0.06026630617270712, 0.0313567078410415, 0.012764189541485393, 0.029739080091530923, 0.033767058775993064, 0.045760688444715925, 0.020798323130293284, 0.06242564049898647, 0.07896709546912462, 0.014863054602756165, 0.047561498649884015, 0.015994508830772247, 0.06690625319606625, 0.03715935272339266, 0.055020038271322846, 0.03340072726132348, 0.10402393803815357, 0.02771353643765906, 0.017565654015925247, 0.018105045091942884, 0.05237946941633709, 0.04286954826966394, 0.06491004663985223, 0.011570744645723607, 0.028469855424191337, 0.039570345616084523, 0.03143818823446054, 0.01704506154055707, 0.02886449987272499, 0.056110323712346144, 0.07992636587005109, 0.1150959575898014, 0.028515237754618283, 0.029929533739050385, 0.021672463626600802, 0.03826375010248739, 0.02648681642313022, 0.03506916429614648, 0.02015129466599319, 0.053914575910312124, 0.03301182703580707, 0.019048843569180463, 0.019384247934794985, 0.006265155025175773, 0.05015230650315061, 0.10341907283873297, 0.03643230033048894, 0.021885936839680653, 0.023277111213246826, 0.017486101351096295, 0.04781047435244545, 0.06592016157810576, 0.05635813795379363, 0.08355312282219529, 0.016662337839079555, 0.051777127519017085, 0.08539285496226512, 0.06721216646838002, 0.057040616957237944, 0.030205698021745775, 0.02166886792110745, 0.055864824971649796, 0.09883053702651523, 0.08229146435041912, 0.021206415294727776, 0.04776124027557671, 0.028223608969710767, 0.046635828985017724, 0.03158121122396551, 0.015462889896298293, 0.01655183205002686, 0.06737486750353128, 0.04131154651986435, 0.008736910331208492, 0.0672478043998126, 0.04118603450478986, 0.049470580779598095, 0.023025367299851496, 0.0021264810720822425, 0.01972939855477307, 0.07141903799492866, 0.016194194795389194, 0.018698093444982078, 0.10105777415446937, 0.024703853014216293, 0.061430197820300236, 0.010420192174933618, 0.017626990666030906, 0.03864921418426093, 0.023871224548202008, 0.025873507438518573, 0.035241498408140615, 0.06279819121118635, 0.11301084916340187, 0.02528066874219803, 0.025556374748703092, 0.026223795575788245, 0.06681267579551786, 0.021915435354458168, 0.09809290160774253, 0.027800803727586754, 0.07435741586959921, 0.05771690273832064, 0.08784729317994788, 0.03164384848787449, 0.030835124598525, 0.03561301753506996, 0.03648172365501523, 0.01850121650932124, 0.08343627167050727, 0.014706032852700446, 0.0627019717649091, 0.08946051442762837, 0.02116783660312649, 0.047525144545943476, 0.017375588140566833, 0.0654824502998963, 0.039381135065923445, 0.031400242223753594, 0.028742804352077655, 0.020771490781044122, 0.054719958279747516, 0.05762435321230441, 0.021335053606890142, 0.018451086289132945, 0.021187629681662656, 0.09435276675503701, 0.0633541563001927, 0.04677871096646413, 0.018114180929842405, 0.068511711579049, 0.03564432874554768, 0.027511546104506124, 0.05634147302771453, 0.09794727739063092, 0.014024080774106551, 0.033273716107942164, 0.08967187066446058, 0.03673253988381475, 0.06316598475677893, 0.047651662171119824, 0.04911829069897067, 0.062287779146572575, 0.014973678207752528, 0.022915312365512364, 0.04377263438072987, 0.07663808020879515, 0.07353749111643992, 0.06685982443741523, 0.012785671005985932, 0.021442605648189783, 0.039313952147495, 0.07637664384674281, 0.0498936309304554, 0.037204965119599365, 0.05642048206937034, 0.062635334325023, 0.03725494505488314, 0.05373864609282464, 0.04807933590200264, 0.014230113956728019, 0.05426256524515338, 0.05856531854078639, 0.013654645226779394, 0.033957683117478155, 0.022415913772420026, 0.03898082431987859, 0.02832032936566975, 0.03843790618702769, 0.05884358310140669, 0.0065503359383001225, 0.024045271165960003, 0.012187806114525301, 0.019285254711576272, 0.03663758951006457, 0.04781121278938372, 0.04213061409245711, 0.039637617592234164, 0.051187891949666664, 0.04333351302193478, 0.02109990040480625, 0.05147757816303056, 0.03521243961586151, 0.02856291517673526, 0.04276763655070681, 0.03875037262332626, 0.0553391246648971, 0.013910462603234919, 0.022740931781299878, 0.010652788678271463, 0.06333512021228671, 0.08554482454201207, 0.039688098477199674, 0.027742465354094747, 0.03760374333069194, 0.02731726854108274, 0.09881191654130816, 0.049745208816602826, 0.037025758720119484, 0.031462638289667666, 0.025439015225856565, 0.02685330564418109, 0.010240533993055578, 0.011522717486514011, 0.019622818726929836, 0.09355539586977102, 0.02450591666274704, 0.021266401236061938, 0.022448776071541943, 0.04021891960292123, 0.07751900207949802, 0.02155482394300634, 0.07293175018276088, 0.01665618172410177, 0.04060232051415369, 0.06856743944808841, 0.04647807436413132, 0.019261066263425164, 0.03206440502253827, 0.04396601209009532, 0.05873912952665705, 0.07932726715807803, 0.01489149741246365, 0.02199895850935718, 0.025502828793833032, 0.05435292172478512, 0.0358078795397887, 0.03828312015684787, 0.059438718744786456, 0.062372391403187066, 0.0473619833792327, 0.03541262281942181, 0.06164068203361239, 0.05048550112405792, 0.048171399321290664, 0.05207055786740966, 0.02500046532077249, 0.018536110437707976, 0.04718033902463503, 0.05260132333205547, 0.041360632167197764, 0.10885835479712114, 0.030893301554897334, 0.039441634944523685, 0.03406579919101205, 0.08552923201932572, 0.046688892543897964, 0.021099217628943734, 0.06475645917817019, 0.02792804309137864, 0.021721562261518557, 0.04659151534724515, 0.032406149184680544, 0.03725107104401104, 0.03336587600642815, 0.004918361082673073, 0.014571979645552346, 0.026988725330738816, 0.03602531767683104, 0.04822651120775845, 0.02600101026473567, 0.041061071678996086, 0.004455729877008707, 0.01880195144622121, 0.10350815282436088, 0.030085876423981972, 0.02344712796912063, 0.017329975744360127, 0.061862279908382334, 0.03762005944736302, 0.005740583710576175, 0.04020897482405417, 0.012249183582753176, 0.03095889071119018, 0.011501845510792919, 0.029274968765093945, 0.038848317562951706, 0.05895443398912903, 0.03726288974576164, 0.02290681662998395, 0.05349381157429889, 0.020251781461411156, 0.02310427986230934, 0.04479869436181616, 0.011841847481264267, 0.057133433656417765, 0.02524861723941285, 0.09930594940669835, 0.039975120380404405, 0.07434027967974544, 0.05146260904439259, 0.014471793419943424, 0.05589013220742345, 0.054426936112577096, 0.01827031581342453, 0.04420717668836005, 0.0541943284770241, 0.017040358179656323, 0.05710844925488345, 0.07285424770088866, 0.05487759786774404, 0.035460892104310915, 0.07820893224561587, 0.04938105179462582, 0.04028702278446872, 0.029007546982029453, 0.028096050482417922, 0.01333518961473601, 0.04877810875768773, 0.05306375183863565, 0.05472056313010398, 0.09871122194454074, 0.07799752405844629, 0.1606696136877872, 0.1254299929132685, 0.0968208753329236, 0.1152858731802553, 0.17830327997216955, 0.15713512053480372, 0.11036915224394761, 0.1200692450220231, 0.14547054801369086, 0.19614369375631213, 0.09937000417266972, 0.1269487536046654, 0.06085248780436814, 0.1690045406576246, 0.18606096447911114, 0.24392216670094058, 0.1329490917851217, 0.18948612443637103, 0.1491093129152432, 0.15138055197894573, 0.17792652128264308, 0.15073577407747507, 0.07788295872160234, 0.21677612647181377, 0.15253531892085448, 0.16687037626979873, 0.11411481609684415, 0.13413271342869848, 0.17547266936162487, 0.10362189437728375, 0.10303392045898363, 0.10986276261974126, 0.1558712133555673, 0.10195265582296997, 0.15851892909267917, 0.14318075525807217, 0.09996468710596673, 0.1361359332804568, 0.16049310128437355, 0.23306919203605503, 0.14850042527541518, 0.11417353482102044, 0.13274707918753847, 0.12020934766042046, 0.09947183425538242, 0.0715672226215247, 0.13550353440223262, 0.1595049019670114, 0.06551134953042492, 0.1707714013173245, 0.12883398681879044, 0.1710316279786639, 0.07400134083582088, 0.16890524129848927, 0.13540747080696747, 0.15011986572062597, 0.0928493239916861, 0.0999546013190411, 0.17133955989265814, 0.20273970934795216, 0.13066254963632673, 0.15936184558086097, 0.06808332909713499, 0.11008773726643994, 0.11974990629823878, 0.15376991126686335, 0.11414242399041541, 0.11329753338941373, 0.14511373825371265, 0.13614932162454352, 0.1911540568107739, 0.13392010296229273, 0.16603554919129238, 0.14451734838075936, 0.10733505958341993, 0.15709520783275366, 0.13114248169586062, 0.12175718569778837, 0.1279146588058211, 0.09496509053860791, 0.1415362153784372, 0.09859661207883619, 0.13810734468279406, 0.10089239396620542, 0.24701564601855353, 0.06616966420551762, 0.15533532336121425, 0.11321573387249373, 0.16754884767578915, 0.22148456366267055, 0.13431581610348076, 0.11174489365657791, 0.17187320860102773, 0.12082430606824346, 0.10485648672329262, 0.20705865259515122, 0.1371956756338477, 0.1191617245785892, 0.14673549419967458, 0.07988899873453192, 0.0992493458034005, 0.25592066114768386, 0.12153209972893819, 0.13156495668226853, 0.21393165254266933, 0.10165756306378171, 0.07699440015130676, 0.11717892863089219, 0.19392548856558278, 0.11708829013514332, 0.1226226931612473, 0.18999644002178684, 0.20174313860479742, 0.10656888858648017, 0.12202135316329077, 0.1524178369436413, 0.07076431531459093, 0.07393534906441346, 0.1053109705389943, 0.12810874526621774, 0.09382328149513341, 0.2537668595323339, 0.19663040904561058, 0.1266742925508879, 0.16526981606148183, 0.16080898902146146, 0.12207549283630215, 0.17014961515087634, 0.09256516306777485, 0.13880370184779167, 0.1532736816443503, 0.19072583760134876, 0.19734655186766759, 0.18373724073171616, 0.09053708126884885, 0.11453310537035577, 0.15941876830765978, 0.1047927956096828, 0.27516452071722597, 0.13154735293937847, 0.13420468691037968, 0.18825933948392048, 0.1432650929200463, 0.12704230874078348, 0.15600711543811485, 0.09848713045357727, 0.1008595094026532, 0.08047696523135528, 0.22021431854227558, 0.09842894607572816, 0.1801745014381595, 0.15513463178649545, 0.17210869205882773, 0.11482810907182284, 0.12272067891899496, 0.15500527544645593, 0.1198780900449492, 0.12635748455068097, 0.10843281474080868, 0.19348971429280937, 0.1574717290350236, 0.12077825580490753, 0.20091565878828987, 0.10531107443966903, 0.16592593397945166, 0.3131561289774254, 0.17112412926508114, 0.10774307753308676, 0.12449888701667078, 0.11247149333939888, 0.11782907968154177, 0.14272135100327432, 0.16528198728337884, 0.1903996043256484], [0.05481142798089422, 0.05626092774036806, 0.02515074836992426, 0.08246282624895684, 0.04766472768096719, 0.08259968570200726, 0.03406235933653079, 0.04978155920980498, 0.004458739749679808, 0.1297501681256108, 0.05657929053995758, 0.03846252693620045, 0.05898196766793262, 0.032158090034499764, 0.020170601637801155, 0.09654766108724289, 0.03465650792350061, 0.06209831255546305, 0.053855293153901584, 0.05475352190842386, 0.024204589863074943, 0.011337277046550298, 0.04497565947531257, 0.06446072817198001, 0.03719390711921733, 0.03074297397688497, 0.020603557604772504, 0.041404366929782555, 0.04557106971333269, 0.041299560834886506, 0.058410272758919746, 0.08408933936152607, 0.05753221186751034, 0.03909906699846033, 0.025809914659475908, 0.04351383264292963, 0.05209164599364158, 0.06142875434306916, 0.01634437394386623, 0.023657172459934372, 0.037488176094484515, 0.05796107303467579, 0.014444066782743903, 0.09696497072582133, 0.012520474738266785, 0.08649389041238464, 0.058013761808979325, 0.02189315051509766, 0.018788251400110312, 0.02574868376541417, 0.025835813758021686, 0.012184095376142068, 0.0587732905842131, 0.033689541451167315, 0.0377094993746141, 0.06567494114278816, 0.047447820179513656, 0.052036099950782955, 0.07303918348043226, 0.06011539044266101, 0.022899014802533202, 0.02268151358293835, 0.014936922416382004, 0.05358118090953212, 0.018469185415597167, 0.06462582634412684, 0.0303674101451179, 0.10999561447533779, 0.039559354408993386, 0.05573726833972614, 0.0005425161555194791, 0.02269312633870868, 0.05441544395580422, 0.03863429701596033, 0.01893334683700232, 0.009433166378585156, 0.05894772497413214, 0.03358685418788809, 0.029675131081603467, 0.014444749558606418, 0.012864610471297055, 0.056868078754632734, 0.01709417687379755, 0.03755406025447883, 0.03864901380438823, 0.015416703263326781, 0.09916611394146457, 0.03995615850726608, 0.09793624165467918, 0.028431870450731367, 0.06215883098775521, 0.015766209362482186, 0.07368729362497106, 0.0006939123102256417, 0.043107562451041304, 0.07009115026448853, 0.08379988692468032, 0.04064020344230812, 0.05468551149533596, 0.028551936957228463, 0.03662545910628978, 0.044082900349167176, 0.047211613127728924, 0.053024347507744096, 0.06049385978258215, 0.0038880975307620247, 0.023396608121402096, 0.034624962936504744, 0.026356046291766688, 0.07393851061351597, 0.033482827348052524, 0.0037939465892122826, 0.03416972955164965, 0.02566357798059471, 0.03534042298269924, 0.043497212245711125, 0.029509509695344605, 0.04813752770132851, 0.034548065304988995, 0.02618416488985531, 0.035150874755345285, 0.03823028666374739, 0.07526271729147993, 0.02811410879075993, 0.058475077094044536, 0.05685629716026597, 0.037755813100375235, 0.04497662426729221, 0.017166504730994347, 0.024394598221988417, 0.01803619790734956, 0.06102899649704341, 0.03793658543145284, 0.07035197064396925, 0.010485019702173304, 0.03881796743371524, 0.02827375032211421, 0.02739799936534837, 0.09470815159147605, 0.06589710304979235, 0.005232976964180125, 0.07526945599238388, 0.1217178296064958, 0.026810663694050163, 0.05493273201864213, 0.01624451055249665, 0.047281890801968984, 0.03705257251567673, 0.014372712994372705, 0.05618499490083195, 0.05554233583097812, 0.08147559914505109, 0.03136160230496898, 0.08797228569164872, 0.011506645350891631, 0.06843292518169619, 0.027115955417684745, 0.04818187102500815, 0.005545713356696069, 0.021128285698068794, 0.05584783350059297, 0.010220837393717375, 0.04452130182471592, 0.01863634490291588, 0.07070440915413201, 0.07431720630847849, 0.030259095547080506, 0.03099806868704036, 0.014149680919217644, 0.04246364544087555, 0.031934993021423, 0.03188018541550264, 0.02453956378303701, 0.05010210021282546, 0.07798653285135515, 0.008726976684556575, 0.02869976349757053, 0.015175621228991076, 0.04462755510758143, 0.05189934810914565, 0.038018882187316194, 0.041004909653565846, 0.02255584015074419, 0.0266999296945869, 0.01552114385049208, 0.05554483686864842, 0.032623008446535096, 0.03976029831392225, 0.029981079605931882, 0.05083467418444343, 0.0576025118061807, 0.027968627437076066, 0.055219727946678177, 0.04163677047472447, 0.002634950101310096, 0.03867239516694099, 0.0434802875679452, 0.008845865959301591, 0.04160931101068854, 0.10482565790880471, 0.05598532377916854, 0.04601785374688916, 0.04777420559548773, 0.029894432009314187, 0.0313713801006088, 0.005628894195979228, 0.04990836256183684, 0.06151979359856341, 0.09834382173721679, 0.039372596656903625, 0.041925606928998604, 0.02453041866829153, 0.039037275782902725, 0.0784778494562488, 0.024933902095654048, 0.06981854457990266, 0.02789683021546807, 0.060818619895144366, 0.01589905565197114, 0.019395691851968877, 0.032167533863685094, 0.04146098537603393, 0.03174773803038988, 0.037195565819274634, 0.04751842068799306, 0.027662771681207232, 0.008991274025902385, 0.004173517554590944, 0.07876493444200605, 0.025786616788536776, 0.014186959924700204, 0.04069157861522399, 0.029840021452400833, 0.08999913552543148, 0.021120209275977686, 0.04807551384146791, 0.030580738639400806, 0.0188621971392422, 0.03952982435293961, 0.028711283484881278, 0.011711358438333264, 0.07775493824738078, 0.019518135086400434, 0.03211882671166677, 0.038133135822135955, 0.050772745671565644, 0.04415057679580059, 0.07204558132798411, 0.02768126785667846, 0.03602811186283361, 0.027519386894709896, 0.04695597664976958, 0.01099040742701618, 0.021630962728522718, 0.03800085913098883, 0.07188412710092962, 0.03626444507972337, 0.027047145340475254, 0.01659808083786629, 0.03846012237772811, 0.016934700470301323, 0.05154479076736607, 0.05228250040090643, 0.016338607456418686, 0.0662846674094908, 0.03286136401584372, 0.028261289662623312, 0.05717519801692106, 0.030492821970256045, 0.03401885835046414, 0.020841853802266996, 0.03869701220537536, 0.023314593381655868, 0.028215879501658492, 0.047773374390089884, 0.044196820017532445, 0.09899555356241763, 0.03125769791950006, 0.021616088233713526, 0.04335122066549957, 0.08821392897516489, 0.04990343841200229, 0.052818702097283676, 0.03180923238687683, 0.029908796277595684, 0.062027786261751316, 0.024161623223335482, 0.04228054647683166, 0.046306946242111735, 0.0677818019175902, 0.015057769105624175, 0.010222946948488243, 0.018326129029446747, 0.04188813589280471, 0.0672316923737526, 0.0458285949571291, 0.05181643908144906, 0.02013560751947807, 0.024805453031149227, 0.03535821597324684, 0.025062865097424947, 0.10503013443667442, 0.032413080843980424, 0.024764295376371592, 0.043876646377611905, 0.041995231513283215, 0.02470757859555306, 0.06982717575738207, 0.019465314580884296, 0.009320771823695395, 0.09112048355746083, 0.06649904418736696, 0.08547887729946524, 0.07032814028207213, 0.03752203287149314, 0.033667451425571926, 0.023119228571886197, 0.04731857145088725, 0.06572715123184025, 0.02544789316743845, 0.024671779247000813, 0.011788308947870973, 0.01315479670665809, 0.02170243526052218, 0.04793833526491653, 0.023524311327491887, 0.07324682155740447, 0.04295916260161903, 0.05863557766133454, 0.08616937149781734, 0.014694972996949218, 0.07368589838733897, 0.007111437616913463, 0.029039362852927297, 0.06929959039553069, 0.047032236034283414, 0.020658871726482175, 0.015969088417477906, 0.03199721468263306, 0.02714862290304154, 0.04057098332850728, 0.05126259282405954, 0.05681539740180597, 0.011025702115148306, 0.0278143163814093, 0.05114848019729834, 0.10081581174745224, 0.058306108621764, 0.01432706905688974, 0.026712028557085432, 0.037282196717569605, 0.02797579287289409, 0.14175391697790474, 0.14014614309417084, 0.16073740145657212, 0.2625814959174022, 0.13119422423187643, 0.14151150186080486, 0.08170231041731313, 0.12272840467630886, 0.09491581193287857, 0.18921933718957007, 0.13031222624704242, 0.13527901988709345, 0.2155722738825716, 0.1695136391208507, 0.1245787792140618, 0.17264027759665623, 0.22113824787084013, 0.13206783594796434, 0.10529433158808388, 0.09436369116883725, 0.13465548225212842, 0.07684682408580557, 0.10101117470185272, 0.18797916389303282, 0.15825913287699223, 0.09202070126775652, 0.14065522671444342, 0.10855177359189838, 0.11005037013092078, 0.11677489601424895, 0.2310203152592294, 0.13864253705833107, 0.19413201342104003, 0.16806511528557166, 0.13824235618812963, 0.12770145462127402, 0.15285475412383676, 0.1153822781634517, 0.10356601065723225, 0.17281396983889863, 0.12296124608838, 0.10772597845061682, 0.1014421324362047, 0.1289577770512551, 0.08413213159656152, 0.20138217281783, 0.18264298851136118, 0.10625727562000975, 0.09717047883896157, 0.12690279982052743, 0.1521330006653443, 0.13267535803606734, 0.195555719838012, 0.07315708848182112, 0.14902781025739387, 0.17975682072574273, 0.13800875778542832, 0.23555685620522127, 0.14169772155582905, 0.17166972655104473, 0.2355987430200912, 0.10138085330254398, 0.06595059705432504, 0.13635494105983526, 0.09284938336350024, 0.18331283616134897, 0.12106724068871699, 0.1964498742017895, 0.15498577180551365, 0.1218194370449055, 0.12116047670133412, 0.15337719640228897, 0.1544905811897479, 0.10415315337013453, 0.08800054667517543, 0.1062854178599082, 0.11269197057117708, 0.1403766096336767, 0.1496441342169419, 0.1547250256408006, 0.10332277917768806, 0.1856213904102333, 0.15103287063539028, 0.16413648234447464, 0.12277985777473077, 0.12267666214029305, 0.22568544605746865, 0.14245386613765731, 0.1446960130124353, 0.11648978514131159, 0.07519010556279682, 0.1418279981589876, 0.13450445519993082, 0.12835093773901463, 0.12418771933880635, 0.25159132783301175, 0.12664000532822683, 0.056198078964371234, 0.095503362827003, 0.15659421362215653, 0.12106703288736753, 0.12131747062085196, 0.12094509060261771, 0.12336239175056107, 0.17682922625681385, 0.14116144564468414, 0.1264211311354302, 0.09087786806048825, 0.11687107835314237, 0.16169598908163607, 0.10248663849779405, 0.16204475396079943, 0.10402173385955393, 0.2131776008172892, 0.07932633947348222, 0.24890269007300958, 0.14520802069455385, 0.21466833801241592, 0.15607254317728803, 0.140504066075664, 0.15031099843326956, 0.18199096724856645, 0.1994050617213361, 0.271088526933454, 0.17512950027594343, 0.16909374680835754, 0.07138527027564123, 0.13489016419043764, 0.1077405690739397, 0.13863431406207383, 0.12497147923568264, 0.18031911633443087, 0.10673363052774221, 0.15619193989550695, 0.13557758589740843, 0.10832615327672102, 0.1632223345222883, 0.12912965845316648, 0.31681067193858325, 0.18707378825638443, 0.1190875394968316, 0.17028922797180712, 0.19698138552485034, 0.1065691928670276, 0.144646986736916, 0.13298409146955237, 0.10219057352514938, 0.12106571928597987, 0.14474661264102906, 0.18203935527708381, 0.15462269831914455, 0.1789282722165808, 0.12004054617136717, 0.1527130781323649, 0.0754065826185979, 0.09719742622110061, 0.116593626444228, 0.1448644805350341, 0.18845217913622037, 0.11477164647658356, 0.10038780033937655, 0.10166911088163033, 0.21165557467611507, 0.07141304144170135, 0.20085827592993155, 0.1438900109496899, 0.15736825880594552, 0.11883188446518034, 0.12872299121227115, 0.09693080224678852, 0.17645344720222056, 0.1328647689661011, 0.06978777513722889, 0.06805010314565152, 0.1256117003504187, 0.13925797044066712], [0.028635949929594062, 0.0748772086808458, 0.020977828244213015, 0.029789139807689935, 0.021763846125395503, 0.03237859324144665, 0.059103913663420826, 0.04305363057937939, 0.033810678505687974, 0.05771978227130603, 0.03424075308430474, 0.059882426576223224, 0.0467705287883291, 0.023328556890191976, 0.027030803248635493, 0.0017329187676295987, 0.05919475253904238, 0.023346873094851617, 0.034625998232513666, 0.07385459597571753, 0.008287299642688595, 0.02498057576303836, 0.017722972625051625, 0.06253882544115186, 0.023011938137642574, 0.0189262240746757, 0.06826593453297392, 0.01842216108343564, 0.05089612030133139, 0.024208011163864285, 0.042977886987500824, 0.0256611901204451, 0.05446566879982129, 0.04711053261416964, 0.046257979338406585, 0.03349557373439893, 0.04055013268953189, 0.011907129573955899, 0.009512091000942746, 0.08553059014957398, 0.02193630083638709, 0.04165822967479471, 0.009229577644873643, 0.029365675909502897, 0.04183004428341519, 0.03187709065969102, 0.01627725039725192, 0.0166904578145477, 0.03553205664502457, 0.052933182087144814, 0.002994176247739233, 0.01136697315814672, 0.016019979339034762, 0.017593924276297912, 0.09261974060791545, 0.04341748703154735, 0.03550879402610008, 0.015807853123988025, 0.01583402496180497, 0.008845825141179375, 0.022405560812330805, 0.04676417971495539, 0.07301248842850327, 0.04496555884543341, 0.08072862008702941, 0.11851855713757686, 0.059176495706196874, 0.008856901695253327, 0.014135743385850219, 0.055649895293754525, 0.021343707048799843, 0.03415165454498492, 0.03384723298950121, 0.01478884076277609, 0.04110337409656495, 0.04230469967296813, 0.04278331442037597, 0.047981980969780125, 0.028092002066841815, 0.030210802142391913, 0.03775885961658787, 0.015228662523441017, 0.017159688104584347, 0.03416631938307546, 0.03414457445614971, 0.01345851971564116, 0.05115284031489864, 0.028273549942241516, 0.015114045236259699, 0.05624703844659962, 0.048263321732520126, 0.010350446063966956, 0.04445434897206724, 0.003021783213625895, 0.013489483044395456, 0.0164035175475874, 0.05804952590551693, 0.07677021960262209, 0.04561297508189455, 0.06984926949371584, 0.030812318400421645, 0.034999072158825584, 0.012914987455587834, 0.05604176410997752, 0.02548180189478444, 0.06468607389251702, 0.055730318126734346, 0.0016456577395729255, 0.025322303226857912, 0.0221556704127579, 0.048981037907651626, 0.014470730293396628, 0.09194083875627257, 0.051342266087885946, 0.01011304693747661, 0.03986664807598572, 0.024298176540469285, 0.023983003120520152, 0.059013449572375976, 0.05815852513478603, 0.03340637500514276, 0.043002915917895734, 0.05524276049982291, 0.02227977976872353, 0.031902802365948446, 0.009143827119260095, 0.07026670529739931, 0.07416541484417394, 0.0037812528489666875, 0.03406363583053462, 0.04941258936014492, 0.08825810902635567, 0.036800650486839004, 0.023584692462463863, 0.019203045158064924, 0.0921986014873255, 0.023326788723352365, 0.02071648650598945, 0.004589295122059411, 0.06572232727194205, 0.06857180327642709, 0.06300366221694276, 0.07663778334972449, 0.04659508136683144, 0.0791326908802148, 0.06429067245335318, 0.030956590053392574, 0.03366814533364959, 0.016612667750450782, 0.049830025163828395, 0.05875097049283795, 0.038935427146498114, 0.052605275268433616, 0.02134891321475152, 0.06520752911455929, 0.02783078463835409, 0.01634714957617689, 0.02285332633618964, 0.03942351911973674, 0.051574202079791576, 0.011294304840703262, 0.017160383868031204, 0.018771972390823066, 0.039186688663903624, 0.01949286124727223, 0.013464422572724288, 0.05143815898918547, 0.030079519929131493, 0.030986832571215928, 0.04275793668057304, 0.018133001794922166, 0.05842513055540621, 0.07619241310749203, 0.060955353183089755, 0.03427111805649474, 0.017614793468965217, 0.032529928284930065, 0.02204729273216799, 0.057134491216856986, 0.03346106757817324, 0.03432392928516492, 0.02645123786351178, 0.04182927616056986, 0.026238311984343454, 0.02266208601213293, 0.08434955860138871, 0.03599402502004523, 0.05190562667849008, 0.0370009227481205, 0.0588017964764731, 0.032500516972504556, 0.013747375651291804, 0.05313813730026595, 0.0617352279368788, 0.027484361235110555, 0.05399352186941542, 0.0877995285554789, 0.032884964311961085, 0.0747048448829446, 0.03833869217487518, 0.01631922812521225, 0.07575833093142137, 0.12631488527404144, 0.05432651982118841, 0.06904343812493607, 0.050371336546959355, 0.02534021310566459, 0.0834067861433141, 0.046849118516547605, 0.09814969074795954, 0.040766865786281414, 0.024965799602796324, 0.04681070495280437, 0.049157579996972345, 0.05806961213238537, 0.011887833734363085, 0.04970789363142103, 0.03544385981513187, 0.01834007583966013, 0.02302211112692021, 0.002072598599625053, 0.05888469437195454, 0.004415106568558258, 0.01792293132893974, 0.05329192885255907, 0.021701225559809245, 0.05940446862950921, 0.03202535321179312, 0.028532422184071038, 0.026060814379889052, 0.021540977322729304, 0.02076343291264493, 0.07769109128275886, 0.014532837849401403, 0.042472655113670044, 0.011669858467939775, 0.023626401161891408, 0.02383689094131114, 0.006236980316316476, 0.04819470275833737, 0.05817353507154621, 0.04582035711791832, 0.05744919893913902, 0.087011434516171, 0.05175815080292523, 0.046330286786542274, 0.028929547261213884, 0.02018947259784909, 0.025590493132767733, 0.030054836097406223, 0.05444180504127871, 0.029486963248928078, 0.026554949290584773, 0.034607188499649055, 0.02513955121685285, 0.018622696807142347, 0.03972652688389644, 0.04261783033143729, 0.026412366023578215, 0.030291538532765117, 0.014432989300985355, 0.039642048213863745, 0.015918674325803295, 0.0446373440354364, 0.04131115689233411, 0.0648946470755618, 0.05149767181137577, 0.027740801087929867, 0.01583844074048102, 0.028711819686577655, 0.011397337202652125, 0.029603851507999934, 0.033847229278762825, 0.06315293037914671, 0.04066404122568201, 0.0621827132999897, 0.06007385614793748, 0.02497671845048899, 0.01766170833434444, 0.11644328958936967, 0.01976509956875816, 0.011732455841411138, 0.0533682772947941, 0.013661149223480606, 0.03215546654246282, 0.03754458302864805, 0.03959612411563285, 0.022540162281075027, 0.040234783009509556, 0.01838753989432007, 0.06491764623206109, 0.021908076960244216, 0.04085423883225303, 0.07391791601548903, 0.04199869363219477, 0.08122054525301792, 0.031024414929561317, 0.04450576125236694, 0.03730795295268763, 0.015626143831468653, 0.034793771847034805, 0.0357731321855681, 0.04720389850263018, 0.03975656160037033, 0.048128135822480544, 0.03790859162108973, 0.0114261585076747, 0.04809537000255659, 0.06795432898798026, 0.04001973458798602, 0.03322031487186905, 0.04246456941473298, 0.09947449856554158, 0.03383530296559911, 0.049110219842987135, 0.010069066338473931, 0.0658690721320454, 0.037659612207789905, 0.05627032704069279, 0.01898259204608621, 0.06759786803741008, 0.024073689855867997, 0.02758448252279777, 0.046297903172671795, 0.05446870418381877, 0.03580153417715337, 0.015701289994467515, 0.047393101631314494, 0.09482668741839007, 0.00823435668280581, 0.04196293324639555, 0.039215688084368594, 0.0726854165259283, 0.05059018476458732, 0.00827840593046858, 0.11674875015160069, 0.05478578677866608, 0.043896706629311666, 0.07724224036792293, 0.026674783875932917, 0.038332962794811465, 0.031895169377094135, 0.0049776025571190985, 0.017208879507961683, 0.06300909473793581, 0.016255280970653985, 0.022857508338347543, 0.06689666464808397, 0.0636774803570006, 0.017931109796336386, 0.0723247995483689, 0.02294147307111416, 0.10429478483274579, 0.12188946609967388, 0.16810363274998963, 0.10762491278001107, 0.12160589889390394, 0.05946707620751113, 0.15290897543309256, 0.16777843848103657, 0.1272136261104606, 0.15945998718962073, 0.12076250000973232, 0.17817934131016955, 0.18658438639249653, 0.1056480169063434, 0.22290966531727463, 0.09396920999279246, 0.13028457382461056, 0.11514009311213158, 0.12005069133010693, 0.12791143788490444, 0.10570804181043059, 0.0870461150771007, 0.12699216924374923, 0.11179596825968474, 0.08691957889823243, 0.16725608526030555, 0.19511132180923596, 0.12488169420976192, 0.13364869955694303, 0.11469602162833326, 0.12467499123886228, 0.22883406694745645, 0.1009824981156271, 0.1619574031792581, 0.1153747305215802, 0.09685366341727786, 0.088234709110111, 0.15813354664715007, 0.12059666711138561, 0.13706225232454017, 0.19465622201096267, 0.07292987254913896, 0.07581882338854484, 0.11297454329906031, 0.10869244768400677, 0.17299667175393552, 0.12434676158591174, 0.1351368986070156, 0.1734574415604584, 0.12424294254742563, 0.08298018481582403, 0.10063257548608817, 0.20516614633379504, 0.13394205569056794, 0.12754539580782875, 0.10495385649846867, 0.19533530197804794, 0.1416620094096288, 0.12751361704431474, 0.2026597800431773, 0.07667969985050149, 0.14369019510922953, 0.0979319223552011, 0.1163256517611444, 0.15414113353472203, 0.13492888945620507, 0.12274955588509329, 0.18492338567739353, 0.12222218574606813, 0.10986092951497994, 0.09649336556321941, 0.10717229917645454, 0.1876509268186055, 0.0928807539457921, 0.26900116237811744, 0.11480509507237002, 0.13943878730060533, 0.12625016999663785, 0.09004158637253568, 0.1066271323361434, 0.16462840751046315, 0.15728484140709043, 0.12651291996007785, 0.25383178261108696, 0.165819049871061, 0.08717058066395111, 0.18841035169316456, 0.09043286889209412, 0.12530185369541869, 0.1849047132418491, 0.09074030356714502, 0.12531040323665366, 0.09035699913511053, 0.08642547923955135, 0.14210974710294977, 0.17141234973678365, 0.19130303553538397, 0.15284993016393855, 0.10057799794594757, 0.18503058148780838, 0.14875510067213327, 0.1407470303820446, 0.18911626772023737, 0.1707856950815767, 0.08611364362877794, 0.16315705521265045, 0.22812210983829573, 0.1823923652409576, 0.14066059986362234, 0.1276314107235521, 0.11407044308725744, 0.09394713852088898, 0.17489961261162534, 0.12772198242601007, 0.14243356097722426, 0.12208985339384526, 0.0903257547179237, 0.18489932524971664, 0.09315068047726527, 0.17580846149940044, 0.0983024989545811, 0.09734169230796397, 0.09852757750195451, 0.12488455889979377, 0.16949192387983203, 0.09269417801988311, 0.28804072353523225, 0.21896086080232635, 0.13643092213897035, 0.1622993402997963, 0.11507672854349948, 0.15480397531064227, 0.12745385931339115, 0.22906336089363322, 0.07454231454175897, 0.19552074983948842, 0.12002306117210537, 0.08071582546108402, 0.159392733767163, 0.15558692626655102, 0.1604552220669575, 0.08722105412743986, 0.1567465765401721, 0.16228258260525763, 0.19341968523804098, 0.16941292968112975, 0.10334686186979525, 0.11422741474234499, 0.13195839885156602, 0.10937712344457395, 0.1788941927952692, 0.19851448450936005, 0.13895524840336293, 0.07190436546807177, 0.18317153124371544, 0.14817518647760153, 0.13684000878129154, 0.14625749172409996, 0.09736621286720037, 0.3494656446855515, 0.1502067266847007, 0.15661760611692443, 0.10486111030331813, 0.12413769116392359, 0.12997063051443547, 0.12081368593499064, 0.10949575575068593, 0.15185661002760753, 0.20918224880006164, 0.13460136484354734, 0.11840447419672273, 0.19757626141654328, 0.17077156458981335, 0.12184081831946969, 0.15533680765656754, 0.10094360215589404], [0.033372373509337194, 0.05763158173067495, 0.019893003154720645, 0.018916013978014234, 0.030105081350484397, 0.02753915214270819, 0.018983961308549624, 0.010778230189316673, 0.06168796055135317, 0.000532728445250541, 0.06189973610162269, 0.06731485002092086, 0.056215742079075426, 0.05148503674718086, 0.019054179610975552, 0.09965970151824877, 0.03122963731584605, 0.0688876687490847, 0.07299757126020268, 0.03569618631445337, 0.014744349937245715, 0.038886738548171706, 0.11769347445806488, 0.03774434691877104, 0.05596184222667944, 0.013542399101424962, 0.04701817604654934, 0.028625888262467925, 0.016349081015505362, 0.05003211939765606, 0.0197663742073928, 0.0436728118074825, 0.06631605283473618, 0.04601730455760844, 0.03868037325446494, 0.06719552009599283, 0.031494457871303894, 0.020950251891918015, 0.04637870821170509, 0.06103687439463101, 0.03324838289699983, 0.05523192885448225, 0.013550777948694304, 0.05147749281604774, 0.06356612109811977, 0.012834702847612789, 0.04194323664705735, 0.021195353583607357, 0.0359943849616684, 0.048585432377876714, 0.1488428670563735, 0.018723038883763365, 0.047841321720625274, 0.03269250686571468, 0.03867039878969081, 0.0073693149170139804, 0.07003243154031225, 0.029272640276758466, 0.03584109806979541, 0.04330808333179448, 0.05317218332493212, 0.039811417445889674, 0.08431947935605422, 0.10711410737712868, 0.13513465732103214, 0.03582452962291427, 0.019051635899813846, 0.0184016091589001, 0.11349284439347684, 0.019858289197145496, 0.060168045820319094, 0.025193676046910696, 0.0463634125480894, 0.02847109666618053, 0.04883700188656803, 0.0089865567497327, 0.015833154793654103, 0.06484208075562492, 0.03731427976163104, 0.06403506195056252, 0.06943879503523931, 0.043862449092557654, 0.0073170756058971165, 0.0420714575011516, 0.0892597709025722, 0.03832756367046386, 0.06348449969664216, 0.03261963909608312, 0.04492923442739993, 0.035359744797460735, 0.07420854846714064, 0.022261207523115445, 0.029721032915404066, 0.023349097682512365, 0.005737314086218248, 0.04070778712048195, 0.048171421585720964, 0.0720384121814277, 0.015298863199859625, 0.02231484995718347, 0.03954734645958524, 0.03951585342292674, 0.06856732070446014, 0.028223605258972384, 0.08289024393889122, 0.015485077328776242, 0.04261200076143723, 0.03302883334981743, 0.012404884309944464, 0.04232632585626561, 0.04968469409504905, 0.042319290296291, 0.06295959348790348, 0.023617925835424103, 0.02170649666368263, 0.05501010462467093, 0.009660323867137777, 0.10321933863451704, 0.017624523025006056, 0.039564415856148116, 0.03660679409222212, 0.053862903878325596, 0.04067129942995962, 0.07357692142250016, 0.050465092062950134, 0.024187720846384764, 0.016540248980163597, 0.07268507513799705, 0.05686965581844561, 0.0968855906103272, 0.06412937407731079, 0.026665553414204624, 0.028000526799587533, 0.05845614861755166, 0.023936784018587787, 0.0457338264095597, 0.03731128519575577, 0.06631103591644205, 0.027489823442010675, 0.034649672743398696, 0.006166600132928579, 0.04210812330711633, 0.025843513540166896, 0.019008773160749115, 0.0428641565667931, 0.03409347016713582, 0.0764476896438282, 0.03754300967557356, 0.08007367476238869, 0.02323230404726928, 0.024995513340400066, 0.08329915988724679, 0.044673167503788136, 0.03249146648158785, 0.053476192988455296, 0.08001753129065037, 0.10677922065951861, 0.02332024298084434, 0.0625498389126733, 0.05745892478444148, 0.04411672744026873, 0.0332389835966751, 0.04026077673188411, 0.07313948473893106, 0.09165876326733269, 0.0263742585957516, 0.00998209034150932, 0.03733346798981074, 0.042491936110309325, 0.05921064192079939, 0.006303697073235526, 0.10160226564039476, 0.04062126754433848, 0.059877149906242266, 0.05184744230064098, 0.028842721549153794, 0.023252045175468083, 0.06675761585938744, 0.029084886191412807, 0.03921574003470596, 0.06220578296051826, 0.044431783971958794, 0.03176337508193683, 0.024305889310198836, 0.07796745223458856, 0.027753888862207532, 0.051841942986357026, 0.05520708175026812, 0.03693573991768062, 0.05396100095822476, 0.037240562232909724, 0.046192121153580956, 0.06971157141379081, 0.02917935973528074, 0.024299781434820034, 0.02509985559299821, 0.03757954931643326, 0.03428037634876091, 0.08668885260703973, 0.04209154372802004, 0.017459959199186414, 0.014223462458176073, 0.010979182443406899, 0.033905996242538095, 0.03349712482304312, 0.004804726677321014, 0.050559493247419596, 0.052500224264804274, 0.04336164412961807, 0.10376783029641956, 0.010998345624102512, 0.02127973762981128, 0.07228438960737549, 0.02452749089570716, 0.03348549907968845, 0.09697921996121295, 0.0220187404556782, 0.018808818167599384, 0.02723051147768274, 0.036742584852618165, 0.0619211359298788, 0.04397970471472945, 0.07461972796590999, 0.015523882375418907, 0.01583674493303988, 0.05816541968670208, 0.0465388970769709, 0.01878167411632603, 0.004438835812834441, 0.02733278499363223, 0.0391907445009565, 0.0373039750411408, 0.03232580056646839, 0.00949078579651541, 0.04192992622847669, 0.017009499679261353, 0.007512966876674909, 0.06151953755761497, 0.03158874031214509, 0.033451156195951626, 0.10523849981836975, 0.019748725935642142, 0.0327870045293821, 0.014813499547017273, 0.05778834929515142, 0.03441914312134031, 0.05386559045291506, 0.015619570258422755, 0.031402149543282576, 0.012835906054533552, 0.028562924453581218, 0.02780918999633286, 0.02183475091442233, 0.085456798406085, 0.019619866834545974, 0.055419439886463806, 0.012838303191529121, 0.08215278663556091, 0.025981658764067106, 0.006169336338643916, 0.04967202192347031, 0.049181918730027974, 0.03754252727958374, 0.04059961538587231, 0.02232837930932874, 0.03752438919036649, 0.01971643137949286, 0.04098043733392842, 0.011966581168962875, 0.06941570682101883, 0.021217582761892118, 0.03166779759339988, 0.016658185522828717, 0.05381600385589991, 0.04379043108201586, 0.004213900128888781, 0.05963069008430466, 0.052507445361698046, 0.09363467950606719, 0.050556498681544326, 0.04421638303028885, 0.03768761715036817, 0.021189386716287117, 0.041868068219628185, 0.007486764889108599, 0.01287849512664252, 0.03334481385536492, 0.07001887992373668, 0.02416292940324638, 0.079411419283133, 0.033622718474362046, 0.04587943578371778, 0.028864369996881578, 0.026159601657127496, 0.06417389551643282, 0.014671326316602062, 0.034957404277520254, 0.029967394402774516, 0.05249544854450505, 0.029094617602822836, 0.04259784058376681, 0.025540849019307643, 0.049482996910228394, 0.06269594552577473, 0.0858908731606789, 0.04819402740395162, 0.02171794058085652, 0.06183746249007527, 0.05668503545166459, 0.007406589747915859, 0.0187884091064916, 0.04494319793593604, 0.08712630413356237, 0.021461380129039753, 0.047914274837239645, 0.0694426913105417, 0.08220122661441565, 0.05570537454332225, 0.012780289507645648, 0.02262183748825919, 0.016892600287974346, 0.010096466430695727, 0.051362048034206964, 0.0466235946805682, 0.06125198589870706, 0.028903186175739393, 0.03471092590189073, 0.0037866459433644195, 0.05235078169789631, 0.025392903735337313, 0.014402325614355505, 0.07448348449543118, 0.020820531899516936, 0.04424443992320448, 0.08317600790178403, 0.06628747272770852, 0.049241546585108154, 0.025995529504143633, 0.05405962496297434, 0.032464975520269945, 0.014448013153014472, 0.05378071844461374, 0.041758579172892496, 0.02958198598207673, 0.0678944525134284, 0.029495279013644904, 0.01668218657869147, 0.02835996747307945, 0.025292159043601714, 0.042450887922313996, 0.02332365129404934, 0.04017083585495129, 0.12007513767457567, 0.15555716614471748, 0.11496991864987649, 0.13171130820410326, 0.25553382409270853, 0.10845601427718066, 0.12170769929070957, 0.1132378721376881, 0.27361203683540225, 0.15127847698749974, 0.2027106171590276, 0.15216520987451077, 0.15082987840287387, 0.1689740680740215, 0.12292802755837329, 0.1839497621404007, 0.08937345308368094, 0.17204085976118222, 0.10052880097646266, 0.10613542239298113, 0.15447995363501832, 0.12755989737343043, 0.23626734386198223, 0.08423115636105649, 0.14134068915154785, 0.06483229924924672, 0.13438964495435357, 0.10013177423388697, 0.12894612533273175, 0.1959059838554822, 0.11971772677497938, 0.13263646949781105, 0.13798892759950832, 0.17198746965732425, 0.13906235515605658, 0.08828062578686513, 0.19288790674181655, 0.11133827836601995, 0.085095914255362, 0.1770385861163959, 0.060992486542090774, 0.0908091600285843, 0.07714964260230772, 0.30625287909060717, 0.2554283500649035, 0.09893623369862325, 0.21238354733213782, 0.08835823959088884, 0.2062741431291215, 0.13370485045015812, 0.19775106688030064, 0.16400145599618554, 0.10154866773518734, 0.09751435296493582, 0.2304695823113434, 0.08113394404063001, 0.15060760517371818, 0.13074613030767068, 0.1627993251895532, 0.15806197392521426, 0.0735668653214816, 0.1318710035411641, 0.18064105999656022, 0.15830250398721546, 0.22296232811640948, 0.1700548132066615, 0.09809092749492265, 0.12762943661073223, 0.11207566145458259, 0.1331651903456077, 0.13831054471665993, 0.1195681988610886, 0.15586861583869904, 0.08472743793390691, 0.10221185089903884, 0.10885611351113766, 0.1433137184358202, 0.16914876963710412, 0.07042204422759824, 0.16470551665406674, 0.11040213328669779, 0.1962783045019023, 0.2116856910288334, 0.139378925669007, 0.16822231700643897, 0.10482299359864555, 0.18824747996404767, 0.0948514677293133, 0.08871694924891926, 0.17009097064146772, 0.1821391741395928, 0.13600158970803022, 0.1554029478575103, 0.17847599257947877, 0.12554891465697438, 0.14569657651009038, 0.1946237901574932, 0.20913001644657925, 0.11451104131992906, 0.1043946853314992, 0.1578191135195084, 0.11610576082603075, 0.2906096528749913, 0.13037293392699212, 0.1102718418405857, 0.11204599781194702, 0.13823018496623263, 0.1407785271294415, 0.1304705857182853, 0.13501456298399717, 0.144364183943253, 0.13825571484630927, 0.18051872437354177, 0.12116680722101592, 0.09173930113320239, 0.14324055751785636, 0.11414329972467385, 0.1611561657045968, 0.1261914215865545, 0.2230351624893956, 0.13456146698445082, 0.14616717235185206, 0.13765313546173275, 0.12754805269651115, 0.10106719942996278, 0.07074815875967033, 0.1873257919214666, 0.15318213030695915, 0.1827586893341504, 0.1677388374810107, 0.18801364407408983, 0.18859953997889534, 0.294488561921753, 0.15952249086694792, 0.14485388266621158, 0.12669385556364432, 0.12786149134626612, 0.1765178656205535, 0.12666353140957654, 0.21825999137945473, 0.15526596223935485, 0.14680685912026092, 0.1282531226752326, 0.14450032351305708, 0.18218980345409364, 0.11067044193623587, 0.21296286780852824, 0.17565143789397553, 0.14123007946182042, 0.1624011035892181, 0.14954477548599243, 0.14914367435267195, 0.17106702842283994, 0.16780203877715394, 0.19939885736675933, 0.14518035342916846, 0.1178167897160165, 0.16639878595015034, 0.19817854394204915, 0.1405556601821445, 0.1893252565059811, 0.13143010844942182, 0.16082105634268373, 0.1299347254098393, 0.1642235362669453, 0.11723746181814931, 0.20115654508117586, 0.18285613332409412, 0.1946128360577859, 0.14950260665500537, 0.10347457806346938, 0.17482566501712427, 0.1835388646577485, 0.1325852464651689, 0.1302107301307842, 0.1267103460850194], [0.033429889954277314, 0.03612250191508792, 0.06639394123340026, 0.03677587388665415, 0.019877763152180705, 0.05261468941171188, 0.05642856405756902, 0.014874786102154758, 0.04660078477172647, 0.07857739372411743, 0.04543963907053694, 0.024068233215075452, 0.06304488852038048, 0.04837012049392797, 0.04318270490330178, 0.029608983459183946, 0.023171267966972664, 0.012950980690220604, 0.027616560000751633, 0.054500197220477276, 0.03889994877681602, 0.022319180388876703, 0.027813535270979628, 0.051722594507737085, 0.016200658901652787, 0.024725017210585065, 0.009695757707959274, 0.017161920113721862, 0.023093886084097903, 0.06357199148624204, 0.016463885694975033, 0.035020338400499895, 0.047381479598698206, 0.016627601617074106, 0.06808862803154625, 0.04111357491638046, 0.03428426520258654, 0.038770970932091586, 0.0526658976014005, 0.05200751242227852, 0.04887944531219546, 0.029695540142711252, 0.05352850697818212, 0.06446638333727606, 0.01734177589241881, 0.042011651530629024, 0.0208671053769649, 0.06270137062529102, 0.0587750828708522, 0.022532325201609638, 0.0844686733034905, 0.04467168320843484, 0.11953581895795651, 0.02118898781191092, 0.0411943910876289, 0.06782673895941116, 0.04459496369236149, 0.022268265347520355, 0.024240097918664105, 0.020828422784688883, 0.038937527424423024, 0.013361083147174213, 0.038138460731715895, 0.06731134708388709, 0.05510555965884123, 0.02727152441366343, 0.033691456192173064, 0.02499149089999264, 0.06462041608756408, 0.04156256312853657, 0.07041647812002338, 0.01628896705369698, 0.010723835403041448, 0.01359960848276387, 0.005919615241509746, 0.04623859073035419, 0.05421616988314781, 0.08059126339503564, 0.024720371366129257, 0.009542878069623839, 0.01080229711078573, 0.012523269851953955, 0.07518540034652688, 0.038059485086705536, 0.05651257517456543, 0.07234442193293944, 0.07168770287535153, 0.01915761829877738, 0.015772946208016947, 0.03879632640746422, 0.015120660555112408, 0.056560094890301116, 0.04894370416877791, 0.029030663026787806, 0.06197877853992395, 0.0676440518873278, 0.04356928220659029, 0.005791717685497133, 0.05490388473845087, 0.04861559697019402, 0.03615022113081068, 0.09030253291712143, 0.009627654526411789, 0.03513531934004277, 0.028751891950378194, 0.09295360316173173, 0.03409617900615558, 0.020514566676865797, 0.07049478954286315, 0.09015814066515304, 0.009476013347011758, 0.06510929844807833, 0.031131792566156946, 0.02975095445435727, 0.04236580069118645, 0.025993720519181807, 0.0350084751698887, 0.005590264017882873, 0.041648986225482076, 0.02306061560375383, 0.038067366695031524, 0.12856080225901678, 0.05664928619808052, 0.020398550441314, 0.07006475949310698, 0.05006189807318151, 0.0446675754210446, 0.0220046860340517, 0.09878922908683307, 0.03465149100520648, 0.029224725367384963, 0.04437270159542095, 0.02731107346335193, 0.03217699624656234, 0.04563351772958413, 0.027553282634471543, 0.04036085163534153, 0.027767653846240137, 0.03767854068428278, 0.043637745329760946, 0.05931404906732496, 0.04371422735857777, 0.030099309296929277, 0.02907694892201107, 0.021401125159172807, 0.00562742196052568, 0.021667131295544095, 0.04360877188446466, 0.020765099034179002, 0.056758166683721356, 0.03339982926263474, 0.005717004751204513, 0.025243351701647043, 0.038712133464287035, 0.029734569689026102, 0.025040494911081623, 0.04117320648219902, 0.008214376211981289, 0.01779908358003013, 0.04672883493185509, 0.04744514844787773, 0.013725983244512463, 0.047053858506842516, 0.04186785670754034, 0.10099754144903272, 0.08367767746676691, 0.03973836785007734, 0.003315628237032797, 0.059234735745121725, 0.003167243462485203, 0.05869827058631927, 0.05764863999502268, 0.08684667031047866, 0.01482699828557088, 0.021076624798297416, 0.01664709227043204, 0.022976953296165448, 0.05476577105582692, 0.04548103235720191, 0.02551084584411001, 0.011580826721910853, 0.0066455720389058115, 0.023088392335921526, 0.07199075887911022, 0.028489216201705858, 0.01407881323757465, 0.0610224025149364, 0.04676618722442072, 0.048536832837271504, 0.040712202899158, 0.06825515112723224, 0.016925729760259856, 0.07383669537375681, 0.044779684249078855, 0.0993001606548205, 0.024789133203739766, 0.07295038551092148, 0.04600856947945431, 0.05589103020611219, 0.036320770377642475, 0.015479415669688024, 0.04953125877364073, 0.11057857147534378, 0.0543301748984959, 0.0388714688597247, 0.04286836825485807, 0.04264943840098567, 0.019427383413130883, 0.021781225368613377, 0.03531739414029289, 0.014815792783338111, 0.03203372463758569, 0.024595929899078328, 0.06303731119260192, 0.023717885705991648, 0.07211715404991992, 0.013357677617023, 0.02438096682453761, 0.041383560819667764, 0.041619905168772675, 0.05030296619224828, 0.10473738686414436, 0.03259642100601923, 0.025237251247745007, 0.04131533147301525, 0.03643410003860481, 0.09236280166078359, 0.008885246170393657, 0.014692797576572048, 0.02246621468657395, 0.030023207618796732, 0.03895452631695662, 0.03372130166098941, 0.05185902351513505, 0.019268456198915374, 0.03903151671693195, 0.040442161334794946, 0.02579631851403974, 0.041326459977426566, 0.06836888525867835, 0.020045885576109868, 0.007039764241199009, 0.028639716329053044, 0.0812820544524584, 0.05249787536740769, 0.012319274792389479, 0.030876649616402574, 0.025397955905646086, 0.025218554692401085, 0.039061054194462486, 0.08724569343030453, 0.00891715295438189, 0.042701344209490344, 0.08613725134637207, 0.016227956948569044, 0.02324575176317012, 0.03068143138079904, 0.013461752696457552, 0.024741012348385993, 0.04687777654908132, 0.02625879154948052, 0.07754672871669754, 0.030993266991572455, 0.01223369032231858, 0.07367589423665777, 0.05636416048218962, 0.06335576676065102, 0.09257326732040383, 0.06975337659241632, 0.021367088411352597, 0.020103437273064628, 0.05211769537709188, 0.04983110127795953, 0.06199961433594581, 0.07765913440380245, 0.044600778419408016, 0.007183886536950013, 0.05340964831702877, 0.041743086840142496, 0.02656557127920678, 0.04353237149189226, 0.04008639800304081, 0.05894945417821873, 0.05064358971139882, 0.03640281480329577, 0.02766184028587304, 0.026221474508929532, 0.03706919291289523, 0.07169093863922171, 0.023028901778161526, 0.04784639801073354, 0.007762501509205322, 0.04098966594028752, 0.033819780946942046, 0.06943405271158554, 0.02175755456846673, 0.017805746210797224, 0.0457039252796676, 0.022111690741439816, 0.008043985599215375, 0.04226084245601669, 0.013658264124387642, 0.04687900480348617, 0.039032147542457096, 0.05544348918192554, 0.028906767038279213, 0.058652914231061004, 0.011465633342595538, 0.05291137407766655, 0.06388630587025546, 0.059049057817901485, 0.04827486212889198, 0.02696537550946232, 0.034653505936148576, 0.03749577568669338, 0.039308564155362546, 0.0529883830313338, 0.043562599166762084, 0.00212107475817902, 0.05398548812081572, 0.04102390492334962, 0.011720359761966392, 0.030350786037161015, 0.02706312563532265, 0.04938885547744576, 0.03865565602609422, 0.06041132925020065, 0.012618685923371231, 0.02985138002259191, 0.039299153722822666, 0.060059220995754004, 0.05970198450086173, 0.06323167224763893, 0.01864927868155064, 0.006991092805037624, 0.010192599602305563, 0.01670339159318246, 0.010618520936986897, 0.015353342405433068, 0.0076523779262061, 0.08378637241548859, 0.01936278316861717, 0.04790502767718863, 0.01812167847674573, 0.011830769071821123, 0.0335785977949854, 0.04387957043945789, 0.03908938939275686, 0.02037175334407948, 0.05584473874478135, 0.017470549646532163, 0.026917905888694804, 0.1148220531467814, 0.20929226477164775, 0.18093492079060525, 0.12964920635567978, 0.15663280530134216, 0.11156629581819288, 0.21519898844417185, 0.14422848966205493, 0.18217663775430992, 0.1574197193258442, 0.15393836394650862, 0.06879688924527727, 0.08366592184756882, 0.10471775705809705, 0.1362420603982173, 0.12267124446225353, 0.14487393549643457, 0.11187341879121959, 0.20533324830466881, 0.09784439345821738, 0.10693286007153802, 0.16024007345549762, 0.14583509095245972, 0.19917533732950687, 0.04537850465567317, 0.14204213744960725, 0.20485766523052007, 0.13778121530776843, 0.13702529337024316, 0.2338720770785585, 0.1473901278222911, 0.1540900144027546, 0.09857327153440565, 0.22216429671971127, 0.14454307121923193, 0.16231630579568446, 0.11970622348599136, 0.11449535973952152, 0.15578726161038503, 0.16129316616570577, 0.23723902297206223, 0.14046056137885898, 0.15393673122162, 0.14972700242651626, 0.20254344097338617, 0.22162972774822265, 0.10696074255974963, 0.15019344224128872, 0.1204421668080613, 0.11856891927891411, 0.2694259973941371, 0.10167955289944075, 0.16074160201242194, 0.15863667824305594, 0.12910648860270157, 0.10741219841293059, 0.1275894942227751, 0.23028076509945095, 0.1102641828765627, 0.14844957331661135, 0.1342890691012144, 0.06989326400798745, 0.15646055282559246, 0.17700290365610272, 0.13337653916096315, 0.08558762419852428, 0.09261657905881293, 0.209074474114459, 0.0879791950865183, 0.06794583139708266, 0.1807470535277389, 0.24553507624659687, 0.11192785532330163, 0.16394877835409716, 0.11282692270469852, 0.19899437204003334, 0.1461422213469632, 0.2163108592503704, 0.058048624196089804, 0.11352942485245876, 0.16659894317854196, 0.18080716748954728, 0.2654095535399392, 0.19465067074634135, 0.08316158055095002, 0.18823608057573438, 0.11249875984503888, 0.06965125707210973, 0.16939048713538796, 0.13265083747683093, 0.16219097189605236, 0.1617581958998926, 0.18097015796229243, 0.07938373717479408, 0.23549518373329192, 0.18670931953238323, 0.07786332149407826, 0.09871416084934026, 0.10914664948359132, 0.17152110405731946, 0.13625809078803286, 0.14491224515950307, 0.06425961357308552, 0.11169971170602366, 0.10023499955423176, 0.1840254315175116, 0.1387527459883131, 0.10901003493927419, 0.1938494629575871, 0.17566800263011828, 0.13507222785847262, 0.1355428682290949, 0.09995644926675595, 0.1160652469843626, 0.20115963241551071, 0.1368011350859888, 0.17502116155810654, 0.052099308668402955, 0.1995948437252082, 0.09678567526862025, 0.10653474237187766, 0.21515171363716945, 0.1234781371022109, 0.07165259929024614, 0.20184251217870042, 0.10246963589452207, 0.12415809280355461, 0.12695990066276863, 0.18909863429144025, 0.13562033360358328, 0.12211770619614981, 0.0958902295678854, 0.16511179797817022, 0.13911580463172868, 0.10160826219362207, 0.198820709483698, 0.07517278383602388, 0.1340766515932046, 0.09438833789317869, 0.10423377287224866, 0.24537716206395999, 0.17066592728951946, 0.15899759950116277, 0.24329469568328932, 0.12064481765264645, 0.09435926796868443, 0.11524803107022308, 0.08324218521011062, 0.08740242017665878, 0.12134458127547987, 0.10119460392161272, 0.07521714942413382, 0.08402947030845098, 0.19802753173280507, 0.221529834670946, 0.14547952800057828, 0.17272293800488114, 0.11641346267424524, 0.11743148890673183, 0.07870400411775336, 0.13301256025442854, 0.10367670198320411, 0.14029736310476437, 0.1183323968143668, 0.23818900168407708, 0.17879719409393147, 0.10440970640047453, 0.08073737000813708, 0.1639234711183235, 0.16270231164526194, 0.13011064409511164, 0.08924063833546825, 0.11202848312677816, 0.08613670957856812, 0.09712160841445439, 0.15521549619734287], [0.032637903350405395, 0.05300860655552242, 0.03453629855357576, 0.10332040430512279, 0.016041989583754912, 0.08753752073971555, 0.04077353769389447, 0.06176268740091473, 0.02744765461102361, 0.06743372723576613, 0.01809584802686004, 0.026077110087499022, 0.04568769450997934, 0.015457346980838338, 0.08800377501756884, 0.035778805904556066, 0.027448673208709806, 0.047699816423119046, 0.028399659386195708, 0.06104951688030269, 0.08655920682940632, 0.03674734944070224, 0.05014567170292139, 0.026714819032349624, 0.012613601284101605, 0.036707043400383554, 0.03749978328414727, 0.018217035176348872, 0.012953568930242909, 0.072148962499341, 0.02976470274006715, 0.02587273746030405, 0.020819752644456457, 0.03188749557011761, 0.0552380033332156, 0.011479681270429865, 0.05420268505986314, 0.029016992666583974, 0.07266614295076579, 0.0597966046188958, 0.06762280419934541, 0.0384581111575244, 0.005706887886844925, 0.02749540624790825, 0.017016963829519227, 0.07473028570530005, 0.022044524521334097, 0.05267798718705308, 0.052747262961929664, 0.03865055005007889, 0.03919927177776117, 0.009548492416797671, 0.011003326362697408, 0.04191506843199022, 0.03359915157489013, 0.02114713624905562, 0.03283235717390198, 0.075900808442384, 0.05272365524433553, 0.02963068756798748, 0.022641190844296943, 0.03071752202231437, 0.08926365233492106, 0.005925446666878997, 0.07813133328454569, 0.031255271096597426, 0.01955418862053193, 0.015185521478997543, 0.058958478693966754, 0.0484315740322927, 0.03764197877899278, 0.040294076898135245, 0.016238105818047188, 0.05514739823411219, 0.051510176999727264, 0.012019416517432546, 0.035101781686535105, 0.03080198213865515, 0.11133459731354378, 0.04194755594653543, 0.03625611076131463, 0.005457938159452169, 0.06162554593174718, 0.02644195545144612, 0.011737714885384776, 0.023550759615318384, 0.0879965687636286, 0.05328530889528338, 0.006834122541476972, 0.03572632122086361, 0.03772724412556272, 0.058273123868275434, 0.04143402686167974, 0.019522029506333638, 0.11026191932614893, 0.028278815480007324, 0.03378865527338348, 0.03720712105860002, 0.06082128791604191, 0.03165258727676701, 0.03769798866414931, 0.02578021762019489, 0.006644403620157391, 0.0077300362590904115, 0.020768841313838493, 0.06532985731610097, 0.043845305481227115, 0.030033794355404098, 0.05562222431763075, 0.025382576750416774, 0.02271422003104817, 0.05077665678982157, 0.01914458433020627, 0.07088852857123129, 0.03744458233995829, 0.03244224724767264, 0.0016110938349811477, 0.03202654064807575, 0.06496424568467773, 0.015521114164585015, 0.0770897141774185, 0.04020425105409231, 0.018380025649094023, 0.01794959112885408, 0.05583188474702183, 0.1621519200853072, 0.1348760782275349, 0.06537564782775007, 0.020619554597942624, 0.04082585910509806, 0.04615263518644497, 0.03469948940619361, 0.027177911761100404, 0.07624369551194832, 0.033710540519678034, 0.03265048275352456, 0.012148505684308475, 0.0009055383873146639, 0.04846932708460372, 0.06083254629629664, 0.03282937374024186, 0.07396981440251693, 0.014214204165909905, 0.07690470418310724, 0.03351120336446911, 0.05225676271948032, 0.0025853041324808146, 0.047843870997894555, 0.0629488100821618, 0.07839861034881324, 0.020423460628080647, 0.004296695051380084, 0.07596150870085694, 0.08641672189696692, 0.02421248260361608, 0.05197667618631385, 0.02447106355248252, 0.012928710693813628, 0.05902891592995729, 0.05240448721451685, 0.028423024050425738, 0.010685779925552197, 0.04445475715328939, 0.05560016397794243, 0.020526960543065798, 0.02191096020396799, 0.04791146951902192, 0.06399826626875438, 0.008188559677364537, 0.004285393533791648, 0.018223579063487705, 0.025207331564160995, 0.04451468186744023, 0.008540834915038431, 0.06832066050264984, 0.03504656961013097, 0.04802732990356162, 0.04612204014847521, 0.017486631986685097, 0.03048878654226428, 0.04893079450994264, 0.02371963346377015, 0.037726067821495235, 0.04401208832859993, 0.031138983977143653, 0.048532543223700486, 0.02222987404820742, 0.03039524995983811, 0.09072459972230718, 0.05836352858750615, 0.024251090981124435, 0.0366222456068499, 0.02716974813665729, 0.014799630662309937, 0.018731584714259952, 0.07553060291684233, 0.07396150977001525, 0.05336370937584434, 0.02711760113015771, 0.01416063501892495, 0.08539320377167314, 0.015606853557983413, 0.05748445095377974, 0.020987413081456907, 0.070872171636438, 0.02481598967278842, 0.02378872926783515, 0.016751172915974166, 0.01306355985434493, 0.03903844837623183, 0.037338243710109964, 0.033624956049607135, 0.028027095686411485, 0.023045136258588172, 0.05483567023475189, 0.04025808273581788, 0.0451803289615782, 0.08662074571475387, 0.029268218931974843, 0.028110223647672683, 0.031054804021550808, 0.07730110010015778, 0.022810699229012243, 0.02205598142609233, 0.05930502084083855, 0.04490253937547095, 0.0496332929469645, 0.02195629058405757, 0.05538357931072824, 0.029257355745357927, 0.021136237810424063, 0.025099427002714947, 0.023329391806328204, 0.029966168003738858, 0.09626496219425462, 0.01950162972207181, 0.034341729697189294, 0.04114805138669908, 0.039685207811999135, 0.012403512264427263, 0.014928858054190641, 0.049374895679648034, 0.03600501993787475, 0.0356493048457196, 0.09528362032142468, 0.04770979088789318, 0.018945146985061, 0.03096543274295982, 0.053998572184355, 0.024834096220729407, 0.050744655382004566, 0.0837423482153099, 0.040883906185626984, 0.01643985124246683, 0.016793393697298598, 0.02345597808016464, 0.030407072372327093, 0.05682133087248076, 0.036877036036457866, 0.051955862654722296, 0.05567560700001195, 0.020521908372757025, 0.033955961334868334, 0.03290466091129929, 0.02413134916423587, 0.030819075655017514, 0.007214907845991547, 0.03956381100579165, 0.045794715915690176, 0.015729486040072516, 0.16402821784140542, 0.10958503611618653, 0.016513082664459944, 0.0362527970719384, 0.024829732392390724, 0.004994061073375633, 0.0364153348346008, 0.038263590540736914, 0.06659155289526097, 0.05810551723698154, 0.05045534766395576, 0.06216208901605569, 0.009164079401671188, 0.05601919910986908, 0.05556664487812668, 0.07961650437209755, 0.07625199272297323, 0.08953021693741903, 0.052264744517742656, 0.01664993840677198, 0.03377472145075444, 0.0063159856472339015, 0.025932866265065968, 0.035199578196625225, 0.011135399890918052, 0.012111254509363789, 0.04653965777833946, 0.05021618686441798, 0.0451375255943276, 0.0272409442186472, 0.0527762030105805, 0.05632742046145722, 0.0527924486232223, 0.027399697028158698, 0.055687225321889855, 0.003919395057891961, 0.056421420886181295, 0.039287078980123624, 0.022456212391261943, 0.03839529577817302, 0.053372418478829786, 0.04620062987669371, 0.0306002163051744, 0.013411886866379064, 0.07345302728936076, 0.036761817609658465, 0.06832692422904074, 0.07615727983647957, 0.05388570636569057, 0.06703001374262385, 0.0830832617066335, 0.057928644891944714, 0.02229501977126347, 0.049623967861407436, 0.03267961947130971, 0.06664025262580253, 0.029080865606374573, 0.026770203658088576, 0.06012982892571017, 0.01858573599747615, 0.020673673861892894, 0.021228032201179303, 0.03176616555720102, 0.04540801986877341, 0.047995877685025334, 0.02595033642137423, 0.08016942665562965, 0.009298063960159197, 0.014475148855126463, 0.02869536998332478, 0.022270430563366972, 0.0076570080000237795, 0.007982133156474447, 0.058025547114084475, 0.04409065208164975, 0.03218707090127282, 0.06358884565997869, 0.003516563328958, 0.02138508549251128, 0.029663043351320084, 0.055482233001384884, 0.07367659185547382, 0.10000387250329368, 0.14565457095159218, 0.10812815569806844, 0.21485763019882143, 0.18043848336674273, 0.1498908389476128, 0.07887627885793336, 0.16375826904550195, 0.11887081011082046, 0.15324919077102095, 0.08326099865371361, 0.07109977348591201, 0.1784578841761686, 0.11215229562367313, 0.11405890269088559, 0.15580686915200204, 0.1922863515210338, 0.23552291037049145, 0.08019883796805516, 0.1747907989192754, 0.13540358195314184, 0.1401242645806633, 0.1322096009971574, 0.0741149859095458, 0.1603228526073508, 0.13038566918112338, 0.16861391864949837, 0.13102210534270853, 0.11339612770825624, 0.2041936805471778, 0.1665431188303046, 0.143600944429636, 0.11607637177803554, 0.11990396873443387, 0.18906704848632216, 0.13120731571689248, 0.1284632395254448, 0.07633644170709886, 0.141384698508773, 0.14522299723466858, 0.11354754809872247, 0.22042216442059726, 0.13029100082349032, 0.05514805503480602, 0.0956385450263042, 0.19521704816725105, 0.13710685539990664, 0.09589676788891666, 0.12040685542160645, 0.0824952803668566, 0.12524334277259186, 0.10135494492715225, 0.12650588440010324, 0.1375865945010446, 0.07164688475313596, 0.1422872391412966, 0.1006252430670429, 0.10947349132038653, 0.2942373894620687, 0.10961619889712892, 0.0823205936467275, 0.1236388566030655, 0.19010906835319474, 0.15414230612805113, 0.23296368832234293, 0.15625318192178383, 0.19446096295723692, 0.21702290541725233, 0.19055785989621654, 0.09429928759345785, 0.2232231930247508, 0.19116484763799235, 0.09727788987220265, 0.12761876452714205, 0.13936384522821754, 0.15487588942050934, 0.17705492820823565, 0.13847469293978065, 0.20158089027972892, 0.1263763796305284, 0.12004375224933028, 0.13600819482235238, 0.11941766904783435, 0.10492354718735442, 0.17444267228711396, 0.14922593400115147, 0.21310654759872705, 0.10391122807050124, 0.10483981066499837, 0.1105691387783736, 0.10373018856626004, 0.19110571331111714, 0.11868763322127052, 0.08956799225416034, 0.23055071389535442, 0.16560505900997669, 0.11813788732979447, 0.12933845428051427, 0.21284367889165878, 0.18424546346068382, 0.18429895746521652, 0.13276677578687668, 0.13744194991886616, 0.17840851651271805, 0.16602129995590076, 0.11594789117225446, 0.13516967184841633, 0.11071298184106126, 0.1359475910430774, 0.13815154699841514, 0.125002961140126, 0.3202103910734877, 0.2015742109506391, 0.10628848292981274, 0.09302557664341293, 0.13121221389155835, 0.21959563455311581, 0.09059298725333065, 0.12420467741321772, 0.15081326913787052, 0.18357521505095065, 0.16682820743881166, 0.18503619212424383, 0.07317788345972076, 0.1484157907543704, 0.33419399696867913, 0.20189827715512365, 0.1969293609727174, 0.16534751892322674, 0.13049900997430086, 0.13077951211016625, 0.11779678883613087, 0.130209052877035, 0.16989985277177766, 0.10435094314743765, 0.19122705445624888, 0.13478115753969178, 0.0813044302049093, 0.15438706643180922, 0.14976489648688585, 0.22140349145047367, 0.18914193118689582, 0.18170210852986202, 0.16587414691457525, 0.16485508909681812, 0.11792599674663506, 0.053093485985300504, 0.13850002986146137, 0.14952307508792728, 0.23134791408665478, 0.08107209345325828, 0.08926819427870214, 0.17560068983584642, 0.23433237191056833, 0.052651154837803915, 0.1248056092299521, 0.133000596833881, 0.20784341439139098, 0.10180350640439428, 0.15453977073775604, 0.11976123147178441, 0.09961777017451823, 0.12495044677052647, 0.11818083541584201, 0.17305090790614486, 0.15739554015453905, 0.07593732210807502, 0.18368261866271496, 0.2053235558560118, 0.11634948954451829, 0.16350515215890482, 0.1314459161949344, 0.13286221597809345, 0.1751414340105839, 0.1641906739678234, 0.1446914710686542], [0.02966549243865302, 0.033932528021978214, 0.06695264484733343, 0.045918205578345805, 0.02187628149840748, 0.0673850423481781, 0.042468617830309086, 0.008211074582504807, 0.024953706306405365, 0.009998464902309934, 0.017539189029776026, 0.049114787761936896, 0.025612828067096416, 0.03372306797245983, 0.03181398584274575, 0.025659605635155458, 0.040212485182564706, 0.016075651546998415, 0.023299221647903323, 0.03463360895693768, 0.05999484710628167, 0.03348169928358402, 0.03389340570720378, 0.03905656420101877, 0.03729716954694595, 0.01921186372783268, 0.020507872504822444, 0.03398837463464588, 0.032922249811235815, 0.028462810587370768, 0.04527946875896305, 0.059680076301447116, 0.06562771828612313, 0.06207523918419611, 0.020607058686437085, 0.023293200974876527, 0.020021186901431065, 0.009065291196748149, 0.01319718354352517, 0.06411354406736791, 0.029047096031717956, 0.04331816169724334, 0.009144044197455514, 0.01728638384520309, 0.08517491587554105, 0.005289452547003748, 0.0673403799009975, 0.026530725590419024, 0.08913500103517435, 0.026112764717254322, 0.03175864017975982, 0.10768875974463299, 0.0749554013600573, 0.026672856147342827, 0.017179215865326114, 0.038223369847401045, 0.04434172064065933, 0.040343388900510035, 0.06305673319729976, 0.017031454262905754, 0.028359512907627504, 0.01338333737294306, 0.028322255238890648, 0.06549276615260169, 0.02117807453032583, 0.007064332112349803, 0.11411609259084798, 0.019245342009526212, 0.01362580165732652, 0.030996035202406347, 0.024066398254944943, 0.027632295386865735, 0.022222673360374756, 0.047482890367973596, 0.007026357807262684, 0.07330281659960747, 0.027308049211569596, 0.03118009895842988, 0.05421458168711979, 0.03918597249139566, 0.0446217849093955, 0.034582894295454025, 0.036523662420222536, 0.023188057202787604, 0.02236002077552257, 0.031083213434612844, 0.037428021314553916, 0.01504876685430645, 0.056901772259152494, 0.02593371787952492, 0.08095208075246774, 0.05586867671809159, 0.05095073865959421, 0.04277201893273741, 0.07728600481641479, 0.06739327276591212, 0.06812189109041356, 0.055269704171223566, 0.04321732238167897, 0.0425716390600428, 0.05656795052345842, 0.024603490528534167, 0.07299916687770747, 0.04777874382853042, 0.0825948543206323, 0.04879032450844534, 0.013200544544815784, 0.04215712360746693, 0.045368400315055624, 0.007107120636646869, 0.037915864668320864, 0.07320090488065034, 0.02653490759257693, 0.038290730881271884, 0.031461502803722396, 0.06710039902827702, 0.05044692057708744, 0.01888482893264154, 0.03318051349197049, 0.04840641522605438, 0.04226124321576208, 0.02567609986726893, 0.10388411741587333, 0.014997266443970148, 0.09705883756396361, 0.023798983893357217, 0.09789781324798241, 0.04032227850984782, 0.055368936737068, 0.07410418766085058, 0.02332744923478458, 0.034380907673039474, 0.02709335516556166, 0.0033577228532521985, 0.0123112141409365, 0.017573077348060906, 0.09462896443437785, 0.06956902710953727, 0.01731691951135872, 0.019438335657468997, 0.04163186487858184, 0.054239618038991466, 0.057699198805494234, 0.0743839328060858, 0.033502657533972524, 0.03544984894688241, 0.07414719511871226, 0.08835274027660489, 0.08204795827623457, 0.05430638906545937, 0.014528711508319248, 0.023839744499127846, 0.0350647114100866, 0.056991972887772135, 0.020410168763191905, 0.03181423817295581, 0.022817608623881824, 0.022202807922440115, 0.04062899330165237, 0.015483546649193158, 0.04321383799833711, 0.007922083204903174, 0.020328092796262354, 0.03950306250771973, 0.07645341902389191, 0.03906044934410602, 0.01990808916161768, 0.035858560804626904, 0.03145105336443521, 0.037621076189680025, 0.018397642379568424, 0.008418313755100826, 0.06736242910847068, 0.05651796316669788, 0.07035332135274075, 0.05237566590949427, 0.09822369029279798, 0.0076659550541080534, 0.02301950618857518, 0.0374185960390605, 0.04913819509965833, 0.027736186784750316, 0.12080877291737124, 0.00787701907029259, 0.04313333352911286, 0.02255609619169263, 0.03021364642336266, 0.1232959472690709, 0.0475757553067524, 0.006400761640179553, 0.038026010515750386, 0.02531645881390432, 0.029710557500948198, 0.03700615488924086, 0.0438594062870834, 0.022579741016670596, 0.032847278052940965, 0.03667909782961942, 0.03012248100276338, 0.02750596329860855, 0.04458457733562682, 0.029150373302400112, 0.017416118680557702, 0.01872228560387157, 0.010351626078772824, 0.030432286839641165, 0.052384159789653495, 0.012425497461663326, 0.016371395540772937, 0.0625509669771418, 0.03137075298582204, 0.04665428990847431, 0.029670861877093557, 0.053984853584552184, 0.038408027321565896, 0.030590824426326435, 0.03840668774500955, 0.011326884196023457, 0.033020239279721864, 0.029515005298890173, 0.08415540534770116, 0.04146930114075076, 0.014597171848436119, 0.03392190417798702, 0.06450934626627713, 0.049810951968538575, 0.022463570785475895, 0.09164434333797544, 0.02263227208459284, 0.03705679904669523, 0.0836146913934499, 0.027868582219525706, 0.0423019834124716, 0.03863770718453452, 0.04321341126342304, 0.08069689327385277, 0.027785517340817023, 0.010814761481015012, 0.026528306188993156, 0.02862489563995041, 0.0833035608229693, 0.018168751048506238, 0.0338604469288839, 0.025645588320912793, 0.06605213027796708, 0.04122653350350447, 0.016308335252688266, 0.05170595184608828, 0.035800621335511096, 0.029902937021688558, 0.05330212596163619, 0.05023369783884846, 0.018427116774546448, 0.012359870270302054, 0.03201217266905587, 0.02226384214736754, 0.05327604689227883, 0.026760769105749205, 0.03856643503240775, 0.05203564352996182, 0.07499244195059873, 0.03353595770022366, 0.025517989015497733, 0.007445166584147955, 0.012786805564246606, 0.007750139648123877, 0.06902967870701104, 0.04713045556854922, 0.010771351408038754, 0.029365442132984754, 0.01184966600703774, 0.07513467455282807, 0.0432620219362434, 0.04669988004025072, 0.12383956302073784, 0.0609680698835291, 0.07220569968922064, 0.016178336954908445, 0.04830115271033719, 0.06835105887148529, 0.01887365033326205, 0.009864705771178706, 0.03839015269477386, 0.0540374792763032, 0.02792908580886433, 0.044706950066029094, 0.035830296110361814, 0.047911647634464316, 0.05163288369658403, 0.05485077665071003, 0.01346482518783887, 0.018997021252289414, 0.047698439739178866, 0.05501244610059075, 0.0204468642550637, 0.00696787517881603, 0.032205279494519345, 0.06448212428949773, 0.04263955299393274, 0.019003618945134804, 0.07237245285068639, 0.03078261393966386, 0.05138721797266044, 0.05996168423735071, 0.028304473380558193, 0.046102595879347064, 0.07054348185192794, 0.031392486780532636, 0.008331633689522278, 0.04249899022397585, 0.020586198770615738, 0.0244612412279821, 0.04111546739295591, 0.06958547310205176, 0.016524487618880812, 0.03704804912558757, 0.02395557519776048, 0.04893034179985989, 0.07010007087956183, 0.07700547299464233, 0.03764459484955296, 0.04204159718938172, 0.024763057845120784, 0.027290872203593608, 0.019523402479535434, 0.035954119739471935, 0.05281761485093739, 0.017078070413845126, 0.0481829879572615, 0.0419077471451601, 0.029103430606483016, 0.013766707670583855, 0.04705713508883491, 0.05287813699396793, 0.04584114096360281, 0.04648267939046491, 0.017983932157221716, 0.027474294001876842, 0.05825861117045861, 0.015015201370260911, 0.05962969931715634, 0.09706708282465115, 0.042063338405569084, 0.026418288362037856, 0.04458609131688718, 0.01052861809512251, 0.05371376930270344, 0.015169130219874205, 0.027004087787645403, 0.020719302956422325, 0.0698479484708514, 0.06726717445417307, 0.13713930209632963, 0.12055027546011843, 0.16949306678725407, 0.1553829840850085, 0.09092910593608394, 0.161021733074449, 0.19709848158527166, 0.07524857937823981, 0.14307965990155935, 0.1374195222160779, 0.08984494692413136, 0.24960931856185198, 0.18964650254929438, 0.05433774851553608, 0.09468987991567701, 0.13135498826159164, 0.16269123880192637, 0.1564243360189721, 0.16936142463237047, 0.12299870970309712, 0.16489854926476255, 0.08164331709849648, 0.13714620406972244, 0.1044617903244216, 0.054299312687362544, 0.16455506847705692, 0.08061768385232426, 0.0646768489968963, 0.13010151567868888, 0.10944617286440916, 0.12149423535447568, 0.1669715903699398, 0.1673142844811082, 0.2016092254780233, 0.23585151851875708, 0.27644629881251603, 0.09716126878629439, 0.12054464998072945, 0.16131461423356086, 0.1249812904279679, 0.08737201438634656, 0.11703755691996776, 0.10238464514259249, 0.13540760439354926, 0.15796294173924252, 0.06600846973014995, 0.10509669024031609, 0.11602949773077853, 0.2252074732678011, 0.1632394187618047, 0.06815416709287092, 0.2183824309031479, 0.15554443089058623, 0.11440479545854032, 0.14017302368301898, 0.1078136706200894, 0.14526567072607577, 0.11887931512319483, 0.16236267518252134, 0.1854644261766225, 0.11565427528694272, 0.13930417655501515, 0.14420141611481085, 0.19854728743666783, 0.17941249388968572, 0.12100009858841076, 0.2881401713239029, 0.14877497538691387, 0.1783299379167147, 0.10332605204894207, 0.13871261064196005, 0.163565399707295, 0.16565972560783848, 0.12781476572854444, 0.09291662194300443, 0.14510950801195577, 0.12123038701247424, 0.11049176246160641, 0.10990092385327443, 0.14692548400489613, 0.24876291397958994, 0.07236448960611597, 0.10505110010853969, 0.15048617497086525, 0.15766605298267677, 0.07732449259492569, 0.12715541204670444, 0.09726200049044564, 0.19497420260449871, 0.06530020109494217, 0.15696320944698527, 0.11006125001586042, 0.1041533166426234, 0.15557917824480683, 0.14981491724029183, 0.15213788399705663, 0.13769073266303167, 0.17104264145018533, 0.25633510609623045, 0.10893446204136126, 0.10456998803419992, 0.12500325799919665, 0.13480544061167166, 0.1608536663115956, 0.17458593647461385, 0.11906859988812357, 0.2018887925078161, 0.22628367645666003, 0.15323308616643772, 0.10798544812132604, 0.1235202762472909, 0.16144011140568182, 0.10241234951536171, 0.13023741776123643, 0.1985569205135107, 0.18617917376104742, 0.184184473764617, 0.13148085650755093, 0.0876643240917474, 0.10590001314994879, 0.13539850566303357, 0.12550434126751497, 0.13725253898883238, 0.064511988312006, 0.15612023358698934, 0.08378024227567948, 0.15749172249343246, 0.20596641901647672, 0.1142978593998123, 0.11707254176144488, 0.13544429617468268, 0.13567431742558256, 0.19776675588218495, 0.1537698964239098, 0.060952473650104366, 0.11115267465356737, 0.17340794031042606, 0.1542652799980715, 0.04068819442181848, 0.11312596368952654, 0.1325165235903114, 0.164678368892055, 0.1550748888985254, 0.16142097883857787, 0.14022225775988773, 0.10238440765533596, 0.15067966771312058, 0.1494781899964437, 0.12852878600824624, 0.13950920227216557, 0.1781240216223523, 0.11656531351036392, 0.15173693129327148, 0.1200482645072043, 0.09882894140901044, 0.17138822993729264, 0.18232569069368765, 0.07500330699258484, 0.1291739201406017, 0.1704160906956531, 0.0663677285774611, 0.16143818182172254, 0.15132557367905974, 0.10533581764320843, 0.18055664811981842, 0.12637198611628264, 0.09835602264502086, 0.10535332490690053, 0.28665893361903727, 0.09413297972059809, 0.10728181048762053, 0.17472032457590103, 0.10374112040153705, 0.17241788562387228, 0.16168828558875248, 0.24836127849994227], [0.03622769392677583, 0.053798912194906734, 0.01178362228529295, 0.007886304265412036, 0.016952571386354975, 0.04207427395158447, 0.040553427825216204, 0.06580542554729618, 0.041074716064031236, 0.042076971658389084, 0.02303438253875356, 0.043900985110667534, 0.007044276962915319, 0.07878051954321563, 0.019404007616685703, 0.04711985769972671, 0.012062952755513834, 0.01734718243824318, 0.0369216910621617, 0.01900180068332702, 0.017346163840556983, 0.07105536336894147, 0.03595488415157888, 0.03940521775803063, 0.027716733238776214, 0.08568284174543805, 0.015684743812016677, 0.051373042952036485, 0.06880196553538553, 0.04538203727861401, 0.05331459775334224, 0.012301441911404254, 0.06741757068084553, 0.03869134219712578, 0.025920951084117405, 0.03771472038351931, 0.04423298487381544, 0.02476804693287704, 0.03159747167956084, 0.020122182068007533, 0.013234519137768075, 0.018669264718482736, 0.051156692061340436, 0.04099147306988016, 0.058188871553284116, 0.07275368669070303, 0.06366593253915198, 0.011426999917603098, 0.03034490637219278, 0.04848535747441929, 0.02359201189392479, 0.06667298133834265, 0.03820781814283691, 0.04715307251899503, 0.031360997454612516, 0.02647894409165019, 0.06355723016895354, 0.017322446656180546, 0.061942094180267304, 0.07090737912221812, 0.047129598387982696, 0.006997442342253635, 0.1223895326256752, 0.020863459576503374, 0.021205699122219812, 0.05143531285284553, 0.04014965124952141, 0.03968963101215195, 0.0318926980253309, 0.0697549944743514, 0.033210589026566595, 0.11088924933574162, 0.11912998292245902, 0.037356148022809066, 0.03967164135247003, 0.04433952759427484, 0.003554695804268704, 0.032369153122999705, 0.05424424532975536, 0.03842520804028027, 0.01163595808975515, 0.030494849888782483, 0.04048252674692776, 0.03712286132213194, 0.016117306440719403, 0.04328514354710933, 0.03423352085519582, 0.06920992411323823, 0.015778567976667546, 0.04359903861768544, 0.028587355955096427, 0.021574498277914245, 0.07621872224262916, 0.03120312037935946, 0.06835212756413966, 0.02353522646444617, 0.009957750680769095, 0.05301035431330092, 0.05528334113478195, 0.01794907162548043, 0.02163234126783209, 0.04864497488597408, 0.04031329481222201, 0.014373368867381942, 0.010620180564728798, 0.03354301552462857, 0.07573041875730269, 0.08347691167728044, 0.03309004197944887, 0.0775334145873785, 0.040765088342595845, 0.04514153319178149, 0.029578214016510174, 0.0703724093909841, 0.06088014764827676, 0.07739168664556928, 0.007521145344071556, 0.020144472473475616, 0.012911521625937894, 0.009491127184446668, 0.0338871827989351, 0.024027337167353835, 0.027125041160616092, 0.05921200747252442, 0.011727249675459461, 0.0075705204289988615, 0.017016201272781473, 0.062610546592623, 0.03864770020300057, 0.021681720063497778, 0.04186543359537609, 0.022538414523296524, 0.03497082601825241, 0.014123347664281027, 0.010011235408455832, 0.02465182846208336, 0.06060195359168574, 0.01678359734796686, 0.08229832179495133, 0.0530335093208123, 0.014649555414507631, 0.04845128918532282, 0.021991978610458318, 0.017587929578439798, 0.07505591784138232, 0.031965402522473596, 0.01991064586036373, 0.01729102041281294, 0.03750889314687811, 0.0855112200952135, 0.0344901666539954, 0.023727845327812247, 0.025580463006917853, 0.06707662061671726, 0.02806693231832469, 0.017206870143127162, 0.015922969505481888, 0.01095956005883636, 0.022425507886509877, 0.0716321160143707, 0.07157201689551584, 0.026776294835144654, 0.03535440133418888, 0.02888176964916056, 0.048303382864105515, 0.05181616077607032, 0.023769509498379193, 0.019291767057438847, 0.031908079035929404, 0.034529211043263786, 0.05471914562804159, 0.06198047434736509, 0.008789707644609734, 0.010947320188279264, 0.023340481347986497, 0.04821872978936881, 0.050459574194974266, 0.040432854802929796, 0.039696948588243686, 0.018927010751212947, 0.015470367034140509, 0.05084978802187834, 0.042343450913904235, 0.02244188894110266, 0.01765309199981857, 0.02516519984055776, 0.023522942065028474, 0.08477683528326452, 0.013485538529494079, 0.00721285116924264, 0.028311074784141965, 0.01976923147594789, 0.01158132303316961, 0.03773117008677218, 0.0790196617890615, 0.007106142857082887, 0.008822776817396516, 0.07334317459026352, 0.05918830698647071, 0.021254784769553225, 0.03149558964651078, 0.04215910143102519, 0.0472132569848327, 0.012899211251351517, 0.013557715174101759, 0.01744013643474318, 0.04614791141648311, 0.08528910271706991, 0.006448039230235736, 0.03952796156227123, 0.016423574088548776, 0.023691519054409582, 0.030970911648182664, 0.06997286676778458, 0.04013837060483638, 0.04545103474811185, 0.05786484616692178, 0.04103101840883028, 0.05574176204390824, 0.06132455680926796, 0.015699384530307725, 0.11792639750638045, 0.02333831613213988, 0.026728227785497438, 0.0984138211060781, 0.03554302929842379, 0.05965617543552071, 0.014947402469260851, 0.00834138458230882, 0.02586559799965471, 0.04982051825209055, 0.03475584810075816, 0.016283293334709015, 0.027392110423534177, 0.04459428462723736, 0.09542499945382588, 0.00415523521041905, 0.07947411591885611, 0.03507479348627385, 0.02816465090290876, 0.05855066112417262, 0.01944120962434681, 0.02213213319919305, 0.06488105093012564, 0.06393381074303761, 0.012094786252418999, 0.005032135568399099, 0.04878038715105504, 0.05399654612119775, 0.0651639947318472, 0.017795588064473122, 0.06745278558810242, 0.025649443778092973, 0.016859506067703478, 0.020944574462191667, 0.026380574272479862, 0.014994190241850447, 0.11204811293282546, 0.04564873917843215, 0.06880100816488266, 0.05673408028087579, 0.022463355562649667, 0.06174271991767455, 0.016910595513763838, 0.1053356692136731, 0.0686335499631241, 0.032121253534569405, 0.029030176920059603, 0.059132809183211066, 0.014488071501546074, 0.04959476435033139, 0.03518465360684786, 0.049434007742092945, 0.016300346032949165, 0.055666226253379136, 0.07956759684020653, 0.043941346812061965, 0.04739689771668054, 0.03694795195769984, 0.04622542503057048, 0.033646886513452046, 0.05864268372533843, 0.015971633984008804, 0.02623195920023136, 0.027722978411475196, 0.04434163529367652, 0.07244191045174375, 0.02530040430428926, 0.03906251993612386, 0.08175212336936966, 0.021155815666134004, 0.026376501737104263, 0.02973565879074158, 0.01990588312764885, 0.04442039200512227, 0.03315556990855839, 0.016533009329577908, 0.05164532209164463, 0.015252594002959086, 0.057206442434107885, 0.042483457073103637, 0.08302980480948463, 0.032471940576215275, 0.0461787662061397, 0.038352002593455836, 0.020389325545693282, 0.05294685244734865, 0.05017650793888606, 0.0283857181420899, 0.036684701044578105, 0.014701472355227452, 0.025270323203585576, 0.031686919028288685, 0.019075065501965582, 0.06027838462614454, 0.044977926736464724, 0.05999142209475394, 0.05619413444946986, 0.07191813972895034, 0.00766110882977955, 0.046467090578516945, 0.07296482770470902, 0.012770113735314226, 0.05720663168176543, 0.06701151942252181, 0.01731928510707803, 0.018816126466845162, 0.031730746559333056, 0.015871017312747426, 0.07884044054662809, 0.036620609171222895, 0.05027014471124858, 0.03886604376020841, 0.01453815255445079, 0.07338506140513346, 0.06770942025468685, 0.03279719050624408, 0.027898271837329958, 0.04209274971799459, 0.04838342349103186, 0.057352070361957885, 0.016851707950991113, 0.042872505728155375, 0.03873739617120009, 0.017199164794874378, 0.026272074137523305, 0.037567853069049306, 0.024667077741469257, 0.02269799297209829, 0.009462013658776414, 0.07964932956383564, 0.04614988552930299, 0.16044889896875247, 0.15414604655234143, 0.12441760700312443, 0.14623121969634667, 0.13027586101088673, 0.1272936593159102, 0.10267000834573992, 0.09954048291547224, 0.09772977617103606, 0.11126393743325025, 0.08237479269155301, 0.23419231380103156, 0.17326950008282438, 0.22112531965831295, 0.10730207854066975, 0.12061427085427567, 0.0966919568600133, 0.1240405959833879, 0.1817601890070364, 0.16000073082977906, 0.08864032250130549, 0.13646342820720747, 0.11282249208306894, 0.1319479345693253, 0.07465356989996508, 0.157771616068203, 0.1411756651941687, 0.10817358255735599, 0.13271317788166925, 0.12239789662999101, 0.1870740405865945, 0.22507728572236374, 0.12488445499911904, 0.16430009622126818, 0.11294237861875445, 0.11252935117227025, 0.20016187423607334, 0.08470099521218799, 0.16458693629829213, 0.12871006299974397, 0.14401601278223097, 0.17763600015314296, 0.13517733081243932, 0.10786468585138209, 0.28092210239265114, 0.16192917188163847, 0.08505472505930811, 0.08159908509696834, 0.17543407768243924, 0.13004615146201104, 0.18036520370515063, 0.12471233610995114, 0.16153011907590553, 0.07723817339865491, 0.12301933398703113, 0.12104035267839208, 0.1291004623635672, 0.10228308965452015, 0.1711774748400785, 0.13523285830160603, 0.09319746546680108, 0.13416645146207884, 0.23880260938312858, 0.12773422786267474, 0.21403219870990142, 0.12872379273176193, 0.14210094523150474, 0.15242182969814166, 0.10821276795468293, 0.16006042918888852, 0.12686236761510372, 0.2470013522543013, 0.22009452106431127, 0.12503079167800024, 0.16265543759800494, 0.16361769143259153, 0.07164454698795453, 0.15756902459543198, 0.13694900058908388, 0.12064780108630657, 0.0673630005621817, 0.2668481325963512, 0.11051860594307072, 0.1341317783226259, 0.10827104881173, 0.10490264830878004, 0.15447138925082982, 0.12913736194605008, 0.15502627822570503, 0.23809669335605577, 0.16719622362870723, 0.09956173060345463, 0.16782688588136807, 0.095286692812806, 0.1412432748475112, 0.08529670230927877, 0.19592625933000818, 0.11274980613961816, 0.24298333504702896, 0.1651189077529125, 0.16219321318203583, 0.14186246349709108, 0.09362165481434204, 0.09663909368100576, 0.18376879685092717, 0.11621876765275374, 0.1439841152750887, 0.11271652823779732, 0.1445006945868954, 0.11120830604340881, 0.1627179709612392, 0.07775563586619683, 0.049589654663577676, 0.11365481812390499, 0.07999470282811671, 0.15845180925680324, 0.06844407966127619, 0.14353582839248702, 0.1359155451063998, 0.0719589355867356, 0.15673529589548707, 0.09942139047780074, 0.1891871725092642, 0.14179843099555, 0.19025685964152217, 0.128807655419223, 0.1153466253890656, 0.1578866341151297, 0.10958278740872629, 0.04771829961100593, 0.117256698285928, 0.14766625128686428, 0.11321721074637026, 0.08101320403511636, 0.0787013843364548, 0.11025047540897503, 0.16275055124424398, 0.09515856843790971, 0.20404967421200126, 0.24187645147321746, 0.0958554822136648, 0.16877723566722125, 0.19080104684690014, 0.08398363526794128, 0.16344892705092207, 0.12852235900936648, 0.13580348080722615, 0.1509445847477764, 0.17437953036278486, 0.16314109903760254, 0.08342487228219397, 0.10749444321845658, 0.10113946977071464, 0.16110896511236206, 0.20298153074691072, 0.13263056200230494, 0.10719815560150892, 0.11090998494182713, 0.1261353597510606, 0.159048852219712, 0.15940915007377043, 0.20880007243249565, 0.09515844227280468, 0.17027580994181335, 0.19207653152989224, 0.13598213059594855, 0.07598392156069167, 0.12227854444063269, 0.10516622205614112, 0.12434765958460048, 0.11787507057306357, 0.1563945462112315, 0.18733952165348455, 0.13572914729593322, 0.165112599497661, 0.21384455409133807], [0.06414692586986348, 0.03851225454127416, 0.03617571390350349, 0.050927231131936423, 0.07437106396537274, 0.049981367628788576, 0.01656166550674243, 0.016180025340872817, 0.010650856311258394, 0.02661598722625058, 0.005884578913537553, 0.009179189528367715, 0.0422667499515228, 0.01560432468977524, 0.08876224994310178, 0.04309680502046831, 0.03891226100677159, 0.05935243294516113, 0.08064303561695851, 0.04180992837063968, 0.034735969675239176, 0.0327753639430739, 0.03430276694416534, 0.02574930160335498, 0.028736034109897446, 0.034941511185024865, 0.010707953442761209, 0.034755373126245104, 0.03958525907364674, 0.006055899993953062, 0.02529240766307339, 0.06806728386436589, 0.022672609666187782, 0.07962049712659791, 0.023783343131071888, 0.043563103827182204, 0.014133677432255354, 0.0016441370325992466, 0.029357757193793077, 0.053270065182005055, 0.03020328233105829, 0.00881467349245213, 0.02502769471902866, 0.02608099708595546, 0.015263454406522214, 0.02938353383797221, 0.015005690747784683, 0.04098585501196794, 0.0459797333314782, 0.023284209855773952, 0.09711639111628756, 0.06610616605030373, 0.007309598004212603, 0.06723478712956421, 0.018349734891671687, 0.04410078239743598, 0.0214344791311305, 0.037076655207783915, 0.026134941945201717, 0.031689420065958984, 0.03797376331931446, 0.015611879753123503, 0.05828845292853657, 0.03713323654665146, 0.005182645436434541, 0.04913793905870989, 0.002908743454099749, 0.03374124687979929, 0.06555018611834385, 0.031707265006843954, 0.0616342401917791, 0.025227651567547582, 0.060789642739109695, 0.00952437540036044, 0.016869886858330574, 0.07380317998467945, 0.015684973877796438, 0.003116456209681928, 0.02763932352536358, 0.004936317809551838, 0.03692037375003565, 0.010666455327736912, 0.04116285723284818, 0.03345469252963085, 0.06175673166580964, 0.02061781797237927, 0.02426592280244222, 0.01829619079217082, 0.014809620897722198, 0.029748501656285953, 0.01646898981562117, 0.028640751625061966, 0.06837719731265679, 0.041113949700957164, 0.07362922056927346, 0.054955530795268714, 0.02209731534094317, 0.06610631447983906, 0.04603479326760862, 0.07894201829913072, 0.030674366134917364, 0.06797635593102314, 0.05993395760015119, 0.01645159201871138, 0.02427325707685668, 0.03190054252627306, 0.08771431515924633, 0.02765628716588253, 0.055577265011379495, 0.03031371204997413, 0.015471677852474386, 0.06142131802334916, 0.020376519787532743, 0.02557605279434938, 0.030539571707777213, 0.046749277389608324, 0.042835851054405794, 0.03166362672345713, 0.05153712067112792, 0.08799515868304297, 0.041281085068476386, 0.05341711061191745, 0.0673589039070066, 0.08921814383938909, 0.042943321459461004, 0.02343525175092509, 0.04329538147430867, 0.06604962181882001, 0.020817325821553823, 0.023562589449284133, 0.07372664229478687, 0.0780729485268239, 0.004840263491132646, 0.12543538090540096, 0.026815964483830612, 0.040411083900835365, 0.019020788531634025, 0.06301700603216887, 0.026185064743913244, 0.06544313131598756, 0.042575709740049206, 0.03156485428917222, 0.057983682563644834, 0.04515817214269191, 0.027730926813092083, 0.012167116892669583, 0.045922176068415865, 0.07237226731376722, 0.014517799154418753, 0.07162577807321213, 0.010213649693469051, 0.037262767291394994, 0.02334571719984524, 0.054540187848033383, 0.00029209549722963857, 0.04732179608254228, 0.042157164425589144, 0.03697789761645254, 0.0380019723525038, 0.015446498637174955, 0.0660961693210993, 0.02008876315812813, 0.03165456138958689, 0.03553275055310223, 0.03961368332966231, 0.051928996908827685, 0.014908755128999474, 0.044938303472008556, 0.03612250562582631, 0.022979647292231675, 0.06892209697980434, 0.03578849835321307, 0.025670298127806745, 0.0395872814260656, 0.04408445143781137, 0.021209194637776818, 0.0263302381063113, 0.013394266425166279, 0.007864501822041348, 0.023847694756113924, 0.037447413633344695, 0.04251775913871825, 0.06301074972725473, 0.085479107365245, 0.022327472033794038, 0.058784207576536573, 0.05007872256101109, 0.02934787920821691, 0.03168560542690102, 0.01766455447068438, 0.05015874463424552, 0.05575233022682369, 0.04773445245518815, 0.04075567419931758, 0.05749492636823561, 0.01900119397760136, 0.0609697285835864, 0.03783232481509913, 0.02235219482827233, 0.027230713712924626, 0.059145214181626216, 0.016040021037042607, 0.015153660151554504, 0.04109407869691495, 0.08146218111505732, 0.02464523076923797, 0.03164897301758174, 0.05437524181616027, 0.052962893969379365, 0.013020770402363269, 0.02889114668505499, 0.027732123526220676, 0.03149449126794934, 0.03878393254126422, 0.03431655975873582, 0.025657997030066326, 0.011683181874104775, 0.01750780731526902, 0.021595565995085053, 0.019566792143450584, 0.026687726931413636, 0.05300655080645811, 0.03186044057656545, 0.04677951990743168, 0.05873311441973783, 0.050532672030385584, 0.08211015025153756, 0.03411188656173181, 0.05027469407650642, 0.024100089904095512, 0.03649426966148894, 0.01628791320399614, 0.03788821224588901, 0.033374188060406595, 0.03451164440775756, 0.08997694530989975, 0.04432351575815119, 0.08125812018988654, 0.03919546084944159, 0.022199961786100175, 0.027371202268113848, 0.054831213637953624, 0.03478078426269349, 0.07306416417122819, 0.03774132637772709, 0.053969179425621405, 0.015235663759085583, 0.04316829610615969, 0.02211138646089239, 0.03382763658009935, 0.06285366675001569, 0.018490848706278484, 0.037601201474899426, 0.0340042157768039, 0.035008311897399835, 0.011305799780529924, 0.03277078489190899, 0.032215035025728866, 0.008070033127296483, 0.02399949178652605, 0.03012190769368317, 0.05001571793400217, 0.00676898887832067, 0.024908207087719347, 0.013650183063873556, 0.013474888710334199, 0.003774521569539502, 0.01072918443242088, 0.07261935053975321, 0.034733557695290074, 0.01795485666661989, 0.005744099635194289, 0.028454969797166996, 0.023942025436554104, 0.046877119748387486, 0.04023899840831291, 0.0661007483722642, 0.06677997676888481, 0.06775512913009152, 0.05909956838877406, 0.024312360837939195, 0.022416704159695655, 0.03143765017739497, 0.028049883330822922, 0.009857019904302433, 0.028926291088282596, 0.017238593245565426, 0.06332726828986779, 0.052782448183279485, 0.024958673129731324, 0.07730934536084533, 0.06774646826670505, 0.09694036853034049, 0.04280706685676705, 0.026832837211259175, 0.042764222671394236, 0.04769954924995545, 0.016929720659391023, 0.0299308139437926, 0.006119988156569889, 0.02038177233771421, 0.02486779158061836, 0.04181416232313495, 0.0121818308980437, 0.04524558600678574, 0.04027612063509878, 0.05248511784884613, 0.05743436711782124, 0.054444298657472245, 0.09748235155711882, 0.04093404197192285, 0.05140463988936972, 0.042395286218379624, 0.03906919926521368, 0.07411668542772532, 0.06925608569872566, 0.043781777640106156, 0.013320900488906773, 0.02248873144708341, 0.007548792664238135, 0.025496487141936086, 0.0575647550431313, 0.059128827560925856, 0.01806562220735941, 0.05564679311646614, 0.11822602478787303, 0.06916469763382338, 0.03829972200037446, 0.02442320059344638, 0.051420414238236845, 0.07590124630951323, 0.0013831624255544739, 0.04332066644565202, 0.035251035005785525, 0.03931047518562991, 0.06191811909957323, 0.037721707703894936, 0.009462656544201309, 0.06095626231399365, 0.02661421905941097, 0.041900681899278425, 0.02567231120337965, 0.057402770180488005, 0.022586865634366404, 0.041710988953127526, 0.03316425303637516, 0.002658848184182716, 0.03774613549467176, 0.08703141313162632, 0.04815473068447318, 0.022315169080684427, 0.04161679185926914, 0.09082375065190718, 0.10202410980127752, 0.06968271671212278, 0.21533031889703125, 0.17954140494111925, 0.09551355993608013, 0.17577280872501433, 0.09239544131560251, 0.11712352730683051, 0.11804319670773111, 0.12787538435077295, 0.07373948144959286, 0.09142246344708838, 0.1313802509685047, 0.16273561923298985, 0.12820782198105007, 0.11589225236093625, 0.16289133665850386, 0.14833630673820153, 0.10158139644772746, 0.1358528484706767, 0.10772614914458245, 0.11209260468604043, 0.12502124765887856, 0.1531613353290595, 0.160052532737609, 0.0775199371855706, 0.1364924164954573, 0.17430592415621504, 0.10110472241649404, 0.10949368515866809, 0.13767887314315885, 0.11394053013646044, 0.19036491634324193, 0.11363892874214798, 0.13044171617366374, 0.09400318551342934, 0.07876172836404294, 0.10958301005302928, 0.1105961603752803, 0.13237952312920243, 0.09346728809759952, 0.21380162826972082, 0.11207678209757432, 0.12009296406176873, 0.1780497474828735, 0.16871139232534915, 0.19074421317782253, 0.13361568882828578, 0.0982504224521108, 0.1856363521073945, 0.10495827227714472, 0.15593266318319365, 0.1219509678776376, 0.07810958835761994, 0.11296862096060067, 0.15006893954705447, 0.16252897563390434, 0.187610138382297, 0.12217839161166921, 0.2235156882670708, 0.09400833601830527, 0.09810099101741798, 0.1159959749202244, 0.15424908633576706, 0.2153547207126394, 0.094340818177443, 0.152165996551048, 0.17308964801486582, 0.07446453004376963, 0.14326696313219145, 0.1362734829308465, 0.16348104720236734, 0.14515155809931457, 0.16639103792840615, 0.18939041707199067, 0.09285899417591281, 0.1460004414548166, 0.13157335779396817, 0.08537905101547949, 0.10028172517195344, 0.10389657807536423, 0.10423709769384004, 0.16139583487529308, 0.12505413964390755, 0.1516815077047795, 0.1531212593545206, 0.07614978414494544, 0.14419164945138618, 0.1014696661150083, 0.11050415632780641, 0.21134112670551986, 0.18337011511903256, 0.1800660291337408, 0.17360374855343252, 0.15288516733562574, 0.15430134837515652, 0.13277063495479524, 0.13763297873083502, 0.1902095996774733, 0.11968692764639854, 0.22292902052868158, 0.16996410791762173, 0.176263902685605, 0.14284882228821516, 0.07932959008030593, 0.15950880566379055, 0.09637236580601893, 0.09358056209748611, 0.13416578352916986, 0.09329880573204719, 0.14372995938174427, 0.08888070413377136, 0.17261896311538294, 0.15617947181453928, 0.15183774463366717, 0.34642470942344517, 0.20391832891618833, 0.15137926064198837, 0.18451278505381197, 0.14671927085146308, 0.14340706577058882, 0.10150686255656183, 0.1220265927258879, 0.11179808338056318, 0.1475336740259081, 0.16807286330731586, 0.143903354764916, 0.1558185208705254, 0.12277766843908466, 0.13895422423956916, 0.15228710020892322, 0.14321130205644295, 0.19305299007100984, 0.0940902617003303, 0.0833755565690808, 0.07847443557693623, 0.18636264750966802, 0.18173636606661603, 0.15443042269907892, 0.16208285582251847, 0.11480496148578823, 0.16571565385675058, 0.12090862888726406, 0.14505789906252176, 0.08770644839387387, 0.13491676276316866, 0.22128814685856923, 0.07119183690520003, 0.3067848802311346, 0.1683501445222646, 0.13868429028661922, 0.12654946331167594, 0.1311385483131744, 0.1663734341855161, 0.06176876187964808, 0.16194968484342098, 0.12477535929065198, 0.0933479136438109, 0.09932684828527272, 0.15663518017390743, 0.08777739029028453, 0.1843851208104752, 0.2202362712705508, 0.17757423862349242, 0.1988196259480901, 0.16423803783254698, 0.11257737554842606, 0.12646303279325366, 0.11585243613808416, 0.17508357617771253, 0.10055319537059404, 0.08666841386002488, 0.07949618739075959, 0.11860946280648932, 0.163144453545101], [0.05820674618007615, 0.04281958688807208, 0.016128867246152367, 0.028458155466069, 0.04770115228893701, 0.04288000884116627, 0.015507409480051138, 0.021040873689344153, 0.06050497715477832, 0.07625143611221574, 0.07587648826302029, 0.036094467286602594, 0.02093023431370966, 0.03093621438893024, 0.05846909167303238, 0.050295630062464625, 0.07412755046971142, 0.025873392405628692, 0.018487568413547706, 0.0448877669259673, 0.04320535525039304, 0.06253052080865018, 0.05010882407077588, 0.026190079806838185, 0.03257154421589803, 0.07667930651223287, 0.020326760641182773, 0.030668651597807184, 0.027849681573570706, 0.02950712925667176, 0.017163951742986683, 0.021854198894288857, 0.00845109256260912, 0.018172205745941028, 0.039026132435537875, 0.011306043761578621, 0.024845525294949766, 0.022191389980434906, 0.045887781234341674, 0.01782163373718504, 0.027715048563550226, 0.03263048187363893, 0.004119845434615854, 0.037518563331104815, 0.07670810926356353, 0.008203923989640316, 0.03369092184584588, 0.024535611846658867, 0.03140541128232144, 0.03246743945055641, 0.07620517804753035, 0.008662453437864315, 0.014113227553025354, 0.017461222705605906, 0.03141873654385563, 0.10150488844374195, 0.07850725334719755, 0.04923224747471977, 0.013673327866854379, 0.011681838586810045, 0.03274808630521875, 0.05614182045974303, 0.03234891846659593, 0.06559173154528253, 0.03671200836834032, 0.04858977765252348, 0.040772810389171354, 0.034696665534283966, 0.032651169240125455, 0.010121878494828707, 0.004620696781785227, 0.0198435928177787, 0.0017770409544937138, 0.024987188298837282, 0.006369941174853011, 0.0369426493125502, 0.03451565571594983, 0.03307019695057534, 0.012933925208926667, 0.04232423671055585, 0.07445799172273837, 0.04585108945320826, 0.030321463782456703, 0.038060089937062, 0.018019056151388213, 0.04014120560896117, 0.038642130384687334, 0.01966145122423768, 0.041380566253792495, 0.04101358907064423, 0.02763506730843801, 0.029487673855328467, 0.05156753017217852, 0.07155845785746351, 0.1070450060069561, 0.02147032857465092, 0.020953684324922506, 0.015658861411793623, 0.07451310360920615, 0.03906638281478081, 0.06054162069631275, 0.08329839547513984, 0.03019233565282775, 0.021150392421986908, 0.0689220153435599, 0.0810998646193184, 0.04186712940281723, 0.024733648388064466, 0.0075039071089122444, 0.08132348855724558, 0.031694930512458086, 0.03141470668197144, 0.025440762983635068, 0.047675522218924016, 0.08605978597188368, 0.0473810825496912, 0.04551174242806155, 0.05255533986201044, 0.032283223554259166, 0.04941548002534546, 0.11621728335740045, 0.06748437881469727, 0.03615017660195008, 0.012629754128283821, 0.04513364787271712, 0.02133168982254574, 0.014303787884273333, 0.059010406766901724, 0.053040136699564755, 0.04909738068818115, 0.033258294279221445, 0.0208516130442149, 0.013748394248978002, 0.06618727536988445, 0.0010094074627886584, 0.056069917482091114, 0.045951735810376704, 0.012339070653979434, 0.04029241819807794, 0.03709127922775224, 0.05265344065264799, 0.04564012655464467, 0.05446975803351961, 0.08762760262470692, 0.025644341512816027, 0.02473964123055339, 0.03228278197639156, 0.030530957228620537, 0.02250515331979841, 0.03695413775858469, 0.029605571435240563, 0.07207170492620207, 0.05336546826583799, 0.04773892760567833, 0.11275654484052211, 0.028581715632753912, 0.02406555777270114, 0.06713030015816912, 0.10147791137569584, 0.08848187397234142, 0.04275647093891166, 0.034188587524113245, 0.031090974443941377, 0.03349716935190372, 0.07055846581351943, 0.06080760642362293, 0.03450600408541504, 0.028514183904917445, 0.03521405378705822, 0.06280406902078539, 0.013785865285171894, 0.03460030507994816, 0.037247690561343916, 0.04808420068002306, 0.01777485987986438, 0.016734392957005184, 0.06282577684032731, 0.023046214228088502, 0.023251301172422245, 0.024097638961393386, 0.04512444153078832, 0.02433216319332132, 0.020917497204209212, 0.007207088392533478, 0.04216800720314495, 0.03642702737124637, 0.036212817576597445, 0.08707904416951351, 0.0780616159318015, 0.07285564293852076, 0.012163048068032367, 0.018806916414177977, 0.052908268189639784, 0.02128330550476676, 0.022492492280434817, 0.030908882945368532, 0.019367262029845733, 0.026374631524959113, 0.017037901670846622, 0.01411383240338182, 0.050433120341040194, 0.0341059122729348, 0.04159834948950447, 0.08376534737180918, 0.02518584453355288, 0.032814078076626174, 0.03287101935711689, 0.040967921013361774, 0.06688749912427738, 0.003241948047616461, 0.03815602736722212, 0.03390248959476594, 0.051167419806006365, 0.026133424253202975, 0.03700395813211799, 0.03720616739883553, 0.04923405831505079, 0.05680064350599423, 0.06668067740974948, 0.02486812369170366, 0.06635344223468564, 0.05909554965910502, 0.027380436440580525, 0.01899870221677702, 0.05710411140171345, 0.05441764813440386, 0.10371700060204603, 0.02999932345119305, 0.006363105067066499, 0.006279184863160481, 0.02833082889992511, 0.08637467180960812, 0.06921476291608997, 0.045256053999764845, 0.025508029393677134, 0.009904233484121505, 0.03516579563438427, 0.07194409263320267, 0.0238829783120309, 0.029171799105824903, 0.024480674364895094, 0.02634955435496522, 0.04770923056639731, 0.023979576253623236, 0.05526672444830183, 0.013131238156347536, 0.017343707331747282, 0.023131037996790837, 0.0176467781784595, 0.018197542667621747, 0.01849506596045103, 0.06350154682877474, 0.012968907267350005, 0.03599455565563403, 0.03989630800788291, 0.024782500258879736, 0.03089664864091901, 0.06597908068215474, 0.04836373802390881, 0.05607865627098363, 0.019430021748121362, 0.07209662624518387, 0.04180954987532459, 0.043548394460231066, 0.007676429540879326, 0.020910686143906787, 0.026036130548163783, 0.044296497871982865, 0.03401935187866911, 0.06262324473937042, 0.11149386962642893, 0.02575149464973947, 0.039869991451269016, 0.00449542735623254, 0.015818309984751977, 0.01791870850865962, 0.019633717165561393, 0.044425575906643644, 0.01673103844950674, 0.015629149529559072, 0.019453790882835165, 0.034789137134794146, 0.03571216846466996, 0.07035548842395656, 0.014760745834792033, 0.04188274047919549, 0.028988143531023525, 0.05419584616902284, 0.057049797323998064, 0.036315768302301876, 0.0573950258694822, 0.04420384815603029, 0.01586539925483521, 0.026531656985753216, 0.01852252727985615, 0.10081981934490614, 0.054730010670027696, 0.057169364736182615, 0.05774621015007142, 0.03383762217708863, 0.06762677468941547, 0.01022580050630495, 0.007163684813349391, 0.01820444464101456, 0.015113612007553456, 0.06976352175115608, 0.04764393641380593, 0.01780556995072402, 0.03156754086376168, 0.024459131673211232, 0.013011726405238733, 0.03583044082915876, 0.04747618506371509, 0.052220757424947806, 0.043519027676666155, 0.02800269201543415, 0.043486024369485676, 0.0331645981350448, 0.01636017612327123, 0.055603852451895364, 0.06581430163350888, 0.05317643212038092, 0.03896837850334123, 0.041583020429243334, 0.05907770842895843, 0.05993682600092143, 0.006931916268513305, 0.044491756925708614, 0.06973072624532506, 0.05996153580781538, 0.03481311221548822, 0.03472452575806528, 0.051123273151461035, 0.04374636977445334, 0.02109291308443062, 0.02004891910473816, 0.07429500124999322, 0.03632213964010589, 0.046033179096411914, 0.024921849617385305, 0.10322684174752794, 0.009886506359180203, 0.021989130618749186, 0.05682889706804417, 0.030599693091062363, 0.0029312732021935517, 0.03833507049421314, 0.039414116108673625, 0.04967104228853714, 0.06533878535265103, 0.025697996934468392, 0.02708675376197789, 0.22127278440166265, 0.1486732714693062, 0.11847813977510668, 0.13169668789487332, 0.3126048913691193, 0.2297231598640792, 0.11438624176662415, 0.12071542558260262, 0.15057478740345687, 0.10466454506968148, 0.11664460456813686, 0.1109820994315669, 0.14548298640875146, 0.3124334552558139, 0.15554413403151557, 0.1322017193888314, 0.217379700334277, 0.1685675047338009, 0.11497985600726679, 0.1125844704802148, 0.11653734938590787, 0.1670477050356567, 0.1318081733188592, 0.11323112601530738, 0.1356083998689428, 0.18410337186651304, 0.22521519160363823, 0.12707726389635354, 0.21786395169328898, 0.09980907358112745, 0.1430633623385802, 0.12164794155978598, 0.13388824998401105, 0.1538446603808552, 0.1775431277928874, 0.10580498856143095, 0.14252499357098714, 0.13349641085369512, 0.09319704986410215, 0.19227898941608146, 0.22590047592530027, 0.10861846298212186, 0.08582169757573865, 0.16167244815733284, 0.17024339293129742, 0.1412395344232209, 0.16260415519354865, 0.08251002684119157, 0.1127939268189948, 0.13368922082008794, 0.13575340068200603, 0.148048754199408, 0.09074428890016861, 0.22400599555112422, 0.21038103994214907, 0.20230663649272174, 0.18101415247656405, 0.135040181921795, 0.11665580357657745, 0.09840380211244337, 0.10323836730094627, 0.12871077546151355, 0.0792009016731754, 0.16850746498676017, 0.11534287754329853, 0.11311593727441505, 0.11655812952085398, 0.17542629997478798, 0.10381794752902351, 0.15656041621696204, 0.08845586169627495, 0.1711427274858579, 0.09749618518981151, 0.07662179748876952, 0.11094811648945324, 0.13574309967225417, 0.05900708194531035, 0.133392020361498, 0.09385203229612671, 0.13620858953800052, 0.17105288308812305, 0.17258921783650294, 0.12371788048767485, 0.15171321225352585, 0.08373690827284008, 0.16962601512204856, 0.11899304183316417, 0.12411247298587114, 0.0835513490892481, 0.10399369552033022, 0.14493994211079553, 0.14495359762804583, 0.19085796957369894, 0.2360667265020311, 0.15831319091375917, 0.1576221623690799, 0.13820581283653155, 0.0979914351773914, 0.1554854746791534, 0.08452805996057577, 0.08246461482485756, 0.10033247323008254, 0.09531527291983366, 0.13753461447777227, 0.16523763653822243, 0.16279230447253212, 0.10889241195400245, 0.12962054461240768, 0.058963792471331544, 0.17752022511558607, 0.14190003101248294, 0.12796242343029007, 0.14762336999410763, 0.14380047825397924, 0.19710370630491525, 0.08818949747364968, 0.12565811426611617, 0.1507393067004159, 0.07155417566536926, 0.14916985732270405, 0.22653346852166578, 0.13570284558227286, 0.11404058648622595, 0.07956181550980546, 0.13985066441819072, 0.11058848656830378, 0.09682401461759582, 0.17398306023096666, 0.09135673884884454, 0.17756172601366416, 0.15607162291416898, 0.1473034152877517, 0.15198960289126262, 0.1657842579879798, 0.07246589666465297, 0.17914370284415781, 0.13277957041282207, 0.13357516756514087, 0.14130129595287144, 0.11566606059204787, 0.17698565614409745, 0.20186851703329012, 0.10605260613374412, 0.2038949661073275, 0.07450637232977897, 0.13822460401570424, 0.12391276846756227, 0.15388348954729736, 0.2382709496305324, 0.2116564949392341, 0.0828447873936966, 0.19582056265790015, 0.259226958733052, 0.1546712644631043, 0.19996614020783454, 0.10133812043932267, 0.16092699050204828, 0.19951203488744795, 0.17007071000989527, 0.10959404578898102, 0.20897281472571194, 0.14281389681855217, 0.1531122496817261, 0.09404768468812108, 0.2306882932316512, 0.19347047782503068, 0.1301462820265442, 0.12420757921063341, 0.2152541745454073, 0.14873930776957422, 0.10502506556804292, 0.08964343156549148, 0.09142189199337736, 0.20348868478322402, 0.1513219965272583, 0.0901103018259164], [0.01018149892843212, 0.01806221389415441, 0.050118386643589474, 0.004009442154710996, 0.07223442822578363, 0.02473329772328725, 0.022460516847786494, 0.0668695688364096, 0.06076302190194838, 0.04771083731611725, 0.02125434319168562, 0.03746820118976757, 0.09441632428206503, 0.04734634632768575, 0.03613608692830894, 0.043074399582110345, 0.011495025173644535, 0.03292558576504234, 0.046695872442796826, 0.021087699497002177, 0.03661555514554493, 0.017339141268166713, 0.017398206946381833, 0.010410613831481896, 0.06410202593542635, 0.03928752055799123, 0.03196764380845707, 0.019363347200851422, 0.01393654260027688, 0.0061956278477737214, 0.07469828429748304, 0.046237551723606884, 0.05410937112173997, 0.025371253432240337, 0.058246937187504955, 0.02223559971753275, 0.051941802666988224, 0.04564173701510299, 0.04466836580832023, 0.02528417724533938, 0.008415184674959164, 0.014208131542545743, 0.0636601734731812, 0.054902192641748115, 0.0620426180830691, 0.034983064033440314, 0.017744314936862793, 0.011644808200799162, 0.03687477990752086, 0.019983797501481604, 0.0421538099180907, 0.03292540764959995, 0.058858296179096214, 0.044911356089869514, 0.035419973792159, 0.031202070240397006, 0.02255406456242781, 0.019084524174104445, 0.050230057604494505, 0.016521357611054555, 0.05072749321698211, 0.06028929419699125, 0.04681270133005455, 0.02532424208766315, 0.021724935322708916, 0.026797523969435133, 0.027682696490956005, 0.04492070715059526, 0.0769249425502494, 0.04187151549558621, 0.036874416255159304, 0.061947901485837065, 0.07180373766459525, 0.028005347048747353, 0.016597835929132998, 0.024003696053114254, 0.02049042646831367, 0.03029784307727823, 0.05001912439183798, 0.05664098156557884, 0.030142856667225715, 0.029261313247843646, 0.02750634364929283, 0.06650179755524732, 0.03855812297842931, 0.03498823680274654, 0.09690835227956995, 0.06798276808694936, 0.028651867141888943, 0.02407819098152686, 0.04976923584763426, 0.01897749534691684, 0.008956725196185289, 0.11250205498072319, 0.004770566547449562, 0.00393317024645512, 0.03465627414698247, 0.008915372727642534, 0.02575945974967908, 0.02661796133907046, 0.007040622349450132, 0.050872219435404986, 0.035093966871500015, 0.06439159711590037, 0.05810999980894849, 0.025833724612311926, 0.015290054834622424, 0.03234200536098797, 0.014314167747215834, 0.019759184651775286, 0.06429016779293306, 0.011329899170959834, 0.019190077982784715, 0.0052795054489251925, 0.04624271336069796, 0.07878895034082234, 0.036881028790958226, 0.01657854565564776, 0.019283367801108398, 0.027067663868365344, 0.06304575683316216, 0.05377775727538392, 0.0840709637850523, 0.053047743713250384, 0.008929709165386157, 0.09256160818040371, 0.02624220825964585, 0.01922649702464696, 0.026472016143088695, 0.025655976533016656, 0.011626705363596557, 0.03807115906965919, 0.056009729305515066, 0.01576041689986596, 0.030493977865262423, 0.015147948397498112, 0.02282356064824853, 0.018371641235717107, 0.03249219378631096, 0.03843922349915374, 0.0503213529009372, 0.032112485059769824, 0.07786463509546593, 0.03746753325685859, 0.016183064435608685, 0.0303659722339944, 0.008225549245253205, 0.04114736490009818, 0.06495200766948983, 0.04538627865258604, 0.06924072324181907, 0.016153744036273565, 0.047649287298554555, 0.013866484787286026, 0.01936369972099783, 0.05891742679523304, 0.056735546022537164, 0.05321922435541637, 0.031251460168277845, 0.046417344419751316, 0.06783367061871104, 0.013156884924683254, 0.01938959139806684, 0.01763163279974833, 0.022123570670373738, 0.041698732384247705, 0.052255998307373375, 0.019980743563792203, 0.043388569247326814, 0.046163017832441255, 0.07484209025278687, 0.05214837576204445, 0.0028793945284633082, 0.046444139661616646, 0.030828307972115, 0.06611024044104852, 0.011899365781573579, 0.06456862902268767, 0.008772849760134704, 0.055402418729499914, 0.013164406591386069, 0.035350690595805645, 0.05780134801170789, 0.024419922156084795, 0.049342478669132106, 0.04467518243473023, 0.07611994980834424, 0.11518361265189014, 0.06015083170495927, 0.0398489478538977, 0.01746285728586372, 0.0034801050924215815, 0.03501294289890211, 0.029822560572938528, 0.03532945775077678, 0.032667945488356054, 0.017153170192614198, 0.04076231271028519, 0.0193861478328472, 0.05261723497824278, 0.02867683670046972, 0.015298516245820792, 0.011055693230446195, 0.026408313897263724, 0.02724183665122837, 0.05404032170190476, 0.03222663850465324, 0.08531221319572069, 0.028396373527357355, 0.04373290350486059, 0.005386842731240904, 0.0248117000592174, 0.02924616044765571, 0.024300883524119854, 0.05964614530967083, 0.06460156553657725, 0.055033096359693445, 0.025536433240631595, 0.02658277611772064, 0.08455083647277206, 0.027958539794781245, 0.07252596609760076, 0.03992832796939183, 0.013091130640532356, 0.04480989337025676, 0.02753036140347831, 0.04189696002868004, 0.0674111139960587, 0.06556799766258337, 0.02213045780081302, 0.02179879942559637, 0.012119343919039238, 0.031708563765278086, 0.047761715250089765, 0.04606621208949946, 0.018160322106268723, 0.035673146339831874, 0.05772788652393501, 0.024629615982121322, 0.020768420145031996, 0.03462487016804516, 0.0031740730764795444, 0.04586112700053491, 0.028252148258616216, 0.022719455882906914, 0.06051907053915784, 0.06756711343768984, 0.04759482108056545, 0.0019171958911101683, 0.04714990354841575, 0.03559323558874894, 0.007706269907430396, 0.006895078377056052, 0.03175321879098192, 0.03596190486859996, 0.06677930141449906, 0.017779604058887344, 0.0882408615143504, 0.05736986706324387, 0.0378903162345523, 0.05371106417442206, 0.04292981808248442, 0.028527139947982505, 0.06517900837934576, 0.04534769439487718, 0.05915967863984406, 0.027484005004225764, 0.07040289681754075, 0.017974369584408123, 0.02886178917833604, 0.029335529870877508, 0.03126613984932192, 0.03618526905484032, 0.05848928551131394, 0.018911896913778037, 0.04377027435111813, 0.004227403505865368, 0.04112857743166387, 0.021909731949563138, 0.028229872696101665, 0.04942280502291396, 0.03519902529660612, 0.005376259705371922, 0.04361939943919424, 0.018786715154419653, 0.03198618636815809, 0.07956413843203336, 0.025872295882436447, 0.02898437527619535, 0.03644099459052086, 0.06273651131778024, 0.012071883575117681, 0.007470562877642806, 0.02639393107529031, 0.05745286514866166, 0.0015651282228645869, 0.03878227013046853, 0.038197891917661764, 0.023595412785653025, 0.007549936035502469, 0.0598926348175155, 0.02534155639295932, 0.03994516358943656, 0.04744223551824689, 0.027673605181917083, 0.07281699930899777, 0.028860212114523165, 0.019082251346844714, 0.056398091473965906, 0.03535762967658229, 0.07658186994376592, 0.012065074370184448, 0.013184706185711548, 0.0385318101325538, 0.10610834884573705, 0.05536492171813734, 0.024881235585780814, 0.050055133397108875, 0.0208228195697302, 0.03694759572681505, 0.009316387586295605, 0.04504351403738838, 0.03534161784045864, 0.043588088228716515, 0.02673968283488648, 0.04623955552233383, 0.00823435018901364, 0.04534126739599742, 0.027350034361006692, 0.06790532497689128, 0.060318438336253166, 0.053275241662049666, 0.005633953787764767, 0.031655017810408026, 0.024944631695689168, 0.041900039941538125, 0.09618895142921247, 0.009068983381439466, 0.030840295512462035, 0.05469392744998913, 0.043349506304366514, 0.027051011929870583, 0.053528488424490206, 0.03603116208978463, 0.006275486184676993, 0.009113648611673852, 0.023417712945956737, 0.0249571071981336, 0.018086213094647974, 0.017413986861356534, 0.03004569654876832, 0.048428008012706414, 0.10768247375381179, 0.13521960354410112, 0.11973287400905974, 0.12604253191966563, 0.1727057053358294, 0.1264529098989442, 0.11026525156921707, 0.16067431890405715, 0.1499029656406492, 0.1324556823237799, 0.1259805922745727, 0.24189853778807446, 0.22338119626510888, 0.09858683799393475, 0.0799060013378039, 0.13982734613819048, 0.1445030397735536, 0.1280428425525315, 0.2227520034648478, 0.08883766699000262, 0.15018407633760944, 0.09853956318693236, 0.06392020717612468, 0.1840730625553988, 0.10916849088971503, 0.12585050862981007, 0.07707234792178497, 0.12723682564683259, 0.19935547141358256, 0.16288618615362793, 0.1209948887117207, 0.22198817023308948, 0.3286519052926451, 0.13188071083277464, 0.17536194092826918, 0.1322058605728671, 0.20458013168536127, 0.14905051997629926, 0.18576895905425772, 0.31329307006672025, 0.10467872009030543, 0.13240487489383668, 0.1413649573805742, 0.20404388546012342, 0.13038142409641296, 0.14176090800901875, 0.10126271823537536, 0.17915612639626488, 0.09458220170927234, 0.1356636601849459, 0.16355220432160422, 0.14884010626701638, 0.1650097972014919, 0.07884040343924426, 0.08692552350112237, 0.14801069686654955, 0.12946917617227882, 0.12947812647325918, 0.11688881568261422, 0.06646648616879247, 0.1069274869223591, 0.1196601361152716, 0.1213682780507952, 0.1001173394615762, 0.16882957192137837, 0.15611888287821785, 0.14000574359670281, 0.08749195287236944, 0.17049422400305048, 0.1817165655666031, 0.1190811644482892, 0.1790093889576383, 0.1101912594458554, 0.21500556991668418, 0.11441395356087014, 0.16258300398476422, 0.09194456433760934, 0.14007549063535407, 0.1499106246046722, 0.20762410975294188, 0.09293849303503521, 0.19753419648623094, 0.16770993825048208, 0.15288973896531388, 0.13263688510050997, 0.12012441628030501, 0.1150724315084517, 0.24924189609009773, 0.16835942136822268, 0.11439940746640787, 0.06163193211250473, 0.15882821171544492, 0.14055766398087144, 0.15915028896415606, 0.06076255063817371, 0.1092550327302888, 0.13991959509439766, 0.13133143249433488, 0.16837653529364616, 0.1039074950676877, 0.23989846464246511, 0.1574668605462648, 0.10530670318985358, 0.17073200811864808, 0.18769892893033102, 0.05499447499460075, 0.11099897586973384, 0.10513809465919621, 0.08946623638621531, 0.07598552459967323, 0.16224951250478625, 0.14122405322268605, 0.15440299292095006, 0.12746358144795522, 0.2151932887500152, 0.0936329280375503, 0.08808005295577459, 0.0865104328840971, 0.1772010125569068, 0.09003333369037136, 0.15653306065360084, 0.08085315246717073, 0.21714875882025808, 0.13605334708699957, 0.13512431178241968, 0.13390500767854974, 0.0948364837677218, 0.09153684324701317, 0.10409482798422687, 0.17405589460395277, 0.07728092852630652, 0.1548417506273836, 0.24305882630869746, 0.13045721221715212, 0.14790623215958476, 0.09118581481743604, 0.07328774358029477, 0.12504619866376743, 0.18547536543337628, 0.13172073347959667, 0.11514552563312463, 0.0772110850084573, 0.10427419023471884, 0.0800151564180851, 0.0963982444955036, 0.09786457987502217, 0.07982584938872606, 0.1383022326626815, 0.25584603077732027, 0.16015904577216133, 0.12223034194903448, 0.17634384683333337, 0.11099693496362306, 0.11966812904574908, 0.12250085477717221, 0.12603570416104048, 0.11077212358941324, 0.12427064692019485, 0.1841994354617782, 0.23447814455721527, 0.17725079582305625, 0.09519903032924049, 0.19265350681962445, 0.09225842601154, 0.1261290514958091, 0.09955183777492493, 0.20827037194976583, 0.09522035965346731, 0.17137895309133455, 0.14507240062812343, 0.18309703445993364, 0.12318587934714742, 0.09904986392939463, 0.14338747307192534, 0.150290010496974, 0.14141952007776126], [0.06989310073549859, 0.035205155436415225, 0.029758312848571222, 0.045311755893635564, 0.028608713109861128, 0.05249846537481062, 0.024151862126018386, 0.028258161510166246, 0.02751468538917834, 0.07848425419069827, 0.04794768632564228, 0.03595833513827529, 0.07731708596111275, 0.00989507630947628, 0.01342060524621047, 0.03828713146504015, 0.04561718676995952, 0.00838522788399132, 0.05006527484511025, 0.01772413594153477, 0.018315084016649053, 0.04395396703330334, 0.052552601337083615, 0.06998499346082099, 0.08108061330858618, 0.03136391409498174, 0.0339238782908069, 0.01934098072524648, 0.04476520494790748, 0.02505543434381252, 0.018314514418307226, 0.04620820349373389, 0.030867960922478233, 0.04873802165093366, 0.05587250991084147, 0.026292728107364383, 0.10914624872384593, 0.04165191399806645, 0.10925869151833467, 0.01503634422988398, 0.029441582773870323, 0.06940495310118422, 0.060127929027657956, 0.05620540767267812, 0.05981424546916969, 0.014981617332523456, 0.02789946855045855, 0.03781351508223452, 0.05549536530452315, 0.053988193249097094, 0.0554208796529565, 0.053010194751550443, 0.006814865200794884, 0.03264022998337168, 0.09836437180638313, 0.030405287507164758, 0.04972736758645624, 0.03318091796245426, 0.03891293265041895, 0.060125413147034124, 0.08978192374343053, 0.06316715735010803, 0.017861208762042224, 0.01032961676173727, 0.02795055799651891, 0.04771043655637186, 0.03386419848538935, 0.04218511370709166, 0.016730043971620034, 0.041880747812683694, 0.022303521072899457, 0.03708634765644092, 0.02742211174336262, 0.04248123434081208, 0.05442263536679093, 0.03981089423177764, 0.040737740200711414, 0.08332304962095805, 0.053431552805704996, 0.05466971117130015, 0.03719576990988571, 0.07014253656961955, 0.03937952460546512, 0.02336947149160551, 0.030851921255816706, 0.032019761129049584, 0.048699971739551984, 0.0460480554465903, 0.037737934762844816, 0.012851507854065858, 0.059261338028591126, 0.04603890105499886, 0.021436137831187807, 0.02852532168617472, 0.025581281224731356, 0.0526164557231823, 0.07360495976172388, 0.02851891695172526, 0.04313305522373412, 0.06233755499124527, 0.006394783640644164, 0.08204028446925804, 0.016071152276708744, 0.028310835441516247, 0.08897014035028405, 0.032094009293359704, 0.014284110766311642, 0.03636778914369643, 0.032211372526944615, 0.054077889217296615, 0.051667211737367325, 0.018403633366688155, 0.05133777238370385, 0.016885757686395664, 0.02662572791450657, 0.04861026463913731, 0.04949093046889175, 0.06333201803499833, 0.03965885785873979, 0.06012101221131161, 0.010082215339934919, 0.0824989317334257, 0.04368978101410903, 0.04524239106103778, 0.03559233016858343, 0.061524227930931374, 0.013443929092318285, 0.01068680408934597, 0.037961009511491284, 0.04352184783783741, 0.046616288236691616, 0.08867967859259807, 0.01108761764044175, 0.10244861827231944, 0.038473414242616855, 0.07214422017568722, 0.037635158441844396, 0.01564019825309515, 0.0730588281294331, 0.07617703580763191, 0.03840182296698913, 0.025117041877820157, 0.0496867424226366, 0.017896852259582374, 0.022069473670853768, 0.06080360253690742, 0.030572426585422363, 0.016886690937099047, 0.08147044864017516, 0.02657947170519037, 0.02251474557851907, 0.05936884925176855, 0.008909328862500843, 0.04466767561098095, 0.06781263815355487, 0.027773448164225556, 0.028683738673862536, 0.03418229411181528, 0.031033866180223413, 0.05120109846757259, 0.052106218063272536, 0.013028864450461697, 0.021890749667363707, 0.027340601664036512, 0.033855170258902945, 0.021202329771767836, 0.11383995428332128, 0.04038366525492165, 0.01995617290958762, 0.030507510928146075, 0.03627642334322445, 0.046107048765406944, 0.04460098622075748, 0.05153196274477523, 0.036610304450732656, 0.026966102814185433, 0.03907306214387063, 0.046652653472847305, 0.046366288370336406, 0.02624196891702013, 0.021880866115679964, 0.04010489603388123, 0.022078147521824576, 0.03952554958232213, 0.017113929134211503, 0.09199834777973592, 0.033948814452742226, 0.05889751497306861, 0.08195348287699744, 0.043747772433562204, 0.04445918406418059, 0.022456177139247302, 0.019604624976636842, 0.04243608578690328, 0.03544594896084163, 0.08574262916226871, 0.02508584384486312, 0.04140561373787932, 0.02319218539923895, 0.008074575998762157, 0.027299878165649716, 0.024468681258440483, 0.028233696612005588, 0.03750158299226314, 0.0038283998674160102, 0.024531648778065573, 0.07172555982833728, 0.07343915654928423, 0.054624076510663144, 0.03624448872869834, 0.02299388168466976, 0.0085111406588112, 0.08082776359515265, 0.049008682908606716, 0.03532494178216439, 0.022756442667741794, 0.06785117788240314, 0.055764364151400514, 0.06344178909785114, 0.03281340643297881, 0.03267533356847707, 0.04574280268570874, 0.057913887285394594, 0.029590355552500114, 0.021868609546800144, 0.01556404462462524, 0.03778491271077655, 0.02555039303842932, 0.032034771065809764, 0.07413625586195849, 0.07273796058143489, 0.034930148904095404, 0.045785409383825026, 0.07323772282688878, 0.01611365321878111, 0.033521994191687554, 0.0925853123771958, 0.022084800875745714, 0.04504165866819676, 0.05124616909597535, 0.050457852412364446, 0.08150471359840594, 0.03421662957407534, 0.006926435971763567, 0.03532836679369211, 0.07605883394717239, 0.019647007175080944, 0.02402193804300623, 0.051911897826357745, 0.03688729622808751, 0.018592341111798305, 0.030426143712247722, 0.045934547670185566, 0.03213048214092851, 0.03394590523384977, 0.023160427044786047, 0.023934360906423535, 0.06960167418583296, 0.006360903207678348, 0.02481463710864773, 0.03825259191216901, 0.027442730461189058, 0.025368910100951325, 0.011738530320144491, 0.07712902573985048, 0.03551650865119882, 0.05083360549178906, 0.06326805974822491, 0.03716222483490128, 0.015059181969263591, 0.007916654394648504, 0.01817465297790477, 0.026149961158807855, 0.042193544504698366, 0.061127661319915205, 0.05718137268559076, 0.05895502028579358, 0.051199495428591035, 0.014687227758258814, 0.038514659099746495, 0.07422603346640244, 0.038015772588551044, 0.025545507851347793, 0.0352123987977393, 0.06304124457528815, 0.04436239687493071, 0.023976013944775332, 0.05491280906426255, 0.049382035140297376, 0.04153220186708495, 0.06388052453985438, 0.026837117547984235, 0.07192894539912231, 0.01648678837227635, 0.007914118104963563, 0.03925500335753895, 0.046163578153937124, 0.08838416280923411, 0.040941411498351954, 0.06343283879687078, 0.04458338247786742, 0.03760799954761751, 0.029763942038698588, 0.06848176592029631, 0.0396957500197459, 0.05218291531491559, 0.03787518013268709, 0.046825006138533354, 0.02545373386965366, 0.04301386259612627, 0.062263748404802755, 0.03448814801231492, 0.06525967241032049, 0.03688669137773104, 0.01168048509498476, 0.03622962722147349, 0.03101186335698003, 0.021649002483172808, 0.12785181374056265, 0.045629209562321194, 0.05329200306732673, 0.04801166687684599, 0.05007797299185768, 0.027672601427184418, 0.05984243223792873, 0.06389274029061198, 0.04867487230512779, 0.047540599771309644, 0.07215461766463704, 0.08657647660584189, 0.009503548881184543, 0.04010970144008752, 0.062369304068852216, 0.03005963964824332, 0.035753869742620736, 0.0363501779793296, 0.05033321984228678, 0.025544776835886296, 0.0535783533268841, 0.05078723239421379, 0.0006009472394907789, 0.048563654054305516, 0.062327773484867066, 0.020545425177260768, 0.042886714145424776, 0.019630542628874537, 0.0298942965673632, 0.014150494498608168, 0.07869927663705312, 0.013077316489216173, 0.036157976574031636, 0.030354387308761943, 0.10348651179810986, 0.08651256284792908, 0.0633469203603454, 0.07939910705317743, 0.12938865314936265, 0.10670092407963239, 0.1059118058765307, 0.15869330411078408, 0.07670425751712173, 0.29321171168703586, 0.1688389971968718, 0.13090552878566086, 0.2430246875155717, 0.12811681983293965, 0.07713575701927766, 0.1595229361555539, 0.12455862248316407, 0.04634807977708988, 0.1548535210895352, 0.14604969037463889, 0.15488810517126694, 0.10436166718136519, 0.13115728012053296, 0.1934969428111799, 0.26682833209633827, 0.09907214320264757, 0.12332005222560838, 0.08168719286913984, 0.13509199867257848, 0.15957993309712037, 0.11236524005653337, 0.11443291543400846, 0.10772433088277467, 0.1797663647448644, 0.26435009320266545, 0.07883518614107743, 0.1891619840171188, 0.10626473420416005, 0.13662475626915693, 0.10066381248179823, 0.14492319925921038, 0.13448622805299237, 0.25434591283556074, 0.14587844721972942, 0.23350367497187108, 0.13761783891823143, 0.1544991010450758, 0.14787173713557422, 0.19393510679947212, 0.15553969598840922, 0.14424178894842044, 0.24213154247263446, 0.14729152608197182, 0.22439112566644326, 0.21462345292093232, 0.1291773043340072, 0.13534354220610112, 0.14287392172263935, 0.11988521466264501, 0.1125075839809142, 0.2158819869509898, 0.13400398049270734, 0.1349726613261737, 0.15985359263140708, 0.10614423910737969, 0.158651580568403, 0.08308213364216499, 0.3525137045653537, 0.15303362655686215, 0.17761075228918344, 0.08866380405379459, 0.15621056780219078, 0.13194794941227883, 0.19684100087033585, 0.06563177783391438, 0.1153452524158638, 0.09279312856961042, 0.17749996448401362, 0.08773737368755974, 0.14874016866087914, 0.12832570471800864, 0.15224300179397687, 0.12479254743084311, 0.09924664438585751, 0.09742634167196229, 0.13010004622628912, 0.1174648261803668, 0.11460197667474858, 0.18003327073529363, 0.11367972459993325, 0.19629290996817872, 0.13488084281561896, 0.11890324196428992, 0.10925554481218569, 0.08425460822763853, 0.21731609827838838, 0.1376208965666592, 0.11041192221455276, 0.2441371520399116, 0.13089484185911715, 0.23572866339236498, 0.12703665357548743, 0.21438519383082166, 0.10574352389085107, 0.14651298348326236, 0.11132302723126486, 0.11077539646066725, 0.10084190565976314, 0.2869582566199824, 0.09576915559591725, 0.14559358125552535, 0.13553822238463908, 0.09872189402813092, 0.381235561799258, 0.1736604783218354, 0.11409019163693301, 0.2457345210132189, 0.1194582051539328, 0.13693708169739693, 0.21672537841368467, 0.1158680286607705, 0.21441128774313256, 0.09074264133232646, 0.17587952956091613, 0.14237070106901228, 0.1282114436617121, 0.08018852953682654, 0.16561032825848088, 0.16073570935986936, 0.14972355886129662, 0.14824334532022476, 0.0984401821915526, 0.11843600063002668, 0.2298533622524701, 0.13092203414998949, 0.18489647540263832, 0.18595172034110874, 0.0833744952979032, 0.11306317057460546, 0.14771701418794692, 0.16549490945180878, 0.1377812895225361, 0.21321389183867723, 0.14725125714903697, 0.17790534038795158, 0.12178635210148059, 0.11915907511138357, 0.08705263113370165, 0.12606641423190013, 0.13649897708091885, 0.11791506491135806, 0.13200540648540482, 0.11927602274226956, 0.2733434981200844, 0.17838971049059182, 0.07863853927119635, 0.18553849251475185, 0.11111545594758354, 0.17442122421925887, 0.1287019142182544, 0.11714716471033171, 0.1277085643960163, 0.1441734965192154, 0.13362045341636986, 0.08270569407613948, 0.16118022613227367, 0.17018985439790413, 0.09130098129389808, 0.1258351164869964, 0.09353794055641629, 0.13512676086975262, 0.08502640470396727, 0.16588081140071154, 0.1198135751474183, 0.13636089308420196, 0.12504814309068024], [0.020496400757110678, 0.007474710091628367, 0.056867759631131776, 0.029499236516130622, 0.07615185473696329, 0.025990469912358094, 0.034174126776633784, 0.041673851883388124, 0.04783732525538653, 0.023391440918203443, 0.06033550773281604, 0.046092580596450716, 0.05368674028431997, 0.06381503742886707, 0.04355204582680017, 0.036160177041892894, 0.04349811395513825, 0.016588195430813357, 0.04243074974510819, 0.031610559453838505, 0.048531990323681384, 0.03569670210708864, 0.046284544514492154, 0.026672442400013097, 0.040092791605275124, 0.038369250105461106, 0.020756837075168733, 0.05818352066853549, 0.030487404292216524, 0.014044198542251252, 0.004443476091182674, 0.032712299944250844, 0.036116501651122235, 0.11296972676063888, 0.04907996619294863, 0.06697067161439918, 0.012118850390834268, 0.0033649469651209074, 0.016054949337558355, 0.09184870112221688, 0.014014231546752853, 0.03652157698525116, 0.05403366834798362, 0.02245726438559359, 0.02895294346672017, 0.0145349854392407, 0.03211313814972527, 0.029507613508030772, 0.06878059168229811, 0.028953260734851938, 0.05385240991017781, 0.06985652769799344, 0.10274138068780303, 0.01816572308598552, 0.02981046727654757, 0.00979361266217893, 0.032221951842075214, 0.01264715006982442, 0.10835851091542281, 0.048851362444111146, 0.035054547697654925, 0.04496054934861604, 0.050557953290990554, 0.02607577793241944, 0.027089629584224895, 0.04114558374567423, 0.05985072573821526, 0.023368823967757635, 0.060864362167194486, 0.035358104651095346, 0.05141463290783577, 0.025368520473421086, 0.016898806497920305, 0.014708738908666419, 0.03685934323584661, 0.054878436494618654, 0.02189787985116709, 0.036294583696871996, 0.015799657958268654, 0.067375416692812, 0.028418209367373493, 0.0652046050527133, 0.03480145678622648, 0.002621560133775347, 0.07316502204048447, 0.036229170800652355, 0.008448847565887263, 0.03264125043642707, 0.050162373736384325, 0.024624962716188747, 0.0668916774156969, 0.015214777868095553, 0.018603044736664742, 0.05364265671232715, 0.015468989422515733, 0.04111235037271399, 0.023508418234996498, 0.008913097117329016, 0.019583581379265524, 0.0944782119768206, 0.06103161256760359, 0.02868557920010062, 0.015147217382036615, 0.030787727337155957, 0.06594664140720852, 0.04377441182441544, 0.033243180441786535, 0.027151257527293637, 0.013888534922443796, 0.02499977512343321, 0.020930191640218254, 0.03637947796960361, 0.06964189116843045, 0.027313661703374237, 0.018041240800812375, 0.0436288135824725, 0.043107310120831244, 0.0516135025100084, 0.021298115061654244, 0.06437250165618025, 0.038776948931626976, 0.038558597952942364, 0.045675860965275206, 0.008271506740129553, 0.05307833504048176, 0.031443965854123235, 0.04711768320703413, 0.014810170087002916, 0.01953440296347253, 0.051441335381241515, 0.02656509073858615, 0.016594364533375483, 0.042078797341673635, 0.0460133080923697, 0.05674966909282375, 0.0323607891186839, 0.021278780259308405, 0.05057258102169726, 0.0531077611958608, 0.0426124274963513, 0.00484115453218692, 0.005411148067651084, 0.04822543509362731, 0.011368764517101226, 0.014297031557362061, 0.017864092005765997, 0.04864707887463737, 0.04013484911411069, 0.08504175231792033, 0.011630684202827979, 0.01506039074229193, 0.020591484717442654, 0.025628420589782763, 0.006783244143662159, 0.0682366345426999, 0.03182842061505653, 0.10199436452239752, 0.02136743536539143, 0.06299663407844491, 0.011145963435410522, 0.01967192663869355, 0.06062938708055299, 0.020096000953344628, 0.04096867058251519, 0.0525612362253014, 0.06524074022308923, 0.09674752887804061, 0.015377189465652918, 0.05061760341050103, 0.017437884016544558, 0.08570371835958213, 0.02208689558756305, 0.04750204891024623, 0.036826874274993315, 0.014797920011915267, 0.03548281885741744, 0.02466205340169836, 0.0034134138468289166, 0.005800741737402859, 0.04715518021839671, 0.03610391111578792, 0.010215510628768243, 0.027261804134468548, 0.018962157009809744, 0.08177512252586894, 0.03235376098018605, 0.027994071970169898, 0.07415158121148124, 0.04550885176286101, 0.0547621456644265, 0.032442058000015095, 0.008573633203923237, 0.11676850612275302, 0.009314401413575979, 0.009964749133359874, 0.07166893396060914, 0.04989639171981253, 0.036823304544668645, 0.015100541859283112, 0.01909182690724265, 0.061280528898350894, 0.04135514027439058, 0.014897674864187138, 0.009029157881741412, 0.04648192239983473, 0.04468952814931981, 0.05085045595478732, 0.016043395953602158, 0.041517563004163094, 0.01219851623318391, 0.02440881962684216, 0.0092559906806855, 0.027952309465035796, 0.0318902192520909, 0.046158049153746106, 0.05088221616460942, 0.02311055472091539, 0.029986191148054786, 0.01760764658683911, 0.036075167736271396, 0.03220745398721192, 0.06785961610148661, 0.040069369424600154, 0.014344030842039501, 0.05280671270156745, 0.06167922918393742, 0.041144774804706685, 0.06446573024732061, 0.08042812449275516, 0.039700529450783506, 0.043411130536696874, 0.04595816651999485, 0.023171117682068143, 0.03690826189995278, 0.07081504110828973, 0.00540241345333925, 0.015220701134239789, 0.04572179990645964, 0.06774580033379607, 0.027853227184095886, 0.01838465850596549, 0.09533414573525079, 0.031768132248544134, 0.007238967345983838, 0.07258856625412591, 0.0504850187280681, 0.07611718901898712, 0.0296851055463776, 0.04500986135099083, 0.009398851325386204, 0.047597051234333776, 0.0305766902238247, 0.08951857264037244, 0.04846337134949863, 0.018172274394601118, 0.0692344075650908, 0.036272378638386726, 0.037176069599809125, 0.04217067893478088, 0.06220674404175952, 0.05488408794917632, 0.037122442008694634, 0.008147219268721528, 0.025665383254818153, 0.03733346427907236, 0.04781207368068863, 0.041989183009718545, 0.02173477620090125, 0.04606747745128814, 0.029330731886147987, 0.03252619528211653, 0.0388931581255747, 0.051679271637112834, 0.07376573863439262, 0.0676754373125732, 0.022398323017114308, 0.05906065758608747, 0.10729532499681227, 0.04909793358820025, 0.00834987196867587, 0.04447184510354418, 0.03771411553316284, 0.023501963405578863, 0.04403236380312592, 0.01785265551006887, 0.05161841181688942, 0.019948554763686843, 0.03547082204022445, 0.06542421397170983, 0.019859048043144867, 0.02925779361248715, 0.03605405734560918, 0.021223341827862896, 0.04558665481454227, 0.02135601742338622, 0.03692097860039212, 0.034119011179427616, 0.03365053045854438, 0.10367122493335046, 0.09969318722141907, 0.07338198891375214, 0.0355339750967687, 0.025531317987770308, 0.02879692732676631, 0.006598486943403259, 0.012979363200429361, 0.008076842332229717, 0.07126845623133704, 0.034609975264174864, 0.04660071797843557, 0.025429734669160098, 0.04071887851750944, 0.059508640188141726, 0.030180635694705416, 0.06744248457835056, 0.0329389184480533, 0.04301945096813142, 0.02896787176723592, 0.02112251921062125, 0.007895281469245674, 0.020287538136471994, 0.02864254576707026, 0.020428883872227743, 0.025337469014630187, 0.09497758088400587, 0.05580274802923668, 0.02186240890296176, 0.06275173276662827, 0.04509642174525652, 0.011132228137284983, 0.042474733127164654, 0.041693533639772795, 0.025360358704347163, 0.029801949276588857, 0.06823460847954266, 0.04813539402675815, 0.021967682550894096, 0.026401718059787527, 0.023788031649019103, 0.02581190175988013, 0.0593466404825449, 0.05549365465412848, 0.06407531604054384, 0.02223829742433736, 0.029619893030030653, 0.02762017054919852, 0.05862326543137897, 0.049405524114263244, 0.0218763872544514, 0.054699359970982186, 0.01455148894820013, 0.027100735824205913, 0.0972734740935266, 0.04492063664656598, 0.1683439698535949, 0.14646783121861517, 0.14421875268453732, 0.09108869737247005, 0.1027289051853586, 0.10046909519587643, 0.11715379951056093, 0.09625261285691522, 0.1221171124780085, 0.1965057133929804, 0.1982116437284276, 0.2168935936060734, 0.12897054199129343, 0.11354761489201337, 0.28070551401469857, 0.08307570664328523, 0.1302301001851447, 0.19412036170251667, 0.18596408452140167, 0.11884540639584884, 0.10231149906758219, 0.11335336515912786, 0.1450796885183081, 0.12888348806882277, 0.10528796396101825, 0.17186624725582078, 0.17831003351602703, 0.10574249972705729, 0.11552446623682044, 0.1568370740278624, 0.09672641477664001, 0.17732551525114104, 0.14571287407306954, 0.10973035605275072, 0.07938505819765851, 0.12444241699995473, 0.12227832179632969, 0.15898336510872468, 0.19646341097541153, 0.14024697127752006, 0.1136938550916966, 0.16999110725009814, 0.12206234197947197, 0.15868049464188516, 0.0806337884569075, 0.15081021148944274, 0.15849903953494504, 0.12417174089932814, 0.14835186215350404, 0.15579466824419796, 0.22374642197974026, 0.11492921184981242, 0.1995051180711016, 0.12831691768951714, 0.1416742251603864, 0.09166443327558227, 0.20793383766431361, 0.22465915972134098, 0.13174555089790374, 0.10906907278695144, 0.21237701643258333, 0.11540846855496056, 0.07531799987191334, 0.2383227663813159, 0.1290625979891047, 0.21527678036363795, 0.1632432482438162, 0.08662630440085195, 0.1542349113151431, 0.1074328226968646, 0.11902560727321543, 0.08783208657405339, 0.13076649483991787, 0.182304895715788, 0.16500203433679417, 0.16405318368924782, 0.11968800376052968, 0.2392695687012747, 0.11791453798650764, 0.12366137336357497, 0.15753561310702935, 0.17548340081702918, 0.18086438707541674, 0.08864084200467914, 0.0929955493484158, 0.12678818253334612, 0.1689825434004888, 0.17027710127877071, 0.13740384805714712, 0.10984501044731587, 0.11281978324404918, 0.21669362933607772, 0.12552942585898563, 0.13351540983421728, 0.1932860244414769, 0.1364671834744513, 0.20104927505599335, 0.17988924955716357, 0.16636831336654723, 0.19952153437770903, 0.11705103432177566, 0.09329148815595545, 0.13618052151286975, 0.1623854145873338, 0.09706320139230229, 0.21619925508275628, 0.1436580007430166, 0.09329208187409677, 0.08535720218787901, 0.1493273113737814, 0.1305941236205399, 0.1729894580785185, 0.1448062070994638, 0.11606242682319134, 0.12005600510747172, 0.18202647159341723, 0.0740541669074446, 0.10372089687734842, 0.17003131681121886, 0.13822323846397921, 0.1928686405881308, 0.20631179970223457, 0.1366379961837083, 0.18123511952580884, 0.13177274318877608, 0.0998865241126623, 0.12999909929931164, 0.16165092587471008, 0.08231488653109409, 0.21813237166497856, 0.10086902373586781, 0.10862233699299395, 0.1489606755785644, 0.14738064317498356, 0.12824611680116504, 0.20827210857532918, 0.1412745044217445, 0.16189969377592206, 0.13911953021306545, 0.09471537268836983, 0.15743012423627079, 0.17649491841439158, 0.09433872532099485, 0.11742707312805578, 0.15508124168263748, 0.09235794059350155, 0.15181395137915388, 0.13886644301237538, 0.136575210490264, 0.1209403557004407, 0.1420672665699385, 0.1440476134303026, 0.21143748715985566, 0.09537078556604683, 0.13183254544856027, 0.16357228683773428, 0.2106021554209292, 0.1423554721986875, 0.12540882686153054, 0.18557886534836143, 0.059165894126635976, 0.2668754436308518, 0.13347885163966566, 0.11751909943995997, 0.1845539890928194, 0.08154476730851457, 0.10670887248124927, 0.10302189766662195, 0.17832955199992284, 0.16492783441208303, 0.08526876044925302, 0.17127074796007946, 0.11758048989577219, 0.1434768276521936], [0.07057763548800722, 0.010631241348164622, 0.014201414178387495, 0.0642332153802272, 0.026331896806368604, 0.09188287702272646, 0.06643133063334972, 0.023186018152046017, 0.02118847016390646, 0.03159739375405479, 0.06152928195660934, 0.039713884398224764, 0.010771813394967467, 0.017447498539695516, 0.021770723978988826, 0.023078616395650897, 0.0204652565298602, 0.03852762070891913, 0.008807367048575543, 0.06755543203325942, 0.022491677773359697, 0.07046140774036758, 0.037980587367201224, 0.05236287870502565, 0.02585998736321926, 0.011808328381448518, 0.06252188963117078, 0.06833856852608733, 0.026299021519662347, 0.04051076917676255, 0.02555360468250001, 0.046730664325878024, 0.03258335178543348, 0.012828582912334241, 0.047254509263439104, 0.034752300634863786, 0.004519118101597996, 0.04882637062110007, 0.052916164640919305, 0.10378424660302699, 0.054514368530362844, 0.07935794012155384, 0.09831321556703188, 0.024500955405528657, 0.025771686632651836, 0.05559327684750315, 0.055616739846300334, 0.016474975236633327, 0.03362830313562881, 0.03169139788951725, 0.05433032332803123, 0.06972347546252422, 0.05337548354873434, 0.05356862006010488, 0.0645404051465448, 0.03380621077667456, 0.04033431614516303, 0.04263825794623699, 0.05635644214635249, 0.014106283833825728, 0.03226025408366695, 0.041343774282722734, 0.04446837927389424, 0.042403616826049984, 0.048651316537871026, 0.03659518690255936, 0.10110785427968949, 0.01900697716337163, 0.04307848881580867, 0.054990211356198415, 0.04393064133182634, 0.046952147167758085, 0.04813274455955252, 0.02850463060894981, 0.036946096588508226, 0.029272408355609514, 0.018865065540012438, 0.01036936804666766, 0.08118097393889911, 0.0586394590936834, 0.0341542483511148, 0.08450632987660356, 0.02706080827920232, 0.0335301058657933, 0.004975188721800805, 0.008190775915863924, 0.026070777712448034, 0.030474635641439818, 0.09808769915252924, 0.030251256612245925, 0.04999469660106115, 0.02668982164323097, 0.05429295248177368, 0.011805551821453264, 0.0561163759266492, 0.07364932534983382, 0.0264299196715001, 0.0060969463265792, 0.013882362109143287, 0.01570596738019958, 0.02640262904606061, 0.028095432644477114, 0.012802613309759181, 0.06362690299283713, 0.12462283310014755, 0.07453603597241454, 0.03439043684920762, 0.0331663681572536, 0.029838770933565684, 0.08042594257858582, 0.0452973396750167, 0.017419092837371863, 0.058854934250121005, 0.028169844081276096, 0.024798725462460425, 0.023271715799637605, 0.035331146136741154, 0.03496304459986277, 0.09679308190243319, 0.04942314641084522, 0.028929274521942716, 0.016832304499985185, 0.018821753801603336, 0.03460766347416211, 0.030197825690265745, 0.03972602222347632, 0.00792454527982045, 0.01919384809298208, 0.04044219844217878, 0.10352312936447561, 0.015699479154136498, 0.03808190165727865, 0.08356366874068044, 0.026158809414482675, 0.01423502048055525, 0.032366525920224376, 0.03852771347737871, 0.04077905185113195, 0.08237054018536583, 0.05837174045154825, 0.0191441130664316, 0.019770706494455226, 0.04424810242198873, 0.0686150704859756, 0.07296513198525645, 0.01809491848689504, 0.06265556527068838, 0.05401236499892548, 0.04896536745945923, 0.06745184306055307, 0.023103860548872035, 0.026770107178890612, 0.05999695851642173, 0.03703300950292032, 0.013437529923976399, 0.030665104131912813, 0.07436499319737777, 0.029399065133475233, 0.007302514668481308, 0.014593719934055116, 0.019183728909411002, 0.0295075411486323, 0.014308200879895594, 0.018126853101421148, 0.1682560401968658, 0.03594771871576086, 0.00922795605220017, 0.01650456280913204, 0.027106912348244805, 0.037877031791140325, 0.009852857383521041, 0.04860326989728492, 0.06895453625475056, 0.021579569001914933, 0.056817289878381416, 0.029704360567848198, 0.03374590756720863, 0.02925468586909119, 0.038330072129610926, 0.07648058905033395, 0.02986361247167224, 0.03003497993631754, 0.05318065122992266, 0.028002994440612383, 0.009386842448293464, 0.04531254628091119, 0.04134387447265908, 0.03840207529719919, 0.04391734575619921, 0.07302021418581717, 0.020619944225472864, 0.015213373353617499, 0.01366487758787116, 0.012073438374500256, 0.05297813768265769, 0.017920690042956267, 0.04177110291493591, 0.03138868327368982, 0.050982213142560795, 0.04744864396343473, 0.01924167765537277, 0.03956255306547973, 0.0033084092274293653, 0.024417584390903357, 0.015416270962305134, 0.034566667236504145, 0.017604568529350217, 0.038301506865536794, 0.028984928176214453, 0.0315920354478294, 0.04195850262476597, 0.03795188109506853, 0.027168076449015643, 0.0731949157488998, 0.007556850532637327, 0.01679767774476204, 0.06082705811422784, 0.04955067335686181, 0.038090640446171165, 0.09790322350454517, 0.020145216476521455, 0.026502828259253874, 0.02344095330045093, 0.02502352941519348, 0.01941236791026313, 0.01609373211977072, 0.02120837085385574, 0.04784162971191108, 0.07055355279590003, 0.007211746296889032, 0.08878814347553998, 0.008461906581942458, 0.04785171178809833, 0.06186623555549886, 0.0349452219234081, 0.05664639553287998, 0.03866898870910518, 0.01671567228186177, 0.07134757659514435, 0.03882994569721632, 0.025307065079687163, 0.043425120020401664, 0.09709945530630648, 0.051461555194691755, 0.051443101692711934, 0.08918073217500933, 0.05350555235054344, 0.022469988507509697, 0.037526801170315593, 0.024897818875615485, 0.013748670698987553, 0.032881936349440366, 0.1041666159289889, 0.047359664167743176, 0.05181224965781439, 0.010115805871464545, 0.025686523331387434, 0.048021170077845454, 0.008733945451240288, 0.06412802336853929, 0.05194712386582978, 0.03728142488398589, 0.0399194815690862, 0.052865179095533676, 0.018168083115597256, 0.060469376330729574, 0.038086462154751644, 0.02190544233599212, 0.01862068187620025, 0.09073798064491712, 0.018593478453112766, 0.06884470582008362, 0.06286495481617749, 0.019854810379911214, 0.06714864604873583, 0.016366053932870273, 0.006945174736756599, 0.015786184267199133, 0.03865216793201398, 0.005956637278359267, 0.061481676893890835, 0.005379225976867019, 0.04095186464837752, 0.03431245197134558, 0.05525149928871542, 0.09059186661033891, 0.05865271756192669, 0.0877489808772225, 0.0023014518956188112, 0.08006441275938414, 0.03554659902874846, 0.045948006518301554, 0.04226259021379519, 0.05096965229313355, 0.06458228453993797, 0.01650952221098123, 0.04187417980574537, 0.08529497310519218, 0.03352898893353995, 0.06567074058693834, 0.008976226054073777, 0.01498605166489142, 0.02781849652819801, 0.032744961863500066, 0.02678127279068576, 0.014031717473699246, 0.027416972370701842, 0.06698268698528409, 0.03140213098959066, 0.057606923874118365, 0.027133963631058577, 0.024201812375395093, 0.07241156403324567, 0.031156209224718623, 0.023597305262228474, 0.0133685667788086, 0.025556263426551595, 0.039164609770523384, 0.040115364026860334, 0.018083930990542285, 0.01707051163975848, 0.03264315033447929, 0.1207310329482425, 0.041193374345311895, 0.01574085017637117, 0.04015961087134201, 0.03451782278716564, 0.061564359566546045, 0.01347762816294562, 0.1293917850125581, 0.05781344501883723, 0.06633204611716792, 0.025663527885626536, 0.03541705715178978, 0.06455556722357869, 0.021106299573148135, 0.01504990883404389, 0.08302638350869529, 0.03991983779997099, 0.10075163081637584, 0.027309275610605255, 0.007014824832367594, 0.025703781975607853, 0.016764796891948208, 0.020063684132765047, 0.0307603402325185, 0.01411460052622715, 0.005888741434318945, 0.04496090186876245, 0.043796268073492683, 0.06142051279312, 0.029230738618934993, 0.17036584729794413, 0.10609139819280244, 0.09740315697854385, 0.18664933915715665, 0.1154617770225741, 0.1684265857329592, 0.13326107582543045, 0.0914797349832952, 0.10456524571054615, 0.11943279401748441, 0.1938273766427301, 0.18143158085877076, 0.11316075557260774, 0.2940935909282416, 0.20540844270726666, 0.07563725695945323, 0.10309497694834135, 0.12762916943756863, 0.11006857501342893, 0.12717610312392935, 0.14705377165228128, 0.12858026137109846, 0.1669247163226828, 0.13010696304263547, 0.11296794560621493, 0.12993969779927284, 0.15632254304364324, 0.1482501730788499, 0.09534305892884731, 0.11644618396530859, 0.09623811871279031, 0.10978222475387156, 0.12007265890133567, 0.0684227874444332, 0.24014346243347973, 0.08663518048706464, 0.12141978309955448, 0.11225819267565385, 0.11489362586871721, 0.12496491865022108, 0.13079189113341272, 0.1345434327959083, 0.14879149559419602, 0.1601982905413024, 0.19372761715203524, 0.14171373710269108, 0.09503441455308348, 0.2220000297529623, 0.09036796807777137, 0.06536649714689702, 0.1803929897141643, 0.15260796033544466, 0.21186089725233614, 0.1272101973881945, 0.2131388013367541, 0.0774926484155003, 0.18487437424482778, 0.1109831607027445, 0.19892722251825035, 0.13819184561725706, 0.11241918677114882, 0.12246405909536406, 0.1891671642079018, 0.11505231930641457, 0.1564617402618751, 0.10024670322309248, 0.2525528840487823, 0.19824579736450687, 0.17614714801311493, 0.16592305444646627, 0.21276253246469423, 0.22960036410950124, 0.09557119512464851, 0.20094065432203934, 0.10658115628757514, 0.18841949495254084, 0.1616748675587587, 0.10388931244960986, 0.2311224050936289, 0.15253894060151652, 0.12915889907162637, 0.13890001777326688, 0.14644908456830308, 0.10202425080933608, 0.10269956066622399, 0.11356317030731589, 0.09956127789337188, 0.18776719167362899, 0.24464763089781627, 0.12857278052251786, 0.09672441097791307, 0.14702261629281566, 0.1526967657264322, 0.15394578542327508, 0.1512912567704916, 0.24635531270178035, 0.16068715805886313, 0.10604804934700951, 0.11204070629901253, 0.09423623472684994, 0.10430766851641238, 0.12136664532590657, 0.08005854979273863, 0.22423666989197955, 0.1848974550375715, 0.09685648357844912, 0.14709831535583362, 0.08304345290525816, 0.13802462490275502, 0.20505587803199887, 0.16982755274511874, 0.13466152333421633, 0.17641693353652954, 0.1551061333157122, 0.2024466500733979, 0.1860398577991873, 0.13938952353782952, 0.14512728987028822, 0.21727510204073042, 0.14842960954410955, 0.14445971319219097, 0.16659575194353238, 0.17059037665603682, 0.09013138624140993, 0.11232923105126247, 0.056991330930031836, 0.1489767653401941, 0.10894698207266629, 0.1603721608989872, 0.14314168860437348, 0.1230540442338679, 0.14583164738724008, 0.16483769315527752, 0.1425778938573785, 0.08718884491827339, 0.14589852973585948, 0.11865289328852668, 0.1444800480385311, 0.10732099588494748, 0.1501028853817843, 0.12673269957304, 0.16297460562782362, 0.07884959122748114, 0.1709010248305276, 0.1387460221303627, 0.09358151204651222, 0.17605846136575565, 0.15293037897208706, 0.14738797559402883, 0.17876667698146775, 0.12224398262333125, 0.16341664362698793, 0.11542011285200715, 0.23756915994454175, 0.14719402272021398, 0.17749236489180475, 0.10325186696718447, 0.17903209867654368, 0.12952571298228577, 0.10908488053246401, 0.18011751933954656, 0.14562720054527745, 0.11111024607089348, 0.20907123835058883, 0.21218575013335794, 0.12054824939696118, 0.10326331088435836, 0.1331759663298726, 0.19518969260388985, 0.10934375648503192, 0.16542783414479345, 0.1768946836818941, 0.10443115446832962, 0.09081563897780143, 0.24127351585775614, 0.0951784431526903], [0.02978797649120679, 0.03820611862465739, 0.09586122643668205, 0.020726520342577714, 0.03756856924155727, 0.007259659350893344, 0.059899963525822386, 0.02363963365496602, 0.035213497176300734, 0.014297674442786956, 0.07612884815898724, 0.04630234863725491, 0.027736611664295197, 0.04006572547950782, 0.0208885738538811, 0.07159730928833596, 0.018517840617278125, 0.05701005160517525, 0.05074333064840175, 0.018227070868306328, 0.03434953709074762, 0.04015911734313704, 0.0752615521196276, 0.018727206042967737, 0.014746250762982527, 0.05863824568223208, 0.013994556284160353, 0.06314648853731342, 0.0342951413767878, 0.041516405253787525, 0.025872820951917674, 0.03728234885784332, 0.07749779892037623, 0.03726665614522062, 0.08898881278582849, 0.011744057464966318, 0.03408035641768947, 0.03213531723304186, 0.028567570298037026, 0.041928304635803215, 0.07250426569953561, 0.052290920066297986, 0.03584003308787942, 0.015246817310980987, 0.04990819557860959, 0.038603687135037035, 0.04797322733793408, 0.019950512178184, 0.09345831553218886, 0.07265878826729022, 0.02746162368566729, 0.04735310729302, 0.06781334319384769, 0.034851978489314206, 0.04474513356399257, 0.024421849884674884, 0.02641736253281124, 0.04171466629486531, 0.047207724273903295, 0.026215639372821897, 0.027161517718923278, 0.049190126883331686, 0.04703310063632671, 0.005498341606653412, 0.015595203694829252, 0.03871911707392428, 0.020046030294906814, 0.039856955627328716, 0.03637727008026559, 0.069880217051832, 0.017227553798875306, 0.03084567051701015, 0.07225389475934207, 0.09340390126453713, 0.019015061006939504, 0.044171779954922386, 0.033671993369353004, 0.059215432484052144, 0.05103757735923864, 0.030899288831278682, 0.025740961718838662, 0.03264433777076192, 0.07966282180859707, 0.06050152987882029, 0.05131199759489391, 0.05626396683510393, 0.020673918770626187, 0.020726305119751487, 0.0717696211358998, 0.020076373002666514, 0.06797179172281176, 0.09254322518245317, 0.06578023705515079, 0.0016647162078697875, 0.06843472117907368, 0.052753942291019484, 0.008144617113430286, 0.07348793049459346, 0.04349057002400514, 0.05277563526760787, 0.0459846908779582, 0.012209652159071993, 0.0139278845199442, 0.07749232929199934, 0.05606118240393698, 0.013955791127955308, 0.01572149125422584, 0.07568545945105143, 0.02808585522870999, 0.08142820559442043, 0.03863394078507554, 0.02660944519448094, 0.019457555426924955, 0.023591002573084552, 0.03890778956701979, 0.028042873746016994, 0.01942030889040325, 0.06119950863649137, 0.02817986678564921, 0.0647090062557254, 0.03623900796810631, 0.028384749639371876, 0.01993051315366756, 0.027970221199211664, 0.03682626200316008, 0.033799939628806897, 0.05787756286736112, 0.04974994371877983, 0.008929849245760124, 0.031832880922593176, 0.012029113604512531, 0.01599183709913632, 0.03426472445426043, 0.01952172151504783, 0.008597820724389749, 0.07718708395259455, 0.056106215924955904, 0.03652678686194122, 0.04740884258353617, 0.050248681800439954, 0.08622018634923734, 0.0336020125541836, 0.09737476240843534, 0.09898477757815272, 0.056368965888395905, 0.006423169397749007, 0.07027470564935356, 0.011424289223214146, 0.03620936658990104, 0.0061577481665153755, 0.023103559979062993, 0.029271951934788376, 0.12048063974361867, 0.044935687401448376, 0.06010306336975191, 0.023253548024513293, 0.03834653296507895, 0.06513483574963175, 0.027529930957825854, 0.10737089047324844, 0.045445279392879456, 0.05034005873312708, 0.08105924687697552, 0.02100738242006628, 0.05940919982094783, 0.028308764849498402, 0.04680052268668078, 0.009228343824361218, 0.03818267046881374, 0.04724676124169491, 0.03008748131833272, 0.04694169030699413, 0.04119988298043609, 0.013090128741168883, 0.016397331746702548, 0.08226321820984595, 0.012418511068972293, 0.043090073741041124, 0.04639145830878988, 0.036066261964151636, 0.020754118959303014, 0.011995736440439941, 0.02087976085022092, 0.024773935874691233, 0.02097355532896472, 0.030805681744823232, 0.08681213817908429, 0.05257578974124044, 0.0753719243220985, 0.02738168324867729, 0.028892204245494213, 0.04853490325331222, 0.027049292002629954, 0.0989407385350205, 0.06004252267302945, 0.015971517095749732, 0.01953124883584678, 0.01511942951765377, 0.026083954544446897, 0.07894121677963994, 0.038025836111046374, 0.055978032178245485, 0.014680191270599607, 0.03072715138841886, 0.0238516615354456, 0.020795211676158942, 0.013606678367068525, 0.049715222339727916, 0.0350443728530081, 0.020738947605423164, 0.049552999989828095, 0.024800610517559107, 0.013182813709136099, 0.024917476512200665, 0.05848786800925154, 0.04620292311301455, 0.06830764323240146, 0.03929862679797225, 0.04908835617243312, 0.03294081463536713, 0.08717013537534513, 0.026842158586077858, 0.024292183697980363, 0.01329147247815854, 0.05047832084528636, 0.02709114913159283, 0.010294395360688213, 0.04705247069068719, 0.046357234168681316, 0.05481142427015584, 0.05206257235840894, 0.02610569204989588, 0.07321477562072687, 0.03492866460874211, 0.05754554826125968, 0.06671300536254421, 0.03343501448398456, 0.10147727312869392, 0.031256336078513414, 0.022775846118747722, 0.028907206760777626, 0.044243193115107715, 0.07846512162359431, 0.05247794499155134, 0.04273609156371094, 0.0700280602904968, 0.039887814127723686, 0.009324291459051892, 0.01708997446257854, 0.045419871967169456, 0.004348514585217345, 0.02089921439619502, 0.03195162084011827, 0.03740336345799733, 0.02982665908348281, 0.05001107951102313, 0.05453411708003841, 0.08646335103549063, 0.004108633438590914, 0.041150686010951176, 0.012789164666173747, 0.01993332403799286, 0.020143346264376305, 0.016455811128253117, 0.05422105321486015, 0.051329961279407144, 0.06469457890489139, 0.03366287979588378, 0.026322410303691868, 0.01994715210457798, 0.03602162549213972, 0.031577051486237906, 0.03945860415115021, 0.052345924341352656, 0.05225722285103984, 0.12254813700565137, 0.02503327195881866, 0.024029185115068685, 0.032497440770384856, 0.06448590182117186, 0.04709777880634647, 0.07330109481699765, 0.006193851331772748, 0.020993988509871997, 0.0426856181002222, 0.015125595837162109, 0.04602133441949263, 0.013426086006802507, 0.060576906107598916, 0.0531036459869938, 0.06473334869951941, 0.015563598408334656, 0.023796573768777307, 0.028476347360992804, 0.02847310603101505, 0.005929233475399087, 0.0213601604627911, 0.040787523466860875, 0.033480029451311566, 0.07800853010849096, 0.04987369313312229, 0.08893855454516597, 0.06315647784504108, 0.03517526543873828, 0.012189290409878595, 0.0547372020810144, 0.04744595367810689, 0.013948307496320922, 0.06317409643088467, 0.041778064260142855, 0.046287357254186645, 0.08970062888693064, 0.043604255915852264, 0.04204321878205519, 0.027889811353816185, 0.05590057422523387, 0.012323313931119628, 0.027652170101646334, 0.023718069387541618, 0.04009879929071758, 0.040627872658660635, 0.07391925930278376, 0.03395087020180654, 0.028735629639413673, 0.0385250602994347, 0.021264586684992537, 0.014548891431331867, 0.04515317006735131, 0.09725944008096121, 0.021987128675391432, 0.03389481578778941, 0.019076698226854205, 0.004050160550832516, 0.013634286260639783, 0.045341916775214486, 0.057177109047188424, 0.02972622423840221, 0.07155912579037249, 0.01661231894104276, 0.033120262232841924, 0.08677610690938309, 0.012935939212184167, 0.010169015076826327, 0.019506889693730045, 0.029149512411095202, 0.017648670655034948, 0.016728025329939555, 0.010536136978771538, 0.04223649259074591, 0.019940687998314388, 0.06677593948552385, 0.01100617435440654, 0.15521435328992084, 0.11472078709630296, 0.22555313596967608, 0.0775905154296197, 0.10402294356026687, 0.0977435133245308, 0.20618685171939433, 0.11511324963066727, 0.15134927787585184, 0.10266765573760495, 0.24704558425582945, 0.14868415135424584, 0.11612138303462416, 0.13016021955991164, 0.1281227867002599, 0.13707734760828316, 0.10465661151101813, 0.18919241207186133, 0.13875307253329083, 0.15537447907263413, 0.09658810071414337, 0.08695532073033974, 0.16603945288807154, 0.12122604544856586, 0.13535724225221202, 0.17853681900305673, 0.08768927509663627, 0.10123833868419752, 0.18662679271074012, 0.13638216303661466, 0.15938580210786313, 0.16958633990725502, 0.10147466076887213, 0.15137130481889471, 0.2149700210429728, 0.07814090698957443, 0.1287719135871157, 0.1339277470833622, 0.12066411349223927, 0.1170122274197638, 0.2047643921105191, 0.16830135573400185, 0.18769907735986635, 0.2000721188960597, 0.19753064902033657, 0.1954881547135301, 0.10163532831938937, 0.15794627310242504, 0.18450971256243065, 0.10027870463090949, 0.056241884230985306, 0.15769294841447845, 0.15708514431025833, 0.1728923703194596, 0.15216461615636945, 0.09820624240092002, 0.15943516977131367, 0.20159432315267622, 0.2178501180605963, 0.11149426296469755, 0.09292192829889245, 0.18114946084097028, 0.10906972587690689, 0.13924608123488724, 0.09052214183611795, 0.136988720332738, 0.15359455661382526, 0.1419905581860803, 0.07920670526800677, 0.16766448912676424, 0.11791460477979854, 0.10528924045502208, 0.1515466149430722, 0.15065793762914836, 0.1270593484514393, 0.11032036345568486, 0.13367359119001776, 0.1927126114605926, 0.1363794764620252, 0.14210009918315336, 0.09248351940186694, 0.21691541274776682, 0.16222117730649188, 0.10084168301546015, 0.10564543423242867, 0.15012124611530453, 0.05475077225128189, 0.14167734218062833, 0.15191406710073352, 0.18130106676835567, 0.2226446443819441, 0.17475680855568498, 0.09967924226657487, 0.0933850729779806, 0.09578282595612109, 0.19082173792412505, 0.055201100039994344, 0.16524354403372854, 0.15982255601556972, 0.20956957567250356, 0.1503579763812013, 0.09188612020807341, 0.12341895082499832, 0.13494668615749106, 0.08886603929568082, 0.1284288929309696, 0.11269090929999948, 0.3063402744010091, 0.14752025599591434, 0.12307985613006167, 0.14490512054180726, 0.0999288191087544, 0.1011236546037253, 0.11398818343877792, 0.09905474726110697, 0.1490824471693486, 0.137740233913064, 0.14183089253492653, 0.08537888032151386, 0.15539638727204874, 0.1398959057405591, 0.1860954743460752, 0.11267470821621828, 0.1296803617151454, 0.08468446758342907, 0.13073772919597104, 0.24618031427962705, 0.21527195640373975, 0.05863303580554202, 0.1405352956498973, 0.09739875604282133, 0.10627312789438292, 0.16007301601348445, 0.12446565364371054, 0.20670996193075553, 0.195610252849292, 0.14980314677814022, 0.13968703569844365, 0.234272287634667, 0.14876930537866428, 0.14407967420993373, 0.09757227016962133, 0.1843465439742431, 0.18216164637124166, 0.14260829222621396, 0.1333408270147629, 0.11577944591408595, 0.08736467454582453, 0.18230054673040286, 0.16561635449761525, 0.13066903600702062, 0.06419362180167809, 0.20619771676138043, 0.12336294836131856, 0.14118641149252653, 0.13242648623418063, 0.07940468058222905, 0.15187672222964466, 0.12977792444871739, 0.12048649528878741, 0.20116803352721035, 0.15424645913299173, 0.1654701810912229, 0.07231897368910722, 0.21781418327009305, 0.1059800389339216, 0.15568716073175892, 0.10712237490224652, 0.14339738816488534, 0.13415830268058926, 0.13025739637669176, 0.13006469031097367, 0.14600769965909421, 0.10525956196943298, 0.19561667984817177, 0.22336568537866697], [0.028357100927678403, 0.10342623456381261, 0.04940448510751594, 0.0349879807617981, 0.03043673230422428, 0.037469711460289545, 0.032478092980454676, 0.014573525168088963, 0.027271225699223578, 0.02976306073833257, 0.040680706151761115, 0.041654652522993274, 0.03031237061804859, 0.022328247578116134, 0.06338531165965833, 0.09534254684695043, 0.011059034750360297, 0.03413868180359714, 0.09356316615594551, 0.02049831920885481, 0.03424103881116025, 0.028104568482376635, 0.018086710333591327, 0.05236510143731721, 0.024037421098910272, 0.025578607637726236, 0.012418746700859629, 0.10342872075852938, 0.032840669227880426, 0.011638060223049251, 0.0822462304495275, 0.029566352641268168, 0.025269393663620576, 0.008167658943420975, 0.05097588633361738, 0.005595812035608105, 0.009235616871592356, 0.020452721655601636, 0.048676093138055876, 0.049700086237862706, 0.01738047332764836, 0.045097011752659455, 0.02922473278886173, 0.06432284455513582, 0.012055803090333939, 0.04439663956873119, 0.062439719040412456, 0.024220575724029914, 0.0266934451792622, 0.012131061503168894, 0.05449465708807111, 0.056566184211988, 0.010291158669133438, 0.054714414436602965, 0.09314043883932754, 0.003261360775468347, 0.032162405623239465, 0.03347851918078959, 0.020681755850091577, 0.049038598881452344, 0.042983063467545435, 0.12407892048940994, 0.015707316233601887, 0.00681560317389085, 0.10376590813393705, 0.03748408686078619, 0.07295280491234735, 0.007985870797710959, 0.028098579350626096, 0.06422353035304695, 0.05510945964488201, 0.015410762371175224, 0.051727277459576726, 0.0343823622824857, 0.015144392582442379, 0.07567370383185335, 0.03265243460191414, 0.0594086320779752, 0.02232264436315745, 0.025448206724831834, 0.032164160802494735, 0.022020169089955743, 0.03249854657042306, 0.0597288799326634, 0.019267964526079595, 0.04913358636258636, 0.08168535976437852, 0.026865246800298337, 0.03372127939655911, 0.09573456409270875, 0.055216399414348416, 0.05608651561487932, 0.048111151772900485, 0.059198953094892204, 0.03588462874176912, 0.09490029362495989, 0.08355448837392032, 0.05191794261918403, 0.012027509637846379, 0.018181280356657226, 0.006557910946867196, 0.03662291353975888, 0.10631244687829167, 0.06609521195059642, 0.02850691456842469, 0.0050594809272297425, 0.10919324893620797, 0.03197006320988294, 0.02296901602676371, 0.014445918441197136, 0.049634903407422826, 0.004832535878449562, 0.014957008643250447, 0.06068731170671526, 0.02713231235247804, 0.027907934600079898, 0.031618374268873595, 0.07565974403405562, 0.04151692846789956, 0.045414498817990534, 0.03653986721474212, 0.02332312065846054, 0.023811134706193116, 0.010474688078829786, 0.0021154242313059513, 0.049619893470662646, 0.054091440833872184, 0.01945583921042271, 0.001099395535675285, 0.01297876577154966, 0.03854541741020512, 0.008529183196515078, 0.04279699220205657, 0.04475981324503664, 0.05585642014921177, 0.02787842309771804, 0.024058002709352877, 0.005108072582515888, 0.0367449671466602, 0.07265405336511321, 0.03852491558063775, 0.05972504302917514, 0.031697108715889044, 0.04376225915621035, 0.1307911638286896, 0.05011773726437241, 0.006993683364271419, 0.021004497320973314, 0.02892055614211131, 0.01817896856664447, 0.054456681391457096, 0.06856464155134745, 0.03660063426650595, 0.06812016930780374, 0.01968660631973762, 0.038217492037802, 0.012978277809452266, 0.03859422846289817, 0.10772089473903179, 0.042136681149713695, 0.015647354412067216, 0.07426426149322651, 0.017064784115063958, 0.03962714588851668, 0.04190665618807543, 0.009101393898163224, 0.038248157579801045, 0.023017908715701196, 0.06876185987493955, 0.026718060362327378, 0.031684499626862817, 0.020495018507062923, 0.030778283507970627, 0.04382518585771322, 0.06797836715122685, 0.04848226271860767, 0.0026175339826295385, 0.019580347470764536, 0.028504580513981637, 0.02584414807643043, 0.01670163826929638, 0.0617998096277006, 0.005554677109103068, 0.05986043674056418, 0.020852108427789062, 0.024177074737963267, 0.0035427050170255825, 0.02852013592928415, 0.10873391889617778, 0.05514674514415674, 0.02542684585932875, 0.0473724959010724, 0.031968040857464075, 0.03107711483608, 0.04120207973755896, 0.03548608430719469, 0.012742275775963208, 0.022319288000289816, 0.025977155783039052, 0.029243833814689424, 0.07697843655478209, 0.10309614212019369, 0.03254140559874941, 0.07293890448636375, 0.022550266621692572, 0.003035711470147362, 0.048411966490675695, 0.024917027512856293, 0.02147978168068221, 0.03203470056178048, 0.03129508731944952, 0.021299289510352537, 0.02935513184638694, 0.06045834059477784, 0.07168101612478495, 0.07299029079149477, 0.07804449458490126, 0.01374820871205884, 0.027356600512575824, 0.08711132017197087, 0.02398368775175186, 0.05584942911809776, 0.027189851061848458, 0.019530686658981722, 0.046929300151532516, 0.03597383860324044, 0.045415946005959995, 0.09369501611217856, 0.028893642156617716, 0.09113842126680538, 0.014231469303922495, 0.052722360196639784, 0.04746200633235276, 0.029926847164460924, 0.08363528599147685, 0.03493810472718906, 0.03126948322460521, 0.0691934632777702, 0.04161483630014118, 0.046218641800805926, 0.07434948231093585, 0.005037880255258642, 0.11617134441621602, 0.02788793557556346, 0.04743725941807497, 0.05542775194044225, 0.07664290416869335, 0.025584118084225338, 0.029370171469054185, 0.022154701910039876, 0.026771144330268726, 0.03687124728458002, 0.029018163404543884, 0.06770216205040924, 0.11503231842652895, 0.030869252259435598, 0.014655672566732392, 0.052787301829084754, 0.08167886597220786, 0.07732692683930509, 0.02657570716110058, 0.02027951180934906, 0.0840412852994632, 0.04080429229361471, 0.04256506734236609, 0.0730365191702731, 0.016251321612799075, 0.04179633964668028, 0.0257882495134254, 0.05535553355002776, 0.046896445273887366, 0.04926440473354887, 0.0492714588472154, 0.0374731513147708, 0.0325789211638039, 0.026215750694973394, 0.014989591709309025, 0.03185280387697276, 0.02699863114685286, 0.0864065025234595, 0.03268364191171713, 0.011283192106930073, 0.06515027984278277, 0.05081838775367942, 0.035575754300225526, 0.038628727197647095, 0.09324672180810012, 0.04241209215251729, 0.05486403882969171, 0.010890795438172063, 0.018179744110966567, 0.04142786332522519, 0.06476069684140384, 0.05103674986457918, 0.03526960725139361, 0.06012120516970754, 0.013823371573380427, 0.051449105667416006, 0.018943588474940043, 0.04390774978674017, 0.006004052165735629, 0.061387999303406104, 0.05918697854212951, 0.07062313656206243, 0.001838886787481897, 0.0020488825748543604, 0.03479897801298648, 0.05161145789315924, 0.02751039577560732, 0.10325605268008076, 0.022512537689181045, 0.008797118916845648, 0.0411430010717595, 0.03941997165384237, 0.024768358634901233, 0.03284537073341198, 0.018096649546350818, 0.06404232015484013, 0.035642632938106544, 0.08249323946074583, 0.07546117500169203, 0.0259858648860245, 0.07785546957165934, 0.04222679643135052, 0.0189473381760763, 0.019095574753009714, 0.023593900659761857, 0.01885359379230067, 0.012707122095889645, 0.026581991296552587, 0.007325456772377947, 0.0629919882339891, 0.057888264636858366, 0.035324986311024986, 0.0523747308034217, 0.030777775136812124, 0.016063864386524074, 0.042264267467544414, 0.00833334155686316, 0.058755816717166454, 0.03509499474603217, 0.052533390844473615, 0.035917628338211216, 0.048560956347500905, 0.04490696999710053, 0.013605172734969528, 0.057757334943744354, 0.0591252541198628, 0.04523328119830694, 0.04816558459424414, 0.01523244840427651, 0.08873965154634789, 0.11451055892393924, 0.16575157380430028, 0.2175531254033558, 0.13876304699806497, 0.10919140840996988, 0.15944512939313427, 0.12112091280869208, 0.2159081253921613, 0.17760557209840044, 0.1664196402998641, 0.12069915770553052, 0.07455119062797166, 0.1402161127771251, 0.12759229954099283, 0.18624292424647138, 0.24226187844760716, 0.1825002141413279, 0.11663679717457853, 0.16985919792205095, 0.1644095778465271, 0.0922001748404, 0.09594064365956001, 0.08006405652849935, 0.1590546261286363, 0.09139612462604418, 0.15081733610713854, 0.09954305074643344, 0.20031821506563574, 0.11410301594878547, 0.0661379522352945, 0.11325848157866858, 0.05898276547668502, 0.12802243349142373, 0.18348011624766514, 0.2028864319436252, 0.15427247883053496, 0.20913068437948823, 0.08118077355902642, 0.10517645627260208, 0.11673426342895254, 0.12384424597257748, 0.0841874661273323, 0.1274536515120417, 0.22896260692505166, 0.12185243293060921, 0.1808860874734819, 0.17067768290871754, 0.07030477747321129, 0.10166739652049728, 0.11306282176519744, 0.23065568326273933, 0.1225334127957467, 0.16433650598628446, 0.1993624327587895, 0.12983055756194517, 0.1644016962382011, 0.15354392729932442, 0.1483217754866928, 0.1728823661687784, 0.20087829907424748, 0.11684792334563099, 0.17687705025309697, 0.09115888227825053, 0.09281050966819748, 0.11207191360881552, 0.21423100522952154, 0.2188909356482327, 0.08696151766343974, 0.1121175111620687, 0.12501673540100455, 0.235988489293959, 0.07805648769135587, 0.12397321639582515, 0.15097360272193328, 0.14118767314357683, 0.08284310271847062, 0.14234490401577204, 0.2159095206297934, 0.2069489037967287, 0.21614561264868826, 0.06984462364926003, 0.20581586693879217, 0.13248121220385656, 0.21623039559926838, 0.12458562181564048, 0.14290256862295792, 0.1806227141059935, 0.2016812434885651, 0.16349686979083344, 0.11167736563947983, 0.1388175057945773, 0.18088776472723112, 0.2360674538067542, 0.16838419425766915, 0.10376336998888291, 0.13712012500036508, 0.13445404852973297, 0.1340273581445217, 0.08698557809111662, 0.17136890441179276, 0.12392116957926191, 0.13000242412090302, 0.16664108232362196, 0.19375808973563835, 0.17011961754178628, 0.09014396564452909, 0.24102862196741626, 0.18389816803392023, 0.08870543853845447, 0.1707367875496857, 0.15195346029940993, 0.10665488865924999, 0.10568834521109238, 0.2683001890545711, 0.08432192844338715, 0.18356512184254825, 0.11414008622523397, 0.13333116425201297, 0.17494063853519037, 0.1902847198653035, 0.1303335852571763, 0.1108775011380203, 0.15758640569401905, 0.15253511111950502, 0.07997985987458378, 0.10986308174324222, 0.14754315867321566, 0.1388358071562834, 0.10914751037489623, 0.15125603444175795, 0.1057148547261022, 0.1881547411903739, 0.17862267064629123, 0.23521193565102294, 0.09741990725160576, 0.09332020184956491, 0.08527634519850835, 0.1384404650889337, 0.18610733386594802, 0.16036334418458864, 0.06902204942889512, 0.1167360668478068, 0.10325353679945692, 0.29942075663711876, 0.15207444521365687, 0.1522644201759249, 0.17286586080444977, 0.1818057568743825, 0.07400792368571274, 0.11070291831856593, 0.13907661923440173, 0.17523700778838247, 0.11695848108502105, 0.17482704541180283, 0.13256436242954805, 0.16402119712438434, 0.10924638670985587, 0.13801996421534568, 0.1733427055296488, 0.1361473771976307, 0.1180896551522892, 0.13970732601592317, 0.12389641153276898, 0.13477750617312267, 0.16885673452634364, 0.13420597824733704, 0.11080062948167324, 0.11609351538936608, 0.2707882836693898, 0.08860582747729495, 0.1118361036060378, 0.1342671163729392, 0.15059659170219675, 0.22721673420164734, 0.17562387452926487, 0.32321882026735693], [0.0509293610957684, 0.033287568294326775, 0.061879148925072514, 0.03525457505020313, 0.05251121176115703, 0.011812405555247096, 0.05736852377594914, 0.05790409464680124, 0.039903569922898896, 0.07384647688013501, 0.08730856818147004, 0.04315806188969873, 0.02037952363025397, 0.010245480407320429, 0.03323362900118809, 0.031224998892867006, 0.023170972963271197, 0.05826292675919831, 0.024738663450989407, 0.027315377919876482, 0.08896493789507076, 0.04587807765346952, 0.014871504881739384, 0.01827502102969447, 0.055763354830560274, 0.023936153193062637, 0.015856922072998714, 0.06719485216308385, 0.03261533835029695, 0.02795918731862912, 0.036767691708519123, 0.029813103756168857, 0.041769915478653274, 0.009771047662070487, 0.021774546039523557, 0.04270509205525741, 0.08504342215019278, 0.029853495143470354, 0.04428702064615209, 0.0966006430098787, 0.0483318479382433, 0.0370641314657405, 0.02061199953459436, 0.12220913878991269, 0.0866230834799353, 0.07185976981418207, 0.02897659385780571, 0.06907932838657871, 0.007985635165823624, 0.04698032651504036, 0.04876532155321911, 0.07832329720258713, 0.016411801771027967, 0.04336394107667729, 0.04197971320536453, 0.024508757232979406, 0.015269028863258427, 0.016520452190889046, 0.020080449248780496, 0.04004984351922758, 0.04813835890672635, 0.01912353702209657, 0.061757440416840836, 0.062111478255246766, 0.026406683027744293, 0.05206814588746056, 0.03205936955055222, 0.01630380629649153, 0.01954256287717726, 0.037159864805289544, 0.02407687181403162, 0.07914270245237276, 0.03531134563672822, 0.03836286392470356, 0.026471190503798425, 0.04409213266626466, 0.02325703426322434, 0.06533497071359307, 0.015410416344820987, 0.029189601373218466, 0.06809256883570924, 0.01819322151277447, 0.03307294660771731, 0.02042254593106918, 0.1284155045868829, 0.07687285120482557, 0.004551663596430444, 0.036940805075573735, 0.031381009466713294, 0.011557582656678278, 0.031233704285114072, 0.06811923420173116, 0.03835559829894919, 0.06994672090513632, 0.059801257884828374, 0.06941900937817991, 0.0436368695955025, 0.015173622996371705, 0.03898661307175644, 0.02780903785605915, 0.036984205871704035, 0.11221111082704738, 0.054131791403051466, 0.09017514326842502, 0.06160346332762856, 0.03207845758879557, 0.04736545291962102, 0.023885867121862248, 0.016772565322753508, 0.030120189621811733, 0.05366013429011218, 0.026288876360922586, 0.044390576222212985, 0.03435056125454139, 0.025619761581765488, 0.03784499327593949, 0.04261185975337867, 0.008152978334692307, 0.07049786203424446, 0.07964872100274079, 0.039199750463012606, 0.015863586559135, 0.03067820674914401, 0.03429869255342055, 0.026311437650292646, 0.014822701250523096, 0.056118587526725605, 0.11283063344308175, 0.042706602325779386, 0.030001395898580085, 0.03715826547704637, 0.06965791413676925, 0.040631405281601474, 0.10561414528638124, 0.05858982425706927, 0.007038810581434518, 0.057095840165857226, 0.03860609911498614, 0.07998122542630881, 0.00978939448032179, 0.024435954401269555, 0.01983190028113313, 0.07711088765063323, 0.0317055061168503, 0.01697913099633297, 0.024536094242648687, 0.02011308890359942, 0.10122534367837943, 0.038137770534376614, 0.020277025614632294, 0.016784281979198568, 0.03903435172105674, 0.04306760893086903, 0.08285780466394499, 0.04663609615818132, 0.019569452742871363, 0.05104697294882499, 0.025810436018218752, 0.03181694701197557, 0.03206547742593102, 0.06783639430068433, 0.02536050342314411, 0.042074262819369324, 0.06434275637730025, 0.012339303502812982, 0.059921133288298734, 0.042313649973948486, 0.04632881362340413, 0.05043621138611343, 0.04972845112206414, 0.05005767896363977, 0.014984179597377079, 0.08798475377261639, 0.0369254760153126, 0.03852080037177075, 0.03425790411711205, 0.024997865948535036, 0.05288241918606218, 0.07582202946650796, 0.030295254837255925, 0.09124349453486502, 0.06371003095409833, 0.05334033914550673, 0.0680819561239332, 0.03183897766575683, 0.019375167757971212, 0.03630942665040493, 0.05373443811549805, 0.057324276931467466, 0.05286363542836625, 0.050695595709839836, 0.007186586562966113, 0.04106631124159321, 0.05556124946451746, 0.07422893526381813, 0.013957268929516431, 0.02712960536882747, 0.0283485588079202, 0.0038250956868068897, 0.03691534941026475, 0.03707213552843314, 0.0707924946618732, 0.052728238006238826, 0.03245690095354803, 0.03896787384292111, 0.05490236704645213, 0.027770776432589628, 0.020145856578892563, 0.02968526696349727, 0.08619222964625806, 0.02130155306076631, 0.029080592867103405, 0.08688466827152297, 0.0823865705751814, 0.05388220713939518, 0.08585352828959003, 0.028706541161227506, 0.06118138167948928, 0.008522889784217114, 0.026787516108015552, 0.08355839949217625, 0.016759327263571322, 0.00869295663505909, 0.06978366363910027, 0.014827335962763755, 0.02914795019023586, 0.031321645074058324, 0.07199215411674231, 0.03572023560991511, 0.10984345935867168, 0.026212719021714292, 0.03706386429257691, 0.011269784281466855, 0.011530552710610209, 0.04516599066846538, 0.02993836529640248, 0.04717156683909707, 0.0231804446229944, 0.037663363764295354, 0.05491891693964135, 0.08043561276281253, 0.02305229241756024, 0.0030441030730798957, 0.02738063682045322, 0.009753439280757448, 0.036639990357798524, 0.01870513086032588, 0.04151003391598351, 0.014694157562189503, 0.006426272038879688, 0.03162857879942749, 0.07765375383314677, 0.026098893977177795, 0.028137503140897024, 0.02222682011051802, 0.07984221374499612, 0.1099953695666045, 0.028328984662948642, 0.012274902710487368, 0.04107932109036483, 0.08714542185771279, 0.029345088732952718, 0.05420398010755889, 0.038034044264350086, 0.009825078795984155, 0.022670407342957333, 0.023700794044998474, 0.029454689101839904, 0.013681506334251026, 0.04270548168278765, 0.04169749670836609, 0.08333735080668703, 0.03341164796438534, 0.03931785584427416, 0.03838867582089733, 0.018164029133913573, 0.04480308045458514, 0.014259379622671986, 0.07533515090472065, 0.05074852939287666, 0.01901570853078738, 0.028243331544217654, 0.03169722003804054, 0.038572531775571406, 0.029362644236243796, 0.07074084860505536, 0.02450074018270243, 0.0925956059654709, 0.1170211257704068, 0.05776342426543124, 0.042692831775639206, 0.03234955671359785, 0.07522477870224975, 0.03916495857993141, 0.06120557198300958, 0.012371831835480407, 0.03230874230212066, 0.015560998108412605, 0.09416929300641641, 0.002084720422317332, 0.027682614854711574, 0.036512726874207146, 0.07387920559267513, 0.10523033619392663, 0.04561740570352413, 0.05349371138436254, 0.08090539966360666, 0.011417121004342334, 0.07605519000208005, 0.05581496377999429, 0.06524201671709307, 0.037765245797345415, 0.07715243307757191, 0.056869214240578, 0.048418219084851444, 0.010296783220837824, 0.03782918553042691, 0.01002938184683444, 0.021848150390724186, 0.053585451969411224, 0.03114506216661539, 0.044255427419557236, 0.028963747281522956, 0.009648656377976295, 0.06295896266237833, 0.03950220161641482, 0.035797682430711575, 0.02651871764101088, 0.03388432181964163, 0.037428225405164994, 0.05210469294979703, 0.04867998570261989, 0.05199514082050882, 0.0545725195115665, 0.09600486911949702, 0.025564067109371535, 0.04889566123893019, 0.010725442152761389, 0.053397146839415655, 0.023546145312138833, 0.02254347225971287, 0.06425740939448588, 0.02302097749634413, 0.04131530178710818, 0.07798069214913994, 0.02910970175435068, 0.0673762553196866, 0.05413096761913039, 0.065140579972649, 0.057643348482088186, 0.03791762355831452, 0.03684629999042954, 0.1906489214161411, 0.13461176975397393, 0.2090356152621098, 0.09561705242958851, 0.2041849825764075, 0.12382345099467784, 0.2157161763170734, 0.33055224863346666, 0.1856456883251667, 0.13726555625908077, 0.1754926925059408, 0.1699112224741839, 0.07244381777127273, 0.11040021854569204, 0.16249712265562266, 0.14145495020784438, 0.13139044807758182, 0.17320218728855252, 0.15901673206826672, 0.1932575853425078, 0.13696905341930687, 0.11814702316769399, 0.09821318148169667, 0.12711777031654492, 0.18576300702989101, 0.11824999615782872, 0.1046380281331949, 0.13479530287440866, 0.09963921082089655, 0.15724535915069282, 0.1320296895573847, 0.10942522203549743, 0.14150204689940438, 0.18487511639250442, 0.10566524957539514, 0.12413481905241497, 0.20220736681949347, 0.2830353827448562, 0.1901722399634309, 0.19409294676734135, 0.1376744796289131, 0.12857506633736193, 0.10580328162177466, 0.19490813661832362, 0.2632430463563651, 0.07797090322128497, 0.2275707683293149, 0.1315982048981823, 0.08757171890465543, 0.22494920587632805, 0.24053840374108404, 0.1592429238371551, 0.10286918593919836, 0.1945505104959011, 0.15837943501537666, 0.1326604260248132, 0.07018710253760219, 0.12817040289519355, 0.15579505416098982, 0.10428399400552735, 0.16757296747528017, 0.08446172680123709, 0.1293411260121502, 0.15111186483409256, 0.10698435027734376, 0.1395468885311857, 0.1198696369829122, 0.11267845606198534, 0.13950379943707958, 0.2368054009275511, 0.14176188764395192, 0.14109083771472797, 0.14209839224349707, 0.19806683587376028, 0.21222677605692297, 0.22585630329558626, 0.10997774355928414, 0.2350436759297736, 0.14749521593330428, 0.15642923419363797, 0.2797549415845424, 0.10874167433939874, 0.1592743315268308, 0.17018106736941263, 0.2237198085640557, 0.24688951059943065, 0.1977155328495428, 0.16366891446523368, 0.12854331725975499, 0.1318719534901902, 0.1663349018781446, 0.12835772096877918, 0.16373811231460422, 0.1961800886783749, 0.12466498708818108, 0.3519016702193767, 0.18059669440845028, 0.06151211979158688, 0.1960634082206525, 0.0932970987923909, 0.13295100652612746, 0.10272376210195944, 0.1402084092842415, 0.20281319681089371, 0.17044013628037646, 0.07267000211868435, 0.12321794012677856, 0.05325055411958601, 0.10314936895156279, 0.13554193312302232, 0.13863526401109993, 0.16548677551327273, 0.3134220850188285, 0.06853493337985128, 0.12202651108964346, 0.10728669381933287, 0.17360440164338797, 0.04920029801724013, 0.22756220394512638, 0.115843352250522, 0.15555283200228587, 0.12626755109522492, 0.20264241378754377, 0.10072694698465057, 0.24950096500106156, 0.16511595400515944, 0.19889674993464723, 0.20360656752018258, 0.16131629148731008, 0.21868199139134958, 0.23953233350766823, 0.11132810352137312, 0.15431794279720634, 0.25960961007513106, 0.14869725768221542, 0.12273925487534143, 0.24042519653448835, 0.16314740729285404, 0.31956688966602087, 0.08991876835352741, 0.14486814674455673, 0.0975995663611684, 0.12216975301271304, 0.15041371167171746, 0.11009382287738845, 0.07709440455073491, 0.1454254996497184, 0.2558276255149394, 0.10494679125258699, 0.09529365415801294, 0.14490050438325852, 0.08111062576062977, 0.16262146207736805, 0.15319002675823867, 0.13026060245465487, 0.08913737590773962, 0.11586319727939554, 0.1549666392384097, 0.21383612329373136, 0.13252680975710973, 0.26060485979542136, 0.12015905973385088, 0.09285146137699485, 0.14806193474214524, 0.10618027037708089, 0.11903414939297363, 0.09510929725365713, 0.1397926136269234, 0.13214622158557177, 0.09383946773596108, 0.16012404608773068, 0.13673138804733753, 0.1451156084658578, 0.14982947817770764, 0.09933832930983044, 0.13296362303663045], [0.05518870988453273, 0.031289732723962516, 0.01681766934780171, 0.0328700879617827, 0.01743545162753435, 0.03505487053189427, 0.043082774718641303, 0.025813157844822854, 0.03515612173941918, 0.03255503143009264, 0.016162909560080152, 0.0436736096162349, 0.030159603229549248, 0.023268572804227006, 0.022133255697553977, 0.010918430234596599, 0.03743387685972266, 0.016170833841897547, 0.020022300122946035, 0.04555266074021347, 0.04107757704332471, 0.025223788688890636, 0.06996393873123452, 0.003883352424054465, 0.024916316906455904, 0.053551910605165176, 0.015256835376931122, 0.11472339945612475, 0.05561530007980764, 0.016359549008484464, 0.01858713494584663, 0.013818048519169679, 0.06591673285583965, 0.027391949006414507, 0.031030016289150808, 0.015003350199549459, 0.07428984332364053, 0.03722797911905218, 0.04995448332920205, 0.04850720630201977, 0.058185450252494775, 0.0508426040323684, 0.023707564287178684, 0.01833245398302097, 0.027322621281200554, 0.011936621594941244, 0.03307964449049905, 0.05958233174169436, 0.04057137295603752, 0.01870437201432651, 0.04045048823172692, 0.05325602745870128, 0.040978570832521655, 0.030535289515682962, 0.022574475478904787, 0.01870326992502669, 0.03789606787904631, 0.048600052687106654, 0.03757877006137278, 0.061773526467732154, 0.04261457230313681, 0.003014597368746763, 0.06346729671349749, 0.012068271171301603, 0.035395297381910495, 0.06948495662072673, 0.009654390396462986, 0.06074545526644215, 0.0624478975078091, 0.06826076918514445, 0.01800634872779483, 0.032904037507250905, 0.045565017499029636, 0.026908901782007888, 0.029750295798294246, 0.0624108272313606, 0.03481784340692684, 0.04707523235992994, 0.019051660019613337, 0.021235023232293315, 0.07964394157170318, 0.052799925761064515, 0.03149885138554964, 0.02149138515960658, 0.013951750133855967, 0.04845430230489001, 0.09860148798907176, 0.03791792783886194, 0.027112984971608967, 0.06988312627072446, 0.07562526385299861, 0.024965443371911533, 0.054686472576577216, 0.04237962690240238, 0.024792916301521473, 0.031424228436662816, 0.04098845995031297, 0.07401472917990759, 0.01747679852996953, 0.0761998345842585, 0.02845694947609445, 0.058360559996799566, 0.04401129423058592, 0.06933233395102434, 0.08771443390287459, 0.1286555893602781, 0.018637369066709653, 0.03771683921513613, 0.020511996990535408, 0.03570473214494996, 0.012723695181193762, 0.04320289874158334, 0.044651478237938136, 0.02317070022400003, 0.00611977989137813, 0.0660355061700102, 0.023525287251686677, 0.008504304551024688, 0.026272317190887406, 0.04319632331316825, 0.04018538194941357, 0.014974494570196839, 0.05993108177790418, 0.026989656726073008, 0.04929091424855869, 0.041744834597921, 0.03793568001128733, 0.07097144130966626, 0.06117570796050131, 0.03783991327509284, 0.036754496322828345, 0.032928802975220606, 0.010641485769156134, 0.0619911167450482, 0.09621865960070863, 0.02103857488691574, 0.08568661927711219, 0.08924765905248933, 0.024166812690964434, 0.02232790990092326, 0.016754514435888268, 0.03968619857914746, 0.06540635789860971, 0.05023426558182109, 0.0102892856739345, 0.02872848832339514, 0.007502607886635815, 0.01439747289623483, 0.02031513304245891, 0.027918936939386185, 0.057530619960743934, 0.03451404525549151, 0.043056461872765794, 0.032201260764850304, 0.023207878111861646, 0.019839019332721364, 0.03683649250888266, 0.033634711580816656, 0.03897171074640937, 0.029569055914180353, 0.044514937908388674, 0.04547359603748191, 0.03435501042986289, 0.028391024497977924, 0.07562233236967586, 0.03477562262560241, 0.055935662967385724, 0.049789975164458156, 0.07646751240827143, 0.04495333196246065, 0.031405489207827486, 0.018242433325212914, 0.02339562663109973, 0.04194172637653537, 0.017819555723690428, 0.025190575724991504, 0.03338556889502797, 0.05296811868902296, 0.001247030509148317, 0.07766457434627227, 0.036350697482703254, 0.027374347118893638, 0.003111325418103661, 0.009487062070547836, 0.045572097587864846, 0.062360902957152575, 0.038584053618251346, 0.11944759986363351, 0.0335567526781233, 0.06630959614994936, 0.03601775890274439, 0.018405286500637885, 0.1225272826559376, 0.017734709690557793, 0.05091397266369313, 0.038414981245296076, 0.011526176822371781, 0.05232465067820158, 0.025172992391162552, 0.04160973403486423, 0.021421766141429543, 0.0546406189823756, 0.0561422249302268, 0.1095377687306609, 0.0340639512432972, 0.019517081236699596, 0.03208903319318779, 0.029649603056896012, 0.012760108656948432, 0.06340827370877378, 0.037556824754574336, 0.04833343984500971, 0.05123639501107391, 0.031392553573823534, 0.03666801756480709, 0.035853603258146904, 0.051952626890852116, 0.0220818823800073, 0.011725438835128443, 0.06745596940163523, 0.04093420153367333, 0.09674692773842253, 0.032843767694430426, 0.014921521924406989, 0.018798962446453515, 0.036364790867082775, 0.028451379657781217, 0.007197705790531472, 0.016714197263354436, 0.08943037581047975, 0.02470465267833788, 0.02116906485753134, 0.03670755548228044, 0.026939519084407948, 0.01858848008851055, 0.0202006029576296, 0.028320986166363582, 0.05372532454202883, 0.04577981359034311, 0.010933139601547737, 0.05891583859920502, 0.039868199164629914, 0.07850309732020833, 0.0055433250327041605, 0.058727392461150885, 0.03301145967270713, 0.060457683794084005, 0.03285279592091683, 0.03361560498888139, 0.07780164160067216, 0.04367877496406436, 0.03012902303453302, 0.014779681732761674, 0.03051864870940335, 0.02427424227789743, 0.03777994032134302, 0.05956316948868334, 0.024452086836390663, 0.03094822048296919, 0.01778421094059013, 0.016449890645162668, 0.04272228019544855, 0.09054380512679927, 0.02934047814051155, 0.06796555026085116, 0.04222449577355292, 0.017119059230026323, 0.05313303503498901, 0.07964489894220605, 0.011353611716913292, 0.021969703047943767, 0.0724899496708531, 0.05623244782327674, 0.01734405057504773, 0.05051799977081828, 0.026368056096544024, 0.029590542944788467, 0.021758688199042808, 0.04264280360075645, 0.023054721095832065, 0.0820403141551651, 0.029312311780813616, 0.037351876962929964, 0.05703564456780441, 0.024056121364992578, 0.016935882340476383, 0.06621744367294014, 0.038769879975006916, 0.06332928693154827, 0.019679188553709537, 0.022721110872225836, 0.020450148258532863, 0.05090970160381403, 0.03905858284269925, 0.004976308900950244, 0.007674109401705209, 0.03155282036459539, 0.01181642150186235, 0.09377829250297509, 0.043321104312781245, 0.02361600552831078, 0.04283183232473675, 0.0028561288945638807, 0.006343049917632015, 0.11390658430173062, 0.050347339201834984, 0.021010256386944093, 0.06365122317220084, 0.029815556554240175, 0.08664877663250081, 0.09729985744343139, 0.0668026642233599, 0.06050484356819652, 0.05195057856326457, 0.03657461085822433, 0.04677748271205928, 0.028376120317261666, 0.02321806037798524, 0.0518429226212902, 0.04295488783100154, 0.062392666877713054, 0.014736703960807063, 0.03715543047292158, 0.02397729600488674, 0.04358356854936574, 0.042724436134449206, 0.043232684838585556, 0.10769594373414293, 0.009074419613170903, 0.02861176890291972, 0.058317741786595434, 0.018852487992262468, 0.0367919970449293, 0.062254167278297246, 0.020635469954868313, 0.046953709388617426, 0.010969669037876884, 0.06357155361911282, 0.020459896368265618, 0.0510447131091496, 0.029448113673424814, 0.021832086604263168, 0.023227750971273053, 0.03547713771695271, 0.06949914648430422, 0.02805270349199418, 0.0508083650493063, 0.00812803289591102, 0.018697401392273605, 0.06375741708325222, 0.03808131907135248, 0.0691245029156562, 0.11950229614740238, 0.18353349150856957, 0.14267020218539983, 0.100341579382075, 0.19846964394673705, 0.2858312608441338, 0.09121960480115376, 0.12693042255705222, 0.18758080870611593, 0.1623935336829163, 0.0885507749626413, 0.21932541858404875, 0.18241875601233914, 0.27520679344888777, 0.1715421662083827, 0.10920346088823862, 0.20306959399022162, 0.14152784395264462, 0.14186543208779767, 0.19100412813713774, 0.17810113378800452, 0.17398308991687372, 0.18596203619381413, 0.1779390635783784, 0.11659173396765254, 0.12048146352753974, 0.223716557957232, 0.1630708621814847, 0.17168339691124856, 0.04318122060794849, 0.17062282335245982, 0.10928189105470665, 0.10529620180022903, 0.15655441966373473, 0.13293084979522973, 0.1654748120927252, 0.1815601802081801, 0.09955989007721655, 0.10525433724978939, 0.12542285345261917, 0.18274662201292813, 0.11499327403726056, 0.11776639046729542, 0.1225790251919534, 0.17821548390202224, 0.1369484662427567, 0.10341499844798818, 0.18128430907381698, 0.16002419753931463, 0.1594992764876224, 0.15247036615619436, 0.10738441240391694, 0.14342509995913133, 0.12401279513142072, 0.08334967787959613, 0.1172550581395626, 0.13204448798205703, 0.09460944595048204, 0.1088375152903609, 0.09617722549592145, 0.10554553373367526, 0.07428389129927382, 0.16772253991803154, 0.14424647932173684, 0.13173793646274135, 0.1537485225708224, 0.1461752172326669, 0.12721313629299402, 0.2195912558818236, 0.10494336253032088, 0.15982032957253978, 0.13705114979529753, 0.13603207713458687, 0.16320194030413404, 0.0996656461211387, 0.13720714923692867, 0.09741719099110924, 0.11308424756862223, 0.1294341022730805, 0.14995947276474908, 0.19061080471146852, 0.17872161377454177, 0.12724495958536863, 0.20260123943444341, 0.12047600132063963, 0.13061542325885966, 0.19601436710217968, 0.11790809614467435, 0.1701752786175348, 0.15974172129062936, 0.10765710714622401, 0.12220841890666634, 0.13063280435744673, 0.07806458452250808, 0.12601229682331905, 0.18514792987843975, 0.1533518743235618, 0.2111335183144547, 0.119788987794891, 0.15104976191651076, 0.1130420713161584, 0.09134720225119963, 0.10797876137075946, 0.147683706600219, 0.1650057005463168, 0.2423123296466656, 0.09370049316203222, 0.228315350250341, 0.06555129933985882, 0.08989726833533496, 0.13170538586564362, 0.13474879990098998, 0.21563645481364802, 0.07473927311366424, 0.14779746299609542, 0.14975465484894812, 0.18548847176134586, 0.12250406085513532, 0.12815462483558804, 0.10314499028027058, 0.17400496843038127, 0.12239536590641364, 0.2168580744182691, 0.16287446022033691, 0.16765910113463178, 0.10658408034942113, 0.11158403314766474, 0.10522859956836328, 0.19255871971836314, 0.11390659914468415, 0.08690216069226153, 0.1639959789463319, 0.09266657012631185, 0.2017329860245809, 0.20265569823095575, 0.1487552491016686, 0.17100590514019132, 0.16430843796115369, 0.14671653974801302, 0.08992544026114047, 0.13342639664188027, 0.11955785332247615, 0.13187067699618638, 0.13773413345916197, 0.22017968993168324, 0.15825453156139702, 0.10250453909975477, 0.11088183528045192, 0.08046463073696941, 0.08157768897945061, 0.16877953632501885, 0.20009144442155957, 0.12508119834819809, 0.188270382641349, 0.1681560283759609, 0.1627843189635314, 0.1266228171880357, 0.08842533716233447, 0.1269333466188982, 0.19500035588862374, 0.1568057108670473, 0.22322403907310218, 0.2289831347297877, 0.20249665598385036, 0.107039892609464, 0.10468761101947166, 0.16073079634224996, 0.10439174642669968, 0.20311787811806425, 0.16334247338818386, 0.13434624415822327, 0.08851538936141878, 0.1211337000131607, 0.11910946253919974, 0.05754880628956016, 0.12509795604273677], [0.059126025953446515, 0.0479276743135415, 0.08893403486581519, 0.02525412397517357, 0.04599008629156742, 0.16308923775795847, 0.019014888457604684, 0.020909808554279152, 0.04571494246192742, 0.06375259312335402, 0.016659449029248208, 0.03544114726537373, 0.0406986587040592, 0.029275183987920173, 0.05698898203263525, 0.03580535252694972, 0.029505858328775503, 0.04802839859621599, 0.05860429613676388, 0.022489892908197362, 0.03844359845970757, 0.05313784415193368, 0.02116654155543074, 0.02251550256914925, 0.08587039730628021, 0.04694947172538377, 0.05433774851553608, 0.027410489710746333, 0.02228800833108835, 0.028779138046957087, 0.025138647652056534, 0.02400060315267183, 0.039025995138217695, 0.009585511670593405, 0.024924512072175276, 0.04883850102487486, 0.03570929264242295, 0.020959280118404422, 0.03494879536447115, 0.059062301443191245, 0.01787224264262477, 0.05577895477472339, 0.019523998053045943, 0.06558118562679738, 0.048997973717632703, 0.01069359845132567, 0.06413410155801103, 0.024180620348488446, 0.01909039270685753, 0.019023848035431, 0.06781142845284194, 0.039834357230574824, 0.02787284400255885, 0.03159257350489497, 0.030125755729386583, 0.03359757080033887, 0.03471544558124151, 0.06646063062362373, 0.022060395349399187, 0.06323965775663964, 0.02848692296538502, 0.017477273504482582, 0.05185510868614074, 0.03425946633797139, 0.048817988063092344, 0.013743105519097298, 0.020674124716606457, 0.043619521893560886, 0.053158279188210145, 0.05771362244558986, 0.005523847366930568, 0.0298235402078717, 0.023906799397082068, 0.04633020515029784, 0.01964918352314271, 0.025743086116563063, 0.06399867444997653, 0.05454732359794434, 0.044274830870563164, 0.0790975650306791, 0.019255661572969984, 0.04233425570419058, 0.012580771453940542, 0.019459344002825674, 0.04679820718592964, 0.06842153321485966, 0.06900704320287332, 0.028843352374678943, 0.11267427777056582, 0.0008361203867934819, 0.029047429998172447, 0.009523240842099767, 0.030382848672161344, 0.020991906785639003, 0.011202241421415238, 0.035520705496310256, 0.07879288372350857, 0.03791498522332404, 0.03010825032106368, 0.032640920180710964, 0.015039320242067333, 0.07980488371686079, 0.03305376951175276, 0.0343816757958848, 0.025292895625170786, 0.024814249336486682, 0.026355595437053125, 0.03637232737673912, 0.05201501182455104, 0.023600058630108833, 0.05430957658973057, 0.03353690764924977, 0.03318481794849504, 0.05960236601822544, 0.026091433537658304, 0.040234185580629855, 0.04413096925418358, 0.041250742360716686, 0.053738308415631764, 0.0419368504662998, 0.009697293953649933, 0.03280048564192839, 0.016683325775375124, 0.005465627737066825, 0.03448218856647145, 0.024111548664222937, 0.07629492596606724, 0.02477183374139713, 0.005346800617189729, 0.08616252147476189, 0.014028275763848796, 0.11697680471115746, 0.023210677863971796, 0.030984316690592095, 0.0634335215727333, 0.05508231930434704, 0.0671982066705823, 0.025426510037505068, 0.033551925007486716, 0.004129361623199657, 0.08738038581213914, 0.05444417991384398, 0.02293281962920446, 0.015348936831287574, 0.003434869336160773, 0.056929554557427764, 0.11196569743333384, 0.010603211358102271, 0.05048271435953211, 0.05820893922646064, 0.07361448893789202, 0.02769272105069831, 0.0440839356451761, 0.003241506469748856, 0.03269410619395785, 0.0328502132470021, 0.02046519901341526, 0.07300949015188962, 0.029248403589008376, 0.05165013863006607, 0.04325853013142478, 0.02974242903292179, 0.025779187890293542, 0.0035679591428561253, 0.029362991190282628, 0.02819601406372385, 0.03028872022696305, 0.0372836587484926, 0.032773100392660126, 0.058199747727485374, 0.04161547825788148, 0.033206766966031864, 0.03229747278965078, 0.03901459203916602, 0.040390737922280096, 0.01871754699095618, 0.024668363512319047, 0.053337370554800145, 0.05221929168328643, 0.024073756649158895, 0.01981422788958298, 0.03903614400769584, 0.0457722473947797, 0.03524474159348756, 0.02755338282440789, 0.05161734683497343, 0.03228358349588234, 0.061722737591480836, 0.04527133110968862, 0.014259118943300564, 0.01954492476215819, 0.034615151744219474, 0.024489945644745603, 0.03226443237508647, 0.03619142888055649, 0.046047283613006584, 0.028692364285234362, 0.06148356194898952, 0.006203085040397127, 0.027874595471075736, 0.070525143382838, 0.04187648788501974, 0.053465509772649966, 0.007739716184005374, 0.006646509464189876, 0.023484151861339342, 0.03983196751505602, 0.0405832621618174, 0.08968381182057783, 0.06032285040419083, 0.0379472834902117, 0.07571541253128089, 0.04350024391897023, 0.042719578777905554, 0.05366656871046871, 0.03527732929796912, 0.034897420191555284, 0.047217579995049164, 0.016614357991784345, 0.05284289611154236, 0.052635788670158945, 0.04700931480329018, 0.035521336321835406, 0.027215889313083608, 0.06705746578518301, 0.038018963823560625, 0.013760165638814215, 0.036802131071453914, 0.025080453997361474, 0.027341946806700435, 0.017451018175052013, 0.03701937253936194, 0.07596757204737514, 0.01125381511883461, 0.08241997464210726, 0.019338616984896362, 0.018896790497819893, 0.09515435303910635, 0.0271619110571919, 0.030724299685971346, 0.04266992167686112, 0.03890543695888482, 0.05067603269708343, 0.028960166418983135, 0.06922498971107416, 0.0724945732508786, 0.027040723907703068, 0.010446471624163678, 0.021189490616961848, 0.051613094328786246, 0.03425954426347744, 0.023625640460522845, 0.035312291875015944, 0.0523338310449617, 0.04479430826904718, 0.15395396389067173, 0.060409188154153526, 0.06690988971968181, 0.05148656928213313, 0.06448242857004516, 0.051032890696660616, 0.031089104231796227, 0.07530334987677634, 0.039743941379128955, 0.04280911147361621, 0.029042236819805112, 0.020545742445392534, 0.03256547715864144, 0.02081589904264547, 0.0630320493655745, 0.005424054943432566, 0.019049882575927768, 0.03503105872368906, 0.08505531135597266, 0.055698368669254705, 0.034776936226990074, 0.019477155547065195, 0.06254301115404814, 0.050930949291796423, 0.051290315750520676, 0.032032581730163656, 0.043291062174830586, 0.03868573527142871, 0.058732350007630885, 0.021633541691699065, 0.038247307820711285, 0.023243339783221018, 0.07012450238107704, 0.02909415190515574, 0.031771943176863715, 0.07660477262106724, 0.03537654331012163, 0.054867571452632546, 0.0384084911638638, 0.040241473470814526, 0.040608064737170935, 0.03770916169742122, 0.06397790915798396, 0.03775402081373613, 0.012019136356684612, 0.07655861103557982, 0.06732605645083822, 0.06282196220126934, 0.04109501380298752, 0.010831881900230655, 0.09694214226328768, 0.05127449316205457, 0.028672155603999272, 0.012248203947820002, 0.035519670200301334, 0.046782740828348324, 0.005249646528682206, 0.07488512739655562, 0.011633002486632904, 0.05237810386461206, 0.009555069700581953, 0.02889281095121987, 0.04437560710357502, 0.05870311309990939, 0.02920035880379146, 0.022623334771196824, 0.04296008657547645, 0.006819730906499899, 0.04942360654240474, 0.0495514711656142, 0.035488262510625646, 0.005382082317737513, 0.0360614454257302, 0.06312654702924192, 0.010357150440540863, 0.04530073500063736, 0.01705803799268324, 0.08922324239392765, 0.011147741806780687, 0.037334699954953976, 0.041760323219932616, 0.012255444526090287, 0.008262700230261544, 0.012211599369038595, 0.0731777647160925, 0.01118214962843922, 0.11247095157159492, 0.03326170815853402, 0.06569387333001941, 0.053403529309434816, 0.0743876287015155, 0.07669620521483012, 0.06700615369481966, 0.055751651161699556, 0.01144908252172172, 0.06474206893472001, 0.04535520121862646, 0.17829042597441003, 0.0872118589177262, 0.20231968344887719, 0.13012642215471715, 0.11767298376071267, 0.20668291806941852, 0.11290895970887505, 0.07928679784527048, 0.11388659084332176, 0.12904315371997654, 0.11109384460723959, 0.17976896226173267, 0.24032245361013338, 0.2312506185262464, 0.1616896956693381, 0.10223602264886722, 0.12545679928734899, 0.16048851481173187, 0.06651320436503738, 0.11679348681354895, 0.10267254649079405, 0.2101447104359977, 0.12051262630848214, 0.12922500958666205, 0.17400793702108786, 0.16471841518068686, 0.17442866053897887, 0.1294242762378417, 0.08873084225342609, 0.07904072394012474, 0.10478109936229885, 0.08191989327315241, 0.15316829667426646, 0.09616235285648145, 0.18575224588857964, 0.22364324860973284, 0.1637430550181307, 0.09616880954126827, 0.13851840543793514, 0.26712486462201923, 0.13514250924345106, 0.17603641957975924, 0.09125367680098861, 0.14595698128687218, 0.12187742846435867, 0.14765872590942308, 0.1893852962530218, 0.11157198809087276, 0.1508478680625558, 0.12950674368767068, 0.22492373536806554, 0.16402588749770075, 0.11059967073379084, 0.15820020635146648, 0.13233554345788434, 0.17214021849213168, 0.1510807836893946, 0.16905818309169263, 0.1582568173762411, 0.14672385732410476, 0.15034273266792297, 0.36171167506836355, 0.10904505688813515, 0.14077833417104557, 0.12627188523765653, 0.18852568144211546, 0.23024683410767466, 0.11513243414810859, 0.1188975348486565, 0.14175661839544773, 0.15498574211960658, 0.12976799451280385, 0.10661408537998796, 0.16276496375212446, 0.08817043169983663, 0.08929733841796406, 0.21059191378299147, 0.09749977718456648, 0.10596743726637214, 0.27343347610440105, 0.23240157082909718, 0.17035953904269263, 0.10427858374896459, 0.11939451404032297, 0.1372804437414743, 0.11672852662741207, 0.2267697683419101, 0.09258123798645101, 0.2685187663882971, 0.18069352983729914, 0.14699168357765302, 0.14549870509654284, 0.1481315036653541, 0.12139742961153388, 0.1204221585066989, 0.15045696403831244, 0.13293013733346015, 0.23061354411765933, 0.12930309836519882, 0.12870823731645942, 0.09618692536605522, 0.1490093010943383, 0.1450078931520693, 0.13356651412323117, 0.1816755990148522, 0.0946012229542248, 0.16851165069965646, 0.14454032527282834, 0.1347867978620343, 0.14319683017674834, 0.1689683535369113, 0.22088337951572612, 0.15880631835898384, 0.1556038620765321, 0.19254571729106829, 0.1413722155848518, 0.14760336169274524, 0.16443408356280997, 0.11616044968832284, 0.11040883488021791, 0.15002766129327938, 0.16690067073795944, 0.06958238576771691, 0.11205378294107504, 0.1344769512070343, 0.14899129659170285, 0.16062106238678098, 0.18362516158958897, 0.10340262684621848, 0.3442160482518375, 0.18058528017718345, 0.17272194352699444, 0.11407609083107673, 0.08335158519912511, 0.14318939385702834, 0.161157842958346, 0.23791500076185912, 0.06748873522155918, 0.09072152723092586, 0.05418374545115512, 0.17483002884546295, 0.12843938689911738, 0.12084075206075795, 0.16454255586722866, 0.07758998850476928, 0.2473129503778182, 0.12118372818804346, 0.10377853948739357, 0.1796749618370086, 0.15151032392168418, 0.15888871159404516, 0.1429926059790887, 0.10603806746075861, 0.18827716587111354, 0.09345973303425126, 0.1833413791609928, 0.1894392800750211, 0.18645792442839593, 0.13151670224033296, 0.23640484898351133, 0.11547941045137122, 0.13055183604592457, 0.14327903045341372, 0.19898715836461633, 0.10470764900674112, 0.1692224945873022, 0.07835144686396234, 0.1883818829082884, 0.06897725339513272, 0.18108611111529171, 0.1980508945416659, 0.16914545965846628, 0.10329724187613465, 0.09557238998240791, 0.18854411639040336, 0.09503776906058192], [0.04457283655938227, 0.04646572131605353, 0.025539199596096296, 0.057863235706463456, 0.03498934631352313, 0.05211741336097475, 0.00914246713364264, 0.028554564160003792, 0.042273436702089384, 0.029359324980759993, 0.005718984430131968, 0.0575294993177522, 0.03313555789645761, 0.052842261575278826, 0.026545349610387348, 0.07651046791579574, 0.022612605171161704, 0.054245043138507754, 0.030538464052369818, 0.03261046986153815, 0.019066033564740792, 0.03677733591757715, 0.015105449310794938, 0.02240204488771269, 0.04575538951030467, 0.04055392877489794, 0.04445144717465155, 0.09140526788542047, 0.1405252469703555, 0.011923616384592606, 0.04829447338124737, 0.028325429775577504, 0.02163214645406697, 0.07506012581870891, 0.033191115071531385, 0.005349459825083613, 0.04882370260020252, 0.020645307122322265, 0.03377124077815097, 0.047715260516270064, 0.07276709729922004, 0.04281968707800843, 0.03340748080518097, 0.02115710885846056, 0.010854176944121718, 0.04250312769727316, 0.04795079963514581, 0.039088825360522605, 0.055749769817339256, 0.05142750917002559, 0.05204156586842146, 0.046987172827357426, 0.012517630457296036, 0.03042492473468883, 0.006080523526179604, 0.05572812879108824, 0.026376171481388155, 0.03328871862322558, 0.03250354864576366, 0.06254750114749186, 0.04415313349454664, 0.03620479867095128, 0.03245708277972881, 0.054632511019008234, 0.036499230918707326, 0.04506314384343568, 0.05930485014687292, 0.10157060562050901, 0.01243369633812108, 0.0190489901433466, 0.03381919093953911, 0.08447461048490368, 0.0421760743483901, 0.043833301242557354, 0.03282396348367911, 0.04309542462578975, 0.039027152888593264, 0.04639482394850347, 0.0070955259707261575, 0.07189582334831357, 0.016607079378445633, 0.02555755290813977, 0.07561511127278209, 0.03742085216799751, 0.035008920458494686, 0.03873115470923949, 0.033270573112531565, 0.08916402643080801, 0.016410022471973207, 0.03964141367760021, 0.0888074393151328, 0.05556456315389369, 0.0671593403967563, 0.10287728277035058, 0.00939356723392848, 0.023014685939415358, 0.020703170521301217, 0.0654563786520157, 0.029343604437599424, 0.0739881009212695, 0.03191886986314785, 0.04012947225419339, 0.10645928079611622, 0.10421628787298687, 0.04784211952937767, 0.026958154412568547, 0.0727932431618683, 0.021442230863613077, 0.023601485409017187, 0.04600242078595329, 0.019867562332365196, 0.0668283573759254, 0.02599496547190938, 0.03215651297068689, 0.03549408465914894, 0.05351040970708709, 0.03589947540604044, 0.00969000420809607, 0.013109113806422101, 0.03766824338526931, 0.025059096842596773, 0.07081090734573081, 0.04294184458558448, 0.04246036885888316, 0.04172731620201375, 0.025695271397125907, 0.01352405228317366, 0.022474287397926673, 0.07018194461124949, 0.030523220339091495, 0.024245584245363716, 0.08769173902692273, 0.047243929948308505, 0.03236536074837204, 0.02393470971583156, 0.014318357170850504, 0.020620643699658103, 0.008689275582582923, 0.05108885976369493, 0.06660832543275319, 0.026817125944944564, 0.017378421289322432, 0.04707476851763204, 0.04027946401038207, 0.03508403693558648, 0.14006556069944054, 0.06813688247348182, 0.007141840160329593, 0.022468071911134757, 0.05144586619280744, 0.02959526114864275, 0.046466426356346346, 0.05051414802437648, 0.02043647604295984, 0.02880240437661996, 0.056707752592046745, 0.0016552654210499895, 0.07761596367345192, 0.0440384976536734, 0.0076393365361582255, 0.043452156460261904, 0.04604088630003389, 0.032767842276371084, 0.02929080990725197, 0.013215850412962027, 0.022956245520617813, 0.03643407777417451, 0.023718696502328385, 0.0826701674668584, 0.011950882890232606, 0.08005151423276402, 0.01844693768362049, 0.05039654359279666, 0.001957023246177414, 0.04221099610731471, 0.02077465418551583, 0.0035156036392436363, 0.01629008213058114, 0.01045911967594293, 0.02990088683873182, 0.04762815835420042, 0.07671501865843311, 0.005266280841169646, 0.01045377250193269, 0.039409180826623924, 0.01720331154501764, 0.04643556414521299, 0.023666193264944013, 0.04391507107357029, 0.04590591190208215, 0.04249877129041124, 0.03893629174854141, 0.02777138870442286, 0.06800206392654218, 0.018344215168326627, 0.007338511613852461, 0.03820476420514751, 0.0348931899497984, 0.036027221285621636, 0.034485097785363905, 0.09325584280304611, 0.02139503583748592, 0.01160578329290729, 0.058777038429980166, 0.09221627202350646, 0.1021438033785671, 0.003484672779450193, 0.02555353603383992, 0.022251062364375684, 0.05218990263529122, 0.05484576344315428, 0.02934559524874203, 0.04819502559257671, 0.035006245016120374, 0.018203242361778393, 0.06642193504376337, 0.05476105470734183, 0.07366932622971945, 0.06327893221168779, 0.044954782861168496, 0.027683694679581095, 0.02112651567585999, 0.060276447620708495, 0.013816323953506071, 0.02194937191234203, 0.028268868845771067, 0.032393618021160364, 0.043470346499816515, 0.04690741792728659, 0.01850783832196612, 0.06163750193081796, 0.028908640961162746, 0.033066627220250666, 0.044867647302453406, 0.03734411409823224, 0.026826528956007678, 0.04659047262975946, 0.02235129868495278, 0.018874941670219414, 0.027545341654331423, 0.022744097041140776, 0.09795415709959343, 0.035918730427511036, 0.029699388178414665, 0.049044806946767494, 0.06647448652074672, 0.042535281245363876, 0.044267431658227, 0.022531210124725476, 0.02809525452903472, 0.019341960360179655, 0.024293565948028117, 0.0686162876081653, 0.042217055743094534, 0.07935777684906498, 0.0544448181608459, 0.040101111080730334, 0.025565855685272254, 0.011449295889178757, 0.03051695104659302, 0.04479581482883077, 0.023012572673906107, 0.07649330946151167, 0.022555059040314518, 0.047107964783208445, 0.07659693554160185, 0.013081324086670065, 0.08235812405473553, 0.024869908556865994, 0.07930071311420761, 0.031963153815013357, 0.020081447437405586, 0.08780677191680297, 0.03566508290532511, 0.02376010834268527, 0.003826624047178484, 0.01818794298742432, 0.03786432251217775, 0.10103639287990518, 0.022914111941645388, 0.08161304489476606, 0.023097528173821047, 0.01629238835448632, 0.03511801616696175, 0.044567578443093225, 0.019264248221588787, 0.05677108005329501, 0.05629263599985279, 0.029567786841653287, 0.021297764396877028, 0.006083377547838609, 0.03932268351491075, 0.04679974714235868, 0.009068436047527939, 0.021994468515913468, 0.08465749793685973, 0.014555311936419457, 0.05048436563811265, 0.02142158988135634, 0.026569282017590012, 0.03341529562021606, 0.019693632602866273, 0.037685579954995774, 0.07224347500596195, 0.021343068801797926, 0.0424085038685007, 0.023720759672869463, 0.07089221704518422, 0.026664280630939174, 0.011582056831684895, 0.04153122965362854, 0.0898909303941764, 0.05204523207794409, 0.02981008878123248, 0.0647050431871321, 0.008566989126848057, 0.024881166937120724, 0.07102142495568842, 0.06942350679310039, 0.04454583351616748, 0.025928181457857136, 0.10138763653230853, 0.05436938256025314, 0.015241285527736181, 0.06999725374043919, 0.02509972942789318, 0.03822268336080015, 0.02892845444876002, 0.035644766612676904, 0.09067349543329328, 0.060012606700183824, 0.017821056717366446, 0.050224365331814624, 0.08221742027672008, 0.022909931794856675, 0.026289106426702347, 0.007759396085020853, 0.036217604429111816, 0.01750833609548863, 0.06618310449994169, 0.02128245760104619, 0.024992171820485964, 0.046045001508900896, 0.03443988985964097, 0.047593459239578806, 0.04018414256279357, 0.022051151900086552, 0.042484833757043816, 0.04088051457074471, 0.01828135340474546, 0.03702304988109972, 0.043461407331051305, 0.14525628997944295, 0.13824440451571718, 0.16168803325854242, 0.150743403355591, 0.14166359760565683, 0.1580286811804399, 0.13483325630659238, 0.17735849629389122, 0.14174395735608414, 0.1043342670891434, 0.15638227108865976, 0.12937468593008816, 0.14114396064542234, 0.08354754929314367, 0.1211302490264643, 0.1856620897888206, 0.10013107661507092, 0.16119070525746793, 0.12286481884075329, 0.1702979110996239, 0.13792119920253754, 0.16275654779747128, 0.2234966299147345, 0.11958605493418872, 0.13547079084673896, 0.1303413332789205, 0.1950019589276053, 0.25645453250035644, 0.277080389787443, 0.1541790275950916, 0.09863466941169463, 0.13089886429952458, 0.1630213312455453, 0.22856447438243777, 0.20498811994912103, 0.13087293365970254, 0.09410583938006312, 0.16904247924685478, 0.10170429610298015, 0.13371351873502135, 0.12789515516487882, 0.18805605039233342, 0.15042956394609064, 0.14870791492285207, 0.08832827908918262, 0.14246870909119025, 0.15723722521215677, 0.14338247099658474, 0.1942884284653701, 0.13500666653271765, 0.1204990227415692, 0.1284420141018927, 0.10515577261685394, 0.16372991900425404, 0.12129870170610957, 0.1587047183420509, 0.11256387588218786, 0.11035024974262342, 0.13354224589420483, 0.12929726508446038, 0.09721195747260936, 0.12647827650653198, 0.12013606799882837, 0.08388841772102751, 0.1510223321383819, 0.19188099046004936, 0.12024859242956154, 0.16272984532406554, 0.10350745520554483, 0.22338646551361308, 0.14062904374441132, 0.16081330832093954, 0.12605921539943665, 0.08279431393020786, 0.13207022566348314, 0.1114219035662245, 0.13963867735583335, 0.25287456053774804, 0.17231453413842246, 0.1429274899419397, 0.1333007065113634, 0.1028517603117507, 0.3006020182510838, 0.2090662659611553, 0.14567926962627098, 0.12887021846836433, 0.18109189986716956, 0.11609170454903506, 0.05365351804357488, 0.1129029705771245, 0.17057615710655227, 0.24965702381450683, 0.09852975941612385, 0.13914192822994664, 0.11945710677537136, 0.1442446536384523, 0.19374663097551093, 0.1409723612596281, 0.11094674351625144, 0.12050207296852022, 0.1281288723112084, 0.18070242076646537, 0.19900019047781825, 0.19534471241058782, 0.18083808536175638, 0.1859461097046733, 0.21814679901581258, 0.1566037576412782, 0.2022195083554834, 0.14798697782680392, 0.11926721344934776, 0.15270126314135268, 0.09044510690728202, 0.12411804651492275, 0.1082522798969876, 0.11519920517457649, 0.11930600550840609, 0.08849066100083292, 0.032190154524869286, 0.17706325510516763, 0.11349294087267481, 0.1543812479940243, 0.13784410490188748, 0.12826257763663307, 0.09337820811197162, 0.10258156660711393, 0.07461584653356113, 0.11609556371695362, 0.1613267112406902, 0.157261211425066, 0.0927787012187764, 0.20280109980376437, 0.1076339150313288, 0.11012819173629396, 0.15318302088417113, 0.15741154085844755, 0.08478986739646643, 0.0988019494980108, 0.17391568806488067, 0.11689139835652895, 0.11158594046719372, 0.17468139150878415, 0.17294130753725767, 0.16731472976971418, 0.1522481522988528, 0.32761269074399024, 0.14003767078975216, 0.08203506717109121, 0.09963021599105559, 0.11709888800396584, 0.10543700205744244, 0.15849247894948348, 0.17370741174090654, 0.2146975786308758, 0.12345781709882431, 0.12525699828984216, 0.11037345670047216, 0.29192369955126196, 0.26491376920603216, 0.08056245322222821, 0.11238530030823313, 0.12424194806953892, 0.10896638181293383, 0.206866109801922, 0.07150209174142219, 0.1843017479404807, 0.11475588325993158, 0.1170088432263583, 0.21795343986013904, 0.10600708279525861, 0.13876258686650544, 0.13876096898457035, 0.0827816009405069, 0.17468707635998726, 0.09585128165781498, 0.17158406786620617], [0.02301135926245479, 0.04752724853460677, 0.04803355652256869, 0.03865399361529853, 0.019787117234955076, 0.06220035043952521, 0.05885322731046472, 0.016683166213624645, 0.0631049282674212, 0.01006040176434908, 0.06622711385716684, 0.024532363095204346, 0.025862056099867914, 0.020694420600193553, 0.0389881047885865, 0.05104810101329349, 0.030708093036082573, 0.07825869324733503, 0.024261466205643956, 0.019018541679542977, 0.017790552592487074, 0.022339576462400146, 0.024026706341828685, 0.04076533696206752, 0.0743812981818337, 0.061736404240946285, 0.08293756327475421, 0.02598756254883483, 0.02806669112032978, 0.025739102638908662, 0.027317077438056003, 0.013355937280721264, 0.025420387319172733, 0.04276996689441148, 0.003807481275543978, 0.03351287690747995, 0.01569271262269467, 0.026378639122413006, 0.027728538952942472, 0.020467011709115468, 0.016534621645405423, 0.016705345296941232, 0.011857677491207141, 0.02945245709270239, 0.049302770057693124, 0.03149373427731916, 0.024710374636924826, 0.018790802532748785, 0.012169506608188385, 0.06381682600476779, 0.03636839770479128, 0.031044265524542425, 0.03877329014358111, 0.028705322183668613, 0.04170325948507525, 0.01884760094981175, 0.03390015925106127, 0.047072011439013295, 0.07943150179926306, 0.021895226673223078, 0.10163933591684327, 0.04725511411379557, 0.009613709571567597, 0.04041222309751902, 0.04570674544083886, 0.035059252913924865, 0.03829584427876398, 0.020079206151422113, 0.004058430859004147, 0.007800138137099566, 0.03634750253695529, 0.09570021749823354, 0.0719852521433495, 0.03287260013166815, 0.03745778514712583, 0.11393411798053421, 0.07115507833077572, 0.026452221209183335, 0.019707707433553878, 0.013562096628447762, 0.02857768577086972, 0.05369995051296428, 0.058589338150341064, 0.015091152763488935, 0.10775881106383167, 0.04799870897841174, 0.016178086480067577, 0.07907671068096533, 0.04754973189847078, 0.05206387482758146, 0.03390608158952091, 0.03201605039066635, 0.08476805567624979, 0.08799084680504166, 0.030801922766841017, 0.0313355937396409, 0.06450714950915426, 0.034117552859243006, 0.012926897070428822, 0.07591985195176676, 0.017322793610219378, 0.04613225952198263, 0.0846659138915129, 0.021482646370714065, 0.012942689045303268, 0.0984674709616229, 0.025656518300820608, 0.04741430107969791, 0.017966181840165518, 0.07449191529303789, 0.03501576306007337, 0.015097099221748067, 0.03478138540231157, 0.031176421616692096, 0.013053544571448583, 0.01809812085411977, 0.02411015157122165, 0.019818812506855465, 0.02559949723945465, 0.09012461785459891, 0.027534899636521004, 0.06749367792508565, 0.049543808490852825, 0.030544349283445626, 0.03142039895465132, 0.02980367476993706, 0.0612022694258485, 0.03386613920156378, 0.024086618068395182, 0.02639406837261049, 0.03564532322343439, 0.022813480427430477, 0.02112308138748631, 0.03496583507512696, 0.015972016190062277, 0.026225560031889472, 0.03426339972065762, 0.04931682262395043, 0.1627658394863829, 0.08586641197325662, 0.062126566117512994, 0.03382828595931642, 0.03225632070098072, 0.030495584614982363, 0.06483288554591127, 0.014077037649258273, 0.01830744917242555, 0.010127794339496177, 0.04720682627521455, 0.05348211161617655, 0.056809174493537284, 0.0454628423176473, 0.010996776909451, 0.023452250643458683, 0.021229746562312357, 0.016498052318638656, 0.029660126710950863, 0.04632373733329587, 0.01989324806345394, 0.06882350266096182, 0.05200914143642876, 0.04509564991167281, 0.01724358975479845, 0.029764626669930294, 0.04258861568814609, 0.01272014771529939, 0.05793215525045525, 0.013200024113757536, 0.031096455204533413, 0.08954273696872406, 0.03190927760442719, 0.07798728242050856, 0.054479780737892725, 0.01606497204193147, 0.017728436687320936, 0.024892790825106204, 0.019818042528640945, 0.0683097360888496, 0.04617362683347892, 0.12132099582231604, 0.012315926778683206, 0.06450296379625797, 0.052043651303392835, 0.020345442353573162, 0.03955895735998638, 0.022728359799657483, 0.08827885205391794, 0.06240616654395126, 0.06005551025737077, 0.0819427811075002, 0.010468253658473259, 0.038145908183651045, 0.024913131237553898, 0.0440907745360164, 0.0621194377890788, 0.040090279435389675, 0.02240222671389347, 0.025327917574031744, 0.04458128591068089, 0.02874974157748511, 0.06576687839697115, 0.019587883980420884, 0.03914478329534177, 0.016178646801563445, 0.00955928417170071, 0.028402843199728522, 0.02347304005525075, 0.04891788114036899, 0.07211946212919429, 0.04692289170634467, 0.08612766279838979, 0.053121097589610144, 0.02746645321167307, 0.027295564432279207, 0.01879387131339172, 0.010758665321191074, 0.03615932357206475, 0.018242884179926477, 0.04725826081994455, 0.0883138294739183, 0.05821391903737094, 0.035851376815116964, 0.027681525752996095, 0.053048697373014875, 0.009554501029924722, 0.037413653335534036, 0.050740443693939596, 0.06563191142049618, 0.02254302511573769, 0.016699654879630543, 0.03237472294131294, 0.04946625776938163, 0.02517437835194869, 0.05020346645324025, 0.05086304649012163, 0.0240537260833662, 0.013969660012662644, 0.04409112334542442, 0.045876411531935446, 0.03446166818321217, 0.05133148268214427, 0.026499523846723605, 0.013012267245358089, 0.031652731995563954, 0.02967375810840167, 0.08948200702434406, 0.0379374129261123, 0.030224311085476074, 0.03784975786402356, 0.0325999462074833, 0.04745584279589821, 0.03538465498422738, 0.04374024705612101, 0.017581927459104918, 0.0050493719481892185, 0.07388887577690184, 0.03680603105749469, 0.026212331249553245, 0.016485827291035093, 0.03361621726071462, 0.031646824500057846, 0.04772867112478707, 0.03170186588249635, 0.029327863485377748, 0.04155716400418896, 0.07253741001477465, 0.053959713332005776, 0.048040554975159466, 0.03456913858826738, 0.025901909430103842, 0.0899899922660552, 0.03926892975869123, 0.0044912550947628915, 0.014508299664157676, 0.029500190175895113, 0.04826224561838899, 0.08027084113564342, 0.06327900642645545, 0.05101687514979858, 0.014195622643455863, 0.0031653834548706072, 0.05024631434935145, 0.031449587622773834, 0.019719871233974118, 0.04041372594656423, 0.07811902105459012, 0.00797651973698521, 0.0427898156340234, 0.03156715494696982, 0.009906789255182957, 0.029209819331299514, 0.11479896493256092, 0.045910665357951075, 0.05277029922581278, 0.025387658606632613, 0.027365671412553638, 0.032343745697289705, 0.019863105735566933, 0.018071028753183782, 0.029750607500318438, 0.07454347229213454, 0.024298117168655153, 0.05660022652591579, 0.013088258529023733, 0.07247023822856136, 0.07960518662002869, 0.03410683624679223, 0.06967246765270829, 0.0503096900501987, 0.011425844950281316, 0.038638527257717215, 0.03520162652421277, 0.05029330714023672, 0.027573220431804657, 0.03516724653309211, 0.05308401618094649, 0.03370832520886324, 0.050263669472769834, 0.02505505584849743, 0.019666267762659118, 0.0593657619174337, 0.020388017510413192, 0.026385789715277497, 0.03260641773522366, 0.010667088008631254, 0.04800570372026414, 0.06427064188756049, 0.035155316509190015, 0.006273250000958797, 0.007174479351306218, 0.04315951278840657, 0.021212710562394932, 0.03063443858991377, 0.048124005770660006, 0.03098768418567488, 0.07905118822236545, 0.008837191180646187, 0.034118918410968035, 0.023010056793282274, 0.058876771945506334, 0.042774044995894656, 0.0629414182913024, 0.023778144386596978, 0.05498970298503991, 0.012637404743145453, 0.04016592283733189, 0.026139070141653065, 0.0939242284221109, 0.04486987003474496, 0.007802956442901632, 0.0064887919506873, 0.0753209758840967, 0.2024253801209852, 0.14143354666884989, 0.16048413614043966, 0.19304022513097152, 0.09906020204653032, 0.17200502887135372, 0.14952504920074716, 0.13030026282649487, 0.1227888154971879, 0.10211262575467117, 0.14759605895960703, 0.1410591628518887, 0.1238732342608273, 0.1814915018621832, 0.13416241417871788, 0.15140489442273974, 0.10238845978165045, 0.1414891632157378, 0.11499869913677685, 0.08681389706907794, 0.1254497785703279, 0.13403097982518375, 0.1753424818161875, 0.14970936899771914, 0.16502355661941692, 0.19510057551087812, 0.15185086580459028, 0.15703795856097713, 0.09951991058187559, 0.16647859651129693, 0.1511073822621256, 0.1478343625785783, 0.20202763349516317, 0.2562581899110228, 0.19834291480947286, 0.18332652136450633, 0.08919855856220238, 0.15668649226427078, 0.08392796677071601, 0.11352904635714367, 0.09368481158162467, 0.19756247231271118, 0.0846942194039002, 0.16724477492971346, 0.18088423210429028, 0.1770101915462874, 0.11496189603349194, 0.13318487210199237, 0.09820351129746996, 0.138905479980167, 0.16577743022935465, 0.08082915883278474, 0.10122753301402554, 0.17897593294037506, 0.07148885924834758, 0.2141661266796291, 0.12304496776778251, 0.17699802032439038, 0.1389427061076276, 0.11912220521480776, 0.1847358449595049, 0.16561378666665405, 0.08148175897076726, 0.09067722843610682, 0.25274809857364744, 0.145960959198419, 0.1347314633312635, 0.10186954270466231, 0.1330671229516156, 0.20337482448667288, 0.1270220332662575, 0.18230084358947352, 0.18510464782593772, 0.1239239377900958, 0.13821235857903957, 0.16937663865974173, 0.1280555035918951, 0.15212991333100945, 0.07900052180048078, 0.13066725485259667, 0.1233503021649085, 0.1302493514958769, 0.07803195228916593, 0.1354604007792659, 0.20517954952083528, 0.14310082595329732, 0.10936513775959611, 0.19040828745346516, 0.09983749783714302, 0.1177672365156468, 0.1652735416428186, 0.08985302891233005, 0.17371046938933432, 0.18467249523382634, 0.1379832427483052, 0.06536178450915031, 0.07792442993377335, 0.11429725826019421, 0.13330226502148435, 0.15472165629034862, 0.17843698529759422, 0.14246628968976438, 0.16463872336316854, 0.07490495758247562, 0.07212127296952531, 0.21568252734141424, 0.06925038600456901, 0.15601915307343006, 0.10356417013099417, 0.1407278681290336, 0.06640029401751235, 0.10803623328683898, 0.10849326266907156, 0.12998156977118924, 0.08340095286257565, 0.2754346327856183, 0.11143692463519983, 0.16815167939057574, 0.23636557452846318, 0.11016472024493851, 0.10521530770347454, 0.19137472700094804, 0.11693111067870632, 0.08379282910027541, 0.2044198871590197, 0.12415807796060108, 0.17276341473916546, 0.1274298582575284, 0.11323793150950223, 0.1516820420511067, 0.12456214026315138, 0.11656015558401123, 0.16438106453279033, 0.10299947738531046, 0.0849174871109426, 0.13065692415693775, 0.11090420361142606, 0.08968052410637029, 0.24953730055131018, 0.24985437572468072, 0.1346934208413586, 0.22476834448752925, 0.1615076616872102, 0.11307187596685253, 0.149198682338465, 0.08900088752852753, 0.13542229891754687, 0.1088397491548676, 0.11859425620059483, 0.1261971064377576, 0.15424218436237425, 0.09582895785570145, 0.08673662465298548, 0.15291666408302262, 0.10940203734207898, 0.09610803506802768, 0.15339815465267748, 0.1954792340984568, 0.07970862716319971, 0.1482310553546995, 0.1326565965428017, 0.11401682291761972, 0.09514488323475234, 0.11153194180224091, 0.14494292554445565, 0.09792035969439894, 0.13230849959654734, 0.11240082603762858, 0.10339476008084603, 0.22989517485257238, 0.14053050137590617, 0.2206928702071309, 0.13498791988240555, 0.1295312197180465, 0.07389702455839142, 0.14477729302598163], [0.01652127226407174, 0.014241601475077914, 0.04653313058952335, 0.043333717112545855, 0.01984468377486337, 0.02656964752532076, 0.06827605000580661, 0.032850973948370665, 0.03333718457724899, 0.02547419302572962, 0.10032455451437272, 0.043012326350435615, 0.04659804624679964, 0.07693597828620113, 0.000734562173647646, 0.030025382111489307, 0.020987491006962955, 0.009398265956406249, 0.033731955190887675, 0.01490652961365413, 0.03314806679554749, 0.06308799987891689, 0.0622135866433382, 0.061757655639667064, 0.0024817313942548935, 0.034530491248006, 0.029907766547694337, 0.08632566779851913, 0.052786555970669724, 0.05290300636261236, 0.08022392998100258, 0.03222362538508605, 0.022359794420481194, 0.030026651184016373, 0.04977681688615121, 0.005915062165513518, 0.05661712151777465, 0.0259712798288092, 0.020143292458669748, 0.06439236894948408, 0.024269718887808267, 0.023747011291561648, 0.02914395558036631, 0.03550010718754493, 0.02198976515501272, 0.03560998215107247, 0.0018795736423271592, 0.033696220780257136, 0.009446091808058554, 0.044723845057887957, 0.029239267751108855, 0.02936334742116742, 0.03672747472592164, 0.0077472086286434205, 0.01169381963336491, 0.035726751666516066, 0.05441813053039368, 0.027772605826612562, 0.030502840963890776, 0.04127496235014405, 0.022093491425039247, 0.020428208517841995, 0.05572547932388261, 0.03224558553483803, 0.0021107412794663105, 0.02331118877918925, 0.062133601677487604, 0.0969501277722884, 0.03682685943203978, 0.049599202393437736, 0.055981442346819676, 0.025451579786022194, 0.01583340341312578, 0.036717221955768764, 0.055372343194903806, 0.05427818003227003, 0.036076128817512654, 0.05279348020849284, 0.04725489146949258, 0.032088777152239345, 0.05751820011937525, 0.02705544811760774, 0.042182137694908306, 0.05617332462861668, 0.03377633562195115, 0.05563395767239854, 0.06670308284810744, 0.024724764880375005, 0.0197062639563228, 0.0332550956227351, 0.056893167056841776, 0.02321759096957976, 0.0048037781198218, 0.06169165644678287, 0.05723289999878034, 0.06291689031058922, 0.02058598354778951, 0.005451267179523711, 0.04764821860590018, 0.04119639488635585, 0.03762426000321284, 0.007237748832267243, 0.06324440008029342, 0.08776727481745183, 0.014879602640576195, 0.011715694436134072, 0.01583002849656623, 0.015153733438637573, 0.04514273918175604, 0.02395916533714626, 0.03756765268917661, 0.040434264883515425, 0.1256405995809473, 0.04523588242591359, 0.030518012317770626, 0.1113798089500051, 0.035957678337581456, 0.008248900921898894, 0.010867664550460177, 0.014445528813666897, 0.08391589944949374, 0.030472774706140626, 0.07124444775399752, 0.06332730539725162, 0.005914635430599446, 0.006041665601514978, 0.007230432183860103, 0.010497809689695714, 0.01980556517082732, 0.024243680636573117, 0.02161333857657155, 0.0771505999728106, 0.09744286187924445, 0.09204829431837425, 0.0452020182274282, 0.03386822463653516, 0.06841167007223703, 0.03554843584424816, 0.015077683710842393, 0.04422460973728448, 0.05463308247271925, 0.0159185184747912, 0.024482060325681232, 0.021036879079474602, 0.013399556082731578, 0.021908882190473378, 0.0774008892767597, 0.014464882169704651, 0.03810568006883841, 0.04604884954460431, 0.030468366348941345, 0.03071677616389934, 0.04819496622076258, 0.01553333640913479, 0.04894645382591989, 0.016562405799049884, 0.03640552364231553, 0.07113656916772015, 0.033482634389656596, 0.04825886513572186, 0.08601409193943255, 0.0284392770845443, 0.0918083282886073, 0.07046762693789788, 0.07040928670903668, 0.03321707910799887, 0.02069798847514903, 0.033639542962191626, 0.058267732165404595, 0.03239860154280905, 0.03044204793695826, 0.049670901280478574, 0.04660162710933946, 0.07270466041518375, 0.06853852537460625, 0.010873222308873665, 0.05281667232338805, 0.034435373891028576, 0.05752463825047016, 0.07261597376782447, 0.0541547571629053, 0.009485568498348584, 0.02002153756620828, 0.009557432513247477, 0.008429543377133086, 0.054269237152766436, 0.11996144807199016, 0.04472113992960658, 0.05961587310594041, 0.012480907134886365, 0.0059966343997075455, 0.014492127338598948, 0.030379338313650806, 0.09655923859099858, 0.00945985864746035, 0.033501017387607135, 0.03121004832792096, 0.038814479339635, 0.03643063049821649, 0.051626853746711276, 0.0878342759096995, 0.018020835450442974, 0.042975319156539626, 0.033057272448786534, 0.04341921994637232, 0.026342413038946688, 0.08517418114934117, 0.04342664513387717, 0.05101921291498002, 0.033095786202466115, 0.0353560785879381, 0.056044168668449856, 0.03396697109565139, 0.027657860518957023, 0.04256210246239789, 0.0311625879839994, 0.018380623077973723, 0.054753510776208714, 0.06035740108927712, 0.026358315408288036, 0.043388283520471305, 0.06040110616595484, 0.01733300741761923, 0.00647076332825236, 0.01142419738243916, 0.03218313751858659, 0.0436096698831534, 0.02971866175357718, 0.02231807644420769, 0.05572413974732626, 0.05082269221020397, 0.090794487769017, 0.050532857567304745, 0.020996346684114542, 0.007698618828726467, 0.02903346648963634, 0.10323233364033513, 0.048722269566496834, 0.044318406071397476, 0.022500544582726434, 0.0193890032460331, 0.019365838961675763, 0.04624331078957766, 0.03983619775681291, 0.10312180558685213, 0.06884354806970805, 0.014482767001027241, 0.031031242688186467, 0.027564867559704, 0.06396166354534216, 0.0162878556875512, 0.07753250174573623, 0.12615939049283043, 0.025580798828741536, 0.0682865439739544, 0.013503617246897193, 0.07094389278790914, 0.04643377928005066, 0.01563078967592446, 0.08563443887396716, 0.08115865755826235, 0.0669601999106817, 0.0036323358153822483, 0.11032777008949779, 0.014152991825540084, 0.03789122907619458, 0.055100286699598655, 0.11007978144334629, 0.05213767028180882, 0.05075540168036241, 0.012673163273575483, 0.014770332527405117, 0.026126503726118244, 0.03419610919081606, 0.020945262804161757, 0.012391812306304928, 0.06771178770577535, 0.021180204494157806, 0.007775887534080539, 0.02527821037801914, 0.06711801019264385, 0.033006676530931145, 0.03392007478396408, 0.06347962378640659, 0.008199512849387247, 0.037723429486504756, 0.015226961149892304, 0.04366276312794071, 0.07922023462015204, 0.05895585520192981, 0.07263320643687621, 0.023259527879417874, 0.08197430011932738, 0.032274636905640364, 0.060978144538239576, 0.035353959756321274, 0.025368064052599948, 0.031343783339252695, 0.031806508704903536, 0.0044838674784841714, 0.04609460294886958, 0.06705949184834026, 0.043712038022931665, 0.027766091625380795, 0.042692579445429146, 0.02368146480876021, 0.019307290931465104, 0.09264221283956431, 0.04382779821753502, 0.052692488752654754, 0.013458678349707043, 0.05829144378367346, 0.014801557463215431, 0.02522903752833372, 0.051644101258716546, 0.04410326488141436, 0.054138559789862484, 0.06006319148582406, 0.03204223707143683, 0.07267433626111597, 0.06788913873606361, 0.0227432064639288, 0.036972535599488765, 0.012336729178059613, 0.04892622659099288, 0.03274901398981456, 0.03212766197975725, 0.004398970422698767, 0.07282249120180495, 0.017024763801600784, 0.06680053425952792, 0.0338728853239445, 0.08754422975471243, 0.12578163732541725, 0.04698940669186413, 0.036769643556908704, 0.004706213530880632, 0.05305667917127721, 0.0532417262729723, 0.07308590167667717, 0.043113874417031184, 0.06716253905324265, 0.0399035476584686, 0.02184966808272293, 0.0737862144887913, 0.059998594952048734, 0.057894851197488606, 0.01785359618224902, 0.03369901496625971, 0.05318923416780308, 0.04032204844406806, 0.015432225281983847, 0.0982516395743005, 0.12192649926873855, 0.11802461332990788, 0.09479201427893713, 0.13127223879564553, 0.15401152486447245, 0.24276889889733866, 0.14655430626589805, 0.13996477704495192, 0.10707849913160317, 0.26335145928896964, 0.1286210201214999, 0.1229261202388443, 0.19157403818098828, 0.09774144273251295, 0.07112467254046351, 0.0693572181626223, 0.16381669091060758, 0.13127173413522542, 0.10534478278714232, 0.06464492180384696, 0.21681125974282622, 0.14426718524191529, 0.1681839331286028, 0.11691842737491243, 0.18574439396616071, 0.1340463274391368, 0.10781145902001299, 0.12155620468547568, 0.22378768539056182, 0.16231557849096134, 0.09171884012175724, 0.061391650669975206, 0.13361806370085105, 0.11570443704840727, 0.18277673836564645, 0.10687333240639418, 0.19884897046722472, 0.11096175716375001, 0.11620879318797961, 0.18291675194632262, 0.06537649387610145, 0.2230336336651817, 0.14986110851168633, 0.14269403996877372, 0.23322780383750796, 0.13849777373252437, 0.14318540110252798, 0.09010676178149879, 0.1419216868816875, 0.1178170791536104, 0.1249342382652685, 0.11825448615127243, 0.10403551554190926, 0.11517288119648583, 0.13356655865209177, 0.19278344203485176, 0.12840980489272624, 0.09196655417326838, 0.2087662898702547, 0.12021324393572286, 0.15940612211124972, 0.1044530478247907, 0.11797085215221159, 0.08794670386123471, 0.09843837135122158, 0.19645045307697728, 0.21924342610873282, 0.13463427167152986, 0.2406801242614165, 0.08468138024909422, 0.08853711202391423, 0.13983421842567623, 0.1688995267613791, 0.16241288889432326, 0.17129273037426174, 0.11669662169879302, 0.16769491718150675, 0.1481646331376396, 0.08822750285617076, 0.15908992267213762, 0.11745001291274093, 0.12453343399101868, 0.21141721168532968, 0.17683498532278463, 0.16493375675054267, 0.1504530306556262, 0.12199236487504095, 0.1304743706714362, 0.11506667986395769, 0.1630633368040435, 0.12477152980864048, 0.08335686929058284, 0.2038577399798669, 0.1350062360870652, 0.11130930492072366, 0.09038218020577915, 0.2618823334341869, 0.1494183877366595, 0.12540749099571258, 0.15672109118895605, 0.14852672698907554, 0.09999172354582697, 0.10941509914118797, 0.12123251697630621, 0.13318166602402925, 0.10950732583296485, 0.07821111415978521, 0.20513635652605444, 0.08717008342500776, 0.11933536487049423, 0.1155523635679856, 0.20642021263483912, 0.13770947931334376, 0.19203786563593894, 0.1764886250020936, 0.16512321220943704, 0.07867667081882246, 0.16877846763236448, 0.11298793906462379, 0.15121748729143292, 0.15265303838532418, 0.12786061561200768, 0.13664516533026472, 0.1441964288824238, 0.1395137739018537, 0.09757070423802361, 0.11289376794593409, 0.07344821075093932, 0.13165707205189392, 0.21442093566292897, 0.18311413354240358, 0.21383138839155436, 0.20362553681479767, 0.14319328271085396, 0.12102282315026969, 0.14079230139032006, 0.1426440934301354, 0.10541625902988017, 0.1501210531569086, 0.18945995630929247, 0.1352675017551519, 0.1251640368718654, 0.2004787712940015, 0.1633757067611441, 0.13252121396362782, 0.09488214069278911, 0.08029086427995935, 0.11945647594984621, 0.08211602063965984, 0.1420338699244894, 0.11642147786915302, 0.13370836823014542, 0.21869864518521354, 0.13437196699669585, 0.09910737295285799, 0.14384604612132534, 0.1491208458901383, 0.16579068498685956, 0.19274485035566613, 0.179443723463919, 0.13624897721456364, 0.21925939712673426, 0.15439009439432994, 0.13174439314752817, 0.10323905749828555, 0.1601518172537908, 0.12320076682954095, 0.19465307530481368, 0.13269376329844818, 0.19194594322470948, 0.07697631401242688, 0.12246340600540861, 0.1663709999411367, 0.1396792134619318, 0.14097288076300174], [0.09966061435989104, 0.029363013454712927, 0.04668389789003413, 0.060481002074084245, 0.010743189686763799, 0.06006777424772736, 0.0590007180289831, 0.04848728334764019, 0.036242458954802714, 0.027630903859972022, 0.04956863333063666, 0.08316403705975972, 0.031179379075183533, 0.023861866065999493, 0.020002943056169897, 0.015190578287729295, 0.03576371804228984, 0.036375314521137625, 0.10017559805419296, 0.024096984016068745, 0.04725544808025006, 0.03487302950816229, 0.06545525800902396, 0.03269332322815899, 0.06434720926336013, 0.00839162612464861, 0.07519083286751993, 0.04757333219458815, 0.04045059213240165, 0.09146547090495005, 0.02387269400060177, 0.01652317587286234, 0.056224406653200276, 0.07576167801744305, 0.041740916058188304, 0.02552137135353405, 0.02504369356756797, 0.007970994447532576, 0.03760719802812673, 0.040370217539020814, 0.04126856132643297, 0.07976395427249372, 0.03963781055063009, 0.04445675353053957, 0.07056709699099883, 0.033610428508836776, 0.023561470661661588, 0.02217961024143733, 0.02936975401098607, 0.003020698286491097, 0.05709197728720028, 0.05142839974723756, 0.006784842080378439, 0.049917079086299054, 0.060360599745763466, 0.0436010164412437, 0.03135906044917647, 0.005013341142330319, 0.10565135657088831, 0.004021941776954918, 0.047555301716784015, 0.019571384182199836, 0.02750489646132337, 0.07016766568995081, 0.057204204858862795, 0.03530216155922972, 0.06668245856417343, 0.054069948237156495, 0.03671868398669176, 0.03317563016025815, 0.044837085661129095, 0.05062201918917708, 0.059909511255682446, 0.02083094608678948, 0.0868253706721589, 0.040740679105510935, 0.013999273560330039, 0.0100637173090945, 0.02545178387663327, 0.031189127184916288, 0.002525200375202985, 0.024706585973035544, 0.029088313058309723, 0.00231902270570572, 0.05248450186627451, 0.03187988113495521, 0.05767883798398543, 0.0053677746382163605, 0.02636790210090112, 0.0323308657243615, 0.022298834410321433, 0.017083408311009407, 0.04928278402076103, 0.04791755884070881, 0.015857875732763205, 0.040577332401880994, 0.03876238799421117, 0.015250956639647484, 0.053653480936191045, 0.027073723504145164, 0.0488511064031627, 0.05901409895159304, 0.017556011662236415, 0.02317743892490398, 0.027926681250391994, 0.0410809426830383, 0.025112692892435007, 0.038187657701200806, 0.05655447312165052, 0.068727810139535, 0.03720464228536002, 0.03636549590737559, 0.020897179056191817, 0.045380348892649636, 0.1200120328576304, 0.009711501443234738, 0.047558767546433955, 0.048325899624614976, 0.03140099179290701, 0.026611259745550342, 0.033445026056142524, 0.06361007850500755, 0.06339485567878, 0.029174763985793106, 0.029418392514344305, 0.019867920418619178, 0.02836121613654541, 0.03294884096249007, 0.11571267488761805, 0.04608116265444551, 0.01798141071049031, 0.013316196200321428, 0.10441658610943705, 0.010024051371146925, 0.06638142862357199, 0.016315446882799733, 0.022408186159736942, 0.030599496421928052, 0.05969598423689604, 0.04092464267159812, 0.006664729189651553, 0.015104152407729998, 0.0400267330405768, 0.06205727921042126, 0.011008612309524324, 0.04224383243126795, 0.04165637059486471, 0.05752733595727477, 0.01342107465461595, 0.044431004716898315, 0.07021578654530458, 0.045472475394490175, 0.031295261724153534, 0.03742956127098296, 0.022055851550248917, 0.002529015014260949, 0.015164378619374475, 0.06855552797787823, 0.10431761329527944, 0.03546896296029445, 0.013327752367331414, 0.017796476786315907, 0.025525584896968212, 0.02768125672446331, 0.012253797885932727, 0.003581507512535609, 0.06216765512363054, 0.007555978509117267, 0.051609880829346366, 0.03679968198412098, 0.008166665393218864, 0.02721669639868196, 0.020436826707737055, 0.039055981615092605, 0.022350395120156463, 0.039341085066553205, 0.049976881346083246, 0.02431794364383677, 0.02835526040144032, 0.026800759733305313, 0.03620405652327463, 0.06633183089434169, 0.042107473927899264, 0.14551512140315026, 0.047649435728089884, 0.02042735504801385, 0.04623266097041778, 0.07868346147006378, 0.022305116690404247, 0.04195369721855968, 0.055800862974138, 0.017770054473658092, 0.0071378019492840394, 0.009267985642509302, 0.026039297663373873, 0.03629799386544619, 0.032544927089475095, 0.08725822830456309, 0.07862872065743431, 0.015472830964426976, 0.06494014072814025, 0.0338457078760257, 0.027648509458231274, 0.04514996770012658, 0.018361332804488484, 0.006864682327432092, 0.02172851989598712, 0.0324277382605942, 0.03728329509613104, 0.02095394036587095, 0.042904789152089506, 0.03890284686349332, 0.04227091711072717, 0.030443626856140327, 0.047224763984559104, 0.03175178273522761, 0.035497728604241274, 0.03182774526067078, 0.025904345529852435, 0.05849297027452849, 0.04909786679490935, 0.05892528984986711, 0.02851914701750502, 0.07151429264922626, 0.023172370056272484, 0.02436562477669213, 0.02465965626470279, 0.04497429392358754, 0.0071567461964150425, 0.06289637734880671, 0.02074648225971032, 0.030652819732495118, 0.10053651189082302, 0.0502321170642972, 0.041654262895463035, 0.0336641154717654, 0.022539357050845865, 0.03491321680485271, 0.03981393703725189, 0.010717738659877796, 0.06786591693526134, 0.013681687232747208, 0.05297076073475182, 0.04356313722382765, 0.03147282426652964, 0.06893900310387835, 0.06913443285156973, 0.002823335707944352, 0.056163160916185006, 0.07148609103751369, 0.09578701166901737, 0.04009899595985189, 0.039714415033813566, 0.03020826214196859, 0.041704617615323514, 0.014554391673300415, 0.023565138726553414, 0.007199907186077326, 0.045084870216669515, 0.009476527284277836, 0.022705236333422363, 0.034661984973354265, 0.0310789961804403, 0.04447075414645951, 0.033535638576722704, 0.025441026446060278, 0.027823665586765856, 0.04545434843748808, 0.028162259332020767, 0.008142360056808684, 0.010911393746937392, 0.04636310084606521, 0.049205159084522165, 0.0546256795496447, 0.041671087383292615, 0.011238474926358322, 0.011830821949843084, 0.00588247909945494, 0.011200140215805732, 0.015663238227716647, 0.04910505078441929, 0.04799467169505078, 0.08563728129956871, 0.06803756084991619, 0.02586710270406911, 0.05032921595557127, 0.07516508034314029, 0.013594566516985651, 0.038405648738262244, 0.07508449794840999, 0.056211381961475126, 0.04420677592861466, 0.04021926099085249, 0.034789916389854625, 0.012415280871209688, 0.04218761474476196, 0.008058065996010555, 0.011460289879323682, 0.012700593979388941, 0.04331344534875825, 0.023645884393772576, 0.02405737373919692, 0.022630060484516434, 0.05495012424944434, 0.04478956965613179, 0.026550826660241, 0.022726022034476046, 0.017662613754509948, 0.06689310976071283, 0.038954259143793024, 0.0609034436638467, 0.055217349363374524, 0.009219153253070544, 0.06951677991310135, 0.03882341850840021, 0.06385855696862563, 0.03865151484205853, 0.003912909151040367, 0.02826749587256927, 0.05758493403845932, 0.027357368635421153, 0.01289285846723942, 0.04517672954534646, 0.047643123762100004, 0.049236752311117016, 0.05123042814375367, 0.06830532031017356, 0.033769778747227974, 0.019738404516829178, 0.02570024378655944, 0.018598500937514473, 0.013466433792928001, 0.018957728243549354, 0.04433831047208514, 0.054147832925082184, 0.0409825227688998, 0.036095706673222594, 0.046423964377027005, 0.027331462115398608, 0.015284745695680613, 0.016237070522038266, 0.014469300731434487, 0.026578590404824354, 0.017760295231710188, 0.08017885193112306, 0.030206905867089517, 0.023332197124545928, 0.059780960145872086, 0.016098214691737667, 0.05150980221515056, 0.023696389398537576, 0.060385810502339154, 0.19486362260067835, 0.15206552459858358, 0.13330127054359764, 0.17282024840824306, 0.17359004850732163, 0.1511788956122473, 0.14994445169577375, 0.25162531819660217, 0.14457216340815648, 0.1072546849900391, 0.2285206876695156, 0.1673768475302495, 0.12060057080816478, 0.11752108839573339, 0.18051829392788932, 0.09229523653630167, 0.1574639364844188, 0.10769050379167311, 0.14336008782265708, 0.13440298876957968, 0.17935386422323063, 0.3124829416628927, 0.1299860968720168, 0.06810755279730074, 0.10224134384770878, 0.20991638128180057, 0.13136134104570374, 0.11819411985925399, 0.2618587628239766, 0.23528088117018342, 0.09066388462088071, 0.0914265526807867, 0.11511252974742092, 0.14985756104579195, 0.12084889342077076, 0.09590202971594408, 0.10433161762193777, 0.13492831058101729, 0.1587029965594411, 0.17375899100443348, 0.1922291170922108, 0.12352280697086826, 0.059613873017951846, 0.14080812397878617, 0.09856317832600325, 0.12320530135184526, 0.14472728711552918, 0.14705135225085542, 0.08739840515772812, 0.11496255654492415, 0.09197635794407688, 0.11125748074846342, 0.11401582843973301, 0.1639337424421683, 0.16915383108425885, 0.08254034357378259, 0.15541491127805784, 0.09734154387842864, 0.1705153306829743, 0.10301350397639908, 0.11752862119465135, 0.11085965990787372, 0.16357624990632758, 0.14072482532355934, 0.1813239249167964, 0.10920375032583252, 0.3298377385362983, 0.1158434858371038, 0.10929364667390473, 0.14476694748736918, 0.19439675234025344, 0.07477575709344819, 0.16059061948908493, 0.10140868384041823, 0.19667110842419788, 0.15894499607384205, 0.11890603243955411, 0.1491877727676183, 0.16463946551084518, 0.15854667057283223, 0.12130860195611604, 0.09635844311560504, 0.1516940351575613, 0.13371476554311812, 0.1331455828039907, 0.10266967437928542, 0.15521522902417928, 0.0860331799776759, 0.12257858732482418, 0.20930664759362116, 0.18198627687525004, 0.11414998647524044, 0.1460563697037287, 0.10716792050516233, 0.11977887974353507, 0.11855292599648237, 0.11260533967288211, 0.12292180836084299, 0.11077453556936234, 0.11712513034581207, 0.18374491453869268, 0.18284676742041484, 0.08502767377649434, 0.08164748796843924, 0.12890110665466636, 0.12227878934936598, 0.12154669777373783, 0.19767259218497202, 0.1315706266905181, 0.13650673994561657, 0.15929040644550696, 0.1866102873464115, 0.10353817269788124, 0.21430587308714166, 0.19554684375179932, 0.14555755740730092, 0.19090530375251547, 0.13867064961232245, 0.09808508679270744, 0.07939944101963192, 0.14856144465738907, 0.09907774641760625, 0.14685492060380057, 0.09525993838906288, 0.21059114194940776, 0.14127025933703408, 0.12457802222343162, 0.17448588012484834, 0.19816647662082687, 0.10593267506919801, 0.1163328431721311, 0.1240951289946679, 0.1926207632641308, 0.09937401919160038, 0.1907021482475102, 0.14160446327878162, 0.12339638953562826, 0.2816917095333338, 0.17806441232096404, 0.20534570154268295, 0.17960751545615494, 0.10955530568026006, 0.20257839612895623, 0.26930772874038666, 0.17531928227981552, 0.12081193446647376, 0.10847637138795108, 0.13457580527756363, 0.09675762208644301, 0.15606835746439174, 0.2250958394142799, 0.15724357799626887, 0.1762525478261523, 0.15557977196294814, 0.20068976387847215, 0.054481858751387335, 0.13881839637178928, 0.29300678987056017, 0.1993513450725004, 0.11143070543766953, 0.1431039726594463, 0.14589559083105996, 0.1391935520223342, 0.07519875158322975, 0.07849447356420569, 0.050136072022723965, 0.19204029988031834, 0.09297994198277593, 0.2131762946373783, 0.10785218808450736, 0.09856132295681164, 0.1383935019839555, 0.07368664795649238, 0.15399485622765496, 0.12276973488042131, 0.09395551736815833], [0.0785795459523797, 0.03228395085898228, 0.023613511912117247, 0.027697704572346993, 0.03150566801195964, 0.0702807393099647, 0.023969690846570302, 0.02645525473781163, 0.06016641309543047, 0.008316317616845481, 0.013960471296741161, 0.08402309525990859, 0.0050589869351824746, 0.03559043769200798, 0.02046187419182388, 0.0279695050267037, 0.016805670675239526, 0.014414154520636657, 0.02514448278816417, 0.02612945005239453, 0.009530562128929887, 0.031017297733342275, 0.04615116573404521, 0.04790121674886905, 0.03875953072565608, 0.03695549217809457, 0.04254992010828573, 0.041728544456418604, 0.06509409184218384, 0.011732031889550854, 0.03193989861756563, 0.02723975121625699, 0.06053444783901796, 0.056295441318070516, 0.006448607900892966, 0.07350563071668148, 0.048218518277280964, 0.0032121995218403754, 0.004523951338342158, 0.011961698764935136, 0.07800369872711599, 0.03559010001481511, 0.0717028278450016, 0.05139203080034349, 0.02201759569288697, 0.011998434147244552, 0.055699916047160514, 0.004178645331194275, 0.027228461294726003, 0.04088556859642267, 0.06722326157614589, 0.0426968171086628, 0.06323590991087258, 0.018388970383966807, 0.0605446412373567, 0.05641135365294758, 0.056528935820097104, 0.03032605025509838, 0.02052862851996906, 0.0007873258584822906, 0.00804609144324786, 0.007854115465306677, 0.023073987249517813, 0.07540610022260807, 0.008925044767238433, 0.04969070178049151, 0.05376032422645949, 0.023033460420265328, 0.03183433182130102, 0.09966906742192805, 0.04434504917298909, 0.03687990072648972, 0.030110025909380056, 0.04038363927975297, 0.008807039575913223, 0.028188627838972025, 0.02732107946940232, 0.054213750481721945, 0.08358787017641589, 0.05229905771557242, 0.05956556291494053, 0.04890512733254582, 0.024466135691909585, 0.061423804218065925, 0.003695633358802297, 0.06326446033199318, 0.0531493251764914, 0.05903636338189244, 0.020961142909072805, 0.03157757098961156, 0.04102853963559028, 0.027508497732924297, 0.008415875799983041, 0.010994752701662946, 0.06071329800761305, 0.0863479619147256, 0.0562105915741995, 0.04449187566933688, 0.029866799995943438, 0.0024024183039728086, 0.026689686201279983, 0.04812691127881408, 0.04754506007884629, 0.041066511621465907, 0.058479908475419506, 0.0264441948820604, 0.0064347561783506535, 0.024915355825214647, 0.008647706035844749, 0.07729474731604569, 0.005589334941760171, 0.02536635711294366, 0.0321035941306036, 0.04317178791097831, 0.02449105515552219, 0.0132975896303833, 0.01677594209468225, 0.04653386531572323, 0.05231385242950637, 0.03590356092900038, 0.011524342789925868, 0.012829068091377849, 0.04322272521676496, 0.0364234576409217, 0.03899010487657506, 0.01653024668485159, 0.047864640000625513, 0.029916509047325235, 0.01655171887250617, 0.039686343297944404, 0.01991177206946304, 0.08194797614123672, 0.03852650748740416, 0.07678576759644784, 0.050320614463998936, 0.010554099735600175, 0.046861063383403234, 0.06273048507864587, 0.0366222678712802, 0.057761353673413396, 0.009788779425434768, 0.018688024356379174, 0.039178335791802965, 0.03612945212807972, 0.07045088408631273, 0.051507252937881276, 0.05396007327362895, 0.025643298795330338, 0.10088279057526961, 0.027911875404242892, 0.028197112442285288, 0.012876079435955035, 0.02080200232740026, 0.048011978578870185, 0.03053051379538374, 0.03137132815027144, 0.028336710420262534, 0.10886884134379216, 0.031374686368508264, 0.019958623852289747, 0.021659832273144275, 0.053077088232384995, 0.057475905123283155, 0.018459646962583065, 0.029079615087539423, 0.07356517322477885, 0.026630154825397767, 0.1101453130831942, 0.023650543225812726, 0.019309817944304086, 0.02313642227818491, 0.04764822602737695, 0.03713032361702062, 0.07097534500644542, 0.044792215412599035, 0.05414015169662889, 0.05306436782120727, 0.032750939863035455, 0.006714996707160026, 0.030548386566806585, 0.00832011555758072, 0.0428869738971116, 0.0773857717285864, 0.009766704242792912, 0.05496723075339105, 0.04572706173348706, 0.02401193203695584, 0.02658098383108154, 0.057930240509449504, 0.02221389746409841, 0.04982137914339546, 0.010617755597195355, 0.05771938893303741, 0.022511457864311524, 0.00700622751537594, 0.03404996547033079, 0.029571514278359246, 0.02248152519314317, 0.03420558641664684, 0.04577712701575365, 0.008828233458189061, 0.06146736828668509, 0.01855867543781642, 0.048940928536467254, 0.042548636192805134, 0.026753403290058486, 0.01819541270378977, 0.04283582136849873, 0.027464208214951213, 0.010034761489805533, 0.016527222433069255, 0.06632697724853642, 0.01865884682047181, 0.035637779292301275, 0.06330313364742324, 0.02046127676294418, 0.028846521345258225, 0.01919788723171223, 0.0644658638339024, 0.02399985914962599, 0.043519439568626694, 0.07068892795359716, 0.045791261218255386, 0.03210400973330252, 0.0332382303167833, 0.035399163971305825, 0.06322002052911557, 0.03190407143847551, 0.06479670584667474, 0.055648013949394226, 0.015096342231117887, 0.019848303600156214, 0.11129332648124546, 0.038033057207940146, 0.025814293330768123, 0.041078731082961895, 0.023586200877616648, 0.011255948793404968, 0.02987179464980727, 0.07286463776836172, 0.048970892748911865, 0.11626918174442835, 0.07188721443526447, 0.018033103151537944, 0.06474167559645139, 0.035477382625686005, 0.05388359866628889, 0.026686185119615402, 0.0759394075430464, 0.05452223900647368, 0.04655002187064383, 0.008776430622674525, 0.027431685448391363, 0.03545821295119822, 0.06923597349668853, 0.012571119823405752, 0.025111568538704887, 0.04323208369896747, 0.027934807767451275, 0.08150584166287445, 0.0327380932867527, 0.028123489537392743, 0.07110122067388147, 0.01740718878863845, 0.009161346442851936, 0.0067615776060847566, 0.06279664012254216, 0.019965633437095676, 0.004666150543926051, 0.05190186398976948, 0.04800419344974216, 0.03053449727303814, 0.02498466314136749, 0.047606357766198926, 0.016686973431205843, 0.03587832790799439, 0.0030555244939023396, 0.08212372413254343, 0.08911206867196597, 0.031185416446533054, 0.03937473404221237, 0.04907062626443803, 0.013476344247465022, 0.04607917369867209, 0.019353094430698548, 0.05439540596853476, 0.03726160583028104, 0.020183416672807653, 0.013224872145656263, 0.030835005854896735, 0.04416806921653915, 0.02431633503874764, 0.024520395963918418, 0.0680297237704508, 0.03459175553871319, 0.025148495951725636, 0.05163721041753888, 0.07680124879698269, 0.0656881216855254, 0.02028291826718487, 0.047387765589519404, 0.05546265143493656, 0.015179764268395957, 0.0417640896193916, 0.023521320472355, 0.029294238629518077, 0.008050273445405765, 0.04497141439060215, 0.014713479376951, 0.02130382588802604, 0.024728904209041502, 0.011598715263971826, 0.00334062562615145, 0.08302063928567804, 0.04078179037605878, 0.0850082295073662, 0.050577568254084326, 0.05367461359128356, 0.02155710790248122, 0.018391480698483065, 0.0460868957452476, 0.024996042120619677, 0.05085660835902672, 0.05550716545258183, 0.014014985754329246, 0.030719091664650477, 0.03666211006930098, 0.024969966762000695, 0.049553916542208754, 0.027523450153239537, 0.030933590896893293, 0.015739620066597126, 0.07026874620351009, 0.025413370312890038, 0.0031269274495571153, 0.030679290284751914, 0.05409844670793973, 0.08468991494737566, 0.049157201501657255, 0.03905567733454518, 0.030295336473500356, 0.06260512891458347, 0.06372085146722384, 0.021480260365933646, 0.020612622938642744, 0.022579798533115536, 0.025405646410945337, 0.09558688412653282, 0.062093677843222395, 0.03148753363348078, 0.03920885661500506, 0.05623300443403423, 0.23821594164473936, 0.12896271975478157, 0.11569398760912009, 0.15893147414317355, 0.11368402163498104, 0.13926193350926042, 0.13756142085185274, 0.09978283123928122, 0.10817479967954569, 0.13537248596549034, 0.045709012701991014, 0.14873712585540488, 0.18658404500456527, 0.12513947178376839, 0.1628141978289932, 0.11826144007500261, 0.15913194307358935, 0.07224992426927201, 0.06989494126173668, 0.1535746967419982, 0.14462740888120607, 0.13568013586336747, 0.18542627978604287, 0.1564592614886351, 0.16656937601510435, 0.083656763745239, 0.08227634680224583, 0.11899243327206932, 0.10249400060274638, 0.06976518416195177, 0.12793337577022612, 0.14816461829468608, 0.2091590641066432, 0.10266288372804411, 0.07797917816787958, 0.24489825416821986, 0.1499871103442274, 0.13089366926578805, 0.09319342818344012, 0.10873004488530569, 0.19431327556958422, 0.2388227661140263, 0.19145196973113343, 0.12940578191773966, 0.13136957888491452, 0.12906765943625942, 0.17086638137698174, 0.13865835964679718, 0.12124415385187604, 0.12498031079303473, 0.13405118108494207, 0.08784807985648513, 0.16409361589467153, 0.14737194520421326, 0.11884576262673363, 0.09595970943337306, 0.2113570531946607, 0.08487870989483781, 0.0968025962356478, 0.0974283974210266, 0.0917254452360794, 0.13307317887665704, 0.090024383389391, 0.1676896182470955, 0.15063122031278908, 0.24977143330033869, 0.24258667195681483, 0.19430634391028434, 0.12271828920347616, 0.15914073010208085, 0.10406088957097381, 0.09427676341147162, 0.08922029606765136, 0.12319593544816598, 0.1850682677468285, 0.27496805938426405, 0.13224734662799165, 0.13959769596112892, 0.1620619569439441, 0.15435651963343844, 0.17686265258817002, 0.13189936842536554, 0.14299971575383097, 0.2210448114783503, 0.09538387705106288, 0.12192151945782825, 0.15967691695550457, 0.11980778639554046, 0.09886804517009296, 0.12699199112830684, 0.1263520965585485, 0.12402048378135078, 0.11509218005812727, 0.10085272617288865, 0.15910365240415558, 0.10531567575526424, 0.14452454721322283, 0.1259413326624781, 0.13729972473811358, 0.12027647491777316, 0.13302765553817153, 0.13194259110605344, 0.13934771093772724, 0.10484421902219765, 0.13685740472283214, 0.14836522081168368, 0.12396124555380084, 0.09581386999343522, 0.14856705529382452, 0.14052782964427024, 0.1177277542592492, 0.06462644232669845, 0.09362074197269976, 0.08591921578045003, 0.1416267573949881, 0.12351264696917497, 0.09211004842654802, 0.1619114345521666, 0.10652438199031167, 0.15032604918815196, 0.06885760434670374, 0.19758350477786735, 0.10252171981846914, 0.13037879689363763, 0.17434662353480235, 0.10719074154621921, 0.12155230841017328, 0.1749324897537008, 0.09298467688495293, 0.06260837952140719, 0.11159376270370558, 0.1341638242593035, 0.05034491237893235, 0.08495570771628991, 0.17238692322280258, 0.084620212437585, 0.1205625431612134, 0.23303540947381407, 0.18533037946326658, 0.17982104618567973, 0.13364326703594998, 0.16166631801752374, 0.22522124752867967, 0.12432747316779569, 0.2902866405202076, 0.14330225967569277, 0.1486769673647359, 0.14818927244050428, 0.2160308914608322, 0.10647917777532712, 0.10405929395346902, 0.09335470429505222, 0.14845092402538285, 0.1972099966951646, 0.09601582321920432, 0.14901860762620345, 0.1472547452431172, 0.17684166465187445, 0.07105214244802482, 0.09163695896859281, 0.13236620899988338, 0.1982740286621265, 0.13688124250620604, 0.20618069189367816, 0.11041577396099456, 0.1667150150751695, 0.13347874773899093, 0.1674914945033379, 0.18912653904408216, 0.13836282159900293, 0.10186210638494231, 0.17440562427509576, 0.12507950625149533, 0.14585483208065853, 0.1410540717188269, 0.08775155612966046], [0.02401540714345174, 0.035633716033771634, 0.03611881344113499, 0.010307410775567405, 0.014482339338428574, 0.02933265033789212, 0.08238004709710367, 0.046100451072561555, 0.04027957904327195, 0.060412895181798376, 0.017284367058891803, 0.03870558772177901, 0.03262527199694887, 0.0352854780794587, 0.09170881370664574, 0.09748194337589666, 0.07521953171817586, 0.002487242768438591, 0.036953095041099004, 0.06296393505181186, 0.06614695448661223, 0.0451721170975361, 0.02770877370494418, 0.04571679783111904, 0.03595604190195445, 0.02714641686907271, 0.003994807466369821, 0.06277338121435605, 0.023912027827464044, 0.05672289240465034, 0.07371107203653082, 0.06258510577026755, 0.04768217928358354, 0.04776547422807198, 0.006673639136351994, 0.03269689666922204, 0.04758595983730629, 0.07877328360336833, 0.06026430979545694, 0.034208933502668515, 0.03115186766081024, 0.04039631887280848, 0.04328429378801957, 0.032684758843970485, 0.035115930731990375, 0.023773676657583565, 0.038833029320812784, 0.04138325653912034, 0.06646253794315271, 0.02235146937891841, 0.05392876577388961, 0.014365099486894906, 0.038658505873172544, 0.035124309579259716, 0.025809575126913842, 0.02276774186611874, 0.00877022812346695, 0.027187687701371033, 0.05878538388060406, 0.057425079139648005, 0.026280323108949233, 0.037582918666885234, 0.04786967547261156, 0.014459534068009816, 0.02669866989890579, 0.040027356444625184, 0.04635868135665078, 0.008756773913773941, 0.1133070996729657, 0.04897848491964396, 0.014099111904215533, 0.029494193622667808, 0.020431167831702624, 0.04243852003128268, 0.06395476157194935, 0.055336653313133866, 0.04322384214901831, 0.01421264287273516, 0.04826140699151438, 0.03705573035404086, 0.045389447623165324, 0.029237340022518765, 0.0166147884374368, 0.0177976067061536, 0.03858481431961991, 0.024361891773878597, 0.003782033727475209, 0.03474460085271858, 0.00855090307595674, 0.017983917314268183, 0.01665498872171156, 0.043981385679217055, 0.019533352824510075, 0.035674422833835706, 0.04752723369165324, 0.01679590957792243, 0.02266270199470455, 0.02682506135897711, 0.055629653215873986, 0.020325601035438012, 0.04659173057007138, 0.024575053284934256, 0.035963173941127025, 0.02783502044621855, 0.08156135430908762, 0.020272355650376994, 0.07610491389641538, 0.06863630333100446, 0.033721524305292405, 0.039512899675173685, 0.028734379120578524, 0.04616344456735533, 0.018519759069022257, 0.056655961816431955, 0.059321470544091426, 0.04688016255386174, 0.024006660933082458, 0.042431985420989804, 0.02186593224905664, 0.0560896623210283, 0.048648526062606834, 0.02936128239525715, 0.028928335705131758, 0.025804333708947524, 0.04274673025065567, 0.07580139776109718, 0.07448377393302508, 0.05519551537872758, 0.0323934770131018, 0.049574585355003364, 0.04101167432963848, 0.018965633971674833, 0.04837169384700246, 0.08553673513233662, 0.05733936850447208, 0.006764529962310917, 0.041025311293196864, 0.02676573221833678, 0.041024335369002074, 0.09625570761272684, 0.0311651558149606, 0.010050821565528167, 0.02767694113572361, 0.14439177699387074, 0.058245571635779925, 0.019285032067273278, 0.051840414162143134, 0.025992672235588543, 0.03222028200980276, 0.059223685166216455, 0.09348687337478623, 0.016275281850539614, 0.09032611837028526, 0.01901880885270657, 0.0724213158537168, 0.030982580065028742, 0.02988022730278317, 0.04739738753414713, 0.015766433862154372, 0.05372195148083847, 0.010989809070451884, 0.04158846408245154, 0.08467994048260152, 0.03974023064074572, 0.021311781711119693, 0.049856063415063545, 0.007527355264755897, 0.09159192544757389, 0.02619373488414567, 0.02400462002697168, 0.04014448219095357, 0.03683568356791511, 0.032172573046409525, 0.06686888606054708, 0.05146922900166828, 0.014693542507302482, 0.028480045111791696, 0.006763875944670872, 0.02337220445042476, 0.02797065164486412, 0.024165640097635332, 0.033327388227917254, 0.06181873439345509, 0.02862306995666586, 0.005175456808501622, 0.05533017065317836, 0.09226806650985964, 0.04717652438557707, 0.05800558705232106, 0.02671009711775696, 0.024324344667547848, 0.03776465578994248, 0.043858630742761306, 0.03923402284272015, 0.030641728335467633, 0.08812118278001435, 0.0383763116406044, 0.007023050147836329, 0.054958042965154164, 0.0536991044646129, 0.08371215022634715, 0.014887173474562587, 0.008261141720140586, 0.07978066001669504, 0.024859837612893898, 0.020826925501751248, 0.06005624127283227, 0.03452579716395121, 0.02227031181973871, 0.056958053028211, 0.004776049627253087, 0.0526778276253026, 0.031593059611623175, 0.02784728629194433, 0.051448875601636246, 0.0013364186020226043, 0.02061871040496044, 0.03407908363442402, 0.1080329529941082, 0.08192224588128738, 0.04333281540311873, 0.07451425393810496, 0.048084768422995694, 0.020626597579394, 0.055945741332834587, 0.02302827651874395, 0.0038224304489631322, 0.06447537816711701, 0.03733950907189865, 0.05031596119806636, 0.02408338972600177, 0.0370723655942129, 0.03246568427130114, 0.05165271017176565, 0.043859777360921726, 0.041531645256327465, 0.02105353843944613, 0.018621670787979383, 0.027979336628050078, 0.09745569361257367, 0.032028726272983477, 0.06929924158612266, 0.03693851926072966, 0.06618002458708361, 0.06569038523593917, 0.03730776741576847, 0.042309942946303636, 0.05231867267866619, 0.0906205728824716, 0.058151804987573996, 0.006255728358155466, 0.012066813778801588, 0.03800328966462985, 0.011041815068892902, 0.06458956500864588, 0.050308907084399834, 0.1550208160188049, 0.039772309974068776, 0.08135875541483983, 0.0822862025233917, 0.03145869748550467, 0.02663480438059196, 0.04834444960579276, 0.023826339456718415, 0.018398414213152137, 0.020847197265538853, 0.038652104849461466, 0.027992619216092862, 0.007619062917001429, 0.027104229484393727, 0.026078585106006358, 0.03460780448222067, 0.027924480782530736, 0.021846092786290683, 0.0787049466453027, 0.01405893666742486, 0.039626095749554224, 0.016697302271495573, 0.03633855594671331, 0.07633751039975323, 0.05757309678301681, 0.04239855166815687, 0.030782511894358322, 0.03697352636663709, 0.020234815965523012, 0.023657289348193444, 0.1170346699655056, 0.06169542655698024, 0.019503986040945165, 0.04430804568983149, 0.04427763618878089, 0.06183163292007521, 0.024536368837289046, 0.038087311913841404, 0.028245478206372354, 0.0495267947553657, 0.012546217985800467, 0.04370554794149939, 0.027536805100680795, 0.02328813210624503, 0.026514617275097407, 0.031703546846983954, 0.055964569619391114, 0.08129648180329241, 0.008611389966972638, 0.027879528897756245, 0.029193686896178406, 0.03474879398709163, 0.03179107574396767, 0.010533525546634337, 0.04842280184675474, 0.08106338063953444, 0.015079069671628531, 0.051425267884042114, 0.04665434928028844, 0.12488739390391856, 0.046137380340951495, 0.04263248403731268, 0.08524109318386763, 0.04699427889136132, 0.039102952141547576, 0.013092562057863688, 0.07266768661793321, 0.041507269415888004, 0.04638364349375479, 0.013131227024132386, 0.09239452105248347, 0.031633213511668146, 0.03197862759407144, 0.04469119798159227, 0.08275262007373385, 0.07777553284540772, 0.06694416209938936, 0.06855399173218757, 0.0866941070125904, 0.01692432339041261, 0.010213925215794006, 0.016591279054409824, 0.035553823836380616, 0.018550960812717676, 0.014808485411776928, 0.018172636191593483, 0.03177420672727749, 0.04544156865449622, 0.06610883778193966, 0.04393902388983406, 0.08712912429473363, 0.04023207045975141, 0.03182683984050527, 0.05066905650892295, 0.05016006936784834, 0.02508636149286758, 0.11309947643894702, 0.1921377587132156, 0.12332466838415712, 0.07141449605114758, 0.13177137763705105, 0.07379134272923693, 0.18559017567895353, 0.1742302399361506, 0.08523212061845697, 0.1107920279901009, 0.19192876992747188, 0.1683536177733913, 0.20819016062887385, 0.22583908546948805, 0.1919238272239454, 0.20627213933039457, 0.2713340293848887, 0.1291638269321993, 0.17632351198699325, 0.16051722108386457, 0.1338208036031574, 0.09840363883995451, 0.13353526970604435, 0.15277886210242286, 0.19531891535734758, 0.10938561361399479, 0.1423846386023797, 0.29896718566305935, 0.11438099478255026, 0.17004522465867922, 0.2341398291173391, 0.1150759047595784, 0.20826072402996942, 0.12173324401373975, 0.062417513981927186, 0.30634083843324333, 0.15702370932558551, 0.1381513985688798, 0.15777808759594336, 0.15987854363629594, 0.12758478900650516, 0.11721616960130632, 0.1984595655812882, 0.16077919921372086, 0.12507137231295928, 0.12814828689442948, 0.16569487372180447, 0.12654599006054923, 0.1603106368565932, 0.16110558091895655, 0.09297588985646144, 0.2290945904678665, 0.17741700721671805, 0.09040743549121544, 0.11630994791630656, 0.10139953315956518, 0.09078162634978071, 0.11921945624635555, 0.1133876375388354, 0.12699641432845965, 0.10100813931785524, 0.14804045698838308, 0.1366754894843325, 0.2472631077398546, 0.10488948260899633, 0.12756418698700145, 0.08814944376354106, 0.11837870682938956, 0.2835554798366502, 0.08766167462454177, 0.14015010616276413, 0.11360243734088726, 0.19422533106990159, 0.2072477963520214, 0.08057973784161732, 0.13846045854734257, 0.13560088933445513, 0.06969908848986961, 0.13927685067756101, 0.11311207068501972, 0.34134503512177616, 0.11494537582620978, 0.17601419967832044, 0.15025685133878142, 0.07607709820149466, 0.11432097729993984, 0.12137929152231663, 0.11164932730025612, 0.10292197490343824, 0.3598308947402984, 0.06543685274664313, 0.09741697576828301, 0.14395183185115457, 0.08872339109075256, 0.12425242719473317, 0.09794111756491475, 0.1721962506417185, 0.09606784777133726, 0.1486269911401905, 0.10023895520134829, 0.15015902143204585, 0.057589520511101, 0.14401455817278475, 0.13793034246191382, 0.2147333204629831, 0.13820744556142017, 0.19545134418876842, 0.2583989594131708, 0.10103225911734626, 0.1346786817885004, 0.18631201819516718, 0.21634128730511293, 0.07987181801581755, 0.12688849121332169, 0.1613356763846241, 0.18695215025218204, 0.12387849608785473, 0.11947054706979543, 0.15258430066751316, 0.14471713453531265, 0.09693989355582744, 0.12778362521203235, 0.10445637264638208, 0.13008306588744745, 0.0959172289003618, 0.1378236067830585, 0.16189393470995128, 0.1427192729897797, 0.11477152031147853, 0.17402209719875827, 0.17947642249055207, 0.07499264233047143, 0.09671728636021726, 0.11863192761666141, 0.15042797575006261, 0.18847537867259234, 0.08257480891188607, 0.19162981800036505, 0.08523151205736212, 0.183822350227274, 0.11519917548866943, 0.099637607781915, 0.13061597244814038, 0.33473392424639314, 0.1775770290987566, 0.11910831221030094, 0.2585044631268829, 0.07130764905014075, 0.12870126112829894, 0.16106393159134313, 0.16010725870728493, 0.10743533857748844, 0.18477474834071472, 0.25333317811600864, 0.17223782575456426, 0.1784541437518783, 0.20154626166913658, 0.14342691079946235, 0.1169005935662426, 0.10728275301516987, 0.11857142031658441, 0.2102075406583026, 0.1491517192334868, 0.10926062852377072, 0.07026890947599895, 0.0879347998125013, 0.14217189454939216, 0.16319530550390482, 0.14140430605039, 0.11380462805391289, 0.12285220975172706, 0.11505172558827326, 0.16683979978552088, 0.17609484144486487, 0.10505590922548436, 0.1109919254668057], [0.11774216676712967, 0.06205829595273826, 0.06401207021554, 0.023013697027636226, 0.07097564186551608, 0.023370569870166946, 0.037234469200484455, 0.057889329618774354, 0.028276774573896546, 0.03680213849293068, 0.011231705611862708, 0.046714426134712994, 0.02271785469929455, 0.02587817554740468, 0.09240166793460958, 0.09619808726711199, 0.05737915504141711, 0.041279533979832195, 0.059859130560653284, 0.02305682879523374, 0.004921520776406396, 0.053138634539209306, 0.005404697876656428, 0.04623849796189461, 0.07182123008533381, 0.08728208093089052, 0.048069695403683, 0.04131876019528136, 0.050287180711166, 0.022862310033815447, 0.03131549266981892, 0.026192694022029173, 0.010025299106928287, 0.026847869412449654, 0.05640398412651848, 0.045491812052205205, 0.06655383695033379, 0.0292775458729011, 0.005954282814855105, 0.09617458345019259, 0.055856872859294526, 0.10528451297432184, 0.09027532578329556, 0.05013419438910205, 0.0560500687424792, 0.020720538632303942, 0.06326637507299893, 0.02488779431587318, 0.049027685599867254, 0.025580281180737074, 0.030082056218816433, 0.02470262104907306, 0.04604722053045407, 0.0625854248937685, 0.0161685201965156, 0.028272093477426097, 0.05603603472991381, 0.031608770877937786, 0.036996417911723256, 0.01538683645776473, 0.0745731581992004, 0.03316375950817019, 0.02032330408837879, 0.013305848806339782, 0.051801777954096906, 0.04651740448025521, 0.029505116181098856, 0.04556016385322437, 0.01018440721963998, 0.048982585285557434, 0.03228510860935785, 0.10769030341180041, 0.02372320133872563, 0.014811466990067856, 0.044587638694792986, 0.02251527621410787, 0.05295495669997763, 0.03849688837362919, 0.04525230986473616, 0.043296580042806454, 0.03071760180318961, 0.03608376551710535, 0.05525901353394147, 0.026079902418132406, 0.011003046201949473, 0.0495038215740351, 0.034737669193418697, 0.029959143575979397, 0.06710713772918098, 0.05279028897348326, 0.033458971010986716, 0.05746573398937471, 0.006544300886162091, 0.056265350940520875, 0.041283734535682015, 0.0372630752826808, 0.056653390274732374, 0.03976872169005219, 0.04179521529295016, 0.03930352126189973, 0.02010132957366295, 0.03176117090333719, 0.04068203088536393, 0.08802939395536669, 0.009781447006389499, 0.04293584432161879, 0.04826286531169899, 0.04401283418701496, 0.07653808323084377, 0.05124168281327002, 0.043521495317691006, 0.04627245492883958, 0.060155206665513106, 0.027958081518590916, 0.016419347557530273, 0.021468792328960262, 0.02747739988990361, 0.033261815769947134, 0.05061834926891606, 0.013980818202981027, 0.0339257373707369, 0.05848467677424196, 0.07238035672344267, 0.14296593319159, 0.039304868259932846, 0.016205007887037937, 0.05510024959221482, 0.06061547181161586, 0.013172617527743569, 0.05726175841118675, 0.01698481399216689, 0.014653141843155026, 0.02277914682053961, 0.01661086433159653, 0.016145253866852727, 0.08785029145656154, 0.045458244712790474, 0.04165011428995058, 0.09299276629462838, 0.024799343300401233, 0.032395833331975155, 0.04298931977245957, 0.016672297460900154, 0.01957300577487331, 0.005772350878032739, 0.06015404149366077, 0.029549231294367928, 0.024347325270355213, 0.12309231678955257, 0.023288445663638413, 0.021099922669236548, 0.03923572236089967, 0.012917890180688119, 0.03342311043525115, 0.04287996060156729, 0.06496816422441043, 0.043926403668592684, 0.10111542418599129, 0.020467757567530498, 0.05791303381556645, 0.03832636881270446, 0.011929035918001318, 0.02643867515871534, 0.0624083707225509, 0.010669996299839113, 0.0755202499567531, 0.02576916889665881, 0.0632907917315606, 0.049129797698697075, 0.022217784462554846, 0.0389172816358041, 0.007337222132264287, 0.05240471728029661, 0.029254413129820023, 0.02768731636024313, 0.03166455069731455, 0.033360105808242224, 0.012181454258097801, 0.06786185738747008, 0.050649589975364506, 0.03861402154143434, 0.021730479165853467, 0.04511368038947694, 0.058280801385990344, 0.040505748547730036, 0.0361201827035984, 0.0124991138727637, 0.060682825424009934, 0.009530093648209004, 0.0104934968840098, 0.039048556427587755, 0.05593175927060656, 0.013865212004020577, 0.041514442273182794, 0.020754154211317655, 0.012055731658620061, 0.05656599867506884, 0.05627703605568968, 0.012227355164213805, 0.018760760394798126, 0.09874799536191858, 0.027812017578980885, 0.07341347823967226, 0.04593497440509964, 0.027510397630976513, 0.011194459075341001, 0.05978949484415352, 0.027425065491115674, 0.01526554911833955, 0.058912933091050945, 0.06414174567908049, 0.04914537908916827, 0.031665931091993116, 0.028371357584546786, 0.02021116186369909, 0.007318133166336338, 0.021545771596720442, 0.04070070703164674, 0.07556287149782293, 0.0675089142168872, 0.033524383907206357, 0.03305937643744983, 0.0685241277096793, 0.040335700250579976, 0.0398159482574556, 0.06562800030224025, 0.04477868234971538, 0.09542637242702767, 0.0134430626349058, 0.03943127085221931, 0.009231050808011787, 0.022003498597769067, 0.012583848583744839, 0.05559222299780231, 0.049092029803432524, 0.005839749946972006, 0.09096871435758658, 0.028208009025547653, 0.08233631233451888, 0.04762292621308006, 0.029860838694730774, 0.03772939264308661, 0.02167292190279113, 0.02214710973930778, 0.010451249199832091, 0.030536167105310597, 0.011152437746204669, 0.008090695446298923, 0.04076250195794273, 0.04002760135335848, 0.05207073598285206, 0.01406267894708435, 0.030482287183986045, 0.04423680693435017, 0.0281291205828893, 0.06258324297959916, 0.10420723367133178, 0.03206902118108701, 0.04841387752094306, 0.018658049011719413, 0.041744934787857346, 0.009197620765917236, 0.06362550775520504, 0.024178310413844883, 0.058150461700279266, 0.041645921155577525, 0.01863473815319594, 0.03635753266280517, 0.00858991499626427, 0.05082181276520714, 0.03749733790755272, 0.031244940400938503, 0.00962819629421574, 0.024211176423705183, 0.03784742752031889, 0.055665777254034765, 0.0693115167086944, 0.053547869611065835, 0.0384463147202041, 0.04530469435849227, 0.06453721391153522, 0.004956645698257489, 0.010061288630822673, 0.054732088683522306, 0.05070293555036187, 0.02314524641406024, 0.027384534951124806, 0.021820206675329246, 0.05310799868311733, 0.04765747689816635, 0.029708260553888977, 0.029497794894268736, 0.04292811485356651, 0.013134006367181428, 0.009496308302914258, 0.05061874631792307, 0.10532543499721214, 0.036392550900927745, 0.08360300998901948, 0.11499101048684679, 0.0360432962042978, 0.03483872002107091, 0.06013031132169999, 0.037539885233854875, 0.02902589472796535, 0.021704806422349066, 0.044460163699113764, 0.03269124521466438, 0.017806666473916266, 0.04689520959800575, 0.019479383845464326, 0.019831147001241334, 0.07620097749168053, 0.014547376522386912, 0.013737493954977253, 0.04648541420465335, 0.08835182001348585, 0.05470902644447051, 0.06396616096026264, 0.04048480142955668, 0.04406701096741017, 0.021788233098050114, 0.03070725069846958, 0.011500260097818682, 0.04236584522004705, 0.07153288344852626, 0.010955725010717288, 0.014255068672355264, 0.015097912801138591, 0.04210956678434741, 0.008197663973987801, 0.05848365632118657, 0.10007395350839943, 0.01144953430411988, 0.026357432252552826, 0.06903753062942997, 0.027157333861396182, 0.022231978036870714, 0.07607498308061622, 0.016424648347310722, 0.006203101274877554, 0.02121454366715625, 0.08775476220762357, 0.024718311906326562, 0.024704437455511652, 0.03110250927420566, 0.016506644533365034, 0.03290485015895683, 0.05202275984629523, 0.030423542484641075, 0.06163021404063329, 0.014121777094260324, 0.12578505120472983, 0.28602603008039296, 0.23963851999724284, 0.14314400410512462, 0.29397241305559874, 0.07801998144714162, 0.14749114896403626, 0.17099731107009575, 0.12251284046215005, 0.15174790023593232, 0.1646428497042507, 0.17827829928137362, 0.2047905305516906, 0.10995484830345958, 0.2901477401610464, 0.1891285873716697, 0.08660668201628141, 0.18151869415305555, 0.17685477097984403, 0.17391285306075588, 0.2004695835057646, 0.12435322569217533, 0.21947221539448947, 0.271144870785065, 0.18846231687348336, 0.18706323491642252, 0.13273569464217871, 0.20212926319800317, 0.07875063325627707, 0.11613060793024488, 0.12208433923660778, 0.1727724986267276, 0.13977103197248653, 0.13121754251187667, 0.1436318177729845, 0.16406161448685452, 0.14699021412525326, 0.16871672094566748, 0.08434688686975278, 0.14096455386606976, 0.12363070040009916, 0.22845954954391345, 0.21490500890649855, 0.14145294640911743, 0.12445861808373593, 0.10126977605978027, 0.1616667484631762, 0.10336885170545429, 0.11712594670825638, 0.1163452593027614, 0.10108935253811069, 0.14368958654813468, 0.08956228513852693, 0.15597578196320683, 0.14003369287820533, 0.17935963813215494, 0.09775429673027247, 0.1138355681905523, 0.102271304349415, 0.03986361640272662, 0.18177559599280357, 0.09293257069657557, 0.16411313437856734, 0.23381948849419132, 0.11170041674631648, 0.08485672005917877, 0.08425086780334823, 0.0695286320114974, 0.1146820024587214, 0.20192604832118377, 0.11870705522596836, 0.27391750481911004, 0.17755170702002943, 0.12128833390306681, 0.10535478693782352, 0.14825605088844895, 0.10786699393065646, 0.1564502518158406, 0.1711745953070931, 0.15865615219809115, 0.1368650933727622, 0.15903374209301546, 0.1855740710743703, 0.15243812726112083, 0.1334844622761011, 0.12740879610646516, 0.11325316780130379, 0.12231398941366933, 0.1395843521459028, 0.1469686918426305, 0.07636629830813035, 0.1532857192796655, 0.1251365477219224, 0.1704588087159209, 0.18294235604116693, 0.12670341442571953, 0.09538602185784839, 0.15718364214990288, 0.12183892584289424, 0.14897400455083698, 0.1937461708439514, 0.11442334172897972, 0.13987353740958497, 0.1361731594079174, 0.12148681387770921, 0.11774261205573566, 0.20185190776828676, 0.11999292255495675, 0.10989449685439467, 0.17220172769157216, 0.08005356256035157, 0.2275228701182641, 0.18703175301197916, 0.061876543986727484, 0.08489163068588823, 0.12524041871074587, 0.10946802911348641, 0.1444244314916432, 0.09977556561352685, 0.0920200852851849, 0.13668074388988316, 0.12183361948700622, 0.19302950851852074, 0.26234201970510185, 0.11844208624097519, 0.11609168970608152, 0.1376787989283912, 0.13472079124767333, 0.10970942748826928, 0.12294546060729772, 0.160181428946089, 0.07975244356202893, 0.07635253889020532, 0.08814404834993184, 0.08121266364469193, 0.17538644664455205, 0.16487046639667824, 0.09640790725825354, 0.11527659633429721, 0.11746139745810069, 0.2603528561303392, 0.09375870722578838, 0.15070824039867148, 0.13921828038292006, 0.11129245074698702, 0.07658100905246101, 0.1348878932185471, 0.05724005059164483, 0.2374968896037899, 0.1427629854879342, 0.1125325498287566, 0.1187426783144474, 0.06743444711901248, 0.13096794340526685, 0.1995449120295234, 0.16777653858298436, 0.1540545842726715, 0.14435747492825612, 0.13749437523074448, 0.11126971876365133, 0.15881663421168923, 0.07969777696416713, 0.1363612196291797, 0.13343412982067093, 0.08349765470484272, 0.16831063257995993, 0.17009543837048113, 0.09978001107810996, 0.11030917186872102, 0.13624691404402256, 0.15322995430324227, 0.1619750662939623, 0.1511556515470147, 0.09634263537009247, 0.20923954260069877, 0.1308971573598683], [0.0604913476126967, 0.017308063834207132, 0.0348869262234075, 0.023694229748798534, 0.025857929758785758, 0.038905707842786796, 0.016342655871994793, 0.04359508297056891, 0.06176608272653539, 0.07412349092192017, 0.06180639247759245, 0.025271597842220217, 0.01426328053639736, 0.041753951882128604, 0.01117524672736181, 0.04608147806720808, 0.017612923256820068, 0.02277192943438422, 0.02343362088140566, 0.053735061519546434, 0.0541162025911035, 0.03152609191602096, 0.020792103932762984, 0.028640966847888194, 0.00480950796372781, 0.017282259359490126, 0.03885830315994099, 0.03418929627514444, 0.03870070810080506, 0.08837993256747723, 0.07690572092542425, 0.09995324318879284, 0.016714067387511022, 0.049301842373097315, 0.04176004120381549, 0.0729468825738877, 0.038585107467952184, 0.037094741346663795, 0.06393277915776707, 0.12331082732998766, 0.06870067722047679, 0.0028962700389456586, 0.0392495485721156, 0.11899373945198022, 0.02971743349917233, 0.029431656548695173, 0.08066708120168187, 0.07178346961154602, 0.1008286805881653, 0.03926537116058171, 0.05186315356695559, 0.07772287004627287, 0.04884472393314354, 0.054927243836573325, 0.015234643306030193, 0.048040380570455454, 0.04392149807245005, 0.03375682084879372, 0.020722753943118732, 0.0037869704010518035, 0.036345179614727385, 0.10880590722081251, 0.09351120839710347, 0.012897661090391921, 0.013540265426854603, 0.02373568611801602, 0.046395870376727544, 0.06429839078919031, 0.03196620775270276, 0.0337701052922057, 0.0439202475536149, 0.031679920575697906, 0.04020434382255189, 0.07582054517115466, 0.08949887604103424, 0.013588990204880247, 0.026022773745353334, 0.041985383213614114, 0.04153326684900094, 0.0755698476859834, 0.041845254600048065, 0.012968698538315948, 0.034962224526680075, 0.04627742360753473, 0.022487317655759398, 0.09361261545564048, 0.009008819324662909, 0.0093241792092158, 0.030208716707420535, 0.014443049112742301, 0.04741937736980617, 0.038300464148051105, 0.019490536469675135, 0.030883373474352993, 0.009712208338896744, 0.014349409557325998, 0.031392679738928564, 0.05642088653985411, 0.020906244390062056, 0.07610601227497682, 0.07634113950189203, 0.011155207812407752, 0.06712330912705511, 0.07600055309012532, 0.03715882950928062, 0.07773591700242832, 0.040620985528221354, 0.023982687707757577, 0.1001962371810805, 0.05705138552002609, 0.0283150953691802, 0.08290043362649158, 0.009799737235880457, 0.016091611432784703, 0.01947416840266669, 0.05076990324596409, 0.06536345434142277, 0.04395556265080813, 0.04744235055113677, 0.027898555708816275, 0.023128805987653323, 0.06519934322568588, 0.01157978957053274, 0.0020512542005235446, 0.10114833843545057, 0.0514946104522096, 0.039734991078148596, 0.01846278624725528, 0.027884588489541784, 0.04440296266693622, 0.025067672359000426, 0.023337262282439042, 0.023646127447136678, 0.031070622899278533, 0.02657002602063585, 0.013112707656546263, 0.0441360344120767, 0.02907581158069661, 0.021469287712534424, 0.07287348416866735, 0.017926655054907314, 0.0038236148702708306, 0.01918604441016214, 0.03578747790015768, 0.04970180430973414, 0.05386912678659428, 0.018358466259087436, 0.019084947198280133, 0.02320530100405449, 0.04314943442295771, 0.03344405384268612, 0.022862664409331046, 0.02850698321708478, 0.037592740991385654, 0.028435560780053493, 0.061902686138637364, 0.0299345321036526, 0.054965846647974104, 0.07044496916932985, 0.11027470653061755, 0.014726080116815865, 0.018341966460866388, 0.04552334219624754, 0.04131772861001082, 0.09163301074295305, 0.05046169302659109, 0.0347928218980087, 0.03716501531016547, 0.04359437421953771, 0.015287499991245568, 0.10798484698170796, 0.013760391066170996, 0.0541801868530456, 0.021903115703025833, 0.033418082384741865, 0.04583115907735191, 0.0868946204718668, 0.03963249306252692, 0.045577511555165984, 0.0034296420653845416, 0.0410742819076404, 0.041852724316413514, 0.07895480550359935, 0.024006694329727907, 0.04893036406429019, 0.05821324739372358, 0.009597471380402567, 0.08459981079795398, 0.03658456676930655, 0.06845053634606302, 0.04907266717054881, 0.010892618338402826, 0.060722660200553946, 0.05579128555837087, 0.024164517599274404, 0.008840590217005229, 0.02690983317734208, 0.010782800891320221, 0.05864899940206669, 0.04163546800555196, 0.03352058040036354, 0.09229039031197317, 0.019934491065214388, 0.05754754092777148, 0.025630199888837524, 0.07730438039288856, 0.010882939805014757, 0.030950793880037963, 0.02515279113140423, 0.05021004188165534, 0.04702417259977665, 0.0337638193013845, 0.04138052543567028, 0.0060573898554139305, 0.06727483341819607, 0.0591266716219252, 0.0676271457632538, 0.005774016071882215, 0.01231007865499123, 0.013552718664868735, 0.09057263014256023, 0.017797588152461685, 0.05334740810212679, 0.04945286942529492, 0.014499544176942436, 0.019634615164250135, 0.015384492198791122, 0.03206562585546635, 0.031433501571882516, 0.06320298081845976, 0.039941003851708956, 0.028000849633826874, 0.060352818327373825, 0.06281316032982431, 0.007212342334241839, 0.008591628429712728, 0.03761931729968637, 0.05527861365408171, 0.02594681121991016, 0.009033474398165708, 0.032148816899280064, 0.025278369939769618, 0.006106437467678916, 0.01919607268064283, 0.028001011050946545, 0.08467648207442835, 0.023890399788797367, 0.029417735713650472, 0.007089395367074758, 0.11117940681288019, 0.1131202194665093, 0.03574319023755379, 0.061670486684306525, 0.057614634788478725, 0.05723226546251681, 0.019934878837375436, 0.015129629409784684, 0.06005065290082712, 0.02987571690027835, 0.05806653593026567, 0.05400046466093045, 0.043638409551931545, 0.04020596912596375, 0.00549436276742199, 0.008685431257617893, 0.05534547002753243, 0.06251297643757425, 0.015885387147136498, 0.010544602100708289, 0.02647853962116642, 0.03203283034963533, 0.04985709871107247, 0.03728994845005218, 0.013173183415347012, 0.010666591697372496, 0.05979594410746358, 0.0242009923022124, 0.032328813686035573, 0.010843894488061778, 0.020570676751958672, 0.022225946231628768, 0.07927721671876498, 0.04190425534034148, 0.029082025212119333, 0.005773909388153697, 0.040136492971214466, 0.028550243005156517, 0.06231863022549078, 0.09725698357215151, 0.029302600778464694, 0.028434885425667744, 0.006424388375307899, 0.030601171820308082, 0.01157142556621693, 0.08567286728066392, 0.05825655171065591, 0.012858358804805903, 0.03321214753668755, 0.01676835549005773, 0.02015148762438912, 0.021380343168857507, 0.062051675995462574, 0.0387829195096856, 0.09709412668598816, 0.028498979154392146, 0.03537913711625151, 0.1136568961373996, 0.01903399133880157, 0.09059064948814921, 0.05919239250943065, 0.038684729661326855, 0.014213691156328423, 0.03717066676472314, 0.020944086500094272, 0.01578049941599602, 0.04014280864794273, 0.06876879153423943, 0.015255797297868412, 0.07688068828429095, 0.05018217423639726, 0.0552553992747562, 0.046113924763631076, 0.013375558737607207, 0.052698607760248706, 0.033122087916126475, 0.08614097692770883, 0.02674275903700618, 0.019041147497773636, 0.04912512958981097, 0.028079574803996366, 0.054539742559427395, 0.030306030821520835, 0.019315174395160284, 0.013645588242070517, 0.033403369307052344, 0.07032588415313512, 0.04847655560297426, 0.006369292723320541, 0.012382758104649838, 0.03328277773107402, 0.055008768758852966, 0.03752401811652817, 0.04664974425395485, 0.06690955575322732, 0.03693875674798619, 0.04950185488269199, 0.029070562741253525, 0.02556625273427926, 0.01955729821929708, 0.025096142999245785, 0.016454981778224465, 0.09324772370746359, 0.2016476687276736, 0.12226479244418442, 0.16101597400847822, 0.13774354389170185, 0.11824753222754225, 0.1474129265989177, 0.13650087697897106, 0.18760951497824863, 0.14422682725125924, 0.17067606502678245, 0.1513564767083153, 0.16580190625973046, 0.10078339473693632, 0.15970206091878936, 0.09642384116887115, 0.1869940519100055, 0.1367935206508264, 0.12653270561713725, 0.10469262051628903, 0.12319558663875796, 0.17847575509222224, 0.089806251344271, 0.18956513347802684, 0.164698199077975, 0.12279553193366155, 0.1915940613253042, 0.12772362999385223, 0.13556897698435932, 0.145777529978659, 0.2399757073726505, 0.09526141526293941, 0.38680722063872963, 0.13114469329593703, 0.1370942240464501, 0.1504780410323292, 0.19834511156659573, 0.14799367199884728, 0.11978141046711244, 0.11930727458093315, 0.19598649203544483, 0.13999624410644174, 0.0716110019129701, 0.1267504517454654, 0.14703321416163817, 0.16216042509768158, 0.12939699488924816, 0.2247158598038368, 0.17599175713257864, 0.18611892621265724, 0.1973670203005895, 0.08018510081456043, 0.18217196222394705, 0.11208291223738343, 0.14601158851291984, 0.20649899903219193, 0.16995802230667323, 0.1135402379441075, 0.19219637353671715, 0.11159656060044654, 0.08907611161703244, 0.1304741925559938, 0.12857714435085654, 0.16226595849730074, 0.14297761459602043, 0.2182623217231594, 0.10149548543267883, 0.05579854747338686, 0.16254813788691536, 0.0680768204620108, 0.11361074197338894, 0.13227651303168386, 0.12281931034522131, 0.11711971266777255, 0.22044195007765666, 0.1540365649270825, 0.18394240003544837, 0.14696808328153566, 0.16163586027687415, 0.11633892878307961, 0.12246025187778287, 0.13588281639385968, 0.16982728557195514, 0.0930677677388303, 0.1601252780528739, 0.09178093561786227, 0.18230375280836597, 0.15952799760270864, 0.09159279376035556, 0.09639551339205354, 0.1551760287838988, 0.13598259072750807, 0.14443725580349565, 0.11563497202587314, 0.11869263529661112, 0.13897126395022497, 0.1069446602195967, 0.12352407604339533, 0.1090679076150991, 0.10150389396585524, 0.1526133928564377, 0.21372987743234262, 0.05700752830307465, 0.10270503029460087, 0.20271265064366162, 0.11829952709376812, 0.24945269571617246, 0.13389626517891884, 0.21773002372356132, 0.10527179256314412, 0.12098545601475053, 0.13155906402971596, 0.17238646309124306, 0.11591244619921781, 0.07024519043625332, 0.08751012064749375, 0.1151878503151238, 0.14403814362594858, 0.12888794095488265, 0.17869137867819518, 0.12039324443321675, 0.17639490659348667, 0.12801049975678325, 0.13506583054549992, 0.1483000602456741, 0.12302096671191975, 0.12656645849347115, 0.09576319615007378, 0.15183146606432274, 0.09497214836301282, 0.14531157998135313, 0.14870723214698955, 0.0883435302239377, 0.12627954420167953, 0.14458345889579505, 0.1295676443260163, 0.14010805607540533, 0.12357984101981856, 0.11162963812239468, 0.09157965774647892, 0.1177471614209935, 0.1485552848316729, 0.100586755288532, 0.18106539035215974, 0.13544355402700603, 0.19261234730947763, 0.11039644843549468, 0.10148883578949608, 0.08595510604209267, 0.10664704415830784, 0.20234062685631216, 0.10354120066040196, 0.06861688874778338, 0.0753554115362931, 0.07371418163529597, 0.16092102363472804, 0.14802277903072536, 0.07280482808710076, 0.13447104371152818, 0.17618416633922607, 0.21730702923377976, 0.17616754223126918, 0.1492149502155371, 0.14412273361813277, 0.12874043168267235, 0.21381525410106406, 0.2327136290841736, 0.13800394866848364, 0.1592214757693, 0.17708035418763757, 0.084249635838205, 0.21049789851531386, 0.11906569809070788, 0.1220997610653285, 0.18065744661726058, 0.13554261589888483, 0.17639734083786607], [0.01234581955941394, 0.04481326643144712, 0.015187869448709534, 0.026489367555768695, 0.047061202058102936, 0.07049565785564482, 0.0583921791985631, 0.022993133970885538, 0.02503432951925788, 0.01276167180549237, 0.025858833323582076, 0.029800353659084067, 0.11357857729308307, 0.027088071074103937, 0.03625153913162649, 0.031366366893053055, 0.09359621399198659, 0.009625537550164154, 0.0714820166467689, 0.09379160663229413, 0.046751882327953354, 0.03979604385676794, 0.046604580857092515, 0.09050001099240035, 0.029259554357849993, 0.018994060083059594, 0.04643078471417539, 0.0216700071177911, 0.02385756903095171, 0.04094057287147734, 0.044959818333154544, 0.07158026215620339, 0.019957221193180885, 0.046099820247036405, 0.004458141856957809, 0.02204342614277266, 0.055950513342395425, 0.03240650912630372, 0.05440170309157111, 0.060371776489773765, 0.04494454122323077, 0.06261299567995593, 0.01600119001523126, 0.02100062516547041, 0.018534091796027496, 0.04365058819530532, 0.03401358910195995, 0.07953969950904138, 0.03158865867590066, 0.016449886934424285, 0.04197737915092148, 0.03041600968572311, 0.032419140479760244, 0.05285179446218535, 0.03989821903815027, 0.01998035022552358, 0.04997783500584774, 0.0729571538977325, 0.016588514554314315, 0.03140629814879503, 0.024541999882785603, 0.07252257448271848, 0.04520927272096742, 0.07035017464659177, 0.02181580573960673, 0.045975436296430416, 0.07377932735835202, 0.032589155380264856, 0.0479865674424218, 0.03906921039742883, 0.01945790609170217, 0.022046977319405414, 0.05750671538407914, 0.03675772466522176, 0.07232591276988387, 0.03565400264051277, 0.028149607569503132, 0.020358554247650318, 0.0697204920288641, 0.009954138276953017, 0.05933605745667592, 0.11290007620118558, 0.017725167526805308, 0.012424358264979674, 0.08273314611869864, 0.01458211738281534, 0.04320665400882717, 0.06734072128892876, 0.023980633814062458, 0.03316569280286785, 0.014155381541058887, 0.04786418729054276, 0.03616342022723984, 0.006740835042364779, 0.025901445587805938, 0.021908511116635054, 0.041750912787392735, 0.10089261661050841, 0.046444540421362035, 0.02985148021252826, 0.043535299264476635, 0.014847252423351165, 0.048355310937040485, 0.037412239544210024, 0.02680676927411696, 0.010878720695473021, 0.00409450758525054, 0.03347635210957378, 0.03392797865672037, 0.021952084462100174, 0.0373134262918029, 0.048918975808192044, 0.049782353307818994, 0.009034820468514226, 0.029897549029556103, 0.03419829852646217, 0.03360052825883031, 0.029063514193694573, 0.03688970078655984, 0.10064235699246638, 0.03229417765396647, 0.09381198600749485, 0.02116976618708577, 0.025593597165425308, 0.06407727531041019, 0.03091364382271422, 0.029869724057789426, 0.04143104342801962, 0.008661283627589, 0.00653359818898025, 0.07587714877445251, 0.04878037601883989, 0.05467944443807937, 0.06502810007077642, 0.024471301039739046, 0.040486731013515964, 0.042211044346913695, 0.10425392218166962, 0.04567652889818419, 0.045909344335086644, 0.048234986534225754, 0.07546227338025346, 0.014364059552463004, 0.015094851441972423, 0.03197293161065318, 0.05073662534414325, 0.01021768697683001, 0.011818480961665045, 0.09748354641487822, 0.050199106335639954, 0.0403813312004786, 0.009523786320642103, 0.059957342673442326, 0.04272772384865675, 0.06812704901676625, 0.021700706056435592, 0.052909681980963796, 0.05134743514645379, 0.037457748039742, 0.04618025050149299, 0.07875806957599707, 0.04312830547860358, 0.022756578109692782, 0.008981143710116157, 0.021165649122849572, 0.037097439053468406, 0.01835636041505495, 0.012170021473139059, 0.08148799301125109, 0.0375227490440011, 0.02261531957628904, 0.02009417898079846, 0.01984943351999391, 0.014817057217442198, 0.050020820199279115, 0.022194430930539966, 0.011120018880319549, 0.05712482103263028, 0.04468513834581245, 0.02997682153363712, 0.01066160446498543, 0.026568884968583006, 0.05280658653646242, 0.03830686517176218, 0.004951961354890955, 0.01674830637057312, 0.05983980132441502, 0.08437154843704775, 0.07623581390362233, 0.019546570474631153, 0.02309648545633536, 0.03759412880754098, 0.03393135542864911, 0.036887374153593555, 0.12731599796097726, 0.054630080485367216, 0.03914498367521446, 0.04007189272670075, 0.060164617098052986, 0.05614519723167177, 0.02829277713317424, 0.012610200392373372, 0.0739834105479531, 0.07032253706711344, 0.03878749113937374, 0.04584750487993006, 0.003066018925892422, 0.0956796451646369, 0.035179540209355764, 0.017099793076340575, 0.0016971355375972053, 0.0283742538158549, 0.025857326763798483, 0.05210811425058637, 0.06549835452460684, 0.05608105711871758, 0.04884294648945797, 0.06799352922826074, 0.03203630360076204, 0.01966041778359795, 0.11719138929038309, 0.0026645260777513613, 0.04838928274693899, 0.09529947259579785, 0.055482028910773806, 0.012322017028054688, 0.040972351634991355, 0.044080536608817056, 0.053386430226964876, 0.05679371926817112, 0.0026583094313537003, 0.024783717381069437, 0.017375552888552193, 0.013758947588939918, 0.022657095069007482, 0.034341488499194384, 0.04008454634458758, 0.06572234211489558, 0.03578231255232822, 0.03876118942571338, 0.005471944805321982, 0.00493874741550826, 0.03212552459444851, 0.0493679974169936, 0.021099135992699303, 0.04574539649183862, 0.08297488588141277, 0.024308240062964614, 0.036263276197132654, 0.029739874189544935, 0.04817275003006216, 0.03542574770108331, 0.04557402717182413, 0.013585695996880531, 0.04421990081027616, 0.07228297210531309, 0.054829985383548774, 0.057302828863612376, 0.057685751089593396, 0.025953872755053453, 0.04859662767557893, 0.05994784318318125, 0.048415487981401384, 0.062326682527782395, 0.0751893114647828, 0.0515386086772196, 0.08342971850652248, 0.03874857291521039, 0.0240736007981468, 0.03813254581473302, 0.0028313175062066875, 0.024702639602764975, 0.026583649996609893, 0.035479642465361394, 0.07394062573439442, 0.019593863835325465, 0.05645447614369914, 0.0477753188170027, 0.029169299923523795, 0.00961857342190342, 0.03123021248029545, 0.04734125148388557, 0.0689716353372205, 0.039079025300452486, 0.05992333004542161, 0.037248414155328646, 0.05299171527440194, 0.04236310298438184, 0.07021669938694686, 0.08494800422340631, 0.006204167184478138, 0.01912449995870702, 0.05282906990032643, 0.0340872992092045, 0.0662559611373581, 0.027214236179133877, 0.014775807721889578, 0.024706964468350634, 0.023894720943644643, 0.09068139930604957, 0.01672477286774665, 0.04767917358549312, 0.015405745452881092, 0.031272874839487486, 0.030871914714225568, 0.02039446491835406, 0.07272909933817573, 0.007903603727754671, 0.049798524705693126, 0.08167505875462666, 0.010538459900999442, 0.05709979210223537, 0.0030654303100163816, 0.007392145234916825, 0.04327633425418753, 0.01947840049979277, 0.029800040101690684, 0.03695847190101631, 0.0149443373993563, 0.010995442899002228, 0.03795656033616979, 0.06168904779769946, 0.024875441267795395, 0.07495733094401658, 0.09253479438484646, 0.03960744557844009, 0.026032885507447645, 0.0231789176541497, 0.03106860982370563, 0.06169589782075491, 0.06772578461095691, 0.03621595315053128, 0.040274280108860694, 0.01701665769360261, 0.05990745179587975, 0.007204407384051592, 0.024704706484044436, 0.02337650705158012, 0.010029323402704904, 0.06530535902129486, 0.02959577879664721, 0.025848138975561596, 0.06703951323288493, 0.008108943002298474, 0.00901672690815758, 0.019196191424271092, 0.04530197067651898, 0.03864554797473829, 0.018859729498217348, 0.022961364484217484, 0.13534652563976124, 0.06170941604068503, 0.09717539927805774, 0.12336898944340646, 0.141174002783373, 0.1302343897987157, 0.12135529788793065, 0.10348428535507992, 0.17693640722427517, 0.14755371201317757, 0.09817222235142253, 0.14437749807257205, 0.1735478945192881, 0.12469863606384024, 0.17498068482382223, 0.08777107461355627, 0.10956137644825503, 0.1823235087795183, 0.1672758857603185, 0.19180126895662397, 0.15430560830282047, 0.17052493407391012, 0.13058354059467092, 0.11244853129028343, 0.1849179234704934, 0.12215935552376322, 0.17564757872605696, 0.12062225636327639, 0.19902744214050472, 0.1384171171230264, 0.12610637146281078, 0.08138249671901576, 0.10611228964990005, 0.11306038009934127, 0.07241228391649202, 0.19134630274493247, 0.13047061540419236, 0.14005435426952317, 0.16176091216038913, 0.2868472313275561, 0.20234748430084437, 0.21176027687033638, 0.11350719010806642, 0.17722951102769002, 0.04790835620951839, 0.1129267860960681, 0.18647491961019114, 0.12177026233985089, 0.1218044085544534, 0.12930058990605175, 0.11104963487014174, 0.1718170428648591, 0.13178236142266542, 0.10629025666275993, 0.12378157902276143, 0.09948708539013751, 0.1939532597316429, 0.09261332103051245, 0.11598093900829554, 0.11897509670234285, 0.1048731108312495, 0.10266772253089584, 0.11990379061899148, 0.15775441308505833, 0.17527218558825552, 0.14991010510129854, 0.08460979268420488, 0.13848563219653443, 0.0907807431940455, 0.1489412461523898, 0.2639993838965893, 0.1250657023047097, 0.1534220518078655, 0.09683132477221079, 0.21228818135568872, 0.1273071367177181, 0.1778095736517571, 0.15492218459257856, 0.09939157098415308, 0.1279430533759296, 0.1549985515885055, 0.13605874992208555, 0.20528111985186115, 0.1973241538507864, 0.17083262850064784, 0.0768120470456779, 0.18339619418838993, 0.16672972444212064, 0.14901148300850764, 0.20927212288370356, 0.14615837048040703, 0.13919695105869323, 0.16593988635577261, 0.19369552668649703, 0.10948358452878892, 0.15782085014507174, 0.08003086026292294, 0.1262622224749066, 0.13312204187968746, 0.1809961925027892, 0.20708765572635457, 0.09162945585558191, 0.09251925381249748, 0.09033756970893592, 0.13370626053074375, 0.11045273291529156, 0.06569389559444971, 0.15253514080541208, 0.11075384449213743, 0.12787217827280983, 0.11410635561333038, 0.20959471963578835, 0.054687674855813384, 0.1737864504684694, 0.17136105248937383, 0.2672287356108427, 0.08516719753970392, 0.1180138744530268, 0.12327096657827497, 0.17932975926669315, 0.10928317497018725, 0.22093823907198384, 0.1493287066114135, 0.15936954907374457, 0.14361145324073732, 0.10151728230994195, 0.17832359997555614, 0.14894866762915626, 0.12387244758429006, 0.13718852133024484, 0.20991700468584895, 0.11374481837265193, 0.18129325937479734, 0.09985983648221008, 0.09283494859118946, 0.27184400358237326, 0.1280660420889035, 0.14746532222488895, 0.2021378869540058, 0.1773517279070802, 0.1452040724689141, 0.11506047550938092, 0.12128887567087077, 0.2120567500242032, 0.09563997737132013, 0.12627494288608432, 0.085266949608922, 0.12787758110789582, 0.10138926925719716, 0.22998307482339442, 0.281918509863317, 0.12250863990630023, 0.17829836695455015, 0.08931575110182166, 0.1724319567438215, 0.12769894616212696, 0.13627754990011454, 0.18060745554976165, 0.20655805914429948, 0.09074808127479628, 0.15872655232669786, 0.1491281931521371, 0.12757365679135546, 0.106505716976244, 0.10458975884830579, 0.14537392038619146, 0.14641674177255481, 0.10032622434664518, 0.1006772973050829, 0.08915751779568382, 0.16820054239360616, 0.1840455288765952, 0.10778442258015275, 0.13424166070763022, 0.0981659215176478, 0.18026456848019734, 0.22898675641044974, 0.13098489405820146], [0.045804341571056284, 0.005039891475462355, 0.021055460601928644, 0.057340604180353694, 0.10268801284837537, 0.033106387782027014, 0.04103435065189842, 0.05682029186573345, 0.026272096401953604, 0.03186746129358653, 0.0548902440641541, 0.00356031594947126, 0.01657096276176162, 0.05635461275232956, 0.06159142569231335, 0.03270935732871294, 0.021828249700774904, 0.043875084156752564, 0.017708007217152044, 0.038729666703147814, 0.07431981866830029, 0.02610612806165591, 0.10331700526876375, 0.0042071108691743575, 0.03571386056137271, 0.055849985728855245, 0.011446997086750343, 0.0276676253270125, 0.0240577095610206, 0.01225069199790596, 0.0035721930953513947, 0.04598000792611856, 0.04875999664363917, 0.06966008120798506, 0.055854668680694886, 0.07629735278896987, 0.02602110391308088, 0.047863207655609585, 0.038105572457425296, 0.030413113454414997, 0.024284418977913447, 0.013612141501653241, 0.04112552720471285, 0.035398284526309, 0.009612270732759498, 0.06497390844742768, 0.042280249617761, 0.03482531312329229, 0.07119369227439165, 0.040782198557280935, 0.040646381821716204, 0.06466150880442001, 0.05111748439958319, 0.08222256336011924, 0.030010908376425505, 0.034501417612773366, 0.02156902864953736, 0.09745999064762145, 0.11009638328687288, 0.014039677007531282, 0.07190053598606028, 0.029762554222543258, 0.075749825919047, 0.03265945160819683, 0.05568492095335387, 0.028188136166136246, 0.03419784581637941, 0.05708674143534154, 0.05896023387322202, 0.05283560079988092, 0.03701346133311745, 0.0746639228600543, 0.04244570402079262, 0.039923043877934106, 0.050170555914519355, 0.05933695545536466, 0.014225913400878198, 0.013721656523557613, 0.018436889004078694, 0.01754806326061953, 0.020342529423942324, 0.006561677810168476, 0.047438925539609045, 0.07609995634993538, 0.038316724603646435, 0.016806138228275813, 0.06844177158200182, 0.024421475100098178, 0.07992437691427767, 0.023756191658321768, 0.030634744725830387, 0.023892305252957158, 0.057891819524229504, 0.090478221536614, 0.057346515386598185, 0.008133192677632906, 0.08062411827268079, 0.036888669201289304, 0.05394002786488272, 0.10293908882886171, 0.02770656210486777, 0.04771035863086581, 0.05696919637557585, 0.025019505119416863, 0.02962084112368757, 0.06781093121389858, 0.020826402287639212, 0.03856745548546314, 0.026604300255712587, 0.02479320202837698, 0.012918528427690035, 0.05258671415504068, 0.007575439476568135, 0.05557913893426303, 0.0525908924464602, 0.05442263536679093, 0.004923990272800438, 0.07850600653910078, 0.06424589868402109, 0.02969240642414661, 0.06629513169173151, 0.01158778342869482, 0.040470574458595365, 0.05756803904660046, 0.0642526225419715, 0.024403557799814735, 0.046602606744272634, 0.05097165980259888, 0.02028099239396397, 0.03608880841056816, 0.013489262255461654, 0.0710232877463568, 0.029152404931664933, 0.11766594077926129, 0.06817564484663308, 0.05231918104982469, 0.041456168837612495, 0.013483753664331743, 0.04601481094141491, 0.02255410909128841, 0.04414102906594053, 0.04589327312714886, 0.018092653081112076, 0.053843919740756974, 0.033469379632151686, 0.01712868303002324, 0.054580148789682426, 0.030517290579155087, 0.04351535775640514, 0.026620649769029114, 0.028085252233722713, 0.01789116740837926, 0.026593268230499234, 0.02797469078359427, 0.03354721608047839, 0.02596936323243426, 0.06628652277868241, 0.016863702912814915, 0.050082915695384145, 0.024792686235741712, 0.07200491163530387, 0.01546766005048994, 0.02924545911810128, 0.03127852258330677, 0.017095306793635245, 0.043781662607216276, 0.015616555283486377, 0.03541891623171978, 0.06272212107433006, 0.04029947602248285, 0.029573638676083647, 0.06528615223942325, 0.035122873523505405, 0.028439566522138193, 0.0032430487453893875, 0.02475760120432824, 0.016891420273168478, 0.0921766710234806, 0.04626923400792293, 0.020205809123581275, 0.045913351932540536, 0.02469158345775213, 0.04727846579044126, 0.06586591800441965, 0.009379795756103704, 0.026632598346623126, 0.02408916363492608, 0.031206545390887186, 0.03518046418321319, 0.06363757507642731, 0.022835583440610208, 0.012132012379879598, 0.03811145397776272, 0.09907258106977679, 0.061163889258750714, 0.08819682989269495, 0.06740199300111271, 0.02048849688435439, 0.03868117477395572, 0.02548521206335863, 0.017348312358080875, 0.07636007911060005, 0.0442549709987361, 0.04311408592911903, 0.04852321813814342, 0.03883345976646524, 0.042447833984624594, 0.03230417067243252, 0.022539711426361464, 0.08343931447598152, 0.03358300615218468, 0.0674172886647284, 0.03531251823005732, 0.0364754450856708, 0.0115324136459094, 0.058136438819929026, 0.011957404512941139, 0.026657621710910462, 0.03551476831489708, 0.02280242057167925, 0.04340257357398514, 0.07029639120446518, 0.01442359742213739, 0.022547207117895596, 0.06391353526851162, 0.07892004330642521, 0.02364958399994066, 0.04822036251425743, 0.10067403185530566, 0.035067089993390255, 0.04322478467656765, 0.012696704197878717, 0.05435565653897356, 0.06514059481560253, 0.04170909276581369, 0.0654651656805072, 0.01604596749530174, 0.04538121720543131, 0.01174573657408473, 0.03645436809165403, 0.03815223870333284, 0.005330666790541727, 0.043867658969247714, 0.09052249064552598, 0.07382661700830795, 0.01617642406927189, 0.010805044912558515, 0.016406133618147578, 0.05419193134002853, 0.016752993033151142, 0.028871767353848554, 0.012781023306160932, 0.029789139807689935, 0.02817279597365996, 0.08488003833917901, 0.02741465315921232, 0.01994892954826355, 0.060225243141758256, 0.08724547078600153, 0.0268114967548172, 0.04386244167108089, 0.042021796689368784, 0.13009667687583715, 0.045651095497305505, 0.0998146842175629, 0.04525618758634664, 0.004040425428684102, 0.06645130924880505, 0.031318836045102216, 0.050823434357880615, 0.05589542743109632, 0.06573460239451379, 0.05161548775504343, 0.04197222864604555, 0.03748006442037877, 0.10530965693760663, 0.02189510421885643, 0.06046074515325017, 0.02592856366391061, 0.020349464793980587, 0.04656005941797048, 0.023037223108985927, 0.045514224912039936, 0.05144793678482529, 0.0515434994304087, 0.057006203569471836, 0.022868239793751854, 0.09923649922711775, 0.04677625445765443, 0.011286965000181226, 0.03805111366091296, 0.05312620727636386, 0.031158736237557605, 0.010440843361720908, 0.006060878877178766, 0.0328757319948636, 0.09659961884608492, 0.03540853729646187, 0.06689240472042002, 0.05814722964714747, 0.04978947421477642, 0.02579265787062468, 0.03816879601799883, 0.04235690976202022, 0.01803106966690393, 0.05564926817896776, 0.015734245062049013, 0.017099459109886084, 0.02029115981713403, 0.05650298291584477, 0.027968224821961485, 0.03619607843575068, 0.07156522624427453, 0.025026542534760665, 0.05599848576821387, 0.028679571514658164, 0.02664011815795675, 0.02013844994507963, 0.022650981627521105, 0.11221324821235612, 0.00670289181471162, 0.03600229996663984, 0.08559093417716213, 0.04655299046135042, 0.039458114333683625, 0.030334837283589877, 0.05656929381075315, 0.023787504724168684, 0.016872057640284766, 0.058476453777984716, 0.013772418496955652, 0.027842495728691574, 0.09669197170296684, 0.07727404139586724, 0.027110788214486092, 0.027407786437834147, 0.018351026228629053, 0.0661218624736648, 0.02659962101461133, 0.023256852437043563, 0.1740866046748124, 0.05188670191273559, 0.03996886036475189, 0.0258124175525154, 0.01773021969711408, 0.03679032721265685, 0.02609315160952974, 0.12923428643262014, 0.10154445975786075, 0.028340118733467534, 0.014865690154692857, 0.02808661593007855, 0.13809315481921658, 0.16981138876872137, 0.14189865061780438, 0.13416737172519788, 0.2258898928994313, 0.18189680355135351, 0.14999457634985447, 0.2416555437957868, 0.10099094375618733, 0.09974924905691296, 0.08735455907299183, 0.14061721391044557, 0.1087272766744718, 0.20197244739392772, 0.08014954451937228, 0.09113825057283975, 0.10922351371846162, 0.26693508261814713, 0.10967037567752413, 0.254237856133841, 0.17801494075683877, 0.0572554167592898, 0.15414619498187676, 0.07167025498347357, 0.12278606212930754, 0.17645552521571517, 0.16293329768814147, 0.1327881941688247, 0.15244274341966957, 0.1651661825599149, 0.1187440735520795, 0.1486440160078928, 0.08676194673171267, 0.10488613552297466, 0.1885573859908618, 0.16117620369186625, 0.1577459229156375, 0.13754625135334209, 0.0877772641251795, 0.1694373314967379, 0.1194032268540468, 0.1467456467798911, 0.12968999479198828, 0.13045338273514062, 0.09661746749770828, 0.11531500989804044, 0.13998816953971982, 0.12895949883386493, 0.24499222490703687, 0.18995614140294492, 0.12107272516004741, 0.1825407799333334, 0.2683888311730698, 0.15186072152573615, 0.11846825436805375, 0.16010770399589092, 0.13317507575266063, 0.2922951296204701, 0.1751452189637348, 0.10502964461920783, 0.2541015384485945, 0.1467534393304959, 0.2714519714936614, 0.1351368095492944, 0.1765089004766196, 0.09648672334151343, 0.14351124846143648, 0.24527989618945867, 0.14052883896511048, 0.12126964662456885, 0.13941635959781706, 0.18273703346494585, 0.12462223938200623, 0.2493987267371267, 0.145594100758899, 0.133144143037498, 0.0869122613221407, 0.13172193575883284, 0.2758802776224911, 0.10274690226651728, 0.12081966022378765, 0.1249442869448103, 0.2255348049220629, 0.1408958013053052, 0.17572404962265864, 0.12743046681862324, 0.19035195844480768, 0.18852652749046683, 0.19693259673658758, 0.15395013440866023, 0.0750367555883713, 0.16774467076174915, 0.15604101674398407, 0.2965818636585027, 0.18676832027267665, 0.14087687653955072, 0.18568617990240455, 0.12823105120332912, 0.11008421206497587, 0.2465913601918146, 0.08525398428901099, 0.16044610849348828, 0.09949573141057044, 0.11448430916061625, 0.13294630130985752, 0.152691941766534, 0.07816188750439323, 0.1637515748734586, 0.1922950940206647, 0.10454186063725501, 0.06492660395451821, 0.11941019562073052, 0.088005422585411, 0.1892061863327399, 0.12410424998961389, 0.11141184746520594, 0.106664581107907, 0.10597160071483813, 0.148626085720025, 0.09069780819118023, 0.1750869009993039, 0.08399659316637553, 0.1690433401381597, 0.1258075679652393, 0.18097377964295447, 0.1474954088917002, 0.1340869822888635, 0.13940708275185898, 0.06731652727467008, 0.14465317624853924, 0.10771498724352568, 0.13699970411835238, 0.09644796096836217, 0.2734595106448978, 0.181259076052811, 0.09579584322636947, 0.211848666658625, 0.1517611401504837, 0.20859017822658643, 0.10687869813409634, 0.2912910038139671, 0.10089869479998015, 0.08914225923945196, 0.19348966976394877, 0.09952411855920218, 0.20663285278715193, 0.1746028129127808, 0.07729556367849, 0.10429576446767896, 0.29504193691536784, 0.143915748631116, 0.07790043629938737, 0.08882095382432453, 0.24518749880371615, 0.12753844930557534, 0.09035236813360825, 0.16980424930807203, 0.10974719538353384, 0.18619113718159497, 0.11477939449832775, 0.1341521873837337, 0.14003729971591383, 0.14169760281220078, 0.1987915430800058, 0.308650461374782, 0.08045980677707121, 0.09680442934040911, 0.15606298431521282, 0.1163529405312147, 0.07890711509389803, 0.07940304785734043, 0.2916564076440409, 0.12688810529652983, 0.1063322696427349, 0.09738415799802169, 0.0863296160241589], [0.04019645479274914, 0.058468523930059746, 0.015176301221799804, 0.01971181707631331, 0.020651231316151097, 0.05604401281743776, 0.05640849638439249, 0.07410578327835537, 0.01977554158656858, 0.027627820236375555, 0.05182522982067894, 0.041118621520581655, 0.054064070427557454, 0.10054969243356027, 0.06457771291024983, 0.05867550149559975, 0.015195232481346466, 0.032448759593535215, 0.08912856661481783, 0.02202062365540769, 0.02701631652598735, 0.007321449638766353, 0.034579736457089894, 0.06157656047435012, 0.03441038577875588, 0.04287442789063789, 0.0448417537700152, 0.0016647607367303863, 0.018935823754873127, 0.05787678361230064, 0.020757677557412535, 0.015921872982289642, 0.031042254304338712, 0.028917808340338524, 0.02050177576165879, 0.036352330207591876, 0.011395750861993292, 0.051057114396826364, 0.07292821013834327, 0.018230557107017376, 0.04254975312505849, 0.1255779920029454, 0.03705674709635787, 0.03681983500428032, 0.04901767031697091, 0.03302557161077857, 0.011738203775166767, 0.06839911293354817, 0.02653457733686082, 0.0027641125552690937, 0.015554254769085674, 0.03143429938063491, 0.036187870282446966, 0.05222109881287906, 0.042017080340883695, 0.055434735550079495, 0.055337443700409494, 0.028013230512442533, 0.04873365782259498, 0.02046665918896906, 0.09086116231628694, 0.06088247428124305, 0.038449027269962244, 0.027152988586749416, 0.015971450302458834, 0.030504432870657183, 0.021981978170515504, 0.025583917704352643, 0.04221532653900795, 0.0298942520385026, 0.04706220395746641, 0.11380195632227696, 0.018021917130681686, 0.023283937116502784, 0.010029966288129799, 0.012360826713120332, 0.019116132243652828, 0.09407555233337916, 0.05102856026496738, 0.022787818816141225, 0.039498464902862906, 0.07390921062324196, 0.05151719771674834, 0.03195323501131497, 0.013419483675534138, 0.03577092800696846, 0.037100307454238646, 0.04295591941627208, 0.009886150128295412, 0.09897936732158996, 0.08180645600077696, 0.015246807106450433, 0.03209475144103635, 0.04629107912478503, 0.06096223289205227, 0.15303313673939556, 0.013055459312454332, 0.02971055007947143, 0.05026933205954265, 0.021373660129029304, 0.012033760376652936, 0.03944905271055177, 0.05858461809111759, 0.050270497231394984, 0.02526289059460396, 0.048451304028276354, 0.06740671306033619, 0.03268272164859809, 0.05423058239102829, 0.026034082220576238, 0.07639916060725227, 0.01312862579652574, 0.07459227592335083, 0.07370035542408004, 0.03941368566302117, 0.013356138588278554, 0.04918717313557863, 0.01278476836887421, 0.05726920957386028, 0.019987949817732442, 0.03035872145119356, 0.09100470851990394, 0.014087783947616117, 0.03443506589974277, 0.03234230222005863, 0.061942175816511735, 0.022502036299556494, 0.01804877359973034, 0.034225735726067796, 0.00930395475734258, 0.031143332962528802, 0.004997847881895723, 0.033623601630097255, 0.06612284953007475, 0.010425133023090893, 0.06822881972766481, 0.07983176430570893, 0.04400114165036939, 0.09629094478441402, 0.04788404345163144, 0.04081491984834429, 0.04017046478111297, 0.03518402278132271, 0.012507770097727189, 0.008022396523301722, 0.056148047078750096, 0.029177875439927448, 0.07534401214797981, 0.04164099329500459, 0.04950316848407965, 0.07095627923263237, 0.049751416881917976, 0.07714779465459287, 0.03015305192093365, 0.055631946452194825, 0.07677779693040065, 0.04799171794729773, 0.011728152312571183, 0.04108257911866531, 0.009766464900167193, 0.007407696475638659, 0.007364975208474789, 0.06200513591466006, 0.0690895329171326, 0.05050913481682073, 0.022285972991085146, 0.031216987408697605, 0.028831498420913704, 0.038532849139301106, 0.07132232873118483, 0.04797478213731665, 0.03306549544504378, 0.07611510358401574, 0.05506587702257093, 0.010465545747138094, 0.038058932186686434, 0.04299068903492298, 0.03876918235619087, 0.018217608485429082, 0.039186588473967277, 0.047167180746328086, 0.0526226526562823, 0.029066968891129363, 0.0497103575617075, 0.023684717270953115, 0.07666175471968018, 0.05611801978375297, 0.09052683963091113, 0.14543173369020224, 0.017305714936810546, 0.02879652656702092, 0.11593673669267446, 0.02811029971780954, 0.03421823632379528, 0.03954050385800656, 0.031717228339402936, 0.025433150403841864, 0.01215594293171307, 0.03138544379908126, 0.03820566591457464, 0.013557622405642178, 0.04834338091313839, 0.04220017930492759, 0.03812509836279787, 0.03345864446600899, 0.06130647438112646, 0.08334047524840571, 0.03686448631924577, 0.04217355846776627, 0.0694467879657168, 0.02372231632762123, 0.00524380721799389, 0.022995633153186645, 0.0223604345228523, 0.02729670362896286, 0.05960859634797089, 0.03181431980920024, 0.032303016632795334, 0.04769416496856138, 0.05687948927516118, 0.04123818151128944, 0.06380823193467222, 0.04521901340922341, 0.07297410455066711, 0.05790089227957651, 0.04669524161727168, 0.08719471530639566, 0.043971849081572145, 0.022541425787494518, 0.02653043429745594, 0.048835421112016775, 0.029490735214494634, 0.05176448874408379, 0.03677374392282218, 0.002932404745479289, 0.01971543133549858, 0.00900844268471701, 0.0864819047274068, 0.02592709606688004, 0.05880250893824268, 0.007043699479254428, 0.04106211810722016, 0.01609062252100557, 0.0793359280214645, 0.03402308859222103, 0.042622472465154715, 0.055480385053670034, 0.08641292210086249, 0.03571078064851463, 0.007446878162227222, 0.03880556614603847, 0.026864897990890313, 0.02009017323871376, 0.043898094445466995, 0.08593581020249985, 0.0029001788379900972, 0.05030806474678684, 0.0755626117461361, 0.01825465093133971, 0.01519952302260208, 0.05507561771082692, 0.010189199638261925, 0.048590300866635516, 0.026289566558261868, 0.04152984925894998, 0.06109002330049407, 0.05686124357453082, 0.06014467558998149, 0.030978670802142005, 0.04590340344293509, 0.023033328689052723, 0.0401859719568165, 0.03390731355466414, 0.03493531054118648, 0.0334657022904139, 0.054208648216445, 0.020162502951279748, 0.06503547701868229, 0.03275887713243719, 0.019425466816755943, 0.07212015974801034, 0.04146146777202375, 0.07533260533818975, 0.010268425758113153, 0.0446216958516743, 0.06811701518017799, 0.06633697397774085, 0.03683156093757134, 0.026932431574095972, 0.01733489061734872, 0.031881847826298326, 0.060876180868945085, 0.03794649681367446, 0.0412105921714101, 0.051658524898812175, 0.030831393451080658, 0.03308508814370725, 0.03679756686324254, 0.0497184135747375, 0.010963917393382872, 0.06378019359544851, 0.03193323784216773, 0.06242690215003677, 0.01878665578260552, 0.07611646913574077, 0.046046021961956285, 0.0811801798408851, 0.019417082403379027, 0.027831812512886245, 0.05091093356895726, 0.11262152591370977, 0.04345520668721292, 0.05950356389803346, 0.048398930666735396, 0.03442182969592977, 0.07059898707666434, 0.08272668943391182, 0.05917554204643238, 0.031200315061141737, 0.04034891418996267, 0.03995419552666135, 0.055459304348914884, 0.06787103033275343, 0.013258891267469153, 0.055941815371625125, 0.03768293419852853, 0.0522154696227517, 0.0013047351581008115, 0.11994207059615292, 0.008621942379249958, 0.012518841085693566, 0.09011570466100238, 0.017501100155641325, 0.047253659504349343, 0.03752125732717104, 0.05378346439101733, 0.019002474182343576, 0.028295100055402145, 0.005193669112486532, 0.03156356295221485, 0.06330150834401138, 0.024127588330884464, 0.07451146346284077, 0.042483145371079445, 0.04610426571161952, 0.0309420439589303, 0.019595997509895824, 0.04620375060767401, 0.047698632697574794, 0.061535289642051794, 0.1466449224972166, 0.02873959641874535, 0.12957248312886804, 0.1564126249286346, 0.18263347417814657, 0.127591245691292, 0.14495266252197325, 0.18300965399248526, 0.13322505197720602, 0.23284372757188976, 0.07324037229409441, 0.15314337535528466, 0.10266900644637644, 0.12880952563136816, 0.17740140727255493, 0.19154542096657678, 0.13769082172075287, 0.20041138428496197, 0.06907896473421715, 0.13597292796475813, 0.1690009783487767, 0.07456221894244663, 0.17772487975889817, 0.06737207702826709, 0.1677530273445882, 0.1372499266290106, 0.12467874650610611, 0.11416217254009098, 0.15700606105383486, 0.10573271079920232, 0.09387762154801749, 0.15838948369491845, 0.2282835269579664, 0.09610937093384564, 0.08417408520472236, 0.09873045841231942, 0.1303367764921859, 0.07008094573393464, 0.08443968501524068, 0.10374498699093238, 0.15000496641732752, 0.21240889909677207, 0.13682924763998017, 0.23508017475251108, 0.23279289045603946, 0.09846543005551212, 0.16284278535749763, 0.20800885395146906, 0.10764256105176173, 0.16832097811857238, 0.16016165813198313, 0.13532736338675022, 0.10699495556764305, 0.08164858634700067, 0.15437327732797712, 0.18218187731690705, 0.1356962404679507, 0.13745072210440412, 0.1348109176615253, 0.15644161321688443, 0.13091286120470613, 0.10444627943797968, 0.12866931909229606, 0.2260951857897453, 0.11047435909858905, 0.10998533573001623, 0.14559340314008296, 0.14205747022060677, 0.08826504810713232, 0.16911923215957358, 0.1752069656504318, 0.0672486430266872, 0.26654361456166953, 0.19443200435489416, 0.1780538441380486, 0.20446606358746067, 0.14881463575875387, 0.14540397736709565, 0.1544257768546231, 0.29792696179356426, 0.1786058090510778, 0.10424877909827046, 0.17838580679381266, 0.18531886133132502, 0.08812792890239507, 0.12286038079764694, 0.10685037035727873, 0.14160185091895983, 0.10559130940237083, 0.1742198201827705, 0.13300797378178686, 0.20181526051601395, 0.24746761395363137, 0.14047610195120797, 0.1052018377231434, 0.11802888810052536, 0.11942672324948944, 0.2660376182757318, 0.1857633632607758, 0.10867485136259347, 0.26208580064121634, 0.095502123440383, 0.07716188803897239, 0.11680637049721554, 0.12421029547112994, 0.08509063016390428, 0.17568035196745768, 0.11503469329909422, 0.15390130109153688, 0.12091077369404957, 0.2118386179790832, 0.1236899163632188, 0.2037264540558681, 0.1340355959837325, 0.12843306380091235, 0.09798126775422134, 0.13665107282577083, 0.14541502052452415, 0.08614737424068153, 0.10012341022957116, 0.13794034661259502, 0.10668410701327957, 0.17303377913776785, 0.3043082443764433, 0.13232029974460602, 0.09348979001515545, 0.1572374626994133, 0.11810967087512836, 0.11728701501851901, 0.11490080985822715, 0.16384101851144806, 0.14352735306601971, 0.21491680905455723, 0.11629124579485506, 0.141692066390533, 0.22581272438401356, 0.1733453624183312, 0.1253381447168067, 0.1802973565645516, 0.10242745964205824, 0.1724209581152536, 0.1651480296277441, 0.20014793670270592, 0.13352640846278518, 0.18007916514761746, 0.18269409280037507, 0.06757488372386433, 0.1382816009572707, 0.13468123477650806, 0.1538733666529879, 0.14042817405425012, 0.11890295252669603, 0.17023343330947682, 0.12221649347338825, 0.2560980641283095, 0.14457084238529205, 0.1106063426414039, 0.1522377919172868, 0.11785653172410093, 0.15266247850377113, 0.18163043190725148, 0.061318883090279996, 0.07941132280393504, 0.151199497631751, 0.14496760937618092, 0.13974179135402665, 0.28258967853616923, 0.12271897940081544, 0.1254648738540709, 0.12724216911010444, 0.07423202259815298, 0.11128396057756618, 0.07360757954302244, 0.1277826158911921, 0.17082263919292018, 0.18111558922100812, 0.2305225864984095, 0.16172934119822457]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03884715239109937, 0.019814428269455675, 0.05552935937885195, 0.03265008199377917, 0.056547448693891056, 0.025729905573825818, 0.0810242842999287, 0.039674880827078596, 0.04225008873618208, 0.04327124683186412, 0.023501163741457276, 0.025259315298171714, 0.03791869596170727, 0.059449928885442205, 0.011724237483576871, 0.07578503340482712, 0.013556440535467118, 0.03414104554394726, 0.025209593259205576, 0.0365869230881799, 0.046040697052376345, 0.11313695489661768, 0.01463629880163353, 0.03615846639149822, 0.0389457429992035, 0.013612371567433001, 0.019813224134850316, 0.07399194524623454, 0.041992719343397766, 0.02103601447743131, 0.012067336065229028, 0.0628531101392582, 0.007817084151611198, 0.04322984612372238, 0.04676171207393054, 0.04206821431580465, 0.06725884013576433, 0.02887201411795104, 0.014832814867986599, 0.04926287590933498, 0.013052431349933613, 0.06775984176783822, 0.03420817280129995, 0.009188856001856038, 0.04156995491939597, 0.04824048584850971, 0.026791618329298217, 0.03730035707121715, 0.059971020455122925, 0.047575324861099944, 0.023266663629328832, 0.005412784967120388, 0.03655944878119044, 0.05654677333950531, 0.0392148680111859, 0.015906601438473444, 0.07015752053121105, 0.04298045110772364, 0.036815638159168884, 0.03479282931948546, 0.023216451772896107, 0.014457067354669562, 0.05465202579216566, 0.06634579069213942, 0.04790952138137072, 0.051047566666966304, 0.023867023992352188, 0.057829761135508306, 0.04019984640763141, 0.06912445096531883, 0.11698908725520596, 0.03390365847735666, 0.01922291616210714, 0.044765075072064064, 0.029011495207669213, 0.028047009363945108, 0.0647734320955351, 0.031096731654542964, 0.021796259425173048, 0.08047394469031133, 0.026643088604032528, 0.052637439948739484, 0.026484641930437647, 0.041419755361857824, 0.03130201526801102, 0.04656857556256, 0.09199159423587844, 0.013792107674817089, 0.05179804495128337, 0.052532771151163615, 0.041499168873997405, 0.03752567310584709, 0.046504294441547245, 0.03753381075512152, 0.026423097478982527, 0.036583954497473314, 0.05751969183620531, 0.052038946087122895, 0.018957600223075133, 0.019660959551401902, 0.02847489831765415, 0.02998018346261233, 0.013904655297665158, 0.06884139584144577, 0.02022744643909391, 0.05283170452457853, 0.025243995514756534, 0.04781872332387138, 0.018788728229992557, 0.0387116993078962, 0.04871733799518552, 0.08150434994604439, 0.05878283831407316, 0.01798447763576405, 0.1010033005150035, 0.016495595809828956, 0.03815130359726027, 0.03513184237817768, 0.03721840170328505, 0.015805578441359103, 0.026881047124334145, 0.0436654422810534, 0.025426265128771774, 0.02065728353045415, 0.07342544908169657, 0.0425629633537028, 0.025180580851156265, 0.05265554464131128, 0.04527403994870838, 0.04257616987160873, 0.0316249905154109, 0.04717955605883617, 0.0360038139479002, 0.06301228597294539, 0.03877837756590452, 0.033843225392047316, 0.031430365997948684, 0.0073194722790503874, 0.04698827862739563, 0.02232827911939239, 0.03255116484069731, 0.04512680898187682, 0.014171178154356312, 0.023747170853312127, 0.04241070433636196, 0.008423963354289299, 0.04974254079570528, 0.04493026230193209, 0.034591017101774924, 0.02926202014350565, 0.011442025625001406, 0.020058413028891664, 0.02972916314320173, 0.04753159009851515, 0.0330858525558142, 0.037694682396249846, 0.022778191305405926, 0.008320368815475376, 0.05022595723858103, 0.051662610421772115, 0.035078199944109656, 0.03414396218431648, 0.10102617350639775, 0.04476751673792023, 0.051712438216782175, 0.03658274479676038, 0.04396498421556316, 0.04758208953717258, 0.023233305946632754, 0.04128668828343507, 0.05245358399406541, 0.0513463924289681, 0.07330260137678124, 0.037355884560383856, 0.015617239914718084, 0.050357681029709056, 0.024358576229133178, 0.006569903125637211, 0.05697218351997435, 0.007813080264895689, 0.020450818046811037, 0.023709299057372846, 0.034641442325664684, 0.025221363721357193, 0.03726755043317098, 0.02775049168121768, 0.020872563873126637, 0.021264720271574333, 0.02756279325694777, 0.005951160692347912, 0.031364726746687666, 0.051585126493591815, 0.027745697407226544, 0.04575588674924802, 0.009020163051900454, 0.004738915804409771, 0.052340825786814094, 0.07221736625069752, 0.0360321417247178, 0.035908459103666246, 0.033852888154797256, 0.012447015105863102, 0.04607808274158742, 0.03218938269128557, 0.008147843600454507, 0.03340909868711606, 0.03312672633910552, 0.03412487043533474, 0.039612165637663566, 0.03626942489063367, 0.03191070994944312, 0.012799420219380409, 0.061177774841780774, 0.026497998733248096, 0.03076400087593356, 0.025876767322188243, 0.022577367999474518, 0.04903009015833959, 0.05740467007854022, 0.02933954674517736, 0.06844288480351679, 0.013487379055732163, 0.04934752156259492, 0.03982552938396111, 0.037896861977060325, 0.06356885962304659, 0.02717143466725247, 0.05510955241334159, 0.03331821157189552, 0.015925338811939582, 0.06629957715631463, 0.025420494930585846, 0.05430877878097817, 0.09100601469981484, 0.07629311512573622, 0.051748528858297504, 0.02923632513557095, 0.0433908513514325, 0.031119626910367515, 0.013706044519494753, 0.010196846542385174, 0.05772203468950465, 0.027283526796963997, 0.055481294184573926, 0.03779531019972637, 0.10069157622638159, 0.046322416310431436, 0.022700466179230716, 0.009944074754457688, 0.05080065784568433, 0.03981016321631614, 0.033737691992428154, 0.022186994610819966, 0.025651948526501656, 0.03526582229824271, 0.018364716997893993, 0.03278283737017773, 0.04677755321608856, 0.03632173145888373, 0.04787858124473132, 0.036386320571182296, 0.03707194257003721, 0.058631399369915016, 0.04417238109454047, 0.0066268694536120165, 0.047122414398472756, 0.036182486001052894, 0.047606127700419165, 0.023680307058384642, 0.04096349410247058, 0.03791491100855637, 0.010666538819350535, 0.07739064021734521, 0.01327535581367556, 0.004047114962304477, 0.0488208527531242, 0.015105263773875777, 0.030020637932466343, 0.0216102957710973, 0.07481568463845178, 0.025676413424662314, 0.03803408137173392, 0.09115557972108945, 0.005194221084821038, 0.05530023612664081, 0.03392026774236001, 0.028201500390423462, 0.04556326231977437, 0.08464687038213015, 0.011205307419004384, 0.05468701434438117, 0.011537613318068907, 0.038833352155052125, 0.060707991651725024, 0.07106605771696195, 0.02485761302523315, 0.07565461579360999, 0.036591012321878225, 0.010941105629171943, 0.014814791811659234, 0.0456610773835564, 0.03222575534891803, 0.032805001610540785, 0.02418316220428096, 0.046544585638912395, 0.03760965082619805, 0.06671928393188864, 0.06101738188590389, 0.011505764978210209, 0.013661610282724723, 0.040743306308286265, 0.07971463113790378, 0.029514986745198257, 0.007751928687866894, 0.03391378137166612, 0.026388131191197317, 0.027333798025210854, 0.02074617241305532, 0.02168751809222158, 0.017112472669396084, 0.039202722764457576, 0.03989695367636159, 0.010051487643067958, 0.042905074878945015, 0.017525657822261564, 0.010583353341644397, 0.017829122007242404, 0.05470660333230626, 0.06383976578945294, 0.006756860793757369, 0.041747881114133634, 0.020603741286322474, 0.021281754416122567, 0.050063797971233726, 0.07887009676778689, 0.01482339979702374, 0.039959973146324046, 0.10864019306609407, 0.016542310295335483, 0.015331854447140358, 0.06605423055589199, 0.0756904689478688, 0.07040623648208566, 0.02067142144369427, 0.03375994157977402, 0.04970620895619504, 0.020840751712967176, 0.0766631870646961, 0.003910877057933249, 0.015318659989134176, 0.07666953242733143, 0.07335801012231968, 0.12245173944393173, 0.13201498019043356, 0.19720161042641848, 0.14264731435105205, 0.14815740461926907, 0.10370956428232603, 0.1782355218892917, 0.11635567905614153, 0.09194126178044826, 0.0893455112236552, 0.09924439567839727, 0.18377440748736262, 0.11668968261801638, 0.161693257978186, 0.09297146665630862, 0.11189975019078702, 0.12439020691090263, 0.11806045906268992, 0.08390011396841146, 0.15845547546632588, 0.19137702765874565, 0.14730893686646596, 0.10003194794990122, 0.1116088505659718, 0.13523452071240172, 0.10221671938779764, 0.13941649318439886, 0.18410555378068238, 0.1271524582989514, 0.11643062112852931, 0.12252022483153269, 0.13139688991941512, 0.11201414483366534, 0.13975575857330114, 0.09644409437896684, 0.10129067493835464, 0.21051020332379267, 0.10589041718048975, 0.17824090988142416, 0.15453472413355485, 0.11141610739286989, 0.15261394204571843, 0.18747975787846372, 0.11982047712081112, 0.18073298240778968, 0.19032104057259858, 0.1624735668883659, 0.1186806644545868, 0.12219318261486478, 0.16790395049611107, 0.1588761989842169, 0.15791179292136803, 0.13363551901420578, 0.10745593317551538, 0.23041424778057262, 0.10701085237087682, 0.2805599046405405, 0.203347617352847, 0.2316073392285034, 0.2077762203407474, 0.11005499371094629, 0.1383271094528027, 0.15552994416793808, 0.30716370209120214, 0.139688549679704, 0.10103527965839021, 0.1862745694234036, 0.20075407839613035, 0.12864426418673247, 0.4103979578940198, 0.18354971485678107, 0.12333108796156012, 0.05586542982200626, 0.15194971987511963, 0.0979849710711278, 0.21620425715809688, 0.13238382758572698, 0.20259871613234282, 0.11610287387156859, 0.18197511497419327, 0.09872858820017427, 0.21484538476215675, 0.07138869899790734, 0.1703720961813815, 0.12559635273646563, 0.08491883039823733, 0.19259777152910829, 0.15064319857629016, 0.09527942718705162, 0.2826286561321467, 0.170740527973976, 0.16409431351348758, 0.09367876307806, 0.0962011597584933, 0.12305080104852095, 0.0746725540375337, 0.19240822701249272, 0.09286247484851629, 0.0808143604081124, 0.12079075357178226, 0.11122552386950701, 0.12506107130320743, 0.2561664901440963, 0.2172661665827036, 0.1030907170206774, 0.11543172746314667, 0.16199039906496182, 0.13566021661972627, 0.12598209141287953, 0.12810736487153918, 0.15183461277047172, 0.1767146386555396, 0.12756914453348145, 0.1283137412974611, 0.16233681875746697, 0.1267967320745811, 0.13469208497554064, 0.1487413264112547, 0.14559625298716128, 0.14231260574888438, 0.14151402516290545, 0.11290369788184762, 0.07769913616357371, 0.14873760082991794, 0.27822849224321544, 0.11915459253941663, 0.09798413244425319, 0.14336121588712558, 0.14815577189438045, 0.16646427306113765, 0.14041068905498832, 0.1804933132370934, 0.07941478121210821, 0.1541389070916921, 0.0956683125696145, 0.14369439566507936, 0.07245561049785465, 0.15996258443919942, 0.1293517238809727, 0.2038194303167984, 0.1602153154090047, 0.14939045329811051, 0.15927581582218409, 0.10034663340775296, 0.15536633029114455, 0.12086412971257232, 0.1224613502563443, 0.09179522196063772, 0.07459874002961442, 0.1371170228230767, 0.10047267976915464, 0.10513426517718472, 0.14749971334822476, 0.11005163920344785, 0.14710423769429326, 0.1394699575030245, 0.14481466758297756, 0.19780577800702304, 0.14007403602590784, 0.11984172480879351, 0.10006947835790925, 0.22513100237119943, 0.12073836536728777, 0.08985898835817352, 0.23998388584004715, 0.1338332865270786, 0.14241404249332845, 0.11231414318899624, 0.11001061327988282, 0.1082114691962488, 0.17918879573699087, 0.2721804636530578, 0.17867321090307087, 0.14091506745899096, 0.11841601459309459, 0.18822759040631354], [0.03324180004710797, 0.09555646349326707, 0.05675133150361944, 0.06620139844017103, 0.045251281990204006, 0.028187907955725677, 0.01716365117317764, 0.028746233074343763, 0.03060497903788928, 0.025673576565168332, 0.025910141703207046, 0.028914815629832447, 0.045706396631430835, 0.023522621086158324, 0.045646000653505325, 0.04218086491164286, 0.025403959880350158, 0.03952672217565123, 0.008546698809368536, 0.047437021930818446, 0.02210376645962242, 0.05602380042546429, 0.13397631322732195, 0.038841745845275, 0.056092835002345964, 0.024042005716182757, 0.046719394813408144, 0.047855403972789645, 0.05346597361494787, 0.03920609953638632, 0.04853761209233198, 0.04145779043028597, 0.03919543116353452, 0.05609188876405824, 0.047703349046059884, 0.0446179999562446, 0.054041750336182304, 0.029312803453649394, 0.04565099530736916, 0.04389779758639634, 0.08503810837282799, 0.016634345884085633, 0.043193035598960705, 0.04381250255391933, 0.08276178559754044, 0.036738647759193555, 0.03434538848523516, 0.056038313123281114, 0.014093551362748258, 0.031284248252632096, 0.019948179979110137, 0.0430902778316522, 0.024612461238575634, 0.050278349153813906, 0.10163126135012135, 0.1079984505486209, 0.04699854624050204, 0.019589477742556483, 0.03261907506384887, 0.01535808936750982, 0.07407513257930987, 0.034335362070123665, 0.06064203327696305, 0.03436145227169618, 0.03828603679721709, 0.043939509996562265, 0.02032961605436867, 0.018930200130853336, 0.02177569636842236, 0.038723506877431646, 0.02668673245352693, 0.02577094448497519, 0.040225428238045424, 0.020730409196403343, 0.0334588411351433, 0.06033257996023167, 0.07532388510298915, 0.041151142431772314, 0.02820355428411858, 0.07381806004559621, 0.06187322287587449, 0.05257069118670188, 0.044365695721353404, 0.10301973801688291, 0.04131088971917052, 0.09970492799766362, 0.019511342579789925, 0.024124903611664195, 0.03843199127004482, 0.06303492147708312, 0.029549086575570982, 0.08555347798392177, 0.05656527508108411, 0.1045855731354095, 0.010574981915851822, 0.028017854092468042, 0.06511987405247055, 0.0645081588299945, 0.030374148846021853, 0.0055895028526720125, 0.024122467511915602, 0.029013287494308315, 0.03732089971890673, 0.019620386337919626, 0.028553890660987236, 0.030777212959947065, 0.015797515006852336, 0.02117370328051038, 0.058415827734279446, 0.03158312596497126, 0.05439316468255129, 0.030129290207696613, 0.023458731448045, 0.0301809492520988, 0.012721606035484001, 0.07695376014453359, 0.0072610694314789725, 0.10918135973042808, 0.02729210231336765, 0.026241454979754053, 0.02427915529551683, 0.04795373111846857, 0.016203527302423026, 0.03471169031399768, 0.04206396552035585, 0.03972766236984171, 0.04355486969870981, 0.045212204204290174, 0.04557551888865419, 0.04623880595318042, 0.07473565885447897, 0.018041697221633513, 0.0343092162074754, 0.01880472893390106, 0.014251003558456432, 0.006545735550389509, 0.005287249296088703, 0.015164554879447678, 0.07729996461421251, 0.07707838900387287, 0.04817105793335941, 0.05865885512321256, 0.009887939631880727, 0.006767277300241403, 0.04106162457901519, 0.01528776716440916, 0.03636866487795487, 0.04277291322068777, 0.045892660855315626, 0.05426226096460596, 0.04663100502511952, 0.05584854596236255, 0.07961904251715168, 0.0040575634739070665, 0.01881115407741163, 0.020367248507682234, 0.04540936315606814, 0.04210446451907046, 0.09493512261542492, 0.004079036589246243, 0.04429122862347867, 0.0674348181928508, 0.07562808401416987, 0.05181145927053876, 0.045754562015645206, 0.06590491786482744, 0.10017829205025919, 0.05098076224385295, 0.02531764253944857, 0.011701561161316931, 0.026595414892653935, 0.027025791896448936, 0.06450608823797666, 0.04889734220341779, 0.05638297392579261, 0.06055788486264646, 0.04579307948006317, 0.03650988444860559, 0.03253071125072893, 0.008777057737461291, 0.03463170905888546, 0.04432487388839945, 0.01629060905543156, 0.019691313391376752, 0.037444396803039126, 0.05482098684296943, 0.009953953667718451, 0.01962802303751232, 0.012626394054677803, 0.02204174146754667, 0.014853684060653904, 0.02966758158436278, 0.03019801679329248, 0.038220753776840866, 0.021518796384043526, 0.025638651095505338, 0.038180013580131344, 0.024064010394795332, 0.04757181821332779, 0.03036062691535335, 0.11651846914901398, 0.07382197116385214, 0.008290131863759598, 0.021603885470540263, 0.025490106527286116, 0.0144226660268032, 0.030634317990916315, 0.024961185299616773, 0.07319052965613082, 0.033310188955510966, 0.03726704577275086, 0.0717854882532265, 0.028426888784451876, 0.02482147785485722, 0.12663071363931522, 0.07591575529659167, 0.018321653878956567, 0.08413062503677793, 0.03830830493825488, 0.08141319936839864, 0.03368675468664151, 0.09650313222664408, 0.03212906463886611, 0.03777047422772739, 0.009146259508270305, 0.027879851731995586, 0.054198844445636496, 0.03287539802840911, 0.015907723936834373, 0.02929133868747158, 0.05722066569433082, 0.05050147956353612, 0.013567576461355202, 0.021597165323328227, 0.02415177306829719, 0.06010372017044574, 0.010157139786315383, 0.08123207080643624, 0.03828130189504009, 0.038460675277747214, 0.028549382113851607, 0.03880066426063422, 0.04430588232935406, 0.024782374093774706, 0.07359653638559394, 0.01054683039910742, 0.03861813303956296, 0.05688573815859854, 0.02772560932498891, 0.01486826540713082, 0.01436060578271281, 0.05148226482560858, 0.050267870028619654, 0.041863236838253215, 0.034841532760765404, 0.03987051095464267, 0.0033246212115045637, 0.05594230518909171, 0.09782814784557559, 0.12464111961890012, 0.03255218900449108, 0.04987669140973594, 0.030892967588442843, 0.045177434585639276, 0.05415501320385374, 0.0639960917760618, 0.06092034607718233, 0.04304602727643214, 0.005969789990558638, 0.08718770943232812, 0.024567685613874346, 0.03439841493673157, 0.05040247335273307, 0.05034563597291708, 0.030730786056665238, 0.028243491105968133, 0.04530215621343814, 0.06647352915024385, 0.08203185367165133, 0.06940574719919823, 0.03134472586680204, 0.03489146816718858, 0.044594340288313106, 0.023522166520706378, 0.02941572634881595, 0.031498636162723415, 0.06447466570534743, 0.02606085705338046, 0.029301420763658825, 0.023738309610052966, 0.04166582555626519, 0.0397818873898359, 0.05868124571861699, 0.04387863533338532, 0.04431267669133376, 0.0313616208586609, 0.03430271870456636, 0.025425886633456685, 0.04033797864394728, 0.08470313259749673, 0.015302666706702439, 0.09838217592914589, 0.019325931825733278, 0.025362805936310906, 0.025638775405241176, 0.030475513231067453, 0.05224717046075966, 0.019561090593924746, 0.056865726146497764, 0.02289101259520976, 0.050277992922929116, 0.05966256903775502, 0.017032797550200485, 0.023251033999258652, 0.059245637894491665, 0.036184964774292894, 0.09517307000351138, 0.015087275969563052, 0.0729285812121816, 0.0481571166892536, 0.1373320972197689, 0.03166551177855581, 0.05116019499837421, 0.011849142792925704, 0.06422414633561857, 0.036691506538772956, 0.023848644705140032, 0.07087444260832854, 0.02258929431263823, 0.05043333556386642, 0.05713324069802184, 0.01262883572053397, 0.007768764771753922, 0.07394683008897118, 0.015019397287687752, 0.04408661479828879, 0.03278136420703959, 0.04670928305131383, 0.03177324564603623, 0.020568739746522624, 0.016649717617838178, 0.03790216091147158, 0.04184401150268968, 0.04513760723057203, 0.05393187537265476, 0.008235640598286409, 0.027917237421206664, 0.05588718588114716, 0.015692026136093773, 0.059184484925935976, 0.029798489013046492, 0.0060337635841278825, 0.1132985798176378, 0.25857790606096387, 0.1962380058830604, 0.10528148501180112, 0.13013001414947212, 0.16119831969263032, 0.13269964110804722, 0.06944102147826925, 0.09291594658861868, 0.08154277835274115, 0.08790651656454429, 0.1153156407235656, 0.09482875058893114, 0.05180178537557367, 0.15929138608044013, 0.10916933693806641, 0.14464994048466906, 0.1271889719646424, 0.1159561586973723, 0.18683028960367665, 0.08265955475508235, 0.1531776922638528, 0.3189036768162623, 0.08832867242745124, 0.17242833506315947, 0.13201861671404913, 0.21293591300491244, 0.15950690576573834, 0.11327537285978906, 0.11845873261336237, 0.17860770894913003, 0.17593389929970726, 0.29259543225634843, 0.20347918529296294, 0.1532223547110334, 0.12447009168681689, 0.15773976308992133, 0.12353821395663545, 0.21623513050144538, 0.12683658540481701, 0.18657803360838443, 0.22207433357834816, 0.10271811435814016, 0.18480983708286658, 0.1721152081154287, 0.1991158616147004, 0.0906988546194043, 0.09535732300719246, 0.06760264746844769, 0.14781950478209183, 0.11532237942446955, 0.1492855729884468, 0.08391969924559817, 0.14088184892898425, 0.23477181239286438, 0.15088417392689735, 0.1270569142070599, 0.12034342405968346, 0.20174678997136652, 0.12137350277043879, 0.157447342062369, 0.16913207131437957, 0.13351380679523572, 0.14491457550320774, 0.09259147220291197, 0.12173970069852658, 0.09740536857862025, 0.07442991627613083, 0.2312260089092888, 0.1781936053885147, 0.1646408755914308, 0.08095714962109923, 0.13413044245680794, 0.09929498788551427, 0.12725814012810588, 0.13925513543654233, 0.09242843720130622, 0.14848059508949518, 0.08289863020763732, 0.18077403801726177, 0.1182606237125583, 0.20169862458715215, 0.16062888462329283, 0.2112406399101019, 0.14946708746720105, 0.13785620190901682, 0.11878232384333387, 0.13805042195599526, 0.11155922315083444, 0.13019367557717487, 0.13710238767089322, 0.32531975128222257, 0.07830989401554689, 0.17313573538558558, 0.09458318134420551, 0.20675842417404056, 0.12788702122634277, 0.186060682462994, 0.1194354731705971, 0.11631257511908188, 0.10887952827033587, 0.12145484957727604, 0.19095887197181582, 0.15355575713329017, 0.1559605827787891, 0.17238564672879875, 0.15435752895427868, 0.07692444531130604, 0.12677675345912576, 0.10225102887488902, 0.1289750839350745, 0.09428532779566012, 0.1393568838830106, 0.08411662813159637, 0.23854256083723158, 0.16516319912625477, 0.09821481420658529, 0.1577582722529769, 0.15681190037867054, 0.18445767316734418, 0.12149603135185316, 0.13081543205771595, 0.10302971990313381, 0.2506461285520345, 0.18678494438063353, 0.17099198244977742, 0.11820658794022165, 0.12495918927015737, 0.15898480487521738, 0.09574401163263246, 0.1764111002557911, 0.23976277036126703, 0.19878648163285106, 0.15433609572937712, 0.0624640095338691, 0.1194840764219407, 0.16254372952971607, 0.10874512532609515, 0.30834932753350586, 0.12273346612346359, 0.1991868851473555, 0.1683481555664912, 0.11843178523122333, 0.09274574244045652, 0.20030168001540005, 0.14999433886259794, 0.13980637304484844, 0.15461048256838694, 0.15020153165096417, 0.15832472388865426, 0.20924346114043146, 0.19642808474600315, 0.13496437895810232, 0.14108786912402138, 0.1195125155209098, 0.07286446707439609, 0.12863060866948217, 0.12809454055968672, 0.19561730325222015, 0.10044545037089847, 0.2084821808966808, 0.17345751577522606, 0.1565507534542121, 0.13126872101565823, 0.11128530386486091, 0.20229505898896605, 0.2343182117328979, 0.1429008023114875, 0.11437000357545912, 0.13738110865233466, 0.08138433724525385, 0.09975294495234266, 0.10563224626821466, 0.1272876182338223, 0.15181133901933208, 0.10421268845675513], [0.04585490780300461, 0.02842575700924499, 0.08025678485864773, 0.04513902844337281, 0.02295142156071961, 0.025170038643409498, 0.049291318719042465, 0.034398478019284084, 0.10860436959774233, 0.023232597195601556, 0.027918020387005527, 0.08435643831035122, 0.01530627632746473, 0.07410903388517909, 0.004443180159796611, 0.0012612900650310621, 0.05510132199560758, 0.02880518000893062, 0.02220957259851275, 0.05997243424644694, 0.026777719758683816, 0.014278437047323678, 0.03862260819005314, 0.02774230950308265, 0.029868378915125504, 0.05247210800007451, 0.02940477781521622, 0.045920316988485865, 0.027677360449160915, 0.04720968354376964, 0.03460256863036193, 0.02236990061646793, 0.03515799566230271, 0.025769703242985997, 0.03061112958675949, 0.022377218192559667, 0.03996674524387345, 0.04645001747121569, 0.04526041040662676, 0.003176839895786543, 0.015916588890831918, 0.034341755672357976, 0.0222511254469282, 0.04987256877939217, 0.02197607624111697, 0.046914724371163175, 0.060239978483878076, 0.028576361037266906, 0.020892703905701637, 0.0298185826613917, 0.07552170456619933, 0.016766995504440274, 0.02322558946616482, 0.06809061698731966, 0.02059702113911044, 0.03142917114018928, 0.0621709836559603, 0.03217007571947761, 0.03508129469992127, 0.015539638170594117, 0.042572024976834655, 0.07814496653736569, 0.018867360631702468, 0.04087301145773381, 0.0549981152289547, 0.06380702965543605, 0.013079438103886787, 0.04145609091210645, 0.0388435603963444, 0.03710198470798787, 0.03219036603695713, 0.033205883810296655, 0.1204560227051843, 0.012157617402408505, 0.059144594488316216, 0.002358074748372019, 0.02103213675582083, 0.031475982104893774, 0.05476388971146662, 0.10033424696302973, 0.003705612461999408, 0.06496302856248803, 0.061768936284352094, 0.017259991218452342, 0.026308678716304712, 0.03761686079087667, 0.019030289877264295, 0.053175894063315354, 0.028642117176786996, 0.00959089316893369, 0.06996364929364063, 0.02351362996705575, 0.03761403320822865, 0.012808329702238552, 0.03443525514740031, 0.060440781380748376, 0.043306484003551304, 0.02182562991947634, 0.031925857183523476, 0.048539827403146774, 0.030015865922905505, 0.045407971629174426, 0.040459880110574886, 0.006317197203316027, 0.09971816049073823, 0.04547080185147934, 0.041098687433986925, 0.06137953881989233, 0.026277020551788155, 0.05642140233248938, 0.010695487217162736, 0.02747621987509774, 0.022845450293971226, 0.04072624433320016, 0.010673262677300954, 0.019126650331600104, 0.08221957250498235, 0.04949522379320115, 0.006625823025387945, 0.009826533405430382, 0.0558399927103892, 0.023454144975403324, 0.02705268547288142, 0.06009275864926167, 0.06739985561580397, 0.029670609546883497, 0.04248499702953268, 0.07918182847788557, 0.01189105279991054, 0.07562377955764532, 0.05337609210982919, 0.047677173497504555, 0.0294390650378773, 0.06479092451627366, 0.08542349823983386, 0.015614616422681138, 0.06159583033877425, 0.03402275462576654, 0.047059320713742636, 0.04980275494745001, 0.009983796353481011, 0.07594747468829155, 0.04768685481394641, 0.015643695624021348, 0.03949067977373488, 0.049744025091058575, 0.03193700424162671, 0.06330621356028132, 0.014004316453792853, 0.03461004205746576, 0.026563751162029803, 0.04166173632256687, 0.042304881499148905, 0.04537389220786281, 0.07106040997314267, 0.05168854848307092, 0.014400768031919142, 0.023349370421783533, 0.011657525828923099, 0.03775868521188386, 0.06469248604844324, 0.06091923656640574, 0.014628274329879787, 0.027406142580730375, 0.06558539360412396, 0.042412110706209205, 0.10029158831457607, 0.024342302785953507, 0.049608508925302885, 0.03449977746640798, 0.04312099903472699, 0.058957298679160886, 0.03796176650212146, 0.04010026503237896, 0.0589698669500649, 0.0378643781732535, 0.051688752573681995, 0.036254129227017984, 0.03126533090835437, 0.01026121579343453, 0.029329236458579544, 0.004000152785010869, 0.030714026506757364, 0.020256816933397204, 0.03355287124577444, 0.013883026331313886, 0.02872106313589029, 0.056353644249611534, 0.022354504762915894, 0.05642692020046525, 0.05071136634796858, 0.04238558634824585, 0.024923677156039048, 0.011974271674262127, 0.04631497256923467, 0.04763707525853533, 0.06450815140851773, 0.010853560961550102, 0.014511891658912646, 0.012597744371305453, 0.032904393738135695, 0.07921172960777767, 0.013883646952308482, 0.03146445655147545, 0.047695203975308686, 0.010552013372944202, 0.06015663158905227, 0.01580835221830057, 0.05698944216419477, 0.04380968981422484, 0.05352354943170212, 0.01700469983916264, 0.03599083378503565, 0.01946117710758699, 0.02719604985031765, 0.016313899504893925, 0.013916287534812, 0.009095053173950873, 0.05096027525723912, 0.02455127858411288, 0.04272391292033717, 0.0640892016235739, 0.024494984827470034, 0.09730381309054792, 0.05912583299505059, 0.08140212652506307, 0.05954945459961891, 0.02913241147325607, 0.013863395597581984, 0.06716829811921343, 0.046704648339073174, 0.02147877421521116, 0.03298900599475019, 0.01677442811342189, 0.07006769097642973, 0.01963686016097199, 0.01922964002005756, 0.039975176041480154, 0.03643741743871942, 0.031266162113752216, 0.03891960084729362, 0.032935916460701264, 0.03926002769730985, 0.034890603565145284, 0.013697136892005801, 0.038648282788926736, 0.03603016761189792, 0.016859745410329197, 0.0387183378188638, 0.04781081202963833, 0.04188411716313567, 0.11305774547508918, 0.03201561252353713, 0.03637537389295176, 0.059757960989372805, 0.006088971022109035, 0.035495513293426484, 0.026701117130869534, 0.02015132620726945, 0.04252145874488633, 0.03675658917927649, 0.017751430277712643, 0.04376843753561843, 0.07750014410703443, 0.05407405973528512, 0.07648662271094508, 0.09627648774767295, 0.04176334747171495, 0.05758161292760633, 0.03948903962736949, 0.029785620172333438, 0.044400227852747776, 0.01141797632953967, 0.02561610464908881, 0.0668362612486817, 0.046087678711046465, 0.04964838451996911, 0.032294812190230004, 0.012589079797180602, 0.030652047898911405, 0.05136561405379325, 0.0579234906763304, 0.07760046020848677, 0.029689653056266252, 0.060185259935678914, 0.044252774241613224, 0.05945959535893053, 0.05054885084973648, 0.0502198122558184, 0.066839779028669, 0.0512027349031996, 0.03225119988201186, 0.03597224669647403, 0.04696716081525665, 0.01934434265422169, 0.06202245764143299, 0.09602486999938264, 0.033544451580382884, 0.01141366259616916, 0.02849432588845957, 0.0667144896578975, 0.04406032421684358, 0.020323194621596485, 0.06263557181227952, 0.04314237288781442, 0.058485289046075195, 0.022331360887619667, 0.07280940713826567, 0.006009332546454971, 0.07150602512410842, 0.05316178212524392, 0.008262675182777457, 0.025148371641989797, 0.09094809007365257, 0.006865106279292377, 0.013842985608789604, 0.012264959786989493, 0.04815385866095312, 0.09715919077279978, 0.049021544327843, 0.02225687523605302, 0.01381441848934628, 0.01443814722733805, 0.011234391258767573, 0.08991853086627088, 0.08072548822383396, 0.04217690555378795, 0.06030095704772975, 0.024855837436916772, 0.02927574430941604, 0.04823502735234797, 0.04833351405977737, 0.051207792639615946, 0.02396235471678665, 0.05748575713369064, 0.05636340720229782, 0.07941809119074605, 0.03810874513874296, 0.02102749091136502, 0.06252796782064252, 0.029453763272613287, 0.02227325257990742, 0.071540423668921, 0.046195928371162154, 0.008607275685790228, 0.004876081857219106, 0.060256524666328914, 0.031803833262529224, 0.01369760630041128, 0.020068836493010167, 0.04220748945954256, 0.02859409651136957, 0.1411202416056767, 0.10007252858486027, 0.13217632309533656, 0.08966911729658023, 0.1628392972634174, 0.08331435165018775, 0.11509652162203565, 0.11194729959242977, 0.25662567175459117, 0.12456219963496551, 0.14563670003553852, 0.2756520523689687, 0.08630276512121782, 0.14171014510793611, 0.10113897253177129, 0.18673133163247257, 0.07577131851576269, 0.0723136895976495, 0.11704963908414356, 0.2070033032214269, 0.17074270988814533, 0.14594999025575817, 0.12774006114341319, 0.07949257313157432, 0.11101524374680594, 0.16737983096390963, 0.10190995264565572, 0.13627513049868867, 0.1463516108924523, 0.13253245007945225, 0.207552284700796, 0.1344922839780338, 0.1264041953254491, 0.11426157579990104, 0.11564950327738188, 0.16639758367091417, 0.1142133584653493, 0.12496975745307282, 0.15027981338789687, 0.0847215081739705, 0.1578100593178533, 0.11177812702953815, 0.11552318974281661, 0.16089740849565715, 0.24226367444498464, 0.2021170622901991, 0.11505913222208619, 0.2222875229199417, 0.15955657028825954, 0.11854073251015507, 0.13501739798812196, 0.1150465602404438, 0.05684215924702585, 0.19581011321861297, 0.1676321611739695, 0.0850800471380353, 0.09380362942465581, 0.13769120763754472, 0.21324431989341974, 0.1374872209271416, 0.09592202317435294, 0.1371752072009258, 0.13148483441909775, 0.09323369711637497, 0.16160474944626912, 0.17542163928737864, 0.1968006428796798, 0.14085738774156198, 0.14078842737944797, 0.11788827338023111, 0.2511320571647957, 0.11818192637292668, 0.18955544102936983, 0.15968187450198457, 0.16696382750524208, 0.2196221292251721, 0.0969748041825369, 0.0907162282965146, 0.16336656350176781, 0.24014595604967326, 0.1672389861778356, 0.11064284146414138, 0.17146590311313048, 0.12716253666440025, 0.08039329550229013, 0.1240305695682764, 0.18376979132881388, 0.12350503995548934, 0.14821364457020536, 0.13199592183809727, 0.14907265082001686, 0.14185027743224055, 0.12639778316952288, 0.06519508329802193, 0.1102478482061997, 0.16403661895310506, 0.050180311445728876, 0.11243089044000953, 0.111446579976473, 0.0913399959972594, 0.12685896857874468, 0.15913541632471606, 0.1718345723929815, 0.08491039217915386, 0.18346519907936454, 0.12001927621895447, 0.17339450743747875, 0.18045850651105866, 0.15866349946008995, 0.12453471048502252, 0.0933937932131812, 0.13435005879728124, 0.21098973462358117, 0.1975926777231507, 0.10762342106318101, 0.13273090036818758, 0.21232370054349303, 0.19888747308868915, 0.1268429827177897, 0.10688922920962796, 0.11172385376994498, 0.03767313784919679, 0.16226324223680422, 0.30707532714586705, 0.15121781383641064, 0.08072590382653289, 0.19453057640930638, 0.14687455783132464, 0.11134206331917085, 0.207332119171042, 0.07692697603488341, 0.2183346514357254, 0.07061857235385105, 0.16150068549904972, 0.16279012255836278, 0.1261668564984575, 0.13997705216752365, 0.22001889621606097, 0.06419219687813893, 0.1735778624424711, 0.19136647431878373, 0.15458285983186215, 0.23616770311491564, 0.1863388839410618, 0.14519391988869756, 0.12639015389140695, 0.16899844020372257, 0.09631480483221821, 0.1319718168815598, 0.11839218423119746, 0.11307405788102187, 0.14842735341517255, 0.13718586444156244, 0.11079158270149492, 0.14389287563972175, 0.2081378540606238, 0.1436730069690384, 0.21490540966624394, 0.13373401685385033, 0.19160005787853152, 0.22513408970553428, 0.1424298353958875, 0.09272420531488024, 0.13850614515831694, 0.12152615512604825, 0.14998736267443746, 0.27801591146271676, 0.08870473349816166, 0.14379268570337445, 0.13266121270135045, 0.11739385459804907, 0.20134052349021658, 0.17382418125635013, 0.11141379931359552, 0.25214603869244456, 0.1744562535895966], [0.021490815561264753, 0.03300853932159953, 0.042421773468959145, 0.03651648214145098, 0.011562053168745479, 0.03556964271410834, 0.055658763958490454, 0.0245888980498421, 0.02392400423559593, 0.03344714117702097, 0.043565664236666635, 0.06591672543436289, 0.04071868184837513, 0.052498973745969124, 0.07443669950589538, 0.02049237460596487, 0.056030004780041054, 0.05095938468002714, 0.0698767883295659, 0.08761914956266992, 0.0392972649569856, 0.027773466717917472, 0.023099958707462065, 0.03226677014026791, 0.016485840278619435, 0.11767055693781003, 0.007313157993849018, 0.06962792394915596, 0.0327097209810745, 0.0303240761422785, 0.045123257805244066, 0.017153784319816623, 0.02490293041773839, 0.020643318166548852, 0.053518513959716074, 0.028378793904266786, 0.034981412754859775, 0.042216391520923935, 0.09689635175163858, 0.04495972927543335, 0.0023769712197463377, 0.01318592516327044, 0.033067439871956594, 0.016770487309258897, 0.023107580564101227, 0.0686432424117811, 0.04907688628009055, 0.04201343639579136, 0.058189847477478907, 0.0347580077504972, 0.0441190800484037, 0.03438716026721522, 0.013084076526865829, 0.05318428033206146, 0.011922828780370764, 0.02782141131319804, 0.06716099538607523, 0.07326939768972807, 0.03169119379890617, 0.015629496483597904, 0.020707749572466128, 0.06904815076268278, 0.022240011785470415, 0.0054950316280155675, 0.03793549818510655, 0.10413428797619417, 0.02011080494412454, 0.015491380017920164, 0.037868701183469966, 0.02993969745148206, 0.060037361035938375, 0.034745320735964924, 0.027999999874737114, 0.06784300683648326, 0.08143038750858977, 0.04469750252610538, 0.05875533061043825, 0.06771709406166337, 0.08599861816037446, 0.019474951368465554, 0.04982894904969726, 0.03616849280660972, 0.030525283509632573, 0.03883910751028452, 0.04159449403232429, 0.05963932126178406, 0.06417434822651558, 0.04237909255607519, 0.02354818436288042, 0.04052123716974165, 0.026841349645110313, 0.0940010481281206, 0.03989212229498662, 0.04886549664661288, 0.06696569180348888, 0.007761353963360307, 0.051660580647876486, 0.033715256868163124, 0.055899446160765365, 0.03062804684304865, 0.043408020937931724, 0.03177933125698473, 0.018189865149906836, 0.0768242850608658, 0.04911606425594073, 0.008819541053526336, 0.03416736581129953, 0.018459236925991718, 0.05128739539941307, 0.03117121545074042, 0.05076359499071259, 0.02784647178486921, 0.0714287007576786, 0.014067256142880069, 0.03132423145871144, 0.018312378888367675, 0.028895156137878075, 0.038762384283472784, 0.044573018385563046, 0.061785783036611974, 0.020286484286771156, 0.059079445054521784, 0.013361945893848315, 0.05741363522247411, 0.06642694454058073, 0.02583727393357549, 0.0390940946090268, 0.022956479297135957, 0.05404486364568584, 0.05300987933878787, 0.04374030642793514, 0.02897805217799032, 0.04046652975375764, 0.042529704005573876, 0.018928695426438935, 0.03328152721223887, 0.013434976935968734, 0.022352627129293978, 0.04868974494456779, 0.05060178824351169, 0.018539079028414562, 0.04169691412243992, 0.04387109882372897, 0.024696041909919586, 0.10121628205524758, 0.022203820954018738, 0.037494877688004635, 0.036863298882963136, 0.025117989971477073, 0.01808543012884911, 0.027145416825078428, 0.054437092403532006, 0.04067578942340333, 0.04777626876602881, 0.040954588330350816, 0.02863506491848966, 0.040510717226425186, 0.036801362948608585, 0.0805541560112033, 0.05153417063411325, 0.0823690855759196, 0.02340191633265931, 0.06316070808679797, 0.10730970781878568, 0.06128905246441718, 0.021432061585073825, 0.028223551453265827, 0.013589891914307373, 0.03675848536659032, 0.07127584802219644, 0.03868198000418488, 0.04060402745380998, 0.057705165672814474, 0.02771532686892897, 0.06348130104015581, 0.034115255912183784, 0.007227338355733082, 0.0643792626215145, 0.04853269907471258, 0.03904213685018476, 0.023335360529017635, 0.029174368792155292, 0.026312677036912646, 0.00156444254798771, 0.06973844458116218, 0.012292557476030197, 0.01366810221952619, 0.03701826302858535, 0.04571231154841371, 0.11900679382961243, 0.05363630392821506, 0.062345570186153054, 0.030572851464967243, 0.0210902172329952, 0.03875172704283614, 0.05711995625460986, 0.06781315765692852, 0.0696265435544774, 0.028492216333688702, 0.03189041592122521, 0.059612874829326756, 0.09279687641537748, 0.02359935544518521, 0.08077959821093827, 0.07448746240697801, 0.047177830565487966, 0.09126737684709951, 0.022661928305751644, 0.016327840748999733, 0.08816283210762776, 0.04043127402837854, 0.03367169279954396, 0.02058620248135412, 0.037538679243880324, 0.05098785717564169, 0.04739939875435084, 0.03322674187074881, 0.014491485380858649, 0.0319156934710918, 0.02877829199860571, 0.028504636175057385, 0.07922439806861803, 0.0036374097862790222, 0.04255037652910687, 0.06154846276331227, 0.09730118588777259, 0.010552632138569606, 0.02219651265477296, 0.03178759878210258, 0.03299295422038995, 0.038868778574396856, 0.027582007460296154, 0.05853302398463711, 0.026579634977679234, 0.04684747465944383, 0.012553606065921485, 0.023959757199918386, 0.04495544337260071, 0.031604444156982936, 0.042054766599903814, 0.016671349367243238, 0.03594580397475511, 0.06629887211602181, 0.0829196404083632, 0.04809489873878192, 0.07020979741355404, 0.04707529544248246, 0.036432612032513134, 0.03529174922732636, 0.027053845078626182, 0.0414467398513807, 0.03509499103529379, 0.13979997573187575, 0.05500047525856644, 0.01725653466564836, 0.012451083930500317, 0.013201141973695485, 0.01181206602268503, 0.08371724135940894, 0.020059043854416814, 0.05135111619892996, 0.00576161014578247, 0.05281124351313338, 0.023891416531114373, 0.06017708146828227, 0.058272207315894775, 0.04508294063271023, 0.07665201774216257, 0.011651008844637545, 0.04664764026529156, 0.027011047277483158, 0.020302518387325108, 0.06589786004042253, 0.037793900119140744, 0.036512047809083015, 0.040213976899394765, 0.026701252572820522, 0.021125536040926818, 0.02246503467176808, 0.03781842067837715, 0.0639626283373218, 0.016857576483744197, 0.051321712307981215, 0.024445709932479076, 0.04067292844410986, 0.0438700746599352, 0.09203918074490502, 0.03481748717604205, 0.044983218249399215, 0.038767516234656796, 0.04910567789920606, 0.03485799359623343, 0.02493336589395767, 0.02047974139713915, 0.02422387828119099, 0.04950245602231007, 0.04145948252698872, 0.031615550396963954, 0.032723706754040904, 0.041649995546322316, 0.07193205499788746, 0.08364843684830703, 0.06579204462468624, 0.05006838073313702, 0.0611798046156764, 0.06808010817621835, 0.044417809331207536, 0.03986338262620848, 0.050337505745119415, 0.04327989285229705, 0.03999358130386099, 0.012645008046092698, 0.053242375652189367, 0.012836043351853732, 0.06239767637453042, 0.02541504942200845, 0.04411562164023053, 0.02422251272946596, 0.06233616717508994, 0.023595377533638384, 0.08494994865031913, 0.03741359025298152, 0.03896179194271099, 0.07187994138803333, 0.0661233245045878, 0.019670663132274058, 0.08255615131929517, 0.05706502990506124, 0.03226881104637869, 0.026180702770943753, 0.0720308200106956, 0.02146134116628673, 0.007529530685133068, 0.0699116247415077, 0.07230847972095944, 0.06852121849078685, 0.005678293864548323, 0.02388940531091066, 0.07110874605132267, 0.018455403733241837, 0.05788186361314729, 0.01619280326849548, 0.048781908553792164, 0.008713674615137279, 0.031645826311432756, 0.04070747170771938, 0.060526273082359694, 0.03808606510574464, 0.02705168542888714, 0.09479134634602815, 0.0344493336888263, 0.0160021993360715, 0.09837040546699427, 0.2659846289316192, 0.12321408095886, 0.11594774274271913, 0.1446139908512123, 0.1709070213837549, 0.21101965801790357, 0.0779264559969306, 0.14462157560046762, 0.12951891490956768, 0.13983607379486784, 0.12265707686310634, 0.11890098583535291, 0.1686892911675386, 0.1982587404199876, 0.12407090529450215, 0.10133039468200877, 0.11344742495566607, 0.13588587404228747, 0.14240016433177516, 0.18587723840028048, 0.15917046053800732, 0.15625753090716898, 0.09599282406270504, 0.19645990803837776, 0.23620440973900259, 0.10699841397581622, 0.17110268119722605, 0.14493842812953517, 0.10862829643883742, 0.17600437364308164, 0.15087314561242238, 0.1175106834853068, 0.18415913684293628, 0.14587714103981853, 0.10934622783679515, 0.12756332609569654, 0.1425711254705675, 0.20956913038389757, 0.119133129628608, 0.14644491369836032, 0.07900441807578318, 0.13340221747057512, 0.12041317851981148, 0.07385809149127454, 0.217979563458357, 0.0637185137020424, 0.176186170137953, 0.23009828582871705, 0.1357603323413059, 0.09127209690632299, 0.14877907204208896, 0.10780697644804604, 0.11051916255382821, 0.10374689431046136, 0.0925843624281697, 0.2025824334123172, 0.17408080107998103, 0.18352664890699089, 0.10051035118522123, 0.14920329849701375, 0.15109433530597016, 0.12147931818617508, 0.12134516015066765, 0.0946851895423606, 0.2421079421765171, 0.09585983119904995, 0.1599506358616054, 0.23340632003964856, 0.27378320577554405, 0.21971877169562504, 0.1482514347299002, 0.12894345360109583, 0.11858988495077938, 0.1745304832002148, 0.09398486188729294, 0.22433680045651272, 0.1916242518927902, 0.1735813802224584, 0.08676746831042692, 0.12978479673620313, 0.1097685618151445, 0.16775795520516112, 0.12387421389576048, 0.14767316810321063, 0.134381050884258, 0.08965195884229615, 0.11272472896962427, 0.13904739345889539, 0.11505804868647829, 0.1285623904550448, 0.20505920285359025, 0.1491763288504444, 0.1897128505515866, 0.09438836015760899, 0.09295142866903916, 0.17943613871466368, 0.11433848456363194, 0.15577546146232635, 0.13860575621947646, 0.17999683128437027, 0.09154605329968035, 0.129350506758783, 0.12197463496704586, 0.1259425943135284, 0.08652799951960333, 0.11083097590017132, 0.13515506638213992, 0.17629670561291277, 0.1362475226051174, 0.17780388880055398, 0.17020303494064137, 0.2881227753823623, 0.1550025146570988, 0.10936685954220593, 0.09748739073984325, 0.14203716506017372, 0.1242454287421424, 0.14355910214362666, 0.16411454445915297, 0.18627967539941892, 0.12016813619993627, 0.12727755471132696, 0.1345121141639538, 0.1835102919721976, 0.17667266278294846, 0.10447365726577118, 0.13782768859528005, 0.1920992709347047, 0.14709905750351027, 0.12255259731318802, 0.22826884727692232, 0.15926349617075175, 0.09704020223580301, 0.09215823607519269, 0.1043811634008307, 0.0884985426091589, 0.06893880272400565, 0.11441379028838128, 0.08241547722718678, 0.07863927399739623, 0.14653662830824032, 0.13410091982223094, 0.08173681286280043, 0.2425507371663116, 0.09459668101044372, 0.16310883045662194, 0.18661779788089916, 0.13583459163783118, 0.13756624481175095, 0.22420683555537835, 0.22756109072361141, 0.10453905531903729, 0.14923663577064872, 0.10302096256054938, 0.11351035165716894, 0.13440784241538495, 0.12013789368211292, 0.2023294204263948, 0.17110979097196832, 0.21190394181758165, 0.11965704135945998, 0.22654826694633812, 0.17687437852146104, 0.15446686215000227, 0.09685644647106528, 0.1428239603410475, 0.10671146999811754, 0.07801662693964317, 0.14526886196108535, 0.20090930600417778, 0.13097440009005368, 0.11874266347149387, 0.19452345179161057, 0.10176697047427297, 0.055505644049844705], [0.04216476030705962, 0.05856222007423639, 0.11393757638870738, 0.06506724093924277, 0.005227518468018388, 0.04237618704792112, 0.048909750912571326, 0.008500486201228341, 0.0171164747007424, 0.020560546436172444, 0.02847729545464972, 0.09231365664163604, 0.0974707592104096, 0.06274190673138946, 0.02403576610959135, 0.03424318361794576, 0.03235781681723893, 0.03867919323965907, 0.02959860266855685, 0.0574543160473695, 0.03210606177162845, 0.12702439329586923, 0.015866623798501678, 0.03996339815785177, 0.034443370532244444, 0.018540667224442586, 0.04912118136417121, 0.023053227523632813, 0.05292868838296272, 0.04597306884534191, 0.039841782418079674, 0.03969789482653141, 0.08012892765691504, 0.05713498845580034, 0.07558400786365382, 0.05516415592865087, 0.018111299541487824, 0.034628807261469774, 0.036368086002767086, 0.1246615286800079, 0.052598814872908406, 0.033976986378547736, 0.03060111059312476, 0.07890233566286042, 0.04540851710771676, 0.011248908595007379, 0.01278064110010746, 0.0657453338499181, 0.04975796633516438, 0.09454686063691042, 0.01042219040755299, 0.056181974359788, 0.10077161685330793, 0.07020147793809883, 0.015837841456232127, 0.015435876648552949, 0.04963129656971432, 0.038279795335256495, 0.0203112182134646, 0.06444909129641019, 0.057243382834712975, 0.06251325845369138, 0.03587647996027954, 0.02711130215175217, 0.01658924371440662, 0.01673068036325276, 0.021558525404543616, 0.042400670499773696, 0.049788620744948275, 0.06779380244552158, 0.03865605307510123, 0.11144034593598917, 0.03229199573979713, 0.027815067805931903, 0.06465991318691522, 0.029261265008244663, 0.01891542211524211, 0.028001482314721216, 0.005048429884482175, 0.03472088181297295, 0.057103150320472196, 0.02598899674921995, 0.028438993213057984, 0.050246833852725103, 0.015283132452168502, 0.03283771548012737, 0.03930556216801051, 0.013122119016770739, 0.034938297685584985, 0.017493919876869768, 0.03683458890009206, 0.05036587062932085, 0.019126457373204175, 0.02951153390313266, 0.043469073716551065, 0.05692951373930555, 0.026088361046276987, 0.06020464112225454, 0.05820646787469741, 0.047241050415323116, 0.046614610982942395, 0.08684403568622656, 0.011006790336978156, 0.04174282708845567, 0.03633734995673876, 0.04400190606247634, 0.04409349821798969, 0.06348786904709414, 0.023887733623269014, 0.027820808318210766, 0.05461354914586991, 0.06327934039290994, 0.023330727672146168, 0.03636130648374092, 0.052975139406044036, 0.03463836983428337, 0.02685557661607163, 0.04541249501926359, 0.08375462333788164, 0.08607681826106273, 0.013518915693566669, 0.06495390756754205, 0.03620753348513972, 0.06097775862144772, 0.030813752600806765, 0.04441320059413556, 0.030054709932301193, 0.04188358652754687, 0.04938500373100396, 0.03807167486229446, 0.028789648713427596, 0.058157838648185134, 0.009764871138031594, 0.043011903326259926, 0.06919126652064733, 0.02844261489372002, 0.03196995188773144, 0.08096956575172953, 0.0398376375233056, 0.0783232823596336, 0.0030616504591307603, 0.12492709880461916, 0.025738772383192554, 0.02639129088493064, 0.02230882742878748, 0.002201650891038298, 0.02980014029162703, 0.05421897891210392, 0.004416596430019126, 0.00504064058077347, 0.05489627401402686, 0.09508547431323677, 0.027350372038199566, 0.017578982988197822, 0.034317056997679174, 0.016718399674573448, 0.03611659070884343, 0.01843105572334025, 0.04350359471573029, 0.04050689887662884, 0.03668925412057433, 0.03991522535216063, 0.04962065788276959, 0.04464752630155999, 0.030699797680426855, 0.0331583789375145, 0.020603320117515977, 0.045737084437860176, 0.027724056380975526, 0.03833797229162883, 0.0227536967213382, 0.00978787586063845, 0.04552507511107251, 0.028609766959561966, 0.053416312803165056, 0.0219830858259229, 0.03085541306063533, 0.030579154154111166, 0.031022208895592485, 0.004403649663800024, 0.04421074641868472, 0.05349927378119901, 0.04213376822008286, 0.005417659949671361, 0.021861772511329036, 0.02514137504476821, 0.09523265704046935, 0.04076486198755447, 0.01995408190850867, 0.037337705653044395, 0.02324577588296961, 0.04118424221815076, 0.042373919786768965, 0.05889584143005777, 0.028662212680501398, 0.12176615826319903, 0.06421045371098444, 0.020878276554867625, 0.030336946838360745, 0.0567224805126898, 0.06368141373968683, 0.032146590456250124, 0.030414521679631434, 0.080623539397493, 0.014332302125694696, 0.05124168281327002, 0.024801734871289227, 0.04126295440073591, 0.06539974536281079, 0.020418278581928462, 0.025674604439700488, 0.0469881524622906, 0.0247689634852577, 0.010309789358871058, 0.004292437906769919, 0.05838788958499208, 0.03294526752142701, 0.06066517344152089, 0.057086348097072914, 0.03514280018862337, 0.02204293446993688, 0.04608493276464287, 0.0049894398125616135, 0.021775438472104724, 0.04748295345052611, 0.07350945277721621, 0.015845392808842007, 0.05719598557334393, 0.026224220455333125, 0.0313281796843512, 0.04047334266942926, 0.02333444768737536, 0.02277687770401826, 0.026435688014316838, 0.0466088110988494, 0.019933032745029777, 0.03907207508746069, 0.044748573418473825, 0.05275653980788775, 0.06043243964086287, 0.033688094263197854, 0.04910884686978534, 0.02523372048017336, 0.024968476900539827, 0.04077113313542213, 0.11612350557697937, 0.04086567532795016, 0.05821537735755555, 0.08644457469927147, 0.06534205080242828, 0.016479378027725033, 0.026964702010445762, 0.019864580754074268, 0.08147149506839924, 0.020336415982455947, 0.04677970544435084, 0.02600413470645435, 0.010797068680403754, 0.03142995781672653, 0.05778778897365555, 0.04050565206853207, 0.016074059640232008, 0.10176047668210231, 0.032896645716391504, 0.04749304294819012, 0.02802415307087358, 0.04086740824277513, 0.07728052034508437, 0.007031100594758755, 0.09574773721396923, 0.058967258300981484, 0.0216967429878423, 0.026310313296562526, 0.04492102256335784, 0.05442420129838865, 0.04265549061528873, 0.10063178880955093, 0.06798552145482972, 0.0532102109718835, 0.10096053054439835, 0.02541168563766405, 0.018811450936482288, 0.007971820086822845, 0.04764228513522539, 0.08418543264269829, 0.03352261759573594, 0.06271544916671701, 0.011735015323210973, 0.08992178889457136, 0.014022776449564844, 0.06475394329754636, 0.01581173641170608, 0.03410416822589468, 0.09160543253528886, 0.14726394787430763, 0.08338855899637565, 0.032983655110001564, 0.018561068864073604, 0.06259878355194815, 0.016743011146900244, 0.04228196026815567, 0.04970941874489654, 0.008601555582572473, 0.03787569592532236, 0.014149534345051507, 0.0659792662190739, 0.039628370432183146, 0.031299336114898324, 0.027918038940697443, 0.007228368549476727, 0.03555086637788918, 0.025184640398947522, 0.03978743865445722, 0.0657415266323369, 0.018273957903147675, 0.025859339839371387, 0.0619738321256591, 0.08648889575852081, 0.04831346494029276, 0.009577934342814842, 0.039628481754334643, 0.021137165495019872, 0.026472383506188635, 0.042019581378553994, 0.058860270291916095, 0.01678634886047803, 0.043604382080957294, 0.03966447591665201, 0.047426772871403955, 0.037116853636689484, 0.020699161068478134, 0.024701097790966742, 0.038508566067321226, 0.06897116778418422, 0.017701005053822882, 0.07437533131451346, 0.03409139215364121, 0.06304184571490623, 0.038307510840240866, 0.035722447209991515, 0.02727976596361259, 0.03204263040970545, 0.03004273723490769, 0.02207406756497221, 0.02188523179938784, 0.019081750397162978, 0.045575229451060295, 0.024962831012089737, 0.05742382491007447, 0.03350532555487007, 0.06580986359040253, 0.02418069270788692, 0.12371850389172323, 0.10906761075602844, 0.16444125270936638, 0.14921244175639004, 0.15958971460349858, 0.15425267833052203, 0.09509763811365701, 0.20086369360797107, 0.08861848851665854, 0.08751390560064465, 0.13790745462756604, 0.12337451844359748, 0.10979585800669156, 0.1776563943712972, 0.07563134946394712, 0.15826857299543917, 0.15471242397325113, 0.13578320533270016, 0.11644576836260967, 0.15361610858235508, 0.0999160467472393, 0.2602803928311914, 0.10440337588079274, 0.14451728900894523, 0.11245938891079277, 0.10808557126438245, 0.13760862144408748, 0.22961060574743897, 0.16053383034886792, 0.1566971791908145, 0.12736630073050037, 0.11959030001889914, 0.1451149702188559, 0.18415009748423472, 0.16203019302338362, 0.11005294538335875, 0.13176452019251883, 0.14940192690119147, 0.107410469208844, 0.3998604998923838, 0.15262157132383436, 0.18113972386345267, 0.11892981085111387, 0.2290730830281973, 0.11827707712654956, 0.1015811441175174, 0.12120522820623592, 0.17348981404211372, 0.11945471705985256, 0.17815240134950727, 0.12825189071008936, 0.15526976203545928, 0.2702553919516504, 0.12567942874738947, 0.0711534678703174, 0.19986039900686592, 0.10469149987329729, 0.08943923705373891, 0.16912530292756855, 0.12058160151354969, 0.1416982855880633, 0.1927297402289696, 0.106461321702227, 0.17378765274770558, 0.16979054926196113, 0.10953358301776461, 0.05936159475822933, 0.15027141227619722, 0.1505732288933359, 0.2531902998453006, 0.13212039484642446, 0.26647622755263, 0.10780639015138149, 0.11461753951152787, 0.19359417899977416, 0.18067889468511567, 0.13237403123639524, 0.2164886036189273, 0.09859909827355295, 0.15850993426283821, 0.179885835677851, 0.10663907349226065, 0.056952887680381536, 0.12933591613546014, 0.07287513915798627, 0.13022809638641775, 0.20830491150263697, 0.14151041832519695, 0.0966017265454866, 0.1134610953158699, 0.12414725744747557, 0.15911346359644085, 0.1084468858607579, 0.2408686000853777, 0.19022215681616217, 0.07510866969823837, 0.1337815885199234, 0.1309638615930453, 0.12563737866003066, 0.1469218623242341, 0.14980820822529495, 0.16227691259700805, 0.12185698229586706, 0.2368740050587803, 0.1255155328544788, 0.07829990470781922, 0.11142585921334103, 0.1248006962123327, 0.16008891281671822, 0.12692224408965558, 0.201416652998887, 0.0899973617924843, 0.1670811016811058, 0.08733394963201135, 0.12302504110266455, 0.10221244461718015, 0.1265171798877418, 0.14655497419880703, 0.22812734940089285, 0.22523071733303368, 0.12658038118388504, 0.11314433926600032, 0.2561921387678012, 0.1413164654513821, 0.18097435851814225, 0.15143045398872346, 0.16884201031643897, 0.14117983606411144, 0.1804933132370934, 0.12225378639413975, 0.22306124155875295, 0.16759836376877502, 0.1645256794290617, 0.12237924645887688, 0.17984932201215997, 0.1019999009440653, 0.0989418888639193, 0.1691805335576646, 0.13583583844592795, 0.20283679710701108, 0.0983843207359314, 0.21331621916033328, 0.0929806767089758, 0.08795612913672812, 0.07680933078518137, 0.17462322197388858, 0.14596468477975577, 0.20844370796112344, 0.18664654868189245, 0.12654312537051737, 0.10241200812743045, 0.254665570682846, 0.08707022003363818, 0.11800679436419159, 0.1046328034135513, 0.15567659254884347, 0.2373720009927638, 0.10206748091150075, 0.10453808310558088, 0.23680920072365552, 0.12967147078597918, 0.12272503532585688, 0.10714391944929957, 0.15453295782208443, 0.13525443995604292, 0.15111349755898118, 0.056854148642742075, 0.15854496363317594, 0.09739190601976588, 0.14680147112812847, 0.1092056576453615, 0.087901091465028, 0.1715081906877458, 0.11202862413483672, 0.12270478211576119, 0.11246676585869864], [0.017148440856544767, 0.059531865699682385, 0.03566094172128942, 0.05293289264955092, 0.023301292239921167, 0.06976458302233368, 0.05914661684073508, 0.07582715028547682, 0.07722946800640784, 0.026653458262444474, 0.022589999352931045, 0.058825441301451065, 0.05524900938326027, 0.02481441817508312, 0.021554875893343706, 0.012412187043082668, 0.01930797370732762, 0.029806801067024935, 0.04053626566019375, 0.029060506640234962, 0.10356871949625202, 0.007516691066484782, 0.03542989259585738, 0.005388250956457341, 0.03183524095220491, 0.05943210249824915, 0.033441445193602704, 0.025176962881232612, 0.037297069357009605, 0.05848383814736735, 0.07036921073449776, 0.0182417728137807, 0.03230361035093665, 0.024474486708641052, 0.10439409161335789, 0.0718252822116483, 0.020962849848729093, 0.012617554148164345, 0.03896524664014578, 0.035611937710200436, 0.08042753077461384, 0.019871063414029777, 0.03249657616834156, 0.10528299157158472, 0.024644963596074376, 0.12039229448419064, 0.053599879320245236, 0.05965928874502424, 0.04906936832412612, 0.03091056762059452, 0.0610589421557961, 0.01989895332371816, 0.02305781399627449, 0.048855915520107374, 0.009674404263932956, 0.050855038716690615, 0.06354101424221881, 0.045592269161716104, 0.09582639744621702, 0.023052424148772843, 0.036957937554689124, 0.03624433287768625, 0.03912650790880434, 0.014139827053440968, 0.04241313487000298, 0.04853599421039689, 0.009533683787594782, 0.013888638823118526, 0.03396138272364624, 0.06621160297072493, 0.033477216711617075, 0.08964396591181867, 0.04424977596499957, 0.013640418255818076, 0.038640813072561286, 0.02629075028380612, 0.04853783844737336, 0.04886291026195977, 0.02832971753377933, 0.06231957275304012, 0.017867086571641266, 0.0477033230708912, 0.019597591272031423, 0.07744458693196066, 0.023671913368161768, 0.07736614934401587, 0.03281117998994887, 0.10230889412923716, 0.01915200766234193, 0.03399026711122133, 0.10335802377085201, 0.022176701022544876, 0.06301331013673916, 0.019484480544633698, 0.052597148751374334, 0.03584354344638996, 0.021001259701733943, 0.03881985991029069, 0.03671429047244601, 0.013994109140185174, 0.013044688894296996, 0.038777865484007634, 0.029668550087080803, 0.05080487324448768, 0.006088763220759574, 0.019861985092575196, 0.020215585063851904, 0.02031767860898981, 0.034815772814908996, 0.067070082295686, 0.022230105969356373, 0.0368639927910408, 0.02733965728111798, 0.06935064273420721, 0.01737792590574827, 0.0012172248148090148, 0.04961543687386438, 0.017192967861774378, 0.028631458080781158, 0.018474655043974053, 0.03668395147542469, 0.025604965012462344, 0.04232518665958196, 0.03785402521316428, 0.02739182840741705, 0.031020661517686676, 0.013270343533804407, 0.03230425230867695, 0.02692215839488199, 0.02612978030811064, 0.013700836498173885, 0.06552406252012588, 0.07414465697365813, 0.025597103813197464, 0.048281890267389826, 0.030415657165576704, 0.054818830903968774, 0.06439710385166109, 0.030523313107551076, 0.041231027207686566, 0.05904013349208981, 0.07226063346024603, 0.04477065602259245, 0.04071434770594351, 0.07725693489192054, 0.005722392743336968, 0.03919572802260518, 0.06319180407444946, 0.025967658148147166, 0.024598046875325963, 0.03270968016295228, 0.028654394154727925, 0.076421350822784, 0.08096035569906235, 0.023926269641378894, 0.08569657889893278, 0.031051186051627155, 0.050822380508179776, 0.07906156344688497, 0.03289687949290965, 0.016701575186743867, 0.019491579187160823, 0.05540794772969093, 0.04599727028107736, 0.03613847293308936, 0.0374032372928923, 0.09450415745959617, 0.023165154525486287, 0.0403923520934768, 0.11902565180207603, 0.023859836292103864, 0.011857735935336677, 0.045682963318540715, 0.021598931634798646, 0.06751893321052194, 0.028262484520382714, 0.08623005691333674, 0.02916423476563068, 0.031208894288283773, 0.01658257551753195, 0.029856571345590055, 0.04925185872707516, 0.02823839440679876, 0.08409687216044404, 0.023318215062317904, 0.04251689082593657, 0.04918008191452827, 0.06230249593500048, 0.03327027254272252, 0.028340795943222474, 0.005707572518076631, 0.04227575220284052, 0.030242582761275116, 0.03887306076649111, 0.015270537278411211, 0.024840729165589437, 0.04982641832611989, 0.04607634611602407, 0.024930067047534976, 0.04907162074232474, 0.10234401255729608, 0.023292841033253353, 0.10646821625414304, 0.028679712522716727, 0.027531046034710016, 0.021007736795581877, 0.027982377578155138, 0.029639986678375863, 0.0378140271641314, 0.028508621508080978, 0.015069740875333082, 0.055203040756168775, 0.0402058466715971, 0.042822484974749386, 0.05152930214535445, 0.04006387753179297, 0.03183309243468102, 0.007255513064592378, 0.02372373011894524, 0.04389307381643448, 0.015538019360974431, 0.09934310131939128, 0.03335942303237971, 0.11503318673931062, 0.03940972630516626, 0.11258524231379852, 0.023061639767547604, 0.02661654940311564, 0.023927739093778655, 0.06506041318061762, 0.017119749427365605, 0.027497296869114507, 0.03041544750885805, 0.04194954861304723, 0.02448155195452273, 0.039719005217193626, 0.04671083042921964, 0.021948824578430504, 0.040500226969015785, 0.05038723335019313, 0.05871337329153903, 0.028134367566963192, 0.04521488335740287, 0.03842475161945913, 0.03656965331174433, 0.02615224882902112, 0.026789197072503157, 0.03584384030546062, 0.05378035479225218, 0.014363266382133588, 0.04323507455410436, 0.018627791650942527, 0.1016700237232726, 0.0542084923654329, 0.01817036150896456, 0.017654440853220876, 0.041886406688718125, 0.034878692094935104, 0.022348469246935565, 0.05274171540804673, 0.007152149055400514, 0.054646771386615, 0.0485326730995439, 0.023982789753063116, 0.051112063010805286, 0.043188322961214, 0.06125345535110682, 0.033971201337408274, 0.03502127350657247, 0.07931136293336749, 0.06086466644774191, 0.08356018806807697, 0.016273331857519224, 0.05262660459266044, 0.1256522216135636, 0.013585651468019933, 0.023359218721452635, 0.007853546794649446, 0.03658123081550002, 0.07942781332531013, 0.03156219740048982, 0.022809613838035148, 0.010864892628887901, 0.04652234347304329, 0.049080326134571806, 0.011608062613959191, 0.057468928935122676, 0.006944024407857796, 0.05098216119222343, 0.09571300470270216, 0.061801631600246765, 0.013862833420716925, 0.0019166598053743655, 0.03908833554305602, 0.03242076207243372, 0.02953434937808197, 0.042551712394924834, 0.012255306301085511, 0.04501811032241676, 0.015084382521308726, 0.018251192523166537, 0.010748507174866972, 0.009536604138702387, 0.005952666324446909, 0.0284910437403596, 0.02612957621749956, 0.014818072104390012, 0.02558299558586441, 0.030170214085956104, 0.06272708604228683, 0.033669996992102824, 0.014601933653466403, 0.03422109359235037, 0.004698823131548124, 0.022827089560450986, 0.012636691353691276, 0.0433214234362822, 0.012851082974520978, 0.021623520842695143, 0.04562668997095898, 0.06663099062279798, 0.05577843156061135, 0.06944330729311332, 0.053133996116230264, 0.06148641179606784, 0.01657799832173623, 0.02072023991786409, 0.014950705954106525, 0.06594616643269546, 0.043734013015637174, 0.07749752432573587, 0.05513772804988548, 0.013010145630687475, 0.026546427579887677, 0.00438674400356831, 0.0248557650775183, 0.03230131340387743, 0.05638436174194794, 0.0634705250558909, 0.03679528846987523, 0.02060903650999535, 0.07322923265746795, 0.033219472534256056, 0.011447913639131002, 0.04593813595420215, 0.052790044064749964, 0.07611405715579167, 0.022862662553961854, 0.018458416852809023, 0.0382660730247153, 0.05357268331863452, 0.06289979864959605, 0.1638212031684816, 0.202752711775247, 0.10460353310918435, 0.16827370331157, 0.14053758146474138, 0.21801677474286407, 0.10211802858975716, 0.12467021180782467, 0.16164970875252038, 0.1272950100246817, 0.1622267730999738, 0.09537888981867582, 0.11590210066060536, 0.13658514042617753, 0.09464326562010683, 0.1747141795931384, 0.13935094670159742, 0.14998495811596513, 0.06743223551893607, 0.11716044915374368, 0.20664842304540798, 0.13495357328793034, 0.08462896235869266, 0.1481352440896444, 0.17961248784558848, 0.16933544946368784, 0.31102607608772814, 0.09584007522789761, 0.08988776142359711, 0.13150294282240793, 0.16307877347571775, 0.09070796077139676, 0.06885358932777308, 0.12658832216402516, 0.1742941833799705, 0.21679091005353257, 0.13797902734950185, 0.16385235852794722, 0.15450117905857041, 0.0920426391530782, 0.18208159832283854, 0.09761914421687834, 0.13467887474689633, 0.24075203837128356, 0.05929766615736298, 0.20811030553886667, 0.1016738754697144, 0.17839300562627614, 0.16491125483298674, 0.25319314969237894, 0.0928050623042509, 0.1663213799474761, 0.11432462124503218, 0.2630279422737658, 0.08747119500185363, 0.22600345633691177, 0.1379834653926082, 0.11536100078956224, 0.17929078167071566, 0.11375506743206643, 0.13764430390438065, 0.12170493107987568, 0.22644147189566866, 0.12112198150134645, 0.20474407210713252, 0.11468523822259158, 0.1360137460869737, 0.08261580514954403, 0.1324833495891653, 0.1716424452024512, 0.1299735248903744, 0.19629577465821058, 0.21966998290736228, 0.11280781240202487, 0.13261426443932578, 0.11754592807847075, 0.23070102848578244, 0.17012619297020137, 0.12748997221933678, 0.12059766901074909, 0.07735323597444221, 0.1865824864944443, 0.11161676186020486, 0.1785441068932414, 0.11657125811325386, 0.2651636948576197, 0.14660906192148104, 0.19598925282480195, 0.09954764464055188, 0.14674532023491338, 0.25331717741210014, 0.18399466207483783, 0.13641833531437442, 0.15195258456515148, 0.15539707004791126, 0.19739538518479094, 0.055607607719139196, 0.23282772686798126, 0.2032004643115215, 0.08822210744256154, 0.1409344226703979, 0.09465838316828012, 0.15923952480079606, 0.13917572563514113, 0.14876862260280177, 0.13153674022760242, 0.11329833490890451, 0.16325657721608877, 0.14107026538113132, 0.24868025357136503, 0.12923407863127068, 0.09522879045107402, 0.08693748692166992, 0.27234726876486093, 0.19858402374666184, 0.08924186287913471, 0.14630806166678667, 0.10645442715031095, 0.14411112642847002, 0.20116779603995383, 0.09890908593661152, 0.164259233570192, 0.15999946917872876, 0.13521829736419022, 0.16700409643817693, 0.11147813609568402, 0.20525553059997037, 0.0848087105259765, 0.06995433534029871, 0.07060370713588782, 0.11456949287094176, 0.11577149751246907, 0.10963360226014629, 0.11891218484379351, 0.1495343557326123, 0.18675212661037222, 0.10101583538926207, 0.22525673703057691, 0.09067699837032706, 0.11860892103868537, 0.17231017031008378, 0.15330470341723412, 0.09650112100644037, 0.08508757993695326, 0.159333465853706, 0.07516478348406963, 0.16867159836692736, 0.12258745598956011, 0.09925598060362972, 0.12176612857729197, 0.0895993851008825, 0.16717490914743394, 0.21157159324502572, 0.12503711477620527, 0.17710313812131062, 0.14818961382843554, 0.15393465320812538, 0.07948575279442593, 0.13931991008576006, 0.13509195414371789, 0.0972797155554872, 0.17752883402863517, 0.17085964267607778, 0.08085232868324965, 0.14703450549859554, 0.20401157235028222, 0.16173784621059895, 0.10621135152177885, 0.15927921485854313, 0.1637566214776598, 0.16226529056439176, 0.12210541623062454, 0.06990382476942614, 0.06759052077541128, 0.22057209309423342, 0.13479525834554806], [0.014216771069186507, 0.03057174752029823, 0.06941354717127979, 0.016327443699992727, 0.020697292711702175, 0.04561893081699964, 0.03768580259929877, 0.016974501850199886, 0.017516753905510996, 0.0412712998513598, 0.033418345847167075, 0.03370380181877408, 0.034153149972553365, 0.024018052899918985, 0.04776581561600324, 0.07364539938862436, 0.06734953800332732, 0.022714902806910686, 0.04190775456663687, 0.01302909822697984, 0.030296653785626404, 0.0023888242458269815, 0.053662672435166314, 0.020275699025660288, 0.042565334515529685, 0.03315300578833558, 0.03163354005664587, 0.02757871046924265, 0.0786750232509803, 0.025343469278595876, 0.055107207226683386, 0.043912302862736396, 0.013648310996359214, 0.016005038050934672, 0.03540099336532876, 0.04302837900468148, 0.010866447428270476, 0.02498618639947381, 0.08434696108452044, 0.023564775074191857, 0.05874295158719178, 0.034422475364408456, 0.018959149456350133, 0.1360630989074707, 0.05480868203449063, 0.04972337483195588, 0.048770665016490966, 0.02738771690928843, 0.03386588316061534, 0.0718895967293065, 0.03598921590310056, 0.0843831333622802, 0.016451770134153776, 0.04757255293952767, 0.058653270461945795, 0.07358327420661226, 0.0624952168436721, 0.050636917803785764, 0.026326330698793754, 0.020853704045293853, 0.05138172607985325, 0.08809830236714333, 0.02252979262266308, 0.028066076993127353, 0.0224438945951988, 0.08254745334852487, 0.02051444236712996, 0.060809944188804366, 0.030815878853900358, 0.02157044058549218, 0.03891133703291416, 0.019420652133703697, 0.022574599788640626, 0.035758459926000796, 0.06034037622157484, 0.054869200466782786, 0.011513526915223338, 0.009904507151077269, 0.07708287157583982, 0.019067493740294594, 0.011629895670921542, 0.024506566041964106, 0.07623184341355227, 0.03179243016347755, 0.030728782257938292, 0.040737499002716504, 0.03498196565487888, 0.04550616147753317, 0.04852497702813707, 0.047112336033023894, 0.07582209625979885, 0.03416692794417031, 0.07175526799983345, 0.009667840895417612, 0.026453243517607916, 0.050103398971259594, 0.051562186708906665, 0.07325246930122375, 0.03869192107231356, 0.01762974960001884, 0.01626030345505569, 0.0232885811055894, 0.06285940355155617, 0.1155013928655535, 0.01667342738073785, 0.015726593519502785, 0.06769595769583248, 0.07134219602448866, 0.06377205965691246, 0.05072690320957918, 0.0244850771559868, 0.03367506586073432, 0.04748363993712701, 0.04604173234838527, 0.06542743489262648, 0.032096373033709824, 0.07293255170225166, 0.027980034246866126, 0.014219376007531537, 0.013400531079241773, 0.020134828264417592, 0.02174697154259775, 0.038312557444442064, 0.03394833576749079, 0.06888250340125524, 0.07399149253615178, 0.026333971109124832, 0.022079435148043558, 0.026191404540441, 0.0254618919279892, 0.043306955267325975, 0.028795439320674632, 0.04757637871080078, 0.052673244863399304, 0.02617986228869995, 0.07106495191692375, 0.024790901370579377, 0.05658408110321034, 0.03034688048501266, 0.030387333099497482, 0.03046155528863892, 0.02441830984025728, 0.019935107047786005, 0.010246863585052779, 0.021994483358867, 0.02717008210311178, 0.04087794673978351, 0.03121498360997066, 0.050823445490095764, 0.024181752123695333, 0.05194014396693092, 0.06477211107267067, 0.10099933002493344, 0.037879109804634936, 0.033890348058776, 0.04234269763401244, 0.023144392944232095, 0.07765245507471263, 0.05055963425547816, 0.03846255291136913, 0.028659453746513464, 0.022818259858468082, 0.004575534312607488, 0.029639923595823348, 0.07709558456554078, 0.09508013084996492, 0.04982699720130768, 0.03555985007551499, 0.016410157913924195, 0.03408859425690025, 0.015541320990450913, 0.0313094552984694, 0.04067980444233399, 0.03391226739040576, 0.04302742534491699, 0.022656328801531345, 0.0334706375724636, 0.020009666914120317, 0.03321507902001031, 0.06928166752913967, 0.011992209383606678, 0.06379277299856767, 0.026900105476670433, 0.04740023738122545, 0.11365270300302655, 0.09034534741658717, 0.058751916731125675, 0.049558747923583724, 0.04260039728251286, 0.031717673628008924, 0.08434048955678008, 0.09898845863062888, 0.07797894068062305, 0.01128625161072705, 0.01782400118827354, 0.043317111558280885, 0.024527472342015244, 0.02321083000424551, 0.02831510835676454, 0.010584903502603993, 0.05026140221161768, 0.024102561255858745, 0.01839503187511582, 0.03305956568510737, 0.03623509684985038, 0.016156605015567038, 0.03786721688811667, 0.0629275401297491, 0.017191440892929677, 0.04516132998105604, 0.025976871911552735, 0.07479875624994747, 0.040954194992082193, 0.009279373898607446, 0.07752798948786221, 0.041226069661206566, 0.010867594974115491, 0.020658799367083702, 0.017251551143999677, 0.06734834314556792, 0.06035159749444574, 0.0210214090111549, 0.04224517942930106, 0.051443101692711934, 0.030355574745044578, 0.1193949741718825, 0.01842759917053627, 0.04498788635828532, 0.011561982664716197, 0.06386518434737809, 0.024137367981893476, 0.05705110350390896, 0.08344716639840044, 0.03716802842973266, 0.042708691471489146, 0.02356732620683033, 0.05779412320407573, 0.05972681305138394, 0.05280414487060625, 0.05008597334381193, 0.004907946895400528, 0.061981847320566885, 0.01706524424662348, 0.03206750348908827, 0.023777754759066738, 0.04642760832211934, 0.02459835486661177, 0.05326256206899416, 0.027952174023084808, 0.06949179180082865, 0.044542445612023585, 0.03737762577657122, 0.0589847618539352, 0.030926985782571137, 0.04229374557326082, 0.031999036655179225, 0.06629105730098672, 0.01898977603559615, 0.06265420714044012, 0.06963076637475751, 0.016488949877384584, 0.05578710355621297, 0.036982703022658825, 0.06289212484261952, 0.03338968410389498, 0.0771319869090803, 0.044803863420384005, 0.032845326204551384, 0.04359598096925765, 0.03593235625885427, 0.051074591974611394, 0.013896753280278062, 0.10115221244632266, 0.043870850204257295, 0.04685653628257569, 0.00268619794951519, 0.02729728992562741, 0.06187145285366569, 0.04389338551845867, 0.07697961656958796, 0.04435311260749586, 0.05254079747828655, 0.05715347535442561, 0.013359480108192656, 0.049571969284443185, 0.01351415945464396, 0.032238023050013, 0.07271712849615142, 0.0767350714886561, 0.03499893857224379, 0.06919853956787847, 0.025060903972189408, 0.04895083991868887, 0.04192462729406543, 0.07701437876676209, 0.05410240606579464, 0.04699837554653641, 0.012242190696269972, 0.004459382171262405, 0.0348348274565069, 0.006204881965459208, 0.08613676895038225, 0.027863543036801275, 0.019588123323046602, 0.02662699142092606, 0.033727858535712585, 0.08001340494956821, 0.06491745327366516, 0.026554515134193935, 0.0660290197993163, 0.01790084130334435, 0.03657902663690038, 0.048538784685661085, 0.0635621951369103, 0.008699430945853237, 0.017313138268946204, 0.030429093749262393, 0.038192670908756554, 0.0718611131014768, 0.015753366496937815, 0.04324039204220753, 0.00987427019936149, 0.010877918248297647, 0.07596608775202185, 0.04783006334037054, 0.07877608892158605, 0.07080041337758303, 0.04068211994308513, 0.008103297113848384, 0.05406289783422835, 0.019099294768238906, 0.055566247829119675, 0.059794856861117296, 0.11485501192510128, 0.07509225339163095, 0.029489907719835173, 0.030776778803556226, 0.04337384132668376, 0.03519076890370343, 0.06284180723014288, 0.04052096999657806, 0.02654694708326133, 0.021129296874278225, 0.030928351334296167, 0.005282645661282004, 0.06003124944982119, 0.002908827177634521, 0.023350281408056617, 0.044385102883097716, 0.022376535416697152, 0.06254680352867581, 0.07808765789377503, 0.1338649762328714, 0.11449197554611601, 0.17946956504601985, 0.1430416916264221, 0.1856059388956055, 0.14679412386612967, 0.13703002827242017, 0.1479579895385541, 0.19790093618212268, 0.21063399355625734, 0.2772423857823014, 0.23168133135186508, 0.1876884201192297, 0.07639006187673658, 0.21713624621042982, 0.16295982204610482, 0.22128923039417714, 0.1348127136589028, 0.09668486192822456, 0.12900521513074636, 0.13117613067151979, 0.1278073590947315, 0.2119936526287347, 0.14805052051087841, 0.1512798128533177, 0.10044836701126769, 0.06830940954387188, 0.07590017761685885, 0.1629094747477211, 0.09032274901983328, 0.13937926705693826, 0.1486340118572116, 0.0693561346270144, 0.08711863774806261, 0.15805759525392205, 0.17417762166587636, 0.11689742459566332, 0.06241289040190168, 0.12482416292186826, 0.12327550110057928, 0.208752010948956, 0.11201226720004342, 0.09348014951683581, 0.22556362993782386, 0.17723636847222224, 0.25615185499191284, 0.07807886344380677, 0.21730698470491916, 0.15787235519383103, 0.22410026314901188, 0.1366214017616585, 0.2372236011433415, 0.14951356075471267, 0.1490104736876674, 0.11986798941507004, 0.27969776652753353, 0.12878503475803882, 0.15384143945993856, 0.11230511867324822, 0.08445842424407601, 0.1816937222611159, 0.15520602639298886, 0.10586439748294652, 0.2086754806805402, 0.19877683371305466, 0.20341884868685156, 0.10466547275427729, 0.09012839538627304, 0.11047185063944198, 0.19208870275178924, 0.10984027554513887, 0.07527563808253035, 0.19853075238643214, 0.1359567788313143, 0.16525656130397692, 0.10375755897257477, 0.13243132503703237, 0.07872116257203743, 0.14388260431587696, 0.10917412379058078, 0.16965003102086484, 0.10060932399937883, 0.18490069080144167, 0.10753145412309095, 0.10772110254038125, 0.12282740717637353, 0.15625764965079725, 0.18082382128341123, 0.1044085634930525, 0.1512396923499182, 0.1172254464472644, 0.08957159909186885, 0.1864822520292364, 0.1138624562008772, 0.12093702345737256, 0.13336790056200698, 0.22072690509958193, 0.15173151361523196, 0.11689660823321901, 0.16746952693210915, 0.12991535535547882, 0.1602534914854914, 0.1636410690844059, 0.27536944253370166, 0.10165270941797644, 0.10981103492667899, 0.12062978916219436, 0.14809417363721877, 0.11466366398963146, 0.08062149849138223, 0.0911140714015346, 0.09823635875363834, 0.1495839311974123, 0.1292670745169744, 0.16749845584854484, 0.14638989086961374, 0.10745745457825251, 0.12500962562626228, 0.09518573104287498, 0.14822482131421566, 0.19699449185281992, 0.0699510402046144, 0.14194785500876606, 0.13874452299205586, 0.15496733685722575, 0.16675360675435513, 0.12615526415174827, 0.09847891487879679, 0.1193128852173686, 0.06899090891238302, 0.1078943198081106, 0.13981495227199048, 0.1445949770277366, 0.19961277401307598, 0.06779580624424852, 0.2083633778966032, 0.2019878543796949, 0.19273503916338086, 0.12439969155821018, 0.1365339767653495, 0.1392007656977512, 0.12188661625259556, 0.10222851953585632, 0.09477179817622527, 0.0754855248669628, 0.21714377158787102, 0.1247074082493782, 0.13784989365376532, 0.137673307035584, 0.12217438401421532, 0.1421966080670245, 0.20903289900161326, 0.18309535720618442, 0.07299630218767561, 0.15108063525985926, 0.20952739199856296, 0.1615766665781848, 0.19160749419825152, 0.1750770304352045, 0.07490000745747238, 0.06871698220493272, 0.12639187567401677, 0.08751020970521495, 0.2803125319769606, 0.16784158040536568, 0.12045974828652106, 0.08847352481097914, 0.1441090484149754, 0.0706689344951883, 0.1058574287162628, 0.09069008243386634, 0.10258201189571992, 0.19204850803362206, 0.08094707125565037, 0.15220693341689184, 0.10804072328028269], [0.028373070090310648, 0.08029614837141708, 0.09804909263039008, 0.020515572286967654, 0.009372955009894213, 0.04706984807853587, 0.0312598575692391, 0.028540415114548523, 0.009345664384454722, 0.023468976796721108, 0.020225732077960856, 0.01277211567867198, 0.08456150113488548, 0.020299104508012533, 0.021347447473090142, 0.033245247323065996, 0.0858544856600929, 0.043595442912192084, 0.015863438129599672, 0.0367957819980802, 0.03804755877354182, 0.05312668967235368, 0.02102352969814092, 0.00827854972158093, 0.06555765954544768, 0.01855483111285139, 0.019313296761538368, 0.008210504056478385, 0.039182135587907396, 0.03114712904789485, 0.019215208958485164, 0.004312135433792719, 0.07567470573121682, 0.06467754661571234, 0.05034336129028816, 0.10448498243931681, 0.01714696398266824, 0.06617496313992888, 0.04495292749197688, 0.055574474536115304, 0.04806249286048114, 0.029299376146809664, 0.10723398649133742, 0.07980526963365264, 0.06103953499405179, 0.028779201129509602, 0.025200468553521205, 0.013828703904437134, 0.003101971342402976, 0.04929174916469492, 0.04314395737310406, 0.056618056623847224, 0.012972884251212236, 0.018773052215692587, 0.03014248559338739, 0.06588150310562924, 0.03763602675462607, 0.10007031698478386, 0.07006956118857488, 0.02003867190069286, 0.006370911532940227, 0.05843096012540627, 0.011491276400192874, 0.024711541664146353, 0.024628643768664915, 0.016246466111624613, 0.035026969489990734, 0.03565301558410283, 0.04103005732758902, 0.01449954324925784, 0.05754709192842711, 0.01725909507513279, 0.09939768628100865, 0.054744697772548534, 0.026056376336782705, 0.0197500191279687, 0.030419353061006404, 0.02457057071296731, 0.11672573615214787, 0.0896389786794316, 0.0478478897275636, 0.02312716213054955, 0.022665896940452512, 0.08397680008783937, 0.005670294904120965, 0.049090927714132704, 0.02557661682658363, 0.01858879921201151, 0.008247050191130256, 0.08897764346329495, 0.10541548719629645, 0.06677890807623044, 0.0244603562168777, 0.019278233994555194, 0.054675258725183085, 0.03040113704628311, 0.05075813278381247, 0.06512261999887414, 0.018111095450876746, 0.041265637264586985, 0.03855292052321602, 0.023580593951919582, 0.016322198571288027, 0.028826739398937207, 0.020212683266436215, 0.036703358637169003, 0.05271001085930038, 0.005607953107755748, 0.08014709543203935, 0.037281417462509125, 0.05572227695665788, 0.020943427844031248, 0.04728800609882455, 0.08125964901410043, 0.04504722477577161, 0.0070635138945363, 0.04284892027499154, 0.033048826808226295, 0.020810026799154002, 0.03394606479560025, 0.01178821896246518, 0.054826682826387696, 0.039788032372598536, 0.03229920570447575, 0.008804640583548462, 0.009821898693189723, 0.036072377261007205, 0.09577734890626743, 0.023004091781331226, 0.07869506865972653, 0.17995365313254297, 0.02726482282014331, 0.03863041187287308, 0.06860446519567631, 0.049690364103298634, 0.06017801657435484, 0.1000144703721162, 0.022043376047804486, 0.030051691246626433, 0.03526637519826181, 0.052773772476939484, 0.011501987446536077, 0.01988738509680843, 0.014839621289866045, 0.03889292434905656, 0.0015673194138798863, 0.09493794277659617, 0.07268684887094423, 0.03712203382747248, 0.03078927842580015, 0.023860630390117876, 0.04387940345623065, 0.03950925573008135, 0.005071297309768852, 0.02797834215016337, 0.03671687314636074, 0.020073307932761963, 0.08105525412247516, 0.014915987358108396, 0.0548821880511241, 0.03261717516579665, 0.03447257033258211, 0.040038570296019316, 0.013806350416416535, 0.0514568982180208, 0.0458347250969382, 0.04664638974645641, 0.04596444880007766, 0.027933176897931844, 0.014682374112453545, 0.065483444777783, 0.051905541331507266, 0.016746217224863358, 0.07296307623619214, 0.04337753722211346, 0.023750052241666708, 0.023842898626753595, 0.03742366119695362, 0.020148153525951784, 0.01645439177082153, 0.03123778609733563, 0.027753846188716125, 0.04887431707174983, 0.030019127661944367, 0.03952986517106183, 0.09902394813252613, 0.04380599391879514, 0.016236298688454553, 0.08593751714215614, 0.0023884858728706604, 0.05820007798320148, 0.0048479001907253405, 0.035646076503326185, 0.0568754334381083, 0.06849865720141679, 0.014392401244549546, 0.03191091775079258, 0.009956546546163736, 0.02638775640662061, 0.007881430210545659, 0.04632417520042509, 0.02977755673782667, 0.061976730212336406, 0.03260563105868641, 0.033427043817937374, 0.04573986378090922, 0.02549215299950447, 0.01418855646988959, 0.021733670400863048, 0.008133912560879253, 0.07970729129738174, 0.03174994591972791, 0.03418801978114061, 0.014568179849447915, 0.06451449677115306, 0.06059326675313059, 0.05055365996668115, 0.08629728807136416, 0.025952637079171836, 0.044593798520509154, 0.0395080052112462, 0.013790616885671625, 0.02959061344881775, 0.040651487797731534, 0.042693440336734056, 0.04264222472556867, 0.06938888560398482, 0.04701696634583641, 0.013744407060585218, 0.02827682652423391, 0.04189186147414148, 0.034220937741338275, 0.05981297268590424, 0.08329652526299469, 0.0177611338585848, 0.0871116244525183, 0.022700692534272093, 0.06275140622165054, 0.046810237399768084, 0.015591439150739461, 0.031105796988413204, 0.03353144544234965, 0.054436747304862365, 0.061328141382546164, 0.05519505895790644, 0.05449763310025446, 0.020611082982213702, 0.03654456500953529, 0.012414577686286066, 0.10370238029281609, 0.042763499077409506, 0.045137429115129635, 0.0570819248969201, 0.016777092423581053, 0.07330103544518352, 0.1552260495373048, 0.06755764363333583, 0.09198369778459892, 0.021206736273597926, 0.07629546773387119, 0.027906945688300766, 0.025692189628898632, 0.02980650977406185, 0.04437723240698688, 0.036639096069848165, 0.019982624908152502, 0.037209325237199664, 0.02044211265456397, 0.028648074767261278, 0.019595849080360495, 0.028786297916667536, 0.06815396671299823, 0.003746019851860183, 0.07788124436046928, 0.04798974383447785, 0.05899295516428538, 0.03477515507256612, 0.04111102192837279, 0.04423756392498035, 0.054747454851167277, 0.05642782190989237, 0.030655010923510417, 0.0690385622147005, 0.0464192740037106, 0.022830035886727273, 0.02255240957310889, 0.0245020964575815, 0.015966093851602636, 0.03171577372995671, 0.04164894540735986, 0.02709364274778636, 0.0396548502612859, 0.04295122162147891, 0.036243757713236846, 0.0630754501617048, 0.04017890300019644, 0.024410489459114615, 0.0733636504446622, 0.06695922769722529, 0.025737167488841806, 0.03118005442956928, 0.029677825077669695, 0.0219132812708267, 0.04219886570353992, 0.03833020200545434, 0.03882786026224494, 0.03314927649626043, 0.018317705653316807, 0.01661136713664746, 0.10811611064127646, 0.0402641869004583, 0.027652331518766005, 0.09205435766489245, 0.03027053018740844, 0.09253425261704251, 0.031182321690721437, 0.030463158327620476, 0.016973941528704017, 0.02440441126964288, 0.01287846172999707, 0.003417603734305885, 0.012583127772813896, 0.015033374711492797, 0.017465408418502193, 0.03174068020598497, 0.07644288052688353, 0.06362679167068563, 0.07863704755436629, 0.07566919157397933, 0.016591677958786022, 0.04174556932412088, 0.0503678744280478, 0.009513201439403929, 0.08550802886020392, 0.0034511622607169556, 0.05128922850417439, 0.010436578795633977, 0.052729258459294215, 0.04226000753988046, 0.04188324513961561, 0.02511788421543315, 0.005826882961628144, 0.0074887482787744375, 0.0008926667055675352, 0.037885956116952, 0.03031422042113263, 0.02341615443583578, 0.09966062920284458, 0.06417157259420492, 0.13427425583358854, 0.018669734126888216, 0.02428677715215599, 0.11822894142824225, 0.13590515503892675, 0.16306030884152278, 0.08621808607131243, 0.1520314600202255, 0.13730313861742616, 0.11025878004147671, 0.1818451055441983, 0.12543348100734875, 0.15118156734388322, 0.17014841287164018, 0.1220076011668425, 0.19504844705807045, 0.20593183493474498, 0.13512524688849226, 0.08698459845618345, 0.12791136367013678, 0.13650488457642496, 0.1542467559920624, 0.1966750418068841, 0.09622368394047953, 0.1507710260921158, 0.1421368058072403, 0.11357019844581373, 0.17568084178492427, 0.07698115281527862, 0.11614279399509542, 0.15158746275119483, 0.12715824705082923, 0.135507081868127, 0.06581640933291055, 0.08927445800509304, 0.14827659353613853, 0.13909184810472652, 0.15724101016530767, 0.29801880999002606, 0.08626418086350895, 0.23490888706874102, 0.21138957410585135, 0.2044594139442779, 0.1319004371180199, 0.19092773145530373, 0.2460688288556412, 0.11235645302804187, 0.08579984874813817, 0.09553614348988049, 0.13627260719658807, 0.1798012011568062, 0.10968663613311946, 0.14870132465148345, 0.13323657010914758, 0.19302931556012481, 0.07309635853744112, 0.1915829736390151, 0.1297113241162151, 0.10581649185041897, 0.09973636537324637, 0.17104936530813575, 0.13509271113434806, 0.13258198101539165, 0.07144211878767237, 0.17173739557620138, 0.13416496716672555, 0.1463028517900966, 0.13033165567321703, 0.10025248455349356, 0.1959032824379392, 0.10358252344303764, 0.18793997849570587, 0.07461134911864065, 0.18437851569615304, 0.09404777374584228, 0.17356909025693312, 0.21696320705814287, 0.11174043334904127, 0.10447191321873106, 0.14203254890162498, 0.11703161231707782, 0.20314536726800725, 0.16342255112249404, 0.1650690205860883, 0.10949613424600102, 0.06629062685533427, 0.23927598085720092, 0.09320991870481521, 0.20515266893198714, 0.09164111499558203, 0.13162201299564913, 0.10850417966139503, 0.12090257296222262, 0.13106224068906158, 0.14099239924689755, 0.2286166770500131, 0.196326840959955, 0.19112873473204672, 0.17202080693095922, 0.06780470459489152, 0.21270721277687699, 0.12816768663469702, 0.11435288222855888, 0.09141396585619077, 0.08425634485320188, 0.13984324294142425, 0.2294905559392646, 0.16486758686369285, 0.11822615095297806, 0.19520811270922422, 0.13960333628347144, 0.20888429135084152, 0.2003645696095191, 0.15010132687166333, 0.07242706749821082, 0.14709217037307099, 0.21859198372112587, 0.07423951828968711, 0.11593457704293542, 0.12340755885816179, 0.15515266597503796, 0.10293934858054854, 0.13657305826200172, 0.11357747891452163, 0.11865790278534405, 0.1539157729712315, 0.12769796652719378, 0.09402294890605845, 0.16693673911504447, 0.16535681061213836, 0.1298402648535557, 0.08490262189297937, 0.22298278170637786, 0.23417517018970102, 0.12118894548621029, 0.10587267242954113, 0.2217574810492806, 0.13679175433935598, 0.12674681522184983, 0.23971873131813481, 0.12490628898376599, 0.1553784718271345, 0.12788423075107858, 0.20791408169316128, 0.1289968437049538, 0.166431306861341, 0.1261318419710733, 0.146211537939962, 0.12480584671720862, 0.14241459168260917, 0.11529468247317709, 0.09264288077247329, 0.23864206799771637, 0.131064007000532, 0.15365208790171891, 0.1389116101199761, 0.08512139960657805, 0.16761391918407753, 0.11420795563026331, 0.11192847872735001, 0.3075861622346565, 0.1594434372964315, 0.19352265080669895, 0.12066438066540286, 0.19539569795597345, 0.11510630312841386, 0.2032534684985876, 0.1461086020572111, 0.1975441857939586, 0.13535850390326232, 0.1221392433217261, 0.09785977817955427, 0.09079704817850143, 0.10189132473897189, 0.1863708408200182, 0.17352123657474294, 0.29098550614435226, 0.08812729065539315, 0.17313456279225647], [0.04163106335909106, 0.04064763605128974, 0.02094410505378619, 0.023239196743816137, 0.028845257838838734, 0.039340075745712966, 0.03549720910086762, 0.018531447894929443, 0.031393540630233474, 0.06734466951456852, 0.007227766018331749, 0.009664838908065576, 0.06526660406962037, 0.061935793346492574, 0.05918812516028993, 0.05559288721997291, 0.016322859082720242, 0.030516394435835537, 0.03943138217437081, 0.03288771025836468, 0.017747263118508272, 0.009718113051349064, 0.06449571301345713, 0.011753948438126827, 0.07047860330203548, 0.04748602965264581, 0.03252952381444629, 0.03613491433497984, 0.027989940062980168, 0.07078062029904686, 0.0292893645746517, 0.13281016174005345, 0.0834389211377129, 0.008573573832109105, 0.005923491107751033, 0.06993771123234183, 0.020439774889382534, 0.008900103039195528, 0.026974008542310912, 0.033641491099842824, 0.008297890090034343, 0.019502828290569596, 0.0849942177592311, 0.004934775997753604, 0.02069951173325535, 0.02500324095308315, 0.037917137451586314, 0.031870036546024494, 0.017270859971176833, 0.029280395719979424, 0.07583889106172137, 0.07812095806002617, 0.04983281934983097, 0.024257907607534435, 0.04987170046661049, 0.05427223914011847, 0.027797141228802502, 0.03256869065808132, 0.011900648769369582, 0.047859051628620364, 0.023514058557339013, 0.025544923410052434, 0.020349321930552833, 0.04453302033653017, 0.02578556664957432, 0.10191676556132734, 0.03192576070432551, 0.027088425449619535, 0.08887837379006669, 0.07730799465207383, 0.015446167453774251, 0.033367991127306595, 0.014739912821823964, 0.021117891919857357, 0.015434504603035748, 0.05205416011449415, 0.05250369751593098, 0.05760461208410561, 0.016809333174023777, 0.036052168579772115, 0.008299238943436649, 0.0296070019248873, 0.016969269709079526, 0.026363514152762946, 0.0368919903121423, 0.08853877443470992, 0.000939321181476771, 0.0363737263251096, 0.02125475508364616, 0.01887193040602142, 0.047220667329384014, 0.04591197895933874, 0.0999388455238659, 0.11550422786967829, 0.07169865697505884, 0.09015768795507029, 0.05186178059375379, 0.023756635091558564, 0.1237407312146388, 0.036698931726277806, 0.08587093907408416, 0.07558454220998101, 0.04153736721491441, 0.11228621617192402, 0.02724438778386684, 0.035650195422931574, 0.013482710946846055, 0.04918603764963336, 0.051702960990951397, 0.06461500583100133, 0.05674360574630555, 0.06277076143305749, 0.03476306919765193, 0.02494606775144348, 0.03858817624859512, 0.030979999246483203, 0.022157217790663708, 0.02943852883618092, 0.013437528996291803, 0.017323326101177372, 0.066715617722366, 0.08732866554055363, 0.05052510212408379, 0.046193427333491854, 0.07702784132561646, 0.022071941311878618, 0.07480708314687945, 0.08198939540307038, 0.05802595158456825, 0.03518850164255127, 0.04827445765840821, 0.052031520899618044, 0.02864526388293598, 0.06666394940111786, 0.011849440579680959, 0.048343225062126294, 0.028465385839808732, 0.040691734466236085, 0.03409722543437965, 0.015544407397101168, 0.021863162182853557, 0.07928840830572881, 0.022501472267322242, 0.017216341802850366, 0.02208944300946314, 0.028332155488897115, 0.03256222284107935, 0.01545542110761744, 0.03551876849087421, 0.020878176364931278, 0.03517183300573379, 0.013516681829059962, 0.03387564982404001, 0.026614386042638216, 0.048564296012045816, 0.005249855257716263, 0.012609014811459929, 0.015649909255444072, 0.009715489559312118, 0.03740562329767272, 0.06262372713536024, 0.04420474244398065, 0.03580304815841373, 0.013833796892868122, 0.07155399754992686, 0.057506489029037766, 0.01941650167282205, 0.050057163171004504, 0.01118372298151371, 0.03238968092773575, 0.0371948867541505, 0.10334439051803201, 0.06455913695390336, 0.025267903802159708, 0.029158165853004903, 0.002414200594103022, 0.024179147185350303, 0.019430734209890943, 0.026582585014693905, 0.021463588018377777, 0.04541971240541898, 0.015545515980193159, 0.04082402228959836, 0.06932359145139344, 0.07375396075076424, 0.0446917657245649, 0.016832660730869975, 0.010727863409556448, 0.09199557956890203, 0.018459862185409293, 0.04758602663059719, 0.031010147140477784, 0.003968817454733653, 0.034190732330898754, 0.07457145125954412, 0.046162591097527184, 0.0430778839654522, 0.04538338056590874, 0.026298453776689712, 0.05449712843983434, 0.05746852817537729, 0.025541541072016116, 0.0017481834697719023, 0.057009895754163153, 0.03918847352906596, 0.037157181941438466, 0.032594966396573, 0.07004118146141991, 0.06558330816915259, 0.020822530132136308, 0.01808472694392549, 0.02970387075038161, 0.03927125268091913, 0.009542112729832297, 0.029047424432064872, 0.03992586032836698, 0.04869594187766779, 0.034141524229198694, 0.059769493964267895, 0.053512075828621164, 0.02906917863583658, 0.06609987263800576, 0.049203919697902165, 0.019295932361274026, 0.026582071077427827, 0.05712384881917387, 0.03697780855873134, 0.00330214039877319, 0.02599363146146061, 0.06770588021026924, 0.06195687776198611, 0.031239177624229342, 0.041683080489747226, 0.024622010823804885, 0.020958649292879272, 0.06212977219547611, 0.029312048318388406, 0.024190962176362518, 0.0714656374475453, 0.04080142760358285, 0.051134750465280376, 0.0523709013214102, 0.022442408444476314, 0.021732516361225862, 0.04691108042607084, 0.0705248316808138, 0.04854736020206474, 0.037508429304580204, 0.03953614745114464, 0.009694381024019094, 0.005441541798063554, 0.04437532879819628, 0.05096979330119211, 0.04267107942723669, 0.04607248323736712, 0.02451211359584704, 0.0358022577711381, 0.0549988907732768, 0.057685097999637946, 0.012915577462990768, 0.023338655664701946, 0.036424385325517505, 0.01590108913660515, 0.039474686491303146, 0.028338903466647025, 0.030443636132986285, 0.003929905260520172, 0.03157651342917234, 0.04794117026904132, 0.028004486157442443, 0.07527805006247945, 0.061285979973035865, 0.045720352718490176, 0.009069059451576322, 0.0501837587216869, 0.04141097575484309, 0.0297067948122276, 0.07536338220234029, 0.024981948736240156, 0.06274666389799677, 0.037806754116900265, 0.017414066642231774, 0.015407367973239161, 0.035034179454669356, 0.026749289936560672, 0.022603291217819788, 0.09833303833147511, 0.005759714422310935, 0.03172860175254755, 0.021858635082026012, 0.02527056811231887, 0.03978408785769716, 0.041969237790908664, 0.035841840217472054, 0.009420614806003869, 0.03497513789625373, 0.09315266943303868, 0.014545498888764996, 0.09451416903175414, 0.037956385931465775, 0.02272646175697446, 0.042554365572868846, 0.05285363869916182, 0.0766362322610803, 0.018962618996738456, 0.030472305297735147, 0.050464587402530015, 0.04571664940158371, 0.0258086771282251, 0.05890037595236208, 0.03835393217741512, 0.025036203442141414, 0.03171578486217186, 0.04171647713519633, 0.010239647126581986, 0.05433624566649087, 0.02581347511295462, 0.01789568894309923, 0.03324414894450456, 0.03142346402455587, 0.020865617370873224, 0.05152758036274463, 0.05074824366602115, 0.02428802581562195, 0.03797912162553985, 0.06999236298725009, 0.07661747818929143, 0.014237040049920324, 0.03655728170997463, 0.04769051731273066, 0.06168216066726018, 0.044190689877723344, 0.02574043108324986, 0.020838235832343344, 0.02436593647871632, 0.037958348912070505, 0.06681669823592529, 0.014935004892322468, 0.05504548651515506, 0.0224823155804188, 0.02920026603533188, 0.031897544249659404, 0.03797785997448955, 0.058538193043204956, 0.015187007629720028, 0.07365023819147609, 0.04806454118806869, 0.04480737748963293, 0.09301891957875341, 0.030443621290032752, 0.015852749347686768, 0.02623345091706142, 0.14596707449527457, 0.13241817418020219, 0.0979902180552017, 0.08760004668147303, 0.1576337101869285, 0.1010655147547368, 0.06785710764233954, 0.1340058952337131, 0.10495384165551513, 0.231233311642427, 0.09101449002628215, 0.07007970634731464, 0.24606494000181556, 0.13378504692809656, 0.134631629625801, 0.10501123193535022, 0.08563447598135099, 0.09504409958026372, 0.1169229470542632, 0.2012821164680645, 0.18026023433776572, 0.08423599516390823, 0.10033670347183943, 0.22594331268919632, 0.12960389081854373, 0.08871398065821268, 0.06266658616368659, 0.1550076503190212, 0.13331082940567285, 0.14317334862425923, 0.12786867533577606, 0.17433663422707468, 0.18876241170801222, 0.07680369046283886, 0.11103781245765276, 0.19489697471726686, 0.15834784921025857, 0.149848566215951, 0.11126620840514079, 0.17230200668564066, 0.2125847287243232, 0.08860061760060489, 0.15461641974980012, 0.1381627534283325, 0.11526910064276308, 0.19743206212297082, 0.1468049146933481, 0.11358060335624032, 0.10888234101003036, 0.2394849102711305, 0.14324468385893852, 0.1740517682628706, 0.08350099436938763, 0.2372291820938699, 0.18989500327734277, 0.21993366797687486, 0.10630033502820879, 0.09695627275505103, 0.12155391144915484, 0.15196793217910454, 0.17495099891675636, 0.08442730599199422, 0.1323716266779229, 0.1557856288854964, 0.12685761786997318, 0.20729419542476535, 0.159467542252969, 0.10613209757138975, 0.11972271400736645, 0.15334684256231412, 0.15486299089388922, 0.08112132010865025, 0.16832041408633813, 0.17924436775501817, 0.07344627374550328, 0.13024863903410733, 0.14112926612142473, 0.1602370454929769, 0.15322655526688322, 0.16053144063334912, 0.07262735831318423, 0.1339167929836549, 0.15135799068957567, 0.1523061140323989, 0.1387360179796815, 0.12240536263561808, 0.08265879776445217, 0.15977924427716061, 0.1739037098013796, 0.10042377965874039, 0.1377259846776724, 0.10966699148411863, 0.23778623813996091, 0.15644541301298887, 0.1881276973290369, 0.2646410744637251, 0.14412083372008055, 0.08305080758873373, 0.3039232478477061, 0.1690574557869695, 0.10708736037486233, 0.2602440572809428, 0.14501868397928774, 0.1917367021087557, 0.1372903143055737, 0.13543883396778256, 0.14331784477690235, 0.11682070879032835, 0.1470795983914286, 0.12038735178066418, 0.16779574536485597, 0.11810368174337782, 0.15922776918159798, 0.05047985709097702, 0.08996039541671053, 0.11046136409277096, 0.11680802548653446, 0.10979899729136378, 0.17273524281335995, 0.21605717833153903, 0.15807070158189163, 0.2187931799562648, 0.16844292782479897, 0.07270993708516471, 0.20136372302658856, 0.1933169868425466, 0.09777431245311163, 0.17829035175964236, 0.09942604374373332, 0.12332508398685604, 0.1836413107230328, 0.16852037835633382, 0.12354688224149868, 0.2001187257701531, 0.1945384283317253, 0.17045670101651922, 0.104100067546824, 0.15360197809059173, 0.110358398524113, 0.1924988135579042, 0.12404729757690802, 0.10342764464439824, 0.19048680667765439, 0.07919158029835671, 0.058354741559014656, 0.14956839062506333, 0.20251684240065515, 0.10989813337801024, 0.1960523205343634, 0.16847835795488209, 0.18230235757073388, 0.12674298573983833, 0.082063929294236, 0.10923972964519635, 0.16240040597040206, 0.20669918594649062, 0.12041303751175292, 0.15212017635349184, 0.13045917148701847, 0.14251709711970761, 0.171134652919136, 0.07836896897060797, 0.13245259498944506, 0.08269662503153086, 0.1651041241711937, 0.14106698508840054, 0.09065657446626574, 0.15089193679159507, 0.1959168043686077, 0.14375730010215193, 0.1238222635583952, 0.24696081614820287, 0.19596465805079788, 0.06490068073617294, 0.08020714260055684, 0.09884518702165224], [0.03885793950757943, 0.11762458088924177, 0.03559825992851984, 0.06775506975827739, 0.049955270005739294, 0.002095168470077624, 0.03992534453573171, 0.03570561530068517, 0.007653050033695763, 0.07450332210282795, 0.00758537126785086, 0.12185378363938071, 0.047728448480484076, 0.013308576199051458, 0.04840646717639174, 0.022452184384746943, 0.024044026213232428, 0.033476515382062644, 0.035805519510176964, 0.016042340248532128, 0.04597916187776718, 0.016168418151210062, 0.09649767744122073, 0.09096233188756742, 0.07653445412870497, 0.0348737790773157, 0.03202017302101012, 0.06645746907452121, 0.02107985499606002, 0.04422466168762185, 0.05209707480389625, 0.01727754672174342, 0.047737421045894735, 0.016365302508347668, 0.01714424401143333, 0.04082092011230998, 0.0686791400949005, 0.017881374769785907, 0.014253698482207255, 0.038089701629360206, 0.04888301504252013, 0.05104681709781289, 0.024224800399679225, 0.08117836900055408, 0.08013623781153001, 0.027669237642840017, 0.03565113052900415, 0.05692670099961106, 0.07664872260647826, 0.0038371316986740567, 0.07013248789007775, 0.06037748731614556, 0.06546489108586684, 0.03912837441021111, 0.02725472775637172, 0.059891881537623703, 0.03802973238634877, 0.011753691469493788, 0.09152749960776418, 0.004872928657277953, 0.04909575538476929, 0.014749395613762317, 0.023313817837333772, 0.0566047833126504, 0.0570850010990398, 0.01651222733926261, 0.06018153806508053, 0.021033288940088823, 0.036484035445027985, 0.03797772638790775, 0.060970708218519576, 0.02332594453037018, 0.03683067778183613, 0.0546301064605359, 0.018160299841838423, 0.09648952123825438, 0.01743419183185324, 0.07658408154384233, 0.03260800593125168, 0.01126084418501705, 0.046474504633806646, 0.082031705242116, 0.06302629772108048, 0.022723326183040626, 0.037996610335540026, 0.035391107958275825, 0.015045601594465552, 0.05496660363860428, 0.05638364928017836, 0.026020925797638483, 0.06321621331153437, 0.049813475270639174, 0.03678399669297505, 0.04416042138473131, 0.024078840360743925, 0.0471295538591221, 0.04250188088917639, 0.026065282108902466, 0.024286825391754974, 0.036733497254317626, 0.05625153215078171, 0.048583599273115396, 0.00957824697252363, 0.02537420717999339, 0.02264493869006401, 0.051792148587992415, 0.024880306045815814, 0.05236852273810655, 0.013974421817692928, 0.047925106482580304, 0.02678557353647193, 0.07984084077179432, 0.01407228883181233, 0.01058286816260079, 0.03843929400318302, 0.01590062900504563, 0.07496551683288999, 0.05624280820484273, 0.020998348627472296, 0.0465555842674803, 0.018580589203338604, 0.06003530528687406, 0.01963989925570786, 0.05080745220766403, 0.05221332481596619, 0.0422537586564431, 0.03225754524464719, 0.07407706958474591, 0.023393941955873743, 0.03448523879342247, 0.036986640116083436, 0.012843603053624975, 0.1065903514972888, 0.09937962982803583, 0.0312877437681891, 0.05165922993910499, 0.1186672761105001, 0.08011586585780606, 0.0032455706559630926, 0.053505270334426314, 0.03263831153162755, 0.0377483396732714, 0.05037133283622097, 0.013320821635716129, 0.043211845331825316, 0.0036874778515993967, 0.035647293625515886, 0.024667899670021143, 0.049983709104708396, 0.060581770885619335, 0.057879852392943576, 0.03256303920352366, 0.002168313385482179, 0.04705657847807743, 0.022445579270424787, 0.006460925233113812, 0.02914609111030586, 0.011998391473753145, 0.01262427893379936, 0.02426866503810743, 0.02722467263083672, 0.05843556144100148, 0.02354220636334503, 0.052451520823524334, 0.02577846244093962, 0.013075697679596487, 0.07951578008942306, 0.02787318910122849, 0.04041428255732171, 0.012365841776045272, 0.05446536451927386, 0.023765863697917666, 0.08099054626654834, 0.03191898860677611, 0.023291738943953533, 0.050073598031303845, 0.029461745070875622, 0.034777155160554685, 0.03647350436949637, 0.10033573867985979, 0.026815265009645373, 0.05357443107641302, 0.006361268715409096, 0.012084049230907112, 0.02763230095297331, 0.08239566188422032, 0.03523651488649193, 0.045885269064456224, 0.08464911166811362, 0.006756227185178432, 0.06805764336604625, 0.02381181748205563, 0.03635419299826026, 0.02770592942397343, 0.021621685882564634, 0.01580381955136545, 0.02553866524976911, 0.0634411360078957, 0.018627789795573335, 0.044648494804278016, 0.0031754196106703603, 0.00909631111426279, 0.03686916927108541, 0.027995604505122174, 0.0913087664230261, 0.018218254153907765, 0.04791303916135803, 0.024315091941389255, 0.05974541498289909, 0.05334531895641703, 0.0697252714599017, 0.06292796315392479, 0.016610791972198058, 0.03018480842001736, 0.044842596107628196, 0.025466990482527763, 0.0416214488359401, 0.027535495210031513, 0.021569475793512538, 0.0995197769952938, 0.03648924903245643, 0.03439553540374618, 0.030587520013796166, 0.01484309268562356, 0.07522521656937897, 0.009718343117128825, 0.03835277813777793, 0.07195648649940267, 0.021681590187654365, 0.03120058223430533, 0.07327240338781849, 0.06253186409594491, 0.051855160636478104, 0.04298746069252957, 0.07164142996771261, 0.09008967754198238, 0.05646645440720022, 0.00675944996146427, 0.010714737600210356, 0.061717616772511974, 0.029252431595523376, 0.019250520344940014, 0.03492903197184205, 0.012033075745421229, 0.0226331663725432, 0.019321807340020314, 0.0301108348503476, 0.05816047698317561, 0.03347945799760055, 0.024293940732604824, 0.005889308713449282, 0.05219863771344535, 0.033238404721487314, 0.08454748938675039, 0.03608647806686349, 0.02777699748548912, 0.06329009411274455, 0.0791808043140918, 0.03129117249045521, 0.029011120423092507, 0.05507779962499626, 0.04425982464454137, 0.032936996285570785, 0.020472973010328133, 0.07243324216688052, 0.026338923089497257, 0.04786048026289791, 0.04420064578880556, 0.08245425444329157, 0.018247793486807495, 0.02495930024451809, 0.006924019353391486, 0.021711840126954485, 0.016141673004312906, 0.05211737625359092, 0.024393071253143717, 0.03910060695488937, 0.009725026156957028, 0.0688937766244635, 0.04240213995217346, 0.043678344518411905, 0.04279120716091711, 0.02815926662151469, 0.041331736647407524, 0.03473209937510546, 0.04041064232296776, 0.030427926722040866, 0.04087054381670896, 0.037878260045545176, 0.014168388606776716, 0.044179951000842266, 0.027051947035943158, 0.058841597856371664, 0.01832269103033468, 0.037042720505269244, 0.02901836563978577, 0.030677857939735986, 0.06380712613463402, 0.04702120400907006, 0.03921710929716937, 0.048197003416134976, 0.018371338810538873, 0.026497065482544713, 0.03273403373896144, 0.0436269545025425, 0.02918407608376583, 0.007534744272561511, 0.015241167711792514, 0.05170877200725954, 0.04153750451223459, 0.03881034928781446, 0.030159877824189607, 0.08492500506690703, 0.09207564246025868, 0.03671679151011631, 0.02815154457493918, 0.04852335914620198, 0.07199798739748076, 0.05646775687637273, 0.034198135253973305, 0.02675387826457154, 0.0280903452221537, 0.007680312364755082, 0.02918354544817703, 0.037832528905710205, 0.032071941532194614, 0.047243848312064074, 0.06340435516904108, 0.03531992115313187, 0.03789843161939643, 0.02692788406420732, 0.04261416783265304, 0.011345893381076166, 0.021858744548808318, 0.05151036995812319, 0.013846106339769904, 0.02848997504770523, 0.08288818076835014, 0.01599146973603638, 0.061368606984615326, 0.039890292900963686, 0.01639905724005075, 0.04301883127482142, 0.047416271481779404, 0.04717202697065659, 0.026180302011198364, 0.09572453025612049, 0.044876033571199514, 0.04165976220974699, 0.03197494654159527, 0.059968300483888015, 0.02458291819493752, 0.1326813397463411, 0.18418140127323568, 0.17785871867090464, 0.20336447894806042, 0.12442087987437844, 0.14236091956263408, 0.14398500585230067, 0.0541652919491753, 0.07399672467727214, 0.21263660484692082, 0.15588348847813904, 0.2233726467238739, 0.12187991465907544, 0.0981957781186793, 0.24438014603219926, 0.09208528295857832, 0.0925423791341018, 0.08270501130027696, 0.10128165042260662, 0.09522530235699378, 0.12207216801471077, 0.2631507528712973, 0.10584194751572795, 0.16922826849622652, 0.15081427845871076, 0.08345547103090212, 0.10218540817731991, 0.16727627167711034, 0.20854751957813278, 0.13433595799142495, 0.22487239359179512, 0.1570057641947642, 0.16171708091860637, 0.1578365985187702, 0.12113906574086286, 0.1807419623946771, 0.11877400436787866, 0.15291734685888514, 0.15587010013405234, 0.11829292940092273, 0.17911708942847326, 0.1598079060204327, 0.1239044193062, 0.31001740833744407, 0.18419109372189268, 0.15233195561449975, 0.1257622821140103, 0.08698698075022548, 0.14430720184464008, 0.08077882637735456, 0.1108208678488154, 0.220508357451763, 0.14296680892584845, 0.16464886110043153, 0.17050388676580042, 0.14923507726052776, 0.1310979379923083, 0.13528325012885034, 0.15257879393175244, 0.2202130717341788, 0.15799007465830073, 0.04860786008066498, 0.1106767427700106, 0.1365306371008046, 0.13555498007917777, 0.14315540349343792, 0.15370668028481305, 0.1034429477294907, 0.1272243427229114, 0.13169833546271548, 0.19770802231505513, 0.09254913267795928, 0.13230750511866063, 0.12060978828230873, 0.06707400825689547, 0.15380066586658359, 0.049640617944533005, 0.19568152871215716, 0.10963533146423288, 0.07591507252072915, 0.18937336251838133, 0.21030940784839913, 0.12363993271719664, 0.1071604470780585, 0.17841041641077027, 0.20177953352686018, 0.17793588718632236, 0.11516280283103697, 0.16366642084904015, 0.08726286672754213, 0.15417187329148874, 0.13216415187343955, 0.13741284288698807, 0.11423730014939792, 0.1359715624130331, 0.11559479215065949, 0.10552808584179729, 0.1463585573947057, 0.13173058920074254, 0.16165595763595775, 0.08318118067109026, 0.11663378405501135, 0.12956841615960002, 0.08486526217893697, 0.110994203860173, 0.16629927878966555, 0.12394685531035066, 0.1462581448140554, 0.09733562896144576, 0.2642307261703536, 0.18423649831674993, 0.202066536876373, 0.11840244071208872, 0.11356798684573732, 0.11189711556653492, 0.1493958561331965, 0.1681480577099137, 0.16275047702947631, 0.14682860404718667, 0.1405859546503052, 0.0985154730733484, 0.14388831885298714, 0.11288562658592127, 0.12118111582822166, 0.1327655289787799, 0.1913229250931181, 0.09581704638549127, 0.15779860055772588, 0.1155259356892202, 0.10029159573605284, 0.08764679456362501, 0.1452221066574566, 0.1633348292671144, 0.21099356410559267, 0.1584283128613606, 0.148395782453008, 0.26012988528236747, 0.20760123676154763, 0.08135175696224906, 0.15597849822370335, 0.07886698716902174, 0.18044605327304453, 0.12053450482198969, 0.100756773899775, 0.15545528411166742, 0.12272442676476203, 0.15948286018101498, 0.06034376783645712, 0.281041914713569, 0.13564865395892411, 0.1247721235267818, 0.16948310716543347, 0.1534818540676497, 0.16192906798096374, 0.12520397925982252, 0.15279305196600035, 0.06694887473713607, 0.09006346488604322, 0.16485700383782387, 0.09590203713742085, 0.08422148617682979, 0.16577437258092687, 0.08074523677350953, 0.07706660369876772, 0.12237776958500035, 0.06328403076622635, 0.17078630364267156, 0.19816134095890447, 0.11222480345168151, 0.10489277032320388, 0.27338781917933375, 0.07695183056057431, 0.12899636873044074, 0.09493712641415186, 0.2145202795509249, 0.23104433115804568], [0.04689296460128389, 0.036270356285967864, 0.012432516323315213, 0.03287154628196731, 0.02967714230180718, 0.06555882471730001, 0.01945669082488166, 0.024476347643940244, 0.10467948450241238, 0.004004604279543855, 0.03814797877566889, 0.06824703945312649, 0.05512390926014632, 0.04682341794250533, 0.02534581446525408, 0.12533001077827066, 0.05751091965066735, 0.04582276538712904, 0.03536245734721888, 0.014875151609885506, 0.0636118151305709, 0.04813563893549144, 0.03566366169252433, 0.04944915126543492, 0.011633836475084536, 0.0673701029154472, 0.019642981023935135, 0.00993430530797923, 0.052066130956518464, 0.030225528207665775, 0.010457308835611911, 0.00469728363896138, 0.04488624552323017, 0.01804412589990534, 0.041616483867983334, 0.019134754584229086, 0.04399962395837065, 0.01689953380264342, 0.05523982901650015, 0.05366216035326943, 0.05193788412725553, 0.07672744221054018, 0.031213543843477964, 0.009952912805601954, 0.008271241422335152, 0.008069379109656438, 0.004096877355550532, 0.03228412155294791, 0.02298334875376895, 0.012446697837731335, 0.07076201465679333, 0.03479918210359756, 0.03894837020197883, 0.036308766138972715, 0.024077921952994075, 0.005316607266649953, 0.013699370756512508, 0.0733104458777234, 0.07390623461105861, 0.03916695866791997, 0.022983218877925538, 0.04215294531604741, 0.04772820357175078, 0.05011367400584277, 0.021054807511973195, 0.03604014949814882, 0.014275086250563618, 0.025155759722110815, 0.025537175388308242, 0.01704619517113315, 0.04176952214038465, 0.03633721265941858, 0.0370380820822902, 0.031561663054162636, 0.022388817960745655, 0.07215147095848806, 0.04650033137295395, 0.020873573193966877, 0.06636559861362912, 0.04846914154768456, 0.027756347226386424, 0.024227624271588866, 0.0725688028614968, 0.05728618991270196, 0.020005186197522562, 0.019950601235905197, 0.011614955310506048, 0.044595086146728136, 0.04681097954744473, 0.10093000601045787, 0.009115152388403658, 0.047452065264224075, 0.08094581702607684, 0.014080475648370339, 0.03801580969593488, 0.04217109082674142, 0.04699893215729389, 0.014807274783379398, 0.027717790799215436, 0.019794622203335166, 0.029981370898894966, 0.06993157367105596, 0.07028754480415955, 0.02491926323273219, 0.008888172087608837, 0.051114174420945346, 0.04366135675809346, 0.02138636940799188, 0.07069857587339357, 0.011846885736304102, 0.03801450351602398, 0.030230636039050296, 0.018038201706076507, 0.02348290876398096, 0.03340590003062971, 0.03718308660609182, 0.02309066887391964, 0.024501100124325603, 0.021388568020483945, 0.010382435411884217, 0.04215098233544268, 0.11383028409909457, 0.07083249642164446, 0.02226054886705242, 0.04268686861905735, 0.0973701239854563, 0.022337027185130864, 0.02714470621867804, 0.014180994912749156, 0.03660345813841559, 0.053312686723074876, 0.025261426708311774, 0.05064564917120151, 0.06423327475204132, 0.057173598688677885, 0.022252003036555834, 0.029884557734476402, 0.019414954294916242, 0.058821378042921424, 0.07467531482689083, 0.03867532293952536, 0.048440450118505396, 0.06010475546645466, 0.029143113242753316, 0.025962815634557046, 0.03238326506107114, 0.03150418742734473, 0.03398225562705193, 0.026569539913907647, 0.05658520916767884, 0.0378004829690326, 0.021562540423474275, 0.05429075943538919, 0.04692128495662473, 0.01388285934808664, 0.06407829205272719, 0.0005706906904379139, 0.06838604371296242, 0.03819625919277314, 0.027829161190311424, 0.035563783458201215, 0.05401386042649392, 0.02808604076562915, 0.0140179395020823, 0.022386198179447092, 0.026331097142247017, 0.014601534749090206, 0.04005683083960321, 0.022182170650921762, 0.04466852165933233, 0.026837509030883666, 0.01572527991811512, 0.07026312814559788, 0.07110969600034878, 0.027807787337224, 0.01833718517445959, 0.0122292151718284, 0.01838979973399546, 0.023297034167626407, 0.016514290509803686, 0.016875191358849406, 0.023717972908343654, 0.011538237649801886, 0.001709729087906453, 0.07493870303733274, 0.012788034746336052, 0.03309065054054372, 0.03415740990021732, 0.023226893790706526, 0.05340898780559655, 0.022274838920566253, 0.0600432425562758, 0.050058703127433546, 0.09253931406419724, 0.011593221515795449, 0.06796434056013823, 0.058471711454330944, 0.037574357993435115, 0.09669229824794456, 0.08715542600839399, 0.028975207897019573, 0.0354125152080087, 0.02922387189755682, 0.026610413697198965, 0.011408333975850837, 0.05889601954550017, 0.04416043622768484, 0.04271243931725621, 0.05598832205578219, 0.01854711092164507, 0.025429330198676325, 0.013634435617859708, 0.08147777363774367, 0.033840308751678094, 0.06375475277309306, 0.03309029802039731, 0.10088242692290805, 0.04275901650544256, 0.008215935649786843, 0.04061107414599974, 0.027915061073144898, 0.01232504220752162, 0.053023278815089725, 0.06384830048773438, 0.05704631665139459, 0.05807160850963555, 0.03284325932327192, 0.017263486734009348, 0.051868107402697206, 0.04136891082453076, 0.03365422635397408, 0.04558484397421125, 0.08648770832223818, 0.015273196022462798, 0.05415417086624075, 0.07168466749135405, 0.04037375016196165, 0.040645316839800216, 0.0399536760232877, 0.03447933129791636, 0.06528509096824564, 0.056387864678981714, 0.008607091076555662, 0.010908414951700252, 0.03431247423577588, 0.01694239839707734, 0.010847287958313245, 0.04565714029013179, 0.07593270594952628, 0.024968489888124168, 0.0194010427367175, 0.05868492306035478, 0.11359994372469373, 0.054185519184102304, 0.041880347052938305, 0.04038328675960656, 0.04447690283996053, 0.016027282072172966, 0.023989539586182218, 0.08075085483142175, 0.04831234800803941, 0.054305290686897933, 0.021757304093625862, 0.07402932722470723, 0.0395718558866065, 0.037445966445375234, 0.019831432728096843, 0.06251246435567737, 0.052996928861830384, 0.08001789494301192, 0.030471524187305477, 0.03920452618331183, 0.04617435784894042, 0.038134052374516614, 0.026749210155685432, 0.01777149795088917, 0.03544273546140175, 0.022704984003212303, 0.07565992214949802, 0.02572985176811926, 0.06374016957124695, 0.06407988024875522, 0.03861129785946105, 0.026845383217732888, 0.052273947148933075, 0.03005464684974868, 0.059637465892592445, 0.015799587454239372, 0.024832593371684197, 0.02791088834783295, 0.012120991486881394, 0.1397711061872542, 0.05610103573417291, 0.011179002922290238, 0.01729916548356414, 0.03864807127683889, 0.03938281974114943, 0.09067675346159376, 0.05791619165393058, 0.04233975130773615, 0.015087424399098381, 0.05058242932136636, 0.041588208041503094, 0.0487136012816336, 0.01697013616649201, 0.02555917264544405, 0.07556586235295981, 0.03490521645289846, 0.08887464820872992, 0.03882312164932955, 0.040697541771805845, 0.017704268648230936, 0.06846927557489835, 0.03667256693006493, 0.04546762545942329, 0.033166305074701086, 0.04025158523290884, 0.059835790016222745, 0.1447790741804056, 0.024906399958126713, 0.042950679853674956, 0.007877712050685659, 0.05434209007944446, 0.011765576964535285, 0.008284268897114089, 0.05702899121388327, 0.038585623260587454, 0.051962037323391996, 0.08323878617375158, 0.0180242381975404, 0.10560151393292472, 0.02264702783577377, 0.0383943495398853, 0.03556806936103385, 0.06424684121157043, 0.008092563803074881, 0.040438925570924766, 0.02269551419885829, 0.015082477984833531, 0.01535104916911223, 0.05978210305329412, 0.01243212947883876, 0.12894710496766493, 0.05239748876192607, 0.10197090523433872, 0.031090043048607185, 0.012513500405475497, 0.027901444518647622, 0.007832776864233892, 0.033726826950442046, 0.03913398875738494, 0.03855993752949871, 0.23384331143461168, 0.11313541865092702, 0.06561197733390145, 0.10808798324433155, 0.13714166212594137, 0.19362292980076745, 0.10882086891797371, 0.08079332052147947, 0.2481745244585909, 0.13266174704767764, 0.16667611169395968, 0.22222607309231535, 0.1180474937427789, 0.13546141010010615, 0.1184178922267165, 0.11452389531768858, 0.131518067792058, 0.21702651225496083, 0.1048140655620955, 0.1437635489855893, 0.14423766260733828, 0.11330416818964295, 0.15828448464162648, 0.19550982542568818, 0.1562263013329357, 0.12205236009322107, 0.08010648511117324, 0.16083658207207918, 0.11741997077479027, 0.1873629735200666, 0.09169659053441137, 0.18683394097024575, 0.16034189611673355, 0.11789417345426045, 0.08618953565019183, 0.12433477590093389, 0.1766190500347875, 0.12931486882735044, 0.15300676081096753, 0.10086704962304793, 0.15071080822963268, 0.1810099816066213, 0.12841746385674924, 0.1569126988761127, 0.0668866976047866, 0.10595470943371765, 0.12490130175137892, 0.11697594381985255, 0.10323720212909393, 0.14216837676940486, 0.12416685756761581, 0.16704001638572663, 0.1608150894753635, 0.10759408396552317, 0.22898442606674507, 0.13669851090526208, 0.19164718425599858, 0.13086194987408817, 0.16496381373144686, 0.2046536488342099, 0.0978151528397575, 0.1543966104509309, 0.09071397958905436, 0.10232000407995656, 0.1522361146635376, 0.13384677877184004, 0.15030338399810717, 0.1855626271571964, 0.1178875683399383, 0.15293321397621185, 0.1301452875486575, 0.10152322691283189, 0.17586961446795613, 0.09616190756787546, 0.06137215816124808, 0.13001637649722397, 0.21820470137754455, 0.10220281154033728, 0.12544027908006683, 0.12963035580469295, 0.11524136658408679, 0.10821644158568233, 0.14930829755030572, 0.16242934972979128, 0.10506428065127693, 0.14213023037882522, 0.11093668741523288, 0.17075655836379156, 0.18291457003215328, 0.18722670036368072, 0.15019547572592273, 0.1319567215978168, 0.1492914804839529, 0.252728060586378, 0.15462571143871173, 0.13357096700929105, 0.10441560647450387, 0.09832005816861056, 0.10147069027880207, 0.11663964702165686, 0.16196378564927727, 0.15444489457877353, 0.1761013426585123, 0.12974351848242804, 0.16725549154216424, 0.19175473629729822, 0.24382087838603184, 0.08009196128114127, 0.19895579520380124, 0.1806102311820723, 0.11622207763139158, 0.17951179324882105, 0.11525291440193541, 0.06896532708196901, 0.10783636549604125, 0.1352275296812877, 0.11732848623069003, 0.09866031803539954, 0.060744223301298916, 0.1218836847692728, 0.10598312626825646, 0.20101832749787718, 0.24854366871295497, 0.269183493219316, 0.16175167984329164, 0.18306383077288046, 0.07835946948034689, 0.12862709088949487, 0.08643220309750177, 0.1469196507241577, 0.1709021528949961, 0.098705366399372, 0.2155250881332904, 0.16924814321100712, 0.13777379383100197, 0.1832036068663001, 0.21952394308755174, 0.12177383207017556, 0.16795193776488304, 0.19220170215703547, 0.09994159889174625, 0.17700346768833697, 0.19634241121821105, 0.1904991560149938, 0.06943236803635955, 0.19074565294431522, 0.141414443787653, 0.08259761510998942, 0.14039538596989587, 0.21999848715495318, 0.07978222594829276, 0.11224855959881097, 0.18880447663832456, 0.09745096613187343, 0.20213466603308916, 0.1729967608116567, 0.11798341671237722, 0.14735747332451865, 0.1739444537088275, 0.0720656341582071, 0.16517991229193285, 0.10031711077317595, 0.14512179797748104, 0.05561911100812722, 0.11267942085396498, 0.11878658377099782, 0.2872191066853702, 0.1078307103307452, 0.22252220485825092, 0.17313359800027683, 0.17732276930473745, 0.09383856973727234, 0.1500435284106061, 0.14546933089150116, 0.07586418345454149, 0.09455344348680228], [0.08719788427697495, 0.027825860488519538, 0.046784637015662156, 0.09870719208265655, 0.029767840169370174, 0.03294837712019216, 0.022105391763034277, 0.00972534435277339, 0.039904304649098776, 0.027586347168835346, 0.12201448087580502, 0.021777848596684635, 0.028233464690856636, 0.03331312786031049, 0.018281184566149022, 0.06158318414236419, 0.05126691954501439, 0.0434808404679643, 0.018522915052017197, 0.04532824270427227, 0.04876901373791043, 0.03452474331425037, 0.0313325620663818, 0.001974613073798537, 0.035681580848176964, 0.04753973516926635, 0.1051659623044543, 0.039698633263469674, 0.031109043884498533, 0.05338899063644931, 0.01702250952803297, 0.012728439360216726, 0.07137093198252842, 0.01633229920116719, 0.016354112776753027, 0.05886232975171879, 0.09527716363663785, 0.05574984403210692, 0.012995452962059062, 0.036485516029642895, 0.04895887366728857, 0.03165003057802096, 0.011724547330231871, 0.036382465114002116, 0.06788979924749583, 0.0508884168084478, 0.027374386081646662, 0.016385128983529285, 0.04603640001732856, 0.05731629513320513, 0.04182195116300136, 0.04312925542762969, 0.023659001853957307, 0.05648508602462243, 0.015272497475962155, 0.042863967319135554, 0.0346601407363778, 0.08391179537284188, 0.03270578759838827, 0.012018213310511783, 0.01680101740930695, 0.06034040961822029, 0.03652830084320158, 0.057502425770508125, 0.021112999311299063, 0.025280535155616235, 0.05054932953498792, 0.09492294397205114, 0.07837359997211024, 0.06098639722040389, 0.014099934760452015, 0.020527012493403163, 0.03346894547576085, 0.012595677490025992, 0.01093066453904612, 0.048842282267287374, 0.028128287522122264, 0.06501940952148288, 0.03934648790163919, 0.013664775542565621, 0.03836231473542284, 0.01954623465280747, 0.0316236398066394, 0.0266704497335013, 0.008243070424214238, 0.04362448315077927, 0.05285869643557817, 0.07636912589077838, 0.016870126200956292, 0.026552080889814533, 0.04983690116205253, 0.025935033336281776, 0.020412909143487923, 0.014722954747412587, 0.05911346881475765, 0.016514446360815782, 0.03885943864588626, 0.02122344943927601, 0.020219588950567413, 0.03346651494211983, 0.025324175294372253, 0.03446925664320588, 0.02738499879342271, 0.022822336104582064, 0.1233862666413188, 0.050429324255674146, 0.030581714563595597, 0.04865310882451013, 0.03731179727765266, 0.02284728154336335, 0.026073959670611657, 0.046448603679891676, 0.06687622590106912, 0.06340874126181006, 0.02984743179695215, 0.05207964175497182, 0.07075716101098806, 0.05154369609954301, 0.06758972667739727, 0.053543494650512, 0.018087702956108842, 0.014105804220889695, 0.042865781870204955, 0.0838637635752093, 0.020869060936092865, 0.017600425489945337, 0.034095507362508215, 0.008818253427307354, 0.06303116620983928, 0.010519895076868124, 0.011380711239326047, 0.022037418457330205, 0.029571031882369425, 0.043669646547641605, 0.04951469032675959, 0.027559238369576633, 0.00606728732236661, 0.030888000765116885, 0.029332553858694155, 0.07858820681576617, 0.034058852688758634, 0.05706173105863854, 0.0377756729722023, 0.05981004491331987, 0.05907517399464268, 0.014564858738594921, 0.04291932411433663, 0.02082509054162074, 0.03658655201434158, 0.05420105233497452, 0.09801275708014145, 0.020042531068611424, 0.05189518094994128, 0.043972446510451846, 0.08628559924545698, 0.067908130295109, 0.030153448969940655, 0.026595520648697857, 0.011536031615833053, 0.022831091591797303, 0.024083144817268476, 0.026539943064562976, 0.04900505380646791, 0.012285599841561634, 0.040040154781308956, 0.014917905809852527, 0.08470769680570811, 0.024839755096763838, 0.01354319412712357, 0.024464343405270483, 0.02598736773506971, 0.05392517377913464, 0.06418948803911917, 0.07965250595589168, 0.06408055560314097, 0.032047027634689584, 0.0063053492795006605, 0.06210310682945419, 0.004519879730651155, 0.04431922614458017, 0.10468617867445573, 0.0593378534540534, 0.029436868280754425, 0.0228098012303235, 0.03422639623750001, 0.005389690259107738, 0.03117695596301928, 0.03565923107089475, 0.12628652038984, 0.032983599448925816, 0.03758419516088907, 0.026277643955836538, 0.0768406642600894, 0.03947258992411662, 0.023208234342746437, 0.03159007988870144, 0.031202114769257605, 0.03801845174166374, 0.04092755560122896, 0.054622929892502725, 0.036141563978162594, 0.04339039864134975, 0.08461233082925901, 0.04006159542768728, 0.048512598004890606, 0.06087966154154856, 0.029805652593495324, 0.03761885716812685, 0.05861409990757238, 0.05895771799259819, 0.04731308697955683, 0.0307337156846188, 0.04533636922133155, 0.008319606258737622, 0.026541069273662288, 0.008550861330149928, 0.031516540475422516, 0.0411021458421601, 0.02179535586037673, 0.07701318390900269, 0.047915102331899107, 0.0336208037333563, 0.05101526840007864, 0.06386064982507378, 0.042720992569229566, 0.017487131080997642, 0.01189326811072533, 0.02060923317912966, 0.025035978942469228, 0.03929257087293081, 0.043143909133505076, 0.029859925853088498, 0.03792564988543745, 0.00533757572156901, 0.025343836641695816, 0.0374002056196332, 0.006555608897542697, 0.013633976413984783, 0.024896312315831892, 0.0816101579403039, 0.02960294052172685, 0.02125535251252586, 0.04741554788779467, 0.079218074970413, 0.03543210790667217, 0.020488482041400857, 0.03140843182336539, 0.04054464821820147, 0.04565843162708916, 0.04476410285860766, 0.03243963859858923, 0.03964478302805219, 0.0440305306983646, 0.09203835696098395, 0.10740435391198844, 0.014438346679526148, 0.04954495139827486, 0.011618920234468533, 0.02611675747175468, 0.021920689760008827, 0.05078698377474211, 0.03285903738287743, 0.04422938174684532, 0.0794424930063542, 0.04210427156067453, 0.014672227098344592, 0.0835849238501396, 0.033624369752942584, 0.05446745366498362, 0.030601999314967543, 0.03257818643760402, 0.011866537806781707, 0.030435340777330566, 0.03130515826342162, 0.013761307618551655, 0.0202773781347787, 0.042184282501693815, 0.04374532334622927, 0.05467299146403093, 0.024283062703034375, 0.06096170225646347, 0.03690494078909978, 0.07213598975795321, 0.0454627755243564, 0.08973039643024094, 0.015931546877254732, 0.09047336046933196, 0.05203574000915978, 0.06546420088852756, 0.026258854632033035, 0.030516451952280477, 0.07638552735443227, 0.033315855253022164, 0.016562949422223028, 0.029322985719772987, 0.07112194143701345, 0.029982333835505415, 0.006698272409266792, 0.04174784029601142, 0.08292062004329637, 0.05418401262431871, 0.007540471333413734, 0.058138227395829745, 0.03675924977869727, 0.04046439607918728, 0.033797724317992106, 0.005113097849971382, 0.02631678853504127, 0.03225055421353318, 0.05316817943821661, 0.04539439032669179, 0.040758754112175666, 0.013078550309728598, 0.026789403018483426, 0.07738268439425156, 0.03764811634027865, 0.07546379478299059, 0.052381569694262, 0.043338043833500706, 0.024596004113845993, 0.00421979185375676, 0.05393744148022961, 0.1275056612212211, 0.023363487925962545, 0.05124061783135403, 0.01085156736735371, 0.04306656992412172, 0.03425368500757031, 0.026194690399279352, 0.05427439136838075, 0.04091972965397872, 0.050801377728930674, 0.016519908567715902, 0.025677712183096446, 0.08095258541288786, 0.03885623627866153, 0.037651611855835654, 0.05163808986253571, 0.023019708423817065, 0.04072062627528794, 0.07320401447941549, 0.030244670051615685, 0.030813932571618352, 0.04158393327088561, 0.06149394088424742, 0.05847466891282238, 0.03907442769559566, 0.025178949981636833, 0.0757917646842543, 0.032705954581615515, 0.05390992264437955, 0.04643116692022886, 0.16999637649860233, 0.1772798880119808, 0.11217386985663325, 0.14468070992734283, 0.14013579755555838, 0.2470885100774467, 0.21228329802397639, 0.11545994391781278, 0.09037779411301017, 0.1281792641384527, 0.16092703503090888, 0.13326107582543045, 0.2579188492381945, 0.08686844492331147, 0.10745569568825886, 0.09605839280993678, 0.139815857692156, 0.11108014456112869, 0.13134029373759404, 0.1757518356316723, 0.1605695573380217, 0.11675360379740596, 0.11788718242314644, 0.10246697158436291, 0.22367513127392158, 0.20423011999810115, 0.2312157821143046, 0.16034308355301619, 0.1589992322260514, 0.1605790716712363, 0.1090542075689882, 0.21114944480359554, 0.12412722688168287, 0.16924441762967035, 0.10931063443422318, 0.19568626361433417, 0.20997273997636512, 0.1024585185223259, 0.0972559890942648, 0.09195927370456047, 0.13307147193700075, 0.0917685565946158, 0.09838477344601415, 0.1438367841183208, 0.2129163796780631, 0.10374664940172806, 0.15683748963056132, 0.21192346030147746, 0.0933691168029327, 0.12350230143056251, 0.07751311684842221, 0.1222704179235734, 0.1186586894618813, 0.11177338470588438, 0.10468061256688088, 0.08519578506820835, 0.12408061258611269, 0.2230918180430308, 0.109748620307073, 0.12625061528524384, 0.12977200211025774, 0.1114875687926542, 0.10476008916157298, 0.12002752890111879, 0.11781837791204453, 0.09425553798791952, 0.153628918051254, 0.17098923650337383, 0.18833223322872072, 0.17425088648451492, 0.09207058843458071, 0.08326511015184224, 0.21372557297581807, 0.07578068441944197, 0.08754637456149794, 0.13807902432745323, 0.19605427980422974, 0.11318889781250618, 0.14134325698250905, 0.06937071040738374, 0.08857470922521316, 0.07953989988891408, 0.12454136012820527, 0.1513114431872964, 0.11937909221160226, 0.22310974833089858, 0.12956675374880433, 0.14964693953515962, 0.1634629536420107, 0.10399960301583633, 0.19139547744998708, 0.12708091526292264, 0.18226810003397986, 0.1372209531837143, 0.14509218628518283, 0.08539079179172404, 0.146204546908848, 0.08287750868475996, 0.10573224324616604, 0.11426588767790236, 0.12415815217536874, 0.14291141502326354, 0.16174473334103823, 0.08385358873056248, 0.166059268231038, 0.17193283274536952, 0.23542016744613647, 0.08173739173798822, 0.19454576075077057, 0.12260592804523185, 0.10637642000801861, 0.11611551264650188, 0.1615866262000054, 0.14460667327512056, 0.07358407572610304, 0.12823483615648001, 0.1529113799915649, 0.10196313494816422, 0.14193604001775384, 0.21061420789919794, 0.08456664421828464, 0.10470918525243178, 0.25935641897376627, 0.14298312133178115, 0.1419970445567742, 0.15690788975916803, 0.12143696381826885, 0.10115049808518961, 0.14360939007019624, 0.17788540630135685, 0.08947825175710022, 0.1669233656139113, 0.13975651556393132, 0.13734409032622352, 0.12143704545451328, 0.1885778395808302, 0.1226176465570461, 0.1334191087516956, 0.14909274817910045, 0.14831264707027003, 0.16686593822669238, 0.1675308431731537, 0.15638420067261904, 0.0852350372588262, 0.1484560893732123, 0.05396960616053548, 0.21966241300106049, 0.09361101983813569, 0.11997780500678346, 0.13026591623201966, 0.15576606587274, 0.1523523943615146, 0.12285964607144706, 0.17192357074236497, 0.2219342754688114, 0.10764414924778976, 0.12792878929758444, 0.12548224010970443, 0.16198000899748877, 0.21672914852388203, 0.11807962131570093, 0.15157707268372178, 0.09342635865323246, 0.12498071155278012, 0.10906831579632126, 0.15985506208380684, 0.19817677763057873, 0.09666215963079594, 0.14001427829498425, 0.1212764298543334, 0.1308790044276975, 0.15688350278651342, 0.16353837068891153, 0.21134712325874716, 0.14420781342778355, 0.10887204742175527], [0.03200172694050707, 0.02842902616976062, 0.06341809232253581, 0.06231511986698024, 0.05998332526360173, 0.020679857807408553, 0.04776172267156653, 0.043300472607370466, 0.06464869933552109, 0.06586602932657115, 0.04721278201031964, 0.004890553736913716, 0.034877452708315104, 0.018116782157449052, 0.02814860752550885, 0.023175609530881047, 0.050567133657750674, 0.0335673542576842, 0.02742879107245244, 0.009200957647408359, 0.0331422891758848, 0.011676798476401018, 0.0032284553390127257, 0.04801710310857743, 0.020649439029511996, 0.04068375637871213, 0.07002454993198626, 0.029754861861874815, 0.05603307356068399, 0.023305860158870928, 0.049699050941853784, 0.07025834871456027, 0.1504859671695158, 0.055491565508418716, 0.005547651753659011, 0.05226615830906667, 0.03690619130793493, 0.021795806715090293, 0.043805518944282085, 0.058283050093450584, 0.03458127270278055, 0.03592911678424571, 0.05457996696350165, 0.031427612630068325, 0.06901628294144757, 0.06452340996474959, 0.03888598897901829, 0.06745639984728768, 0.08054838952375576, 0.04088072237209417, 0.0419437784148613, 0.06052148622984532, 0.04755088964884635, 0.0730437773745507, 0.058407656688359566, 0.03599204348574858, 0.04066891713591758, 0.0561695137002971, 0.024509399190719705, 0.0662462018954102, 0.03491767340165097, 0.02613796248624567, 0.04905047324427869, 0.03991953351942357, 0.03140582317428198, 0.025767040788196027, 0.02874688245356083, 0.02133402016625041, 0.03127855226921383, 0.022758730337955058, 0.0810303699108772, 0.014944654667488066, 0.02506278902728809, 0.07470296724932268, 0.06745452963514253, 0.03766257708775811, 0.018799314966599923, 0.016423972992924973, 0.043479586238390766, 0.052025383338332176, 0.07562636965303682, 0.035647776021505706, 0.030237150240282062, 0.04797657813469414, 0.06065162182494532, 0.09475914455833845, 0.008604560352978297, 0.03197038604412228, 0.05333764886017889, 0.021979939119773917, 0.015602806997776497, 0.09220397463650443, 0.011549227929208428, 0.037348849000409245, 0.07264163723448291, 0.04169355961494148, 0.07026954772300087, 0.021855467966815922, 0.04369462352769915, 0.03447500457696151, 0.016143997781910002, 0.08230836305301636, 0.0231581133994041, 0.0495689339004457, 0.04990634392015636, 0.07677987494389527, 0.05648986916639842, 0.04322580512962304, 0.018924485593743157, 0.07962147676153108, 0.04371202317997813, 0.036967841515433975, 0.01564693324326072, 0.08414747921051458, 0.0387611411861144, 0.01893901870062109, 0.05512923416972626, 0.022799732141720597, 0.05509471317054704, 0.012858448790211696, 0.07230892500956543, 0.032957271760096774, 0.04368546913610771, 0.03387683354958426, 0.016336186199623626, 0.025062664717552252, 0.032874373864615336, 0.006573205218955991, 0.05730686985771172, 0.03430775417655241, 0.019615404671640135, 0.03914467197319027, 0.03293256937467959, 0.005887909301236505, 0.03805155152804218, 0.011462508900876855, 0.021676905380445533, 0.05823825777042657, 0.01694435024546692, 0.07290597539395094, 0.02073676198051544, 0.06035956073901616, 0.06792161511839367, 0.015750498096167576, 0.04333166507421993, 0.08513402353855781, 0.02294867004820844, 0.04239835499902256, 0.03889174804498907, 0.022973966151766945, 0.004180423238722142, 0.02476610621670261, 0.04854973878536839, 0.03527732929796912, 0.0249849266037927, 0.07862978935008869, 0.06319741471088491, 0.04034541496366728, 0.08529673199518584, 0.024233691328845453, 0.056572340326965787, 0.05928840044362005, 0.03243489998567384, 0.013052716149104526, 0.02719984779105289, 0.036085413084947504, 0.04204541182843968, 0.05046749662142247, 0.05419085151515901, 0.06412650938727893, 0.03882355951645877, 0.04331993914092891, 0.01786250195436878, 0.039896463858895004, 0.06216906891495455, 0.04788135687704198, 0.07457878367858939, 0.049929472952499054, 0.018284433317603543, 0.011323263443046017, 0.052612848885473795, 0.019361629128979985, 0.05890236119739711, 0.05544309584365692, 0.02094622945151059, 0.03821894664724823, 0.046318434688146226, 0.022872431072755717, 0.020664807052526157, 0.0475979084149003, 0.08067658069194295, 0.0696401545428671, 0.04085631313500926, 0.02914624139521038, 0.037004600089858286, 0.08270932317827828, 0.006534349149660557, 0.04404480961966328, 0.06171752029331401, 0.008847622993926052, 0.044801303010899574, 0.08597389722126536, 0.012441200378816575, 0.02158861949283164, 0.018582027114462107, 0.019589587209338788, 0.014270202918851282, 0.02485545708623249, 0.058724973059725016, 0.03889538456860464, 0.0483585615438642, 0.0259053492845851, 0.020532313283183612, 0.02471611700457288, 0.04641766725399066, 0.06756436749128625, 0.038054709366406314, 0.017739567047101445, 0.065277929243166, 0.03453436896961648, 0.06201007119670976, 0.012677916729444405, 0.024914851164794527, 0.04825926589546725, 0.05446567993203644, 0.07307752282940783, 0.024910702559282072, 0.018438703555148095, 0.01650310448894743, 0.03228692316042725, 0.0672304307227023, 0.031063440765137784, 0.08177783878636546, 0.06814376218244433, 0.010849239806702826, 0.036241438501747325, 0.022129784301796462, 0.07155173399951309, 0.05498900907696225, 0.05097563400340732, 0.03302893725049216, 0.044098804573877715, 0.030490591816487722, 0.06628082308452576, 0.03944197262171656, 0.06765033045667224, 0.0472639159852406, 0.03601893891755026, 0.046104250868665986, 0.05491975185577758, 0.04696814045018982, 0.027329998229106423, 0.033237280367757194, 0.07654107408598065, 0.015459743190149311, 0.04180017283943016, 0.016444736429548357, 0.02570194330473896, 0.04979195298801642, 0.05698292239685543, 0.023043351393425837, 0.03230707618058659, 0.15192362596280873, 0.03281817102106288, 0.07372359948931262, 0.07096611268934794, 0.015957779942255, 0.0538447546568932, 0.03887246333761141, 0.06046904978575185, 0.03333034568640869, 0.05935431057878304, 0.00932799477595836, 0.04201226380246226, 0.022205162385944277, 0.02079126159514999, 0.04789205493580084, 0.02544566672440851, 0.0086382223162218, 0.03118459637335036, 0.07714505612966605, 0.023073783158906735, 0.01602922649908578, 0.018055653308692854, 0.0035026564091822365, 0.037385433170129545, 0.050708839335129596, 0.015166266457526945, 0.05783123429864645, 0.06345901434542611, 0.02591842036054004, 0.024748487630859017, 0.02239927853224799, 0.036232373167877086, 0.02503820724086836, 0.019393682487134356, 0.018784533240250312, 0.07840586855309084, 0.01356678236334119, 0.05667966601322405, 0.041044076497200876, 0.02593803346826462, 0.01210887499837554, 0.002889838865485217, 0.061005032548564486, 0.01740632975270273, 0.018573523957456928, 0.07279537312570028, 0.06928798320586793, 0.0375686508778017, 0.0401123620395083, 0.06226869852980599, 0.037877733120694757, 0.06912389435456134, 0.05857266209204681, 0.044042160152457654, 0.0508854519284796, 0.07270525413332507, 0.018656972897588275, 0.09043067955644801, 0.0035837884570355527, 0.03592275286791846, 0.01795149659301387, 0.030255000747274607, 0.015601415470882785, 0.02588827432191465, 0.012031496826239163, 0.0834633081103675, 0.0530519887979608, 0.03197642712621018, 0.04477476380998269, 0.010024421517300652, 0.1035518801654689, 0.08957699450547807, 0.060564831364899874, 0.05703773371351417, 0.03288589199655689, 0.013441655337373959, 0.050562795804580674, 0.05019249008910265, 0.07965121461893432, 0.050438204052625224, 0.03791029113926925, 0.04772163927555084, 0.01774066357029369, 0.0033218481303265435, 0.025946573732653633, 0.06499612092738971, 0.016253802241408266, 0.03483635256998241, 0.061853055012761615, 0.02035736495599849, 0.12243100383784622, 0.18798585806507617, 0.18068428267724812, 0.13073102018097416, 0.169512421998661, 0.18516977870604023, 0.1406447179033421, 0.14438922400586307, 0.0788224434654694, 0.16205514402827248, 0.18000526208197698, 0.05764235400420148, 0.11034597497200593, 0.15019605460111052, 0.11145108481287025, 0.11934660098631866, 0.17817776795709506, 0.19150470674503595, 0.10896512016188353, 0.20874801819445565, 0.17301452782703564, 0.1103036651329603, 0.12683478940743953, 0.11237881393753923, 0.11165209551109001, 0.2516014804132283, 0.1728139549959451, 0.09549476875690743, 0.14991286589065567, 0.15322198363719508, 0.12422602158039808, 0.13231847406132147, 0.2845501061528921, 0.2206400886643678, 0.1380515203345567, 0.11158475303091109, 0.15035687800263986, 0.15556098078377545, 0.1520463771885261, 0.14856062829494476, 0.08811720486846752, 0.11920061311684549, 0.11779405031120405, 0.1930162389180623, 0.14810440043220297, 0.16535378264961764, 0.15638614509953186, 0.2629770012572408, 0.12894814397441223, 0.17700602067634463, 0.17538211250212044, 0.13442630704957992, 0.1495882504968904, 0.1373676906223409, 0.21978700475301594, 0.13994089473271742, 0.187399887945503, 0.18685071350773796, 0.08169687789632007, 0.18495391763281077, 0.10480089986231178, 0.11672793290927075, 0.1505631356849335, 0.14093379926634952, 0.143975239188876, 0.15063683094922453, 0.07879903612774797, 0.10892198653891683, 0.15420506213558838, 0.23698074073763564, 0.18577397597255185, 0.1536253112135455, 0.19224062038119882, 0.14271182182710618, 0.14620607573306188, 0.09996571869123727, 0.18262229743413627, 0.17628790374146774, 0.09581004793290049, 0.20060245762579143, 0.16719208244467154, 0.1551891944836825, 0.1287249950109981, 0.1365084171993658, 0.13536653394112363, 0.14509764849208295, 0.23741785087622702, 0.0781607000681106, 0.23188203776953742, 0.1691873316303827, 0.12267309983144514, 0.1418461065622978, 0.06410260481061414, 0.20628760568797588, 0.15703331271652132, 0.1255420720553957, 0.17316119105089456, 0.09414751097210683, 0.07647051068488508, 0.09992240695282817, 0.14801503100898117, 0.2837782131973654, 0.12500901706516743, 0.12061504268785939, 0.17506692238384858, 0.12519179319497198, 0.12307335491641425, 0.0856885191751644, 0.14938836044166237, 0.162151831027586, 0.13388887338805944, 0.1926075085066259, 0.08914396617910825, 0.17593474534805864, 0.18851653818273917, 0.16158768004970625, 0.13653859292389825, 0.19658294128021225, 0.10814308770932257, 0.1117158608394675, 0.19975143688498065, 0.13766584102995694, 0.1788414260954596, 0.18937924032798037, 0.14003747783135623, 0.12320367604843341, 0.07700799629674293, 0.08485620797728188, 0.14601460163248703, 0.1323078019777313, 0.05743628556956537, 0.1553313751355745, 0.1080517441732809, 0.06687363580567762, 0.11593255097977817, 0.12027156932163052, 0.1564343401696533, 0.13100534764816985, 0.15644219209207222, 0.18114580947440118, 0.17116234987042844, 0.12553755979752168, 0.1520228065783158, 0.10609107906930149, 0.1370386965572834, 0.19119487493298948, 0.12725303415209055, 0.18843160680262372, 0.10708164583775215, 0.11542766049387865, 0.13652854424435645, 0.12663602741668, 0.142289896029979, 0.1666382176335901, 0.17229838500497863, 0.16215089592151344, 0.13864658918464556, 0.15321840648539364, 0.14812777808401734, 0.14561213494744152, 0.09610562308807857, 0.1040020669461228, 0.1325631601503119, 0.22548168199136853, 0.13567425805376843, 0.1725121383788064, 0.1215837977360934, 0.11005880092852749, 0.10627164359902963, 0.16748619556892663, 0.12102686043363065, 0.18993031466379762, 0.056643293355591595, 0.07563057020888664, 0.12893457751488313, 0.1919366218498908], [0.02173918084736215, 0.03672248749353457, 0.08459477903670631, 0.09143061965005472, 0.05012367444578558, 0.03876041388139129, 0.03176711550622713, 0.01591222135175485, 0.020316333466325887, 0.05944113443547394, 0.07356157380854711, 0.10258660578983836, 0.00924157817280502, 0.022722214816894848, 0.03889273510139901, 0.023255468331626616, 0.013974710327602224, 0.018532815302023664, 0.076421573467087, 0.0411690059263492, 0.044771398170269094, 0.012650517564907204, 0.06623694731388241, 0.0029066561637591803, 0.07829789348761551, 0.03396451829758007, 0.014174110565363662, 0.04353756652562879, 0.0392378857213771, 0.0674002489540726, 0.025517237590975128, 0.06297508953139186, 0.08286665106425062, 0.04712962436315138, 0.03392078353499528, 0.02106070016452577, 0.02568865329521941, 0.04111026122700423, 0.04324075569456909, 0.06365724198985845, 0.14124098903266713, 0.11025932180928066, 0.06106293491029646, 0.05572477799432818, 0.01888629652967211, 0.04756599235406611, 0.023255418236658443, 0.07167452233261429, 0.03779322105401661, 0.06080672326788772, 0.043593216469162144, 0.057373574090888724, 0.08294023500639014, 0.0684783594624605, 0.017375283860019408, 0.027451254027255345, 0.03921935429389123, 0.06292633785051294, 0.016537065166630782, 0.018132940567738842, 0.008312101290357532, 0.0494541793159442, 0.05693139508366585, 0.035806528831017204, 0.019234454703109805, 0.019591513082559686, 0.03833691473118961, 0.02591811236925423, 0.08859732246492058, 0.052219380741007626, 0.04372833929664921, 0.043142495342181064, 0.04682048274844419, 0.11423868796555325, 0.05656704510329291, 0.03572114845155738, 0.03245659296226222, 0.026234896249661688, 0.02424595531920204, 0.039606818463653326, 0.04517771289101802, 0.03109122862952063, 0.03364042982866522, 0.03398120548808947, 0.027426351261965465, 0.017717118935252074, 0.04811492559383623, 0.009105035060201772, 0.021734505316999275, 0.0326675595715642, 0.02270903056341922, 0.021933909265499096, 0.04115969568374567, 0.07852961425669491, 0.022829200970591046, 0.009917311053868616, 0.02538110358727863, 0.06749596373992972, 0.10645126560120843, 0.033142504398711026, 0.054235933275776915, 0.0028395681010806584, 0.03045010209461907, 0.017656676573096775, 0.05153666796104517, 0.012276806319277966, 0.02542211837862851, 0.006987286515141022, 0.014908135435689474, 0.04941732426232193, 0.01239585515577346, 0.03219563157472294, 0.03303104866063222, 0.06545422642375343, 0.03134819540719036, 0.032136619702214375, 0.03202496729500126, 0.011401269657653756, 0.03863751051540021, 0.007082931724653463, 0.03642731680884026, 0.025138089185929857, 0.027363135122868698, 0.025418448458367493, 0.04991369118215516, 0.021758526781923138, 0.020186062429274898, 0.011550668623385718, 0.016863988639670424, 0.04838674460188486, 0.04405390463944059, 0.024663699114171322, 0.026398487862024922, 0.04028004659630824, 0.07102591494913213, 0.04968613757228013, 0.04356348603323568, 0.011468033262644894, 0.03647329656814691, 0.03954586587497033, 0.07644652447197586, 0.11054090748075396, 0.03366767406987492, 0.020525370491668582, 0.018894833083322737, 0.02531496709707426, 0.03959429101087153, 0.03524825566273648, 0.08252939689555205, 0.04412113208672963, 0.0369724391202908, 0.08333395177032799, 0.07136182583053596, 0.06251350336242467, 0.03388284123502672, 0.06640762643655762, 0.038856121245771646, 0.014968394116294803, 0.018608429018058814, 0.015150402123254025, 0.03645389682787936, 0.02502792478480842, 0.03024118566827383, 0.0064062451838253764, 0.062384532939177006, 0.03722280263900757, 0.018673511658562347, 0.04361126178991981, 0.012002844359813025, 0.017136356836999767, 0.03672869184811134, 0.022338919661706313, 0.02738947579928208, 0.05903277880861424, 0.031664966300013475, 0.04221794632030651, 0.054977175532258116, 0.07078409355017357, 0.04199936898658052, 0.047042759688338265, 0.03336216526804492, 0.04859385204326827, 0.026125735603272915, 0.05440371060103644, 0.06403911407687701, 0.05341391566616949, 0.03761188840144314, 0.006343527675198857, 0.010333562204323243, 0.12023252493236214, 0.032078312869998626, 0.023696493299212307, 0.03690546400321182, 0.02596989943413064, 0.06989491157582961, 0.07666306832106784, 0.025239602000510786, 0.02786212553473888, 0.05030219806940295, 0.049501795510877855, 0.04293645659345202, 0.028856497665401548, 0.035599703405750915, 0.03138634921924677, 0.0334496570576448, 0.09849658541497774, 0.02388582259300165, 0.09587005799403414, 0.04158843439654447, 0.01912814946990693, 0.05071754472737666, 0.021799548994749784, 0.04973593939212151, 0.014813364105066285, 0.0378741374152014, 0.02571391229139408, 0.0760842821910046, 0.05170641939912457, 0.053850543408771046, 0.0480050914484309, 0.022285557388386223, 0.09413748455699533, 0.038292957324301824, 0.006489987736131297, 0.04662077080865856, 0.1355858682654798, 0.02493584281182848, 0.031443668995052576, 0.020359827030915767, 0.03263448576035444, 0.03769937276956625, 0.02904705335822655, 0.032170817867154256, 0.010354558489780175, 0.08125806823954917, 0.07314323258469813, 0.02064409556624014, 0.029724979285674635, 0.09847503344644792, 0.03453944154898636, 0.033941088695428334, 0.026918776056845672, 0.03903932411049027, 0.015166761841101106, 0.04768739658175036, 0.04604683090292383, 0.019690842127602082, 0.033647539603407495, 0.029180066630942747, 0.04013200297777075, 0.08457944626570679, 0.029210095781309064, 0.012118864306103205, 0.04064255233970471, 0.03130121745925862, 0.02965197607409209, 0.05634870154608507, 0.05191090705920942, 0.02907925514591625, 0.028280205151531845, 0.029996980119904038, 0.024721237823541742, 0.01983218600798864, 0.028117561632825527, 0.019416089780861512, 0.049846344991237856, 0.051294835429871455, 0.040369519920204766, 0.07856984608224593, 0.08619651183835231, 0.005543948436752544, 0.03916699948604219, 0.014129791361483512, 0.010508039267733693, 0.09792285331059247, 0.03418432759644929, 0.043273651390336454, 0.024916715810832102, 0.05357354420993943, 0.049531952681718394, 0.080830516963033, 0.01760941289830953, 0.024287426531373058, 0.038797075976617634, 0.014524574962706538, 0.005607528228210867, 0.026892960449913517, 0.048684583307476714, 0.024685956122993957, 0.02659777492226567, 0.051672985646291636, 0.018876030771934893, 0.053646708838641644, 0.03753145814698655, 0.04505979304667562, 0.044040531138307415, 0.041386855955352075, 0.03788004491070751, 0.023834683051973116, 0.0347938163758954, 0.017434655674151145, 0.0661617009609472, 0.023115037292882334, 0.039949390120455064, 0.07395626278594136, 0.03748036870092619, 0.04314983147196472, 0.037051488980068825, 0.0767959795484785, 0.05599919822998345, 0.014566298505087616, 0.025018540327437222, 0.019450553263595793, 0.028322032594587654, 0.017051401337084826, 0.056386120631941594, 0.11384239594917744, 0.06292005185969174, 0.028486973060353193, 0.039829058296163566, 0.03872422304993961, 0.005326314094418194, 0.03493932184937876, 0.02541455403843429, 0.06461817480158061, 0.009068448107427685, 0.05397122404247057, 0.01902798921946669, 0.04133325805014465, 0.03836107534880284, 0.04170302199781872, 0.03115913328656461, 0.02646122531587025, 0.06896849605254829, 0.09709328063763678, 0.04217434143356513, 0.052538530217134394, 0.05308842453814577, 0.036077368204132654, 0.03388000623090193, 0.04210907696688082, 0.04928878057398833, 0.030421306764765177, 0.01901379378978163, 0.057794553649728186, 0.03700936467794236, 0.01928094839968253, 0.03200698134605773, 0.029802325916534755, 0.014975590165704489, 0.034364658349659294, 0.06149443070171401, 0.0978994756587781, 0.09669955645222217, 0.2128006046405062, 0.2341794004314579, 0.1228678022744134, 0.27461043326184154, 0.20960588153684512, 0.1270563798607327, 0.1701760949799791, 0.18963639449793845, 0.18010638712439686, 0.13209698750870302, 0.06311289151199162, 0.2505069610197097, 0.12314879422774538, 0.10732720766100101, 0.09068469444173388, 0.12642444111406803, 0.17552959208842367, 0.17580160405486822, 0.09580163939972408, 0.16567957063671201, 0.16405643429607153, 0.1929383134120144, 0.1914447857416235, 0.15325843793107197, 0.08873502054484561, 0.16615208121947944, 0.09854555974015966, 0.22888482984853908, 0.17111841472797096, 0.17177309287944809, 0.13114530185703188, 0.2057356110890396, 0.16317597997840494, 0.12275660628802143, 0.131321576773189, 0.1220140430086758, 0.1142332554445602, 0.13930395391071215, 0.25277630018536, 0.19489612866891548, 0.1340245973551646, 0.1176247293187771, 0.05581390250881668, 0.14685094269225374, 0.1271555307903327, 0.19323575135786086, 0.1383388353860937, 0.1803242668393068, 0.14171292074024677, 0.15586631518090144, 0.2078833567793481, 0.15668137144530192, 0.13480453519150615, 0.23347210400970653, 0.19784147531026974, 0.16537270741537213, 0.15888065187027678, 0.19263087131548673, 0.1353364621172659, 0.1556928307400085, 0.2535265521146357, 0.15980146417859942, 0.1619799793115817, 0.09285026651923545, 0.10335127022699453, 0.05774335659225471, 0.10841052804607898, 0.14104699162999168, 0.1804031422943808, 0.10095529098180123, 0.11465438714367338, 0.29391933465376496, 0.21096358133945614, 0.16637162334518507, 0.09543148582451977, 0.11657732888124883, 0.11546194029506296, 0.09282753453589976, 0.08612246776465327, 0.13950617430964485, 0.09806228059460409, 0.15648884349502623, 0.1009213451470714, 0.12691419920884073, 0.1059341593645513, 0.0620917297055712, 0.13036683347309008, 0.1262930958182551, 0.08330210621352307, 0.10963340930175036, 0.1834035266074352, 0.17775655462173745, 0.07659597817109898, 0.08436930715106428, 0.16285373945720494, 0.3237227682257071, 0.2795496635371819, 0.12493935908423737, 0.16401134140323848, 0.11913194961380213, 0.1270072051556781, 0.15645348757971078, 0.17842197907157242, 0.08807435326161794, 0.11295951480860822, 0.12811834865715355, 0.1093631488038227, 0.08992138813482597, 0.1465908793034032, 0.08244284763350151, 0.2057790564140305, 0.09721881491714157, 0.10263321266393177, 0.0936268201621715, 0.10829981445567682, 0.09867461922112852, 0.13451551320031285, 0.07171240155003034, 0.08808655416942202, 0.14646135969087481, 0.09888058004435152, 0.15882221516221762, 0.12085265610949136, 0.11429991514887661, 0.08877805026713759, 0.08627042974694632, 0.21021986030973494, 0.18683449015952647, 0.1849761078483425, 0.14396878250408918, 0.24733614991419017, 0.16057277825893834, 0.0738680140057113, 0.14700107916723937, 0.12913086073240265, 0.2362060424638912, 0.09901081211864948, 0.14479200239293277, 0.18930224992800504, 0.22553599235834554, 0.15155424422118813, 0.12542644544737414, 0.13944669859483838, 0.0796025742602069, 0.10029228593339212, 0.0869034075003583, 0.17401559598511085, 0.12161240010755137, 0.08816070214379579, 0.1608470463543199, 0.11952821936574765, 0.13105177640682086, 0.12029506571707316, 0.15444415243109688, 0.15946354949846864, 0.06769788727979176, 0.16418893734226003, 0.13700996059924364, 0.1326021080603823, 0.06397773104254156, 0.13429132523015141, 0.07119354384485632, 0.15145392069825903, 0.16311077488353476, 0.14736207464011386, 0.19422487093834206, 0.1084122720931191, 0.11640849770628847, 0.08677028847159818, 0.14800912351347506, 0.1533642681897618, 0.12357728061033413, 0.0676444749115035, 0.1428844453766942], [0.05365656084904913, 0.03255454532336444, 0.022201043466338888, 0.0474362797831418, 0.08358821898582391, 0.05688447279680986, 0.03301596450910438, 0.056682092836126685, 0.048822845419635996, 0.02673477167263627, 0.09055045476998203, 0.06430967143387534, 0.03311160879093222, 0.0613510626135394, 0.048051798512460664, 0.02917611283919541, 0.03461606829660013, 0.03811242990195751, 0.022576293740712572, 0.014391376153071178, 0.010763219324871898, 0.016810550296213478, 0.0050956369705090765, 0.0381816834124038, 0.034067172164213844, 0.0724039421766065, 0.049186557153007016, 0.04348035807197448, 0.0246263672306668, 0.014657164283562452, 0.00898971273272764, 0.03662556300696451, 0.026196794387942646, 0.03745218564290553, 0.03365265300089959, 0.008699785321368836, 0.02247805750812404, 0.024411730701103806, 0.03704722534166649, 0.042112950977752917, 0.019475741755741183, 0.022418286789616104, 0.051670655302586965, 0.05913654589676298, 0.01625077613425674, 0.008888365046004765, 0.04621784028131515, 0.018346256074437406, 0.025468576823186595, 0.04252358128724154, 0.0493235130852554, 0.05479307466885075, 0.04364239859569352, 0.01513745164629654, 0.021234550113149453, 0.028368489183776546, 0.01857442195614567, 0.056408856326015666, 0.036337409328552894, 0.03190269475453533, 0.06595707600354217, 0.028331949542916846, 0.057519777183188125, 0.023261683818418533, 0.06177775299875066, 0.0222771748303785, 0.030857392739562783, 0.07963715834193863, 0.01000630940325209, 0.07126815195078962, 0.05093713880341966, 0.009155390707746847, 0.03614630630181637, 0.016722379441489466, 0.02789196358207846, 0.08421777543844655, 0.019290375530545134, 0.02445137251925189, 0.07807300789863802, 0.03413872262171935, 0.051913448915001936, 0.048101719075930305, 0.04259462708432693, 0.04755385823955294, 0.06162941252114251, 0.0335524593538139, 0.018382625021331478, 0.009031330519064795, 0.08469893204164691, 0.015594493088428862, 0.07570468849735335, 0.03900135212461464, 0.07171406396082602, 0.042242659837938845, 0.05643185919325333, 0.009577408345649019, 0.08714709911146201, 0.01658137138292659, 0.017494320636615157, 0.025428903463762254, 0.09069153704331256, 0.059688028413802385, 0.04753878150950186, 0.010840065006050281, 0.03839751851046458, 0.014844777360849548, 0.04043034634378273, 0.07793372904416174, 0.038273483369266614, 0.020996636121708434, 0.03836114956357051, 0.06123859013314359, 0.020856654082308523, 0.023441157391062006, 0.05153376616362948, 0.041743810434127226, 0.016667911368131172, 0.03664887757622637, 0.0150490878331766, 0.018254636088386178, 0.026067864782817196, 0.03516803320962936, 0.042333546953159384, 0.006577503645530669, 0.03377693305083085, 0.0259254225238692, 0.04019146384962369, 0.012422539075487293, 0.014042197526578093, 0.07544299238361418, 0.025549604506522883, 0.07657355046831071, 0.0615084647142794, 0.00712911511072889, 0.04805132724868599, 0.018286303529748693, 0.016906036871660035, 0.032986182122840546, 0.08762536133872345, 0.04619151630322449, 0.013539767260226654, 0.016910348749661352, 0.1187041237426456, 0.03097005817835452, 0.011349606902513187, 0.0011618093435572519, 0.052551554908859544, 0.04303225672629196, 0.044054372192476876, 0.02154960107873194, 0.035791381596936844, 0.08887708987458609, 0.01521792550192913, 0.033161792816827074, 0.0055331585372186964, 0.033728259295457974, 0.11046013212762773, 0.09789233619812876, 0.07063717799610458, 0.03101032525592018, 0.018408542673569173, 0.008529451297363266, 0.028327311119937804, 0.012998127476748778, 0.03417490232095588, 0.032060605226433836, 0.013596561966551235, 0.01322435264228261, 0.04272544174455106, 0.06517806585179642, 0.015376411138277035, 0.0342963362345472, 0.08265315002063289, 0.10789699153974652, 0.015825467999093235, 0.06919652092619799, 0.05135561361385044, 0.05619956697046291, 0.06199863099027425, 0.0513941533426987, 0.08453687667497434, 0.02069333706458565, 0.017388349369866773, 0.021505910845007747, 0.07191675191279501, 0.05616187700070441, 0.024620435615361203, 0.03420449545956217, 0.012130103204981424, 0.06334279401926324, 0.07776631537126377, 0.02090408102958463, 0.022616189744439907, 0.038883283850736916, 0.01796810029190965, 0.042327706250944175, 0.06265192132559605, 0.036245605660951696, 0.03413492282561492, 0.04463497287360951, 0.04034782694361638, 0.054191326489672065, 0.038860318090883084, 0.019334813478053547, 0.028045276449120138, 0.025698598074086476, 0.059918862316408195, 0.048494133370695636, 0.07892985449871048, 0.03050493382033892, 0.037981140267220326, 0.020388249431562144, 0.043983864452457055, 0.0055196556240844075, 0.03488753107376397, 0.043171390861971304, 0.04475049558095634, 0.10635738392011262, 0.03848550753900781, 0.037103302020113915, 0.04551988749881275, 0.04999271877750289, 0.03659799593151547, 0.03341109135362785, 0.04662347222620156, 0.05717394007660914, 0.05662766001478303, 0.007070662632031599, 0.019832273210340645, 0.040993421207531355, 0.0284758835186949, 0.056989264048752375, 0.07568902175989933, 0.03178687518811785, 0.02473345542966854, 0.05336817339411937, 0.09545842578518204, 0.016581341697019525, 0.0619130799168488, 0.07522147614508867, 0.031563314332743175, 0.055366662054439075, 0.018638461879163515, 0.024930122708610725, 0.01968458396731876, 0.022234250864130445, 0.10254602515487932, 0.013865604414604604, 0.012138374440837651, 0.01952520960912807, 0.05712106576538645, 0.0845706147083547, 0.05201279651373625, 0.046370051059057005, 0.041159142783726566, 0.025917017701431178, 0.04175979258434381, 0.051405667763901874, 0.05423039685410913, 0.012545642821351066, 0.09285355423344299, 0.018546415158198215, 0.06637566955760121, 0.044530545274028555, 0.07921587821329013, 0.027979542574030347, 0.019774860666075256, 0.04306767943489831, 0.01301287580645294, 0.032562256237724796, 0.08309449040098116, 0.023413495691784192, 0.042222829652018845, 0.028649176856561098, 0.04734033122076653, 0.021217937137407716, 0.12499166565248743, 0.04056584766658489, 0.05910623658564873, 0.0463639209192479, 0.019921642633562442, 0.018197474018961657, 0.020786031309398822, 0.02656675500475103, 0.023558255306852516, 0.01190909255456063, 0.09898247692035511, 0.03747164475498721, 0.049120606199721806, 0.055728262377670035, 0.010755714356491808, 0.016778047938714735, 0.031249452658812515, 0.06222263713425491, 0.02677573822438717, 0.06839666384621523, 0.04256315631209873, 0.032278303115163, 0.030784079681325238, 0.017673649490461685, 0.0658590679813642, 0.06457720824982971, 0.0051811560388159705, 0.02944700601801742, 0.070122342731338, 0.11046812505810522, 0.008145482643158175, 0.03567465289961547, 0.07237710611661896, 0.01589226314536063, 0.15221350884530693, 0.04685819127189461, 0.03458388877334073, 0.059244947697152384, 0.11241543892538175, 0.05540604041016195, 0.004920332412439166, 0.03793416603002697, 0.07539676400483586, 0.02796136737742927, 0.028120969946030527, 0.03184954955941066, 0.036755186520167626, 0.01670757916144794, 0.037060439281049185, 0.07457419720594771, 0.024527155073883478, 0.04695179464761168, 0.030041677819099277, 0.031283706484828144, 0.04492608401051257, 0.042180478994851, 0.11489677999634296, 0.011840449460578384, 0.05084022173832636, 0.019121909863315523, 0.06584288174053654, 0.00755576978008321, 0.03409329576243181, 0.038866596660227515, 0.0419152279937407, 0.028854545817011967, 0.034882699692388996, 0.012251169755472802, 0.0919993496790994, 0.027078874009021092, 0.03907095444446895, 0.013529128573281923, 0.0387129164300859, 0.05174534875550307, 0.07432254235027358, 0.05142811030964367, 0.14770815294468775, 0.1052578105009161, 0.09754259168403223, 0.1608187408419326, 0.3117425454547629, 0.14427741203689948, 0.15706914360634983, 0.13105538324452937, 0.2591217221925035, 0.20902712509268895, 0.17910419090185314, 0.1751062710536644, 0.08664864304591902, 0.20446054200874642, 0.17978192016016692, 0.0736959841742646, 0.09537143865600228, 0.14893337938701734, 0.07468934141797945, 0.17145934252766892, 0.1601424958789721, 0.1598960137926042, 0.08857098364387639, 0.13923251477535814, 0.09627621315303259, 0.13846544577972963, 0.12383355904603377, 0.14249251718865708, 0.0957473884045612, 0.11764120499719866, 0.1162985633709468, 0.14232350047677755, 0.14510995330056176, 0.11607862790697254, 0.19874704390531406, 0.11703209471306764, 0.1002623699605465, 0.099915007740492, 0.11978570008068345, 0.2740083436947316, 0.2145160938380286, 0.2148178659263067, 0.15034825424663723, 0.18702029425185174, 0.0995207492087502, 0.1882304550963454, 0.16974233934888616, 0.10218186813290231, 0.1475596788804978, 0.14940157067030668, 0.17671403009444475, 0.1857184336404316, 0.10506342718144879, 0.1043924069381319, 0.15443628566572443, 0.13911785295931622, 0.07637072892975993, 0.12146947730798274, 0.13976090907817706, 0.12584715412231162, 0.18580199946882203, 0.09672268919530325, 0.145698209234979, 0.13918194483267143, 0.20749187387991697, 0.19149872503476217, 0.06516109293443151, 0.1085798341955524, 0.08080737679847516, 0.195444397686515, 0.16029606107622385, 0.0788612429460045, 0.06661853738478385, 0.13969459076179191, 0.1015390272368677, 0.19607629190431908, 0.07724675262579694, 0.106089283071924, 0.10711079739849083, 0.18482644634786993, 0.11886007123393938, 0.11581963321077637, 0.13914621784351766, 0.18076378153637052, 0.21269642194965854, 0.27506928832735866, 0.12583293457282707, 0.10117387573700398, 0.25457936280872673, 0.09785074624232948, 0.1597675628727302, 0.23176010290626436, 0.15000124083599076, 0.13404932571575046, 0.3024644230026752, 0.13815460464684293, 0.1446832629153505, 0.18926511285826564, 0.10403727443190292, 0.08362796099390835, 0.22543684142874554, 0.11228774499613792, 0.1989782229065895, 0.07822572704753838, 0.19235992804169655, 0.11289399059023708, 0.10894621766055934, 0.18674348801141605, 0.16327752062352374, 0.1635034749051556, 0.2206587462569587, 0.1692539022769779, 0.13484386901836842, 0.13133055676007643, 0.09570376496412791, 0.15004568063886836, 0.10139682432054542, 0.18837947834981605, 0.17568245966685936, 0.12516388844233006, 0.13588899106252939, 0.12847891368437558, 0.11810848343884572, 0.12746396736474708, 0.12938336905790493, 0.08117701087030582, 0.16181523737031966, 0.0712664079037495, 0.22481949330540374, 0.2086252224398777, 0.16816548333736137, 0.13154923799447715, 0.19927552726585418, 0.12154312804341316, 0.2432294757454656, 0.08763434132561088, 0.07028197127510794, 0.19107123313006014, 0.16673996608005837, 0.15972422144841403, 0.16889318882022053, 0.16769055335316807, 0.2463248252752237, 0.12716204684693366, 0.10459610421094112, 0.13166836753953248, 0.14492269459879026, 0.1324578345520422, 0.08510980725986883, 0.17212550912518054, 0.08703447078005411, 0.1215974532533437, 0.08367364760488272, 0.09823875589063391, 0.21535635343752801, 0.11245468369452283, 0.1460230621160008, 0.17062608880223706, 0.1835153831052594, 0.0968818279216066, 0.12122420492232777, 0.09429314261069521, 0.1280681201023981, 0.0731182296294719, 0.09300213219830766, 0.09669825027231127, 0.19603167398599908, 0.11605880514252931, 0.19148343679262325, 0.12459672434488311, 0.12675223289988935, 0.12163417472038418, 0.15951597481034696, 0.19460870971670374, 0.1398212753701955, 0.16145464265719056], [0.04834679850318935, 0.028732913378917146, 0.02514209863875294, 0.10322411806555465, 0.03761542473512236, 0.021112602262292057, 0.03242528917326126, 0.03459224164544139, 0.04317038896260783, 0.021691136062145233, 0.06140357698313892, 0.02178399357944727, 0.036019840626977384, 0.0379325221729232, 0.04100601545360405, 0.06781465679523535, 0.03231373324524611, 0.017439156799810007, 0.01568226689414587, 0.05450098389701452, 0.01618650243472075, 0.05501407511474099, 0.02022576918534469, 0.014831540229351958, 0.029196692594268825, 0.022743477347830776, 0.05075602879514918, 0.013271801853989018, 0.04103024286450818, 0.03958083216275554, 0.04487576268729754, 0.03944758696889039, 0.012903306051157415, 0.021860939450562, 0.004689418728958117, 0.028754580380336847, 0.03279763208411168, 0.025537431429256685, 0.08374911660212092, 0.021839324399479665, 0.07762268010992557, 0.0065781599823822035, 0.06336944454233162, 0.04772490843606647, 0.05210607705521397, 0.019116063594992738, 0.09637995055527426, 0.04051610521855764, 0.05004288053896744, 0.055819850822445005, 0.05521349761693273, 0.01847979256126564, 0.0618449136527488, 0.0605924466799479, 0.07368880018475465, 0.061204696248751134, 0.026568283828964923, 0.06550029153004289, 0.018202969622507226, 0.03793794727243949, 0.010394441505923169, 0.013577318077295786, 0.05263366241706535, 0.008754784030315932, 0.054687318624928594, 0.040137442920240574, 0.02345868320844602, 0.011626907598838443, 0.054713817007723264, 0.04989294073311612, 0.023016034792817663, 0.028794294557883404, 0.03666385782707948, 0.04981573511031456, 0.010151631195185473, 0.02248612465336919, 0.018680751309148036, 0.029366089656832628, 0.06183329904160928, 0.0408783029706683, 0.01681548743363237, 0.03997742103820201, 0.023590937635162845, 0.008208896379073849, 0.039336517147603445, 0.016814229493320454, 0.022815901684225537, 0.01664324609009782, 0.04715059003501665, 0.075744645728264, 0.019122269804938696, 0.045447331431205384, 0.02591301567008486, 0.04943277577694971, 0.027342451467120554, 0.02820263402099954, 0.0677619272028096, 0.036047407702426426, 0.08441465237410739, 0.05447203271614853, 0.05426803487353027, 0.031483845159527846, 0.058112441474804655, 0.006284303826760151, 0.06103456260461826, 0.03849209038889967, 0.015571957774227485, 0.034259325329912826, 0.0044518846243590815, 0.0654230265354272, 0.02988381929753814, 0.05377451037929859, 0.09158131273579784, 0.04935794873745181, 0.05180089108762331, 0.03797009710979182, 0.04523866547970101, 0.010250211598759051, 0.011856818455271423, 0.024750458032940514, 0.029293075313034933, 0.10365204783738591, 0.005339745111996308, 0.02710161712457193, 0.09509699244517833, 0.04344612651038915, 0.0363465934060514, 0.06934418604942039, 0.034014821067103185, 0.0163061589046265, 0.02177124348236248, 0.019259979017078876, 0.017895646269607823, 0.0420918183226604, 0.046440158039331436, 0.032570609109825455, 0.06888042538776062, 0.034862787870224565, 0.03074609841860365, 0.036051077622687444, 0.03265903971623629, 0.04369292400951963, 0.09072405053302646, 0.046865263939253055, 0.03041903764824383, 0.07995157662662677, 0.03205135064490605, 0.06955701173865236, 0.012419062113622203, 0.06093971613154281, 0.014163203777570743, 0.04995824601792265, 0.036077646509511396, 0.054151046424522065, 0.025327490839117672, 0.049562043059268035, 0.04471218220714945, 0.06298228094237857, 0.042594975893734954, 0.025612226927478332, 0.020153482146270107, 0.030439745423791464, 0.02231549191492377, 0.04357525278464891, 0.033336501801386476, 0.03099596840911545, 0.057263476483058184, 0.03461751919530798, 0.012058072206855286, 0.035327487348695286, 0.026210817268292885, 0.08620505395811051, 0.05020676529966295, 0.021510395272343885, 0.037024189077783376, 0.05610693209746387, 0.039982912931009196, 0.03173309545672964, 0.04888133407803252, 0.0016955358614723082, 0.019695916562341154, 0.012481551875680452, 0.06060986117518041, 0.028362349767121486, 0.03418183398025576, 0.029101040890964214, 0.03534113544446882, 0.008225717156165047, 0.03531587644829415, 0.043160421919310465, 0.017510694269731175, 0.028510014890343882, 0.07439938432071358, 0.03993491824076045, 0.01671698959398782, 0.008867878059390932, 0.1019331299175974, 0.04331285163061693, 0.08582952723372728, 0.03333920692966785, 0.004274543798601371, 0.07045057238428853, 0.013867420821043197, 0.04650755989132449, 0.05557686796237249, 0.04598062390869018, 0.015289336806745268, 0.039157266219262965, 0.0523735359456623, 0.01490982474933844, 0.026537718476902228, 0.03164098750858102, 0.006889443620821112, 0.01191783690956072, 0.06908900599228218, 0.031560078568872996, 0.017629241228860337, 0.038936184137128294, 0.04298233616282232, 0.021314874611562118, 0.026809415030584205, 0.024191581869672518, 0.037390264551504515, 0.06641183441388421, 0.04421577075845562, 0.03144642607367132, 0.03682824353745673, 0.026010860419773962, 0.07863194157835096, 0.025592448691895697, 0.03281718396465294, 0.027231710046180524, 0.03225470281904563, 0.050190456604468636, 0.04081912411493249, 0.05075619206763804, 0.030442040515481494, 0.04583081397868227, 0.054169856157386675, 0.036955254690838046, 0.05504212458617985, 0.005267223368718987, 0.018715645237534773, 0.032882140440051444, 0.05197553327889182, 0.04301627828681376, 0.031039011118991766, 0.038455124013125896, 0.03055436085560359, 0.02882352033338975, 0.09743139569764026, 0.04158420786552597, 0.04542241011222359, 0.03440988111833576, 0.045960355855640955, 0.019951623544329777, 0.01907821777422214, 0.017302848391409498, 0.06976160701015033, 0.012895015333924675, 0.07565475680166855, 0.027932752018386964, 0.033736764307832345, 0.022483551256300416, 0.015444047694472829, 0.019809986515610944, 0.04629363211279269, 0.008710579859325662, 0.010701116407290101, 0.09113338950555772, 0.05492021569807548, 0.052493993935058825, 0.03520123689668253, 0.05867059589945711, 0.09528698225039989, 0.062390796665567905, 0.060982597424299456, 0.04659922997234389, 0.023050075251376256, 0.02269881675601937, 0.06895682206959464, 0.021264562565193046, 0.025475875845586415, 0.034909539463114925, 0.010142576065845788, 0.04852338883210905, 0.018187685091106687, 0.08244324097177014, 0.06518214766401798, 0.010483324822416762, 0.03504975713440217, 0.06275615596678108, 0.023645450237381738, 0.02327105528820539, 0.02245868930913275, 0.027064919777330942, 0.023743957353872247, 0.07277212163899094, 0.03586618637200445, 0.03282566300185863, 0.03554974573489744, 0.02702699974179268, 0.030499946587951854, 0.06606315117096528, 0.03249630899517797, 0.013803340079903137, 0.008897242987586651, 0.0208016832038993, 0.04537667155091185, 0.02312409891601419, 0.05870372166100424, 0.0317588220059406, 0.0622397918778006, 0.02213001251220703, 0.03608012899348978, 0.02920047198131215, 0.03127770993160084, 0.028501478336693253, 0.03695553299621679, 0.0784195537562482, 0.08603351394413039, 0.09762770117959008, 0.039780514416634105, 0.061146712250774726, 0.0705932651180774, 0.04998163480195217, 0.02073285086225951, 0.08184912207070738, 0.005291563957143808, 0.08610796619905159, 0.02149439271306619, 0.02402892721875105, 0.022152735218696762, 0.05380138354666997, 0.014694951660203515, 0.1748872484313324, 0.02740651736530708, 0.04178267299721483, 0.09073473745957017, 0.018783869018079713, 0.037151085198274814, 0.030900622841727454, 0.06156957686471287, 0.012788044950866606, 0.009347812901978614, 0.02867378090741113, 0.03178906823450234, 0.009388070702698315, 0.07389260135823861, 0.015132121170609025, 0.07437079679220915, 0.01915957200253615, 0.10548064034082927, 0.24032607529079542, 0.14386431779712439, 0.1560681199771352, 0.10809369035996497, 0.11091325781308115, 0.1722316659288481, 0.07653303662664257, 0.11698274189257063, 0.09052329958649352, 0.09703989795525558, 0.12242684038938023, 0.13974468572996557, 0.0950036451104097, 0.10170238878345117, 0.17001737927785143, 0.24529272050131112, 0.1629124878672883, 0.11646150189335458, 0.14658035564934835, 0.14869293838273734, 0.10115489902091213, 0.21796898043248802, 0.18846745253540576, 0.14289784856373444, 0.2294843812705949, 0.08994406074634753, 0.1857513701543212, 0.15670967695768923, 0.1438775725546293, 0.14021501439856365, 0.13879421720048413, 0.14288947713794187, 0.0852288403257262, 0.06237401670659892, 0.11272596835624427, 0.23242667026352137, 0.15856028156122193, 0.21288834133883938, 0.13280864775879309, 0.11485573180834763, 0.10500134652829729, 0.14085723931202665, 0.1424803608097136, 0.09510845862678252, 0.08811491905362345, 0.14849695202428848, 0.18573476088931784, 0.09320817465777509, 0.13816791877616197, 0.11005352425854653, 0.08891793026123196, 0.268686847994104, 0.22304858051938936, 0.2267101887264289, 0.09879199729766697, 0.14029092126293108, 0.17151414271211252, 0.10708284811698832, 0.11420858645578846, 0.14037758926860988, 0.1634781528264284, 0.12667395116295666, 0.173167024331633, 0.1894536183681339, 0.17046243039658293, 0.17801011679694057, 0.08773951849434525, 0.0953631340235006, 0.15819325984921306, 0.10571161154075526, 0.2503221365623176, 0.16518742282642052, 0.08155831892509013, 0.20548878761474043, 0.11715391083271243, 0.11162341150338762, 0.08206792947021313, 0.1774612392182462, 0.17147439328255132, 0.07797084384947084, 0.13293994852574542, 0.17121409240644425, 0.07347770369960926, 0.19573347904952243, 0.08173935842933133, 0.10900077293626964, 0.09800928382901475, 0.16601071693003178, 0.19419199379626662, 0.1611250697169453, 0.2650166902458295, 0.06884478745632805, 0.22733679885277525, 0.13003795815166086, 0.15590314054861665, 0.14794080139836296, 0.16029524471377954, 0.21847136988071725, 0.19151690765284002, 0.19562932604458183, 0.12387783557642251, 0.13539255363866687, 0.1495395359233953, 0.11848015841678716, 0.10436528886202723, 0.09359394302009605, 0.13725022348808125, 0.15461021539522335, 0.13724391523282975, 0.1370836261776276, 0.14676733233500272, 0.2026828014641069, 0.1413495058659464, 0.10070858625113033, 0.1269837681320496, 0.12382316155708395, 0.09635393085773103, 0.09209939860738814, 0.10376398597145453, 0.10738618613686413, 0.20715274207759649, 0.13987975660711527, 0.08127987253828906, 0.16871489526238292, 0.13512919511413202, 0.07589804765302688, 0.16266541206277907, 0.16429328330559656, 0.1752335493802093, 0.09743457951117307, 0.1269305858295411, 0.22601292614126578, 0.11545365792699158, 0.11930648790439591, 0.1492765633156523, 0.14496878196951002, 0.12460030149668455, 0.1276539868558757, 0.1327286145533435, 0.19718310126336291, 0.09611844739993103, 0.18646004697075114, 0.19263452268205583, 0.18005247751716524, 0.1922766590723768, 0.14494138187728822, 0.1674020360223949, 0.1655812657554634, 0.13042509206570685, 0.09227948074112646, 0.1749483123421669, 0.1466487074503675, 0.1171946621616371, 0.1777030309312977, 0.11087736755143851, 0.16966430994216353, 0.11902591155376285, 0.15191023761872202, 0.24352347012609243, 0.15282906097127125, 0.11300837039016187, 0.16252223693300039, 0.18747244030237198, 0.20045713026775047, 0.10495692898984998, 0.08835839544190094, 0.12998495396459475, 0.05121478738146834, 0.13923653721576557, 0.10716126344050281, 0.12610833073267713, 0.161031425523106, 0.0893214953248389, 0.14407490962184966, 0.16960412176558748], [0.042638365557650104, 0.02377082681050524, 0.04213139334751759, 0.0867597945034504, 0.03822418620984536, 0.11129360849736258, 0.012554866789287189, 0.043993538347422145, 0.023925182395032607, 0.011226138576603262, 0.016940097739279736, 0.02842625053744996, 0.042583880785969086, 0.01685130162513815, 0.009679243994469289, 0.03451634220255073, 0.039152802200987935, 0.04326775131630711, 0.056915509412647225, 0.05049076666182373, 0.04206311576126609, 0.033615924112382345, 0.023365437918982934, 0.03265286504756659, 0.0540065836685244, 0.061491937085520476, 0.022088704572524875, 0.012304341853450751, 0.010248525995848468, 0.023226504163176287, 0.05440287939563859, 0.03437764222326223, 0.02893328211939661, 0.052690837474074215, 0.04664443047659006, 0.042709069966804236, 0.06756291288184002, 0.06229675913346, 0.048528561601415277, 0.03162970315315761, 0.029210661668912508, 0.04355367855168879, 0.04790315004356671, 0.03916328874765895, 0.02554824823164381, 0.10087902046507224, 0.03875524111208506, 0.03803558793151751, 0.025246027144021355, 0.03650794744316954, 0.02787012403132394, 0.026725632123998366, 0.003943810788769042, 0.03358826055773534, 0.039699323460808955, 0.0355458160629496, 0.04270704019290861, 0.05532207011128776, 0.0338619089598069, 0.012387196147756185, 0.08308485732413828, 0.02952499831735622, 0.03865162987494841, 0.00969296537732589, 0.01422621860911022, 0.02170450214180164, 0.036558513675117865, 0.019517884611559566, 0.038597271268372424, 0.04401720914756879, 0.0679084419971332, 0.05470774995046668, 0.025800331677601207, 0.03737125443876721, 0.05446916802611668, 0.03683701201225631, 0.020156890459475107, 0.018514662369852886, 0.052321489129099064, 0.024916307629609946, 0.032452511150040664, 0.015298666530725313, 0.02716255115956301, 0.016841288197610993, 0.03469384908385109, 0.08503300239681266, 0.0595282996800961, 0.021986371684761252, 0.04301329856389202, 0.010596058909868589, 0.025468990570516326, 0.012162766051915241, 0.04383870407764334, 0.043896810529986396, 0.044558052977663465, 0.02085914213239448, 0.046950484756962396, 0.023975147487362847, 0.059758751376648434, 0.049687896462273784, 0.11022171718650497, 0.008747605606913567, 0.01455900968721835, 0.00833799389511114, 0.040972834030981176, 0.028108193873777054, 0.01938808854902163, 0.06647812304436229, 0.02269675358547829, 0.020901548450638074, 0.012125422108510975, 0.05291446883347817, 0.02006030365009792, 0.030364432277565356, 0.03046243844437413, 0.013648961303260876, 0.024772043398115784, 0.06691331102047116, 0.07694677653489634, 0.05453360499814153, 0.030402311494981404, 0.034252646000823006, 0.10294619118212722, 0.06517447385704145, 0.016640325738990214, 0.051403396792011335, 0.04659445054130629, 0.02601698684884468, 0.03162476044963114, 0.02271572288009338, 0.048412460018880665, 0.05229684982623439, 0.031708504393463954, 0.047875705422484316, 0.007422983326250687, 0.032907180502661504, 0.00659963541693287, 0.023363543587038293, 0.006755369076927309, 0.05390046768297907, 0.042318251289543696, 0.07733120903139934, 0.03691004305437673, 0.050476350443204865, 0.013361026558413869, 0.09625010439776815, 0.042170819942839444, 0.024053212146100122, 0.025300710440205876, 0.06374494158080779, 0.05873099929885939, 0.028258270976948552, 0.0389376869861735, 0.010619418007991044, 0.015002260170149384, 0.025213508088199887, 0.03671819045848679, 0.126170685980469, 0.03630157843872439, 0.025806203921092674, 0.02060686758341035, 0.040160234275390394, 0.05985172392684035, 0.0258694516014657, 0.044061463413527235, 0.017305726069025695, 0.023742465637042187, 0.03256587791838683, 0.0887727142253425, 0.04973399125447031, 0.017235364903172012, 0.026936967951769475, 0.015706177036918234, 0.05551531052333303, 0.023882930072431918, 0.031201999736367725, 0.01441420925402781, 0.02766648613032885, 0.028033496710122563, 0.09265143773518503, 0.026649864412320312, 0.1290860350127332, 0.045022604026598856, 0.04328076116507873, 0.009130005546467146, 0.06474440669990145, 0.0386124815850053, 0.06289714918239042, 0.0184599048589007, 0.04654578791814856, 0.0531742687599035, 0.04750933308969252, 0.016823756814119406, 0.018910002581833396, 0.007416025691782124, 0.04305135218601208, 0.06847637050668709, 0.012068222004018025, 0.028521078456833493, 0.04041383355797734, 0.04016856117232237, 0.012258916849532397, 0.02773169122519903, 0.029313987179193646, 0.06814162479713559, 0.006430402090700227, 0.023161408535088412, 0.024521188206563238, 0.026894188704318367, 0.06154046241135802, 0.06883303925860673, 0.05772492164396681, 0.060472359764389694, 0.020063431802554987, 0.08807652033283375, 0.046168249973561615, 0.017473316001996864, 0.0187687997095054, 0.01711090673779836, 0.007074411869325559, 0.029390174204309005, 0.03328225822770037, 0.021290901386237238, 0.0799099644063972, 0.013105075595376547, 0.012991552976018284, 0.05079323636891786, 0.03814961892203428, 0.07589937609736808, 0.05511582727194764, 0.0394738998147659, 0.033832861299742945, 0.04121831792872399, 0.06225991150131449, 0.03560701727110427, 0.02853610694728559, 0.02493340114597231, 0.072782289062161, 0.03286531595222186, 0.06727758678607643, 0.035384970396989956, 0.04870508884778246, 0.05016285984311253, 0.037982698777341284, 0.030102222226560116, 0.011694433760567335, 0.06248279329156503, 0.01870351297839079, 0.007631879807377118, 0.05866485538717825, 0.027892015532415826, 0.04251323945936747, 0.04206974685075693, 0.02720087195484666, 0.041744140689843334, 0.041695990148582496, 0.036816361753153615, 0.12383367036818527, 0.06331143827992491, 0.054723079010727815, 0.010103418499056716, 0.04872841454925947, 0.017325086846540216, 0.006874358077766374, 0.056810540045262314, 0.01588105300470488, 0.09823699700064026, 0.011236565751460148, 0.014345066138048423, 0.0635686592431739, 0.0024255844436993357, 0.04271054312994238, 0.07444493734510615, 0.03249722554755863, 0.02500604256056249, 0.03213849733583629, 0.06788346872781403, 0.009634245725465007, 0.1076213207852561, 0.04477637055970263, 0.0388324281811947, 0.05102801478642505, 0.024629356230434496, 0.07996698361239396, 0.027674076445691753, 0.017537257590447553, 0.027207666316826362, 0.013960357191535877, 0.02712487788812723, 0.03064401043957332, 0.0842234083393123, 0.009836845547397388, 0.06292672376730479, 0.03458679057075642, 0.037480246246559545, 0.02602368658699561, 0.04617207574483473, 0.02247794618597254, 0.05804542925034184, 0.09270835304050706, 0.05306504317559302, 0.034993647059309296, 0.09520190244074911, 0.029261378185765352, 0.04506853554630652, 0.027487426305015106, 0.06523233911138959, 0.05551914742682129, 0.026207010050711688, 0.034489023746573366, 0.022568825879716314, 0.042008245072793216, 0.044671879877569154, 0.013069290162093239, 0.02448684161208803, 0.03210898212273605, 0.0257838003381039, 0.07577725569717586, 0.016219051176449284, 0.020124885340919718, 0.026286234315193724, 0.06745479680830613, 0.03212042975064833, 0.053475502791116014, 0.03119290471659042, 0.023330647891270928, 0.06925206325831823, 0.03484197804937139, 0.03896593312674668, 0.01436693537471001, 0.031610192090738565, 0.027707853441825137, 0.017608453672437463, 0.06520052324049175, 0.07369858169113286, 0.013358343694562791, 0.013400455009104917, 0.034280840191058815, 0.025833629988483153, 0.011379903226043098, 0.0290098828918417, 0.009195138281938853, 0.02133009420504095, 0.06858410808490589, 0.02484597614966333, 0.0022924756194697693, 0.040984986699186265, 0.02205412049079314, 0.03055672459595371, 0.011801716773334192, 0.020582280230883043, 0.048496163144591264, 0.1579355713329278, 0.09504565066890791, 0.13068554137134925, 0.19379482604563236, 0.22269223089097068, 0.18437444872688502, 0.15586306457407773, 0.14061152905924246, 0.08816971181659028, 0.167817163746804, 0.10224894343991764, 0.1491368911229074, 0.10060025495477021, 0.1778175591607578, 0.13274143886519596, 0.09738897453644313, 0.09160181827610359, 0.0971445778850466, 0.18169269809732214, 0.11428854544647038, 0.17199036403326318, 0.10536128072999418, 0.11902896920219064, 0.12415672725182958, 0.19269718963187188, 0.13114309025695547, 0.08726640677195974, 0.17730366642354056, 0.14987071190262213, 0.08188219959265552, 0.11467782416730188, 0.1501475923578255, 0.09440801964956336, 0.18060240894556046, 0.2538261719746515, 0.1697629562113434, 0.20835663919569924, 0.10402881394838914, 0.14083294139709324, 0.10476544746779837, 0.08126890359562822, 0.14874631364364177, 0.0959683777182363, 0.07386425873846747, 0.1487422763602808, 0.20147476316196844, 0.09810950345126912, 0.1536438797484152, 0.09798284110729583, 0.09659792674938217, 0.13454499130602926, 0.1228508516214788, 0.11440264323027804, 0.15515061764745042, 0.20899009192362428, 0.07596731229568832, 0.11095649533672258, 0.14766982843866572, 0.12127671929192729, 0.10625437382259406, 0.2505952469073236, 0.1518006669357419, 0.10432708309963346, 0.16650195932015777, 0.10151200563996099, 0.11105225465144031, 0.10220861513516866, 0.10608408803818747, 0.15914411429548636, 0.159454703098163, 0.19217342633055523, 0.18596445559524, 0.09185873495880514, 0.1634320357698016, 0.13670539803570136, 0.16738965699914843, 0.10466698673553765, 0.1428011170355603, 0.14604314463213086, 0.11815526100690477, 0.13207265990786254, 0.2709343680180609, 0.13719763490371406, 0.0991985086875502, 0.12727043009363115, 0.319916678708978, 0.17065975262084976, 0.14525084261549637, 0.10804510937305167, 0.10049863267340697, 0.262205078615807, 0.0730003543139901, 0.08383672713534907, 0.20238410186721012, 0.13379162235651165, 0.109919655660633, 0.14166839187964797, 0.19233000464737415, 0.08211874432163313, 0.12603214185219258, 0.2700858557363972, 0.1298739286721684, 0.19902646250557154, 0.11661143056699075, 0.21244976174784824, 0.11541278043296188, 0.11867433393490501, 0.12429765367414802, 0.1658620944363065, 0.1153018293553032, 0.13233603327535093, 0.10590108184260316, 0.07265385298524052, 0.13975029636640102, 0.11863369392813183, 0.1412994257407263, 0.14311976556200534, 0.1172439036599826, 0.2716932585462928, 0.14511354529531673, 0.1349341290188022, 0.09536541241686791, 0.19123680627672002, 0.144233031605836, 0.13513980782590806, 0.06879163483972661, 0.16960992536041886, 0.1430881500709802, 0.14562635449692607, 0.15730107959825546, 0.13553961762227118, 0.11165520510985516, 0.09311000336310826, 0.2113019413081929, 0.09663985067163594, 0.1422615014598705, 0.16298705886583775, 0.08287908203783445, 0.08945410227170214, 0.0948615164088551, 0.12979646329768002, 0.1535459904698655, 0.07917771697975695, 0.1356590143404901, 0.11677528193104081, 0.16053813480539247, 0.1450502104125917, 0.14112617878708988, 0.11083815988968126, 0.07687855832045898, 0.20540660218102857, 0.23356678721029311, 0.10257464236929081, 0.0718982279067859, 0.09755984661751427, 0.10198223782936111, 0.07324383070226759, 0.16621617309283465, 0.15998743154341355, 0.08121268590912223, 0.09104065073188394, 0.17312757176114246, 0.22821722348453477, 0.13104261830449104, 0.14848737831925973, 0.1459874093416147, 0.13906113803386688, 0.3019350639078766, 0.1743671513395384, 0.15335570380557328, 0.144081826438196, 0.1075273945752997, 0.1307950378395617, 0.1966334815369919, 0.1157034128846135, 0.08062138716923073], [0.040171618820750155, 0.07150118632125668, 0.03312303786515258, 0.009102692656597355, 0.028734163897752296, 0.031696399964857846, 0.04996486968593672, 0.023439901306119282, 0.07880448349169455, 0.0363286445644917, 0.029246164158394095, 0.013816169030178571, 0.02201548428274691, 0.0501422837987775, 0.09683439726359211, 0.05422084912424907, 0.07477632854715921, 0.05091685219667852, 0.04568047712382395, 0.0069356084532046225, 0.005881966553715756, 0.056598790470161475, 0.017396409093635157, 0.013810709606332239, 0.05790219103801064, 0.026300806384824682, 0.00804170256742509, 0.04827589371416252, 0.05298203766869847, 0.053723736346000805, 0.050900654823635705, 0.05986983233015053, 0.017967510284506716, 0.03854665679682512, 0.025161810081044678, 0.08291990758152679, 0.011867096272908384, 0.026194208003289532, 0.044796004076488316, 0.03269226195698138, 0.04393997754959855, 0.025475345209997613, 0.008119758877001004, 0.04016141429019626, 0.04298520456359256, 0.01696937732049264, 0.009709087607916445, 0.05449378506455105, 0.06753891182597727, 0.030632030320703052, 0.05056938236521091, 0.033848962193587795, 0.045845619824831374, 0.049917012293008156, 0.06640350751695223, 0.019695079790835734, 0.057879243831848726, 0.049336018273606896, 0.030463733492069878, 0.015514513688685838, 0.01921995499287732, 0.03764702538319398, 0.03820706486294512, 0.06407289663911797, 0.02043343694822397, 0.03730350377736613, 0.10431616610730998, 0.06382913823472336, 0.009741681806190172, 0.01953420629433822, 0.059773212124127895, 0.02972342448629206, 0.06212243977643084, 0.05978971748845652, 0.026781057567859534, 0.050731719748000614, 0.029896380146965384, 0.027531075720617082, 0.029709425725741312, 0.08337182356626727, 0.015455798675247934, 0.07595061397296377, 0.0354931198671693, 0.02288791412865976, 0.05861291989276651, 0.005712038391720853, 0.050119707666453905, 0.06817752248025499, 0.015092675093910657, 0.06436207448132336, 0.017441529817006085, 0.04859907305217348, 0.006835735784989083, 0.03693441518407781, 0.030487151962006465, 0.06654076772974804, 0.035725627312785946, 0.051378412390477024, 0.02561854631494498, 0.01345786662568571, 0.09008275330415927, 0.011577059394767275, 0.020360285307106096, 0.07997718814294785, 0.03730006021214649, 0.04910729949187953, 0.03279445198131725, 0.03057128553336952, 0.06997424716246314, 0.019591307136579417, 0.013149774222256383, 0.0225117732770741, 0.010748365239123814, 0.035977530787931755, 0.04421570025442634, 0.033648159296717495, 0.015525300805165898, 0.03135690451017581, 0.06342791835777462, 0.031385647889692336, 0.043778159670182504, 0.031623491377104074, 0.01480863569668145, 0.037587178594549187, 0.019580675871111453, 0.04918257181998342, 0.02300904190633446, 0.06754475252819248, 0.024245873682957608, 0.0954304171318654, 0.049723152187652886, 0.029085873247822747, 0.0019086608449470077, 0.049049731096602045, 0.013757535652985098, 0.03208762311260216, 0.08030607088585384, 0.021435403104987927, 0.003392042312952981, 0.01926961023855256, 0.05201966509048361, 0.025841344613581896, 0.015016328507044818, 0.0530911407986423, 0.05461724133056123, 0.009358241932204692, 0.02907810667238664, 0.024596121002105065, 0.016872994601726532, 0.011598904511629371, 0.03197069774614647, 0.07247571527841501, 0.05223688429396134, 0.014159365946397884, 0.01164129413155024, 0.04244424941134639, 0.05493623866641428, 0.030573899748560507, 0.06576736821443774, 0.0658815773203969, 0.08105448971036822, 0.02228031968115829, 0.036791952516068704, 0.07275618772837333, 0.08673738164361566, 0.04837934538954869, 0.05134573933901265, 0.023661039049329702, 0.025229640523320995, 0.03858701849821955, 0.01852303194027627, 0.03540021411026828, 0.029107848240528256, 0.05426335192169063, 0.057281826084363274, 0.03893131564836949, 0.05511659910553135, 0.04698297598224599, 0.07867836291552521, 0.01682268069998827, 0.1074603563756682, 0.028196947314427234, 0.01587309718161123, 0.051285035369801335, 0.07134221828891896, 0.01884605171653675, 0.02962442198622739, 0.0531402301567141, 0.023566044146718923, 0.03018500137841329, 0.017744721262715757, 0.052941972826374695, 0.012726278782793088, 0.01806430118449498, 0.027645340487651993, 0.024822023333399557, 0.043821423168992624, 0.019633722731668968, 0.03756060228624847, 0.03765322602703236, 0.06126095475337934, 0.028652292021433823, 0.06853225422673859, 0.05648908620059956, 0.07022382400464267, 0.0993091035343241, 0.019746262005355675, 0.0641125273250509, 0.02057792567939032, 0.033086305265896954, 0.04827455042686779, 0.06708248358336277, 0.08145833679009229, 0.030830269097350538, 0.037905756616964936, 0.04330324081820436, 0.08180282689863816, 0.018591148109408095, 0.028271366172702983, 0.04291270786779933, 0.032303740226780064, 0.0707505558966659, 0.0566175964922877, 0.046028637152630836, 0.03493186326522846, 0.09867751359706745, 0.07120693218894303, 0.1535281937685795, 0.03703234157001134, 0.003654215720416687, 0.014420988773053978, 0.08692161238286644, 0.01468582973757293, 0.03391757374629378, 0.03196695732185617, 0.03523874132952187, 0.0202237523990334, 0.04188409118796699, 0.033039772606571205, 0.05921860887610819, 0.028162392918602563, 0.082600583700696, 0.05460777894768398, 0.0699831529345829, 0.020498382291407324, 0.02785184307867894, 0.037586510661640204, 0.008078473201749148, 0.01185667744721286, 0.05161774759471882, 0.05214911048824433, 0.04176717695372645, 0.03714497361215763, 0.019779051945079118, 0.055584137298865244, 0.11692593790940009, 0.02383521554293111, 0.06541582770296372, 0.015804435533937067, 0.006765938187527354, 0.04359033322543837, 0.04923933869577013, 0.04418395859829616, 0.0724700749560725, 0.04707074607722461, 0.047813149794819765, 0.0745500551420264, 0.05344193545170128, 0.02178670427383622, 0.030010669033799786, 0.029477448915713467, 0.05744729161961004, 0.04339178645750508, 0.08805955483694561, 0.03031731888768263, 0.0964639097219333, 0.13331537134945393, 0.028221378815942444, 0.03844077087705955, 0.034049683454213664, 0.00806891619504313, 0.03274659829912707, 0.0682195725676138, 0.05570928937231656, 0.10923261987045407, 0.06881088615045883, 0.02293713707331335, 0.021250354147923645, 0.004322543127273093, 0.023543132192571647, 0.027090685289294925, 0.05651546955050435, 0.04707118023361545, 0.04019622843770776, 0.048456573276780546, 0.047159629393718205, 0.03476059413515031, 0.02770989991404349, 0.014180171128828079, 0.016204304702114314, 0.044901971632498316, 0.04171881118963938, 0.024308950669365004, 0.007487441635021241, 0.015807611925993115, 0.04920254672470037, 0.028043526835972443, 0.0034959840377268847, 0.07491229000152089, 0.09443555332836695, 0.024603592573839705, 0.05860926481545903, 0.03680701440316625, 0.0380910523381317, 0.037492859046324156, 0.06560257432283834, 0.04032089811516926, 0.04719662174466066, 0.04243321738613304, 0.04310546959459316, 0.04464393430680502, 0.056853425048757344, 0.0600010588823352, 0.014750403079233365, 0.02677969758224208, 0.04029208423162345, 0.019164880213793367, 0.022937010908208322, 0.023403665945807006, 0.03804731757554691, 0.037310175684979185, 0.02463429707859177, 0.04492825850320514, 0.018535282943048514, 0.0446783105871873, 0.00790835996667738, 0.027899394335690886, 0.018600282091938425, 0.03826048465271015, 0.03095924694207497, 0.02501305214536842, 0.04473419801797718, 0.052714489720528945, 0.007474681333405897, 0.02393144983216189, 0.03605295525630936, 0.024443973306915723, 0.04076177465321962, 0.03516661570756696, 0.05358629430702422, 0.011211056280444609, 0.05160179141967092, 0.24788072303636, 0.1153586407599505, 0.09982452509575523, 0.1325301791075617, 0.20174990699160844, 0.11491072495118715, 0.11698283095029183, 0.12466065294574946, 0.16793228569440544, 0.16511083318619058, 0.07985324948094785, 0.1695388721418567, 0.09485865171882324, 0.14918734232196584, 0.2586494787828997, 0.1982138107996434, 0.21366263885283843, 0.1016836792405229, 0.15495939587708563, 0.08423678184044547, 0.17045886808773503, 0.12057317071594298, 0.16540654934942722, 0.10047503979876637, 0.14243268524296582, 0.07886881285230629, 0.1814803251181729, 0.2747305721277371, 0.1525086461333558, 0.2850004710489884, 0.1497159295831807, 0.18934912397526205, 0.0912195305863861, 0.1064448534452822, 0.08958736230852082, 0.1328064510016702, 0.11997307752608322, 0.09892069312627427, 0.1841823512222618, 0.15112446650164202, 0.22094618005212396, 0.07354154324275441, 0.09877084608888254, 0.16693758516339585, 0.11651999055175111, 0.15259976702509448, 0.16591164021519944, 0.12314532097661868, 0.13809219002723694, 0.13791088334983215, 0.22473735240055248, 0.26930009946227074, 0.13637441501487046, 0.1259756792569533, 0.12709041475318372, 0.15735647350084037, 0.18959444831125438, 0.13209489465225488, 0.15060267731314525, 0.07828954432625324, 0.09850941714830697, 0.06867353687994182, 0.06823710209573619, 0.1393935311352834, 0.05993756072712131, 0.1303377709700726, 0.18971089128172025, 0.15491026570089161, 0.08614432401373051, 0.19934371579438448, 0.1610103336861357, 0.1720305290655233, 0.2899276785319671, 0.13098652678309008, 0.271301256143488, 0.13818286563036963, 0.09012797236209735, 0.09968510523322038, 0.09260545426514, 0.21214606007561088, 0.1441200915724039, 0.15935507719404995, 0.1770161435706541, 0.06829565754742362, 0.13298386882524937, 0.09336977731436491, 0.07009546956396662, 0.14028911042260006, 0.16628115554340184, 0.11692634609062225, 0.12409295450197533, 0.17032087314873934, 0.10812195134349167, 0.12805587466573343, 0.21949308458715677, 0.18353234860114753, 0.1372150011593476, 0.13532875862438232, 0.11787987969000824, 0.17596489138668403, 0.22184523259056732, 0.12218797273817472, 0.09833162825088948, 0.14399866136955097, 0.11963358207140118, 0.10582240676740184, 0.21564206545008346, 0.1391535354196094, 0.18137065053451806, 0.11757220752770081, 0.09543177526211366, 0.08884088791091926, 0.19506250333506614, 0.19982569618150592, 0.17895975412102416, 0.10751704161521047, 0.08893019054085016, 0.17764260526746511, 0.19305980298668146, 0.1465783073217608, 0.16541702847462147, 0.20035738562000915, 0.13377533963648602, 0.10483109785127454, 0.1360694516915828, 0.2098282883525826, 0.10660750995157287, 0.14503654005238786, 0.1440228256979026, 0.1904255201225169, 0.1184665400069207, 0.10706637986004353, 0.0882469025964383, 0.27553164632990956, 0.12007350494968705, 0.15733532229205593, 0.18299506336916238, 0.12146374050644226, 0.1307422562967986, 0.1982476527336985, 0.13659027608809993, 0.1470124488696456, 0.1781938725616783, 0.09761370427440852, 0.11143705822178163, 0.12149130387115292, 0.15702621778473258, 0.20143962989095598, 0.1567946677096188, 0.13518871535779908, 0.06681502840365283, 0.13160023838281631, 0.1645077342982404, 0.14154589298414066, 0.16074117156676948, 0.0962098354648333, 0.11701574519975111, 0.13474062143359333, 0.17770982900401577, 0.12637908104807138, 0.12781337049091235, 0.11365724494680762, 0.13224393274867907, 0.09922324446961284, 0.17504021991044283, 0.18107471172697842, 0.14190709625836462, 0.12143881918746047, 0.0977581855840981, 0.20043725555296987, 0.09739853339851834, 0.19673153408803046, 0.12644545873627067, 0.14013354142662138, 0.07169134682044387, 0.14553849905496463], [0.019686161031131633, 0.000805237592658159, 0.05877026262169238, 0.012649844065890647, 0.060776421378250234, 0.012693889602815034, 0.02753324279183289, 0.003972952608819469, 0.028229202907823492, 0.059913066143053584, 0.04963476982084103, 0.02877035287383478, 0.03828033339232206, 0.06860199384391308, 0.05280484620016068, 0.018932302264147438, 0.05376495151722338, 0.034906292567029595, 0.008465343653369928, 0.06681022670818493, 0.08516167596098967, 0.02289947307872353, 0.024080914663500153, 0.019404104095883667, 0.024161844012269285, 0.04424514125275891, 0.07138435743399896, 0.06280018758843653, 0.057079327380051836, 0.03656753819086589, 0.007310735345527064, 0.06512850522994995, 0.041415706946281716, 0.06645691246376373, 0.04035389400087297, 0.0619255183119094, 0.04439271731826011, 0.07424418639857322, 0.041953745458158664, 0.012595930747920647, 0.05029868771089241, 0.009575532567396294, 0.0301477511311532, 0.029374921214184724, 0.021827652271895204, 0.04410547648149077, 0.02748625927779358, 0.010900149281951599, 0.06025331487762742, 0.1157861846149899, 0.030063992344366852, 0.08339011008501984, 0.09192808865918778, 0.024504651300958358, 0.04722394391137641, 0.03746980793948751, 0.049463248360552825, 0.060284778228378855, 0.0324653391726315, 0.027067404116678517, 0.02282501896843314, 0.07122726703528315, 0.06953620191779919, 0.04495437467994634, 0.029027479213254992, 0.02098237946484005, 0.021143811427464243, 0.012461119622457772, 0.012963275294168852, 0.05395980610046536, 0.008009886696527246, 0.06079626640712377, 0.025928630457201507, 0.0522581394034205, 0.03462418739218265, 0.009464737340749707, 0.051564780515036546, 0.0485550488519948, 0.028879413330287207, 0.05422723159426823, 0.03595746311475523, 0.058989648896385916, 0.04248995457601268, 0.06251500992220826, 0.02028816339588957, 0.04849377342907246, 0.0071693872905598255, 0.050767925422405824, 0.01880400719528552, 0.027495163194544148, 0.09439701359951869, 0.059359201331972145, 0.0380726619187044, 0.021654115880664904, 0.10033578320872039, 0.07435019477270544, 0.03534866824338678, 0.0357348002580693, 0.09424713687621988, 0.033996126367128454, 0.026465681912668515, 0.05979581794235855, 0.02415191222098656, 0.02133170095476089, 0.08194960886612535, 0.015747603720228653, 0.029618360495078377, 0.008903492798708612, 0.01626274697628105, 0.07132134167477489, 0.006396812023012899, 0.05610989697743207, 0.038181115669431165, 0.04859515822317917, 0.04382389823149424, 0.051463403142406605, 0.02132707551936619, 0.04063001375470776, 0.07630414344021119, 0.02090139445499517, 0.08216390400775708, 0.016742656771384645, 0.005331372294676839, 0.06012494188325945, 0.019222430055378936, 0.05445246599265374, 0.023896366656117607, 0.006612347478949232, 0.025057701604964677, 0.07795448691467755, 0.08264991425676271, 0.04809580415894743, 0.07468923751730472, 0.009020891284308163, 0.07432334386976436, 0.06994830167968757, 0.1345542978378944, 0.044256492401473224, 0.020045410601596814, 0.08538787515135482, 0.046403514497797005, 0.03873933317663614, 0.019664464343804866, 0.01890590963739669, 0.03138943655358162, 0.07345723526668735, 0.052004369426867925, 0.048324715899070725, 0.043112189741805196, 0.024917790069594048, 0.04607904382282868, 0.009977406461985083, 0.03383538831258193, 0.04171972403128166, 0.03063349606236443, 0.07360385396168567, 0.029993657153681852, 0.0409013652097201, 0.02112233552907128, 0.05308245396008715, 0.030077994815655984, 0.02339175818633521, 0.024362741532968357, 0.039282499928958714, 0.041858750555547886, 0.07734723199973814, 0.06539584166603163, 0.036529744320432656, 0.04315259968279861, 0.05589076674368698, 0.03787107976677362, 0.0384551017486956, 0.015007923684606794, 0.025329284981125966, 0.043804876986541785, 0.030030977904971223, 0.02847818974260008, 0.07999745619599707, 0.03531200243742205, 0.052969205935369246, 0.015263904333551181, 0.04004453345260117, 0.03553502152499277, 0.026200204556516837, 0.030695116583956406, 0.05504455511982087, 0.06769496321794577, 0.05302274817950092, 0.020500159735092893, 0.048050124969449826, 0.0688764029473532, 0.019493493928166572, 0.06230936822248623, 0.05652418236422818, 0.025588025491742883, 0.11555336546734907, 0.04356675890448969, 0.04274719780369196, 0.015367181604233338, 0.026046826751553454, 0.07905327365733683, 0.04895616111753043, 0.06265939475269988, 0.03973360697273165, 0.04650734095775988, 0.031227084327838384, 0.0392903815372847, 0.11008024157490581, 0.04695996940426994, 0.053689055785071105, 0.021395039548224304, 0.014952030687709339, 0.020277828989492264, 0.04254258768924046, 0.02489887086994713, 0.07949506674776785, 0.046322817070176825, 0.02375488733378006, 0.02219708596385317, 0.01207591622005566, 0.02938235196779715, 0.05814512936922256, 0.048550135834375396, 0.056114305334631354, 0.024250278329418506, 0.10119976184796542, 0.0874376499268692, 0.17207628989126533, 0.09787229078938253, 0.05385058051615488, 0.026704839001467917, 0.06251877261092886, 0.010698293463065056, 0.03154063429974485, 0.03293055444373749, 0.03251778303820174, 0.03136733910650946, 0.07938314345665276, 0.04656623779737856, 0.007365385245066136, 0.017780314665287733, 0.0069704810448456556, 0.09126135802944191, 0.016623124611214735, 0.025292550526501145, 0.02308164806891, 0.06354709985316731, 0.05072678075521253, 0.01626834462513216, 0.013120894473104272, 0.016514609633304644, 0.058146695300820284, 0.014320587324618828, 0.09770340766408481, 0.058430422068340704, 0.05957932604360394, 0.009917852821672568, 0.05111187005240936, 0.03519283207424451, 0.02186601017456269, 0.024303076570504345, 0.030814990132057574, 0.08960632418165915, 0.004519311059993925, 0.027553264080779627, 0.015642558282706887, 0.04168431616562884, 0.028257630874577444, 0.049036877098842524, 0.05643409676849842, 0.09331512555945665, 0.029629268210555892, 0.04354094329755753, 0.010340739700041013, 0.010308134369552135, 0.0702239501697477, 0.010112014424521476, 0.06956823301152326, 0.12912360252812505, 0.0016527450179637526, 0.07357685462920927, 0.03182456515787635, 0.024331133463419974, 0.05720797867979854, 0.02523374088923447, 0.05281334379105829, 0.014523369900416583, 0.12685179943218827, 0.06129127890744712, 0.07917934970464557, 0.05894103451282717, 0.08599229506216943, 0.025036630177055486, 0.05606958351563662, 0.05463053319544997, 0.04475601715967059, 0.035529896995285526, 0.03559838980436325, 0.021828546559845563, 0.02573471840150887, 0.03430790631682612, 0.010427462439110968, 0.016467800523969345, 0.04379953723400831, 0.04102722603420261, 0.06668261441518553, 0.10393620876129717, 0.014481624093605205, 0.030963421522756107, 0.020073606647201814, 0.04084303982381243, 0.06495897643617354, 0.08624431357020512, 0.008764749218244106, 0.02349252514250111, 0.00589680069424503, 0.030257451689976733, 0.05741569839301519, 0.05182340413739439, 0.060204770998097956, 0.027591306570684537, 0.03597607617848553, 0.045884753271820955, 0.015333836909121601, 0.056841250116121955, 0.021512475141207688, 0.05076158377050888, 0.06205603240232449, 0.02828631488227984, 0.0362013402627781, 0.04764705714478623, 0.03891397165716626, 0.0737131352070719, 0.04295829057809897, 0.007135301839298336, 0.02721740514971316, 0.02971454283397179, 0.020858928764937446, 0.030776031089772005, 0.027376343496143818, 0.0027674941975419642, 0.08581817237427458, 0.060414683757699095, 0.020217479395796545, 0.07242844789288938, 0.09205941911204718, 0.10011520949774422, 0.016508219741808716, 0.059003233909606934, 0.02531282414565794, 0.04345696186646819, 0.010085075391543796, 0.23222078365506604, 0.18334068154217675, 0.17677867115708068, 0.13058992306469008, 0.09686435034382157, 0.14699033286888152, 0.1056988540221937, 0.10736661570263095, 0.07373000422376208, 0.2748720848467201, 0.18071049533318728, 0.07137876906199381, 0.12105368907214142, 0.22693866631016135, 0.20215945376548916, 0.1749795419164002, 0.17373409937135875, 0.13671589200384915, 0.11449777914094739, 0.2904658840270713, 0.20556850911816582, 0.07312158413697034, 0.12952715274877846, 0.12476036790758371, 0.12442674284102395, 0.07758621839457192, 0.16594048007391393, 0.14624941715737805, 0.21347539499402046, 0.13597349199699238, 0.08382580272154883, 0.22245478816330433, 0.22504590771859512, 0.1860700483666733, 0.09096957524889149, 0.09980508082662709, 0.08516648507793434, 0.1789271441521123, 0.10212545006652363, 0.1999156444799155, 0.16761696198955178, 0.09353728004498407, 0.11272796473349445, 0.120274827349931, 0.17209640209330246, 0.1724032504716888, 0.12699601356871426, 0.17275715101277456, 0.09379217066452838, 0.2002263074973598, 0.1770739717176184, 0.17904654087033123, 0.24479950399836525, 0.16276165377348661, 0.22971841011894867, 0.20202263141982257, 0.08408990339376032, 0.11395918030757457, 0.13135454297298566, 0.1268438287661411, 0.10173650531214662, 0.2031128908856772, 0.21726005128584802, 0.1570981170516461, 0.12007581302896142, 0.16260430362308398, 0.10291747748851776, 0.18168999667977914, 0.15765762218507007, 0.13127909624017775, 0.20586682279827073, 0.18030559440376237, 0.1683199984836392, 0.1617777143837884, 0.22000285098329186, 0.11779515611124225, 0.1899992156540975, 0.15483510098420084, 0.11759465749491937, 0.17919927486218512, 0.14879783353535458, 0.06537241948535666, 0.13851571886334568, 0.14158004662021995, 0.15656486910302192, 0.18567046121461317, 0.1377673223032616, 0.1403719192603603, 0.15667452884372324, 0.13317155797267333, 0.1711974831414409, 0.21777361747808754, 0.0968509545782581, 0.2006788839935325, 0.16912132501602173, 0.15088981424923986, 0.1270990978810005, 0.09810215618927032, 0.10935559374047443, 0.104940371675184, 0.08503828648827039, 0.16680328611982986, 0.18380694324150681, 0.09817397381993942, 0.27910015953239053, 0.08937186488765292, 0.20303262019297108, 0.10569802281679586, 0.09766201808815822, 0.159234760212712, 0.07685158867388964, 0.27385252236854285, 0.13022769562667236, 0.12392195625579916, 0.16307673999108374, 0.12579232425196096, 0.08449160566669889, 0.12008084479020908, 0.21204903168836609, 0.11380266878404655, 0.12871757353423163, 0.14153732859995216, 0.09919264572090469, 0.15136380912736058, 0.09459158245590515, 0.1863277071970515, 0.09563961371895857, 0.16368792828870937, 0.11349602820700966, 0.17544733243994415, 0.13262889959150925, 0.11687628822983243, 0.13846244750311598, 0.13474632112774998, 0.08487736660754308, 0.15705585916293785, 0.16931048361584544, 0.09572601455147378, 0.13219376356573775, 0.15364389459136873, 0.16476802033139393, 0.11974359062151052, 0.12781642813934013, 0.14943720860173926, 0.15143796452321112, 0.17517076368676499, 0.23030181240756065, 0.13031053415033966, 0.14830250933300704, 0.11603251085034572, 0.15832255681743845, 0.14301003160653636, 0.09909293075907044, 0.13351554342079908, 0.1399823511019349, 0.14416408608667552, 0.200895887974184, 0.10715878466726281, 0.12918684835312888, 0.10920609551249072, 0.14387438131961972, 0.09318041091319174, 0.08728994769626297, 0.12424215587088838, 0.1318019095924683, 0.20522528066067025, 0.2284970725304447, 0.1526822938467376, 0.2181216105236672, 0.19219082227209583, 0.15383786230813712, 0.087821770721348, 0.15157812653342262, 0.14888525853166357, 0.12904886825708672, 0.09689762824564241], [0.03414538339711726, 0.04482551557885017, 0.0600928625499364, 0.007115762018656824, 0.015870473689574283, 0.1052449936105404, 0.013073103873466607, 0.03124128532363102, 0.00887443400642951, 0.011739065594156273, 0.07804002685588785, 0.005964031388430158, 0.028631272543861996, 0.017894466254801955, 0.01366751592286164, 0.06323177614831366, 0.02099744506267598, 0.025906074733939022, 0.06411445690901019, 0.053241236455505714, 0.018473636446287856, 0.04750070933368988, 0.054380652072723024, 0.041164215363096446, 0.032987614467856474, 0.03323004813864827, 0.03335296634759288, 0.062449782562907785, 0.05885396574740298, 0.05973608618660364, 0.01989942458749283, 0.06312374913250096, 0.05295981405652128, 0.02320586132555036, 0.038914543110877275, 0.021934380529273767, 0.0413160290918313, 0.006654172138951253, 0.011012841623596614, 0.02835764826158993, 0.047864113075775094, 0.03393023107491899, 0.049054391784011386, 0.03140378597890958, 0.044854644875158556, 0.03072317904297961, 0.016807678184704855, 0.025361245570820756, 0.023692415197729133, 0.04912014977890067, 0.03381455622729845, 0.028539507839013822, 0.015017977930256166, 0.04245455413183663, 0.01933296738570789, 0.030175451793184038, 0.043518374586710706, 0.02487620382453315, 0.028493229365267325, 0.014966859725973336, 0.058705521369120106, 0.055000434440444224, 0.022588435276702512, 0.09901470097247511, 0.03620659095759038, 0.04428801512403879, 0.018811515874403995, 0.12294209125684574, 0.09173893005936407, 0.009015273226395948, 0.06760743432096206, 0.021553855440288316, 0.015928808352327906, 0.01663420673139626, 0.06425327563192695, 0.020905164565192536, 0.028836821475124452, 0.02055458513495978, 0.04131691595830489, 0.025760213029570878, 0.03515053707815241, 0.05207995345699601, 0.10962437736452557, 0.044355391000863165, 0.06446898085414432, 0.0993830214429181, 0.04037698221509345, 0.02752701060671825, 0.024959123984444886, 0.03327618003822863, 0.03341634204844013, 0.03420730819925666, 0.020305255056882743, 0.052005553152412176, 0.0713790584995877, 0.03194370954588521, 0.009899390970531385, 0.05718080123187974, 0.04825707284908276, 0.06145968334749341, 0.057134591406793334, 0.05871349203516729, 0.07757937579299323, 0.017536339182697702, 0.025189163789036684, 0.025057161692529917, 0.03614161963923834, 0.06979276236961596, 0.0664307591796387, 0.02978493554110173, 0.08950730683864094, 0.0232272092034691, 0.04068099930009339, 0.01374251643937896, 0.014008850048412569, 0.025835654196271207, 0.01956825788511196, 0.06733130343491212, 0.03430101176491007, 0.04544704199361149, 0.027791990723926574, 0.02275768762046937, 0.04929977178107947, 0.08312672929605469, 0.044379098908393644, 0.0499406830931548, 0.03815283242147416, 0.08764353653532453, 0.012447522549337009, 0.06194364897964988, 0.053352436152636074, 0.050551414969959296, 0.014894794403517153, 0.03897601149219554, 0.08590569384978153, 0.03067249035666464, 0.040540495901950635, 0.04045250316266902, 0.08008041346329264, 0.12066431387211196, 0.04780786199262366, 0.07400437621981837, 0.044923315799678676, 0.012578977311932249, 0.010334423095628154, 0.012779038988810498, 0.052421949949348345, 0.0400632949458668, 0.03277722673374228, 0.016075113489932846, 0.018266885235789232, 0.015341659145633457, 0.02743327549978858, 0.010877469248953275, 0.029911955971329007, 0.06482359385699965, 0.05369749400415458, 0.0229383875921485, 0.014765822124900296, 0.03853934664221015, 0.029224775462353136, 0.007270019732459332, 0.06454110276536085, 0.0077288497504923726, 0.007409861227642978, 0.03359503636602312, 0.050405946603859775, 0.03440801090619061, 0.048516590759390965, 0.01827111733291531, 0.08419105812208727, 0.06538615663885139, 0.04665718428441323, 0.007651479463675059, 0.04690629728429485, 0.0158394407844753, 0.06459831492975354, 0.05177105304028373, 0.06469308718806133, 0.01824352984840516, 0.013088055366097251, 0.06171298948174808, 0.01664414223341737, 0.09020655837957747, 0.07200948326499201, 0.040641160812810995, 0.02452458909829147, 0.05859040313225705, 0.02307121718331473, 0.04782644537044689, 0.03186018453561701, 0.035415012534940615, 0.005675436595993233, 0.015508129363297485, 0.029895163024775684, 0.029334036298678257, 0.05100178357679397, 0.03446464048465714, 0.09674433022155426, 0.05638424670905806, 0.08698364108568057, 0.032276165729854256, 0.020706871982838493, 0.07549051209934987, 0.030834647768642753, 0.055995947623159736, 0.03614032830228098, 0.02763808413874358, 0.038395540686906315, 0.011855322100018384, 0.03451099502854049, 0.038296790517051704, 0.022954644337005448, 0.011061752866226016, 0.09478488966124132, 0.0223574251140235, 0.02676277104910696, 0.016836883551150095, 0.04216016641294118, 0.04173884917690884, 0.052508098451653495, 0.02489924750989303, 0.02704013946640771, 0.020522964077827055, 0.10125157859874889, 0.015182486095000058, 0.03546797961462289, 0.03136023304250557, 0.028403843243722804, 0.041359303722856566, 0.03362224349984899, 0.04806205128261354, 0.006985475674810004, 0.061644656234420836, 0.03881902499415446, 0.06820103371865116, 0.08100797931547277, 0.10539236187469214, 0.02301889948284952, 0.03137503888865467, 0.013628170036099618, 0.05725661903852597, 0.05110815189254936, 0.05756938975537196, 0.017699288837320637, 0.03162437824357767, 0.03678737717564218, 0.02761589206784265, 0.026695230044424534, 0.03996195096988231, 0.0743501354008913, 0.019179118316969834, 0.046953386554378085, 0.016330723992723506, 0.038324368724715896, 0.06419515062589198, 0.07364787816186436, 0.09150553203653544, 0.04486974015890155, 0.010808831721078604, 0.016374872502638027, 0.08630558528238907, 0.011412431558710523, 0.025986569926317316, 0.05978077831969131, 0.04606520276865922, 0.014743748797627632, 0.07581195852253586, 0.032141347182914615, 0.039799665537429973, 0.0514846730948193, 0.028950904415978584, 0.01785268705134513, 0.04766577410919126, 0.0484043075266527, 0.08235581597546116, 0.009665886263974244, 0.0905501504894346, 0.010677083810151089, 0.06703969876980409, 0.08947687136242166, 0.022035744914319366, 0.016794954062788747, 0.07629357525729574, 0.041407246462767944, 0.07097385328961536, 0.03530892623530235, 0.05273465758364182, 0.03622074000304565, 0.01588637791428482, 0.011643346169876168, 0.04349066279246472, 0.01481198185501853, 0.061029464050079696, 0.07536433957284316, 0.07107019890099764, 0.05366810866689775, 0.02032386626524385, 0.05033174667914864, 0.06748618223355152, 0.04599191568559036, 0.01169130096968729, 0.05114778257848229, 0.10611986697767861, 0.020942921328241937, 0.06373666663421318, 0.0424872494477313, 0.030612166738137603, 0.03348067511979025, 0.02639753234689124, 0.08150991605361924, 0.05408917728345841, 0.048360587607021444, 0.03936357956263237, 0.05388703852077015, 0.03805980049946811, 0.06241097566089593, 0.017954587638087105, 0.03791356772126164, 0.0300188771871035, 0.01611329884326551, 0.0404904417518992, 0.036642365230363794, 0.03203627762559336, 0.04321491782320663, 0.03572901521692984, 0.06885994953336194, 0.06882319095893763, 0.016313533997163177, 0.044059214706066996, 0.055815420200815424, 0.04440833210537676, 0.04403302060381975, 0.04715046386991162, 0.057122761572827585, 0.05774507466412615, 0.06216260480869096, 0.044343627960188314, 0.016566964441153686, 0.033317911002086475, 0.01612531421415042, 0.06473220579209737, 0.024795814388198778, 0.04285968141630292, 0.043665791090461425, 0.07612884073751047, 0.1536320202285424, 0.014990203053457662, 0.043914952329942025, 0.005997473490424454, 0.005980035803077044, 0.034795378596754745, 0.1727046663290821, 0.10925058726570569, 0.19813493534456939, 0.16823980200570077, 0.06180104159284383, 0.21150067361304536, 0.11069744126871228, 0.10357617065892555, 0.1479994459077716, 0.14288270875113085, 0.21340787439839914, 0.19099044293398038, 0.15316181030357257, 0.17786326061468571, 0.1406590116675943, 0.17842720379121602, 0.10748221262474544, 0.1384543877793476, 0.14667557319626212, 0.11767765929107554, 0.10599940898828208, 0.11772067417041399, 0.1136852239142172, 0.17056754819350317, 0.14491907291812822, 0.10618373620673083, 0.09251777693862095, 0.2106332068797201, 0.15747140249004588, 0.14212721725925803, 0.08417154705966823, 0.10583085240796208, 0.18828118831152096, 0.09654132314608432, 0.12798508862033486, 0.2075297976261936, 0.09817058962653391, 0.10146309810806997, 0.18071867380058393, 0.10950690280878916, 0.12543405988253653, 0.11444110874435864, 0.15677647024858743, 0.29648125811945647, 0.15377771866042167, 0.12845212215324864, 0.1516865988378413, 0.13928050204413012, 0.1770344449323602, 0.09269615955417976, 0.11110413819551468, 0.0984373471874278, 0.09857939425273798, 0.13606761116534472, 0.1112015153921675, 0.1545847745728679, 0.09407960445969366, 0.19050733448239043, 0.1216163112258073, 0.17939261917490512, 0.197058524354361, 0.20572084235027432, 0.10372354634455405, 0.20382392773171887, 0.14319426234578714, 0.22454696183558553, 0.21123443555552512, 0.2058545031468384, 0.15689790045144036, 0.1306465340894647, 0.13040858670137823, 0.12169188412372023, 0.21588529692962766, 0.09874627357930876, 0.1770727100665681, 0.09025979263242334, 0.1381047916947864, 0.12024721203488298, 0.1966411405010149, 0.1340113129117526, 0.2162898119422607, 0.2176130612497218, 0.20891310152364895, 0.11678125621983781, 0.15486647898796946, 0.18972049467265606, 0.14228263782570139, 0.12120002575102262, 0.12239868330652826, 0.09876688302028924, 0.10202602454228327, 0.1957038079854101, 0.12483201484428719, 0.15581126266624779, 0.10777898263768293, 0.10602321708574891, 0.07439660126692615, 0.1631347759393975, 0.1796519849449396, 0.1776504423469305, 0.15303508116630837, 0.17334512493107468, 0.20529030764009804, 0.19438579824054614, 0.1818871111026965, 0.07608566258568317, 0.13253415701910853, 0.14161794068058953, 0.11535723810084164, 0.1486462276079692, 0.28134859981946647, 0.08335282458574511, 0.1483172780717723, 0.1281542982906103, 0.10242063930490986, 0.1775763017940335, 0.10043544622021727, 0.15322446241043508, 0.12372693468932994, 0.11627427287749015, 0.11654647038085386, 0.09182084089843556, 0.14209036220563576, 0.21389377332525328, 0.12879446003353223, 0.2001779936836101, 0.10212487119133584, 0.24905175785534084, 0.1258546646567993, 0.1833173632621765, 0.20306321152020246, 0.12805431615561247, 0.08771814464125782, 0.2288519378635101, 0.31362451321911067, 0.15512547368416563, 0.1543869180022739, 0.1433352258754894, 0.16708965122234076, 0.17317769641522318, 0.24673259089468047, 0.12637906620511785, 0.1298331847647205, 0.11899193603312597, 0.0934681341459509, 0.11269802649621852, 0.11101689873612486, 0.23508021928137168, 0.23974350420758128, 0.08048452029470354, 0.12392660210025497, 0.1384631302789785, 0.13554546574596316, 0.12724101135972887, 0.14182445069309324, 0.1195844667381607, 0.11790386590291746, 0.16156678117113188, 0.12761212972691283, 0.18410855205729604, 0.21730615349952132, 0.12106743364711292, 0.12228747247718275, 0.10807309576193802, 0.14691861171741039, 0.21899314422626048, 0.3108122188132256, 0.13475090760039166, 0.14189655776135623, 0.12107003116398118, 0.20411228179000318, 0.2364791973377578, 0.1500332125579007, 0.12930949567817152, 0.1430247855023481, 0.11959476774791256], [0.04742039040138479, 0.01690661760221701, 0.04517106695857365, 0.05706278490833938, 0.0632700338610448, 0.008545208947907668, 0.03436311468249187, 0.06082927342504263, 0.06267300574108958, 0.07156017221859656, 0.0346049657673575, 0.0766546672093682, 0.03319366434880067, 0.029809619372827, 0.023132379428716376, 0.04332398013502825, 0.07359402792644687, 0.03639478105469607, 0.07879149590735324, 0.09041719473316334, 0.06571316174813546, 0.027582781149249058, 0.01498819832704612, 0.048510668420931324, 0.0842199350881856, 0.012649987857002998, 0.03828418884950224, 0.009849089128692867, 0.07961165814776905, 0.023164805716078263, 0.02988094161992194, 0.06070843322959263, 0.024514738943253178, 0.023648949463677127, 0.08025615403312258, 0.04044089226226788, 0.059199172028456815, 0.007006810101302108, 0.06939871906070039, 0.030292789051600266, 0.03170446339936461, 0.0783092928759288, 0.021180755538807716, 0.020714623715321068, 0.05553820577915758, 0.020863450299657416, 0.011378133203834295, 0.09789734569494613, 0.035664207171066664, 0.05739729313063435, 0.10817407237482257, 0.004780155095431837, 0.07560271740658209, 0.040048463124549016, 0.02295343092555413, 0.03140728149446659, 0.004873141560892691, 0.007502257685700897, 0.030148855075822212, 0.02919362381362589, 0.030958380484662484, 0.05417105101514608, 0.01847685365646612, 0.03080368165683467, 0.03282784491602797, 0.04077335586771369, 0.029206103026808705, 0.013963642122689635, 0.018622869356477167, 0.02160177034966182, 0.01730879670503782, 0.04047534275741782, 0.02422647023195168, 0.054540807541343383, 0.04157838200626429, 0.09676614936324768, 0.019402081743464805, 0.023664746076974552, 0.037906405996182, 0.043850285292137414, 0.06114016279752832, 0.03997319821792189, 0.07024242222541943, 0.06482147873612121, 0.016214531497098505, 0.018709886171563994, 0.11139322697999887, 0.04710336717835162, 0.0026920739037450403, 0.029552771338785533, 0.0675626753945835, 0.028735405139741488, 0.039471977652283385, 0.04790064529515803, 0.0233973372814944, 0.04443007332156412, 0.10727264496381395, 0.06092966745200101, 0.06814591441070661, 0.014307083019957645, 0.03862325014779344, 0.05876868555787951, 0.0112657683348516, 0.012210423992655706, 0.026481220629648305, 0.013527667470043525, 0.014323853702080669, 0.026819641825568397, 0.043131938291480765, 0.02675765208550729, 0.05386016164266039, 0.03389317193068564, 0.03702562884427607, 0.04106267100723926, 0.08118571626255289, 0.023411597649101168, 0.05074439563031774, 0.03593450477637816, 0.005135673054610379, 0.03681239868456032, 0.05349493592802901, 0.016513253358425573, 0.023397168442897964, 0.04299995103792753, 0.012738917557726381, 0.032450871003675275, 0.017475011809438, 0.06038884959707502, 0.05778728431323543, 0.035189251211704686, 0.03709784723469056, 0.08481521916110069, 0.07552448761998676, 0.005018012498112512, 0.06129029927251395, 0.041499996368656866, 0.0203378650257946, 0.0744222869980149, 0.03193786513293162, 0.026203028428426478, 0.06191795953782275, 0.04541333735687658, 0.014638313732575625, 0.04601109278155491, 0.0795441004447639, 0.04740748445328791, 0.10644588503055274, 0.01829938388254959, 0.047969011939130723, 0.014158889116515638, 0.03459647188719828, 0.06675585696939379, 0.01669706849497743, 0.015070003410073696, 0.07084169905283488, 0.024644247423566412, 0.02105616935295984, 0.015740306553198025, 0.0554122707399074, 0.0110053422213241, 0.007878702817833982, 0.048232726694550365, 0.05318399460520595, 0.032176487875403836, 0.022658280649920925, 0.01057951736584073, 0.01123267225921154, 0.011756997737393249, 0.0639057278749533, 0.057439124284428544, 0.04888593168288935, 0.019198217487428337, 0.06256526074139401, 0.03748093644389883, 0.037610470899380744, 0.04063815140398219, 0.024482513035763986, 0.026963251111737918, 0.022910898442205507, 0.08169243985321373, 0.05762749249697663, 0.0664953186060302, 0.049666218328638934, 0.053319113721954636, 0.056778880025376566, 0.035452446463750675, 0.015888749076111708, 0.02887172839109553, 0.05189003415580373, 0.02317865419172449, 0.03259150056692306, 0.026517392907408066, 0.06045903079211712, 0.006736707773598027, 0.06472941531683318, 0.02174101580749266, 0.1032716674671974, 0.024336588248843327, 0.03134885220788419, 0.024086061457637697, 0.023252835562743712, 0.05728354415623471, 0.021041782820248045, 0.021425543673103675, 0.04795846973138396, 0.01972445214050822, 0.1385693167685531, 0.07347608581767417, 0.06392196606611833, 0.03313835579319857, 0.060553435687324964, 0.010208585463260533, 0.013846110050508287, 0.05402788701758254, 0.013577198405982926, 0.044410176342353225, 0.08814902816084214, 0.02960089776024688, 0.03573000227333978, 0.08226410136558115, 0.06057141792553011, 0.032183497460209765, 0.04771619933308102, 0.03966551121266093, 0.016031939048843924, 0.034405513579258695, 0.06293677986832336, 0.021823948954988737, 0.02233749288279796, 0.1022220405866392, 0.09468663673033006, 0.026194408383162227, 0.012048615390085615, 0.05531847811653279, 0.06511727653560229, 0.06427990389056504, 0.013326634507393464, 0.05377146015234757, 0.02051156468951376, 0.03470873285550624, 0.03664426883915439, 0.03960823225497734, 0.038361984479706734, 0.037594692839775234, 0.08422176077147014, 0.057951610651798546, 0.022300400341919158, 0.035426441609160975, 0.014091979865042958, 0.04710397945018485, 0.032180491762119345, 0.05849713743373286, 0.012983769702259451, 0.012659369531320408, 0.02727828723436687, 0.07650381085113622, 0.06920381623785943, 0.09724518342409283, 0.05461974607896991, 0.01517682443591184, 0.02749646380834747, 0.04506586381467059, 0.030287822228274308, 0.08917024562833831, 0.019649988753371872, 0.05142894893651828, 0.035970023964182474, 0.0096882490288408, 0.08984985994175076, 0.020651849154091906, 0.011022772487194743, 0.042017332671093754, 0.03959563429816626, 0.10083411310915835, 0.030249733354139607, 0.03143177607853431, 0.01715444483124884, 0.05186040019907523, 0.012652084424189525, 0.019587748538469896, 0.033950465731322765, 0.02511976741516264, 0.027810366300400347, 0.020280632452340797, 0.031896315995254554, 0.03311713779112324, 0.010531327861826867, 0.021227297474979423, 0.04430904758919496, 0.04393796632939484, 0.05048730083217379, 0.028292962670093402, 0.025369950963067822, 0.02758895767328795, 0.026924850535579026, 0.09266216176911257, 0.12129370705224574, 0.04457467337488197, 0.047070898217498325, 0.03938211470085662, 0.009719436857267283, 0.027784678713942412, 0.029397016805887688, 0.015370273576991167, 0.02445088826789288, 0.08543423711671494, 0.03149478812702, 0.053570968957501464, 0.03510094677039888, 0.033910300699062645, 0.04021245549665764, 0.017558742765686475, 0.05867777617822867, 0.04563479051284958, 0.05036171089159325, 0.02820249672367936, 0.07890632841736078, 0.018183736865466926, 0.056408143864246085, 0.020687149408331607, 0.02142657154763583, 0.027684065753419418, 0.02068032721581403, 0.028850764574599452, 0.06926226036739536, 0.03286587627371773, 0.022664295756840147, 0.026805557718034834, 0.044085802146582864, 0.09341493700048886, 0.003198582735421951, 0.018397152562101837, 0.03497382429486606, 0.03174252815369982, 0.019027443740924355, 0.03200828381523024, 0.030010630071046762, 0.0214162427073461, 0.09132438121014275, 0.030807715229457244, 0.03967255790485069, 0.038847133837407455, 0.06809941143728793, 0.00902840367416502, 0.06259833084186539, 0.0652843042917084, 0.0405969844723586, 0.029339832472032867, 0.017645509105932433, 0.02189969440223649, 0.033536855698912404, 0.04352292395196855, 0.15031659422675148, 0.18380155524937436, 0.1259317441144958, 0.18170049064792693, 0.09844557760516182, 0.10974227494443767, 0.11630055232672021, 0.14483507664408535, 0.14275655848905444, 0.11311887617921457, 0.07755940459901467, 0.1453499193303287, 0.18762155261356384, 0.1385158227640204, 0.15351217822171748, 0.1606200382229872, 0.16252919827820733, 0.09691482380731031, 0.15776794985868037, 0.15432696731295437, 0.13302931794896722, 0.11095757145085372, 0.12094127596355975, 0.18529071909142658, 0.22578171745408326, 0.24609949439764023, 0.11709352969774045, 0.09724350617034361, 0.17423930898075923, 0.1857414995902218, 0.27479968091938645, 0.14110422605881467, 0.18739167979219928, 0.10539302980760112, 0.19076643307926133, 0.12881813454441726, 0.1373792829690501, 0.1346932872547768, 0.14701522450195625, 0.12393172291922383, 0.11248925293330103, 0.12324806390097365, 0.08783725934335962, 0.1471540061174892, 0.1672456951928325, 0.22331192420097068, 0.1477877705474384, 0.1718688299297355, 0.1431961770867929, 0.14472722774371505, 0.20850202592555434, 0.16983086272375658, 0.15756685752421618, 0.2580486360238865, 0.1824187411693856, 0.0990077989990823, 0.08918292151065543, 0.07013804657617584, 0.16672712692525238, 0.12091672571841627, 0.05848469532793388, 0.1688374683726579, 0.1179422126733698, 0.1151095017849002, 0.14569083228707314, 0.11075160320615396, 0.14375217928318307, 0.1201197259069886, 0.15630998590495437, 0.0887120065453928, 0.0982985581504181, 0.08548623198294081, 0.10723980492912233, 0.2098230191040784, 0.13904959021601826, 0.12907475436804816, 0.10800400181324221, 0.09544124506646767, 0.13703443662961945, 0.26080108364112675, 0.1944329246180132, 0.17002799198962748, 0.1620870563783683, 0.17895029915962368, 0.09742595575517043, 0.09300974663347006, 0.16611086233751848, 0.12372302357107401, 0.1306040387134999, 0.12574460415635258, 0.14470978727331385, 0.09392385734827258, 0.14255077578127384, 0.11572097209864296, 0.1524107568548061, 0.09220917709171772, 0.19064976746449247, 0.15281121974112466, 0.1397334793000482, 0.10500374366529286, 0.16654363833367825, 0.17240084591321647, 0.09481571105425246, 0.09339262804132886, 0.1653595268726349, 0.06366723129758611, 0.08068977607763372, 0.11035214964067563, 0.23161335062468424, 0.15679809643188491, 0.15936462121317163, 0.16536301496671513, 0.17075354524422437, 0.1223413746629376, 0.1774051328538917, 0.17047092056600377, 0.2809942391468212, 0.09963031247025356, 0.08535582921467721, 0.1638357641058974, 0.2614851063117385, 0.0886485083901789, 0.11159135072375648, 0.08436198215349577, 0.08162473372067325, 0.0995206156221684, 0.1228963304311037, 0.0965283578261733, 0.13639230077387765, 0.13627569453092292, 0.1277260493952781, 0.1058835226285737, 0.1566499043838121, 0.15458901965757832, 0.1522217466845177, 0.13794310740195215, 0.1481129351304844, 0.13955971284303814, 0.15384805941721424, 0.0999350160418544, 0.1436540822032839, 0.1518470363225788, 0.1790938898921013, 0.11513405945152044, 0.21520522248465568, 0.12318980530835688, 0.22602536453632638, 0.1271408362663351, 0.17889066017232835, 0.05704653187422082, 0.10966971516609192, 0.11644049911410548, 0.10020593705121428, 0.21607246657367796, 0.1074950146721676, 0.13847775058820844, 0.14100534230237827, 0.09625705090002157, 0.07048785788356327, 0.15096232207724825, 0.09304634193540551, 0.09216640712111257, 0.15538115840172395, 0.15704343561083078, 0.06430909255868755, 0.15033464325824752, 0.11926517996471375, 0.05629316292470321, 0.2537621691590175, 0.15008750808192417, 0.15918502147542313, 0.13717675086809322, 0.14906508091371506, 0.1163592710508965, 0.14201993239112198, 0.17967300256714225], [0.01552726564113982, 0.057021087341126986, 0.06011015459080227, 0.01338192543698824, 0.02955634663521778, 0.024872333524399437, 0.05201708983804565, 0.10722525141318329, 0.020848496023972984, 0.020534968316496816, 0.006503378399429494, 0.03553071335772984, 0.02413586884358665, 0.0316937542083906, 0.01025626937916968, 0.053219985056784935, 0.017987487044592854, 0.03783708198170643, 0.03662604169221595, 0.0653127211262472, 0.04592443219735287, 0.026659942777769174, 0.0578840306843631, 0.015076489780767588, 0.024760464038990904, 0.013296135020937072, 0.09701096161734313, 0.007099873100742116, 0.043375911918701604, 0.05100986556499265, 0.012787709129042923, 0.08545480945031159, 0.09914274371112697, 0.020413783022377174, 0.03964904295571614, 0.10704361819080077, 0.03911998443072662, 0.03268643980845809, 0.05298379655869212, 0.022190410345501732, 0.027257579458819237, 0.03305573991383426, 0.06352137701469474, 0.055270505690714344, 0.10799454685184173, 0.04707567022705916, 0.10459401877596974, 0.041421328714932315, 0.043736413863371126, 0.0638289304333739, 0.03576739167328924, 0.02554759328631917, 0.10182594895013608, 0.047723190364195034, 0.06406699656508863, 0.06649118484347127, 0.07790402829414234, 0.07885533545049839, 0.028820759544032626, 0.045624047925230116, 0.06721614437992685, 0.04232332015817519, 0.06215179913851898, 0.02345798373426078, 0.08211869979277253, 0.04145348597376142, 0.0453917111735791, 0.03131984907668084, 0.02954108436824754, 0.02071803388389526, 0.018361514630669262, 0.048085996677400544, 0.018388645694358274, 0.055858008345239796, 0.0790334508928936, 0.05274573042697739, 0.03159673324262258, 0.09044443897437304, 0.021025559472036548, 0.040221917879534885, 0.034590067152748816, 0.02230059886642266, 0.048472043345100246, 0.05021375633077696, 0.009065565791388508, 0.04623362576239742, 0.053488538615056314, 0.05993802085868083, 0.036460212504607625, 0.092140461638337, 0.025514742119412404, 0.009948550832632463, 0.055517878354294226, 0.06322322660707869, 0.06751445806003176, 0.042824125121114776, 0.07894569935160689, 0.052858625931548886, 0.04701711477537174, 0.033758063946152106, 0.010660853040462825, 0.016973342244455125, 0.003759599298973626, 0.05550468296860345, 0.018443119333824143, 0.09458698114030994, 0.044272960658418015, 0.030373380723176524, 0.026780129883263726, 0.03246351348934695, 0.06479437550297007, 0.036100241195526905, 0.03426967086852528, 0.04823242612474132, 0.05432653837488033, 0.04099926562048495, 0.003798610987360007, 0.02513218354579294, 0.036422811972443014, 0.021407609674497508, 0.02002136501687346, 0.03912385473086033, 0.0121582380234031, 0.00012726162822218612, 0.0639600605063606, 0.04650830203900114, 0.044476253460743465, 0.00951250845901086, 0.04956528624461498, 0.03258217919210438, 0.023794321350578684, 0.04977236400009133, 0.03308992694655899, 0.048738337063696235, 0.01319282806434785, 0.033569012957741506, 0.010505485352041433, 0.03005459304404212, 0.02201135052018799, 0.02313059270818485, 0.0151789135816216, 0.004927131876684143, 0.07084243377903476, 0.03193686694430653, 0.05154505794052966, 0.08703185099875554, 0.048507087558391504, 0.05057314134319313, 0.004145586362938047, 0.0814912658825051, 0.036733371089212596, 0.06151072826469317, 0.04322756030887831, 0.015480448182643158, 0.051367269043112174, 0.06829335688962601, 0.0341345740162069, 0.015835431331652217, 0.017882107640616596, 0.008170968922058819, 0.01601178417331539, 0.09117069726926275, 0.05601063101494219, 0.039348899881588295, 0.021871307253604755, 0.035866917387465946, 0.0072953371727635385, 0.029002992050664034, 0.036209455647622235, 0.020671011407102924, 0.020701652829302475, 0.025044296562555246, 0.08294249113532715, 0.04298883366573136, 0.0653261094703339, 0.09096853624214418, 0.03257875418057665, 0.04425255159731023, 0.09753340389579535, 0.01148977447883226, 0.04975891257345211, 0.02321178551937919, 0.012751444082823582, 0.071975225728238, 0.016205095089389943, 0.038955635827733204, 0.07712245031143539, 0.04471931424632203, 0.03543963328411337, 0.06878771629999392, 0.050517799390945584, 0.025051057527889498, 0.019613823897088878, 0.04831980659218971, 0.01730099302221788, 0.06268140685278922, 0.05987398464640137, 0.04141463454288896, 0.05544723702769261, 0.05917633243370801, 0.05258007193333469, 0.07584898427012376, 0.05073824322607834, 0.05758460007200483, 0.052238186763133854, 0.018487867127987556, 0.0021240554087853525, 0.07970522812684067, 0.03161432585329749, 0.027859977017214987, 0.018186629386036657, 0.07771282136673108, 0.05420877809228841, 0.027132547984365374, 0.09270856826333329, 0.022086949393269606, 0.038135373397381045, 0.055485721095465124, 0.03059578753891401, 0.06664628628641367, 0.022321306641970295, 0.055277574647334404, 0.06436798197682947, 0.0259815492972848, 0.09475304410443641, 0.04128451750148088, 0.026732398655440193, 0.039035015943227336, 0.04302248635212891, 0.047453627485083416, 0.10382792199379764, 0.11072657798649743, 0.043182237350265495, 0.02459160688886186, 0.038469651553896256, 0.021196466805122327, 0.0723459581786301, 0.003877400399687758, 0.01517694596259389, 0.03857418676489033, 0.00306822148104402, 0.041584708815207705, 0.06431624686229043, 0.024097650093608536, 0.03030813666555332, 0.017570852760400157, 0.05952059989795089, 0.020895499947073404, 0.016498523582413327, 0.01726716036500875, 0.020279137024772353, 0.058964712734450586, 0.02208322566730203, 0.09989264683099464, 0.016564162833674345, 0.020518577985058073, 0.02812070833897451, 0.05355856024834793, 0.011252757558395388, 0.028747819415002596, 0.03116711879556533, 0.02574150905275019, 0.014324174680950819, 0.01002615257675643, 0.04327876849856693, 0.04495076784223784, 0.04128327811486088, 0.03685429292090703, 0.04866846385993995, 0.05597655901510734, 0.023023860740067903, 0.04051191950566135, 0.03772568561544176, 0.01873134166089585, 0.02277148414577823, 0.042284810115233995, 0.021278205094859004, 0.023870703189459164, 0.008050126871239627, 0.02169082250475185, 0.051699654723051935, 0.02260274388390826, 0.02213132982433308, 0.043946419391431846, 0.04088747220521327, 0.04460011419723742, 0.021554402774199843, 0.006273194803725346, 0.00637071161690983, 0.050482261649449356, 0.07104512915248051, 0.08004058981896378, 0.0466093639988685, 0.04127314408833627, 0.07044349971693009, 0.016297854272124823, 0.028203214751556516, 0.01767465510056354, 0.017672007488727104, 0.014850368515908485, 0.04718035015685018, 0.0238907022139756, 0.05968089637462981, 0.048185652267420664, 0.019421197612246033, 0.0205839500631555, 0.03143460737192072, 0.03062907842831919, 0.04008915137092117, 0.030409619794227183, 0.039957104745553806, 0.03918607268133201, 0.033166041612275876, 0.03799355268711224, 0.040534595827921294, 0.024847128333931323, 0.037468253140104935, 0.028138200759713072, 0.05068027778179385, 0.0554277853370877, 0.04314908561354969, 0.024490899304510094, 0.03728469404450152, 0.0614804894576082, 0.04220119233650621, 0.042979311911039986, 0.08411385992076248, 0.05253794020973146, 0.07013023176114075, 0.023840822468628176, 0.05516271245141979, 0.005561585112445755, 0.029758238633803558, 0.059125703119207174, 0.04419061937369406, 0.055276450293604285, 0.028749658085871488, 0.01593574557773536, 0.020922918592987116, 0.01728211464069318, 0.04875054168223869, 0.037177642952883616, 0.07147736338083632, 0.03190186725987587, 0.06980361256864853, 0.002442895502099418, 0.02164945333788637, 0.02432168406812707, 0.03723879221070092, 0.0853672953962814, 0.009867556545941625, 0.04956006523570977, 0.0867535753059201, 0.10558958019828424, 0.20986800809623674, 0.10916564104263671, 0.27146717067807913, 0.05458935513161123, 0.11521497581270523, 0.1784108320134692, 0.08392640083911829, 0.16826012200908735, 0.19407797022722661, 0.15077767573529854, 0.11103756754891947, 0.16665694944094867, 0.1714089952292852, 0.12882735201856121, 0.10539409107877873, 0.09741208501509391, 0.09026270927279256, 0.13825034169713035, 0.18872065847972408, 0.19327941932715476, 0.20402568799909204, 0.13370617147302255, 0.18763087398838252, 0.14456570672336966, 0.2765842492226511, 0.12173431270639412, 0.10669276045518927, 0.1868385571287945, 0.1664822330349125, 0.16243144258623943, 0.12231423432240263, 0.1000277473940514, 0.1018299936549738, 0.2263299864716828, 0.15688393323216587, 0.09470553181017749, 0.15716091758804396, 0.14939082437194884, 0.15414327092003077, 0.13011965376790613, 0.17722351447446272, 0.12236387658049352, 0.16504647413967177, 0.13476358348270878, 0.24611859727883711, 0.09968661921448074, 0.1482297491747886, 0.10404045082395896, 0.11414042761316523, 0.1012007192184683, 0.1824546611169353, 0.09481277214945294, 0.2632197429193184, 0.2390069523244165, 0.12410154115059413, 0.15612425602739677, 0.21620651328703389, 0.1401254371739924, 0.19389948371099308, 0.113006173633039, 0.19358623801963404, 0.1621940592303872, 0.12158024284872226, 0.14765256608370692, 0.17242373374756426, 0.13164018077077344, 0.130422450019978, 0.11497168496134691, 0.08875879895640537, 0.08939279345213436, 0.09264806096325628, 0.20013802160974592, 0.10696236044168472, 0.23652906966162845, 0.15213662234600633, 0.21409908105852082, 0.1637275144457817, 0.17114487971412018, 0.09562429579091258, 0.1474908966338262, 0.16176557284779847, 0.13421947049209848, 0.1678979687858373, 0.10526535814278759, 0.11534393881447613, 0.1424895931268111, 0.07017240801360458, 0.23755835427436978, 0.13019584264839068, 0.1816775879706256, 0.1356390060391277, 0.18822747166268528, 0.12162430415628478, 0.16610351507551968, 0.2052632934646681, 0.08477291674353182, 0.12162778482888825, 0.19928345340304077, 0.08962845502537675, 0.10283136609359644, 0.12811042251996696, 0.09132073726505041, 0.12192904483526945, 0.13918777811340988, 0.12614010949619114, 0.1732183067360893, 0.11492921927128918, 0.15115303918719292, 0.14649300486780703, 0.1152619018102996, 0.061458210184355266, 0.14575389999663457, 0.2329559254576452, 0.19337294477736577, 0.10212737222900614, 0.1858925266424194, 0.08184735575923696, 0.06002184272801969, 0.11106271151220426, 0.13353391899727285, 0.06108739980845712, 0.08874562583514489, 0.17403049831045792, 0.1096954380045645, 0.2542027673916891, 0.10351597506087273, 0.22930019506020471, 0.17694997368380427, 0.11927693558391184, 0.1308661059010774, 0.09564880892867222, 0.10689478047424927, 0.13305818749358878, 0.12325645016971976, 0.2068742288975045, 0.09570441805408336, 0.13279169710585847, 0.1355151564348489, 0.1544076536083594, 0.0693559342471417, 0.20903423486743122, 0.09605943181668408, 0.09409058082383126, 0.1732890185667202, 0.0786649523070082, 0.16635639447486028, 0.2565870207035914, 0.23056655132677406, 0.14933986851247028, 0.15977755218045786, 0.13993336935527623, 0.062026109008002095, 0.13197674474213272, 0.15028612164314836, 0.12232080232934095, 0.15595970704453066, 0.09247112553566694, 0.1824057535850443, 0.1517228304874152, 0.2074313591583632, 0.08646913236589171, 0.1483756405650638, 0.2015447328449227, 0.12504315585829318, 0.20424610585905612, 0.1431685543502681, 0.11625711442320608, 0.16474536998430267, 0.10168238048208877, 0.11512830780702643, 0.1544312242185697, 0.17217846878338605, 0.17657373449765146, 0.18228224536869675], [0.10363795445300639, 0.05498714999703225, 0.07957037247251719, 0.029367260394792538, 0.06046704227628652, 0.0682182218588423, 0.0593156335526146, 0.030405927609535865, 0.017509560639155097, 0.03718133513757493, 0.059605115675367415, 0.08360798237845302, 0.03584099787985906, 0.03646902921900619, 0.05769532850536052, 0.022996909647190478, 0.021385937106970232, 0.033785089253797196, 0.03585505786759313, 0.04375865973997861, 0.04923052198137157, 0.05563399849052075, 0.06933570330147631, 0.04038632585434243, 0.046659195504616946, 0.027620660366665106, 0.013308578982105246, 0.02836404000845505, 0.014099585951043991, 0.025781614713196177, 0.021251216894597746, 0.007215080395326368, 0.022860966746520717, 0.023116530865081586, 0.06887235082103871, 0.0196588351536775, 0.022360549555742182, 0.004046377916893107, 0.013953613852208946, 0.04056342826515902, 0.053426996018970385, 0.02131467052095104, 0.006073631757317344, 0.0435961479524849, 0.02090316076646559, 0.08927573449909687, 0.026422852570249233, 0.07605768361827359, 0.05021925193432253, 0.0324071325303521, 0.04084391926880926, 0.01990825985558331, 0.021555222847382538, 0.03178025894158054, 0.009436916079721414, 0.02022305106947897, 0.015757717337692156, 0.05234319694864098, 0.08129974725306965, 0.035927012795582414, 0.07724877126747742, 0.017325235276075546, 0.03759301187528763, 0.03320549047202803, 0.018383723399892915, 0.023123345636122394, 0.016051451966632158, 0.012255776637175586, 0.03800555321504362, 0.03206744782801252, 0.02284630376379937, 0.008982965682662325, 0.04454826776054688, 0.015461132861673832, 0.027416825796535704, 0.03914735483704135, 0.014915049468982033, 0.0733563699759543, 0.04543784678389784, 0.02118661293934565, 0.02282899873534916, 0.009560555099596968, 0.06523405347252265, 0.007758682231724379, 0.0306017210095888, 0.021123339283803944, 0.02690589608391747, 0.04406922256748658, 0.06965494554606266, 0.06366867106407881, 0.11695721943397075, 0.022427778858400416, 0.04410768437082879, 0.049962030971073546, 0.07535636890679598, 0.020640169605030678, 0.10077048136736266, 0.09174937949865125, 0.08112525349133648, 0.056624312928761356, 0.08910807591746561, 0.05022800927690696, 0.021953028845018707, 0.009274641779484227, 0.027073955425294116, 0.056293478337465785, 0.05443320354970638, 0.040301984481629916, 0.017603238229639828, 0.0654590355406981, 0.06661513834842481, 0.01576552658661967, 0.07179878753959201, 0.05519314050616231, 0.029564204123744275, 0.04391845897771418, 0.06689525456749834, 0.05216320016188547, 0.06829214718891308, 0.0489385499531636, 0.03822909922746476, 0.04393257091578562, 0.07639047005795874, 0.09990821708925068, 0.02004706930165412, 0.023504776145273354, 0.027826502446259838, 0.029898723478254396, 0.06195598718477413, 0.010769758573587751, 0.02516066717362264, 0.018766523171507288, 0.02573828627646435, 0.014380307948158588, 0.025396625605935697, 0.05517947385669686, 0.0073721568787732394, 0.0372972252080217, 0.03552833848516457, 0.09341543423943222, 0.02328814509382937, 0.05141674802871421, 0.033690643540467136, 0.019491549501253758, 0.009199167216138449, 0.07302428115508519, 0.04541643582342658, 0.08483100464218296, 0.09955433881259523, 0.06547707715071738, 0.011849864531541243, 0.019881421940226573, 0.0130047177481174, 0.0398078922444256, 0.07080744151608087, 0.0774540715792682, 0.03402338916203007, 0.015716680281911977, 0.02583806617622031, 0.06301356988842599, 0.11525433932547458, 0.05304096048348583, 0.04140929479035549, 0.056539596771472134, 0.013930194454587763, 0.05854601527971681, 0.027479646741994657, 0.049838804770843126, 0.0635932911245618, 0.019274209698778577, 0.05409603843872901, 0.005731433493565419, 0.02032614836934954, 0.03349627135321498, 0.04199549868644681, 0.01659282272157725, 0.030701649338880088, 0.06777154543669894, 0.09083123892196454, 0.08849710284266621, 0.017804091221478302, 0.01716967555694282, 0.046135098236845806, 0.053021831627120264, 0.026881954399868846, 0.031184407125692815, 0.040108710672939196, 0.016466501765535213, 0.03723756395629607, 0.05556621072173584, 0.042975293181370944, 0.012028475357510615, 0.02627584424772067, 0.044560405585798435, 0.006687330369459232, 0.07332059845793992, 0.020670896374213044, 0.035696249397005886, 0.06494562519947067, 0.0242384614830371, 0.013476093772624154, 0.008358870509255212, 0.06564622002770193, 0.03300620897789486, 0.029965967623866163, 0.073519946745364, 0.010005134954553796, 0.02666100590431597, 0.04567907817545347, 0.042705808227765374, 0.03771535863052122, 0.033542674136697315, 0.028679317329078913, 0.05159474101674277, 0.0351082012639381, 0.05888208201213274, 0.04254406085237861, 0.00779222498749732, 0.022625253222940955, 0.032870047143660486, 0.01629501555726165, 0.018174736469518393, 0.04936839817673899, 0.03092057362664491, 0.05526480970729608, 0.019632937910500914, 0.05243209139734972, 0.039733818484819494, 0.07056346046738327, 0.0424588103487622, 0.016354825238522608, 0.04093331466719974, 0.017292411939706653, 0.027815468565677293, 0.04172649983956944, 0.04488730679440778, 0.02714087488129735, 0.018353037448832765, 0.04622355481842533, 0.051621057573356666, 0.04439991986146197, 0.01691048419161234, 0.07905742968432605, 0.042109930436708964, 0.058591679626260884, 0.02938563411589712, 0.03375874672201462, 0.006738244019288686, 0.07179782274761237, 0.023991109228518326, 0.020381353024276905, 0.04175639354798477, 0.03368613870406989, 0.06276183339650743, 0.07136692438507453, 0.01387073543810402, 0.04673073111916892, 0.007407014163618442, 0.06438601616537198, 0.05789288450614549, 0.1419026285293512, 0.028713610117847566, 0.01531599196823663, 0.03551659770892002, 0.02973578495584661, 0.046639112988486886, 0.010552807470958214, 0.06519388101878576, 0.07900959826656617, 0.03715015009220224, 0.04080074853845872, 0.04051654308568686, 0.041493855096632615, 0.11602611353737302, 0.014716992518515326, 0.02815154457493918, 0.03594536610762589, 0.02141004391887691, 0.04321863227232825, 0.058916261623380706, 0.042230644467053935, 0.02501597991795279, 0.03441753266088199, 0.041139620589092374, 0.009899355718516745, 0.0640831828059163, 0.02206266075518215, 0.00088074317545761, 0.0322299447725527, 0.0066740347938321065, 0.04207625177514274, 0.039918498223414645, 0.03202860010787845, 0.008086993057077052, 0.0654936047794763, 0.02800907263008412, 0.02024436184001388, 0.016132418422785122, 0.043195711041335016, 0.036106334227952175, 0.032908353095990606, 0.0351454273913987, 0.01039325035890215, 0.07269795882166363, 0.05621577918645926, 0.009553228246659273, 0.030612515547545627, 0.058375295338919386, 0.05782550491858274, 0.017716796101012733, 0.010134382755495608, 0.09940987976733595, 0.06547420503920875, 0.07377233632723801, 0.07287645275937393, 0.0616000902664382, 0.0338859879411757, 0.03547346408595331, 0.004883347946815775, 0.006629899271501927, 0.07000738405622542, 0.009015930954774376, 0.04186728525382932, 0.03743497152754571, 0.05875552727957256, 0.018208559849881567, 0.033989736475632526, 0.01402148696797667, 0.07985398420714773, 0.013541962161980337, 0.09607651605620049, 0.028492427845776547, 0.022112421756901313, 0.013759559860773152, 0.032088009029394016, 0.01955367097252747, 0.016403068548243027, 0.06821390998084098, 0.07265181950060651, 0.04008122894447297, 0.0038485684262923314, 0.03162215551128611, 0.056943900272017345, 0.02085737211018568, 0.005597200315605733, 0.018938577122753486, 0.024751847704465035, 0.03886474500177428, 0.057465348072582856, 0.014759448931727093, 0.09800564730539918, 0.027072300435975194, 0.22875505790580064, 0.17004504654323682, 0.23633253411389887, 0.11248170529142953, 0.10263372474582866, 0.09010940382722765, 0.18252808920806274, 0.13477725384291261, 0.17091150395572186, 0.09765032184077427, 0.15364552731625736, 0.1843940414255485, 0.07776954371365719, 0.20872922701528296, 0.24459701642626897, 0.09509783107205294, 0.15399706782773137, 0.11689676408423111, 0.10593780330964364, 0.17553092795424163, 0.10849828700884245, 0.08227831349358894, 0.20026117359520867, 0.10923716923571192, 0.08702192848431878, 0.1343894816818647, 0.24850571528077126, 0.1407037631724961, 0.10740860641817562, 0.20304459845647216, 0.08432750197243877, 0.07464006281225011, 0.08494015230098739, 0.15311906259739771, 0.25253430067095906, 0.11483984242659062, 0.1464417521492578, 0.07217869293526746, 0.06613266072236001, 0.20640805625589564, 0.13533365679904819, 0.13469915022142231, 0.13871746428776532, 0.12248841638211161, 0.10655892896465957, 0.21880000771488994, 0.10581158625427634, 0.12938611500430852, 0.1885425578802824, 0.07528587229899131, 0.08625759059214033, 0.2091598804690875, 0.12642368412343785, 0.11223040666664019, 0.11760089153540321, 0.13190117926569656, 0.08792527805780992, 0.12495507777202874, 0.1606929616536945, 0.10784150857944041, 0.20894652785500512, 0.11381328891729936, 0.17882937361719087, 0.10259211994707584, 0.15008459886303172, 0.1700790220638737, 0.12182453559944406, 0.16955390805378556, 0.10493918423890136, 0.11608740751398727, 0.07447787385899574, 0.09878894707071595, 0.1921768402098678, 0.08439969809842296, 0.1546608001808636, 0.12310523758060299, 0.12544320314191282, 0.19815285078948364, 0.1780567830428481, 0.12521251395810395, 0.14486550469882786, 0.07143783659557812, 0.12540400290163234, 0.17365765816066414, 0.2637057605898008, 0.12265551093150862, 0.08275362197309732, 0.12509863881859928, 0.10213081579422578, 0.144406991021242, 0.18143995228456333, 0.10989406640874222, 0.198689557146281, 0.1539062734809704, 0.13775538856862113, 0.21956048643914983, 0.2123534309794195, 0.2257213363191113, 0.12959587562363595, 0.0938794546527788, 0.19888135779183358, 0.13054631446721032, 0.13383070385316387, 0.08644398840260692, 0.18024626711849123, 0.09377366150147282, 0.19690766057465225, 0.0978213497728575, 0.09017918055178598, 0.1443659799406305, 0.13354902912396938, 0.1453473514993675, 0.17757250199792907, 0.09641748838475905, 0.1531080639688298, 0.11813415432698093, 0.10904725364525802, 0.17045627057086676, 0.1370707870228216, 0.1223038145690225, 0.1415276955231093, 0.15748327685287222, 0.1243405275454279, 0.2226183278253302, 0.20445785543415695, 0.10620070170261897, 0.12470837304135785, 0.13663683843333274, 0.2309547390905209, 0.09700040085590445, 0.09455978884943761, 0.11621323123108596, 0.12228939463966526, 0.1354334905045107, 0.16715583595214412, 0.25705448468215764, 0.1306801979080774, 0.11130264043458737, 0.15320282138418406, 0.15213487087748945, 0.09587624008418061, 0.11598413024330512, 0.09113798339967616, 0.12373698336887173, 0.15054817398777232, 0.14962132059736177, 0.11274127144133672, 0.15162488183705136, 0.33808003063313663, 0.19596342608565465, 0.12857846537372097, 0.16407448332756758, 0.15976843860698864, 0.09287980399676599, 0.18231871450552717, 0.09137346685747616, 0.10167735614231788, 0.08544533222448081, 0.08066052803769708, 0.10560812646872364, 0.23883293353719637, 0.12010980339255184, 0.1398700344725512, 0.14066178729990497, 0.13138473354047164, 0.18155672180000693, 0.23976511554792523, 0.07839810568839312, 0.11459886707598343, 0.10657499646185897, 0.11990384999080561, 0.10859477362828329, 0.10424185486044735, 0.1746579841710627, 0.1413162873359397, 0.17363986145937815], [0.011192912625119789, 0.04070360511832405, 0.015969364867487457, 0.06867268341011368, 0.06831343940575607, 0.025213445005647372, 0.026740981593320612, 0.0539915774425026, 0.07276244403328747, 0.014906790293025551, 0.038071211019996554, 0.04230643629853148, 0.06516778710647486, 0.04415253977640532, 0.03559332835720852, 0.057483363707433455, 0.07878140269895084, 0.0330857412336627, 0.032499470544280484, 0.010230984407826327, 0.08983969994005747, 0.01534601833554916, 0.011151515627716435, 0.04153307017986663, 0.014533906542055774, 0.05623281518637668, 0.07045266524073668, 0.029791709494020324, 0.021591473050648347, 0.03216486584278755, 0.035438056220300496, 0.02915062192187179, 0.020560717130138073, 0.025035021571966354, 0.07457166648237035, 0.02886400634452002, 0.07547514222096652, 0.03817446231551003, 0.05610135856841225, 0.07024464866844937, 0.01414175849276944, 0.02517326513043372, 0.026027924250229262, 0.02792252151266439, 0.09174058504868299, 0.02104203143971972, 0.008310321063618176, 0.05054656132415403, 0.058362738200230524, 0.1125498344481457, 0.06194060988491401, 0.023285430688702036, 0.025119060519500636, 0.04653220661566593, 0.01660965648625279, 0.012801439788745483, 0.021125324528838973, 0.04881549073616043, 0.06828393903560936, 0.026296264441043604, 0.06528313911985606, 0.018122364963346627, 0.009160402059933404, 0.06663726177066565, 0.0738806305162143, 0.02333710086531937, 0.060252312978263944, 0.05507093846972566, 0.03842363097646739, 0.03149324817059096, 0.06670275630312972, 0.00961398787694634, 0.010313133661838947, 0.03344453994941432, 0.04332602475187741, 0.0041061472438741475, 0.028422972100088373, 0.06901688408106565, 0.024430479206785094, 0.11557039033505134, 0.0356691127672093, 0.052470389928203076, 0.0555646262364462, 0.09617124378564768, 0.03063735151954461, 0.024105611482809763, 0.054014840061427094, 0.005227620977166225, 0.06524352327687666, 0.025826483106357045, 0.06162084071547724, 0.04507575293246191, 0.12302775736316107, 0.03594860558223445, 0.0748510702396743, 0.00933882827666821, 0.03719007392646745, 0.021288751013344154, 0.05565658946579788, 0.02567616666055983, 0.05469783485750668, 0.04175882408162579, 0.039832787588238716, 0.051561199652496725, 0.020848178755841218, 0.09011303292936645, 0.0218396045602276, 0.014397230770555325, 0.04828124830964953, 0.030033527182240505, 0.03960885194828734, 0.07355445661232807, 0.049213994352612644, 0.11275828888756223, 0.03734194331627805, 0.00806982810900081, 0.027072298580606002, 0.007433402615788509, 0.026116724075109232, 0.03825004263489973, 0.07537475190474652, 0.09556968856486492, 0.04066576300829183, 0.03500352133414708, 0.01564495913044084, 0.05249615729553625, 0.05367233890865464, 0.07145262017729692, 0.06038389947207179, 0.033743580934242345, 0.008096094570646528, 0.008208363888115855, 0.015174738073255867, 0.09859182522632182, 0.07008150234469213, 0.014335419145936612, 0.007106063540049945, 0.06820429174695164, 0.03395547151740175, 0.01700181845080806, 0.017531318553665187, 0.04222603572998196, 0.013303243867994752, 0.02207722354796715, 0.06475550922914408, 0.02298435621924, 0.059138705546502024, 0.0376555860566441, 0.028186047020426486, 0.01074249670637073, 0.030474928789772093, 0.02349928796320455, 0.014084726299188333, 0.0350970467843581, 0.09061352990102023, 0.013863001331628766, 0.04812066239537671, 0.01955908865056699, 0.03834150491456967, 0.01315004696152755, 0.021199071743467357, 0.006300765126070473, 0.07495069614378735, 0.02263539281557314, 0.01659964120335644, 0.038614199656876735, 0.03735663412953727, 0.03057935453398386, 0.06446293977205642, 0.05971063052129466, 0.07303632621187717, 0.006953772981432849, 0.03795884615101386, 0.053164580021984875, 0.0366099853272317, 0.03897279057127889, 0.06327469454845414, 0.021444147459988017, 0.05197829406824894, 0.04885647584160324, 0.03222728417313192, 0.09079593495698646, 0.008979177018773044, 0.05324253150320146, 0.04139176897297148, 0.016733372503949795, 0.024338647708646022, 0.02001833334361436, 0.0664654397405684, 0.012313976785662817, 0.030208725984266493, 0.05126678224769421, 0.06430446897866204, 0.04413934067997616, 0.01964708138984861, 0.039827830041758716, 0.027922560475417413, 0.012282515290280571, 0.07436685598804615, 0.051583256281446666, 0.015594012547808234, 0.03142258457955904, 0.07605166480061598, 0.05434822021925356, 0.06851468759123236, 0.05783702676126268, 0.04407960150274448, 0.02349090726056602, 0.019335600154590793, 0.038321934480336495, 0.03624860393756535, 0.04298326755815651, 0.09822590189287439, 0.05359397553547751, 0.05120029323734343, 0.03675576539535541, 0.0708921576733701, 0.0010138651032320922, 0.02164726214687107, 0.020875588124908973, 0.024314795082318597, 0.04829803197935689, 0.02036063226114493, 0.025631257449276745, 0.03757127436983865, 0.038865012174937874, 0.05761820822954178, 0.03005935392138781, 0.07113528525223956, 0.024087929814413656, 0.1783231843728572, 0.06295910367043689, 0.09610623164917342, 0.04072871939570177, 0.08878468506736681, 0.01061805338395061, 0.027532697313290555, 0.0752897017810028, 0.01468520818889374, 0.034173874446423724, 0.027826687983179, 0.018241730140289292, 0.018806469270202797, 0.026592479698592797, 0.0304096383479191, 0.0339168390200939, 0.009837093239184469, 0.03566804407455493, 0.005501345449374639, 0.07209326431620866, 0.02501053997548297, 0.02698043368582148, 0.011372259104973637, 0.02937475794169586, 0.014085539878578857, 0.07057661132421345, 0.01656912409089273, 0.05382145493058488, 0.08850714410073124, 0.07593605303554796, 0.06128807282948401, 0.01153549448645208, 0.004923409078401164, 0.03653182604466565, 0.0322114207665436, 0.024404810174019076, 0.05498152080690488, 0.03611067950259894, 0.07085272736730985, 0.028237605874892324, 0.021969003573758528, 0.016509724446223117, 0.03983610498835333, 0.02720935099205235, 0.04968767752870917, 0.036510852951323614, 0.039072891449905, 0.052351824415382, 0.04728316729597282, 0.0028131130875408417, 0.05796909565106034, 0.10763801168650389, 0.013254962523205904, 0.06048494287824724, 0.010818054761330131, 0.04161603486863896, 0.037722728156950325, 0.03352787571202498, 0.013103984638291877, 0.05170153235667385, 0.02220899928943254, 0.03595386369852349, 0.019935747150157113, 0.030405007346416824, 0.044913055608049035, 0.06089326510846149, 0.01852954057540046, 0.06741465404047631, 0.06353477278025821, 0.03223401916329749, 0.02191717012465233, 0.03300138872873504, 0.040267533986479975, 0.02271384153573308, 0.02384881354373647, 0.024398999157710932, 0.03441916538577061, 0.0064542723430349724, 0.043275328644085675, 0.05725104550947435, 0.04668514840886928, 0.015968941843311768, 0.04553503844363149, 0.018629524565767497, 0.018677009029488545, 0.05535371528821997, 0.016885644508874975, 0.03797143668634817, 0.09717552544316277, 0.012636241426662309, 0.024878723415895365, 0.034117608520318754, 0.044545785276568495, 0.09010299909277819, 0.0422970258659916, 0.013631303754664259, 0.012610500962182414, 0.016456729536002968, 0.06422830236260779, 0.09094930719584227, 0.07202887558378279, 0.03518640878610313, 0.020809260531677864, 0.06319927008007653, 0.02555361952545354, 0.028545020140882116, 0.02284491780301323, 0.013528244489862118, 0.043968212557956576, 0.014386425100383349, 0.015924722829367965, 0.024903761623136234, 0.02743671906500822, 0.008257678673544433, 0.02466311096213758, 0.0202792149502784, 0.0763162478688173, 0.006756028660674929, 0.07527039109845646, 0.06055901663785335, 0.03211518647731282, 0.0646864523878321, 0.20212153001921251, 0.09768900999915786, 0.1303483688388951, 0.1772840737248771, 0.19163728400599211, 0.19886507507180795, 0.09136237174971029, 0.1879512146115303, 0.1115272736933548, 0.13843043125234544, 0.11026149630197324, 0.08675601697177626, 0.21207482874160632, 0.13997602800372988, 0.19794576190179214, 0.13971868087537587, 0.19753149506868795, 0.10200784934568219, 0.1338279282208532, 0.15966654173098505, 0.16217406577197835, 0.09164773495285772, 0.10666503381798975, 0.15389503736514598, 0.17686582898022607, 0.10532234024140052, 0.39315617526881397, 0.22152741526952013, 0.1036860010935925, 0.12451899179723114, 0.17912379844347015, 0.11121055475086905, 0.09822420979617164, 0.12920914246933535, 0.21834216197021306, 0.13711120438529179, 0.25367705966345966, 0.10358262734371237, 0.116681622894248, 0.13046093779848889, 0.16992530843708664, 0.10531690772040747, 0.10985053944750689, 0.12836460809921846, 0.175948207906913, 0.1556673157028854, 0.1564069846062921, 0.12177202122984454, 0.1802141618099995, 0.22207464528037235, 0.2053741703275591, 0.07038375682896003, 0.0973317252646666, 0.10430274065583944, 0.18127816409105435, 0.15532686287770048, 0.12222427118103951, 0.11213429112103768, 0.20233590679708868, 0.11102924807346426, 0.19762487208936363, 0.1309031984419562, 0.1105418945371639, 0.19083610590314493, 0.1787957691703923, 0.1847764107515104, 0.13452471583150327, 0.09867266737273894, 0.1237467055034358, 0.1324110644054599, 0.083018702280242, 0.15867090609390289, 0.10224046069197357, 0.1198608944832813, 0.2069339866284281, 0.08686279717949219, 0.14944788068532944, 0.11744924850063398, 0.1263748062774539, 0.19754374050535262, 0.13574862125096843, 0.21028945891885087, 0.17925121035659686, 0.32908828812651336, 0.13485820731148124, 0.09485077753197402, 0.11330145935062319, 0.08968954120064154, 0.23316482518566772, 0.09356444264994934, 0.14812939596595243, 0.19443884695647284, 0.21923447580775246, 0.12260158648132347, 0.15096695307875052, 0.11423337418818846, 0.12795313174137846, 0.15043245832202956, 0.12944300804520026, 0.11974131964961998, 0.11144424221129157, 0.15967638260917738, 0.12521246942924336, 0.12225985716213472, 0.13435537257464603, 0.17884942644741386, 0.13066585961496457, 0.1459000734030269, 0.12485864310292527, 0.05973045699647628, 0.11335612594848499, 0.19769862672546878, 0.12619575572898611, 0.1660778367659077, 0.11867875713505782, 0.08200454263715073, 0.09229831644915976, 0.07086814919603057, 0.15489036130020395, 0.11096701156930067, 0.12411408344632946, 0.18910057871835306, 0.17014164448482916, 0.1070040617196355, 0.08710798792890273, 0.12079361826181412, 0.2202504314482212, 0.1362095691729337, 0.14411989861400798, 0.1294621851411648, 0.0995780726952944, 0.14639944973168895, 0.14890856196871027, 0.1861576663213782, 0.12865336291724816, 0.0850739169982262, 0.12795902439393103, 0.1043426978867501, 0.0700909795705229, 0.14733813295606524, 0.059105531545355916, 0.12784838501829654, 0.1754266265197657, 0.1214201541733928, 0.1278953332803212, 0.15917424549115822, 0.13011766481213272, 0.09665052275522612, 0.10759647368104197, 0.05394606894697063, 0.10564901138423011, 0.08205504578654654, 0.19186862627975643, 0.16244579572230577, 0.17407728329999372, 0.0860581903543789, 0.08757550385780632, 0.21274945582263172, 0.11806765047367662, 0.11564280910533853, 0.0884951584157534, 0.10071640106616542, 0.12784117134287953, 0.10616803236189298, 0.17077668540878221, 0.15667449915781617, 0.16590303130215034, 0.09875388801447116, 0.22279721510130912, 0.1527710843947716, 0.169993749295827, 0.04483660697587766, 0.2027356720645912, 0.17009324161335826, 0.19382912811124697, 0.14972660166677088], [0.009150187324848957, 0.021281661647662986, 0.04100688376638573, 0.033529890642967075, 0.013004437587369466, 0.03560045668564271, 0.0022678133564113523, 0.021288571042532567, 0.010862909239222063, 0.06045552043360658, 0.07857024684199132, 0.01875703666883055, 0.018087675125570968, 0.048313917650375515, 0.095570512348786, 0.0431542843580246, 0.06956109355087392, 0.036314079916337505, 0.06513344793347642, 0.040256012143800035, 0.07067877537338063, 0.07819084610673599, 0.021113518814672716, 0.059149333101231605, 0.06349139424855821, 0.033457731624366716, 0.010836224391823635, 0.035398499749135226, 0.012503455436672084, 0.06283273818553425, 0.016827758845465723, 0.0014813487950959825, 0.04049139541166369, 0.027991661845589988, 0.03018915740540251, 0.024993216393340845, 0.0919867109041661, 0.035284257246530615, 0.01749252092849929, 0.033390266689821146, 0.015273097687895643, 0.06801030918722972, 0.026339635551266838, 0.1015526604896877, 0.03791056944464799, 0.0003948967497535705, 0.02113875740178628, 0.03520502184983343, 0.019352667695784476, 0.023147676947701257, 0.04382277387776412, 0.06252696592127904, 0.02058497422694927, 0.024073021922959015, 0.02513863095373381, 0.023617940678377636, 0.11463608578196727, 0.00956327228777809, 0.02446427104587201, 0.06716618299833499, 0.046049532320466824, 0.03492685376841109, 0.0368992930452805, 0.026303010563424323, 0.024288821769005153, 0.015674685855628923, 0.006946858020455693, 0.026904803271463607, 0.019156664639012888, 0.008953466240200214, 0.04305292553908657, 0.0526547208573902, 0.031626040654373355, 0.046826282632537186, 0.018859506853914354, 0.023401825419568922, 0.06912731565535069, 0.022988632845226675, 0.04929966416966636, 0.05261122358206194, 0.008940951775002759, 0.030679845040140208, 0.014516444734908873, 0.03693412203574553, 0.04740676457004156, 0.00950677629589336, 0.12269952771021053, 0.05407635668234434, 0.03331019266624935, 0.0013147685308467771, 0.03556530115019996, 0.03381200323929079, 0.06245805008802563, 0.07842326449463144, 0.046800403943052515, 0.020540588229778223, 0.03337192079925444, 0.053246012175804935, 0.040752612840151414, 0.016361153902835213, 0.018606510566314682, 0.04056688667333219, 0.028133970517956186, 0.023514245949627366, 0.039082732328097336, 0.03209795380826108, 0.0679518205288332, 0.03550472334609367, 0.028665609861491248, 0.03961265174439177, 0.0491231962951133, 0.024740242370171472, 0.022409727971535176, 0.030091500048001762, 0.09031179492012598, 0.03845545055810362, 0.07739551612758078, 0.04001118133601267, 0.08829394733766094, 0.04006006660347339, 0.02809861645800993, 0.03570805325580295, 0.012612170794454869, 0.02145462844055146, 0.03554807961336337, 0.0799441996787209, 0.05408850935054943, 0.07144698727643117, 0.03743758759810589, 0.05074929380498361, 0.031711339397588745, 0.05066203579190187, 0.01803315510187531, 0.00934712548769312, 0.041663706724648364, 0.04473245397093706, 0.02956343043479137, 0.022802162675361615, 0.06527078978251666, 0.017450539489800576, 0.010064235884783557, 0.03300141470390372, 0.04086304812517483, 0.04750994165078737, 0.03604208650358487, 0.012356518545857398, 0.03679285793623421, 0.0386259367223829, 0.07246627515996806, 0.08031381148612127, 0.05389671241573524, 0.041082426978391595, 0.09412479383172467, 0.018026182624453213, 0.01349348136500339, 0.012978228642168688, 0.055608973270864226, 0.06591627272428013, 0.02719512031035265, 0.020657574823417235, 0.018437933576933574, 0.023928418158902787, 0.05143182846950367, 0.0651405354437884, 0.039646972363698296, 0.0555423618061468, 0.020691292447736487, 0.0338270280190045, 0.0046140002905303845, 0.06676954959402792, 0.01694583083008183, 0.024679213711351622, 0.006899385152792092, 0.04492039173783269, 0.03681367888930254, 0.0425968683703104, 0.06027427312801592, 0.044699146383209154, 0.03698519663885236, 0.018277286435477436, 0.019418216033955105, 0.01789304875273956, 0.049399249255657196, 0.027424753789091483, 0.01651712922466686, 0.1004457323870156, 0.027647568786051124, 0.06321678476524539, 0.020478728365560528, 0.06188793224282563, 0.039875980583019555, 0.013349194869078929, 0.041508167414576747, 0.016681270026310813, 0.026707785327744205, 0.02512940605811309, 0.03915934794349596, 0.033177437289850786, 0.03164797482895665, 0.027342134198988788, 0.03256277574109845, 0.05845006300660316, 0.008750865490583237, 0.05687846882210579, 0.06882823756313883, 0.034527259194874205, 0.03540579135005828, 0.0006913129959684738, 0.06080783648940269, 0.019225675096095074, 0.02549004158936441, 0.022319824201986194, 0.033329191646771505, 0.03092827526415931, 0.025160980731016025, 0.04150371823925525, 0.03790294016653206, 0.032483670220244676, 0.03739037216291763, 0.05832976457895711, 0.025930315132427495, 0.04935404132993426, 0.04211695115373004, 0.04815371394215617, 0.07813724820152856, 0.03008896004757844, 0.03964050083595794, 0.04443898651516065, 0.038921370869502425, 0.04908021481242031, 0.03724203539604787, 0.016916367567318957, 0.028668259328696877, 0.05384730393416248, 0.024930985455284826, 0.02297063205332961, 0.021399306897365022, 0.028396789130056277, 0.03279669697803911, 0.04094876618182752, 0.06797934678616002, 0.026683903015509713, 0.046177682670531794, 0.05493272088642698, 0.057093164723482914, 0.04596542472427245, 0.029631568868353497, 0.03577847935957834, 0.07299954537302256, 0.06147707928903401, 0.005971790078547201, 0.010559253951214487, 0.065830918319989, 0.028113541047787294, 0.02210364957136335, 0.03011419677932281, 0.03883829114784021, 0.06187394646985922, 0.02215436237747781, 0.07359387949691154, 0.02576662889623549, 0.01582885961397551, 0.10980307910358533, 0.0230571924475953, 0.0677518562588375, 0.045117060872144066, 0.012974493783985963, 0.01588902552612126, 0.004727094319605385, 0.006107138333391049, 0.05692113489203621, 0.08252402374637313, 0.04662953186198138, 0.07764906345983036, 0.047856676756055094, 0.06414121875423007, 0.04525502983597107, 0.02910804676503176, 0.02237031436379766, 0.05897397844819352, 0.05631960193568375, 0.015876386751187965, 0.0159529337179265, 0.012245206598890945, 0.07492869146517478, 0.0762034636863973, 0.05749825118982699, 0.04430598251929041, 0.05044375531724654, 0.03098613495239988, 0.06853995771962218, 0.04297404637327418, 0.07837675409973599, 0.026260081031068694, 0.054137572733452544, 0.01939475303515792, 0.008000197030924028, 0.08222647447837517, 0.017093403184844647, 0.036226762531441636, 0.06707135878968984, 0.03481662257399876, 0.043616501352516934, 0.06107071261794772, 0.043003825048799627, 0.06596538063604385, 0.05829377412737813, 0.022587292369280476, 0.01077866898413049, 0.03868119703838602, 0.04984684594091959, 0.05334706300345715, 0.014154566106299171, 0.006415969637600938, 0.06400835205568, 0.04478783674130682, 0.01750928975525312, 0.05460528533149045, 0.025721821730257943, 0.10377309212344699, 0.05100906033476349, 0.06311492499662563, 0.03308586368802935, 0.01097321093766368, 0.04643101849069353, 0.03442130648181774, 0.06508865189971402, 0.0212802422902314, 0.015972498586052097, 0.03840754863631446, 0.03621968244260643, 0.0594854072551243, 0.02129591830453137, 0.015488531098526437, 0.078909467702033, 0.07318536430830136, 0.0061518077382061165, 0.028018291959597263, 0.03516035569191445, 0.05465009620820638, 0.023388427798636258, 0.0315170302928891, 0.036332199451862834, 0.01958376135007711, 0.004657361660065362, 0.08513151507941075, 0.04450890053703915, 0.03161487133183982, 0.020179895182081964, 0.02885893190978095, 0.025424589730391745, 0.019546024996088818, 0.1667424596962519, 0.0946110267250333, 0.09140347930951975, 0.07995609630597755, 0.08989423295133747, 0.15507977223023772, 0.13028550893068314, 0.20445901318453252, 0.08486801554681733, 0.14596311142668128, 0.18079250265145674, 0.16222370060859248, 0.12624589522602037, 0.16029659542255104, 0.18235824129078537, 0.07171160003053956, 0.12277771296794526, 0.08990973641630262, 0.14621581271057948, 0.13805515685817227, 0.17210023157531396, 0.1838872881489806, 0.08864069357514381, 0.09988105448428541, 0.09899130105623044, 0.10765001963591203, 0.09481573331868276, 0.11579005120438524, 0.10889799290453084, 0.14206720719812438, 0.10937245533568785, 0.16236616327660158, 0.175247160368599, 0.10667618087609299, 0.09410345708602108, 0.11482040557893924, 0.1540985342580825, 0.15277147031156346, 0.09508281742455438, 0.1447129636653699, 0.20280920405639336, 0.12424620799720287, 0.09956765294191428, 0.22764658613596112, 0.19463704491499811, 0.18921464681625366, 0.13417120120720938, 0.10243056181934662, 0.15475108986720443, 0.20087859593331814, 0.15874724340392277, 0.1716001279419288, 0.1879363865009509, 0.08297736465465277, 0.2680027956375852, 0.18336587003432214, 0.22164688620250672, 0.09709279824164696, 0.09906081802910194, 0.14623077440774068, 0.15673583024181426, 0.09003791274153627, 0.18506626394810155, 0.1411178964190185, 0.09663520482718013, 0.07989282079506665, 0.1002074361895211, 0.21032089629443362, 0.1025839414796792, 0.14259824354667217, 0.10302553419023752, 0.14026680146344006, 0.21952867798972875, 0.13448244309984148, 0.14926816220395267, 0.1330275071086362, 0.19777809589868411, 0.1087643024220597, 0.15543281188001856, 0.17375162889948115, 0.12404110806528479, 0.1514193366165273, 0.08387472509639338, 0.20857149094808847, 0.10717936442233622, 0.09580970654496923, 0.18481175182387233, 0.10322338333935477, 0.13788527925498784, 0.15232923935400322, 0.21061000734334812, 0.17360015655867755, 0.1476701401406899, 0.1569337016553618, 0.1266203384147957, 0.14669141062768176, 0.21504150470718741, 0.16689106734702364, 0.09286076048738323, 0.08202475131838582, 0.15037075616419315, 0.16774695657659322, 0.14116091129835695, 0.1459892201819457, 0.0911811318655964, 0.0892821021261625, 0.27335216640494764, 0.16379025561036542, 0.09064981350093149, 0.17766342993127182, 0.1424094263347797, 0.08893499965779483, 0.1669077211408876, 0.10557288929703645, 0.19254947255831212, 0.11730061858543195, 0.22309854190098122, 0.18827149586286396, 0.15640042402083054, 0.11734876912669279, 0.1160690096730832, 0.13928704778663814, 0.09000407080748118, 0.11666003381833434, 0.08429055043961853, 0.2082036083447747, 0.11688484519254416, 0.18564196274382994, 0.17858744831755757, 0.1301678636809811, 0.19557893421733752, 0.09364267243654467, 0.11621340934652835, 0.10688660200685263, 0.13555953686591238, 0.12504205747973174, 0.07578241362352856, 0.08525569122866727, 0.12219318261486478, 0.10384349225205369, 0.17509999248431996, 0.08739819735637866, 0.09230130730429664, 0.14096363360295072, 0.20031352469231933, 0.12911833327962086, 0.09997910703532398, 0.11714101230609231, 0.17759641399607062, 0.11857527948450297, 0.18805515981512144, 0.12191930043627508, 0.2069268620107323, 0.11079534539021552, 0.08090557035757229, 0.09162232381640933, 0.11785548529587686, 0.26543912070337683, 0.22166781476698816, 0.18797882250510156, 0.07461698944098316, 0.126745761372149, 0.14162628242047504, 0.13450349040795118, 0.13563343993155286, 0.11111313302535564, 0.10327347830752842, 0.07750796634354629, 0.14949898497434333, 0.13168194884201512, 0.14466044929577038, 0.10357363993534818, 0.0897941023868043, 0.1335398858645931, 0.17023353721015155, 0.12081244654837064], [0.016823194637254346, 0.023822163020668086, 0.028068084502592683, 0.028544285414682236, 0.021317661376087926, 0.02955992935312679, 0.04481030897295568, 0.032131261395988986, 0.018551174180174712, 0.06486946600489318, 0.0433629651524825, 0.052755010983673856, 0.024597043120593298, 0.03615626963437535, 0.026224975590594113, 0.012191713522042846, 0.07458184874849394, 0.044483162855613045, 0.056229995025205426, 0.05648311933327932, 0.03439305663050618, 0.039362555398838595, 0.04740934353321791, 0.021956515083729755, 0.07824985426850617, 0.07222793443361297, 0.06414711140678264, 0.005307283572619781, 0.019828061522275675, 0.03507482317218091, 0.06247707875445485, 0.055819576227804646, 0.04334863799158484, 0.028055968941771425, 0.016718145488994196, 0.06946068097022362, 0.02520272468245821, 0.012117026562918909, 0.03075598939176416, 0.02962691374705173, 0.02737675909884274, 0.029161373786337208, 0.017157780785055365, 0.01906093686557142, 0.008132610091706738, 0.05432178120827302, 0.0194447756439331, 0.042235256914864294, 0.013096285783831263, 0.03439989923208486, 0.02165588961361209, 0.023431826739397366, 0.023796148889232427, 0.07130514801247045, 0.015460003869520733, 0.012098973820684478, 0.02357041168579599, 0.11052594578359276, 0.12059119006153196, 0.0820341394864954, 0.03735733174835332, 0.024134976411005482, 0.0678547921415884, 0.07252744297147729, 0.10861231057788245, 0.03344132644997444, 0.01653336741583189, 0.0281963795714546, 0.04976706506568007, 0.06982656719628721, 0.015046487533254549, 0.035591921987361275, 0.028606416162801906, 0.040297910090885125, 0.08759256583289243, 0.0593960823607631, 0.024479663188685663, 0.02562219768151408, 0.07577661745017394, 0.04676149685110431, 0.027244181837886572, 0.05244162428425625, 0.03363380616065115, 0.020722650042444002, 0.008544480715499958, 0.08164382918039337, 0.02475660301570315, 0.01377031636366155, 0.0573745759902522, 0.07578976088552736, 0.04249649660778232, 0.011223225646972423, 0.014051373254915234, 0.020914296692353673, 0.020301685326558072, 0.02392966311163036, 0.008110004273476079, 0.036121700395597145, 0.037529558248934336, 0.04220794959110208, 0.04583914087561425, 0.020686101124738343, 0.09026293191709556, 0.037140702552278526, 0.009830836006585741, 0.0028231262831468484, 0.015956579518388025, 0.06016866922436748, 0.07705601325142197, 0.05195644524064846, 0.009683234893600456, 0.013503593127097702, 0.03419991640839726, 0.024594408496341202, 0.06536190325277857, 0.011136630000692094, 0.027342345711076632, 0.04212161555187777, 0.027009837576770224, 0.060511778938234784, 0.02908006965299137, 0.046490891254507005, 0.05747534851252567, 0.11306818007142283, 0.012411360476107802, 0.008178690040949732, 0.05241782731900457, 0.022953310326556675, 0.04255075131368358, 0.06183035271533299, 0.08908345145755447, 0.03863438978441991, 0.02564707447163528, 0.058482201711740345, 0.04236683598719537, 0.05402210939791985, 0.03451691365626175, 0.08673666176036932, 0.046993874420877546, 0.019135743496008217, 0.02370384056121111, 0.026960674003930762, 0.02505738248146372, 0.008339005071320571, 0.023973427560122218, 0.03421654793783091, 0.024682278781256173, 0.03841924488369841, 0.02680454283108702, 0.04369979629700538, 0.03172191500198096, 0.09794090234208852, 0.01719758587569231, 0.08209846142563038, 0.07944578072056174, 0.04806662291230168, 0.035404292211751454, 0.030350693268701434, 0.03792999516008422, 0.014715491524839308, 0.03311698936158791, 0.03798736688622739, 0.046208979038055986, 0.0026169469902015408, 0.035169947950635105, 0.013492319903889438, 0.03175822086632252, 0.09333719703136012, 0.008209905699914088, 0.025284757975896355, 0.010589425965008559, 0.048577754860161804, 0.03925808698113542, 0.03137930252705701, 0.0712313488475047, 0.021489960236067418, 0.03715846956765745, 0.022354632783390116, 0.027869179648405407, 0.056618642920511775, 0.07373337357421406, 0.01671924015681725, 0.026760320106404833, 0.036167832295177504, 0.04060546722030267, 0.07243525338708423, 0.04274305661965627, 0.06431911897379905, 0.08736699746805243, 0.022368961799656972, 0.04875680911936797, 0.0498594810051145, 0.0029371906703090644, 0.03119663400866557, 0.07468416122719646, 0.0442419574392261, 0.06914647048688494, 0.0060563248734979425, 0.015187796161626466, 0.07174846992711537, 0.03284913342213258, 0.0970355341269169, 0.10769909786176868, 0.027734938121284358, 0.0939083613047842, 0.03149788659357, 0.028240452011232264, 0.04856960607867222, 0.03958850968047045, 0.035261042867205106, 0.028000736456306186, 0.03768766538996715, 0.0164734760983265, 0.027165345345565584, 0.015913208408164792, 0.038834361475892365, 0.01740921856253408, 0.04365863307612017, 0.060443653492257, 0.07204380759503692, 0.03497422505461145, 0.05289402266498655, 0.06136741954833269, 0.03916928901162464, 0.019649673340609297, 0.02702844507439295, 0.042014853897853754, 0.02549538876337465, 0.03559660122846253, 0.05751532058638986, 0.04513790780038107, 0.06229019854799844, 0.025493698522041086, 0.10375873156590387, 0.04062828826135956, 0.07098765723640099, 0.038933753603487276, 0.029435367287078407, 0.04175101297732908, 0.03483145068457816, 0.04415147108375095, 0.06645842644502409, 0.0402051824494265, 0.057090515256277286, 0.0326006104296539, 0.045816416313755326, 0.0313397980062291, 0.03499047066725325, 0.09839100006502122, 0.050355740313534625, 0.07470643307897262, 0.036238603497622535, 0.047118143338593654, 0.06477498318417929, 0.09731297119287774, 0.004378665262265713, 0.038015668687876314, 0.024155244464054704, 0.018483714811736718, 0.07855699950596318, 0.02852432164218044, 0.07226359462947585, 0.04200979987217579, 0.054284440047922544, 0.021066789486212656, 0.014542544213327346, 0.056797055221977644, 0.0080407711720909, 0.030870361770212185, 0.003419536565161252, 0.020441225788090378, 0.03672818718769122, 0.04397062453790568, 0.015645183630113024, 0.019328039525134955, 0.02513544342946261, 0.04371305105451029, 0.04740178475913126, 0.04870079552347306, 0.07763581612380221, 0.0294493122419226, 0.012872782444901532, 0.01055144748534076, 0.06341902000713162, 0.051545499518397264, 0.03168362389260437, 0.06266339492867701, 0.017708033192320727, 0.027619140819297172, 0.010325503408239456, 0.046405581379076466, 0.051306438908795826, 0.03303097444586456, 0.05747417591919657, 0.008401377945119748, 0.06022942143317778, 0.014709143379150191, 0.021155336980882566, 0.034707808881648816, 0.14799319702433422, 0.03685197370941751, 0.042792108870344236, 0.05278085998725146, 0.020813320079469122, 0.0071533768459630664, 0.05237484583631158, 0.05180162210308481, 0.08283236384158954, 0.032279720617225394, 0.05558279030083213, 0.02030436633503996, 0.025908282623277046, 0.02098810327879619, 0.007721637002759962, 0.04029502313642297, 0.08717184973647818, 0.030221164379327092, 0.03836476011201739, 0.058221600265824236, 0.03409811601159163, 0.006395366690412629, 0.0433784129563719, 0.035640027999761514, 0.05663689233188052, 0.07483938883524388, 0.050578325244714506, 0.02935417818662245, 0.03036148595128907, 0.08659902305225842, 0.01152680115410476, 0.051253579440526664, 0.07180631291703321, 0.031770681525813416, 0.03555578310624696, 0.03397209933609702, 0.013208921536715934, 0.04181894917564932, 0.024361361138289794, 0.05818319783429615, 0.020296814982430078, 0.026104539865627885, 0.012927029729326023, 0.011900263780262321, 0.026258223806507885, 0.011225854705116944, 0.013781980142084649, 0.02330503637494985, 0.0069893677755317185, 0.04562581794743892, 0.013209301887400215, 0.01908352041937178, 0.045190047385403886, 0.08326482071424834, 0.13991545391036198, 0.10365460082539357, 0.10502918448764831, 0.14395799167687073, 0.08636863814899698, 0.15627981018042192, 0.16068038967205212, 0.09535802062600851, 0.18952020385768265, 0.11278844234766439, 0.14314026368083432, 0.14041526068467647, 0.18035059823887423, 0.08159994598827325, 0.24367710953811184, 0.1802613475592807, 0.09484677735599689, 0.1820192430750467, 0.11956514121266082, 0.10151657726964913, 0.2170760728768073, 0.10668208095012233, 0.15839592553675175, 0.24545479071093723, 0.15206015144940466, 0.15635690448107198, 0.21901539381360635, 0.18398363376036286, 0.12823160039260983, 0.1264169008936733, 0.09307679225457832, 0.1272358460118994, 0.10305939838872291, 0.11486199553473853, 0.2413795390748419, 0.0698545684281271, 0.060384400421753526, 0.048111485739354976, 0.20317670074291527, 0.08589782708440907, 0.19453078421065584, 0.1314099962473847, 0.15055602591019124, 0.1681513083167374, 0.1338555954862386, 0.14007854828378186, 0.09048005464137532, 0.08861474809236825, 0.19076077791396528, 0.10297897184500471, 0.061262628296390176, 0.15679552860092372, 0.15818485873751342, 0.16798542346805334, 0.11998001660685986, 0.17475542816100642, 0.1704174414044246, 0.2325009147170931, 0.2286347557674162, 0.1275574928149581, 0.14596931578125805, 0.19366544001968578, 0.10712614501244389, 0.250719808973372, 0.12858973117545247, 0.12086347662261687, 0.08416192140430212, 0.15547468385193497, 0.1377549284370616, 0.10243906683172099, 0.1437680167146027, 0.14957088424125686, 0.1336022262694314, 0.2010539357434027, 0.1404096352052875, 0.11601606485783122, 0.1683583526755683, 0.30934695212636143, 0.12931356264743954, 0.17327102890703827, 0.12826600635889918, 0.19759972812607884, 0.16675964783644304, 0.14124149369308725, 0.17175027925986797, 0.11759170374716632, 0.12087782975868322, 0.1269774598767981, 0.14383715519215912, 0.09679236201918684, 0.19870114949299023, 0.07880465418566018, 0.1727135869441554, 0.07054113666526973, 0.10254705674014986, 0.13714357686694711, 0.1302892345120199, 0.10993221279932186, 0.1471449073869735, 0.1476924045709893, 0.14987982547609136, 0.1393947482574731, 0.19932388560846448, 0.08502975178998895, 0.1485696528106928, 0.0996980705531314, 0.1734645216492936, 0.15513999009272084, 0.13595079712104052, 0.1148208805534523, 0.09375219859066419, 0.12863258278230205, 0.10795226669870317, 0.1528290461283177, 0.1513146937941201, 0.12752647104207426, 0.1261458537192084, 0.13355745992157608, 0.139016802131664, 0.13314920448465273, 0.11022801059880294, 0.16400452848756686, 0.22636796958977357, 0.1397746684961021, 0.12532388063846156, 0.09678848800831474, 0.08321048808284104, 0.10322464499040507, 0.15701122640166432, 0.1309131135349162, 0.21093248535180464, 0.1213580289913807, 0.10966420100885443, 0.11548352194949985, 0.2628142631147057, 0.1338893038337119, 0.1518196807592176, 0.21762953692814335, 0.1314674087916501, 0.14799491880694404, 0.15180267073446885, 0.1302029672660865, 0.16127378126839176, 0.06999596240348183, 0.12207261330331676, 0.101760899706278, 0.19663621264044195, 0.16282215365208685, 0.14940735942218453, 0.10455960538820364, 0.20936820132192224, 0.16485407977597788, 0.12618946231668815, 0.15820740518392995, 0.12313682338572107, 0.1077873763279058, 0.14911878271959722, 0.11181066278368235, 0.09080964984605089, 0.10818062553880736, 0.2152935677440837, 0.1188281069335062, 0.09231573465513065, 0.0950288558669854, 0.09252641553757712, 0.1589460053946823, 0.20578484516590834, 0.08503120639943518, 0.11955434296396561, 0.08766618688241579, 0.1522740680957213, 0.085576002165908, 0.09220809355610982, 0.10083549350383691, 0.1780687167774886], [0.0319962313369615, 0.038232045553741045, 0.049529555544722825, 0.01618418507860042, 0.008001737915037666, 0.02283030677062925, 0.01776612665707944, 0.021065540822746698, 0.028328539374342654, 0.039641038893023506, 0.01977018513571238, 0.024932694250310306, 0.0371081074263202, 0.05773584605776705, 0.08466043684165925, 0.02017001163039822, 0.08609652970335446, 0.033857110975077376, 0.017216705455211923, 0.06856311272713356, 0.053997054492356256, 0.05618567767669447, 0.015305162178265164, 0.024352848704438657, 0.032696659181965515, 0.044723830214934424, 0.036020964980707504, 0.057064176435233094, 0.12414004377205856, 0.04037522703583818, 0.022092055369284935, 0.04256211730535142, 0.01881051397504052, 0.02456134210660821, 0.07897342598880641, 0.04839582477870863, 0.06328024581307545, 0.05127812226419337, 0.021016631435486488, 0.05407935495895799, 0.028778709456673823, 0.013884409509046236, 0.04280075489077717, 0.01726198759570252, 0.03879953619616572, 0.03475219302345067, 0.032667040068190545, 0.058000967183033936, 0.02775765155092813, 0.05788324029708747, 0.08715591582586057, 0.033785571649787016, 0.01951746344275307, 0.045398858055705205, 0.022984432289376855, 0.03564317099517211, 0.06460569929913618, 0.05173355602892116, 0.01562073543027509, 0.009516246100247372, 0.04074462362041231, 0.02998059535457287, 0.02419507367449114, 0.03512573450279888, 0.04876456085185055, 0.014853647880954668, 0.026402632756798994, 0.04506183024204802, 0.0543965043470962, 0.036082062288187444, 0.001860462759850634, 0.11281633967882954, 0.04316998449212406, 0.06700910002109595, 0.05894720547075849, 0.045668628736166283, 0.06352592637995258, 0.03854297574434895, 0.03686456424475182, 0.022625514829996973, 0.0253608819184592, 0.08652615157188848, 0.006759395228073117, 0.07469934556866065, 0.09507305076112971, 0.04318181432608981, 0.06081935833208263, 0.10656552665750496, 0.03395560881472193, 0.025651382638898212, 0.04907744289084803, 0.027411907212808728, 0.020087505217816215, 0.015916817101242486, 0.04590602322423365, 0.016285070778394584, 0.03792664807406254, 0.01539446295282687, 0.029117520280124154, 0.05238106503384188, 0.03527377812133636, 0.016753273193899076, 0.024510649709554855, 0.01025856447085971, 0.043468316725920886, 0.0572888801980298, 0.01567685292684473, 0.0884166095056571, 0.09275103395339102, 0.05293396876368206, 0.01481283161410829, 0.057174678513547406, 0.05462856650410686, 0.05236283417616505, 0.04537513530522119, 0.02814705643686466, 0.04101688049559016, 0.010853484891413245, 0.039202733896672726, 0.029293411134858616, 0.014516994851874188, 0.07950224331580102, 0.024318407486134674, 0.008403243518841919, 0.0171397354642977, 0.016960996617854107, 0.016418970917584375, 0.028267063571547624, 0.047377987793879583, 0.05358436843380332, 0.056538049393566325, 0.053760034788865596, 0.171091623196844, 0.039442588604288176, 0.085653638234362, 0.06680270133074373, 0.04328334012825508, 0.0302168914640788, 0.02784105781756807, 0.05350763407477643, 0.07207082919194363, 0.013366970233619213, 0.05375853565055877, 0.08264330914244056, 0.008773135486990213, 0.08564826508518308, 0.04564264614600688, 0.009336768816865515, 0.12030569327180274, 0.021219495647528674, 0.013567772202804917, 0.02997833365952829, 0.0472447722859215, 0.02636700781295076, 0.011530210394994356, 0.02504305160982767, 0.04187924867437687, 0.054590327345067635, 0.03397361702809576, 0.008128135868901154, 0.05904826000914909, 0.012579230569826905, 0.06266966607654467, 0.03419163775106426, 0.05740877786593046, 0.04975066731276456, 0.021902768748987, 0.03888227081915829, 0.0450730552256573, 0.01800236710550962, 0.03748369723325595, 0.03939431560866069, 0.0469801187136909, 0.022069161968829576, 0.050510055079939775, 0.07677523652091622, 0.02053529486147454, 0.014516914143314352, 0.044845486772828735, 0.01639551905100234, 0.01326515963228303, 0.028162658236396965, 0.008996521937660873, 0.07690248516155407, 0.030420826224144548, 0.06502599979285151, 0.026135389089176897, 0.02420607972453581, 0.06331646261969581, 0.019119241842417978, 0.05199196071771439, 0.05490319454111159, 0.015070044228195911, 0.014357498039316852, 0.009645904865465127, 0.06878408719785511, 0.09608639404177666, 0.02623745665914612, 0.008080977022473235, 0.05569154462136794, 0.07119035260984674, 0.02597226317448076, 0.015601311570208054, 0.06323832931229845, 0.04941583996696863, 0.04757316150062252, 0.013684239293070277, 0.014619694175053155, 0.020238263241481036, 0.061388492831611075, 0.03578395269869361, 0.04144554870435968, 0.01983194666536292, 0.029884626383136492, 0.07303226666408591, 0.029314350831555203, 0.020493066658673342, 0.031110914096643683, 0.04132203306653537, 0.02106086158164544, 0.06280544199398719, 0.02114614733727649, 0.014335048999782884, 0.07814431344741024, 0.05330436353688128, 0.06501842246507294, 0.07654028740944341, 0.07653040200239047, 0.05115265477797948, 0.07438226297381334, 0.05126492316776421, 0.07913152570836246, 0.03888654930051416, 0.07458770429366268, 0.06180128279083874, 0.03980726141890045, 0.02134265876520658, 0.026990797778125852, 0.03270241453719791, 0.046920257082092576, 0.06107561450335197, 0.0486001306126127, 0.021649167611030862, 0.029488256441254634, 0.0480335973406909, 0.0928904241300188, 0.03271740963100456, 0.023903099790913984, 0.055587213500984944, 0.024642896714794915, 0.029154033945815172, 0.06879268126795068, 0.04964296684192959, 0.01309060278799734, 0.00877048694746918, 0.030786512070335448, 0.04868577445449773, 0.024207738424593117, 0.041094256812357344, 0.033548217979841866, 0.05594796035438776, 0.035280045558465645, 0.027434613220975734, 0.03987727191997692, 0.019668650056701154, 0.08637100560008548, 0.0343948006775463, 0.01704415240965318, 0.06885401977342553, 0.03241665799578186, 0.012750630503433058, 0.04959763646184001, 0.01364853085760842, 0.03324808603792917, 0.044264114258112386, 0.02135129921953194, 0.018755457749648485, 0.05427841380878817, 0.010875692732952302, 0.08767575316596776, 0.06793196065700613, 0.041758300867513753, 0.02099020541209029, 0.028049543798260856, 0.06312631696346216, 0.042371808376628906, 0.031500599143328145, 0.04054859273310285, 0.02194558324845275, 0.0262167897017207, 0.08298590677441098, 0.03937537971069105, 0.03906553305569105, 0.06423233964596875, 0.004783000304087182, 0.025153844981105067, 0.05865542269020807, 0.035036324261454865, 0.03843088175926823, 0.016533588204765692, 0.0029559419590441394, 0.027252736945229117, 0.06378382269758731, 0.010531964253459591, 0.02273695386975305, 0.034207775752292946, 0.0286733448956511, 0.05408634227933362, 0.050078303247573785, 0.0193176717220922, 0.01524772829725407, 0.016274081426672637, 0.054815138719277456, 0.04748408893647138, 0.049930552777368575, 0.04116138778044842, 0.08109059519483708, 0.03790239468798973, 0.05291846529871691, 0.012953496570844436, 0.04472459833777975, 0.01923627296491759, 0.05137940686836373, 0.053072498049004935, 0.03941500297514722, 0.03632386513345409, 0.008045776958169881, 0.05771809388534166, 0.019215327702113427, 0.02600732223072555, 0.041014271846506745, 0.03788383357459679, 0.013653354817506624, 0.09777083178050816, 0.05929795188421849, 0.03683657785586547, 0.012676392543653492, 0.022310586318781134, 0.05837870921823196, 0.006356843196044792, 0.051016225770581514, 0.05017970659537241, 0.02284718691953458, 0.017851523734861985, 0.05620250216452405, 0.006072198020774522, 0.02466479934810195, 0.05109724974317942, 0.0342819719662657, 0.007613960651724483, 0.06166038605442736, 0.08867399374139495, 0.11707877580192871, 0.15575561643345281, 0.0829056063957978, 0.14265246485592797, 0.07170168493757956, 0.05306979663146194, 0.11919570752070285, 0.11753700004192069, 0.16274678113404661, 0.19251712976256385, 0.07713854749454185, 0.11417745336075313, 0.13816929917084053, 0.13771154248388484, 0.1341489961487241, 0.1538260918459855, 0.19276738195912912, 0.1495310160680674, 0.0913833300000988, 0.2752861735643819, 0.18348557845456526, 0.09268004752811976, 0.11977043410297483, 0.17689757805783302, 0.2012099203420803, 0.0558449057280086, 0.07967559417011216, 0.17583025095518678, 0.1816196262370795, 0.12129300943342969, 0.08392494622967206, 0.10211670756689273, 0.0823105449671857, 0.1237131975358352, 0.14598154637496918, 0.14550933265127242, 0.1352765114279464, 0.09194664235110395, 0.1296393951633945, 0.1999205574975349, 0.10003985182265751, 0.19371581700397655, 0.19946709042415023, 0.14608261204557493, 0.19325892120832577, 0.16993237368296832, 0.10319112217985094, 0.14762906968826428, 0.15144357515964657, 0.11790814809501171, 0.16935471561737359, 0.08826521137962118, 0.1831980556016788, 0.20433229889022186, 0.10792345652589574, 0.14712648728163913, 0.10580385307548568, 0.1819836051436141, 0.2974111691582948, 0.10012574057327583, 0.16618169291177765, 0.16469656635308638, 0.17119507858296856, 0.16628364915959537, 0.1621277557569556, 0.09144351075519808, 0.06497090274933726, 0.17373599926941097, 0.12985964975086972, 0.12226008722791448, 0.10375909521826543, 0.12818437011446804, 0.12274493972654454, 0.180386102583725, 0.09439412664505653, 0.15645819279598072, 0.11751171507057734, 0.08949628594564274, 0.22970417572651058, 0.1275350057403557, 0.10959517385344952, 0.21873582678381354, 0.16863144817762077, 0.2563036390347406, 0.2650380047271028, 0.09298762321122922, 0.12689337454503402, 0.159078597498592, 0.21093739836942405, 0.13893501745769754, 0.0794087401300203, 0.09595312658348121, 0.1631212094798684, 0.10082306253025308, 0.14821371878497303, 0.07642653843504377, 0.11373708519386128, 0.186490178166423, 0.11140135349705815, 0.1267218790599145, 0.17356451862724498, 0.16698864492354915, 0.1327797188423574, 0.18714752804953605, 0.14890108112012967, 0.16844027093611658, 0.11258939834078774, 0.1678980578435585, 0.13182969560148194, 0.16636720014503226, 0.16464169195387512, 0.16755285527324304, 0.13124571443768218, 0.08542283030692488, 0.16094851278467104, 0.18292939814273268, 0.0928878562990576, 0.08989352791104466, 0.07792360614985228, 0.13738661538809538, 0.09538608865113929, 0.13489972305251285, 0.11391030246159062, 0.13755753199802712, 0.14166383509291336, 0.12621471018064767, 0.08672305819345638, 0.12423606283846311, 0.14333961938973516, 0.13619615114293993, 0.16463186591863632, 0.1217537050251849, 0.20726629067212343, 0.13123958429787308, 0.1306992711033672, 0.11053948997869156, 0.14523040386848152, 0.1336621175869368, 0.10503757817787118, 0.13937389390775934, 0.2693698910297826, 0.09945573707227595, 0.1543180615408346, 0.16143890912644565, 0.1531069359043613, 0.16539949894649908, 0.10386163034127094, 0.10900234628934413, 0.32409238745458424, 0.10631076962454244, 0.09578892641002312, 0.10624150498188101, 0.08075120364082977, 0.1462013556738384, 0.09249215057934634, 0.15934231225401163, 0.07645097735803574, 0.12454930110834539, 0.18990347860381007, 0.19444655044935644, 0.08590420213295147, 0.11062361241783947, 0.16084358794614673, 0.06242475734325126, 0.1804954357794486, 0.11777911829994991, 0.08165084247593768, 0.16243181366007775, 0.19769288250245154, 0.09801398162380792, 0.17119864089181647, 0.12116170866647735, 0.17853765020845458, 0.08779278243309818, 0.23929536575451493, 0.16918572859140113], [0.04956597273121588, 0.014529916570609203, 0.024389867030549794, 0.006664420734523446, 0.044666900066658854, 0.041302314202766865, 0.02924100437667221, 0.05873930764209945, 0.010180324479733827, 0.012165853386250092, 0.031211866589728743, 0.11345979655743577, 0.02980880301038269, 0.028702362869807985, 0.016197137410927098, 0.03160707878123503, 0.08829986967612058, 0.0534116780909244, 0.03575128335796762, 0.0063868013785395306, 0.07643601566087455, 0.030390012252610177, 0.03799348960455973, 0.03250388632295653, 0.007756580098430277, 0.059995715419063345, 0.055253477112273686, 0.01933943149197148, 0.0531686024623923, 0.08220653297030367, 0.02056845958577469, 0.009146658412646502, 0.05362679701647721, 0.027779940101027023, 0.03157996070513036, 0.036302843800513074, 0.030478958651656285, 0.03456097867456265, 0.12015416898066178, 0.036957893025828525, 0.042166827188339084, 0.03806272827205248, 0.010759066080936464, 0.03843684862658847, 0.05299028292938601, 0.03997677908046171, 0.029525000172725413, 0.07110847145668231, 0.07953965498018079, 0.027724329120246693, 0.035870783976861276, 0.027845983822771814, 0.012239441966812592, 0.0013824684015162347, 0.038769375314586796, 0.03821299833361991, 0.08547945617465302, 0.04032375538372435, 0.04829548270208761, 0.03358771136845462, 0.03469021256023552, 0.056316247428185306, 0.02087708911858499, 0.03809438829193823, 0.03603914017730858, 0.03732613557076547, 0.010189358272327809, 0.012682568140007788, 0.04997154901502654, 0.01466879280997091, 0.01464532424506615, 0.02988792894029757, 0.005106218604851165, 0.04148251508013345, 0.041361355761182494, 0.043040865639341064, 0.05293439549859613, 0.04157454510277603, 0.053091571244294755, 0.059891046621487476, 0.025299001645180397, 0.03394763443793636, 0.019782686613325495, 0.038261423469521105, 0.023269901248568203, 0.04674865027482156, 0.05305128375766799, 0.013645255203300621, 0.03600680851377547, 0.0258837045475957, 0.08490374995744787, 0.06194389017764479, 0.06679039652226493, 0.02882925527956104, 0.028834073673351668, 0.07060343996272422, 0.026520057217567228, 0.017549438089190517, 0.0411163097305689, 0.04916088255413342, 0.03673038765555248, 0.02525902586057782, 0.024167766350728925, 0.021317798673408106, 0.00949562831010553, 0.007303774000320118, 0.009216512135026278, 0.027745517436414957, 0.03821749574854039, 0.03913748798368033, 0.003565312690625433, 0.07115535292541608, 0.043677954890881665, 0.06658551923464984, 0.0454430343961576, 0.0071495376232633134, 0.05476985657878686, 0.023436266637872905, 0.05351098116079811, 0.027536803245311603, 0.035748555965255946, 0.034334731244598515, 0.047065769977052696, 0.031109917763387784, 0.022641879186267033, 0.028467020420066547, 0.03765493667742703, 0.04806274147995282, 0.022827894790680148, 0.04598136976710521, 0.04922906737192534, 0.03327495178382378, 0.021931348856014665, 0.02949909550807206, 0.03728501316800248, 0.018588314960652497, 0.04391181675600819, 0.10217188624665141, 0.028660604075412266, 0.07960422182804905, 0.016149636248883326, 0.04877326253335923, 0.03751977303181775, 0.014716226251039188, 0.02845497350790538, 0.039126110859797336, 0.08181217053788714, 0.014234676309570204, 0.05742408837249968, 0.026267680623277556, 0.030575536184187513, 0.04961906968674157, 0.03117026179097593, 0.009694270629552193, 0.040351467177970335, 0.06627356488024816, 0.041644462835392915, 0.035061304952250794, 0.06578212211024947, 0.03697848762385547, 0.06462878009187989, 0.03083494277234422, 0.01920609167427756, 0.03285257327661384, 0.016444035099993926, 0.051355658142711036, 0.08552431158022955, 0.010733397048170445, 0.11107601079856977, 0.06338977196719497, 0.02456705849908758, 0.024590187531430274, 0.00956284740823321, 0.04415246185089927, 0.04783962220244575, 0.04958083794917911, 0.048680315958335996, 0.048131338189705275, 0.042887678937404417, 0.06846353877335787, 0.027532741842151154, 0.01382786806061631, 0.022972288898017723, 0.023344770961557515, 0.04179709292657208, 0.02904718137870077, 0.022993364036665298, 0.06352200041874312, 0.006328518202280975, 0.02345939752558479, 0.07569699242594652, 0.03816588308836799, 0.030901533828000538, 0.07778346640407108, 0.028261336046853103, 0.03137071216769982, 0.11726325887138955, 0.023097077319107484, 0.04098469355085399, 0.054068111421656795, 0.038980022800387815, 0.03736515027412679, 0.02939929148851661, 0.027990290727757383, 0.038652561270282604, 0.05265958192467224, 0.02239432098576799, 0.047589659443474375, 0.0749438015918713, 0.02762065480055753, 0.035357232627575286, 0.03345639575854875, 0.015912251037661918, 0.03419626875256654, 0.03743204004422296, 0.07534760414273478, 0.009088179031095933, 0.009110860919463448, 0.03483188113023061, 0.05040517105953768, 0.04717699936009012, 0.05321958800777793, 0.08563524039345793, 0.06856688283733092, 0.044963031832594424, 0.02618474005430471, 0.01699324664514279, 0.024615030924906023, 0.09168152493657544, 0.026634114183252677, 0.023987116474017967, 0.0449428528372664, 0.06344381516100839, 0.04706779232947156, 0.01719625186524354, 0.09223223562003113, 0.04742126984638162, 0.040485688296030276, 0.02723497549595777, 0.031325422605732456, 0.016387691248382907, 0.12251000545802526, 0.021955023366899695, 0.004812142587979906, 0.02151432679966092, 0.06034376783645712, 0.09898410964524373, 0.045170944504207, 0.011035152438125806, 0.018507079475966748, 0.06727647356456146, 0.11294980751699768, 0.0434980582940625, 0.06345023473841138, 0.07747882220428437, 0.07161777772125788, 0.05244545005552936, 0.02362530092796078, 0.03253475595556665, 0.04522977826127317, 0.08671576288179494, 0.05495100740517955, 0.04128595355723519, 0.017884816479636356, 0.0053652870519727, 0.009508512921456713, 0.07297319170902483, 0.03384781186468899, 0.047690565552329645, 0.052271709573687986, 0.027935574034927413, 0.08155165443895385, 0.028498862266133074, 0.0045618384410772705, 0.008242135318141663, 0.07202106819022447, 0.04019618390884716, 0.03088232519075973, 0.009212660388584482, 0.01004131094305194, 0.06480895128333941, 0.03875341542880051, 0.05181394917599391, 0.03166932270687539, 0.07346562895691022, 0.01643108276766725, 0.023021300330583472, 0.08268691773992032, 0.027696216566255316, 0.03466883128567133, 0.038118470984045416, 0.004630806224668049, 0.03054600427276455, 0.03154546197038144, 0.05427348594821524, 0.03282585596025456, 0.03406933552469127, 0.030181670990714338, 0.028814994911954273, 0.027564954762056004, 0.022323649973259307, 0.03540835918101948, 0.034113489600713365, 0.033083195667131804, 0.0365428803343093, 0.015041482674860163, 0.03349696897203103, 0.05387158700614236, 0.026179693450103514, 0.07664142729481682, 0.07601748147862963, 0.061818901376682334, 0.024763150613580365, 0.06785037636291236, 0.02742581877100747, 0.024739383334235754, 0.057019398955162615, 0.02391901329247048, 0.02065709984890418, 0.035443080560071394, 0.07477087376173586, 0.015099131778697483, 0.050396343212923966, 0.11242152453633025, 0.09111204533837736, 0.04393974748381879, 0.013850335653842194, 0.010135225093108602, 0.016570266998314764, 0.05510602721187752, 0.0743043003603816, 0.03287165760411881, 0.013894523126509739, 0.04823976967600174, 0.03634266373410355, 0.04387574837892316, 0.04741250508232042, 0.06389907823177055, 0.09049988482729532, 0.05968020617729053, 0.034371486108284444, 0.037459796367329545, 0.013438736841635546, 0.028172083511890378, 0.06705309453536756, 0.03248500237532426, 0.05907835038669873, 0.05404528295912314, 0.013742976570938481, 0.011890998066519387, 0.049011102310032584, 0.04224764335958753, 0.24645934696309268, 0.13711559789953753, 0.21687174477847293, 0.07689683741773479, 0.12727452674880624, 0.16446246328996494, 0.09345170299638994, 0.19780913251452148, 0.14382171852048486, 0.1529973652213812, 0.07602158555528149, 0.21181604184675962, 0.11467664415249601, 0.1508186719729565, 0.1594950759317726, 0.12045182957081124, 0.15153558662859723, 0.19712908775545657, 0.11206422495888546, 0.12896202213596553, 0.1877046434674412, 0.22199899074621499, 0.12340632689301856, 0.12538602808490396, 0.12007481855107471, 0.1811237380024977, 0.1965734121040441, 0.12022494018310681, 0.09547989611746743, 0.14743814477697015, 0.10837397727300413, 0.1332099418505095, 0.13612868991913274, 0.10219897463684902, 0.15853730466915295, 0.14943581336410716, 0.15165412245551124, 0.11428223719121888, 0.12609179568244144, 0.1315577726927586, 0.11228191913687624, 0.19692234025569633, 0.13178669556509703, 0.0904917879961431, 0.11496109451400116, 0.1248987190774642, 0.20540348516078666, 0.17829867865657434, 0.1578114100266248, 0.0868328069918789, 0.12866866600234061, 0.12201947552966885, 0.2198400831548497, 0.07397534340270795, 0.23173314810264856, 0.15408210310852155, 0.11746084826881997, 0.06621573673328385, 0.13463459821650758, 0.18107607727870345, 0.1604359262273647, 0.12241561911650933, 0.1643828011583537, 0.14331582613522187, 0.08302177477162331, 0.14625590352807194, 0.07194513163994998, 0.0690436756121926, 0.07412128674332052, 0.1404918057960458, 0.13153666601283476, 0.10330242206691764, 0.10742109676357359, 0.14035994099685922, 0.08107535148155876, 0.21593518409645185, 0.12167185355792753, 0.10615677398163825, 0.173933187907096, 0.0980570558749605, 0.10434466457809322, 0.08382773972698487, 0.11713946121744812, 0.1543766912072897, 0.17389575397828594, 0.1631589699536562, 0.17115099501097575, 0.09102329931920394, 0.10849689177121036, 0.13078000192763284, 0.14560547046130523, 0.14075443701585755, 0.12272464198758826, 0.12409963383106515, 0.16852420783834532, 0.17530627985252067, 0.1582305453484878, 0.11471847901702859, 0.1999255595728755, 0.12309437253861688, 0.09857428085524589, 0.14287999249063432, 0.14299371920060366, 0.08200619020499289, 0.14663557143649086, 0.13063816266367212, 0.15515450650127605, 0.13689814863028005, 0.24802459578495473, 0.1525719216442667, 0.14721306622959673, 0.19717851479072124, 0.14579955692170188, 0.16914513311348855, 0.09137162633123808, 0.088768662099028, 0.10657772756530903, 0.10507878963835537, 0.09667749982327223, 0.13977636059280485, 0.12655290687689558, 0.11660610936814919, 0.12615612504305318, 0.12300023110583425, 0.13041011552559212, 0.1965065297554247, 0.08597624240792356, 0.08228378312196583, 0.15962714853230864, 0.12883308139862493, 0.22804939420893788, 0.18248682579724118, 0.16300331189995632, 0.14660474262200296, 0.14291744126239792, 0.15261745982570574, 0.12597927125170827, 0.18362551782047376, 0.11860624188557267, 0.21976809483021498, 0.11661261800327338, 0.1641879280214198, 0.1442655673599802, 0.1689130932209082, 0.2521731419255957, 0.12239600415341556, 0.17924941435921937, 0.16064313385868445, 0.31691955984570086, 0.11761354515329003, 0.17123996367445216, 0.07481077162083238, 0.08624174573924392, 0.12036582949804142, 0.14306921046227217, 0.10408654561615549, 0.09803840570384637, 0.08989372086944059, 0.15848582930630073, 0.10490214364835992, 0.21039166749687865, 0.1289741339860484, 0.1452385526499711, 0.07768559196847491, 0.09925117890816182, 0.10168868873734027, 0.19497831410262734, 0.16219230776187032, 0.2935869712382555, 0.11139782087411731, 0.11154613908729516, 0.17129868239862844, 0.1094918891612906, 0.17082364851376042, 0.09959050366887823, 0.13210629404056817], [0.04608525188814383, 0.008555616641388042, 0.02204473603342194, 0.003623153129410639, 0.09484570866334252, 0.007645181412954116, 0.04483453638385981, 0.07980823822435923, 0.06047466413292568, 0.0375582051492529, 0.005228748113950132, 0.00493228933919454, 0.04667970475566108, 0.030494282145809848, 0.011822509895864641, 0.032077863870654255, 0.11889017274370417, 0.026604033082548995, 0.0692915974650532, 0.053452896972885355, 0.046127016248647124, 0.0180077272671042, 0.11497949235490523, 0.011419789952924475, 0.031050213838170748, 0.03526536216668319, 0.08498258830513805, 0.04258333159668837, 0.06147402906208299, 0.02708209678530693, 0.025356416044814978, 0.06343895409372635, 0.042684694126364775, 0.06416580610675737, 0.04146052524447441, 0.03412325997487642, 0.026945767967845313, 0.02818986165948445, 0.027548568141355645, 0.10868594647035934, 0.0435086376091931, 0.024413977553194854, 0.04692155584052671, 0.04348203903646208, 0.058270544905099086, 0.04355626864708029, 0.05898608658753801, 0.027578302288020495, 0.07016292336629704, 0.04093808667676058, 0.021174007561057806, 0.007443102022079984, 0.036259628541301936, 0.027096392404928338, 0.018826087944034953, 0.003615959399212443, 0.00644166650090483, 0.036005888250656426, 0.024340983618458267, 0.007148809854697902, 0.00837201301692403, 0.05661419374519028, 0.05551101719902363, 0.013088342948321952, 0.00466887747279543, 0.052714949852088466, 0.011496523384266766, 0.0575751785072498, 0.03111917234491557, 0.051470427570166066, 0.0305065758220735, 0.050309489670326, 0.02655027561559109, 0.05728934032958932, 0.03552115820639301, 0.04334296798333526, 0.01807294163882034, 0.06792690663132817, 0.061780699325026944, 0.007285282927114167, 0.044172525813337415, 0.0320241175359115, 0.02229385088867275, 0.033888184698298573, 0.027348464718670584, 0.012918550692120334, 0.01718434039503336, 0.05505502311279997, 0.04334643752372358, 0.03620464281993918, 0.03173811979650054, 0.03495417593512684, 0.02817816912283888, 0.0646593862620648, 0.032580809929640964, 0.04701583085989114, 0.01815326057112543, 0.05076718327472918, 0.017323776955890935, 0.02943564744782634, 0.009227955124515574, 0.020017398237541784, 0.022027800223440863, 0.03848348147585057, 0.04389668807561975, 0.030916630967112724, 0.010318261902284576, 0.03170609241351485, 0.037611758525599726, 0.02065257831418421, 0.01616095771169057, 0.04885231610387564, 0.03836927979136817, 0.004150773975197808, 0.09870261303149164, 0.0747431990748737, 0.02493843847332755, 0.04088063331437297, 0.018418027320876718, 0.10176719311857596, 0.04714042632258497, 0.03020623236807296, 0.09357879578601569, 0.035466539848130196, 0.04778848451678641, 0.02885433244955493, 0.05461002765514422, 0.04646460438380018, 0.042598556756274775, 0.02282247896800982, 0.12087054928997532, 0.022873047055327334, 0.005875186107004993, 0.06679548023384996, 0.04360242652182933, 0.032776336156530306, 0.02404472939815605, 0.03818682649580296, 0.060205320187378675, 0.024881706849555485, 0.09369038511067629, 0.019777875641011633, 0.03839993791189045, 0.04041888016217854, 0.052175749879097566, 0.056968587814481, 0.0400696477299789, 0.02760621817287756, 0.021557649670285173, 0.015179312485997798, 0.03818488949036691, 0.023218930546136107, 0.011735989392036572, 0.050173194249509834, 0.007421468417305732, 0.012249919236637652, 0.04049900242534932, 0.062281663849717006, 0.03318828377814498, 0.030617359916504938, 0.011548309521458577, 0.04012269273516722, 0.021781637260573916, 0.00464946335341665, 0.0049632429272605805, 0.01981127785256831, 0.09747205796884373, 0.049173910956596956, 0.03995289676822722, 0.03946512020775117, 0.02018352799495915, 0.031393804092658684, 0.012478418157115811, 0.0577934218745213, 0.02847055860911496, 0.04081649320141878, 0.05309250263962895, 0.0539575833681738, 0.01606762336450629, 0.05123915208969265, 0.045001074322499335, 0.012447774879547069, 0.00974139236859628, 0.03998331740149297, 0.05139068380231038, 0.014165050797600998, 0.03968328564951662, 0.018009946288657375, 0.10249994520563632, 0.04594867816194892, 0.03177362043061294, 0.05361691532016266, 0.055681499652564526, 0.0062552742565458175, 0.026525645589572378, 0.08658046936034225, 0.04646180277632084, 0.013184986346459482, 0.047145777207333595, 0.017554844635014888, 0.010519142724660924, 0.06528371799504384, 0.024731258672545664, 0.0071330471018882236, 0.03467209302471019, 0.029136890334484633, 0.04470325788133778, 0.029605816343973856, 0.07134460058296099, 0.013185548523324542, 0.01811540361813968, 0.04194145178189501, 0.026618755437084474, 0.05434575999970548, 0.047870035414234735, 0.0452360345661873, 0.027551737111934926, 0.017242187095689587, 0.04857189931499306, 0.032381420824094675, 0.050028497716994025, 0.012811556189262774, 0.05606382073892746, 0.027775283124356065, 0.15754423686303198, 0.055218625857378356, 0.004785085275216261, 0.012033640705340076, 0.037302119671949185, 0.02440155585645698, 0.03516104959999211, 0.04903486216790043, 0.0667927713948302, 0.007691041037105606, 0.015195138785202289, 0.02503953754057875, 0.028798940402339213, 0.05691739446774591, 0.040970114059746265, 0.05865162289410364, 0.04138310810958501, 0.045774596292176284, 0.05200008352403529, 0.022358892711054068, 0.031195754563668743, 0.01770142807799857, 0.01874332363513531, 0.017588777482160367, 0.04800899885594845, 0.029218906929600053, 0.028618066025956068, 0.03373299790837336, 0.0765812539611943, 0.017972686764551327, 0.02086390486510936, 0.045168139185989276, 0.05224881060712505, 0.026199614549113903, 0.028515447411336936, 0.023409083623846527, 0.052550935215549543, 0.029820013151038438, 0.029517012808355503, 0.04435241498867981, 0.058718486689031124, 0.028125669596192893, 0.01821899630158441, 0.03228913476050366, 0.061437448603101075, 0.006189103905853699, 0.034517036110628396, 0.058335657231509686, 0.040327184105990455, 0.025609798249206506, 0.03943200186768081, 0.035277258793939836, 0.0645415777398739, 0.0320353610732127, 0.011869129757542396, 0.02942031467682682, 0.07185185851994902, 0.01981337998586241, 0.06181562479468994, 0.01618380287254695, 0.01625293578399578, 0.026368215658294503, 0.05173130732146092, 0.03945256677980069, 0.008079644867393654, 0.009616846073186025, 0.07148611330194399, 0.06390842187101953, 0.028700570583168883, 0.011454964042059146, 0.03107173241005512, 0.018751696916297078, 0.04455764850717969, 0.01848175554187037, 0.03994001308456063, 0.07089097765856422, 0.030971752130426466, 0.03061911880649859, 0.07854594892705791, 0.008151797392201843, 0.045143076858948916, 0.06231339066289365, 0.027130607268190943, 0.04074159936862998, 0.028511567834357265, 0.0509914194844896, 0.0620631124911597, 0.08481757919071242, 0.09276778422645293, 0.07197014943812974, 0.0332445608364651, 0.02639194583025528, 0.048096498067025095, 0.016450744114990812, 0.04434684517036658, 0.04631863506801892, 0.029714847114519216, 0.0857751426519826, 0.04472741849895101, 0.05058549068053253, 0.0338623282732442, 0.044206597813172266, 0.019179237060598098, 0.046772907371632755, 0.020193827149341814, 0.03481336825643666, 0.05870143955689855, 0.011995908989774762, 0.0517344762920402, 0.10318215703591704, 0.12577543297084048, 0.08340351327206008, 0.0036542908628689474, 0.027705901593435556, 0.01624397064006189, 0.015186031705525238, 0.044301696616457775, 0.0531016087916214, 0.028246339097677264, 0.03702924310346134, 0.05196273123146966, 0.062226566806202754, 0.061661031722906046, 0.06694347932352684, 0.027711640250345226, 0.08900518456357531, 0.030240089145081583, 0.04353582990006544, 0.11363291734596714, 0.1237791521998588, 0.0856205310265068, 0.24782801570836455, 0.1521723493351601, 0.10595850922982208, 0.13981560536194593, 0.19225433527026325, 0.17006300651701167, 0.07806947527569719, 0.16232834343099967, 0.08834494030452333, 0.23241769027663395, 0.10727992543252185, 0.1210658454510849, 0.13026560452999547, 0.29182698286604136, 0.12361831395537592, 0.1603547649574466, 0.14711018971865997, 0.162073400861118, 0.12128284201025963, 0.195013091142755, 0.24604744015960023, 0.1351076876744628, 0.1839885616209358, 0.1585032104048878, 0.29923489317297935, 0.141612968291156, 0.12774142669513822, 0.15188199147814885, 0.15657147421734408, 0.10550006976700388, 0.21450880594784394, 0.07085497607477009, 0.10215184825938195, 0.11922170495381579, 0.0972959834325593, 0.14058681554161012, 0.1864528629812412, 0.14656119339633733, 0.08349921321496367, 0.3392839722801, 0.22078299662098289, 0.18572628556285053, 0.09645944941439666, 0.12415129473083653, 0.11262597137829289, 0.24720070796320215, 0.11442785398685373, 0.1047185659990646, 0.13168929610401392, 0.15494118357310072, 0.1530636241659522, 0.09004134888527915, 0.11463009665021673, 0.10460234567290172, 0.1581731328042224, 0.22784410131862387, 0.14484914776403457, 0.07948991624289192, 0.303294055047445, 0.12291998267755844, 0.12122580796130933, 0.0869788542331662, 0.16085942537756637, 0.11556769633898512, 0.09320568846305832, 0.14383105473825708, 0.1779329334385693, 0.0753344978147652, 0.18388307275017723, 0.15626101900124922, 0.23981966340215877, 0.1312797938589938, 0.15506071387790143, 0.14250327832996845, 0.21135766175575554, 0.14674769510747865, 0.1860377352568321, 0.12286062570638023, 0.05950227627181448, 0.10169475208385848, 0.10569812671747059, 0.13072073401417583, 0.12471589841879904, 0.17004213732434437, 0.1604946597944945, 0.20399564586114138, 0.1940414565615356, 0.14882836549077183, 0.1624934861320071, 0.10172228576266207, 0.1277706227847375, 0.13800826796796173, 0.177862934069708, 0.08720002908376046, 0.0904846856428776, 0.19070994079811499, 0.15431020961841568, 0.12604640593053773, 0.13860952632967383, 0.07988328419742174, 0.09491308082942851, 0.1083317564916797, 0.08853170918882824, 0.10033867016318254, 0.12244808807736263, 0.17659792851191014, 0.1603685540612787, 0.18283879675436765, 0.08417969584115781, 0.10067536772112362, 0.06655568489804864, 0.27366003894712776, 0.224442615872249, 0.1828212820691988, 0.14087702496908605, 0.12967970862518996, 0.2382701777969487, 0.12351171928457916, 0.07433095830492675, 0.23899535997770727, 0.21653391915606335, 0.08125663589453325, 0.131971460650675, 0.195035177457612, 0.09062098106369376, 0.2671308018034324, 0.10340854176320136, 0.19936820666771382, 0.16154525888850912, 0.07831123730284162, 0.1529163820669055, 0.2405810623895377, 0.20751062053022906, 0.18942817754577845, 0.1084930326032918, 0.12614760518772528, 0.09838439495069906, 0.18239028722746298, 0.24675340071553364, 0.14405959169380367, 0.12659137981245294, 0.13513452373445034, 0.15388564177555963, 0.16410422860644758, 0.15252822398906574, 0.06870476645417511, 0.13387431245064363, 0.19887084898073226, 0.17062159138731658, 0.08065462796366774, 0.11925501254154369, 0.18688265554374084, 0.12119322767830454, 0.1797055680071935, 0.2405062539037317, 0.15435836015967652, 0.3172008931869641, 0.06480990123236552, 0.2186942516709678, 0.12025458156131208, 0.08574369785492308, 0.07170473516453058, 0.1505236979573965, 0.15110085136257112, 0.14888420468196273, 0.08726403932087123, 0.20014563604490831, 0.20465741894440725, 0.13005234097363427, 0.10688988972106017, 0.20614563283743337, 0.10610806682961993, 0.12151336792157963], [0.01920798786159139, 0.052171768256812356, 0.0067370556553214556, 0.03941999020753428, 0.0581052389316028, 0.01857956132880645, 0.01901166939205723, 0.045295658710529096, 0.03801412502070889, 0.01870141084509669, 0.06264162773732096, 0.11752624632208608, 0.01600844265340129, 0.032240657674265094, 0.04045527879497968, 0.02981079011078691, 0.002410869046798325, 0.007732417625447852, 0.04668983136070892, 0.04372297727968544, 0.08375725796213374, 0.02103773626004113, 0.07970273451064713, 0.04287632407795172, 0.031118010883801617, 0.025464504287810996, 0.02269940305268392, 0.12508851592428982, 0.02927252895460697, 0.02228829776868224, 0.029128055066394154, 0.021065869223093614, 0.0451790895749582, 0.07921394862933084, 0.09199520107358694, 0.04652040275686886, 0.007600906737934565, 0.034295690566068515, 0.03459646446572151, 0.03124322603980545, 0.020867456041742116, 0.07420080044539645, 0.022585453698411584, 0.03970311212469824, 0.023933809861773625, 0.03869557614962105, 0.0357193969830405, 0.030788610492891166, 0.008437805336143356, 0.022203889602678828, 0.03067303212446859, 0.015060555870149983, 0.04354411968961358, 0.009287671109632356, 0.06475900474470109, 0.022852712208987214, 0.08477240466163494, 0.024158675041690003, 0.03762556618312374, 0.030688003098475747, 0.019678821190609597, 0.021370066278905142, 0.006326484717646963, 0.05076798850495834, 0.017873316901386715, 0.009515537349216174, 0.03471103722404223, 0.03253986935305875, 0.03278742384281941, 0.028557057776197325, 0.04812583516468294, 0.06699071702314541, 0.027055791360908188, 0.04336584097472951, 0.03240489495510701, 0.057833983955788426, 0.02525789779610932, 0.09281988299335353, 0.01884685509139672, 0.024044903802860063, 0.015191642341960687, 0.046174984963727184, 0.02801190577883972, 0.05530719747184776, 0.028690024664683733, 0.10371476673753932, 0.08708838038728572, 0.05101533890410792, 0.05897903989534825, 0.04867568495683372, 0.012658308260142803, 0.042616494465619326, 0.07070809762808494, 0.014947999898140552, 0.020836953772231936, 0.04883119458099827, 0.032799331602291204, 0.03981317633588333, 0.04182432974630501, 0.02186277441069251, 0.011184761988261016, 0.0321358181827236, 0.05841211699589621, 0.0873906422930304, 0.046650081931147724, 0.04737090399430599, 0.05117846667417325, 0.029701857674808707, 0.027434800613264088, 0.07209787305328064, 0.04484172779484652, 0.007344440446104272, 0.08694332020240836, 0.0593962604762055, 0.048677514350856654, 0.014710464402014622, 0.037273016350809485, 0.046348098330781795, 0.07117122004274279, 0.04143042002397124, 0.02454550653055776, 0.037236398784443736, 0.022975964384386316, 0.03170326483086683, 0.032945430793915875, 0.014534708061546553, 0.02569594118540408, 0.02695035444048699, 0.021717317176808137, 0.01619583308638539, 0.006959020429349039, 0.02327143563888967, 0.027173347552889027, 0.022620078598265536, 0.1155643121455796, 0.011521018896019086, 0.019600689738581423, 0.03684032941237092, 0.04249609584803693, 0.04794650260009803, 0.033023040887201205, 0.01972166352061322, 0.00996950815533637, 0.066140764974989, 0.01942860795679735, 0.05431962898001075, 0.06300065651885234, 0.020510570211627055, 0.01609102142538177, 0.03289898348157294, 0.028905013714393135, 0.027965961271547712, 0.08828622900182381, 0.0877613302145619, 0.06053139761206694, 0.026385325872979593, 0.004374119607746252, 0.011044420934922528, 0.01320664499871782, 0.037845290135010146, 0.05382323608500883, 0.045495519079850055, 0.051047084270976484, 0.05989488723571412, 0.016028588252083864, 0.03044382538064383, 0.03323887969600037, 0.04089175068656914, 0.051493779246811755, 0.0060882042907906, 0.04591381948557682, 0.016097522639029194, 0.05485776768182404, 0.057271465702797286, 0.03406734285817947, 0.04026035370770842, 0.025519829541735817, 0.03633185064245481, 0.07765965390717611, 0.06712641130434349, 0.0447192326100776, 0.03887542450684123, 0.04207278965623118, 0.05990157769701909, 0.04419466778927017, 0.03270209170295857, 0.03365206670423504, 0.018008951810770668, 0.032597634417470545, 0.057459392337477766, 0.046192763111321256, 0.051350355497561395, 0.03332994121592492, 0.024879947959561832, 0.016241796147369314, 0.03870797001582105, 0.026855292744585313, 0.04365103719464969, 0.011849713318952126, 0.06705290157697164, 0.018094925908371806, 0.04686654414399527, 0.048024038478615694, 0.05630434337945189, 0.03895357636793051, 0.012615748873940902, 0.0605540256947279, 0.002178049435315188, 0.02461253730871249, 0.08281078218715265, 0.03239807461795863, 0.013220179916970665, 0.0813424504303839, 0.01446181060600793, 0.054637824796373025, 0.028629355947487056, 0.06905508984345943, 0.043954805660177954, 0.022975684223638382, 0.043130721169291064, 0.026327742634748574, 0.02013505647482816, 0.050635541119845584, 0.0411571204313077, 0.09254985256120563, 0.009637538078095531, 0.023220451948873233, 0.061758045267197303, 0.04775705456268042, 0.035020475697820075, 0.020949838144588284, 0.06236271379748359, 0.02690082350454759, 0.05570503315539099, 0.03847824933473021, 0.04688651162723545, 0.02272866779094329, 0.027808433005702682, 0.02524475992686348, 0.0592163935652934, 0.0472293690108927, 0.047558975347783417, 0.024849651636031922, 0.024580927383794915, 0.03593683140934445, 0.015037469511298696, 0.011185721214133082, 0.019619569975475315, 0.03143521593301557, 0.06563340313732624, 0.050783143160515465, 0.07114381995052099, 0.142163255950436, 0.05708122356736567, 0.037127058167243376, 0.01848541432991624, 0.010350944230594905, 0.06948195834411308, 0.010425551408843603, 0.024410751066170633, 0.021853796279174276, 0.038252183730946854, 0.06687232220428996, 0.04261584508640226, 0.03317027185403276, 0.0367630050459411, 0.03928533864382189, 0.015642615799151827, 0.043005372426705435, 0.017882688371173572, 0.01955186940904241, 0.04165942082181573, 0.05832061389810406, 0.04907461530820001, 0.059258892651996575, 0.05055122201156337, 0.030768778451601975, 0.04183825985819567, 0.018196711462223902, 0.07553351213573478, 0.01992075576708885, 0.06455964903580025, 0.020262626094336156, 0.09583053120877594, 0.031965654852683656, 0.015129112689464819, 0.05274327391816769, 0.011279219761490822, 0.021574104939645622, 0.04953942981956061, 0.02193697619077284, 0.02595095611468423, 0.07521522726165131, 0.044704322863253765, 0.03690859586640727, 0.04281443638319615, 0.07221284657134674, 0.03604639838158619, 0.022098998160799965, 0.03429506716202013, 0.017188041856570635, 0.118511180189671, 0.007126174350560177, 0.010694998327380745, 0.0320123210985912, 0.03641941293608397, 0.07548263049102388, 0.02519677822419908, 0.05451911827549338, 0.012141257684561424, 0.13010595372179523, 0.07994775456609204, 0.02946767668618122, 0.0723841342551168, 0.02318011065653991, 0.025955804194381926, 0.024982811482914258, 0.0734120978449937, 0.035500140584190376, 0.05795174052764196, 0.07729442077106796, 0.049961893673753366, 0.05075055545603391, 0.061650289135286584, 0.018875795140047558, 0.055283990513999015, 0.06182040422572754, 0.04269970777386334, 0.027552503379411064, 0.05538389101275243, 0.022932264873816166, 0.0223853113129735, 0.032995477522490546, 0.01618075079022674, 0.06389740839949809, 0.05769604838860687, 0.040264123817905784, 0.02254984174214769, 0.0704743507958483, 0.01081107671780046, 0.05815547119709663, 0.02931579245341709, 0.013030577883910155, 0.069192357477732, 0.03098811092058895, 0.053852918281336315, 0.04038096383737866, 0.02913883661676664, 0.06860566747491248, 0.05358673588489182, 0.015624312582076527, 0.04117224169021938, 0.12256911752047017, 0.19894512312021106, 0.19105970015516505, 0.12175554555142298, 0.12604045390617102, 0.12227858896949328, 0.1662417029729113, 0.0800942767818924, 0.11877581520820968, 0.08403732965234667, 0.12504855869337916, 0.1591722565353848, 0.13206883042585105, 0.09715622960356995, 0.19128345767967403, 0.14621342299506068, 0.07047898921882734, 0.07535964177804999, 0.11569775029784068, 0.10279866706696339, 0.21953773219138384, 0.1628666973556392, 0.22732486511813477, 0.1752008800394833, 0.08406703782384284, 0.1719403878087178, 0.17150501429568976, 0.09000069403555244, 0.2343858065432869, 0.16525442391866818, 0.11934453039430082, 0.19122574827633798, 0.11692918109474704, 0.13387305079959333, 0.22650353028438985, 0.17412246525054798, 0.12247122824192047, 0.14619253895943984, 0.17177868867293, 0.12750784313539043, 0.15066429041326046, 0.10601846734061837, 0.12014111460302956, 0.09430474980035797, 0.1145616483699996, 0.09343289697426371, 0.11520839296281338, 0.13653693051310256, 0.17447054735384881, 0.17393033806001768, 0.14797329262364656, 0.10557753514149226, 0.11677872549626045, 0.09070647647604346, 0.11740693866158836, 0.09767024108441547, 0.15458967274753377, 0.12784234393620864, 0.13722409988986328, 0.10485714723472483, 0.11883475657668896, 0.16167204739758745, 0.08990763613837771, 0.11180530447745696, 0.09783280853298493, 0.10497269962797873, 0.13267900940263644, 0.2468381094513461, 0.1214897156751249, 0.11287689892924391, 0.11197059560799971, 0.1249879103852436, 0.1254116470227018, 0.13231287826783955, 0.1476900148554705, 0.1421321154339239, 0.15243345173075795, 0.22086023935116827, 0.11036879601306282, 0.17988874489674345, 0.10493403373402543, 0.14331388170830905, 0.12711511342786252, 0.1224017706408631, 0.14467642031377181, 0.16252225177595392, 0.1889031971222721, 0.15014474251074716, 0.13085911486996338, 0.14134183205896989, 0.0971421436406672, 0.10828116428456269, 0.13602581340819597, 0.06287817988777533, 0.11542371968971565, 0.09987453842768446, 0.1521585157024674, 0.1019146059115883, 0.17750704457284883, 0.1940488928812556, 0.09316828422015533, 0.14280383329605684, 0.1679083885392174, 0.1857146932161413, 0.09642043471103534, 0.15724613098427653, 0.09621904551750049, 0.20901670533930883, 0.08996297809062526, 0.15091207867953926, 0.07937339905765839, 0.09059568124939688, 0.2081162278773263, 0.12911162426462397, 0.2639135025674477, 0.16771850263467059, 0.16355383704649284, 0.17406580969691277, 0.15075576753588393, 0.25806101504713297, 0.15076050243806094, 0.07983672185218893, 0.08437259486527182, 0.1998391142114997, 0.12985231733182445, 0.15034326701425016, 0.16155213117599487, 0.11565088367206044, 0.10834573113243096, 0.10649413947248831, 0.12413697128067724, 0.10449372493894771, 0.16187760746106505, 0.1212268766539637, 0.3135390771785751, 0.15843433910049498, 0.0822548170981463, 0.13089464890072122, 0.11038220662157983, 0.100890627654735, 0.062444825016427785, 0.16387486044550315, 0.08215193316573277, 0.11714668973581865, 0.13468871562508866, 0.10420632825116627, 0.2060403220821172, 0.16704927838873118, 0.07151370635256171, 0.07680053633521311, 0.1508788304636255, 0.13487322838045657, 0.1326767829596065, 0.17026208020979539, 0.14833526773145422, 0.1087717832706403, 0.1340568214072846, 0.14966167858801782, 0.1708951173350215, 0.13452493847580627, 0.08428566710790619, 0.09934660425642505, 0.1206021144753322, 0.13017449848121032, 0.18079803907312453, 0.13856030709575862, 0.09901817422360182, 0.17636519100051373, 0.27905177150387317, 0.11543648462975398, 0.12630718178115785, 0.1203453610651195, 0.0919247861020267, 0.18125300528481603, 0.07287153232027777, 0.1505761084263213], [0.037928488600300625, 0.02058566071355017, 0.05841228397912346, 0.055498986985185184, 0.03277154559327755, 0.047967946957214735, 0.08671481293276884, 0.07935905334306881, 0.0539885235048132, 0.055810017365729436, 0.06574071026989259, 0.014309403159131762, 0.05015907488996163, 0.03692520142067224, 0.06165215563669335, 0.04102499959117267, 0.07882391291786917, 0.019058758662140463, 0.0269663755534566, 0.05240732221864164, 0.023260984344233293, 0.045509393530664966, 0.01234051876963349, 0.015952252797433175, 0.0457448473025579, 0.08641272914246656, 0.013732467759837164, 0.026209321840724442, 0.058115298743359745, 0.008373495456908131, 0.039874307040008716, 0.08645786656416021, 0.018441115535097197, 0.04702762729721144, 0.022555621217179578, 0.017900618659041356, 0.044512633539852686, 0.05324774137989152, 0.03402543006814085, 0.02222127812274266, 0.058616972019081004, 0.017960174154723063, 0.04698393706348725, 0.02707059720705729, 0.03657049193861894, 0.03899426090356428, 0.030095394467934966, 0.02338175218028482, 0.04548475793853868, 0.014462429371633334, 0.018564167330623604, 0.041242159422836266, 0.02733269036980346, 0.0673564251337666, 0.058232339142705314, 0.024302586753037758, 0.022799316539021675, 0.04448273983143736, 0.022457199447671883, 0.0172206499701133, 0.031315886008087546, 0.04259104251104873, 0.020090881989744958, 0.05761398540926166, 0.038727225037291646, 0.02256052310258383, 0.031663415211369283, 0.02233705687103793, 0.05332528839062434, 0.008478744985040976, 0.03859093332721386, 0.12458709126804024, 0.03982760739745572, 0.0401674034219468, 0.026748779710032977, 0.023314289101108443, 0.020059563357790466, 0.039805610140319914, 0.027797302645922173, 0.032607482717139646, 0.009386561359860934, 0.04017573402961716, 0.04133590751735028, 0.00863328239574912, 0.06099498386902269, 0.03937602537916973, 0.013984459365019575, 0.012034077644784702, 0.03180086467182264, 0.042170983215328306, 0.03573915295419283, 0.03843725680781063, 0.06163306759845, 0.04105284497200046, 0.031657140352763236, 0.022067920726840384, 0.028165756702946965, 0.030254358789534308, 0.026902712270384654, 0.08289399178465828, 0.009388745129399467, 0.017429501458536834, 0.02729943473241292, 0.06745349062839523, 0.02281917641084874, 0.004255029953128542, 0.0458569895272376, 0.06282180635025725, 0.012684604407695588, 0.051436388966976665, 0.06068203132599592, 0.02289232248585904, 0.04327735099650454, 0.025494269975752104, 0.03346368364873342, 0.06455833543441258, 0.03392196354980115, 0.01089328163288883, 0.011190485802217154, 0.016256854323728476, 0.027780205418821424, 0.0218240899630473, 0.029482246900442988, 0.03983989365224261, 0.011353712834534235, 0.02910418203100562, 0.020869843901891727, 0.029970196010253858, 0.01717795978038339, 0.02168573879316682, 0.033104209578596056, 0.010539728045841912, 0.013780623867205577, 0.02491940053005237, 0.0655569693481084, 0.03245600666559767, 0.07716099746176042, 0.017875803096103482, 0.04530296515440568, 0.0683420269342605, 0.039231410482898355, 0.032375405717175454, 0.03509805610519834, 0.03881178163283039, 0.030592156581406016, 0.040965178777696565, 0.019963340200774837, 0.04699869095929898, 0.03647448400442954, 0.01850099015427986, 0.12066147886798717, 0.013307743138284422, 0.0204986531753093, 0.038583226123591885, 0.0702684790303465, 0.05669004123774357, 0.0690608711738605, 0.05931571147812065, 0.03359095084306318, 0.027633096906356514, 0.026102062947757076, 0.03438342726440169, 0.021948507310298737, 0.056878947507357225, 0.03906505437043961, 0.032945245256996714, 0.0474765598482918, 0.037805169631610624, 0.045670903418795206, 0.020375853709992953, 0.02941207498224685, 0.029990940893185325, 0.052978638632339425, 0.06945876622921787, 0.01616273515537614, 0.0456549917726079, 0.012961898610228673, 0.03603031604143325, 0.032146349258255213, 0.01886779849883169, 0.01875596983154537, 0.087735013657948, 0.043865376865142025, 0.01614437256648671, 0.04014092359284405, 0.02050959057669388, 0.09092595922993496, 0.05725205483031459, 0.0875675406132359, 0.05338002178177703, 0.05309826912707649, 0.07394976157229394, 0.054305372323142365, 0.04412645699630957, 0.011503285277285613, 0.07639087823918089, 0.021333508084353525, 0.01997519972064765, 0.014896234170009848, 0.012194309183541918, 0.05154911006684415, 0.05348795973986853, 0.11801227883552201, 0.03149686242977623, 0.10673392738681287, 0.032011809016694315, 0.008779296240390977, 0.04025783040560782, 0.03343184551340528, 0.06172370980493724, 0.08534693086403422, 0.06118384189903736, 0.07142293427023105, 0.04485477475100197, 0.02281467899592826, 0.04801629787834827, 0.04310374781198334, 0.028045573308190797, 0.055105529972934164, 0.056453529905411415, 0.040235859123640694, 0.01913750053063268, 0.017375749557686504, 0.04435812581505161, 0.05360634342650883, 0.043246559289400466, 0.04423908161697909, 0.03709102689754218, 0.07869158798712306, 0.013167680390324676, 0.035453834279906005, 0.036574351106537506, 0.022152167475724127, 0.025836819368123543, 0.04977357370080426, 0.017350112066196743, 0.03294363850727677, 0.07805603498127311, 0.03154662343149539, 0.03589969805034343, 0.04811992766917683, 0.053133665860514157, 0.054845514823682606, 0.0463968982512597, 0.0046023661980143515, 0.03423417394515127, 0.03272715774073731, 0.0026892991991189774, 0.11899546123459004, 0.007186478023868403, 0.01620009858015692, 0.028251133371668402, 0.019327256559336092, 0.037675275234505534, 0.0489311136334436, 0.05990803438180592, 0.03144763577438425, 0.0875799567438662, 0.04021109365567099, 0.01600005452928599, 0.052832086730632, 0.027499543721205555, 0.0298828322411282, 0.011683610464388039, 0.015412523116538068, 0.05674336825904902, 0.028517306491266936, 0.028445340431062505, 0.07225111912703142, 0.02023849701799918, 0.038816676096757874, 0.017636308330111206, 0.06596420062123798, 0.01724341906083282, 0.030039601660973858, 0.06645907211350277, 0.025874436978483573, 0.014881940405757632, 0.03327450649521779, 0.053702919103670865, 0.027238014590693638, 0.046427233537542634, 0.014861547115287976, 0.019027224807359744, 0.005321323151292745, 0.039010825639707036, 0.060390664148144424, 0.10115300654433668, 0.09094288761843927, 0.08968286929302849, 0.018221215323137585, 0.060487358568934724, 0.02744157456618268, 0.09329365522717126, 0.05092376530228648, 0.031123595545068383, 0.020487524670897983, 0.043453926482470706, 0.0988104248244781, 0.055020587460603565, 0.017387594234605785, 0.03301832082797773, 0.012092224915249972, 0.05645470249874052, 0.033348194338032044, 0.09263444255338982, 0.03529571229591966, 0.02283626436110353, 0.05240308826614637, 0.04953562260197941, 0.03821782971499488, 0.04062823631102219, 0.07303415171918459, 0.05902966178837232, 0.05262080470856745, 0.03666037715447601, 0.011980386971117696, 0.0642206211341545, 0.05164407899428625, 0.005253463486951659, 0.0264662830522866, 0.03265499872213695, 0.06006558862281963, 0.054012739783502184, 0.05987942829960957, 0.03470466588623822, 0.10346463328460231, 0.017966109480767045, 0.03642113471869379, 0.07725896095507778, 0.06856683088699356, 0.0359399855369702, 0.009051620836544316, 0.04566978648654185, 0.034470098980818875, 0.03201404288120102, 0.04363432031823322, 0.04134731432714034, 0.03278362033597659, 0.023897843529994134, 0.034588894559419714, 0.049221018780372106, 0.07222382293548435, 0.02148046074580634, 0.026853858544200193, 0.03930233753635548, 0.013269290611788165, 0.06699299541651271, 0.0297315157513367, 0.03989086806541309, 0.06895985745359212, 0.05643915450491477, 0.1398621083353646, 0.1730329924612306, 0.19220747606595978, 0.14897539978846908, 0.10330458171665668, 0.2500336489174515, 0.1797566722962074, 0.13064583647064865, 0.09158883069176227, 0.1166022130928468, 0.19315174024086446, 0.11207706411369145, 0.20023460470838472, 0.14970071555580944, 0.1386462477967143, 0.16320455266395584, 0.225050137960352, 0.08361519605387002, 0.1868989976355806, 0.12437686309567653, 0.16152060474269092, 0.14108114526607096, 0.14050403638975695, 0.09206040616845712, 0.1537725533125922, 0.11970810854109004, 0.2397207499598153, 0.12983432767214254, 0.20992056699469686, 0.13140006631147116, 0.213715850841254, 0.14909536053892225, 0.14899922272888944, 0.15196573542198166, 0.14988478302257136, 0.11760573033825494, 0.2216191595653072, 0.1612884015776217, 0.08285895499284379, 0.09232651063939556, 0.23881391971372068, 0.14307060569990426, 0.1577242076746188, 0.1860277311061509, 0.17130513908341527, 0.12186575448140502, 0.11679336064844392, 0.13565790111897513, 0.13521276094252244, 0.09374352288432419, 0.11391589825507253, 0.10673916694940999, 0.15935647243168205, 0.17683467362076044, 0.22644804732408375, 0.20441714121261612, 0.21845956973265857, 0.1071230650995858, 0.14255166635848582, 0.10240810443065129, 0.12992668052902445, 0.15716124413302168, 0.09502415065071546, 0.19204441137844697, 0.22953591600526124, 0.20799954741960391, 0.10116638746694662, 0.09612822148483247, 0.14281162584666163, 0.15715690999059007, 0.15541716740699485, 0.15870648465352133, 0.2093720604898408, 0.12213991867611185, 0.10927312629064545, 0.15578405553242192, 0.14052710233954713, 0.1629613953991793, 0.08011244455701672, 0.16392183839343488, 0.0953560316702351, 0.19156195601681247, 0.21714221307775006, 0.08813625579932705, 0.12086198490578681, 0.24930108978878707, 0.08356012869626284, 0.14485621300991625, 0.23648503061849624, 0.1407029913389124, 0.15414258814416826, 0.12037124717608094, 0.17404909653123468, 0.1374392188154161, 0.1066731900209561, 0.11675377449137159, 0.09882711572572589, 0.11108160659205168, 0.14098732295678928, 0.25017017440404743, 0.09735418265336193, 0.10147862383746542, 0.07733550606644712, 0.21841760870302096, 0.09195523642119952, 0.1505541556980461, 0.15384207770694047, 0.12311802478507161, 0.11933932051761076, 0.13853520766133443, 0.14573801803635433, 0.1394833013182506, 0.1661528233671561, 0.21468001941684633, 0.11098658200353384, 0.17994994239415973, 0.13582151499576867, 0.15720026625785977, 0.10126288150786422, 0.0860354138421826, 0.20195788645651191, 0.09339824609924108, 0.1387880722177215, 0.14516291295876727, 0.08252694038674235, 0.09338626041426323, 0.14864745957311243, 0.13103288132697344, 0.10397649253718555, 0.2298362780129537, 0.14192253293003887, 0.13731321698287502, 0.10835836990736425, 0.10903317510383204, 0.11457001237431541, 0.09286622269428335, 0.20552418805891648, 0.09710107318824157, 0.15090490953298286, 0.13240247033536434, 0.16171589348232374, 0.08519201495801099, 0.13595085649285465, 0.13818084698868915, 0.15126796817639843, 0.07803342174156569, 0.13647211133502424, 0.10367313967435621, 0.11909587381524034, 0.14382110995939001, 0.1672559665166773, 0.085284523665905, 0.09365221645566635, 0.16571495623793453, 0.12148118839832023, 0.10724547493737191, 0.11580861231777817, 0.16654414299409837, 0.15705998550402, 0.1129430985020008, 0.13198444823501632, 0.10900470631895587, 0.10692842202843167, 0.16056779102655128, 0.15553150267805904, 0.17963957623578608, 0.21571537479758263, 0.08173487585736439, 0.09963266507838853, 0.08501348391291685, 0.09585956402588636, 0.14443933381699026, 0.16115690785227343, 0.12430687856976874, 0.11595002113608643, 0.19819755776552483], [0.04819570094696246, 0.06656824945821427, 0.041784925415413454, 0.08737113865208812, 0.05776326470368076, 0.0355569037492387, 0.013004463562538149, 0.045075656453263946, 0.05159474843821954, 0.04206825513392687, 0.03776344979996793, 0.030529992436640896, 0.03747223847312853, 0.01457924712667591, 0.04295683967939112, 0.02980585297336802, 0.02188594611652661, 0.04873491947364528, 0.014495356608676957, 0.011502000434120419, 0.020353548461571336, 0.019374963667360134, 0.025899905631376896, 0.020945836113241967, 0.07562180544482544, 0.02205603708716808, 0.010014253166445997, 0.02136977684131125, 0.019143164972774684, 0.05856760806636885, 0.0164747822782374, 0.09111036066315137, 0.07930303603643551, 0.023105435757315718, 0.04963987950759474, 0.009525696423224872, 0.036642851337092, 0.031056371808517724, 0.05463975066959392, 0.04516598324698862, 0.021541077512665652, 0.047584920830558985, 0.02519569097785279, 0.014101479355304036, 0.025514883127470966, 0.025573637103661895, 0.013739261194132268, 0.028857883626187686, 0.07617246417794377, 0.06733617192367092, 0.03283912184997462, 0.016754946736909915, 0.050636290688999, 0.0502958118886454, 0.11363738507498056, 0.04699705823441036, 0.045666094301850535, 0.04554316867142916, 0.07798235455993563, 0.022444885362347122, 0.0585160955961328, 0.0696199681260623, 0.03889564803102985, 0.10229441482806578, 0.04238427645759657, 0.01766721692547435, 0.050635518855415285, 0.04254168597981334, 0.04594159807311371, 0.03786032604693901, 0.038113639602670446, 0.11123158721602522, 0.05045745907409582, 0.03780495811952278, 0.07295242641703226, 0.06249957325053401, 0.09245877619832754, 0.04399425451993011, 0.046326145602506585, 0.01968250780919334, 0.07440089088049717, 0.00985169128398411, 0.053288737617549486, 0.010961586121993605, 0.018968732438224833, 0.007786307287460659, 0.04505466851696838, 0.052303232296253555, 0.06339633255265653, 0.007117160503185005, 0.041379753602086566, 0.03308128834760282, 0.111879571195459, 0.023760655676596798, 0.04777722613653168, 0.058507022840785794, 0.0912577289273031, 0.02492007588443812, 0.024107552198984195, 0.01989678254176397, 0.05418966778961476, 0.029995362237968948, 0.024254755335277878, 0.013220958244346548, 0.04017407904029824, 0.014892933468217961, 0.013882332423236221, 0.08563241281080991, 0.06349056304316036, 0.02461314586980734, 0.031152836163528264, 0.03319224684673827, 0.04924174696498085, 0.03475942154182121, 0.1108269534597639, 0.019655857286124956, 0.002737682125371066, 0.015878967569733504, 0.029983101958350744, 0.04208532453048974, 0.015667494444642216, 0.02453634842822794, 0.07301445511984639, 0.024070407707768027, 0.09049473432241939, 0.032869011847651564, 0.031749393019708805, 0.035190924754715525, 0.103997992555378, 0.06316568789770827, 0.02142554738384206, 0.05083250340248924, 0.03259036879171617, 0.036960223369533196, 0.03666700824396685, 0.014155510489217704, 0.04142909157963004, 0.0028550499973789556, 0.03541746162227355, 0.03792950163187925, 0.029100901738274843, 0.05667133169481531, 0.02447980790748261, 0.02756486941507319, 0.01985789214813849, 0.027252885374764446, 0.035594482396845706, 0.029494818882085383, 0.03107073607679922, 0.07003925187746063, 0.026802359061548486, 0.03873924411891494, 0.04597159568220377, 0.039326809855992906, 0.010086153361044126, 0.021334242810553405, 0.07433637598296627, 0.02966018237202661, 0.024108333309413865, 0.046930331736803055, 0.030195621511666104, 0.06920400919625536, 0.011881927166541573, 0.029857328336220235, 0.07358644317719154, 0.06004925766319502, 0.07529958718805574, 0.06606718103284948, 0.04158063071372453, 0.023398890225507785, 0.02450679981848225, 0.02436060043692123, 0.024868004948075395, 0.01865038077085046, 0.026225621259072796, 0.045230097384774126, 0.08040891028940678, 0.03552441252395511, 0.053612098781741224, 0.05752844546805136, 0.0370213280984899, 0.04301736182242166, 0.07404241128824651, 0.002491193777132139, 0.02918486647104146, 0.03818504905211739, 0.026326514380343724, 0.03197675738192629, 0.0941399930161424, 0.022851890280435327, 0.032100699754664674, 0.03015476257132832, 0.05304386228090152, 0.06692524475511163, 0.04624237939424347, 0.018908282654592767, 0.08424699379247613, 0.03585115417081397, 0.0189111306463019, 0.12151870396337472, 0.05541312420973554, 0.04445925085747149, 0.03842682963295374, 0.02080791167827556, 0.03309061343315989, 0.07051545835565776, 0.03702482361404691, 0.04571340621623676, 0.011323053786327364, 0.030525433794537093, 0.028440290116122924, 0.04301399618270807, 0.017884410153783392, 0.06270597194088623, 0.025492446147836745, 0.039978159475140274, 0.06633819109993055, 0.03140779728710186, 0.02176600206439616, 0.020938325578754302, 0.02607717688078992, 0.0012282300531296642, 0.05535672840778716, 0.05921789270360023, 0.059801981478813104, 0.06682092847768217, 0.08652266347780824, 0.024983830080600455, 0.058622137366910465, 0.06411328431568108, 0.03221286795451306, 0.045576928969239816, 0.01293930485189776, 0.03694187005748972, 0.044686964029097, 0.0167260901798727, 0.09347402679850347, 0.03393612372747157, 0.06860841342131607, 0.008498612278344808, 0.015093196452653501, 0.04035352663777303, 0.029590793419629335, 0.023719754062767606, 0.04610436961229425, 0.032027152919908985, 0.02690738965611672, 0.02769672679278301, 0.028848085421486758, 0.02006485672609415, 0.05892237320949789, 0.048246738442685455, 0.03280556935351342, 0.03211327544704545, 0.05216617988480721, 0.03149639487673994, 0.011682929543894716, 0.030190192701411434, 0.05468465431476943, 0.06633651384618133, 0.041926916819647886, 0.021140416101843584, 0.01721253829600755, 0.053970934604876675, 0.08769258507527411, 0.03141405359201599, 0.05552293237997219, 0.009424446143384557, 0.016563439239689615, 0.05929974417085759, 0.061822619536542334, 0.022958520203246735, 0.05696891064872034, 0.012392766893754015, 0.07795683210133575, 0.001978558748305659, 0.0070665645853296155, 0.024478483173879795, 0.023486751233576797, 0.04554328370431904, 0.034768145487760194, 0.05579571989073884, 0.017957810414372943, 0.03925173790776171, 0.09165877811028622, 0.04298655898310244, 0.05959039888693951, 0.08573015365982428, 0.03521062135405373, 0.033999054139712825, 0.05811966257169843, 0.13772479724138975, 0.04822580987820402, 0.03125305207504425, 0.01932211162056774, 0.03837765863863751, 0.059137547796126455, 0.029984632637933828, 0.0690066053357441, 0.001673355502589402, 0.08117399032926187, 0.020154910780547652, 0.03110136265604524, 0.02090973619488068, 0.055012449811329134, 0.05103618583234493, 0.0073088887893391075, 0.032795750739751384, 0.02583412166131893, 0.00690187552208954, 0.09240374594810419, 0.06364472938003018, 0.04834621962800156, 0.02354011721763527, 0.05962987743259873, 0.01052606417943025, 0.060282243794063106, 0.028990106511628255, 0.010569076275714906, 0.004693486162068439, 0.027099290491605643, 0.006314501351880608, 0.020253629409126006, 0.024385200777032878, 0.021053369600849692, 0.0024621818329251255, 0.038637161705992185, 0.0403044669656083, 0.053680862474720925, 0.020995997874706518, 0.03764774897717871, 0.04024358859169297, 0.034923458442790434, 0.03144240363326389, 0.04477530557778664, 0.07118951398297213, 0.04118182281672489, 0.06321460285107605, 0.007081305957399309, 0.009740936875459738, 0.02970970959722763, 0.04372922245238442, 0.05330282358045224, 0.033365649651386775, 0.02999341224494856, 0.11486698276712559, 0.0189724580195616, 0.06241345443413593, 0.01175847368358518, 0.03248772605729755, 0.056981965026352555, 0.05461344895593356, 0.19737128022825345, 0.2772284927777946, 0.11534002027474344, 0.18765494925901294, 0.14829476131126285, 0.1439162384485826, 0.13795211707474664, 0.12146333974669687, 0.1277234370354563, 0.16403543151682243, 0.1858829232514836, 0.07972948893439025, 0.1189174540922977, 0.10500068601686507, 0.19756380817852914, 0.11925692728254944, 0.1364365773042664, 0.15176168933976442, 0.17579597857547924, 0.06982696053455584, 0.23777952912496403, 0.13915776566136628, 0.13898673030780628, 0.2375546732218936, 0.16618157416814938, 0.10464438091730699, 0.14020929986145347, 0.11233525729039684, 0.1122872626001481, 0.1476904156152159, 0.07090349026839249, 0.19408274965826422, 0.1624833038658835, 0.11871610942762345, 0.09984561693272553, 0.16199437697650865, 0.08128869667416438, 0.12647437280975282, 0.158453723997809, 0.1801598959718831, 0.14877810725010931, 0.18025993747869506, 0.0912048805912491, 0.08619455256848596, 0.16608377394732088, 0.09320807817857713, 0.10052855606772937, 0.13680045231012627, 0.2113476427621208, 0.17892505129566416, 0.1448051235638559, 0.13696224050363526, 0.20975907566025853, 0.18462584383087233, 0.10068609175505117, 0.2297657442977652, 0.08293432751088403, 0.07832887073163874, 0.24472202378092334, 0.1600242272252217, 0.22816362557932734, 0.16192578768823296, 0.148990688030608, 0.20432786084711552, 0.1490982252289541, 0.13364549347897992, 0.1866289449390024, 0.07229856462799944, 0.10235845475108363, 0.13139429240254685, 0.0928234304592479, 0.1718113134847954, 0.13414611661573872, 0.13476631458615884, 0.1891101078945212, 0.19546502939192578, 0.12777185474988073, 0.06521770395920612, 0.10022346657933667, 0.13651325600221753, 0.1407805160852149, 0.13673679088242352, 0.13725555210839957, 0.15944579732604325, 0.12338889384409413, 0.13174930616514757, 0.15878619131399319, 0.10228643674054183, 0.13630762172397226, 0.12235192058142275, 0.19715558242751285, 0.12658142019063234, 0.15325140237109736, 0.15005728782853112, 0.08977580102509819, 0.1380088913720101, 0.17459182912716642, 0.1777111054980196, 0.19810159807093441, 0.10276598288328387, 0.09207032868289389, 0.10222497949143872, 0.1347563401213847, 0.12962079694261774, 0.13816664228215814, 0.07749183205305599, 0.10260654729790986, 0.13564000051701441, 0.17719707917422056, 0.1292966862092726, 0.19779734720941633, 0.19994964968645945, 0.16846467275172472, 0.1341495750239119, 0.2592875179834664, 0.1694347636657767, 0.18240596138639376, 0.121500803361414, 0.10842390154721215, 0.08441450394457206, 0.11328813037835062, 0.15276182239176705, 0.2694591268664226, 0.13110062456689775, 0.2794143551727757, 0.1549698453163728, 0.11116281981230713, 0.1422693088534288, 0.2074561914196238, 0.09024045226396993, 0.1316847838461399, 0.12703625281574205, 0.10731511065387167, 0.07862505444791168, 0.17158676928374916, 0.09240423576557077, 0.14421976200537756, 0.05913328415772412, 0.10187271167524159, 0.1971575862262398, 0.11440581962233409, 0.11785611612140201, 0.08869529337971471, 0.12466889078496024, 0.12793785834219307, 0.09454648214159533, 0.12741739017656073, 0.0954912806628272, 0.20651865110266954, 0.16785805608378723, 0.14978561725001782, 0.10808037623064592, 0.18258380965562537, 0.07060649018967524, 0.19309337774757296, 0.15206374344415963, 0.19563361565815285, 0.13023971841903403, 0.09373352615511976, 0.3078435093630105, 0.1349302995367907, 0.20212274714140221, 0.08795877118245699, 0.11629100088612176, 0.13285765919135883, 0.2671232318971306, 0.17092904832679778, 0.10618298663757741, 0.12049724900862202, 0.1665370332193561, 0.10571200487902388, 0.22217533987713978, 0.164014502952341, 0.135512039414607, 0.13660805794643238, 0.21395979478256777], [0.04072830008226447, 0.0032622358139633434, 0.021795255670440383, 0.016553537134313956, 0.062943941593403, 0.004941953493471374, 0.04355590128398035, 0.0575026298611192, 0.05667196623107884, 0.07439952532877214, 0.034001095045823604, 0.03391512836969923, 0.010970068869937677, 0.08000088491826318, 0.017631823902775068, 0.0034667918907871353, 0.022136934894660953, 0.03274714377766941, 0.09367510429001413, 0.043192334269406274, 0.05618750335997902, 0.020234379953762982, 0.04108967405045405, 0.06402671278920025, 0.019144773577863816, 0.03303847013739869, 0.03301026481494773, 0.04277877618733328, 0.04491456216783263, 0.045508740440709516, 0.02446047124976758, 0.012661377968470333, 0.044033347148797475, 0.023575857194373384, 0.04738478957733605, 0.0614922413660679, 0.06862942362204194, 0.00856915063195629, 0.033617486333241686, 0.04884358844719827, 0.024564160412410274, 0.022120334906503558, 0.02126621940988116, 0.014468347071669996, 0.008073534208961064, 0.024634404690004885, 0.08506214653607458, 0.08752851106692106, 0.10078648949274793, 0.009983807485696161, 0.053559940643026493, 0.014040754977031611, 0.046978634418337606, 0.01849550197221106, 0.033047713586711325, 0.044887418116559274, 0.039707231044303626, 0.02518852925277315, 0.021631463678204454, 0.060855077899759635, 0.060940068651689216, 0.08017083673621528, 0.03897375165252015, 0.0814381726377178, 0.05678539237123914, 0.0755871768342331, 0.08120445549138822, 0.04489393046242185, 0.020394388848217204, 0.031155144242802635, 0.03537412761943415, 0.06600222084671259, 0.048223041667370126, 0.02797253298922442, 0.01984032180189388, 0.023236051893036347, 0.015442937256011646, 0.0430828637763625, 0.039851812543929555, 0.011387338618078502, 0.04799803362402599, 0.04157474548264872, 0.0194924697643728, 0.02535407827963354, 0.06544693853356875, 0.03471579067991115, 0.04855887462326791, 0.013718978298129514, 0.040402983358944766, 0.05269018809485715, 0.016683002941135783, 0.027678126716637053, 0.03336575726279989, 0.045287543325684965, 0.018698277126532048, 0.024504716238880064, 0.03790520742768422, 0.02301544664078392, 0.016716896825528238, 0.03559729884727858, 0.12228713108925149, 0.054039791066315956, 0.047209123222273774, 0.04911266893032007, 0.021180764815653674, 0.03316545160487294, 0.03451759272138588, 0.0428820831439225, 0.061376121229841374, 0.06432124893763103, 0.0219871360968682, 0.09172730060527101, 0.06850605641375296, 0.04512007028097287, 0.038665207466692664, 0.01780138238245854, 0.0930442416574806, 0.057753331057028845, 0.04934209646307863, 0.04008063522633165, 0.02023662866122322, 0.09525150759145617, 0.03137062682071701, 0.030249722221924458, 0.0921589633799158, 0.04259594439645298, 0.029873533130739816, 0.05180489126360044, 0.03755878773517907, 0.022483399116026703, 0.019636539182101842, 0.07369955390458927, 0.046372069700737484, 0.04912909265840426, 0.03136923900456168, 0.047378666859003715, 0.019493544023134746, 0.015446469878952485, 0.06031328783137724, 0.041170412296196446, 0.02512725939595839, 0.007590218883706257, 0.05993198348733131, 0.02529641340515809, 0.03115479543339461, 0.04902275402855594, 0.01623949548957171, 0.034062032791553065, 0.0399840409954777, 0.03690472927701194, 0.08164236714947037, 0.0313944423396606, 0.07267195396707393, 0.01597607017174596, 0.040347633985220455, 0.07448876116541214, 0.0634009858185891, 0.01181507172077545, 0.031710675175418146, 0.022232632982195355, 0.021714662143494934, 0.00483024125060183, 0.030909793931641616, 0.11679117873427458, 0.042435154391569085, 0.05523102714505512, 0.03708290409122128, 0.03741209482541308, 0.008406132328673266, 0.02883485663915053, 0.03649884871265385, 0.02841151705069933, 0.03504917083773762, 0.06025555616361089, 0.04173760236881208, 0.021965005253150593, 0.024513668395229615, 0.063900970708346, 0.025617247556510847, 0.016903814139368478, 0.02514737716410309, 0.014373097983479965, 0.04661707491322886, 0.029182196594774723, 0.06523650255985558, 0.017683492224023212, 0.05502275824255776, 0.019103964732494205, 0.012763074464601232, 0.04251002967066597, 0.022005318714946043, 0.025599569598853122, 0.022655879802186973, 0.048519666961510666, 0.08734218747122213, 0.052481381135294214, 0.04718524462077767, 0.00836643763250322, 0.037568379993899725, 0.02322399384866003, 0.022507489229610655, 0.025654894852777943, 0.03923980788385961, 0.0259886535059195, 0.05529942347493488, 0.04565117342281155, 0.01572786073666066, 0.04847193202294875, 0.06804637014283799, 0.042155238552368246, 0.027040883469453547, 0.06724922190187499, 0.040811988365021534, 0.02076036969810957, 0.05472606615512632, 0.01223854396812385, 0.037296256705303676, 0.033862309719552286, 0.10621745939715765, 0.010058419302367838, 0.027731080808734987, 0.030897465003363322, 0.04686279258748982, 0.1762420093291439, 0.03298494644695893, 0.06913325283676386, 0.04656663855712395, 0.036603588014259, 0.00969968459685333, 0.03212936891941354, 0.03901232106727548, 0.04727976083813701, 0.04504038217419293, 0.1452084956690669, 0.06915608129929751, 0.035753558040596545, 0.014837191683909623, 0.049510597382322885, 0.02272268608066952, 0.054603741664323024, 0.032777156229713, 0.04018725216155872, 0.03871363260259386, 0.02441951397486264, 0.011227550512558082, 0.03521814302075654, 0.0016433184669040202, 0.07088843209203333, 0.09411921288119629, 0.0447651121794479, 0.0997638916305732, 0.009538336125842761, 0.057315026060678065, 0.043805875175166875, 0.03611242354963906, 0.04369204085378442, 0.031597820488968864, 0.01510794756541145, 0.0365100365888793, 0.03478497368632816, 0.05476555583300069, 0.01772209503542399, 0.03299075375252869, 0.011554774555406766, 0.05794830809463747, 0.019756232759391423, 0.06113005103543401, 0.01753331864165375, 0.009961088489944814, 0.11144054631586187, 0.088624893251108, 0.05571368659730069, 0.0725776121544186, 0.034247458388563246, 0.0381400749029126, 0.04760715557495132, 0.05966531127342023, 0.030118300855974667, 0.03180825646268204, 0.08966669047367759, 0.03319127834402025, 0.014955915830796584, 0.011096759044448845, 0.04700255383795593, 0.0248002357329824, 0.07525721055571921, 0.023198423150461167, 0.012824547484342474, 0.0770611860207282, 0.05554017247050069, 0.016038904104789253, 0.020787010944331996, 0.08570653109927662, 0.08242182258982211, 0.06186808350321371, 0.05955898006504867, 0.040081329134409316, 0.09365990510559641, 0.032792767306091264, 0.08271662591141649, 0.06572819023858756, 0.045082183642080054, 0.006782979289710056, 0.026728266748250462, 0.04229327430948615, 0.024526518682250753, 0.04397332595544867, 0.06386913999449462, 0.027610891847871244, 0.03560918805305846, 0.07367114449152723, 0.06296240622759797, 0.06751412409357727, 0.030496593935822602, 0.03645883210992906, 0.033237751631531864, 0.028554829477798194, 0.02462584772729315, 0.04368220368633047, 0.05622779455734417, 0.014622653488913784, 0.028346686740405858, 0.060483206252683885, 0.017567474133102223, 0.036405735154403374, 0.031191921370918863, 0.04958956931659486, 0.03218912293959875, 0.06297067375271581, 0.02360672126087593, 0.022147931667859666, 0.05603240933851339, 0.0675671653880272, 0.041534168558428064, 0.017855251171567943, 0.013858041002094978, 0.06843412746093236, 0.04103884435608052, 0.03739613122888841, 0.043810739953187294, 0.005406962354754796, 0.02937962086434709, 0.036247932293917984, 0.019535510618879925, 0.04092040871910285, 0.018979645719809923, 0.03729397831193637, 0.07485849913791753, 0.01705585978925228, 0.04484154225792736, 0.027698175836121663, 0.018883966185967438, 0.10761560624814592, 0.19934702577302232, 0.10315761421225034, 0.1556443388108164, 0.14612498867791146, 0.06128418397565838, 0.12263166572665796, 0.15515202772803605, 0.2569571742787957, 0.12301617243792862, 0.23524965159595013, 0.14628363016527146, 0.12266694742720574, 0.182513780600857, 0.10845027747564018, 0.08692861083545722, 0.13136184570612386, 0.08169762746547349, 0.17131791886640713, 0.09472712088609114, 0.19191735569620505, 0.09549926617182791, 0.14248307707021013, 0.17298558406764641, 0.14006087032612413, 0.09545612512738444, 0.1256371708586812, 0.17567956529092044, 0.11663907556794584, 0.143164902983699, 0.0782387591607403, 0.1309347100323066, 0.18039328657323495, 0.20569569838698953, 0.10051215460407548, 0.1568466774187982, 0.25775323156267405, 0.06255881147808395, 0.12425098742824048, 0.09778897729120217, 0.11917460084077902, 0.11229958225158043, 0.2423654674203135, 0.10507804006920196, 0.13811476615956053, 0.16135326528456062, 0.12157546341768466, 0.32940384931862354, 0.1975677564041689, 0.12447092289221473, 0.16253428941126913, 0.12811067485017702, 0.1698535872856155, 0.16668470576405525, 0.20193891716189682, 0.14175823627738282, 0.13143093965481967, 0.22105840762378648, 0.1540868973825127, 0.11814778015832417, 0.16100222943350673, 0.1369227285613306, 0.08731205627555028, 0.18176832294557244, 0.0839520494628232, 0.14345094154123217, 0.2542998699937016, 0.10786617014673539, 0.0569622572947992, 0.10325768540496938, 0.16811773355584592, 0.23925499292090535, 0.20163638808298856, 0.196419000858441, 0.20164250337984413, 0.09619689983082935, 0.11306820233585313, 0.11688820712151937, 0.12397006968967617, 0.11407245430746116, 0.1804263863596134, 0.12419775317539461, 0.09956144116586074, 0.10292052771546878, 0.1850867917528376, 0.22320864693028852, 0.1171105174580589, 0.06909200426889583, 0.16077053092885762, 0.12570656166644767, 0.10459742523380555, 0.1920607386273332, 0.1544767920859158, 0.25102756277192384, 0.11817310965852812, 0.12123725187848322, 0.17226608673809096, 0.1617741075460799, 0.12864736636402085, 0.13661301549291238, 0.2280198864173144, 0.17186326382216066, 0.1234097927226685, 0.2238992153434083, 0.14694194484036416, 0.11431843173340894, 0.135360166314058, 0.21531503065489233, 0.109510658076033, 0.11774533573770896, 0.08605476905358955, 0.12548917176900432, 0.16374804225051776, 0.09261698724003509, 0.1648091501556337, 0.1058835003641434, 0.21779196336865425, 0.3237608552444726, 0.1623490938800387, 0.18713697470957413, 0.22819812060333788, 0.23922662803670391, 0.07937849019072019, 0.1643430071999319, 0.20039186580106616, 0.1519969798391685, 0.11434040672611445, 0.17871484538773075, 0.09909270069329068, 0.08103727188427001, 0.11275162440142594, 0.1482580101583153, 0.13014610391110182, 0.10908720345469192, 0.1662986256997101, 0.10197466792305931, 0.15577500133076683, 0.08487623854307458, 0.20221262122504413, 0.12885696371085942, 0.06165504259115551, 0.0746367454121355, 0.1455474048270844, 0.22297267365502194, 0.15173794061411172, 0.11025412677554414, 0.09907929008477367, 0.08821169511065818, 0.08522909265593626, 0.15074755938258022, 0.12982985994312912, 0.09498810453806072, 0.1759149448480457, 0.12588492943905294, 0.13064276397926733, 0.12867200566688552, 0.17624364205403253, 0.14265846140915528, 0.09067493519978598, 0.22066285775508732, 0.13803320412989706, 0.126938883040566, 0.11327406667987816, 0.20846864412305877, 0.11579973623156548, 0.12663387518841773, 0.18746587971691042, 0.10491295674000867, 0.15080335404491052, 0.10634464866598137, 0.18631448212545365, 0.17199783003889024, 0.12799789808923379, 0.21235898224404082, 0.1863779209088534, 0.11860239756060764], [0.04615796009602491, 0.026752382837003097, 0.03161576561979018, 0.06470121370512061, 0.06446388229960576, 0.04686002808739431, 0.022885841681272723, 0.02147186482034158, 0.027344583286321722, 0.01706049450149294, 0.023759421856084373, 0.02618166385218501, 0.009167493280983763, 0.038449479980045, 0.04473835775570478, 0.08041871406021528, 0.05391023434640374, 0.053215027510304935, 0.021887640068598557, 0.03265718805778306, 0.030587551555072423, 0.03169710500515066, 0.012793688056262909, 0.05125744231918361, 0.023813385269022547, 0.06957910547498614, 0.015568859307677485, 0.024821461156534497, 0.012893036582681816, 0.06255774278542958, 0.031502721685683355, 0.022378858338925056, 0.03708311931404751, 0.06339613217278384, 0.054484370921272784, 0.017030847557180095, 0.06581317356904037, 0.08239771763328463, 0.015125607897061855, 0.034181370137957856, 0.027108712056360673, 0.04587058567267377, 0.06226751109352335, 0.05009090120438486, 0.0864137161988765, 0.02807075437885942, 0.02342034571483964, 0.03561561505193822, 0.0017428192495572148, 0.025356610858580098, 0.023353426258836407, 0.05040918607846834, 0.01964873637916753, 0.020924452983308583, 0.0373070289788302, 0.0885730393929407, 0.07020950797596015, 0.07441698064212687, 0.03484709515760187, 0.037888060105615295, 0.027950647054240108, 0.030280586288427003, 0.02156366106646601, 0.017027461508405395, 0.08832488747430034, 0.004592715495164157, 0.059753085079137236, 0.025084027438424528, 0.04253125880495645, 0.057033525736187585, 0.015129156290640822, 0.09987468685721979, 0.03503433159494307, 0.04366625493275933, 0.037973106518620625, 0.04291155382816214, 0.04714076771051623, 0.035652228907565586, 0.03262203994381707, 0.035549448875826783, 0.09318720898590982, 0.041111151804216206, 0.049427914709667675, 0.03724017631611787, 0.034405064579914324, 0.04805419564945623, 0.10018585453508422, 0.017882081665447913, 0.03144825546769425, 0.03140319597150665, 0.05150352735654451, 0.027198881143704057, 0.03702986279677134, 0.027469291926536243, 0.03757772363314871, 0.008018243279366288, 0.055063197869458236, 0.03747842427401338, 0.015107742547115777, 0.030826409929431975, 0.0799310117145069, 0.026850650610867888, 0.047448380501009524, 0.01587347567692632, 0.01969308897969313, 0.10733707822510041, 0.026172257130383514, 0.07445780618581921, 0.03799661775701679, 0.061084408953320235, 0.01675192248512758, 0.06285088369622827, 0.047676164176664315, 0.03219338657800108, 0.008084045803116169, 0.03257294316426851, 0.020254911469237413, 0.08454605704173446, 0.032777805608930066, 0.03335869943839498, 0.05460061351186596, 0.03567386251233984, 0.0885406594898086, 0.02392454414803069, 0.07216591315227561, 0.015510820576309925, 0.042208932936773635, 0.15493836341192946, 0.0029173495840950636, 0.07021927463938482, 0.0384753289836226, 0.034136062022298574, 0.04748965133330785, 0.022866044891998172, 0.06351790376356803, 0.014904748459230177, 0.04295627564715687, 0.00815220742879319, 0.010778830401250161, 0.01723067824059399, 0.1193425637029577, 0.03972756960138213, 0.0895226989814546, 0.055313539123744704, 0.03892307409842033, 0.03578277268388774, 0.03352710758917965, 0.07422969967592508, 0.05448672724014614, 0.043584336672211066, 0.047228163020918146, 0.08164045982994139, 0.010100359922944335, 0.031889614401734434, 0.034937677992274985, 0.06130386573204305, 0.020736357510031667, 0.07214905897853896, 0.018929214929812588, 0.014614163319492945, 0.008339077430719044, 0.10722585255280137, 0.04476452217204496, 0.03242414255510084, 0.05351092178898398, 0.01615604469407117, 0.01781652776116971, 0.01631508694117656, 0.018025863500952255, 0.06728943888447247, 0.01988116404390894, 0.033659258115221746, 0.022502620740851853, 0.00776618024247, 0.026890594854194205, 0.06465434707934037, 0.024011097120819613, 0.046650920558022335, 0.04961166676366702, 0.05478435443365015, 0.03137594430882018, 0.04240249989379663, 0.07051873864838853, 0.01746250105497893, 0.029647278279298916, 0.0148281003748707, 0.11585628046304919, 0.027018446489819326, 0.010228868359263288, 0.02752246495219879, 0.03141132248856593, 0.021137551411811728, 0.038077281787991524, 0.03683168710267637, 0.06718662174534984, 0.04413757807924412, 0.024500159452145454, 0.047321265446953475, 0.04180275180260651, 0.0274864095626981, 0.042606464339769445, 0.05324981939338613, 0.02734343295742292, 0.0765705892990809, 0.04092524752195459, 0.023619469502591528, 0.03286487437435426, 0.02037263835518388, 0.026593772890919354, 0.02251509067718871, 0.05124976109073032, 0.06895843253005296, 0.13891006645280868, 0.030130644627206493, 0.08981479346402921, 0.028957765571249183, 0.03302365686977282, 0.07323917743633501, 0.027885876115760766, 0.030964254583523143, 0.06949316477403045, 0.03954981410061009, 0.010694207940105116, 0.027588274897425435, 0.019537549669621512, 0.006484852074208902, 0.01213740315506584, 0.06259447167394683, 0.051110868153045885, 0.045603275211760774, 0.0914241407008376, 0.03229267480492126, 0.026276938915543724, 0.027878885084646754, 0.045433694467647, 0.01963550388609292, 0.024154203601938207, 0.032448588899569586, 0.034539823755039833, 0.02515086340281414, 0.06090004833822604, 0.016692687968316022, 0.0161942374688806, 0.07347576669417322, 0.05457233768538572, 0.0017309720215052948, 0.04865242604864761, 0.02723219986364711, 0.036936044198228046, 0.0420143343944801, 0.023420874495059252, 0.04337954844231717, 0.02287695631821407, 0.049245620975852944, 0.02962989532534266, 0.047472860242123716, 0.025982143015426118, 0.029384207336988766, 0.052323314812383614, 0.009903126756398706, 0.03158871804771479, 0.021728827887272928, 0.1102022580744233, 0.03367863188032061, 0.03429498181503732, 0.028050081855326425, 0.027242408104939386, 0.04808229336049408, 0.0655419408576563, 0.05078415990283247, 0.06925737703568302, 0.04040650113893207, 0.05308223502652254, 0.005729915337724378, 0.050640339104575105, 0.011953365374210989, 0.08410280192038044, 0.045541376384790055, 0.00863674822539906, 0.02431607157632243, 0.030467835713352542, 0.04517736779234838, 0.024393733619945124, 0.02137233539542649, 0.07328777326620184, 0.038992438931018114, 0.08108110312605277, 0.10607641423121095, 0.08535940636647865, 0.06809662096202374, 0.0393691271165153, 0.02990115030115703, 0.03674369436339475, 0.08580537774832919, 0.06630451243836433, 0.047040280915098265, 0.05041605094447732, 0.03770430063013919, 0.016936552128754556, 0.017288875606027432, 0.06743920428561978, 0.05120807465573307, 0.05714413171517663, 0.05220738021307625, 0.020065686076122802, 0.0577307660569204, 0.03741377578990068, 0.06400548736564815, 0.023049778392305598, 0.07966326709720306, 0.048178824508795515, 0.04725185237475671, 0.009288557048421353, 0.010124931504833512, 0.02467079961206764, 0.020710200515168253, 0.06244898104341701, 0.10766137449536473, 0.08065009344136342, 0.011797631250374252, 0.009867350599961355, 0.012777521296811756, 0.04928216432745103, 0.02511654278350761, 0.048306217868230306, 0.048800169097376056, 0.036484506708802655, 0.06310458687948994, 0.03022901259100763, 0.06288443619268946, 0.030602379665651824, 0.017921447033586446, 0.03030440551810898, 0.021310807642294094, 0.015010474817245267, 0.03536573021847289, 0.038658795310766436, 0.11520835585542955, 0.03320767238619737, 0.02865572074369993, 0.11841469357023016, 0.0109550802699232, 0.07144504284951836, 0.033206904263352044, 0.05661510287609417, 0.02062917654257035, 0.05358883616281673, 0.052185754029778764, 0.009563829826220172, 0.019665497784444597, 0.017777553875930607, 0.05436844745418057, 0.1336596833425574, 0.07287706874194555, 0.11945037549594417, 0.18894739943789318, 0.14264541445299983, 0.16215699637541547, 0.1149112444545608, 0.13536488637328148, 0.18405970389721915, 0.09453560967813246, 0.14219184347894043, 0.13283270818646997, 0.1865287104737945, 0.10464383914950304, 0.15599982754793018, 0.12451243121176958, 0.09024469734868035, 0.08760553115280345, 0.16205373394768685, 0.11863295178045519, 0.18823786173015833, 0.0874737925187219, 0.08860016489052214, 0.132315787486732, 0.13128665130352601, 0.10261577961500734, 0.11083122080890462, 0.10835389475687407, 0.13235195976449177, 0.10954323093756102, 0.18121236527804285, 0.08916167382267304, 0.1427578498260118, 0.11194713631994091, 0.17469328071456403, 0.14668107993202284, 0.20213512616464868, 0.14134591387119144, 0.14830464671831578, 0.09297171156504191, 0.08586534328060225, 0.0978063212824054, 0.17789260513382033, 0.09909605520078912, 0.1775147332227789, 0.09050640088389628, 0.08897270818124525, 0.14903910574503243, 0.11944783735089004, 0.15334822295699269, 0.08483355763019063, 0.17785940144676715, 0.16275883361231536, 0.12359992353594862, 0.14804571139393374, 0.10496304428670555, 0.12529447674751282, 0.20002151926746592, 0.15517939813435078, 0.15737998473923653, 0.1341414707712829, 0.1279753219569102, 0.09807273745536804, 0.2020515751792118, 0.20890195446554571, 0.12669392977841198, 0.19270735705504194, 0.1739928120514378, 0.14027293160324916, 0.14742674538865685, 0.06923205495695584, 0.19854743586620316, 0.14838939998298883, 0.1615698981913738, 0.14242927136365324, 0.14482633414445445, 0.12784231425030157, 0.1447690255008638, 0.12482784397434443, 0.10459820448886603, 0.18376798048848286, 0.16165983164682984, 0.16650764417136088, 0.23075573961250484, 0.10518258641241118, 0.1052228405023925, 0.18962621223181486, 0.11014114963472821, 0.10191597146331333, 0.13771390251349658, 0.11701313283992931, 0.17758146714186296, 0.15999323513824493, 0.17096982192015275, 0.15512029349338263, 0.07660805291379802, 0.14231747423764318, 0.08880492343450896, 0.11142826377181336, 0.1251397537998855, 0.19614514836575836, 0.13947205035947263, 0.09354906535008922, 0.13666753366123885, 0.10222366589005105, 0.2112435788149014, 0.09825932080275379, 0.13860192673746496, 0.1487735949922353, 0.12044188479194418, 0.21208817255683243, 0.28890505840536207, 0.16000346193322912, 0.15149493177887052, 0.11433102597948164, 0.10972907213727012, 0.1397693547187373, 0.17390755412634462, 0.10754429327789694, 0.11000049038557336, 0.17749126651324332, 0.23986171348951757, 0.2801309432834387, 0.14234260335797444, 0.1557717952528037, 0.17000274412566796, 0.11215950187761337, 0.26366342848632485, 0.1139838715607766, 0.1892627973575145, 0.14774000592296943, 0.14669187075924128, 0.07923007549834438, 0.18024741002591327, 0.1543092745123431, 0.11565110631636344, 0.13800075743347406, 0.14006765355588868, 0.1418217344325967, 0.13168231991585344, 0.26729080884251744, 0.1803636155091226, 0.18490771151846275, 0.12608729826752096, 0.1229190178855788, 0.11916745395865291, 0.12422245927155018, 0.16369193588616326, 0.1790884870570153, 0.1927197360782884, 0.16874691151315346, 0.21607028465950862, 0.06493456719908863, 0.27346390415914357, 0.1759420777671039, 0.12632598780328408, 0.08195100410375744, 0.20050548861036077, 0.13976815243950114, 0.119739634974394, 0.14100313070230186, 0.14858486683806404, 0.17189833772135898, 0.17879048507893458, 0.23804624215699732, 0.21277476305840537, 0.15871167968725786, 0.09915166432620026, 0.2168755594175309, 0.0936787853424903, 0.14701233012601733, 0.10719497920945287, 0.0835740365437232, 0.05447092691611033, 0.16286491620121524, 0.11403548051021062], [0.039901859272504225, 0.024899815252865665, 0.014170220783853438, 0.09560560851241462, 0.04195190493192058, 0.05263335813651793, 0.06425964325899258, 0.01840916051150998, 0.08417084944085218, 0.0359932568971999, 0.047415321532753296, 0.13898770994273946, 0.07556760639999993, 0.05920480492932256, 0.019766895566135645, 0.07829307694919407, 0.02072379480523523, 0.0700612342916429, 0.04758414899697527, 0.04521365510299802, 0.07255130301928148, 0.02016042864852352, 0.051689932588487864, 0.05290672823321074, 0.012284978292882442, 0.019747236074181274, 0.03701259302033577, 0.04747635575768072, 0.016347648670489434, 0.030493257982016075, 0.031676165308454074, 0.05798750833491795, 0.038267516501946375, 0.022897849630680867, 0.033980403968598694, 0.07313851994695142, 0.0507181124703493, 0.03056694768019952, 0.0265499639135669, 0.049326860171277076, 0.034224848859594204, 0.03098968056292506, 0.033528387793921866, 0.04422011974384077, 0.07036078735836782, 0.04822771348699462, 0.03058444937778404, 0.06239217706024647, 0.021411223933682777, 0.06405478823580779, 0.09036310701048933, 0.039160008454928175, 0.04210200801026076, 0.03657495224615559, 0.03362889685377013, 0.030412699707085267, 0.07413936546072364, 0.04826701020647306, 0.013745029536949005, 0.03808770896284841, 0.09825933564570732, 0.04224084899760783, 0.05564177248743363, 0.024352716973226052, 0.012276742309040856, 0.02599646832095459, 0.05774888188170735, 0.025225820318155456, 0.0542866182513535, 0.0385505567828659, 0.0732347765006125, 0.05700730936951004, 0.04318350642279256, 0.029254993860377, 0.04525562355411239, 0.040691504400456324, 0.014611730930482736, 0.03644795222498942, 0.019961160141974688, 0.012992413867323194, 0.011324859060550807, 0.10854775857296772, 0.022001880715833977, 0.021911553922109306, 0.017658548640611116, 0.045677846210310236, 0.08873136175679974, 0.015056933261803351, 0.03667472657980397, 0.04642543011868838, 0.059977183991577476, 0.009826051009440562, 0.05221513565629721, 0.044968746369704604, 0.01867980507086031, 0.026257515055476688, 0.04470873864192981, 0.058275958872400224, 0.052218508717487566, 0.041518791258567944, 0.016436023615824524, 0.08862704547937028, 0.08991349168354645, 0.08232350286561996, 0.07585774903418496, 0.05602710669336375, 0.022942859031900298, 0.03646887336799409, 0.02761301067948807, 0.034842293462133966, 0.06349432573188096, 0.05017655988922343, 0.05823460640385747, 0.02790198257571319, 0.02821922658768017, 0.01924269996379735, 0.01929682108311681, 0.003718413349815819, 0.030709449310961645, 0.011000289123330731, 0.03914850516594015, 0.047899654528009705, 0.021147729967196938, 0.07172485478804447, 0.05427769021480344, 0.03806413464189973, 0.06440888173528947, 0.017535723200126085, 0.03452814977208618, 0.02005177451792406, 0.018798997698468156, 0.0288313221608405, 0.01583372624736512, 0.09287957393098623, 0.02960483485367149, 0.028303616199991666, 0.06914693061844446, 0.03549201035639271, 0.02445104968501255, 0.008570626578148222, 0.017176015353470575, 0.021031548603787087, 0.03238707227865234, 0.03555780174792744, 0.04537904271273874, 0.01786760607501492, 0.09619121497962624, 0.029137584242562298, 0.03381780312338378, 0.04576665160129778, 0.03843730875814799, 0.024094824366329703, 0.07326833641855046, 0.09556164368405007, 0.009646904909459408, 0.026588451692077797, 0.051693365021492355, 0.10981009982060641, 0.08270824706414714, 0.06103065148636233, 0.016169870905287098, 0.043786709211417474, 0.047318144715973176, 0.08676745346747339, 0.07927257829578593, 0.017640440237300936, 0.029293526167748496, 0.022731302415195387, 0.06292119476711378, 0.013722016465180786, 0.03239704674342647, 0.08249795209849253, 0.08527184778358787, 0.021951674425508827, 0.022352979649440385, 0.04714111651992425, 0.02290449741849443, 0.010302433747710893, 0.02635003675095504, 0.057756785754463635, 0.02304080768226413, 0.08068468494457193, 0.01132238399804919, 0.0106779001725954, 0.04410999616084155, 0.02614783305034507, 0.0588502216123743, 0.06418592573027126, 0.029380615342233796, 0.037633755782735534, 0.05318359755619895, 0.06544093455886468, 0.03780081693548709, 0.055842708970885724, 0.025663128981250338, 0.054546663086512126, 0.06166927327285521, 0.01278367741178954, 0.0524843942548614, 0.06515400542411953, 0.05047103295510169, 0.03977106316597201, 0.04165021447988693, 0.03883081029925961, 0.07097794994479045, 0.04190003623079974, 0.017326018241874408, 0.1068936895171646, 0.021043892375018913, 0.05138197469932493, 0.02797516204736894, 0.02415225546428701, 0.0776585035782773, 0.06799117662012577, 0.021498847454495262, 0.11353968875482678, 0.023547594355477486, 0.019496098866511602, 0.02745185516687343, 0.09299352328525856, 0.12364557303953916, 0.031741292477818206, 0.050341431706328876, 0.05713182319595944, 0.03933949687052518, 0.02973564580315724, 0.020919016751577146, 0.012139690825279104, 0.05415020037617069, 0.07746818722807802, 0.02037588525126921, 0.030086464576015715, 0.08003626309800893, 0.03003237499797251, 0.01992958361370256, 0.046079693202045746, 0.03587828337913379, 0.08902592016966082, 0.01900587507407181, 0.009986416134779574, 0.016211902438953985, 0.019033891148865223, 0.04634410928701982, 0.008730593726795632, 0.055604420194868, 0.013767540731350891, 0.06102108891354874, 0.030432192215812393, 0.04452047804079484, 0.057047685913858004, 0.001510755585059087, 0.06985472427913919, 0.021489383216248825, 0.02629882856126642, 0.025734746232046746, 0.09000570353236981, 0.02030150906648487, 0.06311033110250719, 0.06491110048955306, 0.03299013776995707, 0.0397757127211662, 0.016348093959095422, 0.035844949816237204, 0.013568326958193211, 0.03763414169952739, 0.011061445802624803, 0.08962751249782741, 0.02068220670480514, 0.04289917851565406, 0.05432495760032907, 0.09712293685879558, 0.005289446517053875, 0.033353634280501865, 0.02536070936912438, 0.04642135201720521, 0.0863502848369535, 0.08454507740680128, 0.011584275853238069, 0.01501536742580356, 0.035263336103525944, 0.020322871787357144, 0.05138967448147014, 0.023789226506778505, 0.01918553789437283, 0.01663330873270752, 0.016206828004214913, 0.030924215716368053, 0.04033961507957429, 0.03901610973116476, 0.052336398875922896, 0.02314219618710922, 0.1215467051952146, 0.04815922067791689, 0.01107025045712362, 0.057672793191159144, 0.04038910148665309, 0.03634510168922134, 0.03616080415667966, 0.022978112901910208, 0.022868037558509968, 0.01369723893731134, 0.03585286482120864, 0.022889862266310956, 0.039671492922934704, 0.008432424765487667, 0.02205974411481293, 0.02722596953390166, 0.03842021709715482, 0.02745373836660292, 0.022481384185084607, 0.03992498830484692, 0.024181492372008506, 0.03727663803147152, 0.02591925898741465, 0.01434458652511239, 0.02216577104263706, 0.006333766114039463, 0.011652699085971108, 0.03759226972761098, 0.024895406895666383, 0.030472052967525087, 0.03985610957897734, 0.04616197882569395, 0.044529387523652986, 0.051086503444821574, 0.03640217284555547, 0.03529939705913421, 0.020492027651926037, 0.045331886649364606, 0.024821403640089557, 0.003914412927770172, 0.030067779152886942, 0.015198919099930208, 0.054845640988787636, 0.10502770761377178, 0.026859767895075493, 0.04273449594620615, 0.09822150095715187, 0.04187882565020118, 0.0829464170965366, 0.017156357716885395, 0.029033141800027806, 0.023942379812069703, 0.024282686063088477, 0.009441302172490396, 0.05513434385647997, 0.06415260329958983, 0.08105023720418103, 0.07613194291479886, 0.05917931586736813, 0.028075715636077803, 0.0654823835066054, 0.2489888682612218, 0.18036073597613722, 0.12556936824694276, 0.14289005601312965, 0.13960269803646952, 0.1653229835210368, 0.11682805605232716, 0.17285621288465336, 0.14880696195177734, 0.10291062004398555, 0.1721212937263772, 0.24975299835205078, 0.1798100327141583, 0.19344953441759571, 0.1459712750511244, 0.13862270687241107, 0.12335299616097473, 0.1906632597092539, 0.18414579302771017, 0.07060887990519404, 0.19937450008001179, 0.11323488128255121, 0.18558693991508335, 0.19671639427542686, 0.13712488958844915, 0.10767258092528209, 0.12833486282033846, 0.1576287081115879, 0.13776950421743095, 0.09971051636966877, 0.13303531450219452, 0.16917321598157287, 0.08869409852195531, 0.08162983227521181, 0.08198468276532367, 0.09848949790466577, 0.25890261051245034, 0.14013374922797084, 0.12474132439820096, 0.15374773589428514, 0.15320543374400586, 0.07754300313536078, 0.08546872471924871, 0.11007595938281156, 0.23001149907941, 0.18450528936227784, 0.12575854168972, 0.13377341005252674, 0.10639646541676484, 0.1532443074393086, 0.12697771220700815, 0.13204646209487692, 0.17438365670386702, 0.15850643132580444, 0.12556743866298348, 0.11909866429050453, 0.15867467620410025, 0.15131999272853136, 0.09894905801047571, 0.14480781013844535, 0.1864933842443861, 0.19480511167785153, 0.11268716145423241, 0.1441715966211632, 0.07829620881238952, 0.12355643368209712, 0.17559412925038487, 0.12092507487977855, 0.09546951347147115, 0.1304841521778144, 0.23041807726258412, 0.14927617739886045, 0.17672124376986176, 0.15849166258703917, 0.20734457240905613, 0.10405534572782926, 0.1834959685220383, 0.10399103121017106, 0.07488793271477334, 0.18111184879671782, 0.10628356249071658, 0.14453487790888175, 0.1798252615844831, 0.1047605492931325, 0.16328577330568805, 0.17990289023146033, 0.1929789237328805, 0.10046328417956829, 0.10992475421517156, 0.11143738476675935, 0.24970959755592048, 0.09238525904947892, 0.11328286112984642, 0.11377453396562487, 0.20283727208152413, 0.11754706356441602, 0.12392862074193545, 0.1613909367006272, 0.17783154122298583, 0.15813091944437474, 0.2566263248445466, 0.12602952949237078, 0.15781691676238552, 0.17940605204785243, 0.20710337441414595, 0.17976634990191087, 0.128490817733109, 0.1199648471083492, 0.07491519179893658, 0.08900355926016346, 0.15525971335591748, 0.16684497997630388, 0.16744093940360472, 0.12725496373604983, 0.12667399569181725, 0.21278923493809998, 0.14130313647910953, 0.09559179714415222, 0.21202896401518956, 0.09608430860680528, 0.1669200259493664, 0.16175325319636613, 0.1362315219012089, 0.131163157930132, 0.11478732063551433, 0.1283234337461181, 0.17760515649570152, 0.1498111174441874, 0.12627454212633893, 0.06052812474081293, 0.14287877536844462, 0.1375485520111397, 0.09158569882856682, 0.1504273820319213, 0.07868467117077671, 0.07976241802680306, 0.09415482854819857, 0.13442203227896243, 0.07659546608920209, 0.09446162497624755, 0.12753769231494516, 0.08657998696435243, 0.09567404937115498, 0.16831524873850867, 0.18467596848495305, 0.11012988383299671, 0.12324598588747904, 0.11439263165812008, 0.10899395259912126, 0.15946996165439487, 0.1120031536265742, 0.12155248652561568, 0.22179129329742864, 0.10328760137781501, 0.09261605955543928, 0.13665122125530615, 0.13361941440962255, 0.22702919348375872, 0.16542529599973932, 0.1486695310450159, 0.14933121507056057, 0.1948554441332817, 0.08200321419280954, 0.2395842838450335, 0.2219515378237702, 0.12059797329129651, 0.10669630049960688, 0.11293112023849972, 0.07713779050391167, 0.09188511088723317, 0.14275813184212893, 0.2057500829687342, 0.21716750547057018, 0.06598326639505103, 0.12098356353817508, 0.14405994792468846], [0.03659234076621942, 0.0635055841121357, 0.030548475624527782, 0.02640017068188172, 0.05601569988357369, 0.05795332130219322, 0.0601541231299052, 0.018406479503028095, 0.06542734583490528, 0.050306843913858756, 0.03554201255610678, 0.04872249221079983, 0.03815922231297009, 0.027270405626040883, 0.04653888965549413, 0.0287665642099455, 0.03170993673847988, 0.006398218856702442, 0.03344940472743474, 0.05421510119049344, 0.065462375205243, 0.0021985605417285115, 0.01005058871669462, 0.04693954921094701, 0.07466271315934137, 0.039884886355139315, 0.00863679460962885, 0.014968917330406839, 0.020316134941822384, 0.05616886803181842, 0.029481180063157808, 0.022972003171162214, 0.04517751622188371, 0.028098176735511515, 0.044110408052802086, 0.05204905413847882, 0.01816221087210579, 0.03497066645650193, 0.021449689447763376, 0.03904733188392129, 0.012921299421577714, 0.03896656766301021, 0.01788403907994507, 0.0521347759058699, 0.0785424979403615, 0.00948375673033297, 0.020042126598127652, 0.04712887108325958, 0.06291662313742563, 0.04757297225296497, 0.08461968551273458, 0.026855648975470103, 0.01766059696819866, 0.014705845460412093, 0.052050824160687625, 0.0286493753810646, 0.019038394129893277, 0.008896485069271876, 0.007528897076554131, 0.02974783372337697, 0.025469703032285906, 0.08741467303480022, 0.0483367164270021, 0.07334687790716998, 0.08788253777311184, 0.05579999095061794, 0.028196377716085408, 0.05541681268368848, 0.03459930689132307, 0.03918973889085464, 0.002788783167488873, 0.04422070232976694, 0.00770734694924613, 0.04418450778757688, 0.0239704218620318, 0.07968062593135983, 0.028034717543050647, 0.014324743351608049, 0.03579094001906924, 0.014919710156391375, 0.02904785858845571, 0.041238266858272254, 0.02855552338587586, 0.0383880858134944, 0.0468833129707491, 0.015433985099662095, 0.04799463087692857, 0.0394676138239447, 0.02934125739557203, 0.0819039593625348, 0.03600090101826936, 0.0524347074679099, 0.027145140375068877, 0.09672659289208241, 0.015501578054681886, 0.036757791458512656, 0.06199270494107623, 0.01552138504848699, 0.04935122859023977, 0.047507503695669584, 0.03260817291447893, 0.01232434273333638, 0.03210782437236048, 0.027674399279931094, 0.036119128853897564, 0.056792190443957224, 0.013862812083971221, 0.01383158622047631, 0.04524576783296652, 0.015248761737893801, 0.07454410311765969, 0.02357157314690994, 0.02752097509073792, 0.05025460042816121, 0.028033383532601874, 0.05116773521876894, 0.03956961088988464, 0.05784860797575675, 0.0775534451531712, 0.03325711426441558, 0.059193962151766755, 0.07776591461151838, 0.02374532476096647, 0.023165367892943323, 0.0875022761465516, 0.053705271711805835, 0.012040105739288265, 0.03295324931968935, 0.06007070202031173, 0.012294573334656889, 0.02016676102357451, 0.030101903103059158, 0.059531223741942085, 0.040439129661535844, 0.06788135360693559, 0.010621006204019068, 0.06473038010881282, 0.055912481984705664, 0.011495194939925568, 0.05031779801356606, 0.05916934511333238, 0.090374335704837, 0.06482949393102899, 0.06808490987168625, 0.06890819655382074, 0.044301225352683105, 0.0229163884796435, 0.02321579126146389, 0.041106238786596805, 0.01733753266307758, 0.043514901335584, 0.04060954161104746, 0.035348579185665585, 0.06521682080347091, 0.018021215801127255, 0.08064054942224175, 0.04380948572361376, 0.02985197374073323, 0.03565015831554774, 0.03601226329919882, 0.017223514660145156, 0.06433700473280624, 0.04504716911469586, 0.040435526534565724, 0.043596110845101066, 0.01717664061288815, 0.0077086948749638395, 0.0019305874820929603, 0.018104596092598513, 0.05323850906279404, 0.020670150515798014, 0.019844886010105256, 0.020289859203330707, 0.024475100835843477, 0.028491758057498373, 0.056909382983576506, 0.06964827363844961, 0.049683113320497796, 0.011451535319793038, 0.025997616794484202, 0.04879481450188905, 0.022966865653870627, 0.016568263199587818, 0.012050506938976469, 0.030575445271097124, 0.031575993925798684, 0.06417880853405222, 0.01773358348145848, 0.02068917176075047, 0.05198643913900014, 0.04004506779892836, 0.14065018011024222, 0.03945215117710177, 0.04579126863973215, 0.045882422928116284, 0.047262943771784194, 0.07862644226406701, 0.0426180492650019, 0.029386595197138377, 0.06978665449423715, 0.02073614414257463, 0.0074951339956896845, 0.014505978597298963, 0.08158191179973073, 0.025703403480292764, 0.05146542920556385, 0.019839562955894507, 0.058785161236301064, 0.018714704565354623, 0.019886208792740945, 0.010624589849612676, 0.03057159723539371, 0.029224601057649124, 0.012508541931310901, 0.025941163476090878, 0.03673880361020565, 0.023921608953969553, 0.041970800011768006, 0.016147330024978146, 0.07064411707688123, 0.014704528148286045, 0.03986431402154267, 0.0125389959612221, 0.03206624554877635, 0.018149523857573513, 0.01049474740284495, 0.025454223687120248, 0.051580870276666246, 0.0232690830307547, 0.016207430999202188, 0.04705222949269228, 0.027182845187780913, 0.0426857294223737, 0.027753733011195436, 0.05263996325084008, 0.012161660251877038, 0.057869625597959384, 0.023017667517706286, 0.04823904237127863, 0.02895646310207667, 0.09708307610708289, 0.03266278756200336, 0.02330882318346994, 0.033334423787891865, 0.0651467101124581, 0.023771589367242996, 0.018116038154403213, 0.06940626670257188, 0.03291521054052282, 0.05752276803832501, 0.07569305904326029, 0.08177317809895612, 0.047253522207029164, 0.016372163663618267, 0.011581651433516527, 0.0027878958371729823, 0.009041099037858658, 0.011360278058418771, 0.008616672203061171, 0.06756928793038242, 0.06015768914949149, 0.028517864957393613, 0.07833051087800413, 0.006064533026801655, 0.010460583562235115, 0.07749454831355251, 0.01709715845208848, 0.05265273561235517, 0.04352834163000807, 0.008611568082415033, 0.006981937021919293, 0.047977401918615215, 0.0037314640167096513, 0.012414900520525407, 0.07104074305971153, 0.04418789569172077, 0.03944746080378536, 0.060961984272580594, 0.06839959532953799, 0.016636950822430663, 0.04613300166965928, 0.039989417855395004, 0.0019550658316802583, 0.03091000544372946, 0.04235081672959495, 0.018154713325202465, 0.06467438506660983, 0.025133441486104857, 0.030718458983756136, 0.060513678836287, 0.035666800977196544, 0.025933895994967315, 0.013759961548203137, 0.0667170574888587, 0.029528924278565682, 0.02514912121114321, 0.040000023145694286, 0.03798851350438781, 0.046627027113572694, 0.07219909457489848, 0.027779541196650825, 0.04533676998107694, 0.029027987584413495, 0.03302646589872893, 0.015655790775781497, 0.005975895546725951, 0.06699449455481954, 0.02845193441316951, 0.04807972924027126, 0.04962897364748642, 0.06401487553375773, 0.06421952275559306, 0.04197282607492525, 0.06537530643981881, 0.02536057392717339, 0.009176912990369601, 0.0334652161836857, 0.006481326408902532, 0.018770120732369833, 0.052806638486799784, 0.03472872260317672, 0.03496655866911169, 0.032486572017660365, 0.06531548191560432, 0.012693038916040678, 0.014841387601336464, 0.044844406947959214, 0.033516186886117794, 0.034158404378104024, 0.04744848069094587, 0.02619049912027549, 0.030542146960215177, 0.08442038917564787, 0.028774822458217386, 0.04641516621632036, 0.01888585124106612, 0.009837497709668241, 0.08715521078556776, 0.03304778780147899, 0.036111050576437265, 0.022518428486364428, 0.009079392930289032, 0.020720367938338313, 0.049536427832208574, 0.028890335888718255, 0.052980564505560324, 0.0642924832936842, 0.02933000272605568, 0.03180048988724593, 0.05252176139038056, 0.03008076673722826, 0.052442295927903615, 0.14901857794029638, 0.11321598620270379, 0.17356904572807252, 0.10426963344798423, 0.15058321820106357, 0.13428026722976938, 0.14592128398362547, 0.10016485917731188, 0.13782164751319215, 0.10300549620296806, 0.18829000502591953, 0.11356659160810523, 0.10408176618511789, 0.09561032857163809, 0.14548208098858595, 0.16397757368395105, 0.0766259164083749, 0.15451004030182958, 0.07763539309962653, 0.123005418718094, 0.19145395868690684, 0.12520742282504216, 0.0795983662828803, 0.10055436054244637, 0.1141265346086584, 0.08707887347554788, 0.10267799385474063, 0.18288958934135735, 0.15723875403637066, 0.2219149944721721, 0.11198902313481085, 0.10980218110489659, 0.12365027083433233, 0.07425655800034292, 0.11728780169505626, 0.1579999749083072, 0.07360407660598867, 0.05845312436576933, 0.17359408579068258, 0.16111469449242577, 0.15531915938481688, 0.09760444969288073, 0.1581944027566351, 0.19663131446577609, 0.15706960373790935, 0.17246180592337623, 0.12678007828071713, 0.13219273940194398, 0.13362769677769393, 0.12494645401602611, 0.2502859791275114, 0.13278516620630398, 0.11653403198579326, 0.08830867896904238, 0.1129677971766796, 0.08573440616601147, 0.08271583181340247, 0.16035342909162864, 0.119014371157391, 0.12813936627935618, 0.26555608317721635, 0.152719208272174, 0.10170905326958746, 0.1953196871909313, 0.16173781652469188, 0.11129443228128366, 0.10694333919673227, 0.12988034082809463, 0.11867043765960261, 0.17466876015532762, 0.08088104237685911, 0.10938637060462497, 0.1323206559754908, 0.1473332496243529, 0.19513606501277536, 0.3775062400382012, 0.07783999579260126, 0.10162198450416327, 0.10108320013387129, 0.07454563194187358, 0.10024230970884673, 0.1332634803839028, 0.12890034966403618, 0.09265422078897245, 0.22692153754178435, 0.09949846993549727, 0.1435535360360518, 0.12363219211692922, 0.16518825403181836, 0.09920757773215882, 0.1050604585907422, 0.11708892096066847, 0.10671148484107107, 0.1702755130827427, 0.12098312567104585, 0.09301470417995006, 0.1044518084381707, 0.10090883995871991, 0.22866622282890603, 0.10186004321440123, 0.10637964835041203, 0.14953370264265686, 0.15390475949971005, 0.12319428788032383, 0.13738375069806352, 0.18184850458055735, 0.08008397577214055, 0.13464200485032052, 0.14939385233446956, 0.10335554499761201, 0.18532113230321556, 0.08173961075954139, 0.09854716277914122, 0.14482551778201014, 0.12020083522656932, 0.13874807045795023, 0.12175866999314167, 0.16189397923881188, 0.17932894290424883, 0.12819234078051522, 0.200709757336881, 0.19106695835944265, 0.09368527913466096, 0.15011517534730956, 0.17061577294953167, 0.11517154533066787, 0.12002238581771962, 0.12540363182779402, 0.12813368142815307, 0.12322584399953485, 0.06937689249753021, 0.16440018225694075, 0.08831198152620345, 0.1639173409785144, 0.13181212154449895, 0.17155594046926126, 0.11589335816097446, 0.16886399273062125, 0.15108666149899364, 0.07264164465595968, 0.15560433705104515, 0.11656632283120416, 0.12306921373237856, 0.1350517148966901, 0.12778442673152313, 0.0985900143859908, 0.08568523888243362, 0.12410673618433066, 0.1267615394317545, 0.17144050681963563, 0.05364197764720302, 0.11833572905743495, 0.0964480871334672, 0.17190935119288042, 0.0935499336628709, 0.1767303721862845, 0.2813806902850047, 0.07767992196022533, 0.14636746316682547, 0.1510486041661352, 0.11845203844131902, 0.201077506353613, 0.1313962516724132, 0.16158480051672086, 0.0776523511740379, 0.15869193855905905, 0.07628441715496592, 0.1347887868178077, 0.13678363524377346, 0.10575049265753478, 0.16286389203742146, 0.1528531065559946, 0.12787208921508864, 0.09364017139887437, 0.06722313541104086, 0.13917842705268413], [0.04443252611963544, 0.011410114202590194, 0.0051346011150599224, 0.06341888642054982, 0.04886725924734492, 0.02614063792861998, 0.03472014708677307, 0.03129094613541383, 0.05066223246103618, 0.013459065194183495, 0.017680269447737373, 0.022197002472239546, 0.008567910317651695, 0.008939383988035843, 0.05094305000966415, 0.034377133852103725, 0.04597873514285311, 0.037721191911259666, 0.02193659769545775, 0.052331682527437806, 0.009290656398661667, 0.043916158319916576, 0.06418136894353665, 0.03722582318005152, 0.022514441297971644, 0.06950505397981033, 0.03555055467586499, 0.0526982107112417, 0.022149193318909965, 0.03159300766128581, 0.04861131477809977, 0.061476800983655266, 0.07454772479832172, 0.027028931181121152, 0.05011401910451241, 0.010749597204267047, 0.05343584984075278, 0.006416412606995436, 0.0668932507687714, 0.028449630044633523, 0.08973905729362741, 0.020717213810712565, 0.03477325888525229, 0.029805264821334276, 0.015297137706511421, 0.0179101923640701, 0.11851856455905363, 0.029066625647828914, 0.06714853472658433, 0.004349988676040084, 0.0031613554483556072, 0.048246174410451204, 0.04224663774948567, 0.019533629274519626, 0.05333744476956781, 0.058749898089445196, 0.057289997130283155, 0.01997699942876352, 0.039683842260274105, 0.0700476900965441, 0.06198264512931928, 0.0707454647636041, 0.039716181345283985, 0.06641181957093067, 0.026150890698772855, 0.015473703915631631, 0.01810783927794546, 0.03146225608361419, 0.038326420763041824, 0.03289199616119731, 0.10233433495159261, 0.05755852100264747, 0.03114080594968982, 0.03616625894210301, 0.039449724354199134, 0.034922048362204805, 0.059649722461472265, 0.03819943558482919, 0.03357071247592103, 0.0016270478067781369, 0.02238063021650305, 0.04096004311577417, 0.034551174903754145, 0.032701523959985934, 0.044607053278014064, 0.03302936027466785, 0.03747905509953853, 0.04393188442918472, 0.04115674935746938, 0.017304735301877372, 0.05685215597623028, 0.02553881367930444, 0.011054685764975147, 0.054571012951782905, 0.019382858263270464, 0.04156733142735902, 0.028374584071571007, 0.07311997367651202, 0.06143365622847341, 0.03415413331822492, 0.05729479882575106, 0.02027268405072391, 0.0472855829866603, 0.020891073036182206, 0.031495838265982457, 0.04240642214426771, 0.01110885976231657, 0.019267766001576092, 0.04087257730134297, 0.051324398882570677, 0.07256458004121669, 0.0356832989200484, 0.015029115711513441, 0.06360663493978791, 0.04702130790974479, 0.03282356272393372, 0.015971897446434014, 0.03661377770185936, 0.026042628051072825, 0.010777097486425191, 0.04745461825223174, 0.060995781677775085, 0.029831688989361282, 0.02879273975850083, 0.061513752516475506, 0.03573981717636343, 0.07068322825944051, 0.03073440402658889, 0.024808273192320485, 0.031138742779148743, 0.008870469082467025, 0.05751899050665088, 0.011806044421973638, 0.045015557334409095, 0.03933717394829728, 0.02063668336631963, 0.06611386954318732, 0.015157177003857214, 0.10325741081032902, 0.06254125968553126, 0.030395058856811374, 0.01675274997978704, 0.1106647273991257, 0.028403268079273403, 0.10083900386234745, 0.029305920033948496, 0.05534200419788249, 0.025824340154940728, 0.06813257801695727, 0.03800149366725236, 0.05884480764507316, 0.02663774328539148, 0.051449573220452294, 0.1017594822042156, 0.03139080581604503, 0.10004811934777535, 0.013361752007767791, 0.07624880890944041, 0.020547775930026546, 0.022253472488955595, 0.05776915364549495, 0.04409456691064406, 0.06989622517721727, 0.04840850808250252, 0.07519412800320424, 0.02025748857704457, 0.02947103675978724, 0.08824467615340836, 0.07569199777208269, 0.03567815583664924, 0.012511094919318566, 0.0665883171313908, 0.03886661521391943, 0.047028287808643654, 0.031116793761611916, 0.04744802055938635, 0.024641948621138, 0.022597172210225835, 0.10449604043969885, 0.05364052303775679, 0.03109819554083515, 0.025236342116841115, 0.025067878304980695, 0.034603366439114325, 0.032853578886715695, 0.06410686473827809, 0.02012137498240918, 0.049474128245492466, 0.044252362349652685, 0.043760188564192504, 0.06583113354281522, 0.06009091070154682, 0.060129031116957776, 0.04685782390879467, 0.052680061489809304, 0.014777157502976479, 0.014454131232923828, 0.07221234933240339, 0.042239654139848426, 0.017998472685576417, 0.05305899838276673, 0.04369229318399448, 0.007441973029926885, 0.015602645580656826, 0.06148919856059365, 0.028988683443458285, 0.05126562078658026, 0.05370730519643985, 0.01229628398505156, 0.05277352385746781, 0.014516646042466164, 0.01578852388774976, 0.04711362736998126, 0.044584239658433944, 0.04285868322767783, 0.03976553416578099, 0.10419469137559645, 0.01551095230752253, 0.0361765970592387, 0.055579053587280214, 0.008722370730538387, 0.019514632149366662, 0.05171711374714505, 0.04390701877127867, 0.013880137521482538, 0.05064582728664391, 0.02923837902926607, 0.10525346151553094, 0.017894508928293362, 0.049662399978842586, 0.08884458380634896, 0.08354682940989733, 0.029512984801840503, 0.03040159346710425, 0.054283337958622724, 0.01284110108827008, 0.02208281006460311, 0.013469925597746624, 0.031255579087883234, 0.027096748635813128, 0.027692565199686214, 0.05793709795398172, 0.07337982184253633, 0.030427017591136973, 0.027797141228802502, 0.0661097357806284, 0.03183191984135192, 0.008943553930294001, 0.05021665070671588, 0.03756476944545284, 0.06879366090288386, 0.04009576019598171, 0.09082717937417328, 0.04546063442830928, 0.032427229889435694, 0.038820728223072365, 0.027503388046170585, 0.04523531468294095, 0.06017261745000724, 0.013202600293880096, 0.022134444989205804, 0.007855561725591542, 0.043330433109076694, 0.028074975343770348, 0.03044672903342871, 0.008965888864622684, 0.0008772692285674566, 0.012006672914139926, 0.04068140005983878, 0.03402000496862456, 0.0423689325543819, 0.057191766463802196, 0.07507696514949203, 0.19019217405002564, 0.015061375015648082, 0.03161405125865713, 0.08335353704751469, 0.04761494441481773, 0.02752288055489771, 0.03960893358453177, 0.04262634276528843, 0.011235792062507244, 0.040041817192104645, 0.05166050272237044, 0.04011484452348668, 0.020367087090562563, 0.028652616711042356, 0.04129576846025884, 0.05947408950305544, 0.057655935306684114, 0.005074900436738972, 0.04543311559245922, 0.026814094271685462, 0.048665179856470786, 0.06402290557161905, 0.023634095377929043, 0.0808283053629566, 0.030012810129846912, 0.014401749522221508, 0.03556184645276517, 0.07044102094369009, 0.017062053011613898, 0.07023013225989416, 0.027248439910181332, 0.04882621477008797, 0.042760422875289805, 0.023640158724447247, 0.07144564398913644, 0.028379536051943433, 0.037005034246249124, 0.12776806979672983, 0.05477731516293716, 0.0403588441258762, 0.062105325851007365, 0.01650244026677683, 0.021093662653584033, 0.007775477033646894, 0.04288747484679334, 0.04082619307155255, 0.06259847927140072, 0.03118813270702958, 0.04155838112637866, 0.030064487727941014, 0.004350612543930765, 0.003278442695773265, 0.00669556403408933, 0.053054953677929007, 0.03267875486926641, 0.027839569811476395, 0.054557312905672006, 0.0510625060996972, 0.07194730613264255, 0.01760360930347815, 0.017490429927420337, 0.03996822953922674, 0.01507521885287133, 0.020478483456827234, 0.07517141828429885, 0.028125890385126695, 0.052980865075369366, 0.004552011014311574, 0.03610769235820044, 0.0747691594006028, 0.05598089315753896, 0.03089960795477964, 0.04901748849079013, 0.03269052904215641, 0.07494759396649897, 0.04355358949396759, 0.020263256919861306, 0.02032289961789502, 0.02375420826865593, 0.07273108829394914, 0.10411290670162998, 0.11601172329392284, 0.19892704440280795, 0.15191157348453999, 0.0967692886479199, 0.11801351080066524, 0.0937964825425297, 0.14681566099170595, 0.2251712416182272, 0.13926122104749084, 0.12121762207243592, 0.12391576674417593, 0.08819240669254214, 0.17527346208225936, 0.11202218971448019, 0.20723038556752726, 0.2053400463773869, 0.19585381087381393, 0.13905683357734233, 0.09579481164109893, 0.11838527483632788, 0.142911622824613, 0.0896103614650201, 0.1628662965958938, 0.14374364458490163, 0.07283189421286806, 0.11690106111927889, 0.16057414381066337, 0.13776007894193754, 0.13553514989325777, 0.10790070969960652, 0.17163429642096162, 0.10873961116885766, 0.16753461328335106, 0.1839726945036091, 0.11396908055758104, 0.08270812089904211, 0.08618036270490848, 0.12074029495124705, 0.18049306090688333, 0.298702921718359, 0.17886032117530704, 0.14969273004680872, 0.07111532147973776, 0.13297177181812003, 0.25183596939314157, 0.11504500173032284, 0.0994379329495132, 0.12455635151127353, 0.0987364623870235, 0.12726766930427402, 0.11074107213062234, 0.1328155497321859, 0.17443229706259444, 0.17702801793348044, 0.11421784845879301, 0.18041807430563495, 0.1313995022792369, 0.17765915516065434, 0.182133637717925, 0.12079200037987903, 0.1976443757303059, 0.1916872157016769, 0.13131856365362182, 0.09187205650960095, 0.1686463356600143, 0.16424207511590794, 0.171902404690627, 0.18930184916825965, 0.16876803303603083, 0.19562987523386255, 0.14908516342984512, 0.14336609921883792, 0.14635897299740463, 0.08302604212076403, 0.2098458624095656, 0.15901098784524947, 0.10132945215445943, 0.12123833541409113, 0.15454193780897185, 0.10545632016146556, 0.14072613150347024, 0.1752348110312596, 0.1963370232260786, 0.11533193086506799, 0.1382055159774609, 0.23589753167470917, 0.10304094117600471, 0.10103805529070087, 0.16983126348350197, 0.08996340853627771, 0.1077937736408785, 0.1667290713521652, 0.1466454123146832, 0.1493213593494147, 0.17472642502980307, 0.27042430476285517, 0.10417856450658292, 0.12087756258551963, 0.17342984850984067, 0.1688733883202076, 0.0993545378150884, 0.10764548511360772, 0.09803303997614421, 0.11318738383124582, 0.08670106835779734, 0.21440201089717448, 0.09318850032286718, 0.13897009135689586, 0.12660251202760264, 0.09505261943559162, 0.0661010378098581, 0.22307370963972062, 0.213764981017448, 0.10576753236819059, 0.06217199668753892, 0.13056534313363954, 0.1903462439076975, 0.08921144224586897, 0.22296446550171822, 0.13594054064014927, 0.12022629831335507, 0.1303710785578005, 0.14629753801273182, 0.14256637572543696, 0.22900897631188855, 0.20957845175871626, 0.12767564272508025, 0.14843370619928464, 0.13928474712884054, 0.16260316071566194, 0.11919285767362453, 0.148430039989762, 0.24332248169230297, 0.19911425857571885, 0.2563235582783818, 0.08510663828928955, 0.09313447939348407, 0.1934042782522738, 0.09770812772330828, 0.09814880759222433, 0.236060373717919, 0.10544647186179645, 0.2086385662551038, 0.13139452988980338, 0.10256615962134674, 0.12551894673379138, 0.17208531440701336, 0.08062996639637277, 0.17688543652184308, 0.09308627690188587, 0.1738985296105966, 0.11342283760313876, 0.14066744246520102, 0.2503884845646098, 0.166220833780244, 0.14577699563233182, 0.17273021105211228, 0.09341390541521832, 0.24764930654782802, 0.16841499338625, 0.17091852467274293, 0.17120444448664784, 0.1701830860110931, 0.21386126725701615, 0.17812080070143566, 0.10182923666434363, 0.09550211601890624, 0.13468216988258064, 0.06982032573432662, 0.12190377470687963, 0.06698392637190409, 0.18412312783766538, 0.11088181301602162, 0.0997502806421835], [0.03715506310982164, 0.034440813833498396, 0.01909582337248139, 0.030794417798460927, 0.06327843497274444, 0.03458395556663163, 0.08816146655590273, 0.013678368904948002, 0.02040607767412439, 0.02349958296690602, 0.04082208157342393, 0.05084840020572301, 0.07761570392176509, 0.021589370917354245, 0.0492269077221863, 0.04201763695164118, 0.03920860057405662, 0.03825213178060949, 0.047595214418834075, 0.054339362686732784, 0.013407891328824917, 0.02781190996756777, 0.04468350191018544, 0.02458987397403689, 0.03996124221885111, 0.020024775185447652, 0.04229638019751292, 0.013141477011231473, 0.05358436843380332, 0.03154051926685497, 0.03143741640087683, 0.07795470955898054, 0.025576861735316925, 0.022113317900220864, 0.035985839131171815, 0.036370987800182775, 0.011063987658417318, 0.04255928230122663, 0.011255735425947933, 0.04603778041200712, 0.03420454369916115, 0.024117227949318476, 0.0414379973517498, 0.015023746273072902, 0.028598966855497565, 0.051836157945217565, 0.03566951723769307, 0.0817589065991342, 0.03953572813770734, 0.038980712997727096, 0.041194532095687464, 0.04676504431699868, 0.0720135131268762, 0.06451710170949809, 0.0338505986292148, 0.05886709062906448, 0.046624318274552934, 0.03141907051031012, 0.0791909420513548, 0.01987462572287768, 0.1122126544942148, 0.01888641156256199, 0.0377588744595414, 0.0464595540688606, 0.0417417806602316, 0.1023357079247944, 0.08511480933520943, 0.1408006579731591, 0.03218707090127282, 0.007673678028368158, 0.0031859546288615093, 0.06736248848028481, 0.038824858274892904, 0.0382807898131432, 0.01624719712708611, 0.04339347855420783, 0.018228319531772286, 0.030650635962956585, 0.027673137628880795, 0.010091842850670218, 0.018352992919972166, 0.08914808509871364, 0.03321274125482887, 0.012521391290647443, 0.03418016785872169, 0.05578483258432243, 0.017092276975745335, 0.03687093558255583, 0.08143718558130786, 0.03508103865897283, 0.04670441827329341, 0.020202111372782383, 0.02720459011470666, 0.032161800772883, 0.027295287982269656, 0.00986716599072679, 0.006561746922670864, 0.055011061995173804, 0.02137150975613622, 0.03192045434843749, 0.01305350746406475, 0.03368721481820103, 0.03236759832361713, 0.034936356969410554, 0.026040640950668603, 0.050318777648499236, 0.03496187571727205, 0.08420348167419434, 0.028198212676215917, 0.013932131460023811, 0.03506543129333295, 0.010219424530077958, 0.02821227451931918, 0.030593856099585537, 0.024882144716684707, 0.0404446067113895, 0.02766261026408756, 0.03120151362963952, 0.006730907889505033, 0.012770694465871202, 0.038195298111531883, 0.02084616011416074, 0.005248342667982797, 0.03450445299677085, 0.030411490006372333, 0.055858156774775125, 0.085552008531522, 0.033162598047056235, 0.04197784299321938, 0.010659559848136269, 0.06238264046260156, 0.02374455849349033, 0.021350397510104813, 0.03324969278764911, 0.04410628171171993, 0.01935999269335298, 0.010968564165523276, 0.022819868463557214, 0.15582180116325617, 0.033889401820488274, 0.013281044375617057, 0.06424566119676456, 0.055356082739308476, 0.04068432412168477, 0.029067317700537387, 0.05305285711074248, 0.04592020937707275, 0.02315756235475419, 0.0038732582879674737, 0.038445654208771884, 0.014669868924102047, 0.027794187481049448, 0.04460241485503502, 0.012372381024761125, 0.021187492384342477, 0.047467097465414554, 0.05453792429761961, 0.0993573950836435, 0.021275661383697297, 0.074516413587844, 0.05818025892949663, 0.0419953020173125, 0.0820331450086087, 0.031597672059433535, 0.02868050662073074, 0.07498816717998125, 0.08518706483300775, 0.03477060941804666, 0.08683901134645566, 0.03159161984513048, 0.014551406384271104, 0.03045734545594314, 0.08430452508036979, 0.03217922640033066, 0.011901913203473669, 0.031766195243108086, 0.021731887391069904, 0.03068144251301419, 0.036857881204923615, 0.06523889227537438, 0.056086111144395545, 0.026776949780469295, 0.031392531309393235, 0.016555854490434285, 0.07416750027914532, 0.04286374467483256, 0.015119626186788082, 0.10667337555787526, 0.04322220942412969, 0.02685589945031097, 0.04850477576837875, 0.01811675803764956, 0.05072376021416858, 0.006329232983262045, 0.016050694976001978, 0.056635489672771655, 0.01734050310915336, 0.049066748542827554, 0.037606489277095534, 0.03930982951715123, 0.052667875424958766, 0.04503914278757293, 0.08040902903303504, 0.017807467993407045, 0.01929312333231792, 0.054859641604707576, 0.01850411088526016, 0.0555380907462677, 0.03452144817856606, 0.09448124736081809, 0.05459216044982895, 0.06791469830204733, 0.034401943848934025, 0.047627234380343, 0.14429096365347505, 0.06007576346746646, 0.03834174611256458, 0.011271801995462738, 0.05891782384424005, 0.0272574328846531, 0.045922877397970296, 0.047497395644313656, 0.03501971128571313, 0.06220847695658449, 0.04224080446874723, 0.031004803677205928, 0.008977225170383463, 0.08194245456252247, 0.07247633126098663, 0.06139732438896317, 0.02526767559174914, 0.0643642563954927, 0.06255547923501581, 0.02013661684031831, 0.0394248327211244, 0.028097145150240976, 0.029234230423753615, 0.05747309980506543, 0.018162249834858812, 0.028136542059655767, 0.03192954565747641, 0.026760461114463396, 0.014149656799418153, 0.05223977866990026, 0.028405002849467564, 0.08824027521768585, 0.024568431472289376, 0.054225283456617035, 0.02184502409363631, 0.042889823744189925, 0.03795204065681901, 0.03241742611862719, 0.02655747073731618, 0.0032479183937539347, 0.02793115454551298, 0.007662867719773203, 0.017468913210905157, 0.029724747364525683, 0.01731720523821423, 0.096346145728603, 0.016358083266823087, 0.0229033749201335, 0.05949663223873358, 0.06652451469562948, 0.006285404524533078, 0.04701906662376132, 0.04706325780716725, 0.03188272727129515, 0.04772473774210084, 0.049043062899727374, 0.07198400533525273, 0.06557276225066744, 0.07284499311936088, 0.04178083618171513, 0.02348087899008533, 0.05967984252492897, 0.03748460265342146, 0.07787758557242341, 0.033239736876566894, 0.03215283933968749, 0.0730339958681725, 0.06032423822034616, 0.0352841941639781, 0.03408867589314468, 0.019523012852005195, 0.07389109479845501, 0.0036121602988714585, 0.01104503135138657, 0.03065343014895916, 0.043686526696546935, 0.044857650573248975, 0.04931650350044947, 0.01176340896563488, 0.02753809829300735, 0.03099821897194488, 0.016081822504929733, 0.059118589633726515, 0.030947073864808772, 0.047945845799404196, 0.0342849813750945, 0.038085567866801284, 0.028993240230192896, 0.08922579538193531, 0.03161694192385767, 0.014543430152116343, 0.07053145163808949, 0.06256662629311904, 0.02617792342789471, 0.013761711161350831, 0.025622284883866087, 0.032792793281259947, 0.05285717503284104, 0.02042078889644472, 0.01619207967451075, 0.10570359634584747, 0.011376537586329505, 0.04837361972022336, 0.042443796701263636, 0.02796464024868328, 0.009874105071503436, 0.022816372948000208, 0.02782603489322355, 0.05741527165810112, 0.03529866604367271, 0.021471493746503256, 0.03761107203899883, 0.014386503025889397, 0.04972358263330534, 0.10996279670507647, 0.0658482474682387, 0.010397547393949935, 0.030403539749386255, 0.047606966327293776, 0.048460610560141504, 0.03303584293462336, 0.05571361609327141, 0.06498933769762516, 0.06114952499046922, 0.05690250327461399, 0.0418558264937019, 0.0276564708474325, 0.08786822174442932, 0.03812025213846937, 0.037717781742685474, 0.062257195240817964, 0.023088498091965448, 0.01575651505845599, 0.031105260786716826, 0.08343065361259505, 0.038192971478565596, 0.02542851940233959, 0.03310539701487869, 0.1288562364061363, 0.172373371606227, 0.11652872562990524, 0.10868360128370114, 0.18069109559291974, 0.10137951001524925, 0.2619895589305088, 0.14248429419239983, 0.10060239976155572, 0.1669628033414483, 0.12754060153383762, 0.2581040299264714, 0.11559521517483518, 0.09625516584492289, 0.12767506384989247, 0.19984837621450424, 0.2089825813891366, 0.1254152983892709, 0.16454773605801165, 0.25623212568461895, 0.11277637502644211, 0.18408242845907807, 0.14378763909917325, 0.13297413184773177, 0.16608831589110196, 0.05958029083558358, 0.11346539235091768, 0.14152489020489156, 0.13570970302680507, 0.16004989069188014, 0.11594164228881709, 0.2568044402869418, 0.1293139040353708, 0.180574711994268, 0.16219431156059727, 0.07974083637236618, 0.1170360206742771, 0.16022549767512828, 0.18549289496149868, 0.1297658125986345, 0.18880894436733797, 0.08812550207949243, 0.11596893848036416, 0.14750489353900775, 0.13617553428048268, 0.10327879208489321, 0.17759200563887134, 0.1363731236779131, 0.080295324587496, 0.20313928165705875, 0.15530909586232156, 0.10858365625608712, 0.1617606746731326, 0.2247840928612277, 0.1193477216293104, 0.1355439962935634, 0.1371636742260307, 0.13150525832315907, 0.254281583474949, 0.18755603581666946, 0.2638191607547924, 0.12458866462111473, 0.2284885972039774, 0.19360982347279787, 0.17425980709958822, 0.13414089189609513, 0.12517836032202467, 0.20965444768080488, 0.11819187857327051, 0.14463956526014954, 0.17889871989609674, 0.1415114276460372, 0.16751890943851322, 0.14053940714802593, 0.13142215262632817, 0.1881015143590048, 0.1286431064363569, 0.09730278892675415, 0.141241374949459, 0.18450104427756742, 0.13540634274249896, 0.1646895011072047, 0.07118969951989129, 0.13397144473856315, 0.12887683842564002, 0.07585399376694113, 0.0727534937323071, 0.2361959492554888, 0.1412752317264676, 0.1157183300529141, 0.22136734885862097, 0.10745075298473239, 0.1610089384485036, 0.1181564484431874, 0.19318129256134853, 0.14412596938200295, 0.21130250534042716, 0.19460951123619452, 0.12989169568754733, 0.18180731538450345, 0.10340116481529549, 0.20127183030126616, 0.12831341475248337, 0.16128924762597308, 0.12474503513658419, 0.14119147293968126, 0.08902868095901795, 0.10984061693307012, 0.10934249483398162, 0.16369103046599776, 0.12268148610019125, 0.0795354024739936, 0.11250860814470798, 0.11798216248280369, 0.08293639810290188, 0.14632468577474356, 0.12892993167042732, 0.09811270952923223, 0.17065253894543275, 0.09969402584829368, 0.20878726296359673, 0.1115260120423045, 0.1008222164819017, 0.08327299918164499, 0.11864790605613962, 0.1369577579316683, 0.13914246257627383, 0.09772315621376038, 0.17440458526834846, 0.13532914454117417, 0.2380369504680857, 0.13931247376604006, 0.1181627566984389, 0.08691145980264992, 0.12358303225482814, 0.07762866924167611, 0.054593047316302545, 0.12267622427316383, 0.3430561604909599, 0.0905759549641516, 0.24932023719884455, 0.12605744908796623, 0.19963408849434927, 0.1061153547198046, 0.17384055303409696, 0.1681405323324725, 0.17297522368608043, 0.11918499090825208, 0.17981130920816213, 0.15299136866815388, 0.07180312168202363, 0.10581273658317514, 0.15881204773904756, 0.09583863546140492, 0.14589757978683338, 0.28470791643485427, 0.09202137662214227, 0.1645332493353635, 0.17003902030410245, 0.11598504308494739, 0.22971187921939418, 0.16721215011784807, 0.17029437847668305, 0.14405742462258786, 0.15201214933767915, 0.19012420816579834, 0.15253021294483915, 0.09195998616633005, 0.18875276378821582, 0.14169286791002378, 0.21471976884640753, 0.19300755579024553, 0.16319178772391751, 0.10783114077639766, 0.13538942177547142, 0.18566611222922802], [0.022062989155529067, 0.0487385003361851, 0.062353637331398204, 0.02729666837694822, 0.02278580574056832, 0.08308860516990535, 0.04229292550007813, 0.06102540821302682, 0.04608920011378359, 0.07867034772061743, 0.037776389144710265, 0.02759791910648346, 0.07737961190287024, 0.021287261151883285, 0.054693793863407336, 0.04363054649729747, 0.07977452987688594, 0.08050788310356438, 0.037372349106590264, 0.03819381752691697, 0.014333418130263453, 0.029345153670874424, 0.06810463615693152, 0.06175196707772557, 0.03734896774403751, 0.010223577774013393, 0.0729494058759883, 0.007240936820380739, 0.005315201824487303, 0.10123221596586518, 0.009979238639061805, 0.04131465240789112, 0.14108795818174258, 0.044470516659202985, 0.03328759798023384, 0.08851118880556896, 0.023516531764471438, 0.07455178434611298, 0.024942433083197102, 0.05330250445695128, 0.03897993374266662, 0.028524525732791517, 0.006253873916648445, 0.07454243328538723, 0.007641825513928779, 0.003194162782165222, 0.02642315685079666, 0.03696306579513475, 0.04152135537879076, 0.06551463724463247, 0.011981228381046094, 0.011133489788335282, 0.07069772982504219, 0.03564630285836756, 0.036824120907112956, 0.02860835873434553, 0.020186244255455676, 0.03343109965499025, 0.03945562071749009, 0.028486776391218882, 0.03408677970583085, 0.01994134479900822, 0.03039770646864781, 0.008465813989460003, 0.019899832768714987, 0.024167022347683087, 0.021229126869002357, 0.07702134011196904, 0.02679864461242687, 0.03310027619590983, 0.15364341961685568, 0.043369028499000706, 0.04981738267815672, 0.04514939253567718, 0.03505586500978097, 0.06519624846987426, 0.01467446745664347, 0.07747502240817994, 0.03336537134600803, 0.05014233203837648, 0.027125872366013937, 0.01969633587577846, 0.015231864890665747, 0.033692617653287016, 0.046284796844702214, 0.04601294072926976, 0.024780962157819886, 0.011518941810209071, 0.04403141014336143, 0.008317598749272292, 0.10273692780174315, 0.04577838866680395, 0.030660458287457004, 0.01417908852090477, 0.0305426070917747, 0.02929015867266571, 0.009879777862806804, 0.08074492507148534, 0.044977102952543646, 0.04614679819496814, 0.039282637226278894, 0.03389213663467672, 0.03186164656654, 0.02302143762790365, 0.052528592859744094, 0.023943873384268954, 0.06933514669071883, 0.017676966890576296, 0.02346030480111949, 0.04256674088537693, 0.07423623057547957, 0.04039667510369327, 0.028934664369444363, 0.09910748427500948, 0.047224055233527906, 0.06303374146227725, 0.06436122843297198, 0.03370369791809935, 0.04354292483185418, 0.011255010904278606, 0.026996540145773906, 0.04494329070439562, 0.06953528165468015, 0.07109707206836902, 0.04778607253683731, 0.03698747132148128, 0.004136194947932381, 0.010938431114482228, 0.02898353664932074, 0.11346521423547529, 0.03846769599476829, 0.03573410263925325, 0.038519189911312424, 0.03078915411606431, 0.059944993336102925, 0.020170473617326934, 0.025524059783492703, 0.033036844833986834, 0.002859545788851392, 0.0504681088932557, 0.0201118977565784, 0.10413810261525214, 0.03585520258639008, 0.01344101337963366, 0.03184154920745641, 0.06847188051324338, 0.033010591359925456, 0.045452530175680295, 0.02846540624886984, 0.010249881343042944, 0.011568318750505568, 0.02974758139316691, 0.050576269495650195, 0.024963703035609797, 0.029657319537363946, 0.03524474159348756, 0.06384259337210096, 0.07665986224310473, 0.07662432079087012, 0.019829373268294148, 0.056680623383726925, 0.04098651552340016, 0.040015960767050274, 0.053165533681749366, 0.05118075991049409, 0.04147100065893028, 0.02481879128026776, 0.014633727259933949, 0.020939739370078314, 0.024370832798012998, 0.040001937886700034, 0.015581887710141018, 0.031589259815518744, 0.008563355386286275, 0.02314350422238931, 0.06845216907095164, 0.02215890803199727, 0.01953810813574819, 0.023876783234300092, 0.040059317034319974, 0.023312389203056227, 0.022550405774381943, 0.015472454324481077, 0.024926521437009797, 0.03602634555136319, 0.07294464128790423, 0.04641043873562012, 0.031218453150358982, 0.020686826574092265, 0.044469002677942626, 0.060795335011789575, 0.024454072081425693, 0.014939134944143007, 0.04652151226764545, 0.011787148414441617, 0.019300954845675733, 0.049861180523294024, 0.020680444104073104, 0.011563809275685344, 0.010606944360915804, 0.041441055000177585, 0.017719369498081505, 0.042569201104925014, 0.051394787878962234, 0.031235110654961318, 0.040921904146671295, 0.05343521901522763, 0.03789566340856254, 0.055284873669734225, 0.04786983132362366, 0.017302004198427312, 0.03318632450827863, 0.0475863568863133, 0.0227022399121779, 0.04790658989804797, 0.1105541770812124, 0.0271120257457369, 0.017565366433700547, 0.09797919716220349, 0.06640086547122337, 0.02576947874331381, 0.01901224455650663, 0.03268111489887815, 0.014619678404415026, 0.04974105650035199, 0.056011232154560275, 0.051371195004321635, 0.027266078905086033, 0.04703411366790533, 0.04665388914872892, 0.05869381027878262, 0.01821384023060091, 0.024418107605015393, 0.05130150733748451, 0.04638037062250078, 0.05708565789973363, 0.04559899301966652, 0.015257755640050163, 0.04508057318162173, 0.04686517488153186, 0.019582616587285884, 0.07039568314212374, 0.03685585885250475, 0.015452032275788952, 0.06351193689624779, 0.018675710271054413, 0.050305029362789355, 0.037894887864240445, 0.003211963426110742, 0.05327143815520685, 0.021125719722476788, 0.026074542256537825, 0.06849037483334541, 0.09442062873858958, 0.01710586013359716, 0.03805479471338913, 0.06159824231872335, 0.01348137508102809, 0.10496790535398759, 0.07714089268120006, 0.06069473318348173, 0.024892724031815305, 0.06704249666654505, 0.022550847352249548, 0.04772752079588827, 0.03156063517963048, 0.07595590548589826, 0.006711460837323102, 0.04260657195118256, 0.041702187081682496, 0.027012353457394056, 0.004861347906626179, 0.0711569856503047, 0.0196318562302622, 0.04122771722904872, 0.06492331624031067, 0.030603698833147064, 0.09517374535789713, 0.001720848199511238, 0.039107382763177156, 0.048166337874135934, 0.01593514814885566, 0.08871105659636669, 0.017899147351272404, 0.024729156539251562, 0.08705621570697986, 0.0461582717980491, 0.05616157272015698, 0.12547521939268336, 0.1218389777932316, 0.053639331890735775, 0.036371540700201876, 0.045883892380516045, 0.040308374373125844, 0.03487868467345834, 0.03368884754308965, 0.02134398906491697, 0.022162329332786612, 0.05031410211813636, 0.054814114555483684, 0.06019908243615646, 0.02061582159512909, 0.024507744201400783, 0.05934857006650418, 0.010889146942645311, 0.1242850445851218, 0.02275454462505877, 0.03880548079905566, 0.06181634838867467, 0.024900160351535305, 0.06366797344526276, 0.046422242594417185, 0.06846660384326242, 0.019798210487351753, 0.04839618100959342, 0.019412245455896482, 0.049292190742562525, 0.005854563678440172, 0.01134802612796193, 0.03197292047843803, 0.05026919476222247, 0.10117905592778698, 0.026720579953689594, 0.06962396088056266, 0.0880138311185874, 0.006391165206878213, 0.034990559724974446, 0.026917163741018157, 0.05211237417825032, 0.07900965021690354, 0.03611121755966451, 0.09258238089387305, 0.053206340671749786, 0.04953534800733905, 0.03748311835806817, 0.04162353427091148, 0.03808286644925829, 0.015353925919043832, 0.019723043915291782, 0.03970342382672243, 0.04598643121425994, 0.03422648529522121, 0.024881927638489287, 0.030617066768172663, 0.04382900049677119, 0.06287290321779437, 0.016220620818785392, 0.02342145893635461, 0.050275985413463786, 0.05529899674002081, 0.02785023818432819, 0.052860885771224275, 0.11636933457339182, 0.1356663616024889, 0.2799450798192993, 0.14088113646721467, 0.10737385906395502, 0.12922189256642014, 0.09642644610721618, 0.09073467066627927, 0.2154721730039455, 0.15025232423795387, 0.09802554428461008, 0.1242032005393412, 0.12326131865847856, 0.15394918445963413, 0.17396977578755468, 0.1371718230075203, 0.17217110667843372, 0.14806022780248895, 0.14788165222853422, 0.1263348787324503, 0.12297662338824011, 0.14041205460671335, 0.18068872072035447, 0.1270850861328654, 0.14303278585430235, 0.11716015971614979, 0.27938662853557616, 0.06015034559823107, 0.15892250899923965, 0.17682624282315373, 0.141708972514607, 0.19721945165656507, 0.14931316603906453, 0.17854855977930129, 0.06800049799494445, 0.20467558671953157, 0.1048608950804919, 0.15798453823663294, 0.14203455270035192, 0.19755902874749154, 0.0808950095961336, 0.1492481242166832, 0.12878641515271738, 0.1806892253807746, 0.07226447036373429, 0.15533919737208635, 0.1019974666996859, 0.17117602023063228, 0.16356989712221548, 0.1607074186904356, 0.11860201164381579, 0.09322852434706874, 0.12168101908173412, 0.09102554802666418, 0.10050592798506841, 0.09571211412549019, 0.07432830141624436, 0.1379698544042185, 0.12366754803224467, 0.16910136124351993, 0.19312285585328937, 0.05535807169508189, 0.07542339226347394, 0.14176013617543504, 0.10463964601512998, 0.19732752320123836, 0.11230351563426666, 0.11535167199326679, 0.0908461635117419, 0.07420328664011322, 0.27931107790209353, 0.19651935406727716, 0.09852207076619379, 0.20834289462072775, 0.08983439358416945, 0.09781337910681032, 0.19731886975932866, 0.2572139276890084, 0.1685274436022155, 0.13365018385229632, 0.14542949240421876, 0.14729951159097254, 0.18861929595004767, 0.15549633972113952, 0.11005484528141096, 0.08549374993890524, 0.14712380070704967, 0.09514472738374025, 0.16887769277673215, 0.07941956064314581, 0.15454833512194455, 0.14412708260351792, 0.20152708457317203, 0.11093404536950402, 0.05940302515227813, 0.11563768828636967, 0.15188761695753783, 0.17692131194053218, 0.1226686840527691, 0.1748478107037954, 0.11583790488657542, 0.21476688038092107, 0.1441513656754978, 0.2661941520636901, 0.19484410411678255, 0.11332192036206834, 0.22534561663633212, 0.14489701628917828, 0.08044851871090941, 0.140264515648596, 0.18629379104822874, 0.1471175072947517, 0.2339314340497367, 0.27663483400829136, 0.18090214754920453, 0.092020018491894, 0.2990317525109276, 0.13031304260948673, 0.15477240434847772, 0.12190563749754801, 0.13261283951578662, 0.13620940590044484, 0.13699044211534783, 0.12875279586296529, 0.18813498521922156, 0.15356251067714766, 0.0954181123233866, 0.12372244469588622, 0.06512342893984169, 0.2258083753986284, 0.08805002566077746, 0.09828310663579032, 0.19693394744535908, 0.16141406202223152, 0.10277736742864363, 0.09289509223890491, 0.19146684237057343, 0.09585583844454959, 0.0894740289368201, 0.11654647038085386, 0.14431168441660702, 0.23193550208816305, 0.08619243744760752, 0.0788141907833051, 0.11530913950991817, 0.17285976035054773, 0.16784652310889214, 0.17545481328852475, 0.15146192105021328, 0.10386312947957776, 0.09843788895523176, 0.1610289022210054, 0.12225901111378334, 0.16428945382358506, 0.2318841009400785, 0.14583470503566787, 0.16739660350140184, 0.2557459595846012, 0.20152586745098233, 0.1370376130216755, 0.14140792773105204, 0.14871616760501638, 0.07593022717628628, 0.1311302511021495, 0.10780688739032485, 0.14930844597984105, 0.16596931993262842, 0.09932511165970936, 0.18380020454060286, 0.1013927573512774, 0.13166216318495572, 0.05330918749677949, 0.23738583462545648, 0.10901975707383826, 0.08620355481980368, 0.2828043373301625], [0.005370105909605627, 0.03859602817101404, 0.07417514440021478, 0.01792261035006959, 0.02747810307482723, 0.013356889085116563, 0.013109781739331083, 0.07709890938713215, 0.02343015505175572, 0.05357398207706865, 0.015610623668180779, 0.039610993044334464, 0.03065305350901326, 0.014780400688323425, 0.0736881025659386, 0.031714185533928685, 0.07842765058740042, 0.03458938066614792, 0.05059758768766187, 0.03501360712107271, 0.05663261385052465, 0.11689203660353087, 0.018738460712484084, 0.031100000815058593, 0.027861279486387502, 0.040885286580305547, 0.02123715319612529, 0.018893294982262887, 0.056612661210238, 0.06420444973628037, 0.0151493009616388, 0.028930194785061758, 0.03695770377817098, 0.021849458426004276, 0.03842198711936362, 0.02190624571085209, 0.029263198302942328, 0.05188031944271643, 0.033411748154321685, 0.08239091956056654, 0.03743406239664182, 0.028803185487049632, 0.04161600147199351, 0.04264678151230328, 0.008456309860775946, 0.050112427197746, 0.02072341630992014, 0.09205441703670658, 0.028000554630125407, 0.053229428885970265, 0.03646108823886607, 0.024894568268791772, 0.05976247324724682, 0.03350762992340606, 0.05499610771948937, 0.042932764408760704, 0.008358969771506963, 0.04157432616921142, 0.030631436602561735, 0.043713206905522384, 0.007508912431148929, 0.050028245386783965, 0.021456795511767268, 0.035104063790640794, 0.025111362592724618, 0.018858004004869144, 0.03305563972389791, 0.04238729699864052, 0.034336453027208336, 0.013076810901111457, 0.024098408939607907, 0.08144749401253648, 0.056616037982166745, 0.018968550612044055, 0.038631732895737514, 0.06957414792850614, 0.026911996537819505, 0.031797131669009104, 0.013147650752216578, 0.010961616735585267, 0.06040041596861556, 0.048346323528676294, 0.0406552356434986, 0.06426328720408492, 0.01591717518749647, 0.027303525821480434, 0.0782549602445215, 0.013135232766217086, 0.003313474617243628, 0.0825758404971566, 0.021784134587505832, 0.05168328294530511, 0.013332344406080665, 0.03493821233860217, 0.013532044285966549, 0.13029169844230637, 0.021195670851739123, 0.04942390711221378, 0.030360114833456464, 0.018071379417960998, 0.03982157744758297, 0.021956008567940444, 0.002914703595706669, 0.03397447791940067, 0.05514720156497788, 0.0455916939972667, 0.02797932735120412, 0.06697627482935786, 0.05815921162138693, 0.05305670514644589, 0.07137073902413249, 0.046523527198587544, 0.07438181768520735, 0.012807596831407864, 0.04559065870125778, 0.08527309459168464, 0.02616075384139549, 0.06670958406175487, 0.006888548869028455, 0.023197478767542634, 0.01389944078255212, 0.01785308038961375, 0.0602874017204158, 0.012537480124592548, 0.03434306927374564, 0.04713272282970138, 0.08107791189104319, 0.023297282787098084, 0.04423586811753921, 0.0640557159204036, 0.017517316082376055, 0.014376112030731747, 0.06106152854044922, 0.03769312388612889, 0.02720144340855768, 0.09387504629557952, 0.09610922250431031, 0.009793403005460277, 0.061910972217447124, 0.06153001668280922, 0.07798366073984653, 0.036056988828931935, 0.03037893198779784, 0.050772125978255644, 0.008804157259874046, 0.07578422446385957, 0.04099831196072046, 0.036048988476977684, 0.03754756646230817, 0.04727856969111599, 0.014962346540414728, 0.08522579752025194, 0.013344799499463988, 0.041763536719372496, 0.025326717150164768, 0.03982083158916794, 0.037486762303160504, 0.08477103168843314, 0.031530173728242517, 0.04413990842294879, 0.02820289933879394, 0.06294390448601916, 0.10143864434212446, 0.05629597195365932, 0.07126433731173165, 0.017005176669044886, 0.0363265405758284, 0.07130693658837117, 0.0321554479887709, 0.022509557966259308, 0.031452470866497606, 0.029829789091309067, 0.03317400856758468, 0.035330389146110974, 0.02709629221499199, 0.025553476662025787, 0.02646398981596576, 0.07846164095099084, 0.03206620844139252, 0.10701818478992209, 0.009069277457456337, 0.061679726422880776, 0.0211169308386161, 0.037910265164100565, 0.03854097936709877, 0.010054193699033931, 0.025148184249701444, 0.014618951099691913, 0.0869167735800147, 0.0370201109763002, 0.09388431572006084, 0.0336857156798942, 0.02473128835845273, 0.013632796399178915, 0.035719623338081874, 0.043098315290990286, 0.10148274275707081, 0.08578070875955746, 0.023412859300151467, 0.04716349227237515, 0.029815146517648827, 0.015135094399738591, 0.04256805077602621, 0.030292970877781045, 0.02031569336395478, 0.03976911131758243, 0.05157774954568595, 0.010504358215257525, 0.04367893452581484, 0.017064667226804886, 0.03347038153151516, 0.05696271371562034, 0.06320829459582455, 0.05045046433224343, 0.02771925283013843, 0.0640246421971824, 0.02033093336649472, 0.029024453106103465, 0.03876354945532512, 0.005495831755979452, 0.03462006847257726, 0.10102612897753716, 0.029924347982159816, 0.08713129136594944, 0.025286652307840995, 0.04982515296433121, 0.025364344037370756, 0.04107813736482058, 0.026553926982160192, 0.03154422258376144, 0.03264042294176761, 0.016903044161153957, 0.022071544262871612, 0.02416019644442713, 0.017205838557856623, 0.002646978227858199, 0.04211533327179495, 0.020677527463703882, 0.02877664072002517, 0.020588171028066427, 0.047561784376739524, 0.04050609735713806, 0.008139005549310241, 0.05379298985644709, 0.07538816993474029, 0.025326642935397103, 0.08508695653290488, 0.060677181390929036, 0.01515139474577154, 0.0298765685147373, 0.01588115505001042, 0.030472728321910836, 0.1088372035883367, 0.09085788944503292, 0.032305543645634316, 0.01263392407054198, 0.04757554750540294, 0.017912186885951087, 0.0638116903428454, 0.032511831013835035, 0.05045178535510786, 0.02276399030961329, 0.0711881261668168, 0.053671797140850686, 0.03531327150994912, 0.00998290021016146, 0.03966519951063674, 0.014251483171392465, 0.020237836506566964, 0.01148275190644199, 0.028414504195097834, 0.06091728471801616, 0.007015117516857572, 0.0497574542532675, 0.027597009975579567, 0.00997471803202643, 0.01585142090334557, 0.048243031415040605, 0.04191936175629962, 0.011927392060897546, 0.0511885264859302, 0.043303585916874, 0.01822104833991034, 0.03602715449233074, 0.06775968591682613, 0.047384633726323955, 0.04875161779636983, 0.03345355704368558, 0.027775489070336334, 0.007867884160077665, 0.027894091690541245, 0.1007453077181708, 0.04219495829602238, 0.05046355210652109, 0.04229119629599154, 0.042778186179930344, 0.02507648907339899, 0.068628436565632, 0.038662903098156676, 0.025101595929299947, 0.0320037344499724, 0.059785650519188493, 0.09788855866645463, 0.039672127459198236, 0.03441436369030271, 0.06297054016613401, 0.01781893788574962, 0.042350980002083816, 0.040517923480365425, 0.013196947911637835, 0.06460863078245893, 0.024626658523629885, 0.015860035382502247, 0.10434621566673741, 0.07213100252556615, 0.055068890142138116, 0.03392414546397049, 0.04117649790714495, 0.024258746234409045, 0.011585727679630509, 0.02359673937462503, 0.028443024930311367, 0.05289853492286056, 0.04830927551665809, 0.02470661380357342, 0.05946206671069376, 0.034823368696379475, 0.11613631504587829, 0.08124393032630906, 0.0341808951634448, 0.03899342227668967, 0.04120642501220573, 0.0273320836640778, 0.025614535006752703, 0.03317078764666803, 0.027841417759191245, 0.06406327098375186, 0.03082331702898955, 0.09349900006782264, 0.02585939921118552, 0.044371777621563524, 0.01038534277540748, 0.05626758480502758, 0.004814543899556156, 0.03873542205838021, 0.043929479870712385, 0.010269172544212779, 0.06040902117092628, 0.026138862340303604, 0.06243714378797449, 0.017039879494404886, 0.09952348031220026, 0.11989313337835483, 0.12638105516089126, 0.1566502606146969, 0.1462625531712547, 0.09239931532647461, 0.14161172148305923, 0.1725517987506464, 0.18378055247012526, 0.13424569799099118, 0.19238579930970445, 0.15436670189956203, 0.16631664504529908, 0.15168910729698837, 0.15424678567796946, 0.24295033916132525, 0.11904450235306285, 0.19747307320358232, 0.048870962564251386, 0.06788674902054481, 0.16350574587704614, 0.22355315188178793, 0.19379058096092194, 0.12654649472096935, 0.18948898912640288, 0.16914842824917287, 0.10999159945640713, 0.10401207851828076, 0.11375785790733062, 0.15132993750739843, 0.12262479343917221, 0.08477550683892332, 0.08339565392816439, 0.18123175017535686, 0.25611783494241536, 0.12466308719012886, 0.14248625346226618, 0.10096220779814757, 0.1976894389372319, 0.10322250018361956, 0.22651939740171656, 0.12203280450194143, 0.09087803133297712, 0.10690319642890245, 0.087148561142385, 0.08917811981518753, 0.18673689774004743, 0.0822076313488651, 0.19299164414405823, 0.12322971801040694, 0.17459174006944522, 0.10572064347798005, 0.14771572285098955, 0.1633078744634986, 0.07774450365104713, 0.18556967756012455, 0.07146947435103357, 0.16372997837606817, 0.15247305273078382, 0.12254643006599508, 0.12873798259533942, 0.10960355270071886, 0.11537929472979158, 0.1835773524362594, 0.09272522205719724, 0.07856822820031084, 0.08459020740701817, 0.12814580812118948, 0.15972444409271702, 0.1409714706824161, 0.09064581332495436, 0.23028677649563178, 0.13247984665213153, 0.18414430873235688, 0.154156896751374, 0.08809602397377603, 0.15957353578414768, 0.2598861639853567, 0.14585248689400032, 0.11021540150977671, 0.12194722003187053, 0.14672526740469038, 0.11112326334114186, 0.12300766742555425, 0.13843240536516532, 0.1218193925160449, 0.12246336147654802, 0.12474184390157461, 0.15572205651551485, 0.09256640245439485, 0.14356045285239816, 0.16356430132873356, 0.11237606799113564, 0.0968756532529369, 0.12968883704161271, 0.1780023836181499, 0.17499543871963397, 0.08666704088682309, 0.18259997363202274, 0.18183228123234585, 0.13933951762737706, 0.14431123912800103, 0.158944521099329, 0.12071452016243711, 0.13066219340544194, 0.16207599837798625, 0.17374535033013672, 0.1561436557676643, 0.1671723710023798, 0.1621413667453453, 0.11119065777165815, 0.17643793631577864, 0.15345381572842598, 0.1443905895575881, 0.10249675397062674, 0.11181121939443983, 0.21320676722098142, 0.1284220948582515, 0.1414064731216058, 0.1261525330482982, 0.12106943744583987, 0.10391456773504615, 0.1857978879706934, 0.15612740273354575, 0.11184731003595516, 0.1321685899165459, 0.13308264868101105, 0.18822494836058468, 0.14995694946264848, 0.15621037484379485, 0.2952064562123269, 0.06499625451397151, 0.12074986123479903, 0.1309215888613835, 0.10859156755032018, 0.2010426254128106, 0.12984559347387403, 0.23193461151095107, 0.16819824173580855, 0.24980111920740455, 0.16747078858315945, 0.14960618078475818, 0.13464219780871645, 0.08943886597990058, 0.07939213828649372, 0.10136548342416063, 0.2113322654622607, 0.11747770986403339, 0.15093297755811363, 0.15919625759124756, 0.25704638042952865, 0.07459475469659083, 0.21728135092416778, 0.14296717999968678, 0.16183380590518937, 0.15049185982206836, 0.1153461578360293, 0.1163084561994765, 0.18417593906633556, 0.11662729768431745, 0.08642262939247303, 0.23187371087260544, 0.16057628119597211, 0.2757751598255709, 0.13203191600041464, 0.13483465154422447, 0.11950509404414333, 0.17449030332500115, 0.17513879196485505, 0.1713279527029954, 0.10862464507226832, 0.09878121389192529, 0.1112656517943833, 0.14383958943653852, 0.12561579700559378, 0.05315394504577853, 0.1309707635664381], [0.01623188847588608, 0.057034204801311716, 0.002233755735687737, 0.029832700165570714, 0.00827963418487343, 0.015620362501067575, 0.019384407496545464, 0.015079201402841136, 0.06081679050112143, 0.04241461545461789, 0.06360373314237222, 0.04049405972182285, 0.028031596812070347, 0.05544443913095165, 0.02728548050072277, 0.01594632489286596, 0.027764837395807263, 0.01428105682862224, 0.09050851600477472, 0.013106889218761353, 0.03436840990616474, 0.013396213635132881, 0.055403487422154285, 0.09766638933797367, 0.020362363320600707, 0.04438157397089526, 0.0044128383797215065, 0.08019809582037851, 0.016403998088208027, 0.11626158215221949, 0.029093517368892208, 0.027972436510026455, 0.025528403202770278, 0.002485549280208943, 0.011229506999370642, 0.03820025936875027, 0.04835011961404234, 0.032635469106025994, 0.05118628148920834, 0.026596342577249743, 0.04956704884534702, 0.054174539109226316, 0.020883874203718733, 0.08621418237453327, 0.03406984389584977, 0.03226555672881659, 0.054547245672438294, 0.059998873257427476, 0.015723405995231587, 0.042766412007040344, 0.021635859047819395, 0.05555495976295788, 0.07638983923243359, 0.03598999886889942, 0.09883402512059547, 0.02630802191561088, 0.04655771052057389, 0.11472041602246463, 0.09888685861369595, 0.0391200104058953, 0.02676553740457166, 0.025500042029307224, 0.046504030979122035, 0.020604049277608283, 0.016679310756444465, 0.03711722842126619, 0.01417971934642992, 0.038342465995810926, 0.05095624910609331, 0.040745439982856624, 0.07513997348723933, 0.038210207858355716, 0.061015600731479935, 0.0522173287026817, 0.07173295904067345, 0.05992763450194616, 0.09344010322820395, 0.0409813279111404, 0.005252139217191143, 0.019892728560080286, 0.05252818467852194, 0.0427959235094022, 0.04599954867444467, 0.06330802440061234, 0.031691256881458685, 0.020750632720591966, 0.03459406361798756, 0.059216111549176276, 0.03905615601979662, 0.029833243788743857, 0.026655525143723935, 0.026347283383074682, 0.012524086214398267, 0.036988361898693256, 0.02141986809874652, 0.04605413734680042, 0.11068244988564402, 0.028784245878341608, 0.023519363057857845, 0.014085117782087764, 0.002641371070239984, 0.08202802418963984, 0.0660960134700872, 0.012757872937072534, 0.055243677052203566, 0.07007408828940243, 0.05574289010837674, 0.024826609806041233, 0.016654626924719196, 0.03196292745997198, 0.09126749559072778, 0.03562811281881295, 0.15277127735316753, 0.06034723366610706, 0.03992506994109135, 0.026981986629834864, 0.04231209517456591, 0.052542708508553915, 0.0140471754821192, 0.04571301287796814, 0.05275662515487056, 0.034779095876729116, 0.03873181893141009, 0.057701748082763515, 0.037339724294724874, 0.033564500699867494, 0.04566941912344191, 0.02147148818039568, 0.025615145423216745, 0.05661915129167028, 0.025232314110326115, 0.05675948770658579, 0.04898056293313857, 0.03167429880704731, 0.024560056335758418, 0.03573377238353714, 0.05671782353601884, 0.05242941224423703, 0.03255806310335174, 0.010092209286085563, 0.04674036790675018, 0.05047357852163259, 0.055152385466499254, 0.018205530031991657, 0.05253645962511655, 0.015702356831752695, 0.04423918551765382, 0.02041448991803918, 0.005368770971472259, 0.0250429124571383, 0.06265005853492767, 0.02075595206406433, 0.02163522265618667, 0.06214555396582, 0.04702141923189629, 0.0705063522036653, 0.02397320120508084, 0.0631448335479945, 0.011003745676134713, 0.05803001855383627, 0.01555709070089506, 0.049856764744617976, 0.04202310286927968, 0.047193356294883415, 0.07061985626933165, 0.019017404338228516, 0.11082502387580462, 0.10693253352656029, 0.05329974366759416, 0.004391155607663677, 0.03412341211515013, 0.11303404127829708, 0.048912092388491146, 0.02506914552213857, 0.03977611719164997, 0.023133249596867245, 0.05132265483553056, 0.036566959315678105, 0.03859142685541883, 0.06259790039621294, 0.02783762352919439, 0.04237463967001531, 0.04315124526328873, 0.04338412007200532, 0.05580653669312596, 0.03124248018139042, 0.07955837194458582, 0.02804421332257334, 0.05544429812289309, 0.040084794964059256, 0.022975721331022214, 0.03782120744290296, 0.033923933951882645, 0.05529639180167578, 0.05153452315425966, 0.03262396210629959, 0.05492280579346698, 0.04169227569946088, 0.017408569183317013, 0.02947957516880706, 0.016817224059195723, 0.0371720916882623, 0.045048504980513826, 0.01758826354489429, 0.03373558800376486, 0.05770133248006459, 0.04951505397912115, 0.03185180568834767, 0.04571591467538383, 0.02040407016465906, 0.0528041782672517, 0.024304371618200094, 0.034743209325824864, 0.08557782784919254, 0.06411306909285486, 0.030655285518150777, 0.015571089461445808, 0.029316428845049813, 0.059995726551278494, 0.10587924043647945, 0.019423142039158847, 0.0243577747096424, 0.05741473360103555, 0.028949182633368764, 0.016639514942653477, 0.045340228389250115, 0.04725762257294264, 0.024503744025423657, 0.06935928133316338, 0.028664433557423763, 0.04427885331097059, 0.044682644729618914, 0.08947779904701747, 0.05666414770530537, 0.052390861383173615, 0.028634827431233134, 0.04481417185161263, 0.014100752978265518, 0.03387616932741366, 0.010863026127481135, 0.029415462886390742, 0.023270669371413533, 0.057648673391668126, 0.08074370794929564, 0.04205256613204256, 0.021560462409979664, 0.045358166098594666, 0.04622008156729862, 0.01718455932859797, 0.021383052007877268, 0.027938527782680467, 0.06283921713475138, 0.04668819121434353, 0.04171744563791435, 0.024121101960190572, 0.057948178218794055, 0.10661986671038903, 0.019448892708169296, 0.024437494357698597, 0.02942504401289625, 0.01902335450722603, 0.042963634041370824, 0.022942502801015507, 0.11313133683870547, 0.07454175050952472, 0.05688866222044453, 0.02156961494620191, 0.04590147014823742, 0.09650497275288217, 0.022967288678046316, 0.053283171509974636, 0.04759701041621156, 0.03950800892198458, 0.032536492581130005, 0.05361955365515314, 0.027607119882304687, 0.02545492687204387, 0.03829679793852847, 0.026046262719319202, 0.03160081876558252, 0.044518793365568854, 0.020881699711026158, 0.030147059078444727, 0.0213654055914958, 0.12550339131848887, 0.05639152346702758, 0.08296298925415613, 0.018707142080529593, 0.13822231820086017, 0.07367253972915933, 0.06582196059753187, 0.046857081761118025, 0.01384508032060694, 0.030425548138737213, 0.06130379522801377, 0.027157615877513308, 0.07466047929483466, 0.012355893286439823, 0.006288173663051566, 0.041912478336598724, 0.020365433956612833, 0.05480272258864716, 0.017554223086335696, 0.018813454735209234, 0.025601925917726476, 0.08029485703445971, 0.03442531407927163, 0.027735804578696843, 0.060045992213417776, 0.018993024787050672, 0.02080135851429077, 0.002672176460691844, 0.08222890872275457, 0.03154563637508545, 0.0426973477442516, 0.050559619412524626, 0.03393046485143714, 0.0692296949273441, 0.03335320754558779, 0.02777627389150439, 0.04322012027841993, 0.012912873262393987, 0.03891932254191488, 0.04711189445515629, 0.05937420755799394, 0.02557752224674914, 0.053761893868795596, 0.05515595890756231, 0.06703541657770984, 0.03135954655590467, 0.025675565520941745, 0.02283667625306407, 0.032515330240130424, 0.08019238128326833, 0.06465745667810552, 0.010157637025258737, 0.024694362800801173, 0.02379741425102111, 0.06502686068415642, 0.04317828170314897, 0.018206606146122795, 0.05253729454125278, 0.08551701626856811, 0.03695309875183739, 0.06496171496110037, 0.020290864813432563, 0.04702720056229737, 0.041862398211378604, 0.04059791586769279, 0.012673273668042384, 0.0209430400718702, 0.05040190560976043, 0.15213175385724753, 0.11870839851326309, 0.17580449843080714, 0.14349621254950762, 0.083216781495139, 0.057878108345903456, 0.14157081430312246, 0.18396162166027352, 0.13393758796155453, 0.1310888837906532, 0.18411782890325412, 0.1617952884407714, 0.18704649206483737, 0.09179176355246454, 0.06749209715053439, 0.16227529471507296, 0.17433658969821408, 0.13117912894813344, 0.1856986925122328, 0.07900778742623515, 0.16725336899980903, 0.12290621583815664, 0.12056543011567555, 0.15138083399506286, 0.22704183968016878, 0.10245023615425453, 0.148382943298202, 0.1000874605961144, 0.0920907303225249, 0.16187331784749404, 0.17298579186899588, 0.11579479352803901, 0.1421929121715948, 0.11236314720008522, 0.08716867334442213, 0.11434948319219984, 0.18176032259361818, 0.10631814657244831, 0.07166811759816483, 0.06813165775383823, 0.12009191763354465, 0.1491117471596226, 0.11366690770955756, 0.2058920409763232, 0.07066606980515644, 0.233640200458467, 0.1602137420559302, 0.14357508800458163, 0.11139432535856031, 0.14931913290638477, 0.19565706752473488, 0.17715476191369817, 0.1955720767728053, 0.08523612821591087, 0.2719294693088159, 0.10163088285480626, 0.22874190704897046, 0.24180912383599207, 0.20541678444715217, 0.12710540613625199, 0.10643084911862388, 0.11566725544980727, 0.10290919512044638, 0.165888678166084, 0.16887937003048137, 0.13912925234762952, 0.11998637681244873, 0.19515598425641656, 0.1609957727487199, 0.14184812520397827, 0.20052142994245514, 0.18368171324254945, 0.10860283335205168, 0.13940228847786784, 0.2554566110484302, 0.25745506631210446, 0.15358435950474814, 0.1899232345749624, 0.07661727780941874, 0.0977260728541296, 0.2576747123384848, 0.1678292904398404, 0.10424532069009729, 0.13368016661843285, 0.19721137708984315, 0.24093708547297865, 0.12141324477852322, 0.13920480298111215, 0.15336367447162047, 0.21356283483328298, 0.14712911448441446, 0.17852786870207638, 0.19505591306369752, 0.09926484926836565, 0.11032210008124821, 0.1511560077778995, 0.29661686334293336, 0.10138643425307237, 0.1511878755991347, 0.10012021157308482, 0.12238736555445939, 0.16769356647273526, 0.17085652565583587, 0.11626345236436464, 0.1562651156564243, 0.12819257826777175, 0.15518497908487916, 0.13304913329193369, 0.2395977167179808, 0.09353234476293437, 0.2745320030953735, 0.08978185695013963, 0.26598819124046713, 0.19429074396612123, 0.1279203436570242, 0.11406814242945984, 0.14217689662473276, 0.11490118835354224, 0.23209659266285598, 0.10256212975946255, 0.14906457625329494, 0.11953449793509208, 0.09385336816194467, 0.08043503388762474, 0.15032673196401447, 0.21129579632543027, 0.08194770154659636, 0.13589647191110998, 0.09252346921130084, 0.08681993815116584, 0.13666833518072963, 0.11468592841993086, 0.153632064757403, 0.20922288880683482, 0.061104858832550235, 0.18830392771633342, 0.21458101691678166, 0.06812960942625068, 0.0706181196437683, 0.10194202826824039, 0.12860403978265822, 0.2712421811884269, 0.08063154717092402, 0.12158913377788849, 0.10154707953915931, 0.1411144676967524, 0.1074837933992967, 0.1391229737782851, 0.16198775701923296, 0.0916657542984467, 0.17624527477892116, 0.17084399820305407, 0.11364873993443325, 0.1476679285406135, 0.14903163973940536, 0.17912351642735302, 0.12565901968628168, 0.16613461106317118, 0.17544093512697145, 0.16783029976068065, 0.07777680191793479, 0.13815736543620005, 0.15267632697941735, 0.12912121281260625, 0.2598023309838027, 0.1251029284321703, 0.22346167475916445, 0.18747327150776982, 0.1278304250445217, 0.08998081189929508, 0.09590475339791737, 0.1647377703920938, 0.1126004934485536, 0.13291130162542686, 0.11351771376212128, 0.1694878123817034], [0.006534222056870931, 0.03446949413046241, 0.03353576845256612, 0.04865770271862857, 0.033612343249842525, 0.08436506948783062, 0.04740607437270228, 0.0414788748457795, 0.03150411692331545, 0.036150551386526786, 0.009100893876166083, 0.015949684966471978, 0.04958246325259097, 0.03083870546106482, 0.05439811480755452, 0.0049623755421635, 0.07032224020804279, 0.03814253883319907, 0.018300684496352915, 0.023828320991015062, 0.012556410456454614, 0.033722912121447735, 0.047924338359734975, 0.049784008297137916, 0.03592627806938253, 0.11285619300906546, 0.012588735626195557, 0.032389050102210604, 0.01300860845731222, 0.060500431500258856, 0.04981994679837953, 0.026807743342942558, 0.0251167227543192, 0.06133453869551886, 0.0668259676604066, 0.010412482188257854, 0.01575778042024467, 0.015530531090917066, 0.0536210453719832, 0.04682818995206617, 0.01721699118206743, 0.047011856659082696, 0.008376682053494733, 0.022972333426878322, 0.08712428549188189, 0.054743458385928534, 0.02727419057919178, 0.03957182991143782, 0.014116670190560399, 0.04396407508465927, 0.1300313085084781, 0.016947771546256263, 0.08112187671940774, 0.06407345324987546, 0.06140892786788754, 0.04017096944153309, 0.02078445795632433, 0.04628306021913886, 0.03997463056293782, 0.014064786646486027, 0.02759847200650256, 0.036652970520663075, 0.05921721734921448, 0.038975087518338114, 0.08470770422718488, 0.009560674770909827, 0.008250952032540226, 0.0200229272377328, 0.054622057868982665, 0.045918250107206404, 0.057528074394213036, 0.022704902366967872, 0.0535057378874626, 0.08071762145846151, 0.05534692834771704, 0.03450226737186313, 0.02285205355292419, 0.0525983510306105, 0.04034984187455848, 0.005573239150180598, 0.02902257547248155, 0.0566425623401301, 0.02272886260470841, 0.09009487999719568, 0.02805410429573385, 0.028786631883122027, 0.08415464093559422, 0.009453084694541758, 0.015380081986222649, 0.014861762338114204, 0.0722552157822065, 0.022830887501186226, 0.038743967888876796, 0.06129740162577946, 0.03831453526800033, 0.06930822157301009, 0.019813890212390106, 0.034083365826518275, 0.048787348496261984, 0.07713571249041706, 0.04157686802500393, 0.05101967304653954, 0.028939004077983554, 0.06794674423872493, 0.05398071982199326, 0.10556491863098927, 0.053497410990530625, 0.05394526742747985, 0.031339916749857366, 0.11892153590451926, 0.007736232728348114, 0.028139033820480108, 0.014762562241230626, 0.017408376224921085, 0.0563995089760283, 0.021710487562813796, 0.02804285704769427, 0.0009341122324713069, 0.05508991518581752, 0.04797886766027659, 0.0342354504391551, 0.02741178475844208, 0.03254110131820198, 0.03757643971766811, 0.013086703729641158, 0.028904011815029662, 0.030234122277761344, 0.052262354802223854, 0.03887043356371578, 0.07002974496572278, 0.010890562589338515, 0.026304550519853365, 0.015686281913076527, 0.04497804548009299, 0.06765776677639224, 0.024138041480910033, 0.017287764239881653, 0.03242364531615749, 0.03212668976630084, 0.02126008184859529, 0.015183035284280777, 0.03981120964454021, 0.05415657542471308, 0.003411965035411413, 0.024960912560345605, 0.025513977707305457, 0.08080391096882522, 0.08171310124453157, 0.055482945463154465, 0.020851332883466966, 0.01788136734830914, 0.02034503788308939, 0.04864992501097731, 0.034626881388248876, 0.05659949922119267, 0.028717454442812596, 0.03701829271449242, 0.048509006010135636, 0.01572213321196614, 0.04096936449059285, 0.05521077022422105, 0.04512308711127844, 0.021006881470384542, 0.02326727033505449, 0.016044370022427756, 0.02805926593282493, 0.04563652342767455, 0.05381605209549889, 0.03221225939341821, 0.014341851710923947, 0.03578109171940014, 0.04811278820852749, 0.00673568036290817, 0.021269943135848735, 0.03666274460556451, 0.023345151312241796, 0.03137939529551659, 0.025547906843712553, 0.041628295148257166, 0.04540995316347107, 0.053272688674042, 0.025335355749120936, 0.050652940772124566, 0.02399953817075584, 0.008125054100673879, 0.03406000672839582, 0.018850120541173965, 0.018965127455885522, 0.06614704354433343, 0.020359322370495647, 0.08541554241674021, 0.008494386675010901, 0.052610095517593436, 0.015387383791676257, 0.06233802254428156, 0.008211839922296349, 0.03975881772930734, 0.019834605409414507, 0.0285939573586802, 0.021506875636987388, 0.009164074763248209, 0.027492279950820375, 0.03849701453873422, 0.023389516900351737, 0.0490167426323751, 0.012295531632844359, 0.10420727077871561, 0.04535028820100706, 0.020158450824965257, 0.029469240762409754, 0.012977848291484406, 0.060590654393308796, 0.0219366088276729, 0.025598562133382075, 0.04818008244910743, 0.0376759914070135, 0.15249230404151604, 0.06965645210584626, 0.025641708743933123, 0.029682430104003288, 0.02445674381306162, 0.09051100219949149, 0.03133924510621, 0.03894097470038105, 0.041539356170687824, 0.040152122601284645, 0.035981415931019, 0.014326260115922196, 0.08875695100869052, 0.034791063008015044, 0.05526186709175818, 0.010735380437836284, 0.0306209760310594, 0.05382453484344296, 0.05248649453278631, 0.006880179762447369, 0.07278685327037238, 0.06525102638988756, 0.03826760184892919, 0.05349235696485266, 0.05590771739662159, 0.06053570949006826, 0.02092100570735056, 0.002901157313317526, 0.06147654494270682, 0.059009260148741305, 0.04102370083273854, 0.04248563898727298, 0.007491011365345912, 0.001986691063393664, 0.02491569164703833, 0.026672982312447857, 0.04325267829699442, 0.061317907166085206, 0.056491880386602134, 0.06157071977213491, 0.0414546400133986, 0.03033914359548362, 0.06206170241057407, 0.03674392442917451, 0.01435547104847501, 0.03296570626844186, 0.04974774696165696, 0.06061619540560059, 0.026751623991003726, 0.046158115947037004, 0.015127591286727693, 0.043954519933322445, 0.02918912639870541, 0.045892671987530775, 0.06717783471685834, 0.04554368446406443, 0.020576818023982923, 0.053044853048049845, 0.03845348386676051, 0.06964643311221153, 0.03308361498056911, 0.038272117817541584, 0.026042854406114202, 0.04604902394930832, 0.06355438774335198, 0.07888349995482713, 0.08859111811034381, 0.01557060892082518, 0.013149210190022131, 0.023540631154901348, 0.03221904262318276, 0.036633563358918764, 0.05429975797596853, 0.056989000586327165, 0.0752003991510719, 0.02839946642779978, 0.02749696846876759, 0.017447711907152552, 0.030607166518166196, 0.02257811571325874, 0.015072816149768187, 0.01840062024712097, 0.04018948231532704, 0.016095965984277427, 0.03304082645627204, 0.034597618505358696, 0.03635967746959068, 0.022871490400575567, 0.028775176833732985, 0.014847640195512213, 0.021432748071674723, 0.04578282299917191, 0.029057688334432896, 0.030428568679781165, 0.0349353513593087, 0.03204359520168509, 0.01738455699523911, 0.06979125580983236, 0.03847165164188482, 0.03926661054720171, 0.04116208539926447, 0.023065780951583292, 0.06325873095192946, 0.019094545023108367, 0.05580477780313231, 0.0048352493558923015, 0.14401196065591648, 0.0558263594575692, 0.048484711805940606, 0.035601677518570796, 0.05417803091404494, 0.02965413201309275, 0.010697448342398275, 0.03371302300365642, 0.05511597570148297, 0.04361633436928969, 0.05022867349907756, 0.052865579855279066, 0.039703271686448716, 0.05658324618707411, 0.07428890821756795, 0.035638595654745586, 0.03461089181655552, 0.030487023941532243, 0.013340431960386923, 0.04492632520850748, 0.065613580372883, 0.07798985767294653, 0.05271811140119098, 0.017443500219087582, 0.015619034056726377, 0.02798987512505846, 0.019105122482869774, 0.03900326686562039, 0.014060146368137794, 0.04050752228067722, 0.08703213301487267, 0.06656191893853247, 0.1016233723203186, 0.17453737033065408, 0.3329992282669991, 0.1473583935876377, 0.09604053673683666, 0.10787889055791311, 0.08421496269875206, 0.138749094621744, 0.07857964985305443, 0.26827596535440534, 0.1291605763253756, 0.10158719262108207, 0.1397141834604554, 0.09825549874221906, 0.18069462821586058, 0.13009403483010828, 0.14461681101238355, 0.11271105860942043, 0.13596396282082424, 0.12553125154227018, 0.1674574744538404, 0.16388100542826578, 0.09805108158616349, 0.13880282611353323, 0.13679116062121466, 0.08738213728065602, 0.16788100328994915, 0.16656707535730675, 0.34584069857373834, 0.12044954375596717, 0.1441623197752051, 0.13962669909233227, 0.19326865818584338, 0.09921936303726397, 0.13883384788641706, 0.13729467813391238, 0.18287477607373148, 0.11762826194171794, 0.18794858740875497, 0.15560861182166263, 0.08934272816986777, 0.13331326365005225, 0.18493251409381628, 0.138238689978607, 0.08809455452137627, 0.12267335958313197, 0.09059036005055532, 0.2428564871661365, 0.2115439111366868, 0.10425864966236986, 0.19116872164886445, 0.20166640053503215, 0.1229004938795697, 0.16760113940108567, 0.15152104053413495, 0.15408308274345472, 0.13694309309357777, 0.07935745030408725, 0.15601814375258982, 0.1815338191227056, 0.1402478470117785, 0.26444888790138066, 0.242257974750828, 0.12721355189569294, 0.10919753112830222, 0.08485028563882224, 0.1243776646151673, 0.13846194284269586, 0.1089638436678797, 0.16245308361249045, 0.16659049753798172, 0.13909239729400724, 0.16821070981677622, 0.13412162574240938, 0.1252854967606254, 0.17003073793603107, 0.17430037289159372, 0.1566246268339455, 0.09292178729083389, 0.12288137615541928, 0.172872272960376, 0.168954920663964, 0.17150430183392018, 0.10402036088635214, 0.15644663013517857, 0.128813503542915, 0.1438366950605996, 0.21235053660348058, 0.13360305747482926, 0.08483513840474188, 0.09661101823439822, 0.14491702459054068, 0.2406784173217602, 0.17016678844811395, 0.10951157833915204, 0.1712672450230457, 0.205407923203893, 0.16697737912181765, 0.0900803339027334, 0.1660548450308852, 0.08915876460378058, 0.1845734630478546, 0.17905023676576093, 0.26350956643000245, 0.13922896730946377, 0.13299900863785297, 0.1264722947962582, 0.22547831264091656, 0.09412970684934407, 0.08703542815055698, 0.12683133099926636, 0.10467329499078915, 0.1051026645291131, 0.12152203620644286, 0.13468369870679453, 0.11124783282866701, 0.0874759373255074, 0.20494440745096654, 0.17451756983064115, 0.10524184690439142, 0.16339338471880183, 0.15762538328999653, 0.1051385176833719, 0.106984342855867, 0.19482311618048698, 0.10952925629680976, 0.1333867956418544, 0.16441009734990075, 0.09073726818314753, 0.13390000560320914, 0.1641962252324447, 0.08352996039320715, 0.13058512879069895, 0.07167772098910064, 0.14036019332706928, 0.23481464915676042, 0.09980016780900769, 0.0831943612138275, 0.20253217517165467, 0.07856649899622425, 0.1447346937493421, 0.13861034269211814, 0.0894618799793534, 0.09650854248320684, 0.30734469706658274, 0.14688393857795745, 0.14022322255186737, 0.11478611835627817, 0.19874872115906328, 0.08641279593575746, 0.16070790850790218, 0.10540042159846053, 0.14545990561600775, 0.09815637007704936, 0.16981603461317718, 0.1878613405278884, 0.13722153205890208, 0.20836269512074068, 0.17241537716472521, 0.1367479527834803, 0.10943788307486102, 0.1640486269025132, 0.10175741161219776, 0.11082615936174989, 0.1511241844855249, 0.24216660152887926, 0.14527251332765445, 0.08559347974369302, 0.06990435169427656, 0.06745880440576002, 0.12378229890600778, 0.13635957206133753, 0.11302642684313469, 0.12270283026737161], [0.03263141326897312, 0.07418940105708316, 0.023786000019754283, 0.008941071446315618, 0.038205190940061584, 0.04225411859806627, 0.025218888658855576, 0.006245384674912202, 0.03834767958323937, 0.012947847899340559, 0.02467816913849674, 0.04076194905792363, 0.010947656010102946, 0.015396442631754326, 0.005564900193348876, 0.023267507822311018, 0.04620226631232072, 0.04676905933592934, 0.03452270611887798, 0.02315808742423542, 0.03142079971439671, 0.021842127862328198, 0.03788360350881703, 0.03507506065943744, 0.048381371452705935, 0.04044991306727752, 0.041131004254566506, 0.01539729610158247, 0.1771730335894972, 0.04148079329752363, 0.045452025515260175, 0.010128955800610129, 0.024659750888531562, 0.10554729262366891, 0.046846294644637965, 0.02081438320601592, 0.063092667987803, 0.01708288324152818, 0.04535672262136359, 0.02307694470800925, 0.09029672932229005, 0.049312696282868274, 0.058124583010794595, 0.027161740363226272, 0.02876043778087478, 0.012474077520892024, 0.029276070854393765, 0.06850100980955176, 0.029892914317315444, 0.03247606691729743, 0.04036403544887435, 0.029051624987914693, 0.015185333159024594, 0.044988134977757, 0.04091715811227914, 0.023585885464854073, 0.02532355003495468, 0.031609698562533595, 0.04916100871923845, 0.059982334496453404, 0.013527552437153645, 0.02188220569223631, 0.08872891266946681, 0.08226135541917756, 0.04190100844425615, 0.04353608965175226, 0.05504021726665087, 0.04720036587968934, 0.04301426335587166, 0.05035776266595349, 0.0929859904863406, 0.012394393124850467, 0.04231140126648825, 0.07009435634245165, 0.037367892509792, 0.040522316994611174, 0.004889434021606576, 0.05353083361114841, 0.07516190395108424, 0.02038152000750415, 0.045805695990566164, 0.02368254277826054, 0.004376690685603535, 0.019811327947536483, 0.036208824822097085, 0.058715492123155855, 0.04243489463988226, 0.0503424002090469, 0.06621733235078864, 0.025989681380451657, 0.04855518986005336, 0.034653491093195044, 0.09453223290620372, 0.05380388458434027, 0.016531847868463956, 0.03830489848041907, 0.03255506853747647, 0.06789994440623559, 0.03098969169514021, 0.025420227757422253, 0.0936414924217388, 0.0523486146266805, 0.04371913666545879, 0.04302542896766681, 0.10525709061766975, 0.06193303255713545, 0.03218042867956683, 0.052522993355523795, 0.05416754065663554, 0.07617627881700173, 0.0834041069902014, 0.03194827375409659, 0.05924844692344777, 0.04604346526321024, 0.04378182587970514, 0.04794012384081725, 0.01753550055582309, 0.05142224363225978, 0.08838780675432645, 0.05351361207431182, 0.005321641347109107, 0.07549923233455047, 0.11250443727476522, 0.024311468405358028, 0.030304136489576194, 0.010568850848358124, 0.02469257051416207, 0.06978776029427536, 0.030199901848391164, 0.0802297706832178, 0.03086466578679392, 0.0757883359619882, 0.011554139091458637, 0.03408216354728211, 0.06662848216365092, 0.0070778452300146455, 0.0879939118749462, 0.07062998658511788, 0.022228263587749097, 0.03818445904471446, 0.04086469940375537, 0.08356873018783517, 0.06826805707532912, 0.01981630590307759, 0.022101914801169187, 0.05331017826392781, 0.041049950596061535, 0.012137199064454762, 0.02979926641273778, 0.030602082806581166, 0.056072466759360395, 0.02941360195109155, 0.0434193349792622, 0.039971090518520214, 0.1288054883480072, 0.10016369400545955, 0.005384209962358, 0.04680201811424922, 0.03885389851348009, 0.052111632030573674, 0.02832024772942532, 0.02734241250436753, 0.07768814495648257, 0.05196565900405403, 0.012688430178968702, 0.041284651088062674, 0.08029896111111157, 0.044997011063969694, 0.022540997197211254, 0.009636086251703091, 0.021683723862224724, 0.05193983968638349, 0.07535499593359418, 0.04625521854904946, 0.07869306486099958, 0.05231923671090044, 0.05698508204659447, 0.12700705672614276, 0.025168487554765306, 0.044939220024389215, 0.06479433097410947, 0.052641492075053975, 0.03417044201341923, 0.011906277031812351, 0.033518391064717434, 0.009276216060243314, 0.027791695720225107, 0.021157565279281698, 0.03752358396013733, 0.07191002063336782, 0.031421771927853115, 0.03918823233107105, 0.021654635384038556, 0.03288671578047797, 0.027642609384201933, 0.02709719949052669, 0.01626046116143698, 0.07132283339160495, 0.055600527630303986, 0.04736047310871072, 0.043604062957456335, 0.08094788019661792, 0.03081662842305377, 0.011241062238696031, 0.05426659881777596, 0.06483472607214935, 0.028343508492980618, 0.00832195051771123, 0.014290098970377585, 0.028020872778142802, 0.011461995891295373, 0.04091545859409962, 0.05007316387491301, 0.013828138944518287, 0.020545067091006786, 0.0738061559968628, 0.028146820804977324, 0.05588527114014141, 0.023801024799467996, 0.01099672403142904, 0.010056228111352539, 0.02073370989819523, 0.025326349787064828, 0.004806622864634846, 0.009741717985889409, 0.026721559588622767, 0.041119126181001775, 0.04838423243199941, 0.03390451936866157, 0.08003794777323492, 0.05876333838386927, 0.0383471860550344, 0.022922370189917274, 0.03403467722819187, 0.04159389660344459, 0.009346301703772042, 0.026189298696408514, 0.026834017226065043, 0.02882924600271508, 0.023791495623299852, 0.08874552935594693, 0.048233862180495635, 0.04590893986460287, 0.012089000283594942, 0.05366463170503266, 0.08507149017532356, 0.04180322677711956, 0.0881601900618989, 0.01600823670742102, 0.03558264514140319, 0.04506371158640832, 0.027230368614254985, 0.022088589539634995, 0.06426988489693031, 0.056823509075911716, 0.08263570212875493, 0.07587331929244101, 0.01831486137234606, 0.025446323525102343, 0.044674588716588914, 0.019589971270761453, 0.04237262473907322, 0.013629094009957043, 0.03329281527840067, 0.06392019233317114, 0.027860776681336574, 0.05237132063484751, 0.013710335060750367, 0.08460165874566883, 0.022343018172250595, 0.0438335572835058, 0.013974628691357793, 0.05660867587721441, 0.04356798715889454, 0.02058002781268442, 0.038926959241507575, 0.08840212278300896, 0.04809049038158264, 0.022533471819770057, 0.03738092091225553, 0.12115834673750214, 0.028288945795793552, 0.03343817232234869, 0.027168356609763578, 0.0395873927482171, 0.06422468068194576, 0.045654264467884786, 0.056237360840896145, 0.04906729773210827, 0.019372063725313637, 0.037830703222425655, 0.03017951505171368, 0.04656172182876617, 0.02331897947442485, 0.0332735528354533, 0.03252563867135905, 0.03371469283592887, 0.054230597233981825, 0.06814282707637176, 0.07607338746311143, 0.06299176558968611, 0.02407221298199147, 0.019631871073215734, 0.031123281987675, 0.04889049960183911, 0.050971392629435286, 0.008461714551231125, 0.022512276082125027, 0.028653112094616517, 0.04167251601757016, 0.048304095325875096, 0.037517231176025234, 0.05916284389968496, 0.06187245475302916, 0.05804426778922789, 0.03604704405006487, 0.050529425134300254, 0.03692093407153152, 0.07318660369492136, 0.01679934015555773, 0.04170025007624645, 0.028307883549132384, 0.06206127567566, 0.03941576367651578, 0.0303101107783732, 0.019738207847694866, 0.02388778742897557, 0.04274111219274346, 0.05190932999539655, 0.10978700418490916, 0.04177528491709381, 0.023589915326738264, 0.028299358127696905, 0.019889205213985406, 0.04527827390120365, 0.06439135962864384, 0.05077466783404816, 0.020562038153002504, 0.01702601988654351, 0.007536081066064071, 0.019464507495285943, 0.04724147715023719, 0.02059648493741406, 0.01895857429190073, 0.06944476932403632, 0.015217440322885523, 0.014431454910663888, 0.06846715303254314, 0.030852537238388322, 0.07151681595132686, 0.07771491422317922, 0.027889130433322862, 0.07902568802819587, 0.20272517809644341, 0.1473257242469117, 0.15553798904875293, 0.12375111386063509, 0.28153012914117426, 0.0664441029948648, 0.11256810612394474, 0.08552076411433518, 0.08914214791730046, 0.09938668765244074, 0.09820564126130193, 0.09524058317765594, 0.1776407944271341, 0.1870337122818455, 0.09457078747800551, 0.13246344518847764, 0.18239745637401938, 0.11392781714675948, 0.11954772300668992, 0.17221334972418845, 0.2748352149501443, 0.15849635296035558, 0.2327531113405712, 0.13738021807512268, 0.16584493598202243, 0.09053826870513149, 0.19469177088467404, 0.21706459927372634, 0.16398977459175512, 0.14026936929440126, 0.046860306392773055, 0.12650773976929486, 0.14258418726967648, 0.13598781544715166, 0.13384357269387692, 0.14141766470856965, 0.17114332120399922, 0.09112763043958694, 0.06788253362174146, 0.18432478420436382, 0.12039636887493543, 0.1594487510737963, 0.09657409638748504, 0.13699783390620723, 0.14378382446011528, 0.16399813117459416, 0.10876336731598713, 0.14647547533968464, 0.1514535050955601, 0.13178029825212434, 0.1444546814309433, 0.09801772946957499, 0.16189540416235104, 0.10577271998045035, 0.15669741667807102, 0.08815245688310824, 0.1339449649094604, 0.17362317797960714, 0.10190741450060159, 0.06182949182402808, 0.15283538406947628, 0.14473994815489277, 0.12962806998984888, 0.1963321102084592, 0.1373030198737979, 0.12898200075142086, 0.17908387089846656, 0.11326051506330259, 0.17558213614393026, 0.260839051916264, 0.31524085148703307, 0.11867483117384836, 0.16167514957487583, 0.13245554873719811, 0.1604121329728514, 0.11049651962821372, 0.12623779097339138, 0.125726985570509, 0.17087726126192138, 0.2513810625532642, 0.1305349447648041, 0.10355126418289728, 0.11471495381556451, 0.11128137048217468, 0.1739477488445118, 0.19988863030448556, 0.15924713923595846, 0.17060567974112928, 0.09918211464537308, 0.16405297588789836, 0.12191798683488742, 0.1775698599522002, 0.1705775226582773, 0.12414949873345904, 0.12731127790175378, 0.1305398132535629, 0.15202078793663532, 0.119781774119474, 0.13130398787325248, 0.2286467340309173, 0.1964700606185943, 0.11514145124237984, 0.1611026717000641, 0.25994037045165896, 0.1560992159647867, 0.08489546016789973, 0.11822975779068656, 0.14146873931167647, 0.19675145333167166, 0.13790145807433873, 0.10727943561505526, 0.12989476817892864, 0.17445131088607013, 0.1873750556842424, 0.18950395082356408, 0.1161458516435232, 0.13974168745335191, 0.2665414771763608, 0.10551083832979202, 0.09214324469212443, 0.19293256918899715, 0.27695437311194837, 0.20811904803849757, 0.13961118820589036, 0.11291944625554606, 0.188803096243646, 0.13937656563939527, 0.15888143854681402, 0.24615019792690873, 0.14008009195094928, 0.1939232027507387, 0.12268015765585005, 0.11336710231262259, 0.13910807145293802, 0.10322347981855273, 0.2076764014782384, 0.09676150351879187, 0.1861277874559164, 0.14815127447945997, 0.12463258492061868, 0.23248075798619539, 0.1466455013724044, 0.0675960720400326, 0.23268838122021407, 0.12349058291874826, 0.21705048362491652, 0.2300058290711604, 0.13326594431418926, 0.1258291644626297, 0.13219818676589057, 0.1294387926463969, 0.15997999522369355, 0.1872547683888115, 0.17299285711487755, 0.21083654050016776, 0.10949754432658665, 0.13632544811116531, 0.1597739156568423, 0.1679151866119355, 0.15008574177045375, 0.08726814339752309, 0.23938510625157505, 0.16360955749405548, 0.08359396320884116, 0.17270577955059707, 0.15130789572140202, 0.09614319060347043, 0.16859730938449502, 0.14759629644686356, 0.18098462984198704, 0.17320192011538893, 0.17932903196197003, 0.16917060362175107, 0.176248362113256, 0.10355773571063764], [0.0330307666445151, 0.03617212933022529, 0.027240085182711482, 0.019393402326386422, 0.047722882372909226, 0.07902761761215515, 0.017677401046967134, 0.06129482266260311, 0.05763933346315753, 0.030343898906721734, 0.007287178186743404, 0.07895542890764773, 0.04430796405358706, 0.06831109421909787, 0.017161890427814797, 0.07358955277595669, 0.06162147154100239, 0.029836225367034785, 0.028929333893756848, 0.011773751721193548, 0.045159404107835144, 0.06540177142596804, 0.021009258198319003, 0.0665855934494175, 0.022282544268819038, 0.04077540790603962, 0.011036966989195207, 0.0393399347376544, 0.047243848312064074, 0.02764417902653804, 0.037416725826915354, 0.02311962376552401, 0.02323768647329416, 0.04010799078969285, 0.0454982538940385, 0.029261619383760262, 0.02345734363188967, 0.013895641914132284, 0.07172295488999225, 0.019391279784031212, 0.03709560965944547, 0.030677818976982962, 0.05614511559542734, 0.015764096096972935, 0.04882563589490019, 0.025105560853262432, 0.06742755256709643, 0.06452399626141414, 0.034594405005918816, 0.0432024423207622, 0.05697582004358992, 0.05241807593847625, 0.04193996748654172, 0.047562185136484914, 0.05626810059766285, 0.05038175258960109, 0.021578368578047957, 0.036017729216837324, 0.045371717715170234, 0.04220947841531597, 0.04187732651189435, 0.07614582849782892, 0.017992630127992015, 0.025759443051356357, 0.015806164738023654, 0.05695273925084621, 0.05324297679180745, 0.015115093519852962, 0.0806781169376336, 0.034738986505544744, 0.04410939131048508, 0.06498819479020312, 0.07199598359875381, 0.03861946890538093, 0.05345940560800955, 0.056404392307740636, 0.014635265360993799, 0.12406766210915521, 0.4519443941535428, 0.7765943126287311, 0.8129051048308611, 0.7329259277321398, 0.6232392322272062, 0.8387576113454998, 0.6832900224253535, 0.745717822574079, 0.6032414396759123, 0.6658307311590761, 0.5873135849833488, 0.6907464098185301, 0.369345584185794, 0.26992106926627457, 0.1755209534894675, 0.13752576807746664, 0.4643351136473939, 0.7269647007342428, 0.7605769252404571, 0.16701168118743226, 0.11334956536302343, 0.38689235982019454, 0.1583136510453187, 0.2325631957501173, 0.04903305132756941, 0.0417118350014789, 0.027513013701536693, 0.09851253416854888, 0.04368533183878753, 0.09469183918554336, 0.03514703785185702, 0.03864575206534937, 0.03319489260320552, 0.030088034218351822, 0.10680778592359275, 0.029748638953606132, 0.03868325649818871, 0.019870857468049508, 0.04281357549189124, 0.06312389014055952, 0.0414819733123295, 0.08349124997039326, 0.00859086216223659, 0.021258178239804693, 0.04430699555086903, 0.04849651195399929, 0.014643721206084592, 0.03338699010782875, 0.02162342621886637, 0.09200387677992694, 0.0579942470358219, 0.06047861978004221, 0.013017974360991502, 0.0751460442552343, 0.04811306651390623, 0.013753937164437957, 0.012467400047171395, 0.05085277516627684, 0.0695223682851065, 0.021861633358639665, 0.07803088359651156, 0.07320160992094316, 0.07828900255844928, 0.02237575245089829, 0.03965214884374291, 0.005150013666934683, 0.020083273120690137, 0.0620339869055897, 0.027795597561635077, 0.11347530002240092, 0.017893430958793033, 0.04535910862614401, 0.03123249829513952, 0.0191484286551713, 0.061581080153700896, 0.010062786841444904, 0.03970459642005153, 0.0791659539390821, 0.01593022399902111, 0.03377553410246037, 0.026434663850523066, 0.03609206272813026, 0.01261046199942939, 0.08232529886299744, 0.021954945441393647, 0.0493644128437154, 0.08840047521516681, 0.09790900483494624, 0.05609568856016267, 0.0167247839999618, 0.02966648320580134, 0.04986197833204642, 0.021780227179988287, 0.06391995484591462, 0.04876869461440947, 0.03903996606823057, 0.018423005276417825, 0.1642680205986835, 0.03275777504313737, 0.04404158498800825, 0.0435538529563928, 0.08646490212413482, 0.03936726432584692, 0.0786741178308148, 0.03424696114961989, 0.018231976464448962, 0.04076854675076902, 0.056753917888272554, 0.005143665985087864, 0.02550389192037983, 0.026611699468048755, 0.016677741114108358, 0.04702320038632024, 0.09133847459452227, 0.1180323984590359, 0.03303242163383402, 0.021406069718068466, 0.013324628853297327, 0.06831753606093116, 0.02227458102424862, 0.05968391320493538, 0.03568218569853343, 0.006570124378413311, 0.04091030437848531, 0.06398231751518324, 0.07861990394303575, 0.039026329104672186, 0.030189641656761523, 0.02597832281026058, 0.04092638671863824, 0.07716654872638173, 0.03836178781057242, 0.020996246494178195, 0.04212991647364106, 0.014860682513244683, 0.03412848469452001, 0.04573046448058449, 0.012822209719161037, 0.030281057552201673, 0.04557820917398203, 0.024695142055861652, 0.018244720995426178, 0.025095749660977162, 0.030379496020032093, 0.03662145150883589, 0.06938743099453859, 0.07473293517250568, 0.09535701130516827, 0.01712212058919249, 0.033954885220737197, 0.03795319840719458, 0.089594316232251, 0.031990924981073476, 0.01131576867919648, 0.030411940861085895, 0.033596839784877375, 0.04613073069776874, 0.029428099805954844, 0.043796141908387654, 0.028200125561852474, 0.03251272901252378, 0.05966407559753861, 0.007078778944560327, 0.057085086446022615, 0.009239244118361967, 0.02285555463458877, 0.03317329981655348, 0.04988230575690977, 0.06747676437953487, 0.11303548846626654, 0.04438368538103532, 0.06998124561505392, 0.06849470155430026, 0.03133762351353653, 0.022961425711400807, 0.2178459323477, 0.9278326097410172, 0.9003574121743441, 1.289619687013328, 1.2053569522686303, 1.0155132017098367, 1.0945374425500631, 1.2777334498241544, 1.241723969578743, 0.738944448530674, 0.8673241815995425, 0.5886539036873728, 0.6987089419271797, 0.5288967664819211, 0.30748436925932765, 0.2249054191634059, 0.22653186548268422, 0.48977109719999135, 0.8622893923893571, 0.7606195542030036, 0.4178987554041669, 0.3579841641476378, 0.4462733172113076, 0.15846984344534576, 0.1754569952026941, 0.010295552183379186, 0.03886123093252536, 0.04915667828754522, 0.07916297792689875, 0.007228524864331121, 0.10602560680126771, 0.011641052005870733, 0.006584571210623835, 0.012875806696683867, 0.011344053782522678, 0.0796183077909518, 0.02740058389463229, 0.02138457897672197, 0.013290681163198315, 0.09002462087664753, 0.09764192072907463, 0.0538963673170656, 0.05418226486654021, 0.02738436796789756, 0.0748065859079361, 0.05053144006524235, 0.0779834455170203, 0.014180340895109111, 0.038497571149491705, 0.025706685628392734, 0.04548172255454119, 0.046211825174395926, 0.01865380949311657, 0.02089330504531972, 0.022876639050082304, 0.03588818733987864, 0.06666413493803702, 0.0033902187169587705, 0.049034042094717734, 0.0117619441516581, 0.010292044607922435, 0.013973534951219335, 0.02057968456938397, 0.06613045654376037, 0.09020052471896634, 0.02531605805415893, 0.024931228508648928, 0.014215023311408004, 0.05375711072701961, 0.07703767478233203, 0.027577587970881723, 0.013970872496429365, 0.030668224862893112, 0.03769858980376739, 0.015929724904708564, 0.019382902792131063, 0.0358730363950599, 0.02336033936444437, 0.017989075240620878, 0.07177051913458854, 0.02903531443735119, 0.07040426236926578, 0.03241519596485887, 0.020051531464559957, 0.059818657537107356, 0.028387482598191127, 0.021234652158454992, 0.023022439527267125, 0.033641995760262944, 0.037550167689914815, 0.05032196517277043, 0.04853265454585198, 0.016415549616795033, 0.04246709271683358, 0.02987137904710835, 0.06277236447203904, 0.08085732333711348, 0.020824183266086038, 0.10627812254824676, 0.11416770896175876, 0.1270367277902551, 0.08180517950677313, 0.2522571530425921, 0.15759884408907965, 0.13607834262074903, 0.1895296885049902, 0.127858285268303, 0.2628619089955464, 0.1360386228770949, 0.1668135722866282, 0.13997959031257778, 0.13673959620064124, 0.15540870692348108, 0.09424980860785581, 0.21137899107998237, 0.23038571962388232, 0.15343639010097831, 0.2667705633211881, 0.07878822303609923, 0.0990969903068617, 0.15142914780881256, 0.11313299924950115, 0.22778671846026555, 0.1908122087479569, 0.10568766243522987, 0.21061368839582428, 0.15405042824568227, 0.10487536696018651, 0.15626851469278336, 0.09751224526553415, 0.11546842666575685, 0.15859860606724396, 0.14375964528881013, 0.12672459532041103, 0.08860199057380669, 0.05625506477372255, 0.0756170779641252, 0.16675293882144615, 0.09933487832313403, 0.10670292787835933, 0.19270492281066254, 0.17836052924394608, 0.09053550791577436, 0.1346196365193464, 0.06860370820504613, 0.19116156734526157, 0.19505880743963644, 0.10919105217908509, 0.18684476148337126, 0.22451916098361835, 0.12615808431291953, 0.12967610178748146, 0.1223399794253055, 0.1360360105172731, 0.11789428477641195, 0.13134206004906446, 0.1543577219126746, 0.11905134495464154, 0.13658393814694136, 0.1539597229566425, 0.1341555715771392, 0.09331902925623581, 0.11785212336690165, 0.10233688793960027, 0.16180827602511272, 0.21762646443676203, 0.08157453485182486, 0.19869850744726136, 0.1277164014754817, 0.17185955308377743, 0.11807581409811974, 0.15047119843075052, 0.16314173728460446, 0.0994810665724799, 0.12135462995502166, 0.18434323399560526, 0.4009329329710454, 1.0195395606569946, 1.2959087057970464, 1.82988217798993, 1.8972225207835436, 1.6192212444730103, 1.7859388422220945, 1.7734575807116926, 1.3077126536518335, 1.0177798988297582, 1.4863084140233696, 1.129346543457359, 1.2226106389425695, 1.168971648439765, 0.6847916543483734, 0.3252575296210125, 0.37137589242774993, 0.8143337687943131, 1.6005346784368157, 1.3262671767733991, 0.8870111033320427, 0.7625084090977907, 0.6785621854942292, 0.43934180634096265, 0.47118101036176085, 0.17805933603085577, 0.14731033210409805, 0.2336687286151573, 0.2071619001799263, 0.16206985339522362, 0.1623391787870787, 0.1277907201438211, 0.1090742381347809, 0.11217638573725708, 0.08090256465948187, 0.17736740206601098, 0.12385525944409892, 0.15851990872761235, 0.13324701954843476, 0.15651901921955869, 0.12356533945421688, 0.18271521432325244, 0.2200762345455587, 0.1322122578858398, 0.20971383433789015, 0.12729028996545821, 0.1393829332664609, 0.16962556983344257, 0.06775249450583942, 0.0810226441535633, 0.1578361977590248, 0.14854480570647866, 0.15979016869096085, 0.11117115413071588, 0.13660222466569394, 0.0937432779755909, 0.07449992306646891, 0.12401718864566647, 0.12214653121191077, 0.14478377939667553, 0.09235809644451365, 0.14298531808890402, 0.1274700678186491, 0.14618645334849134, 0.1632483839057386, 0.1803787553217262, 0.07807345318724401, 0.13814455596730113, 0.11919092066818848, 0.13070023589534685, 0.20212843199260533, 0.10145043706870638, 0.09637796902097762, 0.14631189114879817, 0.06494334680610336, 0.16103495814604685, 0.10619626365951262, 0.10868110024603084, 0.19405157945584506, 0.11496808554511517, 0.15537130268057808, 0.12555124500067905, 0.14095031947363168, 0.13304622407304123, 0.18879119219491258, 0.07871649446315132, 0.10422339022625238, 0.17973730224184692, 0.1409519967273809, 0.11021227706805803, 0.11039113465812989, 0.14806447288719937, 0.11031546528101899, 0.1291613036300987, 0.14874855492962524, 0.21686987456632778, 0.11835563345812261, 0.19108289969153702, 0.2792371599934995], [0.03835800656815991, 0.03203295280400198, 0.016265359336102847, 0.04816713939362671, 0.046399417842621915, 0.004741823167933035, 0.029097048136463854, 0.04688547633122653, 0.03921584764611907, 0.005919237673879252, 0.05681908216502052, 0.045687186138820834, 0.03248434928536881, 0.021474855675478466, 0.013906404910812853, 0.034290514086023904, 0.017785977252060547, 0.020187233167234808, 0.0406675181875471, 0.019325996763654985, 0.06862874084617943, 0.011981652332906378, 0.015958770709403325, 0.07029400891042314, 0.04041027124912944, 0.02034546090726508, 0.07500922190956771, 0.03622207215812523, 0.027332938989275135, 0.023217114139697514, 0.05855195617186837, 0.023366061323031317, 0.06880521614220925, 0.042674894066294655, 0.02657168843143154, 0.06630831223446876, 0.053608061498380266, 0.007830317572370404, 0.01204812093419605, 0.032656828116159886, 0.032747266232036054, 0.11417990244808607, 0.04334528719482478, 0.010848432721104473, 0.013767856144113466, 0.08071621879935265, 0.052546003644238226, 0.040124165898305364, 0.10044671202194877, 0.03477391568594612, 0.04510153143201023, 0.06372672185534611, 0.027340857704984955, 0.018049012942356057, 0.04829635472560767, 0.002456026645631937, 0.02012478515098337, 0.03125151211861521, 0.044700133439619094, 0.02438804691337282, 0.05711801924917381, 0.037277639930834994, 0.022586693085031584, 0.055174716690089554, 0.02433784247841686, 0.03474153949355241, 0.07107517129043117, 0.036950237772543915, 0.040442654862999916, 0.05051876789366361, 0.031571589279337786, 0.009753898484632373, 0.0424669554195134, 0.12175305935670622, 1.0059180040843785, 1.4678124315105379, 6.095863748341799, 9.006950240582228, 12.03469617292285, 18.87285389006138, 30.915078409016132, 24.039392955601215, 26.497745141386986, 29.76574268192053, 31.573793962597847, 29.598200172185898, 18.473812602460384, 21.83438267558813, 18.22681065648794, 16.733813770115376, 12.008453831076622, 12.18941817060113, 4.726321287453175, 5.344537189230323, 8.067609295248985, 15.415690150111914, 12.938090097159147, 10.638444945216179, 12.725347112864256, 8.680209573358297, 7.264037914574146, 3.560779904946685, 1.1974764126352966, 0.11860622704261914, 0.011871675324073294, 0.04889824391284492, 0.027596379150054418, 0.008714452942513162, 0.04511562110565137, 0.04676065451349132, 0.0753615194116719, 0.0658953886886593, 0.039530744616058655, 0.08307710188091733, 0.0477498223335715, 0.008016904630494537, 0.02735253539867699, 0.09610066554159857, 0.056960965957841836, 0.02109249006025493, 0.04743615361803677, 0.02853618672816083, 0.10823737757164054, 0.033009797261911444, 0.07924253615783527, 0.043692241233657114, 0.09744003429659642, 0.12215846494655125, 0.02191443902120227, 0.09564594423864037, 0.041274587565567344, 0.03526235275785439, 0.05112170350912493, 0.06596270890440792, 0.04908624105155468, 0.0686767949082423, 0.04025459464173764, 0.036993122776038945, 0.009718119545141235, 0.055434401583625004, 0.021988483094901312, 0.029420112441584934, 0.015506587551499251, 0.057080644692177884, 0.024472507029713597, 0.06769451792933978, 0.030671187887492124, 0.0871574149641674, 0.04667978639190551, 0.029392159449344035, 0.025986440050473902, 0.07006896747043356, 0.026942600852635223, 0.02865715494408505, 0.040422320016659796, 0.027068237177445553, 0.026658690403564833, 0.036662748316302896, 0.015720324227004312, 0.055132807610789314, 0.08301666137413122, 0.024251300637843087, 0.04394319104903843, 0.0248420650314074, 0.034217932043247856, 0.014155583776300773, 0.0640544987982139, 0.03222908759198617, 0.029812951615895145, 0.038251129881246015, 0.0707157194847241, 0.060851474772789516, 0.03290966669737827, 0.04739858239190653, 0.024600846627436113, 0.01805195555789396, 0.056089324643835425, 0.1137872321123723, 0.050794906201190315, 0.04811938961211126, 0.06033196397766005, 0.02414836475509219, 0.060817825797130354, 0.018714877114689443, 0.04199195493129082, 0.029855871871404815, 0.04952502844389528, 0.03322175092762336, 0.04703654791228473, 0.10132181545486674, 0.05986390999169089, 0.0307432986664935, 0.049622268343227915, 0.024947099336714018, 0.03227500797947869, 0.01299708661463228, 0.10264385506161489, 0.028968556398467626, 0.034791040743584745, 0.11234128352953121, 0.0751710546319373, 0.026978760142810643, 0.030956226401031017, 0.052213540038792416, 0.07683836360229179, 0.02642302140884567, 0.010103595686814515, 0.029446970766002778, 0.02905634875787655, 0.04127904787310399, 0.0096765193848114, 0.0848744202812668, 0.028812521704821847, 0.048508753679925576, 0.04188239538052585, 0.036841412947978824, 0.016783545397629496, 0.07743994108750485, 0.05972008177195676, 0.052128159659332596, 0.03168339011608623, 0.03659896814497188, 0.0474394227785524, 0.03390787387616001, 0.04700567827967461, 0.010932396526186494, 0.03745215966773685, 0.02125240247551119, 0.014534537367580924, 0.048223854319076054, 0.03519195262924768, 0.04387059416330885, 0.056920411298051476, 0.014767086559004383, 0.041752679098863155, 0.04019049905764405, 0.05402872935519554, 0.04509572041570209, 0.01746926202031318, 0.026152738646487705, 0.020846375336986966, 0.030141595016175415, 0.04262004564225208, 0.05395399137341883, 0.016631310500088148, 0.04418247059220448, 0.0448325474280864, 0.048293100408045575, 0.09236965168383904, 0.24236619472503662, 1.3758421665988863, 2.398838116787374, 7.745963204652071, 11.843574978411198, 15.241279508918524, 24.381575994193554, 36.657351180911064, 27.66444593667984, 33.36516223847866, 36.69420540332794, 36.879175677895546, 36.28596670925617, 24.451239556074142, 24.55787893384695, 21.890701353549957, 19.09198433160782, 13.749476708471775, 13.587220665067434, 5.315766083076596, 6.375462245196104, 10.270130708813667, 17.46694453060627, 15.362540502101183, 13.653349466621876, 17.050091698765755, 12.876468803733587, 10.858540534973145, 5.614340286701918, 1.8303117924369872, 0.07034952155663632, 0.03527482826029882, 0.06435414092266001, 0.039640118629904464, 0.02755390974925831, 0.014233564943424426, 0.018985588467330672, 0.0383131029229844, 0.040504624193999916, 0.050874019143520854, 0.028144701973360498, 0.02952931205072673, 0.012566110326588387, 0.009451555870327866, 0.03222223756893072, 0.04037723454530351, 0.08271325656096451, 0.0582768939784728, 0.005013888476241846, 0.030949599022278562, 0.06926259433384985, 0.03495038727123756, 0.06118413875810802, 0.07924627658212557, 0.03372573228261899, 0.03287790277681779, 0.06204644014360383, 0.060147941039758734, 0.026815738128789235, 0.023658563986828085, 0.017984594524023123, 0.02608309921924956, 0.07212344746221788, 0.02116232801199658, 0.0674159824848175, 0.023582504982186947, 0.012820597403333522, 0.04197144568024669, 0.068735023814952, 0.04873995123489294, 0.03963710551033728, 0.06750942629878409, 0.020805475578526966, 0.062059353513177484, 0.025447711341257673, 0.04209595950669609, 0.023755601650918834, 0.023284922317543533, 0.02937964683951577, 0.06768082530470565, 0.05669760001183022, 0.011868507281178609, 0.037330818522605114, 0.05046944475907367, 0.040586375471320935, 0.009710147951409454, 0.07544851396232843, 0.018743807886494324, 0.029912295503891073, 0.0951586797600612, 0.01765884178894339, 0.011624495618889341, 0.033243054276681505, 0.016338859786628745, 0.037189290960668586, 0.01692750349320704, 0.04632916985428892, 0.013643030615639873, 0.06310182609013282, 0.059423649436212145, 0.02619878519908525, 0.038913786120247096, 0.05251390946796164, 0.17012487194733694, 0.19165865785907954, 0.07565437830635346, 0.15399141266243532, 0.13272407260956243, 0.10138992976862937, 0.18118576670531183, 0.19467499834718183, 0.11663564684567973, 0.16018110240111127, 0.13559941988205537, 0.10772526598884724, 0.16020633542211726, 0.14252678956836462, 0.16801552497781813, 0.12314379215240479, 0.1101999351521954, 0.13338284741621464, 0.17544299829751253, 0.07815604680217803, 0.1955521130003035, 0.15314119344111532, 0.12440354330465198, 0.13163212104700506, 0.1533726099296473, 0.14280190371209756, 0.23727430467261001, 0.16217793978285044, 0.17689407512079924, 0.16795533680124208, 0.13017630932154134, 0.1203305552189704, 0.1484372981940396, 0.1141007523983717, 0.12954003643244505, 0.18197768280515447, 0.16529748332686722, 0.09682428179075941, 0.183770518633537, 0.07853788920328952, 0.13492734578903764, 0.1454736798768863, 0.17248291260330006, 0.1618076377781108, 0.11142673494759947, 0.18436475627822801, 0.09992156832595356, 0.11568939371500164, 0.1586624456103891, 0.10369665091275238, 0.12034853745717555, 0.1565957276034169, 0.09842706102062948, 0.09884153565508313, 0.1405425538541749, 0.16354488674551249, 0.12474199233110994, 0.2252232958562672, 0.17144390585599467, 0.12387762777507305, 0.2261861730949022, 0.1332145431661047, 0.09059286108822562, 0.16961148387053981, 0.30582151317503303, 0.14195163996191695, 0.16955107304966077, 0.12401010113535449, 0.11897834730916657, 0.2548601618036628, 0.11999793205177411, 0.08409182555624284, 0.2011081125237979, 0.3920572029892355, 2.2400880977511406, 2.8522521117702127, 8.686572331935167, 14.562203697860241, 19.821890965104103, 29.865702018141747, 41.25237621366978, 32.544915452599525, 38.712995275855064, 44.041274562478065, 44.60971646010876, 41.65891259908676, 30.1744544506073, 30.528029277920723, 27.709317728877068, 25.849486626684666, 19.164587035775185, 18.271728046238422, 9.118662346154451, 10.291083734482527, 15.29122307896614, 23.36265116930008, 21.11744474619627, 18.803640604019165, 22.786959260702133, 18.987862318754196, 14.25932290032506, 6.766725350171328, 2.5923593575134873, 0.2873289445415139, 0.16710872441763058, 0.141285770223476, 0.09266988752642646, 0.11437053050030954, 0.14968716393923387, 0.1494717481546104, 0.17002981767291203, 0.13425236247712746, 0.17183789721457288, 0.1534510697820224, 0.1568660920020193, 0.04902388580376282, 0.20448619063245133, 0.17702604382066056, 0.16490326932398602, 0.11639686083071865, 0.16530566179426387, 0.06918501763720997, 0.2398622626787983, 0.08351781143574044, 0.1986353803658858, 0.12546615034807473, 0.2024590439395979, 0.24519186263205484, 0.14390360709512606, 0.19482154282741249, 0.14303955424111336, 0.127774229622446, 0.09617658724891953, 0.1605574306449853, 0.17848798568593338, 0.17977795709157363, 0.1330327318282798, 0.16248311090748757, 0.1546489109750837, 0.07918858944321983, 0.1791713255806826, 0.11727057644748129, 0.09151066769845784, 0.13008207140956074, 0.1883159505086951, 0.20580427459208295, 0.10784883357700892, 0.15675476985052228, 0.18453547992976382, 0.13304212741786614, 0.11713687854353338, 0.09826483495999128, 0.13306927517987788, 0.14609666832257062, 0.21424529899377376, 0.08051282580709085, 0.13641906261909753, 0.12456501979613677, 0.16501925216289237, 0.22666551143629476, 0.14502698119031265, 0.21273676509736106, 0.20219188561895862, 0.1357359898975119, 0.10819490446010605, 0.1002908313239459, 0.2652782230870798, 0.08124701023916714, 0.15706293925177306, 0.07970128732267767, 0.20635218737879768, 0.1592525272280909, 0.15749584883451462, 0.19801164977252483, 0.1464013644726947, 0.11171229853061959], [0.022938140828046016, 0.027186051265744027, 0.046117654055706225, 0.03979888999310788, 0.01537666903459467, 0.025657687183411326, 0.03378568297193851, 0.021679204182873946, 0.02916778037615586, 0.01692223424470285, 0.01857238847151166, 0.07224940476589836, 0.04717009738669731, 0.09085304322070442, 0.0871724211901892, 0.022245694781304337, 0.05446125673188362, 0.05335070694854949, 0.05134031052875798, 0.05320506417774595, 0.07345185469603166, 0.022274304574239068, 0.026653840468497947, 0.03442553672357462, 0.0021391859445429873, 0.03344485907291528, 0.03871633030939847, 0.03331310930661857, 0.044955528719583526, 0.07871671710745431, 0.01729497791529866, 0.03272467525675893, 0.0776660734845791, 0.07492862467188388, 0.008926713671826292, 0.052478353172773495, 0.011297298478893936, 0.01698034626315348, 0.016755052492953837, 0.03828269713267218, 0.031630779267288744, 0.060365223325788975, 0.013421246276266174, 0.03503514795738738, 0.006044907395335031, 0.05703889146388974, 0.07736643878160976, 0.05087413788714912, 0.046333407517522573, 0.06204286670254078, 0.041862869475153275, 0.029394281991699245, 0.04487188496568706, 0.02856154962501023, 0.10788813029648736, 0.06233440828509629, 0.07858204699005, 0.031576672990922816, 0.02270725126436446, 0.03546747124346439, 0.018532266112742946, 0.03187550988513976, 0.03341287992952857, 0.03619276474637445, 0.04778620983415749, 0.04089554677193519, 0.20010205713333562, 0.05457526916870847, 0.28849874739535153, 0.18601778632728383, 1.6918462724424899, 4.688251605257392, 9.596932232379913, 12.611072044819593, 20.37500448524952, 36.53594769537449, 46.98668651282787, 48.10195706784725, 48.8138260692358, 51.651221215724945, 70.84208384156227, 66.43316522240639, 77.14664474129677, 76.44450321793556, 70.53514391183853, 82.92708456516266, 77.35688745975494, 65.60028791427612, 62.1744791418314, 57.374857887625694, 49.83499847352505, 48.83679583668709, 39.59894813597202, 29.3556971848011, 32.06149399280548, 47.11826205253601, 41.80595710873604, 42.77239345014095, 55.205789878964424, 48.00165385007858, 52.330024391412735, 38.216046541929245, 20.938757434487343, 8.60720219090581, 0.7642837450839579, 0.19327818736201152, 0.1033411399112083, 0.20684449846157804, 0.03704412687511649, 0.0416300577489892, 0.008346754020749358, 0.05686128068191465, 0.06493438166216947, 0.03143550165987108, 0.018624596705194563, 0.07575307652587071, 0.033774587864172645, 0.055364250074489973, 0.05459992702526506, 0.05840756763063837, 0.02960341178550152, 0.0685924498247914, 0.029368830037128646, 0.012156445736763999, 0.0553750223480165, 0.011798904961324297, 0.04113942020921968, 0.020123987342230976, 0.022680736183247063, 0.03476313599094283, 0.032935797717073, 0.040327506940229796, 0.0719206259236671, 0.011018119221262168, 0.06292589998338372, 0.031031261241878383, 0.017176362307509407, 0.06673167779808864, 0.039627587466384284, 0.10615652907290496, 0.06440392418880947, 0.02548742551880423, 0.024279008721350692, 0.06003547598083969, 0.08632503697299398, 0.06074568533222191, 0.030168956145644188, 0.04125933272007387, 0.024066936312010512, 0.04622214844857808, 0.02577356055553537, 0.020657153654610738, 0.031029209203552455, 0.06787062215153128, 0.029545750621764455, 0.043468431758810766, 0.030087989689491224, 0.016784725412435364, 0.04240603251673747, 0.014319616038847016, 0.052158765829517506, 0.038216816683416255, 0.01300689131312538, 0.02518320248782402, 0.01219199832121376, 0.049035763877327554, 0.03141125198453665, 0.004846144547627773, 0.0403032943722792, 0.025391933377250098, 0.017372873735439498, 0.07558926969068125, 0.018443291883158963, 0.08904796195565723, 0.030540718325937632, 0.012443462073861156, 0.023203733217087574, 0.027939557512581814, 0.05152232224645559, 0.025987874250859022, 0.05346499769075308, 0.01007237538942718, 0.02741208161751274, 0.016836341783346143, 0.04013266348920297, 0.016721034298825543, 0.04951071612595115, 0.05178325765882619, 0.004875507156612002, 0.044873165170429274, 0.02947415749076754, 0.016002748525352217, 0.023657541678403504, 0.008631306427560048, 0.05777316866442561, 0.05423808179330081, 0.045880701145506464, 0.04608869545336347, 0.00822611698822584, 0.07349095103563741, 0.024108793440973386, 0.011193595400982304, 0.005344505989341997, 0.038346228684531525, 0.047555394485243596, 0.013413681008387357, 0.039625420395168476, 0.04694720817497, 0.04515403095865622, 0.01740046307531884, 0.04292084922781214, 0.030529122268490028, 0.041105904820142314, 0.020534430259431247, 0.07118730980437249, 0.045995355540071614, 0.06216913941898383, 0.04179063253104687, 0.033467587345512584, 0.0512310626800172, 0.04010790173197165, 0.024303970858454704, 0.02957965749374125, 0.01485673243223573, 0.03317022361443378, 0.037585512473015115, 0.04939695601933636, 0.016791104171716142, 0.028488739371823613, 0.030115374938759487, 0.015616197197232395, 0.03630795719800517, 0.07839042445993982, 0.023011251651041675, 0.03055696579394862, 0.07053122157230973, 0.02572021126979962, 0.054050518810981885, 0.01467403793867561, 0.029000492868362926, 0.01673150600254303, 0.08412501440034248, 0.15391109744086862, 0.06053070741472766, 0.28431252983864397, 0.49966125399805605, 2.046229150146246, 5.256447941064835, 10.866229422390461, 15.499149821698666, 23.604453094303608, 43.50710682570934, 55.338440760970116, 60.79020582139492, 61.895448714494705, 64.43527802824974, 82.53654912114143, 77.9819007217884, 89.58692640066147, 87.23816603422165, 80.89491561055183, 92.3336698114872, 88.3899374306202, 76.77857369184494, 71.61709785461426, 68.03123787045479, 57.84466087818146, 56.10868602991104, 43.39103065431118, 35.994583144783974, 39.93398755788803, 53.806028589606285, 50.07942795753479, 51.65080703794956, 65.9716647863388, 59.370750188827515, 61.00523628294468, 48.12574379146099, 29.615947119891644, 12.095749396830797, 2.0010585989803076, 0.12299168156459928, 0.02255393839732278, 0.06325549518805929, 0.10327206080546603, 0.009550536105962237, 0.06418317978386767, 0.02249551467684796, 0.008249818401964149, 0.07473263089195825, 0.03991657977167051, 0.024490763862559106, 0.04562961032206658, 0.030927857806091197, 0.02027376387559343, 0.08221837764722295, 0.02339567301532952, 0.009565796517563285, 0.011656110182229895, 0.08138323144521564, 0.024846523483574856, 0.012229348758410197, 0.07086413417709991, 0.008030588905967306, 0.004202342570351902, 0.09192966943373904, 0.028659791423706338, 0.03180548083037138, 0.10651284159393981, 0.017894056218210608, 0.03298760704637971, 0.026544626016402617, 0.1053168335056398, 0.10583966170088388, 0.01570214346429566, 0.06720705307088792, 0.05839261335495394, 0.016883301177585963, 0.01578085564688081, 0.01173921680674539, 0.07694359272136353, 0.07493100696592592, 0.03710950637469068, 0.017186179065902252, 0.05670545935572591, 0.028054751819581725, 0.01999829906708328, 0.02065959903120529, 0.042456543087610044, 0.019657644006656483, 0.055079124358599074, 0.048070448683574796, 0.05005160077416804, 0.015356001149484655, 0.04155197268119082, 0.05822088038257789, 0.045876719523221254, 0.01623146174097201, 0.05162519504665397, 0.02977455846121302, 0.07560027574072592, 0.08424791405559517, 0.02873696921597002, 0.04803612806426827, 0.03089160760282539, 0.044017969848937355, 0.06838072251412086, 0.011232054421270732, 0.04170363426965196, 0.059819826419698074, 0.019553776728571393, 0.06409258581697941, 0.09453956532524899, 0.15217156265862286, 0.21123004204127938, 0.11973357904935256, 0.12983986409381032, 0.16746669192798436, 0.1066828379407525, 0.10141065053176135, 0.1052994598285295, 0.13418331305729225, 0.1096135716943536, 0.23422574013238773, 0.14601740695070475, 0.11156667431350797, 0.16005314129870385, 0.05812391507788561, 0.12625638919416815, 0.0954501805244945, 0.21088801586301997, 0.11067443469073623, 0.13161010894691572, 0.09862000457360409, 0.11725334377842955, 0.14694880228489637, 0.12970283394679427, 0.12123412743676454, 0.14715295226778835, 0.13378279079915956, 0.16176578064914793, 0.13461485708830878, 0.06891559576615691, 0.17124646488809958, 0.13661457400303334, 0.10325043462216854, 0.1546756728203036, 0.10175429459195584, 0.11578254066989757, 0.07347846811171621, 0.1056097072432749, 0.13217887608334422, 0.11058046395191923, 0.1838691797456704, 0.13385016296524554, 0.10844466683920473, 0.1733862399123609, 0.08736529794987291, 0.15331056638387963, 0.12985225796001032, 0.11356610179063864, 0.11744187897420488, 0.10522909680730663, 0.09828508817008696, 0.19833881815429777, 0.12218141957418993, 0.16372479818528518, 0.15349825553130358, 0.1309664739528671, 0.11687815844197758, 0.1475786036462523, 0.1636700425297022, 0.09366671059979126, 0.1439393192413263, 0.10860574257094413, 0.09608096894226037, 0.16494196490384638, 0.18399069900624454, 0.3841273847501725, 0.22713594400556758, 0.6499381433241069, 0.97794194589369, 3.29234782140702, 8.677838500589132, 14.056948609650135, 20.975484363734722, 29.702455177903175, 51.85022033751011, 63.75756919384003, 67.96195238828659, 72.85035967826843, 78.76973524689674, 93.49519148468971, 89.447952657938, 98.4849089384079, 98.0142205953598, 92.57256299257278, 103.18636626005173, 98.87189537286758, 88.43157559633255, 82.39651143550873, 75.68411082029343, 68.53528842329979, 68.9372992515564, 54.322572872042656, 47.31811612844467, 51.22942864894867, 63.247951939702034, 63.84763956069946, 64.83057081699371, 77.25838154554367, 70.14216899871826, 71.30921557545662, 60.24988241493702, 35.9897194057703, 14.166958406567574, 2.882897942326963, 0.3376276174094528, 0.25885772542096674, 0.34610472503118217, 0.11971858024480753, 0.1396699366159737, 0.0868871841521468, 0.10490019922144711, 0.1311430605710484, 0.13956238457467407, 0.08182241217582487, 0.28069266001693904, 0.18899075570516288, 0.1113562828686554, 0.05991724814521149, 0.11495414801174775, 0.12790649518137798, 0.26496797567233443, 0.11730213998816907, 0.21538099274039268, 0.13270298077259213, 0.12322979964665137, 0.19274431600933895, 0.08503798220772296, 0.09686265082564205, 0.20837249147007242, 0.09117481618886814, 0.16004845092538744, 0.17601762840058655, 0.09021539735840634, 0.07625991886015981, 0.11636752373306081, 0.1281252654734999, 0.19726212514797226, 0.10273641571984626, 0.3423823497723788, 0.1347595758852549, 0.048432427502120845, 0.12331365491263568, 0.16859330178704113, 0.14854862034553662, 0.16075712774181738, 0.12665527872741222, 0.1579787494847551, 0.09794789337320253, 0.1614485718891956, 0.15531969373114407, 0.11938659532461315, 0.10932091317954473, 0.13359847100218758, 0.09156363477814011, 0.09701965216663666, 0.2121422454365529, 0.1235883534536697, 0.1906992687145248, 0.12620663561392576, 0.09898622476612218, 0.1232087894459255, 0.15434025175636634, 0.1887854331289418, 0.340219137724489, 0.14357531064888462, 0.17401222663465887, 0.1638811093289405, 0.1374022598611191, 0.22086754208430648, 0.15955983573803678, 0.17335181910311803, 0.16893807391170412, 0.15108369290828705, 0.20258697535609826, 0.08835328946588561], [0.08453614937025122, 0.04118339988053776, 0.04444526508450508, 0.014266026482800953, 0.01106377707401407, 0.0233063091582153, 0.027398210877436213, 0.04015178121335339, 0.021246556207188405, 0.0275976667762734, 0.013817455728712957, 0.041975193526013754, 0.0637633765290957, 0.024562919170421083, 0.05682097464159597, 0.048535971945966594, 0.08111727540381253, 0.022477343190985266, 0.055715823982609436, 0.06361108040437102, 0.07023924583336338, 0.0696248811436817, 0.009475161732552806, 0.03655096603324637, 0.0026214689887638087, 0.04218519534333609, 0.015339514338847948, 0.008030215976759791, 0.046327533418661915, 0.07007943175267428, 0.021314718760550022, 0.05712874699383974, 0.03827481923508458, 0.03862770303385332, 0.06549326339154504, 0.01498671774243121, 0.09356609763926826, 0.05322746961610392, 0.0357241541496478, 0.06564810508280061, 0.011358141600794625, 0.06341220709146, 0.06486917656729929, 0.02963445211207727, 0.059064412853331305, 0.026232393356622197, 0.04203974924166687, 0.06589528478798456, 0.1580948065384291, 0.046356373277376406, 0.025421216669201385, 0.03210457005479839, 0.05207190115470439, 0.03987680065620225, 0.03983935559517704, 0.07090268874890171, 0.05048651044489816, 0.032570093317190185, 0.04234772197378334, 0.09360008800285868, 0.22100491361925378, 0.6440193671733141, 0.8392887515947223, 0.4396528849611059, 1.0123940440826118, 2.1886730566620827, 2.920786184258759, 4.455240983515978, 10.398555267602205, 14.636456463485956, 23.102389834821224, 31.110129542648792, 46.13737888634205, 55.075369477272034, 54.90215577185154, 71.93209335207939, 79.92390051484108, 79.96651902794838, 85.94133362174034, 60.6448370218277, 68.89791816473007, 85.90677067637444, 81.49565577507019, 72.72219255566597, 65.04634603857994, 75.91085225343704, 79.15957912802696, 71.91800370812416, 66.43514111638069, 72.32042491436005, 66.51099264621735, 62.551209926605225, 61.8880695104599, 65.05395323038101, 62.208194732666016, 65.29431313276291, 61.62220157682896, 61.46591976284981, 64.6977299451828, 64.2239485681057, 68.31912562251091, 66.78995847702026, 66.48393049836159, 47.66602165997028, 27.87066277116537, 8.005722966045141, 0.8628465374931693, 0.0900309588178061, 0.04513187042903155, 0.14073005004320294, 0.01579032359586563, 0.017139670526375994, 0.06841385940788314, 0.05096945562399924, 0.07460839537088759, 0.042419376331963576, 0.035972332043456845, 0.02724220401432831, 0.038682788945152424, 0.04398587567266077, 0.01685118659224827, 0.05915106972679496, 0.053546196068054996, 0.041436464816797525, 0.020499818347161636, 0.02850418160960544, 0.03616139787482098, 0.008798627331998432, 0.028089235711377114, 0.033601830728002824, 0.027160077952430584, 0.04602342356520239, 0.05725560971768573, 0.10717376120737754, 0.10160412100958638, 0.01631799059396144, 0.050808906817110255, 0.07786086498526856, 0.011961677428189432, 0.08003797003766522, 0.03787715053476859, 0.03345652934513055, 0.02068257406790508, 0.006946419689484173, 0.037501349215744995, 0.010289144665875938, 0.03925979392079171, 0.0541776190220844, 0.0202116906439187, 0.015881359140621498, 0.02423406611342216, 0.03639607239165343, 0.012285772390896454, 0.022574954164156225, 0.01292053686483996, 0.00160247958774562, 0.03038398972421419, 0.013472074115270516, 0.07397253066301346, 0.006740981152688619, 0.018083515387843363, 0.02178034592361655, 0.07523355088778771, 0.02678561992070172, 0.024152309269993566, 0.03700189496157691, 0.014049490055185743, 0.04853035759879276, 0.00817070082121063, 0.021020230851718225, 0.06099452744820155, 0.02471688512741821, 0.019132771194563247, 0.005920738203712972, 0.03574322363419924, 0.04824967363674659, 0.022604460100410506, 0.03714986807608511, 0.03871998538670596, 0.01374829498672625, 0.020410710530995857, 0.056875448281061836, 0.07982081762747839, 0.014590512928407406, 0.05051517960964702, 0.02908610702434089, 0.023212349551613443, 0.022071319763199426, 0.03876405411574524, 0.040413276947219856, 0.0386236360645853, 0.017605050925340038, 0.019009750940313097, 0.045031324261799455, 0.051265424117445946, 0.0581708373647416, 0.014625851217715535, 0.05898422750760801, 0.0245142027415568, 0.007701145841565449, 0.05993250299070496, 0.040486593716195785, 0.05173178229597397, 0.05220594415732194, 0.039010595573927276, 0.054614666078123264, 0.007377529100267566, 0.02651698287081672, 0.024834129617374856, 0.04570878634694964, 0.028207227915117983, 0.041141939800581895, 0.06951444956939667, 0.03677061577036511, 0.047450918646063656, 0.04031842305266764, 0.020101847221667413, 0.09296460179029964, 0.01778400499460986, 0.043790932031697594, 0.026440237379574683, 0.021528208671952598, 0.03329852239403408, 0.03818624019913841, 0.0883745816827286, 0.08809990540612489, 0.016647442935209256, 0.02735396959906211, 0.0018397876851850015, 0.01382308770189411, 0.029200388489698526, 0.01447259122869582, 0.0362429042434087, 0.02723844132560771, 0.05456672704895027, 0.06765402635210194, 0.22931432555196807, 0.7704442832618952, 1.095537857618183, 0.7012826506979764, 1.0651290393434465, 2.4407493928447366, 2.9510354110971093, 5.414266772568226, 11.294148210436106, 16.801233552396297, 27.31140688061714, 35.965685695409775, 51.818241253495216, 63.56300063431263, 66.07792988419533, 82.56279051303864, 91.77221953868866, 89.68783378601074, 95.97002148628235, 72.54912704229355, 79.65641766786575, 99.24454897642136, 90.6649361550808, 81.78101286292076, 77.65873566269875, 84.87558200955391, 87.53227785229683, 83.02939027547836, 76.94388762116432, 80.90902045369148, 76.45001292228699, 73.14803570508957, 70.35406842827797, 72.32651978731155, 72.38645777106285, 73.87346997857094, 68.69426429271698, 72.0884245634079, 75.17751440405846, 74.58605334162712, 79.85295072197914, 77.78898507356644, 78.79984483122826, 60.1123221963644, 38.19391652941704, 12.0562638156116, 1.7297012661583722, 0.08839754373184405, 0.044206082020536996, 0.06506640231236815, 0.12696144432993606, 0.02406933344900608, 0.06949730595806614, 0.06421624988433905, 0.07203503540949896, 0.023173474000941496, 0.04536480089882389, 0.012038065760862082, 0.031528793333563954, 0.042278694818378426, 0.03658648522105068, 0.03164195230056066, 0.07859763951273635, 0.054563680532737635, 0.07844802996260114, 0.025536659595672973, 0.005840756484758458, 0.014369052350957645, 0.02923820647993125, 0.03753061580937356, 0.032908260327531025, 0.043176556209800765, 0.046947030059527606, 0.06245017590117641, 0.04114785471756477, 0.037514099312829785, 0.028712747371173464, 0.048403680411865935, 0.07533528449130245, 0.06302687659626827, 0.03261069250584114, 0.03954790307034273, 0.021895831523579545, 0.03797828670940362, 0.01573949946759967, 0.01772482613887405, 0.01727984181343345, 0.02990915992995724, 0.053903169100522064, 0.03381607020855881, 0.03091476817644434, 0.050482558508520015, 0.029876227126806043, 0.0020904785606035148, 0.05054850575106684, 0.028775510800187476, 0.022190195122675505, 0.01849633874371648, 0.052546289371093735, 0.023809019585314672, 0.02941075581475161, 0.04565175600873772, 0.037859713775105774, 0.05755538171797525, 0.015831468263058923, 0.009123232521233149, 0.05839311059389729, 0.03773386779357679, 0.018964633927680552, 0.07542069084593095, 0.07509691407904029, 0.058465711190365255, 0.049825995301944204, 0.06923966197064146, 0.009717857010400621, 0.02599948515126016, 0.18248911161208525, 0.20420895394636318, 0.11422466137446463, 0.13405079516815022, 0.10345024304115213, 0.14941414265194908, 0.12091029871953651, 0.13832681259373203, 0.1182245033851359, 0.17902463267091662, 0.14929015946108848, 0.10098159269546159, 0.07744113594526425, 0.11251083458773792, 0.14361096342327073, 0.09054692214704119, 0.1976310319150798, 0.1130914464010857, 0.1948050077771768, 0.2980621811002493, 0.10394305136287585, 0.18623412237502635, 0.16131875541759655, 0.12019837129628286, 0.2461939401109703, 0.11683066099067219, 0.09463699447223917, 0.12945053342264146, 0.1108170828956645, 0.15631691756425425, 0.06276002997765318, 0.21429828833788633, 0.10000516384025104, 0.2234500675695017, 0.13769545272225514, 0.09537461504805833, 0.3462566278176382, 0.13881103426683694, 0.08728848566533998, 0.25973233161494136, 0.07463571382686496, 0.12751519039738923, 0.137323800008744, 0.14047518168808892, 0.13655103131895885, 0.14397016289876774, 0.11570537215447985, 0.17839541018474847, 0.2612611261429265, 0.1481683735619299, 0.11656893519102596, 0.09879397141048685, 0.12589436955749989, 0.17639440193306655, 0.0986558354634326, 0.11895842806552537, 0.16815127863083035, 0.11533921875525266, 0.12838103924877942, 0.1551181115792133, 0.45858557685278356, 1.2460638117045164, 1.629189772065729, 1.2980088056065142, 2.423957143910229, 4.128724979236722, 4.7733917366713285, 8.40776989236474, 16.701568700373173, 22.586805000901222, 34.58782643079758, 42.22030587494373, 58.46324488520622, 73.10229375958443, 77.3487862944603, 95.90939953923225, 103.3481615781784, 102.61245265603065, 107.38996669650078, 83.05091232061386, 91.56547263264656, 109.55756798386574, 102.06983417272568, 97.13196113705635, 90.21779894828796, 96.93969905376434, 99.47610855102539, 96.60612255334854, 88.78223598003387, 94.0599475800991, 89.21909853816032, 83.903578966856, 80.53255945444107, 87.3490896821022, 85.6908206641674, 87.92295768857002, 81.37454867362976, 83.71381714940071, 87.45898738503456, 85.16471609473228, 89.56316247582436, 88.29211547970772, 91.51526212692261, 69.10638257861137, 43.7412578612566, 13.28601747751236, 2.3329392028972507, 0.44723911851178855, 0.08581461748690344, 0.2269365734537132, 0.16123962763231248, 0.15391405118862167, 0.17221403250005096, 0.1997756605851464, 0.18394288985291496, 0.13500642904546112, 0.15664889506297186, 0.08993175593786873, 0.1319475783384405, 0.1556857061223127, 0.14281802315963432, 0.15647193737095222, 0.13730594393564388, 0.20107271207962185, 0.14165865490213037, 0.13648224907228723, 0.11003071806044318, 0.08419537742156535, 0.0923141761450097, 0.15565260633593425, 0.14789023145567626, 0.1674671669024974, 0.18649645673576742, 0.24605213053291664, 0.1670524844666943, 0.08949322087573819, 0.12757398333633319, 0.1402482477715239, 0.13873641873942688, 0.17947808490134776, 0.22804059233749285, 0.11123017713543959, 0.16133929806528613, 0.12070838260115124, 0.0910536086303182, 0.13740116148255765, 0.1288415864109993, 0.10094530167407356, 0.08896976185496897, 0.13377905037486926, 0.1581681752577424, 0.1277455233503133, 0.07976575769134797, 0.1042240284732543, 0.10792949018650688, 0.09432535924133845, 0.18203387822723016, 0.1369553236872889, 0.37337639601901174, 0.08830000326270238, 0.13286283938214183, 0.20611916785128415, 0.19703672005562112, 0.13176276872400194, 0.0863319389463868, 0.08415694901486859, 0.1218540508125443, 0.08801913005299866, 0.1835925516206771, 0.12846556986914948, 0.1517077797325328, 0.08353033888852224, 0.13681194075616077, 0.14632606616942212, 0.11655226655420847, 0.16954758495558053], [0.01666203541390132, 0.05670427934092004, 0.05206960420764517, 0.0370275918248808, 0.10426670196466148, 0.028381126103340648, 0.008919763458834495, 0.03952845880121458, 0.021595705147774424, 0.009318443335359916, 0.03670228994451463, 0.032387216997449286, 0.006814634207330528, 0.01700894492387306, 0.008525534612999763, 0.09075170295545831, 0.0222709778972785, 0.0453208434919361, 0.02868756630050484, 0.06886628005304374, 0.06532578292535618, 0.08748342559556477, 0.05143355767359026, 0.04558258042379748, 0.011946934664592845, 0.05910085601499304, 0.0613175991747994, 0.11372197506716475, 0.04584253620123491, 0.015945311861287337, 0.026790950396389235, 0.04940541650285013, 0.01847856430686079, 0.012783567945007235, 0.05216857331106439, 0.006249127418413991, 0.054962095091468655, 0.041412675273022614, 0.06270968267926946, 0.02450684620271204, 0.06205963181855623, 0.020705474889837205, 0.03831046458799392, 0.05881088407477364, 0.012754254967148881, 0.027927677583647892, 0.029526794314733706, 0.04600087340804748, 0.025120531827269588, 0.03959242450946476, 0.16592109517659992, 0.10709454436437227, 0.01225564954438596, 0.037249753731884994, 0.04946823188220151, 0.013159477803128539, 0.07033924281131476, 0.15420172247104347, 0.7741277106106281, 5.343687459826469, 6.303469408303499, 8.395450003445148, 12.960588689893484, 13.002949766814709, 12.256210036575794, 16.50512684136629, 26.565102227032185, 30.00041238963604, 39.77078251540661, 52.69599795341492, 60.73884017765522, 66.77813351154327, 62.544032111763954, 70.48877879977226, 72.78269290924072, 65.81380605697632, 59.799560979008675, 57.56217263638973, 56.7250357568264, 44.56063449382782, 48.75317372381687, 41.422462686896324, 48.15562538802624, 27.4651238322258, 32.81426779925823, 39.65235807001591, 55.02489298582077, 36.33790612220764, 35.944600626826286, 47.278081476688385, 42.13630758225918, 56.29534341394901, 57.62869946658611, 54.52836222946644, 49.49256084859371, 54.08566318452358, 56.19505159556866, 64.8538027703762, 61.329830065369606, 54.28523987531662, 56.75019420683384, 62.454242929816246, 74.27613437175751, 71.03336557745934, 65.37917017936707, 52.3682427406311, 29.50777642428875, 12.351807206869125, 3.4078032011166215, 0.49622139951679856, 0.11183532435097732, 0.03598479270294774, 0.05945615179371089, 0.025415526251890697, 0.04300684558984358, 0.02181845520681236, 0.013082112618576502, 0.056669183177291416, 0.04599348161718808, 0.028596326665137894, 0.05926078141783364, 0.07794837161782198, 0.014994732937338995, 0.06407433640561067, 0.03005020880664233, 0.05036633447161876, 0.03436350431002211, 0.04353013020590879, 0.040958395547932014, 0.052281142270658165, 0.07006272600847296, 0.06422479942557402, 0.011119482678623172, 0.031448133013327606, 0.05532568808121141, 0.01577095354150515, 0.054043230920797214, 0.08012478647287935, 0.03414883067307528, 0.012839869123126846, 0.021345284112612717, 0.05068302001745906, 0.045014373608864844, 0.06752202796633355, 0.043854188988916576, 0.08094574281130917, 0.14909495977917686, 0.11027009037206881, 0.016219179196923506, 0.03948096506064758, 0.06297261817962863, 0.03690857360197697, 0.0565216776158195, 0.05625586629321333, 0.05126439253217541, 0.050896832763100974, 0.01938878616783768, 0.021074799115012866, 0.06803540120017715, 0.05628742612316273, 0.010703642492444487, 0.026085130848514382, 0.03867749743221793, 0.03533520568453241, 0.027902626388822682, 0.07973355590365827, 0.08919610205339268, 0.024141787471307907, 0.027702480292646214, 0.021100022859172896, 0.0066586194589035586, 0.029683313259738497, 0.022645632598141674, 0.036748818893102, 0.060838264544145204, 0.03228196190320887, 0.020045215787831694, 0.07986213298863731, 0.008788351369730663, 0.0307415286442847, 0.0069230833196343156, 0.027309676370350644, 0.059202545089647174, 0.02246083226054907, 0.03403881099075079, 0.02482371543010231, 0.013105610869388329, 0.04846288153203204, 0.023147374522523023, 0.01269180324015906, 0.012337950010987697, 0.0752499968803022, 0.023450968583347276, 0.02712864243221702, 0.0253231028909795, 0.04418638171046041, 0.014777621345274383, 0.05127716118295211, 0.017960248369490728, 0.06935516983503476, 0.01868463459686609, 0.09156459214864299, 0.009126008153543808, 0.0544287061347859, 0.019046561465074774, 0.019084915657003876, 0.0108877331513213, 0.08433200680883601, 0.027989834306936245, 0.010822159765666584, 0.07540443039033562, 0.03800415426667314, 0.007778699346090434, 0.040838453351170756, 0.022542958322446793, 0.01451978532713838, 0.036917820762027986, 0.06893374127685092, 0.08035563892917708, 0.02612079475511564, 0.028863700208603404, 0.07580310470075347, 0.01844021382567007, 0.0430513039464131, 0.02742610635323217, 0.033175311036757194, 0.041008074913406745, 0.04739552103274036, 0.04382577957585454, 0.07072253240039572, 0.03791511138842907, 0.030653689900645986, 0.033847207014332525, 0.31287037243600935, 0.8889479306526482, 5.454115709289908, 7.12102166377008, 10.1335983350873, 15.084571167826653, 13.851075656712055, 13.151321355253458, 19.049637503921986, 28.40751126408577, 34.02535021305084, 45.23842312395573, 60.36883503198624, 70.49065589904785, 76.7364339530468, 75.17594888806343, 80.2270482480526, 82.06082224845886, 77.75803953409195, 68.82597282528877, 68.68385285139084, 66.47437021136284, 53.146528378129005, 58.02377566695213, 52.423681765794754, 56.92894421517849, 38.63764151930809, 42.65209190547466, 52.41855964064598, 67.62424170970917, 45.56270532310009, 46.231359243392944, 58.87900337576866, 51.6313710808754, 63.25080178678036, 67.65508085489273, 63.68850030004978, 58.4964133054018, 62.25806325674057, 65.4162485897541, 75.79802110791206, 72.27377101778984, 65.00533863902092, 66.118124127388, 72.74343341588974, 83.01385670900345, 81.25570625066757, 77.4951620399952, 63.78836274147034, 38.1956872344017, 16.821967139840126, 4.507679594680667, 0.8810451265890151, 0.0753430621989537, 0.08134189381962642, 0.007359289429587079, 0.029121115985617507, 0.04471450884011574, 0.0610224915726576, 0.03778225953283254, 0.026763676469272468, 0.02750381849182304, 0.051390349835855886, 0.06654546552454121, 0.07251937582623214, 0.04774987799464725, 0.03513009833113756, 0.05457935098093003, 0.06450579880038276, 0.04359317936177831, 0.03536759671987966, 0.03818915312876925, 0.01848617317591561, 0.013782775167783257, 0.025490429361525457, 0.041113834668067284, 0.06081044142774772, 0.02601841919386061, 0.06596057894057594, 0.047238627303158864, 0.043325753867975436, 0.017070233334379736, 0.014213704143912764, 0.06553307219292037, 0.039232891067513265, 0.06736011360771954, 0.05331357730028685, 0.02328418573597446, 0.019019873834622558, 0.056945380856632255, 0.07393243242404424, 0.004837765700358432, 0.00917908006158541, 0.05376326313125901, 0.048245510188280605, 0.024612244160380214, 0.02839731048879912, 0.03537943397532217, 0.030436695196840446, 0.02963801071018679, 0.02725662950979313, 0.024609190222690813, 0.05169784388272092, 0.06786157537135296, 0.00871695212481427, 0.027189133033971302, 0.0019211826156606548, 0.035704487236216664, 0.03008599887834862, 0.05627055710647255, 0.052186971151968464, 0.024366012548853178, 0.057519020192557946, 0.047048945489223115, 0.02398333152086707, 0.038988468440948054, 0.045628200241480954, 0.048987153204507194, 0.04825356249057222, 0.10970536051900126, 0.21858137100934982, 0.2088195167016238, 0.13935860566562042, 0.159529288939666, 0.13677633251063526, 0.14090717100771144, 0.08706915876246057, 0.0906520473654382, 0.13933099777204916, 0.07765318980091251, 0.11268774775089696, 0.1707135434844531, 0.10221170246950351, 0.08656167075969279, 0.22284079401288182, 0.09362869779579341, 0.13462484639603645, 0.1301719158072956, 0.06530777100124396, 0.15121451870072633, 0.21884602087084204, 0.33001065894495696, 0.1427117921411991, 0.12091602067812346, 0.3095706651220098, 0.1721907884348184, 0.22943839780054986, 0.17859947110991925, 0.10397105259471573, 0.1179075321124401, 0.14372133562574163, 0.1142505400639493, 0.10352586046792567, 0.21313513512723148, 0.12545638368465006, 0.13446552213281393, 0.14962231507524848, 0.2009940444258973, 0.0882657605689019, 0.2521986124338582, 0.10158641336602159, 0.11009987138095312, 0.08278186069219373, 0.08171040724846534, 0.15141296898946166, 0.12852871179347858, 0.177339022338856, 0.08612386300228536, 0.08406051434576511, 0.20116827101446688, 0.22539939265698195, 0.11301893115160055, 0.1493341539753601, 0.09601450219633989, 0.16341380862286314, 0.2111336964298971, 0.6158932170365006, 1.9675680273212492, 7.946117939427495, 10.57965924963355, 14.912263713777065, 21.410703510046005, 20.599922016263008, 20.55524591356516, 26.981145702302456, 37.80064903199673, 43.759097903966904, 56.06042481958866, 70.47769099473953, 80.53144231438637, 88.56670394539833, 86.44150838255882, 91.6241642832756, 92.59935915470123, 87.57033661007881, 79.479119181633, 79.89625319838524, 75.94230696558952, 64.36816602945328, 67.72463992238045, 60.8005640655756, 68.58885034918785, 46.30236603319645, 50.36894962191582, 60.60205511748791, 73.85953232645988, 55.22144503891468, 53.68737995624542, 68.6810790002346, 61.75347313284874, 74.79661524295807, 78.71523097157478, 75.59328809380531, 69.03727948665619, 75.18772065639496, 77.5549328327179, 84.67327326536179, 80.9205262362957, 75.80188930034637, 76.16280913352966, 85.16098469495773, 94.01247292757034, 94.30770948529243, 89.68772739171982, 73.32194477319717, 43.42655494809151, 19.975155740976334, 5.888502700254321, 1.321177112404257, 0.3142764454241842, 0.15758308087242767, 0.1389952946919948, 0.09284765415941365, 0.12680743384407833, 0.15218769694911316, 0.05628482860629447, 0.1060644508106634, 0.09433125189389102, 0.23791638115653768, 0.25931070267688483, 0.2048730425303802, 0.17147838603705168, 0.17049052810762078, 0.10619794833473861, 0.14422093459870666, 0.08763681267737411, 0.10568444151431322, 0.11367165003321134, 0.17109217238612473, 0.12093341661966406, 0.13153386069461703, 0.11112682564998977, 0.19765853590797633, 0.1545553409960121, 0.16286362486425787, 0.12300702175707556, 0.1990055784699507, 0.23101249302271754, 0.09668301398050971, 0.12418167825671844, 0.213856918271631, 0.19022833148483187, 0.11207874878891744, 0.14518709213007241, 0.15892038645688444, 0.29467680025845766, 0.15156181412748992, 0.094758714112686, 0.10307083488442004, 0.20256500778486952, 0.11680941330268979, 0.10774361187941395, 0.15657665440812707, 0.12634477898245677, 0.09739329383592121, 0.15613446797942743, 0.07723783201072365, 0.08705155501957051, 0.11699719150783494, 0.15179824753431603, 0.13950752501841635, 0.1195857506536413, 0.14383966365130618, 0.13776861364021897, 0.18565072008641437, 0.1708033581962809, 0.14238879462936893, 0.11701043142238632, 0.1535506363143213, 0.15205087460344657, 0.06920627274666913, 0.1553757258807309, 0.10978981692460366, 0.17108920379541814, 0.1679015756235458], [0.04173287859885022, 0.0092088939891255, 0.04456368587852921, 0.0611558146920288, 0.02253687271149829, 0.05268621760478709, 0.03167425427818671, 0.029882342423661612, 0.013170563634048449, 0.03213548050553072, 0.08051838449318893, 0.08673335178173147, 0.01236331476320629, 0.04635383142158389, 0.05661879506078549, 0.06219375274667982, 0.019302992041048128, 0.013970170239190338, 0.03792579831497278, 0.02288309387949994, 0.02827622909535421, 0.05444987218652386, 0.008308715241582831, 0.009846535213000607, 0.00805341273007798, 0.031761913051013835, 0.07384655109490268, 0.024972304527182132, 0.04672021859732922, 0.01020880532450974, 0.03987267802585848, 0.027553111940505914, 0.044022812362527475, 0.04727653620648198, 0.0273069192917319, 0.014220191442291252, 0.03978269262006506, 0.049147802201332524, 0.08731124733458273, 0.00511121047566121, 0.0566950581560377, 0.03100829362665536, 0.03424263071792666, 0.04071998431754764, 0.03385329633601941, 0.06298839623923413, 0.03194863740645815, 0.034098156829713844, 0.035890291328541934, 0.03710872340889182, 0.0323161266715033, 0.03166383452480659, 0.013018634872423718, 0.11450313744717278, 0.07810404451447539, 2.3833211744204164, 5.529933990910649, 12.563761733472347, 17.625479623675346, 32.583821564912796, 32.44620054960251, 38.875314965844154, 40.78843630850315, 43.84483650326729, 50.94714939594269, 49.12235431373119, 58.55977110564709, 60.67211955785751, 64.48467537760735, 62.58222006261349, 59.101477637887, 58.109924644231796, 46.341971307992935, 46.95927858352661, 38.79934944212437, 38.31412307918072, 28.603620640933514, 29.726842269301414, 38.51613163948059, 25.121312700212002, 36.52754254639149, 39.45570342242718, 41.07329182326794, 31.815056316554546, 47.1077898144722, 22.87579469382763, 18.018743321299553, 25.435628034174442, 21.248372420668602, 21.323975063860416, 24.140226244926453, 31.477816812694073, 32.37463898956776, 38.74592050909996, 34.03612643480301, 40.60061618685722, 40.51166296005249, 34.37050849199295, 38.64388458430767, 32.79697872698307, 32.68669344484806, 49.122620299458504, 47.53671459853649, 53.61723951995373, 59.28126499056816, 72.87416160106659, 64.13299664855003, 42.95512944459915, 28.38368084281683, 12.149962037801743, 3.8032957166433334, 1.3889125152491033, 0.43274521187413484, 0.014336297663248843, 0.09639684925787151, 0.013258777162263868, 0.10334998631151393, 0.0327512404328445, 0.07433098799083382, 0.03321070034871809, 0.04185974132269621, 0.025779915195016656, 0.04544358358543832, 0.02579600681201555, 0.08634308600449003, 0.006654792296103551, 0.02448996605380671, 0.11765964736696333, 0.007937117261462845, 0.034331265414948575, 0.015179240126599325, 0.04339675884693861, 0.05483702465426177, 0.013508529336831998, 0.046769764376222156, 0.011216873790544923, 0.02581137297966052, 0.025393076284672134, 0.033209672474185936, 0.06523246527649462, 0.01644646006752737, 0.029560649236373138, 0.023544377145299222, 0.02363317325944081, 0.01568215371662518, 0.041153116544592194, 0.032644456514390185, 0.01399036964357947, 0.025509291044727433, 0.012616491949302144, 0.03873674308124464, 0.009878773180389544, 0.052445887922658585, 0.010839999140443979, 0.01742132484650938, 0.05208405382290948, 0.008275080181192607, 0.049155869346577674, 0.03243885192205198, 0.021437536779558286, 0.03591499371395912, 0.02143655528925592, 0.04925574758090079, 0.03904422599589452, 0.020773889773408882, 0.02850030388799496, 0.06257748391362838, 0.007385580474874587, 0.04044527835503686, 0.03189652008586563, 0.06136672192951664, 0.03453214252658654, 0.028495878832472954, 0.02734653327934211, 0.022543507511727512, 0.04786272154888138, 0.01134620693846955, 0.04332612494181376, 0.02166735579521628, 0.04870414632023312, 0.06809081736719236, 0.043919208546867594, 0.018392614329059143, 0.028211755015945528, 0.026665223158488516, 0.044158673626952805, 0.07359378301771358, 0.026150033518206328, 0.005301158998918254, 0.08430812449660152, 0.04040996325784363, 0.043429595170891844, 0.04277050495147705, 0.10098925908096135, 0.10129805188626051, 0.05108453675347846, 0.017967248677450698, 0.014271602794906357, 0.04024643472803291, 0.0061915752576169325, 0.02003809673624346, 0.027304694704071153, 0.07942290772916749, 0.019131411208945792, 0.06416084856027737, 0.06421820173272863, 0.046977083329693414, 0.029867033772461582, 0.05827598484756891, 0.02463821932906285, 0.040805357275530696, 0.03610267543990631, 0.029041472407698166, 0.020041419702465646, 0.10318097702111118, 0.044796427100664005, 0.014888567784510087, 0.05812151423015166, 0.016759917270974256, 0.028951813546882477, 0.05033031433413271, 0.0056254891296703136, 0.038354114003595896, 0.030994669650681317, 0.03324856472318061, 0.01930975486175157, 0.03637754467490595, 0.03329513820062857, 0.005801363749924349, 0.04329590097768232, 0.17434555484214798, 2.5712484028190374, 6.235101576894522, 14.623177126049995, 19.827035889029503, 36.40723340213299, 37.08825945854187, 42.887063696980476, 44.57461394369602, 49.33031715452671, 58.00970122218132, 58.022886514663696, 66.18401259183884, 71.06107369065285, 73.52231562137604, 72.53572136163712, 69.51637297868729, 67.65087068080902, 55.354802682995796, 58.10766376554966, 48.8103112578392, 48.670619353652, 41.31950721144676, 41.852500811219215, 47.26954713463783, 33.65367315709591, 41.69842287898064, 44.904470443725586, 43.3424274623394, 33.81590165197849, 47.88979545235634, 30.502221062779427, 32.86382853984833, 36.820468828082085, 33.17635416984558, 30.253683999180794, 32.901351526379585, 41.61192812025547, 44.08559538424015, 52.474302649497986, 41.85802571475506, 50.1335446536541, 50.92976152896881, 47.10052080452442, 48.103305995464325, 43.86490322649479, 39.56972390413284, 59.15798060595989, 56.3870856910944, 62.143108025193214, 68.75401228666306, 79.69554796814919, 77.82061457633972, 54.56694155931473, 35.05250729620457, 16.214545033872128, 5.190168572589755, 2.127833333797753, 0.4609554324997589, 0.06599685511901043, 0.047573124393238686, 0.037946608135825954, 0.1087408208695706, 0.03942972718505189, 0.020364784577395767, 0.022726465467712842, 0.058706471318146214, 0.04184129153145477, 0.025289409386459738, 0.0719926439342089, 0.09177850137348287, 0.01462680394979543, 0.03031327789358329, 0.024004373262869194, 0.06539869151310995, 0.05711807491024956, 0.015375571583717829, 0.021414572875073645, 0.034821613517124206, 0.005819123807668802, 0.049966799269896, 0.024104290459945332, 0.05301177181536332, 0.010707906130846823, 0.03004995462106308, 0.059133128306712024, 0.060868744549225084, 0.06317710955045186, 0.019606051755545195, 0.06473044690210372, 0.043674385160556994, 0.035141486587235704, 0.02268387546791928, 0.04795871464011725, 0.02698300151678268, 0.07785775538650341, 0.015738427064206917, 0.05095125816296786, 0.06960640908800997, 0.019278042891528457, 0.06434790688217618, 0.06445635692216456, 0.016883612879610155, 0.047656000024289824, 0.09505777736194432, 0.039632960615563206, 0.023168616644397844, 0.010888455817621434, 0.015514527603954775, 0.02911445335485041, 0.025935020348697435, 0.07165227274526842, 0.06625430614803918, 0.03461882166448049, 0.03311324522655923, 0.08098761478322558, 0.05285991355776787, 0.02653460145666031, 0.012499299409682862, 0.05128044147568289, 0.0501912618346978, 0.010009888410422718, 0.09403737625689246, 0.12773645430570468, 0.10494515852769837, 0.1525841373950243, 0.10884311850531958, 0.12761575140757486, 0.17098686163080856, 0.06682278384687379, 0.21309051720891148, 0.20151930686552078, 0.21013829828007147, 0.21270143886795267, 0.22754603996872902, 0.21309577161446214, 0.15217606007354334, 0.22313005349133164, 0.12991060561034828, 0.13287748937727883, 0.29361909138970077, 0.14426941168494523, 0.1396111585199833, 0.20372332219267264, 0.0823655232670717, 0.20714137237519026, 0.1622560730902478, 0.10668798844562843, 0.19467355858068913, 0.03642998111899942, 0.14986032183514908, 0.13278185622766614, 0.1275884997448884, 0.10418231977382675, 0.14088265044847503, 0.17350385547615588, 0.08885696282959543, 0.24307052255608141, 0.09038771662744693, 0.20073071558726951, 0.3049294516677037, 0.14897642395226285, 0.17711585853248835, 0.16104307724162936, 0.1394500382593833, 0.09947654689312913, 0.15753178362501785, 0.11616599353146739, 0.12302272560191341, 0.13145391654688865, 0.21230387035757303, 0.1339304039720446, 0.21462866279762238, 0.21039034647401422, 0.0879385179723613, 0.19721885793842375, 0.2652830322040245, 3.983943248167634, 9.324514400213957, 20.559995658695698, 28.978478126227856, 46.52900107204914, 47.51714564859867, 53.985679149627686, 55.01271843910217, 59.32545281946659, 71.26909732818604, 69.54815447330475, 76.55712157487869, 82.56895378232002, 85.7874646782875, 82.22923681139946, 81.24679952859879, 79.06616494059563, 68.70204627513885, 68.4003196656704, 56.252211928367615, 56.42617039382458, 45.69518521428108, 47.102572694420815, 56.88973791897297, 42.3600547760725, 54.25492890179157, 56.463959366083145, 60.76804921030998, 49.31354485452175, 61.73835374414921, 38.03149424493313, 33.72524991631508, 41.42267547547817, 35.94723388552666, 35.76172783970833, 39.07818228006363, 49.481226056814194, 51.46372027695179, 58.66087608039379, 53.86830724775791, 60.4461532831192, 60.2533820271492, 52.83675380051136, 60.15443533658981, 49.83545824885368, 51.35758817195892, 68.12673434615135, 68.51682901382446, 75.33468157052994, 79.64362755417824, 92.99208328127861, 89.53133538365364, 63.22036921977997, 39.40800838172436, 19.898325763642788, 6.402523443102837, 2.5320190703496337, 0.6162659532856196, 0.20505552180111408, 0.2998761087656021, 0.13889737572753802, 0.2620035706786439, 0.13050359644694254, 0.18176482000853866, 0.15866431582253426, 0.08491417713230476, 0.1428973290603608, 0.14716344623593614, 0.13315956486621872, 0.2415674360236153, 0.12164164814748801, 0.19945916428696364, 0.2972191310254857, 0.2139971693395637, 0.21340811188565567, 0.15252696233801544, 0.14457863493589684, 0.17120015487307683, 0.1286446352605708, 0.12422129409969784, 0.15074950380949304, 0.2005865311366506, 0.10951289936201647, 0.1578180299839005, 0.11923517493414693, 0.088507596810814, 0.15981981006916612, 0.1367228088201955, 0.14275379769969732, 0.13937564537627622, 0.13606041233288124, 0.11693165244651027, 0.11959070077864453, 0.11502209163154475, 0.14159514190396294, 0.11474492916022427, 0.15710280742496252, 0.12407831934979185, 0.10442144717671908, 0.11853054282255471, 0.21668448607670143, 0.0935459705942776, 0.10752762464107946, 0.15500497858738527, 0.14037999382708222, 0.09126722099608742, 0.11758592241676524, 0.1965933758765459, 0.10620411558193155, 0.07695353007875383, 0.18488409637939185, 0.2210229923366569, 0.16085154376924038, 0.15024563006591052, 0.1347377270576544, 0.23302233283175156, 0.08552227067411877, 0.15211279940558597, 0.18516125885071233, 0.11528435919899493, 0.10163426704821177], [0.09518653256236576, 0.0523931657517096, 0.019213247833249625, 0.054391383528127335, 0.11123543896246701, 0.030198137392289937, 0.043320944751030765, 0.03607409533287864, 0.04436199240444694, 0.024792712210910395, 0.013716429020860232, 0.056932011066237465, 0.03839125478407368, 0.050327338321949355, 0.055032706732163206, 0.046188803753466345, 0.07689605816267431, 0.016499117300554644, 0.021238234876364004, 0.0638760493893642, 0.052748227753909305, 0.07247364468639717, 0.04881068161921576, 0.05473282340972219, 0.0666623463621363, 0.05414178071077913, 0.009455863109906204, 0.05101719427329954, 0.021089662477606907, 0.031951951095834374, 0.06372839168761857, 0.016159093065652996, 0.05323831610439811, 0.09543061751173809, 0.023769112449372187, 0.05890524815185927, 0.06457966475863941, 0.036904413864249364, 0.08652966935187578, 0.05297077186696697, 0.0453377533267485, 0.027791749525931664, 0.006278632890825975, 0.09403229254530743, 0.037294360517989844, 0.017742439158610068, 0.026295783900422975, 0.07119748464901932, 0.02808538582030451, 0.032855794197530486, 0.03494234610116109, 0.032762736300355755, 0.599298260640353, 3.6409399285912514, 15.998266339302063, 30.312708131968975, 39.70753110945225, 50.57949632406235, 57.74497702717781, 62.162300795316696, 63.34170810878277, 64.18205201625824, 59.47237193584442, 69.22090083360672, 60.34319780766964, 62.56427742540836, 66.93047493696213, 58.78970056772232, 58.050549030303955, 46.032664105296135, 43.64517241716385, 41.451078951358795, 31.199324056506157, 26.484510451555252, 16.900326535105705, 20.6937275826931, 15.232216995209455, 15.502058565616608, 24.317443035542965, 22.18191772699356, 34.81657795608044, 31.021398603916168, 41.06797590851784, 37.57238008081913, 70.32646670937538, 36.592215076088905, 11.158627532422543, 18.415236845612526, 11.524441502988338, 19.15144544094801, 16.18653103709221, 15.470810942351818, 13.958451244980097, 13.98283738642931, 20.311538390815258, 18.579306341707706, 16.927914954721928, 18.288563042879105, 22.159514129161835, 14.706255868077278, 28.118924349546432, 56.696981862187386, 46.714529916644096, 33.840763717889786, 39.061276987195015, 45.79160504043102, 45.254492461681366, 55.616129860281944, 58.5192196816206, 45.71913152933121, 32.00687952339649, 19.73646204918623, 6.193443462252617, 1.1754044657573104, 0.23859731649281457, 0.06670776579994708, 0.11044663246138953, 0.13117126218276098, 0.03655355983937625, 0.030356545103131793, 0.015303692725865403, 0.05008924621506594, 0.010998011657648021, 0.014970539850764908, 0.037732769415015355, 0.02786739478324307, 0.01758291822625324, 0.02691860165214166, 0.03783981308515649, 0.017171874169434886, 0.00508897665895347, 0.07843995539587922, 0.020118283937335946, 0.06254928972339258, 0.03397979540750384, 0.026312081463402137, 0.00614720132034563, 0.047752913378644735, 0.11260356593993492, 0.029907501229899935, 0.026294323724869173, 0.06495407826150768, 0.039726474933559075, 0.05091473336506169, 0.03205678687663749, 0.09048283769516274, 0.04924680099065881, 0.033799661323428154, 0.05641331292281393, 0.0232501601203694, 0.017606249493837822, 0.02740418516623322, 0.028804923967982177, 0.024701075526536442, 0.06545806332724169, 0.033144960907520726, 0.021814481006003916, 0.05019200769311283, 0.0602835945028346, 0.02804749547067331, 0.06501923882751726, 0.04285434908524621, 0.0338102517707739, 0.015306624209188158, 0.03000309912749799, 0.034385991384624504, 0.029379741463344544, 0.025344294917886145, 0.014771456881135236, 0.057881537068169564, 0.045064683799864724, 0.02718282848945819, 0.025122055085375905, 0.060994082159595564, 0.024426911331829615, 0.06554749954375438, 0.0833566985966172, 0.02033378135820385, 0.03889710635121446, 0.053906382599961944, 0.046716240685782395, 0.04193459062662441, 0.012244257577549433, 0.02796790755382972, 0.01860060863691615, 0.1342630197177641, 0.026192135555902496, 0.03592952125472948, 0.05589421773038339, 0.03309318868559785, 0.029710384951613378, 0.011117370340798516, 0.07163092857808806, 0.007464619202437461, 0.015029597179818666, 0.06997375734499656, 0.03639991300588008, 0.048546725665801205, 0.053928932757116854, 0.020790417402167805, 0.036011086995131336, 0.07834288247977383, 0.02364855055930093, 0.02404366256087087, 0.001904827072394255, 0.017958316930162255, 0.027304108407406602, 0.05975662512355484, 0.06062612905225251, 0.026038564792543184, 0.041295519840787165, 0.048637256550136954, 0.05133367201779038, 0.07615667127538472, 0.04087313020136207, 0.05999835004331544, 0.03854273083561566, 0.038272314486675896, 0.03370897458808031, 0.03292732981208246, 0.05271806687233038, 0.04969811583578121, 0.03444357091211714, 0.08392629693844356, 0.008338751813425915, 0.02628648107929621, 0.02455867037497228, 0.026277912984369323, 1.0073878127150238, 5.433865170925856, 20.97691308706999, 36.24224625527859, 46.669578328728676, 57.38726422190666, 64.3957145512104, 69.34960752725601, 70.558702647686, 71.68488621711731, 67.47666522860527, 77.8002780675888, 71.24312952160835, 71.5541960299015, 77.02548444271088, 71.6016174852848, 66.602962911129, 54.89108316600323, 53.44852477312088, 52.00177140533924, 41.26819096505642, 36.441986337304115, 27.38935399800539, 30.246568880975246, 25.39114572107792, 26.654444932937622, 37.94185325503349, 31.49802602827549, 40.34540668129921, 36.23637557029724, 49.33005876839161, 52.359111830592155, 70.54642170667648, 42.86047652363777, 19.486336670815945, 27.49508522450924, 19.74135048687458, 26.2944408506155, 23.451159819960594, 26.516531333327293, 24.437795877456665, 26.56478114426136, 32.39479310810566, 35.5445770919323, 27.55445133894682, 27.312822304666042, 37.65228599309921, 28.616756536066532, 32.34712466597557, 61.02555759251118, 53.76078061759472, 43.8557381182909, 47.43489906191826, 55.77118434011936, 58.54770675301552, 70.37825793027878, 69.28071722388268, 56.56924031674862, 38.17080236971378, 25.847280845046043, 9.763620737940073, 2.1461250772699714, 0.31635944615118206, 0.10606502968585119, 0.11675392292090692, 0.07211088290205225, 0.08801072151982225, 0.08058898500166833, 0.0577606894512428, 0.0088009140745271, 0.009539019829389872, 0.0317998776154127, 0.0312109908554703, 0.060924620847799815, 0.035878632188541815, 0.05537093682505656, 0.17224693932803348, 0.07969979560584761, 0.0714037571742665, 0.05079198585008271, 0.019937645192840137, 0.17945325264008716, 0.10491991066373885, 0.034795779356500134, 0.07289084300282411, 0.052204990497557446, 0.0392961146280868, 0.025454333153902553, 0.04597535837092437, 0.04397566372063011, 0.01550133592900238, 0.017070142421289347, 0.03900756018992979, 0.025847485885606147, 0.026540512662904803, 0.04538178494840395, 0.04276526167814154, 0.01772092429746408, 0.03094935596891446, 0.048871396720642224, 0.017748085047060158, 0.03199751896318048, 0.02852372421330074, 0.020155202073510736, 0.032093207773868926, 0.09503916429821402, 0.03462565684458241, 0.0405243245040765, 0.039664197611273266, 0.01205746921186801, 0.00852078579555382, 0.027003666618838906, 0.04247786127962172, 0.02259172670164844, 0.0233999273768859, 0.03152044788294006, 0.017842894412751775, 0.03266855776018929, 0.020432486999197863, 0.04521630457020365, 0.03805732914770488, 0.07010947389062494, 0.033323176539852284, 0.02090409030643059, 0.18452002841513604, 0.133404859516304, 0.1584485883358866, 0.1730881934054196, 0.2265341958263889, 0.11294899115455337, 0.13843187101883814, 0.15629425237420946, 0.16332439467078075, 0.2337567473296076, 0.0892028481757734, 0.16112383775180206, 0.21138970769243315, 0.15214272279990837, 0.2007365637109615, 0.198623075557407, 0.19853188045090064, 0.1754766918020323, 0.1892780707566999, 0.16833353525726125, 0.15576873760437593, 0.19335572695126757, 0.20530789654003456, 0.18776912125758827, 0.11941277829464525, 0.17755280539859086, 0.1549454138148576, 0.1351099883322604, 0.09542703293845989, 0.1397634472232312, 0.2232738520251587, 0.16847518156282604, 0.13585752400103956, 0.14810500899329782, 0.17960718891117722, 0.1146398855780717, 0.10690863637137227, 0.10838814487215132, 0.14579943817807361, 0.12140970473410562, 0.08377449063118547, 0.2705858851550147, 0.2100977473310195, 0.1247286782017909, 0.1602779675158672, 0.16385777620598674, 0.09749467863002792, 0.11903543330845423, 0.13237079547252506, 0.09639644849812612, 0.13482688867952675, 0.07181028340710327, 1.8152613937854767, 8.503333814442158, 26.46703328937292, 45.27734823524952, 55.18674910068512, 67.90256917476654, 75.48717498779297, 80.32255232334137, 83.06971371173859, 84.45431381464005, 78.53565260767937, 89.4885116815567, 80.99212199449539, 81.84959158301353, 87.90642857551575, 80.88392660021782, 76.85567155480385, 65.3343477845192, 62.94578455388546, 59.80505168437958, 49.95302774012089, 42.62951731681824, 32.308017164468765, 38.03607679903507, 27.75658529251814, 28.35295759141445, 40.28660863637924, 37.376990765333176, 51.062199622392654, 48.25286976993084, 56.048166677355766, 54.05106224119663, 83.10366868972778, 50.624375715851784, 22.803991846740246, 29.85411074012518, 21.199719831347466, 32.36512050032616, 28.868956603109837, 28.893062509596348, 25.238931588828564, 26.481117233633995, 34.17935974895954, 32.624844163656235, 28.715135157108307, 31.793291084468365, 36.36859707534313, 26.810534857213497, 45.11432558298111, 71.73190489411354, 62.72120900452137, 55.01733899116516, 60.88562250137329, 72.40555554628372, 70.47696903347969, 83.04465785622597, 79.10568282008171, 64.92117315530777, 44.3921173363924, 29.876529537141323, 12.151205521076918, 3.4361138194799423, 0.6968472199514508, 0.25469884858466685, 0.2743964275578037, 0.18052853556582704, 0.22376346169039607, 0.1707539163180627, 0.11898600627318956, 0.14994828117778525, 0.10473581351106986, 0.16490610432811081, 0.1577888338943012, 0.1272436830913648, 0.08872378442902118, 0.20198883401462808, 0.2744351973524317, 0.14895258616888896, 0.13904164923587814, 0.1381765425321646, 0.13089016632875428, 0.20807490509469062, 0.4586467891931534, 0.10114551085280254, 0.11548482812941074, 0.10322079324396327, 0.148779547016602, 0.10552807099884376, 0.13570766954217106, 0.18845563754439354, 0.12251192762050778, 0.11865205466165207, 0.08071352480328642, 0.2225762777379714, 0.13400070019997656, 0.10958894723444246, 0.13026873639319092, 0.08535853805369698, 0.11818079088698141, 0.11980536699411459, 0.20524606079561636, 0.14479261095402762, 0.15252665063599125, 0.2054772843257524, 0.1309412409318611, 0.1539918579510413, 0.19656428368762136, 0.14088322932366282, 0.13797975465422496, 0.106794716703007, 0.11804807261796668, 0.09926828541210853, 0.09873181654256769, 0.04112730464839842, 0.09808756556594744, 0.09518892227788456, 0.17399557284079492, 0.17520888039143756, 0.15063507948070765, 0.12028126177028753, 0.16350780904758722, 0.20646912016673014, 0.12497079645982012, 0.1065366571128834], [0.07157560889027081, 0.09544748652842827, 0.037299366304068826, 0.05297102419717703, 0.025034555874299258, 0.03728016323293559, 0.08360212683328427, 0.02323594242625404, 0.011720468301064102, 0.03763432723644655, 0.05722344132664148, 0.06079459286411293, 0.08545233809854835, 0.02602577573270537, 0.026993601240974385, 0.04912363787298091, 0.012284648037166335, 0.0212811050369055, 0.041346253055962734, 0.04731997039925773, 0.047197156090987846, 0.06839483074145392, 0.05385280695918482, 0.03568977786926553, 0.031205554623738863, 0.00817180291051045, 0.02909928014560137, 0.05991219040879514, 0.055716773931635544, 0.09408980156877078, 0.017209694015036803, 0.012804887992388103, 0.028922090532432776, 0.019495681408443488, 0.02256879619380925, 0.017885540073621087, 0.02767087036772864, 0.04767118065501563, 0.034660285455174744, 0.08024671391467564, 0.017185446195071563, 0.02048450227448484, 0.01004156976705417, 0.05907428712816909, 0.062415688298642635, 0.019075347518082708, 0.027024494993383996, 0.017963226237043273, 0.033253885922022164, 0.05558618933719117, 0.5305788293480873, 4.472646899521351, 19.652961529791355, 41.495103389024734, 52.7512963861227, 61.52137018740177, 63.38446341454983, 67.30584919452667, 58.31592679023743, 59.71671782433987, 56.26287795603275, 62.385451421141624, 58.09835806488991, 61.39606811106205, 56.064612194895744, 52.74746619164944, 49.448847994208336, 32.52866752445698, 37.62904644012451, 30.308302268385887, 16.565868481993675, 12.153112068772316, 17.17460911720991, 14.941691234707832, 16.7209305614233, 13.533646389842033, 25.24568572640419, 18.14500104635954, 20.431718342006207, 31.57697819173336, 37.63231426477432, 24.702046997845173, 19.521332792937756, 24.123531840741634, 50.20785726606846, 28.15196357667446, 33.33664856851101, 59.90559808909893, 45.500289872288704, 42.70973861217499, 28.16256880760193, 19.617313742637634, 19.654943123459816, 22.50501438975334, 14.597138073295355, 14.37710328027606, 28.27726185321808, 25.25912370532751, 15.680689830332994, 14.584443904459476, 38.43030944466591, 32.896335795521736, 52.96608366072178, 46.802571192383766, 30.149425193667412, 38.44061829149723, 40.31934008002281, 58.6559971421957, 49.28828381001949, 59.3364380300045, 58.09450127184391, 54.81053128838539, 36.42742171883583, 25.48969153314829, 14.943638630211353, 5.9001215267926455, 3.5288886912167072, 0.9949041169602424, 0.35530919674783945, 0.05654997570673004, 0.04881267057498917, 0.036969986322219484, 0.03634218133811373, 0.02440065971313743, 0.014531116994476179, 0.03853448557492811, 0.011829833965748549, 0.009739300439832732, 0.05090761616884265, 0.009058377163455589, 0.02047561134531861, 0.017168656959256623, 0.04057443802594207, 0.008548498517484404, 0.01751339754264336, 0.03851115616271272, 0.02490853177732788, 0.0300931513265823, 0.05549335779505782, 0.019541698275133967, 0.04922084066492971, 0.050530527223600075, 0.06456354531110264, 0.040539716646890156, 0.038669775385642424, 0.02681872712855693, 0.018159925057261717, 0.03441244894929696, 0.019996903829451185, 0.04741534008644521, 0.010479790344106732, 0.029735315547441132, 0.007515019378843135, 0.08594474566052668, 0.015092227949935477, 0.0331503897177754, 0.05677444198227022, 0.097160645382246, 0.03685207018861547, 0.022469335417554248, 0.07369737199041992, 0.023372263822238892, 0.039230274996953085, 0.048177288263104856, 0.04697263415437192, 0.041943292308133096, 0.02435460759443231, 0.016823094447318, 0.052874574685120024, 0.021717359850299545, 0.02447667604428716, 0.08593693084549159, 0.03709885284479242, 0.0204550315902452, 0.01977447660465259, 0.07127436372684315, 0.10006832060753368, 0.0895300239790231, 0.029367677852860652, 0.0385144364554435, 0.02235769970866386, 0.018018480986938812, 0.049811697826953605, 0.034799085624399595, 0.03702611866174266, 0.03417927728150971, 0.021790468817926012, 0.041804447610047646, 0.037644680196535774, 0.02230272140877787, 0.012152429790148744, 0.057507943638483994, 0.0665201731317211, 0.05506076733581722, 0.0493582381750457, 0.07177177336416207, 0.036459017646848224, 0.03459048275544774, 0.05948263162281364, 0.024633970533614047, 0.026672770800360013, 0.02125243587215664, 0.04497010449995287, 0.03960541209380608, 0.025508261314826086, 0.1153960672672838, 0.016427325645054225, 0.026094875247508753, 0.05018801864935085, 0.03738835723197553, 0.04695457399066072, 0.044589531171368435, 0.023202343545563053, 0.04989874803868588, 0.033957063424168155, 0.056454609730280936, 0.011122319538117154, 0.03219347563572228, 0.02012897457461804, 0.05944070770055987, 0.043537766905501485, 0.019906645684386604, 0.039105902178562246, 0.06695194722851738, 0.0020197913136144052, 0.03459636427578516, 0.6806718441657722, 6.414571646600962, 26.05814293026924, 48.74893315136433, 60.721034333109856, 70.93235179781914, 70.95875278115273, 76.54578298330307, 65.93384921550751, 68.22615221142769, 64.43664595484734, 70.14008671045303, 66.2601301074028, 71.62684053182602, 64.8617671430111, 61.54230706393719, 60.06060317158699, 42.622825875878334, 48.56777787208557, 41.573713570833206, 25.523378625512123, 22.91669949889183, 29.185027442872524, 28.718193992972374, 25.471999682486057, 21.198999769985676, 34.945315048098564, 23.691430427134037, 29.650196582078934, 37.161511927843094, 44.40181441605091, 28.133228681981564, 27.27991607040167, 30.1154151186347, 55.10925605893135, 31.118090115487576, 33.983582854270935, 57.97357656061649, 29.470950700342655, 30.28827354311943, 19.150504991412163, 19.627366103231907, 22.25314300507307, 27.54563581198454, 19.260533787310123, 13.76006294041872, 18.8645551353693, 19.198296926915646, 15.26010749861598, 14.185321871191263, 40.14759689569473, 48.902342319488525, 60.745790004730225, 51.7860721796751, 36.68515808880329, 46.79551117122173, 47.443566396832466, 65.15570417046547, 58.731126710772514, 70.53621545433998, 68.86167570948601, 64.76292684674263, 47.84247659146786, 35.60771070420742, 22.469655387103558, 10.297493990510702, 6.004250189289451, 1.7911833920516074, 0.4046317673055455, 0.028920570985064842, 0.14588796155294403, 0.042045771770062856, 0.06005637485941406, 0.013906959666201146, 0.05991907382849604, 0.0343372805218678, 0.020065251919731963, 0.08217491005780175, 0.021855720297025982, 0.021940367805655114, 0.045349260326474905, 0.019233998282288667, 0.12302596136578359, 0.016392702600569464, 0.06139629280369263, 0.02010022562899394, 0.06364620625390671, 0.027263867305009626, 0.05107874429086223, 0.04001404973678291, 0.06814920212491415, 0.014537516162818065, 0.03274316586612258, 0.04869893273280468, 0.01471648043661844, 0.037976238381816074, 0.04824063056730665, 0.05257179698674008, 0.039460500338464044, 0.03797420489718206, 0.03055180230148835, 0.0291133494101814, 0.03968488868849818, 0.03512368617521133, 0.034020973471342586, 0.03778525409870781, 0.04000388231361285, 0.06935568933840841, 0.11046425104723312, 0.03126314528344665, 0.09860843449132517, 0.022737959479854908, 0.05843593622557819, 0.05100141621369403, 0.029618265871249605, 0.04580125794745982, 0.023692793693044223, 0.045303803781280294, 0.014682840737805236, 0.025994856005127076, 0.061052218297845684, 0.06473661414929666, 0.05623187265882734, 0.051028552843490615, 0.030429633661697153, 0.07796561170835048, 0.2450254582799971, 0.17612440860830247, 0.1396683484199457, 0.1352008865796961, 0.09740432957187295, 0.16665311995893717, 0.22018017974914983, 0.10707430599723011, 0.1029705633118283, 0.11322124060825445, 0.16107055154861882, 0.1694435506942682, 0.18607350677484646, 0.1069929740333464, 0.14075486746151, 0.16913927014684305, 0.1743581416667439, 0.15213711216347292, 0.1768067094963044, 0.1101949330768548, 0.2336130675394088, 0.19938837824156508, 0.17501365102361888, 0.08779294570558704, 0.12431929470039904, 0.26785430673044175, 0.13291124225361273, 0.17580059473402798, 0.11526812842930667, 0.31329689954873174, 0.12525159545475617, 0.13630052679218352, 0.07954907283419743, 0.10179022196098231, 0.1795721150119789, 0.10897890926571563, 0.15045101201394573, 0.1745574825326912, 0.1352215331280604, 0.19788956647971645, 0.07863488790462725, 0.07107639583409764, 0.09372755186632276, 0.1394960514153354, 0.1821629228652455, 0.13193643128033727, 0.2043194745783694, 0.14236574352253228, 0.12348053423920646, 0.13719741225941107, 1.3226188975386322, 10.541752483695745, 35.22682674229145, 58.40469382703304, 71.64053499698639, 81.20047241449356, 82.07847610116005, 86.01489007472992, 77.33604177832603, 77.41028979420662, 72.6188836991787, 78.86491253972054, 75.70832312107086, 78.71986672282219, 71.97569981217384, 69.3212154507637, 67.6719443500042, 52.028924748301506, 57.66611225903034, 46.59078575670719, 29.941000677645206, 22.635309398174286, 28.523931317031384, 27.957267723977566, 26.89741339534521, 24.837897308170795, 38.804243579506874, 29.60041545331478, 33.757403790950775, 46.75573110580444, 54.86821599304676, 42.4271097779274, 36.145473048090935, 39.41860981285572, 67.07411482930183, 41.297711580991745, 48.70504930615425, 73.28630268573761, 60.73592193424702, 58.057856038212776, 43.113687336444855, 32.25111901760101, 32.15667508542538, 35.97962714731693, 24.788976833224297, 25.524716153740883, 42.80623823404312, 39.78374741971493, 27.044385708868504, 26.00548915565014, 53.226312696933746, 47.40271478891373, 70.4188397526741, 63.39752331376076, 50.52254118025303, 56.79498240351677, 62.012140452861786, 77.91290402412415, 71.03078171610832, 82.11638286709785, 78.9957395195961, 73.05670380592346, 55.917480289936066, 40.93894623219967, 26.504151597619057, 13.00901424139738, 6.779263252392411, 2.016728245653212, 0.6676126574166119, 0.146223486517556, 0.19362857012310997, 0.1091298546816688, 0.12814954854547977, 0.12874638370703906, 0.07483236069674604, 0.1755113946273923, 0.09257714875275269, 0.11309214401990175, 0.18423450936097652, 0.13185427553253248, 0.08496695867506787, 0.1657756490749307, 0.23948817572090775, 0.10954104902339168, 0.1535025451448746, 0.11201720990356989, 0.2071828139014542, 0.09160708752460778, 0.19359918107511476, 0.11331152287311852, 0.14798714109929278, 0.13402268261415884, 0.13581067963968962, 0.13164356496417895, 0.1571881544077769, 0.12449422632926144, 0.13588663103291765, 0.09080918971449137, 0.06231226259842515, 0.1373548069386743, 0.11075215981691144, 0.12375941107166, 0.13195848790928721, 0.1141811566776596, 0.12453951960196719, 0.08814136177534238, 0.23474862769944593, 0.14932958234567195, 0.17284430883591995, 0.13932351692346856, 0.20912073960062116, 0.09151150632533245, 0.17685517173958942, 0.16146589361596853, 0.21031737851444632, 0.1493950397707522, 0.10410282091470435, 0.1285301218740642, 0.0941524759400636, 0.14762271690415218, 0.17401270160917193, 0.1681381871458143, 0.15014264965429902, 0.15911457681795582, 0.10335301427403465, 0.19580050982767716], [0.0651239781291224, 0.061316953506320715, 0.022958757690503262, 0.027326320887368638, 0.047625809456803836, 0.01972568039491307, 0.05367567115172278, 0.04740396296256222, 0.0637471086520236, 0.08128450353979133, 0.047378633462358266, 0.03529705929395277, 0.004823631961698993, 0.06944606808247045, 0.02819531273416942, 0.03433393343584612, 0.04856029954680707, 0.019759045499085914, 0.040037709404714406, 0.07737733350950293, 0.09431905840756372, 0.04363056505098939, 0.024507612470188178, 0.022946066965232603, 0.04380979742563795, 0.02646264652867103, 0.036023788852617145, 0.031500528639298864, 0.020641993432946038, 0.004412532707647188, 0.04275670100469142, 0.04781371011631563, 0.014569369141099742, 0.028358529561955947, 0.03021228087163763, 0.048587016863166355, 0.01497998089689645, 0.03302818025986198, 0.013240816260804422, 0.03492811541946139, 0.026150406447413843, 0.02484927128534764, 0.06052259945136029, 0.013035961237619631, 0.022802448402217124, 0.07676331762922928, 0.04229843965731561, 0.027159938799741212, 0.237914273457136, 2.870524381287396, 21.185005120933056, 41.9688505679369, 58.44330355525017, 62.1234592795372, 66.68196827173233, 65.06163641810417, 62.8433458507061, 56.956302747130394, 49.134369269013405, 41.604678109288216, 38.9845135062933, 40.324454605579376, 37.17495560646057, 38.33156794309616, 33.229490518569946, 30.01986924558878, 22.52988215535879, 20.309735387563705, 21.783704794943333, 14.183039143681526, 21.39408130198717, 23.66770450025797, 15.879863742738962, 17.763195633888245, 26.143254563212395, 33.14942881464958, 42.14598946273327, 47.947168573737144, 41.35978125035763, 41.564898043870926, 40.99768728017807, 41.49719327688217, 42.12754525244236, 53.4598595649004, 45.61932608485222, 60.32698027789593, 49.51964199542999, 44.868231788277626, 68.87022525072098, 46.05762876570225, 41.139628663659096, 50.99060386419296, 49.33654122054577, 43.130657225847244, 46.68171867728233, 79.31682229042053, 66.71346858143806, 54.853651374578476, 52.601952999830246, 53.58143404126167, 30.995016619563103, 10.764961056411266, 18.05309347808361, 45.852268785238266, 45.67816212773323, 43.65345977246761, 55.91963477432728, 63.508690148591995, 57.867056876420975, 50.998477041721344, 61.27644293010235, 61.16155989468098, 63.18826474249363, 59.95283715426922, 57.04738385975361, 40.61543919146061, 35.67711777985096, 19.723379351198673, 6.924158977344632, 3.09658280108124, 0.9597052994649857, 0.05748782030423172, 0.05284729333652649, 0.03991928861069027, 0.020455014891922474, 0.03632918633229565, 0.04588757343299221, 0.011453022398200119, 0.041722247333382256, 0.0653174782928545, 0.04916956568195019, 0.06629966621403582, 0.01599664621608099, 0.013511382894648705, 0.011230984800931765, 0.034164831376983784, 0.0629783327167388, 0.029438295059662778, 0.013232538531156024, 0.06341354295727797, 0.05392485465563368, 0.06540216476423666, 0.08004758827155456, 0.0316912754351506, 0.015486380725633353, 0.030709918719367124, 0.061485372789320536, 0.019763771124416962, 0.030518689527525567, 0.01592101023561554, 0.056498481790185906, 0.03371819206222426, 0.018984248890774325, 0.03612450571381487, 0.01627612789889099, 0.04274430342775304, 0.04649373368010856, 0.04256513042491861, 0.10461274316185154, 0.07426071402733214, 0.06848166201962158, 0.009609111039026175, 0.04792550353158731, 0.047672149157733656, 0.05624792531307321, 0.04718307012808509, 0.06175867238198407, 0.04296729282941669, 0.0177422332126298, 0.015373103015008382, 0.07880119577748701, 0.08071765856584534, 0.110869248455856, 0.0630159373395145, 0.06381648461683653, 0.008402967996516963, 0.09006753185531124, 0.043147968681296334, 0.05120170702866744, 0.03277877040090971, 0.043227233763900585, 0.0750371340836864, 0.028133566047472414, 0.022238896708586253, 0.06431917092413642, 0.07634277964825742, 0.010993142241204623, 0.08814695014734752, 0.05151585442945361, 0.029477263378794305, 0.0407128448568983, 0.00832042540423572, 0.03173677650920581, 0.03634447457443457, 0.014812719364272198, 0.019565177972253878, 0.04254636893165298, 0.06373066265950911, 0.0036289217041485244, 0.03381848960998468, 0.09919763295329176, 0.029296235006768256, 0.05085295328171924, 0.10030626799562015, 0.012519001575128641, 0.044397244419087656, 0.08165430088411085, 0.017436653906770516, 0.046142924184096046, 0.04125167746678926, 0.0342114382510772, 0.02679892106243642, 0.016281942625937518, 0.037846195555175655, 0.04165927610301878, 0.04896797239780426, 0.06581477660802193, 0.02424807786155725, 0.012113576503907098, 0.016013576459954493, 0.11227742914343253, 0.07179453503340483, 0.0354651446104981, 0.028158184941275977, 0.35265245649497956, 4.5442588068544865, 26.688878685235977, 50.537098199129105, 68.04082095623016, 71.57121911644936, 75.14270067214966, 76.5522426366806, 69.73356172442436, 65.99803537130356, 55.21533116698265, 51.59238137304783, 48.19749154150486, 48.16091850399971, 48.4618129581213, 48.06288756430149, 41.45699143409729, 39.990843906998634, 31.837780997157097, 27.131693623960018, 36.20554782450199, 26.481569409370422, 30.21766573190689, 23.403535075485706, 19.649325124919415, 24.2884885892272, 25.888554230332375, 29.428544975817204, 36.201786026358604, 35.21468259394169, 39.96253922581673, 38.65406423807144, 37.331199422478676, 41.21144860982895, 37.56981521844864, 39.611453264951706, 52.00442746281624, 41.15158662199974, 29.06865108758211, 30.47360099852085, 50.39837144315243, 44.61902596056461, 38.95151987671852, 29.067889228463173, 26.611989811062813, 27.374350503087044, 26.2159351631999, 55.28899401426315, 73.01550641655922, 55.26810273528099, 40.997254103422165, 38.040872141718864, 44.55683469772339, 17.329135425388813, 32.7627045661211, 58.104813918471336, 57.893708646297455, 53.77768971025944, 63.30450050532818, 72.8587344288826, 65.85207000374794, 58.955994844436646, 69.64396253228188, 70.51790043711662, 72.63947859406471, 71.44133448600769, 67.73232311010361, 50.73507517576218, 44.57184009253979, 26.63707796484232, 8.64340664818883, 4.535921104252338, 1.0456985444761813, 0.11529889787198044, 0.029855009124730714, 0.021624270411848556, 0.02226813361630775, 0.07117568035027944, 0.03778269739996176, 0.0672339930315502, 0.09836461671511643, 0.05462911940412596, 0.033554299880051985, 0.02833753234881442, 0.05851191730471328, 0.03828954715572763, 0.004159503023402067, 0.029269211554492358, 0.01653816354519222, 0.06276858694036491, 0.011769063203246333, 0.06885033872094937, 0.08445066137937829, 0.07562472950667143, 0.04244730334903579, 0.020383622140798252, 0.01374258508803905, 0.016785946245363448, 0.03971877886215225, 0.03231382601370569, 0.058946615463355556, 0.03230408903618809, 0.024115871674439404, 0.07027826795820147, 0.006012395297148032, 0.023907163049443625, 0.06783479868317954, 0.05276392417727038, 0.00431881893746322, 0.015015265380498022, 0.038423619844252244, 0.044700270736939274, 0.0804973000776954, 0.021321535386960022, 0.08798407841823064, 0.013581249604612822, 0.027687182773661334, 0.10190013403189369, 0.05559374068980105, 0.041186672751791775, 0.01654663516092114, 0.024657997564645484, 0.051208204531576484, 0.048253050408675335, 0.07685501739615574, 0.012174944695289014, 0.0919831708597485, 0.034995342866750434, 0.3673752414761111, 0.08665131477755494, 0.21782562718726695, 0.12529092928161845, 0.0993285106960684, 0.1423481249366887, 0.08356723847100511, 0.2076086582383141, 0.15099868731340393, 0.15336662821937352, 0.22889539803145453, 0.16292117099510506, 0.2105530846165493, 0.1925946693518199, 0.13779626606265083, 0.14331321377540007, 0.19057831348618492, 0.08378920741961338, 0.17912077048094943, 0.18130915617803112, 0.12685006280662492, 0.10322981033823453, 0.09876409996650182, 0.08991174021502957, 0.13982378382934257, 0.14466111722867936, 0.21811055252328515, 0.1856008922914043, 0.0740949998726137, 0.08090721792541444, 0.1978600290021859, 0.08710477442946285, 0.1286799318040721, 0.1750843331683427, 0.1303404723876156, 0.08129176174406894, 0.08183756683138199, 0.08190985201508738, 0.13802262110402808, 0.14315304346382618, 0.13804294110741466, 0.07894564740126953, 0.1892108767060563, 0.11468814002000727, 0.17399509786628187, 0.1870228472398594, 0.1938217956922017, 0.10833192718564533, 1.0074038431048393, 6.456310506910086, 32.81820818781853, 59.744714722037315, 77.19122394919395, 82.09706470370293, 83.60615372657776, 83.65675181150436, 80.41783601045609, 75.4319715499878, 66.44479259848595, 60.131001994013786, 57.16716483235359, 57.37317077815533, 55.82433968782425, 55.79192742705345, 48.98021534085274, 46.011218056082726, 36.699266731739044, 34.49542298913002, 35.4334482550621, 25.32983411103487, 33.244898691773415, 34.174610003829, 25.205084905028343, 28.473046347498894, 40.55643975734711, 48.96900974214077, 56.76094003021717, 63.80990758538246, 57.78644420206547, 58.58055979013443, 57.831847965717316, 61.80285908281803, 58.055918142199516, 71.05500161647797, 60.429460778832436, 75.51631942391396, 65.11617109179497, 58.984162732958794, 88.18101704120636, 60.63811518251896, 56.599722281098366, 67.15216264128685, 69.3294458091259, 58.69523383677006, 65.3848546743393, 97.91557028889656, 82.00530722737312, 69.51470106840134, 68.08160036802292, 72.15780884027481, 44.20455940067768, 20.648301020264626, 30.70066161453724, 60.19341744482517, 64.60219547152519, 62.11153171956539, 72.15493619441986, 83.1406407058239, 77.63066276907921, 71.31791710853577, 81.80052861571312, 79.78394642472267, 81.29006400704384, 82.1335731446743, 75.70640042424202, 59.18724663555622, 53.02403435111046, 29.38151489943266, 10.846586376428604, 5.971388127654791, 1.8256929027847946, 0.30712932581081986, 0.12670706579228863, 0.18437213322613388, 0.14282697346061468, 0.1442716974997893, 0.12652690202230588, 0.14303980657132342, 0.30709186219610274, 0.18381731846602634, 0.09968694575945847, 0.16194395546335727, 0.10584556177491322, 0.11351960623869672, 0.1126935810316354, 0.12156850949395448, 0.12578920723171905, 0.15668637352064252, 0.15589303249726072, 0.19161197677021846, 0.13405472855083644, 0.14721743005793542, 0.23706672596745193, 0.16095295082777739, 0.12810170970624313, 0.1264992347569205, 0.12083888927008957, 0.10016156404162757, 0.15865944733377546, 0.21656906727002934, 0.12548860773677006, 0.22343841585097834, 0.0844046259589959, 0.10362807646743022, 0.16410023585194722, 0.12199239456094801, 0.10647949689882807, 0.16735418234020472, 0.1359409562428482, 0.28101430681999773, 0.17878965387353674, 0.0866865371062886, 0.16646016156300902, 0.11322353384457529, 0.1644673169357702, 0.1855418915511109, 0.17734892258886248, 0.13451889739371836, 0.10190887653152458, 0.1437721578986384, 0.15794226550497115, 0.26960396440699697, 0.20573955931467935, 0.17881344712805003, 0.3327525977510959, 0.17022820858983323], [0.011089916442870162, 0.02197120775235817, 0.011551971092558233, 0.03686535463202745, 0.013085663795209257, 0.062296054093167186, 0.021578594933089335, 0.03553472466592211, 0.05852523143403232, 0.05227098969044164, 0.03166546353895683, 0.03582780991564505, 0.011990266812063055, 0.04213917847664561, 0.02853418107406469, 0.045740720961475745, 0.041737932624528185, 0.05455228856590111, 0.03663874354970176, 0.022078310794313438, 0.07118382913176902, 0.02548743665101938, 0.01047673640641733, 0.03615645517129451, 0.05019683165301103, 0.06880890461616218, 0.03563982761988882, 0.037549306798609905, 0.04738786577945575, 0.03264901701186318, 0.06572646103450097, 0.04080710874404758, 0.06204562378115952, 0.048905836083577015, 0.045803206085111015, 0.024699839850654826, 0.07538281904999167, 0.05630387953715399, 0.05094478292448912, 0.09562292281771079, 0.042320292195654474, 0.031991277501219884, 0.05950501850747969, 0.049326114312862046, 0.025496488997305278, 0.10301320711732842, 0.5999794928357005, 3.392418301664293, 13.266349732875824, 37.23206654191017, 51.603267788887024, 67.5257357954979, 61.00057773292065, 60.659188851714134, 57.29400582611561, 48.21607634425163, 53.43019835650921, 36.7649158090353, 39.37439538538456, 24.35053925961256, 19.448443204164505, 24.361786656081676, 20.159943625330925, 23.174737952649593, 17.09375135600567, 15.274788960814476, 15.556094516068697, 23.70277851819992, 16.423106342554092, 22.011755257844925, 22.164898440241814, 56.737457290291786, 73.22599232196808, 63.59680362045765, 59.74974565207958, 57.07939714193344, 65.60107827186584, 56.19760885834694, 42.17981904745102, 35.71010380983353, 28.122881837189198, 19.43996775895357, 16.74015372991562, 21.30659479647875, 11.921240910887718, 18.697865679860115, 25.370782613754272, 26.597140207886696, 13.164856228977442, 14.614723529666662, 18.808836825191975, 24.893560521304607, 36.638545989990234, 40.49912363290787, 49.49693821370602, 48.487921357154846, 26.34824976325035, 25.410494282841682, 38.94339591264725, 41.48307703435421, 30.784093737602234, 48.95045913755894, 17.33293902128935, 15.014406032860279, 12.332736980170012, 11.995518375188112, 10.55881166830659, 26.72284886240959, 35.13224221765995, 35.61469852924347, 41.07188209891319, 48.541240096092224, 44.36872199177742, 50.38357503712177, 60.04267953336239, 53.10606814920902, 61.02792866528034, 52.245558723807335, 41.34990558028221, 29.13604997098446, 9.166722167283297, 2.8155406191945076, 0.33839470124803483, 0.05597640687483363, 0.06891279044793919, 0.00936004164032056, 0.022046010672056582, 0.03749085524759721, 0.024561672362324316, 0.0189978654452716, 0.06576943138497882, 0.018235574025311507, 0.016018949609133415, 0.016882212075870484, 0.05251172013231553, 0.013801341847283766, 0.0025900311493387562, 0.022379901056410745, 0.034533467260189354, 0.02816283635183936, 0.02680319954379229, 0.10439769102958962, 0.10595501371426508, 0.04058208585774992, 0.06488180792075582, 0.062471482960972935, 0.07072607986629009, 0.0377919185848441, 0.053560011147055775, 0.06785153411328793, 0.0660590767802205, 0.01111277922973386, 0.018461507897882257, 0.0051696917125809705, 0.01961861074960325, 0.019636841607280076, 0.0938607970601879, 0.06603111265576445, 0.01862709588749567, 0.03477918122371193, 0.08731602676562034, 0.06886510003823787, 0.0719044025754556, 0.02697129784792196, 0.03720823056937661, 0.05398174769652542, 0.007051301854517078, 0.048268071477650665, 0.03648261052148882, 0.012805447386199376, 0.0064504423971811775, 0.05975493673759047, 0.030940131073293742, 0.07887034167652018, 0.055229479767149314, 0.016281868411169853, 0.04884765170572791, 0.03938009976991452, 0.05541921724216081, 0.00990406650089426, 0.045699891707045026, 0.021758400616818108, 0.040939058890216984, 0.010858694768103305, 0.037814157039974816, 0.02938173227448715, 0.03630428727774415, 0.016678210522513837, 0.048203782935161144, 0.09524005625280552, 0.07215436533442698, 0.04359306432888843, 0.03520380472764373, 0.07264235711772926, 0.08083006425295025, 0.030906806787243113, 0.03741611355508212, 0.05028321764257271, 0.021505183540284634, 0.03694941769936122, 0.0315115421108203, 0.040634574252180755, 0.04408174630952999, 0.025192100838467013, 0.047235450911102816, 0.02564270322181983, 0.04309673451643903, 0.053370396126410924, 0.039332914020633325, 0.033231565830647014, 0.05308664338372182, 0.046905993003747426, 0.056034884401015006, 0.05456480859720614, 0.03335325949592516, 0.08001117850653827, 0.04477180635149125, 0.04082092011230998, 0.03490589551802259, 0.028799285501008853, 0.009178137534036068, 0.04928722948534414, 0.4541333735687658, 4.462423073127866, 17.855576276779175, 44.887310564517975, 60.1750074326992, 76.22087001800537, 68.92956286668777, 66.96192964911461, 64.72168385982513, 58.3736988902092, 64.96231734752655, 44.417423978447914, 49.49398197233677, 30.737010464072227, 27.83842910081148, 34.438718631863594, 29.27562028169632, 35.07211424410343, 26.75566580146551, 26.340361386537552, 28.592198453843594, 35.56057043373585, 23.69724791496992, 23.74489925801754, 27.404735572636127, 56.534259393811226, 61.78286835551262, 43.605183362960815, 47.26817160844803, 45.76567903161049, 44.377412125468254, 43.0705102533102, 37.29264289140701, 30.032446570694447, 25.60881894081831, 20.095784068107605, 13.786733709275723, 14.521509781479836, 10.83415249362588, 15.906461365520954, 14.067888222634792, 16.837795190513134, 13.280837405472994, 14.855838641524315, 18.878487087786198, 25.03704272210598, 25.883297212421894, 31.11848909407854, 42.46609188616276, 53.93419951200485, 30.11183761060238, 34.91912305355072, 48.10433954000473, 52.251235619187355, 39.455984607338905, 41.795997843146324, 25.632455572485924, 29.046536274254322, 26.979188807308674, 26.358159631490707, 23.7961433082819, 38.7981753051281, 48.191879242658615, 46.7548343539238, 53.51478561758995, 59.81286406517029, 49.4637393951416, 58.96076738834381, 66.79990634322166, 62.39189587533474, 68.80499795079231, 64.61011424660683, 53.181874081492424, 37.571570724248886, 14.315853416919708, 4.072725484147668, 0.7982844987418503, 0.03281847159087192, 0.03451207114267163, 0.013473193830577657, 0.04114897907129489, 0.03670821970445104, 0.04404336243169382, 0.0445152199245058, 0.06231880091945641, 0.034014349803328514, 0.03477434984233696, 0.03272874222602695, 0.10280206610332243, 0.010182716978306416, 0.0089045577806246, 0.020342132374935318, 0.0070884918022784404, 0.02195404373196652, 0.022106660835561343, 0.14497408090392128, 0.023693430084676947, 0.023119835277611855, 0.04012790261185728, 0.039998898791964166, 0.0673468885361217, 0.07717933593085036, 0.03927343088435009, 0.05150281489477493, 0.05796572630060837, 0.0463341533759376, 0.022898135357536376, 0.0544838811038062, 0.04852941507124342, 0.020589451232808642, 0.04234909494698513, 0.09193827834678814, 0.15365495259175077, 0.03223424922907725, 0.06568606593646109, 0.09272883631638251, 0.050920254943775944, 0.03387491138710175, 0.07302470417926088, 0.0668545403459575, 0.02245515483082272, 0.014212033383955713, 0.04236724416841753, 0.03612233493186068, 0.010841420353244757, 0.01577641574840527, 0.08642848493764177, 0.08963303407654166, 0.03444194560870528, 0.05071108062111307, 0.179270654625725, 0.09274848096538335, 0.13332561298739165, 0.1909190186415799, 0.17917012330144644, 0.1763430453138426, 0.1663853827631101, 0.108586869755527, 0.1345015162951313, 0.21985529718222097, 0.12426574874552898, 0.12709955801256, 0.07595401300932281, 0.11289155634585768, 0.09972376370569691, 0.12592852319357917, 0.15497842454351485, 0.13281362014822662, 0.16444530483568087, 0.09297626835177653, 0.18515438656322658, 0.1234071803628467, 0.0814255561272148, 0.12440372884157114, 0.13374589121667668, 0.09461185050895438, 0.10219321557087824, 0.06776612775865942, 0.2472284049144946, 0.09981415729271248, 0.1275346495094709, 0.07967076278873719, 0.11675134024699219, 0.12041960551869124, 0.10632548641297035, 0.12645184120628983, 0.16678967513144016, 0.09809287192183547, 0.15844109264435247, 0.22140230401419103, 0.17726124526234344, 0.13944171136245131, 0.11552033989573829, 0.10809475905261934, 0.20153024612227455, 0.23785182915162295, 0.8700646657962352, 7.190367942675948, 24.833601638674736, 56.57375827431679, 71.77936434745789, 84.21872645616531, 78.69203701615334, 76.8733862042427, 73.11640620231628, 65.08141055703163, 72.85817205905914, 54.1335292160511, 57.73610070347786, 37.36064024269581, 32.515467032790184, 38.47140043973923, 34.58461180329323, 37.64450781047344, 31.05580385774374, 26.570262350142002, 27.11298532783985, 36.683436781167984, 24.829602353274822, 31.927904561161995, 33.59530828893185, 73.19253131747246, 88.78548100590706, 82.16788530349731, 75.95984682440758, 75.54909646511078, 82.06002429127693, 72.10401892662048, 55.34726768732071, 48.150024488568306, 40.40857449173927, 28.30147795379162, 25.0151938945055, 29.684782326221466, 17.380656860768795, 24.530898481607437, 34.21914741396904, 33.83737049996853, 17.836567796766758, 19.514531157910824, 25.541235767304897, 33.872663006186485, 49.75359544157982, 52.93879732489586, 59.70752991735935, 58.031185269355774, 36.99362553656101, 37.896593883633614, 53.71071070432663, 53.147607520222664, 47.94099010527134, 70.12282803654671, 28.783039413392544, 28.363085947930813, 23.79662398248911, 27.15600471943617, 23.61832235008478, 40.360374078154564, 50.88166370987892, 52.10831008851528, 58.00669938325882, 65.18527418375015, 64.27206918597221, 69.64641720056534, 78.58208611607552, 72.99167409539223, 78.98294180631638, 74.12000834941864, 62.310272455215454, 42.89907865226269, 17.06896908581257, 5.419939868152142, 1.1048601823858917, 0.10519652394577861, 0.1517370797228068, 0.14912231534253806, 0.20137169369263574, 0.20271563407732174, 0.11134531392599456, 0.17807109165005386, 0.13550562725868076, 0.12269749422557652, 0.12488133797887713, 0.11919472788576968, 0.1431996503379196, 0.15399680065456778, 0.04687896398536395, 0.1247385042370297, 0.1364533943706192, 0.10651131276972592, 0.15590116643579677, 0.23814226122340187, 0.1692331221420318, 0.13262600521557033, 0.128780611557886, 0.10199610114796087, 0.15338864031946287, 0.13046732026850805, 0.10859651025384665, 0.15275020035915077, 0.19488003890728578, 0.1256246434058994, 0.1998878881568089, 0.14370174292707816, 0.1166715519502759, 0.15004432993009686, 0.19529519631760195, 0.2386386095895432, 0.2880297397496179, 0.14237175491871312, 0.16154536278918386, 0.13874012947781011, 0.2171130763599649, 0.09277641540393233, 0.165519118309021, 0.15905229578493163, 0.08018883381737396, 0.10525498291826807, 0.13351716130273417, 0.10028471602709033, 0.09817491634748876, 0.09695215383544564, 0.169735734234564, 0.22310851636575535, 0.12138754420448095, 0.12133858472225256], [0.03874670270306524, 0.0404017142864177, 0.027098572463728487, 0.018770848037092946, 0.0059376364424679196, 0.020850893160968553, 0.034192031089332886, 0.04273988764907699, 0.06847635566373356, 0.026048516992887016, 0.012184591687400825, 0.03552447189576924, 0.03674508217955008, 0.07471501230611466, 0.08373158707399853, 0.05798434678581543, 0.034927922461065464, 0.02007589617278427, 0.047198061511153355, 0.015469455120182829, 0.03572241752408445, 0.01824482489610091, 0.03774695556785446, 0.052749626702279784, 0.047773489422979765, 0.0739338796120137, 0.030442858733294997, 0.06020766537403688, 0.02908852828113595, 0.03724597620021086, 0.019458611131994985, 0.04655892393202521, 0.04364992397313472, 0.02058352703897981, 0.08209316991269588, 0.026142641727346927, 0.0237481727526756, 0.07166364986915141, 0.019424023339524865, 0.0920588402368594, 0.026259533697157167, 0.05874343027244322, 0.0025082332558667986, 0.021011313947383314, 0.22659626905806363, 1.728486162610352, 10.252554751932621, 32.0657991617918, 49.99254561960697, 65.91256275773048, 69.62483435869217, 64.60591167211533, 53.078458830714226, 53.251341953873634, 49.888051226735115, 71.55201494693756, 35.019088089466095, 22.258565314114094, 19.871318712830544, 17.882590927183628, 19.95868932455778, 15.462003964930773, 14.331788811832666, 11.1620425991714, 12.967776954174042, 15.003980342298746, 16.44946362823248, 16.603917740285397, 34.640484005212784, 46.36267639696598, 57.63585448265076, 41.186765134334564, 57.26545035839081, 67.74048507213593, 43.727001026272774, 31.746821478009224, 21.968422383069992, 16.553984619677067, 18.258671946823597, 13.443971201777458, 4.77707801386714, 2.3548721009865403, 3.3853884413838387, 4.89706845022738, 2.230397667735815, 0.6245473120361567, 1.437735145445913, 0.637769652530551, 1.37819554656744, 4.202893199399114, 5.899012936279178, 4.192127902060747, 5.813878504559398, 7.397913280874491, 7.504936913028359, 9.76403396576643, 28.12677662819624, 28.666150085628033, 17.43531882762909, 27.642718702554703, 42.806755006313324, 48.117566630244255, 55.252044796943665, 44.7593030333519, 35.10754734277725, 26.24146979302168, 21.772463098168373, 19.084194749593735, 13.80019448697567, 16.461858563125134, 11.583954859524965, 29.412735924124718, 33.24190825223923, 46.569126918911934, 38.37821803987026, 47.19930410385132, 60.55443987250328, 60.2147950977087, 66.2887653708458, 54.445359483361244, 50.9469024091959, 24.00120310485363, 14.939134921878576, 4.613514840602875, 0.8458804478868842, 0.26021140278317034, 0.009944722278305562, 0.05091049941256642, 0.014884355168760521, 0.0231086269923253, 0.06185074322274886, 0.04201049749099184, 0.08117807214148343, 0.056105102703440934, 0.052018414571648464, 0.012557941136037698, 0.021009512383898254, 0.06717465090332553, 0.059498023765627295, 0.01416229279129766, 0.01783026491466444, 0.014207618532964261, 0.021462176082422957, 0.05087358127639163, 0.03568397427443415, 0.018562914956419263, 0.07987302771653049, 0.03121603003819473, 0.04924291584757157, 0.049434775864938274, 0.056690241617616266, 0.16538943542400375, 0.08126608343445696, 0.051693424393306486, 0.04327960341470316, 0.08865717667504214, 0.03371512328158133, 0.04129084059968591, 0.03567451931303367, 0.07231826864881441, 0.027521418523974717, 0.04593517107423395, 0.020469876399147324, 0.06224279015441425, 0.02973681468574796, 0.050007083045784384, 0.07725102739641443, 0.01626758763450198, 0.10804433753946796, 0.011112131705885986, 0.13208015559939668, 0.08265891650808044, 0.07244078980875202, 0.0883374000841286, 0.026992087259714026, 0.09660344832809642, 0.11241010288358666, 0.039443263958673924, 0.07008970307651907, 0.011275252982159145, 0.0234311328313197, 0.02928928293840727, 0.056351050443481654, 0.04356058794655837, 0.043302205522195436, 0.036122297824476846, 0.07309829554287717, 0.017852902274171356, 0.04152295099629555, 0.034553698205854744, 0.015999880124581978, 0.013531693621189333, 0.03302622470073402, 0.027440487319836393, 0.08899981141439639, 0.08656034973682836, 0.077833680115873, 0.01910439517814666, 0.020709248710772954, 0.08573603889090009, 0.04271812787919771, 0.04924365057377145, 0.018431298776704352, 0.011988586775260046, 0.03886444814270362, 0.04998987635190133, 0.003309703579361667, 0.02605945624964079, 0.10597294400213286, 0.004100455435036565, 0.057117310498142615, 0.02474123684805818, 0.06580883200513199, 0.08073957418673672, 0.025900592117977794, 0.029200505377957597, 0.030066701183386613, 0.10473205082234927, 0.017032877331075724, 0.06579038221389055, 0.22090798913268372, 3.359738392755389, 13.852519579231739, 37.60247826576233, 58.60880367457867, 74.47399735450745, 79.54390570521355, 74.85907629132271, 59.985925778746605, 60.682189017534256, 58.436543717980385, 77.00819537043571, 50.798383578658104, 35.31782805919647, 32.346862480044365, 26.464686915278435, 24.997431747615337, 23.6613854393363, 22.599009945988655, 19.23216260969639, 21.608564592897892, 22.362529635429382, 21.33487667888403, 28.725305311381817, 32.10714094340801, 39.733647108078, 42.174009159207344, 34.174184426665306, 49.63441103696823, 53.47421519458294, 36.06920354068279, 25.05463007837534, 19.679881185293198, 14.967180266976357, 12.082732245326042, 7.24074468947947, 4.353345176205039, 2.0237001590430737, 2.2645025001838803, 2.417423869483173, 1.2743859481997788, 0.41472438198979944, 0.8329017693176866, 0.6769954820629209, 1.234880299307406, 2.1774812322109938, 4.04381568543613, 4.0754898358136415, 6.414820533245802, 7.424432532861829, 7.960844999179244, 8.937183134257793, 19.126756265759468, 21.744382604956627, 16.7855004966259, 22.76122324168682, 31.95582166314125, 48.88666816055775, 40.073139891028404, 39.43710342049599, 32.29363113641739, 27.924828864634037, 27.668800503015518, 27.11083274334669, 27.83757034689188, 29.44379735738039, 20.90815007686615, 39.52068753540516, 43.968531265854836, 53.9912648499012, 46.680647134780884, 54.45205472409725, 70.7295110821724, 69.03079703450203, 73.51824223995209, 65.09420827031136, 61.513956785202026, 35.09828723967075, 19.931946359574795, 6.67864085175097, 0.9590123116504401, 0.16468482557684183, 0.057976788011728786, 0.07304543978534639, 0.009715340202092193, 0.030046058345760684, 0.06550984297064133, 0.06328170042252168, 0.05906682483328041, 0.01697675797913689, 0.02816431508108508, 0.027558321817195974, 0.02397784890490584, 0.02930911683506565, 0.051023650958086364, 0.041042595912585966, 0.04812665894860402, 0.022630105013377033, 0.011809943480329821, 0.06101840233895928, 0.021622904860123526, 0.011689629282045644, 0.03790216833294835, 0.07255392280058004, 0.003955226411562762, 0.071831456880318, 0.033355274426867254, 0.06702295591821894, 0.04870571596256923, 0.06592195757548325, 0.08311214609420858, 0.045549373026005924, 0.04882121269474737, 0.09626827959436923, 0.04182036667771172, 0.07721952322754078, 0.025387257846887223, 0.022657124754914548, 0.03492186282528564, 0.058377373352414, 0.05222332896664739, 0.0464761076727882, 0.049536383303347975, 0.03169610681652557, 0.047539902152493596, 0.022304209414869547, 0.027856635497300886, 0.08763252306380309, 0.03987716059782542, 0.030271327996160835, 0.0856833612488117, 0.10700292623369023, 0.25481097225565463, 0.11952126544201747, 0.16007208090741187, 0.11609739682171494, 0.06336407881462947, 0.16312753257807344, 0.1745947086601518, 0.16985314199700952, 0.13307736458955333, 0.08131507260259241, 0.14742773986654356, 0.1279937569051981, 0.14521048462484032, 0.13573144795373082, 0.16082092275610194, 0.1759771813522093, 0.13072291592834517, 0.15375931339804083, 0.18988349998835474, 0.12582304916577414, 0.1562976959394291, 0.07532266798079945, 0.16317681118380278, 0.19253452570410445, 0.10291921411408111, 0.20033759996294975, 0.11279796410235576, 0.11443407318438403, 0.23482426739064977, 0.14057753869565204, 0.13762628455879167, 0.13590678776381537, 0.2686043211724609, 0.15280667779734358, 0.2588798414217308, 0.1492274776683189, 0.14837400784017518, 0.12814981571864337, 0.11218779254704714, 0.24798058642772958, 0.08097609665128402, 0.11681239673634991, 0.160843038756866, 0.12724083324428648, 0.5341908324044198, 4.656038358807564, 18.33067048341036, 45.191780626773834, 67.60795578360558, 83.36313396692276, 86.861332654953, 83.49013835191727, 68.53371530771255, 70.62813252210617, 67.46980279684067, 86.32697492837906, 51.887416541576385, 38.12141641974449, 34.74616773426533, 31.08124539256096, 31.48972537368536, 28.810333348810673, 25.085273534059525, 21.460534036159515, 23.281544521450996, 23.665280230343342, 23.709564954042435, 26.5467644110322, 49.74720798432827, 64.2746302485466, 73.38984712958336, 56.26341372728348, 70.84249421954155, 83.02026316523552, 55.504533648490906, 42.23066031932831, 30.405755639076233, 23.241000697016716, 24.653086625039577, 18.287371806800365, 6.935768304392695, 3.7506873020902276, 5.763838989660144, 6.991508938372135, 3.743965937756002, 1.34456901345402, 2.2289641946554184, 1.3102968712337315, 2.4627715861424804, 6.030200896784663, 7.937700916081667, 5.570171931758523, 8.056181408464909, 9.80522945523262, 9.495879504829645, 14.931395687162876, 36.204616874456406, 39.16029967367649, 25.780809111893177, 36.9720920920372, 58.44010792672634, 62.81409502029419, 69.34314027428627, 63.575482964515686, 52.175380289554596, 41.195907443761826, 35.55145852267742, 31.427680402994156, 26.043553613126278, 28.381438963115215, 22.890697494149208, 44.64031241834164, 50.91996185481548, 63.19392643868923, 56.094736978411674, 65.77934190630913, 81.06640040874481, 79.16417688131332, 85.71684926748276, 73.77565562725067, 70.26629313826561, 40.55806986987591, 23.34094673395157, 8.03978243842721, 1.152115990407765, 0.29901248635724187, 0.16252713510766625, 0.1378336554626003, 0.11635000904789194, 0.06966323533561081, 0.1514958668849431, 0.15706397825852036, 0.13915347604779527, 0.1469703987822868, 0.11249238479649648, 0.1170964834454935, 0.14779891760554165, 0.10730565569247119, 0.16820639051729813, 0.09394581749802455, 0.09069693987839855, 0.1115981413749978, 0.09820826846407726, 0.16296881687594578, 0.08887570205843076, 0.06408244065823965, 0.22219208272872493, 0.16015831846743822, 0.1581787582836114, 0.17874647572170943, 0.14261743548559025, 0.24990653386339545, 0.13826332928147167, 0.13297564582899213, 0.20455966325243935, 0.198699694883544, 0.14148739690426737, 0.10878664848860353, 0.10296933876816183, 0.19289789604954422, 0.14702929562190548, 0.07400853966828436, 0.08774425339652225, 0.14838570408755913, 0.16701696527888998, 0.09428977326024324, 0.19978029158664867, 0.1193812073324807, 0.2048183314036578, 0.07449729586369358, 0.23964313615579158, 0.154439699545037, 0.16395493817981333, 0.1546261418843642, 0.15210196404950693, 0.21576339175226167], [0.030038052427698858, 0.09805662542930804, 0.03960631009249482, 0.0669934407051187, 0.036029458860866725, 0.013933483096479904, 0.023009919495962095, 0.02896852671256056, 0.046730597532587126, 0.10673363794921897, 0.04116220043215435, 0.07119887246517465, 0.008192338136723265, 0.026149296936637256, 0.012698826740233926, 0.060378511479939334, 0.023123918945202604, 0.018266198749188334, 0.16104233509395272, 0.012068603282386903, 0.12629971577553079, 0.024098822686937638, 0.04527311226411257, 0.05750989919761196, 0.06753621040843427, 0.0287981908331858, 0.014276625279308064, 0.04485365039727185, 0.032834045559866354, 0.028508517607406247, 0.061423332954291254, 0.03765844703593757, 0.0522445506794611, 0.03340561059303582, 0.0554345574346371, 0.10551841565757059, 0.0320185402961215, 0.030771405654377304, 0.09006627020426095, 0.07016837073024362, 0.025918457467923872, 0.11037497810320929, 0.3190348291536793, 1.7136071110144258, 8.007506020367146, 35.46977810561657, 53.50024379789829, 53.958768993616104, 63.79975453019142, 63.4331464022398, 43.66053119301796, 43.075108006596565, 48.90705406665802, 46.17744393646717, 27.916019037365913, 21.6406424716115, 17.40601859986782, 8.044907413423061, 17.433635517954826, 11.862689852714539, 16.281761527061462, 20.273692421615124, 31.00595623254776, 28.391118943691254, 32.57177621126175, 41.17913134396076, 53.37854012846947, 51.83339104056358, 51.05378307402134, 48.19773472845554, 42.21269868314266, 34.20887276530266, 20.048467107117176, 8.328524194657803, 8.21252116933465, 3.539434550330043, 1.7966427491046488, 2.2441707411780953, 1.5816179872490466, 0.6317778490483761, 0.0472032305697212, 0.18737333390163258, 0.008289639263239224, 0.039307918486883864, 0.0019668235381686827, 0.09912652778439224, 0.10400479804957286, 0.21516038192203268, 0.15473182371351868, 0.07435856619849801, 0.356833211844787, 1.0144189791753888, 0.5713040346745402, 1.1477616615593433, 1.5307061816565692, 3.116425573825836, 1.469578268006444, 4.708838425576687, 5.0324965082108974, 9.203131813555956, 8.619890660047531, 18.076114542782307, 36.803096160292625, 44.823287799954414, 54.65616837143898, 52.958723455667496, 49.79783646762371, 40.06409637629986, 35.509751960635185, 22.961039319634438, 35.20473092794418, 25.059953592717648, 10.192609168589115, 26.97625156491995, 25.23838821798563, 27.249109223484993, 37.074910774827, 50.34379497170448, 50.15027895569801, 56.593239828944206, 58.477163538336754, 65.85475265979767, 49.98444065451622, 31.783592104911804, 8.914001528173685, 4.43528207950294, 0.807535161729902, 0.08317585205077194, 0.021483568489202298, 0.06822258568718098, 0.10009911973611452, 0.00759012518756208, 0.07220928426249884, 0.013084530164633179, 0.016956436120381113, 0.020828318884014152, 0.022334867535391822, 0.05468527029734105, 0.07018371092271991, 0.021452533728734124, 0.062272171780932695, 0.029055656705168076, 0.052780681871809065, 0.03042157579329796, 0.05030209416872822, 0.04432732668647077, 0.0392656383337453, 0.02041760137217352, 0.05534581883694045, 0.07247282832395285, 0.02985234110383317, 0.006639831990469247, 0.0390965511178365, 0.028465204013627954, 0.05783104134025052, 0.04333947246777825, 0.04128981272515375, 0.02153652072593104, 0.021242847324174363, 0.014762798800802557, 0.07345537989749573, 0.0670865505526308, 0.04787840684002731, 0.015476730022783158, 0.05003267971915193, 0.04183119461231399, 0.030547789137926884, 0.058119636596529745, 0.028296233685978223, 0.0284229442695505, 0.05642991105560213, 0.07030632114037871, 0.07632922803168185, 0.06311301025561988, 0.1290761644486338, 0.05705923744244501, 0.01101471925721853, 0.05168323470570613, 0.062260408740257844, 0.04707940694061108, 0.055381764759658836, 0.018466105502739083, 0.04533066210569814, 0.015235995870170882, 0.025745501807250548, 0.041351269974256866, 0.0820229850069154, 0.05261160207737703, 0.02516991618904285, 0.045940032141515985, 0.020004865218652412, 0.06059170453227125, 0.051699884788831696, 0.010221367101621581, 0.09191703065880574, 0.027172622103535105, 0.0022611760050494922, 0.037119963235454634, 0.025775863068702165, 0.05061082760221325, 0.06849521363619715, 0.047039809651323594, 0.08128407309413888, 0.032873134477995336, 0.05965473195828963, 0.10314231854863465, 0.03309352265205234, 0.03851553854474332, 0.1672346965642646, 0.04231333085044753, 0.030128594444249757, 0.04457259907212574, 0.03574184695025906, 0.013792886002192972, 0.06977032724535093, 0.04153394962486345, 0.0647771725198254, 0.013310473314049887, 0.3103672864381224, 2.028624932281673, 11.202521827071905, 43.95742066204548, 63.55801910161972, 63.287458419799805, 73.20333033800125, 70.37683680653572, 55.001607835292816, 53.156115263700485, 57.55378268659115, 57.31834352016449, 39.51779209077358, 34.20029282569885, 21.263366416096687, 14.62877232581377, 27.30982806533575, 17.3195618391037, 26.085674352943897, 26.053343787789345, 29.85480610281229, 24.729568921029568, 29.74919456988573, 35.01063734292984, 35.924560502171516, 36.01262457668781, 40.35367123782635, 38.87939214706421, 37.58033685386181, 28.77505414187908, 14.621151834726334, 8.187281023710966, 5.844222251325846, 4.087399346753955, 1.776089295744896, 1.5494340704753995, 1.007747130934149, 0.3865447675343603, 0.09014123454107903, 0.1077377563342452, 0.06849136188975535, 0.04489534054300748, 0.11892259717569686, 0.04402744707476813, 0.14264731435105205, 0.08846055206959136, 0.13242951419670135, 0.258245809818618, 0.09660002702730708, 0.6745003222022206, 0.3137432271614671, 0.7410763122607023, 0.878061514813453, 2.0325479842722416, 1.2384397583082318, 2.9931979486718774, 3.05853758007288, 6.877740668132901, 7.564847823232412, 13.523037359118462, 25.23603804409504, 35.802792236208916, 42.300948947668076, 43.31409618258476, 43.93114887177944, 36.27829872071743, 32.556413635611534, 28.533632196485996, 41.25698156654835, 28.666305877268314, 20.7794376835227, 38.47855545580387, 38.61880972981453, 38.33641268312931, 45.61370238661766, 56.279327273368835, 58.82348075509071, 62.697836458683014, 65.95610082149506, 76.3401760160923, 63.79704147577286, 43.523400351405144, 16.626640520989895, 8.26368922367692, 2.086027739569545, 0.2957814425462857, 0.042269740806659684, 0.032553317068959586, 0.06337280647130683, 0.03571190871298313, 0.016411974320362788, 0.008379692390008131, 0.04236179309373256, 0.05800632919999771, 0.05124189061461948, 0.04121517493331339, 0.08937533071730286, 0.028929788459208794, 0.03837302021565847, 0.03259522985899821, 0.052907039935234934, 0.019791651757259388, 0.02370163823798066, 0.06953117015655152, 0.04016038270492572, 0.11119960065116175, 0.038806200682302006, 0.03698709653690457, 0.03955847867473494, 0.022394899860955775, 0.02291562777827494, 0.03042305452254368, 0.03269177585025318, 0.029486397361324634, 0.08282753988169134, 0.01757277121214429, 0.07235192504595034, 0.043671346065821126, 0.10835526773007587, 0.020742932938446756, 0.06556427950272337, 0.02505997814296279, 0.013043904073128942, 0.035488125213305466, 0.02066433764412068, 0.033206262305611745, 0.010223857007076731, 0.04237566754454747, 0.1184388950059656, 0.024819724530971143, 0.0900455642840825, 0.03705959323269781, 0.049502092369948514, 0.039901536438264884, 0.11081348347943276, 0.2600603608880192, 0.1488557062111795, 0.16256436123512685, 0.11982009120401926, 0.10279442198225297, 0.10934258389170282, 0.17691567161818966, 0.1138873107265681, 0.1170284062391147, 0.13511579192709178, 0.19805861287750304, 0.12093260767869651, 0.14361353125423193, 0.1030648012238089, 0.19994405389297754, 0.09021108548040502, 0.06817260204115883, 0.27254390821326524, 0.1061699322599452, 0.14013748965226114, 0.17738916183589026, 0.10797360344440676, 0.11506155904498883, 0.17569023737451062, 0.10345517090172507, 0.16286867146845907, 0.1976793457288295, 0.24306471896125004, 0.18446356581989676, 0.10285651005688123, 0.13148299389285967, 0.23646114830626175, 0.10061889770440757, 0.26494639401789755, 0.21857700718101114, 0.11469279328593984, 0.15833392651984468, 0.1719382801093161, 0.165556299907621, 0.11183058944880031, 0.15531199023826048, 0.5810151854529977, 3.852062299847603, 15.971935652196407, 53.97175669670105, 73.54275092482567, 71.86492815613747, 81.80984571576118, 81.5660659968853, 60.613097324967384, 63.968055099248886, 67.55486503243446, 62.03677073121071, 43.98191414773464, 33.54197435081005, 28.23202148079872, 16.699134930968285, 26.889268532395363, 22.19602447003126, 27.5640382245183, 34.275148808956146, 43.807051330804825, 41.93913996219635, 45.07159687578678, 54.37863506376743, 67.68047109246254, 64.53304678201675, 67.891815751791, 63.079848960042, 56.60576395690441, 45.011195316910744, 26.868415251374245, 11.559988595545292, 10.975051783025265, 5.771320313215256, 3.4355144016444683, 3.5901233553886414, 2.5779654923826456, 1.1261059110984206, 0.28696953726466745, 0.5250971484929323, 0.11143754061777145, 0.23868861549999565, 0.15444535471033305, 0.4265635967021808, 0.4037922201678157, 0.5075017176568508, 0.3445352311246097, 0.5584575177635998, 0.7445587066467851, 1.5587592450901866, 1.0447792313061655, 2.1221269899979234, 2.641702559776604, 4.18796950019896, 2.2797551192343235, 6.14142662845552, 7.239595726132393, 12.352005746215582, 11.284597422927618, 24.14509378373623, 47.76718743145466, 54.10239368677139, 68.80894213914871, 67.04076021909714, 64.42068681120872, 55.72191618382931, 44.97637398540974, 33.92806403338909, 49.878566935658455, 36.83143883943558, 21.088326908648014, 39.796092957258224, 40.33500663936138, 42.465316727757454, 52.91200876235962, 67.81012773513794, 70.18472671508789, 74.35796678066254, 76.72085478901863, 84.6744892001152, 73.62368658185005, 49.63414505124092, 20.68272527307272, 9.618090447038412, 2.5786608550697565, 0.3177416219841689, 0.1402338352636434, 0.14467413449892774, 0.16165515611646697, 0.14542895805789158, 0.15141439391300082, 0.14236154296668246, 0.1191950321663171, 0.1339884547633119, 0.11475583873107098, 0.12852783605922014, 0.18118558858986944, 0.10618036685627885, 0.15361613826826215, 0.11275522381765768, 0.12325582676567137, 0.1617097039707005, 0.09613453716156073, 0.22579739161301404, 0.11665590005577542, 0.15412847249535844, 0.12306716540479101, 0.2237187250284478, 0.1758881681598723, 0.12990339193493128, 0.13145980919944122, 0.23137507669162005, 0.16356943699065596, 0.1635792333399877, 0.12126854082453065, 0.09172058416879736, 0.2093599337968044, 0.12217223920742981, 0.20187377143884078, 0.09274264768464491, 0.18161912157665938, 0.06329062845907174, 0.12252619169885293, 0.1425351609941572, 0.08024728536838666, 0.09167061536572874, 0.19422559824306518, 0.1696186381741427, 0.2953748940490186, 0.08823622309137136, 0.21356016310164705, 0.12268164195120335, 0.20251914305845276, 0.15248807379975915], [0.05727320232836064, 0.04000114007794764, 0.02190628096286673, 0.01066096250724513, 0.016433016062364914, 0.05431617428257596, 0.053726686383015476, 0.05383838331908919, 0.04086879234819207, 0.0731106819876004, 0.07124298572307453, 0.03933194180717692, 0.08698388599441387, 0.045295391537365504, 0.028555838798638433, 0.027067971859651152, 0.04824543226277456, 0.02870960994187044, 0.012634496451937594, 0.080701843398856, 0.01570327895024093, 0.024709053614060394, 0.028515592130133882, 0.06492500091553666, 0.043585653984337114, 0.06385639731888659, 0.056089001809596084, 0.004586983332046657, 0.02078664729197044, 0.021600287909677718, 0.040254279228975065, 0.039206737783388235, 0.033425448200432584, 0.05194608856982086, 0.04106324246095028, 0.013361485762288794, 0.022045379846531432, 0.08761823672102764, 0.011508184379636077, 0.04784263903275132, 0.03585543265216984, 0.0853441700746771, 4.882273944094777, 25.207444578409195, 46.64138004183769, 65.33204510807991, 66.14428952336311, 65.28048187494278, 58.19941744208336, 55.532891526818275, 61.09092928469181, 62.01708398759365, 50.4451659321785, 24.955461099743843, 21.467246375977993, 13.4321728348732, 24.78754810988903, 30.737992711365223, 26.844419538974762, 31.0459091886878, 28.608909957110882, 34.600164368748665, 49.496619030833244, 63.161935955286026, 58.0240074545145, 68.55698525905609, 55.19515424966812, 56.28526635468006, 24.613268561661243, 15.272653475403786, 6.719145253300667, 2.393867508508265, 1.3637863635085523, 0.46754136972595006, 0.043636595000862144, 0.09957121525076218, 0.03237538716348354, 0.06041516244295053, 0.09031593610416166, 0.07114671432645991, 0.00785126654591295, 0.03161212909617461, 0.004836611196878948, 0.020748968454427086, 0.08513483247952536, 0.03555584989953786, 0.05483105778694153, 0.06052357537555508, 0.05973147744953167, 0.024518278987670783, 0.027874740189872682, 0.06377154015353881, 0.09138334484305233, 0.009447623415326234, 0.05521305603906512, 0.046898189320927486, 0.08315513128763996, 0.061875983665231615, 0.13539724401198328, 0.15730732848169282, 0.2267834238591604, 1.473317623604089, 3.0303034326061606, 5.076486747711897, 11.567473243921995, 22.82615225762129, 41.60976603627205, 47.306241765618324, 64.74688410758972, 53.40527169406414, 47.266659289598465, 58.8828069716692, 37.73959010839462, 20.037388801574707, 13.045444786548615, 15.261577069759369, 22.56761223077774, 27.7280830219388, 29.5079493150115, 40.40788292884827, 45.26159048080444, 55.243263468146324, 55.30753701925278, 61.73439435660839, 59.08248245716095, 44.601919278502464, 28.235276006162167, 10.246730614453554, 5.366444913670421, 1.499666953459382, 0.2702431910438463, 0.05791691153717693, 0.02711991848627804, 0.031175493932096288, 0.04985375162505079, 0.023468351537303533, 0.029175266790844034, 0.0443174264364643, 0.046127409586915746, 0.0809830505750142, 0.06309428586973809, 0.011803489578596782, 0.05092399165732786, 0.04574802369461395, 0.06253822430153377, 0.0581604584294837, 0.05379817004723009, 0.024193767494580243, 0.06083457235945389, 0.03821967766270973, 0.06305793547653593, 0.046165771200321615, 0.05200219122343697, 0.036859131723758765, 0.04096045871847309, 0.021476692490978166, 0.014136439149297075, 0.05373147694626823, 0.010366623027948663, 0.053025653687654994, 0.100410762388492, 0.023059745435602963, 0.06880403612740338, 0.009900872482830891, 0.07148248419980519, 0.03992259116785135, 0.02759271108516259, 0.03660762529761996, 0.07139208319131285, 0.04271866593626328, 0.06255015803617425, 0.04355141500127502, 0.028986982069909573, 0.013366491548367776, 0.03929347629309632, 0.029230167165223975, 0.0824110020766966, 0.013856797904736595, 0.03970462981669698, 0.01974826580408262, 0.01433186982467305, 0.08301862064399756, 0.016110643809952307, 0.0569424271088792, 0.017868954928417224, 0.039202685657073744, 0.03104798925051, 0.04250179925293196, 0.023853594830143265, 0.04135579336434603, 0.007204295598057797, 0.059578101499937475, 0.005570015446210164, 0.00762755911637214, 0.07479801410227083, 0.046053113183006644, 0.014713922810187796, 0.02430658136290731, 0.065000083995983, 0.029588689430966042, 0.022544668972841464, 0.013617226140922867, 0.11581650134758092, 0.0754795505781658, 0.06785791658330709, 0.05346078600268811, 0.030657506395073142, 0.06906047041411512, 0.0328738951793639, 0.06219500697625335, 0.03456934638961684, 0.024993630140670575, 0.038948132714722306, 0.024376352521358058, 0.10601098649203777, 0.04060500708874315, 0.06090729912102688, 0.12366906201350503, 6.5720337722450495, 30.86942195892334, 54.8876291513443, 76.17685317993164, 73.7183926999569, 76.56504794955254, 65.01422256231308, 66.69243291020393, 60.12317441403866, 65.50144001841545, 63.82634550333023, 37.554676830768585, 31.789895966649055, 21.10494341701269, 33.46903346478939, 21.418352499604225, 26.79460421204567, 26.96427460759878, 22.88534738123417, 30.832835622131824, 42.472384348511696, 51.365598142147064, 42.664999812841415, 45.98414830863476, 43.39382730424404, 38.203381821513176, 20.886975713074207, 11.93081259727478, 5.468794321641326, 2.6292458781972528, 1.453885466326028, 0.4428530257428065, 0.11898277793079615, 0.05474568853969686, 0.04318526160204783, 0.04403941049531568, 0.17405150108970702, 0.06208176266227383, 0.06850734032923356, 0.10642971363267861, 0.10229995124973357, 0.02960709283797769, 0.0871129751612898, 0.13005664543015882, 0.06600261418498121, 0.1010713109280914, 0.06230524930288084, 0.05319123054505326, 0.058205269306199625, 0.025852189246506896, 0.19317606784170493, 0.06176379320095293, 0.038368192545021884, 0.021995633687765803, 0.01149917841757997, 0.061064107503625564, 0.0519551761681214, 0.03672448016004637, 0.08492527966154739, 1.2628523795865476, 2.0715132309123874, 4.164074957370758, 8.890744876116514, 18.1156837195158, 28.140852972865105, 39.54950138926506, 46.58132426440716, 41.415303871035576, 43.182212859392166, 54.12214122712612, 36.25938333570957, 28.24714846909046, 21.824681796133518, 22.412544451653957, 31.246409229934216, 37.44328960776329, 39.05925169587135, 48.40347468852997, 54.177291467785835, 62.552752643823624, 64.77355867624283, 72.405274361372, 74.96132880449295, 57.34801232814789, 37.513737827539444, 16.538785435259342, 7.378696762025356, 1.5987456869333982, 0.22464189736638218, 0.06045404355973005, 0.03749660318135284, 0.037105884694028646, 0.029905330447945744, 0.08886779818567447, 0.03523532002873253, 0.037342065770644695, 0.03320050695037935, 0.01627300716791069, 0.03238171397242695, 0.03679611225379631, 0.02595467241917504, 0.033137591381091624, 0.04868716227065306, 0.0208169102188549, 0.06858100590761751, 0.08558867804822512, 0.04900880165223498, 0.019241763002355583, 0.06157185896881856, 0.02641561848577112, 0.07975677028298378, 0.07895093149272725, 0.034293853750568815, 0.03753077537112404, 0.03334762659505941, 0.05924521858105436, 0.04861209403316025, 0.061948636212036945, 0.049172660437761806, 0.0128046894678846, 0.006594941332878079, 0.020222945313435048, 0.0033984296533162706, 0.049322670747642405, 0.037916543733444996, 0.044799662864534184, 0.03594125089875888, 0.016206807595153805, 0.02327339676412521, 0.07456155100953765, 0.0653509417315945, 0.030296082331915386, 0.10827685982803814, 0.028551872019306757, 0.17206092743435875, 0.08406530861975625, 0.10992413081112318, 0.08448351625702344, 0.08155594405252486, 0.13440941576845944, 0.12227788392920047, 0.22975765488808975, 0.13523643545340747, 0.17785534932045266, 0.15505112532991916, 0.14965529611799866, 0.204877911019139, 0.10647507369867526, 0.05944060379988514, 0.13792734418530017, 0.1350810594158247, 0.144103912753053, 0.13401416275883093, 0.12604624265804887, 0.11619355689617805, 0.12807482911739498, 0.1065640794695355, 0.15758383786305785, 0.1148133774404414, 0.14720003411639482, 0.25862332549877465, 0.15779664128785953, 0.13689332467038184, 0.11895131829078309, 0.20253478753147647, 0.14502769365208223, 0.11435658554546535, 0.1421963854227215, 0.11351599197951145, 0.16858690447406843, 0.17154862289316952, 0.19918655860237777, 0.16188139241421595, 0.23490416700951755, 0.10665163805242628, 0.38019251776859164, 8.839195892214775, 37.97459229826927, 65.068179666996, 82.85289734601974, 83.59010338783264, 86.5756943821907, 75.8378429710865, 74.37509626150131, 72.93200969696045, 74.83902856707573, 66.770701110363, 38.70319180190563, 32.967646569013596, 21.764230839908123, 38.47599819302559, 43.99350732564926, 40.57980850338936, 46.459305211901665, 41.661728248000145, 50.39510361850262, 67.87888124585152, 81.08704850077629, 75.14388620853424, 84.89559173583984, 71.28992781043053, 70.09425356984138, 34.39504377543926, 21.613798812031746, 9.187608696520329, 3.885677671059966, 2.167567564174533, 1.0141033586114645, 0.48048400960396975, 0.33826221304479986, 0.29432083654683083, 0.17782731098122895, 0.48100674874149263, 0.17152536398498341, 0.25136363692581654, 0.28268247668165714, 0.44830864237155765, 0.36933552066329867, 0.2252284315181896, 0.17277083621593192, 0.25127828994300216, 0.18608371872687712, 0.28571901842951775, 0.21360280690714717, 0.27551270672120154, 0.20243010018020868, 0.29231988766696304, 0.152833231841214, 0.20335104607511312, 0.1823611801955849, 0.3021390060894191, 0.3666870330926031, 0.31475014344323426, 0.22418354696128517, 0.4518808959983289, 2.628628648817539, 3.914409354329109, 7.69521027803421, 15.964113771915436, 29.657837972044945, 49.95705932378769, 60.14806307852268, 82.82226338982582, 67.96874642372131, 59.090359434485435, 72.1459610760212, 49.77658040821552, 32.15852178633213, 21.801854521036148, 26.10864032059908, 36.97980187833309, 43.05123008787632, 44.40741531550884, 56.650795340538025, 62.2774688154459, 74.1003406047821, 78.40980336070061, 86.33321419358253, 85.83225667476654, 67.33114063739777, 45.98913364112377, 23.050551116466522, 9.347220081835985, 1.9256309838965535, 0.3356928681023419, 0.18641726957866922, 0.102758383291075, 0.2289774498785846, 0.06405161926522851, 0.14892874838551506, 0.12280244132853113, 0.10235259178443812, 0.1667377247940749, 0.1764115010155365, 0.14157130412058905, 0.11990806538960896, 0.15618390985764563, 0.09160107612842694, 0.10481489676749334, 0.15921573154628277, 0.20268738793674856, 0.13862950494512916, 0.11942675293539651, 0.09271640534279868, 0.20717614941531792, 0.2547853533178568, 0.266633503488265, 0.2115724392933771, 0.09265208340366371, 0.10865513249882497, 0.11978708047536202, 0.2659000240964815, 0.20047587691806257, 0.09877874996163882, 0.1481729600345716, 0.1150822798081208, 0.19183208292815834, 0.12217824318213388, 0.1349526084959507, 0.15179337904555723, 0.14473309071036056, 0.1414012335590087, 0.10377346319728531, 0.12162966246251017, 0.15619999961927533, 0.09293687515310012, 0.10095751742483117, 0.10016122265369631, 0.2203879810986109, 0.14077763655222952], [0.07253507224959321, 0.05489146489708219, 0.08676133074914105, 0.03810731279372703, 0.02648320958542172, 0.025265352669521235, 0.029567371238954365, 0.023994263356144074, 0.047097177666728385, 0.05478678496729117, 0.061427177279256284, 0.027002930037269834, 0.06245735989068635, 0.03625805889896583, 0.027311476078466512, 0.02003784255066421, 0.045151325830374844, 0.04539436806226149, 0.053094473041710444, 0.02585997623100411, 0.051133637243765406, 0.05943920856225304, 0.05951107443252113, 0.02515014351956779, 0.0025835559108600137, 0.04992729845980648, 0.034191971717518754, 0.044320276283542626, 0.022994221217231825, 0.090283860481577, 0.016572411805100273, 0.011449442463344894, 0.06662242623860948, 0.08406014327192679, 0.06818507012212649, 0.03473653370747343, 0.007439914497808786, 0.05776727601187304, 0.052377239262568764, 0.03620796764153056, 0.6553697143681347, 4.160591969266534, 34.58900436758995, 58.62151779234409, 65.82500025629997, 63.2397785782814, 62.64407694339752, 48.89641463756561, 44.09837029874325, 42.80011296272278, 74.00557368993759, 62.35363572835922, 22.99669850617647, 23.631207458674908, 15.874195396900177, 35.40076620876789, 15.093048512935638, 39.103834703564644, 68.79138708114624, 46.18277125060558, 56.154515370726585, 45.19757531583309, 30.751852467656136, 26.614666767418385, 29.67174332588911, 25.13881266117096, 14.029667023569345, 5.495029063895345, 0.9433860657736659, 0.7465167297050357, 0.32600389269646257, 0.24679160647792742, 0.018305760786461178, 0.08296359039377421, 0.07022586491075344, 0.015518903492193203, 0.12025805481243879, 0.12913213722640648, 0.03791193499637302, 0.060575217721634544, 0.032629951238050126, 0.046680469167768024, 0.07942935699247755, 0.06673962619970553, 0.16207748267333955, 0.07453547194018029, 0.07168808137066662, 0.060503952990984544, 0.03227444765798282, 0.08049143711104989, 0.10253022483084351, 0.10401653140434064, 0.04711876674264204, 0.019271153905719984, 0.061658931444981135, 0.06964518630411476, 0.014394548834388843, 0.10737423755927011, 0.0629539902729448, 0.16252195491688326, 0.03340581097290851, 0.03659307178168092, 0.16260145377600566, 0.36543455498758703, 0.6567815761081874, 0.8569764462299645, 5.230420287698507, 6.261418014764786, 17.67851907759905, 36.47611990571022, 48.40309090912342, 51.34734772145748, 56.937790140509605, 46.99032671749592, 36.28575772047043, 32.009524181485176, 21.622889824211597, 12.323905304074287, 17.120099142193794, 23.613992482423782, 34.84639495611191, 41.602877005934715, 47.33561038970947, 61.934901997447014, 58.438173830509186, 66.41273751854897, 65.61311602592468, 62.71905452013016, 38.37056905031204, 20.220561772584915, 5.885788220912218, 0.5625856993719935, 0.1466154443915002, 0.08640358588309027, 0.0475929731328506, 0.08504222729243338, 0.047875876116449945, 0.10405095963506028, 0.024835411677486263, 0.05684594048943836, 0.009103175052587176, 0.031084833171917126, 0.04845081421080977, 0.10460831254022196, 0.016935151325014886, 0.05651929161103908, 0.04120016499655321, 0.04623364802682772, 0.057544564915588126, 0.04339914856245741, 0.04471680207643658, 0.02991364621266257, 0.038145711514516734, 0.02274073882290395, 0.01542841342597967, 0.049151991624967195, 0.017702405857562553, 0.04343884975241963, 0.03730378579348326, 0.09048853738931939, 0.02646780074428534, 0.01093659800972091, 0.0439742721937364, 0.06932540229172446, 0.09924149388098158, 0.01212029294038075, 0.026805431552929804, 0.04601430628099479, 0.0341462591313757, 0.05638388676743489, 0.013848597172909649, 0.051477875022101216, 0.006169849348225398, 0.06866561074275523, 0.04241851915139705, 0.02717128438234795, 0.06311632023425773, 0.06038168787199538, 0.05636103975120932, 0.03475015953881666, 0.06293073136475869, 0.017853655554063153, 0.015582435044052545, 0.013608709996333346, 0.026795933918037917, 0.029069263982819393, 0.04248528275638819, 0.030718364359927364, 0.03796722128754482, 0.05132931190019008, 0.0022259439356275834, 0.029412882067845203, 0.06744744212483056, 0.084171554481145, 0.054973479636828415, 0.07182713015936315, 0.02225327396445209, 0.022448082163464278, 0.03546055071637966, 0.018113203150278423, 0.012532158925750991, 0.04094373442057986, 0.03202778745617252, 0.015070059071149444, 0.03931499486498069, 0.0607559566560667, 0.03686867203214206, 0.031460560276173055, 0.01951375827047741, 0.038194945591385476, 0.06296694817137904, 0.05369150858314242, 0.025725612249516416, 0.051568981070886366, 0.022230360154935624, 0.07339113217312843, 0.7286046096123755, 6.065163295716047, 44.34311516582966, 66.54915779829025, 73.33050951361656, 71.32224887609482, 69.45433750748634, 59.07758831977844, 56.100079491734505, 51.27295531332493, 76.01104527711868, 70.00829458236694, 37.55974195897579, 30.54307647049427, 25.03194909542799, 32.15708166360855, 22.608380243182182, 40.698023959994316, 52.81713545322418, 42.860822305083275, 42.99578346312046, 36.031885743141174, 27.546395771205425, 24.855336472392082, 25.631076246500015, 21.038010008633137, 13.007376529276371, 5.328515823930502, 1.0353938536718488, 0.645361467031762, 0.4472016548970714, 0.1988752870238386, 0.02030304902291391, 0.07070481733535416, 0.05946562530880328, 0.08873421160387807, 0.15749127720482647, 0.17595592624275014, 0.2605969039723277, 0.19133781257551163, 0.08209623498260044, 0.17528419353766367, 0.07582559177535586, 0.19477876543533057, 0.23735156224574894, 0.08469341046293266, 0.15589165210258216, 0.14689214673126116, 0.3103503951570019, 0.3611677105072886, 0.246313470415771, 0.11347974548698403, 0.11752676582545973, 0.022929131155251525, 0.22520695376442745, 0.07629747153259814, 0.07619475087267347, 0.06129392466391437, 0.1163837025524117, 0.18123345711501315, 0.18400745670078322, 0.017257903928111773, 0.07135220759664662, 0.04797517918632366, 0.46171886497177184, 0.7652506150770932, 4.4262775126844645, 5.008131740614772, 15.008765235543251, 23.79314336925745, 33.98273169994354, 49.64479207992554, 58.05835761129856, 43.2395213842392, 28.508944921195507, 31.334057226777077, 28.708018139004707, 24.18439507484436, 26.014222986996174, 33.50121393799782, 43.88846956193447, 54.231674149632454, 58.48730519413948, 68.94479244947433, 63.57873558998108, 75.04234045743942, 73.71604442596436, 72.77317062020302, 47.778666615486145, 27.051462829113007, 8.061612267047167, 0.512076256563887, 0.07571570196887478, 0.02279856511449907, 0.07791478943545371, 0.029308087105164304, 0.029439183781505562, 0.04609296280250419, 0.03052309046324808, 0.038263534879661165, 0.03348729507706594, 0.022392096398107242, 0.0280910094443243, 0.07984274066984653, 0.011827304169855779, 0.08584068913478404, 0.01989724452869268, 0.021975011259200983, 0.07283001657924615, 0.05741904547903687, 0.01643584550038213, 0.05456537262944039, 0.021351987561502028, 0.05806786808534525, 0.03885911210090853, 0.05237361016042996, 0.09154791609034874, 0.056652967250556685, 0.09509271025308408, 0.017205324620590545, 0.01889239327283576, 0.037376401232904755, 0.02865448135707993, 0.05888829749892466, 0.0533017474663211, 0.05032985791331157, 0.13426613673800603, 0.01829998873290606, 0.06842226794105954, 0.015609952024533413, 0.0634831860952545, 0.019097641634289175, 0.02613587334053591, 0.015931229609122965, 0.0152943314606091, 0.02162843942642212, 0.15856237441767007, 0.09645000929594971, 0.20522112463368103, 0.08948697941377759, 0.18225754669401795, 0.07636183800059371, 0.09722145696287043, 0.13565899949753657, 0.11631729517830536, 0.13871333794668317, 0.21092445531394333, 0.1179854798829183, 0.148453016881831, 0.1740400868584402, 0.08627843009890057, 0.1479680382180959, 0.18879306240705773, 0.17880345782032236, 0.15516189829213545, 0.18309283390408382, 0.22903385310200974, 0.09435944608412683, 0.11447049779235385, 0.09471131314057857, 0.14418041333556175, 0.1364450971595943, 0.09199390231515281, 0.13635384268127382, 0.1266563919489272, 0.15199692046735436, 0.13864445179933682, 0.1111628494982142, 0.15101387165486813, 0.16679258435033262, 0.21457424852997065, 0.11542429114342667, 0.13599063560832292, 0.1462252825149335, 0.1832548002130352, 0.17501279013231397, 1.2932581105269492, 8.75980295240879, 53.22924233973026, 75.4505829513073, 83.3334955573082, 81.19239404797554, 80.10524198412895, 66.70816406607628, 62.5505867600441, 58.30790542066097, 85.90921774506569, 71.81173861026764, 35.106350407004356, 35.51338076591492, 24.913061074912548, 47.2260432690382, 24.991445168852806, 56.19245633482933, 85.59120520949364, 63.037021458148956, 72.84617990255356, 58.30562174320221, 42.179199680686, 35.49833357334137, 41.652278155088425, 33.09520572423935, 18.96512433886528, 8.122608494013548, 1.886160601861775, 1.2170229200273752, 0.7409560249652714, 0.5188443465158343, 0.10810502295498736, 0.22330181614961475, 0.20782324281753972, 0.21913179225521162, 0.3292410518042743, 0.4978072800440714, 0.44334186357446015, 0.2519366343040019, 0.26265538414008915, 0.36147656268440187, 0.3502000740263611, 0.391110519412905, 0.528036825126037, 0.32735201879404485, 0.19670989306177944, 0.14928000688087195, 0.4640186915639788, 0.42310406046453863, 0.6421904184389859, 0.2090001554461196, 0.20037380192661658, 0.25265936739742756, 0.31586832250468433, 0.25151758803986013, 0.16187502478715032, 0.31876839813776314, 0.2755056117894128, 0.3289079759269953, 0.2693611930590123, 0.12056405714247376, 0.5014408647548407, 0.9600538713857532, 0.9205459663644433, 1.4692540979012847, 6.5267525520175695, 8.143091294914484, 22.907418496906757, 45.311516001820564, 58.7056452780962, 60.676683112978935, 71.0738106071949, 61.375560611486435, 47.70211212337017, 44.15330395102501, 33.570130839943886, 24.49070043861866, 27.414717637002468, 35.84974631667137, 48.9694657176733, 59.41123701632023, 66.38768166303635, 78.81475523114204, 74.20759364962578, 86.07020750641823, 84.90034908056259, 81.32955148816109, 58.20930831134319, 33.05216163396835, 9.681917522102594, 0.6735170062165707, 0.382447013980709, 0.16132731980178505, 0.1965436668251641, 0.10026412142906338, 0.11764973227400333, 0.19704377045854926, 0.13868209352949634, 0.1865868948516436, 0.09760141430888325, 0.10270592829328962, 0.1263478514738381, 0.21929678652668372, 0.16569935629377142, 0.17921426624525338, 0.11575491051189601, 0.13271204981720075, 0.16958595399046317, 0.1636808630428277, 0.11214102982194163, 0.17683851794572547, 0.10052955796709284, 0.1856528574717231, 0.08390907169086859, 0.1558042864780873, 0.12055794926709495, 0.21194152417592704, 0.12027405551634729, 0.16284567973343655, 0.08307478638016619, 0.14859227347187698, 0.12196013340144418, 0.2443939945078455, 0.12389727242407389, 0.17224308016011491, 0.24746883107582107, 0.07592635316541418, 0.18039022892480716, 0.1644084943109192, 0.1215452876931522, 0.21715851064072922, 0.1493770649540238, 0.08924267182010226, 0.14647465897724032, 0.0745769431523513], [0.018329066078877077, 0.04239883739501238, 0.019272671597718727, 0.01710976197500713, 0.06376765872118995, 0.04704726081399713, 0.04178168223006651, 0.08732839094591327, 0.049414199820603244, 0.03670444588351529, 0.04388018271129113, 0.06018764222972095, 0.038010469943401404, 0.03133892227197066, 0.029546233017754275, 0.044318988657323644, 0.11891297894180752, 0.014195622643455863, 0.08005558862350881, 0.01622323503397638, 0.02250094348710263, 0.01313609736826038, 0.06260774127440527, 0.03023921155545395, 0.03488810623821337, 0.059261453061481006, 0.06268327706493437, 0.037039588642073795, 0.03096845142863458, 0.01323452470387565, 0.035484807813190855, 0.060947742458665743, 0.02865212874894496, 0.0248045513217221, 0.05184993591683451, 0.03186633322911803, 0.01738788552756887, 0.041030302236322314, 0.07900697106379084, 1.9642024766653776, 8.212600965052843, 40.55649675428867, 63.989774733781815, 71.91067770123482, 63.83207559585571, 53.06939251720905, 47.6489681750536, 46.76710769534111, 26.37022588402033, 29.489345513284206, 41.39288127422333, 25.696660727262497, 17.801045402884483, 21.84588845819235, 29.631651677191257, 68.00561964511871, 41.728631258010864, 33.698818534612656, 44.761666506528854, 32.76543281972408, 21.76102951169014, 11.994634922593832, 11.63383573293686, 8.077350072562695, 3.2380805583670735, 1.660438938997686, 1.202510786242783, 0.03801445898716338, 0.049802851426647976, 0.040029972515185364, 0.062353637331398204, 0.041527559733367525, 0.07630610271007754, 0.015121467640710762, 0.027056247781729326, 0.0859477290941868, 0.06397212782758288, 0.04746009159134701, 0.1356863253749907, 0.0933132776117418, 0.046161422214936465, 0.028709222169709392, 0.16076922474894673, 0.1437407947378233, 0.1852264194167219, 0.13379206764511764, 0.06876426443341188, 0.22574082511710003, 0.039262109421542846, 0.17021829349687323, 0.03721855755429715, 0.05675513872120064, 0.1456946914549917, 0.08365219211555086, 0.05207243550103158, 0.04224519056151621, 0.18853207875508815, 0.043487193252076395, 0.07203800400020555, 0.03485988607280888, 0.06411885042325594, 0.07600665354402736, 0.036072470029466785, 0.0629874314472545, 0.010226432259514695, 0.0371139073104132, 0.06197610680828802, 0.5059164308477193, 0.5965153849683702, 2.88885744754225, 9.455913249403238, 11.994367986917496, 22.507077679038048, 46.396209597587585, 61.39228731393814, 52.344653606414795, 40.79771541059017, 27.98385489732027, 21.97749439626932, 16.466085836291313, 22.37062130123377, 17.48333115130663, 29.773653857409954, 47.58969895541668, 52.90149472653866, 59.05244126915932, 60.92131778597832, 65.33696204423904, 64.92786079645157, 49.13294814527035, 35.585238710045815, 8.247567638754845, 0.6008250662125647, 0.17795135354390368, 0.06119741949078161, 0.05106346718093846, 0.04073908719874453, 0.07527141526225023, 0.013196117633924587, 0.07236141711473465, 0.016461399500258267, 0.026306977342756, 0.008475889571855078, 0.018358991328568663, 0.033706299145706, 0.09166589530650526, 0.03559815602784511, 0.061678553829551674, 0.04917697602650151, 0.0694315145665314, 0.015272136606654385, 0.03584791469620541, 0.05506084155058488, 0.04418132397404406, 0.02094568026222987, 0.052921374517609365, 0.03311795044282917, 0.007082840811563074, 0.021605473666568287, 0.037698148225899786, 0.044318610162008554, 0.036198828092892654, 0.053141914831940085, 0.041253714662161656, 0.05827596258313861, 0.017497877379355486, 0.04314915982831735, 0.04347398673417047, 0.07127363642212003, 0.01746011505019851, 0.03367111392435618, 0.02641466482600663, 0.05908186445594765, 0.05634877205011435, 0.04130946479563136, 0.07238529200549237, 0.04415529685502406, 0.03930830440367572, 0.023955261640367098, 0.040159970812965184, 0.07372219683020376, 0.027261262366664596, 0.00468202369120263, 0.07877743220888078, 0.022389446930901613, 0.03610512081650086, 0.10131948511116207, 0.08731019348488189, 0.02511027534637833, 0.0821358359826263, 0.026995963125955313, 0.07638158655026928, 0.09377775073517114, 0.03847428255539853, 0.05350721847207751, 0.09183624788420275, 0.02091664744511945, 0.06905684873345308, 0.05653043124766555, 0.015128279628697783, 0.0592603472614428, 0.029800158845318947, 0.04370690607174765, 0.01964659157238202, 0.04597559214744251, 0.05739942309446633, 0.03844504935841542, 0.0637519771407824, 0.03116510015388485, 0.0843413281836547, 0.0363168258627411, 0.02693406986509217, 0.015740375201858114, 0.032467246492160484, 0.07702433838858269, 2.4384721275418997, 13.620179146528244, 52.455934435129166, 74.19750899076462, 78.80992189049721, 72.45105430483818, 61.363743245601654, 57.76119455695152, 55.70464611053467, 36.674355268478394, 38.66839326918125, 44.078987538814545, 34.97543603181839, 23.534255661070347, 29.261802323162556, 26.05774775147438, 54.31415632367134, 26.99315495789051, 25.79007301479578, 38.047707974910736, 25.31184397637844, 15.658155139535666, 9.90752661600709, 7.477271072566509, 5.828669210895896, 2.927437014877796, 1.4679572987370193, 0.7385651220101863, 0.2321748892427422, 0.08586761425249279, 0.07274369738297537, 0.03431225530221127, 0.09003674014820717, 0.14313665684312582, 0.10721009675762616, 0.10550602921284735, 0.18836609000572935, 0.15604831947712228, 0.12695396348135546, 0.29440241341944784, 0.1602808470488526, 0.165449490013998, 0.13083650905173272, 0.14934115984942764, 0.11653590219793841, 0.14654764177976176, 0.19400970748392865, 0.2652005647541955, 0.45620874501764774, 0.895026654470712, 0.4065427975729108, 0.1760394178563729, 0.20923258125549182, 0.371424607001245, 0.20428500924026594, 0.43277653050608933, 0.07869092005421408, 0.2789018873590976, 0.2837198507040739, 0.21124117425642908, 0.10763392987428233, 0.12949656142154709, 0.43266624736133963, 0.10655504753231071, 0.23466335493139923, 0.05886086029931903, 0.0775991243426688, 0.025529481172270607, 0.03617107548052445, 0.3578984906198457, 2.0111553696915507, 6.739699300378561, 11.297210846096277, 18.40090971440077, 37.34886847436428, 52.062271758913994, 49.81967009603977, 41.72467187047005, 30.501550398766994, 26.7220851033926, 25.16647517681122, 30.671416483819485, 27.315476462244987, 38.65307629108429, 55.63580900430679, 60.816622003912926, 67.36084744334221, 68.42661425471306, 71.6305111348629, 71.35037496685982, 57.471707090735435, 43.92539978027344, 12.347826920449734, 0.9536912315525115, 0.1395911947474815, 0.07189396055764519, 0.04069867354701273, 0.07861736579798162, 0.0627715555310715, 0.0302977169121732, 0.05938562549999915, 0.054163577588042244, 0.02641193557792576, 0.03674679282994475, 0.03699267377669457, 0.051420139643596485, 0.06985876156250015, 0.06224748052773066, 0.052019527793163434, 0.009137387132795993, 0.061124618514440954, 0.07575034542242065, 0.027136275421071332, 0.012760355421050917, 0.07167791394749656, 0.010059197629743721, 0.0626449822448194, 0.0359255990042584, 0.05827785505971406, 0.019556828810891602, 0.019668765089591034, 0.04711370529548731, 0.07718603752437048, 0.025328880510642193, 0.08055419311858714, 0.0001988976501365869, 0.017621947772568092, 0.05704176357539836, 0.045095163804944605, 0.07847060609492473, 0.026295119678252377, 0.050431238996679895, 0.059428354652482085, 0.037119354674359784, 0.0320252901292406, 0.0318159673770424, 0.07775747639243491, 0.1935063532437198, 0.16427152353571728, 0.19872464588843286, 0.1026396693487186, 0.21182356722420081, 0.11060356700909324, 0.26607184612657875, 0.1382228673901409, 0.12433043433702551, 0.1319404537207447, 0.1893281954107806, 0.19850066571962088, 0.1746695171459578, 0.16641684982459992, 0.19283076137071475, 0.10031561163486913, 0.20653465180657804, 0.1239005898241885, 0.16603338212007657, 0.16235838556895033, 0.08640748215839267, 0.18152130651287735, 0.12736120959743857, 0.07737949315924197, 0.26077760208863765, 0.0964330586430151, 0.21216937835561112, 0.15214563201880082, 0.11974743494647555, 0.1551227128948085, 0.18057447450701147, 0.09553630676236935, 0.14289293554611504, 0.1256897594430484, 0.11002045415807515, 0.2660119399661198, 0.15950491680996493, 0.11357073279214092, 0.2038513871957548, 3.2448133220896125, 18.75665232539177, 64.80982393026352, 84.22203987836838, 88.11801642179489, 82.70731955766678, 72.25603356957436, 66.07468485832214, 65.27922794222832, 41.51528410613537, 43.74099187552929, 51.49689629673958, 34.462334364652634, 28.096959628164768, 32.26089969277382, 41.166219636797905, 84.92165073752403, 56.82655490934849, 46.8674299120903, 57.42345727980137, 42.53649450838566, 28.405740559101105, 16.148160696029663, 14.854605607688427, 11.278691589832306, 4.665696490556002, 2.911263657733798, 2.034464031457901, 0.5343944777268916, 0.21341501385904849, 0.22142502857604995, 0.12012166291242465, 0.1971685848548077, 0.1872572471620515, 0.2956817572703585, 0.2109178205137141, 0.20399622473632917, 0.1231654777075164, 0.10253895990899764, 0.4360435833223164, 0.245708649745211, 0.6013832206372172, 0.371932057896629, 0.7246742548886687, 0.5650340742431581, 0.6143685488495976, 0.6903111550491303, 0.5160441936459392, 0.7231663889251649, 0.8192641229834408, 0.33188366156537086, 0.2009431627811864, 0.19736452668439597, 0.3377569589065388, 0.2744000492384657, 0.3680595016339794, 0.1560532473376952, 0.34401002805680037, 0.29414791613817215, 0.22988209821050987, 0.1795808575116098, 0.5562313715927303, 0.5353520263452083, 0.27487822982948273, 0.2954906987724826, 0.25852723221760243, 0.21822907350724563, 0.12679909210419282, 1.0526097798720002, 1.0248913359828293, 4.66324657201767, 11.386811938136816, 16.21158119291067, 29.738798327744007, 59.02264326810837, 76.02377459406853, 68.98428753018379, 53.938584476709366, 38.082521706819534, 33.21721337735653, 26.735276095569134, 33.51629912853241, 28.355093076825142, 45.419331416487694, 65.7102008163929, 72.70981281995773, 78.80749762058258, 77.80151680111885, 84.26170974969864, 81.63189366459846, 71.13428056240082, 54.87943299114704, 17.477017790079117, 1.4944881875999272, 0.305699800956063, 0.13757948472630233, 0.2097171888453886, 0.16797978314571083, 0.18391360470559448, 0.1879009118420072, 0.14289060520241037, 0.10232929576886818, 0.09745504052261822, 0.0795961992116645, 0.07573487906483933, 0.2382364249206148, 0.1909536324092187, 0.1932192756794393, 0.14075427374336869, 0.15207358432235196, 0.12262932053999975, 0.1812481219531037, 0.1132442026573699, 0.15110754553461447, 0.12102660068194382, 0.11233985860599205, 0.22728199866833165, 0.16066495300037786, 0.1876287069171667, 0.08206833022995852, 0.21022045402787626, 0.13971020554890856, 0.15408337960252538, 0.20346881006844342, 0.2604916080599651, 0.10845225158846006, 0.145904615346808, 0.1389225196908228, 0.16693712503183633, 0.12187604064820334, 0.11597771808737889, 0.1581167444237508, 0.15106326900422573, 0.10821345815202221, 0.1951889504562132, 0.10577223016298376, 0.1610877545317635], [0.0881404711981304, 0.05667466022714507, 0.01424872238203534, 0.03793749085161835, 0.002604739588605298, 0.018505112784623634, 0.053589147864840925, 0.06424131963285618, 0.06928675866220146, 0.04543756105704233, 0.049560506813577376, 0.016845626050780993, 0.0503133859456284, 0.035870164283551276, 0.07368530466919765, 0.021188249374972656, 0.017381477082381025, 0.05045470199547708, 0.07630412117578089, 0.033857752932817675, 0.08391675291932188, 0.031366311231977306, 0.0218336952093523, 0.05324767087586224, 0.04360759186965879, 0.043883359103347175, 0.01856805432908004, 0.03880201496940572, 0.01994725600525271, 0.04539088738965802, 0.057912774063879624, 0.05408715493103955, 0.04311768905608915, 0.04071996205311734, 0.05629205712466501, 0.08326640891027637, 0.006279075860220473, 0.05327062921423931, 1.8709005019627512, 17.169587686657906, 51.80201232433319, 67.5096246600151, 70.96585839986801, 63.6209437251091, 53.64202938973904, 40.30982159078121, 28.443626426160336, 30.87114706635475, 22.761597521603107, 23.96155223250389, 32.76262857019901, 16.821923442184925, 33.08737814426422, 35.16618959605694, 67.79918432235718, 53.484759628772736, 42.94780343770981, 32.168978825211525, 12.640144284814596, 7.682668101042509, 4.379421276971698, 1.9831388792954385, 0.6614109745714813, 0.24400101247010753, 0.0682973644870799, 0.03672624647151679, 0.045034641661914065, 0.08905782509827986, 0.021590831092908047, 0.06623993074754253, 0.0420603252860019, 0.0204435449995799, 0.08111328264931217, 0.06394662021193653, 0.007630523068655748, 0.03989497956354171, 0.35990154719911516, 0.3486650454578921, 0.3171288751764223, 0.15619241487002, 0.164888841973152, 0.037831163353985175, 0.09893918744637631, 0.055623122316319495, 0.043021105957450345, 0.10839175913133658, 0.15108672087080777, 0.4628365096868947, 1.1037838901393116, 0.794775327667594, 0.45454188133589923, 0.1821106905117631, 0.35278494469821453, 0.20888406870653853, 0.7082594325765967, 0.18843579251552, 0.14256250171456486, 0.19051607698202133, 0.2735612145625055, 0.4396587627707049, 0.38309268245939165, 0.16963695437880233, 0.1528566688648425, 0.04509818805672694, 0.06284125804086216, 0.03579098825866822, 0.14221790770534426, 0.05411588717834093, 0.04572660902340431, 0.03436267681536265, 0.04017202329123393, 0.9508131828624755, 8.421994429081678, 9.98275687918067, 18.97893089801073, 39.144549518823624, 52.56596893072128, 53.47423419356346, 34.834661185741425, 31.199808530509472, 26.08949314802885, 16.213437393307686, 24.013856425881386, 32.49405898153782, 40.035031735897064, 42.27158032357693, 41.40480503439903, 51.48203909397125, 54.860605001449585, 60.33409349620342, 60.55140383541584, 36.701694801449776, 12.877279110252857, 3.191827777773142, 0.09929298408678733, 0.048969709023367614, 0.11633496571448632, 0.05405204763519578, 0.09141256319708191, 0.0661953870439902, 0.03827882312180009, 0.03723612418980338, 0.058809592737816274, 0.04220209033519495, 0.03918176080333069, 0.023936435209179763, 0.01802663718990516, 0.04932327559799887, 0.008862767444952624, 0.016408356350439135, 0.012064820184605196, 0.06601944609428756, 0.06046207359759137, 0.06825630887760781, 0.08105091255856678, 0.07132913422537968, 0.022869260246807244, 0.0958543986780569, 0.044962285974179395, 0.07758767300401814, 0.032862210064195096, 0.08274952531792223, 0.032207472540903836, 0.03938612229831051, 0.02963402908790158, 0.04949864509399049, 0.036527276679407805, 0.055948951121536084, 0.04533010549494065, 0.014986387486715103, 0.02119532389770029, 0.009983024519897299, 0.06811251034378074, 0.046959572355262935, 0.039692161735729314, 0.08990984031697735, 0.013554006291087717, 0.03144229973258916, 0.06809394180891104, 0.06891605589771643, 0.0303481996525079, 0.10026375035522506, 0.039644560383749194, 0.09437753964448348, 0.06929976108949631, 0.07896617520600557, 0.03370893748069648, 0.03811289003351703, 0.0245523584089824, 0.03726046663359739, 0.028984024611418135, 0.0345857552747475, 0.006427538328352966, 0.09269805945223197, 0.0241597159038065, 0.016052975224738475, 0.036744132230523974, 0.02013946112128906, 0.03392255355720408, 0.010776968538266374, 0.020496371071203612, 0.03563277350622229, 0.04404483930557035, 0.04470499079616275, 0.02540094490541378, 0.04227827550494112, 0.023925572022562847, 0.008230773964896798, 0.03404752380447462, 0.004140460905546206, 0.03334516266477294, 0.07360122675891034, 0.05256632364762481, 0.0814060153788887, 3.8088004337623715, 24.5981377735734, 64.5086520910263, 78.59685972332954, 78.84949296712875, 70.86665332317352, 61.51975907385349, 51.77774302661419, 40.687012150883675, 48.43206815421581, 29.733165130019188, 27.02361222356558, 37.81756192445755, 28.63061249256134, 32.66843542456627, 25.539636053144932, 48.783971071243286, 45.976377725601196, 31.984601318836212, 26.337051764130592, 11.226566936820745, 5.8490589167922735, 3.070314098149538, 1.0735094896517694, 0.6075041578151286, 0.15223556547425687, 0.08657354512251914, 0.12166915214038454, 0.048665569484001026, 0.18886972626205534, 0.0750955188414082, 0.18851572182029486, 0.5881347565446049, 0.5633752257563174, 0.16246994520770386, 0.3272507601650432, 0.09608272041077726, 0.6463680567685515, 1.8360246671363711, 2.4099845811724663, 1.2236621137708426, 0.7928057864774019, 0.2759151585632935, 0.4728772334055975, 0.24248361733043566, 0.3586234798422083, 0.82902199937962, 0.11004314161255024, 0.3256562113529071, 1.1892576911486685, 2.3039816692471504, 2.0738023705780506, 2.096233516931534, 1.9115278031677008, 1.3759501045569777, 1.534339024219662, 1.2579821096733212, 1.3554272870533168, 1.1198864760808647, 0.5554552632384002, 0.5736957094632089, 1.803023675456643, 2.7401175163686275, 2.323249247856438, 0.7124993519391865, 0.1984450194868259, 0.19330046663526446, 0.3035466227447614, 0.3583762556081638, 0.08034469225094654, 0.0912767650152091, 0.08778524221270345, 0.05896354756259825, 0.5887573887594044, 4.834393188357353, 8.308593314141035, 18.019320890307426, 34.504002928733826, 46.6936120390892, 40.625254064798355, 33.213504776358604, 28.26975915580988, 36.613189950585365, 22.79285654425621, 34.20132257044315, 43.54745306074619, 50.9560789167881, 51.290472373366356, 48.984364718198776, 62.2120401263237, 64.84308734536171, 68.32192987203598, 69.83662739396095, 45.44834665954113, 15.996776819229126, 3.816795442253351, 0.035061995149590075, 0.028615650335268583, 0.060518688333104365, 0.05112646067573223, 0.050884761731140316, 0.08856420041411184, 0.04859492073592264, 0.014783121587242931, 0.015788702003192157, 0.031010273305582814, 0.01146044294728199, 0.02831189485732466, 0.03560610071872361, 0.03053630996873835, 0.02086847092868993, 0.03495504424790852, 0.030355203671206255, 0.04255955689586699, 0.011483621146908263, 0.05058026967162732, 0.02601403495646082, 0.05962294206256047, 0.06439625780330971, 0.052404275702429004, 0.0504699679731857, 0.007035077114778687, 0.02720169573876774, 0.09552519681164995, 0.02126830670022173, 0.021572045479842927, 0.02894178713177098, 0.09480218170210719, 0.06354514800477773, 0.10230204410618171, 0.018135844220523722, 0.0170368441104074, 0.06330860327580012, 0.056978027932927944, 0.046848981219227426, 0.058076970526599325, 0.06209254977875389, 0.038945768974372186, 0.09622988087357953, 0.17985567479627207, 0.14312929473817348, 0.1470789304585196, 0.11884015199029818, 0.09792706128791906, 0.11662596923997626, 0.19148594525177032, 0.13585752400103956, 0.10848113597603515, 0.1094313150679227, 0.06987781991483644, 0.13245943759102374, 0.12016020264127292, 0.0921181749436073, 0.1280974200926721, 0.12160310841863975, 0.1175493048503995, 0.1684333838056773, 0.07993162027560174, 0.1520895108114928, 0.08880309775122441, 0.11644687416264787, 0.08462217170745134, 0.13857902406016365, 0.09893995185848325, 0.19998185889562592, 0.15975252696080133, 0.1949473813874647, 0.15325910586398095, 0.2320970973232761, 0.12297772918827832, 0.13304600142873824, 0.1318837536382489, 0.14597142348065972, 0.15978921874193475, 0.1870116704958491, 0.15776875137817115, 4.11668342538178, 31.198533698916435, 76.42023012042046, 88.49370226264, 88.31260398030281, 80.94232946634293, 72.68309265375137, 60.50233706831932, 44.67819258570671, 45.8582154661417, 35.36571308970451, 37.66829453408718, 43.64661633968353, 26.1706130951643, 48.59702490270138, 48.6483259499073, 83.47189173102379, 65.30257388949394, 55.909709706902504, 41.596873328089714, 18.594030551612377, 10.263018440455198, 6.409018244594336, 2.7910371590405703, 1.3603576412424445, 0.5308948655147105, 0.2948149881558493, 0.24856850097421557, 0.16591708757914603, 0.2660183818079531, 0.1459507324034348, 0.27594365703407675, 0.5927957408130169, 0.6807287223637104, 0.13326444517588243, 0.22742735571227968, 0.09259990300051868, 0.2802646189229563, 1.3454002188518643, 1.754191427025944, 0.5898141476791352, 0.538222297327593, 0.45141340233385563, 0.6113036570604891, 0.6117471645120531, 0.5799319467041641, 1.0560273402370512, 0.44482696044724435, 0.930085057625547, 2.0750249549746513, 3.4283574856817722, 2.5701554864645004, 1.6674663056619465, 0.9907219663728029, 1.01572290295735, 1.2307650013826787, 1.0805856599472463, 0.9493727039080113, 0.6505070440471172, 0.503109865821898, 0.6673267227597535, 2.2951369313523173, 4.343146048486233, 2.985421665944159, 0.5114530900027603, 0.19690901128342375, 0.22636799927568063, 0.2504488656995818, 0.37401859124656767, 0.12516081595094875, 0.1353347848635167, 0.14981294312747195, 0.30706472927704453, 1.8202444701455534, 10.033123176544905, 14.122543539851904, 25.72971135377884, 48.30661028623581, 68.56688752770424, 69.19825404882431, 50.107782036066055, 41.684074848890305, 41.228802278637886, 28.380844295024872, 36.82008884847164, 46.395704224705696, 54.096769988536835, 57.61190056800842, 57.551499009132385, 68.01901772618294, 72.77737319469452, 77.58427485823631, 79.00175079703331, 57.971589267253876, 23.28689083456993, 5.910767130553722, 0.2825093187857419, 0.15182601870037615, 0.31427285342942923, 0.09830794631852768, 0.15612487943144515, 0.17001895263092592, 0.10447139371535741, 0.08394724034587853, 0.13508886680938303, 0.07545409491285682, 0.09392117819515988, 0.1293721774709411, 0.13698210037546232, 0.13270483614178374, 0.1559531909879297, 0.07469927135389298, 0.12408599315676838, 0.15228901494992897, 0.11969755520112813, 0.14725398825248703, 0.17957104631932452, 0.24178386112907901, 0.2709260559640825, 0.2196804026607424, 0.1186497465823777, 0.11715022978023626, 0.09711961945868097, 0.22650014609098434, 0.1613040015217848, 0.20338594185886905, 0.14004813507199287, 0.1461740001104772, 0.13858282385626808, 0.16681648150552064, 0.11042368525522761, 0.08211941967601888, 0.14009319827891886, 0.13564129185397178, 0.16062349663116038, 0.10862477865885012, 0.15451894607394934, 0.11717547022271901], [0.040332163916900754, 0.05827892375236843, 0.055922582614584826, 0.014093673817114905, 0.009460080364078749, 0.042300083514419384, 0.07929696526844054, 0.01187344905702048, 0.018871670654334594, 0.005160752543815761, 0.011498453895910643, 0.03188595190295018, 0.040935708093456924, 0.025651508804003242, 0.004309295791244949, 0.016069742196123116, 0.009919781477947254, 0.08007402357179672, 0.038294760743156075, 0.09407177480170503, 0.028676875663222745, 0.03583086385333445, 0.03965915100707207, 0.003960878793805023, 0.03989621523942333, 0.03736158054380212, 0.023424737373716198, 0.029111052463122178, 0.03595610127376858, 0.008707305132702459, 0.014998584683780791, 0.024387380835833028, 0.06182142096804455, 0.02853210306057008, 0.021446646642289124, 0.07373512504273094, 0.007621242511959281, 3.833343554288149, 28.78011927008629, 56.14904746413231, 66.84121012687683, 64.57679763436317, 50.400666519999504, 53.9136616140604, 41.291202530264854, 27.09712117910385, 16.679898463189602, 15.746750235557556, 25.215600840747356, 27.426975779235363, 12.949251048266888, 32.8018918633461, 49.46885772049427, 63.611584827303886, 44.86447758972645, 16.83075036853552, 7.010056218132377, 1.1057163239456713, 0.5517731420695782, 0.12225529295392334, 0.05181460226594936, 0.007133503986551659, 0.06326537317363545, 0.037825311519554816, 0.02027268405072391, 0.014637450058216928, 0.0755253856186755, 0.10415709417429753, 0.22197638492798433, 0.14938182954210788, 0.3630705474643037, 0.583062800578773, 0.2393560140626505, 0.4525211616419256, 0.5295181518886238, 0.9790418087504804, 1.644590583164245, 0.9835234307684004, 0.762516186805442, 0.19706455059349537, 0.011485582272143802, 0.26056763366796076, 0.2181345535791479, 0.08200068346923217, 0.14796566334553063, 0.09644629113608971, 0.3456692327745259, 1.094579715281725, 2.5877521047368646, 1.267996709793806, 1.648472787346691, 3.0868759844452143, 1.342745111323893, 0.8149371051695198, 1.515769420657307, 0.7309844100382179, 1.3465773244388402, 0.4614954785211012, 0.3250872512580827, 0.5215399456210434, 1.1093384795822203, 0.34699589596129954, 0.4398288927040994, 0.27463626000098884, 0.1558515612850897, 0.13392344262683764, 0.12099992047296837, 0.019770671242440585, 0.17617333098314703, 0.051197361754020676, 0.20246489206328988, 0.052019642826053314, 0.06683453204459511, 0.379944343585521, 3.101687589660287, 8.278869409114122, 17.970218025147915, 35.65137416124344, 50.583782494068146, 49.647113755345345, 28.89844112098217, 32.622298300266266, 27.9066164419055, 24.9764758720994, 25.75813762843609, 40.41398540139198, 42.46903672814369, 26.00471019744873, 46.839478611946106, 55.70695258677006, 65.86784675717354, 55.586495250463486, 45.92580243945122, 16.494591906666756, 5.22656349465251, 1.1932796565815806, 0.062645249417983, 0.039148820578702725, 0.040857778876670636, 0.06795293375034817, 0.03790354872762691, 0.0373913963267114, 0.07049405481666327, 0.022091329919931013, 0.03460059822828043, 0.027713786912499927, 0.04232769140799064, 0.020016539201606065, 0.03176238802552689, 0.021543539587582927, 0.047064103855518624, 0.0287383236354799, 0.04432875161000993, 0.06766558159142733, 0.05887433770112693, 0.05567109845287632, 0.06269226447329856, 0.045735062085441314, 0.03764419780054595, 0.02874634439649526, 0.0741992196708452, 0.07183691166574135, 0.04953048694005702, 0.020683496186393313, 0.07282724836841226, 0.020969050492567476, 0.03673868857731577, 0.06696086042211391, 0.02895489160437137, 0.04588200361467898, 0.06662854895694181, 0.05222331041295547, 0.011676362464640988, 0.042492199572734535, 0.01961648820724804, 0.01492438754212344, 0.01772580020769965, 0.018099540211551357, 0.04266365052899346, 0.03872559231240302, 0.027872734535776544, 0.027698567319021095, 0.059879810505663045, 0.08866336618666537, 0.07704908901359886, 0.02491227220161818, 0.008115117670968175, 0.021586413458862808, 0.049492039979668334, 0.028633313449972775, 0.015690356303821318, 0.025240080685762223, 0.051198942528571934, 0.027680937600962352, 0.03209808739484288, 0.029034652070549782, 0.022111024663900025, 0.0613762696593767, 0.04963045423210133, 0.03636181114416104, 0.05823117397085298, 0.024196708254748955, 0.042796446723514237, 0.018732284188445192, 0.04041260530357249, 0.029621065623359755, 0.022490616502182093, 0.07337304603424855, 0.012217692401463864, 0.02384846844506683, 0.04037609163788147, 0.06622054585022852, 0.16213090246310458, 7.214423026889563, 40.90474806725979, 69.25279632210732, 75.29531568288803, 72.3863285779953, 59.680452570319176, 62.45795153081417, 51.567697897553444, 41.12642057240009, 26.621586196124554, 24.641369953751564, 23.81973624229431, 25.651108771562576, 26.262929141521454, 27.62725543230772, 40.719880387187004, 46.111392080783844, 37.33955517411232, 15.929669570177794, 6.949909720569849, 2.0495157362893224, 0.5940542451571673, 0.14250121515942737, 0.04435651906533167, 0.03620109906478319, 0.13753551989793777, 0.18753426120383665, 0.15027641435153782, 0.18877140653785318, 0.453653916483745, 0.9332018997520208, 1.0579659487120807, 0.8758657076396048, 1.2650619610212743, 1.254591504111886, 2.7389524038881063, 1.6936155525036156, 2.963407072238624, 2.735871006734669, 4.573643105104566, 5.937258834019303, 3.728598849847913, 1.393239414319396, 0.6160747166723013, 0.8571530773770064, 0.6257788022048771, 0.7469659368507564, 0.28877868549898267, 0.06444609301979654, 0.44235584617126733, 1.5507813356816769, 3.5434188740327954, 2.928202673792839, 4.942589532583952, 5.999121414497495, 4.234339836984873, 3.5865178238600492, 4.026421643793583, 3.2594014517962933, 4.388165082782507, 3.7134882481768727, 2.989241648465395, 3.956870175898075, 4.246124904602766, 3.365794555284083, 2.939987266436219, 0.99090815638192, 1.2923334538936615, 0.586989177390933, 0.7202400115784258, 0.41229506547097117, 0.4594597971299663, 0.3104724339209497, 0.4147751448908821, 0.08915779239032418, 0.05698360146197956, 0.16000558447558433, 1.7961255018599331, 6.353896027430892, 16.11742414534092, 32.54665955901146, 46.899864971637726, 42.46893033385277, 31.349338106811047, 28.63661427050829, 29.537152647972107, 28.333856016397476, 39.0929900854826, 49.27990145981312, 49.87510912120342, 32.77163028717041, 52.682660669088364, 63.48016507923603, 72.32712775468826, 64.98681843280792, 54.527784660458565, 20.683793015778065, 5.652485964819789, 1.3352881302125752, 0.08682565268827602, 0.0532045446743723, 0.04286337360099424, 0.07959122682223096, 0.02735636859142687, 0.04287846517399885, 0.02961564423458185, 0.028527793037937954, 0.04935444951115642, 0.048859303424251266, 0.03319205388834234, 0.04111230213311501, 0.03624553144618403, 0.010912173929682467, 0.03399415967578534, 0.01996630508074304, 0.07313707275898196, 0.06094097036111634, 0.047933886089595035, 0.053055836833664216, 0.02840274672053056, 0.02812399048707448, 0.02186664285545703, 0.05166964227100834, 0.02354106902203057, 0.06510828170576133, 0.03446366827120073, 0.04500972405367065, 0.04720402095699683, 0.01440925820133998, 0.07345690872170962, 0.05675963613612112, 0.029255253612063825, 0.07802981490385719, 0.02753286244114861, 0.007060786501824623, 0.027704927524609957, 0.013084862275718478, 0.07735277584288269, 0.034194509862572886, 0.12581047718413174, 0.17395120725268498, 0.12468929984606802, 0.06635007288423367, 0.10819884526426904, 0.11951804452110082, 0.18333220621570945, 0.28379887458868325, 0.23277328291442245, 0.14289781887782738, 0.15027867048047483, 0.09559452824760228, 0.1468398846918717, 0.116220348427305, 0.10499778421944939, 0.10415460797958076, 0.10632435834850185, 0.13775936648016796, 0.16137423837790266, 0.22004050755640492, 0.07538494901382364, 0.16371661971788853, 0.14335639192722738, 0.14835380658041686, 0.1742170297075063, 0.10128635563887656, 0.12750702677294612, 0.10054252328700386, 0.22373528976459056, 0.10202115605352446, 0.09956907786545344, 0.1364990512956865, 0.1420860132202506, 0.09971085775760002, 0.1403715630294755, 0.3441989788552746, 0.2615702454932034, 9.986914806067944, 52.85883441567421, 81.10508993268013, 83.15454035997391, 82.05646008253098, 70.35305008292198, 73.60312208533287, 58.193599954247475, 42.37268149852753, 28.29739697277546, 26.91406600177288, 36.17525964975357, 36.85327246785164, 22.693917453289032, 45.9642069786787, 63.99656876921654, 80.1678854227066, 55.489577651023865, 22.2499530762434, 10.424952451139688, 2.3776340670883656, 1.319290513638407, 0.2747847489081323, 0.21418119227746502, 0.1969622529577464, 0.2638667175779119, 0.29511959524825215, 0.16707130533177406, 0.2052335927146487, 0.2960902056656778, 0.7603712612763047, 0.8845811930950731, 0.695121637545526, 0.9525474335532635, 1.5169341769069433, 2.4316761922091246, 2.11810989305377, 3.3279454987496138, 2.9493509139865637, 2.533343774266541, 5.1630774512887, 5.2068202290683985, 0.7206855376716703, 0.4997081577312201, 0.9805174358189106, 1.8624756415374577, 1.3473759940825403, 0.596232240786776, 0.44410081347450614, 1.8046434572897851, 3.0159824760630727, 7.314575677737594, 6.3911093305796385, 5.135390711948276, 5.4273646697402, 4.297031722962856, 2.846393301151693, 5.4921977408230305, 4.104406759142876, 5.401033507660031, 3.1701442413032055, 3.068699659779668, 5.628260364755988, 7.0744874607771635, 11.35203905403614, 2.764369952492416, 0.7672608853317797, 0.9772999584674835, 0.2895196160534397, 0.3704159095650539, 0.2760733844479546, 0.3285721392603591, 0.262090164469555, 0.4857029998674989, 0.2589690772583708, 0.1538583604269661, 0.7286883832421154, 4.383231047540903, 11.522389613091946, 24.546023570001125, 46.78484134376049, 65.78327089548111, 65.0401371717453, 42.776820212602615, 46.35786585509777, 42.35701493918896, 37.938167452812195, 41.12772770226002, 52.79398329555988, 58.00837129354477, 39.32216338813305, 62.34871879220009, 74.32419419288635, 82.03826665878296, 74.00655403733253, 65.03424748778343, 26.967998407781124, 8.753235954791307, 1.8720599147491157, 0.25716928008478135, 0.25206793507095426, 0.11944878729991615, 0.2529897715430707, 0.1114890976168681, 0.13251965545350686, 0.14808238833211362, 0.10504888850846328, 0.11535348283359781, 0.09970106140826829, 0.11572699833777733, 0.12478601653128862, 0.23242258845129982, 0.11121457719127648, 0.12069849719409831, 0.1708642885205336, 0.11567829860723577, 0.19648138579213992, 0.1878561158082448, 0.17804535396862775, 0.13106651545967907, 0.13947381667094305, 0.06544881616719067, 0.179543319682125, 0.12809310079319403, 0.13791947741992772, 0.106603851163527, 0.16761344420956448, 0.15013865689979866, 0.11999244015896693, 0.16031039936933666, 0.16862626798683777, 0.11122363881440833, 0.20630135026294738, 0.11345825289026834, 0.1960208683158271, 0.07287386266398244, 0.10206157341599464, 0.1945083268219605, 0.11602453276282176], [0.016229211178142577, 0.07938526599900797, 0.05529972033400554, 0.07812957439455204, 0.012344041188043775, 0.03320232150144875, 0.02859985557734035, 0.05197071674047038, 0.005036196971559548, 0.026210520409222227, 0.01744100660289405, 0.02146651579096215, 0.0262849337013904, 0.018607067177072167, 0.034758749898173846, 0.03515184325806331, 0.09067571445484646, 0.017325611916021444, 0.04453735447896179, 0.055928401052369736, 0.04500831397308502, 0.05048170132795349, 0.06086416178732179, 0.04205579076369759, 0.056086626937030815, 0.026245694498356897, 0.014078181484364904, 0.03784712323977146, 0.02947892022348242, 0.07928075676318258, 0.08247602905612439, 0.025111414543061983, 0.03125204275420401, 0.01826524137868546, 0.04515991618973203, 0.0813104267581366, 11.341494619846344, 46.47330746054649, 70.6494265794754, 66.66553795337677, 64.80325028300285, 53.64245876669884, 49.75182093679905, 43.73564936220646, 23.757670372724533, 14.69947513192892, 20.262427926063538, 24.690421521663666, 27.02014870941639, 20.34673400223255, 25.678900480270386, 56.21957927942276, 43.6103168874979, 17.687100917100906, 7.268539723008871, 1.9246004079468548, 0.689315014751628, 0.3548404562752694, 0.057090377958957106, 0.08166434214217588, 0.1364948952686973, 0.07000623372732662, 0.06983516868785955, 0.03597841765440535, 0.11677352304104716, 0.162990546959918, 0.5095276620704681, 0.984003214398399, 0.7786171103361994, 0.7137870672158897, 1.4030414633452892, 1.7328333668410778, 1.3624917017295957, 3.912680447101593, 2.6873981952667236, 4.053755002096295, 6.178958639502525, 6.367112193256617, 4.46369600482285, 2.4944053636863828, 0.16986238915706053, 0.11653006891719997, 0.1354280431405641, 0.16588851489359513, 0.5286838591564447, 0.15691600885475054, 0.37586419377475977, 1.3168443948961794, 2.24659311119467, 2.9750534472987056, 4.7933705896139145, 7.715010540559888, 4.468111842870712, 4.789279159158468, 3.5853325249627233, 4.714984595775604, 3.7437075516209006, 2.1707437187433243, 1.4384321705438197, 2.4814984062686563, 1.8161770259030163, 2.7980083599686623, 1.3556791422888637, 1.1350591806694865, 0.29712176125030965, 1.008920674212277, 0.38560746470466256, 0.25116601784247905, 0.2655383903766051, 0.10425588887301274, 0.057041225518332794, 0.04835117717448156, 0.08677056306623854, 0.10874410116230138, 0.07664697113796137, 0.551622990751639, 2.1995768090710044, 6.689109764993191, 15.61451068148017, 33.497953712940216, 49.10911202430725, 61.07303984463215, 49.495479092001915, 75.16149446368217, 48.05887497961521, 40.86312510073185, 43.222334906458855, 27.32330024242401, 33.935895413160324, 41.66251100599766, 55.66811487078667, 60.67390166223049, 64.61627751588821, 46.713465973734856, 28.052101135253906, 7.8251096326857805, 1.690133276861161, 0.40270981262438, 0.05624044446449261, 0.05987930955598131, 0.05751352458901238, 0.039508276095148176, 0.0894097589480225, 0.02811407539411448, 0.015966578102961648, 0.033959668362513185, 0.038791361439507455, 0.0025031300629052566, 0.017873040451377165, 0.05469920411997009, 0.025214862507709768, 0.03155940321448725, 0.05387563542171847, 0.0443020231614355, 0.04874328718869947, 0.09593024617061019, 0.07757853716611862, 0.08723583770915866, 0.01937018423632253, 0.0499859207047848, 0.03129371063550934, 0.05250935639196541, 0.05268254768452607, 0.014667618361272616, 0.02100162520946469, 0.048030075849965215, 0.05523980304133147, 0.016345099393220153, 0.04795829161594156, 0.024787550573819317, 0.06923333887243643, 0.05288887216011062, 0.036542138186632656, 0.03299249779956881, 0.006520912565974868, 0.043846945627592504, 0.012547873902803985, 0.11402698291931301, 0.03757603153644595, 0.049605202657403424, 0.09271624207030982, 0.016724271918064915, 0.017457868198107462, 0.04290832548576873, 0.057206030542147346, 0.02378915229201084, 0.024418239336227998, 0.017640907790337224, 0.06806988138123415, 0.017846534647105727, 0.016581102354393806, 0.03939294634619728, 0.023984925283002667, 0.13001866231206805, 0.07656087458599359, 0.051279562030686066, 0.04197753129119519, 0.03691738660563715, 0.03527095424942672, 0.03625491961429361, 0.029455616786435712, 0.026317929587094113, 0.051843698165612295, 0.03631346393376589, 0.039547405831399374, 0.06830009559052996, 0.023797445792297367, 0.05918013222981244, 0.030948329949751496, 0.0663353264098987, 0.12679192295763642, 0.21469207189511508, 17.499750070273876, 59.484877064824104, 79.314474016428, 74.36296731233597, 73.01792308688164, 63.836810141801834, 59.390987902879715, 56.87837652862072, 38.28679494559765, 22.93219316750765, 32.25205756723881, 23.704790510237217, 23.913741298019886, 25.66822685301304, 29.231728836894035, 43.91858294606209, 36.239081025123596, 20.19047688692808, 6.833118237555027, 2.0093922642990947, 0.5866461270488799, 0.06262282171519473, 0.13358607713598758, 0.09284824787755497, 0.1349827100057155, 0.4117674578446895, 0.42509081948082894, 0.37898531067185104, 0.8282686304301023, 1.3392940652556717, 2.0035994751378894, 2.2277907701209188, 2.787480312399566, 3.7092581251636147, 5.459600714966655, 5.935551775619388, 4.2299653217196465, 7.825157605111599, 7.458737092092633, 6.1347974091768265, 9.66824870556593, 7.780631594359875, 7.927441466599703, 3.945391704328358, 0.9176912507973611, 0.5573059420567006, 0.3989561484195292, 0.4205954528879374, 0.9347156435251236, 0.6357387802563608, 1.0329027310945094, 2.458572811447084, 3.207477950491011, 3.756183232180774, 5.134492535144091, 9.22301234677434, 5.265887109562755, 8.046369384974241, 5.699441470205784, 8.460489213466644, 8.597711250185966, 5.5865158047527075, 5.478647192940116, 3.733050310984254, 4.6773457154631615, 4.689304148778319, 2.927349144592881, 3.6711936676874757, 1.9949471019208431, 1.9757571816444397, 2.5963339442387223, 2.013654448091984, 1.7333059664815664, 0.5636166909243912, 0.3460364474449307, 0.21099945675814524, 0.3926196024985984, 0.18620482238475233, 0.051563953020377085, 0.3665124502731487, 1.730028879828751, 5.729734869673848, 14.468131195753813, 28.60717535018921, 33.79487358033657, 48.61058257520199, 43.00623670220375, 67.14648574590683, 52.078333497047424, 46.78319223225117, 46.594235971570015, 30.911058224737644, 42.95480266213417, 47.748515233397484, 63.10007907450199, 68.58153954148293, 74.29625809192657, 58.69401790201664, 37.079652920365334, 9.607958290725946, 2.4097143206745386, 0.5067136755678803, 0.05637456910335459, 0.02416794446617132, 0.05393035396991763, 0.026474253718333784, 0.04904547116893809, 0.021538890032388736, 0.02092781120154541, 0.0401253978634486, 0.09251779178157449, 0.04079853693838231, 0.01430751995940227, 0.05509324371814728, 0.040846739429980516, 0.018879713679780252, 0.01295066063903505, 0.11133067877381109, 0.055754586355760694, 0.03643376607215032, 0.10427348519442603, 0.07650838248082437, 0.05411742713476997, 0.035946638890891336, 0.03423407004447654, 0.007740898054180434, 0.0424340448807925, 0.08704244144610129, 0.014531033502862556, 0.03696891391882673, 0.007971117829583818, 0.03150628399453126, 0.026153412145504262, 0.004668232732001343, 0.022901356278453022, 0.027408343048591632, 0.05152545410965104, 0.04702583129983395, 0.03486907386104576, 0.03243799103074707, 0.06671641182038002, 0.19434092799201608, 0.10537253168877214, 0.1970195912872441, 0.12816626171115786, 0.12266273202840239, 0.07312549525522627, 0.1644395457697101, 0.09957190544810146, 0.05714272534532938, 0.13214341626735404, 0.09636121132643893, 0.22918902133824304, 0.1349250748171471, 0.12456358002964407, 0.11406568592065014, 0.2009112949599512, 0.09798974308068864, 0.26344737445469946, 0.1709276085603051, 0.16926227370277047, 0.21458557370351627, 0.22236607183003798, 0.10870844838791527, 0.15720078576123342, 0.0808369588048663, 0.1002420722215902, 0.11915071110706776, 0.14989073504693806, 0.08954191318480298, 0.1872236278722994, 0.11125444536446594, 0.14771018642932177, 0.1697148205130361, 0.2827371284365654, 0.5838454992044717, 23.01071595400572, 73.20282876491547, 88.17306786775589, 83.1315515935421, 85.28785228729248, 72.50170558691025, 65.88360071182251, 62.27450117468834, 38.54148767888546, 24.45860356092453, 29.887575544416904, 36.86388909816742, 38.86994205415249, 31.18438135832548, 39.66708227992058, 73.48064705729485, 58.93051341176033, 23.34477122873068, 9.577984549105167, 2.9893497051671147, 1.117201920133084, 0.6931818416342139, 0.25649321323726326, 0.28114344051573426, 0.3019532316830009, 0.27106314548291266, 0.3481692908098921, 0.27426747197750956, 0.6519931205548346, 1.2532333144918084, 1.6814063326455653, 2.397233177907765, 2.2513502184301615, 4.623769065365195, 5.997951552271843, 7.309836382046342, 6.556437034159899, 9.48847085237503, 9.487978778779507, 10.522793401032686, 14.151244349777699, 13.35323017090559, 12.498736772686243, 8.637820947915316, 0.8433270442765206, 0.556566109880805, 0.8216505730524659, 1.3565272092819214, 2.2281764494255185, 0.8541280834469944, 1.8786726286634803, 5.2748308796435595, 6.665055155754089, 8.316711578518152, 12.487941551953554, 18.89349438250065, 10.599339343607426, 13.836678229272366, 11.9657944701612, 9.83766071498394, 12.217115834355354, 7.095072381198406, 8.164619039744139, 7.854585126042366, 6.764031769707799, 10.65514124929905, 5.387571305036545, 5.213590040802956, 3.2928802678361535, 4.237541640177369, 2.842495897784829, 1.2071058084256947, 1.4866748568601906, 0.2552931010723114, 0.22272858128417283, 0.21154416346689686, 0.3239891695557162, 0.29221108881756663, 0.2888868609443307, 0.8265945827588439, 3.3440879825502634, 9.161470849066973, 21.697519719600677, 43.161587566137314, 60.909884199500084, 71.64168253540993, 59.80666659772396, 87.3493404686451, 58.01164671778679, 52.95693755149841, 55.23960046470165, 38.831282928586006, 49.86686356365681, 58.77175413072109, 73.31708863377571, 78.85477468371391, 83.22732165455818, 70.6509616971016, 44.22291621565819, 13.399781472980976, 3.192543564364314, 0.726109865354374, 0.101007129997015, 0.15714646055130288, 0.13769289973424748, 0.05485699584824033, 0.14247213781345636, 0.16964873968390748, 0.13390131178312004, 0.16634508414426818, 0.22307109727989882, 0.12008531994069926, 0.0964505881711375, 0.12435740398359485, 0.14775073737837374, 0.11518108934978954, 0.14617646404076368, 0.11142397415824234, 0.08541930510546081, 0.14889061683788896, 0.17841203429270536, 0.21662965620635077, 0.14178854558849707, 0.07050557294860482, 0.13629881985252723, 0.1518247718922794, 0.173799334152136, 0.13375254085985944, 0.05763341483543627, 0.18379454937530681, 0.08035777631448582, 0.09687635829322971, 0.11114385793916881, 0.1622393896104768, 0.15995979396393523, 0.08648384915431961, 0.11480940695037134, 0.127335486758966, 0.13635323412017897, 0.15101068041985855], [0.039123435417423025, 0.04447555213118903, 0.0527056247665314, 0.048134859680430964, 0.08050436532357708, 0.07494505582144484, 0.08919343032175675, 0.04115196621569339, 0.03583599209378008, 0.03462446198682301, 0.09260497929062694, 0.017779973277356476, 0.011044366201531375, 0.034111745553673245, 0.044428711480577476, 0.056937083645607345, 0.07903874240582809, 0.09282377926865593, 0.015937105563352816, 0.03583480094675906, 0.1517906627850607, 0.01455284151234082, 0.006487963064500946, 0.03609999628679361, 0.038603605498792604, 0.04189863728242926, 0.03949778954847716, 0.11955636160564609, 0.06379225349519402, 0.07073695975122973, 0.09786104725208133, 0.056797778815962374, 0.03753216689801775, 0.1233528477314394, 0.5968473327811807, 15.846396088600159, 55.38981780409813, 76.17429211735725, 58.46795283257961, 55.261160507798195, 54.60542969405651, 56.82103380560875, 38.61865773797035, 21.27723377197981, 24.78912692517042, 25.244238004088402, 22.344372309744358, 26.501242853701115, 20.755457170307636, 28.87095719575882, 43.85775960981846, 30.36269634962082, 9.125865809619427, 2.3904809402301908, 0.5254456610418856, 0.12213657159009017, 0.13630425237352028, 0.09822987980442122, 0.047469323908444494, 0.04967212211340666, 0.23761561838909984, 0.32166212098672986, 0.6265266495756805, 0.7220771536231041, 1.1391563108190894, 1.860093050636351, 1.9323322805576026, 2.803711616434157, 2.545676724985242, 1.8226815643720329, 3.900672853924334, 2.3113169381394982, 4.75951393134892, 2.95237697660923, 5.180083913728595, 3.765090429224074, 8.247324451804161, 9.0197897516191, 3.8908689050003886, 3.9072909113019705, 1.3039247319102287, 0.8191794587764889, 0.18921115872217342, 1.019926427397877, 0.12598066648934036, 0.17327846522675827, 1.2063394370488822, 3.3985497476533055, 3.1647986406460404, 1.653277629520744, 6.429539518430829, 8.242745697498322, 4.964455934241414, 3.952410165220499, 2.5218182802200317, 5.646848017349839, 7.7450773771852255, 6.834834320470691, 4.155002944171429, 3.771613729186356, 3.317978158593178, 0.5573802161961794, 4.165393486618996, 1.116395650897175, 2.0564206782728434, 2.023813440464437, 3.0669588781893253, 1.638929124455899, 1.7945548798888922, 1.5348885697312653, 0.8769777417182922, 0.1765547355171293, 0.040638210775796324, 0.0182875855898601, 0.09210514283040538, 0.07018952193902805, 0.13854016520781443, 1.1746630305424333, 4.003860354423523, 11.965019311755896, 32.59913094341755, 44.20305848121643, 53.36496725678444, 63.01958419382572, 50.95265530049801, 40.2309188246727, 60.52280656993389, 25.630080699920654, 22.898935452103615, 30.769645012915134, 38.770835772156715, 47.36542358994484, 53.33584561944008, 65.814558416605, 54.588927179574966, 39.90320920944214, 10.009952019900084, 2.522637373767793, 0.2749575802590698, 0.027972043171757832, 0.052547677187249064, 0.02196929486672161, 0.023254299449035898, 0.023107667766453233, 0.052501337486319244, 0.08235868066549301, 0.048603781979181804, 0.03291570406872779, 0.025201412936439738, 0.004424739645401132, 0.040704588463995606, 0.0547987298341468, 0.05829138812259771, 0.036083624509046786, 0.06157008152513299, 0.03941703645978123, 0.06605740694794804, 0.046210181317292154, 0.12198263531900011, 0.013397610728134168, 0.018175035183958244, 0.02037819147517439, 0.04223321229801513, 0.054737183527322486, 0.04438608622876927, 0.045592465830850415, 0.01848726227763109, 0.025595680745027494, 0.017324995933449827, 0.04661860744818114, 0.05777485705038998, 0.008173581281880615, 0.05112344755616505, 0.0205361891494249, 0.04353761105448939, 0.02591011016193079, 0.01491338798587094, 0.056911101055447944, 0.06495348454336636, 0.08194352325517684, 0.013872658528271131, 0.043298335222061723, 0.024129267440002877, 0.008148281467583729, 0.052790608096984215, 0.0726445835607592, 0.03741196123883128, 0.09144074996584095, 0.05255561074591242, 0.028517532846308313, 0.02055467604805017, 0.009111419385590125, 0.02351515693590045, 0.0519276870181784, 0.02312175744009437, 0.03595845388190355, 0.0923822088225279, 0.04889223251666408, 0.03786232242418919, 0.018949497825815342, 0.03159986139507964, 0.06006300223816652, 0.009811848158278735, 0.060122314680484124, 0.04128788685193285, 0.048642355104675516, 0.04246894066454843, 0.049853859236463904, 0.062349451618501917, 0.18737035046797246, 1.4730236143805087, 22.14273802936077, 65.53101763129234, 82.56693229079247, 68.46529617905617, 65.41850566864014, 66.6971218585968, 64.50785413384438, 52.54649877548218, 36.69880695641041, 36.05722278356552, 26.46756336092949, 24.85807802528143, 28.501398526132107, 25.578165985643864, 35.629255548119545, 33.297069892287254, 27.140110172331333, 9.220311641693115, 1.7347521451301873, 0.24049388972343877, 0.074514157458907, 0.02480163468135288, 0.10027008829638362, 0.11820118510513566, 0.15142457617912441, 0.24497094011167064, 1.182677869219333, 1.5785267343744636, 2.5081264274194837, 2.811607592739165, 3.800096050836146, 5.075559597462416, 6.73582493327558, 5.20538485608995, 8.71277667582035, 5.885317521169782, 6.288082608953118, 7.895466182380915, 10.560736265033484, 8.15051894634962, 7.370679192245007, 9.22353956848383, 11.403805576264858, 7.492272667586803, 3.3219394460320473, 3.783281953074038, 0.9703161113429815, 0.3109366918215528, 0.8521261846181005, 0.12776753545040265, 0.3536309930495918, 0.5512428330257535, 2.941256398335099, 3.265824532136321, 4.558657659217715, 5.505297537893057, 7.22429109737277, 5.799252614378929, 6.928821802139282, 8.113487083464861, 6.721500176936388, 8.13606832176447, 8.246345054358244, 6.79434796795249, 5.965448571369052, 4.598434399813414, 3.55644837487489, 2.831391468644142, 5.0700147449970245, 4.520919509232044, 5.797794917598367, 4.972680117934942, 5.5088375229388475, 4.325353978201747, 3.108337945304811, 2.7110167779028416, 0.8380063797812909, 0.3521626687142998, 0.5062479036860168, 0.20749812276335433, 0.07809240763890557, 0.09274783529690467, 0.6093520461581647, 3.161980379372835, 10.15446301549673, 29.047087244689465, 45.37785664200783, 58.548493310809135, 70.4761254787445, 52.84023821353912, 39.86574701964855, 58.568362444639206, 25.46221900731325, 33.207356706261635, 38.39213669300079, 47.17456743121147, 55.517669543623924, 64.00589346885681, 74.91717517375946, 64.39123079180717, 51.54326520860195, 15.98380621522665, 2.8574091475456953, 0.39933669206220657, 0.051117399052600376, 0.07188528485130519, 0.024217442005465273, 0.0017863350785773946, 0.037430485244840384, 0.06477948802057654, 0.03507911278575193, 0.0694230169756338, 0.0272877533279825, 0.03245945023081731, 0.03610673869843595, 0.018713775025389623, 0.019669703906401992, 0.03888105369696859, 0.06116609714808874, 0.0058106118376599625, 0.023935268181958236, 0.026023536302091088, 0.07077586313243955, 0.03253244787629228, 0.09004338236991316, 0.08314948354382068, 0.046378429906326346, 0.014101751166890608, 0.046326787560246885, 0.03332693922857288, 0.039125546827563085, 0.010117321708094096, 0.018562879704404622, 0.013600207767012762, 0.035017399495700374, 0.024858468350430485, 0.05209853683481924, 0.0622334390936885, 0.07103735144482926, 0.07457649044226855, 0.028340280150587205, 0.22992345067905262, 0.16157156060216948, 0.1527989297755994, 0.18011318519711494, 0.1433470705524087, 0.153054065303877, 0.13284508720971644, 0.12193761664093472, 0.09514434888842516, 0.19258007872849703, 0.13609466986963525, 0.13939774653408676, 0.13233334670076147, 0.13200300192693248, 0.1644226990174502, 0.19825209077680483, 0.17665427236352116, 0.17235609440831468, 0.09374566026963294, 0.17654931783908978, 0.2283598345820792, 0.14238370349630713, 0.09623390331398696, 0.1902721478836611, 0.3000866709044203, 0.18359356094151735, 0.13115285692038015, 0.17422323406208307, 0.09236640107701533, 0.1875217040651478, 0.1875025121262297, 0.14441061270190403, 0.17094056645873934, 0.22327693935949355, 1.7669830843806267, 29.304160550236702, 78.74287068843842, 92.98019751906395, 77.9072043299675, 76.63046523928642, 73.22339326143265, 71.4989621937275, 53.0620551109314, 33.13518337905407, 36.77222661674023, 35.213307067751884, 28.941825293004513, 38.9896584302187, 30.478468537330627, 43.65017294883728, 59.595865309238434, 39.75267268717289, 12.10600409656763, 3.2790775084868073, 0.7367417542263865, 0.43290881090797484, 0.25431388174183667, 0.23918992141261697, 0.2428079061792232, 0.11924794729566202, 0.3584781673271209, 0.6288081302773207, 1.0746651026420295, 3.417177298106253, 4.382079234346747, 5.880774389952421, 7.5623375829309225, 10.31219445168972, 8.57970591634512, 12.512143403291702, 12.571240682154894, 11.329355221241713, 15.207535419613123, 14.376885741949081, 15.918872449547052, 14.794144202023745, 20.54298587143421, 25.54284308105707, 15.703683346509933, 14.210501220077276, 12.3597383312881, 5.76499555259943, 2.861062651500106, 2.515008570626378, 0.26618117932230234, 0.7572019938379526, 0.9135531540960073, 3.9522007014602423, 5.954759269952774, 10.053564179688692, 16.93720355629921, 19.364099130034447, 15.053096506744623, 14.62968047708273, 13.507525641471148, 16.52758363634348, 19.178615882992744, 15.555087570101023, 13.151241559535265, 11.088539343327284, 8.214274775236845, 4.309890707954764, 14.057459682226181, 8.558467905968428, 9.744432717561722, 7.787740062922239, 8.04387766867876, 6.342238252982497, 5.554905300959945, 3.729192093014717, 3.1190977804362774, 0.6792170566041023, 0.16600176662905142, 0.236930645769462, 0.24188172072172165, 0.3041303367353976, 0.38399792450945824, 2.0927540911361575, 5.982490181922913, 16.747396141290665, 40.12073993682861, 51.51225887238979, 60.86133800446987, 71.35302722454071, 60.98471738398075, 55.39420276880264, 72.31125980615616, 37.4382358789444, 37.58509799838066, 44.82952706515789, 57.521647810935974, 64.9576435983181, 73.50288346409798, 84.59565863013268, 75.05240231752396, 62.9057727009058, 21.626560427248478, 4.362491760402918, 0.5435677198693156, 0.22854390204884112, 0.14119110186584294, 0.13515058381017298, 0.10103414417244494, 0.12100161999114789, 0.13719947542995214, 0.1414589726482518, 0.2035061697824858, 0.12024713039863855, 0.09057073766598478, 0.15050036483444273, 0.1322948292363435, 0.13202548900153488, 0.1072259564534761, 0.16542406403459609, 0.20607333281077445, 0.1739394516334869, 0.13376573624555022, 0.13031602604314685, 0.19980507931904867, 0.25711281748954207, 0.0724748543871101, 0.08591255129431374, 0.12808039522496983, 0.10775274771731347, 0.19515044783474877, 0.2909839921630919, 0.12845468998420984, 0.09020905941724777, 0.09647752813179977, 0.19703314290381968, 0.09029436187120155, 0.1086364006914664, 0.17148404120234773, 0.104145924851764, 0.13879883335903287, 0.13994217122672126], [0.03738053499546368, 0.030028328437765595, 0.06104271138610784, 0.03114606035524048, 0.03692422549647745, 0.017317422316409647, 0.020563999278238043, 0.031181449667201377, 0.05946530989604071, 0.045317815529415384, 0.02294327277923003, 0.05399812318501063, 0.01993013094761409, 0.06253593106521294, 0.13796844432363287, 0.04040242674818728, 0.07952552448841743, 0.029995115473866463, 0.015579672399326228, 0.05608007748378441, 0.025305011185992043, 0.044220112322364, 0.11040925048291683, 0.11701649476890452, 0.03156236438371707, 0.013147682293492835, 0.11376919792382978, 0.18459792423527688, 0.13034447998506948, 0.07631042943103239, 0.03578846124582924, 0.014440775357797975, 0.0249521719160839, 0.3327031113440171, 11.625122800469398, 60.2767089754343, 73.05329918861389, 59.99657280743122, 53.192087933421135, 41.69551223516464, 41.292806044220924, 44.2425611615181, 22.841849215328693, 16.77146974951029, 24.957469291985035, 37.345167472958565, 52.64459051191807, 35.774099975824356, 35.11869974434376, 37.863349467515945, 18.924635611474514, 6.128567643463612, 1.173792164772749, 0.49167871358804405, 0.10714621268562041, 0.08827945319353603, 0.00590741294217878, 0.023011125485936645, 0.14289277227362618, 0.24276879499666393, 0.2867425588192418, 2.439943836070597, 1.747201702091843, 2.1802966436371207, 2.1411091089248657, 1.8409141735173762, 4.4397924374789, 3.9369801431894302, 4.711522506549954, 5.2981331292539835, 5.689957179129124, 7.919507492333651, 3.1597316125407815, 9.145255219191313, 6.342743625864387, 3.248213427141309, 8.926550354808569, 8.638123031705618, 6.701095746830106, 2.465575123205781, 1.7673736321739852, 0.11180454006535001, 0.18130884447600693, 0.7631316944025457, 0.48081696673762053, 3.0500151123851538, 12.8907579369843, 14.88175230100751, 13.450680691748857, 12.865140661597252, 5.027343984693289, 4.971970031037927, 3.218383602797985, 4.621682977303863, 4.477677354589105, 7.387838596478105, 6.253153933212161, 4.40494260750711, 5.295011596754193, 2.6262713503092527, 3.755479557439685, 1.9785915920510888, 2.027307590469718, 4.191754097118974, 1.3764983438886702, 0.4763258749153465, 2.6114274468272924, 5.707459039986134, 4.571671485900879, 3.3371725911274552, 2.2191184479743242, 1.1023879400454462, 0.6268208962865174, 0.20953190425643697, 0.2242077558184974, 0.12496586859924719, 0.12120104249333963, 0.16371225588954985, 0.033232382193091325, 0.43388847552705556, 2.6719743479043245, 9.488837532699108, 19.934611916542053, 25.43325886130333, 35.22908382117748, 23.706557415425777, 40.68038530647755, 40.60756601393223, 17.200671918690205, 20.888174548745155, 31.56908791512251, 45.002562180161476, 57.28724978864193, 55.40459901094437, 61.776948273181915, 58.11869457364082, 43.54500599205494, 21.817606575787067, 2.1302984515205026, 0.7198537385556847, 0.06833282430307008, 0.03220408834749833, 0.03798257632297464, 0.032895740296225995, 0.06106880900915712, 0.09370893880259246, 0.016587948666710872, 0.10860046590096317, 0.14343421353260055, 0.15399831463582814, 0.08801084768492728, 0.04763391370943282, 0.05192949785850942, 0.03169006944517605, 0.017774325533537194, 0.030613708549935836, 0.01644106650928734, 0.008102772972051753, 0.10742190570454113, 0.05461987224407494, 0.011788828451244626, 0.034341388309258036, 0.01029381834086962, 0.004273764079698594, 0.08843818373861723, 0.042587769639794715, 0.05665016935381573, 0.029741733269474935, 0.04245296964654699, 0.03897187772963662, 0.024672653125890065, 0.05076901266875211, 0.04695410272688605, 0.038570591059396975, 0.030851602132315747, 0.06549552694195881, 0.05537760502193123, 0.017501354341220576, 0.08040919972700067, 0.03758726023079362, 0.017804436320147943, 0.018790546491800342, 0.05976073291094508, 0.06653203265159391, 0.013094998157612281, 0.07139540801290423, 0.12461790523957461, 0.04358160185802262, 0.0601237581577152, 0.05064613156719133, 0.014595524280593963, 0.05274939663650002, 0.08240910217864439, 0.016024517572077457, 0.04195271016214974, 0.004228503739795997, 0.0564894312992692, 0.03417639403778594, 0.09034273505676538, 0.02195259468862787, 0.026653933236957528, 0.03694914310472086, 0.17513396800495684, 0.06659691862296313, 0.1139480184065178, 0.01006208829494426, 0.02276852297654841, 0.0195182315655984, 0.06269496589084156, 0.5588516872376204, 21.43357828259468, 72.35793650150299, 79.39056873321533, 68.66543143987656, 61.44471690058708, 55.04429094493389, 48.991113156080246, 53.916203677654266, 31.797964833676815, 23.705962747335434, 30.373075492680073, 37.831089198589325, 34.291218146681786, 36.55180424451828, 35.29390074312687, 36.905717253685, 19.01240710169077, 5.85656113922596, 0.6098761805333197, 0.18636695196619257, 0.05253876399365254, 0.11335228904499672, 0.1698023939388804, 0.18010016792686656, 0.5600935081019998, 0.8989253046456724, 2.0607374841347337, 3.90995433088392, 3.913872870616615, 5.90505413711071, 5.661024106666446, 5.463878335431218, 5.1003048196434975, 6.728311311453581, 9.263332933187485, 11.33982365950942, 10.048040226101875, 7.848923904821277, 9.092980474233627, 11.035591084510088, 9.20053655281663, 8.211582619696856, 9.079499747604132, 9.003590270876884, 5.448728548362851, 4.115362046286464, 3.0645255837589502, 1.4465449727140367, 0.7648219505790621, 0.49402885779272765, 1.0518126538954675, 2.81574628315866, 13.100734669715166, 16.48207727819681, 14.669942166656256, 10.720717180520296, 4.446837259456515, 2.899740538559854, 2.800957001745701, 3.94303725566715, 3.999534286558628, 6.132618226110935, 6.72025004401803, 6.129928920418024, 5.439229058101773, 6.282784268260002, 5.059960959479213, 3.3515455573797226, 7.3937776777893305, 8.439567536115646, 6.737554790452123, 6.403819648548961, 7.797296550124884, 4.757963139563799, 7.087066685780883, 5.058676628395915, 5.6048284471035, 3.5076141078025103, 3.903071475215256, 1.8743095127865672, 1.1175110097974539, 0.4186593083431944, 0.23329329094849527, 0.04104305975488387, 0.03198843878635671, 0.3799320833059028, 2.740542618557811, 11.424881145358086, 24.131832495331764, 31.314923353493214, 35.299539640545845, 31.812191270291805, 50.03512233495712, 36.71790853142738, 26.65710099041462, 32.294090911746025, 41.50908283889294, 53.812203258275986, 64.84180301427841, 62.504715621471405, 69.85827103257179, 65.5498494207859, 55.909804701805115, 34.25277180969715, 5.802317149937153, 0.7403272180818021, 0.05626342506729998, 0.047580156242474914, 0.07689413600019179, 0.012378069586702622, 0.07712126287515275, 0.010440572477818932, 0.030885353153280448, 0.11668646169709973, 0.048535916284890845, 0.05204641209274996, 0.052377628890099004, 0.00749185277527431, 0.03871398512274027, 0.04726096223748755, 0.04030457086628303, 0.03339756942295935, 0.04935953693347983, 0.06070174647902604, 0.04106841894099489, 0.024914778805396054, 0.0328225051634945, 0.016047316348704044, 0.024498118546034675, 0.03834121918771416, 0.01681076922977809, 0.07632962136995047, 0.01934299751155777, 0.03345212469866965, 0.03404009861696977, 0.10087720220326446, 0.05956866509222891, 0.006743183939761366, 0.02171355634345673, 0.06668064772384241, 0.038122281912365, 0.056752930831862614, 0.13776125153526664, 0.09129578626016155, 0.19105088344076648, 0.11934994807234034, 0.10015334104537033, 0.07623660800163634, 0.14068011834751815, 0.14213199669029564, 0.15657105861464515, 0.21911304560489953, 0.25556190696079284, 0.11392982836696319, 0.11125011864351109, 0.11090542815509252, 0.15155642613535747, 0.1659961263067089, 0.13472867285599932, 0.12757528951624408, 0.16036401211749762, 0.11936652765143663, 0.14734656375367194, 0.12766523781465366, 0.13285840133903548, 0.32306964858435094, 0.09471473444136791, 0.12420182014466263, 0.26679137314204127, 0.26814113196451217, 0.24109320365823805, 0.12268184975255281, 0.20618020207621157, 0.11802302513387986, 0.12689974217209965, 0.7513929961714894, 31.780702359974384, 88.37547540664673, 88.97247657179832, 79.9696196615696, 70.78607484698296, 57.62773431837559, 56.857405453920364, 59.79231856763363, 33.54780323803425, 24.51268795877695, 36.12077817320824, 53.5339517891407, 68.70583087205887, 48.69784489274025, 49.2086286842823, 50.774596855044365, 27.154946476221085, 8.874228112399578, 2.073599793948233, 0.9215524373576045, 0.3474614006699994, 0.12533186614746228, 0.25693087256513536, 0.22120986512163654, 0.4902341676643118, 0.7179999724030495, 1.6940376861020923, 8.083483893424273, 7.284779576584697, 7.603954374790192, 6.9358390755951405, 8.918033111840487, 12.8161745890975, 14.417650904506445, 16.726181879639626, 15.167287979274988, 18.17315563559532, 15.652106814086437, 13.488294873386621, 23.466216512024403, 17.137114629149437, 14.856917783617973, 16.358872689306736, 16.71661589294672, 15.555901676416397, 10.051661431789398, 6.566647086292505, 3.549941461533308, 1.9265998131595552, 1.246448066085577, 3.346318700350821, 2.3453690484166145, 7.5525374338030815, 9.17476823553443, 8.078894689679146, 12.57742865011096, 10.382622722536325, 14.905066899955273, 12.74082938209176, 14.141950998455286, 14.605079647153616, 20.21178614348173, 18.59433453530073, 11.798933073878288, 14.175228662788868, 8.17539906129241, 12.113180011510849, 6.315978337079287, 7.304276330396533, 12.099245209246874, 8.964181635528803, 5.8096027839928865, 10.953135509043932, 15.06160045042634, 9.811935145407915, 10.321414656937122, 5.741332322359085, 4.403717173263431, 2.858278350904584, 1.3668194320052862, 0.7224826631136239, 0.28595864307135344, 0.28517742874100804, 0.16935324616497383, 0.18280203075846657, 1.043061485979706, 3.83124559186399, 14.445840641856194, 28.77706803381443, 39.02422897517681, 48.80810737609863, 39.72947873175144, 54.27837364375591, 54.00062374770641, 30.475215911865234, 33.50278325378895, 44.959058314561844, 63.00499677658081, 73.45334932208061, 73.80849346518517, 79.93830934166908, 74.98022899031639, 67.92792901396751, 39.35941278934479, 7.192560425028205, 0.8643829019274563, 0.2410845205304213, 0.14346530952025205, 0.11049558452214114, 0.14223316626157612, 0.2217221399769187, 0.19541223300620914, 0.15475460764719173, 0.1797394989989698, 0.147758737730328, 0.19954736111685634, 0.17415311594959348, 0.17061077087419108, 0.2656617353204638, 0.11731347258319147, 0.07684270516620018, 0.13816478691296652, 0.1911223671049811, 0.11748083430575207, 0.207041657413356, 0.12953683035448194, 0.14408627932425588, 0.09146745986072347, 0.07855731862946413, 0.12939607462612912, 0.11410100472858176, 0.10913171005086042, 0.12739347817841917, 0.09686135206720792, 0.12838972237659618, 0.18870318832341582, 0.14662132220109925, 0.1135067522409372, 0.09734641236718744, 0.12161292703240179, 0.08855687541654333, 0.12566945428261533], [0.0395519589073956, 0.033084620590670966, 0.02074523174087517, 0.053791190148331225, 0.010706154662329936, 0.07169803357101046, 0.06286419782554731, 0.02882867269363487, 0.04346434252511244, 0.027027129617636092, 0.015166619905357948, 0.02690862718736753, 0.03666574659291655, 0.02005475980695337, 0.054434465200756676, 0.03490889379463624, 0.03034457240573829, 0.06666083980235271, 0.06493827793747187, 0.05764281042502262, 0.048618149958201684, 0.09015540214022622, 0.12836505338782445, 0.1320483471499756, 0.13406819110969082, 0.10765405691927299, 0.2528828429058194, 0.2590610145125538, 0.32244306814391166, 0.20447915507247671, 0.11728337849490345, 0.1731611168361269, 0.8433814882300794, 18.764648996293545, 38.85071888566017, 65.48232704401016, 66.9777823984623, 51.60197205841541, 44.09837409853935, 49.27272364497185, 98.5769172012806, 52.77862831950188, 26.315090842545033, 30.347438268363476, 40.30473746359348, 47.24532723426819, 43.46903286874294, 41.92072235047817, 26.47975690662861, 16.86321772634983, 2.6899908436462283, 0.2276520334999077, 0.04292333542252891, 0.05113301383971702, 0.11682243799441494, 0.1503239118028432, 0.28474027407355607, 0.2325578374438919, 1.0172045859508216, 2.017741841264069, 2.632142985239625, 3.3082656422629952, 5.1464148703962564, 3.804845795966685, 3.9015382574871182, 3.4454192826524377, 3.026932538487017, 3.734699422493577, 6.144370520487428, 9.730687905102968, 4.1403894033282995, 4.189033918082714, 6.779074212536216, 7.2469602059572935, 5.422654347494245, 3.977853124961257, 5.584311923012137, 7.5620991457253695, 4.819213952869177, 0.8680338528938591, 1.3107902510091662, 0.5813969462178648, 0.19579901068937033, 0.9010666678659618, 7.872166307643056, 28.17799787968397, 50.20322531461716, 44.99445341527462, 49.08576987683773, 43.3101861923933, 21.030285023152828, 5.896031521260738, 3.164208484813571, 6.1833227053284645, 8.056511040776968, 3.3097240515053272, 2.0844398997724056, 5.657415250316262, 2.6767020067200065, 5.195426065474749, 3.963540242984891, 3.646726543083787, 2.327765543013811, 3.8566420041024685, 3.287496194243431, 8.858879785984755, 4.6540268417447805, 5.751316761597991, 4.279180755838752, 4.043192993849516, 7.131573222577572, 2.270704717375338, 2.732834257185459, 1.9295076071284711, 0.5441239743959159, 0.5103991215582937, 0.3102612780639902, 0.1620528136845678, 0.0364666803216096, 0.18968840420711786, 0.3980858763679862, 1.694541396573186, 11.791872102767229, 24.897219724953175, 43.944486156105995, 39.513866901397705, 26.714430414140224, 44.171368181705475, 25.428862497210503, 20.633894093334675, 20.990493558347225, 25.88228076696396, 33.0040068179369, 41.90035544335842, 50.623064786195755, 54.31159146130085, 66.01038470864296, 61.709581688046455, 32.380992248654366, 9.490212108939886, 0.5045399547088891, 0.16879846109077334, 0.20833532471442595, 0.07651306543266401, 0.034267837763763964, 0.1652631812612526, 0.20774079021066427, 0.5571428476832807, 0.37940486159641296, 0.16027496923925355, 0.29702940839342773, 0.1393420112435706, 0.02502973933587782, 0.030437005043495446, 0.02220709568064194, 0.03962074115406722, 0.09845173000940122, 0.11788187606725842, 0.176942641264759, 0.2310827447217889, 0.06446765240980312, 0.005656413495671586, 0.05237291996309068, 0.11827001930214465, 0.03256829360907432, 0.08621960005257279, 0.04671074137149844, 0.039135369152063504, 0.01955153544258792, 0.06484686760813929, 0.02873616398574086, 0.08156194802722894, 0.02477735346474219, 0.03244286323024426, 0.05611677668639459, 0.03504642860207241, 0.01866465598141076, 0.04167658669757657, 0.017674588307272643, 0.03023752688022796, 0.06314878919511102, 0.05750744268880226, 0.024587270891061053, 0.027698925405275077, 0.04797383589902893, 0.03286067752924282, 0.06623020119150169, 0.04174215173406992, 0.034332812792854384, 0.025217474867531564, 0.10558966183452867, 0.08274302410427481, 0.06678647056105547, 0.027167805565113667, 0.024050957872532308, 0.05753167009970639, 0.07120436435798183, 0.037135180973564275, 0.12402904074406251, 0.05505894536327105, 0.16411427728598937, 0.16859339084476233, 0.15870672214077786, 0.07021191995590925, 0.2464813887490891, 0.04962033504853025, 0.022265658553806134, 0.032576887679169886, 1.219043699093163, 23.879155553877354, 49.5831023901701, 74.68378409743309, 72.27067798376083, 58.710478618741035, 52.433166056871414, 60.07451422512531, 99.10385772585869, 57.72946625947952, 31.351488791406155, 26.269398294389248, 32.361696884036064, 39.03272531926632, 39.95940059423447, 37.82571628689766, 29.562197104096413, 15.619591008871794, 2.6673647202551365, 0.24940828559920192, 0.07880307341110893, 0.013097088231006637, 0.19318954524351284, 0.4758954589487985, 0.6417906086426228, 1.1917086783796549, 2.1210350235924125, 4.632253060117364, 5.382574573159218, 6.575969411060214, 7.076306138187647, 6.133199594914913, 5.475198403000832, 6.03790545836091, 6.471117837354541, 8.457392379641533, 8.952483963221312, 15.186799932271242, 9.345555771142244, 8.697292506694794, 10.452498123049736, 8.446731101721525, 5.292508956044912, 3.9735519932582974, 4.105795109644532, 4.723577834665775, 4.541830737143755, 1.9363404717296362, 1.1260017729364336, 0.5695221084170043, 0.4477325873449445, 1.7116263485513628, 9.308682549744844, 32.32576221227646, 56.35929398238659, 54.052171781659126, 53.58004331588745, 44.56343114376068, 18.156717717647552, 6.235826862975955, 3.182239942252636, 6.770673338323832, 8.310232926160097, 5.660042334347963, 2.942536692135036, 2.889414830133319, 4.282915480434895, 5.481606284156442, 5.177730889990926, 7.729307748377323, 4.730052687227726, 5.853417757898569, 5.205076122656465, 9.500831589102745, 8.003293946385384, 5.795250479131937, 9.49211010709405, 5.10741138830781, 6.660917177796364, 8.32685798406601, 4.9846414010971785, 5.776040134951472, 2.2260393016040325, 1.0045588645152748, 0.6560885289218277, 0.37991819030139595, 0.07000474201049656, 0.17594281991478056, 0.3852636128431186, 1.34262292413041, 8.329741079360247, 22.681108340620995, 37.95237109065056, 39.19796325266361, 35.84121957421303, 44.69879887998104, 19.98190987855196, 25.65874256193638, 29.655267409980297, 33.39317053556442, 39.3902101367712, 48.048965111374855, 56.53157293796539, 63.86387228965759, 73.33438530564308, 76.812923848629, 50.107086673378944, 17.576374858617783, 2.101609278470278, 0.09792214084882289, 0.08393568510655314, 0.06435225586756133, 0.0636269772076048, 0.06016069484758191, 0.11901805963134393, 0.3169104165863246, 0.2591479051625356, 0.13782562542473897, 0.15918424964183941, 0.06215856010385323, 0.03940906208299566, 0.05080944116343744, 0.03713168916874565, 0.050341888127150014, 0.04141562902077567, 0.045935864982311614, 0.06883346228278242, 0.09725025971420109, 0.101110221730778, 0.018765877503028605, 0.050717066042125225, 0.017556022794451565, 0.041274175673606806, 0.07542705105151981, 0.04677074401115533, 0.025673773234302644, 0.043897645446122624, 0.14178848621668294, 0.09807328664464876, 0.0008451852568214235, 0.032364440485253, 0.038745585770811886, 0.07149703029426746, 0.08392290532356128, 0.17104531318182126, 0.11546355075552128, 0.2326682096463628, 0.2481689435080625, 0.12044615956256166, 0.13809411961119622, 0.12619510263903067, 0.13040575169725344, 0.13461007765727118, 0.12490401801187545, 0.12016284468700178, 0.13523411995265633, 0.09551912604365498, 0.122267983679194, 0.266899429843761, 0.1410489805857651, 0.13897770579205826, 0.1791137200780213, 0.20119458757108077, 0.23905306938104331, 0.15678279334679246, 0.1383572703343816, 0.29370060889050364, 0.20841900928644463, 0.28328581305686384, 0.29920131841208786, 0.3469977364875376, 0.2946002106182277, 0.3109586000209674, 0.25397347344551235, 0.25641398155130446, 0.26041813543997705, 1.6845671692863107, 31.308718286454678, 65.42603686451912, 83.78024518489838, 84.79224488139153, 68.68931695818901, 60.22962190210819, 65.73820531368256, 104.8365493118763, 61.91633619368076, 36.792452931404114, 43.557222336530685, 54.59832787513733, 64.4721132516861, 62.111432924866676, 53.488943204283714, 38.222487196326256, 23.128790818154812, 3.9740481041371822, 0.51062639686279, 0.15524984279181808, 0.14401132240891457, 0.23458428651792929, 0.7846410339698195, 0.4801928799133748, 1.2761122430674732, 2.860724707134068, 5.497821914032102, 7.343333484604955, 12.270853500813246, 11.756819933652878, 12.075146902352571, 13.15814008936286, 13.023257777094841, 13.240932896733284, 14.634452071040869, 19.598335660994053, 18.00602350383997, 14.61689131334424, 15.047025382518768, 21.678370647132397, 18.447949290275574, 14.640137515962124, 11.872607320547104, 14.77662619203329, 17.19678472727537, 13.228485714644194, 3.661400405690074, 2.019175076857209, 1.286882171407342, 0.7607225049287081, 1.8397976271808147, 10.58978095650673, 27.668891698122025, 42.10463248193264, 39.11068953573704, 40.983586236834526, 37.868186607956886, 22.524583339691162, 14.16584886610508, 9.8566853441298, 17.724426314234734, 19.14223663508892, 14.62451845407486, 14.393050074577332, 15.03198578953743, 11.185378096997738, 13.725940771400928, 10.668586827814579, 11.21387941762805, 6.6374629363417625, 8.885016683489084, 10.435879714787006, 14.607835449278355, 13.165812827646732, 12.7595148794353, 12.443515285849571, 12.599069438874722, 15.529887322336435, 8.57874171808362, 8.558414708822966, 5.548307904973626, 2.293344377540052, 0.6571642868220806, 0.4822137183509767, 0.382056703674607, 0.3192116384161636, 0.4987676488235593, 0.9515393595211208, 3.33753808401525, 15.83543747663498, 34.51480194926262, 58.26011538505554, 53.268577829003334, 40.83793245255947, 54.608784914016724, 36.98240473866463, 32.982515171170235, 30.496696159243584, 39.909319281578064, 48.78712110221386, 58.55533294379711, 68.28645497560501, 74.84820887446404, 83.30885767936707, 89.20410454273224, 61.194853708148, 21.43204316496849, 2.1443030750378966, 0.2887843851931393, 0.36765675293281674, 0.19500967726344243, 0.22695245541399345, 0.1533640010165982, 0.2315229273517616, 0.5090788705274463, 0.5603414447978139, 0.2911209629382938, 0.3726741758873686, 0.26964493095874786, 0.22047012200346217, 0.15928007574984804, 0.13162386836484075, 0.17222185473656282, 0.214461516297888, 0.14969026611652225, 0.3916085005039349, 0.24860833946149796, 0.2053986315149814, 0.07002230864600278, 0.1390815174090676, 0.20082510192878544, 0.15516099287196994, 0.21949894755380228, 0.2116770375869237, 0.20375627354951575, 0.11960377742070705, 0.2497475955169648, 0.17023494729073718, 0.1218874474579934, 0.13069524866295978, 0.1293352185166441, 0.1536119673983194, 0.21972239337628707], [0.0731144001474604, 0.06349674513330683, 0.05159865955647547, 0.06682814215309918, 0.021453370500239544, 0.0352910998481093, 0.0625212884915527, 0.025217920156137552, 0.048089243573485874, 0.016940748973865993, 0.03715219099831302, 0.040607055416330695, 0.040318256069440395, 0.11091790365753695, 0.09125962140387855, 0.03291691748017911, 0.05562741935136728, 0.019323816704854835, 0.07147607204387896, 0.12193618429591879, 0.06195618014317006, 0.15673293586587533, 0.11596761745749973, 0.11427668592659757, 0.12164232350187376, 0.18151902069803327, 0.27107585105113685, 0.38694810995366424, 0.562515581259504, 0.23618009698111564, 0.039667696837568656, 0.04746003221953288, 8.027869127690792, 42.58665941655636, 64.62931841611862, 60.61158500611782, 57.4684202671051, 53.1545003503561, 34.44930486381054, 31.926506236195564, 59.350881054997444, 52.69382447004318, 23.787926249206066, 40.471947491168976, 48.763474971055984, 51.22506648302078, 46.612045615911484, 32.04377554357052, 9.64666111394763, 2.1501984586939216, 0.20238775323377922, 0.057358163394383155, 0.09207436596625485, 0.12675460777245462, 0.12443738523870707, 0.755577877862379, 1.1127364472486079, 1.2681839684955776, 3.151525715366006, 3.5780022433027625, 6.629423992708325, 4.935300098732114, 4.693081621080637, 6.059792283922434, 4.406498624011874, 2.321946155279875, 1.3150512473657727, 4.970711823552847, 7.7496076840907335, 21.61163292825222, 10.478131547570229, 9.641221705824137, 6.461549000814557, 7.042732089757919, 4.355656877160072, 3.1868944549933076, 6.513183480128646, 5.292064854875207, 3.9074260415509343, 2.520395969040692, 4.029319463297725, 2.652515354566276, 6.990951793268323, 13.716601822525263, 39.781592935323715, 55.105118080973625, 62.777381390333176, 56.260761469602585, 62.076976373791695, 64.2328628897667, 43.581575229763985, 16.951452791690826, 8.108268063515425, 7.954329773783684, 5.1195351127535105, 4.2202444933354855, 2.1963932923972607, 4.7969661466777325, 3.192673232406378, 4.390322417020798, 2.653221166692674, 2.732095909304917, 5.373272197321057, 4.351383531466126, 3.282292135991156, 9.59822891280055, 6.338905356824398, 2.363803996704519, 7.8316395822912455, 3.004263429902494, 6.057239770889282, 3.9162812288850546, 7.198108127340674, 4.144227672368288, 1.9201545277610421, 1.618393245153129, 0.5122532439418137, 0.1910035195760429, 0.11684980840072967, 0.02875873640732607, 0.08416866010520607, 0.1748350606067106, 0.4494330851593986, 4.3365605268627405, 14.661831501871347, 39.067991226911545, 39.67506945133209, 38.57221283018589, 32.50070862472057, 24.961793459951878, 30.273731723427773, 45.42544908821583, 44.29129354655743, 33.601669147610664, 43.968694657087326, 45.30015841126442, 50.63774719834328, 59.535900726914406, 62.53713548183441, 40.83021126687527, 23.299021683633327, 1.8543148669414222, 0.013373802630667342, 0.03917572714271955, 0.24566314124967903, 0.09165295225102454, 0.30300630955025554, 0.6207985756918788, 0.46763862075749785, 0.32857445476111025, 0.34951720910612494, 0.18704701156821102, 0.06452755114878528, 0.0526307309337426, 0.025867943186312914, 0.03529320012603421, 0.08897135747247376, 0.08970760507509112, 0.23193820350570604, 0.2898339898092672, 0.045530704301199876, 0.017871121999633033, 0.049079339078161865, 0.1349597331136465, 0.042165175909758545, 0.11460296373115852, 0.13973530498333275, 0.03636730674770661, 0.055972558839130215, 0.08334100217325613, 0.13472220132825896, 0.06226251643965952, 0.01804380677640438, 0.08291321340948343, 0.1349661749554798, 0.04532540027867071, 0.01839854408899555, 0.033555023474036716, 0.012354772643448086, 0.03958776382205542, 0.033795267809182405, 0.03476254969427828, 0.04580088316288311, 0.02167428745451616, 0.04793655782123096, 0.0389912255195668, 0.05145005190570373, 0.03142245841445401, 0.057561099965823814, 0.07125070405891165, 0.04516302949923556, 0.019428119994699955, 0.1076710966299288, 0.03992254292825237, 0.014127573267614935, 0.10917137784417719, 0.035082626855000854, 0.029753143790003378, 0.058016333350678906, 0.10659300838597119, 0.14272656087996438, 0.12088067218428478, 0.21385153027949855, 0.26143618393689394, 0.3158726269612089, 0.16747268848121166, 0.07055543785099871, 0.04090780334081501, 11.880903225392103, 51.48771598935127, 73.41364905238152, 69.32988658547401, 64.55403685569763, 62.61401675641537, 45.48530347645283, 44.509565234184265, 66.06723725795746, 57.46845066547394, 31.02385137230158, 35.666729137301445, 40.900697484612465, 47.52594597637653, 42.36696280539036, 27.677049860358238, 9.710639230906963, 2.395459860563278, 0.16472913179313764, 0.07308756408747286, 0.12245697158505209, 0.45266834436915815, 0.7509772153571248, 3.078310531564057, 2.9016556357964873, 3.3556661987677217, 5.277812294661999, 7.4676314648240805, 8.816988933831453, 7.550305528566241, 9.016988351941109, 8.115052599459887, 8.558245617896318, 8.68536589667201, 7.84992135129869, 8.646390438079834, 10.243533086031675, 7.769852047786117, 9.629693124443293, 8.153980560600758, 5.331611707806587, 6.747640874236822, 5.270716175436974, 2.588195255957544, 3.4193168208003044, 1.065113008953631, 1.9575199414975941, 2.7010890981182456, 2.959864712320268, 3.790889144875109, 8.51035488769412, 18.19546803832054, 43.4011647105217, 67.37598583102226, 75.25285676121712, 67.56593003869057, 71.78015470504761, 71.70423477888107, 44.740657433867455, 19.823374785482883, 8.553474973887205, 6.879953099414706, 6.800650879740715, 4.559494564309716, 2.945169950835407, 5.503437062725425, 1.6454910160973668, 4.280723948031664, 4.732534904032946, 5.146711729466915, 9.20268153771758, 8.804052527993917, 4.887956539168954, 6.386679718270898, 7.833392713218927, 5.437966575846076, 9.085452128201723, 7.6068787928670645, 8.13082080334425, 6.016667922958732, 7.87490738555789, 5.543540585786104, 4.997588731348515, 3.284147148951888, 0.9662196936551481, 0.3397064917953685, 0.24075767869362608, 0.23618104693014175, 0.026774727048177738, 0.12039728913805448, 0.19064181164139882, 3.7294580787420273, 13.542328923940659, 34.692716002464294, 37.21893824636936, 49.32660475373268, 34.640202820301056, 26.901937052607536, 35.89015334844589, 49.20377254486084, 46.66643209755421, 42.694265842437744, 54.11262273788452, 56.89832925796509, 60.29141418635845, 66.37193530797958, 76.19779765605927, 57.4564965069294, 32.96873331069946, 4.149912167340517, 0.10437901117256843, 0.05093622596177738, 0.154315538238734, 0.07136489090044051, 0.2472158329328522, 0.4426064249128103, 0.22949057078221813, 0.24940822622738779, 0.14224101818399504, 0.062290911009768024, 0.11328261622111313, 0.03708510826982092, 0.008563649462303147, 0.027535723420442082, 0.03114165570877958, 0.06588169606402516, 0.13123020355124027, 0.09785004862351343, 0.08301551846670918, 0.03669983343570493, 0.07528114481829107, 0.038343646010616794, 0.07131625796318986, 0.04509271471761167, 0.02905617806391092, 0.10064069458167069, 0.0354924333805684, 0.02508324818336405, 0.052809395565418527, 0.05861677534994669, 0.042364680048194714, 0.04098556186363567, 0.021279019601934124, 0.06202671385835856, 0.22464323323220015, 0.18528444052208215, 0.16124087444040924, 0.16428844450274482, 0.22673206723993644, 0.09503710854914971, 0.11704405071213841, 0.06182204437209293, 0.11409164624637924, 0.10133279181900434, 0.12691979500232264, 0.12822598975617439, 0.14421305299038067, 0.19015870318980888, 0.21916287339990959, 0.1623469268088229, 0.1443804072914645, 0.16554644418647513, 0.20595120498910546, 0.3183818282559514, 0.08716954907868057, 0.12399893181282096, 0.19621774525148794, 0.2742306317668408, 0.35741597588639706, 0.4464864917099476, 0.5661066854372621, 0.7864285411778837, 0.7670293946284801, 0.3674322087317705, 0.1398367268848233, 0.32020635379012674, 17.672631293535233, 64.673722833395, 86.89613878726959, 81.42227411270142, 76.12394481897354, 72.04429373145103, 50.10935515165329, 47.21913143992424, 69.16673853993416, 61.79684400558472, 34.800824001431465, 57.416431456804276, 66.9630315899849, 66.18516013026237, 59.11891110241413, 42.38173261284828, 13.665089886635542, 3.1948315165936947, 0.6772367097437382, 0.23129486537072808, 0.3236677899258211, 0.47860554477665573, 0.3671454725554213, 1.7681636335328221, 2.891852636821568, 5.1312921568751335, 10.624267905950546, 10.89776013046503, 18.186559416353703, 13.828409872949123, 16.204143092036247, 17.884251438081264, 15.447309203445911, 11.905166823416948, 9.593961741775274, 12.299306374043226, 18.922716714441776, 32.95105665922165, 24.14543766528368, 21.166612207889557, 16.520662307739258, 17.92744942009449, 14.881413169205189, 13.271209672093391, 16.931325271725655, 15.503618381917477, 13.97199371829629, 9.864371381700039, 11.670189332216978, 6.773485187441111, 10.502655431628227, 19.32661034166813, 50.61817444860935, 60.89721567928791, 66.63463801145554, 59.88086901605129, 63.037724420428276, 65.00964760780334, 50.290039256215096, 26.752580367028713, 15.74469169601798, 14.135277606546879, 12.543175388127565, 10.163977704942226, 7.53486268222332, 12.687475495040417, 7.821159269660711, 11.75903046503663, 6.777651188895106, 8.07215005159378, 13.76212053000927, 11.988381408154964, 11.124543361365795, 17.35765479505062, 15.344042144715786, 11.475257892161608, 21.497426256537437, 12.239255346357822, 19.0396174415946, 14.120004326105118, 14.254519008100033, 9.52953714877367, 5.165356379002333, 3.6202331772074103, 1.1889133346267045, 0.3364933782722801, 0.19086763233644888, 0.313639534288086, 0.1486538865719922, 0.6615612446330488, 1.1983858700841665, 5.939210504293442, 19.11406684666872, 49.13523942232132, 52.67047472298145, 54.370602294802666, 44.69375655055046, 34.61377903819084, 38.16593483090401, 57.921302765607834, 55.332239493727684, 48.10788854956627, 59.87716801464558, 66.80901065468788, 72.28097543120384, 78.65627333521843, 87.29402303695679, 68.29348459839821, 39.23916444182396, 5.577114159241319, 0.23539247049484402, 0.20705461531179026, 0.3471548343077302, 0.2538287249626592, 0.5238935630768538, 1.0347173712216318, 0.660497301723808, 0.45002849539741874, 0.5393991654273123, 0.26925557060167193, 0.19370269583305344, 0.14640175038948655, 0.1430310937575996, 0.2762510546017438, 0.18132141645764932, 0.22507985355332494, 0.3475867345696315, 0.36343185463920236, 0.22331084066536278, 0.2405407786136493, 0.127184726879932, 0.3477437433321029, 0.19560072367312387, 0.28913458983879536, 0.2017876526224427, 0.16160840081283823, 0.11122461102786474, 0.16207933804253116, 0.24540049518691376, 0.18416645441902801, 0.133609707118012, 0.23104002670152113, 0.19194417691323906, 0.11713115658494644], [0.03405883413506672, 0.05161603323358577, 0.05709076387574896, 0.04001311834144872, 0.0056160197891585995, 0.0469447516661603, 0.047286666522268206, 0.07807147165294737, 0.07193332407041453, 0.054478214806295, 0.031335337698692456, 0.03473424418189097, 0.042141490266658366, 0.017974395559576806, 0.020418992899067234, 0.22849610773846507, 0.09777756305993535, 0.02888841372623574, 0.010040840606961865, 0.09343901969259605, 0.0681142469693441, 0.07372737702098675, 0.06323244408122264, 0.08149606757797301, 0.10842763455002569, 0.15554291690932587, 0.05043185126851313, 0.2424199559027329, 0.3150536521570757, 0.16029407212045044, 0.3709650394739583, 5.1607363019138575, 39.10167261958122, 67.74357810616493, 57.7286759018898, 55.12767367064953, 48.71041841804981, 41.93409003317356, 27.359962575137615, 22.803786657750607, 33.762856498360634, 30.66215258091688, 37.052788361907005, 32.982507571578026, 50.34272342920303, 44.174601808190346, 31.5378250926733, 10.789354797452688, 1.439710445702076, 0.0387573562329635, 0.0862064714601729, 0.04372029070509598, 0.14888543664710596, 0.053659919067285955, 0.7819503627251834, 1.3801229931414127, 3.251930815167725, 2.7722697285935283, 3.5020424192771316, 7.559891939163208, 7.227431628853083, 5.075035700574517, 7.657665442675352, 4.646798679605126, 3.5629339143633842, 5.1771647203713655, 5.124272983521223, 7.371109519153833, 5.96084606833756, 9.119601845741272, 9.397319443523884, 5.103004574775696, 7.313778670504689, 5.3415382001549006, 4.37486294656992, 1.2169681792147458, 3.3325634384527802, 3.1408430635929108, 10.459397602826357, 12.69773494452238, 16.42335332930088, 15.124781560152769, 33.43653380870819, 44.702317491173744, 54.005582481622696, 52.38549381494522, 49.95670974254608, 48.45785357058048, 50.75458712875843, 53.79673808813095, 52.58941367268562, 32.65716142952442, 23.25595859438181, 29.168923906981945, 21.262498162686825, 16.853957623243332, 14.00463491678238, 11.005676239728928, 7.057851003482938, 5.509519586339593, 2.890759720467031, 4.9564929865300655, 4.571690484881401, 7.968841195106506, 3.182578361593187, 6.124846693128347, 4.961290704086423, 3.76922769472003, 8.69861863553524, 5.274894526228309, 3.4251319337636232, 8.607599269598722, 3.119006110355258, 7.186116920784116, 3.077268674969673, 2.67337029799819, 1.0738905379548669, 1.1944851418957114, 0.07000431898632087, 0.0755564148130361, 0.1217202193220146, 0.012995787856198149, 0.06949823364266194, 0.1918167353142053, 1.7229594779200852, 10.65841382369399, 27.622936964035034, 25.373229682445526, 25.556015074253082, 33.56314301490784, 29.174179024994373, 21.571940258145332, 27.139923982322216, 20.337236411869526, 18.506469950079918, 28.956754691898823, 46.03679448366165, 44.07168813049793, 55.89215844869614, 65.7266691327095, 54.26685266196728, 25.414037592709064, 0.9709860035218298, 0.15801398665644228, 0.14405749883735552, 0.11301472317427397, 0.374295916990377, 0.4447143024299294, 0.2689191995887086, 0.267736334935762, 0.22065129509428516, 0.12638262851396576, 0.00831096209367388, 0.14552950422512367, 0.018069609395752195, 0.07808178750565276, 0.09903285390464589, 0.06583655122085474, 0.03153421472234186, 0.08151176400133409, 0.12444869556929916, 0.057607038907008246, 0.019149486215610523, 0.0431758400372928, 0.03135538681817707, 0.050045793468598276, 0.05292293673846871, 0.03751367999939248, 0.04668707799282856, 0.04815586988115683, 0.06425781757570803, 0.06406347878510132, 0.05291122564813122, 0.09904005273710936, 0.05830565220094286, 0.03228163164749276, 0.034706992519204505, 0.054454614510177635, 0.008503503959218506, 0.0415540135873016, 0.0806075386935845, 0.02760331452009268, 0.01683902279182803, 0.07326087783440016, 0.1236925955163315, 0.042293200094718486, 0.026841871003853157, 0.06721619633026421, 0.005558269103858038, 0.05321579192241188, 0.023827558434277307, 0.06318749961792491, 0.03667699755169451, 0.06586027026060037, 0.03199841325113084, 0.04812265506188851, 0.10583114926703274, 0.050657519823289476, 0.11768091731937602, 0.06658576414338313, 0.15635924966773018, 0.07728118827799335, 0.08304814327857457, 0.15524157526670024, 0.13701193471206352, 0.09741578833200037, 0.20937154098646715, 7.419160790741444, 45.692768543958664, 76.9402626156807, 68.6858743429184, 63.77706214785576, 58.06697554886341, 52.9257146269083, 36.83831267058849, 29.975797310471535, 38.35580304265022, 31.276325024664402, 31.107617877423763, 30.950334817171097, 53.425471410155296, 53.68407033383846, 33.60020622611046, 8.292033802717924, 1.2309527350589633, 0.06530916623887606, 0.06412146278307773, 0.09647680082707666, 0.38587796268984675, 1.3304406590759754, 4.203643184155226, 4.309797612950206, 6.659634746611118, 5.399063788354397, 7.964271940290928, 9.430291224271059, 10.346536058932543, 10.53130304440856, 9.821975156664848, 7.2936340514570475, 6.73689647577703, 8.589511290192604, 7.068046806380153, 7.859061760827899, 10.4425635561347, 9.757579062134027, 8.39232087135315, 3.259426625445485, 1.2496667308732867, 2.512759566307068, 1.6474413801915944, 0.5292791803367436, 2.996028084307909, 3.736768886446953, 9.822503328323364, 15.17819244414568, 18.217734843492508, 20.11211559176445, 42.72499479353428, 49.969214871525764, 59.80245262384415, 65.56196317076683, 58.859643414616585, 56.46427474915981, 60.018588826060295, 64.28207024931908, 57.49033369123936, 37.05375351011753, 25.108378194272518, 30.85350651293993, 20.94745896756649, 17.166344560682774, 15.637680888175964, 13.391699306666851, 7.8257964458316565, 5.920477984473109, 4.568902384489775, 6.304834010079503, 5.598875591531396, 9.655792973935604, 5.228308076038957, 5.511179147288203, 7.1995192766189575, 4.686974873766303, 7.1472393069416285, 4.846288925036788, 5.982244620099664, 6.0074035450816154, 5.903481021523476, 6.667320784181356, 5.617179209366441, 4.649649476632476, 3.279801607131958, 3.202761453576386, 1.0843355837278068, 0.5389400431886315, 0.6357683474197984, 0.06565971969394013, 0.11823064836789854, 0.08014072780497372, 0.9647702495567501, 9.067439194768667, 23.646760024130344, 31.91952221095562, 26.568472646176815, 27.309987656772137, 24.796291440725327, 30.61928518116474, 33.49407032132149, 26.213049218058586, 25.98925832659006, 36.489989161491394, 54.11959536373615, 57.88254104554653, 62.182485312223434, 73.63898456096649, 65.77026039361954, 36.94172792136669, 2.1735123451799154, 0.10341424887883477, 0.06849096113000996, 0.12206122133648023, 0.17552889446960762, 0.38305391266476363, 0.026698857291194145, 0.13435255241347477, 0.13209333614213392, 0.05732842182624154, 0.07109081576345488, 0.02980631496029673, 0.017390195462212432, 0.09780500025954098, 0.12676961399847642, 0.03585105027013924, 0.027935345824516844, 0.15433584339916706, 0.07578302960610017, 0.013819130199408391, 0.06809685844928026, 0.04482926713535562, 0.02714727961574681, 0.03837197749817278, 0.0758611258061137, 0.027298163804516662, 0.022964192066865508, 0.01695053419098258, 0.009356854116049362, 0.02972307938762242, 0.08216140297008678, 0.011829333016066812, 0.06885910348501056, 0.07280287623871118, 0.18493618030333892, 0.1310465220012702, 0.1420486980350688, 0.16127701703226194, 0.1866735628573224, 0.13752590166404843, 0.16347369994036853, 0.20548301370581612, 0.3088426182512194, 0.13811399432597682, 0.0922509674273897, 0.12173925540992059, 0.09632715416955762, 0.2453704085201025, 0.14062755944905803, 0.437202105531469, 0.24338642513612285, 0.14313451945781708, 0.12102077482268214, 0.2330996943055652, 0.2252680028323084, 0.17063483130186796, 0.22070973180234432, 0.29738005832768977, 0.28257946658413857, 0.5131212004926056, 0.3115870803594589, 0.5311953462660313, 0.7084685994777828, 0.3750393708469346, 0.4952295636758208, 10.466170739382505, 57.422647923231125, 85.76247721910477, 75.21811902523041, 72.21193313598633, 68.0238738656044, 58.23703542351723, 41.20715484023094, 34.649626314640045, 45.1626817882061, 39.27670642733574, 50.30551962554455, 48.340496867895126, 65.37287011742592, 56.564767956733704, 40.55608257651329, 13.476372063159943, 2.377523398026824, 0.1417541247792542, 0.22456802398664877, 0.16628577170195058, 0.1660428222385235, 0.6280243035871536, 4.103297693654895, 6.6197036392986774, 10.164582822471857, 8.619463182985783, 12.616845835000277, 21.00750334560871, 18.24681658297777, 17.344239614903927, 18.289780877530575, 14.713224694132805, 11.669731456786394, 13.79832498729229, 16.045296415686607, 20.429292172193527, 16.20951410382986, 24.75431889295578, 22.151591554284096, 11.60395223647356, 16.166409216821194, 13.247448597103357, 12.583658415824175, 7.305586785078049, 9.095683079212904, 6.749065797775984, 15.470334067940712, 19.303925558924675, 22.42051262408495, 21.81273713707924, 47.05904982984066, 52.96518310904503, 69.5660363137722, 63.978952914476395, 64.94929164648056, 57.785866633057594, 61.70620746910572, 67.08130404353142, 64.0134246647358, 43.46768394112587, 30.323450155556202, 36.59540690481663, 27.457626834511757, 22.00760968029499, 18.74258168041706, 16.759357899427414, 10.630377978086472, 10.496855042874813, 9.19418329373002, 11.406491082161665, 11.884249895811081, 15.609688740223646, 9.523697812110186, 13.545837085694075, 14.98066384345293, 9.198638554662466, 19.0412475541234, 15.799095276743174, 12.35547211021185, 22.977049760520458, 13.108644895255566, 18.235996663570404, 8.599717542529106, 7.562656765803695, 5.243895789608359, 3.638793518766761, 0.8125406806357205, 0.2573970006778836, 0.38637722027488053, 0.0873656541807577, 0.30140552669763565, 0.5226343462709337, 2.645374587737024, 14.810889903455973, 35.36056436598301, 38.562671542167664, 37.66806274652481, 47.98927031457424, 41.1257404088974, 32.09010265767574, 39.014953672885895, 33.68983581662178, 32.217145040631294, 44.5577010512352, 62.34116479754448, 67.50922188162804, 74.90976557135582, 85.25583520531654, 75.20649164915085, 44.025942385196686, 3.7337568355724216, 0.4034149122890085, 0.2139044157229364, 0.29069553420413285, 0.5197513103485107, 0.8149088441859931, 0.4948578664334491, 0.5490580096375197, 0.33091284334659576, 0.2133724739542231, 0.209238295792602, 0.21343664004234597, 0.11431046848883852, 0.24383143172599375, 0.3247023734729737, 0.13339110009837896, 0.28629305481445044, 0.3710894234245643, 0.37119243352208287, 0.23989456094568595, 0.2547556674107909, 0.1227715754066594, 0.11854543030494824, 0.15146606223424897, 0.19391880923649296, 0.1281520866905339, 0.15242456080159172, 0.18038075912045315, 0.16526791616342962, 0.1296972084674053, 0.128795929485932, 0.11462532464065589, 0.18058731366181746, 0.18894057167926803], [0.055616661920794286, 0.07173782752943225, 0.030393945635296404, 0.059240543050691485, 0.07684101306949742, 0.09638409173930995, 0.0539568523527123, 0.0069685347625636496, 0.016231181580224074, 0.019072586728725582, 0.056107948839780875, 0.016226775078393985, 0.062010880137677304, 0.023338909850281198, 0.06000518522341736, 0.0990500272018835, 0.07062088043312542, 0.044210761261638254, 0.06240046684979461, 0.14765402069315314, 0.02143290392268682, 0.03845358776743524, 0.10519302100874484, 0.1963087177136913, 0.2002267973148264, 0.03046120091312332, 0.08171860055881552, 0.3184287913609296, 0.16727441630791873, 0.0779612033511512, 2.620121855288744, 23.144107796251774, 61.79540768265724, 63.52545864880085, 60.264207646250725, 49.650142192840576, 38.33569072186947, 33.23275454342365, 29.37139794230461, 29.751691035926342, 27.558013647794724, 57.75366336107254, 54.034669920802116, 39.65503692626953, 51.446583196520805, 15.876596868038177, 5.243238424882293, 0.8237177215050906, 0.01811395828553941, 0.03732674413186032, 0.06896242528455332, 0.29927654250059277, 0.4611432255478576, 3.203373933210969, 4.075751546770334, 8.233378250151873, 6.470972970128059, 2.851167982444167, 3.0591904325410724, 6.910740472376347, 7.946059992536902, 5.1761777233332396, 6.978756822645664, 5.8541173953562975, 6.0024329368025064, 9.901025164872408, 9.168661013245583, 6.786348922178149, 10.781963244080544, 3.1599778868258, 3.261630507186055, 4.398016054183245, 5.177052151411772, 10.814817231148481, 13.071779273450375, 18.97742237895727, 24.24381248652935, 31.88993699848652, 39.2019834369421, 42.45507247745991, 39.998758882284164, 26.537337116897106, 42.41428166627884, 55.53322970867157, 50.074355229735374, 33.0454283952713, 45.03745950758457, 42.76464946568012, 46.99622020125389, 40.18715277314186, 50.69274924695492, 53.7580181658268, 33.14032830297947, 36.23165242373943, 46.521963849663734, 46.41803562641144, 36.41466200351715, 31.726302579045296, 16.452041789889336, 15.98893404006958, 17.991768568754196, 15.596059821546078, 14.076413065195084, 19.972929060459137, 8.23497986420989, 6.453472059220076, 6.290206694975495, 6.901276130229235, 6.0718371625989676, 4.909590678289533, 4.704088205471635, 2.9079243494197726, 4.792383117601275, 2.6071341522037983, 6.794312344864011, 3.8369037257507443, 2.0747969672083855, 1.0634201997891068, 2.037517880089581, 0.6869382422883064, 0.2987412759102881, 0.07040216951281764, 0.033458317921031266, 0.026479910738999024, 0.1359652541577816, 1.0365114687010646, 7.4338071048259735, 28.45312401652336, 49.018133506178856, 46.20828688144684, 43.12509052455425, 20.410004407167435, 15.269379001110792, 21.16832211613655, 32.75136597454548, 39.52865190804005, 20.921052284538746, 27.132366187870502, 47.310041561722755, 52.929731011390686, 56.877316385507584, 56.93686679005623, 25.068510733544827, 2.4739721976220608, 0.08353833924047649, 0.07751981102046557, 0.37121315428521484, 0.2884569496382028, 0.23404470062814653, 0.03872692075674422, 0.08091435738606378, 0.034560629865154624, 0.023103187049855478, 0.016483226063428447, 0.00666123738483293, 0.0811156204144936, 0.04484888951992616, 0.026901472883764654, 0.06668417292530648, 0.08061100452323444, 0.026999293513654266, 0.0385634144913638, 0.04233362116792705, 0.03614373847085517, 0.022201989704626612, 0.0622075455612503, 0.05139275068358984, 0.05478858838614542, 0.04439090276719071, 0.04294047903385945, 0.008812216983642429, 0.09041298675583676, 0.0257262356535648, 0.03665930846182164, 0.05932020147156436, 0.018974975755554624, 0.06152631336590275, 0.060945152363274246, 0.05127851189172361, 0.02581045642727986, 0.1104367247899063, 0.04295618287869729, 0.05120273861393798, 0.07541027109255083, 0.03503989028104115, 0.020177132537355646, 0.04739869000331964, 0.04809951118659228, 0.08923068613512442, 0.03154322439513635, 0.042113949166378006, 0.06271636942983605, 0.10845542055903934, 0.01744684730510926, 0.031354444290627725, 0.050525591941550374, 0.05988987773889676, 0.08874512117472477, 0.06954624317586422, 0.059580936504062265, 0.12278339781914838, 0.10128669702680781, 0.006464369726018049, 0.22406220581615344, 0.09584057988831773, 0.0788833737897221, 3.7577900709584355, 27.03588366508484, 71.96763664484024, 72.70854368805885, 69.31063681840897, 57.652831971645355, 47.237393260002136, 41.54227025806904, 38.72917860746384, 34.68167759478092, 35.25463744997978, 53.84773135185242, 40.306633561849594, 39.511499628424644, 56.95053845643997, 21.22831329703331, 6.355718979611993, 1.0270933178253472, 0.021068214409751818, 0.10565417673205957, 0.33683435060083866, 1.2270941608585417, 2.221048269420862, 5.594667317345738, 9.681658186018467, 10.88015092536807, 9.56271031871438, 8.939572256058455, 8.342147413641214, 9.480030555278063, 11.264140270650387, 10.017540212720633, 10.199363306164742, 12.283882051706314, 8.540777955204248, 11.94372620433569, 8.190634343773127, 9.225742500275373, 6.93468963727355, 4.901316622272134, 3.4601480048149824, 2.58974842261523, 6.252421047538519, 8.35173524916172, 13.297079633921385, 19.368102215230465, 27.218644358217716, 35.56135319173336, 42.01010875403881, 45.57167664170265, 45.59518977999687, 31.321835182607174, 48.10605704784393, 59.65499773621559, 56.56768620014191, 41.30483239889145, 48.91731731593609, 49.088946506381035, 56.223056092858315, 49.55057993531227, 57.25905530154705, 59.03756886720657, 35.96540831029415, 38.6379075050354, 49.36201885342598, 48.49109798669815, 39.35298353433609, 34.39062841236591, 19.469020999968052, 16.45924050360918, 15.552639551460743, 14.380514547228813, 10.887363888323307, 11.844952404499054, 8.37700579315424, 7.471681097522378, 6.598869357258081, 3.562253750860691, 4.8969772551208735, 4.932004725560546, 4.033387620002031, 4.700793782249093, 6.438419641926885, 8.113100454211235, 6.125037157908082, 6.811178689822555, 5.182759445160627, 7.319547710940242, 3.6855578469112515, 2.0868059853091836, 0.8946917380671948, 1.0945431422442198, 0.03838709875708446, 0.03855656075756997, 0.15176336659351364, 0.6421287311241031, 6.744413897395134, 22.558293230831623, 38.871629163622856, 40.61854362487793, 36.70633815228939, 20.032405368983746, 28.06992407888174, 33.73323328793049, 41.08780324459076, 47.27913782000542, 31.941918209195137, 37.05577880144119, 55.589641481637955, 61.7371492087841, 64.7760209441185, 68.19123208522797, 36.44975312054157, 4.750034864991903, 0.04796355715370737, 0.08652500866446644, 0.31364478869363666, 0.22432154190028086, 0.10174532202654518, 0.06921068110386841, 0.049071145767811686, 0.02210265323810745, 0.01745375669997884, 0.02685961389943259, 0.024055529502220452, 0.08133770810673013, 0.05190196789044421, 0.05754197482019663, 0.04194279135845136, 0.0650314248923678, 0.08469229724141769, 0.0578975303506013, 0.01620128045033198, 0.022166225608089007, 0.05438204731035512, 0.01927935278217774, 0.039206956716952845, 0.01945731979503762, 0.005904181352889282, 0.04881474858848378, 0.03741953485587146, 0.08777154216659255, 0.03330384730361402, 0.053151659230934456, 0.0496762299007969, 0.009627069157431833, 0.17404764192178845, 0.16605203971266747, 0.1674937951611355, 0.1629769359715283, 0.37578698073048145, 0.17822431545937434, 0.16947691765381023, 0.1029633941652719, 0.09101227842620574, 0.10184262500843033, 0.16004855482606217, 0.09269355461583473, 0.1965748073416762, 0.12935335660586134, 0.17622728511923924, 0.23180032731033862, 0.1709566859062761, 0.13812757562845945, 0.23242076276801527, 0.21055287681519985, 0.22397945635020733, 0.13482812064466998, 0.23106433945940807, 0.42923387372866273, 0.24368899874389172, 0.24715346284210682, 0.26162943919189274, 0.6318214873317629, 0.4858443938428536, 0.24775717029115185, 4.980399403721094, 36.41517497599125, 83.26677113771439, 81.81365311145782, 77.54588931798935, 68.0270504951477, 54.28733356297016, 49.56156134605408, 42.64383874833584, 41.99224591255188, 38.72613117098808, 74.65766429901123, 71.33178636431694, 52.616548016667366, 63.99315655231476, 24.10405408591032, 8.033210691064596, 1.2032544775865972, 0.21267748234095052, 0.20063698233570904, 0.3210859472164884, 1.1314223008230329, 2.3459599167108536, 7.052698954939842, 10.489559434354305, 17.56868977099657, 16.85918804258108, 11.425464414060116, 12.46917150914669, 14.591072648763657, 22.51082807779312, 18.697778284549713, 18.556792549788952, 16.19518507272005, 14.294096734374762, 18.934478983283043, 22.858176939189434, 18.194160908460617, 18.652708902955055, 10.934847090393305, 11.743558645248413, 12.182533890008926, 12.716341596096754, 16.16881638765335, 17.677631825208664, 23.674722723662853, 27.502131946384907, 35.72189457714558, 43.91489714384079, 47.93832264840603, 49.62738521397114, 36.107972860336304, 55.833645388484, 66.69548034667969, 62.658459171652794, 44.717607870697975, 55.79427570104599, 52.22693592309952, 61.34151443839073, 56.04524843394756, 66.48221299052238, 63.618983030319214, 40.90517744421959, 42.36971005797386, 52.92846567928791, 53.15650664269924, 46.635896936059, 40.87609000504017, 23.583672009408474, 22.001030333340168, 23.429698571562767, 22.43279356509447, 20.454070642590523, 27.70911443978548, 14.50373338535428, 13.109097070991993, 14.707333110272884, 13.298196773976088, 14.072149693965912, 10.630746558308601, 11.496079824864864, 10.891116186976433, 14.183540716767311, 10.991089772433043, 17.893359549343586, 11.189549323171377, 7.591930869966745, 6.332541648298502, 6.311803786084056, 2.0781008899211884, 0.38351398485247046, 0.5268602538853884, 0.07827708366676234, 0.17375888710375875, 0.34443394280970097, 1.8090716446749866, 9.835534729063511, 37.75054112076759, 63.199956715106964, 65.82472667098045, 60.4672459512949, 32.254447638988495, 25.84632709622383, 33.48827563226223, 47.52096064388752, 54.46709431707859, 34.91848848760128, 41.374091282486916, 67.25614786148071, 71.50535345077515, 76.55099630355835, 78.25045511126518, 48.28642196953297, 6.22049231082201, 0.2798226848244667, 0.14289860555436462, 0.654266111087054, 0.4666730866301805, 0.36264648428186774, 0.26010328670963645, 0.13883947336580604, 0.16506177722476423, 0.1318448650999926, 0.1476365653797984, 0.16971884295344353, 0.32592424540780485, 0.23871502111433074, 0.16069636069005355, 0.22034165624063462, 0.2753828902496025, 0.22333588072797284, 0.10685425921110436, 0.11687199119478464, 0.11566589731955901, 0.1844314456684515, 0.15040174825116992, 0.16380937333451584, 0.1036301841668319, 0.11990040642558597, 0.15258200000971556, 0.08547605713829398, 0.19259857304859906, 0.10771149172796868, 0.16160899453097954, 0.16396559542044997, 0.10352402736316435], [0.0254299331936636, 0.03290018576080911, 0.05895719848922454, 0.07878729535150342, 0.025078539256355725, 0.020889863335469272, 0.020316259251558222, 0.026678912072384264, 0.10299658300937153, 0.033318898058496416, 0.08491485990816727, 0.07003453923971392, 0.026133123683393933, 0.045663626660825685, 0.010570398226263933, 0.023382355175272096, 0.05271198497212026, 0.06450355009292252, 0.05838931079779286, 0.006047028082321049, 0.007928307968541048, 0.002949358877231134, 0.05325540776539128, 0.08798295035376213, 0.10039050917839631, 0.1170122051553335, 0.028057232448190916, 0.2376707599614747, 0.033689207484712824, 1.0953320749104023, 15.070671513676643, 49.73817206919193, 71.62233397364616, 56.8315402418375, 50.153683573007584, 39.40793238580227, 29.79314301162958, 23.1985816732049, 24.17129907757044, 26.403776183724403, 23.157340586185455, 36.3530483096838, 46.81845813989639, 40.80690711736679, 17.510778978466988, 6.721063200384378, 1.3063208595849574, 0.11988007900072262, 0.11182431830093265, 0.08876607942511328, 0.535174326505512, 1.4817516272887588, 2.6262590009719133, 6.7902646120637655, 7.314149150624871, 4.591210037469864, 5.864075710996985, 5.035904450342059, 7.457050932571292, 6.122784353792667, 5.9897781908512115, 8.58147282153368, 8.026513550430536, 7.046930864453316, 7.420809427276254, 9.86961605027318, 4.5058689918369055, 3.9918368496000767, 8.495152853429317, 6.599608417600393, 10.225929580628872, 12.208513095974922, 19.09491017460823, 34.24042247235775, 42.89233021438122, 49.906814619898796, 60.659378841519356, 58.097848892211914, 62.74083115160465, 63.09285186231136, 65.21587774157524, 32.65625327825546, 39.45473067462444, 64.14613634347916, 47.966995909810066, 24.144903793931007, 41.86403699219227, 40.28118632733822, 42.39725477993488, 37.91409954428673, 61.32739819586277, 54.203969836235046, 32.59988710284233, 45.75163118541241, 64.53701376914978, 43.26273813843727, 47.827596589922905, 45.418647453188896, 37.484798580408096, 32.88771405816078, 32.30944208800793, 30.498204678297043, 24.870775043964386, 27.584424130618572, 27.361315302550793, 18.98583322763443, 22.76810847222805, 13.696527499705553, 8.851655423641205, 4.37885083258152, 3.0427183164283633, 3.0074212979525328, 3.5422314377501607, 4.70060664229095, 4.911213666200638, 4.249675339087844, 2.3254203563556075, 4.719751914963126, 1.6938427090644836, 1.9952627224847674, 1.6111661517061293, 0.8831265836488456, 0.09932604676578194, 0.03884757541527506, 0.15672361449105665, 0.03370085920323618, 0.4753346327925101, 4.797667684033513, 19.99389063566923, 38.5151094943285, 47.996999099850655, 52.63644374907017, 22.482791282236576, 9.648648407310247, 12.221555896103382, 25.41446126997471, 28.138434402644634, 31.046479158103466, 33.22537913918495, 46.02216526865959, 52.909622490406036, 56.549428179860115, 55.223557725548744, 19.69322606921196, 1.854877236764878, 0.1263848104281351, 0.14412512333365157, 0.3573950473219156, 0.07130003461497836, 0.035885363467969, 0.049292409676127136, 0.03715474398632068, 0.05384032403526362, 0.10347694551455788, 0.02061521303403424, 0.034902366605820134, 0.06200436037033796, 0.0738631232525222, 0.10103019594680518, 0.045567381239379756, 0.02912065028795041, 0.03013721820025239, 0.07527810943429358, 0.018770400893117767, 0.03171411874063779, 0.042085064778802916, 0.016242586534644943, 0.07185582158854231, 0.014599218320654472, 0.03874907757563051, 0.0627862500550691, 0.04807625227840617, 0.05220928382186685, 0.021717196577810682, 0.13303092098794878, 0.08544983706087805, 0.026559958787402138, 0.016036792694649193, 0.045256592056830414, 0.050624572177184746, 0.018384871873422526, 0.014810550437687198, 0.08734544549952261, 0.05282822756271344, 0.020848458916589152, 0.03378824709216133, 0.01643148723815102, 0.03644383330538403, 0.006669110180155258, 0.05132602047524415, 0.0163067118046456, 0.055695889896014705, 0.05030902953876648, 0.03491966977890115, 0.01380533552946872, 0.1090643230418209, 0.02468146056344267, 0.07622001357958652, 0.06897001745528542, 0.0668582807702478, 0.10072164062876254, 0.016646279618726112, 0.06587101655895822, 0.17039090220350772, 0.013157681805751054, 1.3921297551132739, 17.629347816109657, 59.77786034345627, 79.94500458240509, 65.48375576734543, 60.547189861536026, 49.11100052297115, 39.89935241639614, 32.614212334156036, 31.973730102181435, 31.948149874806404, 30.569903030991554, 47.96418786048889, 48.10386076569557, 44.611000791192055, 21.6437716037035, 5.66783239133656, 1.2034899462014437, 0.05235748700215481, 0.047707905832794495, 0.18036453577224165, 1.1181521066464484, 4.0892113745212555, 6.900489097461104, 8.749893084168434, 11.581331100314856, 10.111170038580894, 8.848938569426537, 12.0132377743721, 10.062808133661747, 8.756150398403406, 12.756499741226435, 12.489217333495617, 11.977041866630316, 9.527012184262276, 7.841109149158001, 7.579975761473179, 6.602498637512326, 4.6172671392560005, 7.207950074225664, 5.078745726495981, 9.165729470551014, 12.499812114983797, 19.842763245105743, 34.5822711288929, 46.275573670864105, 51.73140071332455, 62.90898732841015, 59.12946693599224, 63.77317875623703, 62.967253401875496, 69.51283916831017, 37.234145030379295, 44.86871816217899, 68.66595581173897, 51.18807926774025, 30.481890253722668, 48.34784187376499, 48.175714910030365, 49.99690778553486, 44.77390184998512, 66.19627833366394, 58.364469185471535, 36.074128076434135, 49.93011116981506, 64.45448219776154, 48.07269863784313, 51.748754382133484, 50.233631283044815, 43.542995899915695, 35.106152817606926, 35.128928795456886, 29.584040232002735, 24.56043429672718, 25.524917542934418, 24.81540061533451, 19.569385014474392, 22.004396952688694, 15.981809422373772, 10.271951761096716, 4.581265971064568, 1.4387338981032372, 2.474734056740999, 6.664072433486581, 9.34369957074523, 7.519419360905886, 7.662948584184051, 8.184839654713869, 11.744029819965363, 6.173647474497557, 5.6948731653392315, 2.137798061594367, 2.946530277840793, 0.9550389717333019, 0.05121682828757912, 0.12443579704267904, 0.05773529686848633, 0.3447396185947582, 4.467326235026121, 17.147368378937244, 37.28274442255497, 46.808616667985916, 43.41341905295849, 23.547784835100174, 12.72685183212161, 19.5945168659091, 39.93839152157307, 35.54393112659454, 39.598324969410896, 45.84871217608452, 56.15051418542862, 61.91480487585068, 64.75473448634148, 67.35605970025063, 27.792512364685535, 2.928021945990622, 0.021972500944684725, 0.1443187051336281, 0.1350826327688992, 0.03656507054984104, 0.033685099697322585, 0.05939461290836334, 0.04538704306469299, 0.04147133091464639, 0.08360292835277505, 0.06398924175300635, 0.008325178860104643, 0.041867081163218245, 0.07986561366124079, 0.11163482573465444, 0.020460080049815588, 0.029118761522113346, 0.03851024332107045, 0.018980668028234504, 0.023576064995722845, 0.010706580469559412, 0.06758919975254685, 0.07539493090007454, 0.039455728328903206, 0.02293762689077994, 0.047173470447887667, 0.014476111791736912, 0.11591950402362272, 0.028983024567423854, 0.04413340720930137, 0.030304264510050416, 0.12353364974842407, 0.1239388772228267, 0.16812763380585238, 0.14396026264876127, 0.16797804652014747, 0.15814350626897067, 0.11583518862607889, 0.2168259394238703, 0.22376954730134457, 0.21970314206555486, 0.17373580631101504, 0.2176949943532236, 0.19641101534944028, 0.0919866441108752, 0.1683923281962052, 0.1029989801463671, 0.24747815245063975, 0.15687545790569857, 0.24795293400529772, 0.13728081481531262, 0.25427570566534996, 0.162402632413432, 0.1802354762912728, 0.23952275980263948, 0.17593961383681744, 0.22693789447657764, 0.1872916382853873, 0.24644129793159664, 0.4786727239843458, 0.19665947154862806, 1.9999234098941088, 25.628034509718418, 72.1447679400444, 89.62409600615501, 76.49642363190651, 67.2473855316639, 53.478592559695244, 45.18088661134243, 34.034340530633926, 37.32568211853504, 38.75159740447998, 35.506039559841156, 50.12023016810417, 61.488710939884186, 53.615411818027496, 22.800912111997604, 8.798395581543446, 1.7798782861791551, 0.2858948480570689, 0.259326554951258, 0.3135680506238714, 0.956252294126898, 2.769185956567526, 8.95078830420971, 14.10954823717475, 21.05228964239359, 14.904134999960661, 18.476662449538708, 16.99777040630579, 19.741713367402554, 16.263585202395916, 19.292828254401684, 21.368622668087482, 21.0012336820364, 15.916471928358078, 15.50593150779605, 22.634118162095547, 13.24044557288289, 14.030460231006145, 16.015716902911663, 12.070096973329782, 15.920999385416508, 17.001471407711506, 22.789174541831017, 41.19793653488159, 51.76568627357483, 57.51184053719044, 65.99689543247223, 61.14934355020523, 64.30913239717484, 64.87321972846985, 73.93030732870102, 40.21448090672493, 49.822964519262314, 77.50103652477264, 58.070718348026276, 34.04131695628166, 55.72703070938587, 50.843703746795654, 57.34300419688225, 48.88912282884121, 74.51013341546059, 63.422096595168114, 38.42423357069492, 51.073321625590324, 67.24746152758598, 55.499662309885025, 60.67573316395283, 53.21579106152058, 46.40447795391083, 36.24702259898186, 39.11692500114441, 38.58244948089123, 32.43361182510853, 31.922778636217117, 34.30930897593498, 22.743641585111618, 28.986596390604973, 20.50942037254572, 13.363959845155478, 8.713166154921055, 7.726051323115826, 6.538564693182707, 9.815118424594402, 12.308889459818602, 13.179612737149, 12.155303601175547, 9.25056466832757, 14.920056145638227, 9.279758501797915, 10.290342774242163, 4.519352568313479, 2.273045629262924, 0.47353584493976086, 0.16728709219023585, 0.2186701021855697, 0.23161772929597646, 0.7979850273113698, 6.291989274322987, 26.2071006372571, 48.666283786296844, 63.51237215101719, 69.20554205775261, 33.944403156638145, 16.487951762974262, 19.750753082334995, 37.58043944835663, 40.75041934847832, 47.67557054758072, 49.73242297768593, 64.06523868441582, 74.64634090662003, 75.04734098911285, 76.60211876034737, 39.69232812523842, 3.8346851198002696, 0.30185093404725194, 0.35919704125262797, 0.5010197998490185, 0.25908811774570495, 0.24127799842972308, 0.3114849905250594, 0.13613860501209274, 0.26622909237630665, 0.2540278877131641, 0.068296280951472, 0.14298672816948965, 0.14034331688890234, 0.20310993713792413, 0.2670587244210765, 0.10152564631425776, 0.10972795149427839, 0.10386583831859753, 0.12587704783072695, 0.14212466427125037, 0.2973915170878172, 0.15317790006520227, 0.3853474755305797, 0.12884701893199235, 0.05189251292904373, 0.14787834224989638, 0.15738035581307486, 0.14761156984604895, 0.10547436177148484, 0.17912986921146512, 0.31074886908754706, 0.15735530090751126], [0.020831155743508134, 0.033462332939961925, 0.10862180264666677, 0.025189937477989588, 0.05868755768460687, 0.0520871485787211, 0.023344425862887874, 0.060529946713359095, 0.035791507762041874, 0.10378539693192579, 0.03508370296913199, 0.05885524966288358, 0.01709555170236854, 0.0452118887915276, 0.014359099222929217, 0.06974193267524242, 0.09407641322468407, 0.04685537482146174, 0.064005079184426, 0.06576971340109594, 0.034323439467698336, 0.07384618002106436, 0.0619633418682497, 0.025336723156215157, 0.1035841932753101, 0.07031751272734255, 0.022474003526440356, 0.08560427057091147, 0.24474869656842202, 9.128330927342176, 43.22669327259064, 68.13270762562752, 60.83442784845829, 55.84372624754906, 52.79270276427269, 30.714667662978172, 25.11620007455349, 23.594123348593712, 25.957172848284245, 44.060083553195, 28.821888528764248, 19.049603305757046, 37.581723779439926, 14.699313640594482, 3.794075036421418, 1.0074845887720585, 0.09088906706892885, 0.13298989506438375, 0.061634704034077004, 0.4297900095116347, 1.4786840043962002, 4.628573432564735, 3.6874494329094887, 4.052040344104171, 8.498698063194752, 10.812670346349478, 7.813697420060635, 12.308898959308863, 8.680457510054111, 8.595595713704824, 10.318283624947071, 8.69403513148427, 9.965445958077908, 13.188915587961674, 8.619537279009819, 10.292502008378506, 7.525653401389718, 8.805500250309706, 11.72836896032095, 13.962152246385813, 22.078494876623154, 29.804690591990948, 43.893420696258545, 49.47444722056389, 58.42867814004421, 57.89644829928875, 61.10865153372288, 57.850721552968025, 67.70744204521179, 67.33472004532814, 64.98092114925385, 53.81181947886944, 52.24316485226154, 67.46272757649422, 61.32421776652336, 34.76026117801666, 36.53845556080341, 38.4498555958271, 36.90488509833813, 28.33798449486494, 54.414558336138725, 51.00834511220455, 38.960236608982086, 62.83596284687519, 54.14185456931591, 64.61886137723923, 62.46201731264591, 54.423886835575104, 50.64158119261265, 53.4443411976099, 47.085397616028786, 44.14414644241333, 40.06712481379509, 38.77736762166023, 38.658380806446075, 39.86906424164772, 33.12988266348839, 27.819633409380913, 31.367696821689606, 23.524796068668365, 10.841046273708344, 6.037286091595888, 5.258980980142951, 10.708657577633858, 2.3691617092117667, 4.720585495233536, 6.102494867518544, 11.832534670829773, 2.1333553874865174, 2.1477359533309937, 2.9227122059091926, 5.1394707430154085, 1.5790653554722667, 0.23224056931212544, 0.1419448567321524, 0.11733976687537506, 0.055544191200169735, 0.01575854854309, 2.230498599819839, 11.844215244054794, 31.258481182157993, 40.86995333433151, 56.62985846400261, 52.414353266358376, 39.19065624475479, 20.956396088004112, 32.170084565877914, 25.703287571668625, 17.016467303037643, 27.994707114994526, 44.278549030423164, 57.543188855051994, 49.98158320784569, 50.4959350079298, 11.85901639983058, 0.8859089843463153, 0.27852487633936107, 0.08717555305338465, 0.0590837791969534, 0.06593864105525427, 0.06835254316683859, 0.048052626007120125, 0.03733051795279607, 0.12900190515210852, 0.0777418764482718, 0.045883536149631254, 0.06538994901347905, 0.10919716747594066, 0.07613830312038772, 0.07042385506792925, 0.03235368676541839, 0.04239826223056298, 0.021265698051138315, 0.04497279107454233, 0.07499189276131801, 0.03292997927928809, 0.017937557204277255, 0.07776103127980605, 0.05166416151041631, 0.012042322905472247, 0.04362927000329364, 0.04263576433004346, 0.021480744617292657, 0.007264308906087535, 0.11098083035903983, 0.08907228955649771, 0.019886212503479328, 0.026001474107033573, 0.08264491960289888, 0.005504701812242274, 0.06701270685880445, 0.04123654136492405, 0.031830160951358266, 0.024795946119411383, 0.047420657574548386, 0.02607606365927495, 0.0648838488268666, 0.05010974804463331, 0.013989669241709635, 0.0654664941248484, 0.038583422792726196, 0.061717961871181615, 0.06345426460029557, 0.04813454426766839, 0.03561685072781984, 0.05683348725142423, 0.002151367834812845, 0.09473892103414983, 0.03660109439806547, 0.06551563172251917, 0.06413998678908683, 0.06624791625654325, 0.13749336590990424, 0.027308531607559416, 0.4258249222766608, 10.182197727262974, 51.601288095116615, 79.44441184401512, 71.0615448653698, 65.3407010436058, 59.08915489912033, 38.78244034945965, 29.786286279559135, 27.14140970259905, 24.621932096779346, 37.705068960785866, 33.11177283525467, 25.95890935510397, 40.90482406318188, 19.265747107565403, 3.6545021133497357, 0.8239321724977344, 0.06132996335509233, 0.365233522024937, 0.49716324429027736, 2.011709902435541, 6.325022801756859, 7.175211030989885, 8.069519642740488, 8.402689564973116, 10.293194521218538, 10.983067452907562, 13.26556222513318, 12.70922552794218, 14.332012049853802, 13.71514555066824, 11.625823862850666, 9.946435578167439, 9.805499240756035, 9.685761965811253, 7.88716172799468, 5.8116033766418695, 6.208747141063213, 7.571277553215623, 11.916169133037329, 14.283671993762255, 23.509486690163612, 32.07911744713783, 48.05767044425011, 53.57859939336777, 64.10066798329353, 61.58392623066902, 64.59600180387497, 60.267414674162865, 67.05070808529854, 65.19891545176506, 69.75913435220718, 58.378661423921585, 56.00234493613243, 68.03456649184227, 63.60937714576721, 42.271922305226326, 43.409763649106026, 45.576130002737045, 43.90942543745041, 38.52117016911507, 58.5862822830677, 55.42659603059292, 43.58660615980625, 65.23621425032616, 57.53591984510422, 68.94537761807442, 65.45866191387177, 59.24987867474556, 54.257759749889374, 57.03012518584728, 49.94736984372139, 47.22182169556618, 44.355460703372955, 42.458560690283775, 41.90809562802315, 41.013342440128326, 35.45585185289383, 31.01204350590706, 31.961665749549866, 22.15248640626669, 11.067459024488926, 6.850663321092725, 4.808874232694507, 6.137983538210392, 4.615243272855878, 10.12055553495884, 6.233338946476579, 4.872299004346132, 8.75672321766615, 7.473863605409861, 5.921330088749528, 7.281883182004094, 3.9496581628918648, 0.8787323569413275, 0.444158433820121, 0.045980241702636704, 0.0542266861157259, 0.08517497524735518, 2.375253257341683, 12.66360517591238, 32.29624539613724, 38.835090324282646, 40.07401384413242, 29.95662733912468, 27.120450027287006, 24.12365533411503, 37.86504037678242, 32.67084829509258, 27.364341840147972, 39.456353187561035, 50.92721186578274, 67.12969824671745, 56.64273977279663, 62.5032526999712, 18.627248369157314, 1.185460863634944, 0.022075277265685145, 0.07499023035052232, 0.05641537980409339, 0.040432602472719736, 0.075039657385787, 0.049776007945183665, 0.03382157694431953, 0.06527553210617043, 0.020277867952245288, 0.006078564720155555, 0.048780717406771146, 0.033984444962698035, 0.1032991120882798, 0.0627022166736424, 0.030787714349571615, 0.008672022504470078, 0.05446235882118344, 0.022027675913705025, 0.07061148484353907, 0.061093188560334966, 0.02899805120250676, 0.06216623020009138, 0.058229311180184595, 0.031915745421429165, 0.06998746481258422, 0.04859263863181695, 0.008751663299335632, 0.03802362080023158, 0.06512267194921151, 0.027577558284974657, 0.08415437376243062, 0.09423523282748647, 0.19809459219686687, 0.10914163998677395, 0.11143725118017755, 0.18487805529730394, 0.12382279048324563, 0.15957996278302744, 0.11522840868565254, 0.2007409423822537, 0.20623810443794355, 0.16468518180772662, 0.08332140205311589, 0.1485485164448619, 0.1549943065037951, 0.1896322236279957, 0.30881186365149915, 0.17154795496026054, 0.12866994249634445, 0.17495516978669912, 0.10829576232936233, 0.14159520127577707, 0.18411932804156095, 0.15779865992954, 0.26998804067261517, 0.2844300860306248, 0.21343046537367627, 0.3482499474193901, 0.8550602803006768, 15.05126690492034, 61.374823451042175, 89.25894320011139, 81.08536139130592, 75.8272035419941, 70.55246338248253, 45.90361922979355, 38.02406184375286, 33.665520921349525, 38.490220829844475, 62.543595135211945, 41.55299708247185, 32.770999521017075, 50.237130895256996, 21.180135682225227, 5.721666952595115, 1.6564731393009424, 0.16320720955263823, 0.30422637064475566, 0.24841403035679832, 1.2248456315137446, 6.680502276867628, 12.593875117599964, 14.749026373028755, 12.428607735782862, 22.081027440726757, 22.36671321094036, 18.02518967539072, 22.697342969477177, 18.605912514030933, 20.98189651966095, 17.847883589565754, 19.00114830583334, 22.46009700000286, 24.71707709133625, 15.785325765609741, 17.64376614242792, 14.027774725109339, 15.42632007971406, 19.688919000327587, 21.83464676141739, 29.695826433598995, 38.595988154411316, 50.849319845438, 54.33766946196556, 62.70443670451641, 63.569616079330444, 65.38420870900154, 64.19847473502159, 70.25294825434685, 68.48356559872627, 73.70409026741982, 59.83170725405216, 58.54275941848755, 74.94427531957626, 68.60540226101875, 47.41730980575085, 51.2433473020792, 50.41570611298084, 51.70024238526821, 41.341462433338165, 64.77770805358887, 62.080586180090904, 45.96843235194683, 63.95847201347351, 61.92148871719837, 73.36220741271973, 67.4703423678875, 59.39295619726181, 55.497492626309395, 60.28377279639244, 52.76420809328556, 50.45819543302059, 45.13593502342701, 46.81886851787567, 47.319689244031906, 46.7222511023283, 39.98624235391617, 33.20880062878132, 37.71537020802498, 28.760253936052322, 14.21963308006525, 10.71247162297368, 12.904930226504803, 20.58769427239895, 12.578002419322729, 17.735873199999332, 15.243813022971153, 20.92855118215084, 11.17187837138772, 9.126269537955523, 11.342981290072203, 12.2132533416152, 3.804689054377377, 0.32738752313889563, 0.31304934876970947, 0.12291619772440754, 0.21622766449581832, 0.29396787111181766, 3.3090229891240597, 19.266003593802452, 42.560836002230644, 54.7739202529192, 73.11519026756287, 71.59546181559563, 53.07381168007851, 32.336382642388344, 43.90251360833645, 39.1167426109314, 30.26594404131174, 43.659919425845146, 61.44598223268986, 77.95363023877144, 67.38280266523361, 76.25987872481346, 28.336865454912186, 2.1288778027519584, 0.3583478758810088, 0.2155710567603819, 0.2843165077501908, 0.33881226321682334, 0.2336474586627446, 0.13855282624717802, 0.17057691409718245, 0.30831560434307903, 0.17513996455818415, 0.16415398218668997, 0.11840129038318992, 0.3460859338520095, 0.23174468107754365, 0.16458493249956518, 0.11345151418936439, 0.12558722432004288, 0.14436266996199265, 0.12020323978504166, 0.23320950247580186, 0.3308520169230178, 0.12745786691084504, 0.24857549200532958, 0.15894983487669379, 0.09903392259730026, 0.1990432944148779, 0.15053376147989184, 0.0917425294755958, 0.14394176832865924, 0.16622659284621477, 0.23302565765334293], [0.015309474983951077, 0.0517934362142114, 0.04106163942196872, 0.05963547322608065, 0.013334452105482342, 0.047474374223384075, 0.02224788040621206, 0.009805848821997643, 0.04177585266006645, 0.02938416466349736, 0.05120718778925948, 0.034237209329148754, 0.06829452206147835, 0.026338552015658934, 0.015335117113863816, 0.10279419933794998, 0.044708397253998555, 0.0364468724001199, 0.061990085159777664, 0.13997344532981515, 0.006042675386197516, 0.041340560783282854, 0.04152746325416956, 0.034805074756150134, 0.07277451877598651, 0.040328894756385125, 0.05440971828647889, 0.10084560897666961, 1.1530284164473414, 27.760305292904377, 69.16361510753632, 69.27877932786942, 68.02068963646889, 51.02292113006115, 46.0315165668726, 48.73689919710159, 28.30599971115589, 29.670194908976555, 34.96826961636543, 42.699661552906036, 25.191460736095905, 36.5751463919878, 15.776475090533495, 3.495220597833395, 0.22108171106083319, 0.040523155621485785, 0.025298417203885037, 0.14555251080309972, 0.47230812488123775, 2.086360934190452, 2.830659057945013, 7.616343135014176, 7.840618025511503, 7.486688392236829, 9.278335478156805, 7.551179006695747, 4.719880158081651, 10.954007562249899, 7.54856332205236, 6.366024976596236, 10.158489849418402, 8.869512565433979, 9.567437265068293, 6.096624182537198, 6.600811528041959, 5.324506089091301, 12.879126761108637, 16.40595406293869, 26.74142226576805, 33.14876385033131, 46.33496068418026, 51.67595788836479, 60.24901606142521, 58.042900040745735, 65.07201746106148, 64.72397133708, 64.33263793587685, 61.61484137177467, 72.23673820495605, 54.97255079448223, 56.68681740760803, 65.0812129676342, 71.3096259534359, 67.64550536870956, 62.773478999733925, 41.78161941468716, 31.54527459293604, 43.30914884805679, 36.551929637789726, 32.968144342303276, 57.18033492565155, 53.7328939139843, 60.47079496085644, 62.96686202287674, 61.81180000305176, 67.85261705517769, 59.45925883948803, 56.57544918358326, 51.52226373553276, 58.396129086613655, 62.57026210427284, 61.16804614663124, 59.91092920303345, 55.77252946794033, 55.81684269011021, 62.90004640817642, 57.64590494334698, 51.02029927074909, 41.27500779926777, 36.985866352915764, 31.515113711357117, 23.23341630399227, 21.55057780444622, 17.945177368819714, 3.433348755352199, 5.566279040649533, 8.754193503409624, 9.93402449414134, 7.057878552004695, 5.070310654118657, 1.7986008315347135, 4.388418719172478, 4.167957399040461, 1.5933389333076775, 0.6601144722662866, 0.17507438838947564, 0.03699743465404026, 0.08066631678957492, 0.16868768812855706, 1.2906596437096596, 8.293671514838934, 28.562750034034252, 44.26252909004688, 46.3588348031044, 41.725990399718285, 47.389962673187256, 52.49115474522114, 48.05435702204704, 28.0852809548378, 32.60733850300312, 37.24592059850693, 42.44952857494354, 54.77631792426109, 53.82444240152836, 40.306686758995056, 7.98961753025651, 0.08869977595168166, 0.07509363378630951, 0.0034202223559987033, 0.0482604496210115, 0.060090825354564004, 0.09891150533803739, 0.05907785685849376, 0.01747459806210827, 0.09943724275217392, 0.05736581493692938, 0.040289761309395544, 0.048238029339700006, 0.0327828670560848, 0.07344409183133394, 0.03199706625309773, 0.0641710456693545, 0.028482301240728702, 0.05938227470323909, 0.018213124058092944, 0.0290723828584305, 0.08421120743150823, 0.055041245141183026, 0.022955802087381016, 0.019318857303005643, 0.04891638571280055, 0.03583482692192774, 0.023844700190238655, 0.05508590387762524, 0.050569271043059416, 0.013013135558139766, 0.024266826367238536, 0.019888181050191633, 0.021762942560599186, 0.022210520692169666, 0.04016229373519309, 0.07381005969364196, 0.023395988428092096, 0.03919363516615704, 0.018136916623916477, 0.04564481321722269, 0.055252434394788, 0.01494165268013603, 0.035298580696689896, 0.018208697147201747, 0.0339293664728757, 0.05856518124346621, 0.020401322362886276, 0.012217139501444763, 0.08180745047866367, 0.06776793117751367, 0.09301661892095581, 0.027694346354110166, 0.08101674407953396, 0.0275524514290737, 0.08390439616050571, 0.031261835392797366, 0.03851547546219081, 0.0696112924197223, 1.7442244431003928, 34.32481214404106, 81.5360476076603, 77.65695735812187, 72.6611678302288, 59.848946928977966, 54.76871073246002, 52.82243996858597, 33.01285274326801, 34.95134152472019, 34.489810690283775, 44.42990630865097, 25.174310356378555, 32.51015491783619, 20.032859444618225, 3.865121486596763, 0.3010500082746148, 0.05305919505190104, 0.32956970448140055, 0.33270610962063074, 1.1872961651533842, 4.679572395980358, 6.27291239798069, 8.715692069381475, 12.062381487339735, 8.184733260422945, 8.556406516581774, 11.752145234495401, 11.476585920900106, 13.69581313803792, 13.296835497021675, 11.01072046905756, 6.381174763664603, 9.647971093654633, 11.033995170146227, 5.8650807570666075, 6.598669867962599, 5.975505206733942, 12.605886273086071, 15.397933702915907, 24.069105461239815, 36.99576862156391, 48.27191814780235, 53.51277932524681, 60.44036999344826, 59.96643662452698, 64.51280146837234, 68.95978644490242, 66.58278599381447, 63.48069325089455, 71.04410380125046, 59.00782786309719, 59.91667829453945, 66.89724192023277, 72.83573046326637, 67.18329817056656, 64.35287564992905, 46.407540589571, 37.856069058179855, 49.26353953778744, 42.697172686457634, 38.1750163435936, 59.01141867041588, 56.546513736248016, 63.344740346074104, 64.69761595129967, 62.85684272646904, 68.79694998264313, 62.62083739042282, 58.94850544631481, 51.80985890328884, 58.26214447617531, 63.84311780333519, 62.8999400138855, 59.83462929725647, 55.0477259606123, 56.89320333302021, 64.87595558166504, 62.330365777015686, 54.975187852978706, 46.59034498035908, 41.40891261398792, 34.17267210781574, 26.455453410744667, 22.66993124037981, 15.665542893111706, 9.684758819639683, 7.6271469052881, 2.278544884175062, 7.733533596619964, 8.675493076443672, 5.474883494898677, 6.6126450430601835, 9.04321264475584, 8.628880977630615, 4.332413524389267, 1.4968828903511167, 0.5309300730004907, 0.11395243418519385, 0.1877953190705739, 0.10888855278608389, 1.1621418711729348, 8.138627484440804, 30.073393173515797, 47.41396598517895, 50.082030817866325, 41.735269501805305, 34.89980109035969, 47.16638267040253, 49.57258455455303, 32.37115457653999, 40.87083488702774, 48.518927693367004, 50.53104892373085, 64.96683150529861, 62.55125172436237, 49.533416256308556, 9.527920335531235, 0.05209131944866385, 0.08525757628376596, 0.01914691281854175, 0.07018713222350925, 0.028865375606983434, 0.07819994483725168, 0.0044580333178600995, 0.020649448306357954, 0.09992277060518973, 0.0477108039194718, 0.07368572027189657, 0.04336536228947807, 0.05454488564282656, 0.03281943638285156, 0.0355661100911675, 0.028553714400914032, 0.05550377012696117, 0.045021880432614125, 0.03733882258529775, 0.030092108609096613, 0.04727809100586455, 0.06911222037160769, 0.07157805797760375, 0.04275533174222801, 0.04943107996950857, 0.07925196143332869, 0.03597640272346325, 0.023052463111525867, 0.05219960250542499, 0.04191998887108639, 0.09188670650473796, 0.16890975355636328, 0.08668355367262848, 0.15131868654862046, 0.13459998444886878, 0.1333741791313514, 0.08946475209086202, 0.09162187852780335, 0.17206446005729958, 0.10616500439937226, 0.17018338287016377, 0.14887225610436872, 0.13295099168317392, 0.17922027764143422, 0.1791748878895305, 0.23735179973300546, 0.16699967323802412, 0.15808432741323486, 0.30090760497841984, 0.17680846096482128, 0.1283010357292369, 0.19018601422430947, 0.14621251757489517, 0.14112414530245587, 0.1302791413036175, 0.09404933225596324, 0.19497218396281824, 0.259082744596526, 2.8395724296569824, 43.26222896575928, 92.98619359731674, 87.62043312191963, 83.82857859134674, 69.07548263669014, 59.717170000076294, 62.97862999141216, 42.45533846318722, 43.57795022428036, 53.72048757970333, 60.171329230070114, 35.98281517624855, 49.875496700406075, 22.008396238088608, 5.276354122906923, 0.49688998551573604, 0.08930013631470501, 0.3159492462873459, 0.2608865493675694, 0.8954195177648216, 6.747854612767696, 9.468140993267298, 17.79187649488449, 18.546833284199238, 20.235874950885773, 19.381490796804428, 17.177521660923958, 13.743990752846003, 22.36673031002283, 18.07685360312462, 13.94137591123581, 19.967926628887653, 17.440959624946117, 19.127877205610275, 14.333914797753096, 14.844315759837627, 11.725158132612705, 17.9787390679121, 22.93862622231245, 33.07104282081127, 39.704647064208984, 53.52722615003586, 53.535832688212395, 61.36215493083, 60.5044611543417, 67.22484514117241, 68.66008892655373, 67.01667711138725, 63.05456131696701, 72.41749450564384, 61.45088776946068, 62.289951145648956, 66.57479122281075, 70.21110489964485, 71.12576141953468, 67.26499378681183, 49.61828090250492, 42.642987594008446, 55.305040553212166, 47.9653126001358, 44.99797962605953, 63.79087820649147, 59.784236401319504, 63.94744500517845, 64.86268669366837, 63.4454121440649, 68.61758440732956, 63.15180569887161, 60.02163626253605, 55.018516927957535, 59.7590209543705, 65.92403814196587, 63.48736569285393, 60.35830579698086, 56.2256133556366, 58.31159882247448, 68.05966034531593, 66.06190994381905, 60.265305787324905, 49.62434157729149, 46.90753296017647, 36.22632510960102, 28.29394105821848, 28.2675476744771, 27.560931891202927, 12.913870196789503, 14.673495925962925, 21.036226004362106, 24.683467894792557, 17.63496771454811, 9.975677859038115, 8.156485576182604, 14.377872738987207, 13.246437851339579, 5.261174887418747, 1.4597538951784372, 0.2961297769797966, 0.1435960759408772, 0.17133671004557982, 0.66362144658342, 1.915196506306529, 11.521770246326923, 39.92051728069782, 59.45767432451248, 60.67852221429348, 56.704098880290985, 62.218792364001274, 67.1664422750473, 63.29382687807083, 41.80399641394615, 46.74273580312729, 51.473774537444115, 58.00584062933922, 75.12854263186455, 72.89205104112625, 59.54201079905033, 13.835282754153013, 0.2423912941594608, 0.21488756843609735, 0.1256400503916666, 0.18689979915507138, 0.09409495949512348, 0.21989424509229138, 0.13758387824054807, 0.1459081331267953, 0.2914258075179532, 0.19014206423889846, 0.18155789439333603, 0.23952566902153194, 0.16156517813215032, 0.1156760573212523, 0.11037130447220989, 0.1872978574829176, 0.16188954119570553, 0.17885077715618536, 0.11121035437099636, 0.12001277500530705, 0.0970863712427672, 0.19194705644622445, 0.09804535962757654, 0.1826099629397504, 0.10016232103225775, 0.15224208153085783, 0.10231665699393488, 0.17329238791717216, 0.19768761325394735, 0.12044389601214789], [0.04165827420365531, 0.02188872360420646, 0.04647005545848515, 0.026435647196194623, 0.06966072687646374, 0.021409119945019484, 0.11502770968945697, 0.1269079651683569, 0.07185803318861872, 0.06978735953452997, 0.052998134851804934, 0.033701924185152166, 0.03021334770892281, 0.041929544022423215, 0.06586141316802241, 0.03401669498998672, 0.03211820701835677, 0.012894569117634092, 0.04917814119835384, 0.060186510454514064, 0.044315422637737356, 0.03585055674193427, 0.004215692415527883, 0.02900264324125601, 0.04546335439954419, 0.07419540503178723, 0.026246009911119472, 0.3688874118961394, 12.840948309749365, 57.0321998745203, 75.29903948307037, 63.95188316702843, 53.369698002934456, 38.78989934921265, 38.92334818840027, 34.78907123208046, 21.851158775389194, 30.690428763628006, 38.821076676249504, 26.33046481758356, 39.47674289345741, 20.224238075315952, 2.3247722536325455, 0.4617525584762916, 0.025862955953925848, 0.10968522605253384, 0.09436304550035857, 0.9664964850526303, 2.513921116478741, 4.94118170812726, 6.719528557732701, 4.031120091676712, 4.422142384573817, 7.389449710026383, 9.486685898154974, 11.594607587903738, 14.094570390880108, 11.479081436991692, 12.818689104169607, 12.513035405427217, 4.456127285957336, 7.835402330383658, 7.255396703258157, 9.776180014014244, 15.58688996359706, 18.133675754070282, 28.475140035152435, 33.13857659697533, 47.638883516192436, 55.694002881646156, 64.45373743772507, 64.75674837827682, 63.61223839223385, 60.80145701766014, 67.15787753462791, 65.15711009502411, 64.64095339179039, 63.3785243332386, 60.083922520279884, 64.03037175536156, 60.27046591043472, 60.58271795511246, 69.41486522555351, 64.95020359754562, 61.33220113813877, 52.21066899597645, 32.103508338332176, 38.53933319449425, 31.41274720430374, 47.89573833346367, 57.07737945020199, 58.66857826709747, 63.47551792860031, 66.60996973514557, 60.90785130858421, 61.23953551054001, 61.10730640590191, 57.675520554184914, 64.1487430036068, 63.13427343964577, 59.48126345872879, 64.87809106707573, 64.88665580749512, 62.2141832113266, 65.29091611504555, 65.4333932697773, 62.70736634731293, 62.86437392234802, 62.15742565691471, 51.65915139019489, 48.020614832639694, 45.23457773029804, 38.25604699552059, 26.459823176264763, 21.267173811793327, 19.116249829530716, 10.27707103639841, 2.170908534899354, 5.523409266024828, 8.614398054778576, 5.46071975491941, 5.1825224328786135, 4.548235293477774, 5.366194602102041, 1.7438056343235075, 0.35383208538405597, 0.05146453491761349, 0.13956806942587718, 0.11289570495137013, 0.07322178149479441, 1.1778309918008745, 6.579355029389262, 24.483260437846184, 33.935861214995384, 34.59485985338688, 60.95434941351414, 91.85741856694221, 70.14454007148743, 49.48326274752617, 20.008573047816753, 15.574532076716423, 32.74209447205067, 48.54807212948799, 53.32869440317154, 55.71300186216831, 22.867877818644047, 0.9668293234426528, 0.09407075063791126, 0.05939650538493879, 0.06558701148605905, 0.043968453755951487, 0.03977131920692045, 0.07379145405138843, 0.046851311562932096, 0.0741656226455234, 0.07040660013444722, 0.018326193967368454, 0.059823269984917715, 0.08660186547785997, 0.05247101704298984, 0.019379828445380554, 0.052319322057883255, 0.024216525453084614, 0.022053647371649276, 0.06438973432523198, 0.02613443914015079, 0.04443965444806963, 0.027262581534159835, 0.048039441753644496, 0.0337043510080548, 0.009900789918901864, 0.073967365315184, 0.03412656995351426, 0.05418291795649566, 0.07678900336031802, 0.008250795253843535, 0.06091260176617652, 0.009723686580400681, 0.04068715170433279, 0.04117538468562998, 0.04604994050168898, 0.03600356532842852, 0.05538054392673075, 0.09971669103833847, 0.03738827188499272, 0.014636737596447347, 0.08432358343270607, 0.03252637710829731, 0.03479638049611822, 0.039978563945624046, 0.05926885969529394, 0.07716844862443395, 0.02221712209575344, 0.0400504149729386, 0.010321211939299246, 0.040660222875885665, 0.09717177017591894, 0.014951805260352558, 0.06527748395456001, 0.05781954176200088, 0.07959395050420426, 0.033894107036758214, 0.031611223676009104, 0.36131655564531684, 17.511358447372913, 67.47956827282906, 83.8378956913948, 72.19231858849525, 64.14747387170792, 47.30738930404186, 46.223174482584, 43.30947943031788, 28.932563289999962, 29.50369544327259, 38.05575214326382, 31.43979985266924, 33.48532699048519, 21.78112853318453, 3.332974766381085, 0.3361071349354461, 0.0761738297296688, 0.44017128995619714, 0.21389191795606166, 2.209959989413619, 3.6802027467638254, 7.2017046343535185, 11.543245743960142, 8.838007505983114, 8.491774834692478, 13.341575246304274, 6.593532068654895, 12.730821669101715, 8.830470610409975, 11.508932635188103, 10.191656369715929, 8.756195046007633, 4.05771248973906, 6.03737966157496, 6.266123112291098, 8.332829363644123, 15.001508574932814, 20.265296772122383, 28.213520273566246, 34.0985456854105, 47.550013884902, 55.83231545984745, 65.7257267832756, 66.81711941957474, 65.48829272389412, 63.68993662297726, 67.75843530893326, 65.21038323640823, 65.51381215453148, 66.52537867426872, 61.921739503741264, 65.147245824337, 61.34257458150387, 61.532864570617676, 67.99966916441917, 64.58972454071045, 59.80350896716118, 56.12248308956623, 39.109845981001854, 43.865799978375435, 39.255883544683456, 51.59726411104202, 60.02798952162266, 61.79352678358555, 64.81698274612427, 64.40548002719879, 62.85585857927799, 61.9549535214901, 60.413174852728844, 59.066314324736595, 65.39187669754028, 65.47839045524597, 61.19877129793167, 64.81807708740234, 67.34792053699493, 62.89656959474087, 64.92234349250793, 68.10522750020027, 65.21268591284752, 66.62755519151688, 62.94737286865711, 56.388275027275085, 53.49888727068901, 46.587726920843124, 39.782295897603035, 29.604576230049133, 22.29671336710453, 20.347672551870346, 14.153400734066963, 6.068526590242982, 7.974039316177368, 7.636961303651333, 10.78570319339633, 8.615364152938128, 8.841594513505697, 13.72204028069973, 6.380907353013754, 2.2427740786224604, 0.7209552044514567, 0.20360392547445372, 0.09112630199524574, 0.05379802161769476, 0.49019655562005937, 6.217491896823049, 25.6705105304718, 32.10139185190201, 32.91777804493904, 55.091150030493736, 81.02429866790771, 68.6398284137249, 55.62116838991642, 29.928480349481106, 20.67232333123684, 39.439178109169006, 56.06261350214481, 61.07862174510956, 62.96848073601723, 27.55502510815859, 1.3012605998665094, 0.11275025142822415, 0.03982909911428578, 0.023564977309433743, 0.047254431337933056, 0.03658342015114613, 0.01707572151644854, 0.03188119473634288, 0.12693156546447426, 0.012306903190619778, 0.00513308342306118, 0.05558870150707662, 0.025136638287222013, 0.08388869231566787, 0.018179881408286747, 0.04713119771622587, 0.02831957423040876, 0.042796365087269805, 0.0292887448813417, 0.02279062227898976, 0.03030509386007907, 0.04635697441699449, 0.03153202909743413, 0.05390015598095488, 0.016045642805693205, 0.034738826943794265, 0.007876541312725749, 0.07622117132996209, 0.03716641054779757, 0.04182535762083717, 0.1934228913160041, 0.16041875293012708, 0.15181006252532825, 0.21018471219576895, 0.20213987590977922, 0.1535071019316092, 0.22990592115093023, 0.3153107617981732, 0.1344079611590132, 0.1290619745850563, 0.3181354352273047, 0.17278814309975132, 0.13308986235642806, 0.1496102477540262, 0.24168582342099398, 0.16455092729302123, 0.13720419548917562, 0.17101880366681144, 0.12737416749587283, 0.22561550606042147, 0.16282948607113212, 0.22393295337678865, 0.17329372378299013, 0.2426342584658414, 0.17213000654010102, 0.1892926762229763, 0.14486805768683553, 0.7762491249013692, 23.27671878039837, 81.8699660897255, 93.15996587276459, 81.668371707201, 73.39584320783615, 53.62695559859276, 53.71673338115215, 46.347553208470345, 31.42378371208906, 43.89803744852543, 52.88245774805546, 37.74550639092922, 51.266400665044785, 26.915527023375034, 3.9585753343999386, 0.9092432947363704, 0.23928024078486487, 0.630141799338162, 0.15497322950977832, 3.3695254800841212, 6.523853307589889, 13.36927480995655, 15.180820003151894, 15.988065786659718, 13.70556816458702, 17.07074549049139, 17.000758945941925, 19.350984133780003, 24.377229027450085, 20.87465677410364, 23.986579589545727, 21.904103234410286, 14.119361210614443, 22.09130398929119, 12.771925013512373, 17.101527638733387, 23.76520536839962, 24.0910454839468, 33.52346554398537, 38.1611280888319, 52.259142994880676, 57.910249158740044, 66.48484244942665, 69.74363878369331, 70.91776818037033, 64.91432592272758, 72.22508043050766, 68.21207016706467, 68.83433237671852, 65.70364236831665, 65.74848756194115, 64.62769210338593, 65.36680564284325, 63.51524479687214, 67.57002621889114, 64.40961420536041, 63.09609308838844, 58.788074254989624, 44.681361615657806, 49.35835964977741, 44.95840094983578, 58.46403904259205, 62.81702846288681, 64.44329559803009, 64.99786823987961, 65.71076318621635, 64.05144542455673, 62.09011606872082, 61.1099548637867, 61.37099325656891, 65.1046273112297, 67.78348356485367, 64.27899241447449, 68.05160477757454, 68.67930829524994, 65.1409837603569, 67.0494693517685, 70.95816761255264, 66.35358989238739, 70.31897351145744, 68.55234950780869, 61.58020243048668, 58.193694949150085, 52.57688194513321, 44.22384716570377, 31.161842867732048, 28.299942836165428, 25.471955984830856, 14.99422151595354, 7.726121144369245, 17.219408713281155, 23.507584892213345, 17.142489440739155, 14.50452184304595, 15.306444112211466, 12.732294090092182, 5.763482758775353, 1.3952505751512945, 0.5724234308581799, 0.34624362539034337, 0.28835981735028327, 0.26977629109751433, 1.8911512778140604, 9.290753211826086, 35.03497503697872, 46.31019741296768, 45.28178259730339, 66.84721380472183, 95.67157790064812, 78.29147771000862, 61.95172369480133, 30.555534102022648, 29.130241982638836, 49.31726485490799, 63.98468300700188, 71.96521237492561, 72.65581771731377, 33.46013814210892, 2.1637140959501266, 0.1781417292659171, 0.15877568250289187, 0.1725361542776227, 0.08270444726804271, 0.10471892222994938, 0.1361279923003167, 0.1328051893506199, 0.20435405866010115, 0.12308921461226419, 0.06840557703981176, 0.17056875047273934, 0.115261857281439, 0.1241956974263303, 0.11846902620163746, 0.08733790527912788, 0.1372571403044276, 0.12601842696312815, 0.15740487637231126, 0.11753214639611542, 0.10470127395819873, 0.2001055600703694, 0.1894938130863011, 0.16193938383366913, 0.13262710359413177, 0.20686784642748535, 0.19230854173656553, 0.2540034562116489, 0.2082683236221783, 0.06640665422310121], [0.04377265664516017, 0.08278479959699325, 0.020506063519860618, 0.035132788616465405, 0.05271420028293505, 0.040133105067070574, 0.04990981346054468, 0.03502805302559864, 0.025140829566225875, 0.03377644323336426, 0.025106265893555246, 0.019452037558949087, 0.027067643459304236, 0.04507260622631293, 0.04649597867683042, 0.05509670212632045, 0.07511195741244592, 0.05219391765422188, 0.03370601341885049, 0.01442724043954513, 0.05635323606838938, 0.02947972545371158, 0.021813553321408108, 0.02663439434400061, 0.05663737472787034, 0.02578054045443423, 0.10736416661529802, 4.223422547802329, 41.175532937049866, 68.45813736319542, 65.69319292902946, 55.222812965512276, 45.843434259295464, 40.05073629319668, 19.789974577724934, 19.607282280921936, 22.65399869531393, 40.75711838901043, 36.68995723128319, 36.13639533519745, 27.064959704875946, 3.0775054497644305, 0.30055674724280834, 0.017314960241492372, 0.08145310464897193, 0.15478695044294, 1.095661350991577, 0.9709895658306777, 0.7613999373279512, 3.9601301634684205, 8.404759503901005, 4.941848097369075, 9.80046071112156, 7.742518214508891, 2.461591986939311, 10.578220076858997, 8.37315184995532, 11.611812114715576, 13.428400587290525, 10.422104503959417, 4.8190258629620075, 11.534754149615765, 25.98292026668787, 24.786831848323345, 32.079026252031326, 36.657077595591545, 48.79160866141319, 55.46941973268986, 59.15283188223839, 59.845857694745064, 62.23092511296272, 61.011509746313095, 60.13930454850197, 59.04326096177101, 61.80739223957062, 62.8717303276062, 66.7140993475914, 59.73852105438709, 65.09412467479706, 62.92296677827835, 59.419167190790176, 59.810675382614136, 60.95483958721161, 64.4028277695179, 59.19959977269173, 58.71024303138256, 38.97145740687847, 36.38997472822666, 28.08357484638691, 45.429142490029335, 58.389988616108894, 55.84432661533356, 63.478059992194176, 52.76028290390968, 59.71243165433407, 59.680786952376366, 59.06412564218044, 60.317135006189346, 61.38219505548477, 59.39847730100155, 61.04085937142372, 59.59119535982609, 62.75075241923332, 62.22458325326443, 65.24160996079445, 62.532670721411705, 61.74697548151016, 56.00949615240097, 59.23855908215046, 62.9857812076807, 60.033313035964966, 47.61040024459362, 55.672602429986, 43.84549766778946, 46.47184073925018, 38.58424298465252, 21.432217955589294, 14.83381787315011, 6.042635729536414, 8.817720394581556, 7.485297666862607, 6.0889433696866035, 8.631996810436249, 4.696603557094932, 2.0635528955608606, 2.6670027896761894, 0.8395924977958202, 0.16898450267035514, 0.02868146213586442, 0.053255916136549786, 0.0337240921362536, 0.9517730469815433, 11.964550036936998, 45.27301266789436, 60.425885170698166, 78.68016645312309, 92.41629257798195, 82.20313221216202, 47.527773678302765, 15.43193332850933, 21.14022072404623, 26.465216986835003, 40.42352668941021, 50.8627787232399, 62.32096888124943, 37.587750256061554, 5.1490419544279575, 0.02953578543383628, 0.07963310621562414, 0.01932970008056145, 0.04539616405963898, 0.052168758847983554, 0.02225832056865329, 0.023123234313970897, 0.038906761692487635, 0.014860727969789878, 0.04419577730004676, 0.05077099420304876, 0.025787961931200698, 0.03474515375273768, 0.01572735793160973, 0.05321759534126613, 0.11675850197207183, 0.03527222703269217, 0.01984376536711352, 0.05741714558098465, 0.04056080477312207, 0.0181534665171057, 0.02387973141594557, 0.00834603877592599, 0.032801903143990785, 0.06083865046093706, 0.040206859703175724, 0.021784989912703168, 0.019659195095300674, 0.04775072775373701, 0.025210316853190307, 0.05412440332293045, 0.040404256142210215, 0.02939459740446182, 0.06058142207621131, 0.0478726774599636, 0.05723874441173393, 0.010898643649852602, 0.05950151557044592, 0.063237676222343, 0.023308426134462934, 0.04013132391264662, 0.08131187394610606, 0.056041563730104826, 0.06424933482776396, 0.017902590916492045, 0.014947419167583575, 0.04099498713912908, 0.017476828215876594, 0.06533158652018756, 0.020730694923258852, 0.03775640310777817, 0.07583088328829035, 0.017309895083599258, 0.04024939589726273, 0.051739704722422175, 0.08994849878945388, 5.379927065223455, 47.788546085357666, 75.36361321806908, 74.37548384070396, 62.69577316939831, 56.33578464388847, 46.81409977376461, 35.36393478512764, 30.50592966377735, 27.173595875501633, 39.50098939239979, 36.46578066051006, 32.125049382448196, 25.159772336483, 4.317573895677924, 0.4413187986938283, 0.09612773908884265, 0.06322982429992408, 0.42587767413351685, 3.1575683411210775, 5.504592675715685, 6.200388539582491, 9.973797909915447, 9.9962024576962, 10.85075855255127, 12.409642953425646, 13.891875967383385, 9.954082667827606, 11.611360888928175, 9.646608866751194, 6.190083967521787, 9.230810478329659, 9.246749673038721, 4.770232681185007, 9.999463632702827, 18.92734296619892, 24.35226246714592, 29.89443987607956, 37.37767472863197, 46.48067146539688, 53.51486161351204, 57.6884550601244, 62.524010986089706, 64.25006836652756, 63.034954369068146, 61.788340061903, 62.39090412855148, 64.31958183646202, 65.31079664826393, 67.5695550441742, 62.64424793422222, 66.55869528651237, 64.67570632696152, 60.23366488516331, 61.74450561404228, 60.25887653231621, 63.489223793148994, 60.01191258430481, 61.04239448904991, 43.20883423089981, 42.84099876880646, 34.249097406864166, 48.04376319050789, 60.760358422994614, 58.50501984357834, 64.44040015339851, 56.23989298939705, 59.054257571697235, 59.13161002099514, 60.02102069556713, 61.52892418205738, 64.3697239458561, 61.148720383644104, 62.783829644322395, 62.426090240478516, 64.90508481860161, 64.23199653625488, 66.18695363402367, 65.86942747235298, 64.06006336212158, 58.83861914277077, 62.28747747838497, 63.73286671936512, 62.527183815836906, 53.18212486803532, 56.6902182251215, 44.933436289429665, 44.171531572937965, 35.415965393185616, 25.472256168723106, 16.008409895002842, 11.600476372987032, 10.874531026929617, 10.734794475138187, 14.652826935052872, 9.409336298704147, 12.759221345186234, 10.040422584861517, 9.30903498083353, 3.5751818446442485, 1.0278060170821846, 0.09870156660326757, 0.07679826536332257, 0.04627026559319347, 1.144189853221178, 10.93701297417283, 43.13152737915516, 62.500649839639664, 82.33858734369278, 92.44210079312325, 83.93677398562431, 53.45230557024479, 21.44698966294527, 31.913180351257324, 35.44675514101982, 47.04461060464382, 58.4321815520525, 69.17408734560013, 44.07835677266121, 6.7054650373756886, 0.02440308282530168, 0.05355746558052488, 0.04340097795648035, 0.03430338663747534, 0.04453154717339203, 0.029364022775553167, 0.03643363248556852, 0.013565630179073196, 0.029268196667544544, 0.02562612364272354, 0.03984214235970285, 0.00836551922475337, 0.03834637340332847, 0.02125815226463601, 0.07469443255104125, 0.03830433444818482, 0.08436210089712404, 0.019536809377314057, 0.06822347626439296, 0.02630600141856121, 0.07283251761691645, 0.02919356444181176, 0.020971722224203404, 0.03007158822583733, 0.10820178416906856, 0.02275176899274811, 0.029850973696738947, 0.0322863145993324, 0.018555124261183664, 0.12840314040658996, 0.19043680076720193, 0.15293106174794957, 0.10598991691949777, 0.17331450391793624, 0.18232843664009124, 0.11451418060460128, 0.2728920051595196, 0.17906102759297937, 0.11077823146479204, 0.07610107699292712, 0.09873905990389176, 0.1677579403622076, 0.10602312802802771, 0.21892087388550863, 0.19438685209024698, 0.17023913300363347, 0.13890341680962592, 0.10614849161356688, 0.2055535771069117, 0.14288273843703791, 0.06459781026933342, 0.15993852401152253, 0.16469570546178147, 0.15275974437827244, 0.15117527393158525, 0.17577142833033577, 7.518086107447743, 56.935149282217026, 85.73958724737167, 82.79607519507408, 74.8468865454197, 61.00848890841007, 54.95523512363434, 31.27007056027651, 28.933990113437176, 34.41674821078777, 53.27152267098427, 51.5424482524395, 50.25020219385624, 36.06202572584152, 4.663479784503579, 0.7483614713419229, 0.22368287929566577, 0.1644215264241211, 0.360525218420662, 3.6005369341000915, 4.651114298030734, 10.892839394509792, 15.324246156960726, 16.421434432268143, 11.948257461190224, 21.17325995117426, 16.272311434149742, 11.235888786613941, 21.12683404237032, 15.695821568369865, 21.228660978376865, 24.823866561055183, 19.591408632695675, 11.802621725946665, 18.286066576838493, 33.98334726691246, 31.776963360607624, 36.67678713798523, 41.03572703897953, 53.295898362994194, 56.210132986307144, 61.22181326150894, 62.35270477831364, 67.76068478822708, 64.95011240243912, 64.31094110012054, 64.15453389286995, 66.46205127239227, 66.41194716095924, 70.86192637681961, 63.68965923786163, 67.0487017929554, 65.06753370165825, 63.575482964515686, 63.865126222372055, 61.03424772620201, 65.15400186181068, 60.36845125257969, 61.25726155936718, 47.13786520063877, 47.5831139087677, 39.7423068434, 52.039883360266685, 62.36615605652332, 56.76213316619396, 64.7969426214695, 56.44682988524437, 58.901251181960106, 60.6617347151041, 61.902660727500916, 63.89553979039192, 66.15255028009415, 64.05541241168976, 66.80144906044006, 64.00289162993431, 66.79344668984413, 65.59211075305939, 69.1322211921215, 68.43468502163887, 67.21020832657814, 61.70238487422466, 64.93782386183739, 67.95628309249878, 63.37384678423405, 53.93903665244579, 62.3573025316, 48.5207249969244, 49.982498958706856, 41.553251668810844, 25.357356034219265, 21.93225782364607, 14.503785632550716, 15.802179761230946, 16.7066528275609, 19.421742036938667, 19.389823749661446, 12.231409717351198, 11.091331243515015, 10.127592757344246, 2.1828531939536333, 1.1421727552078664, 0.18607898382470012, 0.16977251507341862, 0.1782168642967008, 1.9763478124514222, 16.09482105821371, 57.25381538271904, 69.68052417039871, 85.843116492033, 94.97941464185715, 89.40976470708847, 54.89653967320919, 27.003648094832897, 35.1274848729372, 39.98526580631733, 57.886435836553574, 67.76864916086197, 80.59565126895905, 53.04393008351326, 8.97649772465229, 0.12295380976866, 0.1502105116378516, 0.08203249934013002, 0.13667036866536364, 0.10342955938540399, 0.10964877175865695, 0.16660246095852926, 0.10226498125120997, 0.1295650319661945, 0.0960475426109042, 0.2059866499621421, 0.09654714158386923, 0.10198953314102255, 0.07767037051962689, 0.2908038877649233, 0.25824168347753584, 0.2041228796588257, 0.1318235506187193, 0.11548222319106571, 0.14075485261855647, 0.16937353648245335, 0.1603188004810363, 0.11689982915413566, 0.13649519212776795, 0.17596878024050966, 0.12051756901200861, 0.07036319933831692, 0.19839817512547597, 0.12169932044344023], [0.03690251396619715, 0.11966421792749316, 0.054085726296762004, 0.04657807505282108, 0.03410556717426516, 0.04292254503525328, 0.03673007966426667, 0.03975801620981656, 0.029525367535825353, 0.04512897976383101, 0.05249002715572715, 0.050594426138559356, 0.02864306155970553, 0.02376917182118632, 0.044459395576268435, 0.04981634367140941, 0.045669790197280236, 0.03213921721908264, 0.03127467825834174, 0.04772445572598372, 0.04338778257078957, 0.046859961294103414, 0.03048540049348958, 0.036646576918428764, 0.0549591858725762, 0.027527335296326783, 0.49886976834386587, 11.761115603148937, 53.777697309851646, 67.54654347896576, 62.48776473104954, 40.57275228202343, 47.33276814222336, 28.588324561715126, 15.402517206966877, 19.518646337091923, 37.18663617968559, 42.41713531315327, 40.295443162322044, 25.904832556843758, 7.262988220900297, 0.3874894621549174, 0.07985215852386318, 0.057510170081513934, 0.47106820391491055, 0.947035769931972, 2.578351884149015, 3.1427871342748404, 3.697468307800591, 7.900720350444317, 13.435991629958153, 8.549125157296658, 5.820657340809703, 17.961765378713608, 5.969552826136351, 8.89693284407258, 9.438383840024471, 14.20873811468482, 15.26133293285966, 23.061443231999874, 24.539824202656746, 32.489115446805954, 41.19413673877716, 50.404576510190964, 53.37269224226475, 59.6017549932003, 56.55582323670387, 59.513022154569626, 58.80139634013176, 62.21135996282101, 59.82482962310314, 61.83500535786152, 57.99631454050541, 57.0231069624424, 57.986123487353325, 59.580457136034966, 60.770994052290916, 64.58877459168434, 63.68673339486122, 63.75348061323166, 57.42151938378811, 59.8577244579792, 56.90116010606289, 60.136086121201515, 58.812609538435936, 60.70590354502201, 45.89716337621212, 31.525867134332657, 28.448284976184368, 51.40180639922619, 61.92887932062149, 58.02678890526295, 53.98559555411339, 54.810542687773705, 56.61620959639549, 56.03745885193348, 60.49944922327995, 58.44524905085564, 62.14278884232044, 59.33684840798378, 55.12106202542782, 55.76801910996437, 57.7983071655035, 59.300913736224174, 63.48178379237652, 60.503875985741615, 57.67111279070377, 53.21337439119816, 56.45254097878933, 58.61590929329395, 63.21042135357857, 61.50576822459698, 53.45868922770023, 53.23007449507713, 48.31289894878864, 52.345546558499336, 55.63858665525913, 39.068359807133675, 28.54894157499075, 20.58219976723194, 10.533840358257294, 10.321094524115324, 4.700082270428538, 24.67086397111416, 10.645502116531134, 6.738524213433266, 2.586073544807732, 0.31847361708059907, 0.24070083018159494, 0.11958243325352669, 0.010321500449208543, 0.07903786667156965, 1.0268054832704365, 9.32029852643609, 25.524180382490158, 42.02196031808853, 42.61453852057457, 38.262328058481216, 34.357213005423546, 24.214782044291496, 10.800694338977337, 23.815596364438534, 40.87355934083462, 50.59241943061352, 51.778563782572746, 50.17637975513935, 10.657510422170162, 0.1985033819801174, 0.04442407676833682, 0.04493245534831658, 0.06207764374266844, 0.03275463204772677, 0.0439779458247358, 0.03904811113898177, 0.03628597107308451, 0.01298414170378237, 0.04210926250379998, 0.01469763730710838, 0.02876584247132996, 0.03998695392510854, 0.04969500623701606, 0.04981658858014271, 0.017338085563096683, 0.015971591310517397, 0.031324654482887127, 0.009592133483238285, 0.05603389363386668, 0.03956106134864967, 0.02177636430133134, 0.051364964674576186, 0.09382090662256815, 0.07964390446431935, 0.07933277389383875, 0.023851709775044583, 0.0548408021859359, 0.11927991901757196, 0.05238785939582158, 0.05556523479754105, 0.06538320289109834, 0.01123782461945666, 0.03715672552061733, 0.02708393360080663, 0.034046228756778874, 0.06371688097715378, 0.047803579800529405, 0.06325329100945964, 0.05040774260123726, 0.05483676119183656, 0.05725345377868507, 0.03146336930512916, 0.035235817267675884, 0.05651512816257309, 0.028422845934983343, 0.011611702848313143, 0.06427231171983294, 0.014283595901360968, 0.04141601122682914, 0.08236015753936954, 0.07137068707379512, 0.011767225460062036, 0.011617979562288383, 0.010698042988224188, 0.49404913326725364, 15.305655654519796, 62.2702644020319, 77.40664958953857, 69.58286941051483, 49.133039340376854, 52.62252129614353, 41.15913301706314, 20.60281366109848, 23.00258059054613, 33.14448907971382, 39.58729416131973, 45.19005931913853, 25.27910303324461, 7.660378972068429, 0.4874714190373197, 0.08631751901702955, 0.042085970198968425, 0.9277877246495336, 1.931561278179288, 6.140351286157966, 8.544286116957664, 8.04147619754076, 9.53638058155775, 15.561018101871014, 10.884755328297615, 14.322987534105778, 14.843553900718689, 13.34454383701086, 14.756345730274916, 14.249566923826933, 12.058048769831657, 14.382499940693378, 18.10161117464304, 23.385035768151283, 30.740190893411636, 39.75824698805809, 45.60307435691357, 52.19683773815632, 57.446624636650085, 57.37924665212631, 59.19231556355953, 58.85070629417896, 65.24627611041069, 63.46352957189083, 63.82328286767006, 61.27541698515415, 58.32964405417442, 60.60129135847092, 60.94708040356636, 62.710261791944504, 65.772205889225, 64.89112436771393, 63.16707327961922, 59.05264265835285, 59.296593368053436, 56.55933044850826, 59.84639346599579, 57.20654211938381, 61.323131024837494, 49.278088957071304, 38.10590945184231, 32.86352835595608, 51.885778829455376, 63.489729166030884, 58.555036559700966, 58.72392609715462, 56.431767493486404, 58.83089415729046, 56.00811682641506, 58.86965587735176, 60.089865401387215, 64.4388422369957, 60.8416398614645, 57.885786071419716, 58.16851370036602, 60.95582753419876, 62.30230048298836, 64.95578169822693, 62.98557981848717, 58.67555469274521, 55.69267675280571, 57.563289776444435, 61.945381835103035, 64.44770336151123, 61.254514306783676, 54.17859859764576, 55.48730917274952, 49.985903576016426, 52.61647202074528, 51.58039681613445, 39.75016102194786, 25.492828264832497, 17.11048185825348, 7.654104083776474, 9.484349973499775, 10.127141531556845, 15.925005320459604, 12.065620813518763, 6.881686756387353, 10.175357144325972, 3.427497544325888, 0.6528614333365113, 0.054618521535303444, 0.04935997108987067, 0.06659159742412157, 1.2992658256553113, 10.370085295289755, 32.2228067368269, 52.943672463297844, 59.31715406477451, 49.38508361577988, 35.09425565600395, 29.363110587000847, 18.14216259866953, 29.76881481707096, 48.84983293712139, 57.297459840774536, 58.90502817928791, 56.618972048163414, 14.045094195753336, 0.22781644889619201, 0.12995654455153272, 0.05362305288144853, 0.049042398677556776, 0.09869873902061954, 0.0563802984834183, 0.01627749159524683, 0.01906593894091202, 0.009502379998593824, 0.016682236673659645, 0.01642085782805225, 0.02096445288771065, 0.04693018701800611, 0.01693901420367183, 0.06754806250683032, 0.05810712398670148, 0.0379523746232735, 0.07303758786292747, 0.0281669218747993, 0.035856141403201036, 0.1118049408250954, 0.06226280587725341, 0.010977151741826674, 0.06165922088257503, 0.022529948473675177, 0.05146960749698337, 0.026209390489384532, 0.007084298204063089, 0.04075375574757345, 0.1368714461568743, 0.21633459313306957, 0.12687241629464552, 0.20076426066225395, 0.16716757672838867, 0.12768091197358444, 0.12942090688738972, 0.10023427967098542, 0.12860717164585367, 0.11658819392323494, 0.14073824335355312, 0.16337915032636374, 0.08176795337931253, 0.0958539979183115, 0.1181600552808959, 0.17692919354885817, 0.13197972817579284, 0.12058259599143639, 0.1758979496662505, 0.1715631244587712, 0.1323361965478398, 0.1746615910087712, 0.09839750870014541, 0.07815311531885527, 0.1599547770456411, 0.12068822587025352, 0.9860109316650778, 19.991116784512997, 72.30797678232193, 86.5620531141758, 80.62966704368591, 54.97225821018219, 61.95451274514198, 40.40527246892452, 26.575899347662926, 28.329809233546257, 51.14690087735653, 54.07534293830395, 54.75060850381851, 33.64913620054722, 10.062735937535763, 0.6898886058479548, 0.21853393292985857, 0.1495232235174626, 1.293141741771251, 1.9089498789981008, 7.617479749023914, 9.652699939906597, 12.433163691312075, 15.955311544239521, 28.473924100399017, 22.31844250112772, 14.776434302330017, 29.717059694230556, 13.84410398080945, 18.70773945003748, 21.932801194489002, 22.49038517475128, 21.13425314426422, 29.241805896162987, 30.703308172523975, 35.781163796782494, 43.2060831785202, 52.229489386081696, 58.04270625114441, 61.71870119869709, 57.24493905901909, 60.853126645088196, 58.883053958415985, 66.78609788417816, 64.88677740097046, 68.63895446062088, 64.8529440164566, 62.23834991455078, 62.33018338680267, 64.35193330049515, 64.55621793866158, 67.83981934189796, 66.45034790039062, 66.59345582127571, 60.6714241951704, 64.78615880012512, 58.441080674529076, 60.365711599588394, 59.1560123115778, 61.6700904071331, 52.74896331131458, 42.88889139890671, 40.3580904006958, 55.07670320570469, 64.78351414203644, 60.56871950626373, 59.78685066103935, 56.46749697625637, 58.60079750418663, 56.54283933341503, 61.64566531777382, 61.99385963380337, 65.81236973404884, 64.71324071288109, 61.78086206316948, 60.796391889452934, 62.25885361433029, 63.26650254428387, 67.2941230237484, 65.6039509177208, 62.06593036651611, 57.663953974843025, 62.32361353933811, 65.03989398479462, 66.88822120428085, 61.23680725693703, 55.548094511032104, 57.20606714487076, 52.504298239946365, 55.10298639535904, 58.14463958144188, 42.47079983353615, 34.714720621705055, 26.044723950326443, 20.029319934546947, 20.864729806780815, 19.128055796027184, 43.51068623363972, 22.202966697514057, 15.669418685138226, 9.415862448513508, 2.0194757357239723, 0.42617886734660715, 0.3948474407661706, 0.10946501599391922, 0.2544271631632, 1.7677365127019584, 14.266790449619293, 36.73520900309086, 55.407410860061646, 54.3708872795105, 48.02186116576195, 46.31948411464691, 33.1013385951519, 18.77157412469387, 37.9337102919817, 57.07397483289242, 67.99540579319, 68.7070620059967, 66.03104040026665, 19.742758311331272, 0.4581145505653694, 0.24855325726093724, 0.09739944624016061, 0.09956910012988374, 0.20892757340334356, 0.17185352684464306, 0.08011740952497348, 0.1504532532999292, 0.1474931527627632, 0.14690569834783673, 0.08355008001672104, 0.06534183557960205, 0.19765525561524555, 0.07493708515539765, 0.1794928833260201, 0.15347331936936826, 0.10896267849602737, 0.19253921607742086, 0.27472947374917567, 0.14000574359670281, 0.21674068149877712, 0.11511244811117649, 0.1079869621025864, 0.13806962873786688, 0.21827808493981138, 0.19118029915262014, 0.1227254063996952, 0.11093596753198653, 0.2613014099188149], [0.09957755319192074, 0.05185565787542146, 0.07737856547464617, 0.026906604834948666, 0.0031749198205943685, 0.03359503265528474, 0.025808428508753423, 0.07757570216199383, 0.008323520160047337, 0.04634568264009431, 0.04581031585985329, 0.06912107419339009, 0.011895640200236812, 0.05777633392426651, 0.005516338687812095, 0.0334534420107957, 0.015174468117038487, 0.04837964595935773, 0.03867892977723386, 0.06289287441177294, 0.02700304135942133, 0.02560529155744007, 0.09432762279175222, 0.012359254287730437, 0.06418947319616564, 0.06755907597835176, 1.901584924198687, 18.24576023966074, 62.28420965373516, 61.805769726634026, 57.84027971327305, 47.86017224192619, 33.633731827139854, 19.271161817014217, 29.06776573508978, 38.10782074928284, 54.48943331837654, 55.29019474983215, 24.5621233060956, 9.491919167339802, 0.4324425937375054, 0.03334256514790468, 0.09002337406855077, 0.07182954956078902, 0.28728898731060326, 2.75819837115705, 6.138750622048974, 10.196680650115013, 5.171626517549157, 8.810967206954956, 8.332107402384281, 7.750404691323638, 17.971718944609165, 15.71682969108224, 19.301267601549625, 19.331451281905174, 30.00811267644167, 28.4717221185565, 42.99820773303509, 52.084603160619736, 49.544933438301086, 61.253826543688774, 63.12285505235195, 56.28978431224823, 58.6586569994688, 57.1335556358099, 57.631298527121544, 56.21887631714344, 58.03932823240757, 61.941213458776474, 59.97939012944698, 59.02176171541214, 52.36176788806915, 51.90698929131031, 53.07337090373039, 57.9841285943985, 61.886040419340134, 61.8367874622345, 60.84032513201237, 60.29201075434685, 56.48613877594471, 57.06587366759777, 59.87141512334347, 57.49490104615688, 59.75886516273022, 57.76825837790966, 50.12259364128113, 36.952329352498055, 33.7600864470005, 57.42821842432022, 56.71563886106014, 56.12334184348583, 56.05774596333504, 56.16548538208008, 58.055530562996864, 57.52829745411873, 55.63612058758736, 58.159530982375145, 61.509727612137794, 60.169391334056854, 56.62999525666237, 55.403337478637695, 53.12046937644482, 54.0783903747797, 57.129436656832695, 57.39101842045784, 52.829537987709045, 49.851417392492294, 51.253811940550804, 59.37005862593651, 61.2813750654459, 59.60026167333126, 57.60337382555008, 56.88423201441765, 58.21273572742939, 60.181645676493645, 58.43790404498577, 56.16734728217125, 40.766325294971466, 31.004742197692394, 28.455022014677525, 18.909045048058033, 7.398129869252443, 14.808862712234259, 11.125150378793478, 11.972469761967659, 11.272502671927214, 2.931494484655559, 1.5914777456782758, 0.07802845677360892, 0.15965635946486145, 0.07438319065840915, 0.1329396665096283, 1.6736896592192352, 11.222705394029617, 24.653232917189598, 32.36769296228886, 33.45191538333893, 39.194311648607254, 25.989606007933617, 26.87485970556736, 25.240571200847626, 29.723259061574936, 48.057453855872154, 53.353206887841225, 51.049063727259636, 23.142850063741207, 1.6413120715878904, 0.03488744572678115, 0.0068682687560794875, 0.0370412918709917, 0.023109452631615568, 0.02351505303522572, 0.05373916188545991, 0.021890716270718258, 0.008770651147642639, 0.0723708794976119, 0.01745895544445375, 0.05886831146199256, 0.0377181528165238, 0.04099767371371854, 0.03312555003503803, 0.050028590485453606, 0.017946117877727374, 0.020303191886341665, 0.0387127383146435, 0.024678966947249137, 0.037815808318555355, 0.057473266788292676, 0.013556767080444843, 0.010015955467679305, 0.0677395069214981, 0.017896668578032404, 0.0324783527321415, 0.009538658032397507, 0.00753120330045931, 0.018203761865152046, 0.0384313975519035, 0.02886832935473649, 0.03603269833547529, 0.04278009721019771, 0.026921776188828517, 0.09383217242429964, 0.04794153763214126, 0.0910050721722655, 0.055892009841045365, 0.05952386163698975, 0.08009907847736031, 0.02562095829489408, 0.08233265354647301, 0.03423633359489031, 0.03258551143517252, 0.09796465848921798, 0.033833803827292286, 0.07456322826328687, 0.03575004397134762, 0.05765815803897567, 0.02514864994736854, 0.016716009959054645, 0.03049873874260811, 0.07049300096696243, 0.06502573261968791, 1.987069055903703, 26.35404635220766, 75.34195438027382, 70.5180524289608, 66.11221924424171, 53.78157690167427, 41.029685363173485, 26.20723932981491, 32.790876254439354, 34.58897016942501, 48.962420895695686, 47.58430324494839, 26.574738509953022, 8.950097691267729, 0.9321912133600563, 0.026168115946347825, 0.050896628672489896, 0.4248455842025578, 1.408973776269704, 5.120323095470667, 8.660839162766933, 8.807181660085917, 11.603878140449524, 13.400672525167465, 17.20962803810835, 17.26456169039011, 14.27806444466114, 8.70774669572711, 9.64856006205082, 17.246470861136913, 27.2800300642848, 28.097651191055775, 39.79559898376465, 49.65420417487621, 52.79205299913883, 62.80987724661827, 60.274284705519676, 58.59375648200512, 59.3189437687397, 58.16356636583805, 57.357511818408966, 55.89348457753658, 57.61921897530556, 64.32386800646782, 61.803444251418114, 61.81233957409859, 54.233612045645714, 55.45433074235916, 55.63506804406643, 60.91543190181255, 62.645596861839294, 62.93694242835045, 61.25535026192665, 60.58037348091602, 58.507656902074814, 59.37693625688553, 59.05717961490154, 58.90994131565094, 59.98246416449547, 58.43253493309021, 51.693607941269875, 41.15988537669182, 39.33809973299503, 57.20712348818779, 58.770591393113136, 59.03139799833298, 57.303676307201385, 57.84860126674175, 58.36931012570858, 56.03185795247555, 57.88958966732025, 60.55525682866573, 61.16222485899925, 61.17301627993584, 56.99115067720413, 57.64660030603409, 55.169714614748955, 57.47096233069897, 59.70240779221058, 60.19976690411568, 56.53742082417011, 51.92099913954735, 53.84161368012428, 61.4359849691391, 63.62965285778046, 59.546669349074364, 57.57175572216511, 55.878171399235725, 58.53899382054806, 62.9040589928627, 60.281948894262314, 58.420474380254745, 44.052240774035454, 36.26794807612896, 26.503182649612427, 10.253585446625948, 7.403072929009795, 16.04962818324566, 15.300174448639154, 12.18061974272132, 8.942071571946144, 5.591730074957013, 4.030220489948988, 0.4703692492330447, 0.11759128072299063, 0.07456440827809274, 0.12357333238469437, 1.8909236462786794, 12.75828754529357, 28.159215487539768, 32.544254288077354, 30.92509087175131, 35.65696366131306, 22.97973621636629, 25.816738083958626, 33.34549069404602, 38.64087514579296, 53.05816791951656, 60.63045859336853, 58.46347667276859, 27.34956633299589, 1.9846397987566888, 0.09204102869261988, 0.04893601180810947, 0.05112944039865397, 0.006871225286886329, 0.026438074019097257, 0.030475260900857393, 0.05400409747380763, 0.021933920397714246, 0.07108115300070494, 0.02074185867968481, 0.04376338350994047, 0.02755164805421373, 0.05940329603618011, 0.010596788069960894, 0.11401520503568463, 0.009633184454287402, 0.037873001929256134, 0.016495018790010363, 0.029624082453665324, 0.04489036444283556, 0.06249195881537162, 0.05576831979851704, 0.041664304153528064, 0.07009140259469859, 0.040191437874455005, 0.025487026614428032, 0.10290011123288423, 0.04780217714142054, 0.35000868898350745, 0.18635098094819114, 0.12468554457882419, 0.14924733754014596, 0.19866626855218783, 0.11070726730395108, 0.1427196292206645, 0.20619586139218882, 0.18749311653664336, 0.15929147513816133, 0.17551317578181624, 0.19856395607348531, 0.25326855189632624, 0.15072958456585184, 0.12195410716230981, 0.12332167010754347, 0.18998253217432648, 0.16003939672373235, 0.2772483229637146, 0.21403075894340873, 0.17006555950501934, 0.0854566202906426, 0.1804656905005686, 0.09955034605809487, 0.18434626195812598, 0.1718256963067688, 3.2244433276355267, 37.498474046587944, 87.9755848646164, 79.32227119803429, 76.59604668617249, 63.20558421313763, 47.52346470952034, 29.12383172661066, 38.568975403904915, 51.27442963421345, 69.5529194176197, 69.77506309747696, 34.74031984806061, 12.75876346975565, 1.1838611494749784, 0.1669224156648852, 0.2766499144490808, 0.4938139021396637, 0.6643890647683293, 9.696976114064455, 13.857294023036957, 19.94741912931204, 16.266733333468437, 20.918540619313717, 18.217750042676926, 25.737474337220192, 31.22623421251774, 23.19245260208845, 31.790743321180344, 29.283814541995525, 36.63839019834995, 32.62200951576233, 49.631447196006775, 54.96662691235542, 52.67098769545555, 64.74372267723083, 63.57764884829521, 59.51319694519043, 60.333067551255226, 58.92554707825184, 57.63216108083725, 57.49154582619667, 59.66554597020149, 66.02335721254349, 64.99459281563759, 64.92871955037117, 57.20502980053425, 56.593084037303925, 58.44116806983948, 61.75142124295235, 63.80622938275337, 64.2656247317791, 62.96538010239601, 63.54387626051903, 61.59463405609131, 61.43542259931564, 61.48941770195961, 59.11762297153473, 61.427595019340515, 59.56587731838226, 52.48824030160904, 47.01635152101517, 44.85053613781929, 59.172260239720345, 59.40681405365467, 60.10661110281944, 58.07579107582569, 58.85988660156727, 57.600068002939224, 58.35727997124195, 58.71384523808956, 61.57538428902626, 64.60075914859772, 64.11841303110123, 61.0440132021904, 61.4132621884346, 56.76904119551182, 59.34368044137955, 64.00983765721321, 62.15802602469921, 59.51364912092686, 55.429818257689476, 55.4521344602108, 64.55477401614189, 64.07550573348999, 60.770332887768745, 58.59788306057453, 57.712994143366814, 60.697350203990936, 66.49166688323021, 62.30086795985699, 59.971554949879646, 45.84000304341316, 41.26520812511444, 34.948316887021065, 29.928940124809742, 14.623152427375317, 26.4796220138669, 23.739684037864208, 22.319088466465473, 21.4090695977211, 7.55493700504303, 3.7794306222349405, 0.6435355462599546, 0.3330385620938614, 0.21772706997580826, 0.3410425951005891, 2.6547721959650517, 15.451594423502684, 35.25043107569218, 46.743700951337814, 49.166732132434845, 52.779741659760475, 35.07958084344864, 39.4486054033041, 36.21316261589527, 44.685913771390915, 61.19501709938049, 68.51813614368439, 69.35350611805916, 34.977867901325226, 3.9322111615911126, 0.14683385845273733, 0.10497639552340843, 0.24500461877323687, 0.10743086342699826, 0.16198441735468805, 0.15231352066621184, 0.15282549866242334, 0.09732930586324073, 0.18449863971909508, 0.06330697797238827, 0.14352821395732462, 0.12209131542476825, 0.13038440753007308, 0.06450848537497222, 0.1942623345530592, 0.09494945348706096, 0.11807044094894081, 0.08682926694746129, 0.1122262654826045, 0.17162111587822437, 0.18255266913911328, 0.1500086919986643, 0.10557758709182963, 0.33679955871775746, 0.14215963426977396, 0.12876464053988457, 0.19308727729367092, 0.08762282319366932], [0.034213720355182886, 0.010522927677811822, 0.06719028795487247, 0.02309026625880506, 0.04094066935067531, 0.04889216572337318, 0.028321529789536726, 0.04282683767087292, 0.031777854383108206, 0.019099307755823247, 0.02159099436539691, 0.0987138862546999, 0.02095193285640562, 0.04627022848580964, 0.028979536473343614, 0.0388552900403738, 0.04054546829138417, 0.036734940731548704, 0.014833439199719578, 0.027610915967670735, 0.06148049687908497, 0.0450520301819779, 0.07602418307214975, 0.01467522444727365, 0.08357347993296571, 0.22804835520219058, 4.964069304987788, 48.32931786775589, 64.65555980801582, 58.57941225171089, 41.96092039346695, 38.079014495015144, 20.86422823369503, 18.399074412882328, 26.189446784555912, 32.47031785547733, 42.29729734361172, 32.598990350961685, 15.263234730809927, 1.6006509284488857, 0.0890339131001383, 0.03020833264599787, 0.025207387225236744, 0.1563883270137012, 1.0264588706195354, 1.5645627211779356, 4.75262395106256, 7.718323487788439, 9.344279989600182, 8.245093021541834, 18.065534010529518, 10.04942050203681, 12.896753065288067, 14.793841168284416, 26.99000872671604, 51.62610836327076, 56.564091593027115, 56.401061341166496, 62.65268348157406, 58.44898425042629, 64.49622675776482, 61.93978853523731, 64.57900151610374, 61.11739866435528, 57.03200228512287, 57.1248085051775, 58.21880780160427, 56.802798584103584, 57.22255825996399, 60.50151251256466, 60.04101902246475, 56.118421107530594, 52.89847768843174, 47.45514437556267, 52.47207596898079, 57.01338708400726, 58.11225391924381, 61.95627965033054, 60.6490395963192, 60.26736907660961, 62.00568459928036, 58.80461856722832, 59.5979817956686, 60.85445657372475, 56.437649577856064, 56.97205290198326, 54.23759423196316, 36.00688308477402, 45.52916072309017, 57.75279700756073, 55.52148453891277, 63.868059664964676, 57.93400168418884, 56.73296973109245, 58.450572565197945, 55.588680133223534, 54.613477662205696, 55.14554791152477, 57.35881134867668, 58.81053864955902, 59.810872972011566, 56.44727066159248, 56.30858190357685, 52.855160012841225, 53.12750279903412, 52.86334477365017, 49.34304267168045, 50.96900202333927, 54.60502311587334, 58.69500584900379, 58.30221712589264, 57.90572740137577, 55.22010751068592, 58.70374917984009, 55.63121885061264, 63.71120788156986, 59.21438477933407, 63.09782959520817, 57.79336363077164, 40.48575975000858, 38.63673336803913, 19.12825718522072, 12.804412320256233, 9.545428846031427, 8.729983102530241, 4.596428582444787, 12.927508614957333, 9.421405401080847, 1.096772791352123, 0.461878486094065, 0.29725831642281264, 0.06640069477725774, 0.10113392592757009, 0.07935504574561492, 1.392077982891351, 12.230980340391397, 43.186096251010895, 53.057054579257965, 45.120580047369, 36.390996873378754, 16.69685885310173, 27.159948907792568, 46.268669441342354, 41.00742615759373, 48.76145727932453, 54.37893524765968, 38.74489836394787, 10.65155804157257, 0.06538910296512768, 0.06819905218435451, 0.057046769361477345, 0.10612043100991286, 0.0763990863924846, 0.03512453222356271, 0.05946590732492041, 0.015117760613065911, 0.06281290057813749, 0.05767409937107004, 0.04236259090248495, 0.057555363164283335, 0.009477638650423614, 0.012919799355586292, 0.015598413483530749, 0.12878545036073774, 0.05843113824084867, 0.017982173267228063, 0.03416487590584438, 0.053962637393851765, 0.043960727998637594, 0.032010833092499524, 0.05323616016539745, 0.04740818578284234, 0.02704904709389666, 0.021107466600369662, 0.02896393467381131, 0.03598579089157283, 0.046781538549112156, 0.02238803128420841, 0.0587647262000246, 0.05690756101103034, 0.05099843649077229, 0.05862425248778891, 0.03412692247366067, 0.08268202698673122, 0.056706891700741835, 0.031819752330193296, 0.03405252587981522, 0.051850893287337385, 0.011399702798371436, 0.009125376400334062, 0.08204459634725936, 0.012522357937996276, 0.07474311743862927, 0.029449596113408916, 0.01626852830668213, 0.06369279828504659, 0.02463397424435243, 0.014305227650766028, 0.04144050210015848, 0.03230553993489593, 0.04207238518574741, 0.3528079512761906, 7.606780948117375, 60.05765452980995, 73.67245316505432, 68.71819540858269, 52.24469996988773, 45.50203397870064, 31.500594690442085, 24.565641917288303, 22.107223235070705, 31.72026090323925, 40.653140768408775, 34.28655959665775, 13.636617064476013, 1.785916043445468, 0.04105652973521501, 0.18790612171869725, 0.4651073331478983, 1.816751032602042, 5.386147806420922, 7.670583324506879, 9.76939357817173, 13.739437647163868, 15.3702512383461, 10.64444862306118, 17.836725488305092, 11.452870443463326, 12.090300489217043, 9.803613591939211, 20.70341896265745, 36.166516318917274, 47.71704912185669, 54.18989159166813, 64.06841531395912, 60.84806531667709, 65.57175144553185, 64.53404232859612, 66.20264679193497, 60.11708714067936, 57.71720051765442, 57.9256497323513, 57.84837707877159, 56.246493235230446, 58.65783244371414, 62.379398345947266, 63.675109818577766, 59.689636677503586, 55.20999625325203, 49.32328373193741, 54.9383944272995, 55.991956293582916, 62.44223937392235, 61.868033185601234, 63.44667747616768, 59.598198384046555, 64.52823624014854, 60.27097888290882, 62.373060286045074, 62.290068939328194, 56.373543217778206, 56.58254720270634, 55.378494411706924, 41.5430074185133, 47.963135316967964, 58.62636633217335, 58.616597056388855, 63.41710366308689, 60.68734914064407, 56.8204752355814, 60.277997106313705, 55.11464796960354, 54.90782126784325, 56.27170108258724, 59.36929866671562, 61.09792850911617, 60.98379023373127, 57.19360761344433, 58.0128588527441, 54.10087376832962, 53.88572931289673, 55.15166938304901, 51.76705040037632, 51.725191846489906, 55.30896954238415, 58.800792172551155, 60.92766344547272, 58.26738819479942, 57.06483632326126, 58.442057222127914, 58.45646984875202, 66.993308365345, 62.74957448244095, 64.60252225399017, 58.90782102942467, 45.44040508568287, 37.916147634387016, 21.754911839962006, 13.960315994918346, 6.9386860728263855, 11.324878111481667, 8.259873278439045, 11.38758709654212, 7.731565777212381, 8.375407978892326, 2.6025480357930064, 1.2120208446867764, 0.23784764343872666, 0.029436055629048496, 0.05836181793711148, 1.0745169105939567, 11.04549715295434, 39.93120990693569, 53.17752331495285, 44.551180601119995, 37.945018485188484, 23.25676415115595, 26.56062226742506, 49.084846526384354, 48.50378170609474, 53.81293661892414, 63.693364039063454, 49.33835372328758, 13.292777314782143, 0.07652660220628604, 0.04216382520098705, 0.037433357356349006, 0.046744253049837425, 0.025073030665225815, 0.02275137750984868, 0.007760615526422043, 0.06444259008276276, 0.04197038811980747, 0.07974599429871887, 0.009194593731081113, 0.036398621668922715, 0.06419070516130887, 0.04930117444018833, 0.025519081827951595, 0.08616139341029339, 0.03256896525272168, 0.05294118986057583, 0.028847246794612147, 0.017170916798932012, 0.06826263197581284, 0.020883336146653164, 0.0318778031214606, 0.04649977847293485, 0.03618655297032092, 0.03759706400160212, 0.07986526485183276, 0.019576080121623818, 0.17845585069153458, 0.1256606524111703, 0.18609010119689628, 0.12950659525813535, 0.14574631524737924, 0.2577528456458822, 0.13224338355939835, 0.1728694824851118, 0.14388763607712463, 0.1345340075204149, 0.21213486848864704, 0.12554075103253126, 0.14722808729857206, 0.11455274259787984, 0.15414905967190862, 0.12447766901459545, 0.21586570423096418, 0.12859976501204073, 0.21290373348165303, 0.0715189756010659, 0.17840433079982176, 0.14745859836693853, 0.19350053480593488, 0.22073677566368133, 0.13607829809188843, 0.6357330805622041, 12.514566723257303, 73.11432391405106, 84.85871851444244, 75.89205846190453, 58.38632941246033, 52.59469538927078, 32.3120791465044, 28.49345125257969, 37.22324721515179, 42.9082627594471, 54.34290178120136, 44.01995010674, 19.880411624908447, 2.6602294156327844, 0.3006108052795753, 0.29886132571846247, 0.5020236584823579, 1.5327646024525166, 5.489834267646074, 10.294012427330017, 16.974063478410244, 19.063578955829144, 19.727118350565434, 17.72099319845438, 28.495068065822124, 16.381141394376755, 22.837538346648216, 22.672997675836086, 34.81347352266312, 56.070479080080986, 63.22191193699837, 61.64413779973984, 66.33571565151215, 63.29685911536217, 70.185167491436, 68.09990018606186, 66.78925171494484, 61.504521891474724, 58.40934857726097, 57.912076860666275, 58.16505588591099, 56.072587966918945, 60.186285227537155, 64.65250477194786, 65.36115154623985, 62.787200063467026, 58.16322438418865, 52.657475620508194, 58.41209203004837, 60.3887839615345, 64.78632599115372, 65.31420886516571, 65.55829256772995, 63.09796638786793, 64.56099048256874, 63.305826634168625, 64.47290360927582, 64.64698746800423, 57.12393455207348, 57.51471318304539, 55.719195529818535, 46.11499808728695, 51.62368029356003, 60.72615645825863, 59.869997799396515, 66.45052269101143, 59.99675899744034, 57.909033223986626, 60.579655319452286, 56.049804389476776, 55.974203646183014, 56.92021228373051, 59.662118554115295, 61.49057283997536, 62.429133877158165, 60.44652186334133, 60.924144834280014, 57.76234969496727, 55.79022891819477, 58.081437572836876, 53.70126821100712, 53.10471922159195, 59.53671768307686, 62.471076026558876, 63.34261626005173, 59.31361265480518, 55.75297951698303, 58.737008795142174, 59.31743524968624, 70.33855006098747, 64.8741164803505, 68.54769095778465, 63.34873013198376, 45.55597208440304, 41.99255749583244, 25.465156249701977, 20.152853205800056, 18.71845867484808, 22.428689785301685, 13.140707574784756, 24.05285183340311, 21.303230077028275, 6.5698659885674715, 1.1959093529731035, 0.8552947989664972, 0.2719233836978674, 0.36471891682595015, 0.1960247423266992, 2.3263023840263486, 15.47576492652297, 55.576547384262085, 65.32389834523201, 62.00153902173042, 50.67942336201668, 25.53203836083412, 39.123627841472626, 60.79561673104763, 56.425912007689476, 64.1563805937767, 72.01765716075897, 59.063304886221886, 16.99615739285946, 0.2717847505118698, 0.11375356087228283, 0.15437283203937113, 0.16805073246359825, 0.14434764889301732, 0.1266098889755085, 0.1150016974133905, 0.14320187678094953, 0.2109417473548092, 0.20043206051923335, 0.1717847297550179, 0.11860321392305195, 0.15108906605746597, 0.10135860371519811, 0.14644892129581422, 0.17103967285947874, 0.2217553585069254, 0.20828079170314595, 0.15100373391760513, 0.12573192827403545, 0.09683134703664109, 0.07532272735261358, 0.1130839432880748, 0.18334788037464023, 0.12091972399502993, 0.09626623126678169, 0.16818712436361238, 0.11342714948114008], [0.02083676452457439, 0.024056562942860182, 0.007309507554964512, 0.04598990817612503, 0.0460151449078694, 0.004517126826613094, 0.10381135725765489, 0.04063973588927183, 0.01950591005879687, 0.05116606909723487, 0.044560383321368136, 0.04946539687807672, 0.05320356875017751, 0.04069514834554866, 0.011092250497313216, 0.09607566258637235, 0.08327725910930894, 0.05259060300886631, 0.014793566388107138, 0.05941149305726867, 0.034031460018013604, 0.04588867181155365, 0.024057126975094434, 0.04982199883670546, 0.03156400453008246, 1.054649914149195, 27.103871516883373, 63.289791494607925, 65.23929208517075, 49.36093211174011, 48.04920069873333, 37.248147279024124, 20.646441020071507, 25.35156324505806, 51.43437825143337, 62.897990718483925, 46.98605954647064, 20.285431891679764, 2.574055502191186, 0.05171780394448433, 0.03562238343874924, 0.058639741109800525, 0.05637139271129854, 1.0655788402073085, 4.758357843384147, 4.752552229911089, 9.049992430955172, 7.855418231338263, 11.033185813575983, 10.855228062719107, 21.454862840473652, 22.540931962430477, 32.09575295448303, 23.226299285888672, 38.49352665245533, 50.990964844822884, 62.36104913055897, 64.7929148375988, 59.77705858647823, 58.62811803817749, 56.59336142241955, 58.82007613778114, 59.95297774672508, 63.57642911374569, 59.59802359342575, 56.67702533304691, 58.30869197845459, 55.58941729366779, 57.42012485861778, 59.438245967030525, 58.82326036691666, 54.69092130661011, 50.318807512521744, 46.94822497665882, 46.241212114691734, 51.98025695979595, 57.03145511448383, 58.986283019185066, 62.01560206711292, 61.40670754015446, 59.12417761981487, 61.448604092001915, 60.74333913624287, 60.002690479159355, 60.607549622654915, 54.63881090283394, 58.47596660256386, 41.41252622008324, 52.94512018561363, 61.711192801594734, 60.330639481544495, 56.52666740119457, 58.046768233180046, 61.408900022506714, 59.55537088215351, 58.29432874917984, 56.95601016283035, 55.13837769627571, 56.128334775567055, 53.95497299730778, 58.3454892039299, 58.785270005464554, 55.209281891584396, 54.9936206638813, 52.62441359460354, 51.8794559687376, 51.33308328688145, 50.80537520349026, 53.784126564860344, 58.53658474981785, 60.31677782535553, 54.519124925136566, 58.297436982393265, 54.9936206638813, 62.222189381718636, 62.37235352396965, 61.55606992542744, 56.092388704419136, 64.6193553507328, 59.66113440692425, 51.239536106586456, 36.76775045692921, 23.799880407750607, 17.78831608593464, 12.726013977080584, 10.234089642763138, 4.998042806982994, 5.150271188467741, 10.03149876371026, 2.1480567986145616, 0.14973663550335914, 0.07649096427485347, 0.02707724128413247, 0.069052306789672, 0.17029957351041958, 0.892492902930826, 8.299880381673574, 27.738787047564983, 45.7024010270834, 25.838786400854588, 34.04281787574291, 76.38946697115898, 47.458529993891716, 29.76837784051895, 38.369208723306656, 55.69007769227028, 57.58337549865246, 22.67600331455469, 0.9262821148149669, 0.030274046112026554, 0.04053539363667369, 0.04997597963665612, 0.028642493816732895, 0.03181438289175276, 0.014658318323199637, 0.041954710250138305, 0.02762546206213301, 0.06622203014558181, 0.05961357986961957, 0.044620103944907896, 0.008247490841313265, 0.1080331088451203, 0.01139378602601937, 0.07615360620548017, 0.012379578929540003, 0.0042407301589264534, 0.020307633640186395, 0.022235189680941403, 0.06110870686825365, 0.04409611057781149, 0.04544090072158724, 0.023112562230380718, 0.02829057480994379, 0.07255481337779202, 0.0555460799660068, 0.010218447678198572, 0.04876069426245522, 0.015384174930659356, 0.052845990867353976, 0.048150871516554616, 0.03414971382881049, 0.06697650489513762, 0.035642736838781275, 0.03120671237411443, 0.04423830978339538, 0.03260790945205372, 0.03845711667963769, 0.06086734931159299, 0.068640607787529, 0.03235715630580671, 0.010415852466394426, 0.04426135717949364, 0.05250497029919643, 0.015484031828236766, 0.02551443783886498, 0.08392779607675038, 0.04228080993925687, 0.042503112854319625, 0.024783691405900754, 0.01857608622231055, 0.03619669070758391, 1.5506040514446795, 34.34316895902157, 72.77494892477989, 74.47048634290695, 56.86699993908405, 54.01224732398987, 46.972452476620674, 21.095307134091854, 22.505880743265152, 45.86402915418148, 45.6148499250412, 41.464507430791855, 20.111517123878002, 2.196109970100224, 0.07151145764510147, 0.02273994843562832, 0.22714030783390626, 1.3861233461648226, 4.402117459103465, 8.859552349895239, 10.924274157732725, 9.705133326351643, 11.587169487029314, 16.285534724593163, 11.347723435610533, 14.496549870818853, 12.107106037437916, 25.347151681780815, 22.77794424444437, 40.41560411453247, 48.42444196343422, 61.2200615555048, 63.63572113215923, 63.236016780138016, 61.1311349272728, 61.351036727428436, 60.458248034119606, 61.58896096050739, 64.98638525605202, 60.76885476708412, 56.556435003876686, 58.13447892665863, 55.460258424282074, 57.862170338630676, 59.75819639861584, 60.79497076570988, 57.349843829870224, 51.2906813621521, 48.98294739425182, 49.42922584712505, 53.94468314945698, 60.27382493019104, 60.69841034710407, 63.09207670390606, 63.25823038816452, 60.918718725442886, 63.53880353271961, 61.53345353901386, 60.389251336455345, 61.82131469249725, 54.352678656578064, 56.51714511215687, 44.912317022681236, 54.578679129481316, 62.3045651614666, 62.012543231248856, 59.06832441687584, 60.38159094750881, 62.126704305410385, 60.34768536686897, 59.44711469113827, 56.88167855143547, 55.57541124522686, 55.924297124147415, 55.23700900375843, 60.796958059072495, 61.409287601709366, 58.18957217037678, 56.89579859375954, 54.80095200240612, 53.10318410396576, 54.22098532319069, 53.696738854050636, 56.21680162847042, 60.95739684998989, 62.44695872068405, 54.977338537573814, 55.743385031819344, 53.94371040165424, 62.79782809317112, 64.5611272752285, 63.1909853965044, 59.530763402581215, 66.83028191328049, 61.30810663104057, 52.84910313785076, 38.11926953494549, 23.057124763727188, 15.057983044534922, 9.476650636643171, 10.687501262873411, 13.008924946188927, 11.234368868172169, 9.728392828255892, 4.254168597981334, 3.158964291214943, 0.6168208422604948, 0.08689141439390369, 0.1002474305278156, 0.14528400177368894, 1.0229876381345093, 11.18967566639185, 32.36083813011646, 45.31173638999462, 27.411567606031895, 25.899520441889763, 63.123903796076775, 55.54473169147968, 37.70057000219822, 46.320000886917114, 62.577234730124474, 66.30684480071068, 27.76974778622389, 1.3023828458972275, 0.0886708841426298, 0.017485368480265606, 0.08617036597570404, 0.06435201095882803, 0.05716575789847411, 0.03210160517483018, 0.08571982296416536, 0.020875936934316996, 0.03217508150555659, 0.02891320145863574, 0.0024188691668314277, 0.03658922745671589, 0.009909965647239005, 0.04355881792434957, 0.1356148417107761, 0.018785486900014803, 0.04171363099885639, 0.03578669122362044, 0.03426601208047941, 0.05334189765562769, 0.028929653017257806, 0.009898852913465817, 0.04661465922254138, 0.010555078442848753, 0.09743423812324181, 0.03665775366243906, 0.02203973210271215, 0.1752038041013293, 0.1684309495612979, 0.13452609622618183, 0.21184644021559507, 0.1929822633974254, 0.12286734214285389, 0.1633184723323211, 0.08768493353272788, 0.07075802932376973, 0.23013064346741885, 0.15401945100165904, 0.16145464265719056, 0.22635772795183584, 0.10806675782077946, 0.09165519353700802, 0.2051984000718221, 0.1557764707831666, 0.15896650351351127, 0.10990979251801036, 0.10314390674466267, 0.11133931737276725, 0.23131004971219227, 0.11353689827956259, 0.10955983278108761, 0.07516485027736053, 2.910567345097661, 44.31510306894779, 83.49902987480164, 84.04571413993835, 67.61864081025124, 63.471585139632225, 51.526150926947594, 31.23163942247629, 36.81749738752842, 66.37814417481422, 79.2104659974575, 58.40873681008816, 26.00281409919262, 3.726791334338486, 0.21619423816446215, 0.23021159693598747, 0.3562473604688421, 0.8719460398424417, 4.708252782002091, 16.34157221764326, 16.483536399900913, 16.15557599812746, 18.48766665905714, 20.565651655197144, 24.294186383485794, 32.08262465894222, 35.18532916903496, 44.169156700372696, 29.150194711983204, 42.16466166079044, 57.61492520570755, 66.30097031593323, 67.92021542787552, 66.14760294556618, 64.74293231964111, 62.74146571755409, 62.631089240312576, 64.61664229631424, 66.56380221247673, 61.85007534921169, 57.36910879611969, 58.29936347901821, 55.63491225242615, 59.38279174268246, 62.8554368019104, 64.37416970729828, 59.831057488918304, 53.652995601296425, 52.5548355281353, 51.95696420967579, 55.406278520822525, 62.3238605260849, 62.14874692261219, 66.72204852104187, 65.46154975891113, 63.83924201130867, 67.00641006231308, 65.42634084820747, 65.33789679408073, 63.79494398832321, 55.10845050215721, 57.52305753529072, 48.41442570090294, 57.29671128094196, 66.95048466324806, 65.14454036951065, 59.13635976612568, 62.18095779418945, 65.00882685184479, 62.911745980381966, 61.17235891520977, 59.1052470356226, 55.710809379816055, 58.054443821311, 55.70276901125908, 62.21827559173107, 63.27084571123123, 60.98374083638191, 58.31449046730995, 57.91281022131443, 56.12360782921314, 55.652094930410385, 57.28839352726936, 59.396657198667526, 63.20167042315006, 63.42562660574913, 54.85604904592037, 57.87903383374214, 54.837802425026894, 64.59082648158073, 68.53075906634331, 67.23355427384377, 62.14767538011074, 70.8266718685627, 65.62567055225372, 56.813476011157036, 40.65004773437977, 29.923882596194744, 24.94356583803892, 24.286349304020405, 22.606024369597435, 14.749011173844337, 10.987226329743862, 23.540789410471916, 7.099083065986633, 1.9599260436370969, 0.5351361504290253, 0.1584428144269623, 0.26108654332347214, 0.47169371566269547, 1.6572566097602248, 13.000800032168627, 39.4909693300724, 60.428594425320625, 34.58712346851826, 44.05743129551411, 86.32711172103882, 59.28477220237255, 44.534940272569656, 55.29754735529423, 70.3399483859539, 74.48823139071465, 34.088259637355804, 1.5646549849770963, 0.32235463382676244, 0.13955003523733467, 0.35148152557667345, 0.15216985571896657, 0.20597029302734882, 0.15422848431626335, 0.1999411595170386, 0.10329899334465154, 0.09456396714085713, 0.16988313960609958, 0.047074282410903834, 0.15786662581376731, 0.15337407938204706, 0.1190402869542595, 0.21777642279630527, 0.21025996597018093, 0.14390613039722666, 0.11837667334475555, 0.12126218061894178, 0.1624743832508102, 0.21256323612760752, 0.09472826379351318, 0.1177633625047747, 0.07723567978246137, 0.24092328152619302, 0.14960732369218022, 0.09976398810977116], [0.028357405208225828, 0.005979448578727897, 0.07014669259660877, 0.04320333660871256, 0.056265959501615725, 0.045687612873734906, 0.05708968405087944, 0.024491454059898388, 0.0710033017094247, 0.010788103536469862, 0.047914801762090065, 0.04269463519449346, 0.061959078229847364, 0.03793930169194937, 0.00688791247739573, 0.04524094387306832, 0.059825347998412326, 0.017906207031046506, 0.029147189488867298, 0.054853615365573205, 0.029893487626395654, 0.012172602291684598, 0.07764717098325491, 0.06657322926912457, 0.22782673506299034, 9.898921977728605, 46.05255983769894, 63.10411065816879, 56.57352268695831, 44.60106432437897, 34.80387903749943, 15.625065565109253, 26.487538889050484, 37.23081260919571, 31.746314205229282, 47.98137813806534, 22.86187034100294, 4.379438851028681, 0.2273518792935647, 0.07617530660354532, 0.041130373429041356, 0.2940848929574713, 1.6526742931455374, 3.2114454125985503, 5.937715759500861, 7.809930872172117, 7.579197753220797, 13.494441993534565, 18.25172781944275, 5.521024893969297, 16.462056152522564, 31.788094863295555, 42.996885403990746, 40.1089833676815, 59.5308393985033, 56.07478424906731, 65.33979669213295, 57.09840752184391, 58.431467190384865, 53.266305550932884, 55.94090223312378, 54.39783923327923, 57.678188011050224, 58.11686307191849, 61.64816178381443, 55.106292217969894, 57.73514695465565, 54.024224281311035, 57.488600984215736, 57.44115673005581, 58.99125315248966, 54.77194435894489, 53.708795607089996, 44.87108163535595, 45.753918662667274, 44.80002544820309, 52.10616700351238, 57.65135005116463, 59.679654613137245, 55.533427298069, 56.29441246390343, 54.66242663562298, 59.862143620848656, 55.3092697262764, 60.383376851677895, 52.690499648451805, 60.10230973362923, 38.69283735752106, 51.78863704204559, 59.69242572784424, 54.20810401439667, 55.546696186065674, 56.64930202066898, 58.110000640153885, 59.200739711523056, 56.50587871670723, 58.4604786336422, 55.485633462667465, 53.5709124058485, 54.171846359968185, 56.500771790742874, 58.01980867981911, 58.87505158782005, 57.12103150784969, 56.92316472530365, 55.6497922539711, 53.49305838346481, 53.68965603411198, 54.77533757686615, 57.05531403422356, 56.369614228606224, 54.75550264120102, 54.31568764150143, 56.09090678393841, 57.29342445731163, 60.57746283710003, 58.7001583725214, 60.115909203886986, 60.02626061439514, 60.11455647647381, 57.14558199048042, 56.89959838986397, 46.14569664001465, 26.2537944316864, 22.32881784439087, 7.566800443455577, 11.498273257166147, 7.485826788470149, 11.610832717269659, 9.13265224546194, 4.217897169291973, 0.8923112251795828, 0.10330616249120794, 0.06138246288173832, 0.09374094021040946, 0.09959509756299667, 2.0864742156118155, 16.97262905538082, 43.073143512010574, 48.75494442880154, 69.56187173724174, 83.40862512588501, 65.09371429681778, 27.422330528497696, 35.328756272792816, 47.006684839725494, 55.65098538994789, 35.85919260978699, 2.6692558312788606, 0.027465733328426722, 0.10296616979758255, 0.03061208324652398, 0.03081101407587994, 0.0857046979945153, 0.02310663061507512, 0.01676004714681767, 0.02642301027663052, 0.040249291996588, 0.05737862069508992, 0.035127051814924926, 0.026085475947184023, 0.03780359998927452, 0.03355088229000103, 0.022920618721400388, 0.033880095288623124, 0.04391149021103047, 0.018606848243507557, 0.06567621763679199, 0.033359864610247314, 0.03289872001914773, 0.033324991090921685, 0.08156431547831744, 0.03114352592092473, 0.04458384260942694, 0.030334935618157033, 0.043995605228701606, 0.04050535149872303, 0.015108096922631375, 0.02588849325547926, 0.04419374752615113, 0.05520331164007075, 0.03410714052733965, 0.06368425616528839, 0.04669089634262491, 0.07055704088998027, 0.03510688395181205, 0.03945458913221955, 0.036644662177423015, 0.019542739137250464, 0.014510189357679337, 0.03305294943857007, 0.08080600382527336, 0.00904351101780776, 0.08560219997889362, 0.02359935358981602, 0.016919488298299257, 0.03302690376585815, 0.04632387834135443, 0.03636649780673906, 0.018261946243001148, 0.14356325817061588, 12.817712556570768, 54.691571071743965, 72.19349652528763, 65.40105700492859, 52.414216473698616, 44.120937287807465, 26.00572284311056, 32.64700837433338, 42.75078780949116, 39.36534807085991, 48.01869973540306, 24.74912267178297, 4.802817357704043, 0.36248463671654463, 0.038579979227506556, 0.2851659106090665, 0.8202668535523117, 3.765938733704388, 7.7232214249670506, 10.469838492572308, 11.61473035812378, 13.36836950853467, 12.956570405513048, 12.332936469465494, 10.059244874864817, 11.429556794464588, 24.354223161935806, 39.11195486783981, 41.10389158129692, 57.15807192027569, 59.16850224137306, 65.96872374415398, 60.25547571480274, 60.507956966757774, 55.7952294498682, 58.29269103705883, 58.171124160289764, 60.09240746498108, 60.050643905997276, 61.70123353600502, 57.48064041137695, 57.6723363250494, 54.00933288037777, 58.44983920454979, 59.62082616984844, 61.23042739927769, 57.28562727570534, 55.16892425715923, 47.78071470558643, 47.85113252699375, 47.53880448639393, 54.434324875473976, 61.28354474902153, 60.99296674132347, 58.88029910624027, 57.94132009148598, 58.21102201938629, 62.58942447602749, 58.26382398605347, 60.28873153030872, 54.1842070966959, 58.116087913513184, 41.39910154044628, 52.691673785448074, 62.45980203151703, 55.904530584812164, 57.40057110786438, 58.40603895485401, 60.89529298245907, 60.767372846603394, 59.19071204960346, 59.45136286318302, 56.98421224951744, 53.64106424152851, 55.520234405994415, 56.83592900633812, 59.124428406357765, 59.87485013902187, 58.75799886882305, 58.25148604810238, 58.155731186270714, 54.63806614279747, 56.277165189385414, 57.37158626317978, 59.12725165486336, 57.8417806327343, 54.54555630683899, 53.250768184661865, 56.20073229074478, 61.093102768063545, 62.47492142021656, 59.37907554209232, 61.566564962267876, 62.70475588738918, 61.63982883095741, 56.61128506064415, 58.06314915418625, 42.45551325380802, 24.681186117231846, 13.850226402282715, 7.924844305962324, 11.699210274964571, 9.93374140933156, 15.786649994552135, 8.690934497863054, 5.938944518566132, 3.028694218955934, 0.4843380121747032, 0.11114142369478941, 0.061137691445765086, 0.1293891726527363, 2.5326512614265084, 17.165284417569637, 46.12071678042412, 36.49524047970772, 57.05343313515186, 79.18441459536552, 64.94353115558624, 33.29523839056492, 40.26126019656658, 54.19301122426987, 63.389733731746674, 45.76064810156822, 3.8532347744330764, 0.054630447848467156, 0.04249545017955825, 0.019997788840555586, 0.015618067409377545, 0.03667292316094972, 0.012676230198849225, 0.04884637521172408, 0.038335534336511046, 0.02641084647621028, 0.012114046839997172, 0.09148542725597508, 0.04068816102517303, 0.01764985623594839, 0.01874476711236639, 0.0334056588326348, 0.02136534807505086, 0.02097186694300035, 0.058703179893200286, 0.02919005593867041, 0.04537460095889401, 0.04097562821698375, 0.05725028851884417, 0.038169159670360386, 0.03256115043768659, 0.05028402287280187, 0.024910669162636623, 0.07440322864567861, 0.1251882902579382, 0.11199550950550474, 0.13011956471018493, 0.19388691172935069, 0.1286664544022642, 0.12156647600932047, 0.22915338340681046, 0.1478212562506087, 0.1550426648464054, 0.11714468593709171, 0.14867664081975818, 0.1274490650394, 0.17764401534805074, 0.11727746357792057, 0.15515167149715126, 0.14398423401871696, 0.13091078319121152, 0.2327574454830028, 0.12650376185774803, 0.1620916576939635, 0.1343784385244362, 0.20259114622604102, 0.28472088917624205, 0.18230234272778034, 0.6112239800859243, 16.881717033684254, 65.61216607689857, 81.63247123360634, 75.2271169424057, 61.668737679719925, 50.278693065047264, 25.837104991078377, 40.62611661851406, 51.34052708745003, 42.78848558664322, 63.5327922552824, 29.617172554135323, 6.4711947832256556, 0.5625359457917511, 0.24986271746456623, 0.3031356807332486, 1.2153386604040861, 3.543909997679293, 11.019104719161987, 19.625015929341316, 20.56272391229868, 20.06173599511385, 22.398891784250736, 26.42159342765808, 16.983857452869415, 23.358437195420265, 39.720640406012535, 47.12797433137894, 41.71422243118286, 61.51454575359821, 61.248005256056786, 68.15527841448784, 61.95698261260986, 62.86530487239361, 59.4233887642622, 61.357124000787735, 59.96626943349838, 61.59310653805733, 63.04446905851364, 64.1190741956234, 58.55770021677017, 56.92409187555313, 55.05263529717922, 58.712914288043976, 61.86444237828255, 62.533879056572914, 60.02729795873165, 58.41541305184364, 49.93530549108982, 50.32412342727184, 48.499609529972076, 57.83799983561039, 65.1210880279541, 63.47647547721863, 61.42240069806576, 60.13404943048954, 60.53915709257126, 65.16160905361176, 60.06736680865288, 62.06727549433708, 54.3932718783617, 59.28170196712017, 46.09264388680458, 55.986450389027596, 64.66769635677338, 59.569848105311394, 59.599657505750656, 61.05191297829151, 64.14311170578003, 62.72696949541569, 60.51010765135288, 61.223120391368866, 57.533389180898666, 54.87440966069698, 55.986279398202896, 57.72725857794285, 59.97936733067036, 61.86581410467625, 61.4375314861536, 60.46109028160572, 61.19729317724705, 57.20601014792919, 59.074521884322166, 60.25994807481766, 61.77300028502941, 60.83042286336422, 58.29494811594486, 54.73312184214592, 55.126993507146835, 60.694580152630806, 67.01029345393181, 62.87022940814495, 64.47920367121696, 65.36351501941681, 63.21699880063534, 60.0394307076931, 58.196909576654434, 49.43402498960495, 31.844820119440556, 29.962213039398193, 15.916507076472044, 19.673645719885826, 20.735365748405457, 24.07110795378685, 20.240594297647476, 8.931888118386269, 2.4304220220074058, 0.6215530133340508, 0.1892930769827217, 0.26216440892312676, 0.5878070241305977, 3.3081480860710144, 21.89011998474598, 59.34641629457474, 64.11107942461967, 77.81132787466049, 86.62104114890099, 69.44596275687218, 38.58607828617096, 49.84034098684788, 63.85033741593361, 68.7285840511322, 55.092058181762695, 5.641225269064307, 0.1362593672820367, 0.1768985576927662, 0.14195177354849875, 0.2059378760168329, 0.1854361206642352, 0.18253512476803735, 0.16330480197211727, 0.14655767561635002, 0.10182698795688339, 0.12579717789776623, 0.11963624638156034, 0.11675433852360584, 0.12067557225236669, 0.07595068076625466, 0.1093196812144015, 0.10247704994981177, 0.14437639969401062, 0.1354636365431361, 0.10977898156852461, 0.16571767249843106, 0.17717497801641002, 0.16753541480284184, 0.1521454835892655, 0.14488983229966834, 0.160439444007352, 0.11190088567673229, 0.1865974036627449], [0.004044348606839776, 0.024149335113179404, 0.01853976365964627, 0.028591263362613972, 0.02831610840075882, 0.044965395572944544, 0.042935495512210764, 0.02733099270699313, 0.040311921839020215, 0.011754976312658982, 0.02750156792899361, 0.031866032659308985, 0.08844650321407244, 0.045909151376690716, 0.03704822724102996, 0.03677271604829002, 0.047185667644953355, 0.06475260743172839, 0.07932636173791252, 0.009440318826818839, 0.037738313258159906, 0.01186639123261557, 0.10181254576309584, 0.15306887857150286, 0.32963355886749923, 28.275491148233414, 70.04112482070923, 62.702529206871986, 52.68639586865902, 45.786520913243294, 38.15024547278881, 18.98149576038122, 19.444428719580173, 33.19954812526703, 57.91352838277817, 28.167077265679836, 8.654471654444933, 0.8230090595316142, 0.06709456574753858, 0.06076992387534119, 0.21373591851443052, 0.1861358471796848, 5.244413036853075, 5.798622323200107, 5.823358045890927, 8.715492580085993, 9.30147148668766, 7.692583194002509, 15.55529085919261, 19.960980601608753, 39.0432545542717, 43.882059305906296, 60.421485006809235, 56.76527559757233, 60.14865204691887, 57.110658064484596, 60.10625772178173, 57.43205241858959, 55.029467940330505, 52.018840089440346, 50.455497577786446, 52.15603932738304, 56.387100890278816, 58.91910642385483, 57.75291100144386, 56.26674234867096, 56.41059882938862, 56.088547110557556, 55.98831608891487, 58.67852233350277, 56.36437430977821, 52.50214755535126, 49.43148672580719, 46.14691637456417, 44.13840875029564, 45.69257475435734, 45.81272050738335, 47.36588716506958, 52.95507185161114, 51.13185368478298, 50.17625816166401, 53.16137798130512, 57.91901908814907, 57.7819262444973, 55.15532858669758, 55.173882991075516, 55.90274468064308, 33.03696624934673, 52.71538071334362, 58.95956665277481, 56.19866520166397, 52.60241657495499, 54.45495016872883, 57.26142257452011, 53.52645479142666, 54.166332855820656, 57.60841615498066, 56.904389932751656, 53.40642683207989, 54.12533685564995, 54.212792962789536, 55.716623067855835, 56.51080325245857, 57.65104226768017, 57.73889735341072, 58.93834859132767, 55.40680669248104, 55.7584398239851, 55.18701508641243, 58.737593963742256, 54.98361200094223, 53.928875997662544, 54.265838116407394, 53.22497136890888, 60.3462490439415, 61.97709873318672, 51.56477205455303, 59.166609942913055, 61.593121737241745, 59.924346283078194, 63.98491099476814, 63.31773519515991, 58.93600791692734, 52.14443475008011, 36.668492183089256, 22.09502588957548, 25.55331911891699, 13.518292363733053, 7.470054309815168, 3.3651808882132173, 6.338444156572223, 2.571235578507185, 0.3292426251573488, 0.07473287580069155, 0.05770066083641723, 0.08556610191590153, 0.07378653361229226, 2.4254716001451015, 22.413013726472855, 44.056074768304825, 48.83813716471195, 66.2008684873581, 44.181118458509445, 24.335706755518913, 41.723642125725746, 46.22324287891388, 55.64686641097069, 45.12559197843075, 13.207411095499992, 0.3851679351646453, 0.042389067020849325, 0.06132975555374287, 0.019106729232589714, 0.0215835376366158, 0.03231214504921809, 0.007897755604062695, 0.03811481219599955, 0.04502834453887772, 0.06246458840905689, 0.02764836659480352, 0.009291178685089108, 0.041599570322432555, 0.014413803855859442, 0.02119748169207014, 0.040613701348775066, 0.06314488549833186, 0.06550890044309199, 0.03852084861136973, 0.006028611223882763, 0.08125973807182163, 0.06400369136827067, 0.03087958109972533, 0.015126047619560268, 0.13945426850114018, 0.03602026365115307, 0.030124026525299996, 0.025273820574511774, 0.04609148592862766, 0.06365845911204815, 0.024488192320859525, 0.028118062582507264, 0.05838794524606783, 0.026650226209312677, 0.056541537487646565, 0.06888130112201907, 0.05722236521251034, 0.1057358797697816, 0.043887641295441426, 0.035918511493946426, 0.07880355580709875, 0.015072197384142783, 0.013664806156157283, 0.06656419733189978, 0.07382038296782412, 0.04788306381669827, 0.013956772618257673, 0.01649285728490213, 0.023666605156904552, 0.05848630207765382, 0.05089429090730846, 0.4805887711700052, 35.42550668120384, 78.52363765239716, 72.74317502975464, 61.10871993005276, 51.79806813597679, 41.76584646105766, 18.727297000586987, 22.606609538197517, 28.95268891006708, 48.039807602763176, 28.889120221138, 8.986780922859907, 0.7427033374551684, 0.03757705198950134, 0.06863251837785356, 0.9938910556957126, 2.137250415980816, 8.376812003552914, 12.42198659107089, 13.551847413182259, 15.223064236342907, 8.6670708283782, 11.611107252538204, 9.653262309730053, 16.105526983737946, 30.83326119929552, 40.96036568284035, 52.97784022986889, 56.57687030732632, 59.10630717873573, 59.40916232764721, 61.333105489611626, 61.05844482779503, 56.32469303905964, 54.81441468000412, 53.89150880277157, 55.079401060938835, 57.81290978193283, 59.878444746136665, 58.90915475785732, 57.721228301525116, 57.749430388212204, 56.38869680464268, 57.496299371123314, 61.375184431672096, 60.04696570336819, 55.003492534160614, 51.71495899558067, 49.27049316465855, 46.25647209584713, 48.85327935218811, 47.44349420070648, 49.760093092918396, 55.23429214954376, 53.279255256056786, 51.99031122028828, 57.25984945893288, 59.456348195672035, 61.23279087245464, 57.08560600876808, 55.2397258579731, 55.75264133512974, 36.36799290776253, 52.820988446474075, 61.88100568950176, 57.527043521404266, 55.909496918320656, 56.77124507725239, 59.08074975013733, 56.58023692667484, 55.97812503576279, 59.62032839655876, 57.968389838933945, 54.842468574643135, 55.48776134848595, 55.76724775135517, 56.85581333935261, 58.50511483848095, 59.34815280139446, 59.131613820791245, 60.67492760717869, 59.56294767558575, 57.999483570456505, 58.61468955874443, 61.569779589772224, 56.29957638680935, 54.698927477002144, 55.36919251084328, 52.3436314612627, 61.95642024278641, 63.63528415560722, 54.698919877409935, 60.938105285167694, 63.47169913351536, 61.091309264302254, 63.86036887764931, 63.89347270131111, 62.8069894015789, 50.36313593387604, 33.720066994428635, 15.780500024557114, 7.299789721146226, 10.38185516372323, 9.042930509895086, 8.305164948105812, 9.051638692617416, 4.439540226012468, 1.859334991313517, 0.4425763530889526, 0.027734162576962262, 0.05081554161733948, 0.15509218093939126, 2.8447788627818227, 25.745381712913513, 41.59452125430107, 50.81829831004143, 73.9686244726181, 49.191351011395454, 31.466715708374977, 47.86721706390381, 51.89538091421127, 60.74358992278576, 54.553159698843956, 17.422861196100712, 0.402369552757591, 0.02187057994888164, 0.10157545184483752, 0.020406357834872324, 0.043313909191056155, 0.039645859142183326, 0.030408920320041943, 0.054882499753148295, 0.013338437438505935, 0.04195062101643998, 0.08972486743004993, 0.03452325901889708, 0.012051745397911873, 0.10478036463609897, 0.015759118141431827, 0.057860894230543636, 0.07134744300856255, 0.006452147017625975, 0.02148452214896679, 0.018836617164197378, 0.058810375703615136, 0.07990073951077648, 0.029064974369248375, 0.018343406227359083, 0.011733396513591288, 0.041388024837942794, 0.060725747534888797, 0.1638113326043822, 0.13805000635329634, 0.12345337905571796, 0.10232825676212087, 0.17116416071075946, 0.11866971777635626, 0.15367288287961856, 0.12996150209801272, 0.19563573820050806, 0.12326665470027365, 0.1727596001001075, 0.18206035805633292, 0.17258130654226989, 0.09211290569510311, 0.12832138541853055, 0.15555339603452012, 0.16358980152290314, 0.22383821080438793, 0.15289582457626238, 0.08979336766060442, 0.1654529632651247, 0.10086387323099189, 0.2110869559692219, 0.26574960560537875, 1.3055287208408117, 44.71036545932293, 87.59221583604813, 81.96196675300598, 69.71710860729218, 61.290486976504326, 51.21552139520645, 29.06798042356968, 32.90234327316284, 43.94814915955067, 70.72998225688934, 39.53505076467991, 11.488759517669678, 1.638330656569451, 0.16946958523476496, 0.1422717430978082, 0.798794087022543, 1.7047013388946652, 12.781901378184557, 20.14240376651287, 14.33618612587452, 18.075193092226982, 18.658632785081863, 20.105097368359566, 27.942706905305386, 28.217033185064793, 43.408023342490196, 47.38019339740276, 63.00362125039101, 57.99232095479965, 61.72420710325241, 61.38103611767292, 65.81692948937416, 61.86194971203804, 58.2352989166975, 56.49049714207649, 54.83208753168583, 56.628562733531, 61.279167383909225, 62.61591285467148, 59.522985219955444, 58.179441913962364, 57.02509805560112, 56.670972257852554, 59.42566864192486, 63.226471692323685, 62.47106462717056, 56.128273978829384, 53.94231207668781, 51.04861915111542, 47.683705911040306, 50.34797474741936, 49.84285265207291, 51.54981605708599, 58.93778242170811, 55.32392933964729, 54.588961377739906, 59.26072709262371, 61.453122049570084, 63.4244828671217, 57.6443812251091, 54.982551857829094, 55.374557822942734, 40.640175864100456, 55.4162871837616, 63.76614153385162, 61.770465821027756, 57.827816382050514, 59.722436517477036, 59.47195775806904, 57.775147408246994, 58.175121545791626, 62.082052901387215, 60.92769004404545, 54.47072312235832, 56.204790472984314, 56.505145356059074, 58.59028346836567, 59.818761348724365, 62.12351247668266, 62.18584053218365, 61.781097650527954, 61.749224960803986, 59.74006377160549, 59.44928057491779, 63.59888970851898, 58.2221782207489, 54.972691386938095, 56.19591414928436, 53.11919264495373, 64.02716472744942, 66.74607843160629, 56.585032269358635, 63.882970064878464, 68.21678951382637, 64.71979916095734, 65.58040738105774, 65.94686731696129, 62.62171894311905, 55.59098280966282, 41.42517954111099, 27.71505542099476, 35.82806847989559, 24.277953654527664, 16.123866699635983, 11.183208413422108, 17.38394558429718, 7.539810016751289, 1.4775330224074423, 0.27466336323414, 0.12985007604584098, 0.35659189510624856, 0.22084466909291223, 4.162943568080664, 30.457259975373745, 60.264336839318275, 58.09795528650284, 74.20564815402031, 49.06169816851616, 36.49269461631775, 55.8223257958889, 60.67078582942486, 69.44429084658623, 64.59223240613937, 23.28368190675974, 0.7844217144884169, 0.18709170370129868, 0.18136637576390058, 0.12916059116832912, 0.12960316351382062, 0.18310865649254993, 0.07589936867589131, 0.1853665814269334, 0.06628495684708469, 0.14682021777844056, 0.19756575260544196, 0.13679337222129107, 0.08494430090649985, 0.16040993621572852, 0.09053181944182143, 0.22258447104832157, 0.2194090437842533, 0.20317282673204318, 0.21377522265538573, 0.06935041266842745, 0.19781861716182902, 0.17904064821777865, 0.06861289599328302, 0.14314379630377516, 0.38790028542280197, 0.13226784474682063, 0.24006442370591685], [0.03317217546282336, 0.047715193722979166, 0.007443172526109265, 0.02292577479238389, 0.05508222653588746, 0.019881746629835106, 0.01609361708688084, 0.024433913495158777, 0.04234864594764076, 0.024480331121594645, 0.02880216132325586, 0.0151126063974516, 0.021381749538704753, 0.032109238163684495, 0.05396600303356536, 0.038307028444251046, 0.03971580656070728, 0.018884925411839504, 0.04554538769298233, 0.055632083749515004, 0.04042281725560315, 0.03580476994102355, 0.05006393897929229, 0.054974500089883804, 2.726160865277052, 45.660656467080116, 69.01472389698029, 59.32472325861454, 48.60663838684559, 45.379585549235344, 24.698522686958313, 36.540575847029686, 65.33334463834763, 64.67018902301788, 52.11497113108635, 15.918071642518044, 2.0482064690440893, 0.04546956246485934, 0.25402367231436074, 0.23040808795485646, 0.5377986200619489, 1.7340198531746864, 4.893765952438116, 7.541858581826091, 13.134993631392717, 9.846254903823137, 10.925535690039396, 17.93970186263323, 20.326549485325813, 38.46594013273716, 46.6633390635252, 58.70512470602989, 59.61508087813854, 60.394662246108055, 55.89843951165676, 58.18424105644226, 59.71661902964115, 55.13716176152229, 52.99590066075325, 47.24540323019028, 47.94454291462898, 51.11004665493965, 55.47380469739437, 58.691415041685104, 60.26668131351471, 56.15243308246136, 57.0075011998415, 55.57886146008968, 59.96352218091488, 56.34765900671482, 55.337513610720634, 52.20819532871246, 49.259048178792, 45.21487198770046, 43.05349476635456, 44.378578662872314, 46.380208656191826, 44.73086155951023, 43.73867020010948, 44.693897143006325, 51.72763891518116, 54.70868155360222, 59.64490927755833, 56.34424299001694, 55.99884532392025, 54.092620611190796, 56.54361829161644, 26.70722220093012, 52.64731116592884, 59.09786403179169, 54.88917946815491, 51.22506648302078, 49.36402514576912, 52.51047670841217, 50.751076117157936, 52.4352141469717, 56.33919306099415, 56.570745036005974, 53.29697750508785, 54.65722091495991, 52.51278318464756, 54.42006804049015, 54.179502949118614, 57.80904918909073, 56.229394152760506, 57.84202001988888, 56.94595970213413, 58.89967806637287, 54.083048924803734, 57.578792944550514, 57.5125814974308, 55.11139914393425, 54.618364199995995, 55.63971519470215, 58.67886431515217, 58.38712736964226, 53.077299892902374, 53.39633837342262, 62.18280829489231, 60.25817736983299, 60.96847325563431, 60.014105066657066, 63.077717274427414, 59.52795535326004, 49.974325597286224, 40.59261001646519, 26.5649426355958, 14.118206072598696, 17.117821164429188, 6.169108618050814, 6.8753021489828825, 4.449310451745987, 1.423937373328954, 0.4842669144272804, 0.12608349847141653, 0.09715642998344265, 0.06563939969055355, 0.2927433274453506, 7.715362971648574, 35.71183271706104, 36.0581461340189, 28.329007476568222, 19.21084765344858, 19.950179681181908, 30.555119924247265, 40.76585792005062, 49.86095108091831, 59.73521523177624, 37.227609381079674, 2.6737609645351768, 0.04477716465771664, 0.0945674032846, 0.008342680557689164, 0.014933520596969174, 0.0684187353181187, 0.026830197020899504, 0.021190635379753076, 0.08872507576597854, 0.046110941329970956, 0.04206783582048956, 0.061584074719576165, 0.07563369465060532, 0.009649754756537732, 0.01341739638519357, 0.03622588308644481, 0.061271062804735266, 0.039862187768449076, 0.06415678159100935, 0.013761442132818047, 0.025315722232335247, 0.07192999182734638, 0.0417672326148022, 0.0780417189525906, 0.0173790038752486, 0.01672670059633674, 0.046023356771911494, 0.02448422554152785, 0.06167226783873048, 0.03299551834061276, 0.029122455562173855, 0.07347168488195166, 0.03159274048812222, 0.04503438562096562, 0.010641018216119846, 0.037427550050779246, 0.03136068204184994, 0.013359543190745171, 0.004212283174638287, 0.04197238078631926, 0.05036569622461684, 0.0027339748658050667, 0.024592321206000634, 0.01471465011491091, 0.04942954001307953, 0.04885026406554971, 0.03702272704686038, 0.07261124628712423, 0.025626105089031626, 0.0187012531387154, 0.028326977153483313, 4.771657604724169, 52.25603096187115, 75.85831627249718, 68.47795709967613, 56.846044063568115, 53.00845518708229, 36.90024554729462, 39.296237379312515, 61.59243777394295, 50.48629492521286, 45.39005018770695, 17.927434220910072, 1.9104361929930747, 0.02750025989371352, 0.17475611093686894, 0.5621204618364573, 2.809873460792005, 4.852939993143082, 8.125303499400616, 10.484060179442167, 14.423261303454638, 13.358266800642014, 6.8770966026932, 15.020122826099396, 21.37002669274807, 36.13801024854183, 48.149956092238426, 60.10928235948086, 61.40487603843212, 60.688774064183235, 55.70744276046753, 60.062852650880814, 61.89203269779682, 58.7016136944294, 55.59272691607475, 50.37335738539696, 50.10438121855259, 52.347150072455406, 57.423445880413055, 61.04886934161186, 59.69993032515049, 57.8278923779726, 55.507911667227745, 56.034590005874634, 62.46817298233509, 58.364408388733864, 57.4147367477417, 54.91105869412422, 52.27740861475468, 47.73857496678829, 44.39630091190338, 45.850501880049706, 47.049766927957535, 46.00703068077564, 44.937277883291245, 45.89043773710728, 54.54341322183609, 56.98024146258831, 62.3340629786253, 58.975734785199165, 56.52375675737858, 53.44978250563145, 57.220684960484505, 30.303372032940388, 53.8165046274662, 61.95891670882702, 57.00422577559948, 54.91593383252621, 50.416583865880966, 55.64643703401089, 52.370731607079506, 54.88897427916527, 58.00775572657585, 58.77585791051388, 54.5580842345953, 54.300602450966835, 53.6484282463789, 55.10216563940048, 56.14071071147919, 57.83767305314541, 56.994384303689, 58.87908697128296, 58.226665779948235, 59.89295616745949, 57.03432776033878, 57.80073523521423, 58.12531381845474, 53.86785127222538, 55.52381381392479, 55.17020098865032, 61.94994539022446, 61.43784686923027, 54.32059317827225, 55.447019934654236, 64.77563336491585, 61.048641353845596, 64.4364407658577, 60.74687294661999, 64.75452929735184, 60.776214972138405, 53.748883455991745, 37.412260472774506, 20.58151200413704, 8.12313286587596, 5.553215816617012, 10.481546614319086, 8.777794986963272, 8.96060697734356, 5.478103347122669, 1.3710717600770295, 0.35248618572950363, 0.08906011091312394, 0.14027008175617084, 0.3106279583880678, 8.442857209593058, 34.32169251143932, 39.905299097299576, 38.87388624250889, 18.98489847779274, 24.848075062036514, 40.325868129730225, 50.81687718629837, 58.240926414728165, 67.44138792157173, 46.483452916145325, 4.3896242044866085, 0.03737695042218547, 0.08349536146852188, 0.10373184355557896, 0.022733070582034998, 0.08702565406565554, 0.00730584505618026, 0.017335610500595067, 0.032020933722378686, 0.057419743097852916, 0.0284034239302855, 0.06071066338336095, 0.01611531748494599, 0.02203774500230793, 0.05119820038089529, 0.030030237612663768, 0.05109530902700499, 0.011394653411116451, 0.04729093758214731, 0.012484272774599958, 0.01600999374204548, 0.03730955970240757, 0.059166788414586335, 0.0320104842830915, 0.04768658021930605, 0.06600969427381642, 0.05109028839797247, 0.07148407239583321, 0.12576590379467234, 0.12339909837464802, 0.09736139632877894, 0.1381832515471615, 0.17315703502390534, 0.15836356789804995, 0.1181254860421177, 0.11456442400231026, 0.1874434668570757, 0.1318833528785035, 0.07648274870007299, 0.1000466498953756, 0.15267821203451604, 0.16084585891803727, 0.14893461135216057, 0.0795664984616451, 0.1180450149695389, 0.21123899234225973, 0.20696439984021708, 0.1380039338255301, 0.09497276434558444, 0.23260873393155634, 0.14545571990311146, 8.128608372062445, 64.97701495885849, 85.26652783155441, 77.03268125653267, 65.4675230383873, 61.3108766824007, 37.296142503619194, 50.81368915736675, 78.96436080336571, 80.68631440401077, 64.21780049800873, 21.474940963089466, 2.9739971039816737, 0.1150104176485911, 0.44486112892627716, 0.6785307184327394, 2.733313268981874, 6.855861442163587, 14.639602694660425, 17.301343716681004, 23.285198025405407, 17.788631469011307, 20.593103282153606, 30.06151881068945, 27.497002221643925, 42.3669970035553, 50.463944524526596, 62.915082201361656, 61.850018352270126, 60.7505739480257, 55.4123467952013, 60.9625493735075, 64.39694568514824, 60.67877680063248, 57.154880091547966, 52.591370567679405, 52.07440450787544, 55.415762811899185, 60.980442613363266, 64.88752216100693, 62.97450341284275, 58.467835038900375, 56.0349015891552, 56.89244717359543, 63.305853232741356, 60.27166284620762, 58.967105448246, 58.66108886897564, 53.568632528185844, 49.88417163491249, 46.92441165447235, 48.56734849512577, 50.386398285627365, 48.20859834551811, 48.253063559532166, 48.617612197995186, 55.847909823060036, 60.71519784629345, 66.44661650061607, 63.79662349820137, 57.54347003996372, 54.399226158857346, 57.90922701358795, 35.03142222762108, 56.00543797016144, 63.43088172376156, 60.189724043011665, 57.73130916059017, 52.56172075867653, 58.48276063799858, 54.259458258748055, 58.0535052716732, 60.083021968603134, 59.13776949048042, 53.88640187680721, 54.788059294223785, 54.327246621251106, 55.90982370078564, 57.04183615744114, 60.02609722316265, 58.42634126543999, 60.346594825387, 60.134292617440224, 62.78686188161373, 60.246473997831345, 61.548040956258774, 59.05073896050453, 56.21402017772198, 55.10725736618042, 55.72594776749611, 64.43847745656967, 63.299952149391174, 57.68406629562378, 58.17241229116917, 66.71048954129219, 65.85363551974297, 65.45996904373169, 65.53342670202255, 67.51867577433586, 65.37343248724937, 55.652687698602676, 45.254500061273575, 31.421957910060883, 22.171097807586193, 27.36771795898676, 17.055930085480213, 15.433755330741405, 14.533374644815922, 5.31365149654448, 1.5394488000310957, 0.5309494282118976, 0.234480949875433, 0.29251878324430436, 0.47044040635228157, 10.58740608394146, 48.59127581119537, 48.297456577420235, 38.93651828169823, 26.382149644196033, 29.548324048519135, 42.164927646517754, 56.21899411082268, 65.57568803429604, 74.36631873250008, 53.80510523915291, 5.610810276120901, 0.21134462964255363, 0.2841310005169362, 0.18980545573867857, 0.13222895620856434, 0.18657988897757605, 0.10959988649119623, 0.08819122667773627, 0.14266963815316558, 0.1984557806281373, 0.14139039820292965, 0.2618708153022453, 0.14669415657408535, 0.1168287091422826, 0.09022656668093987, 0.19518749584676698, 0.1567729376256466, 0.08179124939488247, 0.14500887278700247, 0.11182138681760989, 0.10734834402683191, 0.19193723041098565, 0.1083675428526476, 0.1717845071107149, 0.12918876309413463, 0.15454134409083053, 0.11021324186003767], [0.03612446860643104, 0.07061605647322722, 0.046765805018367246, 0.023114556752261706, 0.04322239867178723, 0.0038581537273785216, 0.08800540774245746, 0.023108734603738412, 0.04743434277770575, 0.04626864400052, 0.02777756151772337, 0.04219507703965064, 0.0362219014641596, 0.02434501348034246, 0.054232845941442065, 0.10446886299178004, 0.0021885139494770556, 0.01311065005211276, 0.047036722316988744, 0.010825267509062542, 0.0060954824402870145, 0.05159306376299355, 0.06906869341037236, 0.12119020713726059, 16.7476849257946, 53.00043001770973, 61.83997929096222, 55.10411113500595, 51.15598998963833, 27.0583176612854, 16.786404848098755, 21.316400170326233, 30.044433027505875, 38.887174129486084, 22.990426942706108, 4.598267208784819, 0.1429040529183112, 0.053679819757235236, 0.10854807027499191, 0.17413264751667157, 2.3230141354724765, 4.234074801206589, 5.928731616586447, 8.882574364542961, 16.072345264256, 23.811766169965267, 14.1812152415514, 28.73580414801836, 44.13964368402958, 56.222189739346504, 66.06707006692886, 64.43106025457382, 59.06354047358036, 62.63317532837391, 56.76904499530792, 58.091761618852615, 59.16481263935566, 59.98427666723728, 51.36834159493446, 45.680377408862114, 43.802506774663925, 50.51742285490036, 57.32706405222416, 57.29821600019932, 56.35865181684494, 58.01404818892479, 53.74941922724247, 55.531956776976585, 57.638476341962814, 55.523612424731255, 53.585670813918114, 49.24025438725948, 46.37496493756771, 44.86607350409031, 42.807887345552444, 43.695462718605995, 45.02313047647476, 44.06344637274742, 43.88753101229668, 47.09577485918999, 54.21781249344349, 55.95836989581585, 56.975297927856445, 54.36107620596886, 57.65772230923176, 49.01364594697952, 55.90778701007366, 28.159099593758583, 49.206204414367676, 59.66878339648247, 56.02670542895794, 49.93049494922161, 46.099000945687294, 47.48097538948059, 47.347009778022766, 51.05735868215561, 56.65301442146301, 58.44467148184776, 53.41736264526844, 52.607713490724564, 52.1952798217535, 52.61240243911743, 51.50384232401848, 52.197126522660255, 52.24420979619026, 52.80475191771984, 53.43383476138115, 53.04624795913696, 54.89804819226265, 55.107990726828575, 54.94064390659332, 55.9345755726099, 51.92802496254444, 52.54163883626461, 57.93862223625183, 58.38153786957264, 51.523209884762764, 46.857314854860306, 54.836730882525444, 58.26344780623913, 59.08451534807682, 57.292561903595924, 57.58856602013111, 61.1504302918911, 60.670044869184494, 51.77026882767677, 37.23341166973114, 28.976677022874355, 11.864952631294727, 9.401752855628729, 5.55565576069057, 5.161535684019327, 4.722820725291967, 1.551298820413649, 0.0829665812489111, 0.0307285150847747, 0.024039122472458985, 0.04814110114239156, 0.44877135660499334, 16.533068642020226, 41.107695177197456, 27.77927577495575, 18.650907799601555, 18.44120655208826, 28.070041872560978, 31.61518894135952, 39.211463928222656, 49.3157297372818, 52.192562967538834, 20.479257591068745, 0.4411874682409689, 0.12123694017645903, 0.03733980222023092, 0.006748476380380453, 0.06985777450609021, 0.031717376768938266, 0.1292130461661145, 0.02013370019994909, 0.024769080373516772, 0.03666452947072685, 0.027055004684370942, 0.029511699030990712, 0.07914564877864905, 0.044319081425783224, 0.04788108970387839, 0.021520731534110382, 0.05033965797338169, 0.03532186558004469, 0.023968171299202368, 0.048807249186211266, 0.024142999027390033, 0.028452526275941636, 0.013741550719714724, 0.01563501064083539, 0.02034977649600478, 0.07988376659341156, 0.031071912380866706, 0.02404611535894219, 0.04052580137795303, 0.08414837720920332, 0.021191080668359064, 0.022862913028802723, 0.05959457346762065, 0.026135572770726867, 0.04086482927959878, 0.055566889786859974, 0.025111106551776174, 0.027604991773841903, 0.057005825074156746, 0.024954878899734467, 0.00333535382651462, 0.09335614406154491, 0.04159754797001369, 0.05886548387934454, 0.04452677516383119, 0.03993610938778147, 0.05072730768006295, 0.07351345295319334, 0.04100192993064411, 0.2652787871193141, 20.449495688080788, 62.55389258265495, 70.30879765748978, 62.79304414987564, 56.69902615249157, 35.408665984869, 20.176383443176746, 26.04220848530531, 39.13016729056835, 44.55634452402592, 26.245607770979404, 5.337861897423863, 0.10337849220377393, 0.07761590430163778, 0.16132212476804852, 0.8243501500692219, 4.113021846860647, 9.09463718533516, 12.839295398443937, 15.578988287597895, 15.008735787123442, 9.251310378313065, 11.62683555856347, 25.901999808847904, 41.046784445643425, 55.382199212908745, 65.0114107131958, 64.72789272665977, 61.55124418437481, 62.56884478032589, 57.730078026652336, 57.699531465768814, 62.52847574651241, 60.69001279771328, 55.55064417421818, 47.78680957853794, 45.59156857430935, 51.92579448223114, 58.12267675995827, 59.16860483586788, 58.47558282315731, 56.44887037575245, 56.34625308215618, 55.787926241755486, 59.97238710522652, 56.74305059015751, 57.041893154382706, 51.877168491482735, 49.823918268084526, 46.167226284742355, 45.54521106183529, 45.43553754687309, 45.153132900595665, 44.72307577729225, 46.98202796280384, 48.534054681658745, 58.34608197212219, 57.66194008290768, 60.33399470150471, 55.35505346953869, 58.38770113885403, 48.94707351922989, 55.83888150751591, 30.79393330961466, 51.57194226980209, 62.3722243309021, 57.70857498049736, 52.411024644970894, 48.89755837619305, 48.84734787046909, 49.34243090450764, 53.57923775911331, 58.20919431746006, 60.63800498843193, 54.85982604324818, 51.573401391506195, 51.59866623580456, 53.49128767848015, 52.06189937889576, 54.240052700042725, 53.47321204841137, 52.91301570832729, 55.69897681474686, 55.52422799170017, 56.790897622704506, 56.43475793302059, 56.096899062395096, 55.681927129626274, 51.60361737012863, 52.297068759799004, 60.64597316086292, 59.29268337786198, 53.57482999563217, 49.68598186969757, 57.925797924399376, 60.48438303172588, 60.96095725893974, 60.6904573738575, 60.263238698244095, 63.67231696844101, 61.48309104144573, 54.730450585484505, 41.02321811020374, 25.926525592803955, 9.399683866649866, 7.639283454045653, 10.902938302606344, 12.329591698944569, 8.339912183582783, 4.99872962012887, 0.7663180015515536, 0.11655392896500416, 0.060348220722517, 0.0586071459838422, 0.6514605553820729, 18.230996131896973, 37.780753299593925, 33.70979994535446, 23.441515937447548, 19.20075349509716, 35.012803226709366, 39.08999964594841, 46.78593568503857, 55.22641897201538, 60.64755007624626, 25.959044247865677, 0.3418836562195793, 0.15213819569908082, 0.017757031637302134, 0.014344542923936388, 0.08558233268558979, 0.059909270057687536, 0.04149187356233597, 0.02149021627701586, 0.018310838931938633, 0.01573930279846536, 0.04951088681991678, 0.0534283207525732, 0.08250245693488978, 0.0880846542713698, 0.017810948666010518, 0.023370337949017994, 0.019392038630030584, 0.06037735001882538, 0.03764475441130344, 0.007676440673094476, 0.024990095662360545, 0.08922454115236178, 0.04777177506184671, 0.07490730276913382, 0.04522944429481868, 0.03271283800131641, 0.10940539184957743, 0.23932568990858272, 0.15659443626645952, 0.13169012730941176, 0.18398171901935712, 0.1653140183771029, 0.14102399989496917, 0.08183091718819924, 0.15915453404886648, 0.2034560896572657, 0.10882682836381719, 0.1371885064872913, 0.17245159397134557, 0.09910974040394649, 0.1528175428393297, 0.22688368801027536, 0.17358130600769073, 0.15725473989732563, 0.1002856066043023, 0.24641265103127807, 0.12065379021805711, 0.12077043356839567, 0.15283636370440945, 0.5975782591849566, 26.128461956977844, 71.00128009915352, 77.77288153767586, 71.40368610620499, 63.59836533665657, 41.2662036716938, 25.678917579352856, 29.4354435056448, 43.435625061392784, 52.96102233231068, 31.51552028954029, 6.692365715280175, 0.4719695571111515, 0.23783930169884115, 0.3585893410490826, 0.7361442362889647, 6.4523606188595295, 15.201751179993153, 16.026933901011944, 19.151529036462307, 27.839648835361004, 34.65137802064419, 20.652796179056168, 33.68783712387085, 47.17205196619034, 58.00279699265957, 70.06457716226578, 67.76894554495811, 63.98586094379425, 64.84216779470444, 57.25913889706135, 58.62233854830265, 64.97870206832886, 63.84673520922661, 57.82562769949436, 50.303904712200165, 47.22145691514015, 54.50215883553028, 62.095762565732, 61.3660953193903, 59.10664916038513, 58.95350217819214, 55.81035643815994, 56.948809549212456, 62.569441348314285, 60.94024837017059, 58.83287765085697, 54.54147532582283, 50.660530775785446, 48.524665385484695, 48.822489604353905, 48.415159061551094, 48.44991959631443, 46.94512814283371, 49.402171298861504, 50.509804263710976, 61.13969586789608, 60.05636639893055, 64.06596064567566, 57.31922507286072, 57.99233615398407, 49.28715147078037, 56.16996914148331, 34.3130973726511, 53.604931980371475, 65.4048340022564, 60.47227308154106, 54.601018130779266, 51.838752552866936, 50.74900142848492, 51.398948952555656, 57.033909782767296, 62.38417848944664, 63.309873417019844, 56.15056738257408, 52.91306510567665, 53.4743519872427, 54.51183311641216, 52.31855660676956, 54.251140505075455, 53.43872509896755, 54.967041090130806, 57.597476541996, 56.961003094911575, 58.15516121685505, 58.727277517318726, 57.177473679184914, 57.90516883134842, 51.429826095700264, 52.79795788228512, 63.431246504187584, 63.01129303872585, 55.79606920480728, 52.39057034254074, 60.768763571977615, 63.04339751601219, 64.60645884275436, 63.06221790611744, 62.76688255369663, 64.28581684827805, 63.31021159887314, 55.49204371869564, 42.85714790225029, 34.12285678088665, 20.46254798769951, 15.894331466406584, 16.518257036805153, 19.72714874893427, 14.26177091896534, 5.0004172045737505, 0.4356068739434704, 0.1464822140405886, 0.19190585240721703, 0.2210308739449829, 0.794330514036119, 23.47314164042473, 54.4502118229866, 40.49087047576904, 28.27786412090063, 26.58548053354025, 42.21424140036106, 43.85903634130955, 55.40959194302559, 63.23473624885082, 71.53115406632423, 30.982293002307415, 0.8108735794667155, 0.305103114224039, 0.16343608789611608, 0.09748724973178469, 0.13355456554563716, 0.16262400022242218, 0.16556683840462938, 0.12258121452759951, 0.07928544713649899, 0.18051474646199495, 0.16940959001658484, 0.195610252849292, 0.22098024463048205, 0.2942777919815853, 0.11259892751695588, 0.10643693472957239, 0.11232744989683852, 0.21805354073876515, 0.11949083738727495, 0.16311176936142147, 0.07082740528858267, 0.1884285343112424, 0.07528320056735538, 0.13517924555344507, 0.18659056106116623, 0.16733969561755657], [0.03197093894414138, 0.05778264217951801, 0.04245995696692262, 0.04744393874716479, 0.05780997918918729, 0.005777872920589289, 0.09403417760040611, 0.050843676435761154, 0.02416685350908665, 0.03087400757067371, 0.07787354828906246, 0.07511013915063813, 0.08562910283217207, 0.04834767052670941, 0.02204480468208203, 0.028230343959876336, 0.04365237306046765, 0.014063771759538213, 0.053417585586430505, 0.014957214589230716, 0.010692674477468245, 0.06254469582927413, 0.038729577645426616, 0.6802351051010191, 25.584374852478504, 65.84155216813087, 57.265609949827194, 52.87598289549351, 38.931859731674194, 29.54580668359995, 31.793900951743126, 36.838460862636566, 45.51365375518799, 33.873305171728134, 9.860233403742313, 0.6990204658359289, 0.04807916149729863, 0.044811930565629154, 0.5625536979641765, 0.30204825627151877, 3.172943741083145, 5.5394976027309895, 5.645229779183865, 8.048438373953104, 14.384869113564491, 15.123542826622725, 25.4653462395072, 50.62372975051403, 58.307848423719406, 61.435038819909096, 55.93472756445408, 56.72218970954418, 56.61639578640461, 60.5277045071125, 59.4613753259182, 56.75707943737507, 60.4570434987545, 57.704539597034454, 53.79491798579693, 43.660253807902336, 41.90417043864727, 49.05210368335247, 55.1176992058754, 58.82044851779938, 58.047342002391815, 56.65335260331631, 54.377848505973816, 54.755498841404915, 57.4149077385664, 53.65389995276928, 52.27533772587776, 49.62007440626621, 46.23049668967724, 43.82198452949524, 42.67980381846428, 42.512008622288704, 45.1423566788435, 42.257163897156715, 44.35063876211643, 53.12103934586048, 60.84012754261494, 53.30064430832863, 57.60806277394295, 51.03201024234295, 56.95666752755642, 49.95503783226013, 56.34482815861702, 29.68152590095997, 46.10538460314274, 58.33251670002937, 53.644541054964066, 50.53068794310093, 44.78171423077583, 44.976894557476044, 45.26980184018612, 50.775121226906776, 54.05774988234043, 56.698714569211006, 52.793907299637794, 53.18340539932251, 53.43165747821331, 52.99719639122486, 51.678568348288536, 53.09514373540878, 54.93123181164265, 51.921512112021446, 51.90653711557388, 52.216927260160446, 52.825574800372124, 53.307476341724396, 52.41190619766712, 54.14821542799473, 50.84929704666138, 54.00533929467201, 54.516430869698524, 58.87393444776535, 54.81646277010441, 48.15512381494045, 45.38069128990173, 47.475378289818764, 50.21734915673733, 54.03850771486759, 57.31207765638828, 59.17508348822594, 58.38799752295017, 63.6352613568306, 53.44172693789005, 34.307982847094536, 14.93114585056901, 9.862403087317944, 9.406848382204771, 8.163464851677418, 6.593649862334132, 2.2868312895298004, 0.3984877048060298, 0.11855751989060082, 0.08103430329356343, 0.059903818983002566, 0.03269657012424432, 2.9233990190550685, 30.423441790044308, 45.547350347042084, 30.478825718164444, 18.36032599210739, 29.09414391964674, 39.63658891618252, 38.21443162858486, 46.75447337329388, 53.04275594651699, 36.84422515332699, 4.245758224278688, 0.1153824117500335, 0.06395611228072084, 0.04836776417505462, 0.027987938119622413, 0.05930146224272903, 0.04101527374587022, 0.08958820093539543, 0.03281260491348803, 0.04068937443662435, 0.07139750829082914, 0.08760901924688369, 0.0025243705613320344, 0.04860022338107228, 0.03579098825866822, 0.033471557835582644, 0.052100766988587566, 0.03914505417924374, 0.01858521834947169, 0.06223205498827156, 0.03661857939732727, 0.013306022283359198, 0.05013514804886654, 0.03821673875791021, 0.01834839717048453, 0.019692350542754866, 0.02033799304626882, 0.03054492630326422, 0.022718528198311105, 0.034530576594988815, 0.023433268361259252, 0.028346859289740678, 0.05680843605659902, 0.0140225426730467, 0.04488521022722125, 0.03990116165368818, 0.01944770156114828, 0.022488954091386404, 0.04237834298692178, 0.04438295065483544, 0.045528466725954786, 0.02318604227184551, 0.03563869213394355, 0.014534881538565969, 0.0433687205077149, 0.04777351539814845, 0.04825966294447426, 0.019712501707545016, 0.0419586065254407, 0.784327135188505, 33.04608575999737, 73.8525103032589, 64.99093741178513, 57.6565557718277, 47.05675855278969, 36.57690189778805, 37.34270140528679, 28.33978559821844, 38.327600955963135, 35.754135847091675, 9.711253847926855, 0.8284624200314283, 0.06364990957081318, 0.021057412450318225, 1.3858768343925476, 2.9082442447543144, 6.892684316262603, 12.484505586326122, 13.77703282982111, 13.406322821974754, 9.592348728328943, 10.902486126869917, 23.276202008128166, 47.09054633975029, 58.43058183789253, 63.604646399617195, 60.026169419288635, 59.89577181637287, 61.24716930091381, 62.840777188539505, 59.960911720991135, 57.95992769300938, 62.15358026325703, 58.99662986397743, 55.4154322296381, 46.49151988327503, 44.39313568174839, 51.55714586377144, 58.35357517004013, 60.25359481573105, 57.009674683213234, 57.25302882492542, 55.56079722940922, 56.90360717475414, 60.251037552952766, 56.615259647369385, 53.9039721339941, 50.586096569895744, 49.57359530031681, 45.00400610268116, 44.850729927420616, 44.74196836352348, 46.86937540769577, 43.70797544717789, 45.871237367391586, 55.17107494175434, 62.81803920865059, 55.10598823428154, 58.68277430534363, 52.611847668886185, 58.43479581177235, 50.117444917559624, 56.8640360981226, 31.34361181408167, 48.31298254430294, 59.18303266167641, 56.16204276680946, 52.4731133133173, 47.60867893695831, 47.1553822606802, 47.4640890955925, 52.53253452479839, 55.78806683421135, 58.138814494013786, 53.44668187201023, 53.802794963121414, 52.306982427835464, 52.08017639815807, 52.3201335221529, 53.031801134347916, 54.22900289297104, 52.741591706871986, 51.949132829904556, 52.404044419527054, 54.07490216195583, 54.74964715540409, 53.20167101919651, 54.59956280887127, 53.629740849137306, 53.952560126781464, 56.036349311470985, 60.23583456873894, 56.87702380120754, 50.23254834115505, 47.209856137633324, 49.56462398171425, 53.07314671576023, 56.13592676818371, 58.54200325906277, 61.738916113972664, 61.059744358062744, 64.52782586216927, 55.52663326263428, 35.48530787229538, 15.529274605214596, 8.61320111900568, 9.85581424087286, 6.227375641465187, 9.01709284633398, 6.527248425409198, 2.319827056489885, 0.6376461591571569, 0.1413165545091033, 0.20343484939076006, 0.03940519178286195, 3.755232570692897, 30.563342683017254, 40.97388155758381, 30.74940349906683, 20.710978657007217, 34.375786408782005, 42.299911603331566, 40.91250345110893, 53.809296414256096, 60.0378043949604, 43.38738664984703, 5.763790542259812, 0.05639459966914728, 0.04501930146943778, 0.006898985320731299, 0.011414230339141795, 0.025024867136380635, 0.02402411810180638, 0.05085032978968229, 0.08721540638362058, 0.01005253407129203, 0.04106688640604261, 0.06825990087236278, 0.014480347599601373, 0.0063467532345384825, 0.002918534005402762, 0.030114423134364188, 0.02540271307225339, 0.03855176648357883, 0.04065475695824716, 0.04240100446622819, 0.03775014680286404, 0.017115513619501144, 0.054001941534806974, 0.015060110581543995, 0.027195031252631452, 0.03189773349731695, 0.0844488653820008, 0.16673779900884256, 0.19331753603182733, 0.12983514403458685, 0.11383461824152619, 0.15842955966945738, 0.18475659540854394, 0.13288755289977416, 0.10810410269186832, 0.19390239292988554, 0.19262294517830014, 0.18065557640511543, 0.12121662759454921, 0.12198748896480538, 0.2107206912478432, 0.12890480255009606, 0.10889974437304772, 0.11071675195125863, 0.16210949892411008, 0.07124205061700195, 0.21618251223117113, 0.1738976687192917, 0.1079214749915991, 1.629926220048219, 41.32552608847618, 81.83435440063477, 73.36410731077194, 68.78700971603394, 54.52050045132637, 42.69993133842945, 42.97674648463726, 50.893971249461174, 57.934279069304466, 44.93384286761284, 14.30051838979125, 1.1198829137720168, 0.18963845766847953, 0.12780133285559714, 1.631892139557749, 2.6838665222749114, 9.2787392064929, 12.67321391031146, 18.134021535515785, 18.064587861299515, 22.339613065123558, 23.513130694627762, 29.69009444117546, 54.380360171198845, 58.62381286919117, 65.47679454088211, 60.90863786637783, 62.706344202160835, 61.84761308133602, 64.98646885156631, 61.62816725671291, 58.514124155044556, 64.2997545003891, 63.245132490992546, 58.337080255150795, 48.8145936280489, 46.28355324268341, 54.33917038142681, 61.10471874475479, 63.122908249497414, 58.527579233050346, 57.283978164196014, 55.85352212190628, 57.734622582793236, 63.17007511854172, 58.79906706511974, 57.293291464447975, 53.562115877866745, 51.8873405456543, 48.17233309149742, 48.00497107207775, 47.97163546085358, 51.20531514286995, 47.472156062722206, 49.319069758057594, 58.13206605613232, 66.08166128396988, 57.15797312557697, 61.237947195768356, 54.881606474518776, 59.801286086440086, 52.16519683599472, 56.632685512304306, 34.672831669449806, 50.50086334347725, 62.08263427019119, 58.79790812730789, 54.839405938982964, 49.46897551417351, 49.68549929559231, 49.62274946272373, 56.05114571750164, 57.45824821293354, 61.25717796385288, 55.4463055729866, 54.551434591412544, 54.685920774936676, 52.82691612839699, 52.37500637769699, 54.016180112957954, 55.985686630010605, 53.403295800089836, 53.6730395257473, 52.845364138484, 54.17898237705231, 55.14560490846634, 53.86950418353081, 56.142390221357346, 52.98130564391613, 53.91816057264805, 58.67047056555748, 63.58702674508095, 59.4768100976944, 53.70729088783264, 49.25675310194492, 52.45895527303219, 54.52546298503876, 58.55192072689533, 60.81247262656689, 65.07861390709877, 63.198413997888565, 67.86755785346031, 56.83576941490173, 40.079751536250114, 18.655729740858078, 17.04769402742386, 16.92909099161625, 13.494236804544926, 17.613783851265907, 7.864308804273605, 1.990553350187838, 0.5452490109018981, 0.26078368769958615, 0.22819004603661597, 0.333996526314877, 4.666937123984098, 41.70270524919033, 58.51811774075031, 42.62951351702213, 28.399660885334015, 37.18633979558945, 49.6276094019413, 52.486933171749115, 60.03719262778759, 67.98215210437775, 50.76695166528225, 7.324869325384498, 0.20834782248130068, 0.1493529896833934, 0.12187916508992203, 0.07942664815345779, 0.089982466888614, 0.13402012962615117, 0.2019679351360537, 0.3565959620755166, 0.08529365208232775, 0.2154843442258425, 0.18006559868808836, 0.10416879042168148, 0.1590400206623599, 0.10832968589966185, 0.14303115312941372, 0.09851221504504792, 0.11268896487308666, 0.13047727989032865, 0.14694148470880464, 0.11958142393268645, 0.1170901974546723, 0.13348551612580195, 0.15321932674851269, 0.1347990581416525, 0.1499207178130746], [0.030848924834572244, 0.010876841206481913, 0.03634074157162104, 0.005042658294769353, 0.08787421829765663, 0.03045026536710793, 0.01762081970809959, 0.023837835324229673, 0.054733405995648354, 0.04277712490875274, 0.0050038769040838815, 0.04263623930455651, 0.034456948123988695, 0.04430431639775634, 0.03470810945145786, 0.029122286723577417, 0.039717810359434225, 0.027445782543509267, 0.07979401125339791, 0.031866125427768566, 0.05923014927248005, 0.056352783358306624, 0.018509747496864293, 2.3815283831208944, 41.292445063591, 61.678795740008354, 55.45820653438568, 48.02229054272175, 24.373197443783283, 16.695903204381466, 18.74267667531967, 51.85763753950596, 52.59776182472706, 16.39083657413721, 2.4520894093438983, 0.013792418449156685, 0.13625104038510472, 0.14818542811553925, 0.4214658436831087, 2.1409507049247622, 5.2030926290899515, 13.017800319939852, 18.04684281349182, 16.084430515766144, 18.81368536502123, 24.6110437810421, 43.59139770269394, 56.745037883520126, 61.088805198669434, 59.60368148982525, 61.1008657515049, 55.9748762100935, 55.78737907111645, 58.57222303748131, 60.08269898593426, 56.21223047375679, 56.84838093817234, 56.03849619626999, 54.36882399022579, 45.31970076262951, 42.10696555674076, 47.96355329453945, 55.70224843919277, 57.39650912582874, 55.38479447364807, 54.75238300859928, 56.62116453051567, 57.331844195723534, 55.70137448608875, 53.0349587649107, 49.67595040798187, 45.15640452504158, 44.69581983983517, 40.74454866349697, 42.66645133495331, 43.52760672569275, 43.52831728756428, 40.50554908812046, 48.32986503839493, 55.72586417198181, 57.16010861098766, 54.32660445570946, 55.907935202121735, 54.46421027183533, 56.21670663356781, 49.24568049609661, 56.266027987003326, 30.049486756324768, 44.42544914782047, 60.56021936237812, 53.952742516994476, 49.595542922616005, 43.133058696985245, 44.83696326613426, 44.22527588903904, 49.27433095872402, 53.2320199906826, 58.6249566078186, 52.74147771298885, 52.89602302014828, 51.61762721836567, 50.676995292305946, 51.00768394768238, 52.6320967823267, 50.210992097854614, 52.51448169350624, 50.86552977561951, 53.10631513595581, 51.05406425893307, 54.61998291313648, 49.922952353954315, 53.02417874336243, 52.08193190395832, 50.149226412177086, 58.143735229969025, 55.5703005194664, 57.08084486424923, 54.57178249955177, 51.64103776216507, 45.53794205188751, 47.67417222261429, 50.52026130259037, 53.42669874429703, 56.499829441308975, 58.36108356714249, 57.838569805026054, 63.614225685596466, 53.881139159202576, 27.356538958847523, 16.501423940062523, 11.385811641812325, 7.977854311466217, 5.953982686623931, 5.538768041878939, 3.70749288238585, 0.35595700261183083, 0.114386850327719, 0.13840509433066472, 0.019362078128324356, 0.08613685058662668, 7.6948863454163074, 38.847926035523415, 50.1012159883976, 26.01318184286356, 13.762273471802473, 29.84359860420227, 39.096504896879196, 43.83748009800911, 53.23790967464447, 46.523259580135345, 8.59627302736044, 0.3548985219094902, 0.016172945252037607, 0.07012948219198734, 0.06458990639657713, 0.013867124889657134, 0.03996358369477093, 0.04189802501059603, 0.02559406842919998, 0.05892180175578687, 0.005664238051394932, 0.03083261242863955, 0.05481899046571925, 0.03872675006277859, 0.0665398919954896, 0.06126054657215718, 0.01706465980532812, 0.07293589878827333, 0.016097097759484313, 0.04342668595199939, 0.05820665341161657, 0.07006083353189752, 0.012929661570524331, 0.012611692109203432, 0.016082483016361948, 0.03994946804596111, 0.0071564168683835305, 0.025317842919321265, 0.03792972056544386, 0.047484404349233955, 0.04064994413056411, 0.0364543087198399, 0.0024721266117921914, 0.09108506827033125, 0.06826743367128074, 0.025090229937632103, 0.008028550782910315, 0.056455837984685786, 0.07380145078059286, 0.025006864489114378, 0.022377720997610595, 0.03324542543850839, 0.011973862565355375, 0.03529136331053451, 0.1614168970263563, 0.008455469378532143, 0.05415119114331901, 0.021689533023163676, 0.033328056160826236, 3.660238618031144, 51.30329288542271, 72.09650292992592, 62.798895835876465, 54.85728397965431, 35.48178546130657, 25.86680419743061, 23.014821633696556, 52.423032000660896, 52.8639717400074, 19.092472605407238, 2.5433609867468476, 0.046393944503506646, 0.09363168122945353, 0.23997846816200763, 1.7674660147167742, 7.07574519328773, 9.584001526236534, 10.669239442795515, 10.701339170336723, 11.616422217339277, 15.258002411574125, 21.313656717538834, 44.81206700205803, 57.93132282793522, 61.62751369178295, 60.94834953546524, 64.10679325461388, 57.211690843105316, 57.01151378452778, 59.689917862415314, 61.29251606762409, 56.76992654800415, 58.72668854892254, 58.75615976750851, 56.55818670988083, 47.74119682610035, 44.91638660430908, 50.086206793785095, 58.61034259200096, 58.998974338173866, 57.028164491057396, 54.53095369040966, 56.65869511663914, 58.011764511466026, 58.34207698702812, 54.762110486626625, 51.89073756337166, 47.995361387729645, 48.04769977927208, 44.306599125266075, 44.86800380051136, 45.63533842563629, 46.95298232138157, 42.74149350821972, 49.22987714409828, 58.112770691514015, 60.35037562251091, 55.699387192726135, 59.07346934080124, 56.19888938963413, 57.41624526679516, 50.81903547048569, 55.48723317682743, 31.531002558767796, 47.51818299293518, 62.87926532328129, 56.18973568081856, 50.63908852636814, 44.66706298291683, 47.06874690949917, 46.1455712467432, 51.64991408586502, 56.21525891125202, 59.4311935454607, 54.99480240046978, 54.23826679587364, 51.50198422372341, 51.718416810035706, 51.50873266160488, 53.389703929424286, 50.32362185418606, 52.33645744621754, 51.25720135867596, 53.286467269062996, 52.585420086979866, 55.75652852654457, 51.53058148920536, 54.8914897441864, 51.503789126873016, 50.46055890619755, 58.93387243151665, 57.717420905828476, 59.84604388475418, 55.73247581720352, 52.92995899915695, 46.05653062462807, 49.024315774440765, 51.92333601415157, 55.27902714908123, 59.308433532714844, 61.13985925912857, 60.76957292854786, 64.36617493629456, 53.192251324653625, 30.937871485948563, 11.769184470176697, 8.911341670900583, 9.798027891665697, 8.170211389660835, 10.162799768149853, 7.812373666092753, 2.033053832128644, 0.15977246104739606, 0.24843782361131161, 0.03165777859976515, 0.11495535029098392, 10.189594980329275, 40.39922699332237, 51.213731691241264, 29.59598869085312, 20.939969569444656, 42.20262922346592, 45.9375362098217, 51.181790605187416, 59.38433066010475, 56.243293806910515, 12.333322148770094, 0.26024052465800196, 0.04920864346786402, 0.02763949793006759, 0.011406614048610209, 0.08358458988368511, 0.058227177505614236, 0.04527997341938317, 0.029111839139659423, 0.029646233706444036, 0.02075630458421074, 0.03735840044100769, 0.023579243243148085, 0.04112757924303878, 0.06720973964547738, 0.005363679374568164, 0.07504661873099394, 0.04927561487420462, 0.024046417784120422, 0.021582454101007897, 0.023837352928239852, 0.04392694172565825, 0.07801469735568389, 0.027996910685033072, 0.008086619200184941, 0.03276433562859893, 0.18663635157281533, 0.11109213024610654, 0.17166514007840306, 0.10459426368470304, 0.13050481356913224, 0.1849067912553437, 0.13613954011816531, 0.16186237859074026, 0.18730740150203928, 0.17195818451000378, 0.12833741580834612, 0.07504810302634723, 0.15615931508364156, 0.28675844077952206, 0.103937485255301, 0.21872505079954863, 0.11785975264501758, 0.09424226838746108, 0.1785533837391995, 0.20111198653467, 0.20880909694824368, 0.23625450470717624, 0.235445415310096, 5.2197666093707085, 61.81917540729046, 78.1979039311409, 73.08311998844147, 61.890801563858986, 37.067588567733765, 25.26437882333994, 27.207642048597336, 66.21230587363243, 63.708380833268166, 24.053807482123375, 3.087231977842748, 0.23374193406198174, 0.43367295584175736, 0.6030089990235865, 1.9650543434545398, 7.925445148721337, 14.398864712566137, 25.32691776752472, 26.67763128876686, 22.729627937078476, 27.32094816863537, 27.44485951960087, 48.72994937002659, 56.68080992996693, 63.724518567323685, 64.54477295279503, 67.7891756594181, 60.379972234368324, 60.54530516266823, 62.812445908784866, 63.24538707733154, 57.379600033164024, 58.77174653112888, 60.52390471100807, 60.73488838970661, 51.50781311094761, 47.33387388288975, 52.070547714829445, 61.914193108677864, 61.33543096482754, 56.729945093393326, 54.741640985012054, 56.89033828675747, 60.264868810772896, 60.847012773156166, 57.288325130939484, 55.1607470959425, 50.96331752836704, 51.31093427538872, 46.76819443702698, 47.99416445195675, 49.03897538781166, 49.01727855205536, 45.58711141347885, 54.50548745691776, 59.68633845448494, 63.35390165448189, 57.62497566640377, 60.3192400932312, 59.47506219148636, 58.74275788664818, 51.69061370193958, 55.556780844926834, 34.89287406206131, 51.031440272927284, 64.94603142142296, 58.539138212800026, 53.56292523443699, 46.74603022634983, 49.36072312295437, 48.863394409418106, 54.001353308558464, 57.47640743851662, 61.965611949563026, 56.99349895119667, 54.954554960131645, 52.086411863565445, 52.986841946840286, 51.9171005487442, 54.76659044623375, 51.684028655290604, 54.021712616086006, 52.009861171245575, 54.04344365000725, 52.492112293839455, 56.303019002079964, 51.477179154753685, 55.21438121795654, 52.50117860734463, 50.963465720415115, 59.85912658274174, 59.84679624438286, 62.821611016988754, 59.779281467199326, 56.92350670695305, 50.33339872956276, 51.933473870158195, 54.29844796657562, 59.04302157461643, 61.62319332361221, 64.94575023651123, 63.14712055027485, 66.4498995244503, 55.88222578167915, 32.811740934848785, 21.868067868053913, 23.07364247739315, 20.298588685691357, 16.358067132532597, 15.292205326259136, 9.781692568212748, 1.9461847934871912, 0.2650118514429778, 0.3101466310909018, 0.1791371125727892, 0.4247794736875221, 11.107442378997803, 52.78549835085869, 62.79432088136673, 37.67245531082153, 21.411235481500626, 43.0971772223711, 50.204065069556236, 60.279976800084114, 66.45103946328163, 66.98175698518753, 17.575673796236515, 0.5654996680095792, 0.1819917539251037, 0.15956645569531247, 0.1378186937654391, 0.19685953971929848, 0.1841385496663861, 0.18155464378651232, 0.20783798187039793, 0.20613944332581013, 0.07179408232332207, 0.12938755477080122, 0.09755004284670576, 0.1261570749920793, 0.1568396418588236, 0.052075830826652236, 0.15548381226835772, 0.15135551191633567, 0.0851580617018044, 0.11719861038727686, 0.17463586817029864, 0.19314181030495092, 0.17234818311408162, 0.08987943452666514, 0.07913054607342929, 0.14570499246474355], [0.04349614726379514, 0.022643100019195117, 0.0904569515842013, 0.10743694903794676, 0.013490769742929842, 0.02258822561998386, 0.07674443739233539, 0.04568493000988383, 0.021877621074963827, 0.04578109008434694, 0.03891932996339165, 0.021964469051454216, 0.02857733881683089, 0.021337855214369483, 0.031538767798338085, 0.05959819885902107, 0.058943320327671245, 0.0578486413724022, 0.055152648928924464, 0.04261823480192106, 0.028296061136643402, 0.020418380627234, 0.011782726141973399, 11.123696006834507, 55.79781711101532, 61.9946613907814, 51.20783440768719, 31.890643760561943, 18.183525279164314, 20.946277230978012, 37.59706735610962, 38.19702856242657, 30.021603852510452, 6.591123947873712, 0.3403306083055213, 0.05031847336795181, 0.060909896637895145, 0.1317472875234671, 2.256996715441346, 6.150412196293473, 6.8202554527670145, 8.878347091376781, 9.644472431391478, 18.176907934248447, 26.35487660765648, 36.78546890616417, 60.53351439535618, 60.46571463346481, 63.662084117531776, 60.22895693778992, 56.55592583119869, 50.32952293753624, 53.16745765507221, 59.3388357013464, 59.26332235336304, 57.28054694831371, 55.917290300130844, 56.11605003476143, 54.44374457001686, 46.0961738973856, 41.759322211146355, 47.661864683032036, 54.50881227850914, 55.663121938705444, 57.09103211760521, 54.02323253452778, 56.008694395422935, 56.389278173446655, 55.766727179288864, 50.95480978488922, 47.256848216056824, 44.44378696382046, 44.078489765524864, 40.91526970267296, 44.346310794353485, 40.66358260810375, 42.86157846450806, 40.01341849565506, 49.84979867935181, 54.31007154285908, 56.55274540185928, 53.384559005498886, 58.470217511057854, 53.23417827486992, 56.47981211543083, 50.22432178258896, 58.425695300102234, 31.96955032646656, 43.611802607774734, 58.268220350146294, 51.379250809550285, 51.88469968736172, 42.190276086330414, 42.467315420508385, 44.72892366349697, 47.53015615046024, 49.624835550785065, 55.73993481695652, 55.72221636772156, 55.71981489658356, 54.43043768405914, 53.26407507061958, 53.70677791535854, 55.68245530128479, 51.024547442793846, 51.522225737571716, 51.44413612782955, 52.408771365880966, 52.545818611979485, 51.61973610520363, 52.55190208554268, 47.61944755911827, 50.84227882325649, 50.910557359457016, 52.8531651198864, 54.50585223734379, 58.98552305996418, 58.68117079138756, 58.399670496582985, 54.39534656703472, 45.47037787735462, 44.572482258081436, 51.875230595469475, 55.198201686143875, 59.14892189204693, 59.62594449520111, 58.841009214520454, 53.30579303205013, 48.06403510272503, 27.65839096158743, 13.755982909351587, 5.2251689694821835, 5.901474254205823, 9.930248446762562, 4.773427359759808, 2.4231767607852817, 0.2076158273848705, 0.18981400527991354, 0.029607085416500922, 0.02985537092172308, 0.759971629595384, 22.824985720217228, 34.693472161889076, 37.08838865160942, 18.271055482327938, 18.496366292238235, 37.63448394834995, 41.21489502489567, 50.55651895701885, 46.28754302859306, 17.367357574403286, 0.9100693347863853, 0.02438603940390749, 0.04231902683386579, 0.013838638478773646, 0.04040392588649411, 0.03651956205430906, 0.038155110814841464, 0.022344921781041194, 0.04927840534946881, 0.034485279611544684, 0.02510042704670923, 0.021732280729338527, 0.0028272375493543223, 0.024722723974264227, 0.01751382242218824, 0.027087091439170763, 0.02900990886701038, 0.08592694153776392, 0.04082121326064225, 0.014556664500560146, 0.020480759994825348, 0.03835066301689949, 0.07378770620562136, 0.049371225759387016, 0.058960040914826095, 0.024922307893575635, 0.041035330286831595, 0.06997516000410542, 0.019374015573703218, 0.01378301358272438, 0.035834222071571276, 0.010246570436720503, 0.04452160239452496, 0.02712913596042199, 0.038651737486361526, 0.04047478985739872, 0.08071542470133863, 0.08738201853702776, 0.036288282863097265, 0.04026899972814135, 0.05737484687415417, 0.05206776739214547, 0.008925258134695468, 0.05687143326213118, 0.036336492776172236, 0.04573930345941335, 0.015722038588137366, 0.04253960425558034, 15.749284699559212, 63.97953048348427, 68.97260695695877, 59.59826298058033, 36.45392529666424, 20.43564163148403, 21.887484826147556, 33.43907207250595, 40.29929615557194, 35.372134745121, 7.273983405902982, 0.3542756225215271, 0.011736592387023848, 0.01153560302554979, 0.6670555716846138, 4.242143668234348, 11.140241269022226, 13.898944538086653, 15.191442333161831, 10.537505261600018, 10.591158382594585, 23.92698358744383, 41.830762177705765, 62.33663164079189, 61.361470967531204, 65.28303533792496, 61.982384249567986, 59.0835539996624, 54.85040254890919, 56.21040657162666, 62.357967495918274, 61.084424033761024, 56.71880029141903, 58.19203443825245, 59.16463024914265, 57.737373635172844, 47.743499502539635, 43.625968247652054, 48.96784320473671, 58.069217428565025, 58.08482699096203, 57.61578395962715, 55.36670744419098, 56.61978520452976, 58.24486680328846, 56.9859753549099, 52.05374501645565, 49.709593802690506, 46.34215749800205, 45.80643564462662, 43.66813078522682, 44.5332607626915, 43.487188294529915, 45.43490678071976, 42.43067018687725, 51.07653245329857, 56.914611384272575, 57.33547680079937, 55.88683873414993, 59.883650466799736, 54.585822746157646, 57.404469698667526, 51.67563110589981, 57.12083011865616, 33.705696165561676, 45.765401646494865, 59.849589094519615, 52.85577937960625, 53.044560849666595, 44.79858912527561, 45.454483330249786, 46.48925520479679, 49.82463642954826, 52.48072050511837, 57.65340194106102, 57.52040907740593, 56.67225658893585, 54.6160539239645, 54.172480925917625, 55.04047214984894, 55.287219509482384, 52.99949526786804, 53.17239739000797, 52.254735231399536, 52.88833983242512, 51.652490347623825, 52.531162798404694, 51.64737582206726, 51.53831787407398, 53.50960269570351, 50.253576412796974, 52.55383998155594, 58.01442436873913, 61.749566942453384, 60.06621167063713, 60.86438164114952, 57.54680626094341, 48.106786608695984, 47.14323431253433, 52.88038685917854, 57.433066964149475, 61.99796721339226, 63.06606709957123, 60.02933084964752, 56.66760943830013, 45.68274848163128, 25.05574531853199, 11.839390452951193, 9.665384609252214, 8.446933440864086, 6.038151495158672, 7.670973753556609, 5.334576023742557, 0.6812940607778728, 0.18888022023020312, 0.06521834220620804, 0.011623638438322814, 0.9132762439548969, 25.743136033415794, 35.947754457592964, 30.60082957148552, 21.064070910215378, 21.728575453162193, 44.69248741865158, 48.48515510559082, 56.01683735847473, 55.00615619122982, 24.652467258274555, 1.2789196986705065, 0.0077619073272217065, 0.0679233146365732, 0.038419259726651944, 0.03518267949402798, 0.03703931033669505, 0.019530165300238878, 0.06648204158409499, 0.02536601201427402, 0.01961053432751214, 0.018818588541762438, 0.006439797216444276, 0.02863948069716571, 0.05385869961173739, 0.01628485926630674, 0.052415652826312, 0.09212186341756023, 0.05469308511237614, 0.02226055999926757, 0.04160229400440585, 0.041701474619912915, 0.009786545560928062, 0.009631344855733914, 0.02550233155488968, 0.04489670609473251, 0.11092963701230474, 0.1354137493763119, 0.21926267741946504, 0.17742003517923877, 0.0802024373842869, 0.14170872018439695, 0.20119046122999862, 0.157915607560426, 0.11890485984622501, 0.1686561616952531, 0.1680985267739743, 0.2171873059705831, 0.1662576591479592, 0.19027226662728935, 0.24174293910618871, 0.19372438138816506, 0.16329392208717763, 0.16395784739870578, 0.2048022861708887, 0.19027704605832696, 0.10745925057563, 0.16056400607340038, 0.1882611057953909, 20.780830308794975, 74.63358879089355, 77.88239926099777, 69.07950282096863, 45.766807571053505, 29.515890888869762, 29.85344957560301, 52.51240320503712, 50.22703863680363, 41.89183630049229, 8.739535789936781, 0.7119215454440564, 0.15651516005164012, 0.18543971265899017, 0.41009453823789954, 6.238198410719633, 16.653696969151497, 19.07903842628002, 22.23320547491312, 22.58011545985937, 27.311146594583988, 31.20233729481697, 42.34671749174595, 64.88103970885277, 64.5866011083126, 66.3877272605896, 63.295004814863205, 60.03923311829567, 56.163270100951195, 58.113207668066025, 65.08132696151733, 63.266373351216316, 58.42057317495346, 58.35793733596802, 60.93220040202141, 60.54046422243118, 50.767677426338196, 45.63339672982693, 53.39882344007492, 59.000285267829895, 60.90934082865715, 59.23678457736969, 54.40745651721954, 56.864138692617416, 60.39700672030449, 60.65155506134033, 55.84721826016903, 51.53060428798199, 49.3603241443634, 48.6073337495327, 46.32554478943348, 48.316862136125565, 44.19871911406517, 48.83031718432903, 44.77742426097393, 53.39142143726349, 60.08991479873657, 60.736700892448425, 57.596682384610176, 62.80757077038288, 56.84763237833977, 58.5097049921751, 54.46643315255642, 57.672237530350685, 37.55525819957256, 49.07537743449211, 62.66139641404152, 57.51290448009968, 54.701157957315445, 47.210251316428185, 47.675361558794975, 49.207910522818565, 52.136276587843895, 54.73357401788235, 60.63673585653305, 59.457222148776054, 56.94980509579182, 56.72897234559059, 56.231229454278946, 56.48241117596626, 58.87009285390377, 53.45363549888134, 53.12539391219616, 53.32304410636425, 54.811701625585556, 53.05381715297699, 52.89645619690418, 53.08048412203789, 53.449634313583374, 56.23853646218777, 52.418392449617386, 52.39666901528835, 58.17368522286415, 64.20852899551392, 63.10624994337559, 63.594466745853424, 60.87709195911884, 50.46550244092941, 49.43871393799782, 54.04902175068855, 61.282416209578514, 64.48076158761978, 65.34846782684326, 63.48331891000271, 58.967888206243515, 48.82480747997761, 34.80215772986412, 22.125230468809605, 13.101450931280851, 17.000492960214615, 20.511629953980446, 13.198185190558434, 8.265085648745298, 0.3790992748690769, 0.35934941901359707, 0.10748195287305862, 0.19192476233001798, 1.1921145441010594, 30.965974777936935, 48.13067212700844, 49.98721830546856, 24.893524423241615, 26.316052190959454, 48.75988036394119, 54.69416633248329, 64.8390519618988, 60.35449840128422, 34.86272267997265, 2.2704881289973855, 0.1574045795132406, 0.16602328891167417, 0.12220481206895784, 0.1112869662756566, 0.1018846825172659, 0.13610556459752843, 0.1392942466191016, 0.09012711147079244, 0.1574222426279448, 0.1561433737515472, 0.1032818942621816, 0.1781097278581001, 0.15123120218049735, 0.12337538675637916, 0.15662596269976348, 0.17448737926315516, 0.2368134309654124, 0.167717790172901, 0.16602416464593261, 0.12643670139368623, 0.0959185128158424, 0.14653250196715817, 0.16044898802647367, 0.19759365735808387], [0.021640929771820083, 0.01513452572908136, 0.03154241174343042, 0.02653413019288564, 0.037565363163594157, 0.0045285633223102195, 0.061798351307515986, 0.043203592649661005, 0.037924447606201284, 0.06482376455096528, 0.004925173070660094, 0.058425924653420225, 0.018442720429447945, 0.021961487473163288, 0.026606673272908665, 0.06891307988553308, 0.07039765725494362, 0.02213112387835281, 0.02178384514991194, 0.03024691319296835, 0.015772990736877546, 0.02911036783189047, 0.5982612131629139, 28.109384961426258, 64.60235506296158, 55.10742835700512, 43.02556626498699, 34.525156393647194, 31.648385860025883, 29.46730099618435, 40.05061089992523, 44.37880665063858, 18.085908517241478, 1.3695753528736532, 0.031660995809943415, 0.028147776320111006, 0.13860715145710856, 0.12927850359119475, 1.9260307936929166, 9.118365962058306, 11.329012289643288, 7.185388784855604, 7.591030793264508, 27.036611326038837, 43.813036009669304, 56.27265863120556, 62.54943162202835, 60.16907215118408, 59.57109063863754, 59.54907462000847, 58.80776859819889, 48.67889150977135, 51.627578884363174, 57.220221385359764, 58.230294585227966, 56.38315290212631, 54.618227407336235, 56.66242651641369, 53.474272191524506, 44.82704199850559, 42.09496580064297, 44.526725113391876, 54.763413816690445, 54.702898263931274, 55.40752865374088, 54.08302992582321, 59.27814535796642, 55.52483215928078, 54.79891911149025, 48.01792837679386, 44.083824679255486, 42.04537846148014, 42.462831661105156, 40.951857939362526, 42.13387571275234, 41.58925473690033, 42.95409969985485, 41.068754866719246, 49.222649931907654, 52.50251993536949, 55.86276702582836, 56.35709770023823, 57.43959121406078, 52.06132560968399, 58.55535574257374, 50.844638496637344, 57.222786247730255, 30.806045159697533, 40.97628302872181, 59.912950694561005, 54.07964430749416, 53.37400697171688, 43.97766597568989, 43.29762406647205, 42.53475800156593, 44.302628338336945, 47.1983427554369, 52.86608062684536, 54.872027188539505, 55.25288835167885, 53.6833293735981, 54.62699353694916, 53.72208349406719, 54.6024164557457, 55.172853246331215, 54.58940975368023, 54.09518167376518, 53.44801180064678, 52.4465337395668, 53.54776404798031, 52.87504434585571, 46.23293995857239, 47.36423045396805, 51.668259501457214, 50.7724841684103, 50.0900673866272, 54.71050165593624, 57.17005267739296, 55.92286840081215, 58.36839057505131, 53.82503516972065, 44.40955840051174, 46.458541452884674, 54.78473447263241, 57.84034051001072, 58.238046169281006, 59.79470103979111, 51.604992896318436, 51.266556456685066, 38.087298050522804, 21.995357237756252, 15.985096246004105, 4.228103421628475, 6.453520506620407, 7.758638374507427, 3.014527391642332, 1.1060458375141025, 0.23787128826370463, 0.11836591962492093, 0.11531897296663374, 0.04058817146869842, 7.2700947895646095, 40.30224099755287, 51.05612374842167, 32.860287129879, 33.69904272258282, 26.756889335811138, 30.624243915081024, 46.6342668235302, 49.89741772413254, 47.47624084353447, 7.696242872625589, 0.12391126190777868, 0.08490895983413793, 0.010306081403541612, 0.022813912728452124, 0.010870935566344997, 0.03101964477536967, 0.04842440859647468, 0.038278325882856734, 0.04594468169671018, 0.07443674403475598, 0.03272830064815935, 0.061710859517916106, 0.035712532117031515, 0.023358990511042066, 0.0359813714021584, 0.05846376305271406, 0.04703609891294036, 0.06497007896541618, 0.03211604736861773, 0.030406680889427662, 0.046225191254052334, 0.03479306680674199, 0.045947156759211794, 0.027689275630109478, 0.014674771737190895, 0.05662771567585878, 0.037145129463169724, 0.02352921506826533, 0.04743101424537599, 0.09826646026340313, 0.009340956385130994, 0.042154065959039144, 0.034949990222230554, 0.04808287965715863, 0.05569765249674674, 0.009582972597854678, 0.05089981990749948, 0.025975346798077226, 0.048926549425232224, 0.049008660644176416, 0.07529937196522951, 0.03225802392989863, 0.09702711817226373, 0.01580082313012099, 0.06697073098621331, 0.03884082558215596, 1.3640619674697518, 37.11554579436779, 72.32154205441475, 61.43069565296173, 48.615484312176704, 42.22296193242073, 36.26769348978996, 32.35381990671158, 44.05554659664631, 45.01144990324974, 21.646522656083107, 1.506338445469737, 0.020901604111713823, 0.06466910839662887, 0.2556284924503416, 1.2996310810558498, 7.005870742723346, 9.298215061426163, 9.895080383867025, 8.456984851509333, 7.943133199587464, 20.347474962472916, 39.2789863049984, 59.96797934174538, 64.48636248707771, 64.29018661379814, 62.69828863441944, 62.64385275542736, 60.434639900922775, 51.07573449611664, 53.57505418360233, 60.97500890493393, 59.77670140564442, 57.07030043005943, 55.962241888046265, 58.15381608903408, 56.48671254515648, 47.42115139961243, 43.264216259121895, 47.68415428698063, 57.15435951948166, 58.00158105790615, 56.470768600702286, 54.21592019498348, 59.49693001806736, 56.83926522731781, 57.21970081329346, 49.807100370526314, 45.812667310237885, 44.53362934291363, 45.33840715885162, 43.336264193058014, 43.94985906779766, 44.018935561180115, 44.515002742409706, 43.362874165177345, 51.415489464998245, 54.57459814846516, 58.41282159090042, 56.77556924521923, 58.3911057561636, 53.790422827005386, 60.91230846941471, 53.936156406998634, 56.20901204645634, 33.19542154669762, 43.50275605916977, 62.534806206822395, 55.42920269072056, 54.890061020851135, 46.529183462262154, 45.74028879404068, 43.40505190193653, 45.713264644145966, 48.63115847110748, 53.76819021999836, 55.27423560619354, 56.888233199715614, 54.904029071331024, 56.69730104506016, 56.62636265158653, 56.06666788458824, 56.5722231566906, 57.317731752991676, 54.23434920608997, 53.64372789859772, 54.06923286616802, 55.45789115130901, 52.92370453476906, 47.932326570153236, 49.74392496049404, 51.09366953372955, 50.55721811950207, 50.44106215238571, 56.73704691231251, 58.24104800820351, 59.24752660095692, 60.92694528400898, 55.320938900113106, 46.85359105467796, 49.86549183726311, 58.251550644636154, 59.96785394847393, 60.093767791986465, 60.614168867468834, 54.728839471936226, 55.81574074923992, 40.33770829439163, 19.129936695098877, 11.052411831915379, 7.885777652263641, 13.898336570709944, 13.099260348826647, 8.864426538348198, 3.698997488245368, 0.9096343768760562, 0.11151327678817324, 0.2168458141386509, 0.07289175584446639, 8.663458172231913, 38.78953076899052, 42.84082017838955, 23.361165449023247, 30.78364536166191, 33.878203108906746, 33.08028392493725, 53.838459849357605, 54.56207402050495, 55.473318323493004, 9.861485436558723, 0.0754484768549446, 0.04021541666588746, 0.03717443316418212, 0.01751807863911381, 0.08498964612954296, 0.049096059665316716, 0.014926575022400357, 0.052821214267169125, 0.0486609273502836, 0.03850108892947901, 0.08599674052675255, 0.03855590766761452, 0.03448992174526211, 0.10449319801409729, 0.016009175524231978, 0.006201708820299245, 0.019096094256383367, 0.06661579143838026, 0.1081545687338803, 0.05110363221319858, 0.04535445536021143, 0.04427459709404502, 0.014862696516502183, 0.04257519765815232, 0.11365834332536906, 0.10783140794956125, 0.17499956506071612, 0.17832370387623087, 0.08618648542324081, 0.1823114266153425, 0.13352725451113656, 0.2012108257622458, 0.1457618855056353, 0.13509695621905848, 0.16878845694009215, 0.12058348656864837, 0.11110334409750067, 0.2246556567843072, 0.10240034898743033, 0.22697219654219225, 0.3082924790214747, 0.12957644619746134, 0.1815051573794335, 0.16702100256225094, 0.2141558553557843, 0.1843915181234479, 2.229582848958671, 48.63448329269886, 79.94343146681786, 70.88405638933182, 57.97134608030319, 50.51593333482742, 45.681209564208984, 43.04087184369564, 53.15665863454342, 58.4391313791275, 26.53986968100071, 2.4838884780183434, 0.26995108171831816, 0.28274986369069666, 0.5202533584088087, 1.4393271412700415, 8.88060986995697, 19.612419605255127, 18.91601387411356, 16.248798295855522, 18.15507810562849, 31.081541776657104, 47.82430976629257, 59.59170453250408, 68.52057561278343, 64.10665646195412, 65.50187319517136, 64.13298144936562, 64.9043096601963, 53.8414540886879, 57.22601227462292, 62.81411021947861, 61.35774336755276, 57.71604157984257, 57.13153414428234, 61.761376708745956, 58.95949825644493, 49.14057433605194, 47.591066882014275, 50.80774627625942, 59.96015936136246, 60.98086439073086, 57.221748903393745, 54.20467659831047, 60.15115611255169, 59.45268899202347, 61.26478515565395, 53.00591692328453, 48.883366137742996, 46.878662109375, 47.406810969114304, 46.68643042445183, 46.427740305662155, 46.48530341684818, 46.99597701430321, 47.24980339407921, 52.93264165520668, 56.06209672987461, 60.34318260848522, 59.41260114312172, 61.898328959941864, 56.332277432084084, 62.94285871088505, 55.621130391955376, 56.061861142516136, 36.08613923192024, 46.106049567461014, 63.7276192009449, 59.41254794597626, 57.22638465464115, 49.135030433535576, 47.69525349140167, 45.022746697068214, 48.357535153627396, 51.30630612373352, 56.69740363955498, 58.08959573507309, 59.29775230586529, 56.88208892941475, 58.42908091843128, 57.86178655922413, 57.94939465820789, 58.888635858893394, 58.29855412244797, 56.730157881975174, 56.969491839408875, 56.07390649616718, 58.19314017891884, 54.063077196478844, 50.8857598900795, 51.93165756762028, 52.81930133700371, 52.576346173882484, 49.46847014129162, 57.73547373712063, 59.638605415821075, 61.653508096933365, 63.97909730672836, 58.56273874640465, 50.304866060614586, 51.41572505235672, 60.29142938554287, 62.60974958539009, 64.14637193083763, 61.0244632512331, 55.9365476667881, 57.496702149510384, 41.14363744854927, 28.85381631553173, 26.881811432540417, 12.36089726909995, 17.96119350939989, 17.98301763832569, 11.601090990006924, 4.657567301765084, 0.3586645651375875, 0.2747832942986861, 0.2187271584989503, 0.1504530751844868, 10.021535698324442, 54.290810376405716, 64.6154947578907, 46.53740622103214, 44.313909932971, 37.4114853143692, 42.84922152757645, 62.137662917375565, 63.100288063287735, 64.15153965353966, 13.85840356349945, 0.24508379108738154, 0.17141346295829862, 0.10106201181770302, 0.15089242660906166, 0.10390905357780866, 0.06770188003429212, 0.11167640084750019, 0.11350265558576211, 0.1420666728517972, 0.1853604958159849, 0.26208170398604125, 0.142512985621579, 0.15394740330521017, 0.14962834131438285, 0.17624708561925218, 0.19801531598204747, 0.12728263100143522, 0.1474581827642396, 0.3274978359695524, 0.11519461128045805, 0.21288883115630597, 0.09530803697998635, 0.07458437205059454, 0.14190868445439264], [0.06768261388060637, 0.016652745580358896, 0.022304287340375595, 0.03178458195179701, 0.03169658921251539, 0.01265233118829201, 0.08169644745066762, 0.054592887754552066, 0.05361773910408374, 0.009353060813737102, 0.02378483670327114, 0.05008085994631983, 0.05804483553220052, 0.007487836828659056, 0.06001729707350023, 0.014309482940007001, 0.03108711156528443, 0.030268723057815805, 0.0750408745079767, 0.0817604354233481, 0.01453334529287531, 0.0777168660715688, 2.7456298330798745, 38.24420303106308, 61.1016371101141, 51.108549535274506, 41.475466042757034, 19.98433604836464, 11.77022086456418, 21.90345536917448, 42.88225315511227, 34.94826748967171, 7.516887746751308, 0.1050218817545101, 0.026428084711369593, 0.04843496935791336, 0.11791900571552105, 2.5229199836030602, 4.786209873855114, 9.74883858114481, 11.180618852376938, 11.129429899156094, 13.869697507470846, 29.335516467690468, 47.712998539209366, 61.968989968299866, 59.0477105230093, 58.299013897776604, 58.64209368824959, 57.823237627744675, 51.00976623594761, 46.557773128151894, 52.72861920297146, 59.117987751960754, 60.22029720246792, 55.298873484134674, 55.41839227080345, 55.857204124331474, 54.54719401896, 44.30472582578659, 40.929860919713974, 45.23018516600132, 52.65240289270878, 55.54209843277931, 55.4078022390604, 54.2082180082798, 57.04957254230976, 56.48926980793476, 54.18088607490063, 45.17489433288574, 43.01734730601311, 41.52701407670975, 40.4055992513895, 39.90602105855942, 43.63917253911495, 42.556755021214485, 44.067599549889565, 41.92680202424526, 47.501026913523674, 49.93428714573383, 55.950306728482246, 51.81141681969166, 55.8509686589241, 52.274216786026955, 58.53919140994549, 50.39512641727924, 58.48944067955017, 26.089643239974976, 34.61664408445358, 60.1049467921257, 50.76423101127148, 55.64135290682316, 47.29780621826649, 46.96851588785648, 40.90792469680309, 44.09606382250786, 41.72974839806557, 47.2942990064621, 47.30498403310776, 52.969450280070305, 52.118466943502426, 52.17326380312443, 49.57553319633007, 49.601295813918114, 53.226080909371376, 53.23662914335728, 52.336199060082436, 53.590637147426605, 55.41942201554775, 54.88117329776287, 50.992731750011444, 49.757133051753044, 49.39150147140026, 53.54042664170265, 52.19070486724377, 57.110270485281944, 51.455193534493446, 52.120936810970306, 56.07574559748173, 57.607606798410416, 55.85744351148605, 45.564107447862625, 42.65930771827698, 48.7488229572773, 55.825441628694534, 59.47272151708603, 58.343691900372505, 60.33677615225315, 50.759941041469574, 50.158049538731575, 36.607889235019684, 19.32073775678873, 7.564221806824207, 5.436625247821212, 8.322136737406254, 7.2288228292018175, 4.376416588202119, 0.8517573075369, 0.07599557327921502, 0.13007968169404194, 0.07231944866362028, 0.7531461864709854, 14.741895105689764, 41.65686830878258, 41.98108971118927, 15.882576797157526, 31.238380260765553, 39.93328459560871, 38.30074019730091, 50.01111142337322, 51.979994773864746, 21.647634096443653, 0.23468216095352545, 0.0556905798293883, 0.038694496324751526, 0.02003866818995448, 0.06731579996994697, 0.0337122956989333, 0.05285612489387859, 0.07357986774877645, 0.046563703363062814, 0.02096841224556556, 0.006967672015889548, 0.08711090456927195, 0.025297114734712522, 0.019498451474646572, 0.0509666317520896, 0.0328266649012221, 0.022708902542944998, 0.06296280698734336, 0.03330463026941288, 0.10809884828631766, 0.017567856339155696, 0.026610170643834863, 0.03377139291842468, 0.008444535687885946, 0.06565133342519403, 0.04119033525057603, 0.045897124873590656, 0.03613899243646301, 0.024969426849565934, 0.05781900370493531, 0.03636811197793577, 0.041574003334972076, 0.027414749638410285, 0.04176105052465573, 0.025427838481846265, 0.0460366783227073, 0.06092804585932754, 0.03664560099423397, 0.05393805004132446, 0.015041298993310193, 0.05302704892528709, 0.06327044204226695, 0.035723593828151934, 0.059205265060882084, 0.06088479720347095, 0.009963942975446116, 3.567989068105817, 47.788014113903046, 70.51472380757332, 57.324438393116, 48.996402472257614, 29.199495166540146, 20.467622615396976, 25.00097505748272, 44.92640286684036, 38.278697580099106, 8.892245795577765, 0.11264750850386918, 0.0900975739932619, 0.05566656021983363, 0.7529646868351847, 4.2831558175385, 9.915239252150059, 11.615973841398954, 13.323803599923849, 9.89089585840702, 13.75430814921856, 34.361867755651474, 51.30027964711189, 63.37986946105957, 60.96564240753651, 60.68726934492588, 61.9907134026289, 61.00086651742458, 54.386363849043846, 48.38632620871067, 54.9426805973053, 60.42799025774002, 60.00025101006031, 55.21315008401871, 56.452031806111336, 58.742077723145485, 55.58491833508015, 46.1639204621315, 43.58782209455967, 47.721460685133934, 55.1748975366354, 58.00334796309471, 56.16196297109127, 54.942224621772766, 57.61142559349537, 57.59066350758076, 56.01533263921738, 47.55871161818504, 45.419658198952675, 43.63485977053642, 42.82987296581268, 41.193163990974426, 44.55671690404415, 44.66774694621563, 45.90491496026516, 43.940085992217064, 49.64489467442036, 52.82986477017403, 57.199983671307564, 53.43891128897667, 58.34750309586525, 53.26493762433529, 60.10043643414974, 51.741998344659805, 58.658588603138924, 28.826814964413643, 36.48993596434593, 63.36158864200115, 53.6006648093462, 57.55973316729069, 49.09447140991688, 48.358941078186035, 41.738708317279816, 46.04117564857006, 44.288120716810226, 48.60813930630684, 49.610077142715454, 53.96612539887428, 54.798478335142136, 54.337973445653915, 53.10753107070923, 52.20050074160099, 53.66116516292095, 53.984649404883385, 54.06378395855427, 56.526112630963326, 56.08694739639759, 56.73195518553257, 53.46315398812294, 50.81309638917446, 50.00735342502594, 54.08891201019287, 53.21477271616459, 58.69057148694992, 51.13682381808758, 52.865039482712746, 58.419608026742935, 59.11776356399059, 59.16116863489151, 48.32369416952133, 44.733874797821045, 50.79565532505512, 57.60681264102459, 60.52001751959324, 61.25106789171696, 59.79188919067383, 53.07631574571133, 52.273540422320366, 36.21680662035942, 18.371750079095364, 7.780877631157637, 10.210006535053253, 11.09805878251791, 7.955013737082481, 7.527830209583044, 3.2705880515277386, 0.4346747958334163, 0.05421468187705614, 0.10860908223548904, 0.8390091103501618, 17.0728125795722, 43.64832624793053, 36.974995136260986, 23.57118397951126, 36.994708478450775, 46.41555815935135, 44.91713136434555, 56.616399586200714, 59.401543736457825, 25.510791800916195, 0.6549372500739992, 0.06893613841384649, 0.044732461392413825, 0.03618993716372643, 0.02945686359453248, 0.06523127784021199, 0.042397560901008546, 0.05524469008378219, 0.0250829494689242, 0.023506050783907995, 0.030787677242187783, 0.048382967070210725, 0.010527563317737076, 0.040899135055951774, 0.004109915034860023, 0.02936721586593194, 0.010842458432307467, 0.08551305319997482, 0.05767951333837118, 0.11278733654762618, 0.08786075573880225, 0.04023764398880303, 0.048958510014927015, 0.07175962440669537, 0.11041404475690797, 0.12045280920574442, 0.18345908378250897, 0.17515529732918367, 0.11495324259158224, 0.10869218793231994, 0.12257586364285089, 0.14963331370381638, 0.14635983388870955, 0.14789049862883985, 0.1383971978793852, 0.10173320275498554, 0.16789832501672208, 0.08428151850239374, 0.17605031258426607, 0.20189431408653036, 0.10367058668634854, 0.1879665325395763, 0.13770698569715023, 0.22770946088712662, 0.18549982662079856, 0.10174097304116003, 5.969727141782641, 57.23324328660965, 76.29546761512756, 65.57272419333458, 57.40279398858547, 32.85204537212849, 21.19828350841999, 31.049727983772755, 54.24445666372776, 47.19964228570461, 10.601357985287905, 0.3040023607900366, 0.1532928884262219, 0.17396512994309887, 0.39440808934159577, 4.311442449688911, 15.616076197475195, 24.094041623175144, 20.777663178741932, 20.989351719617844, 21.24640602618456, 35.10025933384895, 52.260324731469154, 66.18179351091385, 64.22752797603607, 64.09692138433456, 65.29549106955528, 62.50424824655056, 56.61016032099724, 50.804755836725235, 56.26429907977581, 63.6259176582098, 61.92765198647976, 54.78471167385578, 58.472679778933525, 61.23193211853504, 58.18395987153053, 48.309102952480316, 45.94770826399326, 51.002953201532364, 58.239547088742256, 61.37829266488552, 57.784563302993774, 53.43369036912918, 58.69911342859268, 61.184343472123146, 58.453042432665825, 50.201329216361046, 49.2346952855587, 47.205569967627525, 44.75860007107258, 44.11149479448795, 48.0403433740139, 47.421671971678734, 49.205243065953255, 45.37431143224239, 51.543740183115005, 54.81790669262409, 59.69706907868385, 57.09294721484184, 61.29306323826313, 56.083417385816574, 60.603407844901085, 54.311929643154144, 59.08222787082195, 31.95378117263317, 39.08534489572048, 66.29729211330414, 55.704102739691734, 59.99293640255928, 51.505141854286194, 50.30934602022171, 44.85952265560627, 48.03803309798241, 45.297977328300476, 51.46264873445034, 53.01622577011585, 56.61316595971584, 57.29611091315746, 56.55323937535286, 56.82723507285118, 53.539947867393494, 57.868189215660095, 56.29813626408577, 55.72746388614178, 58.528760969638824, 59.36137229204178, 58.11954192817211, 55.19368752837181, 52.64934405684471, 52.04625941812992, 55.875872522592545, 53.83565939962864, 60.842278227210045, 52.06344589591026, 52.11935989558697, 59.227357283234596, 61.14351086318493, 61.61701485514641, 49.77155327796936, 48.55805039405823, 53.78153510391712, 61.59292794764042, 63.84918987751007, 65.03858685493469, 61.96214273571968, 55.98811089992523, 53.6862438172102, 40.95384903252125, 26.573079898953438, 22.77937676757574, 12.229956295341253, 16.910187005996704, 17.17294480651617, 13.111349400132895, 3.421947229653597, 0.28145024436526, 0.3502571600256488, 0.25857235479634255, 1.2834387249313295, 20.73075469583273, 58.491321578621864, 55.858739241957664, 24.499375373125076, 41.74206353724003, 51.86215929687023, 50.43657839298248, 64.28308099508286, 65.73253601789474, 32.828308045864105, 1.2423392990604043, 0.15442417381564155, 0.15450475621037185, 0.13673315435880795, 0.1443616161122918, 0.1164383691502735, 0.10545253520831466, 0.11280685503152199, 0.10042843292467296, 0.09112206433201209, 0.09752257596119307, 0.12088826435501687, 0.10182263897149824, 0.10974626027746126, 0.09718273169710301, 0.0921613308310043, 0.07506517242291011, 0.1874166159541346, 0.18538206262746826, 0.20734644262120128, 0.2230922188027762, 0.12981428968487307, 0.12112123193219304, 0.11824366563814692], [0.05194401426706463, 0.05542984479689039, 0.02082325558149023, 0.023259197623701766, 0.08044661139138043, 0.023954784810484853, 0.020166582908132114, 0.049594163210713305, 0.025465188919042703, 0.008220802283176454, 0.05126318283146247, 0.07196075384854339, 0.024303983846039046, 0.06327810100628994, 0.016012405721994583, 0.08770336848101579, 0.07624032616149634, 0.1064923508965876, 0.0227984036973794, 0.030977830319898203, 0.04758428258355707, 0.046981695777503774, 6.868722327053547, 58.777852803468704, 61.94018371403217, 52.50134199857712, 41.0644306987524, 23.48077353090048, 22.878747135400772, 38.59047845005989, 48.39018680155277, 25.131330862641335, 1.7971109552308917, 0.06428101711208001, 0.04594383935909718, 0.024513510688848328, 1.5422257385216653, 3.6820917204022408, 6.665553404018283, 5.011163502931595, 7.402359517291188, 8.188610002398491, 25.20835842937231, 47.014763206243515, 55.247329249978065, 63.96072909235954, 55.61898730695248, 57.19179891049862, 51.08271852135658, 50.9565918892622, 47.35932871699333, 50.39643734693527, 56.95454344153404, 59.00660052895546, 57.884653732180595, 54.9333368986845, 53.82410041987896, 55.16849108040333, 52.92600721120834, 43.310357183218, 40.161002576351166, 45.545104667544365, 53.74587781727314, 54.79236826300621, 53.40118691325188, 52.222619354724884, 56.95583917200565, 54.48471397161484, 51.06154225766659, 41.829519644379616, 38.96390721201897, 39.728391990065575, 39.35357250273228, 39.55697558820248, 42.71491013467312, 42.259865552186966, 45.310444459319115, 42.52270884811878, 47.15789392590523, 47.870173305273056, 51.31762571632862, 47.37665578722954, 53.716076016426086, 51.102450862526894, 57.88493111729622, 49.45594601333141, 58.770959973335266, 27.652828060090542, 30.929434038698673, 60.61335191130638, 51.52107059955597, 55.30457317829132, 48.2591812312603, 49.26092527806759, 40.807203501462936, 42.463869005441666, 42.18855857849121, 40.752414241433144, 42.15240731835365, 45.127545073628426, 46.83542422950268, 47.7302610129118, 47.39243634045124, 46.76219455897808, 46.72062858939171, 50.27085408568382, 50.99107123911381, 51.05754867196083, 52.112987637519836, 52.50358767807484, 53.891558200120926, 49.11642283201218, 49.238806664943695, 54.92631487548351, 56.16745367646217, 55.417161136865616, 56.985956355929375, 51.6797386854887, 58.10025796294212, 57.04261131584644, 56.1509245634079, 51.44155226647854, 41.841257214546204, 45.03932520747185, 50.251174941658974, 56.31966210901737, 58.5186193138361, 59.10450987517834, 58.12744930386543, 47.63043276965618, 45.88621236383915, 34.751894026994705, 16.21530119329691, 22.140973024070263, 14.585464149713516, 6.254729898646474, 5.529244327917695, 3.4263312444090843, 0.7859749405179173, 0.19786005868809298, 0.03380954673048109, 0.039862254561739974, 4.445732943713665, 28.98420251905918, 43.752881437540054, 26.533468924462795, 20.78095380216837, 19.790320359170437, 34.4399269670248, 50.005590319633484, 51.094767674803734, 38.326031640172005, 3.5705577302724123, 0.02465106033923803, 0.06259966670768335, 0.04169545209151693, 0.01399009504893911, 0.0903602348989807, 0.02429359006782761, 0.015525615290243877, 0.03413092636037618, 0.02182174848712748, 0.05307588966388721, 0.019914460499421693, 0.015383695317723323, 0.03781113278819248, 0.001266785204734333, 0.009274097228626488, 0.03643213705800008, 0.03473013639450073, 0.03564671103958972, 0.05133624727022834, 0.07153218582971022, 0.039675682346569374, 0.022642387557425536, 0.04414878821989987, 0.03543081656971481, 0.06941341358469799, 0.051705413789022714, 0.049984306533588096, 0.05352405409212224, 0.03808912275417242, 0.015178633420873666, 0.03421895620704163, 0.03155158097797539, 0.056135812774300575, 0.04953510309860576, 0.04361054190667346, 0.0767858640756458, 0.04228757090459112, 0.06708799774060026, 0.0951699232973624, 0.11497634564875625, 0.059531246006372385, 0.06127635431766976, 0.02970488934806781, 0.01098636828828603, 0.07433180435327813, 10.5912134796381, 67.55611896514893, 66.60496920347214, 60.21560825407505, 47.21250839531422, 31.28694735467434, 25.418918430805206, 32.50125199556351, 42.640415132045746, 28.18439293652773, 2.2985833464190364, 0.020538051940093283, 0.15103356825420633, 0.3570529172429815, 2.8318486316129565, 6.1442897748202085, 10.419678334146738, 10.790390241891146, 8.544919732958078, 8.952248375862837, 27.37934533506632, 46.12893953919411, 58.913186341524124, 63.102567940950394, 58.696913346648216, 57.05621838569641, 54.49664153158665, 53.87587644159794, 51.0524645447731, 50.99070265889168, 58.98540526628494, 58.72041508555412, 58.19806471467018, 55.42743198573589, 54.989756271243095, 55.891626477241516, 56.47152476012707, 44.89172212779522, 43.258968740701675, 46.55214563012123, 56.483965292572975, 56.928305849432945, 54.98428836464882, 51.7142940312624, 58.5604664683342, 55.79613760113716, 54.97457228600979, 44.70365881919861, 42.56782002747059, 42.688417956233025, 41.676486656069756, 42.141612097620964, 45.19053429365158, 43.78245145082474, 48.176957443356514, 44.01572473347187, 48.6808218061924, 50.370610132813454, 53.855232149362564, 49.56803239881992, 56.19431063532829, 52.71342381834984, 59.85841982066631, 51.9577469676733, 57.88293622434139, 27.83270850777626, 33.97170089185238, 61.295939683914185, 54.28834430873394, 56.79446563124657, 51.072105690836906, 52.380284294486046, 43.231792598962784, 44.414543733000755, 44.26783740520477, 43.23717691004276, 44.12763632833958, 47.689751386642456, 47.62968420982361, 50.39606116712093, 49.629045724868774, 49.774798303842545, 48.388792276382446, 51.688736602663994, 53.148473873734474, 53.538868725299835, 54.83170375227928, 55.02922095358372, 55.35045951604843, 50.95515936613083, 50.14021709561348, 57.07645229995251, 57.49081626534462, 57.44119852781296, 58.31142783164978, 51.19600564241409, 60.84511287510395, 58.76923866569996, 58.94207239151001, 52.64816612005234, 43.47256287932396, 47.2045212239027, 52.609438598155975, 59.26472067832947, 60.66599428653717, 61.25512607395649, 57.42663770914078, 51.98933847248554, 46.63553215563297, 30.442347675561905, 10.653438940644264, 9.550418928265572, 14.761592298746109, 14.475192166864872, 7.779901558533311, 7.1464024018496275, 2.883586655370891, 0.154950104188174, 0.06248933161259629, 0.01963168368092738, 4.864086220040917, 33.23474943637848, 45.616012662649155, 25.943964757025242, 27.214327789843082, 24.952613152563572, 38.876739889383316, 57.172055169939995, 57.80091382563114, 45.36633186042309, 5.813569771125913, 0.012030307534587337, 0.05794681637780741, 0.024982581417134497, 0.050097973871743307, 0.0498591062205378, 0.027334718288329896, 0.10761913144961, 0.009400004437338794, 0.04244914016453549, 0.007697536684645456, 0.0559335886646295, 0.020637998823076487, 0.06220876268344, 0.06568763186805882, 0.022995712934061885, 0.060966633827774785, 0.05930451618041843, 0.05184383917367086, 0.03805836815445218, 0.022433719750551973, 0.06272056998568587, 0.041247918488807045, 0.053566909409710206, 0.12175551586551592, 0.1465239078970626, 0.12804254569346085, 0.20661185000790283, 0.15432239568326622, 0.11984677141299471, 0.08946950925746933, 0.1492337859235704, 0.0948686187621206, 0.19463146396446973, 0.1332099863793701, 0.1282194588566199, 0.146263146889396, 0.10814535868121311, 0.13758004875853658, 0.1399866258725524, 0.20788423251360655, 0.17199996742419899, 0.15146938705584034, 0.16887910285731778, 0.12056602383381687, 0.21388241846580058, 15.7182546146214, 78.74700486660004, 74.65589359402657, 66.75194531679153, 54.67503435909748, 36.06719724833965, 32.92692795395851, 52.9089917242527, 60.49532264471054, 35.20078293979168, 2.896946263499558, 0.09677431298769079, 0.33330466656479985, 0.45430121768731624, 4.0055484138429165, 9.86312409862876, 16.386347115039825, 13.749657198786736, 17.158081904053688, 18.34813814610243, 29.667736440896988, 50.917921364307404, 59.19874481856823, 68.46816882491112, 60.77358931303024, 60.596427619457245, 55.63127964735031, 56.90203785896301, 52.42670640349388, 55.105916038155556, 61.32483333349228, 62.48833850026131, 58.714491203427315, 55.867391377687454, 55.78252673149109, 58.613013848662376, 59.31574434041977, 48.92219625413418, 45.959449633955956, 49.361692070961, 59.4169557094574, 59.63049665093422, 53.764945194125175, 50.97197346389294, 61.867657005786896, 60.02260521054268, 56.113766357302666, 46.451785415410995, 43.481872379779816, 43.50942850112915, 43.513334691524506, 45.234760120511055, 48.260917738080025, 47.27788768708706, 49.75877836346626, 47.51380182802677, 51.59582398831844, 52.15741105377674, 56.79074943065643, 51.895605102181435, 57.89099559187889, 56.37108854949474, 61.95270784199238, 54.230629205703735, 57.71888002753258, 31.31900243461132, 37.43272237479687, 62.42303900420666, 59.246975630521774, 58.91741171479225, 53.06558132171631, 54.81417529284954, 44.755955412983894, 46.72987349331379, 46.84192568063736, 44.99678649008274, 46.41465000808239, 49.9460893124342, 51.53013691306114, 54.074259996414185, 52.10587441921234, 52.394020557403564, 50.44949769973755, 55.46221911907196, 55.83084113895893, 55.45131750404835, 57.808745205402374, 57.57038779556751, 57.80498720705509, 53.12793977558613, 52.05331563949585, 59.650130197405815, 62.25282333791256, 60.34628324210644, 61.36119358241558, 53.22579212486744, 59.6135039627552, 60.16292028129101, 61.787967681884766, 55.255004838109016, 46.14038072526455, 49.93192747235298, 53.81560027599335, 62.42940366268158, 63.12317803502083, 63.76991093158722, 59.45713475346565, 53.03686246275902, 49.06869739294052, 38.39151352643967, 25.190449990332127, 33.705498576164246, 33.05890627205372, 20.18163476139307, 15.141464564949274, 6.889826869592071, 2.373350984416902, 0.34076823794748634, 0.10805972968228161, 0.07701434908085503, 6.420399583876133, 41.20041020214558, 57.42710888385773, 38.306899666786194, 31.384085342288017, 31.280556097626686, 50.58203838765621, 63.84607404470444, 64.39011365175247, 53.702833727002144, 8.09688102453947, 0.12178726494312286, 0.14592071995139122, 0.14667192182969302, 0.09046806153492071, 0.2241855359170586, 0.24591187946498394, 0.1994483734597452, 0.10995235468726605, 0.15339760546339676, 0.17564735608175397, 0.1162254172959365, 0.11672182503389195, 0.15634891897207126, 0.10823706586961634, 0.1866028510266915, 0.13460596615914255, 0.08835333399474621, 0.11153283980092965, 0.19732688495423645, 0.21136220369953662, 0.1472889879369177, 0.14038610912393779, 0.20109303208300844], [0.047036655523697846, 0.036464157019509, 0.03072894181968877, 0.024348661136173178, 0.015062427937664324, 0.04483770164370071, 0.05249538917269092, 0.060929864121135324, 0.035948887598351575, 0.05561907761148177, 0.0473774534475524, 0.03996445200755261, 0.05674931286193896, 0.05028821229643654, 0.03926917466742452, 0.07261120175826363, 0.04603407338436227, 0.06783990465919487, 0.0698445865418762, 0.03416502433537971, 0.022758728482585866, 0.5553583684377372, 28.844936192035675, 62.62996070086956, 53.13737466931343, 47.989084124565125, 36.51939198374748, 13.931864071637392, 16.464073844254017, 37.78985761106014, 44.05392028391361, 14.632475227117538, 0.12698085891315714, 0.01792988525266992, 0.209989586728625, 0.06898466002894565, 1.4403323060832918, 4.27703719586134, 8.090006243437529, 9.471436366438866, 12.213153596967459, 20.16797449439764, 38.45846213400364, 58.40016067028046, 60.647021904587746, 59.892234206199646, 56.30590304732323, 53.083166778087616, 47.40357354283333, 45.52117735147476, 44.78497065603733, 53.11733454465866, 55.1059540361166, 57.8193124383688, 55.68564713001251, 53.5249462723732, 53.94141532480717, 54.39302869141102, 51.44260101020336, 42.736500576138496, 40.73341906070709, 46.30987823009491, 51.99591211974621, 53.9206912368536, 54.199611470103264, 53.511111214756966, 54.72434811294079, 53.74579802155495, 48.13594624400139, 40.52407689392567, 40.58797046542168, 39.343871623277664, 42.237636744976044, 39.32740330696106, 42.5977586209774, 42.01693318784237, 46.184488758444786, 42.02128775417805, 42.442901730537415, 43.31240527331829, 47.52505302429199, 45.690222680568695, 51.56787268817425, 53.87611582875252, 58.81252974271774, 52.2710857540369, 59.674536287784576, 26.174236200749874, 32.29685336351395, 58.52852538228035, 52.4572529643774, 56.29529021680355, 48.965335339307785, 47.89006523787975, 41.26184530556202, 41.529130563139915, 42.88404665887356, 41.14506237208843, 38.532675951719284, 42.822140380740166, 41.300747618079185, 42.14491792023182, 42.45196424424648, 43.53571929037571, 44.90499101579189, 44.593894109129906, 46.05025716125965, 47.32232630252838, 47.92801380157471, 51.865050941705704, 52.947430461645126, 51.08783304691315, 51.789032220840454, 55.60459367930889, 49.419521167874336, 51.720122918486595, 54.470263347029686, 58.1112165749073, 51.0113849490881, 54.72872167825699, 54.9681506305933, 52.74246945977211, 47.051868215203285, 42.72330388426781, 46.78389139473438, 53.87578524649143, 57.128897085785866, 56.95556178689003, 56.36982701718807, 53.121780306100845, 45.878825560212135, 46.697343438863754, 17.091323286294937, 12.165310364216566, 8.098253700882196, 7.920067012310028, 6.123981764540076, 6.815207898616791, 2.0267150597646832, 0.13093816844047979, 0.07854669849621132, 0.030549026669177692, 0.4163693671580404, 15.266462657600641, 42.46067717671394, 32.62443758547306, 16.111127883195877, 20.285072810947895, 28.95609922707081, 37.78893046081066, 43.42504262924194, 50.702480524778366, 12.763611059635878, 0.14170425245538354, 0.05567449377849698, 0.021949017536826432, 0.04481953015783802, 0.045365465120994486, 0.024565162311773747, 0.024156292747647967, 0.027964285873167682, 0.08116507713566534, 0.022199228915269487, 0.018099191402143333, 0.045708315083174966, 0.040314515645150095, 0.07130520738428459, 0.04369360307464376, 0.05525120985112153, 0.01471893694542814, 0.07580739431432448, 0.049696241912897676, 0.052510896348394454, 0.03708886724780314, 0.0432738851668546, 0.07239390091854148, 0.09363521385239437, 0.018592294727568515, 0.06240633723791689, 0.049650933797238395, 0.026246859670209233, 0.012527706967375707, 0.08417562145041302, 0.04223373922286555, 0.03278187257819809, 0.0559581982815871, 0.0669044720416423, 0.027034924023610074, 0.056061471841530874, 0.04056521684105974, 0.013448873651213944, 0.022776695877837483, 0.04828630233532749, 0.04790296450664755, 0.02698265827348223, 0.02271610137540847, 0.026762377710838336, 0.7648625015281141, 34.26127575337887, 69.4329446554184, 60.86013726890087, 52.48164005577564, 43.101056814193726, 20.065429396927357, 22.122967690229416, 39.72857818007469, 47.08194360136986, 15.55768283084035, 0.17092426889576018, 0.07466893235687166, 0.30878291989210993, 0.4157840501284227, 4.842170421034098, 8.67235729470849, 7.108070533722639, 8.203985877335072, 6.532265581190586, 16.78915400058031, 37.794018387794495, 53.83781388401985, 63.2807669788599, 61.609388664364815, 58.36357623338699, 55.43097339570522, 51.39860697090626, 48.205170929431915, 48.27903896570206, 55.00507704913616, 58.52906875312328, 59.62694004178047, 56.71543747186661, 53.92227575182915, 54.61801081895828, 56.51647634804249, 54.736393466591835, 45.97288951277733, 41.940979063510895, 46.509359925985336, 54.230363219976425, 57.410651966929436, 54.522347152233124, 53.12433756887913, 57.11225397884846, 56.396858766674995, 51.94588020443916, 42.78894916176796, 42.85541519522667, 41.75288915634155, 43.37502211332321, 41.716772094368935, 45.0006090849638, 44.99393664300442, 47.479014694690704, 42.97597512602806, 44.80813041329384, 44.83217552304268, 49.33638542890549, 47.93027088046074, 55.19748352468014, 55.17194129526615, 60.64018227159977, 53.203407526016235, 59.075669422745705, 28.28653335571289, 32.14836113154888, 60.88778458535671, 54.50298719108105, 56.69757843017578, 50.421607196331024, 49.589163064956665, 45.19170843064785, 43.7443432956934, 44.66127209365368, 42.106935158371925, 41.22338756918907, 44.688015058636665, 43.563928976655006, 44.26450878381729, 45.41029550135136, 44.819214418530464, 46.527435556054115, 46.480751261115074, 49.1696921736002, 48.77795219421387, 49.502254128456116, 54.01899576187134, 54.27877642214298, 50.919749066233635, 54.0675875544548, 58.16413253545761, 53.578812181949615, 53.046498745679855, 58.50267916917801, 57.82284624874592, 51.274118050932884, 54.6228251606226, 58.33286628127098, 54.361547380685806, 49.41926658153534, 44.199391677975655, 48.89136850833893, 56.140091344714165, 60.08396431803703, 59.14785794913769, 59.06147338449955, 53.11806410551071, 51.44633240997791, 44.00115251541138, 18.889394402503967, 10.48961453139782, 4.0724837221205235, 10.461979564279318, 8.739529140293598, 8.730634767562151, 4.801420457661152, 0.6707863183692098, 0.19025153102120385, 0.003476989695627708, 0.46000667090993375, 18.995885588228703, 48.75964857637882, 36.6574689745903, 18.23680032044649, 26.044286973774433, 37.561493664979935, 45.88191859424114, 50.84595322608948, 58.6990412324667, 18.005400337278843, 0.09770494390977547, 0.04822057031560689, 0.03766028385143727, 0.03708614356582984, 0.03124901108094491, 0.024105329466692638, 0.07039531206828542, 0.02393759110418614, 0.018900944669439923, 0.040446050188620575, 0.03603064629714936, 0.015686109363741707, 0.04633671749616042, 0.028558556914504152, 0.01688798041868722, 0.025120689533650875, 0.03344373842992354, 0.018972317011503037, 0.04517713030509185, 0.058807355162571184, 0.05167090021132026, 0.04547113581793383, 0.08322266672621481, 0.18108486430719495, 0.1373683288693428, 0.1421900326386094, 0.20592474000295624, 0.14054850587854162, 0.1767423504497856, 0.18712119664996862, 0.16451184579636902, 0.150989247194957, 0.1310959193506278, 0.17718372051604092, 0.12029437551973388, 0.20083118753973395, 0.12440055987099186, 0.08674279190017842, 0.18853170768124983, 0.09793871300644241, 0.15086766856256872, 0.13228881784016266, 0.13706333586014807, 0.15890404436504468, 1.1186496424488723, 41.730892136693, 75.88222458958626, 68.86858373880386, 61.712564527988434, 50.616384744644165, 22.67376523464918, 25.816977471113205, 50.19581951200962, 57.17429704964161, 19.646632969379425, 0.36132575827650726, 0.14569201972335577, 0.539338190574199, 0.4904027539305389, 5.492470376193523, 13.618423640727997, 20.316499024629593, 21.287141740322113, 22.19111893326044, 26.671779602766037, 40.74613697826862, 59.273190423846245, 63.62942487001419, 64.70695585012436, 61.25914625823498, 59.94657129049301, 52.56262511014938, 51.29611887037754, 49.26284417510033, 56.96662679314613, 58.93401302397251, 59.675623029470444, 56.44136197865009, 55.10527767241001, 56.29368670284748, 58.984345123171806, 57.31537587940693, 48.317701891064644, 45.0219639390707, 50.223238840699196, 55.97008466720581, 57.80896179378033, 56.05516590178013, 53.402763828635216, 58.64006459712982, 59.09315228462219, 53.59533749520779, 45.284085273742676, 45.13922184705734, 44.77643631398678, 47.09500350058079, 44.25066612660885, 47.78459049761295, 47.85592406988144, 50.888123363256454, 45.68201892077923, 47.087799087166786, 47.60100334882736, 50.78345037996769, 51.153816506266594, 57.43697315454483, 58.04917350411415, 63.49031053483486, 55.37732407450676, 59.69967193901539, 30.809417478740215, 36.8552103638649, 62.35410310328007, 58.480670750141144, 59.6300482749939, 54.314555302262306, 51.94612719118595, 46.37001000344753, 46.07811726629734, 47.12158687412739, 46.03571154177189, 42.95865185558796, 46.48861303925514, 45.408999770879745, 45.798836052417755, 48.60036112368107, 47.73535653948784, 50.0660564750433, 48.46770644187927, 50.83402566611767, 51.95259444415569, 52.83777214586735, 56.888635978102684, 57.897979617118835, 53.82845498621464, 54.19388897716999, 60.87729334831238, 54.11120541393757, 56.8916492164135, 60.84249101579189, 61.14802502095699, 52.37488478422165, 57.120628729462624, 60.181550681591034, 58.42924810945988, 53.15238006412983, 47.05926641821861, 50.754093155264854, 59.43060077726841, 63.790787011384964, 62.878345772624016, 60.415260940790176, 55.01319721341133, 50.136147513985634, 48.63854147493839, 23.324085138738155, 19.985367693006992, 18.374934308230877, 17.297194339334965, 16.137956343591213, 16.1509782448411, 4.404246769845486, 0.8186400064732879, 0.39925122633576393, 0.2856419241288677, 0.7749574317131191, 22.360871024429798, 57.406107410788536, 44.56150084733963, 25.922642201185226, 33.02960604429245, 41.727191135287285, 52.60063447058201, 56.05491131544113, 67.20686450600624, 23.137598745524883, 0.39291735214646906, 0.19052585848839954, 0.12391626398311928, 0.15132728061871603, 0.1472368446411565, 0.12085336114978418, 0.176588621980045, 0.13724243093747646, 0.1602189222467132, 0.1700460707070306, 0.18661472538951784, 0.1029670232674107, 0.14255714340833947, 0.1961341200512834, 0.17618489364394918, 0.12338788452325389, 0.15185414609732106, 0.1339219880173914, 0.25575715117156506, 0.15337341144913808, 0.1955930795520544, 0.13719024311285466, 0.23828975565265864], [0.025025325412570965, 0.05886628168809693, 0.018740265986707527, 0.054134934398462065, 0.01850384556746576, 0.042499762057559565, 0.03871745466312859, 0.01830767738283612, 0.01945366100699175, 0.10653538804035634, 0.024314724578289315, 0.04879736377915833, 0.016968015479505993, 0.10290511330822483, 0.010617093230393948, 0.06275579973589629, 0.03905967008904554, 0.024044814745138865, 0.01034332515700953, 0.035747914007515647, 0.06270534111536108, 3.2836384512484074, 41.703738793730736, 58.998176380991936, 53.008759170770645, 39.2817297577858, 35.06833344697952, 26.741667352616787, 36.01222559809685, 38.84824521839619, 30.58157790452242, 4.129014238715172, 0.04252618251484819, 0.04928035719785839, 0.11355197872035205, 0.5885702488012612, 3.076351024210453, 5.457241041585803, 4.5582805294543505, 10.202886667102575, 9.706157371401787, 27.52610106021166, 51.12572841346264, 58.6650026589632, 61.64821498095989, 60.22510014474392, 59.146645814180374, 53.01222078502178, 45.17740599811077, 44.600650146603584, 54.89273227751255, 57.55788266658783, 58.103894367814064, 56.39984920620918, 54.225028306245804, 53.731989562511444, 55.55798918008804, 52.43912413716316, 49.73366551101208, 42.12160997092724, 41.87794044613838, 45.36944389343262, 53.38529996573925, 56.79846301674843, 55.916252955794334, 53.885448127985, 55.84933094680309, 54.89275887608528, 45.57880125939846, 39.102683365345, 39.7892115265131, 40.28453014791012, 39.59166772663593, 41.90920516848564, 43.49083609879017, 43.69487755000591, 44.8642648011446, 40.32840259373188, 44.721312671899796, 42.04262360930443, 41.722946763038635, 40.50011917948723, 48.21824222803116, 50.836286544799805, 59.33047614991665, 50.99390588700771, 60.76661288738251, 29.1204784065485, 30.830415152013302, 59.965927451848984, 49.71693500876427, 54.099513441324234, 46.98098681867123, 47.623619735240936, 40.98621189594269, 41.21883541345596, 41.130212768912315, 42.16120384633541, 38.835337311029434, 39.544394463300705, 40.21098889410496, 39.24565829336643, 41.335777938365936, 42.5806899368763, 40.4641655087471, 42.29963421821594, 41.85027413070202, 43.00355404615402, 43.93802270293236, 49.578846618533134, 53.126864433288574, 49.70951020717621, 50.882275477051735, 55.56913398206234, 48.289499804377556, 46.97695903480053, 50.15168108046055, 56.271438896656036, 53.33373673260212, 54.08101983368397, 55.036961138248444, 55.10658860206604, 48.69709253311157, 45.829663798213005, 41.63777433335781, 49.047999903559685, 54.02305394411087, 57.890167236328125, 56.85304328799248, 56.35766386985779, 48.7119497358799, 45.84448680281639, 34.1927008330822, 19.998241402208805, 11.115230061113834, 12.417932208627462, 3.0461742309853435, 9.751522187143564, 6.144833620637655, 0.6885872350540012, 0.03956925094826147, 0.053593968114000745, 0.0607317886169767, 5.099724875763059, 29.032775312662125, 40.6826613843441, 31.53654456138611, 17.11978565901518, 19.922169484198093, 31.883971318602562, 47.15732775628567, 48.70281122624874, 19.443780854344368, 0.7233145216014236, 0.0368322771100793, 0.062137757704476826, 0.046051680837990716, 0.010714555774029577, 0.04856053332332522, 0.025801129486353602, 0.025256667686335277, 0.033106320988736115, 0.02931314484158065, 0.046219202122301795, 0.02498266676411731, 0.06456912626163103, 0.05271702044410631, 0.04043865468702279, 0.059758235584013164, 0.01757007350533968, 0.042476399248698726, 0.023626855727343354, 0.03361823961313348, 0.037131451681489125, 0.14005276607349515, 0.06513388580060564, 0.013471540696627926, 0.013844413315382553, 0.006604412992601283, 0.07053518464090303, 0.04611624026438221, 0.027789775413111784, 0.03317887705634348, 0.009602816699043615, 0.027848646277561784, 0.022633357475569937, 0.059475566376931965, 0.028165322546556126, 0.032830705895321444, 0.07079664326738566, 0.07870447909226641, 0.039605278507224284, 0.06752684450475499, 0.02893621174735017, 0.00790260368376039, 0.026074154484376777, 0.08077901933575049, 4.739232994616032, 50.07955715060234, 67.7570977807045, 59.62707683444023, 45.189474150538445, 42.880425453186035, 29.617499336600304, 28.30187503248453, 39.570970237255096, 34.92491774260998, 5.2980713825672865, 0.08001031761523336, 0.021098529286973644, 0.4380081966519356, 1.499468176625669, 4.793689297512174, 8.051841091364622, 8.531463705003262, 6.935616787523031, 12.491366118192673, 27.89053190499544, 47.80213415622711, 58.24647031724453, 62.87303365767002, 62.68883094191551, 60.729257091879845, 54.49450224637985, 46.83619558811188, 46.66883736848831, 56.77080810070038, 58.52237731218338, 59.88659530878067, 58.3144448697567, 54.21047128736973, 54.613492861390114, 56.44624091684818, 55.86533948779106, 51.81465044617653, 44.7568179666996, 43.606752678751945, 47.62501426041126, 56.74900867044926, 57.84978300333023, 55.58510832488537, 53.95612433552742, 58.098502457141876, 55.399606078863144, 48.950303345918655, 40.49107566475868, 41.98731757700443, 42.45681658387184, 42.35497824847698, 43.8851523399353, 45.79307936131954, 45.44453166425228, 46.689918637275696, 41.28653258085251, 45.8638733625412, 43.810919523239136, 43.609625324606895, 44.76936109364033, 50.63026160001755, 53.42746630311012, 61.887241154909134, 53.40765796601772, 60.74708193540573, 29.835938215255737, 32.302298471331596, 60.67029185593128, 52.239486649632454, 57.568073719739914, 49.18398700654507, 49.02401939034462, 43.490068539977074, 43.507023230195045, 43.820920586586, 44.48210410773754, 41.345269829034805, 42.53013364970684, 41.92519851028919, 41.64917752146721, 42.99888029694557, 43.918005377054214, 42.56561994552612, 43.72534051537514, 44.23965811729431, 44.64368283748627, 45.89346997439861, 52.32772931456566, 54.589728936553, 52.61750176548958, 52.20194846391678, 58.37178759276867, 50.92437721788883, 49.43668484687805, 51.94518484175205, 58.91121804714203, 54.11688230931759, 55.301814526319504, 57.53775134682655, 58.25219660997391, 51.62567898631096, 47.01504059135914, 43.805687204003334, 50.58975577354431, 56.61773331463337, 61.66035532951355, 59.17990542948246, 58.26903350651264, 50.88206648826599, 48.75348910689354, 35.76556943356991, 16.442908979952335, 5.439755329862237, 12.480206117033958, 13.82880600169301, 10.89723290875554, 8.555144034326077, 2.391034523025155, 0.2130286072497256, 0.22009251726558432, 0.03532875271048397, 5.645627807825804, 32.34330967068672, 37.843438535928726, 31.478806659579277, 24.11048524081707, 24.82812613248825, 37.10284687578678, 52.79997557401657, 53.77080447971821, 24.68668632209301, 1.4216317282989621, 0.037035388086223975, 0.0234916419867659, 0.010917602739937138, 0.012852073741669301, 0.027207992861804087, 0.04029757241369225, 0.02879504598240601, 0.08006856878637336, 0.031116747377382126, 0.01864208355982555, 0.001284786460473697, 0.052601408679038286, 0.018827767053153366, 0.04655274184187874, 0.09804888482904062, 0.0801363491336815, 0.049048421205952764, 0.06097359517298173, 0.007742693587715621, 0.023094763673725538, 0.0645627586345654, 0.02343995511182584, 0.08431346053839661, 0.1622058148495853, 0.11121750125312246, 0.17342818609904498, 0.11195016428246163, 0.16545495222089812, 0.08699740792508237, 0.0893517081567552, 0.10814478722750209, 0.17607599089387804, 0.1255543768638745, 0.2017928328132257, 0.08382870451896451, 0.22914331988431513, 0.08289920166134834, 0.19357437849976122, 0.17591700801858678, 0.0679194406257011, 0.13919386372435838, 0.18763976491754875, 0.2547616936499253, 6.645479556173086, 59.051951095461845, 75.52914753556252, 69.23478528857231, 53.282203897833824, 48.04997205734253, 35.017021000385284, 47.76360422372818, 52.25752428174019, 41.05624973773956, 6.667499374598265, 0.24372120795305818, 0.1958907104562968, 0.48949145595543087, 2.509486279450357, 7.392432549968362, 16.47094577550888, 16.269689574837685, 21.22454959899187, 16.733760572969913, 36.237990483641624, 56.31354823708534, 58.95308040082455, 65.65698847174644, 64.41959246993065, 64.17046263813972, 56.791197806596756, 49.79082964360714, 49.18900653719902, 59.831057488918304, 63.12293864786625, 62.1569848805666, 58.961979523301125, 53.32433603703976, 54.704193994402885, 57.424380630254745, 56.29660874605179, 54.65616837143898, 46.206877157092094, 46.464142352342606, 49.71268303692341, 59.641785845160484, 60.21389454603195, 57.557236701250076, 56.54690511524677, 61.41573965549469, 58.84868860244751, 50.57746723294258, 42.86906026303768, 43.07559818029404, 45.10965943336487, 44.03364837169647, 47.00958788394928, 48.82397912442684, 48.5041730850935, 48.27716566622257, 42.55632944405079, 48.34980636835098, 45.688679963350296, 46.76184117794037, 46.35038785636425, 52.85292573273182, 56.90206825733185, 63.37668523192406, 56.17038331925869, 60.75275883078575, 32.15364284813404, 35.54822489619255, 61.78381450474262, 54.27634455263615, 58.67244265973568, 51.69872626662254, 51.87280252575874, 45.994951128959656, 45.574389696121216, 45.78670710325241, 45.750780031085014, 43.77591960132122, 43.62106271088123, 45.0464878231287, 43.65714557468891, 45.273803025484085, 47.19082295894623, 45.54482348263264, 45.82003891468048, 46.393466144800186, 47.67271310091019, 47.868801578879356, 53.990987464785576, 58.217086493968964, 55.45150749385357, 53.60471539199352, 61.04880474507809, 54.48037840425968, 51.571607887744904, 54.208848774433136, 60.593547374010086, 55.25985337793827, 56.42702154815197, 60.245539247989655, 60.15450373291969, 54.371115267276764, 50.55414788424969, 45.301465541124344, 54.06297840178013, 58.47885824739933, 64.01887357234955, 61.824172139167786, 58.29339399933815, 53.30188304185867, 50.93836046755314, 36.41709767282009, 24.49961096048355, 14.758224729448557, 23.01273174583912, 12.670021131634712, 19.8998361825943, 15.294438656419516, 3.1241909321397543, 0.40986298816278577, 0.2963446732610464, 0.17968134430702776, 7.438350711017847, 40.907240733504295, 54.46854203939438, 44.888921678066254, 27.288917787373066, 31.481232829391956, 44.407605305314064, 61.037819534540176, 61.943204551935196, 31.922733038663864, 2.2258269879966974, 0.1740841259015724, 0.25371499825268984, 0.192539275449235, 0.12406131674651988, 0.1893692955491133, 0.1462873409036547, 0.1799520055647008, 0.180852779885754, 0.12429276292095892, 0.11076330687501468, 0.09520005449303426, 0.17363754595862702, 0.13128476624842733, 0.09137522574746981, 0.19600335363065824, 0.1582717345445417, 0.1408081388217397, 0.21848339267307892, 0.10732942668255419, 0.16520394303370267, 0.45082116848789155, 0.12396768739563413], [0.04598366671416443, 0.11578371326322667, 0.05872801586519927, 0.02277622090332443, 0.05671427978086285, 0.09193618549034, 0.03481273372017313, 0.043637329727062024, 0.08496588256093673, 0.016846639082359616, 0.14509096916299313, 0.013677417100552702, 0.04252496910339687, 0.0235985168183106, 0.011088253104389878, 0.007391251874651061, 0.011047927582694683, 0.03305592174001504, 0.04108365152205806, 0.031710467374068685, 0.08255533495685086, 7.529672160744667, 43.27675558626652, 55.13990141451359, 50.36309793591499, 34.0863711386919, 21.040648967027664, 20.001843608915806, 41.618045791983604, 43.032687082886696, 25.202936120331287, 0.9265957167372108, 0.02700331595406169, 0.051244284040876664, 0.21161910553928465, 1.0892072785645723, 6.771560115739703, 7.423334391787648, 3.5022518830373883, 6.037229094654322, 24.331920258700848, 41.565430015325546, 55.807973966002464, 59.049952402710915, 59.11024756729603, 58.91784489154816, 58.42069856822491, 50.24933964014053, 42.73503005504608, 48.249864131212234, 55.79295717179775, 57.14892581105232, 56.09499916434288, 55.250775665044785, 53.78072954714298, 51.64285786449909, 54.4887113571167, 53.98156017065048, 48.82878586649895, 41.71589054167271, 42.11959607899189, 46.135703176259995, 52.02256768941879, 55.75838662683964, 56.83313615620136, 54.92067217826843, 54.97210621833801, 48.02148498594761, 40.24915024638176, 38.850464299321175, 40.30621558427811, 41.31448768079281, 42.11624465882778, 42.53883138298988, 44.40932281315327, 43.40760536491871, 44.72282499074936, 41.47313676774502, 42.52191849052906, 40.440792962908745, 43.909714221954346, 42.16401569545269, 46.11960344016552, 48.25407050549984, 56.40478514134884, 50.951872542500496, 58.91374871134758, 31.055969148874283, 34.1202387213707, 60.78601844608784, 50.526139587163925, 52.73767791688442, 44.546465054154396, 45.76061770319939, 42.855574786663055, 45.38781210780144, 42.90293164551258, 42.81401641666889, 39.52641382813454, 40.70165276527405, 39.35425266623497, 40.439584627747536, 40.10865658521652, 41.17803320288658, 39.416272938251495, 40.208097249269485, 40.15146888792515, 40.25260046124458, 40.878119096159935, 48.928933292627335, 52.31803223490715, 53.85807439684868, 52.122350335121155, 54.63133290410042, 49.68012258410454, 42.97095559537411, 49.57809805870056, 55.43642230331898, 53.947346806526184, 50.01448564231396, 52.57129244506359, 55.30020721256733, 52.918077036738396, 48.72067406773567, 44.93646092712879, 45.04302240908146, 48.99761840701103, 55.4278651624918, 56.205922812223434, 58.172925263643265, 52.019242867827415, 49.404728561639786, 51.9905050098896, 26.96294277906418, 5.571992984041572, 6.011189566925168, 10.930141042917967, 4.462028844282031, 7.353108935058117, 1.0563788213767111, 0.5965448333881795, 0.11020164209185168, 0.04408049579069484, 0.5577426811214536, 22.370438911020756, 43.559487015008926, 23.762887492775917, 25.262129344046116, 41.67733781039715, 30.63703592866659, 41.79129369556904, 45.072987601161, 32.24058598279953, 2.867338014766574, 0.040224199983640574, 0.0882311690656934, 0.03230979244108312, 0.04664323561883066, 0.055979594399104826, 0.03845827071927488, 0.017305590627074707, 0.018446173271513544, 0.037234365299809724, 0.02125426341081038, 0.09673851178376935, 0.0077410167978086974, 0.007119610982044833, 0.04126790452573914, 0.06538732181070372, 0.052440366343944333, 0.020402400332386605, 0.0653645972488448, 0.05166333772649523, 0.04324429573898669, 0.012926204090035753, 0.021241492904664483, 0.0733400798344519, 0.09389520302647725, 0.02225187316071242, 0.08323303452925757, 0.04363423868198879, 0.06290388788329437, 0.019351407900103368, 0.019860426582454238, 0.026003887942351867, 0.042082285435753874, 0.12507720559369773, 0.011794552265200764, 0.027102518833999056, 0.043892598841921426, 0.03446255133894738, 0.03904319441062398, 0.035357540618861094, 0.01863166195107624, 0.07778105442412198, 0.05752634519012645, 0.04539628280326724, 9.342142604291439, 55.952947586774826, 62.09133580327034, 57.89080560207367, 40.60288466513157, 28.073604181408882, 25.1540669426322, 45.27764841914177, 45.50683692097664, 25.70514567196369, 1.084714257158339, 0.06462759265559725, 0.07694964864640497, 0.7199311594013125, 2.798781618475914, 8.233683183789253, 13.753804676234722, 7.3795008938759565, 8.850795719772577, 25.50468172878027, 44.63539928197861, 56.416735500097275, 59.95433807373047, 60.455424785614014, 60.94061315059662, 61.008971482515335, 53.70882220566273, 45.66240817308426, 50.4606045037508, 57.34863929450512, 60.15971705317497, 59.43933270871639, 55.64817734062672, 54.44839932024479, 52.534259632229805, 56.431132927536964, 56.55559524893761, 51.86670385301113, 43.90122167766094, 43.42734910547733, 47.05091826617718, 53.716710582375526, 57.201150208711624, 58.49956713616848, 57.01763145625591, 56.88716545701027, 50.171204432845116, 43.58392730355263, 40.41798658668995, 42.86507807672024, 43.82328025996685, 45.23086912930012, 44.59370791912079, 46.363751739263535, 46.11252062022686, 45.77286444604397, 43.79761643707752, 43.4924054145813, 40.97428433597088, 44.417553171515465, 44.719914346933365, 48.653619065880775, 50.6039822101593, 58.62234614789486, 53.47147174179554, 59.321793615818024, 32.15805821120739, 35.44826366007328, 62.418578043580055, 51.84132881462574, 53.652695417404175, 46.35097302496433, 47.783313766121864, 45.676098838448524, 47.002166882157326, 44.213591516017914, 44.827995747327805, 41.701603308320045, 42.04253241419792, 41.44599102437496, 41.53554081916809, 42.03842483460903, 42.83508628606796, 42.07020252943039, 42.534982189536095, 41.47978641092777, 42.75681048631668, 42.50690549612045, 50.98605550825596, 54.99260611832142, 55.040384754538536, 54.3421646207571, 56.15728922188282, 50.52237018942833, 45.16215741634369, 51.97079546749592, 56.91487357020378, 56.02929688990116, 50.74365891516209, 55.790076926350594, 57.563289776444435, 55.93669205904007, 50.176322758197784, 46.168939992785454, 46.324135065078735, 50.7609061896801, 58.028707802295685, 57.925341948866844, 59.44470942020416, 54.38576728105545, 53.13567616045475, 49.90490332245827, 29.201879538595676, 9.339349754154682, 3.576798657886684, 11.230515874922276, 11.411674004048109, 9.621394369751215, 6.097690500319004, 0.9133553865831345, 0.24665761913638562, 0.08104653388727456, 0.6083180860150605, 21.613582223653793, 45.67518688738346, 27.339551970362663, 27.83270090818405, 44.63628463447094, 37.17145599424839, 49.44579295814037, 50.637591406702995, 38.86937588453293, 3.927046051248908, 0.038879736384842545, 0.06905169822857715, 0.02678750126506202, 0.04871937519055791, 0.06787932754377834, 0.06640793813858181, 0.039483785221818835, 0.03490999217319768, 0.019727602557395585, 0.046628414929728024, 0.0333696498273639, 0.05546843647607602, 0.028799450628866907, 0.05065484809165355, 0.04131473775487393, 0.017588063165021595, 0.04589613039570395, 0.04512687577516772, 0.059106507469550706, 0.08762164317886345, 0.03144953938317485, 0.03188476446666755, 0.13788841111818328, 0.2011408263933845, 0.09090934996493161, 0.1531625524512492, 0.20007339539006352, 0.20529217785224319, 0.10163647864828818, 0.19151971297105774, 0.2055565160117112, 0.19699645112268627, 0.19520925561664626, 0.1939885414321907, 0.1547709942678921, 0.10533480832236819, 0.08998914621770382, 0.11630502747721039, 0.1591362920589745, 0.18166120134992525, 0.21184269979130477, 0.17632784612942487, 0.1315500246710144, 12.786317691206932, 66.36693477630615, 70.66904112696648, 65.56619614362717, 48.895791471004486, 31.869644187390804, 29.455445632338524, 55.097700878977776, 55.68337105214596, 32.83382534980774, 1.7258603847585618, 0.13162228016881272, 0.2487468539038673, 0.3727101848926395, 2.2805198282003403, 17.344839982688427, 15.772559400647879, 10.823435168713331, 12.320251800119877, 29.44001656025648, 44.92983788251877, 57.69790135324001, 60.36074906587601, 61.418342515826225, 62.66491502523422, 64.7006405889988, 55.52044719457626, 48.53744789958, 53.14980760216713, 59.51435208320618, 63.00433561205864, 59.79770667850971, 56.85689628124237, 54.43169541656971, 53.44186753034592, 57.59065970778465, 58.823294565081596, 53.314293175935745, 45.17956808209419, 47.21917703747749, 50.17465464770794, 56.58235341310501, 60.1148072630167, 61.208335384726524, 59.542519971728325, 59.60690751671791, 52.921223267912865, 45.35066530108452, 41.63156546652317, 43.555516228079796, 46.30149967968464, 46.41603693366051, 47.00679503381252, 49.89772170782089, 48.76312538981438, 49.29970219731331, 46.36786311864853, 45.16930103302002, 43.831765204668045, 47.574172988533974, 47.21400551497936, 50.70457801222801, 53.06140534579754, 59.48833487927914, 56.45238518714905, 62.09963455796242, 34.442089051008224, 39.105738401412964, 64.31727916002274, 54.33657892048359, 55.15961475670338, 48.589820489287376, 50.0363876670599, 47.28686660528183, 48.58043499290943, 46.834709867835045, 46.2463266402483, 43.82652148604393, 44.73327063024044, 43.16472999751568, 43.728589341044426, 44.32535111904144, 45.86125910282135, 44.65358130633831, 44.209347143769264, 44.152802377939224, 44.53898325562477, 45.100471526384354, 54.844243079423904, 57.6116231828928, 57.84189082682133, 55.65732724964619, 58.93902875483036, 54.32039558887482, 47.877856492996216, 54.389449283480644, 60.31819134950638, 57.762653678655624, 51.24717749655247, 56.85797922313213, 59.75829899311066, 59.004822224378586, 53.909797221422195, 49.27197128534317, 48.20556990802288, 53.49413372576237, 61.26514233648777, 61.11599273979664, 61.18435487151146, 55.261624082922935, 52.30097495019436, 52.97955773770809, 30.174294859170914, 11.021851021796465, 12.979644667357206, 19.14216823875904, 14.341921918094158, 17.865051068365574, 5.059029534459114, 1.2297261133790016, 0.26552286464720964, 0.16359704488422722, 1.2022199830971658, 30.202605240046978, 57.020447105169296, 34.24047566950321, 36.892072185873985, 50.910454764962196, 41.879999935626984, 56.047444716095924, 58.70677001774311, 47.01196275651455, 5.89960427954793, 0.16794046416180208, 0.21601397049380466, 0.09047618063050322, 0.11363699173671193, 0.12279538350412622, 0.2413733198773116, 0.17812188423704356, 0.16196540353121236, 0.09194383703288622, 0.19078752491623163, 0.1615113575826399, 0.14442788989981636, 0.0611531800677767, 0.1468569689313881, 0.17905237415106967, 0.15879040671279654, 0.12429056616383605, 0.17710297484882176, 0.1724653533892706, 0.2048625485622324, 0.1333761532441713, 0.17551470460603014], [0.027376395446481183, 0.01691322642727755, 0.025153208589472342, 0.06149967397504952, 0.026821786632353906, 0.032663425809005275, 0.0035456965679259156, 0.061350439209491014, 0.043040624441346154, 0.02026525700784987, 0.06010770550346933, 0.01735593978082761, 0.02279367621667916, 0.11149955447763205, 0.011932199322473025, 0.04277110238035675, 0.03944394673453644, 0.06005041170283221, 0.06050786039850209, 0.03777972509851679, 0.10954213255899958, 12.161129638552666, 53.475453928112984, 53.203681111335754, 44.3752234429121, 23.62938355654478, 20.45487429946661, 24.584971480071545, 30.75430143624544, 34.117415472865105, 11.015965137630701, 0.19639320380520076, 0.0881588616175577, 0.12819329072954133, 2.6383703760802746, 1.3332272158004344, 3.9417237136512995, 7.313447613269091, 8.842842746526003, 16.646348163485527, 40.10758504271507, 54.081430211663246, 58.88483986258507, 56.48620717227459, 61.1641513556242, 59.46045957505703, 59.12350505590439, 49.59194451570511, 42.8102508187294, 53.925334587693214, 60.209361389279366, 59.015317261219025, 56.1825692653656, 52.19507463276386, 52.326919957995415, 52.9656732827425, 56.028742119669914, 52.103347554802895, 48.067530915141106, 42.77944967150688, 41.93625971674919, 44.43547300994396, 52.37026423215866, 52.465863302350044, 51.87224015593529, 50.76593331992626, 48.09924781322479, 40.616240948438644, 38.780749440193176, 38.90535995364189, 39.43135812878609, 40.98304286599159, 44.69137027859688, 43.480835035443306, 43.91237407922745, 41.85249701142311, 43.3150727301836, 38.08599092066288, 40.831161215901375, 40.5940805375576, 42.17010296881199, 40.146681144833565, 45.59714287519455, 46.111555472016335, 55.99081255495548, 49.67476487159729, 62.51420371234417, 33.94973427057266, 33.31035017967224, 61.564224287867546, 49.71620924770832, 53.94631706178188, 47.59671337902546, 47.56610982120037, 46.918806955218315, 47.43564382195473, 44.762772247195244, 45.24480678141117, 40.923773646354675, 39.31353785097599, 39.688741117715836, 40.559927970170975, 40.88925249874592, 41.983384788036346, 39.409592896699905, 40.22119514644146, 39.26754131913185, 38.720002099871635, 40.36964938044548, 46.07607677578926, 53.026819601655006, 50.20020067691803, 52.365636080503464, 51.377039328217506, 49.65185210108757, 40.794561579823494, 45.440006107091904, 53.26027147471905, 55.27496516704559, 53.85248489677906, 53.295127004384995, 55.79721674323082, 55.96176691353321, 51.962131932377815, 49.03171397745609, 46.68784774839878, 45.75386546552181, 50.78588604927063, 56.25875137746334, 56.15769200026989, 60.08494846522808, 50.31682401895523, 49.0957747399807, 44.597279727458954, 18.872166126966476, 7.69001548178494, 19.686933606863022, 12.023695763200521, 7.657491602003574, 4.367730729281902, 0.9021106618456542, 0.15990806627087295, 0.06687481582048349, 0.053176721557974815, 7.179191317409277, 36.76532618701458, 37.993716672062874, 22.47607134282589, 37.103751227259636, 37.190489172935486, 44.078843146562576, 47.8176449239254, 39.62687663733959, 12.236755080521107, 0.41640552459284663, 0.03750141229829751, 0.0662669820303563, 0.05414102372014895, 0.031881547256489284, 0.04295365957659669, 0.021269694516377058, 0.09502082582912408, 0.04075594879395794, 0.0428040463157231, 0.024901882134145126, 0.06363138556480408, 0.04348394264525268, 0.026428029050293844, 0.05008954678487498, 0.05357487636501901, 0.10205994069110602, 0.06298260006587952, 0.04359350219601765, 0.05221936218731571, 0.029127231282473076, 0.04099300560483243, 0.12051373952999711, 0.05557942466111854, 0.026466323870408814, 0.05484480978338979, 0.022222706757020205, 0.058112693805014715, 0.024549701520300005, 0.049029637448256835, 0.01952310933120316, 0.03252004287787713, 0.04801098410098348, 0.08488011997542344, 0.03780265375098679, 0.04403310966154095, 0.03774231343413703, 0.0277768249361543, 0.03838561075099278, 0.011545912384463008, 0.04522063500189688, 0.07520910454331897, 0.08385589680983685, 16.39930821955204, 62.123402282595634, 61.45666345953941, 49.156818464398384, 33.38288068771362, 26.862660460174084, 22.220151275396347, 32.69068323075771, 36.613626927137375, 13.422033078968525, 0.2061323483940214, 0.11551158997463062, 0.05261496771709062, 2.5115951662883162, 3.960994379594922, 9.041393492370844, 11.595320999622345, 10.07786862552166, 13.171704411506653, 37.65904203057289, 53.75840574502945, 60.0383135676384, 57.44082994759083, 62.5680810213089, 60.51765784621239, 61.990565210580826, 51.80859737098217, 46.705345809459686, 55.67230984568596, 62.48537465929985, 59.399803429841995, 57.46257998049259, 53.67622755467892, 54.11445423960686, 52.77802035212517, 59.99531887471676, 54.05760169029236, 51.3060287386179, 44.832661896944046, 44.321296736598015, 46.76142320036888, 54.24807406961918, 54.868253991007805, 55.15212915837765, 52.669490575790405, 51.16933487355709, 43.57480779290199, 41.085200384259224, 40.80686151981354, 42.42714777588844, 42.374334409832954, 46.52498468756676, 46.900978311896324, 46.11665479838848, 45.47634735703468, 44.412442445755005, 40.33131703734398, 43.062082305550575, 41.426235884428024, 43.854043409228325, 41.767161190509796, 46.021576300263405, 47.71403208374977, 58.240120857954025, 52.081403732299805, 63.19256231188774, 34.90193657577038, 33.72025318443775, 61.61005362868309, 52.11976267397404, 56.308764293789864, 49.36473950743675, 50.605855509638786, 47.65938721597195, 49.455930814146996, 46.333927139639854, 46.18063576519489, 43.01757149398327, 41.64656326174736, 41.07110694050789, 42.16812327504158, 43.77237819135189, 43.88328284025192, 42.28436663746834, 42.25769966840744, 41.22174985706806, 41.666865572333336, 42.23877288401127, 49.01974841952324, 54.022825956344604, 52.911043614149094, 53.306670784950256, 53.2502818107605, 52.33838014304638, 42.354465276002884, 47.015808150172234, 54.631416499614716, 58.31344552338123, 53.60193774104118, 52.62577772140503, 58.34237717092037, 56.82164937257767, 56.39147445559502, 50.89541897177696, 47.945428267121315, 49.68779817223549, 53.02507549524307, 58.76733496785164, 57.89967432618141, 58.80287066102028, 51.91639378666878, 53.207249119877815, 41.35124310851097, 22.638848908245564, 7.8718366753309965, 4.94934699498117, 8.214707002043724, 8.687105253338814, 7.383600873872638, 2.1967428736388683, 0.3247812489280477, 0.16318760201102123, 0.04962866936693899, 8.225063346326351, 33.26018147170544, 36.03177174925804, 23.811771869659424, 39.28726226091385, 37.89329946041107, 47.726795598864555, 52.491477727890015, 46.851850748062134, 14.8918198607862, 0.4598983173491433, 0.03999798595032189, 0.0528747342468705, 0.030836059704597574, 0.06917808597791009, 0.06552189544891007, 0.032066330895759165, 0.041175726073561236, 0.06805031094700098, 0.03871236724080518, 0.006129912526375847, 0.08333723948453553, 0.04666154069127515, 0.0382609373627929, 0.08094885983155109, 0.09077910304768011, 0.07545557920821011, 0.03442368506512139, 0.04464211604499724, 0.05641533156449441, 0.015099321954039624, 0.03846144340059254, 0.2622476778924465, 0.11528280811035074, 0.129206960555166, 0.13959877949673682, 0.10099720006110147, 0.11257815480348654, 0.11384179480955936, 0.14527804974932224, 0.1248910601134412, 0.16956272476818413, 0.13458965375320986, 0.19012735487194732, 0.1658574485918507, 0.15864907210925594, 0.17376176663674414, 0.07834239266230725, 0.1813149597728625, 0.11691019695717841, 0.24262342310976237, 0.15832665347261354, 0.4115234990604222, 21.861328929662704, 72.71195590496063, 69.62222769856453, 56.45744651556015, 37.37165205180645, 30.08369632065296, 36.43676541745663, 42.84174732863903, 46.505833715200424, 15.477712322026491, 0.26568809640593827, 0.39463616616558284, 0.2298967630486004, 4.650348639115691, 6.35907799936831, 13.21217318996787, 15.32169934362173, 17.800540030002594, 22.228201143443584, 42.64945864677429, 57.22354620695114, 61.899959072470665, 57.92457439005375, 62.61400915682316, 64.85944166779518, 66.72587111592293, 53.26084904372692, 49.14956845343113, 60.390615463256836, 64.76520672440529, 62.34947495162487, 57.540111020207405, 53.58551882207394, 54.040259420871735, 53.80431108176708, 62.19803407788277, 55.7030425965786, 53.59769716858864, 47.738415375351906, 47.51744583249092, 48.62647332251072, 57.328758761286736, 57.39631913602352, 57.48328126966953, 55.93372821807861, 54.14131499826908, 45.01366138458252, 42.36623324453831, 42.751916348934174, 44.598438665270805, 43.99197980761528, 49.394438713788986, 49.20950643718243, 48.49810481071472, 47.583220303058624, 45.385452434420586, 42.199779376387596, 44.755552634596825, 43.99229139089584, 45.798501670360565, 43.16430062055588, 49.36470530927181, 51.3194078207016, 60.57918794453144, 55.05558393895626, 64.6156695485115, 35.99948488175869, 37.33260914683342, 63.50729942321777, 54.94735434651375, 58.0100242048502, 52.55738139152527, 51.67348802089691, 50.22457256913185, 51.08194716274738, 48.93531695008278, 48.60991761088371, 44.64606910943985, 43.803639113903046, 43.184929713606834, 44.03524428606033, 45.103929340839386, 46.725556924939156, 44.662571623921394, 44.84554320573807, 43.76302309334278, 44.17253091931343, 44.34708595275879, 50.60495875775814, 56.8721866607666, 53.83102744817734, 55.97284711897373, 55.45276142656803, 53.172340393066406, 45.31484842300415, 49.07005771994591, 58.638198897242546, 60.54444260895252, 55.94800405204296, 53.69032479822636, 61.274786219000816, 59.606808722019196, 58.690772876143456, 52.851747795939445, 51.008630096912384, 51.61560572683811, 56.04510024189949, 60.360832661390305, 62.545457035303116, 60.52299655973911, 55.14172151684761, 52.78905875980854, 42.83246822655201, 23.435681350529194, 14.297331310808659, 28.596589118242264, 19.52217634767294, 19.461869783699512, 11.568749975413084, 2.8397329710423946, 0.47822102322243154, 0.4202039848314598, 0.22633001615758985, 10.68756490945816, 48.938322588801384, 52.53634192049503, 33.310901150107384, 47.38675944507122, 46.1397385597229, 58.539009019732475, 59.3300049751997, 55.36293424665928, 19.496077448129654, 0.7481964176986367, 0.1609211423783563, 0.21819628542289138, 0.21490270824870095, 0.16855463589308783, 0.18674944003578275, 0.13048805587459356, 0.16380233777454123, 0.13058239768724889, 0.12556556845083833, 0.1352248282637447, 0.13585980981588364, 0.10464570194017142, 0.12541329459054396, 0.1553834739024751, 0.188002452487126, 0.21134615846676752, 0.18109305761754513, 0.11799107567640021, 0.11521878303028643, 0.14528636180330068, 0.09684452015790157], [0.04263458802597597, 0.050605855212779716, 0.05879476462723687, 0.025520378731016535, 0.0868835105211474, 0.0228643342416035, 0.0710941331635695, 0.05229638598393649, 0.022225864595384337, 0.06005035975249484, 0.018969007032865193, 0.049724792334018275, 0.08245055854786187, 0.0473499865620397, 0.06712759874062613, 0.03277176081610378, 0.04239588735799771, 0.025899619904521387, 0.03307449027488474, 0.07430401834426448, 0.2684334194054827, 27.73230269551277, 61.350778341293335, 47.946826592087746, 44.99750845134258, 25.767962001264095, 20.856250561773777, 31.151857003569603, 50.291050001978874, 31.818544529378414, 3.869320023804903, 0.057783258162089624, 0.1793363198521547, 0.041415796004002914, 1.806846745312214, 3.9804291492328048, 4.7743345610797405, 19.03459221124649, 10.965296756476164, 25.726270638406277, 47.30928160250187, 55.315691381692886, 59.66140799224377, 56.407946571707726, 57.66197808086872, 57.703023478388786, 56.405708491802216, 47.27849565446377, 41.59229837357998, 55.37595234811306, 57.10939273238182, 55.42991325259209, 52.41271175444126, 54.54075716435909, 54.26733523607254, 55.37467181682587, 55.06389029324055, 51.10393278300762, 45.38728013634682, 39.85382705926895, 39.0165875852108, 40.94654582440853, 42.36233465373516, 44.81474205851555, 44.90664392709732, 41.88863307237625, 38.70767556130886, 40.38393661379814, 40.89848220348358, 38.57151746749878, 39.4462039321661, 42.93952368199825, 45.73141627013683, 45.454300940036774, 44.43597078323364, 40.75356937944889, 40.73618531227112, 39.28280510008335, 41.361312568187714, 42.78684787452221, 46.533275842666626, 43.42630796134472, 46.85002684593201, 44.502980187535286, 54.04764622449875, 50.27783051133156, 59.905096516013145, 34.80133697390556, 32.22330830991268, 60.69944769144058, 50.03619007766247, 55.11586770415306, 51.29204548895359, 54.98592607676983, 55.57133786380291, 53.530687764286995, 50.77066786587238, 48.716380298137665, 42.309069111943245, 38.716160506010056, 39.14963744580746, 41.51976026594639, 43.89103062450886, 44.3918589502573, 42.421018704771996, 39.77919526398182, 39.24229547381401, 38.89153249561787, 40.34694939851761, 41.94048509001732, 49.087513983249664, 52.796540558338165, 54.42356005311012, 51.537755504250526, 45.510435327887535, 39.59834396839142, 41.34147383272648, 51.48416317999363, 53.444284200668335, 53.41096378862858, 51.78386069834232, 52.300902754068375, 55.22495225071907, 51.90830402076244, 51.238840743899345, 48.13421733677387, 45.11404439806938, 45.769174844026566, 55.56213475763798, 57.00023598968983, 59.173951148986816, 54.00540009140968, 52.89912365376949, 45.63479885458946, 31.307764537632465, 10.73279483243823, 7.299695676192641, 9.67978773638606, 7.403281917795539, 9.14087500423193, 1.445206138305366, 0.06697050092043355, 0.01238581853613141, 0.09978900590795092, 1.5310507756657898, 29.399577230215073, 40.679655745625496, 24.6399849280715, 21.379942260682583, 31.054266840219498, 44.739920273423195, 47.860989198088646, 45.66375710070133, 19.75540593266487, 0.8390985243022442, 0.04015746235381812, 0.0073727083872654475, 0.022829327135696076, 0.06727304484229535, 0.122284095705254, 0.014509619759337511, 0.05648206548357848, 0.06376935823936947, 0.10940142878098413, 0.044468876512837596, 0.044982034523854963, 0.060566059619304724, 0.03968553806771524, 0.014045156840438722, 0.031140813371166587, 0.02287412316945847, 0.04179680719971657, 0.011080161839345237, 0.01789813246432459, 0.03109234370640479, 0.018806400621542707, 0.06594414779101498, 0.031479562967433594, 0.009975540888262913, 0.039388044460793026, 0.011560915827431018, 0.05021562654292211, 0.061323046538745984, 0.040032351098489016, 0.010886694144573994, 0.03467172566161025, 0.045736153042525984, 0.057683524646563455, 0.019759828464884777, 0.012087015038559912, 0.04113511946343351, 0.020663666000473313, 0.03979989931394812, 0.07567682085209526, 0.0030368235320565873, 0.07647198755876161, 0.40020800312049687, 35.37806622684002, 70.82474157214165, 53.276261016726494, 50.88229067623615, 30.04691619426012, 25.857690386474133, 33.648558631539345, 43.934203907847404, 34.31381173431873, 4.424924785271287, 0.09972909232601523, 0.036794338520849124, 0.15756264212541282, 3.6538722971454263, 7.628284469246864, 9.85584368929267, 6.085360161960125, 6.712458562105894, 23.838486336171627, 50.10088540613651, 56.65791615843773, 60.25813937187195, 57.99773186445236, 59.825714975595474, 58.69219020009041, 59.01317037642002, 48.19197043776512, 43.94898131489754, 57.9745227098465, 60.24105168879032, 56.23029850423336, 53.93633119761944, 54.31088089942932, 54.99474160373211, 56.74857549369335, 57.956188693642616, 54.134072586894035, 47.67338566482067, 40.70629991590977, 40.94911448657513, 43.95412243902683, 44.60946187376976, 46.17360234260559, 48.025349378585815, 44.73868913948536, 41.64238728582859, 41.32378198206425, 43.36881324648857, 41.187836676836014, 41.14259630441666, 44.678169786930084, 47.709935903549194, 47.73692965507507, 47.07801841199398, 42.26012393832207, 43.02253782749176, 41.050686836242676, 43.886174485087395, 43.82377043366432, 48.09088446199894, 44.92639146745205, 48.27699847519398, 44.95442256331444, 54.7668032348156, 51.94782190024853, 60.824381187558174, 35.088753551244736, 33.132804706692696, 62.46872015297413, 51.47155545651913, 56.89916901290417, 52.92607180774212, 55.55120274424553, 56.650787740945816, 54.85693819820881, 52.183002680540085, 50.29233433306217, 44.225572273135185, 40.9038171172142, 40.44962748885155, 42.956238985061646, 46.170235723257065, 47.9474725574255, 44.34936203062534, 41.732526049017906, 41.88154265284538, 41.49789243936539, 41.87560737133026, 44.38686601817608, 51.802145317196846, 55.49392841756344, 56.785057336091995, 55.2969241887331, 48.491162583231926, 41.81204818189144, 44.47923146188259, 53.58354292809963, 55.48931926488876, 55.23332700133324, 52.865252271294594, 53.73710408806801, 57.66054555773735, 53.792204931378365, 54.97349314391613, 49.5214506983757, 46.53259947896004, 48.08264650404453, 56.525751650333405, 57.28415295481682, 60.27111567556858, 53.97297263145447, 55.291612073779106, 47.193820998072624, 30.99142011255026, 15.401568207889795, 6.538826879113913, 7.852477664127946, 12.313909940421581, 17.320090010762215, 5.222733300179243, 1.016651715617627, 0.12761670135660097, 0.07076262321788818, 1.8477236456237733, 28.14319744706154, 39.79998394846916, 23.894979804754257, 28.08891735970974, 37.348632887005806, 50.2158672362566, 54.14900578558445, 52.19111904501915, 25.04987083375454, 1.0053677461110055, 0.029586529781227, 0.08216030459152535, 0.0339932394126663, 0.04856280058447737, 0.027002623901353218, 0.03684565432195086, 0.12027278644382022, 0.025127643457381055, 0.04896516336884815, 0.00813738117358298, 0.01380767515001935, 0.045612756148329936, 0.02461476189637324, 0.004642874009732623, 0.04112001304747537, 0.01627679397643078, 0.05200770538067445, 0.009429616129636997, 0.02971811070892727, 0.04195421301119495, 0.016856838046805933, 0.17460256058257073, 0.15093735622940585, 0.1128671619517263, 0.14683403656817973, 0.1336224126862362, 0.10358207073295489, 0.17298056714935228, 0.11962929987930693, 0.07976809545652941, 0.13757133594481274, 0.08802031006780453, 0.22361770388670266, 0.21839259832631797, 0.1620815644855611, 0.10685099376132712, 0.12322403315920383, 0.09119440146605484, 0.14837222668575123, 0.1751750978291966, 0.22865704988362268, 0.9061310242395848, 44.72322016954422, 80.20880922675133, 61.18759609758854, 60.02157926559448, 37.001415118575096, 31.872893013060093, 43.80490064620972, 65.11280447244644, 43.36893104016781, 5.871074935421348, 0.14427898538997397, 0.4627743177115917, 0.46199256903491914, 4.93135686032474, 10.37757184356451, 17.485521733760834, 30.429802648723125, 17.587154880166054, 28.652852699160576, 51.05747267603874, 60.40240243077278, 61.458688750863075, 60.48134699463844, 61.910172924399376, 61.4511651545763, 62.01807953417301, 50.60608729720116, 46.899864971637726, 59.9852342158556, 62.72914297878742, 56.72094337642193, 53.18214386701584, 54.81035269796848, 55.776272267103195, 60.20412527024746, 60.353183671832085, 56.30711518228054, 49.052768647670746, 43.72242987155914, 42.21595510840416, 46.379213109612465, 45.81818461418152, 49.43963348865509, 49.266161397099495, 46.9245408475399, 42.11485393345356, 43.35287690162659, 47.687357515096664, 43.45200598239899, 42.86648400127888, 47.99692690372467, 51.08160138130188, 51.66233941912651, 48.585549518465996, 43.925775960087776, 45.60063488781452, 44.21981558203697, 46.31537273526192, 46.23610898852348, 49.69161316752434, 48.59012447297573, 51.01914033293724, 48.83584588766098, 57.19347842037678, 56.15366041660309, 63.311530128121376, 38.925035297870636, 34.848716631531715, 64.32221129536629, 56.01059049367905, 58.80705043673515, 55.21109439432621, 57.7688055485487, 60.01952737569809, 57.42272391915321, 55.265876054763794, 52.11824655532837, 46.51218697428703, 40.98223350942135, 43.618577644228935, 46.10880061984062, 49.22684870660305, 49.72840279340744, 46.77599921822548, 43.38434301316738, 43.99187721312046, 42.72676929831505, 43.83742690086365, 46.2704249471426, 54.029293209314346, 57.95665606856346, 58.67144711315632, 56.81867033243179, 50.92625051736832, 43.17490965127945, 46.674396470189095, 57.21061170101166, 58.24949495494366, 57.29993350803852, 55.2614226937294, 55.96397079527378, 59.847651198506355, 56.76469422876835, 57.39931717514992, 52.6108331233263, 50.173347517848015, 50.22262707352638, 60.5174146592617, 61.52372986078262, 65.12449264526367, 54.91168566048145, 55.119773894548416, 50.9951826184988, 34.48097996413708, 16.66559413075447, 12.458611875772476, 26.553664840757847, 14.804545193910599, 16.246573515236378, 5.578396590426564, 0.9520456229802221, 0.23375315533485264, 0.325897735892795, 2.769849020987749, 37.96407826244831, 53.50986108183861, 36.07385829091072, 33.65130968391895, 43.22288207709789, 56.47119417786598, 61.0904087126255, 60.55304154753685, 30.704776793718338, 1.683641206473112, 0.13773922459222376, 0.13465539319440722, 0.10052043697214685, 0.1900050340918824, 0.22050760046113282, 0.1672043724101968, 0.16164294036570936, 0.11449790530605242, 0.16376189072616398, 0.1414118314278312, 0.22016713279299438, 0.13833461998729035, 0.11187603115104139, 0.07417467684717849, 0.08042227636906318, 0.1555000653024763, 0.18417602812405676, 0.11138991700136103, 0.1241771288914606, 0.12806914426619187, 0.22013890149537474], [0.021923569292994216, 0.05790737493953202, 0.020773216274392325, 0.023916183854453266, 0.05186441521800589, 0.01724024081340758, 0.041322418983327225, 0.03462615408352576, 0.07476712591596879, 0.030763331087655388, 0.05921884636336472, 0.01707697203528369, 0.06621817097766325, 0.03590358690416906, 0.04245552634529304, 0.025950824383471627, 0.041655261084088124, 0.04284775510313921, 0.06630744392168708, 0.11265316366916522, 1.7084738239645958, 41.600312143564224, 61.642051711678505, 51.402805745601654, 37.878579050302505, 24.98782966285944, 18.90898235142231, 35.95770612359047, 41.14060141146183, 17.490419670939445, 0.8968640340026468, 0.044873350707348436, 0.03393858023628127, 0.2223670217790641, 1.7102317046374083, 6.428657490760088, 7.695004139095545, 7.620631204918027, 23.8296727091074, 41.328778713941574, 57.92164474725723, 58.41311797499657, 59.011612460017204, 56.62515431642532, 58.835290521383286, 55.04777915775776, 51.839018538594246, 39.854028448462486, 45.111741721630096, 55.527917593717575, 58.87362666428089, 54.042771086096764, 55.572310611605644, 52.146395444869995, 51.4653579890728, 55.32540366053581, 53.1851989030838, 47.43917763233185, 39.275536090135574, 38.25552262365818, 38.64551089704037, 38.443323746323586, 39.067588448524475, 37.77834802865982, 39.074979051947594, 40.60613349080086, 43.83746109902859, 44.61211413145065, 45.859898775815964, 43.140878677368164, 41.641422137618065, 41.8975093960762, 44.33727487921715, 43.931829035282135, 43.35050582885742, 37.890833392739296, 39.963481575250626, 39.51999597251415, 46.927991062402725, 50.64605355262756, 51.768881902098656, 50.1341450214386, 53.664512783288956, 46.71489469707012, 52.69312530755997, 49.49043296277523, 60.746063590049744, 35.11923551559448, 26.200204007327557, 60.50211288034916, 52.53265991806984, 56.94105416536331, 52.741006538271904, 55.37649191915989, 51.75744071602821, 54.595656618475914, 51.990455612540245, 53.2516535371542, 45.668210461735725, 39.31044481694698, 38.26125651597977, 40.947628766298294, 42.77672901749611, 46.12221010029316, 42.88031905889511, 42.38301694393158, 39.89693954586983, 39.00588735938072, 39.41612854599953, 40.97281761467457, 41.41132168471813, 45.9575155377388, 44.477829337120056, 42.61915907263756, 39.323858097195625, 38.87156456708908, 37.744275256991386, 44.2796091735363, 52.86816291511059, 54.57465894520283, 56.88377983868122, 54.63812693953514, 54.01943653821945, 53.97956147789955, 51.21848903596401, 46.08839951455593, 46.259705722332, 46.66482858359814, 53.94518852233887, 53.78677502274513, 57.1413604170084, 55.3272769600153, 48.61108414828777, 51.942221000790596, 42.67874367535114, 24.851876758038998, 9.605983346700668, 5.243820743635297, 6.952080354094505, 9.942683279514313, 3.0378852132707834, 1.0267222439870238, 0.03034994369954802, 0.057766092286328785, 0.15844668843783438, 10.611731428653002, 41.222996190190315, 33.761906549334526, 15.986973345279694, 24.53849997371435, 40.34504950046539, 48.51599045097828, 45.73007494211197, 26.0918927192688, 5.12750138528645, 0.06316306069493294, 0.03121382585959509, 0.024129308258125093, 0.052276644855737686, 0.04547416006971616, 0.05311058135703206, 0.027458757140266243, 0.14610974496463314, 0.06573721475433558, 0.05114425366627984, 0.031254020577762276, 0.043358297043596394, 0.022158340289024636, 0.0780950125772506, 0.06079708276956808, 0.035892150408471934, 0.08469805630738847, 0.03294431386166252, 0.04080582853930537, 0.0811788736609742, 0.010510236024856567, 0.04163645877270028, 0.032127910599228926, 0.014598014186049113, 0.033923544324352406, 0.0579564902727725, 0.017625198379391804, 0.08439668497885577, 0.028707585734082386, 0.07004332626820542, 0.002769789753074292, 0.03696379681059625, 0.039061673887772486, 0.03707314856001176, 0.0179055001353845, 0.01948061395523837, 0.02342071307793958, 0.021339556587918196, 0.03557431082299445, 0.07336074864724651, 0.020131987694185227, 3.5648656357079744, 50.26033625006676, 67.58033126592636, 57.89224572479725, 47.630770951509476, 35.648338124156, 23.254881352186203, 34.14925396442413, 43.35351146757603, 21.137735657393932, 1.109423025045544, 0.023738259515084792, 0.1465609113802202, 0.5858843866735697, 3.768102955073118, 9.78641951456666, 6.217377427965403, 4.777726354077458, 17.17724997550249, 42.90493033826351, 58.159591779112816, 59.77866970002651, 61.52323588728905, 59.37705025076866, 59.697585850954056, 57.27140463888645, 55.50820045173168, 43.02993983030319, 48.44686076045036, 58.05037043988705, 59.16442885994911, 55.12998014688492, 54.839022159576416, 52.29053311049938, 53.64818885922432, 55.976992696523666, 54.68493662774563, 49.95235897600651, 41.46521419286728, 39.65242266654968, 42.1619638055563, 42.10852347314358, 40.767096653580666, 39.10687834024429, 40.86880959570408, 42.49286524951458, 45.26860490441322, 46.002881303429604, 46.68812893331051, 44.10598888993263, 43.37073594331741, 43.8595949113369, 46.56119294464588, 45.81436201930046, 45.34238174557686, 41.146840676665306, 43.793964833021164, 41.16715058684349, 49.571034237742424, 52.51524165272713, 53.4453709423542, 52.39933267235756, 53.84596444666386, 48.44093307852745, 54.50889207422733, 51.16263963282108, 63.42404969036579, 36.10323831439018, 28.480892926454544, 60.05359634757042, 54.15432550013065, 58.972227573394775, 55.53629994392395, 56.74291379749775, 55.38075529038906, 56.41633652150631, 53.959601148962975, 56.681383699178696, 47.34933145344257, 41.74312748014927, 40.226834043860435, 43.70422884821892, 46.78739480674267, 49.45388272404671, 46.02369658648968, 45.16769751906395, 40.127317383885384, 40.318226739764214, 40.77520161867142, 42.1674545109272, 43.77449847757816, 47.829724475741386, 47.41341881453991, 45.23965805768967, 41.92360259592533, 40.75422294437885, 39.587742537260056, 46.88208192586899, 55.43483018875122, 57.098145335912704, 57.582866325974464, 56.582767590880394, 56.447924226522446, 56.920121088624, 53.42424027621746, 48.974527046084404, 47.344049736857414, 49.20558504760265, 54.39770244061947, 56.13323271274567, 57.50572666525841, 56.0959605127573, 50.22896893322468, 52.86124348640442, 42.39275582134724, 26.377392299473286, 11.296915411949158, 3.905657948926091, 8.038889486342669, 15.269092116504908, 5.7913856115192175, 1.9113311637192965, 0.19645989319542423, 0.06079372455133125, 0.12110434807254933, 11.98450181633234, 40.50117552280426, 36.94268546998501, 20.736344195902348, 29.050868041813374, 46.6621383279562, 53.16959694027901, 51.44580043852329, 31.457334011793137, 5.995806567370892, 0.02860363125364529, 0.047821847765590064, 0.12077918348950334, 0.031004120901343413, 0.05836194039147813, 0.059520551658351906, 0.08756142531638034, 0.06905756861669943, 0.040877516294131055, 0.08231284562498331, 0.020630838953366037, 0.056435684964526445, 0.012767207299475558, 0.01771695380739402, 0.03546236526744906, 0.03142612462397665, 0.03161297514452599, 0.009516222908132477, 0.041153955171466805, 0.020779225815203972, 0.025203414879797492, 0.14531974360579625, 0.13759563385974616, 0.10923691690550186, 0.11010411646566354, 0.19916246848879382, 0.09021795776789077, 0.20492849580477923, 0.09475345970713533, 0.13647165120346472, 0.166091492283158, 0.18170096562243998, 0.08412674360442907, 0.1481951354071498, 0.19970957975601777, 0.0816560820385348, 0.09501321139396168, 0.27244440105278045, 0.25855923362541944, 0.19038250524317846, 0.19213312771171331, 5.349329207092524, 61.181349232792854, 73.42925101518631, 66.87309041619301, 50.38052000105381, 38.184223249554634, 29.5317455381155, 48.70296321809292, 53.578485399484634, 26.47476017475128, 1.2981977267190814, 0.16558993404032663, 0.29077562678139657, 0.9299861441832036, 4.368008114397526, 13.778429254889488, 18.140477389097214, 21.17180272936821, 28.729830868542194, 44.500552117824554, 64.63146910071373, 62.92453609406948, 63.72877813875675, 62.61173687875271, 64.16059836745262, 59.57295633852482, 57.5105220079422, 43.94129432737827, 50.75814753770828, 60.489710345864296, 63.020701333880424, 54.60418336093426, 57.02705875039101, 51.990748196840286, 53.150206580758095, 58.33535134792328, 58.063301146030426, 52.15910196304321, 44.006400033831596, 42.81404301524162, 42.374437004327774, 42.814062014222145, 43.05724136531353, 40.8573380112648, 42.57073067128658, 44.84515182673931, 48.75432126224041, 49.63857181370258, 49.03205215930939, 47.051199451088905, 46.41120359301567, 46.437319591641426, 48.76401074230671, 47.6188699901104, 47.843597531318665, 42.191469222307205, 44.47154067456722, 44.976989552378654, 52.10242040455341, 54.60338540375233, 55.4986971616745, 54.62015390396118, 56.09265089035034, 50.934078097343445, 56.69406361877918, 54.626415967941284, 63.00692707300186, 38.60984221100807, 29.644341096282005, 60.693747997283936, 56.49981804192066, 60.306130796670914, 56.7475001513958, 57.376632392406464, 55.6966133415699, 58.01766939461231, 56.12503655254841, 59.2933065444231, 51.92805156111717, 44.9513903260231, 42.00029008090496, 45.96470855176449, 49.18005421757698, 52.85613276064396, 48.72307553887367, 46.47696666419506, 44.09680478274822, 42.38985277712345, 43.256840854883194, 43.05866628885269, 46.0545015335083, 50.01612335443497, 49.99793753027916, 46.389537155628204, 43.161519169807434, 43.401248306035995, 41.44561484456062, 48.67565408349037, 57.175254598259926, 59.15519155561924, 61.463267505168915, 58.85010972619057, 58.58033560216427, 57.47241385281086, 56.033005490899086, 51.03333257138729, 50.72640784084797, 51.676535457372665, 57.519728913903236, 59.10671755671501, 61.07464715838432, 59.30226266384125, 54.45657268166542, 50.173142328858376, 47.215867415070534, 27.44386587291956, 14.817943274974823, 11.816724669188261, 16.520559713244438, 18.82984209805727, 9.55684058368206, 2.4790665367618203, 0.23322617111261934, 0.20157566556008533, 0.30427431338466704, 15.44210348278284, 53.76828521490097, 44.748006239533424, 24.471013695001602, 35.43308347463608, 54.24987517297268, 62.44861923158169, 59.65293824672699, 40.387086644768715, 7.647938439622521, 0.1585246139438823, 0.12824973848182708, 0.14558151393430308, 0.08287018368719146, 0.14405574736883864, 0.23856038722442463, 0.16226802166784182, 0.24534640746423975, 0.17894361983053386, 0.16180600505322218, 0.10342011184548028, 0.13263534143334255, 0.10711203678511083, 0.19543895032256842, 0.08272950959508307, 0.07844659761758521, 0.1572621613740921, 0.06522258729091845, 0.1870068910648115, 0.16785639367299154, 0.07497325743315741], [0.07254257536260411, 0.019870302712661214, 0.03492206320515834, 0.025580398068996146, 0.01818586311856052, 0.09397970396094024, 0.013126396570442012, 0.03590224732761271, 0.0401612732821377, 0.0232731778305606, 0.03547891516063828, 0.05960072587186005, 0.016118659004860092, 0.014997689468145836, 0.04383950188639574, 0.03766303721931763, 0.058023331803269684, 0.05783013592008501, 0.024311845045303926, 0.041998960805358365, 8.483637571334839, 50.95992051064968, 52.446545138955116, 44.843225330114365, 26.352290846407413, 10.953684579581022, 29.581709057092667, 46.38069123029709, 35.18735446035862, 9.851548969745636, 0.11286073495284654, 0.07961691997479647, 0.1458606802043505, 0.5100629583466798, 5.983193619176745, 9.502935726195574, 5.356734059751034, 6.018877979367971, 23.753395602107048, 50.59132128953934, 60.20334251224995, 56.960873901844025, 55.500220879912376, 54.36643771827221, 52.025596126914024, 48.451868891716, 44.36860799789429, 40.00611148774624, 45.17020158469677, 56.611513048410416, 54.254115745425224, 54.95566450059414, 53.6286237090826, 52.569289952516556, 53.288070783019066, 54.040464609861374, 51.384053751826286, 49.99678999185562, 44.118672609329224, 41.936879083514214, 41.23683124780655, 38.48292902112007, 38.8889866322279, 39.43930350244045, 44.41845752298832, 46.500722989439964, 49.57508862018585, 50.20174339413643, 51.540035381913185, 48.38678978383541, 47.072569504380226, 40.40813751518726, 42.54965700209141, 42.261681854724884, 41.95442274212837, 38.60521785914898, 39.719637259840965, 46.08586125075817, 56.61183603107929, 54.666728004813194, 56.85500018298626, 51.419999822974205, 55.85281156003475, 50.5792835354805, 56.54858082532883, 49.29228499531746, 60.28641365468502, 29.59073167294264, 25.27430009096861, 56.29457965493202, 44.51685704290867, 51.40247516334057, 50.24560064077377, 53.2538840174675, 50.01421585679054, 55.381857231259346, 52.712648659944534, 54.95729461312294, 46.48116923868656, 40.142546966671944, 39.044204503297806, 40.4831150919199, 43.708454221487045, 45.11039279401302, 45.51352836191654, 43.31548310816288, 42.26488508284092, 39.71528649330139, 38.16350296139717, 39.09386783838272, 37.908335253596306, 39.77867469191551, 36.36569403111935, 38.056892082095146, 37.38140992820263, 38.43979753553867, 37.3979352414608, 39.364675506949425, 43.621647879481316, 46.05107791721821, 47.91742756962776, 50.10592773556709, 50.49587421119213, 47.979694828391075, 46.02899730205536, 44.80102859437466, 43.879992216825485, 48.86377438902855, 54.05317112803459, 56.840066984295845, 55.79899124801159, 51.494422629475594, 47.90316313505173, 52.40286648273468, 45.84162935614586, 30.93670304864645, 11.944332271814346, 4.98846304602921, 12.572377771139145, 27.162954546511173, 5.998629815876484, 1.5507577056996524, 0.0695161490875762, 0.09488312774919905, 0.07048965388094075, 4.317655116319656, 28.3691219240427, 33.11418950557709, 27.700990475714207, 24.224490523338318, 33.39674234390259, 43.639449924230576, 46.93151347339153, 34.318306893110275, 13.005937356501818, 0.2554090245394036, 0.03651696824817918, 0.06827921897638589, 0.023715969109616708, 0.01781678009137977, 0.05388809608120937, 0.048671076219761744, 0.03011950870131841, 0.013445223212329438, 0.01356960623525083, 0.004553025437417091, 0.019842782021441963, 0.02070305734378053, 0.08862976916134357, 0.0367463623842923, 0.06517146073747426, 0.03836250398308039, 0.04897250320937019, 0.029690721748920623, 0.03295653332315851, 0.012412716750986874, 0.09475596074480563, 0.038941141683608294, 0.03384955220099073, 0.009695933040347882, 0.06417124604922719, 0.05457583691168111, 0.031750413472764194, 0.026114441971003544, 0.027996374483336695, 0.014936680290702498, 0.056036086680251174, 0.012208140033180825, 0.051853750555892475, 0.0610678405064391, 0.05741766137361992, 0.05123601280502044, 0.05002087586035486, 0.09983654046664014, 0.02708462008740753, 0.007038593503239099, 13.269787598401308, 60.47577269375324, 57.928377985954285, 51.81733690202236, 31.95845492184162, 18.451971374452114, 26.82926595211029, 42.30917550623417, 41.80401161313057, 11.643262077122927, 0.15673955582315102, 0.0908465642714873, 0.2542826521676034, 1.6852995799854398, 5.716404234990478, 8.853337783366442, 7.886015614494681, 5.5141515377908945, 27.39611953496933, 51.9269610196352, 61.828519105911255, 59.34122197329998, 59.18286167085171, 55.86610324680805, 55.53858362138271, 51.67802877724171, 47.052810564637184, 42.60707952082157, 48.3191192150116, 58.25759992003441, 58.25192302465439, 56.895608603954315, 53.002782091498375, 52.1510273963213, 54.02240797877312, 55.27129456400871, 52.3888186365366, 50.82434378564358, 46.28992550075054, 43.74919183552265, 42.37217992544174, 40.28392218053341, 41.115849539637566, 41.53072267770767, 46.31756141781807, 49.23457369208336, 51.27050444483757, 52.42117390036583, 53.52935403585434, 50.558810234069824, 48.189470171928406, 43.07532839477062, 44.916869178414345, 44.95050497353077, 44.39481899142265, 39.798118248581886, 41.52678608894348, 48.3058275282383, 58.480655550956726, 55.86061634123325, 59.432063698768616, 53.64642575383186, 58.16156007349491, 52.41100184619427, 58.13697159290314, 51.02908059954643, 60.55422708392143, 31.525684744119644, 24.97524283826351, 57.19914011657238, 45.756612718105316, 52.480724304914474, 51.02393187582493, 53.22465218603611, 50.149294808506966, 56.32508061826229, 54.76385459303856, 55.36290384829044, 48.937372639775276, 42.24888414144516, 41.026751920580864, 42.174309343099594, 46.199125573039055, 47.65958100557327, 47.50143729150295, 45.12411005795002, 43.734676614403725, 41.38447232544422, 39.74174067378044, 40.15170447528362, 38.987427949905396, 39.958549439907074, 39.11664001643658, 39.61448170244694, 39.46225427091122, 40.14188580214977, 40.06204828619957, 42.604442462325096, 44.964993596076965, 48.96058179438114, 50.59519328176975, 52.30205789208412, 53.07639554142952, 50.659945607185364, 48.34703251719475, 47.73764781653881, 46.09573312103748, 49.687194004654884, 55.64109452068806, 57.80074283480644, 59.44020666182041, 53.894465044140816, 50.08496046066284, 51.56387910246849, 47.272370383143425, 31.14570513367653, 14.312071669846773, 5.860992651432753, 3.719523986801505, 12.947607636451721, 9.188893977552652, 3.9987434539943933, 0.578463562997058, 0.017402882476744708, 0.03497879297356121, 4.599236156791449, 33.896259739995, 35.359394028782845, 33.661591932177544, 32.667189091444016, 39.92386870086193, 51.233840212225914, 53.3431526273489, 40.30180022120476, 14.67902747914195, 0.23594645404955372, 0.007799923841957934, 0.05587330771959387, 0.043965251388726756, 0.027109172187920194, 0.02585676087619504, 0.09342854798887856, 0.05581093020737171, 0.013612006987386849, 0.049954067726503126, 0.037889633458689786, 0.05270797366392799, 0.012757939730363432, 0.011280185481155058, 0.02010408108617412, 0.06759233903721906, 0.027044826128985733, 0.01630302518606186, 0.02189921200624667, 0.051723214201047085, 0.02065402179141529, 0.1676663148100488, 0.0783976678212639, 0.06757488372386433, 0.07177477906225249, 0.11342165016685612, 0.17338603211101145, 0.10925946335191838, 0.14296805573394522, 0.09124349453486502, 0.1219382623094134, 0.22782226733397692, 0.08632669938378967, 0.19526269024936482, 0.1121743003022857, 0.1530155329965055, 0.11107532802270725, 0.12789766362402588, 0.2014578421949409, 0.15657902928069234, 0.13238639541668817, 17.71004408597946, 71.04025840759277, 66.16170778870583, 58.982012048363686, 39.34374243021011, 21.430734135210514, 41.410269141197205, 60.1178926974535, 49.96378116309643, 15.077272709459066, 0.36647721310146153, 0.35651901620440185, 0.3544590814271942, 1.722004422917962, 12.811189256608486, 16.77909594029188, 16.031871736049652, 9.751713126897812, 25.22648725658655, 54.69727076590061, 63.3883848041296, 61.308794394135475, 61.35056175291538, 57.964909225702286, 57.08842545747757, 53.88423219323158, 49.937178790569305, 45.324328914284706, 50.18258862197399, 62.105429247021675, 60.21548666059971, 58.4174345433712, 54.10286106169224, 53.09457756578922, 53.95574055612087, 58.30912135541439, 53.79268750548363, 54.636261239647865, 47.24055469036102, 46.347192227840424, 46.00283570587635, 42.54468306899071, 43.68001274764538, 43.63028101623058, 49.08005118370056, 51.767810359597206, 53.96532744169235, 55.6717436760664, 55.44975958764553, 52.51903384923935, 51.40416607260704, 45.36366060376167, 47.299820110201836, 46.82282790541649, 46.23327054083347, 41.54816374182701, 44.50111448764801, 51.54681421816349, 59.62559871375561, 58.92564207315445, 61.15786649286747, 56.01456128060818, 60.16876816749573, 54.754624888300896, 61.32208228111267, 53.96343894302845, 62.47359149158001, 33.57570894062519, 27.96363428235054, 56.87690980732441, 45.55814176797867, 53.474142998456955, 51.913980916142464, 54.30927738547325, 52.32632339000702, 57.92018182575703, 57.5388190895319, 57.85816915333271, 50.81586264073849, 43.87426592409611, 44.59362432360649, 44.12055350840092, 48.60029652714729, 50.77144682407379, 50.589535385370255, 47.0216104388237, 45.85458666086197, 43.40692900121212, 42.28960655629635, 43.296947702765465, 40.91473773121834, 44.03823472559452, 40.173857286572456, 40.5972495675087, 40.676361322402954, 42.372062131762505, 42.087768986821175, 44.584280624985695, 46.90450832247734, 51.036680191755295, 54.222714230418205, 55.21025463938713, 55.4936396330595, 52.131002470850945, 51.457378417253494, 50.331320241093636, 49.274513348937035, 52.33442835509777, 58.922568038105965, 61.089295372366905, 60.05089469254017, 55.15412785112858, 53.86969417333603, 51.80610850453377, 47.24840886890888, 33.51249173283577, 14.118032231926918, 10.577358473092318, 26.193567663431168, 41.792483031749725, 16.183439902961254, 4.088438590988517, 0.7869294018018991, 0.2782046247739345, 0.11133590349345468, 5.8812887873500586, 40.801405012607574, 43.173028752207756, 39.70690034329891, 34.26107056438923, 45.9571735560894, 57.455979734659195, 61.90521039068699, 51.743799448013306, 17.75050051510334, 0.4487151018111035, 0.09512545380857773, 0.2297217646264471, 0.12785406986949965, 0.12296747270738706, 0.134153003746178, 0.16573931352468207, 0.17981784010771662, 0.09543446183670312, 0.13040944759268314, 0.16737996455049142, 0.1401916961185634, 0.16893178049940616, 0.13500403932994232, 0.13902152219088748, 0.13921949750510976, 0.11234386620344594, 0.1228107904898934, 0.10394627970526926, 0.2223394435713999, 0.11434206171543337], [0.038917010751902126, 0.04968140638084151, 0.034267481532879174, 0.0592072540166555, 0.02004300604312448, 0.07534347780165263, 0.031144917447818443, 0.04384362080600113, 0.04689292378316168, 0.034750738414004445, 0.09146446158410981, 0.0710801214154344, 0.024329769767064136, 0.04436130591784604, 0.02820632806106005, 0.04860144792473875, 0.006484735649792128, 0.03368380836036522, 0.08015367086045444, 0.09369445950142108, 17.936962209641933, 53.87667819857597, 47.506969794631004, 37.30417527258396, 27.98955649137497, 22.104128301143646, 33.84637601673603, 33.02048273384571, 27.7688567340374, 3.712825896218419, 0.05146174073161092, 0.0418087520665722, 0.10499025142053142, 0.9704618097748607, 3.2974006002768874, 8.031953908503056, 5.37071730941534, 12.739579249173403, 43.71950022876263, 60.614693239331245, 59.13978338241577, 56.893431320786476, 52.48478248715401, 48.9871309697628, 44.58736605942249, 42.082795053720474, 41.42946571111679, 43.12391258776188, 43.406222239136696, 51.97720192372799, 55.65010383725166, 57.199949473142624, 53.40351998806, 55.6653106212616, 54.011825546622276, 52.84169353544712, 52.53407344222069, 50.26928097009659, 50.14394469559193, 49.45494286715984, 47.486819475889206, 40.93328453600407, 39.592226296663284, 41.587073653936386, 46.401928290724754, 50.74010230600834, 54.234873577952385, 52.45318718254566, 56.879676058888435, 52.058585956692696, 49.47326548397541, 42.407795414328575, 43.321319594979286, 41.356752812862396, 42.34072521328926, 38.48189927637577, 42.53306709229946, 48.57657440006733, 52.43120916187763, 50.24436950683594, 46.86279036104679, 52.11233027279377, 56.932542622089386, 51.0173924267292, 56.762342154979706, 50.27612440288067, 59.34721425175667, 25.458257719874382, 26.68127529323101, 54.11212116479874, 46.19384005665779, 55.12504041194916, 48.44124846160412, 52.9681621491909, 53.441453352570534, 56.504142209887505, 51.27399645745754, 51.82932525873184, 42.57709912955761, 41.02921038866043, 39.50731225311756, 40.99598877131939, 43.82100038230419, 47.82401718199253, 47.121172696352005, 48.176881447434425, 45.16089968383312, 43.48514020442963, 37.91177026927471, 38.264410346746445, 37.14735768735409, 38.089828714728355, 36.70901320874691, 40.19492715597153, 39.07169982790947, 38.30998510122299, 36.97619587182999, 38.780422657728195, 39.22929637134075, 39.91831719875336, 38.921604081988335, 40.29604732990265, 39.41225275397301, 41.285278648138046, 40.90080767869949, 42.237670943140984, 45.948840603232384, 53.806036189198494, 53.394719660282135, 55.908330380916595, 52.77211546897888, 48.48803535103798, 51.641402542591095, 51.549519672989845, 48.70046675205231, 36.42766110599041, 21.559157744050026, 2.122380626387894, 2.5172794237732887, 10.674360617995262, 5.224071778357029, 3.834822387434542, 0.22466908965725452, 0.057638298167148605, 0.02024241184699349, 0.5862159782554954, 18.915271013975143, 39.367084577679634, 20.838875994086266, 11.985303573310375, 29.08251654356718, 43.30862067639828, 48.013676404953, 34.492512345314026, 20.75595684349537, 1.7523935297504067, 0.06524425800307654, 0.0363315203867387, 0.02791405360767385, 0.054269545144052245, 0.03813531402556691, 0.008770264303166186, 0.027097501915704925, 0.03497173143841792, 0.012569361861096695, 0.06577386942808516, 0.053666401727241464, 0.06364055108861066, 0.03254198447393719, 0.011562027193576796, 0.07339940711972304, 0.037159267376409844, 0.006443007005145773, 0.021234885934973136, 0.02930220744019607, 0.102781137538841, 0.03620284311182331, 0.03571869936422445, 0.014775414383620955, 0.020296660986787174, 0.008380233230127487, 0.09705743490485474, 0.10962049593217671, 0.08197321658371948, 0.03132655438093934, 0.03165850961522665, 0.02579947264166549, 0.02210155114880763, 0.04086363442183938, 0.04833197781408671, 0.031117621256271377, 0.03177616228640545, 0.011201261786482064, 0.025534034248266835, 0.06397172706783749, 0.08773265362833627, 23.99222418665886, 61.86677925288677, 54.38377618789673, 45.282652750611305, 33.66767920553684, 22.650991156697273, 36.07054106891155, 38.118049800395966, 31.887809112668037, 5.008734008297324, 0.04511259314313065, 0.07289634973858483, 0.6615335179958493, 2.2077838936820626, 6.324364012107253, 7.084933100268245, 4.142550062388182, 12.295897956937551, 42.38039888441563, 60.676185339689255, 61.27149939537048, 59.46603387594223, 54.931410402059555, 52.22416967153549, 47.538200318813324, 44.06958304345608, 43.40608164668083, 44.0955850481987, 46.114549711346626, 55.00981159508228, 56.844003573060036, 57.87092126905918, 53.60444940626621, 54.57508832216263, 54.419444873929024, 54.80952434241772, 54.678571969270706, 53.34717281162739, 52.450052350759506, 51.367323249578476, 48.909596130251884, 41.37715011835098, 40.76762102544308, 43.60303647816181, 49.05520811676979, 53.27616982161999, 55.081772133708, 54.27653834223747, 56.7950090020895, 53.729683086276054, 52.506407126784325, 44.39334847033024, 43.63713584840298, 42.351714223623276, 43.408289328217506, 41.403254717588425, 44.67556692659855, 50.17342731356621, 55.5685830116272, 50.527914091944695, 50.45302011072636, 53.28137554228306, 58.627616465091705, 52.72470161318779, 60.03020100295544, 51.974127888679504, 59.83657479286194, 25.514785386621952, 27.807878740131855, 55.40026344358921, 45.98936542868614, 54.674266800284386, 49.84985567629337, 54.3766363710165, 53.75685162842274, 56.47188574075699, 53.41442160308361, 54.596728160977364, 45.310265868902206, 43.301663249731064, 41.09322555363178, 42.2291973978281, 46.38180077075958, 50.195523127913475, 48.18710669875145, 50.847606137394905, 46.92261815071106, 45.003143548965454, 39.931950867176056, 40.22699363529682, 40.306599363684654, 38.58982868492603, 38.17210949957371, 40.77816925942898, 41.43138460814953, 39.80849929153919, 38.71142216026783, 41.93286269903183, 41.10932528972626, 41.48149631917477, 41.44817590713501, 43.290062472224236, 40.6821446120739, 43.7041262537241, 42.901605516672134, 44.44926626980305, 47.37963102757931, 55.48044294118881, 55.17430856823921, 58.18325310945511, 52.86633901298046, 50.40020294487476, 52.55922809243202, 50.776063576340675, 49.13997396826744, 37.99635753035545, 19.304755814373493, 5.722926110029221, 5.557716200128198, 10.493985246866941, 9.559101462364197, 6.5397863276302814, 0.9194256796035916, 0.07571810652734712, 0.06330669595627114, 0.5011605110485107, 20.82577809691429, 40.76120316982269, 25.575912706553936, 18.254157789051533, 36.50991149246693, 49.48764391243458, 55.076672807335854, 43.207834884524345, 24.83512345701456, 2.333862315863371, 0.04077209421666339, 0.05576697651122231, 0.03083693729422521, 0.05513874479220249, 0.06911852120538242, 0.024312242094310932, 0.04781952113262378, 0.004761999380207271, 0.012726416080113268, 0.009722908253024798, 0.055475831977673806, 0.027618877356871963, 0.07171044228016399, 0.03510945549351163, 0.044315478298813105, 0.026686097917263396, 0.004476616695683333, 0.03276401650509797, 0.04178354130999651, 0.017555850245116744, 0.10387309652287513, 0.17804134637117386, 0.15182821545749903, 0.12560880597447976, 0.1149794775119517, 0.15249656396918, 0.2345690576476045, 0.1383610998163931, 0.1352574085467495, 0.07995890162419528, 0.16963783011306077, 0.2502791810547933, 0.1008767049643211, 0.12512615765444934, 0.10822692813235335, 0.12817567214369774, 0.07426313342875801, 0.1408396800979972, 0.1554486938402988, 0.29154642135836184, 31.47345084697008, 71.57380297780037, 60.886002480983734, 51.45879194140434, 40.127746760845184, 32.412317767739296, 48.197597935795784, 45.49888774752617, 39.64331455528736, 5.663576619699597, 0.19463612465187907, 0.20161002699751407, 0.8508020744193345, 3.0219989782199264, 11.868281252682209, 16.610003113746643, 11.00629560649395, 13.965585362166166, 47.63633385300636, 63.89948397874832, 62.80135050415993, 63.95994633436203, 57.28545628488064, 54.610988795757294, 50.09497672319412, 46.542528346180916, 45.62910296022892, 46.58690236508846, 48.01073916256428, 56.713058799505234, 59.790806248784065, 60.057441741228104, 54.37640838325024, 55.31556598842144, 54.20359745621681, 55.56682750582695, 56.57765306532383, 55.552958250045776, 55.52214950323105, 55.3373996168375, 51.22840270400047, 46.03922635316849, 42.787402644753456, 46.5085543692112, 50.86271792650223, 56.0289891064167, 57.11275175213814, 56.229067370295525, 59.98646914958954, 55.758633613586426, 53.87006275355816, 47.56384514272213, 46.812602654099464, 44.977111145853996, 46.29107303917408, 42.53329508006573, 46.37235827744007, 53.564817532896996, 57.605437114834785, 54.874162673950195, 52.51383192837238, 54.24188420176506, 60.041501596570015, 53.153474405407906, 61.06009393930435, 53.07633854448795, 59.860521107912064, 27.485179156064987, 31.92526750266552, 54.728075712919235, 48.30335006117821, 54.861334562301636, 51.42759181559086, 54.63447533547878, 56.26882843673229, 59.04258459806442, 56.12283647060394, 57.500897124409676, 46.89176380634308, 45.42584806680679, 43.90458069741726, 44.773613065481186, 48.73143509030342, 51.82317338883877, 52.8739158064127, 53.07036526501179, 50.21551005542278, 47.06728018820286, 40.946215242147446, 42.390928119421005, 41.35293401777744, 40.52092686295509, 40.84026172757149, 45.17365179955959, 44.773210287094116, 42.47453883290291, 40.6873769313097, 44.167234003543854, 43.78759637475014, 42.811816334724426, 41.76182247698307, 44.391775354743004, 43.3201302587986, 46.81107133626938, 44.99508038163185, 46.57802604138851, 48.86308662593365, 58.433009907603264, 58.31272356212139, 59.981054440140724, 53.84198226034641, 51.220514327287674, 51.677075028419495, 51.175957918167114, 50.804387256503105, 38.699464201927185, 25.15153057873249, 5.637198435142636, 13.543531559407711, 22.035251297056675, 10.742820594459772, 7.300533531233668, 0.9580580878537148, 0.20413785619894043, 0.21878604049561545, 1.1552630527876318, 27.305990271270275, 52.21364043653011, 29.076149985194206, 20.54938092827797, 41.28297597169876, 55.53580977022648, 63.57518658041954, 53.90403673052788, 32.42095850408077, 2.997214333154261, 0.1817659183871001, 0.11626452847849578, 0.11566308457986452, 0.14722925989190117, 0.18724946945440024, 0.07756275168503635, 0.17935769370524213, 0.16748273716075346, 0.15151284722378477, 0.10660170635674149, 0.154218643438071, 0.18950343132019043, 0.14706763497088104, 0.11081050746724941, 0.13584369036834687, 0.10963071530568413, 0.10524862271267921, 0.16884695301996544, 0.20965412113582715, 0.15468008117750287], [0.053156019348534755, 0.07461842178599909, 0.036576655475073494, 0.04621353953552898, 0.11983396194409579, 0.023229897633427754, 0.10942951164906844, 0.0395569609827362, 0.03917040965461638, 0.05823831343150232, 0.03219849997549318, 0.01627387919143075, 0.026026588384411298, 0.03896854548656847, 0.045581782615045086, 0.03307005965325516, 0.014322207989607705, 0.048765670362627134, 0.02335353387024952, 1.1136044631712139, 30.84610641002655, 51.25618301331997, 52.57407009601593, 35.02712085843086, 19.720286317169666, 19.93038274347782, 24.036400616168976, 37.142303958535194, 22.882144153118134, 0.48632803664077073, 0.07589285261929035, 0.0397552183130756, 0.6322295498102903, 2.4809265369549394, 3.702867105603218, 5.85549577139318, 8.630115911364555, 23.076623417437077, 48.84914517402649, 58.348912820219994, 55.71814678609371, 49.29801128804684, 45.92189244925976, 46.73101343214512, 45.02512916922569, 46.96447670459747, 46.46592825651169, 41.994521990418434, 42.014193534851074, 46.98261693120003, 52.29513466358185, 57.53141328692436, 52.93474294245243, 53.51544298231602, 51.79441653192043, 50.27429290115833, 54.20360125601292, 52.41472564637661, 55.135140269994736, 53.255149349570274, 50.52521623671055, 46.97246767580509, 41.61155194044113, 42.878479957580566, 50.280931144952774, 50.87277598679066, 52.565611749887466, 51.87835022807121, 53.24723817408085, 54.100037813186646, 48.7533713132143, 45.75416564941406, 44.345786422491074, 39.54575479030609, 40.151647478342056, 40.58754488825798, 42.75157816708088, 50.15078812837601, 52.971593365073204, 45.216665491461754, 52.52719581127167, 48.446047604084015, 52.16540962457657, 50.76158635318279, 55.69511242210865, 45.02948373556137, 54.36566635966301, 25.014443434774876, 30.086435973644257, 56.207818910479546, 49.78878155350685, 58.05282510817051, 50.58326192200184, 53.88405740261078, 52.25862242281437, 53.7685663998127, 47.44763217866421, 44.3471809476614, 41.44615061581135, 42.766496166586876, 39.15203131735325, 40.4816597700119, 42.04829290509224, 48.475974798202515, 47.392318546772, 50.010393261909485, 49.02714282274246, 46.82597793638706, 40.97609683871269, 38.49191553890705, 37.024343088269234, 40.40666699409485, 44.961759969592094, 45.33810697495937, 42.76809208095074, 40.70976532995701, 38.534347862005234, 38.0038583278656, 41.727818101644516, 43.09836655855179, 49.183823615312576, 46.264493465423584, 48.60425591468811, 48.15385088324547, 49.11607705056667, 48.350999504327774, 51.07193849980831, 52.86198824644089, 54.947969913482666, 51.800412610173225, 54.567469730973244, 52.288238033652306, 48.00600841641426, 51.39230690896511, 51.144719794392586, 41.7344905436039, 29.702859856188297, 11.674709189683199, 1.2221581069752574, 7.680126037448645, 10.864353273063898, 6.020850548520684, 0.7259103760588914, 0.1323260588105768, 0.014958323172322707, 0.03225445048883557, 9.141197986900806, 45.91272734105587, 40.416808649897575, 16.925680674612522, 23.81514608860016, 39.526182040572166, 52.55860112607479, 48.41185323894024, 26.76506269723177, 5.458961399272084, 0.09837252058787271, 0.03778591089940164, 0.09915878894389607, 0.060472211334854364, 0.028115875102230348, 0.03166155984217767, 0.04592500365106389, 0.022507400171889458, 0.02279261123476317, 0.056081635993905365, 0.04449661799299065, 0.044220965792192146, 0.037116085513844155, 0.05539867459447123, 0.03984738934377674, 0.01577323750098003, 0.01760579863912426, 0.11015102762030438, 0.0290541464346461, 0.07399249443551525, 0.02776588011329295, 0.01597547274286626, 0.06675591634120792, 0.03711090161232278, 0.07910782893304713, 0.015354346160165733, 0.04786655103089288, 0.023245677548402455, 0.04424703372933436, 0.016046592754719313, 0.008573100712965243, 0.028239400016900618, 0.02255789775517769, 0.1308133392012678, 0.020110194527660497, 0.027442867758509237, 0.02521406098821899, 0.0754931393021252, 0.08839289788738824, 1.7912906175479293, 38.46135377883911, 58.89424055814743, 59.1008734703064, 40.255723893642426, 29.110743328928947, 23.572483509778976, 25.734563693404198, 39.21410858631134, 26.281016170978546, 0.9557881252840161, 0.1718373628682457, 0.12602952949237078, 1.4626690512523055, 6.031708940863609, 6.2792176846414804, 5.645030764862895, 4.715935969725251, 23.6753211915493, 52.09870420396328, 59.51311714947224, 58.08958053588867, 54.02248777449131, 49.438858330249786, 48.43234933912754, 47.862661108374596, 49.58877168595791, 49.242142885923386, 45.005716010928154, 44.232225716114044, 50.177797079086304, 54.67946112155914, 59.674209505319595, 53.52305017411709, 52.93337881565094, 54.607766568660736, 49.85998213291168, 55.73373354971409, 54.921489134430885, 56.09997309744358, 55.138955265283585, 53.130671828985214, 49.32778649032116, 43.770273104310036, 44.584751799702644, 51.19130529463291, 52.50665031373501, 54.042197316884995, 53.506969437003136, 56.19515419006348, 55.38631819188595, 52.358378469944, 47.52563439309597, 45.882777348160744, 42.217562422156334, 42.30599507689476, 41.28270998597145, 44.27722670137882, 51.251763850450516, 56.1627571284771, 49.14318099617958, 54.07452218234539, 48.4280289709568, 52.16156043112278, 50.731651559472084, 55.53835563361645, 45.59642471373081, 54.661780670285225, 25.630177594721317, 31.268301755189896, 55.04019096493721, 52.06254534423351, 59.234105721116066, 52.60618597269058, 56.31208911538124, 55.20867012441158, 55.02871558070183, 50.66251426935196, 46.410067453980446, 42.93128952383995, 43.28899472951889, 41.45462416112423, 41.79627142846584, 44.36543896794319, 49.516256377100945, 50.48883318901062, 51.73339940607548, 50.30475586652756, 47.35470436513424, 43.347986564040184, 39.67985339462757, 37.93519601225853, 40.964051485061646, 46.95575997233391, 47.460475489497185, 43.598966896533966, 43.006943464279175, 41.10041096806526, 40.068587735295296, 43.80906522274017, 45.557024627923965, 49.07023251056671, 48.970677852630615, 50.20775847136974, 49.755761325359344, 51.491876766085625, 51.078185364603996, 53.10552477836609, 54.537998512387276, 57.00703762471676, 52.92474187910557, 53.54253552854061, 50.91698661446571, 49.91816461086273, 52.282659932971, 52.620970979332924, 42.272237688302994, 29.62885122746229, 11.695983298122883, 6.348273754119873, 10.834734812378883, 8.82884619757533, 9.489518646150827, 3.166637741960585, 0.3273032745346427, 0.0486150032520527, 0.15052169415866956, 10.866716746240854, 44.29893493652344, 29.761788994073868, 19.073148742318153, 30.56977193802595, 44.172302931547165, 57.457917630672455, 56.499324068427086, 34.26519334316254, 7.020579278469086, 0.053672817593906075, 0.03424367343541235, 0.12181869489722885, 0.03534718394803349, 0.03143150148389395, 0.04465379744942766, 0.04487777019676287, 0.06326066053588875, 0.007053581639411277, 0.04650104012398515, 0.03132555619231425, 0.04870530407060869, 0.06173606285301503, 0.022824380721431226, 0.058238283745595254, 0.021954262665531132, 0.03870926135277841, 0.0802777282660827, 0.017805004063120577, 0.017077771699405275, 0.07088354876032099, 0.13133495027432218, 0.12734915711916983, 0.13145350094418973, 0.22127550066215917, 0.10857801593374461, 0.19803839677479118, 0.10165092084207572, 0.24898931354982778, 0.0791547326662112, 0.1768434458062984, 0.09740587323904037, 0.10680326624424197, 0.24695158383110538, 0.1473300435463898, 0.14354602550156415, 0.14734922064235434, 0.1969755522441119, 0.1984625490149483, 2.959270994178951, 48.131287693977356, 68.57361316680908, 66.47517576813698, 46.33930005133152, 29.9648766964674, 30.401933044195175, 35.617156997323036, 48.81402745842934, 32.31331408023834, 1.3244658359326422, 0.3139217878924683, 0.1855418915511109, 1.2869798974134028, 7.617844054475427, 13.738421201705933, 14.150127209722996, 13.185073044151068, 25.227596797049046, 52.20585845410824, 61.28755733370781, 61.187413707375526, 54.982380867004395, 51.597883477807045, 51.577603965997696, 50.375439673662186, 51.94832727313042, 51.48366540670395, 47.02499605715275, 46.01247578859329, 51.84636354446411, 57.18134567141533, 62.134892866015434, 53.1620429456234, 53.15302602946758, 53.479622304439545, 51.050975024700165, 57.32296787202358, 56.94100096821785, 59.04554083943367, 57.70438000559807, 54.68735329806805, 51.54283583164215, 45.88971957564354, 46.237594708800316, 54.48368042707443, 55.297938734292984, 56.442916095256805, 54.76768098771572, 57.65977419912815, 58.83050657808781, 54.22975905239582, 50.261346995830536, 48.62247973680496, 44.69914086163044, 43.81921827793121, 44.303194507956505, 47.53403194248676, 54.525341391563416, 56.70918680727482, 52.51811809837818, 54.961937963962555, 50.79342104494572, 53.969712406396866, 52.79041528701782, 55.95243461430073, 45.64484551548958, 52.7412611246109, 28.6874308437109, 33.44708204269409, 56.620936542749405, 53.62392716109753, 61.183055341243744, 54.50628541409969, 58.698182478547096, 56.99355214834213, 57.26076140999794, 52.851326018571854, 48.8760781288147, 46.80984400212765, 46.494540721178055, 43.02522048354149, 43.50708022713661, 45.79552263021469, 54.37245659530163, 53.05990822613239, 54.33074243366718, 51.478277295827866, 50.121442303061485, 44.05398488044739, 42.21292667090893, 40.40983222424984, 43.458857014775276, 49.27289083600044, 49.84454736113548, 46.691639944911, 45.9371904283762, 43.04792806506157, 41.966259106993675, 46.38623893260956, 47.22459174692631, 52.29687497019768, 52.57769510149956, 52.423734962940216, 53.30806910991669, 54.01675008237362, 53.54369826614857, 55.87459199130535, 56.734618842601776, 59.10870485007763, 54.94746074080467, 55.046608820557594, 51.77110858261585, 51.688565611839294, 52.344748601317406, 50.75908608734608, 44.58247572183609, 32.03101582825184, 15.487297307699919, 3.7233613058924675, 13.880610521882772, 18.925811648368835, 15.623938925564289, 3.7671439815312624, 0.5023918824736029, 0.2414672906161286, 0.21151388384168968, 13.876559939235449, 57.678359001874924, 50.793968215584755, 27.84128464758396, 33.722107484936714, 54.70982909202576, 63.04414987564087, 66.1956399679184, 42.73252598941326, 9.780209697782993, 0.21275045030051842, 0.09776285369298421, 0.20971217192709446, 0.12288669735426083, 0.09140390233369544, 0.19181059033144265, 0.16187386703677475, 0.13550583506003022, 0.10619748078170232, 0.18749387352727354, 0.11176479805726558, 0.10859593137865886, 0.14496274088742211, 0.15899975172942504, 0.14417165599297732, 0.12823670636862516, 0.09660241674282588, 0.12342765621724539, 0.13563660148065537, 0.1083404989913106], [0.06791542560677044, 0.044738773358403705, 0.007139634590203059, 0.0528296302218223, 0.04113799528568052, 0.011869681729876902, 0.07867612162954174, 0.01391882382449694, 0.008818782207526965, 0.024582029473094735, 0.027077766353613697, 0.04571812256472185, 0.017091115514631383, 0.034115393209503964, 0.036611818431993015, 0.05091118218842894, 0.010716451033658814, 0.06293275742791593, 0.05624025892757345, 4.329910883679986, 40.141243636608124, 53.6896788328886, 46.55924744904041, 25.913887470960617, 17.490505166351795, 24.093306362628937, 37.55329750478268, 39.48355212807655, 13.55033129453659, 0.09934947636793368, 0.06679582904325798, 0.11405676530557685, 1.7331086145713925, 2.7046385826542974, 3.8054003287106752, 3.0843783309683204, 5.676449853926897, 29.345069155097008, 56.96525886654854, 58.74631069600582, 53.57748985290527, 48.816744312644005, 50.678101032972336, 51.95948727428913, 54.38271224498749, 53.29197317361832, 53.39377351105213, 49.973109662532806, 45.63911162316799, 46.751718521118164, 52.75487579405308, 55.3819028288126, 55.89753895998001, 52.24378041923046, 48.374615237116814, 49.50388044118881, 48.50286975502968, 50.43090529739857, 50.83219416439533, 50.42222276329994, 50.559497997164726, 49.26790930330753, 44.14149038493633, 40.971502885222435, 47.096998393535614, 52.79644176363945, 53.59830133616924, 51.549519672989845, 52.60614417493343, 47.827064618468285, 45.31932458281517, 41.96571573615074, 40.22236928343773, 37.959769293665886, 40.51771983504295, 39.027002826333046, 41.45981088280678, 43.708549216389656, 55.049215480685234, 52.11411237716675, 57.56264381110668, 51.38091892004013, 57.38723002374172, 51.11351206898689, 56.41548536717892, 47.940154150128365, 54.31373834609985, 23.20671133697033, 33.40716518461704, 59.404511377215385, 50.628517493605614, 54.43976618349552, 48.96657407283783, 48.58039319515228, 41.81574538350105, 42.71576128900051, 39.4158473610878, 39.63087022304535, 40.700767412781715, 43.83814886212349, 41.60500109195709, 39.73272755742073, 41.33818320930004, 46.27575986087322, 48.06854546070099, 52.52054236829281, 50.083360746502876, 47.15007394552231, 39.86790910363197, 39.91266690194607, 43.12583148479462, 50.780908316373825, 52.45087690651417, 51.93419583141804, 50.65401792526245, 44.44395795464516, 42.35901743173599, 43.36434468626976, 48.678169548511505, 50.950345024466515, 53.58632817864418, 53.016210570931435, 52.58754797279835, 53.175726011395454, 53.57226513326168, 54.80835780501366, 53.70384447276592, 54.92809697985649, 53.769584745168686, 50.99795646965504, 50.978737100958824, 54.38012458384037, 54.611984342336655, 52.20609784126282, 53.608936965465546, 48.88770550489426, 32.88056284189224, 17.53004014492035, 13.796739522367716, 6.4463232178241014, 9.636779744178057, 6.5647277142852545, 0.9890302259009331, 0.2975277160294354, 0.06486890197265893, 0.044136765427538194, 1.9160335301421583, 30.459182672202587, 52.948612198233604, 29.184316881000996, 27.173899859189987, 33.16894456744194, 43.53314682841301, 47.411982491612434, 31.49432312697172, 15.113851446658373, 0.20113439939450473, 0.07870643094065599, 0.11288775654975325, 0.027180828401469626, 0.046941404580138624, 0.07519369013607502, 0.058270979061489925, 0.05790915609395597, 0.04558495529636275, 0.056624620920047164, 0.007285253241207101, 0.03555110015440732, 0.014785406474402407, 0.011391644929972244, 0.05573959497269243, 0.016776359552750364, 0.01192374811580521, 0.06797483452828601, 0.010680393788788933, 0.022727161231159698, 0.055927035500644706, 0.01570468160934979, 0.02862667308363598, 0.010227138227492105, 0.0488011116249254, 0.04192908760160208, 0.02195250563090667, 0.05628755228826776, 0.03129729149804916, 0.10407170266262256, 0.05354543907742482, 0.005360706609280896, 0.015595379954902455, 0.06839347261120565, 0.05690220270480495, 0.05657217334373854, 0.027685427594406065, 0.028333190784906037, 0.06904806912643835, 5.6862367037683725, 48.85553263127804, 60.54948873817921, 55.01319721341133, 33.658719286322594, 24.49837412685156, 25.67966803908348, 37.81667277216911, 43.83603237569332, 16.065000258386135, 0.12563967931782827, 0.06424577994039282, 0.19692315661814064, 2.512874510139227, 5.878137806430459, 7.899546688422561, 3.793920432217419, 6.4764380268752575, 30.065235011279583, 58.53545621037483, 61.16810694336891, 55.722505152225494, 50.935354828834534, 54.35626566410065, 53.9204366505146, 57.47823514044285, 55.64088173210621, 56.241751089692116, 51.45782299339771, 45.49034580588341, 49.86841008067131, 54.76781778037548, 57.38783419132233, 54.45608250796795, 51.850182339549065, 49.11017216742039, 49.44704309105873, 49.60905499756336, 51.46804824471474, 52.171641290187836, 52.11864173412323, 53.894662633538246, 51.4106485247612, 46.17700316011906, 43.7711014598608, 48.522298112511635, 53.34868133068085, 54.69222843647003, 53.0768933147192, 55.06098724901676, 50.75839452445507, 48.3594236522913, 44.934576228260994, 43.55167083442211, 39.19725649058819, 41.773788034915924, 40.6834327429533, 41.46717868745327, 46.29279434680939, 57.38578990101814, 53.42746250331402, 58.576190024614334, 53.36347013711929, 58.914713859558105, 53.07850822806358, 57.90847085416317, 49.50110659003258, 54.61233392357826, 24.167453683912754, 34.75647658109665, 58.8351309299469, 52.57822327315807, 56.29487223923206, 50.60484476387501, 51.236412674188614, 44.04409781098366, 43.39465565979481, 41.09307736158371, 41.837776601314545, 42.573949098587036, 45.2448295801878, 43.1572861969471, 41.82405173778534, 42.39652141928673, 48.385524451732635, 49.96507689356804, 54.768919721245766, 51.527712643146515, 49.53891836106777, 42.418051064014435, 41.029985547065735, 45.06256476044655, 52.25889980792999, 54.34760972857475, 53.87784853577614, 51.580689400434494, 45.71544572710991, 43.46362955868244, 44.858025535941124, 49.89628538489342, 53.59360098838806, 54.694082736968994, 55.89036114513874, 55.10943464934826, 55.95897026360035, 57.11858443915844, 56.61420710384846, 56.07828766107559, 56.92445285618305, 55.3445166349411, 50.310052782297134, 51.41110070049763, 54.74883399903774, 54.11812484264374, 51.88822589814663, 53.64253096282482, 50.15971764922142, 35.87211191654205, 20.04974953830242, 9.602306094020605, 9.65536929666996, 11.973368413746357, 5.553522650152445, 5.162110403180122, 1.3925783685408533, 0.09368654820718803, 0.19384989340323955, 2.482720990665257, 35.30957490205765, 52.926128804683685, 26.241089813411236, 26.908240914344788, 40.3535420447588, 47.55581617355347, 54.06400054693222, 39.18002061545849, 18.391282930970192, 0.3148117120144889, 0.04842758869926911, 0.08732900692848489, 0.02549111028201878, 0.024586667896073777, 0.03674042149214074, 0.020583684745361097, 0.017078346863854676, 0.022020425130904187, 0.08449969507637434, 0.06575442515895702, 0.05552597518544644, 0.07953005158924498, 0.030651648994535208, 0.007690277552683256, 0.04998965741833672, 0.04266894204192795, 0.021015987622376997, 0.017417577000742313, 0.028360776414046995, 0.1596338872332126, 0.15131056745303795, 0.14703928492963314, 0.13008674693992361, 0.1451515284134075, 0.18095264327712357, 0.18992612895090133, 0.13632892136229202, 0.1366407421301119, 0.23343403183389455, 0.09903057551127858, 0.11384296740288846, 0.15551685268292204, 0.18297783070011064, 0.11970907333306968, 0.1275749778142199, 0.12780621618730947, 0.1620220739278011, 0.10867572709685192, 9.291418176144361, 60.22592090070248, 67.54258409142494, 61.71084322035313, 38.98704797029495, 25.95108937472105, 35.1637577265501, 51.123410537838936, 52.38407649099827, 19.965473860502243, 0.2113113072118722, 0.3165121504571289, 0.34950147557538, 4.398288689553738, 7.954372521489859, 13.88357151299715, 11.281060762703419, 7.9494541604071856, 31.399818398058414, 62.05836497247219, 62.82299414277077, 59.15080279111862, 53.51018786430359, 55.858910232782364, 55.03599599003792, 60.585244819521904, 58.580195009708405, 58.47912423312664, 53.957499861717224, 50.54933354258537, 53.26071225106716, 56.22480019927025, 59.91568274796009, 57.072154730558395, 52.10170604288578, 49.21442337334156, 49.78652447462082, 48.824093118309975, 52.62396901845932, 53.721262738108635, 56.08315519988537, 56.9985830783844, 53.227562829852104, 50.07419943809509, 45.05705505609512, 50.40128968656063, 55.36822356283665, 56.58557943999767, 53.965148851275444, 58.97298753261566, 53.26226256787777, 49.94932673871517, 46.51771567761898, 44.92650546133518, 40.97418554127216, 43.588623851537704, 42.93426476418972, 44.667032584548, 46.67664974927902, 58.79964463412762, 55.21148957312107, 60.61514921486378, 55.47253176569939, 61.8277857452631, 56.0379034280777, 59.29831847548485, 51.11256591975689, 54.590682685375214, 27.357920184731483, 36.56255006790161, 60.40457211434841, 53.75002719461918, 57.571736723184586, 52.5690695643425, 52.42634542286396, 46.14605762064457, 46.045294627547264, 43.14712934195995, 43.074481040239334, 44.62462306022644, 47.49101065099239, 44.71221216022968, 43.730690628290176, 45.457105189561844, 49.78566192090511, 51.56881503760815, 56.61568522453308, 54.641535356640816, 51.28298677504063, 43.580298498272896, 42.41425886750221, 48.04074615240097, 56.39199882745743, 57.19257786870003, 56.64049789309502, 55.67992843687534, 48.98972623050213, 47.19767399132252, 46.86608478426933, 52.67138287425041, 55.15636593103409, 58.83915491402149, 58.596214950084686, 58.42888332903385, 58.50672975182533, 60.114955455064774, 60.94345539808273, 58.27877998352051, 59.863952323794365, 55.75161539018154, 52.23108150064945, 52.60557420551777, 58.28911542892456, 55.94393067061901, 54.01895396411419, 53.63538734614849, 51.67147032916546, 36.73988275229931, 23.55761680752039, 20.22074606269598, 12.909513730555773, 22.946826182305813, 18.152589239180088, 6.576001234352589, 2.282068720087409, 0.17009248462272808, 0.21857672516489401, 2.6543143205344677, 44.43038508296013, 63.76902177929878, 37.5481753796339, 38.51678140461445, 46.15450456738472, 54.972664788365364, 61.46028086543083, 47.483722642064095, 23.16561084240675, 1.0807465575635433, 0.19312104501295835, 0.2162120645516552, 0.08845647767884657, 0.13728056248510256, 0.14395938691450283, 0.17304152715951204, 0.15825022710487247, 0.14060220768442377, 0.16487555752974004, 0.11583236846490763, 0.14454608433879912, 0.11506109149195254, 0.13643636950291693, 0.11000929225701839, 0.1663294990430586, 0.10865845732041635, 0.26823933294508606, 0.13996151159517467, 0.14345296018291265], [0.03302815057395492, 0.023917757207527757, 0.017837235536717344, 0.06506022764369845, 0.06673166295513511, 0.015367463620350463, 0.03607739046856295, 0.03190901414200198, 0.047890129062579945, 0.04258955079421867, 0.026380646631878335, 0.04106743188458495, 0.07927527229185216, 0.02475597404554719, 0.03979027365858201, 0.020890013620373793, 0.03507583249302115, 0.04668459550885018, 0.09837416815571487, 11.323943361639977, 46.529441848397255, 48.01622986793518, 37.36349768936634, 20.467569418251514, 23.04518200457096, 37.1417947858572, 45.42258024215698, 36.00331507623196, 6.191489892080426, 0.1964077795855701, 0.16746367880841717, 0.11107939499197528, 2.1461977483704686, 7.6901280507445335, 4.5732626505196095, 3.173524159938097, 8.145778700709343, 33.70508819818497, 57.58154019713402, 54.94787871837616, 55.42468473315239, 51.97694733738899, 54.76322382688522, 55.03156162798405, 49.77638281881809, 51.163258999586105, 57.6609293371439, 50.38083918392658, 52.14294143021107, 49.535122364759445, 52.7915970236063, 53.163532465696335, 55.4232332110405, 47.77148500084877, 49.47515778243542, 48.441510647535324, 49.34840798377991, 49.26512785255909, 46.684842109680176, 48.567618280649185, 50.5241446942091, 49.39194604754448, 45.96318103373051, 42.63023927807808, 46.02398157119751, 51.448562890291214, 54.27506402134895, 50.493810921907425, 52.57475785911083, 45.470415875315666, 40.75617603957653, 38.33158314228058, 38.98975722491741, 38.808814734220505, 39.14233423769474, 38.91503043472767, 41.26159451901913, 40.06171390414238, 45.104632303118706, 46.31105236709118, 50.299067571759224, 46.47297687828541, 52.96832554042339, 48.904648795723915, 55.261734277009964, 50.7090275734663, 57.84565642476082, 23.961493335664272, 33.49203363060951, 60.113439336419106, 51.85975022614002, 51.380158960819244, 45.981100872159004, 47.69749537110329, 44.63633023202419, 45.38335494697094, 42.27785378694534, 40.61709590256214, 38.69120344519615, 41.136102452874184, 40.73295168578625, 39.939797446131706, 41.10956087708473, 46.405139118433, 51.38077832758427, 51.993833631277084, 48.86161230504513, 46.76321670413017, 40.465609431266785, 40.391760393977165, 48.52443739771843, 53.7199442088604, 53.17450247704983, 52.645703852176666, 52.232130244374275, 48.17902833223343, 47.50641882419586, 50.22198870778084, 51.50967501103878, 52.426846995949745, 54.741204008460045, 53.25843997299671, 55.172245278954506, 52.52168990671635, 52.47060164809227, 52.74375379085541, 52.04803392291069, 51.576566621661186, 49.53255370259285, 51.33394584059715, 54.50725056231022, 52.0881749689579, 56.74184985458851, 56.00112900137901, 53.43678340315819, 51.14417642354965, 45.99594667553902, 31.536466665565968, 22.41264894604683, 16.759281903505325, 6.746890414506197, 7.584116589277983, 5.78053766861558, 1.0900245909579098, 0.06036377242708113, 0.05210480056121014, 0.45503831875976175, 13.643392100930214, 45.69094464182854, 73.95534038543701, 38.842249140143394, 24.675262235105038, 42.62737803161144, 43.90947863459587, 48.52189913392067, 28.366887643933296, 2.3664954397827387, 0.04173225519480184, 0.0553501678223256, 0.051824795664288104, 0.037206768538453616, 0.06374670789227821, 0.06544353207573295, 0.07553465504315682, 0.020963159695384093, 0.05265393418085296, 0.029508246188925114, 0.04455091722775251, 0.044929223295184784, 0.06379827973432839, 0.049563523643882945, 0.0276590164139634, 0.02449425752274692, 0.019497572029649746, 0.07493846555007622, 0.06976609700359404, 0.0061371382616925985, 0.047570289389113896, 0.0810984248528257, 0.03339279370266013, 0.0645351804269012, 0.03911572079232428, 0.039614139750483446, 0.04868515105044935, 0.053991406748536974, 0.012988252274226397, 0.03664916330308188, 0.007679675045437762, 0.09671574269304983, 0.08221647774917074, 0.11896276220795698, 0.07197857281425968, 0.06373884112690575, 0.10311855498002842, 0.03638944501290098, 15.65270148217678, 55.50513781607151, 55.93048699200153, 43.427941873669624, 27.071732841432095, 21.4228742569685, 31.714965887367725, 49.664136841893196, 40.03433637320995, 8.333060201257467, 0.26054409274365753, 0.21670528105460107, 0.21762480202596635, 5.8006922621279955, 8.674507979303598, 9.287314396351576, 6.433386811986566, 9.266931340098381, 35.1725010573864, 60.207389295101166, 58.163140788674355, 55.75060464441776, 55.31612075865269, 56.50946192443371, 58.15132722258568, 53.63973431289196, 53.48160959780216, 58.82656618952751, 52.57103405892849, 53.306138813495636, 50.87686076760292, 55.98683036863804, 54.74996633827686, 54.780478700995445, 48.87632891535759, 50.279449224472046, 47.800773829221725, 49.24717761576176, 49.583512768149376, 47.743567898869514, 52.05056458711624, 53.923902064561844, 51.05513580143452, 48.63488607108593, 42.93595567345619, 47.57905952632427, 54.092833399772644, 55.76166585087776, 52.92430490255356, 55.39137192070484, 48.01857814192772, 41.04166992008686, 40.34635283052921, 40.80924779176712, 39.83752593398094, 40.45534238219261, 41.45853795111179, 41.79577745497227, 42.05670565366745, 47.657635509967804, 49.73782628774643, 53.551499247550964, 50.113185346126556, 55.82111366093159, 51.74739025533199, 56.401813700795174, 51.96103759109974, 57.64522098004818, 25.101920440793037, 34.01121497154236, 60.00945791602135, 54.43431727588177, 54.49450984597206, 46.134570837020874, 48.788831010460854, 46.09289087355137, 46.04181781411171, 43.01230117678642, 42.84656547009945, 41.02615915238857, 43.32158178091049, 42.462265491485596, 42.13704094290733, 42.300443574786186, 48.18250134587288, 53.707260489463806, 53.871198892593384, 51.03495888411999, 48.91727551817894, 42.94707767665386, 42.78121657669544, 49.89304035902023, 55.11350803077221, 54.193216413259506, 55.2380957454443, 54.29332584142685, 49.588870480656624, 48.474971652030945, 52.244426384568214, 53.48013907670975, 55.48424273729324, 56.631819158792496, 54.44653362035751, 54.22325760126114, 55.465327352285385, 54.42853018641472, 53.787968158721924, 54.64995950460434, 53.06241989135742, 48.63590441644192, 51.420866176486015, 53.47266487777233, 54.22362618148327, 56.88260570168495, 59.08212907612324, 55.23892790079117, 52.60825306177139, 46.35542258620262, 30.28720960021019, 13.86434169486165, 9.85236307606101, 10.216963961720467, 7.3790420684963465, 4.186991527676582, 2.3956087650731206, 0.11813605422503315, 0.06276432701270096, 0.38703402096871287, 16.532783657312393, 52.895069271326065, 65.2757777273655, 43.24041433632374, 29.621386528015137, 48.44257079064846, 47.279274612665176, 56.6295924782753, 33.81367117166519, 3.0834711296483874, 0.06125970794528257, 0.032805083246785216, 0.06618348299525678, 0.055573936479049735, 0.027551841012609657, 0.018669743403734174, 0.02519367975764908, 0.03466999274678528, 0.039975027611944824, 0.042354468096164055, 0.03350703991600312, 0.0424946412385907, 0.05266570835374296, 0.041686453550937586, 0.022969333294895478, 0.00740148377190053, 0.0410761632520007, 0.018593799431982916, 0.024089733233267907, 0.12604533723788336, 0.14922965958248824, 0.18407307739835232, 0.06985395986703224, 0.1434854810941033, 0.0924231753742788, 0.17771999642718583, 0.12162083090515807, 0.2327233660616912, 0.18438811908708885, 0.11023629296687432, 0.20469099370529875, 0.1820609369315207, 0.19271862285677344, 0.25122636929154396, 0.1815423389780335, 0.12721865787170827, 0.2532808418618515, 0.21245566924335435, 20.518701374530792, 65.06570219993591, 63.16249452531338, 50.11883944272995, 31.296743229031563, 31.009357050061226, 49.42200243473053, 57.34292060136795, 46.84123791754246, 10.081649422645569, 0.4252977599389851, 0.42749243904836476, 0.42221030686050653, 3.4354559797793627, 17.487681917846203, 11.741160973906517, 8.51433802396059, 11.131461840122938, 37.66635663807392, 61.77456960082054, 59.57854583859444, 61.472254022955894, 57.52028368413448, 59.00721229612827, 60.13083100318909, 56.11711397767067, 56.06302388012409, 61.91627159714699, 54.383027628064156, 56.79445803165436, 54.01208013296127, 57.46806688606739, 56.03586673736572, 54.94048051536083, 49.369432255625725, 50.85216209292412, 48.382161632180214, 50.8402269333601, 49.982130378484726, 49.39874388277531, 50.45830562710762, 56.29401348531246, 54.60966266691685, 50.650693103671074, 46.01876825094223, 50.268840193748474, 56.12904153764248, 57.658235281705856, 54.40975919365883, 56.679814383387566, 50.010530054569244, 43.986177518963814, 42.35313534736633, 41.459696888923645, 42.041780054569244, 43.90398412942886, 43.00689406692982, 44.93597075343132, 44.79627884924412, 49.94783341884613, 50.5223435908556, 55.58143772184849, 50.85690803825855, 57.98193231225014, 54.6013069152832, 59.11568507552147, 54.61787402629852, 59.60368528962135, 26.51731789112091, 36.76879920065403, 62.036485746502876, 57.13675506412983, 56.902220249176025, 49.83216382563114, 52.26357735693455, 48.54229263961315, 49.156271293759346, 46.150693371891975, 45.9533965587616, 43.94950568675995, 44.73483234643936, 44.94051530957222, 43.53377379477024, 44.646126106381416, 51.28334775567055, 56.66428081691265, 55.07614463567734, 53.9651108533144, 52.739688009023666, 45.8968061953783, 44.4704083353281, 53.70418645441532, 58.48018437623978, 56.286546885967255, 55.95596842467785, 58.2501295208931, 52.14053615927696, 51.211732998490334, 56.20610520243645, 56.24094173312187, 57.250338569283485, 59.42206643521786, 55.975772961974144, 57.295495346188545, 57.57112115621567, 56.76150619983673, 55.755905359983444, 55.500597059726715, 52.77579367160797, 49.61058251559734, 51.88529245555401, 55.34213416278362, 56.471205577254295, 61.08737647533417, 59.92442607879639, 55.74057698249817, 51.83285526931286, 49.086237251758575, 33.120379373431206, 26.935874931514263, 24.949974194169044, 13.57311012223363, 15.147300101816654, 14.349588956683874, 2.6582974568009377, 0.2151167584815994, 0.2000036631943658, 0.7767108594998717, 19.546191059052944, 61.873770877718925, 81.9810189306736, 46.8901526927948, 37.695257887244225, 57.16384761035442, 54.76252466440201, 63.512634336948395, 40.54821319878101, 5.611747400835156, 0.24004441540455446, 0.15249542106175795, 0.1262777333613485, 0.1407809168449603, 0.16825889004394412, 0.1984525003354065, 0.16816475603263825, 0.1455034251557663, 0.15135600173380226, 0.14362510875798762, 0.09637986891902983, 0.13242555112810805, 0.1381640150793828, 0.19264387374278158, 0.08272936116554774, 0.11948402447160333, 0.11624855746049434, 0.11289089583442546, 0.13569839269621298], [0.02484951062797336, 0.06881335750222206, 0.035702030727406964, 0.0832592323422432, 0.04091315422556363, 0.020827632397413254, 0.027328098331054207, 0.03725129739905242, 0.022966138349147514, 0.09585880703525618, 0.030222578170651104, 0.012013490468234522, 0.08425277512287721, 0.07783759123412892, 0.051573560122051276, 0.008404228719882667, 0.038641466162516735, 0.12633278587600216, 0.5595170077867806, 17.23070740699768, 45.78870199620724, 42.76134364306927, 33.79398062825203, 15.80540768802166, 27.550771236419678, 48.40034365653992, 50.85541471838951, 28.11466857790947, 1.9866130803711712, 0.10603545510093682, 0.07654090339201503, 0.2944587275851518, 5.238275891169906, 5.815710481256247, 7.608373062685132, 3.11492299195379, 9.28535370156169, 36.19631811976433, 55.55291645228863, 59.48808029294014, 55.46373523771763, 56.93305939435959, 55.41720673441887, 57.9627775400877, 45.589851066470146, 50.879737213253975, 52.975598350167274, 52.962762638926506, 52.872730270028114, 51.67711302638054, 53.58641937375069, 53.37440215051174, 50.59879928827286, 48.25008451938629, 50.45536458492279, 51.43953077495098, 50.31724959611893, 49.96367856860161, 48.15369889140129, 47.29463338851929, 52.333368211984634, 50.36752849817276, 49.936019852757454, 44.20833259820938, 46.41413703560829, 49.755563735961914, 53.45015488564968, 52.55116492509842, 52.67542965710163, 43.717577531933784, 37.25847892463207, 38.03559422492981, 38.63194942474365, 37.363106310367584, 38.22915203869343, 38.84500779211521, 41.20607569813728, 38.605753630399704, 38.3694177120924, 38.32802653312683, 39.9054928869009, 40.59273160994053, 44.4383342564106, 44.19282183051109, 51.445777639746666, 50.39609916508198, 57.5072617828846, 26.846009753644466, 38.817664459347725, 59.55977484583855, 50.70882998406887, 53.4234993159771, 47.802753522992134, 54.917491748929024, 51.84187598526478, 54.082946330308914, 50.02808891236782, 48.46683628857136, 43.26042786240578, 39.36270721256733, 38.00798870623112, 41.011693328619, 40.13895995914936, 45.780167654156685, 50.07642611861229, 52.52402298152447, 49.850570037961006, 49.288363605737686, 41.517184004187584, 45.662894546985626, 50.00198431313038, 52.095656767487526, 50.40736936032772, 51.37620337307453, 52.182470709085464, 51.66448250412941, 49.719651862978935, 52.797543704509735, 52.947137877345085, 53.18713679909706, 52.694041058421135, 49.29253578186035, 46.69544354081154, 48.157380893826485, 48.49829480051994, 51.23804658651352, 48.77839297056198, 49.73476745188236, 52.07648679614067, 52.25814364850521, 51.11385025084019, 55.93238689005375, 53.192517310380936, 57.40250140428543, 56.163338497281075, 55.52185691893101, 47.58909858763218, 32.13120125234127, 19.386229142546654, 12.91345601901412, 10.69776926189661, 2.787217888981104, 4.167756484821439, 1.8695216509513557, 0.2510505396639928, 0.06900411171955056, 0.09413340274477378, 7.946678409352899, 33.80957119166851, 28.98977492004633, 26.135599873960018, 31.062787882983685, 42.88918398320675, 46.02165229618549, 48.4793072193861, 39.03947375714779, 6.007336573675275, 0.1275549249839969, 0.12517214112449437, 0.052683850153698586, 0.004610118858181522, 0.006764289692000602, 0.07309077016543597, 0.035467615962261334, 0.02944254199974239, 0.024656899186084047, 0.044978479636483826, 0.016206672153202817, 0.057997052354039624, 0.026456217674422078, 0.032743870906415395, 0.057107669999822974, 0.05654672138916794, 0.04502209565544035, 0.026332366214774083, 0.016466069464513566, 0.020229459514666814, 0.0720411803922616, 0.033011370614985935, 0.07858868179027922, 0.027380206374800764, 0.015098108542588307, 0.04448704799870029, 0.04958682337019127, 0.0360954617644893, 0.03805948137596715, 0.05908297767746262, 0.06376036340952851, 0.003389363391761435, 0.031151366711128503, 0.033030614504241385, 0.055173147047753446, 0.07747010939056054, 0.13485240371664986, 1.1995964613743126, 25.80067064613104, 53.61663155257702, 51.485230922698975, 40.87073229253292, 23.65484219044447, 26.419043764472008, 50.980306416749954, 55.7822797447443, 34.75673496723175, 2.3001635866239667, 0.14705999084981158, 0.2786472119623795, 0.6458227266557515, 7.6608325727283955, 9.754766263067722, 7.619125535711646, 6.096038538962603, 10.553430207073689, 37.84399710595608, 57.66531050205231, 60.03157652914524, 58.58977809548378, 58.46145138144493, 58.35759535431862, 59.14527028799057, 48.425912484526634, 52.08099715411663, 55.79191982746124, 55.12858182191849, 55.17711281776428, 53.81682001054287, 54.77085381746292, 53.38916815817356, 52.207192182540894, 47.84547843039036, 49.43203389644623, 51.95575587451458, 51.132138669490814, 50.3077083081007, 47.573101446032524, 47.71376229822636, 53.49786512553692, 52.80942186713219, 52.124478220939636, 45.806355848908424, 46.667545437812805, 50.113322138786316, 56.38575576245785, 54.27445225417614, 54.45238150656223, 46.97490334510803, 38.88220399618149, 39.65022258460522, 39.70194920897484, 39.49581027030945, 40.45406185090542, 40.40745735168457, 42.782196924090385, 40.98054260015488, 41.4490232616663, 41.26309163868427, 42.407658621668816, 42.168583050370216, 45.8878006786108, 46.73352509737015, 53.41282568871975, 52.082270085811615, 60.13411022722721, 26.622899025678635, 38.954498916864395, 59.393868148326874, 53.47374401986599, 55.180236250162125, 50.75236804783344, 55.97912058234215, 54.39923755824566, 55.35807050764561, 50.92158816754818, 49.264326095581055, 43.77723813056946, 40.839437171816826, 40.90059109032154, 42.659725695848465, 41.9918355345726, 48.08882497251034, 52.88531519472599, 53.685187473893166, 51.51700861752033, 50.282226875424385, 43.24396334588528, 46.66116178035736, 51.865985691547394, 54.72339056432247, 52.68837556242943, 54.513831809163094, 55.025660544633865, 51.98313720524311, 52.865313068032265, 54.023863300681114, 57.558205649256706, 54.65595558285713, 53.225624933838844, 49.526804611086845, 48.30861657857895, 49.02956709265709, 49.81707863509655, 52.383928298950195, 48.15623335540295, 49.6402171254158, 54.203821644186974, 52.811580151319504, 53.415565341711044, 56.15061677992344, 56.7922655493021, 58.73230844736099, 58.46291430294514, 54.808809980750084, 47.78164565563202, 30.65491396933794, 20.76980520039797, 9.094206858426332, 9.078921228647232, 9.514276217669249, 8.203589748591185, 3.5788495978340507, 0.6167617673054338, 0.05941177878412418, 0.04195607209112495, 8.455451633781195, 37.65325494110584, 39.06410023570061, 33.455069214105606, 40.66202849149704, 50.64163438975811, 51.049329712986946, 53.19776102900505, 45.42540729045868, 8.75485086813569, 0.11745398340281099, 0.14302067400421947, 0.03938586996810045, 0.029598654618894216, 0.02135740523954155, 0.05887151382921729, 0.026582345672068186, 0.022676535627397243, 0.0587967721367022, 0.02883858593122568, 0.040431982779409736, 0.016343474089808296, 0.0471022428246215, 0.030713939304405358, 0.07216474798042327, 0.017838671592471655, 0.03846012979920488, 0.025359904138895217, 0.04279781598597765, 0.08502235999912955, 0.14318909699795768, 0.1806800821213983, 0.20687822165200487, 0.07671090716030449, 0.11893738817889243, 0.1165995562041644, 0.10950720708933659, 0.1620805254788138, 0.12248952218214981, 0.13875599659513682, 0.14037472457857803, 0.12678665370913222, 0.19775197230046615, 0.07299634671653621, 0.09508755232673138, 0.14858936425298452, 0.3399512224132195, 1.908672850113362, 35.88053986430168, 63.44512715935707, 57.40539684891701, 47.089110016822815, 26.577732749283314, 39.98557738959789, 60.64677111804485, 61.086593717336655, 38.94001789391041, 3.4512253711000085, 0.18482623854652047, 0.38563355861697346, 1.2472076690755785, 11.772117912769318, 15.314715318381786, 18.19846797734499, 7.870519571006298, 10.639580134302378, 39.42149765789509, 57.733387649059296, 64.45771962404251, 59.279167503118515, 63.048090264201164, 58.792542815208435, 60.84338776767254, 48.193140774965286, 54.587570652365685, 55.95862068235874, 56.338718086481094, 57.205086797475815, 54.76242206990719, 57.33442045748234, 56.16458483040333, 52.74542950093746, 48.47552262246609, 51.214324459433556, 53.79509277641773, 51.86969429254532, 52.09129840135574, 47.18890406191349, 46.657555773854256, 54.33044224977493, 54.977425932884216, 55.64741738140583, 48.06815408170223, 49.696009531617165, 53.15917409956455, 56.58584162592888, 56.78588569164276, 57.95286767184734, 47.13023900985718, 41.23039439320564, 41.52416802942753, 41.39358803629875, 41.151658818125725, 42.100699692964554, 43.42516042292118, 45.11831536889076, 43.43272961676121, 43.46736095845699, 42.972171530127525, 44.0716577321291, 44.652445167303085, 48.26605126261711, 48.32319639623165, 55.446324571967125, 55.42707100510597, 61.07914611697197, 29.2404892668128, 41.80358223617077, 60.462701395154, 55.09962357580662, 56.82368986308575, 52.29131206870079, 59.99480590224266, 56.12550012767315, 58.19621801376343, 52.91084602475166, 52.702822387218475, 47.89229191839695, 44.06220383942127, 42.22138501703739, 44.43826586008072, 44.34636399149895, 51.08888179063797, 54.93199177086353, 56.29197299480438, 53.50932911038399, 53.624877110123634, 45.32999821007252, 49.54920820891857, 53.08620281517506, 56.879512667655945, 54.95798617601395, 54.63347978889942, 57.188443690538406, 56.179905608296394, 56.21295623481274, 56.54669992625713, 58.918297067284584, 56.56214229762554, 53.90796571969986, 49.15104277431965, 48.269528076052666, 50.277518928050995, 49.88827541470528, 53.42265576124191, 47.880128771066666, 50.55744610726833, 53.34427736699581, 54.038861095905304, 54.68407407402992, 58.72886963188648, 57.22738020122051, 61.6656294465065, 59.413205310702324, 57.71479904651642, 50.28900571167469, 35.39102353155613, 24.852463826537132, 16.808529160916805, 16.419884115457535, 12.285390570759773, 14.253456015139818, 5.457244366407394, 1.0334734129719436, 0.11681574382237159, 0.2223935312940739, 11.06402875855565, 43.61063227057457, 41.50824688374996, 35.58355540037155, 42.33413256704807, 54.40237618982792, 58.25987979769707, 60.445632711052895, 52.68144853413105, 12.721150238066912, 0.44178317533805966, 0.26080063835252076, 0.07709837504080497, 0.08321884466568008, 0.1263416322763078, 0.21827830758411437, 0.12859942362410948, 0.20344644173746929, 0.10294248786522076, 0.07160274923080578, 0.09604300808859989, 0.28552748495712876, 0.12911784346215427, 0.13876352197257802, 0.17086946871131659, 0.11923229540116154, 0.13388477673288435, 0.09873866656562313, 0.13351836358197033], [0.03377963446837384, 0.012496595209086081, 0.03476942569250241, 0.03026543534360826, 0.051720861592912115, 0.016477450299134944, 0.0860358591307886, 0.093179067625897, 0.02059894886770053, 0.07711358164669946, 0.0027310368886901415, 0.04424044345796574, 0.03143184287182521, 0.036811908867093734, 0.05752054159529507, 0.07329918749746867, 0.04332037700805813, 0.06340173538774252, 1.7041031084954739, 29.210461378097534, 44.768707528710365, 50.856729447841644, 24.165411293506622, 19.665650948882103, 41.3861670345068, 55.44914402067661, 48.81386786699295, 16.545640267431736, 0.6535090610850602, 0.06231320512597449, 0.4250148235587403, 0.6230855779722333, 9.805681630969048, 6.911556478589773, 7.16222332790494, 6.74656268209219, 8.700528033077717, 37.83564135432243, 57.89937034249306, 50.055139660835266, 52.73913323879242, 52.84503735601902, 53.001744747161865, 50.676736906170845, 52.433397844433784, 47.98615828156471, 51.39539994299412, 53.300967290997505, 54.701089560985565, 53.59968066215515, 51.47042691707611, 50.09303502738476, 49.62395019829273, 51.15842945873737, 53.56570288538933, 51.554125025868416, 52.068773210048676, 49.81382220983505, 50.70154957473278, 48.31835925579071, 50.1367174834013, 51.83123275637627, 50.472809448838234, 49.25714448094368, 48.94471384584904, 50.15400655567646, 51.97201520204544, 50.33013090491295, 53.132928907871246, 44.45439599454403, 37.34938524663448, 38.27213913202286, 38.29588025808334, 38.24860319495201, 39.390666112303734, 37.944547310471535, 40.80609016120434, 41.432786732912064, 42.25437104701996, 41.36483497917652, 42.69959695637226, 41.260614171624184, 44.01280649006367, 44.10031959414482, 51.26276046037674, 50.54087519645691, 56.69743783771992, 24.16842833161354, 35.365165919065475, 55.52670165896416, 52.80009336769581, 54.99408043920994, 51.89405478537083, 53.478223979473114, 52.92576402425766, 54.23276089131832, 51.061325669288635, 51.797840148210526, 48.72184820473194, 41.878115236759186, 38.526767268776894, 39.14137288928032, 37.5498016923666, 44.02061887085438, 50.687953904271126, 52.65090577304363, 49.199702963232994, 49.84835475683212, 45.954544097185135, 48.596447333693504, 51.47485747933388, 53.37017297744751, 51.35819233953953, 51.41290940344334, 52.88530759513378, 52.62418180704117, 54.344224110245705, 54.35632646083832, 51.36908255517483, 50.67916117608547, 48.415227457880974, 49.05617706477642, 48.34795206785202, 46.59395478665829, 45.957314148545265, 48.71823459863663, 47.29826979339123, 53.6019529402256, 49.72578853368759, 47.34984062612057, 51.76676921546459, 50.29786303639412, 53.59476752579212, 55.08783660829067, 57.066572830080986, 51.58970631659031, 31.754899844527245, 35.85743710398674, 27.87641566246748, 14.036423061043024, 13.000292759388685, 8.275707978755236, 3.798184278421104, 3.697735955938697, 0.6404319440480322, 0.08765167047386058, 0.1294364474597387, 3.5953017650172114, 29.22209445387125, 30.440763160586357, 19.638752192258835, 18.862324655056, 34.04196672141552, 37.210468500852585, 48.872217535972595, 36.47081919014454, 15.83261327818036, 0.7401092641521245, 0.01081731817976106, 0.10182007114053704, 0.05073612439446151, 0.0217000622433261, 0.062061316493782215, 0.045955338937346824, 0.029744809471594635, 0.10224683574051596, 0.04687371700129006, 0.027734925133700017, 0.03552639034751337, 0.014026440803718287, 0.011191694575245492, 0.06405878099030815, 0.01491254935899633, 0.08100150778773241, 0.02308865023223916, 0.021096874297654722, 0.06808213423937559, 0.03295854454336222, 0.042109381247428246, 0.016957491825451143, 0.05204709857935086, 0.04340417290222831, 0.10708533431170508, 0.04431699599081185, 0.024555245363444556, 0.05570998699113261, 0.053144141274970025, 0.020819259116251487, 0.03934971253329422, 0.029131314950063825, 0.012532179334812099, 0.06550760168465786, 0.006383821655617794, 0.04058080194226932, 2.487559081055224, 37.219052240252495, 53.31467315554619, 54.4177121669054, 31.03627670556307, 20.313645377755165, 43.18982005119324, 60.7564028352499, 55.764815881848335, 21.542683728039265, 0.7853710697963834, 0.09499750012764707, 0.4564243240747601, 1.4009535941295326, 10.651771780103445, 9.218968413770199, 12.409284822642803, 8.353544902056456, 8.682901728898287, 39.800895899534225, 57.58275233209133, 53.36338274180889, 53.298524022102356, 54.69045773148537, 53.99444527924061, 52.269896417856216, 54.18003872036934, 48.20546351373196, 52.43508495390415, 55.94870701432228, 57.13329344987869, 54.85794134438038, 53.78106012940407, 51.723303347826004, 49.64177504181862, 52.38625757396221, 54.3591421097517, 53.175391629338264, 53.28302465379238, 52.2105398029089, 51.625428199768066, 49.122510105371475, 51.09255239367485, 53.25223870575428, 53.1184858828783, 50.15710338950157, 50.726206451654434, 53.33592161536217, 53.355273976922035, 50.937509313225746, 54.68680612742901, 46.92277014255524, 39.34104837477207, 39.13203299045563, 39.69483599066734, 39.538048803806305, 40.40754474699497, 40.74512243270874, 41.3623309135437, 42.533352077007294, 44.43129323422909, 43.63420620560646, 43.75637724995613, 42.603910490870476, 45.31908139586449, 46.34252987802029, 53.09878394007683, 52.74805136024952, 58.60974222421646, 24.677466116845608, 36.68512389063835, 55.39266385138035, 53.15389238297939, 57.108754366636276, 52.91774645447731, 55.45897029340267, 54.367300271987915, 55.49769401550293, 52.88088843226433, 53.248556703329086, 49.3713815510273, 42.37872697412968, 41.15767389535904, 40.729383677244186, 40.41857935488224, 45.38496986031532, 53.47412779927254, 53.36781710386276, 52.27823697030544, 50.65828889608383, 48.68499778211117, 51.00706458091736, 53.692775666713715, 55.25525562465191, 52.0296923071146, 52.68265686929226, 55.56861340999603, 54.65397208929062, 56.4790141582489, 55.32265640795231, 52.58803814649582, 50.42031146585941, 48.696134984493256, 48.75735729932785, 49.67981480062008, 47.891566157341, 46.509093940258026, 49.33814473450184, 48.13580185174942, 53.19855138659477, 51.48633286356926, 50.35386063158512, 52.40934893488884, 51.97730451822281, 53.81528489291668, 57.96279273927212, 57.93537721037865, 53.75234127044678, 34.36082661151886, 36.13470442593098, 29.047201238572598, 11.152989584952593, 7.700357101857662, 9.191008564084768, 6.040569115430117, 5.631488766521215, 1.1610456299968064, 0.17188214405905455, 0.04365338980278466, 4.064498925581574, 30.4382286965847, 31.858446188271046, 25.16360253095627, 24.026006273925304, 40.379813835024834, 44.323800802230835, 55.18468581140041, 45.37317909300327, 18.627962730824947, 0.9155082679353654, 0.054242141341092065, 0.06482089243945666, 0.0695679584168829, 0.036306012771092355, 0.012374367197480751, 0.03632974665379152, 0.11690093495417386, 0.05481365442392416, 0.07078779686708003, 0.03159449937811587, 0.07463332411134616, 0.1081967969366815, 0.013886763972550398, 0.03660413349280134, 0.021372352093749214, 0.05180816413485445, 0.07215478835860267, 0.012483565878937952, 0.17579317325726151, 0.09365226840600371, 0.12328399127000012, 0.09231724863639101, 0.16663772781612352, 0.1356674896669574, 0.19262389512732625, 0.1693167770281434, 0.14575912471627817, 0.16556312766624615, 0.13956137525383383, 0.14016423665452749, 0.15833138837479055, 0.11528016606462188, 0.16005694109480828, 0.20835430885199457, 0.12087970739230514, 0.08244779775850475, 3.589017139747739, 48.76051113009453, 61.9902004301548, 63.15945088863373, 35.04796274006367, 30.36633275449276, 53.38495418429375, 62.366885617375374, 58.67093414068222, 24.8862212151289, 0.9743005537893623, 0.16075304592959583, 0.9503434330690652, 1.5527852531522512, 23.54910146445036, 17.91152447462082, 22.9049239307642, 15.204935409128666, 10.219156444072723, 40.268749594688416, 58.220844492316246, 52.766947746276855, 54.08521480858326, 56.017414927482605, 55.567165687680244, 52.67181985080242, 53.28565411269665, 49.13765609264374, 56.96512207388878, 56.35996654629707, 59.0571416169405, 56.69163174927235, 55.12951657176018, 49.60408106446266, 51.2269701808691, 53.92410725355148, 57.20640532672405, 56.404180973768234, 56.79298751056194, 54.74569536745548, 52.913676872849464, 49.711402505636215, 50.72390377521515, 57.14491702616215, 55.58199629187584, 53.953377082943916, 54.163794592022896, 55.75069963932037, 54.59746532142162, 52.66922079026699, 57.106155306100845, 49.72426861524582, 41.908555403351784, 42.419327795505524, 41.924206763505936, 41.0498470813036, 41.54576987028122, 41.436525732278824, 43.69163632392883, 45.9383949637413, 47.39804483950138, 46.63479879498482, 47.40831948816776, 45.167488530278206, 46.50594770908356, 48.10242064297199, 53.74937742948532, 55.5155074596405, 60.44574290513992, 26.52449570596218, 38.81333649158478, 56.84643544256687, 56.04854665696621, 59.89823028445244, 55.484261736273766, 56.67997017502785, 57.87476286292076, 58.090534284710884, 54.349505826830864, 56.426561772823334, 51.963667050004005, 46.45949900150299, 42.85406246781349, 43.63136775791645, 42.33403757214546, 47.771781384944916, 55.49413360655308, 57.546019703149796, 54.36191216111183, 54.80860859155655, 49.9293702095747, 53.9826925098896, 55.87985470890999, 57.0569783449173, 52.891793847084045, 53.40964525938034, 56.79673790931702, 55.98657578229904, 58.574320524930954, 57.43364833295345, 53.01499083638191, 51.2030428647995, 48.50064307451248, 48.412449806928635, 49.81234788894653, 49.21826496720314, 48.38825270533562, 51.64695784449577, 49.54416207969189, 55.28283454477787, 53.34395058453083, 50.80633655190468, 52.783009484410286, 54.773095697164536, 57.628376483917236, 60.40443152189255, 60.874865278601646, 56.25686667859554, 38.51248383522034, 36.878617107868195, 28.696550354361534, 16.652140952646732, 19.82756406068802, 15.06981560960412, 10.566943231970072, 8.953339867293835, 1.2299197842366993, 0.21092923474498093, 0.30392241664230824, 5.587733164429665, 39.758851155638695, 42.91159138083458, 29.75463207811117, 27.27073196321726, 45.20475693047047, 50.45720748603344, 62.01252043247223, 52.824940234422684, 23.46646159887314, 1.3867655117064714, 0.11903914404683746, 0.19631244329502806, 0.213748297537677, 0.11293372517684475, 0.1280180993489921, 0.19432090484770015, 0.1003352488623932, 0.1605871759238653, 0.20928301761159673, 0.0984337626141496, 0.1639377500396222, 0.2631933818338439, 0.09387059340951964, 0.12257244976353832, 0.18776937358779833, 0.18689599935896695, 0.2293704022304155, 0.100663597258972], [0.0318598765443312, 0.009329018012067536, 0.046463554244837724, 0.08967483925516717, 0.045511389907915145, 0.009280830363422865, 0.04802275085239671, 0.0542084923654329, 0.02187383612181293, 0.014845334899291629, 0.04157431503699627, 0.04163407276791986, 0.04754991372465156, 0.022430322569562122, 0.05238834550254978, 0.036725771497003734, 0.07865067338570952, 0.08175530718290247, 6.358070578426123, 35.29145747423172, 47.201272398233414, 43.448977544903755, 33.657450154423714, 36.3932653516531, 49.98364269733429, 58.73632863163948, 30.610610246658325, 12.569661866873503, 0.07779763400321826, 0.03746103204321116, 0.042998555800295435, 1.0447700880467892, 7.896114522591233, 6.138707399368286, 3.8546129129827023, 3.323607319034636, 8.966185078024864, 41.51515871286392, 55.09455844759941, 51.96164555847645, 49.29769970476627, 49.27958607673645, 51.87517739832401, 52.19892382621765, 49.16146941483021, 46.58763572573662, 46.6220048815012, 50.825069546699524, 53.870796114206314, 50.37538267672062, 53.3566989004612, 49.993902146816254, 50.51787883043289, 51.08349367976189, 49.25136499106884, 48.62360067665577, 49.551149904727936, 50.99908120930195, 53.833717703819275, 50.71692734956741, 48.39451476931572, 49.41686511039734, 53.47656726837158, 51.907259076833725, 50.19500635564327, 51.83804199099541, 53.198330998420715, 51.64085917174816, 53.034217804670334, 43.31186190247536, 37.540279403328896, 38.50326932966709, 36.855377554893494, 37.423629462718964, 40.45523978769779, 44.36859279870987, 48.83004739880562, 49.07577641308308, 50.84836229681969, 49.16891321539879, 51.279829144477844, 51.42740562558174, 52.79508523643017, 49.51550021767616, 53.89931358397007, 50.948536321520805, 57.109430730342865, 24.526971392333508, 34.145172983407974, 52.59164035320282, 46.689284071326256, 52.50992193818092, 47.91475251317024, 51.40923500061035, 47.67219252884388, 51.517020016908646, 50.312427654862404, 52.77337700128555, 52.65160493552685, 47.63286843895912, 39.88518677651882, 38.98889847099781, 38.01784537732601, 40.09291023015976, 47.873346135020256, 50.68263798952103, 51.91482067108154, 49.14052113890648, 49.128623977303505, 52.22379729151726, 52.51593701541424, 49.60083603858948, 45.684313997626305, 50.20349510014057, 50.99944218993187, 50.47651045024395, 49.876321256160736, 50.973481982946396, 46.531448140740395, 48.62759046256542, 48.72907541692257, 53.576745092868805, 53.68529386818409, 52.13028810918331, 51.637697741389275, 48.74922193586826, 49.93081033229828, 46.549652963876724, 44.39192354679108, 48.27800162136555, 50.61236456036568, 53.3338887244463, 53.85941192507744, 56.10217697918415, 57.575715109705925, 45.46479217708111, 45.48057273030281, 55.76381653547287, 33.16758804023266, 18.854994848370552, 9.344315137714148, 6.931892512366176, 6.029883613809943, 3.380640596151352, 0.6980831036344171, 0.542234763270244, 0.5614681437145919, 0.61188995372504, 19.380607344210148, 39.37651567161083, 25.711177848279476, 50.36882422864437, 27.261794842779636, 38.872864097356796, 42.5472479313612, 41.5460966527462, 21.89970877021551, 0.9914500429295003, 0.07278698685695417, 0.05494563054526225, 0.07591102039441466, 0.056902484720922075, 0.05795747732918244, 0.056684549344936386, 0.0400929511670256, 0.003492491537144815, 0.06773023749701679, 0.049251602686126716, 0.04193406741251238, 0.03173017510562204, 0.03824344865279272, 0.01040088149238727, 0.012818899740523193, 0.03890975254762452, 0.038665738102281466, 0.018986851973750163, 0.028973269036214333, 0.005173313393243006, 0.04033712517411914, 0.05540752099477686, 0.026888830398092978, 0.09233653705450706, 0.03851043256872799, 0.08314418460940942, 0.06737317540682852, 0.015553782577626407, 0.03533199218509253, 0.017977262104977854, 0.07658181057195179, 0.0701569119701162, 0.07576156669529155, 0.07038949363050051, 0.07126660086214542, 0.026615844362822827, 7.712352583184838, 44.85459811985493, 54.91289399564266, 50.79629749059677, 35.740277990698814, 39.71953086555004, 57.281827479600906, 64.50751215219498, 40.74653975665569, 13.68631649762392, 0.04518549430940766, 0.2138123894110322, 0.5492704419884831, 4.249719036743045, 9.233759120106697, 10.78262535855174, 10.829455945640802, 6.475191218778491, 11.221718396991491, 39.58369195461273, 54.94675397872925, 52.85302832722664, 52.006965726614, 51.284837275743484, 53.57131898403168, 52.40020662546158, 49.58072751760483, 49.509010165929794, 50.27806229889393, 51.26048058271408, 54.50896047055721, 52.371347174048424, 53.41694846749306, 49.44366127252579, 50.54716385900974, 52.466585263609886, 52.20336578786373, 50.39405107498169, 52.198627442121506, 52.37212613224983, 54.59449388086796, 50.24936243891716, 49.55428093671799, 51.08587235212326, 55.514986887574196, 52.44582697749138, 51.827064380049706, 53.29934857785702, 54.79777917265892, 52.02289067208767, 54.67807799577713, 45.18107660114765, 39.3124321103096, 39.67721253633499, 39.803741946816444, 39.436940029263496, 41.79457291960716, 45.67146308720112, 50.41891694068909, 50.718945041298866, 51.571505293250084, 51.71338967978954, 52.809942439198494, 51.88520886003971, 53.81071373820305, 51.090549901127815, 55.24947993457317, 53.972326666116714, 56.5673404186964, 25.2374629676342, 34.411090314388275, 51.62179559469223, 48.91489304602146, 53.645680993795395, 49.716513231396675, 50.88101014494896, 48.56174759566784, 52.08928070962429, 52.310523837804794, 54.096538200974464, 54.520975425839424, 49.14348877966404, 40.8019407838583, 39.7868100553751, 40.1904433965683, 41.259770616889, 50.16493856906891, 53.12121033668518, 54.325008541345596, 51.10492832958698, 52.06325210630894, 53.33158604800701, 55.294009745121, 51.00137248635292, 46.944333985447884, 48.19173105061054, 51.419228464365005, 50.207082107663155, 50.027226358652115, 49.549322202801704, 48.24029624462128, 46.88941553235054, 49.64748993515968, 53.31677824258804, 53.782276064157486, 53.62434133887291, 52.32268698513508, 49.9207978695631, 51.877324283123016, 48.82015272974968, 48.06561961770058, 49.235428646206856, 52.346952483057976, 54.10353742539883, 57.972353026270866, 56.78212769329548, 58.06992419064045, 46.73840783536434, 49.3250772356987, 55.45752637088299, 35.76909564435482, 17.8945279866457, 8.55738591402769, 7.999621443450451, 8.513063192367554, 7.8879649098962545, 0.8935405185911804, 1.0098335752263665, 0.8021162368822843, 0.8554752299096435, 21.85629040002823, 42.62658007442951, 23.249394446611404, 44.185533821582794, 31.854876279830933, 44.08112682402134, 48.655085787177086, 46.242017671465874, 27.93176159262657, 1.4601250877603889, 0.051835330450558104, 0.08053431840380654, 0.05780079882242717, 0.044641563144978136, 0.03765156361623667, 0.07058056697132997, 0.018372283193457406, 0.010939657513517886, 0.009683274784038076, 0.035190639027860016, 0.03612645756220445, 0.0073226477434218396, 0.02472137512086192, 0.03789100643189158, 0.06061025822418742, 0.04025688045658171, 0.07104820164386183, 0.025286119816883, 0.19289905379991978, 0.05803437867143657, 0.19112803711323068, 0.17960819823201746, 0.1408278799499385, 0.16551748558413237, 0.19590442534536123, 0.18585659185191616, 0.12310146004892886, 0.04283119778847322, 0.10017161272116937, 0.14842321223113686, 0.10243079188512638, 0.1251825608778745, 0.2067267196252942, 0.12288480487768538, 0.16894822649192065, 0.17586872389074415, 12.282725013792515, 57.63363540172577, 62.460390999913216, 57.942296639084816, 45.24013303220272, 49.98319812119007, 58.49844999611378, 62.70151846110821, 41.789070814847946, 18.46349235624075, 0.284807839198038, 0.36818738852161914, 0.3951616067206487, 2.864687656983733, 12.524797674268484, 14.407690688967705, 13.125526439398527, 7.214973047375679, 11.729990523308516, 43.29837642610073, 57.390448451042175, 53.73738147318363, 52.94741526246071, 52.1493136882782, 55.246839076280594, 53.51467162370682, 51.308145225048065, 51.53311975300312, 52.177599370479584, 52.375944927334785, 55.23812994360924, 54.16858993470669, 53.90937924385071, 51.49127259850502, 52.61902928352356, 56.14623561501503, 53.85823018848896, 53.17880004644394, 53.324856609106064, 55.420273169875145, 57.47487232089043, 51.7217568308115, 48.94299253821373, 51.25158526003361, 58.82934384047985, 55.36705702543259, 54.30478222668171, 56.046536564826965, 55.59594914317131, 55.84385924041271, 57.56675139069557, 46.850976794958115, 41.638351902365685, 41.37170881032944, 41.80552393198013, 41.76410235464573, 44.30884100496769, 49.074780866503716, 51.7898453772068, 51.690332517027855, 53.95331248641014, 54.398625791072845, 54.838231801986694, 55.925163477659225, 56.293458715081215, 53.77998098731041, 58.88550862669945, 55.691445618867874, 57.42593474686146, 27.484267204999924, 34.74059343338013, 50.38535334169865, 48.24182376265526, 53.66548553109169, 50.13027682900429, 52.302962243556976, 48.73298920691013, 52.62036681175232, 53.621575087308884, 55.789434760808945, 58.75190779566765, 51.20395481586456, 44.95038717985153, 43.28043758869171, 41.87329709529877, 43.376868814229965, 52.09621153771877, 55.87261989712715, 57.06396237015724, 53.5204891115427, 55.16265079379082, 56.694375202059746, 56.11991822719574, 51.28541864454746, 46.9687020778656, 51.20072118937969, 51.711846962571144, 51.73225946724415, 51.24951437115669, 50.52511364221573, 47.86524496972561, 47.19078116118908, 50.15662461519241, 54.384809732437134, 57.42430843412876, 55.221707224845886, 53.59025336802006, 52.30626806616783, 52.74120792746544, 50.89363306760788, 49.110118970274925, 49.81473796069622, 54.25406254827976, 56.13597996532917, 59.92104806005955, 60.4096220433712, 62.20540188252926, 50.94915188848972, 48.408669009804726, 55.659907311201096, 35.80191448330879, 19.228763692080975, 13.047686666250229, 15.74690317735076, 13.253600466996431, 10.264241024851799, 2.636537686921656, 0.8215670962817967, 0.6667568127159029, 0.9666549484245479, 28.222495391964912, 52.57834866642952, 36.44501857459545, 62.9047467559576, 37.416212260723114, 52.00068086385727, 55.46539954841137, 54.79850873351097, 35.910265669226646, 3.0974208936095238, 0.16229267581366003, 0.17583390232175589, 0.3467846510466188, 0.16129978612298146, 0.19368633889826015, 0.13056375493761152, 0.13242179586086422, 0.0932782408199273, 0.182409004191868, 0.3077547188149765, 0.14524064550641924, 0.11944609330384992, 0.13659208692843094, 0.15331593953305855, 0.23453707108274102, 0.13379436830291525, 0.16857943846844137, 0.14116754609858617], [0.0773402706545312, 0.05568772256083321, 0.015246202256093966, 0.04831132013350725, 0.010614831535349367, 0.01159741093943012, 0.021191633568378165, 0.09359601361211389, 0.10435401563881896, 0.01612242169358069, 0.007085955976435798, 0.014831976241111988, 0.04844605333346408, 0.043236276833340526, 0.06155156865133904, 0.02909353221184574, 0.019506718999764416, 0.04258723900420591, 10.102602448314428, 37.89031282067299, 42.82922700047493, 29.531939327716827, 23.88412568718195, 22.305169813334942, 33.41871276497841, 24.20193873345852, 28.071164712309837, 10.369194243103266, 0.03935321918106638, 0.04919086532026995, 1.6432604170404375, 7.636707192286849, 5.846426608040929, 6.65894128382206, 11.17013331502676, 11.600732859224081, 9.776029922068119, 38.88234458863735, 54.18185122311115, 53.91360081732273, 53.293515890836716, 55.47936759889126, 52.85577937960625, 54.49957877397537, 53.31870473921299, 49.71449933946133, 46.29244476556778, 48.46218913793564, 49.694029837846756, 51.30297750234604, 48.96675646305084, 50.450960621237755, 50.31504951417446, 50.92360585927963, 49.89207901060581, 45.91537959873676, 44.490186274051666, 48.70539888739586, 51.246668323874474, 51.454634964466095, 47.05149203538895, 48.21660451591015, 50.68780571222305, 52.682018503546715, 53.64396348595619, 50.73944874107838, 51.01841077208519, 51.412658616900444, 50.743845105171204, 40.77188819646835, 37.018897980451584, 38.61010439693928, 36.21925748884678, 40.25380499660969, 49.57628555595875, 52.80295081436634, 52.725339978933334, 51.475602239370346, 52.99608305096626, 52.57317714393139, 55.83113372325897, 52.686650454998016, 54.62216779589653, 53.20753030478954, 56.784266978502274, 49.28483359515667, 53.30942563712597, 18.402330838143826, 31.902609318494797, 49.65767338871956, 42.97920495271683, 48.040054589509964, 45.220089107751846, 47.45383724570274, 43.084265515208244, 44.718816205859184, 46.41956314444542, 52.53182776272297, 48.71434360742569, 52.3782742023468, 43.65100510418415, 38.06471586227417, 39.25758585333824, 40.02569183707237, 45.63914582133293, 50.209525376558304, 49.91278409957886, 51.47227741777897, 50.87354734539986, 53.12693662941456, 50.30326634645462, 49.04137685894966, 49.599042534828186, 51.28870166838169, 45.737077966332436, 47.33217537403107, 47.99099922180176, 50.800082087516785, 46.68644942343235, 52.128285616636276, 54.657578095793724, 52.291410863399506, 53.03356423974037, 51.60126529633999, 52.98767790198326, 53.93486827611923, 45.36305643618107, 45.489931628108025, 49.6208343654871, 47.03736439347267, 49.495718479156494, 50.58120243251324, 49.70147363841534, 51.42982989549637, 52.45490089058876, 60.05882486701012, 62.41676174104214, 51.01534053683281, 40.613573491573334, 23.678419925272465, 16.907871030271053, 5.78253161162138, 6.367236161604524, 5.172062544152141, 0.9373812598641962, 2.5634749699383974, 2.990248119458556, 0.10209841362666339, 12.435303926467896, 33.50187510251999, 44.21582579612732, 31.409644670784473, 24.926643446087837, 40.14503203332424, 46.07476584613323, 44.395951330661774, 37.74783566594124, 5.819980027154088, 0.0196117384621175, 0.06539861729834229, 0.035369478064239956, 0.0577736362174619, 0.08474346090224572, 0.07570055473479442, 0.011827103789983084, 0.11007207052898593, 0.06192824941535946, 0.028139900277892593, 0.06135689218353946, 0.0749737917794846, 0.04294762962672394, 0.036303396700532176, 0.05593103567662183, 0.014471735903498484, 0.03911077066732105, 0.08957160651334561, 0.07804504377418198, 0.03860361663100775, 0.0364327307761414, 0.04017512546852231, 0.01265414388399222, 0.08010039950022474, 0.022479269064206164, 0.01692492081929231, 0.029679110848519485, 0.05788091366412118, 0.05545781634282321, 0.05270928355457727, 0.0460226034920197, 0.002316664763384324, 0.044626642265939154, 0.028151423975941725, 0.026614443559083156, 0.12943708570674062, 14.279705956578255, 47.22670443356037, 49.198965802788734, 34.94281478226185, 31.53415448963642, 28.177135325968266, 39.674324691295624, 34.45123516023159, 31.56421657651663, 10.613323543220758, 0.040685559797566384, 0.09712258804938756, 2.1678428119048476, 6.036009835079312, 10.124359130859375, 8.151127863675356, 8.47417987883091, 4.001101702451706, 13.239950649440289, 41.28700755536556, 55.58426097035408, 54.581825360655785, 53.48382107913494, 56.036778688430786, 54.10664565861225, 54.348495081067085, 52.529156506061554, 51.16614684462547, 48.56033407151699, 48.95995482802391, 50.03963649272919, 51.49200215935707, 50.30843406915665, 52.47001647949219, 52.81509876251221, 52.110156789422035, 52.80275322496891, 47.77004487812519, 47.17539958655834, 50.85289925336838, 53.20854105055332, 52.242188304662704, 49.57237936556339, 47.759587839245796, 52.30729021131992, 54.73690263926983, 55.856691151857376, 52.115275114774704, 52.620894983410835, 53.31600308418274, 53.77974919974804, 42.06113621592522, 39.182957857847214, 41.526995077729225, 37.60038837790489, 40.587719678878784, 50.5632483959198, 53.56221467256546, 54.454604387283325, 54.93945077061653, 55.12971796095371, 54.862706288695335, 57.21873566508293, 53.7319515645504, 57.36595876514912, 55.740709975361824, 58.433104902505875, 52.79080666601658, 53.711846843361855, 20.439279936254025, 33.72729800641537, 50.249024257063866, 43.202663362026215, 48.10602284967899, 43.03061239421368, 47.730663791298866, 43.97350899875164, 44.078953340649605, 47.42060802876949, 52.60111324489117, 52.01352037489414, 53.617889285087585, 43.798775374889374, 38.929108679294586, 41.60964824259281, 41.79245263338089, 47.00040377676487, 52.02777341008186, 52.41598337888718, 53.715243861079216, 52.970130443573, 55.15608474612236, 52.6164036244154, 48.10295261442661, 48.86438235640526, 50.27561902999878, 44.9106565117836, 47.30521582067013, 47.68074966967106, 50.55104725062847, 47.86879397928715, 52.36220106482506, 55.446658954024315, 54.16310302913189, 54.65296894311905, 52.78281569480896, 54.68310512602329, 55.20924769341946, 49.171113297343254, 48.500388488173485, 50.4814387857914, 47.2906170040369, 51.767046600580215, 53.36264558136463, 53.61136503517628, 55.06529621779919, 54.57739479839802, 61.15737631917, 63.93965542316437, 51.99292927980423, 41.83032140135765, 25.935990884900093, 14.47625420987606, 10.077382251620293, 5.000076172873378, 7.10406269878149, 2.6027418253943324, 3.2598446030169725, 3.412570282816887, 0.03955840445996728, 14.397074058651924, 34.11562576889992, 43.665269538760185, 41.14409722387791, 31.8807452917099, 46.85946173965931, 50.879729613661766, 50.68516105413437, 43.99777449667454, 8.3983663469553, 0.07447857147781178, 0.03874495123454835, 0.028556486322486307, 0.05439068590931129, 0.029719173835474066, 0.06612827462959103, 0.05652083898894489, 0.04359500133432448, 0.028924350372108165, 0.034911732509499416, 0.047604992214473896, 0.02914597607741598, 0.04560585417493712, 0.00782656508818036, 0.033916197062353604, 0.020761497762578074, 0.0888220002525486, 0.03864848687953781, 0.12585145857883617, 0.1613425783580169, 0.15718876296887174, 0.15537427127128467, 0.11152159626362845, 0.21487750491360202, 0.10400485742138699, 0.21490377694135532, 0.09356010108604096, 0.11139678928884678, 0.0856340529571753, 0.12915457977214828, 0.16304378863424063, 0.14148206828394905, 0.2592022897442803, 0.10261818417347968, 0.17526146897580475, 0.17141249816631898, 21.62124641239643, 56.07731111347675, 56.95213817059994, 41.931684762239456, 38.30995090305805, 35.097603276371956, 41.437692269682884, 31.83728512376547, 39.823637679219246, 13.028605040162802, 0.16397206694819033, 0.2595665358239785, 2.524547246284783, 12.530504018068314, 15.170936733484268, 15.661132279783487, 22.187528125941753, 22.244321778416634, 17.52070974558592, 41.82404413819313, 55.07760375738144, 56.66529916226864, 56.041399240493774, 57.63952508568764, 55.25896802544594, 55.53775146603584, 53.43681000173092, 52.5351107865572, 47.921519950032234, 50.55202379822731, 51.373144537210464, 52.0442683249712, 51.49712048470974, 54.455075562000275, 53.363017961382866, 54.81507584452629, 56.087756752967834, 50.36691673099995, 50.404929891228676, 53.02751876413822, 55.9649283438921, 53.28293725848198, 48.333953619003296, 48.12021128833294, 53.80986638367176, 56.2897577136755, 57.56638281047344, 52.394389137625694, 53.032108917832375, 54.848472252488136, 55.38319855928421, 44.937517270445824, 40.482845306396484, 43.371666893363, 39.8551531881094, 43.73298570513725, 53.164793998003006, 55.79777531325817, 57.57465876638889, 56.58223941922188, 57.532032653689384, 56.728881150484085, 59.5157466083765, 56.10654674470425, 59.37945172190666, 58.36781680583954, 59.41540539264679, 53.06946851313114, 53.73973734676838, 23.988249599933624, 38.18396106362343, 52.17517890036106, 45.97687549889088, 49.540396481752396, 47.00550690293312, 50.258113369345665, 45.103636756539345, 45.865302085876465, 47.735455334186554, 54.16301563382149, 54.13392439484596, 55.954551100730896, 47.61520318686962, 40.821581929922104, 44.35477674007416, 43.007312044501305, 49.31946873664856, 54.104479774832726, 53.94695162773132, 55.087308436632156, 54.91805411875248, 57.1814938634634, 53.263364508748055, 48.961569741368294, 49.574704840779305, 52.47266873717308, 47.09070973098278, 45.59042103588581, 49.08210687339306, 51.993233263492584, 47.12175786495209, 55.456508025527, 58.23965348303318, 57.203844264149666, 57.431292459368706, 56.73838064074516, 57.3478489369154, 58.418878465890884, 51.834447383880615, 49.096690490841866, 49.246584847569466, 48.208522349596024, 51.477984711527824, 52.66149580478668, 54.34222161769867, 57.76755541563034, 57.690066173672676, 61.586741879582405, 62.693223506212234, 56.00855380296707, 43.78603085875511, 28.442632779479027, 20.90719062834978, 16.785853877663612, 14.649414718151093, 11.002260223031044, 2.7826329600065947, 4.512880090624094, 3.725199457257986, 0.18598609662149101, 16.877199076116085, 46.922040581703186, 56.90604664385319, 43.7758170068264, 35.65531075000763, 51.08751006424427, 59.11419935524464, 56.55268460512161, 51.41363136470318, 11.205643359571695, 0.2364336294704117, 0.22693547507515177, 0.15929638815578073, 0.15460297203389928, 0.26669982180465013, 0.24478761479258537, 0.12670752592384815, 0.18469805479981005, 0.12005259122815914, 0.07752844219794497, 0.12396595819154754, 0.14663021313026547, 0.13810741889756173, 0.12081736698746681, 0.2138607032247819, 0.12398975144606084, 0.1325855136383325, 0.15598134807078168], [0.10411772324005142, 0.13251837895950302, 0.03590273343434092, 0.04507511097472161, 0.02945858723251149, 0.005803182939416729, 0.03438454048591666, 0.07182051762356423, 0.054515630181413144, 0.028962923497601878, 0.016850527936185244, 0.052310223327367567, 0.0735150559921749, 0.022433710473706014, 0.06671356939477846, 0.03929382510250434, 0.044012173675582744, 0.6412605370860547, 14.017295837402344, 40.06176330149174, 51.96433201432228, 38.197575733065605, 30.78312858939171, 33.47176171839237, 31.03663958609104, 25.629223845899105, 39.145115688443184, 2.9760770173743367, 0.049611377326073125, 0.7077503192704171, 17.583170793950558, 7.449898766353726, 5.620845537632704, 8.56212330982089, 8.553008548915386, 3.4907463379204273, 12.287271469831467, 44.572326466441154, 52.47247874736786, 55.04900649189949, 56.49885669350624, 52.047832533717155, 54.58281710743904, 54.15868766605854, 52.9661026597023, 54.94543544948101, 52.644905894994736, 53.06802079081535, 49.73790988326073, 50.635661110281944, 52.64543406665325, 50.83954676985741, 50.01710370182991, 46.549405977129936, 46.94659486413002, 41.45606428384781, 38.514094948768616, 45.00605799257755, 50.8537732064724, 52.3751849681139, 50.1353495568037, 48.706766813993454, 49.18802998960018, 49.682949632406235, 50.379159674048424, 47.05517403781414, 51.51845633983612, 49.85506519675255, 49.135801792144775, 36.98661111295223, 36.3545074313879, 36.0999096930027, 38.53885442018509, 44.73935030400753, 53.321041613817215, 49.40946690738201, 52.615191489458084, 51.25630080699921, 50.40818631649017, 48.82706455886364, 50.451097413897514, 49.03895638883114, 51.081031411886215, 47.845596224069595, 50.417484417557716, 44.620253294706345, 53.9627929776907, 19.7574882209301, 29.44021414965391, 48.71793061494827, 42.95456327497959, 48.95743936300278, 43.898968398571014, 48.260214775800705, 46.32619075477123, 47.76668965816498, 45.303601026535034, 46.80472567677498, 50.52278056740761, 54.939154386520386, 47.44524210691452, 38.83464574813843, 39.00242194533348, 37.70519435405731, 39.50644209980965, 49.449482560157776, 52.520770356059074, 53.412487506866455, 51.60810872912407, 51.48363120853901, 46.45964339375496, 47.250160574913025, 43.51672790944576, 42.97260470688343, 48.62798944115639, 50.283864587545395, 46.79988853633404, 47.87220999598503, 47.845999002456665, 54.3490232527256, 52.250376865267754, 49.61688257753849, 48.42228747904301, 48.86795416474342, 48.233768194913864, 49.65521492063999, 49.13939639925957, 51.651092022657394, 49.33537848293781, 49.89443488419056, 49.68966007232666, 52.08790138363838, 52.467827796936035, 52.0814873278141, 52.20456652343273, 50.352705493569374, 54.24846924841404, 61.0931483656168, 54.76215988397598, 23.767078667879105, 12.915653251111507, 10.551286172121763, 6.031540324911475, 9.07228298485279, 2.73227212484926, 13.187164831906557, 1.6104627144522965, 0.05957801615295466, 5.572096528485417, 32.115375101566315, 29.37151573598385, 24.936047941446304, 22.01758984476328, 25.111549124121666, 38.137584552168846, 45.247075259685516, 42.14693181216717, 8.124748729169369, 0.0752986446605064, 0.07919584764749743, 0.06775135159841739, 0.0066942137891601305, 0.08238326059654355, 0.027130232483614236, 0.05190435018448625, 0.06083711050450802, 0.04946154142089654, 0.014557045778929023, 0.0797250731557142, 0.09499320309259929, 0.10257533998810686, 0.05409385652455967, 0.06617382023250684, 0.035650748322950676, 0.014702142143505625, 0.04227742203511298, 0.04103688137547579, 0.05254685711406637, 0.08361886226339266, 0.061547145451186225, 0.026304413222533185, 0.0027698356734617846, 0.014168349644023692, 0.040919184175436385, 0.03811671951552853, 0.07701211521634832, 0.050331434977124445, 0.033791275054682046, 0.027431306953076273, 0.0460547607508488, 0.08295573847135529, 0.05800068145617843, 0.022742913315596525, 0.8969652629457414, 18.74328464269638, 48.19736994802952, 59.00474242866039, 43.39842885732651, 38.92204865813255, 40.820065811276436, 32.58630283176899, 23.47049318253994, 38.35073411464691, 3.8948757899925113, 0.05225631743087433, 1.1085729394108057, 14.624555502086878, 6.805460946634412, 8.028459046036005, 9.808760415762663, 9.584118369966745, 5.300413956865668, 13.293625619262457, 43.596265241503716, 52.56804741919041, 54.994224831461906, 56.99154205620289, 54.173191487789154, 56.42205901443958, 56.568294167518616, 54.188508465886116, 54.244323670864105, 52.26089470088482, 53.83947439491749, 50.124991312623024, 51.224314123392105, 54.065908044576645, 53.361817225813866, 51.95123791694641, 50.127958953380585, 48.98851789534092, 43.31044837832451, 40.369679778814316, 48.09178501367569, 52.03538820147514, 53.210060968995094, 51.15897662937641, 50.7819152623415, 49.2323812097311, 49.95096065104008, 51.22736155986786, 48.285631611943245, 51.352591440081596, 52.84535273909569, 50.40865369141102, 39.008615612983704, 37.72582344710827, 37.87021569907665, 39.5702862739563, 46.24604545533657, 54.545989483594894, 51.98871150612831, 54.879839569330215, 52.07924544811249, 52.57289215922356, 50.18023654818535, 51.951986476778984, 50.46491727232933, 52.64301359653473, 47.80456222593784, 51.649309918284416, 44.251399487257004, 53.76141898334026, 20.674842596054077, 32.48215802013874, 52.380523681640625, 45.8937169611454, 51.507896706461906, 46.084774509072304, 49.465544298291206, 46.81245066225529, 48.54350097477436, 45.035669803619385, 46.05452053248882, 50.962257385253906, 57.7116984128952, 49.28516797721386, 40.24061970412731, 39.51976418495178, 39.289899319410324, 41.69670157134533, 52.43271008133888, 52.25592836737633, 55.47209098935127, 53.11926104128361, 53.52695636451244, 46.73756808042526, 48.63213501870632, 44.93099682033062, 44.19485092163086, 49.91973392665386, 50.63069477677345, 47.77170538902283, 48.120344281196594, 47.57486455142498, 56.216497644782066, 53.797220662236214, 52.476582527160645, 51.01680725812912, 50.65694376826286, 50.398386642336845, 51.94081127643585, 50.31514070928097, 53.14147464931011, 48.49470779299736, 50.5847704410553, 48.948578238487244, 52.40182913839817, 52.45936185121536, 54.76602427661419, 54.799078702926636, 53.814380541443825, 52.29893445968628, 61.79460972547531, 52.161617428064346, 29.240388572216034, 11.70276403427124, 9.555700644850731, 9.199139177799225, 6.574540687724948, 6.257977774366736, 10.455956887453794, 2.3589689936488867, 0.05512729716429021, 6.561155905947089, 36.36112667620182, 35.14663964509964, 29.7003310918808, 25.41676204651594, 30.504649132490158, 44.879456385970116, 49.48880285024643, 50.186973586678505, 11.890846341848373, 0.11623125057667494, 0.08852551225572824, 0.013605905605800217, 0.05972238242975436, 0.019912124589609448, 0.02430140673823189, 0.0899971836770419, 0.055347221496049315, 0.011595562064030673, 0.02360279715503566, 0.02925049644545652, 0.04724761842226144, 0.06703275226755068, 0.06795503402827308, 0.02115730181685649, 0.02946596418041736, 0.04576435836497694, 0.028107197540521156, 0.2237930882256478, 0.25545013952068985, 0.16847491438966244, 0.16924432857194915, 0.07652860600501299, 0.13434205844532698, 0.14924364164471626, 0.12420597617165186, 0.2559260342968628, 0.1342167245456949, 0.2073869638843462, 0.14079654647503048, 0.15292552532628179, 0.18067358090775087, 0.15659985394449905, 0.1684881394612603, 0.10153906434425153, 1.643055584281683, 28.16607601940632, 57.756532207131386, 65.37880539894104, 49.68402497470379, 44.14381206035614, 48.54144908487797, 40.72096332907677, 35.58410257101059, 49.006882309913635, 5.110834054648876, 0.1259170050616376, 1.6909218532964587, 19.504953771829605, 13.546132519841194, 17.501136995851994, 17.535850033164024, 18.978598415851593, 8.998489994555712, 15.794523172080517, 46.28976970911026, 55.59051923453808, 57.11389169096947, 59.11182448267937, 54.96232554316521, 58.80651846528053, 58.34194399416447, 54.3055459856987, 54.28667239844799, 50.49652397632599, 54.90484602749348, 49.513976499438286, 52.83393055200577, 57.00620926916599, 56.15937530994415, 55.21295249462128, 52.6541355997324, 51.27389766275883, 44.986147060990334, 41.92531630396843, 51.065106466412544, 54.77205075323582, 55.583235025405884, 53.329066783189774, 50.801609605550766, 50.47247126698494, 49.924829453229904, 51.98876850306988, 47.90461465716362, 52.3948223143816, 55.03557041287422, 53.16818341612816, 40.07620632648468, 39.183748215436935, 40.1953337341547, 42.897395342588425, 48.857295736670494, 57.984417378902435, 54.26948592066765, 55.62459580600262, 53.082376420497894, 51.61463677883148, 50.75334079563618, 50.89570015668869, 50.35666488111019, 52.07430191338062, 48.42533491551876, 52.77610905468464, 45.38127265870571, 53.895209804177284, 23.4989707544446, 36.64056368172169, 53.38226392865181, 48.22443589568138, 54.47863049805164, 50.027233958244324, 52.517274543643, 49.23217222094536, 49.8744897544384, 48.25644537806511, 47.72510468959808, 52.06341549754143, 60.578196197748184, 51.67659245431423, 42.87993907928467, 42.7462774515152, 40.51856338977814, 43.34984466433525, 53.848749697208405, 55.468541979789734, 56.704672649502754, 55.18672250211239, 55.590200051665306, 48.54021035134792, 51.00480370223522, 48.10577966272831, 47.552753537893295, 49.64966341853142, 50.73816440999508, 47.59690336883068, 49.423077777028084, 48.11218611896038, 58.96699145436287, 56.67863264679909, 54.10322204232216, 53.399298414587975, 54.03951086103916, 52.56489738821983, 54.10189591348171, 53.882476687431335, 53.4670639783144, 51.62105083465576, 52.879444509744644, 49.246292263269424, 52.49542951583862, 53.76041583716869, 55.969548895955086, 57.23309129476547, 55.62133178114891, 52.97620251774788, 63.19890417158604, 56.232969760894775, 28.917278610169888, 17.445870861411095, 14.009887184947729, 13.12137421220541, 19.57311451435089, 10.674199126660824, 16.604377515614033, 1.9772915868088603, 0.06386042718077078, 7.20161771401763, 45.521823316812515, 41.16140529513359, 35.73987141251564, 31.728445664048195, 37.566440999507904, 50.95096439123154, 56.65691301226616, 58.13853330910206, 16.49996481835842, 0.2715929498663172, 0.1455163088394329, 0.12301876995479688, 0.16580852621700615, 0.1619270196533762, 0.09862871738732792, 0.21531385806156322, 0.12900003493996337, 0.16553050285438076, 0.08183512516552582, 0.11075336209614761, 0.18271344801178202, 0.13473450613673776, 0.2215029689250514, 0.12042789530823939, 0.13415677385637537, 0.12891020538518205, 0.16368510812753811], [0.04409375054819975, 0.04215474873490166, 0.06109073947300203, 0.0649881131539587, 0.06960053127841093, 0.06005111303238664, 0.04868928110226989, 0.020507232402451336, 0.006673609450444928, 0.05014568654587492, 0.07873560476582497, 0.01673906848736806, 0.07347759237745777, 0.03704407863551751, 0.04208846752590034, 0.06333587720291689, 0.0857862971315626, 2.294565299525857, 23.725280910730362, 48.402733728289604, 42.762996554374695, 35.45319199562073, 23.263313099741936, 10.610860325396061, 24.967151172459126, 42.9405914247036, 29.190362356603146, 0.8507117698900402, 0.027610873294179328, 2.678734422661364, 7.837837524712086, 2.3738307086750865, 7.430591052398086, 4.835976278409362, 5.545510780066252, 3.592593460343778, 20.96888791769743, 41.29186749458313, 51.28467008471489, 55.93076057732105, 53.96710194647312, 51.89504273235798, 52.83092871308327, 53.50354962050915, 54.344680085778236, 52.05192871391773, 53.11770312488079, 50.45136719942093, 50.05918264389038, 54.032884016633034, 50.13958252966404, 48.823257163167, 48.04880931973457, 46.03414602577686, 43.156161457300186, 40.71720153093338, 37.97154486179352, 38.95181246101856, 48.81865940988064, 51.353765577077866, 53.086373805999756, 51.43839083611965, 51.184173077344894, 50.05969561636448, 51.2275667488575, 49.79706130921841, 51.11869119107723, 52.91469141840935, 42.994620725512505, 35.7782531529665, 36.95753127336502, 38.53400208055973, 41.009413450956345, 51.436293348670006, 53.15396077930927, 42.795796394348145, 48.02599914371967, 45.59706687927246, 49.098164811730385, 46.858412995934486, 47.56162986159325, 44.31353375315666, 48.101900070905685, 46.39078728854656, 45.307461619377136, 44.11860041320324, 46.35113641619682, 20.72021786123514, 33.691481128335, 53.45913380384445, 46.730375066399574, 48.819240778684616, 47.791768312454224, 48.61009240150452, 49.31363984942436, 47.664034366607666, 48.3305300027132, 47.995756566524506, 47.49866724014282, 51.925722286105156, 51.07888072729111, 41.3724459707737, 36.71911686658859, 40.512267127633095, 38.7771662324667, 40.39929158985615, 48.98665599524975, 52.18444660305977, 51.96807861328125, 52.33395718038082, 53.84069412946701, 46.23480185866356, 47.17349208891392, 49.57405887544155, 52.50357247889042, 51.19179926812649, 50.33627897500992, 48.09139743447304, 53.596374839544296, 53.50182831287384, 49.747006595134735, 45.162480399012566, 42.085333317518234, 43.163776248693466, 48.779931887984276, 50.574374198913574, 53.247561156749725, 51.30342207849026, 54.21147063374519, 53.34211528301239, 51.34831666946411, 49.436369463801384, 54.01447020471096, 49.953753501176834, 53.9432468265295, 45.69801606237888, 40.86616113781929, 37.70580232143402, 38.89988824725151, 33.81404735147953, 14.770347978919744, 12.752433959394693, 4.24733561463654, 4.762095892801881, 5.1827603951096535, 5.716648371890187, 0.33550617343280464, 0.13644903054228052, 2.0611875224858522, 26.02185867726803, 23.360639177262783, 35.50192818045616, 29.309014789760113, 29.755319841206074, 44.21981558203697, 45.220054909586906, 44.38747398555279, 17.56044991314411, 0.24263004306703806, 0.16194011113839224, 0.06143585669633467, 0.08139537298120558, 0.04990546447515953, 0.07310458153369837, 0.030253507175075356, 0.008784333567746216, 0.05317774572176859, 0.04876719176536426, 0.04240950205712579, 0.09860177000518888, 0.06018282198056113, 0.05353190230380278, 0.050162911793449894, 0.0250891018731636, 0.05134670784173068, 0.053635350268450566, 0.12331696489127353, 0.00980642027570866, 0.06236185290617868, 0.04266476375050843, 0.011083764966315357, 0.030209555334295146, 0.05338520939403679, 0.03798816840571817, 0.03738612707820721, 0.08790693216724321, 0.03741275162610691, 0.05763006403867621, 0.04457593873667065, 0.008940188290580409, 0.019800015761575196, 0.06337181199342012, 0.08992040107841603, 2.749700602144003, 28.87671958655119, 54.154823273420334, 49.283887445926666, 40.053358152508736, 29.127010256052017, 20.520717166364193, 29.32616136968136, 38.36758241057396, 30.587412491440773, 1.2916956818662584, 0.22511307208333164, 3.732017478905618, 10.011908914893866, 5.5110399797558784, 9.64343698695302, 12.187649365514517, 6.674811607226729, 2.93687523342669, 23.075549975037575, 42.02923312783241, 53.93147125840187, 55.82047909498215, 58.432496935129166, 53.81559647619724, 56.442950293421745, 54.77238513529301, 56.26807227730751, 52.51510865986347, 52.986112385988235, 51.39202572405338, 51.46354928612709, 53.98734726011753, 52.819092348217964, 51.31796769797802, 51.07239827513695, 47.59527325630188, 45.40236532688141, 42.25335270166397, 39.682068675756454, 42.54591040313244, 50.59902727603912, 52.865510657429695, 54.75080989301205, 53.022795617580414, 52.019242867827415, 50.429575368762016, 51.100873947143555, 49.35312733054161, 54.36404764652252, 53.241945058107376, 45.874478593468666, 36.54752567410469, 38.623289689421654, 39.631991162896156, 44.148428812623024, 52.94434502720833, 56.585640236735344, 44.338669404387474, 47.41957828402519, 44.88813132047653, 49.84245367348194, 46.04245238006115, 47.20619693398476, 44.99857999384403, 47.79529072344303, 45.6555837392807, 46.06421001255512, 44.138336554169655, 50.57050980627537, 21.615288332104683, 34.73440356552601, 56.51008129119873, 49.69176895916462, 51.40454985201359, 50.12456573545933, 51.67473815381527, 52.30543591082096, 50.131834745407104, 48.77061478793621, 49.1759542375803, 47.619485557079315, 53.8036423176527, 53.55792090296745, 43.42317692935467, 39.390400126576424, 41.157567501068115, 41.34322553873062, 42.02632628381252, 52.43720144033432, 53.75207528471947, 54.52029526233673, 53.60450640320778, 53.92587795853615, 48.390129804611206, 49.42911185324192, 51.724625676870346, 53.40776056051254, 53.65445092320442, 52.8898711502552, 49.608542025089264, 54.635265693068504, 54.713473096489906, 50.96232198178768, 47.30749569833279, 44.10876274108887, 45.29673099517822, 51.04766920208931, 53.83403308689594, 56.14411912858486, 53.66554632782936, 54.44130890071392, 53.530326783657074, 51.733182817697525, 50.32209053635597, 55.67899368703365, 53.52024592459202, 55.70477910339832, 49.498059153556824, 45.09928219020367, 37.00573168694973, 38.973836079239845, 32.56639949977398, 16.732354648411274, 8.515249025076628, 6.168281212449074, 8.509169351309538, 9.744871594011784, 8.912151027470827, 0.24405719304922968, 0.14791731984587386, 1.8328993348404765, 30.410824567079544, 31.621470004320145, 40.12122631072998, 32.58396215736866, 36.19158357381821, 47.33327351510525, 52.19063647091389, 51.08622193336487, 21.558694168925285, 0.8450550609268248, 0.009700305217847927, 0.029945575261081103, 0.03898134011251386, 0.0142308264184976, 0.023779973780619912, 0.01625262593734078, 0.06722079022438265, 0.0691959865798708, 0.012332911755947862, 0.06089864567911718, 0.05073480337159708, 0.02276506827911362, 0.10135581323993392, 0.04882637062110007, 0.05440183296741452, 0.033172821131302044, 0.01757168025505962, 0.1668318736483343, 0.11396175556001253, 0.20269041589926928, 0.1584631492733024, 0.1380927095306106, 0.106896346405847, 0.21868926443858072, 0.09595494484528899, 0.1999749123933725, 0.16614090447546914, 0.11261631603701971, 0.10778157273307443, 0.1751673498074524, 0.05892610992304981, 0.10754917660960928, 0.14045291725778952, 0.1919073218596168, 3.616079525090754, 36.268476247787476, 65.00723093748093, 54.27238516509533, 47.33716070652008, 34.54927749931812, 22.29437079280615, 34.97204281389713, 56.62361919879913, 36.70687012374401, 1.5694008115679026, 0.3875835664803162, 4.442924419417977, 11.830752566456795, 7.404892556369305, 17.715413197875023, 14.066815730184317, 12.973612491041422, 10.240050572901964, 29.26686555147171, 45.50942838191986, 55.67255303263664, 58.66707734763622, 60.29033124446869, 55.342023968696594, 56.67307734489441, 57.74029567837715, 57.366627529263496, 53.888898342847824, 52.29870647192001, 50.43114848434925, 51.01395361125469, 56.113910749554634, 56.112975999712944, 54.19345200061798, 52.8777763992548, 50.73752984404564, 48.07491011917591, 44.887268766760826, 42.477571070194244, 43.8809497654438, 53.87023374438286, 53.73731307685375, 56.757163032889366, 55.20171269774437, 54.44567486643791, 52.266601994633675, 53.121977895498276, 50.2767513692379, 55.269983634352684, 56.2019482254982, 45.94929277896881, 39.889415949583054, 39.98603716492653, 42.688315361738205, 46.3166418671608, 55.076460018754005, 57.89118558168411, 44.82736498117447, 46.6473913192749, 45.20904690027237, 49.46715921163559, 47.8305946290493, 48.50617177784443, 44.36920456588268, 49.318837970495224, 47.69979424774647, 45.93341343104839, 44.182463586330414, 50.80697111785412, 24.555243775248528, 37.86523036658764, 54.70346823334694, 52.19678074121475, 54.3569990247488, 52.591104581952095, 53.92393246293068, 56.01994939148426, 51.39467418193817, 50.61867602169514, 50.47428756952286, 50.5220890045166, 56.510085090994835, 56.74957104027271, 45.41515924036503, 41.039177253842354, 43.544075042009354, 43.89370948076248, 43.24506148695946, 53.78006458282471, 56.75153933465481, 56.84437595307827, 54.60177809000015, 56.32626235485077, 50.39299853146076, 50.75949266552925, 54.37386631965637, 56.047976687550545, 56.11573085188866, 53.41668248176575, 50.2453688532114, 56.12296566367149, 57.825468108057976, 54.12871487438679, 50.530452355742455, 47.660166174173355, 47.466889545321465, 54.575118720531464, 56.23385891318321, 58.655742555856705, 55.69817505776882, 56.53292566537857, 55.255715399980545, 52.78032682836056, 51.90458782017231, 56.37610048055649, 53.02954025566578, 55.32339736819267, 51.758633852005005, 46.02803975343704, 40.02222642302513, 40.93719832599163, 36.28686346113682, 19.04380291700363, 19.30478811264038, 12.193262614309788, 9.988102242350578, 9.848437886685133, 8.993023987859488, 0.7448719523381442, 0.2886130381375551, 2.6395552000030875, 36.68264642357826, 37.60576508939266, 48.068199679255486, 40.63739821314812, 40.91123811900616, 56.73733189702034, 57.48442500829697, 60.00434719026089, 28.83821815252304, 1.7738163052126765, 0.22060966060962528, 0.08065349989919923, 0.20047727215569466, 0.21961911610560492, 0.07878713207901455, 0.11684832410537638, 0.15854570578085259, 0.1293573048315011, 0.1142706819518935, 0.2017293791868724, 0.20473614596994594, 0.1515254785772413, 0.17773918836610392, 0.09305458719609305, 0.1672744459938258, 0.14783620310481638, 0.12430183196556754], [0.08438920413027517, 0.043837512930622324, 0.11396751462598331, 0.04198494163574651, 0.02558909047365887, 0.030888152905390598, 0.01801286849513417, 0.023948049820319284, 0.010002347262343392, 0.05185116046050098, 0.03268240252509713, 0.010305611995136132, 0.013256751099106623, 0.050967559436685406, 0.023899615407572128, 0.09106131954467855, 0.06183795601828024, 2.3379506589844823, 28.26180048286915, 49.44892019033432, 38.90684947371483, 38.31363670527935, 21.549340970814228, 19.413806162774563, 34.04652647674084, 39.0785850584507, 17.78088938444853, 0.3932363272178918, 1.9816194358281791, 6.51750479824841, 0.8356973505578935, 6.149439448490739, 5.307511975988746, 12.112614791840315, 5.823969338089228, 9.813589006662369, 37.1481404453516, 53.95563796162605, 58.08468259871006, 52.84415580332279, 54.74321790039539, 49.68380458652973, 50.68547643721104, 51.07782058417797, 53.24499249458313, 56.712279841303825, 50.4286178201437, 49.62968789041042, 50.17400488257408, 49.639457166194916, 51.80586151778698, 46.60007245838642, 44.41847272217274, 40.197480618953705, 41.518521532416344, 38.31773668527603, 39.36987742781639, 37.66043655574322, 41.959981843829155, 46.27197906374931, 51.29161611199379, 50.003679022192955, 51.52515158057213, 51.027632877230644, 51.499852538108826, 52.74522811174393, 52.43779040873051, 44.66640181839466, 36.96149066090584, 36.41936235129833, 37.870063707232475, 40.200087279081345, 42.94439882040024, 49.41263973712921, 53.6026407033205, 46.788576543331146, 55.232008472085, 52.21891835331917, 53.04330691695213, 52.09462322294712, 54.19472113251686, 49.50079880654812, 48.90338346362114, 45.56679390370846, 47.396144941449165, 41.26933090388775, 50.887386202812195, 23.25918462127447, 39.46030117571354, 55.156783908605576, 49.39321517944336, 50.94160169363022, 46.97029039263725, 51.522841304540634, 51.18342451751232, 50.70884898304939, 49.15533274412155, 48.54804553091526, 48.94233897328377, 51.07129633426666, 48.90492998063564, 38.9791139960289, 37.92335964739323, 39.0057847648859, 39.08213406801224, 38.64413157105446, 40.83325870335102, 47.19537891447544, 50.050902888178825, 51.12411729991436, 53.010970652103424, 53.40870290994644, 51.49452522397041, 51.40315532684326, 50.80082684755325, 50.33584959805012, 47.60002300143242, 51.45828656852245, 52.505935952067375, 50.27548223733902, 44.59568381309509, 40.16971930861473, 41.34014010429382, 42.77510650455952, 43.819982036948204, 46.54262714087963, 49.90252085030079, 51.189283803105354, 50.82904793322086, 51.61417320370674, 55.29001235961914, 52.24219590425491, 52.406882867217064, 51.30819842219353, 47.712705954909325, 55.50369009375572, 41.84870481491089, 34.228893890976906, 25.12376356869936, 21.873752363026142, 15.804951712489128, 6.420480329543352, 7.2205383237451315, 5.49388200044632, 3.7601385824382305, 10.813372358679771, 3.675574120134115, 0.09341625060187653, 0.1208949214196764, 17.065391577780247, 31.264433562755585, 32.07875266671181, 15.68720268085599, 18.176750242710114, 32.789040952920914, 44.30101342499256, 48.53851184248924, 28.87019533663988, 2.215472306124866, 0.06359354345477186, 0.052946622381568886, 0.01743960765452357, 0.006411440217561903, 0.022388229808711912, 0.02126508392393589, 0.06036861494067125, 0.07089280334184878, 0.01900260591355618, 0.0238305919629056, 0.07843484199838713, 0.04360316495876759, 0.024813137970340904, 0.07521455932874233, 0.02187466361647239, 0.023405933206959162, 0.018601968622533605, 0.03210611001122743, 0.09541457227896899, 0.03480719358776696, 0.05148616481164936, 0.050947246854775585, 0.02027271744736936, 0.06552371371071786, 0.03432970690482762, 0.02006420549150789, 0.05993353086523712, 0.018957924912683666, 0.020125143237237353, 0.03390627454791684, 0.012782220019289525, 0.07935535002616234, 0.05015069604269229, 0.03643111289420631, 3.0604636017233133, 34.28371734917164, 57.41143852472305, 43.4511624276638, 45.48216864466667, 25.731305368244648, 19.120760187506676, 35.53059384226799, 40.97659841179848, 20.95672857016325, 0.4122804896906018, 2.1570817893370986, 7.110255416482687, 2.1523812040686607, 7.696461835876107, 9.174663741141558, 10.630103442817926, 4.224960990250111, 8.25877133756876, 37.64664709568024, 54.30987015366554, 57.75342397391796, 53.30632500350475, 56.33999861776829, 53.153918981552124, 51.90426103770733, 54.19148750603199, 55.34226715564728, 55.111034363508224, 51.194223538041115, 50.097397193312645, 51.43761187791824, 50.733479261398315, 54.145426377654076, 49.78783920407295, 46.753922402858734, 44.21209439635277, 44.21259596943855, 40.3217301517725, 42.158901169896126, 39.437274411320686, 45.304322987794876, 48.52469198405743, 51.92954868078232, 51.841537803411484, 54.031067714095116, 51.819920763373375, 52.88450583815575, 54.01826240122318, 54.03529308736324, 47.15980142354965, 39.55817632377148, 38.641213327646255, 39.34356763958931, 42.01537147164345, 44.9937504529953, 52.31531538069248, 55.97073823213577, 48.316501155495644, 54.05440226197243, 52.55851373076439, 54.55161318182945, 52.43685945868492, 53.100205063819885, 50.63351422548294, 49.26524564623833, 47.0845502614975, 47.82841734588146, 44.07312825322151, 51.92590467631817, 23.581152744591236, 40.557648092508316, 56.940567791461945, 49.88390564918518, 52.13031090795994, 47.61378966271877, 52.86916986107826, 52.53997452557087, 52.33880192041397, 52.635129019618034, 51.089546754956245, 50.66312603652477, 52.77043975889683, 51.726160794496536, 41.75416208803654, 39.718770906329155, 39.96646821498871, 40.3231056779623, 39.93288181722164, 42.618342116475105, 50.231066420674324, 52.93495573103428, 54.24463525414467, 54.70890574157238, 54.267810210585594, 53.64725410938263, 54.01073880493641, 53.218268528580666, 53.016081377863884, 50.17539940774441, 53.15055996179581, 54.53393653035164, 51.72600880265236, 46.513304114341736, 41.741759553551674, 42.02741302549839, 43.85748602449894, 47.48629130423069, 48.247831240296364, 52.13271997869015, 53.31568010151386, 52.52866253256798, 53.94565969705582, 54.25285041332245, 53.0928410589695, 54.22743357717991, 50.01541659235954, 49.6349012106657, 55.61929129064083, 45.31582497060299, 38.61058697104454, 28.923135995864868, 21.855728030204773, 14.521873611956835, 7.559353318065405, 11.792397424578667, 8.553503472357988, 2.9535881616175175, 17.101654931902885, 3.929230459034443, 0.07976168330060318, 0.196544973005075, 21.328544318675995, 32.71970607340336, 36.52318798005581, 20.57639367878437, 24.065864235162735, 40.34881889820099, 49.36987683176994, 55.218636989593506, 34.05308112502098, 2.9235360492020845, 0.04350709023128729, 0.09403691612533294, 0.035899126596632414, 0.018278433053637855, 0.05808748675917741, 0.04336079437052831, 0.041211931747966446, 0.029378238614299335, 0.06845032854471356, 0.03158134852128569, 0.03578904383175541, 0.0281272837673896, 0.03862515375658404, 0.0438643415691331, 0.034801575529854745, 0.0116023063310422, 0.012667132396018133, 0.1210014641401358, 0.17920441052410752, 0.15573272859910503, 0.18347803823417053, 0.15235655038850382, 0.10586853124550544, 0.15310044953366742, 0.13783842005068436, 0.18132193596102297, 0.11353057518135756, 0.14410024654353037, 0.09093978544115089, 0.17596610850887373, 0.07801886080414988, 0.19553983787773177, 0.19063133251620457, 0.2132041845470667, 4.332129014655948, 41.01005561649799, 64.18516784906387, 51.0735572129488, 51.63590423762798, 32.094639614224434, 30.845905020833015, 46.00581094622612, 49.46908190846443, 25.507102198898792, 0.42611388489603996, 2.6027845731005073, 9.10834589973092, 4.100459245964885, 15.346821695566177, 16.306171417236328, 23.001930825412273, 12.602380961179733, 16.99951071292162, 43.86024847626686, 57.24197901785374, 58.1177294254303, 54.899150133132935, 59.955139830708504, 55.5332563072443, 55.20732119679451, 56.27167448401451, 56.253549456596375, 57.15009234845638, 51.0176470130682, 50.20011328160763, 50.76135836541653, 52.04656720161438, 57.65865705907345, 53.324883207678795, 49.67047490179539, 45.13754613697529, 47.46929481625557, 42.23458170890808, 44.79186728596687, 41.29419296979904, 46.53723523020744, 49.93231885135174, 54.65616077184677, 52.39412695169449, 55.48371836543083, 54.49854522943497, 55.04245564341545, 57.118238657712936, 56.035380363464355, 49.17310059070587, 40.71421109139919, 40.38101077079773, 41.725561022758484, 44.03992563486099, 47.98667125403881, 54.76202309131622, 60.641550198197365, 49.46126192808151, 54.4124798476696, 56.53254948556423, 57.0441198348999, 55.38282237946987, 56.58635459840298, 52.62555733323097, 50.56895948946476, 47.80691809952259, 48.35577964782715, 45.614709332585335, 52.298501282930374, 29.091807045042515, 44.98458534479141, 58.87576214969158, 53.926261737942696, 54.12485808134079, 50.64312011003494, 56.70950599014759, 54.41150709986687, 54.81288716197014, 54.94521886110306, 52.67736375331879, 51.62045046687126, 55.27903474867344, 52.81408041715622, 42.52437315881252, 42.32795409858227, 41.822839602828026, 43.198050409555435, 42.246186286211014, 45.64123570919037, 52.38875783979893, 54.53465849161148, 55.999483689665794, 58.22948522865772, 58.26931469142437, 56.367239356040955, 56.32891461253166, 55.19958861172199, 54.690438732504845, 51.692270413041115, 57.2979424148798, 55.857762694358826, 54.61333326995373, 48.19969542324543, 44.167518988251686, 44.695930033922195, 47.12941065430641, 50.10112099349499, 52.306940630078316, 54.77301970124245, 56.34374141693115, 56.234539076685905, 55.41171982884407, 57.18152426183224, 53.914812952280045, 52.07206763327122, 52.47865341603756, 51.30496859550476, 57.37724795937538, 47.66920208930969, 40.591758862137794, 32.80241623520851, 25.568596199154854, 19.44285750389099, 11.030682697892189, 16.816309243440628, 15.293766092509031, 10.474484693259, 21.836966536939144, 4.605770381167531, 0.1788204233162105, 0.44118182791862637, 27.516688965260983, 43.385528549551964, 43.41912254691124, 25.20038265734911, 26.340030804276466, 45.64562827348709, 56.6985359787941, 60.9700957685709, 41.24768726527691, 4.519891664385796, 0.18212369293905795, 0.12658597697736695, 0.13954687368823215, 0.1415623983484693, 0.16220628982409835, 0.13683619414223358, 0.20679545734310523, 0.21308860246790573, 0.17279054765822366, 0.12641687120776623, 0.22353909560479224, 0.17517160973511636, 0.1107029702689033, 0.19185544573701918, 0.12555396126117557, 0.13048577005974948, 0.07270722824614495], [0.06750856540747918, 0.025485150836175308, 0.052524392303894274, 0.05655215019942261, 0.038983648191788234, 0.020185311004752293, 0.06004936898534652, 0.035790739639196545, 0.05741196910094004, 0.10895893807173707, 0.03746574839169625, 0.04952633833454456, 0.06663076055701822, 0.07785073466948234, 0.05911206244491041, 0.020515780088317115, 0.01987060699320864, 3.4264948731288314, 26.89128242433071, 49.13101024925709, 47.983297035098076, 30.64679380506277, 18.926463313400745, 28.2389048114419, 29.388725012540817, 35.28799585998058, 11.754692997783422, 0.22182943968800828, 0.7155162713024765, 2.1210024878382683, 1.8833254789933562, 5.589319104328752, 6.257195016369224, 11.855751425027847, 4.532441915944219, 19.979390613734722, 52.175885662436485, 51.210893243551254, 53.072352558374405, 52.42670640349388, 53.650054559111595, 50.833577290177345, 52.281436398625374, 50.09378358721733, 55.739543437957764, 51.021545603871346, 52.16564141213894, 49.48240019381046, 51.844668835401535, 50.32773703336716, 50.52074007689953, 47.18601241707802, 39.8358616232872, 37.05502264201641, 40.861346796154976, 39.81088176369667, 40.84536865353584, 38.439884930849075, 37.90187560021877, 39.304889515042305, 44.367490857839584, 44.6064942330122, 46.86956159770489, 47.38601468503475, 47.44041636586189, 47.06638723611832, 44.93568196892738, 36.42942041158676, 37.676110714673996, 36.070149689912796, 38.94892081618309, 37.063952162861824, 45.993055030703545, 51.42763741314411, 48.61217088997364, 52.20355577766895, 51.21019408106804, 51.168335527181625, 48.93114857375622, 48.6960019916296, 50.993016734719276, 49.95963558554649, 50.38015902042389, 46.21226906776428, 46.21937848627567, 40.66485933959484, 50.56583605706692, 24.22204915434122, 37.463401928544044, 55.206390246748924, 48.087400048971176, 46.69685706496239, 40.69887511432171, 44.39142197370529, 45.059654116630554, 50.07815882563591, 50.11103846132755, 52.20437653362751, 51.72746792435646, 51.27263993024826, 47.85342000424862, 39.87914130091667, 37.53140687942505, 39.405226930975914, 39.12842318415642, 39.297970086336136, 38.88433188199997, 38.7113119661808, 40.5072133988142, 45.0969073176384, 48.49249251186848, 49.47913236916065, 49.23765532672405, 48.64674523472786, 46.727924197912216, 47.434321492910385, 48.98981362581253, 48.4284545481205, 47.6653490960598, 41.96596272289753, 39.44584295153618, 37.28236824274063, 39.7917003929615, 40.99851943552494, 42.982693165540695, 45.86856231093407, 42.93565168976784, 48.87053802609444, 49.64266039431095, 52.35909283161163, 52.594319209456444, 51.11141838133335, 46.81715480983257, 53.173788115382195, 51.11485719680786, 48.97213317453861, 56.60196416079998, 50.321501567959785, 45.00966779887676, 29.826915599405766, 17.88525838404894, 6.372802862897515, 3.4136814856901765, 11.0862803645432, 21.87496069818735, 33.98379944264889, 13.54106169193983, 1.3681941269896924, 0.09542934101773426, 9.523982796818018, 28.168378695845604, 38.929633051157, 40.68587601184845, 25.471477210521698, 34.27183158695698, 43.44039760529995, 49.19862002134323, 35.7238894701004, 5.781373148784041, 0.047955746049410664, 0.01095770747269853, 0.01390799681757926, 0.04494048909691628, 0.049723037154763006, 0.07106827673851512, 0.02408417083643144, 0.019153469693264924, 0.05347777005226817, 0.01666988362558186, 0.10448668195749633, 0.03716513776453212, 0.027829222417494748, 0.025152395937766414, 0.03055997149203904, 0.01569858857692452, 0.02328141938050976, 0.045367390994215384, 0.04618875180312898, 0.03123194539512042, 0.05133944592671469, 0.052284975463408045, 0.01579188396135578, 0.006458404250224703, 0.04467944607313257, 0.06914467448950745, 0.09391760104335845, 0.044626174712902866, 0.01662208745983662, 0.02110675228323089, 0.04578726104227826, 0.010653927874955116, 0.04640585226297844, 0.11834079792606644, 4.189835675060749, 31.835191436111927, 54.70578610897064, 53.18757377564907, 35.367848575115204, 22.632400654256344, 30.335467010736465, 35.120413452386856, 40.57868756353855, 13.897217530757189, 0.10651487507857382, 1.2084552110172808, 3.692894778214395, 3.784205303527415, 7.485946007072926, 7.900867592543364, 8.46941588446498, 4.3140799831599, 20.49063418060541, 52.10649758577347, 54.16538670659065, 56.38215735554695, 54.69429932534695, 55.847780629992485, 52.80954346060753, 53.62283281981945, 52.74972327053547, 55.609286427497864, 53.39163042604923, 51.761472299695015, 49.895058050751686, 51.33597873151302, 52.23522707819939, 53.35569195449352, 48.23084235191345, 40.68662457168102, 40.028480887413025, 42.78288468718529, 41.63892947137356, 42.926877960562706, 41.33799321949482, 39.878552332520485, 41.011788323521614, 47.060185968875885, 47.25446954369545, 49.541536420583725, 49.54355031251907, 49.53453719615936, 49.70515564084053, 46.744088530540466, 39.445265382528305, 39.64051030576229, 36.64986938238144, 40.36239176988602, 38.644522950053215, 48.60439270734787, 53.95376466214657, 52.71353401243687, 53.62808793783188, 53.29617574810982, 53.52513246238232, 51.59543260931969, 51.3848365098238, 51.51219427585602, 51.864306181669235, 50.81543326377869, 46.80632919073105, 46.76427684724331, 40.913586392998695, 52.098761200904846, 25.06862662732601, 38.679416477680206, 58.100679740309715, 50.217432752251625, 49.258880987763405, 44.09965842962265, 47.838042229413986, 48.73129449784756, 51.467333883047104, 52.65618748962879, 53.9778021723032, 53.65620642900467, 54.19454254209995, 48.90705406665802, 41.48937709629536, 40.02308137714863, 40.64694330096245, 39.87671323120594, 40.63525512814522, 40.15333838760853, 40.827327221632004, 43.86206477880478, 47.62364633381367, 49.23696756362915, 51.96849659085274, 50.855357721447945, 52.446218356490135, 49.10430148243904, 49.537789821624756, 50.09284123778343, 50.575514137744904, 49.33892369270325, 45.27422100305557, 41.30855239927769, 39.838947057724, 41.74920715391636, 42.755621150135994, 44.38317261636257, 47.50483810901642, 46.512471958994865, 49.99801732599735, 51.0845348238945, 54.201199784874916, 53.791691958904266, 51.04406699538231, 48.038538470864296, 52.76996858417988, 52.21392922103405, 53.00955332815647, 56.06888696551323, 50.599217265844345, 48.246847093105316, 34.13589768111706, 17.646785080432892, 8.423399403691292, 10.421483237296343, 14.534821417182684, 17.30543989688158, 39.09825660288334, 16.962078921496868, 1.2843301333487034, 0.07285386178409681, 12.022409532219172, 33.49830709397793, 38.604210913181305, 32.67400972545147, 24.821966663002968, 40.1860698312521, 51.217409893870354, 54.701032564044, 42.45082050561905, 7.494873628020287, 0.10425090164062567, 0.08098760736174881, 0.027829873652081005, 0.03743504945305176, 0.023746536317048594, 0.02081740374705987, 0.05551411566557363, 0.029244960023788735, 0.07753718469757587, 0.014036903230589814, 0.08883803064236417, 0.04783162927196827, 0.005512067164090695, 0.01425628486686037, 0.049215452672797255, 0.029190888999437448, 0.048694234938011505, 0.19081087288213894, 0.15495472034672275, 0.09553612864692695, 0.2262732567032799, 0.12997364363400266, 0.06014181089994963, 0.11793296551331878, 0.1268285553669557, 0.10941884698695503, 0.24970285885501653, 0.10488871819688939, 0.10846757693798281, 0.2189851290313527, 0.1265817615785636, 0.12407867558067665, 0.06500832183519378, 0.18099098262609914, 6.731917792931199, 38.3167677372694, 63.800461292266846, 61.25986061990261, 42.49424457550049, 29.697118364274502, 39.48717713356018, 39.841473922133446, 48.22526805102825, 16.667950004339218, 0.4866807349026203, 1.4361632172949612, 3.5633991518989205, 5.575501145794988, 14.687866754829884, 14.474840685725212, 22.108028791844845, 11.36365408077836, 23.053777143359184, 56.01772651076317, 54.93495561182499, 59.98648054897785, 56.261190846562386, 58.35902027785778, 55.22199600934982, 58.01682963967323, 55.003526732325554, 58.210193663835526, 53.56127992272377, 53.150111585855484, 50.77208139002323, 51.26330763101578, 53.2296147197485, 56.78998187184334, 49.580054953694344, 44.34101767838001, 41.66207782924175, 44.19973365962505, 45.34960515797138, 45.882032588124275, 43.50447736680508, 42.898637875914574, 41.918393075466156, 48.08669328689575, 48.87197434902191, 50.79344384372234, 50.95991291105747, 52.24105216562748, 53.516563922166824, 48.36946651339531, 41.453222036361694, 40.87523505091667, 40.04467561841011, 41.718915179371834, 40.15242263674736, 49.8016856610775, 57.44076155126095, 52.69364207983017, 55.92938505113125, 57.016810700297356, 55.352135226130486, 52.84627988934517, 52.32398271560669, 54.71135661005974, 53.02624203264713, 53.56433875858784, 49.74029615521431, 48.07278223335743, 41.80143155157566, 52.50101521611214, 29.2380877956748, 41.277413070201874, 58.50389890372753, 52.877233028411865, 50.4461120814085, 46.436400040984154, 49.70112405717373, 50.96702232956886, 53.7607616186142, 54.86144095659256, 57.18327596783638, 56.404351964592934, 54.956131875514984, 51.3963308930397, 42.52784617245197, 42.82215937972069, 42.41669073700905, 43.66984449326992, 41.99248909950256, 43.208845630288124, 42.030787244439125, 44.7873455286026, 48.4067577123642, 53.28999347984791, 54.25365597009659, 53.28060418367386, 52.88314551115036, 50.091781094670296, 51.17863677442074, 52.98035189509392, 52.04715996980667, 51.947168335318565, 47.12439492344856, 43.78031976521015, 43.05752635002136, 44.73341882228851, 45.727061703801155, 47.48046241700649, 52.185301557183266, 50.08656397461891, 52.690894827246666, 54.75948482751846, 57.21128806471825, 55.851911008358, 52.84440279006958, 48.18972855806351, 53.640733659267426, 54.906738325953484, 53.77715013921261, 57.968990206718445, 53.48475202918053, 51.514291763305664, 37.926703467965126, 20.02909004688263, 8.847832828760147, 7.56034174002707, 16.63344405591488, 32.17669241130352, 37.95395940542221, 15.662165824323893, 1.9294622470624745, 0.22945096978219226, 13.81363246589899, 40.54985091090202, 50.49585521221161, 53.34034077823162, 36.48748129606247, 47.569115459918976, 55.54430231451988, 63.03849957883358, 49.681285321712494, 9.419233817607164, 0.24416064843535423, 0.16152994096046314, 0.13140223338268697, 0.20311946631409228, 0.24244026106316596, 0.1861845765961334, 0.16239981225226074, 0.1308488435461186, 0.17364406201522797, 0.09873183138552122, 0.17437590868212283, 0.14910198049619794, 0.08018404696485959, 0.15796227380633354, 0.11955017209402286, 0.11817627120763063, 0.16151891264598817], [0.013883067149436101, 0.027694862146745436, 0.06024475791491568, 0.01889446757559199, 0.06291610363405198, 0.07514807773986831, 0.05701647489331663, 0.0823751711868681, 0.06623147026402876, 0.033140530285891145, 0.03868375744787045, 0.030566220375476405, 0.02198455713369185, 0.022519949889101554, 0.03897094262356404, 0.04738899755466264, 0.04541985712421592, 5.899339718744159, 34.20293748378754, 49.32813227176666, 49.23863187432289, 40.10369785130024, 25.8878056704998, 23.06324813514948, 35.18653750419617, 33.77471946179867, 7.943658521398902, 0.019485821976559237, 1.5208452357910573, 0.4410250863293186, 1.119168195873499, 5.102183343842626, 7.075934233143926, 4.5546498242765665, 12.581922858953476, 40.29298469424248, 53.83728191256523, 56.55606262385845, 53.255810514092445, 50.70077061653137, 49.615488052368164, 51.390338614583015, 51.9515684992075, 52.030304074287415, 53.40479291975498, 53.42047467827797, 49.01752553880215, 48.91612038016319, 49.702955558896065, 52.24383361637592, 50.10107919573784, 49.35347691178322, 44.363204687833786, 38.7270051240921, 37.90328152477741, 38.94303113222122, 40.54033242166042, 42.040134742856026, 39.46331061422825, 36.472909078001976, 37.17576876282692, 38.418077901005745, 40.01326650381088, 38.60445789992809, 38.48969645798206, 37.204996794462204, 36.82681068778038, 36.08596824109554, 39.51522342860699, 36.23751550912857, 38.98054651916027, 36.61965720355511, 42.458062916994095, 50.998340249061584, 52.68316604197025, 52.649682238698006, 48.7654584646225, 46.285570934414864, 48.82614880800247, 48.11277128756046, 50.380292013287544, 49.02936190366745, 51.31208561360836, 46.25892296433449, 50.115723609924316, 37.718702629208565, 50.21212823688984, 22.264840677380562, 36.857976615428925, 56.79077222943306, 48.32866430282593, 50.26019185781479, 39.46475833654404, 39.13224957883358, 39.735999181866646, 44.52842742204666, 45.24019002914429, 49.25128139555454, 48.407829254865646, 47.86906756460667, 42.44461163878441, 39.22267332673073, 39.38486762344837, 37.79023379087448, 39.014208912849426, 39.96996782720089, 40.5499193072319, 38.364569172263145, 39.80053871870041, 37.33604036271572, 40.37253722548485, 41.93035863339901, 43.008736968040466, 40.334391072392464, 38.584873750805855, 38.49203333258629, 39.03508499264717, 39.798752814531326, 39.84398178756237, 37.691306099295616, 36.86120644211769, 38.645928874611855, 36.97349801659584, 38.556139692664146, 38.20695362985134, 40.83054944872856, 42.67180144786835, 46.05895109474659, 48.38628061115742, 50.499107837677, 49.532283917069435, 47.50497110188007, 53.259032741189, 53.8646974414587, 57.669459879398346, 56.035714745521545, 55.19322395324707, 57.16440998017788, 51.51497192680836, 50.588634833693504, 24.83833998441696, 16.58929042518139, 21.676738634705544, 14.225385021418333, 4.193699117749929, 2.2588446037843823, 2.2900311928242445, 0.12972879427252337, 0.189242061751429, 6.558486074209213, 24.137340299785137, 47.48620390892029, 59.08239126205444, 38.59028846025467, 34.05119642615318, 33.167078867554665, 48.40687170624733, 42.174601927399635, 7.20739577896893, 0.032784792929305695, 0.02473356118571246, 0.04858479784161318, 0.04882616653048899, 0.05341899937775452, 0.04576926396111958, 0.0789428866119124, 0.05936195841059089, 0.019522183501976542, 0.038526752396137454, 0.017403967867721803, 0.05483876127982512, 0.07323846497456543, 0.015283541561075253, 0.02749623188719852, 0.013198587130318629, 0.0418191755306907, 0.04358378748293035, 0.04346571549831424, 0.08773341061896645, 0.01358798459477839, 0.02670047146239085, 0.04922759049804881, 0.016885175100469496, 0.03652530627732631, 0.006520291944980272, 0.03259389770391863, 0.0665011593082454, 0.04088894165761303, 0.035222989245085046, 0.024714597457204945, 0.04306216156692244, 0.03409204895433504, 0.04476406946196221, 7.8989543952047825, 38.7749357521534, 55.83082593977451, 53.57560135424137, 44.64315466582775, 27.441270612180233, 24.417936243116856, 35.459279268980026, 38.669081032276154, 8.590456489473581, 0.035915182961616665, 2.327960282564163, 1.3445932371541858, 3.035697005689144, 6.278285784646869, 7.460941448807716, 6.020566038787365, 11.27629866823554, 44.14631612598896, 56.15526393055916, 58.94917041063309, 54.37355853617191, 53.52950222790241, 51.45806238055229, 52.67624281346798, 53.48039746284485, 54.47673819959164, 55.392223075032234, 52.64078691601753, 48.89740638434887, 50.74831746518612, 50.813673958182335, 52.882548943161964, 52.598092406988144, 50.289815068244934, 45.250058099627495, 39.45243559777737, 41.33073180913925, 40.63167192041874, 43.779286220669746, 44.42357964813709, 41.301055401563644, 40.12507550418377, 39.1088542342186, 40.897448658943176, 41.939839124679565, 41.53738372027874, 42.25282832980156, 39.20670658349991, 39.91291768848896, 37.83812262117863, 41.54576987028122, 37.651028260588646, 40.736166313290596, 39.04862366616726, 45.082635283470154, 53.273141384124756, 54.12758633494377, 53.44830818474293, 48.96168753504753, 48.05328167974949, 50.158212929964066, 47.829002514481544, 52.8437340259552, 50.642846524715424, 52.91563756763935, 46.93352356553078, 51.4006132632494, 38.97855542600155, 49.124816581606865, 23.87428041547537, 38.62610153853893, 58.55461858212948, 51.38495050370693, 50.533214807510376, 41.24325670301914, 42.073432356119156, 42.03674532473087, 46.72478176653385, 47.75875948369503, 52.38773189485073, 49.367992132902145, 50.82397140562534, 43.495361655950546, 40.364508256316185, 41.258710473775864, 38.95087391138077, 40.61849042773247, 40.60766100883484, 40.92176355421543, 39.03504319489002, 39.31219272315502, 40.652232617139816, 42.703218162059784, 45.61231926083565, 44.7431804984808, 43.53955328464508, 41.36508956551552, 40.038592144846916, 41.523187682032585, 40.00339463353157, 41.03427551686764, 38.64447355270386, 38.94479423761368, 40.24202562868595, 40.34612864255905, 41.45696483552456, 40.89378945529461, 41.79720997810364, 44.448586106300354, 48.12586158514023, 51.81563459336758, 53.45726430416107, 51.0809326171875, 48.420132994651794, 52.1102137863636, 54.59018491208553, 59.247841984033585, 57.154682502150536, 56.54368668794632, 60.96012510359287, 52.73963861167431, 51.25793471932411, 28.0346866697073, 14.007545560598373, 14.042955860495567, 13.189843688160181, 11.340879052877426, 4.823949448764324, 2.3527931375429034, 0.3333054087124765, 0.1098305311461445, 7.4156868271529675, 26.033962927758694, 45.65127857029438, 58.62440563738346, 38.6511117964983, 40.589444786310196, 39.37448278069496, 54.243818297982216, 48.98768953979015, 9.565911646932364, 0.08268334800959565, 0.016108931304188445, 0.06526491197291762, 0.012763608810928417, 0.04316766899137292, 0.04242281247570645, 0.021358642770792358, 0.00972040257693152, 0.015456619676115224, 0.04322051361668855, 0.049629244531388395, 0.01993456156924367, 0.047478619308094494, 0.03636781882960349, 0.013791313576803077, 0.0527824667369714, 0.014016570239618886, 0.12427885507349856, 0.26260364160407335, 0.24187760922359303, 0.15247308241669089, 0.18433661403832957, 0.25554709369316697, 0.15434808883583173, 0.15138025511987507, 0.09205621303408407, 0.1230018786736764, 0.15292911732103676, 0.1659294666023925, 0.11682067910442129, 0.1081579529272858, 0.13346939667826518, 0.11297328164801002, 0.13667875493410975, 11.24365746974945, 47.432041615247726, 62.167726904153824, 60.50109073519707, 51.703316420316696, 37.170483246445656, 33.32468681037426, 46.75048738718033, 46.2835456430912, 11.253223456442356, 0.07841115264454857, 3.289602231234312, 2.363684303127229, 4.697399139404297, 12.206467855721712, 17.057320810854435, 13.83127586916089, 15.66065825521946, 46.815045922994614, 57.84294717013836, 61.87672331929207, 55.80172710120678, 55.53243935108185, 53.326125741004944, 56.49647042155266, 55.27967311441898, 55.840724408626556, 56.14388734102249, 54.56430450081825, 51.07823856174946, 52.03134901821613, 50.352724492549896, 53.1099059432745, 54.5853553712368, 55.45270822942257, 47.8128419816494, 42.32938662171364, 43.92662711441517, 42.670254930853844, 44.59898583590984, 46.90706938505173, 44.13439616560936, 41.48690722882748, 40.93749850988388, 42.44773127138615, 43.81191127002239, 43.49122367799282, 42.50381626188755, 40.61294272542, 40.58805026113987, 40.80204337835312, 44.22385096549988, 40.13565793633461, 41.91668316721916, 40.85207909345627, 46.26516602933407, 54.20009024441242, 56.163631081581116, 55.895278081297874, 51.08381286263466, 49.84070956707001, 52.534191235899925, 50.74643276631832, 54.42075960338116, 52.3604341596365, 55.12599416077137, 48.17561611533165, 53.50791938602924, 40.122423246502876, 50.37397675216198, 26.80246029049158, 43.123335018754005, 60.840982496738434, 53.43492150306702, 54.893294647336006, 42.409828305244446, 42.892858386039734, 43.32204155623913, 49.32820826768875, 49.36588704586029, 53.59673582017422, 51.25242881476879, 52.198095470666885, 45.57638458907604, 43.18706899881363, 44.62282955646515, 42.31898657977581, 42.91697569191456, 43.90019953250885, 44.19910289347172, 40.05280718207359, 42.87590749561787, 41.665140464901924, 44.48669046163559, 46.38717368245125, 46.251125782728195, 45.30474476516247, 41.76681160926819, 41.3493812084198, 43.85452218353748, 42.889316976070404, 43.42021308839321, 40.930924862623215, 41.44757553935051, 43.85975070297718, 42.462607473134995, 44.710498452186584, 42.86511607468128, 44.24952618777752, 46.596242263913155, 50.59877648949623, 53.171542435884476, 54.664816707372665, 52.12750285863876, 50.25689363479614, 54.58487659692764, 57.636572644114494, 61.584845781326294, 62.57838986814022, 59.45013552904129, 61.49415984749794, 55.71196831762791, 53.822253718972206, 28.172573670744896, 19.798980094492435, 29.520310051739216, 22.336746118962765, 6.323267295956612, 2.7732365392148495, 4.428667584434152, 0.3912527149077505, 0.45844154083169997, 8.859274964779615, 33.839570581912994, 58.874831199645996, 68.7229223549366, 49.13528881967068, 46.779620423913, 46.82553716003895, 62.102195620536804, 54.871229231357574, 13.59243968501687, 0.12875114829512313, 0.13233348028734326, 0.19774017215240747, 0.16931404592469335, 0.13997677015140653, 0.1498486552736722, 0.2356064910418354, 0.11247518181335181, 0.12626746203750372, 0.1529793904046528, 0.18869094288675115, 0.11388681348762475, 0.12673494085902348, 0.11468526790849864, 0.08765616788878106, 0.19439516414422542, 0.16105474380310625], [0.0719146961637307, 0.060905744321644306, 0.023410595749737695, 0.00854481004353147, 0.08514987581293099, 0.08199003365007229, 0.07135540625313297, 0.032823536748765036, 0.03184824337949976, 0.03229663045203779, 0.07835503143724054, 0.05343083292245865, 0.050579252929310314, 0.02538892767915968, 0.07337149494560435, 0.06795231776777655, 0.04404090221214574, 5.906612053513527, 34.47623021900654, 45.0235066562891, 40.422854125499725, 30.61667662113905, 22.882721722126007, 23.468389995396137, 35.689744502305984, 31.776824668049812, 4.161605089902878, 0.05445838090963662, 16.418043114244938, 12.174264583736658, 4.395316299051046, 4.371467353776097, 4.427102543413639, 6.454869909211993, 16.241966262459755, 41.60172186791897, 55.04677601158619, 55.06115444004536, 51.45784579217434, 51.94906443357468, 51.090242117643356, 51.855851635336876, 52.18594752252102, 50.89608773589134, 51.408106461167336, 49.50141057372093, 48.72177980840206, 50.064407363533974, 48.36263827979565, 50.318389534950256, 49.24242407083511, 49.77631442248821, 47.12817572057247, 41.09463147819042, 39.43089835345745, 40.750692933797836, 42.10938602685928, 42.77041755616665, 44.51188310980797, 40.95776282250881, 36.85415022075176, 36.29613496363163, 38.37594196200371, 38.22704315185547, 36.55827909708023, 35.53909778594971, 37.5302517414093, 35.77809736132622, 36.5940123796463, 36.658422723412514, 39.3761432915926, 37.31503129005432, 39.64488007128239, 47.83423863351345, 49.006992504000664, 45.77941529452801, 44.916105419397354, 42.79105804860592, 45.34088842570782, 48.117676824331284, 50.75932167470455, 47.27626897394657, 49.34194453060627, 43.036141097545624, 46.84591546654701, 40.64401365816593, 50.01977875828743, 24.823174998164177, 32.50306449830532, 58.26538950204849, 47.6033516228199, 51.50216281414032, 43.18186327815056, 39.28828440606594, 37.78701916337013, 37.19072476029396, 37.756202816963196, 39.94066379964352, 39.69538316130638, 43.56739439070225, 38.934587985277176, 37.61460341513157, 38.164715096354485, 37.600209787487984, 38.97607035934925, 39.53915074467659, 42.30003699660301, 43.16633351147175, 37.85152830183506, 39.20154266059399, 37.317520156502724, 37.19004079699516, 37.322323098778725, 39.00335289537907, 37.602713853120804, 38.6703235656023, 38.6301901191473, 40.068416744470596, 38.814689218997955, 36.83620758354664, 36.81528590619564, 38.22170443832874, 37.47072033584118, 36.331974640488625, 37.05596499145031, 39.090630412101746, 42.90208429098129, 46.37396939098835, 50.53177088499069, 51.69426150619984, 48.643576204776764, 49.48195181787014, 51.20229050517082, 54.704638570547104, 50.320411026477814, 54.30740788578987, 52.166032791137695, 55.787899643182755, 56.85079760849476, 52.260830104351044, 34.12973441183567, 17.537934221327305, 16.510195769369602, 8.522945512086153, 8.517844285815954, 4.839315349236131, 0.6608175532892346, 0.012822482458432205, 0.11240659994655289, 3.7522181449458003, 29.604884013533592, 54.34279918670654, 60.07653571665287, 30.485788844525814, 22.232103534042835, 41.93775683641434, 48.87688748538494, 45.22291615605354, 11.243286989629269, 0.08993714393000118, 0.05252459268376697, 0.003961532811445068, 0.11293810384813696, 0.06755783659173176, 0.03390051548194606, 0.07134143161238171, 0.056496025281376205, 0.10523681514314376, 0.016080286259239074, 0.04635007986507844, 0.02564700582297519, 0.012259382547199493, 0.06032375211361796, 0.05934653658187017, 0.031859112132224254, 0.07186090530012734, 0.019044357286475133, 0.03837892771116458, 0.012640374261536635, 0.056382265174761415, 0.08850284706568345, 0.06995746720349416, 0.0618388280418003, 0.02001288226892939, 0.007903673304099357, 0.032268061477225274, 0.05615044050500728, 0.01981961031560786, 0.07969620361109264, 0.034587083719088696, 0.01593802953721024, 0.04458404298929963, 0.03621414231020026, 8.537518680095673, 42.075138464570045, 51.591864600777626, 48.55833537876606, 37.074226811528206, 31.18232946842909, 28.596203438937664, 38.034784868359566, 35.44781148433685, 5.770343765616417, 0.11684687691740692, 18.26009687036276, 13.694851789623499, 8.275674730539322, 9.124173950403929, 12.197544984519482, 12.436235826462507, 19.75627228617668, 44.169327691197395, 55.54484188556671, 56.699227541685104, 52.55980186164379, 55.01973286271095, 53.276614397764206, 53.108454421162605, 54.52556937932968, 52.59259030222893, 52.797585502266884, 50.87036691606045, 50.254545360803604, 50.821649730205536, 49.24341581761837, 51.10311962664127, 50.766149908304214, 52.0936618745327, 49.12952072918415, 42.688683941960335, 41.32679522037506, 42.33516991138458, 44.64600071310997, 45.37513978779316, 46.09479457139969, 41.72125965356827, 39.26607459783554, 37.76774659752846, 40.68651057779789, 40.39271794259548, 37.62087307870388, 38.33379842340946, 38.73267062008381, 37.81552903354168, 38.726552948355675, 38.813993856310844, 40.79923152923584, 39.64665837585926, 40.515310764312744, 50.389571115374565, 50.82334443926811, 48.49247731268406, 47.41834715008736, 45.088741555809975, 46.596344858407974, 50.53518310189247, 53.294587433338165, 49.85524378716946, 51.82812452316284, 44.68209117650986, 46.924449652433395, 41.147209256887436, 49.84030678868294, 26.2985123321414, 34.09208603203297, 58.08871418237686, 49.70493525266647, 53.03379222750664, 44.82111431658268, 40.2896598726511, 38.5300312936306, 40.399511978030205, 40.905044451355934, 42.19859004020691, 42.84241609275341, 45.12500301003456, 41.29669703543186, 39.44669410586357, 39.411865174770355, 38.52620869874954, 42.001992389559746, 43.12566049396992, 43.93017612397671, 44.54207628965378, 39.67720873653889, 40.46850487589836, 39.36649940907955, 38.763897344470024, 39.88376185297966, 40.310767740011215, 38.99125814437866, 39.50137697160244, 38.77834036946297, 40.18759734928608, 41.238594353199005, 39.26148444414139, 37.47181847691536, 40.31043715775013, 39.86507445573807, 38.46425302326679, 39.569005742669106, 41.63543365895748, 45.389738604426384, 48.59112001955509, 51.729117035865784, 54.45509076118469, 48.61758179962635, 49.89626258611679, 51.77854098379612, 56.164668425917625, 53.056480810046196, 57.03928269445896, 55.69005109369755, 55.68101517856121, 58.59224036335945, 53.15536290407181, 36.203579530119896, 16.21745377779007, 15.621073879301548, 11.118089407682419, 9.496841803193092, 5.680880891159177, 1.4267454226501286, 0.018923895586340223, 0.0880933967710007, 3.740382492542267, 31.302059143781662, 57.788602486252785, 60.92278830707073, 38.13848130404949, 28.063067346811295, 48.15780267119408, 55.855798199772835, 53.2076670974493, 13.988901861011982, 0.11471096106106415, 0.03854471608065069, 0.03154044505208731, 0.018042374431388453, 0.03687357762828469, 0.04434150912857149, 0.09672383210272528, 0.05288766617013607, 0.03212586969311815, 0.04223449621349573, 0.06727009851601906, 0.08031815305002965, 0.060514992437674664, 0.012844914799643448, 0.02654850930412067, 0.0342744911176851, 0.020954432038706727, 0.1673363262671046, 0.33011678606271744, 0.2203946010558866, 0.11485552400699817, 0.14275065099354833, 0.2502860384993255, 0.1557226650766097, 0.16858533112099394, 0.12082213157555088, 0.07235628887428902, 0.2066257578553632, 0.1714660515426658, 0.18126775918062776, 0.10040345223387703, 0.1752693357411772, 0.10953743476420641, 0.09768655349034816, 10.974458064883947, 48.973816484212875, 57.054094299674034, 55.09159840643406, 43.133290484547615, 37.719610780477524, 35.832829624414444, 45.77461615204811, 42.23650060594082, 6.871411632746458, 0.1937029036344029, 18.932721577584743, 17.905135117471218, 15.657956600189209, 14.093765784054995, 13.347756564617157, 11.813303902745247, 20.682282596826553, 46.99961721897125, 59.04270239174366, 58.77572871744633, 54.22096252441406, 56.91782221198082, 57.42043264210224, 54.39100719988346, 55.500999838113785, 52.49499633908272, 53.91679644584656, 51.29306763410568, 51.414596512913704, 51.69463008642197, 50.61753988265991, 52.52583168447018, 51.72483466565609, 53.54430243372917, 51.11888878047466, 45.70058852434158, 43.927394673228264, 45.97632832825184, 46.39383852481842, 47.64284290373325, 50.374204739928246, 44.26872655749321, 40.883522406220436, 40.22526852786541, 42.659193724393845, 41.72276057302952, 39.62479814887047, 39.94078539311886, 41.258505284786224, 38.34408827126026, 39.99408133327961, 40.05764812231064, 43.33672396838665, 42.5199805945158, 43.634210005402565, 52.27623447775841, 53.236336559057236, 51.255149468779564, 50.14239437878132, 47.34700217843056, 48.60255740582943, 52.747207805514336, 53.905697241425514, 51.362828090786934, 51.408482640981674, 45.066983923316, 46.85646750032902, 43.27323317527771, 49.293987303972244, 29.795316495001316, 37.66537249088287, 58.95447492599487, 53.033644035458565, 54.86549533903599, 47.227908968925476, 41.85899846255779, 41.45156152546406, 40.972103253006935, 42.52257585525513, 44.73720721900463, 44.25939805805683, 48.33889715373516, 43.06738682091236, 41.58128656446934, 42.8564677387476, 39.005940556526184, 42.43907913565636, 44.093753546476364, 45.64284682273865, 47.802711725234985, 40.855833292007446, 42.273894399404526, 41.71071521937847, 41.03639580309391, 40.6230653822422, 44.0029726177454, 39.99022834002972, 42.186822071671486, 41.155705600976944, 42.13466227054596, 43.2314658164978, 40.56846231222153, 40.018757209181786, 42.57621757686138, 42.860221937298775, 40.220754370093346, 41.305736750364304, 43.450733050704, 48.40878300368786, 52.246098294854164, 56.044967249035835, 55.74476815760136, 50.39446525275707, 50.376997590065, 52.94727846980095, 58.850295916199684, 54.965334981679916, 58.77523094415665, 58.08506637811661, 60.13081580400467, 61.57942347228527, 55.66566400229931, 38.5270294547081, 21.945840194821358, 22.092421129345894, 17.721513770520687, 15.861591473221779, 11.416975669562817, 1.9601936917752028, 0.09223381639458239, 0.3261345700593665, 4.9049007799476385, 42.54989638924599, 61.91380172967911, 66.35921359062195, 42.39859990775585, 34.115777760744095, 54.963834062218666, 61.04211710393429, 60.94793535768986, 19.76171739399433, 0.3003315202658996, 0.17395512579241768, 0.1287252176553011, 0.2978903887560591, 0.13482316309818998, 0.1523828224162571, 0.16330883925547823, 0.17595499113667756, 0.21981977799441665, 0.1226253055210691, 0.15507380536291748, 0.13773465296253562, 0.18677685497095808, 0.1315018889727071, 0.14589844067813829, 0.13909267931012437, 0.1684650735114701], [0.02407262487395201, 0.05006694838812109, 0.02021442174736876, 0.08395731871132739, 0.036619358652387746, 0.04918190388707444, 0.02569798209151486, 0.03783070693316404, 0.07508502487326041, 0.03440671585849486, 0.0066488207903603325, 0.02040972532995511, 0.060185697802808136, 0.005642665209961706, 0.04877430525084492, 0.05230205599218607, 0.15145617682719603, 5.032573454082012, 31.4104388281703, 48.72136563062668, 38.621002212166786, 23.730705119669437, 17.88123819977045, 24.407982677221298, 35.42643003165722, 28.950713016092777, 2.631943258456886, 0.1783448996138759, 9.06393863260746, 15.45915886759758, 5.4273508954793215, 8.409388605505228, 8.576423842459917, 11.661530546844006, 17.7478938549757, 46.809232234954834, 55.662358179688454, 54.934678226709366, 58.220844492316246, 53.639069348573685, 50.861376598477364, 49.700915068387985, 50.282002687454224, 49.16938439011574, 50.368132665753365, 50.543478056788445, 48.11036601662636, 49.488061890006065, 50.71478806436062, 48.3282995223999, 49.79081444442272, 48.94388549029827, 48.37154880166054, 46.236599162220955, 37.686742544174194, 39.47157137095928, 41.201755329966545, 44.19401116669178, 45.17389118671417, 43.91545571386814, 42.709632217884064, 37.599491626024246, 36.506453678011894, 35.702435821294785, 36.11866168677807, 37.31602683663368, 36.06163814663887, 34.942305609583855, 37.18179143965244, 36.63408502936363, 37.41973467171192, 38.18109221756458, 36.857710629701614, 38.155284002423286, 39.88424442708492, 39.10083286464214, 40.52377291023731, 41.772477105259895, 49.60942357778549, 50.13570673763752, 51.914615482091904, 46.596208065748215, 47.68959179520607, 48.45407657325268, 50.2191236615181, 42.039078399538994, 47.86415822803974, 27.05243557691574, 29.422940276563168, 55.0458412617445, 48.17783899605274, 51.089280769228935, 47.53930985927582, 42.66952537000179, 36.888728365302086, 37.05708593130112, 38.05357106029987, 37.42603853344917, 36.34245827794075, 37.22432255744934, 39.20136786997318, 38.088757172226906, 38.79644259810448, 36.30531147122383, 38.17399799823761, 38.652772307395935, 41.04540511965752, 41.88073329627514, 39.17454890906811, 38.32030914723873, 38.58263947069645, 40.14740310609341, 37.657252326607704, 38.15347909927368, 35.401738956570625, 38.09138663113117, 38.862376660108566, 39.10185120999813, 36.95525519549847, 38.63896384835243, 39.48023110628128, 36.732598543167114, 37.11170420050621, 37.67438180744648, 38.80929350852966, 40.35488337278366, 45.45438073575497, 48.44116486608982, 51.259549632668495, 50.91465353965759, 49.87305723130703, 48.7507950514555, 51.644772961735725, 53.32354947924614, 52.357447519898415, 48.78739848732948, 51.141022592782974, 51.009230464696884, 54.05289754271507, 54.333976060152054, 47.38951429724693, 16.859630718827248, 13.454174604266882, 9.576573874801397, 11.456439401954412, 5.271452385932207, 1.1978350183926523, 0.0376320154464338, 0.1300949847791344, 2.256660908460617, 21.597813069820404, 51.72993779182434, 48.45748879015446, 18.316459245979786, 24.362301528453827, 37.37176224589348, 43.34175109863281, 44.25597824156284, 14.494092352688313, 0.09995841595809907, 0.01598266786459135, 0.04870045042480342, 0.026231094598188065, 0.06120649224612862, 0.11970995648880489, 0.0758065482659731, 0.030207349300326314, 0.013859404698450817, 0.07794886143528856, 0.04051792719110381, 0.03021213986357907, 0.024798263475531712, 0.046661180749651976, 0.02553184676798992, 0.043657460482791066, 0.020914678898407146, 0.03556621399184223, 0.04756644877488725, 0.02730586358666187, 0.08502557349856943, 0.038598328828811646, 0.05607113089354243, 0.03262514954258222, 0.0155952370914747, 0.0769173726439476, 0.03923493939510081, 0.03966103606217075, 0.07724466719082557, 0.031604466421413235, 0.004324915216784575, 0.04469647094083484, 0.06589951502974145, 0.13365292979869992, 6.410796074196696, 36.82817101478577, 52.99795635044575, 46.01279877126217, 29.043450839817524, 24.187964983284473, 28.63303866237402, 39.400279596447945, 32.66786925494671, 3.429818982258439, 0.2449684019666165, 9.891116246581078, 18.001729734241962, 7.341583203524351, 9.328541234135628, 14.083594679832458, 11.42904382199049, 20.079038366675377, 48.01157131791115, 57.17998154461384, 56.47919274866581, 58.29751677811146, 54.35155011713505, 53.808266669511795, 51.43496721982956, 51.291011944413185, 50.92529296875, 51.31814248859882, 50.864971205592155, 49.28373545408249, 49.65474374592304, 50.38593091070652, 48.34668293595314, 51.19237303733826, 52.13300496339798, 50.44697463512421, 47.31180466711521, 41.00515007972717, 41.40482023358345, 43.83894681930542, 44.660265147686005, 46.99060030281544, 47.81075209379196, 43.54865379631519, 37.84125365316868, 38.69535282254219, 36.901795864105225, 37.473494186997414, 38.36625628173351, 37.424385622143745, 37.23571814596653, 37.782261818647385, 38.74056659638882, 38.675753474235535, 38.821145072579384, 38.99431698024273, 41.667636930942535, 40.753880962729454, 41.516815423965454, 40.846930369734764, 44.741079211235046, 51.210764050483704, 53.066736459732056, 54.595390632748604, 47.54946291446686, 49.17767554521561, 48.738289922475815, 50.87985880672932, 43.129844069480896, 48.18921558558941, 27.864862382411957, 31.66210312396288, 56.91330425441265, 50.11010751128197, 52.59656108915806, 49.07957620918751, 43.80072467029095, 37.963926270604134, 39.96887728571892, 40.286053866147995, 38.73721897602081, 39.68803435564041, 38.507654294371605, 40.11372171342373, 39.63541857898235, 40.489456951618195, 38.12654234468937, 40.51319807767868, 39.68929588794708, 44.08601716160774, 43.857619017362595, 41.46069623529911, 39.562667682766914, 40.40148787200451, 39.88329827785492, 40.35651348531246, 39.8616736382246, 38.848594799637794, 40.02464309334755, 41.47793971002102, 41.000768914818764, 39.20176304876804, 40.755769461393356, 40.93403309583664, 39.23018932342529, 39.97359283268452, 39.545055627822876, 41.14599332213402, 43.56643304228783, 47.578006982803345, 50.54113358259201, 52.810303419828415, 51.87438324093819, 51.740087047219276, 49.37037080526352, 52.83612683415413, 55.199075639247894, 55.75257673859596, 51.64635747671127, 53.053581565618515, 55.033085346221924, 55.783450081944466, 55.43004244565964, 49.98362369835377, 20.36478493362665, 9.266031738370657, 10.920979734510183, 10.185621343553066, 3.3608341589570045, 2.2996083414182067, 0.2783416846068576, 0.09733962913742289, 2.0657658018171787, 25.080649182200432, 54.14571896195412, 53.93157385289669, 29.5118498057127, 30.09085513651371, 43.54306809604168, 49.81835536658764, 51.85354895889759, 18.63086197525263, 0.2581643813755363, 0.014849836024950491, 0.03682852184283547, 0.008110015405691229, 0.007789190531184431, 0.04778857728524599, 0.05761894666648004, 0.029700412342208438, 0.024635588415549137, 0.0568735743581783, 0.09318234791862778, 0.04596815582772251, 0.062030699191382155, 0.02978455519041745, 0.012815156533179106, 0.037949476536596194, 0.038432547880802304, 0.12976144877029583, 0.1701459044124931, 0.11049580716644414, 0.16119454958243296, 0.09065609949175268, 0.19398113479837775, 0.18284268560819328, 0.14495837705908343, 0.14535324415192008, 0.11618946766247973, 0.1251389819663018, 0.1610147865721956, 0.12725500826491043, 0.08904392467229627, 0.16966365685220808, 0.24216859048465267, 0.34499545174185187, 8.328299056738615, 44.28171806037426, 59.87336441874504, 53.740892484784126, 35.81441581249237, 30.58186288923025, 37.76623047888279, 47.41737060248852, 39.32163521647453, 4.4671533443033695, 0.2854448393918574, 10.708604380488396, 23.484332039952278, 9.777165111154318, 16.579838432371616, 14.516062773764133, 15.049293860793114, 22.25291881710291, 50.2924445271492, 58.41472148895264, 57.25696161389351, 60.94273343682289, 56.514029279351234, 53.88072498142719, 52.40021422505379, 51.673757806420326, 50.721266716718674, 51.75008811056614, 52.48687617480755, 50.90944021940231, 49.91087660193443, 51.683857664465904, 50.13612851500511, 51.67498514056206, 55.49734063446522, 52.01616123318672, 49.18948911130428, 42.312302738428116, 42.907084822654724, 45.87654948234558, 47.97249421477318, 49.22169618308544, 49.42571863532066, 46.31856456398964, 40.41518233716488, 41.01810358464718, 39.07753251492977, 38.80461595952511, 41.24822683632374, 39.2258195579052, 39.73402328789234, 40.28470113873482, 40.47367259860039, 40.127575770020485, 41.85264140367508, 41.893979385495186, 42.37354405224323, 42.94680409133434, 43.95678609609604, 44.33687590062618, 47.26968012750149, 53.11429090797901, 53.74810069799423, 54.736933037638664, 48.291335105895996, 49.25138019025326, 50.32838299870491, 51.60794913768768, 44.4781257212162, 48.332331106066704, 31.28264408558607, 34.02110204100609, 56.789609491825104, 53.728645741939545, 54.51250568032265, 51.0832466930151, 45.56037984788418, 39.97015781700611, 41.82030513882637, 43.482316955924034, 40.57965651154518, 41.49368606507778, 40.48466920852661, 42.989038825035095, 41.08513958752155, 43.17564681172371, 39.51332353055477, 42.675616443157196, 42.14035056531429, 45.311918780207634, 45.28194598853588, 43.93963381648064, 40.59728376567364, 41.77095718681812, 41.530460491776466, 40.358504578471184, 42.48145446181297, 38.936028108000755, 40.20297892391682, 43.31423297524452, 43.03304806351662, 40.749294608831406, 42.13871285319328, 43.585443422198296, 41.3504983484745, 41.33787162601948, 42.713131830096245, 43.59257943928242, 45.57805269956589, 50.215255469083786, 53.62880229949951, 56.13489702343941, 53.931448459625244, 53.54543477296829, 50.69190949201584, 53.82788881659508, 56.79557517170906, 57.45980232954025, 54.67111676931381, 55.93467436730862, 56.66383244097233, 59.024869948625565, 57.92045161128044, 52.475100606679916, 21.101318411529064, 18.12003068625927, 19.257153868675232, 22.461041249334812, 12.358065471053123, 3.4842543862760067, 0.3305314091267064, 0.24854599905665964, 2.9388093296438456, 30.72412345558405, 60.17227917909622, 55.64741738140583, 29.11825742572546, 34.92889612913132, 51.897843182086945, 55.68230710923672, 59.46167171001434, 23.81238743662834, 0.5725267971865833, 0.12045785580994561, 0.11161302885739133, 0.10770732085802592, 0.1472020082292147, 0.17880535771837458, 0.18583656870760024, 0.1517348235938698, 0.10202441408182494, 0.17075727082556114, 0.18879073206335306, 0.20534350478556007, 0.16385498573072255, 0.13535627746023238, 0.09405616001458839, 0.13384091580519453, 0.12450397072825581], [0.07963778916746378, 0.047305828775279224, 0.013578299567598151, 0.0719952117651701, 0.028082433927920647, 0.026254295989929233, 0.03476244950434193, 0.030090507425484248, 0.011869860773003893, 0.10298786277417094, 0.019560413384169806, 0.08929576506488957, 0.041195656449417584, 0.012254195862624329, 0.07313543261261657, 0.04162222066952381, 0.12338087122770958, 8.347457628697157, 37.48558133840561, 46.32664293050766, 40.026740580797195, 33.452599346637726, 16.57835081219673, 22.47914157807827, 34.04836177825928, 25.97516678273678, 1.629770784638822, 0.08260398273705505, 0.3650554659543559, 2.021862482652068, 8.610554561018944, 8.260917272418737, 20.949184074997902, 19.884353913366795, 30.906950645148754, 50.00955730676651, 55.25480344891548, 53.45061846077442, 49.31852638721466, 52.185575142502785, 49.422374814748764, 48.96797999739647, 49.06164117157459, 50.581449419260025, 50.47385819256306, 48.32239843904972, 49.74028095602989, 50.93072287738323, 51.06659218668938, 50.07298730313778, 46.76155999302864, 48.406035751104355, 51.31802089512348, 44.41443353891373, 38.6822435259819, 39.762966334819794, 45.12176938354969, 45.20125351846218, 48.120910450816154, 48.362721875309944, 45.84512136876583, 40.668875724077225, 38.200421780347824, 36.44363924860954, 37.42335967719555, 37.40776911377907, 36.832122802734375, 34.971735030412674, 37.72547386586666, 34.69433851540089, 38.49194213747978, 36.73010587692261, 37.76203170418739, 37.085588201880455, 37.16223008930683, 36.59293323755264, 42.88221515715122, 46.837821900844574, 49.98646214604378, 49.21482615172863, 49.79708030819893, 43.11590261757374, 48.24721187353134, 43.17222699522972, 46.0702782869339, 41.7410945892334, 52.11444675922394, 28.07468142360449, 31.51142030954361, 52.0907474309206, 47.43186682462692, 52.05824017524719, 47.89196893572807, 43.83338771760464, 38.94259795546532, 37.69253343343735, 37.54759781062603, 36.49043753743172, 36.28516875207424, 38.65987032651901, 39.09061141312122, 39.91806261241436, 37.73300886154175, 37.9630371183157, 39.27764117717743, 37.94875368475914, 37.42885038256645, 39.23207402229309, 39.54891622066498, 38.02480660378933, 38.678394332528114, 39.04598280787468, 37.44511730968952, 38.427364602684975, 36.96586802601814, 38.837070018053055, 37.94273100793362, 39.76122982800007, 43.561595901846886, 42.9100676625967, 40.887337401509285, 39.92686294019222, 39.449133574962616, 37.87740111351013, 39.01659518480301, 41.45102955400944, 44.44154888391495, 46.44478999078274, 48.81702169775963, 50.59939965605736, 52.455341666936874, 47.89691627025604, 49.40816357731819, 53.91311824321747, 52.514246106147766, 48.10673341155052, 48.10841292142868, 49.79344770312309, 56.84175409376621, 53.11157405376434, 51.10178969800472, 27.018127217888832, 13.600993975996971, 9.516176115721464, 8.623055890202522, 2.7622380293905735, 1.4855646039359272, 0.21252385777188465, 0.06668599860859104, 0.37680823530536145, 19.82575535774231, 49.93881270289421, 37.96300671994686, 21.32137220352888, 24.177709333598614, 38.07649902999401, 48.246793895959854, 47.24369712173939, 18.085281550884247, 0.6784272927325219, 0.031339297056547366, 0.032117431474034674, 0.042567972850520164, 0.04871657358307857, 0.05604007943475153, 0.005230633632891113, 0.038192923238966614, 0.032023709354689345, 0.06908456794917583, 0.02222745093604317, 0.043595008755801246, 0.01075854657756281, 0.04834102830500342, 0.02509958099835785, 0.014371753768500639, 0.07031855915556662, 0.08214875677367672, 0.03255611125496216, 0.031368938434752636, 0.0902686761401128, 0.023277480431715958, 0.09270611175452359, 0.022392871942429338, 0.014821256845607422, 0.03144343521853443, 0.04399996163556352, 0.02599159983219579, 0.07042049313895404, 0.01227748723977129, 0.011530649189808173, 0.00846746990646352, 0.039853419293649495, 0.12308424222283065, 9.539227578788996, 43.9373729377985, 51.039708629250526, 46.322375759482384, 35.70252701640129, 21.983912251889706, 30.16230270266533, 40.49771390855312, 28.666511066257954, 1.739110155031085, 0.11553867836482823, 0.5158005910925567, 2.2116264374926686, 4.487083274871111, 11.403267905116081, 14.220634326338768, 10.210723746567965, 28.33012841641903, 53.02384816110134, 55.54866448044777, 54.038340523839, 51.61260388791561, 52.885858565568924, 49.22931857407093, 49.89255018532276, 49.65652585029602, 50.454296842217445, 51.25673398375511, 51.385930851101875, 52.23855949938297, 52.093563079833984, 52.37471379339695, 51.35900929570198, 47.64946594834328, 51.12849086523056, 51.94429948925972, 47.609932869672775, 39.6863928437233, 42.01615422964096, 45.185925140976906, 47.488062009215355, 50.31747758388519, 49.0523012727499, 48.089337944984436, 42.21617549657822, 40.01442924141884, 37.831389382481575, 38.86887811124325, 40.093377605080605, 37.8572241961956, 37.79566749930382, 39.90581966936588, 36.759045124053955, 40.76464578509331, 38.61521892249584, 38.863995373249054, 38.927049189805984, 39.18779879808426, 38.3242267370224, 43.13771344721317, 48.97215597331524, 51.89822696149349, 51.03775553405285, 50.72859272360802, 43.96380431950092, 50.791600942611694, 45.83839572966099, 48.232860043644905, 43.465803042054176, 50.630276799201965, 30.36640305072069, 33.1912911683321, 53.416063115000725, 50.147425308823586, 54.80140797793865, 49.894636273384094, 45.57622879743576, 40.667933374643326, 39.57036606967449, 40.500742346048355, 37.8248955309391, 38.389986008405685, 40.622115433216095, 40.93040429055691, 40.3710401058197, 40.154554322361946, 39.18082617223263, 41.14495597779751, 40.036775842309, 39.53074939548969, 40.63021279871464, 40.80001808702946, 40.276208594441414, 40.71646437048912, 40.085850208997726, 39.61188264191151, 40.25442436337471, 39.087089002132416, 39.81643706560135, 39.84098754823208, 40.679062977433205, 43.75586807727814, 44.42819260060787, 44.862725883722305, 41.800766587257385, 40.79942911863327, 40.38525894284248, 41.3048779964447, 44.01100918650627, 48.3109762519598, 49.65868033468723, 50.169095546007156, 52.53147058188915, 53.31390179693699, 49.63874660432339, 50.98563753068447, 54.622730165719986, 53.388708382844925, 50.552586168050766, 50.33811427652836, 51.93014904856682, 57.674707397818565, 54.47252422571182, 51.820916309952736, 27.087813578546047, 13.376684412360191, 12.23860653117299, 8.792601842433214, 8.281686957925558, 2.4179292423650622, 0.5405015219002962, 0.06051010910596233, 0.44229766179341823, 22.306628935039043, 52.81077079474926, 41.4667759090662, 21.2093960121274, 26.52175035327673, 43.40529128909111, 52.9661862552166, 55.68053640425205, 22.89198562502861, 0.8536515652667731, 0.0617897609481588, 0.018659052766452078, 0.00106249386590207, 0.05909331579459831, 0.029637832594744395, 0.05311069638992194, 0.0425394595367834, 0.02436199752992252, 0.036700182245112956, 0.020616962647181936, 0.030256099125836045, 0.03208788657502737, 0.08416065233177505, 0.0946010671032127, 0.020288786799937952, 0.05584052705671638, 0.2334113814868033, 0.20149787364061922, 0.17591574636753649, 0.22106027783593163, 0.08286789787234738, 0.12306448625167832, 0.09831901916186325, 0.17635091207921505, 0.10714967851527035, 0.17840431595686823, 0.12743034807499498, 0.20757825986947864, 0.09673522406956181, 0.090418953623157, 0.13005962886381894, 0.11815586956799962, 0.42967114713974297, 15.029331631958485, 52.419729977846146, 57.339717373251915, 54.31028813123703, 43.144507482647896, 26.827787831425667, 35.228810235857964, 47.368953600525856, 34.57716800272465, 2.4721088726073503, 0.20273633999750018, 1.0215339786373079, 4.3896593526005745, 18.984062522649765, 21.721580028533936, 32.07793191075325, 24.668346606194973, 34.147232472896576, 53.87133948504925, 57.16141574084759, 56.301749870181084, 52.90754400193691, 53.81845012307167, 50.82835637032986, 50.988548174500465, 49.987419694662094, 51.40065886080265, 50.64169518649578, 52.34923616051674, 53.51737707853317, 53.166902884840965, 54.74992074072361, 53.588843643665314, 50.93865305185318, 53.79375524818897, 55.45740857720375, 49.76299233734608, 42.817569226026535, 43.43290440738201, 48.132857009768486, 50.92515617609024, 51.8512386828661, 53.42464305460453, 50.63758760690689, 44.99199874699116, 42.76132844388485, 40.78386515378952, 40.05091108381748, 40.711125656962395, 40.7101035118103, 40.167663618922234, 42.90752939879894, 38.93218271434307, 42.0968808978796, 41.29227787256241, 41.945291832089424, 40.31331740319729, 41.08687989413738, 40.736713483929634, 46.71428292989731, 52.383989095687866, 54.87268075346947, 51.23552352190018, 52.7811323851347, 45.75948916375637, 51.752683371305466, 46.75619088113308, 50.134243816137314, 45.721514001488686, 51.16924747824669, 32.2271803021431, 36.06067679822445, 52.63610176742077, 52.229557782411575, 56.08877129852772, 52.52178110182285, 48.34775447845459, 43.25595170259476, 41.70134112238884, 42.5764911621809, 40.16199812293053, 40.052396804094315, 42.583372592926025, 43.24611023068428, 42.99907028675079, 41.788975819945335, 39.878784120082855, 45.47612316906452, 41.30803182721138, 42.360176369547844, 41.673785001039505, 42.918731197714806, 41.91537983715534, 44.38794136047363, 42.504583820700645, 41.43596716225147, 41.47283658385277, 40.96644155681133, 43.207964077591896, 41.388059332966805, 42.75541216135025, 48.63423630595207, 47.11086764931679, 45.55553510785103, 44.23963151872158, 44.829686656594276, 42.890373319387436, 44.42998230457306, 46.77041731774807, 50.34630283713341, 50.89437782764435, 51.72546923160553, 53.19329246878624, 55.85357531905174, 48.96803319454193, 52.176964804530144, 56.52757555246353, 56.84640124440193, 53.47622148692608, 52.56020084023476, 53.96488666534424, 61.06248401105404, 55.24280749261379, 56.22101940214634, 29.83438979834318, 22.68637675791979, 19.955835677683353, 19.859459549188614, 10.231486782431602, 6.218279879540205, 1.213339848909527, 0.2210785643546842, 0.6539601681288332, 26.787188909947872, 60.19315145909786, 45.670558735728264, 31.612682975828648, 35.22363871335983, 51.234862357378006, 60.018486231565475, 62.95831248164177, 27.48249650001526, 1.6678611282259226, 0.23335904523264617, 0.11287257220828906, 0.11112520776805468, 0.14213578164344653, 0.12828674196498469, 0.0930801170761697, 0.20484751265030354, 0.13427756581222638, 0.17319734848570079, 0.08478213421767578, 0.09400937502505258, 0.1387831146712415, 0.17554219375597313, 0.19265744020231068, 0.08800485113169998, 0.1289086468750611], [0.037188660135143436, 0.036072859656997025, 0.011738974681065883, 0.015622715109202545, 0.032751399994594976, 0.07141805093851872, 0.0013316158629095298, 0.05555983567319345, 0.03193415068381, 0.03002635989105329, 0.04923845554003492, 0.05471526790643111, 0.05303713471221272, 0.035178875987185165, 0.03627621554187499, 0.04181632939435076, 0.4100517608458176, 12.982899192720652, 34.73240867257118, 46.55784152448177, 37.48143956065178, 28.347123004496098, 16.48031037300825, 19.589250348508358, 31.114050932228565, 21.665531136095524, 0.26674328197259456, 0.07580414370750077, 0.7780993287451565, 1.61278807092458, 2.3052940238267183, 4.565264079719782, 18.90144355595112, 15.186607092618942, 31.040116399526596, 53.46351116895676, 51.294826939702034, 50.60833677649498, 51.02854482829571, 41.265751495957375, 50.87888985872269, 45.29473230242729, 51.42823778092861, 50.3316356241703, 52.0891173183918, 51.5948436409235, 48.93820859491825, 46.25913955271244, 48.57549145817757, 48.19612741470337, 53.25120896100998, 50.10442301630974, 49.67324875295162, 41.34107105433941, 37.78391852974892, 40.70950694382191, 43.18536289036274, 47.59866647422314, 48.60933244228363, 48.69595639407635, 47.58185997605324, 47.25975126028061, 45.43480418622494, 40.76092578470707, 38.79764333367348, 35.60596279799938, 37.258566319942474, 35.171193927526474, 35.412971153855324, 37.37417511641979, 36.65041275322437, 35.890943706035614, 38.14058639109135, 37.487849816679955, 38.015679493546486, 37.11125582456589, 46.252695098519325, 47.1391761302948, 52.68343202769756, 48.869284093379974, 46.71181306242943, 45.14470495283604, 48.52870836853981, 45.069001615047455, 45.83558768033981, 42.097082287073135, 49.38503801822662, 32.933277413249016, 34.3651469796896, 50.7432447373867, 48.797141164541245, 51.52465760707855, 48.16952504217625, 43.65322418510914, 38.31816226243973, 41.03385753929615, 36.27571485936642, 38.54792073369026, 36.95261053740978, 37.46609218418598, 37.61581934988499, 39.02902811765671, 38.62947195768356, 37.76032939553261, 37.74380408227444, 38.94964657723904, 37.61354327201843, 37.93573938310146, 38.865933269262314, 39.27972726523876, 41.594118475914, 42.57622517645359, 40.44022299349308, 39.88235592842102, 38.43214474618435, 38.07481572031975, 37.92961411178112, 45.09925939142704, 46.973508819937706, 47.7524708211422, 44.584048837423325, 42.8687334805727, 41.74577973783016, 38.52930173277855, 38.11189033091068, 41.852740198373795, 43.0672462284565, 47.768718749284744, 45.60305915772915, 51.066102012991905, 51.37176141142845, 51.16073213517666, 50.214799493551254, 55.25745190680027, 55.93595489859581, 50.04257373511791, 46.84249944984913, 52.44798146188259, 53.34085755050182, 57.45510958135128, 51.737883165478706, 34.081005826592445, 9.314286299049854, 8.849495239555836, 4.2306972574442625, 3.842764673754573, 1.8829622422344983, 0.26443870563525707, 0.04471371474210173, 0.02767930487607373, 11.571478229016066, 43.381740152835846, 35.15550456941128, 23.879944011569023, 24.9872387945652, 34.8189452290535, 46.70940399169922, 48.739661648869514, 22.16828975826502, 0.5640406056772918, 0.03551238602085505, 0.03138977052003611, 0.025558799716236535, 0.03937806628528051, 0.08940591462305747, 0.03933709973352961, 0.020770561241079122, 0.05564540158957243, 0.08978583486168645, 0.037796252727275714, 0.03301662873127498, 0.051975819005747326, 0.08485205195029266, 0.03900191244611051, 0.021890250573051162, 0.12100438820198178, 0.045820167870260775, 0.03390217047126498, 0.047690773353679106, 0.040160085845855065, 0.06150069442810491, 0.05540211444895249, 0.03858712239889428, 0.0671845066244714, 0.027011238380509894, 0.022398822111426853, 0.015577648191538174, 0.03407058604352642, 0.0527446654450614, 0.017436351481592283, 0.03608092309150379, 0.04281691515643615, 0.7578382221981883, 15.76553737744689, 43.23304273188114, 51.24924458563328, 42.61197365820408, 32.230539321899414, 18.089269436895847, 24.44941185414791, 37.15384393930435, 26.363576240837574, 0.5617784801870584, 0.03134851453069132, 0.800350756617263, 3.389091342687607, 9.272625334560871, 11.311668120324612, 8.1690239533782, 14.436590988188982, 32.82234616577625, 53.458476439118385, 54.342423006892204, 51.08876779675484, 51.456797048449516, 46.14383094012737, 52.67371974885464, 45.33253647387028, 52.17820733785629, 52.03920319676399, 53.99814248085022, 53.66634428501129, 49.789598509669304, 48.702480643987656, 50.52192561328411, 50.34815713763237, 54.192125871777534, 52.908721938729286, 51.69526465237141, 44.00500550866127, 39.7792636603117, 43.461300283670425, 46.82125858962536, 48.909322544932365, 50.973850563168526, 50.79085238277912, 48.379486575722694, 49.50484558939934, 46.46736457943916, 42.82743729650974, 39.96384635567665, 38.146578669548035, 39.62678164243698, 36.42838306725025, 37.17950016260147, 37.23159156739712, 38.000313118100166, 37.614421024918556, 39.085766673088074, 39.316953867673874, 38.68945553898811, 38.206391260027885, 47.28788495063782, 50.1243681460619, 54.069517850875854, 51.230291202664375, 48.03090088069439, 46.18896871805191, 49.20154206454754, 45.77562689781189, 47.046601697802544, 43.20587798953056, 48.79694737493992, 35.6094928085804, 35.84367424249649, 49.71390277147293, 49.276717230677605, 53.25839817523956, 50.0081779807806, 45.02382583916187, 40.200748443603516, 41.490163654088974, 38.44177722930908, 40.632629469037056, 38.306926265358925, 39.16510261595249, 39.29168522357941, 39.981025233864784, 40.29041223227978, 39.645624831318855, 39.49845492839813, 40.03330662846565, 40.23409925401211, 39.54076945781708, 39.9011155217886, 41.27750426530838, 43.237625285983086, 44.710791036486626, 41.395898312330246, 41.48643605411053, 40.40076591074467, 39.8707627505064, 39.04787890613079, 47.50788934528828, 48.623304292559624, 49.64764952659607, 46.145126670598984, 45.61383917927742, 43.80241557955742, 40.97144588828087, 40.850574374198914, 43.634217604994774, 45.591203793883324, 49.91053082048893, 48.79251301288605, 52.19444766640663, 53.71893346309662, 52.48016573488712, 51.38859450817108, 55.79315096139908, 57.54984989762306, 50.14667674899101, 48.682413920760155, 53.90437491238117, 54.79717880487442, 58.465638756752014, 52.93696962296963, 35.90756021440029, 9.910742193460464, 9.293691404163837, 11.184433847665787, 5.628734389320016, 5.20142356865108, 1.1822520545683801, 0.06742937825038098, 0.10722578575951047, 13.50405452772975, 49.958461448550224, 46.15913271903992, 30.07878128439188, 30.234571024775505, 39.69629891216755, 51.946594566106796, 54.14320349693298, 26.62335880100727, 0.9090473083779216, 0.04039160252432339, 0.08498172741383314, 0.05411118196207099, 0.027988166330032982, 0.07062698830850422, 0.08114051204756834, 0.06456491086282767, 0.03265833838668186, 0.11469411430880427, 0.0365211465395987, 0.03849095861369278, 0.05847591572091915, 0.12129542141337879, 0.0577488930139225, 0.010718430712586269, 0.06997372023761272, 0.13271638395963237, 0.1127927987545263, 0.0820630016096402, 0.13709288818063214, 0.09907341227517463, 0.19357203331310302, 0.12219646290759556, 0.20292560249799863, 0.10308495795470662, 0.10956300917314366, 0.1512210347573273, 0.16212846821872517, 0.10537917391047813, 0.1682173297740519, 0.1362974543008022, 0.12584244890604168, 1.125834344420582, 18.93951941281557, 50.593806356191635, 58.84624533355236, 50.15583425760269, 40.33899262547493, 25.7816868647933, 30.438791066408157, 43.60668808221817, 29.651714600622654, 0.6795450858771801, 0.2227501480956562, 1.2468132027424872, 5.216932911425829, 7.616801960393786, 11.575590558350086, 30.645161792635918, 21.95040374994278, 34.236618876457214, 55.877707824110985, 54.54717501997948, 52.34844960272312, 53.73851001262665, 47.37472929060459, 54.0321696549654, 48.948494642972946, 51.413946747779846, 52.960239574313164, 56.404534354805946, 56.89733751118183, 52.46263347566128, 51.41307659447193, 52.81018562614918, 54.56407651305199, 56.95875741541386, 54.363492876291275, 54.76773038506508, 46.014501079916954, 42.184249609708786, 45.83740398287773, 49.117194190621376, 52.181836143136024, 53.44351664185524, 53.642739951610565, 51.80848717689514, 52.2980111092329, 49.03953395783901, 44.92102615535259, 41.74091599881649, 38.90102058649063, 42.54294276237488, 38.835097923874855, 38.60787011682987, 39.92663115262985, 39.90329660475254, 39.47513557970524, 42.01829731464386, 40.723987966775894, 40.47725960612297, 39.69312608242035, 49.110521748661995, 52.71496273577213, 54.795252308249474, 52.340587824583054, 49.77087691426277, 48.236059471964836, 50.132925286889076, 48.03312376141548, 48.5267248749733, 45.34740507602692, 48.20432357490063, 37.64253191649914, 38.49874757230282, 51.63342297077179, 53.02067153155804, 54.79195788502693, 51.634722501039505, 48.443304151296616, 42.784340009093285, 43.536247462034225, 40.606388077139854, 42.95178182423115, 41.5335763245821, 40.66807396709919, 41.67921110987663, 42.66465783119202, 43.2946602255106, 41.82351216673851, 41.917602717876434, 43.31517152488232, 42.41065666079521, 41.74734905362129, 42.470454052090645, 43.152627646923065, 44.77494299411774, 47.8805847465992, 43.85122016072273, 44.4890121370554, 43.82121317088604, 40.85482634603977, 41.07195049524307, 51.375504210591316, 51.656407937407494, 53.14872086048126, 50.18970564007759, 48.1763456761837, 46.50016821920872, 43.08787152171135, 41.99438139796257, 46.521219089627266, 48.9797555655241, 52.734782472252846, 50.274175107479095, 53.72593268752098, 54.770325645804405, 53.779137432575226, 51.216399148106575, 57.56367355585098, 61.82921826839447, 53.77137064933777, 50.90360373258591, 55.712754875421524, 57.20376826822758, 61.58012643456459, 55.567826852202415, 38.80314163863659, 11.10409950837493, 14.17578723281622, 14.431274123489857, 11.546470820903778, 7.354591805487871, 1.402618617285043, 0.25696254742797464, 0.3682524897158146, 16.090753376483917, 54.98192109167576, 49.393982738256454, 34.328554943203926, 35.220682471990585, 48.01089495420456, 60.468442887067795, 63.17860946059227, 32.599830105900764, 1.3482459099031985, 0.12804526195395738, 0.14052008162252605, 0.10806557780597359, 0.08089688722975552, 0.20423248002771288, 0.09651258718804456, 0.20741293905302882, 0.11948569430387579, 0.27440325531642884, 0.20522964448900893, 0.1326812952174805, 0.17269607225898653, 0.17572350043337792, 0.15297115256544203, 0.07921541066025384, 0.2496447932207957], [0.04501750547206029, 0.04475035828363616, 0.0668421242153272, 0.05109919045935385, 0.01617400281247683, 0.05411792066297494, 0.033908671684912406, 0.08228822116507217, 0.029477964708348736, 0.060406672273529693, 0.044855468659079634, 0.02516857104637893, 0.04656888726458419, 0.09527267364319414, 0.04928426460537594, 0.008282792950922158, 0.20630927640013397, 12.048878911882639, 36.614766865968704, 44.3519838899374, 35.22485464811325, 22.382691353559494, 22.567661628127098, 28.15439734607935, 37.27662295103073, 15.244158804416656, 0.3410269506275654, 0.8219047437887639, 21.46373726427555, 4.899247158318758, 4.797102939337492, 12.09353506565094, 7.01975567266345, 18.513051196932793, 37.491718009114265, 55.94407506287098, 51.52646251022816, 50.806556940078735, 50.69309122860432, 46.81535750627518, 43.69751840829849, 48.844862803816795, 49.678876250982285, 55.2835489064455, 49.959726780653, 48.83143052458763, 45.02910755574703, 45.07146008312702, 46.232525780797005, 46.453183740377426, 47.01515458524227, 47.79147192835808, 44.2382787913084, 40.67456781864166, 39.50543895363808, 43.40755216777325, 46.61690175533295, 49.482521787285805, 49.50417302548885, 49.179723635315895, 46.76029086112976, 48.387728333473206, 49.11921188235283, 46.091275960206985, 40.254849940538406, 36.807040348649025, 34.73736360669136, 35.07086031138897, 36.370204389095306, 36.61878705024719, 37.936598137021065, 36.607444658875465, 37.58558437228203, 34.7436560690403, 37.68839165568352, 41.37454345822334, 49.59575191140175, 49.019630625844, 50.7819152623415, 42.43023321032524, 47.51736603677273, 46.50673046708107, 49.10568080842495, 46.102705746889114, 46.91773161292076, 44.867072850465775, 47.307366505265236, 33.37202847003937, 34.80973072350025, 52.400256022810936, 50.33022589981556, 50.90456508100033, 45.20585507154465, 41.23943030834198, 37.17941276729107, 37.06930987536907, 36.961479261517525, 38.242458924651146, 35.478453040122986, 38.84273171424866, 37.3454562574625, 37.7052703499794, 38.59016306698322, 38.53897221386433, 37.72746875882149, 37.81132645905018, 39.11062873899937, 41.01445198059082, 42.57003150880337, 45.202123671770096, 45.674221739172935, 45.654421001672745, 46.00872538983822, 43.46415773034096, 42.01159067451954, 40.60506574809551, 44.541232734918594, 48.51684160530567, 49.01853248476982, 46.82768024504185, 45.59289090335369, 43.42160001397133, 40.2392365783453, 38.39475095272064, 39.011788442730904, 40.47275684773922, 41.8061812967062, 41.92302882671356, 46.37034058570862, 50.71242079138756, 52.32707194983959, 48.73496130108833, 51.471844241023064, 54.02183420956135, 51.93218573927879, 49.06014025211334, 47.784746289253235, 52.79243677854538, 56.65526010096073, 57.90785148739815, 49.856262132525444, 41.32612265646458, 20.101407766342163, 13.107600901275873, 6.6124864015728235, 10.11335777118802, 1.9194300728850067, 0.7650534412823617, 0.18350021360674873, 0.014382552017195849, 7.18189487233758, 35.56368626654148, 32.31006905436516, 15.790142007172108, 17.78532564640045, 29.061005897819996, 44.56181243062019, 48.54524128139019, 18.730338737368584, 1.1809554928913713, 0.04410746543726418, 0.0768307714315597, 0.02779920254397439, 0.09066613332834095, 0.01825926152378088, 0.06182064171298407, 0.031055395884322934, 0.022787531233916525, 0.047658215335104614, 0.029357161620282568, 0.06498146351077594, 0.07042552490020171, 0.03038058326637838, 0.026603905062074773, 0.03612736669310834, 0.02465716821461683, 0.05284252132696565, 0.04245572301442735, 0.08778264469583519, 0.07446396601153538, 0.012685648980550468, 0.03971225909481291, 0.018505908738006838, 0.05502184540091548, 0.03199459119059611, 0.03586357030144427, 0.06305069953668863, 0.038614567019976676, 0.059393366100266576, 0.057437977666268125, 0.013465215743053705, 0.01904512169858208, 0.23645730398129672, 14.130259025841951, 42.69816443324089, 50.62439851462841, 41.080724224448204, 30.266533009707928, 27.627920396625996, 30.53069293498993, 40.654075518250465, 19.42208021879196, 0.21707067004172131, 0.9327819035388529, 20.908881537616253, 6.715068547055125, 5.494344625622034, 13.326047379523516, 8.177066221833229, 18.854155093431473, 38.312842547893524, 57.164235189557076, 51.73432655632496, 51.459050327539444, 52.441920787096024, 48.28433208167553, 46.912871673703194, 48.67277003824711, 50.540331825613976, 56.09700545668602, 52.082243487238884, 51.66632920503616, 47.88735218346119, 47.65584200620651, 48.89180548489094, 49.46436636149883, 50.03276266157627, 49.468090161681175, 47.333227917551994, 41.36556454002857, 41.49184696376324, 45.50661653280258, 48.81765626370907, 51.557632237672806, 50.264253839850426, 50.05307637155056, 49.434328973293304, 49.971555545926094, 51.44773453474045, 47.52618536353111, 42.11084134876728, 39.27253805100918, 37.015082985162735, 37.26046621799469, 37.855373695492744, 38.099408000707626, 39.92959879338741, 39.000453650951385, 38.3901683986187, 37.706140503287315, 39.20598842203617, 43.57887737452984, 49.823462292551994, 50.71549102663994, 52.499084919691086, 44.538120701909065, 46.98804683983326, 47.99740947782993, 49.29869145154953, 47.990414053201675, 47.986872643232346, 44.257498160004616, 48.09618137776852, 35.270220413804054, 36.86260096728802, 52.65011541545391, 53.624645322561264, 53.81330519914627, 47.072618901729584, 42.37563394010067, 38.974881023168564, 39.52902048826218, 39.867859706282616, 39.21909771859646, 38.664768263697624, 40.275771617889404, 39.05030317604542, 38.55920992791653, 39.857467263937, 39.29833486676216, 38.859819397330284, 38.60625520348549, 40.97161307930946, 42.48316437005997, 45.169673413038254, 46.10785447061062, 48.471171855926514, 47.125656455755234, 48.27782303094864, 45.62182255089283, 43.37660662829876, 41.687076687812805, 46.08964964747429, 50.40601283311844, 52.04048752784729, 47.459479942917824, 47.783579751849174, 45.96223868429661, 43.077517077326775, 40.09999305009842, 39.56491716206074, 43.58055308461189, 44.007008001208305, 45.6576432287693, 48.13188426196575, 50.949615463614464, 54.828534722328186, 50.126423835754395, 51.358180940151215, 54.28107529878616, 55.06306193768978, 52.24322944879532, 49.04695115983486, 55.643948167562485, 58.214745819568634, 59.62396860122681, 50.82039199769497, 44.14560176432133, 16.277560852468014, 4.183786399662495, 7.1940285712480545, 11.455120872706175, 4.794205594807863, 2.153339465148747, 0.13954136695247144, 0.0445424419012852, 8.607372231781483, 41.2257282435894, 35.067014917731285, 14.874329399317503, 20.133326053619385, 33.05995501577854, 50.01555718481541, 54.20790262520313, 24.256946481764317, 1.3984095118939877, 0.02285361577378353, 0.05459976746351458, 0.044339152809698135, 0.0404710531438468, 0.03123359667370096, 0.04346178953710478, 0.06738717231201008, 0.017474946871516295, 0.06042997942131478, 0.049073921400122344, 0.04824502037081402, 0.037917449153610505, 0.03703643822518643, 0.016828842381073628, 0.052739886014023796, 0.0568463746458292, 0.16110642696730793, 0.10441605918458663, 0.17977657669689506, 0.18359022127697244, 0.11740197369363159, 0.1691771048353985, 0.14551944070262834, 0.17747320263879374, 0.06644552791840397, 0.19734239584067836, 0.1827538653742522, 0.1611949354992248, 0.13020880054682493, 0.1706273207673803, 0.12394898527418263, 0.1540168237988837, 0.5733645928557962, 17.46172361075878, 52.068575620651245, 56.507573425769806, 47.851402312517166, 34.21196199953556, 34.41020876169205, 36.85749404132366, 49.20681618154049, 21.8425028398633, 0.5201762344222516, 1.1939550703391433, 30.23488260805607, 8.597420565783978, 11.617415864020586, 22.22951017320156, 12.84744881093502, 21.37280434370041, 38.933892622590065, 59.89340454339981, 52.295750230550766, 53.84215705096722, 51.85774013400078, 49.810523986816406, 45.86971364915371, 49.85026225447655, 52.095930352807045, 59.57812026143074, 53.7619623541832, 53.25920753180981, 48.98771233856678, 49.24156911671162, 51.219701170921326, 52.68408939242363, 50.424438044428825, 52.995174899697304, 49.04070809483528, 43.67052845656872, 45.06664574146271, 47.74286113679409, 51.97327673435211, 52.717922776937485, 52.386504560709, 51.053444892168045, 48.71927194297314, 51.60278141498566, 53.783518597483635, 50.64316190779209, 43.53555589914322, 41.07108414173126, 38.80803197622299, 39.0126433968544, 40.13679787516594, 40.51525376737118, 42.173196002840996, 40.698734521865845, 40.84861747920513, 39.967767745256424, 41.52807042002678, 46.13271653652191, 52.57442347705364, 53.23037847876549, 52.12672010064125, 44.52356368303299, 47.815213054418564, 49.00977775454521, 50.90234600007534, 49.75158154964447, 48.89877051115036, 46.6860656440258, 47.88853392004967, 37.82335661351681, 39.999781027436256, 54.397219866514206, 55.551860108971596, 55.79753212630749, 48.69773469865322, 43.159102499485016, 41.0898095369339, 41.14759303629398, 41.45544491708279, 41.55678167939186, 39.87893991172314, 42.77101792395115, 40.61281353235245, 41.951356306672096, 42.57678374648094, 42.07282438874245, 39.71171848475933, 41.58844158053398, 43.784712329506874, 45.21630071103573, 47.66412936151028, 48.272271528840065, 51.35074473917484, 50.892420932650566, 51.52198635041714, 47.92561613023281, 45.75658991932869, 44.27651233971119, 48.964708372950554, 53.112930580973625, 53.88066418468952, 50.09724900126457, 50.19150674343109, 49.86238740384579, 45.33977888524532, 42.76600979268551, 43.286958038806915, 45.59995472431183, 47.18733474612236, 47.123384177684784, 49.597085639834404, 53.53791497647762, 56.6500049829483, 51.66512846946716, 53.42217318713665, 55.39800636470318, 57.52777308225632, 53.96454468369484, 53.079006001353264, 57.56990522146225, 61.20307646691799, 61.14515237510204, 53.988320007920265, 45.706360414624214, 24.61711585521698, 22.109548710286617, 15.332877393811941, 15.052302349358797, 6.652929056435823, 2.3358529340475798, 0.4860168689629063, 0.15373761299997568, 9.907130487263203, 46.145024076104164, 44.17432822287083, 24.895076639950275, 28.695060834288597, 40.97228564321995, 57.62589901685715, 64.64887216687202, 30.140938349068165, 2.1284006908535957, 0.1598384973476641, 0.1789457572158426, 0.14826682687271386, 0.1846681017195806, 0.09979583366657607, 0.1230426671099849, 0.1552022117539309, 0.12894806975964457, 0.13357372779864818, 0.2098832666524686, 0.21216354507487267, 0.21230039710644633, 0.09991139348130673, 0.15387667663162574, 0.15658219082979485, 0.11269052338320762], [0.035842771612806246, 0.05415284613263793, 0.03328235470689833, 0.14642028923844919, 0.02408210581052117, 0.0335278052079957, 0.032867520130821504, 0.0031990393881642376, 0.008868717613950139, 0.06590823526494205, 0.018233920891361777, 0.03490979921480175, 0.09741743589984253, 0.04373580901301466, 0.03092250321060419, 0.0512801965669496, 0.17132134758867323, 12.51206360757351, 35.998572930693626, 43.395263627171516, 34.20995570719242, 17.66459282487631, 12.139062322676182, 22.988658137619495, 32.47540958225727, 15.062045026570559, 0.057329794799443334, 1.7516221711412072, 26.520055644214153, 8.798751812428236, 10.170235019177198, 12.53869827836752, 7.964910781010985, 25.77281054109335, 44.71605375409126, 53.04720550775528, 52.51605860888958, 50.38562312722206, 46.784940138459206, 49.878308549523354, 50.120473355054855, 48.410177528858185, 52.77591146528721, 50.610631853342056, 51.270398050546646, 45.850604474544525, 43.19581612944603, 41.68986573815346, 43.00131596624851, 42.708545476198196, 44.87263195216656, 43.828360587358475, 41.85891106724739, 41.78066186606884, 44.57850493490696, 46.664836183190346, 49.13995876908302, 48.32925707101822, 49.94885556399822, 50.77784188091755, 48.05252932012081, 47.88683161139488, 49.13549780845642, 45.173097029328346, 41.93890817463398, 38.16505327820778, 37.667492777109146, 36.100487262010574, 35.69459304213524, 36.700022891163826, 37.18690976500511, 34.669734835624695, 36.89238376915455, 37.14201137423515, 38.97676192224026, 48.35421793162823, 50.64131900668144, 49.2425836622715, 43.7425421923399, 43.222437500953674, 50.74895963072777, 45.23155689239502, 51.092514395713806, 46.574222445487976, 48.687680438160896, 44.01216432452202, 48.25816668570042, 33.61688353121281, 34.735292717814445, 55.69582678377628, 48.078189343214035, 48.299926444888115, 42.660257667303085, 37.75847889482975, 38.15985135734081, 36.651263907551765, 35.759409964084625, 34.09859128296375, 36.7479345202446, 36.91474176943302, 37.70675227046013, 36.498462706804276, 36.95240154862404, 35.319955945014954, 37.169084921479225, 37.283435985445976, 40.66277325153351, 42.136201187968254, 47.493172734975815, 48.37981715798378, 52.66694851219654, 52.27987468242645, 51.34867005050182, 48.906715884804726, 47.03243985772133, 46.57636173069477, 49.11257743835449, 50.1547247171402, 48.916815742850304, 50.026652589440346, 46.34179271757603, 43.304254710674286, 38.73949505388737, 37.45777443051338, 37.91477590799332, 39.73208539187908, 41.426657661795616, 40.187129974365234, 47.22461074590683, 48.969237729907036, 54.32949610054493, 52.36579567193985, 53.01556080579758, 52.33820915222168, 53.1026179343462, 48.34897041320801, 48.94411347806454, 50.11969439685345, 54.01460699737072, 56.37975588440895, 57.287485376000404, 44.3103951215744, 28.23086254298687, 10.93170940876007, 10.07529616355896, 6.14649698138237, 5.723715042695403, 2.726887813769281, 0.1674275065306574, 0.1354636365431361, 3.949896600097418, 39.17034633457661, 51.17989830672741, 39.006293937563896, 36.33676238358021, 38.74640308320522, 50.73926255106926, 47.63540290296078, 20.402913987636566, 1.050177316647023, 0.06030393677065149, 0.03556648858648259, 0.0463732608477585, 0.09493170873611234, 0.08117434656014666, 0.02541909783758456, 0.02701026987779187, 0.015272685795935104, 0.05438375796074979, 0.048911253761616535, 0.055390692796208896, 0.0945450720610097, 0.06792264670366421, 0.011335881808918202, 0.032765719734015875, 0.018538516851549502, 0.04475644389458466, 0.037932151099084876, 0.005872033834748436, 0.09025297971675172, 0.006841740687377751, 0.03778158417844679, 0.04379935911856592, 0.045046805462334305, 0.10073227560496889, 0.04059108810906764, 0.035169888578820974, 0.02717814739298774, 0.014767936318094144, 0.03697457650559954, 0.04425929029821418, 0.039512372750323266, 0.3112174611305818, 15.35566857084632, 43.168484196066856, 50.00793859362602, 38.89693580567837, 21.821909844875336, 15.957002453505993, 27.175604067742825, 38.03565502166748, 16.71964433044195, 0.06651752366451547, 2.0128809520974755, 29.890303798019886, 12.57085595279932, 10.906240325421095, 14.447085075080395, 7.755599487572908, 24.399283044040203, 44.76678103208542, 53.39801408350468, 53.325810357928276, 51.15230418741703, 47.78681717813015, 50.10231412947178, 50.20073264837265, 48.96908573806286, 53.627639561891556, 50.84319457411766, 53.354871198534966, 46.74389474093914, 45.313180312514305, 43.388393595814705, 44.257729947566986, 45.320133939385414, 47.64880858361721, 47.1601016074419, 44.69504088163376, 44.413909167051315, 47.157506346702576, 48.43837961554527, 52.0706807076931, 50.174514055252075, 51.68312810361385, 51.330526024103165, 49.97089438140392, 51.08165457844734, 49.971008375287056, 48.77933531999588, 44.42921854555607, 39.84690763056278, 40.621781051158905, 37.54685305058956, 37.63559728860855, 37.98650465905666, 38.2798907160759, 36.81913509964943, 39.429427832365036, 38.561729192733765, 41.59518621861935, 48.17919172346592, 52.86319278180599, 51.66920565068722, 43.86488422751427, 44.34997379779816, 51.99328266084194, 48.5971312969923, 51.94562181830406, 48.7469382584095, 50.09407997131348, 45.70402354001999, 48.18868741393089, 34.79466833174229, 36.704575046896935, 57.0355398952961, 50.62625281512737, 50.634847953915596, 44.6187599748373, 39.78309765458107, 40.47079235315323, 38.95872049033642, 37.012176141142845, 36.07450805604458, 38.39057877659798, 39.61055651307106, 39.43024858832359, 39.86057169735432, 38.3605869859457, 37.7676136046648, 39.619752019643784, 39.794421046972275, 43.04827384650707, 43.80319453775883, 48.3277827501297, 50.19787520170212, 55.056625083088875, 52.70938843488693, 52.48934604227543, 51.66510187089443, 48.94993096590042, 47.57714442908764, 50.52128344774246, 53.5978377610445, 50.971878468990326, 51.506262794137, 49.93941307067871, 45.320092141628265, 41.86357721686363, 39.89410489797592, 40.14286994934082, 40.94937667250633, 42.406062707304955, 41.41571044921875, 49.3176182359457, 52.43063159286976, 55.43610692024231, 50.94979405403137, 52.8073737770319, 55.177234411239624, 56.42840847373009, 50.13460099697113, 51.45186111330986, 53.017240315675735, 54.771328791975975, 58.69376711547375, 58.11623230576515, 45.58224007487297, 36.462087258696556, 16.975539699196815, 9.252036139369011, 4.908489212393761, 6.227446412667632, 2.5262051448225975, 0.1733208418590948, 0.10907249408774078, 5.220806328579783, 40.18342897295952, 49.862205013632774, 41.63389474153519, 39.91344965994358, 43.0167431384325, 55.828135684132576, 54.52893599867821, 25.109240747988224, 1.7557808104902506, 0.048930141419987194, 0.017292686534347013, 0.027228439030295704, 0.0575629404920619, 0.11572857169085182, 0.010198535856034141, 0.02953727529529715, 0.022273497488640714, 0.024129451121552847, 0.06577982887392864, 0.012113858520024223, 0.07511114847147837, 0.022978409760980867, 0.003009858060067927, 0.04401575824886095, 0.0775609260017518, 0.12852798448875546, 0.2029575000051409, 0.12563880358356982, 0.2169643499655649, 0.10602349910186604, 0.1609845960047096, 0.06903558620251715, 0.16870680585270748, 0.1765143478405662, 0.14944828144507483, 0.20064229611307383, 0.11103678829385899, 0.15441452589584514, 0.2706755662802607, 0.10907179646892473, 0.12133190539316274, 0.5349208682309836, 17.160145193338394, 50.063571408391, 57.17416785657406, 47.12653040885925, 27.49374009668827, 20.405573844909668, 33.78189727663994, 45.767381340265274, 20.857348702847958, 0.2590633003273979, 2.4557904107496142, 31.491212993860245, 15.52053602412343, 23.736395314335823, 20.920852795243263, 12.827272843569517, 29.117755852639675, 47.30091445147991, 54.25244763493538, 54.22298401594162, 52.37021863460541, 47.99413405358791, 51.54606565833092, 51.374603658914566, 50.36527141928673, 55.28255715966225, 53.533397018909454, 56.194002851843834, 48.23123753070831, 46.902977004647255, 45.70281520485878, 46.7496932297945, 47.150233536958694, 50.059015452861786, 48.18269893527031, 45.21082140505314, 45.785407572984695, 51.15152142941952, 50.93013010919094, 54.36313569545746, 51.56653515994549, 53.00482638180256, 54.94873747229576, 51.870986223220825, 51.64017140865326, 52.32585221529007, 51.15866504609585, 47.72307559847832, 40.23530378937721, 42.31864079833031, 39.690166041255, 39.7292697429657, 40.02852648496628, 40.76715745031834, 39.343693032860756, 42.170338556170464, 40.515071377158165, 42.88036845624447, 51.79943986237049, 54.97644558548927, 51.75808288156986, 43.99009890854359, 45.304262191057205, 53.36949661374092, 49.603355303406715, 53.30547384917736, 49.365024492144585, 52.38037168979645, 47.35384561121464, 47.2888994961977, 37.40049630403519, 39.935260489583015, 58.290646746754646, 51.9292750954628, 51.964977979660034, 47.014197036623955, 41.455615907907486, 43.665611520409584, 39.59433898329735, 39.97139275074005, 37.55295552313328, 40.766857266426086, 41.20288006961346, 40.3530328720808, 41.656951904296875, 40.12046255171299, 39.32519942522049, 42.4331970512867, 40.6546226888895, 46.3715261220932, 46.174035519361496, 51.63199804723263, 53.22988070547581, 57.069392278790474, 54.73513953387737, 55.2774578332901, 53.7539067864418, 50.749556198716164, 51.42123855650425, 53.18972446024418, 54.73771579563618, 52.47621774673462, 53.77048909664154, 51.561420634388924, 49.4475294649601, 44.002729430794716, 42.03876681625843, 42.44639754295349, 44.09504547715187, 45.23840792477131, 42.665205001831055, 51.1199527233839, 53.86161580681801, 58.35907727479935, 52.3705568164587, 52.90482334792614, 55.584135577082634, 57.617452070117, 54.29111436009407, 54.43217419087887, 54.75748233497143, 58.05843360722065, 61.73138111829758, 58.3989979326725, 47.35418759286404, 33.120257779955864, 14.23355933278799, 17.26142305880785, 14.230895675718784, 12.899142187088728, 5.250061433762312, 0.5214961292222142, 0.3990836493903771, 5.986553113907576, 49.85794924199581, 64.39731806516647, 50.963260531425476, 46.53076037764549, 51.52819141745567, 63.1234136223793, 62.319946736097336, 31.640902161598206, 2.212352673523128, 0.1697085567866452, 0.1373826077906415, 0.11778587926528417, 0.14665283379144967, 0.2367599814897403, 0.08728132394026034, 0.15222961344989017, 0.17713414505124092, 0.16968198789982125, 0.10480271812411956, 0.16946686897426844, 0.24412551516434178, 0.0961703086795751, 0.05662278410454746, 0.20748752489453182, 0.17250220844289288], [0.09486382448812947, 0.004954873820679495, 0.013357478164834902, 0.023083846681402065, 0.046388849659706466, 0.046019352885195985, 0.01698136857157806, 0.08580696594435722, 0.034177158449892886, 0.03734695281309541, 0.06019684486091137, 0.016704053959983867, 0.07842297505703755, 0.06322775370790623, 0.07801588479196653, 0.0644385305349715, 0.38157386239618063, 9.662642106413841, 35.85554100573063, 45.028089210391045, 38.701231107115746, 22.773327492177486, 20.106049217283726, 29.682171866297722, 36.989270970225334, 10.444055926054716, 0.085431788029382, 2.585343746468425, 10.887222345918417, 2.6880664844065905, 7.389112003147602, 10.637358203530312, 11.189369782805443, 31.440816298127174, 49.554296135902405, 51.36357665061951, 51.539176627993584, 50.77982157468796, 48.059384152293205, 50.70384465157986, 48.95889088511467, 49.63792584836483, 50.93830347061157, 49.76967617869377, 47.321505546569824, 44.22017276287079, 42.314084842801094, 39.123350456357, 40.164114609360695, 44.82234165072441, 42.152118533849716, 43.36749851703644, 43.58916722238064, 44.68850523233414, 47.48284108936787, 49.67699535191059, 51.290848553180695, 49.52818773686886, 48.67604546248913, 46.00201115012169, 45.2056460827589, 44.83938753604889, 45.886242762207985, 39.905599281191826, 37.9218777269125, 36.9753485172987, 37.462090998888016, 35.44266276061535, 35.51539845764637, 36.91587790846825, 36.791578978300095, 35.58242306113243, 36.343765407800674, 36.50455757975578, 41.23866654932499, 47.242177203297615, 52.48875327408314, 45.96406638622284, 44.59061488509178, 49.31932434439659, 51.28057010471821, 46.64600059390068, 48.67324881255627, 46.55018873512745, 50.7584211230278, 46.14206783473492, 48.332023322582245, 35.31795345246792, 33.780324161052704, 54.860510006546974, 49.3921360373497, 46.051142513751984, 39.96928006410599, 42.894522696733475, 43.301321268081665, 48.34858663380146, 47.05671675503254, 43.01390469074249, 37.12628401815891, 36.6414338350296, 35.9820020198822, 36.32868781685829, 35.39497151970863, 36.77636079490185, 36.811284720897675, 37.57462576031685, 40.873813927173615, 43.257133439183235, 46.78015619516373, 49.74407695233822, 50.45336589217186, 50.814308524131775, 51.29156671464443, 51.72972500324249, 49.94151055812836, 48.18899139761925, 52.16907262802124, 51.308855786919594, 48.03117446601391, 50.54826959967613, 45.21828420460224, 43.11333775520325, 39.7784049063921, 38.68992671370506, 37.18284398317337, 36.717859134078026, 35.72186417877674, 42.373289465904236, 49.526409432291985, 52.62754462659359, 54.264595583081245, 46.99552483856678, 47.16351382434368, 53.15540470182896, 54.02019649744034, 52.42958664894104, 50.81843890249729, 52.72319309413433, 53.5318049043417, 54.847412109375, 50.40682978928089, 44.571828693151474, 31.11949224025011, 13.106338419020176, 5.391283705830574, 9.645761512219906, 3.9326395886018872, 1.9214711571112275, 0.28181864647194743, 0.05261781014269218, 2.828968148678541, 31.859420835971832, 42.41463124752045, 19.689986743032932, 19.379096925258636, 37.7467755228281, 46.748101115226746, 46.05051174759865, 23.040398061275482, 1.3152449182234704, 0.008825437416817294, 0.07148669959860854, 0.10906214112765156, 0.009103907923417864, 0.0189284820589819, 0.030360589807969518, 0.04588584051816724, 0.07021423545666039, 0.030635123221145477, 0.0542471359949559, 0.02403793689154554, 0.02890676518291002, 0.060050259562558495, 0.07659560709726065, 0.05542110600799788, 0.05154502454388421, 0.035505038758856244, 0.07921571494080126, 0.0473116991634015, 0.006771472753825947, 0.03862339857732877, 0.05603786041319836, 0.06931317911949009, 0.056707923286012374, 0.03574429232685361, 0.07307639476493932, 0.028646764876611996, 0.03676647087559104, 0.04251234888215549, 0.06424790248274803, 0.059070357456221245, 0.0384562075487338, 0.5773272458463907, 12.530530616641045, 43.12927030026913, 52.38969638943672, 44.300724640488625, 25.33828105777502, 22.073401249945164, 33.405915051698685, 41.774449199438095, 12.385613042861223, 0.0880675255029928, 3.350305873900652, 12.256280332803726, 5.113858692348003, 6.680344585329294, 7.827492579817772, 10.100977085530758, 29.48056798428297, 50.37863530218601, 51.11568935215473, 51.71504259109497, 50.52585460245609, 49.35523621737957, 49.7961987555027, 50.31433895230293, 49.202731400728226, 52.79291555285454, 52.06241995096207, 49.7045286744833, 45.20626164972782, 46.65036275982857, 42.67101489007473, 42.613109797239304, 45.79582281410694, 44.81202520430088, 45.535046607255936, 44.82992224395275, 46.89381569623947, 49.135938584804535, 51.47754393517971, 53.01456905901432, 49.95976097881794, 50.713036358356476, 48.89765337109566, 48.6030475795269, 47.693505585193634, 47.63596907258034, 43.06528553366661, 40.13396702706814, 39.91911515593529, 38.461631163954735, 37.277158722281456, 38.096938133239746, 39.07135784626007, 38.18417005240917, 37.48640589416027, 37.518035396933556, 37.63196848332882, 42.49395579099655, 49.022153690457344, 53.24535347521305, 47.77329370379448, 45.75628213584423, 50.548793971538544, 52.5434285402298, 48.35624702274799, 50.4136998206377, 48.880398496985435, 52.50996373593807, 48.4803331643343, 49.72625210881233, 37.07858897745609, 36.03044182062149, 56.47812120616436, 51.362828090786934, 49.16967697441578, 41.71098880469799, 43.90113428235054, 44.94040131568909, 48.76698598265648, 48.08092139661312, 44.37354013323784, 39.38389107584953, 37.837640047073364, 38.110340014100075, 38.96118275821209, 37.289986833930016, 37.40568682551384, 39.13208618760109, 38.5334625095129, 41.75367571413517, 46.081833466887474, 47.80472941696644, 51.233429834246635, 51.89238667488098, 52.00073026120663, 51.49094961583614, 52.46147073805332, 51.96231052279472, 50.25119014084339, 54.24651235342026, 54.89966690540314, 48.64593207836151, 51.23344883322716, 48.57597403228283, 45.786486715078354, 41.35950766503811, 40.83428844809532, 39.27686981856823, 39.56667646765709, 39.537585228681564, 44.592188000679016, 51.744681000709534, 54.890558794140816, 54.94652979075909, 49.13831725716591, 49.472741112113, 55.36082535982132, 55.70722237229347, 55.026990473270416, 53.051267489790916, 55.20001418888569, 57.62346714735031, 57.847290337085724, 53.68692398071289, 46.9189665466547, 29.88895107060671, 19.548617228865623, 12.065325379371643, 12.065742406994104, 6.016759593039751, 2.6666729198768735, 0.1708158411202021, 0.04206772820907645, 3.4802643628790975, 35.04366137087345, 50.030699372291565, 26.20905563235283, 25.460989773273468, 43.91421318054199, 52.535357773303986, 53.90466369688511, 26.37441135942936, 1.9568579457700253, 0.08432802147581242, 0.0916609748674091, 0.0459264842356788, 0.026912401008303277, 0.023703604929323774, 0.056579338779556565, 0.029935057173133828, 0.07358193091931753, 0.06268654251471162, 0.07448119125911035, 0.061020487773930654, 0.024692572369531263, 0.011939941778109642, 0.025762641707842704, 0.03277454758062959, 0.043930696992902085, 0.160325643082615, 0.08717254735529423, 0.09859314624918625, 0.1019233929400798, 0.1147019662312232, 0.1414751959964633, 0.13013362098718062, 0.13437346613500267, 0.11421886520111002, 0.1059405789419543, 0.09435779851628467, 0.11855252523673698, 0.3116695478092879, 0.20007008541142568, 0.2036686852807179, 0.13828667724737898, 1.1181257455609739, 15.398233886808157, 52.91931577026844, 60.12036256492138, 53.29656332731247, 33.492181822657585, 31.16509359329939, 41.02053165435791, 49.09664869308472, 13.851249497383833, 0.15606958942953497, 3.8213556725531816, 16.46141778677702, 6.110909515991807, 12.95134473592043, 16.12653225660324, 14.754751715809107, 33.98773603141308, 51.127062141895294, 53.50384600460529, 51.78894482553005, 52.34583154320717, 49.340398013591766, 49.975165352225304, 50.09069815278053, 51.066869571805, 53.75455655157566, 54.61760804057121, 52.28121601045132, 47.67010644078255, 48.90250951051712, 43.50021779537201, 44.49654333293438, 49.250643029809, 46.63268230855465, 47.361278012394905, 47.41170130670071, 50.12520790100098, 51.3058615475893, 53.82046781480312, 57.72375516593456, 54.33365307748318, 54.15782891213894, 51.21600016951561, 49.53614830970764, 49.500282034277916, 49.63187277317047, 45.6463198363781, 41.56449906527996, 40.91577507555485, 40.670213252305984, 38.3207993209362, 40.315741673111916, 40.30776210129261, 39.98977616429329, 39.54872243106365, 39.58314098417759, 39.798958003520966, 44.9619347602129, 52.011533081531525, 56.272225454449654, 47.87184901535511, 46.67156562209129, 52.598487585783005, 55.333295837044716, 51.176121309399605, 51.99722304940224, 51.8158245831728, 55.67321039736271, 49.624938145279884, 48.24270911514759, 39.38022807240486, 39.73798267543316, 57.58402906358242, 54.099034667015076, 49.64590921998024, 43.990440890192986, 46.37906491756439, 47.5731660425663, 52.418031468987465, 51.55371464788914, 46.041316241025925, 41.91968500614166, 39.775574058294296, 39.265109449625015, 41.56971998512745, 39.828353226184845, 40.41044779121876, 40.7088989764452, 40.59637561440468, 43.48038665950298, 49.23387832939625, 51.10903210937977, 54.09196324646473, 54.12687577307224, 54.11559037864208, 51.580784395337105, 54.764907136559486, 54.06517468392849, 50.09344160556793, 56.355311796069145, 56.251166984438896, 50.05282558500767, 53.869580179452896, 50.21946184337139, 49.586427211761475, 44.55456621944904, 43.005590736866, 41.69469527900219, 42.23153427243233, 40.32458759844303, 47.15698577463627, 54.48241509497166, 56.376662850379944, 55.72393387556076, 48.143652230501175, 49.937942549586296, 57.06978365778923, 58.9608433842659, 57.64816202223301, 56.9193497300148, 59.0376790612936, 59.9874646961689, 59.54446166753769, 57.64829121530056, 50.8494034409523, 31.37474924325943, 17.55960065871477, 14.081616885960102, 22.490824051201344, 11.787015963345766, 4.2024419736117125, 0.5744845233857632, 0.19379159028176218, 4.431886961683631, 40.28817415237427, 52.81667187809944, 26.78420227020979, 30.71660365909338, 50.4017798602581, 61.00114390254021, 62.85276934504509, 33.4903921186924, 2.972641051746905, 0.1857179289800115, 0.22728137526428327, 0.17595993384020403, 0.24521534418454394, 0.1614105442422442, 0.1608293387107551, 0.13192307262215763, 0.18268250045366585, 0.10837342808372341, 0.17278449173318222, 0.15948762476909906, 0.2215563738718629, 0.12107608708902262, 0.10401319173979573, 0.1999191622599028, 0.10302597947884351], [0.04275463412341196, 0.06842025672085583, 0.05299675074638799, 0.0288579912376008, 0.024784895540506113, 0.02716386105021229, 0.04720505625300575, 0.04588231531670317, 0.09797411345061846, 0.004235057831465383, 0.016590457125857938, 0.04379518824862316, 0.030051498288230505, 0.029005979195062537, 0.021209866281424183, 0.13099645671900362, 0.6786365190055221, 12.701041717082262, 33.11772331595421, 40.76639749109745, 40.17512261867523, 23.0724835395813, 12.201110143214464, 29.664417318999767, 34.9647282063961, 8.951834198087454, 0.15857957740081474, 1.4078110386617482, 16.9875755533576, 5.396680366247892, 5.235770875588059, 13.040787186473608, 8.506591189652681, 35.645043700933456, 47.355840504169464, 52.47014567255974, 55.78745886683464, 48.16678538918495, 47.97123648226261, 48.36850516498089, 52.695234194397926, 51.32466673851013, 50.1454646140337, 47.26874157786369, 44.38968166708946, 42.341998144984245, 40.63195690512657, 38.128313049674034, 38.88233318924904, 39.1082576662302, 43.81228365004063, 43.620986714959145, 46.61295376718044, 45.98676636815071, 46.916200295090675, 47.37927004694939, 47.37793251872063, 43.5883616656065, 39.488450065255165, 35.90768560767174, 37.387444004416466, 36.761609986424446, 34.50609281659126, 35.04415154457092, 35.164738073945045, 34.361217990517616, 35.989362224936485, 34.11275312304497, 37.35690504312515, 35.27012541890144, 34.89291965961456, 35.01724898815155, 37.38742880523205, 38.33223670721054, 41.145313158631325, 48.823219165205956, 50.70081241428852, 46.97053737938404, 51.52176596224308, 47.77858681976795, 46.6641978174448, 42.6570962369442, 45.31734488904476, 46.291369423270226, 48.238897919654846, 47.47727818787098, 51.266932636499405, 39.21090915799141, 34.372552782297134, 56.319270730018616, 49.25188556313515, 47.32861876487732, 45.05057640373707, 49.694371819496155, 49.1717516630888, 51.74345746636391, 49.99547526240349, 50.505111515522, 44.67290326952934, 37.49522142112255, 35.70642180740833, 38.8069224357605, 36.23052388429642, 37.145545184612274, 39.112118259072304, 36.65436454117298, 39.92656655609608, 43.214522525668144, 47.23805442452431, 47.947529554367065, 50.22155933082104, 48.658034428954124, 49.4895476102829, 50.24426691234112, 48.95536087453365, 48.63579422235489, 48.41599501669407, 46.64098486304283, 49.58450831472874, 50.235432386398315, 44.68546159565449, 43.25104996562004, 39.442229345440865, 38.474356681108475, 36.40203148126602, 37.344669699668884, 38.45023177564144, 44.56200622022152, 51.43124721944332, 52.47793905436993, 48.47378611564636, 43.314586356282234, 50.77656514942646, 53.435461074113846, 55.07425993680954, 55.1127290725708, 54.927834793925285, 53.83385069668293, 52.56651230156422, 54.24484424293041, 47.30762869119644, 47.71792687475681, 45.682702884078026, 33.16012144088745, 12.407958693802357, 2.7600612211972475, 5.253143543377519, 1.4448020537383854, 0.15291302755940706, 0.053959572323947214, 1.6880031349137425, 28.698995523154736, 46.973242834210396, 32.90023058652878, 26.669349633157253, 31.47064659744501, 44.894188195466995, 42.98092246055603, 21.195412762463093, 1.913879164494574, 0.07726739917416126, 0.0814567634370178, 0.07738925240118988, 0.04867564042797312, 0.010828404938365566, 0.09461599169299006, 0.07529550537583418, 0.05932353000389412, 0.03957925880968105, 0.04361751438409556, 0.029042253518127836, 0.05052759202953894, 0.013790378470730502, 0.09632719869841821, 0.009922928184096236, 0.06276705811615102, 0.020861739649262745, 0.09793243443709798, 0.05951004655798897, 0.013554143588407896, 0.03728100557054859, 0.019427101397013757, 0.047671217762399465, 0.03993586818978656, 0.03639836562797427, 0.05882846184249502, 0.014375746523000998, 0.028643282348639332, 0.040440061056870036, 0.030205000402929727, 0.07422904658596963, 0.0661778797802981, 0.8071632566861808, 14.606115091592073, 41.61320485174656, 49.6340424567461, 46.10261835157871, 26.037882417440414, 18.755698576569557, 33.840771317481995, 39.455125853419304, 9.834303595125675, 0.12534767389297485, 1.6134423483163118, 18.37646182626486, 4.283901052549481, 11.229514628648758, 10.7760526612401, 8.899697195738554, 38.74091997742653, 48.64052876830101, 52.198103070259094, 53.502637669444084, 50.2054899930954, 48.70866671204567, 50.161514952778816, 53.02616983652115, 54.48173873126507, 52.169779390096664, 49.90334540605545, 46.532998457551, 45.90713784098625, 43.95436182618141, 41.76861651241779, 41.82548426091671, 41.62403807044029, 45.331016555428505, 46.15709222853184, 48.70935067534447, 46.8962437659502, 50.81159546971321, 49.13904681801796, 49.15646128356457, 46.58134326338768, 41.28640718758106, 38.27052801847458, 38.65811102092266, 39.13393668830395, 37.24295295774937, 36.261203438043594, 37.70572252571583, 36.21937908232212, 36.76284112036228, 36.71326518058777, 38.79917845129967, 36.9820361584425, 36.589703410863876, 37.19978727400303, 38.88106405735016, 38.80830556154251, 44.38075974583626, 50.62197804450989, 50.558202266693115, 49.095352962613106, 53.05594503879547, 50.81884168088436, 50.80544739961624, 44.50139567255974, 47.42912337183952, 47.26901516318321, 50.21064631640911, 50.45480601489544, 51.319369822740555, 39.45984899997711, 36.08757555484772, 58.22511926293373, 50.80985516309738, 48.935449942946434, 46.883810833096504, 51.7586300522089, 50.55515103042126, 54.19968366622925, 50.871058478951454, 51.67485974729061, 46.213310211896896, 39.02071796357632, 37.83514358103275, 40.5496571213007, 37.7027852833271, 38.98724555969238, 39.090998992323875, 39.76532220840454, 42.88755387067795, 46.33711516857147, 49.27195608615875, 50.20780026912689, 53.64489063620567, 52.10018612444401, 51.7754365503788, 51.28548704087734, 49.56770941615105, 48.22418510913849, 49.65117573738098, 48.246554508805275, 50.98108157515526, 52.16657616198063, 46.243321001529694, 45.60938581824303, 41.391102969646454, 40.71377031505108, 37.90784128010273, 38.85097347199917, 40.94342239201069, 46.57468602061272, 54.11100022494793, 54.823370799422264, 50.32800301909447, 44.826692417263985, 50.490801483392715, 53.78435455262661, 56.997842118144035, 56.91029101610184, 56.28914974629879, 54.51985828578472, 54.650153294205666, 57.32917673885822, 52.26956203579903, 52.39172928035259, 40.05935803055763, 19.86690904945135, 9.194931853562593, 8.333702366799116, 6.8431815225631, 2.6628857105970383, 0.48208505962975323, 0.07904220081400126, 1.6065932158380747, 31.96925774216652, 47.41352520883083, 32.6520811021328, 30.818174108862877, 37.53399834036827, 50.539560467004776, 50.625568851828575, 25.223764702677727, 2.3682034481316805, 0.025936066776921507, 0.04372952302219346, 0.015418529874295928, 0.052321537368698046, 0.03409667995583732, 0.043304305800120346, 0.03069313504965976, 0.05606717895716429, 0.027640512817015406, 0.024568834087403957, 0.061120889222365804, 0.04787605052115396, 0.02516481763450429, 0.04998539749067277, 0.051106081300531514, 0.006247708060982404, 0.15309270151192322, 0.23518668778706342, 0.1484376098960638, 0.08088983682682738, 0.11543749395059422, 0.1321287069004029, 0.22396937798475847, 0.19305831869132817, 0.30054709932301193, 0.18697509745834395, 0.1612659590318799, 0.15611094189807773, 0.0850764403003268, 0.22359760652761906, 0.18402001383947209, 0.17652735026786104, 1.6352733643725514, 18.960786871612072, 50.94016537070274, 55.33322364091873, 53.81989784538746, 32.26319096982479, 20.494179390370846, 40.15320159494877, 46.043580919504166, 12.44704244658351, 0.27388532529585063, 2.0794296311214566, 21.534930244088173, 11.549446061253548, 15.381221249699593, 23.31588327884674, 13.131123539060354, 40.42311251163483, 51.668954864144325, 52.33074255287647, 53.63780401647091, 50.494350492954254, 48.69175001978874, 50.065402910113335, 54.53010633587837, 54.924601167440414, 55.4107166826725, 52.47746787965298, 49.450329914689064, 48.200094401836395, 46.58991560339928, 41.98498070240021, 43.44247609376907, 43.771952614188194, 48.42479534447193, 47.581977769732475, 52.586069852113724, 49.41480562090874, 51.9917893409729, 50.83381287753582, 51.53365172445774, 48.62949036061764, 42.7022036164999, 39.11236144602299, 40.61314411461353, 41.182376369833946, 38.783903270959854, 38.86774197220802, 38.827517330646515, 37.37324416637421, 39.017662927508354, 38.67533549666405, 40.51380604505539, 37.976268008351326, 38.21877479553223, 38.139906227588654, 41.792327240109444, 41.62673972547054, 45.36032818257809, 52.79017210006714, 52.46566191315651, 50.83517700433731, 55.593741461634636, 52.974458411335945, 51.74776263535023, 46.88568413257599, 50.17197959125042, 51.3944423943758, 52.139422819018364, 52.65358462929726, 51.34026490151882, 41.818329244852066, 39.74125050008297, 60.925037786364555, 52.82931759953499, 50.981446355581284, 49.31424401700497, 54.06722657382488, 52.627616822719574, 55.15376307070255, 55.03000371158123, 55.29351197183132, 48.72317053377628, 41.11970633268356, 39.269954189658165, 42.562165930867195, 38.905078768730164, 39.85727347433567, 41.71424143016338, 40.00570110976696, 46.36311337351799, 47.78268299996853, 53.54970574378967, 51.50397151708603, 55.41790969669819, 53.10796804726124, 53.01368750631809, 53.079572170972824, 51.034749895334244, 49.294477477669716, 50.27195982635021, 47.788724675774574, 52.9534987360239, 53.921956568956375, 49.58989642560482, 47.71487943828106, 43.274095728993416, 43.061892315745354, 38.79446290433407, 40.54619550704956, 42.57527522742748, 49.17954884469509, 57.04319268465042, 55.25157742202282, 51.61025941371918, 47.59473368525505, 52.67695337533951, 54.166013672947884, 59.13244217634201, 58.0900327116251, 59.94957692921162, 59.3761382997036, 58.54414254426956, 60.22364102303982, 54.71346169710159, 51.48591488599777, 47.87440627813339, 33.73420603573322, 21.55830468982458, 8.247101213783026, 10.373659953474998, 5.765203591436148, 0.5417612730525434, 0.17933799710590392, 1.829245830886066, 37.92060859501362, 57.3706629127264, 44.11284752190113, 35.91293312609196, 44.198183342814445, 58.86009559035301, 58.80393460392952, 30.808765813708305, 3.6414312897250056, 0.13213250669650733, 0.16475472104502842, 0.1772980557871051, 0.24793017975753173, 0.14010594837600365, 0.20853235007962212, 0.11506095790537074, 0.23478910443373024, 0.10317829044652171, 0.21849376789759845, 0.12916448002215475, 0.21810296777402982, 0.14813142945058644, 0.17361295118462294, 0.1356465314165689, 0.17744773213053122], [0.025390137379872613, 0.03299057934782468, 0.04269203025614843, 0.04005322771263309, 0.02725465539697325, 0.05269530520308763, 0.06512744395877235, 0.06535456341225654, 0.05034721674746834, 0.03485689150693361, 0.020741164771607146, 0.05586646882875357, 0.013451076902128989, 0.033782035316107795, 0.05354558008548338, 0.048585536278551444, 0.6641627394128591, 10.530871767550707, 42.07314357161522, 40.080576092004776, 39.07070428133011, 22.242805659770966, 22.96929817646742, 35.840839594602585, 32.945668548345566, 5.187648832798004, 0.08903696332708932, 0.0380688324366929, 12.386701684445143, 11.24008471146226, 5.728911263868213, 3.2122516818344593, 10.076336357742548, 35.567592456936836, 50.0155495852232, 56.82042583823204, 44.50507387518883, 45.70236302912235, 49.35691572725773, 52.765944600105286, 53.3010470867157, 49.94924694299698, 46.341781318187714, 45.02235911786556, 38.90235051512718, 37.50986963510513, 37.60666184127331, 38.067216128110886, 36.6293390840292, 37.37472228705883, 38.61327722668648, 42.683128640055656, 42.52587407827377, 43.13831761479378, 42.27819576859474, 40.46154364943504, 37.7619519084692, 34.717532470822334, 33.134381622076035, 33.95574174821377, 34.628419652581215, 33.687593936920166, 34.10882793366909, 33.63016001880169, 35.085443928837776, 36.0535179823637, 33.822539895772934, 35.73868967592716, 37.51385562121868, 35.70571884512901, 35.557781383395195, 34.84299033880234, 36.45820766687393, 34.4743949174881, 40.640894025564194, 44.01507496833801, 48.14126215875149, 47.92240150272846, 44.62534882128239, 43.08962322771549, 41.337750032544136, 40.08827447891235, 40.59412233531475, 42.30648525059223, 47.69327759742737, 47.44674302637577, 53.061994314193726, 43.08227822184563, 32.944673001766205, 53.33969861268997, 47.93937899172306, 51.24147020280361, 48.971012234687805, 51.41008995473385, 49.41429644823074, 51.29266105592251, 53.79980452358723, 51.41713857650757, 50.06705202162266, 42.74487152695656, 35.01984044909477, 37.857011407613754, 36.086321622133255, 37.6713115721941, 38.442062214016914, 38.617297410964966, 37.047153264284134, 38.976769521832466, 41.53752811253071, 46.50103077292442, 50.35467378795147, 51.712181344628334, 49.89134564995766, 49.1173879802227, 48.1206938624382, 48.73045474290848, 49.58543926477432, 46.51046946644783, 51.447757333517075, 50.126621425151825, 49.27326701581478, 44.73496533930302, 41.085466369986534, 39.72767762839794, 36.77552863955498, 37.62927062809467, 38.4712028503418, 41.029685363173485, 50.103142485022545, 51.213955879211426, 51.95187248289585, 53.710045740008354, 53.59840393066406, 48.24252292513847, 51.014531180262566, 56.91013142466545, 52.863238379359245, 54.564160108566284, 55.216630697250366, 55.93639947474003, 59.775439873337746, 47.75055952370167, 27.423468567430973, 21.447339244186878, 7.719847681000829, 12.9387142136693, 5.0970445945858955, 3.9531765365973115, 0.17235956765944138, 0.13145192759111524, 1.2592605035752058, 23.65552045404911, 49.78888414800167, 24.5510620996356, 21.78184099495411, 35.04148408770561, 53.62603984773159, 47.55118042230606, 18.29354267567396, 2.4855451891198754, 0.1323170936666429, 0.026992899911419954, 0.04826649070309941, 0.04244507319526747, 0.05053332140960265, 0.005188546901990776, 0.029081887914799154, 0.04423857695655897, 0.04930568298732396, 0.028147498014732264, 0.018662461079657078, 0.06331666299956851, 0.05123494040162768, 0.05742400302551687, 0.03467200025625061, 0.028470484394347295, 0.046226660706452094, 0.027029131560993847, 0.03544836465152912, 0.07738056927337311, 0.032471057420480065, 0.03679711415315978, 0.05386808035837021, 0.04441308556124568, 0.024704437455511652, 0.04306047318095807, 0.06213567226950545, 0.039062386349542066, 0.07380644543445669, 0.04019678133772686, 0.04668751957069617, 0.016972275407169946, 1.0539052728563547, 14.856751542538404, 47.170908227562904, 46.121039763092995, 46.877723559737206, 25.535978749394417, 23.520994372665882, 37.56676398217678, 37.46057488024235, 6.417464716359973, 0.0869418952788692, 0.1302835051319562, 15.914126504212618, 10.393082611262798, 7.032241802662611, 6.700415583327413, 8.905338943004608, 38.961642533540726, 49.88142058253288, 57.41557650268078, 45.77944189310074, 48.76704677939415, 49.50977772474289, 52.7043043076992, 54.106588661670685, 52.31210835278034, 49.47732746601105, 48.49352605640888, 42.02200971543789, 39.90481272339821, 40.36344051361084, 39.984654039144516, 37.766260877251625, 39.42758113145828, 41.22287839651108, 45.355137661099434, 45.16201302409172, 46.03289969265461, 44.4993019849062, 41.08520418405533, 41.90551556646824, 38.229304030537605, 34.5697508007288, 35.268738493323326, 37.44005598127842, 36.07548840343952, 34.839832708239555, 35.608710050582886, 36.683619171381, 37.23490118980408, 36.49029314517975, 36.850396022200584, 39.12649288773537, 38.75372529029846, 37.49000050127506, 37.40619979798794, 37.24731892347336, 36.89386568963528, 43.01083065569401, 48.20219948887825, 50.20701751112938, 51.22921586036682, 48.061398044228554, 46.18569329380989, 43.04485782980919, 42.883837670087814, 44.49162259697914, 45.42935907840729, 49.51088726520538, 48.4087336063385, 54.005658477544785, 42.4284853041172, 35.52594669163227, 55.884627252817154, 50.19327364861965, 53.864982426166534, 51.14247791469097, 53.134445026516914, 52.52578608691692, 53.42515602707863, 53.7425833940506, 52.875773906707764, 52.43361443281174, 44.74826842546463, 37.0341731607914, 39.313078075647354, 37.874615862965584, 40.095984265208244, 40.3577484190464, 40.0621584802866, 38.44381771981716, 40.28840214014053, 43.32594394683838, 48.68444301187992, 52.83931866288185, 54.257246777415276, 53.21685500442982, 50.8136435598135, 49.30121451616287, 50.843893736600876, 51.55236192047596, 47.01897718012333, 51.298565939068794, 51.74845799803734, 49.5476008951664, 46.495939046144485, 42.28676810860634, 40.545222759246826, 38.68479698896408, 39.7967579215765, 39.389826357364655, 43.35384584963322, 52.349319756031036, 53.72787058353424, 53.77127945423126, 54.62475925683975, 56.63796342909336, 50.18966004252434, 52.92735613882542, 58.624648824334145, 57.11221218109131, 56.72676466405392, 57.478250339627266, 57.218883857131004, 60.134626999497414, 45.79215221107006, 33.7861530482769, 22.31996051967144, 11.730357203632593, 7.654392393305898, 8.279584720730782, 3.8424630649387836, 0.7119870919268578, 0.14339557732455432, 1.151811769232154, 27.29200702160597, 52.22901061177254, 25.23173287510872, 22.38441076129675, 43.92590135335922, 58.51098172366619, 57.06573307514191, 23.61408367753029, 3.2034368673339486, 0.05037334776716307, 0.061702733000856824, 0.04009018295619171, 0.044669931739917956, 0.038722048557247035, 0.031175720287137665, 0.022877650226291735, 0.031028815865283832, 0.033024428703356534, 0.05412728285591584, 0.011297798500891076, 0.036572733224602416, 0.00872862889082171, 0.03919475209841039, 0.016389092052122578, 0.038857794788782485, 0.17373411421431229, 0.10236879286821932, 0.12499568809289485, 0.23034870129777119, 0.15368974447483197, 0.10978537146002054, 0.1656172747607343, 0.06872415135148913, 0.1558859969372861, 0.08845019910950214, 0.17013649397995323, 0.17329125985270366, 0.15834243153221905, 0.15231450030114502, 0.16687362687662244, 0.1516232787980698, 1.4820892154239118, 19.509076550602913, 57.79665045440197, 54.89468157291412, 55.004830062389374, 33.831492215394974, 33.13448041677475, 46.820722818374634, 45.00321954488754, 7.634362718090415, 0.27431965980213135, 0.2968981966841966, 18.406419418752193, 16.35169107466936, 10.366124957799911, 9.781822711229324, 12.167973071336746, 39.97072018682957, 55.2823443710804, 56.89310073852539, 47.23525017499924, 49.46152791380882, 50.29142998158932, 53.49100649356842, 56.941502541303635, 53.657608553767204, 52.53187336027622, 51.38385996222496, 43.64180959761143, 42.71476574242115, 42.42677539587021, 42.58876070380211, 41.139609664678574, 42.16329373419285, 43.962322399020195, 47.292839884757996, 46.37089155614376, 47.41737060248852, 46.985565572977066, 43.45460504293442, 42.72293530404568, 38.11422720551491, 35.939926877617836, 36.230512484908104, 39.67426769435406, 38.01631025969982, 36.18616126477718, 36.43702380359173, 39.085398092865944, 39.291297644376755, 38.034131303429604, 39.54821705818176, 40.930092707276344, 39.0877615660429, 40.77225677669048, 38.65235053002834, 40.011074021458626, 38.63183543086052, 44.828185737133026, 50.20842723548412, 52.7691326290369, 52.78340846300125, 49.295754209160805, 48.97025227546692, 44.46813605725765, 44.03945066034794, 45.982001423835754, 47.241611033678055, 51.38905808329582, 51.2893970310688, 54.76927310228348, 44.53166864812374, 38.105153292417526, 55.80990046262741, 50.9385846555233, 56.50851957499981, 52.259458377957344, 55.42130671441555, 54.73385900259018, 54.15285877883434, 57.746960520744324, 55.764147117733955, 54.51195850968361, 46.08208425343037, 39.4685847312212, 41.990038231015205, 40.91612085700035, 41.6103246062994, 42.30254866182804, 42.3786585777998, 39.78839077055454, 42.33934588730335, 44.27273154258728, 50.72731979191303, 56.79418444633484, 57.149571776390076, 55.16238480806351, 53.03729943931103, 52.365970462560654, 52.34357826411724, 51.992701292037964, 48.34389388561249, 52.85555899143219, 53.9931533485651, 52.983418330550194, 49.46804836392403, 44.61364544928074, 43.18390376865864, 41.34455166757107, 42.586853206157684, 41.9307804107666, 46.09677046537399, 54.97533604502678, 58.3499501645565, 55.77281065285206, 57.62093648314476, 57.57475756108761, 51.82106450200081, 52.965342700481415, 60.82280047237873, 57.428890988230705, 59.82465863227844, 59.06622312963009, 58.58832277357578, 58.29391837120056, 48.82529765367508, 33.81794594228268, 23.879489935934544, 11.176244337111712, 24.46387577801943, 16.52598012238741, 4.582538427785039, 1.0884615685790777, 0.24972803250420839, 1.5461138798855245, 30.594831593334675, 65.26602745056152, 33.6646431684494, 32.7437549829483, 49.06234033405781, 65.07990583777428, 66.13589197397232, 33.15957047045231, 3.9485593093559146, 0.2828759397380054, 0.0994838347833138, 0.1220873226702679, 0.16617799701634794, 0.15664484293665737, 0.22441370179876685, 0.057285844814032316, 0.09814074786845595, 0.1907393298461102, 0.13683607539860532, 0.12078003695933148, 0.2136711438652128, 0.0988549759495072, 0.15361977479187772, 0.14243278914364055, 0.12342755973804742], [0.03225484753784258, 0.07154090606491081, 0.01445168307327549, 0.07145409705117345, 0.058242899904144, 0.03513392039167229, 0.02854792935977457, 0.04519524241914041, 0.0377335783559829, 0.021775989516754635, 0.048590735023026355, 0.027653090364765376, 0.047371976397698745, 0.01137734188887407, 0.03760829640668817, 0.013260023042676039, 0.6298932689242065, 12.471383940428495, 44.22831952571869, 40.69479413330555, 36.84786155819893, 17.687786780297756, 27.875860892236233, 35.3477780520916, 30.071383081376553, 4.532383494079113, 0.10509684609132819, 0.5944837408605963, 20.265701450407505, 6.953164720907807, 10.725808907300234, 9.849904607981443, 9.4464261084795, 40.029742419719696, 47.7302610129118, 39.37486656010151, 35.18246792256832, 49.63359408080578, 51.69819809496403, 52.53647871315479, 50.615279003977776, 48.6956600099802, 45.761833637952805, 40.86464121937752, 37.82426476478577, 37.750328332185745, 32.68073536455631, 34.37943421304226, 33.66466976702213, 34.68549259006977, 36.964591294527054, 36.907104179263115, 35.61126351356506, 35.915478989481926, 34.363573864102364, 34.03863050043583, 33.04442144930363, 34.630064964294434, 32.991748675704, 35.162568390369415, 34.255914241075516, 36.24442733824253, 36.40533350408077, 36.135012209415436, 33.181932270526886, 33.69257166981697, 34.51344542205334, 36.22328147292137, 35.02725765109062, 36.38960234820843, 35.65765902400017, 35.23817293345928, 35.55063396692276, 35.5713352560997, 38.065107241272926, 41.189227402210236, 43.26990455389023, 41.99419520795345, 39.089798256754875, 37.36302271485329, 40.12886770069599, 38.191503658890724, 41.779130548238754, 43.601375967264175, 47.25018337368965, 45.72018787264824, 51.92382998764515, 42.02732563018799, 28.188815899193287, 49.39348116517067, 50.108853578567505, 53.6630916595459, 50.39836384356022, 50.47627106308937, 47.326452881097794, 43.054262325167656, 47.28317320346832, 48.39359521865845, 52.54282057285309, 47.85885751247406, 33.672945722937584, 36.36563703417778, 36.290051490068436, 37.834793999791145, 36.82712987065315, 37.94295899569988, 35.26015095412731, 37.90864683687687, 38.08142736554146, 39.816269874572754, 40.619371980428696, 46.693349853158, 48.633974120020866, 48.65880958735943, 48.359241262078285, 50.50656683743, 49.11193147301674, 49.70783069729805, 49.31400083005428, 48.75168800354004, 50.52905783057213, 48.605118468403816, 44.306709319353104, 39.99542646110058, 37.734874561429024, 38.59564617276192, 35.07922746241093, 39.57249015569687, 43.04563298821449, 45.58127872645855, 46.74076750874519, 49.30586166679859, 51.52764804661274, 56.984926611185074, 52.148238345980644, 45.735052675008774, 48.76621462404728, 55.17795257270336, 54.983418211340904, 55.457283183932304, 52.47960716485977, 56.3632495701313, 46.220290437340736, 21.044283472001553, 9.34687240049243, 7.8104794677346945, 7.612241255119443, 3.500334885902703, 0.37476649798918515, 0.058897073395201005, 0.09759053442394361, 16.54530208557844, 45.700634121894836, 41.9430385529995, 30.026097111403942, 23.11338074505329, 41.72887444496155, 54.370499700307846, 24.352017380297184, 2.4259935971349478, 0.04676361939345952, 0.015877166006248444, 0.04788652964634821, 0.04178731884167064, 0.04439831682248041, 0.06228095880942419, 0.030907450600352604, 0.031065129151102155, 0.04370624927105382, 0.016320460090355482, 0.062137000713846646, 0.031328751138062216, 0.04221125585900154, 0.036736425026902, 0.08353465076652355, 0.046334661747096106, 0.023316411643463653, 0.030298006349767093, 0.027071580552728847, 0.0332005848758854, 0.12365653456072323, 0.044768841471523046, 0.02314170265890425, 0.020209239701216575, 0.0438030141958734, 0.08700643986230716, 0.016552546367165633, 0.03489149785309564, 0.11123061500256881, 0.07285483399755321, 0.044778708324884064, 0.08572881779400632, 0.5527672043535858, 14.9663813598454, 52.752181738615036, 47.80235454440117, 44.954308569431305, 22.72068701684475, 27.51113746315241, 38.41734454035759, 35.564564019441605, 5.001819804310799, 0.03945398799260147, 0.6505985953845084, 22.65408419072628, 15.446034371852875, 11.93145476281643, 5.632361294701695, 9.480174947530031, 42.10583321750164, 48.411370664834976, 42.230348736047745, 38.061915412545204, 51.169243678450584, 50.651662051677704, 52.95424349606037, 51.89056657254696, 50.42498141527176, 48.129684180021286, 42.81811639666557, 38.4636602550745, 39.044839069247246, 35.83504110574722, 35.64253583550453, 36.01206220686436, 36.47997289896011, 38.23045156896114, 39.77468490600586, 38.40072803199291, 38.51894348859787, 36.71161226928234, 36.59842774271965, 35.97796283662319, 35.588506534695625, 34.99228052794933, 37.0147942006588, 36.01759850978851, 38.197978511452675, 37.5407125800848, 36.83414429426193, 34.46418486535549, 35.8961646258831, 36.51163659989834, 35.66981077194214, 37.21644178032875, 36.575860753655434, 36.3346952944994, 35.96937149763107, 37.25766956806183, 37.0396638661623, 39.2518899589777, 44.0313570946455, 44.76877212524414, 44.05363529920578, 43.32292690873146, 39.8963163793087, 41.82145267724991, 39.937806352972984, 43.43449652194977, 47.250160574913025, 48.50741811096668, 47.07378923892975, 53.12327742576599, 41.90418943762779, 30.979165770113468, 51.03948064148426, 52.42371216416359, 55.11537753045559, 51.69617660343647, 51.317929700016975, 47.981974706053734, 44.895989298820496, 48.52187633514404, 51.397379636764526, 54.16137792170048, 49.33520369231701, 36.59051276743412, 37.24605359137058, 37.84090407192707, 39.65788297355175, 39.27781976759434, 39.30561147630215, 37.22331941127777, 40.084459483623505, 39.09842759370804, 40.82335643470287, 44.675863310694695, 49.586153626441956, 50.89580275118351, 50.74109025299549, 51.450056210160255, 52.549789398908615, 52.21945412456989, 49.35158461332321, 50.512977093458176, 50.30515104532242, 54.28321458399296, 49.3901601433754, 45.95977261662483, 42.1914654225111, 39.115310087800026, 40.22981308400631, 36.81220047175884, 40.99693112075329, 45.77293664216995, 48.355202078819275, 49.937874153256416, 52.5515753030777, 53.41176554560661, 56.9452453404665, 53.08910585939884, 48.57258081436157, 50.59117689728737, 55.50604596734047, 55.592985302209854, 54.09439891576767, 54.071345552802086, 55.926276817917824, 44.63042914867401, 22.018674686551094, 15.313814766705036, 9.09049540758133, 7.165759038180113, 4.717843942344189, 1.239610689226538, 0.17868907802039757, 0.22126993455458432, 19.613059870898724, 50.55276855826378, 35.95070309937, 31.594139970839024, 31.641502529382706, 47.85816974937916, 63.32211256027222, 30.187349058687687, 3.203824209049344, 0.035301471361890435, 0.021786613360745832, 0.08300102432258427, 0.047396934824064374, 0.04578345382469706, 0.0655318921781145, 0.019571842458390165, 0.029516680697270203, 0.061668961570831016, 0.028652490545937326, 0.020543118953355588, 0.031131469731917605, 0.014411454030778259, 0.020176061989332084, 0.11072930908994749, 0.02402197143965168, 0.1901742140762508, 0.20277950330637395, 0.10336217237636447, 0.14224202750483528, 0.18339341855607927, 0.1717799948528409, 0.19171615946106613, 0.18288016406586394, 0.18362281640293077, 0.22081766976043582, 0.10775251765153371, 0.186770279542543, 0.21601266431389377, 0.1448555153911002, 0.14702402637340128, 0.21428161970106885, 1.177872670814395, 21.09868325293064, 59.878710731863976, 55.61236806213856, 52.216395288705826, 28.441741727292538, 38.57065111398697, 46.36674977838993, 42.48906925320625, 6.788982655853033, 0.29245650221128017, 0.9336162556428462, 25.112782157957554, 14.309382364153862, 15.861909706145525, 18.904185108840466, 11.713010184466839, 45.98267778754234, 49.55827072262764, 39.90652643144131, 39.76662553846836, 52.0620209723711, 52.04909026622772, 53.42789947986603, 54.9299056828022, 51.50338634848595, 51.37636296451092, 45.64313940703869, 41.87420144677162, 42.296275198459625, 36.56767599284649, 37.19717301428318, 37.971826046705246, 37.90897361934185, 41.126283779740334, 39.75643828511238, 39.399303048849106, 40.6547936797142, 38.1733064353466, 38.81539598107338, 37.58623033761978, 37.29231230914593, 37.04629831016064, 38.87111619114876, 38.01392398774624, 40.424054861068726, 40.27546763420105, 38.87881837785244, 35.71013420820236, 37.81347334384918, 37.63953007757664, 38.40510159730911, 39.416709914803505, 38.842249140143394, 38.96809458732605, 38.868995904922485, 39.52443413436413, 40.21323837339878, 41.645503118634224, 44.8728371411562, 46.67741350829601, 45.89153587818146, 44.137496799230576, 40.75275622308254, 43.92638772726059, 41.773590445518494, 45.4436045140028, 50.28518691658974, 51.36885456740856, 50.57235650718212, 54.21994037926197, 44.0341005474329, 33.385601341724396, 50.64392186701298, 53.537538796663284, 57.030170783400536, 53.65473210811615, 52.34481319785118, 49.44429963827133, 44.69999201595783, 49.76923920214176, 55.21492458879948, 56.97144493460655, 51.525732949376106, 38.71260769665241, 39.50389623641968, 39.81104515492916, 42.65869975090027, 40.37680059671402, 40.84089249372482, 38.987427949905396, 41.62056885659695, 41.502349600195885, 42.4735888838768, 45.942422747612, 52.505799159407616, 51.801457554101944, 53.50725442171097, 53.80591079592705, 55.328131914138794, 54.15441669523716, 51.827930733561516, 52.46934771537781, 50.668153166770935, 56.187357008457184, 53.71567703783512, 48.75867582857609, 44.61363784968853, 41.096956953406334, 42.17976965010166, 38.00948962569237, 43.03756222128868, 47.598244696855545, 50.33195100724697, 52.28261813521385, 54.44567106664181, 55.484998896718025, 59.92344193160534, 54.08589877188206, 48.389031663537025, 53.51201556622982, 55.92224903404713, 54.576973021030426, 57.37849049270153, 54.90356169641018, 59.13048528134823, 46.66578233242035, 27.134304083883762, 17.506726495921612, 14.36640115454793, 13.606783915311098, 7.997439410537481, 2.4884494207799435, 0.2137908077565953, 0.31304830976296216, 21.924663931131363, 59.50195714831352, 55.4120884090662, 39.562067314982414, 36.54990054666996, 54.27861303091049, 70.40560886263847, 39.111168310046196, 4.464588006958365, 0.11239200190175325, 0.13817504339385778, 0.12380592146655545, 0.16946547373663634, 0.13204295915784314, 0.16006301186280325, 0.0854752556188032, 0.14246664592064917, 0.1997879208647646, 0.20924362441292033, 0.14866914512822405, 0.11696873014443554, 0.12816909671528265, 0.1129827143449802, 0.22051235020626336, 0.1393271831329912], [0.03329131614009384, 0.0047185902349156095, 0.004693441169365542, 0.025264632786274888, 0.05401914080721326, 0.08113265270367265, 0.032753522536950186, 0.08134012008667924, 0.067835006484529, 0.08596719562774524, 0.007481232642021496, 0.019661685000755824, 0.047684680321253836, 0.0616335759696085, 0.05186570284422487, 0.10917417574091814, 0.5126395169645548, 12.557664960622787, 38.70206706225872, 41.65428824722767, 34.1951023042202, 17.084848433732986, 22.157758623361588, 32.0320113748312, 31.24624203890562, 4.11181541159749, 0.05361522322345991, 1.7839185381308198, 29.98694211244583, 4.966926276683807, 4.859505090862513, 3.2009085780009627, 7.373118661344051, 30.940088666975498, 22.686785236001015, 23.19407321512699, 42.62317545711994, 50.058046504855156, 51.23267747461796, 51.595010831952095, 48.811804577708244, 47.89016403257847, 41.05161018669605, 37.71565139293671, 38.33927772939205, 36.86649575829506, 38.233214020729065, 36.86476305127144, 35.16856826841831, 35.79552702605724, 35.682266503572464, 36.33789472281933, 35.64035855233669, 36.685667261481285, 36.49403214454651, 33.25224369764328, 36.58098287880421, 38.26006717979908, 39.90766257047653, 41.40751428902149, 43.82972851395607, 45.695625990629196, 46.70857563614845, 46.4308675378561, 40.88355280458927, 37.62459307909012, 35.075264275074005, 34.70054358243942, 36.21329940855503, 34.53695856034756, 36.28223530948162, 36.14334136247635, 36.734126061201096, 36.16484820842743, 35.87916053831577, 37.36639313399792, 36.992531195282936, 35.2267811447382, 36.63880057632923, 35.76789490878582, 36.124422177672386, 37.26589232683182, 39.40380580723286, 42.37650029361248, 45.60030050575733, 44.90979015827179, 51.95292882621288, 44.38958667218685, 28.572281822562218, 45.47290854156017, 43.75873692333698, 47.16802038252354, 44.522317349910736, 42.99886129796505, 41.85511887073517, 47.80310310423374, 44.4699789583683, 50.79288147389889, 49.56597290933132, 46.32011868059635, 34.80773963034153, 36.58704735338688, 34.35182489454746, 38.45136411488056, 36.18613466620445, 36.40165530145168, 35.946348533034325, 37.2774513065815, 36.033318266272545, 35.41107125580311, 34.9478305131197, 37.09325239062309, 39.4576945155859, 40.56927166879177, 42.034321054816246, 46.234653666615486, 48.51701259613037, 50.06821855902672, 50.25635406374931, 49.83177624642849, 48.78069944679737, 50.522039607167244, 47.01633632183075, 42.512909173965454, 37.34712816774845, 36.304920092225075, 35.85587918758392, 38.31821545958519, 42.786467894911766, 40.428926199674606, 43.6234375834465, 47.74387948215008, 49.48334254324436, 50.4347924888134, 47.549409717321396, 39.38654713332653, 46.901639476418495, 50.048604011535645, 53.92751187086105, 55.34705489873886, 62.65618309378624, 57.452738508582115, 49.29046109318733, 35.02701826393604, 21.194542609155178, 4.2855591885745525, 6.0079944133758545, 4.240713519975543, 0.56052086642012, 0.1227318927703891, 0.1649577429634519, 16.378437839448452, 42.946264520287514, 36.59511812031269, 25.907137133181095, 30.86668610572815, 40.99084384739399, 49.290533289313316, 29.903251603245735, 2.656179782934487, 0.026154389925068244, 0.058510006274445914, 0.043085186698590405, 0.021950409063720144, 0.032537271836190484, 0.03174429075443186, 0.052485251435427926, 0.01941747759701684, 0.003156286811645259, 0.035035144246649, 0.06334763282211497, 0.039912739157443866, 0.03985151939559728, 0.036903727377648465, 0.08153129732818343, 0.0066129258902947186, 0.04516125947702676, 0.005185119107409264, 0.09199330859701149, 0.028309286208241247, 0.07084241893608123, 0.015460574395547155, 0.054286666490952484, 0.05850511552125681, 0.05408311764767859, 0.04726389001007192, 0.022669488935207482, 0.05284522645524703, 0.003647452203949797, 0.03172461270878557, 0.04224976590194274, 0.06531787163112313, 0.653951974818483, 15.553371962159872, 45.19523464143276, 47.671751752495766, 39.209301844239235, 20.623972825706005, 30.18538646399975, 36.03566274046898, 35.58100953698158, 4.807414636015892, 0.11269170339801349, 1.3697584555484354, 28.90910904854536, 7.9359606094658375, 6.76582669839263, 3.555779135785997, 9.17752593755722, 33.06139513850212, 25.486877784132957, 25.084021501243114, 46.94566011428833, 50.07519118487835, 51.131101325154305, 52.67270140349865, 50.94492271542549, 49.57160420715809, 43.4388130903244, 39.602740332484245, 40.07238753139973, 40.15233524143696, 40.459795743227005, 38.12798246741295, 36.6530080139637, 37.36342929303646, 36.732469350099564, 37.56984181702137, 38.352007046341896, 38.046214655041695, 37.84422129392624, 35.724372044205666, 37.23082400858402, 40.1257898658514, 41.89317002892494, 42.8967759758234, 43.07847462594509, 47.34184205532074, 47.891060784459114, 47.16859795153141, 43.155310302972794, 39.23360534012318, 37.01312609016895, 35.7574188709259, 37.71698132157326, 37.15433791279793, 38.835432305932045, 36.89543500542641, 39.21761579811573, 36.3727730512619, 36.73192597925663, 40.43162405490875, 39.89774890244007, 37.13779740035534, 37.732894867658615, 37.54273407161236, 38.99859555065632, 39.079713597893715, 41.28726214170456, 44.55720327794552, 48.58502134680748, 46.2513043731451, 53.706299141049385, 46.982939913868904, 30.167308934032917, 45.958986058831215, 44.60836373269558, 47.47621804475784, 46.49072952568531, 43.00361104309559, 42.887215688824654, 46.46308220922947, 48.56731429696083, 52.551727294921875, 51.432314962148666, 49.012961983680725, 38.125432804226875, 39.327897280454636, 36.30525067448616, 39.69563014805317, 38.68993431329727, 37.54020720720291, 35.75752526521683, 39.38016727566719, 38.25890824198723, 38.16910766065121, 37.38726541399956, 39.298467859625816, 41.43890060484409, 42.72292010486126, 44.017294049263, 47.53126569092274, 51.33580394089222, 52.190248891711235, 51.43829584121704, 50.82860715687275, 50.353298261761665, 52.20906548202038, 50.40980502963066, 45.316261947155, 38.88301335275173, 39.87506031990051, 38.28602738678455, 40.87939202785492, 44.802176132798195, 43.381337374448776, 44.516408666968346, 48.849768340587616, 51.78533881902695, 51.94639317691326, 48.90730105340481, 40.51925875246525, 47.26718746125698, 50.92463560402393, 53.41551974415779, 57.30422727763653, 62.18632310628891, 58.0390128493309, 49.4374980032444, 34.60737258195877, 15.224937535822392, 8.71352143585682, 9.401504918932915, 5.149080427363515, 1.3483230932615697, 0.20396413427079096, 0.12291956707485951, 17.95917011797428, 48.41398872435093, 41.40473663806915, 29.520703330636024, 31.97122983634472, 45.33143073320389, 55.840724408626556, 36.392266005277634, 3.152367607690394, 0.030521648841386195, 0.054627750141662546, 0.012059335713274777, 0.13202839822042733, 0.048247554805129766, 0.02267305681016296, 0.027788769803009927, 0.02350539212784497, 0.09995196669478901, 0.029895281768403947, 0.02307370708876988, 0.03322059317724779, 0.015535962684225524, 0.07756297432933934, 0.009252127802028554, 0.019271890487289056, 0.10259087313897908, 0.06365941648255102, 0.07732876736554317, 0.12127322377637029, 0.13916637457441539, 0.1590748570743017, 0.17451207793783396, 0.1727940802811645, 0.14449267939198762, 0.16660830908222124, 0.1320261717773974, 0.10324774804757908, 0.11358445510268211, 0.12926786119351164, 0.28237178397830576, 0.2314131785533391, 1.0902587533928454, 20.111680515110493, 52.87600949406624, 54.92357522249222, 47.03651703894138, 27.40000292658806, 32.126831486821175, 42.82713711261749, 42.460308596491814, 5.189761044457555, 0.2507470903219655, 2.2497787652537227, 37.20454461872578, 8.342335503548384, 9.15014460682869, 8.976694364100695, 9.406291712075472, 34.93674270808697, 25.658360682427883, 28.90483807772398, 49.14452612400055, 49.93326120078564, 51.72718293964863, 54.74643632769585, 52.36074574291706, 52.48036712408066, 46.88067600131035, 42.92848527431488, 43.46156246960163, 42.439455315470695, 41.74408882856369, 40.69421276450157, 39.63385306298733, 39.52374257147312, 38.45760338008404, 40.43871447443962, 41.525718346238136, 40.80953277647495, 40.37562645971775, 38.12063746154308, 40.05251459777355, 41.876184940338135, 45.78570395708084, 46.30022294819355, 48.00402112305164, 51.91168203949928, 50.727718770504, 51.33283630013466, 46.551583260297775, 41.93499818444252, 39.047590121626854, 38.53836044669151, 39.135597199201584, 38.81444223225117, 41.76096372306347, 40.316376239061356, 41.95605665445328, 40.45069143176079, 39.23475667834282, 43.3275056630373, 41.82430252432823, 38.75460684299469, 39.705650210380554, 40.62377594411373, 40.00920832157135, 41.19208104908466, 42.35418789088726, 46.002797707915306, 49.97710324823856, 49.7070175409317, 55.23396536707878, 48.898911103606224, 32.59340085089207, 45.35858407616615, 45.066463351249695, 46.74308158457279, 46.73868142068386, 43.577528446912766, 44.15114566683769, 47.637226805090904, 49.58881728351116, 54.21118564903736, 53.502390682697296, 51.23096376657486, 39.91529256105423, 42.05449037253857, 38.21843661367893, 41.300344839692116, 39.64670777320862, 40.003527626395226, 37.88855731487274, 41.35764576494694, 39.01156805455685, 39.623190835118294, 39.67856906354427, 41.10928729176521, 43.845064491033554, 44.51073557138443, 46.70085445046425, 50.041186809539795, 53.62105071544647, 54.11285452544689, 53.97997185587883, 51.830237209796906, 52.16545522212982, 54.22286622226238, 53.223652839660645, 48.12199719250202, 40.28486452996731, 41.36096678674221, 40.29970273375511, 43.87336537241936, 47.73754142224789, 45.19580081105232, 48.55762481689453, 51.09020411968231, 55.58397978544235, 53.78339700400829, 51.88118487596512, 43.60990650951862, 48.68075720965862, 51.563179939985275, 55.218336805701256, 59.88815702497959, 64.60881471633911, 59.79969397187233, 54.25093151628971, 35.467065051198006, 28.908295892179012, 14.34899428859353, 14.732176177203655, 11.498621888458729, 1.9145144429057837, 0.3532427013851702, 0.362123804516159, 21.39347903430462, 54.90597456693649, 47.423199489712715, 37.35386900603771, 41.589114144444466, 52.63524301350117, 63.19411262869835, 45.92751234769821, 4.783686334267259, 0.10924695074209012, 0.1880887197330594, 0.18523710634326562, 0.15569784765830263, 0.11664420380839147, 0.09735154060763307, 0.12002235613181256, 0.19091790542006493, 0.26363184268120676, 0.1347773429006338, 0.169904513459187, 0.12696056859567761, 0.13236742612207308, 0.13639801531098783, 0.15382696758024395, 0.1055230837664567], [0.04888168659817893, 0.026667162019293755, 0.023927334623294882, 0.022180025844136253, 0.04831026628380641, 0.03781425722991116, 0.06671587747405283, 0.06959073492907919, 0.017069268542400096, 0.06626351620070636, 0.03853641144814901, 0.05437314524897374, 0.019645892098196782, 0.011650760225165868, 0.012320772075327113, 0.015404777877847664, 0.8455618587322533, 13.778798785060644, 41.292471662163734, 44.99701447784901, 33.08928944170475, 15.372880697250366, 19.877757467329502, 45.95953322947025, 31.357177086174488, 3.0389940412715077, 0.054537735049962066, 0.9747977333609015, 26.072270572185516, 35.492086708545685, 17.650919258594513, 0.6285315763670951, 5.5106514506042, 21.726113185286522, 21.004919484257698, 36.86787888407707, 53.55014652013779, 50.121271312236786, 49.1769003868103, 51.52708947658539, 48.2437464594841, 44.87931579351425, 40.871849432587624, 39.610826298594475, 37.20487140119076, 38.57741855084896, 38.272317722439766, 39.09115098416805, 38.67170289158821, 37.20789983868599, 34.78469006717205, 36.70429766178131, 39.84375, 36.89830765128136, 36.18967227637768, 36.43893890082836, 44.60252724587917, 48.647812977433205, 48.42348821461201, 47.811569049954414, 48.64576868712902, 50.03623187541962, 49.851007014513016, 48.90951633453369, 47.34558865427971, 43.883438631892204, 39.56357583403587, 33.827247843146324, 33.67616415023804, 34.67163473367691, 36.17820829153061, 34.817117527127266, 36.03821240365505, 34.717593267560005, 36.46371357142925, 34.49974335730076, 36.12849175930023, 34.1325918585062, 36.88567332923412, 36.453906297683716, 37.51877635717392, 36.89040407538414, 36.464237943291664, 40.73044382035732, 43.572520315647125, 44.28374335169792, 48.561880588531494, 45.9410510212183, 28.479308411478996, 44.735402315855026, 44.197180196642876, 44.82089772820473, 45.33293925225735, 52.36341319978237, 50.9321554005146, 50.712299197912216, 49.49444554746151, 49.13049727678299, 47.323401644825935, 40.079211965203285, 36.8093354254961, 37.68010810017586, 36.95013307034969, 36.740247532725334, 35.659353733062744, 36.40047736465931, 37.12993182241917, 37.18180663883686, 36.57728187739849, 35.52106395363808, 36.22914835810661, 36.199342757463455, 35.19094526767731, 35.8596333861351, 37.05284155905247, 38.81255753338337, 41.30534917116165, 45.64605765044689, 50.91338440775871, 52.009902969002724, 51.12942561507225, 51.526641100645065, 48.542467430233955, 43.47086817026138, 37.77775526046753, 37.38710202276707, 40.231154412031174, 48.78937438130379, 48.39340902864933, 47.018965780735016, 44.58352826535702, 45.893720760941505, 51.41331598162651, 55.30363082885742, 52.13151924312115, 54.431501626968384, 49.76700112223625, 50.92987172305584, 55.971984565258026, 56.066147312521935, 54.42250370979309, 61.48268826305866, 51.40753649175167, 40.18027514219284, 21.261694505810738, 7.403105702251196, 5.725793531164527, 3.3003053069114685, 0.924415880581364, 0.05801526836876292, 0.06895534519571811, 10.914746169000864, 44.23228271305561, 34.37536843121052, 31.34001910686493, 34.87799026072025, 44.057412296533585, 53.00260730087757, 35.17778277397156, 2.754599964246154, 0.024609739411971532, 0.11211566321435384, 0.0381990125606535, 0.05857615760760382, 0.021822293965669814, 0.016047455501393415, 0.04665376298362389, 0.01967688604054274, 0.010261511724820593, 0.09177346219075844, 0.05461674038087949, 0.039246787782758474, 0.10427569679450244, 0.053109909713384695, 0.02311148797161877, 0.09609942615497857, 0.020200526887492742, 0.04455683956621215, 0.03488668502541259, 0.017028680485964287, 0.07218641869258136, 0.03582823293982074, 0.04359876773378346, 0.0360311472468311, 0.03452824254054576, 0.07507634174544364, 0.06808893973357044, 0.041312800749437883, 0.02015573270909954, 0.04726360428321641, 0.0197109116561478, 0.0681636220542714, 1.1715448228642344, 17.51875475049019, 47.26690627634525, 51.1694260686636, 37.935199812054634, 22.27836985141039, 23.056505396962166, 44.274441450834274, 36.05949506163597, 3.404137585312128, 0.03474179553450085, 0.6418142979964614, 29.207537434995174, 25.25344491004944, 8.940962981432676, 3.9716171845793724, 7.398236263543367, 23.807573094964027, 23.041137121617794, 39.452211409807205, 53.757774978876114, 48.9740102738142, 50.356778874993324, 52.17034175992012, 50.053209364414215, 46.242051869630814, 42.474861815571785, 40.74880063533783, 40.14267235994339, 40.721278712153435, 42.00275234878063, 41.888587474823, 40.09992465376854, 38.81416864693165, 37.21133105456829, 37.75606982409954, 41.26976788043976, 38.53704571723938, 36.222255527973175, 38.61224368214607, 45.6934867054224, 50.00475436449051, 49.82440084218979, 49.087179601192474, 50.6889608502388, 52.20295161008835, 52.71547190845013, 50.87634399533272, 49.32234898209572, 45.718204379081726, 40.64433664083481, 35.58411777019501, 35.1824527233839, 35.15178456902504, 37.892117723822594, 36.6073876619339, 38.052955493330956, 38.80017779767513, 38.440929874777794, 36.3611076772213, 37.37462729215622, 35.87924413383007, 36.93308338522911, 38.75079944729805, 39.14909407496452, 39.3960390239954, 39.01096008718014, 40.88296003639698, 44.37268137931824, 46.40640825033188, 49.786581471562386, 47.600524574518204, 29.843904487788677, 45.55523872375488, 43.98555815219879, 44.81107905507088, 44.11986954510212, 50.48560716211796, 53.10379587113857, 52.73912563920021, 51.317431926727295, 52.2748551517725, 49.542376175522804, 42.745152711868286, 37.13115155696869, 40.073295682668686, 39.86271098256111, 38.79192464053631, 38.355392664670944, 37.943570762872696, 37.89667747914791, 39.634613022208214, 37.65941061079502, 36.57030165195465, 37.36332289874554, 38.99402439594269, 36.9196093082428, 39.85242873430252, 37.46909782290459, 42.7895001322031, 43.49048651754856, 48.21633093059063, 53.034149408340454, 53.58242578804493, 52.55544729530811, 53.642268776893616, 51.207009851932526, 46.335796639323235, 40.07161237299442, 38.84948395192623, 42.12399244308472, 50.10776303708553, 50.07752425968647, 47.716615945100784, 47.38985627889633, 48.34200158715248, 53.740736693143845, 54.9272458255291, 51.61298766732216, 53.33703875541687, 50.74825666844845, 50.897729247808456, 56.79229594767094, 58.7226265668869, 57.67553575336933, 62.9380139708519, 53.35234433412552, 37.740851640701294, 15.333218425512314, 7.292209602892399, 5.401726495474577, 4.952410105615854, 0.6227146822493523, 0.0723892476526089, 0.0888781956746243, 13.393356017768383, 48.85476127266884, 39.130186289548874, 38.82595181465149, 39.41856421530247, 48.99837076663971, 57.21835948526859, 41.4606848359108, 4.185683447867632, 0.008894792044884525, 0.05693635263014585, 0.019760247778322082, 0.024057642767729703, 0.06152028712676838, 0.0828535744221881, 0.07155422761570662, 0.04515239081229083, 0.052066947318962775, 0.0898869005322922, 0.06496775604318827, 0.03371723469172139, 0.046017812928766944, 0.05024230675189756, 0.08589353004936129, 0.04417780990479514, 0.14125595072982833, 0.14831721869995818, 0.11241366519243456, 0.0697788767865859, 0.2336396067403257, 0.1196601361152716, 0.1659496084903367, 0.1860087172826752, 0.08601680077845231, 0.15046644868561998, 0.10723787534516305, 0.1625152607448399, 0.0955294122104533, 0.07285983607289381, 0.11341717501636595, 0.22854774637380615, 1.964504204224795, 22.345339357852936, 57.15616062283516, 56.999916806817055, 45.266249030828476, 22.94397823512554, 28.263489492237568, 56.90895728766918, 41.25309057533741, 4.582364587113261, 0.22697987034916878, 1.3680867827497423, 32.02942371368408, 43.252193704247475, 33.635806515812874, 6.135635739192367, 7.477576956152916, 27.720910906791687, 25.267460457980633, 43.91721501946449, 54.446328431367874, 48.48902329802513, 51.12437568604946, 55.337950587272644, 51.81536100804806, 48.915463015437126, 44.49332870543003, 43.92697289586067, 40.62653839588165, 43.15862372517586, 44.14297230541706, 44.98563788831234, 41.43386967480183, 41.912784576416016, 39.19612795114517, 40.69229006767273, 43.87440651655197, 39.70034949481487, 38.81709448993206, 41.42795339226723, 47.753447368741035, 52.76639297604561, 51.67087376117706, 51.89755819737911, 53.66336144506931, 55.80668583512306, 54.53201003372669, 54.19557988643646, 53.49048972129822, 47.35725022852421, 43.24522107839584, 37.74373568594456, 37.95632287859917, 36.7721202224493, 40.56400515139103, 38.65298509597778, 40.98438419401646, 40.5080683529377, 40.50967566668987, 38.75578097999096, 39.682908430695534, 37.69156828522682, 39.85327988862991, 39.97813358902931, 41.86018019914627, 42.91132539510727, 38.74951131641865, 44.04575452208519, 47.30315253138542, 50.21191164851189, 51.98169328272343, 49.23750713467598, 33.03836837410927, 45.54624080657959, 44.38304342329502, 43.67842063307762, 45.45150429010391, 53.81759516894817, 55.48792853951454, 55.373683869838715, 53.71970482170582, 55.914505049586296, 51.99474558234215, 44.09061871469021, 40.90888984501362, 41.1884256452322, 42.444129064679146, 40.941172912716866, 40.7812774926424, 39.90795895457268, 40.49365192651749, 40.92580273747444, 39.48963560163975, 37.49544180929661, 39.39451150596142, 40.266150534152985, 39.70976158976555, 41.7305501550436, 40.40836550295353, 44.056040570139885, 45.67106410861015, 51.23265467584133, 56.96432791650295, 54.73589189350605, 55.19372932612896, 53.57128858566284, 53.40201526880264, 48.34751509130001, 41.42882354557514, 40.2912899851799, 44.3538723886013, 53.416663482785225, 53.37120272219181, 51.172538101673126, 49.574267864227295, 50.37931926548481, 56.80175743997097, 57.42025405168533, 55.50964057445526, 54.649115949869156, 51.73054575920105, 52.27480575442314, 60.52640877664089, 60.892735719680786, 60.48840321600437, 63.75520572066307, 55.94972535967827, 40.954943373799324, 28.68017703294754, 14.808795265853405, 11.670980639755726, 8.87094508856535, 2.3124100919812918, 0.3118881251430139, 0.1522988558281213, 15.347839090973139, 56.29037708044052, 45.72033226490021, 44.117490872740746, 45.45113950967789, 59.094273224473, 63.844888508319855, 49.230025336146355, 5.971835553646088, 0.13281215069582686, 0.1893555955030024, 0.13753975013969466, 0.13055902003543451, 0.14371664525242522, 0.16010685794753954, 0.1744061437784694, 0.1443302826373838, 0.08108789377729408, 0.1478022275841795, 0.20432164164958522, 0.1149794329830911, 0.17261445085750893, 0.12010765116428956, 0.27554087864700705, 0.1475429063430056], [0.12967013492016122, 0.05092575054732151, 0.07587803935166448, 0.01542348927614512, 0.017664270599198062, 0.04235342537867837, 0.02559666223532986, 0.05721767483919393, 0.02137621497240616, 0.023397381810355, 0.06395067233825102, 0.06585483031813055, 0.11294742522295564, 0.014327864082588349, 0.07949531165650114, 0.05107743068947457, 0.541857099160552, 17.982474267482758, 49.02847655117512, 46.19528777897358, 29.63105320930481, 14.58596857264638, 52.21111737191677, 58.54397535324097, 28.732978999614716, 3.9962579123675823, 0.030577098405046854, 1.4666675054468215, 20.613029412925243, 30.519762821495533, 11.697072889655828, 0.7883387699257582, 6.104064658284187, 23.025495260953903, 41.920733749866486, 54.95291344821453, 49.8124048858881, 50.01989655196667, 50.03385700285435, 50.80580078065395, 47.38012120127678, 41.76319420337677, 37.90117643773556, 38.90440620481968, 35.27321085333824, 37.378164902329445, 36.64557561278343, 39.341789335012436, 37.226306051015854, 38.19852948188782, 36.56709082424641, 36.46324619650841, 37.83672049641609, 34.77391004562378, 35.07058672606945, 40.02573363482952, 44.994286224246025, 47.73556172847748, 47.461410239338875, 47.350900769233704, 49.35366690158844, 47.664049565792084, 45.730492919683456, 46.21124692261219, 45.257080122828484, 45.30381381511688, 43.06961350142956, 40.13498157262802, 37.56408892571926, 35.13563543558121, 35.78581094741821, 34.84216198325157, 35.532630532979965, 36.090736985206604, 35.918857008218765, 35.22732071578503, 36.25533655285835, 34.76733259856701, 35.258593037724495, 36.24631963670254, 36.884825974702835, 36.73142060637474, 38.28929901123047, 38.70265603065491, 43.981100991368294, 44.77473020553589, 48.08744564652443, 48.6478965729475, 30.31176008284092, 44.18213680386543, 47.215954810380936, 49.56948772072792, 49.92721572518349, 48.466756492853165, 47.602823451161385, 47.467653304338455, 46.25036582350731, 46.480135694146156, 39.807815328240395, 34.612057730555534, 35.644477531313896, 37.72019974887371, 36.561831906437874, 36.33352495729923, 36.31161913275719, 35.91153860092163, 35.77798716723919, 37.36401446163654, 35.89493729174137, 37.160474583506584, 36.538550555706024, 34.72096748650074, 35.01929707825184, 34.23119656741619, 35.50090603530407, 36.62438414990902, 35.649793446063995, 36.703039929270744, 41.53118245303631, 46.39714054763317, 49.35292974114418, 50.62952823936939, 49.84804317355156, 43.2751976698637, 39.32262696325779, 36.982727721333504, 46.889787912368774, 51.979231014847755, 53.92174378037453, 52.35770210623741, 52.57372431457043, 51.62251375615597, 52.388567849993706, 54.93189677596092, 47.32659727334976, 52.86766514182091, 54.512623474001884, 56.55609302222729, 55.6226959079504, 58.7345427274704, 56.11459471285343, 56.38709329068661, 55.356979966163635, 49.5217090845108, 15.81953153014183, 7.786055328324437, 6.461691968142986, 2.9941619094461203, 0.9987500449642539, 0.1766857097391039, 0.028164307659608312, 9.444330520927906, 41.51553489267826, 37.758619487285614, 15.872713476419449, 24.09975841641426, 42.49225728213787, 51.77805460989475, 34.54810716211796, 3.8042323663830757, 0.10871747290366329, 0.04570628530927934, 0.04880490028881468, 0.04531690639851149, 0.081157715030713, 0.03421862595132552, 0.10332862730138004, 0.08138781049638055, 0.02757418707915349, 0.03798086196184158, 0.0828275473031681, 0.056505309548811056, 0.0501744633220369, 0.0604982755612582, 0.006901425595060573, 0.09278082376113161, 0.05839679535711184, 0.018155622456106357, 0.049718216905603185, 0.029029694524069782, 0.04655717988498509, 0.0802123970061075, 0.03657202447357122, 0.005851538498973241, 0.025850521269603632, 0.03930017788661644, 0.008509318686265033, 0.057216669229092076, 0.05182372697163373, 0.009568824480084004, 0.06089522437832784, 0.10995590215316042, 0.850657147821039, 21.672271974384785, 55.683667436242104, 51.93593993782997, 35.5510975420475, 15.01000301912427, 38.38197983801365, 63.53309623897076, 33.32133159041405, 3.937094137072563, 0.11088144936366007, 0.9464508388191462, 23.79029732197523, 31.343421824276447, 14.109975714236498, 3.5617172671481967, 8.294254783540964, 27.877585999667645, 41.79891988635063, 55.09953238070011, 48.431957960128784, 50.88352181017399, 51.96189634501934, 52.86957643926144, 49.51520763337612, 44.16938468813896, 42.35469326376915, 39.060273841023445, 36.9853837788105, 39.4181614369154, 37.270581275224686, 41.63428232073784, 38.65148797631264, 39.55783054232597, 37.844517678022385, 38.143329843878746, 38.6726338416338, 35.953260362148285, 36.7014592140913, 41.45782358944416, 47.6235057413578, 51.236712858080864, 49.09837380051613, 46.557689532637596, 50.78161507844925, 48.154344856739044, 47.22686022520065, 48.329253271222115, 47.957690209150314, 48.12280274927616, 46.21904410421848, 39.7966743260622, 38.83404158055782, 37.64599733054638, 36.657753959298134, 36.65123350918293, 37.65097126364708, 37.98808157444, 37.52938538789749, 37.20671430230141, 38.281201645731926, 36.57279431819916, 36.48899741470814, 37.705669328570366, 38.29825513064861, 39.75879795849323, 40.35771422088146, 40.358462780714035, 45.08321285247803, 46.11366055905819, 49.729196950793266, 49.740436747670174, 31.432103365659714, 42.74330221116543, 47.04918935894966, 51.5136343985796, 51.78637996315956, 51.57441973686218, 48.32870990037918, 50.92251531779766, 49.12843778729439, 48.69338773190975, 42.67204463481903, 37.15177305042744, 37.814651280641556, 39.01546284556389, 38.36425758898258, 37.8363823145628, 37.28596664965153, 37.55302771925926, 37.56315037608147, 38.16133327782154, 37.54710003733635, 38.35420332849026, 37.669506669044495, 36.912986263632774, 36.28297246992588, 36.41899757087231, 38.093077540397644, 38.442730978131294, 37.59892165660858, 39.09010984003544, 44.35327962040901, 49.27696421742439, 51.3944385945797, 53.12266565859318, 50.898139625787735, 47.61512339115143, 40.06930969655514, 38.727719485759735, 47.78247021138668, 53.892800733447075, 54.467337504029274, 54.52958956360817, 53.65447752177715, 53.34423556923866, 52.91604794561863, 56.834492683410645, 49.759329333901405, 55.961709916591644, 55.58053717017174, 57.140919640660286, 57.159037068486214, 60.30735433101654, 57.01606594026089, 57.572515681385994, 55.822071209549904, 46.95495821535587, 16.89236406236887, 6.689081741496921, 5.143500426784158, 4.5589331444352865, 1.311291349120438, 0.15660216944525018, 0.13268536218674853, 11.410618610680103, 47.678861171007156, 45.31417205929756, 23.539410084486008, 30.842707492411137, 49.17574904859066, 58.968788757920265, 40.9424040466547, 4.9780055321753025, 0.0911462731892243, 0.0430377597513143, 0.025848703007795848, 0.04684325183916371, 0.047886136308079585, 0.04496090186876245, 0.02555326143919956, 0.05195542107685469, 0.04408088541822508, 0.013892867209506221, 0.026996334199793637, 0.017464599477534648, 0.041529830705258064, 0.05637945985654369, 0.039676762171438895, 0.036243078648112714, 0.22563879465451464, 0.21582773595582694, 0.2040217991452664, 0.1101726909109857, 0.09435572050279006, 0.20447390066692606, 0.1551113580353558, 0.17104716855101287, 0.13438119931379333, 0.14130579336779192, 0.23227166529977694, 0.103782561927801, 0.1846019912045449, 0.0751139983185567, 0.1716433506226167, 0.2530207339441404, 1.4432919910177588, 26.926878914237022, 64.00276243686676, 58.50434347987175, 42.51611240208149, 22.96440403908491, 59.18219670653343, 67.32735604047775, 36.83103986084461, 5.876844450831413, 0.14466788561549038, 1.538203179370612, 25.12088142335415, 38.34805905818939, 17.350653670728207, 3.75619035679847, 9.56283001229167, 30.459032580256462, 45.29031313955784, 55.704566314816475, 52.68969789147377, 53.90718296170235, 53.67333970963955, 53.98092180490494, 51.54345139861107, 46.01100906729698, 43.526934161782265, 41.96983851492405, 38.70715118944645, 42.645860239863396, 40.01085743308067, 44.25157807767391, 41.27320669591427, 41.99259169399738, 39.831662848591805, 39.80939224362373, 41.024179458618164, 37.869102358818054, 39.774646908044815, 43.36826227605343, 50.28794936835766, 52.624641582369804, 51.00791193544865, 47.384954541921616, 52.38926321268082, 51.05646193027496, 49.11588326096535, 49.67386431992054, 48.634376898407936, 50.72123631834984, 49.26450088620186, 42.42468170821667, 40.41359782218933, 39.639123380184174, 38.12798626720905, 38.747132644057274, 39.48572941124439, 39.36101630330086, 39.94327425956726, 39.576054364442825, 39.7917839884758, 37.674788385629654, 38.790077939629555, 39.08056475222111, 40.65850608050823, 42.16938480734825, 43.145389035344124, 44.03033874928951, 48.16540986299515, 48.68552215397358, 51.91876865923405, 52.00877822935581, 35.970127657055855, 42.939911261200905, 48.205307722091675, 52.39715538918972, 52.39430174231529, 53.01859684288502, 50.634357780218124, 52.94988512992859, 51.411210894584656, 51.988544315099716, 44.09480229020119, 38.17020580172539, 39.02892552316189, 41.65933057665825, 40.31956426799297, 39.524627923965454, 40.48400804400444, 38.82954262197018, 38.479699194431305, 39.075442627072334, 39.614189118146896, 41.58163994550705, 40.475298911333084, 38.25985439121723, 37.99311250448227, 39.370189011096954, 40.66483274102211, 40.49531623721123, 40.69961607456207, 41.140536814928055, 46.475366950035095, 51.00323058664799, 53.41854438185692, 55.79255439341068, 54.22881290316582, 48.32857310771942, 42.84731023013592, 39.46614906191826, 51.13078974187374, 56.42859846353531, 57.93867163360119, 55.51973283290863, 56.130797043442726, 54.8699676990509, 55.818092823028564, 60.34231245517731, 52.227714881300926, 56.16188697516918, 58.09127904474735, 60.316405445337296, 57.306522354483604, 64.48719084262848, 60.614666640758514, 60.59200465679169, 58.83659765124321, 51.02344550192356, 22.888463214039803, 11.544120647013187, 13.337423019111156, 8.761591706424952, 1.8248716718517244, 0.3841412777546793, 0.24378567090025172, 13.555778302252293, 54.46337811648846, 47.25114092230797, 25.01831352710724, 35.95462068915367, 55.5515219271183, 66.14484429359436, 48.4297426789999, 7.2972381580621, 0.21718838950619102, 0.13803856243612245, 0.1990587607724592, 0.15293088363250718, 0.11515076519572176, 0.1285536479554139, 0.2183326773229055, 0.14379394735442474, 0.1797271051327698, 0.18578653311124071, 0.13865749875549227, 0.09879932971671224, 0.1533899168134667, 0.14035477564902976, 0.10174805312999524, 0.19363694154890254], [0.08658828417537734, 0.059347601563786156, 0.07532304647611454, 0.05960097078059334, 0.011209337280888576, 0.010185714327235473, 0.05171105411136523, 0.06843156705144793, 0.032842836299096234, 0.0314092036569491, 0.06371363037033007, 0.07537214696640149, 0.02514825846446911, 0.029665844958799426, 0.05055840971181169, 0.06439207209041342, 0.9494767233263701, 18.04131790995598, 44.234551191329956, 49.40278306603432, 34.14543516933918, 37.17430964112282, 56.31449058651924, 43.210517540574074, 28.13464030623436, 3.7734454683959484, 0.12890992336906493, 9.84723525121808, 39.44862820208073, 18.834654539823532, 9.370176550000906, 3.6140200356021523, 5.302226934581995, 26.83207020163536, 46.42284236848354, 49.137568697333336, 49.52669821679592, 52.80686840415001, 50.53402416408062, 50.24067610502243, 45.06424807012081, 42.93356940150261, 40.1382227987051, 37.83742345869541, 38.08651529252529, 39.68497931957245, 38.162735402584076, 38.86442095041275, 37.57641166448593, 35.32858148217201, 36.47963471710682, 35.86392715573311, 34.58497658371925, 33.796043917536736, 35.39968706667423, 38.422417268157005, 42.050732374191284, 47.41545170545578, 48.5118942707777, 47.220104187726974, 47.5776232033968, 45.68790100514889, 43.935594633221626, 43.84883388876915, 43.960958272218704, 46.40550009906292, 43.849438056349754, 42.26433031260967, 41.056371331214905, 38.37300851941109, 37.07398362457752, 34.85592484474182, 34.11848321557045, 33.899546563625336, 35.4746950417757, 35.790933072566986, 35.28601236641407, 35.556922629475594, 33.64636614918709, 35.23300901055336, 35.902985259890556, 37.35537752509117, 37.07586072385311, 37.068112939596176, 42.39619083702564, 42.225804179906845, 45.643469989299774, 48.12522701919079, 27.634412348270416, 45.72501361370087, 52.015169486403465, 50.04565916955471, 47.165094539523125, 46.431711092591286, 47.37240381538868, 43.316626846790314, 40.72360418736935, 39.065316170454025, 34.35062795877457, 36.2155032902956, 36.84345759451389, 36.68575465679169, 37.93451584875584, 36.91614769399166, 36.09540693461895, 37.270254492759705, 37.92511135339737, 37.76136673986912, 37.89245590567589, 37.13775560259819, 37.55861721932888, 37.13992528617382, 34.74652871489525, 34.04046580195427, 34.42763462662697, 33.747455924749374, 35.18899217247963, 35.69220297038555, 36.30187265574932, 36.42232999205589, 41.26780338585377, 45.828352868556976, 46.579074785113335, 43.68366055190563, 40.2593033015728, 37.552704736590385, 47.42130719125271, 53.404545933008194, 51.03710576891899, 52.58164308965206, 50.32344326376915, 49.833820536732674, 52.810193225741386, 49.366954788565636, 49.22571636736393, 53.39539982378483, 50.953183472156525, 56.3484113663435, 55.9262578189373, 56.58923104405403, 51.66100949048996, 57.40825429558754, 53.4660342335701, 49.75028581917286, 19.275199100375175, 4.039942743256688, 2.3653163155540824, 2.9267043666914105, 1.154062079731375, 0.0460813185054576, 0.06680902442894876, 7.997341565787792, 41.47180303931236, 43.04611936211586, 36.76219895482063, 31.14568803459406, 48.07900629937649, 52.66035966575146, 32.32985459268093, 3.842225340195, 0.04046962822030764, 0.04769150065840222, 0.08686062268679962, 0.02573183701315429, 0.012993031705264002, 0.05288025953632314, 0.0376053908985341, 0.05653938525938429, 0.03062753105041338, 0.05114368221256882, 0.02149565621948568, 0.06388265450368635, 0.006252007415241678, 0.06979590907576494, 0.035333535852259956, 0.024044081874308176, 0.04415790179336909, 0.058486276102485135, 0.05381927672715392, 0.05691745383956004, 0.05208424307056703, 0.031107208924368024, 0.03460535910562612, 0.03549383603967726, 0.017953454007511027, 0.06204125253134407, 0.07456827486748807, 0.043519061073311605, 0.04129554581595585, 0.019710765081981663, 0.05325663230905775, 0.05342682903574314, 1.1090785497799516, 22.74208176881075, 51.051670387387276, 54.4844213873148, 38.15865062177181, 36.76900438964367, 60.94875991344452, 49.2759420722723, 32.712706848978996, 4.630786813795567, 0.08338147890754044, 8.902817778289318, 39.26377572119236, 20.724815614521503, 11.410928294062614, 3.9357214607298374, 8.913210220634937, 29.942338205873966, 46.47629790008068, 48.73128689825535, 49.139685183763504, 55.53378447890282, 54.02561500668526, 51.40139602124691, 47.67699547111988, 44.61235351860523, 43.234152272343636, 40.04362307488918, 39.9021452665329, 41.70789957046509, 40.089194029569626, 41.87342628836632, 40.436256006360054, 37.295336946845055, 38.70001137256622, 36.87774695456028, 35.352869778871536, 36.62328980863094, 36.789033114910126, 39.624554961919785, 45.14556750655174, 49.45393592119217, 49.097659438848495, 47.56697237491608, 50.971475690603256, 48.46804082393646, 46.70237056910992, 44.73751500248909, 46.103306114673615, 46.731002032756805, 48.01803097128868, 44.03251223266125, 41.33696347475052, 40.36399148404598, 39.17220823466778, 36.42474286258221, 37.29830078780651, 36.363900527358055, 36.70524001121521, 38.01386699080467, 38.12575198709965, 36.59265585243702, 36.386254727840424, 36.25327706336975, 37.510796785354614, 39.53723944723606, 39.815259128808975, 40.054205507040024, 44.932672530412674, 44.3491530418396, 49.27311882376671, 50.21695397794247, 30.96166580915451, 45.99243946373463, 53.92547897994518, 52.03833684325218, 49.58337217569351, 48.1954700499773, 49.78841297328472, 47.28660821914673, 44.027545899152756, 42.02286086976528, 36.38402044773102, 37.721438482403755, 38.21307510137558, 40.16099497675896, 38.68372164666653, 39.136592745780945, 39.08512070775032, 39.75982390344143, 41.10796496272087, 39.82954256236553, 39.242702051997185, 39.4524621963501, 38.55334684252739, 39.00340989232063, 37.3170717805624, 34.959773272275925, 35.12979134917259, 35.32502867281437, 37.337913662195206, 36.70488283038139, 38.22358153760433, 38.853963911533356, 45.473854690790176, 49.88351806998253, 48.782443553209305, 46.520360335707664, 42.22779907286167, 39.169966354966164, 49.20853368937969, 55.23333080112934, 53.43657821416855, 52.80289001762867, 51.755168437957764, 52.61874809861183, 54.480765983462334, 52.028263583779335, 52.03426346182823, 55.40841780602932, 54.10176672041416, 58.30776862800121, 58.61828416585922, 59.08130072057247, 55.49553573131561, 57.98553831875324, 58.30706186592579, 48.125823587179184, 17.651540525257587, 8.827671110630035, 9.365963526070118, 4.207282438874245, 2.2149555338546634, 0.0961802015081048, 0.059377918296377175, 9.753270093351603, 46.815270110964775, 41.36030562222004, 30.22992767393589, 33.47901172935963, 51.307373866438866, 60.776480957865715, 39.20036092400551, 5.544878114014864, 0.005525377118829056, 0.03563846577890217, 0.12456696422304958, 0.01954717718035681, 0.06351183299557306, 0.02211936269304715, 0.004936172163070296, 0.013318658275238704, 0.0778505639755167, 0.05722232068364974, 0.020084638672415167, 0.01412843972502742, 0.0428175682463916, 0.025848059194686357, 0.0647175929043442, 0.09684983393526636, 0.14701277541462332, 0.1468399737495929, 0.2237990402500145, 0.13772850797977298, 0.33226381929125637, 0.22184070548973978, 0.17487783799879253, 0.14751664915820584, 0.13820275518810377, 0.08933975957916118, 0.19219371664803475, 0.2499021403491497, 0.1660506147891283, 0.11838264763355255, 0.16003406810341403, 0.1486963967909105, 1.7107121413573623, 28.73291440308094, 58.09398829936981, 63.22130396962166, 45.031030252575874, 46.3420245051384, 61.84541679918766, 51.37818306684494, 37.69430413842201, 5.802628258243203, 0.18682692025322467, 12.512696273624897, 45.79724393785, 21.915496923029423, 14.298162516206503, 11.180289220064878, 7.992675416171551, 31.973011940717697, 47.89446160197258, 50.62247961759567, 51.723261550068855, 57.74769388139248, 56.150176003575325, 52.63446785509586, 49.79428365826607, 47.167530208826065, 45.762631595134735, 41.71679489314556, 43.036768063902855, 43.542068749666214, 41.91577881574631, 43.282755464315414, 42.617946937680244, 38.92055533826351, 40.56240923702717, 38.89457993209362, 37.356118485331535, 38.05276170372963, 38.768529295921326, 43.48965436220169, 47.460870668292046, 50.39647534489632, 51.04109175503254, 48.06046709418297, 53.287907391786575, 52.210813388228416, 48.992526680231094, 48.44708874821663, 47.73335784673691, 50.62315598130226, 50.367935076355934, 46.14424891769886, 44.28494028747082, 43.21777895092964, 41.98735937476158, 38.54523807764053, 38.52064199745655, 37.81076408922672, 38.87045882642269, 37.86995731294155, 39.53119397163391, 39.49468933045864, 37.83037483692169, 39.12977211177349, 39.495969861745834, 42.42069952189922, 41.473649740219116, 43.4019360691309, 47.66833193600178, 46.89201459288597, 50.61095103621483, 52.061766386032104, 33.78680661320686, 46.7078422755003, 56.25046782195568, 55.617794170975685, 53.566531240940094, 50.827197432518005, 52.948080226778984, 47.60130733251572, 45.83272263407707, 45.52192971110344, 38.35207164287567, 39.46331441402435, 40.18785573542118, 41.068618074059486, 40.56495890021324, 41.13495871424675, 40.61627894639969, 40.74206739664078, 42.08165891468525, 41.77261009812355, 41.53342813253403, 41.092602387070656, 41.32405176758766, 40.90078487992287, 39.88170236349106, 38.37176598608494, 37.31871709227562, 38.25877144932747, 38.80555830895901, 38.74615229666233, 40.15591084957123, 38.207926377654076, 46.319256126880646, 51.315030455589294, 51.53492085635662, 48.43676470220089, 45.051207169890404, 41.47616520524025, 51.49284191429615, 58.27049642801285, 55.0907738506794, 55.80796256661415, 53.641204833984375, 55.11800318956375, 58.77782620489597, 54.12651099264622, 54.23412501811981, 57.88245365023613, 56.53516374528408, 60.92666409909725, 61.92227527499199, 61.791740879416466, 57.301077246665955, 61.22964084148407, 57.61701509356499, 52.363724783062935, 20.60821697115898, 7.864526817575097, 7.681531487032771, 15.144414156675339, 3.836522796191275, 0.28976072499062866, 0.15778507862705737, 9.994397554546595, 55.81184595823288, 54.384562745690346, 48.574161529541016, 41.15233138203621, 60.883893594145775, 67.27849826216698, 48.287261724472046, 8.14304569736123, 0.16094514343421906, 0.22564888786291704, 0.21678881719708443, 0.10993895150022581, 0.10621265028021298, 0.14122221269644797, 0.1164927240461111, 0.15980125637724996, 0.2563896984793246, 0.19835228071315214, 0.1444773911498487, 0.1324163781828247, 0.14680386084364727, 0.18415582686429843, 0.16116462618811056, 0.15078177239047363], [0.06912163080414757, 0.02432581411994761, 0.1071441346721258, 0.07122565657482482, 0.03727484574483242, 0.08144458479364403, 0.003378548908585799, 0.046214233443606645, 0.031611008453182876, 0.026910434316960163, 0.053265760725480504, 0.037174692915868945, 0.012228604755364358, 0.030702612275490537, 0.04299736465327442, 0.11826474263216369, 0.664403373375535, 19.86970379948616, 45.03578759729862, 43.496714383363724, 28.639279827475548, 23.055158369243145, 49.97724384069443, 41.47724434733391, 29.09974481910467, 6.363398842513561, 0.07796483987476677, 18.638619258999825, 31.908935979008675, 14.358636271208525, 10.24097677320242, 4.497684231027961, 4.459776040166616, 13.28338896855712, 44.45806659758091, 56.45001791417599, 50.509580075740814, 49.43223908543587, 48.699076026678085, 46.58461108803749, 40.685332641005516, 39.07518044114113, 38.98731395602226, 36.63995951414108, 39.62583169341087, 39.610963091254234, 40.32238371670246, 40.09494312107563, 37.315840646624565, 33.86834263801575, 32.762446179986, 35.370979607105255, 35.76203942298889, 35.857862681150436, 37.88794554769993, 39.33316379785538, 42.108846455812454, 47.485789731144905, 46.514204666018486, 49.66354787349701, 46.32657453417778, 43.30004073679447, 39.47953574359417, 40.07298789918423, 44.8946213722229, 45.45568406581879, 46.766571924090385, 43.82670387625694, 41.40035167336464, 38.76067511737347, 34.949156641960144, 34.16899770498276, 35.10831870138645, 35.909733697772026, 35.28969056904316, 34.61844518780708, 34.493120312690735, 35.939805284142494, 35.190291702747345, 36.39231160283089, 34.561607837677, 35.75463742017746, 35.58958187699318, 37.66487471759319, 39.72475178539753, 45.57377032935619, 47.22271464765072, 50.92967413365841, 33.39167341589928, 50.38341924548149, 49.84214968979359, 46.41910716891289, 44.654915034770966, 39.107497707009315, 36.97051137685776, 34.57425355911255, 34.995806738734245, 36.70031547546387, 36.490042358636856, 38.672736436128616, 38.40193636715412, 37.038991302251816, 37.42959514260292, 35.72676971554756, 36.79781064391136, 36.293060928583145, 37.687916681170464, 41.16151548922062, 39.44146938621998, 40.556413158774376, 35.19776590168476, 34.76537950336933, 37.04471759498119, 39.64989200234413, 41.3615595549345, 40.585850179195404, 39.46807935833931, 36.96651019155979, 34.944304302334785, 34.07254368066788, 36.19678549468517, 38.82442809641361, 39.38352629542351, 40.41158013045788, 39.027781784534454, 37.57575049996376, 43.52536864578724, 51.72967180609703, 50.268600806593895, 49.75464418530464, 49.46738339960575, 52.93887332081795, 50.752729028463364, 53.98650370538235, 51.20200552046299, 49.321178644895554, 52.42212004959583, 54.93593215942383, 55.71452938020229, 54.83319707214832, 51.83369122445583, 55.29716357588768, 58.58939811587334, 51.2054443359375, 24.082338251173496, 7.172667067497969, 5.378406196832657, 2.2436717804521322, 1.4105635159648955, 0.20464172994252294, 0.024159196400432847, 7.357077822089195, 41.055960953235626, 51.654660031199455, 33.874901086091995, 38.835740089416504, 53.00823859870434, 52.83133529126644, 29.45955891162157, 6.338485479354858, 0.005926348376306123, 0.035822310601361096, 0.03109080746071413, 0.07671458821278065, 0.019798865432676394, 0.02128774911398068, 0.03622943055233918, 0.05514422926353291, 0.02161621996492613, 0.03599301940994337, 0.0040031069966062205, 0.022562781086890027, 0.017796879401430488, 0.023872424972068984, 0.03190751129295677, 0.04087196874024812, 0.011270895647612633, 0.04232599188981112, 0.012067012303305091, 0.05771072806965094, 0.045177761130617, 0.08899858687072992, 0.019528933335095644, 0.07275948286405765, 0.07733972888672724, 0.11721197646693327, 0.00989882322755875, 0.05245104584901128, 0.009181165496556787, 0.03322351723909378, 0.040318968531209975, 0.038528440782101825, 1.2364750262349844, 23.724469654262066, 50.12827433645725, 50.32515697181225, 37.15157926082611, 31.350599639117718, 52.67474949359894, 48.829325437545776, 31.24123390763998, 7.206537025049329, 0.12201828067190945, 21.62332870066166, 37.242230996489525, 16.813451796770096, 7.9576854687184095, 8.337249476462603, 6.748890532180667, 15.72284571826458, 45.421854481101036, 56.27571366727352, 53.312191888689995, 51.518999710679054, 52.122205942869186, 48.559266328811646, 43.66645127534866, 41.50650657713413, 40.87674356997013, 39.37948331236839, 41.7855180054903, 41.94759450852871, 42.37733244895935, 42.59417161345482, 38.565897569060326, 36.14918924868107, 34.29999187588692, 35.84836699068546, 36.828057020902634, 36.96761213243008, 39.15007062256336, 41.313378140330315, 44.08110782504082, 50.81865169107914, 48.635079860687256, 51.705638095736504, 48.3058275282383, 45.90559132397175, 41.57883569598198, 41.91543683409691, 46.00075341761112, 47.299854308366776, 50.97230784595013, 46.640525087714195, 43.57431761920452, 40.773286521434784, 38.030787482857704, 37.18708835542202, 38.00457648932934, 36.86579279601574, 36.79143838584423, 37.796359062194824, 36.86474025249481, 37.12360516190529, 37.998493015766144, 36.570039466023445, 35.60870245099068, 36.920661851763725, 37.0272309333086, 39.54099744558334, 41.827684342861176, 47.146657928824425, 49.035129994153976, 52.48893566429615, 34.507122561335564, 51.07131153345108, 53.60919915139675, 48.823758736252785, 48.16505268216133, 41.871803775429726, 39.64856967329979, 36.62873491644859, 37.1321927011013, 38.090531677007675, 38.18146459758282, 41.05320230126381, 39.335356280207634, 39.4031598418951, 39.88072581589222, 37.49880462884903, 38.81124660372734, 37.83823661506176, 39.8839670419693, 43.313013240695, 41.069233641028404, 42.65511654317379, 36.84879630804062, 36.801732033491135, 39.65780317783356, 41.28234140574932, 42.549201026558876, 42.897729724645615, 40.5698112398386, 38.37340369820595, 36.26530721783638, 35.711680725216866, 39.09658469259739, 40.516811683773994, 40.99386848509312, 41.95335499942303, 40.65947502851486, 40.823979601264, 46.20374992489815, 55.086757466197014, 53.69631327688694, 51.407840475440025, 51.06086589396, 55.250399485230446, 53.06575611233711, 56.30904547870159, 52.78957933187485, 52.62886695563793, 53.59373398125172, 56.86303675174713, 57.727839946746826, 57.17226415872574, 53.8837306201458, 57.42640592157841, 61.08724348247051, 54.716516733169556, 22.197956666350365, 9.31096337735653, 9.492707625031471, 4.486680496484041, 1.8166150711476803, 0.08674743774463423, 0.09184211085084826, 8.547732532024384, 44.77142058312893, 53.78942348062992, 40.396494939923286, 42.14923448860645, 59.25888039171696, 58.35545986890793, 36.42699994146824, 7.6382408849895, 0.03954875282943249, 0.043772504504886456, 0.0312662103533512, 0.03319228766486049, 0.035972918340121396, 0.01768543108482845, 0.10650894531863742, 0.043825820393976755, 0.00693418816808844, 0.0423763911385322, 0.058691624653874896, 0.04164947604294866, 0.036232625498087145, 0.042258244939148426, 0.056636005465406924, 0.08132220464176498, 0.10234802757622674, 0.09523662010906264, 0.21622692234814167, 0.1499476280878298, 0.1322699969750829, 0.23393355659209192, 0.19247084943344817, 0.1566792489029467, 0.1338345481781289, 0.169009453675244, 0.13622036000015214, 0.10349423013394699, 0.1507233059965074, 0.1254306163173169, 0.13568494498031214, 0.14986891590524465, 2.1929563768208027, 31.193713657557964, 59.08193528652191, 55.65644949674606, 40.996558740735054, 34.55402344465256, 54.9991911649704, 51.34789489209652, 37.95498535037041, 8.994689248502254, 0.21351130009861663, 21.743584647774696, 35.716601461172104, 18.54880727827549, 16.78236946463585, 11.638314742594957, 10.151115395128727, 17.72166196256876, 45.43008863925934, 60.31850293278694, 55.7466034591198, 56.38189136981964, 53.848407715559006, 51.03979602456093, 44.67151254415512, 43.80569860339165, 42.65847936272621, 41.4283599704504, 43.790613412857056, 44.29953530430794, 44.14965234696865, 45.37935756146908, 41.18831545114517, 37.7751599997282, 35.15640892088413, 39.032653123140335, 40.83473302423954, 39.97024521231651, 41.74187354743481, 43.185598477721214, 47.31948025524616, 52.39821173250675, 49.00255814194679, 54.64710585772991, 50.772195383906364, 47.92597331106663, 44.36456121504307, 44.82280142605305, 48.71472358703613, 50.1175133138895, 53.49957883358002, 47.71487943828106, 45.10997101664543, 42.97442860901356, 40.123338997364044, 38.08953993022442, 39.72602851688862, 40.104157626628876, 38.87045882642269, 39.493655785918236, 38.36706563830376, 38.28249357640743, 39.26222160458565, 39.334045350551605, 38.027641251683235, 39.30080473423004, 39.145434871315956, 43.3862429112196, 44.43299934267998, 49.6315535902977, 50.97171127796173, 55.70651941001415, 38.277299255132675, 54.063327983021736, 56.999111250042915, 51.726612970232964, 50.37504069507122, 42.70049370825291, 41.03337116539478, 38.19652698934078, 39.72021482884884, 40.77630735933781, 40.50519570708275, 41.827555149793625, 41.38480670750141, 41.64244808256626, 40.703769251704216, 38.52379962801933, 40.02318017184734, 38.34058865904808, 42.11787477135658, 44.82924968004227, 43.6553330719471, 46.02381058037281, 38.596835508942604, 38.59414905309677, 41.839148327708244, 44.812663570046425, 44.61620271205902, 44.998386204242706, 44.285563454031944, 41.61611929535866, 38.54111909866333, 37.02172502875328, 39.05226767063141, 43.1808677315712, 42.3874057084322, 45.14511913061142, 43.778419867157936, 42.77849592268467, 48.28663855791092, 57.09290161728859, 55.794184505939484, 54.98103953897953, 54.116205945611, 57.508743703365326, 54.4782505184412, 58.37399147450924, 56.998203098773956, 55.37464901804924, 55.78766405582428, 60.14180861413479, 60.90437829494476, 61.00962124764919, 55.45012056827545, 60.34757897257805, 61.92499212920666, 55.65341725945473, 26.143537648022175, 13.043411895632744, 16.923966966569424, 8.106861189007759, 3.72421246021986, 0.5264020815957338, 0.2773559046909213, 10.555412750691175, 53.19451220333576, 64.64291408658028, 45.376671105623245, 51.52825601398945, 66.051756888628, 67.38548532128334, 44.96427923440933, 10.531980358064175, 0.11963409415329807, 0.09403958785696886, 0.2148819577996619, 0.20978580781957135, 0.1085051147674676, 0.12579124071635306, 0.09423096547834575, 0.1427360306843184, 0.10331685683922842, 0.19729590771021321, 0.17889276787173003, 0.08762932440731674, 0.12218194649904035, 0.09787531875190325, 0.17361115518724546, 0.2092987808282487], [0.07518200131016783, 0.06830871192505583, 0.020537708696792834, 0.02277362895256374, 0.016296470166707877, 0.06081674597226083, 0.03967923723394051, 0.03444139270868618, 0.0414634270418901, 0.07266828033607453, 0.026084160490427166, 0.04622542503057048, 0.045024314676993527, 0.03778028542001266, 0.017012980351864826, 0.06950549926841632, 0.518872132524848, 20.154188834130764, 50.54183654487133, 43.076745718717575, 29.433161728084087, 20.424477830529213, 25.467865504324436, 28.22582021355629, 34.005785062909126, 6.12854721955955, 0.31637152831535786, 1.661768511403352, 1.4804585091769695, 5.3432295843958855, 6.796285388991237, 6.7534607369452715, 2.7566905645653605, 8.268904443830252, 39.20778192579746, 52.752060145139694, 52.27823697030544, 49.66940335929394, 47.340603321790695, 41.988476514816284, 39.46879372000694, 39.82440143823624, 40.79378642141819, 41.71406663954258, 40.55215738713741, 40.69908410310745, 39.80748854577541, 35.50606615841389, 34.89849396049976, 33.78925748169422, 36.128142178058624, 40.493625327944756, 43.9426052570343, 44.473497569561005, 42.96178288757801, 43.50640006363392, 47.034339755773544, 49.68988046050072, 45.97191296517849, 47.24357172846794, 45.76152205467224, 41.146616488695145, 37.491262033581734, 36.19889818131924, 37.49394468963146, 42.48366214334965, 42.91556976735592, 44.560132920742035, 40.45003026723862, 37.362505942583084, 35.413256138563156, 35.58898910880089, 34.459978491067886, 36.61412090063095, 35.77943488955498, 37.10287347435951, 35.6056322157383, 34.78254698216915, 33.99575740098953, 33.847622349858284, 35.32870687544346, 35.66728010773659, 35.02344265580177, 36.08348697423935, 36.96486487984657, 42.76046968996525, 47.4933285266161, 50.86891159415245, 38.35957624018192, 49.57197658717632, 48.45702141523361, 45.31006447970867, 37.81304016709328, 35.91703690588474, 33.77090446650982, 33.41688126325607, 33.18740777671337, 34.01710845530033, 35.312059968709946, 36.66431620717049, 35.82656756043434, 36.37818396091461, 37.31000415980816, 36.370641365647316, 35.579459220170975, 36.649968177080154, 37.20990613102913, 40.9317722171545, 43.95065322518349, 41.27493940293789, 39.54041987657547, 40.14810226857662, 46.107303500175476, 47.41703242063522, 51.37381710112095, 48.47606219351292, 48.63122686743736, 47.114990428090096, 40.80823704600334, 36.15328162908554, 35.07310979068279, 36.333570554852486, 37.33135141432285, 37.75381274521351, 38.351140692830086, 36.952553540468216, 42.21602350473404, 48.313518315553665, 50.77553540468216, 49.51584219932556, 51.67709022760391, 51.620195880532265, 51.31381072103977, 47.818754464387894, 47.625865414738655, 46.1468555778265, 45.17334021627903, 51.39703765511513, 53.57329487800598, 53.05499128997326, 50.44880233705044, 58.55883255600929, 59.1266892850399, 49.06142458319664, 23.377677462995052, 15.80285707488656, 12.782914023846388, 2.632085275836289, 1.663369769230485, 0.10099391976837069, 0.06865383285912685, 8.493025917559862, 36.16658851504326, 42.00355790555477, 24.823497980833054, 29.27070714533329, 44.54315923154354, 51.57148629426956, 34.0837948769331, 6.959621524438262, 0.05070270177384373, 0.02923009295045631, 0.016842154655023478, 0.09228477225406095, 0.08939500505221076, 0.03646312914497685, 0.07990199374035001, 0.07032755398540758, 0.04824868286959827, 0.00783571205829503, 0.010606917458062526, 0.04021283770271111, 0.030647596868220717, 0.034920155885629356, 0.013944413076387718, 0.049621062353253365, 0.019595611593103968, 0.05411653284681961, 0.037116245075594634, 0.042963359446730465, 0.036480109483818524, 0.03518218967656139, 0.01171489384432789, 0.011213757697987603, 0.0715661168214865, 0.06827977558714338, 0.009100984789256472, 0.06440520810429007, 0.042188345760223456, 0.05805795299238525, 0.013078773881716188, 0.04456874361494556, 0.885828179307282, 25.810253731906414, 58.12797747552395, 48.36035460233688, 33.92051763832569, 25.783489868044853, 35.83677761256695, 37.369717955589294, 38.407890647649765, 7.3690923023968935, 0.2727074478752911, 3.086603111587465, 2.4682216811925173, 7.50113426707685, 6.821376867592335, 5.791383711621165, 6.8468796741217375, 9.04333708807826, 41.422223299741745, 54.63960886001587, 54.07320745289326, 51.36983871459961, 49.810945764184, 44.912659004330635, 40.280935540795326, 40.37099450826645, 42.76702053844929, 41.976822540163994, 43.830701261758804, 42.00910560786724, 42.37800121307373, 37.73423619568348, 35.94767086207867, 35.600502490997314, 37.28135369718075, 42.49141372740269, 45.60571141541004, 45.80811135470867, 45.6972599029541, 45.77688083052635, 49.1748408973217, 50.0357037037611, 46.109507381916046, 49.74658861756325, 46.93711057305336, 43.404394537210464, 39.15763981640339, 38.826734572649, 40.85639946162701, 45.8659328520298, 45.04546947777271, 47.12206944823265, 41.435473188757896, 39.96504329144955, 36.971898302435875, 36.26641295850277, 36.06305927038193, 38.2216664403677, 36.81640684604645, 39.25473980605602, 37.59037971496582, 36.244731321930885, 35.930921360850334, 36.01856745779514, 35.29830850660801, 38.1712431460619, 37.79823616147041, 38.90655688941479, 39.3287256360054, 45.95546364784241, 48.62802743911743, 53.01885902881622, 39.448347017169, 51.2941999733448, 51.44230842590332, 46.84304662048817, 40.60987249016762, 37.73732163012028, 36.81858412921429, 35.952325612306595, 36.339091658592224, 36.794280633330345, 38.30037161707878, 38.900253027677536, 37.5547756254673, 37.58081562817097, 38.560957834124565, 37.82303363084793, 35.92790812253952, 37.75967963039875, 39.78602349758148, 43.11094768345356, 46.07741430401802, 43.74330595135689, 41.675730496644974, 41.18659794330597, 48.86422276496887, 49.83606621623039, 51.38832472264767, 50.96240937709808, 51.23729042708874, 47.22262725234032, 41.015382930636406, 38.324591517448425, 35.50519600510597, 37.34824150800705, 38.77936631441116, 39.883355274796486, 40.086260586977005, 39.767085313797, 43.1951017677784, 52.100638300180435, 53.17389450967312, 52.54516504704952, 53.690761774778366, 54.82852332293987, 53.865856379270554, 50.857766792178154, 49.92620497941971, 48.75069625675678, 49.17970843613148, 53.46166826784611, 55.93029700219631, 55.60027331113815, 52.92079769074917, 60.17456665635109, 60.3287547826767, 52.067074701189995, 23.27535655349493, 7.099433597177267, 8.239799905568361, 3.357133395038545, 1.1260622134432197, 0.10230336512904614, 0.03550687186361756, 8.726162407547235, 43.38606812059879, 48.17028880119324, 31.834725961089134, 36.473775431513786, 50.92952974140644, 58.871760964393616, 40.53478851914406, 8.52058108896017, 0.06579019667697139, 0.06007950760249514, 0.03758438069780823, 0.047954302572179586, 0.023893199540907517, 0.04361282030004077, 0.05014650661905762, 0.03839332166535314, 0.050249932319275104, 0.02309413470356958, 0.054841429300722666, 0.07203051573014818, 0.04620943916961551, 0.03694538783747703, 0.06213567598024383, 0.03999463144282345, 0.20194187090964988, 0.21759995492175221, 0.13332742382772267, 0.15382508252514526, 0.1362553151557222, 0.13098487921524793, 0.11018783072358929, 0.1497093541547656, 0.12902595073683187, 0.1621385762700811, 0.1108754008600954, 0.11487007752293721, 0.2034673109301366, 0.16308140067849308, 0.0921469480090309, 0.11149428522912785, 1.56755814794451, 31.57237283885479, 63.772813975811005, 55.69526441395283, 40.14643035829067, 31.529020965099335, 34.532535597682, 38.76935385167599, 43.50537791848183, 8.75808734446764, 0.635781231103465, 3.287021219730377, 3.2025052048265934, 8.708241619169712, 14.216656889766455, 12.994325179606676, 7.106642760336399, 11.292633041739464, 44.841177240014076, 55.83879791200161, 58.98061752319336, 54.92592349648476, 53.59415955841541, 46.080959513783455, 42.94637471437454, 43.59919488430023, 45.70329777896404, 44.33378666639328, 45.40594093501568, 44.622027799487114, 46.30177706480026, 38.181335404515266, 38.04547369480133, 36.63776323199272, 40.39742209017277, 45.60628138482571, 47.87951700389385, 49.845466911792755, 49.74873550236225, 48.07486832141876, 52.01491869986057, 51.143329069018364, 46.7143589258194, 52.39470452070236, 50.747884288430214, 45.71776360273361, 40.71408949792385, 41.33112698793411, 41.905082389712334, 47.86919295787811, 46.219173297286034, 49.29769970476627, 44.31659258902073, 42.43524134159088, 39.45357173681259, 39.056071266531944, 37.29109637439251, 40.608284175395966, 39.150724187493324, 40.725849866867065, 39.239666014909744, 36.82741865515709, 37.479266077280045, 36.82242572307587, 37.67587132751942, 40.43583422899246, 40.596603602170944, 39.62609387934208, 41.34737491607666, 48.64131912589073, 51.85069531202316, 54.728470891714096, 43.412180319428444, 53.47622148692608, 53.317929580807686, 49.22419264912605, 41.46626673638821, 39.90595646202564, 38.54007035493851, 37.65729792416096, 38.31340491771698, 37.42510378360748, 40.792323499917984, 40.95259889960289, 39.79112662374973, 39.84355241060257, 41.10916569828987, 39.87596847116947, 38.40733967721462, 40.296902284026146, 41.24181278049946, 45.35465128719807, 48.51407155394554, 46.81410737335682, 44.9392955750227, 44.2056917399168, 53.12880992889404, 51.93617172539234, 55.808342546224594, 53.64501602947712, 54.05938759446144, 52.60495863854885, 44.26933832466602, 40.11564441025257, 39.70075607299805, 39.145776852965355, 41.06797590851784, 40.76856717467308, 42.91396625339985, 42.07109548151493, 45.733414962887764, 53.54288510978222, 55.41745372116566, 52.940416038036346, 55.47446586191654, 56.04164242744446, 56.364229917526245, 52.48281419277191, 52.577068135142326, 50.73463439941406, 50.80076605081558, 56.3952362537384, 60.55920861661434, 57.50755436718464, 56.1051370203495, 63.93450289964676, 61.916157603263855, 53.35946895182133, 28.487781956791878, 23.192927576601505, 21.457148417830467, 6.350694699212909, 4.506478384137154, 0.3778836369747296, 0.203593015903607, 11.172596532851458, 48.40638153254986, 56.36242501437664, 39.30900849401951, 42.48617380857468, 58.026564717292786, 66.78894773125648, 50.01505561172962, 10.837675854563713, 0.2549773914506659, 0.12424493150319904, 0.09070802756468765, 0.1349652695353143, 0.1649459428153932, 0.10813507251441479, 0.14875265158480033, 0.19363545725354925, 0.18782697909045964, 0.12158757526776753, 0.09323802383732982, 0.1285770849790424, 0.12773413880495355, 0.09455069754039869, 0.11966271878918633, 0.1296073492267169], [0.017264032212551683, 0.05974062441964634, 0.06670413669780828, 0.03510595626721624, 0.040218841677415185, 0.08653121301904321, 0.030337293792399578, 0.02405238465144066, 0.024742118148424197, 0.046996490491437726, 0.015030327267595567, 0.06225122095202096, 0.0786195402906742, 0.01629112484806683, 0.06586366929695942, 0.038489032740471885, 0.8764560415875167, 19.377124831080437, 45.523727014660835, 45.13845048844814, 32.791966795921326, 17.94362135231495, 18.490391112864017, 35.187221467494965, 38.188159838318825, 6.949573438614607, 0.16377367603126913, 0.770234166411683, 1.9025956699624658, 2.580385487526655, 3.1427071010693908, 6.879142792895436, 3.4291381062939763, 5.158226536586881, 36.907997131347656, 55.61992205679417, 50.78338198363781, 47.78301738202572, 41.75920441746712, 39.386284947395325, 38.95839370787144, 40.99451445043087, 42.14142210781574, 44.5853141695261, 41.77024282515049, 39.14243683218956, 36.43557608127594, 34.56121265888214, 33.60681027173996, 39.3445859849453, 44.79792796075344, 48.76335717737675, 47.711258232593536, 46.805151253938675, 48.49605672061443, 45.90158633887768, 48.45187269151211, 47.10149735212326, 46.14633120596409, 47.43831887841225, 44.80765923857689, 40.09175129234791, 36.270843520760536, 33.82589131593704, 34.57903370261192, 37.115549594163895, 39.60415005683899, 38.43953534960747, 36.149307042360306, 36.039192751049995, 34.725842624902725, 34.914274513721466, 36.34577549993992, 34.86964590847492, 34.99006524682045, 33.97824414074421, 34.916820377111435, 35.73687717318535, 35.85228458046913, 34.45934772491455, 36.32741868495941, 36.23101785778999, 38.40577036142349, 37.197279408574104, 37.15313717722893, 42.00453445315361, 45.92445731163025, 49.94799681007862, 38.611517921090126, 47.708788365125656, 49.38849963247776, 45.819218158721924, 39.743416383862495, 37.24993698298931, 35.32129347324371, 36.086724400520325, 35.94275012612343, 34.778321608901024, 37.641726359725, 35.22947520017624, 35.99467433989048, 36.41336627304554, 36.12556591629982, 35.7276626676321, 38.00714895129204, 35.748280361294746, 38.93087938427925, 41.13922968506813, 44.79592926800251, 45.71748621761799, 44.12558823823929, 46.70623116195202, 50.02827130258083, 50.1778768748045, 48.19116868078709, 48.614104986190796, 49.75350044667721, 48.615845292806625, 48.36888514459133, 43.733373284339905, 42.14632384479046, 37.74929478764534, 35.78568935394287, 36.24548368155956, 38.53438585996628, 37.05040588974953, 39.36451971530914, 47.17850022017956, 53.324248641729355, 52.09046244621277, 51.33654110133648, 51.15185581147671, 49.56688106060028, 47.2883827239275, 47.87313334643841, 45.32794252038002, 45.23680821061134, 44.43879783153534, 47.19780318439007, 47.77085043489933, 53.1851951032877, 53.895133808255196, 58.68313528597355, 53.3435820043087, 22.912700213491917, 8.504619095474482, 3.8467649091035128, 2.6232611993327737, 1.6848339862190187, 0.11614058981649578, 0.03639697410108056, 6.229067500680685, 38.0367835611105, 41.78974337875843, 32.14491091668606, 26.39297716319561, 45.01370698213577, 49.95154581964016, 40.47964967787266, 6.792466593906283, 0.052056230706512, 0.07824103013263084, 0.02677476230019238, 0.01224740335601382, 0.05337527945812326, 0.00611251612099295, 0.05211822601268068, 0.046391580763156526, 0.06710727131576277, 0.04656643817725126, 0.03932639796403237, 0.037901084797340445, 0.02936409327958245, 0.06830819242168218, 0.06988121895119548, 0.08088963644695468, 0.032371494598919526, 0.03776429955905769, 0.06460594420786947, 0.04462663484446239, 0.00891636071173707, 0.08899775566533208, 0.05994086699502077, 0.035704338806681335, 0.01583009900059551, 0.024241465325758327, 0.07693590407143347, 0.03563503334589768, 0.11383859615307301, 0.051230572862550616, 0.026937817710859235, 0.05003880614822265, 1.2610657629556954, 22.73022260516882, 51.43038846552372, 50.65140746533871, 37.63712100684643, 24.22754365950823, 24.201410561800003, 37.212630584836006, 41.60520628094673, 7.725457604974508, 0.009100067309191218, 0.4202366987010464, 4.959068773314357, 6.53032056055963, 4.451349042356014, 7.44368277490139, 5.9915579203516245, 6.302453437820077, 39.01740834116936, 58.34083825349808, 51.691696643829346, 49.55906867980957, 44.26723703742027, 41.35111391544342, 39.727791622281075, 41.47137366235256, 43.14518004655838, 46.217527985572815, 44.767164811491966, 41.57634302973747, 38.34586277604103, 36.63906656205654, 36.08197845518589, 39.25528697669506, 47.01468341052532, 50.056587383151054, 50.95895156264305, 48.82537744939327, 50.92471919953823, 48.290905728936195, 48.61406698822975, 48.07286202907562, 46.55398853123188, 48.50638076663017, 46.58623360097408, 42.032801136374474, 36.57972514629364, 36.44605591893196, 35.672345235943794, 38.57927285134792, 42.06487901508808, 41.515033319592476, 39.258034229278564, 36.153961792588234, 37.634768933057785, 36.3388978689909, 38.81115160882473, 37.61026784777641, 35.94458922743797, 35.65410241484642, 36.554775685071945, 37.213306948542595, 36.95534259080887, 35.92435151338577, 37.268050611019135, 37.449133694171906, 39.12652708590031, 38.918157666921616, 40.00052958726883, 44.620724469423294, 48.58708083629608, 52.565558552742004, 40.72582706809044, 49.60699550807476, 50.704862996935844, 46.075746193528175, 41.719036772847176, 38.71361084282398, 37.065255492925644, 38.09439606964588, 38.76183405518532, 36.30158007144928, 38.362296894192696, 36.53044559061527, 37.00285904109478, 38.03804889321327, 37.133283242583275, 39.01531085371971, 39.78567011654377, 37.5413965433836, 39.540716260671616, 43.30294378101826, 47.65930362045765, 47.13391721248627, 46.39827288687229, 48.45050476491451, 52.78378464281559, 51.71365946531296, 49.90199647843838, 48.93213652074337, 51.759002432227135, 50.706971883773804, 49.63039845228195, 44.95734840631485, 42.26071670651436, 38.345927372574806, 36.604845598340034, 37.95491315424442, 41.217893064022064, 37.8190628439188, 41.81625075638294, 50.11607699096203, 53.94336462020874, 53.78531210124493, 54.73628327250481, 53.75940889120102, 51.40070825815201, 50.4409671574831, 49.68150191009045, 48.04946668446064, 47.1936310082674, 46.950208470225334, 48.678614124655724, 50.42196437716484, 55.35082429647446, 58.106254041194916, 60.348665714263916, 55.15986554324627, 25.4647059738636, 9.62817795574665, 7.039147932082415, 6.356982411816716, 0.6820744439028203, 0.1079498918261379, 0.05803382948215585, 6.83531166985631, 44.904204457998276, 46.376967430114746, 39.250180050730705, 32.92154364287853, 50.610065683722496, 56.80623359978199, 46.256209909915924, 8.519197963178158, 0.041023578378371894, 0.07952759508043528, 0.08147335043759085, 0.02454927293001674, 0.028866132597613614, 0.04438475407368969, 0.034611055089044385, 0.03688211232656613, 0.05668547331879381, 0.05385777563787997, 0.10011899445089512, 0.04933544681989588, 0.0573036860441789, 0.022481413870991673, 0.04677760887716431, 0.036119670621701516, 0.11519222898641601, 0.1250529076787643, 0.17198736575664952, 0.11860250888275914, 0.19982195575721562, 0.238269405963365, 0.12372516837785952, 0.14277612150181085, 0.2082333536236547, 0.0867077402654104, 0.19024482200620696, 0.18575990485260263, 0.1960725217941217, 0.1932456367649138, 0.12092475575627759, 0.17040402337443084, 1.9472452928312123, 28.079883344471455, 60.51283210515976, 56.32280834019184, 44.69084210693836, 28.283903896808624, 28.395564705133438, 45.95290258526802, 48.18018727004528, 9.217549189925194, 0.3738703398266807, 1.300399589817971, 7.280603125691414, 5.6373585015535355, 5.40009543299675, 12.741194162517786, 6.909966263920069, 6.812389399856329, 41.64519153535366, 61.23443238437176, 55.436608493328094, 53.788697719573975, 46.39306716620922, 44.40925821661949, 42.58679620921612, 46.02402336895466, 45.774258971214294, 50.287466794252396, 46.69415540993214, 43.87439511716366, 39.10088986158371, 39.175662249326706, 37.03687101602554, 43.10255013406277, 50.364427864551544, 52.96626225113869, 53.0254440754652, 50.672234147787094, 51.6314584761858, 50.21742135286331, 49.701146855950356, 47.36954636871815, 46.821984350681305, 50.90801529586315, 49.91144277155399, 45.08280627429485, 39.39497888088226, 38.75005088746548, 37.6908615231514, 40.18413573503494, 43.463648557662964, 42.94972613453865, 40.321897342801094, 38.59410725533962, 38.23909990489483, 38.19604441523552, 41.0573098808527, 38.55846896767616, 38.88307794928551, 36.20245099067688, 38.29882510006428, 39.642493799328804, 39.41655412316322, 37.9079894721508, 40.685298442840576, 41.13864451646805, 42.19802387058735, 41.75009250640869, 42.97725185751915, 45.87810359895229, 50.811933651566505, 54.16729040443897, 43.94851393997669, 52.30596788227558, 52.629220336675644, 49.68766897916794, 44.407897889614105, 41.37992396950722, 37.906241565942764, 42.129521146416664, 40.88595807552338, 38.88883464038372, 40.982666686177254, 38.77740941941738, 39.53181333839893, 40.57542733848095, 38.81531618535519, 40.52487105131149, 42.20941565930843, 39.80602562427521, 41.82555265724659, 45.84110878407955, 49.76646155118942, 48.29889290034771, 49.069936126470566, 51.36918134987354, 54.50944684445858, 53.397352918982506, 51.825400069355965, 51.383289992809296, 54.97762352228165, 51.965304762125015, 52.897478342056274, 47.81221881508827, 45.814263224601746, 42.29994960129261, 39.32290054857731, 40.650773495435715, 44.450223818421364, 41.643531024456024, 42.24382661283016, 51.903881058096886, 55.83505131304264, 55.360460579395294, 55.60812748968601, 55.83734638988972, 53.273939341306686, 52.771594896912575, 53.81640963256359, 51.67552091181278, 50.90303376317024, 49.162829741835594, 49.80819471180439, 51.56650856137276, 58.092901557683945, 59.437508806586266, 64.53312277793884, 53.912696465849876, 26.7028771340847, 13.743747565895319, 12.619461044669151, 7.73756755515933, 4.7369051445275545, 0.6051368254702538, 0.304625378921628, 8.599117174744606, 49.018749073147774, 54.6002733707428, 44.175646752119064, 38.17771419882774, 59.30054895579815, 63.99887904524803, 57.271389439702034, 11.61200400441885, 0.12121014864533208, 0.18994287180248648, 0.1454185976763256, 0.11651405337033793, 0.09009592642541975, 0.1877916231751442, 0.16241774254012853, 0.1536236933316104, 0.12382117260131054, 0.15271408745320514, 0.15571960742818192, 0.16550394881051034, 0.13397134083788842, 0.13967378094093874, 0.12136009216192178, 0.2583991375286132], [0.03306964776129462, 0.04877022343862336, 0.03818861507170368, 0.015412693810503697, 0.009898947537294589, 0.13571149902418256, 0.04909497612970881, 0.05302119338011835, 0.036478769907262176, 0.04926299465296324, 0.0161666388521553, 0.03592440043576062, 0.020778123725904152, 0.012767820498993387, 0.055626198518439196, 0.038857690888107754, 0.4482780065154657, 17.363806664943695, 42.47354708611965, 44.846964329481125, 34.34109807014465, 21.23251397162676, 23.371994867920876, 35.6737207621336, 35.90163633227348, 9.0957011282444, 0.11622469741269015, 0.32705518940929323, 7.59844372048974, 6.375750554725528, 3.3406099816784263, 3.686287170276046, 6.697172457352281, 7.067756596952677, 33.201018646359444, 51.72095127403736, 51.412985399365425, 47.46141403913498, 44.20516736805439, 41.83850236237049, 43.852071315050125, 42.16148503124714, 46.734604239463806, 46.685305684804916, 43.95976133644581, 38.06590519845486, 35.147775784134865, 33.58640156686306, 37.025072649121284, 43.24694238603115, 47.70678587257862, 44.69244942069054, 44.632978811860085, 46.69914834201336, 48.23059156537056, 45.88555119931698, 46.70082025229931, 44.482408091425896, 46.414441019296646, 45.39217807352543, 45.2733014523983, 42.20117390155792, 35.934489369392395, 34.44303520023823, 34.31091628968716, 34.32838395237923, 34.95731480419636, 34.54249106347561, 34.69594202935696, 35.15114240348339, 34.05186519026756, 36.04421228170395, 34.403201937675476, 35.77012158930302, 35.13386853039265, 36.737701669335365, 35.569830536842346, 36.48194119334221, 34.8801713436842, 36.14348955452442, 37.519433721899986, 41.96953073143959, 43.37995044887066, 45.63703313469887, 45.36875233054161, 44.547734186053276, 45.414805859327316, 51.40705391764641, 36.97008579969406, 47.31169827282429, 49.01278719305992, 45.85816986858845, 43.17780129611492, 38.570552319288254, 39.981625601649284, 37.90019229054451, 38.1756167113781, 34.39286649227142, 36.937726736068726, 36.49965204298496, 36.3965217769146, 36.47220231592655, 37.24297195672989, 36.633461862802505, 35.87829798460007, 37.05371551215649, 36.65053814649582, 41.7115093767643, 45.66608637571335, 48.18887360394001, 46.693159863352776, 49.49245825409889, 49.925198033452034, 48.62638592720032, 49.81262147426605, 47.312690019607544, 48.80427338182926, 48.703962564468384, 47.58799284696579, 49.27441455423832, 47.23588094115257, 46.39218561351299, 37.693422585725784, 34.27744388580322, 36.72583870589733, 36.12796738743782, 37.98237048089504, 43.753781989216805, 49.91715386509895, 52.52863593399525, 51.25961422920227, 51.344581469893456, 53.522446006536484, 52.43112176656723, 50.621031895279884, 52.37018443644047, 47.174141854047775, 46.882902681827545, 42.51472167670727, 48.40792804956436, 54.28484469652176, 59.66457322239876, 56.04400210082531, 54.430893659591675, 23.20147141814232, 7.53123102709651, 3.0506748519837856, 4.179861210286617, 0.6025133037474006, 0.16514822258614004, 0.07088477330398746, 5.478495676070452, 36.53181351721287, 44.205231964588165, 30.57247929275036, 29.445113986730576, 40.796655267477036, 49.89282377064228, 36.7788952589035, 4.943414563313127, 0.11350039203534834, 0.03258614226069767, 0.05374256092181895, 0.023957217199495062, 0.006986029966356, 0.025362759552081116, 0.0662992728757672, 0.06510071179945953, 0.03283353347796947, 0.04022146516945213, 0.04097619967069477, 0.08355424346518703, 0.07059265655698255, 0.018874231063819025, 0.03345334924233612, 0.014037360579095548, 0.043307519299560227, 0.06012422942148987, 0.03971614052716177, 0.016966572002274916, 0.052011586813023314, 0.06085491462727077, 0.028587615706783254, 0.042024379363283515, 0.010425964228488738, 0.0609414008067688, 0.021804458301630802, 0.03044579763809452, 0.038199591435841285, 0.051543733206926845, 0.05565008083067369, 0.038815781808807515, 0.9870051126927137, 21.729964278638363, 49.3670117855072, 51.23499535024166, 39.7121212631464, 23.12236536294222, 23.543145284056664, 40.94739317893982, 41.47041231393814, 9.468055497854948, 0.04196395369945094, 0.16980240878183395, 4.0582240372896194, 4.676888789981604, 5.0498587265610695, 8.069308754056692, 5.335810482501984, 7.8280440252274275, 33.993374928832054, 51.90047264099121, 53.2904988527298, 49.589926823973656, 45.19233159720898, 44.75346274673939, 44.47922386229038, 46.3139022141695, 48.2174176722765, 48.52503776550293, 45.31957916915417, 40.21911285817623, 37.63562768697739, 36.250742599368095, 38.965183943510056, 45.402190536260605, 50.0826121866703, 46.65644623339176, 45.77158011496067, 46.48366950452328, 47.75980822741985, 46.799740344285965, 45.83037815988064, 46.18753619492054, 47.13393621146679, 48.71361404657364, 47.438204884529114, 45.34916818141937, 37.11880221962929, 37.00251705944538, 36.87383696436882, 36.60255432128906, 37.25517310202122, 37.7202757447958, 36.258665174245834, 36.51041306555271, 35.44368490576744, 37.394602820277214, 36.94773159921169, 38.77723082900047, 38.33602510392666, 37.98086956143379, 37.91266322135925, 37.94740855693817, 37.67810180783272, 36.9744061678648, 39.87155310809612, 44.41014736890793, 45.44432267546654, 47.5100552290678, 47.70187273621559, 46.183854192495346, 47.07738384604454, 51.743628457188606, 39.40237708389759, 47.62759052217007, 50.575042963027954, 47.290670201182365, 45.701447278261185, 39.66770924627781, 41.24549098312855, 38.98580923676491, 39.623681008815765, 36.36241100728512, 37.23498858511448, 39.14738416671753, 38.09386029839516, 38.180571645498276, 38.86757478117943, 38.32905627787113, 37.746083959937096, 38.417435735464096, 38.253459334373474, 44.2669178545475, 46.3997358083725, 51.036243215203285, 49.29753631353378, 50.39008788764477, 53.07667292654514, 52.08325803279877, 50.692840442061424, 50.39102643728256, 49.37004402279854, 50.33015750348568, 50.10600373148918, 50.4974739253521, 48.79464469850063, 48.14276687800884, 38.73287580907345, 36.993070766329765, 40.08371092379093, 36.838194876909256, 39.089539870619774, 46.41284130513668, 53.816584423184395, 53.59176188707352, 53.34053456783295, 52.26488448679447, 54.81943041086197, 53.87201204895973, 53.18547248840332, 52.916405126452446, 50.01121021807194, 47.61903718113899, 45.45041374862194, 50.13418681919575, 56.58478148281574, 59.76580739021301, 60.5912446975708, 52.420630529522896, 25.152699016034603, 9.369941912591457, 5.059665525332093, 5.619377866387367, 0.6698918819893152, 0.13270114024635404, 0.010700269431254128, 5.743529079481959, 40.29355846345425, 47.73684985935688, 34.20844718813896, 34.63793434202671, 48.01030978560448, 55.51825851202011, 43.39416928589344, 5.95389386638999, 0.05178765488381032, 0.06842770788352937, 0.011786178984038997, 0.03613453955040313, 0.01450987672797055, 0.03240557402023114, 0.02934098280093167, 0.0649194793368224, 0.04769802784721833, 0.03409513257793151, 0.019368575631233398, 0.08587971125962213, 0.03655507753137499, 0.0015730368500044278, 0.03279157244833186, 0.03100759415247012, 0.08303497015731409, 0.3306452842662111, 0.11778121115639806, 0.08981289356597699, 0.20728622475871816, 0.18305660225450993, 0.2525022398913279, 0.15149886516155675, 0.10370936390245333, 0.14836053043836728, 0.08906975883292034, 0.10656119251507334, 0.13685025041922927, 0.1889117615064606, 0.13320716621819884, 0.16014835884561762, 1.5332088223658502, 26.46698199212551, 56.926497146487236, 57.7037188410759, 47.56629221141338, 31.045928187668324, 32.37278088927269, 45.91722629964352, 47.504587322473526, 12.118709664791822, 0.3198539820732549, 0.6803632888477296, 8.640856985002756, 11.09471021220088, 6.669996315613389, 9.557365905493498, 16.378964111208916, 11.292712837457657, 36.352417543530464, 52.59587712585926, 55.62933415174484, 50.9168916195631, 48.28547962009907, 46.79224334657192, 47.58701249957085, 47.37817570567131, 51.081939563155174, 50.916207656264305, 48.02675150334835, 42.76657596230507, 40.02144366502762, 37.92776741087437, 40.83976775407791, 48.84730227291584, 52.866103425621986, 47.522225975990295, 47.529479786753654, 48.09387110173702, 49.31680887937546, 46.645008847117424, 47.677326053380966, 46.63702167570591, 48.09495784342289, 49.66871179640293, 49.462979435920715, 47.7672216296196, 39.51091825962067, 38.64575408399105, 38.98393213748932, 37.73257188498974, 37.739343121647835, 38.89247864484787, 38.24770264327526, 39.15882535278797, 36.26195579767227, 39.21837195754051, 36.970602571964264, 40.60766480863094, 39.829295575618744, 40.056762769818306, 39.132450968027115, 40.93961499631405, 40.988404378294945, 39.31964412331581, 41.589577719569206, 45.75379326939583, 48.102500438690186, 51.04678004980087, 50.64033105969429, 49.554733112454414, 50.397554486989975, 54.697624146938324, 43.24628882110119, 50.395787581801414, 53.51283252239227, 50.07967874407768, 47.731340155005455, 42.9766932874918, 44.36348207294941, 42.03206017613411, 41.80913373827934, 37.938201650977135, 39.7269556671381, 40.612254962325096, 39.40305344760418, 40.51315248012543, 41.34974218904972, 41.78136482834816, 39.32554520666599, 40.85513032972813, 38.623521476984024, 47.338570430874825, 49.66914877295494, 53.2270460575819, 51.318761855363846, 54.12774592638016, 53.925832360982895, 53.60962852835655, 53.02553527057171, 53.16745765507221, 51.74318388104439, 51.16305001080036, 50.10760344564915, 53.509910479187965, 51.10930949449539, 52.0940912514925, 41.47188663482666, 38.35413873195648, 41.31251558661461, 39.442088752985, 41.49539217352867, 48.34977596998215, 55.79727753996849, 56.156795248389244, 54.87061746418476, 52.96542249619961, 57.30483144521713, 58.09602878987789, 57.13854856789112, 57.19763919711113, 50.79433299601078, 52.12820962071419, 47.78491348028183, 52.20995083451271, 59.45444069802761, 62.92707055807114, 60.96987538039684, 56.338839679956436, 26.784063577651978, 11.067908350378275, 10.192413479089737, 10.969232395291328, 1.3378655794076622, 0.29138243640773, 0.18324055097764358, 6.903881840407848, 48.2111632078886, 56.219248697161674, 44.14727367460728, 41.2001746147871, 54.11559797823429, 64.08650994300842, 50.57574212551117, 8.249032460153103, 0.22305787220830098, 0.13387269456870854, 0.11606336935074069, 0.0793976524437312, 0.14346093084895983, 0.18743338849162683, 0.09665770674473606, 0.17515568324597552, 0.10486918487004004, 0.1443670189473778, 0.23196272406494245, 0.2871643065009266, 0.15853889286518097, 0.09111793056945316, 0.1386014072340913, 0.10931411510682665], [0.06862031004857272, 0.05829528068716172, 0.025734447517606895, 0.06611039629206061, 0.05810369155369699, 0.06071901254472323, 0.013143772102921503, 0.036735515895998105, 0.0659669614105951, 0.03892701861332171, 0.04050617899338249, 0.024999860470416024, 0.05660625276505016, 0.011641029741440434, 0.04791440842382144, 0.010751062018243829, 0.34590045630466193, 13.7022708915174, 40.41930891573429, 46.38948775827885, 40.46505466103554, 28.620744422078133, 18.600930981338024, 28.783227503299713, 38.20986807346344, 10.463781617581844, 0.005596845476247836, 0.19937953184125945, 4.689443791285157, 6.48997575044632, 3.005523062311113, 7.621210673823953, 3.9537989906966686, 4.507368486374617, 44.42413441836834, 54.84039008617401, 52.89847008883953, 47.276675552129745, 44.44782614707947, 41.55650049448013, 44.86090578138828, 46.486462354660034, 48.953149393200874, 44.87005569040775, 41.36082239449024, 35.356247797608376, 34.67525213956833, 36.10291913151741, 45.02913795411587, 48.38587023317814, 47.58084163069725, 45.73599502444267, 48.260841742157936, 48.458480536937714, 49.30782996118069, 46.81468114256859, 48.493032082915306, 49.450717493891716, 46.18950828909874, 47.54833057522774, 45.44522702693939, 42.25304871797562, 38.31257276237011, 33.338472470641136, 35.068379044532776, 32.90623426437378, 38.19281838834286, 35.943346694111824, 35.39394937455654, 34.96142998337746, 36.05348378419876, 36.21146410703659, 34.419932439923286, 35.48118129372597, 35.42153589427471, 35.49312025308609, 34.21807587146759, 35.33121094107628, 34.52431283891201, 36.882663890719414, 41.89715601503849, 48.20461995899677, 46.7484924942255, 50.84984801709652, 48.38417552411556, 49.325012639164925, 49.48068268597126, 51.62507861852646, 31.489242799580097, 41.908145025372505, 54.90219756960869, 48.10170628130436, 43.73661071062088, 44.99698027968407, 42.661663591861725, 42.74480693042278, 43.99009890854359, 39.03842881321907, 36.97829715907574, 35.64720578491688, 34.832491502165794, 37.35445037484169, 37.12478309869766, 35.89983142912388, 37.52278134226799, 37.77250774204731, 36.96223542094231, 38.93075779080391, 44.15301896631718, 47.43724353611469, 47.57210209965706, 48.965042755007744, 49.05953608453274, 47.72865749895573, 43.58093686401844, 44.53758493065834, 44.7379519790411, 50.40908686816692, 47.91805073618889, 47.68995277583599, 48.245224580168724, 49.43504333496094, 43.739308565855026, 36.8424354493618, 34.967388063669205, 35.41204020380974, 35.514912083745, 39.936005249619484, 46.74992501735687, 51.33380524814129, 52.97333747148514, 51.89801797270775, 49.25163097679615, 50.63848435878754, 53.880477994680405, 54.431528225541115, 53.7858022749424, 50.88365100324154, 46.28496676683426, 48.1506210565567, 55.072386637330055, 57.53694199025631, 59.29155483841896, 53.86998675763607, 26.548956893384457, 11.581967566162348, 6.523196417838335, 7.247777637094259, 0.46162571059539914, 0.21929151727817953, 0.039227796223713085, 5.427228352054954, 38.95962484180927, 47.505202889442444, 38.16868968307972, 28.783350996673107, 37.361392602324486, 52.23495729267597, 34.22744236886501, 4.261539727449417, 0.15077351970830932, 0.04647796304197982, 0.04063900858454872, 0.014489788645732915, 0.034239595333929174, 0.052612744984799065, 0.03590979125874583, 0.05129464989295229, 0.02202713229053188, 0.09634456495405175, 0.05082799485535361, 0.023598099360242486, 0.04598089479259215, 0.026407996629131958, 0.03688089891511481, 0.023499809321947396, 0.03245883053750731, 0.045179924491094425, 0.013748123365076026, 0.04084384134330321, 0.04386407810670789, 0.04116226722544525, 0.018519013210607227, 0.047348027292173356, 0.0554164750064956, 0.046188974447431974, 0.060555194577318616, 0.046948406743467785, 0.07346601487370208, 0.009437785320187686, 0.04173762834398076, 0.006446314664572128, 0.5574419035110623, 17.365109995007515, 45.050770193338394, 50.86776405572891, 48.13411854207516, 30.65477717667818, 24.010016731917858, 35.18794342875481, 43.128042966127396, 11.258232537657022, 0.05216094774368685, 0.11233640019781888, 2.777434838935733, 9.54306062310934, 6.898531727492809, 7.602209318429232, 7.981694005429745, 8.832745738327503, 44.26881015300751, 55.82970879971981, 54.3855506926775, 50.70253372192383, 47.15749114751816, 44.038367718458176, 47.03762277960777, 48.61423797905445, 50.51319748163223, 47.79130473732948, 45.123566687107086, 37.33143500983715, 35.78516498208046, 38.45129191875458, 45.62827840447426, 50.296419113874435, 46.920478865504265, 45.13450250029564, 49.14875529706478, 50.589698776602745, 50.50464414060116, 47.33305312693119, 49.86320436000824, 49.55320939421654, 48.24739046394825, 48.614317774772644, 46.45361691713333, 44.777591452002525, 40.77460125088692, 34.92543451488018, 37.314066141843796, 35.460461005568504, 40.66671743988991, 38.2215828448534, 35.66200219094753, 37.27310813963413, 37.16419458389282, 37.1012357622385, 36.52466610074043, 37.12369255721569, 36.702439561486244, 37.30803586542606, 36.94285646080971, 36.920703649520874, 36.84327520430088, 39.189235121011734, 43.91197510063648, 48.99755381047726, 49.10417228937149, 51.59533001482487, 50.02164825797081, 50.997154712677, 50.89688949286938, 54.27980236709118, 33.01775448024273, 44.48557332158089, 55.59779964387417, 50.008823946118355, 46.9371447712183, 47.20711648464203, 44.551454186439514, 45.41178122162819, 44.02617037296295, 41.573413386940956, 38.64812135696411, 37.763156443834305, 36.44382543861866, 39.277869164943695, 38.30136336386204, 37.65716873109341, 39.162446558475494, 37.89266109466553, 39.65219847857952, 40.61942517757416, 46.32626675069332, 49.308848306536674, 51.344684064388275, 51.963374465703964, 51.61237969994545, 50.43756254017353, 46.00231133401394, 47.03178629279137, 46.76484301686287, 52.42345377802849, 50.290236845612526, 48.466395512223244, 50.79445458948612, 52.551624700427055, 44.5693664252758, 38.55103276669979, 36.210540756583214, 36.72015801072121, 37.79972568154335, 41.69377192854881, 50.28044477105141, 52.65728943049908, 55.03336273133755, 53.432151451706886, 51.88302397727966, 53.790122643113136, 56.001011207699776, 57.705466747283936, 55.38013972342014, 52.785057574510574, 48.548642098903656, 50.38481377065182, 56.25756964087486, 60.537534579634666, 61.02005548775196, 56.31737843155861, 27.070199623703957, 10.553784538060427, 3.8253072230145335, 10.11957898736, 0.8457489986903965, 0.28799269173759967, 0.02922721156210173, 6.917458036914468, 42.96754717826843, 52.1893597394228, 40.296070128679276, 34.22926627099514, 43.22770021855831, 59.50956054031849, 39.757582023739815, 5.837105233222246, 0.02345959233934991, 0.05378114146878943, 0.023355339144472964, 0.022775411962356884, 0.00896185065357713, 0.04208146536257118, 0.014952686560718575, 0.034075016665156, 0.0905367398809176, 0.08628825613413937, 0.02667221604497172, 0.004191503967376775, 0.07901442222646438, 0.027304028626531363, 0.013326999087439617, 0.0450731220189482, 0.13437159592285752, 0.17484987387433648, 0.10700724553316832, 0.112154269736493, 0.0964095993549563, 0.1391306475852616, 0.06121513455582317, 0.1543782645603642, 0.20231751637766138, 0.14404606976313516, 0.13751301798038185, 0.15549936768366024, 0.2339537430088967, 0.13217497238656506, 0.12768150569172576, 0.05477162660099566, 1.0662103188224137, 20.848468579351902, 52.72541597485542, 57.113572508096695, 54.166196063160896, 39.10003870725632, 29.57013487815857, 40.67299470305443, 49.036551117897034, 14.306977093219757, 0.25814921187702566, 0.4486412135884166, 8.04885920137167, 17.222737334668636, 10.073625203222036, 15.58382447808981, 8.028087615966797, 6.75178550183773, 46.651776283979416, 57.16047339141369, 58.896953612565994, 53.15790876746178, 48.55574391782284, 46.708226054906845, 49.82731908559799, 50.57847797870636, 55.03859885036945, 49.99484069645405, 46.37829355895519, 40.052336007356644, 37.69940726459026, 40.82023300230503, 49.350551068782806, 52.407278046011925, 47.298763766884804, 45.870215222239494, 50.81522047519684, 51.48475594818592, 54.049135744571686, 49.930506348609924, 53.18969026207924, 51.133141815662384, 48.196021020412445, 51.55117258429527, 48.95576365292072, 47.70639069378376, 41.586146503686905, 36.72707363963127, 39.05734799802303, 37.1405940502882, 42.65324704349041, 39.511549025774, 38.42384599149227, 38.53861503303051, 39.93743397295475, 39.364599511027336, 36.966517791152, 38.722281977534294, 39.66188795864582, 39.19491961598396, 37.324226796627045, 37.74868682026863, 38.73775854706764, 40.88913470506668, 46.628939509391785, 52.18679487705231, 50.8209315687418, 54.61822360754013, 52.073762342333794, 53.29935997724533, 53.738491013646126, 56.44545815885067, 37.08035208284855, 45.35745933651924, 57.522848546504974, 53.3788251131773, 47.216794565320015, 49.674289897084236, 46.181281730532646, 48.00907105207443, 47.911203503608704, 42.83841870725155, 39.98777747154236, 39.37958210706711, 38.01075495779514, 42.16873124241829, 41.07040397822857, 39.72273029386997, 40.74801407754421, 39.896312579512596, 41.67634606361389, 42.89646819233894, 46.97754040360451, 51.816953122615814, 51.89038798213005, 52.918555811047554, 53.86969417333603, 54.27419386804104, 48.50364111363888, 49.031398594379425, 48.56294833123684, 55.01939468085766, 52.361125722527504, 47.78410792350769, 52.57253497838974, 53.89203317463398, 48.227312341332436, 42.32659377157688, 38.465628549456596, 37.89813280105591, 39.61040832102299, 44.064624309539795, 52.61925347149372, 56.70678913593292, 56.64844706654549, 55.06643235683441, 52.02266648411751, 55.248058810830116, 56.15797698497772, 60.37629023194313, 58.34582358598709, 55.1149595528841, 51.20341144502163, 52.35003411769867, 58.67793336510658, 62.96002998948097, 62.17009797692299, 56.06282629072666, 28.570169135928154, 16.44690826535225, 12.99555916339159, 14.832602888345718, 3.406492746435106, 0.6801071588415653, 0.14358672488015145, 7.455183332785964, 51.10192649066448, 61.999293342232704, 52.28951096534729, 41.30732126533985, 53.28070677816868, 67.8383070230484, 49.56468477845192, 8.386776018887758, 0.3873591707088053, 0.12323263465077616, 0.15466934972209856, 0.08202711876947433, 0.08129730558721349, 0.1332707385881804, 0.10174951516091824, 0.13120544550474733, 0.20687730138888583, 0.18192585121141747, 0.16005811368813738, 0.08185794620658271, 0.12081636508810334, 0.14143151318421587, 0.17144398007076234, 0.13369238236919045], [0.048387453352916054, 0.07560555983218364, 0.037915419379714876, 0.09489158081123605, 0.0454133781749988, 0.022506468776555266, 0.07515905410400592, 0.014662569901702227, 0.016785910993348807, 0.05411976861068979, 0.03410679542867001, 0.019293763434689026, 0.025776436377782375, 0.02221567676315317, 0.021968406144878827, 0.030534502839145716, 0.3475303907180205, 11.888333726674318, 38.98552045226097, 44.84293274581432, 33.59537288546562, 17.740873731672764, 15.638615638017654, 33.1091395765543, 40.36752909421921, 15.10788956657052, 0.1478623563889414, 0.07402914910926484, 0.9097929589916021, 4.801343511790037, 5.6472294218838215, 6.028199829161167, 7.68632160499692, 5.075779035687447, 28.37832313030958, 55.865943655371666, 50.43534345924854, 49.15595591068268, 47.02160283923149, 46.93128928542137, 46.67718172073364, 48.118227794766426, 47.14983455836773, 45.41920602321625, 37.70966291427612, 34.761180728673935, 35.80601826310158, 44.43017229437828, 48.870348036289215, 47.78241701424122, 47.86441661417484, 47.19904951751232, 44.17105659842491, 43.02489370107651, 42.7210696041584, 43.23404587805271, 44.97011952102184, 47.479352876544, 48.567188903689384, 47.12928906083107, 46.09667547047138, 44.62091825902462, 39.202089831233025, 33.43669340014458, 33.63595850765705, 33.50517712533474, 34.58809621632099, 34.726553186774254, 34.42055560648441, 34.70682844519615, 34.917584136128426, 37.592047825455666, 37.26295508444309, 36.05303920805454, 34.39270310103893, 36.48267835378647, 35.85778288543224, 36.63247391581535, 35.436203107237816, 38.22317875921726, 41.95421755313873, 47.40625619888306, 48.94797787070274, 53.356174528598785, 48.20589289069176, 49.6855752915144, 45.35971261560917, 50.70954814553261, 27.630338966846466, 41.14762343466282, 50.99692292511463, 48.97260434925556, 48.998803943395615, 47.28755056858063, 49.54869903624058, 49.05382879078388, 46.42780490219593, 46.56282305717468, 41.34327873587608, 36.64687134325504, 34.88177865743637, 33.538014963269234, 35.827855691313744, 37.373149171471596, 36.16682030260563, 36.57934136688709, 36.542677134275436, 37.114538848400116, 39.99274380505085, 43.63592751324177, 46.19828961789608, 48.25984999537468, 46.31418339908123, 42.241162955760956, 40.184618309140205, 39.745730459690094, 43.20343852043152, 45.93465596437454, 48.71232211589813, 48.06094966828823, 50.72571627795696, 47.307613492012024, 41.09096847474575, 39.11944046616554, 36.07816345989704, 36.31432458758354, 35.49748621881008, 35.709138661623, 39.96451131999493, 46.287391036748886, 51.67397439479828, 51.909831538796425, 50.58534041047096, 52.11822375655174, 51.897379606962204, 55.56457042694092, 56.77040532231331, 53.954387828707695, 50.77108584344387, 48.22800770401955, 53.088782876729965, 56.84094473719597, 59.313407465815544, 48.320840522646904, 23.467650935053825, 5.74808930978179, 2.894894848577678, 3.10092288069427, 0.7194947171956301, 0.12755685456795618, 0.026608213229337707, 6.537291286513209, 38.04439455270767, 43.272739201784134, 38.396270871162415, 37.05909602344036, 42.94513218104839, 49.147421568632126, 33.627557158470154, 4.271362675353885, 0.05502232408616692, 0.037693624835810624, 0.030815726713626646, 0.050022564246319234, 0.01829218690545531, 0.09393734217155725, 0.017580029416421894, 0.014357974869199097, 0.06091572991863359, 0.036462220014072955, 0.05615527188638225, 0.05483549211930949, 0.08722149941604584, 0.015402283333969535, 0.06608894080272876, 0.024283955135615543, 0.06366956906276755, 0.06966245608055033, 0.1054273615591228, 0.05529979454877321, 0.02210338610893814, 0.02327551930648042, 0.06174523579829838, 0.04571197758195922, 0.03306474587589037, 0.03607980615925044, 0.06308575859293342, 0.08352891396498308, 0.027117551035189535, 0.009396760324307252, 0.02767113383015385, 0.020981338602723554, 0.4680691851535812, 14.128227084875107, 43.926820904016495, 52.285236194729805, 41.569150015711784, 23.897120989859104, 19.920548871159554, 35.36277964711189, 47.137808203697205, 16.298535726964474, 0.26702360599301755, 0.12879564746981487, 1.5343771409243345, 3.80547727458179, 7.181242257356644, 10.717329662293196, 8.540810253471136, 4.771670429036021, 32.52444215118885, 57.48707726597786, 53.7010782212019, 50.87047331035137, 47.654249891638756, 50.1121935993433, 48.855376839637756, 51.53220400214195, 49.142120853066444, 47.827972769737244, 40.47821335494518, 36.73123061656952, 37.628981843590736, 45.10079450905323, 50.73096379637718, 48.8620150834322, 47.26854018867016, 50.23628734052181, 47.17315010726452, 46.39112927019596, 46.131983175873756, 45.62915995717049, 47.438797652721405, 50.21699957549572, 49.63852621614933, 48.69939520955086, 47.81690776348114, 46.23332753777504, 41.317082941532135, 34.55816142261028, 36.17844767868519, 36.706676334142685, 35.51423192024231, 36.035890728235245, 36.740179136395454, 36.08246862888336, 35.975804552435875, 39.443061500787735, 37.75542005896568, 38.1963711977005, 37.033527195453644, 37.134955152869225, 37.33764387667179, 36.9551146030426, 36.76059544086456, 39.305394887924194, 44.66879948973656, 48.27389404177666, 50.446184277534485, 54.689477384090424, 49.730808064341545, 50.47950468957424, 46.85316547751427, 49.73907642066479, 31.346260271966457, 42.93721720576286, 52.64489829540253, 49.51187141239643, 51.71205595135689, 49.46753539144993, 51.25330276787281, 49.82560157775879, 48.92736777663231, 48.67977686226368, 43.36543522775173, 37.95214310288429, 37.69769735634327, 35.89748315513134, 38.00516925752163, 39.68872591853142, 38.76433812081814, 38.34828704595566, 38.39135393500328, 39.149025678634644, 42.115879878401756, 46.00799962878227, 47.04562894999981, 50.10022044181824, 48.858025297522545, 44.596637561917305, 42.49936290085316, 43.217018991708755, 47.05598719418049, 50.16232430934906, 50.55528402328491, 49.35361370444298, 51.20028041303158, 48.54945905506611, 43.80379110574722, 41.46442383527756, 37.29228191077709, 36.750624775886536, 37.59209342300892, 37.859344482421875, 42.577224522829056, 50.003462433815, 53.78242805600166, 54.62767370045185, 52.96706400811672, 53.29857721924782, 53.06444138288498, 57.95649267733097, 57.42667190730572, 55.347522273659706, 51.31857946515083, 49.99588184058666, 56.59428097307682, 58.931022584438324, 62.0572554320097, 49.83305297791958, 27.837247364223003, 10.363196264952421, 2.56463794503361, 4.626122564077377, 1.1710705608129501, 0.15957136871293187, 0.08017798361834139, 7.035425556823611, 44.13637585937977, 51.00261501967907, 42.20508769154549, 40.14899142086506, 48.99655446410179, 54.89344663918018, 40.808822214603424, 5.663208989426494, 0.035866550024366006, 0.062293263617902994, 0.029699916958634276, 0.03190480245393701, 0.05628492508549243, 0.059412828923086636, 0.00823523520011804, 0.017206838601850905, 0.06516889290651307, 0.096974737389246, 0.07242928651976399, 0.04235094289469998, 0.04829548270208761, 0.014997977050370537, 0.073349705489818, 0.026900762277364265, 0.16706654074368998, 0.11316491902107373, 0.17300551815424114, 0.15432524553034455, 0.11551299263373949, 0.08811355350189842, 0.11100959600298665, 0.16289624967612326, 0.17212392092915252, 0.14688531897263601, 0.17704982223222032, 0.14307911071227863, 0.09712759754620492, 0.10521621312364005, 0.14063379348954186, 0.12349464246653952, 0.6047296535689384, 17.329135425388813, 49.75576512515545, 60.92878818511963, 46.675323620438576, 29.25756935030222, 22.464981637895107, 42.530935406684875, 51.71718567609787, 21.331521458923817, 0.3293097153073177, 0.4276240069884807, 3.478981931693852, 11.414995975792408, 11.835546009242535, 11.3246064260602, 12.811785824596882, 7.11163236759603, 33.067288622260094, 58.67075935006142, 55.16312576830387, 53.14537703990936, 53.349597081542015, 51.52669809758663, 52.107952907681465, 53.973554000258446, 52.02190272510052, 49.96261842548847, 42.410903647542, 38.19969601929188, 40.337214320898056, 48.53484883904457, 53.03134135901928, 49.6834360063076, 49.741971865296364, 51.14156596362591, 50.14665015041828, 48.66754151880741, 47.5507016479969, 47.83751405775547, 50.45001067221165, 51.677170023322105, 51.55836559832096, 49.91318307816982, 49.47811022400856, 50.297293066978455, 43.81669141352177, 36.42126224935055, 36.28880895674229, 37.57708802819252, 37.446055859327316, 37.42547236382961, 39.39158946275711, 37.44316041469574, 37.07494497299194, 41.56571879982948, 39.39507007598877, 39.820062071084976, 37.52763368189335, 38.62580895423889, 38.791647255420685, 39.36217524111271, 38.941549211740494, 41.7610739171505, 46.6502183675766, 51.50886945426464, 52.124178037047386, 58.11508856713772, 50.59522368013859, 52.313483878970146, 47.53564305603504, 50.76903775334358, 34.020961448550224, 46.36059030890465, 54.54667344689369, 51.52552776038647, 53.80958899855614, 51.032401621341705, 53.695819303393364, 52.768277674913406, 50.1362045109272, 50.583516508340836, 45.36508932709694, 40.839205384254456, 38.766169622540474, 37.138059586286545, 40.688178688287735, 41.26230888068676, 40.39339430630207, 39.99944284558296, 40.58578938245773, 40.72804614901543, 42.51222141087055, 47.59859427809715, 49.705718010663986, 52.54072688519955, 51.17501176893711, 47.04417362809181, 45.20071394741535, 44.57105353474617, 48.80509413778782, 51.885444447398186, 52.87162072956562, 51.057928651571274, 52.83160127699375, 52.217311039566994, 46.16373047232628, 43.65444011986256, 40.408920273184776, 39.32058647274971, 38.9688241481781, 38.49712885916233, 44.447753950953484, 52.416652143001556, 56.07787348330021, 57.2115084528923, 55.203312411904335, 54.921929910779, 54.082235768437386, 58.8371866196394, 60.989239141345024, 59.132445976138115, 55.79337514936924, 52.59930454194546, 59.750562608242035, 60.50691582262516, 63.29935558140278, 51.20890595018864, 28.201923295855522, 8.621623367071152, 7.636585123836994, 7.001660093665123, 1.681457629892975, 0.6793154357001185, 0.1509443175746128, 8.415359985083342, 50.29698148369789, 55.2958944439888, 52.01596364378929, 48.37798945605755, 56.77783012390137, 63.69573511183262, 50.52869684994221, 7.6508296094834805, 0.13228302908828482, 0.18144900648621842, 0.09544595770421438, 0.15253689227392897, 0.14761838276172057, 0.1385686339926906, 0.0659721861302387, 0.10989476402755827, 0.1319061071262695, 0.2530207933159545, 0.15302043117117137, 0.1465844374615699, 0.1876996413921006, 0.1401440057088621, 0.11485400260426104, 0.11614208153332584], [0.055164779332699254, 0.0862080002843868, 0.019458138012851123, 0.013276925456011668, 0.038975202551227994, 0.0278619659729884, 0.043614712776616216, 0.04857571766478941, 0.034375790564808995, 0.06561942107509822, 0.006428211363527225, 0.013729727379541146, 0.05785905370430555, 0.04234083113260567, 0.07026302424492314, 0.07048818442854099, 0.027158493467140943, 5.243333894759417, 33.91773238778114, 46.115294471383095, 40.55710092186928, 27.654239684343338, 22.157120257616043, 25.956179201602936, 34.9499735981226, 18.5488585755229, 0.5523722036741674, 0.09835066433879547, 0.9000158461276442, 4.273624029010534, 4.435582738369703, 9.208629168570042, 10.21989930421114, 5.0972630828619, 25.119638890028, 53.99826027452946, 49.27969627082348, 47.80225194990635, 45.082669481635094, 44.24865983426571, 45.26898108422756, 46.87117651104927, 45.84902375936508, 41.49080961942673, 34.18370671570301, 35.45856110751629, 38.03410090506077, 51.17549054324627, 47.67672948539257, 46.510070487856865, 46.894400864839554, 44.03407774865627, 41.29552289843559, 41.521815955638885, 39.37275767326355, 41.74482598900795, 42.080025002360344, 44.946420192718506, 47.30292834341526, 49.27055016160011, 47.90934540331364, 47.92158454656601, 40.292836502194405, 34.96280550956726, 33.78654062747955, 34.75785590708256, 35.080614387989044, 36.912876069545746, 35.782280936837196, 35.70290319621563, 39.45781230926514, 43.36172662675381, 36.503178253769875, 36.78023278713226, 35.32567083835602, 36.50189772248268, 35.473349913954735, 37.33785666525364, 33.51278431713581, 39.13422167301178, 39.13713611662388, 44.81719292700291, 45.61444714665413, 50.178792625665665, 47.78403952717781, 49.9873398989439, 41.13056614995003, 47.31555886566639, 25.208337530493736, 39.57593277096748, 44.00769956409931, 47.66542509198189, 52.46323764324188, 49.78175953030586, 50.69960027933121, 50.48320189118385, 47.33439825475216, 47.66091473400593, 46.9939137250185, 38.66334713995457, 37.1890414506197, 36.78110674023628, 36.30741275846958, 35.69040946662426, 36.216468438506126, 35.78083321452141, 35.94468802213669, 35.50705410540104, 37.05214999616146, 41.08868099749088, 42.29842588305473, 41.12635217607021, 37.85594366490841, 37.84991338849068, 35.331096947193146, 36.39541603624821, 42.74961747229099, 45.53212456405163, 50.40573924779892, 46.24390237033367, 47.552153170108795, 48.07376258075237, 41.2433934956789, 39.66905437409878, 37.432840168476105, 37.647399455308914, 36.48526221513748, 36.523054987192154, 38.09379190206528, 39.58412513136864, 46.0283437371254, 50.56463152170181, 53.023722767829895, 55.134634897112846, 50.741496831178665, 50.93980439007282, 56.81412197649479, 56.19997613132, 52.73513965308666, 50.43691657483578, 53.807195127010345, 59.265172854065895, 57.163737416267395, 55.4185176640749, 23.151931576430798, 10.43517105281353, 0.6263512652367353, 9.914736729115248, 0.40846246643923223, 0.036756678236997686, 0.036999950534664094, 7.177712246775627, 44.83674667775631, 40.262077152729034, 35.48756115138531, 29.17679898440838, 37.95813538134098, 52.67509147524834, 35.58919429779053, 5.942404232919216, 0.06686766151688062, 0.053173704727669246, 0.03672165999887511, 0.04588363262882922, 0.020059127346030436, 0.030158532681525685, 0.024701765723875724, 0.03554935239662882, 0.045391113744699396, 0.0216592070137267, 0.0334657913481351, 0.029666828304470982, 0.03546931176970247, 0.03126675954263192, 0.05732689671276603, 0.05989279809000436, 0.02355331445869524, 0.015568901981168892, 0.05323745892383158, 0.007826277505955659, 0.0359800874866778, 0.08059233208769001, 0.02068601763312472, 0.062019956603762694, 0.02330776562303072, 0.05253617389826104, 0.04418086384248454, 0.04259094603185076, 0.06955596531042829, 0.03194504541170318, 0.07468212032108568, 0.022963396113482304, 0.030239083534979727, 8.773778602480888, 41.44990861415863, 51.16405315697193, 46.213352009654045, 28.514927700161934, 21.74948003143072, 31.025853864848614, 42.85223476588726, 20.274617671966553, 0.5340011394582689, 0.1874281934578903, 0.944630024023354, 5.145256407558918, 6.948443949222565, 10.671294182538986, 12.333934865891933, 7.48892362229526, 27.140001878142357, 55.585841685533524, 53.46456751227379, 49.242074489593506, 47.70162954926491, 46.657358184456825, 47.011666372418404, 50.01436784863472, 48.12276095151901, 44.29265767335892, 37.21173383295536, 36.65966525673866, 39.302951619029045, 51.78777068853378, 47.610943615436554, 46.7054446041584, 48.74939292669296, 47.25615285336971, 44.64047960937023, 43.35937075316906, 41.67210929095745, 44.549470692873, 43.15184108912945, 46.5826465934515, 48.932562097907066, 50.44039338827133, 50.10897897183895, 48.72365690767765, 42.2958230227232, 37.26806201040745, 35.55054657161236, 36.780551970005035, 35.74452996253967, 36.46020255982876, 36.094871163368225, 37.92512275278568, 39.75548453629017, 43.10236394405365, 38.43846760690212, 38.3683043718338, 35.53635813295841, 39.23068709671497, 37.06871710717678, 38.636566177010536, 35.84543354809284, 40.69921709597111, 42.231625467538834, 46.691966727375984, 47.30306513607502, 50.962025597691536, 50.247401744127274, 51.56001091003418, 41.81045986711979, 49.86768811941147, 28.142063207924366, 42.84426659345627, 46.86508543789387, 49.216726049780846, 53.94951269030571, 51.65578097105026, 52.76983559131622, 51.218207851052284, 49.58401434123516, 51.200364008545876, 47.39264152944088, 40.45716628432274, 38.05815741419792, 38.226028606295586, 38.36739622056484, 37.01533757150173, 38.01966167986393, 37.579459100961685, 38.03615279495716, 36.77168324589729, 38.71048741042614, 42.571460232138634, 43.14509645104408, 42.46663145720959, 41.05614334344864, 38.89560207724571, 36.79505579173565, 38.52054700255394, 45.40858179330826, 46.02175869047642, 53.366525173187256, 47.3876865953207, 48.61727401614189, 49.400020614266396, 43.368919640779495, 41.10096573829651, 39.56691965460777, 38.58549311757088, 37.50345937907696, 38.86280983686447, 39.44367706775665, 41.50109186768532, 48.31002630293369, 52.139020040631294, 55.8830351382494, 56.796274334192276, 53.48685331642628, 51.4571238309145, 57.82268285751343, 57.46178202331066, 55.951154083013535, 52.978695183992386, 56.26307554543018, 60.994669049978256, 58.80779139697552, 56.33408613502979, 23.95564164966345, 8.175623249262571, 4.602000983431935, 1.7432728316634893, 2.406986067071557, 0.07756117091048509, 0.060652312022284605, 7.890586769208312, 47.30506382882595, 48.079789057374, 44.03078332543373, 35.797613114118576, 45.09721130132675, 59.171420484781265, 39.739453196525574, 7.596171917393804, 0.04765644531289581, 0.032218293054029346, 0.018016579233517405, 0.022306734572339337, 0.0297628102634917, 0.027645182781270705, 0.026822369218280073, 0.03617436690547038, 0.04534231382422149, 0.00793436945969006, 0.008029681630432606, 0.015686589904362336, 0.022778066995670088, 0.025939898114302196, 0.07943581367726438, 0.037393533712020144, 0.18536827352363616, 0.15375388087704778, 0.16354977007722482, 0.08884819064405747, 0.2415662189014256, 0.1184624656161759, 0.11428394413087517, 0.160072585567832, 0.08603763286373578, 0.1403796227532439, 0.11344891667249613, 0.11797259619925171, 0.17890608200104907, 0.17731444240780547, 0.2036292920820415, 0.16713674791390076, 0.19036252662772313, 9.942953065037727, 48.43492180109024, 59.61678698658943, 55.969058722257614, 39.01189863681793, 31.574272736907005, 35.37807382643223, 48.09490844607353, 24.00926437228918, 0.8726698416285217, 0.3375189076177776, 2.9442617995664477, 9.86800018697977, 12.441093865782022, 15.977698042988777, 16.67414177209139, 7.711829636245966, 28.747401125729084, 57.900559678673744, 55.838501527905464, 52.515112459659576, 50.63840836286545, 50.08911743760109, 48.68359565734863, 51.52149237692356, 51.278415620326996, 46.60797983407974, 38.61036658287048, 38.93775321543217, 41.213538497686386, 56.08994923532009, 49.59386721253395, 47.2371918708086, 51.5897823125124, 49.17830631136894, 47.110426872968674, 46.1125548183918, 45.34643232822418, 46.08656421303749, 46.93415433168411, 49.82776366174221, 52.11991086602211, 52.07141786813736, 54.36845541000366, 51.98816433548927, 44.75379332900047, 39.13195699453354, 37.22735859453678, 39.19845722615719, 39.117650762200356, 39.434272572398186, 38.814381435513496, 40.44545151293278, 42.04335696995258, 44.979930594563484, 38.98112028837204, 39.27880771458149, 38.79987381398678, 41.611905321478844, 38.930833786726, 41.05515159666538, 37.0545818656683, 43.84096071124077, 43.88100676238537, 49.7590671479702, 50.894974395632744, 54.584629610180855, 52.834109142422676, 53.14984939992428, 43.69748041033745, 51.775166764855385, 34.149736538529396, 45.5584267526865, 47.67482578754425, 49.92606058716774, 57.83536657691002, 53.65741476416588, 53.96331734955311, 53.61480765044689, 51.044568568468094, 52.255438193678856, 51.262414678931236, 42.424738705158234, 39.70814287662506, 40.58208838105202, 40.99619396030903, 38.27222652733326, 39.451618641614914, 38.711228370666504, 39.919738322496414, 38.93336825072765, 40.49748592078686, 44.98184949159622, 46.66449800133705, 45.132465809583664, 40.60030460357666, 41.331275179982185, 39.41247694194317, 39.84068736433983, 47.52013608813286, 49.31768663227558, 55.209015905857086, 48.78296412527561, 48.703293800354004, 52.78222672641277, 45.94534859061241, 44.081962779164314, 41.5517583489418, 42.03579157590866, 40.00014580786228, 41.911823228001595, 41.91949121654034, 43.07547278702259, 51.22049152851105, 56.01122885942459, 58.57329457998276, 58.639851808547974, 54.52887520194054, 51.61442019045353, 59.06463101506233, 60.67926697432995, 58.46932835876942, 56.434898525476456, 57.30183720588684, 65.45569807291031, 60.49715794622898, 58.56748469173908, 25.7317366451025, 15.422857515513897, 8.94131351262331, 23.282494470477104, 3.929979968816042, 0.17540366447065026, 0.40833181876223534, 9.310891181230545, 55.9293432533741, 51.49972714483738, 48.50490264594555, 40.81657759845257, 53.05685319006443, 66.86649397015572, 50.16575172543526, 10.598777923732996, 0.20658630528487265, 0.17785331583581865, 0.1289372640894726, 0.14959736407035962, 0.1286601906758733, 0.1318734823144041, 0.14436813216889277, 0.1779618178261444, 0.1918160228524357, 0.09506496135145426, 0.1042298914398998, 0.12365637870971113, 0.13341657060664147, 0.091614961711457, 0.23279621527763084, 0.161745980149135], [0.07733466743957251, 0.08172613335773349, 0.019227756820328068, 0.03655200132925529, 0.03902060343534686, 0.06460068238084204, 0.11300395461148582, 0.04844696246436797, 0.049055401104851626, 0.07630803971551359, 0.03645892116765026, 0.03503896630718373, 0.020100242327316664, 0.044518129143398255, 0.03798292142164428, 0.061759284653817303, 0.10573388339253142, 2.6650261832401156, 28.605997413396835, 40.1885586977005, 43.96473526954651, 30.861529782414436, 25.408729277551174, 33.52894864976406, 41.25056371092796, 21.601683162152767, 1.6356279328465462, 0.10516181369894184, 0.5517670861445367, 1.5488050854764879, 5.615113545209169, 11.885836310684681, 9.487149473279715, 8.784315437078476, 21.30751244723797, 49.97901074588299, 49.978254586458206, 49.72861938178539, 44.69522327184677, 45.56788444519043, 43.350859209895134, 45.33662125468254, 41.199578046798706, 37.61644631624222, 36.83069407939911, 35.40339946746826, 41.73186108469963, 49.999031871557236, 47.31656961143017, 49.394909888505936, 43.00426460802555, 41.43764667212963, 39.9325892329216, 37.73392081260681, 35.6273290514946, 38.10327999293804, 38.73108230531216, 41.32548429071903, 44.79037396609783, 46.94337643682957, 47.076684683561325, 46.80229760706425, 39.39545005559921, 31.364049017429352, 34.25980903208256, 35.79415149986744, 34.75178383290768, 35.23089252412319, 34.7608957439661, 35.22132083773613, 36.020421758294106, 37.450437024235725, 37.37365834414959, 38.82982760667801, 35.588901713490486, 36.422915160655975, 35.520512983202934, 36.58582761883736, 34.31107968091965, 36.14310957491398, 35.943149104714394, 40.646331533789635, 40.224759355187416, 46.90569005906582, 43.89345109462738, 50.56387156248093, 43.890350461006165, 48.36998708546162, 32.36021116375923, 38.00936423242092, 51.047357618808746, 47.667119801044464, 52.01982043683529, 48.342518359422684, 53.39239418506622, 50.04677250981331, 51.306686103343964, 49.0097663551569, 48.72205339372158, 39.30123031139374, 35.948123037815094, 35.757000893354416, 37.66746997833252, 36.01546682417393, 36.894671246409416, 36.25979371368885, 37.656043991446495, 37.097568958997726, 37.45924115180969, 38.338380977511406, 35.4012867808342, 35.71584150195122, 35.902331694960594, 35.58672063052654, 37.269475534558296, 35.98529264330864, 43.473227843642235, 46.62901170551777, 48.39229568839073, 48.12564879655838, 48.728497847914696, 49.14880469441414, 46.061295568943024, 41.21026687324047, 43.018570840358734, 40.828083381056786, 39.51835826039314, 37.4761426448822, 35.53195036947727, 37.128309309482574, 38.648098558187485, 44.7532157599926, 50.716543570160866, 51.135611683130264, 52.87026800215244, 52.73341454565525, 51.779471933841705, 57.599270045757294, 55.720567256212234, 51.33363425731659, 53.28624688088894, 54.31236281991005, 60.67826382815838, 49.04842548072338, 25.47068875283003, 10.720932818949223, 1.4039033045992255, 1.1714570713229477, 1.332095351535827, 0.16966221708571538, 0.030467254982795566, 8.701029606163502, 44.01227451860905, 44.01213392615318, 26.68828971683979, 23.6011016741395, 41.66296698153019, 52.33499072492123, 37.87527322769165, 6.8329638708382845, 0.008468572923447937, 0.04053822864079848, 0.03760118292120751, 0.04811235405213665, 0.030720869108336046, 0.055942973122000694, 0.03413637743506115, 0.04794094762473833, 0.07180065775173716, 0.0425796282797819, 0.07218960992759094, 0.03953620311222039, 0.13495931751094759, 0.049888035136973485, 0.019030853909498546, 0.050575018976815045, 0.023320304208027665, 0.08010334582650103, 0.01005661959425197, 0.02920153139712056, 0.030394964232982602, 0.07609998603584245, 0.08471970475511625, 0.06694376876112074, 0.041637772374087945, 0.043354879453545436, 0.02515770414902363, 0.005621951868306496, 0.04775711022375617, 0.028416858658601996, 0.03012179451616248, 0.04415563824295532, 0.07079049828462303, 3.6756216175854206, 35.541909635066986, 48.07349279522896, 50.82000061869621, 36.42451487481594, 25.67101590335369, 31.327572874724865, 42.22174979746342, 24.547666981816292, 1.4986971742473543, 0.05613390174403321, 0.5668925901409239, 5.312226573005319, 9.670781269669533, 8.610539361834526, 9.850007202476263, 9.059254433959723, 24.796069152653217, 53.46674099564552, 50.98095618188381, 51.13156870007515, 46.08251743018627, 47.288276329636574, 46.031334176659584, 46.20020091533661, 43.417625427246094, 39.13090065121651, 38.684398010373116, 37.589251175522804, 42.920900881290436, 52.080803364515305, 48.33119496703148, 50.09974546730518, 45.64339019358158, 44.43988457322121, 44.01814520359039, 40.05814969539642, 38.94680812954903, 41.51748798787594, 41.839672699570656, 44.63452532887459, 47.384798750281334, 49.72201153635979, 48.526979461312294, 49.15620669722557, 42.73085407912731, 34.208185002207756, 35.85737630724907, 35.79550042748451, 35.62640570104122, 36.68830431997776, 36.42081007361412, 35.92267580330372, 37.478452920913696, 39.984695836901665, 36.71975143253803, 38.77303205430508, 35.71655586361885, 38.63919943571091, 37.20098800957203, 37.556075155735016, 35.27777440845966, 36.827604845166206, 37.647589445114136, 42.58416675031185, 43.41089978814125, 48.96049439907074, 46.860263496637344, 51.793895959854126, 44.82587546110153, 49.11525249481201, 36.139693558216095, 40.769600719213486, 51.84251435101032, 48.48241165280342, 52.86435931921005, 50.71929082274437, 54.61991831660271, 51.113128289580345, 53.86275574564934, 50.92963993549347, 50.10270170867443, 40.72453893721104, 38.503170534968376, 38.78138020634651, 37.33753748238087, 38.79451610147953, 37.89794661104679, 37.853325605392456, 38.14210630953312, 38.76240782439709, 40.094646736979485, 38.85213240981102, 37.022937163710594, 38.810418248176575, 37.56830669939518, 36.528416499495506, 39.059073105454445, 38.22334215044975, 45.67550227046013, 47.95058459043503, 51.090618297457695, 51.024289056658745, 50.90707294642925, 49.94381703436375, 47.345421463251114, 43.37820254266262, 44.04278688132763, 41.691860631108284, 40.56438513100147, 39.57022167742252, 37.63881951570511, 39.959134608507156, 42.011073902249336, 48.10142509639263, 52.40265369415283, 52.89794571697712, 56.024258360266685, 53.88954810798168, 53.15776437520981, 59.10743571817875, 58.750703260302544, 54.37679976224899, 54.272620752453804, 57.63630285859108, 61.819806173443794, 49.05515491962433, 22.154551595449448, 10.176485683768988, 5.922288587316871, 2.4061800353229046, 2.361346003599465, 0.15934447932522744, 0.03367571523995139, 9.90999173372984, 49.80407953262329, 50.15730857849121, 31.406886018812656, 27.739218324422836, 45.70332057774067, 59.382936134934425, 44.608652517199516, 8.985717929899693, 0.07390317696263082, 0.014739284779352602, 0.02267925374326296, 0.0733063937514089, 0.024243858752015512, 0.023469383122574072, 0.048422935433336534, 0.06419701341656037, 0.03225221291359048, 0.08772663481067866, 0.015740267590445, 0.015217554428090807, 0.017990976994042285, 0.04689517249062192, 0.021174738576519303, 0.009044864509633044, 0.11909106469829567, 0.19777071895077825, 0.1420779831823893, 0.0881391872826498, 0.1493241052958183, 0.13845302222762257, 0.3250827390002087, 0.17987829545745626, 0.22723380359821022, 0.11396608970244415, 0.10604563736706041, 0.12164323634351604, 0.12183533384813927, 0.12583977717440575, 0.15219143737340346, 0.12872650899225846, 0.21437090006656945, 5.715609602630138, 40.27305096387863, 54.26494516432285, 56.879649460315704, 40.96970558166504, 34.75320115685463, 43.9430346339941, 52.718960121273994, 28.295884653925896, 2.416659635491669, 0.11155676664202474, 2.471512067131698, 8.954059928655624, 13.318229299038649, 22.966338135302067, 18.003378845751286, 12.37454328685999, 26.25731684267521, 54.31597642600536, 54.0149299800396, 54.39527817070484, 49.505597949028015, 50.36804527044296, 47.803490683436394, 48.070479556918144, 45.91716170310974, 41.379809975624084, 40.341698080301285, 38.715130761265755, 44.96638812124729, 55.745839700102806, 48.97104263305664, 51.51510111987591, 48.13645541667938, 47.48529575765133, 45.8040189743042, 43.46878968179226, 40.37050053477287, 43.1132123619318, 43.35047163069248, 46.324864625930786, 50.497884303331375, 51.15970999002457, 51.70388638973236, 50.23535639047623, 43.9077877253294, 35.39764277637005, 38.343696892261505, 38.91527742147446, 38.18378247320652, 37.77081683278084, 38.386444598436356, 37.119983956217766, 38.512601628899574, 41.24829903244972, 40.49012191593647, 42.729132771492004, 38.26298542320728, 38.85392591357231, 39.07816708087921, 38.21798823773861, 37.096752002835274, 39.028819128870964, 39.21325743198395, 45.58351680636406, 46.0591334849596, 50.60141734778881, 49.21982288360596, 53.39787349104881, 47.43070408701897, 50.828002989292145, 39.534473195672035, 43.58611598610878, 53.222349509596825, 51.622802540659904, 54.87145721912384, 52.08372920751572, 55.55081516504288, 54.073515236377716, 54.970282316207886, 53.73657591640949, 52.16693714261055, 43.465005084872246, 41.998758763074875, 41.30922496318817, 40.602751672267914, 39.308123141527176, 39.66862879693508, 39.2794156819582, 40.96056327223778, 39.91840839385986, 41.600680723786354, 41.207405626773834, 37.75362275540829, 40.64622513949871, 39.67332914471626, 39.07765790820122, 41.69471047818661, 39.48355212807655, 46.89447306096554, 51.95941887795925, 52.501801773905754, 51.87625274062157, 51.635383665561676, 53.160393834114075, 49.37219850718975, 46.92910060286522, 46.81851513683796, 44.695303067564964, 42.69180737435818, 41.978726238012314, 39.54292394220829, 41.05395466089249, 42.9784981906414, 50.64938597381115, 56.233414337038994, 55.58189369738102, 57.08108425140381, 54.65443566441536, 53.43096971511841, 61.52495339512825, 60.93046769499779, 57.38004840910435, 59.43362921476364, 59.19989615678787, 63.769606947898865, 50.79272948205471, 28.153928071260452, 19.42484077066183, 8.380399961024523, 7.4520062282681465, 3.2314154785126448, 0.34643872117158026, 0.16165810986422002, 10.99269898608327, 54.695678651332855, 56.364134922623634, 39.28349286317825, 36.49841330945492, 54.41584266722202, 65.77722921967506, 51.45194090902805, 11.394312735646963, 0.18863833945943043, 0.20372878439957276, 0.08736035524634644, 0.14371225173817948, 0.08241152900154702, 0.13161288457922637, 0.16164393484359607, 0.12458039709599689, 0.153631396824494, 0.17374747287249193, 0.11244247536524199, 0.144027293426916, 0.21509631973458454, 0.14736148092197254, 0.12185291532659903, 0.07386613637208939], [0.05947621575614903, 0.008870559995557414, 0.016481298334838357, 0.06436491690692492, 0.021013141486037057, 0.03651247454399709, 0.03722645771631505, 0.027975444063486066, 0.0189173498438322, 0.033903057337738574, 0.08396900753723457, 0.029228180064819753, 0.009695024837128585, 0.09804383080336265, 0.018543962360126898, 0.035841840217472054, 0.006627099519391777, 2.3747452720999718, 25.239131078124046, 44.44192126393318, 42.28954195976257, 27.1798275411129, 33.27006474137306, 45.39715960621834, 47.95243889093399, 27.754045128822327, 3.439974174834788, 0.050631503836484626, 0.26383370684925467, 5.5565069150179625, 8.001462444663048, 6.178292725235224, 13.027631342411041, 13.20355525240302, 27.29216281324625, 48.83162051439285, 48.94915580749512, 49.76591058075428, 46.04367211461067, 44.179951921105385, 41.25232681632042, 39.52316500246525, 35.69692611694336, 37.16215029358864, 34.02671433985233, 36.3822041451931, 45.849198549985886, 48.86855833232403, 47.31510289013386, 48.77846136689186, 44.59454387426376, 42.36767716705799, 37.13250048458576, 35.085022151470184, 33.73056203126907, 36.59348800778389, 35.413666516542435, 39.265546426177025, 41.48650445044041, 43.34153451025486, 43.424461260437965, 40.54902635514736, 34.244594648480415, 36.53692804276943, 34.111970365047455, 33.98968152701855, 34.99644510447979, 35.24099238216877, 35.49797259271145, 35.36199688911438, 35.2473646402359, 36.598199754953384, 36.19304269552231, 37.03480392694473, 35.16408450901508, 36.92465923726559, 33.58696013689041, 35.426297038793564, 35.689144134521484, 35.03400608897209, 35.31078323721886, 37.92071498930454, 36.85054421424866, 41.45102955400944, 42.79073506593704, 48.62089142203331, 46.17923364043236, 56.5118557959795, 37.63405077159405, 43.39943200349808, 53.09520073235035, 45.69447465240955, 48.06956000626087, 43.173138946294785, 49.74347658455372, 46.52368135750294, 49.9206230789423, 48.2783056050539, 46.05342619121075, 36.63091979920864, 36.342754662036896, 35.74264146387577, 35.80317221581936, 36.03730045258999, 36.41382224857807, 36.07001289725304, 36.85643769800663, 37.87671335041523, 37.091196700930595, 37.04131677746773, 35.62719605863094, 35.61880610883236, 37.60320782661438, 35.747250616550446, 35.4218702763319, 38.32387715578079, 42.465746104717255, 46.61646857857704, 49.35796447098255, 45.87781481444836, 49.108583852648735, 50.83916679024696, 50.48554256558418, 50.998872220516205, 47.00937509536743, 48.08268070220947, 49.39077191054821, 47.13157273828983, 42.33008198440075, 36.83353252708912, 34.89742621779442, 37.412389665842056, 44.87711951136589, 50.46083629131317, 51.314601078629494, 54.18476566672325, 50.23993134498596, 55.517563149333, 56.717451363801956, 55.39180889725685, 53.58497925102711, 57.49830186367035, 56.25924155116081, 48.7412765622139, 19.04522404074669, 2.5995298102498055, 2.631455697119236, 0.5072964099235833, 1.860186739359051, 0.14683813322335482, 0.019924477637687232, 8.168725669384003, 43.24457511305809, 47.04190135002136, 36.06217011809349, 30.56653831154108, 43.618216663599014, 51.35455213487148, 30.374380722641945, 4.872311353683472, 0.026480552696739323, 0.051957502801087685, 0.04252658327459358, 0.039937719848239794, 0.04013212172139902, 0.05345553901861422, 0.030982029020378832, 0.06973249255679548, 0.04849434488278348, 0.043702111797756515, 0.029100792271492537, 0.040970388654386625, 0.03913513537554536, 0.011799148942372994, 0.01415820726833772, 0.05303070771333296, 0.07807095957105048, 0.008019937231438234, 0.03774543045437895, 0.07522039260948077, 0.07936969574075192, 0.037987968025845475, 0.016209208442887757, 0.036477734611253254, 0.019556806546461303, 0.03878968047501985, 0.0365920142212417, 0.06313030229648575, 0.03314184388727881, 0.007041123299131868, 0.09265025029890239, 0.029786590530420654, 0.04780195820785593, 3.3963252045214176, 30.50964016467333, 48.94190579652786, 46.79467901587486, 30.71360941976309, 32.87767119705677, 47.0860131829977, 51.16681940853596, 30.742643661797047, 3.208323405124247, 0.008748354248382384, 0.025269991092500277, 5.32742528244853, 6.296106828376651, 5.398808727040887, 10.531631726771593, 9.276475477963686, 29.4583847746253, 51.5424520522356, 51.563008949160576, 51.0850515961647, 48.43341328203678, 47.035840675234795, 42.3946975171566, 41.704415157437325, 38.90781082212925, 38.84617432951927, 36.4368300139904, 36.83608219027519, 47.347112372517586, 51.95566847920418, 47.85371258854866, 48.43548037111759, 46.31064958870411, 44.61410142481327, 40.17360270023346, 37.28687480092049, 35.52774399518967, 37.63860672712326, 37.9773585498333, 41.85587503015995, 43.861392214894295, 46.31914973258972, 45.721145421266556, 44.092210829257965, 36.94981388747692, 37.456919476389885, 35.936932638287544, 35.95552124083042, 36.62602946162224, 37.47757136821747, 36.72129034996033, 36.86733931303024, 36.25420421361923, 36.82402543723583, 38.82429890334606, 37.91753835976124, 37.4787987023592, 38.28251637518406, 36.68331518769264, 35.77298283576965, 38.08143876492977, 36.862992346286774, 36.15861274302006, 38.952637016773224, 39.82235714793205, 44.155994206666946, 46.02549009025097, 48.69552321732044, 48.748674765229225, 56.78383380174637, 40.45098401606083, 45.63915342092514, 54.77455101907253, 48.173279240727425, 49.547342509031296, 46.481112241744995, 51.368702575564384, 48.893724381923676, 50.78941226005554, 49.955793991684914, 48.39452996850014, 39.942008927464485, 38.32690179347992, 36.62910729646683, 37.369634360075, 37.32074998319149, 37.46058247983456, 37.98794478178024, 38.36424998939037, 38.64275224506855, 39.40399959683418, 38.06783929467201, 36.39788210391998, 37.018951177597046, 38.32408994436264, 37.38468915224075, 38.004796877503395, 40.19058018922806, 46.112121641635895, 48.598609417676926, 50.36117143929005, 47.00188189744949, 47.72860050201416, 53.08456510305405, 52.68981948494911, 52.71854214370251, 49.88058462738991, 51.05108521878719, 50.84551244974136, 48.391372337937355, 42.80762515962124, 37.918427512049675, 38.25739972293377, 40.69975666701794, 47.43562862277031, 53.29437464475632, 53.59529189765453, 54.70571391284466, 52.24206291139126, 57.54639208316803, 58.317974880337715, 58.266499042510986, 57.22978167235851, 59.659185111522675, 58.614898547530174, 50.931129455566406, 18.541245684027672, 9.957731422036886, 9.827276822179556, 3.4139695577323437, 1.3707269285805523, 0.2635336120147258, 0.06044374626071658, 8.923148587346077, 48.26481632888317, 49.858458414673805, 39.809719026088715, 36.964351907372475, 51.88787631690502, 57.62336455285549, 38.1077865511179, 7.627638503909111, 0.07321437486098148, 0.054891153195057996, 0.038491626546601765, 0.07342304452322423, 0.033601144241401926, 0.014427606874960475, 0.10370485164457932, 0.08484211459290236, 0.04760272495332174, 0.05241718907200266, 0.09947796439519152, 0.05069165119493846, 0.05188839400943834, 0.007006708983681165, 0.053815232022316195, 0.05609554013062734, 0.24246225832030177, 0.1507605766528286, 0.10154567688005045, 0.15075118106324226, 0.20899579161778092, 0.2123518130974844, 0.08882816007826477, 0.12248117302078754, 0.14894117193762213, 0.16283693723380566, 0.14970629650633782, 0.1194863325508777, 0.06354441327857785, 0.20220488804625347, 0.2670216764090583, 0.10168373119086027, 0.17450072307838127, 4.360228506848216, 36.5850904583931, 56.17934703826904, 55.223352536559105, 38.404657021164894, 43.619546592235565, 52.714312970638275, 57.85163730382919, 36.62718079984188, 4.645094946026802, 0.10181752557400614, 0.6918314890936017, 11.903639305382967, 18.378175534307957, 13.844608403742313, 20.619464367628098, 18.27622890472412, 31.53336603194475, 51.23516634106636, 53.0351297557354, 54.73116494715214, 51.103883385658264, 49.10135664045811, 44.41301241517067, 44.3859388679266, 40.34575626254082, 41.08210735023022, 38.166421204805374, 39.39866468310356, 50.21782413125038, 53.788826912641525, 49.11701940000057, 51.42018601298332, 50.02506427466869, 47.42887258529663, 42.79116444289684, 40.92740245163441, 37.08800867199898, 41.18004709482193, 39.00626353919506, 43.913297429680824, 45.33156752586365, 48.67641024291515, 47.01067842543125, 44.662237241864204, 37.88587465882301, 40.836408734321594, 38.00526425242424, 38.39204169809818, 38.76384034752846, 38.75518441200256, 39.21439737081528, 39.5136921107769, 38.57600502669811, 39.366244822740555, 41.374999433755875, 41.27946116030216, 39.376295283436775, 40.6394387036562, 37.47419334948063, 39.48379911482334, 39.82272192835808, 39.92390289902687, 37.14769206941128, 41.89894571900368, 41.33513577282429, 45.57745233178139, 47.7453576028347, 50.904409289360046, 52.89754293859005, 58.04649844765663, 42.42714777588844, 47.76157133281231, 56.97753220796585, 50.83132401108742, 50.919509679079056, 47.78427131474018, 53.060288205742836, 51.58998750150204, 52.4707118421793, 54.349524825811386, 49.6717744320631, 41.46861881017685, 40.38183152675629, 38.95421773195267, 39.78748261928558, 38.95701818168163, 39.106692150235176, 39.24818895757198, 39.36912126839161, 41.20234049856663, 40.60185872018337, 40.09590446949005, 38.98870088160038, 39.241664707660675, 40.81585943698883, 39.506791681051254, 39.25374045968056, 41.070829555392265, 47.95286066830158, 50.41135534644127, 52.38444127142429, 49.67528164386749, 49.1742367297411, 56.02902710437775, 55.068982020020485, 55.756995901465416, 52.67220363020897, 53.681611865758896, 53.283199444413185, 52.07474268972874, 46.20598800480366, 40.378366112709045, 39.91064541041851, 43.19259770214558, 50.132701098918915, 54.88719217479229, 57.13077798485756, 57.931782603263855, 52.99848832190037, 60.312529653310776, 60.57482197880745, 61.38668641448021, 60.055933222174644, 61.84647314250469, 61.9257976859808, 51.72368332743645, 19.91233181208372, 7.304577464237809, 9.297661241143942, 4.602376688271761, 5.6615332793444395, 0.4425561073003337, 0.12136510908021592, 10.196128729730844, 53.72454576194286, 60.06118834018707, 49.172367230057716, 44.664980694651604, 56.96978822350502, 65.30248269438744, 45.496011301875114, 9.97779244557023, 0.2069199303514324, 0.14625152485677972, 0.1907168873003684, 0.16928146564168856, 0.1940083270892501, 0.1710807136259973, 0.12165569700300694, 0.1863053982378915, 0.09508462084340863, 0.10654824203811586, 0.14537724520778283, 0.22387465025531128, 0.2047441908507608, 0.10941783766611479, 0.1160196123237256, 0.15577535756165162], [0.01654128613154171, 0.11088095954619348, 0.0615969695354579, 0.04393497918499634, 0.05783411754237022, 0.08160658078850247, 0.03804234889685176, 0.047654578811489046, 0.0251337643203442, 0.006332769316941267, 0.11191038516699336, 0.00473648156003037, 0.0751351346843876, 0.01175864623292, 0.009099837243411457, 0.023594724443682935, 0.10968369722831994, 0.8921939064748585, 24.813280329108238, 49.41495381295681, 46.16899698972702, 39.51723352074623, 19.28442880511284, 23.57556514441967, 41.116278916597366, 33.10927256941795, 6.179887214675546, 0.06298186533967964, 0.19038237165659666, 3.660865821875632, 6.457195859402418, 3.1686065113171935, 6.1402002442628145, 11.639982853084803, 25.85589688271284, 45.659687519073486, 52.632788345217705, 48.83684903383255, 46.5034132450819, 43.36855486035347, 40.40824390947819, 37.84832887351513, 35.75276792049408, 36.18493013083935, 34.293034449219704, 40.3585159778595, 47.6111564040184, 47.39339768886566, 45.186928287148476, 48.129760175943375, 42.949163764715195, 40.72750277817249, 37.72056072950363, 35.23179687559605, 34.666562005877495, 33.19803200662136, 33.708876594901085, 35.046401023864746, 38.369045332074165, 38.332479894161224, 36.485231816768646, 35.35641498863697, 34.655679389834404, 36.450277492403984, 35.82635477185249, 33.12511391937733, 35.916782319545746, 36.08861289918423, 34.61595632135868, 35.94604454934597, 34.75391171872616, 36.14746034145355, 36.418036222457886, 36.146400198340416, 34.66586284339428, 33.89930337667465, 33.89863461256027, 36.22405283153057, 35.16522064805031, 33.92063923180103, 35.88624335825443, 36.85534715652466, 34.39698547124863, 36.69608250260353, 42.179180681705475, 46.39411211013794, 44.55524638295174, 48.960851579904556, 39.47661750018597, 42.47282512485981, 53.075267001986504, 44.56854186952114, 46.1617773771286, 43.906575590372086, 44.79714520275593, 43.19739304482937, 45.128719210624695, 43.18809874355793, 38.405945152044296, 35.97817562520504, 36.56841315329075, 34.54694442451, 37.15486228466034, 37.598059102892876, 34.907016903162, 36.95834442973137, 36.77307017147541, 37.813682332634926, 37.46532082557678, 34.5156455039978, 36.734528839588165, 37.52249255776405, 36.30482129752636, 36.67139522731304, 36.53800718486309, 39.741854667663574, 44.61165435612202, 47.15526066720486, 45.57794250547886, 47.551150023937225, 47.11274854838848, 45.858295261859894, 48.27123798429966, 48.63647058606148, 47.88544088602066, 50.51167756319046, 49.39085550606251, 51.82441212236881, 50.81860229372978, 43.5141858458519, 35.761408656835556, 35.801762491464615, 39.67915803194046, 47.327551022171974, 54.18431729078293, 53.16284090280533, 53.03404301404953, 54.900609254837036, 56.99379913508892, 58.698395267128944, 52.80979044735432, 58.536641746759415, 57.7892142534256, 39.07263457775116, 11.578769087791443, 7.959682261571288, 7.999918777495623, 2.362771639600396, 1.9981755036860704, 0.17259644635487348, 0.05721480272768531, 8.289239052683115, 44.51540932059288, 53.256752863526344, 32.12218813598156, 23.341733291745186, 35.43754443526268, 50.632290691137314, 32.22544379532337, 6.708033224567771, 0.06550851452630013, 0.05779958541097585, 0.07736595638561994, 0.032029950816649944, 0.032926966159720905, 0.06055359153833706, 0.07163073561969213, 0.027230941923335195, 0.057177075650542974, 0.02934992382506607, 0.04437736228283029, 0.04754541630973108, 0.047118948568822816, 0.05783408414572477, 0.029223133460618556, 0.06094704112911131, 0.03494713666441385, 0.012620157231140183, 0.00629010046395706, 0.04219151844154112, 0.0028958500297449064, 0.0030751948861507117, 0.02453854147461243, 0.03856718089082278, 0.029200625976955052, 0.03335880333906971, 0.03592324639612343, 0.047825840520090424, 0.05724713810195681, 0.02947619097540155, 0.02711798148084199, 0.035324433411005884, 0.024582409823779017, 1.6246659960597754, 29.6002159640193, 54.53544124960899, 52.43919253349304, 43.547472059726715, 27.16030228883028, 32.849909886717796, 48.55149954557419, 37.4190279096365, 6.382123287767172, 0.055096086143748835, 0.05250683308986481, 2.798826266080141, 8.413780219852924, 4.829129995778203, 5.536655355244875, 8.320366032421589, 26.422533877193928, 47.89589412510395, 55.84156036376953, 50.89642971754074, 48.89203727245331, 45.63681274652481, 42.25388087332249, 40.03427937626839, 38.391768112778664, 37.22875691950321, 36.14216722548008, 41.913924515247345, 50.37174627184868, 49.07289996743202, 45.47735810279846, 49.358747228980064, 44.47557985782623, 43.456455543637276, 38.611054345965385, 36.59797556698322, 37.001559510827065, 34.5800444483757, 34.65608596801758, 38.10821212828159, 39.94004063308239, 40.468113496899605, 38.96941311657429, 38.03202621638775, 35.457915142178535, 37.77965895831585, 36.16341568529606, 34.37274657189846, 36.72987788915634, 37.70028881728649, 36.952534541487694, 36.5417043864727, 35.862977206707, 37.401051074266434, 37.80288331210613, 37.93293513357639, 37.13314265012741, 35.868657901883125, 36.749868616461754, 36.945983693003654, 37.98260226845741, 36.01282596588135, 37.31054373085499, 37.64534756541252, 37.5662662088871, 39.466608837246895, 44.348890855908394, 47.06451773643494, 47.79091715812683, 52.57952660322189, 41.57290041446686, 46.798532009124756, 53.41961592435837, 47.51008182764053, 47.65862725675106, 46.84078574180603, 47.11921580135822, 45.63866704702377, 46.70126482844353, 45.38974620401859, 42.262438014149666, 39.00438264012337, 36.724649369716644, 36.44852578639984, 37.685876190662384, 39.4981699436903, 37.192495465278625, 38.49764943122864, 38.584512770175934, 38.738138526678085, 38.315612599253654, 36.583794727921486, 38.24862219393253, 39.47804622352123, 38.01520071923733, 38.7540178745985, 37.99051344394684, 41.303046494722366, 46.69351704418659, 49.002482146024704, 48.69303435087204, 47.48700566589832, 47.87951700389385, 46.522837802767754, 48.87621112167835, 51.49910397827625, 49.628635346889496, 50.79081818461418, 51.91204681992531, 53.69389660656452, 52.997310385107994, 45.14573089778423, 38.143911212682724, 39.35232236981392, 41.54235005378723, 49.8011688888073, 54.010503217577934, 55.59783384203911, 53.51609654724598, 56.060975790023804, 56.857637241482735, 60.59520788490772, 55.93704544007778, 60.82759961485863, 58.70545528829098, 42.29519225656986, 17.208947874605656, 11.458655633032322, 12.698170971125364, 5.9241994097828865, 1.6275977762416005, 0.07741625173366629, 0.11692160376696847, 8.571547754108906, 49.76992316544056, 52.87418559193611, 37.378541082143784, 26.229819618165493, 42.856406942009926, 59.17057693004608, 40.07595553994179, 7.952457424253225, 0.06884031230583787, 0.013168555196898524, 0.04795779808773659, 0.023919453014968894, 0.03073300136748003, 0.03470775693131145, 0.043286676082061604, 0.022292396279226523, 0.06935605299076997, 0.03709270044055302, 0.03294059199106414, 0.06682414939859882, 0.05988847879052628, 0.06750219778041355, 0.11148117890115827, 0.0077073975080566015, 0.1305622112704441, 0.16566174424951896, 0.11194354432518594, 0.09409966471139342, 0.09975733104511164, 0.12059159824275412, 0.15499392058700323, 0.10458064527483657, 0.07155971950851381, 0.11430349972215481, 0.1668019502540119, 0.12221051918459125, 0.14206947817001492, 0.11615863884799182, 0.12286785422475077, 0.12143887113779783, 0.13623276870930567, 2.050577304325998, 34.93524558842182, 63.18522870540619, 58.858210891485214, 52.39558607339859, 28.92133679240942, 34.81784328818321, 51.7379629611969, 44.20177415013313, 7.5633070059120655, 0.2081894184811972, 0.5649107589852065, 8.350516464561224, 16.038183197379112, 10.49125224351883, 12.42978472262621, 14.509681966155767, 29.683068618178368, 49.37572471797466, 57.54255808889866, 52.538162022829056, 50.50128132104874, 49.066607505083084, 44.92700323462486, 43.687608540058136, 40.90227819979191, 39.186012893915176, 38.60177904367447, 44.77183096110821, 52.74287223815918, 49.96685899794102, 46.60222314298153, 51.89127333462238, 47.3265440762043, 45.719173327088356, 42.898922860622406, 39.49608765542507, 39.1630507260561, 37.104283198714256, 36.272496432065964, 38.824773877859116, 41.433018520474434, 41.6151275485754, 39.98340770602226, 39.4039312005043, 39.159961491823196, 39.19081583619118, 38.82119067013264, 36.54750667512417, 40.674123242497444, 40.05726434290409, 38.898398727178574, 39.149523451924324, 38.27768303453922, 38.87368485331535, 40.615974962711334, 39.61622200906277, 38.88711333274841, 37.378294095396996, 38.46619851887226, 39.5976410061121, 40.17061986029148, 38.25404830276966, 39.271789491176605, 39.99682858586311, 39.46284703910351, 40.915026515722275, 47.292444705963135, 50.01466803252697, 51.50859586894512, 53.352838307619095, 43.87996941804886, 47.45785742998123, 57.01363407075405, 49.648880660533905, 50.43235681951046, 48.50508503615856, 48.15047666430473, 47.72170387208462, 49.56777401268482, 46.74581363797188, 42.31296010315418, 40.78447312116623, 38.629654347896576, 37.617628052830696, 39.8936565220356, 42.65599049627781, 38.09949539601803, 40.422227159142494, 40.73418661952019, 41.884768679738045, 41.40586517751217, 37.837298065423965, 40.155029296875, 41.226134821772575, 39.51297014951706, 41.26461535692215, 38.808712139725685, 44.48976829648018, 49.5822474360466, 51.365822330117226, 51.25969782471657, 48.475435227155685, 48.15502122044563, 45.412138402462006, 49.647208750247955, 51.699011251330376, 50.216258615255356, 53.0010911822319, 52.33796216547489, 56.80597521364689, 56.222714111208916, 47.33266934752464, 39.1928943246603, 40.21426051855087, 44.628126472234726, 52.40686006844044, 58.826775178313255, 56.98078863322735, 55.76502867043018, 56.21392898261547, 60.426458939909935, 61.51446595788002, 57.74876922369003, 62.629200741648674, 60.66757120192051, 42.488214299082756, 14.339969772845507, 11.092236544936895, 16.176273487508297, 5.17189915291965, 4.221163569018245, 0.4852621047757566, 0.33298355410806835, 10.293931681662798, 55.06902001798153, 65.23595586419106, 45.9890728443861, 35.06183199584484, 51.171686947345734, 64.783134162426, 49.46663863956928, 10.397982448339462, 0.22235563723370433, 0.11180954956216738, 0.17479560803622007, 0.1414900241070427, 0.10622652102028951, 0.21615736826788634, 0.25462718680500984, 0.14144948800094426, 0.15877341153100133, 0.18471582181518897, 0.11573666110052727, 0.17192165600135922, 0.12300018657697365, 0.14719203376444057, 0.17998581781284884, 0.08727848151465878], [0.02360132955800509, 0.04815308682736941, 0.0157970363216009, 0.07888292850111611, 0.029794394213240594, 0.05058264454419259, 0.0639006812707521, 0.007560969452242716, 0.015661510878999252, 0.010079606690851506, 0.04948893409164157, 0.10161691563553177, 0.028791485528927296, 0.03889890977006871, 0.031676948274252936, 0.06208615988725796, 0.036523591916193254, 0.4429498908575624, 15.101835541427135, 43.674651235342026, 48.33930753171444, 35.62359765172005, 21.396957747638226, 27.106719464063644, 36.201478242874146, 39.66970033943653, 9.426430631428957, 0.043534174910746515, 0.04470336178201251, 2.201825100928545, 3.936412073671818, 1.4314176281914115, 7.51246620900929, 7.177733620628715, 32.23556645214558, 43.8282959908247, 51.024615839123726, 49.61112968623638, 48.84240813553333, 44.15564842522144, 44.67061959207058, 38.93502876162529, 37.350080609321594, 33.517290875315666, 35.023822635412216, 42.7076069265604, 50.20076684653759, 49.318864569067955, 45.471521615982056, 48.099498599767685, 45.097830668091774, 42.082031294703484, 37.27535001933575, 36.09066478908062, 33.276687785983086, 32.16585919260979, 33.58406089246273, 35.214036628603935, 34.97961200773716, 34.606639221310616, 34.48839336633682, 34.12811569869518, 34.731690511107445, 33.89578476548195, 36.60973213613033, 35.33125653862953, 38.51401515305042, 37.20039904117584, 35.63600018620491, 34.734152778983116, 35.08145414292812, 35.85989937186241, 36.927676275372505, 35.774973928928375, 34.608706310391426, 34.909927546978, 35.874539986252785, 36.588837057352066, 34.766188859939575, 36.77268259227276, 35.5943164229393, 36.85798801481724, 36.58238120377064, 39.12810780107975, 43.71454529464245, 47.11697392165661, 45.967964977025986, 50.69443255662918, 38.19588102400303, 43.33901144564152, 49.6062583476305, 44.57026317715645, 43.22213351726532, 38.274521604180336, 38.68494898080826, 36.11111529171467, 37.16199070215225, 36.18235766887665, 37.29678846895695, 36.13413065671921, 37.02021270990372, 35.52960969507694, 36.52970843017101, 36.756867840886116, 36.93130508065224, 35.21996051073074, 36.824112832546234, 37.33512081205845, 36.719325855374336, 36.424450278282166, 34.64223191142082, 37.93874882161617, 35.91272793710232, 37.19280704855919, 35.33790998160839, 40.77253796160221, 43.72969888150692, 47.38951049745083, 51.310143917798996, 41.27807043492794, 46.7907690256834, 47.84392051398754, 49.11451913416386, 49.44640092551708, 49.90500211715698, 51.36614151299, 52.21381522715092, 50.092028081417084, 50.28186969459057, 50.43905965983868, 44.1829651594162, 36.35770685970783, 36.03924594819546, 40.42614094913006, 46.159106120467186, 52.575601413846016, 53.834325671195984, 53.48390847444534, 55.70451691746712, 54.288819283246994, 57.33819745481014, 62.906266674399376, 53.304337710142136, 33.8841649889946, 10.54369417950511, 16.621187813580036, 17.228321135044098, 5.228953566402197, 0.19726672646356747, 0.14510472858091816, 0.089668679429451, 7.180608166381717, 39.631698578596115, 55.10514087975025, 43.676836118102074, 36.52370095252991, 41.35185867547989, 50.846500396728516, 33.31181690096855, 6.099589923396707, 0.08510205181664787, 0.0895238715747837, 0.026669729850254953, 0.06012514226313215, 0.08341443026438355, 0.10031782323494554, 0.042306762843509205, 0.03669306133815553, 0.05864052778633777, 0.04357855534180999, 0.03683631068270188, 0.044007950855302624, 0.09592801230610348, 0.025809897961153183, 0.06261414600885473, 0.03571312212443445, 0.0331359141273424, 0.06469831932918169, 0.04348805043264292, 0.06717258773278445, 0.022665123251499608, 0.02153642795747146, 0.05663487369020004, 0.028592905364348553, 0.025281720736529678, 0.04565921088214964, 0.05103334340674337, 0.0594766870199237, 0.02318295864824904, 0.06459303083829582, 0.013093016623315634, 0.08421172693488188, 0.03173353703459725, 0.8603345754090697, 19.26959440112114, 51.73751078546047, 53.991903215646744, 40.90729773044586, 22.0639568567276, 29.861111864447594, 44.050732254981995, 43.31766799092293, 9.917059354484081, 0.06269515884923749, 0.14496027695713565, 1.854787941556424, 7.881364189088345, 6.59025426954031, 4.899566816166043, 5.919996360316873, 30.036708042025566, 45.80167829990387, 51.54383137822151, 51.160762533545494, 50.73116898536682, 46.62391997873783, 47.69324339926243, 41.3886559009552, 40.13626590371132, 36.02152369916439, 36.002885699272156, 44.819412007927895, 53.14307436347008, 48.05479779839516, 45.875781923532486, 49.48578581213951, 48.263619393110275, 43.8895221054554, 40.1832427829504, 36.3605111092329, 35.959013253450394, 34.81758110225201, 35.081146359443665, 37.004055976867676, 37.17817023396492, 36.123058050870895, 36.416596099734306, 35.706740990281105, 36.23669475317001, 35.605278834700584, 37.6903485506773, 37.21267618238926, 38.61983947455883, 39.03006926178932, 37.140331864356995, 36.210061982274055, 36.5594532340765, 37.76605948805809, 37.71488003432751, 36.293710693717, 36.18733540177345, 36.146100014448166, 38.109207674860954, 37.58435323834419, 37.398341819643974, 37.7937638014555, 36.62242725491524, 38.76633681356907, 38.184781819581985, 41.5316042304039, 44.762266874313354, 48.82483407855034, 48.626993894577026, 51.16986684501171, 40.321665555238724, 46.432809233665466, 52.826460152864456, 46.46907068789005, 45.35569243133068, 39.93025615811348, 39.95755009353161, 37.358964532613754, 39.332647025585175, 38.496327102184296, 38.72324712574482, 38.97686071693897, 37.555679976940155, 38.33328925073147, 38.160512521862984, 38.85473906993866, 38.15447084605694, 36.71385794878006, 38.038394674658775, 37.8417856246233, 38.28909382224083, 37.625026255846024, 37.51131735742092, 38.58536772429943, 37.62387491762638, 38.63428629934788, 37.81903624534607, 43.05633321404457, 47.14427925646305, 50.21902106702328, 52.38421328365803, 42.9321900755167, 47.13229849934578, 49.18007701635361, 49.6190332621336, 52.09311090409756, 51.80159814655781, 51.69776871800423, 54.117342084646225, 51.81817285716534, 52.606231570243835, 52.089960873126984, 46.12821377813816, 38.237192407250404, 38.79090629518032, 42.8152247518301, 50.23407205939293, 54.95230548083782, 55.572576597332954, 55.7568971067667, 57.7915321290493, 55.56419424712658, 60.52012391388416, 62.57847726345062, 58.81005987524986, 35.45797973871231, 16.17697075009346, 10.5638587474823, 9.371562525629997, 4.837297182530165, 2.026713634841144, 0.12512908171629533, 0.1445851064636372, 9.264449123293161, 41.74344286322594, 62.03073665499687, 49.29735392332077, 39.73431587219238, 47.168757542967796, 56.963780745863914, 39.48693014681339, 8.030985910445452, 0.07728052034508437, 0.11515406033140607, 0.04979496239684522, 0.023397684235533234, 0.014255770929594291, 0.08135087380651385, 0.05331862390448805, 0.026981702758348547, 0.03626438570790924, 0.13555633078794926, 0.013678257582796505, 0.06722065663780086, 0.09613979156711139, 0.03923757030861452, 0.028126647375756875, 0.008581445235904539, 0.07022320060059428, 0.1264285674551502, 0.1624712662305683, 0.25335455196909606, 0.11667575250612572, 0.1377084106206894, 0.1462007174268365, 0.1119363826001063, 0.1264651701785624, 0.14905638294294477, 0.13238192768767476, 0.18497229320928454, 0.21607806236715987, 0.11339124437654391, 0.10985397559124976, 0.27496016293298453, 0.09005016559967771, 1.1308786924928427, 22.203806452453136, 58.801168352365494, 61.78561180830002, 48.868873715400696, 30.597858130931854, 35.93143053352833, 48.1212904304266, 50.875063464045525, 12.432146295905113, 0.2649455628124997, 0.23363552492810413, 7.579084234312177, 9.187863282859325, 8.245987873524427, 15.462801922112703, 9.410992059856653, 33.29520419239998, 46.25235691666603, 53.55402231216431, 53.683891743421555, 53.585655614733696, 48.37589576840401, 49.90444354712963, 43.26869621872902, 42.63483323156834, 36.664194613695145, 38.026972487568855, 45.918442234396935, 55.244498401880264, 50.13823740184307, 47.51656047999859, 51.0131860524416, 49.7772453725338, 47.11297273635864, 41.69477507472038, 39.693095684051514, 38.37928578257561, 36.286285892128944, 36.87331639230251, 39.58155646920204, 39.57449644804001, 38.16996641457081, 38.4682922065258, 37.67749764025211, 38.942708149552345, 36.67968638241291, 40.28347000479698, 39.50769603252411, 42.91300870478153, 41.6680359095335, 39.674358889460564, 39.172770604491234, 39.39807191491127, 40.34299001097679, 40.517001673579216, 38.4333036839962, 38.324135541915894, 38.007935509085655, 41.296803429722786, 40.853344425559044, 39.110678136348724, 41.95224165916443, 39.28917355835438, 40.30623838305473, 40.76501436531544, 43.28988768160343, 48.050773814320564, 49.82752427458763, 51.603697165846825, 52.315687760710716, 43.11838008463383, 49.9237085133791, 54.10872034728527, 48.633088767528534, 48.77677045762539, 42.42001935839653, 42.1754302829504, 39.92987617850304, 41.257038563489914, 39.796514734625816, 41.47002473473549, 40.601277351379395, 40.381272956728935, 40.052130818367004, 39.77985642850399, 40.897216871380806, 39.92302134633064, 38.077334985136986, 40.962995141744614, 40.38289166986942, 39.971863925457, 39.49353039264679, 38.744320794939995, 42.209073677659035, 39.48923662304878, 40.32842919230461, 41.602869406342506, 44.8938500136137, 50.350201427936554, 51.839995086193085, 55.24829059839249, 45.2508370578289, 46.122479885816574, 48.96035000681877, 51.28497786819935, 54.27289053797722, 51.67697623372078, 56.08367957174778, 57.0665842294693, 53.85904334485531, 53.26114162802696, 53.21157708764076, 50.19152194261551, 42.35549122095108, 39.92524802684784, 44.73738580942154, 52.14577227830887, 57.72139549255371, 57.23346747457981, 57.88605585694313, 58.274824395775795, 58.778814151883125, 62.466873452067375, 65.8038429915905, 58.499468341469765, 35.9804593026638, 13.598345518112183, 22.12942734360695, 35.060608461499214, 15.36877691745758, 2.674672440625727, 0.20304066507378593, 0.2911982947262004, 10.64374566078186, 49.959456995129585, 66.81559950113297, 57.0232779532671, 47.60565049946308, 54.04422640800476, 65.87974011898041, 49.164699241518974, 9.397974908351898, 0.28537371195852757, 0.2006260133930482, 0.14734767697518691, 0.13938717835117131, 0.0842755961639341, 0.19242774549638852, 0.168972049432341, 0.1394576081656851, 0.1846889263833873, 0.18002164870267734, 0.1482544033206068, 0.1408904726849869, 0.14107871102169156, 0.14217161253327504, 0.17179419955937192, 0.22123018512502313], [0.061316322680795565, 0.040016984930844046, 0.07102320611011237, 0.008899263484636322, 0.03668144672701601, 0.044813388885813765, 0.014209562959877076, 0.023599386986461468, 0.06574181606993079, 0.03759790262847673, 0.07350046536885202, 0.018096656967827585, 0.026246969136991538, 0.0331811517389724, 0.00894081447768258, 0.027724288302124478, 0.09363085002405569, 0.10470106615684927, 12.573522459715605, 40.22420458495617, 45.53577996790409, 38.90805020928383, 23.894962705671787, 27.186403088271618, 37.28536248207092, 41.88822269439697, 15.340059958398342, 0.1943422044860199, 0.1351869193604216, 0.9917540266178548, 9.022216871380806, 4.538256078958511, 1.7356277606450021, 4.145948505029082, 21.343236230313778, 44.38914969563484, 47.97519966959953, 51.32513411343098, 48.94877962768078, 48.18334490060806, 46.085367277264595, 44.205239564180374, 38.33244189620018, 36.48389808833599, 34.191659688949585, 46.503432244062424, 48.9099495112896, 48.811857774853706, 47.37386293709278, 46.145677641034126, 45.89477330446243, 42.093172296881676, 40.42115181684494, 39.29731272161007, 34.59341213107109, 31.791337989270687, 32.29026451706886, 33.718987852334976, 34.51624967157841, 33.82057160139084, 33.226564675569534, 35.82315534353256, 36.80066429078579, 36.52166046202183, 34.509208649396896, 35.20853452384472, 35.675381273031235, 36.03281669318676, 34.55873519182205, 33.84979583323002, 35.32484248280525, 35.789568945765495, 35.150184854865074, 35.17913930118084, 34.40437987446785, 35.27104116976261, 35.58872692286968, 34.87666793167591, 36.34571090340614, 36.51378348469734, 37.70245470106602, 39.28834140300751, 39.787733405828476, 42.5372164696455, 46.97347842156887, 46.514485850930214, 49.09202814102173, 48.493932634592056, 37.647794634103775, 46.290544867515564, 50.01846022903919, 44.478300511837006, 43.271720856428146, 37.13512234389782, 36.99737213551998, 34.66919146478176, 35.91641753911972, 37.271421030163765, 37.89542734622955, 37.33712710440159, 37.8461591899395, 35.5667906999588, 38.08436460793018, 37.297001257538795, 38.318709433078766, 36.18528351187706, 40.17714411020279, 38.61665524542332, 38.297175988554955, 36.535043343901634, 34.612452909350395, 34.99912776052952, 36.0079850256443, 36.305391266942024, 35.2266101539135, 39.538056403398514, 49.52896289527416, 43.962261602282524, 48.055352568626404, 46.931403279304504, 52.296058014035225, 50.02803571522236, 50.253044441342354, 48.80050018429756, 48.59358228743076, 47.20530018210411, 48.80108915269375, 50.09412556886673, 50.40588743984699, 52.73070529103279, 49.32943180203438, 44.13902811706066, 35.72194777429104, 35.76383672654629, 43.549873530864716, 47.721384689211845, 53.17037209868431, 52.53094621002674, 50.90867646038532, 54.34780351817608, 53.626685813069344, 59.59053419530392, 48.85912723839283, 23.123024627566338, 13.292443882673979, 6.544684264808893, 6.206475337967277, 3.489829399622977, 0.99161485908553, 0.16295502777211368, 0.014874036533001345, 9.149676281958818, 44.0443067997694, 45.86254723370075, 35.032482370734215, 28.726536445319653, 38.365777507424355, 50.245121866464615, 32.184500992298126, 4.765260173007846, 0.14069102791836485, 0.033340988084091805, 0.039738798295729794, 0.018387593700026628, 0.0347965400578687, 0.011802326262113638, 0.08135246200254187, 0.03370914528204594, 0.07353297885856591, 0.05251819908153266, 0.06910076903295703, 0.010692742198443739, 0.0234565847858903, 0.09516559657640755, 0.014281115272751777, 0.03832383437838871, 0.07075739107676782, 0.07539697180618532, 0.009807540918700397, 0.01029633700454724, 0.03036613365111407, 0.02104769773723092, 0.012978714748896891, 0.025416932621737942, 0.052700121741509065, 0.030895425952621736, 0.05517964826140087, 0.029482360077963676, 0.022235913274926133, 0.02741071421041852, 0.14352195023093373, 0.015621876482327934, 0.00990017579169944, 0.26749579003080726, 15.247642267495394, 47.106551080942154, 54.1345551609993, 46.15151412785053, 30.90854275971651, 29.80313267558813, 43.883301839232445, 49.47526037693024, 15.968819819390774, 0.18521583639085293, 0.05794701304694172, 0.7730682799592614, 3.73866047244519, 9.17030157521367, 4.84614928252995, 4.41725442185998, 26.068383380770683, 46.881831139326096, 50.28013318777084, 53.127954974770546, 51.07714042067528, 50.46250440180302, 48.534613251686096, 44.66151528060436, 41.65365368127823, 37.95029640197754, 35.857106521725655, 49.39773313701153, 51.09217621386051, 49.992488622665405, 46.99307017028332, 47.2918975353241, 47.367399483919144, 44.491599798202515, 42.01003275811672, 39.86704275012016, 35.229232013225555, 33.684022128582, 35.2361286431551, 35.975196585059166, 36.14245980978012, 35.85367530584335, 35.75041584670544, 37.39986173808575, 37.96906739473343, 37.821312323212624, 36.495092287659645, 36.0603766143322, 37.4545294046402, 37.805904150009155, 35.934960544109344, 36.26778848469257, 37.453875839710236, 37.461996003985405, 37.44260564446449, 36.47811479866505, 36.108489632606506, 37.574219182133675, 38.30473378300667, 37.253250405192375, 38.35424892604351, 38.03253918886185, 38.44672456383705, 39.56946551799774, 41.22712656855583, 43.538329750299454, 49.157943204045296, 49.07941661775112, 50.41265107691288, 50.04971355199814, 38.819028586149216, 48.27713526785374, 50.466482788324356, 47.418791726231575, 43.62737417221069, 38.69519703090191, 38.8504832983017, 37.27499283850193, 36.29328891634941, 37.94326677918434, 38.37052345275879, 40.871568247675896, 39.13470424711704, 36.67366750538349, 38.45898650586605, 39.33122210204601, 38.65229353308678, 38.20550210773945, 40.84436930716038, 40.879646614193916, 39.40490014851093, 39.10393349826336, 35.879840701818466, 37.67017923295498, 36.8822231143713, 37.45747424662113, 37.0392344892025, 41.784438863396645, 49.84692983329296, 46.53279706835747, 51.54880531132221, 47.64621712267399, 52.11851254105568, 50.306838154792786, 53.51503260433674, 51.84838883578777, 50.25238707661629, 49.638830199837685, 51.885820627212524, 52.108355686068535, 52.723006904125214, 55.15160098671913, 50.182258039712906, 44.97415870428085, 38.71174894273281, 37.70568832755089, 45.84400422871113, 50.761495158076286, 54.338779002428055, 55.01229286193848, 55.541836246848106, 55.74556611478329, 56.12978629767895, 60.682394206523895, 50.046837106347084, 26.59023977816105, 18.172439374029636, 11.328046191483736, 10.727082788944244, 6.974680591374636, 1.6375370929017663, 0.3130394039908424, 0.06113541305239778, 10.723239295184612, 49.45785351097584, 52.372616305947304, 44.34061489999294, 35.17073415219784, 44.82498250901699, 58.27406443655491, 40.03581449389458, 6.706753168255091, 0.020548391912598163, 0.07925560537842102, 0.0452924934506882, 0.031120190942601766, 0.05163450157851912, 0.018824173203029204, 0.08621274260804057, 0.027015936175303068, 0.08731189300306141, 0.003288792177045252, 0.07560069134342484, 0.002970536061184248, 0.05211254487221595, 0.024272988048323896, 0.02617037021991564, 0.017301928128290456, 0.15441323455888778, 0.17620594095205888, 0.1447162142721936, 0.11832340940600261, 0.14939587097615004, 0.1848974105087109, 0.10206791877862997, 0.09087325190193951, 0.19103758415440097, 0.15137078531552106, 0.15467163553694263, 0.09623052654205821, 0.13764871226157993, 0.12502512166975066, 0.24363320408156142, 0.16145214904099703, 0.2517154742963612, 0.4439758654916659, 17.963528484106064, 52.59793661534786, 60.06447896361351, 50.86030125617981, 34.595817402005196, 35.548821464180946, 48.93069639801979, 53.715680837631226, 20.580854639410973, 0.35211208392865956, 0.45484930858947337, 3.2759146532043815, 16.249999031424522, 10.474117062985897, 4.69167759642005, 5.778930829837918, 23.728394843637943, 46.26146882772446, 49.81191471219063, 54.26194332540035, 52.85139441490173, 53.571410179138184, 51.8705340474844, 50.225777104496956, 43.30591522157192, 40.60080237686634, 39.35827285051346, 51.65880560874939, 53.579222559928894, 52.81289488077164, 47.919471859931946, 48.91662575304508, 48.686582297086716, 47.625538632273674, 43.9232224971056, 43.417625427246094, 37.03842133283615, 35.11114574968815, 36.35648712515831, 36.49021714925766, 38.014588952064514, 36.607178673148155, 37.84070648252964, 40.543292462825775, 40.674244835972786, 39.88410383462906, 38.51444453001022, 37.74631954729557, 40.435682237148285, 39.30770896375179, 37.41418696939945, 37.459149956703186, 39.550398141145706, 39.25212174654007, 39.11830812692642, 38.42751659452915, 37.7715577930212, 38.31960238516331, 41.0738617926836, 39.816972836852074, 40.982875674963, 40.97816772758961, 40.82573890686035, 42.919931933283806, 42.95548662543297, 46.36103868484497, 51.04341723024845, 51.49869740009308, 53.71476888656616, 50.545210763812065, 40.56654341518879, 50.992655754089355, 53.81763316690922, 51.130759343504906, 46.236538365483284, 41.24529339373112, 41.4372742921114, 37.940998300909996, 39.052925035357475, 42.031224220991135, 41.00982002913952, 42.395499274134636, 42.50376686453819, 38.25010031461716, 41.705042123794556, 41.787140518426895, 41.39224670827389, 40.14807187020779, 43.285730704665184, 42.16352552175522, 40.81235222518444, 40.742751359939575, 37.89158575236797, 39.40176151692867, 39.20332856476307, 39.253147691488266, 39.348845556378365, 43.26763987541199, 55.082718282938, 49.24022018909454, 53.76869559288025, 52.50472001731396, 53.68119768798351, 52.731556445360184, 55.25775969028473, 53.40511590242386, 53.73165898025036, 52.85775147378445, 53.79194654524326, 53.82031962275505, 53.673335909843445, 54.61177535355091, 52.97403663396835, 48.573424369096756, 41.45363621413708, 39.326723143458366, 48.838087767362595, 51.7914754897356, 56.574286445975304, 56.45578980445862, 57.49018929898739, 57.11184740066528, 56.53298266232014, 60.14844685792923, 51.346656158566475, 25.1019299402833, 17.92758621275425, 16.57817792147398, 13.884502463042736, 12.909458633512259, 3.680218420922756, 0.412386023090221, 0.18677958607440814, 12.860395666211843, 55.33144533634186, 57.59261280298233, 47.271599024534225, 40.55041328072548, 54.38762538135052, 65.39872393012047, 50.04875220358372, 9.497539065778255, 0.18451429903507233, 0.17260517401155084, 0.11579661178984679, 0.3578134108101949, 0.14828048238996416, 0.14476589363766834, 0.16914164501940832, 0.13105311227263883, 0.19506526412442327, 0.08455307775875553, 0.2018647172371857, 0.11118794151116163, 0.1588592038024217, 0.22533142677275464, 0.10297492714016698, 0.07058351329760626], [0.009348518869956024, 0.049146243691211566, 0.013847258524037898, 0.05071771542134229, 0.018127044204447884, 0.042603124675224535, 0.054159826031536795, 0.0458074363268679, 0.015597246456309222, 0.04643092201149557, 0.016047592798713595, 0.015613022660545539, 0.06938011341844685, 0.017008811337291263, 0.028886697509733494, 0.030490018507407513, 0.033775630581658334, 0.04437272385985125, 5.388220120221376, 34.67864915728569, 46.661336570978165, 43.20905841886997, 29.139811769127846, 32.180469408631325, 34.90710809826851, 49.27721880376339, 19.41819492727518, 0.9247301949653774, 0.08156994095770642, 0.36214149731677026, 4.4122652895748615, 11.344469860196114, 4.409428741782904, 0.9394642012193799, 19.196695312857628, 42.42390275001526, 47.04315148293972, 48.7664920091629, 50.83523020148277, 50.01356989145279, 49.140251353383064, 46.53039559721947, 41.28380432724953, 35.01568727195263, 33.95452581346035, 35.524844750761986, 46.800143122673035, 45.43649509549141, 48.13411094248295, 44.428941160440445, 47.41008639335632, 48.79177965223789, 43.27814631164074, 41.35443113744259, 37.97344096004963, 35.34667611122131, 34.24254655838013, 35.00535562634468, 35.07413953542709, 34.63057033717632, 34.9102733284235, 36.47684566676617, 36.464006155729294, 35.7305733114481, 36.904307529330254, 37.02979199588299, 34.76145811378956, 36.950315460562706, 39.821467995643616, 34.99498598277569, 32.40967310965061, 35.76953262090683, 34.63873229920864, 35.93015760183334, 33.539550080895424, 35.42433254420757, 35.052727684378624, 36.09444938600063, 35.32768093049526, 36.46720938384533, 37.204981595277786, 39.077851697802544, 42.0075248926878, 45.721950978040695, 46.75934851169586, 48.346591740846634, 47.99213916063309, 48.0774711817503, 38.85852746665478, 43.735216185450554, 48.80095236003399, 46.493906155228615, 42.927812710404396, 36.921725794672966, 35.117556005716324, 35.5319731682539, 36.67441986501217, 36.9710623472929, 36.00512757897377, 37.79733560979366, 37.25532129406929, 35.841208174824715, 36.909600645303726, 35.53115241229534, 36.82722106575966, 37.20683969557285, 38.358789682388306, 37.78217442333698, 36.8685894459486, 36.615625619888306, 36.2287949770689, 35.044231340289116, 35.99247045814991, 35.12140139937401, 34.00999143719673, 38.03782470524311, 47.88843892514706, 51.92110173404217, 45.4007314145565, 52.41459645330906, 45.513505563139915, 47.326110899448395, 44.249351397156715, 45.51355876028538, 44.97982420027256, 45.416287779808044, 40.74611037969589, 47.98399619758129, 48.9111540466547, 48.32673400640488, 52.66927398741245, 50.09759858250618, 43.3172994107008, 36.208226680755615, 35.57929962873459, 42.93135792016983, 48.325472474098206, 53.74699495732784, 50.79078398644924, 55.478189662098885, 55.61342440545559, 51.2923988699913, 43.712269216775894, 20.106759779155254, 14.953585546463728, 6.773476637899876, 3.5772546334192157, 3.4108012402430177, 1.3074042764492333, 0.18839585012756288, 0.11368260413291864, 7.727617314085364, 42.89588302373886, 52.489634826779366, 38.307218849658966, 36.3174632191658, 45.027093663811684, 45.40228173136711, 33.00633989274502, 3.0670341616496444, 0.10665163805242628, 0.03800265141762793, 0.08190912471036427, 0.06998267053859308, 0.062222459018812515, 0.019759336792048998, 0.04100293925148435, 0.02900517953094095, 0.05357031215680763, 0.0887811450229492, 0.05971444144961424, 0.05678388952219393, 0.043273491828585975, 0.0481614990712842, 0.06987607586779632, 0.028885840329166967, 0.008003967141121393, 0.04450381682545412, 0.021375830910983495, 0.05576026007474866, 0.03503270629153121, 0.030901886348146945, 0.05247413777397014, 0.09178834967315197, 0.009287493921874557, 0.04826321041036863, 0.0265294917699066, 0.02984418304549763, 0.06407379463780671, 0.03108269393123919, 0.022171455893840175, 0.03577388917619828, 0.06136532669188455, 0.03783551976084709, 8.496931158006191, 40.58548539876938, 53.100607842206955, 47.387705594301224, 28.71078249067068, 30.743910893797874, 38.26855592429638, 51.51429556310177, 22.30407927185297, 0.9305651381146163, 0.13918998971348628, 0.9296210668981075, 5.15060224570334, 7.588971303775907, 4.871650189161301, 5.15040323138237, 22.22295932471752, 42.88561597466469, 50.265101194381714, 49.60288032889366, 51.71399764716625, 52.464825958013535, 50.73664449155331, 47.75382734835148, 42.654751762747765, 36.76746927201748, 36.753839403390884, 38.68819780647755, 48.64261105656624, 47.68839105963707, 49.87844914197922, 45.71006901562214, 48.43650631606579, 50.67139819264412, 45.07380835711956, 41.69917143881321, 38.96665446460247, 36.951934173703194, 36.12748481333256, 36.84399336576462, 36.65770836174488, 36.21462933719158, 36.07431046664715, 38.486474230885506, 38.73962044715881, 36.25993050634861, 38.82847487926483, 38.314533457159996, 36.98077842593193, 38.502851352095604, 42.520311176776886, 37.45799861848354, 35.29116488993168, 38.12460444867611, 37.86413602530956, 37.438646256923676, 36.13620914518833, 36.0424567759037, 37.460707873106, 36.564731150865555, 36.55153065919876, 37.53602743148804, 40.39263054728508, 42.23773933947086, 43.31643685698509, 45.96185490489006, 49.394153729081154, 49.97678026556969, 51.48658365011215, 48.089714124798775, 41.74741365015507, 46.58702775835991, 51.42712064087391, 50.360939651727676, 44.75848987698555, 38.02901677787304, 37.94831670820713, 36.00743405520916, 37.60057456791401, 38.23220707476139, 38.53469364345074, 38.88791888952255, 39.803278371691704, 37.06763416528702, 39.1229210793972, 37.55409546196461, 39.77864429354668, 37.20367446541786, 41.025851368904114, 39.892341792583466, 38.03255058825016, 37.64890797436237, 37.7594668418169, 37.270178496837616, 38.55840817093849, 36.63982272148132, 36.453210934996605, 38.72839964926243, 49.62442897260189, 52.8078031539917, 49.35857243835926, 54.34818349778652, 48.689120560884476, 50.56824132800102, 46.99893705546856, 48.89541909098625, 48.236572444438934, 46.6818630695343, 45.58746099472046, 51.14967852830887, 53.050572127103806, 52.96362139284611, 56.5013113617897, 52.299702018499374, 42.98173941671848, 38.14779460430145, 39.71912428736687, 46.635524556040764, 50.84521226584911, 55.71767941117287, 54.23190973699093, 56.91198952496052, 55.61182089149952, 52.346215322613716, 45.00994898378849, 24.891020357608795, 15.906468015164137, 10.008247811347246, 6.482121096923947, 4.588122703135014, 0.7091170584317297, 0.2501208957983181, 0.07381586328847334, 9.27164688706398, 48.45792956650257, 55.93711383640766, 42.48029552400112, 40.86122140288353, 50.30896224081516, 52.74308122694492, 41.62658013403416, 5.0229518953710794, 0.16569056926527992, 0.06743098128936253, 0.010774787551781628, 0.014137905818643048, 0.02973548438603757, 0.032983276614686474, 0.01947330751136178, 0.029477209573087748, 0.08934822006267495, 0.03850666616926901, 0.051451009276206605, 0.036697117175208405, 0.05772530385002028, 0.13632813468575478, 0.06889714597491547, 0.014972376666264609, 0.06636740203248337, 0.1372854012879543, 0.09914405731251463, 0.16558030096348375, 0.10776459981570952, 0.13116862013703212, 0.17548862553667277, 0.21887999639147893, 0.057337323887622915, 0.1260678391554393, 0.1260102484957315, 0.10667117880075239, 0.15993087989045307, 0.1162461974308826, 0.14259886695072055, 0.09570821042871103, 0.19265038979938254, 0.21798176021547988, 10.268828328698874, 46.8461624532938, 62.330973744392395, 54.92945730686188, 39.74812813103199, 43.246019035577774, 44.72575083374977, 60.51685228943825, 25.033455714583397, 1.3463723729364574, 0.2776015258859843, 1.1654239450581372, 12.438848186284304, 26.8377622961998, 10.200804378837347, 3.9504269091412425, 22.766537256538868, 44.32849355041981, 49.91749584674835, 50.096500441432, 52.83720597624779, 54.032207652926445, 54.327759593725204, 51.86519913375378, 45.16934283077717, 38.73955965042114, 37.707915008068085, 39.598974734544754, 51.46173678338528, 49.9419779330492, 50.95257930457592, 45.94155639410019, 50.65691716969013, 53.325817957520485, 48.323131799697876, 43.51065583527088, 41.937661841511726, 39.00059424340725, 37.684265077114105, 38.013285622000694, 40.56345038115978, 37.610982209444046, 38.713200464844704, 39.512726962566376, 40.92050962150097, 37.581328600645065, 41.078744530677795, 42.464005798101425, 38.965252339839935, 40.300021916627884, 43.95135618746281, 40.300983265042305, 36.6409170627594, 40.78545346856117, 39.71457973122597, 39.49604205787182, 37.09873929619789, 38.63913103938103, 39.180001616477966, 39.396293610334396, 39.526516422629356, 39.899424612522125, 42.513912320137024, 43.04367609322071, 46.23605579137802, 48.56156140565872, 54.06753055751324, 52.77445614337921, 52.44643874466419, 51.66453570127487, 43.44861276447773, 46.942920461297035, 54.4899994879961, 51.4765939861536, 46.906742602586746, 40.13494737446308, 39.8953702300787, 39.43459935486317, 39.45059269666672, 40.32278269529343, 39.66141678392887, 41.64780579507351, 41.48887172341347, 38.90876077115536, 41.47298477590084, 38.4745504707098, 41.27117000520229, 39.02354121208191, 41.98654241859913, 41.4837571978569, 40.557758286595345, 39.961517080664635, 39.832692593336105, 38.024761006236076, 39.73461225628853, 38.669031634926796, 38.51444453001022, 41.60495929419994, 52.79403269290924, 57.104430198669434, 51.04977808892727, 54.46343131363392, 52.33907550573349, 54.777742847800255, 49.82250854372978, 51.12623758614063, 50.64516820013523, 48.48669022321701, 47.53390274941921, 53.35416063666344, 55.2694820612669, 52.9565841704607, 57.49019309878349, 55.046095848083496, 46.732613146305084, 40.08466847240925, 39.73001450300217, 47.58584976196289, 54.23328526318073, 56.74092650413513, 57.532701417803764, 59.33581106364727, 57.50061973929405, 51.19256302714348, 46.07125863432884, 25.040819719433784, 17.59865116328001, 15.022031273692846, 10.501409098505974, 10.234141889959574, 2.0038839848712087, 0.7169904734473675, 0.24659321556100622, 10.115238670259714, 56.040430292487144, 64.02049228549004, 48.33950512111187, 48.91431167721748, 57.54827298223972, 59.62672345340252, 50.825259536504745, 7.952923374250531, 0.21305481990566477, 0.111479026672896, 0.14087708434090018, 0.132672730833292, 0.21525218558963388, 0.1001083297887817, 0.15697551425546408, 0.09396837878739461, 0.1679806737229228, 0.1641260032192804, 0.23936600337037817, 0.26870100817177445, 0.12989309092517942, 0.2882009680615738, 0.18797561642713845, 0.09037590905791149], [0.06698897297610529, 0.04648368871130515, 0.03064541866478976, 0.006892789779158193, 0.019695771843544208, 0.08322472247527912, 0.05563269602134824, 0.029099500934535172, 0.023583673864777666, 0.05786762179923244, 0.059992260721628554, 0.04433875576069113, 0.01788236553693423, 0.02258676729979925, 0.018297459864697885, 0.05975680694973562, 0.04118174118048046, 0.04082699088030495, 2.8420724580064416, 31.80457267910242, 48.21995973587036, 51.7854680120945, 39.8039623349905, 35.1718170940876, 43.27638320624828, 51.95238545536995, 28.69016669690609, 2.441504839807749, 0.08699300698935986, 0.7458247512113303, 4.4242161232978106, 10.509932041168213, 4.953228486701846, 3.770756400190294, 19.178524687886238, 34.12691496312618, 50.362277179956436, 48.22159744799137, 48.284123092889786, 50.639871284365654, 49.21674124896526, 48.334998562932014, 43.07686351239681, 34.55986373126507, 36.226268112659454, 36.14710696041584, 42.223763689398766, 48.64908970892429, 47.486048117280006, 47.2945573925972, 44.36479300260544, 46.0147100687027, 46.96907065808773, 45.532747730612755, 38.41845788061619, 34.51985567808151, 33.99938240647316, 34.682555347681046, 33.29811483621597, 35.80053895711899, 35.103029385209084, 33.881657123565674, 34.07445877790451, 35.61290882527828, 35.47279894351959, 35.0762028247118, 34.23316866159439, 34.502638801932335, 35.84997810423374, 36.6644150018692, 33.97963486611843, 35.20951867103577, 33.463531360030174, 35.654467195272446, 36.599974259734154, 35.61657942831516, 35.40545895695686, 34.886334612965584, 35.97947895526886, 38.576548397541046, 40.953066274523735, 44.857717752456665, 45.03475785255432, 47.392603531479836, 48.29680301249027, 50.16832798719406, 46.14699237048626, 46.82799942791462, 39.01025712490082, 42.83281400799751, 51.82437792420387, 45.97007006406784, 46.44616551697254, 45.904911160469055, 42.0949961990118, 39.10074546933174, 37.19345681369305, 36.007209867239, 36.145397052168846, 36.92874401807785, 35.15627972781658, 38.672504648566246, 37.404448091983795, 36.439045295119286, 35.06503902375698, 37.494016885757446, 37.08613157272339, 37.7978827804327, 36.99346214532852, 38.01232807338238, 36.384704411029816, 36.355856359004974, 35.54624140262604, 36.71181745827198, 37.93613076210022, 36.3208032399416, 41.587073653936386, 45.817477852106094, 47.15257041156292, 46.80615060031414, 46.5693549066782, 43.52186523377895, 43.260750845074654, 40.888074561953545, 40.07257752120495, 40.715430825948715, 43.543425276875496, 43.82179833948612, 49.8285274207592, 48.74105617403984, 47.86980852484703, 52.33650304377079, 49.07517984509468, 39.723539650440216, 35.848712772130966, 38.69077026844025, 41.84281513094902, 47.36321210861206, 50.89929856359959, 51.57641462981701, 56.36218562722206, 52.87890873849392, 43.28432098031044, 20.242205411195755, 17.562254816293716, 11.632496304810047, 8.055036719888449, 4.132605995982885, 1.2090933392755687, 0.20769030932569876, 0.2039975457591936, 9.533544033765793, 41.93474359810352, 45.03889963030815, 31.34269416332245, 23.980496115982533, 36.714667305350304, 44.447548761963844, 35.070693120360374, 0.8819596900139004, 0.3111967403674498, 0.052412309451028705, 0.036229100296623074, 0.1402521663112566, 0.05316112903528847, 0.06242826028028503, 0.020274433663871605, 0.03210069233318791, 0.06235093591385521, 0.035198372206650674, 0.010159989633393707, 0.0191054044989869, 0.08181198500096798, 0.02330018272914458, 0.047830709008849226, 0.02465021243551746, 0.021154793357709423, 0.04725958555354737, 0.032081904864753596, 0.028784242167603225, 0.056617737500346266, 0.08939369887229986, 0.026914024456345942, 0.027718926285160705, 0.07897640200098976, 0.053163258999120444, 0.037016155329183675, 0.02679657773114741, 0.026429520767123904, 0.04869268013862893, 0.04103933788428549, 0.08454926311969757, 0.01145601881944458, 0.035102894908050075, 4.320125933736563, 39.302746430039406, 54.334998205304146, 54.34510946273804, 44.10748980939388, 39.030422642827034, 43.21692019701004, 56.001714169979095, 30.525758899748325, 2.674899003468454, 0.07587712651002221, 0.10765521466964856, 3.8727080170065165, 7.037185812368989, 5.19586636684835, 6.15306350402534, 20.092628337442875, 35.52720442414284, 50.655051469802856, 49.43840995430946, 50.73180355131626, 50.885121524333954, 51.82394474744797, 51.46564677357674, 44.682113975286484, 36.63742505013943, 37.59175904095173, 38.58839236199856, 43.76037463545799, 49.59258288145065, 48.66797089576721, 46.44337646663189, 44.96015265583992, 48.475496023893356, 49.85311210155487, 46.57073803246021, 40.19255988299847, 36.151989698410034, 35.54539404809475, 38.04196648299694, 34.970621690154076, 37.605578899383545, 36.62048175930977, 36.87293641269207, 36.3023666292429, 37.190120592713356, 38.4132369607687, 37.41538390517235, 36.89995676279068, 37.68638916313648, 37.75848649442196, 36.83553121984005, 35.87830178439617, 37.383849397301674, 36.82295389473438, 37.79268465936184, 38.919039219617844, 37.32868775725365, 36.67856924235821, 36.903570368885994, 37.298106998205185, 39.63502340018749, 41.77874676883221, 45.97409024834633, 46.443946436047554, 49.277059212327, 50.17823405563831, 52.550450563430786, 48.95213484764099, 47.52429686486721, 42.5813814997673, 47.728938683867455, 53.47454957664013, 48.87210354208946, 49.472771510481834, 46.628897711634636, 42.41148121654987, 39.96871769428253, 37.45484858751297, 38.78254294395447, 37.52181999385357, 38.24589394032955, 37.36362688243389, 39.30714279413223, 39.31267909705639, 38.599392771720886, 38.80878433585167, 37.71205298602581, 38.0940692871809, 39.351513013243675, 37.85753197968006, 39.15729783475399, 38.54197405278683, 38.09000350534916, 37.03724719583988, 38.93641568720341, 39.53228071331978, 37.12669059634209, 42.701538652181625, 49.02496553957462, 49.476088732481, 49.40017260611057, 49.072147607803345, 46.66670188307762, 45.504595041275024, 44.09311518073082, 42.08270005881786, 42.6539272069931, 45.07494069635868, 46.76782205700874, 51.25259220600128, 49.802042841911316, 49.12770062685013, 54.83044981956482, 50.856790244579315, 40.84721155464649, 38.746954053640366, 40.195303335785866, 45.63261017203331, 52.80577406287193, 53.11475828289986, 54.7222126275301, 57.513364255428314, 54.37966100871563, 42.579375207424164, 24.9032860994339, 12.069906983524561, 7.414270928129554, 10.56431757286191, 5.335876978933811, 0.7185443525668234, 0.2290031875600107, 0.169135648466181, 9.701102692633867, 47.17531219124794, 51.2412042170763, 34.264505580067635, 32.05590069293976, 44.7316937148571, 51.64859555661678, 47.01926976442337, 3.1495469715446234, 0.3112431988120079, 0.05417327003669925, 0.019255847109889146, 0.06916047481354326, 0.05189659474126529, 0.03346524958033115, 0.05493858756381087, 0.03526033411617391, 0.0642120122211054, 0.037913066771579906, 0.029658881758223288, 0.024749474687268957, 0.02739768951869337, 0.08368863898795098, 0.04828176781302318, 0.01664821847953135, 0.1132963014242705, 0.13859434198820964, 0.07648222919669934, 0.146208836522419, 0.25375002762302756, 0.22639458300545812, 0.1252966289757751, 0.20162231696303934, 0.1832633200683631, 0.12105700647225603, 0.1735460094641894, 0.16997859464026988, 0.12437504483386874, 0.12084217698429711, 0.10255347631755285, 0.15784918534336612, 0.10566053693764843, 0.09534639859339222, 6.461758464574814, 44.521697983145714, 60.81156827509403, 61.59118764102459, 51.83046139776707, 44.30071324110031, 54.81593459844589, 63.108598217368126, 37.41952948272228, 3.5255268216133118, 0.35730192263145, 1.5818587993271649, 9.24109272658825, 19.86247468739748, 12.831236980855465, 8.273522146046162, 22.279678881168365, 37.110036090016365, 51.316523775458336, 50.838524624705315, 50.7588467001915, 54.305105209350586, 54.14979234337807, 54.331498593091965, 48.21146719157696, 39.99234102666378, 39.10569280385971, 40.43162025511265, 45.113550424575806, 53.69801178574562, 49.375211745500565, 48.596283942461014, 45.38544103503227, 48.7555105984211, 52.81222991645336, 49.38618175685406, 41.57934866845608, 37.391247600317, 36.81899830698967, 39.764870032668114, 36.25464878976345, 38.80919851362705, 37.593119367957115, 38.62873859703541, 36.8756190687418, 39.65048477053642, 40.21373614668846, 39.260469898581505, 38.327574357390404, 38.25036250054836, 39.18073117733002, 39.0718100219965, 36.92973956465721, 39.255932942032814, 38.46464440226555, 39.69571754336357, 42.430107817053795, 40.12192167341709, 39.216787442564964, 39.18871454894543, 38.65652270615101, 41.93479299545288, 43.390658274292946, 48.15381668508053, 50.58470584452152, 52.572162598371506, 52.666009962558746, 54.63664121925831, 49.72402922809124, 48.20531152188778, 44.74254973232746, 49.331194907426834, 54.900316670536995, 50.33685654401779, 51.652893126010895, 49.54763129353523, 45.116020292043686, 42.62312985956669, 40.2742251008749, 39.97705824673176, 40.26450142264366, 39.68310981988907, 38.55476796627045, 42.55156069993973, 41.62950977683067, 39.70441907644272, 40.275334641337395, 40.16590431332588, 40.459822341799736, 43.064886555075645, 40.14972098171711, 40.99122762680054, 39.68783676624298, 40.70476099848747, 40.66822975873947, 40.98723404109478, 42.821916192770004, 39.67270977795124, 46.266055181622505, 50.37335358560085, 54.30026426911354, 52.074089124798775, 51.37520782649517, 49.16177719831467, 48.678614124655724, 45.871640145778656, 44.61046501994133, 44.67633828520775, 47.48533755540848, 49.61002394556999, 53.70026886463165, 52.693748474121094, 49.543679505586624, 56.669095158576965, 54.16755259037018, 42.81618230044842, 40.6886650621891, 42.37247630953789, 47.249233424663544, 53.423370122909546, 56.86697714030743, 56.96919925510883, 58.65549176931381, 56.554991081357, 45.05504496395588, 24.550549127161503, 22.313411571085453, 21.73096552491188, 18.49174953997135, 12.446728013455868, 3.5703762900084257, 0.6655539991334081, 0.48369157186243683, 12.992116548120975, 54.83459159731865, 56.88567213714123, 42.576289772987366, 35.561159402132034, 50.319632068276405, 59.91690628230572, 56.149207055568695, 9.430607557296753, 0.31285167031455785, 0.10312456637620926, 0.10900918146944605, 0.21037295053247362, 0.14058355009183288, 0.11405568176996894, 0.1336768121109344, 0.07449820128385909, 0.13795035076327622, 0.13024351821513847, 0.16257982759270817, 0.13686298567336053, 0.19031206058571115, 0.13424091855995357, 0.15431300009367988, 0.24359891685890034], [0.04348857735749334, 0.05751189928560052, 0.11527568349265493, 0.04923937580315396, 0.06307703835773282, 0.04588856048940215, 0.009551746734359767, 0.03234143390727695, 0.06503710974357091, 0.0349865632597357, 0.030160458554746583, 0.06731038229190744, 0.06817637215135619, 0.021613576063828077, 0.07040136057185009, 0.06531695136800408, 0.030512373850797303, 0.06931194715434685, 1.302395195234567, 20.31707089394331, 48.35986062884331, 47.10632689297199, 24.306098744273186, 22.204000242054462, 32.97865077853203, 44.25390735268593, 32.9812878370285, 4.880732651799917, 0.38310669420752674, 1.2520098988898098, 23.26547898352146, 2.8530068462714553, 3.015050101093948, 4.8370131477713585, 15.093614682555199, 31.790154352784157, 47.21022471785545, 49.7431194037199, 48.82030852138996, 50.25695443153381, 50.06017059087753, 46.98298551142216, 40.57897634804249, 35.64308300614357, 34.7529161721468, 39.13587458431721, 45.59137858450413, 47.12074711918831, 48.40293511748314, 45.136729180812836, 45.311774387955666, 47.39221595227718, 49.39703777432442, 46.04744531214237, 39.937042593955994, 33.11364233493805, 33.09982627630234, 33.94510231912136, 36.01095266640186, 34.39739964902401, 33.54706987738609, 35.028313994407654, 35.9516416490078, 35.144329369068146, 35.51170505583286, 35.288923010230064, 35.64831152558327, 37.04661749303341, 35.759409964084625, 33.6848808825016, 33.6438012868166, 36.60655550658703, 35.78160837292671, 35.85087105631828, 35.399037301540375, 33.688099309802055, 34.91150826215744, 34.99534696340561, 34.141787365078926, 38.236360251903534, 40.78508488833904, 44.66124929487705, 47.163852006196976, 47.907456904649734, 48.97918559610844, 48.53210158646107, 44.56990219652653, 49.53657768666744, 35.56187756359577, 45.32185144722462, 50.47747179865837, 48.85400891304016, 49.87520411610603, 46.674559861421585, 46.81498132646084, 45.890589728951454, 45.86383916437626, 39.43572789430618, 35.73961682617664, 38.4706062823534, 37.38619387149811, 34.56305555999279, 36.33436471223831, 37.5472292304039, 37.353948801755905, 35.434838980436325, 36.49184726178646, 37.18015372753143, 37.6896645873785, 37.926540076732635, 36.1241789907217, 35.028804168105125, 33.844605311751366, 37.49600037932396, 36.149253845214844, 34.541408121585846, 35.78859239816666, 39.656746834516525, 42.00552240014076, 40.92393323779106, 39.09867838025093, 36.772876381874084, 36.79095581173897, 36.12915672361851, 37.20695748925209, 35.80700621008873, 39.27226826548576, 44.398010820150375, 45.699535980820656, 50.057788118720055, 49.25060883164406, 48.20510633289814, 53.3235988765955, 47.905614003539085, 39.00771506130695, 36.857205256819725, 37.817026153206825, 43.03435139358044, 50.523772314190865, 52.467124834656715, 56.36447690427303, 53.08903366327286, 38.855438232421875, 26.65110681205988, 8.463222216814756, 5.541033670306206, 6.999256247654557, 3.4818985126912594, 0.32103975594509393, 0.03688470613269601, 0.22965969139477238, 13.330332599580288, 43.344764336943626, 48.96215870976448, 34.20235611498356, 29.53301467001438, 44.98998865485191, 47.513205260038376, 31.94336973130703, 2.1875972393900156, 0.13657761504873633, 0.041005792809301056, 0.041546770225977525, 0.03444675472564995, 0.033859107352327555, 0.018818469798134174, 0.03430539414694067, 0.012335896117292577, 0.016653968268656172, 0.057508930694893934, 0.08280506765004247, 0.043915742717217654, 0.02374781837716, 0.036973147871322, 0.07115671105566435, 0.03673065482871607, 0.05863111735379789, 0.04384571366244927, 0.1056045047880616, 0.03810145724855829, 0.024547283974243328, 0.02056080618785927, 0.02337985784834018, 0.014428660724661313, 0.04565421251754742, 0.042116758195334114, 0.030329983637784608, 0.03428793883358594, 0.07615391790750436, 0.03289674590632785, 0.01211235196024063, 0.04265352021320723, 0.08991459006210789, 0.13422977150185034, 2.2343720169737935, 27.23245281726122, 52.919851541519165, 53.08329977095127, 32.961540296673775, 30.33919271081686, 44.97470207512379, 53.31615887582302, 36.751095950603485, 5.830774772912264, 0.3055617614882067, 0.9853604540694505, 25.207710564136505, 4.943005135282874, 4.474240439012647, 4.668279876932502, 17.197046913206577, 31.984000951051712, 48.64092014729977, 52.0892047137022, 50.11745251715183, 51.57590165734291, 51.88017413020134, 49.90375578403473, 43.0712778121233, 37.94759854674339, 36.27046354115009, 40.21905206143856, 47.330518662929535, 49.161260426044464, 48.82635399699211, 44.61954653263092, 47.25166529417038, 48.16290199756622, 51.12391971051693, 48.22369873523712, 42.361095920205116, 34.97987799346447, 35.645461678504944, 35.31186617910862, 38.172759264707565, 35.64834572374821, 35.535734966397285, 36.3804030418396, 36.60488739609718, 36.94375701248646, 37.14377447962761, 36.98319889605045, 37.45202533900738, 38.400712832808495, 37.23772443830967, 35.62774322926998, 36.53688244521618, 37.849989384412766, 38.710852190852165, 37.14508540928364, 36.99804849922657, 36.43403336405754, 36.490676924586296, 37.61005125939846, 36.2796476483345, 41.33790582418442, 41.76037855446339, 45.896490812301636, 47.24983759224415, 48.769212663173676, 50.64438924193382, 48.01695562899113, 46.704616248607635, 48.62170457839966, 37.55444884300232, 46.829435750842094, 52.70812310278416, 51.7567453533411, 51.212618350982666, 49.41534899175167, 49.403896406292915, 47.318290919065475, 47.03158110380173, 41.52507238090038, 36.781984493136406, 39.04068969190121, 39.1866360604763, 36.47596411406994, 37.082783952355385, 38.96698124706745, 39.67886544764042, 38.59989054501057, 37.99505800008774, 38.72779168188572, 40.752045661211014, 38.99096556007862, 38.89019876718521, 37.30388268828392, 36.51965416967869, 38.76647740602493, 38.956436812877655, 37.49726951122284, 38.42862993478775, 41.97113424539566, 44.71194997429848, 42.89052151143551, 41.27341188490391, 40.25010019540787, 38.23927849531174, 38.13470810651779, 38.43366086483002, 39.95834805071354, 41.981754675507545, 45.4988307505846, 48.08477818965912, 52.245661318302155, 50.890388041734695, 49.76269595324993, 55.191932022571564, 48.55354003608227, 40.30647397041321, 38.49896416068077, 40.2121402323246, 45.90867295861244, 52.93332181870937, 54.8251149058342, 57.112774550914764, 54.49105963110924, 41.11232332885265, 25.46270728111267, 10.433410797268152, 5.46422079205513, 6.982679162174463, 5.307819284498692, 1.0792649933137, 0.21581535693258047, 0.27042302826885134, 15.069409981369972, 48.9445124566555, 54.9544333666563, 34.581058993935585, 31.231812313199043, 48.13383735716343, 53.42438466846943, 40.93772269785404, 5.4968159180134535, 0.17783554882043973, 0.026925733691314235, 0.01846158025728073, 0.028188993346702773, 0.024574051385570783, 0.03428419469855726, 0.025521000279695727, 0.06615385646000504, 0.027223206889175344, 0.024960370792541653, 0.04492685584409628, 0.035805556617560796, 0.06453145484556444, 0.047901892103254795, 0.041987509466707706, 0.052015891269547865, 0.11614326896960847, 0.21170546184293926, 0.23222327727125958, 0.106955836963607, 0.09055927148438059, 0.09545766879455186, 0.05606439590337686, 0.13355207192944363, 0.11877358876517974, 0.1553561628679745, 0.11341110424837098, 0.14522065204801038, 0.2112370330723934, 0.07330457548960112, 0.14192530856234953, 0.15711114916484803, 0.1548611355246976, 0.17629005596973002, 2.7840737951919436, 31.410214640200138, 62.44317792356014, 59.29140664637089, 35.39800375699997, 33.435336872935295, 43.364819660782814, 56.81543290615082, 42.141270115971565, 7.037420924752951, 0.4618146613938734, 1.5385635662823915, 31.79792683571577, 4.865428972989321, 7.573167001828551, 8.577680625021458, 18.15268613398075, 36.57894618809223, 48.76152567565441, 53.38949114084244, 51.173909828066826, 52.75790423154831, 55.03963619470596, 53.20255637168884, 44.418480321764946, 41.18844084441662, 38.67284283041954, 43.926912099123, 51.31110146641731, 51.54195047914982, 50.29537416994572, 44.941146075725555, 48.54788213968277, 49.87699382007122, 53.97821255028248, 50.2054937928915, 43.828584775328636, 36.95653572678566, 37.114915028214455, 37.41545990109444, 40.76624169945717, 38.00449289381504, 37.57819376885891, 39.526489824056625, 39.041966423392296, 39.12054240703583, 39.7815777361393, 38.651100397109985, 39.69053082168102, 40.534013360738754, 39.43098194897175, 36.28211371600628, 38.88725012540817, 40.824925750494, 39.061672165989876, 39.75673086941242, 40.70141337811947, 37.12542146444321, 40.385946705937386, 39.78358782827854, 38.24451081454754, 43.604187816381454, 44.13841634988785, 48.77194091677666, 50.16083478927612, 51.26573570072651, 52.63908080756664, 50.46140246093273, 47.80927397310734, 50.799808502197266, 40.445200726389885, 47.340732514858246, 54.949109852313995, 52.53953754901886, 54.57552909851074, 50.602382495999336, 50.92603012919426, 50.427652671933174, 50.02083130180836, 43.39351572096348, 38.63459788262844, 40.50159730017185, 41.08618073165417, 37.42664650082588, 40.0279451161623, 40.865803956985474, 40.69854833185673, 39.2325945943594, 40.30174322426319, 40.22674284875393, 42.06786945462227, 41.69188342988491, 40.93007370829582, 39.04126726090908, 37.299265936017036, 41.294812336564064, 40.26202395558357, 38.49115177989006, 40.70251911878586, 43.37016597390175, 48.41801270842552, 45.01966506242752, 43.32662791013718, 41.24829523265362, 40.615177005529404, 40.13044461607933, 40.25808736681938, 41.23270086944103, 44.01871517300606, 49.39593963325024, 50.57625129818916, 53.873653560876846, 54.866540282964706, 50.772358775138855, 57.505004703998566, 52.08057537674904, 43.650074154138565, 40.7442294806242, 41.18320852518082, 46.722862869501114, 55.90302586555481, 57.12159387767315, 58.91314074397087, 54.96722348034382, 42.071433663368225, 31.28610759973526, 16.902881897985935, 15.831633880734444, 12.490614708513021, 7.577726757153869, 1.8904567463323474, 0.39637305890209973, 0.6238165637478232, 18.074184246361256, 53.26071225106716, 63.15511152148247, 47.1975713968277, 41.675947085022926, 58.72450366616249, 62.92101748287678, 50.453388690948486, 12.709801197052002, 0.42792986088898033, 0.14565163204679266, 0.08748479856876656, 0.14204979641363025, 0.07342274766415358, 0.1697929241345264, 0.12548739061458036, 0.1073388964869082, 0.2219201301340945, 0.2067680424079299, 0.1760375773301348, 0.10176973126363009, 0.12109683753806166, 0.1757842377992347, 0.14810478634899482, 0.12600414804182947], [0.054831224770168774, 0.02920165756222559, 0.036111143344896846, 0.04779919741849881, 0.005532360264624003, 0.025864204617391806, 0.050496009935159236, 0.07866555344662629, 0.03900232433807105, 0.03292739289463498, 0.0531499448698014, 0.07575909534352832, 0.013254904079076368, 0.08349583644303493, 0.02812620579788927, 0.07378861162578687, 0.015567829577776138, 0.10155490919714794, 0.5970531154889613, 13.61061505973339, 44.989148899912834, 51.61567412316799, 34.4656477868557, 20.492668971419334, 30.05391351878643, 47.848066091537476, 32.24972069263458, 8.240165635943413, 0.2587532013421878, 3.5631937254220247, 24.760446064174175, 17.55963485687971, 2.4441708717495203, 3.5255536576732993, 9.935248028486967, 22.155862525105476, 45.89493289589882, 51.447449550032616, 48.39325323700905, 50.958715975284576, 48.10873590409756, 46.58565603196621, 39.32888142764568, 34.847892075777054, 40.87548963725567, 45.71266047656536, 48.03164564073086, 49.859484359622, 46.12813398241997, 51.28360994160175, 49.4132287055254, 46.70066446065903, 46.22602812945843, 44.238571375608444, 36.246505826711655, 32.94718086719513, 33.60387682914734, 33.33762891590595, 33.49312037229538, 33.6764757335186, 35.610716342926025, 35.71554891765118, 36.61588780581951, 34.997820630669594, 35.27396701276302, 36.049319207668304, 35.78593634068966, 37.31589004397392, 34.308625012636185, 34.63347718119621, 35.256613343954086, 35.77795296907425, 35.3550660610199, 35.637162923812866, 34.60708759725094, 37.52891041338444, 34.37617778778076, 35.15887498855591, 36.94943770766258, 37.79022999107838, 42.77979165315628, 44.20998930931091, 46.18178330361843, 50.09539470076561, 46.41542136669159, 49.25299130380154, 47.86624051630497, 44.472787007689476, 34.60014156997204, 43.384852185845375, 50.73675088584423, 46.79917797446251, 53.893974870443344, 49.70841586589813, 51.427785605192184, 47.5964929908514, 49.991211891174316, 46.690500006079674, 38.53679493069649, 41.150716468691826, 42.407065853476524, 36.23477205634117, 36.40304982662201, 35.870356410741806, 37.12685018777847, 37.36822083592415, 36.85715965926647, 38.287383913993835, 38.28312814235687, 36.89981997013092, 37.677182257175446, 36.064487993717194, 36.50572031736374, 36.96362614631653, 35.46196572482586, 37.03284703195095, 34.982925429940224, 35.860575735569, 36.90646581351757, 36.39385811984539, 36.21643804013729, 36.08840771019459, 34.582723304629326, 36.971256136894226, 35.8145298063755, 36.98666051030159, 37.994051054120064, 45.525691509246826, 47.88632243871689, 51.264797151088715, 51.13465033471584, 49.41671311855316, 51.39723524451256, 52.81870476901531, 47.57180951535702, 39.197640269994736, 37.85352699458599, 41.261944100260735, 46.4201445132494, 53.17976899445057, 53.40649142861366, 57.50396355986595, 41.11680708825588, 24.909517765045166, 6.358969230204821, 2.668240573257208, 9.849548377096653, 2.716633351519704, 0.40477713919244707, 0.21803120209369808, 0.22791312105255201, 15.458278264850378, 45.25902181863785, 41.122202798724174, 29.410737231373787, 28.85713543742895, 48.89870211482048, 50.0208692997694, 31.556390896439552, 5.8353891503065825, 0.06943570027942769, 0.04706620784418192, 0.03912214779120404, 0.06788437414797954, 0.020255995004845317, 0.04804129341209773, 0.05493548538652249, 0.0345312667923281, 0.05170164367882535, 0.04867328781983815, 0.040917280566645786, 0.03680053916468751, 0.04068577130965423, 0.021145008140592836, 0.036508466946543194, 0.016917716420721263, 0.028878524608444422, 0.040442665995215066, 0.038055098993936554, 0.04180223600997124, 0.025512220672680996, 0.051076016898150556, 0.060792752337874845, 0.07395267079118639, 0.08067733026109636, 0.05734260426834226, 0.058096800712519325, 0.0958371363230981, 0.026288831832061987, 0.05372728381189518, 0.025605447408452164, 0.023890156735433266, 0.034416964917909354, 0.0051871451705665095, 0.8091361226979643, 18.004408590495586, 52.950603291392326, 53.89786586165428, 36.39608480036259, 22.194381058216095, 33.43398414552212, 52.63460844755173, 37.10410840809345, 8.684277255088091, 0.26522731175646186, 2.926110648550093, 31.20993308722973, 11.062648482620716, 5.944471322000027, 2.9047747934237123, 10.082920454442501, 26.647415310144424, 46.28102257847786, 53.76437522470951, 51.19714178144932, 53.746782168745995, 50.069700479507446, 50.00127375125885, 41.71144478023052, 38.413206562399864, 41.177634224295616, 47.217961102724075, 49.805531054735184, 49.90476652979851, 46.77333556115627, 52.150142043828964, 51.92734859883785, 48.20097975432873, 47.34842710196972, 46.254135221242905, 38.93729344010353, 33.760941401124, 35.94525419175625, 35.08531853556633, 35.831218510866165, 35.75513519346714, 37.41624265909195, 37.292620092630386, 37.34685078263283, 37.54865415394306, 36.83127164840698, 37.70361743867397, 38.051788955926895, 38.732290640473366, 35.60350053012371, 37.17161178588867, 36.919837296009064, 38.449764400720596, 35.93595989048481, 38.283173739910126, 37.10300646722317, 38.394804149866104, 36.78622506558895, 37.50857770442963, 38.390012606978416, 40.8432749658823, 44.88996282219887, 46.66043221950531, 48.062025010585785, 51.6836828738451, 49.29574280977249, 50.80250635743141, 50.30969560146332, 45.54869167506695, 36.746517196297646, 46.10263355076313, 51.40475884079933, 48.82024012506008, 55.099980756640434, 52.469438910484314, 53.49397413432598, 52.23634421825409, 49.82945457100868, 48.37446704506874, 40.39803005754948, 42.09035664796829, 43.640297278761864, 39.07323494553566, 37.56205603480339, 37.78364114463329, 38.873969838023186, 37.96899899840355, 39.43467915058136, 39.921942204236984, 40.07177196443081, 38.769076466560364, 39.3362720310688, 37.637280598282814, 37.70694985985756, 37.89896495640278, 35.91762587428093, 37.51569092273712, 37.11917459964752, 37.40229360759258, 38.7035071849823, 40.138534381985664, 38.011134937405586, 37.51194052398205, 37.32714124023914, 39.02788817882538, 38.0494786798954, 39.12412941455841, 39.906446635723114, 47.932736948132515, 47.968812212347984, 51.888856664299965, 54.058661833405495, 51.031577065587044, 55.468405187129974, 54.40199241042137, 49.4682801514864, 39.861042872071266, 40.16525074839592, 42.23458170890808, 50.261491388082504, 55.09874202311039, 56.29922680556774, 56.843042224645615, 44.58953194320202, 23.454763926565647, 8.339453358203173, 4.435970792546868, 5.487160161137581, 7.59540150873363, 0.5181796196848154, 0.22043535980628803, 0.2134110953193158, 17.787628322839737, 50.862999111413956, 48.485151305794716, 38.31842824816704, 37.450281232595444, 55.33527173101902, 57.53800593316555, 37.85752058029175, 8.033818658441305, 0.11357038398273289, 0.02220583031885326, 0.05731415774789639, 0.06954273281735368, 0.016907688150240574, 0.04260934016201645, 0.03331119456561282, 0.05250943802820984, 0.051629937370307744, 0.024755786653258838, 0.0515528616233496, 0.080466137296753, 0.05434105478343554, 0.025237156623916235, 0.05397054868808482, 0.07197432772954926, 0.14776880125282332, 0.17011301242746413, 0.1410702950670384, 0.09600639794371091, 0.08264875650638714, 0.15487542928894982, 0.1726327819051221, 0.19864333618897945, 0.19821568101178855, 0.1587543383357115, 0.23006116360193118, 0.17344583437079564, 0.14141825842671096, 0.10603297632769682, 0.10156277596252039, 0.1517375695402734, 0.12353550511761568, 0.21844520175363868, 1.0111701535061002, 22.206215523183346, 59.44632813334465, 63.429259210824966, 43.95969294011593, 30.613824874162674, 39.99265640974045, 57.932006791234016, 41.58780701458454, 10.926263350993395, 0.3448471409501508, 4.078976148739457, 33.829117342829704, 27.89571102708578, 8.792447000741959, 8.919686023145914, 13.746919445693493, 25.82249667495489, 49.36633542180061, 53.695940896868706, 53.539932668209076, 55.96897512674332, 52.88313031196594, 51.45948350429535, 44.26883675158024, 40.620382726192474, 46.318055391311646, 50.25432497262955, 53.155454099178314, 51.678302362561226, 47.484478801488876, 53.544674813747406, 54.04451139271259, 50.25244787335396, 49.356011375784874, 48.25623258948326, 40.25679163634777, 35.846687480807304, 38.574112728238106, 36.8120788782835, 37.1758371591568, 36.961840242147446, 39.294402077794075, 38.670574352145195, 39.97144214808941, 39.14911687374115, 39.067751839756966, 39.43884752690792, 40.03416918218136, 41.58272288739681, 37.858075350522995, 38.033979311585426, 39.73466545343399, 40.646700114011765, 39.32000890374184, 39.138230457901955, 39.25012685358524, 41.13435074687004, 38.33723723888397, 39.05848413705826, 40.98857156932354, 41.36502116918564, 47.466144785284996, 48.673700988292694, 49.937744960188866, 53.53433936834335, 49.902038276195526, 51.756893545389175, 51.82426393032074, 48.69901143014431, 40.20754627883434, 48.21040324866772, 54.18805629014969, 50.017381086945534, 58.15616816282272, 54.29527133703232, 55.50421826541424, 53.27671319246292, 53.72144512832165, 49.896729961037636, 42.001502215862274, 44.145848751068115, 45.38052409887314, 40.00103875994682, 40.62467649579048, 40.073098093271255, 40.97846031188965, 41.25934883952141, 41.81453324854374, 42.31281951069832, 42.292672991752625, 39.93758216500282, 41.486287862062454, 39.35799166560173, 39.41002607345581, 40.0740784406662, 37.85424895584583, 39.945284351706505, 38.72822865843773, 40.08915223181248, 39.4930250197649, 41.87727928161621, 39.62960869073868, 38.933592438697815, 39.04143065214157, 40.72676561772823, 40.2285173535347, 41.762761026620865, 41.6310752928257, 51.88643239438534, 52.099274173378944, 55.191958621144295, 56.722493693232536, 53.9507932215929, 54.45409521460533, 56.72800339758396, 53.75111013650894, 42.46929511427879, 42.50554516911507, 45.24318426847458, 51.171945333480835, 59.01577703654766, 58.445857018232346, 60.35955213010311, 45.63950300216675, 29.560114815831184, 11.62620384246111, 8.784535825252533, 17.924479879438877, 11.660191118717194, 1.9400971638970077, 0.4306867317063734, 0.40621372929308563, 20.152836106717587, 57.14967057108879, 53.448555171489716, 41.94588840007782, 44.28483009338379, 62.81904235482216, 65.64810454845428, 45.12150339782238, 9.79057364165783, 0.15836812468478456, 0.15089931373950094, 0.12961806583916768, 0.194500207726378, 0.15527206269325688, 0.11958275237702765, 0.24496639816788957, 0.14267170132370666, 0.1229930025874637, 0.12704950757324696, 0.13370455359108746, 0.17845001741079614, 0.19905549532268196, 0.10620840519550256, 0.12786754727130756, 0.1422436157008633], [0.028832735952164512, 0.043172860314371064, 0.11837247278890572, 0.044949294679099694, 0.004604426121659344, 0.03262159836594947, 0.056628019956406206, 0.04292731704481412, 0.04758739218232222, 0.034239150045323186, 0.03901374599081464, 0.07216065874672495, 0.03175936377374455, 0.053957082418492064, 0.020306507431087084, 0.056699592678342015, 0.02152649060008116, 0.05980253808957059, 0.21344732696888968, 9.980040024966002, 37.028450667858124, 51.222471222281456, 38.36979389190674, 28.551924414932728, 34.15976420044899, 47.8125835955143, 45.2886526286602, 11.520015690475702, 0.6798959732986987, 3.5892864502966404, 15.314214695245028, 12.37929493188858, 2.8658717684447765, 1.1755000543780625, 4.791286876425147, 19.456322081387043, 36.001863554120064, 54.56092268228531, 50.27125686407089, 49.30224806070328, 46.58581182360649, 40.80642454326153, 36.7976700514555, 38.09577539563179, 44.742355942726135, 48.97878661751747, 49.62754860520363, 47.25636564195156, 49.18323464691639, 49.70705933868885, 44.811926409602165, 44.55127939581871, 42.040974497795105, 36.53809458017349, 32.3038449883461, 32.40352123975754, 32.733012959361076, 37.44500331580639, 41.07318162918091, 42.18951612710953, 38.87791782617569, 37.50613063573837, 35.66710911691189, 35.80823354423046, 36.192772909998894, 39.43893872201443, 38.67439314723015, 42.978209406137466, 35.75842201709747, 34.80053901672363, 36.02894090116024, 36.039158552885056, 36.47052280604839, 35.69694511592388, 35.02654708921909, 35.62703646719456, 33.753372207283974, 35.45655481517315, 35.4940702021122, 37.90531441569328, 40.37256762385368, 44.03768755495548, 41.270151659846306, 48.78489442169666, 46.15068577229977, 50.19907593727112, 42.39797294139862, 45.73718436062336, 40.38886874914169, 41.923348009586334, 52.313191294670105, 39.86086428165436, 49.67344634234905, 44.8465995490551, 49.6586499363184, 47.84707434475422, 52.878673151135445, 45.78726567327976, 39.91864398121834, 34.752596989274025, 37.26423181593418, 35.569161772727966, 36.58550463616848, 37.33148820698261, 36.33051551878452, 36.370907351374626, 41.35690860450268, 41.24225735664368, 41.004663705825806, 38.179918080568314, 36.63772903382778, 35.6364219635725, 36.217315793037415, 36.7112322896719, 36.26270055770874, 34.78658616542816, 35.896210223436356, 35.37450961768627, 35.25903761386871, 35.416375771164894, 35.24282768368721, 34.39440540969372, 34.37186501920223, 35.28231896460056, 36.62555828690529, 35.52045598626137, 37.07898035645485, 41.16887949407101, 47.5974353402853, 47.99610614776611, 52.1785569190979, 51.62458084523678, 50.77832445502281, 53.48917119204998, 52.07855388522148, 45.57605780661106, 38.615040332078934, 38.472677171230316, 42.93709561228752, 50.08153684437275, 52.51743033528328, 55.306446477770805, 41.217148303985596, 21.196873784065247, 6.023095278069377, 3.2003986928611994, 1.607176959514618, 3.8278193632140756, 0.588135706493631, 0.161396473122295, 0.3499059460591525, 18.215316273272038, 47.24339693784714, 46.300485134124756, 29.973207749426365, 31.787646487355232, 45.10439671576023, 50.17995536327362, 30.897306762635708, 2.3047874635085464, 0.058985656141885556, 0.04435496055521071, 0.050915653628180735, 0.043262726976536214, 0.05268973909551278, 0.011538729322637664, 0.03841075100353919, 0.0668076217698399, 0.04458741233975161, 0.12004579315544106, 0.04953034964273684, 0.015696709087933414, 0.0300810895714676, 0.038062813619035296, 0.03616689718910493, 0.06462663528509438, 0.06928007933311164, 0.04112646602152381, 0.044481359436758794, 0.052400238419068046, 0.040842045345925726, 0.0544249434460653, 0.09177269035717472, 0.04266849675332196, 0.016561810225539375, 0.014342375852720579, 0.027428792927821632, 0.029757639349554665, 0.03980740984843578, 0.09468288146308623, 0.0843274054932408, 0.04737515278975479, 0.025532049003231805, 0.03524942083458882, 0.2911775739630684, 12.846813295036554, 44.290461391210556, 58.333949223160744, 42.341131791472435, 30.552993938326836, 38.75758968293667, 51.46376967430115, 48.62437203526497, 13.03202485665679, 0.6234340311493725, 3.8691210094839334, 17.091646268963814, 15.696265194565058, 4.890734665095806, 3.459634082391858, 6.795627549290657, 21.012197993695736, 38.42497453093529, 55.810880810022354, 53.761445581912994, 51.70370399951935, 50.326243713498116, 43.78253124654293, 39.596934244036674, 40.214047729969025, 48.04915130138397, 51.160583943128586, 49.818412363529205, 47.49446466565132, 51.090994477272034, 52.72412024438381, 47.45966233313084, 46.18804916739464, 44.428880363702774, 40.2377774566412, 35.00466786324978, 33.66439238190651, 35.579322427511215, 38.71950812637806, 42.248777747154236, 42.69092582166195, 40.24791531264782, 38.13956804573536, 37.00937569141388, 36.80499225854874, 37.48118117451668, 40.116677954792976, 40.38882315158844, 42.63455204665661, 37.48149275779724, 36.552681997418404, 36.94417119026184, 37.46369071304798, 37.39248253405094, 37.681787610054016, 37.84560441970825, 37.01121859252453, 35.62804341316223, 35.495198741555214, 36.13672211766243, 39.989696368575096, 42.018403708934784, 45.65664768218994, 45.19241899251938, 49.385828375816345, 47.7608759701252, 52.422644421458244, 45.746406465768814, 46.86788208782673, 43.616381362080574, 44.498409032821655, 52.915770560503006, 42.50700429081917, 51.36306747794151, 46.38655051589012, 50.993985682725906, 50.22293485701084, 54.6662188321352, 47.99493581056595, 41.91546343266964, 37.75432571768761, 39.05435375869274, 37.59970061480999, 38.18801164627075, 37.54477836191654, 38.805600106716156, 37.885661870241165, 43.43042694032192, 43.33577021956444, 41.798425912857056, 38.4611713886261, 38.75642694532871, 38.1865069270134, 37.79451236128807, 38.73659960925579, 38.77456337213516, 36.63150116801262, 38.0622573941946, 37.67782062292099, 37.112806141376495, 36.28225810825825, 36.094502583146095, 37.48662628233433, 35.065787583589554, 36.42777509987354, 38.764626905322075, 37.820130586624146, 40.2255155146122, 44.80568714439869, 50.54408602416515, 50.95677427947521, 52.98332713544369, 52.28461682796478, 49.950143694877625, 53.80433768033981, 55.27550853788853, 46.908722296357155, 39.94042441248894, 42.62240789830685, 45.98318316042423, 52.278111577034, 53.51023346185684, 58.250813484191895, 44.56132225692272, 23.206836730241776, 9.877740014344454, 6.811590492725372, 5.3871984500437975, 5.191105222329497, 0.9145321953110397, 0.17379727098159492, 0.4948825651081279, 20.58225106447935, 51.54580347239971, 49.17116269469261, 35.87838537991047, 34.803730845451355, 49.40958850085735, 57.258622124791145, 36.99058569967747, 4.4231241568923, 0.037345932360040024, 0.01615272914932575, 0.023022623208817095, 0.027650873198581394, 0.05647567188134417, 0.04546243042568676, 0.028203211040818132, 0.09136188935372047, 0.04991619221982546, 0.03182773041771725, 0.012518903240561485, 0.02104445269651478, 0.025335840000479948, 0.026372449610789772, 0.032413459339295514, 0.04947203538904432, 0.12613875878741965, 0.21890646137762815, 0.1756143305101432, 0.14042179158423096, 0.06336575606837869, 0.14676779246656224, 0.24153458856744692, 0.19894074444891885, 0.10167248765355907, 0.17840066459029913, 0.12339871245785616, 0.1532880199374631, 0.12426012326614, 0.15186437289230525, 0.18918067129561678, 0.1535130391130224, 0.08288182798423804, 0.20659437985159457, 0.4280371457571164, 14.364166874438524, 51.19105450809002, 64.32126894593239, 50.73054201900959, 39.06416103243828, 45.33494554460049, 56.969982013106346, 57.15265341103077, 16.708009354770184, 0.7144702586811036, 3.9028268633410335, 19.71207495778799, 17.94194184243679, 9.579190034419298, 4.137594178318977, 7.26416758261621, 22.496613040566444, 40.40948644280434, 58.40793505311012, 52.674696296453476, 53.6075272411108, 52.28277012705803, 46.04681074619293, 42.66522780060768, 41.6476272046566, 50.681144669651985, 54.07234109938145, 51.53581760823727, 47.90987737476826, 53.74428570270538, 55.56334689259529, 50.65885506570339, 48.48295882344246, 45.99726900458336, 40.59435412287712, 36.67286194860935, 35.81710986793041, 37.07378223538399, 41.74286529421806, 47.07599312067032, 46.078216060996056, 42.86936044692993, 40.52366651594639, 39.32731591165066, 39.38205197453499, 39.62256006896496, 43.788109347224236, 42.56763383746147, 47.60983407497406, 40.720302164554596, 38.16866688430309, 40.01163639128208, 39.250016659498215, 39.348872154951096, 40.050238519907, 40.27037210762501, 39.49579507112503, 37.673838436603546, 37.0061344653368, 38.65645430982113, 41.87149979174137, 44.42644089460373, 46.845858469605446, 48.100741133093834, 51.89464755356312, 51.37664794921875, 54.229823648929596, 46.82851240038872, 49.52018156647682, 45.47611556947231, 46.06509916484356, 51.68666951358318, 41.83566391468048, 50.74918381869793, 46.98982894420624, 52.502839118242264, 53.462618216872215, 57.21312336623669, 50.239042192697525, 43.59775856137276, 39.10048708319664, 40.537839755415916, 39.45349954068661, 38.048289343714714, 39.02619726955891, 40.10417282581329, 39.175772443413734, 46.40255145728588, 46.58239580690861, 44.900036081671715, 42.39395275712013, 39.46839474141598, 39.65429216623306, 39.060376435518265, 40.48875018954277, 40.57614549994469, 38.86312521994114, 39.738039672374725, 38.842370733618736, 39.51278775930405, 38.71441259980202, 39.19541738927364, 38.700896725058556, 36.274419128894806, 37.874874249100685, 39.87398877739906, 39.8657014220953, 42.24155053496361, 46.67762629687786, 53.412126526236534, 52.801624685525894, 55.97424164414406, 53.063795417547226, 51.726761162281036, 55.33018000423908, 58.84963475167751, 49.65122893452644, 42.9856988042593, 43.360404297709465, 47.91559226810932, 54.76418137550354, 57.528723031282425, 59.74977605044842, 45.76278358697891, 23.60573172569275, 9.79192541912198, 7.654958562925458, 11.816636323928833, 11.794025637209415, 1.8072026199661195, 0.5988963134586811, 0.7652778667397797, 23.738606795668602, 59.396167024970055, 59.46054697036743, 42.78688207268715, 44.405599012970924, 58.1929349899292, 64.83595132827759, 44.003208205103874, 5.69654650054872, 0.18326547229662538, 0.11823346110759303, 0.25657888676505536, 0.16082297108368948, 0.15784799790708348, 0.14937924686819315, 0.14666383242001757, 0.20815026276977733, 0.11751026788260788, 0.23233295185491443, 0.12525379221187904, 0.0995754825999029, 0.11362515448126942, 0.11510999160236679, 0.13492676691384986, 0.14884533098665997], [0.0803061451006215, 0.048928430769592524, 0.025868817065202165, 0.023361385792668443, 0.011298172357783187, 0.05045753699960187, 0.08993013063445687, 0.03809034729783889, 0.021871678327443078, 0.03309216823254246, 0.014718712445755955, 0.05307473933498841, 0.049262835091212764, 0.05781623178336304, 0.04476968380913604, 0.10133745250641368, 0.051411256135907024, 0.033770595109672286, 0.04002862180641387, 5.733857648447156, 33.000408411026, 49.13300134241581, 45.568249225616455, 16.406104154884815, 24.201024882495403, 46.946769654750824, 43.67984935641289, 21.262866742908955, 0.9812553087249398, 0.35959251690655947, 5.705636087805033, 2.6381048653274775, 6.176058920100331, 1.3371382746845484, 1.4013769151642919, 10.703711193054914, 30.092084370553493, 45.78444242477417, 49.46430556476116, 46.75520293414593, 45.69839984178543, 41.38884589076042, 40.68365313112736, 44.49010647833347, 48.14678706228733, 53.135201185941696, 49.229424968361855, 52.32899844646454, 46.76268093287945, 44.57666963338852, 42.81579092144966, 38.43979753553867, 34.45753142237663, 34.55715827643871, 33.5719433426857, 34.93303410708904, 41.66685797274113, 46.690287217497826, 46.166952699422836, 48.4960263222456, 45.72709210216999, 42.00823925435543, 38.316950127482414, 38.555615320801735, 40.172595754265785, 44.774863198399544, 45.599848330020905, 46.22615732252598, 40.71411229670048, 36.33926644921303, 34.75348614156246, 35.22955119609833, 35.16513705253601, 37.424093037843704, 35.54507486522198, 34.83351744711399, 34.22850251197815, 35.27083218097687, 34.79824014008045, 34.69473749399185, 37.61561416089535, 39.30264763534069, 40.93942500650883, 44.274722635746, 45.849567130208015, 47.28549487888813, 44.16483633220196, 52.1731536090374, 45.18175296485424, 36.07783667743206, 45.35641439259052, 40.60932531952858, 47.61185556650162, 48.3202363550663, 50.34632183611393, 48.01172710955143, 48.021302595734596, 44.896802455186844, 39.26011271774769, 35.72666712105274, 35.524810552597046, 34.096489995718, 37.59547904133797, 36.87483251094818, 36.87900088727474, 38.85713294148445, 45.45846551656723, 46.50046080350876, 46.407494992017746, 41.797669753432274, 37.140768840909004, 37.461825013160706, 36.78634665906429, 38.611027747392654, 38.87854479253292, 38.25125925242901, 35.53435944020748, 35.5336032807827, 37.350517585873604, 35.87766341865063, 35.57861566543579, 35.17903670668602, 35.42997904121876, 36.76147699356079, 35.34328289330006, 35.42290382087231, 36.534108594059944, 38.99756580591202, 44.30477522313595, 46.099696308374405, 49.811029359698296, 52.64646381139755, 50.47725521028042, 51.61152474582195, 52.361828684806824, 49.42980341613293, 40.56708298623562, 37.597226947546005, 44.47319358587265, 46.92151241004467, 51.704361364245415, 54.56113547086716, 42.81921073794365, 19.593078643083572, 9.292657859623432, 3.805886940099299, 3.13847579061985, 5.088725415989757, 0.5576453113462776, 0.11283453713986091, 0.8736465079709888, 18.97780805826187, 48.686084523797035, 40.28849333524704, 31.43884040415287, 35.52024319767952, 44.06944625079632, 50.23469142615795, 23.549432046711445, 2.1082703210413456, 0.046093897908576764, 0.09190282595227472, 0.0049537100403540535, 0.05082297051558271, 0.059213803469901904, 0.02394911109149689, 0.10146791464649141, 0.04212549698422663, 0.061177281313575804, 0.019697306233865675, 0.031026125579955988, 0.03459144012595061, 0.034128696206607856, 0.054748794427723624, 0.06640130333835259, 0.027325513801770285, 0.07566099084215239, 0.05208376809605397, 0.008719249999558087, 0.027038358311983757, 0.03401380432478618, 0.03314733206934761, 0.048606802520225756, 0.01575002312165452, 0.0291727954390808, 0.06289124910836108, 0.019453698114375584, 0.023550906189484522, 0.06565793111803941, 0.014767860247957287, 0.07435300751239993, 0.076857837557327, 0.012645866154343821, 0.02566557621321408, 0.030642867532151286, 7.178102200850844, 39.42758873105049, 57.018053233623505, 49.268441274762154, 25.14642745256424, 28.40546317398548, 54.70999628305435, 50.99916100502014, 22.91758295148611, 1.1207780032418668, 0.6928580277599394, 6.138901188969612, 3.8950363313779235, 6.803595246747136, 4.827189249917865, 6.228415360674262, 14.619388729333878, 32.791271433234215, 48.45438435673714, 52.03074865043163, 49.30513970553875, 47.961197420954704, 43.14139924943447, 42.510868683457375, 47.27050468325615, 49.436525255441666, 53.53049397468567, 50.02349875867367, 52.68702283501625, 49.54706512391567, 47.042281329631805, 46.45311154425144, 40.28046436607838, 37.89067380130291, 35.280331671237946, 36.2240794301033, 35.947078093886375, 42.57250897586346, 48.01166631281376, 49.754647985100746, 50.136698484420776, 47.5110849738121, 43.02526608109474, 40.565707460045815, 40.143637508153915, 41.72216400504112, 46.32052145898342, 48.78974296152592, 48.084440007805824, 41.74816220998764, 37.601041942834854, 36.00499078631401, 36.58050790429115, 36.69633328914642, 38.27341966331005, 36.339479237794876, 37.53018334507942, 36.265839189291, 37.608056366443634, 35.46410880982876, 36.16934336721897, 38.89703080058098, 41.19678519666195, 45.11564791202545, 47.62507505714893, 46.66232451796532, 49.88560415804386, 46.036213114857674, 52.80758656561375, 47.80336908996105, 39.684975519776344, 46.19226314127445, 42.61652201414108, 48.7103234231472, 49.57187779247761, 51.50097347795963, 51.644404381513596, 50.55795527994633, 47.85316921770573, 42.88405425846577, 37.968824207782745, 36.888325586915016, 36.11626021564007, 38.04937608540058, 38.12549740076065, 39.46999445557594, 41.08057603240013, 46.02619305253029, 48.69671255350113, 47.82286964356899, 43.44816438853741, 38.85639198124409, 38.14981609582901, 39.24634985625744, 39.37276907265186, 39.63114380836487, 39.38228376209736, 37.94745795428753, 36.82686768472195, 38.99027779698372, 39.25592914223671, 37.33724109828472, 36.49705298244953, 37.8010518103838, 37.29334205389023, 36.68160907924175, 36.93586103618145, 38.5735085606575, 41.44112728536129, 47.80189096927643, 49.02293264865875, 52.339569479227066, 53.3109949529171, 50.719621405005455, 52.876032292842865, 56.290244087576866, 50.026094019412994, 42.99610264599323, 40.44447496533394, 45.28417646884918, 49.904120564460754, 55.071847066283226, 58.239357098937035, 45.697142109274864, 22.31806442141533, 9.341893717646599, 5.770322866737843, 4.958362961187959, 3.0373710533604026, 1.0293609648942947, 0.11672170629026368, 0.7137422414962202, 21.128323562443256, 54.642033129930496, 47.582011967897415, 38.284176886081696, 43.59608665108681, 53.03972750902176, 56.99145466089249, 29.973977208137512, 3.1828165613114834, 0.022802591265644878, 0.0704020656121429, 0.04232723127643112, 0.03727709445229266, 0.03388443685253151, 0.037360404239734635, 0.012756218875438208, 0.036399104064912535, 0.0543331175140338, 0.03603693228797056, 0.06924283836269751, 0.07152732476242818, 0.019039149265154265, 0.04247924909577705, 0.059071333380416036, 0.032118325761985034, 0.2205026280716993, 0.16208239569095895, 0.12662562250625342, 0.17689457978121936, 0.10184316677623428, 0.1072307804133743, 0.14002388168592006, 0.104172968713101, 0.08736710879020393, 0.10285840995493345, 0.11525168985826895, 0.12228837047587149, 0.1495164551306516, 0.10321038833353668, 0.1773738587507978, 0.16452410607598722, 0.211027970071882, 0.13314114476088434, 0.33293293963652104, 8.473444618284702, 47.86234572529793, 61.991180777549744, 56.10841624438763, 26.923595890402794, 34.37140144407749, 56.87650702893734, 55.28303973376751, 27.89708085358143, 1.5741260955110192, 0.6412391038611531, 7.758413711562753, 4.850375605747104, 14.613084867596626, 5.591175304725766, 3.165737190283835, 12.916755191981792, 33.33867385983467, 49.5265956223011, 54.09778453409672, 51.37808047235012, 50.76336085796356, 46.235371828079224, 45.55751100182533, 50.3412377089262, 52.0224004983902, 55.327155366539955, 52.42452152073383, 57.5093212723732, 51.98138169944286, 49.85015965998173, 48.23830895125866, 42.355521619319916, 38.94297033548355, 37.56114028394222, 37.67003484070301, 38.98934684693813, 45.60924522578716, 49.858697801828384, 51.06469228863716, 52.18034662306309, 51.58942133188248, 45.189371556043625, 42.478600814938545, 41.83549292385578, 44.81348052620888, 48.458446338772774, 51.62859342992306, 50.50921909511089, 44.582445323467255, 39.63832922279835, 38.59517499804497, 38.508254662156105, 37.780350521206856, 41.11641950905323, 38.346003368496895, 38.9882031083107, 37.6801422983408, 39.03240993618965, 38.67610685527325, 38.389495834708214, 40.16492776572704, 42.13474586606026, 46.058373525738716, 48.81367787718773, 49.904508143663406, 51.81596517562866, 49.71524029970169, 55.444694459438324, 49.48501065373421, 41.96451500058174, 47.84559242427349, 44.57677602767944, 49.890665486454964, 51.33902236819267, 53.07096943259239, 52.876606062054634, 51.42229110002518, 48.15127082169056, 43.32053303718567, 39.95544880628586, 39.11697059869766, 36.700372472405434, 40.95705606043339, 40.40689118206501, 42.35844366252422, 41.0492505133152, 48.73379476368427, 52.68436677753925, 50.67423664033413, 45.72660192847252, 41.77026182413101, 39.822718128561974, 40.73536075651646, 41.87439903616905, 43.09071756899357, 41.70018598437309, 40.56045614182949, 38.81565436720848, 42.057670801877975, 41.54451593756676, 38.576016426086426, 38.05574834346771, 40.033120438456535, 39.89149823784828, 38.81792664527893, 37.70044840872288, 40.78331418335438, 43.23979116976261, 50.74921041727066, 50.37076972424984, 54.13411818444729, 55.46052820980549, 52.21237890422344, 53.77050809562206, 58.172161504626274, 53.82278189063072, 45.37148058414459, 42.045443058013916, 48.55951711535454, 52.17561587691307, 57.529220804572105, 59.85778145492077, 46.81204788386822, 23.155558481812477, 13.134833090007305, 9.385504927486181, 11.204568967223167, 10.420975964516401, 1.9074641587212682, 0.266267565311864, 1.3321549608372152, 23.45592476427555, 63.382574915885925, 52.023821622133255, 45.047152787446976, 51.0922522097826, 58.92401956021786, 65.3119745850563, 34.12436529994011, 4.3143692426383495, 0.09936560323694721, 0.18535216891905293, 0.18139848107239231, 0.17155047826236114, 0.23187457176391035, 0.13170513353543356, 0.10097408216097392, 0.0777713545539882, 0.1360838790424168, 0.110949585941853, 0.17808253556722775, 0.20326304220361635, 0.17701737553579733, 0.13971655833302066, 0.16390117700211704, 0.15046171378344297], [0.010442201491969172, 0.07448825650499202, 0.038083237523096614, 0.03604837991588283, 0.035974087222712114, 0.004104867966816528, 0.03913564374670386, 0.021741047348768916, 0.055218017296283506, 0.05004614969948307, 0.11139943133457564, 0.04417387652210891, 0.041663788360892795, 0.050527855491964146, 0.008592014346504584, 0.02886151458369568, 0.010581889455352211, 0.06584001705050468, 0.043804613524116576, 3.036916977725923, 24.8825791105628, 52.15014584362507, 41.38229884207249, 29.893569722771645, 34.37015511095524, 37.76389740407467, 41.49612933397293, 30.22780928760767, 4.037107145413756, 0.03673782768601086, 0.3030883613973856, 4.334015138447285, 4.675590209662914, 4.379516271874309, 5.901517951861024, 4.2797336261719465, 14.403438717126846, 35.83486631512642, 49.687091410160065, 49.4861163944006, 45.32386153936386, 44.566402584314346, 45.28535060584545, 47.29178734123707, 49.36296120285988, 50.059418231248856, 48.988814279437065, 47.00990706682205, 45.44963099062443, 40.159714445471764, 35.197674706578255, 33.25822837650776, 34.866689667105675, 34.070544987916946, 34.72301557660103, 40.305056646466255, 47.69034035503864, 48.278051018714905, 48.75409707427025, 47.122810408473015, 44.876351952552795, 45.582973435521126, 43.33531804382801, 43.90127867460251, 45.750240460038185, 45.49723483622074, 47.36356928944588, 49.099426344037056, 46.152597069740295, 36.80249199271202, 36.95414945483208, 36.39752112329006, 35.964674949645996, 33.90550084412098, 35.04903048276901, 34.25469070672989, 34.68599796295166, 34.04893554747105, 34.77625451982021, 33.58862444758415, 35.90287886559963, 37.538827881217, 38.87114658951759, 38.556523472070694, 41.65344089269638, 44.86887775361538, 45.87591491639614, 48.46251592040062, 46.80400371551514, 35.78900657594204, 46.96517966687679, 45.98747693002224, 49.61044192314148, 49.02490474283695, 47.46172182261944, 48.4713314473629, 45.73813810944557, 40.63765659928322, 37.640385031700134, 35.764444693923, 35.36280244588852, 35.90075857937336, 36.04141943156719, 36.38505399227142, 35.874847769737244, 43.20373870432377, 49.88093040883541, 50.58431066572666, 48.79574663937092, 44.70946490764618, 40.05978360772133, 37.797115221619606, 40.994313061237335, 43.714902475476265, 45.751646384596825, 48.32076072692871, 44.64263789355755, 40.18679179251194, 37.90466085076332, 35.74015259742737, 36.3056306540966, 35.30168652534485, 34.87629555165768, 34.72756013274193, 35.90760961174965, 36.41455560922623, 35.50683371722698, 35.22496484220028, 40.05734793841839, 45.26917107403278, 48.5945550352335, 52.14335560798645, 50.72126291692257, 51.197096183896065, 51.66883707046509, 52.14815475046635, 43.519311770796776, 39.00531738996506, 41.65866181254387, 49.190279468894005, 50.56994743645191, 56.25503897666931, 43.62196326255798, 19.072565473616123, 7.5358544290065765, 3.5717679653316736, 1.5186579781584442, 1.881685748230666, 1.1927350983023643, 0.08626681548776105, 0.9879013895988464, 21.166089735925198, 48.154071271419525, 45.164083912968636, 31.451828107237816, 33.812421038746834, 45.84602952003479, 43.778993636369705, 19.56696454435587, 1.2067714263685048, 0.04712245521659497, 0.09338375937659293, 0.05423509093816392, 0.06586450050235726, 0.03272036337875761, 0.011395685924071586, 0.016242508609138895, 0.023216221707116347, 0.038395566662075, 0.014303205298347166, 0.04375195443572011, 0.05799731952720322, 0.08113426316413097, 0.039646419463679194, 0.06261826492846012, 0.11555530247278512, 0.014262353779486148, 0.0010397904088677024, 0.047647268656874076, 0.0524427412165096, 0.0108569034091488, 0.02369522422668524, 0.04806065604498144, 0.03459187057160307, 0.03998115404101554, 0.014860976589261554, 0.011772782290790929, 0.014929185526852962, 0.023878332467575092, 0.04654901254980359, 0.05236542427155655, 0.032410245839855634, 0.03361481460160576, 0.019718539078894537, 0.09450013501918875, 3.54476495180279, 32.23197944462299, 58.050214648246765, 46.9864509254694, 27.318542897701263, 33.648258447647095, 45.02918355166912, 49.88824121654034, 32.31932155787945, 4.3814983405172825, 0.11124793672934175, 0.5607734934892505, 2.987763052806258, 6.391340643167496, 7.168815974146128, 5.79408916644752, 8.286378756165504, 18.104383125901222, 39.32747930288315, 51.472387611866, 52.66253314912319, 47.04328827559948, 47.90816746652126, 47.35265627503395, 50.567884147167206, 50.04252053797245, 50.56623883545399, 51.47535905241966, 47.64836020767689, 48.36956150829792, 43.16313028335571, 36.956737115979195, 35.61060234904289, 35.34559316933155, 37.0298033952713, 37.16575250029564, 42.788808569312096, 48.25341314077377, 50.873159766197205, 50.07788524031639, 49.70200560986996, 47.48266249895096, 47.80282951891422, 45.71429058909416, 46.016267985105515, 46.881933733820915, 48.983445167541504, 47.87584260106087, 50.57399421930313, 47.31366656720638, 40.0022204965353, 37.10557512938976, 38.80955569446087, 38.24949614703655, 36.2805861979723, 36.38472341001034, 36.563591212034225, 37.34020873904228, 36.780456975102425, 37.1236165612936, 34.274195060133934, 38.005146458745, 39.141730070114136, 40.418043583631516, 41.90170057117939, 44.99601513147354, 46.47943653166294, 48.27342666685581, 49.71897549927235, 50.375884249806404, 38.05631451308727, 46.04297295212746, 48.46402443945408, 50.16654588282108, 51.10930189490318, 50.97293101251125, 51.270071268081665, 47.95542173087597, 43.78467433154583, 39.53739523887634, 37.38926410675049, 36.615093648433685, 39.24516811966896, 37.7051867544651, 37.02601119875908, 39.2176765948534, 43.812093660235405, 51.15914762020111, 51.788416653871536, 50.9733109921217, 45.6281454116106, 41.25551484525204, 39.283306673169136, 42.706751972436905, 45.15184096992016, 47.885752469301224, 48.63595761358738, 45.8995458483696, 42.536106929183006, 37.85685941576958, 36.40773877501488, 37.82516531646252, 37.78074949979782, 36.424020901322365, 36.78878612816334, 36.638374999165535, 38.1274238973856, 37.118559032678604, 38.00504386425018, 43.52702155709267, 47.18049131333828, 50.59496149420738, 54.54234167933464, 52.5498615950346, 51.88924804329872, 53.59296262264252, 53.314756751060486, 45.40831200778484, 41.392793878912926, 43.86517681181431, 52.27427378296852, 52.83828891813755, 57.80497580766678, 43.47716823220253, 20.305276326835155, 9.098990801721811, 6.513502188026905, 8.929646238684654, 4.555885707959533, 1.108047617599368, 0.15245237649651244, 1.2203119997866452, 24.442887604236603, 55.519375652074814, 46.232765167951584, 32.03653313219547, 41.09262138605118, 53.39389890432358, 52.9241681098938, 25.269544646143913, 2.091180975548923, 0.031999622951843776, 0.025550205646140967, 0.04071704541274812, 0.025562794326106086, 0.027083744353149086, 0.05672266604960896, 0.021692551708838437, 0.03729675394424703, 0.02483817246684339, 0.011203404737898381, 0.05941821320448071, 0.04611180593201425, 0.09027807172969915, 0.01915517663292121, 0.10190647939452901, 0.03121747351542581, 0.06216214838786982, 0.11022205115295947, 0.15014894306659698, 0.1548206142615527, 0.10796989270602353, 0.12489485990954563, 0.17380117467837408, 0.1422484841896221, 0.29846935300156474, 0.1691462760209106, 0.21855149214388803, 0.13696381385670975, 0.14807208732236177, 0.09210103875375353, 0.09032029993250035, 0.10525579928071238, 0.0997736508725211, 0.19589755305787548, 0.22545529121998698, 4.487878857180476, 37.02959060668945, 66.33298739790916, 53.31393599510193, 38.32797713577747, 44.065764248371124, 49.533784836530685, 54.74898599088192, 38.69814187288284, 5.0735656544566154, 0.2816317440010607, 0.6401714205276221, 8.390022944658995, 11.43112801015377, 7.400954067707062, 8.566329684108496, 5.819645170122385, 15.666863322257996, 40.05532264709473, 55.1761856675148, 55.66323213279247, 49.53777462244034, 51.01864255964756, 50.97879409790039, 52.11555249989033, 53.8072407245636, 51.243753880262375, 53.50956089794636, 50.643044114112854, 50.09887911379337, 44.42788481712341, 38.985953629016876, 35.86676940321922, 38.556557670235634, 39.11401055753231, 40.06921090185642, 44.21559400856495, 52.12182976305485, 53.02751496434212, 53.34517031908035, 52.77399256825447, 49.609803557395935, 51.399727910757065, 47.56509907543659, 48.31818446516991, 49.137815684080124, 51.30393885076046, 51.13068714737892, 53.022753819823265, 50.403341576457024, 41.462242752313614, 40.20318791270256, 40.97257062792778, 40.088301077485085, 36.690785586833954, 38.91834765672684, 38.93648408353329, 39.23837788403034, 37.64562875032425, 38.27715866267681, 35.871298760175705, 40.55352531373501, 41.518848314881325, 42.936206459999084, 43.11693236231804, 48.374109864234924, 48.029833137989044, 49.968838691711426, 52.41892822086811, 53.16015064716339, 42.46381960809231, 46.551077887415886, 48.772932663559914, 51.504302099347115, 53.25704164803028, 52.01303780078888, 54.08619895577431, 50.15902988612652, 44.08093303442001, 42.06330589950085, 40.594297125935555, 38.51340338587761, 41.20048999786377, 39.506312906742096, 40.52357152104378, 40.90975619852543, 46.333550959825516, 54.19468313455582, 54.090758711099625, 53.666655868291855, 48.22203442454338, 43.653512969613075, 43.35395224392414, 44.22328479588032, 47.40369513630867, 50.45183077454567, 53.966976553201675, 49.21535812318325, 44.46512281894684, 41.94214940071106, 38.50959599018097, 37.90863163769245, 39.066893085837364, 38.856175392866135, 38.6517159640789, 39.07896503806114, 40.692225471138954, 38.81753146648407, 40.15440613031387, 44.646426290273666, 49.465217515826225, 52.94541276991367, 57.19782918691635, 53.400267362594604, 52.481951639056206, 52.87437938153744, 56.96682058274746, 47.851246520876884, 43.86387348175049, 45.41008271276951, 54.69830431044102, 54.94598262012005, 62.005741596221924, 46.65456913411617, 21.351189203560352, 11.763478126376867, 8.90707639977336, 10.23065747693181, 6.907402826473117, 2.718601645901799, 0.3632479504449293, 1.283155521377921, 28.229631409049034, 61.21155001223087, 58.740603402256966, 44.012658298015594, 48.154732435941696, 60.587106719613075, 60.50436995923519, 29.355520494282246, 2.949513830244541, 0.12933296238770708, 0.19128203275613487, 0.1344216166762635, 0.13584328960860148, 0.10553037165664136, 0.09755082210176624, 0.1862155835260637, 0.12906005984405056, 0.07980710273841396, 0.10510287233046256, 0.15014848293503746, 0.11214189071324654, 0.1985323999542743, 0.08426681655691937, 0.12808636209229007, 0.14080641703912988], [0.025022043264470994, 0.04565600109344814, 0.006175849148348789, 0.0350182566762669, 0.0417819494032301, 0.04297875158954412, 0.04696906071330886, 0.10119671904249117, 0.04996195675630588, 0.014587863461201778, 0.03637519577750936, 0.0231060814257944, 0.059464126170496456, 0.08655966696096584, 0.0741792336339131, 0.010885471456276719, 0.028556872239278164, 0.03890012689225841, 0.040615018660901114, 1.1282212100923061, 16.840223260223866, 47.04116798937321, 49.132670760154724, 37.368612214922905, 29.015512838959694, 41.59486323595047, 40.206254348158836, 36.349142119288445, 6.710883546620607, 0.03527029744873289, 0.041084697950282134, 1.1439020186662674, 5.590419145300984, 6.796472053974867, 7.605642434209585, 4.700808981433511, 5.80316117964685, 19.23189092427492, 36.858132407069206, 51.66060671210289, 50.24112068116665, 48.519520461559296, 48.99591229856014, 49.44059483706951, 48.06513324379921, 49.63039465248585, 45.86542367935181, 45.834208354353905, 39.21309024095535, 34.96185176074505, 34.94459688663483, 34.875934571027756, 35.94951756298542, 36.773700937628746, 42.588927894830704, 44.77263271808624, 47.68744871020317, 50.402220636606216, 45.52289105951786, 48.925247490406036, 47.14005388319492, 47.536665201187134, 47.55874961614609, 47.83561035990715, 46.05207346379757, 50.55196300148964, 49.01631340384483, 49.61383894085884, 46.24197207391262, 38.329899832606316, 35.31102642416954, 36.8990334123373, 36.09462037682533, 40.47956608235836, 34.99587893486023, 35.15415944159031, 35.780042856931686, 35.4905591905117, 34.08319070935249, 36.64503984153271, 34.5099002122879, 35.90365022420883, 37.28681780397892, 37.06377737224102, 39.38632294535637, 42.54010431468487, 45.62195934355259, 47.9264634847641, 46.614105105400085, 38.57165805995464, 47.023510336875916, 51.313727125525475, 49.76844124495983, 49.04040411114693, 44.475598856806755, 46.39769911766052, 42.715730890631676, 39.578436836600304, 36.524111330509186, 36.622252464294434, 35.32811030745506, 36.051344498991966, 35.13898305594921, 36.17158144712448, 36.27797573804855, 43.60509216785431, 49.99828331172466, 51.96449540555477, 51.00602723658085, 45.22792048752308, 43.842792212963104, 43.272233828902245, 46.44229352474213, 48.74514475464821, 47.29488417506218, 50.23657612502575, 49.28551375865936, 48.333395048975945, 43.17470446228981, 41.67454496026039, 40.08682295680046, 39.01734374463558, 40.41998527944088, 39.05331261456013, 35.58164030313492, 34.09999720752239, 35.955756828188896, 36.45295634865761, 34.800797402858734, 42.97311007976532, 47.89106838405132, 50.32752804458141, 50.91778077185154, 48.62915977835655, 52.66987055540085, 56.647117137908936, 49.53380763530731, 43.95957514643669, 43.48023846745491, 48.42501573264599, 53.68065431714058, 53.32466281950474, 46.68596304953098, 17.03959286212921, 4.755478547886014, 6.739718299359083, 5.2480565663427114, 2.6418334152549505, 0.523475882364437, 0.2979132765904069, 0.7998917531222105, 22.288602702319622, 47.12045073509216, 46.99805550277233, 30.236643813550472, 27.862930186092854, 48.112718090415, 40.08971460163593, 17.69924696534872, 1.5988966100849211, 0.08774164845817722, 0.038944217885727994, 0.047749722143635154, 0.02348932463064557, 0.08428071698290296, 0.032632830771035515, 0.012270454462850466, 0.026927756043733098, 0.017962703022931237, 0.07109865284292027, 0.04678199868067168, 0.010616461477184203, 0.06553267143317498, 0.058366641897009686, 0.048530773201491684, 0.060835511176264845, 0.01773383395629935, 0.022917542519280687, 0.020090904254175257, 0.02682774607819738, 0.01677783642662689, 0.015382055171357933, 0.014567918242391897, 0.09123824755079113, 0.05580846256634686, 0.014715206725668395, 0.021434334412333556, 0.032728619771660306, 0.07142421076423489, 0.026643255587259773, 0.055064262851374224, 0.03675850763102062, 0.023693713956163265, 0.03550714274751954, 0.011792393543146318, 1.260462545324117, 20.897254161536694, 54.96294490993023, 53.60500417649746, 43.979858458042145, 31.241308003664017, 43.674883022904396, 44.82386156916618, 39.1302090883255, 6.487226122990251, 0.06704589570290409, 0.21818567271111533, 1.1329374695196748, 4.959667716175318, 4.717535208910704, 6.669147536158562, 5.436972454190254, 8.39970102533698, 23.92154037952423, 42.1916364133358, 52.644066140055656, 51.86871774494648, 49.553000405430794, 50.41864335536957, 51.419323459267616, 48.18608455359936, 51.65241815149784, 49.49402756989002, 47.45302028954029, 43.484916016459465, 35.83261303603649, 37.056268975138664, 37.514406591653824, 36.72725982964039, 39.57909420132637, 43.26484702527523, 46.49288401007652, 49.050059393048286, 51.31240099668503, 47.58162438869476, 49.96147468686104, 49.13986757397652, 47.98796318471432, 49.57635395228863, 48.27295929193497, 49.70691874623299, 50.377556160092354, 51.11346647143364, 51.24913439154625, 48.315919786691666, 38.9758575707674, 37.21093587577343, 38.27592372894287, 37.370686903595924, 41.91687695682049, 36.15677744150162, 36.52156926691532, 36.48935839533806, 36.76480181515217, 36.993747130036354, 36.94320984184742, 35.90640127658844, 36.75964169204235, 38.216681107878685, 40.25259666144848, 40.90702794492245, 43.528161495923996, 47.04944774508476, 50.26636652648449, 51.055511981248856, 40.86304910480976, 48.4669578820467, 52.19561040401459, 51.424734368920326, 49.83433350920677, 47.385152131319046, 47.389233112335205, 45.456729009747505, 41.22120648622513, 38.690819665789604, 37.08479404449463, 37.277690693736076, 37.73970790207386, 38.56354169547558, 37.977537140250206, 38.264307752251625, 45.24321086704731, 51.870712637901306, 53.0298138409853, 53.23231637477875, 48.3722023665905, 45.82839086651802, 44.695056080818176, 48.27104799449444, 50.88461235165596, 50.770652666687965, 52.63870842754841, 50.63687324523926, 48.77694144845009, 45.32914325594902, 43.33048850297928, 41.75973638892174, 39.60442744195461, 41.02872781455517, 40.899359956383705, 38.383279368281364, 35.757042691111565, 36.88550613820553, 37.944703102111816, 38.04306082427502, 47.022404596209526, 51.307484060525894, 54.98002879321575, 54.20885257422924, 49.18003901839256, 53.83480444550514, 58.89834053814411, 52.314023450016975, 44.833570048213005, 46.061348766088486, 51.27735547721386, 55.29178686439991, 56.015887409448624, 49.15158614516258, 17.758413590490818, 5.564938662573695, 5.8712677750736475, 9.444909039884806, 3.67464791983366, 0.9214374935254455, 0.2820633474038914, 0.9782693220768124, 25.830871425569057, 53.69312524795532, 53.41276489198208, 35.1243082433939, 35.38683995604515, 54.56891365349293, 47.876157984137535, 21.726675555109978, 1.6154803452081978, 0.11573819734621793, 0.08050439500948414, 0.015064761064422783, 0.006834629521108582, 0.09281795340939425, 0.07093909109244123, 0.01615790377400117, 0.044806973019149154, 0.08012294594664127, 0.07415645712171681, 0.08046790360822342, 0.06901050903252326, 0.03613274355302565, 0.02308211933268467, 0.10595090221613646, 0.007351704216489452, 0.11571863433346152, 0.10856668333872221, 0.10743312697741203, 0.15327915869420394, 0.11475270686787553, 0.13348223583307117, 0.141623106028419, 0.17168216494610533, 0.17685468192212284, 0.08796243739197962, 0.09195024918881245, 0.174364717095159, 0.18285335769178346, 0.1768738590180874, 0.17937635129783303, 0.31165238935500383, 0.15092459128936753, 0.16566646430874243, 0.17301328101893887, 1.6479830886237323, 25.196012891829014, 60.81340737640858, 60.964149087667465, 49.41145800054073, 36.400815546512604, 52.28989474475384, 51.09039790928364, 46.37934610247612, 8.779891524463892, 0.24327502876985818, 0.38711610250175, 4.166762363165617, 10.79474100843072, 12.203686404973269, 16.764202639460564, 8.99309428408742, 8.297104630619287, 21.122768260538578, 41.74080580472946, 55.81102140247822, 55.64780116081238, 51.30339927971363, 52.137743309140205, 54.491435810923576, 50.83616875112057, 55.001022666692734, 52.0257481187582, 49.68653284013271, 45.96014119684696, 38.00060950219631, 37.62022331357002, 39.760010093450546, 40.07552996277809, 41.96340925991535, 47.64886558055878, 49.25148278474808, 51.30230113863945, 54.50606882572174, 49.74537268280983, 50.10256491601467, 51.88239701092243, 52.442813739180565, 52.7175085991621, 51.23885974287987, 51.80728644132614, 54.99639831483364, 52.72585675120354, 53.559072241187096, 49.41648133099079, 42.626652270555496, 38.86542409658432, 39.82714109122753, 39.56536553800106, 43.32466721534729, 38.080386221408844, 38.83714221417904, 39.98864762485027, 38.29382836818695, 39.16179299354553, 39.64447729289532, 38.161895647645, 38.374258652329445, 41.89280144870281, 42.22539000213146, 44.464469254016876, 45.94411365687847, 50.016370341181755, 51.36855058372021, 52.371381372213364, 45.45325979590416, 49.36497889459133, 53.63417141139507, 55.693512707948685, 53.1269708275795, 48.621400594711304, 50.55812247097492, 44.964161440730095, 43.88119675219059, 41.87236234545708, 40.20045205950737, 38.85919623076916, 38.72139662504196, 38.812295347452164, 39.024962335824966, 40.8063979446888, 47.608561143279076, 53.933454751968384, 54.90510441362858, 56.00328728556633, 49.967208579182625, 48.81349928677082, 48.28235998749733, 50.605399534106255, 53.37426915764809, 52.345329970121384, 54.31151546537876, 53.175991997122765, 53.31266686320305, 47.429374158382416, 46.07078745961189, 45.06033428013325, 41.643599420785904, 44.0045153349638, 43.197408244013786, 39.663563668727875, 37.736094295978546, 40.073269084095955, 40.60747481882572, 39.433311223983765, 48.3871241658926, 52.95354813337326, 57.08422288298607, 55.36168411374092, 50.567960143089294, 55.04829593002796, 61.53935842216015, 55.57809390127659, 49.35673713684082, 49.267172142863274, 53.88459697365761, 59.98029448091984, 59.64395932853222, 50.80067865550518, 20.668837018311024, 6.543692043051124, 11.849593855440617, 13.941287565976381, 7.6956092566251755, 1.8784353788942099, 0.5292676028329879, 1.2935939175076783, 30.376985482871532, 58.92859451472759, 60.032917857170105, 41.43322750926018, 41.443882137537, 63.17286416888237, 56.524877697229385, 27.140566147863865, 2.849864889867604, 0.20858351374045014, 0.16337828943505883, 0.14447350229602307, 0.12633345380891114, 0.19336635450599715, 0.1319458565558307, 0.09196505503496155, 0.19448946142802015, 0.16424537025159225, 0.12629150762222707, 0.17717714508762583, 0.11950139072723687, 0.15058198623592034, 0.14090783894062042, 0.12363495290628634, 0.10279227717546746], [0.016990099938993808, 0.03787732122873422, 0.03043396780412877, 0.055532120168209076, 0.026879336473939475, 0.05337721646355931, 0.014042805159988347, 0.02685800900508184, 0.09350596141302958, 0.046839411224937066, 0.018022444055532105, 0.030767262614972424, 0.06389268091879785, 0.0869951221102383, 0.012250546351424418, 0.051332302755326964, 0.10325906579964794, 0.01607221540325554, 0.058357895686640404, 0.29393676028121263, 10.042255986481905, 40.82045339047909, 49.99648220837116, 34.26340363919735, 22.59491566568613, 26.648154370486736, 35.781783163547516, 40.35445399582386, 14.022069331258535, 0.12285710792639293, 0.10912864498095587, 0.40837201348040253, 4.48077323846519, 10.473700985312462, 2.1065549505874515, 1.9948350079357624, 2.450909810140729, 10.934178326278925, 23.208193257451057, 44.68140721321106, 51.27245374023914, 48.786277547478676, 49.617125764489174, 50.368759632110596, 51.72802649438381, 47.04908296465874, 45.17280824482441, 40.76522335410118, 35.44878803193569, 36.07299193739891, 34.54067476093769, 38.29905688762665, 42.24315404891968, 45.01305341720581, 46.91109336912632, 48.69792468845844, 49.854282438755035, 44.5950910449028, 47.413741797208786, 46.55632160604, 47.66856372356415, 49.6189496666193, 49.90525670349598, 47.83293530344963, 47.854677736759186, 49.19129021465778, 50.55662155151367, 49.175239875912666, 45.04898428916931, 41.30601413547993, 35.54753713309765, 36.1390133947134, 35.41686974465847, 38.95876608788967, 37.570533379912376, 35.78058622777462, 36.43971785902977, 34.780688881874084, 34.079197123646736, 34.17001225054264, 34.21076886355877, 33.555665016174316, 35.512856394052505, 37.21071548759937, 37.08924360573292, 40.7388261705637, 45.36919690668583, 48.9401388913393, 47.3478951305151, 41.96206413209438, 50.862269550561905, 48.082623705267906, 47.60313883423805, 46.521082296967506, 45.43356165289879, 43.087274953722954, 40.06496652960777, 38.003303557634354, 35.3886828571558, 34.161147326231, 35.61453893780708, 35.590315237641335, 35.91824524104595, 36.99227660894394, 37.019167765975, 44.90569397807121, 51.3516528904438, 52.24527753889561, 50.120807737112045, 48.78444604575634, 46.714503318071365, 46.16164058446884, 48.38258720934391, 47.30753369629383, 50.07441982626915, 48.79269540309906, 48.84061083197594, 51.357914954423904, 45.11190511286259, 47.51788280904293, 47.47502110898495, 48.17524753510952, 47.52467684447765, 47.17325270175934, 44.15572442114353, 39.00748707354069, 36.0482020676136, 35.27150474488735, 36.3732024282217, 38.53660114109516, 44.39328007400036, 50.09237006306648, 50.37815272808075, 52.57068827748299, 51.62197418510914, 52.71306283771992, 54.12763573229313, 48.45449075102806, 44.85807493329048, 47.97246001660824, 53.510415852069855, 54.516123086214066, 40.983232855796814, 17.286818996071815, 3.667104374617338, 5.808030618354678, 7.7239167876541615, 4.6484658401459455, 0.5332044290844351, 0.12063727743225172, 1.4429933507926762, 23.742805570364, 44.65889722108841, 37.53260761499405, 28.9584930986166, 24.65352740138769, 47.705657333135605, 44.369953125715256, 16.48271184414625, 0.7941703288815916, 0.0487936753052054, 0.0440986301691737, 0.009820254836085951, 0.03130007455183659, 0.06862161622848362, 0.03421468885790091, 0.06404426458175294, 0.016557520611968357, 0.030356378119904548, 0.005197227246753755, 0.03734826641448308, 0.02547584615967935, 0.006738056627000333, 0.03898949260474183, 0.016579323055339046, 0.024509820359526202, 0.050064636598108336, 0.04323506713262759, 0.04240399532136507, 0.02309157429408515, 0.05277743868646212, 0.03903894561517518, 0.019155434529238846, 0.06708843560772948, 0.0789306263322942, 0.036596771387849, 0.07757884886814281, 0.022993829734332394, 0.06751810942660086, 0.029735987191088498, 0.0628284337290097, 0.05270032583212014, 0.05232374525803607, 0.06439392745960504, 0.029450698202708736, 0.5013838678132743, 13.62373860552907, 47.34857149422169, 55.2669095993042, 39.31729584932327, 25.335393212735653, 35.41649356484413, 42.540472894907, 45.09728729724884, 13.670595791190863, 0.40308029274456203, 0.19123398611554876, 0.5472732335329056, 5.248837899416685, 3.9575933245941997, 6.012675287202001, 4.49939651414752, 3.2769918953999877, 16.644989736378193, 28.147278428077698, 48.370036482810974, 52.63720750808716, 50.93341313302517, 50.97383916378021, 51.69080749154091, 55.07419914007187, 49.94610071182251, 46.91258668899536, 44.17036883533001, 37.02878125011921, 37.38531231880188, 36.22367665171623, 39.740946516394615, 42.50239513814449, 46.06493577361107, 48.77642087638378, 49.78617489337921, 51.09444849193096, 46.054497733712196, 48.20641726255417, 48.54727417230606, 48.63165624439716, 50.796764865517616, 52.10036851465702, 50.33468686044216, 51.00618302822113, 51.5556525439024, 52.305337116122246, 51.17459759116173, 47.3895712941885, 43.18904869258404, 37.656135186553, 37.42819681763649, 37.70177073776722, 40.01095622777939, 38.401852771639824, 37.96677611768246, 39.114675521850586, 35.907761603593826, 35.37325568497181, 38.039534613490105, 35.69219157099724, 35.76603300869465, 36.553377360105515, 38.982651606202126, 38.10979664325714, 43.011317029595375, 47.71773308515549, 51.66049271821976, 48.38794872164726, 43.65116089582443, 51.076916232705116, 50.63569910824299, 49.71479192376137, 47.32780180871487, 48.30757923424244, 44.49248895049095, 42.78591692447662, 39.599438309669495, 36.7512821406126, 36.68778754770756, 36.162005960941315, 37.47719518840313, 38.270292431116104, 38.24901357293129, 38.58152233064175, 47.03992545604706, 52.61396795511246, 53.54272171854973, 51.11982353031635, 50.94421215355396, 48.85115146636963, 48.967976197600365, 50.176615342497826, 50.87971441447735, 52.3974783718586, 52.16617338359356, 51.90554536879063, 53.181824684143066, 47.859051302075386, 49.54008869826794, 49.08227026462555, 48.99404279887676, 48.89937847852707, 47.69548527896404, 44.39689368009567, 40.51179975271225, 37.78856188058853, 37.11986996233463, 38.27647089958191, 39.945687130093575, 46.50233410298824, 51.933173686265945, 54.474405124783516, 55.187216475605965, 52.118440344929695, 56.038955971598625, 56.899389401078224, 49.61857348680496, 46.146483197808266, 49.31723065674305, 55.78628472983837, 56.23250998556614, 43.77637557685375, 18.829426020383835, 3.7384780822321773, 7.951154094189405, 10.223746597766876, 3.588739042170346, 0.37801918282639235, 0.23136014468036592, 1.0050890548154712, 26.2012717500329, 51.31567642092705, 44.210369288921356, 31.630017645657063, 29.11065023392439, 54.57321122288704, 51.29667364060879, 20.390712842345238, 1.4899315196089447, 0.1607977380626835, 0.019094288982159924, 0.03426746668992564, 0.02969460689200787, 0.07941003146697767, 0.045508428738685325, 0.05018692769226618, 0.014107821007200982, 0.05440404827822931, 0.010768467236630386, 0.04231086692016106, 0.004161986898907344, 0.020497475015872624, 0.10454882940393873, 0.022280738994595595, 0.03525525040458888, 0.08150901063345373, 0.15876184887019917, 0.22517152363434434, 0.14843649667454883, 0.17686297913314775, 0.17233837192179635, 0.1114539495029021, 0.1249357225606218, 0.16685519192833453, 0.14905786723829806, 0.13265061483252794, 0.13992363237775862, 0.14646187919424847, 0.15850711410166696, 0.12844283046433702, 0.18955178966280073, 0.16495934600243345, 0.1657559970044531, 0.08686229994054884, 0.6713285017758608, 16.088614091277122, 56.4334812015295, 61.41931526362896, 47.66665622591972, 33.77476125955582, 38.43014985322952, 46.868642047047615, 50.47763518989086, 17.4493495747447, 0.44410045724362135, 0.4616800358053297, 2.911956408061087, 10.713382624089718, 17.307980060577393, 6.667440952733159, 4.814449958503246, 4.122645780444145, 14.629501886665821, 26.791127398610115, 48.001030683517456, 54.508842676877975, 51.398561373353004, 53.13292130827904, 52.26489968597889, 56.051157116889954, 52.10134506225586, 48.12482424080372, 44.919004663825035, 39.88769844174385, 39.29933421313763, 38.485984057188034, 42.40717224776745, 46.341842114925385, 47.86852419376373, 52.426622807979584, 51.905628964304924, 54.17453661561012, 46.183690801262856, 49.14487570524216, 50.003283843398094, 49.605593383312225, 54.21659275889397, 55.65472438931465, 52.35920302569866, 52.150563821196556, 51.6649878770113, 54.082148373126984, 53.72394919395447, 49.11100052297115, 46.247284188866615, 38.24095420539379, 38.44927042722702, 38.7280310690403, 41.858683079481125, 41.56776688992977, 39.161314219236374, 40.87415210902691, 37.59424410760403, 36.79640471935272, 39.52308140695095, 37.057899087667465, 38.17548371851444, 38.94753769040108, 41.85576103627682, 41.56462825834751, 45.07745236158371, 49.898914843797684, 51.668764874339104, 51.83744542300701, 48.42434696853161, 51.743309274315834, 50.76369524002075, 52.032937332987785, 50.47056756913662, 50.412381291389465, 46.9510368257761, 45.01410976052284, 41.09679736196995, 39.080021381378174, 37.188422083854675, 38.3147082477808, 39.85907457768917, 39.257304668426514, 40.89819721877575, 39.88417603075504, 49.447483867406845, 54.94991160929203, 57.59426951408386, 53.6783554404974, 52.29016453027725, 50.87368033826351, 50.56857950985432, 52.86083310842514, 54.05786007642746, 51.837817803025246, 54.07777860760689, 53.93185503780842, 55.979565158486366, 48.43700788915157, 52.43752062320709, 51.03053592145443, 51.86544232070446, 50.84822930395603, 51.71090841293335, 47.90055267512798, 43.087369948625565, 38.917770087718964, 37.88538068532944, 39.41607914865017, 42.200482338666916, 49.42865587770939, 54.821098521351814, 56.029144898056984, 56.30585364997387, 51.36217072606087, 57.160933166742325, 58.417867720127106, 53.97804915904999, 48.23561489582062, 54.23312567174435, 56.630679219961166, 60.854771956801414, 43.914866745471954, 21.312474980950356, 5.174501063302159, 14.724250752478838, 24.38478872179985, 13.505642842501402, 1.3171752146445215, 0.41610465792473406, 2.327920622192323, 30.620645508170128, 59.43608768284321, 51.62285193800926, 40.5585790425539, 36.82592533528805, 62.25056625902653, 60.51369845867157, 24.360565021634102, 1.5412432537414134, 0.21721665048971772, 0.12397061887895688, 0.17198341753100976, 0.08925221583922394, 0.22485668974695727, 0.16200835903873667, 0.22008675819961354, 0.11810699172201566, 0.13073588866973296, 0.1344686243101023, 0.10197047478868626, 0.14684108697110787, 0.09604329010471702, 0.14571318577509373, 0.17195748689118773, 0.1034404021629598], [0.012064381389791379, 0.03625119774369523, 0.04082510211446788, 0.009726759071781999, 0.0690261015552096, 0.07868138345656916, 0.04260119138052687, 0.03467668320809025, 0.038340102255460806, 0.00686889447933936, 0.059982026505167596, 0.012944583377247909, 0.09967391364625655, 0.026646869846445043, 0.033848951061372645, 0.08749963410082273, 0.07738276603049599, 0.020484541237237863, 0.05856999778188765, 0.09108198835747316, 6.20403254404664, 35.474413856863976, 51.074659153819084, 35.520615577697754, 18.830372169613838, 26.796141229569912, 34.18574720621109, 41.952059268951416, 14.185045436024666, 0.40047948074061424, 0.04603754663548898, 0.4687084414763376, 3.0346632236614823, 0.9942969214171171, 7.2901710122823715, 3.682599705643952, 1.3608927000313997, 5.697450377047062, 14.522883407771587, 34.65292073786259, 49.38875421881676, 51.8081109970808, 50.17184279859066, 51.047836393117905, 46.558734476566315, 45.19250638782978, 40.11494904756546, 36.482932940125465, 36.99017912149429, 35.573440343141556, 40.41069097816944, 44.39521797001362, 46.02228306233883, 48.45188409090042, 46.20041370391846, 51.65280573070049, 49.16715390980244, 49.966600611805916, 48.71112518012524, 51.81208938360214, 47.10323765873909, 47.532508224248886, 48.65848280489445, 51.135775074362755, 49.36108410358429, 49.23371113836765, 48.104901909828186, 47.891189977526665, 46.13235555589199, 43.798004016280174, 37.10798420011997, 37.14120201766491, 36.14239141345024, 35.0726006180048, 35.174127370119095, 37.35674545168877, 34.97109666466713, 37.289420664310455, 36.460422948002815, 37.367274686694145, 35.20875111222267, 35.972126349806786, 35.2171790599823, 36.672770753502846, 35.86184486746788, 40.41947230696678, 43.553578332066536, 49.08676162362099, 46.76458463072777, 42.133928909897804, 49.46059316396713, 50.64446143805981, 46.89357630908489, 46.054934710264206, 42.72090621292591, 41.20538793504238, 39.3279542773962, 37.48767502605915, 34.87474523484707, 34.02315013110638, 34.549923464655876, 36.648433059453964, 36.153027042746544, 36.659992039203644, 38.38224582374096, 43.14661256968975, 48.67579847574234, 51.951317712664604, 52.0684502273798, 50.93201480805874, 48.36657486855984, 48.465342968702316, 47.51603230834007, 51.73445574939251, 46.25710666179657, 49.677941501140594, 52.00723551213741, 50.958157405257225, 50.28285764157772, 49.24707122147083, 48.64853493869305, 48.72669294476509, 50.37144608795643, 50.72217866778374, 48.736222833395004, 48.64342041313648, 43.85862976312637, 38.752672746777534, 35.92899106442928, 36.630657613277435, 40.05792550742626, 45.99553629755974, 50.48369586467743, 53.864047676324844, 49.45538744330406, 47.23291330039501, 55.198311880230904, 52.31976494193077, 50.08561782538891, 48.767153173685074, 53.78687001764774, 54.26416240632534, 32.5508127361536, 12.955678403377533, 4.803845202550292, 3.3501379704102874, 7.397957453504205, 1.9862526934593916, 0.5655659269541502, 0.34421156567987055, 0.9282852010801435, 25.91804064810276, 47.161895111203194, 42.17676781117916, 28.946107663214207, 33.764760196208954, 47.29928433895111, 38.525129556655884, 8.138276003301144, 0.26431841833982617, 0.0470855333696818, 0.030321523154270835, 0.047359456366393715, 0.021137926196388435, 0.03335275854624342, 0.021020681706431787, 0.012651652123167878, 0.0713951037323568, 0.026647261329344474, 0.04097148703294806, 0.03761143940209877, 0.04263765309588052, 0.08098121747025289, 0.01256969953828957, 0.052446737681748345, 0.017060435129678808, 0.03319528965221252, 0.03620740732003469, 0.08816144429147243, 0.014136505014903378, 0.03993768274085596, 0.02845611270458903, 0.02799184923787834, 0.025697193559608422, 0.2068014835822396, 0.038041695806896314, 0.05683799579855986, 0.08023139598662965, 0.06522485084133223, 0.023358166727120988, 0.019953402843384538, 0.009117029094340978, 0.028990683531446848, 0.03834069226286374, 0.0346971442195354, 0.1565158725134097, 7.542770532891154, 41.733563393354416, 56.949314922094345, 43.135296776890755, 25.027564130723476, 29.622021093964577, 39.07287776470184, 48.47093626856804, 17.20989402383566, 0.9095269732642919, 0.11257784310146235, 0.5822919169440866, 2.646730402484536, 4.338678913190961, 6.59810084849596, 7.677787262946367, 3.168709580786526, 9.729981143027544, 19.987934455275536, 38.44965800642967, 51.92320682108402, 50.835317596793175, 52.15592533349991, 53.49104069173336, 47.83866919577122, 46.807355135679245, 43.2637070864439, 38.48543308675289, 38.28544981777668, 37.60986126959324, 41.85511887073517, 46.14159286022186, 46.476628482341766, 50.14524422585964, 48.307446241378784, 52.22351610660553, 49.21649806201458, 51.681912168860435, 50.35151615738869, 50.97510829567909, 48.32983084022999, 47.742203772068024, 50.529080629348755, 52.923050969839096, 50.43714076280594, 48.27957473695278, 49.91075120866299, 49.14367496967316, 47.4267902970314, 46.010952070355415, 38.80781538784504, 37.977134361863136, 37.443217411637306, 37.60886952280998, 36.42198421061039, 38.8481730222702, 37.03724339604378, 38.44541363418102, 37.57022179663181, 38.437354266643524, 35.677645951509476, 36.969059854745865, 36.758676543831825, 38.135251477360725, 38.46619851887226, 43.28275166451931, 46.65200047194958, 51.62016548216343, 49.336039647459984, 44.355004727840424, 52.20219925045967, 51.725568026304245, 49.29860405623913, 48.659406155347824, 46.34659945964813, 42.98581659793854, 40.834573432803154, 38.9776586741209, 36.5938413888216, 35.78126259148121, 35.676874592900276, 38.02690789103508, 37.88709059357643, 38.482408449053764, 38.98694917559624, 45.88088504970074, 50.802859738469124, 52.24172852933407, 54.3341850489378, 53.21851171553135, 51.03560484945774, 49.87230867147446, 49.78209391236305, 51.419570446014404, 49.52311120927334, 52.292292416095734, 51.70507952570915, 54.09901566803455, 53.17096866667271, 52.082862854003906, 52.00664274394512, 51.42148554325104, 53.35809722542763, 52.786531895399094, 51.27276532351971, 49.942794889211655, 45.569286569952965, 39.99402433633804, 37.70735643804073, 37.797628194093704, 41.97130523622036, 49.801811054348946, 51.59693732857704, 54.64425601065159, 49.990577325224876, 49.99329797923565, 57.822534665465355, 54.265442937612534, 51.696909964084625, 51.55598312616348, 57.4552995711565, 56.54601216316223, 35.45535407960415, 16.047637090086937, 4.676740597933531, 5.595085294917226, 8.105177879333496, 3.3217922039330006, 0.4218633973505348, 0.24207573296735063, 1.4993123849853873, 28.54613732546568, 53.35793383419514, 44.73520092666149, 32.45610661804676, 36.26164801418781, 55.01615345478058, 47.239870727062225, 12.671907730400562, 0.284680308541283, 0.04134378912567627, 0.0477522565779509, 0.08655464262119494, 0.02139037515007658, 0.03276458053733222, 0.04332063675974496, 0.014716456316818949, 0.02116837837093044, 0.01626074874366168, 0.044653255681623705, 0.10367618990130723, 0.09695737855508924, 0.05023194265959319, 0.07445227718562819, 0.023486740101361647, 0.09515844227280468, 0.06133642375061754, 0.12118965794797987, 0.212327292538248, 0.10277734516421333, 0.21724166086642072, 0.19708481122506782, 0.15445139579242095, 0.15394072397612035, 0.31537141010630876, 0.08392661606194451, 0.11349150110618211, 0.22730457480065525, 0.23243391362484545, 0.11409853337681852, 0.12095370693714358, 0.16486714157508686, 0.139756367134396, 0.10773711808724329, 0.14796735544223338, 0.23673366493312642, 9.285151362419128, 46.875629872083664, 64.42856758832932, 50.71068808436394, 30.500429458916187, 35.77423296868801, 44.878050461411476, 52.6593679189682, 19.10185620188713, 1.1609872081317008, 0.20796370168682188, 1.5215384610928595, 9.485577307641506, 4.196796426549554, 15.393374897539616, 9.682049565017223, 4.490951942279935, 10.041198693215847, 18.285637199878693, 38.48218806087971, 54.61380444467068, 55.46782001852989, 54.12099368870258, 54.72013033926487, 50.76521135866642, 47.53868669271469, 44.13149692118168, 40.5734970420599, 41.407252103090286, 39.572410359978676, 45.76906085014343, 48.38495448231697, 48.62100921571255, 52.88690730929375, 49.37272667884827, 55.74370041489601, 50.936950743198395, 54.48181472718716, 52.71413058042526, 53.983543664216995, 48.88927482068539, 46.60624332726002, 51.49840861558914, 55.18757365643978, 51.11987292766571, 50.47609247267246, 50.873528346419334, 51.045393124222755, 48.48410256206989, 47.28845871984959, 41.079884469509125, 40.27496986091137, 40.26793643832207, 38.54352056980133, 37.90411368012428, 40.97216784954071, 37.48974211513996, 40.230014473199844, 39.110301956534386, 40.364569053053856, 38.260834738612175, 39.16075184941292, 38.70348438620567, 40.29018424451351, 39.88301329314709, 46.88025422394276, 47.667549178004265, 52.35038369894028, 51.20492376387119, 47.33842983841896, 52.42950305342674, 54.92775499820709, 51.64129614830017, 51.35706000030041, 48.636649176478386, 45.180058255791664, 42.572592571377754, 40.66091515123844, 37.56884627044201, 38.48936207592487, 36.747896522283554, 40.45140579342842, 39.18837256729603, 40.53853891789913, 41.618646159768105, 47.90112644433975, 53.644978031516075, 54.43859204649925, 55.56029565632343, 55.645072907209396, 51.85597322881222, 52.939599081873894, 51.67432397603989, 53.58489565551281, 50.195599123835564, 53.24851870536804, 54.33168098330498, 56.150536984205246, 55.11518754065037, 54.30320531129837, 53.95601414144039, 54.051784202456474, 55.4557366669178, 55.65301448106766, 53.829841911792755, 52.64125429093838, 48.50707232952118, 43.186130449175835, 40.394264459609985, 39.87137071788311, 44.3939184397459, 51.14287689328194, 55.175562500953674, 57.23523057997227, 50.65047271549702, 49.76431466639042, 59.93705280125141, 56.016385182738304, 56.07122763991356, 52.93272525072098, 61.58499397337437, 57.36862242221832, 38.047715574502945, 15.393394846469164, 8.906011506915092, 11.180995982140303, 14.448295310139656, 4.289124822244048, 1.6198192373849452, 0.6858450884465128, 1.5780628030188382, 33.883226439356804, 60.75395576655865, 55.01408636569977, 41.18787847459316, 45.71138754487038, 61.93845480680466, 54.8530700057745, 14.651080928742886, 0.5456028669141233, 0.11497654602862895, 0.17361887352308258, 0.1429841306526214, 0.11800015956396237, 0.17584113084012643, 0.12019702058751136, 0.08446374544291757, 0.16031470382586122, 0.19718509021913633, 0.1353072511847131, 0.23741785087622702, 0.12620806053746492, 0.20598838658770546, 0.1828807280980982, 0.14569912949809805, 0.20329397491877899], [0.10279316775267944, 0.0042642010430427035, 0.01986841765756253, 0.0375012601580238, 0.03670259793580044, 0.08480281787342392, 0.01443544024368748, 0.015319867834477918, 0.04519667476415634, 0.012506690272857668, 0.03508335415972397, 0.06908337309141643, 0.028599506767932326, 0.04118345554161351, 0.029954445781186223, 0.0014060515354685776, 0.044876252504764125, 0.02864804322598502, 0.044060442960471846, 0.04862464003963396, 2.7696124836802483, 25.871610939502716, 45.71151293814182, 37.19526931643486, 29.15935032069683, 28.183813467621803, 33.81043754518032, 39.616845175623894, 25.706680789589882, 2.2914801025763154, 0.13450055150315166, 0.25594589416868985, 2.1293195290490985, 3.9710025675594807, 5.236594956368208, 7.086841072887182, 2.6914834510535, 7.014007056131959, 16.20537042617798, 37.03951187431812, 49.945925921201706, 51.44467569887638, 46.36322356760502, 47.203905656933784, 44.385129511356354, 42.14051015675068, 37.33142741024494, 37.86059461534023, 39.18108455836773, 44.453096464276314, 46.78487554192543, 46.583775132894516, 49.22412425279617, 50.02126067876816, 50.643473491072655, 48.641657307744026, 47.77149260044098, 46.58644638955593, 44.34178523719311, 45.4397439211607, 49.39208664000034, 48.545408472418785, 51.09756052494049, 46.889385133981705, 49.83203083276749, 50.22111855447292, 49.72321607172489, 51.41431152820587, 47.67190754413605, 47.23077781498432, 42.59916454553604, 36.89782127737999, 35.63357211649418, 36.25039681792259, 36.0662928968668, 36.464864909648895, 36.77128426730633, 36.44828259944916, 37.1200143545866, 40.379240065813065, 35.239597856998444, 36.22868858277798, 34.84719671308994, 37.64843299984932, 37.47522309422493, 40.87060309946537, 45.18141858279705, 49.945694133639336, 49.557700753211975, 41.663331761956215, 48.732647225260735, 48.32437053322792, 47.31093071401119, 44.541301131248474, 42.301127538084984, 41.4791252464056, 39.164821431040764, 37.63137571513653, 34.86727483570576, 35.47289773821831, 35.932692065835, 37.31425233185291, 36.08834691345692, 36.96532465517521, 35.737561136484146, 40.61684891581535, 47.58284792304039, 50.16384422779083, 50.16200132668018, 51.03606842458248, 49.42888006567955, 50.25069996714592, 49.69395384192467, 50.82756221294403, 48.145597726106644, 51.646403074264526, 47.06357538700104, 48.344612047076225, 47.59152665734291, 50.07638432085514, 51.67104475200176, 53.19002844393253, 51.67487494647503, 52.23600223660469, 50.92491678893566, 50.43531686067581, 48.523730635643005, 46.03652469813824, 40.7142186909914, 38.12554679811001, 39.09928634762764, 47.41960108280182, 48.16855989396572, 56.892941147089005, 50.58363810181618, 49.13568399846554, 55.488977283239365, 54.276059567928314, 52.22162000834942, 51.683420687913895, 52.87310265004635, 49.84995447099209, 23.098362050950527, 8.603473640978336, 3.0942839244380593, 5.39892272092402, 3.5149788251146674, 2.683000643737614, 0.5304812220856547, 0.1700715857441537, 2.0372549816966057, 24.081754982471466, 45.80902710556984, 38.597325682640076, 38.39174911379814, 38.744028210639954, 46.68621003627777, 30.470150783658028, 4.2669810354709625, 0.0636243871122133, 0.13397963804891333, 0.017560809646965936, 0.05342574921087362, 0.026609769884089474, 0.0583729241770925, 0.020580287564371247, 0.025204220110026654, 0.05039032068452798, 0.05029738895245828, 0.041184995498042554, 0.03530196860083379, 0.02813474420690909, 0.07497134269215167, 0.03562662852345966, 0.07103030104190111, 0.05208678492635954, 0.08973997013526969, 0.10146927277673967, 0.038099030425655656, 0.043478599181980826, 0.016016301997296978, 0.039522265578852966, 0.0916532936389558, 0.027024632290704176, 0.030361734570760746, 0.07056395770632662, 0.04131925001274794, 0.15310110262362286, 0.02900469713495113, 0.02347745768929599, 0.04065054155944381, 0.06314075173577294, 0.03714808692166116, 0.011793801768362755, 0.04931042902171612, 0.07432211190462112, 4.517622236162424, 31.492465026676655, 53.06886814534664, 42.44715370237827, 32.60522961616516, 33.079527765512466, 36.49585984647274, 44.904778227210045, 23.724845834076405, 2.181589286774397, 0.08781255324720405, 0.37085157993715256, 2.26269593462348, 5.103122368454933, 7.873991634696722, 10.433938968926668, 4.929981809109449, 7.5994226429611444, 17.769011221826077, 37.015090584754944, 53.214692920446396, 51.81408807635307, 50.67036084830761, 48.72262716293335, 47.24676355719566, 44.37441028654575, 40.14565519988537, 38.86417016386986, 39.26276117563248, 44.193536192178726, 47.869382947683334, 47.88357138633728, 50.02760633826256, 51.326057463884354, 51.96799501776695, 49.74835552275181, 49.956952929496765, 48.804311379790306, 47.30695612728596, 48.94772708415985, 49.565357342362404, 49.03358727693558, 52.989080026745796, 51.167503371834755, 51.046757251024246, 50.0962420552969, 50.108390003442764, 52.11851254105568, 49.72629390656948, 49.04336415231228, 43.719336837530136, 39.406127482652664, 37.96761207282543, 37.186628580093384, 37.28470891714096, 37.018480002880096, 38.53351570665836, 38.45579847693443, 39.26767811179161, 40.02906605601311, 37.73061878979206, 37.29344844818115, 36.88237510621548, 39.111346900463104, 38.70461292564869, 41.45243547856808, 47.77570277452469, 51.04137293994427, 50.84080450236797, 42.700406312942505, 52.265857234597206, 51.040692776441574, 50.44710382819176, 46.998237892985344, 43.88591609895229, 42.81768321990967, 39.67831067740917, 38.30992430448532, 37.424495816230774, 35.95701836049557, 38.87050822377205, 38.21902938187122, 39.90528389811516, 37.4903766810894, 37.99025505781174, 43.695333525538445, 49.32800307869911, 51.467067897319794, 52.36705340445042, 52.57749371230602, 51.78557060658932, 52.80233144760132, 51.80100157856941, 52.048809081315994, 48.64802956581116, 51.788990423083305, 47.60029658675194, 49.82894539833069, 49.43694323301315, 51.268543750047684, 53.48418965935707, 55.43536216020584, 52.62781821191311, 53.29802244901657, 52.926873564720154, 51.884878277778625, 50.606026500463486, 47.796495258808136, 41.329371482133865, 39.427334144711494, 41.58577412366867, 49.063864052295685, 49.52113911509514, 57.57099196314812, 51.388408318161964, 50.215529054403305, 56.2585461884737, 56.510848850011826, 54.18349273502827, 54.49858322739601, 55.67255683243275, 51.5083222836256, 27.819576412439346, 10.45635586604476, 3.5551763931289315, 8.785670064389706, 7.204060982912779, 3.4695280389860272, 0.2587187656899914, 0.21897971135331318, 2.1102799382060766, 30.327251851558685, 53.3103071898222, 44.65617276728153, 39.905067309737206, 41.90276451408863, 54.41317521035671, 38.63645978271961, 7.2023035772144794, 0.08625690039480105, 0.025649722083471715, 0.02244269231596263, 0.043785091329482384, 0.04900314277620055, 0.008317709143739194, 0.015113291028683307, 0.048962502769427374, 0.022079238478909247, 0.03816410564468242, 0.06965657084947452, 0.0438880235014949, 0.027240383897151332, 0.04339241728303023, 0.040990289344335906, 0.12397209575283341, 0.039604350822628476, 0.22803656989708543, 0.28303078142926097, 0.3437285462860018, 0.12497989519033581, 0.10888200704357587, 0.17041422048350796, 0.16252520552370697, 0.10373814438935369, 0.16832094843266532, 0.11810046082246117, 0.12677372549660504, 0.24267198925372213, 0.14944528316846117, 0.12623051792616025, 0.1515378279145807, 0.16858542017871514, 0.07696995380683802, 0.10781163713545538, 0.13998089649248868, 0.1595234705018811, 5.339959384873509, 35.62699846923351, 59.16531041264534, 49.76031348109245, 40.13772502541542, 39.662218540906906, 45.34900479018688, 51.2676128000021, 33.55749651789665, 3.6109486129134893, 0.3800433163996786, 0.6590692314784974, 7.426437400281429, 10.373415816575289, 14.07261611893773, 16.045524403452873, 6.128401877358556, 11.028108336031437, 18.455735072493553, 42.2011549025774, 53.24862129986286, 55.840363427996635, 50.81247702240944, 52.043888345360756, 48.810923025012016, 46.374375969171524, 41.41181945800781, 41.642930656671524, 42.41718091070652, 47.917568162083626, 51.32811315357685, 50.5423267185688, 53.55594880878925, 54.52758327126503, 54.09784913063049, 52.87778779864311, 53.05833891034126, 51.832680478692055, 49.044492691755295, 49.69073161482811, 50.76382823288441, 51.10075235366821, 54.90472063422203, 51.6183377802372, 53.52121487259865, 54.40108805894852, 51.634825095534325, 54.34084229171276, 52.20096431672573, 52.14941628277302, 45.72693631052971, 42.51916363835335, 39.45895604789257, 39.17122408747673, 40.985668525099754, 37.97809951007366, 40.13284608721733, 40.89068882167339, 39.96781334280968, 42.80899688601494, 39.1027669608593, 40.35464398562908, 38.59257213771343, 42.70984500646591, 41.8393649160862, 44.32397559285164, 50.69091394543648, 52.4265506118536, 53.56294423341751, 45.88562339544296, 52.40355424582958, 53.83253216743469, 51.604400128126144, 48.58670845627785, 45.107109770178795, 46.04060187935829, 41.774354204535484, 41.132226660847664, 38.12481343746185, 39.51599858701229, 39.92680214345455, 40.40940664708614, 41.552978083491325, 39.77671779692173, 39.712486043572426, 45.47374069690704, 50.67504979670048, 54.815748408436775, 53.37757118046284, 53.7315221875906, 53.42678613960743, 53.73189456760883, 52.79598958790302, 52.38359771668911, 51.549614667892456, 53.61389569938183, 48.37485462427139, 49.95085045695305, 50.18762335181236, 53.293671682477, 54.20984052121639, 56.905271485447884, 55.44677294790745, 54.6710179746151, 54.1540253162384, 54.73089896142483, 53.25075298547745, 50.747318118810654, 43.63913834095001, 42.41271615028381, 43.514003455638885, 52.041186690330505, 51.589307337999344, 61.217648684978485, 52.23064832389355, 50.92317268252373, 57.01302610337734, 59.304310753941536, 56.387184485793114, 56.89195699989796, 57.05165483057499, 54.48228970170021, 26.564203575253487, 11.955057196319103, 5.7931221183389425, 14.54577337950468, 12.018235456198454, 7.107929941266775, 1.6618141089566052, 0.5429190234281123, 3.225020421668887, 33.154626935720444, 61.427424028515816, 53.880204409360886, 50.66406078636646, 50.50571948289871, 62.98424988985062, 44.88292559981346, 9.153348784893751, 0.18459891871316358, 0.24568346125306562, 0.06098279780417215, 0.11485104885650799, 0.13408741273451596, 0.11668471022858284, 0.0939753104466945, 0.1440410380018875, 0.12552875792607665, 0.07806561610777862, 0.23904394096462056, 0.13622567377751693, 0.07921098746010102, 0.18852404871722683, 0.1332738556084223, 0.24637983326101676, 0.21802703122375533], [0.042120810321648605, 0.09389495811774395, 0.06387041648849845, 0.032583633801550604, 0.0195678070303984, 0.02213662133726757, 0.048042250782600604, 0.03025234014785383, 0.0427698963903822, 0.040699011224205606, 0.04781723902851809, 0.024588693959231023, 0.02505695945728803, 0.05107842887809966, 0.01346900811768137, 0.0353064140654169, 0.03307112092443276, 0.009167735406663269, 0.03325552235764917, 0.018142386252293363, 0.536333026830107, 16.306916177272797, 39.24926050007343, 42.217820808291435, 29.27983995527029, 24.8603693023324, 35.03158941864967, 42.38191120326519, 39.002862721681595, 6.884403610602021, 0.12479254743084311, 0.2807318157283589, 0.8047335245646536, 4.431629050523043, 5.512728514149785, 8.04791685193777, 2.5150795793160796, 4.7912374790757895, 17.391733266413212, 35.59198334813118, 51.43190078437328, 47.74859122931957, 46.561006754636765, 44.583748653531075, 43.12087655067444, 41.66549004614353, 42.27726861834526, 42.781999334692955, 45.283587500452995, 45.02077840268612, 48.34553919732571, 50.72395317256451, 52.1857613325119, 48.793170377612114, 45.827193930745125, 46.06139816343784, 45.30449777841568, 44.39625911414623, 45.88926739990711, 46.74229882657528, 49.61030513048172, 51.17241270840168, 49.013220369815826, 47.59082369506359, 46.014922857284546, 46.7623845487833, 51.58907175064087, 49.62299644947052, 48.78412306308746, 47.529814168810844, 48.09967719018459, 42.87686504423618, 35.749032720923424, 33.96295376121998, 35.59484839439392, 35.45635722577572, 35.80830954015255, 35.38025110960007, 35.731986835598946, 36.57305270433426, 35.806763023138046, 36.65081933140755, 36.75543911755085, 39.09835919737816, 38.6357606202364, 42.56406582891941, 44.614534601569176, 47.86969073116779, 48.699847385287285, 43.95234413444996, 51.89186990261078, 47.429776936769485, 45.87644688785076, 43.587088733911514, 43.67033086717129, 42.854818627238274, 39.25709567964077, 38.612357676029205, 35.721662789583206, 35.644082352519035, 37.01783023774624, 37.48953692615032, 36.19675889611244, 36.502140909433365, 35.90084217488766, 39.90533709526062, 46.197704449296, 47.770846635103226, 49.391566067934036, 47.283925563097, 48.47084127366543, 51.137937158346176, 52.360593751072884, 49.35454845428467, 50.25795377790928, 51.405070424079895, 50.94197407364845, 49.721487164497375, 50.10067641735077, 48.86381238698959, 51.69907204806805, 50.59723377227783, 49.76942539215088, 51.18394508957863, 49.092780500650406, 51.340010315179825, 50.91882571578026, 47.958712354302406, 45.86237624287605, 43.59322540462017, 43.682968989014626, 47.002037689089775, 47.63807415962219, 51.29497893154621, 54.019250348210335, 48.240148052573204, 50.49990579485893, 53.03557053208351, 55.269109681248665, 54.76893112063408, 52.94244892895222, 36.912575885653496, 19.3719495087862, 4.166392358019948, 2.985636591911316, 3.0891425628215075, 7.139655388891697, 2.5795122468844056, 0.17083846178138629, 0.2408915472915396, 2.229899656958878, 22.849175222218037, 42.80629523098469, 34.04141195118427, 28.849666938185692, 45.77411077916622, 46.96214742958546, 31.651311703026295, 3.5740960529074073, 0.050617696178960614, 0.07228821166791022, 0.042732466172310524, 0.05570042441831902, 0.029438827550620772, 0.0487371718918439, 0.04280968292732723, 0.082832571642939, 0.055977089650696144, 0.030937815572542604, 0.02129428929038113, 0.04782068259373773, 0.04791984465555288, 0.01259641499927966, 0.04683275044953916, 0.009659258885221789, 0.034691592954914086, 0.013649899192387238, 0.05966411641566083, 0.023923967128212098, 0.018651072823558934, 0.029589309124276042, 0.023693313196417876, 0.0335760967573151, 0.05192527132749092, 0.059626723304972984, 0.06281748705077916, 0.01360286836643354, 0.05259549376205541, 0.03655445783806499, 0.019566716073313728, 0.014132112428342225, 0.024465770184178837, 0.031033172272145748, 0.04036819147586357, 0.01284768301047734, 0.01519315539553645, 0.9773739357478917, 22.04603511840105, 46.317052245140076, 49.316026121377945, 33.9562813192606, 28.80797177553177, 37.478597313165665, 43.92782784998417, 40.08465327322483, 7.235001772642136, 0.039117813648772426, 0.13710979430470616, 1.0693052527494729, 4.759359564632177, 5.600249217823148, 13.18514809012413, 7.265542633831501, 5.348901255056262, 17.635976560413837, 37.783162370324135, 53.21639142930508, 49.146384224295616, 49.514516070485115, 47.12072052061558, 45.368763729929924, 44.58614632487297, 43.39416928589344, 43.847887739539146, 47.11895741522312, 49.269968792796135, 49.751174971461296, 51.44635520875454, 53.808205872774124, 50.50438575446606, 48.27971912920475, 47.11975537240505, 47.93882802128792, 47.90666654706001, 47.07043021917343, 48.195291459560394, 51.39424480497837, 52.09367707371712, 51.20616249740124, 48.90040822327137, 48.55188712477684, 49.68667343258858, 52.915968149900436, 50.839432775974274, 50.41911832988262, 49.9839922785759, 49.57511141896248, 43.610138297080994, 37.3051518201828, 36.750290393829346, 37.40086868405342, 38.80268186330795, 37.69996963441372, 38.08006323873997, 36.7066915333271, 38.61359640955925, 38.67673002183437, 38.527462631464005, 39.193129912018776, 39.92193080484867, 41.14944353699684, 44.9378402531147, 47.69948646426201, 51.90374046564102, 50.880432575941086, 47.3587017506361, 53.011270835995674, 48.16564165055752, 50.03065377473831, 44.73050057888031, 45.11065497994423, 45.600441098213196, 41.282223612070084, 39.953260123729706, 36.73297852277756, 36.09048239886761, 37.73182712495327, 39.28299508988857, 38.136665001511574, 38.81938576698303, 37.5833310931921, 40.433786138892174, 48.82473528385162, 48.80446337163448, 51.312252804636955, 48.41934643685818, 49.2745665460825, 52.64081351459026, 53.59584666788578, 51.31287217140198, 52.92806290090084, 53.140878081321716, 52.411317229270935, 51.58258929848671, 51.1487627774477, 50.941385105252266, 52.770333364605904, 53.53320322930813, 51.475951820611954, 52.00581818819046, 51.31830967962742, 52.19824746251106, 53.81078213453293, 50.08194342255592, 46.71274021267891, 45.308996737003326, 44.72887806594372, 48.29302221536636, 50.562575832009315, 54.319365844130516, 54.212887957692146, 49.03551757335663, 50.82043379545212, 56.095664128661156, 57.950245812535286, 56.430600956082344, 56.47205293178558, 40.913620591163635, 20.81640399992466, 5.371981216594577, 5.214077839627862, 5.4003386199474335, 6.829875111579895, 3.4656467847526073, 0.307341669104062, 0.13667820574482903, 2.412161626853049, 25.981425046920776, 49.225172996520996, 41.536350175738335, 39.396343007683754, 52.50370927155018, 52.481317073106766, 37.73625008761883, 5.4999431502074, 0.027912923687836155, 0.03969689292716794, 0.04026454313134309, 0.08953906333772466, 0.03424706505029462, 0.06487091319286264, 0.025449765234952793, 0.012312775434111245, 0.04439170799741987, 0.016146871748787817, 0.044917475097463466, 0.03701389920024667, 0.05030382708355319, 0.007015780811343575, 0.016736905126890633, 0.07383302174275741, 0.032302077815984376, 0.085242161876522, 0.22890601074323058, 0.160880888288375, 0.20399005006765947, 0.0986048870254308, 0.092254485207377, 0.10886317875701934, 0.1856651177513413, 0.16761406761361286, 0.16293405467877164, 0.1435703382594511, 0.10702798113925382, 0.25512451480608433, 0.16166150890057907, 0.14828592975391075, 0.10848768914001994, 0.1339233832550235, 0.15541436208877712, 0.11543370899744332, 0.1087059176643379, 1.2651269137859344, 24.613631442189217, 53.83117564022541, 55.60078248381615, 40.86562156677246, 35.96975527703762, 46.00624792277813, 51.30271911621094, 48.69837686419487, 9.340799376368523, 0.44861924601718783, 0.6810163788031787, 4.322825688868761, 10.679607186466455, 14.360384177416563, 17.2961512953043, 7.742579011246562, 7.854215120896697, 20.63266295939684, 44.602443650364876, 56.37320123612881, 50.7947813719511, 50.67414924502373, 49.515861198306084, 47.41160251200199, 46.93468250334263, 45.95589302480221, 48.17118555307388, 49.19957377016544, 51.88711255788803, 52.076764181256294, 54.01412442326546, 55.25976978242397, 51.948205679655075, 49.63921397924423, 50.18183246254921, 50.406996980309486, 49.853689670562744, 49.30282182991505, 52.12657190859318, 53.24354097247124, 52.759135365486145, 53.747880309820175, 51.81990936398506, 50.13629950582981, 50.91923989355564, 55.230933129787445, 53.50264146924019, 53.04813265800476, 51.701686307787895, 52.97598972916603, 46.20235539972782, 40.096337646245956, 37.67141416668892, 39.53506596386433, 40.63690423965454, 39.973231852054596, 39.30346839129925, 38.23205508291721, 40.6035952270031, 40.694919526576996, 41.1164765059948, 41.72693654894829, 42.00191639363766, 43.651248291134834, 47.09293641149998, 49.88922916352749, 54.10802498459816, 52.089018523693085, 49.26593340933323, 55.50618655979633, 50.78231044113636, 51.406871527433395, 46.772119626402855, 47.178686410188675, 46.42685875296593, 43.59672121703625, 41.96588672697544, 38.56286533176899, 37.963420897722244, 40.48456661403179, 41.07013039290905, 40.648569613695145, 40.67446522414684, 38.80116194486618, 43.3373699337244, 50.808168053627014, 50.942251458764076, 53.68012994527817, 49.1998815536499, 51.06538005173206, 54.96527038514614, 56.00498579442501, 53.16965773701668, 54.02707792818546, 55.5728729814291, 53.77998098731041, 54.73420478403568, 53.54884319007397, 52.49390199780464, 54.110054075717926, 54.96199496090412, 51.571368500590324, 53.29283192753792, 51.45495794713497, 53.918886333703995, 54.94343675673008, 53.37110012769699, 49.53726924955845, 48.39471995830536, 47.24656976759434, 51.83515414595604, 53.20152662694454, 56.07783928513527, 56.08993023633957, 48.974511846899986, 51.81370809674263, 55.33060938119888, 60.21529667079449, 59.76532481610775, 58.7285428494215, 41.989130079746246, 22.94151596724987, 6.480151852592826, 6.326140416786075, 9.202969372272491, 15.925140213221312, 6.5306919906288385, 0.39248275046702474, 0.43508612376172096, 3.4485541144385934, 31.065345145761967, 54.63067553937435, 48.11030901968479, 44.70617428421974, 58.30907195806503, 63.79824221134186, 44.3823366612196, 7.892818674445152, 0.15608419489581138, 0.1476916772662662, 0.18312899133889005, 0.2629068534588441, 0.12431066352291964, 0.17907437140820548, 0.10086504582432099, 0.2422169191413559, 0.11485392096801661, 0.1377122846315615, 0.11156611028127372, 0.130204095330555, 0.2557159768184647, 0.19438719347817823, 0.0849177542841062, 0.13809793425025418, 0.19170985120581463], [0.03401722191483714, 0.018046968325506896, 0.024461076100124046, 0.033568345024832524, 0.025246806399081834, 0.03794745418417733, 0.01694650618446758, 0.055819954723119736, 0.02211618444562191, 0.09312659036368132, 0.08274930267361924, 0.015513786383962724, 0.026307906882721, 0.015898233723419253, 0.07834352072677575, 0.028984393829887267, 0.09303889077273197, 0.05491706157044973, 0.014852253571007168, 0.051048898822045885, 0.15341158752562478, 10.025385841727257, 36.30154587328434, 39.982096776366234, 32.82179519534111, 25.393748581409454, 30.602396987378597, 39.87115032970905, 42.138507664203644, 13.835603836923838, 0.03885043268383015, 0.1408142244326882, 0.39063417934812605, 3.6404103320091963, 3.6834784084931016, 14.934701509773731, 9.00000611320138, 5.401111878454685, 20.55266585201025, 35.56016385555267, 52.77461193501949, 48.1506210565567, 48.46552915871143, 45.02293288707733, 47.5716233253479, 47.166800647974014, 46.51016928255558, 44.40546602010727, 48.19799691438675, 48.60404692590237, 53.02908428013325, 50.98535634577274, 47.22553789615631, 46.42931342124939, 46.27307340502739, 44.70444917678833, 41.87670551240444, 37.716988921165466, 41.804418191313744, 45.17229147255421, 48.08551535010338, 48.181426003575325, 48.42170991003513, 44.01954732835293, 43.988632187247276, 46.40624865889549, 51.39805980026722, 49.35901701450348, 50.65618380904198, 49.016906172037125, 51.55704326927662, 47.397079691290855, 39.4006671756506, 34.81745570898056, 35.74965588748455, 35.71791999042034, 36.00029803812504, 36.02128051221371, 35.18467180430889, 35.14331862330437, 35.27933992445469, 36.11950904130936, 37.917466163635254, 38.77357542514801, 40.33864304423332, 43.27822230756283, 46.21392197906971, 50.669851675629616, 49.48900803923607, 44.58734706044197, 50.689223036170006, 46.001159995794296, 47.46770650148392, 43.57180215418339, 42.76397690176964, 41.69033691287041, 40.345600470900536, 35.42931407690048, 35.224455669522285, 35.14127433300018, 36.664760783314705, 35.700661316514015, 36.67855404317379, 35.65165534615517, 36.619862392544746, 38.006708174943924, 46.68249003589153, 48.0204476416111, 50.67879639565945, 48.09825986623764, 51.66065230965614, 49.39611442387104, 46.20852626860142, 46.205102652311325, 47.2419910132885, 48.15548859536648, 50.48982873558998, 48.321353495121, 49.906324446201324, 47.66309581696987, 49.20993201434612, 47.35969349741936, 48.354628309607506, 50.593840554356575, 52.220749855041504, 50.16746923327446, 52.968310341238976, 50.387941002845764, 50.83155959844589, 48.77604089677334, 47.87208080291748, 48.75234156847, 50.233889669179916, 54.06519368290901, 51.150970458984375, 50.42026586830616, 52.55391217768192, 53.40461052954197, 55.94316691160202, 52.77314521372318, 48.610529378056526, 30.183834247291088, 10.185155868530273, 1.7860218440182507, 4.157260498031974, 7.276559667661786, 1.91078114323318, 1.388528379611671, 0.6114532146602869, 0.06701036167214625, 3.490587458945811, 24.845973774790764, 43.4398428350687, 32.46006220579147, 33.5985267162323, 45.6366303563118, 47.044724598526955, 23.998134769499302, 3.361416715197265, 0.015135971989366226, 0.019022552987735253, 0.05077487563539762, 0.010919238247879548, 0.030693943990627304, 0.10899453889578581, 0.015385400402010418, 0.08253902997239493, 0.04144444661505986, 0.008157539759849897, 0.011694584045471856, 0.051056965967291035, 0.03861146113194991, 0.06253438739804551, 0.029838132686563767, 0.04513857202255167, 0.007610291659148061, 0.02380116580752656, 0.02287156461534323, 0.05999014560075011, 0.016725637469789945, 0.028371472617436666, 0.029258385475259274, 0.055870873475214466, 0.04796367218659725, 0.008765406946622534, 0.031215165436151437, 0.029210587454144843, 0.045065199592499994, 0.024775403471721802, 0.008306948930112412, 0.020845419821853284, 0.013233798326837132, 0.0521039025625214, 0.033665061710053124, 0.02465373392624315, 0.06941472718608566, 0.2956821135012433, 13.030900117009878, 43.13547156751156, 47.635581493377686, 37.840246707201004, 32.55133330821991, 39.90252524614334, 44.9018219858408, 47.66335040330887, 13.376817405223846, 0.24694043677300215, 0.16031777631724253, 0.9680082101840526, 5.119556011632085, 5.911373198032379, 12.362722121179104, 6.8298884108662605, 4.450026238337159, 18.86159509420395, 39.666599705815315, 53.564680740237236, 52.38891743123531, 49.38766747713089, 47.582414746284485, 47.6854994148016, 48.19921664893627, 47.6927874237299, 47.58981294929981, 49.03997853398323, 49.44649212062359, 54.531162679195404, 53.16963493824005, 49.1540902107954, 48.18354249000549, 47.13174372911453, 47.08463005721569, 43.76506358385086, 40.3363099694252, 43.58293175697327, 46.64226159453392, 51.38985984027386, 51.219503581523895, 48.915246427059174, 45.33110775053501, 45.16549363732338, 47.36803784966469, 52.49870494008064, 53.195131570100784, 51.88414491713047, 50.882207080721855, 52.33749099075794, 48.82494047284126, 41.05698309838772, 37.1052635461092, 36.456315368413925, 37.14843302965164, 37.36978255212307, 37.573474422097206, 37.293889224529266, 37.930647656321526, 37.87282235920429, 39.10667695105076, 39.007038697600365, 40.94579726457596, 41.45483314990997, 45.77833995223045, 47.89684407413006, 51.870024874806404, 52.73259378969669, 48.5677170753479, 53.617418110370636, 48.29746037721634, 49.17560085654259, 45.447955280542374, 44.53886926174164, 42.98489324748516, 42.35957980155945, 38.30606751143932, 37.30804726481438, 37.26719185709953, 38.46921555697918, 38.501069247722626, 37.81187362968922, 38.37390527129173, 37.58089542388916, 39.29923161864281, 49.211957305669785, 50.534096360206604, 53.04931439459324, 49.00430604815483, 53.06815378367901, 53.18933308124542, 49.10410389304161, 49.22489181160927, 47.339771166443825, 49.24527391791344, 51.49379186332226, 50.61680272221565, 53.05765114724636, 50.0859560072422, 50.70532277226448, 50.105912536382675, 50.3390072286129, 51.862307488918304, 52.99220725893974, 51.23343363404274, 54.079097136855125, 52.740869745612144, 51.412445828318596, 50.46368233859539, 49.96044874191284, 50.64803324639797, 52.46163792908192, 56.10857963562012, 52.53531597554684, 52.15773783624172, 51.346827149391174, 53.73209975659847, 55.25775969028473, 57.2215361148119, 50.47545790672302, 33.273188173770905, 10.542635936290026, 3.398336246609688, 8.491673190146685, 6.133285565301776, 9.35814069584012, 3.6201733304187655, 0.461328198434785, 0.09158270797342993, 3.5226909862831235, 29.09661378711462, 47.883404195308685, 37.10264168679714, 36.445991322398186, 53.30623760819435, 53.689861223101616, 30.312297753989697, 3.9563294174149632, 0.0344883075740654, 0.03986401716247201, 0.02317367438081419, 0.032895443437155336, 0.02251764923130395, 0.04258527602360118, 0.028686009645753074, 0.01224721967446385, 0.02203820327849826, 0.028068440733477473, 0.008284210452984553, 0.04289448443159927, 0.021328044022084214, 0.019838869047816843, 0.043348177860025316, 0.026048561521747615, 0.07456106119207107, 0.07940114795928821, 0.1474163998500444, 0.11947252118261531, 0.1579676172696054, 0.08893053935025819, 0.16151030373293906, 0.1934388920199126, 0.11150799269671552, 0.11530330622917973, 0.17107712163124233, 0.23393067705910653, 0.16764053259976208, 0.08059107785811648, 0.08056868726271205, 0.17716503323754296, 0.1362747891107574, 0.20404124341439456, 0.08004525792784989, 0.10934029807685874, 0.1649318271665834, 0.6561768741812557, 15.919934492558241, 50.58548100292683, 55.91816805303097, 43.977559581398964, 35.81991411745548, 41.351486295461655, 50.46914264559746, 53.76790143549442, 17.73579530417919, 0.4098791372962296, 0.37634709442500025, 2.3648166423663497, 9.86619908362627, 10.013824962079525, 27.16999936848879, 18.06594628840685, 7.370867282152176, 24.897202625870705, 41.53047189116478, 55.14054358005524, 53.3485559374094, 52.80419334769249, 49.13655415177345, 52.49516353011131, 52.60314993560314, 51.692202016711235, 48.76378655433655, 53.02715018391609, 52.46484495699406, 56.300077959895134, 55.14167211949825, 51.53197981417179, 52.09281072020531, 50.997409299016, 49.93114851415157, 46.127351224422455, 41.19008995592594, 46.120370998978615, 48.0650420486927, 51.76779896020889, 53.308855667710304, 51.992230117321014, 47.588692009449005, 47.409041449427605, 49.64223861694336, 55.142394080758095, 54.146000146865845, 53.10102961957455, 51.701351925730705, 54.92925971746445, 52.22240276634693, 43.720252588391304, 38.22931542992592, 39.21856954693794, 38.81803683936596, 40.49972020089626, 39.01816450059414, 38.82862687110901, 39.19999234378338, 38.92825372517109, 40.808419436216354, 43.43853570520878, 42.868710681796074, 45.36909431219101, 47.37544745206833, 51.19253642857075, 54.99506838619709, 52.8123477101326, 51.004207134246826, 55.97909018397331, 49.840382784605026, 50.37703178822994, 47.917465567588806, 46.05834312736988, 45.114082396030426, 45.080792382359505, 39.03054043650627, 38.48164848983288, 39.821297004818916, 40.81682838499546, 40.822338089346886, 39.73332792520523, 39.83048491179943, 39.44651931524277, 41.93646490573883, 51.878471821546555, 52.42631122469902, 55.82393690943718, 51.29316262900829, 53.0626554787159, 55.7989988476038, 50.577566027641296, 50.997971668839455, 50.37578925490379, 51.77518956363201, 54.048501178622246, 52.48658359050751, 53.965585827827454, 51.43862642347813, 53.88977229595184, 52.79612638056278, 52.39640682935715, 56.200443506240845, 55.06944179534912, 51.89824976027012, 54.32531252503395, 55.04497490823269, 53.97073835134506, 53.995961397886276, 52.794173285365105, 52.262426018714905, 54.79804515838623, 56.68054774403572, 51.92801356315613, 51.09243839979172, 52.43585251271725, 53.39334033429623, 54.72214803099632, 56.05542428791523, 51.26691363751888, 33.821160569787025, 12.25576926022768, 3.2770030573010445, 7.015369758009911, 14.270267263054848, 9.276801310479641, 7.944749537855387, 1.644990867935121, 0.2494410885265097, 5.090426774695516, 33.85427579283714, 57.63080455362797, 45.175103321671486, 50.439641028642654, 58.19197744131088, 63.01589459180832, 35.39043456315994, 5.152449896559119, 0.11526408372446895, 0.1725225878180936, 0.13060724479146302, 0.08758830590522848, 0.1381112780654803, 0.1335640501929447, 0.11394982924684882, 0.1442194206174463, 0.14336390246171504, 0.13816754770232365, 0.09743787464685738, 0.09597405514796264, 0.0770252883376088, 0.12331346195423976, 0.11073529080022126, 0.1568198562017642, 0.2060899420757778], [0.035275570407975465, 0.021794465283164755, 0.03130290213448461, 0.05378631052735727, 0.012464239425753476, 0.01548497806652449, 0.03858642478007823, 0.06657500300207175, 0.060854524999740534, 0.023240374903252814, 0.07178464962635189, 0.05344173878256697, 0.03586381149943918, 0.01515586989626172, 0.055631612485740334, 0.08422889281064272, 0.045273531577549875, 0.003512003063406155, 0.04140755074331537, 0.05321261181961745, 0.08070350580965169, 5.6235220190137625, 28.553260043263435, 47.25283183157444, 33.585128635168076, 20.225465409457684, 32.87842735648155, 37.1722387522459, 48.98519307374954, 19.13996245712042, 1.166146737523377, 0.05473022589285392, 0.4130559746408835, 4.167607817798853, 3.8632139889523387, 6.52728452347219, 4.18348241597414, 4.983439240604639, 17.81689815223217, 37.188729867339134, 51.91151864826679, 51.092290207743645, 47.448411136865616, 47.62810729444027, 49.17236343026161, 48.78662712872028, 48.430020064115524, 50.49052029848099, 50.67842401564121, 53.31700623035431, 50.692677050828934, 48.077015206217766, 48.25861506164074, 43.8055732101202, 39.49708320200443, 37.233312875032425, 34.92649845778942, 35.99771797657013, 36.88620150089264, 39.608778208494186, 42.82924219965935, 44.611069187521935, 40.61469063162804, 37.09518648684025, 39.413613080978394, 44.65233497321606, 47.99857221543789, 50.32870598137379, 48.76729756593704, 51.27992033958435, 49.58342917263508, 50.56775875389576, 39.31546434760094, 35.30986748635769, 36.92924179136753, 35.27927152812481, 35.78755125403404, 36.217479184269905, 34.0561817586422, 35.07060572504997, 34.793004021048546, 35.38283497095108, 35.33773139119148, 38.353678956627846, 41.5618772059679, 44.569985792040825, 47.15736195445061, 50.95898576080799, 51.536896750330925, 42.71891891956329, 50.460213124752045, 48.99580970406532, 45.608622059226036, 45.128445625305176, 43.21047954261303, 43.07172618806362, 38.43999132514, 37.78524845838547, 36.82496778666973, 36.20784290134907, 35.79415149986744, 36.54440604150295, 37.10287347435951, 34.96790863573551, 35.96921570599079, 40.27726113796234, 49.072679579257965, 48.060155510902405, 51.6009309142828, 49.92965519428253, 49.700409695506096, 48.18709909915924, 47.85729579627514, 45.96045657992363, 44.2354479432106, 45.60359872877598, 46.654056161642075, 46.80061049759388, 46.97954669594765, 46.21904410421848, 45.59694528579712, 44.15047310292721, 46.27048574388027, 47.90872223675251, 49.35936279594898, 48.66308435797691, 49.693908244371414, 49.88900497555733, 52.02658027410507, 50.64086303114891, 51.73677742481232, 50.276063606143, 50.37820592522621, 51.62770427763462, 52.002109587192535, 52.96142891049385, 53.88018921017647, 54.47000876069069, 54.30617295205593, 54.073481038212776, 37.709450125694275, 20.719965174794197, 4.6056867856532335, 2.5264963041990995, 9.627266954630613, 1.9476582831703126, 8.352768793702126, 2.133242106065154, 0.33431045478209853, 0.10150249872822315, 4.902879288420081, 29.544338062405586, 47.45921775698662, 40.23882620036602, 37.32458397746086, 53.32347348332405, 52.306074276566505, 17.16113694012165, 1.8645662418566644, 0.10633053301717155, 0.03373454528627917, 0.038297629143926315, 0.027894069426110946, 0.009841137016337598, 0.04664526910346467, 0.03754009674594272, 0.028213048208272085, 0.03567040781490505, 0.039700414417893626, 0.011385997186152963, 0.05761599291872699, 0.05528408699319698, 0.0735792369232513, 0.05176370948902331, 0.05016280418203678, 0.06523767515318468, 0.035217515905969776, 0.014446128097915789, 0.04789731676282827, 0.04404623083246406, 0.022566063234989997, 0.028430102283891756, 0.05153757338121068, 0.0820639738230966, 0.08929035480832681, 0.009229698243871098, 0.03608474144130014, 0.0395203768130159, 0.05987615913909394, 0.020133696489210706, 0.03657123779703397, 0.1049539826635737, 0.060494876524899155, 0.026464795046194922, 0.025744141821633093, 0.10176870709983632, 0.07037434639642015, 7.207382954657078, 37.05502264201641, 52.64576844871044, 39.37465377151966, 24.06619481742382, 35.02507656812668, 43.943080231547356, 53.12432236969471, 20.893112383782864, 1.1776803061366081, 0.073653577856021, 0.6938755419105291, 4.2818130645900965, 5.602803155779839, 8.077650256454945, 7.064309706911445, 4.692938653752208, 17.577653490006924, 41.47443249821663, 52.934309765696526, 52.188474386930466, 49.247390404343605, 50.083873718976974, 50.54302968084812, 51.090242117643356, 50.33532902598381, 51.65219396352768, 52.90352001786232, 53.6810988932848, 53.16023424267769, 50.450633838772774, 48.60393673181534, 46.52542546391487, 42.63819985091686, 41.767510771751404, 37.29553073644638, 37.8928092867136, 38.25902223587036, 42.35017530620098, 43.908076509833336, 47.20672510564327, 43.86428005993366, 39.355027824640274, 41.4011762291193, 46.15256667137146, 53.50635007023811, 50.98824419081211, 51.067834720015526, 51.67668744921684, 51.98977544903755, 52.614575922489166, 40.77397808432579, 35.18550395965576, 38.55356343090534, 36.01602539420128, 37.021436244249344, 38.018962517380714, 36.172588393092155, 36.17865666747093, 36.96501687169075, 37.35472396016121, 37.75279439985752, 41.12835846841335, 43.937806114554405, 46.78151272237301, 48.67812395095825, 53.2034645229578, 52.85605676472187, 45.324173122644424, 52.822230979800224, 49.73017729818821, 48.19137006998062, 46.59489333629608, 45.61432935297489, 44.35062736272812, 40.77508382499218, 38.51369597017765, 37.47220605611801, 38.186624720692635, 37.735243141651154, 38.21141459047794, 38.79640839993954, 36.35554477572441, 37.17785865068436, 41.7619364708662, 50.54165415465832, 51.17006443440914, 54.128524884581566, 50.551024451851845, 52.55100153386593, 50.61265714466572, 48.54296900331974, 48.44863906502724, 46.14988021552563, 48.46494019031525, 49.57308612763882, 49.39629301428795, 49.647687524557114, 48.394149988889694, 47.45794102549553, 47.08716072142124, 49.23942603170872, 49.99095730483532, 52.99284942448139, 52.36685201525688, 52.48365394771099, 51.17128796875477, 52.57093906402588, 52.29111447930336, 53.86999815702438, 52.92557403445244, 52.69363448023796, 54.58059802651405, 51.53708674013615, 54.77124139666557, 54.8706516623497, 53.57111379504204, 54.89439658820629, 54.77507919073105, 40.877157747745514, 24.105292819440365, 7.006633076816797, 3.145368858240545, 9.024215564131737, 6.34250613860786, 5.936827082186937, 2.802423960529268, 0.8033565734513104, 0.12821669806726277, 5.474132085219026, 31.406283751130104, 52.184142619371414, 41.997953206300735, 44.18286636471748, 57.2683572024107, 59.98334191739559, 21.84624183923006, 2.3977031651884317, 0.047267396657844074, 0.07431955891661346, 0.022728061085217632, 0.09309904926340096, 0.028050089276803192, 0.027332501122145914, 0.020151723256276455, 0.026167919277213514, 0.08447508545941673, 0.04222467388899531, 0.005934333421464544, 0.0464098004886182, 0.08567273369408213, 0.07212588912807405, 0.006949000508029712, 0.07710713980486616, 0.045601108140544966, 0.11031070811441168, 0.0685229328519199, 0.14111872762441635, 0.13219524786109105, 0.057108805485768244, 0.07377788017038256, 0.10625811424688436, 0.13609691115561873, 0.2401045145234093, 0.04777908521646168, 0.18196398275904357, 0.13392448163358495, 0.1502069493290037, 0.19051987677812576, 0.23544887371826917, 0.20749608927872032, 0.15263838839018717, 0.1094126574753318, 0.13810281758196652, 0.19828422577120364, 0.14853551401756704, 9.127554818987846, 42.71110653877258, 60.775048434734344, 45.340698435902596, 29.88144837319851, 45.09069085121155, 48.80472935736179, 58.22487607598305, 24.335442669689655, 1.6342545440420508, 0.2592916146386415, 2.1167968260124326, 9.29634366184473, 10.454673506319523, 16.29180058836937, 8.730834256857634, 8.262645229697227, 20.92081669718027, 42.263612151145935, 56.37580409646034, 54.85527388751507, 52.547878101468086, 53.180031180381775, 54.369279965758324, 54.02974158525467, 51.74161076545715, 53.992666974663734, 54.00469712913036, 55.669931173324585, 54.95951749384403, 52.619394063949585, 53.11281278729439, 48.51316720247269, 44.263809621334076, 42.285958752036095, 38.498960360884666, 39.859454557299614, 39.40884053707123, 43.256069496273994, 45.8705648034811, 48.043561801314354, 45.79499825835228, 40.87073229253292, 43.56148190796375, 48.50928381085396, 55.29371716082096, 55.37275291979313, 52.3539213091135, 52.78416842222214, 53.003116473555565, 55.27319826185703, 43.33152584731579, 38.70325639843941, 39.177866131067276, 38.22304956614971, 38.95212024450302, 39.68797355890274, 37.922732681035995, 38.56702610850334, 37.91300520300865, 39.46639604866505, 39.13100324571133, 42.759455144405365, 46.2605606764555, 49.986142963171005, 51.22340217232704, 54.38705921173096, 54.00988385081291, 47.87779949605465, 54.682755544781685, 52.01379016041756, 49.81571450829506, 49.093662053346634, 47.93412767350674, 47.17445343732834, 43.33597920835018, 40.32148316502571, 40.1311019808054, 40.45591615140438, 39.813526421785355, 40.40672019124031, 42.05511353909969, 38.49991790950298, 39.57306772470474, 43.8996447622776, 53.02895128726959, 52.62864276766777, 54.86459098756313, 51.2334830313921, 54.85912688076496, 52.81893655657768, 52.204604521393776, 51.089090779423714, 47.622658386826515, 49.87857833504677, 50.50787776708603, 52.16270036995411, 52.01915927231312, 51.477281749248505, 50.25203749537468, 47.87323214113712, 52.78430141508579, 51.41009375452995, 54.6980307251215, 52.596857473254204, 53.86108383536339, 52.75610312819481, 53.82843978703022, 53.73423144221306, 57.24788770079613, 55.47901041805744, 54.06342297792435, 56.32156200706959, 57.14638754725456, 53.74053530395031, 54.74700629711151, 55.5945698171854, 56.14144027233124, 54.09960463643074, 41.35382317006588, 23.454444743692875, 7.918283483013511, 6.065514301881194, 16.47815588861704, 8.339512255042791, 12.762703858315945, 5.293265115469694, 0.9841995569877326, 0.3514900157460943, 6.5077863447368145, 40.2122238278389, 61.92482113838196, 52.854498848319054, 49.79359969496727, 66.2016436457634, 66.56808078289032, 27.477752454578876, 2.6553340908139944, 0.14221240096958354, 0.151462247595191, 0.08217273556510918, 0.16205279884161428, 0.13970551517559215, 0.08630547396023758, 0.09389611586811952, 0.07477507431758568, 0.10708629168220796, 0.14069387776544318, 0.16382172267185524, 0.17104580299928784, 0.17969180858926848, 0.15879226208198816, 0.1631385163636878, 0.297933611436747, 0.14680041727842763], [0.011742452570615569, 0.049501209214213304, 0.04013747631688602, 0.022418023327190895, 0.05549654160859063, 0.06244718504603952, 0.009446243948332267, 0.06908746974659152, 0.02292360586579889, 0.06681967424810864, 0.004360726161394268, 0.05280211509671062, 0.03066149729420431, 0.07378687500022352, 0.039933968291734345, 0.03478234648355283, 0.02529270637751324, 0.026633455527189653, 0.06323120469460264, 0.03297773277154192, 0.0709625355375465, 2.4413879960775375, 24.38017576932907, 46.847469583153725, 36.55529245734215, 32.073227763175964, 29.875862672924995, 33.29919397830963, 45.40290869772434, 23.636665865778923, 2.1513495594263077, 0.09775132813956589, 0.7309243257623166, 4.097325839102268, 5.585481785237789, 6.979390438646078, 4.747606795281172, 3.819092893972993, 14.132129475474358, 35.43766602873802, 52.3220220208168, 51.747751235961914, 50.01943677663803, 49.679108038544655, 50.294393822550774, 53.2504528015852, 52.32076048851013, 53.228653371334076, 49.32282395660877, 48.51533688604832, 47.29233071208, 45.164828673005104, 41.674985736608505, 37.88619764149189, 35.85679493844509, 35.286377146840096, 35.807515382766724, 36.02492071688175, 33.88503894209862, 34.3341938406229, 37.695292085409164, 35.44085405766964, 36.4838182926178, 36.84902049601078, 36.747322753071785, 39.36098590493202, 44.43977437913418, 47.782044634222984, 48.31975758075714, 50.09942248463631, 52.00640715658665, 47.9376120865345, 39.67708334326744, 34.30612854659557, 35.138496682047844, 37.03814014792442, 36.11159786581993, 34.485437124967575, 35.200820937752724, 36.12299345433712, 36.84920288622379, 35.0220937281847, 35.926745384931564, 37.0093946903944, 38.34153860807419, 43.417222648859024, 47.3238006234169, 50.41680045425892, 49.882803708314896, 42.82734990119934, 52.543873116374016, 48.84266272187233, 46.44110418856144, 44.9510445445776, 44.86858516931534, 41.26790598034859, 40.779221802949905, 38.165642246603966, 37.23393224179745, 35.311964973807335, 34.74112540483475, 34.73400458693504, 37.386543452739716, 36.17513045668602, 35.337571799755096, 42.29255519807339, 49.75568152964115, 50.208324640989304, 51.34837366640568, 47.51621089875698, 52.410374879837036, 46.14180184900761, 44.876161962747574, 37.53912426531315, 37.016291320323944, 38.49983811378479, 41.43185198307037, 41.2639731913805, 40.69043956696987, 39.66235913336277, 39.11478951573372, 39.59274306893349, 42.02940031886101, 43.54999512434006, 47.116696536540985, 46.714647710323334, 47.706633880734444, 52.04532466828823, 50.39339751005173, 51.72037750482559, 52.127924636006355, 53.34724500775337, 52.94584974646568, 50.187737345695496, 53.15920069813728, 55.72836063802242, 53.25666546821594, 56.31768621504307, 54.7715225815773, 50.88950648903847, 30.112339183688164, 13.5267355106771, 3.6396812461316586, 2.27394784335047, 6.966182347387075, 5.4534645192325115, 9.467464629560709, 2.44000724516809, 0.6264212646055967, 0.3005362639669329, 5.085051013156772, 31.543177105486393, 45.30307285487652, 41.73890970647335, 34.66209724545479, 42.976655289530754, 50.10328687727451, 13.622358329594135, 0.8596293570008129, 0.06117644639743958, 0.03953452585847117, 0.047034187882672995, 0.055854943275335245, 0.02519160545489285, 0.007334955334954429, 0.062303327140398324, 0.03037487986148335, 0.014846585418126779, 0.014748781486559892, 0.011227571849303786, 0.010602681650198065, 0.011352358415024355, 0.017657494790910278, 0.04314073274144903, 0.05857976444531232, 0.08021752524655312, 0.010172104266530368, 0.06507299258373678, 0.039425604554708116, 0.03355835942784324, 0.06274104584008455, 0.031938904139678925, 0.015660627723264042, 0.03639448790636379, 0.019243902243033517, 0.01097754879083368, 0.05985701172903646, 0.03634494583820924, 0.03823835009825416, 0.07288089822395705, 0.05356702815333847, 0.015119658655748935, 0.05167304501810577, 0.023540085676359013, 0.026489089250389952, 0.03191207921190653, 0.08872232239809819, 3.6799445981159806, 30.349315367639065, 51.228832080960274, 40.610263869166374, 31.485484801232815, 34.795857667922974, 40.391118228435516, 52.1043810993433, 25.513596050441265, 2.456038584932685, 0.06478337687440217, 0.5016690900083631, 1.5085473144426942, 6.128991795703769, 6.841685827821493, 4.631286012008786, 4.166667368263006, 15.56865569204092, 37.694349735975266, 53.295290395617485, 54.63618144392967, 50.39974696934223, 51.16980604827404, 51.69182203710079, 55.57820029556751, 53.54804903268814, 55.113641023635864, 51.88653498888016, 51.27673611044884, 48.40218275785446, 49.486063197255135, 43.86723630130291, 40.88603027164936, 38.05920235812664, 37.527151107788086, 37.90074706077576, 37.42843620479107, 34.98202487826347, 36.89118303358555, 39.07204940915108, 38.08149196207523, 38.49394842982292, 39.45777051150799, 37.78554484248161, 41.830788776278496, 46.579169780015945, 50.467200949788094, 50.09895130991936, 50.77648535370827, 51.84278033673763, 50.11053688824177, 41.34716972708702, 36.88959851861, 36.54705069959164, 36.36525705456734, 36.48756489157677, 36.214272156357765, 36.02596566081047, 38.085325956344604, 38.22308376431465, 37.36499860882759, 39.00418125092983, 38.70597705245018, 40.22907592356205, 46.6157466173172, 48.29143010079861, 52.043922543525696, 49.754347801208496, 45.10030813515186, 52.84195192158222, 51.37172341346741, 47.334987223148346, 46.390927881002426, 45.28287693858147, 43.13515618443489, 42.645370066165924, 39.199980944395065, 38.60244780778885, 36.72959290444851, 36.71349696815014, 38.02354887127876, 37.98905812203884, 37.423690259456635, 37.102926671504974, 45.22130124270916, 51.517559587955475, 51.567690297961235, 51.97258897125721, 49.20558504760265, 52.81497336924076, 47.63005658984184, 46.49137929081917, 40.06453715264797, 39.51373390853405, 40.365648195147514, 43.17082107067108, 43.32114480435848, 43.78187768161297, 42.371522560715675, 41.972133591771126, 41.64609208703041, 45.484486520290375, 47.23897397518158, 48.405967354774475, 48.79048392176628, 50.36132723093033, 52.6975254714489, 52.88534179329872, 52.93783217668533, 53.48554238677025, 55.4607979953289, 53.37432995438576, 52.91012406349182, 56.41361206769943, 56.04164242744446, 56.682299450039864, 56.8196164816618, 57.22516492009163, 50.66496513783932, 32.69092261791229, 13.58283570036292, 4.009310211986303, 3.863683263771236, 9.394536092877388, 7.840774292126298, 12.668803296983242, 2.5180260837078094, 0.2945530990837142, 0.21106589381815866, 6.065591722726822, 34.928318560123444, 47.51387782394886, 47.233369275927544, 38.197936713695526, 50.04018746316433, 56.85367785394192, 17.063466981053352, 1.0317993653006852, 0.0571321645838907, 0.062360190495382994, 0.026247317946399562, 0.03698410939250607, 0.023135134651965927, 0.039354098626063205, 0.04370544775156304, 0.043952404812444, 0.0491090769355651, 0.0255669967373251, 0.007484169691451825, 0.02196510358771775, 0.025915696678566746, 0.010475363433215534, 0.03957359251216985, 0.026308315063943155, 0.08742043952224776, 0.2489200563286431, 0.12342577858362347, 0.1455176595482044, 0.13090579595882446, 0.18436613667290658, 0.17524993600090966, 0.08291774051031098, 0.2304949489189312, 0.09339063166407868, 0.20529627450741827, 0.0970715431321878, 0.1805374858668074, 0.14725329063367099, 0.25353530945722014, 0.13760305533651263, 0.13868777838069946, 0.20592022774508223, 0.11227777795284055, 0.12587446515681222, 0.10978865175275132, 0.17240923218196258, 4.151177974417806, 35.133788734674454, 59.05113413929939, 49.38110522925854, 40.58382108807564, 41.116123124957085, 44.167929366230965, 55.76420031487942, 30.682160407304764, 3.3037305856123567, 0.216026735433843, 2.1766666509211063, 8.509384039789438, 11.73375042155385, 13.197429031133652, 12.217989787459373, 6.462176442146301, 15.48166885972023, 38.599666357040405, 54.75200302898884, 57.30539761483669, 53.651597276329994, 54.17263671755791, 54.8651647567749, 58.64663444459438, 56.159987077116966, 56.644491478800774, 52.856128960847855, 53.93161565065384, 51.35866351425648, 51.495323181152344, 46.621917486190796, 43.15644644200802, 39.58959303796291, 39.79420825839043, 38.77498134970665, 39.17538486421108, 37.19460055232048, 36.80383712053299, 41.053293496370316, 39.54915560781956, 39.69889797270298, 41.60900987684727, 38.92108730971813, 43.905975222587585, 48.836089074611664, 51.80432640016079, 50.96632696688175, 52.26322777569294, 54.26525294780731, 52.32678696513176, 43.31734120845795, 38.32744516432285, 38.54197025299072, 39.51414808630943, 38.60589422285557, 38.02181996405125, 39.2631221562624, 40.24778991937637, 40.159535855054855, 39.229607954621315, 40.80967336893082, 41.08540177345276, 42.48587362468243, 48.12059886753559, 51.2743878364563, 53.54894578456879, 52.58461453020573, 47.07722045481205, 54.44893129169941, 53.24615143239498, 49.01890106499195, 48.30616571009159, 47.49018229544163, 44.431718811392784, 44.225538074970245, 42.19405308365822, 41.19462311267853, 38.27742084860802, 38.23165610432625, 39.36332657933235, 39.571019634604454, 38.47402609884739, 38.56224216520786, 46.00629352033138, 53.07978495955467, 54.363895654678345, 53.915979489684105, 49.190621450543404, 56.33193165063858, 50.43814390897751, 48.72417747974396, 40.706239119172096, 40.44382520020008, 42.72558756172657, 43.5681277513504, 45.9021183103323, 44.51629467308521, 43.48670572042465, 42.27310784161091, 43.830830454826355, 47.50635042786598, 47.86541976034641, 49.200603514909744, 52.08004720509052, 53.61937880516052, 55.98069749772549, 54.51754800975323, 53.2293601334095, 54.14102241396904, 56.50005362927914, 55.223781913518906, 56.52963884174824, 56.79252773523331, 59.72119018435478, 59.191855788230896, 59.57035727798939, 58.51344779133797, 53.43488350510597, 32.20812812447548, 15.797566808760166, 5.43030571192503, 6.6545691434293985, 16.153356917202473, 16.150879450142384, 19.069960713386536, 6.007539387792349, 1.4283736352808774, 0.43357623915653676, 7.653684681281447, 42.542330995202065, 60.00741742551327, 55.044089555740356, 47.67948433756828, 58.03678996860981, 63.27608563005924, 21.728866137564182, 1.2979698576964438, 0.175514422589913, 0.15280185383744538, 0.10179516466450877, 0.1294337460421957, 0.1389679391286336, 0.09569727859343402, 0.12981097970623523, 0.14114594960119575, 0.13260026753414422, 0.10578741450444795, 0.09955913308658637, 0.043750700206146576, 0.06017954168783035, 0.23164089914644137, 0.08972719035227783, 0.09834999640588649, 0.17146891623269767], [0.024298061507579405, 0.05419574968982488, 0.025612024692236446, 0.058187676695524715, 0.06022114277584478, 0.008087825190159492, 0.04003873356850818, 0.020280031312722713, 0.10455198353156447, 0.036415238355402835, 0.036287778202677146, 0.03914033412002027, 0.09415758191607893, 0.012994829558010679, 0.04302171822928358, 0.11150162506964989, 0.05125497096742038, 0.016664859285810962, 0.023212499836517964, 0.03573380206944421, 0.11976281966781244, 0.7982049998827279, 15.006314367055893, 46.61543883383274, 47.81631879508495, 34.561284855008125, 23.71425960212946, 34.081647992134094, 43.728657737374306, 32.38875903189182, 4.586133034899831, 0.08296220257761888, 0.6022884626872838, 1.0296286130324006, 3.6261855578050017, 5.223956359550357, 4.646195936948061, 3.029121933504939, 10.803260151296854, 32.18986250460148, 47.08204619586468, 53.27388234436512, 48.39268706738949, 51.96085140109062, 47.15625621378422, 49.60820384323597, 50.20423226058483, 49.499886855483055, 47.37368434667587, 47.007482796907425, 43.10988374054432, 40.6594218313694, 35.31316950917244, 34.422041326761246, 33.051021695137024, 35.02786561846733, 34.721142277121544, 36.648493856191635, 35.81131897866726, 35.19078187644482, 34.46984276175499, 35.32905265688896, 35.233434587717056, 37.01058782637119, 37.379407435655594, 39.59794119000435, 44.97122906148434, 46.099608913064, 48.595273196697235, 49.869914799928665, 50.63751921057701, 48.778370171785355, 38.68645370006561, 34.77731466293335, 33.487698063254356, 34.49968636035919, 35.06492502987385, 36.44871197640896, 38.16269740462303, 39.124494194984436, 39.56598870456219, 37.67360284924507, 37.264611795544624, 37.71064706146717, 38.45046356320381, 42.83977523446083, 45.78048303723335, 49.67205561697483, 49.03133399784565, 40.80830164253712, 49.290335699915886, 50.181023105978966, 47.7863460034132, 46.062598899006844, 44.60312381386757, 43.500548377633095, 39.861548244953156, 36.935754641890526, 35.61714179813862, 33.63580271601677, 34.91352215409279, 35.038964822888374, 35.05342684686184, 36.72282166779041, 36.07208378612995, 43.88605669140816, 49.352257177233696, 51.724257096648216, 48.378217443823814, 49.224185049533844, 50.05709655582905, 48.087039068341255, 43.14244419336319, 37.40482047200203, 36.80419810116291, 37.41872012615204, 36.05770155787468, 35.75181417167187, 34.71217855811119, 33.99764209985733, 35.383309945464134, 37.00257785618305, 35.81316947937012, 38.52270908653736, 42.53228433430195, 47.066231444478035, 48.98504488170147, 47.184758484363556, 51.61856956779957, 49.222600534558296, 50.601379349827766, 51.83725543320179, 49.96463231742382, 52.548862248659134, 52.272339686751366, 50.71667656302452, 51.33178375661373, 52.52231687307358, 55.788002237677574, 44.609165489673615, 26.3943412899971, 6.598462304100394, 2.190447561442852, 2.057591015473008, 7.451617699116468, 7.47420416213572, 4.635784020647407, 1.5055558062158525, 0.08343069071997888, 0.1909709392930381, 6.230398379266262, 32.52299442887306, 47.43608459830284, 34.929306507110596, 40.57609610259533, 49.67344634234905, 37.50940605998039, 10.488170608878136, 0.20794544485397637, 0.018563866760814562, 0.08548356025130488, 0.050503193924669176, 0.006656718633166747, 0.013546470709115965, 0.019454045068414416, 0.015245846025209175, 0.04206605466606561, 0.04104431769519579, 0.01904413464217214, 0.03528730376274325, 0.05300923738104757, 0.033835592403193004, 0.07511998002883047, 0.03837191441562027, 0.05919390277995262, 0.027925837057409808, 0.03542908736562822, 0.008364752029592637, 0.036991115266573615, 0.08227918922784738, 0.014370428107213229, 0.05007546082197223, 0.03655470645753667, 0.05699184301192872, 0.043980788250337355, 0.06719265540596098, 0.037180463114054874, 0.02379113568167668, 0.02888973474910017, 0.06279460663790815, 0.02989972537761787, 0.016599670889263507, 0.0439102879317943, 0.03604147794249002, 0.05232601622992661, 0.03929202910512686, 0.05617711700324435, 1.2760288850404322, 19.75935012102127, 52.484524101018906, 51.61089777946472, 38.859409019351006, 28.68471208959818, 38.48461993038654, 48.54306399822235, 35.46969451010227, 5.324062937870622, 0.11779871842009015, 0.5217315384652466, 2.1516198199242353, 5.16990995965898, 7.204417688772082, 5.8208563551306725, 5.242834696546197, 13.81571190431714, 34.599453806877136, 51.425741314888, 54.59730572998524, 50.343289598822594, 53.877563551068306, 50.15281721949577, 51.842594146728516, 52.99744337797165, 50.89215874671936, 51.52337707579136, 49.53286528587341, 46.93809852004051, 43.68325017392635, 37.91298620402813, 35.94105921685696, 35.21994151175022, 36.49720497429371, 36.5079165995121, 37.44939208030701, 37.347511947155, 35.80948747694492, 35.2089487016201, 36.93485029041767, 38.34993615746498, 38.827319741249084, 39.80388253927231, 40.680066123604774, 47.376283407211304, 49.251790568232536, 50.11383131146431, 52.08017259836197, 51.62381708621979, 49.50591333210468, 41.32587566971779, 36.09546773135662, 35.76618120074272, 37.220226377248764, 35.74449196457863, 37.461790814995766, 39.27283823490143, 40.342659428715706, 42.01423153281212, 38.53437826037407, 38.43900717794895, 40.15487350523472, 41.09858326613903, 44.18868385255337, 47.582106962800026, 51.23036339879036, 51.59024968743324, 43.40977504849434, 51.494586020708084, 50.75883910059929, 50.598358511924744, 48.0692408233881, 46.476164907217026, 44.31840889155865, 42.4809642881155, 40.182175040245056, 37.14672692120075, 36.74483008682728, 36.53548792004585, 36.93250201642513, 37.64423042535782, 38.16454030573368, 38.39839495718479, 46.27503789961338, 51.591613814234734, 52.479550167918205, 49.599323719739914, 49.75643388926983, 52.354848459362984, 48.322368040680885, 45.51847189664841, 38.815297186374664, 39.013255164027214, 38.87278810143471, 38.448400273919106, 36.62549369037151, 36.321642994880676, 36.06910474598408, 37.95895613729954, 39.48159523308277, 37.32886254787445, 40.625896230340004, 45.43229252099991, 48.50704573094845, 50.379794239997864, 49.40246768295765, 53.12963828444481, 52.04516887664795, 53.738962188363075, 52.73747652769089, 53.10299031436443, 54.62435267865658, 53.90399873256683, 52.937319204211235, 52.35921822488308, 54.963917657732964, 57.50883109867573, 46.528070122003555, 29.574707932770252, 10.162099655717611, 4.245249526575208, 4.928679428994656, 9.722314104437828, 8.832320161163807, 8.17943824455142, 3.4781953739002347, 0.294689565198496, 0.31254474772140384, 6.964235901832581, 36.721210554242134, 52.39630803465843, 41.379080414772034, 45.70723436772823, 54.107455015182495, 43.927987441420555, 13.802722301334143, 0.18946365220472217, 0.06820563503424637, 0.11731348000466824, 0.03162284199788701, 0.03190042378264479, 0.06258990004425868, 0.02701156492548762, 0.040436858689645305, 0.059661941922968253, 0.055407628606189974, 0.039207873269333504, 0.0334396529069636, 0.02126285562553676, 0.0347617259103572, 0.07860958809033036, 0.04940192469803151, 0.0372867349506123, 0.056948891215142794, 0.13716419372940436, 0.1392611616756767, 0.19746164412936196, 0.258591947495006, 0.117696680536028, 0.15469351405045018, 0.20299573545344174, 0.16966534894891083, 0.28698963462375104, 0.1214241395064164, 0.15643034741515294, 0.13591765280580148, 0.2869066031416878, 0.09082057425985113, 0.08225498779211193, 0.16204824205487967, 0.2220865641720593, 0.12747202708851546, 0.12835880450438708, 0.1265297518693842, 0.21890825737500563, 1.8054293026216328, 22.525852471590042, 59.79152821004391, 59.81898173689842, 45.02319507300854, 32.539417147636414, 44.65268835425377, 52.26448550820351, 42.76781089603901, 6.271342607215047, 0.2034818718675524, 1.1640588683076203, 3.578756502829492, 12.561551202088594, 13.813091944903135, 13.05761268362403, 6.168617494404316, 12.957522254437208, 35.95140606164932, 52.01037414371967, 56.28775142133236, 52.44171179831028, 54.874960631132126, 50.745030641555786, 52.66467243432999, 54.298740550875664, 52.54648357629776, 53.755092322826385, 52.94124439358711, 47.59285658597946, 46.942783668637276, 38.80415618419647, 37.585709765553474, 37.237796634435654, 38.517446368932724, 38.16802851855755, 40.513828843832016, 39.99637261033058, 37.34796792268753, 38.04629825055599, 38.85398671030998, 39.723041877150536, 40.11192440986633, 42.21699245274067, 43.84988643229008, 49.81996268033981, 50.09842313826084, 53.372802436351776, 53.18586006760597, 53.25198791921139, 51.74897097051144, 43.68962623178959, 37.55092263221741, 35.42639963328838, 39.05473753809929, 37.22376398742199, 39.333171397447586, 41.28326095640659, 42.26488508284092, 43.1612303853035, 40.08481286466122, 40.09424775838852, 41.346709951758385, 43.61523002386093, 47.14005388319492, 49.922815561294556, 54.102317690849304, 53.69492255151272, 45.32128907740116, 54.54354241490364, 52.614078149199486, 52.89822310209274, 51.24485582113266, 49.0371248871088, 47.54360742866993, 44.525224193930626, 40.40444031357765, 39.50967952609062, 37.22705461084843, 38.25969859957695, 38.12473364174366, 37.82076135277748, 40.79386241734028, 40.22307984530926, 47.41308443248272, 53.20838525891304, 55.511779859662056, 50.236796513199806, 50.66663704812527, 54.113705679774284, 52.02010162174702, 47.73054599761963, 41.03207163512707, 40.227981582283974, 41.79307579994202, 39.695428758859634, 38.07013817131519, 37.77110941708088, 38.491147980093956, 39.64548423886299, 41.001395881175995, 38.98611702024937, 42.37160235643387, 47.14621715247631, 52.388396859169006, 53.95373046398163, 51.804664582014084, 57.32006102800369, 54.19533669948578, 55.75327210128307, 54.61280509829521, 54.33790884912014, 56.43009938299656, 56.77993521094322, 54.620131105184555, 54.74088102579117, 57.42942675948143, 60.85558511316776, 48.53554040193558, 30.379791632294655, 9.787101577967405, 4.2882375698536634, 6.586494371294975, 14.295667000114918, 15.317307729274035, 9.579562414437532, 4.197950614616275, 0.7999099208973348, 0.49859737046062946, 8.76214362680912, 44.80069801211357, 61.19970604777336, 48.70750777423382, 53.54781724512577, 64.11731868982315, 51.15359611809254, 15.980656184256077, 0.36776626424398273, 0.21112379617989063, 0.3052753221709281, 0.1688665457186289, 0.10481730874744244, 0.13062210258794948, 0.10460056451847777, 0.09025510225910693, 0.1661871699616313, 0.2124151331372559, 0.14501331083010882, 0.14779320306843147, 0.1802978612249717, 0.13212630234193057, 0.17808465810958296, 0.11099511670181528, 0.25835247128270566, 0.1120740435726475], [0.0685205431364011, 0.12106238704291172, 0.05684778843715321, 0.041777006699703634, 0.07830029804608785, 0.027483262856549118, 0.05973766325041652, 0.05649775448546279, 0.06011211014993023, 0.02949237165012164, 0.01305364939980791, 0.03675296378787607, 0.032336654476239346, 0.023449267209798563, 0.07299850636627525, 0.10638246851158328, 0.008935322584875394, 0.04702006481238641, 0.05827104585478082, 0.02516006788937375, 0.08440037345280871, 0.19440491596469656, 10.054769665002823, 36.35383486747742, 51.45507954061031, 35.46051040291786, 30.9671014174819, 31.921243518590927, 39.86534044146538, 35.47564499080181, 7.358257658779621, 0.0440447836444946, 0.4079323058249429, 2.172626042738557, 3.072085278108716, 6.56412972137332, 1.8618503375910223, 2.3074772441759706, 10.359935089945793, 29.783037453889847, 46.531421542167664, 53.593046218156815, 50.562636628746986, 51.434955820441246, 50.61014927923679, 52.12263152003288, 47.68936760723591, 48.781467005610466, 43.679074198007584, 40.065817683935165, 35.51210403442383, 34.672143906354904, 33.83411407470703, 35.61615765094757, 38.0033453553915, 38.051830753684044, 36.995574831962585, 35.15770465135574, 35.125668570399284, 34.49012987315655, 35.67730396986008, 35.72305351495743, 35.31978115439415, 38.1472360342741, 41.34960539638996, 46.39779791235924, 48.37985895574093, 50.22763900458813, 50.426949709653854, 52.19715312123299, 51.30835801362991, 43.53471614420414, 35.74356861412525, 34.695976227521896, 35.12840062379837, 34.1295900195837, 33.33890184760094, 39.85152818262577, 42.60416887700558, 40.292141139507294, 40.68783290684223, 39.51565280556679, 36.90536007285118, 38.53581838309765, 38.07684861123562, 41.44320957362652, 44.66479450464249, 48.80600228905678, 50.680312514305115, 41.76483191549778, 51.369097754359245, 48.41131366789341, 47.97252461314201, 45.25490663945675, 44.64649088680744, 43.15065175294876, 40.358960554003716, 38.86236526072025, 36.786924228072166, 34.31616760790348, 34.48782719671726, 35.4696299135685, 36.17711395025253, 35.483073592185974, 37.20930956304073, 42.69835442304611, 48.60435090959072, 50.72238385677338, 50.666747242212296, 49.39461350440979, 50.11697754263878, 48.59849542379379, 43.380642011761665, 36.78902171552181, 34.992941692471504, 36.2968835234642, 37.41528891026974, 35.304213389754295, 38.84631872177124, 37.63239026069641, 35.325883626937866, 34.269050136208534, 36.77686616778374, 36.379027515649796, 36.16331309080124, 39.464404955506325, 40.50151750445366, 44.20735225081444, 45.808388739824295, 48.52618150413036, 47.339075803756714, 48.230853751301765, 51.085404977202415, 48.54870669543743, 46.698707565665245, 49.607033506035805, 49.54885482788086, 50.28495132923126, 53.203871101140976, 43.30360494554043, 20.839696750044823, 4.447335507720709, 3.1376923201605678, 3.3169379644095898, 6.1312284506857395, 7.481425199657679, 10.943982750177383, 2.488044505007565, 0.12258255039341748, 0.29809830884914845, 8.097994364798069, 35.93580409884453, 36.94484755396843, 28.983100578188896, 28.82555913180113, 46.37969948351383, 34.964652210474014, 6.100641041994095, 0.1080787435057573, 0.08013638624106534, 0.06752448447514325, 0.021676382166333497, 0.07449616779922508, 0.05383604555390775, 0.13952397101093084, 0.02015156740526436, 0.0421382953209104, 0.06545375887071714, 0.029190389905124903, 0.020163831395620946, 0.0417486195510719, 0.014008791604283033, 0.01851965887908591, 0.060159785716678016, 0.06152158217446413, 0.09182785419397987, 0.05807383495266549, 0.05211634466832038, 0.09429324651136994, 0.05294871523801703, 0.07705932323005982, 0.009545033080939902, 0.04066009300004225, 0.04115928379178513, 0.02006715367315337, 0.03711098695930559, 0.017391881992807612, 0.022123650451248977, 0.015027907866169699, 0.07754257268970832, 0.01617312151211081, 0.07908631407190114, 0.058972846672986634, 0.012214142152515706, 0.06541312628542073, 0.03518795616400894, 0.06234992659301497, 0.44526711339131, 12.99186386168003, 44.66644361615181, 55.017076805233955, 40.76484337449074, 31.462300345301628, 34.707200825214386, 46.06460899114609, 40.358360186219215, 7.872394770383835, 0.052189679990988225, 0.3703599813161418, 2.2659910703077912, 3.5480460757389665, 7.214791132137179, 4.517316352576017, 3.020274583250284, 11.22893325984478, 30.686138793826103, 48.608504086732864, 53.72641146183014, 52.85770587623119, 53.967242538928986, 52.75985352694988, 52.51952402293682, 50.69266565144062, 51.15032449364662, 47.31435813009739, 42.440663650631905, 38.83165530860424, 36.30564585328102, 35.46679526567459, 37.834535613656044, 39.02090795338154, 38.8249334692955, 37.67014883458614, 36.027033403515816, 36.1970666795969, 36.887166649103165, 36.87479451298714, 37.960601449012756, 36.542316153645515, 39.088392332196236, 42.492861449718475, 48.45401577651501, 49.74325619637966, 50.69515451788902, 51.079488694667816, 54.90601256489754, 52.00730390846729, 45.29942125082016, 37.20845840871334, 37.15613141655922, 36.9591423869133, 35.7734502106905, 35.447857081890106, 40.68926922976971, 43.71339775621891, 41.08979433774948, 44.15336474776268, 41.45770959556103, 38.04838813841343, 39.707090333104134, 40.042312145233154, 43.742454797029495, 45.68342104554176, 51.97509303689003, 52.071053087711334, 44.20677848160267, 51.48784518241882, 50.99049746990204, 50.08544683456421, 47.907620295882225, 46.47956192493439, 46.116658598184586, 42.75570094585419, 41.089095175266266, 37.56547965109348, 36.603481471538544, 35.28285093605518, 36.94713123142719, 37.776113748550415, 38.544801101088524, 38.40315230190754, 45.0382574647665, 51.10778197646141, 52.60114744305611, 52.33641944825649, 51.03816211223602, 51.447593942284584, 49.14039954543114, 46.11584544181824, 38.9203767478466, 37.02919162809849, 38.2611995190382, 38.34127262234688, 37.49538101255894, 40.88890291750431, 39.34187673032284, 36.615865007042885, 36.7280425876379, 37.42630831897259, 36.56740240752697, 39.52505350112915, 42.45087370276451, 42.93241806328297, 48.32041874527931, 47.851307317614555, 50.84172025322914, 51.14212453365326, 51.58578872680664, 53.19979391992092, 51.2874211370945, 50.1554960757494, 51.52809262275696, 52.308251559734344, 53.33040431141853, 55.112725272774696, 44.96991813182831, 22.429710030555725, 6.936369622126222, 4.71840251237154, 6.596878739073873, 13.561509344726801, 12.094120234251022, 3.317938498221338, 2.485657283104956, 0.3419169638073072, 0.2650500868912786, 9.846596885472536, 38.999758288264275, 45.6497548520565, 35.68093277513981, 35.16919523477554, 55.425950065255165, 40.37087291479111, 8.644157107919455, 0.06597231229534373, 0.0589332605159143, 0.040241358437924646, 0.043929387102252804, 0.019005834255949594, 0.053713338857050985, 0.10576293105259538, 0.03752628908841871, 0.0006504399084406032, 0.032306783032254316, 0.05963148047158029, 0.04785558950970881, 0.04122711980016902, 0.0329551195318345, 0.031724044965812936, 0.019878195453202352, 0.056559590229880996, 0.027894312479475047, 0.1017494112602435, 0.17915867938427255, 0.2534851402742788, 0.10717231401940808, 0.26003681996371597, 0.10250646868371405, 0.1431647693971172, 0.16154830169398338, 0.21046696580015123, 0.1540853240294382, 0.14089703327044845, 0.19601052277721465, 0.16907891869777814, 0.11023072685929947, 0.18048068188363686, 0.17864153604023159, 0.12829376268200576, 0.0872478679229971, 0.14390638272743672, 0.2066592435585335, 0.11122167212306522, 0.670337111223489, 15.957956202328205, 48.74789580702782, 62.66402967274189, 45.62941074371338, 40.48803962767124, 41.979550793766975, 50.610666051506996, 43.56155410408974, 10.102416258305311, 0.3490463609341532, 1.2564845150336623, 4.708474595099688, 10.510321520268917, 14.527166727930307, 6.7897264659404755, 4.535250440239906, 11.893756985664368, 32.124464213848114, 49.59144674241543, 56.210759952664375, 54.36571955680847, 56.05664782226086, 54.83733505010605, 55.997367203235626, 51.995592936873436, 53.307981714606285, 49.475036188960075, 42.79537461698055, 39.235919415950775, 38.46353866159916, 37.74571157991886, 40.15221364796162, 42.38890282809734, 41.859876215457916, 40.75172647833824, 38.91878463327885, 37.977939918637276, 38.260466158390045, 38.7714247405529, 40.37236623466015, 39.1766881942749, 41.99030041694641, 44.7774850577116, 50.89406244456768, 52.00022488832474, 54.368664398789406, 53.88091117143631, 56.54219336807728, 55.71072578430176, 46.96591302752495, 39.23716954886913, 38.66555102169514, 40.009470507502556, 37.117308899760246, 37.262073531746864, 42.12773144245148, 46.05598345398903, 42.67856888473034, 45.13360574841499, 42.67737194895744, 40.345744863152504, 41.696868762373924, 42.47748747467995, 46.42446108162403, 49.18788179755211, 54.27152641117573, 53.51985454559326, 47.99845442175865, 54.2060749232769, 51.20622709393501, 52.78554394841194, 49.14975084364414, 48.704589530825615, 49.51719492673874, 44.42375063896179, 41.85438551008701, 40.49865625798702, 38.72113063931465, 37.966046556830406, 39.48986358940601, 40.59103690087795, 40.009333714842796, 40.692825838923454, 46.81788057088852, 52.26187504827976, 55.752800926566124, 53.87364596128464, 53.02323639392853, 53.82547974586487, 52.23885968327522, 47.341948449611664, 40.238400623202324, 38.257969692349434, 40.98924793303013, 40.120166167616844, 39.13587838411331, 43.4343521296978, 42.063989862799644, 38.23349140584469, 37.36885540187359, 39.51218359172344, 39.78377781808376, 40.81413432955742, 44.70130294561386, 43.53438936173916, 49.40014600753784, 51.3311567902565, 53.86511541903019, 52.63370029628277, 53.5201471298933, 57.50893369317055, 53.579925522208214, 51.187482699751854, 54.391318783164024, 54.96339328587055, 55.49240089952946, 56.67944960296154, 47.199490293860435, 24.000768028199673, 5.95157029107213, 5.707211103290319, 9.488118421286345, 15.757526457309723, 16.076661832630634, 16.219422072172165, 6.774361040443182, 0.8232718391809613, 0.7288100360892713, 11.690101213753223, 47.247363924980164, 52.35742472112179, 42.60048307478428, 40.04113420844078, 60.671032816171646, 46.56997807323933, 10.938546191900969, 0.27438838267698884, 0.1517221625545062, 0.19429323758231476, 0.07912033412139863, 0.11659986048471183, 0.1525163050973788, 0.15966351376846433, 0.12125868510338478, 0.07642867582035251, 0.11685902587487362, 0.182389841938857, 0.15655064955353737, 0.2367012924514711, 0.18663044407730922, 0.12379962063278072, 0.1356599642895162, 0.1518103593843989, 0.1539353805128485], [0.08630838317913003, 0.01439806383132236, 0.0776573755138088, 0.009648064515204169, 0.020742986744153313, 0.06221808405825868, 0.01047095136527787, 0.03799986465310212, 0.050936196275870316, 0.03592213317460846, 0.052157110840198584, 0.053728705024695955, 0.014194917603163049, 0.030663450997963082, 0.028559234124259092, 0.021877066319575533, 0.038023027082090266, 0.03925761200662237, 0.033859519244288094, 0.02359369656915078, 0.04572358106088359, 0.01202638713948545, 7.359338700771332, 28.825249448418617, 47.1230573952198, 38.39712582528591, 25.861997455358505, 26.87555506825447, 39.70355272293091, 38.56080964207649, 16.49617452174425, 1.2436619843356311, 0.03456044061749708, 1.0405521956272423, 1.7953149578534067, 3.4883576910942793, 4.9738020077347755, 2.3897421173751354, 6.7960896994918585, 26.379860267043114, 45.581506714224815, 54.87659074366093, 51.1008283495903, 51.66908025741577, 51.30726367235184, 47.4796112626791, 46.792855113744736, 42.77901649475098, 38.14943611621857, 35.78551456332207, 35.850323885679245, 38.4786656498909, 41.44149586558342, 44.366255924105644, 46.52115449309349, 46.187410801649094, 48.88823747634888, 41.91905803978443, 34.97103966772556, 33.59050914645195, 35.38074888288975, 35.94674751162529, 35.580830946564674, 44.90189418196678, 48.85406970977783, 49.20061491429806, 51.97639636695385, 50.58481603860855, 48.86679522693157, 49.8172078281641, 47.70045541226864, 40.16921013593674, 34.57238405942917, 34.72859367728233, 35.89340977370739, 34.20296788215637, 39.01683837175369, 43.901970237493515, 48.472228199243546, 46.83280237019062, 44.91284519433975, 43.644800037145615, 40.84951423108578, 39.18725922703743, 39.606057554483414, 40.27826048433781, 45.86117170751095, 47.58003607392311, 51.38270862400532, 40.429268181324005, 50.19789420068264, 49.98024567961693, 48.638818860054016, 47.051138654351234, 44.613307267427444, 44.06710937619209, 40.311763286590576, 37.516808062791824, 36.69740103185177, 36.68915167450905, 34.80046682059765, 35.505009815096855, 37.60084815323353, 37.188900858163834, 36.600567027926445, 39.88906256854534, 47.7184284478426, 50.62710016965866, 51.52045503258705, 50.261012613773346, 50.112626776099205, 47.74516001343727, 45.91578617691994, 37.9241918027401, 35.237181186676025, 36.72806538641453, 34.2989469319582, 34.58811901509762, 36.0981921851635, 37.01593413949013, 38.80746580660343, 38.06391790509224, 34.54838454723358, 37.14737668633461, 35.34018985927105, 36.31869435310364, 36.53832256793976, 36.874209344387054, 38.66827927529812, 40.02512186765671, 40.14162741601467, 42.67695017158985, 42.686806842684746, 43.43029014766216, 42.964617535471916, 46.76970675587654, 49.61225442588329, 51.27607874572277, 53.78310441970825, 41.65750287473202, 15.130352061241865, 5.438400227576494, 3.268305086530745, 6.817099247127771, 8.540924247354269, 16.160312443971634, 8.725789077579975, 2.0935266371816397, 0.510218096897006, 0.44862420356366783, 9.443003442138433, 35.5531570315361, 41.76862791180611, 31.744076125323772, 38.15953217446804, 42.26439490914345, 31.981287896633148, 2.6504594273865223, 0.03023846755240811, 0.06528541751322336, 0.020021038471895736, 0.12736394070088863, 0.05013937457988504, 0.07333658431889489, 0.04479084615013562, 0.022036514892533887, 0.024456406135868747, 0.01112286687202868, 0.013858603178960038, 0.01160123949375702, 0.04354509190306999, 0.028490913864516187, 0.07150972101953812, 0.03383905081136618, 0.029662221422768198, 0.05641025156364776, 0.07518959348089993, 0.024125102136167698, 0.021586216789728496, 0.07334599475143477, 0.006232353025552584, 0.04285925839212723, 0.1077055322821252, 0.07105839875293896, 0.013434817374218255, 0.024409687939623836, 0.03800944577960763, 0.01501766715591657, 0.010499865438760025, 0.0487830291967839, 0.054299487092066556, 0.030493467638734728, 0.03738361490832176, 0.058959640155080706, 0.024314654074260034, 0.039254179573617876, 0.04044869223434944, 0.0796777092909906, 9.116524010896683, 35.024225413799286, 52.29464448988438, 41.319089233875275, 26.203958205878735, 30.180471427738667, 42.5601976364851, 42.729090973734856, 14.999135602265596, 1.0761067690327764, 0.09975056265830062, 1.6682862304151058, 2.740190662443638, 5.530053209513426, 5.676564797759056, 3.0553614255040884, 7.797810472548008, 27.78207052499056, 47.14467443525791, 53.652429431676865, 54.09319818019867, 54.63607504963875, 53.903151378035545, 49.72475118935108, 50.40601283311844, 44.73070576786995, 39.78076457977295, 37.48637169599533, 37.441982477903366, 38.42637285590172, 43.65709237754345, 45.859154015779495, 48.60266000032425, 47.23253332078457, 48.45227546989918, 43.07739928364754, 36.21899150311947, 36.24493271112442, 37.792088091373444, 37.820533365011215, 38.83898511528969, 44.6320516616106, 50.84139347076416, 51.183230727910995, 55.074567720294, 52.63253755867481, 51.57798394560814, 51.2743916362524, 49.71960246562958, 41.55601032078266, 36.139317378401756, 36.64491064846516, 36.97101294994354, 35.46663947403431, 39.560190215706825, 44.08706210553646, 49.70928981900215, 47.933432310819626, 46.43547669053078, 44.115047603845596, 40.90830847620964, 40.17221197485924, 41.90067462623119, 42.298657670617104, 49.46298323571682, 49.67790350317955, 53.75691622495651, 42.80419774353504, 50.390532463788986, 52.38351792097092, 50.93806028366089, 48.48572887480259, 46.15919351577759, 46.72575831413269, 42.05330103635788, 39.05977226793766, 38.324625715613365, 37.489821910858154, 36.60794623196125, 37.11930379271507, 39.168621227145195, 39.69926655292511, 38.17662365734577, 42.05783039331436, 49.66513618826866, 52.350691482424736, 52.407441437244415, 51.9508009403944, 52.35566161572933, 49.1150739043951, 47.36114501953125, 39.98660333454609, 37.79157891869545, 39.67797629535198, 36.78590968251228, 36.53696224093437, 38.39087896049023, 38.82386952638626, 39.81364421546459, 39.83624540269375, 36.339882016181946, 37.69167847931385, 37.41147391498089, 37.719800770282745, 40.07813662290573, 40.604271590709686, 41.40393488109112, 43.631496950984, 45.35677917301655, 45.762407407164574, 46.71883128583431, 45.23672841489315, 45.21956093609333, 48.764846697449684, 51.602667421102524, 53.55371072888374, 55.32854609191418, 41.78254656493664, 17.84802608191967, 6.413915231823921, 6.148908426985145, 6.024867882952094, 8.083298653364182, 14.652374759316444, 8.522388841956854, 0.9336701652500778, 0.5368972371798009, 0.38395051611587405, 11.938453037291765, 42.63255335390568, 49.435932487249374, 35.2532809227705, 42.050998359918594, 47.39576116204262, 39.80000674724579, 5.150165744125843, 0.18558607902377844, 0.07980598209542222, 0.02070895556244068, 0.11419966584071517, 0.11773642254411243, 0.0413573926925892, 0.043422722883406095, 0.012513200763351051, 0.07532923598773777, 0.06082158477511257, 0.029637157240358647, 0.020890655578114092, 0.06138642223959323, 0.044497805429273285, 0.04898900486296043, 0.06559135304996744, 0.04085839114850387, 0.07670138540561311, 0.1278478655149229, 0.14886977733112872, 0.12421520106727257, 0.1599507694481872, 0.07656130503164604, 0.13113595079630613, 0.1943747847690247, 0.1541550413821824, 0.08163720180164091, 0.1290581896319054, 0.13217849016655236, 0.09496268598013557, 0.05388792538724374, 0.12031740436214022, 0.1529340451816097, 0.09736786043504253, 0.07097955298377201, 0.11798084888141602, 0.08277403103420511, 0.11170848389156163, 0.12247840480995364, 0.18866174679715186, 10.386806298047304, 40.11550381779671, 59.06071722507477, 48.712040930986404, 37.3718686401844, 38.59534978866577, 49.571763798594475, 49.640399515628815, 19.470926597714424, 1.9301376608200371, 0.216278679727111, 3.7930661905556917, 6.787354918196797, 12.782314606010914, 12.042754590511322, 5.656069647520781, 8.403166439384222, 30.126924701035023, 50.11037729680538, 57.181368470191956, 54.51646886765957, 57.36888460814953, 55.62505178153515, 51.55135877430439, 52.4732007086277, 46.75094336271286, 41.984824910759926, 39.79829303920269, 40.1374476402998, 42.738480269908905, 47.00134992599487, 48.595634177327156, 51.15901842713356, 49.778544902801514, 49.670387506484985, 46.22392684221268, 39.00483101606369, 38.24505418539047, 40.94801254570484, 40.3098975867033, 40.24650178849697, 48.38587403297424, 53.01297314465046, 52.70578622817993, 56.602036356925964, 54.46036107838154, 52.092286348342896, 52.802156656980515, 51.90250553190708, 43.849061876535416, 36.3298125565052, 38.05881857872009, 39.28657449781895, 37.760242000222206, 43.15271504223347, 46.87225565314293, 52.47185558080673, 50.40559485554695, 48.98756414651871, 47.36802265048027, 44.098419696092606, 41.81136041879654, 43.99211660027504, 43.88117015361786, 52.43652127683163, 53.51763926446438, 55.91483183205128, 45.7032635807991, 51.06408052146435, 53.50534312427044, 53.052939400076866, 50.890783220529556, 49.136402159929276, 49.44239594042301, 43.98303508758545, 40.86692489683628, 41.780886054039, 39.212448075413704, 39.14648741483688, 39.476932883262634, 41.9537615776062, 41.54858931899071, 40.13877376914024, 43.756080865859985, 51.84074744582176, 56.374314576387405, 55.36996766924858, 54.583721458911896, 54.15053330361843, 51.718090027570724, 52.13226780295372, 41.53302915394306, 39.262981563806534, 41.33484698832035, 38.98427031934261, 37.925381138920784, 39.59337763488293, 40.016123950481415, 42.615682259202, 42.61067032814026, 37.66510650515556, 40.190792977809906, 39.00797724723816, 40.726355239748955, 42.001692205667496, 41.97030209004879, 42.35656276345253, 44.55077402293682, 45.95569923520088, 46.483726501464844, 48.182026371359825, 47.89058580994606, 47.536262422800064, 52.22072325646877, 54.066979587078094, 55.52667886018753, 58.333668038249016, 45.24608351290226, 19.61182303726673, 8.825564123690128, 8.091957438737154, 15.054199397563934, 17.122200429439545, 26.43615234643221, 14.289995804429054, 3.6574661917984486, 1.0810885392129421, 0.7750478549860418, 13.718360178172588, 48.556925654411316, 55.68982310593128, 42.313176691532135, 51.857652738690376, 56.96937024593353, 45.27934692800045, 6.969527592882514, 0.23514008091297, 0.10915372215094976, 0.14534557034494355, 0.25082647043745965, 0.1769022981170565, 0.2290588041068986, 0.19467857549898326, 0.06170435830426868, 0.12947879440616816, 0.1532388452324085, 0.09183094152831472, 0.13680066011147574, 0.250873492914252, 0.12671503645833582, 0.20000729971798137, 0.14834910136414692, 0.13822708278894424, 0.21039178624050692], [0.061478452262235805, 0.026840813443413936, 0.04017301034764387, 0.024347924554604106, 0.02076229557133047, 0.09818921011174098, 0.06865126502816565, 0.02324143802979961, 0.027831341249111574, 0.02380524205364054, 0.048032187260105275, 0.007629138035554206, 0.03055520875932416, 0.0558410317171365, 0.024458621446683537, 0.06407102642697282, 0.0396882691711653, 0.046162097569322214, 0.07989133649971336, 0.01447464048396796, 0.02046021920250496, 0.11716258653905243, 3.0747679341584444, 20.921721048653126, 44.92058917880058, 42.46754340827465, 21.955615170300007, 23.27936913818121, 31.245896257460117, 38.59764106571674, 24.06853549182415, 2.7857447555288672, 0.058487986752879806, 1.2481437250971794, 2.529088477604091, 4.910841286182404, 2.041458268649876, 1.254343211185187, 5.452269958332181, 21.71622421592474, 51.32416136562824, 51.20378762483597, 50.500224977731705, 50.9064269810915, 48.483057618141174, 45.190101116895676, 41.319013237953186, 37.889142483472824, 39.15297366678715, 40.632302686572075, 42.98785708844662, 46.54610015451908, 48.40725928544998, 47.09778495132923, 50.83785966038704, 49.493016824126244, 47.92429760098457, 47.37980581820011, 36.687202379107475, 36.076373755931854, 36.570442244410515, 36.67799547314644, 42.08791717886925, 47.80684970319271, 50.05305737257004, 51.9942744076252, 50.423313304781914, 48.35950344800949, 49.225856959819794, 48.00863787531853, 38.811843171715736, 34.64613810181618, 36.07974037528038, 33.87187644839287, 34.0626186132431, 36.7509401589632, 46.03627771139145, 48.677329793572426, 50.31431995332241, 49.65954288840294, 48.53430166840553, 46.860024109482765, 45.33295065164566, 43.5135854780674, 40.27965120971203, 41.88915744423866, 45.979387164115906, 49.95009809732437, 49.43468615412712, 39.63240534067154, 46.0428399592638, 48.166796788573265, 49.35875482857227, 47.29654848575592, 46.20295196771622, 43.10848541557789, 39.90320160984993, 37.96203777194023, 36.379893869161606, 34.97445948421955, 33.806626349687576, 35.304787158966064, 35.30741661787033, 35.605449825525284, 36.9539974629879, 38.59185017645359, 44.47210684418678, 48.26514311134815, 51.00737236440182, 49.90093633532524, 52.49925971031189, 47.60963648557663, 46.51990815997124, 37.59200602769852, 35.31429424881935, 36.36900745332241, 35.55700622498989, 37.43355453014374, 41.513144820928574, 47.47011177241802, 47.43838347494602, 45.42444594204426, 44.44316379725933, 40.00722862780094, 38.07776436209679, 36.87159888446331, 36.685864850878716, 35.657818615436554, 35.124521031975746, 36.95470802485943, 36.88816599547863, 37.94718436896801, 40.47806516289711, 41.7668230086565, 43.37505631148815, 50.01322790980339, 49.17440392076969, 53.37134711444378, 49.42546404898167, 39.22030985355377, 13.95589018240571, 4.454917525872588, 5.862830802798271, 5.957393478602171, 9.022315666079521, 12.322002556174994, 11.91716942936182, 2.095323703251779, 0.1240309035347309, 0.18887049809563905, 14.395301453769207, 30.875144451856613, 34.33276891708374, 29.237363934516907, 43.833805695176125, 47.79626727104187, 18.497088253498077, 1.820112664718181, 0.05571004265220836, 0.02916712357546203, 0.030000809601915535, 0.019451772241154686, 0.04238310386426747, 0.04126046449528076, 0.10481431789230555, 0.02644691485329531, 0.02484042117430363, 0.09292296730563976, 0.05738669897255022, 0.047148014782578684, 0.06708908127620816, 0.015158866317506181, 0.06499750132206827, 0.04800685775990132, 0.06686113061732613, 0.07231726674945094, 0.031022956609376706, 0.06856925770989619, 0.0473072277236497, 0.018521799975133035, 0.03405985458812211, 0.05806920395116322, 0.08337579405633733, 0.034540881315479055, 0.06226653145859018, 0.050205028674099594, 0.10506832535611466, 0.04900949184957426, 0.04387950735690538, 0.023260607704287395, 0.015360122852143832, 0.05271761416224763, 0.021204255644988734, 0.0030474626828436158, 0.05762732922448777, 0.04621821135515347, 0.021905789290030953, 0.025759582204045728, 4.055738020688295, 26.126170679926872, 53.11949662864208, 48.52339245378971, 28.185510076582432, 29.57951657474041, 42.253759279847145, 44.47060592472553, 26.881492249667645, 2.472843420691788, 0.0864568943507038, 0.8254383166786283, 4.13127226755023, 3.622780228033662, 5.480431197211146, 3.346359310671687, 5.380970109254122, 22.66444433480501, 48.61744120717049, 55.81296689808369, 53.64614076912403, 53.05552326142788, 50.2264154702425, 48.428804129362106, 42.426995784044266, 41.31744772195816, 38.94323632121086, 40.85899092257023, 44.27307352423668, 47.800139263272285, 48.52324806153774, 48.26881751418114, 52.25081384181976, 52.25081764161587, 50.74655435979366, 49.6314661949873, 37.46601238846779, 36.53224289417267, 37.92580671608448, 37.48202472925186, 42.600908651947975, 50.06371200084686, 51.17238610982895, 53.58691334724426, 51.42140954732895, 51.95190668106079, 49.925361424684525, 49.90726679563522, 41.27668730914593, 37.62775830924511, 37.20121219754219, 36.86246417462826, 35.42933687567711, 37.296298295259476, 46.50164254009724, 51.114568412303925, 51.0575220733881, 51.00807912647724, 50.8415112644434, 48.22135046124458, 45.70954464375973, 44.74985674023628, 43.44250649213791, 43.98508317768574, 47.223782390356064, 51.57070353627205, 51.72078028321266, 42.25866861641407, 46.744289919734, 49.97219771146774, 52.68411599099636, 47.841918021440506, 48.08762803673744, 45.75757786631584, 42.42097690701485, 40.06528191268444, 37.35938251018524, 36.29709631204605, 35.79594500362873, 37.927072048187256, 36.62600666284561, 37.35847435891628, 38.348173052072525, 40.479201301932335, 45.54795451462269, 51.59656874835491, 52.25049465894699, 51.24881900846958, 53.372905030846596, 50.20664133131504, 47.875352427363396, 38.05754944682121, 35.982989966869354, 38.23947988450527, 38.11015382409096, 38.65622252225876, 41.58135876059532, 48.33624489605427, 47.29913994669914, 47.06617824733257, 44.708655551075935, 42.54166603088379, 39.27276223897934, 39.36913266777992, 37.003250420093536, 37.530399933457375, 37.32073858380318, 38.715636134147644, 37.87886783480644, 39.06948834657669, 41.19592264294624, 43.61673854291439, 45.930138006806374, 52.20335438847542, 50.88154971599579, 55.2584208548069, 52.31451362371445, 40.167219042778015, 15.38410909473896, 4.988196110352874, 4.739294266328216, 8.320681415498257, 6.2663159519433975, 11.175040751695633, 15.887632425874472, 0.9206670254934579, 0.301139778457582, 0.44444190454669297, 16.21652662754059, 39.625379517674446, 43.853450641036034, 37.02849626541138, 50.20865902304649, 54.96498920023441, 24.885263666510582, 2.2911340836435556, 0.04414275084855035, 0.012529680152510991, 0.013174682553653838, 0.05940830182225909, 0.05901216936763376, 0.03202381696610246, 0.029649918469658587, 0.035944928240496665, 0.014504126011161134, 0.02936567776487209, 0.034760571870720014, 0.02543831018556375, 0.03366974837263115, 0.01086610789570841, 0.07083957651047967, 0.05971245620457921, 0.04170785337919369, 0.10743524209829047, 0.11936404887819663, 0.12765410559950396, 0.14048830285901204, 0.1932132345973514, 0.05523144645849243, 0.19242393085733056, 0.12256520640221424, 0.16470118251163512, 0.09805353067349643, 0.17305843328358606, 0.1820347984903492, 0.06702813610900193, 0.1264992347569205, 0.11023161001503468, 0.14149487775284797, 0.18618224625242874, 0.14282514777733013, 0.16396520950365812, 0.13598432735307142, 0.11346371509716846, 0.16082372807431966, 0.23053693963447586, 4.19169282540679, 30.639180913567543, 59.07576821744442, 55.46644449234009, 33.251517936587334, 34.22946386039257, 42.488746270537376, 49.59704764187336, 30.151349790394306, 3.766572349704802, 0.1499214896466583, 3.4210808761417866, 6.225101463496685, 11.529195997864008, 8.712821323424578, 3.0189439421519637, 6.273431545123458, 23.281356431543827, 53.544340431690216, 57.123030200600624, 56.456576362252235, 55.07673740386963, 53.502493277192116, 50.12504830956459, 43.96954581141472, 41.6476234048605, 42.276801243424416, 43.90261620283127, 47.667746767401695, 51.10819615423679, 51.79621383547783, 50.46372413635254, 55.76995700597763, 53.47779840230942, 54.02043588459492, 50.96667654812336, 41.243062913417816, 39.10963699221611, 41.2924412637949, 40.22518493235111, 46.564035192131996, 53.70238155126572, 54.02990497648716, 56.2106079608202, 53.373015224933624, 50.64795345067978, 53.760708421468735, 52.28160738945007, 42.695835158228874, 38.54191705584526, 39.699065163731575, 38.316539749503136, 37.32283227145672, 40.2655653655529, 50.06731420755386, 52.76435628533363, 54.69204604625702, 52.094190046191216, 51.96131877601147, 49.129953905940056, 48.899982646107674, 47.01014645397663, 44.878400042653084, 47.15917065739632, 51.737427189946175, 54.641611352562904, 51.33022204041481, 44.80165936052799, 45.53455263376236, 49.98311072587967, 53.96042190492153, 50.95757983624935, 50.35852298140526, 48.29011917114258, 43.827657625079155, 40.82223169505596, 38.82958061993122, 37.95971229672432, 37.62439928948879, 39.43570129573345, 38.33387441933155, 38.0657684057951, 40.62549725174904, 41.55816100537777, 49.7077888995409, 52.76433348655701, 55.01260444521904, 51.48865453898907, 56.09110817313194, 51.51458814740181, 51.97477005422115, 40.295435562729836, 38.49003843963146, 39.28574614226818, 40.064917132258415, 41.87480181455612, 44.64161574840546, 51.97250917553902, 51.1077705770731, 50.23826703429222, 47.68463686108589, 45.582012087106705, 41.66732534766197, 40.771804600954056, 39.607816860079765, 39.02398578822613, 39.61105428636074, 40.919536873698235, 40.45293711125851, 41.66389413177967, 44.09928984940052, 45.72610415518284, 49.109757989645004, 54.82585206627846, 53.385828137397766, 57.72120550274849, 53.20579759776592, 41.749005764722824, 16.38003945350647, 7.5814885552972555, 10.948629900813103, 11.170946471393108, 21.254925169050694, 20.70038102567196, 18.247736133635044, 3.1946524512022734, 0.6607837707269937, 0.5252089456189424, 21.114437207579613, 43.1158684194088, 47.877556309103966, 40.76773501932621, 56.217242404818535, 61.37193560600281, 29.926852136850357, 3.5423998162150383, 0.1716849851072766, 0.08611191442469135, 0.17659549426753074, 0.09959198796423152, 0.1761862591956742, 0.1695683502475731, 0.15390367596410215, 0.17072000016923994, 0.11311667942209169, 0.22841744008474052, 0.1275578045169823, 0.121212026278954, 0.15564441302558407, 0.08022191876079887, 0.1669331471202895, 0.186314407910686, 0.12309647281654179, 0.13396446855040267], [0.12034977684379555, 0.041548525405232795, 0.04479099457967095, 0.04924947272229474, 0.021343161570257507, 0.07733224803814664, 0.05054401575762313, 0.029511279717553407, 0.05224573069426697, 0.05133802100317553, 0.042837583969230764, 0.024416228116024286, 0.030542924359906465, 0.08169552718754858, 0.07355830835876986, 0.04458986884856131, 0.051343780069146305, 0.027384842942410614, 0.01956279196747346, 0.02802987874019891, 0.042752826993819326, 0.023063328153511975, 0.6746702443342656, 10.143248867243528, 36.553172171115875, 39.04953941702843, 24.41919967532158, 16.477587819099426, 26.41110599040985, 40.275368839502335, 27.91846990585327, 6.445557558909059, 0.3533754270756617, 1.4780302019789815, 1.6511762235313654, 1.0204848786816, 5.588090820237994, 4.376953784376383, 2.412117454223335, 17.522470951080322, 35.356513783335686, 46.9795922935009, 53.88200931251049, 51.05506740510464, 47.7534169703722, 42.01685719192028, 38.93627889454365, 40.72092533111572, 44.92545671761036, 47.541563138365746, 48.86049136519432, 49.32309374213219, 47.67777822911739, 50.15212945640087, 48.13385255634785, 46.456234976649284, 48.00158925354481, 48.20642486214638, 36.26949079334736, 34.77926015853882, 36.589752808213234, 38.30819919705391, 43.05669419467449, 47.39578776061535, 51.61055959761143, 47.682015001773834, 50.177379101514816, 48.21269452571869, 46.801070272922516, 41.167188584804535, 34.75929223001003, 36.04020729660988, 34.68872241675854, 34.6063656359911, 34.31702636182308, 41.3316285610199, 51.05129420757294, 48.43762345612049, 49.711307510733604, 49.21234488487244, 50.411590933799744, 48.71489457786083, 47.8991087526083, 45.916409343481064, 44.354396760463715, 45.731245279312134, 46.72744542360306, 49.57088224589825, 50.71991018950939, 38.75977076590061, 46.41562655568123, 48.461379781365395, 49.56061899662018, 47.09882989525795, 45.83522289991379, 42.81274728477001, 40.208363234996796, 36.90187565982342, 37.12818391621113, 35.38596600294113, 36.28823518753052, 35.941598787903786, 36.09607569873333, 36.06528215110302, 37.833798453211784, 37.79289364814758, 43.707215487957, 48.982966393232346, 50.897771045565605, 50.33393070101738, 50.85516393184662, 50.13906195759773, 45.7395326346159, 38.532660752534866, 36.61641217768192, 36.32351629436016, 34.95378099381924, 39.05538350343704, 49.78296406567097, 48.1591971963644, 51.641341745853424, 49.30216446518898, 48.49301688373089, 45.85329852998257, 46.78953409194946, 43.073265105485916, 42.563811242580414, 42.03051745891571, 40.685230046510696, 38.02514098584652, 39.65985506772995, 39.881854355335236, 44.499514773488045, 45.91415226459503, 47.59128727018833, 49.40365321934223, 51.85147047042847, 54.503902941942215, 48.33745703101158, 34.62604098021984, 12.107562962919474, 2.6527414424344897, 5.20948626101017, 3.213194743730128, 6.7342750914394855, 9.467002004384995, 3.8318507093936205, 2.910051760263741, 0.8194411697331816, 0.584744744701311, 18.567876555025578, 39.96426433324814, 33.64949718117714, 26.558815464377403, 41.386395022273064, 37.89489157497883, 15.113446768373251, 1.4122801925987005, 0.07261155056767166, 0.026019870092568453, 0.03618998911406379, 0.044467796687968075, 0.028506606577138882, 0.05111578488140367, 0.06246897450182587, 0.11102981952717528, 0.01173895983811235, 0.020171781652607024, 0.030890167836332694, 0.012331769776210422, 0.074219977541361, 0.047105200283112936, 0.029266703095345292, 0.0071212924103747355, 0.028642438155657146, 0.10376164078479633, 0.0300483126193285, 0.03066903565922985, 0.022685239164275117, 0.03289617074187845, 0.03922030053217895, 0.04956139739078935, 0.045928213439765386, 0.029617531145049725, 0.02114893595717149, 0.09154389364994131, 0.07285398794920184, 0.034939767137984745, 0.08353542260010727, 0.018195314369222615, 0.040779627015581354, 0.06637149126618169, 0.07427333053783514, 0.055980384786380455, 0.063277336594183, 0.02439925890939776, 0.05485804969794117, 0.0332799278839957, 0.8971551933791488, 13.601297959685326, 45.12621134519577, 44.86896134912968, 28.593621477484703, 20.367344096302986, 28.610977046191692, 46.71104550361633, 32.30734460055828, 6.397598907351494, 0.28888021130114794, 0.9644733904860914, 1.600901240017265, 5.735437888652086, 7.212866060435772, 4.757153308019042, 3.745688907802105, 19.493685476481915, 40.27249239385128, 49.99360576272011, 54.58231933414936, 52.771663293242455, 49.63490881025791, 44.37160983681679, 40.92700347304344, 41.069252640008926, 46.90701238811016, 49.709061831235886, 49.85790744423866, 50.29199995100498, 50.43030112981796, 50.90810649096966, 48.669483214616776, 48.57732675969601, 50.50747498869896, 49.03979994356632, 39.27518650889397, 36.5621966868639, 38.264900520443916, 39.69817981123924, 45.831525698304176, 50.53296402096748, 51.86486475169659, 48.63311156630516, 51.126761958003044, 50.377856343984604, 49.454171508550644, 44.264957159757614, 37.757179364562035, 37.231614366173744, 36.1762285977602, 36.198871582746506, 36.195166781544685, 42.560862600803375, 51.92297503352165, 51.24236315488815, 51.04664705693722, 51.2689845263958, 51.61640368402004, 50.658558681607246, 49.660105258226395, 46.04255497455597, 46.13782726228237, 47.22602806985378, 49.575195014476776, 50.47561749815941, 52.17909649014473, 40.38042940199375, 46.55684597790241, 50.70119999349117, 50.93633137643337, 47.292505502700806, 48.466121926903725, 45.244149416685104, 42.27702543139458, 39.40537892282009, 38.36619548499584, 37.50814452767372, 37.689239010214806, 37.13665746152401, 36.92703790962696, 38.39905612170696, 40.31634584069252, 39.639811143279076, 44.96386505663395, 50.25738760828972, 51.65747947990894, 50.01507841050625, 51.173822432756424, 52.50912398099899, 48.482020273804665, 39.408365562558174, 38.0415865033865, 37.726875990629196, 36.80488586425781, 41.734334751963615, 51.54279783368111, 52.11282044649124, 52.99115851521492, 52.658737152814865, 51.28919184207916, 48.743936419487, 46.37801617383957, 44.70807418227196, 43.2134547829628, 42.93402157723904, 40.752562433481216, 39.51258637011051, 40.46838328242302, 42.08845674991608, 45.95034912228584, 48.128430247306824, 49.869690611958504, 51.63697198033333, 54.82338219881058, 55.65572373569012, 51.48350201547146, 35.90484336018562, 12.90939973667264, 3.701444794423878, 6.7308467254042625, 4.544182335957885, 6.713536279276013, 11.419771369546652, 7.617226112633944, 3.3314752718433738, 0.5416557099670172, 0.6515046686399728, 21.457144618034363, 40.90752571821213, 38.1011027097702, 29.863539934158325, 45.98775431513786, 47.687589302659035, 18.79768632352352, 1.7819074960425496, 0.11367277809767984, 0.022121412876003888, 0.027775362905231304, 0.0646112282993272, 0.018902300944318995, 0.04882175075181294, 0.02450973686791258, 0.0042464279977139086, 0.057615473415353335, 0.06595812243176624, 0.044411207927623764, 0.0212566716800211, 0.019964679777331185, 0.07508469090680592, 0.06021826695359778, 0.03713382284331601, 0.04709105865913443, 0.044409463880583644, 0.2220054919598624, 0.2542777539929375, 0.1590561549528502, 0.11801627901149914, 0.22386319149518386, 0.23495246598031372, 0.17628244153456762, 0.13037082622759044, 0.10978270714986138, 0.23322827881202102, 0.18495231459382921, 0.11104884077212773, 0.13556262420024723, 0.2209525922080502, 0.12388162052957341, 0.25957333389669657, 0.2562304929597303, 0.2898928866488859, 0.17136056267190725, 0.1549591138609685, 0.14190708141541108, 0.1139122543099802, 1.125176742207259, 16.543506681919098, 50.64532779157162, 50.290176048874855, 35.43365344405174, 25.847223848104477, 37.18944422900677, 51.66154146194458, 35.45058153569698, 8.273466099053621, 0.612975686090067, 2.1919696172699332, 6.745138708502054, 9.06180314719677, 13.625408615916967, 8.67288451641798, 5.126557610929012, 20.789028368890285, 41.112745106220245, 52.04156666994095, 57.536269426345825, 55.5489494651556, 51.30779944360256, 46.55363894999027, 41.95945747196674, 44.59134444594383, 50.0321014970541, 52.0228336751461, 53.48664432764053, 54.61773343384266, 51.97651036083698, 51.92123852670193, 50.5693356692791, 51.61905974149704, 53.88058818876743, 51.005210280418396, 41.17155075073242, 37.87806607782841, 40.73336586356163, 42.00405187904835, 47.651248052716255, 52.974750995635986, 55.290692523121834, 48.815706968307495, 53.2203584164381, 53.159820064902306, 51.46992914378643, 45.10926805436611, 38.17875154316425, 40.544003024697304, 38.463337272405624, 37.66566127538681, 37.99820803105831, 45.2151645720005, 55.45378737151623, 52.28211276233196, 51.4637316763401, 52.71720081567764, 52.64325678348541, 51.99889495968819, 51.28551743924618, 48.73243063688278, 48.50456826388836, 49.7450041025877, 51.64027780294418, 52.27381780743599, 56.00838281214237, 44.40938740968704, 47.479907646775246, 51.7311043292284, 53.96141365170479, 50.789621248841286, 49.586385414004326, 47.7950095385313, 44.08484302461147, 41.02826043963432, 40.860849022865295, 38.06157723069191, 39.14268381893635, 39.784336388111115, 38.52941572666168, 40.009751692414284, 42.56464719772339, 41.87728688120842, 48.4433763474226, 53.205691203475, 54.09387454390526, 52.01829291880131, 55.47463305294514, 54.557582661509514, 49.48094867169857, 42.82013788819313, 40.918070152401924, 39.893223345279694, 38.07522609829903, 42.66832463443279, 53.86260375380516, 53.7536484003067, 55.15170358121395, 54.72335256636143, 52.96938568353653, 50.45415244996548, 50.81474170088768, 46.39520265161991, 46.46801054477692, 45.38164883852005, 42.80916787683964, 41.13527789711952, 43.72933030128479, 43.146874755620956, 48.86054076254368, 49.59045119583607, 52.6540520042181, 54.07665766775608, 56.57019026577473, 57.71711692214012, 52.815269753336906, 37.770744636654854, 14.20285603031516, 5.492117470130324, 11.890855841338634, 10.925754178315401, 20.0291508436203, 15.184199921786785, 11.311920806765556, 5.136092724278569, 1.5930911153554916, 1.1818347894586623, 25.151277892291546, 52.95771650969982, 46.32692411541939, 38.599263578653336, 53.558171689510345, 52.90895752608776, 23.032148703932762, 2.0495292730629444, 0.2102304284926504, 0.27291824750136584, 0.12225284386659041, 0.14454875607043505, 0.21269226592266932, 0.07321467172005214, 0.20478757680393755, 0.17200315865920857, 0.1789096146239899, 0.1321363213355653, 0.14688214258057997, 0.11501461820444092, 0.21242322254693136, 0.1450848687090911, 0.23122427228372544, 0.22465347487013787, 0.17547198658576235, 0.16499612684128806], [0.05357458321668673, 0.03393263934412971, 0.07160248205764219, 0.02224594896688359, 0.020841094956267625, 0.03904959543433506, 0.03602572585805319, 0.07308212414500304, 0.02940980401035631, 0.05309490719810128, 0.01392548088915646, 0.07794227858539671, 0.0952580088051036, 0.015532283487118548, 0.03077398461755365, 0.014817333667451749, 0.023070193019520957, 0.0299203236863832, 0.02153272092982661, 0.04535920510534197, 0.025599712462280877, 0.08287813951028511, 0.16213210474234074, 5.226368755102158, 29.14435062557459, 47.55911439657211, 30.270537994801998, 24.71508789807558, 36.44800901412964, 36.07464484870434, 37.340896502137184, 12.444014009088278, 1.1006483458913863, 7.789719756692648, 12.080682255327702, 1.6617052210494876, 4.123017210513353, 4.521359335631132, 1.7214921629056334, 9.748414903879166, 30.121500492095947, 58.076171055436134, 51.415489464998245, 51.41012795269489, 46.38871259987354, 43.64000849425793, 45.403083488345146, 47.81528525054455, 49.104107692837715, 50.83960376679897, 50.62608942389488, 51.374603658914566, 47.98341102898121, 50.261654779314995, 49.195219203829765, 49.67840127646923, 49.32829566299915, 44.24824945628643, 34.58186835050583, 35.56518718600273, 36.189695075154305, 41.28270238637924, 46.042011603713036, 49.613918736577034, 49.532781690359116, 48.686882480978966, 49.39945824444294, 50.093813985586166, 44.365784749388695, 38.856502175331116, 34.79105852544308, 34.85323838889599, 36.030650809407234, 35.167371332645416, 34.668868482112885, 42.62937672436237, 51.51875652372837, 48.85605700314045, 47.72561766207218, 46.82668849825859, 48.82123947143555, 50.3351504355669, 49.21987988054752, 48.58997628092766, 47.426843494176865, 47.8625813126564, 46.058373525738716, 49.006977304816246, 49.037736654281616, 34.56087827682495, 45.69564878940582, 53.65361876785755, 48.93723584711552, 47.02072128653526, 44.434884041547775, 41.045541912317276, 39.11419674754143, 39.34130296111107, 34.03616443276405, 35.38352273404598, 34.181111454963684, 35.60453027486801, 35.46288527548313, 36.21359199285507, 36.73662252724171, 39.207063764333725, 44.739525094628334, 48.983574360609055, 49.89374332129955, 49.23724874854088, 50.70966973900795, 50.006114691495895, 45.585321709513664, 36.49247422814369, 34.68339890241623, 35.8919620513916, 35.087123438715935, 41.014987751841545, 51.40762008726597, 49.26725193858147, 46.49805173277855, 48.29560987651348, 51.39950752258301, 50.17944619059563, 49.40218649804592, 47.402524799108505, 48.751915991306305, 48.216361328959465, 48.40354308485985, 43.46679858863354, 42.326795160770416, 40.57338684797287, 43.11316296458244, 43.51692549884319, 49.91817981004715, 49.77634862065315, 53.506198078393936, 54.14395585656166, 47.808517813682556, 29.14542216807604, 12.192889284342527, 2.4049861868843436, 3.0926718609407544, 6.941446149721742, 9.686975050717592, 3.8425229117274284, 2.1087262965738773, 0.2560755325248465, 0.17358022247208282, 1.5433124802075326, 16.83880213648081, 37.58899658918381, 28.16396713256836, 36.26729071140289, 42.99409635365009, 31.58231880515814, 10.422127302736044, 0.22214413998881355, 0.030213327299861703, 0.015151409588725073, 0.04267968834028579, 0.02180737123126164, 0.036791985912714154, 0.01840646094933618, 0.011195213282917393, 0.007303036954908748, 0.07372466818196699, 0.10895455940044485, 0.00861034724948695, 0.04104828818526585, 0.040792789004626684, 0.02090436675644014, 0.021893625489610713, 0.07993356470251456, 0.032760773319751024, 0.013628822198370472, 0.06006144001730718, 0.013560365568991983, 0.03762745123822242, 0.010570052199909696, 0.03800996899371967, 0.029221775330370292, 0.033845110447146, 0.04383536070236005, 0.015970095882948954, 0.05405140938819386, 0.06739171425579116, 0.04003976515377872, 0.047162854025373235, 0.0273286753508728, 0.030036017087695654, 0.06795487817726098, 0.07917655922938138, 0.04686034350015689, 0.054552800647797994, 0.019840453533106484, 0.043445926130516455, 0.08551847829949111, 0.29028762015514076, 7.724496256560087, 35.34283071756363, 52.41384029388428, 33.49850468337536, 25.42141679674387, 36.72962710261345, 41.13742858171463, 38.67777116596699, 13.087670970708132, 0.9682242048438638, 7.954192981123924, 7.047709347680211, 5.439263256266713, 6.204669484868646, 4.085124218836427, 4.601225825026631, 10.21240420639515, 35.213177874684334, 58.58118675649166, 55.1429982483387, 51.525208577513695, 49.285027384757996, 43.39448846876621, 46.0140261054039, 47.59373053908348, 51.34798228740692, 52.14297942817211, 53.431988060474396, 51.28351114690304, 48.68078760802746, 51.19716838002205, 50.84605202078819, 50.694907531142235, 51.341853216290474, 47.08111144602299, 36.03472039103508, 36.52511827647686, 37.66017057001591, 41.90967634320259, 48.13455551862717, 50.95672868192196, 51.559782922267914, 49.29790869355202, 51.29980467259884, 50.29230013489723, 46.95102542638779, 40.33728651702404, 37.5959350168705, 36.59973107278347, 37.6460125297308, 36.655439883470535, 35.64702719449997, 45.005484223365784, 53.284563571214676, 50.378490909934044, 50.376572012901306, 48.58497194945812, 50.02067171037197, 52.460178807377815, 52.484360709786415, 50.88300123810768, 49.82810564339161, 50.12300781905651, 51.063400357961655, 50.55074706673622, 51.282633394002914, 39.8138228058815, 46.0937762260437, 55.57614840567112, 50.85319563746452, 48.72328072786331, 45.80840393900871, 43.62155668437481, 41.89787797629833, 41.47290498018265, 38.15573237836361, 37.07944393157959, 36.23002231121063, 36.65174648165703, 37.49966338276863, 37.61869579553604, 38.24975073337555, 40.232457742094994, 46.43785156309605, 51.08938716351986, 52.08132393658161, 49.31948773562908, 52.71215848624706, 52.080563977360725, 47.116730734705925, 39.08208467066288, 37.02207460999489, 37.69450552761555, 36.59069515764713, 43.47657926380634, 53.81053514778614, 51.26285545527935, 47.79213689267635, 50.32308228313923, 53.44627529382706, 52.01196625828743, 50.91932348906994, 47.99949176609516, 50.046605318784714, 48.07461753487587, 48.41476388275623, 45.35300597548485, 44.56459388136864, 41.924316957592964, 43.64278994500637, 45.684040412306786, 51.4321743696928, 51.36437460780144, 54.669524654746056, 56.15287385880947, 49.58883248269558, 32.41544499993324, 11.78611446171999, 2.5779153825715184, 6.336490111425519, 8.538689017295837, 7.1920807007700205, 6.576262470334768, 2.5678200367838144, 0.6291564053390175, 0.20565648330375552, 1.5557171520777047, 20.26853609830141, 45.67945405840874, 33.029499650001526, 39.356726333498955, 49.83128987252712, 36.79729387164116, 13.733969740569592, 0.3337070590350777, 0.009377277092426084, 0.06164781778352335, 0.09293651892221533, 0.03397342035896145, 0.03730812735739164, 0.04950681985064875, 0.01681847086729249, 0.053665255109081045, 0.02396529547695536, 0.1461965762428008, 0.045066832317388617, 0.048757246986497194, 0.029489577464119066, 0.02820764908392448, 0.018466237233951688, 0.03279721648141276, 0.036943985178368166, 0.048152741728699766, 0.24267550703370944, 0.16082377260318026, 0.1576165814185515, 0.09147681834292598, 0.09536228797514923, 0.18270483909873292, 0.07824710090062581, 0.1128647499717772, 0.24664948519784957, 0.19753955479245633, 0.15795638115378097, 0.0999101392517332, 0.21087719534989446, 0.08319223124999553, 0.07810310198692605, 0.12472634785808623, 0.13565304747316986, 0.14178191078826785, 0.11699083130224608, 0.09676596382632852, 0.09904229402309284, 0.2953299495857209, 0.37878881965298206, 8.535847719758749, 43.229520320892334, 61.42747342586517, 41.666333600878716, 35.58559589087963, 48.68130438029766, 47.32435539364815, 48.0973669141531, 15.60867229476571, 2.735650143586099, 10.917168539017439, 18.32402653992176, 6.614523567259312, 12.2734934091568, 10.613777618855238, 3.713692012242973, 13.782157804816961, 35.25282494723797, 62.489254251122475, 55.946499332785606, 56.73040106892586, 51.17782361805439, 47.13645927608013, 50.42276233434677, 49.83623340725899, 53.79157416522503, 55.00513784587383, 54.583797454833984, 53.27671319246292, 49.99319538474083, 52.47355788946152, 52.039814963936806, 53.40818613767624, 52.748552933335304, 49.0035080909729, 37.569974809885025, 39.239255636930466, 39.1354414075613, 44.38243925571442, 50.27045510709286, 53.291885778307915, 51.973459124565125, 50.81318758428097, 53.399290814995766, 51.8201145529747, 49.37435299158096, 43.812830820679665, 39.36478190124035, 38.120424672961235, 39.443756863474846, 38.82200002670288, 38.46067361533642, 47.752854600548744, 56.02137431502342, 53.7731109559536, 50.97079932689667, 51.64296805858612, 51.489175111055374, 53.237537294626236, 54.61640350520611, 51.46683230996132, 52.4448162317276, 53.43144468963146, 51.983387991786, 51.6125962883234, 50.85319183766842, 42.56976552307606, 46.9097026437521, 56.56721882522106, 54.26251709461212, 51.376583352684975, 48.290613144636154, 45.21613731980324, 43.6760875582695, 43.24690818786621, 39.174727499485016, 38.207633793354034, 38.52300927042961, 38.47820587456226, 39.46692422032356, 39.100012108683586, 41.2200703471899, 42.86812171339989, 49.046251997351646, 52.74051636457443, 53.42618577182293, 50.93286216259003, 56.06278449296951, 54.25355717539787, 49.323975294828415, 40.38109436631203, 39.18266527354717, 39.5206381380558, 39.98848423361778, 45.77797897160053, 55.27326285839081, 52.66232416033745, 48.563613295555115, 51.244259253144264, 56.779441237449646, 54.5958162099123, 53.16408343613148, 50.33593699336052, 53.529316037893295, 51.910029128193855, 51.99094958603382, 47.24082827568054, 46.778336092829704, 43.609427735209465, 46.3140732049942, 46.37300804257393, 55.244954377412796, 53.87604743242264, 58.390794172883034, 56.357223093509674, 51.08056403696537, 32.64695517718792, 14.828642550855875, 4.8099044524133205, 9.962378572672606, 15.802227258682251, 18.270797096192837, 8.297051433473825, 5.1380605436861515, 1.0921134101226926, 0.4437398031586781, 2.499119723215699, 22.961235009133816, 51.8304879963398, 39.997489750385284, 51.3644278049469, 56.03630371391773, 45.946534126996994, 14.687724262475967, 0.6065093830693513, 0.12638245039852336, 0.16080259170848876, 0.20238929690094665, 0.152047683368437, 0.09853466501226649, 0.14744430460268632, 0.1177796749107074, 0.11250405877945013, 0.08471709981677122, 0.3132331639062613, 0.16970469761872664, 0.13109229766996577, 0.08849285775795579, 0.10705639797379263, 0.10116382705746219, 0.22573989001102746, 0.10585970710963011, 0.10283623458235525], [0.040270940444315784, 0.09248299247701652, 0.019683849241118878, 0.07350492567638867, 0.023276113024621736, 0.06778969094739296, 0.04347613525169436, 0.02476907851814758, 0.05543737017433159, 0.036104096652707085, 0.023347826754616108, 0.059876793675357476, 0.014753929208382033, 0.0343247308046557, 0.06185977144923527, 0.046100736799417064, 0.08407091183471493, 0.07714151608524844, 0.03440502376179211, 0.023035913218336646, 0.0506838957517175, 0.009682473264547298, 0.044966749992454425, 1.5332472953014076, 17.879030518233776, 38.78110282123089, 35.28091683983803, 30.504269152879715, 21.460516937077045, 36.4106760174036, 38.87724906206131, 19.702115692198277, 1.8061515013687313, 9.429035391658545, 28.4650781750679, 17.447713762521744, 6.025925176218152, 5.559050403535366, 3.972572833299637, 6.897531431168318, 37.651697024703026, 49.535327553749084, 54.46379229426384, 48.58174592256546, 49.72290828824043, 48.15018408000469, 50.33663235604763, 48.591241613030434, 53.31851474940777, 51.482289880514145, 50.72825074195862, 50.62862388789654, 49.68465194106102, 51.1650525033474, 49.40301485359669, 46.553426161408424, 45.9070960432291, 36.2884745746851, 35.56810162961483, 37.26816080510616, 36.608489602804184, 41.9526482373476, 46.20803229510784, 50.41675865650177, 50.851250141859055, 49.24348421394825, 51.325286105275154, 47.76268847286701, 44.34609800577164, 35.326525792479515, 35.65718024969101, 34.68724049627781, 34.108094573020935, 36.81661583483219, 35.50190918147564, 39.9707467854023, 48.89578007161617, 49.57122042775154, 49.6261502802372, 46.39700375497341, 43.86442445218563, 45.480637326836586, 47.78190404176712, 47.66361638903618, 50.05715735256672, 48.45370799303055, 46.012281998991966, 46.020804941654205, 41.3880555331707, 38.80533032119274, 51.767551973462105, 49.457705318927765, 48.10814693570137, 46.22444361448288, 43.41092258691788, 38.825853019952774, 36.57881319522858, 34.945805221796036, 35.00919722020626, 35.69441445171833, 35.03502443432808, 34.378222078084946, 36.42671495676041, 35.74900232255459, 35.34800224006176, 39.31224212050438, 47.731305956840515, 48.81786525249481, 49.63362827897072, 51.1460155248642, 47.990885227918625, 47.44553469121456, 38.632166013121605, 35.94620794057846, 38.24424482882023, 35.147999972105026, 35.117821991443634, 37.94689558446407, 50.35562753677368, 50.966235771775246, 49.22648012638092, 48.52892495691776, 49.75393742322922, 52.142656445503235, 52.26528726518154, 50.904656276106834, 50.207374691963196, 49.59062598645687, 49.7983418405056, 49.649488627910614, 47.64152057468891, 46.390095725655556, 43.564510345458984, 45.71215510368347, 47.00393758714199, 50.55284075438976, 52.61050634086132, 57.66498751938343, 45.91033346951008, 27.840574085712433, 7.375408988445997, 3.125861417502165, 2.9989475151523948, 9.543456751853228, 10.292318668216467, 1.2680184398777783, 2.52166248857975, 1.4148214249871671, 0.24553871277021244, 1.5250551723875105, 22.035902962088585, 29.572988525032997, 28.783622682094574, 28.472740463912487, 50.03679424524307, 30.34768335521221, 5.523253949359059, 0.27680175786372274, 0.06976216362090781, 0.05733930542191956, 0.016702124376024585, 0.09762254325323738, 0.16940153029281646, 0.03502171879517846, 0.041661205686978064, 0.03367578945471905, 0.06951093178940937, 0.11294777403236367, 0.01894530469144229, 0.059072687799925916, 0.0410716472833883, 0.012683224013017025, 0.03694011116749607, 0.033345726697007194, 0.004279537524780608, 0.030834577264613472, 0.0385337137413444, 0.035210239148000255, 0.032944569902610965, 0.04395637530251406, 0.03632271851529367, 0.02025251062150346, 0.021485919241968077, 0.048224715210380964, 0.055995658185565844, 0.020028382023156155, 0.04579795539029874, 0.029774977774650324, 0.07131630249205045, 0.031403845350723714, 0.012402643951645587, 0.06906087859533727, 0.05324365585693158, 0.0702968290715944, 0.06485088262706995, 0.016726659778214525, 0.00859888292325195, 0.021793789928779006, 0.01697018069535261, 2.642314089462161, 23.26913058757782, 47.872426584362984, 38.70504230260849, 34.63445372879505, 29.02054376900196, 41.134115159511566, 44.133423417806625, 20.585984364151955, 2.67022549174726, 9.63629812002182, 28.14825687557459, 8.717137891799212, 6.695336205884814, 5.259213717654347, 3.7377720326185226, 8.411551639437675, 37.666470631957054, 51.4144217222929, 54.01018783450127, 51.69712275266647, 50.46708695590496, 49.97768461704254, 52.946400716900826, 51.4397169649601, 54.62080366909504, 53.29460263252258, 51.36317007243633, 51.23439118266106, 51.59435726702213, 51.665276661515236, 52.40376703441143, 50.12920908629894, 48.663566932082176, 39.44825202226639, 35.92405512928963, 38.92716698348522, 38.612597063183784, 42.14005038142204, 47.76111915707588, 51.17824159562588, 51.74587033689022, 49.82083663344383, 52.88750007748604, 50.120180770754814, 46.797407269477844, 36.801526844501495, 37.371287271380424, 36.54634773731232, 36.07712231576443, 38.685974925756454, 37.820594161748886, 41.87127560377121, 51.91279157996178, 50.478873923420906, 50.997774079442024, 47.88141310214996, 45.8970607817173, 48.03505785763264, 49.96046394109726, 48.93629349768162, 51.743343472480774, 51.317226737737656, 49.631986767053604, 47.09620803594589, 43.39450366795063, 40.39456844329834, 53.83343651890755, 52.236572206020355, 49.443110302090645, 48.99250768125057, 45.67527428269386, 42.68468655645847, 38.66875045001507, 36.382679119706154, 36.234939247369766, 37.348537892103195, 36.346767246723175, 35.971335992217064, 37.401651442050934, 37.66287602484226, 37.373988926410675, 42.402958273887634, 49.55982863903046, 51.526340916752815, 51.31987139582634, 53.581160455942154, 49.67953361570835, 49.03159998357296, 42.23813831806183, 38.26489672064781, 38.81204076111317, 37.160877361893654, 37.39237233996391, 40.74147082865238, 51.99217692017555, 52.84241929650307, 48.11612270772457, 50.13776242733002, 51.77090719342232, 54.15568582713604, 53.68380054831505, 52.60203659534454, 51.530174911022186, 52.00262635946274, 50.43771453201771, 50.65418131649494, 49.3320232629776, 47.93986916542053, 46.45958639681339, 47.56980702280998, 50.490330308675766, 52.59319826960564, 54.81463126838207, 57.35820718109608, 48.090983256697655, 28.139017671346664, 10.522121787071228, 3.1786120869219303, 4.715653359889984, 10.435197651386261, 6.972883762791753, 3.15697462297976, 4.587124781683087, 0.5425630300305784, 0.24075206805719063, 1.8270396930165589, 23.432571217417717, 35.53832642734051, 30.257195010781288, 34.27950717508793, 53.50199170410633, 36.37287564575672, 7.670616572722793, 0.23121747421100736, 0.05288384410960134, 0.025397634926775936, 0.025060557018150575, 0.026272300492564682, 0.05986788048176095, 0.032633587761665694, 0.06549233570694923, 0.055453853274229914, 0.05832029848534148, 0.04261320675141178, 0.022186399037309457, 0.04532681035925634, 0.05106516669911798, 0.02795829117530957, 0.030117163514660206, 0.09256597200874239, 0.09920158117893152, 0.021725768383475952, 0.13138311565853655, 0.18748265225440264, 0.25145026040263474, 0.15175547014223412, 0.09759137305081822, 0.10019676410593092, 0.225553996860981, 0.1571927111945115, 0.1911782508250326, 0.1487521469243802, 0.166859911987558, 0.18969477183418348, 0.20633238687878475, 0.12487945292377844, 0.18148808798287064, 0.19552450510673225, 0.14817245537415147, 0.266791699687019, 0.12826189486077055, 0.1040739736345131, 0.0960338648292236, 0.13456174900056794, 0.2027117897523567, 3.0219567054882646, 28.79853878170252, 52.712941244244576, 45.27522794902325, 41.34979158639908, 32.303677797317505, 47.005845084786415, 50.70661850273609, 24.66053992509842, 3.5549284564331174, 10.874416083097458, 36.39126665890217, 30.519352443516254, 18.943550996482372, 13.547008372843266, 6.78347485139966, 9.203381650149822, 40.624421909451485, 53.418893963098526, 56.7754590511322, 52.482757195830345, 53.91502194106579, 52.32385352253914, 55.884824842214584, 54.06516708433628, 58.510221764445305, 54.46723110973835, 52.02441059052944, 52.30041638016701, 52.96444594860077, 54.83533255755901, 53.64156201481819, 51.6411479562521, 50.629573836922646, 40.2339206635952, 37.90107004344463, 40.204263255000114, 39.95486743748188, 44.24322992563248, 49.51459586620331, 53.48857842385769, 53.67264814674854, 50.82300625741482, 54.86686706542969, 50.938759446144104, 49.5819054543972, 38.629456758499146, 39.949015751481056, 37.19956308603287, 37.22704701125622, 38.65384005010128, 39.63121220469475, 43.09807397425175, 52.85009488463402, 54.61012244224548, 52.615723460912704, 47.76775360107422, 46.35972395539284, 48.12520042061806, 52.0174265652895, 50.42646333575249, 54.393427670001984, 52.976369708776474, 52.81480237841606, 50.35074859857559, 45.70893667638302, 45.441936403512955, 55.50406627357006, 52.19460345804691, 51.28144025802612, 51.94701634347439, 48.13427433371544, 43.266678526997566, 40.98042480647564, 38.19326676428318, 38.55147734284401, 40.499746799468994, 38.17048318684101, 38.25600519776344, 38.50035108625889, 39.07705754041672, 39.02929030358791, 44.70587410032749, 53.31669844686985, 52.50084802508354, 52.57385730743408, 56.09762862324715, 52.63890601694584, 51.98266223073006, 42.94497258961201, 38.26612785458565, 40.54502137005329, 39.08659502863884, 39.888978973031044, 42.05319084227085, 54.78265218436718, 55.34497261047363, 50.682406201958656, 51.572637632489204, 50.99691532552242, 55.07958725094795, 55.50345070660114, 53.80200460553169, 53.289537504315376, 54.23658348619938, 53.52285638451576, 53.625314086675644, 50.860023871064186, 51.79733857512474, 48.28521363437176, 51.28394052386284, 52.74558529257774, 55.28703331947327, 55.653774440288544, 62.293329164385796, 48.894925117492676, 32.068922594189644, 10.010151509195566, 6.752099934965372, 8.717097993940115, 19.646498076617718, 17.126205414533615, 4.452129425480962, 10.708907414227724, 2.1909056743606925, 0.8511985593941063, 2.441323399543762, 31.259545125067234, 41.68264612555504, 42.39581845700741, 42.13236719369888, 62.52363480627537, 41.59228317439556, 8.479753229767084, 0.6222934392280877, 0.16073321574367583, 0.2033375686733052, 0.1561654600664042, 0.19344419095432386, 0.2995200559962541, 0.08264784366474487, 0.15192098391707987, 0.12301422058953904, 0.12439443715265952, 0.19264148402726278, 0.16299002745654434, 0.155332503200043, 0.18377488246187568, 0.11296206037513912, 0.16424919973360375, 0.12384626461425796, 0.21401014208095148, 0.13530327327316627], [0.027415796066634357, 0.01468154754547868, 0.03311003543785773, 0.03424715039727744, 0.024430631347058807, 0.01501278475188883, 0.02915297638537595, 0.06870622106362134, 0.048875541615416296, 0.02257884116261266, 0.022155319747980684, 0.058189984774799086, 0.030151278187986463, 0.023797692556399852, 0.0342554364760872, 0.007309400407393696, 0.07433784543536603, 0.035246147963334806, 0.01603771666850662, 0.06712668589898385, 0.04394453433633316, 0.010454102757648798, 0.07422730996040627, 0.25974675896577537, 11.8254404515028, 38.26963126659393, 43.6391307413578, 30.15898358076811, 27.816128097474575, 33.249101266264915, 36.02326400578022, 23.725609593093395, 2.6692437194287777, 1.2477193353697658, 32.857729867100716, 50.48513598740101, 25.10387923568487, 2.617262746207416, 1.9690818898379803, 5.22300498560071, 33.237515687942505, 51.360555812716484, 54.713412299752235, 50.79367183148861, 52.254716232419014, 49.07799169421196, 53.23111183941364, 53.16948674619198, 50.48892818391323, 48.222338408231735, 49.40434858202934, 53.634927570819855, 51.56878463923931, 50.054007321596146, 46.7768769711256, 44.44673180580139, 38.32445092499256, 33.86251375079155, 34.88262981176376, 37.76871934533119, 36.47751063108444, 41.35756976902485, 46.890893653035164, 51.205980107188225, 51.14813581109047, 52.07666538655758, 51.41760595142841, 50.982878878712654, 43.45888741314411, 35.23334339261055, 36.68552286922932, 35.78230753540993, 35.10274060070515, 37.126261219382286, 36.77006833255291, 35.52658125758171, 46.74705617129803, 48.634555488824844, 50.08034370839596, 51.315391436219215, 48.41162525117397, 49.15445499122143, 44.50188584625721, 46.345451921224594, 44.72895406186581, 44.60175208747387, 40.85358761250973, 42.41246536374092, 44.13086995482445, 34.88946944475174, 52.3623226583004, 48.94911780953407, 46.730211675167084, 44.845592603087425, 43.03099237382412, 38.682992085814476, 38.28596659004688, 35.767127349972725, 38.245038986206055, 37.333977073431015, 35.50531379878521, 36.06282748281956, 34.717232286930084, 37.349077463150024, 36.36639319360256, 40.85076816380024, 46.48018129169941, 50.32475799322128, 49.889217764139175, 49.67749312520027, 49.780999571084976, 47.47344799339771, 38.82138065993786, 36.710122749209404, 36.14307917654514, 35.82685634493828, 34.69783432781696, 36.80134445428848, 44.0046863257885, 48.56414146721363, 49.40719462931156, 50.46539604663849, 47.69638583064079, 46.249830052256584, 46.96790412068367, 50.43997921049595, 51.26578129827976, 49.95319493114948, 50.893002301454544, 50.607774406671524, 49.5222182571888, 50.134973376989365, 47.850167378783226, 49.07740652561188, 45.95452509820461, 49.17555905878544, 50.208282843232155, 53.843638971447945, 41.18566319346428, 22.983093336224556, 5.110206138342619, 3.6820406606420875, 2.0754346204921603, 16.553543843328953, 13.485331982374191, 3.9498203666880727, 3.39568636380136, 0.35893562715500593, 0.06959883918170817, 3.350369045510888, 21.699303723871708, 33.601764142513275, 30.263282284140587, 35.39942868053913, 46.86670795083046, 23.98834839463234, 2.6101250667124987, 0.0328211099258624, 0.13128978316672146, 0.03862225195916835, 0.060202737513463944, 0.05172748526092619, 0.10737985561718233, 0.028173447208246216, 0.026911237691820133, 0.10717430297518149, 0.030964334364398383, 0.025214328161382582, 0.02313586010131985, 0.05773912635049783, 0.07275028765434399, 0.05283341888571158, 0.021236800675978884, 0.013566498491854873, 0.12806408281903714, 0.034128373372368515, 0.02136309751222143, 0.05034008099755738, 0.05855096911545843, 0.03453567514952738, 0.03541425183357205, 0.01957393531483831, 0.05833606170199346, 0.03159593543387018, 0.03235666277760174, 0.033929555720533244, 0.017394648348272312, 0.08804976590909064, 0.0542019206477562, 0.06831063408753835, 0.03180761450494174, 0.0019781392029472045, 0.037843820682610385, 0.03906234553141985, 0.03964274583267979, 0.058518566947896034, 0.1110946609696839, 0.018058696114167105, 0.025077448299271055, 0.44892676232848316, 15.38506854325533, 43.377932757139206, 49.35550980269909, 34.230470806360245, 28.677034601569176, 40.21279379725456, 44.1405176371336, 25.187526047229767, 3.6185436928644776, 2.8935813065618277, 36.110606119036674, 42.658129781484604, 21.90673839300871, 4.815868232399225, 2.27971023414284, 6.229322561994195, 37.0918008685112, 53.49122688174248, 55.673806965351105, 53.56373839080334, 54.074928760528564, 52.599790915846825, 53.428188264369965, 55.603430941700935, 52.61540807783604, 48.60521726310253, 50.45173577964306, 55.34835062921047, 53.053752556443214, 52.726909294724464, 48.222604393959045, 46.67180120944977, 40.79323545098305, 35.41156902909279, 36.81278184056282, 38.24085161089897, 37.965651378035545, 44.024544060230255, 48.77550512552261, 52.74236686527729, 51.77414081990719, 53.44885915517807, 52.28966295719147, 51.56617797911167, 46.42827607691288, 38.095110431313515, 37.44431175291538, 36.931122690439224, 37.15575523674488, 38.85604240000248, 37.09835171699524, 37.07323506474495, 49.02466535568237, 51.40059046447277, 51.78096525371075, 51.06519766151905, 50.553270131349564, 49.75523315370083, 45.202834233641624, 47.16880314052105, 45.706128627061844, 45.413475930690765, 44.396585896611214, 43.97038176655769, 45.32087489962578, 38.53613756597042, 54.470039159059525, 50.74064187705517, 50.228288769721985, 46.74798712134361, 44.310972690582275, 40.078584998846054, 39.85870219767094, 36.63347706198692, 39.22156758606434, 38.23569908738136, 37.92006142437458, 38.29154469072819, 35.63087426126003, 39.074971452355385, 36.85150936245918, 41.055007204413414, 47.944029942154884, 52.11161591112614, 50.18073432147503, 51.963442862033844, 51.09310336410999, 49.66816462576389, 40.27899384498596, 38.14405180513859, 38.90646189451218, 37.90364630520344, 34.70270186662674, 39.19603295624256, 47.78957962989807, 49.30836573243141, 50.61310552060604, 51.001171097159386, 47.73550473153591, 47.35258027911186, 48.142478093504906, 52.01775334775448, 51.952381655573845, 53.50874774158001, 53.04530940949917, 52.45355196297169, 51.249628365039825, 51.50819689035416, 48.55101317167282, 50.13531535863876, 48.62190596759319, 50.71378871798515, 53.77365052700043, 57.73624889552593, 44.654082879424095, 24.817171320319176, 5.074664745479822, 4.444470936432481, 5.504641123116016, 11.810589898377657, 19.5884295925498, 4.532491313293576, 2.6844438537955284, 0.5396823096089065, 0.069761235936312, 3.666258445009589, 26.380352340638638, 38.24425242841244, 37.18896545469761, 39.389294385910034, 53.60287629067898, 31.075118221342564, 3.923561875708401, 0.12053006677888334, 0.1138217345578596, 0.05050927953561768, 0.09282667364459485, 0.049889378424268216, 0.07611839871970005, 0.015723606375104282, 0.0177192155024386, 0.07380296476185322, 0.04261108049831819, 0.10936024700640701, 0.03825294072157703, 0.02828354852681514, 0.04057093137816992, 0.018311028179596178, 0.07760300577501766, 0.035434326928225346, 0.05378396534069907, 0.04105523839825764, 0.19230665668146685, 0.11579845231608488, 0.13258747290819883, 0.12294271466089413, 0.11604506056755781, 0.12843068892834708, 0.1438836581655778, 0.15378865791717544, 0.17076935298973694, 0.09482506211497821, 0.11903103979420848, 0.13948500825790688, 0.09659977469709702, 0.12466621905332431, 0.13660402066307142, 0.10330843346309848, 0.1021948408742901, 0.2536239812616259, 0.12570984195917845, 0.2101560652954504, 0.2911745460005477, 0.10275462060235441, 0.22154282225528732, 0.6289218866731972, 18.229215927422047, 51.801210567355156, 57.272726967930794, 41.07750579714775, 35.27391381561756, 44.42091219127178, 48.762034848332405, 28.173935897648335, 5.074663320556283, 3.688277075998485, 36.647490710020065, 62.21923314034939, 34.2594176530838, 8.729706667363644, 5.5126016959548, 7.177743120118976, 41.238465160131454, 55.61426796019077, 58.52471798658371, 56.08869530260563, 58.34084965288639, 54.02089945971966, 56.974765956401825, 56.69215992093086, 53.46522867679596, 48.252231404185295, 51.935111582279205, 57.35230229794979, 56.644483879208565, 54.6466688811779, 51.15015350282192, 49.090618416666985, 41.48035638034344, 38.47759410738945, 38.80028419196606, 39.663392677903175, 39.64544244110584, 46.241367906332016, 52.56429702043533, 54.30886700749397, 53.183701783418655, 54.99064542353153, 53.765089586377144, 53.832490369677544, 47.211581245064735, 38.84303569793701, 39.65271145105362, 39.33642402291298, 37.99967095255852, 40.924073830246925, 39.886132925748825, 39.25196215510368, 52.39614464342594, 54.05255176126957, 54.57853853702545, 53.472144305706024, 50.76637029647827, 51.28299817442894, 45.668879225850105, 48.19554224610329, 45.751441195607185, 47.262190729379654, 46.135000213980675, 45.76501026749611, 49.68176409602165, 44.091302677989006, 55.373444482684135, 53.46207484602928, 50.504530146718025, 48.82301017642021, 46.25949673354626, 42.73420549929142, 43.35244372487068, 38.635331243276596, 40.31386077404022, 41.44660659134388, 38.44998098909855, 41.423184648156166, 36.76372267305851, 40.415075942873955, 39.79293532669544, 43.55393171310425, 50.77905781567097, 53.92297111451626, 50.646878108382225, 54.15617220103741, 54.048569574952126, 52.79946260154247, 42.20823772251606, 40.47648824751377, 39.42118987441063, 40.70449501276016, 37.085383012890816, 39.81197610497475, 47.26380564272404, 52.01633222401142, 53.002310916781425, 51.77233211696148, 50.29056742787361, 48.29389996826649, 48.966570273041725, 53.50930631160736, 54.99644011259079, 55.32820791006088, 54.70618508756161, 53.92467342317104, 53.68521027266979, 53.856288492679596, 52.20018915832043, 53.380519822239876, 50.16505256295204, 53.01228158175945, 56.05116851627827, 57.76272967457771, 45.626568496227264, 25.37589903920889, 6.8665065709501505, 5.651589212939143, 8.940771091729403, 26.11726015806198, 21.897920966148376, 10.66936008632183, 8.042613286525011, 1.431796420365572, 0.2496879268437624, 5.274777682498097, 31.583728529512882, 46.81754618883133, 43.35343927145004, 48.32721658051014, 59.28518258035183, 36.30724176764488, 4.610150121152401, 0.17313932738034055, 0.3385176305891946, 0.11676034991978668, 0.30392746324650943, 0.16496709402417764, 0.19754127657506615, 0.155820376239717, 0.15758342226035893, 0.17478055728133768, 0.07074190987623297, 0.3761147428303957, 0.07300629891688004, 0.1340430323034525, 0.11549195274710655, 0.16764632135163993, 0.14366920717293397, 0.1016603090101853, 0.21463185403263196, 0.15239999571349472], [0.08328024996444583, 0.014080381952226162, 0.05987819633446634, 0.03000394703121856, 0.02295729937031865, 0.031188789507723413, 0.09406620127265342, 0.08953977579949424, 0.027496361763041932, 0.04703342718130443, 0.02090814243274508, 0.0465796409844188, 0.010493143436178798, 0.008533892123523401, 0.014158040285110474, 0.022005353966960683, 0.021288715761329513, 0.058523353800410405, 0.04897309321677312, 0.0542302706890041, 0.0440583501040237, 0.04565768947941251, 0.08192238688934594, 0.06345757457893342, 4.079429749399424, 30.241978727281094, 43.9330829679966, 39.49311621487141, 24.950213581323624, 28.94057895988226, 37.180678099393845, 32.1256535500288, 6.335662230849266, 0.3766195516800508, 10.675260219722986, 33.7888091057539, 31.58531304448843, 6.278104819357395, 0.2543188096024096, 7.262264359742403, 29.838609471917152, 43.85308966040611, 51.57796874642372, 53.12069736421108, 56.98395386338234, 50.92073701322079, 49.89585980772972, 52.15846739709377, 50.27039811015129, 53.41502197086811, 52.402760088443756, 49.22546558082104, 48.5018590092659, 47.64902517199516, 43.34156110882759, 38.39769199490547, 36.29257075488567, 34.785370230674744, 37.54392720758915, 37.178637608885765, 35.96946269273758, 41.260716766119, 45.806511640548706, 51.35954886674881, 49.54636596143246, 48.42781998217106, 48.52943792939186, 47.99827203154564, 43.26950177550316, 36.17249719798565, 35.3205943107605, 35.95731474459171, 36.85155116021633, 34.948617070913315, 33.73513698577881, 33.87907326221466, 41.62728309631348, 48.24876978993416, 49.70066048204899, 47.91682340204716, 49.358002468943596, 50.8803603798151, 51.05215296149254, 50.585256814956665, 48.46854619681835, 47.826327458024025, 49.52759116888046, 42.59282648563385, 48.21481481194496, 37.81103767454624, 50.89415743947029, 49.54386569559574, 46.617346331477165, 43.1524832546711, 41.26823656260967, 38.71396042406559, 37.82312482595444, 36.51821404695511, 37.19031058251858, 34.24734570086002, 34.753368347883224, 36.69894374907017, 36.91718503832817, 35.95512606203556, 37.6105984300375, 39.33316759765148, 47.57529012858868, 48.40335689485073, 51.138374134898186, 47.8083810210228, 49.04421150684357, 48.368185982108116, 44.47993062436581, 39.19498801231384, 36.07764668762684, 33.46202664077282, 36.11128248274326, 34.99005004763603, 37.23058842122555, 43.26257474720478, 48.78611035645008, 50.80577798187733, 49.39569264650345, 48.693528324365616, 45.47057546675205, 46.274099349975586, 45.666006579995155, 46.326399743556976, 49.38807025551796, 51.181805804371834, 52.4337512254715, 50.95311127603054, 49.56078238785267, 49.95513662695885, 49.069240763783455, 51.30486600100994, 55.56248813867569, 50.99734470248222, 44.202024936676025, 21.85801550745964, 3.6023361375555396, 1.368718973826617, 6.151529336348176, 6.544354157522321, 21.22282449156046, 5.20591682754457, 1.664040433242917, 0.5840626813005656, 0.09743123242515139, 3.9092045836150646, 20.09910698980093, 26.939727924764156, 32.8500846773386, 37.22163990139961, 47.401419058442116, 16.95272572338581, 0.646763116819784, 0.027530346560524777, 0.010604559283819981, 0.09818689461098984, 0.011424848617025418, 0.04303502864786424, 0.06490644722362049, 0.11158228910062462, 0.012488477041188162, 0.10705232358304784, 0.029514877278415952, 0.04102365259313956, 0.051847130598616786, 0.060479822059278376, 0.05296231509419158, 0.008290062287414912, 0.01848992473242106, 0.09798085215152241, 0.03165104360959958, 0.05562742306210566, 0.03814256480836775, 0.07838865072699264, 0.05951854043814819, 0.050951102311955765, 0.03751320873561781, 0.021434505106299184, 0.07221569641842507, 0.05263164377538487, 0.014096649829298258, 0.02563678459409857, 0.007451533747371286, 0.02577163282694528, 0.024153010599547997, 0.039855931463534944, 0.05193490440433379, 0.04749237501528114, 0.06096463002904784, 0.0316732598003, 0.005749291885877028, 0.03876825467159506, 0.049005469409166835, 0.012883548224635888, 0.05806609806313645, 0.08378888829611242, 6.468588598072529, 37.78214782476425, 49.54830385744572, 42.541149258613586, 29.569040536880493, 34.00345578789711, 40.93736931681633, 33.01284894347191, 7.457427112385631, 0.1908342505339533, 14.680758286267519, 37.640917003154755, 31.406226754188538, 6.298457952216268, 1.2786538316868246, 7.146715885028243, 34.505682438611984, 45.39673402905464, 53.36326874792576, 53.00859197974205, 59.2864441126585, 52.75827281177044, 51.88328616321087, 52.64249302446842, 51.53132624924183, 53.738069236278534, 54.64736424386501, 52.66363508999348, 49.74926367402077, 49.66289430856705, 47.03940488398075, 40.9399151802063, 38.01650024950504, 35.43287828564644, 39.34575252234936, 37.879616394639015, 38.15514720976353, 43.70519779622555, 47.78579123318195, 52.53992512822151, 50.85811637341976, 49.828497022390366, 51.16300821304321, 52.08715662360191, 46.18344381451607, 38.32819752395153, 36.69447138905525, 38.40930417180061, 37.14956916868687, 36.547856256365776, 36.639739125967026, 35.96503213047981, 44.19621504843235, 49.384851828217506, 50.17570719122887, 49.774532318115234, 51.33447401225567, 52.1316484361887, 52.745114117860794, 49.57411967217922, 47.76119515299797, 48.35548706352711, 49.40384320914745, 45.1823191344738, 49.99391354620457, 40.23620814085007, 52.59354405105114, 51.612717881798744, 48.413452953100204, 44.42360244691372, 45.395734682679176, 40.32560974359512, 40.67426763474941, 37.91670240461826, 38.45810875296593, 35.778807923197746, 36.81547969579697, 38.254523277282715, 37.11296573281288, 38.13149347901344, 39.86423470079899, 41.960118636488914, 50.4557179659605, 49.84735541045666, 52.5949689745903, 50.61081424355507, 50.30742712318897, 48.829462230205536, 45.50350069999695, 40.78660100698471, 36.86243757605553, 35.39799615740776, 37.02639877796173, 36.95839382708073, 38.54206904768944, 45.96914291381836, 49.57194238901138, 52.296563386917114, 51.51703901588917, 50.64186617732048, 48.06659236550331, 48.26188288629055, 46.788112968206406, 48.248089626431465, 50.8910758048296, 52.22434066236019, 53.656761199235916, 53.950572833418846, 50.86204916238785, 52.507281079888344, 51.46150879561901, 53.57194595038891, 54.8071076720953, 53.20683494210243, 45.5414492636919, 23.1104739010334, 4.239255823194981, 2.5194873427972198, 5.43324532918632, 10.162466336041689, 26.39407340437174, 5.573682943359017, 3.2086254889145494, 0.6898586230818182, 0.08188310501282103, 4.710303721949458, 25.107175558805466, 31.870485842227936, 37.50279821455479, 45.19883304834366, 52.29032412171364, 21.526202112436295, 0.9082461451180279, 0.03856612333038356, 0.102965583500918, 0.05645010118314531, 0.06924769200850278, 0.06568224387592636, 0.024642980206408538, 0.0424761394970119, 0.02200363960582763, 0.09012593145598657, 0.004770788727910258, 0.08754638198297471, 0.041409049881622195, 0.026523406158958096, 0.011015812069672393, 0.015717999449407216, 0.05813210838823579, 0.035846397004206665, 0.08599123379099183, 0.05930470542807598, 0.21231060905847698, 0.1527120836544782, 0.1865644523059018, 0.12047531112330034, 0.150928866059985, 0.1389391437987797, 0.20854538219282404, 0.10894267761614174, 0.1203654138953425, 0.1378783179097809, 0.1196065307885874, 0.16449612710857764, 0.12620719964616, 0.18922763440059498, 0.13372612040257081, 0.11903463178896345, 0.17942548147402704, 0.1192284510761965, 0.16462827392388135, 0.126614163746126, 0.15606359287630767, 0.1427555491682142, 0.1653222562163137, 0.20286602288251743, 6.765008317306638, 42.074298709630966, 56.64586320519447, 52.238612696528435, 33.66029240190983, 41.33506737649441, 48.42812016606331, 38.78509260714054, 9.59905631840229, 0.6507618085015565, 15.446151215583086, 43.22295047342777, 39.30704019963741, 10.581079423427582, 3.0125873582437634, 10.139573514461517, 37.36059844493866, 47.215730622410774, 54.84094485640526, 54.984482154250145, 61.958631724119186, 52.614078149199486, 52.296297401189804, 53.669460117816925, 52.746314853429794, 55.140995755791664, 57.660917937755585, 54.829743057489395, 51.5752936899662, 52.8113217651844, 48.5674586892128, 42.14058235287666, 40.85460975766182, 37.92295306921005, 40.70695348083973, 39.840580970048904, 41.682771518826485, 44.83074679970741, 49.172872602939606, 55.10222263634205, 52.109263837337494, 50.460574105381966, 52.099232375621796, 53.676098361611366, 47.54856616258621, 40.324067026376724, 38.55239689350128, 39.4600085914135, 40.35367123782635, 38.60426791012287, 38.10316599905491, 37.89859637618065, 45.37085361778736, 51.51386998593807, 53.58604699373245, 50.476567447185516, 52.825669795274734, 55.147197023034096, 55.569506362080574, 51.56086206436157, 49.61993761360645, 49.16972637176514, 50.950637608766556, 45.32648339867592, 47.79220148921013, 44.78114806115627, 54.453369453549385, 53.43531668186188, 50.6968530267477, 47.192107290029526, 47.65387371182442, 42.25537799298763, 41.64444677531719, 39.3917528539896, 40.86910218000412, 38.43251712620258, 38.39688263833523, 41.27175137400627, 39.55080471932888, 39.612764194607735, 42.51178443431854, 43.47541272640228, 51.93574994802475, 53.74782711267471, 53.971384316682816, 53.04040767252445, 53.14922243356705, 51.29601627588272, 48.709871247410774, 43.25734622776508, 39.31016743183136, 36.95217736065388, 39.37444478273392, 38.5615886002779, 39.688782915472984, 48.011020347476006, 52.052008509635925, 56.28764882683754, 52.97964133322239, 53.13890218734741, 47.70437300205231, 47.74988315999508, 48.47431428730488, 48.13865929841995, 50.83930738270283, 53.60646329820156, 56.517829075455666, 55.59371866285801, 53.94705042243004, 54.13205109536648, 54.254845306277275, 56.33572764694691, 58.680851608514786, 56.16543598473072, 49.52017396688461, 26.651847772300243, 5.924876248463988, 3.189242254011333, 13.7763593159616, 12.2654121927917, 29.296488761901855, 11.851289514452219, 4.876644546166062, 1.4520429214462638, 0.3812919353367761, 6.721380483359098, 28.645055517554283, 41.035198867321014, 46.04306034743786, 49.423377960920334, 59.57942359149456, 25.482048243284225, 1.7049763491377234, 0.16667847172357142, 0.1400921741151251, 0.22462898399680853, 0.1742000345257111, 0.1344086290919222, 0.1487491189618595, 0.2252240528468974, 0.10174794180784374, 0.3038191393716261, 0.08451898349449039, 0.26987279998138547, 0.22368715406628326, 0.14049453689949587, 0.057214832413592376, 0.054037093359511346, 0.17849721800303087, 0.22443228517659009, 0.09543702966766432, 0.1580782566452399], [0.03070462535106344, 0.008872511843946995, 0.04444319449248724, 0.06296832856605761, 0.009881046007649275, 0.06480591589934193, 0.06955714532523416, 0.004271832640370121, 0.018464062741259113, 0.05031404645706061, 0.04484829209104646, 0.03679258705233224, 0.0561064385692589, 0.03379433270310983, 0.0488778422732139, 0.07606121624121442, 0.0361406548472587, 0.04518991379882209, 0.037607843696605414, 0.0678687370964326, 0.0356213073246181, 0.027546801829885226, 0.051364986939006485, 0.0706859519414138, 0.6072463653981686, 20.189306549727917, 48.83452355861664, 40.287786573171616, 32.92035810649395, 32.71241046488285, 46.29628635942936, 28.493762835860252, 7.004755502566695, 0.030199903703760356, 6.698272498324513, 30.775211714208126, 23.34478072822094, 10.695658475160599, 0.6611354893539101, 4.262635018676519, 22.946341708302498, 41.12999238073826, 51.79813273251057, 52.84060299396515, 49.51335333287716, 50.549257546663284, 47.14103803038597, 53.590534552931786, 52.31770545244217, 50.843908935785294, 49.768623635172844, 47.549744099378586, 43.78432855010033, 39.71960686147213, 37.36055284738541, 36.69244609773159, 36.18940249085426, 35.61340659856796, 35.41127264499664, 36.398098692297935, 37.445668280124664, 40.21071910858154, 46.47274509072304, 51.65671952068806, 51.662951186299324, 49.25155118107796, 49.74102571606636, 49.74177047610283, 44.70784619450569, 36.96507006883621, 36.65081553161144, 37.07838758826256, 36.19983673095703, 35.63322253525257, 33.94823335111141, 35.12484021484852, 37.52736009657383, 42.45714336633682, 45.815566554665565, 47.084960639476776, 46.69456958770752, 47.45327867567539, 49.08718340098858, 49.05553109943867, 49.571053236722946, 49.62642766535282, 51.91860906779766, 50.11333353817463, 47.66596466302872, 36.692579090595245, 52.37257830798626, 48.122437968850136, 45.37529557943344, 43.206926733255386, 37.989730685949326, 37.04439081251621, 35.60449227690697, 35.180499628186226, 35.77698402106762, 34.45163033902645, 34.57291983067989, 35.11960029602051, 35.16952961683273, 36.14538945257664, 34.70353402197361, 36.4229379594326, 44.830222427845, 49.324412271380424, 49.6184328943491, 51.50432489812374, 50.39369769394398, 48.1074857711792, 47.58350528776646, 46.018403470516205, 45.06752349436283, 38.23162570595741, 34.474014937877655, 34.115743562579155, 34.70770239830017, 37.031281515955925, 42.086602449417114, 46.1206141859293, 48.210574239492416, 49.86250139772892, 48.57041873037815, 49.47151377797127, 49.15101997554302, 48.81695330142975, 48.95459711551666, 48.00847828388214, 52.00172200798988, 51.67636826634407, 50.86452282965183, 52.55067855119705, 49.14760775864124, 52.45552025735378, 56.169076189398766, 48.548957481980324, 32.51224100589752, 19.749972224235535, 3.247626358643174, 2.297537215054035, 5.846598073840141, 15.213411804288626, 28.419022746384144, 3.004295965656638, 1.2433783058077097, 0.26334780792240053, 0.2374235208844766, 5.4125540144741535, 31.088366210460663, 37.45929054915905, 32.42961443960667, 39.76600617170334, 40.94090312719345, 10.90825516730547, 0.41332276188768446, 0.09795012723770924, 0.016361721645807847, 0.03364854521350935, 0.05747333729232196, 0.06557983491802588, 0.050946757037309, 0.030648903048131615, 0.0107549415952235, 0.028825793160649482, 0.039045194498612545, 0.03889730302034877, 0.011186007868673187, 0.058585196966305375, 0.03816490345343482, 0.026550362817943096, 0.08951792697189376, 0.10729374422226101, 0.05462847002490889, 0.012655066930165049, 0.020592976434272714, 0.013339021879801294, 0.011774779595725704, 0.023547696400783025, 0.011233987715968397, 0.05169527234102134, 0.05868840744369663, 0.03686001859023236, 0.03848970438411925, 0.04423733385920059, 0.03807479930401314, 0.065786300401669, 0.07501417945604771, 0.0425189205998322, 0.04525793163338676, 0.12161793652921915, 0.04110190464416519, 0.06748872037860565, 0.08083498469204642, 0.05006878520362079, 0.04669207635743078, 0.02346014338399982, 0.07084368058713153, 0.11958713846979663, 1.2864628876559436, 25.314230248332024, 53.95898178219795, 46.67143262922764, 33.407381772994995, 34.32820916175842, 48.170680180191994, 33.881056755781174, 9.071567673236132, 0.09156230633379892, 7.869758661836386, 33.154680132865906, 25.448104664683342, 10.886187851428986, 1.051815978717059, 6.1896241921931505, 25.9448729082942, 45.914429649710655, 51.13848812878132, 53.05255562067032, 50.83836883306503, 53.1168557703495, 48.21604214608669, 53.7603360414505, 53.241352289915085, 52.13538743555546, 51.250905096530914, 49.57350790500641, 45.84481738507748, 42.646775990724564, 39.92432467639446, 37.62736693024635, 37.65790969133377, 37.50357337296009, 38.50323133170605, 38.05543676018715, 37.99291491508484, 43.48938077688217, 47.55382888019085, 53.70498061180115, 53.4018062800169, 50.52127204835415, 51.339744329452515, 49.748971089720726, 46.61118686199188, 39.00736168026924, 36.729756295681, 37.61317849159241, 38.1340279430151, 37.35195770859718, 37.04581193625927, 38.10236804187298, 38.394625559449196, 45.054896771907806, 47.96187378466129, 49.289845526218414, 49.10465866327286, 49.31874677538872, 50.69235026836395, 51.28458268940449, 51.51777237653732, 52.605760395526886, 52.20643222332001, 50.52546702325344, 48.56442645192146, 39.34188432991505, 53.32399785518646, 49.35846604406834, 47.08336092531681, 43.56860272586346, 40.35541534423828, 38.066657558083534, 38.58023039996624, 37.3199026286602, 36.34845815598965, 37.14798465371132, 37.322896867990494, 36.842842027544975, 36.47280268371105, 38.430400639772415, 38.53993736207485, 39.097705632448196, 45.9203877300024, 49.9239706993103, 52.14546449482441, 52.24954850971699, 52.30619207024574, 51.0606075078249, 48.985899835824966, 48.171280547976494, 45.92858389019966, 39.909509271383286, 36.072961539030075, 36.04021869599819, 38.258794248104095, 38.52997049689293, 45.602660179138184, 48.56500402092934, 49.12513576447964, 53.45001049339771, 50.52382171154022, 50.752147659659386, 50.84515526890755, 48.49545635282993, 48.7279886752367, 50.629744827747345, 51.698616072535515, 54.9329075217247, 53.012995943427086, 53.709601163864136, 51.60403534770012, 55.57786211371422, 57.07938574254513, 50.15949726104736, 36.288276985287666, 23.862160965800285, 3.5006281826645136, 3.271035240031779, 7.395340343937278, 14.453035555779934, 28.254972249269485, 6.795835588127375, 1.8892507860437036, 0.28664774203207344, 0.351398405036889, 5.827875528484583, 34.986664429306984, 40.195474326610565, 36.561953499913216, 45.41681595146656, 47.709593921899796, 13.951472919434309, 0.5837633286137134, 0.12107994625694118, 0.060646218989859335, 0.04267244497896172, 0.025023434791364707, 0.02547189793403959, 0.051805896873702295, 0.04645887871447485, 0.002914583460551512, 0.06870475903269835, 0.008326509159815032, 0.03755778954655398, 0.01927091827383265, 0.04620073006663006, 0.05029470979934558, 0.028459626773837954, 0.043916180584346876, 0.023956072436703835, 0.06802499628975056, 0.10739422359620221, 0.08713615985470824, 0.2483061220846139, 0.1568952138768509, 0.14580509334336966, 0.07562213941127993, 0.25364793778862804, 0.11530290546943434, 0.16563213255722076, 0.171684272645507, 0.1222529997176025, 0.17391841916833073, 0.23012901074253023, 0.16433793090982363, 0.09989622398279607, 0.06641861764364876, 0.24846568383509293, 0.10076716396724805, 0.13061776844551787, 0.2741945633897558, 0.19627817091532052, 0.11594090014114045, 0.1540000512613915, 0.1343000677297823, 0.24622208235086873, 1.9438907853327692, 28.984225317835808, 62.229408994317055, 53.004112020134926, 42.59087339043617, 42.81655468046665, 59.199607372283936, 36.648759841918945, 11.392005309462547, 0.28074024652596563, 8.551417384296656, 37.57065497338772, 31.58937692642212, 17.706409581005573, 2.9200639855116606, 6.185445841401815, 28.185502476990223, 50.78904367983341, 53.735489174723625, 55.212906897068024, 52.88257174193859, 53.20298574864864, 47.87367291748524, 57.26894997060299, 55.87825879454613, 55.366198271512985, 54.45647768676281, 51.17048241198063, 47.92867496609688, 43.651350885629654, 40.82249008119106, 40.317713767290115, 39.80632200837135, 39.38469283282757, 38.46052922308445, 39.87783797085285, 39.751544147729874, 44.177816435694695, 50.11214420199394, 56.51157461106777, 55.90096637606621, 49.70609799027443, 51.38537988066673, 52.40029402077198, 48.25558662414551, 41.48884892463684, 40.5881604552269, 40.406450405716896, 39.56606090068817, 40.03025159239769, 37.60101154446602, 39.28536616265774, 39.7856131196022, 45.227016136050224, 49.45074029266834, 51.88587762415409, 51.84357829391956, 51.10729940235615, 53.49374994635582, 53.12333822250366, 54.795544892549515, 55.468629375100136, 54.618820175528526, 53.15053716301918, 49.444550424814224, 43.0590994656086, 53.99248458445072, 52.21598111093044, 49.00850862264633, 47.15811051428318, 41.980846524238586, 40.87381772696972, 39.56661947071552, 39.124801978468895, 38.62312249839306, 38.64790476858616, 39.22030605375767, 37.83709667623043, 39.428208097815514, 40.49324534833431, 38.05742785334587, 40.55332772433758, 48.03771771490574, 52.21478037536144, 54.54469755291939, 53.92251893877983, 54.920227602124214, 53.00765722990036, 51.027222499251366, 50.50986506044865, 47.5503558665514, 42.651810720562935, 37.73704804480076, 36.99036531150341, 40.8650553971529, 39.55406874418259, 46.783671006560326, 50.6347681581974, 51.27037525177002, 55.48722177743912, 52.43978910148144, 52.28491701185703, 50.918780118227005, 48.79325397312641, 49.312184527516365, 50.752447843551636, 53.649632781744, 55.787736251950264, 54.106056690216064, 57.70794801414013, 52.85675212740898, 57.102040126919746, 60.16129396855831, 52.472079768776894, 36.783295422792435, 25.438128300011158, 5.213806629180908, 6.299146190285683, 14.98164039105177, 26.00841499865055, 36.754698157310486, 10.333634801208973, 5.275788428261876, 0.679933080682531, 0.4827067715814337, 8.482838664203882, 42.45919905602932, 49.3491717427969, 45.63736751675606, 53.81606765091419, 53.832114189863205, 16.502396687865257, 0.8018373674713075, 0.2658902871189639, 0.19308971153805032, 0.19194521591998637, 0.10543060474446975, 0.12861533527029678, 0.1750918585457839, 0.1069545530481264, 0.1696951239136979, 0.11320585588691756, 0.08561132097383961, 0.13167212280677631, 0.10787494975375012, 0.16535477712750435, 0.16520167206181213, 0.12013424231554382, 0.25700802623759955, 0.2922381029929966, 0.17236293700989336, 0.25541819748468697], [0.03154413352604024, 0.019074204610660672, 0.03201198342139833, 0.03591588800190948, 0.04758595983730629, 0.15547521819826216, 0.05485516274347901, 0.02295160709763877, 0.015383202717202948, 0.020648472382163163, 0.017447017999074887, 0.024086234006972518, 0.0233663748804247, 0.022470062722277362, 0.06144747130747419, 0.041902437078533694, 0.08978474390460178, 0.19617916841525584, 0.027431607522885315, 0.047099700968828984, 0.00396409507629869, 0.03434527345234528, 0.029784874313918408, 0.038089827794465236, 0.21518493216717616, 12.85165898501873, 43.571722358465195, 44.817078933119774, 35.81100359559059, 41.95824533700943, 63.55746053159237, 32.00177259743214, 9.112509526312351, 0.216608579212334, 1.2050338508561254, 22.344765588641167, 21.24360367655754, 10.108977556228638, 2.094014436006546, 6.72712909989059, 20.611007921397686, 37.57017619907856, 45.86147949099541, 45.61010777950287, 50.07082141935825, 54.55373726785183, 54.040415212512016, 51.47639259696007, 48.676968812942505, 48.22339095175266, 45.50891540944576, 41.43800005316734, 38.22170823812485, 38.14134255051613, 36.354640424251556, 36.72655686736107, 36.9247580319643, 35.122693330049515, 36.61054529249668, 36.29801586270332, 36.65642403066158, 38.34734849631786, 45.985938012599945, 50.37480890750885, 51.31712794303894, 48.81164878606796, 51.271902769804, 48.51590305566788, 46.95853762328625, 44.07983109354973, 38.97916719317436, 35.891878455877304, 37.134776562452316, 36.78245946764946, 35.809077098965645, 36.15489274263382, 36.38578735291958, 37.731093764305115, 40.21215163171291, 42.73549742996693, 45.608766451478004, 45.010914131999016, 47.732138112187386, 48.09545561671257, 47.02991679310799, 48.78361389040947, 48.100741133093834, 48.904417008161545, 51.729641407728195, 37.838764786720276, 47.91152648627758, 52.53215454518795, 46.54387727379799, 45.69124862551689, 38.41444529592991, 37.02347293496132, 35.72775386273861, 35.981542244553566, 35.88045246899128, 35.359291434288025, 34.1127835214138, 36.82773783802986, 34.8518742620945, 35.60582980513573, 35.46627849340439, 35.539318174123764, 39.325993582606316, 45.581643506884575, 47.76515454053879, 50.078918784856796, 49.350387677550316, 50.618030056357384, 50.17474204301834, 49.4326950609684, 47.62921683490276, 44.792235866189, 38.30186873674393, 32.94670209288597, 35.46319305896759, 34.862977266311646, 35.65995030105114, 39.36729736626148, 42.83673159778118, 45.45522429049015, 45.93858875334263, 47.79750220477581, 48.753116726875305, 49.48597200214863, 47.056078389286995, 48.758330047130585, 48.60830269753933, 52.67891027033329, 49.69002105295658, 54.62117224931717, 52.36863411962986, 54.34248000383377, 52.38544061779976, 48.434633016586304, 24.969776831567287, 9.52617147937417, 1.4587285439483821, 1.4859623950906098, 2.082769414409995, 26.537815891206264, 6.958255972713232, 4.247302366420627, 2.6753138937056065, 0.2880592772271484, 0.8212742151226848, 6.2634865287691355, 35.04068613052368, 34.29708503186703, 31.368109099566936, 44.69330057501793, 35.32240301370621, 7.115052659064531, 0.08397105586482212, 0.10040560446213931, 0.013814526100759394, 0.02597784041427076, 0.06810543025494553, 0.018096566054737195, 0.039946881661308, 0.005367298736018711, 0.07435888532199897, 0.041663869997137226, 0.0296544307275326, 0.058244963074685074, 0.07670208302442916, 0.03228349072742276, 0.07545056228991598, 0.04100365171325393, 0.017380491881340276, 0.07677027155295946, 0.012304949486861005, 0.0832803464436438, 0.02807184533594409, 0.03415422237594612, 0.014570447110600071, 0.06283946946496144, 0.031116825302888174, 0.036940151985618286, 0.07723592469119467, 0.054673974809702486, 0.022948525329411495, 0.021664287014573347, 0.06350696450681426, 0.03336879635753576, 0.01580884574650554, 0.034074508293997496, 0.07328507184865884, 0.03363727199030109, 0.05293986512697302, 0.08203146775485948, 0.04212814645143226, 0.0717606559919659, 0.012802245018974645, 0.023996578856895212, 0.026176858445978723, 0.026317636438761838, 0.6245338940061629, 18.283786699175835, 51.587696224451065, 49.70992058515549, 40.071372985839844, 43.68421912193298, 60.5416801571846, 34.02764528989792, 9.789178166538477, 0.3370798530522734, 1.6253948444500566, 25.69925218820572, 20.940816923975945, 11.322232503443956, 5.238903807476163, 7.9959688894450665, 24.28056411445141, 41.163776367902756, 50.30568681657314, 49.83059450984001, 51.04944750666618, 54.69739995896816, 55.75831823050976, 53.22774142026901, 51.96931354701519, 52.259792760014534, 48.91130603849888, 46.19781844317913, 40.621404871344566, 40.331784412264824, 37.92052119970322, 38.22771191596985, 38.272127732634544, 37.323816418647766, 38.20524752140045, 38.72485063970089, 39.596789851784706, 40.26145398616791, 49.43238727748394, 52.07559384405613, 53.17514844238758, 49.66596834361553, 51.35236345231533, 51.28504626452923, 50.229181721806526, 45.797859504818916, 38.57344776391983, 37.44097173213959, 37.67820060253143, 38.14591370522976, 38.50211039185524, 38.350179344415665, 39.8735897988081, 39.41167898476124, 43.648778423666954, 44.67566952109337, 46.958055049180984, 46.09066039323807, 49.85084742307663, 50.01584216952324, 50.745201632380486, 49.05292063951492, 50.88171310722828, 49.71723139286041, 53.52948322892189, 39.26426589488983, 50.63540272414684, 53.04452285170555, 49.18882794678211, 47.29479297995567, 40.75465612113476, 38.73738616704941, 38.01915630698204, 37.37741634249687, 37.88559727370739, 36.994039714336395, 36.8377161026001, 37.431134060025215, 35.68985469639301, 36.078646034002304, 37.443798780441284, 36.93100489675999, 41.8754705786705, 48.943296521902084, 51.29719041287899, 52.63568378984928, 51.5812061727047, 51.549827456474304, 51.286680176854134, 50.37148408591747, 48.2661272585392, 45.87383642792702, 38.44932742416859, 35.91209337115288, 36.03282809257507, 36.67147882282734, 37.42823861539364, 41.76300801336765, 45.67203305661678, 49.61579963564873, 48.91086146235466, 49.98061046004295, 49.82961796224117, 51.327653378248215, 49.223816469311714, 48.40070463716984, 49.75882016122341, 53.73520419001579, 52.06755347549915, 56.07725411653519, 53.78498911857605, 57.490975856781006, 53.63934673368931, 50.75270622968674, 26.615630015730858, 11.847081240266562, 2.7872518496587873, 3.7053267611190677, 3.4076255606487393, 28.563044518232346, 15.707232356071472, 6.754677621647716, 3.6470687622204423, 0.14984080335125327, 0.510235670953989, 8.37193401530385, 38.829694613814354, 40.1314477622509, 35.40081940591335, 49.45779271423817, 40.847367346286774, 9.777595438063145, 0.115637836715905, 0.1341402091202326, 0.045232576158014126, 0.027218774412176572, 0.025054081779671833, 0.06515972738270648, 0.0851433671778068, 0.025867603653750848, 0.014313506308099022, 0.01629165548365563, 0.02722469303989783, 0.053805925490451045, 0.11681090501951985, 0.06131079739134293, 0.02120171378919622, 0.03548047738149762, 0.06278479544562288, 0.08459474192932248, 0.0721684587188065, 0.038997949377517216, 0.1812683677417226, 0.13420015980955213, 0.11996454282780178, 0.23617536207893863, 0.103918671811698, 0.23871065728599206, 0.1570056306081824, 0.1459953503217548, 0.20864119345787913, 0.08000272544450127, 0.15827626164536923, 0.12154311320045963, 0.1992138399509713, 0.12711858667898923, 0.1447528021526523, 0.10858871028176509, 0.21674750925740227, 0.27392608404625207, 0.15155828150454909, 0.18270587810548022, 0.11497655345010571, 0.2587634726660326, 0.09991959421313368, 0.09084815246751532, 0.9146569354925305, 21.003640852868557, 56.669034361839294, 56.41998432576656, 47.34182305634022, 52.870560586452484, 70.6020887196064, 39.84701782464981, 13.520980719476938, 0.9701492765452713, 1.5616381843574345, 27.725350968539715, 28.037403523921967, 17.555622272193432, 5.257586929947138, 10.539352912455797, 32.47514359652996, 46.135137006640434, 51.56802088022232, 50.97716398537159, 52.466729655861855, 55.92501528561115, 58.094942048192024, 55.30254788696766, 52.56440721452236, 53.50002720952034, 51.24587416648865, 47.09408015012741, 41.80544413626194, 41.9771683216095, 39.07115265727043, 40.280650556087494, 40.02793751657009, 40.130216628313065, 40.65977141261101, 40.96858464181423, 39.96100790798664, 42.271929904818535, 51.140988394618034, 54.73604008555412, 54.659515991806984, 49.94304187595844, 54.414824321866035, 50.31615525484085, 51.886455193161964, 48.72139222919941, 42.20971964299679, 38.83043937385082, 40.07216714322567, 40.807518884539604, 40.23539878427982, 40.10401703417301, 40.378666296601295, 41.16944186389446, 45.439569130539894, 45.64715579152107, 49.65096294879913, 47.663741782307625, 51.19022615253925, 51.472900584340096, 52.382092997431755, 50.8212735503912, 52.881701588630676, 52.173947766423225, 55.013611391186714, 43.63267868757248, 51.576874405145645, 56.09133996069431, 51.212557554244995, 51.47135406732559, 44.161146730184555, 39.911781549453735, 40.10758124291897, 39.275106713175774, 39.96187426149845, 38.047742173075676, 38.096911534667015, 39.26780350506306, 37.419651076197624, 37.452941089868546, 40.15506349503994, 38.30405741930008, 43.25287766754627, 50.257778987288475, 53.48925858736038, 54.39281590282917, 52.76562921702862, 53.63601051270962, 53.84354777634144, 53.08317057788372, 49.22746807336807, 49.53044481575489, 41.69016972184181, 36.56645245850086, 39.46100793778896, 38.15121442079544, 39.371526539325714, 44.283994138240814, 46.59342281520367, 50.69773457944393, 50.315292701125145, 53.058099523186684, 52.40925773978233, 54.37794730067253, 51.88349515199661, 48.41502606868744, 50.70344187319279, 55.60892164707184, 54.67946112155914, 58.07894870638847, 55.83874471485615, 57.95715384185314, 54.80663649737835, 52.018315717577934, 28.97220466285944, 12.559263724833727, 3.8174896175041795, 4.871251685544848, 9.521075952798128, 35.99167250096798, 11.187657974660397, 10.98845936357975, 5.923434225842357, 0.8290228305850178, 1.185603712219745, 9.465998858213425, 45.06785787642002, 45.51715336740017, 43.092944249510765, 57.22081035375595, 46.38420604169369, 10.735336896032095, 0.25699350982904434, 0.13786188676021993, 0.15273345750756562, 0.11671924235997722, 0.14722372347023338, 0.1237492065411061, 0.13684921141248196, 0.07812311770976521, 0.20774527278263122, 0.13213189813541248, 0.14585805300157517, 0.16864315926795825, 0.1409433878143318, 0.10745646752184257, 0.22652583924354985, 0.09524948152829893, 0.13994473905768245, 0.22146857780171558, 0.1726027249242179, 0.16003829834517092], [0.08200206386391073, 0.032929697263170965, 0.06687735396553762, 0.07485355643439107, 0.027900210698135197, 0.08044960224651732, 0.033725517059792764, 0.030509590797009878, 0.05926872239797376, 0.014089013129705563, 0.05659804832248483, 0.026295470343029592, 0.09691256767837331, 0.024181661210604943, 0.11921697747311555, 0.025499570765532553, 0.036176381836412475, 0.05581329023698345, 0.037043158372398466, 0.08672210082295351, 0.05809448892250657, 0.025808291211433243, 0.04115803327294998, 0.03165410496876575, 0.18852441979106516, 6.799321426078677, 43.75774137675762, 50.912905633449554, 40.17781287431717, 63.242575228214264, 64.27182599902153, 36.980455443263054, 19.92583628743887, 2.3669910756871104, 0.12716678174911067, 12.053531762212515, 17.16940339654684, 1.3524594088084996, 1.919984605628997, 7.12238721549511, 18.803427815437317, 28.01768448203802, 40.0785356014967, 54.75527465343475, 56.77752994000912, 54.09055732190609, 51.45973049104214, 49.810060411691666, 47.875291630625725, 42.27629207074642, 40.46617940068245, 38.224295899271965, 37.37199403345585, 35.54854787886143, 37.37894006073475, 37.39781744778156, 40.15306480228901, 38.64189349114895, 39.31729964911938, 40.4055954515934, 39.75172273814678, 38.53749789297581, 45.520793572068214, 48.891425505280495, 52.90532872080803, 49.74922187626362, 50.557164922356606, 52.924825474619865, 53.317526802420616, 49.32496704161167, 46.64479225873947, 41.605517864227295, 39.162704944610596, 35.8783283829689, 36.05211965739727, 35.51634080708027, 34.16010998189449, 35.05843497812748, 35.852227583527565, 37.68458805978298, 40.80615475773811, 42.53812462091446, 44.22616504132748, 44.661526679992676, 42.66204357147217, 44.15151044726372, 45.918039456009865, 48.34959737956524, 51.75644136965275, 40.424020662903786, 47.24198721349239, 50.851884707808495, 48.54608863592148, 46.24414935708046, 44.272769540548325, 43.858648762106895, 40.69829374551773, 37.93288193643093, 33.41886855661869, 35.09391367435455, 33.74696955084801, 34.17700007557869, 33.14207620918751, 35.329493433237076, 34.60125111043453, 35.669430792331696, 35.55673263967037, 37.45876617729664, 41.619907692074776, 47.25024797022343, 48.63677456974983, 48.36625948548317, 49.780114218592644, 49.82208676636219, 52.764842659235, 49.329693987965584, 40.89868739247322, 35.13843968510628, 35.097386687994, 35.404714196920395, 35.935792699456215, 35.237386375665665, 37.26886756718159, 40.53608424961567, 42.37180754542351, 45.68678006529808, 47.82918870449066, 49.51860085129738, 50.23563377559185, 51.41187585890293, 48.64771418273449, 50.812146440148354, 51.29617966711521, 54.42601092159748, 51.2318529188633, 52.601196840405464, 47.96384587883949, 38.31121623516083, 15.28205132111907, 3.099754680879414, 0.8955317304935306, 2.598779588006437, 9.004385378211737, 19.329558983445168, 5.050478568300605, 8.676964547485113, 1.801997849252075, 0.10528286540647969, 0.6877424928825349, 9.883839637041092, 34.54971827566624, 38.42813976109028, 30.254841037094593, 42.550614550709724, 30.490489192306995, 3.9249008288607, 0.062202743865782395, 0.04559626933769323, 0.06406223939848132, 0.041046837286558, 0.017506688527646475, 0.03824774197710212, 0.01103295382563374, 0.039260009143617935, 0.03069173795665847, 0.07334844383876771, 0.03545269508322235, 0.021045788562332746, 0.02340719300264027, 0.032410294079454616, 0.022410407036659308, 0.03308224942884408, 0.04385399603052065, 0.021243368682917207, 0.072815752500901, 0.026918158218904864, 0.03432091616559774, 0.061976659708307125, 0.02671641093911603, 0.10639604239258915, 0.0010239721109428501, 0.028703099451377057, 0.07199843268608674, 0.042901345586869866, 0.04947913403157145, 0.08695163967786357, 0.056197466692538, 0.04688931323471479, 0.04965176871337462, 0.03603548881073948, 0.09089969462365843, 0.017648186403675936, 0.007675911429032567, 0.06580315457540564, 0.03946045209886506, 0.08579331042710692, 0.03663493262138218, 0.03378923414857127, 0.021041207655798644, 0.004360553612059448, 0.23712306981906295, 9.84906580299139, 51.342780366539955, 55.51938325166702, 42.61031694710255, 60.682223215699196, 73.02310600876808, 41.52098760008812, 19.668071419000626, 1.7535791848786175, 0.2974930132040754, 13.90844402834773, 20.41711762547493, 2.8877106215804815, 2.9029563535004854, 9.305807054042816, 22.567872516810894, 33.671976774930954, 44.99051682651043, 55.171318128705025, 56.71400114893913, 57.3379048705101, 54.60675582289696, 51.5730632096529, 51.999476328492165, 45.25698892772198, 42.69481681287289, 40.090368166565895, 39.01820249855518, 38.47591459751129, 38.85675296187401, 38.21967154741287, 40.70365145802498, 39.85475420951843, 41.043106243014336, 42.17912368476391, 40.87653078138828, 41.67535811662674, 47.04771123826504, 49.88390564918518, 54.42364364862442, 50.118364468216896, 51.94336473941803, 53.97640384733677, 53.53058136999607, 51.276416927576065, 46.87836952507496, 43.25852416455746, 40.35442739725113, 38.54301139712334, 36.762962713837624, 36.58107407391071, 36.53174892067909, 37.34904706478119, 39.202492609620094, 38.46505858004093, 43.46412353217602, 44.552217945456505, 46.1437663435936, 46.45335093140602, 45.79019531607628, 48.338110595941544, 48.517951145768166, 48.994001001119614, 53.779103234410286, 42.7276736497879, 48.847545459866524, 53.597609773278236, 50.82277446985245, 48.74079778790474, 45.8569311350584, 43.61603558063507, 42.12491199374199, 38.886961340904236, 35.76434589922428, 35.60277096927166, 36.087951734662056, 35.81593193113804, 35.01194067299366, 37.46742971241474, 36.56594328582287, 38.6768364161253, 37.62142404913902, 40.50573147833347, 45.99038377404213, 49.538827165961266, 50.86359567940235, 50.90032450854778, 51.15235738456249, 52.67639480531216, 53.586605563759804, 51.003587767481804, 43.01984757184982, 35.64358077943325, 36.73604115843773, 36.89453825354576, 37.525889575481415, 37.258402928709984, 37.94689178466797, 43.55611279606819, 43.71039591729641, 47.89298728108406, 51.07149392366409, 51.07386499643326, 51.341142654418945, 51.33516177535057, 49.66012805700302, 50.9846305847168, 52.640258744359016, 54.355072528123856, 54.139510095119476, 54.05987776815891, 50.182079449296, 39.86409790813923, 18.77656325697899, 5.039287218824029, 1.6202266467735171, 5.4298364371061325, 5.774629935622215, 28.10018565505743, 9.239401817321777, 8.602988217025995, 2.251397240906954, 0.023885299378889613, 0.7267564244102687, 11.227890215814114, 37.639321088790894, 41.20685465633869, 35.824280083179474, 48.248731791973114, 36.021937876939774, 5.472713336348534, 0.06950838622287847, 0.03239434903662186, 0.02296157970704371, 0.040848079006536864, 0.03022043892997317, 0.047119557129917666, 0.0316120660136221, 0.016651205623929854, 0.020107676791667473, 0.028671780819422565, 0.029987335910846014, 0.12674129364313558, 0.04836310719838366, 0.05546444372157566, 0.06118246521509718, 0.04173735003860202, 0.05537980548979249, 0.002458766794006806, 0.040664171101525426, 0.019241098780184984, 0.2424368026549928, 0.13304009393323213, 0.17775014246581122, 0.17629765556193888, 0.07417494402034208, 0.16223130020080134, 0.13216027786256745, 0.1662020426010713, 0.14790658839046955, 0.15622109145624563, 0.1382322481367737, 0.09803189706872217, 0.18060126603813842, 0.11641737379250117, 0.19885199842974544, 0.11728762357961386, 0.12326404234045185, 0.1907101782853715, 0.11892857888597064, 0.21774675173219293, 0.1470992059330456, 0.12370377968181856, 0.16485762724187225, 0.15463532967260107, 0.42206279758829623, 13.540999945253134, 58.28940041363239, 62.83992983400822, 49.68997545540333, 68.66021052002907, 71.16227746009827, 46.87946006655693, 26.976815834641457, 3.4494261676445603, 0.3546926798298955, 15.300482232123613, 21.44254770129919, 2.64493381138891, 4.450766248628497, 10.947193577885628, 24.533132761716843, 34.16529290378094, 46.92810505628586, 55.19015371799469, 57.37053371965885, 56.855991929769516, 56.80769272148609, 54.35884952545166, 53.95083501935005, 46.807328537106514, 44.934568628668785, 42.2476302087307, 41.70194149017334, 39.1061107814312, 40.62858268618584, 40.104662999510765, 43.70984114706516, 41.467475071549416, 42.3972699791193, 44.896426275372505, 43.57410863041878, 43.40166248381138, 49.46668043732643, 51.83630168437958, 56.26708433032036, 51.076828837394714, 52.72630512714386, 55.984212309122086, 57.17802084982395, 54.218743443489075, 50.9818909317255, 45.7901307195425, 42.96079494059086, 39.33556526899338, 38.442894369363785, 38.594426438212395, 37.67752043902874, 39.078170880675316, 40.33970698714256, 41.44326277077198, 44.55390885472298, 45.82112945616245, 48.36784020066261, 48.50204899907112, 46.36840648949146, 48.70634123682976, 50.72571247816086, 51.401263028383255, 55.54948903620243, 45.502493754029274, 49.63596895337105, 56.06489717960358, 52.53053203225136, 50.08348993957043, 48.35481829941273, 46.84378758072853, 46.33209563791752, 41.31562002003193, 36.083859354257584, 38.575545251369476, 37.95934371650219, 36.93834230303764, 36.011914014816284, 39.422223418951035, 36.70709811151028, 40.258767530322075, 38.49057041108608, 42.8641053289175, 46.98168598115444, 52.04241022467613, 53.39551381766796, 52.79043808579445, 52.18553714454174, 52.2626768052578, 55.31188778579235, 54.253112599253654, 45.39110653102398, 38.50206479430199, 38.54852110147476, 38.820742294192314, 38.482537642121315, 39.60354208946228, 40.62577463686466, 44.86724004149437, 44.95046317577362, 50.55556520819664, 52.13915303349495, 53.44065919518471, 51.509583815932274, 52.3034980148077, 49.51605498790741, 51.17510296404362, 52.65596330165863, 56.11766874790192, 54.38740499317646, 56.218743324279785, 50.00279746949673, 41.14792361855507, 17.469898872077465, 5.063525168225169, 2.1033930452540517, 5.884241703897715, 18.152672834694386, 27.488378584384918, 10.577002242207527, 18.767884522676468, 4.595728470012546, 0.3287987021030858, 1.1588485166430473, 14.373865853995085, 45.375443771481514, 49.12505976855755, 41.95460893213749, 56.547824665904045, 41.9330944865942, 6.259967917576432, 0.2244724502088502, 0.09095859888475388, 0.21689610206522048, 0.15345745225204155, 0.15284172201063484, 0.16136261634528637, 0.14186151354806498, 0.09751741803484038, 0.13065594452200457, 0.23553255829028785, 0.15620460093487054, 0.2762151643401012, 0.17816331092035398, 0.1644154853420332, 0.10749364912044257, 0.12613638391485438, 0.10760876364656724, 0.09959384333342314, 0.1340256363619119, 0.12451418268028647], [0.01658607474382734, 0.013801919794786954, 0.010443693208799232, 0.014725687706231838, 0.012749105389957549, 0.03447386538027786, 0.03276773466495797, 0.01991647543036379, 0.045435579522745684, 0.04939378333801869, 0.024676076282048598, 0.08236187932197936, 0.05330417428922374, 0.022846205429232214, 0.015775157808093354, 0.013801135901303496, 0.04794173059053719, 0.01847087565693073, 0.022185987145348918, 0.054563175872317515, 0.013878351728635607, 0.08016347463126294, 0.03800216902163811, 0.07226723115309142, 0.07664758712053299, 4.385316660627723, 35.80256424844265, 49.79377828538418, 46.67986057698727, 59.00797985494137, 34.41896729171276, 34.13848154246807, 25.997794568538666, 3.891701535321772, 0.013382841989368899, 1.123558385297656, 15.36060830578208, 4.473029728978872, 1.7584929149597883, 2.0865806099027395, 9.346209336072206, 26.960180327296257, 46.884069219231606, 52.290810495615005, 57.81523525714874, 54.43735331296921, 53.340789154171944, 49.35742489993572, 44.013422057032585, 40.799193531274796, 39.91493918001652, 38.7210888415575, 37.57028639316559, 38.20028118789196, 39.646335393190384, 42.64049872756004, 45.525699108839035, 42.879258915781975, 44.083729684352875, 43.97603206336498, 44.23210792243481, 45.76992340385914, 49.720218032598495, 48.608067110180855, 51.04738801717758, 48.93206812441349, 45.68865716457367, 51.63770534098148, 51.64923392236233, 51.825666055083275, 47.9517625272274, 46.37424297630787, 41.2295888364315, 38.49164195358753, 37.59033791720867, 35.14989227056503, 35.13122007250786, 36.02815814316273, 35.86241863667965, 35.540891289711, 36.25936433672905, 37.71818965673447, 39.56742882728577, 39.510735869407654, 40.037304013967514, 40.068500339984894, 45.70905067026615, 47.35428258776665, 52.19206899404526, 37.84116245806217, 44.05523881316185, 49.972414299845695, 49.19243775308132, 50.30690275132656, 47.058814242482185, 48.811341002583504, 47.599152848124504, 44.90131661295891, 35.919198989868164, 34.72549304366112, 35.720454454422, 37.006970420479774, 34.13566209375858, 36.63353405892849, 35.11568270623684, 37.42907457053661, 36.2708131223917, 35.72541318833828, 36.01676635444164, 39.624357372522354, 44.81963999569416, 50.81835150718689, 48.38638320565224, 47.45156116783619, 48.14147114753723, 51.06284938752651, 46.863934099674225, 35.03497503697872, 34.183349534869194, 35.26149608194828, 35.56737966835499, 36.11520007252693, 35.75993433594704, 35.32546944916248, 36.80724933743477, 42.128578796982765, 42.15016543865204, 48.445815816521645, 47.401555851101875, 51.61772981286049, 49.40449297428131, 48.28426368534565, 51.59856364130974, 48.149671107530594, 57.18871347606182, 48.90603572130203, 45.95153085887432, 29.65657263994217, 11.445160657167435, 1.6618062718771398, 2.899728901684284, 21.40258714556694, 20.676206722855568, 5.686633782461286, 5.824780119583011, 8.394170422106981, 1.582937822677195, 0.05545325584535021, 1.108290448319167, 12.573515810072422, 26.7307448387146, 42.14340940117836, 35.83984024822712, 41.41194865107536, 21.137557066977024, 1.6117224656045437, 0.03515088959829882, 0.03446370908932295, 0.018236761461594142, 0.007355125517278793, 0.048156114789890125, 0.02570482283772435, 0.03236829594243318, 0.023790386112523265, 0.026666544181352947, 0.03634018496086355, 0.029505771126423497, 0.009343575238744961, 0.001365935554531461, 0.11280490318313241, 0.05779452025308274, 0.017762117204256356, 0.0414460533647798, 0.045430521786329336, 0.07522014027927071, 0.06048527684470173, 0.027998419100185856, 0.01685671930317767, 0.03240419362555258, 0.034389115826343186, 0.011088379269494908, 0.006784249289921718, 0.017297590275120456, 0.04531968203082215, 0.04279047243471723, 0.012215910319355316, 0.051940574412583373, 0.04180571297183633, 0.10359991938457824, 0.07142897535231896, 0.01869405801699031, 0.021755803099949844, 0.025793544737098273, 0.04560423258226365, 0.09202034503687173, 0.04401142410642933, 0.015661674151488114, 0.02089920326397987, 0.05067353165941313, 0.04646988105378114, 0.05182019805943128, 7.027367614209652, 41.573325991630554, 53.53745140135288, 52.569605335593224, 65.41520744562149, 44.65450465679169, 40.28386898338795, 31.23047288507223, 4.083472732454538, 0.08982596278656274, 3.5101267229765654, 22.186139300465584, 3.428741740062833, 2.9818876180797815, 3.1901209568604827, 13.290065210312605, 29.85608283430338, 48.709692656993866, 53.08334916830063, 58.05553816258907, 56.6291669011116, 54.74157638847828, 51.341321244835854, 46.86025209724903, 42.371248975396156, 41.272887513041496, 40.2305768430233, 39.4645531475544, 39.75553773343563, 39.54788267612457, 44.0526207536459, 46.94824017584324, 46.57796524465084, 45.63082806766033, 45.7237558811903, 47.43418850004673, 47.99424424767494, 51.46961376070976, 51.331753358244896, 53.350961208343506, 49.509070962667465, 46.41924776136875, 52.436760663986206, 54.34330835938454, 53.97036977112293, 50.47021418809891, 48.37455824017525, 42.92494386434555, 39.68638524413109, 38.76848749816418, 36.576856300234795, 36.86813347041607, 36.49971283972263, 37.39260792732239, 38.69958959519863, 38.109363466501236, 39.54511262476444, 42.82863423228264, 41.38344258069992, 43.329036980867386, 42.36316300928593, 47.990311458706856, 49.1907012462616, 54.434237480163574, 41.661431863904, 45.69727510213852, 52.4701152741909, 51.8280029296875, 51.96675628423691, 50.26948995888233, 50.74187681078911, 50.77094905078411, 47.10305146872997, 38.05339626967907, 36.90466471016407, 37.07605831325054, 37.37237401306629, 36.452302783727646, 37.87536822259426, 37.07420401275158, 38.294869512319565, 36.935367062687874, 38.32067772746086, 38.508159667253494, 43.07759687304497, 48.3721187710762, 52.81947232782841, 50.01794345676899, 49.04531344771385, 49.467447996139526, 52.3377987742424, 47.19025298953056, 35.744146183133125, 35.79404130578041, 36.694448590278625, 38.13683979213238, 37.50275641679764, 37.28220485150814, 36.480197086930275, 40.19319824874401, 44.12863187491894, 45.90075798332691, 49.83589142560959, 50.22391140460968, 51.901479586958885, 50.95274269580841, 49.48083087801933, 51.68847441673279, 49.39245142042637, 56.721190363168716, 50.37765495479107, 48.91591139137745, 31.631265878677368, 13.619814366102219, 3.3651029923930764, 5.210475632920861, 13.399794772267342, 25.664560049772263, 11.482056677341461, 8.549583982676268, 6.165029536932707, 0.8533266826998442, 0.2633995207725093, 1.499549753498286, 16.21173318475485, 32.526307851076126, 44.585808143019676, 38.66227939724922, 47.97625221312046, 25.801033526659012, 2.360734948888421, 0.010180960871366551, 0.13641376368468627, 0.03274221220635809, 0.057575928076403216, 0.03558267111657187, 0.0335840414481936, 0.024276863914565183, 0.09155446183285676, 0.04239118214172777, 0.02684026610950241, 0.04070659226272255, 0.023780676965543535, 0.024023470577958506, 0.05921084601141047, 0.04842055685003288, 0.0080563961637381, 0.021980913188599516, 0.06462493576691486, 0.029074421909172088, 0.04798370646312833, 0.1402170181972906, 0.18392552359728143, 0.10762549165519886, 0.08544735828763805, 0.10893953090999275, 0.10637840896379203, 0.17369083216181025, 0.10800592397572473, 0.20782166946446523, 0.10745669758762233, 0.14480415877187625, 0.15342255646828562, 0.176741637988016, 0.1279808732215315, 0.09566393389832228, 0.1061176999064628, 0.14847476180875674, 0.09561193903209642, 0.11250916475546546, 0.12358088744804263, 0.14269126433646306, 0.16298682137858123, 0.16408628347562626, 0.2164820281905122, 0.21143649268196896, 8.224121946841478, 48.26777257025242, 59.64283838868141, 57.143765687942505, 65.53928598761559, 45.81037603318691, 45.73175065219402, 34.28461030125618, 6.482315361499786, 0.09142211463768035, 2.189279361627996, 20.524826645851135, 9.427602868527174, 5.431639440357685, 3.6504287319257855, 11.857816614210606, 31.339764520525932, 50.053319558501244, 56.355843767523766, 60.498096495866776, 59.51028250157833, 57.42881499230862, 53.978003561496735, 49.30290922522545, 44.466380551457405, 43.94747279584408, 43.26958157122135, 40.31861051917076, 42.661363407969475, 42.72215634584427, 46.88545614480972, 48.94487343728542, 48.92725758254528, 49.69278730452061, 48.937577828764915, 48.33984710276127, 50.9770879894495, 53.9243770390749, 54.76763159036636, 54.87515442073345, 51.59051567316055, 47.1072768419981, 54.53379213809967, 54.98053416609764, 56.08439013361931, 52.925433441996574, 50.71312375366688, 45.10873608291149, 41.67828015983105, 41.27595774829388, 38.240570425987244, 39.09683167934418, 38.8387381285429, 39.40217949450016, 39.36378255486488, 39.347603023052216, 41.362608298659325, 44.33163218200207, 42.582506239414215, 43.470491990447044, 45.119637697935104, 49.10421408712864, 50.97456872463226, 55.884061083197594, 45.4997693002224, 45.241698548197746, 53.03117036819458, 55.32664239406586, 54.25427533686161, 51.137937158346176, 52.07832969725132, 51.98089152574539, 48.908592984080315, 40.34332059323788, 38.64218607544899, 39.99639920890331, 39.85328368842602, 38.24140638113022, 40.238187834620476, 38.743549436330795, 41.12324394285679, 39.135931581258774, 40.09646683931351, 39.12376843392849, 43.07038486003876, 49.777800142765045, 55.70362016558647, 51.22138828039169, 48.8195713609457, 49.63634893298149, 53.65251682698727, 50.26419684290886, 39.03161957859993, 37.8966698795557, 37.29381322860718, 40.53893029689789, 39.21285845339298, 39.301211312413216, 37.98254907131195, 41.00257381796837, 45.43689027428627, 47.76768900454044, 50.95108598470688, 52.29296118021011, 54.72989201545715, 52.00158141553402, 49.22867640852928, 52.9190231859684, 50.71607619524002, 57.23006285727024, 51.50800310075283, 49.09553915262222, 35.28309792280197, 14.895487613976002, 2.673869258724153, 6.061423346400261, 35.108371898531914, 25.085408426821232, 9.810355380177498, 17.61331457644701, 16.556779369711876, 3.0083076003938913, 0.4718522384064272, 1.9490120792761445, 18.4081844240427, 38.06098826229572, 51.54594026505947, 47.140715047717094, 54.707872197031975, 29.172338023781776, 2.8274895530194044, 0.1535530705587007, 0.19629656133474782, 0.16397788538597524, 0.18593641725601628, 0.11457881424576044, 0.18787367502227426, 0.1220747729530558, 0.22807061963248998, 0.16965561197139323, 0.05937153211561963, 0.16180662845727056, 0.06863836650154553, 0.13227298040874302, 0.24034453992499039, 0.14607913879444823, 0.1333779195556417, 0.17450315732276067, 0.17911504110088572, 0.15342362516094, 0.1405990609782748], [0.020650709957408253, 0.08673594929859973, 0.044410543705453165, 0.0277990225731628, 0.0579483674664516, 0.04751158550789114, 0.012916597916046157, 0.02527131582610309, 0.04439051685039885, 0.02126448649505619, 0.019963835584349, 0.04023452696856111, 0.08292828642879613, 0.03373194776941091, 0.02134976297384128, 0.02132271540176589, 0.038590213443967514, 0.01975194685655879, 0.03470835436019115, 0.06624027955695055, 0.02949101723061176, 0.030742037015443202, 0.052418955383473076, 0.03223323990823701, 0.06652993979514576, 1.3578643812797964, 28.24095670133829, 46.51227816939354, 46.10361389815807, 40.26883319020271, 26.44367214292288, 29.364246726036072, 23.561127819120884, 5.742572955787182, 0.27653440658468753, 0.34211930294986814, 2.8781263483688235, 10.603264532983303, 3.442460666410625, 1.5535466372966766, 3.1637764954939485, 17.31242962181568, 33.68100889027119, 47.60081335902214, 56.04782849550247, 55.48071272671223, 51.4434027671814, 47.88399696350098, 44.88157667219639, 41.181551814079285, 40.12585826218128, 41.31690435111523, 38.43659430742264, 40.42321890592575, 44.90519240498543, 47.52566859126091, 48.16321738064289, 48.806264474987984, 42.57799208164215, 42.46575750410557, 44.85455632209778, 48.04941728711128, 49.316960871219635, 50.877233147621155, 49.476271122694016, 51.67055457830429, 52.58272223174572, 50.986275896430016, 52.24818058311939, 52.59166695177555, 50.333755910396576, 48.3671410381794, 44.334596022963524, 41.50809869170189, 37.52652034163475, 35.56461341679096, 35.10036572813988, 35.09973496198654, 36.36099748313427, 36.36429950594902, 34.92273285984993, 36.617768704891205, 37.11968757212162, 37.98993967473507, 38.98300118744373, 41.553741842508316, 47.0849796384573, 46.131587997078896, 50.2689465880394, 39.082723036408424, 41.40744969248772, 48.003413155674934, 46.81866332888603, 48.57364855706692, 50.059289038181305, 49.18541193008423, 46.765036806464195, 48.44238840043545, 41.233586221933365, 34.307663664221764, 36.54357008635998, 35.68153314292431, 34.24007289111614, 34.969926327466965, 35.00102385878563, 34.732393473386765, 35.23713558912277, 37.23065681755543, 37.58289031684399, 38.999879881739616, 43.295146599411964, 47.14004248380661, 49.178093522787094, 48.04398737847805, 47.82515712082386, 46.58704295754433, 47.48594552278519, 36.04742310941219, 35.59744365513325, 35.30304305255413, 38.85608799755573, 35.99980026483536, 36.00827381014824, 35.07084511220455, 36.649257615208626, 36.991911828517914, 40.36898821592331, 43.66678185760975, 48.725522607564926, 49.078622460365295, 53.838752433657646, 42.78395622968674, 55.69416247308254, 45.495076552033424, 44.81979958713055, 58.254955261945724, 36.46802254021168, 20.68763840943575, 6.06410457752645, 2.0345944119617343, 4.724343018606305, 20.930741764605045, 9.530973471701145, 4.961098339408636, 6.122977193444967, 6.263016778975725, 0.7209615572355688, 0.2460063697071746, 1.7574374028481543, 15.82829860970378, 30.543730035424232, 40.871370658278465, 51.54719419777393, 35.361058339476585, 12.61368440464139, 0.45280273247044533, 0.028839337355748285, 0.02674381474207621, 0.03476050136669073, 0.0557784204283962, 0.04357756828540005, 0.011618413718679221, 0.02486494544427842, 0.038852388242958114, 0.06206929829204455, 0.08863362832926214, 0.037851898960070685, 0.050810958855436184, 0.01700963512121234, 0.06030688680766616, 0.05206044610531535, 0.05919475996051915, 0.04526851094851736, 0.04151562228798866, 0.07126620010240003, 0.035943035763921216, 0.017389972817909438, 0.01801232672733022, 0.02690726349101169, 0.028619116164918523, 0.013550591484090546, 0.03280572149378713, 0.035945147174061276, 0.012366835326247383, 0.015975476453604642, 0.04752930428367108, 0.02995990613271715, 0.03569245331163984, 0.041526732238708064, 0.05612947483314201, 0.029109313982189633, 0.04388849105453119, 0.02938572873972589, 0.021513092979148496, 0.023155044618761167, 0.10277756038703956, 0.03854961054457817, 0.05788857633888256, 0.02720326723647304, 0.03247169566748198, 0.016428552044089884, 2.7403991762548685, 33.321920558810234, 51.90015345811844, 49.54710312187672, 46.943615823984146, 30.511636957526207, 36.993481144309044, 27.805479168891907, 6.873528119176626, 0.09454654151340947, 0.6129204109311104, 6.104209050536156, 12.361129056662321, 4.376900587230921, 3.2499591959640384, 5.251620300114155, 20.151948854327202, 38.22110407054424, 50.708241015672684, 57.964943423867226, 56.714894101023674, 53.64862963557243, 49.52725298702717, 46.3447679579258, 43.96554462611675, 42.349122762680054, 42.801412492990494, 41.10699601471424, 41.701705902814865, 43.71867947280407, 47.81587041914463, 49.585226476192474, 49.105076640844345, 43.90824370086193, 45.17564669251442, 48.353127390146255, 49.105847999453545, 52.50316970050335, 51.78313873708248, 52.559247091412544, 53.345052525401115, 52.163365334272385, 51.44179545342922, 52.51758232712746, 53.78621645271778, 50.51364205777645, 49.795560389757156, 46.6190030425787, 41.621408611536026, 39.09219592809677, 36.619907990098, 37.234574407339096, 37.542988657951355, 37.11567118763924, 38.14986549317837, 37.201455384492874, 38.55959750711918, 38.77770960330963, 41.122263595461845, 41.63832910358906, 42.22402587532997, 48.3808659017086, 48.65241453051567, 52.41484344005585, 41.04130893945694, 42.04402953386307, 49.18682925403118, 48.651225194334984, 49.993867948651314, 52.624178007245064, 49.95577499270439, 50.34911088645458, 51.56159542500973, 42.62461178004742, 35.157894641160965, 38.02533857524395, 37.278743237257004, 36.01395830512047, 36.4389730989933, 36.68452352285385, 35.595931336283684, 36.57904498279095, 37.93249815702438, 39.08314861357212, 39.79098983108997, 45.49424819648266, 48.841655775904655, 51.75073407590389, 49.207009971141815, 48.64488333463669, 47.502083256840706, 49.10797968506813, 37.590881288051605, 36.42784729599953, 36.73299752175808, 40.27473047375679, 38.46056342124939, 39.0327975153923, 37.59064570069313, 39.49440434575081, 37.747497484087944, 41.737670972943306, 45.52727982401848, 50.168160796165466, 51.065562441945076, 54.58325408399105, 46.06354884803295, 56.07964798808098, 46.98149599134922, 50.57853117585182, 55.854521468281746, 41.8439094722271, 23.214005045592785, 8.951351623982191, 2.6517900684848428, 7.742474041879177, 30.74932750314474, 16.281850822269917, 6.513045262545347, 4.762161914259195, 4.516125116497278, 0.7117081631440669, 0.2266141548170708, 2.2486613877117634, 18.51561415940523, 33.65562245249748, 45.09715050458908, 53.9068827778101, 42.162339985370636, 15.96969947218895, 0.7531170349102467, 0.045510770214605145, 0.012642263955058297, 0.03823020502750296, 0.039406082360073924, 0.07157184620155022, 0.0066196172792842845, 0.025354876088385936, 0.011787205930886557, 0.05985457006318029, 0.05282301768602338, 0.09491021613939665, 0.021635608572978526, 0.010644349531503394, 0.11883248560479842, 0.0221773151497473, 0.0869840789528098, 0.053867367896600626, 0.027094574143120553, 0.02937275970907649, 0.058400264897500165, 0.10872941405978054, 0.18619545648107305, 0.1656180020654574, 0.11877081313286908, 0.09696747176349163, 0.10673679207684472, 0.09460581684834324, 0.11063961312174797, 0.13830788782797754, 0.17192558938404545, 0.1213707345596049, 0.12389940238790587, 0.16770788992289454, 0.12030578232952394, 0.1155098013987299, 0.1659550706972368, 0.10521039468585514, 0.11574706601095386, 0.24939967668615282, 0.22061409865273163, 0.12816504458896816, 0.07188993811723776, 0.13412639033049345, 0.1326986021012999, 0.15665186365367845, 3.690137076191604, 38.51075492799282, 56.613314151763916, 57.55933038890362, 51.208457574248314, 39.047419130802155, 40.865317583084106, 34.68882121145725, 8.665561359375715, 0.7070537691470236, 0.6474172160960734, 5.6081698928028345, 15.809692908078432, 8.478132616728544, 3.003123728558421, 5.258878860622644, 21.400200873613358, 39.90031376481056, 50.14156982302666, 59.21755760908127, 59.48260858654976, 56.6236761957407, 51.44350156188011, 49.61263060569763, 46.2712799012661, 44.54151012003422, 45.25207199156284, 42.78552554547787, 44.2804679274559, 48.052472323179245, 50.64141400158405, 52.31784224510193, 51.97948560118675, 46.36974401772022, 46.55392773449421, 50.67400485277176, 53.32460202276707, 53.650594130158424, 53.59854832291603, 53.41551974415779, 56.36582963168621, 55.322481617331505, 54.092457219958305, 54.61481899023056, 55.18489100039005, 52.46740981936455, 50.94334959983826, 47.63166010379791, 46.07843264937401, 39.82080303132534, 37.863117679953575, 38.87713126838207, 38.36833856999874, 38.14902953803539, 39.10562060773373, 38.76067131757736, 41.18836484849453, 40.78928366303444, 42.88536138832569, 44.09027673304081, 45.73165185749531, 49.73426587879658, 50.0651141256094, 53.129573687911034, 45.10732255876064, 43.938167095184326, 46.98262833058834, 50.20932778716087, 49.99644801020622, 54.25602704286575, 51.97230778634548, 52.10829868912697, 52.95069068670273, 44.63340438902378, 37.29588031768799, 40.23286812007427, 39.264345690608025, 38.106589615345, 38.6214429885149, 37.62480586767197, 37.812781780958176, 38.46833400428295, 39.73457045853138, 41.92415736615658, 43.65381695330143, 47.967045307159424, 50.407175570726395, 53.4766660630703, 48.85710194706917, 49.19624134898186, 49.83380913734436, 49.94341805577278, 39.548228457570076, 38.11255909502506, 38.011279329657555, 41.9712520390749, 39.84465815126896, 41.739521473646164, 38.8038370013237, 40.61616115272045, 40.05107067525387, 42.55413696169853, 47.35677145421505, 52.613660171628, 54.22331839799881, 55.94669692218304, 48.15749868750572, 55.62980152666569, 51.30667470395565, 49.3177056312561, 58.934959173202515, 45.647072196006775, 22.958985529839993, 8.41810628771782, 3.3187314681708813, 7.446708837524056, 31.339310444891453, 12.709037438035011, 10.729506108909845, 17.615394964814186, 9.737395495176315, 2.1407227171584964, 0.46439513855148107, 2.824919940903783, 22.124500907957554, 42.91533797979355, 50.355399549007416, 60.13559214770794, 50.74046328663826, 19.40319523215294, 1.0962709807790816, 0.10696776327677071, 0.15732175583252683, 0.13101419404847547, 0.13916514260927215, 0.1589736429741606, 0.13558963837567717, 0.10446831380249932, 0.12288213314604945, 0.15751352679217234, 0.10847533980268054, 0.2141375094652176, 0.12111424090107903, 0.16427458118414506, 0.19896297919331118, 0.19109982065856457, 0.15072355832671747, 0.22438811254687607, 0.10286002041539177, 0.12595532956765965, 0.1543631692766212], [0.023447213316103444, 0.0571890873106895, 0.051842288085026667, 0.08589521472458728, 0.07523079751990736, 0.023976962038432248, 0.029368750256253406, 0.03501464241708163, 0.04880249573034234, 0.0824397528776899, 0.034766149110510014, 0.028042326412105467, 0.043749093456426635, 0.01883607910713181, 0.031686002475908026, 0.009241212665074272, 0.04524918913375586, 0.035985000504297204, 0.015595999648212455, 0.011706255245371722, 0.03772004529309925, 0.11016607095371, 0.004651833123716642, 0.040177530026994646, 0.06954590178793296, 0.8298235782422125, 14.382131360471249, 37.85751298069954, 49.316162914037704, 40.69201648235321, 21.683067195117474, 29.36335187405348, 32.933714389801025, 8.167803268879652, 0.4689899826189503, 0.8082800998818129, 1.5866035572253168, 1.741340160369873, 6.964960712939501, 3.340509762056172, 1.6742307739332318, 6.358519904315472, 27.102518789470196, 45.11023320257664, 57.35542953014374, 56.91543594002724, 51.45736701786518, 49.35246616601944, 46.67810507118702, 42.9329614341259, 42.27193370461464, 41.06744013726711, 41.524164229631424, 46.53701104223728, 48.99543732404709, 50.27498446404934, 51.026698127388954, 49.00342829525471, 45.88624656200409, 43.33969920873642, 47.50333718955517, 50.214096531271935, 51.02830924093723, 51.44410952925682, 50.96513383090496, 51.41507908701897, 52.1056654304266, 49.84043598175049, 52.46851935982704, 52.37512417137623, 51.22294619679451, 48.97188238799572, 45.22909462451935, 41.86700843274593, 39.54360030591488, 36.94152273237705, 35.962436869740486, 36.57312490046024, 37.99559377133846, 36.177140548825264, 36.25092878937721, 37.53454931080341, 38.81837502121925, 36.81176729500294, 40.48602573573589, 43.46014894545078, 48.581381142139435, 48.485014513134956, 51.670584976673126, 35.27952991425991, 42.053536623716354, 45.26941046118736, 48.33596371114254, 49.730671271681786, 48.91487404704094, 48.811033219099045, 49.31964352726936, 48.157107308506966, 42.56027363240719, 36.55758373439312, 35.908111184835434, 35.53470142185688, 35.51214203238487, 34.845175221562386, 36.67268715798855, 40.74739471077919, 42.6710756868124, 44.39038842916489, 45.78949615359306, 46.485417410731316, 46.76361948251724, 47.77982175350189, 48.34339611232281, 47.19053417444229, 46.72957330942154, 48.93269129097462, 46.022115871310234, 36.25570133328438, 34.537832513451576, 36.732324957847595, 37.183672338724136, 40.40537886321545, 39.446131736040115, 38.937023654580116, 38.31028528511524, 36.64567440748215, 35.8051785081625, 38.62939976155758, 44.34722654521465, 46.98305010795593, 52.12402984499931, 47.54469037055969, 41.98113910853863, 58.37513901293278, 40.089536011219025, 46.410082653164864, 35.02441920340061, 16.743184067308903, 6.21027703396976, 2.891928870230913, 3.158848397433758, 13.31626195460558, 13.997173067182302, 4.209964144974947, 6.462366431951523, 2.065593861043453, 0.5557343107648194, 0.26903672609478235, 4.066415447741747, 21.882649585604668, 28.096689842641354, 34.359424486756325, 48.09717312455177, 33.30632619559765, 6.257460527122021, 0.04649980073736515, 0.05347021127818152, 0.029613195147248916, 0.039517938857898116, 0.07881499972427264, 0.017298061538895126, 0.034509310353314504, 0.05102313145471271, 0.040432153473375365, 0.11343796999426559, 0.030906456122465897, 0.03468675786280073, 0.024451352110190783, 0.03879215924825985, 0.0296088832692476, 0.0197266693066922, 0.036793652034248225, 0.05201105617743451, 0.07508739974582568, 0.055428687046514824, 0.0603842074633576, 0.06636637044721283, 0.05851138666912448, 0.042307705371058546, 0.04308640011004172, 0.07841934595489874, 0.021263517992338166, 0.04930236558720935, 0.04677339718909934, 0.03911557978426572, 0.03869478576234542, 0.07398631234536879, 0.028617720927286427, 0.02421976678306237, 0.007011445741227362, 0.010676972487999592, 0.09433287719730288, 0.030076569892116822, 0.01893818007374648, 0.03470922267297283, 0.021046946312708315, 0.015876767101872247, 0.027377237784094177, 0.017305922738160007, 0.05278107892081607, 0.09731064827064984, 1.2447123904712498, 21.218971498310566, 43.63580971956253, 54.938166439533234, 45.41069068014622, 30.214213617146015, 32.34250411391258, 35.597029477357864, 9.22306364402175, 0.384512945311144, 0.2901133638806641, 2.17138540931046, 4.465332292020321, 5.580202918499708, 3.7532075168564916, 2.142922799102962, 9.746271818876266, 29.02591858059168, 47.00756639242172, 55.840937197208405, 58.62990394234657, 52.55450874567032, 50.8455428481102, 48.611547723412514, 43.96465927362442, 43.515143394470215, 42.41278074681759, 43.38989071547985, 47.46161922812462, 50.79141855239868, 52.50406265258789, 52.88845382630825, 50.14833725988865, 47.13340803980827, 44.811033457517624, 49.79495622217655, 53.120940551161766, 53.23069766163826, 53.588733449578285, 51.60421773791313, 54.04480777680874, 53.136417120695114, 52.26026013493538, 55.047501772642136, 54.3905246257782, 53.28718163073063, 50.89191175997257, 47.86001645028591, 44.42724645137787, 40.601201355457306, 38.70041035115719, 37.50038914382458, 38.126804530620575, 38.880186304450035, 37.772401347756386, 38.50632056593895, 39.72607031464577, 38.72055687010288, 40.55473744869232, 41.08223654329777, 45.624220222234726, 50.449493899941444, 52.10373893380165, 53.171447440981865, 39.66244652867317, 42.65357002615929, 46.24802514910698, 50.01779906451702, 49.77817252278328, 49.630314856767654, 50.36958418786526, 50.99847324192524, 49.722421914339066, 43.9824765175581, 38.66287596523762, 37.106604874134064, 36.54417805373669, 37.069157883524895, 36.41601473093033, 38.460859805345535, 41.27285711467266, 42.56816580891609, 45.06986416876316, 45.45020096004009, 47.939888164401054, 49.23133626580238, 51.42481416463852, 50.896501913666725, 47.09787994623184, 49.01755593717098, 50.117167532444, 48.09132523834705, 37.93613076210022, 36.53063178062439, 37.62022711336613, 38.505157828330994, 41.16433873772621, 41.36362664401531, 40.601243153214455, 39.46625925600529, 38.461855351924896, 38.150644451379776, 41.088939383625984, 46.82627812027931, 48.018110767006874, 53.82605351507664, 48.072041273117065, 47.21927583217621, 57.984561771154404, 41.92613705992699, 51.37898862361908, 36.92462123930454, 19.993995130062103, 8.566394280642271, 4.154204512014985, 3.5726193571463227, 12.025305926799774, 8.4628089889884, 3.2515714969486, 1.2582401395775378, 1.4068697579205036, 0.42537114350125194, 0.3833125956589356, 4.513923609629273, 25.003878101706505, 35.53528279066086, 39.88898657262325, 54.24820326268673, 38.89416955411434, 9.915571734309196, 0.09955667657777667, 0.08700570513610728, 0.04948938309098594, 0.020318819661042653, 0.03844367638521362, 0.013413951892289333, 0.05047230573836714, 0.03856843140965793, 0.04359138707513921, 0.03249091729230713, 0.028445078824006487, 0.05187169568671379, 0.04957990655384492, 0.0274789509785478, 0.05108230659971014, 0.05212515396124218, 0.04564228991512209, 0.08051477023400366, 0.04525082928012125, 0.005868426069355337, 0.05122026814206038, 0.22839930199552327, 0.14306311000837013, 0.06782528434996493, 0.2110324229579419, 0.13137710426235572, 0.12477215321268886, 0.16778329212684184, 0.10905019255005755, 0.10746742162154987, 0.150430632638745, 0.1819058577530086, 0.0724115120829083, 0.17553115059854463, 0.06112637369369622, 0.20162899629212916, 0.13907549116993323, 0.13849870883859694, 0.16443078842712566, 0.10583218085230328, 0.16596139379544184, 0.10402200103271753, 0.14392380835488439, 0.1263664645375684, 0.17436636466300115, 0.2284900814993307, 1.942314226180315, 23.472556471824646, 48.95561546087265, 63.03047440946102, 52.05637067556381, 33.90600621700287, 42.7234710752964, 43.29145699739456, 12.399275209754705, 1.1289137229323387, 2.615611022338271, 6.994216293096542, 4.872737880796194, 11.669162437319756, 5.8277221117168665, 2.7014329796656966, 7.6053370255976915, 30.036605447530746, 48.44559162855148, 59.36500109732151, 59.8820735514164, 55.47959178686142, 53.439131677150726, 53.472512885928154, 46.30634441971779, 46.34172812104225, 44.187901094555855, 45.406358912587166, 50.23858241736889, 53.30037072300911, 53.479819893836975, 54.62141163647175, 52.51120626926422, 48.844304233789444, 47.83100500702858, 52.17719279229641, 54.2626728862524, 54.57182049751282, 55.7314308732748, 53.55640098452568, 56.02909930050373, 55.379892736673355, 53.38622331619263, 57.56443731486797, 56.85781963169575, 55.51450431346893, 53.71666118502617, 50.81446051597595, 46.39447309076786, 42.77707859873772, 40.27085468173027, 38.29771175980568, 40.000791773200035, 40.7182502746582, 40.29607392847538, 40.22315964102745, 42.163411527872086, 41.92182429134846, 41.61768481135368, 42.59772062301636, 46.892592161893845, 52.694778218865395, 54.20069821178913, 54.950876757502556, 43.621826469898224, 43.89369048178196, 45.46254649758339, 49.85547557473183, 51.98486611247063, 51.48676224052906, 52.292018830776215, 54.03095372021198, 52.03233316540718, 46.27293661236763, 40.9620413929224, 39.4444864243269, 37.788580879569054, 39.64567802846432, 39.89237979054451, 39.91557754576206, 44.34599921107292, 45.52985228598118, 49.199129194021225, 49.49071414768696, 50.30661016702652, 51.49636432528496, 52.963872179389, 50.90387351810932, 47.195082530379295, 50.34548208117485, 51.46302491426468, 49.53811280429363, 39.87896271049976, 38.46418842673302, 39.65135492384434, 40.61879061162472, 43.524867072701454, 43.982430920004845, 42.81477637588978, 41.54277183115482, 41.024274453520775, 41.16169027984142, 41.739890053868294, 47.989711090922356, 51.95680841803551, 57.116494551301, 50.8942486345768, 47.870017513632774, 57.02409490942955, 47.336503341794014, 48.44192482531071, 40.15461131930351, 20.509270280599594, 11.418726425617933, 6.156629137694836, 7.974450644105673, 23.7577273696661, 23.914588652551174, 12.050533723086119, 11.309800520539284, 5.4307004157453775, 1.6270934720523655, 0.6241727946326137, 6.308164056390524, 29.667896032333374, 38.86911749839783, 47.31485590338707, 57.12348997592926, 45.502383559942245, 10.50998143851757, 0.3454665670869872, 0.2224450363428332, 0.12800469616195187, 0.09500633168499917, 0.14292692590970546, 0.1581560040358454, 0.13476901600370184, 0.16578911163378507, 0.0682355064782314, 0.1814438559813425, 0.15279440267477185, 0.20176019315840676, 0.14977852231822908, 0.15561750275082886, 0.19249927368946373, 0.12128053393098526, 0.09108782163821161, 0.18048305675620213, 0.16603418363956735, 0.0886746690957807, 0.1439698808826506], [0.028755246457876638, 0.03924865428416524, 0.04651467337680515, 0.03298066796560306, 0.07240135950269178, 0.021376676959334873, 0.038515015330631286, 0.03318573821161408, 0.05136224841407966, 0.08431998401647434, 0.039110778088797815, 0.004694112349170609, 0.019002349872607738, 0.048420115272165276, 0.007394178719550837, 0.06946301131392829, 0.05433591912151314, 0.029943543631816283, 0.04313092154916376, 0.0617853563016979, 0.025523555123072583, 0.011348500174790388, 0.05149074757355265, 0.047348164589493535, 0.048429444068460725, 0.27798782859463245, 6.030363813042641, 26.946261674165726, 41.18094004690647, 37.04057201743126, 29.29740071296692, 33.183038011193275, 26.386337019503117, 13.706610258668661, 0.849147381959483, 0.26191139593720436, 2.4938928661867976, 6.4764731749892235, 0.6746552826371044, 4.623425658792257, 8.585108276456594, 10.868339259177446, 11.994094401597977, 37.82382398843765, 50.00636167824268, 58.48999924957752, 53.48385147750378, 52.565961331129074, 47.70325966179371, 45.63332833349705, 43.2463002204895, 46.188733130693436, 46.44754484295845, 50.70100620388985, 51.18458725512028, 53.866707533597946, 49.9294576048851, 49.47527177631855, 41.88647098839283, 39.31632310152054, 43.554315492510796, 48.13045173883438, 49.23311837017536, 48.579401448369026, 47.245984598994255, 47.671930342912674, 47.98249147832394, 50.74525102972984, 50.233338698744774, 48.62137779593468, 48.37425045669079, 46.02887950837612, 43.00094358623028, 42.95150823891163, 37.77588576078415, 37.550303265452385, 37.35839456319809, 35.22013530135155, 35.41516363620758, 37.03560568392277, 36.37121133506298, 36.60311669111252, 36.654573529958725, 38.60830329358578, 44.510936960577965, 49.329393804073334, 48.61676864326, 48.90166975557804, 50.1430631428957, 35.14289304614067, 42.895997017621994, 48.922492638230324, 48.46020184457302, 50.99609836935997, 48.17859135568142, 47.63937748968601, 45.37140838801861, 45.25052547454834, 39.44074362516403, 35.803966373205185, 35.236725211143494, 35.69483622908592, 34.96907897293568, 38.19702096283436, 44.07250128686428, 47.05415949225426, 48.689660131931305, 49.501361176371574, 47.690119966864586, 49.23962362110615, 47.848837450146675, 50.026918575167656, 47.712629958987236, 45.92282719910145, 50.41227489709854, 48.76058332622051, 44.3414356559515, 33.35435941815376, 35.19664876163006, 36.205996200442314, 40.4981204867363, 46.69503316283226, 46.17362514138222, 46.70977637171745, 42.04460710287094, 38.973509296774864, 38.86721380054951, 38.185845762491226, 39.87735539674759, 46.390867084264755, 47.7950893342495, 54.76254366338253, 44.97933402657509, 47.13588170707226, 52.88436144590378, 34.36859339475632, 28.907159753143787, 10.772477053105831, 2.7229540748521686, 3.7384804571047425, 21.537107527256012, 31.665838323533535, 20.5289114266634, 0.7610761828254908, 1.0159060056321323, 1.5537620382383466, 0.11535436598933302, 0.698275052709505, 7.34671862795949, 21.184461750090122, 26.52546275407076, 36.18196249008179, 44.05772008001804, 24.525023996829987, 2.674573170952499, 0.009875054092844948, 0.032117479713633657, 0.04950217771693133, 0.03408677228435408, 0.04056086043419782, 0.06539214577060193, 0.018549042360973544, 0.04648631591408048, 0.07571017296868376, 0.05651338040479459, 0.01378122964524664, 0.011377189748600358, 0.04516551569395233, 0.02571465814980911, 0.024968586367322132, 0.029549409409810323, 0.036600055391318165, 0.04798706839210354, 0.03017972470843233, 0.04542902264802251, 0.11284304215223528, 0.0376071386563126, 0.07200648498837836, 0.11134316911920905, 0.01590571086126147, 0.03330788829771336, 0.036818280204897746, 0.04560428082186263, 0.04548584889562335, 0.1844091367092915, 0.06801942276069894, 0.020095448053325526, 0.047408352766069584, 0.05949893660726957, 0.03915229382982943, 0.03265285020461306, 0.019836451501760166, 0.013836504804203287, 0.04655864933738485, 0.01122795591072645, 0.11492486286442727, 0.041701841983012855, 0.017973948415601626, 0.10181365156313404, 0.029493327165255323, 0.030007407294760924, 0.2937762188958004, 8.378145731985569, 34.13384959101677, 47.126291021704674, 43.021675273776054, 31.0912274569273, 36.9231241196394, 32.120178043842316, 14.998421240597963, 1.111109065823257, 0.179357411689125, 1.3616540841758251, 3.7626331485807896, 4.044635966420174, 4.936774419620633, 8.576519787311554, 10.375536102801561, 16.899399384856224, 41.321388110518456, 52.095956951379776, 58.32006096839905, 54.41049635410309, 53.87610822916031, 49.79952737689018, 46.56195670366287, 45.184424221515656, 47.94898487627506, 48.092997148633, 53.08923125267029, 52.50817023217678, 53.95922116935253, 51.321144327521324, 51.55893936753273, 44.168731123209, 41.75101585686207, 46.02118492126465, 50.03766059875488, 51.0864233225584, 51.94068968296051, 50.05730174481869, 49.68988426029682, 49.90688681602478, 52.73701295256615, 51.468827202916145, 50.77449806034565, 51.24610215425491, 48.69110405445099, 45.212858095765114, 43.49691957235336, 41.02647453546524, 39.14018735289574, 39.37307305634022, 37.28265702724457, 37.73260988295078, 39.392091035842896, 38.28447327017784, 37.721499279141426, 39.7427324205637, 39.886809289455414, 45.35285398364067, 50.97701579332352, 49.401160553097725, 50.965335220098495, 51.141512766480446, 38.65034803748131, 43.997865691781044, 49.2948916554451, 51.0637803375721, 53.78539189696312, 49.86415430903435, 50.41776940226555, 47.89326086640358, 48.95021215081215, 41.367042660713196, 37.80207775533199, 38.29176127910614, 36.05490490794182, 36.37889452278614, 40.1111264526844, 45.72782926261425, 49.00259234011173, 50.94221346080303, 50.729671865701675, 51.19347117841244, 50.06804756820202, 49.58610042929649, 50.99435046315193, 47.22225107252598, 48.18211376667023, 51.82567745447159, 50.38827918469906, 45.254405066370964, 35.53174898028374, 36.51545159518719, 38.13432052731514, 40.35834118723869, 48.309346139431, 47.839060574769974, 46.73503741621971, 43.17342013120651, 40.2609334141016, 40.60924552381039, 38.810254856944084, 41.65036305785179, 49.33057174086571, 50.25579169392586, 56.0408178716898, 46.042858958244324, 51.37339912354946, 51.76110751926899, 37.94685758650303, 32.282676324248314, 13.759052194654942, 4.333685506135225, 6.617265595123172, 12.019139807671309, 22.64450490474701, 18.0920147895813, 2.62828737962991, 1.0985464649274945, 0.526801060186699, 0.14791317866183817, 0.5774062697310001, 8.733139783143997, 25.220194794237614, 31.186682134866714, 40.0020495057106, 49.20637920498848, 30.883350111544132, 3.7791731860488653, 0.03797460194618907, 0.04211281368043274, 0.046535371875506826, 0.07267938286531717, 0.01473930054999073, 0.03934073625714518, 0.009357462677144213, 0.06422740436391905, 0.021833131177118048, 0.04453476438357029, 0.014163415289658587, 0.025644118868513033, 0.020269305423425976, 0.021796064611407928, 0.07757025479804724, 0.06793401640607044, 0.04964445855875965, 0.06081958097638562, 0.011884944924531737, 0.041946194105548784, 0.07869460852816701, 0.10685655986890197, 0.11863226900459267, 0.17015440942486748, 0.1075483750901185, 0.10063018577056937, 0.12723314459435642, 0.16811949986731634, 0.09312287962529808, 0.19999395590275526, 0.16166109329788014, 0.1361706361058168, 0.1470690153655596, 0.21491366234840825, 0.12160888974904083, 0.15167604549787939, 0.15936910378513858, 0.21813556289998814, 0.16135409648995847, 0.14352092606713995, 0.226433961361181, 0.13297502242494375, 0.13927465392043814, 0.16920725087402388, 0.12146837150794454, 0.18376185034867376, 0.5344585992861539, 8.736674543470144, 37.3103803396225, 53.44500996172428, 51.162255853414536, 41.37658774852753, 44.83161695301533, 37.02733352780342, 19.225615561008453, 1.4873748505488038, 0.6513946526683867, 5.518633397296071, 12.036178093403578, 5.68567955866456, 10.372957941144705, 15.05518639460206, 17.267892211675644, 20.059315524995327, 44.64925333857536, 52.8746073693037, 61.722117215394974, 57.87287436425686, 56.85682028532028, 51.83841057121754, 49.15570132434368, 47.3273154348135, 50.34587725996971, 51.3325285166502, 54.18004631996155, 53.34346801042557, 55.944200456142426, 52.43183232843876, 54.13389019668102, 45.56224934756756, 43.64259235560894, 47.65160143375397, 50.867387875914574, 53.10361348092556, 54.009500071406364, 50.37192866206169, 50.92849239706993, 52.213693633675575, 55.24875797331333, 53.821687549352646, 51.88363954424858, 52.07109488546848, 50.277750715613365, 46.63891777396202, 46.260446682572365, 43.173507526516914, 41.68487660586834, 40.71066588163376, 38.413525745272636, 39.36011575162411, 40.471578910946846, 39.36154447495937, 40.16570292413235, 39.32494103908539, 41.34185381233692, 47.865404561161995, 53.79124358296394, 51.00047193467617, 52.514580488204956, 51.688265427947044, 40.649033188819885, 45.148561745882034, 48.903387263417244, 53.15465994179249, 55.40106140077114, 53.86514961719513, 51.53805948793888, 48.581715524196625, 51.01437158882618, 43.375075310468674, 40.427125096321106, 39.87552769482136, 38.04127112030983, 37.96794645488262, 41.431270614266396, 48.53854604065418, 51.832235902547836, 52.47584156692028, 52.86316618323326, 53.45870442688465, 53.74718874692917, 51.21215097606182, 52.89679817855358, 47.41577468812466, 47.973759546875954, 54.96732987463474, 52.207116186618805, 48.01473654806614, 36.12445257604122, 38.81745167076588, 38.93863096833229, 43.70616294443607, 50.981807336211205, 50.24887226521969, 50.39385728538036, 46.45625397562981, 41.21271014213562, 44.09231722354889, 41.428527161478996, 44.38771717250347, 50.95927834510803, 52.027268037199974, 57.46912322938442, 47.90690213441849, 49.23462688922882, 53.279631435871124, 41.22234262526035, 34.449540451169014, 14.4858287461102, 4.58235033787787, 6.932581700384617, 32.03683331608772, 41.15615777671337, 28.64348240196705, 9.207557626068592, 3.737515308894217, 4.646740257740021, 0.49461524351499975, 1.0952781653031707, 11.0317418910563, 31.042113192379475, 38.21417324244976, 47.4411915242672, 55.405370369553566, 35.06858043372631, 5.564476987347007, 0.11697414782247506, 0.11452134232968092, 0.16588955390034243, 0.08460415236186236, 0.09823716027312912, 0.12745371088385582, 0.1264220365555957, 0.1478732659597881, 0.1358845381764695, 0.17704817466437817, 0.1218257230357267, 0.05862107238499448, 0.23519210546510294, 0.17041475482983515, 0.18586433987366036, 0.16380658285925165, 0.0966848767711781, 0.08317821950186044, 0.056403472044621594, 0.1406317451619543, 0.2799701347248629], [0.04546340634988155, 0.10078568797325715, 0.04250667887390591, 0.0385931152413832, 0.0441718207730446, 0.01770921877323417, 0.01928315257828217, 0.06352062744554132, 0.006025654693075921, 0.06441981357056648, 0.01350992550214869, 0.033650281839072704, 0.058904279649141245, 0.06387105473550037, 0.047169611279969104, 0.007843479561415734, 0.030966709236963652, 0.03988159493019339, 0.052360232948558405, 0.007743543346805382, 0.0039871304124972085, 0.028159305584267713, 0.015580572253384162, 0.03299443480500486, 0.024976176682685036, 0.08393490585149266, 2.035707514733076, 16.35119140148163, 39.075066447257996, 44.486584067344666, 33.68756353855133, 19.2771065980196, 25.358615666627884, 13.81798418238759, 2.8517275024205446, 0.09512068179901689, 0.6900645839050412, 5.096970498561859, 1.6338781267404556, 6.259439270943403, 27.20863949507475, 33.28927271068096, 24.457853101193905, 29.10849764943123, 40.00949710607529, 54.72928784787655, 52.907118424773216, 51.48194029927254, 48.23620766401291, 49.70736712217331, 49.10592779517174, 48.77795599400997, 51.68931037187576, 52.78159216046333, 52.78818480670452, 49.5684389770031, 49.042418003082275, 49.86955001950264, 42.12311469018459, 37.50084891915321, 37.98675164580345, 40.3300479054451, 40.021200478076935, 40.11739231646061, 38.148318976163864, 39.187916591763496, 39.9743527919054, 39.64664697647095, 41.437863260507584, 42.23797872662544, 41.89867973327637, 41.6766956448555, 39.47813741862774, 40.62009394168854, 39.58519287407398, 37.68386609852314, 39.18521873652935, 37.893603444099426, 36.01146183907986, 35.78946255147457, 39.66378025710583, 38.17385360598564, 39.2797614634037, 42.085736095905304, 48.32431733608246, 46.07543081045151, 50.73065221309662, 48.40986594557762, 48.88901263475418, 37.79617667198181, 45.900100618600845, 51.59940339624882, 46.837521716952324, 46.96308597922325, 46.69124096632004, 46.37776538729668, 45.86551867425442, 41.7362954467535, 35.57525284588337, 35.848154202103615, 35.734061524271965, 36.13329090178013, 36.51968076825142, 44.76740039885044, 49.929032027721405, 52.14314661920071, 48.901707753539085, 49.5087593793869, 49.93913188576698, 48.40327329933643, 49.03783544898033, 48.43019485473633, 48.4982568025589, 49.71219666302204, 49.78494755923748, 44.42226491868496, 39.19166699051857, 33.882455080747604, 36.25869557261467, 34.467239901423454, 43.35909716784954, 49.50390323996544, 49.203913137316704, 48.78281593322754, 46.65143810212612, 44.14568156003952, 42.527264803647995, 40.72771176695824, 44.01886336505413, 44.788044691085815, 48.74525494873524, 51.010089218616486, 51.873763874173164, 48.80880653858185, 43.65157887339592, 30.66466424614191, 8.865173198282719, 6.800724025815725, 5.9489109087735415, 17.401339150965214, 32.48767912387848, 16.111874543130398, 3.0562007054686546, 0.6662529241293669, 0.23104786378098652, 0.13750112877460197, 0.2559352369280532, 1.947041053790599, 17.22088873386383, 23.3512631803751, 34.15718033909798, 35.181544572114944, 34.51879173517227, 13.343216758221388, 1.2915435712784529, 0.02832400114129996, 0.03913392938557081, 0.0826295126171317, 0.004642578542188858, 0.04632111013052054, 0.038514373372890987, 0.012644629550777609, 0.04099074947589543, 0.02214683514466742, 0.04239159403368831, 0.0471134418330621, 0.0036567580400515, 0.04035761587147135, 0.011515803453221451, 0.06046517948561814, 0.019812428181467112, 0.049879314901772887, 0.05455172082292847, 0.025954049015126657, 0.07016333896899596, 0.09153973762295209, 0.09112028317758814, 0.028821169580623973, 0.007722631944488967, 0.04124019273149315, 0.026470802731637377, 0.006386874665622599, 0.026700588350649923, 0.020889362385787535, 0.046354076330317184, 0.059754461763077416, 0.04924499757180456, 0.026561020058579743, 0.025792077140067704, 0.013209932712925365, 0.047643951256759465, 0.030042137950658798, 0.06302977839368396, 0.0657228913041763, 0.05639336028252728, 0.02388098193478072, 0.012884289444627939, 0.02324975750525482, 0.018406258714094292, 0.042981341684935614, 0.018489724352548365, 0.0795020948862657, 3.00515400711447, 20.95305796712637, 45.3539065271616, 47.10562393069267, 37.528101056814194, 25.61852741986513, 33.100742027163506, 18.387108854949474, 2.885281126946211, 0.07393393898382783, 0.6388820428401232, 5.829944992437959, 4.904015902429819, 8.06031558662653, 29.116948395967484, 32.924393489956856, 23.966081589460373, 34.41517889499664, 46.314779967069626, 55.96788838505745, 56.313164457678795, 54.03934367001057, 49.986538141965866, 52.16355912387371, 50.72340980172157, 51.66439890861511, 54.14490960538387, 53.47857356071472, 54.5104917883873, 52.57619798183441, 51.936217322945595, 52.05085337162018, 44.38603766262531, 38.84729906916618, 39.668039828538895, 42.81209371984005, 44.82787795364857, 41.85721255838871, 41.21376268565655, 40.85905931890011, 44.00147929787636, 42.75616832077503, 44.385714679956436, 45.03611817955971, 44.91754174232483, 44.81948800384998, 42.84023880958557, 43.72165851294994, 40.836537927389145, 39.133856892585754, 40.61268053948879, 39.43313643336296, 36.612950563430786, 37.15286359190941, 39.092978686094284, 40.029886811971664, 40.31466633081436, 44.079511910676956, 49.637424275279045, 48.93652528524399, 52.64838270843029, 51.06568403542042, 50.105304569005966, 38.96495595574379, 46.85870558023453, 51.610650792717934, 50.199691504240036, 49.70380671322346, 48.85546803474426, 48.93782861530781, 47.10355684161186, 43.610636070370674, 38.75699691474438, 37.44112752377987, 37.28206045925617, 36.790336444973946, 37.77903959155083, 45.7507686316967, 51.01799659430981, 53.704334646463394, 50.727502182126045, 50.28214327991009, 51.6721048951149, 50.28725400567055, 50.18574245274067, 49.12104718387127, 49.68059375882149, 50.94466432929039, 51.626062765717506, 46.174282506108284, 41.21366389095783, 36.430366560816765, 37.42859199643135, 36.398037895560265, 46.13213136792183, 50.903379544615746, 52.161651626229286, 49.981469213962555, 47.915637865662575, 45.53179398179054, 43.7219662964344, 42.09344208240509, 45.11738441884518, 46.23920202255249, 52.07443110644817, 53.21275882422924, 52.643268182873726, 49.559938833117485, 47.32717864215374, 34.36391964554787, 12.730394192039967, 9.12302641198039, 3.6640065908432007, 11.312428079545498, 25.492123402655125, 22.977760322391987, 6.258769556879997, 0.9997590095736086, 0.0176615840246086, 0.3232404019217938, 0.10846539502381347, 3.1166599737480283, 21.100486256182194, 27.935306802392006, 38.10908988118172, 41.082715317606926, 42.0135285705328, 17.34401922672987, 1.825017489027232, 0.0832691919640638, 0.0911092474416364, 0.04166293489106465, 0.06703581733745523, 0.0627738339244388, 0.006575577308467473, 0.02237482291093329, 0.021946889428363647, 0.04105220301426016, 0.07567978202132508, 0.0017260679328501283, 0.04926749206788372, 0.06422147460398264, 0.0612275432649767, 0.01878358885733178, 0.023546837364847306, 0.05890257270948496, 0.03527853528794367, 0.020420004075276665, 0.018499752623029053, 0.03319090355944354, 0.18421582208247855, 0.1854198527871631, 0.15107854240341112, 0.12634770304430276, 0.13479163666488603, 0.0826950219925493, 0.0947197810455691, 0.14224364538677037, 0.1564811251591891, 0.14635202649515122, 0.11914838818483986, 0.148919026250951, 0.1129924735869281, 0.21280401851981878, 0.1382010185625404, 0.08207709499401972, 0.12251197214936838, 0.15920467354590073, 0.10694890530430712, 0.072570353950141, 0.07166457013227046, 0.0837203954870347, 0.13074336951831356, 0.12215577837196179, 0.10768681531772017, 0.13183451956138015, 3.1414120830595493, 22.091015204787254, 53.35501179099083, 56.536942049860954, 46.06389842927456, 29.494714625179768, 37.84227579832077, 21.26968927681446, 3.8871971145272255, 0.18243751750560477, 2.128029973246157, 10.184618197381496, 6.13409492187202, 11.46070372313261, 36.3051974773407, 38.26019637286663, 33.1430109590292, 39.696021527051926, 47.97925025224686, 56.07073366641998, 58.68731886148453, 56.351614594459534, 52.62860096991062, 54.58481200039387, 53.571531772613525, 54.682360365986824, 55.81190675497055, 57.43170663714409, 55.28178580105305, 54.43898342549801, 52.68427558243275, 53.49516727030277, 46.492139250040054, 40.33697873353958, 41.77300147712231, 45.47926180064678, 46.88960552215576, 42.579572796821594, 41.480998545885086, 42.04417772591114, 44.48565311729908, 44.1212260723114, 45.974257439374924, 46.25064700841904, 45.40732026100159, 45.354700684547424, 43.194919377565384, 46.47268049418926, 42.94695608317852, 40.690808147192, 42.95355632901192, 41.54461093246937, 37.76350602507591, 39.01649259030819, 41.9839471578598, 43.322064355015755, 43.02702158689499, 46.707188710570335, 51.766883209347725, 49.58964183926582, 53.97852033376694, 54.78396311402321, 51.80366903543472, 43.09743940830231, 48.96720103919506, 53.53620886802673, 51.57070353627205, 52.172811627388, 50.85573390126228, 50.11788569390774, 51.06320656836033, 46.78218528628349, 39.24198769032955, 38.75666253268719, 38.936902061104774, 38.86097073554993, 39.65916730463505, 49.02882993221283, 53.38552035391331, 55.630280300974846, 50.816280618309975, 50.123509392142296, 51.46139480173588, 50.241812244057655, 50.11844426393509, 49.187543615698814, 51.08220174908638, 53.031295761466026, 52.66623795032501, 48.941419422626495, 42.03910119831562, 38.36548112332821, 39.860355108976364, 37.73465037345886, 47.795936688780785, 53.67455564439297, 53.88661466538906, 53.212257251143456, 49.84950989484787, 47.709764912724495, 45.585990473628044, 44.83874537050724, 47.49356411397457, 47.73030661046505, 53.604939579963684, 55.041927471756935, 52.70590782165527, 50.38596510887146, 45.693102926015854, 35.184656605124474, 13.3624361269176, 12.477831244468689, 10.239700991660357, 29.114463329315186, 38.66802468895912, 18.60862746834755, 6.484374376013875, 3.065960481762886, 0.5942850827705115, 0.9807652537710965, 0.39917425077874213, 3.9770641922950745, 29.534536488354206, 33.81752796471119, 47.04790122807026, 46.0107696801424, 47.32950031757355, 19.653508700430393, 2.122675348073244, 0.25006152398418635, 0.15048130648210645, 0.17387632455211133, 0.12340709872660227, 0.13243430847069249, 0.10777314935694449, 0.14740958693437278, 0.08829580270685256, 0.14709188835695386, 0.36111641325987875, 0.25808571372181177, 0.12707079236861318, 0.10652856028173119, 0.10882350354222581, 0.190535981382709, 0.12238496841746382, 0.2413748190156184, 0.2485069027170539, 0.09696059205452912, 0.10128293433808722, 0.18097985041094944], [0.017623237254156265, 0.03736518367077224, 0.0658999454753939, 0.02731514599872753, 0.024963400610431563, 0.027847603560076095, 0.019033271455555223, 0.03833121503703296, 0.052963984926464036, 0.03350837949255947, 0.08841023445711471, 0.03470055809884798, 0.04143301383010112, 0.05264214887574781, 0.007556990613011294, 0.006121758178778691, 0.03329957624373492, 0.012526651262305677, 0.07831594251911156, 0.048052555503090844, 0.01370412421238143, 0.08130893504130654, 0.04370525108242873, 0.050460067723179236, 0.02008056984777795, 0.01197772358864313, 0.3742284409236163, 6.010533627122641, 23.35110168904066, 48.20425137877464, 36.65015436708927, 20.149904564023018, 19.802814088761806, 24.886747486889362, 4.699772112071514, 0.48681176849640906, 0.24567062209825963, 3.893167544156313, 6.654960047453642, 6.136810826137662, 29.29453756660223, 19.3188264593482, 13.313400708138943, 9.720018077641726, 31.628030352294445, 47.51733183860779, 53.69567111134529, 51.54879771173, 51.08887039124966, 48.5917279869318, 49.66314509510994, 50.74378050863743, 53.974291160702705, 53.13402704894543, 50.69248326122761, 54.11142200231552, 47.63714320957661, 46.045853197574615, 39.42357234656811, 35.437282249331474, 36.02197587490082, 34.86359663307667, 35.36553829908371, 34.87344570457935, 36.51725269854069, 35.92402473092079, 37.0148815959692, 35.97983993589878, 37.8863762319088, 36.84603005647659, 37.012537121772766, 38.91146242618561, 39.51251417398453, 41.135084107518196, 39.32804547250271, 37.71043427288532, 38.21923077106476, 34.40731331706047, 36.022386252880096, 35.32661698758602, 37.40334615111351, 36.33935384452343, 44.31391753256321, 49.42391753196716, 49.802453219890594, 49.31424021720886, 49.06146638095379, 44.16126072406769, 50.70391304790974, 40.06544530391693, 46.880106031894684, 51.91586181521416, 47.25314721465111, 46.584751680493355, 42.60405868291855, 41.70577548444271, 39.692008942365646, 37.67204873263836, 35.14011159539223, 35.66563479602337, 36.25315546989441, 36.236953139305115, 41.612661480903625, 49.61624041199684, 51.33233852684498, 47.020466700196266, 46.0912911593914, 49.33244124054909, 50.30703194439411, 50.84762513637543, 49.91583153605461, 49.34220291674137, 50.15577346086502, 47.91429653763771, 46.90188646316528, 42.84679725766182, 35.65414421260357, 33.46953123807907, 35.112908855080605, 35.06497822701931, 43.05715397000313, 49.71232205629349, 49.744776114821434, 50.11527143418789, 48.881667628884315, 45.21082140505314, 46.325172409415245, 47.62928903102875, 45.25305233895779, 46.369094252586365, 50.309520810842514, 50.19884794950485, 51.46233335137367, 50.48693709075451, 36.35160058736801, 22.34565284103155, 10.438493024557829, 16.561529114842415, 32.52665363252163, 39.50102739036083, 31.587433330714703, 9.886798728257418, 0.5978368234355003, 0.021847244970558677, 0.17094556853407994, 0.007814838227204746, 0.1604273173143156, 4.265871020033956, 18.365252427756786, 24.44357916712761, 29.488325268030167, 35.45118570327759, 27.09513958543539, 6.152275996282697, 0.28009425150230527, 0.025289633886131924, 0.09501474763965234, 0.02144792499166215, 0.0999733924982138, 0.015815768128959462, 0.045646575817954727, 0.024493628552590962, 0.01560563272505533, 0.04012237361166626, 0.012411421703291126, 0.04724265345430467, 0.022177905157150235, 0.057053526616073214, 0.051369532593525946, 0.0408535375026986, 0.013452341336233076, 0.03345127493957989, 0.03129697979602497, 0.11114376145997085, 0.011928639796678908, 0.07593224581796676, 0.08622887689853087, 0.044290575533523224, 0.11055846669478342, 0.04584092945151497, 0.028466443400247954, 0.011517340626596706, 0.05258305536699481, 0.04641552615794353, 0.0359938543260796, 0.026937023612845223, 0.02372327184275491, 0.03511114016873762, 0.05403002811362967, 0.017537205640110187, 0.012062590030836873, 0.05852390670042951, 0.015854786543059163, 0.04442143101186957, 0.10245866695186123, 0.020923618067172356, 0.06489671024610288, 0.046711086470168084, 0.06303179703536443, 0.03608214021369349, 0.023583130241604522, 0.011312359438306885, 0.8432764001190662, 9.600489791482687, 31.41553435474634, 53.65615703165531, 40.04531018435955, 23.61563589423895, 24.286288507282734, 23.839255794882774, 5.05211865529418, 0.329034942551516, 0.2540665090782568, 2.69888901617378, 7.704259967431426, 8.716939352452755, 32.096672505140305, 26.62445694208145, 18.64187378436327, 14.983318001031876, 34.69818390905857, 49.26225520670414, 56.36647939682007, 54.23436440527439, 51.94624498486519, 50.57047560811043, 51.879611760377884, 52.89041452109814, 55.79833008348942, 54.186817556619644, 50.39331391453743, 54.56157244741917, 51.325673684477806, 48.633320555090904, 43.60475018620491, 36.619072034955025, 38.974375650286674, 37.63792276382446, 37.82182149589062, 36.18636645376682, 37.48188033699989, 37.432581782341, 39.333418384194374, 38.423496410250664, 39.681992679834366, 39.05672863125801, 40.36776468157768, 40.871404856443405, 42.61851690709591, 41.47570163011551, 42.17177487909794, 39.5720873773098, 39.166246354579926, 35.74753940105438, 38.10955725610256, 37.36806124448776, 37.95955650508404, 38.72937619686127, 45.134198516607285, 50.80024167895317, 52.12062902748585, 51.229288056492805, 52.57553681731224, 44.858093932271004, 50.93932181596756, 41.4211555570364, 49.13604877889156, 53.54888878762722, 49.834652692079544, 48.65991532802582, 46.475298553705215, 43.36194321513176, 42.458321303129196, 38.88493984937668, 37.2285745292902, 36.474417597055435, 38.36197391152382, 38.102485835552216, 42.440329268574715, 50.2668908983469, 52.370944395661354, 49.934374541044235, 47.13585130870342, 50.212732404470444, 51.63327097892761, 51.504492089152336, 50.06757639348507, 51.0270819067955, 51.347932890057564, 50.80449365079403, 49.19937618076801, 44.83113817870617, 37.34928645193577, 35.72241894900799, 36.66761822998524, 37.59390972554684, 46.394940465688705, 52.082596868276596, 52.88402706384659, 52.381150647997856, 50.42746268212795, 47.68871784210205, 48.50912041962147, 48.375113010406494, 47.3541571944952, 48.71622450649738, 51.83510094881058, 52.55822874605656, 52.049846425652504, 50.932166799902916, 37.06355318427086, 24.609368070960045, 12.713863179087639, 19.36767663806677, 31.26173570752144, 35.71595549583435, 36.543988063931465, 14.143550712615252, 0.22591849527088925, 0.06011421784933191, 0.18928363686427474, 0.06448333399021067, 0.58680304675363, 5.942232767120004, 25.963799692690372, 29.018761664628983, 36.15072436630726, 39.42660078406334, 32.28802263736725, 8.764474801719189, 0.4089215293060988, 0.021233872903394513, 0.010602400561765535, 0.007710919462624588, 0.005816920556753757, 0.0657453783787787, 0.06358874175930396, 0.021879613741475623, 0.021901291875110473, 0.05707277792680543, 0.06873798498418182, 0.04045413588755764, 0.07321030047023669, 0.02233206407254329, 0.04816524691705126, 0.008404224081459688, 0.053568467919831164, 0.028854451193183195, 0.039060089402482845, 0.02218299443484284, 0.06640445746597834, 0.048977583210216835, 0.2283432995318435, 0.12727175111649558, 0.24222140171332285, 0.14695983059937134, 0.11698357309796847, 0.1394238998182118, 0.0811429091845639, 0.16937669803155586, 0.11646927960100584, 0.08664773020427674, 0.27826456062030047, 0.1126476569334045, 0.16493504808750004, 0.1361682909191586, 0.10607832155073993, 0.12176491145510226, 0.10331444485927932, 0.14173855452099815, 0.18210948823252693, 0.13296975317643955, 0.1471948836115189, 0.1118208524712827, 0.21646635403158143, 0.18471613351721317, 0.1733751522260718, 0.11203514019143768, 0.7092219684273005, 9.548911359161139, 35.28306372463703, 61.95287883281708, 49.860301315784454, 30.24560183286667, 30.555798187851906, 33.98618571460247, 6.688068620860577, 0.8971640991512686, 0.4840394906932488, 7.477047834545374, 14.116253927350044, 10.069889053702354, 35.96103474497795, 24.26037199795246, 16.095286533236504, 14.99439250677824, 36.27471171319485, 48.32365617156029, 57.830955013632774, 57.298197001218796, 56.07858404517174, 51.48721061646938, 54.02423568069935, 55.48508249223232, 58.90236832201481, 54.644202813506126, 52.00269475579262, 57.31872349977493, 53.25901374220848, 49.68929149210453, 44.6020370721817, 38.22822108864784, 40.612399354577065, 37.98450596630573, 39.500875398516655, 37.6021970808506, 39.60554078221321, 39.257931634783745, 41.091872826218605, 40.723440796136856, 42.37714245915413, 41.36849418282509, 41.012415289878845, 42.75419622659683, 44.40140403807163, 45.390658155083656, 43.995380625128746, 41.36223591864109, 41.76426574587822, 36.42861485481262, 37.51126416027546, 38.35657820105553, 40.8975550532341, 40.52138663828373, 48.38126488029957, 53.48369188606739, 54.83528696000576, 54.606463238596916, 54.08420406281948, 46.818279549479485, 51.106543242931366, 45.25130443274975, 50.657004565000534, 53.49506847560406, 53.171823620796204, 50.20773947238922, 46.923514902591705, 45.471966192126274, 44.71212096512318, 41.69297017157078, 38.35712917149067, 39.273351207375526, 39.35961037874222, 38.83053816854954, 45.329508036375046, 53.162160739302635, 52.36390717327595, 48.814977407455444, 46.89800687134266, 50.614283457398415, 52.776850014925, 52.765910401940346, 52.17683561146259, 53.75577248632908, 54.23047721385956, 51.777610033750534, 52.104745879769325, 46.205076053738594, 39.29872624576092, 38.0947570502758, 39.34246949851513, 39.218789935112, 47.41908811032772, 53.984486013650894, 54.52963896095753, 54.21989858150482, 51.23732842504978, 50.03045238554478, 49.782808274030685, 49.25339788198471, 49.252869710326195, 51.064300909638405, 53.91746520996094, 53.37653763592243, 53.12684163451195, 50.41174292564392, 40.11620298027992, 26.110901199281216, 20.82260526716709, 25.767251439392567, 37.077297046780586, 49.68646824359894, 37.83137418329716, 13.372585382312536, 2.4731333926320076, 0.26795408106409013, 0.6194621161557734, 0.20142339169979095, 0.6516928772907704, 11.317136976867914, 31.991847530007362, 34.8734875023365, 43.02270121872425, 46.62822134792805, 36.81587867438793, 10.23825041949749, 0.5194339680019766, 0.11746264426619746, 0.2158519151271321, 0.15137734590098262, 0.24249804468126968, 0.16098380932817236, 0.17637084616580978, 0.11464872455690056, 0.14934117469238117, 0.2472237145411782, 0.18137127393856645, 0.11899700490175746, 0.15750414604553953, 0.12923658709041774, 0.23748977982904762, 0.1441233273362741, 0.15261376393027604, 0.12804961093934253, 0.09353106084745377, 0.20605161756975576, 0.13883568841265514, 0.22867349587613717], [0.021319312654668465, 0.05066993966465816, 0.029729510097240563, 0.07547986228018999, 0.02696904914046172, 0.09173090002150275, 0.035070314625045285, 0.01811439244193025, 0.011360608314134879, 0.016559938158025034, 0.07426237643812783, 0.11605147272348404, 0.027365096248104237, 0.07891133791417815, 0.05360709299566224, 0.007824381318641827, 0.07298787881154567, 0.01876392194390064, 0.04848638905968983, 0.07601762990816496, 0.07687218327191658, 0.07945884994114749, 0.014833796358288964, 0.037473370248335414, 0.12189241242595017, 0.004924938366457354, 0.07409908168483526, 2.6203797664493322, 11.934856530278921, 38.81159618496895, 43.2299192994833, 27.08727590739727, 35.00629797577858, 25.019681453704834, 6.29638041369617, 0.5486314825247973, 0.49645286053419113, 2.4189953226596117, 4.607929140329361, 7.179550873115659, 8.498994447290897, 0.997713531833142, 2.150990953668952, 4.180880030617118, 19.430120587348938, 37.23240092396736, 51.83227390050888, 54.79608826339245, 54.08397227525711, 54.0404000133276, 52.873193845152855, 50.70987492799759, 54.799120500683784, 52.301039546728134, 55.3744438290596, 51.03854589164257, 50.76038561761379, 45.88285334408283, 37.725416868925095, 36.517001911997795, 38.04636284708977, 41.031414270401, 43.19535635411739, 45.43367184698582, 42.90906831622124, 38.632090017199516, 38.9752534031868, 36.79418943822384, 36.3152289390564, 36.424613669514656, 36.55946083366871, 39.574477449059486, 40.191701129078865, 38.2816082239151, 40.014212653040886, 37.37155705690384, 37.093810960650444, 36.54979795217514, 38.92525568604469, 36.73449084162712, 37.04572834074497, 42.13775910437107, 51.44028693437576, 47.92539194226265, 52.206774204969406, 46.1668349057436, 46.438356935977936, 45.68428359925747, 46.782504469156265, 38.20705622434616, 47.47372157871723, 50.050766095519066, 45.27306206524372, 44.15963441133499, 39.39673438668251, 35.32463729381561, 35.37634491920471, 36.882648691534996, 34.71695490181446, 35.572383999824524, 35.050140023231506, 37.8728299587965, 43.26280273497105, 48.200755566358566, 44.15441729128361, 45.05775421857834, 48.719921708106995, 49.650491774082184, 49.678697660565376, 49.2633381485939, 47.20547877252102, 47.42185056209564, 47.47538208961487, 44.24715131521225, 39.923230335116386, 35.528325363993645, 33.4078149497509, 34.22137029469013, 34.07242588698864, 35.67923806607723, 43.217885345220566, 48.746273294091225, 50.87148405611515, 49.15421940386295, 50.180593729019165, 52.38797128200531, 48.249624744057655, 48.7447115778923, 46.318800151348114, 48.301590755581856, 49.92965519428253, 51.84805445373058, 49.68027837574482, 43.151970282197, 31.803212352097034, 17.708210684359074, 6.803055675700307, 2.2934928070753813, 11.240002065896988, 18.435330167412758, 10.671499371528625, 0.4796459467615932, 0.42675325996242464, 0.10405869281385094, 0.09535506687825546, 0.32861862739082426, 1.4401684398762882, 8.524778913706541, 15.395597778260708, 28.67301631718874, 32.440949231386185, 29.83429290354252, 16.78562019020319, 1.897279042750597, 0.11861128848977387, 0.06855920160887763, 0.03590268148400355, 0.034388403364573605, 0.03850402412354015, 0.0878180080326274, 0.018913627973233815, 0.04720783188531641, 0.023203725795610808, 0.0657787304953672, 0.09485273680184036, 0.013639272565342253, 0.02100212986988481, 0.05106181590235792, 0.08563610128476284, 0.04925585148157552, 0.04528084544290323, 0.011199546497664414, 0.1047629835375119, 0.057695365612744354, 0.008257619301730301, 0.06884541086037643, 0.028408030811988283, 0.03767228437936865, 0.021663559709850233, 0.045943876466481015, 0.018139586500183214, 0.09422514704056084, 0.05431484212749638, 0.04968666449713055, 0.01379606888804119, 0.05281563331664074, 0.049411490981583484, 0.07234569842694327, 0.06697329139569774, 0.027538525027921423, 0.06131446731160395, 0.018694521859288216, 0.029960527681396343, 0.02983775790198706, 0.05884001337108202, 0.03135369101073593, 0.017642490420257673, 0.042974157695425674, 0.006996545271249488, 0.00688938424900698, 0.06168400861497503, 0.054493080024258234, 0.09124802905716933, 3.0911863781511784, 16.01114384829998, 46.70764848589897, 48.22386972606182, 30.232633128762245, 31.966278702020645, 32.12813101708889, 7.89035165682435, 0.6624493282288313, 0.19437160837696865, 1.6121177631430328, 4.169072639197111, 9.157360419631004, 14.434601794928312, 2.0385509496554732, 3.728071628138423, 7.077110270038247, 24.903850369155407, 41.78712911903858, 54.57003839313984, 54.79638084769249, 54.378927648067474, 55.88479824364185, 55.982574597001076, 53.36372472345829, 55.65544635057449, 53.007892817258835, 55.83065114915371, 53.43942806124687, 53.13395105302334, 49.407240226864815, 40.4591079801321, 38.10628943145275, 39.74628522992134, 42.12624952197075, 44.65382069349289, 46.07980437576771, 43.5477190464735, 39.762795343995094, 40.19356682896614, 38.74439299106598, 38.6946764588356, 38.582825660705566, 38.980010747909546, 39.98401567339897, 41.647296622395515, 41.07689402997494, 42.01338417828083, 39.06237132847309, 38.73020455241203, 37.41139031946659, 39.78935971856117, 37.87680074572563, 38.29280622303486, 43.25866475701332, 52.62531414628029, 50.32456040382385, 53.353370279073715, 49.220480248332024, 47.57238708436489, 48.030923679471016, 48.3166341483593, 40.25868393480778, 49.48552742600441, 51.51061736047268, 47.93950438499451, 47.27268196642399, 41.9322357326746, 37.165182530879974, 36.71281300485134, 38.000252321362495, 36.435914263129234, 36.92348890006542, 37.38061957061291, 38.798798471689224, 44.791996479034424, 51.638305708765984, 45.97949355840683, 46.35366328060627, 50.36643035709858, 51.53457127511501, 51.58230811357498, 52.11228847503662, 50.37072412669659, 50.03016360104084, 50.235063806176186, 47.278450056910515, 44.40591059625149, 37.41368159651756, 35.80676682293415, 35.75084902346134, 36.503315046429634, 39.14871409535408, 44.847857281565666, 50.620397329330444, 52.77651563286781, 49.733612313866615, 50.42660012841225, 52.28476122021675, 49.6949227899313, 49.46593567728996, 47.91888289153576, 50.079321563243866, 51.03406213223934, 53.08487668633461, 49.60463583469391, 45.13036832213402, 35.24207912385464, 22.563310861587524, 10.923075322061777, 3.7469673017039895, 16.24717578291893, 26.588197387754917, 17.14807704091072, 2.4356567161157727, 0.6931900349445641, 0.2308831812115386, 0.0699868710944429, 0.17031223454978317, 1.8580444855615497, 11.834875345230103, 20.782834701240063, 31.862988844513893, 36.039268746972084, 36.141494661569595, 23.646530136466026, 3.0678192945197225, 0.11751166312023997, 0.07308021682547405, 0.03882847253407817, 0.02173419918108266, 0.025230475439457223, 0.010621133296808694, 0.007022566360319615, 0.019783447314694058, 0.059710348505177535, 0.08639347783173434, 0.011743186369130854, 0.019200922615709715, 0.05803926942462567, 0.04164684512943495, 0.08613530691945925, 0.034898384983534925, 0.03820887199253775, 0.054326386234606616, 0.037440678643179126, 0.09181377565255389, 0.02641140679770615, 0.06067783819162287, 0.15407986182253808, 0.07008649699855596, 0.11220691027119756, 0.14662259869510308, 0.1658126080292277, 0.15771602920722216, 0.1879426056984812, 0.14000936527736485, 0.16853165900101885, 0.22777897043852136, 0.1867501376545988, 0.19283843517769128, 0.08883657603291795, 0.19018730556126684, 0.13186380470870063, 0.12137992976931855, 0.16601404175162315, 0.08614453923655674, 0.16099166125059128, 0.1314371291664429, 0.21881259453948587, 0.14930564066162333, 0.08702402134076692, 0.12623215065104887, 0.2160984417423606, 0.11013320865458809, 0.17850122560048476, 3.40095026884228, 19.16635014116764, 53.496421203017235, 56.909413263201714, 38.38964022696018, 44.062378630042076, 36.23155742883682, 9.321491662412882, 1.2221423140726984, 0.904151686700061, 5.877435794100165, 12.099080868065357, 12.404959704726934, 12.779687996953726, 1.922337629366666, 3.737898850813508, 7.632769178599119, 24.506262503564358, 42.15779162943363, 54.74433124065399, 54.788925647735596, 57.99954816699028, 58.37096303701401, 56.970031410455704, 53.52069430053234, 55.80159030854702, 53.76940995454788, 60.1748326420784, 55.00283896923065, 55.16371473670006, 50.98425820469856, 42.88221895694733, 41.0248102247715, 42.53039203584194, 45.380322709679604, 49.22943636775017, 49.31617051362991, 47.52151161432266, 42.94572114944458, 42.48920984566212, 40.8928395062685, 39.0945366024971, 40.4304651170969, 39.37747322022915, 42.141099125146866, 44.16149251163006, 42.74288423359394, 44.051898792386055, 41.24846242368221, 40.57950831949711, 39.53476957976818, 41.53929501771927, 40.202051773667336, 40.98393961787224, 45.30925512313843, 55.90051420032978, 54.51670445501804, 55.399891063570976, 50.11608839035034, 49.400415793061256, 49.26851347088814, 48.896338641643524, 43.28380800783634, 51.581342965364456, 53.097043633461, 49.10428248345852, 48.83688323199749, 44.324811547994614, 38.60325336456299, 37.991102412343025, 40.22361561655998, 37.953123450279236, 38.24900597333908, 38.89170728623867, 40.67358747124672, 47.19614267349243, 52.491606920957565, 47.58642353117466, 48.0424028635025, 50.07773704826832, 55.409211963415146, 54.194166362285614, 53.42783108353615, 51.52449041604996, 51.93593613803387, 52.570771872997284, 47.60299824178219, 44.98230166733265, 39.82258893549442, 36.595627292990685, 38.15152980387211, 38.70253823697567, 41.599643379449844, 47.22671963274479, 53.38598392903805, 53.95581655204296, 51.70954428613186, 51.17730684578419, 54.643344059586525, 50.93262657523155, 51.24847322702408, 49.37333084642887, 51.24658852815628, 53.984041437506676, 54.78607960045338, 50.28440035879612, 47.3033881187439, 39.33079272508621, 25.499002933502197, 10.060453210026026, 3.290334641933441, 15.643758662045002, 28.07561807334423, 14.422660935670137, 3.336549187079072, 1.0742211202159524, 0.5789907253347337, 0.4790779366157949, 1.048119014594704, 2.6549849845469, 16.3757361844182, 26.246327832341194, 38.81304390728474, 43.09192970395088, 40.41492395102978, 25.623915530741215, 3.425559173338115, 0.1768750761402771, 0.14138210099190474, 0.10919500782620162, 0.09341219105408527, 0.10883845781791024, 0.1581201286171563, 0.13556179299484938, 0.09701485789264552, 0.09641569980885834, 0.1335385351558216, 0.1673928927630186, 0.11334381371852942, 0.14062537753488868, 0.19169963925378397, 0.3084326855605468, 0.14952421799534932, 0.15076776064233854, 0.10913035192061216, 0.22288410575129092, 0.16072696686023846, 0.10551357685471885, 0.17596962628886104], [0.037702129848184995, 0.03614492219639942, 0.018739483020908665, 0.034066025546053424, 0.05057443639088888, 0.009526153771730606, 0.07907647319370881, 0.0357365925447084, 0.05437172774691135, 0.037067782832309604, 0.02885807101847604, 0.03977030617534183, 0.020092694685445167, 0.02311521540832473, 0.06215917237568647, 0.03804506886808667, 0.030053440859774128, 0.07209586925455369, 0.03441313543589786, 0.08538591588148847, 0.10473590999026783, 0.06415054755052552, 0.024010683373489883, 0.02505427288269857, 0.025619689222367015, 0.04668763460358605, 0.04482966789510101, 0.83658003131859, 5.633169701322913, 27.753771543502808, 44.58292029798031, 34.1463965177536, 22.10082057863474, 22.846473567187786, 13.399432841688395, 2.676626010797918, 0.06142006008303724, 1.1893397429957986, 2.884621862322092, 7.033460587263107, 1.721436115913093, 0.7016982533968985, 0.8483937755227089, 0.6142285501118749, 6.0144459921866655, 19.52820472419262, 39.44917917251587, 49.275858476758, 56.33475869894028, 50.3994619846344, 54.16372999548912, 51.872992515563965, 53.107348680496216, 53.0868411809206, 52.040730714797974, 50.03366321325302, 47.191548720002174, 39.53115597367287, 38.02754245698452, 39.03915457427502, 47.45111659169197, 49.84620027244091, 52.332604452967644, 49.2432676255703, 47.92312726378441, 45.1907242834568, 39.68169629573822, 37.43153303861618, 37.638010159134865, 35.50733529031277, 38.732891008257866, 40.03210209310055, 39.69287529587746, 39.66279610991478, 38.91761429607868, 38.009504824876785, 36.76330469548702, 36.17945842444897, 40.814730897545815, 36.593320816755295, 39.88978452980518, 49.089520275592804, 50.162833482027054, 49.16798986494541, 50.98056100308895, 44.221362099051476, 48.920307755470276, 48.05714227259159, 64.20523837208748, 43.91201689839363, 42.418925017118454, 52.712401673197746, 44.368247017264366, 46.77441470324993, 41.45972728729248, 38.36321644484997, 33.82279448211193, 35.45946925878525, 33.989259749650955, 36.664426401257515, 34.1121793538332, 38.30363564193249, 45.149025321006775, 47.3551869392395, 49.13321793079376, 48.38262900710106, 49.225788563489914, 48.2071278244257, 45.686981454491615, 43.09568390250206, 40.487956032156944, 39.25820901989937, 38.39581869542599, 36.90363496541977, 33.4482865780592, 35.76617740094662, 34.25808772444725, 34.28536266088486, 34.560281708836555, 36.621268317103386, 42.00404807925224, 46.78897552192211, 47.5328616052866, 52.06475302577019, 47.15134687721729, 49.021538123488426, 49.490410163998604, 50.60974270105362, 49.186479672789574, 49.88978013396263, 51.75580680370331, 48.39131914079189, 48.54475110769272, 35.560327246785164, 13.6280732229352, 2.846939046867192, 0.5269363091792911, 0.5914599937386811, 0.23575515806442127, 0.4393062723102048, 0.33702214364893734, 0.0987806127523072, 0.11632192617980763, 0.043850285292137414, 0.07206495138234459, 0.5842923314776272, 4.181535020470619, 10.523359570652246, 26.445959620177746, 26.822950690984726, 32.12540276348591, 29.091668352484703, 7.457897812128067, 0.6022555707022548, 0.018435677447996568, 0.03490347611659672, 0.02923034528066637, 0.05886846731300466, 0.06057093181880191, 0.08882910260581411, 0.06443867896450683, 0.015174117452261271, 0.034110988563043065, 0.018069264297082555, 0.037264926941134036, 0.011460197110864101, 0.025710246081871446, 0.029047485659248196, 0.02099228157021571, 0.0160232466441812, 0.040984756633406505, 0.06051176409528125, 0.02322427957551554, 0.05851281530340202, 0.0952728814445436, 0.04520659727859311, 0.030429038088186644, 0.010320909514121013, 0.0335988918232033, 0.042931547286571003, 0.03292786415840965, 0.05158540479897056, 0.04193097636743914, 0.03938437454053201, 0.06048028590157628, 0.02332992800802458, 0.0077451269044104265, 0.0593708307860652, 0.02826594478392508, 0.03985947150795255, 0.02497674257028848, 0.033283668308285996, 0.03965061630879063, 0.04298101513995789, 0.00579700780690473, 0.014913749782863306, 0.04341182815551292, 0.006374715503625339, 0.01109927863581106, 0.02877015434933128, 0.03409635341085959, 0.01463755117583787, 0.025619618718337733, 1.0347849363461137, 8.890297450125217, 34.705262929201126, 51.878095641732216, 37.48536095023155, 27.965260595083237, 27.244376577436924, 13.133265674114227, 2.9772889148443937, 0.05959363465080969, 0.6176471791695803, 1.1707567214034498, 6.338783763349056, 3.606808972544968, 0.9049217985011637, 0.7816615188494325, 1.02345121325925, 8.839447628706694, 26.034591794013977, 43.794265016913414, 50.76529875397682, 57.8308068215847, 52.2490469366312, 53.79216693341732, 52.096496522426605, 53.27968083322048, 55.22494465112686, 55.29908627271652, 50.775060430169106, 51.13381437957287, 41.48534171283245, 39.784594774246216, 40.43102748692036, 48.26365739107132, 50.673693269491196, 53.144666478037834, 51.03996321558952, 49.20773573219776, 45.316679924726486, 41.04746460914612, 37.95839376747608, 39.20433171093464, 37.16903932392597, 40.63509173691273, 40.866259932518005, 42.14414656162262, 39.35203738510609, 41.0146077722311, 38.43049183487892, 38.20624306797981, 37.2231750190258, 41.74447640776634, 38.7018770724535, 42.58341059088707, 48.25803369283676, 51.95940747857094, 51.28234840929508, 53.04170720279217, 47.234003841876984, 49.564722776412964, 48.215529173612595, 57.43826888501644, 43.979421481490135, 45.60825727880001, 54.961329996585846, 46.82699628174305, 48.90648789703846, 41.20080158114433, 38.70413415133953, 35.92774473130703, 38.453454002738, 36.145096868276596, 36.836298778653145, 37.23153077065945, 40.337480306625366, 45.32459110021591, 49.159109741449356, 50.22008880972862, 50.40561385452747, 50.89475400745869, 49.93959166109562, 48.45992065966129, 46.745562851428986, 42.98593059182167, 41.97780288755894, 41.72536723315716, 40.07037363946438, 35.567562058568, 36.9990174472332, 36.812827438116074, 37.700524404644966, 38.58266606926918, 37.468299865722656, 44.49004948139191, 49.53747823834419, 49.71689321100712, 52.53968574106693, 48.32282021641731, 49.5708404481411, 51.22853569686413, 51.34369611740112, 51.11709527671337, 52.91618853807449, 52.036520540714264, 50.021781250834465, 49.28156957030296, 40.106608495116234, 18.64837523549795, 4.092989321798086, 0.6525290105491877, 1.4799137134104967, 0.25591944402549416, 0.7341709546744823, 0.15442512376466766, 0.19119346485240385, 0.10142873667064123, 0.0753012570203282, 0.08440551653620787, 0.8440977497957647, 5.333435134962201, 13.884942289441824, 26.263238824903965, 32.20082111656666, 36.771402060985565, 33.54595273733139, 11.288676504045725, 0.7654376956634223, 0.05330110921931919, 0.035197281249566004, 0.0351026017597178, 0.03847329178825021, 0.09971151826903224, 0.016222368576563895, 0.03947010001866147, 0.03135626255243551, 0.018780000573315192, 0.03822235310508404, 0.03540054807672277, 0.02032560845691478, 0.036441083648242056, 0.03010953794728266, 0.0504272981925169, 0.03358962610946037, 0.04792228261067066, 0.014252716064220294, 0.046053376645431854, 0.02051466130069457, 0.02719680684094783, 0.034390937798889354, 0.09596675241482444, 0.12434301374014467, 0.12529630243079737, 0.11055249982746318, 0.1002225092088338, 0.09788502604351379, 0.12104378140065819, 0.15250845317495987, 0.20527466316707432, 0.10413949043140747, 0.14552923705196008, 0.10427978602820076, 0.10877855907892808, 0.12438896010280587, 0.1280663241050206, 0.21922985964920372, 0.17089320259401575, 0.1503504510037601, 0.12654024583753198, 0.2215928430086933, 0.14479887468041852, 0.1342472416581586, 0.13123952492605895, 0.1230304068303667, 0.10301299931597896, 0.09794897690881044, 0.17004191468004137, 1.2957875872962177, 9.824084993451834, 38.87338846921921, 57.909899577498436, 48.188079446554184, 31.485855281352997, 33.086291402578354, 16.344665251672268, 3.9970810431987047, 0.15527966228546575, 2.6572935981675982, 9.482117593288422, 14.566196333616972, 5.004883389919996, 2.1271215844899416, 3.331951671279967, 1.2372316606342793, 8.736816085875034, 25.565879344940186, 46.193783059716225, 51.11826941370964, 58.32536168396473, 51.76813714206219, 53.8965967297554, 51.7207270860672, 55.685187354683876, 57.697217389941216, 56.9559645652771, 54.92937371134758, 50.81592723727226, 43.06850016117096, 42.05957069993019, 42.713329419493675, 53.06567631661892, 53.23009729385376, 55.609244629740715, 52.0412702858448, 51.142987087368965, 48.65397624671459, 43.553346544504166, 40.30811168253422, 40.73755323886871, 39.044538885354996, 42.950657084584236, 44.130345582962036, 44.70938891172409, 42.25348949432373, 42.52407297492027, 41.34203240275383, 39.7319296002388, 37.52300553023815, 44.35474254190922, 39.97737742960453, 44.03677560389042, 52.58961886167526, 54.653257727622986, 51.629919558763504, 54.64404322206974, 49.806784987449646, 49.99300539493561, 50.31483292579651, 56.98619954288006, 46.54562518000603, 48.73011276125908, 55.52678145468235, 48.29132750630379, 50.854544565081596, 45.40164336562157, 41.05445243418217, 37.53890387713909, 38.62746946513653, 37.62763671576977, 38.798619881272316, 38.77983368933201, 42.07920424640179, 50.243750140070915, 51.27549737691879, 52.564958184957504, 51.15885503590107, 54.171743765473366, 50.79401381313801, 50.04672311246395, 47.75816671550274, 43.6476194858551, 42.39051394164562, 42.16341532766819, 42.14175269007683, 36.670840457081795, 39.436723440885544, 39.176011830568314, 39.832263216376305, 39.23532284796238, 39.89624038338661, 45.915356799960136, 51.54304102063179, 50.89101500809193, 54.4951444119215, 48.681847751140594, 50.04938296973705, 50.99405027925968, 52.165200635790825, 51.54955007135868, 53.466357216238976, 52.913334891200066, 50.08960761129856, 51.873300299048424, 41.85658559203148, 18.490647599101067, 5.589449722319841, 1.6118245851248503, 2.1149468002840877, 2.1614852780476213, 1.7844158364459872, 0.8829093421809375, 0.4535422974731773, 0.31062006193678826, 0.37277896713931113, 0.5251618637703359, 2.5354379368945956, 10.459904875606298, 19.604297541081905, 38.307131454348564, 39.079352617263794, 44.3774539232254, 37.72875688970089, 13.241248279809952, 1.296237031929195, 0.08893979393178597, 0.14720402687089518, 0.1189943628560286, 0.1987389544956386, 0.20480191509705037, 0.16636614629533142, 0.08174228991265409, 0.10338890453567728, 0.07110842692782171, 0.18277740629855543, 0.13548570801503956, 0.0634448096388951, 0.12023803166812286, 0.1429766498040408, 0.08415188014623709, 0.16431636409834027, 0.13144756376277655, 0.1605198928155005, 0.10937061480944976, 0.1299471192760393, 0.11878441669978201, 0.12644758127862588], [0.03757378282898571, 0.022801752638770267, 0.04107818560441956, 0.05627829028526321, 0.012340582779870601, 0.029944003763375804, 0.06941764382645488, 0.021501843875739723, 0.01822528229240561, 0.040017890351009555, 0.04201470917905681, 0.02903552223870065, 0.10523824748815969, 0.07109263402526267, 0.030498410342261195, 0.029590118065243587, 0.02917523896030616, 0.0694106008450035, 0.007006868081589346, 0.008636930051579839, 0.056974209583131596, 0.02872685745387571, 0.07280280202394351, 0.07961018869536929, 0.07225618799566291, 0.03325870988192037, 0.06497179332654923, 0.18329287238884717, 1.705539550166577, 13.399181105196476, 33.28803777694702, 35.568808391690254, 31.570381745696068, 32.34481059014797, 16.3880817219615, 4.262539548799396, 0.659680642420426, 0.07527822075644508, 0.46961585059762, 2.137410482391715, 1.0900672199204564, 0.34398253890685737, 0.47951414133422077, 0.21560635330388322, 2.3074176348745823, 9.554687049239874, 26.82403553277254, 42.5658593326807, 50.23371867835522, 51.273244097828865, 52.23528787493706, 53.37152570486069, 53.21436233818531, 51.7466226965189, 50.6014933437109, 47.118771225214005, 41.29533290863037, 42.24829137325287, 42.50418484210968, 49.43875953555107, 52.92012132704258, 50.19723303616047, 50.63660725951195, 48.624170646071434, 49.88646671175957, 48.45584727823734, 44.46504682302475, 39.288622587919235, 38.367681205272675, 37.28445053100586, 37.6543340831995, 37.82878652215004, 38.49672228097916, 38.970439061522484, 39.330047965049744, 36.05022355914116, 37.86928094923496, 40.9309134632349, 45.027359649538994, 40.71636937558651, 43.59418295323849, 51.319730803370476, 51.83523394167423, 49.00490641593933, 46.218462735414505, 47.966137155890465, 46.49228744208813, 47.807959243655205, 56.51011548936367, 43.71659718453884, 46.034997180104256, 52.52980247139931, 47.12752975523472, 48.56417566537857, 42.49484494328499, 42.20099911093712, 38.53969797492027, 37.24455647170544, 36.149538829922676, 36.360256522893906, 35.0778329372406, 39.079352617263794, 45.58928869664669, 49.655629098415375, 50.0418783724308, 48.598009049892426, 46.892892345786095, 44.49915759265423, 38.90499137341976, 37.0978919416666, 36.19433082640171, 36.17034271359444, 33.99011850357056, 33.93863886594772, 35.89738056063652, 32.93753318488598, 34.0023348480463, 35.35506226122379, 35.08904993534088, 36.94863975048065, 42.2030434012413, 47.29285888373852, 47.93402887880802, 48.08161675930023, 47.77434624731541, 47.16688044369221, 48.24897117912769, 47.255073711276054, 51.08829662203789, 51.08042724430561, 48.84157218039036, 46.81602627038956, 38.794717490673065, 19.17628850787878, 4.336890634149313, 0.32897904398851097, 0.0811715486634057, 0.3746652393601835, 0.44337101513519883, 0.1140660941018723, 0.18572358414530754, 0.09008866079966538, 0.12500218930654228, 0.04306216156692244, 0.3984666574979201, 0.9972537565045059, 7.1794335544109344, 21.91147293895483, 28.984326012432575, 30.103261470794678, 31.7652390897274, 21.29548989236355, 4.469678308814764, 0.036854760473943315, 0.06567831049324013, 0.041326137143187225, 0.06559349785675295, 0.07519314836827107, 0.015789087919984013, 0.022978146298555657, 0.01871838561783079, 0.013082704481348628, 0.05628079503367189, 0.029039976980129723, 0.03569986736692954, 0.031205087070702575, 0.05194625926378649, 0.02874500110920053, 0.009171219790005125, 0.0030455915430138703, 0.026271306014677975, 0.00796275382526801, 0.08389475566218607, 0.041127605218207464, 0.04378899131552316, 0.0531352503458038, 0.025572696431481745, 0.0584150855866028, 0.041460907450527884, 0.02738180941378232, 0.029035102925263345, 0.02734783018240705, 0.06780363590223715, 0.032644731109030545, 0.045937256509205326, 0.031143132582656108, 0.04467476683203131, 0.02909108869062038, 0.08468530621030368, 0.11121551229734905, 0.002918025634244259, 0.023265793461177964, 0.05768805916886777, 0.03528632783854846, 0.03358270558237564, 0.08255435532191768, 0.043405761098256335, 0.04004364658612758, 0.06606021226616576, 0.018490726251911838, 0.07148628399590962, 0.06063999608159065, 0.05896199647395406, 0.16230701410677284, 2.7170914644375443, 17.385929077863693, 41.94744631648064, 42.02132195234299, 30.746965929865837, 33.20436626672745, 20.216053314507008, 4.035449009388685, 0.537202408304438, 0.17548188683576882, 0.645344783551991, 1.8815369624644518, 1.120855186600238, 0.33567648148164153, 0.5539421131834388, 0.47360640834085643, 2.880311943590641, 11.278648842126131, 30.217300951480865, 45.795860812067986, 51.893188431859016, 51.936551705002785, 52.29814790189266, 55.90351603925228, 55.86188167333603, 54.05964978039265, 52.04831510782242, 51.415352672338486, 43.75927269458771, 43.48248794674873, 42.68977448344231, 51.83877915143967, 54.48144234716892, 53.65435212850571, 53.149066641926765, 50.90049549937248, 52.3161019384861, 50.50319641828537, 45.66295154392719, 40.94159089028835, 40.81386834383011, 39.19033706188202, 38.55719603598118, 40.170160084962845, 39.85225014388561, 40.24325296282768, 40.812192633748055, 38.75138841569424, 39.515770599246025, 40.23163318634033, 44.538360089063644, 42.65286326408386, 45.557127222418785, 52.68485315144062, 52.891322672367096, 50.3475833684206, 47.003048434853554, 49.1474861651659, 46.138644218444824, 51.700185388326645, 56.6303676366806, 48.14521014690399, 47.27228298783302, 53.09629887342453, 48.57061251997948, 49.49292562901974, 45.11965669691563, 43.34416776895523, 39.28011864423752, 37.664164155721664, 36.58536784350872, 37.30640195310116, 36.26855604350567, 40.879977196455, 47.143751084804535, 51.14285409450531, 50.89177876710892, 49.52728718519211, 48.41361254453659, 47.10038401186466, 40.970241352915764, 38.68488438427448, 38.42413477599621, 37.12635241448879, 35.713326036930084, 35.874334797263145, 37.75012694299221, 35.401514768600464, 35.69483622908592, 37.09882669150829, 36.49935185909271, 38.063537925481796, 43.30517426133156, 48.65842580795288, 49.699087366461754, 50.2616585791111, 48.022108152508736, 48.61819736659527, 48.88272017240524, 48.04080694913864, 52.16678135097027, 52.67297498881817, 50.65752133727074, 48.67858372628689, 41.987834349274635, 21.014667861163616, 5.739763006567955, 1.5575414104387164, 1.5257627656683326, 1.071976984385401, 1.0109998751431704, 0.5762808176223189, 0.09656390669988468, 0.044083761240472086, 0.11661749391350895, 0.05606339400401339, 1.0543532925657928, 2.0029437728226185, 9.655307549983263, 21.66000433266163, 33.87746214866638, 33.89915518462658, 37.082954943180084, 26.97664674371481, 5.851496960967779, 0.0877373588446062, 0.025583839778846595, 0.018174832948716357, 0.04459790259716101, 0.08201144461054355, 0.01873892826552037, 0.029670683761651162, 0.015616586824762635, 0.04094370473467279, 0.08385281689697877, 0.012498658379627159, 0.03512563431286253, 0.027411066730564926, 0.03346357974805869, 0.05130780074978247, 0.018467383852112107, 0.029247910060803406, 0.015079380445968127, 0.01740077477734303, 0.0494878208701266, 0.051365573235671036, 0.04027230228530243, 0.06326071990770288, 0.146593491663225, 0.17092796479118988, 0.1894516739412211, 0.1453784920158796, 0.1864157704403624, 0.12350672463071533, 0.1534354401519522, 0.13893099501729012, 0.16303654527291656, 0.12905703188152984, 0.10801767959492281, 0.07059661962557584, 0.1778750607627444, 0.2899616095237434, 0.1883595739491284, 0.13647546584252268, 0.08139013341860846, 0.14751905371667817, 0.10072467601276003, 0.1270511551410891, 0.13554420409491286, 0.16528238804312423, 0.24280265177367255, 0.18951506819576025, 0.15352231595898047, 0.11563740627025254, 0.15592408395605162, 0.25494126370176673, 2.480583842843771, 20.158805586397648, 47.094247341156006, 49.940230026841164, 41.33339546620846, 44.972615987062454, 22.595139853656292, 6.0548800975084305, 1.4611059101298451, 0.2656800515251234, 2.7591148344799876, 7.141358647495508, 6.825789380818605, 0.5461632180958986, 1.2418307201005518, 1.1976747144944966, 4.4886397663503885, 12.601222023367882, 30.717338919639587, 47.169057726860046, 51.56219959259033, 52.73600600659847, 52.150647416710854, 57.48962692916393, 57.5187523663044, 56.73768527805805, 53.92692670226097, 52.88776606321335, 45.61325401067734, 46.04630917310715, 44.84023109078407, 54.878399446606636, 58.15662033855915, 54.16942588984966, 55.57778611779213, 53.678173050284386, 53.25386501848698, 51.84047006070614, 48.0401723831892, 41.540157571434975, 42.208112329244614, 40.84169045090675, 41.04475535452366, 41.40629455447197, 41.65329270064831, 42.09069103002548, 42.57902942597866, 40.94573646783829, 41.48029938340187, 42.3569655418396, 46.2907462567091, 43.641429618000984, 47.03548729419708, 55.457746759057045, 55.824841260910034, 52.629049345850945, 48.03463988006115, 49.29793909192085, 47.631747499108315, 50.690697357058525, 58.23381319642067, 49.347796216607094, 49.57805626094341, 55.763820335268974, 51.689226776361465, 53.66727523505688, 47.2648011893034, 46.18150971829891, 42.89006553590298, 40.32071940600872, 39.21567030251026, 39.2645812779665, 37.769794687628746, 43.40096712112427, 49.817219227552414, 53.47702704370022, 53.58290076255798, 52.14497052133083, 50.748648047447205, 47.61285111308098, 42.10887685418129, 40.64037725329399, 39.51775409281254, 38.886824548244476, 36.75781399011612, 38.58197070658207, 39.254261031746864, 36.6976024210453, 37.59807430207729, 39.153064861893654, 39.31772902607918, 39.467045813798904, 44.7430969029665, 51.707336604595184, 53.570699617266655, 50.589527785778046, 48.3468197286129, 47.96038046479225, 50.19643887877464, 48.26869212090969, 52.82986097037792, 52.90451176464558, 51.29656724631786, 49.54826205968857, 42.87226729094982, 22.127624340355396, 6.768329339101911, 1.0161547735333443, 0.9458385966718197, 1.9949171785265207, 1.950803801883012, 0.9202412702143192, 0.4491532954853028, 0.2968151948880404, 0.2813782560406253, 0.3788128949236125, 3.988412758335471, 5.017645480111241, 15.805953908711672, 29.732201881706715, 40.717642307281494, 41.75557941198349, 44.16439175605774, 29.515241123735905, 6.94882582873106, 0.3624964220216498, 0.10296651118551381, 0.1237072677758988, 0.16348297678632662, 0.18871807580580935, 0.1638416270725429, 0.07286961015779525, 0.1042560298810713, 0.1515493608894758, 0.12286038079764694, 0.12567380326800048, 0.13358434051042423, 0.1468276244122535, 0.16366496623959392, 0.23056217265548185, 0.16185204789508134, 0.1314280304359272, 0.08878592445398681, 0.09902196659822948, 0.1360493988613598, 0.2144800848327577, 0.06246445482247509, 0.23619042767677456], [0.027257095207460225, 0.022043956778361462, 0.08393361451453529, 0.0263552466276451, 0.029622130605275743, 0.04142423793382477, 0.005701299978682073, 0.03329968014440965, 0.00675190742185805, 0.03763511762372218, 0.03926039134967141, 0.0607300408591982, 0.026275803429598454, 0.04011907847598195, 0.05334838402632158, 0.03576918024918996, 0.023611385659023654, 0.05796777091745753, 0.013748332094110083, 0.08445739265880547, 0.04427202926308382, 0.032843871595105156, 0.07564630373963155, 0.08525030323653482, 0.033367256401106715, 0.008957261397881666, 0.06962167506571859, 0.04101005644770339, 0.19285118527477607, 8.161412961781025, 19.624035581946373, 38.92332538962364, 35.32977841794491, 25.615202598273754, 22.470791526138783, 16.659079380333424, 1.3063339213840663, 0.4391223384300247, 0.03349399667058606, 0.5237717914860696, 0.49506448034662753, 0.1390670900582336, 0.3873195103369653, 0.27110829774755985, 0.35197169927414507, 2.214489821344614, 11.610713973641396, 33.69561530649662, 45.787945836782455, 51.47434450685978, 51.187098920345306, 52.17634543776512, 55.230306163430214, 51.413027197122574, 49.435890689492226, 43.565342500805855, 43.23811165988445, 42.46634267270565, 46.91578611731529, 49.52675901353359, 52.17553228139877, 52.763972505927086, 49.154470190405846, 51.675292924046516, 51.61129675805569, 50.24975761771202, 47.65844106674194, 43.515280187129974, 40.86200796067715, 40.1473119109869, 40.23099862039089, 39.038364216685295, 37.41046316921711, 37.73629188537598, 38.03844787180424, 36.2582091987133, 36.353318095207214, 42.87984788417816, 48.66262838244438, 41.82459510862827, 44.87080805003643, 48.950234949588776, 50.20005628466606, 48.77246528863907, 51.83710344135761, 47.672849893569946, 51.8141982704401, 46.36415831744671, 39.005735367536545, 34.58876118063927, 45.030954256653786, 53.299903348088264, 51.35398976504803, 48.15770387649536, 45.71426399052143, 44.98044736683369, 44.219397604465485, 40.20988315343857, 36.48319132626057, 37.03887350857258, 35.42580306529999, 38.456357046961784, 46.932794004678726, 49.379155933856964, 49.81342323124409, 50.01707710325718, 46.526903584599495, 42.045006081461906, 36.64685234427452, 38.62647011876106, 38.59240874648094, 37.501175701618195, 38.229311630129814, 41.30114659667015, 40.20187318325043, 37.910048961639404, 34.38405096530914, 34.192355051636696, 35.633192136883736, 34.98278483748436, 40.45171357691288, 47.12977923452854, 47.56220743060112, 49.745969250798225, 48.36761601269245, 48.91337312757969, 50.04143759608269, 48.80751080811024, 49.989615976810455, 46.63806661963463, 50.71563921868801, 39.60262633860111, 23.96906442940235, 7.311723455786705, 0.7592551899142563, 0.9923361672554165, 1.2160274921916425, 1.2323998636566103, 0.6058506527915597, 0.16802661266410723, 0.041305286504211836, 0.021057056219433434, 0.09354456793516874, 0.12099994273739867, 0.8628488529939204, 1.3300421554595232, 7.600949686020613, 22.978275194764137, 29.07280046492815, 30.084404982626438, 29.54574018716812, 13.209843914955854, 1.751422444358468, 0.07086398574756458, 0.06483177974587306, 0.07064917852403596, 0.0021581779674306745, 0.032111568507389165, 0.04389758236357011, 0.02641680035594618, 0.03659310888906475, 0.07104610136593692, 0.019663399361888878, 0.03572192770661786, 0.03121855334029533, 0.022962455441302154, 0.07135486448532902, 0.049275607452727854, 0.07268772460520267, 0.08374040378839709, 0.03782000516366679, 0.05255837895674631, 0.0547242775792256, 0.0690572866005823, 0.02304251647728961, 0.026907185565505642, 0.008427396714978386, 0.056460795531165786, 0.04890175798209384, 0.044031684738001786, 0.04677788347180467, 0.041350305182277225, 0.07515707256970927, 0.024175408616429195, 0.031030873469717335, 0.03055819404835347, 0.026653296845324803, 0.06713048569508828, 0.07209340532426722, 0.028999719179410022, 0.06193554843775928, 0.02737654016527813, 0.03932634230295662, 0.06292676829616539, 0.07410826947307214, 0.04061467727296986, 0.0498194235842675, 0.008441982699878281, 0.06629483483266085, 0.04397571938170586, 0.055975471768761054, 0.030558797043340746, 0.0024847377881087596, 0.007491066098737065, 0.36371538473758847, 10.241404250264168, 28.126200959086418, 45.19373372197151, 41.97821706533432, 32.66009867191315, 23.55652056634426, 14.663224127143621, 2.009852514602244, 0.22186452843016014, 0.055915788252605125, 0.5487970705144107, 0.08404576787143014, 0.1862930934294127, 0.13734012725763023, 0.10816657668328844, 0.4534631845308468, 3.489858373068273, 14.777006171643734, 37.66456313431263, 48.033059164881706, 50.85838235914707, 52.502755522727966, 55.60653157532215, 56.69052980840206, 54.00337480008602, 52.29719415307045, 45.67013315856457, 45.40417023003101, 44.21049848198891, 47.38171711564064, 51.57749757170677, 53.38970012962818, 54.57085154950619, 51.59274235367775, 53.18462513387203, 54.162301272153854, 52.27608248591423, 49.67471927404404, 45.120401456952095, 42.04683378338814, 42.383510917425156, 41.22038193047047, 39.949296936392784, 39.39721696078777, 39.92573820054531, 39.960171952843666, 38.82671557366848, 38.08730565011501, 43.9877962321043, 50.36794647574425, 43.70783105492592, 46.02929748594761, 52.00464025139809, 50.739232152700424, 50.512787103652954, 52.01809152960777, 49.15221311151981, 49.51053388416767, 48.438759595155716, 40.47279104590416, 37.97431871294975, 47.61546157300472, 53.984778597950935, 51.532694175839424, 49.2033089697361, 47.83105440437794, 45.71596249938011, 46.33441351354122, 41.44091069698334, 37.187863513827324, 38.909205347299576, 37.03830733895302, 40.60187391936779, 48.207682594656944, 51.26954309642315, 51.543618589639664, 50.93191221356392, 48.6760226637125, 43.66104036569595, 38.67356859147549, 39.17313538491726, 39.516671150922775, 38.20102594792843, 38.90358544886112, 42.14000478386879, 40.727753564715385, 39.12640929222107, 37.16664545238018, 36.83167442679405, 37.52065345644951, 37.271113246679306, 42.73603320121765, 47.60474234819412, 49.2455019056797, 50.67587435245514, 48.76013495028019, 49.75622870028019, 49.89042989909649, 49.87559549510479, 51.08768105506897, 47.97921985387802, 49.83659818768501, 41.83198571205139, 25.078376904129982, 9.528367761522532, 1.5337574179284275, 2.636546711437404, 4.153035124763846, 1.4467170322313905, 0.7597549818456173, 0.4215752659365535, 0.022762294502172153, 0.048359132997575216, 0.05983184921205975, 0.04369167720142286, 1.1817286326549947, 1.644146719481796, 8.814916145056486, 27.67719615250826, 35.53863801062107, 36.99255399405956, 35.5982606112957, 17.45203223079443, 2.6647300366312265, 0.05043891280365642, 0.07320884586079046, 0.02113458096573595, 0.021468463928613346, 0.043538891259231605, 0.035884773460566066, 0.03332348082039971, 0.05036859802203253, 0.06842695089289919, 0.06325071575702168, 0.05868111584277358, 0.053539802465820685, 0.0717771242489107, 0.023003347778285388, 0.043899437732761726, 0.01015267205730197, 0.02503299921954749, 0.013616459873446729, 0.04573579310090281, 0.020030083396704867, 0.09793801538762636, 0.038451966174761765, 0.03947555109334644, 0.10839990791282617, 0.09896661722450517, 0.25798023969400674, 0.07609688385855407, 0.13714828208321705, 0.144275838683825, 0.1270205934997648, 0.13925964769441634, 0.24593659298261628, 0.10527548103709705, 0.09885991123155691, 0.09139613946899772, 0.17826822091592476, 0.13020844431594014, 0.19315773679409176, 0.1268151224940084, 0.1190586328448262, 0.1903732432401739, 0.19093797309324145, 0.14799586875597015, 0.15107315441127867, 0.1065492513589561, 0.23715331975836307, 0.1639784939470701, 0.08160632103681564, 0.10871391801629215, 0.08267214900115505, 0.16001018579117954, 0.5088295682799071, 10.896721836179495, 34.19310741126537, 56.9435278326273, 47.887040600180626, 36.414004638791084, 29.837798215448856, 17.58123479783535, 3.303879015147686, 1.3886143499985337, 0.10431358343339525, 1.2985290214419365, 2.207171176560223, 0.8425242779776454, 1.0882145818322897, 0.9804580640047789, 1.1620902176946402, 3.4382763784378767, 15.481738205999136, 39.28850099444389, 49.192088171839714, 51.27122260630131, 53.32285411655903, 56.81162171065807, 59.258492812514305, 56.93494409322739, 54.509519040584564, 48.055481761693954, 47.24272437393665, 46.89133062958717, 50.73697127401829, 53.93119007349014, 56.34148433804512, 55.924992486834526, 51.0128478705883, 52.279901280999184, 56.781223341822624, 54.69247542321682, 52.91806183755398, 47.23474860191345, 44.45310026407242, 45.23352898657322, 44.2352769523859, 43.21402095258236, 41.43108442425728, 40.83970695734024, 42.998257130384445, 38.9635044336319, 38.31343911588192, 45.70914186537266, 52.05433778464794, 44.98561508953571, 48.95125329494476, 53.82989890873432, 53.093798607587814, 52.66680791974068, 54.14677530527115, 50.400187745690346, 51.32448434829712, 49.628247767686844, 43.59211586415768, 40.61976715922356, 49.70698334276676, 55.16844928264618, 56.27833932638168, 50.62477849423885, 50.20736709237099, 48.6139339953661, 48.692274391651154, 43.784875720739365, 39.8410901427269, 40.4925499856472, 38.76630261540413, 41.414410918951035, 51.22479669749737, 53.54934096336365, 53.72546151280403, 54.28476870059967, 50.49979940056801, 45.47463744878769, 39.52465832233429, 41.79920107126236, 44.06104490160942, 40.07859259843826, 41.541829481720924, 45.52414119243622, 45.021880343556404, 42.40388922393322, 37.99412705004215, 37.61247932910919, 38.73096451163292, 40.11312514543533, 44.52015906572342, 50.51899217069149, 51.42802119255066, 51.56608298420906, 49.429491832852364, 49.5653535425663, 50.36206439137459, 50.31393997371197, 51.67417958378792, 49.088270142674446, 50.656696781516075, 42.63167180120945, 26.48465294390917, 10.234119091182947, 1.5165034937672317, 2.2959923604503274, 3.082728269509971, 1.8639853480271995, 1.6445917706005275, 0.6943799648433924, 0.13131569896358997, 0.23869306838605553, 0.295544964610599, 0.2990169986151159, 2.5102908862754703, 2.828984772786498, 10.52592633292079, 33.523780927062035, 41.088665798306465, 41.96467079222202, 40.44051557779312, 19.98484142124653, 2.84774127881974, 0.18316152709303424, 0.19995171285700053, 0.1471470299293287, 0.09471205528825521, 0.14037099899724126, 0.07738022788544185, 0.1183919319009874, 0.19095324649242684, 0.1854425179772079, 0.16067865304648876, 0.2727062604390085, 0.13276658282848075, 0.1780266221612692, 0.1318438260932453, 0.20186381181702018, 0.1258258247980848, 0.1445812324527651, 0.20869240164756775, 0.1510704678366892, 0.1657893491210416, 0.20280635420931503, 0.10945778747554868, 0.10579796784440987], [0.03300736301753204, 0.04347534486441873, 0.04157720570219681, 0.030978155009506736, 0.04229822814522777, 0.02207805846410338, 0.045632608598680235, 0.08094263321254402, 0.008808989568933612, 0.0160417929146206, 0.017096306837629527, 0.0342224368796451, 0.033769767615012825, 0.04173533510765992, 0.02987439773278311, 0.06313433215836994, 0.029604103838209994, 0.02201675706601236, 0.01790193226042902, 0.02838494816387538, 0.02658938308741199, 0.024115123960655183, 0.020065255630470347, 0.02435823484120192, 0.03124774942989461, 0.05558701683185063, 0.021188991522649303, 0.03128575852315407, 0.1360913153621368, 2.3165319208055735, 12.704914659261703, 29.982942827045918, 33.70004966855049, 29.33642841875553, 42.28274792432785, 16.546677611768246, 3.8166814483702183, 0.7978597527835518, 0.13056967727607116, 0.0811987929046154, 0.082293215818936, 0.16236059716902673, 0.1526531422859989, 0.11223606183193624, 0.11977105008554645, 0.3846956620691344, 2.9148965002968907, 16.29751168191433, 32.4340146034956, 49.84364300966263, 51.6260589659214, 55.41668616235256, 50.23815304040909, 52.36691281199455, 47.341032698750496, 43.743568137288094, 43.117984905838966, 45.05505256354809, 48.1784013658762, 49.730500280857086, 51.71913497149944, 53.765845745801926, 53.466589003801346, 51.54437854886055, 50.963199734687805, 49.89662356674671, 49.89144064486027, 48.40981274843216, 46.28659687936306, 44.25073832273483, 43.48896659910679, 43.27714316546917, 41.33964613080025, 39.416907504200935, 38.978612422943115, 36.41239732503891, 38.4886135160923, 38.353618159890175, 44.69782993197441, 42.539492547512054, 39.326757341623306, 46.77062630653381, 50.318526327610016, 50.51907196640968, 51.46451063454151, 50.04563257098198, 52.52920210361481, 50.761529356241226, 53.794503808021545, 36.58170863986015, 45.477574691176414, 50.416051894426346, 48.73078912496567, 51.781683415174484, 48.03097687661648, 49.714814722537994, 46.526645198464394, 40.8472191542387, 35.44483624398708, 35.633302330970764, 36.315080747008324, 40.66974587738514, 46.806017607450485, 48.00556004047394, 47.22970627248287, 46.56603768467903, 44.41332399845123, 38.727426901459694, 39.7342474758625, 41.82746775448322, 43.722251281142235, 46.558905467391014, 47.25084453821182, 47.063392996788025, 49.18085217475891, 43.847370967268944, 42.21223130822182, 35.810809805989265, 35.70880047976971, 36.30466550588608, 38.53432886302471, 45.33216029405594, 47.784316912293434, 48.381648659706116, 50.585864782333374, 48.71962912380695, 50.42669512331486, 46.42241679131985, 45.681665539741516, 47.362649738788605, 42.342271730303764, 25.288452431559563, 11.032944526523352, 1.1161808436736465, 1.600065166130662, 3.888074867427349, 5.914966380223632, 0.6210255541373044, 0.5504131712950766, 0.15103025827556849, 0.298131468007341, 0.09437704240554012, 0.07009632303379476, 0.07295929128304124, 0.4270267562242225, 2.544980412349105, 15.876605417579412, 27.154063023626804, 25.28092883527279, 27.588252425193787, 20.80247774720192, 4.937922433018684, 0.347340430598706, 0.1026670026476495, 0.04116220043215435, 0.022957644468988292, 0.028956333226233255, 0.013374067020777147, 0.040261095855385065, 0.009922059871314559, 0.20404916955158114, 0.06368693531840108, 0.038751953397877514, 0.04631671661627479, 0.0800165739201475, 0.01956475494807819, 0.04166674210864585, 0.00483480267575942, 0.015280320640158607, 0.028574062234838493, 0.03431427765463013, 0.024347089638467878, 0.059549962970777415, 0.034391075096209534, 0.023603936351719312, 0.12529097381047904, 0.01847808376624016, 0.038611787676927634, 0.00891582079930231, 0.03352253224875312, 0.017134609079221264, 0.03023992587259272, 0.05215140001382679, 0.04607931099599227, 0.023274847662833054, 0.03840699573629536, 0.05779019353212789, 0.04705458581156563, 0.06570951038156636, 0.057574918755562976, 0.0334205314720748, 0.04926318390062079, 0.06311202319920994, 0.030983157084847335, 0.01910780163598247, 0.006000724561090465, 0.030559251608792692, 0.05397631517553236, 0.08497702961903997, 0.03376402710273396, 0.004825049463761388, 0.022863629201310687, 0.03176245481881779, 0.04694656250649132, 0.12113666118239053, 3.787332298234105, 17.303146719932556, 38.4316735714674, 40.455946549773216, 31.096942350268364, 37.01833561062813, 20.73311436921358, 5.507396450266242, 0.9527481102850288, 0.24200812331400812, 0.14740218030055985, 0.10089972638525069, 0.3050278010778129, 0.05265691761451308, 0.0939289855887182, 0.36982121178880334, 0.973216068232432, 3.9869360625743866, 20.563652962446213, 36.23927481472492, 51.06143966317177, 52.93294183909893, 58.07619005441666, 53.52635979652405, 53.69779899716377, 49.358139261603355, 45.56088522076607, 43.347583785653114, 45.771010145545006, 49.89806368947029, 51.020610854029655, 54.26205351948738, 54.30369548499584, 53.53430137038231, 52.61084072291851, 53.386728689074516, 51.25062011182308, 50.99124222993851, 50.205383598804474, 47.12395794689655, 46.34735941886902, 45.286330953240395, 44.810132905840874, 42.38927140831947, 41.002957597374916, 39.20836329460144, 37.78109908103943, 39.88929055631161, 40.27552843093872, 46.66713126003742, 45.66469945013523, 42.78522536158562, 48.676771223545074, 52.60149322450161, 51.08431063592434, 53.27159486711025, 50.635053142905235, 55.14178231358528, 52.28009507060051, 52.00566999614239, 39.67560142278671, 47.09615483880043, 52.62366883456707, 50.49341194331646, 53.07830683887005, 50.658737272024155, 50.42121961712837, 47.7131125330925, 42.77245044708252, 36.45433947443962, 36.680351346731186, 38.19205462932587, 42.63153500854969, 48.32003116607666, 49.818822741508484, 49.09552775323391, 48.57661999762058, 45.75824283063412, 40.99566198885441, 41.09379932284355, 43.345543295145035, 45.608888044953346, 48.06058868765831, 48.273867443203926, 49.03661951422691, 51.30856700241566, 45.776291862130165, 42.88033425807953, 36.77071429789066, 38.43283250927925, 37.253182008862495, 41.005708649754524, 46.41370765864849, 48.48818354308605, 50.29131978750229, 51.580210626125336, 49.45543684065342, 50.00996008515358, 47.472490444779396, 48.38323317468166, 46.53562031686306, 44.33152578771114, 27.901860997080803, 12.701343800872564, 2.1616980666294694, 3.8285522488877177, 6.44960624165833, 6.984185306355357, 0.6596767832525074, 0.8010653557721525, 0.3853014326887205, 0.3634989744750783, 0.0568718711292604, 0.11999982452834956, 0.052525149294524454, 0.19952285540057346, 2.9739398695528507, 15.992880128324032, 31.385555863380432, 30.46401221305132, 33.394751250743866, 27.99117900431156, 8.079210072755814, 0.6333738821558654, 0.15633701492333785, 0.014630845871579368, 0.0015425500032506534, 0.022987287702562753, 0.012868704343418358, 0.012481655776355183, 0.04978107310307678, 0.07520041399402544, 0.05294445902109146, 0.016510648420080543, 0.003861671971208125, 0.05434665799839422, 0.06383861546055414, 0.02944935862615239, 0.04382072926091496, 0.04993377369828522, 0.02779915987048298, 0.023035087579046376, 0.07917587645351887, 0.0488704282179242, 0.02441089764033677, 0.04248360921337735, 0.0790331169264391, 0.15714368491899222, 0.08989446301711723, 0.09696641049231403, 0.1528737531043589, 0.21156795672141016, 0.28083319310098886, 0.13169903308153152, 0.11013828494469635, 0.10807060214574449, 0.11593100731261075, 0.1384997775312513, 0.11160956302774139, 0.12024852563627064, 0.0992173221311532, 0.15783397131599486, 0.19266100251115859, 0.1630618970375508, 0.08729412598768249, 0.11042066471418366, 0.14552350767189637, 0.11887328888406046, 0.1629336687619798, 0.15478841989533976, 0.08723194885533303, 0.09735750747495331, 0.09995061598601751, 0.08149088738719001, 0.13829159026499838, 0.2701949217589572, 2.7681619115173817, 21.867777183651924, 45.349418967962265, 49.74661901593208, 38.66581320762634, 48.63685816526413, 21.992571987211704, 7.308346386998892, 1.833795493002981, 1.0049008461646736, 0.462216489831917, 0.423167321132496, 0.6910306820645928, 0.6763972516637295, 0.2946771268034354, 1.16501689190045, 1.2988144811242819, 4.573376644402742, 19.95289083570242, 35.4700592905283, 52.71921470761299, 52.43591330945492, 60.11018671095371, 54.540605172514915, 56.05034776031971, 52.90646106004715, 46.894556656479836, 46.66799381375313, 48.53059686720371, 51.45801678299904, 54.59612779319286, 55.48036314547062, 56.7312066257, 55.32834090292454, 52.783222272992134, 54.22334499657154, 53.47376301884651, 52.56025403738022, 52.75187395513058, 49.612334221601486, 48.4323151409626, 47.47070454061031, 46.395670026540756, 45.74385680258274, 44.2515666782856, 41.7729938775301, 39.37969230115414, 41.3889978826046, 41.31873205304146, 48.07058595120907, 47.248051688075066, 43.23433846235275, 51.61549553275108, 53.66553872823715, 54.520204067230225, 56.10065706074238, 52.77462713420391, 56.624683141708374, 55.00389151275158, 52.710000202059746, 42.67898686230183, 48.606968969106674, 51.560668274760246, 53.05317498743534, 56.640307903289795, 52.948175221681595, 52.511270865798, 50.22897653281689, 44.537683725357056, 39.09599952399731, 38.16717356443405, 40.10975852608681, 44.71412345767021, 51.09875746071339, 50.956983268260956, 50.45819163322449, 51.21585577726364, 48.680468425154686, 43.67871321737766, 43.58140803873539, 46.3326770067215, 48.303992226719856, 51.77693746984005, 50.781018510460854, 52.07465149462223, 55.74470356106758, 47.79027879238129, 45.454456731677055, 39.345338344573975, 39.61965322494507, 39.27539549767971, 42.99186207354069, 49.73202399909496, 50.22117555141449, 51.607143580913544, 51.9856982678175, 48.972718343138695, 51.005552262067795, 47.79195450246334, 49.33319739997387, 48.25786650180817, 44.97341774404049, 29.020849652588367, 13.339127227663994, 2.389475656673312, 3.5491936141625047, 9.122655931860209, 13.232451751828194, 4.401912745088339, 1.0351790464483202, 0.7529641524888575, 0.7698144670575857, 0.17178432899527252, 0.2809540741145611, 0.19501441216561943, 1.0823252541013062, 4.390861038118601, 22.343433760106564, 37.72633641958237, 35.52367061376572, 37.9916799813509, 31.24363537877798, 8.381535150110722, 0.6532480625901371, 0.26716624677646905, 0.08576104184612632, 0.12323766641202383, 0.16660066496115178, 0.10724327075877227, 0.1983991844463162, 0.13449360500089824, 0.2598234376637265, 0.12569410842843354, 0.13187841017497703, 0.13195111096138135, 0.20303649420384318, 0.0978647060401272, 0.15120816591661423, 0.10469438682775944, 0.11890899360878393, 0.19452367443591356, 0.19834373117191717, 0.1830051714205183, 0.23519177892012522, 0.10830135070136748, 0.11284517211606726, 0.24472310731653124], [0.01602078085852554, 0.049151152998092584, 0.05544021631067153, 0.07419769826810807, 0.05630023188132327, 0.05635594490740914, 0.04216856752464082, 0.08200584139558487, 0.06209335129824467, 0.05429015829577111, 0.04468770246603526, 0.04700226440036204, 0.011460632194939535, 0.021736854214395862, 0.014796096183999907, 0.06263539369683713, 0.05902119759412017, 0.038973677437752485, 0.06299327957094647, 0.02118530304869637, 0.12360171211184934, 0.008885504066711292, 0.030757885579077993, 0.07659453840460628, 0.041087889185291715, 0.023832721926737577, 0.047898908669594675, 0.0029983570902913925, 0.01595996000105515, 0.9833691827952862, 6.912947203963995, 25.952362306416035, 37.14178338646889, 37.22588427364826, 39.85484540462494, 19.585412554442883, 6.03787268511951, 1.0216022562235594, 0.13706424128031358, 0.13902128470363095, 0.10108081783982925, 0.04697641539678443, 0.05645154837111477, 0.11437659384682775, 0.5824146384838969, 0.48239373369142413, 0.5499304190743715, 5.153653007000685, 17.573331221938133, 38.564301654696465, 53.93714055418968, 52.74092674255371, 52.94690228998661, 51.00576125085354, 50.43696217238903, 48.97802285850048, 45.47174200415611, 44.39430981874466, 45.429518669843674, 47.24646337330341, 50.30503325164318, 50.79672686755657, 53.57653230428696, 52.388077676296234, 51.6595883667469, 50.503124222159386, 50.86182117462158, 50.52772410213947, 48.05377945303917, 47.87423148751259, 48.856448382139206, 46.262145191431046, 46.04880563914776, 43.661032766103745, 41.75620637834072, 37.03567788004875, 36.983278691768646, 36.9592297822237, 38.24866399168968, 38.682938888669014, 36.715465262532234, 38.71424540877342, 44.01977151632309, 46.534157395362854, 48.68301808834076, 49.25755865871906, 51.38587385416031, 48.28478045761585, 54.9615465849638, 39.676984548568726, 41.1656990647316, 48.94838444888592, 50.044865012168884, 50.69940648972988, 49.950348883867264, 48.139046877622604, 45.97866900265217, 38.64126272499561, 34.85518008470535, 37.006267458200455, 34.419734850525856, 39.11266542971134, 44.07867215573788, 48.512376844882965, 47.06795275211334, 47.097127586603165, 41.20212770998478, 40.786544010043144, 43.22436399757862, 45.454566925764084, 46.39465928077698, 48.9009477943182, 48.82229581475258, 48.63159544765949, 47.021914422512054, 49.45587761700153, 46.823758855462074, 40.23433484137058, 35.178630128502846, 36.39377452433109, 37.877720296382904, 41.86640806496143, 48.17787319421768, 48.498758375644684, 47.939413189888, 48.47282476723194, 49.81320284307003, 46.69284068048, 48.563476502895355, 42.77098752558231, 29.052051678299904, 11.842460688203573, 1.859764487016946, 0.8073600742500275, 2.8982044709846377, 3.807098362594843, 4.718051506206393, 0.40210077655501664, 0.44495550042483956, 0.4535531031433493, 0.13372220186283812, 0.17288497852860019, 0.051685457437997684, 0.02233946514024865, 0.726912037935108, 5.044104410335422, 20.559606179594994, 22.7362946793437, 23.795668333768845, 28.39438296854496, 13.510221596807241, 1.6239604214206338, 0.07540864578913897, 0.02076288186799502, 0.05595857306616381, 0.09744537775986828, 0.027773845213232562, 0.01333043986960547, 0.08368514347239397, 0.05040708580054343, 0.019374690928088967, 0.06462455727159977, 0.01147554565250175, 0.06011720128299203, 0.05491476091265213, 0.04472455751965754, 0.014732394865859533, 0.04568931610265281, 0.07447616691933945, 0.06175957038067281, 0.024636920570628718, 0.06805499389884062, 0.0731155727407895, 0.014336709555209382, 0.015830015508981887, 0.0056045262408588314, 0.03688255019369535, 0.05022935998567846, 0.04504794836975634, 0.09518032078631222, 0.03432221863477025, 0.03846398525638506, 0.018289461368112825, 0.04425870029081125, 0.04521803748502862, 0.05470547155709937, 0.009070643009181367, 0.02302953631442506, 0.05031597233028151, 0.004728580006485572, 0.05933929693128448, 0.07472326498827897, 0.02099971788993571, 0.03722012719663326, 0.06788527214666829, 0.08512041255016811, 0.08302253918373026, 0.043213945609750226, 0.0052007932663400425, 0.06760462900274433, 0.05530897120479494, 0.03304257792478893, 0.08422974628047086, 0.03598428062105086, 0.07996968502993695, 0.9467941266484559, 8.87727839872241, 31.081781163811684, 42.80515909194946, 40.321315973997116, 43.79986971616745, 26.124569065868855, 7.2324620839208364, 0.472603440284729, 0.5133074498735368, 0.023293592457775958, 0.11798821098636836, 0.011956834914599312, 0.06080393279262353, 0.13771094876574352, 0.5190495355054736, 0.6157322006765753, 1.2830347591079772, 7.431140597909689, 21.948589347302914, 42.40251749753952, 55.443049147725105, 55.52985168993473, 53.97854693233967, 52.792630568146706, 52.142029479146004, 48.469484746456146, 46.39156624674797, 45.489794835448265, 48.52352924644947, 48.90954293310642, 51.63571044802666, 52.81571052968502, 54.365062192082405, 52.463815212249756, 51.371009051799774, 52.86764234304428, 52.97866478562355, 53.051248490810394, 50.82994468510151, 49.73069407045841, 50.20604856312275, 47.39517979323864, 48.17976549267769, 45.2173038572073, 42.61991523206234, 38.7246036529541, 38.71589832007885, 38.092632964253426, 41.19241163134575, 40.93780629336834, 38.279278948903084, 41.197989732027054, 47.7755393832922, 48.599114790558815, 49.1388264298439, 51.656795516610146, 51.41265481710434, 50.27636379003525, 55.09290553629398, 42.26190224289894, 44.41213086247444, 50.221532732248306, 50.08679956197739, 52.48680017888546, 50.983832627534866, 51.21416486799717, 47.995490580797195, 41.82167686522007, 36.973543614149094, 37.2995775192976, 35.794140100479126, 41.99645608663559, 45.93089796602726, 50.15670821070671, 49.19778786599636, 49.19336870312691, 43.034400790929794, 41.77904695272446, 44.667306169867516, 46.996421590447426, 48.11745263636112, 50.35766802728176, 49.63983714580536, 50.70099480450153, 49.294743463397026, 50.334493070840836, 48.04280944168568, 41.785331815481186, 36.95574916899204, 37.67420321702957, 39.0142735093832, 44.788455069065094, 48.44355493783951, 50.11827327311039, 49.30155649781227, 50.549189150333405, 49.42305497825146, 46.70147381722927, 47.750377133488655, 44.532751590013504, 29.973669424653053, 13.670840878039598, 2.4875944666564465, 3.1697143893688917, 7.346350522711873, 7.474969821050763, 9.300645031034946, 1.5961785684339702, 0.6772696017287672, 0.09511931624729186, 0.36536155734211206, 0.1903916781884618, 0.12678450148086995, 0.050526604973129, 1.191919210832566, 5.6570651941001415, 24.167001508176327, 30.372323133051395, 29.342813976109028, 32.84589730203152, 17.51694604754448, 2.6387800415977836, 0.05731541939894669, 0.060858406432089396, 0.06945033543161117, 0.061216689355205745, 0.041521719031152315, 0.004895085940006538, 0.025198746770911384, 0.04740291282359976, 0.0621424332348397, 0.05389285695855506, 0.008557535093132174, 0.012102763412258355, 0.05592954024905339, 0.027503308265295345, 0.039842550540925004, 0.0029701172115892405, 0.006528586372951395, 0.04714576236438006, 0.04199051145405974, 0.0566977595735807, 0.02198751830292167, 0.04084350737684872, 0.043264163032290526, 0.015916368101898115, 0.16550558153539896, 0.17692233610432595, 0.17566800263011828, 0.22203022032044828, 0.13616011245176196, 0.1548611800535582, 0.05478836945258081, 0.22422360809287056, 0.09609055749024265, 0.14574095694115385, 0.11814395067631267, 0.13109752238960937, 0.06145422114059329, 0.10309516990673728, 0.18107160954969004, 0.25784656405448914, 0.11414210486691445, 0.21438221039716154, 0.2012278654729016, 0.15904607658740133, 0.23128233791794628, 0.10613161517539993, 0.09480105363763869, 0.18892210704507306, 0.1371680380543694, 0.09407881778315641, 0.21061538049252704, 0.09428871198906563, 0.15569357288768515, 1.212140063289553, 9.813895840197802, 36.34277746081352, 51.74575254321098, 48.41352514922619, 48.77553932368755, 28.58664695173502, 10.838585905730724, 3.673692033626139, 2.0869375532492995, 0.7196682610083371, 0.3926131606567651, 0.3581309609580785, 0.27636608749162406, 0.8052757673431188, 1.9157162471674383, 2.841724776662886, 1.5939569938927889, 7.197465011849999, 21.455318816006184, 42.24498935043812, 57.219218239188194, 55.140893161296844, 57.29628190398216, 55.186840295791626, 54.25335958600044, 52.39710979163647, 49.63615894317627, 47.5649356842041, 50.191852524876595, 50.36561720073223, 53.65383915603161, 55.637602508068085, 56.08926147222519, 53.466357216238976, 53.7052807956934, 54.78065349161625, 55.38450948894024, 55.70090711116791, 51.05352468788624, 52.13194862008095, 52.18666948378086, 51.354297548532486, 49.76330392062664, 47.396540120244026, 45.45304700732231, 40.053323954343796, 40.01887880265713, 40.21101549267769, 41.798133328557014, 41.95036455988884, 41.471624448895454, 42.489190846681595, 48.21113660931587, 50.16832418739796, 52.32946202158928, 54.817644506692886, 55.778852328658104, 54.02764409780502, 56.96545645594597, 45.57418070733547, 46.62617325782776, 51.97936400771141, 50.3855699300766, 52.660751044750214, 53.378821313381195, 52.516518384218216, 50.90861566364765, 42.027390226721764, 38.85630078613758, 39.91230212152004, 37.219223231077194, 43.70174378156662, 48.36543492972851, 50.93088246881962, 50.54804541170597, 50.73884837329388, 46.2487281113863, 43.395544812083244, 47.829876467585564, 49.418860003352165, 50.66125653684139, 52.75948114693165, 51.700021997094154, 51.31924822926521, 50.80500662326813, 53.159451484680176, 51.15280956029892, 44.83147636055946, 39.63480681180954, 40.390027686953545, 41.09021611511707, 46.1703535169363, 51.7561449855566, 51.75524823367596, 49.54815946519375, 48.64779397845268, 49.56620089709759, 46.89525581896305, 48.7932425737381, 44.45751942694187, 31.906849890947342, 13.219167664647102, 3.212260468862951, 2.2222570795565844, 7.598485993221402, 7.803652659058571, 15.328225493431091, 5.705628963187337, 0.6717191089410335, 1.2444144627079368, 0.4537257563788444, 0.3295391279971227, 0.18867788108764216, 0.2631950442446396, 1.2702872743830085, 7.4295594077557325, 27.341132685542107, 34.10694323480129, 36.63204453885555, 39.76912200450897, 20.5147210881114, 3.1117399502545595, 0.12517271999968216, 0.17826295166742057, 0.13378782256040722, 0.15451605169801041, 0.17792723374441266, 0.17607771267648786, 0.14318826579255983, 0.12097720333258621, 0.16693362209480256, 0.20311813044827431, 0.10477602307219058, 0.12529051367891952, 0.2207580307731405, 0.16673193604219705, 0.09879377845209092, 0.14809074491495267, 0.13672582193976268, 0.19925306987715885, 0.1325536161311902, 0.13487178861396387, 0.1610999257536605, 0.10980619612382725, 0.1639814773807302, 0.08688811925821938], [0.005426801817520754, 0.04308501971536316, 0.005154931786819361, 0.014635546449426329, 0.024256840770249255, 0.0768739273189567, 0.05017144278099295, 0.012737064971588552, 0.06840966627351008, 0.04181178745056968, 0.025036583792825695, 0.03841559351712931, 0.04035568257677369, 0.022340886353049427, 0.03391792626644019, 0.046325948933372274, 0.03219036603695713, 0.015831640812393744, 0.004788764008480939, 0.028903130514663644, 0.011502517154440284, 0.014009343576617539, 0.03984441333159339, 0.08872535778209567, 0.043648346909321845, 0.05029105843277648, 0.05493967481015716, 0.015765597090648953, 0.025449616805417463, 0.10883049457333982, 1.5891183097846806, 12.687913421541452, 35.25510102510452, 40.22717982530594, 29.387410283088684, 12.550553642213345, 6.949415747076273, 3.426526696421206, 0.47299253346864134, 0.005051760272181127, 0.08605895476648584, 0.023458568175556138, 0.07108423291356303, 0.07814237644197419, 0.08367349917534739, 0.8329411328304559, 0.5626763007603586, 1.1067368066869676, 6.763385804370046, 25.21019373089075, 45.01952826976776, 57.34465330839157, 53.80399189889431, 53.32500860095024, 51.41246482729912, 52.12501019239426, 52.56267450749874, 48.764573112130165, 46.47477798163891, 44.25673820078373, 45.451823472976685, 50.95977611839771, 53.4756401181221, 53.58043469488621, 52.03784666955471, 52.01328858733177, 52.18180574476719, 52.29950822889805, 51.2871665507555, 49.78436999022961, 50.21570764482021, 50.40108069777489, 49.58356976509094, 47.367091700434685, 46.73909179866314, 42.14979685842991, 38.231549710035324, 38.19327816367149, 37.92810179293156, 36.98335848748684, 37.64768444001675, 35.66819205880165, 41.322991624474525, 40.361362025141716, 44.82700780034065, 46.996900364756584, 50.95990531146526, 47.681673020124435, 57.775071412324905, 39.94077779352665, 38.00645738840103, 50.2692049741745, 46.684139147400856, 52.733042165637016, 47.87365011870861, 49.44606274366379, 44.659562185406685, 36.870865523815155, 35.26164807379246, 34.64410521090031, 34.862418696284294, 36.91979929804802, 41.80140495300293, 46.28036521375179, 45.07302179932594, 43.860913440585136, 38.80399279296398, 40.03544211387634, 42.19244956970215, 43.35505798459053, 45.401229187846184, 48.2205905020237, 49.68160070478916, 50.312849432229996, 48.98797832429409, 48.57592463493347, 47.52484403550625, 44.04282867908478, 37.87380650639534, 34.63872849941254, 36.007962226867676, 43.00011903047562, 45.24412661790848, 46.52318358421326, 48.691693022847176, 50.388670563697815, 47.29364924132824, 50.748716443777084, 43.519353568553925, 29.469563774764538, 12.52457158640027, 2.9082216834649444, 0.48418409074656665, 2.3364084167405963, 8.347762562334538, 8.809390291571617, 5.992186311632395, 0.5988678149878979, 0.3952867625048384, 0.4506044019944966, 0.06340663356240839, 0.18161661311751232, 0.07853621937101707, 0.20470059709623456, 1.8158128391951323, 6.858754036948085, 21.707317493855953, 21.928851306438446, 23.75680021941662, 24.488709345459938, 9.003500025719404, 0.4937345813959837, 0.007186963202912011, 0.052507987129502, 0.014736279081262182, 0.01014043960822164, 0.01654636984312674, 0.042828162404475734, 0.08445800864137709, 0.05264568892016541, 0.01797334542061435, 0.03455340876826085, 0.022400914967874996, 0.02475055822287686, 0.048326174219255336, 0.055449021892854944, 0.04365038039395586, 0.036500722635537386, 0.027301963600621093, 0.0020351046032374143, 0.059200860414421186, 0.05554445837333333, 0.06868964148452505, 0.0813870683487039, 0.05532390692678746, 0.02433643054246204, 0.023649177674087696, 0.030074942733335774, 0.013815027978125727, 0.040566578682046384, 0.04010596101579722, 0.03439454463659786, 0.012688924634858267, 0.04723174017271958, 0.041929302824428305, 0.032885353939491324, 0.05005375300243031, 0.03367292847542558, 0.06067478425393347, 0.016821428325783927, 0.035474169126246125, 0.09833366173552349, 0.006462135861511342, 0.008721608173800632, 0.04854972765315324, 0.027701756698661484, 0.03464919405814726, 0.0172518999534077, 0.031441179089597426, 0.03736256017873529, 0.02436439837765647, 0.06830648548202589, 0.055297794460784644, 0.027965736771875527, 0.003548720587787102, 0.26117732282727957, 2.828689101152122, 18.909827806055546, 41.98654241859913, 45.482351034879684, 37.32483856379986, 21.189481280744076, 8.684749379754066, 3.7814502138644457, 0.22383384697604924, 0.3000101703219116, 0.16593620530329645, 0.03866368606395554, 0.03556402094545774, 0.08600382061558776, 0.2840216673212126, 0.32195016334299, 1.0761090251617134, 1.506699901074171, 7.274072701111436, 27.795563600957394, 48.36411640048027, 58.473485335707664, 55.815444365143776, 55.01179128885269, 54.60360199213028, 54.098897874355316, 52.055242136120796, 49.45661477744579, 48.01466055214405, 46.106615737080574, 48.5162640362978, 52.04444691538811, 55.72040006518364, 54.260761588811874, 53.52276898920536, 52.05129034817219, 53.123718202114105, 53.23338031768799, 53.30141566693783, 53.58383931219578, 53.752398267388344, 52.23782993853092, 52.10407331585884, 48.99468496441841, 47.38830216228962, 42.13805548846722, 39.687642976641655, 38.39228108525276, 39.378138184547424, 38.55376861989498, 39.30888690054417, 37.52975016832352, 42.8585310280323, 44.180689081549644, 47.36046485602856, 47.87225179374218, 51.29292704164982, 48.701948672533035, 57.893374264240265, 43.6638256162405, 39.94143135845661, 50.56953705847263, 49.140714928507805, 54.0537790954113, 50.7566200196743, 51.02751508355141, 45.59848040342331, 37.694779112935066, 36.46688260138035, 37.527116909623146, 35.67125469446182, 39.00532878935337, 44.658756628632545, 47.17997834086418, 47.78714016079903, 45.36336801946163, 40.30728332698345, 42.205205485224724, 44.324716553092, 46.23534522950649, 48.26507851481438, 50.285414904356, 52.16711953282356, 51.42526634037495, 50.00855416059494, 50.163665637373924, 49.96010676026344, 45.48249542713165, 40.18173426389694, 37.52527020871639, 38.47700513899326, 44.91648159921169, 47.950778380036354, 49.57409307360649, 49.5928792655468, 48.18736508488655, 47.12748795747757, 50.20006388425827, 43.91463875770569, 30.648581609129906, 14.93641996756196, 3.8993020774796605, 1.4722454873844981, 4.158373363316059, 9.779968410730362, 8.943159263581038, 7.931953724473715, 1.6022851970046759, 0.3985023993300274, 0.7409768051002175, 0.9971319255419075, 0.5741138651501387, 0.10013093560701236, 0.11715963279129937, 1.8757910770364106, 8.402402680367231, 26.631963439285755, 24.493827670812607, 29.51444696635008, 29.99909956008196, 11.200312245637178, 0.9556315618101507, 0.16723043663660064, 0.027070443211414386, 0.0355297485657502, 0.013501698795153061, 0.038726111815776676, 0.04444553596840706, 0.06933291282621212, 0.029161854326957837, 0.05740722677728627, 0.012432924504537368, 0.04353679840278346, 0.08275404499727301, 0.017834606478572823, 0.09271988601540215, 0.04378291683678981, 0.02661635458935052, 0.019106556683254894, 0.0471759640640812, 0.07157664789701812, 0.018791958427755162, 0.06246470715268515, 0.06765994869056158, 0.021964456063869875, 0.023563888207718264, 0.10883250579354353, 0.17237010615644976, 0.10975236815284006, 0.07963947384268977, 0.14689110772451386, 0.16696909675374627, 0.1128422628971748, 0.13994505075970665, 0.27736593852750957, 0.1538158650510013, 0.12346788062131964, 0.1515648717759177, 0.16803810111014172, 0.06842982300440781, 0.09539437844068743, 0.2440330880926922, 0.14246191101847216, 0.18469489325070754, 0.1045301569683943, 0.09670536004705355, 0.11635490722255781, 0.15153965359786525, 0.12390720978146419, 0.1508013205602765, 0.1038422306010034, 0.18634228297742084, 0.14105116249993443, 0.1489996086456813, 0.1186225246055983, 0.22743455454474315, 3.297141739167273, 20.827953480184078, 50.20708590745926, 50.75382336974144, 43.938585072755814, 27.78279058635235, 15.19028814509511, 4.67432202771306, 1.3611782784573734, 0.7990355521906167, 0.37806442414876074, 0.2071842091390863, 0.2891249122330919, 0.1890912721864879, 1.001676837913692, 2.2204305650666356, 2.1374052576720715, 1.9527862267568707, 8.428963255137205, 28.38019073009491, 48.67252305150032, 61.744893193244934, 57.082752361893654, 57.79502414166927, 55.731256082654, 56.545054614543915, 55.6530524790287, 52.56923295557499, 50.16471438109875, 49.34029921889305, 49.19256694614887, 55.813240483403206, 58.02718408405781, 57.86429442465305, 54.403907507658005, 52.41251416504383, 53.16475600004196, 56.369074657559395, 54.77318309247494, 54.446157440543175, 56.1704783141613, 53.354673609137535, 54.82964426279068, 50.71218900382519, 49.46763798594475, 45.41792169213295, 41.60253122448921, 41.20392121374607, 41.15317113697529, 40.61778746545315, 41.75125144422054, 39.56288427114487, 44.63091552257538, 44.27389807999134, 49.17865589261055, 50.432721599936485, 53.55819448828697, 51.17648608982563, 59.75521735846996, 46.79998733103275, 42.02488616108894, 52.937311604619026, 52.702924981713295, 56.03706747293472, 52.60330192744732, 53.209453001618385, 47.94905707240105, 39.74292241036892, 39.10622477531433, 37.6388993114233, 38.13980743288994, 39.99619022011757, 45.636945739388466, 48.89533169567585, 49.64219681918621, 48.42807076871395, 42.84477196633816, 43.544033244252205, 46.689892038702965, 47.16945290565491, 50.41965790092945, 51.828504502773285, 54.5290157943964, 54.42913435399532, 51.30375266075134, 50.762334913015366, 52.402433305978775, 47.71818906068802, 42.64374755322933, 38.34904320538044, 39.390795305371284, 47.06502690911293, 50.02054251730442, 51.17488257586956, 51.47288538515568, 49.71830673515797, 47.40385852754116, 50.917381793260574, 46.723326444625854, 32.04554244875908, 14.982270207256079, 3.7165974313393235, 1.5283645573072135, 4.573810771107674, 14.498690105974674, 16.01716462522745, 17.21561461687088, 3.6836057016626, 0.37241593818180263, 0.7269014697521925, 1.8945534015074372, 0.9700218052603304, 0.42103406216483563, 0.4483757325215265, 3.0646600015461445, 10.77239915728569, 31.876660510897636, 30.779173001646996, 36.3394982367754, 33.84989082813263, 12.667457219213247, 1.0363763384521008, 0.33457997313234955, 0.12130552946473472, 0.1425843356992118, 0.0968956615542993, 0.14289189653936774, 0.13271138188429177, 0.2033594175009057, 0.1211274808156304, 0.1134276764059905, 0.10024808361777104, 0.1422068348620087, 0.2079842146486044, 0.1665106721338816, 0.22241965489229187, 0.15682997909607366, 0.09302401071181521, 0.1083525366266258, 0.10794989924761467, 0.1905348087893799, 0.12435129610821605, 0.1616676093544811, 0.17795764695620164, 0.25419092271476984, 0.19741209835046902], [0.02307012808159925, 0.05928497172135394, 0.008861652368068462, 0.059642757405526936, 0.08650647723698057, 0.01987677052966319, 0.027311086450936273, 0.07942028794786893, 0.06433794726035558, 0.04068742258823477, 0.02640335264004534, 0.020704968374047894, 0.022288596483122092, 0.019118514537694864, 0.04900161766272504, 0.03669499834359158, 0.027154317031090613, 0.030545106274075806, 0.069520794932032, 0.042561145091895014, 0.08242409356171265, 0.021898709201195743, 0.015038333185657393, 0.049421866206103005, 0.03737409315363038, 0.009176419462164631, 0.040028551302384585, 0.05689816171070561, 0.04813027691852767, 0.055115593495429493, 1.2243925058282912, 4.793856488540769, 25.951102674007416, 38.0511049926281, 27.11631014943123, 21.711231283843517, 8.930801376700401, 6.051783263683319, 1.8541037407703698, 0.07795924408128485, 0.07999784211278893, 0.07385395772871561, 0.10986004635924473, 0.06834321437054314, 0.19373208488104865, 0.16888811253011227, 1.1153971357271075, 0.6777975359000266, 0.7065499399323016, 11.219456568360329, 28.85482706129551, 47.64802202582359, 55.92579424381256, 54.58171136677265, 55.27032181620598, 53.480883836746216, 53.0613749474287, 51.818651631474495, 52.150510624051094, 47.022651582956314, 44.46305572986603, 45.170558765530586, 51.96406602859497, 51.469153985381126, 52.57864125072956, 50.71679815649986, 51.67514853179455, 51.8417201936245, 53.44342924654484, 51.705432906746864, 51.47899925708771, 50.536463633179665, 52.99495071172714, 48.927956745028496, 50.33445507287979, 46.6269788146019, 41.46897979080677, 36.602444127202034, 37.392220348119736, 37.97485068440437, 38.917454704642296, 36.6137371212244, 37.76453197002411, 36.50456137955189, 39.82027865946293, 41.08205035328865, 49.601288214325905, 47.25601226091385, 54.778335615992546, 42.333224415779114, 36.06006883084774, 51.259078457951546, 48.56487102806568, 49.9478942155838, 47.11087144911289, 47.123384177684784, 37.50578485429287, 36.742082834243774, 35.18332667648792, 35.8303901553154, 36.79917477071285, 35.31909339129925, 39.42782051861286, 41.58977530896664, 43.58499124646187, 41.885034665465355, 36.99642978608608, 38.73767875134945, 39.51192520558834, 42.71088995039463, 45.65864637494087, 45.68703465163708, 46.32034286856651, 49.698118418455124, 46.30992762744427, 49.421732649207115, 47.51379802823067, 46.7789326608181, 40.642318949103355, 35.90675085783005, 37.82812915742397, 43.94728280603886, 47.7969778329134, 47.9335805028677, 48.278875574469566, 47.888780906796455, 46.82958394289017, 46.85275889933109, 30.224176682531834, 14.198320973664522, 2.36694666557014, 1.4505917555652559, 1.5642433008179069, 5.286768889054656, 7.683410011231899, 6.1743067391216755, 6.149831302464008, 0.7714017131365836, 0.3925285261357203, 0.2168306743260473, 0.7489210506901145, 0.4151812777854502, 0.12200729688629508, 0.4679498774930835, 4.000233449041843, 10.421235300600529, 21.26970637589693, 24.109795577824116, 28.32840520888567, 17.998042032122612, 3.2823683694005013, 0.10869811769225635, 0.07473266057786532, 0.06123558443505317, 0.014698051982122706, 0.060028477528248914, 0.01767977406416321, 0.06568729048012756, 0.03225440967071336, 0.020843826059717685, 0.05830174108268693, 0.03510306931275409, 0.021508604841073975, 0.02360043155931635, 0.00866905855218647, 0.013086802064208314, 0.022339928982546553, 0.02896263962611556, 0.041788621310843155, 0.03602308381232433, 0.035170014743926004, 0.03694631552207284, 0.0812793752993457, 0.03208733367500827, 0.044459844575612806, 0.012824707046092954, 0.03301871787698474, 0.05826612912642304, 0.03670903606689535, 0.07718360327999108, 0.03572582398192026, 0.07355148060014471, 0.0055512117432954255, 0.08004020390217192, 0.12452638358809054, 0.06944836131879129, 0.02374615225562593, 0.005410308513091877, 0.036440256153582595, 0.09151201098575257, 0.0645739131141454, 0.07101939889253117, 0.024195437326852698, 0.042611674216459505, 0.0187836723489454, 0.05318240640917793, 0.07006215455476195, 0.02213301821029745, 0.0072176468347606715, 0.0069815297683817334, 0.0674184612580575, 0.014460319816862466, 0.015494649178435793, 0.028646237951761577, 0.055483383330283687, 0.008285855237772921, 1.3130840216763318, 6.6344216745346785, 32.80241623520851, 44.587958827614784, 33.189623057842255, 26.226663887500763, 13.49786275997758, 7.972095720469952, 2.3938145488500595, 0.010815650202857796, 0.04647077163099311, 0.1953201918513514, 0.08130424466799013, 0.02969397792185191, 0.11894989336724393, 0.40037552069406956, 0.7189853070303798, 0.7340010919142514, 1.353307832032442, 14.12025511264801, 31.755181029438972, 51.79358057677746, 56.1768239736557, 54.61547635495663, 54.744513630867004, 56.02094113826752, 55.1696690171957, 54.85722318291664, 53.14014472067356, 48.563210517168045, 46.297817677259445, 48.25529403984547, 53.58224719762802, 54.543975591659546, 52.926770970225334, 49.887321665883064, 50.75163088738918, 52.100003734230995, 55.182014554739, 53.02788354456425, 53.53684723377228, 54.704862758517265, 54.251904264092445, 50.95863237977028, 52.60733351111412, 48.57378914952278, 42.773381397128105, 38.87328967452049, 39.45512965321541, 39.16974976658821, 39.18742261826992, 38.01727920770645, 39.98404607176781, 38.72025288641453, 41.103568598628044, 43.8472455739975, 50.15621043741703, 49.22340229153633, 56.08168847858906, 44.03825752437115, 38.82044970989227, 52.6930683106184, 51.52336947619915, 52.197802886366844, 49.34062600135803, 50.6712082028389, 39.27617825567722, 37.71150201559067, 36.307826936244965, 37.70008362829685, 38.00722114741802, 37.16853775084019, 40.246368795633316, 42.49345801770687, 45.68658247590065, 42.58167788386345, 38.416147604584694, 40.61651833355427, 41.257460340857506, 43.75295363366604, 47.52487823367119, 47.79730461537838, 49.354537054896355, 51.166097447276115, 49.00662012398243, 51.090257316827774, 49.56870496273041, 48.938941955566406, 42.01067112386227, 37.452853694558144, 39.5290432870388, 46.069461330771446, 48.97316291928291, 49.398914873600006, 49.53103378415108, 48.708001747727394, 47.537865936756134, 48.46904397010803, 33.48983734846115, 15.824502613395452, 3.806830714456737, 3.284146199002862, 3.0723783373832703, 9.661141186952591, 10.017767250537872, 8.839888405054808, 8.469197396188974, 3.6833895882591605, 0.1896987497457303, 1.5417232154868543, 2.297669257968664, 0.30100325297098607, 0.0997586446464993, 1.0717524401843548, 5.779225789010525, 15.812918934971094, 26.665112860500813, 29.062358625233173, 32.359880581498146, 22.978769168257713, 5.731208240613341, 0.09013990609673783, 0.031113374316191766, 0.07408498830045573, 0.02730352211074205, 0.035446112233330496, 0.03725890812347643, 0.05567830099607818, 0.05344820659956895, 0.06796454094001092, 0.06905894901137799, 0.010884318344324129, 0.024720955807424616, 0.014093367681198288, 0.027555809647310525, 0.06033994577592239, 0.055781006813049316, 0.019008576491614804, 0.03300282849522773, 0.02253199680126272, 0.08648423507111147, 0.02619461803988088, 0.061341592809185386, 0.03295958355010953, 0.047924843020155095, 0.05277916417981032, 0.13983666751300916, 0.13301238213898614, 0.05168099713046104, 0.1990453278995119, 0.2061952231451869, 0.1980812186957337, 0.10044280090369284, 0.1638395490590483, 0.3103245981037617, 0.2026652719359845, 0.11186390445800498, 0.10422969106002711, 0.08448087421129458, 0.2565623220289126, 0.1876899934723042, 0.163109305431135, 0.10415687152999453, 0.1208871066046413, 0.08927897026296705, 0.12362136418232694, 0.17898414109367877, 0.11091799271525815, 0.1353216340066865, 0.09352918321383186, 0.12187924672616646, 0.09736141859320924, 0.10915418970398605, 0.23154979309765622, 0.16434458055300638, 0.15623449464328587, 1.5455018752254546, 9.47186004370451, 36.06128856539726, 50.31764477491379, 39.96885448694229, 34.257259368896484, 18.778446055948734, 9.180836509913206, 3.0567761370912194, 0.3123889263952151, 0.23461536766262725, 0.5220100516453385, 0.2955236204434186, 0.17919562349561602, 0.49085124861449003, 1.145711315330118, 3.0439874483272433, 2.703718557022512, 1.2204106757417321, 12.899132687598467, 31.59666683524847, 50.80802746117115, 59.05386619269848, 57.0321960747242, 58.05700868368149, 57.78576783835888, 58.674350157380104, 55.95180384814739, 56.743115186691284, 52.22221277654171, 48.03734913468361, 49.65070076286793, 56.3769668340683, 57.23890118300915, 55.4439876973629, 50.93511924147606, 51.1819501966238, 54.451397359371185, 55.9711030125618, 53.88729102909565, 55.8733494579792, 56.31795980036259, 55.49243129789829, 53.42313453555107, 53.89816604554653, 50.492473393678665, 44.05440665781498, 41.03865668177605, 40.431000888347626, 41.756251975893974, 41.61103516817093, 39.75472077727318, 41.601170897483826, 40.372081249952316, 42.321752831339836, 45.63386030495167, 52.30896212160587, 51.20830558240414, 58.22798050940037, 47.62629099190235, 43.21297600865364, 52.23204664885998, 53.21920707821846, 52.9899425804615, 51.28286898136139, 51.93612612783909, 40.37658400833607, 39.9356784671545, 37.77286872267723, 39.032326340675354, 40.06086274981499, 39.20891046524048, 42.93225847184658, 44.099232852458954, 47.85932868719101, 44.73563030362129, 40.81088550388813, 42.88599215447903, 43.66394720971584, 46.90564066171646, 50.215768441557884, 49.77487429976463, 51.06355994939804, 53.5091657191515, 49.78769101202488, 52.156909480690956, 51.75853505730629, 51.31187282502651, 44.40354332327843, 40.44531092047691, 40.54184094071388, 49.051499515771866, 49.94805000722408, 51.79304860532284, 49.273802787065506, 49.07346993684769, 47.232187539339066, 49.10662695765495, 32.41585537791252, 15.855244863778353, 3.347935276106, 2.393762064166367, 4.036400858312845, 14.554394166916609, 14.823851007968187, 16.072561852633953, 15.993269607424736, 6.578710014000535, 0.7008853345178068, 2.6595103042200208, 4.704705672338605, 0.9547241823747754, 0.6392685533501208, 1.1224818555638194, 6.0020102094858885, 16.346435956656933, 30.882094278931618, 35.46216331422329, 39.25630912184715, 25.764661878347397, 5.799063099548221, 0.28121468669269234, 0.22278663207544014, 0.1776516149402596, 0.17795818130252883, 0.14730492926901206, 0.17298798862611875, 0.19155166985001415, 0.17371962749166414, 0.1694358472013846, 0.12652164761675522, 0.1307698493474163, 0.146203878975939, 0.15129993989830837, 0.04823072289582342, 0.14607339457143098, 0.13177934830309823, 0.155894516792614, 0.09608053849660791, 0.06966014057979919, 0.12947690935106948, 0.1542822306510061, 0.16286261554341763, 0.11163100367411971, 0.1045521542255301, 0.1132863640668802], [0.007724756806055666, 0.022761622858524788, 0.056619344250066206, 0.029060827619105112, 0.05589936823525932, 0.019903263346350286, 0.051890520262531936, 0.06584145681699738, 0.04275543935364112, 0.05228394016739912, 0.051232866098871455, 0.03580406118999235, 0.036945213432773016, 0.04625717039743904, 0.04456609414773993, 0.06416029194951989, 0.10594299834338017, 0.02255527982924832, 0.049697232680046, 0.03946613323932979, 0.025111041613854468, 0.044010626297676936, 0.05588743821135722, 0.030944908648962155, 0.12517239345470443, 0.00833977783258888, 0.03406717958569061, 0.043099988834001124, 0.05417290267359931, 0.03296058173873462, 0.12160097845480777, 5.24673281237483, 17.52616625279188, 34.1425359249115, 39.50979731976986, 23.9914870262146, 20.9415502846241, 9.955950267612934, 3.6439334554597735, 0.2166159264743328, 0.03962912371207494, 0.10745845647761598, 0.045890538312960416, 0.04944808257278055, 0.04543266288237646, 0.25666171044576913, 0.2402174545568414, 0.21517808956559747, 0.15152598323766142, 2.4608626635745168, 16.538941226899624, 33.553141951560974, 49.714617133140564, 55.18285050988197, 53.83000910282135, 54.395813941955566, 54.221752882003784, 53.31413358449936, 53.47562111914158, 51.581890136003494, 46.72052979469299, 42.62121856212616, 50.14179401099682, 52.30871133506298, 52.632685750722885, 52.976491302251816, 51.8732813000679, 49.78986829519272, 49.00531679391861, 50.159748047590256, 48.8935723900795, 50.04253953695297, 50.697191208601, 49.41890560090542, 51.59597598016262, 50.57521015405655, 47.059353813529015, 43.094342574477196, 41.12128704786301, 37.65789829194546, 37.56542265415192, 37.052256390452385, 37.226203456521034, 37.440720945596695, 40.26432663202286, 41.77202492952347, 49.75784741342068, 47.16700963675976, 56.07787348330021, 41.94619998335838, 39.02899391949177, 56.55960403382778, 49.67378072440624, 49.6821478754282, 46.318526566028595, 44.55791383981705, 38.60850468277931, 36.44423581659794, 35.11237308382988, 40.915094912052155, 36.70082084834576, 34.19822573661804, 37.13984929025173, 38.07217866182327, 37.599404230713844, 37.94826731085777, 35.831792280077934, 36.16996273398399, 37.321217358112335, 39.072038009762764, 39.495627880096436, 44.11804564297199, 47.00867213308811, 47.236758694052696, 51.17196053266525, 50.84593042731285, 47.970845103263855, 47.086263969540596, 42.831005305051804, 37.98579029738903, 39.739635586738586, 44.67519834637642, 48.32172207534313, 48.66703614592552, 50.648242235183716, 50.05436070263386, 45.55995047092438, 32.839164063334465, 15.745978876948357, 3.965558409690857, 1.162241140846163, 1.866887561045587, 2.7685630274936557, 5.621329536661506, 8.559662941843271, 7.412904426455498, 4.780473131686449, 1.919453227892518, 0.37665229523554444, 1.2617662316188216, 1.435055814217776, 0.05023247700592037, 0.16547225910471752, 2.503086947835982, 6.054705306887627, 10.102999527007341, 19.505637735128403, 21.135214492678642, 27.236454002559185, 12.084931377321482, 0.8364707278087735, 0.006628407090829569, 0.09221459476975724, 0.01907445323013235, 0.017176035762531683, 0.009626442042645067, 0.03244061452278402, 0.019146562153764535, 0.04471810083487071, 0.022863182057335507, 0.040499469978385605, 0.07423835311783478, 0.013072597357677296, 0.05592892055574339, 0.02986544928717194, 0.07381921037449501, 0.02342471696465509, 0.05644326600304339, 0.08678044847329147, 0.015231302713800687, 0.01841392138885567, 0.030810162461420987, 0.06134965624369215, 0.052464638283709064, 0.05312188797688577, 0.043811749274027534, 0.0349482981255278, 0.029418609592539724, 0.09728163771796972, 0.02654399890161585, 0.015353113267337903, 0.009525778987153899, 0.08006467993254773, 0.1065243745688349, 0.06380553051712923, 0.01567590112244943, 0.028483087917265948, 0.0251269031650736, 0.06780506082577631, 0.04519601054198574, 0.09804972345591523, 0.09296263509895653, 0.050497189949965104, 0.024083280259219464, 0.0606078944838373, 0.05057031004980672, 0.024517204728908837, 0.07205674322904088, 0.042334682439104654, 0.004383009609227884, 0.045486854505725205, 0.0065494889622641494, 0.045510495619964786, 0.03655727057775948, 0.06003365029755514, 0.06833937004557811, 0.22498897014884278, 6.131110182031989, 22.33097232878208, 41.238628551363945, 42.43685245513916, 29.084063060581684, 23.469239249825478, 14.634244032204151, 3.8306839345023036, 0.3911964304279536, 0.011520056887093233, 0.10576386615866795, 0.06991987000219524, 0.021673788360203616, 0.15046919463202357, 0.042153505637543276, 0.09318022537627257, 0.49926465027965605, 0.40476505702827126, 2.581335436552763, 17.945369258522987, 35.493595227599144, 51.01312145590782, 56.70028768479824, 55.03321833908558, 57.43173323571682, 57.90256217122078, 55.655963122844696, 55.001049265265465, 52.45708577334881, 48.094688057899475, 44.77587014436722, 51.92581728100777, 54.34484347701073, 56.882453709840775, 53.46159607172012, 50.86682550609112, 50.14204479753971, 51.15128584206104, 51.821824461221695, 50.389046743512154, 50.531653091311455, 52.01101630926132, 51.95043236017227, 52.2883178293705, 51.498780995607376, 49.6878057718277, 45.29114909470081, 41.186818331480026, 39.361092299222946, 40.44355161488056, 38.76163266599178, 38.58612008392811, 39.4793913513422, 41.17385722696781, 42.597777619957924, 50.57064279913902, 49.358678832650185, 57.08583779633045, 45.22429168224335, 40.68106546998024, 56.7409873008728, 51.09425850212574, 52.496812641620636, 47.999031990766525, 46.601018607616425, 39.479060769081116, 39.85775984823704, 36.15842655301094, 41.55446380376816, 38.866963014006615, 36.553472355008125, 38.14332224428654, 38.91941159963608, 39.73156861960888, 40.24664618074894, 38.20701442658901, 39.11504790186882, 38.905378952622414, 40.78494809567928, 42.128373607993126, 46.1108373105526, 48.1031996011734, 50.770154893398285, 49.92492064833641, 50.372164249420166, 50.538770109415054, 49.12242271006107, 43.55719953775406, 40.529905781149864, 40.579360127449036, 45.50600476562977, 49.71508830785751, 51.244722828269005, 51.756498366594315, 50.06644405424595, 46.12382121384144, 36.512286365032196, 19.113453179597855, 4.7600478027015924, 2.5237020291388035, 4.129592282697558, 3.556721485219896, 7.45507076382637, 10.055908653885126, 7.154900170862675, 8.543451111763716, 5.048056673258543, 1.0046118241734803, 1.4381521730683744, 0.15987420949386433, 0.13441510061966255, 0.06370829432853498, 2.425470412708819, 7.8249334171414375, 13.12977746129036, 22.99627672880888, 25.943316891789436, 31.471499651670456, 15.999064296483994, 1.3803938473574817, 0.03543388163961936, 0.07199547893833369, 0.01159668920081458, 0.06364833621773869, 0.021752250067947898, 0.03527179287630133, 0.04743540775962174, 0.09466059476835653, 0.018785466490953695, 0.029715221899095923, 0.049807200412033126, 0.0626610942708794, 0.059728341875597835, 0.006795189474360086, 0.04377285331429448, 0.03875005721056368, 0.04668908179155551, 0.043610512220766395, 0.03839053861156572, 0.006765783728042152, 0.013688874932995532, 0.030113753346086014, 0.10807799393660389, 0.024814835633151233, 0.023002013767836615, 0.09670179031672888, 0.17399206990376115, 0.25978763645980507, 0.15105262660654262, 0.09655008791014552, 0.1064028924156446, 0.11875969576067291, 0.1771378706325777, 0.15216550673358142, 0.18479070451576263, 0.15795963176060468, 0.16080606495961547, 0.11044165265047923, 0.11551674790098332, 0.13791821576887742, 0.1738608136656694, 0.12524824094725773, 0.09103361517190933, 0.16007347614504397, 0.14991855074185878, 0.09764958711457439, 0.27288657263852656, 0.22649901802651584, 0.1349244365701452, 0.2260297877364792, 0.14760499441763386, 0.18955983454361558, 0.10264977740007453, 0.2569993579527363, 0.13927506952313706, 0.3651776828337461, 6.907207611948252, 25.71122344583273, 46.69151455163956, 53.43444272875786, 35.28119042515755, 32.10914723575115, 16.906269416213036, 5.284924088045955, 0.8147708640899509, 0.11683284290484153, 0.27730733854696155, 0.28599209908861667, 0.25587752752471715, 0.25225676712580025, 0.4160270589636639, 1.854398581199348, 1.5719242324121296, 0.5953709338791668, 3.848635358735919, 18.410889878869057, 37.55709730088711, 51.13284543156624, 57.79850095510483, 55.470635667443275, 59.12206493318081, 59.228573217988014, 58.54619823396206, 57.01469421386719, 55.66263936460018, 51.21400907635689, 47.4311600625515, 54.059794172644615, 57.4949162453413, 57.754404321312904, 56.02371498942375, 52.709741815924644, 50.88012859225273, 50.70700988173485, 53.194018229842186, 50.24327136576176, 50.84907665848732, 53.046909123659134, 53.44287067651749, 56.13718830049038, 54.1305273771286, 51.97131983935833, 47.14570418000221, 44.64630089700222, 42.626796662807465, 41.29599407315254, 40.76919034123421, 39.45910423994064, 41.33286729454994, 44.63238224387169, 45.262620225548744, 53.631344363093376, 52.53163397312164, 58.10467712581158, 48.35224583745003, 45.183968245983124, 56.66546255350113, 51.88466168940067, 53.335473239421844, 51.07534311711788, 49.2589645832777, 43.31108294427395, 40.12960106134415, 38.278226405382156, 43.92649032175541, 39.57652173936367, 37.60525591671467, 39.393455162644386, 41.17243230342865, 42.30336181819439, 42.14738018810749, 40.271116867661476, 40.123494789004326, 40.62500707805157, 42.938505336642265, 44.030502140522, 48.16316798329353, 50.597055181860924, 52.52449035644531, 52.03008748590946, 52.49913811683655, 53.439637050032616, 51.338577792048454, 46.569624692201614, 42.35441967844963, 42.93118692934513, 47.229588478803635, 52.733323350548744, 53.170144110918045, 53.69742661714554, 49.08955827355385, 47.236260920763016, 34.93249833583832, 18.21531817317009, 4.903726642951369, 2.1064851293340325, 4.153962749987841, 6.253402819857001, 11.211685985326767, 14.857692942023277, 15.726917199790478, 14.31825963780284, 5.813692314550281, 0.5650106223765761, 5.420742575079203, 4.594692550599575, 0.2969557873439044, 0.5357898934744298, 3.4121834160760045, 9.28033322095871, 17.79623296111822, 30.049006082117558, 32.234817892313, 35.26705898344517, 16.86486303806305, 1.573742909822613, 0.11004995452822186, 0.1791738488827832, 0.13731464190641418, 0.06176637216412928, 0.11596303840633482, 0.1784548710566014, 0.14240191580029204, 0.23767850798321888, 0.12839773757150397, 0.1053567610506434, 0.11080781347118318, 0.16841647768160328, 0.1421343715628609, 0.08624445457826369, 0.13155342370737344, 0.09810130271944217, 0.1476891539641656, 0.11093559645814821, 0.12632707133889198, 0.21006083290558308, 0.13346362276934087, 0.19220970250898972, 0.17545782640809193, 0.11674135836074129, 0.10492198867723346], [0.07257746372488327, 0.010434147334308363, 0.05405749870988075, 0.020821400212298613, 0.02827280779456487, 0.04322009801398963, 0.05403580202255398, 0.11918717282242142, 0.04645953551516868, 0.04810883627214935, 0.061670980212511495, 0.06188126775668934, 0.04442803612619173, 0.05095182219520211, 0.024850115478329826, 0.029736118922301102, 0.05330767722625751, 0.04312592318456154, 0.037485730717889965, 0.04188790211628657, 0.010133384566870518, 0.03509392976411618, 0.029937669532955624, 0.13958568801172078, 0.04598955565597862, 0.03838004464341793, 0.039793205141904764, 0.041237543264287524, 0.0643447379115969, 0.03755534788069781, 0.03554095499566756, 1.4771495992317796, 8.366277068853378, 26.684847101569176, 36.0102991014719, 28.955004885792732, 18.167138658463955, 16.60326987504959, 7.750768521800637, 1.391380364075303, 0.04130889334192034, 0.04240449256030843, 0.013961797885713167, 0.06296397958067246, 0.04226256794936489, 0.13992842665174976, 0.5623280850704759, 0.4961093352176249, 1.0298880678601563, 0.33759288489818573, 3.1867474503815174, 18.192116618156433, 31.689959429204464, 45.54405212402344, 51.5497400611639, 54.179305359721184, 53.64875502884388, 53.912077099084854, 53.98342207074165, 53.25307086110115, 51.18453025817871, 43.6577383428812, 43.379304483532906, 49.29666996002197, 51.79702319204807, 54.3630862981081, 53.21755796670914, 53.14617499709129, 51.40692092478275, 48.26782576739788, 49.184963554143906, 48.046822026371956, 51.64302885532379, 50.38249969482422, 53.47139194607735, 49.450493305921555, 49.575878977775574, 48.31908881664276, 48.20274665951729, 42.47360788285732, 38.99783559143543, 36.01008251309395, 39.11286301910877, 36.156785041093826, 39.7223275154829, 41.29354700446129, 50.44393479824066, 47.67150096595287, 57.68291115760803, 41.99232570827007, 40.95597691833973, 52.83379375934601, 49.2084576934576, 47.59805850684643, 46.506639271974564, 43.40145729482174, 40.5752981454134, 38.117913007736206, 37.31414593756199, 38.080807998776436, 35.38654737174511, 35.48715077340603, 35.67578785121441, 39.00728568434715, 36.746148616075516, 36.94390520453453, 35.594654604792595, 35.048046335577965, 36.84874311089516, 37.588153034448624, 37.55576357245445, 40.394598841667175, 46.02724179625511, 46.54588736593723, 48.97307552397251, 48.29918548464775, 49.64189663529396, 46.41892857849598, 44.500639513134956, 40.52353732287884, 44.45311166346073, 45.61345539987087, 46.87084972858429, 48.51605884730816, 47.42827221751213, 45.151031613349915, 36.81287303566933, 20.908951833844185, 7.36251438036561, 1.1558875255286694, 1.6090846946462989, 5.350263481959701, 2.950596297159791, 8.421603050082922, 10.40791891515255, 4.017747659236193, 7.226179596036673, 5.1635391265153885, 0.8264617086388171, 0.6325586477760226, 0.5656898359302431, 0.2300936251413077, 0.4052413970930502, 8.718237932771444, 22.26773802191019, 37.854070365428925, 24.09015443176031, 25.686412677168846, 21.65654081851244, 4.551075166091323, 0.03732809112989344, 0.03856624949548859, 0.09283330844482407, 0.015118029641598696, 0.05578221651376225, 0.06736792842275463, 0.03437259561906103, 0.044421939383028075, 0.04122582475247327, 0.05744660513300914, 0.05333607921784278, 0.011665274778351886, 0.05494625394931063, 0.02406636114756111, 0.06211862884811126, 0.045531450159614906, 0.0821000050927978, 0.052656194020528346, 0.020483674779825378, 0.057473047854728065, 0.021650310518452898, 0.038893313976586796, 0.02323397944564931, 0.0765552268421743, 0.0454270336922491, 0.02857663934264565, 0.1358182347030379, 0.04038648170535453, 0.01370768095512176, 0.03255394047300797, 0.050927954725921154, 0.039353237734758295, 0.010252990014123498, 0.028839372607762925, 0.012513367746578297, 0.008358904833585257, 0.037863238976569846, 0.06741552977473475, 0.03127892705379054, 0.02170685289456742, 0.07886260849772952, 0.0462548326322576, 0.0754658727964852, 0.012494486581999809, 0.09469811033341102, 0.033740092840162106, 0.02763807486189762, 0.06450755026889965, 0.0387876989407232, 0.061431849098880775, 0.03326989775814582, 0.04575947874400299, 0.016461226950923447, 0.04607763003150467, 0.047810177493374795, 0.044702760642394423, 0.019401014906179626, 2.183475885540247, 11.980641223490238, 32.38586738705635, 46.281592547893524, 34.37139004468918, 26.465456373989582, 20.510220229625702, 7.923123948276043, 1.8154062610119581, 0.017239966218767222, 0.04419730612426065, 0.0723262615792919, 0.03755827565328218, 0.030832630982331466, 0.2272336551686749, 0.3023851616308093, 1.103842668235302, 2.341675409115851, 0.2745262737153098, 3.879018290899694, 19.34277467429638, 33.138360008597374, 48.32068853080273, 51.65627874433994, 55.08701965212822, 55.10323338210583, 56.1950021982193, 55.51060572266579, 54.23077739775181, 52.21336305141449, 45.276451483368874, 46.30092591047287, 53.27526547014713, 53.739896938204765, 55.713518634438515, 55.03603778779507, 53.427675291895866, 50.19352823495865, 48.50079506635666, 50.30669376254082, 49.33097831904888, 52.26762033998966, 50.82703784108162, 54.21423688530922, 51.672606468200684, 52.12175376713276, 49.11097012460232, 49.916298910975456, 42.96688601374626, 41.19910307228565, 36.78014159202576, 39.868357479572296, 38.058408200740814, 40.2457532286644, 44.41037155687809, 51.5723792463541, 48.88091906905174, 57.257824167609215, 43.942514061927795, 43.77078987658024, 54.23063300549984, 51.66683457791805, 48.67057375609875, 48.22665497660637, 45.14343962073326, 42.11496792733669, 39.71951566636562, 39.70318794250488, 39.474147632718086, 38.033291548490524, 37.2492416203022, 37.08600617945194, 40.26634432375431, 38.7468970566988, 38.22477087378502, 38.320354744791985, 36.40791356563568, 38.68828520178795, 39.50217492878437, 39.38409626483917, 42.73484006524086, 47.94212244451046, 50.04830002784729, 49.95368890464306, 48.86488012969494, 49.96454872190952, 48.949805572628975, 45.85866004228592, 42.08587288856506, 45.40485039353371, 47.522826343774796, 49.45480227470398, 49.10090446472168, 48.404637426137924, 45.89082531630993, 40.028788670897484, 23.16045831888914, 9.259617682546377, 2.5758789293468, 3.4156490676105022, 3.8680924521759152, 5.942393783479929, 7.575026052072644, 11.550499554723501, 11.119306292384863, 11.058797389268875, 4.765616878867149, 2.6355072297155857, 1.1743974010460079, 0.1305531125399284, 0.30122497701086104, 0.5801539379172027, 9.396589882671833, 19.14523847401142, 31.96568213403225, 25.852699354290962, 28.389044255018234, 26.199278756976128, 6.658572228625417, 0.144203063682653, 0.06748809697455727, 0.022153004247229546, 0.06831424092524685, 0.043350541600375436, 0.02620997493067989, 0.03138385189231485, 0.03320777257613372, 0.032342907070415094, 0.045652115950360894, 0.04782488686032593, 0.012039918346999912, 0.03274067596066743, 0.019435430149314925, 0.06632469885516912, 0.014228479376470204, 0.06919571940670721, 0.016365664305340033, 0.0029076914597681025, 0.0643124248017557, 0.005384960923038307, 0.054742575230193324, 0.02064009167952463, 0.032061647943919525, 0.09334600632428192, 0.01630487313377671, 0.24039663869189098, 0.10671126961824484, 0.16057853732490912, 0.08864821895258501, 0.11473019010736607, 0.16851363965542987, 0.11789159078034572, 0.18382420559646562, 0.1465548257692717, 0.12911765050375834, 0.13534079625969753, 0.139453288866207, 0.12599022535141557, 0.24139740999089554, 0.19331064890138805, 0.17460023023886606, 0.1692255077068694, 0.20634104032069445, 0.14198402728652582, 0.13044835097389296, 0.11398008660762571, 0.12195035931654274, 0.07016152812866494, 0.25861130270641297, 0.17381949088303372, 0.16101601853733882, 0.13981187978060916, 0.15654572169296443, 0.12308257981203496, 0.10301904781954363, 0.11802125882240944, 1.861986774019897, 12.169307749718428, 39.74604584276676, 50.22989608347416, 42.0401993393898, 28.664924651384354, 25.045090690255165, 11.214777119457722, 2.3320894734933972, 0.24398235487751663, 0.29759706230834126, 0.22222797299036756, 0.18431993055855855, 0.2780264202738181, 0.5374614475294948, 1.1869167792610824, 1.0589055670425296, 2.6250053057447076, 0.8499417174607515, 4.199957856908441, 18.956211917102337, 34.268183782696724, 48.08525316417217, 52.132169008255005, 55.85468105971813, 54.66499149799347, 57.2366289049387, 58.48402597010136, 58.071257919073105, 54.91628721356392, 49.14533548057079, 48.53905141353607, 55.098875015974045, 56.55811071395874, 57.94396474957466, 56.433807983994484, 55.03517523407936, 52.02684625983238, 48.83162051439285, 49.46659304201603, 49.86375153064728, 53.26781406998634, 51.43461383879185, 57.78666839003563, 51.80564492940903, 53.71340095996857, 52.00260356068611, 52.576604560017586, 46.67798727750778, 44.1641865670681, 38.53837564587593, 41.960050240159035, 40.004040598869324, 42.77735598385334, 46.29843324422836, 53.77982519567013, 52.639365792274475, 58.70294742286205, 47.339926958084106, 46.3185303658247, 56.01806849241257, 53.65558706223965, 49.19256694614887, 50.687756314873695, 45.72729729115963, 44.8915359377861, 40.80124922096729, 40.71039229631424, 41.351159512996674, 39.46801856160164, 38.67886930704117, 38.66960920393467, 42.533139288425446, 39.76919040083885, 39.40126374363899, 39.32057127356529, 38.273826241493225, 40.61361148953438, 42.55086533725262, 42.50387705862522, 45.1920086145401, 50.10861039161682, 51.28224961459637, 51.919418424367905, 49.75169934332371, 52.884547635912895, 51.32864132523537, 48.98922085762024, 44.49382647871971, 49.099692329764366, 49.94627930223942, 50.81548646092415, 51.311223059892654, 47.84584321081638, 45.4350283741951, 39.92451086640358, 22.692384235560894, 9.131861887872219, 2.198688369244337, 3.664842308498919, 9.736626036465168, 8.604644928127527, 13.681634198874235, 21.95381596684456, 13.29266807064414, 18.329122066497803, 11.299353931099176, 5.827618567273021, 3.556431750766933, 1.3711108267307281, 0.8007492602337152, 0.8198809367604554, 11.48040471598506, 26.394337490200996, 43.003196865320206, 32.54213020205498, 36.638504192233086, 29.324941635131836, 7.276588641107082, 0.28694875712972134, 0.13694281107746065, 0.13917627482442185, 0.19415352086070925, 0.19074620213359594, 0.20122396177612245, 0.1574862899724394, 0.22526170942001045, 0.14461725630098954, 0.11251147283473983, 0.17084224673453718, 0.08434446746832691, 0.20612166146747768, 0.13263596483739093, 0.18663725699298084, 0.11578318633837625, 0.15902682527666911, 0.12658947991440073, 0.0641385989729315, 0.17366693500662223, 0.12720279075438157, 0.19225955998990685, 0.16697766113793477, 0.20272511872462928, 0.18714228848693892, 0.09328037078375928], [0.038734086192562245, 0.11854998709168285, 0.023828029698051978, 0.07172187877586111, 0.07348518454818986, 0.026639012357918546, 0.007565812429675134, 0.061814222135581076, 0.02936380940809613, 0.02421527122351108, 0.020178527774987742, 0.01990556400414789, 0.06981308979447931, 0.021053271266282536, 0.023105263207980897, 0.07170803772169165, 0.059174543857807294, 0.024954138607427012, 0.05761702821473591, 0.04802901457878761, 0.045507337781600654, 0.023796206405677367, 0.026899663898802828, 0.043103317366330884, 0.07614806236233562, 0.06481101445388049, 0.06096494173107203, 0.054974307131487876, 0.03312883403850719, 0.07140694098779932, 0.04512329862336628, 0.2133982116356492, 4.556781034916639, 17.074419893324375, 28.69119644165039, 27.108794152736664, 26.00934024900198, 27.037673369050026, 9.010926727205515, 2.8211020957678556, 0.4095866420539096, 0.07506776993977837, 0.07192531629698351, 0.02691203735594172, 0.030812706172582693, 0.06845769807114266, 0.04311659067752771, 1.3800697959959507, 1.3152141636237502, 1.1240482027642429, 0.07758491963613778, 2.9377335123717785, 14.150548037141562, 27.499487288296223, 43.54735806584358, 51.463142707943916, 54.47264961898327, 53.220609202980995, 53.30409832298756, 54.826809614896774, 51.12504445016384, 47.04657509922981, 42.233985140919685, 44.392162933945656, 50.19124075770378, 51.462842524051666, 53.62125210464001, 52.29974381625652, 52.95957840979099, 50.03495134413242, 49.516624957323074, 48.561967983841896, 51.494578421115875, 48.43662030994892, 51.325852274894714, 52.16924361884594, 50.81288360059261, 50.43909765779972, 49.57669213414192, 49.954456463456154, 44.950071796774864, 37.67318867146969, 36.89271055161953, 36.47607430815697, 40.98974950611591, 46.161591187119484, 49.51236538589001, 48.606858775019646, 58.09743091464043, 42.35264517366886, 39.81224209070206, 56.1721084266901, 48.80926251411438, 47.56213143467903, 45.18431782722473, 45.66788747906685, 42.839813232421875, 40.0650729238987, 36.19447901844978, 36.015679612755775, 34.82327699661255, 36.705680787563324, 36.92159280180931, 39.51314873993397, 36.318048387765884, 36.61183342337608, 36.32340230047703, 38.27870897948742, 38.40871140360832, 40.8094035834074, 43.01564119756222, 43.53824235498905, 45.68129315972328, 48.653345480561256, 49.08333420753479, 48.07886950671673, 47.36974775791168, 46.578801199793816, 46.78586348891258, 45.473828092217445, 45.23725278675556, 46.81204788386822, 47.248815447092056, 50.080005526542664, 49.86101187765598, 39.99229162931442, 26.62948217242956, 11.51361208409071, 2.8741227881982923, 0.9925525775179267, 2.705326108261943, 3.1890311278402805, 2.4627896351739764, 4.439557800069451, 8.668248765170574, 8.04598655551672, 6.633411878719926, 3.5617901757359505, 2.2382884193211794, 0.79132309416309, 0.13217856438132003, 0.46537667338270694, 1.9774210173636675, 10.852690748870373, 25.387342125177383, 28.518212623894215, 30.246808268129826, 26.716696992516518, 11.225734781473875, 1.7309331125579774, 0.05713908882171381, 0.016831074390211143, 0.030632722373411525, 0.10471998350112699, 0.02540069257520372, 0.06424846651498228, 0.06280202811467461, 0.06328310308163054, 0.048982392327161506, 0.030787289470026735, 0.0810785056091845, 0.0029073769746901235, 0.058942481700796634, 0.08179732016287744, 0.013477501070155995, 0.04125728810322471, 0.06012649668264203, 0.0031604282276020967, 0.09679809139925055, 0.042592842219164595, 0.08033462130697444, 0.016311799226969015, 0.04286875788238831, 0.03326156715047546, 0.06419885394279845, 0.01777722547558369, 0.0632946657424327, 0.08175934446626343, 0.021575622631644364, 0.05411069585534278, 0.02980589935759781, 0.0377936886070529, 0.03520345220749732, 0.052987473900429904, 0.046824879973428324, 0.06606871727854013, 0.03710776232765056, 0.025641230058681685, 0.1364383436157368, 0.04220750430249609, 0.0678510294528678, 0.021927346824668348, 0.04293688703910448, 0.04029105635709129, 0.025443421727686655, 0.026648649145499803, 0.03823170787654817, 0.021060089748061728, 0.01432201224815799, 0.033413926357752644, 0.06535569147672504, 0.012846017816627864, 0.011472436053736601, 0.09344908321509138, 0.04054760567669291, 0.05889799365832005, 0.11282540872343816, 0.4708696942543611, 5.357335852459073, 22.602368965744972, 36.943532824516296, 34.549938663840294, 25.77570218592882, 31.133076511323452, 12.207518499344587, 3.716249749995768, 0.42213000648189336, 0.11389796796720475, 0.09819151076953858, 0.0969350547529757, 0.05557731325097848, 0.12330354686127976, 0.14937369560357183, 0.09040437784278765, 3.8235783157870173, 1.9848073460161686, 0.8773883571848273, 4.7696722112596035, 17.766345664858818, 31.781785301864147, 47.327011451125145, 52.883510291576385, 55.356489792466164, 54.108895137906075, 56.066147312521935, 56.19528338313103, 53.62164728343487, 48.25968660414219, 44.9826018512249, 46.878118738532066, 52.190488278865814, 53.458681628108025, 55.2037987858057, 53.415352553129196, 53.90544645488262, 50.546008720993996, 49.421432465314865, 49.359434992074966, 51.857025772333145, 48.69396910071373, 53.18135350942612, 52.89100728929043, 52.32119366526604, 51.76092512905598, 52.1942500770092, 51.68587915599346, 45.380512699484825, 39.84406918287277, 38.94097924232483, 37.00087174773216, 41.76323980093002, 45.38149684667587, 51.212599352002144, 50.849817618727684, 57.901049852371216, 45.56139059364796, 40.23110121488571, 56.61814749240875, 50.91890171170235, 49.710631147027016, 47.579447105526924, 45.546803176403046, 43.719808012247086, 40.41582070291042, 38.36825877428055, 36.96361854672432, 36.49481490254402, 37.44291342794895, 38.457291796803474, 41.60262241959572, 38.59167918562889, 36.132154762744904, 37.505154088139534, 39.768704026937485, 40.22905692458153, 43.46946984529495, 43.44063699245453, 45.17226867377758, 46.69228971004486, 50.21808631718159, 49.24573369324207, 48.304360806941986, 49.57978896796703, 48.69706213474274, 47.082893550395966, 46.50645688176155, 47.207903042435646, 48.750004693865776, 49.738764837384224, 50.37906087934971, 49.111380502581596, 42.260234132409096, 27.397031486034393, 13.032865561544895, 4.033105485141277, 2.521394365467131, 5.238982178270817, 4.736503791064024, 7.806345764547586, 8.477895129472017, 8.95823210477829, 7.793220318853855, 8.025966379791498, 7.239732518792152, 2.4546362226828933, 0.3941991302417591, 0.05931097286520526, 0.3889671969227493, 2.4796341313049197, 11.941186040639877, 32.28304110467434, 34.75296176970005, 33.11027951538563, 31.160640232264996, 14.95344590395689, 2.4421225441619754, 0.02458384773490252, 0.02328967020730488, 0.04853366386669222, 0.07643467237357982, 0.04538940680504311, 0.03977985390520189, 0.04562562127830461, 0.026351047927164473, 0.02070207214273978, 0.035399980333750136, 0.049992221538559534, 0.0303308482398279, 0.02264600552734919, 0.041526331478962675, 0.028560325081343763, 0.03259355631598737, 0.026899617514573038, 0.04079890430148225, 0.05335095556802116, 0.016783317187218927, 0.09741445988765918, 0.02110660385369556, 0.013519341500796145, 0.05124728231749032, 0.059869127289857715, 0.032056037307484075, 0.18670194258447737, 0.2000673394650221, 0.11086248749052174, 0.17406413244316354, 0.12491816334659234, 0.16367290721973404, 0.07964610122144222, 0.151967917336151, 0.10886535324971192, 0.1150402519851923, 0.11627363463048823, 0.08925816044211388, 0.2785657538333908, 0.1250309994793497, 0.18118555890396237, 0.11016866847057827, 0.10804994817590341, 0.13676338945515454, 0.17042795021552593, 0.132055516296532, 0.09160938076092862, 0.2062203671084717, 0.08100747465505265, 0.2049795852508396, 0.18499617552151904, 0.1678911707131192, 0.09625766688259318, 0.14067584357690066, 0.1209766541433055, 0.170824138331227, 0.2586578798945993, 0.5846815730910748, 6.438053911551833, 25.23260112851858, 44.10522133111954, 44.717383682727814, 35.12685410678387, 39.7915294021368, 14.857231266796589, 4.964571828022599, 0.716011313488707, 0.31656184466555715, 0.2850967721315101, 0.2879286592360586, 0.173732629918959, 0.3104153776075691, 0.2228702127467841, 2.962963921017945, 4.143978785723448, 1.896018460392952, 0.5727066344115883, 3.362200898118317, 15.96877422183752, 32.17234544456005, 46.20184622704983, 54.58032824099064, 55.267737954854965, 56.52845710515976, 56.25462479889393, 58.58869135379791, 55.225461423397064, 51.44288219511509, 46.901871263980865, 48.75745229423046, 52.38104805350304, 55.41159063577652, 57.575741708278656, 55.33606968820095, 55.210851207375526, 52.147459387779236, 50.09687282145023, 49.36342477798462, 51.386436223983765, 49.15532894432545, 52.65972889959812, 56.58936783671379, 54.88932006061077, 55.29033914208412, 54.40322354435921, 54.861608147621155, 48.02031084895134, 42.64941304922104, 39.82760846614838, 39.44357067346573, 44.204228818416595, 49.16438765823841, 52.41271175444126, 52.87047319114208, 58.82744014263153, 47.56186544895172, 43.13288010656834, 57.628194093704224, 53.02193686366081, 50.385832116007805, 50.48691809177399, 48.22202682495117, 46.999267637729645, 43.831841200590134, 39.85963314771652, 39.86967220902443, 38.35153587162495, 39.78971689939499, 40.40351316332817, 43.57050262391567, 40.991877391934395, 39.75548453629017, 39.91550154983997, 42.283686473965645, 42.406689673662186, 44.2005468159914, 46.79270312190056, 47.2207273542881, 49.29313614964485, 52.72124759852886, 51.3369894772768, 48.93445439636707, 52.320266515016556, 51.7632620036602, 51.783089339733124, 49.120598807930946, 48.86966027319431, 50.31904689967632, 51.19379036128521, 51.28832168877125, 49.921991005539894, 42.0910520106554, 28.32243002951145, 12.10212355479598, 4.488681089133024, 2.4724035942927003, 7.552087157964706, 7.963447859510779, 8.175039030611515, 13.204178418964148, 17.635186202824116, 15.62586447224021, 16.72415278851986, 13.414276745170355, 7.782114939764142, 2.35589852090925, 0.4530327982502058, 0.47293241950683296, 3.314011408947408, 15.067655425518751, 35.40339186787605, 37.30565719306469, 40.07959574460983, 35.93771919608116, 16.12315993756056, 2.7391917910426855, 0.09721416907268576, 0.22919849114259705, 0.1041978232387919, 0.2594735298771411, 0.0791745405877009, 0.13879589445423335, 0.1174649820313789, 0.1858896916382946, 0.20990636228816584, 0.20133807440288365, 0.13150988932466134, 0.0719366711564362, 0.15042506653117016, 0.12775612121913582, 0.10886536067118868, 0.09569597241352312, 0.21939814905636013, 0.07895371454651468, 0.16435700410511345, 0.12345026945695281, 0.18617561145219952, 0.09162402333458886, 0.11514115438330919, 0.1456021604826674, 0.15758204186568037, 0.1279108293238096], [0.018709188552747946, 0.028665823228948284, 0.053755878761876374, 0.058219396087224595, 0.07392080296995118, 0.018331797182327136, 0.028242136686458252, 0.04311368888011202, 0.028000137172057293, 0.01356833159661619, 0.02479892584233312, 0.012373323552310467, 0.02706123130337801, 0.039184911220218055, 0.04244959287461825, 0.03559960321581457, 0.026393556290713605, 0.03228637397114653, 0.045725332529400475, 0.04088306755875237, 0.09690603677881882, 0.03186232192092575, 0.02118936630722601, 0.01579988431331003, 0.02065432050585514, 0.020452706812648103, 0.06527407007524744, 0.013546275895350846, 0.05358560410968494, 0.06581735928193666, 0.04351648211013526, 0.10650789146893658, 1.7872110614553094, 8.99063866585493, 21.55672587454319, 30.116714648902416, 29.35922719538212, 20.206599421799183, 10.837710052728653, 7.021286990493536, 1.2085651676170528, 0.09710649828775786, 0.043710167810786515, 0.062448231474263594, 0.16719384875614196, 0.176990405889228, 0.03507034060021397, 1.0919573809951544, 5.726894997060299, 1.2109265034087002, 0.6887753843329847, 0.24830163951264694, 2.1541378973051906, 8.037692550569773, 24.162688739597797, 37.943483367562294, 46.68783634901047, 51.820760518312454, 53.62589165568352, 52.388343662023544, 52.68267206847668, 48.50154362618923, 45.08442498743534, 42.938968911767006, 44.622783958911896, 46.19636312127113, 49.41801264882088, 52.45029553771019, 51.647250428795815, 51.17716625332832, 51.50588281452656, 50.88557370007038, 51.08277551829815, 50.03843575716019, 48.82849708199501, 50.72285123169422, 52.04733856022358, 50.638860538601875, 53.13566096127033, 50.356376096606255, 50.43735355138779, 41.80191412568092, 38.219253569841385, 36.563169434666634, 42.52175509929657, 47.27436147630215, 52.522708252072334, 47.20132939517498, 56.16287872195244, 40.74452966451645, 40.32047241926193, 54.56848427653313, 49.65264245867729, 49.77434612810612, 44.80007104575634, 44.23119597136974, 41.839775294065475, 39.41057324409485, 36.06652848422527, 34.62730631232262, 36.82464100420475, 35.11785998940468, 36.90952464938164, 36.876835003495216, 36.230968460440636, 36.60243272781372, 39.21489894390106, 43.847336769104004, 45.25304093956947, 46.70135222375393, 45.98361253738403, 46.64777509868145, 48.24327148497105, 48.561067432165146, 48.753895685076714, 48.537185713648796, 50.399955958127975, 50.167963206768036, 47.11152881383896, 45.76839208602905, 46.69164374470711, 47.00182870030403, 49.104263484478, 49.30516630411148, 45.07333718240261, 31.501462943851948, 15.756634455174208, 6.879256786778569, 1.8171933526173234, 2.719865315593779, 4.2114669643342495, 2.52305606380105, 8.606170546263456, 7.665488747879863, 7.0832037180662155, 8.964215833693743, 7.359839323908091, 4.396037310361862, 1.0961983096785843, 0.26456240681000054, 0.059890586489927955, 1.1731858598068357, 7.942789318040013, 17.581018209457397, 19.85124249011278, 26.284365691244602, 26.849526464939117, 19.90491271018982, 6.364435711875558, 0.4880345013225451, 0.0031488094418818946, 0.026134101462957915, 0.020269407468731515, 0.020201903571432922, 0.009528278169455007, 0.032266239504679106, 0.03548327898897696, 0.022118416454759426, 0.025867336480587255, 0.06322370158159174, 0.057226996214012615, 0.013689043771591969, 0.0120008581870934, 0.022509838127007242, 0.04406862142786849, 0.03314993329695426, 0.024301794510392938, 0.032186941025429405, 0.03852558722428512, 0.04249993275152519, 0.033367326905136, 0.06946421359316446, 0.039187159927678294, 0.0088204566782224, 0.06048726208973676, 0.01968041866348358, 0.026906372913799714, 0.0334923491027439, 0.020243716171535198, 0.07090142709785141, 0.03599196927098092, 0.01835237879276974, 0.02286476839799434, 0.02235959589597769, 0.044356147991493344, 0.10068311574286781, 0.054345685784937814, 0.01704167363641318, 0.05694655344996136, 0.024201493251894135, 0.01655925538216252, 0.04524437630607281, 0.018044819807983004, 0.054700402688467875, 0.011115019588032737, 0.053793576153111644, 0.03763556291232817, 0.038524871051777154, 0.0265294027121854, 0.026720791465777438, 0.041433904407313094, 0.058307748768129386, 0.025317017280030996, 0.024738951033214107, 0.06652259995462373, 0.041735030827112496, 0.037857350034755655, 0.05326753816916607, 2.735758200287819, 11.40875481069088, 29.218712635338306, 37.17763066291809, 35.96678763628006, 29.186423867940903, 15.62033386901021, 8.421041630208492, 1.9630760746076703, 0.08777249953709543, 0.060864877959829755, 0.08777329363510944, 0.1998606661800295, 0.23757916409522295, 0.06539804584463127, 1.6258053411729634, 5.63328274525702, 4.459278266876936, 2.322977799922228, 1.2070071324706078, 4.75415906868875, 10.794046595692635, 26.17286067456007, 41.31125025451183, 49.29587960243225, 52.70968481898308, 54.90299932658672, 54.35899391770363, 54.078162387013435, 51.162324249744415, 47.249294221401215, 44.19108912348747, 45.95796391367912, 48.367935195565224, 50.515283569693565, 54.71104882657528, 53.641212433576584, 52.08411678671837, 52.69125200808048, 52.23183386027813, 50.781235098838806, 50.79648368060589, 49.890289306640625, 52.047232165932655, 53.160967603325844, 52.44715690612793, 54.52700190246105, 52.80884049832821, 52.88891360163689, 43.188832104206085, 39.342355504631996, 38.42436656355858, 43.987104669213295, 48.90381284058094, 54.871050640940666, 49.21793058514595, 56.175319254398346, 43.37867371737957, 42.578090876340866, 55.568757802248, 51.38130649924278, 50.67504599690437, 46.126013696193695, 45.55287145078182, 43.30107808113098, 39.77828711271286, 38.0013694614172, 37.50333398580551, 37.86810681223869, 37.33102083206177, 37.826442047953606, 37.72880628705025, 36.20155803859234, 37.908411249518394, 40.98359763622284, 46.03732645511627, 46.735744178295135, 47.98703983426094, 47.798201367259026, 48.98115389049053, 49.002877324819565, 51.36172994971275, 48.81057344377041, 48.394845351576805, 50.9320680052042, 51.30215294659138, 49.48399230837822, 48.995631113648415, 47.97340616583824, 48.26387017965317, 50.87613120675087, 49.425771832466125, 45.517217963933945, 33.870827704668045, 18.611452616751194, 7.52784208394587, 3.0653116665780544, 3.96312250290066, 5.897474493831396, 4.294859664514661, 6.494532180950046, 8.929501846432686, 9.323358312249184, 7.654566233977675, 6.079140370711684, 3.430103729479015, 0.7114265626296401, 0.12788611580617726, 0.12631835852516815, 1.0175945400260389, 7.908135652542114, 17.61974573135376, 23.3755324780941, 29.51237417757511, 30.82674454897642, 26.036159209907055, 9.044410530477762, 0.5577882786747068, 0.034850887532229535, 0.051546716640586965, 0.03358206733537372, 0.026323132042307407, 0.014733858752151718, 0.047319725490524434, 0.034356223841314204, 0.04438597861735616, 0.02528731096390402, 0.024149906566890422, 0.026868438035307918, 0.03365123178809881, 0.03959952315199189, 0.04948736073856708, 0.05025346123147756, 0.017351752212562133, 0.020776600467797834, 0.01398605405483977, 0.005623160177492537, 0.015992191474651918, 0.03908766389940865, 0.03578469484637026, 0.020246304411557503, 0.015542577075393638, 0.02202612296969164, 0.03516309421684127, 0.1464212837163359, 0.13564762979513034, 0.09400528579135425, 0.16803088743472472, 0.22201509535079822, 0.13869441318092868, 0.0977519886509981, 0.0915370807342697, 0.18009819381404668, 0.1497840735828504, 0.24411859834799543, 0.14331116544781253, 0.1403308191220276, 0.11520137966726907, 0.18865417689085007, 0.16276534966891631, 0.18441807216731831, 0.13958910189103335, 0.08502466065692715, 0.11918251955648884, 0.16568182676564902, 0.1863150016288273, 0.12630698882276192, 0.1397221689694561, 0.1365390233695507, 0.1339148633996956, 0.241499692783691, 0.13231201737653464, 0.20281595760025084, 0.17376521020196378, 0.1892558953841217, 0.16656291933031753, 2.613357505761087, 12.225609328597784, 34.22815293073654, 45.602018013596535, 43.96669216454029, 33.77015970647335, 19.81419637799263, 10.554217714816332, 2.193358442746103, 0.33695802208967507, 0.29598428634926677, 0.45670482621062547, 0.47019383520819247, 0.47127312573138624, 0.1689112081658095, 2.9189736815169454, 11.508035883307457, 2.435597344301641, 2.452158755622804, 0.8271236449945718, 2.9307879600673914, 9.252432268112898, 26.999308727681637, 39.905751273036, 50.0641717761755, 52.36306741833687, 55.91250255703926, 55.80895811319351, 57.464631870388985, 53.47612649202347, 49.54740710556507, 46.07680253684521, 48.6501232534647, 49.399986416101456, 52.21926033496857, 55.787857845425606, 55.35202883183956, 53.0252730846405, 53.55093687772751, 53.310451582074165, 51.963237673044205, 51.05406045913696, 50.71873225271702, 53.14092367887497, 55.89666120707989, 53.562355265021324, 57.301206439733505, 54.85904708504677, 55.46321086585522, 45.94724088907242, 42.70227201282978, 39.846147671341896, 46.43047235906124, 51.4422894269228, 57.17529259622097, 51.53317295014858, 56.77184924483299, 43.30015853047371, 46.54743768274784, 56.93877428770065, 55.60311555862427, 53.76218654215336, 48.07163089513779, 47.7983533591032, 46.02676682174206, 41.747204661369324, 40.941986069083214, 38.271983340382576, 41.34129524230957, 37.87115424871445, 41.21704950928688, 38.46193514764309, 39.184109196066856, 39.08868491649628, 42.189858108758926, 47.012224942445755, 49.01189424097538, 50.29643051326275, 50.96762269735336, 51.813164725899696, 52.0784816890955, 51.97233438491821, 50.34446373581886, 49.635657370090485, 52.511149272322655, 53.82826119661331, 51.25251621007919, 51.311979219317436, 48.22914004325867, 49.72809121012688, 51.308772191405296, 51.54080294072628, 45.08211091160774, 33.41618210077286, 17.166183069348335, 7.7616197895258665, 3.4339669346809387, 5.811800016090274, 9.59582744166255, 7.34463918954134, 15.758719593286514, 16.995530426502228, 17.2531908005476, 18.35631910711527, 16.59006178379059, 10.620548855513334, 2.9448386561125517, 1.2150904862210155, 0.3233003674540669, 2.1341512072831392, 10.985699761658907, 24.128598868846893, 30.229802280664444, 38.52659247815609, 37.30427406728268, 29.008832797408104, 9.606573265045881, 0.6650394236203283, 0.0959361981949769, 0.18570329382782802, 0.14172264287481084, 0.09704728974611498, 0.14379083033418283, 0.16283805045532063, 0.17070206988137215, 0.12331115387496538, 0.17638466495554894, 0.18012658838415518, 0.10230890897219069, 0.09160610046819784, 0.13894767849706113, 0.14732370560523123, 0.18978250853251666, 0.14071810146560892, 0.20308817736804485, 0.10381550586316735, 0.16316186432959512, 0.1492684442200698, 0.23659598169615492, 0.13853047275915742, 0.09670620609540492, 0.07616948816576041, 0.12617733562365174, 0.12096535865566693], [0.017935423529706895, 0.041547653381712735, 0.035748645022977144, 0.0446948419266846, 0.051175624248571694, 0.0236393943123403, 0.02634648928506067, 0.048148678470170125, 0.027692886178556364, 0.05306091312377248, 0.03338860427902546, 0.010148148667212809, 0.011370672764314804, 0.06478264214820229, 0.01780618964403402, 0.026744293427327648, 0.05238194818957709, 0.03113440121524036, 0.05552422000619117, 0.020247143038432114, 0.019347350207681302, 0.013972041379020084, 0.021933514071861282, 0.0964369771827478, 0.03192686279362533, 0.03276819479651749, 0.023616621510882396, 0.029372067656368017, 0.026267222347087227, 0.021758536058769096, 0.10254017703118734, 0.09706918310257606, 0.1679767551831901, 5.386172505095601, 12.046901118010283, 23.764696195721626, 27.306453846395016, 22.461267337203026, 15.56489959359169, 9.392349310219288, 3.9996159821748734, 0.363213574164547, 0.13047880871454254, 0.15115121350390837, 0.1505738522973843, 0.09041180674103089, 0.04242097566020675, 0.22370423830579966, 3.866163343191147, 7.999014426022768, 2.4542545806616545, 2.400508364662528, 0.9826814790721983, 1.3263516034930944, 5.386870242655277, 20.43461188673973, 31.978567242622375, 40.392831936478615, 50.86158558726311, 55.72489522397518, 51.6385754942894, 51.79025575518608, 52.65773020684719, 50.35820759832859, 48.06033790111542, 45.5671738833189, 44.29826617240906, 45.41596099734306, 49.76792827248573, 50.238270834088326, 53.124645352363586, 50.573937222361565, 49.91892457008362, 47.377434745430946, 48.919270411133766, 48.141379952430725, 51.42446078360081, 51.903478279709816, 52.81412221491337, 52.9875373095274, 52.03983396291733, 46.88189193606377, 39.45799469947815, 36.34592369198799, 43.93695496022701, 48.446074202656746, 52.07982301712036, 49.96197246015072, 53.85651648044586, 42.37906135618687, 40.36031328141689, 54.62906442582607, 48.34981396794319, 48.51209565997124, 42.9229261726141, 43.77330154180527, 41.40043526887894, 38.68969492614269, 35.78831501305103, 37.18896545469761, 35.39480432868004, 37.64840640127659, 37.71834924817085, 35.68022981286049, 36.09388321638107, 36.49267181754112, 41.345930993556976, 47.24984899163246, 49.583622962236404, 50.042695328593254, 46.31957150995731, 48.38140167295933, 46.70431986451149, 44.42846238613129, 45.98148465156555, 46.97071976959705, 46.51411347091198, 47.82393358647823, 46.96477308869362, 48.64384979009628, 47.787292152643204, 49.393006190657616, 48.15724790096283, 45.08366882801056, 41.93227753043175, 26.606852486729622, 10.270065162330866, 3.856444889679551, 2.0459066424518824, 4.013808220624924, 3.392267497256398, 3.6862857453525066, 6.316376840695739, 5.63697662204504, 5.820694388821721, 2.7904220670461655, 4.59534659050405, 3.263430898077786, 0.9786636696662754, 0.04738060015370138, 0.30497994739562273, 6.0950771905481815, 14.348918292671442, 21.405839771032333, 33.086025416851044, 28.97066004574299, 23.556695356965065, 15.494530219584703, 2.531249849125743, 0.08350621166755445, 0.010381824067735579, 0.10571065417025238, 0.06845308933407068, 0.02756174868409289, 0.06576822910574265, 0.032732486361055635, 0.10643857487593777, 0.03528082110278774, 0.03515336837153882, 0.07794343633577228, 0.029781358389300294, 0.06016078019456472, 0.027706430373655166, 0.05554832867346704, 0.040845693001756445, 0.13962312194053084, 0.039442863198928535, 0.03751496391487308, 0.04766167374327779, 0.019065705164393876, 0.041810069378698245, 0.025378099744557403, 0.0620339646411594, 0.06595923565328121, 0.0553527133888565, 0.04559943459753413, 0.014840359726804309, 0.04611225122062024, 0.051710349071072415, 0.04134070179134142, 0.045522533255279996, 0.0565595679654507, 0.02119954671798041, 0.031163563908194192, 0.008732239439268596, 0.10252345644403249, 0.025899031752487645, 0.0598567371343961, 0.011539443639776437, 0.060620099102379754, 0.0369420741481008, 0.07217260732431896, 0.059368140500737354, 0.025233436608687043, 0.03465906091150828, 0.02565115999459522, 0.011014406627509743, 0.11155157902976498, 0.07389867954771034, 0.08190755135728978, 0.004516245062404778, 0.029644682617799845, 0.02640735838213004, 0.06639778555836529, 0.03500285711197648, 0.06136376818176359, 0.08000649555469863, 0.09523111337330192, 0.27310921694152057, 6.7556551191955805, 16.52453240007162, 31.47661417722702, 35.622883290052414, 29.281908944249153, 23.066597655415535, 15.255968570709229, 6.003834111616015, 0.7944800122641027, 0.18582454591523856, 0.1439682926866226, 0.294389856280759, 0.3154205996543169, 0.4140674031805247, 1.2825271300971508, 6.618423108011484, 11.744037419557571, 7.538879066705704, 4.510477669537067, 2.191233169287443, 2.672515343874693, 8.416046798229218, 23.766520097851753, 35.41512943804264, 43.44545513391495, 52.473136112093925, 57.9830152541399, 53.642166182398796, 52.40755543112755, 53.8947082310915, 52.32858046889305, 48.56586277484894, 46.16385206580162, 46.13241635262966, 48.49409602582455, 50.753846168518066, 51.84127561748028, 53.93138766288757, 51.00172586739063, 49.764884635806084, 48.41551624238491, 49.529985040426254, 48.916568756103516, 51.65295772254467, 52.04610362648964, 53.9702557772398, 53.635151758790016, 52.095219790935516, 47.719256803393364, 40.54651848971844, 38.26136291027069, 45.118737146258354, 50.57821199297905, 53.76189395785332, 52.99305081367493, 54.13984067738056, 44.845353215932846, 42.54402570426464, 55.23958146572113, 49.75805260241032, 49.704429879784584, 45.64055934548378, 46.68526388704777, 43.95896337926388, 41.04914031922817, 38.63218501210213, 39.9568585306406, 37.185652032494545, 38.1865069270134, 38.75545799732208, 37.266173511743546, 38.675487488508224, 36.93611942231655, 42.94994652271271, 49.163122326135635, 50.15891209244728, 50.73313347995281, 47.60838255286217, 48.814567029476166, 48.723884895443916, 46.132933124899864, 47.76467576622963, 49.33919347822666, 47.337001115083694, 50.71248158812523, 48.889195024967194, 49.890631288290024, 50.31693421304226, 50.18827311694622, 49.370830580592155, 46.27031475305557, 42.96372078359127, 26.763719469308853, 11.816742718219757, 4.785609981045127, 3.2282519107684493, 3.6716482182964683, 5.941136525943875, 5.947890663519502, 5.121796941384673, 7.186681190505624, 7.654114533215761, 6.987700117751956, 5.823898566886783, 1.245478168129921, 0.8012343279551715, 0.12525929894763976, 0.18728521128650755, 5.81849193200469, 15.587004907429218, 25.138035602867603, 33.86707350611687, 35.65132096409798, 28.997927382588387, 19.1802079975605, 3.7562694400548935, 0.11955757872783579, 0.04334948032919783, 0.1092775643337518, 0.02059780224954011, 0.03353054002218414, 0.026761824810819235, 0.013816710797982523, 0.0433439327753149, 0.021333769691409543, 0.0270208863003063, 0.07461532703018747, 0.0818299746606499, 0.007494274495911668, 0.034406259437673725, 0.07744023052509874, 0.05923388227529358, 0.07635172994923778, 0.021792207298858557, 0.050851079358835705, 0.014097033890720922, 0.07623131648870185, 0.04147845924308058, 0.040666980130481534, 0.04493406209803652, 0.033501752113807015, 0.0795554330397863, 0.03157201972499024, 0.1560497295577079, 0.17051975388312712, 0.16388585907407105, 0.19334760785568506, 0.13821831060340628, 0.08496673603076488, 0.11604008817812428, 0.15617460332578048, 0.1218540062836837, 0.19038916972931474, 0.09898074771626852, 0.11122524927486666, 0.09968732425477356, 0.17543980706250295, 0.16258086659945548, 0.15146092657232657, 0.1126777584431693, 0.1112830032070633, 0.14651270146714523, 0.11688147584209219, 0.14150013215839863, 0.21802691248012707, 0.17920418787980452, 0.20583258010447025, 0.07570943824248388, 0.11702583098667674, 0.0719059313996695, 0.16445038112578914, 0.10040328896138817, 0.12120699451770633, 0.20870190113782883, 0.2072089523426257, 0.22039822273654863, 7.030782205983996, 18.841368779540062, 38.74980770051479, 46.84906169772148, 35.72751447558403, 25.633519515395164, 16.238846629858017, 6.412742994725704, 0.9606645698659122, 0.3915469319326803, 0.5546992819290608, 0.42237764631863683, 0.3009560820646584, 0.26349938416387886, 0.9174967487342656, 16.00759483873844, 19.846887923777103, 9.20193012803793, 5.128199122846127, 2.11026877630502, 2.2685281466692686, 7.273008758202195, 21.292341761291027, 35.596687495708466, 42.803566977381706, 53.56622725725174, 59.142188653349876, 55.797752514481544, 55.364963337779045, 57.10712805390358, 55.61023637652397, 51.727034747600555, 48.47481966018677, 47.32235670089722, 50.82226149737835, 53.486370742321014, 53.38721506297588, 55.4639708250761, 52.43788540363312, 49.99827951192856, 48.28159622848034, 48.409911543130875, 50.28368219733238, 52.40932233631611, 54.26392301917076, 55.185673758387566, 55.532952323555946, 55.58929570019245, 49.925688207149506, 42.463078647851944, 41.36271469295025, 46.83108106255531, 51.805280148983, 55.18431343138218, 56.291015446186066, 53.41194413602352, 46.70571058988571, 45.85877023637295, 56.014154702425, 53.576824888587, 53.173875510692596, 48.044823333621025, 48.203172236680984, 45.18359586596489, 42.881762981414795, 40.1985027641058, 41.61861956119537, 38.956231623888016, 40.972095653414726, 41.10536590218544, 39.27102193236351, 40.54662108421326, 39.56690825521946, 44.65424247086048, 50.506365448236465, 52.966570034623146, 52.62486957013607, 48.47175322473049, 50.896475315093994, 50.512874498963356, 48.39325703680515, 48.46083641052246, 50.533659383654594, 51.220111548900604, 52.335059121251106, 51.253838539123535, 51.562313586473465, 50.42375408113003, 52.06144720315933, 48.32664281129837, 47.168457359075546, 44.21699233353138, 26.422438882291317, 10.916900653392076, 5.12565515935421, 4.344812259078026, 7.488941196352243, 7.419092394411564, 7.60685171931982, 13.521409146487713, 13.39128227904439, 14.732738547027111, 11.602460816502571, 10.323189161717892, 7.65620157122612, 2.744679171591997, 0.47751574544236064, 0.6683375872671604, 7.443302320316434, 18.804396763443947, 30.010764934122562, 43.82527895271778, 39.13731470704079, 34.648759961128235, 22.801729068160057, 4.082916537299752, 0.25322574481833726, 0.18409685580991209, 0.1662896605557762, 0.19461601244984195, 0.08708750465302728, 0.12230685737449676, 0.1007690119149629, 0.12984645436517894, 0.10488119281944819, 0.11936348484596238, 0.1983699735137634, 0.15342562895966694, 0.13047012558672577, 0.09838139667408541, 0.17437947099097073, 0.22153544530738145, 0.22406656964449212, 0.1210791447374504, 0.11342265948769636, 0.09400340815773234, 0.1474584499374032, 0.11029464803868905, 0.12011704675387591, 0.09793592253117822, 0.16615022585028782, 0.1997559194569476, 0.13657464645802975], [0.04542366063105874, 0.03616372821852565, 0.022197330872586463, 0.029549650607805233, 0.04478949173062574, 0.03470261755865067, 0.023784383993188385, 0.08115861302940175, 0.028852167233708315, 0.07733348742476664, 0.03454986872384325, 0.024165885006368626, 0.057273424972663634, 0.03193912678398192, 0.0543851272232132, 0.019816541534964927, 0.05469268435263075, 0.06725014216499403, 0.06748253828845918, 0.056285236787516624, 0.060640560113824904, 0.08957663827459328, 0.053339778824010864, 0.04629556540749036, 0.04839606968744192, 0.005095725564387976, 0.019957796357630286, 0.0486777703918051, 0.025434209819650277, 0.05898501789488364, 0.04181572083325591, 0.045059002659399994, 0.017571617172507104, 1.1303730821236968, 5.671867299824953, 16.73495750874281, 24.453215450048447, 22.947274558246136, 17.75039792060852, 12.851101364940405, 6.558844679966569, 2.2552509466186166, 0.04714416303613689, 0.07121352988178842, 0.2596978365909308, 0.27332251018378884, 0.04116036361665465, 1.8902111845090985, 2.977740615606308, 6.508329715579748, 4.85528351739049, 3.0154091818258166, 2.7080223010852933, 0.46604089555330575, 0.5826521851122379, 4.281466333195567, 12.378811407834291, 22.185470536351204, 34.18342173099518, 46.3013818860054, 54.84879143536091, 50.63213109970093, 49.13040608167648, 51.452412083745, 51.52940355241299, 53.75761158764362, 50.117498114705086, 44.50365275144577, 45.27551673352718, 48.44703555107117, 53.2183863222599, 53.10804404318333, 52.926163002848625, 48.23053456842899, 50.87905704975128, 50.228091180324554, 47.92797580361366, 52.3442280292511, 53.530482575297356, 50.52503004670143, 51.24379187822342, 45.44616937637329, 41.126515567302704, 36.977180019021034, 42.463447228074074, 49.21210549771786, 53.47559452056885, 49.748849496245384, 49.391349479556084, 42.24832557141781, 40.54951272904873, 53.939219042658806, 49.18713703751564, 49.59357462823391, 44.566607773303986, 42.37520456314087, 38.81895259022713, 38.20557430386543, 34.38802555203438, 36.11553065478802, 37.638705521821976, 39.6515791118145, 38.85427549481392, 38.100726529955864, 35.70769473910332, 38.003888726234436, 43.22521135210991, 46.68817073106766, 49.932273253798485, 47.62309916317463, 47.946465611457825, 47.65049949288368, 45.06229877471924, 46.02078594267368, 47.46486805379391, 46.0803135484457, 45.46313166618347, 45.95350295305252, 48.543538972735405, 48.193919733166695, 50.46162664890289, 49.80146527290344, 47.80637852847576, 44.39148657023907, 32.63003088533878, 20.155364871025085, 7.114917291328311, 1.6486643208190799, 1.9747574790380895, 2.725816983729601, 5.990634094923735, 4.083671746775508, 1.7727960599586368, 6.367884026840329, 5.274001574143767, 4.585005445405841, 4.330530250445008, 0.688393326709047, 0.19869853713316843, 0.5334143084473908, 2.7293353574350476, 13.115831259638071, 23.048136346042156, 29.966628402471542, 24.187854789197445, 27.653078846633434, 21.79744865745306, 9.75390750914812, 0.6869954767171293, 0.033131015952676535, 0.05438722750113811, 0.02834773316862993, 0.07356882459134795, 0.06397802048013546, 0.017803751688916236, 0.041708888675202616, 0.08478348492644727, 0.023545434705738444, 0.023873781246948056, 0.04713310503575485, 0.02114208593411604, 0.03778515390877146, 0.053533802201854996, 0.08402867621043697, 0.06274371757172048, 0.026597812029649504, 0.04801852803211659, 0.028932742206961848, 0.05082536765257828, 0.021591645599983167, 0.007824021377018653, 0.06171347929921467, 0.04078702251717914, 0.03116799081908539, 0.11226283109863289, 0.018815419571183156, 0.02216501219663769, 0.04568835502141155, 0.04208946200378705, 0.03145231501548551, 0.050837583403335884, 0.0424891975853825, 0.013038970646448433, 0.07068777020322159, 0.006788251321268035, 0.05908305560296867, 0.0834227868472226, 0.04944910302583594, 0.044376482837833464, 0.021898195263929665, 0.004309508231017389, 0.026414536805532407, 0.10287670389516279, 0.01942247781698825, 0.022335997455229517, 0.07946231577079743, 0.08306478965096176, 0.07512054406106472, 0.1035568822408095, 0.02670823803782696, 0.014161055260046851, 0.044612311394303106, 0.03065040033106925, 0.0184992553840857, 0.05996235217025969, 0.010648051920725266, 0.008034895217861049, 0.05378750909585506, 0.023206226833281107, 1.5223523299209774, 9.301568381488323, 24.624899737536907, 35.41174381971359, 29.886741489171982, 22.01522447168827, 15.95944382250309, 9.091877583414316, 2.5207595620304346, 0.11071732340496965, 0.1360262290108949, 0.11986473138676956, 0.18396920640952885, 0.49352873931638896, 4.53413899987936, 10.143114924430847, 7.813360188156366, 10.137170143425465, 7.024664534255862, 2.9721290292218328, 1.9858369720168412, 1.321900023613125, 5.323395123705268, 15.113675706088543, 26.163112297654152, 38.29757496714592, 50.41670545935631, 57.295605540275574, 54.01834599673748, 51.171113178133965, 53.140346109867096, 54.60519030690193, 55.29908247292042, 48.8694778829813, 44.65117983520031, 48.49832899868488, 51.02431945502758, 55.394521951675415, 53.17060388624668, 52.510548904538155, 48.43860760331154, 49.119998440146446, 50.44372580945492, 49.71686281263828, 52.53620132803917, 55.57008773088455, 52.76099346578121, 52.720993012189865, 46.75258107483387, 43.205638602375984, 38.04316721856594, 44.729406237602234, 50.06920650601387, 55.76921224594116, 51.48450896143913, 49.2774011939764, 43.04404467344284, 43.981332778930664, 54.15288157761097, 51.55185654759407, 51.829705238342285, 45.679374262690544, 42.951257452368736, 40.949361473321915, 38.95254582166672, 36.89051806926727, 37.146882712841034, 39.07054089009762, 41.13079033792019, 41.15756370127201, 39.565574526786804, 38.78931798040867, 39.96826931834221, 45.291878655552864, 48.826999962329865, 51.64592809975147, 48.809190317988396, 48.81685830652714, 48.986883983016014, 46.850163638591766, 46.93452671170235, 49.86534744501114, 49.06077861785889, 48.2522352039814, 47.27079726755619, 50.61218596994877, 50.06164871156216, 50.893868654966354, 49.553935155272484, 49.22854341566563, 43.52063030004501, 35.23337759077549, 20.230456441640854, 10.461382996290922, 2.668466423638165, 4.648394118994474, 4.983419291675091, 6.702375328168273, 8.143419027328491, 5.801014294847846, 7.086865296587348, 6.356789572164416, 5.8472806122154, 4.1162075009197, 0.9487922256812453, 0.16816156479762867, 0.2458018931793049, 2.6572738867253065, 12.962923664599657, 23.971203714609146, 32.473201900720596, 32.24637307226658, 30.909506008028984, 25.998653322458267, 12.946793530136347, 1.3869052729569376, 0.0332592998893233, 0.021243262926873285, 0.02273549554956844, 0.11738699715351686, 0.010163650276808767, 0.06560069668921642, 0.01523606915725395, 0.018764970227493905, 0.03319670715427492, 0.03900622803485021, 0.0068217718126106774, 0.05678390065440908, 0.019995736802229658, 0.04517802459304221, 0.04432786845427472, 0.057567686526454054, 0.014045448133401806, 0.05092195075121708, 0.04563803369819652, 0.04525365315203089, 0.029789969157718588, 0.04594588768668473, 0.06604959213291295, 0.04472555570828263, 0.016505256717209704, 0.03352637657371815, 0.030617330230597872, 0.13770199846476316, 0.14724585431395099, 0.11365265105268918, 0.0801079100347124, 0.17235928564332426, 0.08473954978398979, 0.07179229374742135, 0.1820757205132395, 0.13106051890645176, 0.1887400879058987, 0.2653223363449797, 0.09422600051038899, 0.1127905426255893, 0.14394582045497373, 0.1616961375111714, 0.1345939582097344, 0.17126590915722772, 0.12764804967446253, 0.129891324613709, 0.18050226353807375, 0.08953508542617783, 0.20494085998507217, 0.2584349090466276, 0.14436890400247648, 0.1239280567097012, 0.09248346003005281, 0.12250772706465796, 0.13141866453224793, 0.1189398075803183, 0.12793024390703067, 0.11428853060351685, 0.13057056785328314, 0.26360384887084365, 1.133435124065727, 10.823390521109104, 26.603879146277905, 45.47497943043709, 39.49327200651169, 29.034183137118816, 21.185958869755268, 10.361769441515207, 4.178850939497352, 0.46281371091026813, 0.3183372993953526, 1.9007938541471958, 1.1368669336661696, 0.20199417747789994, 5.771420057862997, 19.42450638860464, 20.179261788725853, 13.527595214545727, 8.924178332090378, 6.731178257614374, 1.5218197647482157, 1.316761749330908, 5.02046350389719, 14.248549528419971, 26.95135910063982, 37.407047152519226, 50.481659173965454, 59.82315011322498, 55.626465305686, 52.8188643604517, 55.93975089490414, 57.38449417054653, 57.88858652114868, 54.44045014679432, 47.96134561300278, 50.655401051044464, 51.67103335261345, 56.64816968142986, 55.14241307973862, 54.35672543942928, 49.215088337659836, 51.49284951388836, 51.124322488904, 51.03185065090656, 54.564004316926, 57.81718075275421, 53.733061105012894, 54.79534350335598, 48.60517926514149, 44.402015805244446, 41.98185347020626, 45.82893043756485, 54.536607787013054, 56.618774458765984, 54.455356746912, 49.242355674505234, 44.483282044529915, 47.40986980497837, 55.66881783306599, 53.848818093538284, 54.65877503156662, 48.363744020462036, 45.43456479907036, 43.61076146364212, 41.07573889195919, 38.39659005403519, 38.91861364245415, 41.399139538407326, 43.59811954200268, 42.50962994992733, 41.233981400728226, 40.193080455064774, 42.16413728892803, 47.102804481983185, 50.89712508022785, 52.98680394887924, 50.24455949664116, 49.98441405594349, 51.637021377682686, 48.14974330365658, 45.73418632149696, 50.19463397562504, 49.88766744732857, 49.24568049609661, 49.50596272945404, 52.630918845534325, 49.55106630921364, 52.9973179847002, 50.65682977437973, 50.67903198301792, 45.27708224952221, 35.62151916325092, 19.608507715165615, 8.587135467678308, 3.4152498515322804, 6.953757964074612, 8.775951135903597, 14.725854266434908, 11.398711949586868, 7.720235260203481, 12.903479654341936, 14.848833717405796, 13.243037983775139, 8.26929772272706, 2.9260356025770307, 0.5880337057169527, 0.8519486035220325, 3.670860710553825, 16.85631349682808, 29.57139641046524, 40.12500710785389, 32.568660378456116, 38.45472693443298, 30.132079124450684, 13.550490885972977, 1.559533216059208, 0.1612449562526308, 0.13558080681832507, 0.08351776690687984, 0.17736706067807972, 0.14980564039433375, 0.15971230255672708, 0.17130665306467563, 0.17558853345690295, 0.1587362596183084, 0.15598905156366527, 0.23245108692208305, 0.12456203636247665, 0.11491511104395613, 0.16942700080107898, 0.20752117387019098, 0.14717579557327554, 0.0847380654886365, 0.242515321879182, 0.16509631677763537, 0.2525683800922707, 0.11817952181445435, 0.10933168916380964, 0.23437486728653312, 0.12226325619849376, 0.11317104916088283, 0.16601561510469764, 0.22113437385996804], [0.015459810911124805, 0.03725947215571068, 0.036067030086996965, 0.018172339332522824, 0.027112478455819655, 0.02757246529654367, 0.03935738634027075, 0.03379591347766109, 0.03952212086005602, 0.024020724631554913, 0.09771751589141786, 0.03044282719201874, 0.015727831050753593, 0.03739981599210296, 0.040440669617964886, 0.028761014800693374, 0.1160828433057759, 0.011095056743215537, 0.04372662122477777, 0.03316987109428737, 0.04893608231213875, 0.055578263200004585, 0.05266705535177607, 0.04684042425651569, 0.042155880510108545, 0.08482979494147003, 0.012616793446795782, 0.1080515437934082, 0.07303727616090328, 0.04338553386332933, 0.03436465092818253, 0.0566312742739683, 0.037067645534989424, 0.12365898364805616, 4.303600620478392, 8.742109201848507, 20.880569256842136, 31.77705455571413, 23.17394569516182, 17.021741420030594, 10.36933483555913, 6.744634285569191, 1.5243594534695148, 0.13512664212612435, 0.04481782692892011, 0.3577121818671003, 2.0076498202979565, 3.624037723056972, 5.276499940082431, 6.095995316281915, 9.921812899410725, 7.020774967968464, 2.340848478488624, 2.1834986843168736, 0.42236526729539037, 0.40197081165388227, 2.117022438906133, 6.655678683891892, 16.078721322119236, 30.848483182489872, 41.203229650855064, 53.14261078834534, 54.26124416291714, 54.270272478461266, 53.149913996458054, 51.55940294265747, 53.27776953577995, 49.29541602730751, 46.67770229279995, 46.89258076250553, 52.20810793340206, 52.28811264038086, 53.785327300429344, 50.101478174328804, 49.50246311724186, 49.01713415980339, 51.60737916827202, 54.0195619314909, 49.94921654462814, 52.11127012968063, 49.19754847884178, 45.77388659119606, 40.353488847613335, 37.17281252145767, 42.034123465418816, 51.66033312678337, 52.349954321980476, 49.44046564400196, 52.31939256191254, 42.791191041469574, 39.483407735824585, 52.581688687205315, 48.785118609666824, 46.886109709739685, 43.18749077618122, 37.9716132581234, 36.46761976182461, 37.267476841807365, 36.39710694551468, 38.61742660403252, 38.85899484157562, 41.93839140236378, 41.49323768913746, 38.389986008405685, 36.402050480246544, 38.513931557536125, 42.721954956650734, 47.883643582463264, 49.264147505164146, 46.67435847222805, 44.61023323237896, 46.03139877319336, 51.2250816822052, 48.55699025094509, 51.13560788333416, 51.84305012226105, 48.897539377212524, 48.75940538942814, 47.94424653053284, 47.99191877245903, 48.64856153726578, 49.24662284553051, 47.00449235737324, 40.76688386499882, 24.822865314781666, 13.475031685084105, 6.5775510761886835, 1.4352918765507638, 3.306879191659391, 2.0070931501686573, 5.211722915992141, 7.347575007006526, 3.360885218717158, 3.7805643863976, 5.247306581586599, 4.468629090115428, 4.222137741744518, 0.6784005160443485, 0.18433507037116215, 1.7705077514983714, 8.081477601081133, 24.955109618604183, 26.463032104074955, 27.29586001485586, 26.083212085068226, 27.563441656529903, 14.715514071285725, 2.7749058371409774, 0.06314566475339234, 0.13207745418185368, 0.0545452530059265, 0.007906557475507725, 0.03906126570655033, 0.025406158492842223, 0.06762290067854337, 0.039574479378643446, 0.025586888150428422, 0.03155424157739617, 0.0730199841200374, 0.03803148756560404, 0.049267369613517076, 0.05525704313185997, 0.06953751551918685, 0.03274993796367198, 0.013603252427856205, 0.03304564299469348, 0.03550930239725858, 0.03587222003261559, 0.03706252100528218, 0.028419673253665678, 0.04051153729960788, 0.05483360335347243, 0.08661989966640249, 0.05994104139972478, 0.05322777389665134, 0.04296375278499909, 0.02649956466484582, 0.027775555863627233, 0.042222851916449144, 0.05934334905759897, 0.02677736723853741, 0.03428383846767247, 0.023423943275702186, 0.01160366538897506, 0.05446769486297853, 0.052388590411283076, 0.021290660188242327, 0.02977154348627664, 0.015701588708907366, 0.04501112300204113, 0.05450195982120931, 0.05028131774452049, 0.030749078141525388, 0.025452119698456954, 0.05065089986601379, 0.02942341499874601, 0.07878861637436785, 0.04159387433901429, 0.05588152329437435, 0.03224092484742869, 0.02984526101499796, 0.07775851539918222, 0.019231252335885074, 0.08344668400241062, 0.034829380092560314, 0.026843329324037768, 0.03285915241576731, 0.07588596548885107, 0.08400059334235266, 0.0993559553171508, 5.566698918119073, 11.801686026155949, 27.57920891046524, 38.769703432917595, 28.53345550596714, 20.1765164360404, 15.20716018974781, 8.90948737040162, 1.657146296929568, 0.035484384789015166, 0.0256989691479248, 0.22944574506254867, 2.3546878108754754, 5.050903195515275, 6.54421404004097, 7.247650343924761, 10.795446820557117, 9.24608375877142, 4.116097781807184, 5.158902900293469, 2.040015058591962, 1.5638924133963883, 4.622086705639958, 8.49370513111353, 19.814430065453053, 33.80091905593872, 48.795298263430595, 56.83663196861744, 55.37673130631447, 54.90560978651047, 56.21044456958771, 53.17343853414059, 55.12643113732338, 50.84670178592205, 45.85309714078903, 48.48331220448017, 53.83134663105011, 54.582364931702614, 54.11254294216633, 49.95134823024273, 50.22282086312771, 50.736720487475395, 52.022244706749916, 54.17431242763996, 51.202746480703354, 53.21063093841076, 51.43985755741596, 46.963595151901245, 43.50340202450752, 38.38465869426727, 43.575700744986534, 52.89361014962196, 54.41284842789173, 52.267168164253235, 52.282561138272285, 45.00949680805206, 43.02246183156967, 55.20040176808834, 51.711204797029495, 49.68784756958485, 44.54638905823231, 40.103367269039154, 38.79166625440121, 37.587339878082275, 38.14220890402794, 39.893774315714836, 40.60175232589245, 43.16129118204117, 42.540366500616074, 40.132515504956245, 38.4222386777401, 39.76610876619816, 43.66110876202583, 49.01531405746937, 49.72488798201084, 50.56329779326916, 46.30350597202778, 47.02247679233551, 51.32850453257561, 50.211550667881966, 50.48689529299736, 52.18014143407345, 49.9594683945179, 49.89071108400822, 49.67557802796364, 49.70416769385338, 50.53068794310093, 49.77857530117035, 49.37749922275543, 42.30403058230877, 26.891956888139248, 15.394187103956938, 7.277966542169452, 2.682932009920478, 3.5832428745925426, 5.15995591878891, 5.587665718048811, 7.4831906799227, 7.414729753509164, 7.7696041110903025, 5.107781393453479, 3.60617155674845, 0.7815811887849122, 0.31198991811834276, 0.09560685532051139, 1.8530837330035865, 8.745300080627203, 25.86799543350935, 30.414848551154137, 33.3541314303875, 27.93534480035305, 32.59974651038647, 19.465756975114346, 4.537056293338537, 0.266925998730585, 0.05528496272745542, 0.010593718361633364, 0.0025634926441853167, 0.03368235375091899, 0.05301695942762308, 0.036916176904924214, 0.05679038702510297, 0.0629265456518624, 0.03009003801707877, 0.058089490557904355, 0.010361154327256372, 0.011971992353210226, 0.05167713425180409, 0.14650562137831002, 0.02174363373342203, 0.020145951202721335, 0.01437573724615504, 0.00883756874827668, 0.01752581367327366, 0.008602047255408252, 0.026690465456340462, 0.10508477134862915, 0.05470970179885626, 0.03614362343796529, 0.06352567404974252, 0.028693961758108344, 0.02079895210044924, 0.20423240581294522, 0.12036833053571172, 0.1284791511716321, 0.13362180412514135, 0.1191094476962462, 0.11896215364686213, 0.14371858967933804, 0.14928242628229782, 0.2636198792606592, 0.15413267305120826, 0.1146422530291602, 0.1860590052092448, 0.10262740164762363, 0.140390042506624, 0.08467136125545949, 0.18553798785433173, 0.24853369424818084, 0.10923413385171443, 0.12068428506609052, 0.06807829733588733, 0.1335582762840204, 0.08612396690296009, 0.19967627216828987, 0.07644083962077275, 0.16538998461328447, 0.18108608142938465, 0.1764812332112342, 0.2413880589301698, 0.1145431466284208, 0.12497156829340383, 0.1279375169542618, 0.2475549202063121, 0.14876192843075842, 0.15290570998331532, 5.074683269485831, 15.93473944813013, 32.88379646837711, 49.70928981900215, 36.351843774318695, 27.368726804852486, 17.346002720296383, 9.24380673095584, 2.3697979375720024, 0.3827791102230549, 0.6109873834066093, 2.3786417255178094, 8.235799670219421, 9.769742209464312, 10.761058665812016, 10.656283088028431, 19.839438423514366, 13.834850527346134, 5.921553326770663, 5.137485349550843, 1.6473520849831402, 0.7221921568270773, 3.1017350871115923, 8.032815512269735, 18.310883045196533, 33.585238829255104, 46.04934521019459, 57.83606193959713, 57.62356214225292, 57.66069374978542, 58.13510589301586, 57.15475469827652, 58.57718177139759, 54.99564975500107, 50.64168758690357, 49.94798541069031, 55.782978907227516, 57.017977237701416, 55.889654383063316, 51.50243639945984, 50.42112462222576, 52.23748415708542, 54.14053224027157, 55.8224093914032, 53.1398369371891, 55.872692093253136, 53.918114975094795, 48.789560571312904, 44.59455527365208, 39.91371564567089, 45.89230723679066, 56.330229341983795, 57.4697045981884, 52.41750709712505, 52.80808433890343, 45.28651714324951, 47.544701769948006, 55.23533709347248, 54.42760683596134, 52.629220336675644, 47.00168430805206, 41.63623921573162, 40.30170902609825, 39.870363771915436, 39.923633113503456, 41.29197768867016, 43.9133620262146, 45.3557114303112, 44.7234595566988, 41.39788940548897, 40.306466370821, 43.12295503914356, 46.41036383807659, 50.92463180422783, 51.94086067378521, 50.90777970850468, 48.50168041884899, 48.3958674967289, 51.2643563747406, 51.253340765833855, 51.53317295014858, 54.42186914384365, 51.47989600896835, 51.7025488615036, 51.26798897981644, 51.25248581171036, 52.633430510759354, 51.60588964819908, 49.4074834138155, 42.50844061374664, 26.58047240227461, 14.747424758970737, 8.807204458862543, 3.536882749758661, 7.625517267733812, 6.224817903712392, 12.189969141036272, 15.965358205139637, 10.446827877312899, 12.908176202327013, 15.64593119546771, 12.180881928652525, 8.69583623483777, 1.961806348990649, 0.42404626146890223, 2.678391966037452, 10.9128044731915, 31.33095659315586, 34.54323582351208, 37.86008544266224, 35.698552429676056, 36.450767666101456, 21.71636290848255, 4.4346242398023605, 0.3496075433213264, 0.1762695430079475, 0.09064594691153616, 0.14828872022917494, 0.13874910946469754, 0.10605198272969574, 0.22816191863967106, 0.08302232396090403, 0.1958720083348453, 0.11292421084363014, 0.14586421282729134, 0.14921679074177518, 0.0692807101586368, 0.20264573860913515, 0.1628871212597005, 0.07302400656044483, 0.13029227731749415, 0.08423990628216416, 0.078504188277293, 0.10050146767753176, 0.0972251602797769, 0.18287299491930753, 0.14775066316360608, 0.14768864930374548, 0.1841420229175128, 0.2038937935139984, 0.10933752986602485, 0.12549905717605725], [0.03970772828324698, 0.027821355652122293, 0.03632645893958397, 0.013195418159739347, 0.04140617405937519, 0.030620250581705477, 0.06815939923399128, 0.03398115724849049, 0.061433511509676464, 0.04038929444504902, 0.06571128411451355, 0.014792984729865566, 0.01310372952502803, 0.02507793626136845, 0.08205837802961469, 0.09673141685198061, 0.08602967704064213, 0.06380777922458947, 0.06917357372003607, 0.03531026952259708, 0.0020932442203047685, 0.07756887440336868, 0.033213835922651924, 0.0269769771330175, 0.05276471456454601, 0.016095960418169852, 0.028279824800847564, 0.02169809926272137, 0.07104354837792926, 0.02312076852831524, 0.019716125243576244, 0.025254947759094648, 0.055285033231484704, 0.08432419941527769, 0.26879947632551193, 6.631363313645124, 13.523961659520864, 22.7013061568141, 25.256030671298504, 14.425519332289696, 11.170632038265467, 9.825897496193647, 5.266221966594458, 0.8722455706447363, 0.07721321497228928, 0.13475602841936052, 2.0769025292247534, 3.6871853470802307, 5.71098287589848, 5.771555425599217, 8.703405428677797, 7.066036714240909, 1.1338603449985385, 5.023329500108957, 1.4461934915743768, 1.7455264669843018, 0.5785818910226226, 1.2627115496434271, 3.9247310254722834, 10.117742735892534, 23.671720884740353, 36.17591321468353, 48.70310001075268, 50.41054219007492, 54.6122807264328, 53.12680743634701, 56.05637803673744, 51.01314805448055, 49.96850050985813, 46.92477263510227, 51.453761011362076, 51.934503614902496, 56.05921268463135, 51.52342267334461, 49.24885332584381, 50.21030053496361, 50.255609303712845, 53.010799661278725, 49.352401569485664, 50.72579227387905, 46.00237973034382, 42.3621940612793, 40.910858139395714, 37.40383632481098, 40.8680572360754, 47.62943722307682, 53.259462118148804, 49.029890075325966, 53.14674876630306, 44.27340790629387, 41.54465273022652, 54.02788728475571, 49.379140734672546, 47.45367005467415, 42.90081515908241, 38.33754502236843, 36.5599700063467, 38.250347301363945, 38.390498980879784, 38.11775341629982, 40.19261308014393, 42.35716313123703, 42.45156906545162, 40.48659950494766, 37.391156405210495, 34.93506699800491, 40.946222841739655, 45.76823249459267, 51.28835968673229, 46.052799224853516, 49.32052507996559, 47.688052877783775, 45.75543478131294, 49.93159309029579, 49.63490501046181, 49.37939912080765, 46.08553446829319, 44.514007195830345, 46.61493346095085, 45.525330528616905, 49.11176808178425, 47.477171793580055, 44.655823186039925, 34.43763189017773, 19.374780356884003, 9.104153774678707, 5.179565716534853, 2.155407266691327, 2.367689525708556, 4.736053040251136, 2.5045700557529926, 5.475089633837342, 7.228442849591374, 5.9215110540390015, 2.5081366393715143, 2.1855370374396443, 0.42479369323700666, 0.22994599712546915, 1.341888732276857, 7.103100875392556, 22.1693878993392, 25.707454048097134, 28.767619840800762, 26.365299448370934, 30.700042247772217, 21.527499742805958, 5.710945827886462, 0.4682187724392861, 0.02664466381247621, 0.03138232677883934, 0.05289719163556583, 0.044362356056808494, 0.03171010372170713, 0.029565326622105204, 0.03840204932203051, 0.004670205917136627, 0.06360195940942504, 0.0407965702470392, 0.07696875894907862, 0.02856401541066589, 0.04323096676671412, 0.023580632914672606, 0.05980979258310981, 0.02044462482444942, 0.033654619692242704, 0.03282762969320174, 0.02557699346652953, 0.025590313161956146, 0.0820740002382081, 0.05174851030460559, 0.05862500947841909, 0.020453359902603552, 0.056780520171741955, 0.02590225267340429, 0.0699475669534877, 0.028199600492371246, 0.025948380862246267, 0.035235049144830555, 0.014031069022166776, 0.05042619610321708, 0.08778879710007459, 0.014809168187639443, 0.07833816984202713, 0.035100712993880734, 0.037742432177765295, 0.11980873634456657, 0.11042044949135743, 0.04447327373782173, 0.08641942331450991, 0.05173623518203385, 0.015460902795894071, 0.0207973676151596, 0.047814608115004376, 0.047060548968147486, 0.046746204898227006, 0.028552200419653673, 0.03291955581516959, 0.01998347281187307, 0.03958551511459518, 0.021380773614509962, 0.02689469893084606, 0.027921016808249988, 0.06396469892933965, 0.030172650185704697, 0.04383129002235364, 0.04484636621782556, 0.03062276646232931, 0.05455992155475542, 0.05150851829966996, 0.10737584801972844, 1.0978749697096646, 9.830085821449757, 19.634707309305668, 30.757783949375153, 31.721507236361504, 19.435054622590542, 12.624762710183859, 12.103670071810484, 5.403541848063469, 0.6778184941504151, 0.17456754605518654, 0.10646282826201059, 1.2970120715908706, 3.9762754971161485, 5.4951772559434175, 6.763277985155582, 7.931659240275621, 10.114358067512512, 4.496389450505376, 6.795507380738854, 4.455997617915273, 2.416458483785391, 2.2640094766393304, 1.4569539204239845, 6.49672893807292, 14.530848730355501, 27.965224497020245, 39.490961730480194, 51.43726609647274, 52.815851122140884, 57.18092769384384, 54.60932448506355, 57.88658782839775, 52.09884859621525, 49.721760749816895, 49.82965216040611, 52.039583176374435, 54.12962302565575, 56.19307570159435, 50.960490480065346, 50.1854232698679, 51.868482157588005, 52.31775104999542, 54.213864505290985, 52.45027273893356, 52.775675877928734, 48.33898834884167, 44.57402117550373, 42.581769078969955, 40.118752643465996, 43.81136789917946, 50.1628714799881, 53.393142744898796, 51.22174546122551, 54.33222435414791, 45.54048411548138, 44.04901474714279, 55.150206461548805, 51.18988037109375, 49.846967831254005, 43.69080036878586, 39.85568515956402, 38.477829694747925, 39.66265171766281, 40.32556414604187, 39.34155374765396, 42.29118347167969, 43.812428042292595, 44.470480531454086, 41.88133366405964, 40.05437269806862, 35.87898574769497, 41.82783633470535, 47.471194714307785, 51.594171077013016, 49.14421074092388, 50.74736751616001, 47.92009122669697, 47.59428910911083, 49.71474252641201, 50.346318036317825, 51.07312023639679, 48.958792090415955, 46.783876195549965, 47.31457091867924, 47.36377827823162, 50.698570534586906, 49.34343405067921, 46.89464025199413, 35.59030003845692, 21.186737827956676, 12.28258727118373, 4.676806144416332, 4.232194377109408, 2.6971076242625713, 6.92728478461504, 5.933078108355403, 5.872377315536141, 6.728183543309569, 6.147040827199817, 3.180664451792836, 1.467915263492614, 0.14992282551247627, 0.23793722066329792, 1.0244326293468475, 6.557446355000138, 24.0500570833683, 30.21907925605774, 31.161787770688534, 30.763333551585674, 34.00768116116524, 26.826362907886505, 7.895703669637442, 0.7742891425732523, 0.013830395073455293, 0.03190859853930306, 0.004902255550405243, 0.055876346814329736, 0.0277393334908993, 0.04086546381586231, 0.05546844760829117, 0.057147378611261956, 0.11964236167841591, 0.06730249326210469, 0.017232346217497252, 0.016205134052142967, 0.04783411175594665, 0.03879556570609566, 0.028379081486491486, 0.024989049234136473, 0.027981594612356275, 0.0475118155736709, 0.04391865193611011, 0.04255735271726735, 0.01960053759830771, 0.044451536232372746, 0.027477179100969806, 0.02764945755188819, 0.021952008391963318, 0.037457350990734994, 0.0027788861643784912, 0.011342803263687529, 0.11715005166479386, 0.09207903407514095, 0.1315194630296901, 0.15027170913526788, 0.24611708329757676, 0.13156045926734805, 0.14429758361075073, 0.17388119304087013, 0.16686237591784447, 0.2509902772726491, 0.15074456110596657, 0.09973583102691919, 0.11833704265882261, 0.1487406436353922, 0.1850967513746582, 0.1885753162787296, 0.165107196662575, 0.15695759881054983, 0.14689530828036368, 0.21683632949134335, 0.13409055944066495, 0.1837702069315128, 0.09591186317265965, 0.06852345235529356, 0.18279512878507376, 0.12290323240449652, 0.10166413107072003, 0.12130609349696897, 0.17170287086628377, 0.11479430424515158, 0.1371208077762276, 0.13305762346135452, 0.27379371458664536, 0.17084150458686054, 0.7142651884350926, 11.166475061327219, 24.337283670902252, 38.085618540644646, 42.71663524210453, 23.1704118847847, 17.477618157863617, 15.13870781287551, 8.114274591207504, 2.04885124694556, 0.39461701875552535, 0.5057003174442798, 6.913777459412813, 11.169157717376947, 15.197127778083086, 17.214307487010956, 18.269757851958275, 16.858830861747265, 7.931829756125808, 10.499295461922884, 4.596164496615529, 3.170475298538804, 1.6349146398715675, 1.6568237892352045, 5.289873797446489, 11.2368187867105, 27.884205244481564, 38.6086642742157, 51.330731213092804, 51.061291471123695, 59.320714473724365, 58.42371940612793, 61.77404522895813, 54.92528893053532, 53.37422735989094, 52.32483007013798, 53.89525160193443, 56.55523046851158, 57.86480359733105, 51.13269343972206, 51.464085057377815, 50.95887176692486, 54.137272015213966, 56.53221130371094, 54.630550146102905, 54.21444967389107, 50.21768353879452, 46.4914058893919, 44.724063724279404, 40.77112063765526, 45.53477302193642, 52.05162473022938, 56.36999420821667, 54.057255908846855, 53.51755566895008, 46.276508420705795, 47.05906122922897, 56.87635503709316, 53.173514530062675, 50.721456706523895, 47.57079876959324, 41.72072008252144, 40.28796896338463, 42.20929406583309, 42.41826005280018, 41.09002232551575, 44.35539610683918, 46.43367558717728, 46.531516537070274, 45.003341138362885, 40.268027633428574, 37.194877937436104, 44.439626187086105, 49.85068783164024, 54.038861095905304, 51.07725441455841, 52.28699170053005, 50.42372368276119, 48.59969615936279, 49.68115232884884, 52.012726217508316, 52.30954349040985, 50.89893378317356, 47.37385153770447, 50.638955533504486, 49.69217173755169, 53.405533879995346, 50.26406764984131, 46.62971846759319, 37.36592195928097, 21.592421159148216, 12.477797046303749, 9.379216264933348, 5.25316396728158, 5.829968741163611, 11.289511509239674, 8.39362420141697, 14.001140054315329, 15.729224625974894, 11.882815472781658, 5.655047502368689, 6.225152285769582, 1.2099391501396894, 0.8287816029042006, 1.8833804572932422, 9.459208622574806, 28.4438544139266, 33.44754941761494, 40.07684089243412, 36.16866700351238, 39.690842404961586, 29.555199779570103, 9.123885165899992, 0.8103647036477923, 0.2241380829946138, 0.1112647241097875, 0.10825899633346125, 0.1319790305569768, 0.15396144473925233, 0.16464439337141812, 0.11387658669264056, 0.09798691549804062, 0.17180797382025048, 0.09581826350768097, 0.21555927145527676, 0.08989730544271879, 0.10781658726045862, 0.24999666027724743, 0.1827075405162759, 0.07095289503922686, 0.126092953432817, 0.13163740513846278, 0.1563831913517788, 0.08471609791740775, 0.12244446639670059, 0.1384355075424537, 0.23760720243444666, 0.14099483349127695, 0.18260582175571471, 0.22596826369408518, 0.13919169665314257, 0.1290818492998369], [0.029643626912729815, 0.046963301647338085, 0.030497471525450237, 0.03143774294585455, 0.10220393218332902, 0.06101947474235203, 0.025365618676005397, 0.026412373445054982, 0.0217584024721873, 0.057901597319869325, 0.05259344914520625, 0.04644168686354533, 0.07788497736328281, 0.037561240533250384, 0.025221632749889977, 0.010471403147676028, 0.0878675389685668, 0.06788294922444038, 0.10810442181536928, 0.05948237929260358, 0.027785461679741275, 0.020013867469970137, 0.056530832007410936, 0.05567087580857333, 0.05404896401159931, 0.03849876971798949, 0.08013579252292402, 0.016461844788864255, 0.019187636316928547, 0.06745165010215715, 0.02828031276294496, 0.03557484888006002, 0.06989784305915236, 0.07053609006106853, 0.023867179843364283, 2.717185034416616, 13.427500035613775, 22.296684868633747, 24.76828694343567, 22.443041615188122, 19.33851510286331, 14.479936212301254, 14.108049217611551, 4.3505784496665, 0.4376238532131538, 0.2706199052045122, 0.29431620554532856, 2.1119884215295315, 3.483720039948821, 3.516928358003497, 6.604882534593344, 7.930244766175747, 5.166786527261138, 6.725005013868213, 4.991241171956062, 3.397595761343837, 3.466761074960232, 0.3667046665214002, 1.669127291534096, 5.219419877976179, 9.917397536337376, 21.80662516504526, 34.9022101610899, 46.48647375404835, 51.53539963066578, 53.27351376414299, 53.24563845992088, 52.01860070228577, 51.503906920552254, 49.22754406929016, 50.42816184461117, 52.39878170192242, 53.98116119205952, 51.587893813848495, 50.63415639102459, 53.335005864501, 53.16997691988945, 51.134479343891144, 50.45878820121288, 45.875892117619514, 44.343711733818054, 40.886436849832535, 40.17905920743942, 38.453708589076996, 44.075814709067345, 46.53150513768196, 52.66267754137516, 50.68838708102703, 55.28711311519146, 46.840523555874825, 40.70004545152187, 52.87762060761452, 48.938991352915764, 49.27367739379406, 41.905469968914986, 38.512723222374916, 38.16887207329273, 39.40258227288723, 40.28804875910282, 44.40396890044212, 44.86361123621464, 45.56259132921696, 42.75866858661175, 42.30141632258892, 38.43752905726433, 36.65602125227451, 37.879247814416885, 45.652612298727036, 48.1486451625824, 49.46659304201603, 46.73235855996609, 48.111897334456444, 47.00109153985977, 51.11241392791271, 51.04003921151161, 48.84487420320511, 47.498386055231094, 46.22509337961674, 45.682592689991, 46.69802360236645, 47.23464600741863, 44.921474531292915, 39.985828176140785, 24.716849103569984, 14.504724182188511, 6.390498038381338, 0.5394772987347096, 3.7540323100984097, 1.3732811040244997, 5.937112541869283, 4.40612624399364, 3.9807972544804215, 4.9942396860569715, 5.732138240709901, 2.3539067152887583, 0.8893150265794247, 0.06428046050132252, 0.6029615609440953, 5.923834629356861, 16.002803295850754, 24.500199928879738, 27.136578261852264, 27.522531151771545, 21.82857658714056, 25.29931604862213, 11.415164116770029, 1.725735585205257, 0.04624640925612766, 0.013447154651657911, 0.07761362590827048, 0.06474716748925857, 0.04703291138866916, 0.025634689882281236, 0.011957286696997471, 0.02444153720716713, 0.05091457009257283, 0.044115306227467954, 0.03760423314815853, 0.03736740269232541, 0.01640284219320165, 0.029718641344516072, 0.04625849142030347, 0.0398890943324659, 0.053399098687805235, 0.07279989280505106, 0.031948726464179344, 0.026932398177450523, 0.022214008786249906, 0.027415046497480944, 0.01572772529470967, 0.02625757628266001, 0.07929247527499683, 0.028480937544372864, 0.039052927677403204, 0.04108137312869076, 0.016474895455758087, 0.014488950018858304, 0.09693316969787702, 0.055824693336035125, 0.052393213991308585, 0.019062356223003007, 0.012329802157182712, 0.02981233748869272, 0.058212015428580344, 0.026773986755870283, 0.055410441345884465, 0.08304228031192906, 0.02611811003589537, 0.04981279249477666, 0.04884575551841408, 0.021479768693097867, 0.007500916717617656, 0.037590881911455654, 0.04029637013445608, 0.04283074136765208, 0.028218382394697983, 0.03435550395806786, 0.005157690720807295, 0.042177421346423216, 0.02493977990525309, 0.06788364684325643, 0.05323595236404799, 0.04994287985027768, 0.03888274950440973, 0.015924776635074522, 0.04593282217683736, 0.05695077627024148, 0.09258716032491066, 0.02620396167912986, 0.008377032718271948, 0.09846053188084625, 3.451122776605189, 16.46201815456152, 27.506057135760784, 31.06426600366831, 23.192747086286545, 17.67328105866909, 19.924048483371735, 16.114230416715145, 3.703874764032662, 0.3560706996358931, 0.2181773606571369, 0.12056259511155076, 0.8206409553531557, 2.966742105782032, 7.655776469036937, 9.708879925310612, 8.377126436680555, 8.71285267174244, 4.836786109954119, 6.514813592657447, 6.306818453595042, 5.2798375859856606, 2.3848985647782683, 1.9694773061200976, 8.355823829770088, 13.444188740104437, 24.40115824341774, 39.018521681427956, 49.243719801306725, 53.95548216998577, 54.2402008920908, 54.36501659452915, 55.2561067789793, 52.18866437673569, 50.70521637797356, 53.624542728066444, 53.81930127739906, 55.94646133482456, 51.95329360663891, 50.027062967419624, 53.49737875163555, 55.00681355595589, 51.665421053767204, 52.14943528175354, 48.63612860441208, 45.90068198740482, 42.00381629168987, 41.59652754664421, 41.494529619812965, 44.88352216780186, 48.50517623126507, 54.758363887667656, 51.16225205361843, 54.9994495511055, 47.306595146656036, 43.439200669527054, 54.216976538300514, 51.09509065747261, 50.60873195528984, 43.71865667402744, 39.604438841342926, 40.17356850206852, 40.10170295834541, 41.28730393946171, 44.98821035027504, 45.43698146939278, 46.99875086545944, 44.66037914156914, 43.5653804987669, 41.42961770296097, 38.43030944466591, 38.953339979052544, 46.024775728583336, 51.549519672989845, 50.02137467265129, 49.85799103975296, 48.82882386445999, 46.819677874445915, 51.453358232975006, 51.83613829314709, 50.02880707383156, 48.26170429587364, 48.335435539484024, 48.11890795826912, 48.284833654761314, 50.3863450884819, 45.7031761854887, 42.9151251912117, 27.0533000305295, 16.06355633586645, 7.256221733987331, 2.786791599355638, 5.444656116887927, 4.477066062390804, 5.391047168523073, 5.734310774132609, 8.016156256198883, 8.113014958798885, 4.6330068446695805, 1.2852190481498837, 0.35968403855804354, 0.10396254016086459, 0.4045906226383522, 4.9544216226786375, 17.28643711656332, 24.88329727202654, 28.873757645487785, 31.180296577513218, 26.64142493158579, 29.194656126201153, 14.72681276500225, 2.8716386714950204, 0.0472187674313318, 0.07726411888143048, 0.12262524614925496, 0.043691209648386575, 0.01765198991051875, 0.04919267616060097, 0.01693613095994806, 0.006461720722654718, 0.052582528442144394, 0.04146775005210657, 0.006177189188747434, 0.02879607014619978, 0.02955728916276712, 0.024258811172330752, 0.02981127250677673, 0.05102542469103355, 0.022365510812960565, 0.0589950739959022, 0.027407380111981183, 0.03400663517822977, 0.024462406399834435, 0.011266422352491645, 0.05182289947697427, 0.05166623210243415, 0.03867750856443308, 0.01822123202146031, 0.08963443673565052, 0.05259286655928008, 0.04371383402030915, 0.10890064979321323, 0.14538034738507122, 0.1993055100319907, 0.1313673672848381, 0.10901074740104377, 0.15120944241061807, 0.15942285011988133, 0.12076313083525747, 0.087815573788248, 0.14343912655021995, 0.15899951424216852, 0.20997634681407362, 0.1998197886859998, 0.15076554904226214, 0.11612215486820787, 0.11182812551851384, 0.23139999801060185, 0.13143056858098134, 0.1738563904655166, 0.2774708188371733, 0.1029285577533301, 0.1291106446296908, 0.11629999571596272, 0.14439759543165565, 0.13106020720442757, 0.20152387849520892, 0.18032635969575495, 0.25176294206175953, 0.07560796439065598, 0.11993032981990837, 0.16103593778098002, 0.1076870528049767, 0.20337770401965827, 0.1950431035947986, 0.31074872065801173, 3.351010736078024, 19.75430019199848, 33.20558600127697, 40.57974010705948, 35.834923312067986, 27.15072300285101, 23.572145327925682, 19.686354137957096, 6.555290445685387, 1.4505919930525124, 0.6240328552667052, 1.3795526674948633, 7.143961982801557, 11.73200536519289, 11.491957996040583, 15.547918304800987, 17.96288061887026, 10.868993774056435, 17.17007216066122, 11.21604910120368, 10.050298254936934, 9.166685119271278, 2.543086213991046, 2.269054655916989, 8.550149202346802, 11.68089335784316, 24.110112860798836, 36.68461471796036, 49.60339330136776, 53.855669125914574, 55.893837958574295, 55.353275164961815, 56.69478937983513, 54.2410596460104, 54.25068452954292, 55.13135187327862, 55.63660316169262, 57.10187293589115, 53.37026797235012, 49.34925153851509, 55.32828010618687, 56.10174000263214, 54.037284180521965, 53.777267932891846, 51.4994003623724, 48.20976488292217, 44.83850218355656, 42.52342700958252, 43.73516298830509, 47.98156812787056, 50.22584930062294, 56.71392135322094, 55.141588523983955, 56.156419068574905, 48.75432886183262, 45.719454512000084, 54.99180816113949, 53.893735483288765, 54.57939349114895, 45.892417430877686, 41.45190350711346, 43.40103171765804, 43.290294259786606, 43.405200093984604, 49.38694171607494, 47.16571770608425, 50.848711878061295, 47.12494969367981, 45.21758124232292, 42.37836979329586, 40.583870485424995, 39.66947615146637, 49.18586790561676, 52.94486179947853, 53.45474883913994, 50.34770116209984, 48.23784537613392, 49.73886363208294, 53.32215495407581, 54.21213939785957, 50.77481724321842, 50.3399533778429, 51.15610398352146, 49.56994749605656, 51.01141154766083, 53.00812840461731, 48.89165349304676, 44.430715665221214, 27.062136456370354, 17.336075752973557, 9.961369726806879, 2.925076629035175, 7.195239756256342, 5.063229259103537, 11.942906398326159, 9.876882210373878, 8.991334978491068, 11.020840276032686, 10.961646102368832, 7.552241049706936, 2.7299454621970654, 0.29695231409277767, 1.1987667996436357, 7.650064425542951, 19.7921309620142, 32.54756771028042, 38.50883603096008, 36.84181608259678, 31.905618757009506, 34.39172275364399, 16.68072111904621, 2.977311951108277, 0.1028146455064416, 0.1859075773973018, 0.21580634725978598, 0.11205983144463971, 0.16214062459766865, 0.11993316482403316, 0.04906219917756971, 0.11059116572141647, 0.18713918630965054, 0.15520362183451653, 0.16560915566515177, 0.17161949799628928, 0.1373883371707052, 0.09947158934664913, 0.13528200332075357, 0.14134319761069492, 0.10542649324634112, 0.22554466064320877, 0.1003872363071423, 0.20263969752704725, 0.11468577256891876, 0.11863878506119363, 0.10094464116264135, 0.14569368213415146, 0.1539052344742231, 0.0777293267310597, 0.19285762711660936, 0.1199354357959237, 0.09394008069648407], [0.006187463295646012, 0.12967847666004673, 0.04468328297662083, 0.07481460852432065, 0.028989750280743465, 0.022369642720150296, 0.027888250988326035, 0.029375407320912927, 0.10271050734445453, 0.07189442068920471, 0.03848369298793841, 0.08977613499155268, 0.024882580728444736, 0.039082134899217635, 0.01786126071237959, 0.04521473863860592, 0.016694997902959585, 0.04914822522550821, 0.037968148972140625, 0.054950792182353325, 0.08913733880035579, 0.10006348180468194, 0.03284208301920444, 0.026825927816389594, 0.0348589064378757, 0.13283377687912434, 0.07844237479730509, 0.07508193753892556, 0.016262524331978057, 0.023132214300858323, 0.044199907351867296, 0.056668366814847104, 0.035912589155486785, 0.04946814653521869, 0.1161745133867953, 0.2711071399971843, 6.41498202458024, 20.056492276489735, 24.63900078088045, 24.8342153057456, 13.007363229990005, 7.680113688111305, 14.65811150148511, 13.164054471999407, 4.511636607348919, 0.334989401162602, 0.13098526513203979, 1.0146648972295225, 2.7947234362363815, 5.33243483863771, 5.244516106322408, 6.034164084121585, 5.413479739800096, 2.279017483815551, 6.081576989963651, 2.623364981263876, 3.267800663597882, 1.8107107817195356, 1.3460438093170524, 3.2549704145640135, 2.9032857483252883, 11.57313209027052, 22.07152985036373, 35.998082756996155, 46.32880121469498, 52.18227691948414, 55.40885478258133, 52.00796887278557, 54.05015788972378, 51.659067794680595, 52.86984622478485, 53.869424387812614, 54.555929750204086, 52.223322317004204, 51.904318034648895, 50.988745763897896, 52.6709420979023, 50.10656230151653, 50.61179459095001, 44.57369439303875, 43.08511666953564, 40.84654659032822, 40.646502524614334, 39.77887608110905, 39.24069955945015, 44.912556409835815, 52.657836601138115, 51.927238404750824, 54.73817177116871, 46.26680374145508, 38.885528817772865, 54.14470821619034, 51.127654910087585, 48.640756756067276, 41.60133048892021, 38.452139273285866, 38.715928718447685, 45.48934645950794, 48.22089448571205, 51.002808809280396, 49.58768114447594, 48.920805528759956, 46.96598142385483, 45.409942120313644, 41.143314465880394, 38.41241240501404, 35.861677676439285, 42.42348477244377, 47.06878870725632, 51.77317947149277, 48.90178754925728, 49.99694958329201, 49.59298186004162, 46.177421137690544, 50.233931466937065, 48.35174046456814, 49.3202742934227, 47.65022590756416, 47.60270565748215, 47.14576497673988, 49.433755204081535, 38.63736033439636, 31.786861829459667, 17.247559502720833, 6.128237536177039, 1.5339795872569084, 1.6380459093488753, 3.093153960071504, 3.4377517690882087, 2.519306377507746, 6.273649083450437, 5.529059087857604, 6.188880857080221, 4.188467748463154, 1.3417664263397455, 0.5422399286180735, 0.3645635407883674, 3.8332364475354552, 11.910851318389177, 20.657716915011406, 32.129533141851425, 24.35246955603361, 19.58668738603592, 28.38709305971861, 20.900143906474113, 4.535500751808286, 0.18912725150585175, 0.0404815656656865, 0.039660052716499195, 0.01445271002012305, 0.05223884727456607, 0.05252906041278038, 0.026830625611182768, 0.09355702117318287, 0.04503559161094017, 0.05474765152030159, 0.014355018338392256, 0.027969302791461814, 0.02902098356571514, 0.03794714619289152, 0.07818280122592114, 0.01796916898456402, 0.020014654146507382, 0.009285672877012985, 0.042200932584819384, 0.021941230552329216, 0.026848136585613247, 0.08195346061256714, 0.02843428428604966, 0.030796711034781765, 0.10412967181764543, 0.03703058639075607, 0.06619429608690552, 0.1182941539445892, 0.02612940181279555, 0.023119959587347694, 0.020924686759826727, 0.016540625620109495, 0.05608543207927141, 0.15777038410305977, 0.017304740867984947, 0.02196281962824287, 0.0642070324101951, 0.026201720393146388, 0.022221114850253798, 0.048939540720311925, 0.020190350187476724, 0.029391446987574454, 0.041175644437316805, 0.08084229484666139, 0.06436473879148252, 0.05593818626948632, 0.03564451057172846, 0.032851879368536174, 0.0663560842804145, 0.027952559939876664, 0.05611497697827872, 0.03375393389433157, 0.0575423792906804, 0.022159947038744576, 0.024394377433054615, 0.03677155458717607, 0.01718416970106773, 0.03206197819963563, 0.04186812016996555, 0.011716199096554192, 0.030760906120121945, 0.11501441782456823, 0.04134195973165333, 0.06633499986492097, 0.05987076001474634, 1.2440078845247626, 8.601536694914103, 23.933137357234955, 30.800723545253277, 30.198452062904835, 17.10186582058668, 12.381779998540878, 23.054136224091053, 15.555411502718925, 3.5504589462652802, 0.3540846233954653, 0.14024002477526665, 0.9306815068703145, 0.9277230687439442, 5.589246908202767, 7.964812936261296, 8.198995795100927, 8.909796103835106, 6.260946365073323, 5.113947037607431, 4.715056791901588, 4.2239901423454285, 3.4035315178334713, 2.718044025823474, 3.5174914402887225, 5.316712707281113, 14.826410170644522, 24.813614711165428, 38.70883449912071, 49.09897416830063, 54.166967421770096, 56.36942803859711, 53.678473234176636, 53.314654156565666, 52.80512049794197, 55.030273497104645, 56.35376147925854, 56.41700528562069, 51.34682334959507, 52.073256969451904, 52.26442851126194, 54.80955094099045, 52.22247116267681, 50.901236459612846, 46.981689780950546, 44.06090050935745, 42.69929677248001, 41.12629137933254, 41.244381442666054, 40.95743604004383, 47.413415014743805, 54.37352433800697, 53.04827705025673, 56.14979222416878, 48.426600247621536, 43.11838388442993, 54.84718792140484, 53.054455518722534, 50.575035363435745, 43.62661801278591, 40.26339188218117, 40.807545483112335, 45.98456248641014, 49.53911975026131, 51.21528580784798, 51.39196112751961, 51.03306658565998, 49.22549597918987, 46.001338586211205, 42.43250548839569, 39.450170919299126, 37.943449169397354, 43.98586593568325, 49.791392013430595, 52.48602122068405, 50.87457329034805, 51.35913088917732, 51.221312284469604, 46.81282304227352, 50.85406579077244, 49.77779634296894, 52.06662632524967, 48.06712053716183, 49.15582671761513, 49.14797253906727, 48.814852014184, 40.62375694513321, 32.66680151224136, 18.64495161920786, 7.462728777900338, 2.415381004102528, 2.6520814653486013, 4.391052927821875, 7.361423838883638, 7.558280350640416, 8.653233870863914, 4.959172792732716, 7.058524992316961, 2.577011031098664, 0.7376272848341614, 0.10690278082620353, 0.5910943227354437, 4.328890638425946, 15.165853556245565, 23.520886078476906, 32.647346556186676, 30.39514660835266, 23.54318518191576, 29.577941559255123, 24.23665177077055, 6.306256083771586, 0.11896380121470429, 0.06144185324956197, 0.039881465054349974, 0.02866743740014499, 0.06719423618051223, 0.013776926116406685, 0.01810146051866468, 0.12469559325836599, 0.041202372885891236, 0.013735225766140502, 0.020341809540695976, 0.042686991073424, 0.03808182002103422, 0.05826515320222825, 0.07045904771075584, 0.007717756961937994, 0.026024001999758184, 0.03976774947659578, 0.02657043791259639, 0.028896530966449063, 0.026546255030552857, 0.028353820634947624, 0.055535010833409615, 0.02394693103269674, 0.053599248494720086, 0.02974467588501284, 0.02060130333120469, 0.040901829052018, 0.00618046113231685, 0.009537579135212582, 0.15861324121942744, 0.16638983564916998, 0.2567621081834659, 0.3222342277877033, 0.1653005855041556, 0.1193217613035813, 0.12692041840637103, 0.11603378734434955, 0.15635500458301976, 0.17742353811627254, 0.1072744038538076, 0.1867931822198443, 0.13374176487559453, 0.1462990668369457, 0.1413643339765258, 0.19666459236759692, 0.2218274655751884, 0.21679747063899413, 0.1091396584524773, 0.1639348259777762, 0.25526724464725703, 0.2110312058357522, 0.08403960062423721, 0.13231742021162063, 0.10644590729498304, 0.23817402514396235, 0.18859805568354204, 0.19110194320091978, 0.14925980562111363, 0.08889907228876837, 0.20759332546731457, 0.22072614810895175, 0.2344796436955221, 0.11757453044992872, 0.2575521689141169, 1.0166018432937562, 8.930514492094517, 29.34262588620186, 38.64816315472126, 39.652046486735344, 21.083630360662937, 14.84810795634985, 22.656016387045383, 18.074644021689892, 6.779608558863401, 1.1326605593785644, 0.8290577412117273, 2.1629921346902847, 7.805740172043443, 14.114447124302387, 16.45317602902651, 16.75719391554594, 15.288427378982306, 9.230127464979887, 12.730669677257538, 9.016481079161167, 7.754517495632172, 4.784031165763736, 4.0654688235372305, 6.098305592313409, 4.827369740232825, 13.986742626875639, 24.33302029967308, 37.85132311284542, 47.580913826823235, 54.161324724555016, 57.69140750169754, 56.50725044310093, 57.344725504517555, 55.172594860196114, 58.16255182027817, 58.78101423382759, 56.977004036307335, 51.24213516712189, 52.56645530462265, 51.49315729737282, 56.95518180727959, 55.029836520552635, 53.32494780421257, 48.90736944973469, 47.063016816973686, 45.037212520837784, 43.149523213505745, 43.64908620715141, 41.85198023915291, 50.54736904799938, 57.674243822693825, 56.51580758392811, 56.97585269808769, 47.7148300409317, 44.50096629559994, 57.608970925211906, 56.92932419478893, 52.51146465539932, 47.47972145676613, 42.09115460515022, 42.743761986494064, 48.8632196187973, 52.395658269524574, 54.5400770008564, 53.80786769092083, 52.794500067830086, 51.65497541427612, 48.374436646699905, 45.515511855483055, 41.541658490896225, 39.36458811163902, 44.93941716849804, 53.18829193711281, 55.89976564049721, 53.449790105223656, 51.987309381365776, 51.51263125240803, 49.53692726790905, 51.755297631025314, 51.23689524829388, 52.814137414097786, 49.99298259615898, 50.2631177008152, 50.82581430673599, 51.509865000844, 41.208461970090866, 34.212376177310944, 20.071104392409325, 7.776961466297507, 2.988906791433692, 3.9092136081308126, 6.337487082928419, 8.559584096074104, 9.06342850998044, 14.926243163645267, 14.05202692374587, 13.83268179371953, 7.806394211947918, 2.0938135217875242, 1.104916229378432, 0.8717529033310711, 5.182929486036301, 16.495334766805172, 28.303233459591866, 43.37236985564232, 34.59527403116226, 29.174201823771, 39.25659790635109, 27.91007425636053, 6.931149177253246, 0.2710358938202262, 0.18272365996381268, 0.13920512952608988, 0.17041696642991155, 0.22989269607933238, 0.16989020485198125, 0.09593959723133594, 0.19950884365243837, 0.17240785178728402, 0.10008076642407104, 0.1655399429728277, 0.09897826894302852, 0.14089779026107863, 0.1632144083851017, 0.2560905832797289, 0.08192857640096918, 0.08591533434810117, 0.14066578005440533, 0.1728892681421712, 0.16201785852899775, 0.12306182936299592, 0.13869565998902544, 0.15742561197839677, 0.06432940514059737, 0.16401669970946386, 0.1810275111347437, 0.23660867242142558, 0.19831131416140124, 0.057664072955958545, 0.1887374310172163], [0.015660651843063533, 0.08695293101482093, 0.012718373982352205, 0.03467017457296606, 0.02157810697099194, 0.010279724028805504, 0.031411318777827546, 0.011904627608601004, 0.10167313332203776, 0.04853002363233827, 0.04573110643832479, 0.07758171355817467, 0.05004095466574654, 0.03671106584079098, 0.022499166043417063, 0.06127433938672766, 0.0736795381817501, 0.05415273109974805, 0.07346973303356208, 0.060659035880235024, 0.0775336372316815, 0.05294062582834158, 0.04941607745422516, 0.017936868862307165, 0.05706678508431651, 0.016726383328204975, 0.061258839632500894, 0.004614488716470078, 0.05969283010927029, 0.028823362627008464, 0.07292556809261441, 0.03844405488052871, 0.03723774578247685, 0.02074583844660083, 0.0527192580193514, 0.03656247674371116, 1.9862824981100857, 13.844208475202322, 22.89911214262247, 27.250802032649517, 19.63781364262104, 18.398293554782867, 14.70475209876895, 14.630646575242281, 9.51019998639822, 3.8614247599616647, 0.213678669242654, 0.4496650805231184, 0.43640857154969126, 6.1800881288945675, 6.219619307667017, 5.832467582076788, 10.057471320033073, 3.287659347988665, 2.87663659080863, 3.385963160544634, 3.673023981973529, 3.5653843078762293, 2.5081095658242702, 2.234185114502907, 2.776951789855957, 5.904118912294507, 13.274431899189949, 19.953324012458324, 37.00393058359623, 46.6166889667511, 55.01686401665211, 54.673708230257034, 53.71830649673939, 53.07497441768646, 53.43925707042217, 56.23186022043228, 56.33900687098503, 51.40086404979229, 53.35062302649021, 52.583987563848495, 56.62189409136772, 51.76440194249153, 50.77279195189476, 45.019007697701454, 44.32956509292126, 41.55260190367699, 43.32855440676212, 40.73389783501625, 43.24816212058067, 45.6860277056694, 53.6176422983408, 49.62159812450409, 56.93062372505665, 46.95318751037121, 38.52193392813206, 54.38785336911678, 49.401263147592545, 49.400115609169006, 41.03308618068695, 41.72234259545803, 46.721662133932114, 50.39505422115326, 50.89641831815243, 51.81940019130707, 50.592579022049904, 50.31975746154785, 48.78401666879654, 49.72632810473442, 45.72894260287285, 42.09779664874077, 38.11849057674408, 39.530160427093506, 44.54317443072796, 47.94474430382252, 49.73944880068302, 48.96924152970314, 51.567029133439064, 48.88091906905174, 51.394590586423874, 51.30031004548073, 49.20798271894455, 48.37298512458801, 49.21929091215134, 47.02586621046066, 40.89803382754326, 28.459076397120953, 20.949710346758366, 6.392881460487843, 1.6007671784609556, 1.0043324204161763, 2.047589239664376, 4.036484928801656, 5.752988671883941, 5.134239373728633, 3.9988674223423004, 7.764030285179615, 7.695562709122896, 1.5658389776945114, 0.3255074849585071, 0.2593206474557519, 1.7919964296743274, 10.986332427710295, 19.613088369369507, 35.43448179960251, 30.43695766478777, 18.052996583282948, 24.523306488990784, 26.767726354300976, 11.013814453035593, 0.5604754469823092, 0.0813746967469342, 0.13886332599213347, 0.0577214929217007, 0.02064315489405999, 0.035648221310111694, 0.046457290518446825, 0.03310843982035294, 0.02104202958435053, 0.026601417011988815, 0.08268592326203361, 0.027643602006719448, 0.041914485846064053, 0.019922184401366394, 0.05369010592403356, 0.048409049850306474, 0.10099686609464698, 0.041325242855236866, 0.07042634868412279, 0.06606218637898564, 0.036029354960191995, 0.05714984625228681, 0.024531272138119675, 0.04270229044777807, 0.019104398888885044, 0.01889520415716106, 0.0517927274631802, 0.026153298967983574, 0.03518583733239211, 0.02359291545872111, 0.04621263040462509, 0.055421388024115004, 0.028820954357797746, 0.033654794096946716, 0.0024391411625401815, 0.07528927875682712, 0.03279985852714162, 0.029342047782847658, 0.028686792611551937, 0.055281682434724644, 0.06130759131337982, 0.03788417867326643, 0.06703974329866469, 0.04159848307608627, 0.0787630642298609, 0.02628808782901615, 0.06756318747648038, 0.050677394538070075, 0.0561083421780495, 0.05569224966166075, 0.06176313268952072, 0.028188201104057953, 0.06910326264915057, 0.02332674976059934, 0.04778379785420839, 0.027325491537339985, 0.06364746790495701, 0.0720473105320707, 0.04420223398483358, 0.03665955337055493, 0.012038947988912696, 0.07270200352650136, 0.04668725610827096, 0.09589100140146911, 0.0073862887620634865, 0.08336368220625445, 0.06208277198311407, 3.9473799476400018, 17.863493151962757, 29.255209676921368, 33.306983560323715, 22.279566787183285, 15.845031961798668, 20.223117135465145, 22.237997017800808, 11.466054785996675, 3.7055566487833858, 0.19955512398155406, 0.05036577786086127, 0.5648189107887447, 1.6679449612274766, 3.9255422819405794, 7.818422941491008, 8.955264464020729, 6.0532238613814116, 8.74420003965497, 5.14544639736414, 4.619942670688033, 6.003307839855552, 3.167460635304451, 2.2873442620038986, 5.486763082444668, 8.121771588921547, 17.070751190185547, 23.312862440943718, 37.65220619738102, 48.39692384004593, 57.326896861195564, 55.994999930262566, 56.54630854725838, 54.2825648188591, 55.107090175151825, 57.0810766518116, 57.54763841629028, 51.806663274765015, 52.621065974235535, 53.841666877269745, 57.03413397073746, 53.45709711313248, 52.638096660375595, 47.0670598000288, 44.57523711025715, 43.15029077231884, 44.0701188147068, 43.305687233805656, 44.88606423139572, 49.39148247241974, 55.3753861784935, 53.73341828584671, 57.19296544790268, 47.974994480609894, 42.75038503110409, 56.908676102757454, 51.27513639628887, 52.0459820330143, 43.36680315434933, 43.16216513514519, 47.48894736170769, 51.671964302659035, 52.91729427874088, 53.239243403077126, 53.19457679986954, 52.29410111904144, 51.39451079070568, 51.06218062341213, 45.97416244447231, 42.817671820521355, 39.05250325798988, 41.38308919966221, 46.822577118873596, 49.721718952059746, 51.50601960718632, 51.59454345703125, 51.65759727358818, 49.40214090049267, 51.70522391796112, 52.397014796733856, 50.7194048166275, 50.2863572537899, 50.47412037849426, 48.059794530272484, 42.02359423041344, 31.93391963839531, 23.685751631855965, 9.123869016766548, 2.7026990242302418, 2.2644426533952355, 4.312652684748173, 5.226996196433902, 7.4128403048962355, 8.257605750113726, 8.384257704019547, 5.27551531791687, 6.330323042348027, 1.5382390399463475, 0.32380467164330184, 0.2737868274562061, 1.523456764407456, 11.618536803871393, 19.452788271009922, 37.69764795899391, 37.83081941306591, 18.658967167139053, 24.896524362266064, 32.245890498161316, 13.67458937689662, 1.0345013765618205, 0.017246165007236414, 0.05354222186724655, 0.040282703484990634, 0.04019423577119596, 0.034699047828326, 0.03738738872925751, 0.10113428215845488, 0.08173388137947768, 0.01668062621320132, 0.028573516756296158, 0.034532068311818875, 0.025127359585894737, 0.08411797884036787, 0.07380919880233705, 0.02095165826176526, 0.01864033951278543, 0.05164851332665421, 0.09060947035322897, 0.044205484591657296, 0.0240930543441209, 0.040664226762601174, 0.017422616183466744, 0.038007991170161404, 0.025567221236997284, 0.031914598803268746, 0.018289127401658334, 0.0824320493848063, 0.02389328488789033, 0.04209865350276232, 0.01935628752107732, 0.12192130423500203, 0.2322906197514385, 0.1336916847503744, 0.11048294574720785, 0.3110986581305042, 0.11869115842273459, 0.1254102963139303, 0.12029998615616933, 0.2629279007669538, 0.1973941532196477, 0.13769846584182233, 0.150663859967608, 0.1136482649599202, 0.24631591950310394, 0.12188437496661209, 0.2025780250551179, 0.1382302146521397, 0.12805891747120768, 0.16596501547610387, 0.20944873918779194, 0.14630102610681206, 0.13510820717783645, 0.14593979314668104, 0.18969267897773534, 0.10995600605383515, 0.12898458342533559, 0.13751329999649897, 0.08439282581093721, 0.1663929081405513, 0.13451815524604172, 0.2187915620743297, 0.15993169625289738, 0.23935680073918775, 0.12148877314757556, 0.17654971859883517, 0.20752259879373014, 3.843418713659048, 18.543785847723484, 34.546955823898315, 44.20147396624088, 32.34834060072899, 27.110631354153156, 22.245898693799973, 21.53672944754362, 13.605478685349226, 5.629147617146373, 0.7620789727661759, 0.8500483492389321, 1.9428970199078321, 12.206614147871733, 15.829660836607218, 14.120585694909096, 19.586881175637245, 11.226795874536037, 12.833284121006727, 8.940028231590986, 8.914721589535475, 7.327276496216655, 5.719917621463537, 4.585459046065807, 5.261354902759194, 8.329629935324192, 14.540408067405224, 21.561977192759514, 38.438794389367104, 47.759527042508125, 59.740170165896416, 57.97136887907982, 57.500509545207024, 55.88671334087849, 57.98503674566746, 58.9871721714735, 58.53155381977558, 51.98238864541054, 51.69670097529888, 54.572067484259605, 58.900582417845726, 56.37498714029789, 55.280224084854126, 50.27947202324867, 46.56512573361397, 45.50478883087635, 46.20973460376263, 44.63914208114147, 47.32632368803024, 51.31076708436012, 59.09325107932091, 55.207522585988045, 57.16925852000713, 50.447658598423004, 45.75538158416748, 57.83877119421959, 53.23901541531086, 53.75620946288109, 45.51075831055641, 46.19654171168804, 52.03028127551079, 54.33709569275379, 55.61391457915306, 56.04642637073994, 56.42489746212959, 55.0208006054163, 53.509937077760696, 53.90428751707077, 48.88101406395435, 46.18932209908962, 42.403182461857796, 43.819073885679245, 48.17290686070919, 51.13404996693134, 52.102317810058594, 51.23169332742691, 51.30213014781475, 50.69434516131878, 52.31954835355282, 52.47975915670395, 51.68681390583515, 52.61235684156418, 51.83307185769081, 49.474169835448265, 43.80884103477001, 31.572817414999008, 22.81525444239378, 8.11632078140974, 2.7919521974399686, 3.0391999427229166, 6.41741911880672, 9.331106096506119, 11.796921081840992, 11.897121705114841, 11.401033625006676, 16.53778038918972, 13.99954603984952, 3.3777938364073634, 1.104588971938938, 0.713596127461642, 2.3311084136366844, 14.884737990796566, 25.10070640593767, 44.32073816657066, 39.63955655694008, 25.830964520573616, 34.828478917479515, 36.177235543727875, 14.722178913652897, 0.973442749818787, 0.19733031367650256, 0.18947212753118947, 0.24724226823309436, 0.04400595076731406, 0.1660817107767798, 0.20528643362922594, 0.21964598185149953, 0.12336996907833964, 0.146796528424602, 0.21332557022105902, 0.1606039484613575, 0.10537644280702807, 0.1750966379768215, 0.1136036915704608, 0.18671490048291162, 0.16538514581043273, 0.13948858540970832, 0.17864984809421003, 0.1678096828982234, 0.14668162912130356, 0.21324396366253495, 0.11158745444845408, 0.25062879198230803, 0.11330007153446786, 0.16752159601310268, 0.17297099344432354, 0.15901554463198408, 0.14015426218975335, 0.15517622174229473, 0.09977996654924937], [0.03271882342232857, 0.03035588830243796, 0.059135321353096515, 0.05063536300440319, 0.0484749080351321, 0.06991825212026015, 0.08758399402722716, 0.09254165925085545, 0.07595258808578365, 0.08930498996051028, 0.05891068809432909, 0.018844463520508725, 0.08110250666504726, 0.08264963966212235, 0.03336678884807043, 0.01793631410691887, 0.027145917774760164, 0.08974368829512969, 0.029595669329864904, 0.08235352273914032, 0.03980395144026261, 0.0362244470306905, 0.03507383611577097, 0.05948283571342472, 0.00539019213647407, 0.053067277040099725, 0.01399753136865911, 0.05601860168098938, 0.030488311567751225, 0.0040831457681633765, 0.06551264086738229, 0.018466958972567227, 0.07155756728025153, 0.02881157361116493, 0.04273306731192861, 0.12466149899410084, 0.17562878754688427, 4.617852782830596, 13.89073982834816, 20.17566718161106, 26.665509939193726, 22.51169253140688, 14.343581479042768, 17.236342504620552, 16.091152355074883, 10.209826044738293, 2.9767417442053556, 0.7992363476660103, 0.22854482231196016, 1.2791419867426157, 3.077038787305355, 5.5733314622193575, 5.558321792632341, 4.910600949078798, 3.5376239474862814, 2.6554559217765927, 2.3553166771307588, 4.495097519829869, 1.703236042521894, 1.0504611139185727, 3.0903720343485475, 2.4911313643679023, 10.212581846863031, 14.322879239916801, 23.189591355621815, 37.8850919008255, 48.773061856627464, 53.13021965324879, 58.98220203816891, 53.351930156350136, 55.919562578201294, 54.45455498993397, 56.80570162832737, 53.07040326297283, 57.3626871407032, 54.57910470664501, 56.25386863946915, 52.27136313915253, 51.111019402742386, 44.93074983358383, 46.371434926986694, 43.07842142879963, 44.304087460041046, 44.63570326566696, 47.71803706884384, 48.723402321338654, 53.79020243883133, 51.44951283931732, 51.14995211362839, 46.76814503967762, 37.97579683363438, 54.476650804281235, 50.08610039949417, 50.49099147319794, 45.359933003783226, 45.91548979282379, 48.29534389078617, 51.53957940638065, 52.11558289825916, 53.03292967379093, 52.3880472779274, 52.4001382291317, 51.35668762028217, 49.25019845366478, 47.367391884326935, 46.240106374025345, 44.47380915284157, 43.36018390953541, 45.982069820165634, 47.55246855318546, 50.18882788717747, 50.02888306975365, 50.10020524263382, 50.91636344790459, 50.57081758975983, 49.37260888516903, 50.53407356142998, 46.92250795662403, 42.550511956214905, 38.61342541873455, 26.687493659555912, 16.97640985250473, 8.738118465989828, 2.116532502695918, 0.421150045003742, 1.0828273021616042, 3.0147271184250712, 3.8295131223276258, 7.53371799364686, 9.878179840743542, 6.7000973504036665, 2.0943644922226667, 3.630361296236515, 1.5806552139110863, 0.28814005258027464, 1.2252833205275238, 10.211974829435349, 26.096315681934357, 31.399683505296707, 21.361053474247456, 41.89352720975876, 38.80570650100708, 28.777345418930054, 17.162341475486755, 4.865465071052313, 0.09243220731150359, 0.04174845998932142, 0.025727788597578183, 0.01691860885330243, 0.033238727555726655, 0.00897946552868234, 0.05169396616111044, 0.0457089273550082, 0.04066688736202195, 0.06328780087642372, 0.05293285183142871, 0.024217113605118357, 0.04244660944095813, 0.025555333886586595, 0.0790197508467827, 0.03042651849682443, 0.054083889481262304, 0.041394006548216566, 0.04284761780581903, 0.02245552033855347, 0.05125070732901804, 0.04523571544268634, 0.05431533936643973, 0.030223485446185805, 0.03803969200816937, 0.0385224479396129, 0.0464551271579694, 0.0273559641209431, 0.041023830708581954, 0.12577909918036312, 0.030855526238156017, 0.05995382489345502, 0.045992464874871075, 0.044498814750113524, 0.04772920918185264, 0.018821510748239234, 0.019142821729474235, 0.020318715760367922, 0.08908575211535208, 0.04930158633214887, 0.02869089297746541, 0.03466319838480558, 0.023295904247788712, 0.08370321476832032, 0.036942582519259304, 0.003535262203513412, 0.006043995017535053, 0.02511449631128926, 0.025708830435178243, 0.026727520889835432, 0.048900192050496116, 0.07443732290994376, 0.03313566179713234, 0.06752127097570337, 0.013999415496073198, 0.043756633676821366, 0.03309665080450941, 0.048392355238320306, 0.0984116985637229, 0.011361235428921646, 0.016815641429275274, 0.016239844298979733, 0.02017371494730469, 0.04647203328204341, 0.04429760738275945, 0.05406444892287254, 0.11446047137724236, 0.5421193444635719, 8.225905001163483, 20.05497805774212, 28.66219449788332, 31.9999410957098, 27.23855149000883, 15.07093084976077, 20.781101994216442, 22.90897261351347, 9.594651404768229, 3.400033568032086, 1.0823753639124334, 0.18187148147262633, 0.11826591522549279, 2.419592603109777, 4.713439028710127, 6.867394773289561, 4.478713748976588, 6.977394120767713, 10.611632633954287, 3.7195439357310534, 7.26521585136652, 3.2384063908830285, 2.3110737511888146, 3.7673408584669232, 2.688570194877684, 11.142519246786833, 16.447624526917934, 26.92246165126562, 40.823006853461266, 50.15809893608093, 55.181102603673935, 58.81397746503353, 54.39161516726017, 56.94892734289169, 55.89942745864391, 57.68093526363373, 52.75131918489933, 55.85023529827595, 54.519759491086006, 58.1956784427166, 56.24178148806095, 53.56125332415104, 47.25580707192421, 47.26951293647289, 45.520022213459015, 44.9842319637537, 45.35625100135803, 47.854609340429306, 50.82751281559467, 54.816546365618706, 52.53850020468235, 53.43005396425724, 50.053536146879196, 41.571475490927696, 56.12556852400303, 52.54690155386925, 52.009758576750755, 45.601109862327576, 47.892930284142494, 51.08523778617382, 52.6089446246624, 53.96882325410843, 54.661712273955345, 52.947308868169785, 53.406081050634384, 52.02263228595257, 51.432330161333084, 49.924365878105164, 48.83563689887524, 45.205038115382195, 45.237237587571144, 47.23015084862709, 49.280327036976814, 51.705733090639114, 51.23263567686081, 51.201169565320015, 51.08217895030975, 52.19936080276966, 50.6361398845911, 52.99444533884525, 49.48324374854565, 46.1288483440876, 40.45369327068329, 30.75698409229517, 18.762163929641247, 10.937866028398275, 2.9449944477528334, 1.5899935690686107, 3.0106197763234377, 4.0753568429499865, 5.644564814865589, 7.713264059275389, 10.383400730788708, 7.280951756983995, 3.1411498971283436, 1.9119562301784754, 0.5398264643736184, 0.38976764772087336, 1.3393336068838835, 10.26442151516676, 29.502103328704834, 36.28660887479782, 25.207281187176704, 42.23965063691139, 35.02564273774624, 32.463193237781525, 21.264926232397556, 6.375558665022254, 0.12607625511009246, 0.04300378051993903, 0.041813490679487586, 0.024408253739238717, 0.07131458070944063, 0.032648619962856174, 0.018045368997263722, 0.043324421712895855, 0.04698218188423198, 0.11456759297288954, 0.040362714426009916, 0.056908967380877584, 0.035402217908995226, 0.060904705314897, 0.05992564183543436, 0.0464934590854682, 0.043643448734655976, 0.09177407817333005, 0.015488255576201482, 0.022345070210576523, 0.0797845637134742, 0.0816500632208772, 0.017198726927745156, 0.014437723275477765, 0.048365478360210545, 0.1110151621105615, 0.08361691783647984, 0.008338637708220631, 0.05825556465424597, 0.11286450506304391, 0.03615889683715068, 0.12215140712214634, 0.14210021792678162, 0.1245056999323424, 0.14300660288427025, 0.0870458701683674, 0.16390514007071033, 0.27013189857825637, 0.20107284566620365, 0.20805863721761853, 0.12282038645935245, 0.17356589902192354, 0.12023628762108274, 0.209605599520728, 0.19076224736636505, 0.13250267511466518, 0.07441948167979717, 0.14752441202290356, 0.14123856963124126, 0.07709858284215443, 0.21238376997644082, 0.11858792568091303, 0.14964667236199602, 0.19152783206664026, 0.13963995384983718, 0.06537353270687163, 0.14968236966524273, 0.08750472523388453, 0.11884482009918429, 0.08259993803221732, 0.11524905523401685, 0.1550001694704406, 0.13069468463072553, 0.13749954057857394, 0.11744213130441494, 0.16576543712290004, 0.2047844894696027, 0.4901428835000843, 7.912657409906387, 23.67017436772585, 33.695645704865456, 40.792726278305054, 36.52699537575245, 21.92631494253874, 27.453327365219593, 24.65523350983858, 14.396142158657312, 5.190406059846282, 1.2582015478983521, 0.29213636938948184, 3.5331940976902843, 7.395362667739391, 12.249436900019646, 14.352540448307991, 11.994866710156202, 8.331813868135214, 10.438120644539595, 7.700408874079585, 11.06608159840107, 5.700864968821406, 3.5392355360090733, 5.776905063539743, 3.789376588538289, 12.699614893645048, 17.37180333584547, 26.998330280184746, 40.97011595964432, 51.63332797586918, 56.33805312216282, 61.855398863554, 57.01481580734253, 59.50274370610714, 57.057198733091354, 58.638179898262024, 53.42061147093773, 58.147371634840965, 54.74629573523998, 59.64629240334034, 57.63201668858528, 55.100451931357384, 48.81053164601326, 51.02284133434296, 47.42928296327591, 47.72361136972904, 48.68359185755253, 51.8074194341898, 53.87348257005215, 56.64379991590977, 55.864476934075356, 54.17924076318741, 52.50298731029034, 46.880125030875206, 55.998385548591614, 55.38045130670071, 53.13295930624008, 48.42666484415531, 51.32910490036011, 52.633020132780075, 54.838995561003685, 55.2504450827837, 55.75240954756737, 54.4222567230463, 54.81560781598091, 54.91330437362194, 53.891721591353416, 50.43114088475704, 50.09237386286259, 48.71921494603157, 47.2846095263958, 50.08125565946102, 53.70664872229099, 54.466189965605736, 52.82111003994942, 50.39506182074547, 52.35042929649353, 52.59613551199436, 50.81433892250061, 53.41858997941017, 49.523358196020126, 47.12420113384724, 41.02148160338402, 30.083580426871777, 18.942984826862812, 10.19417468458414, 2.850413485430181, 1.4499066048301756, 2.4339422956109047, 6.171582285314798, 9.832112062722445, 14.174887631088495, 18.360276594758034, 12.379252184182405, 5.475719450041652, 5.943079646676779, 2.925353064201772, 0.7036031980533153, 1.9304376072250307, 12.208401951938868, 31.734025664627552, 38.39456856250763, 29.708747640252113, 48.800135403871536, 45.36255866289139, 40.04571296274662, 24.21406578272581, 6.822593277320266, 0.27649213385302573, 0.20557078009005636, 0.08007961936527863, 0.08673233503941447, 0.1651970559032634, 0.1194664578360971, 0.0826194862020202, 0.1980287191690877, 0.0946036349341739, 0.1312264334410429, 0.10790424232254736, 0.22088182100560516, 0.11351153167197481, 0.10805610058014281, 0.12216719260322861, 0.13698284252313897, 0.12130466115195304, 0.20959422981832176, 0.1380190736381337, 0.16311438172124326, 0.11852640905999579, 0.21024577610660344, 0.14399395615328103, 0.07975669606821612, 0.16604436590569094, 0.2353153019794263, 0.19651038892334327, 0.12666131980950013, 0.12331951787928119, 0.206811576790642, 0.13566360081313178], [0.07827597786672413, 0.07171436081989668, 0.037866025741095655, 0.022521855353261344, 0.022282405116129667, 0.029608944496430922, 0.04161589757131878, 0.04116364390938543, 0.07153358848881908, 0.030219208820199128, 0.07658573653316125, 0.0043044722951890435, 0.06350269715767354, 0.06847628144896589, 0.03807787179539446, 0.042080667553818785, 0.012411464376782533, 0.12828078994061798, 0.03735904239874799, 0.03664929317892529, 0.004888595858574263, 0.01703652313153725, 0.048575012624496594, 0.06456423550844193, 0.03643522439233493, 0.040082947016344406, 0.07665058539714664, 0.030078879826760385, 0.029261688032420352, 0.06483966135419905, 0.043017892458010465, 0.06082322863221634, 0.008353018674824852, 0.020161784923402593, 0.03340413371915929, 0.017746648991305847, 0.08979187594377436, 1.3713084161281586, 6.792137436568737, 20.501450300216675, 27.018934674561024, 25.69008708000183, 12.906147111207247, 13.187634106725454, 14.148337505757809, 22.448281534016132, 9.226884339004755, 2.3480061069130898, 0.8988311409484595, 0.1275994538445957, 1.9571828283369541, 4.655468864366412, 6.499689929187298, 3.5829322412610054, 5.806489801034331, 9.674331229180098, 2.728448580019176, 7.0685645285993814, 4.288853611797094, 2.2971277870237827, 3.058016770519316, 1.254263890441507, 3.9521729154512286, 7.296047396957874, 15.46215595677495, 23.933606632053852, 35.1994264125824, 45.03972038626671, 52.48544745147228, 55.21462820470333, 56.10827565193176, 57.01683729887009, 55.207059010863304, 54.05528761446476, 50.95085799694061, 54.67274688184261, 58.14881935715675, 53.587601110339165, 53.199075758457184, 47.554398849606514, 47.85156190395355, 47.016134932637215, 48.3579683303833, 47.77771286666393, 50.74017450213432, 49.71125811338425, 53.890501856803894, 52.697616666555405, 52.360920533537865, 50.34957826137543, 39.5299856364727, 53.75350780785084, 50.261145606637, 47.47869551181793, 47.06257984042168, 50.06473794579506, 52.019987627863884, 52.47309811413288, 53.87182965874672, 52.18622490763664, 52.67082430422306, 56.17304317653179, 51.65884740650654, 52.8474236279726, 49.502827897667885, 49.93493691086769, 47.271409034729004, 48.78643713891506, 48.184006065130234, 48.78790006041527, 49.91707406938076, 48.229223638772964, 51.40841044485569, 50.702830106019974, 51.73642784357071, 45.773350819945335, 42.77992084622383, 39.44976434111595, 30.12208566069603, 23.867083601653576, 15.258002411574125, 5.798739166930318, 1.4323376538231969, 0.5641223606653512, 2.0072772027924657, 3.92600039485842, 2.653877343982458, 3.335747430101037, 7.163852965459228, 6.640331782400608, 7.392287207767367, 2.4503792636096478, 3.122139279730618, 0.6154515501111746, 1.0027196444571018, 7.2315287590026855, 19.1272996366024, 19.102340675890446, 16.111025288701057, 16.713490560650826, 34.78296495974064, 40.713519528508186, 27.101283855736256, 7.164204446598887, 0.9251143899746239, 0.02018343522649957, 0.04574479906295892, 0.007982246333995136, 0.0506710157787893, 0.01761501611326821, 0.038277064231806435, 0.024955624758149497, 0.04386806715046987, 0.057198523718398064, 0.05041551288741175, 0.04730317188659683, 0.07498812265112065, 0.07424693976645358, 0.07206810550997034, 0.01393479855323676, 0.0544399051432265, 0.010127903806278482, 0.0685045869613532, 0.04078599464264698, 0.026368737017037347, 0.03551794470695313, 0.086245270940708, 0.01798584318748908, 0.05033541288867127, 0.06419271638151258, 0.03728625255462248, 0.01953734001290286, 0.023098888159438502, 0.019154733199684415, 0.04728287043690216, 0.059194043788011186, 0.06475602131104097, 0.0752095201460179, 0.053601393301505595, 0.025036698825715575, 0.07720911089563742, 0.051935275478172116, 0.01878806400782196, 0.03658247762359679, 0.049250270531047136, 0.0313032806297997, 0.03433482030231971, 0.012263178632565541, 0.07019165190286003, 0.04708365573605988, 0.00937883838560083, 0.07093068998074159, 0.03116541927738581, 0.0492849585134536, 0.028787665323761757, 0.015810044315003324, 0.04885571514023468, 0.021219195077719633, 0.025727632746566087, 0.017305521978414617, 0.0493892228405457, 0.02089942034217529, 0.06864865266834386, 0.04573665399220772, 0.047642173813073896, 0.07620474018040113, 0.05913956272706855, 0.026857897682930343, 0.09778692154213786, 0.04992167669115588, 0.03708804717462044, 0.0023859252314650803, 0.198444603884127, 2.1113241696730256, 10.546772964298725, 23.158609718084335, 31.46094761788845, 30.559656880795956, 15.789662282913923, 14.325199015438557, 20.226390659809113, 27.270469777286053, 10.657669063657522, 1.9453830365091562, 0.5521546653471887, 0.1414395432220772, 0.695183799834922, 2.212847121991217, 3.7335138861089945, 4.955897843465209, 7.755911545827985, 16.087458953261375, 4.312194809317589, 5.163829335942864, 6.231304630637169, 4.49678985401988, 4.44276150316, 1.938722706399858, 4.535259464755654, 8.715565726161003, 17.490554563701153, 28.10968704521656, 38.68544675409794, 47.437938898801804, 56.20197482407093, 55.192619785666466, 58.952461034059525, 56.919995695352554, 56.14930585026741, 55.572568997740746, 51.93627431988716, 54.63465392589569, 59.80949744582176, 54.24186900258064, 54.35649745166302, 48.80300424993038, 48.213952258229256, 48.73866610229015, 49.93198446929455, 49.49269384145737, 51.5842080116272, 51.08037404716015, 55.10669879615307, 54.06922146677971, 52.41347171366215, 50.90155564248562, 41.024814024567604, 55.12675791978836, 52.92448729276657, 50.52062228322029, 47.567812129855156, 50.1861110329628, 53.17486345767975, 52.997378781437874, 54.86299887299538, 53.76667410135269, 52.957359328866005, 55.81890217959881, 53.65987703204155, 52.91195176541805, 51.753059551119804, 50.7330346852541, 49.49405416846275, 50.277081951498985, 49.55447852611542, 49.6531668305397, 53.01619917154312, 49.96788114309311, 51.78132623434067, 52.26759374141693, 52.17223405838013, 48.61510433256626, 44.38862532377243, 41.526805087924004, 34.040769785642624, 25.64140599220991, 18.015942871570587, 8.080211319029331, 3.9761805022135377, 2.317622462287545, 2.4965702975168824, 6.029221499338746, 4.418395785614848, 7.897670064121485, 8.148643746972084, 10.056745558977127, 6.364654200151563, 1.4585048309527338, 0.7557301071938127, 0.07740155720966868, 0.8340599352959543, 7.829646589234471, 23.091987892985344, 26.807662211358547, 22.021005861461163, 20.42484261095524, 41.18754789233208, 46.19285210967064, 31.03642299771309, 10.411796607077122, 1.3969518151134253, 0.0771802339295391, 0.02330982137209503, 0.04600076579663437, 0.022192065334820654, 0.07361414754996076, 0.056068069534376264, 0.05586072089499794, 0.029906180207035504, 0.08872864549630322, 0.025232206498913, 0.04678848505136557, 0.07290475085028447, 0.01510278871137416, 0.050759962177835405, 0.009682922263891669, 0.040398014680249617, 0.015843580113141797, 0.04915887504466809, 0.08327825358719565, 0.053601174367940985, 0.016435852921858896, 0.01934756728587672, 0.04770244733663276, 0.04774476830789354, 0.09325901919510216, 0.043189592033741064, 0.07722444366663694, 0.02754947912762873, 0.015013066768005956, 0.005796611221740022, 0.057344782471773215, 0.14269798819441348, 0.23784786608302966, 0.11620632925769314, 0.09338294301414862, 0.1870486739790067, 0.08775649141171016, 0.10956041165627539, 0.17627157649258152, 0.16308494814438745, 0.10465266328537837, 0.133220539719332, 0.07352814747719094, 0.12834467401262373, 0.17042012797901407, 0.1543655144632794, 0.2103598293615505, 0.31749211193528026, 0.17099103250075132, 0.08590361583628692, 0.16025545075535774, 0.15734168991912156, 0.0980642695503775, 0.14449873531702906, 0.14882278454024345, 0.2014263899764046, 0.11774489787057973, 0.20307554601458833, 0.24821807368425652, 0.09312648646300659, 0.2145623296382837, 0.1845611582393758, 0.16394260368542746, 0.1350618971628137, 0.13844536326359957, 0.2980216301511973, 0.13587388093583286, 0.26942531461827457, 1.9691556296311319, 11.044958531856537, 29.439070411026478, 39.72812220454216, 39.273803383111954, 22.844640165567398, 22.589664347469807, 23.217951133847237, 30.49723193049431, 14.03843505308032, 4.2801653780043125, 1.4794387388974428, 0.525632860371843, 4.996630232781172, 11.704512890428305, 14.766932912170887, 8.71233019977808, 15.606586206704378, 24.013539142906666, 7.470213426277041, 11.945203375071287, 10.447641983628273, 6.828131005167961, 7.892642458900809, 3.7026148941367865, 6.027816524729133, 9.960142392665148, 18.647845163941383, 28.213603869080544, 39.155671522021294, 49.09460820257664, 56.96907766163349, 58.20863574743271, 57.92162574827671, 58.36273267865181, 55.47187440097332, 55.62410183250904, 52.4478180706501, 55.55399939417839, 62.357188537716866, 57.02735133469105, 56.646946147084236, 51.782112792134285, 52.05416299402714, 50.82775600254536, 52.410948649048805, 52.74147391319275, 54.51764300465584, 54.11228835582733, 56.50634989142418, 56.110027357935905, 54.04225431382656, 49.44365747272968, 44.96600814163685, 56.87199667096138, 56.70952118933201, 52.191293835639954, 49.8569080978632, 53.68059732019901, 56.76720969378948, 55.58099314570427, 57.630055993795395, 55.85811987519264, 53.65497529506683, 57.90770709514618, 53.833949491381645, 55.300837978720665, 55.05353584885597, 55.0614470243454, 50.875869020819664, 54.55710008740425, 52.72620253264904, 52.87125214934349, 53.087247759103775, 52.55171589553356, 51.14760763943195, 52.49042898416519, 51.1491883546114, 47.906624749302864, 43.84497709572315, 42.855669781565666, 32.808594703674316, 26.316044591367245, 17.10194181650877, 7.7982540987432, 3.104608920402825, 2.178438068367541, 4.132636869326234, 8.778605293482542, 7.065463894978166, 10.852324068546295, 13.641456104815006, 13.915394805371761, 15.798791293054819, 4.550508996471763, 5.786523297429085, 1.0000039776787162, 1.4533963613212109, 9.552075639367104, 24.42733123898506, 26.986410319805145, 25.719493702054024, 26.565326415002346, 43.99827226996422, 46.74872808158398, 37.027534916996956, 11.33833508938551, 1.5217115893028677, 0.21655468444805592, 0.21704944461816922, 0.10090569325257093, 0.11434425105107948, 0.22621893149334937, 0.1406434562522918, 0.18958600267069414, 0.1507829301408492, 0.19669962173793465, 0.1364228327292949, 0.21599060768494383, 0.11592193084652536, 0.2134760035551153, 0.22396413842216134, 0.08170443295966834, 0.17367285734508187, 0.08055267913732678, 0.17948532826267183, 0.22938589827390388, 0.11880751233547926, 0.09899560551275499, 0.17431382060749456, 0.11246626861975528, 0.12913810409372672, 0.20766546222148463, 0.08543381409253925, 0.16714652942027897, 0.10360215324908495, 0.06711781723424792, 0.11946121827349998, 0.1188172418915201], [0.034164901881013066, 0.03294519330665935, 0.0529560476570623, 0.029643239140568767, 0.025491082451480906, 0.0555423618061468, 0.0481025168846827, 0.017941436781256925, 0.007867451859056018, 0.07835204058210365, 0.04113673363463022, 0.04145124097703956, 0.010536600821069442, 0.02944938460132107, 0.08980585800600238, 0.032010536233428866, 0.06474058463936672, 0.05269406952720601, 0.007984964449860854, 0.0551104800979374, 0.09039694152306765, 0.031129287817748263, 0.02405964656645665, 0.013841097770637134, 0.02018530543864472, 0.1459697462269105, 0.019052429997827858, 0.010581047117739217, 0.04434049238625448, 0.007241343610076001, 0.04310651602281723, 0.030051598478166852, 0.058013899106299505, 0.044478665440692566, 0.0178614796459442, 0.058529906964395195, 0.02649570735229645, 0.1751040742965415, 2.3841139068827033, 12.664404083043337, 23.363933600485325, 32.73301675915718, 23.197517730295658, 16.798615492880344, 20.033725798130035, 16.808753348886967, 33.34791496396065, 18.169059455394745, 4.065562393516302, 0.5996943300124258, 0.30937634117435664, 0.7994236657395959, 2.3509818222373724, 2.650232627056539, 7.579354019835591, 14.372158795595169, 3.524698941037059, 2.7587063563987613, 3.082059030421078, 3.372900648973882, 3.852989450097084, 0.36372912931255996, 0.938741349382326, 2.0495653711259365, 6.2473853677511215, 14.527216125279665, 21.58054679632187, 30.311355404555798, 41.758927032351494, 48.16929705440998, 54.344585090875626, 54.614891186356544, 54.06843490898609, 55.768193900585175, 55.42138271033764, 55.41350573301315, 56.85618191957474, 53.66092197597027, 52.94170416891575, 50.12953206896782, 47.63925589621067, 48.418556079268456, 48.51366877555847, 49.51443247497082, 51.648211777210236, 51.41822151839733, 56.349308118224144, 52.74616666138172, 52.24509134888649, 52.16367691755295, 39.16983336210251, 53.27873848378658, 53.84319819509983, 50.863496884703636, 51.37402608990669, 49.758755564689636, 50.73831260204315, 50.375952646136284, 51.10529311001301, 50.648857802152634, 52.49802477657795, 52.15067021548748, 53.41173894703388, 52.56378024816513, 52.25565478205681, 51.958263739943504, 51.228516697883606, 49.867368936538696, 47.940788716077805, 48.53880062699318, 48.31287235021591, 50.65925404429436, 50.90511605143547, 48.29171508550644, 46.08986243605614, 36.64997957646847, 29.36156027019024, 23.525130450725555, 19.12410020828247, 9.907983541488647, 6.171826422214508, 0.735063609899953, 0.8356829825788736, 1.7214483465068042, 1.7564336629584432, 4.804830299690366, 2.9118155781179667, 5.654706945642829, 4.717794544994831, 10.848320983350277, 5.301854554563761, 1.493396102450788, 0.1262704751570709, 1.0694758873432875, 6.329821469262242, 16.73063714057207, 27.631553001701832, 21.11567784100771, 18.934368789196014, 15.972593016922474, 22.99073662608862, 24.724275805056095, 14.601653181016445, 3.2116753002628684, 0.2077346303849481, 0.049239954678341746, 0.03525069732859265, 0.03585527309041936, 0.008162751491909148, 0.09006488238810562, 0.08396782010095194, 0.013651419667439768, 0.020038558723172173, 0.04794351916643791, 0.03048291244340362, 0.05687190823664423, 0.010328111129638273, 0.02323891101696063, 0.021616155027004424, 0.07463099376764148, 0.044145467109046876, 0.026178108964813873, 0.008126803713821573, 0.047103812466957606, 0.05363560630939901, 0.1048086627270095, 0.06351981108309701, 0.05518813100934494, 0.006257288723645615, 0.05837412645632867, 0.026390507919131778, 0.03564608392480295, 0.05642114258080255, 0.050541796736069955, 0.024738808169786353, 0.05638792776153423, 0.03186701229424216, 0.03638281021267176, 0.02250886962428922, 0.03341644965985324, 0.07345942460233346, 0.04409708650200628, 0.04992916125047486, 0.07445279668900184, 0.03615595793235116, 0.009779598130990053, 0.04290708609914873, 0.041549156230757944, 0.04512724684900604, 0.01786666725820396, 0.09802588567254134, 0.022027328959666193, 0.07507148809963837, 0.027992671166430227, 0.045808059730916284, 0.011270939248788636, 0.024537931058148388, 0.07851794027374126, 0.0234342980911606, 0.06508435486466624, 0.0195999865536578, 0.09854695497779176, 0.026979621034115553, 0.039477165264543146, 0.012729066475003492, 0.02893330809456529, 0.040633531534695067, 0.09107124948059209, 0.02645032131113112, 0.053251556018949486, 0.04492079249757808, 0.056921201685327105, 0.02402698650257662, 0.3040319279534742, 4.125763513147831, 18.914438858628273, 29.19696070253849, 36.05191066861153, 26.473966017365456, 16.731294505298138, 18.934910260140896, 24.501142278313637, 34.17665049433708, 17.369086481630802, 4.036053651943803, 0.32913970411755145, 0.010817261591000715, 0.7049999793525785, 1.800374505110085, 2.358423722907901, 7.582560097798705, 10.150962453335524, 8.196037653833628, 5.400993609800935, 4.726072400808334, 5.183524629101157, 5.211912905797362, 2.5904817832633853, 1.4674084656871855, 3.318165773525834, 9.619925748556852, 17.24064577370882, 25.827930383384228, 34.94145065546036, 45.22746831178665, 50.68657077848911, 54.25440452992916, 54.55740787088871, 54.13997367024422, 54.663084000349045, 53.46600383520126, 56.06370784342289, 56.83070808649063, 56.50110237300396, 54.44646902382374, 50.824788361787796, 48.693699315190315, 49.63639833033085, 50.68963721394539, 51.39647148549557, 53.70233975350857, 53.17908123135567, 57.568202912807465, 54.3105199187994, 51.82831451296806, 51.325088515877724, 41.3107942789793, 55.151851773262024, 54.19800415635109, 53.067747205495834, 52.07260720431805, 51.082361340522766, 52.156221717596054, 52.68650986254215, 52.52574808895588, 52.70059570670128, 54.898086190223694, 53.104810416698456, 53.77150744199753, 53.312533870339394, 53.139582350850105, 52.62127496302128, 51.50959901511669, 52.02270068228245, 50.391938388347626, 50.761612951755524, 49.982609152793884, 52.877859994769096, 52.11967147886753, 48.80964249372482, 48.52822579443455, 40.208826810121536, 32.95048289000988, 27.350385189056396, 21.77473157644272, 11.119268294423819, 7.484445562586188, 2.186249024234712, 1.2974478607065976, 3.1506873853504658, 2.3050102265551686, 5.136295538395643, 5.78772165812552, 6.232313001528382, 7.267638696357608, 8.302546888589859, 2.0113873947411776, 0.7694172102492303, 0.29669992451090366, 0.9299272473435849, 6.527482587844133, 17.69615203142166, 33.257350623607635, 21.228326596319675, 21.083377674221992, 19.110367745161057, 25.664550550282, 30.887229703366756, 19.51451025903225, 4.0611859783530235, 0.21312251861672848, 0.03543611179338768, 0.04466252510610502, 0.05134127160999924, 0.028959270275663584, 0.05149610587977804, 0.05521742357814219, 0.06143171922303736, 0.014004924087203108, 0.033695886813802645, 0.02532639802666381, 0.11126749232062139, 0.09958359427400865, 0.049630038629402407, 0.020110205659875646, 0.019227934935770463, 0.028954103072464932, 0.051003798507736064, 0.03558469717972912, 0.04819014226086438, 0.06392804425559007, 0.07678975292947143, 0.03914462373359129, 0.019671921072585974, 0.012713857086055214, 0.01875581769127166, 0.06338508901535533, 0.05695080224541016, 0.08221860029152595, 0.03431856726820115, 0.0239257148859906, 0.03233713316149078, 0.1867907479754649, 0.19819801789708436, 0.10280790680553764, 0.15019241807749495, 0.20943975920090452, 0.15913175011519343, 0.1680773458792828, 0.16885876801097766, 0.08939740218920633, 0.1495240250369534, 0.2517567080212757, 0.16161503561306745, 0.15297854435630143, 0.12851588748162612, 0.20459847757592797, 0.10036529842182063, 0.18341369403060526, 0.18705535330809653, 0.17622732964809984, 0.12817659240681678, 0.16112820158014074, 0.10106065368745476, 0.07698857429204509, 0.10546138903009705, 0.14549312414601445, 0.23588913056300953, 0.1302771523478441, 0.14240672491723672, 0.1276232025702484, 0.2333641066798009, 0.11398966773413122, 0.2660866593942046, 0.17891534400405362, 0.10113520984305069, 0.15398258110508323, 0.10892142250668257, 0.10251182698993944, 0.33977794577367604, 4.048739271238446, 18.451602794229984, 34.447370767593384, 44.949593022465706, 37.14262314140797, 25.596425905823708, 28.962726071476936, 26.681774966418743, 41.40271134674549, 22.076650075614452, 4.965654769912362, 1.2143036909401417, 0.9833535680081695, 3.223354211077094, 6.401325082406402, 10.615935903042555, 15.770036336034536, 28.824236802756786, 14.754127599298954, 7.919875597581267, 7.7691091876477, 7.830878673121333, 7.991660870611668, 2.1931200055405498, 2.5309347035363317, 3.000246570445597, 9.060496017336845, 17.347230054438114, 25.82427877932787, 34.694543704390526, 46.92503102123737, 51.713743060827255, 57.494756653904915, 55.652824491262436, 55.491036772727966, 55.31165599822998, 54.881538078188896, 55.14026999473572, 59.657573997974396, 58.077766969799995, 56.94234989583492, 54.68183219432831, 51.38070993125439, 52.05391600728035, 51.46900199353695, 52.631587609648705, 56.83039270341396, 54.898884147405624, 60.299469754099846, 55.40892317891121, 51.73200488090515, 51.05860501527786, 45.0559189170599, 55.007421523332596, 58.18920738995075, 54.89165313541889, 54.81116585433483, 54.447597563266754, 54.488270580768585, 53.326057344675064, 54.44528728723526, 53.764576613903046, 56.98819823563099, 55.36989167332649, 56.4140984416008, 53.93035031855106, 54.98244546353817, 54.586962684988976, 54.39235232770443, 54.160484969615936, 52.27473355829716, 53.67585517466068, 53.90994541347027, 53.82391422986984, 51.77375704050064, 47.869314551353455, 47.88673281669617, 39.01364654302597, 30.11997677385807, 25.835028402507305, 20.62875296920538, 12.154275756329298, 7.478758217766881, 1.6592371347360313, 1.9854525988921523, 4.1834482178092, 4.948210855945945, 9.685803763568401, 10.102349761873484, 12.508420553058386, 11.176849454641342, 17.905750684440136, 10.531867314130068, 3.2087043346837163, 0.5285905266646296, 1.493889125995338, 7.157371463254094, 20.967305302619934, 37.225458696484566, 27.53195084631443, 29.064818993210793, 26.128302365541458, 31.35946076363325, 34.64262709021568, 21.005875132977962, 4.878413826227188, 0.30666123842820525, 0.13906590262195095, 0.19495642074616626, 0.18745871057035401, 0.18684882845263928, 0.12820599629776552, 0.1651534324628301, 0.1794178967247717, 0.10499040727154352, 0.10781814577057958, 0.10971037743729539, 0.19281525048427284, 0.24301064608152956, 0.10034413237008266, 0.1319548810715787, 0.2189556063967757, 0.0849053158890456, 0.1631548732984811, 0.24159449472790584, 0.17323092324659228, 0.21130281704245135, 0.17152852553408593, 0.1541907386854291, 0.16851124993991107, 0.19746358855627477, 0.10046548835816793, 0.11992138694040477, 0.21215334796579555, 0.14183199091348797, 0.13447457633446902, 0.17900996783282608, 0.12883407587651163], [0.011160468711750582, 0.018326815516047645, 0.07582300910144113, 0.009029182001540903, 0.05609931024082471, 0.050339272056589834, 0.051859969753422774, 0.0727303906751331, 0.008408198282268131, 0.03197158461262006, 0.0385924732836429, 0.04870878474321216, 0.01950414003658807, 0.0722886792209465, 0.04154271438892465, 0.039457609673263505, 0.0172969167761039, 0.10478262818651274, 0.07634334368049167, 0.04524470285105053, 0.02388552758930018, 0.055782301860745065, 0.02338237001822563, 0.01794603253074456, 0.03376011227373965, 0.01803443159587914, 0.012058455340593355, 0.037393281381810084, 0.023929073104227427, 0.01813269565900555, 0.011612700109253637, 0.08165444189216942, 0.052414168530958705, 0.05318294817698188, 0.016846982325660065, 0.08058842839091085, 0.11107590689789504, 0.040617293343530037, 0.31866749573964626, 3.4847265109419823, 16.619821786880493, 30.14902051538229, 32.10191622376442, 24.654959924519062, 25.52355531603098, 43.78212086856365, 35.90399220585823, 11.527532637119293, 8.960571829229593, 3.674143496900797, 0.6629594508558512, 0.3504836931824684, 1.5517257037572563, 2.0459270663559437, 6.128608966246247, 6.957275150343776, 3.662277921102941, 4.414237858727574, 3.1722056306898594, 2.7131745871156454, 5.105415545403957, 2.784447600133717, 0.4217478894861415, 0.6123981170821935, 1.7855219333432615, 4.596819961443543, 10.118150264024734, 17.44607225060463, 26.40510231256485, 34.277899861335754, 43.367711305618286, 47.80627213418484, 52.23027214407921, 54.14343908429146, 55.35108648240566, 58.360266610980034, 57.924802377820015, 55.63355952501297, 53.250509798526764, 50.91892071068287, 50.237446278333664, 51.86959929764271, 48.71182434260845, 52.1197322756052, 52.509469762444496, 53.98925095796585, 55.89484490454197, 53.6832457780838, 52.74753458797932, 53.037041053175926, 37.732518687844276, 51.99154995381832, 56.09481677412987, 51.83933012187481, 51.72353893518448, 51.15225858986378, 49.04105007648468, 50.064517557621, 48.53820785880089, 46.04691334068775, 47.880375757813454, 51.01458817720413, 51.6881438344717, 51.988544315099716, 52.408547177910805, 51.686825305223465, 52.171477898955345, 51.548995301127434, 49.521530494093895, 51.07980027794838, 48.97483102977276, 50.937380120158195, 45.67911587655544, 39.21482294797897, 32.36780695617199, 24.83276568353176, 16.407912857830524, 12.102987058460712, 7.752112224698067, 1.4732248848304152, 0.2892436261754483, 0.35330780257936567, 1.3691430073231459, 3.057471737265587, 2.0261415280401707, 4.750519338995218, 3.7289565056562424, 5.716472156345844, 6.311979526653886, 8.613624796271324, 1.864225803874433, 0.6298353220336139, 0.6566022732295096, 4.205955835059285, 8.91710976138711, 24.602591134607792, 20.325892120599747, 12.95737311244011, 11.182964276522398, 20.023504346609116, 23.761641159653664, 13.351263776421547, 4.986849557608366, 0.11568848087335937, 0.030113846114545595, 0.052243537647882476, 0.0035241436717114993, 0.09234179146005772, 0.047972548272809945, 0.04865106049692258, 0.030021532220416702, 0.04329561154008843, 0.015053784700285178, 0.049158785986946896, 0.022831553578726016, 0.05323439014318865, 0.11019758996553719, 0.017783578259695787, 0.05476530721352901, 0.08603137655882165, 0.06041088025085628, 0.11727422781405039, 0.06709256194881164, 0.04164235513599124, 0.012326619271334494, 0.05363684569601901, 0.05803527295938693, 0.052131762786302716, 0.02933184881840134, 0.029231328626337927, 0.021459682466229424, 0.09409523408976384, 0.03591143882658798, 0.04109050154511351, 0.04260087225702591, 0.031400976949953474, 0.014927607535355492, 0.02210362730693305, 0.08003612208995037, 0.05582356156082824, 0.0030875024776833015, 0.051072309870505705, 0.06677461104118265, 0.0316182852111524, 0.042512604923103936, 0.05043421500886325, 0.053658646284020506, 0.05752984812716022, 0.03925350421923213, 0.04981600599421654, 0.05980257148621604, 0.04122186168387998, 0.02800814494548831, 0.06395437565515749, 0.029633502163051162, 0.022044864053896163, 0.020582970428222325, 0.03880751428368967, 0.05240812373813242, 0.0724750770314131, 0.033197723896591924, 0.015594012547808234, 0.015101776607480133, 0.01515713154731202, 0.03542806691257283, 0.050457507313694805, 0.03509187401505187, 0.07410310412524268, 0.02913293839810649, 0.02969398905406706, 0.03869037740514614, 0.02017387636442436, 0.04779301532835234, 0.05340538467862643, 0.5222104315180331, 6.013892171904445, 21.87751416116953, 35.63816227018833, 37.589638754725456, 30.75573205947876, 27.04098679125309, 37.496855333447456, 46.67913481593132, 21.478689461946487, 14.442863501608372, 4.724897788837552, 0.8164779818616807, 0.15807840507477522, 0.5239990667905658, 1.6102286707609892, 3.0190987838432193, 6.453942283987999, 6.931536756455898, 5.910921972244978, 7.768580541014671, 6.973229069262743, 3.9834689861163497, 2.7863045129925013, 2.525309817865491, 1.4134569419547915, 3.134349687024951, 6.8609811924397945, 11.345319114625454, 21.078536733984947, 29.66657180339098, 37.66977645456791, 47.02319115400314, 49.33396115899086, 51.93552576005459, 54.03065733611584, 56.731795594096184, 57.48184494674206, 60.52463427186012, 57.95501455664635, 56.511620208621025, 53.0100928992033, 52.89022833108902, 53.32877039909363, 51.68705329298973, 55.51812931895256, 54.697445556521416, 55.82696154713631, 58.23506332933903, 55.05520015954971, 51.68513439595699, 53.24206665158272, 40.47461874783039, 53.8779853284359, 57.138749957084656, 53.240846917033195, 53.17277356982231, 52.88967356085777, 50.63306584954262, 51.18105724453926, 50.50893411040306, 49.04651798307896, 49.99123468995094, 54.60732959210873, 53.24973464012146, 52.42317259311676, 52.10148945450783, 53.368995040655136, 53.54055963456631, 52.3628356307745, 51.15841045975685, 52.83443212509155, 51.599300801754, 52.00389929115772, 47.08363451063633, 40.746851339936256, 34.89506654441357, 27.821024134755135, 18.511413484811783, 14.949238579720259, 10.675579402595758, 3.258311147801578, 1.3061116333119571, 1.4765861607156694, 3.257119911722839, 3.9241460943594575, 3.6210935935378075, 5.999058717861772, 6.045223865658045, 8.261095862835646, 5.395110575482249, 5.949861332774162, 1.3028829940594733, 0.17859310348285362, 0.698257478652522, 5.278332391753793, 10.505366586148739, 28.63712914288044, 24.89142883569002, 17.145937755703926, 16.8246041983366, 23.005610927939415, 28.74713324010372, 17.33711689710617, 6.678033834323287, 0.4167003947077319, 0.055315606005024165, 0.04797726833203342, 0.036594719349523075, 0.06738848591339774, 0.029854472923034336, 0.02717867617320735, 0.015891398543317337, 0.07553084782557562, 0.038260595974861644, 0.024059514835244045, 0.02022804386797361, 0.05870586646778975, 0.03658682660898194, 0.031136048783082515, 0.029358285974012688, 0.008174814174708445, 0.07147449869080447, 0.03816695178102236, 0.010073015491798287, 0.009005731062643463, 0.018004908961302135, 0.062361956806853414, 0.034138474002247676, 0.06894640973769128, 0.019823655020445585, 0.03973267928813584, 0.04028198360174429, 0.07939015675219707, 0.032986248916131444, 0.024470108037348837, 0.058731856479425915, 0.03878883442666847, 0.13276699843117967, 0.10212096007307991, 0.14611925929784775, 0.1440700114471838, 0.15339184639742598, 0.18881041381973773, 0.13054600276518613, 0.15484440751606598, 0.06900336957187392, 0.13014053780352697, 0.14860879367915913, 0.1705761274206452, 0.10943628745735623, 0.18426719354465604, 0.16315417567966506, 0.11614177725277841, 0.1213569677202031, 0.24223768443334848, 0.13057521369773895, 0.13479136949172243, 0.1740822705323808, 0.08527685728040524, 0.12018785506370477, 0.1286340967635624, 0.1308348317979835, 0.11606893545831554, 0.1622474196483381, 0.10302523733116686, 0.10642585446476005, 0.15683803881984204, 0.11348954925779253, 0.16577866219449788, 0.11605377338128164, 0.10463735277880915, 0.10914648621110246, 0.14933336729882285, 0.2417325193528086, 0.09878542186925188, 0.5518426070921123, 5.858946461230516, 22.343574352562428, 41.77172854542732, 43.87335017323494, 39.14038874208927, 35.33389359712601, 53.20960499346256, 48.75139541924, 19.209204241633415, 14.318645317107439, 5.007475800812244, 1.1553630349226296, 1.0387945524416864, 2.9589444492012262, 6.245968993753195, 15.878907144069672, 16.526517793536186, 10.362182669341564, 11.30519611760974, 10.953273251652718, 10.188569985330105, 11.266788728535175, 7.06917392089963, 2.3915282590314746, 1.3106645015068352, 3.401678167283535, 6.740614576265216, 11.695266086608171, 20.109180249273777, 28.770386092364788, 37.733700424432755, 46.80353634059429, 49.56764481961727, 52.36959166824818, 54.613192677497864, 56.519200801849365, 58.257451727986336, 62.810884192585945, 60.86957596242428, 58.65104980766773, 55.380595698952675, 55.18521398305893, 56.026941016316414, 52.46163412928581, 57.51899175345898, 57.73437179625034, 57.600531578063965, 59.118322134017944, 55.95298558473587, 52.43139535188675, 52.77802795171738, 42.917925640940666, 54.187881499528885, 59.01639640331268, 54.79402117431164, 56.06833219528198, 54.31166745722294, 51.615358740091324, 54.551502987742424, 53.683127984404564, 50.13258330523968, 52.53495119512081, 56.550226137042046, 54.343479350209236, 53.99800568819046, 54.48898494243622, 54.29116755723953, 54.37612719833851, 55.163737535476685, 52.511251866817474, 54.59517024457455, 51.17945373058319, 52.48152606189251, 47.42906257510185, 40.291559770703316, 33.306656777858734, 27.175611667335033, 18.56913808733225, 14.371909908950329, 10.892313122749329, 2.8730564704164863, 1.0163929732516408, 1.2694782740436494, 3.61288508400321, 6.472372245043516, 5.587296187877655, 11.280434746295214, 8.289040513336658, 13.077913094311953, 14.79383546859026, 16.783830486238003, 4.223903696984053, 0.9851641114801168, 0.9855094773229212, 5.970204966142774, 13.34225445985794, 32.38578759133816, 29.125062860548496, 20.217373743653297, 20.557643584907055, 29.88399613648653, 34.140765219926834, 18.286606147885323, 7.4333573039621115, 0.33034141932148486, 0.24168855452444404, 0.24307874555233866, 0.10958435334032401, 0.17965376609936357, 0.18745192734058946, 0.11227500974200666, 0.1689151267055422, 0.1360456584370695, 0.13647055282490328, 0.09229291361407377, 0.0662784704763908, 0.23576575593324378, 0.16909730911720544, 0.10781416785903275, 0.13221961999079213, 0.19061770668486133, 0.22562749916687608, 0.14738720376044512, 0.13334305345779285, 0.11625156315858476, 0.07891653294791467, 0.10179281947785057, 0.12468321423511952, 0.1411221266607754, 0.09015156523673795, 0.1394394107046537, 0.129715109069366, 0.16100558394100517, 0.1980659007676877, 0.11796634731581435, 0.13172230683267117, 0.18192021088907495], [0.03311292239231989, 0.01549109985717223, 0.017666938620095607, 0.021796918081236072, 0.010206143797404366, 0.037556101160589606, 0.03779637518164236, 0.02544463142839959, 0.09800417043152265, 0.08541741262888536, 0.044763857949874364, 0.023227303827297874, 0.07045387494144961, 0.032132337510120124, 0.04028545314213261, 0.04612718323187437, 0.03255905015976168, 0.02107547075866023, 0.02580806856713025, 0.02831580968631897, 0.044794029963668436, 0.05450523640320171, 0.019981400364486035, 0.03103207389358431, 0.05836820411786903, 0.02288505871547386, 0.09326462241006084, 0.08222430740715936, 0.020679616609413642, 0.05130479134095367, 0.059369127557147294, 0.0725700422481168, 0.01480369113778579, 0.027762421705119777, 0.0553656824195059, 0.06280168672674336, 0.04144791615544818, 0.05299979726260062, 0.05880563709069975, 0.5288424412719905, 6.876497184857726, 21.647875383496284, 30.150738023221493, 28.132288232445717, 27.971872240304947, 28.325690254569054, 16.91574990749359, 17.524872422218323, 21.83290835469961, 10.92808535322547, 3.788083945401013, 0.14399477251572534, 0.3795891220215708, 0.9845367295201868, 2.2250171564519405, 3.2891638297587633, 4.439862733706832, 4.71924084238708, 3.808284611441195, 5.134132029488683, 1.674536420032382, 1.6396189061924815, 1.1584807676263154, 0.7326763879973441, 1.097990507259965, 1.1666962830349803, 1.6222889861091971, 6.002272395417094, 11.461309790611267, 19.112850911915302, 28.233531899750233, 36.597420796751976, 42.17723898589611, 51.38544447720051, 52.8751203417778, 54.91200104355812, 57.719727382063866, 54.37721014022827, 54.38264764845371, 54.29420739412308, 50.88376499712467, 53.19357745349407, 53.68323057889938, 52.26064771413803, 52.75964833796024, 55.59478260576725, 57.343353778123856, 52.81311146914959, 52.04211004078388, 52.579519003629684, 37.62821048498154, 50.4756098985672, 56.870765537023544, 55.98229721188545, 54.3437035381794, 51.37942560017109, 51.21508441865444, 52.183842435479164, 49.1257019340992, 48.58994588255882, 48.029251769185066, 47.77360528707504, 52.43148274719715, 54.37301516532898, 55.08514255285263, 51.796202436089516, 51.88372693955898, 50.59115409851074, 51.14896036684513, 51.31658837199211, 49.375416934490204, 42.90482394397259, 37.52591997385025, 26.0519340634346, 18.92027534544468, 12.325314078480005, 7.540531978011131, 4.603832010179758, 2.369477804750204, 0.6940693908836693, 1.6923793125897646, 1.239625175949186, 2.124691139906645, 2.3857915168628097, 1.3651356473565102, 2.498044380918145, 5.783682474866509, 5.5042364448308945, 4.446658669039607, 3.6007406981661916, 0.604295467492193, 0.5697006988339126, 4.580928264185786, 12.630300913006067, 21.458537243306637, 19.702807255089283, 16.769286766648293, 14.777000471949577, 25.208282433450222, 24.04863975942135, 13.472045995295048, 4.867275198921561, 0.533523018239066, 0.0945165661687497, 0.04865107162913773, 0.02985714094393188, 0.01517078242613934, 0.035415687889326364, 0.025705772786750458, 0.0982825574465096, 0.02254302140499931, 0.08498695213347673, 0.043558227916946635, 0.09677576017566025, 0.018222579019493423, 0.04801575239980593, 0.03683704911964014, 0.029653117126144934, 0.05811895382066723, 0.013971261196275009, 0.03179407402058132, 0.06950880924705416, 0.04521461989497766, 0.05140699620824307, 0.04083640502358321, 0.028919966134708375, 0.06622076849453151, 0.04172033259237651, 0.06428066088119522, 0.036901556595694274, 0.08087116439128295, 0.013910757606936386, 0.016443003514723387, 0.008571393773308955, 0.018851946224458516, 0.03182606800692156, 0.02795852309645852, 0.07527896290412173, 0.03470931915217079, 0.05298794145346619, 0.03389825935300905, 0.03773807577090338, 0.057334206867381, 0.07140140456613153, 0.006066008972993586, 0.04581606379360892, 0.025688564237498213, 0.06972130839130841, 0.07224188680993393, 0.016874454777280334, 0.034087050589732826, 0.12375363716273569, 0.040430260996799916, 0.036836525905528106, 0.027476696704979986, 0.05400697700679302, 0.02786761186143849, 0.03499120910419151, 0.06553513536346145, 0.05862829719262663, 0.050113544129999354, 0.06664755535894074, 0.05831916299939621, 0.02809315425110981, 0.043972940038656816, 0.014669795637018979, 0.09983775016735308, 0.012767700827680528, 0.06514162640087306, 0.07781703374348581, 0.12793898640666157, 0.04002254732768051, 0.08800440584309399, 0.05880464261281304, 0.009658077015046729, 0.884856084594503, 9.943020511418581, 26.335398852825165, 35.593659058213234, 32.639044001698494, 34.05201718211174, 41.00323498249054, 21.597214601933956, 16.384667605161667, 22.823051624000072, 13.61531350761652, 3.9522954588755965, 0.5326160544063896, 0.10733131173765287, 0.6631506280973554, 2.1034374553710222, 3.7693393137305975, 6.405540481209755, 5.574630042538047, 5.830149706453085, 6.100481925532222, 4.4289573188871145, 5.358313350006938, 3.2881143735721707, 1.913262172602117, 2.452529235742986, 2.2422881796956062, 2.8359543113037944, 7.931112069636583, 13.807139564305544, 23.143078051507473, 31.001966446638107, 39.54985477030277, 45.06644815206528, 52.555492892861366, 53.61915081739426, 55.82307815551758, 59.562723487615585, 57.966212555766106, 57.03435815870762, 56.213058829307556, 53.88399660587311, 55.13806611299515, 54.02769349515438, 55.237776562571526, 54.18696954846382, 56.53083577752113, 58.5915943980217, 52.26669318974018, 51.43204517662525, 53.302133828401566, 40.384506583213806, 52.20785714685917, 55.2250624448061, 56.21398977935314, 55.03903962671757, 53.853723630309105, 52.65521474182606, 54.198129549622536, 51.20215751230717, 50.63392460346222, 50.125576481223106, 50.62061011791229, 52.23014675080776, 53.9567930996418, 56.63666009902954, 52.17619724571705, 52.03345790505409, 52.18128517270088, 51.70577108860016, 53.09289425611496, 49.4741166383028, 46.86628997325897, 39.177201166749, 28.929540552198887, 22.288218922913074, 17.301790192723274, 10.480008646845818, 7.790865395218134, 3.1360707571730018, 1.3995716557838023, 2.809958243742585, 4.6188801527023315, 4.16713141836226, 4.274740219116211, 4.339551441371441, 6.578341433778405, 6.490755658596754, 5.754306726157665, 2.237190753221512, 1.801819377578795, 0.48217812494840473, 0.5539072619285434, 4.474117895588279, 14.111878462135792, 24.949846900999546, 26.250950284302235, 18.53452954441309, 14.566608611494303, 25.449009016156197, 27.72877648472786, 17.878787331283092, 7.459854707121849, 1.0168799408711493, 0.028347540210234, 0.043743482819991186, 0.03367833131051157, 0.005488325859914767, 0.014264788951550145, 0.06546831238665618, 0.021784097480122, 0.07829395268345252, 0.0482158094382612, 0.02365594235016033, 0.05892225817660801, 0.02849783624697011, 0.030454540137725417, 0.03655821310530882, 0.020038297116116155, 0.027879196786670946, 0.023769272011122666, 0.04762068121635821, 0.023909767987788655, 0.05416236417659093, 0.08319497719639912, 0.03544518825947307, 0.04555868697934784, 0.028448346129152924, 0.03119258559308946, 0.07989541089045815, 0.006889432488605962, 0.03989395911048632, 0.006864885490358574, 0.011777273211919237, 0.05049753875937313, 0.011978198563156184, 0.03133219470328186, 0.08137150551192462, 0.198295877489727, 0.09102040494326502, 0.1446631655562669, 0.22920390882063657, 0.11525191250257194, 0.20334267464932054, 0.11295921794953756, 0.19886569847585633, 0.1158260453667026, 0.17731874686433002, 0.14380328357219696, 0.2653504488989711, 0.09246050540241413, 0.12333073915215209, 0.22254259907640517, 0.1332092739176005, 0.10974137694574893, 0.1512057613581419, 0.13895360083552077, 0.09093109489185736, 0.15548194205621257, 0.12162026687292382, 0.17628839355893433, 0.19348208501469344, 0.1030289035406895, 0.22964092990150675, 0.1841359373065643, 0.10090860989294015, 0.10947082701022737, 0.19074274372542277, 0.08633175340946764, 0.25077306549064815, 0.20791777758859098, 0.34800940251443535, 0.115288329689065, 0.19506741635268554, 0.2836094191297889, 0.24967985227704048, 1.0273336549289525, 9.962376672774553, 29.906348437070847, 42.361874878406525, 40.35419940948486, 39.665642157197, 40.85743300616741, 27.76682574301958, 27.075994312763214, 31.24108761548996, 16.042524464428425, 5.175829092040658, 0.721717004198581, 1.00353006972, 2.3620299668982625, 7.072807000949979, 9.895025286823511, 13.092493861913681, 13.2006218098104, 9.035570304840803, 13.245945777744055, 5.58313968591392, 6.78281226195395, 5.252502802759409, 3.341585579328239, 3.1007609143853188, 2.6605319743975997, 2.373955389484763, 7.381808795034885, 13.840958699584007, 21.142095923423767, 29.69438251107931, 38.944912031292915, 45.26059113442898, 51.55881017446518, 54.064277932047844, 55.60810089111328, 61.8651719391346, 58.84502559900284, 59.40665066242218, 59.988137260079384, 55.20545929670334, 57.51785181462765, 56.33757434785366, 57.023293152451515, 57.26542755961418, 59.35076326131821, 59.31317947804928, 54.24309253692627, 51.599323600530624, 52.06966996192932, 45.13802871108055, 52.66049265861511, 57.13908813893795, 57.857967764139175, 57.22525231540203, 55.65277509391308, 55.55731661617756, 56.34752981364727, 53.41830499470234, 53.27933505177498, 52.94550396502018, 52.58135810494423, 55.78003026545048, 56.708350852131844, 57.82974287867546, 52.74360939860344, 52.37940274178982, 51.87281012535095, 52.13569901883602, 52.34866999089718, 50.511278584599495, 46.487416103482246, 38.62229414284229, 27.725833542644978, 21.04760069400072, 16.13020095974207, 9.486405663192272, 6.685339417308569, 5.05724648013711, 1.6427278518676758, 3.2361844601109624, 6.461188020184636, 6.81613314896822, 6.015868540853262, 5.425269082188606, 7.8495750948786736, 13.420429565012455, 13.915028125047684, 10.0867990963161, 6.99604969471693, 1.3662422192282975, 0.941215135389939, 5.522562861442566, 16.57081201672554, 27.449614964425564, 29.287245757877827, 25.453006401658058, 22.65230778604746, 35.69362409412861, 32.111894488334656, 18.818011432886124, 7.398178316652775, 0.9003441722597927, 0.16887264617253095, 0.14378823281731457, 0.1181340949551668, 0.1016962512221653, 0.11757732834666967, 0.09311061934567988, 0.18362620059633628, 0.11015714291715994, 0.09354672016343102, 0.11737742344848812, 0.231456178589724, 0.14606833312427625, 0.1528001468977891, 0.13678344228537753, 0.1666482217842713, 0.1490710032521747, 0.17212142731295899, 0.08713562550838105, 0.11446793738286942, 0.2639022219227627, 0.20314738590968773, 0.134162918839138, 0.10670540665159933, 0.16643151466269046, 0.1227046262647491, 0.14356305036926642, 0.1334603870054707, 0.19789379672147334, 0.10040293273050338, 0.13167344382964075, 0.16060593741713092, 0.05912506487220526, 0.10592975842882879], [0.09331608292995952, 0.05736367755162064, 0.06558859226061031, 0.03250030174967833, 0.04330951938754879, 0.020424603535502683, 0.03065338562009856, 0.032229974458459765, 0.08813426684355363, 0.050623273418750614, 0.07759314263239503, 0.05845924708410166, 0.02258378572150832, 0.040497955997125246, 0.025857892651401926, 0.0670543265005108, 0.05616327965981327, 0.08088594055152498, 0.027547647878236603, 0.033297505651717074, 0.0042563338138279505, 0.061801297633792274, 0.06989733839873224, 0.02762659569270909, 0.06313143778243102, 0.05031411325035151, 0.08010853343876079, 0.036451388368732296, 0.008884660801413702, 0.09087816491955891, 0.07767300514387898, 0.03031264706805814, 0.0769111979752779, 0.04749069034005515, 0.0350455454463372, 0.015312425948650343, 0.033672464633127674, 0.02826762018230511, 0.016875237743079197, 0.0845880329143256, 0.7251323678065091, 7.473328309133649, 24.800887294113636, 28.251731023192406, 26.66885755956173, 16.433614678680897, 18.711421452462673, 19.23715554177761, 22.178211025893688, 21.618949435651302, 11.891479007899761, 4.634608458727598, 1.3487756252288818, 0.7932752394117415, 0.22154043253976852, 2.775139999575913, 5.337354149669409, 2.837666356936097, 7.976893913000822, 4.476526966318488, 3.8254468655213714, 3.449390782043338, 4.499163776636124, 1.7389364331029356, 2.3989599477499723, 1.0703006805852056, 0.2695844310801476, 0.8810046350117773, 2.104247761890292, 6.987464055418968, 13.160011488944292, 21.246033646166325, 26.098920442163944, 34.648398980498314, 47.075844928622246, 54.9660911411047, 58.979173600673676, 58.10275822877884, 55.70729456841946, 55.50742909312248, 54.6843096613884, 55.17708241939545, 54.93937097489834, 57.254206761717796, 55.041661486029625, 56.64667636156082, 52.424650713801384, 53.25435899198055, 52.64342777431011, 53.75264525413513, 40.363470911979675, 49.0312048047781, 58.12464885413647, 52.73468367755413, 54.448764100670815, 54.26113776862621, 54.97935622930527, 52.930939346551895, 51.74801342189312, 49.49035696685314, 47.314893901348114, 50.879376232624054, 50.20425505936146, 53.12958508729935, 53.83814826607704, 53.8989982008934, 52.87234269082546, 51.998663172125816, 49.03348848223686, 48.57921905815601, 42.80711218714714, 34.95460934937, 25.048254020512104, 16.439717151224613, 11.046772934496403, 5.192465074360371, 2.437080927193165, 1.9878103723749518, 0.16580371710006148, 2.3010368272662163, 1.9398448336869478, 4.28503149189055, 4.972731890156865, 4.172201296314597, 3.9691812777891755, 5.326772192493081, 4.950166326016188, 5.549830673262477, 1.2102615390904248, 1.51454042410478, 1.1060837167315185, 3.0450340546667576, 10.57118285447359, 17.119103595614433, 13.030770923942327, 15.63402833417058, 13.620838411152363, 23.249882720410824, 23.9905883744359, 14.95423911139369, 3.4847614215686917, 0.17936526361154392, 0.017722239754220936, 0.03164492089126725, 0.05975799067527987, 0.03825813204457518, 0.07318999530980363, 0.059515902103157714, 0.0393629747122759, 0.049829624404083006, 0.05829643472679891, 0.029781998491671402, 0.04326423353631981, 0.056885934827732854, 0.06252463557757437, 0.049895438060048036, 0.06776804992114194, 0.02462743221258279, 0.042395252821734175, 0.06197946873726323, 0.06808730700868182, 0.01646052005526144, 0.026068096703966148, 0.02542172689572908, 0.010957558115478605, 0.06946212073671632, 0.026753744677989744, 0.05172269469767343, 0.08484661200782284, 0.0403372216533171, 0.04691535148594994, 0.08587749965954572, 0.02131442746758694, 0.06327286144369282, 0.042792865860974416, 0.04144949321926106, 0.08732691407203674, 0.038875216705491766, 0.046469509979942814, 0.0871374289272353, 0.06162658864923287, 0.05366771903936751, 0.04889816227660049, 0.02502976160030812, 0.0030414181219384773, 0.015586774752591737, 0.05505688961420674, 0.048853473854251206, 0.02488935468136333, 0.03040212410269305, 0.036384587656357326, 0.039859100434114225, 0.04941908315231558, 0.03261713434767444, 0.0029162463351894985, 0.023429279317497276, 0.03152874509396497, 0.07357877679169178, 0.03029652390978299, 0.028884207604278345, 0.014574056731362361, 0.028441625981940888, 0.03359231639478821, 0.07338428957154974, 0.01771169569110498, 0.031220920791383833, 0.05860713485162705, 0.013509051623259438, 0.04894505116681103, 0.01881608935946133, 0.05018030402425211, 0.013166287008061772, 0.041183184657711536, 0.04681954764237162, 0.05582172474532854, 0.039690187622909434, 1.411469173617661, 9.766253996640444, 29.69511017203331, 34.076237082481384, 33.063500225543976, 21.084926091134548, 20.803564488887787, 18.493862226605415, 25.70887517184019, 27.89342924952507, 16.348751932382584, 4.691065354272723, 1.7993151932023466, 0.47109812730923295, 0.43047219165600836, 1.425426893401891, 1.4506136043928564, 3.702205466106534, 6.700355261564255, 5.271088555455208, 3.91132605727762, 5.697680739685893, 4.783303029835224, 3.533567665144801, 3.306386643089354, 2.3277489189058542, 0.9050614410080016, 1.7534537916071713, 3.7848631432279944, 9.300522487610579, 15.253034178167582, 25.972178243100643, 28.264114558696747, 38.226773366332054, 48.52286048233509, 54.368227422237396, 59.59708884358406, 59.189154133200645, 56.15217089653015, 57.30353191494942, 56.20770111680031, 57.05396130681038, 56.10086224973202, 57.000775560736656, 57.714992836117744, 57.63231307268143, 53.80902662873268, 53.810170367360115, 52.60542221367359, 53.82146716117859, 42.56588213145733, 50.99291414022446, 56.47660508751869, 52.9010995477438, 53.95942635834217, 57.533362582325935, 56.83203421533108, 53.38909596204758, 53.00568513572216, 51.53329074382782, 48.60017493367195, 50.990296080708504, 52.3822145909071, 54.913840144872665, 53.43355357646942, 54.68984216451645, 52.490113601088524, 52.758740186691284, 50.20064525306225, 50.82226149737835, 45.82862265408039, 37.095467671751976, 27.000859044492245, 19.262293092906475, 13.51949404925108, 7.539886487647891, 4.772762870416045, 3.403106890618801, 2.610857952386141, 3.5233450261875987, 3.8316690316423774, 8.374889306724072, 4.1820308938622475, 7.05067508853972, 4.6325489692389965, 6.980603048577905, 5.735105881467462, 1.853872190695256, 1.4322548895142972, 0.4879563086433336, 0.9645943308714777, 4.039404597133398, 11.923940666019917, 21.40012677758932, 18.72611716389656, 18.400571532547474, 16.068744957447052, 22.65050668269396, 29.214175678789616, 19.910823293030262, 6.017296314239502, 0.6606880039907992, 0.047821309708524495, 0.02912590283813188, 0.03107587544946, 0.05352657739422284, 0.015476022199436557, 0.011774171034630854, 0.015327199325838592, 0.023729003078187816, 0.04136366012971848, 0.053135777270654216, 0.045188128933659755, 0.031871632163529284, 0.06416774311219342, 0.04059398619574495, 0.07726954398094676, 0.052237110649002716, 0.05703836082830094, 0.03698728578456212, 0.016029274738684762, 0.07563331615529023, 0.03417417130549438, 0.039012131819617935, 0.06385986314853653, 0.029675220139324665, 0.04527707533270586, 0.012548949089250527, 0.00944079009059351, 0.030901413229003083, 0.06633022785536014, 0.046588769400841556, 0.11202138077351265, 0.05728265728976112, 0.03618028924393002, 0.02421470904664602, 0.2777770289685577, 0.16412625554949045, 0.17386228311806917, 0.250768939149566, 0.19246777694206685, 0.14017666020663455, 0.1615655343630351, 0.11738002096535638, 0.07902473807916977, 0.11692485437379219, 0.12796165159670636, 0.16707773233065382, 0.10815599365741946, 0.07312905014259741, 0.10325986731913872, 0.11132638916024007, 0.1562865191954188, 0.12159759426140226, 0.24413025006651878, 0.12237166170962155, 0.1406158780446276, 0.17597041296539828, 0.19868434726959094, 0.12742105638608336, 0.14290712540969253, 0.13473737082676962, 0.12206560742924921, 0.1263931966968812, 0.10716607997892424, 0.13684771227417514, 0.22036209498764947, 0.12958308099769056, 0.12111930976971053, 0.16033883846830577, 0.1291611700435169, 0.10648144132574089, 0.16066910902736709, 0.1388783025322482, 0.15423989854753017, 0.1310875776107423, 1.247450381051749, 10.061556100845337, 33.13299089670181, 40.75820133090019, 41.67274385690689, 28.408286422491074, 26.974017284810543, 28.948972709476948, 32.686834037303925, 29.517213217914104, 17.990951612591743, 7.0593087002635, 2.1128934854641557, 1.4573468430899084, 2.040463909506798, 7.878268780186772, 12.473760712891817, 9.748076722025871, 15.754055343568325, 10.412885248661041, 9.177391044795513, 7.415421791374683, 8.17440066486597, 5.12602848932147, 5.67690915428102, 2.430365737527609, 0.7602561393287033, 1.6925625340081751, 3.2764983968809247, 8.795494437217712, 15.462383944541216, 22.614858895540237, 27.489330433309078, 37.17795364558697, 47.45909236371517, 56.87555328011513, 61.916131004691124, 61.60630702972412, 59.659055918455124, 59.698201417922974, 58.976696133613586, 59.358959421515465, 59.55100491642952, 58.769656643271446, 59.992066249251366, 58.77464957535267, 53.793534860014915, 53.88118855655193, 53.34593787789345, 54.075624123215675, 48.49086619913578, 53.23351711034775, 57.48252131044865, 53.69553431868553, 54.81664136052132, 57.03870132565498, 60.43567344546318, 54.695971235632896, 56.06897436082363, 54.252668023109436, 50.0225830078125, 54.5187221467495, 55.34900799393654, 57.61531658470631, 55.45478671789169, 56.551871448755264, 53.47292326390743, 53.03923733532429, 48.88356372714043, 50.71192681789398, 44.7380355745554, 37.15363495051861, 26.579340063035488, 18.581310734152794, 13.720704652369022, 7.947223205119371, 6.023499481379986, 3.481964059174061, 1.8584039225243032, 5.554144866764545, 4.006233802065253, 8.737104870378971, 10.537723749876022, 11.386372111737728, 10.839792340993881, 11.244844906032085, 12.564688883721828, 8.7980991974473, 4.128287527710199, 2.709190263412893, 1.7361761187203228, 4.410986183211207, 12.925589717924595, 24.173742346465588, 20.968464240431786, 23.951349779963493, 21.78201198577881, 31.354591324925423, 32.03656733036041, 21.401340812444687, 6.119179772213101, 0.7614347885828465, 0.09293183597037569, 0.1643400831380859, 0.3120967873837799, 0.1827120379311964, 0.12506429222412407, 0.19784687814535573, 0.12519379699369892, 0.17718459625029936, 0.11751525511499494, 0.08284432726213709, 0.1605686073889956, 0.1678639042074792, 0.0914936576737091, 0.15918656514259055, 0.19328704860527068, 0.1144402552745305, 0.17706088023260236, 0.2804189856396988, 0.14040813606698066, 0.12430176517227665, 0.1481646776665002, 0.09169227123493329, 0.11128263213322498, 0.09392264764755964, 0.13646420004079118, 0.11148365767439827, 0.1266838810988702, 0.08369678776944056, 0.2606036723591387, 0.18305312900338322, 0.18651475809747353, 0.1174376932613086, 0.2085504584829323, 0.12280713170184754], [0.058159066902589984, 0.026386066165287048, 0.03510912152705714, 0.03701736874063499, 0.02702292535104789, 0.02896684018196538, 0.023594887716171797, 0.020470186245802324, 0.017300226754741743, 0.01354092779365601, 0.027419937250670046, 0.0096683084484539, 0.026464179063623305, 0.03216626850189641, 0.07304175131139345, 0.08927091053919867, 0.07610662825754844, 0.034218919099657796, 0.03596385671698954, 0.045335961040109396, 0.044068829229217954, 0.043898313379031606, 0.020617181580746546, 0.16376039158785716, 0.02901376432419056, 0.03244662962970324, 0.08052023244090378, 0.021217909306869842, 0.018101443820341956, 0.047418913527508266, 0.05423169190180488, 0.03803900552156847, 0.013405814243014902, 0.016526714061910752, 0.0537494332093047, 0.031375328326248564, 0.07491611206205562, 0.0285886231722543, 0.05932768232014496, 0.04404635699756909, 0.0307352426534635, 1.0814081970602274, 7.499083327129483, 17.637846060097218, 31.080871112644672, 27.35544841736555, 21.56253196299076, 15.299113355576992, 10.029639713466167, 11.150211934000254, 11.982227638363838, 8.631021212786436, 4.675776399672031, 0.8071565476711839, 0.8830455411225557, 0.9978398750536144, 1.8854310410097241, 2.7720626397058368, 2.97198629938066, 3.6771016381680965, 3.473596195690334, 6.587910745292902, 2.562859640456736, 2.8842181339859962, 2.6060818461701274, 3.731755055487156, 1.9836336839944124, 1.1880265572108328, 0.39822344086132944, 1.603237995877862, 2.6133059710264206, 7.6745816599577665, 12.443185653537512, 19.599604792892933, 31.604173332452774, 46.24990224838257, 51.542531847953796, 57.73109257221222, 56.33061692118645, 59.327592104673386, 57.22394518554211, 57.36370928585529, 53.78471553325653, 60.46349935233593, 55.965217128396034, 54.44182567298412, 53.627764955163, 55.00645637512207, 53.72652925550938, 53.53152371942997, 46.33033633232117, 47.45207034051418, 56.98664791882038, 64.30277913808823, 59.888624399900436, 51.035213470458984, 57.10253790020943, 55.14210529625416, 53.061899319291115, 52.87622608244419, 48.80419358611107, 51.863037049770355, 51.740231439471245, 53.053418174386024, 54.63461212813854, 52.98401489853859, 51.961368173360825, 52.38521263003349, 48.46183955669403, 39.569784700870514, 32.1628687530756, 24.20975871384144, 12.547635398805141, 6.957713076844811, 4.133159816265106, 3.354750922881067, 1.3094093813560903, 2.338563376106322, 2.9584799241274595, 1.98217598721385, 4.540582979097962, 7.185817211866379, 2.467204760760069, 5.223536482080817, 3.1544161727651954, 6.741654770448804, 3.99748002178967, 2.010527215898037, 1.2271891557611525, 0.7840565778315067, 2.9177917074412107, 8.13702967017889, 16.88606970012188, 15.146149713546038, 19.753933511674404, 18.312378264963627, 22.841668725013733, 22.9575777053833, 16.47288177162409, 3.610508074052632, 0.1595554273808375, 0.014939464272174519, 0.0314638479903806, 0.002666609425432398, 0.062437114102067426, 0.07942818439914845, 0.040979179393616505, 0.06008290663885418, 0.03772508818656206, 0.04660953469283413, 0.035679721768246964, 0.04987155203707516, 0.03021524204086745, 0.03166869930282701, 0.029995358527230565, 0.07004547107499093, 0.06915441146702506, 0.05183768676943146, 0.02831802499713376, 0.06570455283508636, 0.036895259472657926, 0.024574248054705095, 0.0330312527512433, 0.030325283987622242, 0.03488705609925091, 0.08149363333359361, 0.026123293937416747, 0.02255258212244371, 0.039523067098343745, 0.07242127874633297, 0.043786846508737653, 0.043582959988270886, 0.03715159356943332, 0.03620355186285451, 0.0322657311335206, 0.063614449754823, 0.09202342494972982, 0.012755472089338582, 0.10285011274390854, 0.00917209088584059, 0.016611118517175782, 0.02053892210824415, 0.03965650525060482, 0.0008956499652867933, 0.03830951463896781, 0.06883398920763284, 0.08778907911619172, 0.0533631193684414, 0.04776668021804653, 0.05170828590053134, 0.052458478457992896, 0.08042672925512306, 0.04044925626658369, 0.028353100751701277, 0.017907800793182105, 0.017267395996896084, 0.042926741880364716, 0.06237759385840036, 0.10463537866598926, 0.09286500557209365, 0.04283251881133765, 0.08808328871964477, 0.027944494650000706, 0.07306386731215753, 0.022226686523936223, 0.025643063163443003, 0.0354545430309372, 0.038921066588955, 0.03237668963265605, 0.0636416049383115, 0.004161592632954125, 0.04479216346226167, 0.10133544128620997, 0.02443087440042291, 0.015916284610284492, 0.02912150746851694, 0.06248801058973186, 1.7761025950312614, 10.861420780420303, 24.362559914588928, 36.244206950068474, 32.64746434986591, 25.114986039698124, 17.381395921111107, 13.677619714289904, 16.539380103349686, 19.215249717235565, 15.173659287393093, 4.8106354381889105, 1.4664200437255204, 0.2776789467316121, 0.7138948864303529, 0.7735605910420418, 1.8480334477499127, 4.457460064440966, 3.6082562198862433, 5.060120075941086, 5.326779317110777, 4.242900777608156, 3.235731334425509, 3.3035299088805914, 3.9874395355582237, 3.239714470691979, 1.8590580811724067, 1.8422384024597704, 2.35990968067199, 4.134383825585246, 10.317994840443134, 16.34724721312523, 22.93756227940321, 35.70439651608467, 49.771557077765465, 54.7465693205595, 59.682588055729866, 58.08586433529854, 60.753313601017, 58.34089145064354, 59.28551696240902, 56.62765458226204, 61.16799674928188, 56.794876009225845, 54.98009338974953, 54.47312459349632, 55.59321328997612, 53.476217687129974, 54.36387285590172, 47.38647826015949, 48.375466391444206, 56.87909089028835, 60.80426886677742, 58.015777096152306, 51.88619300723076, 57.65099287033081, 57.13916413486004, 55.29085211455822, 54.058217257261276, 51.55038222670555, 51.99021242558956, 53.629543259739876, 53.78089673817158, 55.64577966928482, 54.869257137179375, 52.74471893906593, 52.60261796414852, 49.33908708393574, 41.95994384586811, 34.97668996453285, 25.416007786989212, 15.683791413903236, 9.582116827368736, 5.921454532071948, 4.666801756247878, 2.672603214159608, 2.7136695105582476, 5.419907569885254, 5.736341765150428, 7.718364335596561, 6.829164074733853, 6.558316983282566, 8.496810514479876, 6.438328921794891, 5.96751993522048, 5.331919966265559, 0.6167658045887947, 0.6851828552316874, 0.37758769816718996, 3.420940521173179, 9.177677929401398, 19.605883955955505, 18.888269662857056, 15.8758226595819, 19.239551313221455, 22.342611104249954, 28.047227896749973, 19.843623898923397, 6.062950389459729, 0.4067339451285079, 0.014631534213549457, 0.0204487901282846, 0.06945128538063727, 0.053347823704825714, 0.050158403246314265, 0.06732454246957786, 0.06780335388612002, 0.04333626638981514, 0.05496759440575261, 0.027366417270968668, 0.07344708268647082, 0.056494752498110756, 0.022212517069419846, 0.03406864903809037, 0.02935477561550215, 0.07000273079029284, 0.05485712201334536, 0.04579829306749161, 0.02348689224163536, 0.028763013033312745, 0.037579775671474636, 0.012502114932431141, 0.03416056031710468, 0.07233923432067968, 0.02539813402108848, 0.01829083434131462, 0.04769166393089108, 0.04602052918926347, 0.04128106651478447, 0.05808330104628112, 0.03436843217059504, 0.07555802527349442, 0.047890062269289047, 0.032497370266355574, 0.04179724506684579, 0.19259918160969391, 0.133946820278652, 0.1354350193287246, 0.1355436845915392, 0.08711271540960297, 0.1991016569081694, 0.1667720713885501, 0.16194781463127583, 0.18451562005793676, 0.17775162676116452, 0.12770627858117223, 0.1594488401315175, 0.15062750957440585, 0.14944072638172656, 0.12403003522194922, 0.1960968048661016, 0.1631303972681053, 0.20668802404543385, 0.11298707075184211, 0.1461068951175548, 0.1765409464132972, 0.29182463767938316, 0.1450105945696123, 0.24151109217200428, 0.08514764194842428, 0.23475788970245048, 0.20634161919588223, 0.23047339695040137, 0.14722560852533206, 0.1478146214503795, 0.16848211322212592, 0.12932365585584193, 0.14805982704274356, 0.1588164412532933, 0.11677491827867925, 0.14478851429885253, 0.19711342843947932, 0.10992603070917539, 0.1377810668782331, 0.22126926662167534, 0.21177845948841423, 1.8015707284212112, 10.843860022723675, 26.962243616580963, 43.76545496284962, 39.876777827739716, 34.67295326292515, 24.032920002937317, 19.225634559988976, 20.168040990829468, 19.289383739233017, 13.995407111942768, 6.585107445716858, 1.6018389584496617, 1.4522833772934973, 1.9535815715789795, 5.838541556149721, 6.849600803107023, 8.845875933766365, 10.112766902893782, 9.453311339020729, 11.896311398595572, 6.592888478189707, 5.845871362835169, 5.96519161015749, 7.296961722895503, 4.5686777215451, 2.8718008752912283, 1.8604527250863612, 2.3852593079209328, 3.4652029210701585, 9.437358845025301, 14.333524368703365, 22.9233206436038, 36.19975693523884, 49.192456752061844, 55.37203475832939, 61.44342117011547, 60.59932306408882, 63.45541700720787, 60.80402188003063, 60.91771177947521, 56.96086250245571, 62.65579171478748, 57.29573093354702, 55.1022682338953, 54.23415161669254, 57.23382465541363, 53.67511801421642, 54.85541447997093, 52.442049980163574, 51.85288779437542, 56.88982151448727, 61.551977545022964, 58.317135125398636, 51.706755235791206, 57.732426300644875, 60.165644735097885, 57.886865213513374, 57.300598472356796, 52.81813479959965, 55.10456711053848, 55.44009290635586, 56.71392135322094, 57.02838107943535, 55.08377082645893, 53.072394356131554, 52.92481787502766, 48.58513914048672, 42.64944724738598, 34.80290628969669, 27.009252794086933, 14.021313171833754, 9.192577879875898, 5.956653943285346, 6.640182165428996, 3.889075401239097, 6.032128818333149, 6.180427260696888, 5.8927541971206665, 10.91759031638503, 16.263283118605614, 7.207352556288242, 9.008777942508459, 9.266675803810358, 15.359593760222197, 10.932865496724844, 5.1402986235916615, 2.740151477046311, 1.1491669923998415, 4.3649473786354065, 10.379498340189457, 24.788973033428192, 22.84432478249073, 29.014219008386135, 27.46532902121544, 31.465948149561882, 32.52400517463684, 21.38138808310032, 6.300829499959946, 0.40755731344688684, 0.20727117400383577, 0.1400487733189948, 0.14065081835724413, 0.10237821072223596, 0.182346812216565, 0.14307813107734546, 0.17650572408456355, 0.1832110877148807, 0.14055571955395862, 0.15323296742280945, 0.12448624082026072, 0.1920825577690266, 0.16102327674161643, 0.15055561030749232, 0.19690648798132315, 0.1379044118220918, 0.14636295090895146, 0.1208924426464364, 0.16176407370949164, 0.11705648168572225, 0.14181547070620582, 0.09845267253695056, 0.12772342219250277, 0.1418691873550415, 0.1137757214019075, 0.08530082865036093, 0.11955379377468489, 0.17557478888193145, 0.15629885368980467, 0.12025669668219052, 0.12712706200545654, 0.1407710017520003, 0.1093009568285197, 0.06470983003964648, 0.13674419751623645], [0.03741531203559134, 0.029046919771644752, 0.017437845053791534, 0.029652874072780833, 0.028031607944285497, 0.053734764660475776, 0.03136497165542096, 0.04873801051871851, 0.06354632059810683, 0.11995731430943124, 0.026910055821645074, 0.0005257522570900619, 0.049315520154777914, 0.011166064505232498, 0.016657756932545453, 0.058202630971209146, 0.026672657622839324, 0.020528814056888223, 0.05519830956473015, 0.012663563593378058, 0.07532875359174795, 0.03093277267907979, 0.05175897458684631, 0.03213058975234162, 0.052800018529524095, 0.018159759929403663, 0.017456560162827373, 0.05840285499289166, 0.03353646978212055, 0.004354166503617307, 0.09138841371168382, 0.0642639774014242, 0.035508871951606125, 0.04161308112088591, 0.011622016845649341, 0.062389178783632815, 0.058894950852845795, 0.039804649059078656, 0.04608431307133287, 0.03452085817116313, 0.006612778388443985, 0.05304430756950751, 1.3692138972692192, 6.843048054724932, 16.849553659558296, 30.98691165447235, 29.464116767048836, 23.853911608457565, 17.563018575310707, 17.574303969740868, 13.18443562835455, 11.292588394135237, 14.663415066897869, 7.771794693544507, 1.7054307810030878, 0.3419940284220502, 0.2827129641082138, 1.526890592649579, 4.431285168975592, 3.256866750307381, 1.9746493035927415, 2.876722323708236, 5.840851357206702, 3.317839941009879, 1.9866602215915918, 2.6102535473182797, 2.194396974518895, 1.1963015631772578, 1.5251359180547297, 0.938930626725778, 0.982567782048136, 2.2911176970228553, 3.9989206194877625, 8.128991201519966, 16.456141769886017, 28.85853186249733, 42.4483772367239, 54.1877257078886, 57.31575965881348, 59.29078347980976, 56.56114675104618, 58.01083356142044, 58.77955511212349, 55.66998817026615, 57.39852301776409, 54.164866134524345, 55.528286173939705, 54.50545705854893, 55.90040400624275, 51.722395196557045, 52.724329233169556, 49.12702426314354, 54.31140527129173, 51.3179486989975, 59.50872078537941, 58.26057516038418, 53.886591866612434, 54.90772247314453, 53.90057131648064, 54.922955855727196, 55.32677158713341, 55.07730357348919, 51.92488633096218, 55.701952055096626, 53.34490433335304, 53.17394770681858, 51.71121999621391, 47.302658557891846, 38.0053136497736, 24.70646996051073, 19.989870451390743, 9.279500115662813, 5.0293327029794455, 2.626184904947877, 2.0711225643754005, 1.450755384285003, 1.9734523678198457, 0.8593004965223372, 9.408003520220518, 3.379773055203259, 5.208769049495459, 6.46008750423789, 4.9160403572022915, 8.599430657923222, 3.558861007913947, 5.764050353318453, 4.3219218123704195, 0.31788524240255356, 0.7355944532901049, 3.3284240355715156, 9.907903745770454, 14.037926830351353, 14.710203856229782, 20.224232375621796, 21.330311223864555, 31.27177096903324, 27.155163064599037, 13.590087611228228, 4.222866827622056, 0.31861486262641847, 0.04779475937539246, 0.014650890352641, 0.02580763255537022, 0.07267771303304471, 0.0668783336004708, 0.028596944503078703, 0.021108045475557446, 0.09565418207785115, 0.02906326928496128, 0.029234818575787358, 0.06054389537894167, 0.027116417404613458, 0.005769024664914468, 0.043514712087926455, 0.0572622333856998, 0.039505786189693026, 0.02902228046878008, 0.03371485981915612, 0.004581664916258887, 0.06123323553765658, 0.05063952645286918, 0.05189947798498906, 0.07682450028369203, 0.029683929242310114, 0.08095755780232139, 0.02898366095905658, 0.01976468767679762, 0.08032592333620414, 0.02251196994620841, 0.05457797058625147, 0.08321710061863996, 0.022677819542877842, 0.022280464399955235, 0.011714253741956782, 0.02638335918163648, 0.033175529970321804, 0.015536736373178428, 0.019558556159608997, 0.062280847487272695, 0.08576513850130141, 0.02380991387326503, 0.05122760427184403, 0.05303274119796697, 0.0453258900961373, 0.0078124763422238175, 0.07973135172505863, 0.032030926740844734, 0.07707206590566784, 0.06316251892712899, 0.019609853407018818, 0.049119055111077614, 0.03962805130868219, 0.06515125205623917, 0.02555061197199393, 0.01379232196995872, 0.029186803476477508, 0.032404349476564676, 0.012955644160683732, 0.14616896834922954, 0.04084040519956034, 0.08015177838387899, 0.024839456382323988, 0.024098178873828147, 0.006595896848011762, 0.032057907519629225, 0.07085052318871021, 0.03389029610843863, 0.01806703414331423, 0.015160893308348022, 0.036417821029317565, 0.056291263026650995, 0.062067468898021616, 0.05136565858265385, 0.013775229381280951, 0.04172932371147908, 0.05990465760987718, 0.02028144139330834, 0.08419962992775254, 2.1389023773372173, 10.568066071718931, 22.66865260899067, 34.690048545598984, 33.93192082643509, 27.442034371197224, 16.29644963890314, 12.408840246498585, 14.190881922841072, 20.95942072570324, 17.41747308522463, 7.0898837596178055, 1.6432673041708767, 0.19809840683592483, 0.25049499759916216, 0.3743368835421279, 1.127759178634733, 2.561166356317699, 3.954532351344824, 5.037653781473637, 5.658780802041292, 7.819118779152632, 2.840135986916721, 5.620161099359393, 1.9589537708088756, 2.563968230970204, 2.52769632730633, 1.838045446202159, 1.5096614859066904, 2.704284251667559, 5.552440658211708, 9.88691272214055, 19.91118997335434, 31.674942634999752, 45.71037299931049, 56.11350417137146, 59.13750730454922, 61.06938064098358, 58.59072424471378, 60.58517262339592, 59.07859526574612, 57.59106628596783, 56.71644441783428, 53.7712262570858, 56.53805918991566, 54.035448879003525, 55.022290125489235, 51.950382962822914, 52.80287481844425, 50.74265956878662, 56.613348349928856, 50.67867860198021, 60.94863072037697, 58.11440460383892, 55.72408586740494, 56.04747511446476, 55.4118300229311, 56.48938000202179, 55.75186237692833, 55.90477757155895, 54.87306073307991, 57.18235641717911, 53.78623925149441, 53.42544861137867, 51.77247270941734, 48.08359645307064, 40.52004151046276, 27.868650779128075, 23.18168018013239, 12.684556301683187, 8.288905620574951, 2.6166163058951497, 3.388602831400931, 2.548718461766839, 3.243799488991499, 3.3709321171045303, 5.618848269805312, 5.734522612765431, 11.231031697243452, 6.776125570759177, 10.102788638323545, 11.999382767826319, 7.337765833362937, 3.471926422789693, 0.9861086576711386, 0.2746840246254578, 0.2652512979693711, 3.019610093906522, 11.609240602701902, 16.334791481494904, 18.55140633881092, 18.927597552537918, 20.433863326907158, 30.788930878043175, 30.57235959917307, 18.640693947672844, 7.327960459515452, 0.6145016010850668, 0.023575936975248624, 0.041762134060263634, 0.04089627036591992, 0.055257755593629554, 0.05107721546664834, 0.08451671994407661, 0.016435611723863985, 0.05979632260277867, 0.0549957700422965, 0.028765172683051787, 0.01613265776541084, 0.03096443640970392, 0.039960270005394705, 0.020276337272662204, 0.05946395547653083, 0.04291597331757657, 0.03200687002390623, 0.025233622145606205, 0.05801599567348603, 0.043639956929837354, 0.03940030474041123, 0.04503409247263335, 0.02779281265247846, 0.03464911613264121, 0.09818494276260026, 0.05649670805723872, 0.053785509007866494, 0.0708499739994295, 0.01986487019166816, 0.02212522565969266, 0.041837094686343335, 0.031627877469873056, 0.058231641523889266, 0.025961711689888034, 0.025633354016463272, 0.049110390536952764, 0.13428253820165992, 0.11060876204282977, 0.16365543706342578, 0.18254944821819663, 0.0858374014205765, 0.14407076843781397, 0.1271356560755521, 0.14172558177961037, 0.12627762946067378, 0.2106253698002547, 0.13508453266695142, 0.11006738757714629, 0.1315377643913962, 0.06536155444337055, 0.13055274146609008, 0.26603913225699216, 0.10081612344947644, 0.17340526857879013, 0.17985669896006584, 0.10629594893543981, 0.19342237181263044, 0.0982865205151029, 0.22519697929965332, 0.13059093238553032, 0.23108934983611107, 0.14795733644859865, 0.11285789994872175, 0.1432291729724966, 0.14661934808827937, 0.14000682713231072, 0.16748833295423537, 0.11456371154054068, 0.1193128852173686, 0.1665201864670962, 0.1983093994203955, 0.12361644374323077, 0.21758816961664706, 0.09328427448053844, 0.12938954372657463, 0.15190611127763987, 0.08861905997036956, 0.20006913546239957, 1.8494565901346505, 11.138337571173906, 24.679635800421238, 43.746091201901436, 41.41477569937706, 36.63167595863342, 26.46938346326351, 28.363883905112743, 20.331629812717438, 20.923049077391624, 19.02072485536337, 10.59588247910142, 2.8952919272705913, 0.5907567346002907, 1.1741196596994996, 4.42307760939002, 10.034512002021074, 10.168956387788057, 8.653571102768183, 8.205221761018038, 12.292688079178333, 10.612260550260544, 5.8055308274924755, 5.837232526391745, 4.016419155523181, 3.4654981177300215, 3.640049588866532, 2.244732636027038, 2.1480598859488964, 3.6034732265397906, 6.2179929949343204, 9.523124042898417, 20.207794457674026, 33.4190471470356, 47.52071365714073, 56.120077818632126, 61.07508413493633, 62.48159386217594, 58.951450288295746, 61.060937494039536, 60.19675746560097, 58.58326144516468, 57.72272542119026, 54.72458750009537, 56.74780793488026, 55.399974659085274, 57.40305237472057, 53.538663536310196, 56.33054092526436, 54.813639521598816, 55.70607103407383, 51.84656873345375, 60.87049551308155, 56.69342905282974, 56.199364364147186, 57.93306693434715, 58.5650148242712, 58.95171247422695, 58.31279955804348, 58.50345052778721, 55.783218294382095, 58.73858571052551, 54.871419221162796, 53.79696607589722, 52.61540807783604, 47.76526853442192, 40.994183868169785, 26.487994864583015, 21.755316518247128, 11.075235307216644, 8.016323447227478, 4.106315681710839, 4.24914431758225, 3.415835495106876, 3.9037354895845056, 3.904625829309225, 15.278575457632542, 8.824148699641228, 12.40046264603734, 14.362131133675575, 12.362580578774214, 17.28190775960684, 10.225233267992735, 10.334098376333714, 7.648937311023474, 1.209180022124201, 1.3821415160782635, 4.081733375787735, 13.141301292926073, 18.68791401386261, 22.590904980897903, 30.152096450328827, 30.9198110550642, 42.41622716188431, 36.05149269104004, 21.19856469333172, 6.952136401087046, 0.5623611551709473, 0.08259788228315301, 0.1576593884965405, 0.14894739113515243, 0.16104367095977068, 0.24484418128849939, 0.1344395469641313, 0.1247929036617279, 0.20490465802140534, 0.12436596094630659, 0.08765535894781351, 0.08532378327799961, 0.15006513975095004, 0.09764021378941834, 0.1471894362475723, 0.12972554366569966, 0.12072415323927999, 0.18273375317221507, 0.11225796260987408, 0.1934515530592762, 0.12058200227329507, 0.1124534517293796, 0.11095210182247683, 0.18085331423208117, 0.078923100954853, 0.24342314660316333, 0.24952691048383713, 0.18274019501404837, 0.1744057281757705, 0.11241399173741229, 0.16197328513953835, 0.10131115821423009, 0.10129742848221213, 0.13095847360091284, 0.10505733414902352, 0.12363337955321185, 0.15547558927210048], [0.0977371382759884, 0.030833682976663113, 0.014645011615357362, 0.041103106923401356, 0.04185746664006729, 0.048826114580151625, 0.03488426191324834, 0.02059228438156424, 0.06800985647714697, 0.027386965484765824, 0.03477613099676091, 0.05467748145747464, 0.030268700793385506, 0.013057725645921892, 0.020252777794667054, 0.0583537804777734, 0.003956872587878024, 0.012982700081920484, 0.047821198386373, 0.03034368739463389, 0.07330839755013585, 0.07923697005026042, 0.02125956234522164, 0.06677081866655499, 0.02418219555693213, 0.13429698039544746, 0.05651759580359794, 0.018771052127704024, 0.04206503421301022, 0.015207814667519415, 0.08468345084111206, 0.04639279417460784, 0.0325576957402518, 0.08368307288037613, 0.011488745676615508, 0.013958825584268197, 0.06194620938913431, 0.017072346599888988, 0.033655792285571806, 0.031306727905757725, 0.045923311554361135, 0.029262851348903496, 0.06670235554338433, 1.6404019016772509, 5.744778262451291, 19.825409576296806, 31.776345893740654, 29.685722775757313, 20.291690155863762, 10.656197592616081, 23.375426083803177, 15.241488497704268, 11.41507102176547, 12.793409060686827, 9.459755793213844, 3.879645257256925, 0.4063151066657156, 0.3956320689758286, 0.683081093011424, 1.0214464645832777, 2.3303327802568674, 3.633172670379281, 2.1668213792145252, 3.5454185167327523, 1.6496453806757927, 3.3518253173679113, 1.4860018179751933, 2.134067374281585, 1.9864641758613288, 2.229033065959811, 1.632207166403532, 0.6485787662677467, 1.1115175439044833, 1.3811577251181006, 4.440056048333645, 11.635197009891272, 21.35580785572529, 36.288782358169556, 48.18907119333744, 54.94527965784073, 57.27578580379486, 58.534042686223984, 55.83889290690422, 55.633426532149315, 57.457746639847755, 58.44457648694515, 55.320585519075394, 53.073355704545975, 53.53565409779549, 52.06158399581909, 53.061789125204086, 56.39087788760662, 54.37941402196884, 40.67157357931137, 59.77953605353832, 56.98582336306572, 57.916211038827896, 54.523832872509956, 55.663311928510666, 52.4486768245697, 57.53263682126999, 55.77150732278824, 56.02271184325218, 56.02903850376606, 53.819859847426414, 50.031341537833214, 44.46845144033432, 35.67492909729481, 24.68492701649666, 13.032764866948128, 9.666952025145292, 3.5376757197082043, 1.8129474367015064, 0.7418005296494812, 1.7927871434949338, 2.461779364384711, 3.6761683132499456, 3.632681309245527, 3.281308701261878, 9.220164399594069, 12.744920812547207, 3.819696824066341, 8.43536401167512, 13.649208638817072, 8.350293226540089, 3.380457730963826, 1.358895432204008, 0.853067405987531, 2.7755237789824605, 8.826375380158424, 14.48221419006586, 12.221349757164717, 18.565324991941452, 25.514202117919922, 28.721845597028732, 24.78002641350031, 14.61149275302887, 2.7367815328761935, 0.45555075688753277, 0.012000954666291364, 0.06089103866543155, 0.07779137027682737, 0.057237345463363454, 0.0335438504407648, 0.03209435810276773, 0.07020106975687668, 0.057692244881764054, 0.1570156347588636, 0.01322819696724764, 0.05715063292882405, 0.03019445633981377, 0.08775583832175471, 0.04481745956582017, 0.057933053249143995, 0.05188469440327026, 0.06690326234092936, 0.030829005590931047, 0.02240554411400808, 0.02525104777305387, 0.03679612338601146, 0.05533509851375129, 0.05031713008065708, 0.1304421911481768, 0.048667899827705696, 0.03098331293585943, 0.03768759488593787, 0.0499630143167451, 0.02126796345692128, 0.03468875052931253, 0.02568556596088456, 0.06645070810918696, 0.04007545874628704, 0.004343242089817068, 0.0235288458497962, 0.014848861956124892, 0.05507902416866273, 0.057358486228622496, 0.06319621985312551, 0.01957578326255316, 0.020873619578196667, 0.019550058568711393, 0.04197215814201627, 0.023788569706084672, 0.03587090272048954, 0.014563935692422092, 0.023068768095981795, 0.0150021238005138, 0.031217755531542934, 0.053515704930759966, 0.028518887265818194, 0.0273859747176175, 0.1095328334486112, 0.03260821744333953, 0.03541045945894439, 0.04546391101030167, 0.04416684838361107, 0.08609871903900057, 0.05744049725763034, 0.04865573231654707, 0.07333524845307693, 0.022238393903535325, 0.09303916536737233, 0.0800857346621342, 0.008741673063923372, 0.012533181234175572, 0.03237244083720725, 0.19840865425067022, 0.0419213803979801, 0.10375981510151178, 0.04253491017152555, 0.09268636320484802, 0.10944331559585407, 0.02923713964264607, 0.021904624118178617, 0.032271252712234855, 0.007963824373291573, 0.09501110369456, 0.006676541397609981, 0.07245850487379357, 2.540842671878636, 8.143694512546062, 25.43012972921133, 37.41364359855652, 33.96285116672516, 23.45175638794899, 14.748860131949186, 14.639161918312311, 12.392968498170376, 16.45822785794735, 15.284007266163826, 9.344040602445602, 3.1845559179782867, 0.18667515105335042, 0.2912610210478306, 0.8517724473495036, 0.3497990174219012, 3.2353971898555756, 4.621439790353179, 5.109335035085678, 4.163909666240215, 4.0193673223257065, 7.63145349919796, 4.754632618278265, 2.864492917433381, 5.100580304861069, 3.3040654426440597, 2.479642918333411, 1.7116055684164166, 2.4923978839069605, 2.3124257661402225, 6.399071803316474, 16.221703849732876, 25.284895822405815, 40.69877251982689, 51.60336658358574, 57.511779740452766, 58.147645220160484, 58.65032784640789, 56.69037401676178, 55.79149045050144, 56.582923382520676, 57.63056896626949, 55.98119907081127, 53.816010653972626, 53.89738328754902, 53.38713526725769, 52.31803983449936, 55.012669041752815, 57.52954378724098, 42.24277786910534, 58.91426168382168, 59.59760561585426, 57.24833607673645, 56.860012114048004, 56.15209110081196, 54.092654809355736, 57.26018384099007, 57.98962689936161, 56.47276729345322, 56.917586624622345, 55.41227079927921, 52.45795972645283, 45.35053990781307, 39.348442777991295, 27.857040502130985, 16.098848842084408, 9.775528348982334, 5.4010705556720495, 2.970481342636049, 1.6220206255093217, 2.3997265566140413, 2.94788371771574, 3.7341565266251564, 2.2928651282563806, 5.6270164065063, 5.331037463620305, 7.930544475093484, 5.35066626034677, 6.157644158229232, 6.140732690691948, 3.9971736632287502, 1.9061781652271748, 0.4612792463740334, 0.47693823580630124, 3.3171735517680645, 9.64741537347436, 18.662898056209087, 16.86354260891676, 18.86814594268799, 26.239843480288982, 32.57667034864426, 31.36973351240158, 20.85366480052471, 5.383762009441853, 1.1316032661125064, 0.04637843361706473, 0.06918453524122015, 0.025759821546671446, 0.04190798463241663, 0.06369029724737629, 0.06442427387810312, 0.09609627202735282, 0.040684079212951474, 0.013118668957758928, 0.02812488477502484, 0.016290560815832578, 0.015098913772817468, 0.05182989050808828, 0.06116137337812688, 0.03922434894775506, 0.06010617667925544, 0.09795856545679271, 0.10189593347604387, 0.011609623907133937, 0.08937628066632897, 0.04631978168617934, 0.020079760906810407, 0.03400020817935001, 0.04637356883904431, 0.09171925572445616, 0.014958070842112647, 0.044000941270496696, 0.05702009286324028, 0.03640000206360128, 0.0819835695438087, 0.030345347950060386, 0.01851682573033031, 0.031065140283317305, 0.02474522032571258, 0.05827032968227286, 0.04520140224485658, 0.044623016874538735, 0.138297735247761, 0.14587191632017493, 0.08588594530010596, 0.0627353684103582, 0.10680455758119933, 0.15599841746734455, 0.10467161773703992, 0.13067782303551212, 0.11581961836782284, 0.09513020355370827, 0.14431625604629517, 0.18609537044540048, 0.08810976112727076, 0.09534053562674671, 0.1766919734654948, 0.29210730688646436, 0.10459770724992268, 0.0738839701807592, 0.1889179807039909, 0.22862383135361597, 0.15634454030077904, 0.1761553413234651, 0.11140418107970618, 0.1825249573448673, 0.10801975760841742, 0.31703298969659954, 0.21733793226303533, 0.10036917985416949, 0.17727494530845433, 0.13421883224509656, 0.3660665679490194, 0.3824961738428101, 0.2744932333007455, 0.1432601353735663, 0.21867761272005737, 0.25994473427999765, 0.18862069118767977, 0.2032422472257167, 0.14668695774162188, 0.09703505915240385, 0.1736086021992378, 0.2369144224212505, 0.2544630831107497, 2.257865918800235, 8.385368194431067, 27.702206410467625, 43.875823840498924, 42.56299428641796, 32.42952324450016, 21.530463583767414, 31.222082935273647, 22.633781880140305, 19.970233105123043, 18.24701987206936, 13.239258136600256, 4.927925644442439, 0.8513901522383094, 1.3140821806155145, 3.3883335208520293, 4.475378002971411, 8.221924714744091, 8.908604867756367, 7.684767013415694, 7.503027515485883, 6.449530245736241, 10.226487200707197, 5.786230713129044, 6.753323944285512, 6.235768916085362, 5.17156477086246, 4.102685451507568, 1.8071571411564946, 2.0954659581184387, 1.642005534376949, 6.016741069033742, 12.71701605990529, 24.54878032207489, 38.68740364909172, 51.46215856075287, 57.93643735349178, 59.36999022960663, 60.17726071178913, 56.762547343969345, 55.7530403137207, 58.6980114877224, 57.46655456721783, 55.90986929833889, 52.10436590015888, 55.311564803123474, 53.88145834207535, 54.636637419462204, 57.408455684781075, 58.4189772605896, 46.61255478858948, 58.962237909436226, 58.58257748186588, 56.880721002817154, 56.53169833123684, 58.31287935376167, 55.62435641884804, 59.52933467924595, 58.11666548252106, 58.10541048645973, 57.44244106113911, 55.733224377036095, 51.90825842320919, 46.0263716429472, 38.29810693860054, 27.17282261699438, 15.37943534553051, 12.07325080409646, 5.9274515602737665, 3.599631395190954, 2.5156115507707, 4.513707496225834, 5.084491968154907, 7.5061894208192825, 5.784882735460997, 11.675946973264217, 18.95693577826023, 22.870501577854156, 11.389152612537146, 18.7299245595932, 23.027317263185978, 14.309928584843874, 6.875067511573434, 2.3922623321413994, 1.6376179573126137, 3.837358276359737, 11.102116014808416, 20.762767978012562, 20.108843967318535, 28.544026538729668, 37.99405485391617, 40.153395384550095, 36.12218029797077, 22.32493445277214, 6.3784892577677965, 0.8629461040254682, 0.1324077692697756, 0.21037358877947554, 0.21061499457573518, 0.12236225869855843, 0.22848577704280615, 0.08368093549506739, 0.14782838086830452, 0.10847343248315156, 0.2884580480167642, 0.14262469368986785, 0.09504090834525414, 0.11410435181460343, 0.14781387930270284, 0.17591402458492666, 0.10702902014600113, 0.11515592312207446, 0.18452394695486873, 0.11215926439035684, 0.08259991576778702, 0.2641415497055277, 0.10780916578369215, 0.19092077011009678, 0.11431126258685254, 0.23356377409072593, 0.20384681556606665, 0.09887231251923367, 0.13017112913075835, 0.1869425320182927, 0.11950631116633303, 0.21609234128845856, 0.11122386888018809, 0.1447897611069493, 0.11215151636861265, 0.09613398055080324, 0.13489583419868723, 0.1686654830700718, 0.13551414711400867], [0.10890113961067982, 0.06329095500404947, 0.030327697822940536, 0.048285367229254916, 0.030527821654686704, 0.09663396544056013, 0.04073626332683489, 0.07563130493508652, 0.03923819000192452, 0.03153376572299749, 0.021323821201804094, 0.029208557680249214, 0.019018046295968816, 0.020664686453528702, 0.031426636705873534, 0.07247127723530866, 0.03423601447138935, 0.04985212261090055, 0.048716855599195696, 0.030664944570162334, 0.014767296215723036, 0.12781565630575642, 0.05284741950163152, 0.036325464461697266, 0.05756487007602118, 0.035849276537192054, 0.018346831238886807, 0.05199502207688056, 0.04778289614478126, 0.05110030368086882, 0.04213515974697657, 0.025957687394111417, 0.038879209459992126, 0.11323658080073074, 0.04741827156976797, 0.01862884921138175, 0.013334015166037716, 0.08016806110390462, 0.05707481141143944, 0.04165543919953052, 0.047301895392592996, 0.019972361005784478, 0.03854318354569841, 0.03769611103052739, 0.8885420055594295, 4.181553069502115, 14.350937884300947, 28.88138383626938, 29.360906705260277, 24.70922101289034, 25.558562837541103, 30.972430631518364, 26.532319486141205, 20.06299752742052, 13.229390066117048, 8.781596682965755, 3.895463333465159, 0.6462984730023891, 0.5387597309891135, 0.8118770224973559, 2.509254729375243, 5.3988585993647575, 3.524564760737121, 5.666939439252019, 2.203146480023861, 6.607296355068684, 1.8478512950241566, 2.424721852876246, 5.0007169134914875, 1.7115409718826413, 1.2567072780802846, 1.6663464345037937, 1.0870109964162111, 0.645290695829317, 0.8011040661949664, 4.9010226130485535, 9.408460445702076, 17.724418714642525, 28.47920011729002, 44.11254733800888, 53.35614413022995, 56.90493330359459, 55.92504948377609, 59.06836621463299, 58.44470947980881, 58.674274161458015, 56.25312387943268, 59.21873174607754, 51.164889112114906, 51.56070627272129, 50.140650272369385, 55.90798079967499, 54.42271649837494, 53.04664693772793, 58.54335978627205, 56.58597081899643, 62.9865487664938, 54.47806432843208, 52.626442685723305, 58.14427860081196, 50.27713134884834, 61.45643547177315, 56.353700682520866, 54.184913858771324, 51.33105419576168, 40.22274926304817, 32.426312416791916, 20.506448931992054, 11.996013298630714, 6.625305013731122, 1.4721497800201178, 1.2887785071507096, 1.0566920670680702, 0.44444383413065225, 2.1650416497141123, 1.9301120121963322, 3.855099049396813, 2.1723059099167585, 4.711740994825959, 1.4127075509168208, 7.981975190341473, 3.046266851015389, 8.374187294393778, 6.13495035097003, 3.3644016925245523, 1.3667749031446874, 0.6080903357360512, 2.032877616584301, 9.598956573754549, 14.49800519272685, 16.41644150018692, 18.25662385672331, 27.08577498793602, 26.585854813456535, 23.001271560788155, 14.987268839031458, 5.175611078739166, 0.6395353109110147, 0.04866862713242881, 0.04344353270425927, 0.007637727467226796, 0.04942139865306672, 0.03509188143652864, 0.021397373602667358, 0.019180828967364505, 0.03126687828626018, 0.0804266773047857, 0.12030167825287208, 0.014930313591321465, 0.018913297717517707, 0.07172709607402794, 0.0505109567893669, 0.007001625735938433, 0.03269816574174911, 0.029779291508020833, 0.03634792927186936, 0.05974485837214161, 0.022514903284900356, 0.11848899739561602, 0.08784951962297782, 0.00887531252374174, 0.019188933219993487, 0.06444555867346935, 0.025089153823500965, 0.0768877832160797, 0.06103480751335155, 0.03347735029819887, 0.048174612820730545, 0.046111342089716345, 0.07092994783306494, 0.01984608457860304, 0.13037389871897176, 0.033335685438942164, 0.0522891908622114, 0.04153033907641657, 0.05075074099295307, 0.10500146527192555, 0.02935225231340155, 0.04274305290891789, 0.019177917893102858, 0.011693783453665674, 0.08676860379637219, 0.029732461989624426, 0.06298760214122012, 0.03503970474412199, 0.02987895451951772, 0.012446952950995183, 0.040529961115680635, 0.05561051322729327, 0.017048185982275754, 0.07182370143709704, 0.07065021753078327, 0.04522825314779766, 0.027119337755721062, 0.03016622689756332, 0.02861297118215589, 0.014470977985183708, 0.09952638210961595, 0.06238079251488671, 0.04585931987094227, 0.022014159549144097, 0.019751245527004357, 0.02090185458655469, 0.0315282738301903, 0.09158362081507221, 0.011481140518299071, 0.0022188501634445856, 0.05419128567154985, 0.08753889371291734, 0.03412694844882935, 0.01154533443695982, 0.029180177953094244, 0.0370969752111705, 0.015745733508083504, 0.044247953992453404, 0.11274756485363469, 0.07971166996867396, 0.02434190388157731, 0.0808641807816457, 0.042846615906455554, 1.533786510117352, 7.381351869553328, 21.14823069423437, 34.45109076797962, 33.012229576706886, 24.932483732700348, 22.356753945350647, 19.560200907289982, 22.105102948844433, 24.6640832349658, 18.192760683596134, 11.373529750853777, 4.138525603339076, 0.5831994744949043, 0.26230844494421035, 0.4483299271669239, 1.2942606629803777, 1.4095791312865913, 4.102643178775907, 3.7081348104402423, 4.1324402298778296, 12.776422072201967, 4.81050007045269, 4.968730229884386, 4.789984971284866, 6.089520938694477, 3.225706284865737, 3.629552652128041, 1.9196559232659638, 2.6105841295793653, 2.4286420550197363, 6.818032572045922, 11.049627531319857, 19.638186022639275, 32.57663995027542, 46.246957406401634, 55.09330831468105, 57.38347962498665, 57.318803295493126, 59.60503801703453, 58.05006265640259, 58.574217930436134, 56.99846908450127, 58.73147249221802, 53.027203381061554, 57.32557073235512, 49.87326622009277, 54.76434476673603, 58.23520392179489, 56.270348355174065, 59.00791525840759, 56.27604804933071, 62.18437381088734, 56.55231982469559, 55.05260109901428, 57.33478523790836, 53.004944175481796, 62.04071491956711, 55.2402426302433, 55.68230330944061, 52.384623661637306, 43.19628730416298, 34.55241233110428, 23.806550949811935, 15.587855111807585, 8.063775300979614, 2.7743087941780686, 2.661718698218465, 1.9573732931166887, 0.9353410662151873, 5.425356002524495, 3.6311839520931244, 5.009809350594878, 4.290628591552377, 4.552267352119088, 6.069786222651601, 5.715705547481775, 6.07502281665802, 4.913522992283106, 4.333695480599999, 1.4490789617411792, 0.37936226231977344, 0.47774465347174555, 2.4351325817406178, 8.979647755622864, 17.60113053023815, 20.185092575848103, 16.743664741516113, 29.36361216008663, 31.56680803745985, 28.091408126056194, 18.373980559408665, 6.494595827534795, 1.186997287441045, 0.12045703202602454, 0.007971096492838115, 0.008596130483056186, 0.04227943325531669, 0.01582394659635611, 0.03298533607448917, 0.010360901069361717, 0.06075317731301766, 0.010482423112989636, 0.06596654580789618, 0.007022532499831868, 0.033267808612436056, 0.017361466925649438, 0.06649361166637391, 0.028717111199512146, 0.008676283359818626, 0.01917299745400669, 0.005561078132814146, 0.038062435123720206, 0.022627854450547602, 0.088879190152511, 0.07753419384243898, 0.004537536351563176, 0.041025047830771655, 0.07250789480167441, 0.022293715446721762, 0.0849066665978171, 0.04077004217833746, 0.07176099737989716, 0.004192638525637449, 0.05176936094358098, 0.027443355720606633, 0.025214445049641654, 0.011201961260667304, 0.014134949287836207, 0.023769683903083205, 0.033536317641846836, 0.019908783069695346, 0.12973113945918158, 0.10703484600526281, 0.12704640539595857, 0.15038953250041232, 0.21559247514232993, 0.2227433500229381, 0.14831328531727195, 0.1861379251931794, 0.11959012190345675, 0.17655276140430942, 0.09059426374733448, 0.1588103111134842, 0.15352703601820394, 0.16656657069688663, 0.11137846566271037, 0.30386803206056356, 0.10811704574734904, 0.1467824721476063, 0.12580137845361605, 0.10186225481447764, 0.13539028266677633, 0.3028135292697698, 0.20172695978544652, 0.15565789042739198, 0.1814289833419025, 0.1148643704073038, 0.09667994891060516, 0.13225705391960219, 0.24260025325929746, 0.16969919088296592, 0.19992400106275454, 0.07145411931560375, 0.1787038764450699, 0.2357819941244088, 0.10791114429594018, 0.16053663566708565, 0.09322646859800443, 0.15056770731462166, 0.13867565168766305, 0.19278786523500457, 0.14181694015860558, 0.14666990318801254, 0.1419082094798796, 0.1546792796580121, 1.29073825199157, 7.678138744086027, 23.728964813053608, 41.89720921218395, 41.85646019876003, 35.42544208467007, 37.68599018454552, 40.36029428243637, 39.081358909606934, 29.268714152276516, 20.737782418727875, 12.504182830452919, 5.53034009411931, 1.181988324970007, 1.134742135182023, 1.9822937808930874, 6.612222790718079, 12.020901963114738, 11.7173714004457, 13.496775068342686, 7.029506424441934, 12.998467907309532, 5.97648935392499, 7.349716192111373, 9.149873871356249, 7.2714261431247, 4.170087659731507, 4.287320394068956, 2.802489032037556, 1.885429141111672, 1.411351142451167, 6.5008065942674875, 10.727566312998533, 18.503747396171093, 30.268886983394623, 46.56765639781952, 54.49503421783447, 57.58359208703041, 56.352507546544075, 59.18821558356285, 58.77216450870037, 58.21215435862541, 57.220323979854584, 60.73875278234482, 53.87928865849972, 56.23949781060219, 52.315429374575615, 57.2404059022665, 57.41916351020336, 57.088094875216484, 58.99815358221531, 57.34042413532734, 64.34577763080597, 58.195537850260735, 55.40486499667168, 58.972261771559715, 52.66689911484718, 61.371950805187225, 56.561089754104614, 56.772700399160385, 51.406537145376205, 42.85743668675423, 33.45250055193901, 22.529903054237366, 13.964995443820953, 7.982005588710308, 2.6977106044068933, 3.600194239988923, 2.535389489494264, 1.1824194830842316, 5.679083112627268, 5.134393740445375, 9.988929647952318, 7.859972286969423, 10.461725927889347, 8.209406286478043, 17.364194244146347, 13.551089353859425, 15.389393661171198, 13.260093368589878, 7.166093895211816, 2.6912281522527337, 1.1993197887204587, 2.977829435840249, 12.915685549378395, 19.790483750402927, 24.216659143567085, 28.446755558252335, 36.441256776452065, 39.47684548795223, 33.340676352381706, 22.400474399328232, 7.79427096247673, 1.0524714435450733, 0.2605300513096154, 0.1534268312389031, 0.17160928604425862, 0.20240774669218808, 0.16565886471653357, 0.16226218838710338, 0.10850481790839694, 0.20218269783072174, 0.13835430174367502, 0.25119941448792815, 0.1321234821807593, 0.10440520156407729, 0.09339190815808252, 0.14006737153977156, 0.24587969994172454, 0.21854245278518647, 0.15173507592407987, 0.14407302456675097, 0.11212367098778486, 0.09825728731811978, 0.3011941333534196, 0.19785475975368172, 0.13486669748090208, 0.1392515137558803, 0.2078042586799711, 0.11548524373210967, 0.21267466217977926, 0.1774724604911171, 0.10991159593686461, 0.13542351603973657, 0.12019953646813519, 0.17332903516944498, 0.19083466613665223, 0.1786109001841396, 0.12772141839377582, 0.1452901170705445, 0.1526185730472207, 0.13564371125539765], [0.08663648666697554, 0.08414872601861134, 0.02417447351035662, 0.03466555099294055, 0.01217639744936605, 0.06010742348735221, 0.008323700130858924, 0.05176477076020092, 0.04482035023102071, 0.035106383002130315, 0.05462208384415135, 0.03826863343419973, 0.06506583085865714, 0.054994296879158355, 0.01701475408481201, 0.02232286144135287, 0.03387364973605145, 0.035729263836401515, 0.038919637954677455, 0.09978628222597763, 0.02218332840129733, 0.01197105075334548, 0.03254276001825929, 0.02492339328455273, 0.03209750480891671, 0.013513446992874378, 0.042196780268568546, 0.02140826647519134, 0.07612686662469059, 0.03293457688414492, 0.03511957838782109, 0.04518696376180742, 0.016051401871663984, 0.06757822338840924, 0.02005137375817867, 0.07545160871814005, 0.0564094685978489, 0.018877808215620462, 0.05056072892330121, 0.0322709335887339, 0.010981412597175222, 0.019650782851385884, 0.05689808378519956, 0.10995088523486629, 0.1130343678232748, 0.3532390500186011, 3.5107957245782018, 13.189723994582891, 26.911375746130943, 35.62292128801346, 27.239771224558353, 26.09468936920166, 18.865594379603863, 14.627560190856457, 20.54797500371933, 16.637754924595356, 11.618343014270067, 4.79561104439199, 1.5816518291831017, 0.05415675354015548, 0.903861892875284, 0.7120640971697867, 3.6883516469970345, 1.2166259600780904, 3.162082973867655, 9.967168215662241, 4.684924408793449, 2.5057715037837625, 3.879045364446938, 6.895980164408684, 3.57224412728101, 2.6391293853521347, 4.490244705229998, 3.049620408564806, 1.2690694397315383, 1.5447786077857018, 2.2391735343262553, 5.307513400912285, 14.05276408419013, 25.140722058713436, 36.40797816216946, 45.09891360998154, 50.197065845131874, 54.13262866437435, 54.7313017398119, 60.293200090527534, 56.26037009060383, 59.70631778240204, 52.60304354131222, 45.5108343064785, 44.77582074701786, 44.843464717268944, 61.777058467268944, 47.37161345779896, 54.74882259964943, 61.63017354905605, 54.102739468216896, 55.460110232234, 54.784920662641525, 59.665994346141815, 58.229572623968124, 48.04946668446064, 64.53696817159653, 48.74246969819069, 38.19072090089321, 24.70303874462843, 18.156136348843575, 8.682265263050795, 3.385251648724079, 1.6240640846081078, 0.9214727010112256, 1.3972218381240964, 1.8580550537444651, 0.8242754603270441, 3.725744727998972, 3.434418635442853, 2.959699658676982, 2.382311853580177, 2.9891062807291746, 4.118522526696324, 2.7842782717198133, 3.2894402649253607, 1.140911104157567, 2.242326415143907, 0.7776929880492389, 1.0476515209302306, 3.2844682317227125, 9.35538299381733, 17.828711718320847, 19.72728744149208, 17.07670547068119, 26.887072250247, 26.38560365885496, 22.323881909251213, 16.15672543644905, 5.071643907576799, 0.8507298189215362, 0.019261890047346242, 0.03528934837959241, 0.01635575848922599, 0.020297393857617863, 0.05289139175147284, 0.032536470316699706, 0.0666003770311363, 0.07004855098784901, 0.03776868194108829, 0.04536890868621413, 0.04989284054317977, 0.036417167939362116, 0.02750726205704268, 0.033488716289866716, 0.038003805457265116, 0.09362342112581246, 0.06549312238348648, 0.016152564021467697, 0.02485800265276339, 0.046394345263252035, 0.014548309773090295, 0.061719134464510716, 0.039252825154107995, 0.02637742942170007, 0.03724887428688817, 0.03330208841362037, 0.01727179878798779, 0.04685600564698689, 0.06729721659212373, 0.07324831327423453, 0.08199932533898391, 0.010334540911571821, 0.02114583749062149, 0.02796898923406843, 0.003109775025222916, 0.05225677385169547, 0.020175848621875048, 0.022154149010020774, 0.0509348047489766, 0.03368067278643139, 0.061930861775181256, 0.010614199782139622, 0.029868768542655744, 0.0589852479606634, 0.05142733847605996, 0.03684004368551541, 0.04216488276142627, 0.017549278527440038, 0.0544545996672241, 0.09549661670462228, 0.014125356101430953, 0.030930969260225538, 0.016884817014215514, 0.028895486393594183, 0.044212724242242984, 0.059066809990326874, 0.0621604488696903, 0.03917532267223578, 0.025728970467753243, 0.07184578033047728, 0.030349856497196015, 0.044523535689222626, 0.03804716172453482, 0.11317288968712091, 0.0760123755026143, 0.05987056334561203, 0.020563826728903223, 0.049828451810753904, 0.07780302199535072, 0.0822638935642317, 0.0352407488389872, 0.054302997450577095, 0.01471230863899109, 0.04616855796484742, 0.09589166191290133, 0.0320779417961603, 0.0290336520265555, 0.09221929256455041, 0.07056731221382506, 0.037120812994544394, 0.0018186394913755066, 0.030334939328895416, 0.06642472551902756, 0.11481839435873553, 0.7977848849259317, 5.415592426434159, 18.933536633849144, 32.7309762686491, 41.2899561971426, 33.57874497771263, 31.17734793573618, 23.5868676379323, 19.599274210631847, 24.497686363756657, 20.142175778746605, 14.82889048755169, 6.543038003146648, 1.4386790385469794, 0.09626288418076001, 0.4282561386935413, 1.2135599995963275, 2.9029888892546296, 2.392694321461022, 9.415616411715746, 14.93834076449275, 5.947199575603008, 5.503776194527745, 7.790428418666124, 4.914935091510415, 4.624717589467764, 3.4566578920930624, 4.832083387300372, 2.428011051379144, 2.9843641351908445, 2.356326710432768, 3.1115934206172824, 7.917145444080234, 16.684135235846043, 29.14682049304247, 39.4042693823576, 46.51743069291115, 52.24406540393829, 56.81844234466553, 55.00290356576443, 61.665127873420715, 55.94112642109394, 60.338356867432594, 53.59720699489117, 52.97521077096462, 45.072071850299835, 46.55710056424141, 63.39428968727589, 51.65535919368267, 57.17654652893543, 62.84637428820133, 57.97339417040348, 58.77442538738251, 54.40662816166878, 59.47661250829697, 56.74487829208374, 54.32559370994568, 63.61397109925747, 50.26293911039829, 41.986633613705635, 28.88784918934107, 20.939232409000397, 10.054573025554419, 4.859849447384477, 3.666991093195975, 1.3988330704160035, 1.5624836389906704, 2.8203722974285483, 1.6779083828441799, 4.421799927949905, 4.246107330545783, 4.542042575776577, 2.398286908864975, 5.812302064150572, 5.6720036175101995, 4.262048425152898, 3.871972281485796, 2.6470248866826296, 1.5747307380661368, 0.40475591376889497, 0.6027574406471103, 3.0721553368493915, 9.025932122021914, 22.590240016579628, 28.00026621669531, 19.039203263819218, 27.134741060435772, 30.744169279932976, 27.171171605587006, 20.37213373929262, 7.865770300850272, 1.5314991516061127, 0.043007127605960704, 0.0149841526945238, 0.03618663460656535, 0.015908705427136738, 0.06797435213229619, 0.06474969079135917, 0.05487143433128949, 0.026746792609628756, 0.03188369948475156, 0.025637222461227793, 0.10138684243429452, 0.02802914215862984, 0.0614446585677797, 0.04574587888782844, 0.10253615459077992, 0.026918985713564325, 0.029783382597088348, 0.018489173307898454, 0.04460878248210065, 0.04623176297172904, 0.043031789173255675, 0.013055555791652296, 0.027747155727411155, 0.07685745164053515, 0.029379077241173945, 0.06026185699738562, 0.0724302142043598, 0.06503924712887965, 0.05845453073561657, 0.07607803330756724, 0.0746315429569222, 0.048975931931636296, 0.03998312073235866, 0.04949053341988474, 0.0665434988331981, 0.0312511595984688, 0.04413648712215945, 0.016965996837825514, 0.03764455774216913, 0.13810296601150185, 0.16150326817296445, 0.09136953347478993, 0.12848759681219235, 0.09694330001366325, 0.14082225447054952, 0.10355800288380124, 0.14973124751122668, 0.14635699888458475, 0.14575376641005278, 0.17627295688726008, 0.1336878552683629, 0.18139816937036812, 0.14165507775032893, 0.15449176862603053, 0.14138279861072078, 0.1159129137522541, 0.18083548784488812, 0.14595929678762332, 0.17007232789183035, 0.14470230642473325, 0.10560660506598651, 0.14449630107264966, 0.11638693831628188, 0.12642536137718707, 0.11834758857730776, 0.21376630204031244, 0.19044405897147954, 0.17024646542267874, 0.12024232870317064, 0.12225657686940394, 0.1582885070820339, 0.14629350072937086, 0.10813152504852042, 0.16050735051976517, 0.20398828375618905, 0.14549020008416846, 0.12481564306654036, 0.18910124665126204, 0.1034379456541501, 0.09066960657946765, 0.10992994924890809, 0.12709368020296097, 0.17090500274207443, 0.22513140313094482, 0.8193024771753699, 5.996218370273709, 19.633120894432068, 38.816490322351456, 50.06699122488499, 39.84601087868214, 39.09085460007191, 27.676892168819904, 21.171447448432446, 30.471691600978374, 24.015435241162777, 15.919389221817255, 6.667927326634526, 2.199327922426164, 0.26397557579912245, 2.2933296533301473, 4.9913223925977945, 8.874595742672682, 6.853440022096038, 8.047256637364626, 17.818609960377216, 10.684473775327206, 9.649722799658775, 11.321984566748142, 15.678437501192093, 10.761325601488352, 8.356617037206888, 9.17271539568901, 6.054385649040341, 3.4919083630666137, 2.4197163339704275, 2.7673919778317213, 7.237139157950878, 16.219482868909836, 27.66574926674366, 39.73571039736271, 46.55286379158497, 51.088714599609375, 56.4413657784462, 55.508785620331764, 60.7305072247982, 57.15377815067768, 60.1067440956831, 54.505411460995674, 52.17120811343193, 48.0797016620636, 49.40279446542263, 63.148883655667305, 53.33800010383129, 58.45292083919048, 65.06648495793343, 59.900783747434616, 56.90912447869778, 55.16860507428646, 60.07118560373783, 59.389521181583405, 52.89268299937248, 63.81885230541229, 52.129672542214394, 40.37938445806503, 26.114098727703094, 19.710028767585754, 9.425002858042717, 4.556900253519416, 3.8953797379508615, 1.829780770931393, 3.149831243790686, 5.0947442930191755, 3.168995752930641, 7.016797531396151, 6.1665247566998005, 6.607086891308427, 6.955385226756334, 7.435854244977236, 10.672270730137825, 7.300124578177929, 8.13845269382, 4.580934438854456, 4.732869761064649, 1.85696474974975, 1.5570528991520405, 4.787366911768913, 12.525065559893847, 24.828217327594757, 29.49033536016941, 25.49032609909773, 37.65897363424301, 38.34164120256901, 32.962064668536186, 22.71643314510584, 7.161087663844228, 1.1427649296820164, 0.11563338382984512, 0.20450475916732103, 0.13011705625103787, 0.09089840328670107, 0.16503687074873596, 0.14558086084434763, 0.1777630706783384, 0.12188366992631927, 0.08474747592117637, 0.1316912702168338, 0.19703575526364148, 0.11642224228125997, 0.11401671159546822, 0.22972505976213142, 0.14881518494803458, 0.21790534869069234, 0.16409179021138698, 0.1214326816261746, 0.1616649969946593, 0.10019929482950829, 0.13038237404543906, 0.1444442616775632, 0.23374270589556545, 0.24174880207283422, 0.10553377811447717, 0.130959453235846, 0.16439031169284135, 0.18551251734606922, 0.15546511014690623, 0.13194710336392745, 0.2544932143064216, 0.09502059576334432, 0.09414429747266695, 0.19264657516032457, 0.16203408187720925, 0.13077725598122925, 0.12917889253003523, 0.11710458769812249, 0.06774425666662864], [0.06697957738651894, 0.03635261964518577, 0.07279034136445262, 0.03021669665031368, 0.029605884992633946, 0.0657487848366145, 0.03352099971380085, 0.05867202453373466, 0.06718621356412768, 0.08760331213125028, 0.09755474064149894, 0.03280297554738354, 0.016190478490898386, 0.06165064165543299, 0.04432048779563047, 0.055353444404318, 0.043367614707676694, 0.039970645229914226, 0.02498313617252279, 0.04113992858037818, 0.03498953927191906, 0.04309040399675723, 0.07770562995574437, 0.05157104795216583, 0.013206745188654168, 0.018460711944499053, 0.0469571010034997, 0.08930103431339376, 0.009615563085390022, 0.04282567620975897, 0.04704289327492006, 0.02423862104478758, 0.07694826083024964, 0.026392075706098694, 0.08428390079643577, 0.04794291060534306, 0.03319125607958995, 0.1277824377757497, 0.03303050318208989, 0.033139669394586235, 0.014398347702808678, 0.06560339068528265, 0.020751528863911517, 0.061289353034226224, 0.062766709306743, 0.07326134538743645, 0.3228849428705871, 3.6896545020863414, 12.113372851163149, 22.238673381507397, 30.31038075685501, 21.70503381639719, 21.205250434577465, 18.605426140129566, 13.200680706650019, 15.195230729877949, 18.547969423234463, 11.829510983079672, 7.326949713751674, 2.2533548483625054, 0.6612570828292519, 0.4377400141675025, 1.4952979004010558, 0.9514094539918005, 11.482965778559446, 19.611095376312733, 6.240650229156017, 4.507213644683361, 4.332001721486449, 3.181610838510096, 2.306172726675868, 2.529540890827775, 1.949930323753506, 2.690459406003356, 4.471194427460432, 0.8519033621996641, 0.5421445181127638, 2.307054754346609, 3.2735917903482914, 8.09839429333806, 16.23950209468603, 29.27718959748745, 38.96500155329704, 43.87136667966843, 49.312743097543716, 53.56103673577309, 55.48996903002262, 57.74409547448158, 50.69804236292839, 38.686240911483765, 37.33667112886906, 29.81607288122177, 51.30111560225487, 49.776967987418175, 51.335860937833786, 52.14212827384472, 54.10824537277222, 58.42474155128002, 59.014887884259224, 55.05039721727371, 61.61391422152519, 50.30979439616203, 39.90305721759796, 36.333749145269394, 20.512720495462418, 13.90181053429842, 5.691699385643005, 2.9439668403938413, 0.8360054902732372, 1.05553918518126, 0.938456958392635, 1.08634983189404, 2.207244085147977, 2.087993659079075, 4.724235674366355, 4.149578735232353, 3.401953889988363, 2.777062221430242, 3.9820343255996704, 5.3025575168430805, 1.9456478348001838, 3.319102660752833, 3.013128829188645, 2.2941197734326124, 1.138165988959372, 3.3158887457102537, 11.172091159969568, 13.802566509693861, 16.774745173752308, 14.524651262909174, 18.248971067368984, 25.933883897960186, 31.547828055918217, 18.279766514897346, 4.504919517785311, 0.7139911875128746, 0.1145689511031378, 0.04109625690034591, 0.025133315320999827, 0.019556934566935524, 0.007014323882685858, 0.03212147988961078, 0.009615183662390336, 0.05757949038525112, 0.003812933509834693, 0.04440143755346071, 0.04480072784645017, 0.06385823042364791, 0.0813250767532736, 0.04068610527610872, 0.041415291343582794, 0.04028420262329746, 0.05313764377206098, 0.050902502771350555, 0.09319074160885066, 0.05112572223879397, 0.02010202904784819, 0.05221505030931439, 0.027331460260029417, 0.023862335474404972, 0.04434093396412209, 0.13963369012344629, 0.05016514936869498, 0.09745041694259271, 0.044666061439784244, 0.013798013314954005, 0.06938027669093572, 0.08215648253099062, 0.03229075635317713, 0.019135795446345583, 0.020662094502768014, 0.06949561386136338, 0.04198635542707052, 0.052829830601694994, 0.0699289316253271, 0.030369527121365536, 0.020155727142991964, 0.029937294748378918, 0.015150213803281076, 0.06262501105084084, 0.01277976443816442, 0.03425882438023109, 0.032968129380606115, 0.053724964600405656, 0.09977019246434793, 0.026091090294357855, 0.018513332070142496, 0.02976379546453245, 0.012883467516076053, 0.06248233316000551, 0.017959662072826177, 0.09051592263858765, 0.06683315164991654, 0.07360331219388172, 0.012372115706966724, 0.07862800819566473, 0.01976519233721774, 0.06820084076025523, 0.04862497400608845, 0.0909247124218382, 0.04174866036919411, 0.03844136088446248, 0.02921589566540206, 0.036264055452193134, 0.011809092793555465, 0.019683596910908818, 0.07777972597978078, 0.06678727950202301, 0.03588264720747247, 0.08818943810183555, 0.02544099304941483, 0.06837526030722074, 0.041912741799023934, 0.07250755341374315, 0.03357927314937115, 0.05029392683354672, 0.016811396344564855, 0.06093638017773628, 0.03395416904822923, 0.03225268046662677, 0.07421804795740172, 0.11491177880088799, 0.659551271237433, 5.427313847467303, 15.839126128703356, 29.68471772968769, 35.08423179388046, 25.707816928625107, 19.17800411581993, 16.358186826109886, 18.229846693575382, 19.553127586841583, 22.795227617025375, 12.964343838393688, 7.592868944630027, 2.714232592843473, 0.48393864766694605, 0.3598977770889178, 0.48095812322571874, 1.7422746727243066, 9.750481992959976, 6.715400079265237, 6.0307319182902575, 8.255781847983599, 4.755384977906942, 6.474713394418359, 4.707771632820368, 5.188891366124153, 5.668683545663953, 4.502524696290493, 3.3681378420442343, 2.4440537905320525, 1.589837777428329, 2.86940676625818, 5.24639843031764, 10.636071022599936, 18.840067349374294, 32.01216123998165, 41.58678486943245, 46.22844099998474, 50.95544435083866, 56.40862673521042, 57.31173947453499, 59.96956005692482, 52.69826263189316, 46.39812469482422, 40.121325105428696, 35.170715153217316, 56.155355125665665, 55.06990157067776, 54.92361322045326, 55.41358932852745, 56.72221250832081, 59.73682254552841, 58.21783125400543, 57.12475150823593, 59.93240565061569, 51.16004817187786, 48.261860087513924, 40.3586869686842, 23.50717831403017, 15.577301178127527, 7.725005429238081, 4.549891529604793, 2.026241747662425, 1.6147642023861408, 2.844102974049747, 2.194889048114419, 3.9328808756545186, 2.632708204910159, 3.3149323845282197, 5.461705327033997, 6.921407449990511, 4.612056193873286, 5.416036527603865, 5.988549431785941, 3.5360961919650435, 1.1558853881433606, 0.5445319775026292, 0.28624267783015966, 0.8657909638714045, 3.072098814882338, 12.55746927112341, 18.954899087548256, 21.258766762912273, 15.981801822781563, 19.464571438729763, 28.757785968482494, 36.35981194674969, 23.647411689162254, 7.713694861158729, 1.025554637890309, 0.07525083550717682, 0.04508588324824814, 0.007134716470318381, 0.02978856093250215, 0.007450371358572738, 0.03521949744026642, 0.0447098481527064, 0.04371321803773753, 0.010008390199800488, 0.03321887881611474, 0.04856032923271414, 0.0482427011593245, 0.01689094158791704, 0.04562036687275395, 0.05651686107739806, 0.044678811536869034, 0.012387555161694763, 0.024973412182589527, 0.05806340406707022, 0.06147631487692706, 0.024264160201710183, 0.025100113489315845, 0.01963894745131256, 0.04438419004145544, 0.03262397694925312, 0.08392716525122523, 0.05161248205695301, 0.014717161357111763, 0.03333104330522474, 0.07187826413428411, 0.04815031119505875, 0.027455055678728968, 0.0738458386331331, 0.04086764201929327, 0.044409742185962386, 0.015010716942924773, 0.03076708635489922, 0.03843694881652482, 0.056232852293760516, 0.05213954049395397, 0.16227919841185212, 0.26718450360931456, 0.1380530491587706, 0.12891830963781103, 0.21295881568221375, 0.09403963238582946, 0.11029337896616198, 0.12832377513404936, 0.18944499461213127, 0.13131353189237416, 0.15370938170235604, 0.10208817941020243, 0.0879605597583577, 0.12325197501922958, 0.11976775494986214, 0.22205123794265091, 0.15348848886787891, 0.1031897566281259, 0.07303652659174986, 0.18924348667496815, 0.10144490806851536, 0.1387839310336858, 0.16133456316310912, 0.16282954544294626, 0.14411911193747073, 0.16326815471984446, 0.18482319574104622, 0.15344085782999173, 0.13581559265730903, 0.13355251721804962, 0.15845428803004324, 0.08066843933193013, 0.14572517888154835, 0.1796198499505408, 0.1583383942488581, 0.18494613992515951, 0.12332072015851736, 0.3502506291260943, 0.1912307651946321, 0.0971930252853781, 0.11151087965117767, 0.12347912415862083, 0.1937733037630096, 0.17149357037851587, 0.18088209471898153, 0.1459401345346123, 0.515141801442951, 5.718267560005188, 17.21305165439844, 34.28277499973774, 45.911393612623215, 34.746277928352356, 30.937890484929085, 26.25797800719738, 22.69467931240797, 23.871611058712006, 26.808509565889835, 15.586964059621096, 9.652395956218243, 3.6898646783083677, 0.9882341686170548, 1.4076807769015431, 4.144542580470443, 3.27493145596236, 17.747701965272427, 31.489826068282127, 15.436380989849567, 10.272522680461407, 9.972152598202229, 10.589032396674156, 9.050769489258528, 10.294305961579084, 8.180152606219053, 6.422472847625613, 7.548969425261021, 2.6190066151320934, 1.5920075797475874, 3.0883564800024033, 4.329633973538876, 9.939642492681742, 17.09564745426178, 31.13498590886593, 41.67291484773159, 45.34051604568958, 52.00274035334587, 54.906369745731354, 57.09114991128445, 59.47193495929241, 55.73463410139084, 48.42963248491287, 43.562340661883354, 40.33061407506466, 56.241192519664764, 57.79908612370491, 59.0201810002327, 58.476772159338, 57.551894187927246, 59.75989870727062, 59.244969338178635, 56.56825236976147, 61.28346495330334, 53.64447645843029, 46.47741883993149, 39.85178276896477, 24.448214918375015, 16.18377808481455, 7.443376891314983, 4.24625932238996, 3.107826397754252, 2.507757847197354, 2.989882151596248, 3.147996892221272, 5.726457545533776, 4.3636435735970736, 10.373087134212255, 10.3515156917274, 10.891376473009586, 9.241440407931805, 11.715884730219841, 11.251162067055702, 8.041736483573914, 8.828443419188261, 5.775827821344137, 3.684266391210258, 1.9306180975399911, 4.807296842336655, 15.177308041602373, 20.443231724202633, 24.728964753448963, 22.478698901832104, 26.106577031314373, 34.49488341808319, 41.2066874653101, 26.02724678814411, 8.697789330035448, 1.1788675049319863, 0.26388408383354545, 0.20147807314060628, 0.15218272455967963, 0.0648886505223345, 0.06023812682542484, 0.1554054266307503, 0.1328054565237835, 0.18283768353285268, 0.15067338914377615, 0.1467034631059505, 0.09886246421956457, 0.20322118507465348, 0.14859500457532704, 0.14278735761763528, 0.21906387089984491, 0.17473985790275037, 0.07502327076508664, 0.13629846362164244, 0.2442919195163995, 0.18073986953822896, 0.0964346097316593, 0.16817294934298843, 0.16482172213727608, 0.12392570410156623, 0.0796890196215827, 0.2003323455573991, 0.297646964318119, 0.15155872679315507, 0.09624427111702971, 0.16521464480319992, 0.17803894181270152, 0.14539156865794212, 0.22906107507878914, 0.12535223067970946, 0.10853066691197455, 0.13997528585605323, 0.1261257563601248, 0.1602592208655551, 0.15547146293101832, 0.21625160617986694], [0.08167887339368463, 0.03765679204661865, 0.009278135439672042, 0.02720129497902235, 0.029928158910479397, 0.05340547002560925, 0.025809293110796716, 0.08645194422570057, 0.02772197094600415, 0.04121979480260052, 0.03965482428611722, 0.008859571571520064, 0.011565730510483263, 0.07835353972041048, 0.030395448484341614, 0.010364903100708034, 0.0536817307875026, 0.0758178140677046, 0.06830960992374457, 0.018505159168853424, 0.03704061280586757, 0.01516290360086714, 0.05120536210597493, 0.04624508823326323, 0.12065079194144346, 0.031895744541543536, 0.08428072440437973, 0.03027191985893296, 0.029057012980047148, 0.02162259872420691, 0.07626593767781742, 0.03980617788329255, 0.036719760100822896, 0.029117062003933825, 0.04546380710962694, 0.026603114674799144, 0.040584546077298, 0.05749372408899944, 0.03891694766934961, 0.04245565622113645, 0.06331910466542467, 0.013596954377135262, 0.04781942094268743, 0.13283603300806135, 0.0743501799297519, 0.01578567775140982, 0.012213472364237532, 0.32547373208217323, 2.2342390241101384, 9.200304765254259, 23.49179483950138, 35.43279469013214, 35.1443787664175, 26.268178559839725, 20.051058568060398, 17.835013680160046, 18.55728842318058, 20.39155449718237, 12.825650330632925, 7.692668214440346, 3.1359187653288245, 0.5026459938380867, 0.36197311885189265, 1.929481364786625, 14.81863958761096, 7.45025547221303, 4.05155966989696, 5.581271136179566, 5.607645995914936, 3.8161718007177114, 2.9312679218128324, 2.2828923258930445, 5.163569999858737, 2.4161224393174052, 1.6062761703506112, 2.5779194198548794, 1.2255000276491046, 0.9236840042285621, 0.903785303235054, 1.8773171701468527, 4.637592723593116, 9.73901230841875, 17.433572821319103, 24.62901681661606, 31.599699072539806, 37.162944450974464, 39.90524210035801, 47.33082264661789, 51.671493127942085, 40.96025928854942, 31.591611206531525, 22.12689097970724, 43.24862949550152, 50.96473105251789, 50.67263312637806, 66.1120292544365, 56.811682507395744, 57.14233696460724, 52.6584255695343, 52.198300659656525, 46.29109583795071, 44.6137822419405, 23.38385783135891, 14.296932332217693, 7.956137051805854, 4.086403325200081, 1.3465640251524746, 1.2853699713014066, 0.7185168040450662, 0.9808477212209255, 1.7461546207778156, 1.945139968302101, 3.058313154615462, 1.542457288596779, 1.307170232757926, 3.655453724786639, 5.154855642467737, 1.995466249063611, 4.899232909083366, 4.578579990193248, 3.1821743957698345, 1.4741463353857398, 1.0960794473066926, 1.4788458519615233, 4.109925962984562, 10.920386016368866, 14.047544114291668, 18.582351878285408, 23.090891651809216, 24.017420634627342, 23.69404088705778, 28.19759152829647, 18.780858926475048, 6.3834014441818, 1.460894071497023, 0.01498127130616922, 0.12443194529623725, 0.03919587274140213, 0.09308539374615066, 0.12157840974396095, 0.08167265419615433, 0.015912353082967456, 0.022344717690430116, 0.04807092365808785, 0.03532790295139421, 0.09046513747307472, 0.016090372046164703, 0.040196658883360215, 0.021191067680774722, 0.01760656676196959, 0.037319916373235174, 0.010424557858641492, 0.05516779245226644, 0.02070116672257427, 0.03271876405051444, 0.02372232745983638, 0.040042392356554046, 0.031200281664496288, 0.03568340282072313, 0.02871979035262484, 0.08762113109696656, 0.04240165013470687, 0.054571528744418174, 0.016145721419889014, 0.08980985076050274, 0.04689582929131575, 0.034930527399410494, 0.029324865208764095, 0.04305147835111711, 0.015677904921176378, 0.07848322260542773, 0.06983997780480422, 0.0348378813941963, 0.014732040490343934, 0.0032609129357297206, 0.06402048617019318, 0.08629113566712476, 0.017322075582342222, 0.050765895648510195, 0.09321807490778156, 0.005268733639240963, 0.0811887442250736, 0.060520283950609155, 0.02264227809064323, 0.053357475335360505, 0.010475758626853349, 0.01978900414542295, 0.02824313116434496, 0.009647892893553944, 0.03696386360388715, 0.07508210081141442, 0.027143925108248368, 0.02644823402079055, 0.020836883268202655, 0.007812709191057365, 0.005865638840987231, 0.06414398696506396, 0.043423847237136215, 0.028908911845064722, 0.027219661278650165, 0.08859816851327196, 0.05158878899237607, 0.07803299871739, 0.008073739227256738, 0.033566727142897435, 0.02428457111818716, 0.06504502103780396, 0.01722544609947363, 0.037811310903634876, 0.03541376572684385, 0.050678233164944686, 0.036955874384148046, 0.04618990955350455, 0.026446469564689323, 0.04695014336903114, 0.02427244071441237, 0.06770764652173966, 0.03053053791518323, 0.0397839245852083, 0.03521829145029187, 0.016683635622030124, 0.03777517944399733, 0.01901451552839717, 0.5948510149028152, 4.249076396226883, 12.677292041480541, 29.887780733406544, 39.02966268360615, 37.888234332203865, 25.46875085681677, 16.93722065538168, 19.58729725331068, 21.48350190371275, 22.794764041900635, 18.04323110729456, 9.071123097091913, 3.2388628413900733, 0.8120682591106743, 0.314352530403994, 0.44572959013748914, 1.6226155310869217, 0.7020841701887548, 3.674156558699906, 5.3365490678697824, 4.661668706685305, 4.618901526555419, 4.219010509550571, 4.110087929293513, 7.010994292795658, 4.51940861530602, 3.259691186249256, 3.445777175948024, 2.338535115122795, 2.191646872088313, 1.755415911320597, 3.2871917355805635, 7.045463193207979, 13.621023651212454, 20.294452607631683, 27.489243037998676, 33.99872124195099, 40.197720006108284, 43.2834280282259, 50.21433971822262, 55.390072390437126, 48.02750006318092, 33.82328845560551, 27.04192914068699, 47.17463202774525, 55.310253873467445, 54.93827663362026, 64.83886197209358, 59.31121118366718, 58.663786724209785, 55.90175673365593, 53.018406853079796, 50.069913268089294, 45.52979148924351, 27.151534259319305, 18.083752132952213, 10.007493551820517, 5.81344342790544, 2.443329691886902, 2.3417067574337125, 2.1379885263741016, 0.9931736660655588, 2.5985717866569757, 3.6475394619628787, 2.7438455913215876, 3.8361494662240148, 4.323473554104567, 7.157354364171624, 6.070648301392794, 3.1607086351141334, 3.216483942233026, 2.2608841443434358, 1.0697178868576884, 0.4870986827882007, 0.4403586674015969, 1.425817203707993, 4.0442403126508, 11.986961234360933, 18.070357851684093, 20.46891074627638, 21.426628455519676, 19.32013738900423, 20.973025895655155, 32.24237948656082, 24.767131805419922, 9.439842961728573, 2.1986415842548013, 0.046300771573442034, 0.1462041906779632, 0.03894713081535883, 0.027876094609382562, 0.0630952580831945, 0.02754184799414361, 0.019734020279429387, 0.01871950811619172, 0.02547684434830444, 0.03151395038003102, 0.024544528750993777, 0.06552783263032325, 0.009761019391589798, 0.011273710242676316, 0.055306321737589315, 0.03166871414578054, 0.06933857541298494, 0.012145576984039508, 0.0636319792829454, 0.07203280154499225, 0.055689900764264166, 0.04988229091395624, 0.021420599114208017, 0.05678379675373435, 0.008796040947345318, 0.15405293670482934, 0.020791397037100978, 0.009988265937863616, 0.07553492963779718, 0.06384438936947845, 0.037744807050330564, 0.04694145653047599, 0.04789922408235725, 0.04139137934544124, 0.01507069082435919, 0.052531613400788046, 0.06107783723564353, 0.08696335818967782, 0.08459999633487314, 0.014472181192104472, 0.0435222708620131, 0.21432646026369184, 0.09327939114882611, 0.08502443059114739, 0.17893645068397745, 0.10845547993085347, 0.18252244888572022, 0.16301940166158602, 0.16957302577793598, 0.10857895103981718, 0.11452365040895529, 0.08555555599741638, 0.11175197374541312, 0.07335762420552783, 0.13185406773118302, 0.15015486540505663, 0.1518709334777668, 0.11591084316023625, 0.179744545603171, 0.15679647854994982, 0.10355371327023022, 0.15742525574751198, 0.23916963109513745, 0.1430864876601845, 0.08819181297440082, 0.20147629198618233, 0.11973466258496046, 0.20727442461065948, 0.09877276082988828, 0.08450454130070284, 0.1054644763644319, 0.2595598268089816, 0.14510535198496655, 0.1338522558216937, 0.11954784917179495, 0.20900627074297518, 0.18987634568475187, 0.11500634325784631, 0.13825323607306927, 0.16778419754700735, 0.12465988111216575, 0.22295671747997403, 0.10180280878557824, 0.11974036970059387, 0.26685739459935576, 0.1282723294571042, 0.12431572497007437, 0.08347753508132882, 0.44708935311064124, 3.72357243206352, 14.582220073789358, 33.80083546042442, 49.77622702717781, 48.327866345644, 37.4592487514019, 27.609312795102596, 29.960655122995377, 28.723350316286087, 29.86387811601162, 20.2039547637105, 11.131393443793058, 4.656876213848591, 0.8278654958121479, 1.03937212144956, 3.8918454525992274, 20.311906971037388, 16.673203222453594, 7.43842433206737, 12.067384868860245, 11.667893305420876, 9.659419879317284, 9.01075953617692, 6.56121052801609, 10.476140454411507, 7.632888397201896, 5.772828357294202, 6.685764044523239, 2.569135478697717, 1.823273382615298, 2.048508315347135, 3.1318225851282477, 5.906372191384435, 11.632274016737938, 19.292056895792484, 26.58951971679926, 34.04108516871929, 40.43705776333809, 43.072337955236435, 50.37369176745415, 58.86794216930866, 52.668719217181206, 41.54121391475201, 32.22157560288906, 50.32690867781639, 60.1689163595438, 59.13428507745266, 68.7984699010849, 59.73367251455784, 59.170022159814835, 55.142196491360664, 53.35173636674881, 49.12874937057495, 46.59044377505779, 26.82599812746048, 17.49830424785614, 9.507618974894285, 5.273947902023792, 2.4124874593690038, 2.914459523744881, 2.3583700507879257, 2.7795821987092495, 4.767910530790687, 5.272103575989604, 5.960849868133664, 7.06461844034493, 5.888662291690707, 9.472060482949018, 11.976768281310797, 5.336761856451631, 13.145840149372816, 9.864077847450972, 5.953772747889161, 3.4501977637410164, 1.929762193467468, 2.2282963804900646, 5.262038391083479, 14.798437021672726, 21.136780008673668, 27.259604260325432, 35.651336163282394, 31.33626490831375, 30.6059592962265, 39.07805308699608, 27.573923394083977, 10.197759792208672, 2.116964254528284, 0.10741881094872952, 0.2745618671178818, 0.18022193951765075, 0.23105693282559514, 0.2109338657464832, 0.14855495828669518, 0.09840100421570241, 0.150195149180945, 0.09620959797757678, 0.2205849767779, 0.2581264131003991, 0.16882317460840568, 0.14025143900653347, 0.09072804328752682, 0.08794943496468477, 0.12125846245908178, 0.17125304031651467, 0.08541903051082045, 0.2068865337059833, 0.17837696039350703, 0.10508858598768711, 0.09634748901589774, 0.11924161677598022, 0.12905165873235092, 0.1345885850605555, 0.2865743584698066, 0.1350965554593131, 0.12358003397821449, 0.19178669317625463, 0.16422886488726363, 0.17462809046264738, 0.09692331397673115, 0.19703010009834543, 0.16318916052114218, 0.09104015349294059, 0.17137182847363874, 0.1150601489644032, 0.16730114846723154, 0.1718237964087166, 0.08331029210239649, 0.11252342141233385], [0.03938686815672554, 0.11641131786745973, 0.03760430365218781, 0.021467358128575142, 0.06709354158374481, 0.048166374981519766, 0.04619306739186868, 0.02594199097075034, 0.011242696818953846, 0.059990746740368195, 0.09511429190752096, 0.06997162738116458, 0.03059491551539395, 0.041066281555686146, 0.005052967653682572, 0.024446572679153178, 0.057606370974099264, 0.027273229497950524, 0.05102546179841738, 0.02299260890140431, 0.008296889118355466, 0.03581645876693074, 0.01328959113379824, 0.07670047256397083, 0.053554445039480925, 0.06252042017877102, 0.028867340442957357, 0.016499015255249105, 0.06204240657098126, 0.02758119851932861, 0.019097344775218517, 0.013845061766915023, 0.08029604447074234, 0.03306204074760899, 0.06182473465742078, 0.09278491299482994, 0.020330655061115976, 0.0519332865223987, 0.039117297856137156, 0.00834594600746641, 0.057706980223883875, 0.026227845846733544, 0.05665195421897806, 0.0227574594100588, 0.03970828118326608, 0.027589338023972232, 0.02261754787468817, 0.027403170279285405, 0.11769638367695734, 1.7285201232880354, 7.452717740088701, 17.773614674806595, 27.94599372893572, 37.21349313855171, 31.40208687633276, 19.11028604954481, 20.194029696285725, 18.245127573609352, 22.325548119843006, 18.337487317621708, 12.153962273150682, 5.406241603195667, 1.3195488997735083, 1.0855333507061005, 0.8025136718060821, 0.44172472378704697, 3.640114185400307, 8.047942500561476, 2.987787751480937, 3.9962241891771555, 2.6569380797445774, 2.556062280200422, 4.11733984015882, 3.8465974805876613, 2.396183484233916, 3.0128208082169294, 2.64365850482136, 2.591162659227848, 1.3324521761387587, 0.7477992796339095, 1.047055902890861, 1.7410897300578654, 3.708496503531933, 7.624304657801986, 12.81016331166029, 17.054413966834545, 20.347765646874905, 25.904110595583916, 34.45738323032856, 31.15171831101179, 29.234206303954124, 21.499592140316963, 33.83500702679157, 46.98986314237118, 48.49936254322529, 57.524288669228554, 48.75270634889603, 49.811891913414, 40.13142116367817, 31.073463410139084, 24.961808659136295, 17.528134547173977, 10.251468010246754, 5.017237002030015, 1.9964420842006803, 1.20762103702873, 0.39306563325226307, 1.6058574803173542, 1.1165355308912694, 0.8627038076519966, 3.248615968041122, 2.082995977252722, 0.9570565447211266, 2.1616448694840074, 3.036343208514154, 5.307407956570387, 5.408529080450535, 2.6188021386042237, 1.8849530979059637, 2.0241625467315316, 1.4217518968507648, 0.6091589690186083, 2.2217213083058596, 4.551845574751496, 10.151123944669962, 12.435101587325335, 25.858199559152126, 24.782397486269474, 20.375669449567795, 23.511325791478157, 31.443861834704876, 21.47389031946659, 9.157199878245592, 1.1961276037618518, 0.03710787364980206, 0.04240539426973555, 0.056076081018545665, 0.01579304356710054, 0.03083278312260518, 0.03373071951500606, 0.04437222291016951, 0.035077038482995704, 0.019212459301343188, 0.03307120998215396, 0.07719003027887084, 0.06671767347143032, 0.03282304693129845, 0.08090715113212354, 0.04490845058171544, 0.05934247332334053, 0.05220776984060649, 0.0779960620275233, 0.020227670938766096, 0.02840871729858918, 0.039196937723318115, 0.04052361946378369, 0.04104228049982339, 0.050519053620519117, 0.023726077160972636, 0.030907689942978323, 0.04413833135913592, 0.061149580651544966, 0.033246954262722284, 0.03386519296327606, 0.03369642116012983, 0.012496103536250303, 0.034450224266038276, 0.0713825540151447, 0.01916141809488181, 0.02132723508111667, 0.02521534675906878, 0.025483577483100817, 0.05509667615115177, 0.032648185806465335, 0.07244520558742806, 0.04620107887603808, 0.03271832247264683, 0.09829855072894134, 0.03180194449669216, 0.03702486814290751, 0.06665818291367032, 0.005724155344069004, 0.02307840117282467, 0.01898749207612127, 0.06401202568667941, 0.01785178348654881, 0.06006854979204945, 0.03268186075729318, 0.03146080889564473, 0.019046079069084954, 0.03177924591000192, 0.004479578328755451, 0.028257228259462863, 0.04886889939371031, 0.019759462957154028, 0.02191309758927673, 0.032965743375825696, 0.01634355943679111, 0.14015282242326066, 0.034653413167688996, 0.04560766501526814, 0.01978884458367247, 0.08438403136096895, 0.04452944689546712, 0.03367613084265031, 0.042920556079479866, 0.01943327792105265, 0.04856612911680713, 0.040793731532176025, 0.06860134075395763, 0.04415794261149131, 0.061007348049315624, 0.053096562187420204, 0.02299026928085368, 0.02361468636081554, 0.05088060199341271, 0.07109040016075596, 0.022384029252862092, 0.042113132803933695, 0.03246120912081096, 0.06899906511534937, 0.08179837401257828, 0.024969120713649318, 0.044782163022318855, 0.15127121878322214, 3.097374583594501, 10.705036371946335, 24.49559647589922, 34.834790378808975, 40.57584911584854, 31.986026242375374, 19.626292660832405, 19.994794987142086, 21.156820133328438, 25.516385100781918, 25.019576959311962, 13.806682638823986, 5.602990770712495, 1.469644526951015, 0.3577248874353245, 0.12071912889950909, 0.31201794161461294, 1.3694744207896292, 0.9202573006041348, 2.549489582888782, 4.957013558596373, 4.382534734904766, 5.315752308815718, 6.604775665327907, 5.773531794548035, 4.173237690702081, 3.9924880396574736, 3.956553842872381, 3.6303147487342358, 3.12437925953418, 1.8659938964992762, 2.2028961684554815, 4.978819638490677, 7.158016478642821, 8.813267033547163, 13.944327402859926, 19.889371544122696, 25.765338242053986, 29.289003163576126, 40.68147964775562, 37.17125080525875, 33.696846440434456, 23.336727060377598, 40.25653325021267, 52.838182523846626, 55.493590235710144, 62.49208129942417, 55.34344129264355, 52.786524295806885, 45.876621678471565, 35.18807262182236, 28.674604631960392, 21.236226372420788, 13.615430351346731, 7.611676510423422, 3.2569840690121055, 1.7446022853255272, 2.036110768094659, 2.531915050931275, 2.307417872361839, 2.920642029494047, 4.758937312290072, 2.7396655781194568, 4.6765088103711605, 4.082783069461584, 5.1823376677930355, 5.301853129640222, 3.462653257884085, 2.745379996486008, 1.6483103460632265, 1.1780986399389803, 0.6246734177693725, 0.6265062850434333, 1.2962243263609707, 5.96536735072732, 11.541937664151192, 18.50515902042389, 26.264490857720375, 22.724705301225185, 22.629034034907818, 26.284164302051067, 33.81726197898388, 26.567931175231934, 12.504886742681265, 2.3715068958699703, 0.1724714835290797, 0.13941604789579287, 0.03910770930815488, 0.02154128345864592, 0.03149657670292072, 0.06370839080773294, 0.047442116774618626, 0.031209495427901857, 0.039622470358153805, 0.018773645933833905, 0.012334203092905227, 0.03201121900929138, 0.06683470273856074, 0.04080015110957902, 0.020631107981898822, 0.0498750178667251, 0.017788702789403033, 0.03254177667258773, 0.0366465249680914, 0.06107610803155694, 0.04629163202480413, 0.04322961605794262, 0.028612574133148883, 0.04776981208124198, 0.032400115524069406, 0.01174197202999494, 0.04478953625948634, 0.08774190078838728, 0.0320822796493303, 0.030949968240747694, 0.006307069206741289, 0.039940005663083866, 0.05026910199376289, 0.034533778962213546, 0.04968654575350229, 0.050688823612290435, 0.04354009353846777, 0.05197818645683583, 0.070235126913758, 0.09659963368903846, 0.025690612565085758, 0.016386333118134644, 0.09585742664057761, 0.2065816445974633, 0.12420390557963401, 0.19699947908520699, 0.18196735210949555, 0.10097167018102482, 0.13497502135578543, 0.12254538363777101, 0.20655620377510786, 0.16762223123805597, 0.24364127864828333, 0.0916174182202667, 0.24159198626875877, 0.09614911294193007, 0.06260829046368599, 0.0692868625628762, 0.12058163119945675, 0.10758434698800556, 0.1671196785173379, 0.0873818552645389, 0.1621918476303108, 0.0724463930237107, 0.2595453994581476, 0.14930160337826237, 0.08508614759193733, 0.13168329955078661, 0.16533367044758052, 0.15366350213298574, 0.12965134374098852, 0.11284005871857516, 0.0939091554027982, 0.0996025709901005, 0.14558529888745397, 0.19081047212239355, 0.16294230736093596, 0.2519148448482156, 0.1130953649408184, 0.0892323040170595, 0.12333390812273137, 0.12148877314757556, 0.1898066877038218, 0.06785094039514661, 0.14242959790863097, 0.1777485987986438, 0.14101972512435168, 0.1262954410049133, 0.12018360997899435, 0.10387840287876315, 0.4164063557982445, 2.7442015847191215, 11.813789326697588, 26.169674545526505, 41.81915000081062, 50.230321660637856, 42.053502425551414, 27.505314275622368, 31.857619732618332, 26.81147910654545, 33.74419569969177, 27.72767074406147, 15.599174704402685, 8.06763969361782, 1.8531602039001882, 1.377471329178661, 2.397737600840628, 1.9532925495877862, 7.060088133439422, 14.004598818719387, 10.508332327008247, 9.449312053620815, 7.961014090105891, 10.12482650578022, 12.741804029792547, 11.187006309628487, 7.62826357036829, 6.580726280808449, 6.71528086066246, 6.365742366760969, 3.4965999238193035, 2.8443979332223535, 1.7064307210966945, 2.4486237578094006, 4.525977512821555, 8.687271494418383, 14.407519698143005, 18.68262279778719, 22.637135200202465, 29.396313205361366, 40.90922422707081, 40.183888748288155, 37.18526065349579, 31.941751018166542, 43.035833314061165, 56.90487250685692, 59.261072874069214, 65.77140033245087, 56.32924899458885, 54.74499240517616, 44.45593111217022, 34.346828162670135, 26.845988854765892, 18.67412455379963, 11.534413117915392, 6.455478351563215, 3.470425265841186, 2.29558530729264, 1.6790195857174695, 4.25238411873579, 3.2404402317479253, 4.890272514894605, 8.465405199676752, 5.357335852459073, 5.682550426572561, 5.960741098970175, 10.974472314119339, 11.593341305851936, 11.417986415326595, 7.5752136670053005, 5.290469890460372, 4.947534017264843, 2.9212678084149957, 1.278725671581924, 2.903590206988156, 7.204815242439508, 14.473057631403208, 21.07937838882208, 37.932019382715225, 31.742155328392982, 30.292728804051876, 34.51464995741844, 39.564324393868446, 29.717933647334576, 14.40121678635478, 2.3536309925839305, 0.34362414095085114, 0.22971168626099825, 0.1251654766383581, 0.15125689533306286, 0.20798283425392583, 0.14109079318586737, 0.10922487927018665, 0.2984752011252567, 0.16239737800788134, 0.12006515578832477, 0.13967219274491072, 0.16490853857249022, 0.15679395524784923, 0.18458127044141293, 0.16217655938817188, 0.13855123805115, 0.2232871067826636, 0.20777164871105924, 0.10746113563072868, 0.16765651846071705, 0.08201239455956966, 0.10782314784592018, 0.19034284487133846, 0.15080135024618357, 0.12098211635020562, 0.07952406245749444, 0.11284468229860067, 0.14990298048360273, 0.13144331867806613, 0.15328272100305185, 0.1429531682515517, 0.11464269831776619, 0.21746666519902647, 0.14308108482509851, 0.13197088177548721, 0.10581974245724268, 0.1492022001184523, 0.21365463850088418, 0.15316736156819388, 0.11862907776958309, 0.15526968782069162, 0.1512391134747304], [0.04452706460142508, 0.010172201673412928, 0.02952194437966682, 0.04029809562780429, 0.020835680988966487, 0.027368907176423818, 0.03366941069543827, 0.07707077456871048, 0.003170496156599256, 0.0721329172665719, 0.07380315772024915, 0.01957819338713307, 0.01096390440579853, 0.035403468427830376, 0.02887388433009619, 0.04682460908952635, 0.058770414761966094, 0.029737534568994306, 0.06775866175303236, 0.05934429158514831, 0.03676113112305757, 0.023594939666509163, 0.051325534368515946, 0.02861676170141436, 0.0065109019215015, 0.04417406948050484, 0.06487229358754121, 0.059031064447481185, 0.06986823878833093, 0.03822447564743925, 0.030830404539301526, 0.0115195995385875, 0.06419176643248647, 0.030316671363834757, 0.037862456010770984, 0.05803497238957789, 0.08968565234681591, 0.0205116667348193, 0.028565356842591427, 0.043573067159741186, 0.043059192976215854, 0.01703966798231704, 0.02076451273751445, 0.013798515192320338, 0.021344337874324992, 0.011654406953311991, 0.025277737258875277, 0.015944976039463654, 0.058905930927721784, 0.019806071686616633, 0.7116598938591778, 5.1363230869174, 15.7556845061481, 32.93977126479149, 34.920430183410645, 29.59584429860115, 29.832894578576088, 29.85219184309244, 28.327155075967312, 15.760176815092564, 15.007810536772013, 13.610925693064928, 8.166239652782679, 3.1686437968164682, 1.1227188678458333, 0.04206713449093513, 1.766530789900571, 0.3198401187546551, 2.2763020545244217, 2.627621227875352, 2.8923162119463086, 3.3399723283946514, 5.8298989199101925, 2.760355230420828, 2.257263413630426, 2.4255288345739245, 2.186543745920062, 2.0132397953420877, 2.7281932812184095, 3.777935402467847, 3.089141850359738, 3.3044539717957377, 1.2153736897744238, 0.7464336685370654, 0.7125220913439989, 3.514619506895542, 5.163641246035695, 6.07736824080348, 10.874462630599737, 12.738267369568348, 19.04019881039858, 15.690079126507044, 22.129647731781006, 33.784021362662315, 33.53054456412792, 37.578782737255096, 29.83077049255371, 23.926320523023605, 19.89253107458353, 11.104419641196728, 8.760744351893663, 3.196252640336752, 0.7819384289905429, 0.6010477698873729, 0.45417621033266187, 0.798781500197947, 2.7806340297684073, 1.2510218331590295, 2.4262797692790627, 1.6326762037351727, 2.661101706326008, 2.325850920751691, 2.6589942444115877, 1.7403013911098242, 3.7195349112153053, 4.387575164437294, 2.2226344468072057, 2.842263635247946, 1.2678025639615953, 0.956561443163082, 0.597031801007688, 3.1903294706717134, 9.276000503450632, 10.482581108808517, 13.775238376110792, 22.594611681997776, 27.121031396090984, 27.353865802288055, 27.90077805519104, 27.042185626924038, 21.811977177858353, 11.234454363584518, 1.3735137227922678, 0.053243692964315414, 0.06501069670775905, 0.09044302889378741, 0.02321780804777518, 0.04229032798320986, 0.06534418818773702, 0.02482136096659815, 0.03793700845562853, 0.03729742187715601, 0.014874790740577737, 0.07982441704371013, 0.011034475228370866, 0.04133592978178058, 0.014961180440877797, 0.032014621756388806, 0.03532300477672834, 0.06103837724367622, 0.05463458161102608, 0.055703303951304406, 0.06161147110105958, 0.0344027676328551, 0.016303310912917368, 0.027480643075250555, 0.050938938511535525, 0.06711763911880553, 0.09144075738731772, 0.008295351017295616, 0.012823310880776262, 0.01923600950249238, 0.05331167369149625, 0.057551726640667766, 0.061257336783455685, 0.06964184663956985, 0.04337896214565262, 0.03751490825379733, 0.08654209290398285, 0.04978809753083624, 0.02042983382125385, 0.028074296278646216, 0.07625994112459011, 0.06302777459495701, 0.07160580687923357, 0.009935903708537808, 0.06294043865636922, 0.03993911508587189, 0.0781481280864682, 0.029234369576442987, 0.024141082431015093, 0.01345324119029101, 0.04230334154271986, 0.07059992960421368, 0.0168835368094733, 0.08982293482404202, 0.06297131199971773, 0.011708139372785809, 0.024783544831734616, 0.03155242702632677, 0.035695388505700976, 0.024667623220011592, 0.04016131038952153, 0.05281057929096278, 0.002041844463747111, 0.027106359448225703, 0.049641742298263125, 0.05106026481371373, 0.01461612537241308, 0.02024601311859442, 0.04976992975571193, 0.07820893224561587, 0.01996644052269403, 0.040412323287455365, 0.009199962241837056, 0.04832226681173779, 0.009973059331969125, 0.010741568094090326, 0.07397833425784484, 0.05164709211385343, 0.0341486933757551, 0.020412983358255588, 0.03502111023408361, 0.02517573462682776, 0.009537052210362162, 0.04854836952290498, 0.029784679500153288, 0.0698926554468926, 0.02262230875203386, 0.03670001526188571, 0.04422041660291143, 0.01079904835933121, 0.014013188829267165, 0.03660036338260397, 0.0869974450324662, 0.04123189180972986, 1.4381743781268597, 8.24466934427619, 20.637845881283283, 40.43910965323448, 39.04513545334339, 30.178565829992294, 28.282214887440205, 29.033727161586285, 31.765411980450153, 24.463702887296677, 20.084475874900818, 17.666631415486336, 11.025683116167784, 3.8868045480921865, 0.8666405151598155, 0.14823892212007195, 0.35688023432157934, 0.6455135776195675, 1.3782767672091722, 2.1911324746906757, 2.0577988168224692, 3.821678892709315, 5.686815222725272, 4.806904513388872, 4.89260938949883, 5.007686214521527, 5.488917091861367, 3.8768868427723646, 4.936167877167463, 3.558002016507089, 8.802696950733662, 7.270062966272235, 2.0617912150919437, 1.699393498711288, 1.8975598714314401, 5.851152129471302, 8.640635646879673, 9.747877232730389, 14.256892930716276, 17.192851938307285, 22.30135291814804, 18.78436043858528, 26.70290183275938, 38.125064224004745, 38.954103738069534, 44.7989235073328, 34.517807587981224, 30.98497375845909, 22.752848491072655, 15.254949275404215, 11.440713945776224, 5.862380051985383, 1.477412497624755, 1.3708279794082046, 1.72387475380674, 3.88746143784374, 3.0750049464404583, 2.607500832527876, 4.430346144363284, 2.9123774729669094, 6.0450884979218245, 5.128111252561212, 4.509311132133007, 3.370630983263254, 3.642937671393156, 4.6337207313627005, 3.1125561939552426, 1.642115016002208, 0.7814353122375906, 0.8301634818781167, 1.4587723603472114, 3.189469766803086, 10.659556612372398, 14.920068494975567, 21.01545251905918, 22.753836438059807, 28.236653432250023, 27.934482246637344, 29.10049717873335, 30.188857577741146, 27.326062694191933, 14.020878095179796, 2.4025061074644327, 0.1350128708872944, 0.11331632456858642, 0.011235966467211256, 0.09608705455320887, 0.03707631381985266, 0.01742937158269342, 0.05633742090140004, 0.09134660111158155, 0.06058529608708341, 0.025146579355350696, 0.039270384368137456, 0.020783532127097715, 0.023663807260163594, 0.03216982338926755, 0.035677795895026065, 0.04867611169174779, 0.03015735823282739, 0.07587813583086245, 0.027376927937439177, 0.027168421547685284, 0.06862187598017044, 0.02303323406522395, 0.0327244377695024, 0.04869466538366396, 0.033105701295426115, 0.03989568089309614, 0.04591578617691994, 0.006355082450681948, 0.040102350467350334, 0.09986707242205739, 0.03738403793249745, 0.0737564246810507, 0.03569547385268379, 0.04584065485687461, 0.045716129898210056, 0.03949765225115698, 0.01615092758584069, 0.017164697601401713, 0.07479402134777047, 0.04482740805542562, 0.015447795540239895, 0.04229147460137028, 0.0270890970932669, 0.12536119582364336, 0.12607693788595498, 0.17439799499697983, 0.14903619652613997, 0.09585263978806324, 0.08819979848340154, 0.14757421013200656, 0.164184870372992, 0.08885851391823962, 0.20694909675512463, 0.20281509670894593, 0.1918002447928302, 0.08380041384953074, 0.10802390621392988, 0.10631816883687861, 0.16261769196717069, 0.12586272438056767, 0.1425340774585493, 0.17880556551972404, 0.14375505881616846, 0.11479005916044116, 0.18138420215109363, 0.14410135976504534, 0.08407945395447314, 0.15365695639047772, 0.15255620295647532, 0.1970486983191222, 0.1511758824926801, 0.1254225120646879, 0.16691212949808687, 0.126075602020137, 0.1105296787864063, 0.13715864246478304, 0.1742154563544318, 0.14874356769723818, 0.09895394134218805, 0.10361443579313345, 0.17519696149975061, 0.17749614984495565, 0.1426935798372142, 0.0952346608391963, 0.16591967025306076, 0.08752367226406932, 0.14112414530245587, 0.11781169116147794, 0.05933799075137358, 0.1365958570386283, 0.10712100935052149, 0.1331543253036216, 0.12168813627795316, 1.2013412802480161, 8.070169407874346, 22.433819510042667, 45.27418680489063, 47.44212627410889, 41.176938861608505, 41.97239577770233, 39.019866809248924, 37.59143605828285, 26.005230769515038, 20.884471647441387, 18.704828806221485, 11.465841997414827, 4.601202076300979, 1.5803623921237886, 0.42377653531730175, 2.8093595383688807, 2.0393310952931643, 4.281565602868795, 8.820106666535139, 9.778513088822365, 10.623833779245615, 13.75839103013277, 10.283877421170473, 8.831115625798702, 9.275135099887848, 7.347243474796414, 6.767669599503279, 5.015490045771003, 7.413670560345054, 9.1357690282166, 5.524531155824661, 2.0315533876419067, 1.5826350264251232, 1.435639914125204, 4.5340539794415236, 6.1177353747189045, 7.034584376960993, 14.508869759738445, 16.63152515888214, 24.084680825471878, 21.80699184536934, 29.439967162907124, 41.04633986949921, 43.027747347950935, 45.919247791171074, 36.31751261651516, 29.771641865372658, 23.2776041328907, 14.179365690797567, 9.285259656608105, 4.267064156010747, 1.0921276593580842, 1.4014795096591115, 1.4919431554153562, 2.26517743896693, 6.240367144346237, 4.63311561383307, 6.49102876894176, 5.106168380007148, 8.81873494014144, 9.273003414273262, 6.642026016488671, 6.171338623389602, 9.98890969902277, 12.236940320581198, 6.645899908617139, 5.998560944572091, 3.145904866978526, 2.323740846477449, 1.3659910764545202, 4.568607425317168, 13.63845806568861, 15.638998467475176, 23.435525558888912, 31.981261298060417, 37.65599459409714, 38.242690712213516, 37.557583674788475, 37.11863122880459, 30.822906754910946, 15.048803687095642, 2.457507443614304, 0.32738369365688413, 0.156693572353106, 0.25576682877726853, 0.19531999889295548, 0.18360150192165747, 0.10545439799898304, 0.12510226049926132, 0.2592192107113078, 0.12510570406448096, 0.08053783618379384, 0.20130162010900676, 0.1515717143774964, 0.10104150627739727, 0.08261987211881205, 0.14222813450032845, 0.12059050728566945, 0.14083550922805443, 0.139586919976864, 0.1294905351824127, 0.14297028217697516, 0.15168680663919076, 0.17108596803154796, 0.09184878275846131, 0.1720229146303609, 0.19192885898519307, 0.12838577415095642, 0.08529540355084464, 0.0886735632957425, 0.13510213640984148, 0.1662779346224852, 0.17879771359730512, 0.1843854325124994, 0.2070974075468257, 0.18418784311506897, 0.08722094280528836, 0.18290539708686993, 0.09245730674592778, 0.15665722195990384, 0.21392660593846813, 0.1658003032207489, 0.22309104620944709, 0.16424456873210147, 0.10511044223676436], [0.0454510681447573, 0.02076182801829418, 0.029410419992927928, 0.0354490325844381, 0.025906638766173273, 0.03811277500062715, 0.042481928248889744, 0.019518708395480644, 0.017841066874098033, 0.049518761006766, 0.013198602900956757, 0.03422474124818109, 0.06360914339893498, 0.009390732229803689, 0.05901487820665352, 0.021063952626718674, 0.024035498936427757, 0.05538046971196309, 0.06435066025005654, 0.04192746971966699, 0.05310629916493781, 0.08469893204164691, 0.022813638133811764, 0.044613654681597836, 0.04245093616191298, 0.06454243863117881, 0.015290872124751331, 0.010124919444933766, 0.055138306925073266, 0.02180948078603251, 0.07178390005719848, 0.06938003178220242, 0.0024087959036478424, 0.06176707349368371, 0.09416682907612994, 0.025601031629776116, 0.01455863768569543, 0.025872227233776357, 0.026185120404988993, 0.06771016982384026, 0.027705168722604867, 0.04482753422053065, 0.012956061618751846, 0.09193540623527952, 0.03977715990913566, 0.04014961414213758, 0.023673915311519522, 0.041595566435717046, 0.011715205546352081, 0.03387659977306612, 0.07369008410023525, 0.3459731274051592, 4.9390338733792305, 16.040225587785244, 32.62425899505615, 40.57142995297909, 39.60543818771839, 30.723272301256657, 20.65507035702467, 21.810590252280235, 17.561926133930683, 16.94990247488022, 15.982945561408997, 11.629543863236904, 5.4225037805736065, 1.803677121642977, 0.6597531354054809, 0.4067830753047019, 1.1272289883345366, 3.1203336641192436, 1.5841315523721278, 3.3077455451712012, 2.258250885643065, 4.14630426093936, 4.712670994922519, 3.6534716561436653, 5.483052106574178, 1.5400472679175436, 6.052636317908764, 2.3117109294980764, 4.597474951297045, 13.742609526962042, 3.752550627104938, 0.16538055933779106, 0.7203968719113618, 2.4354805005714297, 2.6814462896436453, 1.3194254064001143, 1.270464677363634, 2.7217602264136076, 5.394238522276282, 4.548305114731193, 6.797815281897783, 14.6666363440454, 16.32164228707552, 14.222481027245522, 9.705100078135729, 5.653669126331806, 4.9161377269774675, 1.7201704275794327, 0.7826806954108179, 1.3088676729239523, 0.12229556930833496, 1.4730889233760536, 2.2855355590581894, 3.8728942070156336, 3.1807641964405775, 3.6021071998402476, 3.5624931380152702, 2.496191505342722, 5.691582541912794, 2.429235060699284, 5.152111239731312, 4.300132356584072, 2.4322801223024726, 2.3250301647931337, 2.707410058937967, 0.8458599646110088, 0.7316859473939985, 1.587185044772923, 3.774610343389213, 20.70475649088621, 20.871848724782467, 12.915753945708275, 18.81086591631174, 27.447435781359673, 26.328395828604698, 29.498324431478977, 31.011893413960934, 21.280849277973175, 9.84377458691597, 1.6825840319506824, 0.08417510194703937, 0.07244870852446184, 0.04465687736228574, 0.024436080566374585, 0.036519643690553494, 0.047738545399624854, 0.0344566586863948, 0.05583133555774111, 0.0019804152771030203, 0.050698716440820135, 0.04755634814500809, 0.03150912270939443, 0.050989797891816124, 0.07976601002155803, 0.007894168247730704, 0.062022862111916766, 0.06819258065661415, 0.03136712017294485, 0.026853674862650223, 0.0201748856852646, 0.003676635537885886, 0.03836162082734518, 0.036759487265953794, 0.060442351023084484, 0.07098943096934818, 0.01582876870088512, 0.014908150278643006, 0.04923062959278468, 0.021568234551523346, 0.03808100736932829, 0.01852601537393639, 0.038822850765427575, 0.05265191924991086, 0.05042642245825846, 0.01612652948097093, 0.016440790059277788, 0.02197725811129203, 0.037529613910010085, 0.06915828547789715, 0.02939752517704619, 0.013067147210676922, 0.017643076716922224, 0.03772897704038769, 0.0567210852750577, 0.017324728760286234, 0.035441625950625166, 0.06355547127895989, 0.051263138302601874, 0.06962335231946781, 0.018045673277811147, 0.034013169788522646, 0.04592692210280802, 0.03831369293038733, 0.07247339977766387, 0.030239922161854338, 0.06341537606203929, 0.016391405697504524, 0.012422042764228536, 0.0106010804665857, 0.03903346856532153, 0.08973457472166047, 0.010972526306431973, 0.03148796036839485, 0.027705155735020526, 0.02599339211883489, 0.06153623588033952, 0.012121456256863894, 0.045615542912855744, 0.04976390351657756, 0.03258252429077402, 0.0575776795449201, 0.05662173396558501, 0.041304781843791716, 0.015421162643178832, 0.07752561461529694, 0.024177575687645003, 0.040418772550765425, 0.0687377697613556, 0.07786239380948246, 0.048497665993636474, 0.01723687702906318, 0.005879068467038451, 0.07142017348087393, 0.026015419061877765, 0.015655638635507785, 0.10167566404561512, 0.05206773399550002, 0.02274030466651311, 0.02325043285964057, 0.04784152581123635, 0.024639878029120155, 0.060109969053883106, 0.046761214834987186, 0.017648796820139978, 0.06088778805860784, 0.5852773098740727, 6.669452469795942, 20.07344126701355, 37.294273003935814, 44.96504679322243, 40.96019089221954, 33.14070828258991, 21.247525066137314, 15.436465535312891, 18.352595306932926, 22.551922872662544, 23.2972414791584, 19.257687740027905, 6.977571761235595, 1.8289378099143505, 0.09762155619682744, 0.2023188374005258, 0.4687595012364909, 0.4744921764358878, 1.0633575031533837, 1.578075389843434, 3.103139824233949, 2.3812191747128963, 4.003012049943209, 5.95291874371469, 3.7297003157436848, 5.638505090028048, 5.386799471452832, 4.954819651320577, 21.23904962092638, 14.014191403985023, 4.951591249555349, 3.284423346631229, 2.534290635958314, 2.367090582847595, 2.776483464986086, 3.273468059487641, 2.056815857067704, 4.127127164974809, 8.574173413217068, 6.895647682249546, 8.992595560848713, 18.76429181545973, 20.528451651334763, 17.535008378326893, 13.554045595228672, 8.09019623324275, 5.744286188855767, 3.71826886665076, 3.185756653547287, 1.8068696628324687, 2.8067129803821445, 3.9657479245215654, 3.408742700703442, 6.210551569238305, 4.9982318468391895, 4.3766512256115675, 6.06548105366528, 4.10107291303575, 8.820345103740692, 4.6289709862321615, 3.755456996150315, 2.761216596700251, 2.1677314303815365, 2.0427198009565473, 0.88395333616063, 0.7556640263646841, 0.9898005751892924, 2.8422121005132794, 4.399312734603882, 19.500895589590073, 24.89764340221882, 19.055348597466946, 20.197605304419994, 28.2015186175704, 28.83361279964447, 33.97939547896385, 35.34547917544842, 26.9857282564044, 13.024182077497244, 2.949904496781528, 0.088323944946751, 0.022674277643091045, 0.10227557169855572, 0.031294426808017306, 0.025078622747969348, 0.05791309318738058, 0.027975739067187533, 0.04895437254162971, 0.033627768789301626, 0.03364827804034576, 0.05962292350886855, 0.008104517019091872, 0.07331518820137717, 0.030380919088202063, 0.06285811963607557, 0.05324609381204937, 0.004108590765099507, 0.036830774261034094, 0.04273549042409286, 0.09451941601582803, 0.026351736269134562, 0.03523296370985918, 0.07884021048084833, 0.05749674834078178, 0.02639948233991163, 0.021494756365427747, 0.0060928918810532195, 0.06556371547048911, 0.023135266383178532, 0.018753863987512887, 0.04005042610515375, 0.01053637539371266, 0.02076114895317005, 0.09258450343622826, 0.006266537275223527, 0.01507724398834398, 0.05717225911212154, 0.03230489426641725, 0.04124515769944992, 0.036914377196808346, 0.022609540101257153, 0.033516131225042045, 0.05245897940767463, 0.0706526888825465, 0.15799442364368588, 0.18954557046527043, 0.10719402926042676, 0.10010895319283009, 0.10672160031390376, 0.11052865462261252, 0.12053034879500046, 0.08705422675120644, 0.15845059213461354, 0.11448884368292056, 0.08786074831732549, 0.2257006600848399, 0.2122736649471335, 0.11532012329553254, 0.11835133642307483, 0.19354086311068386, 0.18516559299314395, 0.14004647266119719, 0.17599972779862583, 0.18170564115280285, 0.1660469634225592, 0.22146866685943678, 0.13688812963664532, 0.16724385466659442, 0.18775107222609222, 0.2697201253613457, 0.12396318255923688, 0.1555281481705606, 0.06812968364101835, 0.08261834329459816, 0.11274444783339277, 0.15649242064682767, 0.1041665936645586, 0.1247362926369533, 0.2133169464650564, 0.14221706165699288, 0.1787231574417092, 0.09536027675494552, 0.13473063212586567, 0.13061790203209966, 0.0789043988334015, 0.13292739138705656, 0.07924715973786078, 0.15424395067384467, 0.09311272704508156, 0.18646145705133677, 0.11431062433985062, 0.12026131284073927, 0.19941319565987214, 0.1487913471646607, 0.26587701751850545, 0.5826489196624607, 6.442788457497954, 22.48304206877947, 41.157077327370644, 52.38003730773926, 52.81995490193367, 41.905135586857796, 29.478837177157402, 30.17011508345604, 26.252880580723286, 25.236932896077633, 21.642346680164337, 16.735757365822792, 7.133732931688428, 2.6479073893278837, 1.0017459467053413, 0.9642234351485968, 1.9609408266842365, 5.997352134436369, 5.977511499077082, 8.429938852787018, 7.776952916756272, 11.72838605940342, 14.333105441182852, 9.606342427432537, 11.697749253362417, 8.870255425572395, 12.741097267717123, 6.549465833231807, 19.34879545122385, 23.15955776721239, 8.183689266443253, 2.063041110523045, 1.84978895355016, 3.3546623401343822, 4.091533999890089, 2.1457807207480073, 1.9993543904274702, 4.177815495058894, 7.33731840737164, 6.4987789280712605, 9.609860088676214, 17.874491661787033, 20.490227602422237, 17.811130061745644, 12.843071445822716, 7.525438712909818, 6.096470290794969, 2.6894797710701823, 1.8607499403879046, 3.269043196924031, 1.3454085309058428, 4.283533897250891, 5.6340982764959335, 8.583456315100193, 8.353692144155502, 8.838295340538025, 9.08114030957222, 7.928132079541683, 15.50028121098876, 9.467155896127224, 13.96501349285245, 11.855447441339493, 7.208399400115013, 6.330911535769701, 4.743991289287806, 2.463794918730855, 1.2270140089094639, 2.539151287637651, 4.75729770027101, 24.119965732097626, 27.677456438541412, 20.078580491244793, 27.427431754767895, 37.585470378398895, 38.140996769070625, 39.84998546540737, 41.9376390427351, 30.33865313977003, 14.252031091600657, 2.6125555112957954, 0.31991038529668003, 0.20672778831794858, 0.20050136226927862, 0.09077518450794742, 0.10910726370639168, 0.13120023562805727, 0.1932194092660211, 0.1083527370064985, 0.18473490985343233, 0.203893838042859, 0.141707161674276, 0.06412750386516564, 0.2075080675422214, 0.14421314204810187, 0.09869505796814337, 0.08845363525324501, 0.15642795769963413, 0.1303550333250314, 0.10786402533994988, 0.1911987637868151, 0.10378171587944962, 0.1575992300058715, 0.15205209172563627, 0.156013720552437, 0.21618819708237424, 0.09580415528034791, 0.07914927045931108, 0.15526438888628036, 0.09525084708002396, 0.17580247978912666, 0.08970983893959783, 0.15482097049243748, 0.2481423449353315, 0.14539284515194595, 0.10411510345875286, 0.08618150561233051, 0.16771850263467059, 0.12399273487972096, 0.17332885705400258, 0.14489839668385684, 0.17689440166577697, 0.11650819782516919, 0.15872095653321594, 0.20265093364287168], [0.02642222916620085, 0.05066199868451804, 0.04056072313687764, 0.11710464706993662, 0.030140340786601882, 0.002649761049724475, 0.04321548556617927, 0.045248788374010473, 0.051280641855555587, 0.009543725045659812, 0.01804724663088564, 0.017130915039160755, 0.026869378707488067, 0.0742585321131628, 0.07537797282566316, 0.026043613252113573, 0.004474921815926791, 0.07503834378439933, 0.016504442210134584, 0.03454466255789157, 0.048920686458586715, 0.02410285254882183, 0.010994784242939204, 0.03719000713317655, 0.04220306625938974, 0.04214686712657567, 0.040135160816134885, 0.04189995088381693, 0.031753445146023296, 0.0460670432948973, 0.03907198602973949, 0.010743275961431209, 0.0084514729132934, 0.01973276048374828, 0.02711562701733783, 0.0656510291446466, 0.03871787768730428, 0.006882896950628492, 0.05315479851560667, 0.04465327423531562, 0.08307181036798283, 0.043053144472651184, 0.05460623899125494, 0.0453364471468376, 0.07712740043643862, 0.0305143887817394, 0.03265656094299629, 0.16162309533683583, 0.030185513460310176, 0.12970761337783188, 0.06256514199776575, 0.02197071607952239, 0.13852564879925922, 3.2942192209884524, 14.01333075016737, 27.194635346531868, 37.87792548537254, 37.198001369833946, 30.89473620057106, 27.219206728041172, 21.611549332737923, 22.812892869114876, 21.98662720620632, 17.99864050000906, 17.748813405632973, 9.560005813837051, 3.8976584281772375, 1.023421052377671, 0.3437826636945829, 0.06324872680124827, 0.11426290424424224, 0.6545178475789726, 3.6785887833684683, 1.7382555571384728, 3.275623731315136, 3.9436535350978374, 2.712086895480752, 3.7133155949413776, 4.502319032326341, 5.258135525509715, 23.29973604530096, 10.049119368195534, 2.3124148417264223, 4.439059551805258, 2.3857444943860173, 1.4619525521993637, 1.8910811003297567, 2.0797269651666284, 0.22883648634888232, 0.20353836414869875, 1.140468071680516, 0.9495255863294005, 0.8186273602768779, 3.2324718218296766, 2.436441848985851, 2.233604220673442, 0.9745560307055712, 0.7946633524261415, 0.16371378471376374, 1.2358300108462572, 4.043043851852417, 2.049251887947321, 3.2204848900437355, 2.7416357723996043, 3.0534064304083586, 9.768145345151424, 1.3648994662798941, 2.062739501707256, 4.578965669497848, 3.141699442639947, 7.203338546678424, 3.9386577531695366, 1.9051627884618938, 0.7108914444688708, 1.176924027968198, 1.730126605834812, 1.8371894233860075, 1.5261700563132763, 2.501520956866443, 5.069594392552972, 16.109385676681995, 43.472935259342194, 26.105024814605713, 12.331666387617588, 21.682877205312252, 26.53227958828211, 32.41156920790672, 29.07113805413246, 23.575434051454067, 9.210392273962498, 1.517491084523499, 0.06184973390190862, 0.03587402716220822, 0.05792736839794088, 0.011510438653203892, 0.04477056696487125, 0.023858353852119762, 0.04643009822757449, 0.04843572634854354, 0.045616095812874846, 0.0602353474823758, 0.01885426914668642, 0.017658596880210098, 0.03438044383074157, 0.05939293565461412, 0.04021415501483716, 0.029309382152860053, 0.054346513279597275, 0.056041585994535126, 0.0431927276076749, 0.040921295585576445, 0.04209742895909585, 0.013431458228296833, 0.06538017492857762, 0.024944960096036084, 0.06666098823188804, 0.052989689211244695, 0.01265512630197918, 0.08844266631058417, 0.03432317229453474, 0.017620550679566804, 0.07029869186226279, 0.0761822827917058, 0.071741204301361, 0.01400331455442938, 0.04964055486198049, 0.024141464637068566, 0.050816847797250375, 0.021205394841672387, 0.09498375555267558, 0.03205448992957827, 0.03706633193360176, 0.041938034191844054, 0.003362600850778108, 0.00975468701653881, 0.06477242277469486, 0.011812542852567276, 0.03460710315266624, 0.006433919406845234, 0.041587736777728423, 0.01911500788992271, 0.07300218741875142, 0.05656944224028848, 0.03862143188598566, 0.015638094264431857, 0.05606548686046153, 0.012836830956075573, 0.048301063652615994, 0.04423577163834125, 0.06777032089303248, 0.04322223168855999, 0.06717987562296912, 0.039573904214194044, 0.03149282514641527, 0.051736146124312654, 0.05011406734411139, 0.025934871919162106, 0.09649851606809534, 0.015313280346163083, 0.025516387831885368, 0.09431029364350252, 0.012281416911719134, 0.036856927545159124, 0.07167593983467668, 0.133461871300824, 0.01852487061114516, 0.06176847615279257, 0.056955756081151776, 0.029078689258312806, 0.03302274031739216, 0.06466865568654612, 0.057730966436793096, 0.04749544008518569, 0.14142045518383384, 0.014544916302838828, 0.06299529821262695, 0.011265300781815313, 0.02779906524665421, 0.05339716168236919, 0.10225980106042698, 0.058607895552995615, 0.02857300096366089, 0.059649295726558194, 0.022900862750248052, 0.07589877495774999, 0.08677653735503554, 0.03223266474378761, 0.02073368577839574, 0.2571200311649591, 4.811995290219784, 18.18829022347927, 33.46459910273552, 41.96701146662235, 41.37415207922459, 31.763192899525166, 25.31773556023836, 17.25543837994337, 15.655267294496298, 17.63660352677107, 22.578359954059124, 23.72606746852398, 14.652023278176785, 4.86553156748414, 1.1557869496755302, 0.35046053817495704, 0.155081479169894, 0.1413302545552142, 0.2516318194102496, 0.32834109384566545, 1.0535533167421818, 2.6511859009042382, 2.823394797742367, 1.1454042443074286, 5.826784987002611, 4.243870675563812, 3.10294555965811, 19.47068341076374, 12.391262389719486, 4.61754547432065, 4.496129639446735, 4.837925573810935, 3.634770722128451, 3.00747686997056, 3.362935446202755, 1.1073295748792589, 0.5403301154728979, 1.1034531891345978, 2.0485964231193066, 2.0457026408985257, 3.5888511361554265, 4.079757006838918, 2.5178251694887877, 2.053191801533103, 1.6248387680388987, 1.5647218376398087, 2.353742136619985, 8.53863961994648, 4.932243162766099, 4.864469049498439, 8.432203531265259, 6.459494261071086, 9.543353207409382, 5.593979554250836, 6.093875030055642, 5.8918374963104725, 2.7637902460992336, 4.934333050623536, 2.3323528468608856, 2.7545945020392537, 1.7877000477164984, 0.35516150936018676, 0.4913628852227703, 0.8914763387292624, 1.7493939469568431, 3.9900827687233686, 7.5759741012007, 16.0830644890666, 46.140635311603546, 31.08641691505909, 11.65636757388711, 21.41987431794405, 28.714327700436115, 36.35061264038086, 34.44201685488224, 28.162967786192894, 11.189481876790524, 2.75997216347605, 0.11509553456562571, 0.00888094542460749, 0.10316991902072914, 0.05040025062044151, 0.06333151337457821, 0.04593412464600988, 0.03230130227166228, 0.0226676261445391, 0.010076802300318377, 0.01721804688713746, 0.06085078086471185, 0.033204644423676655, 0.017130054147855844, 0.015381163666461362, 0.030174483290466014, 0.02050203736871481, 0.07367682934273034, 0.042539697024039924, 0.038683167440467514, 0.05559714343689848, 0.01667186887061689, 0.008783014400250977, 0.06125106563558802, 0.017093885580834467, 0.020705586211988702, 0.010050390192191117, 0.01433226130757248, 0.07279106866917573, 0.011765262479457306, 0.030044896884646732, 0.01342122493952047, 0.01632699841138674, 0.04460467469471041, 0.025181180135405157, 0.06399990641511977, 0.0329092176980339, 0.08222749122069217, 0.033578753645997494, 0.03270320863521192, 0.051294386430527084, 0.025665142056823242, 0.043469222146086395, 0.032668750718585216, 0.0401382555719465, 0.03992174883023836, 0.2039185367175378, 0.14051714271772653, 0.10858931884285994, 0.1898453535977751, 0.13417109730653465, 0.14731442875927314, 0.1373723364667967, 0.18356160406256095, 0.19718560972250998, 0.21316388592822477, 0.08963914937339723, 0.1344329715357162, 0.08329772754223086, 0.1386456986074336, 0.11175739142345265, 0.19161985837854445, 0.12128716130973771, 0.1746993069536984, 0.11998256959486753, 0.11377623348380439, 0.18321647570701316, 0.14235211769118905, 0.14664903399534523, 0.11386445257812738, 0.14935860031982884, 0.06289090029895306, 0.10927662922767922, 0.18687634728848934, 0.2673569490434602, 0.13632194517413154, 0.11118827547761612, 0.1828694622963667, 0.12063608257449232, 0.1197332376614213, 0.14778336219023913, 0.2181172912241891, 0.16619413130683824, 0.33994291035924107, 0.09762093279277906, 0.17134528927272186, 0.12257616792339832, 0.12660804844927043, 0.11739501976990141, 0.12487874046200886, 0.1445580626023002, 0.10128552443347871, 0.19133240974042565, 0.3549904591636732, 0.22743397566955537, 0.18553003203123808, 0.14835692360065877, 0.23798452515620738, 0.2139392521348782, 4.3954055942595005, 20.243364349007607, 36.85901015996933, 48.94659474492073, 50.774999633431435, 42.645989432930946, 37.617840841412544, 30.992066077888012, 29.67882614582777, 30.52774239331484, 23.22099857032299, 22.990312948822975, 13.5203898511827, 5.164978299289942, 1.6390249505639076, 0.6417234591208398, 0.4041847272310406, 0.9790413931477815, 2.171516977250576, 6.020493842661381, 3.582092486321926, 6.5711702685803175, 11.044190973043442, 8.774498663842678, 12.992385383695364, 11.989083420485258, 13.901909328997135, 35.331533923745155, 18.305310644209385, 5.893114702776074, 9.825280029326677, 5.7907244469970465, 6.061644684523344, 3.7314325477927923, 4.706009477376938, 0.9312580665573478, 0.4581860639154911, 1.8509645154699683, 1.390337438788265, 1.651505974587053, 4.383916910737753, 3.452101699076593, 3.2099392684176564, 1.5379319689236581, 1.3520707609131932, 0.6885000772308558, 3.382016122341156, 8.610849995166063, 4.137547155842185, 7.606119783595204, 5.257572205737233, 7.614622777327895, 19.946585074067116, 9.308617953211069, 8.645629528909922, 11.018392257392406, 8.292281739413738, 13.095606844872236, 8.599226418882608, 5.045332694426179, 4.0311770886182785, 4.885292407125235, 3.4323014365509152, 3.444755980744958, 2.276065992191434, 3.787805372849107, 7.833419311791658, 20.782175436615944, 52.90567450225353, 36.039200350642204, 17.77994703501463, 31.488908417522907, 35.498063787817955, 41.83477096259594, 41.835546121001244, 31.596163362264633, 12.691143248230219, 2.4671031162142754, 0.19048745976760983, 0.13177584536606446, 0.11004936081008054, 0.1338593359105289, 0.14168060763040558, 0.09251179522834718, 0.12981663487153128, 0.18612780229886994, 0.14335002430016175, 0.11389186009182595, 0.16836500231875107, 0.09746707073645666, 0.11647551364148967, 0.1824280180153437, 0.15935596777126193, 0.11020132296835072, 0.1603963103843853, 0.1586433278862387, 0.14327350887469947, 0.17052318260539323, 0.12438187259249389, 0.11397462440072559, 0.37075376487337053, 0.12104163659387268, 0.19465265970211476, 0.1410863848286681, 0.1384020218392834, 0.17161470372229815, 0.10387561240349896, 0.1124966076167766, 0.13147885270882398, 0.18803559680236503, 0.19093061098828912, 0.1760530733736232, 0.13579776627011597, 0.12098303661332466, 0.17029743612511083, 0.1827994777704589, 0.11310058966046199, 0.10288025136105716, 0.12311435857554898, 0.10065535199828446, 0.10085415851790458, 0.07879020457039587, 0.12330190671491437], [0.029701696257689036, 0.047237617982318625, 0.06662114232312888, 0.0643383183341939, 0.07326236212975346, 0.0302397978521185, 0.019573473327909596, 0.012244641638972098, 0.058657504414441064, 0.07776027428917587, 0.03302238408650737, 0.051030411923420615, 0.0444056010019267, 0.043777955579571426, 0.0551283176173456, 0.06875204126117751, 0.04269131779437885, 0.07255089483805932, 0.023839930036047008, 0.04513961474003736, 0.04843404167331755, 0.024736329396546353, 0.04512127627094742, 0.04289775730285328, 0.03905848636350129, 0.04397618322400376, 0.018779156380333006, 0.05831561553350184, 0.04682604514528066, 0.013874506475985982, 0.04390386835439131, 0.019269203912699595, 0.031993114316719584, 0.031904991701594554, 0.0141234200236795, 0.0830187468091026, 0.03181698783009779, 0.04570461547700688, 0.059434677750687115, 0.018796307413140312, 0.038629191039945, 0.04515150765655562, 0.041959530499298126, 0.10651347241946496, 0.03653101339295972, 0.036326885674498044, 0.04302849403757136, 0.04435438539076131, 0.04816099812160246, 0.03797744066105224, 0.011309900146443397, 0.04442522709723562, 0.05568769287492614, 0.05736436403822154, 2.528899200260639, 9.81910441070795, 26.541735380887985, 34.20323766767979, 38.004223108291626, 38.2199527323246, 49.51311394572258, 42.86745674908161, 43.4152315557003, 40.852728858590126, 23.56809474527836, 17.512167803943157, 12.978240642696619, 8.858778141438961, 3.9493214059621096, 0.9076036827173084, 0.4199329228140414, 0.3736469830619171, 0.7451510592363775, 0.8301022101659328, 1.292015458457172, 2.9478409700095654, 1.556103543844074, 4.3424829840660095, 2.27534759324044, 2.0270527666434646, 25.953399650752544, 11.835228726267815, 4.841688796877861, 6.367926774546504, 7.005486963316798, 3.752858410589397, 1.929065880831331, 3.153329431079328, 1.3193254242651165, 0.6889432878233492, 0.6225157273001969, 1.0448172292672098, 0.2692794083850458, 0.1335777502390556, 0.38003429188393056, 0.44772157387342304, 0.7949020864907652, 0.4055483196862042, 1.4036198635585606, 1.2674451456405222, 6.290336363017559, 3.4835763601586223, 5.645102486014366, 13.37136184796691, 4.864329881966114, 3.0020296247676015, 4.5285889226943254, 3.717988869175315, 4.486061129719019, 2.2162978118285537, 3.6668531130999327, 2.3601433681324124, 1.8817917862907052, 1.0324918781407177, 0.3716143890051171, 0.6613675144035369, 1.6482824413105845, 2.561238552443683, 7.079574437811971, 9.036486055701971, 28.980465419590473, 57.876848950982094, 15.800890680402517, 19.18662015348673, 22.663614079356194, 31.840997524559498, 23.830250278115273, 21.80183172225952, 8.96601788699627, 1.2904742849059403, 0.016972227167570964, 0.08277162647573277, 0.02354900072532473, 0.06783292104955763, 0.03517818950058427, 0.059484839512151666, 0.013346418309083674, 0.05071766718174331, 0.033656181913102046, 0.05224838387221098, 0.05684020368789788, 0.031394895049743354, 0.03701113470015116, 0.012391981144901365, 0.005125312673044391, 0.04921703344734851, 0.07945350647787564, 0.03325217156088911, 0.01643518127821153, 0.03824272134806961, 0.08068804687354714, 0.018544203558121808, 0.01981440971576376, 0.025953279036912136, 0.05527432404051069, 0.02278824740642449, 0.05121858717757277, 0.027955372679571155, 0.049168504410772584, 0.018425472917442676, 0.01567467286804458, 0.08195673348382115, 0.0503554582974175, 0.0861683176481165, 0.018972968246089295, 0.014695460031362018, 0.051167846540920436, 0.03160356842272449, 0.0724836859444622, 0.039888660176075064, 0.01606612237083027, 0.019823424954665825, 0.01786750402970938, 0.04808177756785881, 0.047454670202569105, 0.04969182984496001, 0.03146556977299042, 0.03891501808539033, 0.04093806441233028, 0.042673150019254535, 0.046922056790208444, 0.025704837680677883, 0.06477025570347905, 0.05615756141196471, 0.030436290726356674, 0.045623598925885744, 0.031199097938952036, 0.0465779822843615, 0.043120449845446274, 0.08702907536644489, 0.06655628603766672, 0.07145416384446435, 0.0780241894244682, 0.02662794322532136, 0.03641241077275481, 0.024660869676154107, 0.027400576473155525, 0.03863127276417799, 0.04938416510412935, 0.030993098152976017, 0.04340340477938298, 0.0501713648554869, 0.07128635683329776, 0.021799012793053407, 0.036679134937003255, 0.055487387216999196, 0.07060756630380638, 0.0463325392047409, 0.0429893568798434, 0.026948406302835792, 0.04033781537145842, 0.055917888530530035, 0.024585552819189616, 0.02752470438281307, 0.05171059397980571, 0.07180426458944567, 0.04943507272400893, 0.04559546781820245, 0.030165707394189667, 0.029268382204463705, 0.06785848061554134, 0.016636605723761022, 0.018584973440738395, 0.0572083645965904, 0.040394374445895664, 0.03873410474625416, 0.037916517758276314, 0.033508041815366596, 0.06231310864677653, 0.11416085893870331, 3.412950737401843, 13.422317113727331, 31.767769753932953, 40.638348162174225, 40.28728500008583, 38.57934884727001, 43.74327935278416, 37.116887122392654, 34.356981217861176, 21.226569190621376, 20.52923820912838, 25.471593104302883, 19.77632001042366, 9.91986645385623, 2.7633463824167848, 1.0300685581751168, 0.2640264871297404, 0.2401330872089602, 0.1917051459895447, 0.22214405093109235, 0.49331479298416525, 1.1493534198962152, 0.2509097394067794, 3.2647826755419374, 1.3321437989361584, 2.715036724694073, 6.404216252267361, 11.804451327770948, 5.365071762353182, 3.318799389526248, 5.251468308269978, 4.707131367176771, 4.449964966624975, 6.142963645979762, 2.778437272645533, 2.654492435976863, 1.5437234519049525, 0.8407816558610648, 1.0175640229135752, 0.9864644729532301, 0.8596431312616915, 1.207185722887516, 1.9600105891004205, 1.996417623013258, 3.1831808667629957, 5.3413258865475655, 8.971407897770405, 9.376286622136831, 4.86103973351419, 16.774414591491222, 10.311250202357769, 4.497659057378769, 4.273169003427029, 2.7512024715542793, 3.0930136051028967, 1.818783686030656, 2.747639687731862, 0.9860201936680824, 0.5403353401925415, 0.5272369086742401, 0.44247366953641176, 0.9874300367664546, 3.854102077893913, 7.165207592770457, 13.593054302036762, 15.388632752001286, 28.778245970606804, 61.506889164447784, 21.196982078254223, 16.626167446374893, 21.435392685234547, 34.939657151699066, 32.2281264513731, 26.48011028766632, 12.765716146677732, 2.5393864000216126, 0.08079145773081109, 0.04348352704255376, 0.03312082255433779, 0.025502656244498212, 0.04695472242019605, 0.062189444579416886, 0.02364914984354982, 0.03196140976797324, 0.026634568748704623, 0.04650719252822455, 0.03102969902101904, 0.018832680070772767, 0.03417882828216534, 0.0632525711262133, 0.02432222398056183, 0.045457706655724905, 0.09790955402422696, 0.01431345157470787, 0.08478571879095398, 0.024710005418455694, 0.0445543941896176, 0.026510837888054084, 0.03678977060189936, 0.05270357272820547, 0.016161397434188984, 0.030575962919101585, 0.05347889440599829, 0.05427007949037943, 0.04103898907487746, 0.0037899273957009427, 0.04337260194006376, 0.022126791591290385, 0.06698313969536684, 0.011061248205805896, 0.026862057420657948, 0.09477420273469761, 0.06885281749418937, 0.03165696965879761, 0.050076477564289235, 0.03738921812328044, 0.013776001214864664, 0.047205679657054134, 0.022599367111979518, 0.011924546852242202, 0.05022696284868289, 0.051265479778521694, 0.07176156141213141, 0.1231930559151806, 0.20559712633257732, 0.13484616967616603, 0.16521114186616614, 0.11008099856553599, 0.13369895779760554, 0.13543717155698687, 0.11634969734586775, 0.13503460097126663, 0.12061816712957807, 0.08794789129751734, 0.17104108294006437, 0.1428425734047778, 0.27761150035075843, 0.18798480421537533, 0.13132291263900697, 0.20721607696032152, 0.1290799494017847, 0.17366680142004043, 0.1573984048445709, 0.14593293570214882, 0.1072395897062961, 0.14419308921787888, 0.07420391746563837, 0.11707050827681087, 0.22159564832691103, 0.2337870269548148, 0.10018108994700015, 0.1748838197090663, 0.12460408644983545, 0.10049594609881751, 0.09274848838686012, 0.06388453955878504, 0.10138695375644602, 0.15571453113807365, 0.11756785854231566, 0.17513686238089576, 0.1731381844729185, 0.16168795904377475, 0.15683322970289737, 0.21589837357169017, 0.11498675055918284, 0.18144299509003758, 0.19148110644891858, 0.10176686657359824, 0.20084070187294856, 0.17469212296418846, 0.16472058225190267, 0.1329192129196599, 0.11701199735398404, 0.2195402851793915, 0.13416717876680195, 0.2494743961142376, 2.879708488471806, 13.53993695229292, 34.82976324856281, 47.30934999883175, 50.76078459620476, 47.438231483101845, 58.32189626991749, 52.10513725876808, 53.2693225890398, 50.700679421424866, 32.064868211746216, 26.54720328748226, 18.279466331005096, 11.777821406722069, 5.60143475420773, 1.3181899976916611, 0.5950480699539185, 1.060356970410794, 1.4499456714838743, 2.20786202698946, 4.7677333652973175, 5.787026295438409, 4.191213101148605, 10.392431896179914, 7.662968533113599, 8.789110779762268, 37.96784766018391, 24.033529870212078, 13.011892586946487, 15.194560065865517, 13.460185881704092, 10.336190164089203, 9.599569290876389, 9.610063377767801, 5.189138352870941, 2.770722499117255, 2.3928914358839393, 2.145191039890051, 1.5185861382633448, 0.5542398034594953, 0.9929174766875803, 1.2112167128361762, 2.2652151994407177, 1.973420069552958, 3.3589720213785768, 6.038847332820296, 11.697230581194162, 10.505434982478619, 17.978020906448364, 26.03351265192032, 12.627712301909924, 9.869287367910147, 13.3649867400527, 10.622191317379475, 11.408645566552877, 7.157528204843402, 8.928408455103636, 5.9305716678500175, 4.545292826369405, 2.6559938304126263, 0.8907460060436279, 1.083992295898497, 3.1483630975708365, 4.224746776744723, 11.771942172199488, 15.186176765710115, 35.29025673866272, 66.59252107143402, 21.40797335654497, 26.464918702840805, 30.377038680016994, 43.389921113848686, 38.887029737234116, 32.04938784241676, 13.936617616564035, 2.468136423267424, 0.1258897385559976, 0.17636686825426295, 0.10929225143627264, 0.16336856730049476, 0.12559149909066036, 0.21565627015661448, 0.08888995129382238, 0.11733888371963985, 0.08504861718392931, 0.17150351515738294, 0.2605533547466621, 0.12197333620861173, 0.08831828235997818, 0.07314879869227298, 0.09327564330305904, 0.09245324719813652, 0.19073655421379954, 0.14745022694114596, 0.17275854625040665, 0.12244454803294502, 0.2172276342753321, 0.2038322397856973, 0.2390568543341942, 0.12362060719169676, 0.14687547809444368, 0.1520199270453304, 0.19934022770030424, 0.2324739599134773, 0.14231083943741396, 0.05382408584409859, 0.12552795640658587, 0.13605388143332675, 0.16159723891178146, 0.15219914086628705, 0.08785927886492573, 0.23837296525016427, 0.17827245115768164, 0.11608602711930871, 0.22429516597185284, 0.11191615165444091, 0.0898449617670849, 0.1489442741149105, 0.11084716956247576, 0.16106966097140685, 0.2912687690695748, 0.19929149828385562], [0.06328791962005198, 0.00799173561972566, 0.021822546295879874, 0.04298631407436915, 0.02595037909486564, 0.04682626036810689, 0.04980774217983708, 0.04435438539076131, 0.0278821950632846, 0.01220542562805349, 0.029430934810079634, 0.03573305992176756, 0.06011922734614927, 0.02273292215249967, 0.04387141794722993, 0.013581094681285322, 0.06379753758665174, 0.022362642412190326, 0.022587283092434518, 0.02382406106335111, 0.028717061104543973, 0.016118169187393505, 0.010464322131156223, 0.011727261735359207, 0.018176194789703004, 0.02068523652269505, 0.06474793932284229, 0.07441291367285885, 0.023392902949126437, 0.07934556109830737, 0.02996230512508191, 0.06261438349611126, 0.022781106090405956, 0.07914411253295839, 0.07490156596759334, 0.02570038293924881, 0.03973745500843506, 0.035906232660636306, 0.07353889377554879, 0.02220943530119257, 0.07173063611844555, 0.04283521280740388, 0.02731047603447223, 0.027043659101764206, 0.022277158132055774, 0.07559698802651837, 0.027614255632215645, 0.028920817749167327, 0.010870516252907692, 0.0586598644440528, 0.06758240167982876, 0.004665405613195617, 0.06905474845552817, 0.017117005336331204, 0.14972772973123938, 0.8662749035283923, 8.3385338075459, 22.562704794108868, 34.22936886548996, 37.35656686127186, 36.84961326420307, 36.42026670277119, 34.31462109088898, 48.86859633028507, 47.6959640532732, 39.62282985448837, 28.35901066660881, 19.24391157925129, 15.846901461482048, 8.008043691515923, 3.5202085319906473, 1.0290201706811786, 0.26440931658726186, 0.4784357117023319, 0.5051834264304489, 0.8064248494338244, 0.3410810383502394, 2.1660512080416083, 0.920189319876954, 0.8986767148599029, 3.6732742935419083, 9.481260739266872, 5.043153986334801, 0.4635025723837316, 3.0454658064991236, 2.79151379596442, 2.9162736888974905, 4.611721336841583, 2.59877388831228, 3.1341055501252413, 2.01972343493253, 1.6251425142399967, 2.1018800139427185, 0.8777216705493629, 1.087201104965061, 0.5467201257124543, 4.276256337761879, 2.796189682558179, 5.279500829055905, 4.1114031337201595, 10.97482094541192, 8.497687317430973, 2.541224076412618, 17.258254028856754, 11.257229391485453, 5.578518183901906, 2.776969838887453, 3.911963473074138, 3.080295450054109, 1.009328558575362, 1.5230569546110928, 0.41210278985090554, 1.216829961631447, 1.402025017887354, 1.828488721512258, 3.429997335188091, 5.426105512306094, 9.427036698907614, 14.054970815777779, 14.466281644999981, 48.601592257618904, 42.27486714720726, 13.06810962036252, 17.25655362010002, 29.78240668773651, 31.32431074976921, 15.646445117890835, 8.219292405992746, 0.6372570956591517, 0.03156747407047078, 0.037256733630783856, 0.01403191135977977, 0.02584441153885564, 0.05716675237636082, 0.02144287838746095, 0.0884331000270322, 0.1045139558846131, 0.010453079521539621, 0.03700856686918996, 0.024409849356743507, 0.001424532520104549, 0.03719429674674757, 0.06276663509197533, 0.045197331564850174, 0.050099038853659295, 0.023300336724787485, 0.09315050236182287, 0.04887303686700761, 0.0694093391939532, 0.017938267810677644, 0.0024754340392973972, 0.04942946950905025, 0.06096522374718916, 0.011177291344210971, 0.042082560030394234, 0.0497609497688245, 0.054105018425616436, 0.009507932190899737, 0.025086020104936324, 0.03164702116919216, 0.03741969441762194, 0.022944758929952513, 0.020061125578649808, 0.10457476746523753, 0.03125821000139695, 0.026092695188708603, 0.08854821455315687, 0.011528637041919865, 0.05866830637387466, 0.02381188427534653, 0.06023021924193017, 0.07726488329353742, 0.03597188675485086, 0.07301352001377381, 0.053133257679292, 0.034968766558449715, 0.029613041151606012, 0.042981089354725555, 0.019760776558541693, 0.02100479232467478, 0.06438726297346875, 0.055103051199694164, 0.01786613662261516, 0.04376211072667502, 0.018796333388308994, 0.04133185539103579, 0.0674410819192417, 0.01802877271984471, 0.027545363918761723, 0.020359799200377893, 0.03216498458641581, 0.015747911711514462, 0.027821992043755017, 0.0556174114899477, 0.011184248050994938, 0.04174221110588405, 0.027429761430539656, 0.040606929251225665, 0.0422964061726816, 0.03355470806127414, 0.05959399830317125, 0.06497013091575354, 0.036511361322482117, 0.042912385033559985, 0.0369588503963314, 0.07329812622629106, 0.03551238602085505, 0.04294991544156801, 0.035447659611236304, 0.060211424352019094, 0.02692664467758732, 0.05418290682428051, 0.02799684945784975, 0.04241562477545813, 0.04038271159515716, 0.03427111805649474, 0.09460725661483593, 0.04096606564417016, 0.01236163287103409, 0.05215867677179631, 0.052774440409848467, 0.04093184521479998, 0.0328099777107127, 0.04249981029715855, 0.013289368489495246, 0.0710343976970762, 0.02591145344922552, 0.041532368850312196, 0.04731648230517749, 0.02347355770325521, 0.08721329126274213, 1.4342818432487547, 10.840482953935862, 27.602307870984077, 38.49145196378231, 44.468003064394, 43.362969160079956, 44.25858110189438, 40.08027210831642, 49.1322185844183, 41.50221660733223, 28.737044781446457, 28.42719040811062, 27.8377166390419, 21.15989986807108, 10.438450276851654, 3.354937112890184, 1.2466546799987555, 0.5435760319232941, 0.23380899452604353, 0.47506496601272374, 0.06600587221328169, 0.1911124074831605, 0.5262380966451019, 0.0328173917660024, 0.9075639036018401, 2.5594847090542316, 4.961506817489862, 2.4590349616482854, 1.76770837046206, 2.7480517281219363, 4.738670149818063, 4.7669358830899, 3.9144017547369003, 3.3602459030225873, 2.721798224374652, 3.804408344440162, 2.454782039858401, 2.5613945815712214, 4.252731325104833, 1.6025518951937556, 2.875818684697151, 5.154989585280418, 3.9680116530507803, 7.177164126187563, 4.764241352677345, 7.918017972260714, 8.746589161455631, 1.497246720828116, 4.130688048899174, 8.231585696339607, 1.088501822669059, 3.1813992373645306, 1.4768986939452589, 1.0759064485318959, 0.6352091243024915, 0.5504708213265985, 0.3085142030613497, 0.5157085054088384, 0.8186277758795768, 2.453396776691079, 5.557764172554016, 9.927075617015362, 12.015455905348063, 18.08323346078396, 13.397221360355616, 46.385182589292526, 50.74799828231335, 11.977972816675901, 18.03610648959875, 32.42356136441231, 36.81975066661835, 20.382512882351875, 10.96742844209075, 1.155489378143102, 0.024425258197879884, 0.0541162025911035, 0.025800858602451626, 0.0400837225606665, 0.07128379642381333, 0.06769011699361727, 0.06478037117631175, 0.08382015497772954, 0.04236675435095094, 0.027599106542766094, 0.05651450846926309, 0.03958334062190261, 0.03971524623921141, 0.039304879392147996, 0.03377619832463097, 0.011135206004837528, 0.0324326512782136, 0.06226533660083078, 0.04693564180342946, 0.04600935244525317, 0.05243859261099715, 0.07150146091589704, 0.045206111171864904, 0.06185925936733838, 0.04011898199678399, 0.07531800729339011, 0.01315799258009065, 0.05662685478455387, 0.04645714951038826, 0.030661243108625058, 0.02010355601669289, 0.07375491812126711, 0.022881609584146645, 0.036733404485858046, 0.06766855018213391, 0.10897338768700138, 0.017949195935216267, 0.017103088212024886, 0.026585041523503605, 0.004943565345456591, 0.06916589249158278, 0.05665032520482782, 0.023836039326852188, 0.040221023591584526, 0.06794577202526852, 0.07757144223432988, 0.013503481804946205, 0.12741951271891594, 0.11010993490344845, 0.09256577905034646, 0.12844346871133894, 0.22295202710665762, 0.13053803209913895, 0.15387289167847484, 0.1530274370452389, 0.07792555057676509, 0.10640111868269742, 0.13468096760334447, 0.09126769597060047, 0.23471450374927372, 0.14874196465825662, 0.13845149340340868, 0.12678717321250588, 0.1518663766910322, 0.14327716024126858, 0.09384706732816994, 0.09241916035534814, 0.18986889452207834, 0.12883551564300433, 0.08481644370476715, 0.07475652062566951, 0.15952136280247942, 0.14673156081698835, 0.10302439128281549, 0.13256200239993632, 0.1203629796509631, 0.1748198168934323, 0.06694535695714876, 0.18101195571944118, 0.13433493382763118, 0.158326861273963, 0.2475919682183303, 0.13160535920178518, 0.11865670050610788, 0.10919664055109024, 0.15412609762279317, 0.1270332100102678, 0.16338146582711488, 0.11839141981909052, 0.11331990172038786, 0.1422721438575536, 0.14475939242402092, 0.19769288250245154, 0.07350828018388711, 0.09609535918571055, 0.1475913982721977, 0.264830767409876, 0.12824386067222804, 0.06918831277289428, 0.25283525639679283, 0.1404776456183754, 0.2700243465369567, 1.280272426083684, 10.983547177165747, 31.583745628595352, 46.21540009975433, 51.10075995326042, 46.46015256643295, 45.69701291620731, 42.18086779117584, 55.69906800985336, 60.021358877420425, 47.9068299382925, 39.95345011353493, 27.153247967362404, 19.78310264647007, 12.010397426784039, 5.539856208488345, 1.9552426761947572, 0.6722628360148519, 0.7927918341010809, 1.0457249055616558, 2.228800803422928, 1.27650564070791, 5.311357844620943, 3.363450081087649, 3.4197635343298316, 10.587475430220366, 19.75402470678091, 12.107072789222002, 8.28367805108428, 9.923130478709936, 10.492844358086586, 11.566163264214993, 10.164077449589968, 7.777304872870445, 9.0585913695395, 4.437419939786196, 4.952170243486762, 4.882791666314006, 4.196989741176367, 3.8584117591381073, 3.711726092733443, 8.731336779892445, 7.178873559460044, 12.660034317523241, 9.344659969210625, 24.012347906827927, 19.191421195864677, 9.055024310946465, 29.742987602949142, 20.281987376511097, 12.445534877479076, 8.845421858131886, 8.717194888740778, 6.892153769731522, 3.750295448116958, 3.126612827181816, 1.4589027408510447, 1.7206652322784066, 1.7992380098439753, 2.7244637813419104, 4.87963498570025, 7.52797887660563, 14.691072832792997, 22.049067355692387, 20.344841703772545, 56.046365574002266, 53.048170655965805, 17.186593674123287, 26.750585474073887, 41.90884418785572, 43.79798501729965, 27.684337869286537, 12.418876457959414, 1.4576649572700262, 0.1280556371784769, 0.12159892270574346, 0.12392991950036958, 0.18501073645893484, 0.3050580807030201, 0.09152252721833065, 0.20030254090670496, 0.18275540904141963, 0.12163957755547017, 0.132243680418469, 0.14329062280012295, 0.13892870920244604, 0.12114414203097112, 0.16679742315318435, 0.16895067557925358, 0.21025678957812488, 0.15195424697594717, 0.13080925738904625, 0.09051204862771556, 0.18869431223720312, 0.14035833795787767, 0.21573832200374454, 0.14792530535487458, 0.19392605259781703, 0.13730937265791, 0.16282562690321356, 0.1688618553453125, 0.13311934046214446, 0.08822348041576333, 0.17717800597893074, 0.1661670280736871, 0.10626972143654712, 0.08208967439713888, 0.1486236960045062, 0.2176470961421728, 0.12926573865115643, 0.1405457450891845, 0.18787891458487138, 0.13842035288689658, 0.20294296875363216, 0.11335452290950343, 0.14525557751767337, 0.14323589683044702, 0.10040703680715524, 0.22433096717577428, 0.10922930989181623, 0.13095452537527308], [0.00828796015412081, 0.04030380645417608, 0.040437456118525006, 0.012278121776034823, 0.08918964536860585, 0.04722518329799641, 0.035023930395254865, 0.02507092296582414, 0.026925167803710792, 0.04256308951880783, 0.03503717773128301, 0.04995820519980043, 0.0412359328038292, 0.033942684312933125, 0.022272430651355535, 0.013699475584871834, 0.054854658083058894, 0.04490348932449706, 0.02219506732217269, 0.029651729309989605, 0.028687386329693254, 0.03413879683648702, 0.06641140396823175, 0.057157497794833034, 0.014739000907866284, 0.03568906169675756, 0.031455981225008145, 0.031340981731773354, 0.05928342434344813, 0.06333676778012887, 0.042405902640894055, 0.035366758093005046, 0.04873543897701893, 0.0194620379988919, 0.03332645683258306, 0.026313458147342317, 0.017330912705801893, 0.046053239348111674, 0.04730274515168276, 0.05882434292288963, 0.06522285446408205, 0.022420023415179458, 0.06326391856418923, 0.07183783935033716, 0.024197927232307848, 0.04876864637481049, 0.04343202570453286, 0.020008130668429658, 0.11125546952825971, 0.05383069466915913, 0.04763831093441695, 0.07346191821852699, 0.05889947795367334, 0.02301231106685009, 0.051415478956187144, 0.039400542227667756, 0.5348016496282071, 3.6325801396742463, 16.827144362032413, 28.194466196000576, 40.85280865430832, 31.389606446027756, 26.84519089758396, 19.798757806420326, 26.45619247108698, 26.628104746341705, 28.55568241328001, 26.81985765695572, 19.631899259984493, 19.833115562796593, 16.80225569754839, 12.570027597248554, 5.727685354650021, 2.942999554798007, 1.8083464773371816, 0.9987476700916886, 0.3746128437342122, 0.36225647083483636, 0.18724834138993174, 1.0914024920202792, 1.6108533809892833, 4.870425704866648, 0.8809737022966146, 1.1438490590080619, 2.043633651919663, 3.3400723105296493, 1.7295669671148062, 2.723719021305442, 1.3427998521365225, 2.6854664739221334, 2.74185283575207, 0.4576596734113991, 1.5239395759999752, 5.197376310825348, 1.9973214995115995, 3.07703569997102, 3.061937685124576, 2.8127444442361593, 4.378805235028267, 5.242840396240354, 5.206575617194176, 9.367266856133938, 1.395529385190457, 5.577691253274679, 8.002298399806023, 0.15891195565927774, 2.1379410289227962, 0.34704633231740445, 0.5862575978972018, 1.0244009247981012, 1.3932383456267416, 1.9898693868890405, 3.1157667841762304, 3.960416573099792, 7.7383270394057035, 8.437929823994637, 15.210201926529408, 18.919826969504356, 19.680608846247196, 21.63611501455307, 39.80976462364197, 33.082510605454445, 28.10317039489746, 27.04638060182333, 25.72512309998274, 17.092385329306126, 5.841890601441264, 1.269921069033444, 0.037574851521640085, 0.09393364627612755, 0.031638868676964194, 0.10848853518837132, 0.0647537800250575, 0.031379220890812576, 0.038529049343196675, 0.018771812829072587, 0.055050414375727996, 0.022770376490370836, 0.014065310788282659, 0.009598360102245351, 0.010030203775386326, 0.03284993123088498, 0.09359875213704072, 0.026123024908883963, 0.02919926970207598, 0.058015298054669984, 0.029601623209600803, 0.02246743180876365, 0.03996499006461818, 0.049693314140313305, 0.0635526808036957, 0.037711551412940025, 0.04392756141896825, 0.04281237692339346, 0.006456684786826372, 0.008782028271525633, 0.01674971830652794, 0.12658726831432432, 0.045355331094469875, 0.0684488590923138, 0.030749085563002154, 0.0650499266339466, 0.0454107435507467, 0.026238668215228245, 0.010868320423469413, 0.017297792510362342, 0.025284988041676115, 0.04753393528517336, 0.0653091142885387, 0.0650103998486884, 0.009981263774534455, 0.09196530736517161, 0.07602382684126496, 0.0020574754853441846, 0.036169290615362115, 0.027968052272626664, 0.016473414871143177, 0.04778081442054827, 0.05898376366531011, 0.06742771583958529, 0.009723052044137148, 0.015504988223256078, 0.034130737112718634, 0.028159101493656635, 0.020599813469743822, 0.05542727325519081, 0.017418302450096235, 0.07013655485934578, 0.0722654203127604, 0.03925738565158099, 0.038745596903027035, 0.02849998290912481, 0.06102493694925215, 0.012710460832749959, 0.031082792265806347, 0.004926274232275318, 0.01727124774333788, 0.024532134884793777, 0.023835221109038685, 0.036232131969882175, 0.05601639008091297, 0.04876960374531336, 0.027269912097835913, 0.00497733213705942, 0.05352518957806751, 0.048858821028261445, 0.019018827406398486, 0.04906272981315851, 0.019807542994385585, 0.013556883968703914, 0.02180937874072697, 0.025367026901221834, 0.02730927004449768, 0.07007573585724458, 0.010716115211835131, 0.051430845123832114, 0.06985737374634482, 0.025631713870097883, 0.03042878019186901, 0.03038832757738419, 0.038537379950867034, 0.08891050136298873, 0.06622788569075055, 0.005258293012957438, 0.03569370754121337, 0.047078542338567786, 0.01687240644969279, 0.053547787974821404, 0.05719464970752597, 0.05420581321232021, 0.09072759799892083, 0.025933003562386148, 0.8625041402410716, 5.842395024374127, 21.87034584581852, 33.22813779115677, 44.52788025140762, 35.83544388413429, 29.143106192350388, 26.790063455700874, 35.28155900537968, 32.51126825809479, 28.43687418848276, 25.855376310646534, 27.02681925147772, 26.185605190694332, 22.70809829235077, 14.04658181592822, 5.9494751784950495, 3.0656410614028573, 1.8065292248502374, 1.0755375120788813, 0.3616545890690759, 0.054718373794457875, 0.06065923626010772, 0.2458129363367334, 0.27606332092545927, 0.260988668887876, 1.3328186189755797, 0.630389676662162, 1.2745745130814612, 0.4858292837161571, 2.2165006259456277, 0.7197572593577206, 1.135367201641202, 0.9862483595497906, 1.284187047276646, 1.0654034558683634, 1.8565151863731444, 4.510704707354307, 2.5656636524945498, 2.748820949345827, 4.158941907808185, 3.4057128382846713, 3.9400282921269536, 3.8180087646469474, 4.507647771388292, 3.727274858392775, 1.631403628271073, 1.6881636762991548, 1.214802770409733, 0.9853767219465226, 0.9565705864224583, 0.26083813165314496, 0.19502864655805752, 0.5189208767842501, 0.7711673725862056, 1.5110430680215359, 3.7653687642887235, 8.124821875244379, 11.001378670334816, 12.233421709388494, 16.955292485654354, 17.724538408219814, 15.742014739662409, 14.919199291616678, 44.29668165743351, 36.88691206276417, 25.131408758461475, 28.5005359724164, 30.62804751098156, 22.799808271229267, 8.23922423645854, 2.043692311272025, 0.05799586491775699, 0.030450925878540147, 0.02656195702002151, 0.03833122616924811, 0.061325974311330356, 0.05417780455900356, 0.021311095224518795, 0.008493398690916365, 0.039404627750627697, 0.06846659642178565, 0.016367421339964494, 0.04313758974603843, 0.05405067466199398, 0.04629307550203521, 0.03627931029768661, 0.016137908460223116, 0.024277839838759974, 0.15335626783780754, 0.024889811102184467, 0.03924492499209009, 0.03366495780937839, 0.10867718912777491, 0.05263974431727547, 0.007832482788217021, 0.018153117707697675, 0.026125713338842615, 0.004218707854306558, 0.013214318805694347, 0.055809019177104346, 0.02569922333350405, 0.060901977922185324, 0.023281629037228413, 0.04162907069257926, 0.026114408574358094, 0.003355832927809388, 0.04908626702672336, 0.032125936486409046, 0.05597528252110351, 0.06007000440149568, 0.02641631795995636, 0.013458539197017672, 0.0564690259488998, 0.04189943880192004, 0.05347171041648835, 0.048692283089621924, 0.05776427031378262, 0.031190945446724072, 0.024562679827795364, 0.056240322010125965, 0.09572366194333881, 0.18377342785242945, 0.13171616184990853, 0.15438549307873473, 0.10324768867576495, 0.13449667749227956, 0.11746253294404596, 0.1715309004066512, 0.1232199439255055, 0.14972024888265878, 0.15200799331068993, 0.12392382646794431, 0.1314375744550489, 0.09727604934596457, 0.14685244183056056, 0.25385944987647235, 0.13937610550783575, 0.11753302213037387, 0.23247658711625263, 0.20570121996570379, 0.1344736263854429, 0.15101955650607124, 0.17317002260824665, 0.12433510244591162, 0.14505044789984822, 0.12254006986040622, 0.17016904457705095, 0.08901026085368358, 0.2239988709334284, 0.09558165940688923, 0.14102961053140461, 0.19807323318673298, 0.1241991261485964, 0.17073546652682126, 0.12401767104165629, 0.08325205577421002, 0.20309092331444845, 0.14232416840968654, 0.18114193546352908, 0.1490997985820286, 0.15256387676345184, 0.11299761667032726, 0.10365699796238914, 0.08364730136236176, 0.1559459773125127, 0.17896016972372308, 0.07725095318164676, 0.1822565373731777, 0.13414265820756555, 0.14800302305957302, 0.14656477054813877, 0.1560259363031946, 0.09245059030945413, 0.18748057424090803, 0.17600919760297984, 0.8621764078270644, 5.521039143204689, 23.249324150383472, 39.02221888303757, 56.13959737122059, 42.32765011489391, 39.01614300906658, 27.86276489496231, 38.582928255200386, 34.11221735179424, 38.61153692007065, 39.01414431631565, 28.57909105718136, 27.438418865203857, 22.879746481776237, 17.320690378546715, 8.194721974432468, 4.250555466860533, 2.4119884986430407, 1.6480232239700854, 0.9980165655724704, 1.0056479810737073, 0.7515991351101547, 2.102425522170961, 3.078387714922428, 9.253806844353676, 4.674265030771494, 3.6154568335041404, 7.982403617352247, 8.04256958886981, 6.568597806617618, 9.239213727414608, 7.446368280798197, 7.0404075644910336, 8.193673230707645, 4.66252651065588, 5.163324438035488, 13.283566609025002, 4.868530556559563, 8.367065526545048, 7.316382955759764, 10.363599043339491, 10.858512986451387, 15.222398322075605, 15.75836906209588, 13.659881316125393, 5.288241310045123, 12.157468535006046, 16.45740520209074, 4.391274265944958, 3.852824396453798, 2.735824934206903, 1.958093591965735, 1.944190019275993, 2.017491767182946, 2.6911212829872966, 4.809353007003665, 6.3967672269791365, 10.929403882473707, 12.362854164093733, 23.071218207478523, 27.723310478031635, 27.955519817769527, 28.858465366065502, 49.721452966332436, 41.608519703149796, 34.37863625586033, 38.181240409612656, 35.72042405605316, 26.073710694909096, 8.944342900067568, 2.199282324872911, 0.14789116656174883, 0.16270579973934218, 0.06048059760360047, 0.13205306720919907, 0.12029198580421507, 0.1284859492443502, 0.07745781942503527, 0.12484203383792192, 0.11413042346248403, 0.1348411972867325, 0.09203926238114946, 0.1836017839377746, 0.14020226430147886, 0.11586880791583098, 0.15665440179873258, 0.08620509106549434, 0.136268065252807, 0.2847633697092533, 0.09535666249576025, 0.11729684105375782, 0.1613672325038351, 0.1446993081481196, 0.151821669714991, 0.11987446836428717, 0.04585241789754946, 0.1250990989501588, 0.1468573696911335, 0.12423218882759102, 0.10800074378494173, 0.15276936261216179, 0.11085556325269863, 0.14448988891672343, 0.13830499345203862, 0.18277605558978394, 0.1797474845079705, 0.1722245116252452, 0.15252844663336873, 0.19107199012069032, 0.16805583843961358, 0.07429624063661322, 0.09572653405484743, 0.1751704074558802, 0.15205470408545807, 0.3063615591963753, 0.14817037736065686, 0.16478581703267992, 0.0872664587222971, 0.06844082905445248], [0.05068923179351259, 0.057644072076072916, 0.029249570616229903, 0.021266108087729663, 0.08587387055740692, 0.018602460295369383, 0.03504487009195145, 0.04427084182680119, 0.03655016822449397, 0.008130290880217217, 0.010617356692819158, 0.010217946728516836, 0.0241166249543312, 0.06866380732390098, 0.049007361885742284, 0.06665335895377211, 0.0993808098428417, 0.015911835434962995, 0.012734387673845049, 0.04550937868771143, 0.049066748542827554, 0.05022112585720606, 0.06078162754420191, 0.039589775042259134, 0.04199183618766256, 0.017057965633284766, 0.08632508150185458, 0.050803121775970794, 0.07462496752850711, 0.049675480331643485, 0.027763260331994388, 0.028407468635123223, 0.012765184947056696, 0.020451909003895707, 0.01775758824805962, 0.035440661158645526, 0.013280472921906039, 0.055229353602044284, 0.0426956445153337, 0.01365220263323863, 0.03421724926738534, 0.08360560750588775, 0.010391802243248094, 0.05695630155969411, 0.007739204102108488, 0.12210917891934514, 0.06675172320683487, 0.04543272967566736, 0.038842888752697036, 0.039774833276169375, 0.020123905705986544, 0.026531631010584533, 0.07944149110699072, 0.05796126228233334, 0.06060959029127844, 0.0713069069024641, 0.013498734842869453, 0.0530286408320535, 2.4369068490341306, 10.992263909429312, 23.805194422602654, 42.91809283196926, 42.77552828192711, 47.291441559791565, 26.223449259996414, 15.960800349712372, 20.539165176451206, 35.73748134076595, 34.40266236662865, 23.543069288134575, 21.19495488703251, 20.263318978250027, 20.792235396802425, 11.675925124436617, 11.823982279747725, 7.720579616725445, 4.615194350481033, 2.6863221405074, 1.6050234250724316, 0.7020812015980482, 1.001927861943841, 0.5341141240205616, 0.6073602999094874, 0.1693779745255597, 0.5521794233936816, 1.135616444516927, 2.92048457544297, 0.42026579088997096, 0.5000115477014333, 0.27227079786825925, 2.2594121983274817, 0.4335856792749837, 2.0417135674506426, 3.7267915718257427, 1.9411275023594499, 2.0939344028010964, 3.759937430731952, 2.133376761339605, 4.9011370819061995, 2.1188947884365916, 2.4984329100698233, 3.3120578387752175, 0.6586476322263479, 0.24192908458644524, 1.284898677840829, 0.35209940804634243, 1.028309133835137, 0.8004474733024836, 1.1190981371328235, 1.9709004485048354, 4.415110861882567, 5.8181418757885695, 8.321343529969454, 12.517658807337284, 9.751141257584095, 12.725339513272047, 19.24543909728527, 14.828730896115303, 14.341022316366434, 18.659379445016384, 23.09869833290577, 30.343340188264847, 29.106816239655018, 24.9788773432374, 12.948976512998343, 3.8531839521601796, 0.4837787296855822, 0.03511714414344169, 0.03194247758074198, 0.04355582706921268, 0.005750900954808458, 0.05277301919704769, 0.06088577312766574, 0.02613840963022085, 0.027504315730766393, 0.0684662772982847, 0.007268823019330739, 0.07466562979971059, 0.0843794597312808, 0.07226064088172279, 0.039515181779279374, 0.06964690808672458, 0.0379995603725547, 0.08927675866289064, 0.04051911091664806, 0.05563589838857297, 0.02061537259578472, 0.03248218592489138, 0.06622273518587463, 0.05225642133154906, 0.030472878606815357, 0.07015656316070817, 0.07333881076192483, 0.06467353901825845, 0.004074877315360936, 0.03544586361385882, 0.035202884464524686, 0.028470126308093313, 0.03930448605387937, 0.021091195012559183, 0.05265608269837685, 0.06702657759888098, 0.048691069678170606, 0.024963012838270515, 0.05293525638990104, 0.01143798555858666, 0.015443402953678742, 0.060918390518054366, 0.0664789171423763, 0.050246444225194864, 0.0399274707888253, 0.026359085386502557, 0.0357559588883305, 0.11008004861650988, 0.06754107889719307, 0.08649753435747698, 0.0379722493380541, 0.031963829169399105, 0.05377065121138003, 0.009897121854010038, 0.03472589130979031, 0.021067904563096818, 0.03226978697057348, 0.05438945023342967, 0.033099560023401864, 0.033353819817421027, 0.03608502716815565, 0.01779683672793908, 0.036618794620153494, 0.05421726826170925, 0.02085763742798008, 0.0640493854007218, 0.09042059376952238, 0.04825272386369761, 0.026246175038977526, 0.03143488567729946, 0.04880048079940025, 0.022860285826027393, 0.045780403597746044, 0.0354136210080469, 0.014820137130300282, 0.04849695353186689, 0.026443226379342377, 0.012599747242347803, 0.026407840778119862, 0.04412785223394167, 0.03311076645331923, 0.03254923896747641, 0.037579764539259486, 0.01982431367650861, 0.015176256692939205, 0.023660378537897486, 0.031592658851877786, 0.05703578928660136, 0.05998155895213131, 0.055806826130719855, 0.04797959125426132, 0.033445875815232284, 0.015865694258536678, 0.05860619232407771, 0.06545469397678971, 0.05830334783240687, 0.036512233346002176, 0.1222840734408237, 0.05259097779344302, 0.006101486414991086, 0.05112510254548397, 0.016195103926293086, 0.04489218641538173, 0.01012618480672245, 0.017748242753441446, 0.03844074861262925, 0.0664184989000205, 0.14191604655934498, 3.5655408119782805, 14.755905903875828, 31.68349787592888, 45.524927750229836, 47.84038670361042, 43.60359504818916, 26.67746029794216, 20.462088212370872, 26.247538067400455, 35.229327008128166, 24.560624286532402, 21.918766647577286, 28.74612059444189, 29.229775741696358, 27.371992729604244, 18.731573671102524, 11.918482258915901, 8.525706063956022, 4.85525406897068, 3.196504614315927, 0.9374459157697856, 0.9010807983577251, 0.5123153468593955, 0.14618207467719913, 0.25027677649632096, 0.09919176256516948, 0.26008755317889154, 0.5083018122240901, 0.6023807858582586, 0.4933731851633638, 0.16659192246152088, 0.11398758229915984, 0.7091220456641167, 0.2362795892986469, 0.8603750076144934, 0.6768642703536898, 0.11739294917788357, 1.1129739345051348, 1.2653817376121879, 1.1897869314998388, 1.1282609892077744, 0.7441955292597413, 0.2524981729220599, 0.596746935043484, 0.08948876056820154, 0.2577644231496379, 0.49902912229299545, 0.17953567556105554, 0.3155921248253435, 0.4798522935016081, 1.0387792345136404, 1.7477830708958209, 5.299603650346398, 7.850336004048586, 12.487982399761677, 17.316385209560394, 16.562266275286674, 15.959136039018631, 16.5998462587595, 13.880215343087912, 11.755216419696808, 20.253582000732422, 28.527979999780655, 34.499861150979996, 33.95387224853039, 30.567433163523674, 16.40765257179737, 4.901444390416145, 0.744478435954079, 0.024556417956773657, 0.044980821112403646, 0.06817404922912829, 0.08797859394690022, 0.05201799896894954, 0.06797657115384936, 0.01671437537879683, 0.04497684320085682, 0.01482832394685829, 0.08186237682821229, 0.05647864789352752, 0.01551143470351235, 0.04895094010862522, 0.01740337786031887, 0.10975941113429144, 0.006498199600173393, 0.030003969295648858, 0.06945064713363536, 0.017379102209815755, 0.05734881975513417, 0.040206848570960574, 0.025455906506977044, 0.04396708820422646, 0.03661922877654433, 0.0814742484362796, 0.0615691946586594, 0.05824299638334196, 0.03242875129217282, 0.11360577700543217, 0.06312495141173713, 0.027776427887147292, 0.036924911983078346, 0.027266830329608638, 0.07326205784920603, 0.06154865201096982, 0.0638794781116303, 0.05224046515650116, 0.04302471279515885, 0.018689250755414832, 0.0445506092364667, 0.04075774108059704, 0.020858335046796128, 0.005655977947753854, 0.03438146428379696, 0.035424801462795585, 0.012348346572252922, 0.011941151478822576, 0.028378389433783013, 0.039465320587623864, 0.12189063869300298, 0.1712285791290924, 0.17381717538228258, 0.06916682759765536, 0.15513133665081114, 0.11276829303824343, 0.11932835899642669, 0.21428012056276202, 0.16929853503825143, 0.16917717905016616, 0.11894014896824956, 0.07367688129306771, 0.11150774778798223, 0.12562124436954036, 0.12325428309850395, 0.18283017299836501, 0.20416910061612725, 0.1993008641875349, 0.1617207916569896, 0.0771208324295003, 0.12764806451741606, 0.23916312988149002, 0.12479389813961461, 0.09945950718247332, 0.15339276666054502, 0.09362589989905246, 0.24664464639499784, 0.14126993279205635, 0.12949875817866996, 0.21046065754489973, 0.1357302605174482, 0.11901227830094285, 0.08389108203118667, 0.27731009933631867, 0.14050571364350617, 0.10448240718687885, 0.21932969335466623, 0.18198872596258298, 0.0871711150102783, 0.17867763410322368, 0.19720980373676866, 0.1605323312105611, 0.17095184710342437, 0.17282321699894965, 0.12478450255002826, 0.19343221269082278, 0.15355534153059125, 0.232316312904004, 0.08778303061262704, 0.08753230344154872, 0.10629725511535071, 0.16428467439254746, 0.15218382293824106, 0.14172990107908845, 0.15233563666697592, 0.1782849192386493, 0.20233958784956485, 0.17966412648092955, 3.2051693368703127, 15.370404180139303, 33.720959946513176, 55.78653171658516, 56.64652056992054, 59.13687273859978, 35.330162197351456, 24.46330390870571, 30.099915750324726, 44.87728290259838, 45.19199341535568, 34.552001953125, 34.68705430626869, 27.093146592378616, 28.55432588607073, 17.65860054641962, 15.69911789149046, 11.479291375726461, 6.949976217001677, 4.027147404849529, 2.3303007194772363, 1.463490875903517, 1.0608357447199523, 1.267817763146013, 1.4537204126827419, 0.6495614885352552, 1.4019477157853544, 3.059675144031644, 5.75583946891129, 2.7762160543352365, 3.924583070911467, 2.8097095945850015, 6.030381387099624, 3.7870515882968903, 6.302121905609965, 8.762690797448158, 6.878047976642847, 6.362360548228025, 10.888503827154636, 6.078324364498258, 9.533257149159908, 6.097080633044243, 5.111437272280455, 7.47723544947803, 0.956383862067014, 1.9603124354034662, 3.5299849323928356, 1.1157379299402237, 1.8694760533981025, 1.6987551329657435, 1.6537676844745874, 2.673002192750573, 6.423810375854373, 9.265904445201159, 11.632179971784353, 17.96660251915455, 18.193077966570854, 20.457758344709873, 27.940417528152466, 22.886890098452568, 23.188143633306026, 28.850888572633266, 34.72594901919365, 41.15203879773617, 39.11266162991524, 34.324979335069656, 18.584494963288307, 5.936967199668288, 0.8211311884224415, 0.1660187914967537, 0.15026406501419842, 0.16450334078399464, 0.18798624398186803, 0.10974514705594629, 0.17781595612177625, 0.11192612611921504, 0.12033645529299974, 0.19992287299828604, 0.1808980360510759, 0.1750437673763372, 0.1473615551367402, 0.17957812640815973, 0.10012246028054506, 0.15836987615330145, 0.12425357010215521, 0.15457149012945592, 0.25241436960641295, 0.15838514955248684, 0.12233162284246646, 0.1472884981194511, 0.08941908774431795, 0.14858510432532057, 0.0759082224976737, 0.21806648379424587, 0.17087810731027275, 0.15672380744945258, 0.1502538679051213, 0.23261202906724066, 0.21282859845086932, 0.07880431279772893, 0.11785242764744908, 0.13814001402352005, 0.15462476148968562, 0.18423105095280334, 0.1804565917700529, 0.11727118500857614, 0.1679511065594852, 0.08827616547932848, 0.14086069772019982, 0.15825574868358672, 0.15015632001450285, 0.05974577121378388, 0.1326528115896508, 0.09658908034907654, 0.16188498440897092, 0.18594333407236263, 0.17814544000430033, 0.14773785369470716], [0.08973535397672094, 0.03267693660745863, 0.015895014657871798, 0.04622177737473976, 0.036289429481257685, 0.019572117053030524, 0.016656268926453777, 0.024963549039966892, 0.06071364310628269, 0.0515330982307205, 0.07633149900357239, 0.0834311508515384, 0.013504487415048061, 0.13737192086409777, 0.01500961763667874, 0.05874555652553681, 0.08013455313630402, 0.04000978238764219, 0.02581473676400492, 0.04568766482407227, 0.05471430311445147, 0.042798854992724955, 0.032239752254099585, 0.09781314161955379, 0.06927184149390087, 0.024373469277634285, 0.08825476194033399, 0.023097056910046376, 0.07596608033054508, 0.029611562422360294, 0.08175279130227864, 0.04109699162654579, 0.023134444454626646, 0.010846273999050027, 0.054132307195686735, 0.017616685945540667, 0.09025848645251244, 0.026616965005814563, 0.04185672078165226, 0.02075513570162002, 0.050674822996370494, 0.08323192872921936, 0.025853705083136447, 0.04693043934821617, 0.02393857630522689, 0.035367422315175645, 0.02912351683335146, 0.05151924604433589, 0.048393743054475635, 0.060612206361838616, 0.03101013229752425, 0.03507360233925283, 0.04943149928294588, 0.06406305576092564, 0.13214555365266278, 0.03014704980159877, 0.01988076513953274, 0.08686048167874105, 0.08709587607881986, 0.058055155095644295, 4.1519692819565535, 13.985157161951065, 24.519278705120087, 38.0840378254652, 51.14641450345516, 39.180138409137726, 23.551162853837013, 23.229662105441093, 50.19507855176926, 37.68882103264332, 54.96804803609848, 38.36863495409489, 20.042771212756634, 22.33581706881523, 22.9033812135458, 21.04923650622368, 16.578516103327274, 13.441279996186495, 11.272460874170065, 7.913307650014758, 3.729205154813826, 2.412652038037777, 1.920610978268087, 1.2528323172591627, 1.0898625059053302, 0.27609778626356274, 0.3846396744484082, 0.23545631003798917, 0.1485088560730219, 0.03874721849570051, 0.02737887236435199, 0.14492567803245038, 0.5045226181391627, 0.5289756716229022, 0.33008980157319456, 0.7900781265925616, 0.9108197351451963, 0.9687995177228004, 0.811461954144761, 0.6006612593773752, 0.5526602163445204, 0.0362287403549999, 0.8196509897243232, 1.0398703697137535, 0.7113187434151769, 2.5293373642489314, 3.101517311297357, 5.2235032338649035, 6.949186334386468, 10.536466967314482, 12.637299187481403, 17.598236985504627, 19.665394462645054, 19.626843631267548, 14.966377560049295, 12.944591548293829, 15.363177917897701, 18.034928552806377, 22.548476457595825, 27.232355922460556, 24.534738175570965, 30.21784622222185, 18.995125629007816, 10.19384315237403, 2.4066274613142014, 0.1378136026323773, 0.0248445215402171, 0.03930954007955734, 0.060055205976823345, 0.04338006423495244, 0.09583391540218145, 0.04378663499664981, 0.0345442358229775, 0.004827467009818065, 0.03929719445295632, 0.06670678616501391, 0.0702176641789265, 0.010501013912289636, 0.04571124285575934, 0.017996888200286776, 0.04702435071521904, 0.022386877244571224, 0.03165563008224126, 0.008040142201934941, 0.04680924292188138, 0.04996569718059618, 0.03720279062690679, 0.018684803435462527, 0.034790755016729236, 0.011941101383854402, 0.056116453852155246, 0.051674440255737863, 0.04033295430417638, 0.004241247343088617, 0.12734673771774396, 0.022135517392598558, 0.027353121695341542, 0.03114359271421563, 0.07510581242968328, 0.007554557296316489, 0.039095356260077097, 0.0220995659037726, 0.04063894921273459, 0.04604917237884365, 0.03718738735187799, 0.034772702274494804, 0.04063555388711393, 0.08724830579012632, 0.04224395117489621, 0.033183415289386176, 0.031098215949896257, 0.02693983264180133, 0.07415063126245514, 0.05667503872246016, 0.018285884216311388, 0.04850752913625911, 0.050328989600529894, 0.03344961995026097, 0.00930398166019586, 0.09323768244939856, 0.038737848881282844, 0.03242478451284114, 0.03381807400728576, 0.07126484197215177, 0.0491034329024842, 0.018568816885817796, 0.007363717268162873, 0.09917038871208206, 0.04302666464354843, 0.08690901813679375, 0.0428795153129613, 0.008752988960623043, 0.013209041208028793, 0.041099800655501895, 0.047736159394844435, 0.04603034409228712, 0.06359046354191378, 0.01630588245461695, 0.06048387789633125, 0.1444881671341136, 0.06669647773378529, 0.027994207412120886, 0.02514559786504833, 0.05236464872723445, 0.11745356780011207, 0.04137023184739519, 0.046154019291861914, 0.026318927775719203, 0.014893220122758066, 0.06465776838012971, 0.046431345035671256, 0.05988202210573945, 0.045862822807976045, 0.009651181535446085, 0.0770725186157506, 0.038691820882377215, 0.05387919401982799, 0.009503854089416564, 0.0070925532054388896, 0.07974199412274174, 0.05695459833077621, 0.05658244466758333, 0.017392561057931744, 0.023755616493872367, 0.06491128602647223, 0.017518557324365247, 0.04014498685137369, 0.024160224274965003, 0.03325445737573318, 0.01817069176468067, 0.012892520790046547, 0.07376690380624495, 0.06102959392592311, 0.12738694727886468, 0.04829613208130468, 0.33946683746762574, 5.303329825401306, 19.613669738173485, 31.285055056214333, 47.57502794265747, 51.33241072297096, 36.81680582463741, 24.333924651145935, 29.88490428775549, 52.678914070129395, 37.469208016991615, 45.20678222179413, 30.029665119946003, 24.751444347202778, 32.07344435155392, 32.183915823698044, 28.06558471173048, 22.968585714697838, 14.462707936763763, 11.941291484981775, 7.494825180619955, 4.796848352998495, 3.16725283395499, 1.8252282589673996, 1.5376201481558383, 1.015774318948388, 0.12322051537921652, 0.37724711175542325, 0.09811126234126277, 0.22438766725827008, 0.04662408078729641, 0.07469376461813226, 0.09280836486141197, 0.26910449902061373, 0.39646956778597087, 0.5218948109541088, 0.5069088900927454, 0.37798908131662756, 0.14948149997508153, 0.36827888048719615, 0.37914273503702134, 0.3479129233164713, 0.48142914951313287, 0.36076546646654606, 0.5615494830999523, 0.9366668981965631, 1.7920168535783887, 3.144640722312033, 6.071725068613887, 9.100334029644728, 13.741392642259598, 17.91104570031166, 23.473156839609146, 23.996042981743813, 19.48931761085987, 14.058258589357138, 13.29386880621314, 17.2412271425128, 18.41822348535061, 24.858186319470406, 30.402172431349754, 27.747078202664852, 33.461164087057114, 22.641814649105072, 12.76089420542121, 3.082979768514633, 0.27920224936679006, 0.05245782536803745, 0.01853544807090657, 0.01817152111470932, 0.09317599513451569, 0.07260654107085429, 0.054414093247032724, 0.07504868932301179, 0.03476257195870858, 0.020834254210058134, 0.08999307217891328, 0.049913798793568276, 0.04411208901728969, 0.05147822754224762, 0.04087543456989806, 0.09122372372075915, 0.03533674193022307, 0.031567125261062756, 0.025672292649687734, 0.0156575162691297, 0.0762356432096567, 0.046474263435811736, 0.11465029790997505, 0.028109919367125258, 0.06579078297363594, 0.03621611642302014, 0.041706569463713095, 0.058865595201496035, 0.06284106508246623, 0.03895213289069943, 0.015794795035617426, 0.022036926784494426, 0.038757415604777634, 0.0657416602189187, 0.023368156034848653, 0.042338022103649564, 0.07683978110435419, 0.005831578437209828, 0.042179725714959204, 0.03204770298907533, 0.016977218110696413, 0.01979725311684888, 0.03794247437326703, 0.014997182952356525, 0.034480863832868636, 0.047034737071953714, 0.059390256501501426, 0.033119653671747074, 0.05835781405039597, 0.015603638203174341, 0.06625534515478648, 0.2213266643229872, 0.08929547562729567, 0.13015184813411906, 0.2502534136874601, 0.1828567567281425, 0.14778391137951985, 0.0895597469934728, 0.13244425324955955, 0.15691068023443222, 0.13403331016888842, 0.12306574048125185, 0.17558124556671828, 0.1333211749442853, 0.20929259131662548, 0.13217856438132003, 0.1394175915629603, 0.22467291913926601, 0.10612471320200711, 0.12318527078605257, 0.11957659997278824, 0.1307394212926738, 0.10376585618359968, 0.1615409247460775, 0.25922986795194447, 0.14384335954673588, 0.07521148683736101, 0.1332826426369138, 0.10866522570722736, 0.22581330325920135, 0.1432113762712106, 0.2194586192490533, 0.20300100470194593, 0.10452946677105501, 0.16184593259822577, 0.12087071256246418, 0.19336248049512506, 0.15015437558759004, 0.10574633663054556, 0.18603726028231904, 0.14767227752599865, 0.22511831164592877, 0.14924272138159722, 0.11580431528273039, 0.18948946410091594, 0.13539811974624172, 0.09125248194322921, 0.09863258397672325, 0.19564439164241776, 0.15129611041629687, 0.18622665636939928, 0.1685294770868495, 0.14455911645200104, 0.12868287070887163, 0.11404018572648056, 0.24732152960496023, 0.18302709446288645, 0.23141145677072927, 0.22072599967941642, 0.2302751544630155, 0.4923928080825135, 7.01190291903913, 20.670508928596973, 37.493458315730095, 53.0924116820097, 64.31395813822746, 49.89867925643921, 34.23042520880699, 31.333627849817276, 61.62840284407139, 44.20170195400715, 68.20181831717491, 46.52490869164467, 25.676613003015518, 33.89856241643429, 31.548793204128742, 29.25705447793007, 23.24137307703495, 18.862191662192345, 14.699003957211971, 10.012754369527102, 5.3974659740924835, 3.7084836792200804, 2.5779400812461972, 2.3269951343536377, 1.7292340099811554, 0.965455281548202, 1.2651659804396331, 0.743644202593714, 0.6724725372623652, 0.6644724227953702, 0.602699612500146, 0.3968417696887627, 1.5858045313507318, 2.2623161925002933, 1.8345100921578705, 2.8375618625432253, 2.771134776994586, 2.577485768124461, 2.0780828408896923, 1.6383453807793558, 1.5980684920214117, 0.9442684496752918, 1.4644459309056401, 1.5314631722867489, 1.2434826814569533, 2.845236025750637, 4.468565443530679, 7.070255437865853, 9.341087210923433, 14.826368372887373, 17.62130554765463, 25.572363696992397, 29.287770129740238, 25.70689357817173, 23.240983597934246, 21.61089386790991, 25.452943705022335, 28.752359859645367, 33.67248974740505, 39.6388041973114, 34.577851966023445, 38.86298842728138, 26.878319419920444, 13.42924414202571, 3.53228903375566, 0.36080860008951277, 0.08893508871551603, 0.1299263836699538, 0.16642715083435178, 0.1306988555006683, 0.14266763435443863, 0.15028111956780776, 0.21828865312272683, 0.14029527024831623, 0.14178104989696294, 0.15496981563046575, 0.15751407598145306, 0.14769651606911793, 0.12603172624949366, 0.1191221087356098, 0.20147615839960054, 0.11445935073425062, 0.12602743663592264, 0.15319686935981736, 0.18978611537022516, 0.20513485738774762, 0.13268203736515716, 0.17375281633576378, 0.08585594026953913, 0.24250907299574465, 0.17010713461786509, 0.18040096038021147, 0.14187280903570354, 0.18895017507020384, 0.17282695742323995, 0.08028990690945648, 0.0893885335244704, 0.16639972105622292, 0.2417703391984105, 0.15438446891494095, 0.10906067909672856, 0.19780539209023118, 0.12223984886077233, 0.1171389788214583, 0.15472211642190814, 0.1228692420409061, 0.07410445483401418, 0.1076200146053452, 0.11856244775117375, 0.11448209756053984, 0.1353456053766422, 0.14328459656098858, 0.2543692459585145, 0.13965366873890162, 0.19730521424207836, 0.10801831784192473], [0.023275155654118862, 0.011842184230772546, 0.03334290282509755, 0.027651216441881843, 0.06817925910581835, 0.034781515278154984, 0.033104380272561684, 0.015481269183510449, 0.01909806094772648, 0.038333248521666974, 0.04444254511327017, 0.03903052594978362, 0.037232302129268646, 0.03292321831395384, 0.05462421009724494, 0.04393932074890472, 0.023314326208492275, 0.02441518910927698, 0.020508058041741606, 0.12052680132910609, 0.01844551461545052, 0.11490417920867912, 0.03172377408191096, 0.08880927241989411, 0.03353451793373097, 0.03691836624057032, 0.03737017461389769, 0.07231239083921537, 0.03661330272734631, 0.013697705562663032, 0.009995598356908886, 0.013073217978671892, 0.03282341800513677, 0.04332449221692514, 0.023517140325566288, 0.04240700101945549, 0.025008135417010635, 0.06729534637997858, 0.029402727632259484, 0.07093158055795357, 0.06961816470720805, 0.018407798670523334, 0.021596822080027778, 0.041654092201497406, 0.060311447305139154, 0.04308233685151208, 0.009775754733709618, 0.11852980809635483, 0.04238176428771112, 0.04028573144751135, 0.026817792022484355, 0.037032853651908226, 0.0377101190679241, 0.028004686537315138, 0.1036115711031016, 0.03726651513716206, 0.013694072749785846, 0.0522078551875893, 0.029275874185259454, 0.005515930042747641, 0.08852635088260286, 0.7152881054207683, 9.149220306426287, 20.408999361097813, 40.08600600063801, 45.26209965348244, 45.535578578710556, 31.749849915504456, 22.412715442478657, 26.7472967505455, 42.70218841731548, 73.21036756038666, 44.87694852054119, 27.51226220279932, 17.245040237903595, 21.11787222325802, 26.856673881411552, 27.66543958336115, 20.073462165892124, 18.923615366220474, 16.440936885774136, 11.753687001764774, 11.26487648114562, 8.613056726753712, 6.413141023367643, 5.6522969249635935, 4.0431279223412275, 2.6852225745096803, 1.9451081450097263, 0.9496469423174858, 0.8650492317974567, 0.9178934118244797, 1.085502477362752, 0.7851490785833448, 0.46350138494744897, 0.7079160853754729, 1.0052973311394453, 1.1004198831506073, 0.9966570697724819, 1.7455644649453461, 2.1045142225921154, 3.196768225170672, 3.796153049916029, 6.329686101526022, 8.00910858437419, 9.737925566732883, 11.433548480272293, 12.617481350898743, 17.516180388629436, 13.329940270632505, 18.464166820049286, 15.442074034363031, 15.66138781607151, 14.530167616903782, 12.72420147433877, 19.112744517624378, 22.946829982101917, 30.13344705104828, 25.052321702241898, 23.323885649442673, 18.729291893541813, 11.16521067917347, 4.632612615823746, 0.82743558450602, 0.008087689748208504, 0.08382717569475062, 0.03632145315350499, 0.03650392129202373, 0.05781797211966477, 0.03313726112537552, 0.10594357721856795, 0.09869737346889451, 0.04407052132592071, 0.028312965405348223, 0.020023825236421544, 0.016625868702249136, 0.032844224115251563, 0.042573182727210224, 0.05594416426902171, 0.028943839170096908, 0.009794929974304978, 0.06248285266337916, 0.0533030313818017, 0.09113317428273149, 0.051547429102356546, 0.051147715785191394, 0.024254853669845033, 0.06694059236906469, 0.036100975921726786, 0.04548535907815676, 0.04788956503034569, 0.055542469417559914, 0.057327512695337646, 0.020273159025236964, 0.02948829725937685, 0.056838600648916326, 0.08287133401609026, 0.0171469064662233, 0.019894929027941544, 0.04084722182597034, 0.005649129780067597, 0.021511987179110292, 0.04004285619885195, 0.04780992887390312, 0.10622900721500628, 0.10729041197919287, 0.027888948607142083, 0.02813434159179451, 0.06868454292998649, 0.06245436903554946, 0.03479273655102588, 0.0504849964636378, 0.02276187889947323, 0.023104582287487574, 0.050293437016080134, 0.04114670067792758, 0.036103016827837564, 0.01210900580190355, 0.040781578863970935, 0.03407051553949714, 0.023950543436512817, 0.022926144010853022, 0.041982607581303455, 0.0841786568344105, 0.035304970588185824, 0.08241662013460882, 0.043016181807615794, 0.031351713187177666, 0.030479656270472333, 0.044599561297218315, 0.026584776205709204, 0.04105192099814303, 0.05472712000482716, 0.0430333328404231, 0.013756009611824993, 0.10929499738267623, 0.01848565552791115, 0.04795371256477665, 0.029920258748461492, 0.01296909187658457, 0.006581508923773072, 0.058804772488656454, 0.08435494659352116, 0.07350445070187561, 0.031135918907239102, 0.026101949770236388, 0.029112865158822387, 0.01041703804730787, 0.02194400247390149, 0.06006299481668975, 0.03120805195067078, 0.04267787007847801, 0.03230638598324731, 0.051079193290206604, 0.03926005738321692, 0.03360872527991887, 0.035837287141475827, 0.035707036513485946, 0.026819890445040073, 0.06568997705471702, 0.040769196129986085, 0.03488508198643103, 0.01913098447403172, 0.12244820682099089, 0.009596873951522866, 0.04127897736907471, 0.02858694406313589, 0.0013834083779329376, 0.035616205059341155, 0.029209910244389903, 0.10263022180879489, 0.04325617010181304, 0.001735497498884797, 0.025983963132603094, 0.03328221740957815, 0.018803483981173486, 0.052844187448499724, 1.4947105944156647, 12.182165309786797, 24.622847847640514, 44.849270805716515, 51.38902768492699, 46.97793558239937, 33.04816424846649, 29.601561091840267, 34.44666400551796, 51.23083837330341, 66.11292600631714, 31.93030223250389, 22.777322977781296, 25.158489905297756, 30.466793663799763, 32.838666290044785, 38.35743695497513, 29.32405438274145, 26.94673664867878, 22.229846455156803, 13.841311130672693, 11.835807245224714, 9.32266104966402, 7.4073766730725765, 6.376195605844259, 3.872987302020192, 3.1228790525346994, 1.8085207929834723, 1.2119189626537263, 1.3071030238643289, 1.203287725802511, 0.8492607227526605, 0.6628140492830426, 0.42705617495812476, 0.7175875164102763, 1.0296160262078047, 1.5051535028032959, 1.054016298148781, 2.177571477368474, 2.1290649427101016, 3.28939585480839, 3.44461087603122, 6.40862544067204, 8.214251976460218, 11.579168066382408, 13.023103885352612, 17.576874531805515, 23.18608034402132, 22.20990512520075, 21.384876295924187, 19.31641548871994, 18.201072737574577, 14.513129331171513, 13.684480246156454, 19.31612480431795, 26.385615058243275, 33.03728923201561, 31.115793138742447, 28.984077125787735, 22.76911921799183, 15.270113311707973, 6.744178785011172, 1.5251312870532274, 0.04765234494698234, 0.02467501130013261, 0.027095286604890134, 0.028389772123773582, 0.08652125339722261, 0.016540005926799495, 0.019835690800391603, 0.041409751211176626, 0.01385344618029194, 0.02301221087691374, 0.030986290803411976, 0.027448489527159836, 0.03393078026419971, 0.02611419706227025, 0.049001888546627015, 0.06015253493387718, 0.011165442956553306, 0.03968912635173183, 0.06074384851672221, 0.08981944672996178, 0.050226487874169834, 0.014937305550120072, 0.11367600644007325, 0.06433791757444851, 0.024496799378539436, 0.03780006736633368, 0.011523856683197664, 0.027328335818310734, 0.07352676708251238, 0.02243277536763344, 0.10009786550654098, 0.04327874994487502, 0.06178011302836239, 0.05856599389517214, 0.024435653831460513, 0.055737602306180634, 0.09456433821469545, 0.04010614655271638, 0.05336723457730841, 0.04861454312049318, 0.035827646643156186, 0.09497136910795234, 0.013097683804517146, 0.0537940288631944, 0.017305920882790815, 0.060426068303058855, 0.027208590290683787, 0.03812267525063362, 0.013835290465067374, 0.008966890763986157, 0.029878640962124337, 0.05458928833832033, 0.14228130195988342, 0.0932684370491188, 0.11692213069181889, 0.19007872935617343, 0.12475180352339521, 0.1263224403373897, 0.11646727580227889, 0.15651787631213665, 0.2372032217681408, 0.1792412210488692, 0.1610903668915853, 0.10754767747130245, 0.14650666038505733, 0.12908940436318517, 0.1688188553089276, 0.12326319629210047, 0.21553181199124083, 0.11110401203040965, 0.135784704471007, 0.23377007630188018, 0.15865564753767103, 0.22898896801052615, 0.09436877488042228, 0.3083658032119274, 0.14485499588772655, 0.11544985813088715, 0.15040470199892297, 0.14199110737536103, 0.09104987562750466, 0.12412791707902215, 0.06400699392543174, 0.12118902712245472, 0.04934939919621684, 0.22785468434449285, 0.2394779192400165, 0.10885748648433946, 0.13187480333726853, 0.21021321066655219, 0.14062945934711024, 0.13303436455316842, 0.19610692776041105, 0.13541116670239717, 0.11478539105155505, 0.1667970372363925, 0.15431892243213952, 0.09594433213351294, 0.08860755668138154, 0.23399733676342294, 0.11672930588247254, 0.09256352292140946, 0.07888509557233192, 0.13032016722718254, 0.19574783218558878, 0.14449904701905325, 0.26342983008362353, 0.1913007497205399, 0.06628089729929343, 0.15909390058368444, 0.1948255207389593, 0.16722210973966867, 0.2548677317099646, 1.6022955277003348, 13.1806206330657, 28.295213989913464, 50.048193633556366, 58.575684651732445, 60.191555544734, 42.57328413426876, 33.56633864343166, 38.546131029725075, 49.89564701914787, 83.10741528868675, 52.542182207107544, 39.61565583944321, 27.05774199217558, 31.077865473926067, 35.79603239893913, 40.05776211619377, 27.57753700017929, 26.64321843534708, 21.441103778779507, 16.773046664893627, 15.630777608603239, 11.608344800770283, 9.292907696217299, 7.2043749410659075, 6.003895858302712, 3.594481721520424, 2.7589390939101577, 1.497349077835679, 1.4902796759270132, 1.6251520137302577, 1.4519689441658556, 1.2129257898777723, 0.976993718650192, 1.2359062442556024, 1.5465773362666368, 1.693050570320338, 1.5482847508974373, 3.0333442194387317, 3.341393214650452, 4.087737528607249, 5.059387190267444, 8.408499453216791, 10.932286977767944, 12.857531569898129, 16.223278865218163, 18.342706337571144, 24.973280243575573, 21.96270179003477, 26.842048466205597, 24.999031461775303, 24.444430321455002, 23.888411857187748, 20.58664172887802, 29.556581005454063, 34.185245633125305, 42.734767869114876, 37.632872834801674, 34.40954379737377, 26.235067136585712, 15.519143398851156, 6.4042395260185, 1.453489693813026, 0.10815249814186245, 0.3256429417524487, 0.15865486086113378, 0.08081636420683935, 0.2410372457234189, 0.1496216026134789, 0.1700716748018749, 0.21714044676627964, 0.15932117588818073, 0.09153849823633209, 0.07558512850664556, 0.1056283871002961, 0.090462332154857, 0.11030374676920474, 0.1496027669054456, 0.20633688429370522, 0.14606350916437805, 0.11645408783806488, 0.20253478753147647, 0.20905741956084967, 0.15479532186873257, 0.11750418227165937, 0.19130113563733175, 0.13243522873381153, 0.10677870115614496, 0.12202463345602155, 0.16285491205053404, 0.12556813628179953, 0.21684038161765784, 0.09943195123923942, 0.19068542023887858, 0.258800609735772, 0.16554723086301237, 0.15142329968512058, 0.2589892933610827, 0.18091017758706585, 0.16250973916612566, 0.08380038416362368, 0.23302418820094317, 0.11422673196648248, 0.20075292064575478, 0.2615075191715732, 0.15817239065654576, 0.11308821805869229, 0.21775352011900395, 0.08914736521546729, 0.12249298801179975, 0.11488963311421685, 0.12454944953788072, 0.11962114367634058, 0.16404841910116374, 0.16326779848895967], [0.08237487432779744, 0.014799848668189952, 0.004636167777789524, 0.06063133892894257, 0.05407337324868422, 0.03220202517695725, 0.0826183136086911, 0.03544975617842283, 0.03996128674771171, 0.0572218642628286, 0.030391019718081225, 0.040952565977931954, 0.08210906671592966, 0.0362602556560887, 0.0331756635569036, 0.03321770993352402, 0.02114439401339041, 0.05445236951345578, 0.03378475899808109, 0.03147213406919036, 0.08594264538260177, 0.04717301773780491, 0.03945648903027177, 0.021801239236083347, 0.043651846135617234, 0.08225918092648499, 0.04477031834539957, 0.01538382426588214, 0.061652664007851854, 0.06514089167467318, 0.03352076964802109, 0.04375824784801807, 0.011469327382656047, 0.07935324974823743, 0.1428633535397239, 0.039191119285533205, 0.1366566092474386, 0.04704635910457, 0.03628276870585978, 0.03791496295889374, 0.1006141331163235, 0.006130579995442531, 0.025737737087183632, 0.0280925141487387, 0.03790145587117877, 0.03830353292869404, 0.017299792598350905, 0.03551253816112876, 0.043143103903275914, 0.05775684883701615, 0.036902246793033555, 0.04390513371617999, 0.04223412885039579, 0.029599676927318797, 0.04400532736326568, 0.1003885870159138, 0.020584139310813043, 0.07317300754948519, 0.044832955609308556, 0.04507118872425053, 0.022921754207345657, 0.06118685872934293, 0.1461628678953275, 2.200995795428753, 10.163189247250557, 26.77157174795866, 34.49591316282749, 52.102268412709236, 41.54417395591736, 33.09682443737984, 22.796918526291847, 43.25740322470665, 64.79592427611351, 43.69569070637226, 23.73898297548294, 21.065381839871407, 30.868356116116047, 22.315404564142227, 24.049965888261795, 20.213887430727482, 23.005776219069958, 27.103058360517025, 22.478294223546982, 24.76144541054964, 21.246748007833958, 15.515196360647678, 14.639947526156902, 12.561514154076576, 10.230782870203257, 7.879619607701898, 6.998470639809966, 9.394604489207268, 8.42925013974309, 8.841559365391731, 7.557401172816753, 7.95394029468298, 9.002208095043898, 8.12612995505333, 9.413758311420679, 9.232858568429947, 12.188811153173447, 12.2075298987329, 18.04427035152912, 18.161824643611908, 23.835824579000473, 24.679744094610214, 20.887728072702885, 23.463465459644794, 24.20259039849043, 22.585699260234833, 25.490650981664658, 24.372864961624146, 22.874821946024895, 28.79240781068802, 27.89173074066639, 32.86884427070618, 28.608055002987385, 24.515195824205875, 14.626503847539425, 8.844256270676851, 3.4298253944143653, 0.7770296861417592, 0.10974272023304366, 0.035615963861346245, 0.04925415567413438, 0.016066812568169553, 0.034037337827612646, 0.07563419931102544, 0.025338094274047762, 0.0603543731267564, 0.05191694443055894, 0.05426638730568811, 0.02282225261296844, 0.035219924175180495, 0.048042091220850125, 0.04045594672788866, 0.04549821307591628, 0.013635390205308795, 0.041315294365631416, 0.010375918427598663, 0.05840099220222328, 0.05612623906927183, 0.018718795654422138, 0.02536596563004423, 0.05376872533815913, 0.02706954150198726, 0.07923623532406054, 0.07594256167067215, 0.029265578741615172, 0.052177631223457865, 0.08801459553069435, 0.034015232959063724, 0.024666890349180903, 0.011011965889338171, 0.06548790508531965, 0.022091420833021402, 0.0281384382469696, 0.011753985545510659, 0.05023779820476193, 0.02056038130831439, 0.00810546047432581, 0.05658398833475076, 0.014266996840888169, 0.045781160588376224, 0.07312064903089777, 0.027740235200326424, 0.009615600192773854, 0.022219220518309157, 0.042898855681414716, 0.011461852100183023, 0.06295527418842539, 0.03439708278165199, 0.05406113152275793, 0.028413153486326337, 0.01517064976724214, 0.030887264183547813, 0.021761497227998916, 0.004858624688495183, 0.0159600601909915, 0.040236193090095185, 0.046008873760001734, 0.05429397293482907, 0.05242743813141715, 0.03531976159138139, 0.018893775522883516, 0.05014711518015247, 0.02394340954197105, 0.03840053905150853, 0.07760946245980449, 0.0242973768763477, 0.07227204027003609, 0.029006656404817477, 0.029958076738694217, 0.017957353993551806, 0.0196873410459375, 0.03437523395405151, 0.0696833104302641, 0.09368062586872838, 0.07093305001035333, 0.01592313463333994, 0.0070155502817215165, 0.02625451121275546, 0.0327962776646018, 0.04773491258674767, 0.05526463901333045, 0.014280610612331657, 0.07729827251750976, 0.05203904627705924, 0.0257029971544398, 0.013969456849736162, 0.02246011052193353, 0.039585863924003206, 0.08887092262739316, 0.04569073731545359, 0.018336320572416298, 0.025978224475693423, 0.041915921901818365, 0.04215322362142615, 0.0038599991239607334, 0.013185262796469033, 0.051388936044531874, 0.05247238259471487, 0.053508198107010685, 0.0756144878687337, 0.01872039312729612, 0.13976662361528724, 0.018713719364313874, 0.004950932088831905, 0.044815708097303286, 0.04673767019994557, 0.009270326190744527, 0.05718526153941639, 0.04462171440536622, 0.005941505814917036, 0.0980854059162084, 0.07622891935170628, 0.09911774075590074, 0.02893457902246155, 0.25373595650307834, 3.2638871110975742, 14.520078208297491, 31.751424930989742, 43.94042417407036, 55.26180647313595, 42.020634189248085, 33.260325863957405, 28.57636470347643, 51.73748418688774, 66.72324165701866, 36.58970721065998, 18.768492490053177, 16.766127236187458, 28.798603378236294, 27.179044783115387, 30.916649624705315, 27.378636673092842, 29.8319199308753, 32.84258008003235, 32.133872509002686, 28.408991284668446, 25.314420238137245, 20.04621382802725, 17.912341430783272, 14.905561823397875, 13.28768938779831, 8.962421379983425, 5.985704334452748, 9.462359603494406, 9.989999290555716, 11.80069237947464, 10.323344953358173, 8.450664840638638, 10.21530345082283, 8.062953595072031, 10.298579782247543, 11.061760280281305, 16.038684770464897, 18.056672886013985, 22.62037619948387, 23.971262611448765, 27.53947824239731, 27.563658244907856, 26.603141985833645, 26.535800099372864, 23.48655492067337, 19.991983138024807, 24.153451435267925, 23.03061928600073, 20.723607279360294, 26.833345033228397, 28.34916539490223, 34.97562222182751, 33.148710653185844, 30.001419335603714, 20.321628749370575, 12.948891967535019, 5.8245492819696665, 1.7091911542229354, 0.2293703577015549, 0.060114696534583345, 0.05838630509970244, 0.0074673442759376485, 0.020663280083681457, 0.032818438194226474, 0.026756835723062977, 0.01838039115682477, 0.05463526067615021, 0.024895957940316293, 0.041585421276977286, 0.007375697387033142, 0.03978736815042794, 0.026141432026633993, 0.013701560092158616, 0.04169596417341381, 0.018341125978622586, 0.03876511909766123, 0.029982526793901343, 0.08801696298178285, 0.11106136080343276, 0.013228033694758778, 0.13249238894786686, 0.043659709190251306, 0.036386606298037805, 0.024526581764803268, 0.03101986370893428, 0.041660634233267047, 0.050653927828534506, 0.09241349034709856, 0.02960405188787263, 0.03187961767253, 0.049364832157152705, 0.02197962185164215, 0.04630276052921545, 0.040878032086766325, 0.04077779391082004, 0.022297311152215116, 0.013291072646097746, 0.05537740093132015, 0.03631272920756601, 0.025825711272773333, 0.0336319582129363, 0.06351620424538851, 0.02413194473774638, 0.05719320251955651, 0.027303264214424416, 0.024381868533964735, 0.05483977060066536, 0.10025333060184494, 0.04002708556072321, 0.010951123695122078, 0.05267644351988565, 0.0729360620607622, 0.24941092764493078, 0.10624350878060795, 0.11762019479647279, 0.21601554384687915, 0.20420326909516007, 0.12503661011578515, 0.16425141133368015, 0.13040346588240936, 0.11667288781609386, 0.15718701150035486, 0.17714170011458918, 0.1367292506620288, 0.1851762947626412, 0.1276115360087715, 0.16834586975164711, 0.11132361352792941, 0.10147863868041895, 0.1741647082963027, 0.22116227861260995, 0.11054006143240258, 0.2621264703338966, 0.2716248028445989, 0.142951283196453, 0.12311914542806335, 0.13989741972181946, 0.21520678099477664, 0.1757256971905008, 0.13031941023655236, 0.1829691178863868, 0.1940055811428465, 0.17147304257377982, 0.15340400277636945, 0.1362688370863907, 0.17140630865469575, 0.1849909804877825, 0.12074341939296573, 0.16192172071896493, 0.16862678749021143, 0.15761851100251079, 0.16006624762667343, 0.21940077625913545, 0.09367667022161186, 0.11879358964506537, 0.09803331457078457, 0.21801054070238024, 0.12181798243545927, 0.24347699683858082, 0.18852526583941653, 0.07739553097053431, 0.22122491587651893, 0.1425686912261881, 0.11964556775637902, 0.12477114389184862, 0.14906300290022045, 0.1479805656708777, 0.13887766428524628, 0.15386995277367532, 0.17670041910605505, 0.08937966485973448, 0.18865150515921414, 0.20642928167944774, 0.17172878666315228, 0.39073549734894186, 3.4912588354200125, 14.367034770548344, 35.091086626052856, 48.860194981098175, 65.11252328753471, 52.30098634958267, 44.943159967660904, 34.054183065891266, 52.47723989188671, 79.56835359334946, 53.74359413981438, 35.23806653916836, 30.139942802488804, 44.47080731391907, 33.073797672986984, 35.91205537319183, 29.540445171296597, 33.892060965299606, 38.97412866353989, 34.15562242269516, 34.316505789756775, 28.98291628807783, 23.91397498548031, 21.18181899189949, 18.06175511330366, 14.142406024038792, 12.032971065491438, 10.096630118787289, 12.926282230764627, 11.82643884792924, 11.560948994010687, 9.77071875706315, 9.995976369827986, 12.340023089200258, 10.216944962739944, 13.381033279001713, 12.522924374789, 16.92341599613428, 17.406877353787422, 24.82428453862667, 24.80085499584675, 32.740635350346565, 34.64092098176479, 30.971349589526653, 34.9357433617115, 31.64283435791731, 33.73775504529476, 34.705863296985626, 35.625961124897, 33.91146272420883, 40.862296745181084, 37.569047659635544, 44.865271747112274, 38.63450288772583, 35.303974002599716, 22.11815904825926, 13.66902457550168, 5.760970143601298, 1.6877023573033512, 0.22460631880676374, 0.12352162695606239, 0.1555493735941127, 0.13864774693502113, 0.12978562794160098, 0.1377167078317143, 0.09712274390039966, 0.14183684455929324, 0.147502978798002, 0.10418699530418962, 0.1637584768468514, 0.18745234294328839, 0.16423791908891872, 0.1548115600598976, 0.1628649458871223, 0.1320159449824132, 0.13204310758737847, 0.11123296761070378, 0.16713738616090268, 0.18710426083998755, 0.19929589179810137, 0.12578453170135617, 0.27603366470430046, 0.12593058636412024, 0.17665580118773505, 0.17612638272112235, 0.1387999762664549, 0.17373329785186797, 0.200803950720001, 0.1346372254192829, 0.21906154055614024, 0.1890273584285751, 0.15697600407293066, 0.14058344619115815, 0.08803271877695806, 0.26193158235400915, 0.325986971729435, 0.15416633686982095, 0.1542687532491982, 0.13047725020442158, 0.12217338953632861, 0.2997792436508462, 0.10999163656379096, 0.19937800301704556, 0.10143364968826063, 0.13642302568769082, 0.09604748323909007, 0.12363090820144862, 0.09150542813586071, 0.16070583049440756, 0.11411068233428523, 0.0819712424708996, 0.10003415212850086, 0.12786169914761558], [0.027876233762071934, 0.08965025932411663, 0.04733452762593515, 0.055406871615559794, 0.0552511504793074, 0.023252284518093802, 0.03810754657024518, 0.013351544694160111, 0.030909996166883502, 0.07500719584641047, 0.03365854194271378, 0.05525105771084782, 0.04369999667687807, 0.02175511104724137, 0.04082689440110698, 0.006550802099809516, 0.044671171126537956, 0.042662600390031, 0.0466653145122109, 0.0652358791558072, 0.04015922866528854, 0.04859475004195701, 0.05376268054533284, 0.034954869843204506, 0.03398112385184504, 0.01882644231955055, 0.029044114453427028, 0.014880206563248066, 0.04786221317772288, 0.014232230005291058, 0.04612070799339563, 0.028435469866963103, 0.06358374710544012, 0.027467230611364357, 0.04028235467558261, 0.010461452802701388, 0.08765008969930932, 0.07007778418483213, 0.06421870639314875, 0.03586824954254553, 0.02021731426793849, 0.02475402219715761, 0.01690952125500189, 0.050436129749868996, 0.044160510442452505, 0.08958796344813891, 0.0393177371006459, 0.010269984268234111, 0.017937293741852045, 0.04971252092218492, 0.04950553964590654, 0.039325307006947696, 0.02268312960950425, 0.03597769406042062, 0.036990161606809124, 0.059847278462257236, 0.04533165287284646, 0.05435809820482973, 0.056192397823906504, 0.014829450155957602, 0.11340898170601577, 0.03336305955599528, 0.06029759882949293, 0.02493085001333384, 0.35685544658917934, 3.764076833613217, 15.39855781942606, 29.48107335716486, 40.02131827175617, 48.22291977703571, 44.07204911112785, 36.518031656742096, 45.811485573649406, 56.81408017873764, 48.42514492571354, 27.77026455849409, 27.314190231263638, 27.121863551437855, 26.168792992830276, 25.963501408696175, 27.653584219515324, 16.87849100679159, 21.628393828868866, 25.50460573285818, 24.095637537539005, 28.258196376264095, 28.427391797304153, 25.964831337332726, 17.25313000380993, 20.129131078720093, 20.648935586214066, 21.99387911707163, 21.15096654742956, 16.305305063724518, 17.360789626836777, 22.81267438083887, 21.730042174458504, 25.03123663365841, 35.51881447434425, 28.052929490804672, 19.036351516842842, 19.984436742961407, 13.66170996800065, 23.504543155431747, 34.431430622935295, 32.29417830705643, 18.65112628787756, 26.580272912979126, 34.078364968299866, 32.094297632575035, 30.103432461619377, 28.603645339608192, 39.37161773443222, 38.59826423227787, 32.690299451351166, 25.56442592293024, 13.401563577353954, 8.524065501987934, 3.080352209508419, 0.7635319198016077, 0.1899038496776484, 0.03311457367090043, 0.05205999710597098, 0.02230718357168371, 0.16375714098103344, 0.033166913635795936, 0.03984738934377674, 0.07873705195379443, 0.03091737125942018, 0.07180979358963668, 0.053230668272590265, 0.07792546894052066, 0.019483259711705614, 0.06992657159571536, 0.049716862486093305, 0.058271873349440284, 0.027205412043258548, 0.08382212909054942, 0.03803747669735458, 0.03306187747512013, 0.054819142605992965, 0.035855840833391994, 0.05962832263321616, 0.022367978453985415, 0.07099999173078686, 0.028279416619625408, 0.05491794101544656, 0.035368706230656244, 0.047809190436964855, 0.04041940708702896, 0.029473843933374155, 0.035748314767261036, 0.027989927075395826, 0.01660573423578171, 0.020017145907331724, 0.08837470784783363, 0.01870434047305025, 0.10119796585058793, 0.035121667533530854, 0.06551762809976935, 0.027594918974500615, 0.016508032349520363, 0.03624992867116816, 0.08927966046030633, 0.060761355780414306, 0.04138403579418082, 0.05457502425997518, 0.05473913537571207, 0.08871356505551375, 0.06303334812400863, 0.0022839450957690133, 0.020394700550241396, 0.03781529623665847, 0.0649048293416854, 0.01049212947691558, 0.03447337185207289, 0.11593548988457769, 0.08609149052063003, 0.06293620841461234, 0.10756598625448532, 0.0207574864543858, 0.02857076524378499, 0.039658687164774165, 0.05020405646064319, 0.03652971834526397, 0.07054426852846518, 0.018172569398302585, 0.06548444667714648, 0.0207069369207602, 0.02387572567386087, 0.017958637909032404, 0.0453755768830888, 0.012999198952456936, 0.06333713885396719, 0.0513686791236978, 0.0741530951927416, 0.014307735182228498, 0.011465271545603173, 0.008498938823322533, 0.0590368383564055, 0.03656600194517523, 0.06057734768546652, 0.02250159472168889, 0.03140854314551689, 0.026537505109445192, 0.04910282434138935, 0.10564871452515945, 0.03960497793741524, 0.03081209390074946, 0.0248652812661021, 0.08434713177848607, 0.052919229710823856, 0.04036182384879794, 0.020018420545966364, 0.015454738331754925, 0.012067164443578804, 0.03211975439626258, 0.011535806188476272, 0.0605675698898267, 0.08227204234572127, 0.007225059962365776, 0.014496837193291867, 0.04345626424765214, 0.009755436585692223, 0.12859060690971091, 0.03926932309695985, 0.02283292469655862, 0.06425553918234073, 0.048207938962150365, 0.02198136589868227, 0.03578707342967391, 0.053770005542901345, 0.012666622169490438, 0.021475267567439005, 0.07378827023785561, 0.014383642046595924, 0.10881890964810736, 0.027485648861329537, 0.020911971914756577, 0.07763671412249096, 0.4792217054637149, 4.896534578874707, 18.117910400032997, 34.850259348750114, 47.935070022940636, 53.78676362335682, 45.788458809256554, 39.239700213074684, 51.58572033047676, 63.18480312824249, 43.88679005205631, 26.060073226690292, 27.527571581304073, 25.81871397793293, 24.444126337766647, 20.96416287124157, 25.01610964536667, 26.394312791526318, 27.31628391891718, 30.999487079679966, 31.787331104278564, 34.52758826315403, 33.47754120826721, 35.348237827420235, 25.38898553699255, 28.320874013006687, 29.025812186300755, 31.65995053946972, 30.930653773248196, 26.402146071195602, 24.94709774851799, 30.99915459752083, 30.815816335380077, 32.21501335501671, 40.36328472197056, 30.1202180609107, 22.714020274579525, 25.82681704312563, 23.984491601586342, 30.320647805929184, 38.974812626838684, 37.58374907076359, 22.976342998445034, 27.67619490623474, 31.221292577683926, 32.81709864735603, 34.33391645550728, 32.273382022976875, 42.31285750865936, 44.71175618469715, 38.97126741707325, 31.429190821945667, 19.118012934923172, 12.76093315333128, 5.251056030392647, 1.5991383721120656, 0.29101317340973765, 0.025857853688648902, 0.06123441555246245, 0.06043344896170311, 0.026481072200112976, 0.07021747864200734, 0.07771098826196976, 0.045008521774434485, 0.047283234089263715, 0.01572553039295599, 0.03960255111451261, 0.019221270449634176, 0.04162507422734052, 0.015549646032013698, 0.03242484017391689, 0.033942157388082705, 0.03867937877657823, 0.022763763954571914, 0.024993006736622192, 0.0570707036240492, 0.0718477024929598, 0.025849309713521507, 0.08346761998836882, 0.01056710123521043, 0.07495463694795035, 0.03771266092371661, 0.052729844755958766, 0.04142488360230345, 0.010436890497658169, 0.02935813754447736, 0.037688463198719546, 0.13029935740632936, 0.027319997789163608, 0.03133270307444036, 0.009296796743001323, 0.03370539743627887, 0.008469861477351515, 0.08305842202389613, 0.06469718384323642, 0.07674961016164161, 0.00952716402025544, 0.010227660513919545, 0.04254081395629328, 0.05356713947548997, 0.05698183143977076, 0.08017834727070294, 0.07558866855106317, 0.049961181211983785, 0.014539883613906568, 0.033860654730233364, 0.05424904702522326, 0.08302685848320834, 0.00945136012887815, 0.048703081338317133, 0.07561124468338676, 0.02242716473119799, 0.2751524088671431, 0.2587778406450525, 0.16231004206929356, 0.22796018805820495, 0.17693787667667493, 0.09471785888308659, 0.1294402769417502, 0.20284781057853252, 0.186525103636086, 0.16105746006360278, 0.09590105750248767, 0.19182464660843834, 0.222750059037935, 0.1485185930505395, 0.08937844031606801, 0.13824919878970832, 0.14463741303188726, 0.23496195062762126, 0.21050735347671434, 0.15741565235657617, 0.17370313697028905, 0.09924196885549463, 0.16253366600722075, 0.14687497343402356, 0.08943456152337603, 0.1373068493558094, 0.05934626569796819, 0.13001045415876433, 0.11323736747726798, 0.1568963419413194, 0.19933806062908843, 0.10224331053905189, 0.1300925950636156, 0.11046216561226174, 0.15085180144524202, 0.16303425945807248, 0.2767160249641165, 0.17360487661790103, 0.2615561446873471, 0.06551684884470887, 0.14674581005237997, 0.1505145398550667, 0.169315010716673, 0.15431636944413185, 0.10500415926799178, 0.19382034108275548, 0.12978855200344697, 0.07141505266190507, 0.13018753059441224, 0.11076803435571492, 0.12417313613696024, 0.14661925903055817, 0.20121216162806377, 0.1245478168129921, 0.1805227913428098, 0.1263241918059066, 0.13278947066282853, 0.19556553103029728, 0.1521787466481328, 0.12503971229307353, 0.18227995955385268, 0.15484164672670886, 0.1290368751506321, 0.16664140886859968, 0.6317931076046079, 5.576956942677498, 20.7415784150362, 39.08949427306652, 53.382389321923256, 62.985834404826164, 57.013474479317665, 47.91427753865719, 57.65362612903118, 68.88398811221123, 59.580054357647896, 37.933022528886795, 42.78732664883137, 38.15911039710045, 38.82553383708, 34.565194845199585, 40.91391317546368, 27.460060603916645, 32.37823739647865, 38.09676714241505, 33.66657346487045, 41.033329367637634, 43.11767712235451, 35.495115146040916, 27.56331816315651, 32.77809754014015, 30.58749608695507, 31.17557343095541, 30.497195832431316, 24.602824822068214, 26.57465111464262, 33.09951089322567, 30.50770226866007, 33.353648856282234, 46.45362451672554, 38.54764334857464, 25.54965801537037, 30.942366644740105, 23.184556625783443, 36.872545033693314, 45.92512987554073, 45.21046802401543, 28.529213033616543, 38.301986530423164, 46.70585498213768, 40.26953995227814, 41.71781323850155, 39.330682530999184, 50.90938322246075, 52.95056149363518, 45.08223630487919, 33.84032294154167, 19.17829480022192, 12.175880447030067, 4.516482297331095, 1.3352685375139117, 0.5140302423387766, 0.11577584649785422, 0.14812227134825662, 0.12998349935514852, 0.26625815487932414, 0.17636182165006176, 0.18662225076695904, 0.1864314594422467, 0.09070299580343999, 0.13662563200341538, 0.17757281369995326, 0.19153783621732146, 0.14397601102245972, 0.13754507876001298, 0.08561437120079063, 0.12626554729649797, 0.15147217753110453, 0.1953142843558453, 0.1514202865655534, 0.1717351097613573, 0.2076110034249723, 0.07809041126165539, 0.17783452465664595, 0.13345100625883788, 0.17143988341558725, 0.12673416902543977, 0.22058233473217115, 0.16206698870519176, 0.1102333317976445, 0.17201613140059635, 0.16720784566132352, 0.2973498380742967, 0.19953664450440556, 0.09672973217675462, 0.13863314146874472, 0.2016560549964197, 0.12449677189579234, 0.20569970598444343, 0.15031751448987052, 0.18795222393237054, 0.11807968810899183, 0.24237005389295518, 0.15553542121779174, 0.17729873856296763, 0.1696185045875609, 0.12273260523215868, 0.13523089903173968, 0.15059947123518214, 0.15422928583575413, 0.19038532540434971, 0.14681008004117757, 0.13319929945282638, 0.14166166802169755, 0.13852116622729227, 0.1822321504005231, 0.08190387772629037], [0.03412705234950408, 0.03894941291946452, 0.06518081921967678, 0.049192880251212046, 0.02996105275087757, 0.03662893235741649, 0.05731691482651513, 0.06662797008175403, 0.046436094780801795, 0.05534268326300662, 0.07725012197624892, 0.03849636887025554, 0.035575557631091215, 0.015498629873036407, 0.015134810528252274, 0.015873724296397995, 0.02295566664543003, 0.03945875258068554, 0.0427253230009228, 0.012557710142573342, 0.022002131190674845, 0.006278448281591409, 0.09121242823312059, 0.015280271472875029, 0.019204971031285822, 0.06134470611868892, 0.06589500277186744, 0.014766764652449638, 0.015880010287219193, 0.027506898404681124, 0.05990220481180586, 0.002690613728191238, 0.04754932742798701, 0.06812204694142565, 0.11409398401156068, 0.035115700666210614, 0.007664573267902597, 0.017701457763905637, 0.0206964021344902, 0.04710189030447509, 0.051322239232831635, 0.002885746616811957, 0.034989650594070554, 0.02546985702792881, 0.038169066901900806, 0.04031311298604123, 0.011868253095599357, 0.05064266202680301, 0.060009704902768135, 0.008301923662656918, 0.02391934540355578, 0.015192131231742678, 0.047619931647204794, 0.08574950887123123, 0.0570702397817513, 0.01949051977135241, 0.01217806171553093, 0.03575462302251253, 0.063462005200563, 0.03168255519995, 0.020841128352913074, 0.016080928216979373, 0.047457928230869584, 0.07165074392105453, 0.04228614969179034, 0.05031685548601672, 0.27058410400059074, 4.643498556688428, 13.246191814541817, 25.33290434628725, 42.89598561823368, 46.63290649652481, 45.2269097417593, 42.77709759771824, 54.27358590066433, 41.90512418746948, 40.478695929050446, 32.749158293008804, 32.52030797302723, 35.59796042740345, 27.818204686045647, 20.77185709029436, 37.364094257354736, 21.82576473802328, 25.009665191173553, 20.99164679646492, 22.209492847323418, 16.654930002987385, 22.15293288230896, 20.33688873052597, 19.677460715174675, 18.5966220125556, 19.60844311863184, 19.194789715111256, 20.31702909618616, 27.709076441824436, 22.535450756549835, 15.657627917826176, 60.69918170571327, 61.27495341002941, 29.700844064354897, 24.77098859846592, 16.508698649704456, 21.160857416689396, 28.103054501116276, 32.055254727602005, 33.85265327990055, 32.819218933582306, 40.59320658445358, 28.0251282826066, 32.446762919425964, 27.99660511314869, 26.734567433595657, 22.807576954364777, 13.42258119955659, 7.431360511109233, 2.0274790562689304, 0.40393043775111437, 0.031502217025263235, 0.06365518624079414, 0.04273000224202406, 0.04973076662281528, 0.04060567131091375, 0.049563831635168754, 0.029036091837042477, 0.019001245927938726, 0.0064633205147401895, 0.0707665120717138, 0.03076949647947913, 0.0765144829347264, 0.079622115008533, 0.0627479626564309, 0.049015959666576236, 0.12509685766417533, 0.02295096328452928, 0.073521186131984, 0.03337596179335378, 0.014687327948195161, 0.027827441263070796, 0.06343787797959521, 0.017164734708785545, 0.032986846345011145, 0.01833358019212028, 0.024561381069361232, 0.06124171086412389, 0.030337408825289458, 0.0505246790999081, 0.037017765789642, 0.05182943037652876, 0.0030975247182141175, 0.023596930477651767, 0.1450979453511536, 0.04604900168487802, 0.03613759719883092, 0.020717731458717026, 0.03314864938147366, 0.01979435317480238, 0.06677498953649774, 0.03812335060501937, 0.057411078523728065, 0.03535629381076433, 0.040270988683914766, 0.042914852674584836, 0.06708491782774217, 0.03556949057383463, 0.02845776212780038, 0.025481338052486535, 0.06787316029658541, 0.11255536344833672, 0.046686183704878204, 0.03371744620380923, 0.1544661051593721, 0.022646701290796045, 0.03996746141638141, 0.15555805672192946, 0.06744693004293367, 0.03543492064636666, 0.025746438768692315, 0.06179603951750323, 0.06411067195585929, 0.04118347409530543, 0.013761711161350831, 0.10764043108792976, 0.004229481983202277, 0.029422767474898137, 0.018007923936238512, 0.05670604936312884, 0.016532285735593177, 0.021834836261405144, 0.033840126925497316, 0.02616813264467055, 0.03475753648672253, 0.022319070922094397, 0.03622162686951924, 0.04475049558095634, 0.047251815267372876, 0.04516480323218275, 0.04441285549546592, 0.09551246897899546, 0.006464505631811335, 0.043826840847032145, 0.07032230700133368, 0.04952408962708432, 0.03535401170665864, 0.00336156462708459, 0.04465748221264221, 0.07040934608085081, 0.04762228054460138, 0.013884916024835547, 0.040037902363110334, 0.06438039810745977, 0.030546123016392812, 0.039824063642299734, 0.01704320060525788, 0.029712203213421162, 0.03299194861028809, 0.029113518248777837, 0.05322878321749158, 0.02750964991719229, 0.044895704195369035, 0.04668434317864012, 0.06361793042742647, 0.008899238437152235, 0.011353634909028187, 0.10379070328781381, 0.053418995667016134, 0.016488606634084135, 0.02526676831621444, 0.033287163823843, 0.016306810139212757, 0.03247829336032737, 0.012213734898978146, 0.04814150932361372, 0.05644351833325345, 0.052305974531918764, 0.02729696894675726, 0.046300634276121855, 0.016595203160250094, 0.05098361951240804, 0.030858092213748023, 0.05792055177153088, 0.10104970700922422, 0.681261228164658, 6.397168105468154, 15.674616806209087, 31.567676290869713, 49.570555463433266, 52.42333598434925, 49.60009127855301, 49.46478433907032, 58.32252323627472, 45.981591045856476, 45.555960685014725, 34.23020102083683, 30.95187373459339, 34.391745552420616, 29.316321797668934, 16.750931851565838, 29.500480815768242, 21.89645804464817, 21.98327198624611, 23.91300793737173, 30.196966342628002, 20.821946002542973, 23.825663924217224, 27.004098370671272, 25.096393637359142, 23.45144670456648, 21.915757209062576, 19.04983889311552, 25.515771433711052, 34.155215844511986, 29.823545180261135, 22.229635566473007, 68.1759113073349, 60.46451769769192, 28.12202498316765, 25.69945927709341, 14.547504186630249, 23.696721643209457, 34.2595050483942, 36.324428245425224, 33.27422931790352, 33.75033237040043, 44.23899695277214, 34.64720964431763, 36.46995663642883, 32.792000994086266, 33.53931449353695, 29.210419580340385, 18.118373975157738, 10.827865730971098, 3.4468577429652214, 0.9700012032408267, 0.17453864682465792, 0.0585905255866237, 0.007166149671320454, 0.055116031362558715, 0.03776988050958607, 0.07489700918085873, 0.03510410831950139, 0.09543771244352683, 0.021542502436204813, 0.03677892040286679, 0.035602226707851514, 0.08528984486474656, 0.06924756584339775, 0.07981880640727468, 0.02238057270005811, 0.02139146610716125, 0.007649191793461796, 0.07813937074388377, 0.03263493475969881, 0.014887229135638336, 0.0199188187616528, 0.0620413341675885, 0.043215882615186274, 0.009076326932699885, 0.024640774172439706, 0.023720787503407337, 0.04621878280886449, 0.047832935451879166, 0.020847288178629242, 0.022067620157031342, 0.04783322860021144, 0.03103661583736539, 0.025547908699081745, 0.04008937772596255, 0.030166546021064278, 0.006702437713101972, 0.015687296800024342, 0.022338498492899816, 0.01310368963459041, 0.08916797465644777, 0.059043562214355916, 0.05817610661324579, 0.12036912463372573, 0.014329414243547944, 0.021795270513393916, 0.030017866010894068, 0.058758195300470106, 0.024548291439714376, 0.03448498646321241, 0.08078069658949971, 0.15479787485674024, 0.01645614880544599, 0.039885116420919076, 0.07610823129653, 0.049125827208627015, 0.03932234212697949, 0.0372277304995805, 0.023072786825650837, 0.11274555363343097, 0.0948937849898357, 0.17391363973729312, 0.11421634189900942, 0.1621856284327805, 0.13550489995395765, 0.19916657998692244, 0.14131950825685635, 0.17977792740566656, 0.18497417826438323, 0.15845293732127175, 0.08575889703934081, 0.13494581042323261, 0.10404488886706531, 0.09256589779397473, 0.11373474000720307, 0.09088190534384921, 0.1286188530502841, 0.13907770277000964, 0.17191279475810006, 0.07161723595345393, 0.15798692795215175, 0.2477613411610946, 0.11317064840113744, 0.1398721124860458, 0.13633230555569753, 0.15449145692400634, 0.1335620167083107, 0.10293226849171333, 0.13539562613004819, 0.19547990203136578, 0.15311046852730215, 0.18908241094322875, 0.2347087298403494, 0.15956584713421762, 0.14592542516766116, 0.11440826870966703, 0.10666510061128065, 0.06956262979656458, 0.19648846588097513, 0.08310740377055481, 0.1911027150345035, 0.12422877494827844, 0.12720436410745606, 0.19909325579646975, 0.13605352520244196, 0.14983210538048297, 0.07409059151541442, 0.20096006890526041, 0.15095262962859124, 0.09474380436586216, 0.10840755203389563, 0.08904834045097232, 0.12332734011579305, 0.14955635298974812, 0.12465956941014156, 0.1538768399041146, 0.11588094203034416, 0.1153565404820256, 0.13477731321472675, 0.1574630755931139, 0.09571803646394983, 0.12243834367836826, 0.19139727344736457, 0.15035907475976273, 0.12431096780346707, 1.043723956681788, 7.240794086828828, 18.501921594142914, 35.844210013747215, 55.30247949063778, 59.203114584088326, 58.24880339205265, 55.11942811310291, 66.86620518565178, 57.8459832072258, 54.84765909612179, 46.34256027638912, 44.97719094157219, 49.09302368760109, 41.61020681262016, 29.752373099327087, 50.64195357263088, 31.96103498339653, 34.229330867528915, 31.918735653162003, 36.5530239790678, 25.41938580572605, 34.136220663785934, 33.92220474779606, 31.612293496727943, 29.654125571250916, 29.83461208641529, 29.853231087327003, 31.500799879431725, 42.38224558532238, 33.82284387946129, 23.399134911596775, 73.15219268202782, 68.44790071249008, 39.703119546175, 35.17016798257828, 24.166081957519054, 33.17008450627327, 42.20901668071747, 44.63956005871296, 44.57180969417095, 43.15842613577843, 52.33044236898422, 42.86612682044506, 45.08479356765747, 40.442533269524574, 38.07724379003048, 31.575182788074017, 18.770781867206097, 9.869588501751423, 3.1844395492225885, 0.8327934157568961, 0.16455233737360686, 0.2272489879396744, 0.12824173812987283, 0.13107821170706302, 0.12862416682764888, 0.2202310910797678, 0.13538707658881322, 0.16265687736449763, 0.13080568023724481, 0.12448929104721174, 0.23247605276992545, 0.16398361476603895, 0.13356137846130878, 0.21724247722886503, 0.12374090190860443, 0.12672094395384192, 0.06845823241746984, 0.2022308186860755, 0.1172989042242989, 0.07605033635627478, 0.0911275265389122, 0.16137527738464996, 0.1425906884833239, 0.10488667729077861, 0.07901630728156306, 0.10641773536917754, 0.1545475484454073, 0.08837350556859747, 0.07720270616118796, 0.1002820220310241, 0.12667758768657222, 0.08565561234718189, 0.07371666040853597, 0.2344382318551652, 0.09875421455944888, 0.0922943236946594, 0.15013711323263124, 0.10258922557113692, 0.15511791862081736, 0.2406635892111808, 0.14439655642490834, 0.21676022966858, 0.19510171841830015, 0.1390552899101749, 0.10552119871135801, 0.20203049818519503, 0.1304282684577629, 0.11158453780808486, 0.16028347425162792, 0.10536414542002603, 0.3789885464357212, 0.14320640388177708, 0.13700298441108316, 0.19705432379851118, 0.12061199988238513, 0.08765000064158812, 0.23472498287446797, 0.15234357764711604], [0.025836008571786806, 0.0332284933392657, 0.039692462305538356, 0.050328830038779415, 0.038757025977247395, 0.05158841049706098, 0.038545287534361705, 0.05336018046364188, 0.05908005732635502, 0.045975640387041494, 0.027643503672152292, 0.0571649192715995, 0.07557591845397837, 0.10859128553420305, 0.02909693866968155, 0.07827703913790174, 0.06429399727494456, 0.012033921793772606, 0.043714138300856575, 0.03803076397161931, 0.06460331700509414, 0.012710161190625513, 0.0294195001697517, 0.05450642383948434, 0.023523194395238534, 0.0667528215853963, 0.019220788053644355, 0.081175289087696, 0.032306415669154376, 0.02468948317982722, 0.010623805956129218, 0.11196670675417408, 0.04983770639228169, 0.025344612186017912, 0.00899831979040755, 0.04695057752542198, 0.03278351272456348, 0.027385633329686243, 0.024899403360905126, 0.047244263914762996, 0.027196662122150883, 0.032135703149833716, 0.0433699376299046, 0.03288648200395983, 0.05677066816133447, 0.019178279690095223, 0.029272762731125113, 0.05832918941450771, 0.04415721901750658, 0.03369704085343983, 0.09138846566202119, 0.07333415749599226, 0.011064957088819938, 0.03538959768775385, 0.07905742968432605, 0.017232708014489617, 0.019009975439985283, 0.05381338036386296, 0.054117653489811346, 0.05822393803100567, 0.01745621135341935, 0.049472105893073604, 0.04245640207955148, 0.02895734996855026, 0.07777988925226964, 0.08833247964503244, 0.023691869719186798, 0.05362563184462488, 0.327467467286624, 2.9426428489387035, 10.363380555063486, 19.737092815339565, 30.01419425010681, 37.50101611018181, 42.70599581301212, 45.06842404603958, 44.91489328444004, 49.262088015675545, 52.65544652938843, 48.013729602098465, 40.819697231054306, 50.6335636228323, 46.662537306547165, 36.15417838096619, 34.89396460354328, 37.12017774581909, 29.093190170824528, 31.194728203117847, 30.418429858982563, 29.56343963742256, 35.8400834351778, 32.39063233137131, 33.80160301923752, 28.789932243525982, 24.372838363051414, 28.400082662701607, 31.276771500706673, 24.456722661852837, 55.66969558596611, 66.37879773974419, 39.7630575299263, 24.374569170176983, 30.786035433411598, 30.00985488295555, 39.749435260891914, 45.85322253406048, 41.006806790828705, 37.52219617366791, 31.932338923215866, 33.48092682659626, 30.42325370013714, 16.88082218170166, 10.419444646686316, 5.709051629528403, 1.3829785399138927, 0.22006685379892588, 0.04519322006672155, 0.042939651539199986, 0.04058949991303962, 0.01419587126292754, 0.051305945380590856, 0.03248225271818228, 0.0320830329292221, 0.06694971336401068, 0.0052781640169996535, 0.03131004159513395, 0.035585554360295646, 0.03711630815814715, 0.022058374852349516, 0.010259131286147749, 0.0727600691607222, 0.06023434929375071, 0.012784604168700753, 0.026175435377808753, 0.061856324173277244, 0.02925495118688559, 0.018929851321445312, 0.02627304449561052, 0.07190952339442447, 0.0202432950027287, 0.0556596174283186, 0.0427028581907507, 0.01611492600204656, 0.053401885452331044, 0.08141815691487864, 0.05950307036982849, 0.009728428904054454, 0.021369908572523855, 0.046743700149818324, 0.08124127343762666, 0.008235483819589717, 0.024187539020203985, 0.07023337544524111, 0.01671702670137165, 0.045869272071286105, 0.023520936410932336, 0.00935073510845541, 0.020500035425357055, 0.06274045212194324, 0.06640680265263654, 0.013833419325237628, 0.07509076167480089, 0.032404935773229226, 0.022648673548246734, 0.014522886576742167, 0.06450956148910336, 0.020300002506701276, 0.007954068842082052, 0.11262755215284415, 0.04242253788106609, 0.0194540042502922, 0.044252336374484, 0.043436819978524, 0.03994562372099608, 0.0009465744574299606, 0.02484820259269327, 0.05385067328461446, 0.0235449578758562, 0.021979401062708348, 0.0719875528011471, 0.053267274706740864, 0.03191851363226306, 0.029677986494789366, 0.02926814657257637, 0.03182649103109725, 0.0409737802692689, 0.012202908819745062, 0.04005411457910668, 0.03264716164267156, 0.016788211651146412, 0.036950709036318585, 0.07069650528137572, 0.028385232035361696, 0.031167708802968264, 0.012706392008112743, 0.043908135703532025, 0.06697752163745463, 0.01344824375337339, 0.07907298509962857, 0.008830321676214226, 0.06408955785445869, 0.09611360117560253, 0.03442099849053193, 0.03740262873179745, 0.0378849171102047, 0.017003549510263838, 0.04123826314753387, 0.06589579686988145, 0.023091867442417424, 0.06037561339326203, 0.023475494708691258, 0.0030189971448635333, 0.05586171166214626, 0.017078517557820305, 0.029349489668675233, 0.05944357610133011, 0.031547042744932696, 0.017030812305165455, 0.05779634593636729, 0.00979564892986673, 0.014437039571930654, 0.03492139898298774, 0.019356675293238368, 0.05419912646175362, 0.039327039921772666, 0.02313645753019955, 0.12005498094367795, 0.11486830378999002, 0.03489084105240181, 0.039267731190193444, 0.0916893026442267, 0.03467683905910235, 0.022481185660581104, 0.03822814927843865, 0.03890702144417446, 0.03877728660881985, 0.041682252995087765, 0.007870875015214551, 0.05663262869347818, 0.11830220624688081, 0.02736896654823795, 0.05719767767004669, 0.03030303996638395, 0.018519423247198574, 0.5040352942887694, 4.023896679282188, 13.56001602485776, 25.40551844984293, 35.50860062241554, 44.3144229054451, 49.44346748292446, 51.994373202323914, 50.33003970980644, 53.584599271416664, 55.46992890536785, 51.31965100765228, 42.61099711060524, 46.62057615816593, 51.15635097026825, 36.13948076963425, 34.15641278028488, 33.35906356573105, 31.126413568854332, 22.776010148227215, 28.705882653594017, 27.297689616680145, 32.97124497592449, 27.803949750959873, 28.823847323656082, 27.559172585606575, 22.57675264030695, 28.914772644639015, 27.330584451556206, 22.90439385920763, 58.15570838749409, 70.98489537835121, 40.153900757431984, 25.418546050786972, 26.152136586606503, 32.75574713945389, 40.96497483551502, 50.546411499381065, 48.500061705708504, 43.812754824757576, 38.36139254271984, 38.336845859885216, 35.8580906689167, 21.89680192619562, 14.800578206777573, 8.393161576241255, 2.6302107889205217, 0.5448703374713659, 0.11477196560008451, 0.06420367790269665, 0.037492272749659605, 0.05824042855238076, 0.08778805495239794, 0.02258502325275913, 0.0371025524509605, 0.035697911807801574, 0.035558540184865706, 0.017520692854304798, 0.037979852641001344, 0.026832929979718756, 0.050060365538229235, 0.03380608461156953, 0.04591649863868952, 0.0642861750384327, 0.04358431069704238, 0.03755829049623571, 0.030490376593661495, 0.011687487258313922, 0.08241951451054774, 0.034645023188204505, 0.03432619654631708, 0.024971621751319617, 0.06625749738304876, 0.07381192248431034, 0.021627630485454574, 0.059873038408113644, 0.030459625704679638, 0.045761297005810775, 0.041600661279517226, 0.03829241555649787, 0.06454895468777977, 0.016433923337899614, 0.02030477080552373, 0.032069347726064734, 0.0699694306240417, 0.04708065003796946, 0.010984896052832482, 0.06690973386866972, 0.04672470116929617, 0.04427063773619011, 0.008865323216014076, 0.022365507102222182, 0.03764247601793613, 0.034112168577848934, 0.05797977515612729, 0.021864809750695713, 0.002328667378606042, 0.006644517725362675, 0.007725981813564431, 0.05706134885258507, 0.07051566615700722, 0.011126810459245462, 0.033340791414957494, 0.06676169025013223, 0.03726388422364835, 0.051806160336127505, 0.03327017606352456, 0.04078306315932423, 0.13956630311440676, 0.13737395434873179, 0.11705429235007614, 0.1458805549191311, 0.15239753178320825, 0.14982005290221423, 0.16299934883136302, 0.11688732396578416, 0.12303937939577736, 0.1013120413699653, 0.14014262531418353, 0.2195883763488382, 0.266350478050299, 0.13366593222599477, 0.2557491953484714, 0.20122500078286976, 0.16141109343152493, 0.20750042342115194, 0.09465286901104264, 0.19977002026280388, 0.18847856990760192, 0.10824304757989012, 0.1768849912332371, 0.12533152475953102, 0.1358050393173471, 0.24479390820488334, 0.08959957063780166, 0.1459177810465917, 0.08900169646949507, 0.14593596366466954, 0.0747124815825373, 0.3072052920470014, 0.13458350877044722, 0.12084202855476178, 0.08473583162412979, 0.15234994527418166, 0.22040047886548564, 0.12556234752992168, 0.12720525468466803, 0.14843484910670668, 0.13359260803554207, 0.15198921697447076, 0.21495188295375556, 0.12125237684813328, 0.13566812791395932, 0.22698711371049285, 0.12737205979647115, 0.24700972368009388, 0.14666084898635745, 0.12821136944694445, 0.19250041659688577, 0.2588299987837672, 0.25634736637584865, 0.16643863928038627, 0.14870138402329758, 0.1186610123841092, 0.18828975269570947, 0.14114198653260246, 0.20756825571879745, 0.1578576012980193, 0.13338464341359213, 0.13051465444732457, 0.21128487191163003, 0.1871690503321588, 0.15391465974971652, 0.2601580275222659, 0.09057045564986765, 0.08599210952525027, 0.7861419534310699, 4.255389757454395, 15.437170397490263, 28.621251694858074, 39.792912527918816, 52.20976464450359, 55.56388646364212, 61.20421640574932, 61.61069959402084, 64.44333359599113, 66.41178756952286, 63.61653596162796, 53.90184424817562, 65.09983956813812, 63.76717507839203, 50.222482681274414, 47.52612076699734, 51.3968400657177, 41.92174829542637, 40.99122002720833, 42.313115894794464, 42.28446923196316, 47.72933006286621, 43.21861490607262, 49.77361276745796, 38.517833948135376, 36.281365156173706, 41.851239278912544, 41.7548156529665, 32.88512259721756, 65.87232291698456, 72.78082340955734, 50.747534707188606, 36.13220416009426, 42.0386528223753, 42.044557705521584, 52.38585479557514, 61.34462267160416, 52.61264182627201, 51.941825821995735, 45.21377004683018, 46.22757464647293, 40.09617805480957, 24.976728558540344, 15.048649795353413, 7.743131406605244, 1.830871431156993, 0.5120855779387057, 0.15982792916474864, 0.29687198402825743, 0.14453907846473157, 0.11561578750843182, 0.1775865731178783, 0.14603015704778954, 0.13059370801784098, 0.115186477341922, 0.15910047601209953, 0.15037323493743315, 0.07467256145901047, 0.09367166072479449, 0.20231935690389946, 0.09969593316782266, 0.20948451070580631, 0.14375862112501636, 0.07125578777049668, 0.11546643770998344, 0.19906800793251023, 0.08901011984562501, 0.09678811693447642, 0.08548127443646081, 0.12844906450482085, 0.09999248053645715, 0.1737349751056172, 0.13830762065481395, 0.11372869892511517, 0.18991063290741295, 0.2664015971822664, 0.13625674007926136, 0.1226660716929473, 0.17212886363267899, 0.18734574085101485, 0.22190136864082888, 0.09004382023704238, 0.10946073380182497, 0.23631831456441432, 0.168761353706941, 0.08889205157174729, 0.14319800277007744, 0.09951907937647775, 0.13517485203919932, 0.13722614821745083, 0.06938400969374925, 0.15494237100938335, 0.1272957373294048, 0.1759254833450541, 0.15170988743193448, 0.2035918433102779, 0.11311822308925912, 0.1208585561835207, 0.09445195479202084, 0.16149768722243607, 0.0924382261291612, 0.1129753225541208, 0.1236613436776679, 0.08472563451505266, 0.16192140901694074, 0.13473553030053154, 0.11027935979655012], [0.030285245120467152, 0.05035896123445127, 0.004934929529554211, 0.03147760369756725, 0.03910124520189129, 0.006944745218788739, 0.1010465231956914, 0.07090278522809967, 0.06707426058710553, 0.02161237378459191, 0.024017672549234703, 0.09719359673908912, 0.02147351795429131, 0.009511745902273105, 0.028602777783817146, 0.03522980958223343, 0.031706496883998625, 0.04190814419416711, 0.04821031754545402, 0.06680717648123391, 0.02178709390136646, 0.05992491824144963, 0.009225591384165455, 0.02865959846531041, 0.028578285055118613, 0.03171254909830168, 0.002654491545399651, 0.08431439564446919, 0.02352268416871084, 0.03314389592560474, 0.04371011586044915, 0.050142313484684564, 0.053909217604086734, 0.052094395650783554, 0.03552960384695325, 0.04173876754066441, 0.026841754115594085, 0.09114415806834586, 0.0035186816967325285, 0.031869854719843715, 0.04221692586725112, 0.04648631962481886, 0.03280709817772731, 0.005206031901252572, 0.02126999694155529, 0.08860982765327208, 0.017065374122466892, 0.045931619897601195, 0.04165326099609956, 0.05131413498020265, 0.07328245948883705, 0.01807643158826977, 0.06121749829617329, 0.04766660902532749, 0.03441456035943702, 0.05099968700960744, 0.03910705621819943, 0.040546199306845665, 0.06763519806554541, 0.07774564655846916, 0.04459206931642257, 0.06786901911254972, 0.014899523739586584, 0.052295476853032596, 0.02571980865468504, 0.0575784773536725, 0.048773511152830906, 0.06179878917464521, 0.0359138916246593, 0.05890010877919849, 0.27801338816061616, 0.830020752036944, 5.199026372283697, 7.07183045335114, 18.366848342120647, 19.656054563820362, 31.00472129881382, 34.140028059482574, 40.919065698981285, 49.47685249149799, 47.20096081495285, 47.978767678141594, 45.591332986950874, 45.4415450245142, 49.67153124511242, 53.11398312449455, 50.69295063614845, 51.266434863209724, 46.344802156090736, 48.222030624747276, 47.89064660668373, 40.50092853605747, 41.847990453243256, 37.16419458389282, 42.277667596936226, 39.94727924466133, 43.14733073115349, 35.12243874371052, 42.45460890233517, 56.97584509849548, 43.09575229883194, 41.47324696183205, 45.82198441028595, 43.72954688966274, 44.00877110660076, 41.00985802710056, 27.060147263109684, 24.135202914476395, 18.525444231927395, 11.203818507492542, 6.314577162265778, 2.5857581617310643, 0.7119477877859026, 0.07168791809817776, 0.06533082210808061, 0.01964468610822223, 0.04058323618664872, 0.03270546476414893, 0.08169182387064211, 0.014351559002534486, 0.025379802973475307, 0.02522351780498866, 0.046592428188887425, 0.036222124108462594, 0.04773725406266749, 0.03023002005647868, 0.04542221715382766, 0.042761502700159326, 0.026836495999305043, 0.038055466357036494, 0.036659809411503375, 0.0817714117874857, 0.0314253156830091, 0.01646837939915713, 0.03394390885659959, 0.040902200125856325, 0.04510467071668245, 0.04685675892687868, 0.0269140114687616, 0.08391885319724679, 0.012196373281767592, 0.04247209850291256, 0.05140193105034996, 0.01755616751324851, 0.011047539810533635, 0.03565883402188774, 0.030946994083933532, 0.04732816742034629, 0.017461081697547343, 0.02259400880575413, 0.049557760867173783, 0.018931519298348576, 0.07156966428738087, 0.0031895565962258843, 0.028549896051117685, 0.08361918880837038, 0.012128250618843595, 0.09861026759608649, 0.028057551571691874, 0.0331465825001942, 0.01672001013503177, 0.024673402695043478, 0.03400134366529528, 0.03044273627892835, 0.048759566197986715, 0.028727974386129063, 0.07614601403474808, 0.017598828017071355, 0.023565292722196318, 0.045088291517458856, 0.05951089260634035, 0.010975341829180252, 0.026283115439582616, 0.02525030191463884, 0.05076609231764451, 0.06588624542928301, 0.051879926104447804, 0.03340576273330953, 0.017373142763972282, 0.0899602692516055, 0.11748011442250572, 0.052574416768038645, 0.06477709830505773, 0.13495197024894878, 0.01695300183200743, 0.01702893652691273, 0.047463390437769704, 0.04222119692713022, 0.03735214784683194, 0.03179517610988114, 0.007219802309919032, 0.049651471854303963, 0.0038979840974207036, 0.09969840451958589, 0.03661968890810385, 0.03151231023366563, 0.03234209070797078, 0.06169376785692293, 0.05494227974850219, 0.02882552784285508, 0.027955027580901515, 0.037474565106094815, 0.04077947487530764, 0.03828933935437817, 0.02860397635231493, 0.03227044006052893, 0.03880660515278578, 0.0683221522194799, 0.06047682749340311, 0.07938262395327911, 0.02553314367105486, 0.07443277354468592, 0.016583672040724196, 0.05421883048256859, 0.03332787433464546, 0.02707063245907193, 0.04466361235245131, 0.08511485386407003, 0.0207345355374855, 0.055682920865365304, 0.020194231619825587, 0.07827121327864006, 0.023933923039294314, 0.07277835567947477, 0.019399970333324745, 0.024094169421005063, 0.013044447696302086, 0.035780939579126425, 0.04778351212735288, 0.026503438675717916, 0.0480002452241024, 0.04283964342903346, 0.05548467466724105, 0.02716349368711235, 0.0612097057455685, 0.008078844275587471, 0.04006063434644602, 0.033075507017201744, 0.015382460569526302, 0.022219111051526852, 0.03209668102499563, 0.008958394100773148, 0.048919617765932344, 0.030409382306970656, 0.03344655116961803, 0.06537532128277235, 0.2738005423452705, 1.558480910025537, 7.275475300848484, 12.255415879189968, 24.33605443686247, 27.427825033664703, 38.39013800024986, 41.49580255150795, 49.511875212192535, 57.36115202307701, 53.767844438552856, 56.4887872338295, 52.75590553879738, 52.26121008396149, 52.470092475414276, 56.291547417640686, 51.00057452917099, 51.3199207931757, 48.11807580292225, 48.48511330783367, 50.297061279416084, 45.3962666541338, 44.81884203851223, 42.39154748618603, 43.92228774726391, 42.50349707901478, 42.611422687768936, 39.13357950747013, 45.59180796146393, 64.24327433109283, 47.82644145190716, 43.82597431540489, 48.926866203546524, 46.54509320855141, 51.5359316021204, 46.74582123756409, 34.38353419303894, 29.517547599971294, 23.787078894674778, 16.42902832478285, 9.02054401114583, 3.9025371288880706, 1.368803281802684, 0.13888467015931383, 0.10704296510084532, 0.0380099170433823, 0.09857677447143942, 0.04326221489463933, 0.06793978289351799, 0.0017514002161078679, 0.006829674293840071, 0.0306374201682047, 0.056610772444400936, 0.06537259017932229, 0.01740670824801782, 0.10318658023606986, 0.046840409413562156, 0.014067520532989874, 0.05051909072790295, 0.010183572303503752, 0.020189825117995497, 0.033238864853046834, 0.01245099023435614, 0.002646972429829475, 0.058089227095479146, 0.03334967121190857, 0.027605737632256933, 0.06347750866552815, 0.021756294772785623, 0.08390250368393026, 0.015007492311269743, 0.02636777593579609, 0.06234553307876922, 0.07091998078976758, 0.06732867623213679, 0.03280271208495833, 0.01168661337942467, 0.018446347676217556, 0.014589515667466912, 0.011682595577440225, 0.07310891567612998, 0.06712269314448349, 0.07654450280824676, 0.05767113820184022, 0.09835922872298397, 0.040594501988380216, 0.04906816975562833, 0.05533666073461063, 0.021436700008052867, 0.030744712457817513, 0.03205524320947006, 0.04231793587678112, 0.04927719564875588, 0.02824150215019472, 0.06833265360910445, 0.024250979658972938, 0.02082107552269008, 0.0072679496042837854, 0.022260127698245924, 0.025053649478650186, 0.04387385219160933, 0.08895020626368932, 0.02529275090637384, 0.033715694735292345, 0.032152293861145154, 0.05802920219139196, 0.1385401503648609, 0.13791034900350496, 0.13896283315261826, 0.19672954513225704, 0.2303679526085034, 0.09181372370221652, 0.14130318100797012, 0.25523132469970733, 0.1622812170535326, 0.1417863488313742, 0.18657246750080958, 0.2823766227811575, 0.09186787821818143, 0.11398664719308726, 0.10136859302292578, 0.1335488658514805, 0.14570291445124894, 0.15920203150017187, 0.14774214330827817, 0.11324939026962966, 0.10451435664435849, 0.1823167403927073, 0.10339294181903824, 0.18741104984655976, 0.08212190587073565, 0.13030422589508817, 0.13000576378544793, 0.2176092317677103, 0.15638890588888898, 0.1098825853841845, 0.08790742940618657, 0.12220953954965807, 0.1586205291096121, 0.19245885632699355, 0.10205873841186985, 0.16755356773501262, 0.13555600424297154, 0.23171389679191634, 0.07987700562807731, 0.13220222404925153, 0.22654443746432662, 0.22161665110616013, 0.16753391566453502, 0.12203618869534694, 0.17544363654451445, 0.21724820660892874, 0.14791402471018955, 0.18608977465191856, 0.1408179648569785, 0.08377411955734715, 0.1132058707298711, 0.09663589502451941, 0.13439374160952866, 0.13938515970949084, 0.10799489566124976, 0.11538188482518308, 0.09346480932435952, 0.12134766118833795, 0.17073310649720952, 0.15369234199170023, 0.1534414812340401, 0.1756351551739499, 0.10042372770840302, 0.11470468991319649, 0.07953414824442007, 0.22004929458489642, 0.2907313354080543, 0.10235895199002698, 0.11502270761411637, 0.1620431212359108, 0.37210952024906874, 2.1204531798139215, 8.08737013489008, 13.598650451749563, 25.792248398065567, 28.974153958261013, 40.613170713186264, 49.397018775343895, 56.346754655241966, 64.27389308810234, 62.96609826385975, 64.6624906361103, 61.679692491889, 63.0531819909811, 64.37480047345161, 67.90477305650711, 64.92732122540474, 64.79001939296722, 59.85924817621708, 60.152729228138924, 62.50053584575653, 52.82731130719185, 57.827440202236176, 50.52391670644283, 56.41895838081837, 55.31738229095936, 56.825935542583466, 49.36748296022415, 53.83747950196266, 68.26417297124863, 56.69205352663994, 53.651950657367706, 57.76450797915459, 58.59486602246761, 56.58547684550285, 52.28421404957771, 40.48176236450672, 33.143763318657875, 25.77364269644022, 15.588012803345919, 8.596735652536154, 3.9630830800160766, 1.2167515908367932, 0.16902845265576616, 0.17044791398802772, 0.13676163798663765, 0.20736106293043122, 0.14162824169034138, 0.22519945807289332, 0.15187553479336202, 0.17127298924606293, 0.13884392625186592, 0.11762259935494512, 0.12677764403633773, 0.13639889104524627, 0.1388426942867227, 0.16152813012013212, 0.16377323074266315, 0.12038502885843627, 0.07238777077873237, 0.1390020630788058, 0.1513494411483407, 0.10672397518646903, 0.13976257148897275, 0.15347364591434598, 0.10697114004869945, 0.17530037235701457, 0.17631853959755972, 0.20233593648299575, 0.18232563132187352, 0.07434724102495238, 0.11619084805715829, 0.18888753780629486, 0.11317681564833038, 0.10236655900371261, 0.09684334756457247, 0.10495208276552148, 0.1661680670804344, 0.10523787641432136, 0.13841374777257442, 0.2187990429229103, 0.13533010933315381, 0.33121935033705086, 0.18925521260825917, 0.1988728082505986, 0.23237356217578053, 0.16672708239639178, 0.136612169444561, 0.10708037676522508, 0.1415329350857064, 0.10744213665020652, 0.08600805085734464, 0.0965397794789169, 0.0941855831479188, 0.16009862010832876, 0.11228122151806019, 0.20695265906397253, 0.13339843251742423, 0.12645310285734013, 0.13860253529855981, 0.10642193592502736, 0.16343693394446746, 0.09037236159201711, 0.1284377244883217, 0.2038199795060791, 0.1666518731508404], [0.03876859605952632, 0.05000815544917714, 0.028504942310974002, 0.08346280344994739, 0.0720979472680483, 0.042585576593410224, 0.05637101421598345, 0.06525927907205187, 0.08018317123060115, 0.05228883834206499, 0.03267784202762414, 0.022305250276986044, 0.04245908494340256, 0.04084754466020968, 0.0377031688549323, 0.018737243590294383, 0.07272663540788926, 0.060949672042625025, 0.019870293435815256, 0.00526540788996499, 0.044188615574967116, 0.0296101003914373, 0.05875255126738921, 0.021690779831260443, 0.1005793412332423, 0.03185087800375186, 0.05720856868720148, 0.01415436943716486, 0.03663288429379463, 0.02783207226457307, 0.04177326998615172, 0.041889664717018604, 0.09747752759722061, 0.02229963407444302, 0.029222593548183795, 0.03736339509487152, 0.007993000053829746, 0.035768430680036545, 0.005992263149892096, 0.0455583196162479, 0.06833194114733487, 0.04848715347179677, 0.027653023571474478, 0.06105753578594886, 0.03229391048080288, 0.059100640792166814, 0.02271085439133458, 0.034596137920743786, 0.10112648960785009, 0.03657184635812882, 0.025250400249205995, 0.03553270973498002, 0.07642439362825826, 0.018093901744578034, 0.05046978985774331, 0.028791808363166638, 0.02865458340238547, 0.004527460305325803, 0.045458738240995444, 0.03856829040159937, 0.055225015748874284, 0.020928091362293344, 0.028167240998300258, 0.07136604122933932, 0.08638765197247267, 0.03147233815980144, 0.027896512947336305, 0.030743196621187963, 0.06682057224679738, 0.08767220570007339, 0.036990528969909064, 0.05503448046511039, 0.049297356090391986, 0.5246934201568365, 1.2498343968763947, 2.848005839623511, 4.97917634434998, 10.34236578270793, 11.400478854775429, 15.90755570679903, 20.210023038089275, 24.918641075491905, 34.55415643751621, 34.68249835073948, 36.99073389172554, 45.8323160558939, 43.666983246803284, 49.33716058731079, 51.66798211634159, 50.73448620736599, 43.065160140395164, 47.15445891022682, 44.70420598983765, 38.15768927335739, 45.05854457616806, 44.58988532423973, 44.99313488602638, 46.75092056393623, 46.51271894574165, 47.595964819192886, 46.433493196964264, 41.449585631489754, 32.97388203442097, 29.08035635948181, 20.008789636194706, 17.709403820335865, 8.57806820422411, 4.243457922711968, 1.2239930522628129, 0.4076063248794526, 0.06629383293329738, 0.009172537102131173, 0.06797404785174876, 0.029895810548623558, 0.04935682809446007, 0.060645094636129215, 0.04946773093251977, 0.007986716846062336, 0.07019527358352207, 0.03744951762200799, 0.023734467140457127, 0.016037818713812158, 0.032783761344035156, 0.03244707862904761, 0.024105568809318356, 0.08952816860983148, 0.06435667906771414, 0.024253180126834195, 0.10895806233747862, 0.025925188747351058, 0.07148254357161932, 0.02460023435560288, 0.01792740833479911, 0.04921574211039115, 0.03477952632238157, 0.032149863327504136, 0.01361730499411351, 0.07271043432410806, 0.04010004238807596, 0.032488891229149885, 0.04737857037980575, 0.01412102752510691, 0.030424297619902063, 0.054444688285002485, 0.03392503975192085, 0.03907638696546201, 0.05009037056879606, 0.029656965161848348, 0.047375601789099164, 0.023461332675651647, 0.024798565900709946, 0.05012249072024133, 0.032747852528700605, 0.07174414320616052, 0.0409725186182186, 0.08255543885752559, 0.06671995186479762, 0.024401507616857998, 0.07563380597275682, 0.056898974362411536, 0.009184467126033269, 0.02456490256008692, 0.024682143339305185, 0.0498082691046875, 0.008944681994762504, 0.04430530345416628, 0.10366450107540004, 0.021678228258679155, 0.03542525046213996, 0.03647517420176882, 0.03812085327808745, 0.09150674915872514, 0.025392608731635846, 0.04915480807540007, 0.029117787453287747, 0.08096647099591792, 0.011874266347149387, 0.04044297769723926, 0.021840227964275982, 0.08764692072873004, 0.10715987562434748, 0.033658567917882465, 0.0358003764267778, 0.06140421894087922, 0.07816513811121695, 0.0360638574056793, 0.02382153590588132, 0.06987822067458183, 0.036544134563882835, 0.039001585901132785, 0.042206498692394234, 0.036702234283438884, 0.023147057254391257, 0.06203471049957443, 0.02182010834076209, 0.06792218657210469, 0.019840355198539328, 0.03153351339278743, 0.03946398101106752, 0.06453063848312013, 0.03516289754770696, 0.025621648492233362, 0.041820236801868305, 0.02339818518521497, 0.03540465586411301, 0.03559138764103409, 0.054496352895512246, 0.02460480227455264, 0.05058437003754079, 0.036698493859148584, 0.008212079264922068, 0.02345272747334093, 0.0207177592892549, 0.013984195902594365, 0.03320219162560534, 0.051440370589261875, 0.04055616263940465, 0.05581398043432273, 0.03019289782969281, 0.02249075194413308, 0.09203921043081209, 0.03725290785951074, 0.06520452341646887, 0.059612036202452146, 0.07970055259647779, 0.04251931022736244, 0.04743117751786485, 0.019195291570213158, 0.023109619614842813, 0.0038211692617551307, 0.031229251399054192, 0.010694088268792257, 0.028632949797611218, 0.0037493866511795204, 0.03246136868256144, 0.011378966264601331, 0.04287839838070795, 0.028913138376083225, 0.021611199335893616, 0.04210450533719268, 0.03601016302127391, 0.04119228709896561, 0.048726529494160786, 0.0359596821363084, 0.03155663129291497, 0.07670286227948964, 0.0326729364314815, 0.023150831075327005, 0.042953685551765375, 0.5784601788036525, 2.1417709859088063, 4.084022752940655, 8.40425793081522, 14.189736284315586, 16.923522390425205, 24.475905932486057, 28.64731639623642, 31.863708905875683, 41.440884098410606, 42.45394393801689, 47.76475936174393, 53.45057666301727, 51.303642466664314, 55.04606544971466, 59.025831297039986, 57.70220272243023, 51.080799624323845, 53.79115618765354, 50.553760305047035, 45.150123462080956, 52.814034819602966, 53.321417793631554, 52.343445271253586, 50.346462428569794, 49.563548639416695, 52.34473340213299, 51.598476245999336, 47.59678557515144, 40.02129167318344, 36.581066474318504, 27.02013920992613, 23.34628164768219, 12.274101376533508, 6.565263960510492, 2.3939299676567316, 0.6095717812422663, 0.23916066595120355, 0.043164069575141184, 0.05248834619123954, 0.0829875394992996, 0.11136178218293935, 0.024959676884463988, 0.020112513739150017, 0.04207665995636489, 0.024878413569240365, 0.05108041412313469, 0.04507768993789796, 0.0771418574731797, 0.034928360328194685, 0.010671785803424427, 0.059456259405124, 0.04597798928443808, 0.05149953460204415, 0.0717447220813483, 0.07510481053031981, 0.030879291662131436, 0.006527212472065003, 0.008687342287885258, 0.03515782496833708, 0.019019539868168067, 0.049772382553783245, 0.03289692773250863, 0.025761636097740848, 0.022781453044444788, 0.035738225269597024, 0.018345035241509322, 0.08495257585309446, 0.02187241305364296, 0.01553994523419533, 0.013920150413468946, 0.07906894781626761, 0.01951676396856783, 0.018185011504101567, 0.02902959804487182, 0.04497179288591724, 0.05371758023102302, 0.034417803544783965, 0.0561708644090686, 0.005955740671197418, 0.027125195156258997, 0.026435854997544084, 0.040658144862391055, 0.04332692646130454, 0.028239164385013282, 0.05151117147761397, 0.055480121591244824, 0.011890049972862471, 0.01871754884632537, 0.052419389539863914, 0.07585843181004748, 0.04258664899680298, 0.031413808683282696, 0.05856072093592957, 0.02188065460359212, 0.024387397534155753, 0.03323785924294498, 0.0503604381083278, 0.05322302786225919, 0.08443586295470595, 0.05746789734985214, 0.0387147309811553, 0.026634236637619324, 0.18533406051574275, 0.17239971784874797, 0.08665248737088405, 0.15126848767977208, 0.18768073146929964, 0.1491379301296547, 0.13978461327496916, 0.21589346055407077, 0.1667699933750555, 0.13930245477240533, 0.11696062589180656, 0.1361855532741174, 0.16514846007339656, 0.12651260825805366, 0.12393219047226012, 0.05773515586042777, 0.14361850364366546, 0.17908568173879758, 0.13226181850768626, 0.12036342493956909, 0.15534353151451796, 0.10535385183175094, 0.12145229658926837, 0.2206695222412236, 0.18612572428537533, 0.12350205652182922, 0.08932456039474346, 0.1082063112698961, 0.09186271287035197, 0.12614849576493725, 0.18254793423693627, 0.1389417561586015, 0.17074349656468257, 0.17148319515399635, 0.10467823769431561, 0.11321039783069864, 0.1265776649233885, 0.12502914411015809, 0.13743623538175598, 0.19243675516918302, 0.13225473841885105, 0.19070623005973175, 0.1634762083995156, 0.1391254080226645, 0.18906390178017318, 0.18200208462076262, 0.22516634344356135, 0.13400700845522806, 0.2361651204410009, 0.11673732107738033, 0.16804619051981717, 0.15433170221513137, 0.18234449671581388, 0.15484759875107557, 0.18089597288053483, 0.1129811855207663, 0.138183711678721, 0.13651425048010424, 0.1440035447012633, 0.10881493173656054, 0.21333572280127555, 0.10849611251614988, 0.06623054257943295, 0.21253883431199938, 0.13392710883636028, 0.14924358227290213, 0.11614810777246021, 0.15900925121968612, 0.20750539581058547, 0.1779532534419559, 0.0809682669932954, 0.1320930541260168, 0.1591758633730933, 0.7073024183046073, 1.7979319486767054, 4.303300436586142, 7.303065145388246, 13.324631955474615, 16.378399841487408, 24.124432392418385, 31.893193423748016, 35.06245516240597, 46.17847368121147, 48.17042179405689, 53.88472996652126, 59.79264535009861, 57.05030210316181, 63.6302076280117, 69.6673084795475, 64.96628433465958, 59.18824978172779, 63.3353890478611, 60.67479841411114, 56.10777027904987, 61.03333197534084, 60.887640193104744, 59.783218055963516, 61.155153438448906, 59.82149340212345, 61.67432337999344, 58.20624567568302, 56.13567218184471, 47.40241460502148, 41.032816395163536, 30.17579197883606, 23.175252825021744, 12.367817647755146, 6.451983964070678, 1.9721339573152363, 0.656012948602438, 0.28412607265636325, 0.12264161792700179, 0.273482131306082, 0.1722762838471681, 0.1336567592807114, 0.16599569586105645, 0.12890515878098086, 0.12493771151639521, 0.10773584901471622, 0.15680424141464755, 0.18042493175016716, 0.17513496248284355, 0.12190207518870011, 0.1998464169446379, 0.10368820527219214, 0.16020844312151894, 0.13918488373747095, 0.13176126958569512, 0.27247153397183865, 0.13998724927660078, 0.11801251632277854, 0.07613315261551179, 0.2008227418991737, 0.11998652524198405, 0.20238148950738832, 0.1771511699189432, 0.08881035595550202, 0.15167309175012633, 0.10836605855729431, 0.11351507171639241, 0.1263628131709993, 0.13891351001802832, 0.10092462543980218, 0.20237616088707, 0.08135943076922558, 0.1023282493406441, 0.12236199894687161, 0.1422478904714808, 0.13573465403169394, 0.12387650713208131, 0.13769359735306352, 0.13370924396440387, 0.1755549290101044, 0.26338111551012844, 0.09767087190994062, 0.1812562410486862, 0.13886187138268724, 0.06921572028659284, 0.19198926980607212, 0.14631858532084152, 0.12927850359119475, 0.11602764978306368, 0.1485089006018825, 0.22715682804118842, 0.1251372304977849, 0.07245409651659429, 0.21100135665619746, 0.12335096267634071, 0.14271185151301324, 0.07842992155929096, 0.09395739500178024, 0.14258623559726402, 0.14389002579264343, 0.15439695183886215, 0.13815978483762592, 0.12146802269853652], [0.03967776778154075, 0.018328424121136777, 0.0455457921634661, 0.021381257865868974, 0.018236961841466837, 0.03255063791584689, 0.0416810507158516, 0.030573289332096465, 0.032291587558574975, 0.12171903930720873, 0.06682732579065487, 0.03638102534750942, 0.044940711741219275, 0.08097271987935528, 0.02466069156071171, 0.06516473687952384, 0.031113097866182216, 0.01180114624730777, 0.04365565335319843, 0.07474039375665598, 0.01323651644270285, 0.03376288048457354, 0.014052697060833452, 0.02660929490957642, 0.01691395929810824, 0.020128436517552473, 0.013830637199134799, 0.11940078518819064, 0.08267533281468786, 0.046957943341112696, 0.06968612316995859, 0.0036557811881721136, 0.03794199939875398, 0.05013632806367241, 0.0469083233474521, 0.0632053853769321, 0.07746839502942748, 0.021452578257594723, 0.03498962090816349, 0.023342334861808922, 0.017380386125296354, 0.0486614802503027, 0.09781414351891726, 0.03240327336243354, 0.01900555223983247, 0.05764172688941471, 0.03471431009529624, 0.054413406760431826, 0.0247687204318936, 0.010150825037271716, 0.020956894113624003, 0.015901024198683444, 0.03596265072701499, 0.018611013547342736, 0.02641970400873106, 0.0903629140520934, 0.020726627953990828, 0.0036938345783710247, 0.037659393274225295, 0.028208322582941037, 0.1118434731324669, 0.02740114607149735, 0.016791313828434795, 0.08978275494882837, 0.05876549432286993, 0.07007986219832674, 0.02943461215181742, 0.03700352397572715, 0.0533156033634441, 0.044609810356632806, 0.03917897403880488, 0.03149790514726192, 0.07113125539035536, 0.053264510206645355, 0.08070300857070833, 0.10144158324692398, 0.05503629130544141, 0.026332917259423994, 0.6416797020938247, 0.5798667564522475, 1.1463841167278588, 2.5507489778101444, 4.371659243479371, 6.772005166858435, 7.555125569924712, 11.009625177830458, 14.879533220082521, 16.945224925875664, 16.31897673010826, 20.103482455015182, 19.16688021272421, 19.023798890411854, 23.563810475170612, 23.56404986232519, 22.008293643593788, 22.4644173681736, 22.639612667262554, 27.575583904981613, 27.081971392035484, 28.054054230451584, 20.246537178754807, 12.48381782323122, 10.062288511544466, 5.1241713389754295, 1.9848694489337504, 0.8520494762342423, 0.3066814545309171, 0.05363856005715206, 0.011183980877831345, 0.049394911402487196, 0.07378255570074543, 0.039193598058773205, 0.026573816539894324, 0.027801666474260855, 0.052514339913614094, 0.028535804522107355, 0.1081100398732815, 0.01426774455467239, 0.006456412511397502, 0.09779694053577259, 0.0469776399404509, 0.019225077667215373, 0.04165071171883028, 0.06203122982697096, 0.08345169349922799, 0.056164982888731174, 0.07740451095742173, 0.0771217378496658, 0.05505827743036207, 0.03271640031016432, 0.03064980290218955, 0.048083566143759526, 0.026248156573274173, 0.046363842993741855, 0.0842704605020117, 0.03296268572739791, 0.045315396127989516, 0.025800858602451626, 0.03521392020047642, 0.0028251555932001793, 0.05904122815991286, 0.025321844950667582, 0.03326902573462576, 0.04203396791126579, 0.02788046400382882, 0.009887539799819933, 0.022837325632281136, 0.035851102220476605, 0.02041148421994876, 0.07257755278260447, 0.08285576375783421, 0.04559579807391856, 0.04016675775346812, 0.05970129059278406, 0.022907820384716615, 0.02070684600766981, 0.07473603734979406, 0.05752330609539058, 0.07925206533400342, 0.03138922504149377, 0.023457681309082545, 0.045265200969879515, 0.04290277051040903, 0.07872622401919216, 0.060276336298557, 0.025062045024242252, 0.0170155314845033, 0.0213737714511808, 0.016417930055467878, 0.05043760662374552, 0.034565954774734564, 0.0033288110989815323, 0.039028273531585, 0.05358392314519733, 0.0513073294860078, 0.06964246262214147, 0.04733211564598605, 0.04102313680050429, 0.048370643708040006, 0.041573060807422735, 0.05303876743710134, 0.04749667576106731, 0.07224568660603836, 0.012094829853595002, 0.05555953881412279, 0.03293726716947276, 0.05889232736080885, 0.0397008188883774, 0.032047740096459165, 0.04451609194802586, 0.07320065255044028, 0.042581342640914954, 0.04236434237100184, 0.02344820779399015, 0.013889591555198422, 0.0111212248702941, 0.05789979019027669, 0.01091682997866883, 0.028841712228313554, 0.012952030829183059, 0.028693197346001398, 0.053994059926480986, 0.01685130162513815, 0.04226478697091807, 0.02217668246885296, 0.05879014475794975, 0.034183685638708994, 0.06625273279496469, 0.04733695444883779, 0.024579387427365873, 0.017729395913193002, 0.08030600409256294, 0.03853139452985488, 0.014014308544574305, 0.06029850053892005, 0.03791181254200637, 0.02507708650227869, 0.03236354990804102, 0.03368416830198839, 0.04369156959000975, 0.023213640888570808, 0.001334014275471418, 0.06823636736953631, 0.045852069088141434, 0.008715892709005857, 0.031835804984439164, 0.014232572320906911, 0.005293584918035776, 0.013667956573044648, 0.04079189842741471, 0.010701440169214038, 0.07420277455821633, 0.04560473724268377, 0.01698663596471306, 0.05877501236682292, 0.02673596281965729, 0.005780702822448802, 0.057046368601731956, 0.030781910754740238, 0.09653883695136756, 0.053986827697372064, 0.07880812001531012, 0.03426774870604277, 0.01946909582329681, 0.05817867444420699, 0.029729421039519366, 0.032005864413804375, 0.015386064624181017, 0.052992732016718946, 0.058852099245996214, 0.01852513407357037, 0.059679456608137116, 0.06713474562275223, 0.32006867055315524, 1.052652052603662, 0.9945903962943703, 2.2633452247828245, 4.279309473931789, 7.276857476681471, 11.277644746005535, 12.02164102345705, 16.539402902126312, 19.81740340590477, 23.264407441020012, 23.82942382246256, 27.59934403002262, 26.420208401978016, 26.725666411221027, 31.725685112178326, 30.138075202703476, 29.308568313717842, 30.58760818094015, 31.43047895282507, 35.48353336751461, 33.043357506394386, 33.762978091835976, 26.876003444194794, 17.993094697594643, 12.991570327430964, 7.411045376211405, 2.85943491384387, 1.4319047145545483, 0.4682535643223673, 0.06681353668682277, 0.0632646978192497, 0.06820426948252134, 0.031447086585103534, 0.0423893824336119, 0.035322700496180914, 0.024401236732956022, 0.025133703093160875, 0.021388245186244603, 0.01772931242157938, 0.04661513419705443, 0.020570841879816726, 0.01531829169834964, 0.039354926120722666, 0.009458476397412596, 0.05042513112130109, 0.006613546511289314, 0.05513969103049021, 0.0635549369326327, 0.024584912716818508, 0.05780167455668561, 0.02786068947898457, 0.031990279312594794, 0.03987401018093806, 0.05363022573874332, 0.05115961983392481, 0.012446648670447757, 0.02051319184829481, 0.03267949330620468, 0.04533044317213353, 0.06920642859768122, 0.0186693611976807, 0.021902841108385473, 0.034957463649334386, 0.04320251653552987, 0.052881506344419904, 0.05027103157772217, 0.01675907307799207, 0.04291130891942885, 0.06197357979544904, 0.09305550003773533, 0.025532596337143332, 0.033943671369343065, 0.05550912472244818, 0.05619172989099752, 0.025629502270021476, 0.06848800738225691, 0.019641186881926842, 0.03130785597022623, 0.06330322270514444, 0.050781640311470255, 0.010539791128394427, 0.02958640547149116, 0.030777283463976346, 0.0624937325483188, 0.046995366137707606, 0.06495971858385019, 0.06793899621698074, 0.023278474909602664, 0.011802291010098998, 0.027638080428005196, 0.05459463551233057, 0.05208679605857469, 0.0312525771005312, 0.014504364426102256, 0.02586697468359489, 0.04556531064736191, 0.07597903822897933, 0.0452619503630558, 0.1207598060136661, 0.13230415061116219, 0.10794379137223586, 0.09186934767058119, 0.1390914770308882, 0.132028472435195, 0.13994071661727503, 0.10625742404954508, 0.0880114191386383, 0.18431380041874945, 0.17685247032204643, 0.09961851232219487, 0.13101885473588482, 0.20012127875816077, 0.11365885540726595, 0.15526916831731796, 0.20187155983876437, 0.11134337692055851, 0.1675550965592265, 0.12615106359589845, 0.11693039821693674, 0.12037483174935915, 0.11092276472481899, 0.09569270696374588, 0.1524836802855134, 0.1622895142645575, 0.11459364235633984, 0.1628847760730423, 0.13106397731462494, 0.2098597405711189, 0.24504680244717747, 0.1840433618053794, 0.15121551317861304, 0.09824591019423679, 0.16269460815237835, 0.1947636849945411, 0.20926674973452464, 0.11734763364074752, 0.16440549603430554, 0.23030262877000496, 0.11367084109224379, 0.18071549740852788, 0.22737739433068782, 0.13845567911630496, 0.10213589208433405, 0.11910467568668537, 0.10946837050141767, 0.17269665113417432, 0.17655751114943996, 0.11786102913902141, 0.0850974208151456, 0.13048084219917655, 0.18294053035788238, 0.1543193231918849, 0.09918260446283966, 0.15833495068363845, 0.09008182561956346, 0.15682763390941545, 0.2053945793886669, 0.07788860646542162, 0.1586518922704272, 0.19004889501957223, 0.10023822789662518, 0.1828066914458759, 0.15010512666776776, 0.20343658601632342, 0.167945614666678, 0.11964494435233064, 0.15083862090250477, 0.17124337755376473, 0.0754049424722325, 0.13605864602141082, 0.12172051618108526, 0.21365024498663843, 0.21972322458168492, 0.16892924235435203, 0.14786447893129662, 0.26232634554617107, 0.9428131277672946, 0.9028012154158205, 2.01304339338094, 3.624240537174046, 6.441166419535875, 11.26894986256957, 12.515256386250257, 16.03270199149847, 20.858992114663124, 23.279057554900646, 24.64516595005989, 29.3122636154294, 28.9176319912076, 28.351587764918804, 33.19499596953392, 32.98509903252125, 32.10226960480213, 33.754040971398354, 34.5770388096571, 38.01383279263973, 36.06236390769482, 35.46649508178234, 28.657600544393063, 18.520365804433823, 12.824774477630854, 7.501966897398233, 2.7519678929820657, 1.1407230142503977, 0.5541156569961458, 0.1617796884966083, 0.18436822952935472, 0.14528449159115553, 0.20173347584204748, 0.1879696050309576, 0.17952417227206752, 0.11265216176980175, 0.11273897078353912, 0.12399297236697748, 0.1787560642696917, 0.10974021919537336, 0.12778764765243977, 0.14305690565379336, 0.10077100829221308, 0.1734258112264797, 0.13649351487401873, 0.1094150249264203, 0.22643954231170937, 0.2202060361742042, 0.15891069400822744, 0.23894974758150056, 0.10638479885528795, 0.11524256144184619, 0.12076874889316969, 0.18000192241743207, 0.1482502621365711, 0.08053664132603444, 0.22120878158602864, 0.12256197063834406, 0.1725531939882785, 0.11963524448219687, 0.10309036821126938, 0.1096964770113118, 0.2232231039670296, 0.2184009994380176, 0.11996902539976873, 0.13452750630676746, 0.0999994641460944, 0.10259160044370219, 0.15392251167213544, 0.22189022158272564, 0.10777421804959886, 0.19509125413605943, 0.1855445929686539, 0.15529560361756012, 0.15246322669554502, 0.21412468515336514, 0.11469642238807864, 0.1057933145784773, 0.18073080049362034, 0.22841727681225166, 0.19998490170110017, 0.13234339538030326, 0.11169287652592175, 0.18732202181126922, 0.1557585850241594, 0.260919263237156, 0.13455737032927573, 0.11890585432411171, 0.0930577190592885, 0.1801797261578031, 0.14916231710230932, 0.10535456429352053, 0.17104553582612425, 0.15705922851338983, 0.1608714778558351, 0.10399860853794962, 0.12374620826449245, 0.13335377007024363], [0.019823666152660735, 0.049717240981408395, 0.023415805626427755, 0.011079571831942303, 0.04463221208425239, 0.060152119331178255, 0.028043474885635078, 0.01495690381489112, 0.06249693120480515, 0.02779319114779355, 0.025674409625935368, 0.04471129162993748, 0.01334211014182074, 0.02762510768661741, 0.013148603484296473, 0.012037744781991933, 0.03002765864948742, 0.05882905927137472, 0.04001225373940542, 0.039864195277914405, 0.05082803196273744, 0.05347513171727769, 0.04450553489732556, 0.030177620719769038, 0.025121884391410276, 0.0368342029833002, 0.04490936342335772, 0.08263532363343984, 0.022775489887862932, 0.014870718205202138, 0.040816385590005666, 0.07075910543790087, 0.04324288936913945, 0.0065107618411275325, 0.04169272469880525, 0.023293087797355838, 0.07102274597855285, 0.06933047116035596, 0.05126151299919002, 0.010415637243568199, 0.0323594161454821, 0.015183132691163337, 0.018220719939563423, 0.00803845381597057, 0.02587724415207049, 0.03248786335461773, 0.06094625445257407, 0.02575854134192923, 0.13419199618510902, 0.01643986423005117, 0.029222294833743945, 0.04634687378711533, 0.06267210032092407, 0.0247373591264477, 0.022876965595060028, 0.018739115657808725, 0.004826093108931673, 0.08265089389169589, 0.053169719394645654, 0.016764412830525544, 0.047160237954813056, 0.06110239861300215, 0.04141527650062926, 0.0644699604890775, 0.014217238622222794, 0.03759692670428194, 0.013165318505343748, 0.04773250060679857, 0.018677701082197018, 0.018494208779884502, 0.06935791578143835, 0.06631085037952289, 0.0574272276571719, 0.036074121308047324, 0.018538739495852496, 0.012855277964263223, 0.023051153220876586, 0.028550929491757415, 0.024039987074502278, 0.011150138943776255, 0.08796256355708465, 0.03566888270142954, 0.026088047488883603, 0.021475701723829843, 0.21867894858587533, 0.1252587349154055, 0.442246631719172, 0.604797515552491, 0.9470006811898202, 0.45189469994511455, 1.0817436478100717, 1.402805163525045, 0.823537171818316, 1.9191719242371619, 1.9942013919353485, 2.597124776802957, 2.704597497358918, 2.861309163272381, 2.7835874212905765, 3.299626330845058, 1.2094264151528478, 0.9514907340053469, 0.23688587942160666, 0.024040912903728895, 0.007412576560454909, 0.036562484165187925, 0.048921777415671386, 0.025632597025833093, 0.08563967101508752, 0.062450918048853055, 0.032187148826778866, 0.02368536665017018, 0.034351600261288695, 0.03970835168729536, 0.021631133422488347, 0.055417751500499435, 0.006821049610152841, 0.014145299464871641, 0.04180190204351675, 0.03524995889165439, 0.025833735744527075, 0.03164616027788725, 0.030903324259270448, 0.02330072264157934, 0.00841171513457084, 0.04432257694134023, 0.052831518987659365, 0.030414920584007632, 0.09209658586769365, 0.04576980943966191, 0.04093216062756255, 0.01692440317128785, 0.02240918063762365, 0.061070638403180055, 0.021727013336203527, 0.024491843687428627, 0.06455820926930755, 0.0328051760152448, 0.0320148666651221, 0.08372608775971457, 0.05032464432588313, 0.05539092657272704, 0.011736868837033398, 0.03297717987152282, 0.015723021933808923, 0.021146557373867836, 0.07483714754926041, 0.04896860693406779, 0.044056850965716876, 0.01461049061617814, 0.04079767233633902, 0.027146351931151003, 0.010611789657559711, 0.08356510850717314, 0.026008164568338543, 0.09452855185372755, 0.05097870649478864, 0.0897528909263201, 0.014403815475816373, 0.036745130419149064, 0.01116622777772136, 0.09896547431708314, 0.009998787736549275, 0.029910935518273618, 0.026838906123884954, 0.07961798866745085, 0.02418302305159159, 0.02308292456291383, 0.010155189793294994, 0.056210521070170216, 0.0237603235655115, 0.04466282196517568, 0.09371540290885605, 0.05861625584657304, 0.03585680933611002, 0.05098466594063211, 0.0564665917045204, 0.017966306149901357, 0.037274693604558706, 0.08604678354458883, 0.0043064862984465435, 0.025324869202449918, 0.032782418056740426, 0.03545285093423445, 0.015834525911486708, 0.013058110635029152, 0.03295019909273833, 0.10290048972819932, 0.024840957376000006, 0.022206351677596103, 0.08074706245679408, 0.0653893849812448, 0.02894059227401158, 0.07604408005136065, 0.03024779634870356, 0.0382263681240147, 0.0019075645536759112, 0.03453658056969289, 0.06740531782270409, 0.034118551047868095, 0.055462918608100154, 0.031216527277138084, 0.020130458869971335, 0.06170455126266461, 0.014909976889612153, 0.06713996292091906, 0.02639559534145519, 0.029742236074525863, 0.11908536500413902, 0.060796437101089396, 0.04194777488010004, 0.04161681412369944, 0.038048067144700326, 0.01729665331367869, 0.11010313683073036, 0.02143324902135646, 0.005595551356236683, 0.014227301217033528, 0.058229162750649266, 0.013710913008253556, 0.04784489516168833, 0.042964461536030285, 0.07877598502091132, 0.04746154249005485, 0.04551208381599281, 0.045814393961336464, 0.0308512143601547, 0.02463371078192722, 0.024043423218245152, 0.05203033717407379, 0.051562483567977324, 0.04124656035855878, 0.04195168970909435, 0.04021231448859908, 0.02487162477336824, 0.026353521134296898, 0.05001825236831792, 0.009145208441623254, 0.046508220402756706, 0.07466072420356795, 0.040552418504375964, 0.07875014343881048, 0.028172376660222653, 0.029698113539780024, 0.015189277673925972, 0.022731599274266046, 0.0022842932094135904, 0.01819417331716977, 0.029889335310144816, 0.010437296823511133, 0.026793564611580223, 0.021385655090853106, 0.01646834600251168, 0.07135610387194902, 0.024661088609718718, 0.025650974457676057, 0.05967901131953113, 0.022368772551999427, 0.05214849079493433, 0.06160861383250449, 0.34751937724649906, 0.2799883618718013, 1.2047254736535251, 1.2697355914860964, 1.605295347981155, 1.4021486300043762, 1.9898911169730127, 2.2128041367977858, 1.9944631028920412, 3.6708740098401904, 3.474351642653346, 3.9443921204656363, 4.754615994170308, 4.9903258960694075, 4.698871560394764, 4.842017004266381, 2.0856261486187577, 1.4909852505661547, 0.4172564414329827, 0.032603430590825155, 0.024359557719435543, 0.024347406906599645, 0.026012225971498992, 0.0606295837496873, 0.051186838099965826, 0.06855775442090817, 0.021440325399453286, 0.10505672558792867, 0.05692965474736411, 0.013078573501843493, 0.021174031680857297, 0.013853725413355278, 0.02552239180658944, 0.02996687118866248, 0.0467402974027209, 0.035758422818616964, 0.015967459403327666, 0.04228958212479483, 0.015569824099657126, 0.034279452374903485, 0.03572182009520475, 0.033734767930582166, 0.023905450543679763, 0.03293688496341929, 0.03329380233481061, 0.03423387337534223, 0.050332800528849475, 0.03921792937035207, 0.0314781454653712, 0.03307773717097007, 0.03145870490698144, 0.036447840902837925, 0.06363531152601354, 0.08384231550735421, 0.042994781979359686, 0.022477079728560057, 0.022253472488955595, 0.017132657230831683, 0.04981756821507588, 0.009937033628375502, 0.041358268426847644, 0.08261613169452175, 0.06756211136234924, 0.061572448976221494, 0.024542933133488987, 0.022744865163986105, 0.013602456474473001, 0.02784827520372346, 0.03181145140843, 0.030903943952580448, 0.02923841242591152, 0.017515434738015756, 0.07023304147878662, 0.07088057274813764, 0.042454672875464894, 0.007293823191503179, 0.028248521011846606, 0.05514432203199249, 0.02019755273067858, 0.04937584191793576, 0.03961337904911488, 0.0577543366671307, 0.02689571752853226, 0.019220339054299984, 0.006767781960661523, 0.09996922162827104, 0.012114711989852367, 0.04293249723559711, 0.05005719285691157, 0.04131300112931058, 0.06756037473678589, 0.01733331911964342, 0.17043356085196137, 0.0869602856982965, 0.14057690044865012, 0.10415450407890603, 0.11723607400199398, 0.12320981360971928, 0.1578673382755369, 0.11250454117543995, 0.15165051561780274, 0.147743865090888, 0.15915067488094792, 0.22894777881447226, 0.10710089714848436, 0.10222340613836423, 0.19594439741922542, 0.09866601772955619, 0.13737586908973753, 0.22760892956284806, 0.11886178559507243, 0.08307646363391541, 0.11292999959550798, 0.20095910411328077, 0.233915121643804, 0.19234664359828457, 0.1762205018894747, 0.16440781153505668, 0.12759234406985343, 0.23773370892740786, 0.05680754176864866, 0.16201370250200853, 0.09381775991641916, 0.19557791005354375, 0.12823964527342469, 0.10799022755236365, 0.1329870749032125, 0.09468708944041282, 0.1112248633580748, 0.07141218055039644, 0.21020760003011674, 0.11397466892958619, 0.12643772555748, 0.16319255955750123, 0.1343679297133349, 0.08827917859889567, 0.11637202114798129, 0.12538426177343354, 0.12089590847608633, 0.1533453434240073, 0.22001613542670384, 0.14083555375691503, 0.07540520222391933, 0.13987622398417443, 0.21481207717442885, 0.11118210823042318, 0.16556962887989357, 0.11279267258942127, 0.13151778577594087, 0.1825930568156764, 0.14535318478010595, 0.14402664033696055, 0.15673295070882887, 0.13302373699843884, 0.11257833291892894, 0.19439327908912674, 0.15006968169473112, 0.15794345294125378, 0.102727398625575, 0.13293766271090135, 0.17005375935696065, 0.10412572359200567, 0.1620542979799211, 0.13478151377057657, 0.15275276819011196, 0.0982776444288902, 0.14241772354580462, 0.10380598410847597, 0.08567003227653913, 0.10491458946489729, 0.11554814074770547, 0.11380280979210511, 0.19458473834674805, 0.14044828625628725, 0.17412109969882295, 0.12020928086712956, 0.3630184486974031, 0.30078782234340906, 1.055253844242543, 1.0484853386878967, 1.4213512558490038, 1.1206777836196125, 1.6811670642346144, 2.3516845470294356, 1.5501903486438096, 3.1775146583095193, 3.119432399980724, 3.9241194957867265, 4.580735899507999, 4.716904917731881, 4.5924934186041355, 4.723241552710533, 2.022391129285097, 1.5023050806485116, 0.3717165975831449, 0.15948999964166433, 0.10293037601513788, 0.21606540132779628, 0.12522198376245797, 0.11383847740944475, 0.29588810401037335, 0.2129037631675601, 0.11790681222919375, 0.22648631245829165, 0.23123580525862053, 0.08999095705803484, 0.05982652430247981, 0.20236395997926593, 0.12139944825321436, 0.0731366423133295, 0.1415994018316269, 0.11658104704110883, 0.11764482667786069, 0.08974906886578538, 0.09412572151632048, 0.14343885937705636, 0.14396052982192487, 0.20900217408780009, 0.11679137169267051, 0.10412544899736531, 0.17203524912474677, 0.14758262608665973, 0.21975807583658025, 0.09658894676249474, 0.128720898355823, 0.0852793880039826, 0.11523985260282643, 0.15727782069006935, 0.170839456259273, 0.20021036616526544, 0.11722983996151015, 0.16005141951609403, 0.08645903915748931, 0.15026498527731746, 0.1017830082855653, 0.11955015725106932, 0.14429180970182642, 0.1253764543798752, 0.2586070873076096, 0.11174454484716989, 0.12985826935619116, 0.09211414508172311, 0.07030416149063967, 0.15090384084032848, 0.09359649600810371, 0.16764102241722867, 0.09351828106446192, 0.13870658440282568, 0.2068746741861105, 0.20302800403442234, 0.1255395932821557, 0.14020434231497347, 0.10810345702338964, 0.19473373191431165, 0.06627199894865043, 0.09387689424329437, 0.14832049899268895, 0.11289125206531025, 0.10681526677217335, 0.08177897427231073, 0.14208115957444534, 0.1994246692629531, 0.12099077721359208, 0.13699544419068843, 0.19165454636095092, 0.17621484672417864, 0.13293586671352386, 0.1473765168339014], [0.062331580702448264, 0.04340795043390244, 0.08269901474704966, 0.008185802598745795, 0.0018805754257300578, 0.06823958086897619, 0.056891100175562315, 0.03931424900656566, 0.02528050546970917, 0.021253636296023615, 0.04637362821085844, 0.0420180080254795, 0.03167412069160491, 0.027759512486227322, 0.004000154176537762, 0.038443728335550986, 0.028350404900265858, 0.060180109430802986, 0.007557857534266077, 0.026658005772333127, 0.0052125915590295335, 0.050513955065980554, 0.05272300215438008, 0.04048493501613848, 0.04653732001315802, 0.019759559436351992, 0.023982270249689464, 0.03076369102927856, 0.04599021987814922, 0.04632882846635766, 0.06278917411691509, 0.017860028747236356, 0.046520439864252694, 0.1413289929041639, 0.03005984744959278, 0.024769865194684826, 0.027509456958796363, 0.018370891666563693, 0.04719150463643018, 0.029827408652636223, 0.037794152449350804, 0.061352253760560416, 0.03595223468437325, 0.06991700531216338, 0.02848580974387005, 0.060061484546167776, 0.07958700400195085, 0.019551205186871812, 0.04283599948394112, 0.06624472502153367, 0.04719016877061222, 0.017732234628056176, 0.038523943367181346, 0.013953902362118242, 0.03526014115777798, 0.05027900966524612, 0.08101626168354414, 0.03429086289543193, 0.028770367716788314, 0.030776617386436556, 0.08718712313566357, 0.04278813466953579, 0.07391508101136424, 0.06641258398303762, 0.062238801110652275, 0.03372682323970366, 0.010390779007138917, 0.03446234353759792, 0.021897911392443348, 0.06204858495038934, 0.04546148789813742, 0.03763627908483613, 0.019466565099719446, 0.04789341677678749, 0.07196611957624555, 0.016696341190254316, 0.017139305018645246, 0.02994867187226191, 0.012658484520216007, 0.0367885015293723, 0.03054663880902808, 0.03928569858544506, 0.057082700441242196, 0.005621380414595478, 0.08775347829214297, 0.05054097295214888, 0.035069843361270614, 0.0813527885475196, 0.11818565195426345, 0.09879363002255559, 0.08800617957604118, 0.047063094534678385, 0.05607326456811279, 0.05644338103593327, 0.04259457884472795, 0.016182856634259224, 0.06270943777053617, 0.12044313902151771, 0.005558310385822551, 0.026253412834194023, 0.06275792969972827, 0.02363186707952991, 0.05554392031626776, 0.026860708567255642, 0.013478553064487642, 0.041879452764987946, 0.012400220839481335, 0.03947933604649734, 0.07302192854695022, 0.025058453029487282, 0.052517015355988406, 0.059901225176872686, 0.04883697962213773, 0.029867414123145863, 0.03750340867554769, 0.01767944937455468, 0.014423112243093783, 0.014395415291801328, 0.0635436933953315, 0.05884004305698909, 0.08514481436577626, 0.08044070389587432, 0.04311544034862891, 0.01984696773433825, 0.07828701360267587, 0.1020545007486362, 0.013099363841320155, 0.03719372158229817, 0.04351953604782466, 0.02492952156899264, 0.0410990028467495, 0.03385812771739438, 0.03522714527207427, 0.02650822738360148, 0.019462121490505524, 0.06404331463272683, 0.06872272642794997, 0.026616321192705072, 0.0326606984162936, 0.022727318937540986, 0.07813049465767108, 0.008643098226457369, 0.02315539342816919, 0.004076031354998122, 0.04237445413309615, 0.08325687231263146, 0.05703761496988591, 0.04081815932295285, 0.014236912029446103, 0.029658430903509725, 0.01776610253727995, 0.03529519650328439, 0.028253693781152833, 0.05173921861569397, 0.035356338339624926, 0.038228167832130566, 0.03938677538826596, 0.05500636420038063, 0.008387516481889179, 0.008469602653349284, 0.049987690726993605, 0.04317696439102292, 0.06126581582066137, 0.06140427831269335, 0.010347024763177615, 0.017803694172471296, 0.026983239004039206, 0.08232014093664475, 0.03643090509285685, 0.020448769719223492, 0.058966293509001844, 0.0561319127882598, 0.03414589547901414, 0.060623004610533826, 0.06625302223255858, 0.03008193747518817, 0.03270860033808276, 0.021585059039352927, 0.030242100365285296, 0.017756818269845098, 0.01565259026392596, 0.07960232192999683, 0.03397316802875139, 0.04978122524335049, 0.047740371082909405, 0.015770790269016288, 0.053083682214492, 0.021498112728295382, 0.01955015875864774, 0.022366980265360326, 0.04538197048532311, 0.07576516611152329, 0.0433511909795925, 0.03480550520180259, 0.00729331621187157, 0.020288309970055707, 0.032883071835385635, 0.011719843041646527, 0.0427978048537625, 0.04434616239450406, 0.040616658807266504, 0.03415896098886151, 0.004223406576784328, 0.006500931631308049, 0.10726344975410029, 0.010749729863164248, 0.029456368210958317, 0.013959837688162224, 0.019383596700208727, 0.005804753045595135, 0.015047632296045776, 0.04451381726539694, 0.012384749843477039, 0.04039819279569201, 0.08307077136123553, 0.019968204978795256, 0.04187765676761046, 0.02050811926892493, 0.02933709394710604, 0.03971260419348255, 0.07934022505651228, 0.030971358792157844, 0.04280929329979699, 0.012677782215178013, 0.06176817558298353, 0.08805242279777303, 0.05758971346949693, 0.018934745785372797, 0.032851456344360486, 0.027165658902958967, 0.016058277869888116, 0.027580055611906573, 0.025479523501417134, 0.0482066698896233, 0.047321666206698865, 0.014351148965943139, 0.08291420788737014, 0.027036087340093218, 0.017632118906476535, 0.05679742629581597, 0.011558829464775044, 0.027486470789881423, 0.017747027486620937, 0.03977361986471806, 0.022969238671066705, 0.08213039604015648, 0.017425558799004648, 0.0672982630203478, 0.04065161767357495, 0.033687808536342345, 0.03285988343122881, 0.04477849681279622, 0.024176117367460392, 0.04839380242628977, 0.021386172738857567, 0.04832644139241893, 0.01461092662793817, 0.033809543019742705, 0.03384064642887097, 0.027458400909381453, 0.07006836633081548, 0.0648491460015066, 0.05504203181772027, 0.04118439435842447, 0.1004788618593011, 0.07448079792084172, 0.0482381629262818, 0.060460886161308736, 0.05475686899444554, 0.016127692797454074, 0.009942136821337044, 0.045039116812404245, 0.06354243916575797, 0.18791685317410156, 0.03791545648709871, 0.04558164160698652, 0.054880711177247576, 0.13267982576508075, 0.08893972713849507, 0.06139248929684982, 0.012771058118232759, 0.044991697286604904, 0.019881149200955406, 0.05198982704314403, 0.03751441472559236, 0.013889039582863916, 0.039225926011567935, 0.032679894065950066, 0.047208930263877846, 0.043504615168785676, 0.027835495420731604, 0.01094800481951097, 0.06184246085467748, 0.037854652327951044, 0.029006368822592776, 0.028453405720938463, 0.04768357081047725, 0.0615269664558582, 0.024561800382798538, 0.05953745036094915, 0.030109083381830715, 0.05670306592946872, 0.03704833856318146, 0.01702229059446836, 0.033087466727010906, 0.02963117181934649, 0.08561073467717506, 0.050543403485789895, 0.05914712521189358, 0.1488459692336619, 0.024560123129049316, 0.014050752633920638, 0.052950774697819725, 0.031013648222142365, 0.06864982526167296, 0.036391140820342116, 0.05908105551498011, 0.015015445351309609, 0.05376639499445446, 0.068458640598692, 0.047789256350370124, 0.07694303611060604, 0.05421717920398805, 0.059761760785477236, 0.008825572858768282, 0.06675659911707044, 0.017560293854330666, 0.03838618962618057, 0.030170846766850445, 0.01392867026879685, 0.018711966040427797, 0.02968943412270164, 0.01431476610378013, 0.05010473854781594, 0.03898796006978955, 0.016884522010514047, 0.044891399738844484, 0.0326997390948236, 0.05082526746264193, 0.015335908428824041, 0.008936239137256052, 0.054189879301702604, 0.02807418495649472, 0.04226122466207016, 0.09663599150371738, 0.09519436964183114, 0.04276250831026118, 0.024323802899743896, 0.02576755843620049, 0.0494789447839139, 0.01679620643699309, 0.04455669113667682, 0.14591966610169038, 0.12464260391425341, 0.1447861987981014, 0.13937769370386377, 0.10504187521291897, 0.11463555143564008, 0.1341616571880877, 0.1332483405712992, 0.10185575360083021, 0.10426996741443872, 0.10649681120412424, 0.08761876364587806, 0.12163347710156813, 0.1287932725972496, 0.19810198398772627, 0.14843597717117518, 0.14077021507546306, 0.09989413112634793, 0.10387182745034806, 0.10485483915545046, 0.07101481984136626, 0.10194308211794123, 0.1396169769577682, 0.14704860630445182, 0.10391794450697489, 0.10432179900817573, 0.1895154541125521, 0.04845280316658318, 0.1657709587016143, 0.07121818314772099, 0.15799197455635294, 0.11989898150204681, 0.08612995603471063, 0.2181344199925661, 0.07062589735141955, 0.12815152265829965, 0.13309030764503404, 0.15195590938674286, 0.12600358400959522, 0.0739672985218931, 0.09755655148182996, 0.18160991894546896, 0.1106346036249306, 0.13813968747854233, 0.23845654592150822, 0.1566117283073254, 0.19418822368606925, 0.16379084932850674, 0.16513692709850147, 0.2295179115026258, 0.12394959383527748, 0.2090936215245165, 0.12372845609206706, 0.08692617659107782, 0.09407812016434036, 0.22711606929078698, 0.218029584211763, 0.14582636329578236, 0.18121511122444645, 0.13584573869593441, 0.20332217653049156, 0.163124400714878, 0.1363140338798985, 0.15246640308760107, 0.16635427193250507, 0.0767450756393373, 0.2101033431245014, 0.13061186095001176, 0.12471168301999569, 0.17086462990846485, 0.15711968386312947, 0.12236384689458646, 0.09023929451359436, 0.09501972745056264, 0.23815547145204619, 0.11238091421546414, 0.1357463057502173, 0.12855476117692888, 0.11686040626955219, 0.16035961860325187, 0.15105596627108753, 0.21331558091333136, 0.1401761852321215, 0.13801741122733802, 0.24837349425069988, 0.10575346866971813, 0.198637280263938, 0.2689932065550238, 0.2158923918614164, 0.11198820677236654, 0.2252747563761659, 0.149819043581374, 0.1769266850897111, 0.2103110108873807, 0.07762953013298102, 0.16360259614884853, 0.20553359849145636, 0.31840308336541057, 0.1038841471017804, 0.10649039904819801, 0.15656322153517976, 0.2258853954845108, 0.2324775222223252, 0.239328064781148, 0.1736875221831724, 0.1121929578948766, 0.19496155640808865, 0.14019626774825156, 0.11745827301638201, 0.1369131400133483, 0.10579191191936843, 0.17618294921703637, 0.12124751578085124, 0.1477080787299201, 0.12945743539603427, 0.0764562317635864, 0.16076683503342792, 0.1000105073035229, 0.1563793618697673, 0.08137482291203924, 0.13278665050165728, 0.14825898979324847, 0.09392965352162719, 0.18707874580286443, 0.12823534081690013, 0.14269208069890738, 0.1396172441309318, 0.15035634365631267, 0.09417525245225988, 0.07459123691660352, 0.14223546691937372, 0.10971176525345072, 0.15320421662181616, 0.31165515014436096, 0.16360120091121644, 0.1988074992550537, 0.24128960561938584, 0.10145275256945752, 0.18921429058536887, 0.10198776682955213, 0.16812007874250412, 0.08567883414798416, 0.16170801187399775, 0.1287979184417054, 0.13212216115789488, 0.2836949145421386, 0.1272173220058903, 0.11249810675508343, 0.1337054738542065, 0.12172340313554741, 0.12289164747926407, 0.17976473201997578, 0.12855875393142924, 0.13644940161611885, 0.06701652891933918, 0.13973459252156317, 0.13168508070521057, 0.10867356744711287, 0.20303472789237276, 0.15522619796684012, 0.11236593767534941, 0.12352263627690263, 0.20441518194274977, 0.23303674533963203, 0.11710996084730141, 0.11131415856652893, 0.10971476353006437, 0.21026443369919434, 0.23893779900390655, 0.1646012152195908, 0.16539173608180135, 0.1056431929464452, 0.11231956086703576, 0.11505726200994104, 0.0899004892562516, 0.0921887754520867], [0.03558392163540702, 0.03358879861480091, 0.028328112639428582, 0.07090501167112961, 0.03172471289872192, 0.023979299803613685, 0.04123062644794118, 0.014918379856680986, 0.06422956401365809, 0.10382301639765501, 0.04319037128880154, 0.03671814592962619, 0.04809981917787809, 0.07402229166473262, 0.0023954866446729284, 0.029886542979511432, 0.04179183109954465, 0.039466641610488296, 0.09794226047233678, 0.1152708446898032, 0.04441658849827945, 0.05791179071820807, 0.020678106338891666, 0.1123105215083342, 0.026673865468183067, 0.023208620259538293, 0.06384857508237474, 0.019302415021229535, 0.01996249415242346, 0.03815316267719027, 0.0390722272277344, 0.012458518394851126, 0.024531103299523238, 0.040585503447800875, 0.042811478924704716, 0.06355207966407761, 0.0351974593650084, 0.038900026702322066, 0.06269087665714324, 0.0326818347821245, 0.022470801159215625, 0.026723324044723995, 0.04746713828353677, 0.030711826038896106, 0.03337314905365929, 0.02006416838412406, 0.03257145515817683, 0.06868700686027296, 0.018959418484882917, 0.027784450503531843, 0.0439567204011837, 0.06396084718289785, 0.05525382963242009, 0.017007952301355544, 0.05155403050594032, 0.05048664774221834, 0.054042577830841765, 0.12820555100915954, 0.012189934222988086, 0.026802783941093367, 0.05900480355194304, 0.008903523412300274, 0.07557203702162951, 0.029147803616069723, 0.006431350184357143, 0.008834433174342848, 0.0521522163762711, 0.06625543421250768, 0.043778894396382384, 0.04906489688437432, 0.04356410943728406, 0.06631613447098061, 0.05250375317700673, 0.0669068394927308, 0.05484408247866668, 0.06955805074539967, 0.038425931634265, 0.06988766821450554, 0.1135799428448081, 0.04055343524669297, 0.07876708667026833, 0.05829357745824382, 0.021271484947646968, 0.0422245662775822, 0.056299096395378, 0.012946398856001906, 0.05222400061029475, 0.044762562902178615, 0.05364477554394398, 0.08670766605064273, 0.038969488014117815, 0.034463501287973486, 0.04279469525499735, 0.010481152185093379, 0.03601732103561517, 0.02029625466093421, 0.010776920298667392, 0.031065396324265748, 0.04101744823856279, 0.04459107483853586, 0.07793692770064808, 0.04994995993911289, 0.04346801986685023, 0.030473726510535926, 0.04842888374696486, 0.057839227229123935, 0.06546679840539582, 0.030101372467470355, 0.04588524308928754, 0.03581268865673337, 0.06927459486178122, 0.03863159930915572, 0.01042518682879745, 0.019673273636726663, 0.016224470709857997, 0.046790648411842994, 0.03901981675880961, 0.028948290200787596, 0.022943738476897124, 0.03922750678611919, 0.04488142527407035, 0.04907671558612492, 0.01795451342331944, 0.026762297929963097, 0.056403115813736804, 0.006584171378563042, 0.01421474964445224, 0.02792480732750846, 0.04391681512061041, 0.05876388757314999, 0.03490727220196277, 0.021519714791793376, 0.017105184779211413, 0.028679332172032446, 0.01488549065470579, 0.03086185490246862, 0.09532679847325198, 0.04379963000246789, 0.01422066548911971, 0.020454560326470528, 0.01808906665246468, 0.016036072811402846, 0.14002048264956102, 0.018671502293727826, 0.04018516672658734, 0.048345577670261264, 0.03445730806561187, 0.050841097472584806, 0.05894208465178963, 0.03860231416183524, 0.04712111192930024, 0.020520023317658342, 0.003987354448327096, 0.04662745755922515, 0.03243728227971587, 0.040738281968515366, 0.019159863295499235, 0.043913263943977654, 0.04257135333318729, 0.03575571769033559, 0.06415059207938612, 0.02178712544264272, 0.016281170792353805, 0.024694227358850185, 0.020943550298397895, 0.007104759215508238, 0.018310313862457406, 0.033008123718900606, 0.07735834937193431, 0.014386937182280235, 0.013578225352830486, 0.13015253090998158, 0.014857392943667946, 0.07510017210734077, 0.031055787367222365, 0.08000444722711109, 0.02535061059461441, 0.012341853707766859, 0.03395392785023432, 0.034936991505674087, 0.03301594224467408, 0.03474638571788091, 0.02261370169435395, 0.05699160923541058, 0.022958097179071046, 0.07461652930942364, 0.07327901592361741, 0.020550594235828612, 0.025294467122876085, 0.034516115847509354, 0.0389564559009159, 0.00933691817408544, 0.07643585238838568, 0.010909268421528395, 0.054756531317252666, 0.059743570745922625, 0.03526260508806445, 0.03548649248841684, 0.03964678311604075, 0.06487441612989642, 0.05164729620446451, 0.018675428254937287, 0.05596323375357315, 0.05477559709106572, 0.056361277238465846, 0.028473295278672595, 0.030395177600439638, 0.018521902020438574, 0.03224766354833264, 0.015202418326225597, 0.013320008984010201, 0.035474365795380436, 0.04210222323308699, 0.045166428535594605, 0.0064671356176404515, 0.015208943659672514, 0.07540330232586712, 0.04813131221453659, 0.03072053885261994, 0.010309215122106252, 0.0904262563562952, 0.01832700476370519, 0.028841537823609542, 0.023571185374748893, 0.03635136170487385, 0.029705954329983797, 0.01832924419431947, 0.05038807568780612, 0.07223122956929728, 0.023609628624399193, 0.02977721163915703, 0.052930131860193796, 0.058674948595580645, 0.06905373171321116, 0.015511302972299745, 0.02125008326402167, 0.016133466706378385, 0.021957298049528617, 0.042832789695239626, 0.04372314426291268, 0.0495156848046463, 0.009355745532957371, 0.08267119163065217, 0.011372304561518831, 0.06715508789056912, 0.11376205846318044, 0.08679601131007075, 0.06885775277623907, 0.022157544335641433, 0.05705755276721902, 0.058528519148239866, 0.06786289639421739, 0.053979105650796555, 0.010597775126370834, 0.04119645796890836, 0.03395525629457552, 0.03512852497806307, 0.0383129470719723, 0.0347685202723369, 0.01555437722345232, 0.033587395955692045, 0.013053928632871248, 0.0781790682231076, 0.056515406467951834, 0.027889527482329868, 0.036609042799682356, 0.05523467480088584, 0.09127125085797161, 0.017233338840014767, 0.05217084428295493, 0.04619222505425569, 0.05249817964795511, 0.03857751900795847, 0.05929355465923436, 0.03084956122620497, 0.06730920969857834, 0.04010757889773231, 0.010602715046843514, 0.024333541732630692, 0.010950205287372228, 0.012939701900904765, 0.011408455502532888, 0.045090321291354485, 0.0412998057436198, 0.046573744621127844, 0.036483942676568404, 0.05915713307331316, 0.030602726619690657, 0.07106391291017644, 0.03892851033015177, 0.04102734106709249, 0.04027291084639728, 0.03507495304802433, 0.09102392272325233, 0.045270960035850294, 0.0397361414070474, 0.028793862256861757, 0.10188795538851991, 0.06296207226114348, 0.026753139827633277, 0.028438212102628313, 0.01554557999043027, 0.06074224176700227, 0.009760975790413795, 0.05207810550928116, 0.05559465353144333, 0.07155047234846279, 0.03404628070711624, 0.03368892917933408, 0.02077055753034074, 0.015136965539568337, 0.09309258515713736, 0.07156148581998423, 0.07232169737108052, 0.010874316049012123, 0.0364922213339014, 0.04549529272480868, 0.032523167319595814, 0.02968174547277158, 0.010438681856612675, 0.050955117330886424, 0.08162665588315576, 0.011798963405453833, 0.05605840306088794, 0.05915677684242837, 0.017976735180127434, 0.03559178840077948, 0.026853099698200822, 0.027709755195246544, 0.053595701028825715, 0.007145435401980649, 0.027460527162475046, 0.06555771891726181, 0.0831226326408796, 0.015556069320155075, 0.017056815304385964, 0.09014875249704346, 0.02676463012903696, 0.023709584784228355, 0.030043442275200505, 0.06670697170193307, 0.03179190323862713, 0.07202644876088016, 0.04126022700802423, 0.03890881002007518, 0.09160696135950275, 0.022282969148363918, 0.06664854241535068, 0.06348980605253018, 0.05372054882172961, 0.037392398226074874, 0.016844928431964945, 0.10038944048574194, 0.0724723088205792, 0.10012785569415428, 0.11592865470447578, 0.0988033447356429, 0.15522115136263892, 0.07477717459551059, 0.16999955289065838, 0.12146255307015963, 0.17012319469358772, 0.13311842019902542, 0.14994363533332944, 0.08476848612190224, 0.18793467956129462, 0.11701115130563267, 0.06414366042008623, 0.11647543200524524, 0.15455804241355509, 0.19054479809710756, 0.17861809901660308, 0.13142163312295452, 0.16075435210950673, 0.11403648240957409, 0.32278409984428436, 0.1590555760776624, 0.26945645513478667, 0.24109734484227374, 0.1210247453127522, 0.12384587127598934, 0.0989716564072296, 0.1363608188694343, 0.14080668421229348, 0.1454855690826662, 0.1222395223157946, 0.13645165774505585, 0.1536595687502995, 0.17453033477067947, 0.13105186546454206, 0.1520252853515558, 0.10116119985468686, 0.16335175023414195, 0.13556749268900603, 0.14092904952121899, 0.16551530366996303, 0.19181823445251212, 0.12229639309225604, 0.10177603209740482, 0.1356972349458374, 0.07810967741534114, 0.1592206148779951, 0.11333106362144463, 0.15620470483554527, 0.13490761950379238, 0.15338415774749592, 0.1380890136351809, 0.1608991005923599, 0.27744674356654286, 0.20103556016692892, 0.13662662648130208, 0.17449080798542127, 0.1311010104836896, 0.1554441370535642, 0.10175471019465476, 0.1760367164388299, 0.12403120781527832, 0.19563602021662518, 0.1234095923427958, 0.17625067761400715, 0.1567591930506751, 0.14889339247019961, 0.10397767997346818, 0.18756577279418707, 0.1205404123174958, 0.17067737120669335, 0.14011752587975934, 0.1300750210066326, 0.11360795149812475, 0.1960082963341847, 0.2049939235439524, 0.10872108716284856, 0.13361813791561872, 0.13698367372853681, 0.0808529149799142, 0.15950092405546457, 0.15273979544872418, 0.1206824742257595, 0.11569446258363314, 0.1909922092454508, 0.12108586117392406, 0.23037958948407322, 0.12898590444820002, 0.20582765224389732, 0.13384357269387692, 0.22591039101826027, 0.13099850504659116, 0.18769992340821773, 0.11078246170654893, 0.15000199782662094, 0.1296921618632041, 0.14732383919181302, 0.0985810937709175, 0.19216374872485176, 0.20126987103139982, 0.08938061480876058, 0.14723953121574596, 0.1959449762944132, 0.1667610727599822, 0.1756379011203535, 0.1433044861187227, 0.13324014726094902, 0.17457326059229672, 0.13328026776434854, 0.16981823137030005, 0.10154436327866279, 0.09943818527972326, 0.15195384621620178, 0.12091803931980394, 0.17659681529039517, 0.09592587492079474, 0.1237010040495079, 0.09683775919256732, 0.19350158865563571, 0.14918968750862405, 0.11511020682519302, 0.11388901024474762, 0.06752492976374924, 0.13338638003915548, 0.07947542209876701, 0.24117144086631015, 0.12100064035621472, 0.15674847643822432, 0.07463553571142256, 0.08498880750266835, 0.0953784519515466, 0.1265666662948206, 0.12799494434148073, 0.2267369654146023, 0.1289186510257423, 0.11127154444693588, 0.16495331976329908, 0.13997911533806473, 0.11137877736473456, 0.19452535168966278, 0.10473451475263573, 0.09234979923348874, 0.22263844002736732, 0.11260729894274846, 0.20590726984664798, 0.14956019731471315, 0.16541123972274363, 0.13484164257533848, 0.1320961711462587, 0.158061855181586, 0.21697316667996347, 0.10820039635291323, 0.12925237999297678, 0.23242220253450796, 0.12627819349290803, 0.13508684816770256, 0.13283540960401297, 0.20352291263407096, 0.07241854022140615, 0.18153659475501627, 0.14816788374446332, 0.1578502985648811, 0.1303297557751648, 0.23652005998883396, 0.10291044192854315, 0.26376266847364604, 0.2289092168211937, 0.06561579197295941, 0.20417327148607, 0.17571012693224475, 0.14512500405544415, 0.14228717976948246, 0.2018637376022525], [0.07173342659370974, 0.05426031653769314, 0.05383093586715404, 0.0486595766415121, 0.07467207906302065, 0.031160873622866347, 0.11886295818840154, 0.027641980414045975, 0.07751333207124844, 0.01124781485486892, 0.03954318672185764, 0.07554458497907035, 0.011784559246734716, 0.03842048427031841, 0.10690844341297634, 0.0887156579119619, 0.0385218505107332, 0.09838854355621152, 0.10814916589879431, 0.023089102942321915, 0.07217536069219932, 0.03546325955539942, 0.002639405538502615, 0.006669655658697593, 0.010797991726576583, 0.01002353465082706, 0.009764035294210771, 0.08269822064903565, 0.028053686837665737, 0.012852362251578597, 0.06279331530095078, 0.06525251810671762, 0.037007776481914334, 0.013411858108156594, 0.11590621958021075, 0.01534500715933973, 0.008145797128236154, 0.013600948987004813, 0.017419172618247103, 0.02657564964465564, 0.016060873531387188, 0.05630959407426417, 0.018275496004207525, 0.033695920210448094, 0.03691775396873709, 0.017935225005203392, 0.04901228974631522, 0.020973009850422386, 0.02863281435566023, 0.01000279255094938, 0.02987534026033245, 0.07398289104457945, 0.01233463168318849, 0.03627756625064649, 0.045139644425944425, 0.04031336531625129, 0.01689136646746192, 0.015921487065497786, 0.033706547765177675, 0.054126937757246196, 0.03833281065453775, 0.04039303486933932, 0.014607753946620505, 0.02729276653553825, 0.021466732869157568, 0.058451643781154417, 0.022596495000470895, 0.0771988247288391, 0.062311223591677845, 0.04144504404393956, 0.03224527012207545, 0.03256020419939887, 0.021935135664534755, 0.020823172089876607, 0.01584319419634994, 0.038731941385776736, 0.05617571805487387, 0.09952100153896026, 0.04573098027321976, 0.02155341015168233, 0.04678110439272132, 0.034224622504552826, 0.013981989868625533, 0.014122740958555369, 0.02046605062787421, 0.030754193394386675, 0.018516315503802616, 0.023553941573482007, 0.048092835568240844, 0.04070274793775752, 0.033677882311167195, 0.07885050406912342, 0.04102956751012243, 0.06740078330039978, 0.05481868989591021, 0.07793688317178749, 0.011380626820027828, 0.008787984934315318, 0.051041254700976424, 0.09137625733274035, 0.04785224242368713, 0.04784849828865845, 0.05489181370649021, 0.013780526460323017, 0.02842175312252948, 0.06369966315105557, 0.07183938301750459, 0.0342757750331657, 0.03767648493521847, 0.010694559532566927, 0.06999024044489488, 0.014957144085201435, 0.01018615776047227, 0.05311850749421865, 0.06148772910819389, 0.00953084043430863, 0.039389718003803864, 0.022727812465745956, 0.023125861516746227, 0.059909303454332985, 0.0933491752948612, 0.013484303781297058, 0.045755055543850176, 0.052045981647097506, 0.042138343560509384, 0.08166187079041265, 0.03534657538693864, 0.029523547418648377, 0.05486537098477129, 0.04859078697336372, 0.03226771266781725, 0.026539735263213515, 0.041239680649596266, 0.04621375475835521, 0.0289431545388652, 0.02063993211777415, 0.027054585370933637, 0.07785866080666892, 0.02707554362132214, 0.023534211577498354, 0.05850195768289268, 0.015370556520792888, 0.019077384713455103, 0.02089003217406571, 0.0014129337955637311, 0.07298896234715357, 0.07074873763485812, 0.02993211084685754, 0.03678879096696619, 0.03256749208958354, 0.03106811815086985, 0.07709130979492329, 0.04406369727803394, 0.042785681871464476, 0.05267801687296014, 0.024789936578599736, 0.050393118581268936, 0.05116878164699301, 0.01746312074828893, 0.04093072457180824, 0.023471646672987845, 0.0629759652656503, 0.0477958132250933, 0.02993794969370356, 0.04289441763830837, 0.05954493120952975, 0.0471505121095106, 0.03569284664990846, 0.04769959377881605, 0.02579308275016956, 0.10073461337015033, 0.0691987547907047, 0.0760309217730537, 0.053737688722321764, 0.0681150633317884, 0.014195632847986417, 0.07054049099679105, 0.040237169014289975, 0.06801367111620493, 0.048674623685656115, 0.043538961763260886, 0.05335549380106386, 0.08541800634702668, 0.04474120018130634, 0.04854806524235755, 0.018557831244834233, 0.046528254679287784, 0.019166939673596062, 0.015446684174094116, 0.04686498192313593, 0.07559364836197346, 0.1200106598844286, 0.05853303140611388, 0.04490999424888287, 0.0036784920666832477, 0.019295062193123158, 0.0008331109779646795, 0.05064317781943828, 0.004304088233766379, 0.008456491686956724, 0.04885859467322007, 0.0417150670546107, 0.051563114393502474, 0.09565942164044827, 0.008589288809162099, 0.08430456218775362, 0.03661900613224134, 0.06184665769978892, 0.04795051761902869, 0.023068191076163203, 0.05307913655997254, 0.0040723155143496115, 0.03320758703921456, 0.03671812737593427, 0.007704808804191998, 0.015765508032927755, 0.03357172550749965, 0.03874788271787111, 0.06437427538912743, 0.008732529804547084, 0.05276862568280194, 0.10588031655061059, 0.04546276068140287, 0.00535462610059767, 0.03024069214006886, 0.007507157715735957, 0.010309601038898109, 0.0637394496880006, 0.019847043804475106, 0.041151762125082314, 0.06086517110816203, 0.018990941207448486, 0.04555919535050634, 0.05127049298607744, 0.015497547265113099, 0.06822527968324721, 0.029346931114559993, 0.04955590920872055, 0.058800193437491544, 0.021925231703789905, 0.020058643094671424, 0.06621827487833798, 0.03626350255217403, 0.03827448897936847, 0.03097872275247937, 0.018944328767247498, 0.02729159765294753, 0.03561463912774343, 0.0803113920846954, 0.012399043607729254, 0.027047065559600014, 0.019226697404519655, 0.08151387912221253, 0.08032336292671971, 0.019624033993750345, 0.027716616350517143, 0.05018057861889247, 0.030580825841752812, 0.024285819781653117, 0.00886292329596472, 0.02584778831078438, 0.023440929180651437, 0.04545156167296227, 0.026795607373060193, 0.044576539876288734, 0.026468732139619533, 0.06433678208850324, 0.05127934680785984, 0.06068189031793736, 0.02081419952446595, 0.0264266226804466, 0.08782784148934297, 0.021625023691740353, 0.036381878817337565, 0.05692374354111962, 0.05578024240094237, 0.05199457307753619, 0.041569732275092974, 0.06429923683754168, 0.03405559837119654, 0.03199267273885198, 0.02776030101813376, 0.07074040331644937, 0.0394957004027674, 0.026048450199596118, 0.01742908585583791, 0.05497041085618548, 0.017188227393489797, 0.024769807678239886, 0.021533726539928466, 0.02879107549233595, 0.03782025378313847, 0.020185689500067383, 0.03136127947072964, 0.024519750295439735, 0.0864957383600995, 0.12048249511281028, 0.0535912332998123, 0.056004300495260395, 0.08151045782142319, 0.033076805775635876, 0.04531545549980365, 0.07683866788283922, 0.010981163977703545, 0.07977070039487444, 0.05283253201923799, 0.047082535093068145, 0.026696664244809654, 0.015144850858632708, 0.044149196401122026, 0.026633856286935043, 0.0100503716384992, 0.0285378083208343, 0.01374039853544673, 0.011944342713832157, 0.022074266089475714, 0.035425020396360196, 0.022404104347515386, 0.02128766933310544, 0.011192798519914504, 0.02183076929213712, 0.044963744294364005, 0.03976812797191087, 0.03414736864215229, 0.055855332902865484, 0.025983605046349112, 0.053935957184876315, 0.02152277244022116, 0.04265716044756118, 0.025136146614386234, 0.19879932078765705, 0.03965286501625087, 0.05279456374410074, 0.04097078570339363, 0.04890818127023522, 0.04427489766385406, 0.07715380605077371, 0.030047548207221553, 0.03029501920536859, 0.02553055172029417, 0.07301124162040651, 0.029506229402613826, 0.040036893042270094, 0.05930713967245538, 0.05306833460053895, 0.07271626760484651, 0.021861483073735144, 0.028376624977681786, 0.0179941608075751, 0.03006763814482838, 0.04719108161225449, 0.009601126457710052, 0.22171900811372325, 0.1408879048540257, 0.16133330151205882, 0.10917265433818102, 0.17559228872414678, 0.1710246072616428, 0.14246275706682354, 0.1346158960950561, 0.15081297227879986, 0.07346172526013106, 0.08287007236503996, 0.1597696408862248, 0.10651736127329059, 0.1676947539090179, 0.2245049414341338, 0.3271769906859845, 0.14968504139687866, 0.14966780872782692, 0.17453732580179349, 0.07522339830757119, 0.17815734405303374, 0.24452327663311735, 0.13493648904841393, 0.11557608260773122, 0.16163816093467176, 0.10503417914151214, 0.13806566566927359, 0.2169158135075122, 0.20823376922635362, 0.09514068267890252, 0.16112996789161116, 0.1501871636719443, 0.14748838817467913, 0.07413497936795466, 0.262184803141281, 0.05606411759799812, 0.1775873894803226, 0.14898245019139722, 0.10826373865711503, 0.10809702260303311, 0.10102492669830099, 0.13449504476739094, 0.16332286584656686, 0.1028616308758501, 0.11061630968470126, 0.212002795888111, 0.18047518999082968, 0.07151204394176602, 0.10470852474099956, 0.11742918824893422, 0.08150562644004822, 0.1696479826932773, 0.1293745226575993, 0.1677414498408325, 0.18271113251103088, 0.17846358387032524, 0.13243398192571476, 0.11518595783854835, 0.17015636869473383, 0.17675449198577553, 0.11490544085972942, 0.1327076117740944, 0.19788135832641274, 0.08649713359773159, 0.11150804464705288, 0.16654044709866866, 0.14819618925685063, 0.2267730189487338, 0.11166585492901504, 0.16830378997838125, 0.14583322074031457, 0.10195474125794135, 0.1285749179078266, 0.09814117089263164, 0.11235112440772355, 0.16066090087406337, 0.1329702726798132, 0.19583694927860051, 0.1422562767402269, 0.1553813216742128, 0.1562206313246861, 0.21677643817383796, 0.22566077706869692, 0.08850567464833148, 0.13181923131924123, 0.08589251330704428, 0.14678511419333518, 0.07387804784229957, 0.1381396281067282, 0.11825241555925459, 0.1493683669832535, 0.11488507632748224, 0.18237634969409555, 0.2300640579778701, 0.1611122750909999, 0.2731792163103819, 0.0869702898489777, 0.09023274134960957, 0.20948071090970188, 0.21145479404367507, 0.13496498751919717, 0.10840998627827503, 0.12313264509430155, 0.08319973436300643, 0.1354439399437979, 0.21679665427654982, 0.15023834217572585, 0.1073253077629488, 0.18778853584080935, 0.1242465345421806, 0.20235161064192653, 0.12161722406744957, 0.06017498119035736, 0.11232013974222355, 0.13350184337468818, 0.09175024038995616, 0.10001408445532434, 0.11658466872177087, 0.11761641726479866, 0.193384091835469, 0.16818730247905478, 0.12471704132622108, 0.1659929647576064, 0.20362878742162138, 0.15612430055625737, 0.11718434630893171, 0.19108799082459882, 0.23375987919280306, 0.18648275668965653, 0.13892824907088652, 0.1953064472763799, 0.09989534824853763, 0.20377610373543575, 0.15322921215556562, 0.12034541301545687, 0.07781183128827251, 0.12373140241834335, 0.12796981522114947, 0.09930577871273272, 0.147275376948528, 0.1383193169021979, 0.0888086119084619, 0.18379166984232143, 0.1306005654623732, 0.081864388048416, 0.1928278521518223, 0.1958927439409308, 0.21038212347775698, 0.13714921718928963, 0.1543669542297721, 0.10302821334335022, 0.16138022008817643, 0.13197428081184626, 0.09542639469145797, 0.2477764364448376, 0.10445690699270926, 0.16613326035439968, 0.1557049129041843, 0.16273103276034817, 0.1891512080328539, 0.12386176065774634, 0.16777422308223322, 0.15740771137643605, 0.08938212879002094, 0.09552212432026863, 0.13085794227663428, 0.08914286780054681, 0.16896468732738867, 0.25419786921702325, 0.22155952057801187, 0.21246662334306166, 0.15702146803960204, 0.1924277751822956, 0.15292588155716658, 0.14082164590945467, 0.13959595933556557], [0.07439857537974603, 0.05238949954218697, 0.04546696123725269, 0.052003579039592296, 0.0624008008162491, 0.025350135620101355, 0.023947658337419853, 0.021225633208814543, 0.03191776777384803, 0.04926810062897857, 0.03619319148128852, 0.04911016418191139, 0.07494978330214508, 0.004497213149079471, 0.10650090043782257, 0.03548909742676187, 0.0037446893202286446, 0.006520435736092622, 0.045307225082069635, 0.03546919673681259, 0.07201922766398638, 0.014341494552354561, 0.03877457034832332, 0.04554919862130191, 0.07274809831869788, 0.043153583028470166, 0.007753016861897777, 0.014022006471350323, 0.01966092244401807, 0.04302241955883801, 0.05995804771373514, 0.05955185173661448, 0.041086787095991895, 0.018458101440046448, 0.047028759072418325, 0.0359336550172884, 0.04284140974050388, 0.05774402823590208, 0.05148068034031894, 0.10074838763102889, 0.03218362733605318, 0.007383367483271286, 0.009094029937841697, 0.04627339745638892, 0.027227821192354895, 0.04916180652799085, 0.0881860835943371, 0.07597826639539562, 0.0506492597196484, 0.04744270307128318, 0.03978301174356602, 0.020248890796210617, 0.010738322125689592, 0.01715101425361354, 0.028719166948576458, 0.003648405631793139, 0.03309979751065839, 0.04849155440751929, 0.03376767475856468, 0.04674410090956371, 0.043324789075995795, 0.05605763122730423, 0.0090873895715049, 0.04123633727431297, 0.0810750323580578, 0.0909218774177134, 0.028252584270376246, 0.016424288405687548, 0.03660784052044619, 0.03342266885738354, 0.04761226897244342, 0.021743309043813497, 0.029087479997542687, 0.020473091753956396, 0.04334426674176939, 0.02276997758599464, 0.030283467676781584, 0.04610851450706832, 0.03933069499908015, 0.08067447299254127, 0.0911834102589637, 0.03946769917092752, 0.02680550762306666, 0.0458383987279376, 0.021776917201350443, 0.03719414831721224, 0.06793210908654146, 0.04915474870358594, 0.06818817972089164, 0.018601836891321, 0.04300579174014274, 0.017713398920022883, 0.07604632133734412, 0.03898504342942033, 0.025262074232159648, 0.17068802844733, 0.034558703991933726, 0.028639534502872266, 0.011308370394544909, 0.015016006600490073, 0.01747951850120444, 0.04285313938453328, 0.079520485305693, 0.016734762175474316, 0.012897227861685678, 0.03705691036884673, 0.010677577338356059, 0.043426348274806514, 0.01157215843704762, 0.01714462436211761, 0.038514451298397034, 0.058391715356265195, 0.08265783297247253, 0.0477064883307321, 0.006240973070816835, 0.029942339497210924, 0.05415768493548967, 0.029605944364448078, 0.07116068896721117, 0.012542392214527354, 0.021001454515499063, 0.02291216565936338, 0.023804687298252247, 0.0632475245220121, 0.020764082291861996, 0.06013989986968227, 0.03942704432120081, 0.04716665753221605, 0.1067363096808549, 0.028138831585238222, 0.022263769787969068, 0.0403111722698668, 0.06493882712675259, 0.06320314409094863, 0.020815678253711667, 0.05358650210837368, 0.04841622641833965, 0.05496059966390021, 0.015631472451786976, 0.02708984109631274, 0.026920468153548427, 0.02648613735800609, 0.025907280723913573, 0.021111834139446728, 0.03329509367176797, 0.05014007962017786, 0.024583587983215693, 0.021607258531730622, 0.03746334383322392, 0.01351577269815607, 0.04730196589662228, 0.07147063210140914, 0.08475379159790464, 0.03320661482575815, 0.05717659696529154, 0.11329087632475421, 0.0787135110294912, 0.024573535592935514, 0.04960329533787444, 0.00395263075006369, 0.027447033062344417, 0.02705950024392223, 0.014858561826258665, 0.08810047685983591, 0.021831808298884425, 0.01996318434976274, 0.01271222899958957, 0.044431531641748734, 0.08061285989242606, 0.03316390793770552, 0.0700131431221962, 0.008653480872453656, 0.05858196862391196, 0.017361144091410097, 0.021574887905444484, 0.06760685544577427, 0.021388317545643076, 0.037220401791273616, 0.036557411585818045, 0.05323197445250116, 0.03952574996219482, 0.0978249343461357, 0.02154992391297128, 0.021373500567278825, 0.0317835429450497, 0.0330839266825933, 0.0015663120643694128, 0.013055999224889092, 0.03337171299790498, 0.014152582716633333, 0.09686612407676876, 0.06591255456442013, 0.014906408086972078, 0.008642396896902937, 0.005035875065004802, 0.042870234756264836, 0.04591809796693269, 0.04236615321133286, 0.035200669153709896, 0.05000442986784037, 0.037114593797014095, 0.06541807641042396, 0.02776028988591861, 0.05640912349917926, 0.014862393163639354, 0.04815925036382396, 0.060128823315608315, 0.03123508839053102, 0.060934283610549755, 0.0781173438008409, 0.024262128572445363, 0.0320079387165606, 0.029079971318424214, 0.07624828198459, 0.026076366084453184, 0.015555693607893772, 0.026424160605529323, 0.01800507408916019, 0.0255994861072395, 0.03436678831349127, 0.01095856187021127, 0.07389883539872244, 0.07450709963450208, 0.03695470550155733, 0.05370689330447931, 0.020966625525034033, 0.02944395393569721, 0.0329402468923945, 0.05812336217786651, 0.07753532932838425, 0.028150713369541336, 0.05273077615129296, 0.02881309872464044, 0.05609266059764195, 0.0179816778836539, 0.03290610809926875, 0.03679430141346529, 0.0625558354659006, 0.030605672945966944, 0.029796184644510504, 0.061983350169612095, 0.043845179316122085, 0.02656718916114187, 0.009951653937605442, 0.06504619363113306, 0.026126928605663124, 0.018064768737531267, 0.06643063301453367, 0.009415979166078614, 0.009647793631302193, 0.00865494290337665, 0.03004383932420751, 0.03654913292848505, 0.05076271183497738, 0.010692435134842526, 0.03683209899463691, 0.058662829324021004, 0.0179525745625142, 0.013134011933289003, 0.009304451996285934, 0.013942597597633721, 0.02824057446559891, 0.01617362431716174, 0.008968991969595663, 0.07659779643290676, 0.04516640998190269, 0.03379360539838672, 0.07262206680024974, 0.050336232961853966, 0.014550619707733858, 0.01970424345927313, 0.025163023492495995, 0.07180456144851632, 0.022181309759616852, 0.03494297692668624, 0.05486740075866692, 0.056438015308231115, 0.02476766658219276, 0.04241254857333843, 0.03901549745933153, 0.014689089621242601, 0.029242596283438616, 0.007601297756991698, 0.038760525203542784, 0.027019053195544984, 0.025045686234079767, 0.03118043292488437, 0.09581389225786552, 0.03126318239083048, 0.04676592376199551, 0.05760814841778483, 0.05926212470512837, 0.061742590041831136, 0.015710769075667486, 0.029690309856960084, 0.1005160434579011, 0.011909853255929193, 0.07930164822028019, 0.03193645505234599, 0.018577974988147616, 0.02781428484013304, 0.027630026270344388, 0.08032699945033528, 0.06667588313575834, 0.09292075570556335, 0.005924019887970644, 0.03247030414058827, 0.04421663536049891, 0.08486801554681733, 0.10414727556053549, 0.012256952941243071, 0.005994411203573691, 0.02446962007525144, 0.08537033820175566, 0.05098806126625277, 0.025093040821957402, 0.08627780669485219, 0.02290260494191898, 0.03816220945736859, 0.0363181097782217, 0.06998153505264781, 0.05169857118744403, 0.07017614843789488, 0.04606126567523461, 0.027340063606970944, 0.018470836694177706, 0.06458544608904049, 0.024483500092173927, 0.011086881058872677, 0.05888170351681765, 0.05943865566223394, 0.02920100076153176, 0.051810201330226846, 0.02254404556879308, 0.04335584424552508, 0.04613766235706862, 0.04257464475813322, 0.05064356744696852, 0.018433794248267077, 0.00315846663852426, 0.06361158506479114, 0.04086868844751734, 0.016363322829420213, 0.03447526061790995, 0.013906986569054425, 0.035293556356919, 0.028915854636579752, 0.03144677117234096, 0.01886426587589085, 0.045270629780134186, 0.05742664507124573, 0.03810696769505739, 0.20815351337660104, 0.13480017136316746, 0.12946482718689367, 0.16104465059470385, 0.16075313498731703, 0.11491943034343421, 0.15136659960262477, 0.13843904016539454, 0.16202232625801116, 0.1541160192573443, 0.1619088667212054, 0.09828681737417355, 0.24206010333728045, 0.08839723945129663, 0.1909366372274235, 0.19345103355590254, 0.1004455765360035, 0.14287697937106714, 0.17210045421961695, 0.11330763401929289, 0.1663952978560701, 0.1615622837562114, 0.08975033051683567, 0.12500066048232839, 0.22249805537285283, 0.10502486518817022, 0.10793214707518928, 0.11763209142372943, 0.10616633284371346, 0.17306952096987516, 0.19204071548301727, 0.15275793353794143, 0.19155235262587667, 0.2061792224412784, 0.2159120884607546, 0.10421591679914854, 0.11175378458574414, 0.14315786742372438, 0.11025616768165492, 0.19786510529229417, 0.12612216436536983, 0.12318711131229065, 0.11457494765636511, 0.17666325235040858, 0.11494104910525493, 0.1252517438842915, 0.19302107772091404, 0.20348402409581468, 0.11961401905864477, 0.09844650528975762, 0.09374165267217904, 0.1020110108947847, 0.1400838472181931, 0.15784486604388803, 0.1263205404393375, 0.19913851196179166, 0.1462662045378238, 0.11643796096905135, 0.14302171301096678, 0.17581197927938774, 0.09694497726741247, 0.18387272721156478, 0.27707938046660274, 0.11162864364450797, 0.1850635773735121, 0.30034493829589337, 0.11822796179330908, 0.13675852096639574, 0.1552693612757139, 0.11493102269014344, 0.1546562137082219, 0.13816161052091047, 0.11028323380742222, 0.07655083332792856, 0.088598072034074, 0.14003718097228557, 0.19119444448733702, 0.1382924511563033, 0.09994570296839811, 0.10258925525704399, 0.1894834527047351, 0.1595839110086672, 0.08463973834295757, 0.07683404430281371, 0.0866167529602535, 0.16275062545901164, 0.14857796486467123, 0.0958209129748866, 0.1420155240339227, 0.13711104111280292, 0.14908679615473375, 0.23517798981629312, 0.21897785598412156, 0.09619353790185414, 0.09970880943001248, 0.14888638659613207, 0.2043436240637675, 0.0874485372332856, 0.14418203121749684, 0.10392836426035501, 0.1373187979334034, 0.09820782317547128, 0.17313554242718965, 0.16589768783887848, 0.09575465403031558, 0.1139396098733414, 0.08246741272159852, 0.1469763062777929, 0.0933303618512582, 0.08491405096719973, 0.10034224731498398, 0.18720448046224192, 0.16213016031542793, 0.09014428476803005, 0.13102715194690973, 0.13125542172929272, 0.11205550472368486, 0.09695311120594852, 0.16167388792382553, 0.1698062679497525, 0.12050400997395627, 0.204833070456516, 0.06646008885581978, 0.16863596043549478, 0.1455871542566456, 0.1384916584356688, 0.12208762695081532, 0.1569239646778442, 0.16780042089521885, 0.10741738602519035, 0.1301776006584987, 0.1758919531130232, 0.13816422288073227, 0.22656833461951464, 0.07958073285408318, 0.277519355295226, 0.08221370953833684, 0.14552769338479266, 0.10361396824009717, 0.08288007651572116, 0.21453930821735412, 0.12486547086155042, 0.18966691161040217, 0.13387426792178303, 0.1258928852621466, 0.1645309041487053, 0.15026566805317998, 0.10602688329527155, 0.10864063093322329, 0.12341792666120455, 0.14449413400143385, 0.17244261398445815, 0.13478789624059573, 0.19381140562472865, 0.14593719562981278, 0.21661036036675796, 0.24232792959082872, 0.1179368766315747, 0.1891924417577684, 0.11339341144775972, 0.1215551805216819, 0.07950779458042234, 0.111689722398296, 0.14704269880894572, 0.16859098628629, 0.0955913147481624, 0.06544567688251846, 0.16101725050248206, 0.12306021148106083, 0.10191808658419177, 0.12096181861124933, 0.12251019841642119, 0.14233766065444797, 0.1374024379765615, 0.11297439486952499, 0.19617137586465105], [0.04759847615787294, 0.06692379756714217, 0.04099397781828884, 0.038568616946577094, 0.050172793489764445, 0.07831227630958892, 0.033225817896891385, 0.021195663430262357, 0.006184061012390885, 0.05371712752094027, 0.06382210267474875, 0.06951024901354685, 0.007364474258793052, 0.033651302292128094, 0.009974238419090398, 0.01623187734367093, 0.06515404995298013, 0.03290031563665252, 0.019284020891063847, 0.06276311731198803, 0.033759255093173124, 0.05452082521514967, 0.01797591510694474, 0.04217429319396615, 0.018464240856701508, 0.07154262042604387, 0.018712001292442437, 0.06074029362935107, 0.05094856045616325, 0.024315103073604405, 0.02829925051628379, 0.021041729014541488, 0.036062417639186606, 0.042714034934761, 0.013729630900343182, 0.057709299435373396, 0.015471853184862994, 0.09070769359823316, 0.014926800449757138, 0.04014257858216297, 0.07553982039098628, 0.025287876851507463, 0.024992552171170246, 0.03257408978242893, 0.016964204551186413, 0.029819161536579486, 0.0661678311007563, 0.06849340279586613, 0.03044234665139811, 0.07344740923144855, 0.04058443104440812, 0.03314326510007959, 0.039233982024597935, 0.10817955684615299, 0.05083326039311942, 0.004826988788408926, 0.046290993777802214, 0.053320616570999846, 0.031496847586822696, 0.019240523615735583, 0.06381519327987917, 0.020376536485855468, 0.015099032516445732, 0.006092534722483833, 0.01555196709887241, 0.03608855236961972, 0.055122354460763745, 0.04543425478914287, 0.024123270886775572, 0.08702727194759063, 0.032604888911009766, 0.05485835768922698, 0.05570156361500267, 0.03572836583771277, 0.047886629836284555, 0.06502039657789283, 0.022126696967461612, 0.034275964280823246, 0.04569265205645934, 0.044267635748838075, 0.014179211902956013, 0.039167077411548235, 0.06000076202326454, 0.038220282513066195, 0.03781174134928733, 0.05032613975345157, 0.02387276450463105, 0.029811025742674246, 0.030887967368471436, 0.034686475846683607, 0.06565556366695091, 0.044330132004688494, 0.012893016173620708, 0.022356078115990385, 0.049784212387748994, 0.04825915086257737, 0.05948630525381304, 0.01917107900226256, 0.04770494837430306, 0.030781838395341765, 0.019575323130993638, 0.026571809030428994, 0.03204483458830509, 0.015926051273709163, 0.07020543358521536, 0.030370091153599788, 0.006156308863864979, 0.04338864346209448, 0.0945751958352048, 0.054295308800647035, 0.032127290905918926, 0.00338173341788206, 0.06539047593832947, 0.08061795844696462, 0.0941212463658303, 0.04496845322137233, 0.019020398904103786, 0.00843195721245138, 0.032482568130944856, 0.0730993939214386, 0.054251700203167275, 0.012733421954180812, 0.03705743729369715, 0.032466170378029346, 0.033195282230735756, 0.02367391345615033, 0.08791496220510453, 0.062120829315972514, 0.029022414055361878, 0.027639527615974657, 0.050421965861460194, 0.017429135950806085, 0.025981784929172136, 0.008443081078439718, 0.10448785455082543, 0.007025175473245326, 0.024988262557599228, 0.12996038887649775, 0.029862482551834546, 0.021989574051985983, 0.01170033105154289, 0.08834809443214908, 0.021499496833712328, 0.04836920394154731, 0.025906219452735968, 0.05677516928699333, 0.0255025041042245, 0.0390803055051947, 0.019320170904393308, 0.016966243601928, 0.027744480285036843, 0.036535492254188284, 0.026052867833641358, 0.06506604608148336, 0.026353057291998994, 0.022668045457976405, 0.03214492433471605, 0.040128102991729975, 0.05118330547702499, 0.0168763212786871, 0.02928439589595655, 0.013077386065560859, 0.02549878779973369, 0.013858944566891296, 0.030155901768011972, 0.030827450791548472, 0.006763046130799921, 0.02376775060838554, 0.05801090825116262, 0.07437732769176364, 0.03155450503982138, 0.02241053505713353, 0.07004373444942757, 0.023043420042085927, 0.012612601240107324, 0.0198965098024928, 0.04512344334216323, 0.02689583441679133, 0.07725012197624892, 0.03515319767757319, 0.07713902246905491, 0.02726638689637184, 0.02222584604169242, 0.006058288781787269, 0.03283118458057288, 0.005703969854948809, 0.02879439103708137, 0.027049509080825374, 0.03254100483900402, 0.012294556636334164, 0.0599248143407749, 0.04749770734633785, 0.018615726185089443, 0.020114612161705736, 0.023798926376912277, 0.026656031659513246, 0.009949031373253092, 0.13842397456755862, 0.04881680062680971, 0.05013075453462079, 0.011438954061304685, 0.05301938253978733, 0.061545067437691614, 0.038995032737147994, 0.0356993441528175, 0.09073539054952562, 0.05067419588158373, 0.010559023885434726, 0.0495856433553854, 0.0375400781922508, 0.010938992363662692, 0.027321691741235554, 0.08464060665573925, 0.01615618199139135, 0.04061894833284896, 0.018919999311037827, 0.11558933736523613, 0.07260480444529094, 0.033884147414937615, 0.02303444933204446, 0.05011680586903822, 0.024996886313601863, 0.019744779565371573, 0.019526038959156722, 0.0362211704486981, 0.03309435385745019, 0.03580145254090894, 0.01837523694121046, 0.045702344505116343, 0.038641625724267215, 0.058576717929099686, 0.05410951212979853, 0.03558945063559804, 0.06754481190000661, 0.04010026503237896, 0.02802714578137966, 0.06082466468797065, 0.030720870963705238, 0.02307082755578449, 0.11770193494157866, 0.01697493229585234, 0.03503463958622888, 0.03721813453012146, 0.040445601189276204, 0.0403546175948577, 0.057405007755733095, 0.02456858546793228, 0.060321718628983945, 0.06026544899214059, 0.01731258351355791, 0.037302520431694575, 0.02159903924621176, 0.042853180202655494, 0.024110444719553925, 0.02803280651278328, 0.01577727478434099, 0.014914413077349309, 0.019240262008679565, 0.038228178964345716, 0.07940399780636653, 0.034559264313429594, 0.019920887498301454, 0.07982210896443576, 0.05316364120517392, 0.053120192169444636, 0.028430849997675978, 0.05567293155763764, 0.043808031114167534, 0.026537167432252318, 0.022338403869071044, 0.021131888825038914, 0.09490344033110887, 0.043194883546675555, 0.05195839337829966, 0.024021956596698146, 0.029361955894273706, 0.026312305963074323, 0.02184617998864269, 0.046753685746807605, 0.018707923190959264, 0.02660152462340193, 0.028476221195887774, 0.048825172052602284, 0.006393189878508565, 0.014425321060116403, 0.04904583111056127, 0.00850804683068418, 0.015596984849253204, 0.03939341760997195, 0.04029436633572914, 0.033659324908512644, 0.03485754088615067, 0.019855456048389897, 0.04248543860740028, 0.02737998373049777, 0.05193526805669535, 0.02336500747333048, 0.02001035896682879, 0.03752787728444673, 0.02490800485247746, 0.03806155938946176, 0.15855618490604684, 0.01775327265931992, 0.01359984968075878, 0.039867798404884525, 0.03823334802291356, 0.02307126171217533, 0.00942493225011276, 0.0433592915214831, 0.09398911439348012, 0.0032272938778987736, 0.03779761085752398, 0.012801856319129001, 0.050911612634081393, 0.056196449950220995, 0.031204096303554252, 0.05632466709357686, 0.08791207525064237, 0.04651889619708527, 0.03859022457618266, 0.019602630454755854, 0.029872475570300594, 0.05753740690124687, 0.07271620081155561, 0.029806745405949187, 0.0238135949257412, 0.08198905401513912, 0.019474003274808638, 0.037291562621248886, 0.10116111079696566, 0.017630950023885816, 0.05017215895350091, 0.023592969264427666, 0.01836870789702516, 0.019479407965263817, 0.0692880351562053, 0.06044826965080574, 0.02306935995875392, 0.042689915135269985, 0.009608272412151564, 0.00528893860973767, 0.0089645131083671, 0.06822892362833954, 0.0491655580844963, 0.0416933109954698, 0.02027061716944445, 0.04726851359009743, 0.08791234984528273, 0.031460478639928624, 0.03134772414341569, 0.03165874339174479, 0.04932330528390594, 0.20061816147062927, 0.22918401926290244, 0.20974780985852703, 0.12945390277309343, 0.15294783428544179, 0.13683527387911454, 0.20425138995051384, 0.14334834704641253, 0.14664643647847697, 0.21508812642423436, 0.14509041997371241, 0.21631836978485808, 0.11212635756237432, 0.0890215637627989, 0.13730668608332053, 0.13041296537267044, 0.18812667316524312, 0.12591926119057462, 0.13760526693658903, 0.060536592645803466, 0.09529259288683534, 0.3367812425130978, 0.10598797249258496, 0.23065128974849358, 0.048633838960085995, 0.17955286370124668, 0.08896330517018214, 0.1576153197675012, 0.1315060895285569, 0.15206865646177903, 0.14017811481608078, 0.11473108810605481, 0.13305011292686686, 0.1556676867767237, 0.0798466221021954, 0.257922678720206, 0.21892623219173402, 0.19469539256533608, 0.1607678591972217, 0.08033396821701899, 0.2857403625966981, 0.14016175788128749, 0.09960230381693691, 0.07407752971630543, 0.1176187105011195, 0.13461984432069585, 0.15381966484710574, 0.16365830175345764, 0.17201528535224497, 0.15437231253599748, 0.07777833816362545, 0.10821422998560593, 0.12630045792320743, 0.2794760721735656, 0.11366823615389876, 0.1288131473120302, 0.18775369942886755, 0.17019368387991562, 0.1608256428153254, 0.10086076363222674, 0.23703653539996594, 0.09478863008553162, 0.07886301667895168, 0.16286077501717955, 0.09633613415644504, 0.1605478866258636, 0.11146017612190917, 0.17660359852015972, 0.08764410056755878, 0.14815145259490237, 0.13648496533278376, 0.22379473579348996, 0.12033310820697807, 0.0908675002574455, 0.12122065003495663, 0.1212156331166625, 0.2758083486696705, 0.11324543462251313, 0.18741361767752096, 0.0956610321009066, 0.158270072133746, 0.09856915261480026, 0.12456705328077078, 0.22393308696337044, 0.131839640380349, 0.13314442505361512, 0.11315805415506475, 0.09548581103445031, 0.15398078510770574, 0.1317998464219272, 0.12214664995553903, 0.10912926838500425, 0.1481715647969395, 0.14852834487101063, 0.13890635571442544, 0.13991919433465227, 0.13747911667451262, 0.17865406349301338, 0.1914576842682436, 0.18578834395157173, 0.09549750728183426, 0.10821552132256329, 0.15011570969363675, 0.06669730893918313, 0.15289169823518023, 0.22139948385301977, 0.21300812397385016, 0.14760655292775482, 0.1996154012158513, 0.10201967175817117, 0.13699488015845418, 0.10824888828210533, 0.11780968736275099, 0.12382198896375485, 0.2520068414742127, 0.1520212777541019, 0.07146289150114171, 0.17630062415264547, 0.09836590063059703, 0.2899855066789314, 0.10492998160771094, 0.09961269388440996, 0.12210543107357807, 0.09178494321531616, 0.16689473355654627, 0.1718056880054064, 0.17767154902685434, 0.11575350043131039, 0.06269715522648767, 0.13830788782797754, 0.08139983328874223, 0.07826917979400605, 0.1295279394253157, 0.31126935209613293, 0.1937290420755744, 0.1690557785332203, 0.1478940312517807, 0.1988647782127373, 0.09574577794410288, 0.10848492835066281, 0.15477762906812131, 0.2858203067444265, 0.13262944878078997, 0.08941552543547004, 0.07294903480214998, 0.25649306480772793, 0.103094479709398, 0.11083644552854821, 0.09327075254986994, 0.11552733834832907, 0.1047517400002107, 0.23327907139901072, 0.10071706157759763, 0.18956320389406756, 0.09400827664649114, 0.1728953982819803, 0.07832359406165779, 0.14716966543346643, 0.15511836390942335, 0.12603888055309653, 0.1652641163673252, 0.14140699262497947, 0.1383670963696204, 0.10947107191896066, 0.13536585116526112, 0.13528304232750088, 0.1170274785545189, 0.10701153514673933, 0.15936319628963247, 0.18908431084128097, 0.1532079273601994, 0.2173164693522267, 0.15764565876452252, 0.12483667553169653, 0.09963139600586146, 0.08769793596002273], [0.03166819835314527, 0.07606768776895478, 0.01692652571364306, 0.02598978713649558, 0.011091820979345357, 0.015543334066023817, 0.05236819248239044, 0.03655477696156595, 0.11183864175109193, 0.025825917218753602, 0.06117142205766868, 0.07217730511911213, 0.03000151649757754, 0.05413572478573769, 0.04271564910595771, 0.03159258092637174, 0.10361884415033273, 0.04153939698881004, 0.02345302804314997, 0.07365234589087777, 0.0284836742139305, 0.04369755130028352, 0.06585682669538073, 0.05449962947750464, 0.019301201609778218, 0.036997657298343256, 0.052649147328338586, 0.025029492571775336, 0.03229349116736557, 0.01981518154934747, 0.04019751606392674, 0.003313145057290967, 0.023163462428783532, 0.010371976695751073, 0.07840678881620988, 0.06218169284693431, 0.038483180906041525, 0.062305338360602036, 0.034080475161317736, 0.09700491311377846, 0.0239871535814018, 0.02335846915229922, 0.012832876236643642, 0.03460073181486223, 0.018988108058692887, 0.013853059335815487, 0.07739195381873287, 0.06420190416974947, 0.06906381750013679, 0.040659833248355426, 0.05591291243035812, 0.012353200218058191, 0.03368560806848109, 0.03047086182050407, 0.04732261615572497, 0.02270948883960955, 0.017836719744082075, 0.0335864979570033, 0.04177600480034016, 0.05149880358658265, 0.08926419410272501, 0.008625581685919315, 0.029216285292932298, 0.03730442404048517, 0.005467416776809841, 0.025388100184500217, 0.04203570082609076, 0.05768948409240693, 0.10552613399340771, 0.017396269940945785, 0.04275556551874615, 0.015132189819269115, 0.03892062130034901, 0.04343401094956789, 0.03189802293491084, 0.0688194134272635, 0.021900568281125743, 0.02106536085193511, 0.06848133547464386, 0.04912536336632911, 0.010648115930962376, 0.01808190492738504, 0.014904920080880402, 0.07199674058938399, 0.022053842185414396, 0.028437341934477445, 0.02850926717655966, 0.13308152061654255, 0.022090572929300833, 0.014600228569179308, 0.03013313267729245, 0.03179808161803521, 0.015202727245196002, 0.07439308348693885, 0.07668830134207383, 0.04084969317773357, 0.007601496745337499, 0.029699356637138408, 0.030728142155567184, 0.017570943673490547, 0.015455809807463083, 0.041481702428427525, 0.03338174312375486, 0.09622457451769151, 0.06528643425554037, 0.03323820434161462, 0.012001096602034522, 0.08223509081290103, 0.030908699263818562, 0.007923483080958249, 0.05289040840580128, 0.043914870693697594, 0.043799414779641666, 0.029894474682805594, 0.0391052713530371, 0.014973724591982318, 0.014506407187582226, 0.03222872022888623, 0.06133856484666467, 0.039843355771154165, 0.03322019983897917, 0.019805260890279897, 0.09343330515548587, 0.05533677576750051, 0.02880306859879056, 0.009706049440865172, 0.02808119825203903, 0.012763747035933193, 0.03624084849434439, 0.024627050006529316, 0.04297275503631681, 0.06700242811348289, 0.03336736401251983, 0.0196894877080922, 0.029436085314955562, 0.044129147281637415, 0.07681102288188413, 0.006793149495933903, 0.02244622493890347, 0.026154150582442526, 0.03946675293263979, 0.026370063606009353, 0.02697452433494618, 0.06701290723867714, 0.06872095269500278, 0.03823361148533877, 0.07422476439387538, 0.020437719140318222, 0.010619650856824592, 0.08017995773116127, 0.06446072817198001, 0.035239364733570255, 0.05751839678850956, 0.020477082653087564, 0.0031326593807534664, 0.07999606095836498, 0.04862399808189366, 0.09920944052282721, 0.02318021270184545, 0.06570485711563379, 0.06400893093086779, 0.016809425942483358, 0.05449980388220865, 0.018807821834343486, 0.03598715644329786, 0.038675653195241466, 0.05085750264697708, 0.01347996778349625, 0.06258618188439868, 0.016132949058373924, 0.03935811735573225, 0.01109353348510922, 0.02713203961320687, 0.03014208112290362, 0.04654834832763299, 0.014741896211489802, 0.0294916721759364, 0.030168265948304906, 0.0318301757943118, 0.02890362960897619, 0.013277992293296847, 0.04091410417458974, 0.07008008484262973, 0.058622998258215375, 0.07122132243239321, 0.03428777556109708, 0.019901046180166304, 0.07155517014325596, 0.007454706892531249, 0.07060893927700818, 0.025994290117523633, 0.015895587966952007, 0.048867322329897434, 0.04072490475664381, 0.05708129036065657, 0.016338169589289464, 0.03494827957183588, 0.026800243940670043, 0.019427249826549087, 0.04817452747374773, 0.06591225770534948, 0.018496850825613365, 0.005976352431389387, 0.0730239026597701, 0.0390300880826544, 0.08910340038710274, 0.0569239031028701, 0.01904418102640193, 0.03774972377868835, 0.03109233257418964, 0.03503052437736187, 0.04595948754285928, 0.08006526622921228, 0.050059734712704085, 0.018984480811923277, 0.05620600139081944, 0.04889206924417522, 0.028571815382747445, 0.03273768139479216, 0.019610536182881333, 0.05286012506985571, 0.04494345768762287, 0.01655935000599129, 0.021332797477953136, 0.038623814180027694, 0.010388930131739471, 0.02912079871748574, 0.035399794796830975, 0.044336191640468314, 0.015639105440641288, 0.05703640897991136, 0.02205267701356206, 0.03531181690050289, 0.07943430711748078, 0.026614994603733066, 0.027872096288774628, 0.03534446397679858, 0.05954396641755011, 0.012581734390550992, 0.0018056454132420185, 0.014850215447950177, 0.004728039166366216, 0.01215025529745617, 0.08584436276578344, 0.04577945364871994, 0.05560787489230279, 0.011320335670461645, 0.03183754161000252, 0.024283866077894345, 0.06763731318642385, 0.01860843458416639, 0.03307462015072815, 0.00884920376847731, 0.04462354751012754, 0.08318276886711828, 0.0336268670798745, 0.02614201461256016, 0.03218279613065533, 0.06200004478159826, 0.014478497796517331, 0.030647826934000477, 0.05442603811388835, 0.005076659790574922, 0.029117759622749873, 0.04011960169009399, 0.030094615212874487, 0.0011098812706222816, 0.014134217344690114, 0.03177009151841048, 0.04596592938469257, 0.053063202649354935, 0.03474774755886756, 0.04168056089838501, 0.05451633893244434, 0.011318078613840044, 0.045249007307575084, 0.04605590736900922, 0.008209963216359029, 0.039259905242943205, 0.008871996978996322, 0.05247979665000457, 0.04966346867149696, 0.022265623301791493, 0.045211573378765024, 0.001886693969481712, 0.07807504138327204, 0.07166176481405273, 0.07223070264444686, 0.008705457184987608, 0.056348389844060875, 0.014903969204169698, 0.010546514986344846, 0.05251704504189547, 0.02388162203715183, 0.01700967037322698, 0.018312276843062136, 0.06110337082645856, 0.018968643380503636, 0.020023207398480736, 0.025490266089036595, 0.06414830626454204, 0.01913986798172118, 0.067310745944269, 0.008543556741642533, 0.0550881488743471, 0.058851319990935735, 0.09345801125164144, 0.0299862764950376, 0.03778447484364733, 0.038711146407877095, 0.05324941121216398, 0.03386434691492468, 0.01278259944228921, 0.024036721624725033, 0.014189096382324351, 0.0574121546378592, 0.011775506900448818, 0.04813465930055827, 0.08961516316048801, 0.13514901045709848, 0.041149903045152314, 0.028506780981842894, 0.056748374045128, 0.06962324099731632, 0.08181139870430343, 0.03316858346806839, 0.022044164579710923, 0.06226337733096443, 0.04370666487375274, 0.04493209911743179, 0.03595050919102505, 0.03479861064988654, 0.032628537446726114, 0.06207279751833994, 0.058721529494505376, 0.06584858885616995, 0.024958328031061683, 0.043845754480571486, 0.058416903848410584, 0.019412475521676242, 0.04558403874398209, 0.08652716089272872, 0.02495266915502725, 0.0549896399024874, 0.022630323946941644, 0.031123727276280988, 0.005865074808752979, 0.034072508206008933, 0.04783570737345144, 0.05017378425691277, 0.04261252026481088, 0.05109087098389864, 0.14950989454519004, 0.20094430568860844, 0.1338789434521459, 0.0975920409837272, 0.11741731388610788, 0.14637855085311458, 0.1317100613960065, 0.2664543193532154, 0.15139808150706813, 0.1339871931122616, 0.19944408384617418, 0.14631873375037685, 0.0766175746684894, 0.21141556411748752, 0.19883610162651166, 0.08939432969782501, 0.207540558767505, 0.1361448538955301, 0.13021423306781799, 0.20331330044427887, 0.10590713034616783, 0.11524174507940188, 0.0949507299810648, 0.13381020573433489, 0.17572810174897313, 0.1218282686022576, 0.12994921213248745, 0.17617624020203948, 0.17450067854952067, 0.3541330114239827, 0.1637749228393659, 0.10606606869259849, 0.11084886165917851, 0.10991272400133312, 0.15109801635844633, 0.16021720046410337, 0.20769360446138307, 0.13685618760064244, 0.1640551578020677, 0.12536174501292408, 0.12023734147078358, 0.1403966179350391, 0.0895162794040516, 0.14055067294975743, 0.12402154505252838, 0.11092096130596474, 0.1708192698424682, 0.1240194150886964, 0.12429555339622311, 0.14475660194875672, 0.09080708943656646, 0.1122139161452651, 0.1510542444884777, 0.11239675164688379, 0.23039732681354508, 0.06560342037118971, 0.1030451936821919, 0.16238927375525236, 0.19575988466385752, 0.1458857796387747, 0.1744293433148414, 0.10882704358664341, 0.09966313024051487, 0.19046908419113606, 0.16001606360077858, 0.08580958572565578, 0.1500556996325031, 0.13184308394556865, 0.1907381572527811, 0.1602955415728502, 0.21729619387770072, 0.11932496738154441, 0.12589534919243306, 0.18266032508108765, 0.09756317143910564, 0.15542436623945832, 0.09090857070987113, 0.13402479031356052, 0.21904699446167797, 0.11880135993123986, 0.13306259585078806, 0.12072550394805148, 0.09701378177851439, 0.14345506788231432, 0.12948087241966277, 0.18111777113517746, 0.19276533363154158, 0.1908681815257296, 0.12613403872819617, 0.09619992779335007, 0.1199115757481195, 0.1481450255960226, 0.06504745528218336, 0.13609619869384915, 0.1356217436841689, 0.11813969817012548, 0.1455396568053402, 0.19257382984505966, 0.1432542278780602, 0.15602222556481138, 0.09425797965377569, 0.07789579045493156, 0.17747082776622847, 0.16969353571766987, 0.14715160155901685, 0.10593031503958628, 0.06593260739464313, 0.14429005823330954, 0.1050057919928804, 0.18018425325863063, 0.13167512108338997, 0.19170354295056313, 0.1390805229311809, 0.13514071324607357, 0.08347885610419326, 0.10563396062934771, 0.16770781570812687, 0.1609702131827362, 0.11133976266137324, 0.17404587561031803, 0.15906933549558744, 0.10206710241618566, 0.1911428800667636, 0.2565900486661121, 0.21218309324467555, 0.0850541536055971, 0.27854072861373425, 0.15168134443229064, 0.12116217621951364, 0.14433719945373014, 0.19127372070215642, 0.13521967775886878, 0.10644669397152029, 0.07290812762221321, 0.1548232711502351, 0.16510856221430004, 0.13328927743714303, 0.13471761485561728, 0.060027857834938914, 0.14204691688064486, 0.07655228793737479, 0.11632375928456895, 0.17076377203920856, 0.23184111574664712, 0.16043758863816038, 0.0824458607530687, 0.16273723711492494, 0.15867409732891247, 0.23172833898570389, 0.17620145838009194, 0.10320924542611465, 0.1487913916935213, 0.11356816496117972, 0.13757783715846017, 0.12762682425091043, 0.15800981578649953, 0.1027883066853974, 0.25639501225668937, 0.13017190096434206, 0.17292756296228617, 0.17166165198432282, 0.1708957110531628, 0.21016308601247147, 0.09389811966684647, 0.10760221048258245, 0.16106623224914074, 0.17549005046021193, 0.08305682640639134, 0.17353447648929432, 0.12616252235602587, 0.11958544637309387, 0.18835365161066875, 0.11779663298511878, 0.12007586497929879, 0.17832195240771398, 0.11526308182510547], [0.01348027299172827, 0.03146038216073066, 0.01574749796418473, 0.012207787513034418, 0.09011141504743136, 0.05505202483618632, 0.07401714858133346, 0.03738921812328044, 0.07196839796961285, 0.01881457537820097, 0.045032482012175024, 0.008553263105568476, 0.04321976033679675, 0.13030971778789535, 0.023590418131789193, 0.04758249400765635, 0.06622164422878996, 0.016326833283528686, 0.09961400748579763, 0.049273291951976717, 0.04648213020118419, 0.036375084455357864, 0.048108628470799886, 0.033840939577203244, 0.03315204470709432, 0.035003859011339955, 0.03672673999972176, 0.0501026456913678, 0.010208074309048243, 0.04394985182443634, 0.09215229147230275, 0.056181889012805186, 0.019285590533399954, 0.029439751524478197, 0.006388310721376911, 0.051872434123652056, 0.0183164013287751, 0.030018140605534427, 0.02934881988039706, 0.03223766681912821, 0.054653305996907875, 0.033443615975556895, 0.05199976440053433, 0.055438958370359614, 0.047360729149659164, 0.014236359129427001, 0.011274517328274669, 0.017400023352820426, 0.02486677112756297, 0.050585153003339656, 0.07034802983980626, 0.06224031138117425, 0.039800596932764165, 0.07398605259368196, 0.09051412664121017, 0.009022488757182145, 0.057640238883323036, 0.06262429116759449, 0.054679997338098474, 0.034381378936814144, 0.0278843639898696, 0.04899585859675426, 0.043586975007201545, 0.03143311936582904, 0.1021401297475677, 0.05392199367634021, 0.048968836999847554, 0.015700866970291827, 0.023258531546161976, 0.00761577613047848, 0.0544987760076765, 0.005710991499654483, 0.03637106201495044, 0.01769798451277893, 0.05923295087995939, 0.035075513369520195, 0.008085861281870166, 0.032339500612579286, 0.08483678597258404, 0.05010604472772684, 0.05946655299339909, 0.046379346458707005, 0.04281246227037627, 0.04552600279566832, 0.039745076865074225, 0.045092295404174365, 0.04195505163806956, 0.04547299860860221, 0.01129169804698904, 0.026181749199167825, 0.062492151773767546, 0.058109124074690044, 0.04783460157341324, 0.03627154743298888, 0.021788546655443497, 0.07576769683510065, 0.017855709447758272, 0.06809740021708421, 0.03884756799379829, 0.016950738281593658, 0.039417440930265, 0.05573440736043267, 0.05702545116946567, 0.07605475213495083, 0.016050873091444373, 0.0022122385553302593, 0.08883104703272693, 0.022050452425901312, 0.0755304767517373, 0.08621235669124871, 0.026829334274225403, 0.009015227769850753, 0.024889840788091533, 0.048126391775440425, 0.06820081849582493, 0.11252565527684055, 0.020424124850251246, 0.005478076800500276, 0.0337825436872663, 0.017863335015135817, 0.04696621457696892, 0.047469713535974734, 0.02360300310101593, 0.027752042769861873, 0.03312628476123791, 0.06582511472515762, 0.019668846725835465, 0.043353328364901245, 0.04337100632255897, 0.05035625239543151, 0.07156105537433177, 0.030111469386611134, 0.01623409079911653, 0.039275891103898175, 0.048164226463995874, 0.05684429292159621, 0.03163090172165539, 0.03277553834777791, 0.021487869234988466, 0.005929177350481041, 0.027579120505834, 0.007882499830884626, 0.025306849856860936, 0.01762375861289911, 0.05992152291582897, 0.02774549888272304, 0.04168753708654549, 0.07513198797823861, 0.03950091027945746, 0.01677837448369246, 0.07659082766622305, 0.019938827063015196, 0.06798376256483607, 0.046333927020896226, 0.062278494879137725, 0.04786419100128114, 0.049862512678373605, 0.02876064372685505, 0.006618052275371156, 0.06420082063414156, 0.0900504550372716, 0.04346072826592717, 0.028011037466058042, 0.011889768884429941, 0.06564187104231678, 0.04878719635598827, 0.012202018242533086, 0.03541285288520157, 0.01507223541921121, 0.007055035785015207, 0.004660619688365841, 0.03605574202083517, 0.03912983273039572, 0.002238301622128347, 0.055422709046979435, 0.007519774226238951, 0.04058260907186195, 0.019693474896484986, 0.040903543413151056, 0.03299378171504941, 0.027088800234196242, 0.02479022787156282, 0.03957577813707758, 0.02979106197017245, 0.08932769967941567, 0.03768205104279332, 0.04038599188788794, 0.03700408429722302, 0.07225002816994675, 0.05260882273432799, 0.030882790888426825, 0.02463682965753833, 0.03950970101868734, 0.03486861372948624, 0.06659713384578936, 0.021138122865522746, 0.06576797677553259, 0.008558252193324734, 0.021086779233883135, 0.11126344761578366, 0.04646758039598353, 0.08171859313733876, 0.0716257409658283, 0.050842277487390675, 0.04015961829281878, 0.06822017370723188, 0.0636119932460133, 0.11636971306870691, 0.041043490200536326, 0.09148762401309796, 0.0522849198023323, 0.02501887058315333, 0.04863169786403887, 0.014588310605176957, 0.050690912758000195, 0.042847031509154476, 0.04340394654718693, 0.004607862729244516, 0.03294597256171983, 0.05769305753346998, 0.04958320168952923, 0.07368051039520651, 0.06845150855951943, 0.02664921874384163, 0.016060879097494762, 0.02397028642008081, 0.037737508027930744, 0.029719526355620474, 0.03500199622067157, 0.015364546052296646, 0.05422207737865392, 0.028458276065066457, 0.02861235334421508, 0.020657931054302026, 0.07106820252374746, 0.03379387628228869, 0.01844192262069555, 0.011835483564937022, 0.038969821980572306, 0.05794371791125741, 0.0455360106570879, 0.012312751314311754, 0.045704745352850296, 0.09506997826974839, 0.030338653778017033, 0.03509825277433265, 0.03041961095732404, 0.014247195413190639, 0.06652276322711259, 0.06451503111748025, 0.05001190700568259, 0.03151071461616084, 0.07124208030290902, 0.04483254371734802, 0.04539113971986808, 0.04253728133335244, 0.015057558521220926, 0.03208411275409162, 0.04479953298869077, 0.06740447177435271, 0.032765719734015875, 0.06800456496421248, 0.015483039205719251, 0.03500756232824642, 0.04332710457674693, 0.05843913859280292, 0.048071550772874616, 0.0036741224403158412, 0.12626845651539043, 0.06731316534569487, 0.08876659892848693, 0.05889936663152184, 0.07208067749161273, 0.029870781618228648, 0.027679727900249418, 0.03640699680545367, 0.024212415810325183, 0.07294873052160256, 0.00276728268545412, 0.05601709883194417, 0.058034968678839505, 0.008363485740119359, 0.004210479755784036, 0.022869822423672304, 0.023815322274458595, 0.042796342822839506, 0.039221714323502965, 0.02618298301968025, 0.02722442957747262, 0.02276071743835928, 0.04314921920013148, 0.0565149055182701, 0.04834477986150887, 0.051410131782176904, 0.023754007888783235, 0.014750095087947557, 0.03585810438380577, 0.07357247595791705, 0.009150595506071113, 0.0577092103776522, 0.0310209657982341, 0.04838221750105731, 0.041124759081867523, 0.08697598954313435, 0.015505298997595673, 0.03437433966610115, 0.04549887729808688, 0.04786432829860132, 0.03052997388294898, 0.08343665016582236, 0.03671193044283427, 0.013859682076144964, 0.027166434447281063, 0.048271811901940964, 0.025804047982092015, 0.01596390822669491, 0.03676491236547008, 0.0040860600893211085, 0.04858514294028282, 0.02534930441470351, 0.012967546354047954, 0.055937544311746024, 0.11154831357998773, 0.017748411592037883, 0.028272308700252324, 0.023629349343536887, 0.049981872289208695, 0.052035550761502236, 0.01759533435688354, 0.03279534626926761, 0.07656122339540161, 0.038559403183171526, 0.05626728052448016, 0.03483523192699067, 0.10936728998785838, 0.049088174346252345, 0.024188778406823985, 0.0577718216663925, 0.06108709923864808, 0.03062306517676916, 0.0272552862224984, 0.06193854671437293, 0.018048127931251656, 0.02672215887287166, 0.012017236458632397, 0.02170399748138152, 0.04162797973549459, 0.03706337076437194, 0.028033646995027084, 0.03331533203891013, 0.034338438272243366, 0.014009772166900802, 0.08876529274857603, 0.15826184913748875, 0.17515511921374127, 0.14380101260030642, 0.15436683548614383, 0.13315245509147644, 0.16067099408246577, 0.08235178611357696, 0.27336718747392297, 0.14026453049154952, 0.139150878530927, 0.07668918449780904, 0.20435641868971288, 0.20350806968053803, 0.14229123189579695, 0.09961978139472194, 0.10243797587463632, 0.126232210022863, 0.14103256427915767, 0.06088428883231245, 0.13649673579493538, 0.09955279514542781, 0.1359190628863871, 0.15842237567994744, 0.24262029124656692, 0.1719626522390172, 0.1914249555557035, 0.14874199434416369, 0.11852866518893279, 0.13211634272010997, 0.1829922728938982, 0.16924965719226748, 0.1383908450952731, 0.16284140496281907, 0.12444899984984659, 0.2001043874770403, 0.19967861735494807, 0.12986264802748337, 0.16331249062204733, 0.12163934006821364, 0.10427289889776148, 0.11606960339122452, 0.13889244786696509, 0.16005823243176565, 0.17141806427389383, 0.13735513348365203, 0.1397669650032185, 0.12447034401702695, 0.11511053337017074, 0.22642933035967872, 0.11591180053073913, 0.1108295658195857, 0.09269284215406515, 0.13647518382640556, 0.10797586699482054, 0.07832276285625994, 0.1385264948476106, 0.17810606164857745, 0.18864334153477103, 0.10923891328275204, 0.09434484061785042, 0.14691913122078404, 0.12943336012540385, 0.15235611994285136, 0.2009522615117021, 0.046842439187457785, 0.1560068631079048, 0.21460396412294358, 0.0903829891467467, 0.08716869560885243, 0.06498497386928648, 0.10350536234909669, 0.17801361973397434, 0.18389646109426394, 0.16816724964883178, 0.09799041843507439, 0.17196069296915084, 0.13980708550661802, 0.21227764285868034, 0.10771358458441682, 0.09374797577038407, 0.1614721870282665, 0.1456750393845141, 0.13763205846771598, 0.10594762934488244, 0.19410366337979212, 0.10272270083078183, 0.1608077422133647, 0.16639105277135968, 0.11616032352321781, 0.2376339049078524, 0.08636715385364369, 0.3272271004971117, 0.14561934862285852, 0.13738017354626209, 0.20230227266438305, 0.18240251782117411, 0.14005321136210114, 0.13851093943230808, 0.17356477095745504, 0.11157024404383264, 0.12505945342127234, 0.09862528124358505, 0.177128994546365, 0.14076558407396078, 0.11727924473234452, 0.17167713318485767, 0.10995067001204006, 0.18320384435355663, 0.11556791898328811, 0.1384257260360755, 0.09788161958567798, 0.1077910276944749, 0.10911121193203144, 0.1316387706901878, 0.25606600334867835, 0.18605182121973485, 0.16078740736702457, 0.11042450903914869, 0.08463923368253745, 0.10438113371492364, 0.20083917304873466, 0.15334369585616514, 0.13842201529769227, 0.11062399091315456, 0.10062068628030829, 0.10341070883441716, 0.16490151785546914, 0.09115292283240706, 0.11797272236435674, 0.17374469724018127, 0.1334552958724089, 0.24843332619639114, 0.14343431743327528, 0.14923310314770788, 0.11238818726269528, 0.17290900927037, 0.12858038011472672, 0.11733651626855135, 0.08642003929708153, 0.0848134899570141, 0.19424185127718374, 0.11383100398234092, 0.10622281028190628, 0.10550074512138963, 0.08718871133169159, 0.1509496313519776, 0.12199577133287676, 0.14113606419414282, 0.09527107802568935, 0.16338838264346123, 0.10410420873085968, 0.14015402470249683, 0.1720783085329458, 0.25647180969826877, 0.11787789073423482, 0.16454154654638842, 0.15363838785560802, 0.16178728808881715, 0.18308397266082466, 0.1005310942127835, 0.1044628070667386, 0.10963401044136845, 0.10801779833855107, 0.10694854165194556, 0.11336255294736475, 0.10514886322198436, 0.12552273168694228, 0.06312292534857988, 0.0898880731256213, 0.08757983057876118, 0.16613793588476256, 0.10090850599226542, 0.1195870345691219, 0.19140073185553774, 0.08297739434055984], [0.03620655756094493, 0.03430401375226211, 0.012680570835073013, 0.0787742632383015, 0.025110546230280306, 0.03021047745278338, 0.018150228897866327, 0.028479709289968014, 0.054439226078102365, 0.011640259763225913, 0.032051239322754554, 0.04375449629151262, 0.04241378053848166, 0.04322790169680957, 0.02770970510027837, 0.050627785676624626, 0.04491057312407065, 0.03481687119347043, 0.03361790564667899, 0.0557046991889365, 0.034599199279909953, 0.032232568264589645, 0.06170038781419862, 0.02516223867132794, 0.037931679835310206, 0.022852842084830627, 0.03818879689788446, 0.07930057210614905, 0.04422560421517119, 0.004214244299873826, 0.02104516330291517, 0.023024873771646526, 0.016786864653113298, 0.03905624136677943, 0.0808666595548857, 0.00543601418939943, 0.019620681341621093, 0.07034087553620338, 0.024145672614395153, 0.026656844311219174, 0.04381707789434586, 0.032413322041975334, 0.06090557362767868, 0.07833228461095132, 0.018335157255933154, 0.0592386802600231, 0.013589510635938495, 0.05028889878303744, 0.01228383445777581, 0.019324043059896212, 0.07787463182467036, 0.043137459870195016, 0.03752315722522326, 0.02351621264097048, 0.05207825393881649, 0.017735077053657733, 0.025476875889580697, 0.06279229855863377, 0.038757278307457455, 0.037893533444730565, 0.004582595847750781, 0.020191873445583042, 0.027907634030270856, 0.008612654401076725, 0.04360379578429274, 0.018864479243347887, 0.03824671781330835, 0.04551008743874263, 0.049638320997473784, 0.030651828965346795, 0.039769315408193506, 0.034704869976849295, 0.03189399678376503, 0.05004807928344235, 0.05239416022959631, 0.02636570905451663, 0.03311641419713851, 0.06993716204306111, 0.031428451256942935, 0.06839094930910505, 0.04453800014744047, 0.04418678618094418, 0.05455820348288398, 0.059332428354537115, 0.024158686173905153, 0.07652567452169023, 0.005253706076473463, 0.05444266222184524, 0.017647310669417493, 0.036528927957988344, 0.07289820510777645, 0.041202406282536685, 0.044658350525423884, 0.030521832522936165, 0.06428563327062875, 0.025251572842535097, 0.04109194502234459, 0.03789774884353392, 0.03751155745703727, 0.07548789973952807, 0.06761001699487679, 0.04739973272080533, 0.09371024498250335, 0.05010909866541624, 0.07157641783123836, 0.0414708856260404, 0.03230883135984186, 0.014522750207106583, 0.054657610453432426, 0.02499491962225875, 0.05059283794253133, 0.051226175637566485, 0.04137787225772627, 0.03798688077949919, 0.05901192445890047, 0.009972122370527359, 0.0459352267353097, 0.055018579951138236, 0.011454816540208412, 0.03331398133013863, 0.03790852853853721, 0.030183789822331164, 0.016549575921089854, 0.06389112240867689, 0.026060519376187585, 0.03366190387168899, 0.10873728824662976, 0.023437383570126258, 0.03405421426577959, 0.004995319013687549, 0.05070033803349361, 0.022878204981680028, 0.013711285009776475, 0.04843153692490887, 0.027373875855118968, 0.055814455408835784, 0.0645439006621018, 0.07732003228738904, 0.028928515675943345, 0.047670290077803656, 0.010494483940419741, 0.024449541269859765, 0.03611568157793954, 0.0314050216547912, 0.10280644477461465, 0.07452220976119861, 0.028043771744705737, 0.04597271261445712, 0.06465574973844923, 0.07304425234906375, 0.05096046079415828, 0.05938306509051472, 0.0511480905697681, 0.07295631527085789, 0.034556455284473486, 0.006971414295549039, 0.02998523192218272, 0.013243739394965814, 0.06831320191849954, 0.008121402734104777, 0.052303911361377686, 0.07930998253868893, 0.08539730042684823, 0.028890632747788914, 0.014823139117652318, 0.012130055893067038, 0.04510306396696251, 0.028669023740803823, 0.021210454433457926, 0.022342825213854667, 0.008421680322499014, 0.03031240587006323, 0.01387473468639655, 0.06891611526953056, 0.0337285413115751, 0.033504806051496416, 0.0073446556689305, 0.0849349275813438, 0.08302564136101864, 0.05393676983658224, 0.07834250398445874, 0.038595356527366675, 0.04672506111091934, 0.0371572190488223, 0.11430189668317325, 0.05789991264464334, 0.028115528148191515, 0.01696708037343342, 0.033152178293676116, 0.04642889223759994, 0.06445366292609833, 0.06132303169579245, 0.03666148295451421, 0.04649209353374317, 0.03576377741410397, 0.04694168659625575, 0.02770941751805367, 0.11086155980592594, 0.060251841714489274, 0.021557632971962448, 0.11892766604432836, 0.025194867193931714, 0.03330022933369037, 0.02591735352325486, 0.02731195476371795, 0.030877204371790867, 0.02839308581314981, 0.013056646748736966, 0.046805843885522336, 0.035223872400820255, 0.056676767926546745, 0.03308835730422288, 0.01713254961941857, 0.0124009370119893, 0.0071183683485287474, 0.034339814956183545, 0.010693353542592376, 0.020989199801988434, 0.0056037224021565635, 0.07711250553256832, 0.012051647063344717, 0.02215729942690814, 0.016123983914440032, 0.02671572074177675, 0.06434790688217618, 0.07560731130070053, 0.04658777492295485, 0.04853993872529827, 0.005099905247334391, 0.054196974233491346, 0.019231424885219894, 0.05918158683925867, 0.031247274455381557, 0.031840098308748566, 0.030362352408701554, 0.03659331297967583, 0.03530852176481858, 0.04207292695355136, 0.0344133469479857, 0.08130875692586415, 0.04449643616680987, 0.047009834306663834, 0.0416642522031907, 0.02553829974203836, 0.02647491237439681, 0.020010856205772143, 0.023896628263173625, 0.026529065034992527, 0.015370417368103517, 0.03028812465345254, 0.029548001184593886, 0.013646412025991594, 0.059050686832051724, 0.01818769993406022, 0.008909514399420004, 0.01445944037186564, 0.02898205420933664, 0.07138858767575584, 0.05921120224229526, 0.006648078642683686, 0.03501162187603768, 0.08414678159169853, 0.044978398000239395, 0.02529817971662851, 0.043839809877681546, 0.09704254000098445, 0.057140858843922615, 0.04411459376569837, 0.07129335528588854, 0.0898276548832655, 0.01836826075304998, 0.03746321766811889, 0.0509920391777996, 0.05289492808515206, 0.03806955231993925, 0.048991917792591266, 0.06983407773077488, 0.012795786478818627, 0.07495312296668999, 0.06573368213139474, 0.004726928727905033, 0.017985720733122434, 0.03498269295960199, 0.0852103163197171, 0.04863541602389887, 0.08563801602576859, 0.032282177126035094, 0.032539947278564796, 0.015249101270455867, 0.08362296634004451, 0.07160277149523608, 0.03678828630654607, 0.02079060850519454, 0.023341050946328323, 0.012362438101263251, 0.025688174609967973, 0.04565203431411646, 0.049283849002677016, 0.04972673676093109, 0.04547251250187401, 0.026687827121349983, 0.021217972389422357, 0.04505896184127778, 0.013937286603322718, 0.07466466500773095, 0.037744406290585175, 0.03503072104649618, 0.021738533323514275, 0.03620176328695379, 0.014869862880004803, 0.04469964733289089, 0.03805114334682003, 0.03745617839740589, 0.0309265516261803, 0.05928562110057101, 0.04769268067320809, 0.06519089758512564, 0.056893371147452854, 0.021951661437924486, 0.04287748182832729, 0.021682625483663287, 0.015031964630907169, 0.005322858933141106, 0.014444841399381403, 0.05364651216950733, 0.06454084301367402, 0.03345190947584342, 0.061077317732269876, 0.03593078290577978, 0.05747491064539645, 0.019097081312793307, 0.05463987312396057, 0.00560434951694333, 0.011468228076410014, 0.008072518394328654, 0.002351634761907917, 0.044091835807194, 0.09335938724689186, 0.05919893825193867, 0.039781178638804704, 0.012339412041910691, 0.06874424128909595, 0.023080095124896616, 0.11670276668155566, 0.02391872571024578, 0.018061334449157584, 0.026835761273105163, 0.03176761274517048, 0.029111982003087178, 0.020361296483315527, 0.04294875398045406, 0.0498119650001172, 0.1563620995148085, 0.1574355419143103, 0.16789516346761957, 0.12287540186662227, 0.2822713565547019, 0.0999880424933508, 0.1413472497370094, 0.1496025887900032, 0.20953730709152296, 0.1433783446555026, 0.09039302298333496, 0.1695912380819209, 0.09404063428519294, 0.16066945041529834, 0.17859126295661554, 0.14073055470362306, 0.16954069782514125, 0.12095933241653256, 0.1044358299986925, 0.1088932654238306, 0.13177713670302182, 0.15918773773591965, 0.1221280220488552, 0.10410678398329765, 0.1379686372820288, 0.08287822114652954, 0.12343047637841664, 0.19900388637324795, 0.14930510631529614, 0.113842536957236, 0.09161024907371029, 0.1121892619994469, 0.13249764335341752, 0.14344924944452941, 0.15607178618665785, 0.15176431654253975, 0.21904113149503246, 0.19416515773627907, 0.1048781129065901, 0.16223005339270458, 0.11209269374376163, 0.13706476078368723, 0.09128265766776167, 0.14729287679074332, 0.13382807665038854, 0.11974621782428585, 0.11101656476967037, 0.18548738822573796, 0.14994725701399148, 0.17256604798603803, 0.16397746978327632, 0.05826287480886094, 0.10430978363729082, 0.14621953829191625, 0.0592802442406537, 0.1344283256912604, 0.08812237021629699, 0.2182004414498806, 0.11120540424599312, 0.09701744798803702, 0.15635129384463653, 0.14631324185756966, 0.1148842673865147, 0.15297723817639053, 0.13656853116117418, 0.08623489571618848, 0.12486538180382922, 0.16119842359330505, 0.09361746910144575, 0.11146206859848462, 0.07013036534772255, 0.18030437728157267, 0.1461098637082614, 0.13814817764796317, 0.11405752971768379, 0.27721427322831005, 0.13123536889906973, 0.16392407967941836, 0.20468784699914977, 0.13769186072750017, 0.10250537772662938, 0.12112566997529939, 0.21729240892454982, 0.12008762801997364, 0.155160799913574, 0.2206419440335594, 0.1478819639305584, 0.14999104372691363, 0.12175136726000346, 0.16810747707495466, 0.12577031215187162, 0.10153062612516806, 0.12440180667908862, 0.14765218016691506, 0.20586900471244007, 0.2042787306709215, 0.11998895948636346, 0.1792920581647195, 0.11539175538928248, 0.19208604586310685, 0.10330460398108698, 0.10647025716025382, 0.24094133055768907, 0.24689380021300167, 0.1492206795956008, 0.09001650920254178, 0.10098810875206254, 0.20289383857743815, 0.14460846927249804, 0.16734490549424663, 0.11527868176926859, 0.13036064396146685, 0.1411135622765869, 0.14283215365139768, 0.21166250633541495, 0.14365476497914642, 0.12772882502758875, 0.15296788711566478, 0.15424325305502862, 0.08428223096416332, 0.11274923468590714, 0.1318371170782484, 0.1519682735670358, 0.10983750733430497, 0.07409472527797334, 0.09633579276851378, 0.17513436876470223, 0.12760393641656265, 0.2430213478510268, 0.04333216231316328, 0.15460439695743844, 0.10938988838461228, 0.1112209448183421, 0.1426688811625354, 0.1732270937645808, 0.16000469389837235, 0.10755387440440245, 0.1213423177250661, 0.099322358291829, 0.18254866154165938, 0.14876500092213973, 0.16044446092564613, 0.18891648156568408, 0.10985600165440701, 0.2135088064824231, 0.18190884118666872, 0.11666775957564823, 0.08188668216462247, 0.1810085418401286, 0.17017536767525598, 0.1947589055635035, 0.15798674983670935, 0.11469329794635996, 0.1422266650479287, 0.10533538719755597, 0.11963292155996896, 0.1052947249263525, 0.07947402686113492, 0.06235456501599401, 0.09583656486938708, 0.15809081378392875, 0.15020479710074142, 0.13209286116762087, 0.1628253300441429, 0.17618124227738008, 0.1844716552295722, 0.18315873661777005, 0.24517651501810178, 0.17276567086810246, 0.11062622477766126, 0.13434055930702016, 0.1968294827383943, 0.10973063806886785, 0.1825755718164146, 0.20178401609882712, 0.20901153999147937], [0.019405491912038997, 0.05538494857319165, 0.028979584712942597, 0.005684238931280561, 0.0346804792934563, 0.048236122020171024, 0.012587824639922474, 0.025837947432592046, 0.012001392533420585, 0.10549512706347741, 0.007475310303561855, 0.06327211929601617, 0.11192071586265229, 0.03169686380715575, 0.030521762018906884, 0.017399034441041294, 0.03265479092078749, 0.039019842733978294, 0.020634902211895678, 0.08416824450250715, 0.03582524208468385, 0.043148209879291244, 0.026157716602028813, 0.06008623888192233, 0.020200625222059898, 0.02544504703109851, 0.0408472292474471, 0.01606754543900024, 0.04444083075213712, 0.053851701159146614, 0.02988859316246817, 0.03275572671554983, 0.05394995409005787, 0.01605004188604653, 0.04492288164328784, 0.02579583611804992, 0.03239013363781851, 0.03905251949618105, 0.003075488034482987, 0.05649534992699046, 0.07714084815233946, 0.026333288333262317, 0.05137612286489457, 0.03423276015382726, 0.02743468929111259, 0.027550644299481064, 0.057269443350378424, 0.004576500496114022, 0.04008354073448572, 0.015154959837673232, 0.06272310070926324, 0.026203280758636538, 0.0261389736624551, 0.021717302333854605, 0.08652814794913866, 0.06588096875930205, 0.038219618290895596, 0.06737935007549822, 0.04724029713543132, 0.016053125509642996, 0.06893519588629715, 0.04737751653010491, 0.033555446498212405, 0.023992498900042847, 0.04722889032564126, 0.050434270669938996, 0.021362119732657447, 0.00839506783449906, 0.011032468646590132, 0.015738068977952935, 0.02362968702072976, 0.060359980052453466, 0.032466456104884855, 0.09211649768985808, 0.04917975536955055, 0.03142079971439671, 0.0324647862726124, 0.018374025385128334, 0.0029357912580962875, 0.0413922513689613, 0.029618039516208228, 0.04546054537058808, 0.03732571996806655, 0.0038994772057776572, 0.030295549840957392, 0.032107664810610004, 0.10788159939693287, 0.021312095268513076, 0.07353298628004268, 0.06568511598743498, 0.05041779499151744, 0.02234428724477766, 0.05455337952298578, 0.02470134641043842, 0.004039748218929162, 0.03736806320375763, 0.04372478440927807, 0.02300529962667497, 0.019446679252723698, 0.017758675494405907, 0.0303879490820691, 0.045619409502251074, 0.006741048409821815, 0.042488470280659385, 0.04460446689336095, 0.0462815907667391, 0.06938615450053476, 0.03371304155734833, 0.04428088308486622, 0.022541778307640925, 0.046486976425512694, 0.02128131098288577, 0.02324025615962455, 0.0631038669962436, 0.02372252598433988, 0.04207925376249477, 0.09415884356712922, 0.030641424054920208, 0.018340895912842825, 0.029221936747489963, 0.10237478199996985, 0.019378349716134835, 0.01647539083933225, 0.016058441142376978, 0.02987602674693335, 0.0322769524063915, 0.01860513202700531, 0.01715946174954297, 0.016332789018633775, 0.09201569177093916, 0.026836184297280852, 0.03049051945708925, 0.007053179488138994, 0.03224617183150258, 0.037601246003760025, 0.02844285794708412, 0.04065482375153806, 0.05541335056477692, 0.029090071948303375, 0.01528578655779711, 0.042499980991124175, 0.01922000137710711, 0.003253255827075918, 0.047194157814374194, 0.02774852684524376, 0.04360474573331885, 0.08849990816088393, 0.014017250232427614, 0.026664750039344653, 0.0748409770312719, 0.03957348861149512, 0.015970888125593774, 0.008228251590480795, 0.03102745959040476, 0.08058068036916666, 0.05157418723683804, 0.00947335924138315, 0.08492041859426536, 0.034176034096162766, 0.07014105227426626, 0.010936782618955476, 0.07323449448449537, 0.03017642957274802, 0.016238523276115302, 0.08207259015762247, 0.03293929323263001, 0.03871870147122536, 0.010564926742517855, 0.054936721062404104, 0.03503836145682726, 0.053769040750921704, 0.023461408745788503, 0.05471781347296201, 0.03195480465365108, 0.05759866377047729, 0.06062406217097305, 0.06639593018917367, 0.03273434915172402, 0.03160717897117138, 0.08182237506844103, 0.03442993023782037, 0.01873532328318106, 0.0074183393371640705, 0.03016308390215272, 0.013810768050461775, 0.054067206001491286, 0.06988379420363344, 0.02844674494554056, 0.10403849897556938, 0.059340599400456995, 0.03445073263719678, 0.01927322635310702, 0.06245002005016431, 0.02411738194496138, 0.04423881815455388, 0.07276046249899082, 0.01125787373894127, 0.04388899942568969, 0.024077706730167847, 0.024647004502185155, 0.036209489044267684, 0.04096161275811028, 0.019447388003754895, 0.013071845005470095, 0.07724723502178676, 0.04678712321037892, 0.017540853295940906, 0.05600383294222411, 0.014541074760927586, 0.022957714973017573, 0.037922829724266194, 0.038838101900182664, 0.015815333972568624, 0.06952414943953045, 0.02309419222001452, 0.02039781571511412, 0.010901859004661674, 0.021692709415219724, 0.033152649557450786, 0.039400709210895, 0.05390027101384476, 0.0753483759763185, 0.05054611603554804, 0.03939666450605728, 0.006909601279403432, 0.04739268231787719, 0.08707872504601255, 0.0556315308494959, 0.03808566805673763, 0.02885364039684646, 0.012496282579377294, 0.034649257140699774, 0.015665705868741497, 0.08503046425175853, 0.02960258429084206, 0.03312867076601833, 0.035131816403009, 0.06866100200568326, 0.04308816642151214, 0.042216506553813815, 0.05893244786420837, 0.025662743064458482, 0.05202355023357086, 0.0451752155640861, 0.10604458351735957, 0.029101285799697507, 0.05662332216161303, 0.017599573875486385, 0.013833064022037433, 0.022509890077344608, 0.07960022165207192, 0.019204219606763218, 0.025670645081845578, 0.012777433166775154, 0.004368740892459755, 0.06243046445888467, 0.04563524322293233, 0.029254164510348346, 0.004252519638612284, 0.018012170876318123, 0.03483485343167558, 0.03234925614378881, 0.056213137140730396, 0.030108864448266104, 0.028885168685519602, 0.029468929060385562, 0.07695100677665323, 0.030652012646896765, 0.026007040214608423, 0.07130099198548123, 0.02363802876061527, 0.029528273043979425, 0.03023825975105865, 0.005779957891718368, 0.027035369312216062, 0.03205955508747138, 0.02700930694118142, 0.06491398002253845, 0.022760927095077932, 0.016850542779138777, 0.03997313884610776, 0.03248293920478318, 0.004199726499791723, 0.019170639279764146, 0.015954000555211678, 0.035480815058690496, 0.034709300598478876, 0.06521193747175857, 0.060636968119069934, 0.011472080750536406, 0.006653736591033521, 0.025576666921551805, 0.05910874133405741, 0.020155580568825826, 0.03353064021212049, 0.06322450310108252, 0.03679844630823936, 0.07326002436457202, 0.06206282305356581, 0.02874925918149529, 0.020435871192603372, 0.04188964616332669, 0.02029417850280879, 0.010346443104936043, 0.04924120148643851, 0.003560338909665006, 0.014166209475661162, 0.011131463725178037, 0.053343292893259786, 0.010325151815777645, 0.045235192228574306, 0.0624887972662691, 0.07118480134522542, 0.04328235307184514, 0.016004488861653954, 0.028549530543386936, 0.019754585191549268, 0.038925044500501826, 0.031510261906078085, 0.03298807831015438, 0.03219221769541036, 0.024587051957496442, 0.05389688682043925, 0.05072097344964277, 0.04552454447548371, 0.03615161265770439, 0.03675148691399954, 0.001042009430420876, 0.05099937901832163, 0.014134016037132824, 0.0836072550737299, 0.043962071285932325, 0.07371677915216424, 0.02591176515124971, 0.022842164435132872, 0.02945626987639116, 0.030929407039366197, 0.08655944431666285, 0.059274154918966815, 0.026005641266237944, 0.06767237966414541, 0.02701324217923684, 0.018329353661101777, 0.026320410215703305, 0.05350249841285404, 0.046994171279948205, 0.01972093064978253, 0.012926197596243583, 0.03331372528919019, 0.07782159795169719, 0.031264577628462575, 0.031984323577489704, 0.15216213738312945, 0.11947615770623088, 0.11567026856937446, 0.188772683031857, 0.0882815386285074, 0.16107539035147056, 0.14152345043839887, 0.0975338566058781, 0.10270380575093441, 0.2438363595865667, 0.08622685825685039, 0.1391172592411749, 0.23035215970594436, 0.13547749986173585, 0.10756447969470173, 0.12610974081326276, 0.14734432246768847, 0.12047845040797256, 0.14551393396686763, 0.2312568822526373, 0.1928683734149672, 0.11593925999477506, 0.06860750800115056, 0.13251239724922925, 0.08036747618461959, 0.17535950668388978, 0.13093568966723979, 0.13017463206779212, 0.16913003782974556, 0.20201396313495934, 0.16775108291767538, 0.11525803522090428, 0.08256193264969625, 0.06578888307558373, 0.20354413805762306, 0.17018004320561886, 0.08183072422980331, 0.18454769568052143, 0.07654494067537598, 0.12803773657651618, 0.15708349674241617, 0.1328982101404108, 0.1121432933723554, 0.14086647162912413, 0.08446095496765338, 0.19187756173778325, 0.1804696535691619, 0.1886499614920467, 0.09730562393087894, 0.12987263733521104, 0.15090940694790334, 0.15662582911318168, 0.1577828818699345, 0.09752101745107211, 0.11976671594311483, 0.2218780355178751, 0.07912569984910078, 0.19969095184933394, 0.09105205012019724, 0.18171361181885004, 0.18541341094532982, 0.1898502220865339, 0.14410872186999768, 0.11739680092432536, 0.12408086491632275, 0.119840025290614, 0.09374901477713138, 0.1463192087248899, 0.1398505159886554, 0.08992668706923723, 0.16960991051746532, 0.13229232077719644, 0.09442695183679461, 0.18741731357295066, 0.10426653127069585, 0.09589332432369702, 0.1603504753438756, 0.06658781989244744, 0.08537111003533937, 0.14818158379057422, 0.11285562897683121, 0.2329474056023173, 0.07726446026936173, 0.03724809503182769, 0.15601944993250072, 0.15576429956126958, 0.1550013420637697, 0.18224068509880453, 0.14859862625598907, 0.12980205909116194, 0.12783373502315953, 0.07560967133031227, 0.17712357686832547, 0.16565269004786387, 0.10926752307568677, 0.1649782113963738, 0.146290636039339, 0.12186306048533879, 0.10710154281696305, 0.1022690704849083, 0.17156336194602773, 0.26822935848031193, 0.06936052071978338, 0.17882414889754727, 0.11557139965589158, 0.11571129449293949, 0.11078125942731276, 0.06951044197194278, 0.13805955037241802, 0.159105864004232, 0.1354781529516913, 0.14388588460860774, 0.11512982920976356, 0.09555078606354073, 0.1237867221061606, 0.1997902215225622, 0.1620840432588011, 0.08490142703521997, 0.14092848548898473, 0.1566557673504576, 0.16378167638322338, 0.19658236240502447, 0.12188736582174897, 0.10481741264811717, 0.0883152024471201, 0.11268511312664486, 0.27831006911583245, 0.10590310048428364, 0.13018708530580625, 0.16008684964617714, 0.15596651996020228, 0.079447584139416, 0.1270305085927248, 0.12140066537540406, 0.11551089977729134, 0.12340448636678047, 0.15004554705228657, 0.18415434256894514, 0.0891232379944995, 0.13686381687875837, 0.13248584320535883, 0.1567210169741884, 0.18109734723111615, 0.15153947548242286, 0.14699028834002092, 0.12039956010994501, 0.14546127116773278, 0.14529577223584056, 0.16055836575105786, 0.21771795640233904, 0.10411546711111441, 0.14209883753210306, 0.1016935943334829, 0.10788493906147778, 0.19622363790404052, 0.11801656844909303, 0.16259094496490434, 0.1872316430672072, 0.06999582881690003, 0.10084453286253847, 0.09928101324476302, 0.20646904595196247, 0.1925762789323926, 0.12166846936452202, 0.1869006155175157, 0.08043529363931157, 0.08579898785683326, 0.11246756737818941, 0.17833636491559446, 0.16093310579890385, 0.19709754647919908, 0.08230281920987181, 0.11044243932701647, 0.19328045833390206, 0.13614947005407885, 0.17237396532436833], [0.044843753858003765, 0.022397356369765475, 0.026878831813519355, 0.009793639565032208, 0.006394182964868378, 0.04337624959589448, 0.10567529083346017, 0.04835708095924929, 0.10614987200824544, 0.040202306627179496, 0.008130106270982651, 0.007418063814839115, 0.012047130167047726, 0.01603807289939141, 0.04564814174955245, 0.07540952894487418, 0.030229686090024188, 0.09645163459936157, 0.07167526448029093, 0.04533092556812335, 0.02676091196917696, 0.05660908034769818, 0.014759871955902781, 0.062411762337433174, 0.004351200695964508, 0.06813172454712912, 0.05237471224972978, 0.009578059580235276, 0.025046417249541264, 0.05656544948578812, 0.0821259431540966, 0.03031427793757757, 0.05414017396105919, 0.02065748762106523, 0.0007019595682322688, 0.04782846772286575, 0.044582265545614064, 0.07535218319389969, 0.014426771031139651, 0.0405220906395698, 0.02984671747981338, 0.022489440198114607, 0.03773481032112613, 0.042400314268888906, 0.0034464561167624197, 0.05711923637136351, 0.06782608586945571, 0.012542247495730408, 0.06756755130481906, 0.06651799121755175, 0.028209869960846845, 0.038887506671017036, 0.03389041856280528, 0.042015725921373814, 0.05637887727061752, 0.05585690996667836, 0.024653360997035634, 0.051036653385381214, 0.017744949473126326, 0.0041017755302164005, 0.06620480489800684, 0.03449848241871223, 0.08175240538548678, 0.055121044570114464, 0.030398077542486135, 0.04282735717424657, 0.04027804279758129, 0.04073604068253189, 0.03141513341688551, 0.043116056331200525, 0.03519025311106816, 0.03386755670362618, 0.050538742798380554, 0.018828733700502198, 0.04689432644227054, 0.032725038909120485, 0.01943986448168289, 0.037870396990911104, 0.034865530105889775, 0.07707498254603706, 0.06512533625937067, 0.04073465657711495, 0.01612726420717081, 0.007797696471243398, 0.055382807477144524, 0.06357653343002312, 0.03940471309761051, 0.010785208232846344, 0.04628302311175503, 0.017779297922970727, 0.06912675162311643, 0.04097664867003914, 0.05816433986183256, 0.04866033363214228, 0.047964573896024376, 0.03293236899480689, 0.028715344888041727, 0.008481041932100197, 0.02316477974090958, 0.024280799152620602, 0.05827797380334232, 0.024687423720024526, 0.05154659418622032, 0.03789135895203799, 0.07187430848716758, 0.015647825675841887, 0.012833007967856247, 0.0943629490211606, 0.01852708592195995, 0.026642531993275043, 0.046875913758412935, 0.0447308064030949, 0.04912776050332468, 0.011119571736344369, 0.12142927516833879, 0.03123549286101479, 0.02865911606932059, 0.13367761363042518, 0.02491801085852785, 0.04778320042532869, 0.0628399221750442, 0.02780399125185795, 0.027872077735082712, 0.03455743863014504, 0.045272336719790474, 0.049914270057342947, 0.15441848896443844, 0.0251263280006242, 0.04374641059257556, 0.0088658046843193, 0.059111565205967054, 0.03362494862813037, 0.06254785737837665, 0.014888223613525042, 0.03625078585173469, 0.027071638069173787, 0.026057639843202196, 0.030904292761988472, 0.06395792312105186, 0.03811266738921404, 0.07803025277098641, 0.035517662690836005, 0.06571380741661415, 0.07163264293922111, 0.010876891301450087, 0.044437097749323584, 0.060147057884023525, 0.07856313706724904, 0.04240408437908627, 0.02528678218368441, 0.028156242369732354, 0.04538634544587694, 0.011435819415055448, 0.022252797134569846, 0.043637504131766036, 0.03330130173708312, 0.0313975630706409, 0.008431415444647428, 0.07640634459676221, 0.017371714129694737, 0.08236827663495205, 0.002240606454506633, 0.05482882021169644, 0.014861245617794339, 0.027854236504936125, 0.01319630502621294, 0.024359385170100722, 0.04569732387608383, 0.07639475225005299, 0.041248883280786686, 0.026605443163134623, 0.07999489578651264, 0.010804663634189637, 0.09609549277229235, 0.02214635089330841, 0.018162175620091148, 0.10314714993000962, 0.08013095372007228, 0.040174591122195125, 0.04992435955500696, 0.011354140497132903, 0.033299160641035996, 0.046844057069392875, 0.06365383553202264, 0.022568367603525985, 0.06230385406524874, 0.05635834204440471, 0.02327319081814494, 0.03555180519470014, 0.022214513446670026, 0.03336690759169869, 0.02824044644512469, 0.050028074692818336, 0.039939775597304106, 0.06940197708900087, 0.0419691190472804, 0.023539616267953534, 0.01867930968728615, 0.0353071450808784, 0.02134600956196664, 0.0268951330872369, 0.04976105366949923, 0.06006294657709077, 0.05423107591923326, 0.03420664768782444, 0.024559809571655933, 0.01845121616497636, 0.024330599117092788, 0.05999576736940071, 0.048590712758596055, 0.017481017639511265, 0.04741104305139743, 0.05560183752095327, 0.05557792181207333, 0.024735013939789496, 0.07008847111137584, 0.015366964526037918, 0.010743210095824907, 0.046811120555503294, 0.09061922217370011, 0.05306482424202841, 0.05962059316516388, 0.05128889824845828, 0.03347424812091049, 0.07879119904828258, 0.008389034173887921, 0.01386820378684206, 0.052629190977313556, 0.016923065450100694, 0.0008437699000296561, 0.02297041497513419, 0.04908645627438091, 0.03561099147191271, 0.01297117452850216, 0.03947630808397662, 0.05130271332745906, 0.020322780874266755, 0.07994202518602833, 0.031335382227553055, 0.023082306724973023, 0.017588382288522553, 0.018276089722348843, 0.05202796601224691, 0.03604310695664026, 0.03603325123549439, 0.04854901148064528, 0.005997226726321969, 0.05850029156135861, 0.004230596132401843, 0.038191605926840566, 0.02298096089361934, 0.029769263237540144, 0.033148207803606056, 0.03957961504056584, 0.019950291389250197, 0.040185586040024646, 0.0292812640327611, 0.014819536918366794, 0.04290288554329891, 0.04890923140919767, 0.053571210155496374, 0.020626233927032445, 0.05599973628704902, 0.018227274958917405, 0.022596049711864907, 0.03416733612539247, 0.0264786546540563, 0.01569107062096009, 0.03030627573025413, 0.06981013604672626, 0.02098537403071532, 0.007496992147935089, 0.036762058807653375, 0.04554818558972329, 0.0039739373460179195, 0.09557886151014827, 0.014637977910751943, 0.02229414774774341, 0.02230141151812859, 0.028713021965813823, 0.07887127678259276, 0.03429207259614486, 0.019289917254354805, 0.05441777058877051, 0.03955636726459488, 0.007352182437898591, 0.07656065936316736, 0.024617134913569316, 0.012779340486304136, 0.00686868203956692, 0.07445902330800891, 0.06388459893059917, 0.005450658618428861, 0.06279757522861473, 0.03860020275169518, 0.06023569258104544, 0.013885586740798317, 0.015311996430682484, 0.05155730337719433, 0.033844153076643124, 0.07987797784153372, 0.015247551109496271, 0.04515133325185161, 0.029634787933900952, 0.032286021451000124, 0.01618838377908105, 0.016549266074434854, 0.07187612674897537, 0.022099810812505893, 0.023062062791723292, 0.06855606232420541, 0.030793347250437364, 0.017685846687527373, 0.03160211010253988, 0.06611544289626181, 0.007908784846222261, 0.037079605244798586, 0.010996062592312228, 0.05812537710880861, 0.05604614649200812, 0.07128540688427165, 0.05551270929572638, 0.06050101408618502, 0.019886451846105047, 0.022783575586799998, 0.0563853228231892, 0.040147725376300514, 0.036041748826391995, 0.018302760654478334, 0.060729703182005323, 0.037866875500185415, 0.04153604619204998, 0.04372101429908071, 0.02502068513422273, 0.04100690232007764, 0.06604936948860995, 0.0889214406197425, 0.03443481728027109, 0.017742435447871685, 0.05368324476876296, 0.04355524077254813, 0.02973640464915661, 0.02313351862540003, 0.04481729629333131, 0.012621896639757324, 0.03534715055138804, 0.014191289428708842, 0.08487891769618727, 0.03475223384157289, 0.03265403021941893, 0.06623899564146996, 0.034880907405749895, 0.22093350416980684, 0.12342309200903401, 0.119977597205434, 0.12071455726982094, 0.10759464057628065, 0.17295432480750605, 0.13426209945464507, 0.18396926578134298, 0.18209308676887304, 0.22094401298090816, 0.09493969424511306, 0.13870723749278113, 0.19724418001715094, 0.1256695730262436, 0.1253110563266091, 0.1534172278479673, 0.14773770526517183, 0.1878135313745588, 0.23783766897395253, 0.13590356684289873, 0.0961097345862072, 0.11691694307955913, 0.08293621998745948, 0.09814353834372014, 0.11871266586240381, 0.15340247395215556, 0.1895205007167533, 0.08723728489712812, 0.12132551550166681, 0.1291120843961835, 0.23215882916701958, 0.1528229159885086, 0.1178886741399765, 0.16354830062482506, 0.09546932051307522, 0.14428716385737062, 0.25374848395586014, 0.14437438105233014, 0.04998076277843211, 0.08851401638821699, 0.09827351808780804, 0.11793692858191207, 0.10512469889363274, 0.16268982872134075, 0.24810497037833557, 0.17600894527276978, 0.15101722616236657, 0.1435812923591584, 0.17257462721318007, 0.09947977523552254, 0.14376313338289037, 0.14734071562997997, 0.11964531542616896, 0.12962986598722637, 0.1225417990644928, 0.15954336005961522, 0.11724326541298069, 0.14756577933439985, 0.16991097014397383, 0.13563747721491382, 0.12308965247939341, 0.17251430545002222, 0.1706858613761142, 0.10273286825395189, 0.18282655131770298, 0.1257689911290072, 0.1422062114579603, 0.10430789858219214, 0.17897409241413698, 0.16217103780945763, 0.19215485779568553, 0.10777812916785479, 0.0785226009611506, 0.10972052259603515, 0.13835878431564197, 0.18182726431405172, 0.07058700881316327, 0.15365602128440514, 0.059529787686187774, 0.1305104687344283, 0.1269856680301018, 0.10998949175700545, 0.18133376579498872, 0.18266470375237986, 0.09337696130387485, 0.11611802852712572, 0.10166744847083464, 0.13085964921629056, 0.1117526416783221, 0.15526614035479724, 0.13703249220270663, 0.13781231129541993, 0.1055279745196458, 0.1267258421285078, 0.14924990537110716, 0.09707031858852133, 0.17645825631916523, 0.15308600733987987, 0.1163987533072941, 0.19688058702740818, 0.1341014838544652, 0.11137809458887205, 0.059506803372642025, 0.062498452607542276, 0.13994559994898736, 0.09179150380077772, 0.10643287518178113, 0.18779920792439952, 0.08134294024785049, 0.06253216095501557, 0.18276195478392765, 0.12457149132387713, 0.16299578652251512, 0.07244435211759992, 0.1628840487683192, 0.10547746394877322, 0.1243044740112964, 0.24234539974713698, 0.08926569324103184, 0.3853617247659713, 0.08585384741309099, 0.10910173470620066, 0.1033153577009216, 0.07552544499048963, 0.19410507346037775, 0.20379332156153396, 0.38771964667830616, 0.11248344933846965, 0.1421957471757196, 0.10149822395760566, 0.12036965898005292, 0.2180991679779254, 0.14721333340276033, 0.07105200143996626, 0.14960931264795363, 0.1365698967128992, 0.0808083861193154, 0.17333979631075636, 0.21364610380260274, 0.08032040917896666, 0.27679000224452466, 0.08827373865642585, 0.17370941553963348, 0.14642163994722068, 0.15053601760882884, 0.18017555528786033, 0.18500140024116263, 0.15471297316253185, 0.12417567428201437, 0.131894396035932, 0.18017052352661267, 0.1678738193004392, 0.10348888667067513, 0.08800775292911567, 0.13771939440630376, 0.20087887794943526, 0.23341979744145647, 0.07538186167948879, 0.19738885428523645, 0.15467386197997257, 0.13973674474982545, 0.11839023238280788, 0.18873487802920863, 0.16516085393959656, 0.17250577075174078, 0.17344754131045192, 0.17078517557820305, 0.17460339178796858, 0.11884387015015818, 0.11663511249935254, 0.10611792997224256, 0.17430568666895851, 0.08671554023749195, 0.22495082375826314, 0.11901496487553231, 0.16604571661446244], [0.06885823517222889, 0.00505098287248984, 0.02075524887914071, 0.029409108246909454, 0.041318563526147045, 0.03522134538798127, 0.061465806065825745, 0.035032019804930314, 0.030219741311157122, 0.07752183708362281, 0.0028968521610295284, 0.032511934914509766, 0.009235754168912536, 0.06651435469393618, 0.04852876198128797, 0.05873727786820382, 0.04331784257374238, 0.004266692340024747, 0.01457669970477582, 0.044856997483293526, 0.02437122428091243, 0.0566797216742998, 0.06633419092395343, 0.015496372816414805, 0.005490189114425448, 0.055550284232595004, 0.027356450227671303, 0.04655084565456491, 0.019199050548195373, 0.011189222295797663, 0.025380673141626175, 0.0627108255866915, 0.06377612662618048, 0.017185344149766024, 0.0024648053249620716, 0.01644769945414737, 0.09578250683262013, 0.02342487838177476, 0.010493709323782241, 0.05313985908287577, 0.050300416914978996, 0.021038027553004213, 0.016069144767243415, 0.026352036838943604, 0.058857988187810406, 0.05478832121298183, 0.037228914225124754, 0.05850112276675645, 0.028659073395829182, 0.010244160312140593, 0.048980818974087015, 0.02674668314284645, 0.03847339939966332, 0.03861970268189907, 0.008536659406672698, 0.034995298337889835, 0.03890985644829925, 0.012833285345550394, 0.055646648397669196, 0.05704787516151555, 0.10693006959627382, 0.012474200902943267, 0.009569446956447791, 0.053548938303720206, 0.05046795675298199, 0.013782428213744424, 0.018814499308064114, 0.06666979752480984, 0.017301419757131953, 0.024259434576379135, 0.023040926425892394, 0.048634918784955516, 0.0062829674970998894, 0.026280300844518933, 0.06393525793100707, 0.08841456859954633, 0.06472347071394324, 0.022028648127161432, 0.025636606478656176, 0.04529061581706628, 0.014806275667069713, 0.042927417234750465, 0.03038468919839943, 0.05558480894251261, 0.01961466252396349, 0.01724959372950252, 0.04280609835404903, 0.026386685858597048, 0.02406572846666677, 0.006598461895919172, 0.03633720152720343, 0.009568489585944917, 0.030803323570580687, 0.0027260406113782665, 0.05516231911315117, 0.033022146599250846, 0.016674687176418956, 0.015428675960720284, 0.018822889287548605, 0.008097172540146858, 0.029956143443996552, 0.014550036194123095, 0.0395452536031371, 0.014153354550217045, 0.10153420327696949, 0.05259692239633296, 0.07783520894008689, 0.07360736432019621, 0.00977316278294893, 0.020852722554991487, 0.020486261164478492, 0.00678674754453823, 0.040572927755420096, 0.02867160270398017, 0.029455288386088796, 0.08809769380604848, 0.030928509040677454, 0.07488791787181981, 0.06868852826301008, 0.016184144260478206, 0.05699491550331004, 0.053226159725454636, 0.04657309895264916, 0.04144272483245004, 0.0225557047087932, 0.027530389234016184, 0.023122429083741736, 0.04716404517239425, 0.05514541669981554, 0.06586188814253546, 0.03897351045452524, 0.04256218409864232, 0.03163964422128629, 0.028475805593188852, 0.025814341570367105, 0.02307564594957512, 0.04788389131135773, 0.05461391279823147, 0.015267975013557589, 0.01796995937183965, 0.04402880891575478, 0.05150605065864511, 0.015892689880274702, 0.04134331415116321, 0.07256139622768387, 0.04117078708077315, 0.028840522936661728, 0.02206786877650302, 0.07140691872336902, 0.016944804810918868, 0.04637212536181323, 0.037553989750449546, 0.06133164431957994, 0.046922413021093234, 0.04646984023565892, 0.026825434288184624, 0.024100336668197997, 0.034393464811728336, 0.020748324641317595, 0.014353149053931702, 0.020181240324745886, 0.042114416719414294, 0.018897343397838995, 0.048650181051925756, 0.03771741809032392, 0.05519604972505476, 0.003538321011546941, 0.008797099435469136, 0.021988497937854845, 0.007217208039946854, 0.0379504710144829, 0.05247357003099751, 0.02828271361067891, 0.015337331496994011, 0.06299573607975617, 0.025126333566731773, 0.013913966467953287, 0.016815719354781322, 0.019003813758899923, 0.0195726977835875, 0.026663733297027647, 0.041863696969812736, 0.08949535826104693, 0.043138547116541304, 0.02635008127981564, 0.03944580952520482, 0.004604006344379741, 0.06538957051816396, 0.023501850228058174, 0.025084279768634588, 0.015188487286650343, 0.05772136675659567, 0.012217609837534837, 0.024641080308356322, 0.012513753663370153, 0.06149854219984263, 0.0868812321277801, 0.033284985620412044, 0.02180817275075242, 0.037086362499394454, 0.03236600641685072, 0.03776252211537212, 0.03966421616496518, 0.0508835260552587, 0.010381362080806866, 0.03591339438571595, 0.06022460860549472, 0.030485025708912872, 0.017867142232717015, 0.015307492521969834, 0.04321253923990298, 0.05240763392066583, 0.0238454646023456, 0.028985553435632028, 0.067263649252709, 0.06042308115866035, 0.010649674441083334, 0.029975227771501523, 0.045510940908570774, 0.03472033262369223, 0.08499527903040871, 0.06600113731110469, 0.022045014338800684, 0.05463514935399871, 0.004755115960506373, 0.020565570775943343, 0.10247617421555333, 0.023425711442541797, 0.05273813454550691, 0.028039467288181186, 0.03754739576834254, 0.05572531976213213, 0.08096060060779564, 0.025419448502361774, 0.01178874124889262, 0.058400791822350584, 0.05202260770602152, 0.05953147978289053, 0.02708595224248711, 0.021377369012043346, 0.09069987878319807, 0.04724217105831485, 0.035702424065675586, 0.028664722995017655, 0.031889636666164733, 0.024999519082484767, 0.06892817516927607, 0.040877423525671475, 0.0275149154549581, 0.03621475087129511, 0.032560601248405874, 0.061733409675071016, 0.028417400426405948, 0.030702688345627394, 0.05713424630812369, 0.010384075558249606, 0.03394440980628133, 0.0375433547742432, 0.034610836155479774, 0.014593425858038245, 0.01714393602014752, 0.018566117323643994, 0.02011235788813792, 0.029430038666760083, 0.04292536148568615, 0.035784334904747084, 0.025528265905450098, 0.014461785558523843, 0.05205544402997475, 0.01751419906213414, 0.024353809785679914, 0.014041846861800877, 0.01408496378644486, 0.024480871034029406, 0.074713253416121, 0.02079120593407424, 0.039941898139659315, 0.01564388116094051, 0.029096051803207956, 0.005028584391766344, 0.031572231237078086, 0.06987157845287584, 0.049280691164312884, 0.10774994982057251, 0.03158310741127934, 0.03147279829136096, 0.060249054949963465, 0.01778624442522414, 0.027791243010142352, 0.04468813291168772, 0.019677117961691692, 0.06790451603592373, 0.016096975305117667, 0.03756303653062787, 0.04276054532965645, 0.03240315832954366, 0.07665742799872532, 0.0483528729819227, 0.024950231199909467, 0.027392806186981034, 0.06622562956181355, 0.03015969599800883, 0.030201946465240326, 0.0356902713974705, 0.07888276522862725, 0.0424227122857701, 0.046901102250558324, 0.019881505431840196, 0.039408446100424044, 0.019776916415139567, 0.03740315565664787, 0.03508513531414792, 0.07665782875847071, 0.012908328535559122, 0.01652807775826659, 0.026517359510762617, 0.02947681994555751, 0.02726278005866334, 0.021899720377405174, 0.0321610474929912, 0.022570916880795266, 0.013635316918225726, 0.031237021685228683, 0.02638988080434501, 0.020040180315845646, 0.04412187794514466, 0.03511065035127103, 0.009841691771725891, 0.08703656363650225, 0.05664933814841788, 0.004279440117898048, 0.029796579838148318, 0.001022592643948883, 0.07099234018824063, 0.03630225379311014, 0.015609319343639072, 0.07499518047552556, 0.007219364442789811, 0.01856325448898133, 0.02050528612016933, 0.029825601523043588, 0.04758967428642791, 0.04515483618888538, 0.01756445173668908, 0.02718788993661292, 0.0888160259637516, 0.10932690973277204, 0.03165198984788731, 0.04349455906776711, 0.026075700006913394, 0.036676748932222836, 0.013720380957238376, 0.16071970865596086, 0.13627467036712915, 0.13963930075988173, 0.11230896299821325, 0.17796719097532332, 0.12351930403383449, 0.14925020223017782, 0.1813493508961983, 0.12085728711099364, 0.12784356105839834, 0.08967100235167891, 0.17983535479288548, 0.07749498618068174, 0.13712882297113538, 0.16614448162727058, 0.21066568326205015, 0.14223214209778234, 0.09132624400081113, 0.09979538837797008, 0.16664387279888615, 0.14377509680343792, 0.10908571173786186, 0.11491769371787086, 0.1144400771590881, 0.09262174440664239, 0.1493052250589244, 0.12278636640985496, 0.1483955152798444, 0.12781421653926373, 0.17738957743858919, 0.17016481433529407, 0.12489450367866084, 0.13451646314933896, 0.1327886839862913, 0.12871347687905654, 0.09985737255192362, 0.20855112641584128, 0.17064434563508257, 0.15543901623459533, 0.1602915785042569, 0.19987065548775718, 0.09527138230623677, 0.24640200863359496, 0.09664463010267355, 0.16107552393805236, 0.1580023200949654, 0.2001385114272125, 0.22026707039913163, 0.13301969971507788, 0.07747900031972677, 0.16069348115706816, 0.23389603360556066, 0.07340705866226926, 0.15670572873204947, 0.13820373482303694, 0.15924473467748612, 0.1395846193190664, 0.11455999338068068, 0.14250146748963743, 0.2738006314029917, 0.18570877087768167, 0.0992049950582441, 0.16412493452662602, 0.17398883413989097, 0.24278123339172453, 0.12001394017715938, 0.15463292511412874, 0.1873239513952285, 0.10304379102308303, 0.08853827719576657, 0.1547935258713551, 0.09043728467077017, 0.09157504900940694, 0.08702794730197638, 0.18142206652555615, 0.23516636778367683, 0.11940904529183172, 0.09936652350006625, 0.1435219353879802, 0.07439913199050352, 0.11210142882191576, 0.09984903823351488, 0.11751948535675183, 0.09079932657186873, 0.07486071815947071, 0.14978900144342333, 0.1318633445771411, 0.09230475086951628, 0.08860738598741591, 0.09539872742607258, 0.17359537712763995, 0.0795328346430324, 0.10111612180480734, 0.14864561904687434, 0.1243652930133976, 0.10394348923000507, 0.10564109266852029, 0.14116716018179432, 0.14994688594015315, 0.05350615349016152, 0.11338807540596463, 0.09521286396193318, 0.2391300894669257, 0.10272391053149477, 0.22886247636051849, 0.18577452516183257, 0.14142780244583264, 0.21331025229301304, 0.05399713983933907, 0.10909921140410006, 0.17577736551174894, 0.1951383805135265, 0.14410397212486714, 0.11080641081207432, 0.12704990833299235, 0.1911105224280618, 0.123314248630777, 0.1352995922206901, 0.20770939736394212, 0.1257541184895672, 0.21384302526712418, 0.2708087075734511, 0.09370069354190491, 0.18986591108841822, 0.10785968377604149, 0.12902431801194325, 0.11094521469203755, 0.12758961296640337, 0.20157847087830305, 0.23196408961666748, 0.12689040595432743, 0.15404121077153832, 0.20864971331320703, 0.14327977260109037, 0.10393597127404064, 0.14931539248209447, 0.17006498062983155, 0.15122474549571052, 0.10884943418204784, 0.17107076884713024, 0.15865900204516947, 0.2411659192875959, 0.08621385582955554, 0.14301714138127863, 0.13909992267144844, 0.1454489366733469, 0.08740403805859387, 0.06501264855614863, 0.12661072018090636, 0.14017004024935886, 0.16335403604898602, 0.17737415560986847, 0.21596087724901736, 0.22722148394677788, 0.14103084249654785, 0.162204330554232, 0.09930701809935272, 0.13845076609868556, 0.16446445224573836, 0.17358005919959396, 0.18289810919668525, 0.13116483518388122, 0.1094360277056694, 0.12776008428772911, 0.09014444804051891, 0.16235641145613045, 0.09797226550290361, 0.1260833055130206, 0.09540634186123498, 0.16935496794758365, 0.23534193023806438, 0.17921052582096308, 0.11274616219452582, 0.17790148122003302, 0.230380613647867, 0.14121689891908318], [0.018318267830181867, 0.03242738945118617, 0.12034588798996992, 0.016766437038313597, 0.055481832241639495, 0.027530021870916244, 0.08943283974076621, 0.007934590248623863, 0.041272613452747464, 0.08732899208553135, 0.026314133501728065, 0.03280496079241857, 0.027351923126843758, 0.06954906333703548, 0.04358119367680047, 0.04590493226714898, 0.0383520545437932, 0.00917582203328493, 0.010933297307929024, 0.04224727599648759, 0.06813371350290254, 0.0601343820017064, 0.03749137475097086, 0.05090655860840343, 0.077004085178487, 0.02057691635855008, 0.020273377958801575, 0.07656094137928449, 0.02266082065034425, 0.04597120976541191, 0.015811745688552037, 0.05153578851604834, 0.018229915149277076, 0.06477307586465031, 0.07166338269598782, 0.06783217148040421, 0.03835458897810895, 0.056768471404211596, 0.06934308024938218, 0.03249646113545168, 0.05248624220257625, 0.025371075316797942, 0.05455693069961853, 0.025591574813006446, 0.02725380934862187, 0.025484965299256146, 0.019578451283450704, 0.026445280273037497, 0.05933697771979496, 0.014181929091137135, 0.06462186327553354, 0.016369130134989973, 0.04362541083537508, 0.043917739094467834, 0.010371608404966537, 0.02710348548134789, 0.06466960563557222, 0.031891566250124015, 0.04724087972135749, 0.04481080250116065, 0.07693778170505539, 0.06746699029463343, 0.11477949839900248, 0.02533369519369444, 0.03364181764482055, 0.03904042248905171, 0.019015786456293426, 0.009838787191256415, 0.02851157340046484, 0.030832432457827963, 0.028078161012672354, 0.05746062801335938, 0.0051788563087029615, 0.03713349629833829, 0.003453600911598187, 0.025718439392221626, 0.023157477007771377, 0.03639354166807607, 0.03444547452090774, 0.03702923939272296, 0.07054150031763129, 0.021794615568069275, 0.05735014448873699, 0.07340037933317944, 0.009042532310559181, 0.07553913761512376, 0.0375613036158029, 0.03555168645107187, 0.041028810519492254, 0.02286359951540362, 0.042902436543954536, 0.03489650734991301, 0.032860017017810605, 0.06631663913140073, 0.020315941983426455, 0.010359707139286911, 0.04623715467459988, 0.04404461295052897, 0.013983733915665653, 0.0689211321878247, 0.05706910800654441, 0.05392001956352033, 0.024086388002615422, 0.026581655474728905, 0.03959488843975123, 0.03837504256807733, 0.07904455342213623, 0.03772269847104326, 0.017805575516831595, 0.06134272087365389, 0.006349162895276095, 0.05456838945974596, 0.025411299720872194, 0.043638706411002204, 0.077709296165267, 0.009783397927094484, 0.03609261191741098, 0.04734476926387288, 0.035894803586415946, 0.017636030024732463, 0.03750677431526128, 0.03240233454562258, 0.03824353028903715, 0.08650972042232752, 0.017065537394955754, 0.019562881025194656, 0.033987992428592406, 0.04008212694316171, 0.015745356868137605, 0.012278358335606754, 0.0447797399101546, 0.015449260354216676, 0.0364772819011705, 0.0489360934443539, 0.042720198471215554, 0.011201523393538082, 0.05373489453631919, 0.02480184062733315, 0.038464404569822364, 0.10964350251015276, 0.023271979262062814, 0.02460488205542788, 0.009361538923258195, 0.017419792311557103, 0.037970342018525116, 0.0342281922348775, 0.010889540280913934, 0.039298864285228774, 0.041693429739098065, 0.04304729634895921, 0.01966649040696211, 0.027383330816519447, 0.0479909720888827, 0.11476530111394823, 0.12210150511236861, 0.03157325540087186, 0.050744733307510614, 0.04709874359832611, 0.04519271169556305, 0.021393330753198825, 0.05166492221178487, 0.03177038837748114, 0.036755932378582656, 0.04451826272998005, 0.04323020977608394, 0.03031117947102757, 0.07792477132170461, 0.07899774616817012, 0.013166306489438284, 0.10942442051600665, 0.029862194969609845, 0.04960230457072612, 0.03589397980249487, 0.07987435616087168, 0.010037321899289964, 0.02052068753982894, 0.018146247275581118, 0.0743504248384852, 0.04653434029023629, 0.04649458343919832, 0.10605460993247107, 0.05595368973445147, 0.04403399652801454, 0.02389185996435117, 0.09981272494769655, 0.030707877813256346, 0.027283790259389207, 0.03720266817254014, 0.10339123487938195, 0.06150816043373197, 0.022378027133527212, 0.0349259223730769, 0.042576626292429864, 0.013625579940708121, 0.02197186269768281, 0.02226534314104356, 0.044157126249046996, 0.03268317806941923, 0.04892191100225318, 0.03381868627911899, 0.03282253856013995, 0.019042789499508217, 0.08014610837562941, 0.0365125376265496, 0.0764193396025803, 0.020812978691537865, 0.06074600445572287, 0.040612358061480336, 0.05280280158331152, 0.037246432621032, 0.043497431179275736, 0.03981749192462303, 0.018850820015359204, 0.03470058407401666, 0.01808727622119477, 0.10003053044783883, 0.026588668770273216, 0.04486946556426119, 0.03931516555894632, 0.050017859030049294, 0.0448574687470682, 0.02849010121281026, 0.0743095028155949, 0.040378941484959796, 0.05651853090967052, 0.03543342150805984, 0.057228202203987166, 0.02644504278578097, 0.041031014698091894, 0.029996848388691433, 0.01971988607692765, 0.043641266820486635, 0.018506812302803155, 0.038302000393741764, 0.10366503542172723, 0.04715402617875952, 0.022566966799786314, 0.031355212413473055, 0.05255472016870044, 0.020379746274556965, 0.03852920148347039, 0.059820423848577775, 0.027607943666225765, 0.013264923072711099, 0.015183988944045268, 0.013810586224280996, 0.03495216842566151, 0.05106825403345283, 0.019204768796043936, 0.06774041234166361, 0.02620119532366516, 0.01831542354921112, 0.028220931671967264, 0.047826360023464076, 0.025258103742089588, 0.032456552144140005, 0.05048527105827816, 0.021828631906828377, 0.01326572830294026, 0.06601681147003546, 0.02480916376953246, 0.028554501077451278, 0.04162744909990579, 0.06110859183536377, 0.029907133866799995, 0.07577282507554628, 0.022189436276676133, 0.0482934714818839, 0.03662204522697721, 0.0613013980910182, 0.003967226011809544, 0.01265669130589231, 0.023280200402950868, 0.03365681644936558, 0.05404696763434913, 0.06586468603927642, 0.07562521190266125, 0.040827079938026145, 0.05836776254000142, 0.056728855561232194, 0.04410504603583831, 0.043709603778552264, 0.057439491647528484, 0.060140471323393285, 0.05025452992413193, 0.06570384779479355, 0.014046705146029126, 0.03852586181892548, 0.021635827506543137, 0.01272823248655186, 0.06529234917252325, 0.023532872000942007, 0.04047602924401872, 0.015705857913417276, 0.03632792468124535, 0.022110842837719247, 0.007898897583800135, 0.01379370329232188, 0.01985771032195771, 0.09844424916082062, 0.01901034094771603, 0.0723866575572174, 0.017986264356295578, 0.0280382687196834, 0.01917740395583678, 0.013425968190858839, 0.06838690460426733, 0.03854593320284039, 0.017584929446456954, 0.03310861793579534, 0.07337320930673741, 0.10115177457919344, 0.04784509554156102, 0.0348917947121663, 0.005925874329477665, 0.01883695113065187, 0.04929288836137857, 0.04074364769621752, 0.02492149895260809, 0.04953919975378085, 0.05468967865454033, 0.0173349833858083, 0.05456845996377524, 0.02350471306272084, 0.03573561662051361, 0.0406317095621489, 0.028901677760586608, 0.04309448951971717, 0.0012586940556502668, 0.09578010969562456, 0.025019647982844617, 0.06475524205598049, 0.035073275794275105, 0.038343738779076375, 0.0462872125353897, 0.04559449189400766, 0.07051090156892315, 0.006088818881835323, 0.03988376571214758, 0.029423348205455113, 0.08429791254457086, 0.03582526063837577, 0.014598155194107676, 0.024004178449104074, 0.012654714410018642, 0.07713030223385431, 0.03377748595084995, 0.010980835577356629, 0.014764154147997033, 0.0113841297570616, 0.025536787616147194, 0.057631585441413336, 0.07282653590664268, 0.12269126018509269, 0.15995376772480085, 0.09632996690925211, 0.3219786618137732, 0.12767340143909678, 0.18872289976570755, 0.08620509848697111, 0.20671956532169133, 0.22199229657417163, 0.09078409770154394, 0.11406127014197409, 0.19604776374762878, 0.09018479118822142, 0.1786526682553813, 0.10267133679008111, 0.11643006451777183, 0.11599384495639242, 0.10331395504181273, 0.1053209524252452, 0.1615620611119084, 0.19306853064335883, 0.10454692950588651, 0.12775002076523378, 0.1729480759240687, 0.10967856156639755, 0.15023145504528657, 0.12901412090286613, 0.13045045867329463, 0.09984898628317751, 0.16774069285020232, 0.19498506764648482, 0.21897475380683318, 0.1667772515793331, 0.1813124364707619, 0.1107350162055809, 0.14611583057558164, 0.0861568959953729, 0.13672968110768124, 0.21298139181453735, 0.21214957785559818, 0.1185308322601486, 0.14972099103033543, 0.2417779091047123, 0.11762317823013291, 0.1844808430178091, 0.1608604792272672, 0.14530567248584703, 0.2839713200228289, 0.18179983453592286, 0.15987303690053523, 0.1436505644232966, 0.18752580072032288, 0.15823890193132684, 0.13127179350703955, 0.20565749262459576, 0.10112818912602961, 0.13119131501298398, 0.19941030128393322, 0.12658812920562923, 0.19268083269707859, 0.09646558697568253, 0.2658313309075311, 0.09574252733727917, 0.13339495926629752, 0.13198204367654398, 0.11425292235799134, 0.09198111511068419, 0.11049591848859563, 0.07681417700950988, 0.14615887514082715, 0.13156234432244673, 0.10554491775110364, 0.15446613484527916, 0.15082974481629208, 0.123570801661117, 0.12911757628899068, 0.22956913453526795, 0.13338982360437512, 0.21077615936519578, 0.1973969882237725, 0.04845544150157366, 0.1362272322876379, 0.16945520241279155, 0.10530009807553142, 0.1000665246101562, 0.15382355370093137, 0.24773987825028598, 0.10642827386618592, 0.23119044519262388, 0.1617962383897975, 0.12009425539872609, 0.13985220808535814, 0.1785437951912172, 0.08044672271353193, 0.15927922970149666, 0.10704538450227119, 0.1995311229256913, 0.1351012013037689, 0.15960561140673235, 0.12824999081203714, 0.13617131888167933, 0.15203824324999005, 0.12213248235639185, 0.23439294600393623, 0.19026157970074564, 0.1726600484107621, 0.1337209253688343, 0.161951050395146, 0.23691525362664834, 0.12078254541847855, 0.18656843021744862, 0.14053845719899982, 0.10720079764723778, 0.17796489031752571, 0.1492895805859007, 0.20100827881833538, 0.08115876145893708, 0.17968049825867638, 0.13944019738119096, 0.14503351208986714, 0.10871876424062066, 0.1477726158918813, 0.1687458428204991, 0.0908290124789346, 0.09278342869947664, 0.10720895385020413, 0.156028370547574, 0.10978509686538018, 0.1087035279488191, 0.15987119637429714, 0.1286183187039569, 0.10715554148191586, 0.144924609339796, 0.11614156945142895, 0.13133738451870158, 0.17962344194529578, 0.0833421599236317, 0.09203270921716467, 0.14769540284760296, 0.18793356633977965, 0.09806991729419678, 0.0605094300408382, 0.10280939110089093, 0.1389181855483912, 0.14122616092208773, 0.11301667502266355, 0.19954875635448843, 0.10850472885067575, 0.10295767220668495, 0.1713315595407039, 0.10125849541509524, 0.10051432909676805, 0.25958274432923645, 0.26799798652064055, 0.22507453977596015, 0.1856857939856127, 0.12240877651493065, 0.11614560673478991, 0.09717135457322001, 0.11998190908343531, 0.08224205215810798, 0.1305850694188848, 0.1659141486743465, 0.11718816094798967, 0.20685897034127265, 0.1516053781961091, 0.22107902448624372, 0.11437183668022044, 0.21200984629103914, 0.11201790010090917, 0.14432915457291529, 0.12322739508817904, 0.12179993340396322, 0.09398449081345461, 0.20626997225917876], [0.04753065499244258, 0.017620932885620277, 0.06642759020905942, 0.1771075910073705, 0.024891471657610964, 0.020381421672936995, 0.05376303306547925, 0.032162420466193, 0.03216359677026048, 0.04466377191420179, 0.0450818199897185, 0.02471324860380264, 0.0561820634175092, 0.03353716369019821, 0.023552455422759522, 0.022526081884279847, 0.017155793684651144, 0.04281120804080274, 0.058531947870505974, 0.0164152917204774, 0.07675962915527634, 0.018825123152055312, 0.021601924345304724, 0.021382885024650022, 0.028694368083961308, 0.037734617362730205, 0.03355362452566624, 0.015156324461713666, 0.024313481480930932, 0.017241923633264378, 0.032640842255204916, 0.017091553381760605, 0.008615905935585033, 0.022342177690006793, 0.03733682620804757, 0.05918656665016897, 0.05351362320652697, 0.011555813562154071, 0.019838459011225495, 0.02471732299454743, 0.024572804577474017, 0.04063077816681471, 0.02203402869781712, 0.0005990324984850304, 0.011938535408262396, 0.015111804877960822, 0.059440655750222504, 0.06283670867560431, 0.04388890665723011, 0.06220635441422928, 0.061511284875450656, 0.030712957814102992, 0.048932345598586835, 0.05366013429011218, 0.023627030132047366, 0.035393965226830915, 0.010769668588181958, 0.0055600377345399465, 0.025147690721496474, 0.06037494546035305, 0.0629265456518624, 0.02992275607539341, 0.016470932387164794, 0.08770629996433854, 0.04383361665531993, 0.07824189844541252, 0.028533817421703134, 0.02486491204763297, 0.014732680592715042, 0.00681965761941683, 0.0187387668484007, 0.030336534946400207, 0.05291776767990086, 0.012553153355838731, 0.020326612211647443, 0.06371861018124036, 0.023432385205524042, 0.08610465622041374, 0.04869215321377851, 0.0352227554685669, 0.04869226453593001, 0.05243360537861008, 0.018398985666863155, 0.049033344475901686, 0.04418356897076592, 0.06476591413957067, 0.025459201642661355, 0.030065304090385325, 0.08190242311684415, 0.022095947933848947, 0.03400291701836977, 0.04657544042856898, 0.05919999581237789, 0.03568434534827247, 0.007702830052949139, 0.01922922998346621, 0.036169004888506606, 0.021770586681668647, 0.04652854782762006, 0.025844443080131896, 0.02008182964345906, 0.036371310634422116, 0.011986411354882875, 0.03166138914821204, 0.035609228871180676, 0.015522403646173188, 0.03592571403714828, 0.04445620805199724, 0.02413239002635237, 0.056420192631776445, 0.0762940947606694, 0.04214105611026753, 0.02613798475067597, 0.03348966252815444, 0.04590440163156018, 0.02718728137551807, 0.04771019535837695, 0.06361683204886504, 0.004486358775466215, 0.0093375026153808, 0.0023616734688403085, 0.06966338376514614, 0.02478380087268306, 0.04904381246888079, 0.016794570001366083, 0.026553238640190102, 0.03392099875782151, 0.06077462538087275, 0.029028089629719034, 0.05343795011867769, 0.07055812442558818, 0.0641017068119254, 0.06809958213125356, 0.04388122171803843, 0.08817924099275842, 0.03840076911728829, 0.04989575347281061, 0.005499649178091204, 0.025819289840001147, 0.02491894967533881, 0.054892552143428475, 0.0470035780017497, 0.033099077627412044, 0.02281084394780919, 0.024042964942054823, 0.005476451960930717, 0.02147457551473053, 0.051207469805376604, 0.056490136339562014, 0.02238039087387733, 0.015526456700172275, 0.023623206216143444, 0.039447694580303505, 0.0231311790048494, 0.03341647934576031, 0.02078781802993035, 0.0611122357804561, 0.054812084781588055, 0.043726324365707114, 0.0689617202442605, 0.048209408414550126, 0.02451912318065297, 0.01806349780963501, 0.025370288640260696, 0.08849834965076298, 0.030533161407220177, 0.0006890674774240324, 0.005563376935242559, 0.03182716267474461, 0.027801892829302233, 0.04567799092910718, 0.022333902743412182, 0.05232466181041673, 0.09784051944734529, 0.04041694315674249, 0.03487362693704199, 0.04461077885935083, 0.05488819573656656, 0.027410311595303938, 0.06231699007912539, 0.034791627040249296, 0.014149240269034635, 0.03067429377551889, 0.03809787267528009, 0.048855217901291326, 0.0550694244884653, 0.030828957351332065, 0.04745526020997204, 0.028361386830511037, 0.02781748349661939, 0.04157908333581872, 0.05049801373388618, 0.04721930919913575, 0.014180393773131073, 0.042637163278413936, 0.03137555097055156, 0.01285344393181731, 0.07593749280204065, 0.05009138731111307, 0.017779088266252074, 0.03520894781104289, 0.04407259191793855, 0.015192940172710223, 0.05060238196165301, 0.010471554360265145, 0.025045843940461054, 0.04875218182860408, 0.02154995916498592, 0.018113422083843034, 0.02600602532766061, 0.0630377787456382, 0.03573056630557403, 0.013043571962043643, 0.09444171315408312, 0.029292574363353197, 0.03909512990503572, 0.012653201356442878, 0.06492143118521199, 0.04828285877010785, 0.035987939409096725, 0.03991593410319183, 0.08252732630353421, 0.009042780930030858, 0.021710177716158796, 0.016111194854602218, 0.0328596199688036, 0.020217722449160647, 0.04881477085291408, 0.08241440853453241, 0.01636418000998674, 0.009352818688057596, 0.0765059630793985, 0.05607374696410261, 0.015373729202110553, 0.0805876639788039, 0.059002009365940467, 0.014801003635511734, 0.009577658820489887, 0.021682998412870802, 0.0569983108289307, 0.0470959123049397, 0.08176205330528319, 0.044781383767258376, 0.007288764527402236, 0.027991992101306096, 0.01861653698142618, 0.03889973355398979, 0.033427734015276656, 0.004064872236995143, 0.06380111473845318, 0.030578992736991495, 0.00854359292134177, 0.0075411081888887566, 0.02434948863083264, 0.03875481437717099, 0.07095903260051273, 0.04779932358360384, 0.02841159683157457, 0.0427215825766325, 0.08448347172816284, 0.03097644992521964, 0.011865483957080869, 0.04899182873487007, 0.04529927668045275, 0.015307993471651571, 0.01747344773320947, 0.039143183967098594, 0.08268264296930283, 0.024393215971940663, 0.08319067273987457, 0.027326883064233698, 0.07958545291330665, 0.029800079064443707, 0.02398845233983593, 0.04802806091902312, 0.10578649424132891, 0.03438368330535013, 0.03266160383645911, 0.0362411119567696, 0.03186782865668647, 0.0503734071389772, 0.006531645412906073, 0.030074063288338948, 0.048420571692986414, 0.035608126781880856, 0.04890343152510468, 0.07057283379253931, 0.08739072392927483, 0.01467506952394615, 0.07248353751492687, 0.05784411798231304, 0.0075035531972389435, 0.03999626787845045, 0.05365518416510895, 0.007717191074334551, 0.024087903839244973, 0.01651445378229255, 0.08204966521589085, 0.03606798745749984, 0.02744345591054298, 0.06486825630418025, 0.02872167169698514, 0.05741335691709537, 0.022193143304320984, 0.030236042584874667, 0.039498613332398236, 0.0545351597975241, 0.036701488425023854, 0.07685419361223467, 0.18543790181865916, 0.06518602909636684, 0.033083358939620666, 0.008604087233834434, 0.01721464785077842, 0.020032664215250406, 0.05388901634432841, 0.033446758970967494, 0.030781376408413053, 0.02010934847930912, 0.002198054257860349, 0.04317465631174855, 0.056238659599330276, 0.051158365604351275, 0.0278383953627781, 0.03616038113250397, 0.034025333588942885, 0.010929099535132991, 0.07366419056779705, 0.02486211044015363, 0.044945405825274065, 0.026705866876000073, 0.019764069838856813, 0.03840276549453847, 0.017056772630894557, 0.05939625305472873, 0.013189223082008539, 0.02553616235672962, 0.029436762524710502, 0.0036939769779564813, 0.07586032428662293, 0.046460318480967544, 0.012327006115810946, 0.023500826064264402, 0.05144954353454523, 0.05849119283084292, 0.05408672819612548, 0.060487599766929634, 0.04627573893230874, 0.04972188311512582, 0.10453275448526256, 0.03154615216772072, 0.038152379711391404, 0.11391231368179433, 0.11383256249246188, 0.13956777256680652, 0.3131549118552357, 0.16413093107985333, 0.2074386618915014, 0.12011792990961112, 0.13762750168098137, 0.08103173546260223, 0.1537728650146164, 0.07685538846999407, 0.12955928774317726, 0.16830910375574604, 0.16828572610393167, 0.12175625801319256, 0.13795844017295167, 0.13381249154917896, 0.11711024286341853, 0.08414351614192128, 0.10367717695771717, 0.11637410658295266, 0.17447415419155732, 0.11130139362649061, 0.12723121501039714, 0.08958489837823436, 0.10613668404403143, 0.08869053621310741, 0.11958693066844717, 0.09292953531257808, 0.08009872966795228, 0.1251808539382182, 0.22244371531996876, 0.14440941042266786, 0.12018965106108226, 0.09255733340978622, 0.15491261088754982, 0.12996930949157104, 0.1358747566700913, 0.15245400922140107, 0.13080618489766493, 0.09165432522422634, 0.13444500917103142, 0.09553783558658324, 0.09231028729118407, 0.07800312727340497, 0.1401497350889258, 0.13133358472259715, 0.15154781722230837, 0.12037416381645016, 0.13338543009012938, 0.11884848630870692, 0.1530268433270976, 0.19661624886794016, 0.12324391529546119, 0.10189093882218003, 0.13123195501975715, 0.16974021680653095, 0.15691164502641186, 0.13533322635339573, 0.14019522874150425, 0.16748181689763442, 0.07157295942306519, 0.08081791529548354, 0.25464508740697056, 0.1994468001066707, 0.2184108254732564, 0.12349875396466814, 0.12424497603205964, 0.125523280876223, 0.09368787665152922, 0.16657559521263465, 0.07247316229040734, 0.25115245138294995, 0.07942799886222929, 0.121381822245894, 0.15399634052300826, 0.11634463589871302, 0.10877431399421766, 0.20082726900000125, 0.1499113964382559, 0.14660667220596224, 0.10299640489392914, 0.10437716322485358, 0.1688371566706337, 0.15843518514884636, 0.10056872852146626, 0.14091635879594833, 0.14627732191001996, 0.13847923488356173, 0.1019765084492974, 0.08469991167658009, 0.14204917300958186, 0.15740834962343797, 0.11647267121588811, 0.11504198861075565, 0.16723322711186484, 0.12738261313643306, 0.13109170395182446, 0.1350927705061622, 0.2532388363033533, 0.1337828946998343, 0.12086643779184669, 0.15804586932063103, 0.14458831254160032, 0.10458028904395178, 0.07670114791835658, 0.0812077580485493, 0.13503989990567788, 0.08630292839370668, 0.0691739670583047, 0.14646174560766667, 0.15198488283203915, 0.08635563572170213, 0.16574387031141669, 0.11436687171226367, 0.17109313717810437, 0.1517686209990643, 0.20830814726650715, 0.10092791315400973, 0.14262841927120462, 0.14971907628932968, 0.15514491795329377, 0.24091109546134248, 0.13067460211459547, 0.11432290688389912, 0.17099628690630198, 0.17669670836767182, 0.08673220887430944, 0.1463945663999766, 0.17892183037474751, 0.18009930703556165, 0.19758963491767645, 0.1254617123049684, 0.2460542382323183, 0.16153581877006218, 0.11762960522901267, 0.09677007532445714, 0.10116180099430494, 0.11438846820965409, 0.13397490314673632, 0.23043793713441119, 0.23130806075641885, 0.07420115667628124, 0.12450625654309988, 0.08113467134535313, 0.17869059200165793, 0.17074127012165263, 0.16415418998803943, 0.17225406394572929, 0.1180571861914359, 0.20939187583280727, 0.1530076068593189, 0.1279032594175078, 0.15869809838477522, 0.15701912285294384, 0.0876134424470365, 0.12326670665061101, 0.09551694412948564, 0.13238666258985177, 0.1777686516288668, 0.1146621500083711, 0.11813729361165315, 0.1413488230900839, 0.18829214241122827, 0.3193432657280937, 0.07339114701608196, 0.10862381386687048, 0.13461127993650734, 0.07577971220598556, 0.11119234244688414, 0.23437085968907923, 0.10091458418173715, 0.13834316952852532, 0.14416233461815864, 0.12243699296959676, 0.10343842805013992], [0.029011853293923195, 0.04954375282977708, 0.00410674652812304, 0.014580591341655236, 0.02883709235902643, 0.03864490230625961, 0.01563499023177428, 0.04416069969011005, 0.04465022029762622, 0.02003959958528867, 0.01973168251424795, 0.06202417571330443, 0.05338817056326661, 0.04003258116426878, 0.01424514801328769, 0.007226271054605604, 0.04105122709006537, 0.045700359260081314, 0.08136401724186726, 0.0808119484281633, 0.03689466946525499, 0.025312456782558, 0.004788433288922533, 0.02753349512204295, 0.0391108040639665, 0.013097867486067116, 0.024009317821764853, 0.020388848715811037, 0.08817743757390417, 0.026656452828319743, 0.0049434071752330055, 0.06514499575132504, 0.06272066646488383, 0.06087123816541862, 0.05433829399407841, 0.018565065329312347, 0.03234269184758887, 0.041280417135567404, 0.026274081646988634, 0.043302984777255915, 0.016119842730404343, 0.0322830825462006, 0.03323665325297043, 0.04323320434195921, 0.0302775768795982, 0.027724941392079927, 0.05438421809230931, 0.03620763738581445, 0.059009490214521065, 0.07826404413208365, 0.01589578649145551, 0.044266696932027116, 0.04909441951895133, 0.07594869923195802, 0.05086153993033804, 0.03845164705126081, 0.015467996799998218, 0.10663324763299897, 0.02904112174292095, 0.0795726731303148, 0.058764481291291304, 0.08106985958875157, 0.02876145637856098, 0.052554564317688346, 0.03864305806928314, 0.03576649738533888, 0.0756307557458058, 0.018670429890335072, 0.044844581352663226, 0.017547632814967074, 0.04429673535923939, 0.09077326976694167, 0.04720534569059964, 0.03304139419924468, 0.0228023649106035, 0.014039233574294485, 0.11434782820288092, 0.03407526157388929, 0.02477495447237743, 0.034657175856409594, 0.007741457447991706, 0.007395369402729557, 0.03209521899407264, 0.030534673533111345, 0.020643895186367445, 0.002926503743765352, 0.037515602161874995, 0.029878663226554636, 0.11210565906367265, 0.06629925803281367, 0.031721644118078984, 0.06320471744402312, 0.023691452261118684, 0.04327267917688005, 0.05379249632824212, 0.039753225646563806, 0.017725314100971445, 0.009334064616268734, 0.024684920826985035, 0.03911232917744201, 0.012342082845862024, 0.031325181407737546, 0.05485418681928422, 0.008179612159437966, 0.11767489850171842, 0.06993992283241823, 0.006538538573295227, 0.07624123900313862, 0.014040798578207614, 0.042573357131914236, 0.02579218660685001, 0.051934930379502475, 0.05126224030391313, 0.07139613531762734, 0.083924471255159, 0.010125329481525114, 0.04829742341826204, 0.01272585112019442, 0.03639586087956559, 0.016836377035360783, 0.016397558101743925, 0.10749579392722808, 0.050104823894798756, 0.03805336978984997, 0.08452915833913721, 0.04079992475453764, 0.024761059612501413, 0.04730560613097623, 0.02117045638442505, 0.036311014846432954, 0.016127980379678775, 0.018443124899931718, 0.09607132844394073, 0.038585600996157154, 0.028742663344019093, 0.007788631137373159, 0.022810689952166285, 0.037860815864405595, 0.014785205166845117, 0.01974847175006289, 0.041206810928997584, 0.07244693479151465, 0.07664025470148772, 0.03883340410538949, 0.028198604159115348, 0.020099863832001574, 0.053731298830825835, 0.10871198843233287, 0.043746202791226096, 0.05784900873550214, 0.0404514010733692, 0.017723510682117194, 0.053110826265765354, 0.09439222674700432, 0.09958669645129703, 0.07852483482565731, 0.06737503077602014, 0.022362707350112032, 0.029112434713169932, 0.014722834148415131, 0.04251525067957118, 0.10842606861842796, 0.04255004627339076, 0.014790680361329578, 0.015457723620784236, 0.02238331493572332, 0.03252629918279126, 0.024819509308144916, 0.02432847657473758, 0.014034621126484126, 0.017813952508731745, 0.014447450976149412, 0.029972979064041283, 0.036132843742961995, 0.04206087447528262, 0.009336015536973719, 0.040219932634499855, 0.016019090617191978, 0.06216985188075341, 0.06927317735971883, 0.010994391832355177, 0.03587889194022864, 0.018014848174061626, 0.03010386608366389, 0.03809574271144811, 0.06225879827979952, 0.05383531082770787, 0.019712535104190465, 0.02438511171931168, 0.02031760068348376, 0.048100973217515275, 0.07295615199836902, 0.055005176764097996, 0.04395407464471646, 0.042304054004489444, 0.1122175007185433, 0.032706963902455755, 0.026986827288055792, 0.012450213762349449, 0.04223920142976567, 0.03000390250235796, 0.0058289122716814745, 0.05788657996163238, 0.03390538397070486, 0.033996315614786, 0.03292009016149677, 0.0954129321326036, 0.04385155436466448, 0.02788694666378433, 0.04637778423784766, 0.07040263706585392, 0.03153607380227186, 0.05348188155039679, 0.008746631538087968, 0.037055734064779244, 0.04541045411315281, 0.018854311820177827, 0.03174691795720719, 0.07756018385407515, 0.10321320107323118, 0.028782841363863554, 0.02545586568885483, 0.04431292902154382, 0.02545043873396935, 0.020536541669571307, 0.05100280402984936, 0.02870165597414598, 0.06566281444975175, 0.02637362962559564, 0.03309710351459216, 0.027469969136291184, 0.06274310158914886, 0.01861703236500034, 0.060120963971712627, 0.029955215759400744, 0.03188916169165168, 0.041311505701742135, 0.06355351200909354, 0.013800133074255427, 0.0707434090145398, 0.06186807237099856, 0.01573920075315982, 0.06464668811531737, 0.043823501182487234, 0.02694873470318271, 0.02138157513400074, 0.06349302697344683, 0.07759343206998892, 0.0839357370568905, 0.037490710528800264, 0.062057702234596945, 0.04126170388190076, 0.04542208356724586, 0.06028042553225532, 0.02951539121568203, 0.04124333572690375, 0.02862330187781481, 0.0456030488567194, 0.042114301686524414, 0.04361516177596059, 0.0426751946361037, 0.021188375540077686, 0.11307777604088187, 0.03780690625717398, 0.08616436942247674, 0.03938466026738752, 0.01310669718805002, 0.034460046590538695, 0.027890499695786275, 0.037422648165374994, 0.04659354883187916, 0.061098832593415864, 0.030543488392140716, 0.012775857030646876, 0.02505682030459866, 0.0231414707377553, 0.08346294445800595, 0.05595565642579459, 0.045992142040631734, 0.03469261711870786, 0.03297663810371887, 0.03378076624358073, 0.039085875323507935, 0.029477539828803856, 0.06295956380199641, 0.030226045855670236, 0.022443694215326104, 0.026463114081707317, 0.004215610779283452, 0.01989238902751822, 0.008836731976771262, 0.025194470144924708, 0.050726569243124686, 0.05487305221322458, 0.016410490025009494, 0.049012341696652584, 0.027047397670685314, 0.013206024377723224, 0.018519593941164203, 0.056592582404846326, 0.07244107182486914, 0.027297189735691063, 0.0075269229637342505, 0.06771854124963284, 0.008148209108185256, 0.015133757606236031, 0.056867232706281357, 0.02352191604586551, 0.051764778181677684, 0.01699230411759345, 0.04904845460259821, 0.013081338929623598, 0.00977916490228381, 0.05824999854667112, 0.04405115498229861, 0.025602278437872883, 0.01260401273611933, 0.056643820280442014, 0.06085731918574311, 0.06175657210405916, 0.019283171131974086, 0.03425245675316546, 0.04788515296240803, 0.05232005307334475, 0.011351526281941915, 0.03825171988864895, 0.02315228382940404, 0.04680922065745108, 0.01041817538862233, 0.06540649890666828, 0.04577347564918455, 0.03909813931386452, 0.05348053826310206, 0.03154772181005683, 0.04009243166365195, 0.026838113881240133, 0.02729472951614298, 0.06621004446060397, 0.030569482114515267, 0.04903901819488965, 0.051779984787572175, 0.06987114058574662, 0.04742168173834216, 0.02147340477677062, 0.04575695173116401, 0.03127778785710689, 0.0322944374056533, 0.04197349771857262, 0.06977518831263296, 0.11344763275701553, 0.06237591660465114, 0.040468036313541234, 0.1704324031015858, 0.11865994369145483, 0.13183316885260865, 0.192313039151486, 0.06501340554677881, 0.098210405849386, 0.11761594971176237, 0.06965398817555979, 0.20084145886357874, 0.1211722323205322, 0.11262093961704522, 0.2284281121683307, 0.10369404597440735, 0.10951588279567659, 0.10023737442679703, 0.20434951671632007, 0.1279938459629193, 0.09774197707884014, 0.13753663311945274, 0.1896053578821011, 0.15696255635702983, 0.12123947832151316, 0.05420357563707512, 0.1309210990439169, 0.10070966978673823, 0.10905944713158533, 0.1302579158800654, 0.1573340903269127, 0.1842152135213837, 0.12323661256232299, 0.14425654284423217, 0.09638883406296372, 0.17982768098590896, 0.2176305462489836, 0.11389512554160319, 0.13941679004346952, 0.11546424837433733, 0.12329548713751137, 0.09982782765291631, 0.14967331546358764, 0.10608562428387813, 0.09645466256188229, 0.12517687602667138, 0.2532149094622582, 0.1377555963699706, 0.18364524410571903, 0.10140904749277979, 0.18220584868686274, 0.13077545998385176, 0.19151290005538613, 0.14292269566794857, 0.15041926293633878, 0.13799971842672676, 0.11312928851111792, 0.15671031520469114, 0.17946380598004907, 0.09340149670606479, 0.1904395763995126, 0.1789708121214062, 0.15226073912344873, 0.19683004677062854, 0.20447900664294139, 0.10186238097958267, 0.1581668690778315, 0.13499531167326495, 0.10709268157370389, 0.14371710538398474, 0.13028050685534254, 0.11840242586913519, 0.13646926148794591, 0.1293006047490053, 0.1482138375286013, 0.15176878427155316, 0.11438892834121361, 0.0876754117780365, 0.11515207137563266, 0.21034281933680177, 0.1375701930373907, 0.12488494481658563, 0.15156565845245495, 0.1563404139596969, 0.1085062873607967, 0.12270913110114634, 0.11771934572607279, 0.11271577124716714, 0.07741593261016533, 0.20365004253108054, 0.16205374879064038, 0.30146955919917673, 0.1992359707946889, 0.14157828030874953, 0.10534371409448795, 0.15019241807749495, 0.30257126258220524, 0.1749420040869154, 0.23421039251843467, 0.0790296436753124, 0.13778835476841778, 0.1319544209400192, 0.16613321582553908, 0.1486661468516104, 0.1373258780222386, 0.15565563429845497, 0.03962043687351979, 0.3646528359968215, 0.14051525766262785, 0.1190280712035019, 0.19461690302705392, 0.1580445928266272, 0.12507766572525725, 0.158594791428186, 0.13064178434433416, 0.13956471491837874, 0.11763375383452512, 0.1509444956900552, 0.07360724557656795, 0.11426824770751409, 0.10397735342849046, 0.07495119338273071, 0.10897093117819168, 0.16787806438514963, 0.12111950272810645, 0.16225828469032422, 0.19225789757911116, 0.14409332972718403, 0.2025587292155251, 0.10985260261804797, 0.22523169696796685, 0.12082240617019124, 0.09633911759010516, 0.08934012323152274, 0.1812080162926577, 0.18317632551770657, 0.10592845224891789, 0.10120977342012338, 0.10674087388906628, 0.15595011849654838, 0.11154758627526462, 0.11033390022930689, 0.11079513758886606, 0.10900436493102461, 0.13587684952653944, 0.11611638095928356, 0.16357011976651847, 0.09066364713362418, 0.13937564537627622, 0.2242981197196059, 0.20424900023499504, 0.12222555509652011, 0.1369144461932592, 0.1359685938223265, 0.16495189483975992, 0.15901786013273522, 0.18319994065677747, 0.13529907271731645, 0.12840720737585798, 0.13142837182385847, 0.14802328369114548, 0.13971687003504485, 0.11263010514085181, 0.06924032248207368, 0.23247839795658365, 0.1959714264376089, 0.16223756392719224, 0.1540271396515891, 0.1634320357698016, 0.13938989461166784, 0.09080168660148047, 0.11036547861294821, 0.12077480481821112, 0.09587807318894193, 0.0894443727156613, 0.1139914192026481, 0.21291643904987723, 0.16640730580547825, 0.11263610169407912], [0.017774822772480547, 0.06700839498080313, 0.030707276673638262, 0.06309446398518048, 0.02140130141924601, 0.029163767212594394, 0.007410921571135987, 0.028739915542246308, 0.03599991396185942, 0.051330031783436425, 0.03724529342434835, 0.06951732910238206, 0.027745569386752322, 0.034640251178643666, 0.06792220141505823, 0.048054117723950185, 0.04317150960559957, 0.04213163825625088, 0.03325444624351803, 0.0175543993464089, 0.05158164211024996, 0.0738199673651252, 0.03379277419298887, 0.0037146256136111333, 0.026255971388309263, 0.054189330112421885, 0.03669695390271954, 0.02707848252612166, 0.05034067100496031, 0.05679967500327621, 0.03364453019457869, 0.02248026168672368, 0.017096048941311892, 0.018287361090187915, 0.0009999581834563287, 0.039100862995837815, 0.05764870307757519, 0.025402347564522643, 0.05310005770297721, 0.03352463252667803, 0.014282722950156312, 0.025045213114935905, 0.04261602691258304, 0.0625136295275297, 0.03780361854296643, 0.01881029318610672, 0.08002437389222905, 0.05257812750642188, 0.01732518332573818, 0.11747147582354955, 0.07596822513733059, 0.01025598829073715, 0.03777818885282613, 0.08964660053607076, 0.09863411280093715, 0.05011382985685486, 0.02035153353062924, 0.04614106139342766, 0.02374993906414602, 0.031248220693669282, 0.040824727329891175, 0.07041228498565033, 0.027322636124154087, 0.05961573580862023, 0.040776792011456564, 0.03238094584958162, 0.029909506883996073, 0.024299228534800932, 0.011180373112438247, 0.0376772753224941, 0.02997497173055308, 0.04835786763578653, 0.010994577369274339, 0.05448701667774003, 0.03190167059074156, 0.02673887760465732, 0.05378084089898039, 0.04171622851572465, 0.018353380692133214, 0.021176597656449303, 0.04848171352932695, 0.024711534242669586, 0.04504979260673281, 0.058502651590970345, 0.018665949173737317, 0.014139862305455608, 0.014679285850434098, 0.04321273219829891, 0.01955982152139768, 0.01839003907662118, 0.018570768734207377, 0.019313836673973128, 0.018961492787639145, 0.03059422717342386, 0.09136847220361233, 0.027821426156151574, 0.02457038888678653, 0.07502942316932604, 0.02757761765678879, 0.027035341481678188, 0.01291636042878963, 0.030549969196727034, 0.059018852407461964, 0.021932658746663947, 0.016140763873409014, 0.07691448568948545, 0.0938226432481315, 0.05127800352056511, 0.05575679424509872, 0.03792611743847374, 0.019056543351325672, 0.02841753030224936, 0.05225629516644403, 0.0348361559008481, 0.011131063893117243, 0.04491144514759071, 0.03713774509378709, 0.05795738827146124, 0.025181191267620306, 0.04546244155790191, 0.02377128323132638, 0.05320250005752314, 0.01713071651465725, 0.03426822368055582, 0.05199044302571565, 0.010997103454428725, 0.041363374402862974, 0.03851494111586362, 0.03526809698087163, 0.0384927026607329, 0.036386398496688344, 0.056492537187295966, 0.088591429812368, 0.028767625481123105, 0.014876173918310087, 0.05145272734807804, 0.02201286635681754, 0.021027793336543255, 0.04566448013065383, 0.04884415247943252, 0.058718809523270465, 0.03968747507315129, 0.1123761644703336, 0.017958248281502165, 0.022270675472100265, 0.018586652549856808, 0.01897057481983211, 0.045403585536405444, 0.03832676215097308, 0.022504273874801584, 0.017243663969566114, 0.029430235335894395, 0.005076855995866936, 0.036371102833072655, 0.036144502882962115, 0.013388727220444707, 0.05657671528751962, 0.022900465701241046, 0.10387092203018256, 0.024925816396716982, 0.01833560996601591, 0.07397659763228148, 0.00265959984062647, 0.03500961065583397, 0.04965427717252169, 0.03219124919269234, 0.09422697272384539, 0.03946909440855961, 0.04292534664273262, 0.017653943614277523, 0.033237959432881325, 0.01549995275127003, 0.06351330244797282, 0.018841365053958725, 0.04234490552335046, 0.046841337098157965, 0.023731311157462187, 0.01918168243719265, 0.043839256977662444, 0.0483770187565824, 0.024798872036626562, 0.03678551809571218, 0.04423466954904143, 0.05029887324781157, 0.06743280697264709, 0.04524565280007664, 0.030745985241082963, 0.05256787844700739, 0.020537768068606965, 0.014305518943729112, 0.06436551062506624, 0.015859836857998744, 0.03017484694282757, 0.021006371243856847, 0.05878868272702675, 0.03769303111766931, 0.07384238764643669, 0.038883224478922784, 0.024758985309745185, 0.03916422385373153, 0.0430778394365916, 0.008156592593877576, 0.05431749530544039, 0.02326262263522949, 0.028026921281707473, 0.0720656118937768, 0.034434305198374204, 0.0426007869100431, 0.09043753700098023, 0.024555074669478927, 0.020014093825011514, 0.07858656666940078, 0.009347685809188988, 0.08229968734667636, 0.07001869438681751, 0.024388963465753477, 0.023344795081357006, 0.02003935838729376, 0.05421962086984422, 0.0578090032649925, 0.06624957866733894, 0.052697724604513496, 0.04883716144831851, 0.02677080665307585, 0.04614903205947485, 0.04830229561775923, 0.030704948185302783, 0.043173376107006334, 0.03917413894669153, 0.05875743830983993, 0.03625931312853936, 0.05038901450461708, 0.058279079603380524, 0.10473251095390879, 0.02771193154330831, 0.019204525742679834, 0.029386546957539394, 0.07404279720503837, 0.04867259762249887, 0.042503951481194235, 0.025142215527012013, 0.07354771791142412, 0.016515284987690393, 0.039626325815333985, 0.032340680627385154, 0.034577246551634744, 0.020838959426328074, 0.02660690704942681, 0.05741599896282423, 0.04490973078645766, 0.01709262578515336, 0.03651135390100535, 0.028269679642107803, 0.05331793741788715, 0.0003784909955584226, 0.029227829400042538, 0.04265845178451855, 0.008520941646565916, 0.010822440854099113, 0.04319509876950178, 0.015708494393038563, 0.030873716277710628, 0.017510352881799918, 0.014643036574852886, 0.026932461260003038, 0.07137413806049153, 0.011914964798052097, 0.04286631621653214, 0.07328013656660914, 0.05337722759577446, 0.04214157561364118, 0.08833060943288729, 0.01845980281359516, 0.018746976857073605, 0.056733560777502134, 0.020553032190946396, 0.05318385359714739, 0.027326166891725734, 0.03977736771048512, 0.027975110097031575, 0.031013805928523652, 0.05585197839536704, 0.10085604357300326, 0.0283619044785155, 0.025869366254482884, 0.021739611293014605, 0.03227221008273773, 0.054662452967022546, 0.0851372147735674, 0.045387336213025264, 0.012013862469757441, 0.004053763677802635, 0.0192910694386228, 0.04309294214181136, 0.04807398501725402, 0.007249626441989676, 0.021170951767999213, 0.023585499548062216, 0.03099756402662024, 0.01415434067894239, 0.02677594788110582, 0.013417332374956459, 0.011884788145835046, 0.059567577845882624, 0.0016943636160249298, 0.035021670555579476, 0.04842761467443779, 0.02742892836977262, 0.02793930147163337, 0.023676371820329223, 0.00816800960819819, 0.03565873754268978, 0.05520052116480656, 0.014413157259696163, 0.058076784989680164, 0.023965874352143146, 0.019031577503483277, 0.04091323586180806, 0.030236996244639158, 0.05170828590053134, 0.014772496815567138, 0.0342982398433378, 0.05656537898175884, 0.04359391408797819, 0.07268366505741142, 0.030218609535950236, 0.02370054728089599, 0.03128194759483449, 0.006925052330188919, 0.035356497901375405, 0.015615050579071976, 0.01223584162289626, 0.020706690156657714, 0.006145820925667067, 0.0340780483384151, 0.045506970418500714, 0.02260476252558874, 0.05153490536031313, 0.08269989790278487, 0.06558708570082672, 0.00919247861020267, 0.028605091429199092, 0.04102865837921854, 0.057572770238039084, 0.04141764024097938, 0.06788713493733667, 0.018671910474949982, 0.07365027529885992, 0.03854164358926937, 0.04210411570966244, 0.021735273439844605, 0.019994410213257652, 0.1442271686391905, 0.11780520479078405, 0.11055862254579552, 0.1133616104198154, 0.1346584953716956, 0.14982714783400297, 0.09759895780007355, 0.11939487769268453, 0.12591837061336264, 0.14570514089427888, 0.14535820169840008, 0.20919630507705733, 0.175388227798976, 0.1631010082201101, 0.19510698766680434, 0.19694277900271118, 0.12837415211834013, 0.2219599240925163, 0.11281367536867037, 0.13227767078205943, 0.2619190252153203, 0.12655691447434947, 0.10289539117366076, 0.14948933705454692, 0.16073308215709403, 0.10661869411705993, 0.165087589120958, 0.0754388734640088, 0.09500215339357965, 0.17385987855959684, 0.11667336279060692, 0.11185680210473947, 0.1728211241425015, 0.12895535764982924, 0.10315876454114914, 0.12703224521828815, 0.10465762083185837, 0.14973004523199052, 0.13967931736260653, 0.11140161324874498, 0.09549562222673558, 0.121883773826994, 0.15779416251461953, 0.1513642692589201, 0.25568845798261464, 0.22333936882205307, 0.15495605621254072, 0.10125118526048027, 0.14576899528037757, 0.21798665839014575, 0.13428157340968028, 0.1358825937495567, 0.13109856139635667, 0.18757360987365246, 0.19150954554788768, 0.1648036137339659, 0.18629294499987736, 0.2042649415670894, 0.13235261285444722, 0.11825155466794968, 0.07701627124333754, 0.22389339690562338, 0.12763950013322756, 0.19060072634601966, 0.10495862108655274, 0.15918098419206217, 0.11047519030398689, 0.10666104848496616, 0.17667687818175182, 0.09619855482014827, 0.1887903906754218, 0.13703271484700963, 0.09094434964936227, 0.11901544727152213, 0.056998422151082195, 0.08094910474028438, 0.16867750586243346, 0.10297132030245848, 0.10607692631310783, 0.2252559206681326, 0.14927739452105016, 0.10984333319356665, 0.22022119082976133, 0.17655909934546798, 0.13106749509461224, 0.12676220736466348, 0.06842805669293739, 0.12878015142632648, 0.15077960531925783, 0.07103657961124554, 0.07909406209364533, 0.16687052469933406, 0.14063740032725036, 0.20395386294694617, 0.1253739756066352, 0.22138280037324876, 0.0588253225578228, 0.17591797281056643, 0.16315463581122458, 0.05735852333600633, 0.09887690641335212, 0.13536956190364435, 0.16603419848252088, 0.13987362646730617, 0.1348572870483622, 0.24128712684614584, 0.24281608464661986, 0.19324452354339883, 0.24518586607882753, 0.12351637255051173, 0.12431128692696802, 0.12539293005829677, 0.1874811531160958, 0.1678129335050471, 0.09555419252137654, 0.13428718404611573, 0.08962473686551675, 0.19559750275220722, 0.09045497747138143, 0.12994560529477894, 0.1174324240128044, 0.19450473482720554, 0.11483264359412715, 0.09349079933599569, 0.14372102392371744, 0.13584426924353465, 0.1641863991972059, 0.17296195408562198, 0.10009934980189428, 0.13500905624823645, 0.10468414518982172, 0.12560577801195905, 0.1631279630237259, 0.15300487575586885, 0.15238963533192873, 0.08898941392544657, 0.12137994461227208, 0.09995990767492913, 0.12646655057324097, 0.1500872557517141, 0.11268920236034319, 0.12546787213068455, 0.22976446780376136, 0.08311344485264271, 0.15415970206959173, 0.0647385288903024, 0.11778506290283985, 0.12268704478628933, 0.17377969692461193, 0.15646478306734934, 0.09453517923248, 0.11191247802344151, 0.08662001841003075, 0.15202865470200777, 0.09980592687497847, 0.14232204586733133, 0.1677925541298464, 0.1371136386296712, 0.18955627223476768, 0.13462990784319118, 0.07072760869050398, 0.1509256599820219, 0.1351632151636295, 0.13810548931360245, 0.12202702317154035, 0.20261936268070713, 0.12227602856000885, 0.2279850945342332, 0.09786493610590696, 0.12609679775778204, 0.12178660443169065, 0.11799855652498081, 0.17182856099680066, 0.11228628296521492, 0.14560034964233637, 0.15058618679177016], [0.006109151872806251, 0.026502553664613515, 0.031866926947259344, 0.050420796978869475, 0.015917941454972606, 0.02811434998875484, 0.03905108715116512, 0.015254171994456556, 0.06612031138502061, 0.04601125976478215, 0.040243206385639496, 0.03381942842679564, 0.07259937934577465, 0.07038091440335847, 0.06758566712960601, 0.017314707911282312, 0.037349375925259665, 0.086865980993025, 0.03945224394556135, 0.05426288065791596, 0.06432526395656168, 0.06872803278383799, 0.06254768668441102, 0.055187904654303566, 0.0191243051449419, 0.012436617616913281, 0.05111790742375888, 0.022399167210096493, 0.015012674357421929, 0.03110454275883967, 0.01605273031600518, 0.020618534144887235, 0.04244181516696699, 0.007136102894946816, 0.03249372632126324, 0.047279515929403715, 0.009807723672565771, 0.017679388147371355, 0.035637823821161874, 0.025767196639208123, 0.025877880543703213, 0.025214237248292193, 0.055127334271674044, 0.04219984904921148, 0.0075296146405889886, 0.04176435679255519, 0.026593472321110312, 0.006521995173898176, 0.017926436121342704, 0.03417948879359756, 0.04522810842900071, 0.04573165191686712, 0.055279849329963326, 0.018521189558668993, 0.003564169319361099, 0.019649554596981034, 0.04311071286792867, 0.044613402351387776, 0.027102093954454176, 0.0722179896547459, 0.005208288494031876, 0.04347299225628376, 0.02515391734050354, 0.05573137939791195, 0.036881763517158106, 0.08956092700827867, 0.08125561173073947, 0.029045133051113226, 0.03166016460454557, 0.03751189884496853, 0.04423381978995167, 0.016924716728681233, 0.03542677928635385, 0.0491933552257251, 0.09208558723912574, 0.03133992046059575, 0.0392810638732044, 0.04990722707589157, 0.03980101253546309, 0.021755470988864545, 0.044716623960994184, 0.0370845813449705, 0.06702800252242014, 0.023586440220242366, 0.04608501069014892, 0.04611182077496778, 0.03201020968845114, 0.05001779594749678, 0.06089068243454676, 0.08285531846922822, 0.014798879237787332, 0.057971221904153936, 0.043515034922165796, 0.010889465138461674, 0.03336820263939444, 0.05417820160801057, 0.02211657221778296, 0.006520578599520377, 0.02753640990704298, 0.07228182177641429, 0.01880207761132624, 0.059731418077717535, 0.07798061051289551, 0.11635273272986524, 0.06233740656170994, 0.05404897514381446, 0.05095300963148475, 0.0702463259221986, 0.008814337670628447, 0.11492816542158835, 0.006470583821283071, 0.051992402295581996, 0.03053649365028832, 0.030676134301756974, 0.01912613082822645, 0.08441599566140212, 0.011789495456469012, 0.035025351608055644, 0.01931476992467651, 0.02025090387178352, 0.02304921807080973, 0.024974176594696473, 0.026398643713037018, 0.06490415398729965, 0.03731857308594044, 0.029123331296432298, 0.012686188892985228, 0.06401756952982396, 0.027521166193764657, 0.06445516206440516, 0.06937494807061739, 0.028959021656191908, 0.05744428592151962, 0.01878673556348076, 0.11455470186774619, 0.010821136529557407, 0.025949672199203633, 0.017687228937575128, 0.03690982412081212, 0.06911172313266434, 0.06788109385524876, 0.030011377784830984, 0.01692715653916821, 0.038435442256741226, 0.05457516526803374, 0.07244381034979597, 0.023927570255182218, 0.060415039988583885, 0.02156191701942589, 0.03716923813044559, 0.028361017612041906, 0.035173391515854746, 0.032704555633245036, 0.02371154219872551, 0.03188282375049312, 0.018102570029441267, 0.0226183159975335, 0.05149917466042098, 0.01793852756236447, 0.03668022960482631, 0.005447872781587648, 0.018448824594088364, 0.066047810978489, 0.03437635830778163, 0.007321055836655432, 0.011414181171858218, 0.04784478012879845, 0.04372116643935442, 0.048818700524861924, 0.005527690764211002, 0.041523737672832794, 0.028275327385927085, 0.04982715305231977, 0.04794927081093192, 0.09098628841456957, 0.04493998072575778, 0.0242927069120924, 0.010800443596963305, 0.027379751809348818, 0.011448805144027574, 0.02709079475607723, 0.050990339659620076, 0.018731061500147916, 0.011360507196513936, 0.057505086369928904, 0.06280444751610048, 0.11063222875236534, 0.0923613396298606, 0.12676093087065965, 0.0658234597358387, 0.010986737506755162, 0.032680443255230784, 0.01839156604546588, 0.10153988070669584, 0.045890182082075626, 0.019451690604910254, 0.05942478121141903, 0.08430939356912859, 0.047709868813399225, 0.02746929934801301, 0.04882294189883396, 0.014376766048371792, 0.03677823762700427, 0.0017471188357376377, 0.002868850233426201, 0.033890310951392166, 0.06410068264813162, 0.05982706235954538, 0.01947215903783217, 0.06219932627573144, 0.052013401364092715, 0.12485956336604431, 0.021185605473874602, 0.03939840113162063, 0.010597187902021687, 0.019107569714833517, 0.03309440209704917, 0.052063492621527985, 0.04055463010445237, 0.07285723855602555, 0.021727219282183796, 0.046511812397511676, 0.044386101071722806, 0.013449430261971429, 0.10943563436740078, 0.026952803527819924, 0.035530620589270256, 0.03277629533840809, 0.013931918092566775, 0.029890782498114277, 0.04145039492868818, 0.044171972913318314, 0.03159750507620629, 0.1574274228187278, 0.05558307973842602, 0.012021246839140076, 0.01990386634133756, 0.09893464550259523, 0.07404632240650244, 0.06178374955197796, 0.06787267047911882, 0.015198220553429564, 0.08915782207623124, 0.03230762908060569, 0.01474626560593606, 0.04284102011297364, 0.05369832520955242, 0.05631906387861818, 0.012528192146419315, 0.05599937263468746, 0.025356273181387223, 0.07315863957046531, 0.05051105697930325, 0.06117145916505251, 0.07181819470133632, 0.038279290674836375, 0.01739684696076438, 0.04655197000829503, 0.047947749408194795, 0.01883641492895549, 0.05589703418081626, 0.05309646199748386, 0.0996211172605399, 0.028535463134176098, 0.017376591895299498, 0.027420050428190734, 0.020675384512287565, 0.03951304068323225, 0.0504775156150572, 0.005573130611082888, 0.015365782655862859, 0.010721362195909023, 0.02438141767925117, 0.03791336734138895, 0.016009134706109762, 0.11458277731435373, 0.02433615594782168, 0.03483523934846744, 0.037856615308555774, 0.12533538392744958, 0.02601361193228513, 0.017663619364611804, 0.04711244364443701, 0.06907055620104074, 0.05503628017322626, 0.009200794374919496, 0.03948761099309195, 0.017007334463414736, 0.0006451876481605723, 0.07574175135232508, 0.054896340807317756, 0.04299186904972885, 0.06076953053707257, 0.06281620313529857, 0.012883468443760648, 0.03224444262741599, 0.02049355833150912, 0.012434897689672653, 0.002647762585183955, 0.015175667613220867, 0.06538320289109834, 0.04132452297199052, 0.05773102580860723, 0.016429153183707967, 0.023332328855758533, 0.01610609073395608, 0.11034308059606701, 0.034525641312939115, 0.04458990595594514, 0.0033290460351054207, 0.03822546270384919, 0.01891897143650567, 0.054916560620767996, 0.005636501209664857, 0.018160450126742944, 0.016140750885824673, 0.03909198690962512, 0.08955809200415388, 0.02267327203298919, 0.015528684998571407, 0.08335513266501948, 0.040598082850920036, 0.021860648157598916, 0.06604084221180528, 0.028741256974171847, 0.024700845460756682, 0.03131450561340898, 0.02851920638931915, 0.04300494569179136, 0.022361352930602152, 0.01861637556430651, 0.03209590176993515, 0.04497002657444682, 0.13469898694893345, 0.046627279443782754, 0.017397941628587432, 0.03143117864965461, 0.02986007799336221, 0.01078086017514579, 0.025247350022254977, 0.02938115896540694, 0.0225736758147832, 0.026392192594357766, 0.0244023703635321, 0.04877742598182522, 0.028014234267175198, 0.029225222606328316, 0.01813909853808582, 0.020699825290648732, 0.03009551506693242, 0.05828812638355885, 0.04625190485967323, 0.1555315323639661, 0.1100422658782918, 0.18298519280506298, 0.15951046807458624, 0.07235370620037429, 0.15503033035201952, 0.1550236955517903, 0.10932926234090701, 0.1603389423689805, 0.1339373950031586, 0.15983653807779774, 0.12649804732063785, 0.26246542402077466, 0.20430562610272318, 0.15612829331075773, 0.07647677441127598, 0.12119808132410981, 0.3385805943980813, 0.1472924611880444, 0.106731507985387, 0.2223909189342521, 0.12511648004874587, 0.09374682544148527, 0.13505582639481872, 0.07013479596935213, 0.08402216757531278, 0.21751358377514407, 0.1180959188786801, 0.119730736623751, 0.1042525343655143, 0.1530054397881031, 0.09780702632269822, 0.23726360290311277, 0.22031508735381067, 0.2019538194872439, 0.17425663070753217, 0.07299458782654256, 0.13841022999258712, 0.13942208897788078, 0.14549975894624367, 0.09536779471090995, 0.10081167056341656, 0.07831361217540689, 0.21071098395623267, 0.08500083029503003, 0.12798921496141702, 0.1614641273044981, 0.11819032006314956, 0.12384432760882191, 0.17465413984609768, 0.15645958803361282, 0.14945464907214046, 0.14742950617801398, 0.12435773795004934, 0.1498740367242135, 0.10083376429975033, 0.13254091056296602, 0.22597026749281213, 0.13839321996783838, 0.20194955955957994, 0.10349543983465992, 0.23343294829828665, 0.17691639892291278, 0.15138501970795915, 0.1483929029200226, 0.22604010358918458, 0.21655640623066574, 0.13873529067495838, 0.18402415502350777, 0.3084775112802163, 0.1230381103232503, 0.16662788693793118, 0.08658654012833722, 0.11283558356808499, 0.25315625010989606, 0.1470837989472784, 0.1930173669825308, 0.16106605413369834, 0.133537822694052, 0.13474318926455453, 0.18103214213624597, 0.1468303258297965, 0.15223400696413592, 0.08639351493911818, 0.1694654143648222, 0.14248473948100582, 0.17942148871952668, 0.14406353991944343, 0.11213879595743492, 0.10484234138857573, 0.08379060265724547, 0.13263863656902686, 0.20998017629608512, 0.0935003804625012, 0.16239292512182146, 0.15450610691914335, 0.15169692953350022, 0.08829191385302693, 0.07210838186438195, 0.15627342771040276, 0.10867497010622174, 0.1567705479101278, 0.10263731674058363, 0.2087436246802099, 0.25674224831163883, 0.12606853677425534, 0.08645435620564967, 0.20593073655618355, 0.15966036706231534, 0.21081530023366213, 0.2397980965906754, 0.17087122017983347, 0.08472754925605841, 0.12740076606860384, 0.09107265956117772, 0.19105484650935978, 0.17525002505863085, 0.1619572250638157, 0.08617144208983518, 0.11444164309068583, 0.15500279667321593, 0.05944982869550586, 0.12142031744588166, 0.14717101614223793, 0.16888100275537, 0.2467843482736498, 0.17826759751187637, 0.13489656150341034, 0.20404440496349707, 0.14095147722400725, 0.13002577208681032, 0.11594749041250907, 0.20790242997463793, 0.09638555377023295, 0.21568729192949831, 0.08852805040078238, 0.12945869704708457, 0.12776369112543762, 0.10436377488076687, 0.22645904595265165, 0.17572715179994702, 0.12874632433522493, 0.17853742756415159, 0.11976971421972848, 0.21918534563155845, 0.11674592999042943, 0.09208739065798, 0.1391027428326197, 0.07780854357406497, 0.10697896228521131, 0.15886509645497426, 0.12762710626702756, 0.09946531819878146, 0.12205900973640382, 0.15936589770717546, 0.1682129511027597, 0.13704294164199382, 0.1535773981595412, 0.13773324288195, 0.12315557745750993, 0.15983871999196708, 0.09075705384020694, 0.11342101934133098, 0.0921179968281649, 0.29342037392780185, 0.10235230976832099, 0.17163655254989862, 0.13125588186085224, 0.13369837892241776, 0.1481182489078492, 0.1831922074779868, 0.07886096092988737, 0.12953966535860673, 0.15171632927376777, 0.19616294506704435, 0.09950854087946936], [0.05576004114118405, 0.025539149501128122, 0.05218619560764637, 0.007851966947782785, 0.034528509713709354, 0.06878622458316386, 0.07558626399259083, 0.04089011054020375, 0.006617803655899479, 0.0110012919503788, 0.01777578014298342, 0.0064024203402368585, 0.039055384186212905, 0.05293903763231356, 0.05492639036674518, 0.02750632138486253, 0.01000854883386637, 0.019754787426791154, 0.024832979288476054, 0.02802542585413903, 0.03205110573617276, 0.05839502904564142, 0.03429333053645678, 0.0722528038022574, 0.03885033991537057, 0.04369356967799831, 0.028745515046466608, 0.02926369554188568, 0.06423268845537677, 0.02354808231757488, 0.03156682098051533, 0.003310506954221637, 0.0588843715377152, 0.046979803300928324, 0.03378673682163935, 0.007777645496389596, 0.042105778120458126, 0.06935659475857392, 0.042074793454958126, 0.020726242037198972, 0.03709605123731308, 0.024761632921581622, 0.06735215036314912, 0.04335342484409921, 0.028898033815494273, 0.04210893595882226, 0.03796464603510685, 0.008246407305705361, 0.02062178846244933, 0.03907965983671602, 0.022256801021285355, 0.05325590871507302, 0.05113084305776283, 0.02581199267297052, 0.04581716588290874, 0.02120475659467047, 0.08252298473962583, 0.03576081624487415, 0.012398417420627084, 0.03392318438272923, 0.023917707112559583, 0.07927484926767647, 0.021555898201768287, 0.03932256848202087, 0.012430705482984195, 0.025796108857321087, 0.05822261700814124, 0.021957516983093228, 0.03866055420076009, 0.038979941164143384, 0.042048970426549204, 0.0655123514297884, 0.035660559515235946, 0.016825916463858448, 0.03959401270549279, 0.13399528252193704, 0.021713404203183018, 0.09166241463390179, 0.049863028471008874, 0.015888619200268295, 0.11975973233347759, 0.051674247297341935, 0.059717499098042026, 0.02931762926891679, 0.07232209813082591, 0.033894452135427855, 0.04804581680218689, 0.004925124367218814, 0.03533932089339942, 0.05671974940923974, 0.053488449557335116, 0.039926346435095184, 0.02317010279512033, 0.0594235715107061, 0.017492053375463, 0.03989804092270788, 0.061404604857671075, 0.054927566670812666, 0.022905603218532633, 0.01817425221815938, 0.03509966656565666, 0.017839623396866955, 0.01654762036196189, 0.06281947600655258, 0.028159179419162683, 0.027815479697892442, 0.07979971836903132, 0.0360464614641387, 0.06322146029560827, 0.04950901660777163, 0.02085736097797053, 0.02969864603073802, 0.025046064729394857, 0.03560183336958289, 0.02300050535268383, 0.009408379573869752, 0.043379745111451484, 0.027279866153548937, 0.04666508815716952, 0.05820823418616783, 0.018019584931607824, 0.04918436039588414, 0.05448915406304877, 0.023212318010337185, 0.014041758731764276, 0.05954659733106382, 0.007960917937452905, 0.0679900188697502, 0.01987277777516283, 0.05000441502488684, 0.020360053385957144, 0.013436101289698854, 0.061072404714650474, 0.044460200806497596, 0.040368933623540215, 0.05630471445329022, 0.047486126131843776, 0.0574916980258422, 0.019116223156743217, 0.012133560685470002, 0.03136578430712689, 0.0620254002569709, 0.02631393312185537, 0.05818348356115166, 0.047393517234013416, 0.05944809578068089, 0.015936003474052995, 0.016988788192975335, 0.04291378769266885, 0.047409146864083596, 0.04173106404778082, 0.03202645901183132, 0.028697551897494122, 0.00999544250589679, 0.04569494900351856, 0.02393207323621027, 0.03089899011683883, 0.03951481441617943, 0.05848343367688358, 0.029734091003774665, 0.06383057057973929, 0.017939818899321835, 0.0031147318759394693, 0.03733572782948613, 0.06199684241437353, 0.02074455638648942, 0.03629282109613996, 0.03455370191659313, 0.1010394653712865, 0.02634012165799504, 0.014116546808509156, 0.057519305919413455, 0.05202930187806487, 0.00997894085230655, 0.039010525069897994, 0.04786207959114108, 0.04479194823943544, 0.028664242454397026, 0.037240988967823796, 0.028334875460132025, 0.04163628807873465, 0.028624548685911577, 0.029096304133418016, 0.04422868041729089, 0.02305534821061883, 0.03990038610936608, 0.037422763198264875, 0.020918256050208583, 0.045662710108445026, 0.03802653001912404, 0.033049906633095816, 0.05121693218825385, 0.03166764545312617, 0.010936036760540446, 0.0730973381723743, 0.030747586424695328, 0.006977344055485446, 0.06763548008166254, 0.10032088830485009, 0.05457015948195476, 0.02880662719690008, 0.04689283472544048, 0.018310247069166508, 0.057080666956608184, 0.05378784677304793, 0.037687691365135834, 0.005897968649151153, 0.05802051906357519, 0.08066864713327959, 0.06827861041529104, 0.04299255924706813, 0.03219794336473569, 0.054680249668308534, 0.015655913230148144, 0.05221515049925074, 0.01638845009438228, 0.01914549902721774, 0.027452198410173878, 0.025809946200752165, 0.0308428707649, 0.08801990188658237, 0.05520677375898231, 0.01404353060934227, 0.023627866903552786, 0.06766407503164373, 0.038644379092147574, 0.047948495266609825, 0.05508143985935021, 0.016829770065669436, 0.028531420284707565, 0.01195060736790765, 0.023730641369184013, 0.022682070193695836, 0.022690046425850596, 0.05399431967816781, 0.07162018970120698, 0.021859236221644096, 0.02099272871419089, 0.004274784996596281, 0.0968929824011866, 0.046023416143725626, 0.040443961042910814, 0.06325312773697078, 0.07091844454407692, 0.022021660806785803, 0.03908682156179566, 0.018999475905729923, 0.10768876716610976, 0.03506152017507702, 0.07306141822482459, 0.07047659208183177, 0.0714594627788756, 0.007686205944992253, 0.019334715143486392, 0.0946470579947345, 0.058825500673265196, 0.044735604387824424, 0.004229513524478534, 0.045403207041090354, 0.03920522751286626, 0.021271779951348435, 0.027166469699295703, 0.004197831240162486, 0.028831513263867237, 0.026554598625807557, 0.029307409895409364, 0.03933748936105985, 0.024583304111729376, 0.04934682394377887, 0.04757717651955318, 0.0514573620603187, 0.024028838161029853, 0.05452563062135596, 0.04882294189883396, 0.0561931956326589, 0.028041931218467653, 0.02986572202644311, 0.04199696813884657, 0.02578509538579965, 0.08483882687869482, 0.03928068166715093, 0.07110430058673956, 0.025395339835085906, 0.0543691710481653, 0.05030354135669768, 0.013478423188644229, 0.032660293945809826, 0.0034348389544902602, 0.06970164147787727, 0.03893421744578518, 0.03601447861001361, 0.03184136738127563, 0.012780422166542849, 0.051322665967745706, 0.054872183900442906, 0.054324033626471646, 0.016667224881530274, 0.028506784692581277, 0.06511580708320253, 0.022430912576965056, 0.05958339672361035, 0.02867606486688601, 0.07279983343323693, 0.016015545006666798, 0.05873549671377987, 0.04311141790822148, 0.03850269196846057, 0.04379613448691089, 0.03578032730729319, 0.08453806411125697, 0.06636448539211415, 0.061799405157216825, 0.03085864140302874, 0.04700875448179431, 0.04803878124221228, 0.03444698479142971, 0.045835797500330955, 0.04784988981555216, 0.01476134419135633, 0.026985697368218098, 0.048275463268510066, 0.015507456791965524, 0.031419200386153534, 0.01569412455864949, 0.028086387719667982, 0.0719675890286453, 0.0027076049673269154, 0.014084943377383752, 0.11379779287381098, 0.027481836077640764, 0.010661694450391224, 0.04339003498898819, 0.04064392902364489, 0.007325691940422985, 0.02426621224003611, 0.0279785573729896, 0.0313094107696088, 0.03554041693860199, 0.023252950595633592, 0.05380824099120218, 0.02872459946956951, 0.07289845743798651, 0.010407275094621582, 0.03241972306568641, 0.008029591645026812, 0.06659996142843738, 0.031930157929309644, 0.0959681773383636, 0.039179816376417875, 0.010876463638851419, 0.018455505778547376, 0.02812729489960475, 0.14918352768290788, 0.13915257062762976, 0.11193803016794845, 0.08978562706033699, 0.09693935920950025, 0.18363276118179783, 0.20646033313823864, 0.15473529696464539, 0.08280080030090176, 0.046400141436606646, 0.04833436010812875, 0.0991934843477793, 0.09012681461172178, 0.08108849491691217, 0.13196460320614278, 0.16736648714868352, 0.09965852892491966, 0.09623151359846815, 0.1926493804785423, 0.12416109108016826, 0.17892938543809578, 0.1900176506023854, 0.21593071636743844, 0.11172384634846821, 0.10476271636434831, 0.17213537968927994, 0.12453681818442419, 0.15720652998425066, 0.12603948911419138, 0.14773194619920105, 0.09605682687833905, 0.13639179611345753, 0.1912452222313732, 0.1767580839805305, 0.08430598711129278, 0.09869165893178433, 0.2308587497100234, 0.1531789093860425, 0.2217967258184217, 0.1435039605712518, 0.14000863797264174, 0.10477113231900148, 0.17318731464911252, 0.0781000591814518, 0.14842199510894716, 0.22728275565896183, 0.13058671698672697, 0.09477380197495222, 0.07359618757618591, 0.13753829553024843, 0.08465902676107362, 0.12288329831790179, 0.21248041244689375, 0.08356214733794332, 0.11939783144043759, 0.09158961736829951, 0.16223924118094146, 0.15864312008488923, 0.12224840582348406, 0.10448875997099094, 0.09688129357527941, 0.2665760612580925, 0.10638383406330831, 0.14331843849504367, 0.10247529105981812, 0.15606558183208108, 0.15869940456468612, 0.1428022451000288, 0.08059086263529025, 0.11623698737821542, 0.12110501600545831, 0.22942609299207106, 0.0916820221755188, 0.16243276360910386, 0.13448058773064986, 0.17757388239260763, 0.10283875788445584, 0.1882268037297763, 0.14086847542785108, 0.17794970597606152, 0.17768603574950248, 0.1299281945102848, 0.20817600045120344, 0.15743128198664635, 0.1783262865501456, 0.0877845223294571, 0.1758449009503238, 0.1080240991723258, 0.14138247206574306, 0.14288693899288774, 0.0869913371570874, 0.11316978008835576, 0.10142441737116314, 0.11047979904105887, 0.13430079503450543, 0.09905789396725595, 0.10768881911644712, 0.11218843821552582, 0.1583601688616909, 0.206891120178625, 0.11985680524958298, 0.11483248032163829, 0.09708643061458133, 0.2121579195954837, 0.11419488640967757, 0.14439409249462187, 0.1563896331936121, 0.1401095700566657, 0.14515581802697852, 0.08543777716113254, 0.12895920197479427, 0.11478720189188607, 0.14362766174599528, 0.17694857844617218, 0.07866611005738378, 0.19373497925698757, 0.10989582529873587, 0.10887768774409778, 0.1534470621845685, 0.15266964765032753, 0.08354405377758667, 0.11097233276814222, 0.18709724012296647, 0.16546362050576136, 0.12458946614060551, 0.12455663352739066, 0.24813606636598706, 0.09494130470557138, 0.16039944224758074, 0.13379657990299165, 0.13977330294437706, 0.12567941390443593, 0.15920918580377474, 0.14606454817112535, 0.24504516972228885, 0.19861713837599382, 0.07849733825423755, 0.15509474877035245, 0.19526892428984866, 0.10937963932519779, 0.13519540952984244, 0.09325281484052539, 0.12634056358365342, 0.1031180503196083, 0.13472129590809345, 0.12142694482463412, 0.08722169237444177, 0.0768467053421773, 0.09371406704303809, 0.14671222044853494, 0.132053705456201, 0.11807536138803698, 0.2441689753322862, 0.18889482569647953, 0.11942383629502729, 0.10673992394004017, 0.1781773375114426, 0.17298969556577504, 0.07969957296154462, 0.1485606876667589, 0.08758401629165746, 0.06838604371296242, 0.13916735420934856, 0.22723362548276782, 0.1557996851624921, 0.10777738702017814, 0.0783171299553942, 0.10619615233736113, 0.21791639184812084, 0.11157563945744187, 0.08054989608353935, 0.23605841444805264, 0.110731453896733, 0.15554400044493377, 0.1926133714732714, 0.08158669123076834], [0.0902301438327413, 0.02191866369685158, 0.06086870373110287, 0.0340556948503945, 0.007392012112177326, 0.07799927552696317, 0.03800529346335679, 0.05808415080537088, 0.032346970328944735, 0.062190168173401617, 0.03642180636234116, 0.016761110273364466, 0.02956354546768125, 0.029311241232790053, 0.07567836451926269, 0.014982631291786674, 0.012477756717999, 0.024248294939752668, 0.04235279455315322, 0.030163768533384427, 0.04924300861603115, 0.0570334997610189, 0.020664037074311636, 0.060017716386937536, 0.04958350968081504, 0.05409565623267554, 0.07321812270674855, 0.0270983702284866, 0.05149973127117846, 0.027203942590858787, 0.02326069305127021, 0.032172528517548926, 0.021845487935934216, 0.023295668615901377, 0.039300689968513325, 0.029019595749559812, 0.007187569444795372, 0.025420381753065158, 0.047040844947332516, 0.014525973911077017, 0.04350057788542472, 0.05155930346518289, 0.01020929235892254, 0.017992574466916267, 0.011264162512816256, 0.0186991064765607, 0.024602811463410035, 0.010599903234833619, 0.053835062208236195, 0.018165973560826387, 0.04598354425979778, 0.011965850153501378, 0.045453161001205444, 0.06411223788745701, 0.010850006074178964, 0.051522466965252534, 0.034093637150363065, 0.03916195288184099, 0.05265061306999996, 0.04836800908378791, 0.05495851051819045, 0.04350285256805364, 0.047462759612244554, 0.03534849383868277, 0.02448799194098683, 0.016543790879950393, 0.010971636656904593, 0.060835774638690054, 0.06454728485550731, 0.057781343421083875, 0.0361600211908808, 0.07718804874457419, 0.015184078929451061, 0.03136377679766156, 0.023424948885804042, 0.01960339301149361, 0.01711119617539225, 0.03058923437492922, 0.024629768122395035, 0.028404203185345978, 0.024591178298578598, 0.03277294083090965, 0.05230038244917523, 0.012929633739986457, 0.03364843760209624, 0.01694827435130719, 0.047705334291094914, 0.04740984819363803, 0.022073199252190534, 0.01835693186876597, 0.02199538877903251, 0.05341772659448907, 0.036969025240978226, 0.0820963537262287, 0.01801284251996549, 0.029606504685943946, 0.0629522610688582, 0.032656056282576174, 0.040479239032720216, 0.028685542092716787, 0.01872871445812052, 0.04824025949346833, 0.017927859189512674, 0.060229280425119214, 0.030049642919038888, 0.02253665563330287, 0.085984999750508, 0.01229172255989397, 0.037305837831809185, 0.021585825306829065, 0.02242353748442838, 0.024369558159378357, 0.025783219607546926, 0.012709937618637923, 0.033488167100586, 0.05684634124918375, 0.01156288715719711, 0.039253949507838115, 0.012177520875411574, 0.025493700377410278, 0.03744817804545164, 0.05804923646792304, 0.04486715748498682, 0.05013825764763169, 0.06781682386645116, 0.007536055090895388, 0.035100635068374686, 0.016459495891467668, 0.03378475157660432, 0.05552026806981303, 0.015750876591482665, 0.04759021976497024, 0.012543624179670587, 0.037151649230509065, 0.06366935383994132, 0.03371017686731648, 0.07525089487899095, 0.014590071350539802, 0.026955408466164954, 0.035499520890880376, 0.021932710697001312, 0.004157461189606693, 0.0686432424117811, 0.03175479585479479, 0.06406871834769845, 0.040544202929595485, 0.015519262506131781, 0.02692931826459244, 0.05468008639581967, 0.045228683593450114, 0.015654985545552336, 0.01987800991628319, 0.01575262620463036, 0.03209775713912677, 0.02996266877744347, 0.09955295841791667, 0.04278690270439256, 0.03287106017523911, 0.016215980540437158, 0.01361115908366628, 0.08480980148306116, 0.017850789008662105, 0.037823096208740026, 0.06605175920412876, 0.014877762114338111, 0.021736160306318197, 0.06419759229174815, 0.0389590014674468, 0.08066358568612486, 0.055438420313294046, 0.06251193000935018, 0.014895690546836704, 0.02406781946774572, 0.023477153408748563, 0.04521772949374281, 0.036758489077328704, 0.05329865642124787, 0.011013438124791719, 0.05958776055194903, 0.07926013247924857, 0.005001214913136209, 0.01290412612434011, 0.02690110180992633, 0.07502632099203765, 0.04297975348890759, 0.053696113609476015, 0.007081856074364623, 0.06249428173759952, 0.008998608300316846, 0.018226746178697795, 0.0530471425736323, 0.017975909540837165, 0.100590473448392, 0.019258407519373577, 0.010035820905613946, 0.017987019491556566, 0.056696312385611236, 0.005310918704708456, 0.05606501188594848, 0.08771007749601267, 0.07370764331426471, 0.03129424498183653, 0.11316865202388726, 0.019278603213024326, 0.04533169369096868, 0.04799774047569372, 0.02831499332387466, 0.029427804802253377, 0.03789787500863895, 0.023845559226174373, 0.036889233233523555, 0.031693757919128984, 0.04023177731141914, 0.019682878883031663, 0.03437350474996492, 0.04595729820721317, 0.01399812230374664, 0.045954986417200416, 0.010049397569673602, 0.03742170192708727, 0.022963258816162124, 0.020638191781472415, 0.023735348440823145, 0.030751287886232603, 0.04269150704203639, 0.007351603098868509, 0.037086340234964155, 0.023144888327806257, 0.03247490916692186, 0.0186994831165066, 0.044723429455189034, 0.07825160573702306, 0.03852507514238823, 0.024406711927440483, 0.09847107037785463, 0.03369393867615145, 0.026098316957359202, 0.0448071177379461, 0.043599368873401545, 0.02809975565469358, 0.020968358439859003, 0.024630847947264556, 0.09665070829214528, 0.061956977951922454, 0.06456363436882384, 0.029850465325580444, 0.04057379606820177, 0.057096070231636986, 0.04965232532413211, 0.03428161202464253, 0.011372995686542708, 0.058297625873819925, 0.03300776006653905, 0.047016743701533414, 0.02432248744298704, 0.029583594587165862, 0.045791454176651314, 0.044256047112867236, 0.024880113087419886, 0.053125572740100324, 0.0281894961517537, 0.04979899225872941, 0.046497603980242275, 0.13113443681504577, 0.02712991707085166, 0.04767581536725629, 0.024404580108239315, 0.053031011993880384, 0.041418920445721596, 0.053620329199475236, 0.02993003468873212, 0.035436323305475526, 0.04560556844808161, 0.017764070908015128, 0.03133784244710114, 0.028140662834630348, 0.09052872468600981, 0.06605962596950121, 0.02236552936665248, 0.012333139038673835, 0.017871075615403242, 0.06837442168034613, 0.03975331099354662, 0.027230136693106033, 0.03876972412399482, 0.029246496269479394, 0.06761383905541152, 0.02359210095164599, 0.05029216794355307, 0.0446776018361561, 0.03230949929275084, 0.05120472014823463, 0.0495229875377845, 0.008597688065492548, 0.023303882335312665, 0.020396593026816845, 0.01573498720972566, 0.025363173299410846, 0.06790739556890912, 0.026796800375450402, 0.026432437407493126, 0.03552113223122433, 0.02888197745051002, 0.0416655806475319, 0.017903898951772135, 0.003952815823140554, 0.03886087841237895, 0.04532304395979736, 0.02286703009303892, 0.010606683681544382, 0.08516032525221817, 0.04961187456501648, 0.03172520642692689, 0.09233952048816718, 0.03096105963777518, 0.052373498838278465, 0.025146345578832552, 0.036401434408617206, 0.014946486844564788, 0.02708990974497283, 0.053128188810660504, 0.017437479546060786, 0.03024584450031398, 0.00842977065985906, 0.06743053600075655, 0.08517816648236476, 0.09532205614959821, 0.020697352083516307, 0.01129116926676943, 0.06344708061078563, 0.02586520651675528, 0.03459169987763744, 0.03411075107578654, 0.08531978310202248, 0.035625363161670975, 0.04465396072191652, 0.052218471610103734, 0.0581776762555819, 0.038644998785457574, 0.017434978508390486, 0.03021886557689868, 0.043314254289725795, 0.03698880347656086, 0.04637226265913341, 0.039960455542313866, 0.04053464777825866, 0.04876125829468947, 0.019028408532903995, 0.028630958986468613, 0.008059387018874986, 0.02388814180449117, 0.009260488095605979, 0.23985745356185362, 0.09588232569512911, 0.14027417841134593, 0.19203197298338637, 0.07246251247124746, 0.1230181465507485, 0.0982517731608823, 0.13889942405512556, 0.16165718960110098, 0.3583069983869791, 0.23685978550929576, 0.11782744695665315, 0.079111487721093, 0.0882740800443571, 0.11553067801287398, 0.09497287566773593, 0.20081833354197443, 0.07348458340857178, 0.10120971404830925, 0.11277212994173169, 0.0756393201299943, 0.13486847863532603, 0.20969192613847554, 0.13713674910832196, 0.23753012297675014, 0.08950995630584657, 0.1836721395375207, 0.14362375804921612, 0.113862589787459, 0.1299945721984841, 0.11091848253272474, 0.11698203685227782, 0.11744003102649003, 0.08917821629438549, 0.21877774328459054, 0.20016359601868317, 0.16317394649377093, 0.1091562380315736, 0.11110079853096977, 0.09375378678669222, 0.09387394049554132, 0.1217783814354334, 0.13018531899433583, 0.13718565664021298, 0.10966543297399767, 0.14046743366634473, 0.15454787499038503, 0.11201004817849025, 0.17251761542866006, 0.13711916020838544, 0.1017346054140944, 0.10778160984045826, 0.1237742391822394, 0.09848283341852948, 0.13701663992833346, 0.21038550767116249, 0.13651264744112268, 0.11799334664829075, 0.16468685906147584, 0.21354943164624274, 0.10028291260823607, 0.14738024241523817, 0.1690408168360591, 0.10001128655858338, 0.14922726986696944, 0.1270280298194848, 0.19822311733150855, 0.1665923380642198, 0.242141695052851, 0.16879279108252376, 0.19930484209908172, 0.34526882926002145, 0.06667189038125798, 0.14168231457006186, 0.0817952273064293, 0.14196796721080318, 0.18289370083948597, 0.13389807601924986, 0.10991184084559791, 0.06465189057053067, 0.1470630633411929, 0.09630872664274648, 0.13506591960322112, 0.111347651691176, 0.20794445037608966, 0.1423096371581778, 0.18395362130831927, 0.14706730842590332, 0.07852113150875084, 0.1639591238927096, 0.1701718647382222, 0.29616635001730174, 0.15567737922538072, 0.20409585064044222, 0.1427461238927208, 0.14070710283704102, 0.10580544869299047, 0.10795454509207048, 0.17577479768078774, 0.1825290688429959, 0.19641392456833273, 0.17189021862577647, 0.13426570629235357, 0.08189644140657037, 0.12044529124977998, 0.1265259669162333, 0.1593776830122806, 0.146674623247236, 0.15860694780712947, 0.11821072170278057, 0.18492691830033436, 0.09349917076178826, 0.18471530231181532, 0.11881172773428261, 0.10910900033195503, 0.12827317550545558, 0.12071391160134226, 0.0781159708276391, 0.11617337790085003, 0.07733685677521862, 0.06992398150032386, 0.12979860068298876, 0.14685607835417613, 0.1368463021935895, 0.13881216233130544, 0.11814848519861698, 0.1026918571733404, 0.10143294464796782, 0.08592136058723554, 0.1013455270731356, 0.1422754835220985, 0.10705197477363981, 0.14733363554114476, 0.21955753269139677, 0.15997996553778648, 0.1174251658085268, 0.23039576830342412, 0.18913618696387857, 0.15590683644404635, 0.12437413199222647, 0.11528193979756907, 0.12069651565980166, 0.0959958000748884, 0.1291617489187047, 0.08551421837182716, 0.17223929520696402, 0.08616544553660788, 0.10168713022721931, 0.11108548802440055, 0.15269949682988226, 0.20795957534573972, 0.07620185322593898, 0.0907409047067631, 0.17566696362337098, 0.11434695246862248, 0.19639584585092962, 0.10593248953227885, 0.19415531685808674, 0.10925460970611311, 0.1655367368948646, 0.16499373712576926, 0.12778059724951163, 0.10197730996878818, 0.1583418229711242, 0.14424745895667002, 0.12335812440142035, 0.14999289909610525, 0.10410887683974579, 0.19506639218889177, 0.0884862378006801, 0.1525220344774425, 0.07751766621368006, 0.14388837822480127, 0.07543692161561921, 0.1981075797812082, 0.10858683264814317], [0.0534988989966223, 0.03465994406724349, 0.051306060413480736, 0.04469264888030011, 0.03849849512334913, 0.011099622806796106, 0.03497628080367576, 0.00841620141727617, 0.021010649725212716, 0.05792776544694789, 0.04239867041178513, 0.08196865979698487, 0.07602194178616628, 0.03474143930361606, 0.03501761100778822, 0.046821358482702635, 0.0035179516089556273, 0.01831114692322444, 0.0521427873900393, 0.06824504307587631, 0.018512126080167945, 0.029433296695060562, 0.06951188173843548, 0.007135528658182011, 0.032862610823940486, 0.02063590225588996, 0.02824604594934499, 0.08989881200250238, 0.011591723305173218, 0.02802177819830831, 0.0071705492155160755, 0.03446134534897283, 0.05578385294938926, 0.03334731489303522, 0.09441596805118024, 0.05953096770099364, 0.04914530858513899, 0.049940067110583186, 0.05360669223591685, 0.01300794701819541, 0.017567858194524888, 0.11384122335584834, 0.04458229894225951, 0.04049068666063249, 0.009708744364615995, 0.010391596297267824, 0.06686609558528289, 0.039600369200343266, 0.01579216968821129, 0.013278168553370051, 0.05455361329950392, 0.01105390187149169, 0.02105459414451616, 0.04292882360459771, 0.025557120607118122, 0.005288754000503104, 0.016735929202695843, 0.018135745885956567, 0.06014869431965053, 0.03528960070980247, 0.03860944620100781, 0.11168509881827049, 0.03176154197717551, 0.018196780110883992, 0.026846897198993247, 0.008889414257282624, 0.059173248810111545, 0.05442098779894877, 0.058891325461445376, 0.0798872324230615, 0.018313540349481627, 0.01040243536408525, 0.004667259127018042, 0.02736492555413861, 0.03185631052474491, 0.02480231189110782, 0.038028155322535895, 0.04289598356990609, 0.022253116258070804, 0.009673355052655097, 0.06883803391247056, 0.06985409345361404, 0.03180693543981761, 0.019021751468244474, 0.05322833421814721, 0.025262920280511025, 0.021887717994104605, 0.03184238412359264, 0.03855371833196841, 0.053989777734386735, 0.01280890579437255, 0.053961398007231764, 0.03284398291725665, 0.044727585482178256, 0.04598684681695886, 0.01435110907550552, 0.050781974277924746, 0.031160398648353294, 0.03506918656057678, 0.058891095395665616, 0.01706635932350764, 0.04049375173053704, 0.025504361328785308, 0.034504067079978995, 0.04307539405999705, 0.05063150012574624, 0.00972390829701908, 0.04573600832372904, 0.03313617758976761, 0.030345171689987183, 0.035034969841944985, 0.08179919779649936, 0.03003640114911832, 0.056668389079277404, 0.05419784996774979, 0.019953896371589508, 0.07104641306796111, 0.07375562316155992, 0.041709289434948005, 0.033197070806636475, 0.03006841925525805, 0.07438045955495909, 0.038439564887085, 0.0443142834410537, 0.020528919812932145, 0.053492119477596134, 0.0582272962492425, 0.06168738538690377, 0.03250426481827162, 0.011419707388995448, 0.05703598966647405, 0.06224159158591647, 0.030113582652120385, 0.03077595501963515, 0.027763592443079688, 0.0296633272228064, 0.05474528777995147, 0.02238730769022368, 0.04384196952742059, 0.03652909494121559, 0.025498457544017583, 0.022613069013459608, 0.03218045465473551, 0.035088148433715105, 0.058039020805153996, 0.062031307752477005, 0.016845160353113897, 0.015627739448973443, 0.01764245145750465, 0.04010877004475333, 0.1164631791471038, 0.04912368611257989, 0.0470483740355121, 0.06055388839740772, 0.03350879509525839, 0.07805070636095479, 0.10534752131206915, 0.032785757721285336, 0.027093694698123727, 0.006210826568349148, 0.06002261085086502, 0.025452190202486236, 0.06641552288783714, 0.02081832029944053, 0.014463730913121253, 0.03649050326202996, 0.1316102870623581, 0.12354124934063293, 0.04276365121768322, 0.08546792319975793, 0.01643871575652156, 0.03366937358805444, 0.033319161520921625, 0.01405983281074441, 0.03042027889023302, 0.057975526360678487, 0.01941078713571187, 0.012518323437689105, 0.05754684330895543, 0.018038294474536087, 0.024380458453379106, 0.012912130187032744, 0.03713625337695703, 0.009393328818987356, 0.042598211657605134, 0.0892781390575692, 0.06324460046016611, 0.03857352254271973, 0.08778742412687279, 0.042102390216314234, 0.0387586178840138, 0.04661504513933323, 0.01658572036831174, 0.04343400723882951, 0.07880262070102617, 0.041556674186722375, 0.005696846164937597, 0.05287212559778709, 0.05877586212591268, 0.02176866080844775, 0.04129173488763627, 0.06561206639162265, 0.07250630660564639, 0.0643568200757727, 0.041551853937562555, 0.016753211966715753, 0.04701193087385036, 0.0757286672887858, 0.07899116331827827, 0.031390282601932995, 0.042858609012910165, 0.03591097869502846, 0.08267270561191253, 0.04259670138708316, 0.05019450130930636, 0.04711631023383234, 0.02759362763754325, 0.019751484869630076, 0.03915711036825087, 0.06170168286189437, 0.05002411162422504, 0.0234665221432806, 0.025449999011470936, 0.029604126102640294, 0.0038606512862315867, 0.022321648029901553, 0.049894335970748216, 0.02984827042382676, 0.06069489645597059, 0.05974558196612634, 0.012561691764858551, 0.02946666550997179, 0.031699383398517966, 0.018060568181681447, 0.04828975703276228, 0.03688775635964703, 0.04233881249092519, 0.09212899545673281, 0.03805975597060751, 0.025995724317908753, 0.0030357464902408537, 0.024830123875290155, 0.055929466034285724, 0.04801659844815731, 0.03348625235958025, 0.1085647389118094, 0.028273091666051187, 0.03140102890029084, 0.02611198175145546, 0.04221037270326633, 0.0954599175020121, 0.03609774757933337, 0.05599045201961417, 0.05935613997280598, 0.04537440057902131, 0.03352732652274426, 0.030968952378316317, 0.03960119669500273, 0.03091663838858949, 0.02342991570913, 0.0030727543799002888, 0.07536384233389981, 0.06788136102841236, 0.043671000967151485, 0.028679356291831937, 0.03273442336649168, 0.018711068041739054, 0.029899499022576492, 0.0344536270131357, 0.08555213469662704, 0.06443444130127318, 0.021758914554084186, 0.014710148061567452, 0.0438334459613543, 0.007372419413513853, 0.015541654956905404, 0.01891941858048085, 0.0261600654994254, 0.08028044452657923, 0.017044618107320275, 0.031134453165577725, 0.01551988034407259, 0.04524543015577365, 0.06493984386906959, 0.029939884843770415, 0.045051900306134485, 0.026275551099388395, 0.054131928700371645, 0.014596900036849547, 0.04990216933947522, 0.05693856051948387, 0.008318339041579748, 0.01660319794609677, 0.02938875670224661, 0.038023943634470925, 0.030416759254876524, 0.03757501479412895, 0.06801905910833739, 0.0723446074698586, 0.04360352490039077, 0.010152842751267599, 0.022326742873701733, 0.06241807801416144, 0.011089174295193516, 0.048617830834700726, 0.038040330255171284, 0.0758402566134464, 0.025922292516042944, 0.09637510433094576, 0.10798243500175886, 0.02598826387838926, 0.0469490449904697, 0.01127727904531639, 0.022536293836310506, 0.0441253437747946, 0.019847995608870406, 0.024750812408456113, 0.03173013057676144, 0.050060079811373726, 0.05611444263195153, 0.02268558611831395, 0.020255913368600886, 0.018429519477649592, 0.018474809039616957, 0.05567592612351291, 0.049223816677113064, 0.03973060127464123, 0.04070176088134758, 0.008244789423770271, 0.060966047531110235, 0.020254844675946515, 0.03084571690123994, 0.043865028055734, 0.06569693839992397, 0.012531494703580393, 0.058372690400574356, 0.022395554806280416, 0.01651064470934216, 0.08620020773378201, 0.01324347036643303, 0.022984855313552544, 0.04529514662863221, 0.06524794647702947, 0.0026445013099873904, 0.02295278711244464, 0.007936855654406827, 0.05181342225114349, 0.023993222494027577, 0.025799802897381596, 0.02564266982517438, 0.02602153064799495, 0.024289354259963147, 0.13737548317294568, 0.11235910991672426, 0.10543901327764615, 0.12275610904907808, 0.1562386951991357, 0.10540056260651909, 0.09226195121300407, 0.141878197027836, 0.146338400663808, 0.11542302949237637, 0.20492681855103, 0.16292106709443033, 0.19949100242229179, 0.13122863019816577, 0.12744502775603905, 0.1894736266694963, 0.11418123089242727, 0.14816712675383314, 0.16890990198589861, 0.1140434066473972, 0.07389033038634807, 0.1617440950940363, 0.1374696468701586, 0.1444228581385687, 0.21775911591248587, 0.1329832008923404, 0.1767272551660426, 0.2753986237803474, 0.11934424095670693, 0.15827514842385426, 0.11209127624169923, 0.13407334161456674, 0.1385670606396161, 0.1635485381120816, 0.2773021731991321, 0.2497681975364685, 0.15607499226462096, 0.12970439245691523, 0.3181933524319902, 0.14022433577338234, 0.11541485102497973, 0.25716806296259165, 0.07912729546660557, 0.1404573701438494, 0.15801496629137546, 0.08456133786239661, 0.13023486477322876, 0.09358714494737796, 0.10687739937566221, 0.12357527681160718, 0.19506421027472243, 0.05820892809424549, 0.21414660819573328, 0.10053428544779308, 0.06093383832194377, 0.07697746434132569, 0.10484654936590232, 0.09760466491570696, 0.1934690825873986, 0.20631341758416966, 0.18087277334416285, 0.24822077510179952, 0.14985045127104968, 0.0771812952007167, 0.0687002987251617, 0.1226004955242388, 0.13714175118366256, 0.10858845795155503, 0.13248033646959811, 0.201171031803824, 0.11630781053099781, 0.1359726904775016, 0.12381649707094766, 0.12394247663905844, 0.22698304674122483, 0.07303772887098603, 0.24194838042603806, 0.1285928036668338, 0.147418700507842, 0.21799485170049593, 0.15837789134820923, 0.2268714425736107, 0.08789676474407315, 0.09796187543543056, 0.2694875659653917, 0.16711717005819082, 0.18836619390640408, 0.12648075527977198, 0.13907497166655958, 0.21264364040689543, 0.09670541941886768, 0.1274365821154788, 0.19770346552832052, 0.18897128175012767, 0.13598596007796004, 0.07554704890935682, 0.1274260733043775, 0.1746256265323609, 0.14678925537737086, 0.17858522187452763, 0.12389113486278802, 0.08990720569272526, 0.13901588186854497, 0.14077349536819384, 0.11781382112530991, 0.10486734434380196, 0.10269508551573381, 0.10862574345082976, 0.14139686973067, 0.1486968866083771, 0.09244890563422814, 0.17386669147526845, 0.11490593067719601, 0.14056340820388868, 0.13370180764468387, 0.08552756960853003, 0.12370560536510311, 0.13961935183033347, 0.07910448184702545, 0.14252383582061157, 0.09382831325638108, 0.13711654784856364, 0.13655965507496148, 0.2297282955260016, 0.11446704680565745, 0.09705071846838109, 0.17922956933034584, 0.15361100260633975, 0.17368734406773, 0.1098932945751585, 0.17525409202789888, 0.16450573049951345, 0.22756251564715058, 0.176548516319599, 0.17952685884665698, 0.08885858813300729, 0.12111597752664238, 0.09715518317534588, 0.14138199709123, 0.15500549809075892, 0.15620979596860707, 0.11370789652573876, 0.1178961549885571, 0.13386856822762638, 0.18493462179321796, 0.08430233574472368, 0.12340369969024323, 0.12401560044963844, 0.08979944585007615, 0.1839123578974977, 0.2690157084725797, 0.13146620651241392, 0.10642990659107454, 0.12603181530721486, 0.10115518103702925, 0.1765783951850608, 0.2304846775950864, 0.15979511139448732, 0.1497075433144346, 0.11531493568327278, 0.11342586556565948, 0.15168458019616082, 0.13523327390430495, 0.169453154085204, 0.10688077614759095, 0.13953949674032629, 0.2658116788370535, 0.11880470701726153, 0.1466196301043965, 0.12014760097372346, 0.09829759335843846, 0.09398592315847054, 0.12159195393905975, 0.11274584307102486, 0.08759838427067734, 0.12617038912139833], [0.034766160242725164, 0.023505421813752037, 0.024659504124429077, 0.03422998823225498, 0.041752426768653095, 0.05124012430314906, 0.048679729661671445, 0.03638818707258906, 0.045005894571659155, 0.06991789588937536, 0.0797624773986172, 0.037859483709326014, 0.044661037100013345, 0.020188387206871994, 0.05435843217128422, 0.017420159674657043, 0.07897702540503815, 0.06921543084899895, 0.04311930693802424, 0.00637230074062245, 0.010105945511895698, 0.08600667046266608, 0.0356016107252799, 0.09953119864803739, 0.058950240854755975, 0.03924754106265027, 0.0504161214485066, 0.0336046917072963, 0.02303047698660521, 0.06778153474442661, 0.02202482421125751, 0.056539633878855966, 0.07023483005468734, 0.028276164157432504, 0.05516205565072596, 0.02845333336153999, 0.06568532378878444, 0.010891729616560042, 0.03471218384220265, 0.05037708819145337, 0.04210628649161663, 0.009719421086629154, 0.041970855672843754, 0.03970753161411267, 0.027746166815632023, 0.01952236347278813, 0.03459910651145037, 0.009331825185654452, 0.03430843324167654, 0.015771747639519162, 0.030678524017275777, 0.048466198932146654, 0.07674170628888533, 0.0116878462722525, 0.01719229250738863, 0.014728942023793934, 0.046069284580880776, 0.0030669308398501016, 0.03748480674403254, 0.025064226938411593, 0.03548817716364283, 0.07364441233221442, 0.04110744848730974, 0.04705178791482467, 0.0652495346730575, 0.0028541350684463396, 0.029814877489116043, 0.03194264827470761, 0.0337229863362154, 0.02352877720113611, 0.015938840333546977, 0.02602379048767034, 0.07045725913485512, 0.0394585410685977, 0.07564841143903323, 0.10245258134091273, 0.009040968234330649, 0.06501101583126001, 0.0626440990890842, 0.03917241716408171, 0.06680545469862409, 0.025214328161382582, 0.037304505676729605, 0.04064539847604465, 0.050513209207565524, 0.01994625596125843, 0.075459586805664, 0.03578893622034229, 0.0491358128056163, 0.05014030226448085, 0.04872259611147456, 0.029032472011749633, 0.003927843945348286, 0.07166255891206674, 0.014654794977104757, 0.02782813517114846, 0.011673549724946497, 0.021546133393712807, 0.03729473159182817, 0.04647338399081491, 0.010633849997248035, 0.02277063438668847, 0.10827703052200377, 0.06268614175496623, 0.04961707702022977, 0.04262367474439088, 0.009123193558480125, 0.053214649014989845, 0.05268435110338032, 0.006533438627229771, 0.017210697769769467, 0.05583827463851776, 0.031516136004938744, 0.08479412732413039, 0.014066891562833916, 0.020957183551217895, 0.03602975943067577, 0.05353205815481488, 0.03807284003414679, 0.07576624222565442, 0.022938829170016106, 0.07230180781334639, 0.04537768087175209, 0.05271152112982236, 0.042337840277468786, 0.021332073883968405, 0.051724409058806486, 0.0169835727501777, 0.06041843902494293, 0.024298833341163117, 0.09513151715509593, 0.010912929992628051, 0.04488986720389221, 0.03640095572336577, 0.04946335968270432, 0.0177012221320183, 0.016961829678621143, 0.03441291279159486, 0.08610039629274979, 0.037850477747269906, 0.09938381554093212, 0.01575342772412114, 0.022480040897789877, 0.035384647562750615, 0.13339767552679405, 0.012939847547386307, 0.05248332556220703, 0.011143518986500567, 0.05590082655544393, 0.0189498837426072, 0.01586072743521072, 0.018922474373539444, 0.08469936248729937, 0.03303956109448336, 0.007928549166535959, 0.03683621049276553, 0.02723941539443331, 0.043623158417176455, 0.036378401855472475, 0.015081527108122827, 0.012697451911662938, 0.05775835539679974, 0.030419872564380057, 0.03650272272352595, 0.015907247106952127, 0.02205443219281733, 0.03884954581735656, 0.05066512312623672, 0.04958946541592013, 0.03478287340840325, 0.0653386814519763, 0.02229244080808712, 0.007211687388917198, 0.08643964683869854, 0.02013691555475816, 0.04497956317209173, 0.050549644947750494, 0.013071938701614272, 0.10528138853260316, 0.03960465139243752, 0.04389738940517418, 0.09807600290514529, 0.0446193729294464, 0.05430041106592398, 0.03935383887437638, 0.03938661582651548, 0.07021057666861452, 0.051158239439246245, 0.027317090425640345, 0.04233319443301298, 0.01284634621697478, 0.021306414128048345, 0.04211037201457657, 0.07069700252031907, 0.05849792039953172, 0.029328755917958915, 0.04302703200664837, 0.07086859448463656, 0.08374768425710499, 0.06464909267378971, 0.017586135436431505, 0.014134554094198393, 0.05881133307411801, 0.052165430315653794, 0.04241874179570004, 0.004039770483359462, 0.029324414354050532, 0.03279229604231659, 0.05907070626562927, 0.009345251564809587, 0.02844038845069008, 0.10501365875825286, 0.026495831662032288, 0.01931323182361666, 0.04639759587007575, 0.007929043622425525, 0.006756324128218694, 0.014433871529035969, 0.012833617456635693, 0.04493016953347251, 0.05750297124905046, 0.0055820182933530305, 0.028154789615655318, 0.02510921778593911, 0.04080801416421309, 0.027624833091977052, 0.041095396009040996, 0.1030996821646113, 0.05103641960886307, 0.039440087566617876, 0.023146296553022694, 0.0411455021094298, 0.029787150851916522, 0.042110012072953396, 0.044582128248293884, 0.04130897868890315, 0.02330735558643937, 0.06679461192106828, 0.0419828636222519, 0.1520638621877879, 0.034619192738318816, 0.014897030123393051, 0.03750048090296332, 0.03176998761773575, 0.06851695114164613, 0.07765308590023778, 0.06286876945523545, 0.04484692282858305, 0.04197857771941926, 0.06372485164320096, 0.06416890086256899, 0.022173292709339876, 0.0369452394079417, 0.016007052981876768, 0.04008031610283069, 0.04594661499140784, 0.08095411423710175, 0.081663830060279, 0.030282599363999907, 0.02695208921068115, 0.038294530677376315, 0.03391990780073684, 0.041090197264566086, 0.06116293930972461, 0.024911088476073928, 0.05263530256343074, 0.036620056271203794, 0.021081029444758315, 0.07131192382075824, 0.04379492478619795, 0.013563195007009199, 0.02692539415875217, 0.029499961965484545, 0.03515744276228361, 0.04863576854404528, 0.02922440253314562, 0.03033226945262868, 0.02373629467911087, 0.02286700782860862, 0.023693450493738055, 0.026503954468353186, 0.023674468211538624, 0.014457477391260909, 0.06244660617085174, 0.09649180705309846, 0.007519858181694872, 0.03286373888840899, 0.017706619400996715, 0.0647771057265345, 0.005712404827136197, 0.03530800968292169, 0.04629663410014473, 0.05534975593036506, 0.02896699974371586, 0.05860427387233358, 0.04868834228545893, 0.021525189986277837, 0.04971528171154205, 0.05439587352157105, 0.02600785286631435, 0.06417740587494336, 0.06559268149430864, 0.05845171799592208, 0.07222264292067848, 0.035257944400655106, 0.012571790539368521, 0.015177080476860283, 0.06004613322147634, 0.04387834960652981, 0.011496997431095224, 0.09325003178673796, 0.0406057269719895, 0.026734109305834863, 0.012823065044358373, 0.047435827073059045, 0.0010223180493085238, 0.04453604829905089, 0.025655722347437404, 0.0155001141683897, 0.05264755913231056, 0.05713099570129998, 0.07805067667504773, 0.04643066968128551, 0.04180823627393693, 0.05428297801699955, 0.014188810655468842, 0.020753616154252086, 0.06465177924837917, 0.04117988581128884, 0.017797289438021835, 0.03750976888113655, 0.035403650254011154, 0.12395520447171293, 0.01872961987828603, 0.01091992844521883, 0.019515222156769596, 0.014183195380610414, 0.04911978612653911, 0.03512658426188864, 0.07827766996342689, 0.07288667213288136, 0.03387434364412911, 0.06449952023103833, 0.07114861422451213, 0.0480181050079409, 0.010990799837600207, 0.04255421714333352, 0.01308975302890758, 0.05915062443818897, 0.012690708572336007, 0.014116406728135189, 0.04087428795173764, 0.16548546933336183, 0.16681536828400567, 0.17504948191344738, 0.10008182027377188, 0.13707405247259885, 0.21806139266118407, 0.08055126905674115, 0.10551592204137705, 0.1337258383864537, 0.14196051604812965, 0.10490714572370052, 0.1532096491428092, 0.13214921986218542, 0.15322404680773616, 0.12384067624225281, 0.10769782136776485, 0.12466537300497293, 0.16705373127479106, 0.18356461718212813, 0.18881543073803186, 0.09378334652865306, 0.11765371760702692, 0.15046797750983387, 0.1400966418441385, 0.13582610146841034, 0.2634203602792695, 0.210632034286391, 0.09406804922036827, 0.12993870332138613, 0.19338321610121056, 0.08660479696118273, 0.1786650621215813, 0.1322543970309198, 0.07357606795267202, 0.10118384278030135, 0.20074478670721874, 0.17444335506297648, 0.1470995621639304, 0.07010657209320925, 0.11479728025733493, 0.16979233041638508, 0.07942720476421528, 0.0881741127523128, 0.15268771152477711, 0.12552478001452982, 0.09015281946631148, 0.08888886775821447, 0.07438304222887382, 0.17979824740905315, 0.11329895089147612, 0.2003120700828731, 0.1547360242693685, 0.15997466660337523, 0.07153350685257465, 0.10869406556594186, 0.11779451044276357, 0.1939644364756532, 0.10920273358351551, 0.11476316372863948, 0.10017107095336542, 0.09978286834666505, 0.09067152874195017, 0.14146407862426713, 0.31443155428860337, 0.13070523797068745, 0.1911185821518302, 0.11110598614322953, 0.12921932473545894, 0.11053268448449671, 0.2134526110603474, 0.10407398847746663, 0.09917237766785547, 0.1515908321016468, 0.16424051660578698, 0.2196076128166169, 0.16839951218571514, 0.22363023133948445, 0.25159575103316456, 0.10523393561015837, 0.15276036778232083, 0.166949815757107, 0.16612313746009022, 0.11939548625377938, 0.13421929237665609, 0.16755805030697957, 0.13100120646413416, 0.2356683267862536, 0.1469662575982511, 0.15583720814902335, 0.2556257613468915, 0.09262996740289964, 0.0842256867326796, 0.21617139485897496, 0.21872070181416348, 0.19463125616312027, 0.07938146620290354, 0.12807049497496337, 0.09733726168633439, 0.1422771014040336, 0.15113556903088465, 0.16388951044064015, 0.11567590889171697, 0.16753538511693478, 0.13023949577473104, 0.1709745716652833, 0.12439273763448, 0.12478092539822683, 0.20549646142171696, 0.14709743962157518, 0.09580666373949498, 0.1290319621330127, 0.12320821057073772, 0.1566342599107884, 0.15309411159250885, 0.09621072604204528, 0.15666909632273018, 0.17497416876722127, 0.11298526733298786, 0.16470573929836974, 0.1070625577995088, 0.09009499131934717, 0.25644399400334805, 0.18039514194242656, 0.12090286239981651, 0.12240501382621005, 0.1150985254207626, 0.14450462796958163, 0.1478782680351287, 0.07801755462423898, 0.06536132437759079, 0.1256256378837861, 0.18678058055229485, 0.14565519435564056, 0.08376075347769074, 0.14794244896620512, 0.12837623013183475, 0.07510213879868388, 0.09656752838054672, 0.2198871798464097, 0.1826086122309789, 0.19660142075736076, 0.06830629994510673, 0.0765678878815379, 0.21277115622069687, 0.21020751097239554, 0.16294870467390865, 0.17091830202843994, 0.09876397380139679, 0.14492772636003792, 0.06013592937961221, 0.10336669205571525, 0.07518853963119909, 0.13873147603590041, 0.07905964128440246, 0.08992998220492154, 0.15197559114312753, 0.19141394208418205, 0.2758307318435982, 0.12551816005725414, 0.09683994852821343, 0.08388869231566787, 0.1563603332033381, 0.11191665631486103, 0.18586051039164886, 0.11775111706811003, 0.14858180918963626, 0.1838107727235183, 0.1402561442228034, 0.13112290384015068, 0.15830994030693546, 0.15439045062521473, 0.08124605286866426, 0.09444195806281641, 0.1300364441704005, 0.19649360154289752, 0.14539655589032918], [0.006627115753872204, 0.05276001676975284, 0.04868025287578348, 0.0537642613198841, 0.006956901597732212, 0.03153459321765695, 0.045650327374460176, 0.0718464408419095, 0.030943877063691616, 0.07597879332024604, 0.05445232869533356, 0.019518823428370524, 0.03528378969349433, 0.07637204995262437, 0.05202028478379361, 0.016579849980189465, 0.046549992184736766, 0.04733599707833491, 0.048084861191455275, 0.09121910014073364, 0.03712119520059787, 0.07343191318796016, 0.06902682143845595, 0.010901990735874278, 0.05564744620642159, 0.048897242013481446, 0.04044160101329908, 0.046590201745857485, 0.031059848770382814, 0.05644922173814848, 0.03822924023552332, 0.015059227425808785, 0.046620588982477784, 0.036789900477742776, 0.04274769133189693, 0.04837646214582492, 0.02071769991744077, 0.03505635111650918, 0.010311756977898767, 0.07604890401125886, 0.025430905407120008, 0.07779450956149958, 0.035484648251440376, 0.05747883289586753, 0.0063229669376596576, 0.01874553523521172, 0.05034278612583876, 0.022086181270424277, 0.024917771515902132, 0.010266257759212749, 0.057400877703912556, 0.02278693009429844, 0.017836766128311865, 0.06583439899259247, 0.05297736213833559, 0.04728032487037126, 0.027478761730890255, 0.029093719604134094, 0.020965901931049302, 0.028906117659062147, 0.010692001906136284, 0.042666860317694955, 0.062389475642703474, 0.04298280371585861, 0.0497890586120775, 0.04242832292220555, 0.057879232699633576, 0.008562508410250302, 0.04305804264731705, 0.030425037912209518, 0.04512516883551143, 0.024176568222173955, 0.012536248159449315, 0.03616427369706798, 0.007698771432842477, 0.042537986373645253, 0.1585611721384339, 0.11855927878059447, 0.04050551477121189, 0.06642579421168193, 0.07058784744003788, 0.08160428755218163, 0.05066735699074343, 0.13137609494151548, 0.009145545191131532, 0.021637360041495413, 0.05468735202157404, 0.00816790570752346, 0.07666556935873814, 0.004719871831184719, 0.04774766268383246, 0.030344910082931165, 0.03501006336591672, 0.06886084011057392, 0.04059279875946231, 0.029611243298859335, 0.06553246363182552, 0.04824522075068671, 0.08386875822907314, 0.0614260232396191, 0.025851098289422225, 0.112440790690016, 0.05116115236887708, 0.021107214270159602, 0.025357653576065786, 0.027091171396023128, 0.03517656048643403, 0.05594316236965824, 0.03729412303073332, 0.03461416097707115, 0.026786037378769834, 0.022639218586846255, 0.05261100835923571, 0.019787150631600525, 0.017109158980019856, 0.006743422818544786, 0.04078995771124028, 0.03846673862426542, 0.032764079587650485, 0.010336958457628498, 0.03873194509651512, 0.051909419053117745, 0.03511558192258235, 0.015252930752467364, 0.01256362413187162, 0.010532698979659472, 0.01747851103573339, 0.039018158058752306, 0.07827265304513276, 0.02273604659421835, 0.04368952497316059, 0.03455128622590564, 0.012688030346907908, 0.02140765976946568, 0.026205455251329113, 0.07030507433228195, 0.056503576633986086, 0.09961517265764996, 0.06681151062366553, 0.024368385566049255, 0.08165242325048894, 0.022006174040143378, 0.02444408648443641, 0.04401802179927472, 0.033086650364566594, 0.07987872741068713, 0.011036525411327602, 0.009990760481741745, 0.061736990537610836, 0.046132986826705746, 0.04735456561320461, 0.006858889864815865, 0.07017120573436841, 0.009418946829100605, 0.03302094432001468, 0.025708062312332913, 0.04607377457432449, 0.04241156522766687, 0.016313070154865272, 0.05032900815422181, 0.011493103938846616, 0.027088414317404386, 0.04469339102797676, 0.047320244993898086, 0.03477473204839043, 0.044738487631548196, 0.06555429761647247, 0.0595666316075949, 0.019146881277265493, 0.04476425870961975, 0.04877885461610276, 0.02753197000856744, 0.024697489097889047, 0.01795693282474531, 0.02802729606628418, 0.020220104743202683, 0.034628818393684924, 0.016278257862722967, 0.0678153544140514, 0.0068666471634060144, 0.03347838930494618, 0.017926263572007883, 0.0241219591407571, 0.04066227120347321, 0.019042167950829025, 0.036399827658897266, 0.017539868094900157, 0.022680474576191045, 0.05468998664582614, 0.07545268483227119, 0.07241718209115788, 0.08999293117085472, 0.03331919862830546, 0.0483020136016421, 0.04071199880854692, 0.05647404286719393, 0.024428714750683866, 0.004924615068375715, 0.07236190693220124, 0.03557670053851325, 0.03244494495447725, 0.0630404578987509, 0.03466320580628235, 0.09355494315968826, 0.09439523244509473, 0.07083867851179093, 0.09011319620185532, 0.02735038873652229, 0.016002112133719493, 0.01948278288182337, 0.02892218515626155, 0.039501273931819014, 0.06927510694367811, 0.05907582708459813, 0.0634359335526824, 0.12721974140731618, 0.08816024943371303, 0.05647514866723213, 0.08199732154025696, 0.0733040263003204, 0.0624517047253903, 0.04559410226647742, 0.022979667701292783, 0.02142769590136595, 0.05689081815944519, 0.020672462305810768, 0.022827362299722154, 0.07438074899255298, 0.03685782925458625, 0.06197155744303018, 0.031402171807712875, 0.03419197913899552, 0.027436366544861812, 0.05892290013434831, 0.03213682008208707, 0.0855582722579129, 0.05342063581338152, 0.005121457679706509, 0.061849485282436945, 0.07530318660428748, 0.03189821960404515, 0.04859661654336378, 0.02912436659244122, 0.050225697486894205, 0.012579064514284255, 0.05680300353560597, 0.035196661556256004, 0.010767920830403455, 0.039651685001445, 0.1129899502848275, 0.06939303420949727, 0.03144582122331485, 0.04829426557989791, 0.03463719353021588, 0.009562161849316908, 0.04291717188607436, 0.08674504802911542, 0.09160925459582359, 0.021600401087198406, 0.023316240949498024, 0.013128200916980859, 0.06623479508562014, 0.04724493184767198, 0.05109115671075415, 0.020013292305520736, 0.029729983216384426, 0.03773962685954757, 0.06683779749437235, 0.05007828840462025, 0.015348107481258921, 0.009407186571479542, 0.05143430724274367, 0.03119096771115437, 0.025751875000423752, 0.029216762122814544, 0.023302954650716856, 0.019745744357351214, 0.09783645989955403, 0.08893590507796034, 0.022301919889287092, 0.03901653646607883, 0.025169140644720756, 0.07210349853266962, 0.018883192497014534, 0.0332122699910542, 0.038091089445515536, 0.010692908253986388, 0.07451098106685095, 0.03390198493434582, 0.016413519842899404, 0.04686375366873108, 0.01693267626251327, 0.0526479710242711, 0.06300905020907521, 0.004409212988321087, 0.049236752311117016, 0.02740375100984238, 0.013012987128604436, 0.08832663152134046, 0.011131826449854998, 0.032786733645480126, 0.018442085893184412, 0.023630423602298833, 0.03722253175510559, 0.05380530950787943, 0.060626630001934245, 0.026681934468797408, 0.035752756521105766, 0.028596399024536368, 0.026697963003243785, 0.030496284089167602, 0.042072945507243276, 0.0284009006281849, 0.041193545039277524, 0.012185594514448894, 0.006902027198520955, 0.021910416580794845, 0.016925249219639227, 0.02208837802754715, 0.02822788188495906, 0.022940150192880537, 0.02530883881263435, 0.029569864855147898, 0.0111318923154613, 0.017135566449724138, 0.031691327385487966, 0.05943746080447454, 0.017333588148176204, 0.06103481493482832, 0.011396561658330029, 0.032543769339099526, 0.045589931396534666, 0.028308310284046456, 0.056604378842166625, 0.03804944011790212, 0.04565883238683455, 0.04183319098956417, 0.027880551206180826, 0.03237950608308893, 0.08228592792875133, 0.05489347240654752, 0.04954066178470384, 0.029590850936074276, 0.03742067034181673, 0.05489470808242913, 0.045562019222415984, 0.06310167023912072, 0.06671390336123295, 0.014669811407657107, 0.01932926035806304, 0.009319150231021922, 0.03524989580910187, 0.21905469795456156, 0.166564937971998, 0.17480055073974654, 0.14485388266621158, 0.07786738846334629, 0.05037501017795876, 0.11679436996928416, 0.31882224837318063, 0.08868168981280178, 0.13188354583689943, 0.1588893646840006, 0.14218145341146737, 0.11923090016352944, 0.19904169137589633, 0.17320744169410318, 0.21621596824843436, 0.13334805553313345, 0.16281520714983344, 0.1410298331757076, 0.16333894076524302, 0.1406969502568245, 0.33647046075202525, 0.16627864708425477, 0.105901118949987, 0.155104456061963, 0.1278750874917023, 0.18847619503503665, 0.1822638401063159, 0.14724331616889685, 0.15877667698077857, 0.12251620239112526, 0.1263004430802539, 0.08144741237629205, 0.11425278877140954, 0.08955012875958346, 0.18290423933649436, 0.2070318313781172, 0.1708847569534555, 0.14731839182786644, 0.19869764655595645, 0.13693657703697681, 0.13970177475130185, 0.2999201329657808, 0.1433793391333893, 0.19056819059187546, 0.08755568851483986, 0.13321479549631476, 0.1157468582096044, 0.1605889422353357, 0.12855136214056984, 0.1117193563550245, 0.17901835410157219, 0.2286969032138586, 0.10800716336234473, 0.15146361314691603, 0.23521337541751564, 0.15403672819957137, 0.23256226064404473, 0.17883102118503302, 0.18169231218053028, 0.12944170186528936, 0.13594144606031477, 0.15139604802243412, 0.08182005214621313, 0.20882575074210763, 0.11964178280322812, 0.12383378169033676, 0.11804548994405195, 0.12061919129337184, 0.10493214125744998, 0.15988982428098097, 0.1192532388085965, 0.10206788909272291, 0.17966574436286464, 0.11710532984579913, 0.09122710791416466, 0.2321292768465355, 0.23447082698112354, 0.07483652414521202, 0.22656762215774506, 0.20349906000774354, 0.18105878523783758, 0.10154562492971309, 0.2306120449793525, 0.09925060003297403, 0.12889509525848553, 0.2201736785355024, 0.11470799989183433, 0.1957813772605732, 0.11189867407665588, 0.11720736772986129, 0.20613549510017037, 0.16710204508854076, 0.14250863663619384, 0.14466975582763553, 0.12343953058007173, 0.12248089100467041, 0.07561770136817358, 0.13778318942058831, 0.1682722190162167, 0.13110442436300218, 0.2028753442573361, 0.15554918063571677, 0.13586852262960747, 0.09558558536809869, 0.1602850476047024, 0.1424585416680202, 0.28190040146000683, 0.19450835650786757, 0.1552892359904945, 0.08995718933874741, 0.19228785065934062, 0.15130412561120465, 0.18484547501429915, 0.09489543997915462, 0.0797880147001706, 0.2417620419873856, 0.20552567235426977, 0.09717302440549247, 0.0804601184790954, 0.09391492189024575, 0.10695664590457454, 0.1599956545396708, 0.076181132462807, 0.052649707649834454, 0.10008659228333272, 0.07162082052673213, 0.12885007658042014, 0.1711014937609434, 0.1212180673610419, 0.08053447425481863, 0.1342307956656441, 0.0993645642301999, 0.12621119240066037, 0.13514583406504244, 0.14100973581662402, 0.1559630170231685, 0.17824414564529434, 0.10707981273299083, 0.13063820719253272, 0.14768812980037183, 0.2052367987926118, 0.129152204899583, 0.13489218283211812, 0.10044346883660182, 0.1621921148034744, 0.12696165213128552, 0.14604206109652296, 0.08756225652177818, 0.15017398312920704, 0.08798173323157243, 0.06204871111549437, 0.18465907720383257, 0.10551449711783789, 0.15143291791900992, 0.10842191259143874, 0.15557505190372467, 0.13545208872528747, 0.13303524028742686, 0.18318987713428214, 0.14863085030810907, 0.1424023462459445, 0.12762060505338013, 0.15976493566995487, 0.11535444762557745, 0.12595939653692767, 0.1770754560129717, 0.16144410416018218, 0.12377117411233485, 0.1404651626944542, 0.12197912496048957, 0.14677580766147003, 0.0983161767362617, 0.12055397135554813, 0.08288565004477277, 0.2873879304388538], [0.03822924023552332, 0.028631510031118523, 0.01494848507718416, 0.03141800181765575, 0.01887443329906091, 0.048857696674531326, 0.060919295938219875, 0.046936194703448564, 0.0351733135903487, 0.04775449415319599, 0.044103383625042625, 0.06677743120235391, 0.04105160929611884, 0.027364712186681572, 0.022711253295710776, 0.0036122681422057212, 0.053934509996906854, 0.02713300440518651, 0.04628704184142407, 0.03558071926818229, 0.02307715250935871, 0.02307325066794874, 0.013717346500925487, 0.04818831286684144, 0.03463963519607205, 0.0641377380816266, 0.04580957742291503, 0.0449223584291758, 0.06115339529060293, 0.07360032133874483, 0.03201042862201575, 0.009951894207915757, 0.05563415434153285, 0.03054658129258314, 0.0403069457388483, 0.04193937005766202, 0.04203397904348094, 0.02357648430916015, 0.10107141482876614, 0.03566681582015008, 0.033395817954442464, 0.03868757950840518, 0.020131089695496485, 0.03239190366002731, 0.02409049393463647, 0.006895952719787601, 0.004699835699284449, 0.06516813591588289, 0.031652572433813475, 0.06486643804237247, 0.07722186841419898, 0.06756066417437978, 0.035200873244320974, 0.034902092011179775, 0.0036471265866566682, 0.022501173552882392, 0.020483075495576486, 0.041854538867482916, 0.018385124203632586, 0.05241993501840625, 0.07281736296135932, 0.14646143390564248, 0.046567618192057125, 0.004336909250923782, 0.02886526614020113, 0.009292411577916937, 0.0483335734315915, 0.03017789902514778, 0.023548293829662725, 0.059599697997327894, 0.014635087245551404, 0.028604065410036128, 0.042388940855744295, 0.07534459844464436, 0.04650028313335497, 0.07266534143127501, 0.009430655136384303, 0.050087550407624803, 0.01262772713744198, 0.035892907399102114, 0.009489766271144617, 0.04939304861181881, 0.0371452667604899, 0.05585988226812333, 0.02865527359972475, 0.07240124075906351, 0.015277352977136616, 0.03230945105315186, 0.06476586961071007, 0.029718726691498887, 0.016694105470378418, 0.045127009361749515, 0.010925615151791135, 0.08370627983822487, 0.05297951807733625, 0.024766857641225215, 0.0582557353482116, 0.027650440897559747, 0.026837334626179654, 0.01966241601621732, 0.04124975901504513, 0.06562458642292768, 0.04097784352779854, 0.0522710861696396, 0.05987507560348604, 0.042219868482789025, 0.06508670005132444, 0.031284726937883534, 0.01859709642303642, 0.036182716066832654, 0.032431708750664257, 0.04083500236447435, 0.01838696658523986, 0.09818719889153726, 0.03039597169845365, 0.02708252166485181, 0.06826352255302481, 0.003908226663043024, 0.04766498372191563, 0.06521105431602336, 0.008108676756819477, 0.11914064758457243, 0.08422293336479925, 0.01843508372985525, 0.07302824422367848, 0.06972928647883236, 0.09215399841195904, 0.01241309617398656, 0.027697650766640436, 0.06361521416692995, 0.0502581664477475, 0.019190662424080074, 0.025595753104425967, 0.026193790545221418, 0.04598414911015425, 0.07483290246454999, 0.04538244174909778, 0.012582525705511216, 0.016845549980644137, 0.02740808886301238, 0.05268317479931284, 0.044731222005793825, 0.016609615668130573, 0.021317691061994992, 0.019984259488410316, 0.028593111310328823, 0.03068243142479332, 0.05922550713876262, 0.03290097614808474, 0.02506118227756815, 0.004547842927422607, 0.04859503576881252, 0.030132078827591613, 0.03128833377559204, 0.051366675324970856, 0.02018768402194837, 0.024242383733508177, 0.05331454951374326, 0.04001049113867339, 0.045764670067001134, 0.005801885108667193, 0.05336847396392841, 0.05979305715300143, 0.04155292634095531, 0.0206749781864346, 0.013573401392932283, 0.042561950322124176, 0.031238123774528503, 0.06707818654831499, 0.025549435667926446, 0.014408803635888034, 0.018366121512372047, 0.010868433600990102, 0.0818275181518402, 0.046789457264821976, 0.06843250957899727, 0.06978899968089536, 0.09443802468013018, 0.04343679400335532, 0.04170864376646932, 0.04149964755924884, 0.009797133225220023, 0.030150498932925984, 0.01942125141795259, 0.07267273322213441, 0.048532083092140965, 0.05007019528420642, 0.02683302831428591, 0.03066064753511455, 0.06304596463451162, 0.06061906009563245, 0.03347550235048402, 0.0790120918827597, 0.049856590339913964, 0.05038069131842349, 0.020916499015584122, 0.06307895309873857, 0.06068138936825562, 0.007910553940746468, 0.0387133134790929, 0.031016859866213053, 0.054162338201422244, 0.03194415112375282, 0.10407789959572256, 0.16769654990639538, 0.06876166691654362, 0.014083220667089336, 0.016834137604746502, 0.04376434088044334, 0.029984276407049038, 0.06428430482628755, 0.05667195138812531, 0.051613435716717504, 0.027401737934269477, 0.021631647359754425, 0.022618152725044638, 0.044785168720409274, 0.04492778352869209, 0.03270828863605857, 0.025725014820636716, 0.035491186572471634, 0.07255241624079645, 0.06120944228314329, 0.02529898123611929, 0.038047651542001404, 0.08317204483319074, 0.037222880564513616, 0.020956988737452775, 0.02217425193521194, 0.03648872210760601, 0.1087978549185209, 0.01053316838806495, 0.04541308131592814, 0.06682589344563894, 0.050150024399044923, 0.07663074036827311, 0.040670471935300156, 0.035275696573080495, 0.06506715930299833, 0.01862371169409016, 0.026636759939719923, 0.019675522344186902, 0.04303098023228813, 0.009551362672937103, 0.05083988777187187, 0.007210227677205694, 0.04474667723115999, 0.03880679068970494, 0.05997492786264047, 0.03057174752029823, 0.04670237365644425, 0.01344473153949366, 0.030476591200567782, 0.009935420384863392, 0.03590277425246313, 0.06476311624282971, 0.023148226136981975, 0.02809169964166358, 0.04059541483002249, 0.02083697974740062, 0.06551855578436516, 0.02062098323222017, 0.031029062629386317, 0.029652402809006162, 0.024816590812406503, 0.044825229851994663, 0.02163143584766658, 0.013882886250939919, 0.04308459298044909, 0.04265196170308627, 0.05278013268252835, 0.06058606792066712, 0.07788105882355012, 0.020558353389787953, 0.01742241765896324, 0.018341231734666508, 0.11435927954153158, 0.0735827547032386, 0.05074210981547367, 0.05271994821669068, 0.030239630868891254, 0.05957848741672933, 0.05938105758104939, 0.08498829542077146, 0.0566401280957507, 0.029563024108938407, 0.05140645444043912, 0.03884624697093386, 0.03973691324063111, 0.04015405960672069, 0.024842072452884167, 0.03538969416695181, 0.06702535305521451, 0.043452353129396215, 0.04662155006371904, 0.025005504503496923, 0.028652343971771188, 0.0615889357868582, 0.042125378240598366, 0.05708665237762034, 0.06147964711999521, 0.0493248415295966, 0.05311358705512248, 0.055786457887734286, 0.03844616629066877, 0.05413774342741817, 0.015497676213271916, 0.041097392386291176, 0.0276592594673275, 0.04457284027012065, 0.06618694140342996, 0.06309652715572156, 0.0460695665969979, 0.04796571680344641, 0.03676958047435619, 0.020969416000298224, 0.05072368228866253, 0.04829619516385719, 0.06397168253897689, 0.013110400504956488, 0.04222618787025567, 0.02579352803877555, 0.03953988416469656, 0.04545253388641868, 0.01325036213529529, 0.08484196616336703, 0.006264023713811184, 0.03165482856275048, 0.014922628652129788, 0.007513462724091369, 0.002223698938905727, 0.01318737049587071, 0.033943786402232945, 0.03511805698508397, 0.046571484781452455, 0.07493049488402903, 0.02465511246555252, 0.08918753766920418, 0.050729882932500914, 0.03899386014381889, 0.04515190841630101, 0.034734017826849595, 0.05464207730256021, 0.024395488799200393, 0.027188813910470344, 0.0074081524326174986, 0.02190071299992269, 0.03019023351953365, 0.023861400368332397, 0.057247765216743574, 0.05250939721008763, 0.06718651042319834, 0.12354796577710658, 0.15087430336279795, 0.1241982207284309, 0.14022353425389156, 0.11882498249178752, 0.07230904375319369, 0.23490275692893192, 0.10032033911556937, 0.144774072105065, 0.2969757065875456, 0.12204612605273724, 0.09896519972244278, 0.24815288343233988, 0.18497765151550993, 0.10616099680191837, 0.11277078665443696, 0.12796948867617175, 0.07507384070777334, 0.09582462371326983, 0.07521478939452209, 0.14978613675339147, 0.20781230356078595, 0.13644895632751286, 0.14147576002869755, 0.16829224216053262, 0.13792655750876293, 0.2213501013466157, 0.11442369053838775, 0.41826181404758245, 0.18201201455667615, 0.07960884540807456, 0.17732158186845481, 0.16808196203783154, 0.14306529192253947, 0.17879404738778248, 0.15149957762332633, 0.20738910126965493, 0.14960388012696058, 0.18449415714712813, 0.12685236346442252, 0.1289024276775308, 0.24117072840454057, 0.09277590332203545, 0.10678045262466185, 0.10935683312709443, 0.16673307894961908, 0.13004683423787355, 0.16383782727643847, 0.0984736233658623, 0.18672839272767305, 0.23185803671367466, 0.1480080102919601, 0.08813834123429842, 0.06282634087256156, 0.26212917175143957, 0.1246147436904721, 0.13951795961475, 0.19426488754106686, 0.14955957391066477, 0.2200763236032799, 0.16980298765702173, 0.19398175820242614, 0.13131893472746015, 0.12535457586636767, 0.08814105749479495, 0.0704099249560386, 0.15695268579293042, 0.10836153887794353, 0.16932329308474436, 0.08437376745860092, 0.20365758275147527, 0.10843998388736509, 0.16957669198745862, 0.1514643256086856, 0.12840790499467403, 0.17988902691286057, 0.18291269982000813, 0.09922528537572362, 0.13656580005772412, 0.09196324419463053, 0.13574174896348268, 0.23668287234613672, 0.16926475247601047, 0.10107855428941548, 0.14930991543224081, 0.146154303511139, 0.16651983023621142, 0.15774316212628037, 0.10341287590563297, 0.13020601007156074, 0.12169140172773041, 0.12445624321117066, 0.11555645280168392, 0.2399159941705875, 0.15388245054055005, 0.09478548337938264, 0.141808568732813, 0.12155336968135089, 0.15004327608039603, 0.11408311896957457, 0.21057721925899386, 0.16000729141524062, 0.1534001881373115, 0.1394724808051251, 0.15107879473362118, 0.15771436679642648, 0.1779906131559983, 0.18976131279487163, 0.16806772764539346, 0.19459950708551332, 0.10416569566586986, 0.07840322650736198, 0.11973636210313998, 0.1870013546431437, 0.14168652996886522, 0.15446260222233832, 0.18232000584248453, 0.15071251516928896, 0.07037580842734315, 0.1060063777549658, 0.1172773670987226, 0.17407701612683013, 0.09424966017832048, 0.18546219973359257, 0.23768456390826032, 0.10653835663106292, 0.20136700331931934, 0.12272205931367353, 0.15637240052456036, 0.2240202299435623, 0.17936959775397554, 0.17233394872164354, 0.07622986930073239, 0.16896960034500808, 0.16297769296215847, 0.1963734329910949, 0.15090329165104777, 0.13949792162748054, 0.1256237825145945, 0.08656347417854704, 0.15661091194488108, 0.1231579745945055, 0.13162205752450973, 0.08133746319799684, 0.14816338632954285, 0.14733019197592512, 0.1583254215074703, 0.1443802291760221, 0.13539920328184962, 0.1660470524802804, 0.16994528705254197, 0.16114017984364182, 0.07504537192289717, 0.13723782962188125, 0.11173494887771085, 0.09772222852916457, 0.13918757031206042, 0.17125142243457958, 0.0669403474603314, 0.12501268327469006, 0.10736234835349023, 0.1953170748311095, 0.10350766300689429, 0.12382599656120874, 0.17475355794886127, 0.14515351736918092, 0.11413450527470559, 0.21844368777237833, 0.1260491370339878, 0.09478886015131138, 0.06910673590027727, 0.13443500502035022, 0.10756339615909383, 0.2439273172058165, 0.15267086477251723, 0.11747247030143626], [0.08115039745462127, 0.041417105894652195, 0.057511962368153036, 0.06011680052324664, 0.03645572251116391, 0.01816295673052082, 0.05534386698855087, 0.06306661118287593, 0.027901915782422293, 0.030023142680875026, 0.03351477309479378, 0.046174550807336345, 0.05248276524071116, 0.016699057450750843, 0.023296932122320868, 0.028977265501453076, 0.03612991968111601, 0.09974802451324649, 0.02634612377732992, 0.01627931542316219, 0.01832255002227612, 0.05765439163951669, 0.000990334035577689, 0.02520103629649384, 0.0779215652437415, 0.011245801779296016, 0.009153330320259556, 0.04324545348936226, 0.027488329869811423, 0.044341175162117, 0.01888362479803618, 0.025168207394017372, 0.003456956114860077, 0.014218992873793468, 0.010418730144010624, 0.055411291104974225, 0.015183942559815478, 0.020131833698542323, 0.027593497761699837, 0.05283051708829589, 0.02282958317664452, 0.026543937674432527, 0.01874798061180627, 0.06774605266400613, 0.041111656464636326, 0.021634974036714993, 0.06540088084875606, 0.03829516892437823, 0.07623040364705957, 0.07969632977619767, 0.051421631360426545, 0.006438151503971312, 0.021287925374053884, 0.03136183979222551, 0.011677364364004461, 0.014113919605733827, 0.007888673571869731, 0.00682196384332201, 0.027533432039490435, 0.00461866886325879, 0.011437185894465074, 0.01602160464244662, 0.16127652721479535, 0.017125658778240904, 0.022336949259624816, 0.07387953213765286, 0.028010464156977832, 0.04929615381115582, 0.013110998861520784, 0.004711892352133873, 0.07175307866418734, 0.028589009089046158, 0.04918762584566139, 0.009463021124247462, 0.01830491288274061, 0.01380383731884649, 0.020451122327358462, 0.016718514707463328, 0.08652204007375985, 0.02450749929266749, 0.08872270831489004, 0.032874533426365815, 0.05292423549690284, 0.07410064761643298, 0.01934047420945717, 0.01566357590490952, 0.03642404393758625, 0.030506612929457333, 0.05434010483440943, 0.023647813977731857, 0.0818672230525408, 0.03209875903849024, 0.03391402628039941, 0.01422757952241227, 0.04713361711765174, 0.031654305348638445, 0.07123140079784207, 0.04227299883496016, 0.05086858291178942, 0.03468810115009546, 0.08615602026111446, 0.03170660449541174, 0.04327359201852232, 0.042208532177028246, 0.04990631794498768, 0.03159275162033737, 0.020806533138966188, 0.052002532611368224, 0.036181272589601576, 0.05406279393355362, 0.023838872475607786, 0.04163525278272573, 0.018110690980392974, 0.03726271534105763, 0.038608956383541226, 0.034819260908989236, 0.06681735132588074, 0.008100180093606468, 0.021610277217405383, 0.025352961347380187, 0.01230626958204084, 0.062446190568152815, 0.005440080230982858, 0.037713295459980145, 0.05011333261791151, 0.03919033631973434, 0.06253131490666419, 0.06148204796772916, 0.04798197354830336, 0.04962057253578678, 0.0176482606184436, 0.038122430341900326, 0.04343253778642975, 0.023608506126038264, 0.04342258187534753, 0.05477836159116123, 0.0491555316693848, 0.013955065678601386, 0.02224404721346218, 0.026550566908554174, 0.015070677836774848, 0.0059127610438736156, 0.09575485441018827, 0.03698749358591158, 0.029689118709939066, 0.011602526192291407, 0.11703242867952213, 0.0205820909832255, 0.013768867320322897, 0.04327785936766304, 0.034510586847318336, 0.03901776472048368, 0.07684254189371131, 0.034833098252420314, 0.046872885795892216, 0.06734771974151954, 0.027249829581705853, 0.013268587426864542, 0.033677778410492465, 0.027850000697071664, 0.025902660854626447, 0.024181776243494824, 0.03607768732763361, 0.03272637848567683, 0.029646519433299545, 0.027012963873858098, 0.12473411072278395, 0.03630224266089499, 0.07521893057855777, 0.035723812761716545, 0.04440349330252502, 0.07709263823926449, 0.01614770109881647, 0.03154572914354503, 0.06553382918355055, 0.028499255604401696, 0.01886488556920085, 0.03556775023753289, 0.043544216168811545, 0.028796394835808314, 0.0320761272450909, 0.04273909726180136, 0.06003222908475436, 0.05237207020400092, 0.05358143323974218, 0.04224316820909735, 0.05848937827977352, 0.02980961751745781, 0.0033364362025167793, 0.04098568431800231, 0.014985901379986899, 0.023587701871292666, 0.0147847218431707, 0.02088311164698098, 0.04239046967995819, 0.032958548254100606, 0.04311901007895358, 0.0698939170979429, 0.1068726644734852, 0.03432614088524133, 0.0377755839144811, 0.05176648141059559, 0.07143091977923177, 0.05128155469719786, 0.031205832929117605, 0.03943754200008698, 0.01889029299491085, 0.04653789888834581, 0.03230833412089851, 0.020737517115776427, 0.048150255533983, 0.022448811323556583, 0.05679879555827938, 0.09599526572856121, 0.07692040060646832, 0.03184888162650168, 0.034930126639665104, 0.03996460043708794, 0.019011995937034953, 0.04322698514442891, 0.01550238050185726, 0.00558778385311598, 0.033609441452426836, 0.06179890420753509, 0.05591629662376363, 0.019443931450950913, 0.013591542265203316, 0.06819810965680517, 0.039559146607643925, 0.0725552809308283, 0.015075410883582663, 0.05376934503146913, 0.06749016014509834, 0.052558442039298825, 0.012069474378222367, 0.026291813410352916, 0.021931805276835803, 0.07874721195548773, 0.03587060586141888, 0.018297988644917496, 0.03983767091995105, 0.008759122811170528, 0.08392303148866631, 0.02707145624299301, 0.012809173895220738, 0.04498657646763604, 0.023782179814588744, 0.048415903584100306, 0.028467261618061457, 0.049337714081048034, 0.022173624820425175, 0.022117314365459606, 0.007082068514137063, 0.05405839670856949, 0.023848581622587517, 0.032752398183220066, 0.03196140976797324, 0.01535034320113482, 0.02915324170317035, 0.056866624145186506, 0.04989545290300157, 0.0551988958613947, 0.08384730273974128, 0.07285702333319932, 0.04393542076286394, 0.03002465109602781, 0.039654865104239434, 0.031140935825533234, 0.017924725470948033, 0.027682505387929268, 0.04590067233948503, 0.0688265603093896, 0.006630497164223925, 0.06887655137688853, 0.05359731520002242, 0.009902597976179095, 0.09404420401551761, 0.06200702839123551, 0.049948063751799054, 0.06560788810020313, 0.02406620158581063, 0.01631980514503084, 0.0557420589029789, 0.013879690377507359, 0.02500795915693743, 0.04618760518496856, 0.014435619286814472, 0.001494127882324392, 0.0460261435364373, 0.02444454476062674, 0.044730431618518196, 0.06551419937750325, 0.06137760923593305, 0.030321281956275925, 0.06530457976623438, 0.016168789225048386, 0.031687928349128924, 0.022952163708396256, 0.05313561028742697, 0.02659383782884106, 0.022026267688488588, 0.09852077200775966, 0.07016177303739823, 0.007676398463445366, 0.0605285737401573, 0.08470675427815877, 0.08794589492026716, 0.04320135136367753, 0.09589219625922851, 0.04625157831469551, 0.01226761853104108, 0.06202907759870868, 0.030854320248181466, 0.00877807819051668, 0.03164046800520737, 0.031253938941517845, 0.025916004669852555, 0.010110754628840368, 0.046853237436152995, 0.017114908769144677, 0.05046521451731678, 0.06407107095583342, 0.030013364885235205, 0.03727069342858158, 0.010755827534012496, 0.03525369931594469, 0.058718382788356394, 0.053096217088750564, 0.10789043095428497, 0.05418119617388584, 0.050039136403938755, 0.03158467334287707, 0.01204606704050093, 0.042467022212804295, 0.04268953292921651, 0.0863716661115177, 0.03457083068497013, 0.0532802585803438, 0.04270256504241843, 0.05777314639999531, 0.023756907830829732, 0.0322130572021706, 0.07200284846476279, 0.03413145699596498, 0.06366210305714048, 0.0688615748367738, 0.012076055372745031, 0.06762204720871523, 0.023397971817757934, 0.042602504981914535, 0.01288228193516261, 0.05110355057695415, 0.1202688753255643, 0.14387533126864582, 0.08674872166011482, 0.11622847494436428, 0.09510271440376528, 0.1472804680815898, 0.18741235602647066, 0.1528813230106607, 0.11860697661177255, 0.10100729326950386, 0.07845669824746437, 0.08662632666528225, 0.125431788910646, 0.13409188046352938, 0.13103915989631787, 0.143316108151339, 0.09225032175891101, 0.1768749425536953, 0.11211173725314438, 0.15076272888109088, 0.13512411882402375, 0.1533823023783043, 0.1348215897451155, 0.1034752385749016, 0.11986424156930298, 0.11338437208905816, 0.12704702880000696, 0.12724579079076648, 0.08839142101351172, 0.2648695668904111, 0.1392444336670451, 0.07938726979773492, 0.041705571275088005, 0.15899945487035438, 0.15356182790128514, 0.20274003589292988, 0.09996517692343332, 0.1407487818505615, 0.15211275487672538, 0.12740400183247402, 0.10195844457484782, 0.1650489677558653, 0.12750122317811474, 0.13245498470496386, 0.09041714278282598, 0.16484181949635968, 0.11256447702180594, 0.13220263965195045, 0.18725883535807952, 0.16544034675462171, 0.16744659456890076, 0.13123505719704553, 0.2641370374476537, 0.1740426101605408, 0.06861864763777703, 0.16105119633721188, 0.25804658769629896, 0.11128274345537648, 0.1390906161395833, 0.11821336374850944, 0.1054978952743113, 0.16384052869398147, 0.21575708349701017, 0.08312440637382679, 0.09427372802747414, 0.18300328636541963, 0.17025817651301622, 0.09835156233748421, 0.0904135953169316, 0.0887452473398298, 0.14510557462926954, 0.12090236516087316, 0.1079038564057555, 0.1035199010220822, 0.13511626690160483, 0.06914831843459979, 0.07785633046296425, 0.10135677803191356, 0.1346685440512374, 0.14796435716561973, 0.22310081287287176, 0.14340578927658498, 0.12745728803565726, 0.2210745567572303, 0.1658928341930732, 0.17055601521860808, 0.23139196797274053, 0.14314211905002594, 0.14012784173246473, 0.12389250041451305, 0.16138594946824014, 0.12758220633259043, 0.12119470455218107, 0.13345442013815045, 0.11819898834801279, 0.13535909762140363, 0.22399829205824062, 0.18608300626510754, 0.1715167105430737, 0.09082349090022035, 0.28139027883298695, 0.10990660128300078, 0.16264909965684637, 0.12966960057383403, 0.16205622756388038, 0.11793751487857662, 0.252041217754595, 0.1671019708737731, 0.09253276832168922, 0.19396022107684985, 0.09992662977310829, 0.127219429705292, 0.1057757627859246, 0.18004919722443447, 0.07393197971396148, 0.16003098076907918, 0.14642325782915577, 0.12947278300998732, 0.12031649152049795, 0.11833423734060489, 0.1580703305080533, 0.11874834832269698, 0.17087003274355084, 0.08295266597997397, 0.06133986731583718, 0.1628424142836593, 0.20719158608699217, 0.16610358929028735, 0.20685600175056607, 0.16966609109658748, 0.14805301412707195, 0.1393959208508022, 0.18693312158575282, 0.14852461928967386, 0.12360378270386718, 0.21192507818341255, 0.21629343362292275, 0.09116775836446323, 0.09821327053941786, 0.13966392521979287, 0.11759651286411099, 0.1640703421435319, 0.2082533173961565, 0.09418596906471066, 0.12723488121991977, 0.17701773176668212, 0.1813540857983753, 0.08042096276767552, 0.0725688028614968, 0.1401322946185246, 0.12053056401782669, 0.114690500049619, 0.23927847447339445, 0.14157192752463743, 0.10668358750990592, 0.10410161863546818, 0.1202822414052207, 0.09709811944048852, 0.21100233629113063, 0.32291448034811765, 0.10419585654744878, 0.08390142014832236, 0.13548086921218783, 0.16791732399724424, 0.11123399177449755, 0.09578609140589833, 0.23181281023425981, 0.10115974524524063, 0.1492747079464607, 0.19427282852120697, 0.13652573892613873, 0.22541337471920997, 0.11619735669228248, 0.1335070384084247, 0.1444864453515038, 0.1272893400164321], [0.050685862443060614, 0.02442084612994222, 0.020946132972312625, 0.04477275630051736, 0.023200703399197664, 0.039216686272993684, 0.04141068260651082, 0.029328824566619005, 0.06220310751814395, 0.012924627953907475, 0.028294432122493163, 0.07170334734837525, 0.028749043958669063, 0.026066942664328963, 0.00634109250313486, 0.03204042252036743, 0.05544129613554105, 0.027513490531418938, 0.0194951915909769, 0.04585212474921718, 0.08017770160222426, 0.007492778604500927, 0.038323864064295776, 0.01540017748993705, 0.0037064953858134686, 0.07079453556798398, 0.047256817342713475, 0.030721913681190927, 0.009175626291835215, 0.026079752133227885, 0.03109096516709542, 0.05420572044386063, 0.07640664887730964, 0.014351342852023663, 0.03214080170437228, 0.05328601393557619, 0.016237962954619434, 0.01374242367091938, 0.0831575803749729, 0.05276983909425326, 0.011367441638867604, 0.14006418030476198, 0.035196813696529716, 0.047561301980749704, 0.05845372550538741, 0.054371185979107395, 0.03863294259645045, 0.04398550830956083, 0.021551521385845263, 0.021326186797523405, 0.03214709511667024, 0.014532286804751493, 0.02769864338915795, 0.005946012970525771, 0.03824459156021476, 0.023023808789730538, 0.030355867893376853, 0.027189570901100524, 0.020724974820041098, 0.025538496411172673, 0.042087220717803575, 0.056854126378311776, 0.028942364151589572, 0.049963934579864144, 0.017472135987190995, 0.1128236943623051, 0.03669143232400529, 0.044244844393688254, 0.01970875571714714, 0.039531445945613086, 0.012697411093540723, 0.010507060560485115, 0.05860235542058945, 0.06768173814634793, 0.042323264497099444, 0.01901838582853088, 0.034538814434199594, 0.029107941008987837, 0.032200841451413, 0.06315973587334156, 0.02054026539553888, 0.026211414697172586, 0.029399367558653466, 0.04301948065403849, 0.023291662873816676, 0.01641048445890192, 0.010363086694269441, 0.046353011348401196, 0.02977500931592658, 0.04153961592237465, 0.04821900438400917, 0.025902850102283992, 0.057629370130598545, 0.027643245775834657, 0.04426430350576993, 0.027422725870565046, 0.053292051306925714, 0.03515097494528163, 0.03625069679401349, 0.047356587965623476, 0.05985293733829167, 0.007337516672123456, 0.028964778866793495, 0.02520746515074279, 0.03471261057711672, 0.05499146558577195, 0.030132184583635535, 0.01698768053756794, 0.05687326265615411, 0.03219727172108833, 0.02070030583126936, 0.05127666765474714, 0.011075095753767528, 0.016823398727865424, 0.031360077191493474, 0.01508609688244178, 0.03454544181295205, 0.08420786034548655, 0.02646845383424079, 0.008491582284477772, 0.023748831408738624, 0.031668020237702876, 0.04920321465760935, 0.02594149929791456, 0.06452547313529067, 0.051514492588466965, 0.05526147746422794, 0.030031441747269128, 0.06162354213302024, 0.02153037017706083, 0.028907412706757896, 0.03513894473144319, 0.09181042856653221, 0.03844619226583745, 0.03943264011468273, 0.06766379301552661, 0.0570601020444883, 0.048599136134725995, 0.052972282137488946, 0.05734486039727926, 0.04409448527439963, 0.07208098177216016, 0.08599139706348069, 0.008279746434709523, 0.039794444528524764, 0.05602155542874243, 0.013708036258321954, 0.023667102395847905, 0.05807791305414867, 0.027373875855118968, 0.054822801394038834, 0.045559566424344666, 0.035541314937290736, 0.021038454287918285, 0.1183065700752195, 0.00591912959862384, 0.08923202942241915, 0.014775490453757811, 0.05032349770772271, 0.07445097100571729, 0.027426649976405315, 0.04142171092098579, 0.058518808145890944, 0.0232925868476741, 0.05561145575484261, 0.0466905438224785, 0.03161368760629557, 0.007754941343591781, 0.045403689437080175, 0.022571603367396165, 0.04397741889988538, 0.025386836678080726, 0.04321966385759879, 0.017975993032450788, 0.005147088213561801, 0.020675590458267834, 0.01538873078970937, 0.021772612744825892, 0.009528193750156788, 0.05030825770518277, 0.06463180063292384, 0.01326063809756306, 0.04806804041436408, 0.029936751125205774, 0.042709010594990104, 0.007619933085152297, 0.04150528788159136, 0.03648488891485613, 0.05053947381384205, 0.04600914093316533, 0.01223432114784373, 0.049170983184012584, 0.05454096710309386, 0.05442396752187051, 0.0945030219736509, 0.05283620936097577, 0.035244103346485645, 0.02051376515737502, 0.026638346280378755, 0.02114929404342547, 0.030171190010150895, 0.039289387059397995, 0.05174338206415996, 0.07274713352671824, 0.02352393468754599, 0.013951389264548197, 0.04754733105073683, 0.04084016771230381, 0.044721960002789274, 0.012154087562521454, 0.04745874830405228, 0.10071082011563703, 0.012862087169196457, 0.05081486997369211, 0.03287635539891198, 0.07262309838552028, 0.05000776953238528, 0.03567166204447858, 0.02932785606390098, 0.01925387856317684, 0.02410788059933111, 0.04946281420416199, 0.017244758637389168, 0.05342730029951781, 0.08190471635316499, 0.031707402304164134, 0.019888607785105705, 0.06542090399307199, 0.04699290220742114, 0.013562055810325546, 0.029439085446938407, 0.012530571657407563, 0.04170429478108417, 0.02366482585784979, 0.010353102024964755, 0.0281374196492834, 0.05956547385721933, 0.028494340731413104, 0.07666156918276101, 0.02834915809216909, 0.03657682616903912, 0.15277154452633113, 0.020971699959773105, 0.03223321764380671, 0.022548047600139398, 0.06298059626715258, 0.010826875186467078, 0.008911124859878328, 0.04719959033536725, 0.04179726733127609, 0.06452404079027474, 0.06310005235718563, 0.0456147785007488, 0.07147455064114183, 0.015903712628642097, 0.06736490788171068, 0.01443450420993031, 0.051061808480881155, 0.048627011201460846, 0.03130241973849479, 0.04023732486530207, 0.016908686338865664, 0.009686838948255172, 0.07474114332580939, 0.07400394577416591, 0.05032762033806648, 0.06618411382078193, 0.08339957988937385, 0.04372712588519789, 0.03770300929318182, 0.03119106790109072, 0.021726039267377928, 0.05514461518032476, 0.011003016516042408, 0.024401105001743417, 0.016397845683968626, 0.04105435153178405, 0.019962766891694628, 0.024322448480234016, 0.02171397936763242, 0.01834507791500073, 0.04433180183696095, 0.03200009792635683, 0.020830743851547595, 0.012692169675574405, 0.008753344263823237, 0.04530182595772203, 0.05024298210628331, 0.04993384791305289, 0.03740273263247218, 0.04531302867690101, 0.01628224319574656, 0.041966736753238365, 0.046200199431041256, 0.05252236624073703, 0.006598516165468027, 0.02903211207012646, 0.04001802022685297, 0.053577718790620565, 0.019372739079699386, 0.028630285487452056, 0.06177933006256353, 0.02705644630623283, 0.03846204454021063, 0.10922992587438785, 0.043397178160375915, 0.04929079921566881, 0.034539927655714564, 0.008096060246316483, 0.11218682033359073, 0.08592486352426931, 0.028638708863581996, 0.07172213110607117, 0.027974711192655377, 0.06151732966827694, 0.015769337514939252, 0.049056328789447434, 0.03618911337980535, 0.07112775987479836, 0.024817794947011862, 0.04586868206388317, 0.027572457875066902, 0.05058635528257582, 0.0775854910898488, 0.027966759080300108, 0.006540614731420646, 0.05391098762629554, 0.05956246815912891, 0.03849297354463488, 0.05086251585453283, 0.05412516402429901, 0.080572947190376, 0.06668371279374696, 0.032476196793140844, 0.053089300272404216, 0.023538104142062366, 0.030072267290961463, 0.03769866030779667, 0.08805389967164956, 0.03653678359114565, 0.02773738349787891, 0.02968307577248197, 0.06352272030198947, 0.06810846563894302, 0.01322821273788577, 0.030809093768766616, 0.0720919061859604, 0.019379459226911422, 0.025157229174510576, 0.026621501383488066, 0.005032975122958305, 0.0072408468349749455, 0.17603765154490247, 0.0829501797852572, 0.08695088268723339, 0.0966709986096248, 0.16339209338184446, 0.09604220656910911, 0.1865182610345073, 0.1352133695036173, 0.1999604405136779, 0.14588745689252391, 0.14549348037689924, 0.20194926270050928, 0.14070490607991815, 0.10142397208255716, 0.11329170010867529, 0.07733107544481754, 0.17633635114179924, 0.11687431411701255, 0.11887322951224633, 0.19828738732030615, 0.18127469083992764, 0.0644772186933551, 0.08555179330869578, 0.09724056726554409, 0.15077964984811842, 0.22030169900972396, 0.08769886364461854, 0.12848348531406373, 0.11084349593147635, 0.0739624968264252, 0.09011711474158801, 0.22819543402874842, 0.1904785688384436, 0.13964169047540054, 0.11545800691237673, 0.26060206932015717, 0.1355428237002343, 0.17716384580126032, 0.16118729137815535, 0.20746947586303577, 0.1383567211451009, 0.17898405203595757, 0.1522692441358231, 0.10277736000716686, 0.1024737251282204, 0.12693552853306755, 0.08909480631700717, 0.15241273096762598, 0.17428281367756426, 0.04420286481035873, 0.12564410251798108, 0.19009121228009462, 0.18751946277916431, 0.13162607996491715, 0.14027450495632365, 0.0779622200934682, 0.11240896739764139, 0.13719419133849442, 0.18579551309812814, 0.17750274011632428, 0.13190333149395883, 0.13429574843030423, 0.24389087775489315, 0.14428496710024774, 0.12920158740598708, 0.24679551017470658, 0.10051420293166302, 0.1561788038816303, 0.09762145971762948, 0.10065976035548374, 0.07512387630413286, 0.10455312643898651, 0.110053509415593, 0.18899897870142013, 0.11826863148598932, 0.1979313642368652, 0.23176289338152856, 0.21012418263126165, 0.11626579755102284, 0.12618541019037366, 0.0975885232037399, 0.11918224496184848, 0.10348552474169992, 0.12092741264495999, 0.0746776006417349, 0.0824522135371808, 0.07853458664612845, 0.16989517724141479, 0.17876795347547159, 0.13956238457467407, 0.11407850281102583, 0.13593629555543885, 0.16916137130465358, 0.10807326645590365, 0.15855189529247582, 0.16876191773917526, 0.15212774625979364, 0.10407353576738387, 0.10049521137261763, 0.16479858197271824, 0.12801812903489918, 0.13230925658717752, 0.0924766693788115, 0.12306565884500742, 0.1399663503980264, 0.0994144959258847, 0.09335448907222599, 0.08428957080468535, 0.12527632381534204, 0.10873175924643874, 0.12395892263157293, 0.14024244417669252, 0.09685347045888193, 0.15904482977930456, 0.16668786731315777, 0.09568310357281007, 0.0755541141552385, 0.1882489345734939, 0.06570063429535367, 0.11555336546734907, 0.10629850934492424, 0.22963255847571418, 0.16768280533142388, 0.12465308303944767, 0.14971315395087004, 0.1889884253614582, 0.1318206117139198, 0.18929304729681462, 0.2469483480672352, 0.15048941073473543, 0.1125447655795142, 0.14424607856199145, 0.14727904315805063, 0.2982229896588251, 0.1955929459654726, 0.16766776941949502, 0.1498150805127807, 0.15737971756607294, 0.16416959697380662, 0.10029662007582374, 0.20079694484593347, 0.14042413677088916, 0.15641385689377785, 0.09023902734043077, 0.19776494504185393, 0.09335370239568874, 0.11545176545041613, 0.14381603366928175, 0.15140243049245328, 0.15454931475687772, 0.11547668676939793, 0.14349095814395696, 0.05304310157953296, 0.21131074317963794, 0.20414567843545228, 0.2068623248487711, 0.20804054365726188, 0.11345541788614355, 0.15115657181013376, 0.16511550871655345, 0.13073492387775332, 0.20336995599791408, 0.17943705897778273, 0.14075997343752533, 0.13720415096031502, 0.11869195994222537, 0.13895588665036485, 0.13361392251681536, 0.18929282465251163, 0.11364767866325565, 0.1933913500397466, 0.11378174764104187, 0.10443014514748938, 0.07618983785505407, 0.06845804688055068, 0.09540620827465318], [0.04309418152843136, 0.10131644972716458, 0.04837636195588857, 0.030535462065017782, 0.05760885345807765, 0.0402078170736786, 0.02617561534862034, 0.035454602402751334, 0.06033839097653981, 0.030969957988418173, 0.0075787652258441085, 0.07452574980561621, 0.03244723819079809, 0.043980881018796936, 0.01160211151727708, 0.021218475194473285, 0.05698186854715459, 0.0035755649969360093, 0.054615296903648414, 0.018364418283454143, 0.019688873580889776, 0.025447164007346146, 0.04233207379002124, 0.02569703028711956, 0.029606836797029246, 0.02891021802497562, 0.0454313715454191, 0.05168301206140313, 0.01785212487448007, 0.015248856361722574, 0.030978405484347604, 0.055603396031074226, 0.060548159017344005, 0.05129405246407259, 0.024579725104558747, 0.040948550959001295, 0.038577292652917095, 0.03270898625487462, 0.02190833300119266, 0.06426164705771953, 0.04507025361817796, 0.06150973749754485, 0.013912170470575802, 0.043677093999576755, 0.038830940175103024, 0.035671680598170497, 0.04115742471185513, 0.02102142942021601, 0.05543538492929656, 0.07284435487235896, 0.01811472640838474, 0.03175808356900234, 0.06402907281881198, 0.047606034931959584, 0.05282736667140853, 0.03185180568834767, 0.05100805843540002, 0.026605624989315402, 0.02678060485777678, 0.05855548137333244, 0.03299425297882408, 0.0025429469815207995, 0.03267227592004929, 0.04269631244824268, 0.01217358656504075, 0.03855823430058081, 0.02173210075852694, 0.05355492372473236, 0.08606463961768895, 0.05266088810458314, 0.03218936413759366, 0.023572152022097725, 0.04887789051281288, 0.009703743216959992, 0.015694195062678773, 0.06443115358706564, 0.011784907128458144, 0.025342962762806565, 0.019426181133894715, 0.06170976113935467, 0.017877803184092045, 0.052399525957298465, 0.06180467069498263, 0.01499066596807097, 0.020140190281381365, 0.011407560286897933, 0.016465423796034884, 0.006535606626130175, 0.048778468699310906, 0.011951505366596393, 0.06569238161318935, 0.06747115374309942, 0.0323011649743421, 0.033629924728302285, 0.026176999454037286, 0.02032199419772951, 0.01859058964328142, 0.046123576394165866, 0.024347353100893088, 0.09986589982872829, 0.08624099617009051, 0.009002036094898358, 0.0298592616309179, 0.059309373536962084, 0.0647585594560951, 0.015517565771006048, 0.03721202665474266, 0.03512393850542139, 0.0280593382922234, 0.06890145043144003, 0.020733236779051367, 0.10600147958029993, 0.04939706363074947, 0.026702048526203725, 0.042046287562698126, 0.04407356784213334, 0.11735322943422943, 0.02392197075096192, 0.060861861129524186, 0.046795079033472575, 0.015979805029928684, 0.03780348124564625, 0.009242121795978164, 0.02079963858705014, 0.061740007367916405, 0.015443860302184476, 0.07333164161536843, 0.02106750565872062, 0.03503628344333265, 0.025291886304330546, 0.023155491762736347, 0.01675402461842168, 0.024025569000514224, 0.022373626197804697, 0.042295860694139265, 0.08330025084433146, 0.04622031163307838, 0.07245215951115824, 0.0315922358277021, 0.07672956475289539, 0.022822816645202693, 0.02220457980001811, 0.024563668739574496, 0.035328819503774866, 0.024424998446193058, 0.038107772925286554, 0.06819780537625775, 0.07034606314846314, 0.024684991331014317, 0.02699299824598711, 0.011454895393399056, 0.02755495432211319, 0.01652114609896671, 0.048092182478285395, 0.06808401929447427, 0.0744731018494349, 0.026776148260978516, 0.05467416405736003, 0.04957734985509887, 0.0033525326898597996, 0.019816708518192172, 0.00986190509138396, 0.02693108643143205, 0.02374122996116057, 0.030112862768874038, 0.009336996099591488, 0.011954677120229462, 0.035867685510311276, 0.04447951891052071, 0.037791744180140086, 0.10793673354783095, 0.06191267915710341, 0.07114814667147584, 0.04298753119655885, 0.04686197622504551, 0.020937741137458943, 0.002188806402045884, 0.056437855746480636, 0.024788049668131862, 0.04631114308722317, 0.08925269081373699, 0.06400798098184168, 0.06293568891123869, 0.010502430486667436, 0.036051871720701456, 0.06800242757890373, 0.05689038400305435, 0.0535077082895441, 0.0386130344850244, 0.007548687372036511, 0.03350022328959312, 0.02201959021476796, 0.02330614959646482, 0.011432890714786481, 0.035751172035816126, 0.010269697613694007, 0.022400406596716493, 0.02945075942989206, 0.05482125030539464, 0.07120538110029884, 0.07511006493587047, 0.03492952178930864, 0.05877789561054669, 0.04700574136222713, 0.0833157988381572, 0.03425507282372564, 0.009468774624110665, 0.07409182348055765, 0.048228964005829766, 0.02467792794050183, 0.05966247998003382, 0.010449719447933603, 0.07018383708782494, 0.052735592689714395, 0.015966273822414223, 0.04992435955500696, 0.02570153883425519, 0.041756512291613035, 0.029269623446452897, 0.050013669606414624, 0.01596551126567647, 0.021324958543118555, 0.02177535126975272, 0.013149927290214691, 0.034103266516467556, 0.046988100511953235, 0.081577072996879, 0.03191704046912491, 0.049919821321964264, 0.03780876904784236, 0.025611429118725937, 0.047397877351613715, 0.042897764724330045, 0.020387880213093013, 0.030286924229585566, 0.04625168221537024, 0.038426788814831525, 0.05003388941986486, 0.03529148205416277, 0.044970894887228496, 0.02728382922214223, 0.043578963523032144, 0.03133686652290635, 0.08721147300093435, 0.019649304122140165, 0.010179278051509755, 0.039211465264088474, 0.04204453609418124, 0.07596697090775706, 0.036967611449654214, 0.003939006774089648, 0.023003492497082334, 0.041904240497387946, 0.033247139799641445, 0.02003752157179406, 0.024123526927724015, 0.013970576565043302, 0.054625994962407276, 0.048180249432334676, 0.05703018236090429, 0.041309910084237345, 0.03685209987452254, 0.06684146370389499, 0.024297519739775453, 0.011176174411957618, 0.057292179044452496, 0.04142394107475411, 0.02741499640251277, 0.022457353443314787, 0.03935497807106003, 0.06341223677736707, 0.04895590878732037, 0.019482528696244117, 0.013454838663164992, 0.04153964560828172, 0.0640051014488563, 0.05198531478527002, 0.034481379625503905, 0.011680556526698638, 0.045776329207001254, 0.04061448802531231, 0.05197347381908912, 0.0658256268070545, 0.029193547743489034, 0.03127735741145443, 0.07417468426865526, 0.006115064470577636, 0.028021635334880557, 0.0324901491694618, 0.018333138614252675, 0.01572797576955054, 0.021012221222918015, 0.08326999348355457, 0.03794509786530398, 0.007098047881299863, 0.04645264467399102, 0.0336255831643939, 0.02481657782482216, 0.039550289075123146, 0.02336049707082566, 0.0926101001095958, 0.023935310855449643, 0.04078370882780291, 0.046413440722972155, 0.0407990935491398, 0.03575525384803768, 0.014909582623658935, 0.012227304141561035, 0.05523764339159243, 0.0739114148018416, 0.0470167474122718, 0.04616616824932862, 0.05823328909173142, 0.058877918563666753, 0.06977705110330135, 0.04976371426892001, 0.04950336515321396, 0.025997770790127106, 0.008129168381856289, 0.011679464641929371, 0.028540394705487415, 0.04701888108684216, 0.054689385506208055, 0.017829263015300967, 0.009831165334617253, 0.038327797446982004, 0.013208035597926937, 0.009033539336087415, 0.01784166059223935, 0.027261212271696422, 0.025413377734366804, 0.053336361233959906, 0.032322802289854735, 0.03906779660610482, 0.04302813780668657, 0.04025972288218327, 0.056125611954485066, 0.018064983960357495, 0.042264705334673636, 0.03347950994793791, 0.03875309630529955, 0.03290867964096833, 0.03869594351272099, 0.029348690004553646, 0.04245948941388633, 0.025125259307969827, 0.042870349789154716, 0.06538870962685905, 0.07043610050459392, 0.1007269172987435, 0.08549024700187147, 0.024256866745417938, 0.10841565628652461, 0.17837516439612955, 0.11353195557603613, 0.1747492386493832, 0.2983921399572864, 0.16664387279888615, 0.19708139734575525, 0.0770263496087864, 0.13456523709464818, 0.20629290462238714, 0.1263962098164484, 0.15235150378430262, 0.1528944738674909, 0.1307740795891732, 0.07331534405238926, 0.11619424709351733, 0.1192819228162989, 0.16823646234115586, 0.1351916987914592, 0.12570176739245653, 0.18001534044742584, 0.12767262960551307, 0.14444580534473062, 0.20687543117674068, 0.07422246373607777, 0.06707985638058744, 0.13940737961092964, 0.09231143762008287, 0.19809462188277394, 0.08945580178988166, 0.06966117216506973, 0.129117502074223, 0.2365048014326021, 0.09105581280891784, 0.11356161179719493, 0.14679762680316344, 0.22603631863603368, 0.13605288695544004, 0.09530471957987174, 0.14905195974279195, 0.10768857420771383, 0.20037328242324293, 0.06572944446816109, 0.3066397161455825, 0.18763615807984024, 0.15892124734818935, 0.13499847322236747, 0.1721757822087966, 0.14329929108498618, 0.16404800349846482, 0.14024602132849395, 0.20945053518516943, 0.1278672949410975, 0.1553034406970255, 0.09206635819282383, 0.11862696264870465, 0.08457950563752092, 0.20469635201152414, 0.10176410578424111, 0.19033297430723906, 0.15450371720362455, 0.15458259265869856, 0.1284556250902824, 0.1699676108546555, 0.1742825613473542, 0.21135542046977207, 0.1289840045501478, 0.161592296208255, 0.22131069330498576, 0.17602120555238798, 0.15881181025179103, 0.13874277152353898, 0.18810175184626132, 0.17983222292969003, 0.05804344771604519, 0.11503943562274799, 0.07387352074147202, 0.09317892661783844, 0.18035767832770944, 0.11629350192379206, 0.09570525668095797, 0.12009679354378022, 0.09487300485488959, 0.17839971464127302, 0.16125876019941643, 0.14571924170013517, 0.1162328981445171, 0.13322334503754973, 0.10661811524187215, 0.1041297682968434, 0.11763386515667662, 0.13324995845323429, 0.1642336740042083, 0.23552282131277025, 0.1716844507609494, 0.19577728060539812, 0.13448961224639788, 0.12432498697307892, 0.07254903204739094, 0.20751355943502858, 0.2624221419682726, 0.07919797018985264, 0.14581796218408272, 0.1439656803268008, 0.13965585065307096, 0.09456342537305318, 0.11504989248351194, 0.09518170860246755, 0.11729648482287303, 0.22671254875604063, 0.15437771537108347, 0.170055718626827, 0.13907783635659143, 0.17884535947814584, 0.13089617772493511, 0.14435894438065588, 0.16204611951252446, 0.10386171939899214, 0.1302136987214908, 0.12789954867912456, 0.14516787050524727, 0.10615439168759622, 0.16768090543337166, 0.10513272151001729, 0.1882336611743085, 0.10162703110836446, 0.10214586654910818, 0.06578507585800253, 0.09979788199416362, 0.1378205491346307, 0.12580259557580575, 0.1450128506985493, 0.1555242741596885, 0.22756417805794626, 0.18587383936392143, 0.1807541781454347, 0.19896435958798975, 0.1764404893037863, 0.14339789282530546, 0.1645346891018562, 0.13179377565393224, 0.10385627203504555, 0.1132054699701257, 0.09856773511273786, 0.12511245760833845, 0.13054583949269727, 0.14814778638537973, 0.06076647659938317, 0.10940367748844437, 0.14556643349351361, 0.14730056544067338, 0.15086162748048082, 0.11420379218179733, 0.15737637790152803, 0.1379056289442815, 0.14466236403677613, 0.12266488425666466, 0.10955798483337276, 0.10694958065869287, 0.09741753980051726, 0.10559083442785777, 0.06420582270948216, 0.14665452588815242, 0.1878745062276721, 0.1247857345151715, 0.15617531578755006, 0.1287805225001648, 0.16878952563274652, 0.12852571351686493, 0.15149977058172226, 0.1531072030775249, 0.23019381507765502, 0.19041040999582037, 0.22717578249284998, 0.1338316686451435, 0.15957522788085043], [0.044689153364743106, 0.0427953483449528, 0.06459265234298073, 0.01705873746686848, 0.03256335090554785, 0.05752121323894244, 0.06084894033847377, 0.051346017644391395, 0.050956586783286184, 0.031955394661054015, 0.06399647769285366, 0.03326907397422474, 0.03598764255002607, 0.02655725365912076, 0.08381493767956272, 0.034529897529864684, 0.0465530609653797, 0.05282080608594697, 0.067574735294329, 0.016783372848294675, 0.017595818608242553, 0.061102472827769816, 0.06221151605132036, 0.03317474700452294, 0.05417538144683931, 0.04203297714411747, 0.02909331327828113, 0.01354062907921616, 0.01610708892258117, 0.04363473221019376, 0.04815057465748396, 0.01747483740473399, 0.04748059713165276, 0.026465668925084174, 0.0421166060550604, 0.031732616771478206, 0.06108447574661113, 0.023546379088656977, 0.053839229367440566, 0.012709636121144285, 0.035856646063621156, 0.0028558021176650072, 0.011226167334825732, 0.03348307225678582, 0.060624333054875024, 0.042216907313559204, 0.019632661460491363, 0.074564972310327, 0.029102337794029154, 0.07717539512668736, 0.05554736759222578, 0.022549066197825596, 0.024944822798715904, 0.04589298368955497, 0.021531346101255622, 0.06882911329739727, 0.011550520193850389, 0.017290220748691354, 0.029380836131167598, 0.021732865170633886, 0.029108972594258375, 0.011488945128803607, 0.06979772733757272, 0.09404258613358252, 0.02667735727300169, 0.03316617148811929, 0.04383545718155801, 0.047280974249588326, 0.05521150123968255, 0.03189886898326222, 0.03426526993280277, 0.021533702420128975, 0.02834147871908499, 0.0330343957466539, 0.0350362055178266, 0.03749357521883212, 0.06714733986882493, 0.08904582457034849, 0.08909675816539675, 0.03888105369696859, 0.023299798667721916, 0.03913402586476877, 0.007696501388636534, 0.0571810980909504, 0.04695087067375425, 0.0450532695685979, 0.03150374584947713, 0.08407214379985817, 0.05841088503075298, 0.02991276305692736, 0.016357096210413147, 0.08844194642733783, 0.0310606706989347, 0.047916100520524196, 0.02704504135181196, 0.02402106601948617, 0.014555788766301703, 0.1273494094493799, 0.06825063886935823, 0.04389546353195328, 0.021435536691569723, 0.05634660868963692, 0.05679606074409094, 0.03371234764927067, 0.057198052454623394, 0.07963911761180498, 0.013560807146859588, 0.06032689881976694, 0.051372434390941635, 0.035920277805416845, 0.07320714634261094, 0.025081836247409228, 0.06485051155323163, 0.06765490208636038, 0.010824853761732811, 0.04508423568040598, 0.018368596574873663, 0.01520152589364443, 0.03535896925313864, 0.07614950955030508, 0.04345695815572981, 0.043773228098871186, 0.03285287384642288, 0.05531250382773578, 0.048266750454786234, 0.04339144506957382, 0.05236260039964691, 0.05009814827644732, 0.006449001703003887, 0.041786921792663634, 0.01801513761165552, 0.01959251498192316, 0.06865366216516122, 0.029321870642888825, 0.04340955718362238, 0.06685524538625032, 0.03361786853929516, 0.017766519995348062, 0.029409625894913916, 0.06995634656050242, 0.05129161821969319, 0.034404444886604324, 0.04593798752466682, 0.02776082794298418, 0.027637915300147142, 0.06523130752611905, 0.05982937043881975, 0.01848736803367501, 0.035503684339346364, 0.002977550748255453, 0.004478935443330556, 0.019454341927485075, 0.03644594471552409, 0.011880224865308264, 0.021546775351453107, 0.055693492759019136, 0.047890852656564675, 0.0515944701328408, 0.08370218318304978, 0.0585587653768016, 0.01909378988784738, 0.05674399908457417, 0.0011476940426291549, 0.031200608209474012, 0.008749329244892579, 0.07052663509966806, 0.033156527279061265, 0.0749922044633422, 0.006676016328128753, 0.02088331944833044, 0.05329447812982835, 0.0031166909138846677, 0.0628483084437903, 0.07342771263211034, 0.06359310558764264, 0.01785276868758956, 0.012877639801445184, 0.10238152070087381, 0.06614639787585475, 0.018238167831441388, 0.08620487584266812, 0.05253321272903122, 0.10827590245753527, 0.02663373939867597, 0.03547845873981714, 0.02968099961435655, 0.031828164574108087, 0.039621186442673206, 0.06182266035466455, 0.007812078365532216, 0.06889408090501092, 0.03456052225374151, 0.014212179030437255, 0.11188978314748965, 0.11843202271847986, 0.0200341485106037, 0.048635720304446295, 0.04399675555760041, 0.025578180902812164, 0.05323282792232931, 0.03246005879191216, 0.07135644525988027, 0.05443029062007554, 0.05830126981891226, 0.03219072226784192, 0.029185781168052927, 0.054804451792733744, 0.050603420968400314, 0.08926158174290322, 0.021191527812334243, 0.013850622308382299, 0.056964773175423034, 0.05277222138829529, 0.0946455959638115, 0.014424792279896792, 0.036633221970987506, 0.016315804969053715, 0.051671104301931337, 0.009976870260288706, 0.021006406495871488, 0.03870776963594835, 0.053631643240805715, 0.046010124278836884, 0.026151441743422765, 0.012573294316098327, 0.027528470782272052, 0.05513593947398476, 0.02448255199851701, 0.050196994925499894, 0.06256355380173773, 0.021277808045851998, 0.01005757325401646, 0.027793105800810736, 0.027537296773516573, 0.04266002513759304, 0.010414765220048139, 0.009476777759118704, 0.02867250997951487, 0.04541671783954371, 0.10929107884294353, 0.025260461916332133, 0.08479011230519973, 0.049997164242086, 0.017436514754081145, 0.06207330588949844, 0.026881188132392708, 0.10960203129798174, 0.02975504925416317, 0.06553846018505283, 0.01672194714046782, 0.12236262235091999, 0.012758400789607549, 0.01074262936526793, 0.07948121827212162, 0.01942127553775208, 0.008393912867177278, 0.021716842202295084, 0.05508919159183279, 0.009867448006843915, 0.06551002850756049, 0.0753406947478652, 0.08918328516301699, 0.044453588270698674, 0.06081536186684389, 0.04612578428350389, 0.02795143002003897, 0.005583901029240224, 0.02205692209827248, 0.03236654447391629, 0.02806601391057484, 0.012304985666560242, 0.1177683868445456, 0.008921600274334196, 0.0596019986551255, 0.03434423073485959, 0.04763713834108785, 0.023783293036103714, 0.05431982935988344, 0.11129841019283049, 0.025661162289907224, 0.02890618816309143, 0.07435524137690663, 0.03452383418334648, 0.06943341446458362, 0.08106110224616714, 0.01799739657144528, 0.06477311297203414, 0.04403916929732077, 0.018816953961504623, 0.0023126209862311953, 0.007631187754668645, 0.024695075262570754, 0.012588233748829225, 0.035795778821920976, 0.06816711014835164, 0.010687037865864113, 0.02727293634961825, 0.029096333819325082, 0.014635676325269742, 0.04554732840915676, 0.06599994245334528, 0.044789265375584364, 0.050632743223104626, 0.04545751740806736, 0.02636831399286166, 0.06647926595178433, 0.023327430681092665, 0.01626056506211171, 0.04970637965016067, 0.020352988140075468, 0.028757756772392895, 0.028845905362686608, 0.043157427353435196, 0.060599237331189215, 0.02801099108182825, 0.07073534929077141, 0.040045008427114226, 0.07418086635880172, 0.010640866075846134, 0.04087603942025453, 0.01990268261579331, 0.059730041393777356, 0.07228205926367082, 0.02894099674449535, 0.026414037711219862, 0.043955002329312265, 0.06038236322638113, 0.03699794673593715, 0.06887920084409416, 0.003186856802130933, 0.06502171017928049, 0.04500079601712059, 0.008098952766886214, 0.05387357967265416, 0.08078494167421013, 0.04741936623759102, 0.06499743452877738, 0.04708460939582437, 0.09922959725372493, 0.04342110129073262, 0.05693778126442339, 0.025228525446436834, 0.05482279397256207, 0.024598750060249586, 0.014798066586081404, 0.007803708795108832, 0.020887137798126787, 0.02822288908646442, 0.03926301855244674, 0.03078860492678359, 0.11804324123659171, 0.01347099521808559, 0.14014379790751263, 0.14307011588243768, 0.1347494826768525, 0.07407728480757214, 0.19335088814841583, 0.11135963737615384, 0.18344425567192957, 0.16561760130571201, 0.07809179165633395, 0.1361800910672173, 0.1554807397769764, 0.1607954374048859, 0.13477315718773752, 0.12107391259633005, 0.18987076473422348, 0.1475709001533687, 0.23377295583486557, 0.13576417666627094, 0.15265786234522238, 0.11826554415165447, 0.12932865793118253, 0.16133569122757763, 0.11946486221859232, 0.10345869610318914, 0.21316683967597783, 0.11283650383120403, 0.2148055165889673, 0.13909777044318616, 0.10120507562533021, 0.19646013068268076, 0.09969473831006326, 0.11858927638968453, 0.28147090575657785, 0.09817297192057595, 0.0980990391690284, 0.12298821573494934, 0.2928393316688016, 0.24074719956843182, 0.17444771889131516, 0.11756868232623674, 0.11338599739247002, 0.1598079060204327, 0.10349075688282028, 0.2062413253588602, 0.18143346591386944, 0.19947359163779765, 0.09905898492434062, 0.2694547630380839, 0.0701815883803647, 0.1420537001104094, 0.18293327215360478, 0.07772645461955108, 0.14046925934962928, 0.1069472503149882, 0.193061628669966, 0.1174832165997941, 0.11659003444947302, 0.13331854774150997, 0.12140066537540406, 0.12588268815306947, 0.09243194013834, 0.07586414634715766, 0.1408817747142166, 0.17903509695315734, 0.22303158533759415, 0.1803333210409619, 0.1421412586933002, 0.1292407134314999, 0.12441219674656168, 0.11277052690275013, 0.1898888434516266, 0.11005286374711432, 0.2211694180732593, 0.1081097281712573, 0.17251044628210366, 0.12510340340668336, 0.1566447687218897, 0.32820430118590593, 0.10988343143253587, 0.13480964116752148, 0.22748782590497285, 0.16859913506777957, 0.057565014794818126, 0.237681268772576, 0.20864906022325158, 0.15073567017680034, 0.060956039669690654, 0.1792620457126759, 0.1423482139944099, 0.08102750522084534, 0.12584868294652551, 0.1368312959675677, 0.1500710769323632, 0.1497928160824813, 0.06803318960010074, 0.2265885061933659, 0.07346641563344747, 0.1886465772986412, 0.09349468818982132, 0.1495636408799328, 0.10740292156697251, 0.12529179017292336, 0.2072076016338542, 0.11796974635217339, 0.13335170689970255, 0.15554668701952323, 0.13741236791247502, 0.24107252742396668, 0.14391424949280918, 0.12089220515917987, 0.15672403009375557, 0.11891423317138106, 0.12001527604297735, 0.1447975536575541, 0.12566287885420024, 0.11621281562838703, 0.11984936892986298, 0.11180960151250474, 0.10579438327113166, 0.16741855622967705, 0.07863484337576665, 0.1045722515846137, 0.1586661860346794, 0.19766251381952316, 0.16928266792092472, 0.1248886703979224, 0.22283548023551702, 0.12174795338069089, 0.10371685959398746, 0.14840845833532512, 0.09331724068033509, 0.08558746092603542, 0.10238462287816219, 0.16376791696529835, 0.16422669781604782, 0.19548169802874327, 0.07657436683075503, 0.14400121435755864, 0.16825994389364496, 0.21790877741295844, 0.10789364445372485, 0.12691050331341103, 0.12167802080512047, 0.0821916751738172, 0.16851791442604735, 0.13996428722748533, 0.21203175449045375, 0.13801016786601394, 0.08365747620700859, 0.17105647508287802, 0.16475464683026075, 0.10590244739432819, 0.1374069502344355, 0.1106360656558536, 0.18563308665761724, 0.14490014815237373, 0.1566800504224375, 0.18833370268112049, 0.19628047157311812, 0.10324506889446639, 0.15741623123176396, 0.13882566941902041, 0.19234925595810637, 0.21127452637301758, 0.20360871974844486, 0.15121917938813567, 0.11811350035713986, 0.1955166383413598, 0.06911720760399476, 0.11660461765131913, 0.12294677420868538, 0.09250633302144706, 0.2060076527413912, 0.08633072924567387, 0.10717014694819227, 0.1060172427969519], [0.010394131659268169, 0.06885607552248985, 0.054024146593292244, 0.02964807608805131, 0.04667915556638036, 0.04643856984330341, 0.023575074228574522, 0.02818862227286445, 0.028236984326213133, 0.08336858780239709, 0.034534053556853905, 0.03827679705864284, 0.03485205270408187, 0.019467505771899596, 0.07732208061497658, 0.028452260958147235, 0.036944489838788286, 0.019809849218290765, 0.02288928153575398, 0.0674273818731308, 0.02769428141618846, 0.02045072898908984, 0.11700781164108776, 0.0190112556447275, 0.025996562944783363, 0.024047094993875362, 0.03917943045962602, 0.01476337118219817, 0.0430593822238734, 0.04898025494185276, 0.060974333609919995, 0.04542563474387862, 0.06532694809720851, 0.030840707404422574, 0.019548577984096482, 0.05436088496935554, 0.03243682956963312, 0.03888928040396422, 0.026732628721219953, 0.00922851173527306, 0.004393962781250593, 0.04385862703202292, 0.025479478972556535, 0.026699050249590073, 0.02121908746630652, 0.0740079979004804, 0.021030376010457985, 0.044697691773762926, 0.04443417739821598, 0.04655599615944084, 0.0414175920013804, 0.025917527927958872, 0.01712570145173231, 0.033780992598622106, 0.007751478296995629, 0.04140981058299076, 0.029063749825581908, 0.016388695003115572, 0.02858718711649999, 0.022661152761429548, 0.06485222591436468, 0.02046274435997475, 0.0250590690120589, 0.041919525028788485, 0.06253583458601497, 0.05136711690283846, 0.05999754481308628, 0.02347608100535581, 0.045496966267819516, 0.01815524581616046, 0.035283006727695465, 0.01956457312189741, 0.03020034528162796, 0.04578502717777155, 0.03598721952585038, 0.03921362120308913, 0.07865419116569683, 0.0058314007856097305, 0.04016577440779656, 0.018028488848358393, 0.02922607793152565, 0.0483516335953027, 0.05737741099437699, 0.03523040701111313, 0.021987659310980234, 0.0560333592875395, 0.062370773521251976, 0.01927079210872762, 0.011687200603773817, 0.0584131374489516, 0.07369847779045813, 0.022329969360725954, 0.037001716846134514, 0.01006255306492676, 0.06008612755977083, 0.04863711554207839, 0.05672469582350459, 0.07713353799772449, 0.027821188668895047, 0.04261881367710885, 0.08002104907063767, 0.04698677206761204, 0.09075910216779448, 0.029367805873334873, 0.07740040688076988, 0.013170434685889632, 0.031115713936742395, 0.08924792622565292, 0.07282756007043645, 0.02777913487079786, 0.028152683771622833, 0.06776183072361164, 0.009991014667320997, 0.043258734222035855, 0.04220051698212046, 0.05025357997510582, 0.06435994451749139, 0.049886532287928276, 0.011477032730908832, 0.15545034140814096, 0.03098295484960545, 0.015827416136744432, 0.13423722266452387, 0.040780421113595366, 0.044601798872463405, 0.014096775066718692, 0.03182019019732252, 0.040758568575256504, 0.05612216096778866, 0.021630296650982928, 0.03020468127942877, 0.058455566031625494, 0.05478953091369476, 0.073778755904641, 0.019847008552460466, 0.03164298759656958, 0.03005615340953227, 0.0337148412654642, 0.04254286970535759, 0.07536014643847011, 0.03180273859470617, 0.028746403768309392, 0.04260174056980759, 0.045697527966694906, 0.02410001754469704, 0.04335850855568424, 0.06083932581532281, 0.05458708415972069, 0.025903889109031297, 0.032272147000185214, 0.026572154129098635, 0.0466962991777109, 0.09321562582044862, 0.1101066917181015, 0.023752764791424852, 0.017774370062397793, 0.02054044907708885, 0.04140116085181944, 0.04082123552507255, 0.025067145434150007, 0.08276135515188798, 0.04007541421742644, 0.05414985898823943, 0.07659012262593023, 0.016882076633919496, 0.02431446668197168, 0.04674858719226904, 0.05399898407631554, 0.057779714406933635, 0.032224913011305034, 0.09204308444168419, 0.03556577612471301, 0.0922495944541879, 0.020325812547525857, 0.09445697913179174, 0.027420794431236573, 0.032589775073574856, 0.011819209194072755, 0.01834277354646474, 0.032464526520925574, 0.029387899521680083, 0.0028447151271393523, 0.0893762287159916, 0.043970746992272325, 0.06275480525800958, 0.1103297590452712, 0.031484717183047906, 0.05487370530318003, 0.022101914801169187, 0.036682530262623914, 0.028217562321515288, 0.01359124911687104, 0.0628667211276479, 0.018798489327309653, 0.027318361353536602, 0.035156659796484746, 0.06942067921045236, 0.010075377376779215, 0.034566563335829414, 0.03033834022062365, 0.056528891291236505, 0.026330945001973305, 0.039165229463833384, 0.026818651058420073, 0.011307185741316061, 0.070497876877198, 0.014881384722684743, 0.07503139728214592, 0.02540590245189378, 0.051856400023098104, 0.046106510708341375, 0.023999324803298805, 0.036778159701498225, 0.016132444397953805, 0.0226890278281644, 0.06262343027628958, 0.05994373910652939, 0.013903556919103721, 0.02109517292410601, 0.03945184689655434, 0.035377968233660795, 0.027374456585675944, 0.16765954642323777, 0.014228666768758558, 0.01230521387697081, 0.10199186348472722, 0.059060865387436934, 0.0145331263593107, 0.054010836174711585, 0.036057137258467264, 0.0350802928005578, 0.022455937796621583, 0.08584091177908704, 0.03648032470664475, 0.07850373556721024, 0.04830673737160396, 0.021792721236124635, 0.029421776707749814, 0.02697181549592642, 0.03860301920212805, 0.03167543429299258, 0.06587248601135798, 0.047523055400233716, 0.05888475745450705, 0.04656848279410042, 0.01580311822181102, 0.04833451224840246, 0.02762618565611774, 0.027206144914089236, 0.052868607817799784, 0.007039900146992295, 0.02342237734410446, 0.054707805611542426, 0.04800570372026414, 0.03464608817012049, 0.044241942596272565, 0.035789132889476605, 0.051419657247606665, 0.01824382670747582, 0.028711463455692865, 0.023243404721142724, 0.02761693664069753, 0.02819113629811909, 0.033299984424957074, 0.033988612121902406, 0.043739534594351426, 0.0948576646624133, 0.03473831486189738, 0.03057337467907928, 0.014678198604087811, 0.04065356210048776, 0.004618214761649142, 0.04774651606567204, 0.015818810934433714, 0.03715348975674715, 0.0916136332671158, 0.02687684285774594, 0.07311629262403585, 0.08692658477229998, 0.03584234116715379, 0.05424418224720284, 0.033420160398236476, 0.054073150604381226, 0.03859510048641823, 0.04780627379659563, 0.005580446795647731, 0.0072638051733520115, 0.042673402349464595, 0.10777809206047095, 0.04203176373266615, 0.018250389148306567, 0.04539816414762754, 0.052085285788052715, 0.020715022619697265, 0.03566464874893427, 0.03127427749859635, 0.027115986958961003, 0.044239037088118494, 0.06805675278883427, 0.056437855746480636, 0.032249645082629286, 0.01624448828806635, 0.043236814890406094, 0.0440750595589634, 0.07194352860096842, 0.07625142126926221, 0.024851800153555814, 0.024341018870472908, 0.043689153899322264, 0.08317274987348355, 0.025202732103934977, 0.058798612662940286, 0.07993991006514989, 0.02727714989305241, 0.03817678523773793, 0.04523030518612359, 0.01355060818241327, 0.06295684754149988, 0.007845380387152545, 0.04768342238094192, 0.012808221163140843, 0.07013271795585752, 0.06560535737662576, 0.024076441368379164, 0.059720066929003224, 0.0050362999445496826, 0.02857294715795433, 0.022979662135185208, 0.07972397477715276, 0.051694971771212295, 0.09134927284321748, 0.01896758210932603, 0.034790064819389954, 0.05475567413668614, 0.0737191762891598, 0.04927381145535037, 0.09691116501926444, 0.03574539441615343, 0.016179049416678026, 0.02672537422768073, 0.02426514169201255, 0.031160650978563353, 0.022345428296830505, 0.03230097201594617, 0.07801466766977683, 0.039664895230089314, 0.03654879896203056, 0.016524561833648477, 0.009747811945999274, 0.017368255721521564, 0.03863914324028883, 0.03137253785098437, 0.10691026909626089, 0.12945002876222134, 0.12703847925877199, 0.09005107844131999, 0.13165952113922685, 0.0822424900252372, 0.14590785111067817, 0.11221853230381384, 0.20514707313850522, 0.17554526624735445, 0.11782023328123614, 0.16594886634266004, 0.11411391809815541, 0.15363933780463412, 0.2030036912765354, 0.09518922655843198, 0.12003831230686046, 0.11487548777949996, 0.09957008718629368, 0.1745529702748172, 0.18258176132803783, 0.10934138903394341, 0.26027905696537346, 0.055552981939399615, 0.12157019416918047, 0.17166291363537312, 0.11358668154571205, 0.07825165026588365, 0.19745079393032938, 0.17834479571320117, 0.12994201330002397, 0.20080279296962544, 0.15995922993170097, 0.18474155949661508, 0.08395604221732356, 0.1260809157975018, 0.10328943448257633, 0.10802442571730353, 0.1678330753929913, 0.14219858217984438, 0.13762604707153514, 0.11193822312634438, 0.15958659758325666, 0.12712228257441893, 0.11010557849658653, 0.13504086469765753, 0.35846709448378533, 0.17880175088066608, 0.13296101067680866, 0.19196903886040673, 0.14772333728615195, 0.1211647514719516, 0.15793659549672157, 0.1428242720430717, 0.17166977107990533, 0.14125026587862521, 0.12216462477226742, 0.07633996690856293, 0.15459785121493042, 0.10041923029348254, 0.09603907470591366, 0.10304431052645668, 0.06640807914664038, 0.12148930007242598, 0.19938650802941993, 0.1629064467852004, 0.11872102986671962, 0.1682520771282725, 0.1834417917416431, 0.14777291275095195, 0.12052214806317352, 0.15506987198023126, 0.19183217198587954, 0.1460378902265802, 0.19106020481558517, 0.11574856514926068, 0.21656850323779508, 0.12901581299956888, 0.16405873495386913, 0.16371329489629716, 0.11986632700427435, 0.1770169154042378, 0.1147610782936681, 0.21376460994360968, 0.1199366751825437, 0.11538204809767194, 0.23236983659444377, 0.1333184289978817, 0.11215355727472343, 0.1098090162849985, 0.20266889361664653, 0.19796339533058926, 0.07589979912154377, 0.08926956725190394, 0.1302920695161447, 0.15580773004330695, 0.23659589263843372, 0.16335658903699368, 0.1395244014565833, 0.1311281434027478, 0.18053199397400022, 0.10997483434039168, 0.19832835387205705, 0.08260363392764702, 0.20162850647466257, 0.11089106759754941, 0.11564951069885865, 0.14624707197071984, 0.19873518438544124, 0.10237838883767836, 0.0900877924868837, 0.10159816898521967, 0.21432273468235508, 0.11549952265340835, 0.11247602786170319, 0.18569593172287568, 0.18069299549097195, 0.13560929044615477, 0.08728553191758692, 0.365931200212799, 0.18016316142166033, 0.11457517772214487, 0.23458909563487396, 0.15797698317328468, 0.09033293128595687, 0.12297456021769904, 0.08059680723818019, 0.15600062906742096, 0.18156614707550034, 0.14494482544250786, 0.10947804810712114, 0.09453102320549078, 0.14829768537310883, 0.24419717694399878, 0.13136561581632122, 0.14060495363082737, 0.13201682071667165, 0.18006239261012524, 0.12593048246344551, 0.15249426331138238, 0.11994604850769974, 0.15951655368553475, 0.13079442927846685, 0.07810863098711707, 0.09222618711646646, 0.15056969627039507, 0.14318810252007097, 0.10300998619641177, 0.14617020031437278, 0.09409410602529533, 0.13794212776701897, 0.15828292613150552, 0.13631535490276292, 0.1392876118188724, 0.13400687486864626, 0.17789685021853074, 0.1191493307123892, 0.1354160500341095, 0.18425818387186155, 0.09294275296269916, 0.2763464947929606, 0.07288143257028423, 0.14330233389046043, 0.19419294374529272, 0.07685079457587563, 0.13265065936138853, 0.1268084134790115, 0.1366247414262034, 0.21193074819166213, 0.14931519952369854, 0.13569203991210088, 0.1658362676971592, 0.11226762537262402, 0.08449605855275877, 0.1351491588866338, 0.11737757187802345], [0.012888374039903283, 0.04480655741645023, 0.05533144714718219, 0.038751760439481586, 0.053970474473317154, 0.03403479597182013, 0.023196825677587185, 0.012640814911719644, 0.05426325173175428, 0.060602736557484604, 0.027675785240717232, 0.00872354517923668, 0.011347230174578726, 0.043282085898681544, 0.022970580102992244, 0.05976703374471981, 0.021370576505432837, 0.049141987474286, 0.019289356932858936, 0.02672427213838091, 0.06516097419080324, 0.03424393689783756, 0.05845750303706154, 0.020860891745542176, 0.018997169681824744, 0.018538793301559053, 0.08120128652080894, 0.10750706715043634, 0.04032901721075177, 0.03056419616768835, 0.008733108679734869, 0.04371725161036011, 0.04024877991469111, 0.0592784519540146, 0.07616649731062353, 0.0611465638212394, 0.014821910863247467, 0.03606610240240116, 0.044451948124333285, 0.035059664805885404, 0.04861321467615198, 0.017401331388100516, 0.041488901260891, 0.05215761178988032, 0.029587121643999126, 0.02427736671961611, 0.027005614756490104, 0.02672494749276666, 0.03579558586352505, 0.043236172932665795, 0.04311416014388669, 0.04527685639914125, 0.015424225857714191, 0.06123905397544149, 0.05604492936981842, 0.014787026211706689, 0.04152711444476154, 0.0865795713616535, 0.02196874196670251, 0.06026672919688281, 0.008226569698308595, 0.037084343857713975, 0.04724998587334994, 0.018818835305864923, 0.0466056458390085, 0.04378356250526849, 0.03866184924845584, 0.012354934060567757, 0.03967450975324027, 0.054243351041805, 0.007035159214865416, 0.019889418581442442, 0.061240397262736224, 0.01615298147953581, 0.049649108113953844, 0.04233325751556549, 0.054326419631252065, 0.05338889415725134, 0.03547854779753834, 0.011709954851539806, 0.01602741194801638, 0.028139273163105827, 0.05980499088764191, 0.05827916495036334, 0.029757687589153647, 0.014113657070993213, 0.07533166281064041, 0.04024862406367902, 0.0543281822319841, 0.015548939136351692, 0.04224124233587645, 0.017954713803192135, 0.08249343984061852, 0.0510278478031978, 0.009949507275450742, 0.061889869248261675, 0.04863592439505737, 0.011952786499023205, 0.029755863761238288, 0.006477254801211529, 0.03090869740844937, 0.045078869952703826, 0.01295933634537505, 0.028462402406148612, 0.04905808767944109, 0.0366562842100393, 0.058816019736696035, 0.02032181051617954, 0.03697768239362631, 0.04222156429023016, 0.02638034235133091, 0.028282750718062744, 0.02054946617136011, 0.01578518422320485, 0.06361826439388096, 0.024991745085571893, 0.028445915595511906, 0.04517946064879652, 0.03572766450815834, 0.008542452796973521, 0.032840209096320905, 0.03513279232720379, 0.05793158008600585, 0.06437857242417522, 0.06393143587047234, 0.05481073778355494, 0.04583940433803946, 0.04130081506446004, 0.02169124552892754, 0.02771364033833379, 0.006552415343321627, 0.017551605160406325, 0.053517526903306134, 0.03795674587308895, 0.02143805813830113, 0.012396568545227638, 0.06129812521976419, 0.017492090482846834, 0.012188040818728041, 0.08144320439896546, 0.06769120052922517, 0.04657407487684395, 0.016555255206185393, 0.04216598485072609, 0.03381308306416031, 0.028026719046465587, 0.050578336376929656, 0.03044840628717793, 0.005046485921411659, 0.03217025012418162, 0.015716669149696827, 0.04125609695620369, 0.09409338614204898, 0.030545531153620686, 0.04903791610558983, 0.05526452398044057, 0.04483268843614496, 0.019227343072998337, 0.06179038806294557, 0.021339074191928376, 0.08366593669052236, 0.009838455080171116, 0.04291445933631621, 0.022675344480376225, 0.061567068405565806, 0.024750565644353628, 0.08515167181030847, 0.032804393049445935, 0.03314183275506366, 0.01714458725473378, 0.02852494319085963, 0.018889688144554384, 0.02957929940748727, 0.03421105975576211, 0.05106698125018738, 0.054792451264802366, 0.02511514012439875, 0.014124145473033423, 0.07371278639766388, 0.09917542789480649, 0.04616996804543305, 0.04547195218037814, 0.014258847131713992, 0.03475287579931319, 0.07216567566501908, 0.07209490446257405, 0.04434490816493053, 0.059389373345766217, 0.03425883922318462, 0.024721699810470454, 0.06118964549386874, 0.037498068923014216, 0.03973188519012183, 0.0397082329436671, 0.025949926384782884, 0.08123871302814223, 0.04141839352087118, 0.05606901948340237, 0.051992973749293014, 0.01980965997063322, 0.055514126797788776, 0.049046725398511626, 0.0765456679800991, 0.08398687845328823, 0.029217270493973047, 0.039212545088957995, 0.013927784330007853, 0.11505441216286272, 0.0073870438973244745, 0.07083058910211548, 0.060081923293182626, 0.019842127076117322, 0.033728867856552824, 0.029231499320303556, 0.06612110548303463, 0.007457248748323764, 0.03180175153829623, 0.03809930130955763, 0.026339004725741688, 0.023718835655017756, 0.05475498765008524, 0.007075177209117101, 0.009600183002476115, 0.027087286252935883, 0.04693999078881461, 0.04621995540219359, 0.08051810989854857, 0.06288658842095174, 0.04209085353068076, 0.05295042217767332, 0.031107947361306287, 0.015900050129857846, 0.06360679821227677, 0.08703752842848189, 0.04802418690815102, 0.008956395868153777, 0.06144857339677401, 0.0335760967573151, 0.02116449693858158, 0.018003231707552914, 0.030551360723620746, 0.0072925490167108364, 0.022376014057954308, 0.03340261602716055, 0.031374719765153714, 0.052109190364717506, 0.04728389460069593, 0.007396018318104325, 0.01890725292469142, 0.02638705507706618, 0.035874442764907144, 0.04591489188896958, 0.0253014136251295, 0.04084591935679782, 0.04028658120660111, 0.03425913608225528, 0.014592338611691957, 0.03213183656043839, 0.017724024619383272, 0.12914463499328122, 0.004920118117297534, 0.030386375728994608, 0.0477797011990333, 0.07307810170459561, 0.0704719388158992, 0.0462370841705706, 0.016689984695403837, 0.033032759311026894, 0.061485005426220596, 0.04634025382983964, 0.025446201070735697, 0.010659753734216793, 0.03750285948626697, 0.012953427922184346, 0.03375073523784522, 0.06985995642025955, 0.0613682581752073, 0.0005361709668250114, 0.05347670507035218, 0.01295017360462225, 0.04673260875279084, 0.010449072851770325, 0.029904220937169157, 0.03934006090275943, 0.025965904824261088, 0.06134606424893718, 0.03920452618331183, 0.046021887319511734, 0.012998896527278703, 0.039833462942624465, 0.07941541203763336, 0.011631242668954656, 0.02783361964247888, 0.02664613326487597, 0.04257232925738208, 0.00977868900008616, 0.047847566893324256, 0.050747215791489, 0.04795157889020629, 0.05363356169254985, 0.026031143315776717, 0.006351876836561132, 0.06766357037122361, 0.025355210054840427, 0.007416142116198898, 0.04438298776221927, 0.03273350310337264, 0.026508565060794353, 0.043718442757381126, 0.0439686726895161, 0.07701546230237, 0.03903164659277536, 0.02352730960410554, 0.03377325199835468, 0.013133672400726937, 0.011454674604465254, 0.01303679800912505, 0.07054167843307368, 0.04525824333541095, 0.03767691538087092, 0.09022373167681508, 0.007289530794878374, 0.009306453939643688, 0.07071983098285273, 0.03942010895116255, 0.04179297400696669, 0.03886963575496338, 0.03755947051104158, 0.0847305401111953, 0.08495938134728931, 0.00990088175967685, 0.022643476659141015, 0.0297374473666423, 0.011487453411973547, 0.030717414410901256, 0.03607327525969595, 0.05670102131261956, 0.03605840633099433, 0.016618250556348357, 0.1043428092089016, 0.009438610959477955, 0.059091356524731964, 0.06830817757872865, 0.04752039851155132, 0.021968942346575204, 0.016555370239075273, 0.024029274172789883, 0.0362375273834914, 0.02593530236481456, 0.0033196940466950764, 0.043550205300562084, 0.039477450991398655, 0.09652095861383714, 0.17208279110491276, 0.2075834697461687, 0.163139050710015, 0.12581268878420815, 0.08008145247003995, 0.18631921702763066, 0.10757268042652868, 0.14995887904660776, 0.15218281361740083, 0.14661145163699985, 0.17554796766489744, 0.22602306387852877, 0.16169193695532158, 0.12260948293260299, 0.14162208186462522, 0.10819966162671335, 0.07156080304412171, 0.06424505263566971, 0.25242671894375235, 0.12580888898810372, 0.12438219913747162, 0.1437090605031699, 0.09525996807496995, 0.182803351781331, 0.12456288241082802, 0.19565976894227788, 0.16481873870361596, 0.15391044435091317, 0.1491217958391644, 0.1211201112892013, 0.19899919599993154, 0.14570300350897014, 0.17209188983542845, 0.23119501682231203, 0.12022192706353962, 0.1643529222928919, 0.12869379512267187, 0.12631302990484983, 0.10794802903546952, 0.09849049238255247, 0.13467744982335716, 0.10426071283291094, 0.15743897063657641, 0.19108809472527355, 0.117835491837468, 0.146323528024368, 0.1451450865715742, 0.11319968121824786, 0.19091993890469894, 0.16495406191097572, 0.18142657878343016, 0.12257619018782862, 0.23423648643074557, 0.14230813801987097, 0.13302959996508434, 0.20122920133871958, 0.19399185141082853, 0.07499039362301119, 0.16639767272863537, 0.11336324314470403, 0.17959188582608476, 0.10165585612412542, 0.08651685988297686, 0.15497426851652563, 0.11623597805737518, 0.16651200799969956, 0.15004645247245207, 0.15018069214420393, 0.11977009271504357, 0.2198952395701781, 0.060751106720999815, 0.09937626047758386, 0.07961925773997791, 0.1434760558186099, 0.18051704711979255, 0.09509489958873019, 0.16717826365493238, 0.09953016706276685, 0.13045275933109224, 0.053151269603404216, 0.101174224546412, 0.10169577624765225, 0.1949285011505708, 0.14309837686596438, 0.104677621711744, 0.11644455124041997, 0.2165696313022636, 0.24896001355955377, 0.08401578510529362, 0.10757265816209838, 0.05474023004353512, 0.14560489158611745, 0.16483374492963776, 0.0898486576625146, 0.08771080480073579, 0.10250376726617105, 0.12107496644603088, 0.12740355654386804, 0.0977841904386878, 0.13554644538089633, 0.15884968946920708, 0.12788754072971642, 0.07719664281466976, 0.12358530322671868, 0.12137952900957316, 0.12820388859836385, 0.13248296367237344, 0.19667342392494902, 0.10853848172700964, 0.13998772425111383, 0.16493068425916135, 0.20866368053248152, 0.12353267753496766, 0.1972331220167689, 0.10550855251494795, 0.14776152820559219, 0.13940049248049036, 0.1969979947898537, 0.10666075904737227, 0.14772924478165805, 0.10728691646363586, 0.1791030479944311, 0.206625446153339, 0.15227099560434, 0.17112260044086725, 0.16180319973500445, 0.2773453661939129, 0.11747057782486081, 0.12169350200565532, 0.1555465831188485, 0.08453496193396859, 0.1329882474965416, 0.12895354680949822, 0.16337251552613452, 0.08837448520353064, 0.11822555723483674, 0.09815093013457954, 0.15167215664405376, 0.1450310184736736, 0.18671274825464934, 0.13803453999571502, 0.15825135516934097, 0.17880552099086344, 0.14690875599626452, 0.07994441490154713, 0.0777108695183415, 0.12063786372891627, 0.12783766840584576, 0.16912902850890532, 0.18569633248262107, 0.1503267022781074, 0.13521895045414567, 0.24012211826629937, 0.06175425660330802, 0.130674394313246, 0.12146856446634047, 0.12920433335239068, 0.17021171806845814, 0.2760156453587115, 0.1966223047929816, 0.0860630143142771, 0.10703859385102987, 0.16254393733106554, 0.13506391580449417, 0.1178552774945274, 0.2808076929068193, 0.15794462553458288, 0.10633819198119454, 0.14515831164317206, 0.1288902564556338, 0.1383620942942798, 0.19085393229033798, 0.09283123043132946, 0.10997372111887671, 0.09369793275254779], [0.06114648589573335, 0.02482381747540785, 0.06364642147673294, 0.05471781347296201, 0.014843286571704084, 0.04207786965707783, 0.0425665256625507, 0.02776459434244316, 0.03185393194144126, 0.04353226388047915, 0.037743649299954996, 0.0223610987450229, 0.0474212958215503, 0.012303584862820571, 0.012482223519327817, 0.020541530757327564, 0.02682919512153603, 0.02641690425662091, 0.05170912823814433, 0.020914105589326937, 0.011587637782213278, 0.04716197829111479, 0.08679854945512488, 0.0051469996196829015, 0.07226912362966686, 0.0641202085535042, 0.016993519384413958, 0.04156438139034435, 0.03267850996053312, 0.05691056670912076, 0.022233942872844636, 0.027440975281933788, 0.042239424074068666, 0.04750839056214318, 0.01742520442348905, 0.009946693608071655, 0.11348057669238187, 0.04080889360920992, 0.056196646619355306, 0.019178031070623547, 0.04706462335889228, 0.0862291143857874, 0.04684089180955198, 0.07413416300551035, 0.017709100029605906, 0.05509991191502195, 0.034549486517789774, 0.05946075682004448, 0.03598821771447547, 0.04548233853711281, 0.07286085281521082, 0.02570029017078923, 0.0442152883624658, 0.010740151519712526, 0.017326198212685995, 0.0036399831833477947, 0.028904592545586638, 0.02259304586914368, 0.0410821820696583, 0.03208460628229659, 0.07405838230624795, 0.04128763823246118, 0.008811755924398312, 0.007517207322962349, 0.07436025829520077, 0.09965253979316913, 0.025500823139736895, 0.03162874578265473, 0.021387590240919963, 0.02622396441438468, 0.0279000993759837, 0.0543405093048932, 0.057196115449187346, 0.021483234522747807, 0.07849773901398294, 0.04034960067656357, 0.004892738434136845, 0.08598053202149458, 0.05707794327463489, 0.08408747657085769, 0.014259474246500758, 0.010045289782283362, 0.02349166610656539, 0.016217789525398985, 0.04003927904705051, 0.055189362974488176, 0.03246419997594785, 0.01874944820883684, 0.049317839366267435, 0.027642655768431723, 0.043222331878496334, 0.06125478379544802, 0.027039690467063338, 0.025429697561776266, 0.02483195512468228, 0.0587101041310234, 0.00924069316170062, 0.05085282711661421, 0.03884874429786578, 0.033043397997971624, 0.02495708678907249, 0.11423994219512679, 0.02679910474398639, 0.02964326511573745, 0.00133228530330598, 0.09784495006897487, 0.013443579355225665, 0.01866965805675136, 0.0764275700203143, 0.026868328568525612, 0.04391664813738316, 0.07458038671757095, 0.04234318374074064, 0.06157512812933419, 0.015653976224712096, 0.04416680756548885, 0.02284226462506922, 0.0486219534650445, 0.06675438751699403, 0.030183723029040266, 0.053376478026621044, 0.04270302517397795, 0.0036693279344035545, 0.0493823839497054, 0.009879472654574784, 0.030023281833564397, 0.019037804122490343, 0.039193334596347995, 0.012187236516183475, 0.012358165186014958, 0.04277979664038867, 0.042424756902619265, 0.03354670770931989, 0.026280330530426, 0.07136010404792614, 0.00730489789020794, 0.05586230909102596, 0.07175131977419369, 0.042985727777704597, 0.05907367114559747, 0.07262623024871573, 0.03353223582962528, 0.0340930323000066, 0.00956653031607857, 0.028464654824347235, 0.022151442026370205, 0.05238725083472673, 0.040151239445549436, 0.011701542607625015, 0.07481267894036137, 0.057933650678023696, 0.04373366049549077, 0.04125224149902351, 0.03395109284610953, 0.04162491466559004, 0.1281249983003363, 0.06999835211900063, 0.02457436865370255, 0.013888720459362958, 0.07356699148658663, 0.024716812768019736, 0.07639509363798425, 0.013782913392788032, 0.0801314361160621, 0.07290276931598783, 0.062432765116682276, 0.05709229641070124, 0.003715372863553057, 0.0194679250853369, 0.02839825116097927, 0.021057596131868195, 0.03805696178460494, 0.024329747502633836, 0.009904233484121505, 0.024647325481055304, 0.025329379604954738, 0.04631141768186353, 0.038173449283931404, 0.12619770015589893, 0.10082862863782793, 0.02504293657693779, 0.04657485413190443, 0.008766115697653731, 0.025331375982204918, 0.036872364216833375, 0.007477339613615186, 0.014259566087275743, 0.06889701980981044, 0.06323559078737162, 0.03008689687703736, 0.014150550159683917, 0.022937129651836585, 0.010217979197477689, 0.023101864171621855, 0.022626557547482662, 0.021410776789707597, 0.044348333176458254, 0.015270503881765762, 0.0641290846397169, 0.015105603306437843, 0.05953263011178933, 0.029231679291115142, 0.017843567911768332, 0.0246712949956418, 0.017640121113799978, 0.03817865544988308, 0.005987403937979252, 0.005091120538054383, 0.1031886508280877, 0.036872649943688884, 0.03817374243226368, 0.0641349030775018, 0.0382357080525253, 0.08021446759812534, 0.045893325077486224, 0.029388650946202688, 0.041007514591910876, 0.04672877556004096, 0.05228519068623427, 0.05556379503104836, 0.02920184124377556, 0.021685297215299215, 0.031483039929298684, 0.053816976069356315, 0.00845185604703147, 0.020155864440312143, 0.050399853571434505, 0.042348100469098426, 0.0217155768405064, 0.06380976075888611, 0.04498207534197718, 0.05849802430020645, 0.038290905285975896, 0.039603259865543805, 0.04681593709392473, 0.0389556580921635, 0.06463999394327402, 0.030385509271582123, 0.03692797334224451, 0.025020141511049587, 0.07290280642337166, 0.07858669283450581, 0.052885558470734395, 0.04970403817424085, 0.014241817625588737, 0.008851999809849076, 0.027201448974665254, 0.02582095596153522, 0.0290853964179405, 0.08266563294455409, 0.0810537401412148, 0.025617891369620338, 0.025119116180576384, 0.05686900643922854, 0.019027007729164325, 0.03152239602059126, 0.028281079030421097, 0.030496434374072123, 0.01435076583220507, 0.047681626383564435, 0.02320765175682027, 0.03131606041279156, 0.05675147993315477, 0.04173086737864651, 0.037761045241495594, 0.0394286176742753, 0.13971669191960245, 0.033287820624536835, 0.07540679784142412, 0.022161520391819067, 0.019273590005468577, 0.009807179121708032, 0.0673343165544793, 0.009692395778984064, 0.016848622472025454, 0.030713314044987783, 0.03804277192102745, 0.08065695088589564, 0.0596837313787546, 0.09007199216284789, 0.06327997863991186, 0.034668445368879475, 0.0277531652682228, 0.0011861156076520274, 0.05416023421275895, 0.08313070720760152, 0.015325845834013307, 0.0685774213343393, 0.05164436843188014, 0.016898943795240484, 0.028725683005177416, 0.043239868828095496, 0.04101276157598477, 0.024440485212835483, 0.028605967163457535, 0.03458711340499576, 0.07611917797476053, 0.03480206163658295, 0.030907623149687424, 0.03892697779519949, 0.05772834294475615, 0.020469828159548342, 0.0517078962730011, 0.037147919938433915, 0.03446186485234648, 0.07900072218035348, 0.03794090102019254, 0.011840417919302126, 0.019404835111345164, 0.04664190717448946, 0.01038828631862998, 0.04325599569710903, 0.02225350031949347, 0.04962393817550037, 0.07548268244136125, 0.07586532636196353, 0.044357584047247656, 0.004963686360497377, 0.02591883410786977, 0.007520115614170209, 0.05196104284550529, 0.045793509925715625, 0.02983984704769682, 0.014751452290511224, 0.0243828945531277, 0.057827119089779444, 0.025084229673666414, 0.049995839508483186, 0.08036111597903073, 0.03789605303609278, 0.0971544039202854, 0.041994578423327766, 0.02327522059204057, 0.06720721634337679, 0.08900013053789735, 0.036777896239073016, 0.041594508875277825, 0.04664514293835964, 0.010802414926729398, 0.026857098018808756, 0.03141794615658, 0.010811280808411539, 0.05372651939978823, 0.025520321214571595, 0.041622224380262196, 0.013341062785912072, 0.012238078270456754, 0.04989766079233959, 0.04825723241083324, 0.05248787121672649, 0.03434775964706205, 0.035844608428305946, 0.16266076621832326, 0.08038099069381133, 0.20172261080006137, 0.11782609624788165, 0.06544582531205378, 0.12254338726052083, 0.16419701190898195, 0.14086126175243407, 0.08858213070197962, 0.1690381154185161, 0.09298352655605413, 0.16155282879481092, 0.0904311693739146, 0.10068691553897224, 0.06624663976253942, 0.12327757169259712, 0.11481263529276475, 0.16084796661743894, 0.13151334773283452, 0.16750507580582052, 0.09760570392245427, 0.1395811460679397, 0.2226220682496205, 0.15536334685748443, 0.13983703858684748, 0.12787158455466852, 0.06998201744863763, 0.15581242041662335, 0.11933529807720333, 0.13322240993147716, 0.14141284074867144, 0.06799349212087691, 0.22493103810120374, 0.16831294808071107, 0.09137386761722155, 0.2801236405503005, 0.23739371623378247, 0.14068865304579958, 0.15776490705320612, 0.09164041737676598, 0.08708870693226345, 0.14456017030170187, 0.1578202861128375, 0.18788391666021198, 0.10839511363883503, 0.08460839002509601, 0.1842154361656867, 0.11336615236359648, 0.09558439051033929, 0.09480235239607282, 0.08930883428547531, 0.12483945116400719, 0.08257319102995098, 0.13335225608898327, 0.14549906132742763, 0.1163192989770323, 0.12631712656002492, 0.21471644402481616, 0.09537753168842755, 0.13199822249589488, 0.1440648757852614, 0.1450599919189699, 0.07716417385381646, 0.1055701136647258, 0.18870065017836168, 0.1803925444255583, 0.138303583371453, 0.11881836253451183, 0.11747137934435159, 0.07878879448981024, 0.07404120158753358, 0.13473392726154998, 0.161582603759598, 0.17748286540154368, 0.25984540523495525, 0.16384881106205285, 0.1231492766237352, 0.1957529381616041, 0.1364677623496391, 0.13379278010688722, 0.10265089804306626, 0.08589235745603219, 0.05266629836114589, 0.11248486684053205, 0.1559557142900303, 0.14489335007965565, 0.19947264168877155, 0.17789729550713673, 0.10352175639127381, 0.158852806489449, 0.18412731355056167, 0.22999138687737286, 0.17488427984062582, 0.09877797812805511, 0.17124639067333192, 0.15845743473619223, 0.17347774672089145, 0.2050502970814705, 0.17611483490327373, 0.11786561561166309, 0.1155730991740711, 0.21084966167109087, 0.15157463843934238, 0.18068555917125195, 0.1562745260889642, 0.1841176804737188, 0.15356285206507891, 0.07333847679547034, 0.1950722254696302, 0.1546167314518243, 0.08487653540214524, 0.21397655247710645, 0.1743709362926893, 0.11019920784747228, 0.09433908897335641, 0.16975728620309383, 0.08029242279008031, 0.0873570452677086, 0.19718270050361753, 0.15146361314691603, 0.20896417612675577, 0.1508999668294564, 0.11614466420724057, 0.17437256901757792, 0.19358816760359332, 0.10085244415677153, 0.15602014755131677, 0.12107964939787053, 0.10930136500974186, 0.11203151851077564, 0.06601707122172229, 0.14464812964433804, 0.10506770937354304, 0.12499248201493174, 0.15267358103301376, 0.17324897227808833, 0.1274818679667078, 0.1464660352212377, 0.16113243182189763, 0.13025251304497942, 0.17459412978496403, 0.12872172956122085, 0.18898254755185917, 0.07053953362628818, 0.11289390153251588, 0.12058070351486094, 0.15226832387270406, 0.13043861399637535, 0.10358618965256028, 0.15230054792482406, 0.1353918857057579, 0.14855322166113183, 0.21133054367965087, 0.09251210693037137, 0.23565758048789576, 0.20239199831848964, 0.16020605340600014, 0.14126939844572917, 0.16808819607831538, 0.20861054275883362, 0.11818286890047602, 0.18615925451740623, 0.09946142192347907, 0.13859503960702568, 0.1966424466809258, 0.1682847464689985, 0.22992227808572352, 0.07793083466822281, 0.1266314706299454, 0.14223807927919552, 0.10129335409146734, 0.08863619616022334, 0.1823934933054261, 0.05701827831217088, 0.12745084619382396, 0.17220537905814126], [0.07217139020212926, 0.01762322055583354, 0.04103368642972782, 0.02754814882791834, 0.06587226336705498, 0.044669816707028076, 0.020496074212132953, 0.02739002684393199, 0.04640751467377413, 0.044118497462477535, 0.08864561401423998, 0.02836996420228388, 0.04233341707731597, 0.051867554502678104, 0.027906565337616485, 0.04387086504721083, 0.030102723176241852, 0.01763701522577321, 0.007674312564631691, 0.005144766219018493, 0.005606308786809677, 0.02025419715209864, 0.06788494560169056, 0.08886452531442046, 0.025247620906156953, 0.06450190994655713, 0.09604640712495893, 0.06741034958395176, 0.017325225999229588, 0.045353241948760115, 0.05680885908077471, 0.005491663205248187, 0.05128223747306038, 0.05180634958378505, 0.03083272746152943, 0.07511547519243322, 0.020233602554071695, 0.04216530578560196, 0.046854142856318504, 0.020199610335112084, 0.030836449332127813, 0.055722351171425544, 0.009790486365091056, 0.027267494551779237, 0.013074235648673493, 0.07284166087629274, 0.02489305243216222, 0.017343920699204318, 0.031135121098486707, 0.01797084438294405, 0.02900392715673661, 0.01882356093119597, 0.050143196640419774, 0.052595727538573556, 0.046883086615707725, 0.07039992822683416, 0.06901499902596697, 0.07302285623154603, 0.025547079349053092, 0.05197483937081415, 0.04131655230594333, 0.02475839344697306, 0.045882192862336524, 0.04782161027833354, 0.03160125663271174, 0.04738237759738695, 0.05771464289864525, 0.05160964334208984, 0.06573335558641702, 0.03954855244955979, 0.007388145058939699, 0.0712884942186065, 0.03940893591789063, 0.014787592099310132, 0.0393504917883547, 0.025069060175155755, 0.013217055475251982, 0.014959877044020686, 0.04707793006673455, 0.01915806544275256, 0.043315801667631604, 0.016003288437786978, 0.02017888215050334, 0.03499059683235828, 0.01675993211392779, 0.0573334535874892, 0.01762494233844336, 0.037687691365135834, 0.05806564164231531, 0.04156406968832016, 0.05061898009444121, 0.011024751238437602, 0.03912957297870889, 0.032145224904525094, 0.0299336470925482, 0.010226471222267719, 0.043074306813650765, 0.040952636481961235, 0.039829021188779734, 0.049248801078647375, 0.044197543611517176, 0.02950471727672266, 0.07429315330227837, 0.03314150249934755, 0.03335219080327079, 0.04428260857821442, 0.013398745286394842, 0.0167712387337815, 0.021272620433592238, 0.021399828256107867, 0.023318161256611347, 0.047835195291554555, 0.10414268908789381, 0.05816394281282555, 0.0409267726354301, 0.08440190969849937, 0.04461229655134957, 0.06584463320905343, 0.023948834641487338, 0.02939662717835745, 0.06065655339625664, 0.007400289377983427, 0.0314037600037409, 0.01868199440650642, 0.024578285338066053, 0.03817250675638206, 0.06945794986677356, 0.026993317369488068, 0.00964142043812899, 0.05432451973319985, 0.013605485364678316, 0.08836859997245483, 0.04574520353344269, 0.01593789223989006, 0.09311320201959461, 0.05026719096349552, 0.031416023994097486, 0.02688626442250097, 0.02351817376620602, 0.06010672586853616, 0.03110232744802488, 0.030877662647981197, 0.0314613692171406, 0.016116631086333655, 0.021905906178290024, 0.019697096577147022, 0.006481375112343812, 0.017946642947208602, 0.05077962538052816, 0.027534508153621573, 0.01547972180560464, 0.034872977557824925, 0.05065334895334672, 0.011663945406326093, 0.02104966071783565, 0.0305769332771888, 0.0757633478497155, 0.027322402347635943, 0.06027750518114772, 0.020425030270416755, 0.017919309648277704, 0.03193717493559234, 0.06630518779275008, 0.02858357285731472, 0.007006700634519802, 0.029800867596350145, 0.06466953142080456, 0.013326855296327267, 0.060904044803464785, 0.03559407792636193, 0.02474190292559797, 0.039925923410919495, 0.05272533620882314, 0.053742108211736195, 0.013750661510130158, 0.05787712871097028, 0.02665348794835154, 0.018971823483298067, 0.021320824780559633, 0.035982970730401576, 0.05685207805072423, 0.02033523782301927, 0.04676962336816359, 0.040646556226420216, 0.02022711432800861, 0.045286511740414426, 0.0840312366199214, 0.08445279876468703, 0.04478268623643089, 0.03676058564451523, 0.029563133575720713, 0.07713508166489191, 0.05838335877342615, 0.05837867211084813, 0.041307431310997345, 0.02494379677955294, 0.04533565304882359, 0.052680855587823316, 0.044200823904247954, 0.014877706453262363, 0.04644288543204311, 0.10387825444922782, 0.10439763907925226, 0.030225324117054697, 0.03900006449839566, 0.03330998486489989, 0.026765552247525193, 0.021909737515670713, 0.014174448242556537, 0.052433828022913076, 0.044420184203772806, 0.08386106957914308, 0.030671234271721914, 0.13220792374340817, 0.04453358065802604, 0.06141605248558335, 0.04770521554746665, 0.05787113215774298, 0.024486986330884974, 0.015153950516832992, 0.016742510197218508, 0.028469426833908074, 0.013686079819308361, 0.028043927595717832, 0.09645281461416744, 0.009248886472050799, 0.020750456460518762, 0.026974813772540074, 0.0067939027758257, 0.02544136041251477, 0.020129275144427083, 0.07952409956487827, 0.04267265278031118, 0.025091968418564647, 0.017785530108085368, 0.004240708358338452, 0.009233275395672536, 0.003978628183176625, 0.03659906091343146, 0.08302633897983469, 0.021245890129648615, 0.02169542382034706, 0.042422541591804475, 0.026096251931448933, 0.007579814900964266, 0.0560519278224092, 0.03891419430146925, 0.0991132804483641, 0.04322651388065424, 0.029359692343859933, 0.05318138966686092, 0.027062706321885344, 0.05998508415359538, 0.0471145476331003, 0.034979702104465105, 0.024302924430230632, 0.024651399871800095, 0.02168888178857742, 0.007539751450167387, 0.023328966926783323, 0.034940557525260374, 0.06199136907525826, 0.03387966484297067, 0.01361065442324616, 0.03465655987383798, 0.023626933652849402, 0.02012494471273385, 0.046944080022512935, 0.05959404654277023, 0.03937561348720919, 0.007017677926342003, 0.056874932488426566, 0.02873011548217619, 0.01836080216889968, 0.04761768665048294, 0.028419454320101067, 0.04353590040409472, 0.020449098119570408, 0.06555660569574684, 0.029318230408534873, 0.026209275456494652, 0.041710539953783154, 0.023643470558454283, 0.03363781746884342, 0.06262915223487653, 0.08687757333973423, 0.03304406222014222, 0.03809390960668679, 0.043679034715751186, 0.04040204454213381, 0.03312556116725318, 0.035383051945245825, 0.07748710457235575, 0.041418553082621656, 0.005878791553186602, 0.03348090889630839, 0.0419314513419522, 0.04931850729917642, 0.043502756088855676, 0.04634558987163473, 0.001387489842272771, 0.03766091467696242, 0.081417192122899, 0.05504083324922249, 0.0129413318427396, 0.013456117012538016, 0.0019571760822145734, 0.06285547016886994, 0.02125471055478556, 0.019132307352265343, 0.13708698068512604, 0.010832142579602078, 0.12244200988789089, 0.04022970300866291, 0.023439329852408264, 0.02482635376509279, 0.034618354111444205, 0.03589723040931858, 0.04967949163983576, 0.019513626539264806, 0.038973517876002006, 0.02899188024457544, 0.022985786708886735, 0.06754196947440505, 0.01621492854610551, 0.07302680445718579, 0.02052450588962529, 0.03935301137971692, 0.034698019953793846, 0.009921599739755038, 0.08769367603235878, 0.01790811806131387, 0.008352099339390406, 0.039238056415342726, 0.03749232098925859, 0.06383164669387043, 0.01778535013727378, 0.01160768875706708, 0.039872321794973686, 0.0268851957298466, 0.004555298264676821, 0.055295144993579015, 0.06180485994264018, 0.03519611607771367, 0.049545392976142466, 0.057770522907958366, 0.003614574366110901, 0.037564754602499306, 0.06395948905264959, 0.08279599118395709, 0.043539258622331545, 0.03996992534666788, 0.1977852056734264, 0.17980645556235686, 0.07699652269366197, 0.16429458948550746, 0.2144369957386516, 0.16298615344567224, 0.1718844595598057, 0.11205410948605277, 0.17627439665375277, 0.18045331147732213, 0.1871856744401157, 0.28673495922703296, 0.20120517059694976, 0.15979180141584948, 0.08923242276068777, 0.20866666396614164, 0.1997400078107603, 0.15522333327680826, 0.08623862129752524, 0.20646597346058115, 0.10561004120972939, 0.18894831970101222, 0.143856480717659, 0.1523900212487206, 0.08651749070850201, 0.12935179809574038, 0.18085196352330968, 0.10029760713223368, 0.1588921106304042, 0.13724597840337083, 0.17762626317562535, 0.08934766345191747, 0.1697968426742591, 0.1844125654315576, 0.08158325508702546, 0.1608196907909587, 0.10620367029332556, 0.32842225511558354, 0.13765184412477538, 0.11578872276004404, 0.13541855849325657, 0.18783469742629677, 0.08615706668933854, 0.07819117265171371, 0.15639276505680755, 0.10874376719584689, 0.09774543548701331, 0.19841766392346472, 0.1931191748008132, 0.22759346320526674, 0.09430339909158647, 0.1257305924082175, 0.14532078261254355, 0.14114596444414929, 0.10791234657517634, 0.10510176653042436, 0.15588308771839365, 0.20482251711655408, 0.17837862280430272, 0.1793508807895705, 0.07878221163991839, 0.07305689854547381, 0.25288204138632864, 0.12967167858732864, 0.11650349260889925, 0.11777215695474297, 0.12048532269545831, 0.11431964885559864, 0.2840443473542109, 0.1726901053916663, 0.10613696606014855, 0.24157237872714177, 0.1534421046380885, 0.11076443493948318, 0.1742413276224397, 0.07742630041320808, 0.08893754522432573, 0.0892201773240231, 0.2578012039884925, 0.11090975487604737, 0.123879408929497, 0.11657251976430416, 0.08195556089049205, 0.16260604024864733, 0.0872429326409474, 0.20211470226058736, 0.16778317338321358, 0.08176112562068738, 0.15314926800783724, 0.05183122637390625, 0.13912042079027742, 0.20839496370172128, 0.22788601781940088, 0.09371531385113485, 0.19462723372271284, 0.13815853802952915, 0.1481646331376396, 0.13554622273659334, 0.1623509789351374, 0.19733294087927788, 0.13276567740831524, 0.12856341461883858, 0.1940212701447308, 0.12772110669175163, 0.14466509514022619, 0.11580225211218931, 0.11872086659423076, 0.13982060743728653, 0.1170246880792547, 0.12918301887111738, 0.13875492790248245, 0.15012259682407603, 0.15610389149514958, 0.16079934110166505, 0.13231902325060219, 0.17926767119206488, 0.17634153133258224, 0.1763537322403863, 0.11553876742254943, 0.13308448920724913, 0.13708082085940987, 0.17295138590270653, 0.13925604085670784, 0.1250871949014254, 0.09893725786241703, 0.11364225356373936, 0.2671069046482444, 0.16719205275876448, 0.10146756583708338, 0.20602570177288726, 0.09101227842620574, 0.13381535623921081, 0.15253291436238214, 0.0847020342189353, 0.34439508395735174, 0.23344218061538413, 0.22648338839644566, 0.08659149767481722, 0.1115258116624318, 0.14912707993062213, 0.11328579261316918, 0.14560542593244463, 0.09641821568948217, 0.08130967718898319, 0.17047776316758245, 0.1555714153801091, 0.1241239911178127, 0.1315788200008683, 0.25048021401744336, 0.1593715974013321, 0.17412308865459636, 0.2157154044834897, 0.11393367269192822, 0.12597524881130084, 0.1672183841583319, 0.1041714621533174, 0.12922511348733678, 0.16563103417865932, 0.11945761143579148, 0.17108253930928186, 0.15957298659486696, 0.1509097483358346, 0.1339959801407531, 0.06860854700789787, 0.0995419301034417, 0.12144181746407412, 0.1686243384028785, 0.08290140583994798, 0.17019708291627467, 0.12912792182760313, 0.14563986158464104, 0.13393481232924387, 0.21577778941718861, 0.14997130259871483, 0.1046330260578543, 0.11340800949255936], [0.011043116610380821, 0.037928006204310805, 0.032731258106650785, 0.0039006382030493114, 0.010739591198216658, 0.03008876708918251, 0.037112185527803376, 0.021790483660879545, 0.03988260054029524, 0.014249368050514022, 0.041959437730838545, 0.08469936248729937, 0.057045470603043213, 0.011322438731440343, 0.052073808474233374, 0.04041478350700345, 0.03953618084779009, 0.03749505209270865, 0.037686626383219846, 0.02549907538195839, 0.07124641444534063, 0.01008357625323697, 0.06252344071981497, 0.014264499513956252, 0.037216178970993496, 0.04198947244731244, 0.02637898978719022, 0.0438254567416152, 0.08509471197612584, 0.06850971520179883, 0.03197995974915102, 0.06036097081960179, 0.04502068186411634, 0.0188004931260366, 0.055566121664014645, 0.046137955505400896, 0.04997959760657977, 0.030900218371243682, 0.10143436215003021, 0.04059316241182387, 0.025977515724662226, 0.05229197020526044, 0.05374407861381769, 0.03005982518516248, 0.08934459096053615, 0.05697616143152118, 0.020478416663536336, 0.022370379301719368, 0.01739619387080893, 0.03718183237651829, 0.026820003622560762, 0.047785296992515214, 0.03384200084838085, 0.029089118288538884, 0.05920172872720286, 0.0494263821747154, 0.02373976236413, 0.03134329352178611, 0.021229802223388106, 0.004368527061160421, 0.03387873344763648, 0.030882158207532484, 0.04734269867185503, 0.03609999628679361, 0.06997034346568398, 0.02611870560940588, 0.05252404349448625, 0.04589458301779814, 0.0166860309036565, 0.01791087142919423, 0.025246290606446564, 0.026006735934060998, 0.028031190486217383, 0.021862022986169904, 0.045885591898695566, 0.014684158049931284, 0.061492968670791015, 0.010880948993872153, 0.021440436721604783, 0.05919700866797939, 0.007978119065228384, 0.009949404302460607, 0.055950836176634766, 0.0414652415929595, 0.017951008630916476, 0.045328613778110594, 0.045196351929917, 0.025812267267610878, 0.041453552767052315, 0.04512170300586149, 0.022120700414234307, 0.08886379058822058, 0.049042513710446656, 0.03256103169405833, 0.0161652009410318, 0.057798936031758785, 0.12012778563075699, 0.008877645650500199, 0.05338738759746775, 0.005081218432678725, 0.0027816399961011484, 0.03743746143300086, 0.03673566061479505, 0.02094975279760547, 0.026773098034027498, 0.054271979388431646, 0.02572631543444004, 0.040186124097090214, 0.06438739656005055, 0.022477131678897422, 0.021919691571383737, 0.0413859431137098, 0.06464423902798444, 0.04294731050322298, 0.06122586601122748, 0.02102395643305499, 0.034809045246220194, 0.02879368043068098, 0.015410566629725508, 0.0603760623926064, 0.06470314328907989, 0.03990844954387285, 0.06089650087233167, 0.014504074060823768, 0.010686824498407077, 0.030855730328767095, 0.05590960987319704, 0.046801231437711976, 0.01944829899002798, 0.03629850223660469, 0.019617196958279237, 0.011457783275545808, 0.044496736736618914, 0.03545751533238217, 0.01209673810080858, 0.01002985774903209, 0.03293463625595905, 0.04099615973245818, 0.056289574640686624, 0.06253720013774, 0.026441892368893605, 0.024072532105492428, 0.04512313535087742, 0.05123455819557421, 0.0287721414497355, 0.04770034705870785, 0.046360492196981795, 0.023156545612437185, 0.0222709333684179, 0.04672561030020006, 0.0613584766688291, 0.007847403667256003, 0.04824588497285731, 0.039747878472553566, 0.003661550226752297, 0.005772458025603555, 0.02556372757680947, 0.0973319479089696, 0.0306767706933897, 0.026382654141343664, 0.02092400027322583, 0.1141277294664178, 0.0229842448970885, 0.034666356223169714, 0.04864120106503833, 0.03961728645663243, 0.0418155686929822, 0.057543874718248844, 0.0466186593985185, 0.01706279144855216, 0.11122137526399456, 0.03892360102327075, 0.04353736985649448, 0.022582117744605057, 0.03473884549748618, 0.0058738799270940945, 0.06135083625849802, 0.05550519505050033, 0.031067799027368892, 0.035071921374765225, 0.016975652179098688, 0.018954357037728187, 0.013259579609439243, 0.05269854467769619, 0.024986828357214108, 0.04605549918778706, 0.04167210041487124, 0.07451473633409478, 0.03540235891705379, 0.028143171293777414, 0.03115854698990006, 0.018641053829924203, 0.04214243279420771, 0.07751008146442473, 0.0292453218207811, 0.04357525649538729, 0.032971424516290426, 0.03393876948393881, 0.08116993078147061, 0.007771796445013024, 0.05798496647912543, 0.023816045868443325, 0.04055563942529261, 0.021379363533924334, 0.025825943193922285, 0.014474296312982915, 0.017245181661564857, 0.01933000807184726, 0.07582217047456652, 0.03283979349362198, 0.06597789324587211, 0.03068338137381943, 0.0755442213267088, 0.0907507752708625, 0.04381464736070484, 0.04047703114338219, 0.02227856635727221, 0.020978073152946308, 0.03466538400971331, 0.04415341551066376, 0.016511015783180483, 0.02220906608272344, 0.008362016287719598, 0.06682058708975092, 0.05650701648846734, 0.00411154683206405, 0.038571874974877574, 0.01925686199683696, 0.04090512047696393, 0.034629864821908996, 0.060610978107433766, 0.03238244869862683, 0.02562871559348423, 0.022667583471047692, 0.09427579119801521, 0.008591141395299928, 0.027541163362911902, 0.04140411088883411, 0.013106045953463763, 0.03301030934380833, 0.02091522252158029, 0.009316285540990066, 0.015414439712913008, 0.015313318381231511, 0.03027064522029832, 0.039392014950863086, 0.0240227636822965, 0.062275489181047305, 0.044749330409104005, 0.031879046218818985, 0.030829246788925957, 0.009089315444725798, 0.021264629358483944, 0.01895581906865118, 0.06123891296738293, 0.017031183379003778, 0.04706387750047725, 0.060582828446058556, 0.021083040664962027, 0.055848471747594886, 0.008061485441430705, 0.05479579092934728, 0.03258172648202162, 0.062281055288622156, 0.04034612371469848, 0.04222790965286549, 0.08078650018433109, 0.05310850334353745, 0.06594730191864073, 0.024782535510894377, 0.03405386545637157, 0.014118634098849725, 0.06916225596796721, 0.02479519655025797, 0.06302255729679018, 0.038616849124082364, 0.030645552251371555, 0.027396182958909776, 0.03774122247705236, 0.02594754594611004, 0.0387735127878841, 0.06180083750223275, 0.039078405607142486, 0.028231501710251905, 0.020809614907193463, 0.052938840963179246, 0.026688897669373546, 0.10496951581444591, 0.024800363753456622, 0.018047016565105878, 0.02419811276922701, 0.017053928349923808, 0.07814564189175144, 0.087612314382568, 0.09209513867972419, 0.04347571964899544, 0.02829394601576496, 0.061490122534451075, 0.02771346964436816, 0.023004592731012963, 0.01847879251727136, 0.04416459225467406, 0.007532966365033644, 0.03820188467216212, 0.1204957053414546, 0.10995056611136533, 0.010804921530507272, 0.029391530479188077, 0.01691875913820695, 0.018106649986293633, 0.0521992908034008, 0.05690521211363375, 0.017784747142286506, 0.040445348859066144, 0.0065362184341211105, 0.07885681232437491, 0.03110020490566967, 0.04461545810045209, 0.05321296433976386, 0.08937249571317807, 0.023282092879526317, 0.02701846318814205, 0.007693128791288473, 0.052155470693833195, 0.03308083563752007, 0.01616546811419539, 0.009304525283369003, 0.03221443388611078, 0.03115912215434946, 0.05351535241061356, 0.021565275237662718, 0.034318044054089114, 0.04188394275843166, 0.013525304657378001, 0.023777454189257696, 0.02446479982609162, 0.011295736258034594, 0.02779676087811822, 0.09571966176736169, 0.00895541252248222, 0.06954105556360446, 0.05968170160485897, 0.06357366873999126, 0.07711009355261922, 0.013792566878692014, 0.036965648469049484, 0.0031429427644980024, 0.05918967624893412, 0.02922995565313613, 0.020107257478230167, 0.025841925344138872, 0.032159971378860064, 0.16196770418900996, 0.11615285009611398, 0.08669475268106908, 0.0831129401922226, 0.11903445367352106, 0.1069212231959682, 0.1043093902990222, 0.18933615123387426, 0.10148744055186398, 0.18746096669929102, 0.22558718570508063, 0.18557243834948167, 0.11562867861357518, 0.0830931322707329, 0.1953609802876599, 0.13526077789720148, 0.1704100496135652, 0.1027859392343089, 0.06395151096512564, 0.15459492715308443, 0.16157834383193403, 0.13512113539036363, 0.21652205963619053, 0.10236127491225488, 0.14463821455137804, 0.16066936135757715, 0.09084795950911939, 0.19502646464388818, 0.3671085729729384, 0.1119264675071463, 0.09825117202126421, 0.2562729438068345, 0.13684135949006304, 0.12601857539266348, 0.19359563360922039, 0.10807668033521622, 0.1291587357991375, 0.17450527986511588, 0.17834117403253913, 0.11330587512929924, 0.18996844621142372, 0.14864750410197303, 0.09330275395768695, 0.181281385011971, 0.12259101087693125, 0.11782962144934572, 0.09412639687070623, 0.186945827153977, 0.13161723356461152, 0.10656695158104412, 0.14551822358043864, 0.19387983164051548, 0.1325985012226738, 0.11266960224020295, 0.15561014064587653, 0.19019091239897534, 0.08996224336442538, 0.1417666967608966, 0.2746057725744322, 0.09299738987465389, 0.13463119918014854, 0.12136472316342406, 0.11352096436894499, 0.10312839585822076, 0.1451490051113069, 0.11397492868127301, 0.14136255282210186, 0.07852130220271647, 0.1355771702947095, 0.1066943709156476, 0.07561672915471718, 0.14205935527570546, 0.11607600070419721, 0.21028417482739314, 0.0888109570951201, 0.10298146546119824, 0.0835242384346202, 0.09615701681468636, 0.13749680947512388, 0.17915130243636668, 0.11053401292883791, 0.11220455766306259, 0.17584938352229074, 0.09685050186817534, 0.07343230652622879, 0.1386816185549833, 0.16658792970702052, 0.11671065571135841, 0.14655151579063386, 0.16014144202927127, 0.10829562132130377, 0.17305567249422893, 0.20136540028033778, 0.12807322607841343, 0.08811183914076537, 0.12106780472095124, 0.26137078588362783, 0.11005520893377252, 0.12865458003943786, 0.11849554313812405, 0.08643961715279147, 0.11187902942765504, 0.11327278276439756, 0.30933267320506275, 0.22034686611732468, 0.16358065826352686, 0.12468737026210874, 0.12051408833940513, 0.1374346620286815, 0.2190368270385079, 0.08117327786749229, 0.18532910296926275, 0.09927599632646888, 0.1495771628106013, 0.10098796032252721, 0.14357578562339768, 0.12982194864889607, 0.1713005971396342, 0.14121427171630785, 0.12566250778036192, 0.1586271045380272, 0.21012602315749973, 0.1480806665495038, 0.16999029088765383, 0.11853474337840453, 0.1447219733381644, 0.20942862698575482, 0.06947663714527152, 0.1385370481875725, 0.19375224161194637, 0.12786290142685175, 0.07698035129578784, 0.08527070487616584, 0.09156684085610323, 0.13564216758823022, 0.21633076365105808, 0.12553986045531929, 0.12213418187457137, 0.09814682605792768, 0.15866128786001354, 0.1904540037503466, 0.14299192320322618, 0.10000385766034015, 0.1604970940388739, 0.15926355554256588, 0.09823252185015008, 0.11041091289371252, 0.18187612731708214, 0.1351698796497658, 0.10970475937938318, 0.12773143738741055, 0.06484743164037354, 0.22048152139177546, 0.1288009760901332, 0.07263770385179669, 0.06319454259937629, 0.10840863556950353, 0.10918630243395455, 0.12343169350060634, 0.066149440681329, 0.0949246805976145, 0.2045727102085948, 0.1552576056565158, 0.15606970817316324, 0.15330169029766694, 0.12780287652276456, 0.1888036899617873, 0.22492573916679248, 0.1517897573648952, 0.10823660573805682, 0.171211272245273, 0.17884077300550416, 0.11427263380028307, 0.08370895899133757, 0.1403455136460252, 0.08520278352079913], [0.03548222142853774, 0.02450195730489213, 0.06564040901139379, 0.07158241438446566, 0.03155491693178192, 0.03519507707096636, 0.05359523718652781, 0.023909504525363445, 0.056012178392848, 0.04094112206075806, 0.020332603198767174, 0.008529729602742009, 0.049077446601586416, 0.08359445302630775, 0.026054116497107316, 0.010055095408461057, 0.07814320764737204, 0.051501605194061995, 0.047098487557377666, 0.020190535724395886, 0.07140495945350267, 0.10886132338782772, 0.01957182576006744, 0.01703481248114258, 0.009521726860839408, 0.06208213744685054, 0.027620396904239897, 0.03257746655435767, 0.03486029054329265, 0.023876605118857697, 0.020848494168603793, 0.058684934192569926, 0.04457275863387622, 0.05837002237967681, 0.041853826405713335, 0.02498121957614785, 0.07433342965668999, 0.052006376936333254, 0.03363510862982366, 0.08699734855326824, 0.07994018465979025, 0.03388641096535139, 0.0537523758248426, 0.13661101169418544, 0.05765650304965675, 0.02346441073314054, 0.01962158490641741, 0.016207772387133446, 0.04712504531198647, 0.01462765834730817, 0.06096652250562329, 0.04079137521330267, 0.06237292574951425, 0.05224067295785062, 0.03220526465156581, 0.013297165678523015, 0.04450729007658083, 0.0583028097753413, 0.025939412007573992, 0.018285867517988663, 0.015480028869205853, 0.06586487899767235, 0.05525893560843542, 0.010799640222103335, 0.02056175799225457, 0.06318994870525785, 0.075625664612744, 0.10918818006757647, 0.07590307199279778, 0.015257196246238891, 0.05489013645274099, 0.04146138242504094, 0.03460527746938169, 0.02592635020846501, 0.0720606543472968, 0.021527331082324963, 0.05495310397236608, 0.04629753209883347, 0.06190435597090982, 0.06945684406673536, 0.027867791832250077, 0.06243036797968671, 0.028778173254977446, 0.02653947736689588, 0.029932873403595295, 0.008301331799884792, 0.02147861279809149, 0.021010749915149063, 0.0305434698384488, 0.0726669147843495, 0.07779924446367659, 0.07525033826823346, 0.0170479763255571, 0.017195756481669378, 0.010068854826386087, 0.07910264132078737, 0.06457288152887486, 0.04332459982833825, 0.06816522509325296, 0.0242210655414965, 0.0528425324591808, 0.038356971272150986, 0.025550901409587823, 0.08544437485397793, 0.05926210244069807, 0.0560512858646689, 0.023558980756206438, 0.016008813727239612, 0.09078458751901053, 0.03035559886484407, 0.05260698962956667, 0.029310565878404304, 0.01992780245927861, 0.017395878458046354, 0.014436349374591373, 0.0354516226798296, 0.015583572385367006, 0.03078424109844491, 0.044082061722292565, 0.050729515569400974, 0.033513366724946536, 0.007195696425696951, 0.08505580117343925, 0.04591541881382, 0.001674623647431872, 0.040839221474016085, 0.03470249881502241, 0.007021670680842362, 0.07523490901803598, 0.015145826782827498, 0.04410072673636023, 0.07957489215186797, 0.1156897573673632, 0.030070502834860235, 0.05907542632485274, 0.024891102439141832, 0.05369817306927871, 0.03563613172445912, 0.05272380367387086, 0.029629754317284096, 0.004005623804914649, 0.031513234207523055, 0.015050649126351345, 0.0328929720853921, 0.024160328175639734, 0.06796889734687284, 0.03950070618884638, 0.027808141712739598, 0.042728221087600105, 0.06451621113228612, 0.04767048674693797, 0.010413224335934501, 0.05713630576792639, 0.01970638826605864, 0.049040090598282404, 0.04193723638309166, 0.11885529922437854, 0.015186229302344145, 0.030603529994550627, 0.03428398318646941, 0.03989280136011075, 0.11761166009819135, 0.03625593635661062, 0.016632214064884465, 0.028031086585542653, 0.05501589708728716, 0.12180469057057053, 0.050556461574160494, 0.12911483034258708, 0.05180248299438972, 0.0227878021178185, 0.06605247166589834, 0.02644682022946654, 0.07264722560648806, 0.10932393372058868, 0.031545435995212756, 0.05643722863169387, 0.0314891440939391, 0.01076936059689615, 0.0626043719239533, 0.08055376267293468, 0.05886392536922358, 0.06417674536351115, 0.04022355060442351, 0.023438747266482096, 0.020411385885381605, 0.03892048400302883, 0.006876317811475019, 0.020286727340135258, 0.013520397205866175, 0.04327280163124669, 0.07274815026903525, 0.04461818920390215, 0.05312071538355667, 0.03905842328094877, 0.061818226022296585, 0.03522248829540331, 0.046327856252901256, 0.04449787222256418, 0.023978782155609224, 0.012802187502529705, 0.029872393934056163, 0.02179790328227682, 0.009878537548502209, 0.014364366616064217, 0.0716701585042756, 0.07752011530101299, 0.1090754329925403, 0.04490283623454161, 0.04551656267722137, 0.057025940986932255, 0.024924244899011683, 0.0410681072389707, 0.006573843465957907, 0.023574988881591707, 0.08397236204473302, 0.03769534290768206, 0.021807788689329755, 0.045144613104639575, 0.07559391553513706, 0.03910388724762015, 0.025359453284181654, 0.03939518763218075, 0.048913079444901086, 0.057501657647662796, 0.012903601982543478, 0.03552785608917475, 0.023087750378181227, 0.04432605019246694, 0.02191108636907302, 0.08133641676977277, 0.049850864670588635, 0.05253504954453092, 0.030319356083055027, 0.03489379108941648, 0.028261924198886845, 0.015114774396352004, 0.05069624137831852, 0.05988346558297053, 0.03217680328816641, 0.0616070182149997, 0.00857507760883891, 0.036005565416417085, 0.07855377858504653, 0.05106304044602439, 0.07146837597247213, 0.025985076354118064, 0.038001831344445236, 0.029997742676641792, 0.035567353188525885, 0.028920587683387566, 0.04923855572997127, 0.07694906234974042, 0.0728231665561907, 0.07721082525677048, 0.026991627128154505, 0.07178819709224626, 0.035701641099876724, 0.006564693712789449, 0.04436067880305927, 0.06554864245117642, 0.03552354421117343, 0.03401622743695043, 0.052241893790778704, 0.13985878351377323, 0.02722040342632681, 0.08837738700094633, 0.03516682350891642, 0.08602845991845243, 0.031563648299197666, 0.04564290589769371, 0.06826324795838445, 0.07335323811275885, 0.03951024278649129, 0.028040155630151276, 0.05433236794488039, 0.03148871735902503, 0.05627850550808944, 0.13242045999504626, 0.028017970980727114, 0.013137172554706922, 0.04196248424705118, 0.04691734415246174, 0.04543041046417784, 0.01683368675003294, 0.020253570037311874, 0.06020711247401778, 0.059399767123977654, 0.03553053153154906, 0.040492950211046264, 0.044456927935243584, 0.05189735173189547, 0.01916587098094169, 0.009835966102400562, 0.046871943268342875, 0.03016498751094332, 0.053443211945705116, 0.023394760173687246, 0.03385515170521103, 0.03134340113319922, 0.03219504527805839, 0.03040690724446904, 0.02170437597669661, 0.029688738359254785, 0.030639501892437693, 0.007773752467983286, 0.02107988839270547, 0.029576082197309006, 0.008646758869872428, 0.028329467058938462, 0.024682260227564257, 0.042134306277148426, 0.01942696781043196, 0.03660830065200571, 0.024917159244068898, 0.04742819779494312, 0.04024063113320153, 0.02885940131818643, 0.03905693898559548, 0.020457974205783103, 0.05262200327706523, 0.03196007019141689, 0.023693118382652756, 0.08644493093015626, 0.058154844082309864, 0.029339396460272837, 0.04398173448862508, 0.016308218364429194, 0.03647656943940092, 0.039432283883797936, 0.044779361414839514, 0.039012521447148174, 0.03735542071808595, 0.016350476253137458, 0.022986040894465987, 0.011550189938134281, 0.04821723807253875, 0.14063650975003839, 0.049559267426957376, 0.03016178699908778, 0.02091876998747466, 0.01849615506216651, 0.041346356956637464, 0.014367914081958588, 0.0396772037493065, 0.05926790603552945, 0.029211394539743196, 0.05948173733486328, 0.0344190355099272, 0.033854583962238394, 0.04564260903862305, 0.034688483356148936, 0.1900863289483823, 0.1395491891889833, 0.11627779807895422, 0.22242608189117163, 0.14563135657226667, 0.12750757596222684, 0.1602549312519841, 0.05384012736612931, 0.08663805259857327, 0.1515750985709019, 0.11317361699184403, 0.06887896335683763, 0.11655804046313278, 0.1120887826255057, 0.23976274067535996, 0.15922707156278193, 0.12553804961498827, 0.11426878205384128, 0.1764986291527748, 0.11487090130685829, 0.15657560055842623, 0.30365972605068237, 0.12331730627920479, 0.13956026203231886, 0.10680792693165131, 0.12487635074649006, 0.08393581869313493, 0.14992597221862525, 0.13706268277019262, 0.27926340233534575, 0.161217778804712, 0.1547319276141934, 0.09896017538267188, 0.2293362931231968, 0.24761190230492502, 0.11298239522147924, 0.12469639477785677, 0.06489432053058408, 0.1492568667163141, 0.17901915562106296, 0.11899583230842836, 0.09444208422792144, 0.13569992152042687, 0.32766119751613587, 0.20033627894008532, 0.138934779970441, 0.16023734235204756, 0.13736651802901179, 0.11595172807574272, 0.1097597302577924, 0.14658436324680224, 0.10494468355318531, 0.13617931923363358, 0.110487517376896, 0.13158947724150494, 0.09336083443486132, 0.17056518816389143, 0.18050606333417818, 0.1150452540605329, 0.1305332378251478, 0.119696033798391, 0.1379172658198513, 0.2449689808418043, 0.061820727059966885, 0.10730863170465454, 0.10584515359369107, 0.12497572432039306, 0.27175922063179314, 0.16250537533778697, 0.15541148255579174, 0.1729435339802876, 0.11839731247164309, 0.1290941095794551, 0.16282074357150123, 0.14608924684580415, 0.06741625707945786, 0.1013688305101823, 0.12267796089872718, 0.19537110318196937, 0.13241318694781512, 0.15377995994640514, 0.10685316083254293, 0.10220888230833225, 0.13103767560096458, 0.19866604590788484, 0.06634495948674157, 0.13741484668571502, 0.11823123466456309, 0.1558915333589539, 0.11973367552855052, 0.20830427325563505, 0.16482626408105716, 0.20781478233402595, 0.09725963303935714, 0.1038555966806598, 0.14693784818518907, 0.122709205315914, 0.13606977823656052, 0.16587306337896734, 0.15266326518030837, 0.13674167421413586, 0.12047130352584645, 0.2291646195226349, 0.14177830395055935, 0.11726951517630368, 0.1721783055108972, 0.13135599758243188, 0.12706810579402372, 0.1827613462228328, 0.09425731172086671, 0.13520480511942878, 0.19512438360834494, 0.11859931764774956, 0.26344669167883694, 0.24607632454717532, 0.1313652002136223, 0.10245462966850027, 0.08926020134822465, 0.13321059494046494, 0.14133135293377563, 0.1323946035699919, 0.08571111015044153, 0.1148876738443505, 0.08440731253358535, 0.13194809784181416, 0.08622383029432967, 0.0931554524868261, 0.12736359931295738, 0.15693579451180995, 0.1532397061237134, 0.12117414706153795, 0.1655362025485374, 0.11583282117499039, 0.1637714050593786, 0.15733950800495222, 0.07670964550925419, 0.1142270139825996, 0.10805454207002185, 0.23178086819825694, 0.08478419738821685, 0.10340909095248207, 0.09229974137269892, 0.08523410957423039, 0.1339921506587416, 0.15721202187705785, 0.09301744270487688, 0.12630249140784144, 0.20155737904133275, 0.22763183224014938, 0.15283398883184418, 0.13534710451494902, 0.16560424264753237, 0.15249427815433592, 0.10789494321215898, 0.14859231800073758, 0.10096090903971344, 0.15586042252834886, 0.06888840347528458, 0.11026972671970725, 0.14238159579690546, 0.14138211583485827, 0.24570349924033508, 0.16849646635819227, 0.11929885862627998, 0.08654063829453662, 0.14519856573315337, 0.12416985584422946, 0.18977294967044145, 0.21827582881087437, 0.2567619300680235, 0.1356157471309416, 0.15908627130556852, 0.09147022807155736, 0.19103363592876121, 0.13790402590529993, 0.1896459682029672], [0.03336402434797492, 0.048713308133301325, 0.029931567223684397, 0.025830295890045818, 0.04192289066850208, 0.021748071776528377, 0.025778308445296716, 0.06454626069171354, 0.036237330714357086, 0.05411831400124356, 0.09366296275402419, 0.00546302836482937, 0.027480192220536992, 0.08073996010352857, 0.039916249515954405, 0.006987875131017063, 0.09394571359734982, 0.013853037071385188, 0.03420591296162456, 0.02932074072305113, 0.064878846751526, 0.015940133525873534, 0.06128018008894287, 0.04890540934866294, 0.01409511543897679, 0.005706003803425119, 0.023202011434477754, 0.05218275575316511, 0.07929082770715468, 0.06168752268422395, 0.03434981910686474, 0.017692025066935457, 0.014435939338000026, 0.03703235641296487, 0.019447649610810913, 0.036488247133092955, 0.023821654649509583, 0.032825841117301024, 0.00633624998954474, 0.009494737732893554, 0.02699529519304633, 0.03281050463556312, 0.1412368330056779, 0.022269551118370146, 0.040353051663259976, 0.01749048002238851, 0.01676955962466309, 0.03852034395094961, 0.011504097001306945, 0.011476723811938427, 0.025282700371462852, 0.052340621696203016, 0.018349606871197466, 0.06658886632067151, 0.015107305607671151, 0.027535220615391154, 0.0006170647736780666, 0.005356712927095941, 0.019725535676116124, 0.08111800270853564, 0.026875954135903157, 0.05198365237447433, 0.07415797852445394, 0.04655623735743575, 0.10955808131257072, 0.025599448999855667, 0.06729918328346685, 0.02321939438843401, 0.036572825993062, 0.021143976555322297, 0.05243983570835553, 0.01928401346958708, 0.08512624583090656, 0.08614308462711051, 0.019828586591756903, 0.0569295026070904, 0.03421943860303145, 0.041243799569201656, 0.01639945799979614, 0.04941192142723594, 0.09424409407074563, 0.022787867055740207, 0.036281306674936786, 0.033976158883888274, 0.04301861976273358, 0.08412758223130368, 0.02254375798656838, 0.03288026651716791, 0.05340582625649404, 0.011007935099769384, 0.05033397312217858, 0.017135807647719048, 0.02239824509160826, 0.03636592264228966, 0.08989569498226047, 0.022570512410311494, 0.07183800262282602, 0.06528231533593498, 0.03811702750681434, 0.045190607706899755, 0.020859396317973733, 0.04922887441352941, 0.06292008896707557, 0.018988816809724085, 0.03616241461713798, 0.08668386537465267, 0.008880172663339181, 0.027057145780418068, 0.09206451024510898, 0.029547309131885413, 0.026364981749793515, 0.024169497410184704, 0.04986490610463079, 0.013789901640848257, 0.01001371696474962, 0.059226312368991785, 0.035547786465031095, 0.011106814217782812, 0.05299822019878775, 0.0600154008861864, 0.0671931155375205, 0.03530327849148307, 0.02027645787165966, 0.11034269467927516, 0.06279307039221749, 0.08985776381450705, 0.05090262151497882, 0.0424253246455919, 0.07346502781729214, 0.022796561315772124, 0.08892662081052549, 0.015393282010336407, 0.04810682134120725, 0.043239238002570346, 0.02808004050166346, 0.01889765881060157, 0.09250176139175892, 0.021277359046507627, 0.014857438400213141, 0.03794922791712452, 0.03346177632920444, 0.0366613308142405, 0.02805714339046972, 0.0862291143857874, 0.029578182475233916, 0.0888531852979213, 0.07307631312869489, 0.03433837147895247, 0.026868950117204804, 0.051142873271601275, 0.056815579227986746, 0.09043989703059196, 0.034544506706879474, 0.0059677991794160334, 0.021398368080554064, 0.04152335546677932, 0.02598443068563938, 0.025966242501453962, 0.02345635472011054, 0.029990887087478768, 0.02756650956143858, 0.029231762782728765, 0.02226442473329371, 0.06092741874454077, 0.035875247995136306, 0.0806163702509366, 0.044436247990233824, 0.036412425615708344, 0.040873556936276145, 0.0193437433699728, 0.029570857477665413, 0.015565695903205778, 0.0414931055274792, 0.03342226438689977, 0.019834659215121064, 0.06402113183867186, 0.012689785526163178, 0.03360674745636061, 0.034803594171535224, 0.007879463519202545, 0.04921136343909893, 0.026441144655109383, 0.025287214484706055, 0.08371250645723194, 0.09228707291185856, 0.02922755851614056, 0.03029103943845257, 0.09063311517820694, 0.06116843862400856, 0.016456380726594944, 0.09112461732001975, 0.011912647441931767, 0.03375248299562372, 0.07782146436511539, 0.0032198584858633694, 0.047172654085443355, 0.02501743452739902, 0.071377618733095, 0.07545012442278676, 0.019698675496329088, 0.06540344125824049, 0.03869648899126332, 0.046923826812417246, 0.048977731639752164, 0.028377322596497834, 0.09274871103116311, 0.020623081654775888, 0.005061841420683777, 0.008822544896247564, 0.018865774291043635, 0.033331763188471086, 0.01515130847110413, 0.017857045313576236, 0.045151247904868796, 0.012453972740331665, 0.09240048791980371, 0.12199948949273676, 0.012152468752901768, 0.04911070594971534, 0.0160607158250059, 0.057423220059718005, 0.05547303779167123, 0.028578233104781248, 0.04079326397913974, 0.058182559587294236, 0.004421753428687225, 0.014080818891670788, 0.022506580098706763, 0.025147826163447462, 0.014970111260481644, 0.016486539752804674, 0.05010561799281277, 0.04762600612593815, 0.030482736183330417, 0.07603772726724856, 0.05544564141018782, 0.07876431103795767, 0.048683332788641565, 0.04145436912949663, 0.0325676108332118, 0.05568276872509159, 0.034636484779184684, 0.05619464282062836, 0.03937278961529955, 0.02833449139870936, 0.028339858981780708, 0.06790329149225727, 0.010609025157464202, 0.04274945393262897, 0.05658501249854453, 0.002562721274443902, 0.015394037145597395, 0.04033244593301788, 0.12149570480687544, 0.014496813073492376, 0.031007202669570688, 0.0177626162985689, 0.026962618430843577, 0.039408286538673565, 0.008894712264009286, 0.04758152921567671, 0.035990176984341815, 0.04377745462988969, 0.09149454825092107, 0.08897201798390597, 0.033607845834922045, 0.02986402621900197, 0.06211684027221054, 0.0850561870902311, 0.03263320555561222, 0.028372661909088492, 0.06456513350713067, 0.030781148198002484, 0.02300024003488943, 0.035692805831786245, 0.08975245305919088, 0.02054283508186927, 0.019212936131225433, 0.047732418970554136, 0.02392623067862587, 0.020550939334498253, 0.0238891975095612, 0.039681181660853326, 0.02053964384685969, 0.009166374493361218, 0.037865383783355355, 0.021761389616585802, 0.03306389982753899, 0.025770053907763213, 0.02846913739631418, 0.027375180179660674, 0.04026011622045189, 0.030135615161270835, 0.03502925159409642, 0.020037241411046125, 0.033354840270476416, 0.019876924525306094, 0.05937616682786029, 0.03326031663164031, 0.05068987746199127, 0.039000817778287455, 0.03285543054516893, 0.03553063543222379, 0.07815995792043395, 0.03953276696847752, 0.06482230252004229, 0.08823615629808046, 0.039044081277097575, 0.023606565409863833, 0.04313940058636945, 0.10829079736140557, 0.03283915153588168, 0.03722358189406805, 0.04140319433645345, 0.022217233417904936, 0.041223613152396865, 0.018816911288013216, 0.04635423218132928, 0.015754110499983653, 0.04467909726372454, 0.05902593991777394, 0.06593947968212888, 0.03929526857973542, 0.03330814804940019, 0.034320467166253366, 0.034516553714638576, 0.042223723939969204, 0.030305900945677422, 0.024968207872007042, 0.03190421615727246, 0.04577585794322658, 0.03500823397189379, 0.029862493684049696, 0.010036614075943362, 0.024324296427948866, 0.02518805798899848, 0.025266582779295277, 0.033022821953636594, 0.018925836302514654, 0.040620414074510336, 0.0481577586469939, 0.09716857151943259, 0.039095330284908414, 0.03843603597488254, 0.024016722600208595, 0.02147989671357209, 0.026291260510333814, 0.02604586010420462, 0.03833313719951548, 0.04405621642945334, 0.011070076980104204, 0.055263343965634704, 0.10079394065542147, 0.11398529648431577, 0.1353061676491052, 0.16181931918254122, 0.15544930240139365, 0.1201385838794522, 0.07577313677757047, 0.20795025397092104, 0.17910911876242608, 0.1331618952099234, 0.1434834921383299, 0.19852598779834807, 0.1649327771156095, 0.1003764157940168, 0.17298292717896402, 0.049781058260123245, 0.10626911287545227, 0.14242698554880917, 0.1285362965427339, 0.15183890238404274, 0.17969688487937674, 0.1311301620444283, 0.2364928528550081, 0.12584172160131857, 0.2621773519786075, 0.14140044688247144, 0.15777976484969258, 0.13913918228354305, 0.19862582150381058, 0.26247257832437754, 0.07457847939804196, 0.14041695278137922, 0.109060315444367, 0.14681245491374284, 0.10373208846431226, 0.11453296436229721, 0.07550021939096041, 0.19418458716245368, 0.08662048596306704, 0.178531534911599, 0.18599436414660886, 0.17139388510258868, 0.25061006017494947, 0.20432274002814665, 0.1906822735327296, 0.1096767581475433, 0.0910113581630867, 0.17709512292640284, 0.20952688733814284, 0.13874928758013994, 0.12011741040623747, 0.12988892005523667, 0.07000675323070027, 0.17870475217932835, 0.09504296409431845, 0.1104664255399257, 0.14834126428468153, 0.13908583670854568, 0.17454759712563828, 0.15995358960935846, 0.22799205587944016, 0.1476367434952408, 0.12181591184344143, 0.10199578944593668, 0.16256615723250434, 0.12196574403787963, 0.14475876901997253, 0.14481699792668223, 0.14742345025297254, 0.11589269764954224, 0.1762995554599911, 0.11008767789462581, 0.23420500452630222, 0.25968720903620124, 0.11927890969673172, 0.08693845913512632, 0.1440233303583227, 0.17083780869143084, 0.1385480468161404, 0.1269978837808594, 0.13463652780046687, 0.07567896565888077, 0.09220913256285712, 0.0856772311090026, 0.0832999985141214, 0.16025454533519223, 0.22040720272343606, 0.12772668764228, 0.20838844764512032, 0.065496283932589, 0.11828339280327782, 0.09659845367423259, 0.1992214989149943, 0.20766997447935864, 0.13246408343547955, 0.19388671877095476, 0.1784201682312414, 0.3117352427216247, 0.16420612548245117, 0.19076304888585582, 0.11630826324108057, 0.07215410558274016, 0.1163826190168038, 0.07030726366792805, 0.13777138927252963, 0.1915462373290211, 0.09351359811262228, 0.22654599597444758, 0.15208246040856466, 0.15478369983611628, 0.11291063696262427, 0.09345855301944539, 0.08333545090863481, 0.19584940251661465, 0.10446001659147441, 0.21299201936926693, 0.11504574387799948, 0.153653483139351, 0.11734052386600524, 0.20280497381463647, 0.18258950934978202, 0.2509985299548134, 0.08981464503449388, 0.21229640435194597, 0.10688459820812568, 0.14210707537131384, 0.11951067499467172, 0.1677863349323161, 0.15617259952705353, 0.15686858561821282, 0.14119889441644773, 0.14708273025462404, 0.16343056631740183, 0.1642337185330689, 0.15314336051233113, 0.2559038292383775, 0.2450510920607485, 0.15406789840199053, 0.051616938653751276, 0.09429713536519557, 0.11729492631275207, 0.1363748306175694, 0.1041445073497016, 0.17150694387964904, 0.08931139469495974, 0.2763757947832346, 0.10057578634587117, 0.11171551945153624, 0.11641314355074428, 0.12663207919104025, 0.08684800617629662, 0.12593025981914252, 0.08953823955380358, 0.14448246743995696, 0.20156417711405084, 0.06703929058858193, 0.10808730046846904, 0.09521397718344815, 0.07406420074403286, 0.11375172034604475, 0.11781695298850536, 0.07559523655800149, 0.10574666317552328, 0.17122311692219228, 0.09473935147980228, 0.20240020647179335, 0.24471035721944645, 0.1293605109094642, 0.09564853433403187, 0.19086889398749918, 0.12596276588737965, 0.10671155163436197, 0.14223364123608917, 0.15280399122275412, 0.23003986396361142, 0.14512458845274523], [0.050908837001770735, 0.0519694068498211, 0.03719078638823703, 0.021801823677378707, 0.04347250986029394, 0.0397261372563662, 0.02958392669825116, 0.027177806005056482, 0.021903598099015653, 0.04807800374692306, 0.04959709469403606, 0.00427803653110459, 0.0641238599200733, 0.013693643231817987, 0.016368927899748087, 0.014748275898455177, 0.044553473926498555, 0.03794993295741733, 0.05001873847504612, 0.036180033202981576, 0.02495906090189237, 0.05469051728141494, 0.01324201854004059, 0.0428684944199631, 0.027971839081146754, 0.05208592403505463, 0.04821909715246875, 0.021222518043941818, 0.06400234065949917, 0.023943769483594224, 0.04741942189866677, 0.025146506995952222, 0.04160585260251537, 0.030170353238645475, 0.024225856104749255, 0.06856972526293248, 0.05627798971545417, 0.03153474535793066, 0.06682130697299726, 0.024581498837505933, 0.0239241433882853, 0.0912752361909952, 0.040855919796740636, 0.015015289500297513, 0.07597865231218748, 0.05619787858449854, 0.05467692855745554, 0.009006006584968418, 0.0006249295097404683, 0.025895506551023573, 0.061007574404357, 0.06612283468712121, 0.04537403321592137, 0.018892222578870133, 0.02469170776748797, 0.06328525530989282, 0.0731477967929095, 0.029753735652775504, 0.040226337368949316, 0.08117509612930007, 0.05009101994801313, 0.021894295277888887, 0.03447257404332049, 0.039829251254559495, 0.04671016620704904, 0.044174796785227954, 0.038057844940340146, 0.026870887122640852, 0.030525294641847722, 0.05827889035572298, 0.03514119343890343, 0.03144507536489982, 0.05341354830306955, 0.01055655995514826, 0.022975127612880897, 0.03589483327232301, 0.012796221562894061, 0.0906156376004219, 0.027146207212354057, 0.04101356680621393, 0.039783108222763985, 0.06741791206877679, 0.010392452550149756, 0.04554569939500652, 0.026818148253369145, 0.02730524018261349, 0.03239290927012917, 0.003785016001529584, 0.0567819933348801, 0.022758047562092543, 0.03380514208402019, 0.017268396040890366, 0.023080633181962185, 0.04537522436294239, 0.011537919453985523, 0.040434940237901174, 0.025753281370270997, 0.04551816942694131, 0.01649095182074234, 0.03928723112039734, 0.05106219068693463, 0.07335092261200771, 0.0328887232899433, 0.059831830658367835, 0.024450448545394465, 0.023132633614295628, 0.01615346202015644, 0.012957532926520798, 0.07878368109231815, 0.028666580219578464, 0.024875372619135305, 0.043629195788525976, 0.04370659065898508, 0.06148162494355347, 0.015167678393481765, 0.05819655649247579, 0.024208181857829913, 0.03408605611184612, 0.007980810278240824, 0.026279532721673604, 0.0768233351118397, 0.06585592869669199, 0.026592474132485222, 0.04547162192466203, 0.020271632056392264, 0.022586362829315476, 0.03511312541377265, 0.012609230034286156, 0.06757357012247667, 0.06516304478282109, 0.03598175731895026, 0.047431444691028446, 0.02718950781854801, 0.025660084320406895, 0.04354125871032011, 0.06310331780696288, 0.03980876055720728, 0.03239509118429851, 0.027646785820252262, 0.06741949284332804, 0.03189422684954479, 0.07229768147226423, 0.029588557699753437, 0.004006803819720517, 0.008946233083406696, 0.024711990663490724, 0.004910696552542504, 0.07993247374542989, 0.03951515580411069, 0.02071471833914984, 0.019919855913030915, 0.016397326180594973, 0.02290438424097374, 0.030853236712573562, 0.07958940856042318, 0.043544342333916575, 0.031576235123793595, 0.024120979505823925, 0.07555717180366628, 0.04609941577655263, 0.07715352403465658, 0.01600409552338533, 0.029529798157454934, 0.06959817867027596, 0.058768336748471484, 0.034315509619773366, 0.04884975198365282, 0.014545436733897077, 0.05898645395063795, 0.01916169454489136, 0.04620512729161419, 0.03460388594248798, 0.052278997463872656, 0.026264847474521957, 0.017094436625484377, 0.025835615233518183, 0.04647375135391485, 0.016020304028643295, 0.10138347308384255, 0.06492825894383714, 0.014946208539186046, 0.07275906726135872, 0.009177929732686607, 0.06525693388539366, 0.008176603678293759, 0.014822403463767841, 0.01782988827471854, 0.03565555001841858, 0.045765059694531374, 0.01504964537161868, 0.024055186258920003, 0.010461931487952825, 0.02628140849992633, 0.036961622317903675, 0.024204293004004285, 0.07382989730103873, 0.023203248965728562, 0.08498223207425326, 0.03923109878087416, 0.04112730464839842, 0.027347132563591003, 0.09125798867898993, 0.020831619585806038, 0.0144955903851951, 0.07129151475965045, 0.05155014165211469, 0.01522062784715672, 0.006324983723970945, 0.04852046105952468, 0.02068781734124059, 0.01869162191724172, 0.04660910795792006, 0.004504463468038011, 0.02806897507980466, 0.056044487791950814, 0.04366979126643855, 0.042831286846194416, 0.03204361746611539, 0.05999333683575969, 0.03688768956635613, 0.028302994651312474, 0.04965521227859426, 0.0838145220768638, 0.029229608699097298, 0.020133624129812233, 0.051229956879979, 0.054241944671957754, 0.16002633492462337, 0.009807880451262463, 0.03068169484322425, 0.043458583459141664, 0.02490897892130306, 0.01913913140015211, 0.039590580272488296, 0.03484794120595325, 0.11608478773268871, 0.037118838881724514, 0.020849618522333913, 0.039553925598738715, 0.03686051582917571, 0.027008863507944625, 0.05966668795736041, 0.035831936256727204, 0.008469056247122353, 0.03334582688694354, 0.07340239055338316, 0.05407054195529781, 0.028123127740400378, 0.058950181482941844, 0.05978390276140999, 0.021876954997424036, 0.051428585284156725, 0.03952093713451177, 0.055706721541355364, 0.010732770861068275, 0.05410711499280296, 0.03230746209737845, 0.04621251908247359, 0.017306460795225576, 0.02940686510555679, 0.059169244923396036, 0.004053190368722426, 0.034626376727828756, 0.06264340147026815, 0.07616844173753634, 0.02661541206180118, 0.0362057671736693, 0.025381923660461325, 0.045159073852119036, 0.059191895270487294, 0.022753564990125597, 0.08569763274863362, 0.02613042226585094, 0.05489006594871171, 0.04717921096016653, 0.039939270936883986, 0.026861172409553546, 0.09463942871661857, 0.03448196963290684, 0.05066889694717247, 0.09203886162140407, 0.03862778838083614, 0.07418779059662484, 0.020392774677020498, 0.03651994054962415, 0.017125317390309647, 0.04615009333065245, 0.05030841726693325, 0.032976459988276474, 0.026157955944654532, 0.057540342095308006, 0.02124281949363649, 0.026628909872670192, 0.0335729537619045, 0.03989282362454105, 0.032186184034799226, 0.06106521701440215, 0.05416190033429302, 0.02416620969597716, 0.08472117420751601, 0.035753617412410676, 0.032993696368066594, 0.015403939250973053, 0.017408103485649917, 0.07991933773155324, 0.0876931862148922, 0.016363747708965093, 0.04756535039632581, 0.04616833532054443, 0.04055446683196351, 0.013653578389494214, 0.07616455288371071, 0.0632849510293454, 0.012027227621729253, 0.051393229368841276, 0.019631353425211273, 0.011421426388551481, 0.03807673630944919, 0.01972943380678771, 0.041771481410251, 0.015983443408913445, 0.04023298330139369, 0.0135322984715458, 0.028508079740277026, 0.06708003449602984, 0.031793094385648146, 0.051861509709851816, 0.051624293337226845, 0.018212398608739022, 0.0796256327885203, 0.07943013624753803, 0.015538997140538413, 0.011743097311409656, 0.048739231351646595, 0.0551469306810759, 0.04435748756804969, 0.060847756612929516, 0.06546464617713355, 0.041945644916268066, 0.03655827618786134, 0.04769897408550605, 0.01771508359524887, 0.05432214486063458, 0.040956514203571714, 0.030432238600042183, 0.03827789914794266, 0.047100747397053055, 0.053195646323729306, 0.007671660314372275, 0.0226697950711241, 0.06389703732565977, 0.0929042577627115, 0.15361627185484394, 0.17281263397308066, 0.1604454850894399, 0.1273883128305897, 0.17767113342415541, 0.15305694483686239, 0.09741075657075271, 0.10083701490657404, 0.09393433647346683, 0.21422699763206765, 0.11824711662484333, 0.14942097041057423, 0.2049515617545694, 0.16769916226621717, 0.1316947879968211, 0.11916167262825184, 0.0905243682791479, 0.1549487534794025, 0.14173521485645324, 0.2070508006727323, 0.11882801045430824, 0.1660408778116107, 0.10897197018493898, 0.12057438783813268, 0.10874428669922054, 0.13945322949439287, 0.17632017232244834, 0.05426119969342835, 0.0896191930223722, 0.10090020135976374, 0.1037168967013713, 0.125208031386137, 0.12264403732842766, 0.137665648071561, 0.11241106025408953, 0.11270240516751073, 0.13220997207099572, 0.16542869503609836, 0.09634898815420456, 0.1466044902917929, 0.1802864024648443, 0.1527213308145292, 0.1341686927480623, 0.13613364746561274, 0.17746135796187446, 0.2464244660222903, 0.15227040188619867, 0.15998747607227415, 0.10540676696109585, 0.10467802247148938, 0.15094099275302142, 0.271809182013385, 0.14954168815165758, 0.15584749431582168, 0.1005115089355968, 0.1349845653749071, 0.18456184101523831, 0.09922992379870266, 0.1364197750808671, 0.18440949294017628, 0.1284311490599066, 0.14680258434964344, 0.11039138698833995, 0.12836009584134445, 0.09874939802102745, 0.09266806926461868, 0.09050894645042717, 0.10381152795162052, 0.11232120843487792, 0.1565565273631364, 0.12423810374457389, 0.19222975533921272, 0.16613556101219729, 0.1706366569851525, 0.14859303046250716, 0.11576956050703302, 0.11082630036980845, 0.21062715095467865, 0.1096530984796118, 0.11941907912841998, 0.13137348258169368, 0.16382255387725309, 0.11600373036344536, 0.10364294910687022, 0.22062885254854336, 0.10342503970605321, 0.11800958483945578, 0.09317467411165126, 0.11084487632615492, 0.15058335178764537, 0.13802287343423814, 0.09072016167920083, 0.1229363915626891, 0.14543709199642763, 0.0855697161750868, 0.2580333180958405, 0.17411223845556378, 0.2435505436733365, 0.177372136968188, 0.12931325094541535, 0.08699634665390477, 0.2513751550577581, 0.15542488574283198, 0.18907421763287857, 0.1594892723369412, 0.1392571986070834, 0.136972036852967, 0.08809550447040237, 0.21621035761199892, 0.12437657365808263, 0.1903040157048963, 0.13829396513756365, 0.11313634633552283, 0.11537176935235038, 0.09346127670141868, 0.13487805234035477, 0.07890016859164461, 0.0991935288766399, 0.12924847629619762, 0.06540337446494959, 0.22414623177610338, 0.25311572884675115, 0.0792860853835009, 0.16805867344373837, 0.0944028765661642, 0.1233492186293006, 0.09999432106269524, 0.0911354081472382, 0.11007672379491851, 0.16470931645017117, 0.09635281763621606, 0.11682071621180512, 0.07923176759504713, 0.14603582705603912, 0.12266310310224071, 0.17435582616599277, 0.21086487569846213, 0.1918147166725248, 0.11791954006184824, 0.2371916887932457, 0.10818635491887107, 0.1323223629151471, 0.08973816671641544, 0.15144171979045495, 0.11242044842219912, 0.09649471627199091, 0.12040105182677507, 0.12110953568480909, 0.12055440180120058, 0.08521683979779482, 0.14726252295076847, 0.09362054901430383, 0.13631630485178903, 0.14049783203518018, 0.1418106467463076, 0.12813393375836313, 0.09803398992517032, 0.09934096393408254, 0.1864166758605279, 0.10827897494891658, 0.16681958368280903, 0.16289043123833835, 0.10911327510257252, 0.15485647483728826, 0.15420334035297856, 0.09564495718223043, 0.13779145694570616, 0.13042016420513391, 0.18880006828112528, 0.133154280774761, 0.13490422046743333, 0.0851468849577941, 0.12732828792650253, 0.1372728293063119, 0.12560217117425054, 0.16605330136371776], [0.02187453930673655, 0.06722493140841834, 0.017544558468216565, 0.02693325721338624, 0.10936815830064006, 0.061744070626446046, 0.01425134494638769, 0.039393117040162906, 0.07164621682022698, 0.02107433527271496, 0.050458160403650254, 0.09859859361313283, 0.03804125422902871, 0.11215278544113971, 0.060795565077569336, 0.040327644237549976, 0.02082162656733999, 0.016785231928224675, 0.017205747644766234, 0.04907471920887474, 0.05272475362289697, 0.05805448345199693, 0.006423144814107218, 0.015008538739493815, 0.06134305484010838, 0.03632956853834912, 0.04278589338355232, 0.05967263627098873, 0.04427101252076682, 0.04597497987560928, 0.10524575060117058, 0.018397026396996807, 0.05033107503550127, 0.047620276745874435, 0.08499774296069518, 0.06908095368999057, 0.05644059427140746, 0.0355264497193275, 0.06371859533828683, 0.09290733767556958, 0.05232610899838619, 0.08585203657275997, 0.04372071744001005, 0.03940317685191985, 0.038323300032061525, 0.03355708293383941, 0.06491564243333414, 0.023467527753382456, 0.046688688453286886, 0.009577053042448824, 0.059575314735411666, 0.01464849785406841, 0.009140800084423972, 0.021544580449699424, 0.03196569196006749, 0.008585034447605722, 0.027385624052840285, 0.020400084831635468, 0.10323764741769992, 0.0295173671838711, 0.06184517711517401, 0.02892043183237547, 0.016510744899278507, 0.0063627636791352415, 0.0298285645476426, 0.04125530285818968, 0.011722541676135734, 0.027409276299295016, 0.009312059937656159, 0.09300231773522682, 0.053575240017380565, 0.0553439708892256, 0.03475217818049714, 0.024001668134587817, 0.04481958952965215, 0.0018023019219981506, 0.040922731641330756, 0.034567758193588816, 0.037332736974349245, 0.03140034983516671, 0.08318229389260523, 0.08417834513238631, 0.04620506049832329, 0.04123601072933525, 0.030671082131448202, 0.06432025445974432, 0.06869456934509799, 0.021984523737046402, 0.0693620421225205, 0.0533563917997526, 0.05733968020649627, 0.13303672458278015, 0.08417832286795601, 0.018382647285761777, 0.01704230631730752, 0.020920423121424392, 0.01104994900742895, 0.04997345633455552, 0.0343364604486851, 0.023112636445148382, 0.04948369452904444, 0.028136243345215917, 0.019488204270601273, 0.01104189948819112, 0.03784628461289685, 0.025595408005756326, 0.035714149998966604, 0.0716443762939889, 0.006808211846873746, 0.011539707102201646, 0.00839360487589147, 0.020519832214631606, 0.06165351005620323, 0.07314365560887381, 0.01022907801598194, 0.01394015222103917, 0.06959789665415883, 0.024460456406814046, 0.06007219373714179, 0.03217774210497737, 0.06178381634526886, 0.06130132016551215, 0.01734251061861869, 0.0683062183088623, 0.035674511891556904, 0.04351417774159927, 0.035830492779496126, 0.004639167909772368, 0.05089404970931355, 0.04322082531871274, 0.025219161398126744, 0.02433739533444168, 0.08870900084730238, 0.05498861202795524, 0.031128460323088802, 0.03760835206776392, 0.02786635948723415, 0.03247814122005366, 0.018003786462941207, 0.004723544070657226, 0.030462343820545357, 0.025709444562380668, 0.07231985684484243, 0.07338428215007298, 0.029712791365454905, 0.013017880664847326, 0.028665847348747775, 0.02485637363861315, 0.015927899221424013, 0.006428775395761477, 0.032041049635154195, 0.04162894452747423, 0.03534748080710415, 0.038853675869177096, 0.043266619541100226, 0.025870412682706956, 0.07255539967445657, 0.043117870882269926, 0.04801250921445899, 0.06941992221982218, 0.03558309414074756, 0.029905042865721043, 0.06623009729082696, 0.012815055415558163, 0.06799094655434601, 0.03399686480406672, 0.01764889144396875, 0.027327693860570434, 0.007242559340738808, 0.04489500657655299, 0.04703221005911473, 0.03482696811261121, 0.02508803503587842, 0.012752575858030468, 0.007002645261309226, 0.03918220980267506, 0.04284718736016657, 0.05319941643392667, 0.016350355654140003, 0.038127476946101524, 0.041152693520416506, 0.0444563713244861, 0.045663960627280176, 0.04276791856682394, 0.03929919454094488, 0.029529412240663078, 0.05456169157696422, 0.06284851624513976, 0.05360231356462464, 0.07342293320107274, 0.030257221624196973, 0.03557523850759026, 0.03910379447916057, 0.07754366364679299, 0.03582340897992253, 0.12415618548402563, 0.07344550191191956, 0.060198837527423166, 0.004443398165676626, 0.019626894973043818, 0.08404515188885853, 0.059687716711778194, 0.03766363464819733, 0.0453865087183658, 0.0329878742195433, 0.11943644538405351, 0.03193987264239695, 0.055308043520199135, 0.013395539208431728, 0.04105591375264339, 0.05966664342849981, 0.041846378953778185, 0.028268829883018043, 0.02116225936333649, 0.0507848167035263, 0.06213921231392305, 0.05277357580780517, 0.04806012912013102, 0.026364341647422407, 0.03711417448357679, 0.03318239854706917, 0.03774182732740883, 0.05078346228401642, 0.059828535522683524, 0.021045979665359482, 0.006122886707089492, 0.14136733225313947, 0.029774404465570115, 0.08459745076834224, 0.05717523512430489, 0.020461376952880528, 0.004404306928336155, 0.009231728017766727, 0.022350890503730625, 0.0632671097991988, 0.050037518522003666, 0.015474762403755449, 0.04292254503525328, 0.03245507527026348, 0.03119182860245928, 0.10361234293668531, 0.05772182688815519, 0.030101921656751074, 0.007590033810629393, 0.05433473168523051, 0.04684076935518533, 0.0747232353023719, 0.01757514794007875, 0.00872468066518195, 0.08187300438294187, 0.06231644831132144, 0.04109679124667309, 0.013875888726033736, 0.03460572275798768, 0.04070975752256345, 0.020625961187761277, 0.023790979830664583, 0.05028435312851798, 0.05220505358010996, 0.025678009042167105, 0.03756577876629308, 0.04909012248390354, 0.05669767422659788, 0.006853449458503746, 0.06785771620343439, 0.09414367406861857, 0.07424657611409202, 0.02468713057169225, 0.08971171657321975, 0.028613290305656847, 0.056278616830240935, 0.031882708717603236, 0.01021687246975489, 0.04112702634301968, 0.08590248777181841, 0.030958452844060957, 0.06224230404768605, 0.016113300698634703, 0.06593281519599259, 0.018649057892616838, 0.061010056888335384, 0.009911444376484724, 0.057700256365933456, 0.06473736371845007, 0.022853617629152723, 0.0250426248749136, 0.06895943442941643, 0.057375663236598484, 0.05475087615195662, 0.02953434752271278, 0.026761771005112678, 0.06682365958113223, 0.02378846209467156, 0.04525270691374317, 0.0352872481016675, 0.056732332523097284, 0.042621808242984116, 0.042195288551738486, 0.09477941261138767, 0.08537311383406632, 0.02749881456111325, 0.029067293580737896, 0.04630310933862347, 0.030944797326810658, 0.09351929780677892, 0.016132488926814403, 0.02050292052445002, 0.051824532201862894, 0.03792648851231206, 0.026279775775037706, 0.02677645254152594, 0.027538239301065914, 0.025387050045537762, 0.015941076053422876, 0.007146962834667647, 0.015805166549398564, 0.02491476210707333, 0.029254750807012897, 0.06789498685975559, 0.01560197208164027, 0.07862899525207467, 0.05246202592388727, 0.022852552647236735, 0.044457376934587955, 0.004420997365741641, 0.04174384754151106, 0.024561373647884466, 0.03604671008361038, 0.03438295600062702, 0.015444296313944506, 0.022387372628145386, 0.022833099101262633, 0.011426115834183292, 0.012408326947479509, 0.07878630087361671, 0.10561589675489813, 0.011295454241917469, 0.02904673423472559, 0.0457547178666573, 0.08776239890721627, 0.03049421720788814, 0.03675096369988751, 0.037420559019665234, 0.021639669976138975, 0.026595240487949923, 0.037463432890945114, 0.04242332826834172, 0.017916190772666596, 0.01624949036340695, 0.006174819418447441, 0.05605914891930297, 0.025561475158610847, 0.13917574047809467, 0.14140933781163767, 0.09004923049360514, 0.11570816262974404, 0.21845269744517282, 0.1184615379315801, 0.1351877357228659, 0.147372271749191, 0.1181897115020547, 0.07874218761571683, 0.21005323331337422, 0.27711791277397424, 0.20078187924809754, 0.15227657655486837, 0.1930733842891641, 0.1045496086589992, 0.06830399928730913, 0.13379292853642255, 0.09670180515968241, 0.23380846017971635, 0.20362001523608342, 0.18672662641620263, 0.1458677157643251, 0.10599470377201214, 0.12433899129973724, 0.20690810051746666, 0.17464403179474175, 0.2425416384357959, 0.145349147496745, 0.22362156305462122, 0.10932276112725958, 0.13150082028005272, 0.10330856704968028, 0.1658800692530349, 0.22422478068619967, 0.15259338455507532, 0.15791124373208731, 0.13140443013980985, 0.33985037938691676, 0.10918994637904689, 0.15626006905222312, 0.22065533237764612, 0.09624890211853199, 0.13350801804335788, 0.12851992476498708, 0.11675935544189997, 0.17631318129133433, 0.13014509459026158, 0.12028633063891903, 0.11068147025071084, 0.22005543956765905, 0.1397732287296094, 0.14906941505614668, 0.18619729700731114, 0.20441228756681085, 0.058974097191821784, 0.12308458361076191, 0.1136048418993596, 0.17387994623277336, 0.18750709859887138, 0.1683678521658294, 0.10577229695627466, 0.145478043705225, 0.13995175977470353, 0.23011428653262556, 0.1338147179922089, 0.1336563882068731, 0.12115786434151232, 0.1650787575636059, 0.1292888046009466, 0.1257128402357921, 0.25541828654240817, 0.09302703867433593, 0.17498115979833528, 0.20459644409129396, 0.1743237950722687, 0.10423231826280244, 0.22638707247097045, 0.18099310516845435, 0.1208328630309552, 0.1527659932617098, 0.1924102456541732, 0.23817991779651493, 0.1581606053514406, 0.24427075346466154, 0.172599830548279, 0.1144562782428693, 0.17468729900429025, 0.1659086419385858, 0.1685224415268749, 0.20147891918895766, 0.3092019067844376, 0.26989812206011266, 0.22107204829808325, 0.13146077399142087, 0.07151585115934722, 0.0728432193864137, 0.16401196480728686, 0.14606567623559386, 0.205847111355979, 0.13697675691219047, 0.11296597149339505, 0.15738325018901378, 0.08801774223684333, 0.13017341494560242, 0.13281434745294973, 0.1547028057393618, 0.1863011679961346, 0.08039783002459444, 0.15413262852234766, 0.07175693041062914, 0.09531111689284444, 0.1388792524812743, 0.17767413170076907, 0.12385412395815365, 0.13954375666799024, 0.12029597855871543, 0.07005008723353967, 0.14631811034632847, 0.12105439411243424, 0.15427881677169353, 0.1327908955863677, 0.16066097508883104, 0.23805989767424762, 0.24075004941551015, 0.11374401685316116, 0.10228460363578051, 0.12564524542540312, 0.12098581966711208, 0.09183018453768454, 0.15447265090188012, 0.10151267357286997, 0.16743086103815585, 0.11293805931927636, 0.18810792651493102, 0.1947382590151392, 0.06776340407668613, 0.07894823007518426, 0.10149709589313716, 0.07909066305728629, 0.0948984976275824, 0.08704969222890213, 0.13953575631603599, 0.15449142723809928, 0.140239059983287, 0.1488284842344001, 0.18583771161502227, 0.1485082771978341, 0.1857127487892285, 0.0742411584360525, 0.11748664532206021, 0.12803634133888409, 0.14197457232512534, 0.12300495858653449, 0.12624905677512288, 0.13564142544055358, 0.1304702294874005, 0.13216217776061967, 0.14113224955508485, 0.1560177726787515, 0.13146910088835284, 0.16509886976564303, 0.1719023156329058, 0.15251476143021137, 0.18185910244937986, 0.11229409778025001, 0.09896894756820984, 0.12172332149930298, 0.11424974596593529, 0.13009735965169966, 0.1555867333081551, 0.13332789880223572, 0.04906509355350863, 0.11141353214043193, 0.13685036916285753, 0.11075037866248749], [0.02456596754200291, 0.03840711447992362, 0.025508033104415517, 0.02578721792815486, 0.005489139439305291, 0.01029714037940721, 0.017364609921060037, 0.03309950065158773, 0.05652763335092459, 0.020559741205943283, 0.05255463482171763, 0.0687353132525459, 0.08231129453633912, 0.026058105540869292, 0.02270636810862925, 0.029922466637799516, 0.008241918239946244, 0.046869245561538264, 0.0663503549003508, 0.011911229012184776, 0.021598816601908766, 0.013343333757802611, 0.03998460131697357, 0.05732988014642615, 0.05915926303714514, 0.01604254804988159, 0.010689095470297616, 0.03534468662110157, 0.03343904434586875, 0.05308614985551685, 0.07635752612259239, 0.016411272990808357, 0.050268890481675044, 0.0608527178701479, 0.01664703289861791, 0.016823205769469496, 0.06048906550859101, 0.04536832981102634, 0.037664684787159786, 0.06369970767991617, 0.04546822288830299, 0.026768489296955522, 0.022067315876483917, 0.04307548311771825, 0.04619104503944982, 0.07587941232486628, 0.006027762392477598, 0.027665781090036035, 0.011841744508274132, 0.0949382247927133, 0.015050417205202393, 0.09439686516998336, 0.03791964591073338, 0.04208730606478639, 0.06853710045106709, 0.049859644277603365, 0.01991870187339373, 0.09332499612355605, 0.029870987564208917, 0.02989124448504299, 0.023397055265377276, 0.07444724542438053, 0.019249843135185074, 0.05626526559353806, 0.11835210825665854, 0.01838531345129013, 0.03615455156250391, 0.05903198842133861, 0.015837550163269043, 0.05906096557737328, 0.045416291104629636, 0.013951701894256985, 0.02340964951144997, 0.007320746917685028, 0.03712510260811541, 0.011902020814886782, 0.048731806164141744, 0.07464410751708783, 0.026710815145634115, 0.026952538210025523, 0.02686082174477633, 0.018220962992927525, 0.02289527066750452, 0.008771514822001336, 0.07545140091679059, 0.060939849718124606, 0.033655918450676836, 0.04501474839344155, 0.017132683206000365, 0.019211455546610523, 0.017349403315165546, 0.053929392888676375, 0.03957894710765686, 0.03222917664970737, 0.040848401840776205, 0.016360877452825662, 0.026101396870217286, 0.03466348411166109, 0.021263573653413914, 0.08386543340748176, 0.023082226944097783, 0.05918040311371442, 0.037271661931299604, 0.02511124941520393, 0.003572675955183513, 0.03125883340544533, 0.09064170182682574, 0.03689104036311619, 0.033708028349792585, 0.04286929965019226, 0.06927727401489392, 0.020743953391502146, 0.0393443393841153, 0.027338620129739866, 0.03646205674158409, 0.047025627209222876, 0.06770685242372565, 0.015839824845897965, 0.0831847578228917, 0.003056433160963934, 0.03883153018250596, 0.023291935613087844, 0.02283109901327407, 0.05003860576834995, 0.016796603486000095, 0.016547484920010902, 0.037353966108639725, 0.020944661664543673, 0.013672553250216879, 0.047630351400584914, 0.09093099099118263, 0.0021214360913290875, 0.06599923741305247, 0.019870909418386873, 0.050534438341856, 0.05052670887380373, 0.11598824174143374, 0.04910078343527857, 0.0029772687321383273, 0.04487515412620269, 0.044569229721673764, 0.014987751183070941, 0.10794000641908497, 0.04459643314476125, 0.03190626448486, 0.015807994132046588, 0.0823419526568614, 0.059781108575407416, 0.05825438092870172, 0.037075323052704334, 0.05065763114544097, 0.008363307624676963, 0.03645889890321996, 0.017046445645974018, 0.02886969676183071, 0.05056220579717774, 0.03404569441045169, 0.06508281861897558, 0.053057844343129545, 0.006149432401798549, 0.02709100255742669, 0.019629848720796872, 0.048816600246937014, 0.03817221731878817, 0.06796659668907523, 0.043510812101885676, 0.057796479522949085, 0.00610048080488923, 0.05705767522158567, 0.031584361640852876, 0.015819109648873564, 0.06569798482814804, 0.03320223244372755, 0.04141652330872603, 0.049475987325422466, 0.016342379421985243, 0.03159540479828138, 0.05438973967102356, 0.027309986217005644, 0.05167697469005361, 0.03117326006758958, 0.013083168323646532, 0.026727695294539444, 0.013178677163523389, 0.0444569464889355, 0.005451377110148314, 0.04135154827963561, 0.030269504168245476, 0.017380731223965995, 0.07372619700618088, 0.05783779859484639, 0.013522598601412028, 0.03985220588219818, 0.02072684688755544, 0.054708436437067576, 0.07398895439109765, 0.06853607628727332, 0.021746565216744784, 0.04968529523466714, 0.04788308608112857, 0.048770549983601086, 0.04247827688232064, 0.030382080549316015, 0.039094896128517576, 0.006810695258536725, 0.01100391915315413, 0.05128778502694331, 0.051007917427341454, 0.028392449421517085, 0.053702102741226554, 0.01409591232004459, 0.0663082380197011, 0.02660366015334148, 0.02117394447850529, 0.036204049101797864, 0.01651413465879159, 0.018658783737919293, 0.03801343482336961, 0.02278459975059377, 0.028065481419616845, 0.039115115941967815, 0.05060160641733091, 0.01496882641731645, 0.03470628376817331, 0.010201767909165937, 0.04924210690660402, 0.06998632932663895, 0.048630280361976475, 0.03616355010308325, 0.056337339265155606, 0.046557966561522335, 0.039682810675003566, 0.039783750180504285, 0.013836582729709335, 0.013444682372210082, 0.04960833080986049, 0.06011674115143251, 0.03939657544833608, 0.030202473390090745, 0.015193966191873187, 0.07132704136893153, 0.052445980691118166, 0.008502643067913596, 0.036394695707713254, 0.016095943719847128, 0.044688303605653346, 0.024599943062639795, 0.044808602033299394, 0.01988896958209807, 0.03257929965911899, 0.018278653842571657, 0.03443493231316097, 0.03437781291722786, 0.06455471375375055, 0.055840059503680095, 0.05453120043966919, 0.07394155341899022, 0.036706060054712, 0.03103874209045898, 0.02355219010496512, 0.00624197914476099, 0.013190418867452536, 0.013273147924337536, 0.07326874459977262, 0.04538254193903413, 0.05594291375018656, 0.040112428832799196, 0.04044708919536788, 0.04049232680699788, 0.05594626454694662, 0.033952335943467915, 0.02456304348015692, 0.02764140153885819, 0.08198178838938475, 0.08763419289607555, 0.05933718181040604, 0.01844006354076555, 0.03246484193368815, 0.028969981322006788, 0.0053395683880808065, 0.02745806508755777, 0.0222786795347929, 0.05032435117755085, 0.02427164847176755, 0.040258079025079496, 0.013367112169362372, 0.044548538644448854, 0.048207122599706054, 0.04836134088691324, 0.005491443343998981, 0.026099712194991298, 0.02853825546480948, 0.036218027453287505, 0.01985820199479349, 0.01381622469125432, 0.023325764559558593, 0.052840654825558886, 0.029066375172988046, 0.024061635522230063, 0.01689486383838812, 0.029672468626813497, 0.04058930695464369, 0.06534740910865366, 0.04365124499599915, 0.07777044171234593, 0.03679853536596056, 0.06750096581527032, 0.01590524330822518, 0.04899200313957408, 0.0494555968180066, 0.02932311374024721, 0.05418535591161344, 0.0257497617349145, 0.015806352130312007, 0.048570893704891205, 0.03409339224162977, 0.030264359229477122, 0.031016984175948892, 0.04147605097386986, 0.016584438308200333, 0.017646013766352553, 0.018782909792207647, 0.009937449231074424, 0.05076989211374894, 0.05853678667335771, 0.008612908586655976, 0.034748649268294685, 0.013923105088906595, 0.048244879362755455, 0.04755045549245551, 0.04854097031056881, 0.010141177117475308, 0.05774800243671052, 0.047688958802609704, 0.036086481777601875, 0.02152400069462601, 0.03993303318566177, 0.01961474601557711, 0.08300181842059828, 0.07843450803193264, 0.06891633049235679, 0.0360453556641005, 0.05727859403123148, 0.007518806187363225, 0.033777330099837855, 0.024037369148572907, 0.023308472518692724, 0.03542778118571732, 0.026977522611559834, 0.051683104829862714, 0.02598050472442992, 0.044848700272268616, 0.22145327471662313, 0.2253485852270387, 0.10585685726255178, 0.1041532498493325, 0.208937918941956, 0.0936666586494539, 0.08970215028966777, 0.09939856943674386, 0.15461423783563077, 0.1245054772880394, 0.13390157895628363, 0.12771429377608, 0.23588215437484905, 0.12866477714851499, 0.11651632434222847, 0.1565927144838497, 0.1228132915275637, 0.12014020176138729, 0.13930187589721754, 0.16584506956860423, 0.14282989752246067, 0.14031323022209108, 0.14945464907214046, 0.14452812436502427, 0.1772026007529348, 0.13489239063346758, 0.1216877948900219, 0.135890623787418, 0.07979083486134186, 0.08655692843603902, 0.15940089739160612, 0.1256411339272745, 0.11133168809465133, 0.24094737163977697, 0.0908317361609079, 0.24155706079909578, 0.1488891473854892, 0.1142803966649808, 0.18022590258624405, 0.1502785220509395, 0.0651901109085884, 0.09764330854522996, 0.10008662939071655, 0.1198722048138734, 0.10325714363716543, 0.1291993906488642, 0.09614965470973402, 0.1274285966064781, 0.07729783465038054, 0.1739657236612402, 0.20004939433420077, 0.15866327681578696, 0.12766461441060528, 0.14311872655525804, 0.2784415183123201, 0.10936957580270246, 0.11067679472034797, 0.14091852586716413, 0.09042122459504753, 0.11825455294456333, 0.11190111574251205, 0.13241847103927284, 0.08911353070288897, 0.18336627079406753, 0.2489457346382551, 0.09878388562356122, 0.1314757505315356, 0.17626694549107924, 0.08055535829043947, 0.2495975629426539, 0.11510144948260859, 0.14667112031020224, 0.0970404694089666, 0.12608410703251138, 0.11644416532362811, 0.10227068094536662, 0.11774156562751159, 0.1194061954447534, 0.13854733435437083, 0.13618406897876412, 0.18935057858470827, 0.12214262751513161, 0.09211001874064095, 0.08034515980398282, 0.1417811241117306, 0.11323977945721708, 0.09930237967637368, 0.21538109664106742, 0.11217636347282678, 0.16794843482784927, 0.13095779082505032, 0.11272309624473564, 0.11361030410625972, 0.15744223608635366, 0.1091162214288488, 0.20306724880356342, 0.08543480114894919, 0.17963077436434105, 0.21035309066064656, 0.1938016983331181, 0.22331573884002864, 0.12243473684065975, 0.16546023631235585, 0.0957339555316139, 0.1102234612335451, 0.12304067815421149, 0.1859573309775442, 0.05569644279603381, 0.1651665536337532, 0.12534982612123713, 0.15416650014230981, 0.17410560365533456, 0.16617688379483297, 0.07388709462247789, 0.11434600251959637, 0.13368644518777728, 0.1290882911416702, 0.152429191803094, 0.1136297186894808, 0.13048191089183092, 0.16025481250835583, 0.14100519387284294, 0.10389053699327633, 0.11278897669399157, 0.07176521277870052, 0.10773017158498988, 0.20956369786290452, 0.12957862811163068, 0.163689561013598, 0.09306951920734718, 0.14448430796619505, 0.13907960266806185, 0.12098081759177148, 0.1282673273817636, 0.1722041767789051, 0.12450263486243784, 0.20902504707919434, 0.1256202647346072, 0.11125982593512163, 0.20878086565062404, 0.21454806555993855, 0.08402899533393793, 0.10086188427521847, 0.1087928083143197, 0.10798396382597275, 0.15595761418808252, 0.16823316720547155, 0.1988925493787974, 0.15598817582940683, 0.20745323767187074, 0.21875718579394743, 0.09432035716599785, 0.12117717502405867, 0.21357634192099795, 0.10098726270371117, 0.15130379906622693, 0.13687552796909586, 0.1528125407639891, 0.3047484566923231, 0.09546299741487019, 0.11785196009441279, 0.08772748085903004, 0.20132582896621898, 0.1665566852898337, 0.17590879986528307, 0.27894888014998287, 0.12864493211964145, 0.10507888611755334, 0.1636871267692186, 0.21664583502570167, 0.11511877863085829, 0.08234706605435349, 0.12366578172077425, 0.12080695465556346, 0.14192443282809108, 0.11145712589495815], [0.05807799840113148, 0.010485335114935879, 0.02601641353976447, 0.0451361971499864, 0.015828267751203384, 0.07959414346260019, 0.018350258105783723, 0.013901695056119934, 0.06894185295095667, 0.019650580616143998, 0.09376506743137725, 0.043413750317995436, 0.01847743809776148, 0.06258601861190982, 0.05588271815213375, 0.052656628176919185, 0.04428139887750149, 0.03467415619525127, 0.03355529064720031, 0.023637448030058295, 0.10264148018904962, 0.03703581853187643, 0.05461663648020476, 0.027704695603461005, 0.07306308063562028, 0.05645971941703465, 0.030942383491492365, 0.04440545628312975, 0.04124152117583435, 0.07878546966821887, 0.020269112465030048, 0.03210462200513575, 0.028501422675617505, 0.09473665006225929, 0.05403720097092446, 0.01712777760985773, 0.032821043132571504, 0.029979567480040714, 0.0075426036164572, 0.04048305367177818, 0.02684800299903145, 0.017814241946325637, 0.03527779314026702, 0.01925053889863193, 0.025867518306768034, 0.041218217738787644, 0.052251155793783255, 0.028149143727205228, 0.032710040104575455, 0.07945664576254785, 0.09267323461244814, 0.027765286395151634, 0.02638335918163648, 0.06137749420304317, 0.04129267741518561, 0.034313798969378695, 0.05085104225145187, 0.018417487408441957, 0.01851548058766639, 0.03282613797637168, 0.01321193465628312, 0.05694606734323315, 0.01620018207177054, 0.01696875577181345, 0.06562811162439175, 0.014231413642846746, 0.08851801656419411, 0.042304822127334774, 0.07469776479410939, 0.0442727639892837, 0.031199821532936767, 0.03841682548227254, 0.04923272615997121, 0.06645894594839774, 0.015698360366513953, 0.05221072358835954, 0.07977058907272294, 0.008695447468198836, 0.012427615365595557, 0.0804995784710627, 0.0582073324767407, 0.05428469608887099, 0.006584745615327847, 0.05729683231038507, 0.057469455859973095, 0.03075874461501371, 0.06397611316060647, 0.01797816381440498, 0.09331013832706958, 0.016616721732134465, 0.08633125617052428, 0.019430654429015703, 0.036727541519212537, 0.03351383056724444, 0.07418249908369035, 0.019590975025494117, 0.036853877318208106, 0.05971081234747544, 0.11350999542628415, 0.019809886325674597, 0.02978153836011188, 0.04218866117298603, 0.020316695263318252, 0.040561324276495725, 0.01762024825438857, 0.020594356828951277, 0.06941581814317033, 0.031635566119803116, 0.048875036954996176, 0.031366400289698504, 0.05024786543799564, 0.058980594694730826, 0.047556459467159584, 0.04308688992750831, 0.0897493063530419, 0.020381199028634, 0.06781471616704948, 0.029505722886824515, 0.015225977804220747, 0.04897606180747971, 0.035681113295140676, 0.025041301996679977, 0.0775309135497082, 0.03056005312828347, 0.0872725443332456, 0.0342807325796457, 0.12416643454344012, 0.00991405024251435, 0.016301344221574254, 0.04044471432280261, 0.07308058047783561, 0.05116034342790954, 0.018182768362748902, 0.050739671860355884, 0.04053576099977363, 0.006013456568325637, 0.031901952606858686, 0.03863913210807368, 0.06526817742269486, 0.011015932668669848, 0.034102977078873664, 0.021890883253945503, 0.06422237260267138, 0.07407319557387382, 0.024112828868965153, 0.050557426366140135, 0.09199376872857101, 0.015672374065616168, 0.12343280672212131, 0.005436912188088172, 0.011246049471083097, 0.04191399231785908, 0.027327897951181512, 0.003400847431294096, 0.048796462069731206, 0.06591043202206492, 0.02297423703566892, 0.0351875665364787, 0.01374000890791649, 0.04599905885697808, 0.0009862656747827714, 0.020312375963840168, 0.027741116500692442, 0.07809205140802078, 0.019685773258970585, 0.060899361851625144, 0.03271843379479833, 0.0201711452609743, 0.031349301207228564, 0.06313302597845905, 0.014108252380538033, 0.021799825444759335, 0.03299295422038995, 0.011604493811319117, 0.04013373218185734, 0.03468444978352636, 0.023490291277994402, 0.0441041851445334, 0.028644694284594152, 0.0026501743332119077, 0.05427427633549087, 0.04071227340318728, 0.018883489356085192, 0.025327043695142493, 0.02806886004691478, 0.014518837233481463, 0.02563792008004384, 0.015956995121086948, 0.10099061721120961, 0.07481824504793622, 0.04198043679934926, 0.035371771300560795, 0.01664115879975725, 0.03733959441888146, 0.01695932307484327, 0.07431025980622508, 0.06761936805560254, 0.032778009699541144, 0.06537670167745091, 0.02602387212391477, 0.05306411178025883, 0.013900120775360847, 0.09308141583460383, 0.02230141151812859, 0.022966218130022753, 0.044584722054423764, 0.034373668022453785, 0.04568708594888449, 0.02432056156976614, 0.03851965375361033, 0.02671669666597154, 0.011382576813048217, 0.05559053461183794, 0.05990107303659897, 0.014205657407728722, 0.02375396707066102, 0.030383525881916285, 0.03354607317305636, 0.020787511894013733, 0.020976588857593015, 0.00826075116492575, 0.03934956039302051, 0.04365410226455424, 0.0734256643045228, 0.030626005936937872, 0.031462259794352576, 0.053251578283379786, 0.030970648185757454, 0.0461525609716773, 0.015666323706682306, 0.06673601194052026, 0.1196664666349534, 0.03272668647696264, 0.008399897360504838, 0.025640825588197913, 0.02204169322794769, 0.04630647868907545, 0.02815493062371388, 0.009596255185897462, 0.03609441533626523, 0.06386824941728264, 0.008117271754599642, 0.06840073081548326, 0.0760448667278979, 0.09801561434869654, 0.06353329590638168, 0.04165001410001423, 0.03474938028375618, 0.05395241802034434, 0.06529574078740552, 0.026730654608400073, 0.07339540694374591, 0.05256685057247523, 0.05269987683277577, 0.08322277062688954, 0.018300729025213514, 0.07831730807083659, 0.019256247869634535, 0.05443652094982099, 0.07800809224136174, 0.014429221973841777, 0.03831541842373554, 0.024645572157169227, 0.018368253331573214, 0.0341208962345263, 0.040643123793415725, 0.0406570279301377, 0.023175103015091736, 0.00694657322128478, 0.07509430171921849, 0.04391523434605915, 0.01593747663719114, 0.10138690922758542, 0.04162776822340675, 0.0835937108786311, 0.03210532704542857, 0.034396667178953066, 0.020451654818316456, 0.02344687749427976, 0.034122131910407916, 0.038860778222442605, 0.028311648093222175, 0.026588781947793905, 0.028543203734443523, 0.01868351024313597, 0.026441293084644713, 0.05863372229214292, 0.019179684204573277, 0.036753453605342656, 0.025050834883586504, 0.011411508512537694, 0.010487706276762765, 0.04783085001690779, 0.010009956131398212, 0.021705726685468107, 0.032988820457831025, 0.03170432981278282, 0.048680713007343, 0.04945265049173031, 0.027880638408532832, 0.04031913180369884, 0.07756438440992497, 0.029024312098044902, 0.03339736162160989, 0.013450052738335216, 0.03385212745342869, 0.016634581515972968, 0.11125940291094594, 0.045246702939039096, 0.04909988914732821, 0.004829470808545011, 0.038808252720627934, 0.013102915945637506, 0.008223320019169478, 0.0462982556928182, 0.030287762856460176, 0.012560456088976935, 0.03482932814222295, 0.021940022706985474, 0.04711062167189084, 0.01596076152054593, 0.06339745319564827, 0.03750747564481571, 0.0018220972037852334, 0.13091921398881823, 0.04298098916478921, 0.044567188815562986, 0.01810702477087034, 0.07012290676357225, 0.059866221781703644, 0.044513561224448495, 0.03203949483577162, 0.023725808132439852, 0.036102237572777085, 0.07111729559255764, 0.054461364343296736, 0.03166101065289695, 0.04776861722348258, 0.016252492350758985, 0.038176146990736015, 0.013187055083108135, 0.03230601490940899, 0.04823678624234162, 0.03757617996598128, 0.02817849937855499, 0.02742394855886232, 0.03279103810200468, 0.08017678876058199, 0.0228175473966985, 0.026394226078991778, 0.026356424787081778, 0.01100906687497627, 0.22168034221976995, 0.09483449481194839, 0.08877709289663471, 0.19140531832817942, 0.21264156239340082, 0.23504803975811228, 0.07138633154681884, 0.1475394776207395, 0.1610239001456648, 0.08582123002270237, 0.1446885766927153, 0.14941625035135075, 0.20145916321780533, 0.18861699529225007, 0.12013826475595124, 0.13326977379620075, 0.09896919247694314, 0.14767551328986883, 0.11339600154315121, 0.09210067510139197, 0.17816798645071685, 0.08305992858367972, 0.09022235870361328, 0.0958270208502654, 0.14844899444142357, 0.14059224806260318, 0.2090161561500281, 0.11349565713317133, 0.16104901442304254, 0.25630126416217536, 0.10844860022189096, 0.16089740849565715, 0.08523013166268356, 0.17261909670196474, 0.10597108863294125, 0.19829621887765825, 0.11168742916197516, 0.15154722350416705, 0.10165558895096183, 0.09797932332730852, 0.21363975101849064, 0.12217521521961316, 0.1184975914657116, 0.1758181391051039, 0.14907680684700608, 0.16880865819985047, 0.13770504127023742, 0.16180616832571104, 0.08224424891523086, 0.14266799058532342, 0.16129644645843655, 0.14030736725544557, 0.19465576187940314, 0.10440908299642615, 0.1390624590567313, 0.2649107709294185, 0.1055650002672337, 0.17284760397160426, 0.12476317322580144, 0.16694496211130172, 0.08426798915024847, 0.12219865966471843, 0.06695957650663331, 0.15705088677350432, 0.17290054878685623, 0.09411418111994863, 0.24654632667079568, 0.1298281381605193, 0.2730633522151038, 0.15485332813113928, 0.13108290208037943, 0.1386361100594513, 0.15796438150573522, 0.17067373468307778, 0.15891173301497474, 0.23268072225619107, 0.1461716994526796, 0.1674443087540567, 0.14886294957250357, 0.21229214442428201, 0.14563417673343793, 0.17176466208184138, 0.17169631028082222, 0.16886031167814508, 0.29522266471758485, 0.14375630562426522, 0.15114677546080202, 0.10660159503458999, 0.15958361414959654, 0.13888711924664676, 0.20037089270772412, 0.11261392632150091, 0.08491629967465997, 0.2349560579750687, 0.15332526090787724, 0.16001934389350936, 0.30658574716653675, 0.09619549717172049, 0.2845406363485381, 0.16362401453079656, 0.08746210369281471, 0.23490596300689504, 0.1311062797321938, 0.1940545332035981, 0.20620751311071217, 0.09471915022004396, 0.1550206379033625, 0.06532415762194432, 0.24127063632477075, 0.06582317771972157, 0.11123681935714558, 0.15987170103471726, 0.10376054982771166, 0.176038111676462, 0.20057167334016412, 0.1669331471202895, 0.1509349961997941, 0.12357487605186179, 0.13830180221702904, 0.16526794584933668, 0.15348148299381137, 0.1416284346487373, 0.17984279111260548, 0.14041303424164653, 0.17603652348043397, 0.19047542213229463, 0.22690181125653908, 0.11786540781031363, 0.07279204088263214, 0.12565484881633893, 0.16299137816531584, 0.20181707135634497, 0.16092234465759248, 0.1088884637283627, 0.12503233534516767, 0.1074294607678894, 0.1145047479076311, 0.1394761321716942, 0.14143856358714402, 0.13950451189884916, 0.049221397275687195, 0.17072905437089503, 0.1353757514152676, 0.12907083582831547, 0.09552271803840995, 0.24220019113272429, 0.154994722106494, 0.08956356905400753, 0.23857089603552595, 0.10168473309022374, 0.1862802988034673, 0.1273838005727157, 0.20565057580824941, 0.21050583949545398, 0.17903554224176332, 0.15874476463068277, 0.1114985674212221, 0.12997627083677799, 0.17136649985332042, 0.1761826523579657, 0.11614156945142895, 0.12355494196526706, 0.06748857937054709, 0.20278937387047336, 0.07600349941640161, 0.1556145490030758, 0.15070053690578789, 0.10003249713918194, 0.2584938652580604, 0.21016624756157398, 0.12003722877125256, 0.11337473159073852, 0.14610308047849685, 0.09642559263738804, 0.1878956871223636, 0.12251379041117616], [0.07558327313745394, 0.09475449129240587, 0.06011523088091053, 0.02655418858921621, 0.024842540005920455, 0.007664895174457342, 0.06537082386785187, 0.02763444761512801, 0.03398333545192145, 0.037728464958490804, 0.008004714854905615, 0.0005354352549602481, 0.023216923036670778, 0.08308611897518858, 0.0685416127089411, 0.022914030305400956, 0.02910651237471029, 0.006568939725184464, 0.028985881835978944, 0.027008390388800763, 0.005608813071376062, 0.04532637991360389, 0.028084729019610677, 0.02870102700399002, 0.02405351828201674, 0.02982001686177682, 0.05249430192634463, 0.0192430432070978, 0.029292655999597628, 0.0579490094241919, 0.06232230385649018, 0.11582128077861853, 0.0597948123322567, 0.043987719909637235, 0.035559950265451334, 0.003939948373954394, 0.06792521453462541, 0.013490562869264977, 0.01825949344492983, 0.01860905613284558, 0.04814897903997917, 0.03780300998187158, 0.04489869505050592, 0.01317372611083556, 0.02874688430893002, 0.01574266658280976, 0.05668471632816363, 0.02119291377312038, 0.03184329325449653, 0.03116721156402491, 0.04079092250321992, 0.03081103634031024, 0.08319980857777409, 0.02308659633854404, 0.04140413315326441, 0.03110206213023048, 0.022488185968541075, 0.03254338713304605, 0.023191489635792095, 0.04874994054262061, 0.046008428471395746, 0.0584094415535219, 0.02058091096841963, 0.02608637765661115, 0.012485880452004494, 0.017756404522515368, 0.1148490747436881, 0.021794524654978886, 0.060675218410324305, 0.036188489975756966, 0.024840868318278808, 0.053232801947160624, 0.030092064080236014, 0.05875410606677178, 0.013183031715016114, 0.08538283596863039, 0.02713326786761172, 0.06415520081645809, 0.02422062767436728, 0.03588227984437253, 0.01733895202050917, 0.03895197332894895, 0.09115126784308814, 0.016732788062654436, 0.05948629041085951, 0.041610791595303454, 0.014637521489930805, 0.029031753983872477, 0.039258023898582906, 0.025643536282586865, 0.013634243587148376, 0.025926491216523573, 0.034944528015330434, 0.02980032211780781, 0.04832699058169965, 0.018220380407001358, 0.04015203725430183, 0.06831274178694002, 0.09240370884072036, 0.05079319184005726, 0.03777813690248877, 0.0270392117818119, 0.009442663085792447, 0.02199968024797272, 0.0771184649784118, 0.09046391292940825, 0.05900724521779921, 0.04714723923825659, 0.030374883572221734, 0.06537420063978061, 0.03316539594379719, 0.027380542196624447, 0.06615551144932397, 0.01347841391179827, 0.008907540286600124, 0.012307744600548176, 0.015054766190587543, 0.02371929764194647, 0.04345180765085388, 0.04793591957422905, 0.02407418709481135, 0.028202212852193043, 0.03327251753944438, 0.03248332883231342, 0.026093279630003963, 0.02112311849487014, 0.0362685120489914, 0.08577831904403865, 0.022357326779456344, 0.034878120641224086, 0.06583123002201319, 0.017262160145037342, 0.09978441943530925, 0.04146802835748531, 0.0327665991790127, 0.03089822013862431, 0.02584211644716561, 0.08002844086149707, 0.048453908966621384, 0.015846971728024073, 0.02649774083693046, 0.04280228371499106, 0.035297753202030435, 0.08569713550969027, 0.05879598917090334, 0.013590695289167343, 0.034764716765494086, 0.019874868776241783, 0.07642840122571215, 0.06130390283942688, 0.00796159607489244, 0.044569036763277836, 0.0339827046263963, 0.030309808353194967, 0.028299309888097923, 0.044794901987188496, 0.022410781821236014, 0.03341506926517468, 0.026164351402258035, 0.021930910988885444, 0.05165271017176565, 0.034562526052468456, 0.030444649164564908, 0.014035591484571341, 0.09975326407584362, 0.04370270551589783, 0.03210315255273599, 0.020288525192881934, 0.08521692143403925, 0.03289360291091725, 0.04855238825257402, 0.051363929378567263, 0.07024179882137105, 0.03563264734111726, 0.05499327271536458, 0.019334503631398547, 0.028346844446787145, 0.03072898820391856, 0.02155001668143086, 0.007902906108938623, 0.06975838608923368, 0.02979793611302739, 0.025440033823542763, 0.029914033984823618, 0.015650076238671318, 0.026573152317723725, 0.040908133596531115, 0.05058541275502648, 0.022297541217994876, 0.08072991884546354, 0.0902180616685655, 0.07309926775633357, 0.028703374046017416, 0.06792862099246122, 0.0059106398930453, 0.03388640354387462, 0.0035434255960353767, 0.03666832184535451, 0.026552670897217467, 0.02320852378034033, 0.009817766785999993, 0.024665174132678658, 0.045121844013920054, 0.06028399526257999, 0.015405225021822844, 0.01757482510583941, 0.08057068363996223, 0.02947101635072613, 0.07071477695717476, 0.05234768323134631, 0.04809447200386785, 0.011007142857124563, 0.024665504388394766, 0.014814026471867692, 0.029340595028770622, 0.08718627708731219, 0.01942160764883738, 0.015326912671298487, 0.05812262745166663, 0.010780325828818604, 0.08835772008751519, 0.02689882712729741, 0.02449161547701806, 0.015163408261287259, 0.043788501498056576, 0.01766109977324959, 0.03639324480900541, 0.04734567839477677, 0.1611375081120059, 0.003950646432713256, 0.025174764268740546, 0.0295277034456376, 0.02167306847695727, 0.10451947746332735, 0.01805264204449486, 0.04659796461055521, 0.03565884144336451, 0.019184940465493128, 0.04987398257071618, 0.04906334950646851, 0.04008954841992818, 0.005923734161115135, 0.05794633769255597, 0.04949251495418139, 0.020810789355891757, 0.06643753498792648, 0.031514117363258265, 0.019790017177001573, 0.030149502599670086, 0.04143428290262818, 0.04284575130441226, 0.05833985407662112, 0.004977795051672729, 0.04959429308655672, 0.04704469298303593, 0.05568880238570273, 0.02109212269715499, 0.057915301076718606, 0.020726221628137864, 0.08119062928017229, 0.06708952656481415, 0.009098429945879616, 0.026392869804112706, 0.012106409212719882, 0.02410182096355129, 0.03245352789235767, 0.05194338344153948, 0.01663381339312764, 0.02490685637894785, 0.034527225798228756, 0.04311885422794148, 0.07819278311217204, 0.017747097990650218, 0.03015941212652251, 0.006551656961164554, 0.02543771090131486, 0.02774693308310816, 0.015641728932678234, 0.03479705956124235, 0.043848392815561965, 0.02447913069772767, 0.02070777554763481, 0.049247331626247615, 0.017314002870989498, 0.053706911858171225, 0.022870820612297393, 0.0911551938042976, 0.022707008211000357, 0.028464782844821457, 0.013991242594784126, 0.03698927102959715, 0.058097843430005014, 0.0521212539752014, 0.046771334018558264, 0.04735493297630455, 0.06835909633082338, 0.07862136597395875, 0.08073841643636115, 0.040198692367994227, 0.021882140754314605, 0.03626509816967882, 0.022472105483757332, 0.05325045764038805, 0.05932918887992855, 0.010232544773316476, 0.02018871560721891, 0.026506240283197258, 0.03763283551961649, 0.0700514305208344, 0.027381686959415674, 0.026830922470253427, 0.05055736328358762, 0.03873320674756542, 0.18797281110892072, 0.04290723823942244, 0.05641182120598387, 0.021401865451480262, 0.014642195164924487, 0.02616757046780549, 0.035432987351669, 0.02473344429745339, 0.0573261063254904, 0.04277563690266106, 0.022442410299845506, 0.05389963276684284, 0.05958853609627113, 0.05363300508179236, 0.04095350108400453, 0.0059406064247014, 0.030181264664861374, 0.027246538156759925, 0.03333204149384983, 0.0814728309342172, 0.03383663140994031, 0.032182740469579585, 0.005079849634057609, 0.056150993405026384, 0.025140464058495127, 0.010519709539948963, 0.0329078669892624, 0.07582224468933418, 0.06818800160544924, 0.0190707239380572, 0.11709387850714847, 0.007644650313523016, 0.04371211223769933, 0.05203917986364104, 0.02709889529796783, 0.02672955994057702, 0.033591032479307614, 0.041202105712727644, 0.04910321396891959, 0.14929620054317638, 0.13230824726633728, 0.1275994093157351, 0.13965360936708748, 0.13532430573832244, 0.07702462782617658, 0.09263269108487293, 0.12455802876502275, 0.1669372883043252, 0.1029720476071816, 0.1290552061982453, 0.13503682741429657, 0.14770469453651458, 0.21219916816335171, 0.13422837626421824, 0.11931590575841255, 0.12633349833777174, 0.13331293710507452, 0.1269070597481914, 0.16363807080779225, 0.10186200990574434, 0.16571648506214842, 0.07787109178025275, 0.1643244831939228, 0.14560190815245733, 0.09105325982091017, 0.09436482665478252, 0.12887896096799523, 0.14216750103514642, 0.19467709120362997, 0.23127620777813718, 0.1705019423388876, 0.20133605576120317, 0.14442771178437397, 0.0914142478723079, 0.19014102523215115, 0.12410512572387233, 0.11994319123914465, 0.12100415071472526, 0.1646229304606095, 0.15743313735583797, 0.12789120693923905, 0.21948392648482695, 0.10156800068216398, 0.2321390583529137, 0.12020333626423962, 0.1458060581353493, 0.08018300795811228, 0.12100927895517088, 0.07503625092795119, 0.13396495836786926, 0.24186030233977363, 0.2328988691442646, 0.11165996227646247, 0.13011000584810972, 0.13470547331962734, 0.15029403293738142, 0.2569714532000944, 0.09388122096424922, 0.12225285870954394, 0.14510789013002068, 0.20049918035510927, 0.12118069280404598, 0.11050906192394905, 0.10501619690330699, 0.10820621479069814, 0.14144168060738593, 0.1463420965592377, 0.13854963501216844, 0.15050938935019076, 0.16532561072381213, 0.09760413056937978, 0.12470461777411401, 0.13358169846469536, 0.14084860071307048, 0.19962525693699718, 0.09897561205434613, 0.19405365746933967, 0.13531214935937896, 0.16479571728268638, 0.08274591848021373, 0.12637447973247617, 0.20713714213343337, 0.13284176238812506, 0.14297618967248127, 0.0839417781389784, 0.15398120071040466, 0.14263483142713085, 0.1001542984158732, 0.10128386202268302, 0.08795385074336082, 0.11280607577646151, 0.08224350676755421, 0.07567130669485778, 0.14627784141339362, 0.12068432959495112, 0.10557956862612627, 0.2284408622654155, 0.18211362941656262, 0.07103134004864842, 0.06336195627227426, 0.07012783462414518, 0.10857891393243335, 0.10832453539478593, 0.2194210368907079, 0.14490706496872008, 0.19076405820669606, 0.08743642538320273, 0.10429048037622124, 0.16591055667959154, 0.10667615861166269, 0.1377688511274755, 0.1363257152843289, 0.09325352730229497, 0.13761326728854328, 0.11201357337995432, 0.11345424529281445, 0.11598928816965781, 0.13787613599561155, 0.21820271242177114, 0.1835767735610716, 0.2237239497480914, 0.1644255785504356, 0.17973998881643638, 0.16290858417050913, 0.09836066848947667, 0.24848546949215233, 0.24719134205952287, 0.0954253927920945, 0.14493485097773373, 0.18710102507611737, 0.10557418805547059, 0.20642968243919313, 0.16133506782352924, 0.12138656456954777, 0.12640110799111426, 0.06264973941142671, 0.2788657002383843, 0.13448346726363525, 0.24989436264149845, 0.13902677659643814, 0.14235205831937492, 0.22131510166218504, 0.2184409269830212, 0.2141543265315704, 0.11411166939069517, 0.13900694641051814, 0.1058624530560337, 0.19603133259806782, 0.14963414490921423, 0.09884641898679547, 0.09063865159987472, 0.1591890142299235, 0.11518508952576667, 0.19024035427719355, 0.12092606935766526, 0.21276538231177256, 0.10651313845301047, 0.10024190152762458, 0.15853730466915295, 0.13715036009671167, 0.11077978255343623, 0.09445606629014947, 0.08075981255387887, 0.25392217619810253, 0.1253872600500472, 0.14353363163536415, 0.13572033058153465, 0.16147122223628685, 0.11470286422991194, 0.16759079386247322, 0.15205703442916274, 0.1610357893514447, 0.13494726503267884, 0.17815879866247997, 0.11775534730986692], [0.051225522547611035, 0.05920713156228885, 0.029218958879937418, 0.05348147707991302, 0.00583547100177384, 0.05490204792295117, 0.05703601193090435, 0.041228318368666805, 0.007528551514042192, 0.07363561046076939, 0.034435648485668935, 0.05550952919293195, 0.02014997178775957, 0.037386316325864755, 0.03904359517036937, 0.009526252106297761, 0.09063001300091855, 0.008417982571700122, 0.029571397390100174, 0.03468917355348822, 0.04739183255878743, 0.11416160850785673, 0.008648529819765827, 0.004701158113675774, 0.04127771571802441, 0.04995393785065971, 0.07329969215788879, 0.06274888291954994, 0.022743210174667183, 0.04010920049040578, 0.02456491369230207, 0.036053478470421396, 0.028125946046202444, 0.031669957243138924, 0.037300683616194874, 0.03768247777770739, 0.007850605106796138, 0.05083981355710421, 0.05138371874636505, 0.020839501194132026, 0.019354673349880613, 0.038607394162681885, 0.02367696553847054, 0.07366039819316939, 0.018798123819578905, 0.023255201158463024, 0.03146631192066707, 0.011521056003402919, 0.054357586122932844, 0.03712691344844643, 0.05485496236360632, 0.029258984759508166, 0.031921311529004015, 0.023898236868262757, 0.07150419944082387, 0.04560058863717131, 0.029028217650193255, 0.07070795662002638, 0.03229807764000725, 0.03203833708539605, 0.018691673867579084, 0.07037339644739404, 0.06755292357411236, 0.020540799741866067, 0.05322731376509182, 0.02655277665326139, 0.02817061591485981, 0.03904137985955458, 0.03870712025673129, 0.03606940867030062, 0.03153870471578557, 0.019137773269903846, 0.031441832179552875, 0.04956513410434127, 0.012576705412357114, 0.062485791568178684, 0.04264176830474753, 0.017845556867541745, 0.012653015819523716, 0.03519321799103636, 0.020516167860478163, 0.006268007655307883, 0.04398811324790586, 0.02136440740287071, 0.08984747022623196, 0.025130591639026534, 0.013739711121161235, 0.039165207199403085, 0.01032122678225278, 0.05004223858122714, 0.05286808460368775, 0.04146364226471633, 0.09981031296774745, 0.081476682680659, 0.02102744452713523, 0.03487810579827055, 0.0424042996019125, 0.020378143235575408, 0.04515842076216359, 0.09882852580631152, 0.08174100599717349, 0.1088435786368791, 0.030005481421540026, 0.03634185479313601, 0.01424422496711486, 0.02701832403545268, 0.03972319835156668, 0.007526809786213562, 0.02159726180252619, 0.019629930357041303, 0.03474788485618774, 0.05325571204593871, 0.03469306982879061, 0.01958481705514714, 0.030540744301106315, 0.05242161969363224, 0.03012964458321221, 0.03555619128746912, 0.01839843091147486, 0.018191009912698064, 0.018506090564187616, 0.017283569250139408, 0.05592849382082932, 0.05198975282837637, 0.02926285691501107, 0.02136844654160086, 0.04528433724772185, 0.03334377113787923, 0.025812009371293243, 0.028152618833701126, 0.001042532180690614, 0.04530237514700275, 0.038010299249435775, 0.059844465722562745, 0.02429586289508734, 0.09699253409053199, 0.03489077054837253, 0.033997514183283783, 0.053931712100165896, 0.09079909650608897, 0.060310575281619094, 0.07548713532742113, 0.020758456812473014, 0.02073847263091011, 0.11957412119954824, 0.042476132075535133, 0.006065008465157007, 0.030590191745432094, 0.03776090052269865, 0.03802626655669883, 0.06700178244500421, 0.02149088235455565, 0.05431060075352434, 0.026466795134183485, 0.03742823282664176, 0.04302784836909268, 0.03555986491846852, 0.006045057680239552, 0.034697285227593966, 0.037810598441865295, 0.06180016956932377, 0.01595023786649108, 0.09114809887250885, 0.004087222941961954, 0.04073396266903728, 0.021871626377105713, 0.05198849117732607, 0.04184838275250513, 0.04212781619571615, 0.023526352233602665, 0.007907558447186602, 0.049726580909918994, 0.04803649913810659, 0.02149954321794212, 0.04733636444143485, 0.026056686183437705, 0.047824144712649286, 0.04544365780020598, 0.023774674846208654, 0.042608783551258966, 0.031064884242368862, 0.04073563621204812, 0.02576026126916986, 0.0652715541946236, 0.06513268352136947, 0.09751293546287343, 0.018926415177702438, 0.04104662948520854, 0.01907755355205154, 0.025960240382119082, 0.02019661020312924, 0.006342493770716828, 0.03976431333285291, 0.03745999303646386, 0.0017405412040716328, 0.059519482965697534, 0.030338212200149428, 0.07004950093687512, 0.06631752228713594, 0.03863924343022518, 0.009543260275677312, 0.021440060081658885, 0.0499179102916969, 0.013327602082426893, 0.043562625141930766, 0.03943165676901117, 0.011869693789776647, 0.04238655114022549, 0.08889668257324956, 0.012097710314264987, 0.08175265771569684, 0.013590941125585232, 0.012177899370726664, 0.06287662879913114, 0.027905376045964658, 0.010420025191706372, 0.027334250735293608, 0.011835496552521363, 0.013130481165717356, 0.0727810719399713, 0.040124110237229615, 0.032428632548544556, 0.061084420085535385, 0.0455335541482782, 0.025099907543335576, 0.045305432795430534, 0.05502528525539674, 0.01920012480695732, 0.0169426729917177, 0.04736728973512072, 0.06365692286635749, 0.035124157438986, 0.026475381782802287, 0.007129521900424152, 0.09925371705321595, 0.020318090500950348, 0.04417709002154879, 0.058515895216260105, 0.038489021608256735, 0.02514113199140411, 0.033304036551271565, 0.04323930108512286, 0.02728878491325304, 0.0226351145101944, 0.05689252138836309, 0.05015548660594504, 0.051888809612137266, 0.03216997552954126, 0.010159644534724066, 0.0412898683862295, 0.030374801935977302, 0.019735599198611453, 0.040740708791418, 0.07044405632768758, 0.04693459908594377, 0.017554803816892672, 0.060972886421950534, 0.024457422878185753, 0.04274565042578615, 0.033082624213420786, 0.021494210886885412, 0.028177699714433402, 0.030930618595448323, 0.01106887377318344, 0.025112049079325516, 0.005858506337972358, 0.08748312131501734, 0.018062829876726028, 0.047353029367513955, 0.04212612038827501, 0.02830145283951424, 0.061322530746110715, 0.03699065884575248, 0.01887350375909591, 0.03073601077630883, 0.025429779198020697, 0.10968449874781072, 0.057907519658328965, 0.011766769039240899, 0.06233847525436431, 0.017456055502407253, 0.03449593314144295, 0.05034939124016091, 0.04707562940893695, 0.02415276012470713, 0.019848875053867232, 0.019752514599531423, 0.013918449967604829, 0.04067250913067255, 0.021399997094704304, 0.022449228781624697, 0.04504786302277353, 0.03391253456356935, 0.08201376753277145, 0.02074179930787068, 0.022690491714456584, 0.053677571049775, 0.029112299271218944, 0.022394200386770535, 0.08480189018882811, 0.02449035568133695, 0.0035237663360021543, 0.03980408873758279, 0.029434395073622, 0.01824691589717986, 0.018418285217194352, 0.04236361877701711, 0.07237806348712184, 0.018691386285354383, 0.02753303499048343, 0.03142842157103587, 0.05925410951022059, 0.03501924373267684, 0.043495019199326634, 0.03296542796306312, 0.08148109103785828, 0.10599728644592687, 0.031717180099803954, 0.0513781526387902, 0.0249997992432327, 0.04648426758649293, 0.007460869037458906, 0.031179037687252276, 0.0950288336025551, 0.046931767792557366, 0.0347895453160163, 0.09090747975278646, 0.03318048009532504, 0.04248140874551609, 0.082345715345582, 0.04857045583776198, 0.0445350278459955, 0.06762812539818697, 0.005064256183686666, 0.05227255191130098, 0.02894299126637634, 0.06673570023849607, 0.05899852127186023, 0.0451491661806358, 0.014248929255700205, 0.033012943968060426, 0.03518135847116355, 0.025098701553361025, 0.05594801972620189, 0.013677150855073705, 0.028896877920487896, 0.010075745667563751, 0.020622513911803253, 0.044518622671603225, 0.004494372115004808, 0.014876707336952677, 0.027173095222678967, 0.11143520285259001, 0.12848872487666085, 0.11929408661671914, 0.127350359398406, 0.13493026985088363, 0.1188443970750086, 0.12113610457163304, 0.16656844090903178, 0.12305080846999772, 0.20306500751757994, 0.10463187572895549, 0.17978747142478824, 0.12277276284294203, 0.10347848918172531, 0.11271451701759361, 0.2335943208890967, 0.18909991078544408, 0.13717957102926448, 0.09077625320060179, 0.1525780517840758, 0.14873391977744177, 0.14885284152114764, 0.11158706853166223, 0.06635187630308792, 0.12542865704745054, 0.11125835648272187, 0.13496667961589992, 0.21883840643567964, 0.07139730048947968, 0.19111279339995235, 0.21323971857782453, 0.09157533102552406, 0.28153517574537545, 0.08876578256604262, 0.17815870960475877, 0.1132740815228317, 0.08502815617248416, 0.13818099541822448, 0.12386600574245676, 0.08792516673565842, 0.15375002170912921, 0.11030539433704689, 0.09670879619079642, 0.2331480526481755, 0.13815399608574808, 0.17095089715439826, 0.14665712340502068, 0.12574895314173773, 0.13553932076320052, 0.12898398970719427, 0.17349572153761983, 0.12921481247758493, 0.14291668427176774, 0.09291345297242515, 0.20452341675991192, 0.15463239076780155, 0.10330190998502076, 0.1481665181927383, 0.24119640671415254, 0.06077414298488293, 0.13419417809927836, 0.28171860496513546, 0.1529191280133091, 0.09666805970482528, 0.1534815868944861, 0.1224017706408631, 0.10185859602643177, 0.10711746188462712, 0.15050432790303603, 0.180720959615428, 0.15723504329798743, 0.12565746117616072, 0.09672078187577426, 0.17814336199080572, 0.180629690294154, 0.12924452807055786, 0.16225396539084613, 0.2826024731621146, 0.11847110421513207, 0.0997601512062829, 0.15766946686198935, 0.0965667342825327, 0.16122181608807296, 0.10250623861793429, 0.130335025023669, 0.10951263961032964, 0.06549241734319367, 0.15366786596132442, 0.07733019228908233, 0.13169922603992745, 0.17335124022793025, 0.1578840662841685, 0.3335507627343759, 0.12863451236626133, 0.20355838729301468, 0.15642323764041066, 0.1272981270449236, 0.06666967878118157, 0.07847779008443467, 0.15826793474843726, 0.18192880495917052, 0.2662686933763325, 0.15546335867838934, 0.1307136390823871, 0.06224372897122521, 0.07451070647221059, 0.19170101964846253, 0.14157477737171575, 0.14361691544763744, 0.13136463618138805, 0.0892314876546152, 0.1082918289466761, 0.13704543525818735, 0.10070269359857775, 0.09926740967785008, 0.2974555199034512, 0.14335389831103384, 0.141754481010139, 0.13953658752143383, 0.08950412302510813, 0.07320373246329837, 0.11200414810446091, 0.15900147351203486, 0.1399185264017433, 0.11612144982791506, 0.05038043156673666, 0.09635237234761007, 0.13855220284312963, 0.053030325507279485, 0.09125555443461053, 0.10268584577715956, 0.11589907269808464, 0.10914427461102605, 0.15184133662842214, 0.22161147091537714, 0.18158372113248333, 0.13078121904982254, 0.17106282786699012, 0.15011734241852537, 0.2003614229033701, 0.1934738620184362, 0.159308678121306, 0.19146446749800816, 0.12298874265979975, 0.2333698805887252, 0.15803074435098097, 0.13930385001003742, 0.20762928994372487, 0.1907852094154805, 0.174934834940359, 0.17031545547069982, 0.07578648801427335, 0.13946900755399838, 0.1400347170419991, 0.16938174463575706, 0.13364982762141153, 0.1178475740016438, 0.14168880094075575, 0.08003453389392234, 0.09121859548031352, 0.15491587633732706, 0.14951991353882477, 0.1898577919928357, 0.1126045901037287, 0.13213097787229344, 0.09794321042136289, 0.16789744928246364, 0.11104910052381456, 0.10444027546327561, 0.07907366045401432, 0.09872246548184194, 0.1591417839517817, 0.15740639035357162, 0.09177298721624538, 0.1272495460580103, 0.15014576667454094], [0.01981088636966888, 0.09056451846845448, 0.0134768359203008, 0.0312853763171006, 0.045122901574359275, 0.03862094206851907, 0.028466998155636247, 0.06774139939807355, 0.06247098572202958, 0.04172616587311495, 0.07234881544718519, 0.06498779403045774, 0.03817691140284296, 0.05441651264845859, 0.026189853451796807, 0.0005695965444374451, 0.021122281723364722, 0.05142439214978367, 0.022242321720113978, 0.04969844609149732, 0.047861452476354316, 0.02262150537717389, 0.04779417678946629, 0.014415053447009996, 0.0489833237224957, 0.02607486880151555, 0.03511576374876313, 0.019632535295386333, 0.029141658633307088, 0.051079965123790316, 0.057363454907317646, 0.03014034820807865, 0.03829608176602051, 0.019822597460006364, 0.014755907031940296, 0.07640713869477622, 0.0464657955308212, 0.08588318451074883, 0.05314692432875745, 0.03548198023054283, 0.07770252035697922, 0.012040280143992277, 0.018868733604904264, 0.006971709299250506, 0.011409093749534804, 0.0254386756932945, 0.046592966245952994, 0.06894172678585164, 0.02111928344675107, 0.09244128377758898, 0.008090018236543983, 0.03654843159893062, 0.03907564852852374, 0.06498942675534636, 0.048560518480371684, 0.02532344984501833, 0.018927973687823396, 0.03884758654749021, 0.02942212737252703, 0.031484520513913594, 0.031140995197347365, 0.07237479803734459, 0.04187412043393124, 0.0617767028597882, 0.04159239375439938, 0.052168610418448225, 0.03631032093835529, 0.024551581009291112, 0.024788292721495964, 0.05031091088312678, 0.035319052840350196, 0.008038906526053324, 0.024220176819653716, 0.043728023883886635, 0.009633459976612357, 0.03755899553652853, 0.06421121812309138, 0.0631035775586497, 0.025245477954740636, 0.06335115060210228, 0.011775230450439267, 0.09863181956461631, 0.029954547826491762, 0.04003629932412878, 0.010114562774106162, 0.05765252142737154, 0.052902657553204335, 0.020219729958625976, 0.08448949796729721, 0.018835860173567198, 0.011830947187263519, 0.07939381554024294, 0.01190365261209081, 0.022818812758487184, 0.04724380749394186, 0.02113794289471116, 0.023621419495611917, 0.038045243272790685, 0.03929860824428033, 0.017082489903259557, 0.030387991755560506, 0.021902731641603168, 0.06403368897736073, 0.046575284577556886, 0.02291462958964985, 0.033936420586542226, 0.033782714381231926, 0.025270126534451265, 0.03328681872517336, 0.006755112572136568, 0.08265851574833505, 0.02824316827172879, 0.0420249805029016, 0.042910114061669447, 0.07077977425069548, 0.07511416901252232, 0.025769881358428393, 0.03350582279381342, 0.007788992006680928, 0.025144260143861175, 0.011254242781433277, 0.03753233759198338, 0.04342450774856843, 0.04034049452457111, 0.03793437754211482, 0.04407029497087933, 0.07841846279916354, 0.015226803443511017, 0.041804536667768843, 0.018033062333415728, 0.043225775443715975, 0.004245704867571476, 0.07111172948498279, 0.07218822953291237, 0.051942734062322415, 0.01630572289286647, 0.0822325526678469, 0.03866662867949344, 0.040885342241381295, 0.05002426005376037, 0.011062458834203426, 0.04086457694938872, 0.0484860625147121, 0.05059614792116918, 0.06121171325503383, 0.035286116326460615, 0.06128216162323952, 0.03469453928119037, 0.06462011180701666, 0.05402564944233745, 0.012171754387964029, 0.02192980333347805, 0.04322420951211825, 0.09333740483270958, 0.032471027734573, 0.08183884332538582, 0.049988562750513665, 0.029578995126939844, 0.02629822371090995, 0.02455429726978764, 0.01949234545463696, 0.05179110215976834, 0.016190513742913026, 0.03274827184213791, 0.010871006998058874, 0.011849772690766258, 0.030738242785446346, 0.04485740566451568, 0.0646393111674115, 0.018373140374023933, 0.05476596772496123, 0.05695118445146363, 0.0020014931988043827, 0.0619813129742397, 0.040449619918945245, 0.06388733003404923, 0.026508327573537827, 0.07730031342362054, 0.03460728497884702, 0.019268595351604745, 0.08118738609482534, 0.0511817098595202, 0.01832214926253073, 0.07145944793592207, 0.050643678769120015, 0.07374140361207537, 0.07791634794557467, 0.032657618503435515, 0.03051105097256368, 0.03995530503743794, 0.007846403623261722, 0.03018813509697793, 0.028785047397832386, 0.08112007330055349, 0.032491221572854556, 0.07819214486517012, 0.004063764581587748, 0.08477385927108116, 0.012695404511759989, 0.04070082577527501, 0.05144473441760056, 0.0042410961304995, 0.04026560811325908, 0.03554692928446457, 0.03687536620418541, 0.015919928555376828, 0.03895926864061039, 0.059895005979342386, 0.022277673924691044, 0.02439712709019659, 0.03713266509294044, 0.11723491625161842, 0.1014622743241489, 0.03569397842511535, 0.04605708738381509, 0.0606350051384652, 0.08457451840513386, 0.05166464390640613, 0.03463808410742786, 0.022762192456866615, 0.019085913845628966, 0.07311007342650555, 0.05284590180963278, 0.023697543438174762, 0.0657502691319678, 0.06374396194587462, 0.032844843808561563, 0.06586136863916181, 0.024328354120370932, 0.03768382848647889, 0.02698094947845675, 0.02503037943824893, 0.008699610916664824, 0.044275131440372206, 0.04194261695374735, 0.07412786959321238, 0.014740288534085266, 0.04645491935661994, 0.04299424392229412, 0.07400298098218627, 0.060668835940305144, 0.056372338949586265, 0.034232069956487976, 0.0455166665778961, 0.005493484713952057, 0.013898880461056251, 0.06983565108384937, 0.03258689182985108, 0.03141988316201605, 0.010929944655799773, 0.020212291783536784, 0.022379132933565415, 0.0707616881118156, 0.04920727420540061, 0.05468091017974075, 0.04594106743752491, 0.005391506665546331, 0.06256191365537234, 0.026086331272381358, 0.0114205367390241, 0.017093874448619317, 0.06495468682260253, 0.015337199765781406, 0.0025232995494661736, 0.06653989941696636, 0.012134944790886948, 0.02003605397476349, 0.0497473610448651, 0.027249421400483698, 0.045088599508744664, 0.053452058346010745, 0.05250702233752236, 0.08266382210422307, 0.056198264501290396, 0.03282420468167402, 0.018582793381938245, 0.09954829773050733, 0.04613805940607563, 0.058901734082610346, 0.044975195633014664, 0.015548186784144491, 0.030758521970710717, 0.046994872609502636, 0.031418124272022396, 0.07646775731700473, 0.026318593809264712, 0.05371536120946985, 0.044791102191084065, 0.01581666241690982, 0.03996145002020057, 0.04434471149579622, 0.026703174735303037, 0.06062815140467137, 0.05377992805733811, 0.01573575718794018, 0.04082908002601471, 0.021853083817404695, 0.026357636343163904, 0.019723609802895226, 0.07460678491042927, 0.055238029308384284, 0.05172552970179822, 0.05271772919513751, 0.024723579299461562, 0.03000501572387293, 0.017869027287815697, 0.027778017938544508, 0.012369245450827293, 0.01773401763784932, 0.016901288981898688, 0.05083413241663948, 0.034853778197430074, 0.0650721242709551, 0.01721082579024369, 0.06609019503230229, 0.055469460639869794, 0.010626004568621283, 0.021484308781509753, 0.06583599461009726, 0.053331826711655594, 0.03096064774581464, 0.08642213215352967, 0.0509831630915869, 0.03439136824454181, 0.022068401267461013, 0.017450524646847043, 0.03590126027120277, 0.03864208214508835, 0.045181575769674964, 0.01702076362562366, 0.029692766365769785, 0.04143154808843974, 0.03506294509861618, 0.07777214865200222, 0.013215472845331533, 0.05004122183891013, 0.020081356524315197, 0.03275088791269809, 0.034258520099683665, 0.04307358693040442, 0.06106294604251161, 0.0259958245078451, 0.024424180228379555, 0.023655363474972546, 0.028551421164593194, 0.029904818366048858, 0.026652384003682528, 0.011607915112108458, 0.04897412480204366, 0.020049839367857203, 0.051847483118763193, 0.0018449660205988039, 0.09461288209422491, 0.22214743512449786, 0.2153519747662358, 0.20482466934481636, 0.12986385030671954, 0.16739418409997597, 0.0740365928504616, 0.20570800319546834, 0.16828505817102268, 0.21933570475084707, 0.17874044948257506, 0.11481062407256104, 0.2536211017286405, 0.1624828140484169, 0.08931623349781148, 0.09833499760134146, 0.07923095123260282, 0.3024903091136366, 0.17146576952654868, 0.14752030052477494, 0.12896267522592098, 0.1742352865403518, 0.2520445722620934, 0.08168649525032379, 0.1070735118992161, 0.11593615039600991, 0.08867702170391567, 0.10284554853569716, 0.13032653485424817, 0.12315245301579125, 0.15990226267604157, 0.25266102980822325, 0.09787807954126038, 0.1541623886441812, 0.09218355815391988, 0.22693856240948662, 0.14616108674090356, 0.16073521954240277, 0.13177799759432673, 0.09274940122850239, 0.13590867281891406, 0.14509944448946044, 0.17442440061131492, 0.08414009484113194, 0.13420939212664962, 0.09238641679985449, 0.14653230900876224, 0.11304366693366319, 0.2226281093317084, 0.17341570317512378, 0.14391938515473157, 0.17219583503901958, 0.16353093436919153, 0.11774365106248297, 0.10651601056451909, 0.08191371118300594, 0.14451666560489684, 0.18343104544328526, 0.26148590783122927, 0.12150394264608622, 0.12830997118726373, 0.2184942428721115, 0.23077519872458652, 0.19828002521535382, 0.15747401484986767, 0.12731932278256863, 0.17013483156915754, 0.12954814068507403, 0.12121664243750274, 0.1323814081843011, 0.25218074151780456, 0.08162395446561277, 0.11191816287464462, 0.10780188531498425, 0.11941277829464525, 0.15266938047716394, 0.18259038508404046, 0.09634011206799187, 0.1159030431881547, 0.16803523642010987, 0.10734447001595981, 0.18521548015996814, 0.08105565488222055, 0.13386833074036986, 0.09632197397877462, 0.14866354933474213, 0.12478932650992647, 0.16595370514551178, 0.13197926804423332, 0.0995259293995332, 0.17021346953697503, 0.17306635942077264, 0.08180736884241924, 0.13397233531577513, 0.14521165721816942, 0.12868232151959091, 0.09695340064354241, 0.11005212159943767, 0.11727931894711219, 0.08851207196130417, 0.15965401427820325, 0.15459578804438934, 0.16508413071278483, 0.1494332158472389, 0.14852254127617925, 0.13539501756895334, 0.145611452171579, 0.13814694568281993, 0.16502842510817572, 0.22955331194680184, 0.21053556993138045, 0.13391673361184075, 0.18443092616507784, 0.13247062917798758, 0.23175738664576784, 0.14232462854124606, 0.1400624733651057, 0.1582703838357702, 0.043438775537651964, 0.07753228652291, 0.12015255852020346, 0.07441305468091741, 0.12437079974915832, 0.16481419675983489, 0.14263781486079097, 0.10894120816374198, 0.1449276669882238, 0.1460071059409529, 0.10391708361566998, 0.07631297499756329, 0.08356336446013302, 0.11556402270798571, 0.19870034797349945, 0.07706872624112293, 0.25255891028791666, 0.12764178594807163, 0.21864605660084635, 0.16532492794794962, 0.08986506654764526, 0.14595420565456152, 0.10020408168202266, 0.11382389420759864, 0.18652158585609868, 0.2000094816321507, 0.14002195210196078, 0.16159891616553068, 0.09735048675793223, 0.15056377393193543, 0.1567875876207836, 0.08099530343315564, 0.12074346392182633, 0.11373756016837433, 0.1358411819091998, 0.10593724669888616, 0.12759047385770828, 0.18777372257318348, 0.13673566281795502, 0.15980998403392732, 0.13351775502087548, 0.11490847624372691, 0.11698310554493219, 0.1605397675302811, 0.11890304900589399, 0.1219409859913867, 0.09730744961416349, 0.09912600828101858, 0.20969446428352967, 0.15298535727197304, 0.13568383175879717, 0.09297079872339964, 0.14130230527371168, 0.20459531602682546, 0.09433159328182228, 0.14789587177801877, 0.1217113209713716, 0.13223850022768602], [0.0037504766805795953, 0.035338998059160076, 0.012633473215828417, 0.03434400066907983, 0.032781590562080964, 0.02215014141256688, 0.080779924755916, 0.014989093542681076, 0.03108908382273512, 0.04423089943884406, 0.05708322365535423, 0.06534780986839905, 0.017859685503935907, 0.005104851661599241, 0.04937609424814582, 0.035715790145331994, 0.014386918628588319, 0.056391467805951834, 0.033297828485956416, 0.041961341339629143, 0.03118118991551455, 0.06051141899661161, 0.07527552676037885, 0.0716567256313283, 0.014585214921680745, 0.12415942124789581, 0.09554918302455917, 0.03768011032661889, 0.031115016317926347, 0.031619394721928984, 0.04758015253173653, 0.020788560177606996, 0.013442718463920755, 0.031782971491338685, 0.008511179621564224, 0.029987358175276313, 0.027951895717706066, 0.007496800581066054, 0.04780303061124869, 0.023055066194501705, 0.04049542527354788, 0.04592071403749287, 0.08174161455826834, 0.0072320551680604694, 0.04858703541685827, 0.003818926120402466, 0.0185454670645413, 0.014177453940646956, 0.10734680778114125, 0.022202177096914966, 0.03639129667135421, 0.0504509133315878, 0.029370631600613706, 0.009303311871917685, 0.04234882406308316, 0.025196937785949558, 0.016043071263993625, 0.030730596809007693, 0.04258993671101052, 0.0313845717755612, 0.0381704398751026, 0.036042932551936246, 0.022399237714125775, 0.03382495742698666, 0.0644350127549842, 0.0371516418090323, 0.0010273151383444201, 0.1105071471829433, 0.09327942825620994, 0.0070681866418453865, 0.013585527158284094, 0.037142572764423676, 0.0723779150575865, 0.04879821353824809, 0.06497124413726851, 0.021243144183245022, 0.06083540356485173, 0.008977301240520319, 0.048751016656751744, 0.006085651302782935, 0.04065297209308483, 0.019192224644939415, 0.039542737722513266, 0.07743148060399108, 0.02445851012453204, 0.027718217534129508, 0.08232535081333481, 0.06146731633634772, 0.02002917983190855, 0.03327905957121402, 0.09780398351722397, 0.031063244096003473, 0.007961625760799507, 0.02930593487690203, 0.1387981208972633, 0.08919979794882238, 0.03432746190810576, 0.02328055848920485, 0.04293684251024388, 0.04436324663402047, 0.027034348859160673, 0.030479006891255267, 0.05316458744346164, 0.007218865348477266, 0.0942402942746412, 0.015871740906732157, 0.0557710509019671, 0.02913806849392131, 0.053169444800005294, 0.08401281651458703, 0.056598434239276685, 0.03867978695780039, 0.0037828368704140303, 0.050810075699700974, 0.030168551675160415, 0.01779422993422486, 0.04314039135351777, 0.03050924940907862, 0.030835957659292035, 0.045648583327420056, 0.01407364974511438, 0.04169013460341375, 0.03460763749899343, 0.025927858623617794, 0.0533298117807135, 0.032153626016224734, 0.017461656861996744, 0.08013241575099528, 0.06994069466600195, 0.04270876197551843, 0.036474213120527565, 0.0452775094890967, 0.04445422651770059, 0.0757222699758131, 0.021569909949903376, 0.04709346321760677, 0.04469228151720017, 0.04063060747284908, 0.009399201062478824, 0.035418051629676484, 0.009713971867313376, 0.01787598492228426, 0.005393271585489856, 0.10733151211752556, 0.02733864796027774, 0.02570124011981534, 0.02232650909718359, 0.052269171428633854, 0.05457545099488925, 0.04556804175081197, 0.06411804890376516, 0.05156927421921864, 0.0944644896662794, 0.04161478063906543, 0.0059694935953302775, 0.06947566493181512, 0.03018845422047889, 0.02199032918724697, 0.02012625274801394, 0.04861777888436336, 0.052679831424029544, 0.02987675034091808, 0.03268578671850264, 0.009544386484776624, 0.0162002136130468, 0.024017960131459404, 0.004716264993476216, 0.011245472451264504, 0.018055387990898453, 0.047090717271203175, 0.06569480843609199, 0.0457094357261667, 0.04152297326072585, 0.01949437708390178, 0.027398019774409477, 0.06941273823031224, 0.0478675417980412, 0.04730334629130084, 0.007793064542056527, 0.013823739864164963, 0.019376570417080075, 0.05723853661038447, 0.11363353332853876, 0.04587690134940203, 0.054619211732642725, 0.05618915834929794, 0.053365865314844996, 0.018178593782067765, 0.07531828188803047, 0.026879264114541, 0.04253956714819651, 0.03401716996449977, 0.018392241399851628, 0.049301567778456956, 0.05060279756435193, 0.028301562306296546, 0.00662296019072528, 0.03453027973591816, 0.09883069287752733, 0.021815061736560892, 0.02514859428629279, 0.01761245384841459, 0.022935899542062543, 0.10584139090497047, 0.051173857937101275, 0.037241619793348946, 0.06541634720633738, 0.030756028354517184, 0.030730797188880388, 0.03566906452761032, 0.024282075646624435, 0.0299258341328823, 0.016340694746759254, 0.011566729626792949, 0.059335419209674, 0.02637726614921121, 0.03882413097016979, 0.01605594010470668, 0.031238272204063833, 0.0703169932239689, 0.10155301672057249, 0.01146591628639726, 0.0042229812333971495, 0.0416333343309816, 0.05563748287386261, 0.044996780998189934, 0.011237235539738322, 0.04183055636531208, 0.0558108448603889, 0.02348018879274605, 0.04526336044364143, 0.049031737726181746, 0.0209514281959855, 0.01801806538423989, 0.07554549039923586, 0.04034501420392189, 0.0925270612060558, 0.021776197318104096, 0.04597671279043425, 0.017211541962751653, 0.06637595157371834, 0.04802689945790917, 0.07824001339031383, 0.034588252601679415, 0.05052375141531229, 0.047776380088180304, 0.01725372378132306, 0.0223896269017132, 0.026416458968014922, 0.0300978658196982, 0.03453472520050127, 0.005546705515371286, 0.013548235165217193, 0.017866234957182314, 0.030909858869563323, 0.05151433673745487, 0.015475421987503069, 0.026566942397039384, 0.08137909026117995, 0.04366458138974849, 0.027310941732139327, 0.04032782235299237, 0.047370046813739464, 0.027475477727421094, 0.019481409908621572, 0.011427103818277828, 0.09070402738871053, 0.07367222060565837, 0.030629661014245357, 0.042150622393819503, 0.05447108647786081, 0.01923164752952289, 0.019822530666715465, 0.005971201462671161, 0.013573865235230187, 0.022401799978979398, 0.006153324966362561, 0.037133885925868526, 0.07030514854704961, 0.051614630574476905, 0.06179320451337844, 0.012915888237330364, 0.03731591619725805, 0.04550975347228814, 0.01956646559847286, 0.040386043838225305, 0.027222039861953817, 0.03704970040416811, 0.03713026053446811, 0.022657833505945746, 0.02238710174424341, 0.022469344694400206, 0.03492510972137097, 0.021159062562219333, 0.025337066399515606, 0.0392804441798944, 0.034285430374438874, 0.022693593891744968, 0.07231725932797417, 0.015130507927096914, 0.08262032482889481, 0.0096675115673861, 0.015505820356338518, 0.018786763394018635, 0.03133831371087581, 0.02389069108176045, 0.037076080043334514, 0.04896302969427779, 0.012506270031735767, 0.024785335263004526, 0.0072027449732559035, 0.058838373224716634, 0.006012643916619709, 0.011189395772817079, 0.025758901283552404, 0.05165649883565493, 0.029783931786369067, 0.1141863146040123, 0.025658878330432344, 0.09038795411470346, 0.01624375356186647, 0.07402961666230112, 0.054197397257667035, 0.018572418157418724, 0.08960348917753436, 0.03694232647831086, 0.04805171316547785, 0.05245631509751547, 0.03850818015052937, 0.08736311603570357, 0.046263326512416825, 0.045531071664299816, 0.024241749197244644, 0.014668751991848694, 0.021713391215598676, 0.03020391501195263, 0.04431085100804921, 0.03558872333087493, 0.028812336167902686, 0.13417384325293824, 0.04846424337301869, 0.015677439223509282, 0.037440470841829665, 0.03671712176583242, 0.015267423041223083, 0.05862791498657316, 0.08587824180722237, 0.0799087250197772, 0.04186575271887705, 0.04850958488532342, 0.007766072167214588, 0.051639418306876905, 0.13544374698540196, 0.11844578955788165, 0.13765594077995047, 0.115353571891319, 0.092001427692594, 0.08349652664037421, 0.21373704657889903, 0.11301398844807409, 0.11217293475056067, 0.21347944712033495, 0.1483830323559232, 0.22173000674229115, 0.1441067477571778, 0.06883509500767104, 0.18378307577222586, 0.14072194579057395, 0.1091819311841391, 0.13960109499748796, 0.14940744847990572, 0.08399873055168428, 0.12947558832820505, 0.1272197562502697, 0.18924847390735522, 0.26654055691324174, 0.1410958546330221, 0.24420915520749986, 0.18272832065122202, 0.1584303760319017, 0.09902842328301631, 0.1172131416387856, 0.17072455695597455, 0.10794914967846125, 0.14488055545371026, 0.10994783500791527, 0.14553435787092894, 0.1304377382621169, 0.11189834011020139, 0.11849157264805399, 0.12921145797008649, 0.07197623504907824, 0.19805659423582256, 0.169292701757513, 0.14824220241280273, 0.18379443063167855, 0.20965415082173422, 0.0912418395455461, 0.08486791906761937, 0.11900778830749914, 0.17026923451339826, 0.10519246439798735, 0.09413648265763186, 0.19822878733975813, 0.1164866606995929, 0.118776408926351, 0.07773271092446521, 0.14439772901823744, 0.12843935721321031, 0.13959974428871647, 0.1400339452084154, 0.1878096128348261, 0.10343854679376818, 0.11769207179895602, 0.11322469901642762, 0.08492529450450093, 0.1267257975996472, 0.08762055222177878, 0.11325696759740822, 0.1892066464642994, 0.19403508893446997, 0.10732076581916772, 0.14788364118430763, 0.11542489228304476, 0.14414951030630618, 0.07886208899435587, 0.21003007830586284, 0.06257132408791222, 0.12125984285376035, 0.09595584284397773, 0.12029660196276382, 0.1318285081651993, 0.11582986000576057, 0.05115033556648996, 0.1389125155401416, 0.1154444256098941, 0.1351907488424331, 0.09971043473342434, 0.17789656820241362, 0.23038284009089693, 0.08492927241604775, 0.13345490995561704, 0.23864089540438727, 0.23375536693492904, 0.10504715930437669, 0.0990984300733544, 0.2784241223707795, 0.2996527520008385, 0.1003587749437429, 0.2112487144768238, 0.11929563770536333, 0.1578735129442066, 0.11729100777301937, 0.14432139170821756, 0.17625786160351709, 0.17457709007430822, 0.2087712919455953, 0.08568217381252907, 0.16252470086328685, 0.14464970299741253, 0.16164139669854194, 0.12590061844093725, 0.10131610091775656, 0.13138779118889943, 0.06983319457503967, 0.15551516058621928, 0.09957144531654194, 0.13321200502105057, 0.1349769064108841, 0.10639737825840712, 0.07350799074629322, 0.1096442446578294, 0.1326088616042398, 0.15237410960253328, 0.16299025010084733, 0.14978388062445447, 0.13393494591582566, 0.15452004445251077, 0.13019505597185344, 0.1588167084264569, 0.10657104081474245, 0.1542636175872758, 0.13100242358632386, 0.19098956719972193, 0.1172058611700777, 0.13345409359317273, 0.09820101768127643, 0.13935096154455096, 0.17305202112765983, 0.1848557314951904, 0.09969948063371703, 0.20948664809111506, 0.1565197019954212, 0.23869357304647565, 0.20995360740926117, 0.23218824790092185, 0.07615958791575395, 0.14981298765633255, 0.17898583319038153, 0.1510152520495467, 0.2603613759856671, 0.1344706874806434, 0.11794647260103375, 0.15223770285956562, 0.47513080935459584, 0.12329098230111413, 0.16870922525413334, 0.20018810173496604, 0.1328443895909004, 0.09662463664426468, 0.1321771543007344, 0.11998472924460657, 0.09171073586912826, 0.14885610697092488, 0.09626309940358624, 0.2665068337228149, 0.08790696927462704, 0.10907998977927491, 0.09323974561993964, 0.19074535608524457, 0.13178740802686661, 0.1467554282862693, 0.21311546821380034, 0.15729414793895558, 0.18003117787884548, 0.10397319740150124, 0.0911611012998037, 0.1460849423892796]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.031204088882077485, 0.032031665177783, 0.019185118580935523, 0.04758366289024707, 0.08921798056690022, 0.002275691717841255, 0.02971251120470697, 0.001213415625898051, 0.043129322220920585, 0.031410146184498444, 0.030763800496060867, 0.026650185391190462, 0.06478948474978097, 0.03857839103147853, 0.013633735215989873, 0.01929890837345738, 0.017074305869755335, 0.0219638308044523, 0.035074032784905285, 0.011734173913282575, 0.02206843095336808, 0.045009204550297, 0.013860128292435547, 0.0066160971800854895, 0.01754245262418408, 0.043704223207896575, 0.04783299853443168, 0.07160121298511513, 0.16439558094134554, 0.005927906886427081, 0.03721725137438625, 0.05346459693100769, 0.07058468589093536, 0.028350300999591127, 0.05634362154523842, 0.010629645730659831, 0.03759226972761098, 0.03411920042708516, 0.044643088258453645, 0.05523524625459686, 0.03445026137342211, 0.011598315431911033, 0.018246025319967885, 0.010518973886064487, 0.04490294755669311, 0.04096898228453938, 0.06015577069774736, 0.0903431951883249, 0.01634284883039072, 0.015172932799032424, 0.02702819645492127, 0.02336502973776078, 0.03299635696748737, 0.011122308405902004, 0.028688968959613703, 0.02349610600504093, 0.013918718996137613, 0.024006727726373356, 0.012437935856723925, 0.0291393987936317, 0.06614311758312397, 0.04461706856091041, 0.0835380275384523, 0.010868813023989787, 0.04100180747627746, 0.053901265491731465, 0.033483402512501925, 0.09904329592245631, 0.025670116301625967, 0.051867910733562894, 0.030785508315602783, 0.02515352585760411, 0.08001474081538618, 0.04165961378021166, 0.042830574384424835, 0.024775581587164197, 0.011706427794706542, 0.05291135181323625, 0.02194723638240248, 0.050013795771519653, 0.037318714093999006, 0.030053400041651912, 0.017908880618051626, 0.04549679557385389, 0.04530649406660814, 0.08240404073148966, 0.035438089616945945, 0.0851182677433826, 0.06368298709276132, 0.009281751554226503, 0.04875651968177408, 0.05542760351090692, 0.055133854039013386, 0.07738251370028593, 0.04631055679055862, 0.038774251224822365, 0.05476295089465566, 0.040303810164914466, 0.04311636061174795, 0.010541357987676747, 0.0007464938209977845, 0.014553444507328095, 0.013789060230919858, 0.04442336430656724, 0.00753571602217562, 0.04166458245890681, 0.03751936485059559, 0.01671805828664219, 0.012733171479339944, 0.04657624565879814, 0.07634286128450185, 0.011676145386445569, 0.019771322477026843, 0.04914784673019312, 0.031852926331339404, 0.038433167574112304, 0.014926006351743126, 0.06533165331347845, 0.014162061797833303, 0.08317551808431745, 0.019313452612550464, 0.02811113834468415, 0.021333424592739902, 0.015539362648269162, 0.04408584296470508, 0.05076650049886666, 0.019441489785094745, 0.019877278900821693, 0.007622087632626062, 0.08642466287710704, 0.06104723106545862, 0.07257578647113405, 0.06411534748622216, 0.06560313835507259, 0.03265426399593707, 0.03285022437921725, 0.03369796853803564, 0.08827762008877471, 0.04570995894027874, 0.005269994826448965, 0.04636810663214419, 0.025963952975871507, 0.07842290084226988, 0.04091308372153435, 0.04953525523887947, 0.03408497999771498, 0.007751906887278892, 0.07270112037076615, 0.05334579764166847, 0.019069525369559415, 0.015522898102062754, 0.008144725652527995, 0.002931329095190449, 0.007127290355128935, 0.025235778084606864, 0.021661129176209215, 0.023392340772261377, 0.016542807534278836, 0.05681754591932986, 0.025620538981456775, 0.053097560376045294, 0.024381375005759764, 0.035310607199789956, 0.06059655446733814, 0.07813713687937707, 0.04226878343615681, 0.01675253104622243, 0.03947018907638267, 0.0403309801913565, 0.04286312498152256, 0.05998293934680987, 0.03473771743301768, 0.01691696685156785, 0.04839526074647438, 0.08680537721375003, 0.020997793872084003, 0.019548813615983818, 0.03693283440952655, 0.071018196613295, 0.0314632505615009, 0.040816018226905726, 0.02144433299690718, 0.03114444247330539, 0.04342043706856202, 0.006914179402883747, 0.08491267799399793, 0.03695611558214296, 0.015120321950234938, 0.04331061034463346, 0.04358214733656496, 0.02370876656641485, 0.02929438149294583, 0.04280328190361615, 0.01898180908028735, 0.028177909371152055, 0.01945717136550229, 0.051903441053582355, 0.029407516340143047, 0.11250578056205995, 0.02236831798654748, 0.047579651582054794, 0.03597558265028056, 0.08921720873331651, 0.046135268930811435, 0.13510460034012794, 0.04172776891209651, 0.06763094555935822, 0.011676986796373967, 0.048354012178606354, 0.015783959679538384, 0.030768010328756645, 0.011932786546822172, 0.03685378826048691, 0.035971103789051995, 0.06032308789144736, 0.04759288778586779, 0.040734218709985726, 0.04439858028490562, 0.0174189963581739, 0.051332877919776365, 0.04156068549491465, 0.04971638751158025, 0.013798734125884948, 0.011627331550698727, 0.05308732987032272, 0.013121415831847116, 0.04590111020661425, 0.03325688419863582, 0.022687654854962602, 0.04109066110686399, 0.052673716127173975, 0.03632249958172906, 0.041816945376922376, 0.04155659626121633, 0.023262524300662335, 0.054621415911242366, 0.03201985760824755, 0.04036629899928812, 0.04609815412550233, 0.06435089773731306, 0.02864774451154517, 0.03884251396812033, 0.010910302789852722, 0.04340115607192274, 0.004518102286965586, 0.015357072625192814, 0.025711381567816716, 0.053926030959701166, 0.06322365705273114, 0.04655169912439305, 0.02692528098123148, 0.023465689082513563, 0.009058712057594676, 0.03324104305647779, 0.04642764171876479, 0.034255388236488216, 0.023246106138685718, 0.06511619299999438, 0.059962893938063644, 0.055380306439474225, 0.03928821075533051, 0.04901011896436103, 0.012391696345730452, 0.016880759321793448, 0.03778870508540422, 0.03911609928763937, 0.05603745594271459, 0.03786458597460296, 0.04354592310846783, 0.049415186877013184, 0.07470433280104771, 0.0140712331267423, 0.09064069992746226, 0.045389228689600714, 0.04641209372493904, 0.04928375994495582, 0.031823860117583536, 0.0228532465553144, 0.013578281013906235, 0.017838306084740907, 0.022497392310469877, 0.0358307636633981, 0.03311371277959552, 0.0606263516965555, 0.048341414221795276, 0.020504944732238073, 0.0948354002321139, 0.017414871872460935, 0.011814029930974357, 0.0768230679386761, 0.006280719253481948, 0.049148559191962704, 0.03899027928127907, 0.04530816760961898, 0.013389724481385201, 0.033298437047051266, 0.06278673987253569, 0.052672773599624634, 0.023062524778652005, 0.041994578423327766, 0.06811161976656877, 0.06870098150102422, 0.04395824180392083, 0.02091149322950514, 0.015895536016614642, 0.02175002733565634, 0.08043369802180678, 0.02956693893793272, 0.04303585985326208, 0.0778002389415633, 0.03235538628359791, 0.027033090918848757, 0.03353282212628983, 0.051938867472927086, 0.038755923887947574, 0.037002188109909184, 0.021851697856618557, 0.041615797381382436, 0.03596152637328487, 0.09584708110196516, 0.03984816859883722, 0.0073253834852948785, 0.03516385120747145, 0.07185720198322088, 0.029220023861853406, 0.04535797685093712, 0.0035771480906987563, 0.04737264433060773, 0.0057905390622181585, 0.037131789358682, 0.03766730456845835, 0.025778399358387105, 0.03527449800458271, 0.012246113874425646, 0.050723674867185764, 0.034485557916923426, 0.08715213829418644, 0.08362068052520044, 0.007865671632316662, 0.030585616405005567, 0.03286711566033773, 0.012876250129920663, 0.035817030220641755, 0.0034668790931391413, 0.03176190562953707, 0.025771707041712943, 0.06215594774403144, 0.08039785228902474, 0.04471134358027484, 0.008621326396678342, 0.06771635191398673, 0.09468110773013905, 0.09877118005533703, 0.22676443972159177, 0.17334920674329624, 0.14921137306373566, 0.13695814384846017, 0.12056209787260741, 0.07367950107436627, 0.14665099326521158, 0.1868633003323339, 0.17401921766577289, 0.11944155878154561, 0.08426423388300464, 0.14923814975190908, 0.15008007176220417, 0.09768388175871223, 0.13397009402979165, 0.15763782168505713, 0.1350950711639598, 0.10599563145660795, 0.04898886756564025, 0.1481754833366722, 0.1269486645469442, 0.22673735133139417, 0.13253155950224027, 0.15092551155248657, 0.1570684163016267, 0.1493932883022353, 0.13554315024521202, 0.3696687746560201, 0.1519437084789388, 0.10641970206052065, 0.10470758221345022, 0.19154697947669774, 0.09134391453699209, 0.15449252561666071, 0.09433782732230611, 0.1356975466478616, 0.10417539553600363, 0.13324129016837105, 0.21573192469077185, 0.11873684503370896, 0.0846832653041929, 0.10640976470313035, 0.17319896636763588, 0.14547531260177493, 0.11120420196675695, 0.163114040333312, 0.1441608354798518, 0.13169725192710757, 0.11507257251651026, 0.13650007545948029, 0.13928888831287622, 0.12214369620778598, 0.16044612333644181, 0.22299312724499032, 0.11648219297057949, 0.10374591467552818, 0.11252319876803085, 0.15978877345332876, 0.1534272765275091, 0.20961083908332512, 0.1478484782273881, 0.16750224080169573, 0.15697279799496755, 0.08601999943493865, 0.13489521079463884, 0.16615217027720064, 0.14751909824553877, 0.09463116861297749, 0.1317698636557907, 0.10270888946251944, 0.14273922191932797, 0.21551137324422598, 0.10552626757998951, 0.08828425488900393, 0.09426166812772863, 0.07009998182184063, 0.23711469839327037, 0.17060842568753287, 0.1306454950827174, 0.1451224510674365, 0.098391801584512, 0.10645818983903155, 0.1921236579073593, 0.15127086255233735, 0.16359318571630865, 0.08132868359098211, 0.10965426365146413, 0.10899324013735168, 0.16534719237824902, 0.10217395683866926, 0.17666724510490894, 0.12815250229323283, 0.18255753762787208, 0.18016552145127207, 0.1187094375200104, 0.18530720961280167, 0.18451575364451855, 0.16624594805762172, 0.11585273299715482, 0.21675142779713497, 0.12584515032358468, 0.09343228841316886, 0.10829014427145012, 0.09603441401850432, 0.11983722739387304, 0.1601104499422945, 0.13120557909132913, 0.13184811570681632, 0.08068368304520845, 0.21042948734248057, 0.11637763178441674, 0.12670878757489845, 0.23845273128245026, 0.18860378506360576, 0.0853610984631814, 0.16010883206035942, 0.11313907743897289, 0.062076018439256586, 0.19648194982437417, 0.16967058851150796, 0.15178203902905807, 0.10960614279611036, 0.1330934395082295, 0.15971847722539678, 0.1713309806655161, 0.1195805704628583, 0.15212307072943076, 0.05920952869928442, 0.17757037945557386, 0.270839759032242, 0.10549975806497969, 0.14172133669489995, 0.15308113885112107, 0.1315520136267878, 0.10245820682030171, 0.1252904097782448, 0.15480559319257736, 0.20002316683530807, 0.07860667887143791, 0.15571944415569305, 0.10987022120389156, 0.1844417318352498, 0.16967671865131706, 0.14159974321955815, 0.16979155858280137, 0.09332593865110539, 0.2140984428115189, 0.15542601380730048, 0.08956014033174142, 0.11861643157317303, 0.1330362496082671, 0.06522543713799678, 0.12250271014636382, 0.15929500776110217, 0.16627458011498675, 0.09927134306053631, 0.06934564808034338, 0.18762061750749126, 0.1307750740670599, 0.21087666100356728, 0.2561420586425811, 0.12930121331010014, 0.1441350977984257, 0.1921061729080975, 0.12544744822662324, 0.15211760852253065, 0.12234339330461808, 0.3208124212687835, 0.1370770952780731, 0.13383796205744147, 0.12772061687428504, 0.11729446618119255, 0.15214972867397591, 0.17989416257478297, 0.2005047316197306], [0.003538084220053861, 0.05282027916109655, 0.03096105036092922, 0.06680584803689271, 0.05279512035485823, 0.08635467092972249, 0.038005445603630506, 0.025507803038635757, 0.054435886413557455, 0.029803218349115923, 0.02761233346973313, 0.029985295004735235, 0.03461505526502151, 0.031067242416611407, 0.009620882428862387, 0.027819283204735257, 0.01866424037871184, 0.10806771519128233, 0.04223072981403675, 0.03261220277636312, 0.01786567834642483, 0.01130789634771645, 0.037770693161292, 0.07869851964642294, 0.09493207980995066, 0.055360750848194584, 0.04734732967335731, 0.05653576357872225, 0.07001626756391488, 0.017825131108111236, 0.020872437708021607, 0.022066827914386522, 0.07177387364208698, 0.03903631841239985, 0.11363911427906714, 0.026816298450285103, 0.008430406123807188, 0.034854939658544026, 0.06113651143095922, 0.054229209417826496, 0.05015258851926774, 0.020455243102333043, 0.044092930475017056, 0.006725813045704854, 0.033258513212786056, 0.03081767114053946, 0.03573824011255056, 0.03762357351661194, 0.013671981796505861, 0.04867097974056378, 0.038141718760016374, 0.0819835472793784, 0.0845196662703529, 0.04221411312755663, 0.0812743286951445, 0.046704028645763174, 0.012622027443285333, 0.032175626984098926, 0.05019391130190343, 0.056374394698650576, 0.039990267614484765, 0.03565866332792211, 0.028243392771400977, 0.03210479269910138, 0.0879258346685674, 0.04566488089039922, 0.03894659646903165, 0.02846634692104999, 0.0216638547135517, 0.03464512337814085, 0.033763663450372405, 0.052872774977004156, 0.06549979429109953, 0.005484830344357761, 0.030990203777037095, 0.1033720132545568, 0.06810065082390793, 0.046487058061757125, 0.049442156523582526, 0.030138465008349158, 0.03335500725370366, 0.014036256634426536, 0.03336684079840779, 0.04639775172108784, 0.07124946467229165, 0.00820533499791054, 0.015053463721415028, 0.03862307203235105, 0.02734426972892834, 0.061814886357751675, 0.03957069813623093, 0.0030795807469985448, 0.04492644024139736, 0.03012214703630889, 0.016809984408610035, 0.029276428940647747, 0.09307735628681257, 0.07104885473381728, 0.06034124453435652, 0.045270466507645324, 0.013140720948285889, 0.041778487284318544, 0.008460481658403296, 0.008899399854271905, 0.016435624711448327, 0.044741433957824484, 0.050622011767700315, 0.04434512338775676, 0.019085978783550672, 0.04871024677413516, 0.04163832898484543, 0.0634890267974697, 0.04999772827432025, 0.04722439291072078, 0.05601943288638722, 0.024868990149116144, 0.033113011450041085, 0.07244847845868208, 0.022816313576186076, 0.04958146877470426, 0.013481022560881684, 0.01968792548723286, 0.05862738806172274, 0.05747811672335956, 0.03564628059393726, 0.017642996936046984, 0.040899732484831475, 0.03754566656425595, 0.03228022156690713, 0.020209666436130647, 0.02058413745544385, 0.04863327121711336, 0.007411236056213966, 0.04064683453179896, 0.06839213674538769, 0.006325821887003258, 0.07143910566810519, 0.045575975309475325, 0.023242185743583832, 0.044781313263229094, 0.022793429452576675, 0.023206610894703772, 0.015260840191331226, 0.038942462706472725, 0.03213089774362743, 0.0357123577123275, 0.02566780265624402, 0.004452313678484643, 0.0031255964540832792, 0.02868539737391984, 0.10031092868302949, 0.06839855632279068, 0.039938339541549794, 0.043278657176415436, 0.08694299365743063, 0.030749421384825837, 0.11505247515742667, 0.03201001301931683, 0.03073560630582506, 0.08973728356068023, 0.07829844267689623, 0.02570890836068429, 0.019917492172680795, 0.027000408590538427, 0.026695096457842737, 0.04527724231593311, 0.06383750223903917, 0.03961097449064255, 0.030689008708577603, 0.051590440270956606, 0.028332717665762175, 0.09050879802089185, 0.04151604531216435, 0.06483885983470827, 0.06144412422145251, 0.031178581266431138, 0.08973338728537783, 0.03422172070713714, 0.03914212640665937, 0.060183608657098375, 0.08068450682912953, 0.06816181121394038, 0.040771296407910995, 0.018844751102733426, 0.055267555653699674, 0.015606556698912755, 0.1048374135280028, 0.09783693487406708, 0.042714034934761, 0.06888438103487715, 0.029436571421683766, 0.019850717435474508, 0.058830369162024, 0.03915029374184087, 0.049020995138562284, 0.029876880216761492, 0.021625975496135652, 0.03253665585361887, 0.012576865901792189, 0.11652222441625781, 0.04621879394107964, 0.01350761278445134, 0.050911189609905705, 0.04156907176366076, 0.060771293137804605, 0.03816046169959009, 0.02020310770603828, 0.022364629512594547, 0.06910321812028997, 0.06960620870813727, 0.01991007440665271, 0.02675834042747738, 0.03109009314357536, 0.005888415817025816, 0.02384270937909605, 0.04649452406738419, 0.04588320589391515, 0.05930945146246813, 0.15432748681632802, 0.05104421958094463, 0.021120485725987237, 0.02791980154142948, 0.004649838601835654, 0.057356994511792436, 0.012332614896877203, 0.02964781077025691, 0.02929005477199098, 0.08562962975702249, 0.057585843169363216, 0.05208906703046523, 0.06762704186257906, 0.023533109488198534, 0.06746522398316301, 0.056136117054848, 0.07571777256089263, 0.0021251941416267073, 0.05653149994031992, 0.035529859887901694, 0.024136759420798626, 0.04353230098786298, 0.023211523912323173, 0.054585210236837156, 0.06171864835778251, 0.03128657117486, 0.03418371532461606, 0.0663254113169387, 0.04379558900836855, 0.057530575431883335, 0.022216817815206014, 0.05583208883763291, 0.037639963848050684, 0.04115074538276531, 0.0653571164002642, 0.01462381402234314, 0.05824053987453226, 0.03588309991755523, 0.025630201744206715, 0.013426081368379528, 0.09351552027510479, 0.01035682575093233, 0.034836185586755164, 0.10571849867119454, 0.06998784330789931, 0.03207543704775162, 0.0364258028275799, 0.04243922507157549, 0.024145947209035512, 0.03832258385955356, 0.020355036467663012, 0.060057729278923944, 0.027469410670164507, 0.048901947229751386, 0.0524069325911114, 0.03818994351604488, 0.039388801451423205, 0.020810167807212565, 0.03776468918658793, 0.08704754000063986, 0.014738717964064563, 0.025122580154857133, 0.008498136376147158, 0.032029045396484435, 0.06729455228196457, 0.05890075073693879, 0.05369006881664973, 0.02498542013199767, 0.03143735331832431, 0.05189949653868098, 0.014006599485583138, 0.021659507583535742, 0.02599363146146061, 0.0032924300921877148, 0.003952765264330083, 0.037417152561829425, 0.033488315530121326, 0.051664699567481875, 0.096560782258166, 0.018012623586400878, 0.045669790197280236, 0.03682703012600541, 0.02718188967264723, 0.07615394759341143, 0.024374510139750782, 0.01731188218400348, 0.058973651903215796, 0.06184401936479844, 0.039578691066708416, 0.07725689036305994, 0.02868641597160604, 0.026797984100994654, 0.06687907574814744, 0.05030182328482624, 0.04006188486528117, 0.023281460198631976, 0.058165746231679805, 0.04053539363667369, 0.0369544680143008, 0.053488620251300745, 0.0366935103374999, 0.04200734707410447, 0.09146383818006143, 0.03479818391497247, 0.03845869745418895, 0.025902922461682465, 0.04187732651189435, 0.03396890439034905, 0.04749067920784, 0.09107744641369209, 0.04404807506944053, 0.02782318690151442, 0.0353900503978366, 0.010589672729111044, 0.04105008047190495, 0.04703238075308036, 0.029559554568550084, 0.0145093785613426, 0.08608256248407997, 0.04765425226651132, 0.03494343334750738, 0.0128842096637527, 0.0658134333207272, 0.038156865994096734, 0.05565847452089656, 0.03631753090303391, 0.05671836159308441, 0.055958766024559736, 0.020799464182346128, 0.05495128942129668, 0.0697029179718811, 0.013873476746084634, 0.04817500615899917, 0.036760637594852597, 0.1691566512454301, 0.13952428271295503, 0.15304303698940203, 0.22136825427878648, 0.14930613047908992, 0.14436979457968846, 0.17477095389040187, 0.10828751706867479, 0.15044648491311818, 0.08687819674378261, 0.14354443730553612, 0.2005696843843907, 0.12809258128982037, 0.10294023173628375, 0.0628766362206079, 0.14921759226126596, 0.12350345175946131, 0.16010218241717666, 0.14216612064046785, 0.14570836181519553, 0.09583034567185678, 0.09627998326322995, 0.1463117724051699, 0.13222491892520338, 0.159822229470592, 0.07068435632390901, 0.16398993786424398, 0.12393249475280754, 0.17535448976559564, 0.0850972872285638, 0.0524502220650902, 0.184600462380331, 0.20938626519637182, 0.16277648188406602, 0.13230026175733656, 0.11151197802973911, 0.11376640744856559, 0.16473958123242483, 0.18879045004723594, 0.25656297511886805, 0.25579280394595116, 0.15400995151139796, 0.19138609670335427, 0.09010460955323651, 0.14633166196290404, 0.13284841203130782, 0.12771687644999474, 0.10377256519859657, 0.0851268321275711, 0.11662388380500488, 0.18275385053129867, 0.23576683946885169, 0.18181145656853914, 0.1490375175490044, 0.1442173871328123, 0.098506841895869, 0.19643988489406183, 0.10415843004011549, 0.13496060884790495, 0.15479734051041305, 0.12671131087699905, 0.08795099347480573, 0.1221369649283588, 0.1682282393448986, 0.1552109097247012, 0.1561110161128454, 0.16530543914996088, 0.14876069646561518, 0.23021146334940568, 0.1198188889247831, 0.12420456609106623, 0.1544040912995115, 0.14025724260136485, 0.12390557705657557, 0.14175203192280605, 0.18316902278456837, 0.1715717779006809, 0.17024852859321982, 0.14517642004648224, 0.11312955568428151, 0.12576680921483785, 0.13940647419076413, 0.22027082566637546, 0.11737564971554093, 0.21562530775554478, 0.16883389122085646, 0.12336833635345101, 0.09393371306941845, 0.10201697034062818, 0.14854697277769446, 0.15765590040246025, 0.12860938324593008, 0.2127005037618801, 0.15777501510456204, 0.12772897345712408, 0.1288666858454235, 0.12848073936766014, 0.14528444706229493, 0.11118757785880007, 0.15537155501078814, 0.08869792058249004, 0.1851623275433667, 0.10573767576715909, 0.12963004410266876, 0.09558824225678109, 0.21574878628598526, 0.11925022568902932, 0.1529065560316667, 0.09985722412238829, 0.12238752882694826, 0.12078064552042633, 0.1711333022103645, 0.1629046062589623, 0.08543891264707781, 0.1236194717057515, 0.20068354468094185, 0.1070411765249446, 0.18245396349811926, 0.18948112236103043, 0.2283595674089156, 0.19958699180278927, 0.12291365215787664, 0.11274104879703373, 0.12941738910740241, 0.1093456638045609, 0.16360734589397907, 0.13047106069279835, 0.12507635954534635, 0.10226421683910303, 0.1545500272186473, 0.1662797454628162, 0.1501120434841141, 0.07705829906626604, 0.08052486344240606, 0.14352033234899864, 0.07770040523610078, 0.13855445897206664, 0.13752409082371742, 0.12569603801239282, 0.12190712179290131, 0.12349800439551473, 0.1264068967429921, 0.10146214815904386, 0.18137777515221387, 0.1129019538348075, 0.11417267392971553, 0.13835250574629754, 0.08910569362342358, 0.114234628417762, 0.09892671194393188, 0.17449885286623612, 0.11669078841805458, 0.12750628462526947, 0.09168522083200514, 0.27561343100387603, 0.18908911995822564, 0.18366940843407065, 0.09261685365345329, 0.17561533983098343, 0.17141607531812042, 0.18995652731973678, 0.12314995197812095, 0.11755172425182536, 0.1354147883830592, 0.13266829279018566, 0.1357036767876707, 0.16334294836269692, 0.1634292452945374, 0.23150521970819682, 0.11829879236756824, 0.08281981412437744, 0.191509916621726, 0.13516147853806615, 0.14110226678894833, 0.13884149200748652, 0.10677800353732891], [0.03158822080877144, 0.10664141125744209, 0.02413534006336704, 0.034004560875473544, 0.015180917380348546, 0.08553385559935123, 0.012752046150126262, 0.056119997607311234, 0.007546725319116376, 0.015166295215749415, 0.05037282455305103, 0.024444433438475244, 0.0306343217016547, 0.03152111581584904, 0.09014634051709436, 0.028626007006096188, 0.010848732363228919, 0.0304235814473941, 0.025929148105205968, 0.014316003635030938, 0.027183216261619236, 0.048038050226750784, 0.017523854403407313, 0.023514014028478414, 0.061733535840176046, 0.017868199793156236, 0.04112100381462369, 0.019036247467738576, 0.013024665749981068, 0.04102872888324782, 0.017675428789516445, 0.05748815427068621, 0.03240965954319108, 0.036915972814313136, 0.046889843870303594, 0.0665337395912502, 0.015946432504279073, 0.018382469170319382, 0.024364956843783148, 0.04568746815493796, 0.026428292512719054, 0.062127130149747245, 0.11016339922207408, 0.034280368927284144, 0.025279998953919858, 0.056163216577260755, 0.012168073335487861, 0.07437579144607298, 0.013116860900481697, 0.03583160229027271, 0.01507992870756425, 0.025652909607742913, 0.04416647359903436, 0.046959286628407426, 0.06654056734987535, 0.03417072402953636, 0.014792593246966135, 0.03377861772605684, 0.029857636327506043, 0.022183009277796373, 0.02466289202857297, 0.03460802341578528, 0.07006428451859392, 0.16187238274142146, 0.015245352497004205, 0.02467214104399318, 0.07303069331101142, 0.026714817176980432, 0.09557563316775486, 0.04542735652648844, 0.07802522843121551, 0.04192020038317423, 0.06483957971795462, 0.03660797781776637, 0.018463804844941478, 0.03264319857407827, 0.07257160075823776, 0.0391529654734768, 0.030881375241733622, 0.04321996071666945, 0.030675768794026226, 0.04100883561477531, 0.01769497695931932, 0.033373557234881446, 0.017829062635428272, 0.031045163523231167, 0.024509746144758537, 0.04552064448944293, 0.03339430026244372, 0.03557150179403834, 0.06483005054178648, 0.023047000904625747, 0.05280172546918038, 0.05725208822696004, 0.043994959560222924, 0.03213890922779683, 0.04008470590633806, 0.006578059328603558, 0.07423928080243059, 0.06601304878131486, 0.07537513040006161, 0.06802071409765631, 0.009327956740889931, 0.06406990578398108, 0.046880344380042516, 0.041190687770722434, 0.00905338158190716, 0.025470072250755038, 0.04258450419001747, 0.04227958168485202, 0.02550982539105462, 0.0580066854308825, 0.04281150861061178, 0.02101628819218604, 0.025102822328335606, 0.02511409555154387, 0.01827138265070971, 0.059937178521067835, 0.01208162611874286, 0.026853047747863457, 0.004466372274691821, 0.015886450273683295, 0.059594992781057954, 0.03004972455528332, 0.04727652507426683, 0.03219693404389545, 0.02894929210015107, 0.03205169574357569, 0.026625180580595043, 0.01339770999038592, 0.04750849446281791, 0.045868734014220536, 0.04641722196538467, 0.02443909183057258, 0.013956972070445772, 0.06523482530610636, 0.040379605707130395, 0.04722444115031976, 0.046526395599357784, 0.028139280584582593, 0.040367612600675784, 0.04928187117911875, 0.09021225065225735, 0.030533254175679758, 0.08522269534296356, 0.08083885128144175, 0.054645973577862605, 0.033550396183272824, 0.04237428343913052, 0.058566929001244716, 0.05148251344508026, 0.0447209358389955, 0.005020753342250828, 0.05745915856095962, 0.05095478336443193, 0.054311020066961646, 0.02918194240919547, 0.01087542092136573, 0.027836899935209658, 0.01965143223060295, 0.01987516192457406, 0.017687692779873032, 0.031134649834712036, 0.03363256677403115, 0.01959634817467304, 0.04858666434301995, 0.10220339783700183, 0.086055644787848, 0.07635853544343263, 0.008823646057862788, 0.029469628534570802, 0.09656185837229714, 0.013374060526984977, 0.035476659031701274, 0.020690628225565888, 0.021471432519319933, 0.0337296916404739, 0.01699511685728794, 0.026305648898414802, 0.10356111990404315, 0.017702474506222643, 0.027063084817200433, 0.026833499578060582, 0.037380842986749485, 0.026519283528614324, 0.02567023504525423, 0.02346413428313099, 0.05267949374683667, 0.034132481159758754, 0.027102884341729805, 0.06122199942183215, 0.08225472061894834, 0.02504268424672773, 0.053930665671941824, 0.0035500114609021693, 0.05980570706014987, 0.03491694609692786, 0.04755755413498264, 0.0160288238839712, 0.03160198022669647, 0.03143188740068581, 0.015229375912895193, 0.04949148336891085, 0.01536385678264196, 0.04622326167009305, 0.02744572688243352, 0.02735891230258858, 0.03508691275783349, 0.08171693072654307, 0.03422026980842929, 0.005977987939331797, 0.10444780826219358, 0.05190118492464535, 0.052744646891369484, 0.02102570048009511, 0.02986511532071745, 0.035427599359536543, 0.049465656629763544, 0.03474188830296043, 0.044359739986248314, 0.07457818996044807, 0.038743129262002185, 0.0688453960174229, 0.09472598540014587, 0.02914000735472655, 0.06019413602189161, 0.05105771924718283, 0.04038900129671674, 0.052838903357042, 0.04684645791712683, 0.029890242585679516, 0.05109638143039774, 0.05156137776793912, 0.051315734308445826, 0.05666577671945561, 0.031167193010332994, 0.026376605637778994, 0.046127016248647124, 0.02397916621703189, 0.03092800994636491, 0.037284950085449964, 0.006756491575288237, 0.051288742397446185, 0.027194472786504775, 0.01155761327026994, 0.06330589443678036, 0.1587153904256411, 0.04005093076557387, 0.04498401234741323, 0.02387011318205623, 0.028571366383403074, 0.036901823768857867, 0.012786115366907325, 0.07124295603716746, 0.009452694139326923, 0.026868399072554894, 0.02376007309067063, 0.027710905524145346, 0.08433929469902068, 0.031128508562687784, 0.0408850750682177, 0.024160882931028027, 0.009519811192149064, 0.015397872193716466, 0.02293563051352976, 0.04086413166078273, 0.040154898233595304, 0.0900826790893916, 0.033518309428473, 0.06160722972708754, 0.08211885564378463, 0.04965301552147139, 0.06037062616087496, 0.02732413155172253, 0.016211332840612158, 0.04580405955493916, 0.0279384980967734, 0.08243814983870834, 0.04191201449430082, 0.04778245456691366, 0.04934023738314863, 0.025473927707935218, 0.029118551865394693, 0.06656438286881894, 0.018584157078294083, 0.06631568176089786, 0.05916042078752071, 0.03578798998205457, 0.08964095279225148, 0.014459904214163544, 0.02846256196789909, 0.09002365608466789, 0.05296878291119356, 0.0250853169200127, 0.04471951462619472, 0.07443945287377574, 0.05707523814635351, 0.06129638488346245, 0.04169497340626549, 0.036418989911908284, 0.039691772108199075, 0.037427627976285294, 0.007938392827782081, 0.045193947371444665, 0.024978393848869018, 0.05834066301758867, 0.03872549954394344, 0.10659318650141358, 0.042972035153070465, 0.024285873587359674, 0.007845740328775719, 0.02829721888701897, 0.03498282654618379, 0.0776598320226185, 0.10425010012113489, 0.027910925455216784, 0.01743694334436441, 0.05520117425476201, 0.10671806769096293, 0.03163342131301761, 0.03930779603251722, 0.023466692837246228, 0.03195970653905533, 0.00899903689060011, 0.033860665862448514, 0.05601377401035279, 0.03835049974441063, 0.022764244495192543, 0.02864639009203529, 0.04142013014643453, 0.014554597619280685, 0.02466878097038716, 0.04494315340707544, 0.012386018916004105, 0.01258010815945454, 0.02143889676517574, 0.03644205957243685, 0.01855875892943004, 0.014452354716922855, 0.06828978715930134, 0.06299191401922144, 0.04330144111008849, 0.019043346110265702, 0.09268254114431329, 0.021606777991109993, 0.023250132289831527, 0.04546975171251688, 0.015281596206477843, 0.03747904767806176, 0.051587490233941935, 0.09828637950704433, 0.044850088088423945, 0.08664253517054021, 0.229217401065398, 0.1110238600813318, 0.2043412788771093, 0.11178843546076678, 0.10944960158667527, 0.12348686475888826, 0.19558331288862973, 0.09309883404057473, 0.08909724798286334, 0.21386491862358525, 0.13742562266997993, 0.13577676349086687, 0.18089018412865698, 0.14409515541046858, 0.16095577098894864, 0.14734548021806404, 0.12338538348558359, 0.11947910403250717, 0.16347217111615464, 0.14489158376818523, 0.20943959592841566, 0.056049226404866204, 0.10265022268868051, 0.18064166855765507, 0.1096862947451882, 0.14590057806344703, 0.0717112586426083, 0.15526597708230838, 0.13003466301597655, 0.10783422068925574, 0.128297250776086, 0.18657364009413868, 0.16013157146517187, 0.09613700851332396, 0.11647959545371123, 0.12539607676444575, 0.13164231815608218, 0.11041828984161839, 0.1511439256137237, 0.05264169245492667, 0.14924508141120896, 0.20003277022624388, 0.13747294200584292, 0.21386212814832106, 0.1584899111185223, 0.19783463270869106, 0.17142547090770677, 0.17178811394842342, 0.1378713417216204, 0.13785355986328796, 0.11407640253310092, 0.18477810284821317, 0.19961897836765274, 0.12228953564772382, 0.13674298039404675, 0.3014433168573305, 0.10521295509533957, 0.12264377757674083, 0.10891324403928593, 0.11925870101549663, 0.13218767795478925, 0.1849263542681001, 0.18745777546428144, 0.0920824108470697, 0.09125819648033939, 0.17785322677809745, 0.1526060010655783, 0.12961638858541846, 0.11838116333819926, 0.2138925265171565, 0.12240765587193891, 0.18346745520830154, 0.12977755337487906, 0.13386304664891213, 0.11691984487697482, 0.3250404365826398, 0.12112854950828478, 0.09672260755905882, 0.08213042572606355, 0.11159351779497229, 0.10924862057436258, 0.12282772629987448, 0.1286532441736199, 0.1027075907040853, 0.1511136905173771, 0.17205939861014485, 0.13142979674739763, 0.0999946179217659, 0.13393507950240746, 0.1206626885687001, 0.21384915540693328, 0.15410985943162814, 0.1383463607635349, 0.24389917496591806, 0.14507379586575553, 0.09478333857259713, 0.19058946054428816, 0.13755873427726328, 0.12095250465790741, 0.11965477038756944, 0.12890367448562756, 0.09238676560926251, 0.1493465923704207, 0.1112929405644536, 0.1519180746981874, 0.11128192709293216, 0.10238947652396746, 0.08026373878237791, 0.24256090458948165, 0.11703711163136177, 0.08655457582790405, 0.20007335086120293, 0.07616329123266041, 0.2366911992430687, 0.15650371613446623, 0.10185675550019369, 0.08509925391990691, 0.11221815380849876, 0.1269785879412666, 0.13476946129230782, 0.10327419819077477, 0.10591686732368544, 0.14170509850373492, 0.13699887291295454, 0.1636661239899695, 0.1428945385850966, 0.13673392619239166, 0.07622305638506077, 0.11211035685846582, 0.15848995564738289, 0.19420842494582757, 0.10678724327590317, 0.1593952570692636, 0.1307891303440556, 0.13728424353757873, 0.18240990961203352, 0.1265822068671696, 0.1884705398697406, 0.12060763605404645, 0.13614289462566376, 0.12385675116092898, 0.12071441626176238, 0.12645341455936432, 0.19179647468263283, 0.13297695200890303, 0.23561688110930845, 0.07378264475846663, 0.18582356628030539, 0.17953485919861123, 0.11931442146305926, 0.11081263000960462, 0.11731782899005339, 0.1431757234968245, 0.1422907569212839, 0.09533274307614192, 0.08710729031008668, 0.09097250673221424, 0.11699296126607805, 0.13030024798354134, 0.10305737974704243, 0.18692981160711497, 0.22516983153764158, 0.2081761637236923, 0.1840233980328776, 0.14229730266379192, 0.12408752198098227, 0.2609208069043234, 0.1417882487294264, 0.09062729674042203, 0.12868849618826061, 0.14643266826169565, 0.15357784344814718, 0.17610306444112211, 0.19826136762276292, 0.14213009679224342], [0.017006816815410275, 0.008484174722980242, 0.04296988663554657, 0.08612783349235542, 0.05210935734794475, 0.021138423435331788, 0.03922697243979201, 0.009163606282527326, 0.02733277386141708, 0.03945140902942512, 0.02738403585681226, 0.02830395573255373, 0.05292691093927715, 0.028960277741134632, 0.02620610463054618, 0.05764147084846627, 0.04379347759822849, 0.03374255305971019, 0.01873791708931094, 0.028516135753307026, 0.07631244807271287, 0.009041285502462415, 0.00955807818172616, 0.03881666867528111, 0.07183658512076363, 0.05733173180487938, 0.031645191775169224, 0.024290578803629614, 0.01599601539055584, 0.10820778072229587, 0.0098584216357267, 0.03554901100869756, 0.0034261140808666823, 0.02004197631322313, 0.011898474276677007, 0.029703403197345324, 0.02986499843245838, 0.08394534044782631, 0.021685907631763257, 0.034346895045018755, 0.05837920274643693, 0.022177205682964996, 0.03159611354931258, 0.005751760918428772, 0.05179017818591092, 0.024495374455000274, 0.030033426992304157, 0.0326748177758418, 0.0037733659064542735, 0.009039875421876786, 0.021649688969773706, 0.040697634540265426, 0.016730608003854286, 0.02962352769827703, 0.016879401191545185, 0.08412970477365889, 0.021922675005043857, 0.04698535085481126, 0.0249577046270133, 0.03177659644279629, 0.0429355103551643, 0.027142155086039566, 0.08221980999223888, 0.07034614478470758, 0.05996510553814005, 0.0371026860375423, 0.026665750083338935, 0.01929982492583804, 0.0010422589775771485, 0.03722907378687523, 0.03909708546416368, 0.0841775510343723, 0.026958610833389685, 0.07428254059050232, 0.060968641337240115, 0.04147170198848471, 0.05758817722380627, 0.024251918475783896, 0.033186892251251265, 0.015983745834091678, 0.02885717487515649, 0.01269764858079725, 0.022493175056297332, 0.021237041873973794, 0.08950547373387963, 0.02854634301911574, 0.020111372687097173, 0.04592579403833952, 0.08511282037943602, 0.05864709208253771, 0.022987530755926855, 0.07429725737893023, 0.002343800929338613, 0.01157586546469247, 0.04515043896390125, 0.05296860479575116, 0.030654717775178142, 0.03204425942385569, 0.026931490901915822, 0.011843249212688534, 0.041541374812368304, 0.01679611737927189, 0.02660867707163561, 0.06488668383099139, 0.0471411944454303, 0.012877962635684526, 0.030170295722200535, 0.08195553862606175, 0.027789938685600646, 0.01780967588274507, 0.008161034347722307, 0.024378013076784555, 0.03914510984031949, 0.10264300901326351, 0.02336201290745521, 0.0945836711616721, 0.07163520334870555, 0.03267521853558719, 0.0066114058790844865, 0.011684299734042725, 0.03848293599730823, 0.044363999913912266, 0.030586976390623022, 0.025042697234312072, 0.018860009658965282, 0.02835895629687002, 0.04464252793695778, 0.05714317434467375, 0.060766999813495204, 0.024646245656185783, 0.025623513138270937, 0.014242156230466207, 0.004753578323288821, 0.05375121065299027, 0.031274893481167965, 0.03975844294473063, 0.0021735979407822015, 0.0304269452317385, 0.025817532805376686, 0.037174243916524574, 0.09273522620787844, 0.05487996902957093, 0.04366351269709412, 0.04166535429249052, 0.00939525561989285, 0.04303503235860262, 0.00967020927419071, 0.03982336973422207, 0.03357880559633486, 0.043288802335155196, 0.03889483166858554, 0.054390763834817335, 0.03813701725448482, 0.10010614787461236, 0.014913246050127782, 0.01388108004903188, 0.10310603494872339, 0.051959476913907565, 0.02132931309461128, 0.009939228530129185, 0.04131864887312986, 0.05194253368244972, 0.03436901104578283, 0.002471644215802371, 0.061334464480751194, 0.02510086491383845, 0.018378712047706358, 0.06833612686023116, 0.05346502366592176, 0.04024988200399093, 0.05624029603495728, 0.01560690736368997, 0.0917386554647237, 0.046931122124078684, 0.08625727889011614, 0.05080975286546163, 0.020919380403938703, 0.04251887236023322, 0.1161358029639814, 0.03078473462664988, 0.021852657082490623, 0.05833189454278909, 0.029633607919095084, 0.06317279767245054, 0.014655867380497511, 0.049109199389931746, 0.053038941841805354, 0.019075238051300403, 0.025754331509233452, 0.017443683900637552, 0.004896727014056523, 0.02091551010380499, 0.054607229758403264, 0.07153379629016854, 0.062332500965567306, 0.10259675094857812, 0.05715891900763381, 0.020140130909567233, 0.054558240590267815, 0.08779822979704477, 0.06152554153231904, 0.016724774723115843, 0.035810180197586305, 0.05766979120380711, 0.017679297234280966, 0.029254450237203855, 0.013916627995058661, 0.024969161531771533, 0.01385492676490685, 0.054817602649563923, 0.02382776994636515, 0.036561474844347686, 0.0651193768135272, 0.031581400471623056, 0.063360375497723, 0.06562080889125355, 0.02683245314983651, 0.024169215394067578, 0.03477869511698373, 0.0653537099424284, 0.06577029969776049, 0.014336598233057884, 0.015071546149556525, 0.024313038047694135, 0.07303167294594459, 0.06731614135787822, 0.008163451893778984, 0.024788006994640455, 0.05894012538192328, 0.05770348470832687, 0.010971927022183081, 0.04596149505232461, 0.025246453878935426, 0.02745938425505301, 0.06748307263478637, 0.017702485638437793, 0.04556348125333898, 0.03186264475516509, 0.06254669962800108, 0.03216647259250749, 0.01223873878188897, 0.033812433684943244, 0.005170958929738845, 0.033009544931701384, 0.021281054941937327, 0.05150413591763936, 0.06130773232143838, 0.01090498251869576, 0.03302687779068947, 0.013707810830965172, 0.027708690213330556, 0.05149001284735277, 0.023109999965527095, 0.028923476493218914, 0.03653824191133026, 0.01555273522171774, 0.0425858029484516, 0.009469314536545426, 0.010908721087616868, 0.025037893683474977, 0.019847858311550226, 0.05621691467240453, 0.04944758904457558, 0.050046995747834444, 0.12933591613546014, 0.037772199721075594, 0.03633350192103535, 0.07819234524504282, 0.09303777012974024, 0.03058585018152371, 0.008615015358373057, 0.09130506310611963, 0.04548017888737377, 0.05221759587584529, 0.04201186304271687, 0.08658028382342309, 0.04792872816324234, 0.008316599632962607, 0.025958071455534082, 0.08644260800792836, 0.039325407196884044, 0.021847102107130922, 0.027026400457543787, 0.057765012461459264, 0.033077492262236774, 0.014554885201505385, 0.0484730266907718, 0.045950281200930476, 0.05518398611457087, 0.043568911132751964, 0.038493645188282244, 0.061163236168795265, 0.023758380993967876, 0.03277645490015857, 0.020059836097061634, 0.03277988733316306, 0.021809762802149635, 0.0919112419069279, 0.03600790318159852, 0.08489652143907733, 0.02973241003928706, 0.05272679823974613, 0.032799539403640665, 0.003578544024094299, 0.04560651468636934, 0.0009447683135022089, 0.02630354490975151, 0.025152761445497163, 0.00815235585832852, 0.04421620491484646, 0.0333988644706551, 0.013401702744886279, 0.056669561672606505, 0.03585138052585535, 0.06071152056392748, 0.022224187341635115, 0.027769652078859508, 0.028381651172821876, 0.08202252487535588, 0.03327048405481037, 0.0014707823515891505, 0.05069197031843942, 0.04809994534298312, 0.041259462595917284, 0.02625331635499606, 0.04233656749420334, 0.059678729303414, 0.018017037509707734, 0.037675701969419606, 0.024984954434330575, 0.04671710528782569, 0.026205607391602825, 0.04954768250172492, 0.08309856479172595, 0.05782872955023777, 0.024588148480688687, 0.06521270930534229, 0.056683595685171895, 0.012948282055731397, 0.016172089926840272, 0.032958351584966294, 0.019118989512207918, 0.07225276669487357, 0.012318425033299718, 0.023450693988706917, 0.03447320486884564, 0.008391858973482158, 0.07514519078540616, 0.0670416654611472, 0.024826129265420604, 0.0043106260909553384, 0.03113984115771018, 0.07497856378904544, 0.15466492652194574, 0.14740768703632057, 0.126517491589766, 0.14489943569060415, 0.12250150786712766, 0.10917759704170749, 0.09191165750962682, 0.2094062141259201, 0.16766196582466364, 0.16313007072312757, 0.18811082089086995, 0.13931008405052125, 0.07906755257863551, 0.10461834637681022, 0.16076373285613954, 0.13080568023724481, 0.12429930124199018, 0.2546369534684345, 0.2096342167351395, 0.23275741579709575, 0.09285373977036215, 0.0999780383426696, 0.14939434215193614, 0.2531464537605643, 0.15659612836316228, 0.09103400851017796, 0.11135543682030402, 0.11281855127890594, 0.18950516794575378, 0.10515933492570184, 0.0809200199728366, 0.09402673385920934, 0.17642720486037433, 0.1527928441646509, 0.0770489702699706, 0.1277212254353799, 0.14754491014173254, 0.14014258078532293, 0.18598204449517652, 0.12957591185113415, 0.0819425584631972, 0.10683840693673119, 0.1461230294080451, 0.12144010310294107, 0.049117036469397135, 0.1723281154409051, 0.13042467646300793, 0.16097009443910792, 0.08387206820771098, 0.0789913340122439, 0.17321743100183085, 0.24591107794549316, 0.082610498793656, 0.07765229180222377, 0.17923945473739877, 0.1420316137955524, 0.23054097691783682, 0.2909672789974138, 0.16660857625538483, 0.13713792170165107, 0.10326730363885872, 0.22359435592079535, 0.10243047276162542, 0.15348471875768155, 0.12497459625592455, 0.07026815248536877, 0.13823153567500412, 0.08402170002227649, 0.1338397283689119, 0.19505249918438494, 0.1473110297229141, 0.09692741805338301, 0.15113512374227867, 0.18773400282952935, 0.1545892423018813, 0.08545126198441721, 0.11401721625588834, 0.10221767675830051, 0.0952036316448357, 0.1312656930531375, 0.1777735646464862, 0.11777025705669075, 0.059102362574776635, 0.15846070018596947, 0.11604257437284105, 0.06714567003655247, 0.14205307670636103, 0.19612963747931644, 0.12505164602771401, 0.1403472651145421, 0.17107802705140784, 0.12492626759922132, 0.18863252102164552, 0.20040768838953227, 0.19321623287396505, 0.0924825100810267, 0.11367874496500008, 0.10901724119321443, 0.16319928341545165, 0.1821827975800261, 0.1591659482801333, 0.1282689452636987, 0.26204091554973274, 0.09723517927341163, 0.11070345266489312, 0.12807748600607738, 0.14868977683363482, 0.09490429380093701, 0.10201403143582866, 0.27893552149180323, 0.11993135398370214, 0.11384744997485541, 0.22537163633387536, 0.15138222923269495, 0.15604861633619294, 0.14271091640694067, 0.098530390241649, 0.0720052381802816, 0.14630639925599098, 0.0736339257855434, 0.19832381192827597, 0.17754576983861625, 0.14960192085709423, 0.17939025914529338, 0.13640451652463526, 0.16350432095350698, 0.1103734492789954, 0.1728891345555894, 0.12360902226646431, 0.09159766967059113, 0.17945163475815207, 0.11573439012863673, 0.1639457355486229, 0.12044486080412753, 0.2392048534238711, 0.14176402502926067, 0.1496335511910729, 0.1472834069863893, 0.10122060135472566, 0.12001791808870621, 0.11244608962442726, 0.17464518954511732, 0.12386406873702072, 0.07609245323692448, 0.10239118346362375, 0.0739972219162155, 0.11285703163594007, 0.17039618629496545, 0.11877889512106776, 0.2200413090758957, 0.09083324272069149, 0.15682291385019198, 0.24624652869533747, 0.12006482182187028, 0.12519875454017892, 0.1988705521216616, 0.19663260580273345, 0.1281917915912345, 0.10195486742304638, 0.1535804706509225, 0.1803600532002747, 0.09476845851168036, 0.1728803475270979, 0.16648643359076232, 0.11463593735243194, 0.12136313496739604, 0.17176004592329264, 0.10200245393207297, 0.08394029384362511, 0.12429030641214922, 0.16021380142774433, 0.1777795611997135, 0.12197611184092239, 0.1291677009430714, 0.2048042305978015], [0.08728181375772692, 0.039751355434418656, 0.04069412789249327, 0.04187818369246088, 0.04493400272622239, 0.06069960167224053, 0.02638830745127052, 0.01681157260463806, 0.05812587063701358, 0.040352777068619616, 0.12051106779836118, 0.05302796547766775, 0.025292402096965816, 0.04154852169449441, 0.05742241854022723, 0.062382202595472336, 0.05116898573760409, 0.04594340891344473, 0.020565630147757474, 0.03947236356907524, 0.015867781548877247, 0.007881907040427905, 0.00831397614092566, 0.030483272385026794, 0.02070552498480538, 0.0810773552802857, 0.017320390907116234, 0.03689287717861589, 0.018902080155385192, 0.055927217326825485, 0.085776337509742, 0.01996856306504924, 0.03404284085263498, 0.042569464567350224, 0.007602282958032447, 0.08348385817953385, 0.019229061144869775, 0.030800601743976586, 0.06650137453107163, 0.039356106135528535, 0.014208886677806731, 0.034137071343138814, 0.06310881712124683, 0.02303466641023988, 0.02648088109708624, 0.021286812152538914, 0.07018494288786314, 0.032396638562204316, 0.019850025382766034, 0.05424100956588518, 0.01938052235345822, 0.03040042458451353, 0.033601715695112944, 0.042934497323585674, 0.03823689177806955, 0.04132739137276076, 0.03567332445527427, 0.02811675083648879, 0.02615964061988052, 0.07257583842147142, 0.07304248603759333, 0.04919667262583971, 0.04516837296250742, 0.04562096801237203, 0.07357031630817801, 0.019940847560064867, 0.07532216332037933, 0.022741686916560866, 0.04861916670051869, 0.05067105659691151, 0.06870836587040685, 0.0008226784109410801, 0.03187399961461779, 0.034456306166248396, 0.03256296127801761, 0.02120044100593077, 0.09073963563423604, 0.04004982496553566, 0.054852216417202726, 0.016602357463852968, 0.035995052894577384, 0.04701518890215084, 0.027952355849265587, 0.025604942748032045, 0.025439707278565038, 0.09902702804538421, 0.06349173563648947, 0.05511956769623794, 0.041900106734829023, 0.0371986271784408, 0.02041609666775912, 0.08563651688746177, 0.05096950015285984, 0.010501341384951957, 0.04407922300742939, 0.025996002623287495, 0.02738119899731828, 0.09723141658469103, 0.03411052472074516, 0.013834990822942927, 0.05050705309258774, 0.03998880558356177, 0.07480286032659933, 0.03609964005590882, 0.018202923238277435, 0.08443756247288547, 0.013669840700458735, 0.018175506447732914, 0.03106888627371518, 0.024038471237872727, 0.04771163141413126, 0.05015213580918498, 0.05521198363567237, 0.040304923386429437, 0.032707182836020365, 0.06714095739880577, 0.025859599591058213, 0.04727107771032024, 0.06783149612601846, 0.03393260594748426, 0.02913897391408682, 0.019810068151855376, 0.01580169515364105, 0.025131370894087013, 0.009933755191013915, 0.013973431050544605, 0.025013564227265306, 0.05176325677894056, 0.0340099043387454, 0.02743137189099798, 0.06734940441674553, 0.004931273988404428, 0.02299988380400464, 0.008902060453692684, 0.04307612507545855, 0.007916224876680644, 0.04581188921292778, 0.0020683277716671, 0.011904985694854986, 0.06398720084689558, 0.014734981250512647, 0.07731677425908856, 0.02333334745344473, 0.08669732793350704, 0.051768485209322535, 0.029127904781489633, 0.039391462050843984, 0.021790197934024036, 0.04457118899154011, 0.013127121092111338, 0.0184053718476207, 0.010149799018108752, 0.014843283788650297, 0.08133735929732211, 0.028845638189523015, 0.032067225183709525, 0.06481855467427522, 0.01649842524784617, 0.06081699830247089, 0.02894549230404664, 0.03518787823850289, 0.022407223223126493, 0.028214276462676935, 0.07604855520185083, 0.036427298255148344, 0.02666662767296657, 0.016208354973059613, 0.04995975257770624, 0.06645528716035187, 0.0576417083357228, 0.024014407099457458, 0.014745960397704039, 0.07330533990170807, 0.11059034935897216, 0.004951720620738342, 0.01787659162800992, 0.04071178729645908, 0.014376174185599666, 0.028783772759197745, 0.028688213824352715, 0.040233840481960215, 0.006968139105083537, 0.009249403192370664, 0.051806631599902175, 0.026064844241773244, 0.03564765356713906, 0.06457392795709893, 0.025570690777385607, 0.047946016493369825, 0.05265999381663278, 0.016485441374243237, 0.03143118978186976, 0.02584956760983914, 0.03382356961083133, 0.03818923476501368, 0.037768173569929786, 0.014491495585389202, 0.022903783101355657, 0.03988727607065812, 0.04679481928178575, 0.015048582245071884, 0.018875355417549144, 0.07032818481093273, 0.02263884565763874, 0.048890469915932044, 0.0442376195860561, 0.024162842200894374, 0.037292386405169964, 0.06624806468607858, 0.03483870517811738, 0.043003042083000764, 0.057418503711232916, 0.060947916863369755, 0.050708839335129596, 0.003708308777277125, 0.03840872865112033, 0.026413900413899682, 0.06553447485202923, 0.030384097335627303, 0.029098508312017657, 0.11234322053496726, 0.006943106000107946, 0.06120404686953407, 0.036734150344273075, 0.028122068324591964, 0.04005716851679608, 0.01842995177867124, 0.03695968902320601, 0.08976716984761879, 0.026440319015819114, 0.043229378570686094, 0.019344745269336272, 0.03198479855200276, 0.021128608532308135, 0.008034473121369956, 0.04133120601181872, 0.10718389152316377, 0.08706879511009902, 0.04007713228929788, 0.024810427275951952, 0.08955391371273436, 0.018457923324604053, 0.019275925915280823, 0.026406842589494772, 0.05419089604401961, 0.02039784911175957, 0.03793156851315871, 0.031039170680742245, 0.026595988201734144, 0.06635553509113379, 0.049465062911622226, 0.004676625494539621, 0.019129808169964235, 0.03725004688021727, 0.06015710656356532, 0.03671856895380188, 0.01806309704988962, 0.12785285274730995, 0.0542705507541541, 0.025815501176111866, 0.032548185117775574, 0.06243686919333413, 0.07658565489691682, 0.04705804793047719, 0.049624713719822466, 0.037733515273430385, 0.019078364348388277, 0.10441070087836124, 0.037045807839604095, 0.03314917630632408, 0.03367250916198827, 0.011854954736918444, 0.05739465850638226, 0.10464063307153992, 0.07167973963078111, 0.012190958386781858, 0.021295343140081968, 0.056379315137746744, 0.0462778503424488, 0.04822045528271701, 0.035928482247982174, 0.04331380157964304, 0.02063532894680975, 0.043955829823971726, 0.032173237268580124, 0.042128498971578665, 0.014917419703124324, 0.06672236384474672, 0.05107066601340193, 0.026307331718271598, 0.039700425550108775, 0.084860653441865, 0.031944537040544674, 0.09592581554898061, 0.01726060720102396, 0.07778188562951982, 0.028520004198071547, 0.048307802353519946, 0.013646652296301909, 0.05344675941159949, 0.042376628625788726, 0.03247271612053737, 0.020095375693927053, 0.0323607000609627, 0.06389535265043378, 0.07213835720904171, 0.03413332720811013, 0.04973509334377013, 0.009389687656948809, 0.022716713647241704, 0.06602901237783954, 0.03176645499479491, 0.046071785618551075, 0.02330014933249913, 0.036603131593437865, 0.03429692253121175, 0.04804815456736833, 0.024496858750353567, 0.04414207178342622, 0.06191738066263497, 0.05362334231904242, 0.06591696292161942, 0.020009093605040107, 0.02034821798588382, 0.04082221887074411, 0.02584379370091483, 0.005193488677832647, 0.0040740340500633465, 0.0405850544484565, 0.04876054583291989, 0.030499647873512004, 0.008571185971959494, 0.00988905656413408, 0.03253593597037252, 0.024202754902944434, 0.038260929941316135, 0.026679945513023995, 0.045917481984361075, 0.08690357077284716, 0.04879202402662486, 0.032855530735105276, 0.03031100692169275, 0.03992662102973554, 0.041804503271123394, 0.03265021186962258, 0.034452094478183426, 0.0145090687146876, 0.023046702190185897, 0.01929413636389654, 0.04344183689681813, 0.031856644491199404, 0.040574579034000635, 0.12884955707704648, 0.16438327613286674, 0.12117305610445328, 0.09238200102117844, 0.15888434776570648, 0.16874585766345263, 0.11173710110597312, 0.10883766371989623, 0.197821763867978, 0.10961694104480557, 0.2530826290603727, 0.15785322262672707, 0.11826691712485626, 0.1704638107912615, 0.17215710977325216, 0.1995322064612992, 0.09395824847160839, 0.15909556299448013, 0.15551392862107605, 0.08944374931161292, 0.13429990445729345, 0.09062518161954358, 0.08883440154022537, 0.1534463942516595, 0.10219023213721812, 0.17068033979739994, 0.15584537177346647, 0.14457697252510116, 0.06252191189560108, 0.16296480927849188, 0.14955146965803578, 0.1212577722617425, 0.13982112694066018, 0.112642810709076, 0.20379562221933156, 0.2123966091312468, 0.14892906008753926, 0.10034557955805212, 0.2015343279344961, 0.1421523463795893, 0.10932000775937922, 0.19100340083241463, 0.1653675569104962, 0.13147542398655787, 0.22914789151400328, 0.10927233219263144, 0.2901478885905817, 0.1096829996095039, 0.08808791229967028, 0.24122422240907326, 0.10171054498641752, 0.09558980076690204, 0.17927694803802297, 0.12798022013157606, 0.15761529008159414, 0.15707677288446575, 0.09628895582864061, 0.1077403019007761, 0.16981431283056736, 0.13332205067854375, 0.22280371631495655, 0.16394720500102267, 0.11999777620076202, 0.14825024729361758, 0.2277526241960004, 0.07244314983836375, 0.1635627873474732, 0.09915331189404242, 0.11994498723652214, 0.0900665893277619, 0.16814464383060113, 0.09672252592281438, 0.08162320489645936, 0.13972979824757203, 0.14166861452395096, 0.1728757016826421, 0.17669154301984236, 0.08535946573829278, 0.1853483691229485, 0.0958505024027545, 0.08255406588432379, 0.14455032942350954, 0.11201220040675253, 0.13968130631837994, 0.1662173605291173, 0.22041861695470288, 0.17883872467791662, 0.08180194374290295, 0.12533921340946108, 0.18200212914962322, 0.17844989866716787, 0.27865371317602694, 0.15216408181004226, 0.17759160487912595, 0.12419027232681401, 0.08762182871578261, 0.09790381722268648, 0.17286151181906462, 0.1165311672957614, 0.09696244000224397, 0.13232708297437057, 0.15027132321847603, 0.17397299670847133, 0.11430352940806188, 0.20448623516131192, 0.1316369153209962, 0.10459769240696914, 0.13278056489070877, 0.13527996983611956, 0.12629419419681653, 0.12686169968219474, 0.1526039230520837, 0.11475946783320978, 0.20508154149865732, 0.2226474942290224, 0.31840536918025464, 0.1368873578030616, 0.160258048272226, 0.23085855675162748, 0.17635631491430104, 0.13381780532654375, 0.15440857387147844, 0.09568136694724672, 0.0772832143411506, 0.09876889424049295, 0.12338618500507437, 0.09376369445817545, 0.11561004328541458, 0.16255964117590338, 0.26292570400983095, 0.10382977736298926, 0.10500722433789633, 0.0620475088362582, 0.12455045885872096, 0.1657094940310344, 0.10093457764014602, 0.15527232986642048, 0.1305079009034671, 0.09525080997264013, 0.11495817045215517, 0.12950347823789343, 0.25373126612976193, 0.1311112372786738, 0.17919559380970895, 0.1614299588254653, 0.15350800735177472, 0.154266630706843, 0.11136362270917743, 0.15484417002880946, 0.09200861168210395, 0.0803955145238433, 0.05737541832786519, 0.09997419401770458, 0.10549290804192424, 0.13532693294109777, 0.12035185485729016, 0.1613058865768835, 0.09171840967610478, 0.09066176950000226, 0.15401674958411604, 0.13786307419650257, 0.12059169472195208, 0.16618270223261788, 0.09585390886059031, 0.07818860482075252, 0.1891126311966218, 0.10784826954477467, 0.14458660560194403, 0.17911366070620716, 0.12613956030691043, 0.12009254103759304, 0.12923894712002948, 0.16338216344593093, 0.16181112587219104, 0.1464341377140954, 0.10644955124007538], [0.023794803746568505, 0.039232661001733504, 0.026110816579603124, 0.0561920230393298, 0.03857627591060009, 0.024200554435083177, 0.05230933275015559, 0.08000179033842869, 0.03136664890917018, 0.03719203690707218, 0.07672668521991, 0.050443566069588996, 0.007570734724140493, 0.07028805688605644, 0.041356227520736866, 0.03846930274448823, 0.0643199501791969, 0.053477350738830864, 0.020091535079700407, 0.022126758194644935, 0.04587525378155988, 0.014264490237110294, 0.09606191801140085, 0.05744527297792956, 0.025473122477706056, 0.03075395961786853, 0.016012479936762247, 0.018464958884578664, 0.0434623164619552, 0.05013723348383792, 0.04799166970769875, 0.03988995522377081, 0.014962816876504803, 0.01035147208312992, 0.07819256788934581, 0.03827171334705781, 0.09966076278942637, 0.026908901782007888, 0.03778075297304895, 0.09029673674376681, 0.04460739466594532, 0.06151465051516425, 0.05484970424731728, 0.012538728788058506, 0.04059810882608872, 0.02529833000153303, 0.038360069738700986, 0.013611146096081939, 0.02248394459456904, 0.09780963126104325, 0.024800974169920664, 0.03648736026661936, 0.06927958951564506, 0.013713629268750083, 0.06856975494883955, 0.03817210228589829, 0.10381678235717118, 0.020324111173977144, 0.04254283630871214, 0.0761835221783258, 0.05306369246682152, 0.01380199586492381, 0.08396094781346619, 0.024139692759490572, 0.054555695023736916, 0.023077673868101556, 0.0158989981355262, 0.07435819512465969, 0.11182476358953863, 0.012601641574292444, 0.02289832274982473, 0.0480144981702324, 0.00961700192419812, 0.08072744007222354, 0.01825419265514938, 0.04555473875370808, 0.036601376414182596, 0.029392916439974215, 0.03728073468664661, 0.06070253686630167, 0.04401093057822436, 0.05024740159569774, 0.10966287998599, 0.027739626639231574, 0.03794986616412643, 0.038860744825797155, 0.07332508845138364, 0.038649533307761885, 0.04128806496737525, 0.02195235534600215, 0.034870591553044505, 0.04822879702260252, 0.045304241648409516, 0.04668777561164461, 0.007854650739318458, 0.01335417653535842, 0.031853315958869644, 0.027063927154813427, 0.014186016469466267, 0.032198232802329585, 0.02882169279473601, 0.03612048698414583, 0.011210081283934414, 0.028262863015697803, 0.018870327367039863, 0.04899749874311965, 0.009474809212406399, 0.07052800807286985, 0.03128191419818904, 0.026564305917418096, 0.010182836649619276, 0.10694062293623574, 0.02132796980731655, 0.04625598667189479, 0.0776266134926118, 0.026839611164177768, 0.029490928172890563, 0.013755786039837403, 0.050045322204823606, 0.03331979976792354, 0.036007116505061276, 0.027352873075869866, 0.057338644910487346, 0.03057402962440392, 0.027019021654268727, 0.0240602328631212, 0.021432603352877777, 0.02094005663821008, 0.049584730513743125, 0.023283241353055928, 0.020783726940862834, 0.03628056452726014, 0.01563140936923446, 0.03827577660558745, 0.03515116419293918, 0.051458122761687264, 0.113548008230282, 0.06608700379729271, 0.09274505966459401, 0.06359542850987054, 0.02865112870495068, 0.031432685209438205, 0.03820533194812015, 0.0664939456328284, 0.05702671653125435, 0.029042806418146938, 0.03989660115621518, 0.04361428975244053, 0.024162992485798895, 0.0019885921210516244, 0.017352537033730187, 0.0515696378715802, 0.03292930021416396, 0.028225419810041785, 0.025816662637225818, 0.035967419025837444, 0.03679066488984972, 0.028312527538219, 0.07809135378920473, 0.047787018775125034, 0.09141669695964083, 0.030247206341300625, 0.018081131238432135, 0.03283668389485683, 0.06254307794733904, 0.013223493606346892, 0.04031580698210746, 0.02737384431384271, 0.011160590238432633, 0.05710647514206357, 0.025764938654901925, 0.04083524356246926, 0.08252665837062523, 0.09385474855662324, 0.01842020923504606, 0.049881070081028156, 0.02812185495713493, 0.08858992325258441, 0.05833763876580633, 0.05083482632471714, 0.018410481534374412, 0.010382092168583767, 0.06264749070396647, 0.053807955264346674, 0.04840717221668456, 0.02053354895906523, 0.04825277210329659, 0.027725811560230795, 0.0033454697631896124, 0.06486635640612803, 0.04672887203923892, 0.026424429634062108, 0.039418042069883086, 0.027943782188231125, 0.08868928940501064, 0.061411822243826464, 0.03870901644404512, 0.043470083037391305, 0.05711266094294842, 0.10495070237084292, 0.05566702035139315, 0.05049504885391798, 0.0694587588077411, 0.03960628040658776, 0.027690331335179508, 0.013573173182521714, 0.04751943371957168, 0.056610783576616086, 0.009479967138759093, 0.043233831456745975, 0.03221278631826863, 0.02156456834200071, 0.0209383701076149, 0.02290047126734862, 0.01452634962333832, 0.06411560723790899, 0.08670324285048991, 0.05149754564627074, 0.065333701641066, 0.003981745203418541, 0.0313416793505894, 0.07864754894399084, 0.04454405607248191, 0.045046712693874724, 0.027215796544624027, 0.04272419864719268, 0.01775411314156372, 0.009565949585521594, 0.03592753600969445, 0.028165367075416725, 0.07780913729220629, 0.05080810529761948, 0.03577256444259547, 0.06919989027664997, 0.0224172255184385, 0.06474475550930947, 0.034472240076866, 0.04631113195500802, 0.0778457622800488, 0.036869907708023675, 0.05070203013019636, 0.025309892662335187, 0.00864413816088927, 0.08051430268096738, 0.07879949625930749, 0.0412626686738804, 0.030881410493748263, 0.0199244627947337, 0.023595438760821708, 0.047197337917168625, 0.010468646069057286, 0.03430822915106546, 0.022123036324046552, 0.05959157148026861, 0.019083730076090433, 0.07060870178975165, 0.04633788266801275, 0.05074773158412427, 0.047314252151409164, 0.0022277967536865617, 0.01789298195944866, 0.0152416575292591, 0.015013000902399654, 0.028381630763760768, 0.04329077644797508, 0.057426478088018484, 0.04154513379035052, 0.03758520819246769, 0.06906501977937296, 0.06459342417656444, 0.010603608407109277, 0.033801865502027795, 0.03481078558252193, 0.017479572306910995, 0.010495111055206507, 0.0647882379416842, 0.04409879715240095, 0.01876356571301585, 0.016029096623242367, 0.025397898389201146, 0.03276694427768234, 0.061354847566690296, 0.006380584500220721, 0.07234607692225836, 0.015766675060149282, 0.03033251250599278, 0.02319750659808051, 0.023728062406007666, 0.09078285089344718, 0.02032077707553981, 0.029765489416604396, 0.04011899683973752, 0.021298211540852208, 0.047688454142189585, 0.019276571583759505, 0.013486471780197462, 0.06028067786246538, 0.03171277174260467, 0.013840123701811535, 0.022308293082460295, 0.014428686699829996, 0.07814158234396018, 0.019082999060628936, 0.033549720828887075, 0.03828020351647865, 0.08449919041595422, 0.047904793900670484, 0.03915080953447614, 0.02057225752650993, 0.030003941465110984, 0.031528967738267966, 0.059864262511837296, 0.074805413314607, 0.012723993895633612, 0.06573929276783019, 0.07186423754319549, 0.010400927876617061, 0.06408117158571258, 0.022050649095035624, 0.004653444975701859, 0.07219400344183668, 0.01719848016364267, 0.04559617656923365, 0.03976164531195536, 0.01073423938578344, 0.09071872191270813, 0.034990949352504686, 0.043203421955695376, 0.05496618803590536, 0.020859194082731847, 0.022701212037645746, 0.012230331176397158, 0.020945298056176398, 0.0223704164091032, 0.024294105860462878, 0.02975857445562724, 0.04821517490199767, 0.03584454163501505, 0.017457170579291414, 0.019678657918120734, 0.038410917986766435, 0.04131209941988345, 0.06422725593438372, 0.022852619440527633, 0.03465552828856744, 0.07168572876253165, 0.02196665282099275, 0.03501168124785181, 0.12500401498982683, 0.037585341779049486, 0.011343611276970478, 0.03142255860439036, 0.11526317830430344, 0.11877436059876345, 0.18975590995978564, 0.26691724138800055, 0.16470370581373572, 0.11154304433148354, 0.1894454102148302, 0.1557717952528037, 0.0958925524901133, 0.19025945715839043, 0.1772016062750481, 0.1468351497896947, 0.07546769847976975, 0.13023602252360433, 0.0925221481884364, 0.17658384254900739, 0.16115398379042745, 0.14608644152758643, 0.21694800787372515, 0.11062529709306546, 0.14205782645149156, 0.07774458528729156, 0.15568125323625281, 0.29960507643409073, 0.11413046799134463, 0.14242694101994857, 0.18333450687350705, 0.08205081554478966, 0.10382374370237812, 0.15144305565627292, 0.15996705216821283, 0.2805474662454799, 0.06479861316620372, 0.19070177717367187, 0.1757659958093427, 0.14145634544547647, 0.17817104409914464, 0.12751349830068648, 0.1446005134494044, 0.1669331025914289, 0.2378288225736469, 0.15047118358779699, 0.10278216912411153, 0.062444171926472336, 0.12303798415814526, 0.12150628783274442, 0.10617658932460472, 0.13300865655764937, 0.10831092440639623, 0.1730148692149669, 0.0947624100081157, 0.1722707028966397, 0.1421485614264384, 0.18532233458245173, 0.11358280011336319, 0.13275733566842973, 0.14458078716415912, 0.1664199965307489, 0.1341121707810089, 0.22478314291220158, 0.11558836515177973, 0.10066331524285488, 0.20173693425022066, 0.12910129356896505, 0.14444838801864535, 0.13778442138573155, 0.12593177380040288, 0.1409089521621354, 0.21646023873472586, 0.20352586638182402, 0.10829830047441646, 0.14495951996650547, 0.0890503145637922, 0.13146341603714973, 0.08277231667307205, 0.13228196039563045, 0.10045249335234985, 0.18293664150405675, 0.12576774432091042, 0.1506666949717328, 0.14498700911644846, 0.27178590826224536, 0.20694577193353325, 0.09650533640524372, 0.12878298643045127, 0.11268059344729409, 0.27236427878960967, 0.09832278927206062, 0.08274294988950714, 0.14176515309372917, 0.13203106995206326, 0.09747844786033966, 0.205190013803076, 0.2811914129415527, 0.09165019146166742, 0.07532631934736855, 0.133836166060064, 0.13594183197710663, 0.10346550159738399, 0.12240686919540167, 0.1316010844311677, 0.10172446767683141, 0.09129057638347149, 0.15667289611883461, 0.09714886749861762, 0.1158274406043347, 0.06602389898034744, 0.2093909852555953, 0.23494779044995084, 0.15371966786915436, 0.09292523085605353, 0.20803931169211864, 0.17083498853025958, 0.08966580731794238, 0.15398436225950718, 0.10473671893123537, 0.12515884183812886, 0.20025033823912963, 0.11531420837854967, 0.11700890259817243, 0.09810453106183559, 0.11350630695233122, 0.22500192804727703, 0.09896972682327032, 0.09179322558338754, 0.22334224835503846, 0.11690454179188237, 0.14825407677562907, 0.30427134479396045, 0.1838116187718697, 0.12454570911359042, 0.11019509634934366, 0.09522467153146863, 0.08892616810044274, 0.1284526861854829, 0.12308911813306622, 0.15671720233513042, 0.13728111167438328, 0.1733938543475233, 0.2760577102890238, 0.11699526934535243, 0.12390134681481868, 0.06355875899316743, 0.09839462174568325, 0.15074098395416513, 0.1066188351251185, 0.08123237508698367, 0.1307006663409993, 0.04850650126172695, 0.14853312430204824, 0.17139989649876952, 0.16127716546179727, 0.13391198386671022, 0.11658361487207003, 0.08254216925706714, 0.15846218448132277, 0.11897032469278201, 0.050658150648814626, 0.09335116425063461, 0.12247502061654814, 0.16313392989104614, 0.11490199729450978, 0.13838847022270784, 0.1349971818854101, 0.18948026146972552, 0.18995857564732432, 0.11766030787839554, 0.1663189902319573, 0.08996440301416442, 0.18308431404875591, 0.14055905921850353, 0.12291026796447113, 0.2917057159356773, 0.12615112296771258, 0.13120627671014518, 0.14310882630525157], [0.05953203268290963, 0.04579647851642221, 0.03132777892460581, 0.020615081302821636, 0.06878638043417595, 0.09874161289189942, 0.03465417757979594, 0.04509282975050155, 0.026163937654928304, 0.021827203272550832, 0.00638571923445852, 0.08958277583587915, 0.023384652122331318, 0.03281471261288971, 0.1062044347054325, 0.01861155717051588, 0.027151827125635464, 0.061619972402695566, 0.04147425126575399, 0.02029677045356948, 0.05532876057259273, 0.057342522632097825, 0.06872160578495823, 0.02848113792424556, 0.0561162646044977, 0.014914227540430147, 0.061631791104446165, 0.01831527697504498, 0.04599501786287874, 0.039322987795458175, 0.010051328081317479, 0.023949476599227637, 0.011255429290031316, 0.03316439404443372, 0.004162391369391116, 0.0394180160947144, 0.01461726735215052, 0.0405499545740895, 0.01759113194566453, 0.07115785396308638, 0.04251748454407789, 0.009332045974588254, 0.012672053762798896, 0.061518342699855566, 0.002503937612345908, 0.03624633667641319, 0.041738485524547286, 0.010904879545705626, 0.03009036085131811, 0.056972131569636986, 0.04376641518319957, 0.06729596978402697, 0.03135547216515988, 0.057956048694904894, 0.05999972672725562, 0.06608473282540217, 0.0026729441196948756, 0.040644478212925605, 0.015667158622818533, 0.039187779620988294, 0.030548447793989908, 0.030086622282397002, 0.09563290470396169, 0.02436109210975701, 0.020025075755256694, 0.016737469159124885, 0.060924472418264486, 0.03130493190838024, 0.04720786899270024, 0.025070460978895426, 0.02586420832813019, 0.07833986936020665, 0.009197311846946832, 0.08424110856140032, 0.014534906586050056, 0.08131452341331169, 0.03541171368851792, 0.06412639806512743, 0.008308808937727008, 0.07444793562171981, 0.03434639409533702, 0.03376715525519103, 0.06508074802695774, 0.020372185645101126, 0.01415575725332019, 0.06282078218646348, 0.03247929154895246, 0.013252291719254572, 0.08885915216524154, 0.011735455045709386, 0.00461554395769781, 0.06493516091722995, 0.032090061067719944, 0.08221297481213696, 0.034473575942683965, 0.03538632481649984, 0.04700216049968731, 0.04708439046225976, 0.048690713447285816, 0.022387075769074727, 0.04282341637008358, 0.017583957233000547, 0.044869710472994484, 0.021834535691596102, 0.022758902887289878, 0.027030081510019954, 0.039966915937839076, 0.09195007107337005, 0.06799775204854086, 0.03523133840644732, 0.021397277123469394, 0.06330983524094336, 0.022220500723051373, 0.048296543973265216, 0.028781015680579003, 0.04192583328403998, 0.0268338057139772, 0.01703433008515276, 0.06237175315618515, 0.011727688470273279, 0.00941541142310598, 0.027151645299454685, 0.034084215585608035, 0.011884525611094432, 0.018395937295281328, 0.020849679749517236, 0.026680544797272887, 0.041467657283646986, 0.0596659161237767, 0.025846830940281507, 0.0542694672185462, 0.03734503436135128, 0.027307230993756093, 0.028587894012161996, 0.035693321624421515, 0.04423121856234502, 0.07674558772123419, 0.007375450159088359, 0.061556648652185686, 0.05522577645024285, 0.04463500255951658, 0.04518751666182652, 0.060211873351363465, 0.0471987813943997, 0.014282975280366372, 0.006716473117194255, 0.06721995159750804, 0.04830110447073821, 0.03130039738607593, 0.14421326079173014, 0.015539061150775524, 0.0742102405638434, 0.0410927836492192, 0.04574642065563239, 0.026668353166314773, 0.06013133177475538, 0.04330861396738328, 0.02372959123022156, 0.044761872704839334, 0.014859218626952497, 0.01601778629265027, 0.021048924136266578, 0.0373933889932232, 0.03981385540100746, 0.0717990769771859, 0.009294996107200859, 0.02368118650338147, 0.019261136767454445, 0.030051134635868948, 0.02019495706917951, 0.09872507784166373, 0.02924701762822224, 0.03632211737567559, 0.02943018524092622, 0.03623225442424882, 0.028430111560737714, 0.17473196145147085, 0.06394222669769078, 0.01049089658408775, 0.026869694120250642, 0.06300525783444755, 0.02357955865591066, 0.02487743022356881, 0.060494152930914424, 0.02974277042085305, 0.0372116852668114, 0.022716917737852782, 0.060243570478633046, 0.027869611949427053, 0.022450188007496763, 0.08243757096352056, 0.01978643445909256, 0.06102982399170287, 0.0789552136848215, 0.03983357055403758, 0.035543448611861095, 0.007781754675306729, 0.06724412334733643, 0.10694157288526185, 0.03934091066184919, 0.02677313514141133, 0.03032879434613278, 0.05837952186993789, 0.022854723429190926, 0.044828294921899214, 0.01834994269302115, 0.006981983869991382, 0.03394202751223929, 0.06333335390081629, 0.02461119402141776, 0.011314686071273172, 0.04598524006723892, 0.004832929216718185, 0.03848227177513763, 0.024726150841161143, 0.024080311668512877, 0.0643061610753648, 0.02419154847302707, 0.035517581054591574, 0.036049266782356426, 0.010378426886745729, 0.018074839681503363, 0.014645342798758065, 0.04627891532436479, 0.040054348355624825, 0.03864515463646967, 0.030822574881312903, 0.026493224868318066, 0.03840441306238063, 0.06277649823459797, 0.08479450581944548, 0.03160165739245713, 0.0309082706735353, 0.017818058440752793, 0.048542892473051324, 0.047815799262025394, 0.04941900151607115, 0.004599938447427121, 0.03153369150822982, 0.005166306127648568, 0.06875287988805212, 0.046828898703097366, 0.05230087226664182, 0.07434722618199885, 0.0537976802297635, 0.012244578556419583, 0.05474810051964596, 0.059042252323706634, 0.04455738504475448, 0.06683823536150157, 0.050270567735424265, 0.021914149583608378, 0.05658058558765333, 0.06493856737506576, 0.017665010891505517, 0.04996089919586666, 0.03194500459358096, 0.05478574224980548, 0.004991373107259278, 0.026789839030243456, 0.0171962166132289, 0.0426242016692413, 0.018230293644592166, 0.008575046995247249, 0.031901974871288985, 0.02926263983681565, 0.015508815849898383, 0.05001811878173612, 0.08776387578109279, 0.0792316636943724, 0.03966588599723764, 0.01604744807991665, 0.03585231563192792, 0.05334892950486392, 0.027799358394986484, 0.08912207282264717, 0.029296763786987867, 0.0270553015434416, 0.05506242232513614, 0.026362846219853964, 0.043240395752945915, 0.00642426870399504, 0.04519199923379347, 0.03856962255667895, 0.05297874624375254, 0.048789838401717134, 0.03989127624663524, 0.034695377908064984, 0.03798371180891991, 0.03760185085411649, 0.0248966203071177, 0.04696503827290144, 0.012928539999847999, 0.02024740093474975, 0.027714976204151753, 0.022344667595461942, 0.039265768209588714, 0.02695065129955765, 0.06728750187903643, 0.04818909212190192, 0.011274975604464998, 0.07621224329341203, 0.03310727093776222, 0.030664196856378112, 0.06523788295453414, 0.06352924378006719, 0.036800880552618764, 0.010796812639455311, 0.016917074462980963, 0.0948489444272127, 0.05285503022605553, 0.07215224279207177, 0.018701225308177527, 0.05849194239999633, 0.06584099668543786, 0.039492197465733625, 0.06990207330090925, 0.04395152165670879, 0.030521877051796764, 0.044395912264008075, 0.04512225590588059, 0.04971111826307606, 0.011665845304378308, 0.08730471643502824, 0.05597385759756435, 0.005145192490090267, 0.03803744701144751, 0.0048367503495683195, 0.08451117610093206, 0.010411462662887061, 0.050303756579523906, 0.03442119515966624, 0.017211222839250695, 0.03209913382306695, 0.0209870828257408, 0.022088441110099666, 0.017494120256742463, 0.05058860027929768, 0.01762958818289917, 0.015200968355202349, 0.029885413059673738, 0.03145945076539647, 0.08808423866867088, 0.03932171872293111, 0.05558566241234075, 0.020799414087377954, 0.0658729684073478, 0.08204900470445864, 0.06779363917303272, 0.06871278907055967, 0.08508006198098883, 0.06308005889877677, 0.22358442598488182, 0.17048551118932664, 0.1622774321003817, 0.09154600877081975, 0.1992781544686295, 0.16871090250788257, 0.0946379815286491, 0.1324630295857787, 0.08922383611206897, 0.14177086763083935, 0.11608731103478931, 0.14657032181276008, 0.12183504441054538, 0.12241988646565005, 0.2672069164691493, 0.1450126280542463, 0.16148158261785284, 0.2634311362635344, 0.15236184932291508, 0.08769722349825315, 0.07090556086041033, 0.17271760938456282, 0.1651833113282919, 0.11989060265477747, 0.13612399954581633, 0.10557494504610077, 0.17438800568925217, 0.06704114595777355, 0.13246733404230326, 0.1114827893616166, 0.059880122207687236, 0.10047961142845452, 0.13779200613498688, 0.2956921770237386, 0.12912513135233894, 0.15480265428777784, 0.1348919898737222, 0.14091762044699863, 0.09950161664164625, 0.19540592475095764, 0.1548511313740164, 0.05868770240340382, 0.07788667688146234, 0.130761819309555, 0.1297597715165466, 0.18250710127176717, 0.12302351227845065, 0.07817813311703503, 0.08643563924124464, 0.17081324360333383, 0.15478439745493233, 0.13361703953705728, 0.10667277441825718, 0.22098622634075582, 0.11507853196235374, 0.1301327600958757, 0.08214229266741313, 0.10861827002372593, 0.1543370753643103, 0.08269088080851361, 0.0982641002337914, 0.09047581697814167, 0.1580852031474933, 0.1421672190190293, 0.27569123776629567, 0.09851631912169978, 0.2203577756881714, 0.19705280981725082, 0.273625454865396, 0.058662335795816034, 0.19828832242637873, 0.16732292308006436, 0.12885832926258445, 0.14182688493747264, 0.141999879560899, 0.1401014212751761, 0.12794804060831666, 0.189194519771263, 0.06536607412272133, 0.10277576438966207, 0.11442865550634451, 0.12761998164933175, 0.11888074746821076, 0.10832594547537155, 0.13753831037320197, 0.13849821902113035, 0.06180263721034862, 0.17227772361366078, 0.21904887951677665, 0.09838998332270421, 0.12250287341885269, 0.17653713177423924, 0.1327317167306319, 0.24387542624026537, 0.10170685651246458, 0.11351412918884307, 0.11778774947742932, 0.18687134521314874, 0.12425857959897257, 0.1003144241985865, 0.11088824743637815, 0.07124188734451309, 0.21915322548011318, 0.1054287790611852, 0.13381879980443045, 0.08487724786391482, 0.17533204721985385, 0.16127655690070242, 0.19089970795903355, 0.1624336838722229, 0.16079614986665547, 0.1446773554198444, 0.19425473496085033, 0.22091287246439606, 0.15987900376785547, 0.1411582247237675, 0.1009163876005914, 0.08969407572294585, 0.1638175518019125, 0.11907449996215291, 0.11030931287677959, 0.13606872438685969, 0.12753846414852887, 0.16642924369079992, 0.10253745334921405, 0.15699786774348468, 0.14792885282076895, 0.09914679583744146, 0.1796930850832723, 0.14326528587844223, 0.13159079826436937, 0.15427513571921736, 0.11436182510806248, 0.13437867601169273, 0.20673728780820966, 0.19725765741895884, 0.07542020844994113, 0.12867853656644002, 0.10172498718020506, 0.14170100184855983, 0.12338206608546898, 0.1484541894751601, 0.09423028270248324, 0.15029608126496896, 0.185691567894537, 0.07784631146932952, 0.19056010118220001, 0.11410684543079697, 0.20598770381184295, 0.1352710640639998, 0.17937796917976812, 0.11180139335920103, 0.2377460731077008, 0.1698986059636809, 0.19231734360801056, 0.140735482564196, 0.21848205680726096, 0.09134671985520981, 0.11268261208897457, 0.16431471653049812, 0.10271696402924135, 0.17740467272233218, 0.11798576932051219, 0.1357214289600961, 0.2154481125762686, 0.0913557740568649, 0.1863621428492479, 0.07625406331499107, 0.0945103692356497, 0.11968757331487723, 0.1680885226232931, 0.1206354443274904, 0.16943304188316688, 0.21657254052115604, 0.2017019790946506, 0.15395549271488562], [0.028045063081663102, 0.0349452441878384, 0.02396827891061548, 0.058345227225800045, 0.04147711595578585, 0.06161091820104048, 0.024603741003375035, 0.025623852670833003, 0.05486662150360644, 0.05815425407490693, 0.08601377281593159, 0.04465737831196748, 0.019271463752374984, 0.04189763167232741, 0.0200227287132293, 0.11677695176331326, 0.04784955955983605, 0.07236485325847752, 0.04708401938842144, 0.02887906266550999, 0.06582640606211498, 0.040099816033034585, 0.02321833868336398, 0.04068210881086998, 0.02576097373093944, 0.02593151555629447, 0.03852401387121063, 0.06742419805959798, 0.02213368243246805, 0.005931871346547268, 0.026102174269908573, 0.0638188817538321, 0.02861405100702541, 0.01263621916223201, 0.050876727982540615, 0.03796873155806679, 0.01519215071311919, 0.015196669464785373, 0.03090278620220488, 0.08080782950855792, 0.03720267930475529, 0.04129522669245489, 0.036648814493673854, 0.03351730381837115, 0.07935434812679887, 0.049762007329263724, 0.028981453069718555, 0.005146698122189264, 0.023103088715288322, 0.010768085030576913, 0.015320767688535852, 0.050985575071536005, 0.05706906347768381, 0.033649651013547555, 0.0396709845517762, 0.047727977216709405, 0.006712053163937526, 0.07991903345100582, 0.060003589605912566, 0.033083310700021684, 0.055747187143424526, 0.06054651516024023, 0.03304966172436252, 0.024451173994748387, 0.06938708218513057, 0.03219612510292791, 0.030120286101009697, 0.0444252530724043, 0.052982549750595354, 0.07000225581577979, 0.033512101363157853, 0.006605060980291455, 0.04086308894329704, 0.024261924481834285, 0.033189690147992224, 0.037046486904728226, 0.03995109706011135, 0.05179189996852074, 0.014750088594155386, 0.029965728281240445, 0.060333778528729454, 0.016445367255073506, 0.023654432079638354, 0.11206207273062319, 0.02316715646884404, 0.021556356477958616, 0.02895794554206077, 0.01665631902142195, 0.025253053427150007, 0.040337559330509976, 0.008402480962104164, 0.04101791579159908, 0.02892879769206047, 0.04066788555064704, 0.07281314756255597, 0.06773972214432433, 0.00988913634500932, 0.03628606013080571, 0.10731741131166928, 0.029924062255304307, 0.0436518312926637, 0.013231307493697386, 0.02592835957329953, 0.018119485430361237, 0.022096528664405923, 0.030306594853755087, 0.04164909383689519, 0.04312479883083142, 0.013909538629377494, 0.018128246483684052, 0.048407020076410845, 0.05604579397186171, 0.05229320588114206, 0.006257596714931424, 0.05041204705776181, 0.02893414301070152, 0.01627384208404692, 0.03179104234732222, 0.04605874608387239, 0.03354989523359109, 0.09301913480157964, 0.004734753747470677, 0.035417008912190795, 0.06311941499006934, 0.012418754122336395, 0.02071562375931535, 0.021035966237832326, 0.005570812327277963, 0.04139411415962968, 0.022856237410451286, 0.018299350485904142, 0.026877718592004385, 0.06444691680371761, 0.056227583045256324, 0.08719953926629387, 0.043257724901195616, 0.017153005064756144, 0.11039258184609935, 0.010270590046275174, 0.05080220151285175, 0.08212437722249888, 0.04919375598547049, 0.0558298995019868, 0.010459339537192136, 0.022805962471466046, 0.03180557359883096, 0.022545058600371704, 0.05652456828102004, 0.04171583517745603, 0.04575028724502772, 0.040450859305565245, 0.013917660508013796, 0.03172058284690138, 0.02397578202362638, 0.05504131564521231, 0.04282177622371819, 0.03806092114245985, 0.03428227253607474, 0.005233997417235514, 0.015505985484196572, 0.02876646030927077, 0.06970554517465644, 0.02959613317216281, 0.021706426159653347, 0.026786809212353546, 0.03980961402703542, 0.027024140617868397, 0.05168292671442032, 0.014012423489475623, 0.08307940253871493, 0.05267587577691302, 0.04732981869892683, 0.05430898287158925, 0.0446558903058758, 0.0481198682973627, 0.0401797527592862, 0.0078008710079302546, 0.0456928153289482, 0.04113462593522854, 0.05083506381197367, 0.08830251914332621, 0.028617119787668344, 0.018259831122122705, 0.07997243839781731, 0.04044071785756387, 0.06254799096495844, 0.04000250934041105, 0.02301214037288446, 0.024162155714293476, 0.044285009425948374, 0.003607639923757233, 0.05391949263866991, 0.0678043780499138, 0.06044357185601257, 0.026401729192002676, 0.06475906411651522, 0.020446374437597115, 0.041290517765446566, 0.02871866599889472, 0.036363254621392116, 0.030938390736992005, 0.022698568136547692, 0.03591293054341804, 0.052273887777118944, 0.031373951642308384, 0.014445368324231822, 0.022912802050996106, 0.01352044266241137, 0.06297874831943773, 0.013475688374455785, 0.021652154755429365, 0.04955666991008911, 0.015530575619777665, 0.037128972908249125, 0.06663459746050648, 0.03820032987277955, 0.046071807882981375, 0.06648224196396768, 0.015085034683579579, 0.0779845290526282, 0.057359105921932496, 0.0189827274880372, 0.030796490245847963, 0.008820240527711576, 0.018910392209363636, 0.04949727212078869, 0.09371028951136395, 0.08107722911518067, 0.043226406269241124, 0.028467801530496217, 0.020581539938575588, 0.028060948752681725, 0.035879251881851815, 0.024509248905815184, 0.024980468151625246, 0.06383761356119066, 0.0415062081447104, 0.059282496658852324, 0.04837501866859384, 0.01962748312507756, 0.03675876738270745, 0.02014903111557942, 0.06510601815534756, 0.019482031457300764, 0.07778382263495587, 0.02481082618032815, 0.01831560908613028, 0.012632869293156546, 0.02531299483962357, 0.07696642860537395, 0.16734536562580615, 0.042063924702233635, 0.022738000297977123, 0.0149880480421416, 0.03131069097435102, 0.0017364649579576508, 0.12136123506934382, 0.0074073105588468025, 0.01324061309787794, 0.04540946705674287, 0.011217171577300178, 0.07087432386470027, 0.02427015861030668, 0.03984662864240818, 0.04458869625523221, 0.030738921850570478, 0.020683522161561996, 0.03990076089394279, 0.0707815405621659, 0.04330385309003759, 0.054212362665566616, 0.02579440377303399, 0.029909139520896133, 0.07585046856547706, 0.03268786102125887, 0.014533590201608604, 0.03665198717499152, 0.05988062315736897, 0.07812580428435467, 0.006555452118846006, 0.05542684280953836, 0.05945441887888592, 0.04471449399716221, 0.024295797957165632, 0.028912160596519243, 0.04790148392203264, 0.016867454469320364, 0.04553693834168371, 0.11638975847745314, 0.07476239843526855, 0.06341528700431809, 0.1046056482300628, 0.02174177465349203, 0.04153406836849172, 0.014899930065439548, 0.024936994996096473, 0.06491659980383702, 0.038988613159745, 0.035563876226660796, 0.0035741593228522106, 0.033014376313076355, 0.014247519175114576, 0.03204250424460042, 0.04311893215344753, 0.03271795510954689, 0.08560234098695219, 0.0650661277177278, 0.046647202398162335, 0.047540336308884434, 0.03928789163182955, 0.06906946524395607, 0.0792538835958112, 0.0525871742866002, 0.03114602695859503, 0.007406509039356024, 0.04443369871296454, 0.06761670374544337, 0.00956813242737553, 0.062471690762322396, 0.024361259092984255, 0.05168176154256798, 0.035068592842435464, 0.02968120556033682, 0.04217655303364154, 0.05911522399401292, 0.04163167192018591, 0.035622632058220915, 0.023171318061940838, 0.05209340488363523, 0.03330451152578462, 0.04177858747425489, 0.024381551265832968, 0.04785772689501755, 0.04153322232014034, 0.07239884362206794, 0.07684464217163622, 0.08432381349848583, 0.05960849615803454, 0.06241423368919641, 0.018754125594568904, 0.0498565383895766, 0.013963649544166401, 0.049185985699296, 0.04908372517093085, 0.03730465039552655, 0.01606376790732611, 0.014028186706127599, 0.027737563468690496, 0.018327424077142496, 0.02945716416434152, 0.024391232582274824, 0.056802966428222135, 0.1163715090660844, 0.10170221066800877, 0.11346939994837157, 0.13761883339611813, 0.22275017778156325, 0.13423103315290064, 0.08806707279291004, 0.11417273330152966, 0.21126198407728225, 0.19784583913860843, 0.1707742511644028, 0.14886740245856345, 0.09921899196342565, 0.19197649002308026, 0.16514158778591082, 0.2029994165059179, 0.15975383314071223, 0.12062826033798046, 0.09147079210379161, 0.1710681416443549, 0.1386325477506034, 0.13583564548753202, 0.08605182272731327, 0.11328624532325193, 0.1163717539748177, 0.07738852509646676, 0.11475917097413912, 0.2074836360407062, 0.10313326434697956, 0.1791525789303705, 0.057733304201974533, 0.10168687047553249, 0.09955270608770661, 0.14880201924825087, 0.15673275775043294, 0.1238385759643279, 0.12870670849224553, 0.08144005769281648, 0.12463154591387138, 0.20958823326509446, 0.15663163270801306, 0.14176592492731288, 0.11613854148890823, 0.2244719010195695, 0.19310927455080673, 0.09985896816942841, 0.06665186723694205, 0.09927610022714362, 0.08852119295625016, 0.08430774600128643, 0.0978968187700957, 0.12539955001557246, 0.18077172251651064, 0.08874347360688262, 0.12284922631806694, 0.1214699745469261, 0.0812719167151954, 0.111673387727933, 0.18633411935297772, 0.16735177778173238, 0.12843695265473798, 0.14858456997899339, 0.1967000076547265, 0.06514837994473055, 0.17301290994510055, 0.1345512253465131, 0.13878318888600916, 0.09671726409578696, 0.153026353509631, 0.11553380245459266, 0.11376382477465086, 0.10408838614239357, 0.14975664380472153, 0.17125704791396856, 0.2691963769029826, 0.09149997335043736, 0.16481137659866363, 0.13776058360235766, 0.13426474150037393, 0.21138311742106453, 0.1928900886559859, 0.09809398514335044, 0.1245685524190776, 0.2063909126445651, 0.14796849834965542, 0.17167582700494677, 0.17242894362425432, 0.0599304138449952, 0.11289903719443828, 0.14659990381915122, 0.13801053893985227, 0.09012279217131436, 0.15626746084308252, 0.12109123432310298, 0.15240315726259723, 0.1322963580605574, 0.06705416322802193, 0.15340657060733065, 0.17140881711384282, 0.13433015439659357, 0.11808289418695495, 0.10458175107487477, 0.14252726454287767, 0.10870597703615203, 0.1231716301117558, 0.21121629746630788, 0.10889782963204198, 0.09524234948912635, 0.08770118656684645, 0.14442769694142044, 0.08645037829410285, 0.14633893501013517, 0.16840537515236065, 0.06779894552892074, 0.12416213008691557, 0.1506554291700013, 0.1286833456833847, 0.0832950632320717, 0.11363767451257445, 0.13276221900014207, 0.11993540611001663, 0.14082663314184174, 0.15616364922607318, 0.15996795758837834, 0.1616431778529659, 0.1245304208714515, 0.1349526084959507, 0.10231935099000111, 0.17840067943325266, 0.21122570789884776, 0.19133756024530157, 0.1262875593965873, 0.15112967637833208, 0.13188550510676578, 0.08104737993562594, 0.19725810270756483, 0.09821236511925235, 0.1404801243916154, 0.09905103652272373, 0.16594229091424495, 0.17720098287099972, 0.20077940047485754, 0.10753453403594904, 0.13545238558435813, 0.2128929871832952, 0.0694613934319932, 0.10219101881375536, 0.10217252449365333, 0.10676485268049873, 0.16516373347258195, 0.11755436629755422, 0.07241191284265369, 0.17552007775520906, 0.08453152579022571, 0.10717375378590077, 0.1625996726215817, 0.13688223698409274, 0.12147134009865113, 0.13901369995437562, 0.13125907309586182, 0.20040403702296317, 0.14034818537766114, 0.17898354737553746, 0.1963477546814829, 0.12088371498975903, 0.08393814161536284, 0.11327316868118942, 0.11373735978850164, 0.20921426505083218, 0.15018075151601806, 0.2632269565947354, 0.12626440438907593, 0.10330403994885273, 0.06881313485791907, 0.11820716681540944, 0.15613610070431605], [0.05950338949332945, 0.015581932239001617, 0.03595475427573547, 0.01645284253754653, 0.04838996181206312, 0.046978875616332516, 0.035384855364100076, 0.06409025547327474, 0.054030091196182184, 0.03417093925236259, 0.06660103012109175, 0.03106054267846048, 0.06117395649198443, 0.05218891928961966, 0.020466597961785737, 0.0404607187374495, 0.014000412757013692, 0.009119079277297715, 0.023276142710528802, 0.03996581755927764, 0.00991749844615697, 0.039185601417557336, 0.036978105417802, 0.040683322222321294, 0.029590262784040533, 0.0030315445428641397, 0.023933060292620212, 0.026847563276533037, 0.0228678093480994, 0.05390540296502877, 0.019276111452199984, 0.025857614346023183, 0.032435148605145514, 0.06528254540171474, 0.03370797639945522, 0.03175114077748731, 0.015423571840074146, 0.024194524485210422, 0.049922084872378036, 0.049576960227568634, 0.04629401802958455, 0.032449839418404736, 0.02360106609557988, 0.04382827319204807, 0.03428341544349678, 0.030787781142862514, 0.07999226116226055, 0.02869707877835026, 0.025829947080637794, 0.024357973234145902, 0.02515134579880396, 0.04473827611946035, 0.04878096602624282, 0.020101858353882562, 0.030758223256270867, 0.03510427901346702, 0.029965795074531343, 0.04146770552324597, 0.030923657250241376, 0.01596386184246512, 0.05261378028080799, 0.0240048148407368, 0.03658389512565918, 0.017139314295491204, 0.04238192756019998, 0.06450328291975893, 0.016206865111598745, 0.01212807899719337, 0.03887966959155165, 0.021970252237224486, 0.029035321858827956, 0.02417815827357117, 0.03562220161256846, 0.03158468447509222, 0.06067619804525748, 0.014609128775191493, 0.03739250954822637, 0.038604904257226735, 0.029911152596469037, 0.033934617167687975, 0.042211433974443935, 0.041481082735117525, 0.031319225672632456, 0.020797807337658014, 0.06309423391940072, 0.11730775804608129, 0.02556601339165354, 0.018861724020098336, 0.0432613799785031, 0.07063119628583081, 0.008448512671748176, 0.009758321684785187, 0.0436808900849428, 0.048980911742546596, 0.021182989403314423, 0.044283632742008194, 0.03748778275621589, 0.04464131823624484, 0.020299579482525587, 0.01947944507264765, 0.05075620691059157, 0.016041429262259044, 0.08709595029358752, 0.04699858334788587, 0.04772830376168713, 0.03577276111172978, 0.04606857954058796, 0.021287673043843824, 0.06033216806827113, 0.05709195873350836, 0.02161309923394583, 0.112244744959753, 0.014699174480483634, 0.05845436746312771, 0.020058709887962323, 0.014838868937658845, 0.012209291289764224, 0.021834368708368856, 0.04396040516439825, 0.0482530800945824, 0.039051413696142845, 0.022166246017150115, 0.034958921969519, 0.012938633208250394, 0.0228776799121988, 0.045600922603625804, 0.04447906991117634, 0.09740050751133822, 0.09751142890308984, 0.052923014663974755, 0.006747647958036396, 0.04346459114458412, 0.034541523273219354, 0.043842837840202264, 0.03495560828014277, 0.05826671913382597, 0.016213345916185062, 0.06734771974151954, 0.04037801380036399, 0.025396510573045816, 0.009609745575289708, 0.028043701240676455, 0.047903625018079765, 0.03769862320041284, 0.05352107065846212, 0.0498367082036566, 0.035570429390645586, 0.05485217559908051, 0.01391500176396221, 0.08529949278454296, 0.025574976680218242, 0.0423645056434907, 0.055095867210184224, 0.026781391534314025, 0.021436998722492717, 0.07588389489683323, 0.058052112290170044, 0.056515899996156804, 0.11080049589509144, 0.030309843605209608, 0.01679627879639156, 0.02239702796941856, 0.03699427681567613, 0.009895432540361071, 0.024109110709105153, 0.020452558383112773, 0.014974873993196525, 0.007071713234836352, 0.009673886615928495, 0.04922674816043582, 0.04094836171134375, 0.03949433485104237, 0.11069448752095923, 0.048019162568380125, 0.02702407567994669, 0.05774553479568567, 0.02701887693547178, 0.018954203042085283, 0.01916195800731657, 0.07840225429390557, 0.07060710617224686, 0.07176607367000543, 0.040137353862519376, 0.03880785938235931, 0.04085115149791818, 0.051041737096966244, 0.08260850241640583, 0.018488037821953185, 0.08462298064841889, 0.07451817247783765, 0.050090077420463786, 0.02529011071601417, 0.010436683623993304, 0.04443945777893532, 0.009443175167689333, 0.0319875333661912, 0.018190527516708244, 0.04572976686176844, 0.019132446504954714, 0.059755678885267116, 0.060945504883420654, 0.01371590951748658, 0.011328591135679744, 0.040634184624650516, 0.08516359812347218, 0.07100387316313572, 0.03498258534818888, 0.017096800365834497, 0.03437323386606295, 0.06968409710680135, 0.01693460399110336, 0.06438951168092899, 0.015397363822557963, 0.03832280279311817, 0.026416527616675012, 0.046927177609177306, 0.04921676627418492, 0.00949075054450077, 0.021062737359898165, 0.041779511448112316, 0.0472377998084994, 0.024537689860153478, 0.04830626981856767, 0.035044461910729297, 0.04313604978960939, 0.022693866631016135, 0.025964273954741657, 0.04708990833023563, 0.006176870065246476, 0.03007434159371769, 0.04609319657902233, 0.03138289452181198, 0.013848754879290937, 0.008377168160222936, 0.05972611172182951, 0.09046120409038849, 0.03570294727978762, 0.039106106269173324, 0.022993477214185987, 0.011243549361097394, 0.027571086757234298, 0.0378723451285623, 0.00808622771728551, 0.0343185116071254, 0.003897580554621527, 0.022880175383761525, 0.03148508083540946, 0.0137016741973639, 0.033087741321651265, 0.015123082739592064, 0.09772841061931103, 0.035140651671099477, 0.04477739843423478, 0.0019548262571333908, 0.07493159326259047, 0.010022769311035518, 0.008387014604522847, 0.023248033867275808, 0.00974891496298369, 0.026739256099972408, 0.02890974861657014, 0.04283102709450759, 0.005293347430779249, 0.027890523815585766, 0.03556891169864684, 0.01777404351742007, 0.026715024978329893, 0.003595570283323468, 0.026747558877104893, 0.018682883128349204, 0.04278025677194819, 0.03403533031814732, 0.01767120967997471, 0.0832145476306323, 0.04392549082695041, 0.03494210490316618, 0.009537654277664842, 0.049381782810087316, 0.06921030260855332, 0.040863779140636325, 0.04466364574909676, 0.047236549289664254, 0.08815628636511974, 0.022261233498284128, 0.06986930005950853, 0.06117359655036125, 0.016969013668131083, 0.025199915653502103, 0.029190423301770352, 0.09502508575678803, 0.048634228587616235, 0.023374082084046677, 0.004389912974147592, 0.0731355365132913, 0.02682983522390714, 0.040722789635765366, 0.03467221176833846, 0.016843230769154616, 0.005131409416208044, 0.04409689725434873, 0.03159388339554425, 0.028044467508152593, 0.023867137169872876, 0.048519470292376354, 0.049256237398367375, 0.03573871137632523, 0.03243330436816905, 0.05225557899393607, 0.066885858977912, 0.008157581505656708, 0.025984226595028304, 0.0546629947348265, 0.020026214951940347, 0.029319839013624005, 0.048944049267447554, 0.0026001343303505564, 0.020710963071906008, 0.028304499355726875, 0.0515311946219299, 0.03715331535204314, 0.030760091613046825, 0.02964604445878649, 0.009743077043822268, 0.03033423057786422, 0.04441216529812664, 0.027974401346000377, 0.05377461427997332, 0.018782778060995042, 0.02012873152125394, 0.008530662853445392, 0.04441062905243598, 0.027224433288211003, 0.0710333586903289, 0.05617069371510297, 0.07288192238775082, 0.01258367788977921, 0.0023100533871911466, 0.10059483727673069, 0.04963110732205678, 0.00878510725669912, 0.03266345178417396, 0.009013500421133358, 0.011536305282788817, 0.010224312500213273, 0.02177041784307221, 0.05411056969023775, 0.07508080205298029, 0.023728693231532816, 0.013049062927166233, 0.03793690826569218, 0.04747546889120713, 0.013643453639815561, 0.12598796922247857, 0.061911603042972274, 0.12783419515471905, 0.1349115974153392, 0.19784809526754543, 0.1469120808178559, 0.22942264942685142, 0.19076500815572217, 0.07584252016386017, 0.08849339952575974, 0.14713401265908033, 0.09302180653321557, 0.19144873396726325, 0.12097505110432394, 0.21005968999816105, 0.15300972940167412, 0.10669710201909766, 0.13209485012339428, 0.08817350419121794, 0.09990390521124937, 0.10314478990039788, 0.09689369486295618, 0.10755109877209179, 0.12827948376070708, 0.0879482549498789, 0.16266327467747033, 0.15262166038155556, 0.1067092212906573, 0.34611701499670744, 0.14539459662046283, 0.11751834987080656, 0.1457985327579081, 0.10231456413748674, 0.13271831354359165, 0.10988646681653336, 0.14871245686663315, 0.15925579267786816, 0.12339573644567281, 0.1002499093010556, 0.15467732038814574, 0.13470997073454782, 0.09091663043363951, 0.15383274148916826, 0.08752657406148501, 0.16363930277293548, 0.13394110574154183, 0.13913274044170976, 0.10635017766617239, 0.15795056271599606, 0.11901720616151579, 0.09408132624230348, 0.09117489782511257, 0.1478891627630219, 0.12776015850249678, 0.07448559961630963, 0.1398822502233088, 0.09283921594033018, 0.09897336334688589, 0.25404166197404265, 0.22426120529416949, 0.23495274799643084, 0.11456475054728799, 0.138784020091407, 0.08887572432286106, 0.15023469080915675, 0.30885725340340286, 0.09482105451752432, 0.07626607126439922, 0.22629299783147871, 0.17035927186952904, 0.09916441442328505, 0.15258833795087412, 0.1316032069735229, 0.07474281315808184, 0.18549014901509508, 0.13760586065473035, 0.1687760482309386, 0.13664256781339645, 0.1520549861015752, 0.18024092365521938, 0.11332298905472271, 0.17744458542438224, 0.10272302737575956, 0.1747301802970469, 0.24650654755532742, 0.2152379511971958, 0.12318685156060383, 0.08213426262955181, 0.14385532296728343, 0.0959597688051872, 0.07987591467099264, 0.07657468595425598, 0.1403003020095639, 0.1558612092048861, 0.13425691926386207, 0.08350410396815278, 0.08098403020994738, 0.13276604848215356, 0.12434977470547892, 0.08266181088401936, 0.1604420563671738, 0.12071692472090945, 0.1710405040648766, 0.22753241413738579, 0.14846756297629327, 0.20278926996979862, 0.2084227348677814, 0.19365966611076146, 0.1278683784767054, 0.147745675931219, 0.10925837981631048, 0.11936039751162753, 0.07979559944942594, 0.1909336686367169, 0.22908457147423178, 0.12321951347985305, 0.08417516874033026, 0.20694207603810355, 0.20601799828000367, 0.1261140897986479, 0.1538816638640128, 0.11504677546327002, 0.14063652459299192, 0.07053349254420027, 0.1116130140144378, 0.08641952721518464, 0.13423689611954615, 0.15036864846479148, 0.1353909505996853, 0.1474110860726796, 0.14393333753105253, 0.11845726316096261, 0.2362378063844517, 0.07122400900698267, 0.13837951992172748, 0.18838182353647426, 0.17625913809752092, 0.12180728066596203, 0.10123189684236422, 0.18966024712426588, 0.11089905310655013, 0.10652217781171203, 0.11533271012012847, 0.15364723425591365, 0.09624929545680061, 0.14942408743081614, 0.1108155763358809, 0.12674559809966013, 0.12418656900990754, 0.15897155011771247, 0.0675351639802102, 0.11371400440111756, 0.1196452634758316, 0.11073714616941288, 0.18248991313157603, 0.1783820366836153, 0.16919772169785574, 0.16172189003555104, 0.15182100178208202, 0.19176615052856505, 0.068355548864929, 0.15697242692112923, 0.09890690402244218, 0.07974862892297097, 0.10759213953861035, 0.053718493072665296, 0.06751845081453212, 0.0883560131478589, 0.11420054899645038, 0.0978745988686569, 0.16767386987339705, 0.11394670480513014, 0.1620235582231544, 0.1592249787063338, 0.1620769631699659, 0.06806845645769499], [0.016837766706885304, 0.07339289848459885, 0.06145189079688862, 0.023856806474213954, 0.037015787966083735, 0.09397511748829857, 0.007723864837316796, 0.008201600139727816, 0.013359712957026204, 0.08189220374333672, 0.04249762467225082, 0.03829419300018344, 0.06161599449114874, 0.04907103444566019, 0.027461063364171423, 0.012358571511867922, 0.011081566353823291, 0.02865146081603598, 0.05898961921047885, 0.02852410456398502, 0.08845723466947675, 0.00315660315209243, 0.013287349847814767, 0.05315244219673332, 0.04027100723760668, 0.04077778277860489, 0.021165194557397626, 0.009498469808022492, 0.05144744325662032, 0.034727119564195164, 0.04147418076172471, 0.053903573571005836, 0.05090396851301193, 0.03209351947589312, 0.018877010406868067, 0.047504980393568985, 0.006830744378021336, 0.03236203221604228, 0.03442834575253073, 0.027611351979430765, 0.07827829336747527, 0.0130273365539324, 0.08683027626830153, 0.03714974191098008, 0.043167398107470945, 0.017814189995988272, 0.0150027434938238, 0.04552357968350407, 0.030430934275500476, 0.04749852741952054, 0.019544199312804267, 0.08274076055386104, 0.04509302641963586, 0.021038984923507087, 0.051858927035937086, 0.07058878254611045, 0.042334122117608786, 0.035975853534182534, 0.06418057484552264, 0.016106120419863146, 0.07407552591757849, 0.021065364562673494, 0.035122840126859955, 0.023651598930882756, 0.008623902576800901, 0.023762227174302097, 0.08150326641043648, 0.036014597353641875, 0.036172964246361516, 0.055882050219224766, 0.019088806366198696, 0.030073773850745056, 0.02273363461426925, 0.027401780607760884, 0.018485052532923874, 0.02972528356622206, 0.020631590377888642, 0.04196012421743944, 0.09131141589023173, 0.020625363758881576, 0.054469568785862066, 0.05211891249928158, 0.038343646010616794, 0.053250097698764876, 0.02691142693947768, 0.029892595193814486, 0.027832216983370017, 0.05759356892667711, 0.03285664766735863, 0.02441207765514264, 0.08101341925794259, 0.04322672539274208, 0.03618363261921331, 0.005832396191181033, 0.0679886681609787, 0.05439376582216937, 0.059328353963792324, 0.009355609163321787, 0.05464871210278943, 0.05624357632768806, 0.06043617635441478, 0.03527304339513648, 0.02016763304709457, 0.022515484015457332, 0.010088548642670503, 0.023349615330516826, 0.047283749881898984, 0.01987261450267397, 0.05667535042448435, 0.017729982209857553, 0.048636143328621984, 0.023166037681221496, 0.05635744033497758, 0.015631747046427336, 0.00513229767420853, 0.08596711399150081, 0.005595242901108577, 0.020791476817976218, 0.04300309774407651, 0.02319556959264446, 0.03929912032617722, 0.0581380604126025, 0.006135640514912666, 0.025672153496998362, 0.015969032756402157, 0.033611426697461866, 0.04237155975715723, 0.038199947666726075, 0.07136459404136986, 0.03632411375292577, 0.024681952236278448, 0.05146750721905846, 0.03309364881715737, 0.006786759604437975, 0.02804073264996987, 0.026299190358258784, 0.015673607886128593, 0.02507947621779749, 0.021369517089624424, 0.017605906250537373, 0.03101768179476494, 0.10451414884300902, 0.02907966703787679, 0.07034528389340267, 0.019229678982810583, 0.08543657488189638, 0.044360749307088554, 0.0868573275511153, 0.006766894630345632, 0.06953348565730266, 0.04597669423674233, 0.0202070874729543, 0.03485964858555235, 0.02655098622199148, 0.022588854590139817, 0.0012737298516185547, 0.04810469879885204, 0.030378939409274608, 0.01637620836845599, 0.0290136010517017, 0.05544454303162638, 0.011651831700874027, 0.016962430818239227, 0.033854320499813184, 0.09314013455878012, 0.02763093540124828, 0.05658850430336315, 0.046590398414991796, 0.050317389832343906, 0.043384335294831544, 0.05725137576519046, 0.08936220954637975, 0.03841672158159781, 0.07319921278394759, 0.04437159208464436, 0.0424718907015631, 0.031213358306558803, 0.036452568383538164, 0.036379400044097565, 0.02726981747400714, 0.03429947180848103, 0.048652578188921325, 0.0019484999120322755, 0.03316872076538857, 0.01630196020414587, 0.01645129144890234, 0.01609132013982162, 0.0760608229029458, 0.045559358622995205, 0.037113332145963795, 0.047140029273577966, 0.04629298644431401, 0.037007227292633615, 0.07202681983471848, 0.03655558961327188, 0.06927766735316254, 0.05509973379957955, 0.04089520909474231, 0.055072734467103146, 0.07398679474135861, 0.030183765702531673, 0.01799297893740004, 0.016377037718484644, 0.05437416570202913, 0.01804085673938971, 0.055518097287858836, 0.013423266773315845, 0.04033649434859399, 0.057757130853133276, 0.02802471339236945, 0.022776365622121375, 0.024401103146374226, 0.041035445319721475, 0.004089285184818436, 0.022308396983135026, 0.04978539240255486, 0.03078431160247419, 0.014475491170742316, 0.009329029144282686, 0.008973006988526322, 0.08895359045709483, 0.052740687533514574, 0.04841931746341288, 0.051398290815996006, 0.013277391153678764, 0.019182077630830463, 0.04842105037823785, 0.0214729446452111, 0.05647059930197429, 0.026021343255706597, 0.023719301352684852, 0.05818367651954759, 0.0341891292919172, 0.03231673523259815, 0.07164755268604495, 0.04810607177205384, 0.024814564749249257, 0.040529764446546324, 0.04200241179205477, 0.0130690331934602, 0.01382899241434643, 0.020061856594111305, 0.09318239244748838, 0.013987323127366835, 0.020340074770501815, 0.0514319323701784, 0.026746965158963576, 0.022925077173567843, 0.04485473022214137, 0.0252509086203645, 0.030412825872190297, 0.036924325686413795, 0.011909088843822246, 0.04075637552887201, 0.09539702790789306, 0.013155723463569302, 0.01850725573603995, 0.029338552267290652, 0.08281580652692355, 0.023545722287963144, 0.02901250081777107, 0.04251459758961573, 0.015424588582391152, 0.04323835855757352, 0.032446314216940664, 0.01854346141044516, 0.11548428636160679, 0.03026878614036832, 0.020315793553891126, 0.0304056103414041, 0.052798126052948646, 0.031291443374357186, 0.07318442178075202, 0.013224088252172805, 0.054643171970383264, 0.01901721509057097, 0.05320755037246272, 0.03243095176003408, 0.03936221772164572, 0.01954393956111744, 0.05127312018885277, 0.06060569030523766, 0.0253599301140639, 0.02776883757178439, 0.04824699819437228, 0.0707681299536489, 0.017156840112875216, 0.030852503841742873, 0.024584682651038747, 0.049689377046888694, 0.01804662693757564, 0.0942611634673085, 0.023292347505048383, 0.03932309540687129, 0.012483909122238401, 0.018934719810204115, 0.02102151105646044, 0.017032096220646054, 0.04724467209598515, 0.015344775238190778, 0.029426836299535353, 0.011220183769182768, 0.07142857459257357, 0.02874904024793068, 0.010189567929046461, 0.02995094284415245, 0.034624228210304864, 0.021175347137614153, 0.12244811776326969, 0.027899288579646964, 0.01785275570000522, 0.044043432935723104, 0.07550443478976376, 0.03434722530073486, 0.07863108810852282, 0.029228925923234783, 0.06850216755992733, 0.05306412662321236, 0.037540538323810324, 0.08759459931752644, 0.07579308570711873, 0.01460755356674781, 0.05583325772022363, 0.014429768380068708, 0.03419571585254744, 0.034778279514284804, 0.0338445575471269, 0.027671590250974987, 0.04870245422353037, 0.02399624489044072, 0.03274054608482402, 0.02927470901340712, 0.03553531467332505, 0.06360925472108647, 0.04144834660110064, 0.021876543105463497, 0.019153456705680583, 0.022736306345905177, 0.01581669581355527, 0.0122502847443684, 0.04880216176388785, 0.04689690540544689, 0.04167154009337537, 0.022862616169732064, 0.013138448121026158, 0.019379945333639625, 0.07441772278980352, 0.06445176302804612, 0.049313742711092345, 0.05826928696478717, 0.0199408846674487, 0.04893937373708468, 0.07747937881504185, 0.11444633346400224, 0.13831329066306353, 0.0984053012507502, 0.11686510406434536, 0.17907184810610488, 0.13006777764530852, 0.076141472090967, 0.11881358310347423, 0.1481973024783656, 0.13297488883836195, 0.16023112315451726, 0.136954462795984, 0.12859703390859067, 0.09273961230064742, 0.09402759475051425, 0.08880677880370058, 0.18600071693072096, 0.14768666034797207, 0.11577361263334751, 0.15526014380156994, 0.13409674895228818, 0.1427756465272978, 0.25274688145145774, 0.09001259808428586, 0.09599501339835115, 0.18895915505709127, 0.13646604056702927, 0.2169845809112303, 0.15540593129117042, 0.08240809285780415, 0.2167910584830679, 0.18119998625479639, 0.15089092747075483, 0.11172095197252929, 0.14056208718102425, 0.18218894256278872, 0.13135368208168074, 0.10130145834409632, 0.08775255802902393, 0.21529192017624155, 0.09635796814109199, 0.12742205086397007, 0.07476429833332077, 0.10635213693603873, 0.15240826323861256, 0.1308162187342532, 0.12009175436105579, 0.1224627454939764, 0.07696394241065718, 0.09154367100563832, 0.16653925966238603, 0.12252402462763712, 0.11583054278162308, 0.08182782985386439, 0.13600427628261968, 0.11968847873504274, 0.11738238841644488, 0.24615291418740526, 0.15894953801762313, 0.21131813497049734, 0.1282085492857732, 0.07530041839345358, 0.12413134580128826, 0.1389303567702882, 0.07409465106320567, 0.2517027984140441, 0.12792488560080528, 0.2685337874572724, 0.13340232137124985, 0.11457773071015254, 0.10375983736594208, 0.09368732004077174, 0.1974936158512719, 0.10415982527774759, 0.07978530586115085, 0.0988627462356817, 0.11659332216368057, 0.18942808848805726, 0.14278333517722785, 0.2754211553838104, 0.14501725905574858, 0.15339140110882, 0.1628134705242701, 0.08344445013790391, 0.14317821711301804, 0.19159312621923164, 0.19922964769648388, 0.2460904253530316, 0.09398672467796132, 0.21848984935786575, 0.07410582780721597, 0.09819561484619044, 0.12297269742703065, 0.2352019611862488, 0.14581140159862116, 0.14380326872924343, 0.10168685563257895, 0.09364492114400491, 0.1387390904710628, 0.13847433670889586, 0.0986023637233302, 0.10781350734760053, 0.1378429916803725, 0.16864825040102005, 0.19347504945471883, 0.2149245422333479, 0.08655749246827327, 0.11311936599668115, 0.10453909984789789, 0.145929180434905, 0.09902198886265978, 0.10495709968381561, 0.13525757181923836, 0.0995591479295399, 0.22917695401702076, 0.081042674719356, 0.21313670848030597, 0.14474544004769996, 0.09404134674696252, 0.06388640234945342, 0.13731287559494376, 0.09855520765995607, 0.10246014382573776, 0.15178089612163603, 0.22271710768109187, 0.3240570909110829, 0.10390807394287549, 0.19631226517958567, 0.14522261131787673, 0.13897945726057515, 0.14065853669308126, 0.24032212706515566, 0.11540872088517062, 0.13117954455083236, 0.14475409348960966, 0.09266405424568802, 0.09846168220974505, 0.21613955672364682, 0.10326440184144303, 0.11083137665991671, 0.14321945083793253, 0.10245032521197572, 0.1887432494550012, 0.17105369945056736, 0.14848869934212416, 0.11087097023846582, 0.14281692478107288, 0.09154514787951484, 0.1929615723202005, 0.13295220880536363, 0.1533379516331479, 0.14643398928456008, 0.1446596923051402, 0.155959855474066, 0.1595997781259939, 0.222280902962666, 0.22322622098727152, 0.2535062172682956, 0.11486110495752655, 0.1881151253473945, 0.10860076276003383, 0.10017788386903703, 0.09005280764540657, 0.2261465572519228, 0.21429721964523196, 0.1671165318111889, 0.21073467331007123, 0.18876782938605174, 0.1244063486228697, 0.18846334103727713, 0.21559722488746047, 0.08113754345686175, 0.24406173499301076, 0.13950342836324126, 0.21745869453297928], [0.036076381147722714, 0.020837196825596038, 0.02643380666995654, 0.04951005190378055, 0.03484587803541217, 0.08163639286067337, 0.03084154046518961, 0.0214958732976811, 0.020069669553777203, 0.025435182033106685, 0.005618367295028293, 0.01582732336828485, 0.008258319703600137, 0.003391218297110754, 0.06188724575622473, 0.04453548797755502, 0.01110253666411154, 0.016502286271133926, 0.04278197855455801, 0.029193076479714364, 0.08372624361072667, 0.062285300373332575, 0.05396794746047817, 0.054655439671478234, 0.07346502039581537, 0.06737605493981391, 0.07367342288489453, 0.033827217266662046, 0.05246390726824757, 0.030854398173687514, 0.07854033829062246, 0.045105539029464126, 0.03926831377611961, 0.029370622323767748, 0.04170467327639926, 0.04944839056406636, 0.032312772164004855, 0.059562082242337056, 0.03373053026734851, 0.021947575914964546, 0.017043734951585066, 0.027381781583244447, 0.020240200246917084, 0.07657217749510892, 0.05018455281970091, 0.060829703870695084, 0.05887276063731406, 0.06899005544255488, 0.05444452130177524, 0.03548499335011002, 0.06668673333479092, 0.149979718553368, 0.06093159332522191, 0.055458239366998896, 0.10098544444190338, 0.017928261804627255, 0.06279974972130731, 0.04246970507665537, 0.07606914979987778, 0.025255354084947612, 0.029943359950266313, 0.03267232415964827, 0.03070364757149946, 0.04272329322702717, 0.039848357846494764, 0.022792225317971315, 0.035750196111621335, 0.027279098030703608, 0.02425083494017599, 0.051310131093487144, 0.010090714786201715, 0.07436330852215178, 0.08063603716436774, 0.041389817124581896, 0.03762049360375386, 0.033566682614036836, 0.06388295878423378, 0.025621333079470787, 0.04595909049385227, 0.0263259002531413, 0.02199163536715787, 0.04717652438557707, 0.055082935286918655, 0.0042624876095942454, 0.012597236927831545, 0.0323867939732736, 0.0478744697466027, 0.04608364513842389, 0.06857497966848314, 0.02318526487215422, 0.06611131655517966, 0.04289083677576855, 0.04323173488955945, 0.02395668841927545, 0.01302292355831014, 0.020675030136771966, 0.04753873698064126, 0.021755003435828257, 0.018380075744062196, 0.05776762482128106, 0.02574776350229513, 0.059454738002386875, 0.043836733675561845, 0.009388877788296668, 0.026214281242573634, 0.0396865436778171, 0.02104017050442053, 0.010730726244219113, 0.025689499343570787, 0.005185396948945709, 0.016155096600414254, 0.03816206844931003, 0.007966760495037306, 0.07428463344695047, 0.018605172845127527, 0.01655231259064749, 0.024970656959339976, 0.0233316497906344, 0.032179033441934735, 0.04204204618872609, 0.03207101013686042, 0.023659697617404163, 0.06839245586888865, 0.06898371750139631, 0.045050122862448916, 0.02007192568271421, 0.024001703386602458, 0.054426487113232724, 0.045220271349535324, 0.04023805588076357, 0.09253517288016155, 0.028659283052547835, 0.08833250190946274, 0.02671126785571687, 0.03730433127202559, 0.006612690258407383, 0.0473245791363297, 0.08270452148281038, 0.15789101278642192, 0.03179968465701677, 0.024822329469316173, 0.04753314860863611, 0.019116644325549714, 0.05210320865444373, 0.03945486372685991, 0.03682020236738026, 0.056747194030322134, 0.10707314082537778, 0.008172273246600525, 0.0586592892796034, 0.021179386276344303, 0.04812999861314893, 0.038998431773507036, 0.017757397145032883, 0.025535282911732793, 0.030643554018752184, 0.03152401761326473, 0.07666638572118245, 0.03416651234147139, 0.02439698979287641, 0.03496733421343379, 0.05390001126215793, 0.0475892995018512, 0.07397727298666723, 0.02349541951844003, 0.026642281518434174, 0.05677135835867375, 0.007197246122814249, 0.019826124516839627, 0.013796421408187598, 0.029080960230203345, 0.07203685367130674, 0.08293757811770774, 0.028793357596441638, 0.07843252649763599, 0.057140929347951896, 0.029289336744113825, 0.04490056155191269, 0.01133467396357446, 0.020379605266498402, 0.07479513456928544, 0.03661721384560224, 0.04112988732231315, 0.0768592327949591, 0.08215992609621026, 0.030100064432190266, 0.03794060416112188, 0.01161071857495699, 0.00657998891256284, 0.07783986220601946, 0.03174129618855659, 0.019681875128298998, 0.0381142036349047, 0.042272071150364354, 0.022819304431322962, 0.014419752169487765, 0.02267009564093314, 0.026843809864658397, 0.06511343221063726, 0.005536182789001032, 0.019022441665583756, 0.0597650002600858, 0.062455957231577486, 0.030757933818676975, 0.03586625687603373, 0.017182280935230665, 0.03818138284259476, 0.08359897270565853, 0.04077824291016441, 0.06055367317458149, 0.015526195093116257, 0.027499395291670226, 0.05485190100444015, 0.0662086418014951, 0.03131148136162665, 0.02198131951445248, 0.05797106976388022, 0.008716736901988043, 0.04599064290232491, 0.019517174005159177, 0.03942398296203464, 0.047235929596354254, 0.08297500462504104, 0.01183903381388518, 0.03593145826016553, 0.02499104375601746, 0.05286324580083601, 0.020538499084068462, 0.10372464472311549, 0.06610592114157043, 0.08458574709948152, 0.014463224397331942, 0.0390599669481162, 0.04103548613784369, 0.027643876601359807, 0.04383901949040592, 0.02672003633051645, 0.051811589146382175, 0.02970148103486281, 0.02839516382664442, 0.029980574945511762, 0.0646233327279333, 0.023805141863704193, 0.0032920826743065845, 0.0073809197874652455, 0.06434644485125318, 0.031155225879047066, 0.09925399164785631, 0.020837617994402535, 0.06366762463585474, 0.0358420294651296, 0.05291091394610703, 0.04141605946642812, 0.03128073047264479, 0.06189579900819808, 0.018119444612239022, 0.06495399662526324, 0.10324377013603225, 0.034493613929953426, 0.051248380696051754, 0.010294702424289426, 0.0063714250063640065, 0.07978264897246845, 0.02865343678422505, 0.0662213696341496, 0.03894493405823596, 0.027706302353180945, 0.012146207809564658, 0.020500612445175648, 0.018900939103332348, 0.03254560615459923, 0.00456609233879135, 0.017060659629350994, 0.04138693017011974, 0.06852873644675128, 0.08362364911590703, 0.04119970486499369, 0.012073985708411783, 0.010260599810862914, 0.012419341346685542, 0.028606748273887206, 0.03380696776730474, 0.026336626142438035, 0.022183662367751822, 0.07624939520610496, 0.05379677109885961, 0.04432263631315436, 0.029506678401958197, 0.04469353945751209, 0.02371064791077515, 0.031026548604131676, 0.0317191838985309, 0.05264090206765104, 0.04831999583984725, 0.01211400323882117, 0.060688243102049455, 0.0070832285837241216, 0.04054096345498692, 0.015073344002303202, 0.05540032216231339, 0.02897310576372547, 0.05734495316573884, 0.057419190197833814, 0.08403663203353062, 0.021460213101818226, 0.04071330498845782, 0.04444804071681574, 0.059808293444802985, 0.060745243754354306, 0.061495458576246165, 0.05137397063663229, 0.040558203545515426, 0.09421624868991785, 0.020743244640470948, 0.01669086042966228, 0.030465911695500836, 0.007465038979717065, 0.051755312088062055, 0.041972395629272796, 0.040599574567750096, 0.011998663285339717, 0.006229489263205323, 0.016306529978464823, 0.019525471216184087, 0.012569388763949974, 0.021741253294749185, 0.0047231168719008565, 0.05762121763837058, 0.045456007137545384, 0.053308141068555415, 0.09248354166629724, 0.019895090445061214, 0.0535441366082523, 0.03878698647895362, 0.04564950730127748, 0.02153611996618565, 0.011524912388267694, 0.013592300183518091, 0.03294969072157983, 0.03816639517026488, 0.05577366697252728, 0.08180665638064966, 0.015286375637515448, 0.033499778000987135, 0.050481274593039416, 0.01642962630285183, 0.04102627979591489, 0.04376667864562478, 0.04348732683865819, 0.02878297309507616, 0.028933161520399153, 0.034040985483443365, 0.14667566225398332, 0.10670930292690173, 0.1004974526586011, 0.22162606153870001, 0.08908487638109364, 0.19784692267421633, 0.07700694986851886, 0.13024626416154206, 0.17545778187923133, 0.11235313562792726, 0.13719393900828436, 0.09875260409899056, 0.0784419295086991, 0.17447111138608307, 0.10101136023877189, 0.16911641199840233, 0.12779851269442588, 0.1565232643042691, 0.1442924776347354, 0.10946926850010641, 0.21452097716974095, 0.14831638749456033, 0.17920604324899614, 0.08771256369072944, 0.20140106789767742, 0.14338949171360582, 0.13365108927246183, 0.09046142673469149, 0.17797436012187973, 0.1507348389714025, 0.180708343104925, 0.15438114409334958, 0.07674589200178161, 0.1939159445464611, 0.23296451952774078, 0.08989955415017903, 0.2092585267382674, 0.11909399618161842, 0.10380226594861597, 0.2226314935251139, 0.13694583903998137, 0.09305425322963856, 0.15330743452068418, 0.1307650699163787, 0.17855133541161194, 0.09899588010739535, 0.20333393214968964, 0.10536887290072627, 0.10964279004838318, 0.1035120639426168, 0.13516953826183453, 0.20856359449680895, 0.16924658470088616, 0.16389693191740662, 0.17796422238461673, 0.06469720610766672, 0.21258833556203172, 0.1048856605484616, 0.11873821800691076, 0.19165321049513295, 0.09792992597795092, 0.10222509081359021, 0.07716309773968533, 0.09333054738817737, 0.1052747388894204, 0.1543582117301412, 0.10693444826756604, 0.11946800150326453, 0.24849456822266802, 0.18935678293928504, 0.0836954519036226, 0.17052057024557143, 0.1894276580424048, 0.1979232154553756, 0.10394504774012603, 0.13337598997168243, 0.10582490780507214, 0.11425736040109769, 0.185239985876251, 0.14045348129002377, 0.20618627284420654, 0.21428920445032418, 0.13804582064040005, 0.09973721142159775, 0.12526605249149725, 0.1339063880732283, 0.21205407829256728, 0.12600917980307713, 0.15029256348498166, 0.14063089911360294, 0.13915531657403335, 0.13702597614610568, 0.09437089000130072, 0.11837672529509291, 0.09039449985721149, 0.13219287298852578, 0.11969978164415807, 0.15416566893691197, 0.227487439988181, 0.17405988735845312, 0.16171225695870817, 0.11135979322716594, 0.08515616180375218, 0.06168100291688461, 0.07749681186396629, 0.10274017840856686, 0.12961190601345152, 0.13386766280746087, 0.1907920668600127, 0.13417894922895357, 0.11192680889507756, 0.10671616779291071, 0.1064029814733658, 0.1689267932670191, 0.12561254639877006, 0.1606383841135539, 0.2554935700027272, 0.09333876296295784, 0.19605558598414063, 0.1790322025772184, 0.09867210334050469, 0.1675360678927973, 0.15320967882871628, 0.13301751780090854, 0.18037931935396045, 0.15393165493151173, 0.11044789411243983, 0.25085283152293414, 0.1612710056360811, 0.11435694177635014, 0.22954315936658531, 0.20624991942895576, 0.24455109232803807, 0.15999010327504948, 0.1550735827186145, 0.11967715356149711, 0.12934361962834373, 0.18611567560583353, 0.18393825885141268, 0.10029334720456973, 0.16376675921492279, 0.08698120684130117, 0.16272462060442194, 0.2402394518139772, 0.07766384704154916, 0.1572523353388533, 0.0833742726536002, 0.2322133770212531, 0.07476722239516675, 0.18357137072598562, 0.09863766026683152, 0.15116789698367938, 0.12159270350821316, 0.20141001819865778, 0.1252593137905933, 0.08871380996424705, 0.1460637169657275, 0.2783771889517084, 0.09580819256370887, 0.11064304926549084, 0.07722510417806916, 0.1827032063738443, 0.12244927551364526, 0.16292381304083392, 0.15056733624078333, 0.25613347941543907, 0.1367698164540343, 0.1109805928717833, 0.18667354801436886, 0.13781551737338305, 0.08587908785557374, 0.21341085783205926, 0.15129284496651962, 0.16622653347440064, 0.21033980621723458, 0.1841177250025794], [0.048639575761626475, 0.03265116181864869, 0.03606677033531014, 0.01889995575766079, 0.049498878870508634, 0.05912488675676286, 0.02823437753249891, 0.013437865745800082, 0.03518137331411708, 0.02747418824583292, 0.04058807870023884, 0.044471310757217, 0.03210566101188306, 0.018578086310299113, 0.04504036362050101, 0.0180483171789092, 0.018217211436422076, 0.026931093852908816, 0.05904029305384029, 0.0344554192997748, 0.029749640852969605, 0.0548159253958147, 0.07495187615859322, 0.02529441331716953, 0.042064637164003216, 0.02576132996182423, 0.042998945427825674, 0.030301097394840326, 0.007408170058624819, 0.01568359904922545, 0.03865035338094458, 0.056500593200325966, 0.028425771852198523, 0.04382586863357574, 0.01799040739570046, 0.020472065734793432, 0.08188795123714954, 0.039025583246257156, 0.023878913198132068, 0.03724440284713637, 0.05282786762109026, 0.0059581206460279645, 0.08907438241294585, 0.04371463553979993, 0.004741414986710879, 0.11355313647072762, 0.12389023686409928, 0.05872942223504651, 0.040215112385340035, 0.0650968897389248, 0.022513166659337003, 0.08844985772157088, 0.021128662338014692, 0.03363367257406935, 0.07239741869852878, 0.02212019760918338, 0.01952651949977735, 0.032115401700139046, 0.03604014949814882, 0.009294353221775964, 0.032760613758000545, 0.0254039728679345, 0.03052804615435889, 0.0028640854134209803, 0.05886218503292184, 0.021247266813588794, 0.038890456708031707, 0.07160168795962818, 0.024860717057890724, 0.03415716128074564, 0.09565889471559785, 0.0738731496676337, 0.052141069318167865, 0.038346610890585, 0.053106258346815594, 0.07016431860392913, 0.018316622117708903, 0.03262612175603863, 0.015802802809048444, 0.010642734432622092, 0.044058376079192385, 0.025167088606394827, 0.051430937892291695, 0.049398755727452226, 0.01516934173196205, 0.011587028293433832, 0.06370468749082647, 0.07382406402030028, 0.019974446440755855, 0.032031858136178926, 0.05633339846099261, 0.017476551765867043, 0.03861045181110967, 0.025247758203477133, 0.04270655037544202, 0.026121718728973065, 0.019129587381030433, 0.047709972714073956, 0.019694139118655585, 0.003376403637957992, 0.09628393148886971, 0.028947494247404393, 0.040104487852659076, 0.037300683616194874, 0.04104294472199399, 0.03229944319173228, 0.024513106218364555, 0.022801247978350148, 0.041137876542052254, 0.01872444525361061, 0.0039014174581097905, 0.018566304715932347, 0.03161437780363485, 0.032148475511348806, 0.014345023464557016, 0.021590805117739365, 0.03265473525971174, 0.04119884397368878, 0.0315250863059191, 0.04295862825529184, 0.033287579426541924, 0.02275992705108365, 0.09648707957239822, 0.028513425058918074, 0.016242849997070152, 0.05537763841857668, 0.03212309777154587, 0.02907672998844646, 0.03207272820873186, 0.04667737812269479, 0.05222542182309553, 0.04795733795617707, 0.045803228349541314, 0.038013650046195835, 0.008353587345482083, 0.046989432667032816, 0.03482233340037055, 0.025958249570976477, 0.004716428265965078, 0.03640867034846451, 0.025652495860413183, 0.036005394722451456, 0.05917495203902945, 0.0031832144804866402, 0.012550515948532848, 0.058031135486089624, 0.01126688619478955, 0.011410049264668487, 0.023616599246452097, 0.028251745643501636, 0.07522566927946173, 0.027095153018308338, 0.021486260629899334, 0.10796556598506868, 0.04825718417123426, 0.07725525021669455, 0.03001551711349748, 0.013335048606677447, 0.09649664585595019, 0.06972998409764841, 0.02441311109578237, 0.06753772438969463, 0.04320041254686657, 0.059105208711116575, 0.10850938953808509, 0.01630148708500201, 0.0590422152163228, 0.0864323960558977, 0.07284042148967274, 0.06207739883393515, 0.057684155472088605, 0.043529551330721006, 0.05410901860159356, 0.013554984070651699, 0.034339677658863366, 0.02261060322780395, 0.06254350097151473, 0.06860934852738865, 0.015469520058104536, 0.058286608691560104, 0.03754907302209176, 0.018901074545283336, 0.01576096979988506, 0.09822135994909331, 0.07102791874785908, 0.05921339899941813, 0.014141329902486177, 0.026763772948470432, 0.012936087641719496, 0.03145425202092156, 0.06364179047523066, 0.021990516579535324, 0.03750073694391176, 0.03289457512437366, 0.034670419481699355, 0.026397688197903335, 0.025660030514700338, 0.06805673794588074, 0.06263431758270599, 0.007051248048810521, 0.034258427331224084, 0.07456382940290496, 0.08047339550103061, 0.01419926195012522, 0.01819976168917492, 0.01605409401236102, 0.041849696353892796, 0.01402938805767917, 0.036272653233027086, 0.03662849449028727, 0.051227162693976425, 0.06006167008308694, 0.02051937764917966, 0.023631340154679492, 0.026284720333933365, 0.055437548289773986, 0.024894879970815964, 0.036637927187257446, 0.08864309813361615, 0.01883603457827121, 0.02234633000625763, 0.05335907466360368, 0.028819217732234392, 0.03884992802341003, 0.0270024068231578, 0.07128983750590123, 0.0331094676948851, 0.0880785018671304, 0.07000720594078302, 0.05488058872288093, 0.021656628050550353, 0.0495769676490454, 0.03383239745744504, 0.004545439296634868, 0.017863813700387254, 0.02347805511817569, 0.04265444789780304, 0.007823219857527874, 0.03468122144113295, 0.02556789288064465, 0.13709659891901538, 0.04422979734954424, 0.07727850170340389, 0.04462200384296011, 0.0890414830064401, 0.05094683125207666, 0.06494502405985259, 0.013473110338964034, 0.014613390558224637, 0.025421558057132643, 0.030407957383431494, 0.030239998231991194, 0.020315928995842114, 0.032438258203910664, 0.052994657889939845, 0.02282119505252922, 0.04112126356631052, 0.04154868867772166, 0.030974357068771496, 0.06782735494198278, 0.02058382389805047, 0.046198088020901196, 0.05857194591953885, 0.013652470734086819, 0.03602058277465403, 0.015140661434998037, 0.03511085073114373, 0.0913089000096079, 0.019223519157094415, 0.0342038683447754, 0.027953975586569868, 0.09914323352859356, 0.03562526668247301, 0.019221932816435583, 0.05394717103627045, 0.0814428852754645, 0.008242263338615885, 0.0759517791448161, 0.05282978236209601, 0.04507130375714041, 0.029992653398949187, 0.0066962908749701455, 0.026941929208987858, 0.040857352141756564, 0.029479246768460143, 0.008010679866856663, 0.059719989003497176, 0.004757806245834217, 0.048893568382482044, 0.019857610132021364, 0.0030646742470707977, 0.014490496469079517, 0.07441443507559597, 0.009573229126544902, 0.08431330468738452, 0.0797287245222833, 0.020035820198245347, 0.018765604763757437, 0.04494961380260065, 0.015957705727487337, 0.03512745999614708, 0.02587597322417423, 0.08689441267051734, 0.02253689683129778, 0.04169443534919992, 0.024265972897410393, 0.013043567323620664, 0.039619256858713925, 0.011770472356147366, 0.04443355028342921, 0.06818972338805906, 0.05556568008614704, 0.04588692776451353, 0.027397808262321632, 0.0146510452759685, 0.01600598614459159, 0.015730480517959222, 0.04345992303569801, 0.008124291543936124, 0.016786734777269885, 0.04512214829446748, 0.07913939247373492, 0.03374682411958929, 0.018845005288312677, 0.04962869905284606, 0.009138230398093583, 0.037820353973074816, 0.01548758300486952, 0.03306151011202019, 0.06753152003511786, 0.07820252008968964, 0.045745129318675026, 0.06083791573473718, 0.032127461599884555, 0.058625558667699806, 0.10781758915982209, 0.05040696334617678, 0.033898548790602945, 0.020497066834650468, 0.02333839776838431, 0.040200377043220215, 0.030858795398671646, 0.03699229899211787, 0.024325248232344165, 0.07327252955292352, 0.028312508984527085, 0.05121275389683433, 0.041004471786436625, 0.056479189661331475, 0.01721318025374785, 0.019818693763227202, 0.03342940384754911, 0.14998127706348896, 0.1679966744268313, 0.09725924712256528, 0.13745290401857346, 0.1383199996780604, 0.15067184547660872, 0.1629266480449587, 0.17160091461846605, 0.14430785493459553, 0.22097528708400205, 0.11237805694690906, 0.10573996158200316, 0.11651108477963135, 0.09445936142583378, 0.14372777746757492, 0.14688154886243865, 0.09317762043792754, 0.1093231767299585, 0.13164684525690973, 0.08474652597215027, 0.13970849860925227, 0.15688075684010983, 0.19064138119574636, 0.0747381302062422, 0.2091711907996796, 0.1425915048457682, 0.20227059780154377, 0.10034572056611069, 0.17534552462166175, 0.08705508022103459, 0.1272490413975902, 0.1150315317499917, 0.19714070978807285, 0.1606033102143556, 0.10616956860758364, 0.18899066664744169, 0.10675738667487167, 0.10117277735844254, 0.12054820486810058, 0.1696628998615779, 0.12371212884318084, 0.07216825091745704, 0.17946846666745842, 0.14712567091919482, 0.09905801271088421, 0.14120342151727527, 0.19135540147544816, 0.19728001090697944, 0.18835803028196096, 0.1682264285045676, 0.1432872682926245, 0.17024731147103012, 0.1281277442467399, 0.14485480292933062, 0.1880552340298891, 0.08344848742126487, 0.1538186555262655, 0.06680917285848409, 0.12755436095176265, 0.13593078881967813, 0.14907092903740704, 0.09084741031983867, 0.14209922344889492, 0.1558760373154655, 0.3374948026612401, 0.12920906825456768, 0.1272673427592963, 0.10811713480507024, 0.1874017878435552, 0.2152906882110983, 0.204481307300739, 0.11442082584835589, 0.15601922728819773, 0.11687372039887123, 0.14613886683946475, 0.13066292071016505, 0.1637347726500593, 0.087072958558565, 0.14816809154581279, 0.12241408287081867, 0.26115924410987645, 0.17325403372524306, 0.09924487807438709, 0.12305596639635041, 0.09914880705764517, 0.09710641665151343, 0.16203751059947535, 0.19727959530428052, 0.12465668987715617, 0.09576019045198336, 0.1358264428563416, 0.11548216381925158, 0.1193367452651728, 0.1670396898407489, 0.1315485403756611, 0.15257943217875436, 0.0924156945256982, 0.10971552794217132, 0.2515502425376326, 0.1646268935292028, 0.21606485213851556, 0.15418739902088419, 0.20546910585835576, 0.1589181154849939, 0.1722774564404972, 0.16674406273523346, 0.11723533185431734, 0.08280379857751541, 0.15075541130499914, 0.1139828770828899, 0.11550019058631733, 0.10664426852599718, 0.1141648665361572, 0.08610324613982812, 0.07866200598073192, 0.09009596353280358, 0.21003607485909015, 0.21353962045395747, 0.16306691395584494, 0.18185199267463759, 0.17813193291658536, 0.14155013806885108, 0.20264510036213323, 0.07090763887390494, 0.13347938598599285, 0.1317444525193423, 0.1748712922562845, 0.1610668853390962, 0.1206257518788334, 0.19146654551150277, 0.16370486409869045, 0.22509013972012326, 0.10319408334908076, 0.14619924797443673, 0.06650114446529187, 0.14671885524876416, 0.08838423702400178, 0.17724316654494032, 0.12192074762424454, 0.14807774248765782, 0.13479942921549082, 0.18540165532613173, 0.11637752046226524, 0.07127698350814171, 0.10144050713279285, 0.12411206480464898, 0.1398359698941931, 0.12611328827915713, 0.07550637921667658, 0.17281771026318893, 0.2929083810886368, 0.17200887319631875, 0.2434280002489686, 0.16342743445420638, 0.13002897816477343, 0.14061345864320174, 0.1558227214263752, 0.09110262006288394, 0.161740799958352, 0.247496067895554, 0.13709901832044125, 0.10651303455233574, 0.17863386223325506, 0.09014994735480286, 0.15818637271877378, 0.10118145306478254, 0.2661707892548293, 0.18215271091321483, 0.18196864344645292, 0.14663019828731194, 0.1959618230466731, 0.17248055257368833, 0.1889707919326611, 0.08026569805224426, 0.1656495433417149, 0.13865046319551766], [0.028167547134216875, 0.020589360319718253, 0.02117994474247098, 0.027136063908983488, 0.06169597945699934, 0.04249699013598729, 0.01961257523362292, 0.036038398029631935, 0.07107477795216255, 0.03548162399965804, 0.024533786163374316, 0.02937280423793709, 0.09915207250742242, 0.01864545662101591, 0.02072222145216074, 0.01962073514732765, 0.030379913478100207, 0.13102476223139092, 0.005463340530695859, 0.028399369948601816, 0.014019698392075952, 0.009190537894028239, 0.011562527215573937, 0.012244714926055167, 0.028036882758897264, 0.02349878144741524, 0.04225195894832723, 0.04498452442931011, 0.02756297693849774, 0.010395069548394531, 0.0184159511627513, 0.02601931533718016, 0.00899590966582764, 0.052800374760408886, 0.01796283289877465, 0.01156317288405262, 0.07298276541405357, 0.03413039943552576, 0.026631509244907647, 0.027470407003420405, 0.061792221167706884, 0.06942141393665224, 0.051643514962051995, 0.04650744485843461, 0.06255590968066826, 0.07482535482267849, 0.05700546513253357, 0.05019493917643558, 0.021160083015274722, 0.07481069740606472, 0.036560224325512536, 0.07754801263217814, 0.05071257233794313, 0.09580043712048791, 0.033244145233766176, 0.059420562101877294, 0.023975320036697667, 0.06609656265936792, 0.024199060862883925, 0.06393437477527186, 0.049376847528037615, 0.016585865087108687, 0.0531921953370329, 0.036394755079527386, 0.03455446632870007, 0.01973366775928298, 0.027719751924450975, 0.003588518025026133, 0.04789640021044761, 0.03186695292242803, 0.0044678227095573675, 0.05266944877803326, 0.04597000006469898, 0.03699608023453038, 0.026448929784237407, 0.03482134263322223, 0.05387822551710997, 0.021219415866653435, 0.06130476373073179, 0.020121263660257682, 0.0401905101898592, 0.04044948633236345, 0.03891712949553039, 0.019741204268939327, 0.01005167967377929, 0.030865532244206406, 0.047097682327148505, 0.019171954736521002, 0.08460599288810045, 0.01704289075860288, 0.1036724123696331, 0.04767201928189024, 0.0165361319159274, 0.044318027576082386, 0.02634200300235534, 0.03402483263926115, 0.06403236053301953, 0.012716632718365872, 0.031368192576337606, 0.015527611667494057, 0.07975392785738222, 0.026710427373473067, 0.037255034112604335, 0.012257677462912397, 0.05099796522699762, 0.09727041644509882, 0.03901726006006356, 0.038697962154401466, 0.017264792913920246, 0.06566974610905163, 0.0326314615085721, 0.008136311553244013, 0.01693524965958204, 0.05216457313508727, 0.03369848804140929, 0.007940215728012845, 0.052348870667628944, 0.06662360625341535, 0.04609254719980527, 0.07071757485391572, 0.04512203697231598, 0.04439299933437724, 0.04232706800394226, 0.07015138296992518, 0.049212914527743123, 0.04254966777807567, 0.013209207263571443, 0.08170473724021576, 0.015201285623334115, 0.08051008728216402, 0.03315253823529929, 0.07541781873442233, 0.04518730514973868, 0.013505249971785815, 0.04323173488955945, 0.02520652262319345, 0.019442359953245614, 0.040056519137579016, 0.06032026401953772, 0.13098401832394302, 0.07639838135219179, 0.0544379124767147, 0.04213063635688741, 0.06424350896850228, 0.03166290684021078, 0.06031898010405712, 0.007736491552350344, 0.017389061831636354, 0.04060769366333261, 0.01536746640340425, 0.06515158602269366, 0.006998904373176629, 0.024813332784106024, 0.04537466404144652, 0.047238089246093296, 0.05417190448497422, 0.05687704018782824, 0.010858967507374473, 0.06536694985697977, 0.03377646549779456, 0.034005611014436, 0.01005709085802664, 0.02580687556474004, 0.09989699581637979, 0.004895033525826875, 0.011851816379930824, 0.007728596492597717, 0.03611022679251619, 0.02733932331466349, 0.016328955825883895, 0.02785388584015891, 0.09924277779646218, 0.0365411325765308, 0.016030508559197187, 0.028435117346816696, 0.11173069637152366, 0.07973775645950809, 0.02556439179898007, 0.006549995941895759, 0.062303995073307306, 0.028214172562002204, 0.02425167171168141, 0.019553745187295135, 0.03494081356620882, 0.07503533066483214, 0.060945909353904426, 0.08683679232490249, 0.021651362512784544, 0.0690794397087302, 0.011336098887113621, 0.09886251616990194, 0.011763601924030809, 0.07661174880922772, 0.07061485419399105, 0.024263232517114375, 0.014125744801276596, 0.016777958880993538, 0.031005338023533113, 0.03749721174244769, 0.04897103375697043, 0.01756083747750381, 0.024034946036408655, 0.06530916623887606, 0.048980945139192045, 0.03906963342160452, 0.08619113868917339, 0.009984846492443467, 0.054904018325032666, 0.04614889476215467, 0.02940626767667709, 0.036153968976577744, 0.04689777742896695, 0.0425839883973822, 0.027536107481864747, 0.03044616500119446, 0.015421113475895254, 0.029338925196498167, 0.014165716875140788, 0.043995902087772265, 0.0726807706814725, 0.020480546627368312, 0.037571938592009246, 0.0013497307600118802, 0.06695542790112086, 0.017642629572947044, 0.00983711086519179, 0.01432260318324552, 0.03829307977866847, 0.03331027430249378, 0.06663349908194505, 0.03654951142380014, 0.034352082657278515, 0.05285495601128787, 0.05277340882457793, 0.05038503288233187, 0.013317380853550276, 0.11525243942742236, 0.019757885893341154, 0.0467447020491818, 0.03842758291284554, 0.04013691970612854, 0.014783394326514099, 0.031156558034126647, 0.11426190976635553, 0.01776960361894453, 0.05554057323024608, 0.0429019133298425, 0.021915646866546012, 0.042632331897038966, 0.02165208239603089, 0.07890956418123096, 0.06514662847621366, 0.12454878160497174, 0.06199522453243844, 0.04127723703277297, 0.020964562354492955, 0.03148375610180665, 0.034199396905023605, 0.044020437489962205, 0.011540667255758308, 0.025771478831302375, 0.04888717106950935, 0.07117323868442327, 0.049608575718593784, 0.02012642344197957, 0.0735716224880889, 0.06275018167798407, 0.0864955157157965, 0.04297448795114178, 0.015809389369678684, 0.03246261920139659, 0.0305766011661035, 0.021786440811411012, 0.011805908052338054, 0.05019443451601546, 0.036847209121333435, 0.049246403941651806, 0.0029975402640047832, 0.026306109029974323, 0.011655913513095584, 0.042952034273184836, 0.0194611752522178, 0.021900809479120653, 0.0361176816659281, 0.02454664201650303, 0.052972003832110204, 0.009574576124578016, 0.026187372823187616, 0.02841805908246897, 0.04791305400431156, 0.027077972299593966, 0.02347259291127557, 0.03430875607591588, 0.01913595315272687, 0.0511108199134469, 0.010212035522272345, 0.04768423874338623, 0.019356996272108518, 0.011605812978814356, 0.06822092327638529, 0.029961973013996612, 0.02937539989943616, 0.024194823199650273, 0.037801637008669786, 0.08500170602928847, 0.054300804404192604, 0.028361132644931786, 0.03947063065425027, 0.04120294805034064, 0.05996099404001143, 0.006598640475203865, 0.08894130791304633, 0.041628799808677286, 0.05468003073474392, 0.003800866884375864, 0.03482422216620762, 0.019817856991721783, 0.057876579521689564, 0.059544901523622684, 0.04611162410583347, 0.04636883764760569, 0.030931516594137065, 0.022232460432860535, 0.014890591064613545, 0.06335462385322899, 0.04882240013103001, 0.06521871328004636, 0.013462728620652342, 0.025014764651132282, 0.04535172054602299, 0.04851939607760869, 0.009705918637337163, 0.017972464120248333, 0.05498638187418692, 0.010291726412106073, 0.08413223549723625, 0.1084752804308664, 0.05465898342663422, 0.030132034298731014, 0.006365788858602173, 0.015545715432381257, 0.06774426408810541, 0.06872613288578577, 0.01831304867664585, 0.08350101663381793, 0.10341008543036878, 0.020373271036078222, 0.01554478960315464, 0.05047453960287385, 0.0920882515492849, 0.05747166374931112, 0.03820457495748997, 0.10002070441260003, 0.13254178629722446, 0.11634670649073087, 0.14399083913303912, 0.16299980896292254, 0.09219057144946419, 0.0754995811439585, 0.09570897484081797, 0.21066851826617494, 0.10958957063849084, 0.13113883032929152, 0.12921028537675738, 0.24965595512185246, 0.10797288356116042, 0.30433119158260524, 0.09801664593396708, 0.07691296428674832, 0.3007033362518996, 0.18066062300931662, 0.1252145177568309, 0.08680037513840944, 0.08142198639689013, 0.11530914693139493, 0.11837176774861291, 0.12425823078956455, 0.09785827161977068, 0.13111748616211116, 0.15006398200057447, 0.15260111773386598, 0.19410253531532362, 0.10746465341071598, 0.2180143998702988, 0.20094497362151742, 0.13537401478970423, 0.11947974970098585, 0.14172244991641492, 0.21173007145989686, 0.10737285716459155, 0.08839001093292609, 0.1402493758359924, 0.14386949798790738, 0.14358739281306043, 0.12120778119424358, 0.15285120665794238, 0.14655543433036655, 0.12577187066199258, 0.12652575911488384, 0.24005631945328787, 0.0916767529270146, 0.14458448305958882, 0.09764660368091427, 0.2139862152398564, 0.1537954856758006, 0.18606421508593485, 0.11742544782464392, 0.16535482165636495, 0.08871934638591483, 0.16235572868026793, 0.09178817897918634, 0.0819597985537257, 0.18119712156476453, 0.09498334737145342, 0.18553056637756526, 0.11959481969824992, 0.09374910383485258, 0.11438438639743254, 0.14590802922612056, 0.20718944870168343, 0.17066070256987587, 0.13676171220140532, 0.07225257373647764, 0.15660075936466455, 0.149292875721585, 0.12449050816940144, 0.26658030634280294, 0.09337893541669473, 0.21042096748715267, 0.17905025160871446, 0.11474632439785637, 0.06532977567985654, 0.1336364244343713, 0.15694103407440707, 0.22233135416172445, 0.16437800688436255, 0.07492902543162927, 0.2765920269303024, 0.16821424243971705, 0.1495694593177177, 0.13656121358508244, 0.1434755660011433, 0.1848193514160812, 0.18851377739338204, 0.08277432789327577, 0.12012489867629483, 0.14515273069264367, 0.10620725486660376, 0.07064676654408686, 0.11205936389160343, 0.09450472149183042, 0.09548296118737198, 0.152446765860077, 0.09937986731529236, 0.07376657726126723, 0.08797759946901351, 0.11167438962729648, 0.17686050035990775, 0.166101407376118, 0.11944931422476657, 0.19085458538029343, 0.1686087087728083, 0.06824169598985463, 0.21779364062240347, 0.08715829069842584, 0.1117543040891178, 0.19315154728246853, 0.10237582842819393, 0.2336735080461949, 0.09599786324542947, 0.08398821431910619, 0.1529716869117692, 0.11288449852145277, 0.1491460343822837, 0.12255978130269796, 0.2565012878039852, 0.1525408701854758, 0.09821450992603786, 0.15752172010252252, 0.1867678452981636, 0.12925488845212385, 0.14090668119024485, 0.14529118576319888, 0.1094941675546579, 0.1439415308414027, 0.12579713336890563, 0.12528742634458467, 0.17246842588065192, 0.25399947830010206, 0.1982472074450925, 0.2209787306492217, 0.2318567008478567, 0.2781040489207953, 0.13220853230450302, 0.10499371725018136, 0.16923766408581287, 0.09563717947457917, 0.1532611096627079, 0.12272959211259149, 0.1370410417439416, 0.2138281674706377, 0.10398380269180052, 0.18953957391204312, 0.08278383480501361, 0.07686017532250844, 0.11152804552693851, 0.06711230307701044, 0.09298880322603509, 0.1584500281023793, 0.12653154786676168, 0.16629616176942363, 0.12392137738061137, 0.16935489373281598, 0.1754415436880663, 0.07255327713210136, 0.18887536658439785, 0.08341592940269038, 0.17840905085904524, 0.11798596227890812, 0.14628683624323457, 0.14608184021199122, 0.18480572558473796, 0.10146643035113811, 0.14592449006158859, 0.13163354597054422, 0.20325124205555767, 0.1850949999061413, 0.23790612467564642], [0.02433561418001773, 0.053576984064420685, 0.11200045220903121, 0.017824633869167883, 0.017809909659263212, 0.04625271751137916, 0.03754198922251817, 0.018925984732049983, 0.02171893876948161, 0.03563928956282325, 0.04665794127504341, 0.0951689065550454, 0.027180383112863638, 0.0035918556022807024, 0.011312314909446286, 0.030520715590682812, 0.07802021893439814, 0.03620469105953816, 0.030801861539657693, 0.01434740854165284, 0.040837143460521474, 0.025394291551492643, 0.03394845080038067, 0.03328515631437767, 0.016395986604038626, 0.059251627026242204, 0.044378687016433105, 0.026977526322298218, 0.06826517754234374, 0.03628228630986996, 0.01160347706900211, 0.09147451768512838, 0.023753121022309642, 0.025976881188398693, 0.008882573511073133, 0.04238746769260615, 0.03694926926982589, 0.018836337003449444, 0.025260864531446714, 0.01679297067312291, 0.041828352186712436, 0.0397447725845268, 0.017485902826592792, 0.04329659488575999, 0.03411793877603486, 0.03426912167924456, 0.035993561177747324, 0.09415951892151497, 0.04608531125995796, 0.03378838438948151, 0.031864655975368805, 0.050767020002240315, 0.06850489866337739, 0.051245215436210856, 0.021676233736798167, 0.03439517175138462, 0.057464579949737526, 0.03238500539737288, 0.036279228661442176, 0.03742686356417835, 0.05736285005696118, 0.03406299387279432, 0.031270577892428264, 0.003052985189242463, 0.01521976046205964, 0.07041494929580949, 0.047307873392128386, 0.012055781753588235, 0.02260577184642898, 0.0379950666683726, 0.010537245561863529, 0.04580534718115814, 0.008338432689924957, 0.04151948887738399, 0.036700742566608824, 0.028174122562631965, 0.015773105769767426, 0.05700486770365387, 0.022187293325259816, 0.051966315804747865, 0.02366440097830491, 0.08628091629361734, 0.036454119472182356, 0.033635216241236776, 0.08059132276684977, 0.03139991567877587, 0.057670730020618066, 0.039309836938627996, 0.02807981971272966, 0.09784490554011427, 0.024037588082137518, 0.030476298052235506, 0.045847801739000715, 0.075749825919047, 0.05301924895320553, 0.15022860519820824, 0.046134719741530716, 0.06382413615938276, 0.05763726287113968, 0.03006766040925868, 0.03361455484991893, 0.040019140869844705, 0.029360391818045173, 0.07447782933013514, 0.024145503775798716, 0.03957955566875171, 0.07160438937717117, 0.0824695649498608, 0.05485888090333901, 0.047701868461444974, 0.004970119853169308, 0.06521054965560324, 0.01299833713346743, 0.06091659452067688, 0.08314995851833373, 0.10408049711259082, 0.06291334284469485, 0.03935456246836111, 0.02485963352228282, 0.018295530280738603, 0.05841801335918717, 0.06844321876997128, 0.027435062220320106, 0.0242123453062959, 0.03829667919490021, 0.022489930015581194, 0.04744666613987647, 0.06009921904478688, 0.009003242084872909, 0.02817954395140987, 0.05594838708930183, 0.032339418976334855, 0.032576104713371024, 0.034734785949694924, 0.009929827374435263, 0.027396173682063818, 0.05385070668125991, 0.04511922423262149, 0.04377086806925945, 0.02820714256813517, 0.007420234132951009, 0.016195306161534972, 0.009613163165340666, 0.03418538144615013, 0.08463173799100332, 0.040221045856014825, 0.023036798229441047, 0.06305015776888467, 0.03508074179990217, 0.048107697075465694, 0.03441502420173492, 0.046826683392282575, 0.07337598493904807, 0.0251271462184377, 0.00535312557076395, 0.025956180834327824, 0.053222875721985474, 0.036839624372078106, 0.03848893255053554, 0.0647809129441157, 0.07153924365411513, 0.003827737500614603, 0.005716315945392125, 0.09423347393749282, 0.04037507489556447, 0.05584292048297357, 0.06078172773413826, 0.053910182396066375, 0.041218288242816925, 0.03887319064233452, 0.03529542656906415, 0.049793622820288874, 0.02766256202448858, 0.054135587488417514, 0.050630561308935285, 0.09656639289460145, 0.05792955031211022, 0.033478122131782584, 0.05018684976676013, 0.020943284980603494, 0.03043671189516317, 0.03154829697450623, 0.0233543576541706, 0.041087314020842314, 0.022204427659744397, 0.04790798884641845, 0.013915256877226057, 0.05799882237624843, 0.015380787026515463, 0.04325120884459466, 0.028297612225287594, 0.05640117509756237, 0.048654849160811864, 0.0615091066720197, 0.031751871792948805, 0.05649021055432968, 0.03201226172677707, 0.03359230897331145, 0.04711249188403599, 0.04641696963517461, 0.02285607228259323, 0.044049470307072625, 0.05171456446987577, 0.08051123761106282, 0.02597018701635534, 0.03352809835632797, 0.058023803067044355, 0.04754923837026581, 0.02769257262116298, 0.035775039505097084, 0.10609955439576879, 0.041968562436522916, 0.04327397793531418, 0.036655976218753494, 0.01804929310310399, 0.042823687253985554, 0.003085776984335098, 0.05377797620894853, 0.06719402837916277, 0.021378363489930052, 0.023001574045338202, 0.017465961318521295, 0.03468098024313804, 0.02625455759698525, 0.05717151325370651, 0.04981662568752654, 0.025879040149447974, 0.0897246076783631, 0.011976281966781244, 0.013150918057363015, 0.03322746175399516, 0.02985273444210179, 0.03118180960882455, 0.04452397726709023, 0.059779282892122865, 0.06957412566407584, 0.017251985300390515, 0.033465765372966416, 0.0609165685455082, 0.021406999258033466, 0.019246158371970523, 0.04354315118689556, 0.04890565796813462, 0.037508752138819546, 0.06679422600427642, 0.06187486673297826, 0.015454737404070329, 0.03939472007914446, 0.019040501829294953, 0.028714493273582775, 0.05993877784931101, 0.021777711299364455, 0.051520886190701276, 0.047092220120248385, 0.049077272196882404, 0.0754148353007622, 0.06372765696141869, 0.024023088371905033, 0.046215921829571016, 0.037772715513710864, 0.033294845052296296, 0.032771723708719946, 0.07759985164739192, 0.08008046541363001, 0.0332617786625633, 0.02138916916010203, 0.032574245633441024, 0.03681658810819499, 0.03952711551391985, 0.06683832441922277, 0.04667069508286659, 0.041828901375993155, 0.019697193056344986, 0.06632716278545558, 0.05509787471964955, 0.03138134714390617, 0.06132943643024191, 0.04563181078992784, 0.017251345198019408, 0.034726351441349834, 0.03818708995822817, 0.03814097661233973, 0.03805288368312176, 0.031030285317683592, 0.02727050581597723, 0.028935207992617507, 0.00937591246838565, 0.052791880880249664, 0.04041699139634147, 0.0277433169685537, 0.03843585785944015, 0.07159456334193237, 0.009891894351312658, 0.07546832188381813, 0.053467769612325355, 0.072924818523461, 0.025196932219841983, 0.05003108781238552, 0.015480808124266332, 0.04593948295223527, 0.04406884407217149, 0.04486808888032101, 0.03569679487554822, 0.011942530945816543, 0.05348060505639296, 0.005695055733667687, 0.058124297283939086, 0.05792643700260669, 0.020844030150328763, 0.059507883197511546, 0.05278008815366775, 0.04213180895021651, 0.017608815469429828, 0.09120871007326059, 0.018710531840042677, 0.03198533660906833, 0.06378158141160384, 0.04045713045343291, 0.05320323478372302, 0.04528343182755634, 0.07563894163467921, 0.04017754486994818, 0.038104065897641703, 0.030335353076225147, 0.045079741976223886, 0.026149872101086657, 0.03548199878423475, 0.035866928519681096, 0.09625915117794648, 0.05004933351301588, 0.03920523122360464, 0.03325888428662438, 0.025681601036922075, 0.02959498840937158, 0.04644882632419467, 0.08371815420105122, 0.05299001575622242, 0.03861569508444518, 0.07120667985873297, 0.10991213770466857, 0.07687262856052257, 0.049073772970587015, 0.03078227997320937, 0.02856500617781421, 0.03202482999768108, 0.02403246169706108, 0.03985228009696584, 0.032856150428415276, 0.01339340089543839, 0.0054738266135245794, 0.04118408265640028, 0.09431545899133198, 0.11802905137301423, 0.0942165455489885, 0.2220153179951012, 0.12056602383381687, 0.16899438807740808, 0.1779539362178184, 0.14054874336579815, 0.1519866194576025, 0.09733452316140756, 0.14274312561610714, 0.16888723679585382, 0.21916723722824827, 0.10940884283627383, 0.13585829583462328, 0.10248847902403213, 0.16050905745942146, 0.2305997401708737, 0.1534123593592085, 0.14273248321842402, 0.0964457642112393, 0.13400525698671117, 0.12571007944643497, 0.12398987761116587, 0.1342331853811629, 0.10494121772353537, 0.13546906906412914, 0.24149503209628165, 0.20016254216898233, 0.09728718156111427, 0.17611195537028834, 0.1306897567701526, 0.12481991783715785, 0.17541873006848618, 0.1091350348724518, 0.13494432612787932, 0.11623450118349865, 0.20147651463048533, 0.08037676045205444, 0.13321267295395955, 0.12313001047004946, 0.15242929570376873, 0.1237619789026212, 0.11455929576186463, 0.09714706407976337, 0.25151141337119043, 0.11957975410041399, 0.09745657676830888, 0.2656407473841682, 0.15736319735879079, 0.10385578221757896, 0.15854819939704612, 0.18459264014381915, 0.196501023019664, 0.10861553892027587, 0.09702858020318672, 0.1644540621782653, 0.09226338355802, 0.1255537979886867, 0.14796621253481135, 0.16070786397904158, 0.16496299736900255, 0.15527007373748347, 0.25801788142416626, 0.11035025716410019, 0.09915973147144541, 0.17871312360512093, 0.09714055544463918, 0.09642548131523654, 0.09842487168498337, 0.0801276511629112, 0.13454350701067597, 0.1098664733581245, 0.1444617021479644, 0.14782998390728608, 0.23416341457050294, 0.10846892022527754, 0.255811209208332, 0.09794290614081547, 0.14050274505279958, 0.2897250128444284, 0.19674930110340938, 0.14036642736755311, 0.2497497625881806, 0.10717634388129227, 0.22546514694113284, 0.17272295284783468, 0.1635966738103889, 0.23469415405998006, 0.15616589051205665, 0.17997668939642608, 0.1180672348709777, 0.11854289958137088, 0.13609305198770016, 0.19853774341754615, 0.13030409230850637, 0.33682155597489327, 0.18392644386040047, 0.21439300122438, 0.1757045162958093, 0.08016763807972893, 0.20436851569684222, 0.1187872739683371, 0.13614852010505274, 0.17622250568820164, 0.18670991325052455, 0.10337708954466507, 0.19303039909573272, 0.14560720708686858, 0.09150513127679005, 0.14175324904499575, 0.13481421279720962, 0.25987090542912483, 0.12350028278888203, 0.13801089517073706, 0.1817779560224153, 0.1907411406864412, 0.16360568348318338, 0.18135082034859806, 0.14404954301426187, 0.12991338124265894, 0.12414919445291162, 0.15049098408780992, 0.13929521141108125, 0.11918995587620884, 0.16753342584706843, 0.18472373310942203, 0.1384235144359991, 0.10871464532101527, 0.13051337795332074, 0.15001652907812968, 0.228295297420118, 0.10450822650454938, 0.13088264095131308, 0.18716795195359737, 0.183577174320817, 0.16766275250120088, 0.14612638391554356, 0.14053366292500868, 0.0899834391020704, 0.10653819335857406, 0.082761926605599, 0.11024914696463384, 0.10135799515410326, 0.11818308412330225, 0.17200597882037982, 0.14173764910083264, 0.0907174008898437, 0.15644336468540132, 0.10381088228314184, 0.1361299812560901, 0.20447332179173827, 0.13305535248946398, 0.31565686978865415, 0.13573931471910328, 0.0879942013125401, 0.14412625139812008, 0.12595411244546995, 0.12411607240210287, 0.1380091140163131, 0.24503078690031543, 0.12515188049292192, 0.11304558167466894, 0.21854681661352515, 0.1454836394987069, 0.12375784514006227, 0.21576820086920634, 0.09290319649153389, 0.15799054963281378, 0.24734480335609987, 0.10987293004291132, 0.1485688067623414, 0.14186216663802043, 0.08493016299325973, 0.31102494802325964, 0.16683555470081046, 0.2513132896274328], [0.06821353148552589, 0.016073720107669942, 0.05845733976457268, 0.05878030016901903, 0.049647078340058215, 0.03029153296665754, 0.024417215172434226, 0.028425686505215708, 0.021824281066074036, 0.04499465103435796, 0.06621805965551175, 0.026004952924267855, 0.020264956438040826, 0.013627750722662313, 0.020079738642380107, 0.03562680663890205, 0.03533037059241906, 0.04241427406668663, 0.032515423008590005, 0.04132692381972447, 0.05007315645343624, 0.04122264464967884, 0.028940471675014123, 0.03941811628465075, 0.011793859284807695, 0.011245140340179205, 0.07064747900585644, 0.012349421758699464, 0.09346925478894264, 0.036973259193473496, 0.006850818081147736, 0.07042634868412279, 0.022679294561385177, 0.06644103792496026, 0.02533955073886318, 0.026230495313939173, 0.0700255815172568, 0.034926467851619236, 0.04343410371802747, 0.007348085782723501, 0.020856997325608972, 0.021265089490043465, 0.1031750843685586, 0.05409009012510069, 0.02798339988657972, 0.04012808814877644, 0.05704397146473639, 0.0326977686927421, 0.01131561839429196, 0.05700401794456411, 0.0528216632665135, 0.009574598389008315, 0.10046240102383308, 0.027094588986074086, 0.02480931405443698, 0.0065313624691043515, 0.09805626919842325, 0.022211611649254337, 0.03959238740208093, 0.032851845971890725, 0.041531404058332555, 0.054473216441692784, 0.008877102955011651, 0.03725691174622625, 0.07572735368739814, 0.05700954694475513, 0.012140807757532457, 0.032685619735275395, 0.019522116708685644, 0.03890337378834374, 0.11434114145231433, 0.040352877258555964, 0.01596022160811117, 0.026106695804628544, 0.027279623100184835, 0.023643988206458744, 0.002811794847730198, 0.05779317696578801, 0.0038385948892027955, 0.062378862930927426, 0.0386421378061641, 0.06394005962647498, 0.03236207674490288, 0.06223914249858353, 0.050642279820749536, 0.07117694200132973, 0.04784283570188563, 0.05775368357717525, 0.031026270298752934, 0.033562916214577854, 0.025692466078908183, 0.03522254766721744, 0.026388954975118395, 0.029220404212537687, 0.058892345914500766, 0.026818283695320133, 0.028525191810331307, 0.011336439347360283, 0.020118167049076874, 0.0036917336046826676, 0.05344646255252883, 0.033310162980342284, 0.027690279384842142, 0.0395309338637162, 0.06305993185378611, 0.0649197019811254, 0.014624803861806868, 0.0019649614432637463, 0.05107710043375846, 0.054227246437221766, 0.07114646941772662, 0.11778253960073926, 0.028902143458253704, 0.03536350377544295, 0.048031831029220484, 0.025707119784783572, 0.06336107311653905, 0.0018293599305252428, 0.022253518873185385, 0.08823978540021926, 0.043008997818105854, 0.03716044368047733, 0.06502125004772097, 0.0558715970691992, 0.051221069661551155, 0.02088626948534511, 0.010764955950435251, 0.025310293422080576, 0.03767190588405356, 0.03531308226229157, 0.007721479296378675, 0.020912578620482236, 0.037252009860822, 0.011435096748755313, 0.05296207389619667, 0.01924736992805265, 0.06662564715952612, 0.033174498385051265, 0.07392009792965837, 0.0349104745691875, 0.024776223544904497, 0.07460557520971633, 0.0240899558775709, 0.009627329836803256, 0.061112328548915684, 0.04932665979140438, 0.04765623380080797, 0.05428226926596835, 0.016475535558129195, 0.011596088061196497, 0.02715411665121792, 0.01857536262832582, 0.09184155424009077, 0.020707014846266247, 0.03634733184298966, 0.047438984911423177, 0.047236115133273415, 0.013124940105626592, 0.015339071833295748, 0.08450236680801027, 0.04458897456061095, 0.04988954540749546, 0.02947146349470131, 0.049561204432393424, 0.018087593489326537, 0.058565893705235794, 0.03134697828500066, 0.05285117105813697, 0.042614668782334775, 0.02578393578005489, 0.08408519817749038, 0.08124306943500414, 0.011323808921588352, 0.02953284652903676, 0.025832270002865698, 0.009515359233773779, 0.05669849429978058, 0.025190941232722253, 0.01907059962832136, 0.03666021759272553, 0.052176002209307626, 0.019082657672697678, 0.06378919584676623, 0.03649171667348128, 0.03305940241261851, 0.012691476695181336, 0.03799116297159344, 0.062104108728817664, 0.03658624773379415, 0.005781682921224274, 0.016114335994643625, 0.0321072232327424, 0.036171609826851636, 0.03026963589945808, 0.036373180846567266, 0.026573723771434743, 0.032060835292213596, 0.06873208491015248, 0.0634819689730648, 0.02300227166415425, 0.0638004245411139, 0.04999848526495043, 0.050523276440799236, 0.022036891532479785, 0.04171949767624028, 0.06082447915105149, 0.10255113855237141, 0.08376594851142727, 0.03520276572089642, 0.02185504123190185, 0.054864654812263325, 0.018875828536693007, 0.032083864134619944, 0.0032118024728333694, 0.06769307074137032, 0.040868862852221355, 0.009779726151464274, 0.13253813493065536, 0.07148014643462375, 0.007309099373742356, 0.02094832045258954, 0.05398004075686913, 0.08114607815514319, 0.060113791114417836, 0.014651385736215161, 0.023244234071171377, 0.03445580521656666, 0.009399776226928225, 0.032361761332140304, 0.013785175087832613, 0.04208205165923573, 0.03231611553928815, 0.04836797197640408, 0.005640626623062417, 0.029984419270476792, 0.0460690582258394, 0.04127091022382956, 0.012449299065337982, 0.029949731288070325, 0.03124281414784491, 0.04679229969042353, 0.03141576053167228, 0.04195003471977543, 0.018423266883473843, 0.04376996264909394, 0.03836912765109446, 0.17015390476444736, 0.05492126954777632, 0.03121005203865934, 0.06522591211250983, 0.018789986170304473, 0.027789742016466334, 0.03887059683620464, 0.02830037301464472, 0.0665025322814472, 0.08171687135472894, 0.05936360597843304, 0.029128502210369334, 0.012361049357423326, 0.053302433952922, 0.02607644029922085, 0.04599411986419, 0.026614261732902378, 0.02706864535866771, 0.03405703813768923, 0.022933168438612483, 0.06367205525748432, 0.010810548865265446, 0.02417130453977734, 0.013111249336361652, 0.13596734701422974, 0.02340603339689551, 0.026581521888147108, 0.03212518320651725, 0.04812451785255689, 0.02776034925773274, 0.0668609376589302, 0.06914368001162075, 0.029295307322172448, 0.07481250082491897, 0.0388788383861538, 0.004331242953412584, 0.03669444173283409, 0.02695177750865696, 0.025813927823037375, 0.1358653759234585, 0.026149230143346358, 0.028015898533340078, 0.0898818984569516, 0.06645588087849319, 0.03705237584654242, 0.046586554090026766, 0.05360399452911224, 0.030045683561183978, 0.04331113726948388, 0.028984620184928644, 0.09310130539233796, 0.021522562783502508, 0.021024693014624063, 0.025326895265607163, 0.02319651026482461, 0.09419758367585018, 0.03671937789476942, 0.06358097889460623, 0.05742154651670717, 0.040460336531396024, 0.0459650165430503, 0.016061560017988086, 0.039536195690743625, 0.0789220174192451, 0.05437327883555554, 0.012223308604006888, 0.03785505308769643, 0.06200037503731437, 0.08809627630398609, 0.03363619587616995, 0.015356605072156526, 0.07431811915012076, 0.018330409366171807, 0.041026001490536146, 0.058743537883856334, 0.0059705390958697535, 0.04604396250215359, 0.032697969072614796, 0.042943748194375075, 0.04164248130109627, 0.0213208322020364, 0.0328162637015339, 0.06523663614643738, 0.028891578986076638, 0.003652172727015568, 0.019677858253999148, 0.05702768874471076, 0.011162728551425971, 0.05120404479384888, 0.0227754305160488, 0.02822367947374005, 0.03545078405295499, 0.0446824480604846, 0.046822631265968084, 0.07236172139528207, 0.021202086718403734, 0.04215004351863172, 0.06054760240658652, 0.02992078381794272, 0.060263708655838855, 0.0605602003633976, 0.05865055420144927, 0.03220167265681084, 0.020289261774451006, 0.02266334580781404, 0.02110913828801131, 0.0926213213824667, 0.0816129038867075, 0.11207362054847181, 0.20204016094794497, 0.1872588650439866, 0.15509888995438814, 0.10105412278790027, 0.1324797427514568, 0.1343549569719471, 0.06383031082805246, 0.12979319784790277, 0.17529599368572235, 0.21595771569991484, 0.12381266758893616, 0.08671285366290249, 0.146779399656225, 0.13128907070495188, 0.1511236946680583, 0.15152659179875627, 0.09554288219078444, 0.16285736113786697, 0.1659326726803556, 0.2490978006972, 0.09571345741278492, 0.16386344621423632, 0.18241970596136525, 0.12999221216887236, 0.17648598295636475, 0.15319321799324825, 0.17837903840700164, 0.19613560434663668, 0.2049008582253009, 0.06807771846069954, 0.18585770507343113, 0.12330863799434155, 0.1389647924224846, 0.13527182105462998, 0.14333506260300055, 0.14228912419639528, 0.09568290319293737, 0.07854131792555563, 0.15353542228695005, 0.18315187917323783, 0.12446923821698874, 0.11190686738700606, 0.10989535774569958, 0.22456751932622865, 0.13837503734976053, 0.08592821061029099, 0.12542261596536264, 0.11711809478583746, 0.09411963590537198, 0.18264699610881507, 0.10024764575064182, 0.1578672492178157, 0.16424838337115943, 0.16514903894858435, 0.07694460946368054, 0.07201982880360447, 0.09092001462704502, 0.0696039674221538, 0.12048164164298214, 0.07877870870288461, 0.11743591210688464, 0.17395110335201025, 0.06959069782169536, 0.1138476058258675, 0.11177627166034654, 0.13943434925749898, 0.12188004824565724, 0.31878273643087596, 0.08601450754213147, 0.11026067251805216, 0.08311742276418954, 0.0540543668466853, 0.11535274810739793, 0.10199989352258854, 0.18411238153930753, 0.14046731492271647, 0.1753178276703693, 0.17116361152147874, 0.27084658679086715, 0.10670709132682532, 0.17155527253635228, 0.26554061681963503, 0.20411159901414067, 0.11946642815019004, 0.15514733735471964, 0.12947030423674732, 0.12260816933121532, 0.12392862074193545, 0.10342091336497106, 0.07371222978690639, 0.1618321138084866, 0.2544913737801835, 0.10468692082213238, 0.09756430692505091, 0.1187053853936959, 0.07159142405726016, 0.09282311133574694, 0.10472309309989214, 0.10570580052444711, 0.15616606862749904, 0.20202724757837132, 0.21894379140576348, 0.1586670320830308, 0.08389980968786404, 0.0866999699792359, 0.14832391287200153, 0.3703466523438692, 0.1811473976704292, 0.3250319167273119, 0.12725818465696648, 0.09936892805853859, 0.11910308749065734, 0.18665975891053677, 0.12838935130275786, 0.14370790275279433, 0.11127645746455528, 0.15450517181307077, 0.1498554681893438, 0.23451072484022006, 0.14170573675073683, 0.10610713914502412, 0.07690657439525239, 0.19046338449697942, 0.14156671764794737, 0.11831999552669004, 0.12431147988536395, 0.16365800489438698, 0.10822497628396377, 0.12153263407526538, 0.1781329867662862, 0.18560178286861628, 0.17990275664487854, 0.06394938842277043, 0.1022228792135138, 0.18678725988138467, 0.1454576791729778, 0.10750872956123203, 0.11296659489744343, 0.17922958417329937, 0.1430862650158815, 0.14738604601006955, 0.2054862939985469, 0.1364944945089519, 0.11984904980636202, 0.15293362957891077, 0.1572283639688976, 0.09200205851811916, 0.09646880789659917, 0.12304522751946934, 0.23591262695845217, 0.06301946996245533, 0.17465682642068714, 0.22122320893686265, 0.14433712523896247, 0.21834774292074144, 0.1262633505393751, 0.1301794857135974, 0.11989614649792202, 0.15111777232959867, 0.10974700984661467, 0.18008140643360093, 0.15677765768487006, 0.11166438547661528, 0.13025319582084194, 0.16098140476970002, 0.14558847527951002, 0.09478186912019737, 0.17514848441351205, 0.18840333097614348, 0.08624231719295494, 0.17468366248067468, 0.13676805014256388, 0.10181122474023141], [0.039036014131852426, 0.02198227317421697, 0.11979697330389172, 0.04733091336674988, 0.03732126337126829, 0.007088881893650978, 0.05612695895251818, 0.028083868128305767, 0.033509210697957315, 0.06282320158788934, 0.018478436286386568, 0.06180559466884006, 0.07579102253657766, 0.05553476592467632, 0.03892804277711548, 0.04046320122142788, 0.06053174642147496, 0.008707601064088522, 0.06281082256464288, 0.058392680148244835, 0.06361412320984527, 0.018878704358940013, 0.0154798414769175, 0.03713561141921673, 0.015454642780241556, 0.020770930459548254, 0.020656678680097684, 0.024906012185965665, 0.07561416874523275, 0.05189167430216912, 0.01595413043105509, 0.08221890457207337, 0.005974137120574596, 0.049365956510882825, 0.05924648394284304, 0.02456205456837779, 0.01737692771712318, 0.023476292517443653, 0.04163961661106441, 0.03190882118360605, 0.06858128050225787, 0.025688669993542135, 0.01968181019037729, 0.0395923057658365, 0.0719234609277919, 0.025033594793058, 0.018089452569256537, 0.02844932947482448, 0.08414756826823577, 0.02605358215078013, 0.06714524701237679, 0.018364716997893993, 0.029956043254060205, 0.06819307047408074, 0.008838304402161157, 0.07148917095037177, 0.05588327105215285, 0.02965846986626275, 0.022947443649172783, 0.10032562320702709, 0.028469367462093942, 0.03867313360387925, 0.030250944910221733, 0.02783016680041328, 0.030086605584074277, 0.020493250340223312, 0.01256799538168707, 0.01692122492386261, 0.03237885299313348, 0.04064625936734956, 0.07704928939347155, 0.03241659862396773, 0.04224551339575555, 0.08283567382022738, 0.027853050924022682, 0.03705852082930505, 0.03728836767550092, 0.014280307259468827, 0.04117876145755872, 0.03275036840932444, 0.006542682076542405, 0.07929961473564617, 0.05232039446127601, 0.03214410426153336, 0.05806089931866154, 0.018835099472198635, 0.008844557924021501, 0.1063212932785973, 0.08314791019074619, 0.0368658963998314, 0.005907914355702815, 0.05646327801514417, 0.04970918867911678, 0.04291088589525316, 0.0017761332151167153, 0.065904042130569, 0.05679530375346076, 0.04342856729635969, 0.021755059096904006, 0.021945727967249695, 0.0674582774809096, 0.03164749243296683, 0.02284139260154916, 0.07156412786571309, 0.06675346725387499, 0.025611011660657823, 0.01822651054681046, 0.12219843702041544, 0.02306955477251904, 0.018158153179683723, 0.024586862709838897, 0.05648998048854992, 0.08586679789004847, 0.010809707455337048, 0.11586695254663937, 0.01998939329496352, 0.027118879479530733, 0.011528919985721586, 0.06286217918386683, 0.01581976088345982, 0.022200238236109726, 0.06569716104422696, 0.066346503153909, 0.03805693952017464, 0.014413444841920864, 0.09574181487550959, 0.10983375948853791, 0.011620750556176063, 0.02992897898366209, 0.057708219610503875, 0.038979184173513204, 0.02517031509341905, 0.018642126233316958, 0.04974717921868432, 0.026693658546719234, 0.03646828336059116, 0.08988930509076454, 0.01789657024346525, 0.04238471432472579, 0.12461512960726395, 0.002769379252640647, 0.03189174436556641, 0.03483918015263043, 0.04988042441254947, 0.06964357584365644, 0.017813859740272164, 0.04550143399683293, 0.03929572871129494, 0.03871947330480907, 0.058669887148425914, 0.045004484491073526, 0.06809334809076972, 0.04262408292561304, 0.0024711541664146353, 0.029906959462095983, 0.043488822266226634, 0.027480915814521722, 0.037999775595380925, 0.020848303065577056, 0.028621346318686847, 0.0055011803215165855, 0.0372755804710323, 0.0558362745505292, 0.02139940894267056, 0.06989800633164123, 0.011970123996434268, 0.02525749703636393, 0.010428237055748468, 0.02049703529337421, 0.04048401475301944, 0.08179331998690031, 0.03923258678696584, 0.040924794811871834, 0.026929602136078756, 0.04150383327214513, 0.013465208321576938, 0.05125277049955912, 0.010757382333395071, 0.046667503847857006, 0.010352214230806567, 0.023692556205787696, 0.02302674954989925, 0.039256977470358834, 0.03042652220756281, 0.006383677400663146, 0.018498871322663035, 0.023897234968899284, 0.06440744939027354, 0.0624144118046388, 0.07894203314208426, 0.01862860059191007, 0.039723584268358536, 0.0362918377504684, 0.067501611483749, 0.040121894926414825, 0.11671700107399374, 0.06243378185899928, 0.05845345833222382, 0.003468444328973419, 0.057941153791034594, 0.021817442175233737, 0.03612150743720122, 0.033932676451513544, 0.05727116142224986, 0.09959780640201643, 0.020155658494331874, 0.08645604088087566, 0.01073647696102853, 0.022095183521742, 0.034580322753754444, 0.03308162231405731, 0.007008793954810244, 0.02420558248559246, 0.05884875215997454, 0.03087429329752922, 0.037305893492884934, 0.027675866876961663, 0.03684998104290571, 0.010961956268147333, 0.029280618364282418, 0.04646583263820503, 0.03302240264019929, 0.04318484599934891, 0.03625208089943044, 0.008932995951909106, 0.03021238106157398, 0.034508738899603486, 0.02135189850378083, 0.03363037001690827, 0.025145492109004408, 0.05080321825516876, 0.035317891379236244, 0.030753801911487244, 0.06739226344507188, 0.007247408348121098, 0.06199604460562114, 0.07238531426992267, 0.03082498315052362, 0.05958658795861993, 0.024223891268775333, 0.009710031063150382, 0.01698770465736743, 0.039491440475103445, 0.01447843378628022, 0.046495607602992095, 0.0441774202772649, 0.04599937798047904, 0.009537359273963375, 0.023131702218961436, 0.02540983954531839, 0.08512142187100835, 0.00817039561297861, 0.02603138636914082, 0.03933554864488542, 0.02170795683923643, 0.04415025396156125, 0.01802616592613049, 0.0671036347921472, 0.044497278504422866, 0.025418372388230637, 0.054817958880448714, 0.050349669545539655, 0.020954680658178404, 0.044596496227313764, 0.026747662777779624, 0.019439812531345524, 0.034405858677928336, 0.024488064300385304, 0.014607148168579442, 0.024594844508101232, 0.03604745594202541, 0.11827738140709698, 0.077484967187047, 0.044121963292127475, 0.037440021842485294, 0.1272164165857248, 0.01852026929554995, 0.07312436719075777, 0.0436439311306458, 0.034268127201357856, 0.0846583662496414, 0.058698957072920166, 0.0024660245344421128, 0.00675847403726948, 0.015827579409233294, 0.013303587111295201, 0.00393442725908244, 0.02479225950082764, 0.06693236195133068, 0.036524475071928464, 0.04182950622634962, 0.060651083767879754, 0.03054607292142464, 0.060003782564308494, 0.052669560100184754, 0.02124577138602035, 0.023220784059958532, 0.02673937113286229, 0.0435811639908934, 0.04636804726033006, 0.010313683778804261, 0.040766787860775366, 0.051320484053576365, 0.013578468406194588, 0.026672681742638815, 0.041288829379482195, 0.04731428554805461, 0.0855684099951759, 0.032895153999561444, 0.014972436965763336, 0.03906435304088518, 0.03876911556289997, 0.0882533889671322, 0.020408857017173432, 0.02084067749819951, 0.010516449656279292, 0.031243864286807366, 0.029106742440490052, 0.02639771602844121, 0.01741990548907779, 0.043088433594675735, 0.026477342908037826, 0.05571193512878381, 0.041114339328487404, 0.04644233995350078, 0.033491287831566297, 0.038612407370237634, 0.022464040193881374, 0.025011285833898, 0.025483011595497373, 0.02567958796134917, 0.01853509369539097, 0.07482536966563202, 0.03118363158137072, 0.023968329005583655, 0.04567211311950814, 0.029617199033964425, 0.02697439816984115, 0.07215733392513357, 0.01773307696566917, 0.04110477304493543, 0.027622634479484987, 0.024712632621231023, 0.07602928904816508, 0.03791485905821901, 0.03597261405957397, 0.04815463049453683, 0.009871041856968077, 0.07229451992316172, 0.04799794827704318, 0.01424980684532784, 0.07586783482111059, 0.17541582084959373, 0.19558215513825417, 0.19640815065940842, 0.1255355856847018, 0.1497290062252432, 0.06334461228107102, 0.10012710612500086, 0.11279604936135001, 0.10330959863495082, 0.10399014805443585, 0.13487552903825417, 0.14909518242347986, 0.1570725574856624, 0.31826872495003045, 0.09282756422180682, 0.14048903016373515, 0.13804580579744652, 0.12204628190374933, 0.11089041450759396, 0.24825304368278012, 0.10086000664159656, 0.12825603189412504, 0.11304258339805529, 0.14581432566046715, 0.1701726217288524, 0.1822105687460862, 0.12970277457498014, 0.16848677390953526, 0.2794815937522799, 0.10145154286874458, 0.16048679302912205, 0.1856479889829643, 0.1780611468711868, 0.3023306583054364, 0.1508385466877371, 0.06976721022510901, 0.1409073788090609, 0.07876044444856234, 0.12025761694530956, 0.21013679914176464, 0.1660893252119422, 0.12629483244381845, 0.10783292935229838, 0.1014669201686047, 0.17355779476929456, 0.1007715352170635, 0.1053479962865822, 0.11019152661901899, 0.16358160821255296, 0.08395854325499386, 0.15748550329590216, 0.14166947541525587, 0.1287263457197696, 0.18183412175858393, 0.11958058530581184, 0.21446562779601663, 0.12179622266557999, 0.12603482842678204, 0.09819538478041068, 0.13290399889228866, 0.17697629024041817, 0.1182419215911068, 0.10153181356145069, 0.17700630269246176, 0.06573938182555139, 0.10394273223937489, 0.236188824637793, 0.13254128163680434, 0.1922356034629047, 0.11991039573331363, 0.20627642894396558, 0.11408006874262355, 0.10859872185392305, 0.13455045351292938, 0.31472891801968217, 0.17272442230023444, 0.24893935216823593, 0.11056176183046773, 0.12342695117695257, 0.11397486930945888, 0.11549144066520967, 0.21316703263437375, 0.08774642046773806, 0.0840820737357717, 0.16344607720384374, 0.13708629790926352, 0.23807698191376403, 0.27720477373804897, 0.16231955640250817, 0.18817072705132887, 0.14605313393985853, 0.0962952863483224, 0.07222168555017561, 0.09347377446829341, 0.14302159426733851, 0.21735105343395844, 0.1768829725915566, 0.14022492949152365, 0.1305843866430223, 0.2943603484891355, 0.1245278975693509, 0.15129064820939675, 0.11808028182713315, 0.0737727370869834, 0.10175297356909141, 0.1304810945293866, 0.14376659179106355, 0.22568053303984925, 0.11760817942558788, 0.16169989277841523, 0.10414782474981621, 0.16349841345800087, 0.1685649814317003, 0.16723039210774004, 0.2184111817041412, 0.1053419552044943, 0.07872528149164282, 0.11873766139615327, 0.12440548031008802, 0.14393641002243385, 0.15267974085872993, 0.1329533665557392, 0.16249701875494793, 0.11477609194116667, 0.12421967621776275, 0.10841018665814772, 0.17381484503857791, 0.10968115908326581, 0.1722556521417573, 0.25912246434018016, 0.07983317438629456, 0.18859004048863426, 0.23469603911507875, 0.11748823351808824, 0.09028708882397041, 0.16206989792408422, 0.17597566737094894, 0.1610696906573139, 0.11036593132303096, 0.24202820583013818, 0.14890065067447722, 0.18145212350646034, 0.10690712981158867, 0.07087633508490399, 0.19225993106374517, 0.08705174055648968, 0.1519168130471371, 0.1314657018519938, 0.13857375481165946, 0.18345595191931352, 0.10461226818733849, 0.15309276088373736, 0.11027751184883527, 0.07794990786351264, 0.07988432320416905, 0.10833760461537167, 0.1516088069183752, 0.17418299481505528, 0.09957403541193344, 0.19903962820535526, 0.1284745943848975, 0.11009322915924713, 0.1525356899946928, 0.1852805813541636, 0.1278187139541842, 0.12388503440888599, 0.1019119935517665, 0.12383926616166718, 0.15776857326272875, 0.12489043670939282, 0.12094539488316514, 0.1312814562697895, 0.1450301575823687, 0.13289390568388626, 0.19367465749382973, 0.10632401696057059], [0.007566945596408914, 0.013393701465247432, 0.018370147663517855, 0.022033451677998528, 0.02899811057432089, 0.02758700582489837, 0.04018833569716662, 0.08444357386906631, 0.04472018998058047, 0.03728721734660212, 0.026301144062017556, 0.037092158672749065, 0.020971410522179212, 0.04916648205835372, 0.037519676552619785, 0.028516376951301936, 0.0620978821098106, 0.04616430916939862, 0.07208271097624674, 0.04129724904487375, 0.05548377666855231, 0.02218187008111272, 0.05411713398643769, 0.02871406468329951, 0.050360100431134924, 0.06367441528709605, 0.018618598296598066, 0.04324296358390711, 0.005389612797443988, 0.026847030785575043, 0.01707346353214234, 0.024006466119317338, 0.013084166512271622, 0.07187498384155333, 0.01662583716097288, 0.03804233034315985, 0.06247205441468395, 0.03580017604690511, 0.035984978239866905, 0.11803229455836117, 0.049147538738907315, 0.019264739894424565, 0.0837005653011147, 0.06283885348238982, 0.06609876683796756, 0.02173470569687197, 0.026870135698118247, 0.024090983752103057, 0.03713035330292769, 0.020415538201632444, 0.07787236085277982, 0.051732450228882954, 0.05851100817380939, 0.05885121980099939, 0.01013282424537465, 0.07095002292771824, 0.021478225025930442, 0.010051321587525308, 0.03644197422545403, 0.07188529227278195, 0.03288822605099995, 0.040366729444940574, 0.0731368649576325, 0.006813630916440161, 0.027560010203160346, 0.03754311357624829, 0.027380056089896243, 0.02481161842297297, 0.03191585674358066, 0.003396926572349912, 0.11619716373388655, 0.09447148069739342, 0.03412660335015971, 0.04402695354656316, 0.04696461524872575, 0.026346778722654562, 0.03623165328463074, 0.020356082895887084, 0.060280440375208855, 0.05469959745823871, 0.03059841474168934, 0.04946176406519953, 0.008965778470155783, 0.04534271458396688, 0.03798412741161883, 0.010473021957295714, 0.012775810646417085, 0.05193205455725547, 0.02510810641979333, 0.0260392253039754, 0.0340681332454551, 0.05478423569002189, 0.015275236000888981, 0.03590993597754277, 0.029486096791515592, 0.016547566556255333, 0.07184350935858674, 0.028206277966091875, 0.04929637645545881, 0.040120781704899855, 0.02036364166997373, 0.005711127869290067, 0.016194311683648266, 0.06656968922470696, 0.030474956620309968, 0.0698950451624114, 0.021739058392995503, 0.03356662695296109, 0.062386173085542396, 0.01433825043932302, 0.024134369705279823, 0.034013121548923664, 0.026990309816028457, 0.019196267494407948, 0.03866959727020003, 0.09772310426342301, 0.07963133248267695, 0.05106155986140948, 0.02128178224666044, 0.009883473758236505, 0.048254037465085275, 0.015737332396383863, 0.051014173732255585, 0.029799169933539815, 0.03421939407417085, 0.13900194433517754, 0.0191599152458366, 0.030095644942775834, 0.06652659270912409, 0.0454901978810085, 0.02702604979276657, 0.022303623118204996, 0.059443030622787774, 0.04982779501006007, 0.011940682998101693, 0.008950159044616157, 0.01681801259110216, 0.02100124300341122, 0.054867627113708295, 0.06494767352705821, 0.009066940619959496, 0.027140353522554506, 0.11689064136589877, 0.03240053112676833, 0.10860177208087407, 0.10860479262191802, 0.008542774703528266, 0.027685186396411154, 0.012407165486365557, 0.04648957765311934, 0.036613803677028045, 0.01578513783897506, 0.028028155102219898, 0.03757946025871206, 0.008111348488455405, 0.0717421319859568, 0.03949402685975656, 0.042263558716513216, 0.026198981868219562, 0.05970406622509472, 0.035066114069195464, 0.05541135047678836, 0.03503689942590427, 0.021963285325909965, 0.023631720505363774, 0.07673214742681012, 0.035766571600106545, 0.09582629354554228, 0.043996098756906576, 0.011184890008735238, 0.034823324167518876, 0.04680139471020084, 0.01988620322663337, 0.11902942191227339, 0.1219051105726976, 0.019844359085254837, 0.04508710037043784, 0.03508684225380421, 0.04857386229559779, 0.057768352126004174, 0.02674507639312651, 0.022380735972546972, 0.05357013033062685, 0.02455443456710782, 0.012422928703017533, 0.008812388605292654, 0.03376821652636863, 0.02587736104032956, 0.002262121315652621, 0.014634527851740131, 0.06794097032980062, 0.0689346986473538, 0.054482786435983144, 0.04443595855263993, 0.050437665995559655, 0.03588353778468445, 0.045456764128175564, 0.0314178793632891, 0.059117246346431784, 0.01609409948287066, 0.026228523056488484, 0.03604452816944104, 0.004198811802780256, 0.05809045163914561, 0.008198320774681633, 0.06754657821147703, 0.03421756096940953, 0.019990122455055825, 0.029299296365934424, 0.04217715046252124, 0.016235747643804643, 0.10569807476713322, 0.056943180388771, 0.041578088857932016, 0.026067508551932406, 0.11348989806720056, 0.05133909340656828, 0.0750767721910961, 0.025488522041996475, 0.024528067915525753, 0.01836397856095573, 0.013785725204797927, 0.03015954942384269, 0.07282205333467573, 0.022918928480066825, 0.058465136025915854, 0.016612946055829525, 0.030725861906830687, 0.027114588010590523, 0.029381110725807957, 0.03161896798701491, 0.05495136363606434, 0.02918315582064679, 0.01751805637468351, 0.05250314461591188, 0.055141175325843506, 0.05914066110562999, 0.016378531290683895, 0.0896403293882031, 0.07636781971086748, 0.0021726382510678377, 0.06082490959670395, 0.059480869022081606, 0.013681669606739888, 0.027182403609913308, 0.08893466569134034, 0.03235513395338785, 0.031810456930543296, 0.051344262465136126, 0.05680080306774471, 0.003451774532550189, 0.08175011214916594, 0.0505382010305766, 0.021402590900834184, 0.04418475640704855, 0.04634838776837569, 0.01448239314413513, 0.0543796390411444, 0.02949496545625152, 0.0228315795538947, 0.008056901751842815, 0.033647621239651926, 0.0660995980433654, 0.029595053347293288, 0.01029439164994983, 0.015070431072672363, 0.013617331896966789, 0.11466808718978427, 0.02446297228743788, 0.034712525230133906, 0.05987743192235939, 0.04129321918298956, 0.020666890632128343, 0.0029660363270522794, 0.01390589653965435, 0.015344824405474355, 0.06607506264117546, 0.0239588907425059, 0.04255891122738831, 0.03917446549166925, 0.018388231947028544, 0.03648555684776511, 0.02391048416029662, 0.0452458383369958, 0.021051237781648524, 0.030613411690865178, 0.026261587590852287, 0.032901065205805935, 0.02064627748040948, 0.03581323413527571, 0.009123747386183823, 0.05791805073386058, 0.07529413982410915, 0.06799949609558098, 0.0375824399816338, 0.02659866921021603, 0.05563227299717255, 0.016596514906268567, 0.021995255192450713, 0.11243656044825912, 0.0418025551334722, 0.04727401290438138, 0.08564208299503662, 0.04069836184498854, 0.0303460307259229, 0.016018662026908714, 0.037742124186479487, 0.07097772730048746, 0.054356164910132065, 0.08118764584651217, 0.018108967342413962, 0.00915082649953547, 0.02985901115607703, 0.06613223027670756, 0.03411378274904564, 0.04122240345168393, 0.013746656695730053, 0.014635456464020535, 0.03774219469050877, 0.018797422490024474, 0.05917024682275951, 0.02603166467451956, 0.05382181116146967, 0.041800889011938125, 0.03703989292262122, 0.010625772647472331, 0.024574055096309166, 0.0307721589342691, 0.015419364790432155, 0.0978053935978096, 0.040105003645294346, 0.0051765421994787175, 0.021331808566174004, 0.020350884151412174, 0.03264441940700635, 0.04928098431264516, 0.03158786457788665, 0.03381908703886438, 0.02422832745651249, 0.05066297460871283, 0.04168602310528513, 0.032828653856995516, 0.016519223936484195, 0.06121426253230311, 0.024327322535100393, 0.0113841297570616, 0.0404656762839295, 0.021966727035760414, 0.058564895516610704, 0.0896612208453007, 0.05683448172931094, 0.009591898779035546, 0.08040394532145001, 0.15579192229779437, 0.1900601459783502, 0.1764923654263839, 0.14340423076646402, 0.14442210114793852, 0.16727613809052855, 0.15146757621550933, 0.16804955987026915, 0.18595477798953652, 0.08055238227825612, 0.18757234822260216, 0.16848793165991083, 0.181492303381674, 0.17214078252436593, 0.15907942870398983, 0.18682052294025198, 0.16337817069143057, 0.15033384173875675, 0.12586401571752504, 0.1001903296855744, 0.12589451798703521, 0.1762263648561202, 0.11631034125457518, 0.2013090712716803, 0.11287713641650043, 0.10800438773003407, 0.16550863918382674, 0.13209317286964506, 0.17465945362346247, 0.08634396173874848, 0.11458126333309337, 0.12941470253281295, 0.08792937471298501, 0.13552937598433346, 0.17776691500330344, 0.12360451743006706, 0.16484524821862578, 0.12103417058824562, 0.2065326480078511, 0.1280010596383363, 0.14631472615292296, 0.21938440448138863, 0.12255077162990347, 0.20793267991393805, 0.20186977868434042, 0.08980116763268597, 0.10287926430464722, 0.1211339671863243, 0.09219316154485568, 0.17562868364620954, 0.19092590577201918, 0.10508355422643945, 0.11272067684330977, 0.09199721971526742, 0.11894311013747938, 0.10775012051453814, 0.10967763388180174, 0.16301091149216518, 0.1857379372813739, 0.13535111211240292, 0.1165015333390329, 0.17373151669744402, 0.20730028103571385, 0.06279088847804815, 0.2944200171623379, 0.13232073019025847, 0.09066366197657771, 0.09119426045799628, 0.15454083943041041, 0.38846998766530305, 0.14424512861296535, 0.11098508286522701, 0.24610842985566705, 0.17724037606967613, 0.16720659885322675, 0.12343947862973437, 0.09660509589593858, 0.07756911931210198, 0.15014503936981782, 0.1328668321366422, 0.09961726551409811, 0.131282139045652, 0.14348929573316127, 0.09966741243260913, 0.0681315761175938, 0.16443121887277812, 0.12713513657217845, 0.07464438211172819, 0.08912189470720477, 0.1866076304577291, 0.2566867950372398, 0.09205446898704395, 0.10440704951179214, 0.11938707772060297, 0.11057818555855192, 0.1712170906830579, 0.11697676018229686, 0.15748853125842288, 0.11707522833603434, 0.12775555718690157, 0.10332711332011968, 0.07383045391179621, 0.14758945384528488, 0.14095768157858402, 0.12500655313488096, 0.10124999040272087, 0.14772940805414692, 0.12543500983156264, 0.12345005423412658, 0.09846823537372984, 0.12632576515898108, 0.10321323075913824, 0.09523803761112504, 0.11169796023750678, 0.16712763434043154, 0.262866243137978, 0.16002303978893906, 0.09609664310119115, 0.10597531887469813, 0.14395385049283504, 0.19990544737083837, 0.13071758730802685, 0.28419687354471534, 0.10266640892950818, 0.22797691606683657, 0.1799401905736886, 0.23146674677263945, 0.19341074978001416, 0.12482365826144814, 0.10378086240962148, 0.2924499713117257, 0.10668532413546927, 0.22864375059725717, 0.13153703708667308, 0.12716825120151043, 0.15279800951248035, 0.1702865117113106, 0.12543829012429342, 0.1248339147423394, 0.08234510678448714, 0.07703548544668593, 0.22427855670684949, 0.0886735410313122, 0.2076897452934645, 0.16485329309944063, 0.2087959906202741, 0.08793350847554393, 0.09202041183016263, 0.12886913493275642, 0.13802536705043167, 0.10810690058860928, 0.23314846825087443, 0.17743462580256164, 0.14064397575566545, 0.11413238273235038, 0.07384540818748064, 0.1055898325284943, 0.17287764610955492, 0.1251014886656776, 0.16274954192340374, 0.14685060130432248, 0.13342102349270135, 0.1273307073279284, 0.12554695538710803, 0.150808296748437, 0.1409925179905258, 0.18850988853955641, 0.1010259211761877, 0.226151158567518, 0.120680329418974, 0.1352545735426247, 0.13937747105956078, 0.20391901169205084, 0.17671587062068284, 0.14020394155522808], [0.1004579258733429, 0.012518171297415392, 0.05545287363929674, 0.029885477997595444, 0.02686437848751666, 0.012799013893527444, 0.03862357669277117, 0.033531311855767854, 0.03749637311557308, 0.09846019791439176, 0.024900483185774647, 0.03570131826563738, 0.05442009351099841, 0.023452987225027755, 0.0336411645548651, 0.07314350717933849, 0.03995314909843728, 0.03851575747830793, 0.10749785709776916, 0.04722765093902126, 0.03258144817664288, 0.009961569030565443, 0.034513214050093666, 0.06742709985701367, 0.10040313311037607, 0.046096539954305626, 0.04135975643293932, 0.024872882713680156, 0.037323705037124455, 0.04152655783400405, 0.01983767233468825, 0.013590212893177522, 0.06039638239599299, 0.014125540710665518, 0.045300085621420294, 0.0770213030045852, 0.03405231065698899, 0.03625181743700523, 0.14240751159377396, 0.037113194848643616, 0.041222188228857704, 0.004035395058963331, 0.014978289727878291, 0.05424725102784578, 0.017448266662540846, 0.03168656650814228, 0.03610023377405014, 0.034553620280348696, 0.06604991867789067, 0.006729190281475894, 0.06153642512799706, 0.016106352341012098, 0.01705101727566216, 0.09041715020430274, 0.11657358845695853, 0.04642931897251401, 0.042080519124283455, 0.005738076179113705, 0.03639129296061583, 0.07156178267905489, 0.07894337642937899, 0.03736086066055577, 0.04287555224436801, 0.04179304451099597, 0.044270986545598134, 0.04491407977184281, 0.039039376060827635, 0.04055286008224357, 0.006054280720491079, 0.014584880955226254, 0.02969832690723706, 0.003431834184084437, 0.06086762390623335, 0.031611338708898984, 0.07647600999916904, 0.02821110192599008, 0.002398988190179807, 0.02382613907684572, 0.03230189970054198, 0.042046239323099144, 0.048545130048296414, 0.07064221717882901, 0.02755254605290247, 0.03648934180091601, 0.020588890911312774, 0.02819881196046481, 0.05422064503363799, 0.014275181802076986, 0.029163123399484903, 0.08199124335078523, 0.02704096696106717, 0.036333383177407086, 0.05180074636882637, 0.04052411670272704, 0.03465596244495828, 0.07400451722787693, 0.08482143835863099, 0.05539524958294351, 0.033077930129365996, 0.06160831326269545, 0.04568814722006209, 0.04349550901679322, 0.054871163447387516, 0.039697393876849674, 0.04256946827808861, 0.019816702952084597, 0.024691277321835514, 0.049873448224388994, 0.04658545942220371, 0.06795613982831128, 0.0035145078118148376, 0.02244151972263353, 0.057484317367197946, 0.02223582978331251, 0.08733050606679171, 0.02558660056820372, 0.07896231603808701, 0.05443054666102398, 0.04145379767578561, 0.017574875200807583, 0.06269731107749976, 0.015690539985371288, 0.029654560603376012, 0.06175984497531317, 0.024794100027065724, 0.025766075996216387, 0.0552832632092759, 0.056813857445376925, 0.02036056546785403, 0.07180543718277477, 0.037663857292500325, 0.03955176594899967, 0.055617693506064825, 0.037369770143413916, 0.06170192777062766, 0.03538422453857493, 0.005975471594865667, 0.02194730688643176, 0.05881407159904484, 0.0715700798900798, 0.021407951062428765, 0.0329365064681042, 0.044427089887904, 0.06886852876050398, 0.023629265851923265, 0.011967411446676124, 0.036818231965298764, 0.05887812265427783, 0.043682704636012204, 0.1345290499739349, 0.011182828693563351, 0.029327388510864694, 0.008295466977870092, 0.07435435822117142, 0.011548526599653997, 0.03033845525351353, 0.02458594986819662, 0.059462575081852265, 0.021570678072748706, 0.036893285359838046, 0.061391650669975206, 0.03994083686848171, 0.05175142694497481, 0.0290937845420558, 0.04287552626919933, 0.036104393511777744, 0.04438568546902388, 0.06664203378022648, 0.0647435754945036, 0.011689794409903698, 0.037940849069855176, 0.03603125485824421, 0.026558591380307917, 0.038588380339206196, 0.08276294334791601, 0.022164351685205474, 0.010641048829711508, 0.007098200949258171, 0.06170592052512802, 0.03586740720493253, 0.11302751780021936, 0.011636943290795898, 0.0008971724696493766, 0.04924186199787073, 0.005582386584137566, 0.09382116637425497, 0.022453232668340206, 0.07107585406629369, 0.020570784363371786, 0.018424725203658454, 0.11495201804791577, 0.06507287384010851, 0.02631482926517492, 0.035032398300245404, 0.06136858843092341, 0.07281854297616519, 0.044722260572598316, 0.017755400767782703, 0.02696972635021666, 0.06588448653928936, 0.026928989864245523, 0.030856967860017903, 0.005773183474957477, 0.0034529552431195043, 0.02109477401972981, 0.049248422583332285, 0.030012594907020684, 0.03140947454085108, 0.028104564771638252, 0.029910336234024726, 0.011241976008022903, 0.013014290525461547, 0.010538007190916687, 0.039776796256774105, 0.06331690048682503, 0.07816013603587635, 0.031659170126658864, 0.019150601292494684, 0.037536248710239306, 0.07687020173761994, 0.057763131117098965, 0.005223195921644219, 0.038486049306811765, 0.0472490210813703, 0.033049721096176654, 0.046606888936366886, 0.05428035823570099, 0.03171295356878545, 0.031066847222973593, 0.011999720845778938, 0.13070379820419475, 0.017270459211431444, 0.03769175091292709, 0.05285456638375763, 0.027637551647785585, 0.07347838647547178, 0.03966470598243177, 0.046662820896017365, 0.022630142120760866, 0.009449132758163614, 0.02335528904950479, 0.03966976000810973, 0.026187198418483604, 0.049218239437323064, 0.025432818292756565, 0.03322962511447258, 0.04969799338141456, 0.029015710606472567, 0.08263952418928966, 0.021777972906420473, 0.030921063444111496, 0.00987830933809164, 0.008734592975088162, 0.07036753348074853, 0.0294290608871961, 0.024891816756280605, 0.09094869863474742, 0.02376094511419069, 0.023342433196376078, 0.01654707117268117, 0.03207411973562557, 0.03565101549611427, 0.11639108692179434, 0.017611195908102673, 0.013218484109529527, 0.05766603964730166, 0.027312513229844626, 0.015821979905012995, 0.04611981741618365, 0.02067028410237981, 0.03532607726810966, 0.030863305801176466, 0.03873183377436362, 0.049266887217527255, 0.04072183968673926, 0.09725561059894972, 0.020227631976013072, 0.02774809268885292, 0.0327994429244427, 0.06100193779275287, 0.04914206911053043, 0.013639782791869948, 0.0319584077806212, 0.04470705025596544, 0.036067902110517025, 0.013037088374403538, 0.019285944908915553, 0.03214670919987839, 0.05199118888413068, 0.03583430370781571, 0.017451352141506504, 0.0747320445952937, 0.053886485620751046, 0.06549382000230253, 0.03942973831726704, 0.05810421105707064, 0.04206578749290202, 0.030628766726294998, 0.057335223609698005, 0.08726261439733207, 0.03439628868363798, 0.016036816814448684, 0.03178849307005294, 0.03841981633740943, 0.013004939464735799, 0.06410951420548372, 0.010637933664838783, 0.04335343968705274, 0.02061537445115391, 0.06391152404830791, 0.10993503296049312, 0.07173416874138638, 0.03611752952565439, 0.05109032921609469, 0.0409712792315986, 0.03265292813011911, 0.028479892971517984, 0.015113241861399729, 0.06805423690821044, 0.03813515817455482, 0.06600740103749558, 0.08619276399258524, 0.04904658439045306, 0.03998355859948788, 0.018719226100074593, 0.025264959331252612, 0.015017485329735791, 0.0134578026154486, 0.016929093544604257, 0.04807101271580905, 0.04026387519843411, 0.03392461301700678, 0.09527114481898025, 0.05904067897063214, 0.030137843459669966, 0.017106505802075844, 0.0550949432363268, 0.010347704755986342, 0.05315227150276769, 0.030785382150497753, 0.08452932161162607, 0.005726766776206205, 0.07692077910178341, 0.04900342108157929, 0.04169268016994465, 0.06667812442174181, 0.06795030654757284, 0.04609116309438832, 0.04372987554233987, 0.0652889278717339, 0.06444863116485067, 0.056338738213526085, 0.15099711396032944, 0.12203226273413748, 0.16901631111977622, 0.16534627211512998, 0.19608634058386087, 0.14509524393361062, 0.1554526123800315, 0.17264118301682174, 0.09362094977404922, 0.20536942058242857, 0.1662921393290162, 0.14614520478062332, 0.1636335882358253, 0.07685583375860006, 0.19031318865017965, 0.20681963651441038, 0.11342591751599684, 0.14184226223733276, 0.21194283035583794, 0.09887185980915092, 0.13668712635990232, 0.20195870281895623, 0.10151345282793045, 0.1430707541294396, 0.10547719677560963, 0.15859192673815414, 0.14920113142579794, 0.09498969273408875, 0.22818660247139633, 0.23811008170014247, 0.1385290626785718, 0.13263439148431644, 0.1578763034194708, 0.12255674591870047, 0.07248263951623812, 0.15160861395997927, 0.15277366706868634, 0.1266736988327466, 0.212042678904254, 0.19128485291730613, 0.15857037476962432, 0.09125305339694023, 0.16593011969234794, 0.2083979471353814, 0.145517481432762, 0.1487608003662899, 0.13913737144321203, 0.16814759757835418, 0.12449028552509844, 0.10822867217939347, 0.12460626836400479, 0.12604222021764144, 0.06279314460698515, 0.15158572612563148, 0.23372017429210246, 0.17200611240696162, 0.16543932259082794, 0.14332951133837923, 0.22658182686427608, 0.1516879495466128, 0.19299913983559236, 0.13392321998253465, 0.14775087096495554, 0.11544520486495458, 0.15698654256993905, 0.11787410578108393, 0.12394485151162371, 0.11573499868973158, 0.09285238906159066, 0.16560805728659034, 0.10924732923740521, 0.08516960209817626, 0.16875516419531778, 0.11791188109782524, 0.1366837866953574, 0.08182143996236846, 0.13680236705113202, 0.14499652344966307, 0.1232201888342388, 0.1663999437005259, 0.1668443565722555, 0.20202261657686904, 0.17779036686988547, 0.12615225103218108, 0.0877413441776298, 0.10963452252326533, 0.226053818478249, 0.11085081350756809, 0.15062178019434214, 0.17385189305059612, 0.08700928970938548, 0.12165459120296873, 0.18322665797313675, 0.14372629317222163, 0.09042100195074454, 0.14548654871759936, 0.13680180301889777, 0.2066608762834221, 0.11179351917235181, 0.19301260239444673, 0.15612762537784874, 0.09892196219880134, 0.1597128517460078, 0.1790711356443353, 0.08572504768380895, 0.13422914809780195, 0.10328004631446674, 0.14673941273940727, 0.12480206176405773, 0.14937897969502956, 0.0843422781326808, 0.10656920028850436, 0.1970137728494592, 0.15893692150712013, 0.1953619153937325, 0.19826837349683046, 0.1019059524696786, 0.17494757019449025, 0.11332574984407984, 0.08984632731880993, 0.143177296849899, 0.10847010766156018, 0.20282345329178497, 0.17813350626965985, 0.24667240271810442, 0.15767969365697354, 0.14642152120359242, 0.12832525942940265, 0.09397647561854683, 0.1394968677777797, 0.13290799164678901, 0.11663029596093111, 0.14221587422071025, 0.13324722734978423, 0.19109594664769247, 0.2329899900360033, 0.08569920610170811, 0.1410591628518887, 0.1196116441860795, 0.18285778089193627, 0.042834040214074776, 0.10559054499026388, 0.12909620243590325, 0.23256424959981814, 0.08320979788550176, 0.12279944305191748, 0.15727727150078863, 0.1890608441317454, 0.1283417796366848, 0.16420416621258482, 0.035004089077119716, 0.07556197349913418, 0.0711683627741877, 0.12847821606555954, 0.0498813261219766, 0.13111891108565032, 0.16952180274529383, 0.12718116457108408, 0.14452137082116678, 0.1305622557993047, 0.1453169679734856, 0.11822219530586153, 0.17936324496986344, 0.12197159216157161, 0.15728136815596372, 0.10861269649467431, 0.15528212621575221, 0.097392410680186, 0.2045120915863663, 0.15312670671846718, 0.10337545681977645, 0.11983424396021292, 0.1269139617215842, 0.19978280004579574, 0.18889982777182013, 0.15667389059672132], [0.038571852710447274, 0.026695953638409264, 0.039268948312383145, 0.055781474366085604, 0.037016671121818945, 0.04936257973895408, 0.02091165279125562, 0.06402418948709965, 0.021487307058123406, 0.07039314499706961, 0.06419612283934839, 0.019520695495884866, 0.021096178534207866, 0.06426829670090228, 0.00893193282536231, 0.01944976844242774, 0.02762858279311331, 0.022604150253755506, 0.07385558303212747, 0.01502377781434916, 0.05987851174722891, 0.009007118878798792, 0.02487661571649369, 0.08410508031374775, 0.030298000783659518, 0.01981027780857403, 0.03093037368671503, 0.04430735920323059, 0.08748019725317135, 0.11230715215788223, 0.04524462863628287, 0.07271228969329968, 0.03507509405608289, 0.052330153703223914, 0.0380241254606517, 0.07488483053748496, 0.06863932387204841, 0.019327072877786122, 0.07220291663543321, 0.018845446866180282, 0.01543364556710003, 0.03623490018071607, 0.036790861558984034, 0.012785594935849076, 0.03604514044127427, 0.02341753111977596, 0.02451789678161731, 0.028668695340456907, 0.002854175654647406, 0.04104811006982345, 0.08926814232836477, 0.0718526155105792, 0.05574686801992357, 0.05132927108206786, 0.046878069697413594, 0.013591263959824573, 0.03782045787374955, 0.029489137741620652, 0.01758588867232902, 0.06662929852609523, 0.05980622285278514, 0.05272851631161757, 0.06752377201337367, 0.009600067041901639, 0.06161475510452874, 0.029393879376584664, 0.015166183893597918, 0.02709866708755726, 0.07289067230885848, 0.09794866520678625, 0.01819207303924486, 0.018335643362661358, 0.07475533318938687, 0.037506054432014935, 0.056299949865206145, 0.045993808162165806, 0.08893903694115579, 0.028760717941622715, 0.023677967437834013, 0.06477637842181139, 0.07177886087447405, 0.015857050093472935, 0.015394541806017514, 0.048983620581566356, 0.0014657489668934431, 0.07123534902348183, 0.041032313456526026, 0.01765843731845962, 0.03757937120099086, 0.029269770020619035, 0.049853228410938755, 0.0534047501423629, 0.08222142787417397, 0.037179097562329844, 0.02469139977620216, 0.007008795810179436, 0.030714238018845208, 0.0746079946111422, 0.02179287523176754, 0.04301814107748214, 0.06723287981003523, 0.023519377900811378, 0.028794064492103644, 0.015527151535934536, 0.010255181205138797, 0.03790620932704769, 0.03922643438272644, 0.047681028954684734, 0.05647431004035752, 0.059806619901792146, 0.007310714472623658, 0.05190902571484912, 0.02474169883498689, 0.029223717901913915, 0.028982373332837597, 0.04583920024742838, 0.01574144760525087, 0.05777397018391639, 0.011278340316493995, 0.018112128891516477, 0.05551174450374674, 0.029613495717057958, 0.035275132540846244, 0.059941687068203464, 0.006782096597817144, 0.009960942843463272, 0.05221764040470589, 0.014127347840258153, 0.03948162557207979, 0.04580967390211299, 0.022960136229812633, 0.029434011012199335, 0.059613264456856996, 0.05657492300088052, 0.06839794034021907, 0.014640665413026, 0.05154565536940936, 0.05609538799035363, 0.04469511652132496, 0.02694904454983771, 0.05522623658180237, 0.07675608168938197, 0.08994965653982945, 0.01316811547440011, 0.016928618570091203, 0.018925378026324324, 0.020727290320792235, 0.03600173964514397, 0.05877851159311831, 0.07336056311032735, 0.015401160835608607, 0.03845875682600308, 0.02356280652747955, 0.09320946599473245, 0.019945766143791843, 0.02431887132843258, 0.010471180503373034, 0.0769333956122864, 0.03138943655358162, 0.05322673860064242, 0.05134047009050846, 0.03791519673541188, 0.024815310607664287, 0.06593593963771127, 0.005886020071557141, 0.02374321335082641, 0.04782051932124887, 0.07697730106883682, 0.06267332486459054, 0.0312743108952418, 0.03691962789162062, 0.05227629233559128, 0.09873695220449008, 0.02826183885190403, 0.05487683716637548, 0.014926122312317602, 0.07879660930484533, 0.0046251598723756615, 0.049522141489433125, 0.04444845260877628, 0.022902805321791675, 0.017381267425662372, 0.03421138259000145, 0.061437597032636404, 0.09001477257697843, 0.049094682981376536, 0.053787301294505596, 0.019159779803885613, 0.036037262543686666, 0.013386702084972057, 0.014860728897474473, 0.03941320326703135, 0.020761111845786218, 0.014153678312140983, 0.014255987080105115, 0.034905487336800434, 0.0736823954503052, 0.030849381255393382, 0.042601759123499505, 0.09289935958804563, 0.03394607963855378, 0.04004733134934213, 0.03811691247392446, 0.028022434999002144, 0.10384355162386782, 0.022138844069559127, 0.05145454932062421, 0.001689644600446627, 0.03282979676441755, 0.0680074593401514, 0.04034125893667806, 0.02824757477355888, 0.0469533383147791, 0.006024871263434761, 0.021628482099913526, 0.08175713286618702, 0.029840758033969905, 0.0384122538525844, 0.07235683806356974, 0.011991732553724432, 0.013679757648787927, 0.041040803625946864, 0.023978598474059254, 0.03218289632059168, 0.036970698783989064, 0.038496034903801046, 0.05579621341894381, 0.07558545505162328, 0.03792761286604218, 0.05176205449970439, 0.04225937300361693, 0.032000220380723476, 0.015514522965531796, 0.031378667990793474, 0.10998801488312893, 0.027377736878406722, 0.018880578281823546, 0.03720777043781709, 0.03930037826648913, 0.009589782730472507, 0.04185098769085016, 0.057229567755712196, 0.013194686216593254, 0.011482947647891706, 0.0783377097104676, 0.01584293073392473, 0.04821217662538402, 0.04617275109922048, 0.10603881702991202, 0.014363622613018379, 0.06711754263960756, 0.011680292136588832, 0.07950126368086785, 0.018565542159194592, 0.03285335253167432, 0.014591236522392137, 0.03372536120878067, 0.030469499979517423, 0.04649418639019132, 0.10457700132974423, 0.07968710488057695, 0.06810189021052793, 0.09341291835880838, 0.02545827581343474, 0.043977426321362145, 0.024809848400764167, 0.06815322456532158, 0.0679789757123217, 0.09192650788463652, 0.04102452461665962, 0.015437039037351497, 0.023982522579899523, 0.028799090687243734, 0.036681910569313914, 0.03176176091074012, 0.031233578120009042, 0.0059406964101071935, 0.0169191023815074, 0.013749252357229125, 0.03936655557481572, 0.028372700871841516, 0.0532641020254232, 0.03685073432279751, 0.01636832304939162, 0.004223642672513961, 0.04863599118834827, 0.084234763198765, 0.04055646320921369, 0.02707796302274801, 0.04421182624355424, 0.007587599566249992, 0.05038747454818804, 0.07149349767132662, 0.026675817316572648, 0.029643010930158198, 0.03287473751697689, 0.04041328065795824, 0.048133219534065574, 0.05602442382951267, 0.005158171725270222, 0.0021162883695069468, 0.04648047521186527, 0.042390202506794594, 0.010766392006189562, 0.06582872898434289, 0.0934893818339333, 0.01050591765306308, 0.017049692542059347, 0.04526643293502275, 0.03367194141901564, 0.025674494972918183, 0.038767493970226496, 0.0357775590964593, 0.015011282830528216, 0.03610782223404385, 0.06991345042479225, 0.03824757499387488, 0.02497353092621779, 0.0415297564904904, 0.03346351295476779, 0.039653981948504224, 0.0243893122751615, 0.028166031297587324, 0.024420517729595304, 0.038111090325401165, 0.03534750678227283, 0.007723125936536235, 0.020576942333718762, 0.05492038639204111, 0.05569292130530812, 0.06315888982499018, 0.021176488189666998, 0.032505173949175514, 0.02459623232425656, 0.031654776612413116, 0.06927782320417464, 0.0075171238313487265, 0.039346294943243265, 0.017836560182331596, 0.10071654949570075, 0.03600525000365451, 0.01880993695522193, 0.024988158656924497, 0.030577757061109878, 0.04675152238633018, 0.034049375462927856, 0.043446753625175916, 0.016738344893383328, 0.017071448601200245, 0.04176276488578878, 0.05662978997861501, 0.02160039366572164, 0.0906904238217976, 0.1807070814538747, 0.14326286647701636, 0.19647289562271908, 0.16000222996808589, 0.10116310717421584, 0.1604011343442835, 0.25127909146249294, 0.13846663321601227, 0.18628550868015736, 0.12442414532415569, 0.09941804339177907, 0.1455607486423105, 0.1298804595717229, 0.08939278603065759, 0.1284339840640314, 0.12065212038578466, 0.09648443010519259, 0.17690905166091397, 0.1104748118086718, 0.23912438977276906, 0.1225864615116734, 0.10251652478473261, 0.1826433595851995, 0.08858558168867603, 0.0820405813283287, 0.07493953424273059, 0.10669048948329873, 0.17363543825922534, 0.13428083126200363, 0.18244373670313507, 0.13057745498372242, 0.0958812644239515, 0.15099604526767507, 0.09546541681629606, 0.1953959057573229, 0.11872929739183746, 0.09796735990676098, 0.214967853971757, 0.24785114102996886, 0.06985583750065416, 0.052129387913737446, 0.18366215022979304, 0.11955275476793759, 0.11925658589461818, 0.11924203237867914, 0.07838212724891491, 0.14095116552198306, 0.11373690707841888, 0.10125062122824602, 0.12430552043952048, 0.15173676802078262, 0.0955144505132921, 0.12717038858681917, 0.12470251007471234, 0.1593171979766339, 0.12310256584896706, 0.11972006454016082, 0.1361428204108961, 0.1592840685043484, 0.14252160937758163, 0.19183965283446014, 0.16881187912076712, 0.1560676153167151, 0.15265762485796586, 0.07671923405723646, 0.09174652223009616, 0.13408174272626638, 0.19012196687981486, 0.12237419985467568, 0.09997551504056901, 0.12070869430317543, 0.19615791330579668, 0.07995538384420797, 0.1846216878038831, 0.11971875093877316, 0.21824480703799054, 0.13342966209165752, 0.10853339059394784, 0.08979327118140645, 0.14136308716842905, 0.12589429534273222, 0.21938798163319007, 0.1629601782769896, 0.14914486178895459, 0.21437605057144538, 0.21760820760391653, 0.10364493806264363, 0.1282356376759708, 0.08289540928672068, 0.14476675452897325, 0.15766087279189378, 0.15944363025482744, 0.10361525215557776, 0.10888324643019587, 0.10919686319539323, 0.1334821616183035, 0.11567746740183793, 0.12954739853739738, 0.12856319197453558, 0.187861162412446, 0.13057932519586757, 0.1365834631724283, 0.1272794249234721, 0.10797971131978557, 0.18551653978647664, 0.0838318066962529, 0.1480694898054935, 0.20408400596352294, 0.13150603015674278, 0.14249403116991743, 0.1202564146660734, 0.15091380046214908, 0.0996140149072744, 0.13152502913726494, 0.14567595964763314, 0.11202460911590606, 0.09696341963717714, 0.0928642188955564, 0.08764780388446525, 0.12632790254428983, 0.142125851707533, 0.1259438559645787, 0.11893136936123483, 0.07472259705536999, 0.10841608673217706, 0.17621080944081768, 0.19178434798959643, 0.17349594418192282, 0.1309570635203272, 0.17256870487472042, 0.071902101917658, 0.1143123758083675, 0.21933606098173186, 0.12557966925669461, 0.10713007839513011, 0.11391313746571541, 0.06657438701950014, 0.13719162350753322, 0.16763701481977478, 0.10512618318898603, 0.21898487670114264, 0.2747605845797807, 0.08545118776964955, 0.08696674238308333, 0.06450887871324085, 0.23558379616588354, 0.09720984235173091, 0.1764370605815202, 0.2091209325590171, 0.0872406987764407, 0.09034945149323903, 0.10254494161927141, 0.19466659723548219, 0.14135945064481348, 0.07950501152663492, 0.07256623503053561, 0.10930261181783862, 0.11975513101788238, 0.15570054907584563, 0.17269409814616665, 0.27087336347904056, 0.12871518381871283, 0.14782480371650308, 0.10805187775986269, 0.14030514081241563, 0.10707730427384377, 0.08170849992893636, 0.11153618688695133, 0.19644963671453297, 0.11748220727895387, 0.09914509631926194, 0.1686393891577609, 0.16499697288963944, 0.20792234921827912, 0.12077178427716717], [0.040630191870150156, 0.018732963253569324, 0.023168546140368562, 0.04055681201862171, 0.07817075616912916, 0.031401058586197905, 0.04068858404934872, 0.020710463977593463, 0.0348223222681554, 0.014456800181505969, 0.09379606693983078, 0.02914826003689086, 0.026511676514928695, 0.005889632475373219, 0.016596717141510453, 0.013817524377373047, 0.032099508607643656, 0.02797341800032882, 0.015509786207985599, 0.018723317189142108, 0.05422824833658524, 0.0160250611952506, 0.08654929173644632, 0.007859299366828054, 0.03393640945432708, 0.024201656524382997, 0.01553562036860967, 0.027881684836756904, 0.0661826592113357, 0.018305146659258753, 0.024913955021474976, 0.013076189352432266, 0.04382574617920909, 0.028797565573768225, 0.02597150618385058, 0.07163479516748339, 0.04354492120910436, 0.04131011417484842, 0.011440946727816481, 0.026966470177285373, 0.011574704931263113, 0.03692586935358122, 0.05073414657090325, 0.03229275273042731, 0.047868565961834975, 0.015298263915610733, 0.07974482170538977, 0.057415657574892975, 0.019825293311441783, 0.06907374001457356, 0.046710745082236826, 0.00652603570415522, 0.027604694914771244, 0.0332630625780439, 0.09387959566083737, 0.06968601926928386, 0.0199349753165734, 0.07188951509306207, 0.020785198248631787, 0.02942409035313176, 0.03190260940755252, 0.018155596480937675, 0.021924391221546102, 0.07479966909158975, 0.044134045456303284, 0.06583350841538049, 0.05667880512191914, 0.07671189421671443, 0.025401432867511176, 0.09898344913381152, 0.042494897279539146, 0.046338138708961196, 0.015003452244854998, 0.02011594617215451, 0.052861746662529185, 0.041279890210716985, 0.04559526001685299, 0.010487863983144052, 0.0220524024189217, 0.017519015600555576, 0.029406584944808856, 0.03672840612125583, 0.049771373232943006, 0.04425410268595442, 0.048837257927516475, 0.04678456280089449, 0.07585257626487873, 0.057189413855667226, 0.05412394690210931, 0.055097737422329374, 0.04500009468756616, 0.07275509677128866, 0.014510408291243948, 0.03322617783851456, 0.040104751315084286, 0.08409119473071769, 0.03927025078155566, 0.02613523138279561, 0.007538304726040224, 0.022794626165705267, 0.0555752278160071, 0.04250656013027765, 0.0559899584914092, 0.02821883881551912, 0.04901031934423372, 0.05646523728501052, 0.013284952710819198, 0.0343123369384557, 0.031752962750033475, 0.027182802514289506, 0.00988369176411652, 0.04971370464772917, 0.053965450133546256, 0.05002325073292013, 0.026241458690492436, 0.09386935402289964, 0.04467279271921143, 0.07199628787930124, 0.036455793015193194, 0.047232007345883176, 0.017537617532070726, 0.06762350181816146, 0.060276161893852986, 0.07801003666827455, 0.042470521439099684, 0.0699534967134241, 0.027531264968274627, 0.016643516973999795, 0.048256583031616174, 0.03661077942524571, 0.022382531969924457, 0.03300784170278348, 0.018099362096108962, 0.06773139524739236, 0.060794095625169575, 0.03271701258199755, 0.03942626506614033, 0.023290180433832575, 0.10103649678057991, 0.034822107045329176, 0.06426635969546624, 0.03531200243742205, 0.05988657518173568, 0.024254222844319884, 0.03934409447538201, 0.04530942554993089, 0.02016703747358406, 0.02382020746154012, 0.04781601448485162, 0.04301333196053747, 0.07081162722897716, 0.0650164631952066, 0.013303749456099467, 0.026237786914862227, 0.024196572812797967, 0.03325660218251869, 0.11465381568996236, 0.029782239689666312, 0.031842692114878446, 0.09752492114785127, 0.03430133459914941, 0.013769761608273257, 0.039033754292177036, 0.017767360477591865, 0.06434284543502145, 0.05702535097952932, 0.025292836253356654, 0.057712294001248665, 0.02016532682318939, 0.0361976443673484, 0.037160851861699484, 0.050837999006034806, 0.022476001759059727, 0.024999519082484767, 0.04383709361718502, 0.012717877671093447, 0.06051935626601335, 0.023382793042401318, 0.08430206857156008, 0.033544763282407075, 0.013969441079098033, 0.053527638665400445, 0.019920948725484777, 0.02550405519286869, 0.016955473183770664, 0.03443231253186241, 0.018676893996598665, 0.02983770966238808, 0.009826203149714274, 0.047430042031919584, 0.0192141606748919, 0.01684016013314249, 0.030835968791507185, 0.054956243257038295, 0.03037855163711356, 0.057000878659891896, 0.04555867584713269, 0.042600968736223876, 0.06152220186777413, 0.03899177099810913, 0.07354204048169777, 0.051259353349450976, 0.03195705336111132, 0.057729393083718605, 0.013871988739992958, 0.029266244819154963, 0.05170051190361846, 0.05484389323100913, 0.026472099634702317, 0.07079488437739201, 0.019117755691695493, 0.05704864328436088, 0.05505875240487512, 0.018678107408049982, 0.042409702436998487, 0.01792053419194417, 0.08081758132902905, 0.03430955759540666, 0.05362865609640721, 0.050515183320385404, 0.02625216973683564, 0.007876415147620719, 0.04735208683996461, 0.02492894825991243, 0.03360229828103911, 0.01621277075173566, 0.020847050691372715, 0.02981536916195182, 0.04097432203707285, 0.05034327594330534, 0.10000961672631092, 0.028147646444267593, 0.03809518981142901, 0.022257259297475684, 0.031403054963448085, 0.05195627083594445, 0.021063704007246997, 0.014206355954229366, 0.025276004344050307, 0.01811167247069534, 0.017853841090982314, 0.020471969255595468, 0.01173932070742012, 0.07546636261395179, 0.017324854925391264, 0.025270152509619948, 0.01371615071548149, 0.06904082576511428, 0.011834536398964701, 0.11964653254835866, 0.004647446567105362, 0.04731299421109725, 0.03820613717834931, 0.017032695504894946, 0.026896099734585732, 0.04161504410149064, 0.01958000608283328, 0.053533687168965116, 0.0962138430622872, 0.023051301650411915, 0.03916071720595937, 0.03682941613078583, 0.022729341289959848, 0.0653150217840448, 0.0068147028559906175, 0.04021725348138716, 0.015463874169654446, 0.027279136993456632, 0.03645544420578517, 0.024495482066413388, 0.02894952031056164, 0.035890313592972234, 0.029435432225000113, 0.03779183323786128, 0.043763390931417234, 0.03623734555731062, 0.04703268874436617, 0.026722609727585223, 0.09768964824615978, 0.0028060515523975482, 0.006672038416581927, 0.054779767961008474, 0.06833515464677475, 0.031197929056361318, 0.045006009604549035, 0.0369483824033523, 0.029221988697827328, 0.007897365976532456, 0.08172765476047061, 0.06768529303371906, 0.006694662324662204, 0.025978157682402525, 0.009510878517176025, 0.04006213719549123, 0.016822530415083747, 0.08195668895496055, 0.046335864026332274, 0.06516656998428516, 0.04433604692167137, 0.07320491247810423, 0.044668198825092986, 0.03193469616235234, 0.03285400933236815, 0.04847179843636695, 0.025807465572142974, 0.04289692238671705, 0.019114501374133397, 0.04400556856126059, 0.051990576612297446, 0.03439557993260678, 0.04214732725813519, 0.04434231435880065, 0.054671358739142306, 0.016447166963189375, 0.038647893161396496, 0.015240093453030568, 0.023311307522817515, 0.027566941862460226, 0.026770101612783037, 0.044494488029158674, 0.05426924086350482, 0.0035688188745552907, 0.02815744093823014, 0.0702286628074944, 0.07938517694128677, 0.057199993170797825, 0.028234483288542833, 0.06492327913292684, 0.05050040716014337, 0.023279897977772634, 0.011902795431524282, 0.018245075370941777, 0.05106884775159415, 0.022423259179049637, 0.0252071979775792, 0.042270349367754534, 0.03047329606488347, 0.04756199588882737, 0.014737652982148575, 0.008284524010377936, 0.01926608874782687, 0.032377461466239765, 0.061218515038490295, 0.012635330440389225, 0.0476289376092609, 0.062280721322167665, 0.029028794670011848, 0.060240394086577, 0.026782527020259295, 0.021122476537129842, 0.04680721314798575, 0.030254047087510116, 0.1368866304983385, 0.09170987497782335, 0.23402573133353144, 0.07244929482112639, 0.18111861718352884, 0.17364415107294917, 0.08213553170207888, 0.1365214047837071, 0.1252569240750745, 0.17151813546661288, 0.13146864075679332, 0.11136114393593743, 0.13961556687718257, 0.16362748778192326, 0.05647215039061848, 0.07728317723376676, 0.10838486457942054, 0.13864690088666975, 0.07512023235904053, 0.1948035234818235, 0.2218266492127441, 0.12355974366073497, 0.23115730087738484, 0.1566729851765558, 0.13367044448386878, 0.19399375130888075, 0.15752232866361737, 0.09461685258429497, 0.15200459427433088, 0.08447729705949314, 0.1274925103643909, 0.18094633502187207, 0.07981980830663815, 0.12993135605938733, 0.13585675216745585, 0.13967392937047407, 0.1434361728024669, 0.0975573158939369, 0.13174987019738182, 0.17625269625568762, 0.1304927610908635, 0.173536806832999, 0.13935698778368533, 0.14697740465635434, 0.11010355985490605, 0.1239925716072321, 0.17628101661102846, 0.12689175666309893, 0.09960231865989044, 0.13163627707399428, 0.13113661872921512, 0.1937587428255938, 0.12206419734866358, 0.16680408763932064, 0.18515523261157796, 0.17619273072341457, 0.10218302588327788, 0.19224393035983667, 0.09303192200604826, 0.12381947308313102, 0.15051182359457016, 0.17012307594995946, 0.08973922798759304, 0.14728780050063506, 0.12014039471978322, 0.1962438243208453, 0.254209921695292, 0.13181731657823548, 0.08853454419295304, 0.14054041646886617, 0.1300811956753023, 0.21168653707718477, 0.05627173712127842, 0.18919410416856408, 0.10856972614419647, 0.16496032563736662, 0.14680065476568416, 0.06926512505742721, 0.1293894843547605, 0.17303291824646294, 0.14923236100003123, 0.13324814761290327, 0.17495803447673097, 0.09018603799631819, 0.172592394228559, 0.1603461560443975, 0.15325776999816298, 0.117350891669048, 0.15421888092532754, 0.20747199916513637, 0.08301275767735206, 0.124189255584497, 0.10218399067525752, 0.10648887764546089, 0.135474635171704, 0.14901370945153758, 0.13877881021471694, 0.20514311006991193, 0.12268267353647389, 0.16808916087029502, 0.1390428960439749, 0.08495874310028739, 0.19518241955665872, 0.08229629573179409, 0.19834661070490256, 0.2026858294266276, 0.2393460989696905, 0.1359446521382779, 0.14996171405073255, 0.10947898321319371, 0.13419517257716507, 0.19041131541598588, 0.16128216753713787, 0.16517863579792902, 0.10961549385683611, 0.21965139952953905, 0.09090258899959736, 0.2489639024133794, 0.09421470502275042, 0.09986635253881104, 0.06998301934800111, 0.18547045241575688, 0.16853033797815442, 0.19710410706466064, 0.13444263429846615, 0.16342093324055895, 0.1161807548487559, 0.177973810932599, 0.17298488644883037, 0.10323509442969225, 0.07662841002456844, 0.21719708747696131, 0.23035535094095394, 0.12048787568346597, 0.17670807807007805, 0.13447724806610495, 0.14965562266297638, 0.1154418800433632, 0.18867675302317366, 0.17038469784893095, 0.14584113203454763, 0.11698228918248788, 0.11660222051432356, 0.15703604381997138, 0.17869847360998392, 0.07189691430539824, 0.06736818817444146, 0.19447905651759356, 0.1829557295423001, 0.17535579594550654, 0.1124321372481063, 0.13864946871763095, 0.09744151859194972, 0.14751117210835218, 0.11819373394246213, 0.0637347147858236, 0.17658192780800164, 0.14500979305012152, 0.10042642912594602, 0.19265994866145775, 0.18973581260070205, 0.15699654672062024, 0.15663510595913976, 0.11310453788610175, 0.20629143516998738, 0.15543815534329042, 0.11933624802622944, 0.17187460383865982, 0.1337302615866065, 0.09837858393439092, 0.12846420431742445, 0.1745106975431554, 0.1325746189104393, 0.05968248085991945, 0.1475560275139287, 0.11859024860314094], [0.062694824882783, 0.05231474671745673, 0.03893739383784123, 0.02069377493171487, 0.05567076077568345, 0.016990253934636712, 0.04175233028945513, 0.011649900261545554, 0.031245782738551497, 0.025941632884496357, 0.1665921154199168, 0.09239189384970814, 0.0368894447456114, 0.03916195659257937, 0.010643900532159023, 0.05519848025869578, 0.048942490757326595, 0.06664967047981918, 0.0783417618367821, 0.0407308604917489, 0.022974472667556256, 0.04091774069820531, 0.02090328878693981, 0.03133084028377198, 0.022268070533755235, 0.014967028564569773, 0.012324146064202068, 0.0636702666815836, 0.05927010650339071, 0.028943963479832746, 0.06096403260016814, 0.03367522171174642, 0.03799663631070871, 0.0111273995389638, 0.00755547106564336, 0.06413209775928408, 0.042991212249035016, 0.02595857426058501, 0.0524224471882917, 0.03239548452256713, 0.021635482407873496, 0.027460282253741752, 0.04668415764172096, 0.04304095098632388, 0.04657584118831437, 0.021237155051494483, 0.0600414947984973, 0.008633863126306096, 0.025543580122757703, 0.027700394857674837, 0.03532360962708481, 0.05004942628147546, 0.06540278074680828, 0.00831834089694894, 0.0042707277680165134, 0.032029642825364135, 0.029681485721084755, 0.03128559153992683, 0.02990727673022775, 0.01164570063338033, 0.03340214847412426, 0.04287450952688232, 0.0718699891876895, 0.008898432279238477, 0.06755691632861272, 0.0638521670771297, 0.04650242051866371, 0.0660105403221678, 0.01614305525436066, 0.04671965085435659, 0.025727228276082315, 0.015904009487712756, 0.03225927444873378, 0.008324434857058804, 0.038119524833746254, 0.01004446692604688, 0.04706399253336713, 0.003440160385252966, 0.04064388449478429, 0.038260354776866734, 0.008363187025679508, 0.00911574517886038, 0.04995308809156995, 0.06684441003017128, 0.01872693330369657, 0.022054664113966282, 0.019551153236534446, 0.03745995963981841, 0.0007211720901523222, 0.01707307019387372, 0.052655503823189065, 0.04373988340375945, 0.10402655039797537, 0.030692880864080507, 0.019752885673369747, 0.016631490470899735, 0.02518908957426902, 0.025045432048500516, 0.008370514806301799, 0.061494482652051374, 0.057125103048747405, 0.007489779864044976, 0.018334698979742825, 0.0047155497486528475, 0.056898974362411536, 0.05458479092339985, 0.08825816097669303, 0.06738545052940026, 0.023904435656731948, 0.023930542556627188, 0.02615705980133498, 0.041147587544401176, 0.06813973232056014, 0.05244995860266499, 0.04009322205092758, 0.036826161813223734, 0.021832231323060114, 0.04068069130880758, 0.04809457590454258, 0.04783952943398617, 0.0549021295591956, 0.023536601293017156, 0.04238582383550238, 0.03557936113793403, 0.05685277566954028, 0.08962409119703807, 0.07263474268256687, 0.06858411550638266, 0.012093669320165645, 0.04761849559145048, 0.028532926844491158, 0.03919635513739195, 0.021376988661359064, 0.13483536400599405, 0.010546394387347391, 0.023076308316376526, 0.04061430990986992, 0.03639284033852164, 0.01153289418653003, 0.06026785726135131, 0.07909077437943779, 0.07139401277527213, 0.06859946312033571, 0.021512699640879873, 0.05053381493780762, 0.11521326887304895, 0.029798893483530264, 0.035734874472836964, 0.018497158816899173, 0.05175762016733643, 0.04890252610493917, 0.023467407154385, 0.061834646039642394, 0.052054449552088045, 0.05262427424895577, 0.04235148837324232, 0.021991514768160414, 0.03433261612372007, 0.027338983782101423, 0.015742293653602246, 0.037132405341253616, 0.0118674246732553, 0.03349259772221558, 0.056955169784487225, 0.04658235724491533, 0.034249937161803246, 0.04121871868846938, 0.017007208298309706, 0.01389811048284173, 0.06896280377986841, 0.006977122802709346, 0.007531228347943397, 0.016415141435572878, 0.037583619996439666, 0.0927133922232315, 0.06421890677302144, 0.07252371739014052, 0.019484593722154386, 0.03577229355869349, 0.041008705738931894, 0.028554862874443643, 0.04182365068118088, 0.0169336429098621, 0.0577263836748898, 0.006063849323254544, 0.03839267970761284, 0.06435020011849701, 0.015333282153733307, 0.018419871557853185, 0.04420040459081065, 0.025412071554455906, 0.022238453275349457, 0.03872056055115536, 0.0745709688635543, 0.004992650992790004, 0.05202716449275613, 0.04106101972865872, 0.03571483277482912, 0.003773334829020314, 0.05207170448557008, 0.04129573506361339, 0.03211139039194677, 0.03970301193476189, 0.0867072949768044, 0.050369982127449475, 0.02886670034058625, 0.01869236963102594, 0.01035971177770989, 0.06089007387345191, 0.0446312138956273, 0.0381891197321238, 0.06368380345520563, 0.03510173344693612, 0.05972613398625981, 0.028330982895568013, 0.029104688546794932, 0.030036141397431493, 0.034714911234914325, 0.016642173686705064, 0.07674531312659383, 0.017635093063290697, 0.01955334999365732, 0.05312235552992206, 0.09190537151880562, 0.037109313416294754, 0.052452441086643375, 0.02842859015800059, 0.061982055121916346, 0.05377963861974422, 0.03734983976755757, 0.04821287053346168, 0.019904332039004657, 0.04680368052504491, 0.05177238519536331, 0.02041111500147963, 0.029226517654024065, 0.017452617503295187, 0.030606511572841555, 0.04592002755089197, 0.07241942337714136, 0.021003818255849183, 0.04742664299556054, 0.03912252257578075, 0.022948065197851975, 0.027477984331198968, 0.04957201752404217, 0.011505585935083218, 0.06388404974131845, 0.02044994787866017, 0.04879084401181899, 0.054904934877413325, 0.016226836305577308, 0.07780276224366389, 0.02713924586714711, 0.05886698672838975, 0.1335023480351083, 0.01591250522324117, 0.0591991534747649, 0.01866272639745148, 0.017973441899812315, 0.06157225230708718, 0.017696704308036715, 0.026862960985454265, 0.03253860770200845, 0.01452780794352293, 0.03762604115763679, 0.014260459447541507, 0.008504445559083251, 0.015709987965237815, 0.045420606693369336, 0.0654665163892787, 0.04913524506264366, 0.02720756241615163, 0.07203369212220423, 0.0032805561932036653, 0.040408386194030754, 0.061978541052667424, 0.009086759673664346, 0.08074606797890738, 0.05146200048329774, 0.05575166971539147, 0.0249143483597436, 0.027386690890125465, 0.04896872567769606, 0.01085797674022615, 0.026889216314884834, 0.03385843570868019, 0.01261028481167159, 0.051611324306577444, 0.013110681593389018, 0.03078932666539913, 0.011223487254028441, 0.009620166256354423, 0.009010730354930274, 0.03734784339030739, 0.07563920138636604, 0.01482818479416892, 0.037000455195084214, 0.062351997185032815, 0.0470892737939721, 0.012359873981040437, 0.0588210069690831, 0.06087855945224874, 0.00510615552229865, 0.14358247979544103, 0.005195506855670828, 0.003707117398334958, 0.09686957506346516, 0.091674452269217, 0.030099947543931194, 0.030432277562795207, 0.044067029521102086, 0.034681162069318816, 0.0309614975049044, 0.027255353015789296, 0.07574929899419658, 0.027258360569248907, 0.04494673426961526, 0.01866919792519184, 0.02124595321220113, 0.04998404678190127, 0.049926259453059174, 0.06043161585694179, 0.03395980937057175, 0.0256418683056836, 0.07691585124121048, 0.061900344662717544, 0.015246273687807843, 0.0559565173170995, 0.033556125563336536, 0.012183766975795152, 0.04050522162287962, 0.039862900230218656, 0.032111234540934674, 0.05359874383429997, 0.040053097836789675, 0.04828907425689977, 0.004708529959316365, 0.02353005369513994, 0.035521221288945526, 0.10630186385242268, 0.03414224040170666, 0.011341160334268352, 0.0215513803777867, 0.07148567543481477, 0.019892865857400466, 0.019525560273905285, 0.04940763181366492, 0.03783836589718703, 0.05400731839472428, 0.027722056292986963, 0.028215938873472624, 0.17419273179257289, 0.1359548937762156, 0.14972105040214956, 0.16273462475510314, 0.17591108568012714, 0.0819338827568572, 0.07742447472992353, 0.3242073016008362, 0.1195596567413304, 0.16355711733922362, 0.2330563380382955, 0.1537369450670667, 0.12765337829478085, 0.07621595403179526, 0.14067133131902665, 0.20251007401384413, 0.15741718118079007, 0.12493532180087641, 0.13339280703803524, 0.16364991548471153, 0.09068764076801017, 0.14217766845831648, 0.09979302092688158, 0.14869881619233638, 0.06932019983651116, 0.19852520112181082, 0.08612132485723123, 0.2322062969324179, 0.09463135414989665, 0.13393720204476267, 0.11587901244638488, 0.11096551243099384, 0.16878409311175346, 0.15129519015317783, 0.14743150997674093, 0.12160807338659652, 0.16316572349751368, 0.18735158897470683, 0.1534418374649249, 0.1249815576011315, 0.09800807412830181, 0.1364993629977107, 0.17407501232810318, 0.14026239310624078, 0.21373352879891172, 0.10207078346866183, 0.17229378368938342, 0.12476274278014898, 0.08314262609928846, 0.17814640479627997, 0.1399626545025967, 0.14740641054231673, 0.12079152540536597, 0.13326597400009632, 0.08519233408151194, 0.16730803559767082, 0.15564098430331796, 0.15407582453917712, 0.09279959267587401, 0.13951358094345778, 0.14734827069332823, 0.08867448355886154, 0.1720963278785348, 0.1897139786160551, 0.18826662737410516, 0.14934699313016608, 0.11218932137126103, 0.12876407650765032, 0.15894561947789043, 0.12787795218173414, 0.11199539076187648, 0.12695639772573486, 0.1481498050270602, 0.15421601623529568, 0.11776192273828201, 0.08254518237663433, 0.1430259580956772, 0.13551919371820986, 0.17916666489327326, 0.21714126312872395, 0.06870131546747871, 0.12150244350777939, 0.18511773931095377, 0.17737050424329937, 0.0865265671745874, 0.20973494101781398, 0.0950175900652539, 0.19144684891216457, 0.17467720579588786, 0.14420710096601397, 0.06836979067884386, 0.07433472099364735, 0.21204658260103315, 0.09680119357653894, 0.16176052624359727, 0.10375711368396878, 0.1725508933304809, 0.14862569980323315, 0.07556828917586245, 0.12724231753963977, 0.12446986904251389, 0.13820202788338065, 0.1668270051595755, 0.13077820593025535, 0.14036774839041755, 0.16203314677113667, 0.24176201230147853, 0.11104048418928869, 0.12182400867459364, 0.1317511170054786, 0.10512760069104843, 0.13739553600316867, 0.23780645424267277, 0.204144194140099, 0.08775895534199663, 0.1132079264789354, 0.12942368251970038, 0.17119620664743707, 0.18395371036604047, 0.20285554375732318, 0.2043010396300815, 0.19924302119761705, 0.11142443428980187, 0.1828249779646285, 0.16648321266984567, 0.2164931158768013, 0.17137411428848282, 0.16520446253707632, 0.2231793914688751, 0.17749508115230128, 0.09664094162872061, 0.16368647367926314, 0.2845671458635479, 0.19719212577911094, 0.09979218972148374, 0.11633158894255757, 0.14666757284430787, 0.08972786570666358, 0.13222261826740578, 0.23265189724043012, 0.13564736262196675, 0.13128489983500913, 0.13171973900170997, 0.1483512981212698, 0.20209558453643695, 0.31667506671510637, 0.10359963736846112, 0.0955540218274109, 0.14347252319566905, 0.15253380493959412, 0.1353045497671701, 0.20033494307426736, 0.10486891027539968, 0.16097254352644086, 0.16989390074741095, 0.12995979515835643, 0.1284329450572841, 0.11489342548884451, 0.14060522080399096, 0.16459186415886506, 0.11839415834401734, 0.10421167913591489, 0.1423451118171215, 0.1287879588198848, 0.21785262651974335, 0.087940751836868, 0.08531773477443494, 0.16366768250009045, 0.1879106488195248, 0.25300986890215427, 0.11526964241056703, 0.0733538912027143, 0.11168612298206426, 0.11675134024699219, 0.1351978734601289, 0.0983135643764399], [0.003215131237084279, 0.008267835892183939, 0.027859229303430766, 0.04985341023711953, 0.027559162299439777, 0.029640482061950024, 0.05563880018598866, 0.04634561213606503, 0.027017938118660823, 0.031845308185438626, 0.025421389218536206, 0.05416686901298817, 0.08235148183302954, 0.024009171247598715, 0.04033060169604141, 0.045752253936370835, 0.020596100875991397, 0.04511190294579137, 0.030121594136289787, 0.11077990871854126, 0.032906445776461624, 0.02718381740123732, 0.014035686108400114, 0.019116531148029026, 0.03614645102061331, 0.0959458015859127, 0.054376188054447994, 0.04024282417958602, 0.04366870773083065, 0.05101955801364966, 0.012744949362968327, 0.0073263274043711135, 0.082565086777322, 0.04143437938182615, 0.0361072359373793, 0.029248860009829514, 0.02233954863186227, 0.0212780733636464, 0.014292491468950175, 0.0471127776108915, 0.007696841848883196, 0.0040529881334805395, 0.02386014242802048, 0.07515784440329298, 0.10408461603219621, 0.06261292146518826, 0.07680404669372365, 0.04725548147689551, 0.03489691182039678, 0.01943595150805777, 0.048561149305896834, 0.053905751774436794, 0.02254862461995799, 0.038217321343836375, 0.04199536138912663, 0.019756019391934387, 0.004235266096657142, 0.024749610129219946, 0.01679857017734321, 0.042723515871330164, 0.018433066943543963, 0.012134962416894268, 0.04461121301574167, 0.009921949476847658, 0.06034098478266969, 0.018307640275452286, 0.0906394753837958, 0.027150597015861422, 0.015115288333618082, 0.019455844776530284, 0.0541628131759353, 0.024300427103298716, 0.07636542999534868, 0.032786937736091204, 0.02463050841470249, 0.09494661106145941, 0.06456795366830193, 0.025187636820191983, 0.07026589635643177, 0.06036014703568071, 0.007019827371550491, 0.005869184915354708, 0.012881163147540065, 0.024683477349753957, 0.03491463801765349, 0.034933076676679775, 0.02795845259242924, 0.028201559762237594, 0.07406679826090112, 0.05556418836931698, 0.030906226056686137, 0.037140298081794754, 0.030293874442577362, 0.010522826560190879, 0.07640201787580736, 0.0008949039329309016, 0.043198957937420346, 0.08853872990584932, 0.0930578749103006, 0.049549452523933724, 0.04431446526723448, 0.05381610775657464, 0.060832802337245084, 0.024296374976984225, 0.030636887677246705, 0.054238378652371466, 0.049235639089602046, 0.03627510232036002, 0.03458342864178121, 0.009766179173311684, 0.024658376059960574, 0.0482059388741618, 0.014701640266139293, 0.04549773810140323, 0.0361662181239808, 0.044458089396357536, 0.013328531622391893, 0.05470060306834057, 0.036347231653053313, 0.021657869292539544, 0.04967906490492169, 0.041622669668868184, 0.03155648286337964, 0.017399266362190247, 0.07329149142606184, 0.04269840159395244, 0.008949191469582729, 0.06478420807980001, 0.01924578915350139, 0.028284426116442773, 0.015942257923597936, 0.029664360663446132, 0.05753390767495148, 0.04901601903839037, 0.08421270656981505, 0.03282038262113929, 0.021951373855699785, 0.0678982597310096, 0.03877770221151877, 0.0677808297041338, 0.0665511132683605, 0.021900145256950054, 0.02402396967227105, 0.019474083055683877, 0.05337835937098134, 0.01580629646923626, 0.0419871792109916, 0.03341121751873288, 0.08908604155294597, 0.019726170212379657, 0.05140676243172493, 0.013760403126070742, 0.04892030054179486, 0.03650091188319493, 0.02373992192588048, 0.0499055609543575, 0.022036715272406582, 0.025768782979866955, 0.06589225682546385, 0.028949217885383405, 0.029859912865504157, 0.05852418871654663, 0.07281259095179848, 0.020142416724411305, 0.03271458204835653, 0.07733821490546688, 0.06375018114340492, 0.013100753512844676, 0.04083088344486896, 0.00526040164004371, 0.0407228490075795, 0.022515198288601823, 0.01414568909240188, 0.04795670713065192, 0.04582754110742826, 0.05256942211417481, 0.04300253371184226, 0.03104689829342533, 0.04899971034319606, 0.0396598078077659, 0.0016978338521767, 0.06610862255911343, 0.052779509278479964, 0.031971851785783656, 0.05284471808408853, 0.04141536555835046, 0.03459821964497678, 0.04470912826946005, 0.04000903652922716, 0.06176517730636988, 0.034955467272084206, 0.05031784254242666, 0.030808757946942933, 0.046773664362262934, 0.012844849861721741, 0.020463453111005947, 0.0386478486325359, 0.01868286643002648, 0.03976956402766518, 0.013687114187632687, 0.01112485675548669, 0.07579508950584568, 0.015306267050618771, 0.02660155987541657, 0.050573401094879955, 0.14704456902109087, 0.0262195560571854, 0.08184628706658259, 0.01725821006402839, 0.007620833866894827, 0.023561468806292396, 0.05542611179407686, 0.015509724980802275, 0.03167369024595246, 0.015465648830286227, 0.03944072210288141, 0.0059052185042673955, 0.037929074896965176, 0.032937545474851504, 0.08433804789092392, 0.040229903388535604, 0.04108049368369393, 0.07622684133821167, 0.0789479554805439, 0.03569270935258828, 0.03769731702050194, 0.06979240613873117, 0.06762239601812325, 0.02754916000412777, 0.040297257000929676, 0.028062279052392114, 0.08508768383762799, 0.0250745613448089, 0.043888843574677594, 0.07316456933040172, 0.047437630491913296, 0.024825568943924736, 0.020233934665156994, 0.004133973607167718, 0.035264738762634806, 0.07708353208727203, 0.048594338149996474, 0.08148820081260055, 0.03921016279491596, 0.0518285583530087, 0.01647146673349198, 0.04322355271142442, 0.01605892724910518, 0.09472156962146983, 0.030174770872690715, 0.025283412833232433, 0.010806839054566808, 0.019790224978351034, 0.08471845052554272, 0.08628403331385925, 0.038919994185562246, 0.05723729351302609, 0.022858107622596435, 0.06411870941519737, 0.06614516591071151, 0.02667953918717103, 0.03883753415721003, 0.01742247517540818, 0.02163705947168637, 0.032453776511829346, 0.05445099654025398, 0.045419215166475624, 0.031335452731582336, 0.029733588198723737, 0.06155222174129449, 0.031204489641822875, 0.015144845292525133, 0.12260065879672766, 0.056119162691175006, 0.06128812106908299, 0.04514820138865616, 0.03301118878880516, 0.07064353078021668, 0.029809372608724516, 0.06953485863050446, 0.07879263881477527, 0.09721337497467175, 0.029565705117420293, 0.06830750964581966, 0.03912837441021111, 0.04861941903072875, 0.03997585881734267, 0.041568021624698304, 0.06274344297708012, 0.02527885233575944, 0.08016825406230055, 0.04938330050208606, 0.02168806913687149, 0.023442072088073473, 0.09088287013582885, 0.0112556983185641, 0.020971904050384182, 0.01891319752758136, 0.015948881591612007, 0.03396196902031079, 0.12262085263500921, 0.03964222632930614, 0.027470364329928998, 0.059168246734770946, 0.026006453917943873, 0.0354708331724396, 0.05466149559651967, 0.05258245422737673, 0.03814107309153769, 0.08193557485355996, 0.04501228817389347, 0.03818720499111805, 0.04438551848579664, 0.014473460469162092, 0.0382523507141741, 0.04818498433451168, 0.038175779627636075, 0.02649587990163127, 0.0070825750299263746, 0.025635936690378003, 0.09516339981928468, 0.030960250696807634, 0.03934897038561758, 0.07330841239308938, 0.07992146769538522, 0.02303091670910362, 0.03688523305754643, 0.013287033507367596, 0.07156799445510842, 0.029821820280631073, 0.02989080847328296, 0.028160825131635647, 0.028452617189032026, 0.022635704517597333, 0.006927565427758964, 0.039615445930394344, 0.05482756969286129, 0.07162566675106063, 0.010402656153019052, 0.03515052594593726, 0.019453507011348847, 0.098199696658412, 0.043486699723871425, 0.009484136153332656, 0.047585596184944734, 0.018152989687223453, 0.03105275383859407, 0.06637321304879151, 0.07693195584579371, 0.023086403380148113, 0.0431957370165037, 0.021621674750349484, 0.08836361274006777, 0.12998743273783475, 0.17962079989956692, 0.12399341765558347, 0.15965882339514792, 0.1647878356743604, 0.17098739597713575, 0.11972456937655807, 0.18888213497120887, 0.15698059054557234, 0.16461841820273548, 0.19274287624284625, 0.10911318604485132, 0.10406732399133034, 0.08905859693186358, 0.16810905042802915, 0.08917561877751723, 0.1421267125988379, 0.13132844906067476, 0.1529160258360207, 0.13341533864149824, 0.09511207288596779, 0.17642012477153912, 0.10885965355555527, 0.11801640517660417, 0.17530519631691277, 0.10677176949684508, 0.08772583329118788, 0.11133508713101037, 0.2540852111997083, 0.17201927810674533, 0.1770022654091008, 0.16609217505902052, 0.11476233252324164, 0.10255967325065285, 0.11712867039022967, 0.061977097575436346, 0.11553685268154368, 0.20627522666472942, 0.10445009407703765, 0.10782532976008952, 0.15862508589634672, 0.0760089245159179, 0.12513590947492048, 0.18529215885791928, 0.14263245655456558, 0.1556615566369146, 0.13123119802912697, 0.11096079237177037, 0.08920191306970082, 0.1424221764318645, 0.19114178168820217, 0.15399349067592993, 0.1179071981459856, 0.2104725467506796, 0.21850887802429497, 0.07931663218187168, 0.1004491165804211, 0.11170319237862714, 0.11562598461750895, 0.08192873225198127, 0.09533860604278743, 0.11858688667416573, 0.08421385689871386, 0.1592070929473266, 0.11328300213790499, 0.19769433711189777, 0.14042973256437108, 0.1516660413471982, 0.04527179124124814, 0.1403790884069167, 0.06914871919434518, 0.20126112853176892, 0.12073809819412418, 0.0587497199740028, 0.1888859792961739, 0.15807910269359127, 0.16541512857656926, 0.16600059403572232, 0.131718625780195, 0.16857357550179586, 0.21345032524550334, 0.12525505386292934, 0.10574871150311083, 0.13613554736366495, 0.16046050615841523, 0.08699104771949351, 0.11647854160401039, 0.20846667001023889, 0.1480758871184662, 0.1361483716755174, 0.1465843929327093, 0.13611212518298998, 0.15426812984514982, 0.11068184874602593, 0.10237024005618878, 0.2009361717500724, 0.19020956999156624, 0.2235243417089805, 0.07461197252268903, 0.10162408478208818, 0.23574239312438294, 0.16280738491332158, 0.17626762826694176, 0.15474029903998598, 0.17858911072835326, 0.23219721304485574, 0.130870885332115, 0.07714939027209766, 0.20896754547720775, 0.12116031342884526, 0.1527083432301879, 0.105768504581647, 0.13054002105491236, 0.16748811030993238, 0.137375631602481, 0.06739315402228385, 0.18445719819283113, 0.12892013532109559, 0.19288296403829008, 0.1559358841041103, 0.08239408853114583, 0.12372455981676467, 0.09145596399321221, 0.1902497498667799, 0.1355847402010113, 0.1466283726040274, 0.17757226451067254, 0.08913765792385675, 0.11483791284263134, 0.19838981854263693, 0.10737140255514532, 0.10725677784648724, 0.1361742874723859, 0.18488129106117412, 0.12231069427798502, 0.15663069760194048, 0.08250207101809792, 0.13903391605708748, 0.18804065824951977, 0.09118508751271293, 0.17626791028305888, 0.1482169990777038, 0.11841742467368022, 0.27175467868801206, 0.142586903530173, 0.12913572922116145, 0.07360061819781549, 0.15750105871120468, 0.10657524879206903, 0.10577135442872532, 0.08925573361921124, 0.25706255924887955, 0.17700017255265266, 0.09936026719515212, 0.13624672108562663, 0.11082254510256462, 0.13735387183260173, 0.12364880880340934, 0.10644889815011993, 0.215171113377437, 0.11015709838829935, 0.15161186456680298, 0.1678062096470967, 0.11464203780633397, 0.1291773933917284, 0.16268110106466338, 0.08517684545950033, 0.1608383929124102, 0.04152990863076411, 0.15914668212644756, 0.11107638929388486, 0.20458443614188582, 0.12056685503921472, 0.10503325145691633, 0.08834526684950106], [0.06154123053420335, 0.018570525680843275, 0.033337911881972104, 0.05726146155211609, 0.0333776835759636, 0.05883698911929969, 0.040638637510710396, 0.014194928735378198, 0.020088998790015467, 0.09911100947647355, 0.043645604673656635, 0.017686445971776266, 0.011067137147620087, 0.031931571720633656, 0.022152852106955834, 0.1220960429054685, 0.02899993440223625, 0.0387810381653253, 0.04266857467882801, 0.03247633409046102, 0.03668362493044697, 0.03709834076289553, 0.07305205974262208, 0.005746107144659618, 0.05981343281746376, 0.055712105822749436, 0.0676219210436102, 0.05898432027606759, 0.07139759734855033, 0.04353425283625256, 0.00934285628318321, 0.07281740749021992, 0.026461696579644922, 0.06126945976575371, 0.03997017025540117, 0.053114488764549606, 0.028126461838837713, 0.029218992276582867, 0.03140534077829216, 0.023943563537613954, 0.04806252254638821, 0.0263608461318654, 0.026255993652739562, 0.0675177680386696, 0.015733168947917875, 0.06253031300730072, 0.02594636407593498, 0.04957005083269905, 0.007204460725915851, 0.017329101865470875, 0.0384406261582626, 0.07019621611107141, 0.03152315672195982, 0.05798547113954555, 0.058792070631170645, 0.050949391661561094, 0.017429208310204558, 0.041451545257586986, 0.011953182620345615, 0.018266304505232256, 0.025452097434026655, 0.02417901916487608, 0.021500216716958676, 0.03159005020279437, 0.02864922509616008, 0.08679475708049722, 0.07524362925323658, 0.023549956240458414, 0.06364068467519246, 0.06697533230180852, 0.032470986916450784, 0.041137787484331056, 0.06740680211805739, 0.04612745782651473, 0.048808521969476715, 0.03467928814643528, 0.0177849252577289, 0.03302406876173336, 0.01278392324820743, 0.04807012213859707, 0.06120078884123359, 0.0390897344914265, 0.04874202924838755, 0.06559688947163522, 0.04097503449884243, 0.01983626039873343, 0.03517731005558744, 0.07038553056190722, 0.06957546895137057, 0.02605821686302079, 0.016901871567824855, 0.048481071571586654, 0.02651358754519606, 0.07140839559724554, 0.030395355715882033, 0.02034249231655849, 0.011089909021393396, 0.056678912733332254, 0.0791002664482221, 0.03989807803009171, 0.08040761153097264, 0.03268652886617929, 0.027503126439114567, 0.05010882407077588, 0.037748640243080445, 0.03261612873757258, 0.02371998783928575, 0.026763216337712947, 0.0631718328804709, 0.015973277841112576, 0.028113045664213132, 0.014372279765666462, 0.06409867142792791, 0.06302581532509066, 0.019588529648899566, 0.030838124730507843, 0.05601951452263165, 0.03612432388763409, 0.02360652644711081, 0.019779311696765944, 0.05178741368581541, 0.025560059511917643, 0.04356091078079771, 0.02188902046327712, 0.019884967550751753, 0.011956222642766079, 0.07510220559197478, 0.03404788003535941, 0.029170737834647298, 0.040989565750351176, 0.012766181280312594, 0.035373652644921094, 0.049266208152403124, 0.05863754064193927, 0.02240871308458736, 0.050511557928984985, 0.033948079726542346, 0.0158534506772412, 0.07948949321871623, 0.030876115270075388, 0.04018730411189608, 0.04500151590036694, 0.036381737809279, 0.007526159015469602, 0.02613254851894453, 0.038001590146450326, 0.015819968684809282, 0.0366161822603317, 0.005740042406614521, 0.060787713155150414, 0.04566180468827952, 0.1052042274386622, 0.02418887674139114, 0.004140432147323736, 0.10396144178230315, 0.024843989049259108, 0.054020959069021046, 0.007367887210421031, 0.025744464655872434, 0.06087163892516401, 0.07023284852039069, 0.09922869925503619, 0.03698020940646529, 0.05326536738721188, 0.011053209818783216, 0.027343108267814387, 0.017458478614571504, 0.028775061800843105, 0.02167242651921697, 0.06690709182294086, 0.02147454026271589, 0.02570004897279432, 0.011226318547414849, 0.03269426946644671, 0.02906857007474173, 0.03664285504783038, 0.11128429454402067, 0.10584916119114496, 0.07686221622861922, 0.02314808327355422, 0.017568635594216175, 0.014432916013902286, 0.10549361308221705, 0.049219504799111746, 0.01234357549037668, 0.07505416637286544, 0.0549760066496674, 0.07504610664909706, 0.03401404552278109, 0.05927369849814568, 0.018991085926245432, 0.018728523355093785, 0.045889046596130356, 0.013575330976891564, 0.02950976944703143, 0.02751337920926744, 0.026804357294167858, 0.01246714215085376, 0.08220934570999816, 0.057103172584902495, 0.028601907615666278, 0.02959395496873185, 0.04491751591558568, 0.05156405321031343, 0.05974719242658466, 0.04536567663308233, 0.037279168755048886, 0.041148229502141476, 0.007190648893811158, 0.07195023019448854, 0.06178464012918994, 0.042237449961248785, 0.030487931217066944, 0.014444125226873439, 0.036934689778718166, 0.0717422655725386, 0.08764636411797255, 0.018410752418276388, 0.011385079706087708, 0.02608726266771555, 0.0221828923895373, 0.04043653214466758, 0.02028089034865843, 0.06770875974325463, 0.021654746706190053, 0.039279126867768355, 0.014225390186766163, 0.011836744288302725, 0.04555240841000341, 0.09056081515154801, 0.0065704184544301825, 0.04385681990243029, 0.03939045644074213, 0.04013707926787902, 0.034541994536994025, 0.0373945838509826, 0.026997172826668248, 0.035868212435161695, 0.026483931324037258, 0.02989116470416775, 0.038064030741225, 0.06900182590470649, 0.06423257713322528, 0.03617209593357984, 0.026550936127023306, 0.014192425842338707, 0.03666605829494074, 0.051599334910861216, 0.037964590374031104, 0.046018250795896165, 0.04766965183080174, 0.03527580789523199, 0.07016638177447021, 0.026608567604853306, 0.013068001608189661, 0.0063480074641120154, 0.005131149664521217, 0.04271798316040076, 0.027671028074109927, 0.0952184597554151, 0.04657132150896359, 0.08809537830529734, 0.047804533460293896, 0.019046563320443965, 0.07929001876618713, 0.022973029190325178, 0.06459576194174588, 0.04607629787642509, 0.039082595030777156, 0.07284826599061489, 0.013128661976224976, 0.0428182324685622, 0.053253711957950145, 0.04786676254298072, 0.05170112046471331, 0.029683149987249635, 0.05198867671424523, 0.024938141614256892, 0.07546794338850304, 0.009859775127551984, 0.0256704632556648, 0.04821948677999899, 0.01716760867566336, 0.012870730406575603, 0.03380591020686552, 0.0424322525941534, 0.014744216350663919, 0.06593740909011103, 0.025799988434300758, 0.041238233461626805, 0.019217307381040882, 0.03807219065492973, 0.022581208613701165, 0.019057958998018876, 0.03557287476724014, 0.006160435668789432, 0.05329163570422679, 0.052883194730384275, 0.016274586087092757, 0.024676172761246562, 0.031841634554439224, 0.050778976001311094, 0.16564727236982435, 0.022040962212486193, 0.03706407209392637, 0.007320492732105777, 0.029557855050370563, 0.053517987034865655, 0.05958383459073957, 0.05817638862936292, 0.028980352835787926, 0.009781256831047358, 0.06467012513894588, 0.04249139063176699, 0.05071115854661912, 0.05084529060695786, 0.05687489909178112, 0.014111913951637689, 0.015088298277987633, 0.05135525367222726, 0.014068861037230818, 0.008311715373565676, 0.06499689276097342, 0.024422940841759555, 0.018367828452028334, 0.02754516539425822, 0.026449916840647347, 0.035294758636155166, 0.020077864719496574, 0.014969587118685013, 0.04422924444952514, 0.016122245433507487, 0.012295164269744419, 0.029105003959557507, 0.049750407561077736, 0.02287285780766979, 0.07225465917144902, 0.02033366632531397, 0.024425749870715663, 0.03848485073831398, 0.09186514711473137, 0.027204514044569805, 0.04955930824507959, 0.06085174565669149, 0.0024531923372705933, 0.053568505027214997, 0.01034468885336537, 0.0665693255723454, 0.05745280206610914, 0.04438865405973047, 0.04710997971415054, 0.012486515915952623, 0.21759142022347078, 0.17778572102542967, 0.14058141270652413, 0.15284191496903077, 0.1056084678566549, 0.13918614538852125, 0.22873197711305693, 0.17311238741967827, 0.07534613469033502, 0.18715003650868312, 0.17174549982883036, 0.15869656956056133, 0.10168927503400482, 0.14871845341986045, 0.11525355264893733, 0.32368975749704987, 0.09117500914726406, 0.14087226038100198, 0.13019936042837799, 0.1499516802141443, 0.12210678920382634, 0.12291864681174047, 0.1771693376940675, 0.18841182114556432, 0.17142505530500785, 0.17821931338403374, 0.1493230217602104, 0.12561248702695593, 0.10303533796104603, 0.24374351691221818, 0.13236678787507117, 0.27025646064430475, 0.09050523571204394, 0.18421031534671783, 0.13346252439077944, 0.20784592285053805, 0.10170473397010937, 0.1138703155447729, 0.11282232138910331, 0.14849148981738836, 0.21631963143590838, 0.13028962042881176, 0.08615377897513099, 0.1298076251987368, 0.07921247917693108, 0.12108743452699855, 0.10235613182885572, 0.18708609306486323, 0.10982685009366833, 0.18600905867060646, 0.13854617660399526, 0.12248317681951448, 0.10508052626391873, 0.17949332861462608, 0.06722598525811918, 0.19651372858788818, 0.07340706608374603, 0.12655415368499234, 0.08909024210879579, 0.1878839315031655, 0.14562829892383888, 0.21085375832626596, 0.14073572005145252, 0.12237511269631796, 0.16524765553185716, 0.16746327804867178, 0.19585802627261728, 0.08476658622385003, 0.12554130022181198, 0.10909414253546856, 0.12172959264717065, 0.10018531276728027, 0.19356216274900362, 0.1446045804186724, 0.1751391778816469, 0.13049804518232122, 0.16188798268558457, 0.1379670194000937, 0.09151448975899257, 0.17259543703403324, 0.07694543324760161, 0.17516717169201002, 0.1580191816901788, 0.17577634134795517, 0.14786563668167219, 0.10563534102402627, 0.11169240897288546, 0.1263055342133157, 0.19096038595307618, 0.10622686240822077, 0.12579777161590755, 0.14249925588956103, 0.16267232887912542, 0.10961990221403539, 0.13423567899735644, 0.19063799700234085, 0.23043710592901334, 0.19139163312502205, 0.17661902034888044, 0.15828939765924588, 0.12974883225979283, 0.11541113286511973, 0.1770495402161032, 0.14259521558415145, 0.15876196761382744, 0.11768048687372357, 0.07689255522564054, 0.07735181847237982, 0.14646296272985637, 0.07920073097920977, 0.11162985334522091, 0.18245325103634968, 0.1413335496908985, 0.1630344078876078, 0.1436525979079306, 0.11891998481587507, 0.1901494708727114, 0.10472045105416328, 0.1282144122524187, 0.14425237197428942, 0.15796160587342456, 0.16017623391235247, 0.14779206016100943, 0.11287835353869013, 0.10512072098208591, 0.09879482488031499, 0.22681662754621357, 0.12294712301809341, 0.151132348109968, 0.17083516664570197, 0.09394639637321234, 0.06716815711115487, 0.15535965096205473, 0.1631342267501168, 0.10414613265311345, 0.14676293882075697, 0.18052559666102752, 0.14265489910030738, 0.13723437121370807, 0.19748371560126543, 0.16105857328511775, 0.09822947904467583, 0.07704226867645048, 0.12364717607852072, 0.14075057784793898, 0.06824634925578721, 0.15326406341046095, 0.08129452995490283, 0.07603347476106137, 0.15552020719042048, 0.1780622749356553, 0.16331436083419248, 0.08559460038668476, 0.11670370178762823, 0.1723295997362584, 0.08513397900969721, 0.1380727902869694, 0.11563483101781458, 0.1308282563695684, 0.17613387841265649, 0.3145376517204568, 0.27733168099075556, 0.18041050439933315, 0.16659615270327777, 0.15608793532010168, 0.20353440108010545, 0.049694163899403065, 0.16707899398170412, 0.06875610823044553, 0.14186985528795049, 0.10578586341580376, 0.15906074142549187, 0.12223436438944191, 0.12816017610020936, 0.0736140733351931, 0.08657617974677123], [0.023274829109141137, 0.04210735147353262, 0.016149081493495032, 0.048073361613205634, 0.03988716103776824, 0.04401863778184634, 0.03181052743457258, 0.025771573455131147, 0.03297666407888755, 0.056586418868391775, 0.026937953152810223, 0.04959946956660133, 0.019221841903345194, 0.03836567666439805, 0.06621494263526984, 0.028230353236722294, 0.02690789431653684, 0.043230825758655556, 0.08598928936407901, 0.05673396895872429, 0.06400626662070863, 0.03258259850554168, 0.015310205071727978, 0.03347336867591366, 0.02904862671130104, 0.015413719829666661, 0.005992603610138758, 0.03977691871114075, 0.03261221390857827, 0.06544824471347965, 0.025529384693072643, 0.04055295285070315, 0.012915952247567475, 0.03679885448946152, 0.04506421624682844, 0.005949817405053182, 0.03260945311922114, 0.11319136916426942, 0.057571015058783814, 0.01923715797602199, 0.024649681799928658, 0.013121669089741772, 0.0317966900911415, 0.02775371445750352, 0.02330651510419557, 0.03324563323985785, 0.04493266314966604, 0.043198141574976034, 0.08159757111570798, 0.10134540090803057, 0.05254867166513577, 0.02843942551407963, 0.041194602599716745, 0.051815400074701756, 0.0537312839878723, 0.03532133865519427, 0.05993261802359484, 0.017845972470240667, 0.03583111989428289, 0.03762937711144332, 0.01767691308486974, 0.025772259941732045, 0.007872059668443399, 0.06526361321448348, 0.023377909710688982, 0.03263987004174851, 0.07080373077769764, 0.04817302091396414, 0.045167886855779216, 0.009832798987190472, 0.028544912529469002, 0.05227697140071541, 0.036058090918231755, 0.018941259986604564, 0.03003501333296299, 0.05854126553458627, 0.030445426564256195, 0.0270488838214078, 0.01384179353408399, 0.012028333421767456, 0.03438502288190648, 0.040101949707604945, 0.03375677260919474, 0.011336973693687469, 0.008565575335524045, 0.014698984305141494, 0.007556500331702409, 0.025959609556593932, 0.05968498931906652, 0.054651150057907216, 0.048252924243570305, 0.030904454179108143, 0.03216965269530192, 0.02411398290860234, 0.033257307222811505, 0.011456888987595448, 0.07429144636262208, 0.09720840258523822, 0.016073423248599283, 0.018194659423897974, 0.011124558968731435, 0.028954381377843674, 0.025965145978261717, 0.07146439063944854, 0.018827342173608486, 0.005624141667794902, 0.06677202094579116, 0.05266833926725667, 0.011915881350432755, 0.03999968546850141, 0.016662165289744735, 0.008829421822156291, 0.0315828958991915, 0.010802054985106224, 0.044130661262897775, 0.05027749197324738, 0.03036125588550931, 0.09259343889425509, 0.038988468440948054, 0.009478999563725665, 0.0203285918905749, 0.0755675247637555, 0.04746062222693581, 0.051640197561937384, 0.06149509863462299, 0.017467284196754918, 0.037531127891270444, 0.020336210036475677, 0.05931794163188897, 0.10040420180303045, 0.061990831018192694, 0.0999374057573732, 0.09243346154107712, 0.02087163804390002, 0.01607478508958593, 0.0832183548482135, 0.03228501584089827, 0.03416955514694564, 0.02540374465752393, 0.0402318737906171, 0.03176182770403102, 0.007689952399232425, 0.030100741641945206, 0.005283910559228389, 0.08741023499169387, 0.0310386493219994, 0.011663450022751931, 0.06021441520715598, 0.009748201573529514, 0.032707331265555695, 0.0673705482040532, 0.07156196821597405, 0.0036559801765179145, 0.045841237442800775, 0.014889694921293994, 0.055589499315829016, 0.03491723553452175, 0.004274658367648954, 0.048886992954066955, 0.04473867687920574, 0.06570562152774073, 0.025696705597511027, 0.03980017761932686, 0.052144891378702596, 0.04833925828279462, 0.039837997464928776, 0.038424239537562244, 0.025084096087084617, 0.015492756701860344, 0.035077290813205764, 0.09370558429509401, 0.05394677398726344, 0.07285943531314842, 0.03822609724011272, 0.0385150784131838, 0.10991254588589072, 0.017084005739889108, 0.014615085437981179, 0.014234716200007824, 0.053954021059325896, 0.016585080265940633, 0.05161535787920002, 0.04015699109004345, 0.04986418251064606, 0.019567525014281273, 0.050366757495794445, 0.027122901919938158, 0.03383034170838073, 0.027741533958760556, 0.044639715197263286, 0.10517383649130352, 0.010746056232164847, 0.03902333082805853, 0.014519377145916224, 0.02086459320707945, 0.0829243753105402, 0.042758920026244596, 0.00986867533356417, 0.010025419705925742, 0.013339777942746878, 0.02195009550632676, 0.07596857394673862, 0.008016966785362456, 0.07332449473324232, 0.055967853622860275, 0.014642808364442317, 0.0017002640379359946, 0.0721440272172913, 0.02176194993808167, 0.02794670253933873, 0.037654895859304816, 0.1256525333155878, 0.011345955535944086, 0.13018797588301823, 0.04988926710211672, 0.010444320323585998, 0.023040171290631406, 0.032690072621335275, 0.04156958013481926, 0.013259335628390545, 0.002425761863378284, 0.014169089936331147, 0.06344288005493581, 0.010754175327747362, 0.05173578618268948, 0.07216376092401333, 0.07763849527691491, 0.02567499592259992, 0.0007599617140385817, 0.11422704366850667, 0.07545845131971873, 0.04828944904147647, 0.039868829990155064, 0.019295746824354865, 0.06988209468545392, 0.05031928973039612, 0.03744521316548344, 0.05001060453651007, 0.0423782056896016, 0.0969993692706339, 0.03317567097838037, 0.04525737873336766, 0.06854462582850829, 0.06896229911944829, 0.06589070573681965, 0.03126156821963377, 0.04477692717046011, 0.030782387584622484, 0.021979467855999246, 0.012312839444348356, 0.0210145923847449, 0.042799200091394596, 0.08973985881311819, 0.011009947247657692, 0.03338402522786055, 0.05502456166141201, 0.043400495560490526, 0.02715707782044774, 0.014977838873164728, 0.0006218213604824996, 0.005217938733039773, 0.030270849310909398, 0.011922686844627606, 0.0297182368740323, 0.041362250049132854, 0.06913380202604458, 0.08132831993862055, 0.04283359863620717, 0.07189969735918567, 0.03052759901038371, 0.046302263290272094, 0.0360348208778305, 0.08296681131469086, 0.04973785413312726, 0.01924574091390241, 0.03989821161667351, 0.06623844645218924, 0.0592282567959046, 0.012003568881482352, 0.07818097554263659, 0.020424785361683462, 0.038553310150746256, 0.043348589751985855, 0.06704879007884301, 0.01720810767437797, 0.049151464700116776, 0.04249029967468232, 0.04908451184746809, 0.06761461088899523, 0.015835234662517905, 0.05690370555385016, 0.011433053059590748, 0.02631066210597055, 0.035831995628541335, 0.04585762777423952, 0.030461174937954638, 0.04161065058724489, 0.013411377567535965, 0.04067587848112453, 0.06766267979401164, 0.008643974888400408, 0.05853235976246651, 0.05080910348624457, 0.024593755406385753, 0.09619168253266253, 0.11853987904032692, 0.03245386928028893, 0.0705486249353271, 0.008756610641285079, 0.05248072433460038, 0.007691617593081901, 0.041256445765611716, 0.01716871262033237, 0.03374147694557905, 0.06079746497562155, 0.04897414706647396, 0.05199535604333505, 0.008985554850369226, 0.033127550123026595, 0.04569453340081964, 0.03737618601007853, 0.008369877486984478, 0.06949932459974661, 0.023517904737673234, 0.04058846832776908, 0.036286390386521816, 0.03946055599953979, 0.034264887726749294, 0.014746839842700865, 0.0814269958937075, 0.04246408701874316, 0.04657091703847982, 0.015936528543534223, 0.0611638929694891, 0.07679866612306796, 0.05791943855001591, 0.02973913389723748, 0.023354906843451317, 0.026017424715973902, 0.02362000013818033, 0.029931350145488977, 0.009541206381982192, 0.0651946899597533, 0.03401325513550546, 0.033204529390786774, 0.025487546117801685, 0.0685067317681387, 0.058622549258871004, 0.05211483068706002, 0.07937637506984174, 0.07483462424715981, 0.09399536327691749, 0.10428725203382783, 0.0858858933497686, 0.09971594146918505, 0.15587723959470168, 0.16887892474187538, 0.19501978531479836, 0.12288910191273317, 0.13745385396759957, 0.0773797083820682, 0.17628027446335182, 0.0829615123802796, 0.13461871625622734, 0.07701837152126245, 0.23013297381112352, 0.1761435708613135, 0.10767684827442281, 0.09799447798286565, 0.08631178963696584, 0.16785823419922963, 0.2921456313924864, 0.15608119661919773, 0.13898238132242113, 0.10883502909564413, 0.13055327581241727, 0.09972432773793116, 0.24644613673444837, 0.13366925704758614, 0.18361560272751376, 0.12844625918660313, 0.21938887221040204, 0.12049154189298861, 0.28898319171275944, 0.1007271176786162, 0.1791775447782129, 0.15121827396797016, 0.2006340879597701, 0.11096766465925612, 0.2537802478764206, 0.140298995829653, 0.17024512955686077, 0.11202351073734462, 0.08000394998816773, 0.1571862248238176, 0.11137957146274857, 0.07299047632841393, 0.1267008317518048, 0.1229424771736376, 0.14855418645311147, 0.21820102032506838, 0.18993500503711402, 0.13945615355623886, 0.10518864233745262, 0.1154169141955208, 0.1824923325330019, 0.16810057510156184, 0.10195062233833596, 0.12187630782136694, 0.11270644245087169, 0.15188582096016034, 0.10330285993404686, 0.1454514154465869, 0.21186589932767674, 0.16314448323100805, 0.17467140220105648, 0.09566004504449666, 0.12918576481752098, 0.2336766102234833, 0.20260468299966305, 0.20725815673358738, 0.13417943904642016, 0.15640205674571916, 0.10316933272406459, 0.1615103631047532, 0.1909599406644702, 0.1138081458339002, 0.1669188088271767, 0.19260614295490086, 0.15189527592156082, 0.13516747509129345, 0.11768546668463387, 0.10455502633703873, 0.10071609678561799, 0.08711739836144261, 0.0991490890737623, 0.09959434799384326, 0.07642339172889479, 0.10106210087542422, 0.1362739282194525, 0.17482980620115995, 0.0992011655762326, 0.14826047408860177, 0.24972684506792575, 0.1279611320933327, 0.11908723521628417, 0.1194888781174086, 0.11998484056675807, 0.16806645115138963, 0.14903141709510237, 0.1395857919123955, 0.09297927404986694, 0.10961662934278138, 0.10054245649371296, 0.1379862558678724, 0.28713984531350434, 0.12075777252903208, 0.09962449403246865, 0.19173587090335786, 0.1715100312139839, 0.10797209688462317, 0.18749132053926587, 0.16924041003221646, 0.1954827518784441, 0.14165521133691072, 0.1046032139856834, 0.13163936440832913, 0.15630879846867174, 0.09122888906858861, 0.25855576037429273, 0.13654899783432484, 0.1441097163478844, 0.13183257513446733, 0.14175626216456294, 0.30455671541858464, 0.11720605412847362, 0.15844787587411702, 0.17201406823005527, 0.12769290508003905, 0.09767537674633786, 0.16702622728189453, 0.21448118321131915, 0.11828105503809638, 0.1507495780242607, 0.1570749472011812, 0.11874094168888405, 0.09864289240795188, 0.2669002313632518, 0.07058785486151464, 0.1641844547702931, 0.09398910697200336, 0.13049476488959044, 0.10012082013417967, 0.0745586863195058, 0.13170198682928458, 0.20942418894264847, 0.14352502272231504, 0.15471810882445425, 0.13172842212952673, 0.1516710434225388, 0.20328535116277635, 0.13249132025521249, 0.13529997813748196, 0.1292676237062551, 0.10114070173585787, 0.10820684561622329, 0.15781233028974384, 0.1063383107248228, 0.14057339751161635, 0.2695512125501409, 0.1976919177104719, 0.1484695667750202, 0.12337081512669101, 0.11900230383616872, 0.12055175975547172, 0.11029090761439875, 0.18599326576804742, 0.08965839326265268, 0.22195737110450864, 0.1311302065732889, 0.16739828075515106, 0.09612621026462875, 0.14990364841651171, 0.11889342335052788, 0.17764986347174272, 0.12687250535236672, 0.15190812991932034, 0.23015359067358077], [0.025985671927628573, 0.057232881445088424, 0.03338047034048941, 0.008130660098686349, 0.04169744475802872, 0.008956883830251172, 0.005836988693772582, 0.10617016974720173, 0.11312243848806247, 0.10175966774113476, 0.06891422279295512, 0.008586946405557683, 0.027830331928271335, 0.03854523558402434, 0.01555475571876741, 0.020959949906682596, 0.025567748161847703, 0.07884277831180952, 0.008768553652771516, 0.05682490431354381, 0.08419188932748511, 0.034201474918518215, 0.007361667085206136, 0.06936960460734554, 0.06384681619238108, 0.0025620211044952157, 0.06123587387264706, 0.06729935397743247, 0.027224386903981213, 0.03664185314846691, 0.03548629210854415, 0.038305032067000866, 0.04694520808698144, 0.04263276976416819, 0.017106895429606084, 0.008063347304414492, 0.04360824867035262, 0.05963633411738556, 0.03653944419056643, 0.023829252386349253, 0.02717285959079163, 0.07058786228299141, 0.042451092012925074, 0.024257979966932908, 0.032447854173369706, 0.06845982803497463, 0.04020491527626291, 0.07224950866657309, 0.012037392261845525, 0.0330822234536754, 0.025093000003835186, 0.03984962320828345, 0.013948543128208257, 0.06723072016029619, 0.029179523007769603, 0.029116915429767687, 0.007393858668365283, 0.007504253135266481, 0.06154689683171455, 0.06285251642111689, 0.014666062634205446, 0.035390992925385945, 0.040960291735245846, 0.04763785080285743, 0.03576643801352475, 0.03813100585830398, 0.03346031058754306, 0.06055574005586095, 0.012830589494114975, 0.06531850245664828, 0.027051472061430104, 0.046315265717566945, 0.036530672005028464, 0.06326043789158575, 0.011778334483096842, 0.0441179742483655, 0.038448466948466375, 0.08116947064991109, 0.04666503991757054, 0.03435606056882534, 0.01394288332448923, 0.0177015987719642, 0.007473711903003277, 0.01810354780900525, 0.007828546622477006, 0.0509288527246099, 0.07558808967587538, 0.051683383135241456, 0.011198902684554923, 0.015003951339167543, 0.05388130171922967, 0.022959275338507723, 0.007387898294837214, 0.04298079620639328, 0.013638955297210487, 0.015948775835568085, 0.011410728329792619, 0.09129957121331245, 0.024160281791409943, 0.025795398250920698, 0.027523101343831513, 0.051433624466881156, 0.03169537951180246, 0.06190083076944575, 0.009949063842213945, 0.03862898323859554, 0.02214550484495703, 0.014249499781726627, 0.07436959451297298, 0.03871404078381602, 0.03570850967662409, 0.03639620597823523, 0.06327778930426575, 0.03918031361536123, 0.008661015526740812, 0.03619981143856421, 0.006899450090713799, 0.04329687690187711, 0.029521424876293167, 0.024720406618143898, 0.044764789345208555, 0.021847220850759186, 0.041328434090246446, 0.022049161088943947, 0.028016985779686365, 0.02689302353246603, 0.006591285791728296, 0.04353677242761478, 0.05273770781059284, 0.03945111959183123, 0.06283203314524144, 0.04825164032808971, 0.044960575323784724, 0.03663564879389014, 0.03466794441919774, 0.06629710580455139, 0.02812958071444882, 0.05534170733881183, 0.046463602484436706, 0.040065985231194645, 0.038525813579326496, 0.050289800492464565, 0.0071402269168174826, 0.0207128240072052, 0.03491991097689606, 0.10823394142789766, 0.04067552225023974, 0.08534215885447338, 0.05699190980521962, 0.010045886283478467, 0.06645387707976624, 0.021396922747953795, 0.028870268215541728, 0.013212077519710874, 0.03420674787776079, 0.02993403857544763, 0.032016480836318806, 0.045153552273404785, 0.03579887357773259, 0.02883575092710089, 0.010655375990609173, 0.08778433679253794, 0.06486872385721654, 0.04407939370139502, 0.04851900273934007, 0.008626668004581006, 0.028903727943543345, 0.030569355949410237, 0.01223754114107578, 0.025462096018600278, 0.02616563160700025, 0.05947050864051562, 0.023885199188953266, 0.07499689483665861, 0.013490567507687956, 0.033084286624216475, 0.03327766804432031, 0.048751417416497134, 0.046682261454407126, 0.01347684705251595, 0.03413908627408091, 0.015366677871497814, 0.09149225501460023, 0.03326389007270336, 0.046847489502397366, 0.036823994742007926, 0.02273243233503308, 0.01941397651535226, 0.0385280697082635, 0.06574678103788756, 0.03200893319444731, 0.012710360642813612, 0.025821755625656806, 0.06374120115651749, 0.021098883662489243, 0.062051998829701915, 0.027782088618550915, 0.05425070572528057, 0.023225966106110718, 0.00805579409643542, 0.03619430099206511, 0.035768271118286066, 0.045340354554355145, 0.010279267607984366, 0.025199251431331504, 0.04449462161574047, 0.04043329267005902, 0.061176683884696104, 0.0824670861766208, 0.019599209153966513, 0.061036176775814965, 0.03070176622713916, 0.051142528172931634, 0.06373153839376755, 0.01871325366664678, 0.022070835511840414, 0.02282129709783476, 0.04402013320941478, 0.07032467445242219, 0.02063585772702936, 0.020828667693422176, 0.1368123118299991, 0.05396414766437374, 0.013688038161490113, 0.0316423641925212, 0.08755449365708046, 0.03585511352866888, 0.04165997001109645, 0.033417681624996476, 0.048273006759700365, 0.06945705186808482, 0.0467370653495891, 0.04636188743461389, 0.012938045056216652, 0.01201122227939777, 0.021430211781989783, 0.010594165505608544, 0.04516443957982119, 0.0541249228263041, 0.06363373075146228, 0.10524672281462699, 0.04269057193596382, 0.0478818392730318, 0.01542384086860693, 0.027237997892370913, 0.03963620380091015, 0.004902438304270618, 0.019291800454084296, 0.04042637214297429, 0.033979784275288694, 0.048373144745710306, 0.0047448163422814105, 0.06874335071188398, 0.06857469765236601, 0.04903168577584438, 0.04340796156611759, 0.033161622122861445, 0.05859430682903621, 0.04987335174519103, 0.023529153841082007, 0.00276235389719659, 0.06926881353138015, 0.03989988887042273, 0.02813422841427382, 0.003173750706082501, 0.011866509048559237, 0.06734893686370924, 0.025958017649827525, 0.05097759698401205, 0.06567253658431582, 0.0440745066589443, 0.09636233196943067, 0.035267892890260555, 0.08935198275139555, 0.0570819694257807, 0.023292484802368563, 0.01938440378580708, 0.02206884470069781, 0.05900135627598502, 0.06518838912597857, 0.04509193546255119, 0.03102850230789045, 0.04303444606193807, 0.03982921043643728, 0.03894402863807045, 0.017693147565296385, 0.032537420265725814, 0.03309962310595438, 0.05093178420793265, 0.022985510258877184, 0.04671291586419102, 0.020936496184731368, 0.02971204179630149, 0.0991574308136478, 0.04358019919891376, 0.009617744999559363, 0.06445031584007666, 0.030095947367954068, 0.023036362217681017, 0.017106618979596533, 0.07926609934656881, 0.04809348494745791, 0.040048437149380334, 0.053887851172476076, 0.02471477557264734, 0.049766230149543844, 0.012156396569480421, 0.06271439531701617, 0.01870239975687582, 0.02189110775361769, 0.002178364152314316, 0.03485767447273247, 0.029644766109413467, 0.06826999408076517, 0.015516642724833218, 0.04860743705648929, 0.0332271203660639, 0.03709817749040667, 0.055147234961623326, 0.05799618404125795, 0.04377166958875023, 0.03239831952669192, 0.026501785541768186, 0.05641640396788716, 0.09512834076303989, 0.022322158256429248, 0.02831654441251885, 0.04230288883263711, 0.005365858969526016, 0.055172137726913206, 0.0447960968449479, 0.018041897601506207, 0.018587873382784892, 0.030535686564689968, 0.03359322181495372, 0.018659787492651958, 0.006329912048386177, 0.04338914070103783, 0.029193011541792657, 0.02833286052918993, 0.0783605084870942, 0.042062466382049024, 0.004878923355136067, 0.05395659631176386, 0.004829142872040393, 0.03050621959118871, 0.05905068312131334, 0.012172867609478999, 0.00863289276821888, 0.04816411514184438, 0.03647088087745942, 0.03131025681796018, 0.15351297974120826, 0.11033344751922414, 0.18659865047084168, 0.0895595911424607, 0.1427605957724154, 0.10029834185843356, 0.10023022754467092, 0.2850051020504907, 0.18025158089585602, 0.1709395571378991, 0.14141533436486498, 0.09330837201559916, 0.11419892369303852, 0.1260799658484757, 0.22979185305302963, 0.11029354223865084, 0.1748314092401415, 0.10591412879875861, 0.07420246285619214, 0.13573336269473657, 0.10566481912974268, 0.10010412181145512, 0.2162285996018909, 0.10255611094180495, 0.24604686128441244, 0.12299279478611425, 0.13656085735419765, 0.11356660645105876, 0.08153693765052594, 0.11767386691644788, 0.1684739941265434, 0.19872988545103, 0.21418986056232825, 0.09992377992602997, 0.18443444394506514, 0.16659788932884112, 0.10145750973606482, 0.13483416172675788, 0.07699888272327371, 0.17116263188654557, 0.07289128086995333, 0.12861189170507714, 0.16023927193600684, 0.07565481617348269, 0.10116357472725213, 0.2064320127828978, 0.12679269479122013, 0.14732462586835027, 0.08691951210494153, 0.15772885351907462, 0.14768588851438835, 0.16106433235108852, 0.16875428846105933, 0.14754059084225446, 0.1448542537400499, 0.10443895444041118, 0.06979810583288781, 0.08084852888714522, 0.15374611801235005, 0.15676922688726336, 0.09294009607401676, 0.2785667928401381, 0.1411470479797572, 0.1957459916593507, 0.19174293614923954, 0.09819807135500014, 0.1071754087752197, 0.13752587197814137, 0.12234084773808718, 0.29860000067856163, 0.13853255077265203, 0.12059201384545304, 0.17374955088598654, 0.18912590079708025, 0.20531470945570618, 0.13106137979775667, 0.1594056619796902, 0.14069113181903958, 0.16407740738941357, 0.17133518122136593, 0.12993592768907547, 0.1366329050506465, 0.09562526058289222, 0.14158239180687815, 0.10853808096726425, 0.1299389556515962, 0.17072705057216808, 0.1745060962275602, 0.05412383557995781, 0.06900179621879943, 0.13340466655790806, 0.14445434004301205, 0.14852622232865542, 0.1766203116858378, 0.1676401318400167, 0.244181948073674, 0.12446188353351317, 0.21773508517071605, 0.10085985079058446, 0.11603634033235721, 0.11771435849368572, 0.12172784117865376, 0.1577043329598382, 0.15278567501809448, 0.0823926784505602, 0.1324830378871411, 0.14062347763683647, 0.06641961954301223, 0.14885073382174596, 0.08300065324874595, 0.1134536812605802, 0.10657493709004484, 0.1441536663332954, 0.08442726146313362, 0.116972433461342, 0.07281251673703082, 0.17887581721879542, 0.17519182583782822, 0.1667302439454943, 0.10504645426408388, 0.1477607266861014, 0.09179682499961928, 0.11233954690396786, 0.1220164772530552, 0.1790120013174601, 0.08502054915879853, 0.13980603165691718, 0.15136438800254837, 0.15548026480246335, 0.1530018774792552, 0.10292945575201884, 0.14023385010659695, 0.11490665056044236, 0.17162907170131803, 0.0609990100201685, 0.15271236567059532, 0.19107206433545798, 0.14581184688722715, 0.19404120423132554, 0.08912608784157783, 0.15567887836368755, 0.1372793156770058, 0.11476593193947338, 0.1621362756122835, 0.15420384501339868, 0.23139610915677622, 0.11024225241271779, 0.23828594101360068, 0.202676315093413, 0.13482435053447261, 0.15901787497568876, 0.15703353536082432, 0.12371618096949533, 0.08728988090297207, 0.16500075784279034, 0.1296298363013193, 0.1101849957194645, 0.1909967660321854, 0.14740890415851027, 0.11053163805627264, 0.08423495615716092, 0.21158936026040465, 0.16171599738299847, 0.11243143220781349, 0.20648575911764055, 0.09772123405127786, 0.14112417498836294, 0.1653393404558301, 0.13227890274720266, 0.11568702626391314, 0.2024223521584645, 0.15465263655642048, 0.1185731717851013, 0.12405328670865856, 0.14258038747357205, 0.14072031306568533], [0.04526129356236197, 0.051756276880041696, 0.014746531851415057, 0.0204775836027693, 0.03489478927804157, 0.03267502557719126, 0.018212324393971357, 0.042368995636934415, 0.03948227495129686, 0.02483790900441818, 0.041301750170532614, 0.02208480644185329, 0.04263440991053358, 0.02874037567380583, 0.022236800141399726, 0.017267488765355665, 0.08722929196665064, 0.019570376716728788, 0.0289385513679008, 0.0058770025134435855, 0.023716126815997995, 0.035297111244290136, 0.05317879586073104, 0.021458029332279693, 0.014391199892997975, 0.09138807232375257, 0.06395911797881126, 0.029998913414601702, 0.05899337447772268, 0.05245476771960966, 0.021030745228927117, 0.014931841487850761, 0.05416255342424847, 0.04794795349880587, 0.048406033020000905, 0.046263452677521855, 0.05581352401350159, 0.035482006205711514, 0.030471013960777782, 0.04308596966438927, 0.03825791682174895, 0.03431133503909223, 0.06028122334100772, 0.04563116883218754, 0.041875011011143215, 0.048376677368651144, 0.06011600271449424, 0.05276459582091775, 0.07999590510735288, 0.04560619556286838, 0.05659501664922573, 0.03125207244011108, 0.021082259554532357, 0.0052418391351238824, 0.03383959257917013, 0.005363787913665874, 0.013992789045005338, 0.04102102910110261, 0.056602931654197164, 0.04937555619108025, 0.03756777514354326, 0.02468467406288255, 0.036016857193317264, 0.05510843177034985, 0.07480490865418687, 0.022745117494196165, 0.05495829900610261, 0.016599643058725633, 0.017941802288987674, 0.04063635911734309, 0.04918791528325528, 0.07748432894004509, 0.08412948212935589, 0.024510406656190753, 0.06483318240498193, 0.03616651869378984, 0.03830900626780931, 0.02014231838984415, 0.03447357965342235, 0.05881574143131729, 0.05381118360674009, 0.030119805560389068, 0.018994924685102887, 0.03316046066174749, 0.005841241663802066, 0.049044324550777674, 0.02609623894386459, 0.0439060391363455, 0.030036005955480505, 0.023176546492322814, 0.022529122834384907, 0.10049835065728985, 0.05715764993510675, 0.022216545075934846, 0.04860476161411498, 0.04740357704577036, 0.04910557770926971, 0.03230553993489593, 0.057716368391993456, 0.021527503631659783, 0.0053553367069980595, 0.018636443237483036, 0.059955862088827416, 0.02465939094690839, 0.027289250610920135, 0.03919619928637985, 0.03611335123423487, 0.023929613016662188, 0.03870204396662302, 0.029998490390426014, 0.05534718438866548, 0.04506384146225173, 0.0422993933170801, 0.029868184101360384, 0.0426726935984334, 0.09078049086383544, 0.02999238251504721, 0.029371809760050382, 0.011432878654886736, 0.04571318357193377, 0.03328579456137959, 0.017957155469048303, 0.043184771784581244, 0.12476091709686443, 0.028441920985642355, 0.08120765414787456, 0.04707620828412473, 0.018618264330143575, 0.05542110971873626, 0.031351186262327246, 0.015080694975040387, 0.05135209212312475, 0.07711755955824628, 0.07037343355477788, 0.035993872879771516, 0.03038056100194808, 0.06000081397360191, 0.07763663248624653, 0.005757463395639206, 0.09365835401695222, 0.016423375564045273, 0.01809676828997908, 0.03127186922938563, 0.009794100624276325, 0.06017007559421472, 0.0416480956482701, 0.016377230676880572, 0.04707950713054743, 0.09014591749291867, 0.025236958099412732, 0.04584183858241886, 0.042238403621013276, 0.010783053221530281, 0.0361240789789008, 0.06519379196106456, 0.04088486355612986, 0.06379088794346899, 0.03129637865640689, 0.049652206580503844, 0.014498979217023589, 0.08084848435828462, 0.028613715185201727, 0.008332886063726619, 0.01642298222577665, 0.03401801601285115, 0.046084947607596405, 0.04552913836960215, 0.04328359245846514, 0.038798957320977934, 0.024170610631699674, 0.04597822677169461, 0.02378375873377081, 0.003859356238535838, 0.03290338812803384, 0.024131041172950063, 0.016129830182762817, 0.062485390808433294, 0.040127587199094705, 0.04282410656742286, 0.022452121302194428, 0.04174873829470016, 0.027387848640501034, 0.052685698101413436, 0.030452170831267722, 0.05352511165256146, 0.0543962817027932, 0.03594486515794415, 0.04471755164558999, 0.08689345530001447, 0.04634220567822922, 0.04417790267325472, 0.031704786233603954, 0.06034800549969077, 0.020875176232948434, 0.056230855916510336, 0.010668482318578754, 0.02385439078352647, 0.021268004275043495, 0.03605055811931379, 0.032883988387766294, 0.025680821781861596, 0.027841922419611365, 0.03324613418953959, 0.03237161334254779, 0.022885394537297543, 0.04393450421048328, 0.09209294934407808, 0.10743097474914975, 0.02380497673584614, 0.07431868318235502, 0.017583934968570247, 0.04672022972954437, 0.03467659786110744, 0.0192779668213916, 0.022639979288214818, 0.06328496587229893, 0.021401108460850082, 0.024314780239365064, 0.08242043477366678, 0.07948086204123683, 0.03648920450359583, 0.014179890968080144, 0.05910233659960795, 0.02499324607924791, 0.018484507054381538, 0.07574197399662808, 0.07538186167948879, 0.029741493926849216, 0.005871670646229177, 0.020263405349396635, 0.07693315812502988, 0.01182411479021539, 0.03843430306005757, 0.016391016069974285, 0.039245229272637516, 0.034761202696245164, 0.01941898044606205, 0.04423487735039089, 0.14533041568938643, 0.02008102812396828, 0.04058803417137824, 0.03799664002144709, 0.027544334188860375, 0.017772481296560727, 0.012765341725753387, 0.007065816871545394, 0.011189976503374055, 0.006068973389119492, 0.08583198374253698, 0.052229993452783674, 0.018759290942398366, 0.06810310733271763, 0.05367759702494368, 0.041709679062478244, 0.02887409398681484, 0.06724385617417283, 0.019484569602354895, 0.04957506032951642, 0.042194186462438665, 0.040159006020985544, 0.09131356069701724, 0.026496894788579084, 0.04693065828178078, 0.05905008198169526, 0.05937224457738921, 0.05322182558302302, 0.010917565632553305, 0.07808106762240641, 0.08768760526436381, 0.04837188680539839, 0.0271752567277872, 0.07333800182095729, 0.07330991153139621, 0.0230006890342338, 0.029476862619048916, 0.012115827994421124, 0.027330129960319027, 0.024631514024804346, 0.03896223352057859, 0.0205690551592852, 0.053547331554000266, 0.06921914158738218, 0.03619109120336361, 0.05349502127501182, 0.0491981791856233, 0.04087778346729465, 0.03673390543553978, 0.06058593433408532, 0.016213271701417398, 0.007905195634521078, 0.030325848019856494, 0.023900205414975062, 0.03669237114081625, 0.034730633633444086, 0.06051984237274155, 0.02043334603513358, 0.015160911862039939, 0.026582317841530312, 0.03179561397701036, 0.022957202891120687, 0.02841773624822963, 0.08971381685114466, 0.011600528887356631, 0.015387359671876766, 0.0880312938534189, 0.054258713498711586, 0.04045309317007195, 0.06227504389244132, 0.042070500130648725, 0.049658188290777616, 0.030414278626267333, 0.013820134881825652, 0.015674264686822426, 0.023994263356144074, 0.0409674720140174, 0.02534403516619932, 0.07311732420930639, 0.01802644423150923, 0.049168827245011926, 0.03400596724532079, 0.03435985665419139, 0.029569961334345862, 0.01799729267077055, 0.06794096290832385, 0.03367241268279031, 0.05195727644604631, 0.04250192912877537, 0.01578546995006036, 0.03327212420117576, 0.04539372610452119, 0.024020362834562548, 0.05157531159056816, 0.022624978628300596, 0.044555414642672986, 0.06524012424051762, 0.04220873255690094, 0.06604309834074229, 0.023358530379482545, 0.026171143908868544, 0.025393400974280667, 0.02019919287704397, 0.05123390881635714, 0.06031500961398706, 0.03302832497865893, 0.03766815803828649, 0.0405845906061586, 0.054462993357446976, 0.03958277287892997, 0.02240177029307233, 0.04906671143544372, 0.03832951180811506, 0.02212746509030694, 0.20787307061254978, 0.15673223824705929, 0.1712714455788955, 0.1150242290168535, 0.11604419225477614, 0.09734101695357822, 0.18253056798130274, 0.18459507438819855, 0.1632132357917726, 0.0881923695851583, 0.20883581426460296, 0.14193197304848582, 0.14916390529833734, 0.18967563926707953, 0.11362883553374559, 0.13549197174143046, 0.21347051166230813, 0.10167503322008997, 0.0997809758700896, 0.059757742055808194, 0.08243352625868283, 0.1904109591851011, 0.07445511218975298, 0.17725790559779853, 0.10580429836409166, 0.2318329075933434, 0.1584855472901836, 0.19659564684843644, 0.15151575644267723, 0.12494599388446659, 0.1994524255860597, 0.1644148025661707, 0.08242187454015948, 0.20746582449646667, 0.11786672141170129, 0.12340365516138263, 0.0788076376193203, 0.08919427637010813, 0.09661346732173115, 0.15915567695628852, 0.11235641592065804, 0.11140030706883408, 0.12361926390440203, 0.14922257949365303, 0.10130759590538219, 0.15795654442626983, 0.13226123963249847, 0.16708825598470867, 0.17157634953036904, 0.16372401150874794, 0.10302879964001477, 0.10782875106087886, 0.1466381986392662, 0.10635407394147478, 0.13026664353674278, 0.12885129370260984, 0.12725295993732288, 0.14337950240587816, 0.1429369449033402, 0.10937163155176677, 0.18091805919539183, 0.149087137542665, 0.19393173744902015, 0.14730975322891027, 0.17585538007551804, 0.10049243574030697, 0.13645570987137035, 0.0905602214334067, 0.158470630121883, 0.1880705074290745, 0.15829135692911223, 0.1366432654322125, 0.16025294229621068, 0.09969238570192829, 0.21030449483077973, 0.13350656343391165, 0.09609248707420193, 0.11688787315506488, 0.09234683806425892, 0.1241386856418103, 0.17355549411149696, 0.12963298300746828, 0.11247299989918247, 0.19433493143878877, 0.12578669877257198, 0.1547061899327673, 0.14512350491713732, 0.1464872161159292, 0.18104199785739183, 0.057592348093749024, 0.09893425216432661, 0.25365556706674397, 0.21915062796324492, 0.1103796016832348, 0.08477198905893601, 0.1379499351605773, 0.2754455275135115, 0.13844040571711957, 0.1235289964824915, 0.08818911155685782, 0.1287209874135442, 0.10400722487247549, 0.1841293173492886, 0.19677880889503285, 0.10883320341235958, 0.11588021472562104, 0.1434047205839306, 0.0959397159749642, 0.20905532670440152, 0.09305468367529102, 0.15772797778481618, 0.19425230071647093, 0.10054414116893895, 0.12222944395034574, 0.10683684100513346, 0.19787393684964627, 0.1819296510075219, 0.1159562922839541, 0.13185034214984626, 0.1739531071507372, 0.15011692681582645, 0.0868549378355965, 0.08271601735032164, 0.3102333139395341, 0.06618331230129115, 0.27769159292802215, 0.09938245741068386, 0.05859634773514699, 0.14242750505218282, 0.12332649406744167, 0.12172814545920119, 0.21124053600942716, 0.20008725870866328, 0.2172725193668157, 0.12748851760989055, 0.09513311277260073, 0.17277678824029863, 0.1768334416556172, 0.15260956337442622, 0.14399585605133325, 0.1730911323102191, 0.15776320011354983, 0.12190899942652322, 0.07609738851897418, 0.10162240010686219, 0.1140622423554305, 0.08786020654952154, 0.17162071511847898, 0.17280677100643516, 0.14691139804199338, 0.1151667362137232, 0.13859882456017658, 0.08081441977992654, 0.2045590546913445, 0.15103059966349974, 0.12712250521872193, 0.10932766672340222, 0.13217900966992602, 0.17113751760916784, 0.12055492130457424, 0.18314753018785268, 0.11520293817739002, 0.15628279361408204, 0.11453448576503433, 0.09458688466111198, 0.14112804899923503, 0.22456827631685883, 0.18058937683235854, 0.08527092752046883, 0.10161319747567177, 0.1781337140710093, 0.1170979677408468, 0.08339693042216823, 0.1315378089202568, 0.19870995136443526, 0.08341952881892212], [0.05376020919356961, 0.06324283414869569, 0.04285025985154789, 0.06533758307341486, 0.014203913360688603, 0.031739307232783176, 0.04865703849645797, 0.014700199571962003, 0.016539994794584345, 0.027454788505565375, 0.04744978687085677, 0.10116972713149153, 0.04545083807897754, 0.018738332692009863, 0.012789418851752998, 0.12119533537770621, 0.025400293670827523, 0.09104502940317616, 0.01559250598802464, 0.039772918535163626, 0.0432557359454222, 0.00969905191595899, 0.011335307572153397, 0.051875369317713194, 0.05099566085846163, 0.020671417732955888, 0.04627062182407826, 0.046438562421826646, 0.07048557949019596, 0.048682405104045756, 0.06276357744354755, 0.04413873211888131, 0.023385568674711976, 0.03140095839626156, 0.019645944048534147, 0.05637169328110758, 0.055773132626200095, 0.0365628441068111, 0.02254816263302928, 0.034270112446392886, 0.04619395796908066, 0.02074065268971026, 0.015271720076270867, 0.0857988245843444, 0.03939094254747033, 0.05625007011985872, 0.06512899504741654, 0.011056697912863456, 0.045655893482035026, 0.029604589944938198, 0.020233806644682772, 0.026874874311033636, 0.019914785189030226, 0.05322513185092248, 0.030245414054661524, 0.019321467807458248, 0.05024661491916049, 0.017785379823180847, 0.042789400031324476, 0.024853525646904018, 0.016436769474239554, 0.04655435972381383, 0.03869461506837979, 0.07721451373072341, 0.01857474107964663, 0.027346442366251722, 0.03004745358339278, 0.017764492076821625, 0.02069011243293062, 0.009712340070109349, 0.07090982820955105, 0.014228003474272555, 0.02254388229630422, 0.038013612938812, 0.08488745981594548, 0.051665341525222175, 0.039086747347027995, 0.01992573743336834, 0.08513995329849422, 0.03050152550713392, 0.06413289185729809, 0.01668847256951267, 0.03318843591841869, 0.03582721619750373, 0.005240269028945477, 0.06540114802191965, 0.0384215047233738, 0.009438567358301952, 0.013291324976307806, 0.02532340346078854, 0.05612218694295734, 0.006388262481777929, 0.043901742101297714, 0.04996386407583486, 0.052244097969378345, 0.03731563418114092, 0.04074386662978213, 0.08027162781218067, 0.08308115400723182, 0.002719874059948779, 0.07824592088581994, 0.06800952251069248, 0.08004285336937755, 0.06941901679965667, 0.04006719493190758, 0.016557713570364285, 0.04163130826782435, 0.025654922683315817, 0.016801516503619496, 0.06469546948210336, 0.05728604148316663, 0.049698512884788215, 0.007431833437294699, 0.04847709366003983, 0.029134608230378944, 0.0653623633843381, 0.04200954754196573, 0.08646036018035375, 0.029238258430268615, 0.026550244074314833, 0.03475887235254049, 0.03859013180772308, 0.028747888063662685, 0.06387800865923055, 0.04829078861803282, 0.0353046663076384, 0.03006317412655335, 0.04351265633886214, 0.03776452591409907, 0.037043488628114574, 0.051346819163882174, 0.0030613192757300567, 0.024440140114165843, 0.08781113574514166, 0.03346315301314462, 0.0040012432782532414, 0.0677978471503593, 0.027008440483768936, 0.022169342628330924, 0.028602980019059032, 0.06433045899029821, 0.01946450192917837, 0.03435409758822061, 0.0036526358735500253, 0.035227097032475285, 0.0046051988829276524, 0.014829814736003755, 0.017990335036301985, 0.024499441424268298, 0.013347730055102147, 0.03180745865392964, 0.016499167395522818, 0.01979701377422316, 0.06736324547091499, 0.06390531227225438, 0.0753520718717482, 0.10891455021919683, 0.03143893409287557, 0.029863081836083438, 0.02813279235851951, 0.03625853387347888, 0.027383497799746692, 0.032476300693815574, 0.02823190803610487, 0.044295317857177, 0.0026058952516905265, 0.02570397307863459, 0.034498697641538456, 0.02572575325757498, 0.018470847826392855, 0.05461593515065033, 0.09265725617296994, 0.019368891043995973, 0.02140792323189089, 0.021603957829938736, 0.017478939626016654, 0.03188158065313473, 0.07898904077592306, 0.03878831121255644, 0.01611446958122542, 0.03878963594615925, 0.091949373454554, 0.040394192619714886, 0.05818567660753615, 0.04965155720128678, 0.08966749941464514, 0.07158119726227596, 0.016406758877565153, 0.06064300920115784, 0.07789729701471515, 0.03282415273133665, 0.08711191389011219, 0.06333638928481378, 0.0548123853513971, 0.04240820329869166, 0.06787262595025823, 0.014452456762228394, 0.05808178706502076, 0.03995436622062698, 0.005017579269406269, 0.05602165561867878, 0.028431003993318882, 0.06588247531908564, 0.020502803636190947, 0.0526076686946908, 0.016996233789541293, 0.033143524851766415, 0.05526139211724512, 0.04162096643995028, 0.02962372436741134, 0.04255378298694268, 0.013962092889414635, 0.08792890715994872, 0.012769593304255977, 0.027228188555454835, 0.06814665655838326, 0.08407310117036104, 0.026882436795858666, 0.03998827494797297, 0.03829763656540308, 0.06705126143060625, 0.0263691897271201, 0.0175256281363545, 0.0913122842030134, 0.02141239652701188, 0.020929941165377386, 0.014091731245571282, 0.029128650639904663, 0.06984077190281823, 0.046406464534811676, 0.023079360398696736, 0.02054991517070448, 0.08105573651846498, 0.07063600540277548, 0.010964783850795357, 0.018735022713372018, 0.044643592918873765, 0.012945498074259376, 0.044130052701802924, 0.041798525271588005, 0.07831974231521599, 0.0050172633928013965, 0.022766713991586585, 0.06024929985869676, 0.025917349812516477, 0.018440347412251867, 0.027316255509504117, 0.02539333418098977, 0.07726526178885251, 0.061031527220620774, 0.06212727486854419, 0.017709189087327104, 0.057062937048613094, 0.037402784582809545, 0.060906742510269396, 0.01585512793099042, 0.029151900271244813, 0.03303226207208354, 0.028095907618990168, 0.044693365052808076, 0.015895105570962187, 0.06534536820254289, 0.04960386308084708, 0.014718618749611778, 0.04372970113763586, 0.028006588290736545, 0.03245308260375168, 0.04826725882594474, 0.04128459913772531, 0.04695377247116994, 0.042552517625153996, 0.02135045131581137, 0.06712291578878649, 0.05535901051189285, 0.024794953496893868, 0.056585557977086864, 0.048113448719959706, 0.1069435544195585, 0.02312351261934964, 0.038579782558372244, 0.007313738724405994, 0.03641088194854092, 0.04689640074502677, 0.018334537562623154, 0.020245443520252593, 0.027002898495993577, 0.04172275570454076, 0.034009715091087855, 0.003343240305184736, 0.03918832509953063, 0.05569339256908279, 0.07553656978416257, 0.05615673020656686, 0.025504211043880787, 0.04984286431863438, 0.03901479984051548, 0.03958381559641566, 0.020681752139353193, 0.037466026697074994, 0.04780708273756318, 0.053641443300875835, 0.04355968252639286, 0.03396738669835031, 0.036058940677321516, 0.03897941052855458, 0.016467041677969974, 0.06188240324263461, 0.02234018873423338, 0.020448417199077085, 0.037191320734564215, 0.04925675690174103, 0.03983269110904075, 0.02659887701156549, 0.01727295839373255, 0.04972900031134486, 0.11621424797340296, 0.028118739792262204, 0.0384667645994341, 0.010860755155590596, 0.06285281328018755, 0.09516263540717773, 0.059539186986512505, 0.052278203365858644, 0.008476309812976979, 0.06882335423142649, 0.02607874837849522, 0.023209147184388712, 0.04777252834173851, 0.01982360307010822, 0.03855451985145919, 0.011655667676677695, 0.08018664448172785, 0.04173029592493549, 0.14286994381109253, 0.04461064898350742, 0.012466747884900542, 0.02062340634438442, 0.08111332717817277, 0.020839718272327445, 0.07242938299896196, 0.016158619946509134, 0.04081858976860531, 0.025324546368210576, 0.028445384959923103, 0.01460903229599353, 0.0311483350378694, 0.045751474681310356, 0.045859575911890715, 0.018702420165936928, 0.026712722465163097, 0.05187482383917086, 0.03403091825020965, 0.12774256960256025, 0.14668156974948943, 0.1421597826993093, 0.10667362788808532, 0.1335220001055859, 0.15188064076937735, 0.1541026754421182, 0.172639268275816, 0.1577542201266624, 0.271818651817739, 0.18769544083625078, 0.1410467244568281, 0.09917274132021703, 0.13997156027471647, 0.07948284357553348, 0.2847467752872035, 0.18544285936513916, 0.22222737927222624, 0.15246448834659532, 0.11825505018350668, 0.11336071242112666, 0.1070153943146579, 0.0954178674146533, 0.11981583127635531, 0.16583367018029094, 0.09180153021588922, 0.1675577979767695, 0.12486296240240335, 0.12239390387549065, 0.15362681035185233, 0.1742222989560105, 0.09012308903038502, 0.17555617581820115, 0.16055818763561547, 0.10830641956999898, 0.13454702479066327, 0.13456762681016698, 0.06622997112572193, 0.10192733374424279, 0.22883393336087465, 0.11976727997534908, 0.10348821131628938, 0.11922958656214178, 0.20063143107108772, 0.15096889750566334, 0.11359943906427361, 0.13290788774611428, 0.21380438905907795, 0.13662313838722184, 0.13787100033368915, 0.08465255523333326, 0.14618194109061733, 0.29016003012657166, 0.1023668039124459, 0.17650147899985313, 0.12021231625112705, 0.18576208676677197, 0.20171524869510904, 0.1383701094891876, 0.09102611205889843, 0.291774527868256, 0.12274864304345101, 0.07592276859213598, 0.15311409020796418, 0.181420196313411, 0.10959676947095431, 0.08574208739446476, 0.07859925739467144, 0.13903489569202065, 0.13972188695333898, 0.1743187039392069, 0.0968446463230066, 0.1937561749946326, 0.17090017878217623, 0.1877805800177157, 0.12280913550057448, 0.11524814239237458, 0.09964432421838865, 0.15633187926141545, 0.06990801790379919, 0.11408742342609912, 0.058453662422834896, 0.11451778002083302, 0.12780309916706756, 0.043631926891976036, 0.16419074818259105, 0.15817406791029498, 0.18448784889187664, 0.07998639819561504, 0.1697088239598088, 0.1276194176170975, 0.08878046224708669, 0.15079066331963986, 0.21774136374006048, 0.1475435445900075, 0.07861499834689312, 0.11546599984285422, 0.1308004406746477, 0.17376207833876833, 0.20533715200144798, 0.26330595079343766, 0.15287547488696873, 0.1646867106319405, 0.14772103662835434, 0.12250200510607101, 0.12519670621259138, 0.17422097793314606, 0.11085125879617408, 0.09367264778120443, 0.09806648857193068, 0.12151631424785592, 0.1578783814329654, 0.08590697034378536, 0.1318386904313229, 0.12080604181392118, 0.2266044623684138, 0.1633674986078404, 0.1849318461609073, 0.11851731775095686, 0.13380835036514327, 0.1314016545074992, 0.14508102438412607, 0.13062182057183236, 0.2175343342241831, 0.11379260526155122, 0.1775835599983111, 0.08098659061943181, 0.09851913928287104, 0.12621150410268456, 0.10377286205766723, 0.14641558402217925, 0.08460030803689733, 0.10906631199759431, 0.14820729178609326, 0.23305293900193647, 0.10732092167017981, 0.15522680652793497, 0.16233977250522003, 0.11282831794233061, 0.21198716625804082, 0.1656755927251652, 0.13231657416326925, 0.13365110411541536, 0.09621462973882444, 0.19892144860932603, 0.09984745003748685, 0.17765943717677146, 0.15019462967757136, 0.24380925635341555, 0.12762044178089127, 0.09113483669352718, 0.16384238406317309, 0.10415689379442483, 0.19467499834718183, 0.12488031381508335, 0.1448925634031184, 0.14398948842426762, 0.21396022522822022, 0.10378547856817022, 0.0910756281518843, 0.10938819628790952, 0.19649342342745513, 0.1269318029517308, 0.14052831946173683, 0.09299939367338084, 0.16889136313693598, 0.11752515536500141, 0.18565388163551688, 0.10680915889679454, 0.15813186939340085, 0.12210214335937053, 0.18736125173745677, 0.06732049034326337, 0.1097186969127506, 0.12252104861545376, 0.0989207079692278], [0.021492138439498376, 0.10037061219918542, 0.01727908667817246, 0.06510743565740995, 0.01900612925965106, 0.03939128393540159, 0.02232264436315745, 0.03444424626650289, 0.009993959138228092, 0.05547621418372728, 0.061779920069966465, 0.048751384019851685, 0.017917634249897674, 0.030738769710296765, 0.031184210456558503, 0.03711673118232284, 0.01405245864589233, 0.04022174347483087, 0.005591666213149438, 0.05675478620105423, 0.03273344744229689, 0.0172339065829874, 0.01803129602194531, 0.04172117121925112, 0.055265848714043386, 0.034116554670617916, 0.014462526778515894, 0.0149508441791113, 0.04369723959825933, 0.05216908539296128, 0.14942475536372513, 0.013941541892563691, 0.03374666455783881, 0.0146163201861782, 0.019310031311761122, 0.0529467077285517, 0.011369255262252409, 0.04678850731579587, 0.0024686753931746352, 0.08296407278976403, 0.007819100937922485, 0.030998981528682634, 0.0603481539292261, 0.039243759820237756, 0.047264494860428385, 0.03864873920974787, 0.08471531866234727, 0.07572804388473742, 0.04462168100872077, 0.05016301940486301, 0.07548154695541598, 0.05432582591311075, 0.034829461728804745, 0.03041246407519793, 0.09390441307914443, 0.04020304877485614, 0.022224139102036133, 0.030674034023832064, 0.02791425027680816, 0.027150097921548877, 0.04888767944066785, 0.04060639861563686, 0.015665312530472875, 0.06190280488226563, 0.00526521539541136, 0.030172800470609218, 0.045577938290080056, 0.01765334247465944, 0.023848002747399732, 0.057676774813444354, 0.04118323289731052, 0.021060972903796937, 0.053418101379065774, 0.051584447428467683, 0.024798944396025036, 0.048583484240225516, 0.030121521776891313, 0.06103288906160742, 0.0389557471498847, 0.03249794914154336, 0.04087282592081465, 0.020775978919118643, 0.05158928623131942, 0.007120872169252834, 0.03309132960566785, 0.06031674623955041, 0.05639344934024848, 0.0246883588260971, 0.004309706755520892, 0.004666751219701837, 0.02947325392597122, 0.049112424021586776, 0.06420901394449174, 0.04417634416313376, 0.04989795765141025, 0.02537343905714806, 0.043816695688292384, 0.030848522219457664, 0.03023060449777404, 0.03387161254067905, 0.09723567651235498, 0.032642860896885395, 0.03937253728508949, 0.031629346922272816, 0.07376548630418256, 0.011874534447997576, 0.006134205850685248, 0.028685013312497176, 0.05234001684584655, 0.03383238261449151, 0.03873310284689069, 0.018156353471567854, 0.03639324851974379, 0.06509788421681151, 0.022573647984245326, 0.046136656746966764, 0.004569024285956402, 0.04685215390054509, 0.0072700164855632465, 0.034387371779303066, 0.012580775164678926, 0.014168030520522734, 0.0584175643598428, 0.003737255087798985, 0.020069856946065556, 0.03938222231226973, 0.03924298056517728, 0.019089299894403666, 0.0434813711035531, 0.007009883984210319, 0.012580687034642324, 0.03844155384285841, 0.0217190519470023, 0.04541468064417131, 0.019761214425670914, 0.03559057498932816, 0.06528156576678157, 0.023374772281385958, 0.0606178318412276, 0.09150300873443484, 0.02398734839516692, 0.031492669295403175, 0.06341823333059438, 0.06849641591543332, 0.04051993470056914, 0.0611223735177191, 0.04003744965302758, 0.05968230645521544, 0.06580311004654504, 0.045939171250211075, 0.025782475604501087, 0.028910795044794213, 0.07478213956346735, 0.02509741021640366, 0.06309916177997366, 0.058267858330509625, 0.03344132644997444, 0.02593153782072477, 0.02246169315185398, 0.009528667796985246, 0.05062118798377924, 0.0404041040019365, 0.0365323455480393, 0.057461251417407766, 0.03582115285098553, 0.031977967082639225, 0.027887024589290377, 0.07310355736990459, 0.053252680372679606, 0.012488231204770273, 0.03023835437488742, 0.0682031488395296, 0.06113106406701263, 0.05071097672043834, 0.06579979264643043, 0.03128740980173461, 0.02640288137627067, 0.009420699225302087, 0.04882438908680342, 0.019432218505244236, 0.023992218739294913, 0.06665905122645199, 0.05325203099346254, 0.02481173345586285, 0.012930481643707026, 0.0239511445761309, 0.04624924426025245, 0.05201581334404182, 0.06041882865247317, 0.01859552492533112, 0.02414799739199225, 0.016759963655204047, 0.042751242508529685, 0.022734124431735836, 0.04366610279248562, 0.05188208946492523, 0.004468953557079658, 0.023843837443564553, 0.02726445916778175, 0.09516184873064049, 0.08637147315312177, 0.01668539636739297, 0.027521529846126214, 0.01737666425469797, 0.031473403141717426, 0.06796702713472769, 0.08607875526649877, 0.054878930022823624, 0.055617396646994166, 0.02842659378075041, 0.07167337200371549, 0.03501494669762906, 0.007019264267000835, 0.060181634544278495, 0.02237662632978754, 0.0670429271121975, 0.019878325329045765, 0.023254178850038443, 0.013437379639071878, 0.04337810125434771, 0.01743216020258842, 0.007114721156540327, 0.07506250811275095, 0.08120451486320235, 0.08692518953466788, 0.04912175652862061, 0.052250606604502536, 0.07484645408112556, 0.0823987417970784, 0.052502576872939244, 0.042941109859384596, 0.04280610206478741, 0.03115424253337551, 0.04432754562003538, 0.03806613101914991, 0.03154234495013952, 0.033999065271927975, 0.021188939572311938, 0.07082566124154255, 0.061804017605027184, 0.08178180927643552, 0.01254337556019891, 0.028996923138038255, 0.013499504821083974, 0.020545996630971786, 0.04200529132504016, 0.03834999508399051, 0.055024591347319074, 0.012072156314388849, 0.011256663110543741, 0.006562443613802316, 0.053793130864505656, 0.049725170829333365, 0.030902439248166047, 0.014370083008543588, 0.013421010644378839, 0.03846120220259763, 0.0711310030601453, 0.05209686700254679, 0.021550764395215083, 0.023141424353525508, 0.08713570714462548, 0.043028497748309746, 0.03105572242930066, 0.043941966505371965, 0.014785935254622018, 0.02662735692865681, 0.06988506327616051, 0.015490662917727605, 0.09791882344870828, 0.03630547842476517, 0.02119223470799625, 0.018989584932569414, 0.04712354246294126, 0.05914082066738047, 0.0497152483148966, 0.044626115341088735, 0.034009908049483784, 0.02564729526056908, 0.03738139588676859, 0.04216300141706597, 0.043722561676986516, 0.030960582807892933, 0.02434775757137686, 0.07105589029379189, 0.017592423282621894, 0.053390719840535894, 0.034935774383484386, 0.03593885005102493, 0.019296680075058248, 0.053931953298160806, 0.04969872439687606, 0.029647152114193887, 0.08444670573226176, 0.07352126776822843, 0.044258525886107236, 0.04725457605673, 0.040315387668670155, 0.0329171401244821, 0.024904863712436054, 0.013390166059252806, 0.024405580152233597, 0.03128519449091982, 0.032444020980619825, 0.0279794646485243, 0.03725009140907787, 0.028481419940362684, 0.04461585886019748, 0.08646107264212333, 0.03525732099660672, 0.06387645757058635, 0.027911417128052562, 0.036353428586153314, 0.0498906660504872, 0.027273815794615075, 0.09333736030384898, 0.047041119541972876, 0.02865744067094056, 0.0317929719312815, 0.0175190322988783, 0.06020101944159251, 0.032928858636296354, 0.009453990114707267, 0.03565706399967894, 0.01819747958506923, 0.017905463028000668, 0.07039847361738794, 0.028418433867045678, 0.0727316300617531, 0.015126004018384265, 0.07317605777643621, 0.032719884693506174, 0.007018806454652804, 0.04263241724402178, 0.02962144968478242, 0.06179583171615377, 0.04561131638183724, 0.027448259461380076, 0.08144485938828439, 0.02126439372659661, 0.015236068229569355, 0.030389735802600626, 0.02352921692363452, 0.07393963125650771, 0.019591967648011632, 0.02069556536298478, 0.022553667513420805, 0.036554635953507386, 0.04225020747981034, 0.09684106917120516, 0.08473807291011326, 0.07278181408764794, 0.130397216998972, 0.1560904734651558, 0.07711030135396868, 0.1582029671408236, 0.11113855158328079, 0.14398071623872966, 0.1530072803143412, 0.18832300091162324, 0.16801580699393526, 0.10391680902102962, 0.16409961244789883, 0.13166676450055093, 0.11496465682284907, 0.11222937508136965, 0.12517923605628312, 0.10830906161572784, 0.11934441907214932, 0.16622732015093789, 0.13786776456981897, 0.16516926989424974, 0.08448560911347158, 0.09166883421130478, 0.11005716820363887, 0.10396803947514854, 0.2533208584645763, 0.11327186250127852, 0.16761667997343466, 0.13816603372106329, 0.1208192297781352, 0.1286423346027732, 0.18456518067978323, 0.12568734004162252, 0.11547736954526044, 0.09392628417117521, 0.08909266151022166, 0.138330181944184, 0.07251078917761333, 0.14664101880043745, 0.12577780784340575, 0.1408085395814851, 0.11150995938805863, 0.0732382942805998, 0.0831860862672329, 0.14697516337037086, 0.1539988786680624, 0.055263700196519494, 0.20561808458296582, 0.19677708711242303, 0.10645752190612257, 0.12419652121025138, 0.17775348213035613, 0.20150262338574976, 0.13801516994135454, 0.19629463175078854, 0.14321566588478163, 0.13864460022887215, 0.12449254165403545, 0.22784634260460734, 0.14767751708859578, 0.13262352644233033, 0.1451643230393529, 0.12353651443845592, 0.16591002233326435, 0.15850530326133594, 0.23203356948215514, 0.10712230068747886, 0.11636986149824224, 0.08114506883430295, 0.182589954638388, 0.13353532907785848, 0.1306289155036211, 0.12305006632232107, 0.12689981638686731, 0.14881344832247123, 0.14327107463032007, 0.16320842667482793, 0.0563382929249201, 0.19026233669137582, 0.09001003767480142, 0.18828920350642875, 0.17825558956246823, 0.1745513523928821, 0.18029759405180812, 0.07690693062613718, 0.10128011417691596, 0.21989449742250144, 0.2036531298654154, 0.0523994294781005, 0.13912868831539527, 0.1045064082427416, 0.1068021307582967, 0.12474153219955042, 0.21410742279840633, 0.18262418248923495, 0.1904312495025806, 0.1717693524551578, 0.14507758081890643, 0.10407711291918531, 0.17337151570245624, 0.20534758659778163, 0.21449298335937783, 0.17483137955423445, 0.14995806268416345, 0.1223571972514037, 0.1595159005955793, 0.0965459541475866, 0.12084432179108262, 0.1495147481909953, 0.13478354725521058, 0.10034571314463392, 0.1887225583777763, 0.09747280011652038, 0.08881493500666693, 0.1470706332474947, 0.14662578993011266, 0.20182878244668245, 0.13457513734465465, 0.14558207796653733, 0.11325507512083277, 0.17385394137818366, 0.14795196329941973, 0.09977066743886098, 0.15583379426971078, 0.06929413561010733, 0.1283667900133878, 0.11148926831083372, 0.10975341458106413, 0.14296559180365875, 0.07265759340953082, 0.10967118461849168, 0.1451118680415675, 0.1746424287557602, 0.15106110193300992, 0.0918617554998491, 0.17481092596426606, 0.1513730562874116, 0.1075656374450773, 0.15639885066775605, 0.11284860083833337, 0.15235309198033065, 0.15394229732919484, 0.25499265000689775, 0.2538871468277648, 0.10576611486612819, 0.15367653424618766, 0.11917342082597315, 0.10688174836104736, 0.15976713242707774, 0.1224480509699788, 0.13657170755323023, 0.12589637335622683, 0.13240848173154518, 0.11419819638831541, 0.09854754869593307, 0.20198754267767072, 0.10060010652523488, 0.1671452380833216, 0.19684542407048866, 0.1062381430529058, 0.1810515864053741, 0.17220874840859324, 0.08120976926875301, 0.14914250175934285, 0.11418452602811158, 0.08501363234245218, 0.11224646674236283, 0.07040978394798003, 0.13909259025240317, 0.09936967020621523, 0.053368069493444636, 0.06665556313237175, 0.22861186793306842, 0.15642507816664875, 0.13527578412322327, 0.16014739405363798, 0.17583685606950894], [0.046715988355572335, 0.020054179076396395, 0.0671458629949484, 0.07230128830997273, 0.016364176299248356, 0.019767975391005166, 0.02544803046475863, 0.03136989951599389, 0.02440168016619282, 0.032400182317360304, 0.03327104066556785, 0.0866109345224686, 0.05252093018498272, 0.07793689801474102, 0.03372864521224983, 0.03384940748219378, 0.06849438985227607, 0.011526331745699281, 0.02459411720337812, 0.035832440917147323, 0.014031181272002868, 0.029819721858075354, 0.021829272009199485, 0.04314512625569478, 0.014834138673904818, 0.0792801556235645, 0.018568082159617916, 0.08135462165228091, 0.01573075325723039, 0.013455067801260157, 0.046139929618220776, 0.06682743711280636, 0.04059954488184303, 0.08320942681166343, 0.02868490384571487, 0.06447378997108899, 0.07130591984605417, 0.025524991178826895, 0.023129316214181017, 0.05549548404815141, 0.0642789390985854, 0.04375270400487352, 0.03770507617446128, 0.04445390739419963, 0.004203312000754522, 0.017911633985931985, 0.02742188353295205, 0.06176101385790389, 0.025501693307887763, 0.07258362355059944, 0.06818248744821176, 0.05765405025158543, 0.04205307821393944, 0.062216870646807365, 0.022726927454641555, 0.02295473710546503, 0.04954766023729462, 0.05291853580274619, 0.030756764936086256, 0.040996668103616685, 0.0382739509223029, 0.046188402993720956, 0.04128853623114992, 0.03744373629160691, 0.017924775565916207, 0.018329043814446777, 0.05542789294850081, 0.022264478539000265, 0.0450266004918376, 0.044404291111277416, 0.0719479146937374, 0.01771884628396947, 0.08204879690310918, 0.056605870558996685, 0.02254251674457919, 0.029404942943074275, 0.0594724382244749, 0.0352376281080069, 0.12193145681521855, 0.05098591645946726, 0.01782439081580378, 0.010517008122405969, 0.058824717707466334, 0.033972956516663544, 0.09564978114212863, 0.054602153468295, 0.04912927819532342, 0.06777282935217954, 0.021973616021568887, 0.03995366489107255, 0.06325136884697713, 0.045553046657005325, 0.09429767713299952, 0.030938058625906706, 0.0197707788538537, 0.017983780016948003, 0.049446872872067615, 0.05544824634853285, 0.049190620411536656, 0.05041271127993241, 0.03991493220382836, 0.062069097912171856, 0.012087910254194867, 0.027686449902830645, 0.06255922708078288, 0.08061177635681815, 0.04605774418450892, 0.03137988140224479, 0.03922502801287919, 0.04295217899198178, 0.022047780694265384, 0.12816923030186445, 0.03705453920701984, 0.020544230319501366, 0.029376129059528466, 0.015759095877001528, 0.01988228839763906, 0.052582368880393915, 0.06139710916613694, 0.0815929401142057, 0.0647570974251721, 0.037541295314440504, 0.03523326427966822, 0.03905581463186536, 0.01822834550694097, 0.02296934628247982, 0.03767567970498931, 0.052103141861152835, 0.06711585054290481, 0.023941748986544553, 0.017553885409142822, 0.016145535882969853, 0.004022833745693788, 0.016565094229008537, 0.03060782517422922, 0.10039537024567835, 0.05152295307198074, 0.009604178540030262, 0.0472640050429618, 0.028496717459347565, 0.03150402786559425, 0.022575692601094488, 0.007709727387918974, 0.04096788390597794, 0.04837869229959324, 0.02641367776959669, 0.025723417347762734, 0.059791331659653224, 0.04654750970075838, 0.010216678583674366, 0.08319618689711206, 0.04410933564940933, 0.015715837944298983, 0.012882720729976427, 0.035331903127371334, 0.049109336687251925, 0.040884273548726924, 0.02771835668681888, 0.021795682405354455, 0.08322219175170176, 0.015059884226502618, 0.08632021301309578, 0.02268049312988296, 0.05965225318504963, 0.052699732113978826, 0.04785106240888126, 0.028332008914730977, 0.017057583427231293, 0.05629446168313734, 0.06258887588046491, 0.0017842381635091442, 0.05398748078732751, 0.03749790936126374, 0.04947307810653001, 0.027471414468891453, 0.016363007416657638, 0.03857648371194955, 0.012994549397262745, 0.04741212658700533, 0.024036769864324015, 0.04175432295596693, 0.031552297150483355, 0.027732980706787203, 0.05546264772419818, 0.01967426811461337, 0.07291535614058375, 0.04649211579817347, 0.033070271165343, 0.04448807216249406, 0.15368388150818646, 0.016970011856756173, 0.02485325105226366, 0.011545391025720164, 0.050729827271425165, 0.023569899603899103, 0.10141890321392566, 0.029607721808133647, 0.029376147613220382, 0.03803634121140931, 0.01786861725122435, 0.03190981566149276, 0.058675705586210825, 0.070893241208978, 0.0461792745772982, 0.022925030789338052, 0.05686253491148818, 0.04265086703526322, 0.024180586951842997, 0.03675927204312757, 0.09849364651017822, 0.06818095862399787, 0.05469856216222979, 0.04272524136467837, 0.018114041777153034, 0.023777153619448654, 0.03921630035620183, 0.020263956394046545, 0.027135128802910913, 0.047630284607294016, 0.06282329064561054, 0.038903191962162964, 0.01521863610832952, 0.059026151429861784, 0.024975877968245186, 0.01683818602032261, 0.009266535671486054, 0.047326842686743475, 0.02988482861837838, 0.07498461229261011, 0.0479799066670239, 0.03568795960745774, 0.02191851155657787, 0.032378218456869945, 0.050075297549483366, 0.06143575279565994, 0.0574487833364401, 0.05096347020298708, 0.04086394612386357, 0.05331141765054781, 0.051048542591161095, 0.05262108301394619, 0.01968755626876373, 0.05664515614625998, 0.028443653900467325, 0.028483702044468373, 0.025500975280010607, 0.057781710784183815, 0.03547595770214684, 0.047482189038419165, 0.08136675576679409, 0.008436110456386814, 0.07511619507567957, 0.03120191438938491, 0.056155939819291234, 0.051259858009871095, 0.015310622529796092, 0.13252762611955404, 0.042642714543035254, 0.030048461048863828, 0.07327958737732843, 0.024646188139740843, 0.05640064075123519, 0.05857925607415382, 0.01572128716361476, 0.06223916476301383, 0.030436348242801614, 0.0456457186373882, 0.026756245715660043, 0.054249796594376676, 0.034910548783955164, 0.051679078678716905, 0.016046744894993026, 0.04012850004073698, 0.04746124934172258, 0.068106654798612, 0.08944302942836657, 0.031998257400118746, 0.10555344502790831, 0.058512611212790944, 0.04295845756132621, 0.03354341257363558, 0.06170841043058317, 0.026508208829909563, 0.008165173676388804, 0.03780683946388308, 0.059576275816652924, 0.0155514383186528, 0.025950067392841447, 0.03476348108961247, 0.09643728146329522, 0.07427537886542268, 0.05168566895008553, 0.023461367927666288, 0.027701444996637292, 0.07462764668161981, 0.0061217665279400535, 0.02592152995930519, 0.03641678573330864, 0.009798622158996295, 0.0994873080344405, 0.0526623130281223, 0.05039344512624666, 0.02552473513787845, 0.047148315352387726, 0.03706804629473481, 0.03502083935018163, 0.06039192579919472, 0.03269490771344863, 0.015710583538748324, 0.028575442629517056, 0.02834021892340388, 0.05760125757660717, 0.026579035693430342, 0.023999976037885062, 0.06881598470499739, 0.009410296170244692, 0.025301027708337642, 0.0581082706048619, 0.035986744551337324, 0.013066834580968134, 0.043564940642681904, 0.05182110719033517, 0.029347586059884634, 0.04268691685865633, 0.014223690668586642, 0.02933433872385649, 0.05256846845441032, 0.03260948651586659, 0.020116248597332742, 0.030557839672837872, 0.030736268672626466, 0.0543369915249059, 0.015062936308822827, 0.041973850238719024, 0.03174069875967689, 0.026832321418623906, 0.034474102867534384, 0.09590345463948324, 0.048677228624001145, 0.09729510027682409, 0.07086674653692171, 0.04609097755746916, 0.0677370726771187, 0.05330246363882907, 0.04358420308562927, 0.004804478985533933, 0.03936394692573231, 0.04756057467602659, 0.03440065622271504, 0.06922354994458146, 0.012237709979672218, 0.006860121829959098, 0.16177995566977188, 0.10664643559721299, 0.15503358095884323, 0.14347550662932917, 0.09663703793194145, 0.09088342674658634, 0.09640677919378504, 0.10767934931209311, 0.12596200889674947, 0.18990848067915067, 0.1055488659767434, 0.21787046774988994, 0.11838572754641064, 0.1813159542507492, 0.10341336572309956, 0.12802047422155738, 0.14609436766477302, 0.08380749393836595, 0.0766621035290882, 0.24937076261267066, 0.06763130179024301, 0.12301561582717113, 0.09500679181655869, 0.2572648093337193, 0.09128826088272035, 0.1578142895596102, 0.0885284882679116, 0.13009152637096122, 0.10984507724060677, 0.11273678886936978, 0.17539771244628355, 0.1319115693331696, 0.14272322121541947, 0.24236751574790105, 0.11903938895557076, 0.16045862110331655, 0.16556066373595968, 0.1585093850735575, 0.06696909083984792, 0.16094512859126553, 0.0777478062082082, 0.16479816637001932, 0.21215245738858357, 0.11050612301914953, 0.1420599638368003, 0.10676717560272664, 0.11009756330167875, 0.1901131501654163, 0.09459260661969893, 0.12400220468407497, 0.12694820441538468, 0.09496263402979821, 0.13741223432589322, 0.22561611462151632, 0.19650663365609944, 0.10620469445711933, 0.12714905926259235, 0.12354441088973545, 0.09905153376166709, 0.11157909786561504, 0.10194190210313536, 0.22974610707024112, 0.1032965219928883, 0.12092351636965759, 0.1541785674635321, 0.11324613224132918, 0.2188810205552727, 0.09860415229923092, 0.11720384994987398, 0.1376800160505809, 0.21174789784708992, 0.20363162242574617, 0.19440071540884674, 0.1614738642820157, 0.1729623251594603, 0.20450358657399192, 0.10885417650570162, 0.20156512706307694, 0.25609037547837943, 0.14756275137187913, 0.22122294176369905, 0.15662734309444204, 0.19074200157774612, 0.22680966620100662, 0.1743207374238409, 0.24121001770254225, 0.1390669564716518, 0.14738203841261566, 0.11584707783185877, 0.2789518190547824, 0.26348558021709323, 0.09413906533154659, 0.1680770341772586, 0.12467576307244599, 0.1342344470322132, 0.09134994077612646, 0.1921407421468757, 0.2056905478821136, 0.15271431009750813, 0.19238677894463763, 0.11370176638592966, 0.1835683872923255, 0.13833467935910448, 0.2066286077024415, 0.14266610553022474, 0.15544818917987868, 0.15259264240739867, 0.06499022827483714, 0.14168428868288174, 0.14227432577172294, 0.14129847579170018, 0.1978427666472271, 0.11388423081371002, 0.1934820256428793, 0.19155748828779906, 0.1274089000071399, 0.06825336997280829, 0.18813836941262707, 0.12059464104822837, 0.18743475404335186, 0.12425880224327557, 0.11514878366142511, 0.11972317413892597, 0.21814516629092395, 0.1457751402631402, 0.1265561129548587, 0.1887277830974199, 0.10637437168043107, 0.21621687366859987, 0.09385559460497461, 0.12438943507731892, 0.08747892075916752, 0.150532707630191, 0.11022444086847827, 0.14723237691214308, 0.1622771203983575, 0.13833893928676844, 0.12622027628822252, 0.21127727231942117, 0.17247537238290533, 0.10484532482223585, 0.14485692547168583, 0.11856131226522848, 0.18033716536592692, 0.19295550155220553, 0.1406696837511845, 0.09416098095243797, 0.11188475138624199, 0.07870712855947204, 0.07731357560260221, 0.1388663539546542, 0.20049921004101634, 0.07082488940795884, 0.11779390930314548, 0.1061341904278379, 0.16149850358488038, 0.18109194439603016, 0.11400503761251457, 0.11570099348318763, 0.19370320049347356, 0.09072083703358658, 0.19098296208539978, 0.08103085972834378, 0.2510387246729806, 0.17748411220964044, 0.1308553002309054, 0.18351320119109005, 0.13077780517050996, 0.2039478812366724, 0.09928212646627799, 0.11646504935924895, 0.23925399844301865, 0.17689975997200236, 0.1365208110655658, 0.11485660754260607, 0.10425439715618268], [0.031598247223882936, 0.0241534744418459, 0.03701353554788511, 0.022395957421394996, 0.02324110406334512, 0.014995941710367333, 0.10187755789957009, 0.028448297889553942, 0.01688330859906273, 0.009922935605573002, 0.01839896896854043, 0.007794410612405045, 0.0241175544942962, 0.02212926479842281, 0.04574188984406646, 0.05974305124254897, 0.056588277948321775, 0.06519036323879845, 0.07949007951538078, 0.05407761091191787, 0.042410503956489265, 0.0454189331503585, 0.008334990052389912, 0.04976938056643121, 0.011053473281208426, 0.05216166391619481, 0.06225324330443982, 0.06156356546853203, 0.07005473307799548, 0.05082996154669672, 0.005245614811428823, 0.036322699961601757, 0.03206989691534545, 0.02820608871843433, 0.013775330498901894, 0.039853063062764704, 0.02866911279852502, 0.02663843162736157, 0.033803735714172944, 0.11924448888748884, 0.012876628625235753, 0.043603283702395856, 0.06698697659885511, 0.04891441531071905, 0.019522313377819955, 0.036469288970693015, 0.02237768203485757, 0.02835832547134487, 0.041079948205151595, 0.007928530612844042, 0.10020222631283104, 0.025818564390647225, 0.051769104902632535, 0.005293724998409743, 0.029553188796853647, 0.048883352719713, 0.0523660996259423, 0.027582493567024358, 0.043604727179626934, 0.06436758863856085, 0.02857275234418921, 0.03987657059042249, 0.035318548179930076, 0.05726260817027651, 0.054505280932062306, 0.16889378253836185, 0.053060861173435114, 0.04859338449023198, 0.017990678279602434, 0.0874622150149662, 0.04352221149019897, 0.03983325143053662, 0.09309819579357281, 0.030024712323211133, 0.05358721457014326, 0.022638140617345925, 0.017584806992090307, 0.03963475661294069, 0.018053666208288632, 0.048464996652910486, 0.023513190244557336, 0.008394481537834508, 0.11729269986972213, 0.024586506478954107, 0.02085824598907493, 0.03737827886652667, 0.03800827689701691, 0.03542222249961924, 0.03525090141920373, 0.04962919629178941, 0.03691111916850787, 0.04256671862094663, 0.007444008833772386, 0.02283398967847461, 0.06008997559547424, 0.017308123206021264, 0.05034496061853133, 0.08097499827272259, 0.028831535528297536, 0.01068433830369031, 0.020912623149342835, 0.06098496487538796, 0.028265206346986815, 0.06797181398724206, 0.0071386053241440095, 0.0480703373614233, 0.017618229612708092, 0.027830254002765287, 0.036536423649522476, 0.03759110455575865, 0.027437984426796902, 0.0382243531930726, 0.027935438592976425, 0.0355712012242293, 0.02499009937309893, 0.054385383264161646, 0.05785689776530489, 0.01857261853729142, 0.061631308708456345, 0.05230050490354188, 0.035130896139889956, 0.017912262956087943, 0.03701784371514805, 0.0401116532884771, 0.05070836436061654, 0.026773495083034504, 0.027719603494915646, 0.031342017027782276, 0.07621181284775957, 0.039279872726183385, 0.025394538315595128, 0.051653199989232235, 0.04255749001458753, 0.02645524360559648, 0.034487795492168516, 0.008927200706239091, 0.0574104068800807, 0.005554434055738966, 0.07932034292025492, 0.017358798904751893, 0.037647919671144336, 0.039985792463994585, 0.055227390621439554, 0.014891540085955057, 0.09965646575437859, 0.046027201096876524, 0.018249856657348573, 0.0187347388418857, 0.05713237238524016, 0.030182841728674248, 0.04241000671754591, 0.020384852250572294, 0.01148257935710717, 0.025354749923280906, 0.013313404797372641, 0.034305353328818455, 0.024669519407325424, 0.07411299695377238, 0.12030434256303124, 0.024233233052655123, 0.05642310556140728, 0.06522806434077211, 0.02133478643372655, 0.006133102833700832, 0.019953664450440556, 0.041770616808207706, 0.023050978816172574, 0.009266039360227296, 0.013253129418444587, 0.01948911896761274, 0.013566504985647043, 0.06215605164470617, 0.04533138941042125, 0.03196529491106048, 0.01398785561832483, 0.04330214243964292, 0.1090232674323488, 0.050318844441790134, 0.04429719178006053, 0.07549376270617358, 0.03453658428043127, 0.03725678558112122, 0.03238589226384647, 0.0644807364733424, 0.021962433711451013, 0.0843314798839856, 0.028064646503480617, 0.03544626437360421, 0.006382965402735863, 0.033222801066585816, 0.02608697694086004, 0.039500828643213026, 0.07233412834466435, 0.008602879388490692, 0.0917734696122352, 0.04483608005102724, 0.03364461554156151, 0.04081450424564537, 0.025486930135230068, 0.02189761638874188, 0.07386776167550124, 0.019264921720605344, 0.04016340695670806, 0.017935816867975518, 0.048316337051801383, 0.05456402934214566, 0.04694903385825455, 0.0470012773439521, 0.03288290485215839, 0.02384431612881599, 0.02262828860693844, 0.07642402255441993, 0.0730078796914313, 0.03310328189400025, 0.0028456423478928627, 0.06124076833657455, 0.026093995802511927, 0.041006067403941415, 0.013011745886615245, 0.032396222959505394, 0.034805579416570254, 0.006736841360179824, 0.10806062768097036, 0.018826883897418156, 0.013943982630735263, 0.026971808074449655, 0.06779825533158146, 0.05243081490334589, 0.03858770498482045, 0.01975059243704891, 0.03323642318719067, 0.0647585594560951, 0.023924412416818086, 0.08166820131009445, 0.027779897427535616, 0.09911653847666457, 0.0447420944692567, 0.04041469444928225, 0.012802424062101636, 0.04858584426983725, 0.07118647859897465, 0.08021793342777528, 0.022102243201516103, 0.05492341806530021, 0.047114183980738744, 0.0670915748924017, 0.06536461209179834, 0.03423552094318438, 0.033134563418570906, 0.031749463523738086, 0.06447353764087893, 0.03658541652839631, 0.043602099976851605, 0.020724303176393732, 0.08564251344068907, 0.04761104442877695, 0.03334255401568953, 0.022439617969212122, 0.04381657694466412, 0.013107401300658239, 0.0840263903955929, 0.04079913065652363, 0.07735515071544796, 0.012693915577983717, 0.0677855868707411, 0.026114787069673184, 0.055953819610294886, 0.010872267721424578, 0.05881409015273675, 0.010681010699045146, 0.05524330226762686, 0.042100957871298306, 0.004668980445785564, 0.04323079978348687, 0.030582720173697453, 0.10214525798801333, 0.07669046841328964, 0.017022708052536473, 0.03766554196772631, 0.04196206122287549, 0.042579932560329325, 0.07507569607696496, 0.017591464056749828, 0.025501136697130278, 0.037875287744100206, 0.021924691791355144, 0.047537423379253596, 0.057396628908463754, 0.030390309111680835, 0.01417854397004703, 0.060581436919164844, 0.019803258946922142, 0.04636597295757383, 0.030888677974871825, 0.021765738601970952, 0.09886151427053846, 0.04594786179950461, 0.05248809757176787, 0.013418983653536998, 0.02373091225308599, 0.04601536384143401, 0.01658344568568282, 0.02921707939094631, 0.022430485842050985, 0.07231257637613453, 0.10970975403324701, 0.07699661175138317, 0.04556683205009904, 0.04867613395617809, 0.021539196168305352, 0.0575901624688413, 0.03669541023555212, 0.03846202598651871, 0.05283642829454038, 0.014345157978823408, 0.042221003968734294, 0.00670322160658543, 0.07643606018973514, 0.03554998322215397, 0.012420984276104718, 0.0556249368673889, 0.02159556413971586, 0.034273184937774204, 0.07650209649000317, 0.025077888021769468, 0.03594969653931912, 0.039656861481489614, 0.056349651495111175, 0.03718590676726308, 0.026946814396069385, 0.023693817856837995, 0.06394849784555845, 0.004970492318534525, 0.031795985050848685, 0.027940312647842802, 0.013513045305444393, 0.06235786757315509, 0.11558171550859697, 0.012269849612494, 0.03188788890838623, 0.01907090761960717, 0.04038023282191716, 0.038208645637496375, 0.00981086666797637, 0.07293893417227082, 0.024922148331825156, 0.012406224814185407, 0.07755223545245826, 0.013852477677573916, 0.022118835768196732, 0.00648519995593233, 0.04812137485714629, 0.25994514988269657, 0.1379916735459119, 0.12226136372191831, 0.19141023134579882, 0.05837539181811735, 0.10913142061326653, 0.14292222069343552, 0.11288024601526558, 0.1299463474424556, 0.17759156035026535, 0.09432291015400551, 0.10069864147226326, 0.1021351276722271, 0.1325206202454865, 0.14705886278534308, 0.23884100810391828, 0.14935851126210764, 0.09925715319695882, 0.2667263016337529, 0.1733964667073451, 0.12366912880679592, 0.11109097249573097, 0.09480609282036312, 0.10259298825985752, 0.10194223606958985, 0.11373237255611457, 0.1351161184720695, 0.11301548016490415, 0.1911419746465981, 0.13510415505152196, 0.10918357875198126, 0.1086513401241973, 0.14491764799458906, 0.10707351932069287, 0.15286340756574646, 0.14569080260116607, 0.09579763922374696, 0.12143133833887987, 0.14438730926485732, 0.28412197600118816, 0.0867581766215153, 0.08653945085825399, 0.12490514607634395, 0.13796335319057107, 0.11102778604254127, 0.09026152183650993, 0.20901827869238332, 0.16026380733819678, 0.1625971047906205, 0.07870513218222186, 0.18576648028101772, 0.08453524395008571, 0.15649549313820899, 0.0651157031825278, 0.12440118327504024, 0.1934720214921981, 0.07931652085972019, 0.18775739532429725, 0.15131377353100106, 0.15183697280008346, 0.12242074735695496, 0.15171376144280657, 0.0973580418212805, 0.166180950764101, 0.18281595344888046, 0.19889884279109538, 0.1488668384263292, 0.17989106039749458, 0.11321226804284379, 0.22675669169984758, 0.14016048138728365, 0.14696176018333063, 0.11279223472229205, 0.10958063518046401, 0.17980853357585147, 0.11089262610767037, 0.10561873918049969, 0.09298746736021712, 0.15690343687310815, 0.18357540800934657, 0.09213495490257628, 0.11052540401578881, 0.25863193441182375, 0.1029941339220386, 0.24554876144975424, 0.2165942409192212, 0.15363291080575436, 0.12015764965326525, 0.12443329600500874, 0.10819986200658605, 0.13810022006509826, 0.09828568188822828, 0.16823717480292544, 0.16240183089394122, 0.15478147339308634, 0.09063648452865891, 0.17409263091394678, 0.16003206430468708, 0.11752873251680285, 0.23987053020391613, 0.13653170579345897, 0.14344224357046187, 0.16144728055223823, 0.15725040575489402, 0.1205637602834031, 0.11786850256612524, 0.07056744580040686, 0.09131824364885688, 0.17289897543378174, 0.13045620289631188, 0.1941561629064381, 0.1867464862880297, 0.13160142581909895, 0.12639560125535354, 0.16394955018768087, 0.13185673946281895, 0.18117025581886992, 0.11593858464038931, 0.23778508038958535, 0.21967315929941833, 0.1177931523125153, 0.16743197425967082, 0.08184283607988618, 0.12719700200250372, 0.21123479178640991, 0.08954513410571963, 0.15751288854517043, 0.2141044393647462, 0.1846403008676134, 0.20805771695449948, 0.1491744734812528, 0.13055640767561272, 0.13784293230855837, 0.08875729981809855, 0.1640458809561096, 0.12528033141279593, 0.14864152239169925, 0.13687391008716077, 0.2179950149729848, 0.1489238947397098, 0.07853661270928569, 0.10948602619464509, 0.11971639833063819, 0.11250544659560546, 0.14390823809662834, 0.09258160906028934, 0.12535108777228743, 0.10144671890884638, 0.11709394530043937, 0.17950560373719782, 0.11278016740106978, 0.1442916167434305, 0.11313891416648403, 0.10599206172628328, 0.17037666781106964, 0.1506570470519364, 0.16843730234541, 0.21258420922094956, 0.14832040993496776, 0.08208241619286127, 0.2855737059144303, 0.16066612559370697, 0.08970128939836286, 0.0776154590130318, 0.1273441402008757, 0.13779870030703023, 0.11634369337116368, 0.09945071273250505, 0.15610319387633353, 0.1291130788740702, 0.08235361921833828, 0.30770425277296454, 0.14865660283248872, 0.13167277589673176, 0.12901220616186038, 0.0918928514875006], [0.025573214079486206, 0.04917644910165109, 0.07539266734966077, 0.01783919480658369, 0.053186384320724756, 0.04274756145605352, 0.060936198351555504, 0.02814129737089388, 0.024449437369185034, 0.02214666073996341, 0.056037110844044946, 0.016615215172350872, 0.03367449069628492, 0.008501850825268775, 0.0251739330633427, 0.019687849417096004, 0.02200360435381299, 0.060999132474535145, 0.032695831687306054, 0.023898543004179373, 0.05365974466258194, 0.0376462015992729, 0.01736671205435414, 0.07383041680441238, 0.042112743176403455, 0.00724075731341145, 0.02503519968740875, 0.039565744300489314, 0.05751133525336627, 0.044405723456293344, 0.01796115935576381, 0.06641526313615032, 0.018262914745719172, 0.08343344408785924, 0.08888851894880645, 0.05141512643604074, 0.021052933589089662, 0.04325843365222681, 0.048624851551721804, 0.015774586354382336, 0.0110111847789085, 0.050246399696334265, 0.002919240901064768, 0.03556262199708726, 0.008586327639932279, 0.10562785275396891, 0.03687426411488559, 0.0235488745602197, 0.045559210193459876, 0.07230730712763034, 0.054765986278653145, 0.017055418211384676, 0.02092931590595981, 0.024117970096995123, 0.022142651287140325, 0.02062239516817499, 0.04789179147337563, 0.01709937376290327, 0.02756960988335777, 0.021726436316384934, 0.02659361889527645, 0.04080415870703291, 0.051953784641227685, 0.04341178362665232, 0.04997362331778277, 0.019406410319788847, 0.0148200443618407, 0.012508393501775572, 0.028072123641322833, 0.0992110584047623, 0.04981588353984989, 0.07525544424424879, 0.05417619780928362, 0.03909255836333614, 0.014048905613890383, 0.04253314757079352, 0.06367837835568935, 0.08442261561867781, 0.10655904028681107, 0.045584695544675924, 0.09487351693678647, 0.027959476756223012, 0.035950182646047324, 0.0975487515097484, 0.031354685488622636, 0.029877976739953738, 0.05466897273436189, 0.04681307982536964, 0.014247689869080205, 0.05921127645706292, 0.043753546342486516, 0.02459344370436156, 0.03168147537508048, 0.032753934428910725, 0.008189636719180271, 0.04445063081220724, 0.02180406496336218, 0.01092059452275862, 0.009964145210688002, 0.012620237939700019, 0.03218363104679156, 0.005292566320349579, 0.04437729177880101, 0.014406960326596163, 0.0508395723591093, 0.04767072052345611, 0.06802876639994793, 0.02251007561426377, 0.04896031714451965, 0.046964678331278265, 0.0320736039429903, 0.04428889456903562, 0.06229031729162671, 0.026822324689419474, 0.04448484753083903, 0.0124049650185043, 0.049488403456052765, 0.03308998260763474, 0.1152779915719293, 0.07655661465832964, 0.019050173868890852, 0.028832140378654003, 0.05493660974025261, 0.035556232105591334, 0.016954636412265245, 0.04223889343847986, 0.0177573711698642, 0.014853244338155491, 0.01072178336471552, 0.035192082505091093, 0.04236195265548304, 0.01638316229218617, 0.018281256925547495, 0.03330330553581007, 0.00658323998322885, 0.022104185773059726, 0.042358312421129085, 0.050492967129684985, 0.019321237741678488, 0.02872397606552113, 0.044922673841938376, 0.03629078761150595, 0.06841238253400661, 0.01682412788795773, 0.10415652272058651, 0.05452180856082123, 0.0490402464492945, 0.05782479245681316, 0.04459294505068101, 0.04660279970266856, 0.04152165223786142, 0.03917567519238219, 0.008758491057960782, 0.018268393650942016, 0.026821335777640343, 0.07006824016571045, 0.054109044576762244, 0.05179581850825343, 0.07183067020378076, 0.04048403701744974, 0.08236572364694439, 0.0624133505334612, 0.08927709262934513, 0.029158330980862956, 0.07198117775260471, 0.04832194768823683, 0.020119224609516095, 0.06321602777461521, 0.02793622341414448, 0.034674527269089594, 0.04837668107938953, 0.039335381661658175, 0.037857498464290984, 0.0467016983020585, 0.05129294666403439, 0.06994338866206817, 0.06515920787933283, 0.08400706487009302, 0.07191224707639776, 0.006734394128216081, 0.0570236737257801, 0.010166377669520443, 0.06066612710128538, 0.022403688744816463, 0.05171835313376505, 0.003020882431883365, 0.008205373032978969, 0.015940079720166977, 0.0463341979047982, 0.024801430590741802, 0.05753148456278723, 0.0014044791100786824, 0.027606060466496274, 0.03291911423730198, 0.022776055775466375, 0.018913431304099504, 0.02792675917589804, 0.05842544967890717, 0.05686760749085806, 0.01445605617846013, 0.0602644953323761, 0.060818872225354426, 0.02767311907518888, 0.020210801922075916, 0.06228096623090096, 0.026163833754253574, 0.03197595586243551, 0.047265711982618086, 0.026664380820875522, 0.0750740039802622, 0.027720200923795346, 0.06548748206114396, 0.0114306067553116, 0.015273079134203726, 0.07386327168205753, 0.05051317952165846, 0.02471063253324246, 0.023712800139037427, 0.04078584992385004, 0.021550975907302927, 0.03837396274320781, 0.038508725629071705, 0.012819009207305498, 0.051970137865282595, 0.031575066241202876, 0.05333006782166194, 0.033276347021455877, 0.030188602650014218, 0.050264452438568696, 0.05023362362408079, 0.032631316789775155, 0.009273820778616937, 0.0544293258280959, 0.02956515221740119, 0.04242858638463076, 0.07962151386891492, 0.026083375669259112, 0.14584565913537517, 0.056415316721540876, 0.011009270037902752, 0.007639723380634678, 0.03551553272700403, 0.022304515550786164, 0.041687507400638424, 0.007639785535502597, 0.045907017702120356, 0.011627146013779566, 0.023425974904967006, 0.03159962019708473, 0.025056252561626025, 0.04156714217970148, 0.040199631184805185, 0.06357360936817713, 0.01255797174962936, 0.056130877492250875, 0.04152894383878447, 0.07003597900620662, 0.032467866185470484, 0.02622948042699136, 0.02235534895589808, 0.05739156746130902, 0.04139022530580405, 0.02345924909604946, 0.060185330439708196, 0.03331251929921564, 0.0389593985164538, 0.03499445600027684, 0.02333245131012518, 0.029822801770933438, 0.018997687329829205, 0.037211002490948886, 0.02434301895846147, 0.05985980591503903, 0.037723188288509846, 0.02526882220990956, 0.013127903130225604, 0.0320794038270833, 0.06415066629415378, 0.056142124740290456, 0.020676141502917744, 0.04856583596847486, 0.10280458198394626, 0.04655389959225431, 0.019825809104077052, 0.05229095717368182, 0.030987736136012245, 0.023954591852088924, 0.04484314158617053, 0.004886550314040505, 0.014299925005616387, 0.00815722713014111, 0.07118935071048327, 0.05438357613456901, 0.08020925029995851, 0.04715196671895683, 0.023512167936132755, 0.04189178354863543, 0.012426870434865123, 0.0651554080832284, 0.029341090412344784, 0.03825053987384308, 0.06567613600054756, 0.04812854029296432, 0.03510526235913858, 0.02811068006849382, 0.033672913632472046, 0.06018711159413215, 0.026854194366023876, 0.011118452948721824, 0.022559439566975925, 0.017882907304738183, 0.016043286486819852, 0.04405738531204406, 0.023102255654521286, 0.019682546771946363, 0.035679161446751095, 0.040794202795950696, 0.06314874466625042, 0.036870078401989304, 0.012187240226921858, 0.05387418081227224, 0.03234625044569839, 0.06352398937451653, 0.07211238946183585, 0.004358784053692943, 0.03904502009390853, 0.06094495198340155, 0.043546316446736455, 0.04643046559067443, 0.04747044084069785, 0.056776571946102194, 0.05404335337516386, 0.061365712608676404, 0.01177255408038036, 0.06618704530410469, 0.03422550937102642, 0.021437555333250202, 0.04011290380731225, 0.048097002727445215, 0.027476462928461842, 0.04143703627050854, 0.02627764766657492, 0.016941797257459257, 0.09320080513134599, 0.03206033063179348, 0.03395914885913953, 0.06175185946631245, 0.016274593508569524, 0.03695848674396984, 0.05385516327805817, 0.03895467103575356, 0.03256005948060192, 0.22984567360254005, 0.20822514547035098, 0.197479915805161, 0.12768811080604792, 0.1189671631436795, 0.18107635929482058, 0.11489485783386044, 0.18443359789671376, 0.13833975564921275, 0.14341433881781995, 0.12361153814708814, 0.11968684601015411, 0.13518824038328603, 0.09850462287431583, 0.19510713609633967, 0.10603074988466688, 0.13688732811715454, 0.09724706105771475, 0.1167346270813141, 0.11196060630027205, 0.1430652622366324, 0.1998936472227797, 0.13908821158111095, 0.2222702160361223, 0.11954807181609794, 0.0929313906817697, 0.06874176993733272, 0.07206883281469345, 0.15100064658327028, 0.2015740328351967, 0.10341529530705884, 0.16338260873453692, 0.11883311643032357, 0.21303046261891723, 0.13436700945021585, 0.1993005079566501, 0.07398819740046747, 0.12727710942272097, 0.1283534461981617, 0.13606753695057705, 0.1472773659043014, 0.1608400553232059, 0.08031802688492462, 0.1140859465522226, 0.14206772670149803, 0.23006313771475106, 0.1517947594402358, 0.16569715953664854, 0.16518571588676423, 0.17135958303697407, 0.10306076394044794, 0.1696292360429652, 0.1351314809289761, 0.1258289418183267, 0.0732977848383598, 0.10370653631980531, 0.1112101465696469, 0.0916209137358237, 0.10210544176516123, 0.11119570437585935, 0.1340452884323895, 0.1854169138823636, 0.12768771004630253, 0.14625054522184655, 0.07843171755666845, 0.14586465811589733, 0.10161920145037584, 0.15631898073479533, 0.15338815050199628, 0.27289233170449734, 0.22023964062100276, 0.18730187992332503, 0.12476569652790204, 0.12739753030473366, 0.14602546667447314, 0.08129432215355337, 0.1703344692941755, 0.15634989860700443, 0.20306871825596318, 0.1689740680740215, 0.14994317520176992, 0.12393959710607305, 0.06592695965082385, 0.1120579315465875, 0.27523523254785687, 0.0949496019165963, 0.11722187671693973, 0.10674148245016113, 0.18928000034065917, 0.14325952681247145, 0.12051444457028992, 0.07271191861946136, 0.16001067560864612, 0.06261030910536647, 0.09737486630911008, 0.11310755100566894, 0.07408322198898531, 0.12057701504090801, 0.08613443860667758, 0.03967549680965021, 0.12760764715494588, 0.11544988781679422, 0.2278648962965235, 0.06444566999562085, 0.14193023642292246, 0.16641135793179274, 0.09274022086174227, 0.10307418197044171, 0.1696678574080579, 0.17350250476738438, 0.09580095662386157, 0.07406535849440843, 0.11201576271560043, 0.17506839183624834, 0.07866593194194138, 0.2132582722697407, 0.11399494440411218, 0.15177215362200513, 0.21844756178325042, 0.1192123613145668, 0.1272253817296587, 0.12464334606193006, 0.1630474696867168, 0.14058647415367886, 0.10913789956248365, 0.13872521230950952, 0.1253925441415049, 0.07700145055423491, 0.18199929414549842, 0.09825860091950744, 0.20097080036066473, 0.07848921173717827, 0.09635429451009259, 0.1500998722622171, 0.05703469090803992, 0.12189661298179999, 0.15261512948200107, 0.11516179351019673, 0.11801097265561111, 0.19658542005345225, 0.10286946053383872, 0.13183022994780913, 0.12128149130148813, 0.12025444055325352, 0.1676073289127089, 0.19055343669606373, 0.12947855691891164, 0.13364947139052674, 0.10705592299927957, 0.1097212870081421, 0.13980655116029084, 0.09016267518745735, 0.12453491828637198, 0.07409796846332029, 0.12434639793355018, 0.1460949020111002, 0.12885439587989822, 0.1587496924912557, 0.2372991814627312, 0.14190941175911576, 0.13468056684359908, 0.11462069363915361, 0.15488270233618096, 0.08667490765219554, 0.1351926042116247, 0.09705333824967965, 0.11457139276899397, 0.11893119124579243, 0.11877183729666285, 0.150948918890208, 0.1526233079493977, 0.08412732990109362, 0.10925346679869108, 0.2410661894828081, 0.11851391129312105, 0.23451599408872426], [0.03286721585027408, 0.031740761842229404, 0.02253824754006928, 0.032203431546804495, 0.05880619370145723, 0.0404574866843177, 0.0018749377704807557, 0.04514050902798772, 0.041140644752886146, 0.025948950460588094, 0.023336592494160868, 0.0343334510398563, 0.03661305039713625, 0.00976912364421878, 0.014106650269241072, 0.03333280219521839, 0.09162181915598921, 0.07317867755773477, 0.013154510052117985, 0.04229157850204501, 0.026631509244907647, 0.019590032497944776, 0.02703914127778262, 0.06111206137575209, 0.0016511423268639192, 0.03135605846182443, 0.024506712616130244, 0.011428422058088472, 0.03966879521613009, 0.036374282935867086, 0.06674350021057762, 0.08579009692766704, 0.04664659754780587, 0.08155116462148726, 0.024594607020844705, 0.003590022729440534, 0.013429139944491908, 0.08023559654247947, 0.032202960283029824, 0.047336138086393476, 0.053964863836881705, 0.024768408729869407, 0.015494969229621347, 0.019571937082218938, 0.06395701770088635, 0.025052565943042282, 0.05868501582881436, 0.06961711085750721, 0.055243298556888476, 0.0661023885186296, 0.03705950788571499, 0.017316928788204677, 0.04177824237558525, 0.09509285868261941, 0.0439796267892234, 0.007873705380916363, 0.030354057053045835, 0.07063360826577991, 0.017553163670527283, 0.04529288307821844, 0.054916709050303325, 0.03169186173181515, 0.03419670661969576, 0.03373844527231995, 0.06324742062133737, 0.021559245287789963, 0.03804097963438835, 0.06302142181084491, 0.040459902375005186, 0.04848370990657713, 0.009851130034803646, 0.01818368491512956, 0.015436593748745508, 0.03297040777397342, 0.028246170259080827, 0.02900895520724589, 0.01143503552157199, 0.045977395566296764, 0.01881446034531109, 0.07798566453857347, 0.05987763601297047, 0.11282198000117205, 0.03790161543292925, 0.025016445615619887, 0.02711309072765289, 0.038121443285490386, 0.011771646804845659, 0.017349000700050965, 0.057248351513408124, 0.05526033084606752, 0.007479823489120463, 0.02950042766315164, 0.03328392805997282, 0.03422205467359163, 0.014057777989364695, 0.06389337111613713, 0.009489893363934243, 0.007629207611898892, 0.09837592704570852, 0.048822051321621984, 0.023232851381180808, 0.05490571042173542, 0.03998090913228225, 0.07544375679572113, 0.04707504682301078, 0.051702489727176726, 0.05990544057567604, 0.0471357730566524, 0.03551373301888816, 0.05401858790719416, 0.030859806574881077, 0.03364837451954372, 0.029958234445075504, 0.055429985804948956, 0.07634222303749993, 0.04647424488211982, 0.06960352955502458, 0.027249200611549895, 0.023047525974106975, 0.08365222180145793, 0.07463014771929011, 0.04618461061909329, 0.040439096264890395, 0.028272356939851306, 0.02498248308256734, 0.07610044616740197, 0.0606326154229464, 0.088896764209494, 0.06212378306372557, 0.02244924547994742, 0.038597282400587574, 0.023591835633851588, 0.039871746630524285, 0.04310417454689741, 0.06223044081707485, 0.006737070962117286, 0.006630502266489202, 0.057057831072597764, 0.01937221401021816, 0.04382913408335298, 0.029610922319989186, 0.05516863107914105, 0.04208202568406705, 0.011106933889095671, 0.019640635837276932, 0.04018668441858608, 0.04620170599082485, 0.03077245764870895, 0.024416524975094944, 0.02320883362699533, 0.07573390685138293, 0.010130037480848841, 0.005555383077080478, 0.027447693573776633, 0.03552267218765337, 0.02842019275703933, 0.06340792489936575, 0.07566810803837143, 0.027344078625901602, 0.03579167474526912, 0.0547261811880162, 0.024085861077765003, 0.05787001151475124, 0.007193630472102086, 0.028039361532137264, 0.020480411185417324, 0.11157438522786833, 0.04569789161905646, 0.0416401286929613, 0.017689863561827224, 0.03540414749295451, 0.06429876186302863, 0.03983233116741758, 0.014407785038201837, 0.008603787591709988, 0.03990377030277159, 0.07599681266583502, 0.03242745624447707, 0.02923647170973709, 0.04670309725042898, 0.027118838661408518, 0.02301827978953952, 0.033627939483267255, 0.03237967306631617, 0.0749463471584022, 0.039009905376587994, 0.02067587432975415, 0.021228605510259513, 0.01453129603760317, 0.01894557000923669, 0.03518101708323229, 0.02427119019557722, 0.0438856115215458, 0.02773474516288843, 0.03407058604352642, 0.02685312010726193, 0.03856512143102009, 0.03603512144763954, 0.011486414405226242, 0.016647407683194615, 0.03838024873402901, 0.03690658835694194, 0.03747233124158811, 0.01483509882746148, 0.07256253913510591, 0.058999011089326814, 0.04132820773520507, 0.05062556294433307, 0.038973517876002006, 0.009290464367950335, 0.03286454411863815, 0.04943555511999875, 0.02969641958770808, 0.03251359361456707, 0.03255343952332623, 0.03901708565535955, 0.04241451155394316, 0.04500151590036694, 0.03245641855755821, 0.056637530578882433, 0.02735140918957768, 0.005686746926585329, 0.06240281945792958, 0.06566319294506684, 0.03529007197357714, 0.018010245003097225, 0.04203796066576615, 0.015088317759364145, 0.03608663391787559, 0.03334614972118288, 0.0324357497447636, 0.0372254298417829, 0.05807526729768142, 0.03643946576630697, 0.035740006424020976, 0.016720242056180723, 0.1023532819817774, 0.11058455318561755, 0.05146802301169373, 0.10762123914901167, 0.06340860767522827, 0.053153332773945294, 0.011527009883138817, 0.053911629584035836, 0.05059116811025888, 0.049611837457632646, 0.03538966448104475, 0.01993452631722903, 0.008810991512291366, 0.04036704856844153, 0.039248854664037935, 0.07473136181943119, 0.06142512895166874, 0.009469140131841414, 0.05286892694130074, 0.02252576276077889, 0.018569961648609024, 0.04116078664083034, 0.042271429192624055, 0.06683787913061678, 0.014359041706484277, 0.03782616870012134, 0.03718256710271817, 0.042727234031190164, 0.0488375622080639, 0.007955339769978309, 0.028240908432053402, 0.05206803456530906, 0.010813651970238425, 0.020822563528781757, 0.04719066600955557, 0.047559502272633836, 0.02809195197187364, 0.01915222659590654, 0.09348849125672132, 0.035054098698310554, 0.015898755082162097, 0.06336018253932707, 0.047819335595704615, 0.02532310474634869, 0.13305700005730614, 0.029789206600980833, 0.08229625862441026, 0.04011575736512896, 0.08852161598042585, 0.0422734552557813, 0.07037057628622279, 0.10115236829733476, 0.0042175004728051135, 0.05308425366820302, 0.05073398329841439, 0.052189509297022596, 0.06488216415164061, 0.0064767315870994935, 0.016078163716883864, 0.03832182686892338, 0.03847695799777284, 0.07534717369708233, 0.041550740716047585, 0.03721207118360326, 0.02782694216875825, 0.058748439769260585, 0.05563079612329602, 0.017531222074467223, 0.014645154478785116, 0.021894864876230713, 0.06818508496508002, 0.022629782179137692, 0.02590359410532983, 0.05441168868856039, 0.0319591387960827, 0.027650830525089987, 0.008916175174817909, 0.026430828802403994, 0.04361429346317891, 0.04595416634401772, 0.04633127013221383, 0.028012208204017952, 0.04083564432221465, 0.04630536546756048, 0.026593117945594713, 0.04573247941152658, 0.06494044500868767, 0.043695592030417174, 0.10213152825599536, 0.02213266383478185, 0.054423681795015, 0.01883225890196627, 0.022414717059291434, 0.06489101055194624, 0.04637716825527605, 0.009761582496139454, 0.05090786478831433, 0.04263417984475382, 0.01703520210867282, 0.022519563972309697, 0.007342195449382416, 0.03700832196045667, 0.04878266925516073, 0.012033465372951468, 0.01908830727188615, 0.04743506637169048, 0.07696197571931407, 0.021014443955209572, 0.027169510649400763, 0.001958590801223181, 0.040114929870469496, 0.034618261342984624, 0.021086226333864033, 0.07660766699700616, 0.030913591872376855, 0.044573408013093285, 0.11283666710369289, 0.10617027364787646, 0.07664067030418664, 0.11159689456690103, 0.1671760223689489, 0.10206045277300291, 0.1048512026318349, 0.1528371058520861, 0.1546094287186861, 0.12971570278750733, 0.21088630892336369, 0.1367077580653131, 0.13249825191451237, 0.1027314284874592, 0.12141025392338634, 0.1974127217545174, 0.1683474876335822, 0.2592520136386156, 0.11392084838007577, 0.1261915551731363, 0.09686678458820097, 0.11542624299181625, 0.13620268204249442, 0.15281283762305975, 0.06706298736389726, 0.12200233191833831, 0.13589271664386615, 0.08010839243070222, 0.15167205274337903, 0.07696035041590221, 0.11533806842635386, 0.15318045305320993, 0.1660081194131635, 0.10091215735883452, 0.2110025440924801, 0.13506670627975836, 0.13192807469749823, 0.15726478857686743, 0.1806936040520668, 0.13759883993770927, 0.22408889344660565, 0.09870715497527272, 0.12328278899076395, 0.16601151844952255, 0.32915169722400606, 0.15452678315341473, 0.1485711964778602, 0.20887268416117877, 0.1825936950626783, 0.09073766894289292, 0.12777074152836576, 0.08919748986954801, 0.20448578987270594, 0.18357566033955663, 0.20684142597019672, 0.11578539793845266, 0.16161322477273643, 0.07246528810355812, 0.08658874430693686, 0.1388227750430815, 0.22361558134434745, 0.19402535195695236, 0.09096526337089017, 0.2058927237521857, 0.12819122755900025, 0.14804425678448752, 0.11807263770606369, 0.15118058770895004, 0.134861932892818, 0.20771839219378307, 0.08068638446275145, 0.09600676901754923, 0.10824073950061575, 0.14885193610098213, 0.09892196219880134, 0.17184641706990078, 0.19837021100101992, 0.0918950408231467, 0.16535891831154004, 0.1407180866226554, 0.13038841512752697, 0.25962145475205034, 0.14177261909935623, 0.18050843820674345, 0.08088415939710103, 0.11644642145256512, 0.12565993994940072, 0.07985942414961755, 0.12740685167955235, 0.18372223450569436, 0.10818937545991503, 0.08516263333149254, 0.07406232311041094, 0.16804475075332448, 0.19851858116453514, 0.11167066404595971, 0.11539303930476308, 0.12494966009398922, 0.17944488121429458, 0.13803468842525035, 0.11802196386270225, 0.13616768235806376, 0.24858306191163138, 0.16461988765513524, 0.20173966535367072, 0.0959894027619157, 0.23355531360721216, 0.09387340614921413, 0.1721235943841748, 0.11389709965442307, 0.1529357224353589, 0.16049690108047798, 0.11869549998664297, 0.09952722815796733, 0.15606819419190288, 0.08286006821435876, 0.13934677583165467, 0.24184860609238967, 0.10548965743510053, 0.07877432261011563, 0.1244671230961103, 0.14028694335138425, 0.09941637355950661, 0.11429647158365697, 0.16196135140489787, 0.13226610812125728, 0.18544279999332502, 0.16507409687619656, 0.09559590864228085, 0.1518581240088679, 0.14904149546055123, 0.1633570936974138, 0.29153430950827897, 0.1690825997502543, 0.13065300561720505, 0.09774357269634493, 0.08832401916151866, 0.1374229064094834, 0.2084315218962729, 0.13678675226401538, 0.10877495224121958, 0.13372586807236075, 0.16040481539675966, 0.21617706486722454, 0.16443663655081764, 0.3194390324642882, 0.24973221821710467, 0.09693094325484708, 0.19225506257498637, 0.09474904392845929, 0.18662352726096287, 0.08467230378300883, 0.06757045310223475, 0.10230712039628997, 0.2190041428548284, 0.06008084717905149, 0.12869003985542804, 0.16674050042638555, 0.07014528993749991, 0.14803251600824296, 0.12165262451162562, 0.11681084564770572, 0.14325744879897684, 0.05968664801912382, 0.21759915340226144, 0.2693442424060777, 0.20127368567045778, 0.14593054598663002, 0.16667263844283298, 0.09224006527801976, 0.09767579234903678, 0.16627544100629166, 0.12961245520273224, 0.16979081643512473, 0.1156201736012008, 0.1516986364731565], [0.018612790991028305, 0.06153915252070874, 0.03153916113660671, 0.018621375784277916, 0.03461525193415582, 0.0851780477387365, 0.07313648646231741, 0.02319161951163551, 0.04789717204403132, 0.04699190401879605, 0.020168146984360646, 0.04696606243669521, 0.008099027909338474, 0.06154114147648215, 0.06667995752650313, 0.028301128149905708, 0.05410740814113524, 0.013375709950196324, 0.036790152807952836, 0.04327378126617987, 0.03521795748383738, 0.0455098722159164, 0.007117111799743725, 0.047249425551854074, 0.022149364012875594, 0.050651230121729895, 0.033284859455307014, 0.02857199164282065, 0.08164224098436534, 0.031337196778622456, 0.039947935511008836, 0.023177719085651916, 0.044346292270347476, 0.03210782437236048, 0.015935394912958145, 0.03899043884302955, 0.04422121070092544, 0.08094261836959049, 0.04900982210529037, 0.025718287251947913, 0.045577006894745864, 0.0762258617032785, 0.01930055037519196, 0.03594789312046487, 0.07412677863612771, 0.02780436789180385, 0.09443642164114863, 0.012422519594110781, 0.0274916101625422, 0.08546396013116464, 0.03355335364176426, 0.08672636075061746, 0.039822115504648536, 0.019539425447874237, 0.031002369432826526, 0.04779451075592078, 0.0398067419155268, 0.019131392655253876, 0.053397606970975175, 0.041103058683802374, 0.034841143133235164, 0.005734158103223308, 0.06598764506634325, 0.04525612079305574, 0.011676099002215778, 0.05988297205476556, 0.04197126014332753, 0.033860369003377855, 0.006958572357689263, 0.09351183922262862, 0.0357254158006981, 0.04138009127927944, 0.02192332252889173, 0.018831576126103755, 0.008794961122475797, 0.060219298538868316, 0.058742138935485855, 0.031410157316713594, 0.05307446845108643, 0.04505611941567622, 0.03619639013777487, 0.059106481494382024, 0.04449789448699448, 0.030518524399667513, 0.08668550552101806, 0.05478940474858973, 0.03943210576835554, 0.026621269462339114, 0.04201672039926052, 0.03357959598361049, 0.008936487756727729, 0.07979409288964234, 0.064956705464283, 0.053363431070465595, 0.07979612637427635, 0.058183257206110284, 0.05008285261283163, 0.058244859174010344, 0.08763890553382225, 0.07144105751649477, 0.013973721415823093, 0.052301028117653914, 0.0320843168447027, 0.033305802862741984, 0.027503315686772112, 0.0038337637397489743, 0.047483532325713895, 0.01192751729831798, 0.05381958471843973, 0.048165914849960245, 0.05702609312720597, 0.03747830181964673, 0.0555906533554662, 0.037458041188074276, 0.05773540819063783, 0.007513982227465021, 0.013996563793625683, 0.009619784977985546, 0.0455949037859682, 0.01778502915840363, 0.05992131140374113, 0.05526589695364237, 0.028474354694481008, 0.03722548921359703, 0.05056101093941834, 0.012591174508997938, 0.06026788323651999, 0.045801154046785086, 0.07438912783982232, 0.01267378574993927, 0.07753665777272545, 0.028657479633693583, 0.07504232169594616, 0.07029647284070961, 0.030260468520282302, 0.06377459780196659, 0.0495088013849454, 0.03895693087542895, 0.04198776550765615, 0.05598462616035249, 0.05534566669666674, 0.035571553744375706, 0.021121196332387626, 0.016038584981288295, 0.022108111734269187, 0.040275612263940275, 0.02079796133330092, 0.05600830067123752, 0.030682919386890717, 0.04532119972282089, 0.0191708266720525, 0.011961094842263265, 0.03428153409913648, 0.0404252626321977, 0.04258279725036118, 0.042744618840515614, 0.05241353399469517, 0.012811786255042534, 0.04925761779304594, 0.04034868412418291, 0.03798652825935278, 0.04271533740393352, 0.07272308052051812, 0.01829113305575447, 0.06149956265289802, 0.016679370128258597, 0.035842025754391216, 0.028482622219598852, 0.030752883503737394, 0.05519005317182746, 0.008774963953328552, 0.02934702017228119, 0.006237067518668482, 0.05220234103035182, 0.024240869752247818, 0.022680936563119758, 0.02699579799809726, 0.024982852301036473, 0.03518908422847744, 0.021282704365148675, 0.0220196699956432, 0.04108377397642471, 0.07947279489599168, 0.01859424100985052, 0.008184398084267741, 0.02510726964828791, 0.04005927992693614, 0.03212767682271078, 0.021689213899662718, 0.03799242462264374, 0.031165768086793832, 0.030496068866341375, 0.018736327037913725, 0.05407936238043476, 0.020776127348653972, 0.0642959565448109, 0.06553179569891654, 0.028724428775603883, 0.053451449784915894, 0.0512770981003996, 0.07462500463589095, 0.04031648604723159, 0.047055109025677666, 0.022594806614506524, 0.04360555096354801, 0.026550353541097138, 0.0266964768525213, 0.057683168415678665, 0.06438990501919761, 0.017863817411125638, 0.024180850414268207, 0.03140535933198407, 0.019664659157569986, 0.08036490835365839, 0.05877308649360202, 0.03038842220121296, 0.02327376412722515, 0.06536807049997151, 0.03401879897865001, 0.036744158205692656, 0.03087926012085518, 0.10943918925477192, 0.027706649307219777, 0.019604903282015584, 0.03766145644476637, 0.05303745383571368, 0.03681461399537511, 0.014718245820404263, 0.028714354120893404, 0.05141028392245062, 0.013836400903528556, 0.018627272147568874, 0.02973638052935712, 0.02208104375313269, 0.08409980364376679, 0.004769561865032301, 0.01320222087088041, 0.041546413995092735, 0.030839345563435927, 0.023797790890967008, 0.019961948673881125, 0.016113575293275062, 0.059597311992547475, 0.007434786721205455, 0.030051483445276972, 0.020079909336345736, 0.04149681997660082, 0.008988195040728897, 0.02776771507342346, 0.0776361500902567, 0.06852073609479703, 0.05603411998890806, 0.017990598498727195, 0.10126455134013668, 0.0637332304904703, 0.04406171203299891, 0.04474981651583221, 0.034605466717039235, 0.06824821946793236, 0.03307290950033348, 0.01819933495426085, 0.020588859370036516, 0.03519534053339157, 0.03810523106949404, 0.021196845300437417, 0.034101785931852646, 0.09106523066293448, 0.00799537399871042, 0.026318148520658724, 0.04815621126908809, 0.08802097800071351, 0.047550262534059584, 0.03362218041729648, 0.021263380695017986, 0.0599261650495464, 0.02999210420966847, 0.027159619676240254, 0.060459268279373646, 0.07663819153094664, 0.01662969447352225, 0.040451742461300455, 0.03872369241435081, 0.019791831728070974, 0.05914441637287382, 0.020262978614482563, 0.016529996210010722, 0.05199157851166092, 0.025754722992132884, 0.023540664551546797, 0.010280686037731357, 0.08892132187611423, 0.07502470311010256, 0.0808692941791378, 0.041419892659178004, 0.039474604855058715, 0.06826373777585104, 0.04306853290472645, 0.03425509508815594, 0.055510223101009615, 0.02425618025881704, 0.00966601335676387, 0.04555928440822754, 0.0723779150575865, 0.03873841662425548, 0.04681785183493048, 0.004941373226756696, 0.020680030356743373, 0.018964904811582528, 0.035229713103035465, 0.06615669146412984, 0.044414721996872686, 0.014418086047953693, 0.07616048591444269, 0.07684508746024221, 0.019553951133275405, 0.08202491459087469, 0.028785594731743913, 0.06647203001193702, 0.025007799595186953, 0.04810053535038605, 0.042284053124603815, 0.019865296926582232, 0.023365001907222904, 0.05010828601371031, 0.04517165696597658, 0.01706683058728231, 0.034300247352803126, 0.035549174281186424, 0.0467923071119003, 0.013394470515777357, 0.03195318306097761, 0.061663132000830956, 0.08568696808652021, 0.031056364387040958, 0.008328833009727532, 0.03329363164084498, 0.058687331329565495, 0.06718918957631104, 0.037656766071449965, 0.023801230745448265, 0.06067611640901305, 0.04798014786501881, 0.057499546237522736, 0.02988659678521799, 0.027578268891375046, 0.0559538158995565, 0.13887623936170712, 0.08634690806502476, 0.03838181095488835, 0.09940463278326206, 0.01734224901156267, 0.026431767619214952, 0.05425471703347284, 0.19924441643524915, 0.11527499329531565, 0.13219352607848123, 0.13870345253963023, 0.26475860096979886, 0.20851473149377853, 0.1273897080682218, 0.09418518238817342, 0.09964317388948984, 0.20266567269572988, 0.12201093340991065, 0.1164521805185359, 0.14789239852689207, 0.1630842059967108, 0.18274032860063016, 0.1955089793773368, 0.13214003207394853, 0.10165387458982877, 0.18040379538433626, 0.16240926721366122, 0.1722674077609554, 0.10521046147914603, 0.10579403446172364, 0.1884666213300079, 0.19535116909537464, 0.11685452103847638, 0.16127811541082337, 0.14167775778332725, 0.18890028790337965, 0.09423347393749282, 0.1399159140419215, 0.12356801860732958, 0.06697010758216493, 0.10445489577250555, 0.08002349815797061, 0.12785283790435642, 0.30561552266590297, 0.12929346528835595, 0.19217293651308864, 0.10955690129776485, 0.1905032229842618, 0.1215295541624073, 0.12332280559348874, 0.10912164652836509, 0.17582377942744642, 0.11874552816152573, 0.11680239258566871, 0.1249258074676618, 0.18355154054006562, 0.08696440461790189, 0.23528226156486198, 0.15425258927280083, 0.11102976015536115, 0.08171891968231648, 0.21200092567596585, 0.14394641417311504, 0.14400784915778786, 0.21845058974577114, 0.16368823999073356, 0.17205383250257, 0.07465931412298232, 0.1366375360521488, 0.1383789410465397, 0.07848374953027815, 0.0716333331365604, 0.13930241024354473, 0.17221737216459587, 0.14532983681419864, 0.1952727240859531, 0.11167335062054917, 0.08171562454663217, 0.12849120364990085, 0.25486375379841775, 0.11552413969184272, 0.1585001082275994, 0.18147456605220214, 0.2863377024186775, 0.13141228206222877, 0.14065991708775982, 0.08619985892437398, 0.13248511590063572, 0.17449776933062822, 0.08225036421208642, 0.17458543181419373, 0.1390166240162216, 0.14497807365842164, 0.08966555498773232, 0.13372454704949632, 0.0995231834531296, 0.20344038581242785, 0.09728290679049678, 0.12951484794029966, 0.09573431918397546, 0.21627410809742287, 0.17083169339457527, 0.12032921193167567, 0.13312731112819165, 0.15494214836508036, 0.1662293536355719, 0.08849219724652357, 0.11544101915205829, 0.14925043971743435, 0.09244140994269401, 0.11350534958182834, 0.09973911874112673, 0.15639272052794695, 0.15491457015741616, 0.1602333941264078, 0.11983746488112956, 0.18752011586911976, 0.16642581496853381, 0.11054075162974186, 0.08432802147581242, 0.15714473876869306, 0.11832355041406117, 0.14038695517228916, 0.12951343785971403, 0.09108951373491436, 0.1295039532124065, 0.13571663468610495, 0.10854945066967048, 0.18098347209161147, 0.11853063930175267, 0.12756918906234205, 0.09626904400647618, 0.2000093480455689, 0.11505054557346739, 0.14558326540281996, 0.06248960620723665, 0.14680228749057278, 0.16813082504086196, 0.10553724394412711, 0.14177759148878977, 0.15134972316445783, 0.11897882970515639, 0.19394426490180194, 0.1035110917291604, 0.08010068151634187, 0.1476478311815299, 0.15922297490760684, 0.21491047111339867, 0.1374604887678288, 0.09864282561466098, 0.1790638774400577, 0.09926889397320338, 0.08919581261579879, 0.08588586366386153, 0.12111516858567484, 0.1372582238400355, 0.16279261617455631, 0.14857291826047003, 0.14047173812286928, 0.1515216936240904, 0.21583594410913065, 0.10402463565696962, 0.1583328578271903, 0.07525142922531813, 0.16090086690383032, 0.08159503297065385, 0.13367060775635764, 0.14512916008243337, 0.17308189999312162, 0.08650260322610848, 0.18680303794099018, 0.15090646804310381, 0.18213409784948453, 0.09855946016614325, 0.12248521772562526, 0.15198452660115436, 0.17234787141205743, 0.15663914324250072, 0.17747804144164547, 0.17382706078933552, 0.09102809359319508, 0.14932055782992393], [0.06021593289915472, 0.024947574311227072, 0.06333877900033258, 0.05509643866389524, 0.05088294346933253, 0.019222771443310194, 0.05985484465782065, 0.0571712943201419, 0.06256114182178862, 0.036991642191424035, 0.009887453525152523, 0.03098525179666467, 0.045338781201280653, 0.015489664729102515, 0.030532159507856704, 0.033093318561441265, 0.03293800931714941, 0.0022426517671192414, 0.047894374147290364, 0.04031727643450722, 0.06781655669328757, 0.1414549650507979, 0.03176925289153587, 0.06716342220897786, 0.09922301440383308, 0.027611398363660555, 0.04004844086011872, 0.05845874984515831, 0.01946615691849729, 0.016104200112749822, 0.019600120140239596, 0.10474961745785549, 0.0737699688761495, 0.07475495469407178, 0.011854322983708698, 0.0031667703433413408, 0.042248971803928725, 0.038784856515121646, 0.02248776851047296, 0.05302316007146146, 0.038765267527196556, 0.06730457869707607, 0.05992320759105496, 0.024500376530340873, 0.03176800237270072, 0.03136778068437707, 0.054755199162173085, 0.028184154543851037, 0.028725098563882057, 0.052819585253018886, 0.04971505535650067, 0.020788905276276637, 0.04988539309124462, 0.019501253082125913, 0.05158998756087385, 0.04165471931628417, 0.005631808980979258, 0.033078412525355816, 0.06575510051334277, 0.047119074733927846, 0.0841279755695723, 0.03506820692564361, 0.02702579560718732, 0.03474584766081534, 0.06326120972516946, 0.03929615173547063, 0.012195399212941993, 0.04376773249532562, 0.014931297864677617, 0.0377924269560026, 0.051699561954592355, 0.022315983587759547, 0.02499037767847767, 0.03701832611113787, 0.057876134233083576, 0.09201978842611425, 0.05471605829370674, 0.01050669226970058, 0.07656788046006113, 0.05891359360248316, 0.013377164559642551, 0.07387706820736639, 0.009516935369902058, 0.06550136022269726, 0.0619739657122409, 0.048946724709821865, 0.019507852630340494, 0.01981559158593882, 0.04933758420520462, 0.1132080823299475, 0.034455500936019234, 0.017449125698476564, 0.0481328150635818, 0.05552954491577111, 0.01723098808724899, 0.0715402900823392, 0.02628664435178507, 0.0677101401379332, 0.03914857566996943, 0.049564451328478754, 0.01947557662788313, 0.005468523040690343, 0.01849684525950579, 0.007785971465636976, 0.005877996527487994, 0.02701432014873717, 0.04549918157863431, 0.03174367477186024, 0.062368591607082635, 0.022696710911986884, 0.0936529363389127, 0.06516672583529726, 0.0178646449057851, 0.022420396344386972, 0.02156322505470598, 0.0277510631349287, 0.07851198824937455, 0.00841156484966632, 0.02746658123214729, 0.022196232494025026, 0.010537439447944053, 0.06523734860820696, 0.030116220987110864, 0.06507409096229821, 0.038957828874117695, 0.03630942665040493, 0.020785587876162026, 0.04117276119359303, 0.03480351995676756, 0.013420495779428165, 0.04072505318617914, 0.04504751050262712, 0.034684453494264744, 0.05401117756264284, 0.04291041834221687, 0.0196725574642187, 0.03449595169513486, 0.050349279918009415, 0.0525047328119399, 0.09504478235612623, 0.04651150811696425, 0.012485907354857773, 0.06493355045677163, 0.08446968262433074, 0.030116324887785595, 0.04293667552701663, 0.047251158466679044, 0.03154581077978946, 0.016120404907269403, 0.03764933717320673, 0.04360018152510747, 0.034625949992914684, 0.01627237634238554, 0.02753268989181379, 0.062210306350607425, 0.07305587438168004, 0.03475224497378804, 0.019979164644610137, 0.020884269397356547, 0.0796826668374706, 0.020881454802292865, 0.0749552009801846, 0.04178204217168968, 0.030342566751642153, 0.0552269379113568, 0.05242939369054511, 0.049421498843003064, 0.01668781762418803, 0.04870130760536995, 0.0631643742963206, 0.04199799972411711, 0.023501705509261228, 0.055828860495239496, 0.012307185206736904, 0.034194955151178874, 0.03827384702162817, 0.05701404807041399, 0.025830433187365998, 0.03332010775920935, 0.03906336598447524, 0.043569864792516455, 0.01264480395548162, 0.07319337208173238, 0.07446682328009047, 0.05620136667857878, 0.03605366400734056, 0.03190410112438258, 0.017861553860711865, 0.05431905381556135, 0.029129663671483286, 0.004967604436387774, 0.03359612361236941, 0.0526095723034814, 0.016388930635002907, 0.02028992043051403, 0.014049587462068303, 0.044856975218863226, 0.04180720468866639, 0.04291476732760202, 0.07145794137613848, 0.032887958877836354, 0.040082980412989855, 0.004480054694795399, 0.05265235711704008, 0.023300453613046557, 0.06471096552559175, 0.04039796272991225, 0.05560445359151345, 0.037783881125506014, 0.07138500310247764, 0.026747698029794265, 0.02930728001956595, 0.05068200327514205, 0.06470366279245354, 0.006073352988096303, 0.04934650110953953, 0.010251205148961162, 0.06987057655351236, 0.007545529069830081, 0.02242229809780838, 0.08611621145973913, 0.06789682738599367, 0.01602926175110042, 0.037977054744260386, 0.06968226400204003, 0.03363142015587073, 0.047250253046513535, 0.03235619893530384, 0.03424277914746199, 0.061452380614355206, 0.022596676826651674, 0.024946971316239797, 0.061324560520006344, 0.058254785399185494, 0.04900226333120372, 0.0701716287585441, 0.041258946803282015, 0.08488407562253997, 0.034485246214899234, 0.010804969770106254, 0.016344229225069284, 0.04771032152348198, 0.022133355887490325, 0.03423379544983618, 0.03936156463169027, 0.03610940300859511, 0.02506671313312836, 0.0269220452173613, 0.03998772946943063, 0.028233162265678402, 0.06000634668453131, 0.030364098311110865, 0.006853455024611321, 0.03124421309621539, 0.009624665526644094, 0.031092557073861826, 0.027224208788538817, 0.014332223272504052, 0.0675091368611902, 0.049157980756717734, 0.056674563747947104, 0.04553608116111718, 0.020206690423947293, 0.02227555694844341, 0.07067009224556386, 0.06734034279361367, 0.03959185676649213, 0.04372841722215526, 0.03883449135173578, 0.036970528090023436, 0.017594226701476146, 0.016340043512172997, 0.03312556116725318, 0.05363162839785218, 0.008887973563105334, 0.07195513579063118, 0.006023679652571445, 0.040455505150021054, 0.10447387248859741, 0.013255311332613928, 0.022868436462886166, 0.03209275506378617, 0.08582405760535039, 0.020393238519318402, 0.001684605185801047, 0.02065029249934014, 0.03812564013060182, 0.05092746861919295, 0.026863669736485463, 0.07389409307506867, 0.012461465648812009, 0.024834586038195994, 0.05597020252025686, 0.0359038874739781, 0.09268792171496898, 0.009677655798441265, 0.02659063546161633, 0.05083115269371774, 0.03492643445497379, 0.02662362763658166, 0.025962426007026806, 0.01657372726185713, 0.056846597290132195, 0.032132304113474675, 0.038062698586145416, 0.03850422450341284, 0.05421235895482823, 0.034682972909649834, 0.03968192009779159, 0.035108976808260195, 0.05405039635661524, 0.06980726393521763, 0.07697353095863946, 0.055986770967138, 0.023063205699145328, 0.02446190730552189, 0.02160139370971592, 0.047350309396279044, 0.04715997078164946, 0.015210962301352993, 0.030627130290667992, 0.022658039451926015, 0.048590965088806115, 0.05333693639840931, 0.016443715976492967, 0.036374854389578104, 0.08139443787513301, 0.0018935642856376944, 0.033771741727832705, 0.035157635720679536, 0.029963963825139217, 0.03579832809919026, 0.027416974226071034, 0.02013574481679825, 0.08911695942515507, 0.026702310133259743, 0.008771161374170333, 0.026840171485673636, 0.05867521947948262, 0.039536563053843565, 0.02425717844744213, 0.030332067217386793, 0.03386857715668157, 0.060129602570668794, 0.03289732107077725, 0.00776205482907244, 0.05585553699347656, 0.05864206774276681, 0.0584175420954125, 0.02606524129078025, 0.023971531372808386, 0.02835431972926017, 0.20128115167608485, 0.25084446009714156, 0.1193441147916019, 0.18678549356991425, 0.14636211970355362, 0.09556199991493486, 0.24459035194013268, 0.11707844925695099, 0.21798973088152707, 0.2218015497783199, 0.18128217168850824, 0.1355224591679871, 0.2608334115939215, 0.09013298928039148, 0.11060898468713276, 0.20745268848259002, 0.2696219243807718, 0.1470903743756935, 0.18891651125159115, 0.1054360817943234, 0.17082027916330844, 0.15388372703455389, 0.13560911233071238, 0.16224952734773979, 0.16950194287346676, 0.18131395045202225, 0.14201752783264965, 0.13453483872581273, 0.10801795418956317, 0.11705196200637147, 0.11180192770552821, 0.24973061517812312, 0.15562894666800275, 0.17107856139773503, 0.10074299221741967, 0.12295415857806802, 0.17227776814252138, 0.07126433731173165, 0.05933390522841364, 0.1620270314742811, 0.07581008831039071, 0.20661429909523576, 0.15750083606690168, 0.08684890417498536, 0.14675955462735146, 0.12020464986562729, 0.09388975566253066, 0.07245457891258411, 0.12617053755093366, 0.13419435621472076, 0.1478461775695905, 0.07165301489294507, 0.1189734936633613, 0.15921685961075127, 0.1729700286523439, 0.1113671256462112, 0.14056852902285755, 0.21732966473791748, 0.1784376532305032, 0.18417254002997652, 0.18311591469682753, 0.09769574127858505, 0.10320337503799237, 0.16880102892173454, 0.13918433454819024, 0.14911099016899243, 0.13711236213566735, 0.12110792522435077, 0.15761858521727845, 0.22974506806349382, 0.13513271289411932, 0.11544744615093805, 0.18306190118892118, 0.1539437667815946, 0.11834600038127974, 0.1940331148216501, 0.23274603125173599, 0.07483681358280592, 0.1470250653801486, 0.148556680069305, 0.12193771312013268, 0.12826061836676672, 0.13854104094207287, 0.10296406209818088, 0.22181934647960588, 0.13593366835266352, 0.153850196802523, 0.11907844076631591, 0.27995867596473545, 0.13476211403030902, 0.1066111093678046, 0.1164287212304771, 0.1259249757276848, 0.22633123327977955, 0.12613249506102875, 0.1112543637282215, 0.09087133716093376, 0.14969454088713974, 0.11483918933663517, 0.1618486933875829, 0.07636850990820676, 0.16817605152027681, 0.13908712804550305, 0.13284214830491692, 0.12739456171402708, 0.13095603935653344, 0.1698537208721973, 0.09989881407818757, 0.10149098059628159, 0.08875807907315902, 0.2379482044489123, 0.2108927656081505, 0.09313748509157449, 0.20953085040673614, 0.07361316791502759, 0.15329318528529257, 0.14921321358997375, 0.10459578508744016, 0.1466601068386808, 0.058567741652950644, 0.158964573929552, 0.17053349845809862, 0.1540900144027546, 0.14261528325732797, 0.15475082269404083, 0.10238698290777393, 0.17568654147908092, 0.122991785465274, 0.08094077042187564, 0.14901088929036632, 0.10954871540889144, 0.11796798004070297, 0.13425588025711477, 0.21438446652609855, 0.09633659428800456, 0.14728208596352488, 0.21238325047306716, 0.14903597388183698, 0.1412946017808281, 0.14380421867826954, 0.19709046639036387, 0.21504270698642358, 0.16745115135563537, 0.1830988601432182, 0.10656481419573538, 0.12246673824847676, 0.10646376336808316, 0.08136071468470618, 0.1465543804806657, 0.1323044326272793, 0.24766576738329604, 0.15571539202937856, 0.10728030392783694, 0.1058775928686373, 0.20518719364190474, 0.12100899693905376, 0.0996262529224623, 0.09408207581145689, 0.15712392894783989, 0.09782544642803259, 0.1275072494172491, 0.16409119649324566, 0.13276496494654566, 0.15943154809065163, 0.21817776141688228, 0.06535602544317953, 0.22230540867894888, 0.1308820620761253, 0.10231303531327285, 0.11191839294042438, 0.14921506895916536, 0.09805663285078481, 0.10077351675136015, 0.28909285145346075, 0.12317511078435928, 0.11596466370974667], [0.04951219671056606, 0.0217041125142714, 0.011907466323464178, 0.008428534983977443, 0.014419664039451163, 0.03238816323573701, 0.02705286544369301, 0.005136240333740716, 0.0020469982155191246, 0.027040180284529924, 0.01429926263881498, 0.08324027789058164, 0.04455568552657496, 0.0017105111260207195, 0.06947743124328554, 0.027197996132599656, 0.04835539257328492, 0.05143311609572265, 0.06863449249067344, 0.03684194729430601, 0.0074723259422171395, 0.020511076727416366, 0.03840879915514961, 0.005428020795079647, 0.015624691077391617, 0.03734924233867787, 0.09198423955240287, 0.084580329421442, 0.014277492664405145, 0.05357671689125709, 0.03339532071549911, 0.03638083238911349, 0.05531116054044105, 0.02064534794044448, 0.0909703693469055, 0.01557622141262982, 0.033067172698793, 0.029296095854078885, 0.065273194340989, 0.03993415382865351, 0.013796735893265577, 0.04725639802927617, 0.06359485705615953, 0.022893968198332004, 0.01589964194863569, 0.024971267375804018, 0.02146241913578706, 0.03788239751884248, 0.03487489972030744, 0.016932386824919377, 0.07780203493894078, 0.04180731972155627, 0.024572632028139196, 0.008608352727605961, 0.016571630694670603, 0.018102451285813004, 0.0101695522062073, 0.01006961088933167, 0.05770768526417669, 0.10811288972035982, 0.012160824408056214, 0.026692228057072498, 0.015831266027817037, 0.015329616871895269, 0.04201594856567681, 0.014577619967894861, 0.00655453046420007, 0.009402194700669497, 0.014628941335104173, 0.0490180265478557, 0.04941512750519905, 0.03179906867444515, 0.05337710143066943, 0.007690812362852739, 0.022345899560605176, 0.014870916729705641, 0.02790304941299837, 0.03139066480798647, 0.022874438582221046, 0.023382952604151797, 0.019710689011844806, 0.0291591621862608, 0.13273309712531045, 0.031591545630362816, 0.008790643678366905, 0.0331020313751651, 0.03412858488445636, 0.026478669497009832, 0.05500580387888476, 0.018144798232242465, 0.0901917896408122, 0.04521034141362179, 0.031751882925163954, 0.030991602725407574, 0.09678821341367438, 0.04169170424574986, 0.05540212929190602, 0.01215597632835852, 0.0565973692573607, 0.05738973806728609, 0.03298438612546306, 0.046048511867411435, 0.015441268351423787, 0.02019632262090454, 0.01154498933829018, 0.014230646447686013, 0.0401146404328756, 0.05954782558546867, 0.02353308165766066, 0.03483995940769091, 0.01697042003797833, 0.04642462488845922, 0.02288199364556931, 0.05383250550949015, 0.05719668319215998, 0.0439451020793058, 0.03105190407950431, 0.01890160703624133, 0.06814049673266709, 0.05001917263143696, 0.10391811520094052, 0.008776740469329525, 0.03068821461056359, 0.018743915497907437, 0.03418266889639199, 0.0012672103162003623, 0.04433467023773119, 0.01522086904515163, 0.03436531143961474, 0.034282150081708096, 0.004692976399383042, 0.03212324249034282, 0.07556830401881598, 0.01258033358681132, 0.03082074734265916, 0.02083063438476529, 0.030227147944970056, 0.02871189575671451, 0.01637578163354192, 0.027333321195328608, 0.04491098501603119, 0.07592078705783933, 0.023118825956771616, 0.05519992373592686, 0.03296359856904019, 0.07182544548413716, 0.03446081100264564, 0.16847350430907682, 0.053024310400360264, 0.06404120693332516, 0.03365609285538085, 0.04236545559251681, 0.037381544316303916, 0.006045409736543661, 0.11831573559902608, 0.09929322899552062, 0.023774756482453085, 0.027606932490016334, 0.0688713340787217, 0.04698690936493222, 0.019092400216322858, 0.0398116104042856, 0.03728869050974026, 0.02143494853953598, 0.03742026587133296, 0.058442726876819506, 0.08443453451036476, 0.04813940162421204, 0.04201964446110651, 0.021509306170628406, 0.06661266699666157, 0.05368613914470188, 0.011146405013278127, 0.003956794198529678, 0.042146447813138366, 0.024970451013359707, 0.05422003647254314, 0.02914505952503532, 0.10242279153317213, 0.01966526215255726, 0.05283661012072116, 0.06248831487027928, 0.023096973418432754, 0.0607554705493385, 0.0021112457079652813, 0.01648265460971743, 0.03215858727344312, 0.054957482643658295, 0.045905043589300476, 0.06830460784840398, 0.05484103967319243, 0.05938465699728113, 0.06955103744985536, 0.03710176206368487, 0.08138887176755816, 0.090015930327354, 0.014195850853866432, 0.04973883005732205, 0.004112901715416228, 0.009247443922504317, 0.08717112985323183, 0.034964692167704925, 0.04289765340217855, 0.06428819368011318, 0.013071440534986323, 0.022406870702980086, 0.09248841015505604, 0.044291941085248254, 0.024307492349180393, 0.01523906372312922, 0.04397196040372364, 0.039462648855987936, 0.0724127514695283, 0.025949264017981477, 0.04130646280827932, 0.06565891075297259, 0.02050097053142963, 0.06181867873237934, 0.04378400037239771, 0.06207410369825084, 0.055121630866779014, 0.00986530691079679, 0.055041093000909314, 0.03752330565475859, 0.059570160519797355, 0.013931999728811206, 0.03270894172601402, 0.04296465078368783, 0.034774424057104625, 0.028711140621453524, 0.06797909445594996, 0.0326890707219718, 0.0483957431424642, 0.01634623116842704, 0.017483724623161834, 0.07784907225868665, 0.059814928245032206, 0.028912060406582896, 0.02571985503891483, 0.018820560799213126, 0.03014618891029386, 0.03020975571416784, 0.028764411981683224, 0.08684346423251554, 0.04498406058701221, 0.09393960572197102, 0.022515983109769877, 0.021885053683945443, 0.06746926126652397, 0.042086760586244054, 0.050547615173854865, 0.027682570325850975, 0.06433377639041282, 0.06745867824065499, 0.029390484050964005, 0.021958843572065234, 0.07351479624048807, 0.02139988948329119, 0.06984013365581632, 0.02874711251934059, 0.07162408597650938, 0.035576993686845526, 0.02517257864383282, 0.05371385093894787, 0.0369432690058602, 0.041221995270461775, 0.03720921391504817, 0.06796830362873152, 0.042835301865125075, 0.14873011998133734, 0.05897219729376957, 0.04207574711472262, 0.011885816948051797, 0.06334225225145929, 0.02726675240410259, 0.05778131373517681, 0.037830599321750924, 0.07155422761570662, 0.08379144128412008, 0.032968656305456534, 0.02081289334455505, 0.03545892170222942, 0.052027698839083314, 0.06354666198603809, 0.018121227622032166, 0.052867164340568706, 0.025792745072976686, 0.03291463537607342, 0.024836673328536563, 0.037837464187759906, 0.04561880465189461, 0.053810986937605776, 0.04863318958086893, 0.04072749114129692, 0.02227443445008248, 0.05962729104794562, 0.09033338399603963, 0.021345258137444034, 0.0674807422910817, 0.050412959899404086, 0.06659984268480912, 0.0626848875253927, 0.0424328500230331, 0.025013887061504647, 0.08064498004387133, 0.03408117649087217, 0.0851763853279408, 0.06449664811952971, 0.03772455012949649, 0.07909259264124557, 0.01617994741536677, 0.08750680324737914, 0.06496627916931175, 0.03328945706016384, 0.06968923276872374, 0.05831456910527777, 0.026859509998757858, 0.06292196660069749, 0.017794675222830847, 0.08420297701377422, 0.0789751106640324, 0.015752939762023743, 0.023608073825016618, 0.07729118500719778, 0.04732693174446467, 0.023272728831216227, 0.012543062002805527, 0.025085582237807103, 0.04147241445025429, 0.027626784940366633, 0.08345681431819685, 0.11502807334181853, 0.03501751081785187, 0.06601335306186229, 0.02866769900720101, 0.0233549550830503, 0.026546735571173485, 0.046374400044442154, 0.04876072394836228, 0.009044237394846277, 0.024488607923558448, 0.04359596241556574, 0.031467458538827486, 0.044874623490613885, 0.045619283337146044, 0.0771914106735494, 0.08128154979203828, 0.024274329480249435, 0.07043531382805668, 0.039447371746064164, 0.03092185012064874, 0.04083064224687405, 0.1032831559132319, 0.15143428347073495, 0.18079409084748477, 0.08001063673873432, 0.08489471802022308, 0.10899695829721168, 0.12518061645096168, 0.10373975484981202, 0.09720542657305487, 0.16052446444518864, 0.13795979088172317, 0.15712995518697426, 0.191311392118223, 0.16157417296199128, 0.14801785117015243, 0.13467776152538136, 0.1823362143477425, 0.16470029193442315, 0.1995928696123883, 0.19306228175992146, 0.11685787554597482, 0.1505328412167728, 0.119170311227208, 0.08343177425558679, 0.14260140509577468, 0.13867118395864964, 0.15459178044693545, 0.11907356485608034, 0.05635445319057908, 0.13286276516737416, 0.160612958134152, 0.1868119288701564, 0.15295132237952203, 0.11208050025743432, 0.302851022570394, 0.1674981293035671, 0.20405880262842402, 0.13987045007525012, 0.1297981257084757, 0.08205507547245361, 0.09546572109684348, 0.10094191005919129, 0.12135839264374226, 0.13709032034967095, 0.13617908174637705, 0.0755587822641246, 0.13721624796744436, 0.13471574464347214, 0.1058995010680519, 0.1424279503407888, 0.1102307194378227, 0.11749732482712716, 0.0800311571219936, 0.10592171354801394, 0.1308363160933368, 0.05525059386854991, 0.13311062764842063, 0.14239434589399025, 0.1494184322655201, 0.16843268618686125, 0.18590904684970155, 0.17601047409698367, 0.0906989436771255, 0.2145920303883031, 0.06700797937810421, 0.14030965307028964, 0.1039446544018574, 0.14330901321955025, 0.1321511494461447, 0.18216326425317675, 0.10627954005030915, 0.09430497986613773, 0.19638996804133058, 0.13401356904068962, 0.14475315838353708, 0.0920163448608946, 0.1830833640997298, 0.12204134662169963, 0.12055358543875627, 0.1050085824681446, 0.12004482094198465, 0.09471302008023486, 0.2959092106902972, 0.11559453239897266, 0.1402329743723385, 0.11927274244953878, 0.13099286472424865, 0.10315818566596135, 0.18077524029649794, 0.1305250742007047, 0.2169356436934322, 0.09830370123381726, 0.09483235000516288, 0.2298241513199173, 0.2610816451488063, 0.11469093049527146, 0.12908521865028888, 0.13806539849611, 0.10015585692599416, 0.1667672028997913, 0.12941776018124074, 0.19898356636986136, 0.22346786427078769, 0.12113991178921424, 0.08663991538924165, 0.21087765548145398, 0.08425371765042655, 0.17836670391261578, 0.09887845008051954, 0.22147726092953235, 0.09085011173738167, 0.16712335956981406, 0.0968568843381945, 0.1596928434446454, 0.23803662392310798, 0.1361529581481591, 0.16664032533299178, 0.15790404489962384, 0.1237344674882479, 0.12112684999010526, 0.1622713910182938, 0.23115320422220975, 0.1764948441996239, 0.07956277288030833, 0.11165835181600414, 0.1467778708320111, 0.1405431772582233, 0.12791517830919474, 0.14809168002102524, 0.172309368790593, 0.14714323013322428, 0.2826320700114593, 0.14229227090254426, 0.0935065328667406, 0.11985008881310932, 0.1775932079181075, 0.21585979673545808, 0.19547665142454207, 0.0814541065483354, 0.10877199107198976, 0.11531237527378835, 0.14424523251364008, 0.1549539781990461, 0.20954159670509398, 0.23645494395168498, 0.18209845991805196, 0.10122558858711272, 0.2278289763489738, 0.22597909905016422, 0.15337920020101592, 0.09173927144729532, 0.09989986050641164, 0.16826899809530005, 0.14363171387230977, 0.24407389137195423, 0.21516004053410143, 0.13381960132392123, 0.09014799550641328, 0.16873082175152376, 0.1362368802074343, 0.14549285697285086, 0.1870146836154163, 0.13008279871428385, 0.24239491584012285, 0.10138506127987057, 0.21662590093910694, 0.21390195179264992, 0.2183872103341855, 0.15957145777065307, 0.1236823687213473, 0.20200575498165563, 0.18043578194919974, 0.193741480470635, 0.08692096671438776, 0.1280171939288266, 0.10769146116217598], [0.01207183719088789, 0.04594549805915449, 0.04669796900998335, 0.030632607340521645, 0.05997040818328969, 0.010899984154093545, 0.021671936701750383, 0.04540712929156143, 0.034776420434354804, 0.022908965147507843, 0.026695539891079534, 0.04256187239661813, 0.023635357028979342, 0.11618251373874955, 0.02205497210525209, 0.030942648809286766, 0.027359411396901123, 0.017264163943764288, 0.06680539532680996, 0.02840879522409523, 0.060833021270809695, 0.06603897199966013, 0.11109929939266294, 0.041177021121256985, 0.042679332109401, 0.026330644432164263, 0.04529541009105742, 0.06199522082170006, 0.013916199404775398, 0.08643724970170297, 0.012426319390215212, 0.026426604126754683, 0.03783737884077709, 0.0455551320919767, 0.02124395683495095, 0.08364107474335469, 0.04046383575769141, 0.031504235666943714, 0.0206114818865899, 0.022836971256765537, 0.0533670601726044, 0.05235202108451631, 0.04907110123895109, 0.0618994689284591, 0.015482201506529236, 0.07034925438347273, 0.06499143797555007, 0.07343514153035358, 0.07878613017965108, 0.03182738531904761, 0.009549905280437088, 0.09247654321370646, 0.027709627174772322, 0.06121642218204215, 0.06508797654532827, 0.04645094886654988, 0.030626180341641884, 0.057025469723157585, 0.014721299758093664, 0.06252501407288946, 0.01855997234088136, 0.005649404374707956, 0.04860748529608827, 0.02274586706334958, 0.017009718612825964, 0.03226239146897569, 0.06732008958351798, 0.05604117410257459, 0.07293591363122687, 0.04178052447969094, 0.03551491303369403, 0.09216234015184455, 0.06892689125379547, 0.020785233500646427, 0.0852300351834856, 0.033684056979836896, 0.03242356367991306, 0.020265390594431665, 0.042176044662483037, 0.03418824613618199, 0.06185674719745293, 0.03603732562623918, 0.05611799751932267, 0.07894708716776222, 0.02046936617261963, 0.02482558564224746, 0.041977227010647766, 0.03174249104631599, 0.03551081637851894, 0.03975718129368033, 0.05870446751941927, 0.022673160710837692, 0.04242444891133346, 0.013754157025687164, 0.03902215823472943, 0.036410073007573374, 0.050138265069108456, 0.08031052377191372, 0.022872002482472453, 0.0985959886747878, 0.05113119557790924, 0.016609190788585693, 0.04853302933042869, 0.02623372736707097, 0.037738265018560924, 0.07718462002230808, 0.03427497351367492, 0.03408697637496516, 0.02585290356364567, 0.06297462197835557, 0.04069743416039273, 0.08050937482039444, 0.00769308287090098, 0.0976527931925375, 0.06850941834272817, 0.03180829357006587, 0.03172465352690779, 0.02182882857596269, 0.06611162083572708, 0.027836423105327412, 0.05019991898734588, 0.01992311023059301, 0.010479284756002016, 0.08746191815589555, 0.03674629930173978, 0.03448751347605139, 0.018185184053436387, 0.060805469038314186, 0.014882555460644653, 0.09344714620965533, 0.04693275113822892, 0.031773238224559464, 0.021994075177644845, 0.016323918498528656, 0.02285649345139973, 0.022909278704901226, 0.02530961992306402, 0.01891523843369214, 0.08011790676391684, 0.005162529059816734, 0.011792797085945494, 0.016312329862557817, 0.039199026869027875, 0.016713931945560034, 0.08047905808780342, 0.055734630004735664, 0.010450144327478483, 0.034173232488683425, 0.021119366938364692, 0.012964772577106487, 0.054501733466167934, 0.04948533096467145, 0.028554300697578583, 0.0297210477583576, 0.004766076554005849, 0.061018606429570355, 0.018725218942563515, 0.04623361091944389, 0.03460288775386289, 0.03328982442326378, 0.013602884137071669, 0.01673902581387665, 0.04162628021731507, 0.025390710688952822, 0.04888911920716055, 0.03346215482451953, 0.06326017813989893, 0.07500640916987322, 0.02903950386098586, 0.05776221085397992, 0.02644311505719088, 0.07722781301708892, 0.09257095181965269, 0.05707357944629621, 0.0644249418110121, 0.0299494715363835, 0.047699794158688746, 0.04686679276346695, 0.002007790089919581, 0.017226768977707252, 0.033228983156732284, 0.06375342432875186, 0.025882941990857944, 0.023866667761467397, 0.04890305302978959, 0.012476307674660347, 0.0737377002951689, 0.032703130709705874, 0.03624949822551571, 0.042317264233133756, 0.0683113317063544, 0.039206303626997396, 0.052196233154973015, 0.04177291375526693, 0.025045892180060036, 0.024553646035201382, 0.044888382908538915, 0.0695756396453362, 0.03365812634001486, 0.05230589289567433, 0.041124002091237344, 0.011661879452731228, 0.021118878976267297, 0.030667688661196735, 0.04955489617714193, 0.07294634080608375, 0.03978104876296129, 0.03296836315712426, 0.028663875091297086, 0.04038110113469884, 0.015148780530580552, 0.07861939186113887, 0.04004231814178638, 0.038941030361456797, 0.027509195351740345, 0.050347558135399595, 0.02975216044433182, 0.031793758607818745, 0.06493509412393905, 0.05727210023906082, 0.021434217524074484, 0.04436994451680221, 0.04621820764441509, 0.02442845685436623, 0.013321902388270246, 0.035966914365417324, 0.032309799862559885, 0.04657888399378862, 0.06916261962032877, 0.03084905842115404, 0.04523243143921718, 0.015263250315911137, 0.0450891227228567, 0.040557628381066024, 0.07129047575290315, 0.05914479486818891, 0.01669978846621234, 0.02235934356576763, 0.020353411164251156, 0.06440543817006983, 0.006619588521061814, 0.03165375987009611, 0.023322165143326856, 0.012133624695707113, 0.02602758842840558, 0.017009824368869886, 0.007804016786394641, 0.05907724829739891, 0.029683955217478797, 0.03365757715073414, 0.06326431932393461, 0.06827685152529739, 0.02346753146412084, 0.0028116174280512496, 0.013346557461773045, 0.030128887592582032, 0.03002384957653703, 0.06748518033418804, 0.013126070953148883, 0.04228855796100106, 0.05084804397483822, 0.018336175853619352, 0.06158723626867868, 0.07401628769002855, 0.014428884296648903, 0.064679082861403, 0.017891675779537763, 0.024962463648989797, 0.03406684561923612, 0.016207798362302128, 0.026599583907227498, 0.019567742092476692, 0.013938899846834829, 0.06701825812342577, 0.05989698380290065, 0.03359013448061887, 0.05641465249937028, 0.029940207678009756, 0.03999161461251788, 0.07112683219020255, 0.03393041290109977, 0.0019511303617036901, 0.017495168540335726, 0.0477063992730109, 0.02805115425871918, 0.05570802401052788, 0.050274022432859056, 0.02069520913209999, 0.06149349930637982, 0.053816504805581644, 0.02316844038432464, 0.022191718380781822, 0.04429682812769897, 0.03651073049695697, 0.024089892795018386, 0.067468148045009, 0.053540893422905356, 0.028753500555467326, 0.023940073588164523, 0.04544231451291125, 0.04763182456372306, 0.008332809993589763, 0.015975916176103055, 0.06554495397722349, 0.005384839860198554, 0.12565896031446755, 0.0533985977381235, 0.03864063124638051, 0.045547124318545684, 0.04950812603055965, 0.020814956515096128, 0.02172725638956763, 0.005995928895572433, 0.029475888550223317, 0.02618592192447977, 0.03607765022024978, 0.08203125995351002, 0.049829702329589054, 0.02493937729013851, 0.030639655888080597, 0.003691248657560209, 0.011240329367865343, 0.03576557712221984, 0.028467417469073553, 0.04190583240415435, 0.015055782005219953, 0.002892612178584386, 0.037084514551679604, 0.030772233149036765, 0.05351917447114829, 0.026073970802826807, 0.03811602931818925, 0.009457811247557402, 0.037082210183143616, 0.014407355520233978, 0.014024155916558811, 0.03584823753044475, 0.0338722433662042, 0.04175071982899681, 0.01962236416147789, 0.023314244572247844, 0.022605975937040057, 0.05624249650281854, 0.09011376765556633, 0.08124493222567253, 0.013415426910796668, 0.06975296841119416, 0.058102318580495194, 0.04515525921306107, 0.029384136832959484, 0.03946404409362003, 0.0381129197194241, 0.11899117162101902, 0.1217141114466358, 0.11159562549437396, 0.12090589036233723, 0.18428206618409604, 0.1635439071105793, 0.09802026019315235, 0.12486787542002276, 0.11419993301387876, 0.1410563278477639, 0.20755161676788703, 0.11150810401886702, 0.1363432448124513, 0.2260807584389113, 0.12462649930967018, 0.11430671322159469, 0.15657502168323845, 0.07398540692520328, 0.17257412255275995, 0.07034947702777572, 0.12707068846793845, 0.10545638695475645, 0.13863092986866832, 0.12693238182691857, 0.08805219273199327, 0.12997877929592505, 0.13551696727517992, 0.14219979930203408, 0.12917715590447187, 0.1699160019052215, 0.06912583878147416, 0.1651702050003223, 0.11582549617742188, 0.08801343035884202, 0.07765287809888832, 0.13203310343669727, 0.1036348745401483, 0.10785670776385814, 0.0941152943414636, 0.10320366447558627, 0.1708619433338754, 0.21835672290762886, 0.15600223210640252, 0.2005313301924616, 0.06402113926014863, 0.22749094292521477, 0.16264475067146122, 0.24434440420009196, 0.1072211770224385, 0.08423304883763194, 0.0816202734131366, 0.15979889634763822, 0.2332936620223336, 0.11808558818302117, 0.1918485586065799, 0.10208504754700698, 0.11102276912424713, 0.1400671637384221, 0.1540593637037091, 0.14663407229818404, 0.11727551172953099, 0.10211210625129752, 0.20503536507021636, 0.09376901565701701, 0.09835102056968026, 0.15245178277837113, 0.14836818940239027, 0.1072211992868688, 0.17841550754383206, 0.15526596223935485, 0.11529014052939601, 0.15361843892605975, 0.11665216705296189, 0.08553055304219015, 0.2941368136089295, 0.17678325762972236, 0.10917677325778641, 0.09347546656499617, 0.09876502022962086, 0.19884074747096747, 0.16224301129113883, 0.23794363281922415, 0.14787630876526237, 0.14971959579270333, 0.17607152316486463, 0.10106692483532242, 0.12351062832749449, 0.09172700374620035, 0.16031835519243032, 0.09022068887134083, 0.18124335736501962, 0.10173090209718794, 0.08287767195724882, 0.10028852324467152, 0.14012788626132533, 0.21137056028237566, 0.10307150281732902, 0.15886717446846887, 0.07363024473306723, 0.19821113906800747, 0.09069175968761556, 0.09711938939290121, 0.13786455849185586, 0.09992068517021835, 0.09879241290036589, 0.13025193416979164, 0.18788434710586444, 0.10851648446987383, 0.19119331642286852, 0.14426464709686115, 0.1043538523663301, 0.14347133575938642, 0.11279935933998786, 0.16993744997307658, 0.2165712640271522, 0.2630447444971651, 0.11139149035443552, 0.11339462856994942, 0.16590979968896136, 0.1704305922612548, 0.1702656870475039, 0.1164791130577214, 0.10437373450258747, 0.13142166280886158, 0.15708380844444036, 0.09571017712005414, 0.10313837032299489, 0.16043558483943343, 0.0794980650243815, 0.17078484903322533, 0.1120838696078863, 0.1536137337097898, 0.1376152562443167, 0.163198095979169, 0.09655494155595079, 0.12857993482612073, 0.06356764250085689, 0.13802395696984604, 0.15925552550470456, 0.1381627534283325, 0.19225942640332505, 0.1932056646910496, 0.11182529793586582, 0.13187683682190254, 0.10631957891746424, 0.08784303325228393, 0.1748530799522996, 0.22055719076888636, 0.14386710827238858, 0.10020647139754146, 0.13215765065979213, 0.12168454428319819, 0.09529028480756097, 0.15189677505986765, 0.10872920625843108, 0.16185684216907248, 0.1129091897746548, 0.09528719005174935, 0.1539920360664837, 0.17065304360585287, 0.08726885585929267, 0.12644324713619426, 0.2580100146587938, 0.16232780908467248, 0.13489932229276747, 0.11403379583498463, 0.2111240039812401, 0.23172073939349502, 0.40173023706302047, 0.12406674926751293, 0.11809374438598752, 0.17462921852711588, 0.16913238301640376, 0.11760506982682273, 0.1692731090588495, 0.15886932669673115], [0.029921015739091672, 0.04278442022041418, 0.060603987076319754, 0.0039795294287614524, 0.01624548647669144, 0.06677182056591846, 0.061381160412565805, 0.02108888507791562, 0.03380786576599348, 0.05842239945195615, 0.023040527521516196, 0.015126281396078411, 0.0404582176997792, 0.02391841400822159, 0.038607932219747454, 0.08961638770415448, 0.030442122151725926, 0.0629374329582788, 0.046781468045082875, 0.03516843025863636, 0.06065605615731329, 0.07130556361516938, 0.10428089924971573, 0.045277605968294665, 0.045139162029954605, 0.011275171345914714, 0.02787510569760343, 0.018881544929172378, 0.03597521528718062, 0.03579820564482361, 0.09366153783048503, 0.03524747269693762, 0.1160899679234717, 0.010701647042878903, 0.05851955029356759, 0.057887481671059504, 0.03160360924084671, 0.025372145864821505, 0.03561094323231373, 0.07680010588956065, 0.028075582049496006, 0.042773321401909925, 0.08673494739923626, 0.04378242330858484, 0.06943007480003871, 0.13455435720970854, 0.04310458643885795, 0.04011962766526267, 0.03351537794515025, 0.010632464964146493, 0.013175002604839392, 0.052141792912152596, 0.04067647591000423, 0.026339654104958754, 0.08929623261792585, 0.0623438780894503, 0.013684417408512672, 0.05857241718331352, 0.015938745709718205, 0.08621177039458416, 0.04200142102490645, 0.013880485403205967, 0.030721392322448082, 0.040530525147914886, 0.05454539772472344, 0.014166952551022405, 0.010000212660088437, 0.06905857793753967, 0.013418111630016938, 0.012728944948321441, 0.09294532079366036, 0.03058420817978913, 0.02660653968632687, 0.04250389953085687, 0.02357970708544599, 0.06095743861806113, 0.03883757126459386, 0.025821410526987165, 0.050798832162399776, 0.04107270484382752, 0.03377774570253678, 0.037911664112471044, 0.017258434563700575, 0.0022582303745366517, 0.028752545040333644, 0.02586794875242049, 0.01854501064372016, 0.05462072942464147, 0.03616545000113547, 0.06227535559446551, 0.08681007500854321, 0.025726037129061297, 0.07536514109233394, 0.03174486962961964, 0.05210040704696439, 0.09572673443472013, 0.0525173270580126, 0.033952265439438634, 0.04079378348251339, 0.06652461859630421, 0.07364290577243082, 0.033819825475802645, 0.03906181860656943, 0.07388273821561597, 0.039317926348303445, 0.019783970528806094, 0.06260745183681138, 0.03416059371375013, 0.03800479622441344, 0.028092083703086246, 0.00756672063289443, 0.02371553495322587, 0.09703290692414157, 0.03691486330353655, 0.057440018572378904, 0.019402862853894476, 0.01987791714782361, 0.04502886404225137, 0.043063003904535435, 0.03542694255884271, 0.04752000888402108, 0.020884809309791308, 0.06991605536313727, 0.05844331317348406, 0.09447202246519737, 0.04826087264518719, 0.01480903181800386, 0.05465535061375704, 0.03905932870111428, 0.03773402735532727, 0.012429181297193281, 0.04818294713913929, 0.0016845724849190447, 0.044653519144048914, 0.03552721784217283, 0.054359103814931586, 0.028400733644957654, 0.06231020684936084, 0.02196963811002206, 0.046167459586285986, 0.034601759689394385, 0.0697314238641411, 0.06087190980906598, 0.06926267597009428, 0.08571680984459817, 0.03486008645268157, 0.05927996964601334, 0.034183514944743365, 0.008658912465762114, 0.03888547689712141, 0.03331526895635761, 0.07594756374601275, 0.014344395422085654, 0.020477379512158222, 0.04171854772721417, 0.03611741078202613, 0.002338130921089032, 0.06555673928232864, 0.017443502074456774, 0.031074558137333952, 0.06533877793117426, 0.028758155676769093, 0.014635504703619517, 0.030226068120100535, 0.02291382807015907, 0.02371952956309542, 0.09126069751800969, 0.04543866314634215, 0.014285747201938648, 0.015120184652914759, 0.014902903294569114, 0.023279144697880838, 0.022873176931170747, 0.007849415815144312, 0.021999043856339995, 0.026334275389672257, 0.02086788648739457, 0.05133368686074391, 0.0107750816277985, 0.057008704607142136, 0.026292076872778125, 0.013001800180063583, 0.02968495711684227, 0.05932646519795526, 0.030246286078181583, 0.025423227889405098, 0.04323040644521825, 0.04374727148388047, 0.040749377076281235, 0.11064897902542725, 0.01533572938569705, 0.046527052400051616, 0.007196606948127737, 0.021612583441310562, 0.05608383275102824, 0.01281068509342731, 0.02654647581948666, 0.04659926336898934, 0.011187413310835836, 0.01020497862555203, 0.014753938485227991, 0.02646302687935531, 0.04313025361625478, 0.05803985943202861, 0.026015387520601507, 0.05273828668578062, 0.03284859165432863, 0.038426031824201345, 0.06524517084471881, 0.05046536294685211, 0.02591963748272974, 0.052428788840188645, 0.06226915123988874, 0.02925166532804724, 0.05145338785951026, 0.046544908473151736, 0.03839613440504763, 0.07697903769440018, 0.1360304740956053, 0.018825325387297198, 0.004808599296666216, 0.05927802521910053, 0.04081831517396495, 0.04335645651735831, 0.014114808327576611, 0.024743723042774945, 0.05630379047943279, 0.015827694442123175, 0.024363875163544435, 0.050154892887803726, 0.10237103415420279, 0.03418310676352121, 0.020901735842926428, 0.07273786410223693, 0.02959114222903736, 0.03388554265256971, 0.05127894604811445, 0.025379624858032912, 0.022336971524055116, 0.030751343547308352, 0.04384450767247472, 0.03039003822777886, 0.07645033911103383, 0.06909296163939871, 0.03513409108563792, 0.007557962362625403, 0.016980281325231772, 0.016801997044240125, 0.04857814448769204, 0.03550096065737307, 0.04326107940869406, 0.02254086732136784, 0.12928951706271619, 0.00924215148188523, 0.02433944737276761, 0.028963767690584064, 0.06462906210799702, 0.013001605366298463, 0.023642889827897307, 0.03269592816650402, 0.0190976138037513, 0.04711677407613024, 0.0394521214911947, 0.02605524456157582, 0.019039310682273936, 0.06265337593504228, 0.051325270906090736, 0.04698467921116389, 0.02688949833100196, 0.06241687573492527, 0.05144867522176355, 0.06513426429592073, 0.030524585890816525, 0.009553964828228345, 0.017150218300230335, 0.09862824241281487, 0.048910930927377194, 0.028015484786010347, 0.09121671042521484, 0.09566943321260624, 0.04293251578928903, 0.018359933856118005, 0.035893419480999, 0.00544833940693934, 0.013140501087036682, 0.03025076865014853, 0.06223708303878084, 0.004837853366552736, 0.0523624037305126, 0.055099974997574463, 0.04875750673818402, 0.030567025605705567, 0.039858848103904165, 0.04860484325035941, 0.09139840301941149, 0.08374930956051685, 0.026700658854679205, 0.028293743780523073, 0.020747558373841457, 0.04675030897487886, 0.02702288082218729, 0.006349486193357734, 0.010896568419411778, 0.022755340578441974, 0.08082337750238366, 0.1089242500893306, 0.024361925170524046, 0.18779131147312, 0.08658895210828632, 0.04575769758957904, 0.056534101167926565, 0.015994165587471798, 0.014198847275110893, 0.011498123640194535, 0.019361304439371452, 0.00019307941528268202, 0.0032266254811474937, 0.09551765659125522, 0.05394590196374338, 0.016814572736620903, 0.0024077877424133476, 0.03177312690240797, 0.022665575961582363, 0.05610374086245429, 0.016369339791708626, 0.02181027302867733, 0.020830665926041547, 0.029190955792728346, 0.03501690967823379, 0.03448881965596229, 0.010792007233249024, 0.02567747655120911, 0.05126389158249367, 0.024371038743993267, 0.010388803966634441, 0.017863778448372614, 0.058830743946600705, 0.031171289665508084, 0.01975200622837292, 0.040848676435416564, 0.012543036027636845, 0.0027649256708173198, 0.025093306139751803, 0.03499762126011774, 0.010124200489372015, 0.021988334665365983, 0.07430740253766999, 0.03786494962696452, 0.03590410640754271, 0.03543368868122343, 0.06248302335734479, 0.043081735711894, 0.18995262362295762, 0.16910933190956712, 0.1931836229050532, 0.11727983102900907, 0.09160319124930538, 0.2143791675916873, 0.12013059837045148, 0.17393149581039324, 0.13465897034620866, 0.13183569215470925, 0.06887345662107691, 0.10303926392225549, 0.11032446011085995, 0.24711884907446802, 0.07814674027031288, 0.1770603607292287, 0.08251459847087972, 0.09816183970542625, 0.10894105973420665, 0.15922806604066864, 0.13885404914617538, 0.17370962334098294, 0.23854935890994966, 0.24594572139903903, 0.12217190524097532, 0.07318482996197417, 0.1358904456719756, 0.14869636710500345, 0.12134243646869436, 0.11847695233882405, 0.17731168161844835, 0.2070832473691553, 0.18409287789836526, 0.14721898856805637, 0.14260989526519552, 0.12876860360847786, 0.15127584978472441, 0.0938806272461079, 0.12432570685632527, 0.19289402203867212, 0.22247648856136948, 0.1394196250475943, 0.19339514983585104, 0.17450237064622343, 0.16155030549271032, 0.14741150167537853, 0.1597025358933024, 0.20900043746223673, 0.10004564799601212, 0.15684483689256012, 0.15004997025243938, 0.1186883011541795, 0.11777468767832033, 0.15382530516944826, 0.1969452280900441, 0.10793094479595311, 0.13851692114258185, 0.17298939870670438, 0.1248498709173873, 0.2190287079429254, 0.12266794190509245, 0.09709530670079403, 0.09499801963102072, 0.17377751501044258, 0.20385818526847288, 0.16479181358590722, 0.1810453226789832, 0.13307724584592506, 0.15367199230240658, 0.09612459238269366, 0.2188457833835855, 0.09835514691076241, 0.09972347426810302, 0.10788326180772856, 0.08206497572246008, 0.15451548766577616, 0.21328130853362381, 0.07228749920614064, 0.20880139345536008, 0.1896344797569327, 0.10396478144684806, 0.198181408632081, 0.16566725098527968, 0.07210145762655884, 0.1012502278899774, 0.11913404989172705, 0.11760313282138668, 0.07620149699505419, 0.11474799423012882, 0.09927447492373176, 0.14295391039922833, 0.10480486293090507, 0.11744550065486692, 0.14480504934908822, 0.1421647402457893, 0.27152523631229997, 0.1250334782525897, 0.08765293212491088, 0.15628380293492228, 0.2145266768638976, 0.21537931548664346, 0.2025901072192937, 0.14937005907995626, 0.21830916608450934, 0.11461368776508607, 0.10573673323960975, 0.15684949757996947, 0.13985413766931742, 0.16401873319409788, 0.12954521662322804, 0.12524617777671665, 0.09964507378754206, 0.1568960747681558, 0.09005867061205208, 0.15248942450853065, 0.08634326411993243, 0.12161899037891999, 0.12678675760980695, 0.19648365676403046, 0.11264844360994175, 0.13648708787513897, 0.08719974706764333, 0.1469846034888178, 0.0910003150056582, 0.306811656919308, 0.1032619082252495, 0.13880711572710425, 0.07494144898373634, 0.17323586595011875, 0.1967105906805955, 0.08356481906957924, 0.24730689445277676, 0.1625944479019381, 0.09972665808163583, 0.17071458249120042, 0.10751066656666808, 0.13314182753674686, 0.13327013002708554, 0.11899529054062441, 0.14918093016603962, 0.10835845896508545, 0.18146674381569028, 0.13289528607856482, 0.1554806952481158, 0.17554268357343972, 0.1873176876688376, 0.15363595361122862, 0.22281587269390002, 0.13792617159197107, 0.22368868289049715, 0.1369087168131955, 0.07504507506382652, 0.10568385521764867, 0.1349006878444925, 0.10629881362547167, 0.23046171554597095, 0.1476309695863165, 0.09341701501398347, 0.17071094596758485, 0.12773396068951115, 0.13453826744807884, 0.13195013132644817, 0.14748043235158548, 0.20088640332687646, 0.09727935932460241, 0.10715602387790568, 0.22026068792911246, 0.15936653595417738, 0.1125535526080057, 0.054744894441682845, 0.15447128535015509, 0.16631438891636208, 0.10731038317317143, 0.1269277508254163, 0.18598452326841652, 0.21346107154386118], [0.05515108670806512, 0.033198492019437253, 0.06401322054443881, 0.02804173454933334, 0.050591268300195225, 0.044065389374736696, 0.02096035808790475, 0.07482764063752256, 0.13742661714786664, 0.05799332677270286, 0.020134971127845347, 0.012466560492612189, 0.0493310384626966, 0.014326504096970893, 0.07512677810154855, 0.028152090053481515, 0.042075951205333695, 0.015577514604956377, 0.07242362393299118, 0.059137443895451725, 0.049888688226928934, 0.028974647575523704, 0.03529225388774648, 0.016208009874389973, 0.017374601084156893, 0.1236971745674964, 0.019446206133579835, 0.031735106676933356, 0.05186186965147499, 0.03558332420652732, 0.05922299867961556, 0.018973229853145313, 0.02542033907957375, 0.0877052906434983, 0.0393667819298571, 0.09933167224517092, 0.019900576771760825, 0.03933193438570015, 0.08322350535308942, 0.09270704686059617, 0.03185992478393018, 0.024825040163705125, 0.0358716188929975, 0.04394845658680424, 0.027724494248104747, 0.05618621202302165, 0.027918512059841305, 0.04003271475085057, 0.03607150152674876, 0.049540676627657376, 0.06591625045984983, 0.023507535079261288, 0.029330646539165173, 0.07293377624591812, 0.01850753960752627, 0.008782207314652624, 0.0072293050470761955, 0.0030432700123128598, 0.05577169657044578, 0.02277838982990943, 0.053924424209981225, 0.020310711697675288, 0.052817919131484814, 0.01798139957827516, 0.06619886771659367, 0.07264285435667261, 0.03904142809915356, 0.0564899396704277, 0.05404350180469919, 0.07737081745290197, 0.04195840243482962, 0.049268872462562285, 0.04807099045137875, 0.09446414827834815, 0.019574159814510494, 0.05168431453057565, 0.03224557811336126, 0.021173779350647237, 0.027287968550808728, 0.029299895650183316, 0.0414199149236083, 0.03536092110152822, 0.07753371144644916, 0.057833316022879444, 0.02507324217731366, 0.03280289391113911, 0.05702565897081513, 0.03829644170764368, 0.1219360061804764, 0.04516504443017766, 0.044177965755807236, 0.054671369871357456, 0.032615846721455455, 0.035125237263855524, 0.011443667626735987, 0.05931288018473424, 0.026886425839620642, 0.020595395835698582, 0.06968518064240925, 0.006490396381195751, 0.04706309082394, 0.06754500485840254, 0.071816361596575, 0.005422314143288531, 0.05802243380458094, 0.11720009468263015, 0.06734482536558062, 0.09540185186779127, 0.09889673659927212, 0.045053380890749395, 0.020973872597096488, 0.03705675822857302, 0.04735705180792138, 0.05209477043536026, 0.030306103180919308, 0.0406186960026389, 0.029760160796286073, 0.026129880498046987, 0.021220850067038555, 0.03857091018289793, 0.06966802218812518, 0.06623105466132984, 0.03845754712529015, 0.013759583980572643, 0.006771687976652174, 0.03410440571315121, 0.05070300234365277, 0.04829550125577953, 0.02905433011619607, 0.0373065651365323, 0.026761937988339923, 0.06136461051937658, 0.03519614947435912, 0.027857828499691095, 0.04388701789139304, 0.010179142609558767, 0.12567127996589988, 0.05311682281899266, 0.01863960293121636, 0.015227767307806062, 0.016841555370774586, 0.060807443151134066, 0.023354882723651826, 0.03506991757603828, 0.020381091417220887, 0.013444097930914722, 0.027823240707220975, 0.04723339145130012, 0.05643296870402992, 0.0875815078325104, 0.04928109934553504, 0.0675849398248829, 0.04223421790811699, 0.032472493476234376, 0.0113883572157647, 0.029447607157635503, 0.0433978015644243, 0.02333869462745497, 0.052921500682714395, 0.022099352536315564, 0.07959803973790258, 0.038272633610176854, 0.08024016075069085, 0.049701117823133245, 0.003988063199358294, 0.04406229461892508, 0.07796417194185778, 0.05392227198171895, 0.025450344110140577, 0.030080497708695475, 0.01340082608294324, 0.026937350157822948, 0.031565585304633714, 0.04328086877649184, 0.04753750501549803, 0.005327596154529601, 0.012968267164978897, 0.05431715020677075, 0.014680576259706868, 0.028070127264072653, 0.03463288907369133, 0.024470211938023567, 0.02974370181618724, 0.06700547091895714, 0.0554123375331983, 0.015934649054543115, 0.06182976641866844, 0.05217050660576206, 0.01020023815726745, 0.03732350465725176, 0.006289705270319246, 0.06560074863955379, 0.023744975951558445, 0.049188887496711686, 0.04970182286342606, 0.06837940149125643, 0.11157859320519492, 0.004685651401814539, 0.0670739117776975, 0.022557430202141404, 0.04529206300503574, 0.03511145929223858, 0.030034640403755475, 0.032978834860841744, 0.03216354481992312, 0.029615132152684964, 0.04503692747675814, 0.019521038739185315, 0.013846730671502883, 0.11791965138399974, 0.06816702109063044, 0.05701161011529621, 0.058311110697104596, 0.0325725461152615, 0.11273866650299169, 0.032664665195625275, 0.022630208914051764, 0.03826046238827985, 0.034474941494408995, 0.022851450557936914, 0.028404672593751457, 0.036464275763137266, 0.0559948937734589, 0.047715835680719465, 0.017351752212562133, 0.01992345161852427, 0.055613426156924106, 0.04782281626830809, 0.027912151854252443, 0.008270582766272128, 0.04612939854268916, 0.015560604770143982, 0.04835183768591378, 0.030254711309680715, 0.01466419798816787, 0.00986101544185658, 0.017951177469512913, 0.05177287872356828, 0.0432756551890634, 0.0655879317491781, 0.032397829709225334, 0.02463316901412327, 0.03372211802343372, 0.02919629554526182, 0.087879005150171, 0.06330790565698408, 0.08619311280199327, 0.09327306062914431, 0.04620395469828509, 0.07894868278526701, 0.0405565930850571, 0.06739418560755439, 0.03598913055611774, 0.025332294389954768, 0.045294623414520174, 0.03329888975713402, 0.04404100982355885, 0.04250953243172262, 0.025512658539810218, 0.11997558598523028, 0.05150646626134403, 0.008497561211697757, 0.03615950539824553, 0.07100388800608926, 0.01841945224441588, 0.07597128278575838, 0.04068470261699986, 0.0647500173363369, 0.04863936424953863, 0.005578852569669834, 0.06426029634894803, 0.032272020835080184, 0.0073364943636988755, 0.02160475378332194, 0.02544660554121947, 0.023668280555284582, 0.02947029090137221, 0.0518354195082793, 0.05683167270035483, 0.053234616498230025, 0.02054368484095903, 0.040651098170201294, 0.05133606544404756, 0.004347543299445533, 0.018392753481748514, 0.048865971621125937, 0.018307523387193214, 0.027631504999590106, 0.0441438677808037, 0.015835793128644582, 0.025759624877537135, 0.03763653141504619, 0.025514100161672104, 0.07926062229671516, 0.06924637098563835, 0.016681201377650723, 0.01300989886658499, 0.026425932483107317, 0.07122722250642255, 0.016887941455934197, 0.044205562517163344, 0.008157739212037995, 0.04550104065856431, 0.01246384701516945, 0.024166445327864494, 0.05539953548577614, 0.042202791664749384, 0.060090034967288375, 0.0512485699437093, 0.01065905054929317, 0.009619551201467402, 0.04380477679660544, 0.10398090089438483, 0.0176686882332433, 0.07021923011052422, 0.008003833554539597, 0.022418359149014577, 0.03241482118028216, 0.008341142456629314, 0.0007763255484860565, 0.0373319725622423, 0.06608774594496936, 0.051519142143661156, 0.003967544671468204, 0.046017401036806405, 0.057249935998697765, 0.02618081409309525, 0.04153741545451339, 0.029690562187170144, 0.07389485748717561, 0.01165019990367, 0.018372622726019472, 0.036934411473339424, 0.040644923501531594, 0.04790680883161258, 0.05155830156581942, 0.1031687983777374, 0.009723116054374259, 0.00976516428636387, 0.006738654983564629, 0.03336681111250073, 0.05365188902942464, 0.02902761465520598, 0.03336501140438486, 0.025627296236052644, 0.0710876467928756, 0.04074909506016411, 0.011012913982995087, 0.027376371326681692, 0.046254261178546585, 0.0653711281483993, 0.010928330484603066, 0.19562969711842015, 0.10897081243456341, 0.12139108424889855, 0.26152497448492795, 0.1558328146347776, 0.14872458355966955, 0.10944813213427551, 0.272567686624825, 0.1937116016051732, 0.19114255352178589, 0.18193431169493124, 0.14465642685536295, 0.1092662094742991, 0.1297356962459162, 0.18330912542296574, 0.15173281979514286, 0.16075418883701786, 0.21657933859387413, 0.22443840047344565, 0.21766311168903485, 0.23500172974308953, 0.12790254695573822, 0.12613411294296384, 0.05957732595561538, 0.1594241414568387, 0.2110111530055292, 0.09947033511707559, 0.08197018862119876, 0.17454122949857265, 0.11356755640008487, 0.12159289646660909, 0.0912284066725988, 0.08870387260685675, 0.1987050531897694, 0.14544991630828008, 0.30379245174117386, 0.16223756392719224, 0.08341831169673242, 0.25204804551322013, 0.15982203651219606, 0.14683313114801422, 0.08451323184999637, 0.13466548640280962, 0.1073992924648337, 0.13105514575727284, 0.127218761772383, 0.11721889328327961, 0.15695255220634863, 0.11196425024536438, 0.20818872086238116, 0.1357268911669962, 0.1364781375741586, 0.15122112381504849, 0.18079143395880237, 0.13476932770572603, 0.07234254429931752, 0.10433740637381561, 0.07166987648815848, 0.13863824744476005, 0.130538729717955, 0.10817846588906832, 0.1780447899363935, 0.09126444536377676, 0.1526457504951395, 0.22405460622394457, 0.19052001036470756, 0.13507026858860627, 0.1551950426073745, 0.13643182755913585, 0.1972627782379277, 0.13780644832877442, 0.22813091170974076, 0.08995199430501089, 0.21366053115343675, 0.07128567405743524, 0.1556925190379843, 0.12652522476855665, 0.14218905300367624, 0.10732360824476928, 0.17357835225993767, 0.16465337335830554, 0.14095879480009899, 0.14164814609102905, 0.2240029230597429, 0.15009985741926357, 0.10631515571731143, 0.12561297684442252, 0.1482355676125735, 0.18116247811121866, 0.11384091165382415, 0.1203084243752528, 0.18642601207830012, 0.10232464992441237, 0.15573810174828395, 0.10910308541497216, 0.10325162947992794, 0.11857979916385375, 0.1401914586313069, 0.1903868542285636, 0.10438699668156914, 0.09480546941631474, 0.16624875337583944, 0.13323352730367333, 0.1411188908969052, 0.10790801243274473, 0.14928499411325902, 0.09728359698783606, 0.14050650032004341, 0.1921173941809684, 0.1460401463555172, 0.1281865223427303, 0.11447426048107445, 0.14644004520960152, 0.12215030132210813, 0.13635952753247693, 0.11840271530672908, 0.1529275588109158, 0.12599306035554036, 0.24606073944596574, 0.1277917591505684, 0.2179423373308964, 0.14919566921889782, 0.10032458420027979, 0.19538998341886327, 0.10799921496072784, 0.12926199822686613, 0.13291818875586614, 0.09920188545947894, 0.08777558687143028, 0.17239011445781216, 0.15036737197078764, 0.24328377126948908, 0.17626126063987613, 0.13919548160629347, 0.10912503814324737, 0.19151710061123595, 0.28233099554199725, 0.18862889934098348, 0.12316166306845844, 0.14515357674099505, 0.11570737595320679, 0.12078362153260969, 0.1796757781994529, 0.11981528208707459, 0.11194387829164043, 0.1546464767307043, 0.19407538755331188, 0.1282131060725078, 0.19903857435565442, 0.12905152514576912, 0.09943319062585942, 0.20736222068080679, 0.09806376488995738, 0.1533992975600995, 0.04083662395714782, 0.09304156992584467, 0.1827933031017892, 0.08876118125044741, 0.2160450813244097, 0.09373678418342024, 0.18708511342993006, 0.08636089754872955, 0.14356474246596918, 0.08798011534963734, 0.11307892636978067, 0.24552484945161268, 0.16063823568401858, 0.0873481914459262, 0.12619422690477222, 0.2120607576216571, 0.11076053124270402, 0.07451802404830232, 0.11501443266752176, 0.1370023313211277, 0.171126993955113, 0.10380981359048747], [0.007322148649109295, 0.0548954465193674, 0.026443191127327736, 0.015536476621491602, 0.054280024269246496, 0.05372938780055847, 0.01100505000067642, 0.024669428494235035, 0.05741631437558681, 0.03667687880806625, 0.059133543909410946, 0.04065900946443435, 0.09192635203362443, 0.020432984238141216, 0.052232887828722596, 0.008905555041565094, 0.013196919153415365, 0.05627375947369728, 0.030517207087541465, 0.0173882324816077, 0.0411777261615498, 0.08085229157586582, 0.0428708618710516, 0.030679785668326076, 0.060324197402223945, 0.09494782076217234, 0.030214761500246823, 0.03493797856208403, 0.05260608420940116, 0.002165762252843706, 0.024441390633000992, 0.014316009201138513, 0.07296084237168543, 0.048378525316365995, 0.0349580573674757, 0.06914060009876266, 0.030753388164157514, 0.010999254755006405, 0.05382223789638374, 0.0022081912993598962, 0.03957392276788596, 0.03322193646454252, 0.06600346023333259, 0.04634425771655515, 0.03240054596972186, 0.05097822409879882, 0.03931793005904183, 0.036484347147052176, 0.04453512803593185, 0.04333696771936957, 0.053573655532090925, 0.025525382661726326, 0.07243343512527645, 0.00730615722204675, 0.07167485629906878, 0.06484493802418001, 0.051378482894506305, 0.03885828089551069, 0.021723733043472748, 0.028208216826897115, 0.02704761289351154, 0.05014220587327145, 0.045103071388439275, 0.03288935411546845, 0.00863194560224656, 0.04330577896325849, 0.02010160231293412, 0.07215508521767333, 0.033819677046267316, 0.06229953476577066, 0.03426474671869073, 0.010564639160293154, 0.0037160329111429746, 0.030105582300166134, 0.03360127782798372, 0.05639533439534716, 0.05602441269729752, 0.01711072491161758, 0.019120314245810732, 0.06679462676402181, 0.029146282213332597, 0.05044780373282265, 0.015400042975670658, 0.051483968054526486, 0.0452256111020688, 0.046845307588228025, 0.07413149127387442, 0.07397629335173406, 0.08328904441441409, 0.03174335935909767, 0.09255745215341449, 0.0954391818959266, 0.013036704312980874, 0.035684486356331035, 0.042860638786805794, 0.07065628829877824, 0.06580681336345151, 0.019757555637625046, 0.023698190962022636, 0.06053852594050113, 0.007855256517359521, 0.01870955962658627, 0.024379836904699914, 0.012574695119837997, 0.03610341387684457, 0.035415917955106124, 0.02650892871315591, 0.05661619383317884, 0.010398012163932435, 0.011892391448782291, 0.019926876630051993, 0.02590999883977929, 0.04355539662356023, 0.06114732081186958, 0.037023235418018885, 0.06451107547036372, 0.008880868426786037, 0.028125567550887354, 0.08165768507751636, 0.060194752004463226, 0.0317979962710524, 0.029708136244153138, 0.045237956728669815, 0.054438606384792365, 0.024564368213759735, 0.0310941341376747, 0.043418039931566454, 0.05885454833332915, 0.10526171419769526, 0.01906240631797118, 0.03174351521010976, 0.04421127334353514, 0.02944791329355212, 0.00988231971859932, 0.020099368448427413, 0.07273384908330627, 0.04720020260720048, 0.023610331809322815, 0.030751929843972903, 0.0627343516680412, 0.023009418546280358, 0.010997603476425866, 0.01555038910737494, 0.017241561836272012, 0.010138581455976237, 0.024649492552271113, 0.02943792027508607, 0.0171474816306727, 0.018672799196792766, 0.02847767209459562, 0.013578947091446025, 0.013391962984314887, 0.05753278332122136, 0.0431628487422131, 0.0325516769225942, 0.012225809641677188, 0.05469410556543153, 0.008178771677194163, 0.029588051183964126, 0.03122999354673084, 0.013508408737834543, 0.05728900265239645, 0.037042100811959244, 0.05582512749242596, 0.025471823719271924, 0.024253727460745722, 0.025698134231788572, 0.06608277355553582, 0.01625891378353117, 0.007580564933959977, 0.07036649447400123, 0.026698354486143216, 0.045488643081625924, 0.03743912384379655, 0.027405710279708728, 0.0320946735155303, 0.12134359421906993, 0.01759598930220818, 0.06196410256961826, 0.014305261975096073, 0.03573743117158301, 0.06292542500887066, 0.018935910957225133, 0.0713283327058889, 0.039707067771814764, 0.06288811724516563, 0.04206125297059771, 0.0604566002584761, 0.027101516934635583, 0.03208131485735066, 0.0324481881398242, 0.03005417929671239, 0.03176498554239515, 0.05005766040994786, 0.00882103648109478, 0.029852636107534636, 0.039787857967894524, 0.007776242373438436, 0.02712872221309226, 0.02869866140827071, 0.016013774984457996, 0.030466130629065447, 0.05708770993805956, 0.01899959650472738, 0.06772153952624649, 0.04725110651634168, 0.03721121771377511, 0.007273068567883456, 0.10762808175059035, 0.03923489115550183, 0.026078984010382555, 0.039931522915139794, 0.059887658717343584, 0.10363092631450854, 0.083225457201479, 0.012056971045240061, 0.018549560008978005, 0.021420356060843915, 0.10560721362708136, 0.0036019404615217354, 0.04563450849673245, 0.0345298047614051, 0.050628542667254806, 0.004382068937047734, 0.04685778680141084, 0.024426627460343298, 0.06347613569232635, 0.01629662230698159, 0.04734884365461767, 0.026968778256559744, 0.030526136979460716, 0.02502480219845893, 0.022054380242479965, 0.0047431650637008715, 0.02451808231853647, 0.04105125306523405, 0.045770993165206164, 0.030648630308860447, 0.020705792157968972, 0.018822913407348096, 0.034609080976224504, 0.034504605137044564, 0.013927376148785697, 0.03394428735191468, 0.0352246145484969, 0.02114573544531595, 0.0898632185999304, 0.0334880335140042, 0.023323335881286766, 0.025232987609342672, 0.02643962696311064, 0.030565886409021914, 0.05650291612255387, 0.07887626401497982, 0.0536434433888644, 0.05457600760564674, 0.019083321894868277, 0.027515750371094327, 0.030827695700281765, 0.030733535713807214, 0.015148109814617783, 0.019509490921336692, 0.09841855600825511, 0.07517314006690867, 0.03122606016404461, 0.02874423113098601, 0.025641461979830638, 0.14309751597465947, 0.02386287167610135, 0.030314372561406344, 0.06984269406530075, 0.08124349245917983, 0.0373672060231911, 0.04078172358276788, 0.03385660260391887, 0.052362882415764034, 0.060171834484208375, 0.052967907176935114, 0.019554570826585405, 0.06046783637430053, 0.03539348654157948, 0.04282367983250879, 0.033506204999866895, 0.01955170799192274, 0.01584451336384518, 0.040263081100420095, 0.008021479970921064, 0.03283073558122851, 0.019037277197639924, 0.06470045671449043, 0.05014295173168648, 0.06648934431723319, 0.04094842108315788, 0.010044577320513781, 0.06682301391265355, 0.03517071236274205, 0.025728517757670488, 0.009627737090340815, 0.028019967357977293, 0.08065132540650666, 0.019931789647671394, 0.016986272312351502, 0.08135452517308295, 0.07941860327264294, 0.0220663455183967, 0.017474186170147732, 0.013498169882950606, 0.0027881405139851267, 0.025756422510312404, 0.056810977912391536, 0.0329270329530118, 0.04783826407219749, 0.08500258176354691, 0.018498572608223185, 0.06395294331014156, 0.05064482167654205, 0.057039240273297764, 0.056122765818145126, 0.07061417141812854, 0.048056997256935574, 0.017113630419771653, 0.005781143936474109, 0.06393873118213378, 0.03512770861561876, 0.04278621621779166, 0.03961807684390806, 0.023589740922034252, 0.05906410115130711, 0.05393579391238745, 0.02348279373109108, 0.057983315200544894, 0.012433841056918027, 0.0226444099098444, 0.03594344394514337, 0.015671659748477396, 0.05205546629440505, 0.03798378602368757, 0.031214723858283833, 0.05140360830409918, 0.025976886754506268, 0.05691842976375483, 0.03113288723398, 0.08213401772081852, 0.02983444235724164, 0.030347997417266015, 0.08015269864699803, 0.03705643910507206, 0.026212570592178963, 0.01646407865337096, 0.05123979404743295, 0.060324048972688615, 0.041180063926731236, 0.22560228098882362, 0.09806090019992553, 0.2974720549536869, 0.10934982725302689, 0.13150231941835955, 0.1515283135813661, 0.09455404462642036, 0.1340948638971895, 0.2036045934073627, 0.16535473259864375, 0.17763239331543446, 0.17185855860589072, 0.1433456753147766, 0.10739483957877383, 0.19923806365113705, 0.1077031648310367, 0.144225372641813, 0.1411516492953524, 0.11706575853168033, 0.12314198131207377, 0.15629515779437497, 0.10363208406488411, 0.13170931924832985, 0.16305952216498554, 0.14303455216577277, 0.12416373312589712, 0.16754261363530532, 0.1251554724876769, 0.2501978713553399, 0.2414921228773892, 0.18509817629819736, 0.1386187586467713, 0.20364153751870617, 0.16888615326024592, 0.12842932337662205, 0.13936642790213227, 0.25223675882443786, 0.16406018956331536, 0.19764053140534088, 0.0682491619954817, 0.10571695500402711, 0.19274413789389655, 0.2193745190743357, 0.11587024026084691, 0.16434132994618267, 0.05852582886291202, 0.1197654617135413, 0.12707236572168767, 0.10960895553580485, 0.08842014955007471, 0.10743610298959538, 0.07135692023439333, 0.13970753381727263, 0.07534839081927203, 0.12219665586599149, 0.09856228032731451, 0.12262879361514933, 0.09872454349533655, 0.11122301541035995, 0.10815203801030293, 0.07470641081454232, 0.1606470820843242, 0.14207692933268845, 0.07785660505760461, 0.11862417217344046, 0.08902263245545328, 0.12005501062958501, 0.08568822973757051, 0.12973449396668002, 0.17916716955369338, 0.11812707423814572, 0.14346715004649013, 0.08665463217766955, 0.13751950435107574, 0.15396420552860945, 0.12127564317779616, 0.18241167592350394, 0.1495343557326123, 0.15843275090446696, 0.12820317613659427, 0.11275006589130498, 0.17253179044928402, 0.08893563048331998, 0.12847892852732912, 0.06563815288245678, 0.19445596088189632, 0.17179777671117336, 0.17411329230526462, 0.15167747042141855, 0.12770246394211426, 0.1473495620302856, 0.2887615864165127, 0.16934062965447083, 0.11348520027240738, 0.19640213926322758, 0.17833925929153338, 0.12838862399803475, 0.190867691708263, 0.15316463046474382, 0.16445977671537548, 0.1172836308251135, 0.07412500490318052, 0.07774696758133359, 0.1869415820692666, 0.12049575729179196, 0.14645273593487218, 0.13968589279102162, 0.1577507914043963, 0.1117737557797227, 0.11869258334627375, 0.10742358295829035, 0.08387599416892044, 0.11142118368297815, 0.17115598224336281, 0.19229910161811858, 0.2266234761918895, 0.13680791831575334, 0.1684262146591209, 0.20261590427253395, 0.13351282716030255, 0.19168412836734205, 0.10649390198523179, 0.11647469727904536, 0.1695298179402016, 0.12099968298571184, 0.18385392118943855, 0.13662698271218687, 0.14869538747007027, 0.21964869811199605, 0.07587372747366317, 0.08461110628559254, 0.08288304510642774, 0.1844783642445691, 0.19400345860049129, 0.15026850305730477, 0.1506339365732856, 0.1413411641260609, 0.11809582239948213, 0.1791946735465899, 0.1861715890117921, 0.13251146214315668, 0.1672167662763968, 0.12409561139065772, 0.11761434667278081, 0.11437695007771254, 0.10292036444297992, 0.19529393466655165, 0.1043058279901743, 0.1551557533093728, 0.07546184293460101, 0.11586634398554452, 0.07305755163542926, 0.17312466254225, 0.13238188315881416, 0.1291851414134726, 0.08520658331690356, 0.11578391364309937, 0.16189938207389787, 0.10331310157198459, 0.1427255367161706, 0.10043900852906518, 0.12749004643410444, 0.14873724459903315, 0.13827342248987406, 0.14863187447190285, 0.08705812302650884, 0.14306855737231672, 0.1419061017804779, 0.10105698747793213, 0.15442176925716922, 0.16715834441129118, 0.17457156849559397, 0.1347049983451143, 0.13441141956718639, 0.2504673006478697, 0.0955070364580024], [0.009469683755014557, 0.013670422358700307, 0.020920675451634452, 0.022884808240632992, 0.028255484212422743, 0.04005923539807554, 0.040205071127275005, 0.01709418615064351, 0.053678669428336434, 0.008355579084309284, 0.027757909447245765, 0.08180617398465984, 0.012059950768161798, 0.03392337363038678, 0.013178483277442865, 0.05943219155597035, 0.06383962478139438, 0.04870616125117522, 0.1263850330724381, 0.06701535632601008, 0.07852732102037407, 0.020238387551216874, 0.028167951604700647, 0.035444115856080316, 0.05818522760819178, 0.11346114726620726, 0.018290207226527855, 0.0059748481908172835, 0.014252357977966312, 0.07453305253875442, 0.021887003676965833, 0.045484260699595325, 0.031005176606413443, 0.03463072942395229, 0.033239243348361924, 0.046369167903321795, 0.06052553093468305, 0.044313378020888194, 0.04567826552374754, 0.03212956558854785, 0.05230052716797218, 0.04463168515940197, 0.030831881413178053, 0.03156878396112006, 0.029191848225309514, 0.020004581347166095, 0.03631801329902373, 0.07338377748965286, 0.052232609523343854, 0.038052082163630985, 0.02740331499808235, 0.04074985205079429, 0.008770273580012145, 0.02793557217955822, 0.03106776191998506, 0.023781595373293385, 0.020420243417902384, 0.020727058399643283, 0.037282964840414934, 0.10970357194310054, 0.033445530716562644, 0.01970027482457226, 0.06228331141755916, 0.027807048900285736, 0.019660790712805465, 0.04275132043403573, 0.018614718719618395, 0.05395966880314518, 0.10938842635368928, 0.04480816416617017, 0.019343466919963248, 0.02924843141954625, 0.027727898850571364, 0.046476074276142754, 0.0655966297199484, 0.05705542651412543, 0.014260402858781163, 0.07714641425991431, 0.051555770842242055, 0.043199035862926394, 0.023376865137834102, 0.07714414328802377, 0.006123523098722217, 0.0669610608019866, 0.03662010080006439, 0.01954677270987304, 0.04033728102513123, 0.09138989800703712, 0.024910225729399826, 0.06069990595278796, 0.022722383655491285, 0.03861895311274566, 0.045830164599465206, 0.003908229909939109, 0.03995339029643219, 0.004089962858415674, 0.06965392880374566, 0.051399919830146246, 0.043340463234926574, 0.06794842891395092, 0.0338513741735369, 0.031129599519772455, 0.018507166678318754, 0.0484050162776839, 0.04668251749535557, 0.050764103361871094, 0.07378944283118472, 0.022184872068464756, 0.015458068719453877, 0.030843047024973202, 0.05054714762081858, 0.06486280894023366, 0.012724676671496127, 0.07287948072189465, 0.010063800800708123, 0.0627576328406576, 0.055927606954355724, 0.07097921901731752, 0.08652687145513482, 0.03483295724436175, 0.04710648790933192, 0.06898849693243392, 0.051631291789817624, 0.015246769071382005, 0.04720881152024958, 0.02340862720302539, 0.03310263251478318, 0.07917416951386258, 0.02474900713423267, 0.03304851139546372, 0.04100565922271926, 0.03126825497020036, 0.07378536101896316, 0.020858310926996637, 0.01464659238990862, 0.05509811962838285, 0.019081334794464055, 0.039495685559813865, 0.04558540058496874, 0.027989199770672712, 0.024614617177576292, 0.04571877194393892, 0.02790380454825936, 0.040145421007764526, 0.04916826692351606, 0.037289117244654335, 0.08519321723724715, 0.04207527956168633, 0.06996567535679787, 0.06168655789224431, 0.013256277052278165, 0.01652045590162743, 0.06200493182404898, 0.02453931145282695, 0.01627446363272611, 0.01872273274784675, 0.04911908479698468, 0.022923129035916645, 0.04838689674215857, 0.03723117035406176, 0.015276626600098098, 0.05264564068056643, 0.011036090327252168, 0.03949573008867446, 0.0773697710246779, 0.031146327528404072, 0.03724478876392823, 0.03823972678219434, 0.033547609418747015, 0.04060026476508938, 0.023686630156589672, 0.036932199873263016, 0.09004865903989412, 0.017983813413593452, 0.04709053915576078, 0.025557975932315458, 0.02090234811475966, 0.08252840241766535, 0.02013106186495861, 0.017550480806676205, 0.056762745734886266, 0.07449324373737909, 0.026641383519745432, 0.03735898673767224, 0.06295827246503904, 0.06478203358710743, 0.05232770461589098, 0.041003566366271116, 0.035085762428934686, 0.0617533326294506, 0.04143006750382483, 0.014149484250083333, 0.040686053325771354, 0.02324277946172515, 0.04290585784474388, 0.06306568349828012, 0.06118582343333401, 0.028877999538963195, 0.01848201714892639, 0.008711913869774435, 0.0919310720928479, 0.06863804737804458, 0.024890853819670156, 0.03398184373509139, 0.046331240446306765, 0.009604121951269917, 0.03411515572224744, 0.046845077522448264, 0.03965883930504788, 0.0241436484066071, 0.05787017107650172, 0.04994463131879456, 0.05449791882710997, 0.013552192667702911, 0.06304795359028503, 0.03553561895387247, 0.010353564011893468, 0.006608824132854352, 0.03832447633612901, 0.05627417878713459, 0.03620736279117409, 0.013317648954398464, 0.02795736163534457, 0.02379333058343036, 0.12937110877828673, 0.002339976781513542, 0.042286624666303396, 0.021361804319894873, 0.03707752352056559, 0.038037291160435416, 0.01933082443429157, 0.060200281004654244, 0.01361332801025128, 0.029374774640018586, 0.0938287956523709, 0.057561582361813635, 0.032723235490266234, 0.041947077261283994, 0.010342215646232944, 0.02499460049875779, 0.039880581898614764, 0.0370883662981214, 0.010549424205237301, 0.036133151734247804, 0.07437012885930017, 0.04461595533939544, 0.04945323678839486, 0.034019344457192346, 0.11311208552797325, 0.02471948078891728, 0.02898680580983637, 0.0952704249357339, 0.017246289316972252, 0.05949892176431604, 0.04388906992971897, 0.0037812319760632818, 0.07940419076476246, 0.04981660342309624, 0.041527778666932136, 0.06862881506094709, 0.118190179055091, 0.00839692691442906, 0.03799697398790158, 0.05355724293622188, 0.027932536795560736, 0.019570066870073788, 0.005618486502498854, 0.02066164364805445, 0.01521661097285687, 0.04321254666137975, 0.030453916733677033, 0.037927731609670445, 0.06975892043556087, 0.03187214424542617, 0.02781182647595415, 0.03695042702020146, 0.03680248359160032, 0.027238192706136033, 0.047895650641294196, 0.012656315593631007, 0.04013864148873836, 0.01719370444334345, 0.024890556960599497, 0.05546654399950057, 0.012671394179051276, 0.08275941814645194, 0.03364401069120504, 0.018187479145126417, 0.043662369789672084, 0.07483529960154556, 0.020625282122637145, 0.04837603170017246, 0.056714673119131476, 0.06383195097441785, 0.038330094394041225, 0.0238681056725909, 0.027829599057440646, 0.02849185639206553, 0.013570754708780441, 0.022555092436959967, 0.006570457881025504, 0.022788137939642183, 0.039551676891278476, 0.024834819814714137, 0.05171964075998403, 0.017500528701930307, 0.06390248468960635, 0.03464686371444259, 0.05008847809222061, 0.0068121368803986115, 0.03518613048072439, 0.04210455728753004, 0.04280976456357166, 0.018636074019013904, 0.045044085491099395, 0.06672044910374098, 0.01088457252990338, 0.07089843624271452, 0.04520972172031179, 0.03757751212106086, 0.04684040199208539, 0.04182585114904214, 0.05527807559701614, 0.05426797921245452, 0.019506088174239267, 0.04787363483046647, 0.01660526482737623, 0.10063071269541979, 0.03995023245806806, 0.03166092901665252, 0.026052207322209142, 0.04401524245622568, 0.06446789731853642, 0.05211609233811032, 0.05651847524859477, 0.02023652476054849, 0.0428417585499119, 0.039534221577923745, 0.013840435403835727, 0.038750725143472664, 0.05394198342401069, 0.041654689630377106, 0.0546411496179644, 0.03213153970136773, 0.05063298813183792, 0.05131173042173032, 0.04749822313897312, 0.09550132192089222, 0.014394307636393933, 0.006835041413069121, 0.046117802485241555, 0.06263039162149653, 0.14661529596196488, 0.12030397148919292, 0.1185481836728286, 0.1425266411388293, 0.17885862907860428, 0.15485724667087197, 0.15628211083821952, 0.16425869922386482, 0.0731963109865319, 0.1625132272602059, 0.1888895416050218, 0.26612385583575815, 0.167705396306701, 0.08792912980425172, 0.11953065361012705, 0.1443884224863723, 0.23257697001099586, 0.11084084646427073, 0.18123106739949435, 0.16054160805651918, 0.20326498663052917, 0.09384422490256839, 0.12467243825085461, 0.10018024389864877, 0.17097393341828138, 0.17210590158356354, 0.09927486826200038, 0.08444966690149158, 0.1258512062486261, 0.11336734722135589, 0.07930121035315096, 0.11492383127915673, 0.14233264373615384, 0.13706918398384005, 0.25167483428958803, 0.17593523516552523, 0.13904954568715766, 0.12077015897375531, 0.09165540133835748, 0.14597387256799266, 0.14333743747556582, 0.09883067061309703, 0.11847163856145926, 0.09630045169615187, 0.1358300051651895, 0.11839005426736549, 0.1381063205190003, 0.16307458776282147, 0.23421776946634054, 0.11769814256695099, 0.08798893206403591, 0.08384146203752607, 0.12926254741614684, 0.11403314274502918, 0.10735696778283454, 0.1266626556753181, 0.13476425141561776, 0.1456607604632154, 0.21048378286650404, 0.1981079508550465, 0.11047038860851899, 0.08021727291634306, 0.16231528163189068, 0.09468829914112575, 0.1718552634702064, 0.12148129972047172, 0.12250731146195903, 0.1523369873757474, 0.2624256449053064, 0.17587489855941385, 0.2329038712196052, 0.04894892517768312, 0.24502853077137843, 0.20447290618903935, 0.20980912609957159, 0.13718562695430592, 0.09603433980373666, 0.21367486944654956, 0.09240831757779233, 0.14561839867383242, 0.1659962153644301, 0.12159038058598526, 0.1016416736820247, 0.1681361091323197, 0.32264009350910783, 0.11218570711207576, 0.09948690727469511, 0.2100306423380971, 0.09594424307579175, 0.16248036496108398, 0.20428450457984582, 0.05414084931544494, 0.11796867023804225, 0.18546945793787017, 0.1394350320333615, 0.1266278192633763, 0.16903447889490053, 0.14048900047782809, 0.10430103371618316, 0.11750113204470836, 0.08983208550489508, 0.15780051529873163, 0.08650969815789722, 0.16156603902345523, 0.11124779572128318, 0.16669763397658244, 0.12824832840124145, 0.12812677945476025, 0.07110428574378602, 0.17172954365378246, 0.12374358106171712, 0.139041812508367, 0.18299522664165124, 0.2046107972273603, 0.12749685934977606, 0.1078347401926294, 0.1409466384211555, 0.15759894798975438, 0.3207019600085914, 0.10041951973107643, 0.18846773455152288, 0.15271606156602502, 0.1290212306776084, 0.13014012220082805, 0.1796018602908589, 0.20076936663826928, 0.14317823195597157, 0.1282129279570654, 0.20539581135381013, 0.08499179093632847, 0.15534313075477257, 0.10204915728536434, 0.1632170207449235, 0.06761124896002002, 0.10359703243011609, 0.1971976028289646, 0.15058672113809735, 0.11881629194249399, 0.14776862313738093, 0.15570034127449617, 0.13909901725128293, 0.20118149608606473, 0.11358326024492271, 0.159844761074055, 0.2764069946715608, 0.14344003197038546, 0.1479656930314377, 0.12974570039659739, 0.20506309170741588, 0.20660616515669972, 0.15622475766576827, 0.2301263390108943, 0.09504231842583977, 0.10881931782932952, 0.08228078484535217, 0.13049047527601942, 0.08491557979141362, 0.11834378878120333, 0.18219369230791926, 0.13196527113905177, 0.10601946923998185, 0.1369125908240676, 0.1132864531246014, 0.11782833011238836, 0.18135815276764333, 0.11861651320941746, 0.15210692159598693, 0.10110996197909117, 0.12794646725524217, 0.17840081301983446, 0.12063536269124597, 0.21212293475400656, 0.15974287904100493, 0.08733067676075734, 0.1463839240022935, 0.12400852036080323], [0.049468710567452945, 0.020831011024711188, 0.08623439105576836, 0.03769657858356368, 0.017788892037060577, 0.06196115253260359, 0.029619527522299904, 0.02267938918521395, 0.024858687283995096, 0.047723557727294974, 0.02728474577452289, 0.029159418227209244, 0.03247595188440755, 0.010815943351190072, 0.04776378584210761, 0.017424927973479498, 0.07605320104630664, 0.05711691715987399, 0.012932538320455933, 0.024128734949044883, 0.0712601219129283, 0.09877800039248541, 0.021659453777829185, 0.06524249169160612, 0.028983647971472237, 0.034765002492349595, 0.043542253188206814, 0.03210784663679078, 0.0202488722425187, 0.06797257097787224, 0.05356765155738685, 0.11688212151057087, 0.047069258071132936, 0.06348714174237102, 0.08638565559522249, 0.031560572097077966, 0.030334477341966704, 0.06338774590403773, 0.06344186331261881, 0.024596787079644855, 0.05115526342706289, 0.013817893595842179, 0.0379933189105941, 0.014193990846251836, 0.041882413934217766, 0.018157648519263603, 0.019582781715143938, 0.02645586329890648, 0.0149782433436485, 0.03221110164304264, 0.029525120771722868, 0.013172013605071697, 0.02461673600919312, 0.045464122522389516, 0.033540173099027015, 0.08110799855785444, 0.014579042108380236, 0.02825993153237505, 0.050257851034984924, 0.01646100059588207, 0.03578562995244283, 0.009564777919877088, 0.07141937196138315, 0.03346422170579899, 0.057361673752893694, 0.020394964012666605, 0.05001582554541528, 0.05423101283668075, 0.04084879517904483, 0.026623546000337228, 0.007160052464314504, 0.03431700875808019, 0.07119821195374243, 0.05687799013685435, 0.020950789948983584, 0.03693924656545278, 0.11851629358716309, 0.024063774762907997, 0.0325727687595645, 0.045066542879794724, 0.0542241628136253, 0.04285846429411322, 0.05160019580216613, 0.0097524095508561, 0.08466305662295781, 0.07145161085645668, 0.0609760368388379, 0.01814906001527561, 0.04596530598064419, 0.10206538063357584, 0.08963419182691723, 0.0028069650898032705, 0.033892296196427196, 0.011582887109398143, 0.010478720723767765, 0.06861503337859176, 0.04097791403182782, 0.09462454123422503, 0.08657697384478524, 0.051363654783926904, 0.00787565351856756, 0.02360377307923045, 0.03815589006990194, 0.06197171700478066, 0.041342397598782554, 0.07193192141130567, 0.07190018717665225, 0.07182292960351333, 0.07392535233520903, 0.051265528018120676, 0.018209507943538483, 0.05396152788307518, 0.06303422385826707, 0.08735931623959914, 0.04541344125755131, 0.036015057485201396, 0.014810881621087901, 0.030417230518651195, 0.023142476347857155, 0.012357793184492039, 0.11139976530103013, 0.03967947843193542, 0.024165439717762638, 0.02358435664064018, 0.03653219711850397, 0.04640828279661946, 0.021495199798664544, 0.02485090029949788, 0.06905920134158805, 0.05597644398221746, 0.011943683130084537, 0.05645896242640447, 0.036383945698617026, 0.03326353013108019, 0.04676871052652132, 0.027138813566125464, 0.0147976027437835, 0.02747415484918747, 0.04468445185921155, 0.0377076402946841, 0.034219731751363724, 0.04094174917554483, 0.027617064661171753, 0.026430001307744533, 0.07767384377075359, 0.0756246256059967, 0.01118410611525178, 0.07661577867111191, 0.018185731387347914, 0.00756639084102062, 0.035623433577711694, 0.018718641658779234, 0.06421662837965414, 0.025492811655567493, 0.021723935278714634, 0.03389067460375372, 0.02824042603606358, 0.020726006405311637, 0.049717574947862886, 0.02065287517325487, 0.019363673745829146, 0.03453400160651654, 0.06494656772702001, 0.009126389431912685, 0.03356756948051043, 0.02459714702126803, 0.04152698085817974, 0.04556312873319257, 0.05061930663941894, 0.03476819743809756, 0.047608628738089465, 0.03578411226044409, 0.014524142661684891, 0.02181565545470221, 0.013387315284489887, 0.03847075735393446, 0.048700925399316475, 0.048015641077654436, 0.024583532322139945, 0.019202369803679176, 0.020729435127577744, 0.10532439599046484, 0.05530819566047285, 0.006949257940505049, 0.022060738592699636, 0.02437571241898695, 0.029757108713965863, 0.04041610452986788, 0.01721517663099803, 0.01473913913287106, 0.019889746981789358, 0.06696268610539846, 0.028056989394826815, 0.15354423900134861, 0.03662170383904595, 0.062213530982262455, 0.022301175886241253, 0.04277471663954202, 0.020207920533721335, 0.05729779339162633, 0.01819668548705522, 0.023655454388062935, 0.026431943879288156, 0.04370919559733011, 0.03345834389619995, 0.055471642554039136, 0.024018846997932997, 0.05186935050005559, 0.019309791969135404, 0.032566078298259526, 0.061878874330432154, 0.021622120038955472, 0.009707480858196504, 0.0515082437050296, 0.03245099345804192, 0.0556024275283562, 0.023690016205364373, 0.07006615473073907, 0.028170001787657384, 0.025371793344675098, 0.048823465112945996, 0.016404766211053357, 0.01474682314437814, 0.023585334420204163, 0.018249743479827885, 0.04118543707591016, 0.049485271592857316, 0.059711001595132984, 0.03425398186664097, 0.05444629132398404, 0.02487504607415758, 0.02282773522892967, 0.03207616064173635, 0.015192134942481061, 0.07219830789836124, 0.04405454659718089, 0.053020547711639665, 0.030722806113772094, 0.029600728921650443, 0.01845693441282492, 0.04315140853577759, 0.0440516225353349, 0.023597331237397157, 0.024907043771236204, 0.06807690209825523, 0.0033634881810939987, 0.05770590782049112, 0.02547963482356863, 0.03641671522927936, 0.021363481573644094, 0.06054562458302826, 0.012594244217325468, 0.04507608318817802, 0.009965653625840787, 0.05488032526045572, 0.029886927040934097, 0.06999028497375548, 0.05485515903274063, 0.013587149678642163, 0.028111819265177473, 0.03286878920334857, 0.014102015557000414, 0.08266066797659732, 0.009872412974800682, 0.07292656999197789, 0.03392895458091516, 0.1155545529036317, 0.06105579173890874, 0.044717232522089034, 0.014036270549695473, 0.051196923886891454, 0.02772686169919325, 0.022635984678345267, 0.035504649131326005, 0.057801244111033157, 0.053114867259864695, 0.02565679660619935, 0.05359983479138464, 0.02631415020005079, 0.015959735501382966, 0.01721346598060336, 0.08339602500200272, 0.0531635335937608, 0.002871281694751815, 0.06888470015837811, 0.07248004942084663, 0.037918298912700266, 0.03493580406939145, 0.0326927888818318, 0.022769101851736195, 0.06405508509487845, 0.06616960483370349, 0.0244159813519218, 0.04929883296426851, 0.027801894684671424, 0.0611985067371279, 0.12046060917782597, 0.02880109634133987, 0.08950586707214825, 0.07694889907725155, 0.016455449331260752, 0.03860624383378308, 0.03328930863062851, 0.031774915478308685, 0.04496566274610814, 0.029147510467737447, 0.0879629717383068, 0.06983140599913895, 0.03618745096900966, 0.04941415158100426, 0.022020070755388588, 0.06143955630250275, 0.03528253175318241, 0.00889751758222701, 0.05129328434122726, 0.05686192635039333, 0.012964436755282804, 0.07979379603057168, 0.04058679107401986, 0.011045613937312737, 0.017843204259406775, 0.021655509262927808, 0.03584451937058475, 0.00912294030058547, 0.044162748017697595, 0.02373690138483653, 0.020617788286472205, 0.021941455052001402, 0.03161104556056671, 0.021712380039389245, 0.04754928289912641, 0.025028275449585635, 0.043263829065836035, 0.036298921550041996, 0.0031902822775009554, 0.0842405371076893, 0.036455266090342775, 0.03648283316579182, 0.05524583670194261, 0.04826082811632659, 0.03264052313170396, 0.012718938942271052, 0.04413984905113466, 0.038252654994721524, 0.029991235896886792, 0.02814881347148912, 0.05076050394563936, 0.1173867002944462, 0.049197322005056776, 0.025751030807441566, 0.07511567557230592, 0.02502840718079824, 0.22097295674029738, 0.10122646432137117, 0.12037997483275831, 0.13932976580690593, 0.0868961047672201, 0.20593965717125684, 0.07377940899459645, 0.12720730301225558, 0.11473623118945397, 0.16982075467240065, 0.14521665929351002, 0.11826525471406057, 0.19050040282309055, 0.12439772486686707, 0.08254282976849936, 0.15654996677767485, 0.19743900862522423, 0.2463571383850649, 0.18689518299652264, 0.11834850141895004, 0.09703582356451079, 0.17650593188591301, 0.11565690991119482, 0.15123593708267435, 0.1229996670736, 0.09711252452689223, 0.13954052090412006, 0.13108232320519164, 0.09434883337235078, 0.19509778503561392, 0.10224059427855536, 0.20116767729632556, 0.08985576743725687, 0.11636514886049554, 0.22656251618172973, 0.22609435458434746, 0.11059785247198306, 0.10852940526092425, 0.21604948968160897, 0.14305794466054067, 0.08601942055975087, 0.2694965014234185, 0.13675256894202903, 0.0902488904830534, 0.19766364188399166, 0.09725398529553786, 0.22290089313173667, 0.15369096159702167, 0.07497127589886077, 0.11316841453663073, 0.1447489281417802, 0.15218174492474645, 0.0752847219700925, 0.18779714475385845, 0.17012700933264568, 0.15176355955190957, 0.08748942957026884, 0.07098272195435129, 0.18684967450099066, 0.1529612671583891, 0.13603376923128963, 0.1708755543222651, 0.1655995671171695, 0.10171922069275752, 0.1519728303537704, 0.1673111823038198, 0.15553064178675413, 0.22366785822669044, 0.18793919181916863, 0.17542113462695852, 0.1441453245934099, 0.07601547025842592, 0.20492101495619863, 0.14936177671188489, 0.10123277257662266, 0.12267433921806514, 0.22386656084563583, 0.18773256306303665, 0.09126863107667305, 0.0829850829904899, 0.1800830985303037, 0.21686102816602215, 0.09001177430036478, 0.09883858190733008, 0.24393007799517363, 0.10989038535626605, 0.15597621240885928, 0.1216928414942231, 0.10803490484249778, 0.16683840454788879, 0.20018842827994376, 0.15321199432946742, 0.11703007607138716, 0.16787027183454484, 0.15200181864202023, 0.09092125401366502, 0.1037799940968398, 0.1261142679140903, 0.2237548676203005, 0.12469272856833413, 0.17928677407326177, 0.16316472901962698, 0.08026464420254342, 0.1282059369259514, 0.1583037804812193, 0.14916592394001782, 0.20911250176141039, 0.11217833758564666, 0.14690587646327913, 0.1398721124860458, 0.11075581118348055, 0.18828543339623138, 0.13332494505448267, 0.1437294398783706, 0.20356058405013755, 0.13820943451719359, 0.10127903064130805, 0.1034267021168489, 0.26386745972558856, 0.14698363869683817, 0.24023680976824835, 0.1177336840191856, 0.12535361107438803, 0.21212496823864058, 0.13366263709031045, 0.09242984728189185, 0.17709187231957912, 0.09161177047644742, 0.1928765667253174, 0.16083445952972397, 0.15662765479646623, 0.14111878699623048, 0.07648234051885083, 0.16252955450909212, 0.15932703885482624, 0.17457956884754822, 0.10227924532955512, 0.08836421387968585, 0.14165924862027168, 0.14098281069891527, 0.11497236031573266, 0.14851912739686668, 0.07615149108460173, 0.08842890689265914, 0.14818038151133806, 0.20249984721885994, 0.1010157834389247, 0.17611974792089313, 0.11222052868106402, 0.10552213381743059, 0.17654801165917888, 0.11391051768441685, 0.11625537779764272, 0.07376371257123537, 0.11960029674810357, 0.13578368030721322, 0.20504977757809684, 0.07000094963586889, 0.14641202171333134, 0.1598715377622284, 0.09580781406839378, 0.20117006701184437, 0.1172666801721789, 0.05974462459562346, 0.16308344900608063, 0.13074610062176362, 0.11798334991908632, 0.15212433238048106, 0.16420551692135632, 0.06222691932634916, 0.1767063859733753, 0.14820818236330524, 0.12806044629542157, 0.12058054024237208, 0.16112337762024254, 0.1263738563284278], [0.028793769488402177, 0.02218430247012293, 0.033414375357097015, 0.028347989209578373, 0.04351080839114729, 0.018525943014537916, 0.04379815683932975, 0.010771310589916538, 0.06317771811154671, 0.07562007624073885, 0.007291908914339729, 0.0895993183075916, 0.04550960504275281, 0.01721485379675869, 0.04396261305373628, 0.03458035243966151, 0.050503294114605524, 0.02044711658527376, 0.015411282802233472, 0.06569565448444337, 0.042265966985723935, 0.01785599517461378, 0.021795695392938796, 0.025236824512830935, 0.021998823067406192, 0.03209387941751629, 0.03590088919736445, 0.06142099518910982, 0.07130563782993704, 0.05076088615169283, 0.03965204865380656, 0.04923012122162618, 0.049765358126023784, 0.019496540444379207, 0.03698793887451757, 0.044752247049473226, 0.020954214960511308, 0.022990465949987993, 0.033735179822542705, 0.03146734721667599, 0.11623890954069793, 0.03067180201469455, 0.05807648070913274, 0.027704166823241394, 0.018447759612172376, 0.020574114751070738, 0.06641576037509367, 0.03773998309043236, 0.04935453485813923, 0.06225913224625401, 0.03979392131441273, 0.017208903627761174, 0.04693075105024036, 0.046551057166652754, 0.0304449831310194, 0.018980189342983067, 0.016234315298788715, 0.037870972155360505, 0.04840820009121671, 0.021117235119163524, 0.034780298155965284, 0.021271299410727806, 0.034363971863058396, 0.035808929678751156, 0.04101875070773531, 0.0511443501454778, 0.022258680510276463, 0.02107262462232029, 0.04419558805238921, 0.02698760654311627, 0.052622741714003496, 0.025727998254296836, 0.06499288516351953, 0.015633125585736707, 0.02158570470783161, 0.028249290990061127, 0.02518188332032878, 0.03510573362291325, 0.09582141763530672, 0.028301591992203612, 0.11069852480432019, 0.033363972397637554, 0.04442750920134131, 0.02982543082907796, 0.028476057923398912, 0.0474103194574127, 0.021050295254099183, 0.05094450832984876, 0.029962438711663708, 0.012164472063886933, 0.03676442996948026, 0.05158049178135116, 0.09648225561250001, 0.05388812205637805, 0.06498350441688672, 0.04163711186265573, 0.0843029739917256, 0.02928285965026589, 0.014738146510353545, 0.02069792724796571, 0.018407709612802137, 0.0328223270480521, 0.05337965441867709, 0.007487171214961563, 0.010125605003850069, 0.022270373046922032, 0.03741766093298793, 0.029667013841390144, 0.01224885518240626, 0.039086999677238055, 0.019099428354820702, 0.09250878953025676, 0.061197983523015864, 0.01888669914478669, 0.019878466337104328, 0.05145405208168086, 0.03131497316644527, 0.03689901845064014, 0.058351320258225314, 0.0299956386879785, 0.047736341221025214, 0.08701104859937914, 0.027807826299977023, 0.030336416202771943, 0.024895972783269826, 0.13615223084343597, 0.03283383775851689, 0.034151027430198155, 0.04463620854949113, 0.04030735763080884, 0.04382249557238538, 0.007226611978694564, 0.02588065432064468, 0.0152593187885941, 0.06525977631099522, 0.04281321926100645, 0.023748612475174014, 0.015574482931697275, 0.1129675745323766, 0.01585858077305602, 0.023384076957881916, 0.027569626581680495, 0.05164791218703613, 0.024054418136074673, 0.05301774981489871, 0.07854349983972497, 0.03479183113086037, 0.029276211862452328, 0.003741375630852417, 0.06735237300745212, 0.026519504317548126, 0.09544184620608576, 0.02554852097091498, 0.06498474380350672, 0.034697730516199954, 0.04479849027120508, 0.01653586845350219, 0.034619203870533966, 0.0276165006289375, 0.034354951058048755, 0.09963938893633895, 0.024278036507894285, 0.02980486591695808, 0.03954831867304165, 0.010865711774386, 0.03774884062295314, 0.03986223971878644, 0.034697808441706, 0.02328348440642003, 0.029858050074835774, 0.01072551265679067, 0.035909123325836845, 0.004913473112537758, 0.02441353597532725, 0.033920089626917616, 0.040104187282850035, 0.041202198481187224, 0.01948261404322693, 0.02085422911477508, 0.0516915838670684, 0.0276289835528587, 0.06309936215984635, 0.0368120721395826, 0.04143231621128507, 0.03310776446596719, 0.09428192133782431, 0.01877198908914579, 0.04701112935435958, 0.04145826540479902, 0.0505817131488584, 0.05636165202304255, 0.04851455356401857, 0.0771133293164894, 0.020053101106896065, 0.06827078817877918, 0.03743577304703649, 0.04128194224904291, 0.03934084757929668, 0.025087480280490126, 0.05873397531104274, 0.028453901104512624, 0.026602333564369474, 0.04464748177269939, 0.07378403999609873, 0.04877620143815875, 0.0516570591571508, 0.036892376228934154, 0.04775765941303689, 0.04727628387627192, 0.08170947956386954, 0.02869419738999568, 0.012151632909080945, 0.015678060772188473, 0.05980253808957059, 0.03535580028255936, 0.038330999814206734, 0.05927396196057089, 0.07179408974479884, 0.039566007762914523, 0.06603817790164612, 0.02562121062510414, 0.032076657880679704, 0.03282173704064917, 0.013012798808631487, 0.017312314485025126, 0.034137049078708515, 0.044199859112268314, 0.04792810846993234, 0.0407468611956574, 0.07477639534045011, 0.018209738009318244, 0.03132711099169683, 0.04496639747230802, 0.01436239621398272, 0.034961007404490374, 0.019563432069844566, 0.02624995628139004, 0.07938516209833324, 0.06317121689789928, 0.053136074129724875, 0.06804274104069918, 0.07549697620561346, 0.02191215691709658, 0.029083451991027687, 0.010231011310679605, 0.037542775899055414, 0.020472273536142893, 0.005757796898251399, 0.09968765079975128, 0.09053261353983544, 0.040283805574290454, 0.014918373362888815, 0.04883608162344899, 0.07223433916806243, 0.01798204524675384, 0.03726064845977817, 0.14151644456433132, 0.05187877206481062, 0.02957613229227718, 0.03659337235148996, 0.014311555387394037, 0.04537598135357257, 0.055178401453304105, 0.03814522169705015, 0.06446155937737785, 0.04222134535666555, 0.019185198361810762, 0.043915226924582385, 0.04227148114296142, 0.04735302565677557, 0.03502907718939241, 0.021643043037329335, 0.03601693511882331, 0.10661858279490843, 0.06365319728502072, 0.05050068546552211, 0.025374016076966655, 0.003990912582594319, 0.017250261662411503, 0.06646790367085487, 0.05494963814271614, 0.021638807229464874, 0.043445031842566095, 0.03391557365830522, 0.008751538989599794, 0.07139063600334339, 0.027052759687649086, 0.024578302036388777, 0.05885723490791861, 0.03625045559601858, 0.04723903177364264, 0.02240687626908766, 0.0362771654909011, 0.031033294726512395, 0.04034455036162399, 0.012261187821422936, 0.013822643340972718, 0.10930912045296282, 0.02174302702769637, 0.046146297245286405, 0.053216426458675414, 0.09413349922397174, 0.05904703175474424, 0.07544963460532017, 0.050946593764820136, 0.0843521264323499, 0.028410648737917654, 0.020994385558879003, 0.03363264098879881, 0.052760736652999185, 0.03965191877796315, 0.03783124870096799, 0.04084337750100531, 0.04568088901578449, 0.10498910109163262, 0.01603745320608141, 0.07717977379797958, 0.03073914078413509, 0.05697259912267327, 0.030525908769050147, 0.028756090650858823, 0.07883303391281515, 0.04707247899204958, 0.04994616756448522, 0.01574236786836991, 0.11553558360901661, 0.04102050959772896, 0.006164985034047277, 0.006237786010387936, 0.05234729360381607, 0.04546880918496754, 0.04931069248414133, 0.034463122792658396, 0.0899058252980467, 0.029493590627680533, 0.09695318542071618, 0.03573805828636978, 0.03233789757359773, 0.06113225892477203, 0.025815888948272914, 0.01881001859146636, 0.03772498428588733, 0.045930313717690296, 0.02900694584241137, 0.018822347519744653, 0.03598025818064343, 0.0769148048129864, 0.04063727938046213, 0.05153524674824439, 0.053837425948586315, 0.02924292468378553, 0.09151247853878886, 0.16673812555382028, 0.10321539783035405, 0.10099062463268638, 0.12886900134617463, 0.20352692023152485, 0.11675361864035949, 0.11060686956625432, 0.07015101931756362, 0.17255696409847587, 0.21553136670263484, 0.11021551283192821, 0.15588065347401425, 0.11680132389301434, 0.08852627666783519, 0.19244669994805008, 0.11591934075113386, 0.16692094621248543, 0.05606888218608219, 0.1528398072696291, 0.17743750533554703, 0.08680924380314536, 0.08570641977712512, 0.10661953274393454, 0.13776184525340796, 0.1621422276366502, 0.12085568407201208, 0.0926043262006715, 0.14794308721320704, 0.13882090483093634, 0.06933077544090338, 0.21750105632236227, 0.1296262739924714, 0.19393049064092338, 0.13850948482286185, 0.08314759106724523, 0.09808156901272014, 0.10894434744841419, 0.15271364216459915, 0.275112243834883, 0.18380967434495687, 0.19504185678670183, 0.13059388613328338, 0.1960763958049938, 0.17868582741357386, 0.08019750952371396, 0.09165111172478646, 0.12124730797950178, 0.15419440489495173, 0.1522863283753395, 0.1337047020206228, 0.06314349026069976, 0.1441647094907239, 0.13401768053881824, 0.19230302015785128, 0.14695914782350883, 0.11672558772261254, 0.1086674744146876, 0.06556569700478576, 0.14888990437611938, 0.14327953511383384, 0.10440273021231405, 0.14190268790116534, 0.10435567804961465, 0.15771150210639462, 0.14619164838222787, 0.1576101395767182, 0.14847882877802476, 0.11333239948726259, 0.08657715196022764, 0.10222216675174423, 0.10727337226853706, 0.06195403904712293, 0.21551947749685496, 0.13749639387242496, 0.11756672305637039, 0.09862583785434254, 0.15242269058944657, 0.1635471428744495, 0.12827560974983498, 0.11667999759083614, 0.2330292496480979, 0.15554641984635964, 0.17716641363222152, 0.1815897028427571, 0.2251011977205053, 0.11425953489379026, 0.19770481623709202, 0.11494354272144847, 0.15927838365314528, 0.09800279745832086, 0.11583423867705278, 0.22551069996552542, 0.12823957105865702, 0.16059643792686984, 0.15453233441803604, 0.12360639506368898, 0.21514056657906622, 0.2020276928669773, 0.11381491422071122, 0.2108324586879462, 0.13198443339206278, 0.10324187023798004, 0.08331521254149266, 0.14696349680889398, 0.15890383656369522, 0.14569023856893182, 0.1770750997820869, 0.159537170547992, 0.14734237804077566, 0.09208673014654778, 0.054990003554848954, 0.17097402247600257, 0.1640167145524174, 0.1280893455259502, 0.06466505627031438, 0.17594433389604092, 0.22215976961888373, 0.09179306973237544, 0.1909822941524908, 0.11425656630308367, 0.0916445956681855, 0.1871820230735466, 0.057215474371332675, 0.10242430551443249, 0.08506859579938464, 0.30653729976620525, 0.13938069198047742, 0.132551270944532, 0.21355199947720394, 0.11265748296864331, 0.13048427092144266, 0.07457410072674975, 0.10342210822273046, 0.1391794512164779, 0.18481550709111616, 0.09559380094287917, 0.11889938279637136, 0.10136669312487356, 0.3465295006753877, 0.13599072466604412, 0.21317783830454573, 0.140159739239607, 0.16376993560697883, 0.11396813060855493, 0.1628224505111575, 0.16741483064834028, 0.11757262313039973, 0.1410117989871651, 0.154826388170477, 0.27326943178195506, 0.25340908498037606, 0.2216155081987381, 0.08796733556664549, 0.19353418378159404, 0.15973508649040014, 0.14159349433612078, 0.13870542665245011, 0.1512554704095237, 0.18706393253523856, 0.26647512917406857, 0.25387399597093463, 0.18815319752320647, 0.11468356096884236, 0.14149805414490402, 0.17082872480386868, 0.16350359364878386, 0.13073634880129248, 0.1387657632585615, 0.10529236489674076, 0.06786213940358721, 0.1469404753879644, 0.17998105322476476, 0.15412189706694335, 0.13902407517889515, 0.10673206459614448, 0.14448466419707984], [0.022512311334139667, 0.0853911777085159, 0.05521965002117213, 0.014014448624948272, 0.02368847439356614, 0.021814939282194246, 0.017490270365669858, 0.01142261939094169, 0.07156749721616507, 0.010169430679525249, 0.0381643319997238, 0.009776309489097912, 0.03750244759430643, 0.003420974940127053, 0.03376398628461175, 0.05442793801194057, 0.06351488322252408, 0.055154968140413985, 0.024175141443265602, 0.019961835496360436, 0.06897984349052422, 0.023080898499756586, 0.026813695367309265, 0.03062400584894931, 0.019220719404984266, 0.05626652724458836, 0.010379812847531866, 0.030176665204635356, 0.049130246698041447, 0.010224902507616207, 0.045480739208869636, 0.03439752064878121, 0.013859347182005877, 0.032676231567165814, 0.09215995043632574, 0.04764445962791797, 0.03305575104604941, 0.036250388802727684, 0.04009843563835602, 0.12064481765264645, 0.04824291267141234, 0.006189232390170218, 0.04718332245829515, 0.010338452957512345, 0.00719941041097627, 0.014633820956078125, 0.017077348675229587, 0.055613964213989675, 0.00639964238871471, 0.016359845867555123, 0.037095301668159664, 0.03404359413252678, 0.019607821777753998, 0.05927389516727999, 0.007449095328411204, 0.02529761753976345, 0.021706079205614515, 0.050695733007160015, 0.03160858905175701, 0.011171112037118291, 0.07412429244141094, 0.00963398597377818, 0.03358135487360414, 0.04268666452844627, 0.014753752020624233, 0.026028044849226717, 0.0451157472707564, 0.021218208021309692, 0.05412763908680063, 0.040680991878616624, 0.011480145112727769, 0.02522728049370926, 0.018134205929527525, 0.05950547863903921, 0.07724947630777024, 0.037301110351108946, 0.058040419753524475, 0.02744901088590268, 0.06083618653065059, 0.03520311824104283, 0.00770345624005131, 0.023765761652612127, 0.026074711095134262, 0.0212458493115264, 0.10572664745268412, 0.06689687244943343, 0.041476640981272794, 0.008390958191739628, 0.016059793706517667, 0.04414362658280879, 0.10013138089561835, 0.02219263307779329, 0.02386203490459593, 0.06917961480212398, 0.019099077690043487, 0.03612785651057493, 0.024961795716080815, 0.016801191814010963, 0.02802232553221984, 0.04090951399120968, 0.12011279424768873, 0.04774494642333593, 0.013961158711026656, 0.014387061492016073, 0.06776157097192481, 0.08797325048362836, 0.02796562730509322, 0.04260294284904376, 0.11395042296499014, 0.027921059481741395, 0.06755093461833894, 0.038724241603631526, 0.014450055914494442, 0.0277334018755937, 0.02636064018588513, 0.14746275439392775, 0.039992738966248, 0.012998327856621472, 0.03629606057074852, 0.0400546192395268, 0.030854867582092993, 0.031224516496877186, 0.013250979973236099, 0.008525667271896964, 0.03510460926918313, 0.04078152691363357, 0.062382306496147066, 0.0145853132562479, 0.012551543823065003, 0.06126379346824251, 0.03429970929573756, 0.03916993096936494, 0.07501688087359071, 0.06015374463459011, 0.09095991990761831, 0.01745578647387447, 0.026803732034750283, 0.01238477396327653, 0.05957252797088586, 0.024152409459929913, 0.014966549879318336, 0.07671082552406006, 0.025797973503358662, 0.005612515460597933, 0.04223924595862627, 0.05727839365135878, 0.04912567135761492, 0.10634120510076173, 0.012509156058513327, 0.029806958773406222, 0.009206423565046862, 0.011299764264549594, 0.029802093995385803, 0.056326618941966444, 0.025289982695539948, 0.06265566174988635, 0.08839856047416106, 0.01918387548357714, 0.03513205760100391, 0.046601378489867784, 0.03776149795157835, 0.049895894480869174, 0.06277911059441976, 0.05391161103034392, 0.09118154746829532, 0.04619641447789036, 0.0717969544348307, 0.04677549746702425, 0.056032439024420455, 0.0641363651084248, 0.029079307096253615, 0.02940096874226583, 0.03924256867321674, 0.05442944457172416, 0.01765025514032459, 0.02755146622803295, 0.027883004004252143, 0.06460635238909163, 0.005977920218356303, 0.010522851607674966, 0.07085447883582674, 0.06552769162226468, 0.04372309231257532, 0.024132939215633087, 0.0646407509339042, 0.044977136349189095, 0.0031736899427414755, 0.06159003416541964, 0.044582588379853405, 0.04788974314578809, 0.021750088562839665, 0.014838936658634339, 0.0334279232629342, 0.11050785964471288, 0.04268132848665118, 0.022569573593500536, 0.033172112380270846, 0.023640158724447247, 0.03433519508689642, 0.06426002175430767, 0.014500515462714247, 0.02603742559585953, 0.03852845933579374, 0.0562159906985471, 0.04245245014317334, 0.014303945590654621, 0.022399940899049398, 0.016576026064285543, 0.022041672818886582, 0.01975948893232271, 0.04975058567652013, 0.021274763385008555, 0.020221769009367563, 0.03877510840538889, 0.0048576023800706025, 0.05122324786498211, 0.05148219803231768, 0.029419490892905742, 0.03168460352753755, 0.029605615964101162, 0.014825116013525985, 0.048909198012552224, 0.06425550949643366, 0.0459424849395873, 0.035626257449621335, 0.02207970232120715, 0.03428661038924474, 0.08843875519232824, 0.009704938074719394, 0.02739247964200331, 0.036304817913332954, 0.05315208596584853, 0.04125990788452327, 0.05521674822375644, 0.03152732388116419, 0.03014567311765859, 0.042724365630419925, 0.024795029567030724, 0.011619056604104117, 0.047127498110057786, 0.043285748397465795, 0.028278761674300767, 0.040801590876071714, 0.06347713017021306, 0.030100407675490715, 0.04368344678368885, 0.02235397041658871, 0.0196449588474934, 0.061602160858456045, 0.059670023911166936, 0.05564908635278698, 0.015624987936462276, 0.042260905538569205, 0.060914408895769157, 0.03862201076117344, 0.01932104663865175, 0.007569286608486436, 0.03873384128382895, 0.08872500155121088, 0.022001901124895085, 0.04082411505805794, 0.05288604828820098, 0.009284527186537161, 0.06047774033504538, 0.018687475167098455, 0.030250223171606194, 0.028861438513558824, 0.06637399230385199, 0.01734360157570336, 0.058091234604944475, 0.03423456728341989, 0.06734904076438397, 0.0666390651895199, 0.0131728318228852, 0.06054675635823514, 0.044144179482827894, 0.035844252197421156, 0.0485834434221033, 0.03801169448706787, 0.049660047370707616, 0.02660250240296591, 0.01102301646824344, 0.08646125075756572, 0.006241331620913115, 0.05032109314925037, 0.01791441703971941, 0.020973698192392476, 0.009766670846147463, 0.0342961581191048, 0.033423500062781386, 0.05666087854478974, 0.02651197894010693, 0.03298280906165019, 0.045424792406265624, 0.04993704285880085, 0.06410155838239007, 0.01037071133396239, 0.04984918370610103, 0.0398167238017777, 0.057912569973268546, 0.01955790678039193, 0.08937610255088657, 0.02103930961311562, 0.015398280374938622, 0.05374088737880811, 0.036315215402282774, 0.03618386639573146, 0.04376300501462538, 0.023684025218244642, 0.03225053194910288, 0.02500900001905393, 0.020842130252276547, 0.032283969412674196, 0.08578879074775614, 0.05026547660236247, 0.02395829516899539, 0.12121429725084454, 0.023302424015128054, 0.0561956521414686, 0.025674519092717674, 0.01585181053087581, 0.06783678763895296, 0.12967917427886277, 0.038836060994071886, 0.007705745765633765, 0.042125471009057947, 0.02202894498623209, 0.03982768903370015, 0.004244684414516087, 0.015040276684885612, 0.02672033318958711, 0.0652692090079654, 0.007624641084476025, 0.03745502435776871, 0.045285491287359037, 0.06581953377462924, 0.042188586958218366, 0.034880220919148996, 0.042742763471324, 0.05822268380143214, 0.02754667009867262, 0.09193171033984981, 0.03473977318208199, 0.04901437889202498, 0.08319542990648188, 0.014237431532819755, 0.07295480871107429, 0.04314251389587298, 0.027544467775442172, 0.037815990144736134, 0.0626822529011406, 0.08814362532575615, 0.08976082448498346, 0.14404235902475193, 0.19242816109908745, 0.07556928365374915, 0.18931923026684672, 0.19393049064092338, 0.11000618265825324, 0.1488823493127711, 0.2727737068198621, 0.1317500334698707, 0.13383086712565273, 0.11672267108224332, 0.10456712334416807, 0.13725489901844412, 0.15144356031669304, 0.13775427534710616, 0.18071880738716573, 0.1986219920217991, 0.11717727364157327, 0.07078116948832758, 0.16043686133343726, 0.09109725433518179, 0.14556864509359002, 0.13273198390379548, 0.1142841370892711, 0.1266301199211739, 0.08404573818552308, 0.09605314582586288, 0.1973443996394053, 0.07390725877485238, 0.09365830206661485, 0.24632432061480358, 0.1398735522525385, 0.1601136411773041, 0.2461882701027207, 0.10852540508494712, 0.13586301589384675, 0.09346257545985281, 0.13887711509596556, 0.2028256352059543, 0.11802052409620956, 0.10158203469472937, 0.16338906541932374, 0.11959563606069423, 0.10019918350735679, 0.1533109968295321, 0.17447859223466367, 0.11184008893906139, 0.09943618148099631, 0.09992409162805416, 0.1228681362408679, 0.14895261585479602, 0.08940681262174621, 0.17509767698356882, 0.078505427663913, 0.11956675909459591, 0.09695752698462456, 0.11254707365878858, 0.1509946648729965, 0.117179856315488, 0.1298091243370436, 0.08480654345476069, 0.12076053331838921, 0.13058444601483643, 0.06834307336248457, 0.09926071550580673, 0.11664213321637362, 0.12007828438072465, 0.14911346894223243, 0.19251450255978853, 0.14893915329594165, 0.104504107584944, 0.17581257299752906, 0.1856100800796412, 0.09509553041425534, 0.13167227123631164, 0.11838609862024896, 0.11569259237148799, 0.10436056880280375, 0.09018963741254993, 0.09228344380971976, 0.0808653979038354, 0.09633777430281043, 0.11071118584368378, 0.19882612716173753, 0.129583734087646, 0.07050934305880219, 0.17404166021151468, 0.06740209690178744, 0.13008382287807763, 0.15366571373306215, 0.12206726241856813, 0.13070786517346278, 0.12047189724398777, 0.13755641877651215, 0.17188217374496162, 0.1756829346413724, 0.12758713419316337, 0.15171288570854813, 0.07195685015176423, 0.18217939854366705, 0.0973156800318975, 0.12012429011519998, 0.15942764439387247, 0.08576998472562991, 0.19812359532807022, 0.13161309238057584, 0.08251720340922475, 0.1858104599523358, 0.1296864473260939, 0.1447075608302839, 0.11299088539090008, 0.11848611786263064, 0.13243126566521823, 0.16357510699890554, 0.28915148111991584, 0.10512359309359454, 0.10321320849470794, 0.12613834318472072, 0.11287039771559648, 0.19490261503960937, 0.08371648436877877, 0.11521199237904511, 0.10227738996036351, 0.0810735480627045, 0.2510174398776144, 0.1355454805889167, 0.1392243808368221, 0.09569528221618384, 0.16492559312609956, 0.09806375004700385, 0.12155659060226753, 0.19004646077519283, 0.14618976332712919, 0.15263779467204586, 0.08455059898551553, 0.10155880547245033, 0.10664728164556436, 0.20197574252961203, 0.1008337717212271, 0.20731343189254403, 0.1163827748678159, 0.11451970218331553, 0.13755564694292843, 0.09981446899473667, 0.2522770129144192, 0.1742766093229875, 0.22386808966984972, 0.07576990101370029, 0.16622553899651393, 0.09716892775031738, 0.07768672003294341, 0.18174349068431184, 0.1340831973357126, 0.11721061091520824, 0.11771469988161698, 0.17027382098603994, 0.12344890390522778, 0.1268579444149509, 0.1497162858140655, 0.14441178529523313, 0.08963952786871232, 0.12491641187807545, 0.19551868666894734, 0.1855895374319516, 0.1482651793048717, 0.20092483173357323, 0.16884938726434484, 0.18631794053362682, 0.1356329204281792, 0.1357420755084604, 0.19305683439597487, 0.16341878101229668, 0.23073353455401957, 0.12803953257389367, 0.16417029459262267], [0.024734538965276442, 0.019117215779260732, 0.02960787580377655, 0.01642444054596126, 0.10688646842027083, 0.035133820201735944, 0.06048968520190101, 0.06004517956171185, 0.0377633681637235, 0.035132706980220973, 0.06421812751796097, 0.04484219905862119, 0.03586804545193445, 0.01593643206433626, 0.04612020333297551, 0.06860163019155152, 0.05149487762537319, 0.04124788138142321, 0.05526131048100069, 0.05159676707990002, 0.048771340370876715, 0.02407750263955677, 0.030727683879376855, 0.04388025692605879, 0.04924405504425522, 0.010448840930621373, 0.015244294008880388, 0.006074273251215345, 0.018353792584093753, 0.03922002222680021, 0.037510793044930324, 0.015250116157403681, 0.009333454199804692, 0.024106234886858147, 0.035824203077936545, 0.0042321022283431375, 0.10954113065963611, 0.025222213480446953, 0.01074671952665085, 0.006756557904736837, 0.05606152750260662, 0.02497011148079764, 0.01819420856918441, 0.0021843356580575346, 0.02478304388205288, 0.08520556657458656, 0.07068708742735907, 0.03720629356394056, 0.025307035393780097, 0.029132804811524693, 0.04151854634983465, 0.016983945679385215, 0.01809015575418016, 0.035688501375261694, 0.0515019577142084, 0.07912037865025923, 0.04824105359148234, 0.039321369913523085, 0.08026871859328821, 0.005903101064177463, 0.006055281228327658, 0.06436850890167989, 0.05064747485448606, 0.022891155458637513, 0.01610592003999045, 0.03945700853364542, 0.02091703707264969, 0.042223850105074234, 0.03377956025360618, 0.04213689266180154, 0.014815405011177063, 0.027190964283363428, 0.041281990488641895, 0.10486060564289801, 0.011519728486746317, 0.031554397428408265, 0.00993343977825134, 0.016345162475772668, 0.11885394109413028, 0.02820014597091358, 0.04283127200324088, 0.012932147765241098, 0.08140328427543864, 0.06484801051556133, 0.03915822730050422, 0.056087224365910515, 0.001336928132786852, 0.05891499255085364, 0.04826075390155893, 0.12373195902910084, 0.03498473386571277, 0.050451529314159416, 0.028320889687165618, 0.054548681728192605, 0.050890431739389896, 0.04597132850904018, 0.05991816840833053, 0.02522321909054881, 0.0259514719073195, 0.0174924077509786, 0.02516313110390911, 0.02044036860752385, 0.040816890250425786, 0.04843125490879174, 0.017749159305822104, 0.026739376698969863, 0.034153402302763425, 0.04560514171316754, 0.03177783582941629, 0.0016541736522412975, 0.053945219187880866, 0.02913646174420137, 0.031919957109494135, 0.05121005619002972, 0.028253810669411905, 0.04912515556497965, 0.05599248550424818, 0.0137513823210611, 0.07399676920613274, 0.03476303580100648, 0.03803268242336344, 0.019842809851979837, 0.08447354179224931, 0.028022268015774898, 0.018085166666423902, 0.03545245388522744, 0.08098581136437133, 0.044514960172818974, 0.051126750113326125, 0.023527279918198474, 0.023512474072049372, 0.06649148170254193, 0.027659617553581484, 0.03296792900073342, 0.024772408905846532, 0.01600836287252605, 0.048616762142046355, 0.03879675314237829, 0.030227814022509847, 0.033310957078356296, 0.03758084807486739, 0.019553403799363878, 0.031555659079458565, 0.03511528506351169, 0.008954112836363493, 0.022248798813961912, 0.004304117919673445, 0.02910315786721185, 0.017359836056130007, 0.03670695434266236, 0.0542273058090359, 0.04743455800053198, 0.05765776841144543, 0.04782308344147168, 0.02963626666314667, 0.054499818725162186, 0.05140377899806481, 0.033455022785346955, 0.01062997134795296, 0.04633468030078802, 0.040067258014460094, 0.025450321845710278, 0.01391408521158155, 0.028376580448821187, 0.021881042375753168, 0.07162286143284291, 0.026009357570728753, 0.06378838690579869, 0.038572179255425, 0.025180063203151803, 0.022815346928837243, 0.027143474253534805, 0.02801318041747436, 0.03822692473477218, 0.01551574379845988, 0.05826967288157903, 0.03262452984927222, 0.030460436501016375, 0.03386976088222582, 0.045422692128340714, 0.033101155640906654, 0.023128151042328682, 0.02402500125754159, 0.04381530416139867, 0.03963107184972614, 0.04969592278939672, 0.039379424415528774, 0.035986046932521276, 0.03811864909948781, 0.05803191103041172, 0.05153109443199355, 0.05566558800637722, 0.02473767082847189, 0.048075851518660784, 0.06148166947241407, 0.03529732275637798, 0.0133972053299658, 0.07579977245768532, 0.027373276570870075, 0.01737775335641345, 0.01877769249404082, 0.016955471328401472, 0.037543603393714875, 0.028694568463834003, 0.03316985254059546, 0.07903409656137228, 0.03652831568615511, 0.020899527953588404, 0.07218699756776914, 0.08389030277612619, 0.012133743439335376, 0.01074754052751814, 0.02299993018823443, 0.04717398252978455, 0.015196252006717259, 0.01219475818288629, 0.06747679406544194, 0.011262450007052394, 0.04213533415168058, 0.015879162383498624, 0.03091255286562955, 0.0461037387867691, 0.02727540584601229, 0.03492832322081085, 0.022770042523916345, 0.012408957773004659, 0.03951432459871285, 0.04919011946185492, 0.031154799144132994, 0.023710282403044403, 0.0539582475903444, 0.06317611507256515, 0.01870487853011582, 0.03512026487442199, 0.06867897682241164, 0.03740478467079811, 0.01669602392212255, 0.049388621700927615, 0.017812746518757194, 0.06570789992110804, 0.01022495260258438, 0.03997103114670608, 0.0174958828574745, 0.012694883153017145, 0.0031323486064138706, 0.04211260958982166, 0.017401320255885366, 0.01782676383299986, 0.07472340599633753, 0.04792489868123084, 0.04248462224495597, 0.027441817619546782, 0.012741439004457789, 0.06900052714627236, 0.11400085189961828, 0.023742808880342636, 0.0184233206891804, 0.03920876755728386, 0.05177937993721571, 0.06586754330783151, 0.021790136706840713, 0.0498942060949048, 0.049101017211796716, 0.025851272694126237, 0.004884930112893926, 0.12433841984602623, 0.015505491028307006, 0.041464647874818183, 0.04502578784013167, 0.07071905172779225, 0.029710082526435144, 0.007608757268826594, 0.08698919235030189, 0.05891655477171298, 0.0411677888041595, 0.058594228903530166, 0.01989072661672253, 0.047029976194608025, 0.017321975392405875, 0.02593656216049567, 0.027149648922204506, 0.008183745921996888, 0.020121933448535856, 0.06936110701644793, 0.029836078792868648, 0.025560933390806895, 0.040826367476256564, 0.03346966164826881, 0.05209947194089182, 0.05392206789110787, 0.03417877262108959, 0.03813006704149302, 0.0534817256993847, 0.032632875299896114, 0.0451739984418964, 0.020370167003420647, 0.03249101006076671, 0.06899568092194386, 0.029227295053715352, 0.01159354898845777, 0.04000268003437668, 0.035355993240955286, 0.03256933261582162, 0.03524704596202355, 0.01604710669198539, 0.009723557632241864, 0.0391572142689256, 0.05006320425309241, 0.03146063449094072, 0.023980490950634703, 0.010680388222681358, 0.013882221101084724, 0.009010364847199526, 0.05580977245699614, 0.04804197989869863, 0.018588771381473634, 0.013170280690246727, 0.014823289402556838, 0.04124239319935441, 0.026469678377907258, 0.022198098995431792, 0.011936482442251872, 0.005050778318036464, 0.006292163634498138, 0.012024536408716813, 0.0377688563457923, 0.038956418793532066, 0.04348547889094334, 0.009872333193925442, 0.11487103489344008, 0.017541710476507433, 0.06585777664440684, 0.022985697651165538, 0.04330775678681675, 0.010470837260072585, 0.10318542248569429, 0.11180071800481528, 0.0055916040582815185, 0.04918180740787648, 0.04574317004880868, 0.019204362470190972, 0.040239061490865424, 0.046412613228312694, 0.03804684260103386, 0.03887417398800608, 0.025605595837987494, 0.04278395637811627, 0.05439933192974422, 0.039351308150799014, 0.026443543647474144, 0.020362830873636995, 0.06978046498261392, 0.25496655609458685, 0.12553690670756623, 0.1566911826375872, 0.13367664883844554, 0.18417009094264358, 0.10427344066556543, 0.2195123804267496, 0.16470416594529524, 0.13253734825411811, 0.13146536046406254, 0.12409344431944191, 0.17819280386902392, 0.09993840765673667, 0.1504496909910813, 0.16968608455499634, 0.09049270825926214, 0.11862479557748884, 0.18749789596768096, 0.20215353142702952, 0.10324217451852746, 0.19324596330989152, 0.13790355093078688, 0.11684133307426237, 0.14810125372605398, 0.11607228254433721, 0.06326512826490216, 0.13706526544410735, 0.1402971998322755, 0.15398817689856514, 0.09337278301245533, 0.06280815825448371, 0.06659429884166457, 0.12976420955965295, 0.16118214087327942, 0.12342896981863305, 0.08374913886655122, 0.15760338603286073, 0.1107834636059124, 0.1126008496794384, 0.06244978998438455, 0.2215947725926526, 0.1657347270520404, 0.09070223881280981, 0.1213843232835643, 0.10199195996392518, 0.25777653499972075, 0.12914916209410876, 0.18692032695980743, 0.17919500009156764, 0.08795238129096106, 0.18470425915438682, 0.10910963857895695, 0.0877611298346892, 0.11150252306833863, 0.18225273757707328, 0.2201836826861836, 0.1568065123865381, 0.10105250490596518, 0.12784278922481462, 0.07494732679333538, 0.1336746895685792, 0.13652278517838567, 0.12432288669515401, 0.12317731496295892, 0.08742486272240058, 0.22566341911442578, 0.12523250741651282, 0.09235546182026155, 0.24993966333568096, 0.1455029204953462, 0.15281924977898598, 0.10264341719448566, 0.16494137118570507, 0.20078873669262975, 0.13983887911308557, 0.09479559143073857, 0.1012341381283477, 0.20512522431090474, 0.1600339196738787, 0.06646647132583894, 0.1393578338320367, 0.08122055267449468, 0.1896500648581423, 0.21456835587741807, 0.10752225149190053, 0.1663349464070052, 0.13904584979172796, 0.09359617688460276, 0.14909084828104824, 0.2066015193122439, 0.09188745607389137, 0.20268568099709228, 0.12827382859541103, 0.20950765087036416, 0.08867000840837136, 0.1384666925878264, 0.1549482042901218, 0.1643199412501417, 0.08018057371373288, 0.19957572600105777, 0.14117631828412414, 0.1317911929800175, 0.2728000975912437, 0.10177481497521512, 0.09243296430213377, 0.16534959693672135, 0.1192945838556625, 0.11725853881216608, 0.17389472981449217, 0.1271436712704599, 0.18287566665094346, 0.10886319359997287, 0.1008543960051611, 0.20946898497641087, 0.13223354268120602, 0.16693767422111705, 0.1259817648679018, 0.10807062441017479, 0.204374274762813, 0.1455346547299996, 0.08999387369840406, 0.20630534301744774, 0.2249679822125472, 0.1239527999132406, 0.12253624037839472, 0.10585863841697574, 0.15076284762471914, 0.09993726474931464, 0.12816232832847163, 0.10160055870073847, 0.1338179685990326, 0.20549096952890977, 0.15583692613290623, 0.082398563681636, 0.11033054572180845, 0.12381240783724934, 0.1469624726451002, 0.13468252611346543, 0.18540552933700383, 0.12488015054259449, 0.08853377235936932, 0.06567521573742852, 0.15203304821625352, 0.1024885755032301, 0.21731761225964874, 0.13019741600146517, 0.081126953009516, 0.05250830254226457, 0.0878493044001516, 0.12711134331766516, 0.14043460105312988, 0.12697217578534037, 0.14942471083486453, 0.1487608003662899, 0.09955196394002996, 0.2294678462203592, 0.16978351370198652, 0.1309071169816889, 0.1698631461476907, 0.23456656403141096, 0.25621481880079955, 0.10875888474402018, 0.1309863486676477, 0.0945041723025497, 0.10487838750123046, 0.18140630330890417, 0.12133471071138047, 0.1802987963310443, 0.1895972536294721, 0.13297953468281776, 0.12682398373726755, 0.09806209505768493, 0.10275249063852243, 0.17510701320134103, 0.10812071195687167, 0.12919585802592337], [0.01031280989991501, 0.04111114809347782, 0.03497183533909265, 0.07039197982521728, 0.017573602417542133, 0.035818202813970856, 0.0515554071898805, 0.04797111592779402, 0.053634237046935596, 0.03980373621743638, 0.08844985772157088, 0.010591477075649891, 0.00446234009359614, 0.030115970512269996, 0.01627702404221054, 0.013706659574381774, 0.03678381115605589, 0.03339461938594468, 0.03670903235615697, 0.036340622827992775, 0.034738515241770074, 0.04273978374840226, 0.03168242532410659, 0.024496751138940454, 0.025764471101865638, 0.00677757599078177, 0.05495694087585434, 0.011353175705153262, 0.03604567849833984, 0.024370749306399375, 0.04471122483664658, 0.010353643792768707, 0.053215992302284576, 0.038106270076241344, 0.02159760504582664, 0.048595577536616474, 0.05795859055069741, 0.033197887169080786, 0.03415271952690091, 0.04523577481450047, 0.027796124486485496, 0.04817193366761785, 0.011612959860940464, 0.01940160491358256, 0.07696337095694616, 0.01936046581249684, 0.04444495338248089, 0.020336165507615078, 0.0777331339486409, 0.05623736455163453, 0.04740498341561761, 0.085764166287845, 0.06315644815913402, 0.02831293943017954, 0.01192150404676795, 0.016428975068265572, 0.019508600344124716, 0.023662168969167396, 0.03338084141432773, 0.017828995842137374, 0.0636094031506218, 0.030060428180149756, 0.03445054710027762, 0.027091718729934655, 0.029953820521768648, 0.09305263534770347, 0.04946459906932432, 0.05171901735593565, 0.08400158782023937, 0.10339850050513633, 0.03120394416328054, 0.02265422295749886, 0.07536353063187562, 0.03461080646957271, 0.008333159730682382, 0.06441165736760013, 0.04405689178383909, 0.040968759640236385, 0.031165538021014072, 0.02828234439220978, 0.08522504795109853, 0.01250249806616921, 0.02907910671638092, 0.037815637624589726, 0.08263002469902858, 0.028562978259287775, 0.022297459581750445, 0.03624562421464361, 0.11267123496509157, 0.07201944288681261, 0.04535249980108347, 0.015226916621031705, 0.04500403920246754, 0.10859130037715659, 0.07023201731499285, 0.011302475886623142, 0.06880201006424613, 0.013341383764782222, 0.022210635725059547, 0.013013772877457086, 0.022617839167651255, 0.06328997536911629, 0.0322788782796124, 0.02497361998393899, 0.0022760333376936615, 0.05863042715645861, 0.01587448870850494, 0.04085053180460818, 0.07498420411138795, 0.012501744786277413, 0.031207328356686048, 0.03126404328213539, 0.04010600554465782, 0.06844064351753332, 0.06071075244108215, 0.052566843150998466, 0.023268368713615928, 0.05364059725252446, 0.041211482748622075, 0.0395383924478665, 0.011998564023087965, 0.04767598235048354, 0.017303284403169528, 0.042276698441128246, 0.041649832273833454, 0.06425467829103582, 0.020888317812932655, 0.02889138602768071, 0.05922317308431957, 0.04466255850275047, 0.03935881126380991, 0.03152642217173707, 0.037420733424369246, 0.01629908809263725, 0.035102230685879476, 0.04148214400629513, 0.04299307875044178, 0.02851628974894993, 0.032756928994785994, 0.043798242186312564, 0.022604994446737692, 0.031499118558713235, 0.039203179185278714, 0.07587195374071598, 0.021241645044938195, 0.03208791255019605, 0.054736300371587276, 0.028859612830274273, 0.013678880059160292, 0.02173432905692607, 0.0395463148743147, 0.023619892526767217, 0.01812347076338483, 0.02604979348689085, 0.045580383666674607, 0.017009911571221892, 0.09302632621256635, 0.015413867331517395, 0.02560051769251004, 0.06977780067245476, 0.03358701003890019, 0.03677178094221745, 0.05900342686800286, 0.017726607293298002, 0.08949079405283555, 0.033529189313412644, 0.0016571072228543926, 0.035558814779506065, 0.061899405845906585, 0.028012564434902743, 0.03381891634489875, 0.03812602975813206, 0.02696223251405172, 0.036243011854821816, 0.036266456299927086, 0.042549990612315014, 0.02242325175757287, 0.08491212138324045, 0.0038006029581083567, 0.028186998824821785, 0.06381180908647366, 0.014706730471516494, 0.044579419409274124, 0.009173629914585035, 0.03983796406828333, 0.02271356508572353, 0.06100180420617107, 0.04850341021665372, 0.013687460213986924, 0.02696530686080223, 0.032400790878455155, 0.008758628355280962, 0.07533802301622927, 0.016999675499391742, 0.037596140027744696, 0.07332544468226843, 0.00360408619599184, 0.006714265691698529, 0.01767150839441456, 0.01909391605295241, 0.046062204492045566, 0.03477023092273157, 0.028050818436895497, 0.012008194316877052, 0.038132723930175416, 0.022790284601796884, 0.08566821401473135, 0.01626843739359174, 0.03953552033635788, 0.01881076630525058, 0.0564311133348383, 0.04718901102023665, 0.04361364037322346, 0.047107575155678205, 0.034861296153394505, 0.048136421901290305, 0.07656896399566904, 0.055574867874383926, 0.03466226327873301, 0.022147597701405175, 0.025898976091411896, 0.010854246520466404, 0.121390497952234, 0.04164290432527196, 0.14258314826292917, 0.04942962907080073, 0.03657596527773421, 0.03713456499099266, 0.04487130237976089, 0.08665912217111327, 0.03189277966157533, 0.04092326598765794, 0.03939497983083129, 0.020968139506294392, 0.06146426239865832, 0.029480521407094784, 0.04547462762275245, 0.018407177121844143, 0.03711080513312481, 0.01770062284776941, 0.028032053232891485, 0.07928215942229144, 0.03965788935602177, 0.03126798037556, 0.07818505735485815, 0.0086258284500218, 0.0213347530370811, 0.029037511194474064, 0.038113695263746195, 0.04374084448500071, 0.057848511496558785, 0.06772752865799703, 0.04146341962041333, 0.03138055304589216, 0.066691275278572, 0.041608531755628064, 0.08350238960701972, 0.055969965033000335, 0.11091365857282653, 0.08820533490506932, 0.11033585949917324, 0.02457672126183752, 0.017567155009601265, 0.02477659461874282, 0.08744680060772225, 0.07012249858235009, 0.0176684006510186, 0.0311526951554697, 0.0787741741805803, 0.07510987939895131, 0.025506064557703212, 0.0647773506352678, 0.010184256007050863, 0.03367171506397426, 0.014005323919263901, 0.10707215376896784, 0.019358027857379057, 0.02866421276848996, 0.05205394118092954, 0.09474484337260947, 0.0329816772864433, 0.022216776997083798, 0.07851074144127779, 0.01658684286667267, 0.13399032497545704, 0.07670266189961694, 0.06560071153216995, 0.01626027747988701, 0.05063065036665648, 0.06426267864299007, 0.11761980145820417, 0.04488652011787053, 0.024991429672809318, 0.029486536514014006, 0.0320798454049509, 0.03500007776892744, 0.016922699942369945, 0.032159110487555154, 0.11932866327697411, 0.024641978307045065, 0.03624992496042978, 0.04759051291330252, 0.022463687673734967, 0.015527531886618817, 0.021601905791612808, 0.004879368179899757, 0.011390399049560074, 0.04307441442506388, 0.03234493313357234, 0.043083409254904836, 0.003093034724770405, 0.018493418392608874, 0.04224679360049777, 0.018978829357365612, 0.08190997818019241, 0.053633420684491284, 0.015032700284791645, 0.02371693575696554, 0.021822256858285982, 0.03428741190873552, 0.034997754846699536, 0.007748892840027111, 0.03349024511408061, 0.02810167039569933, 0.022891298322065268, 0.016563500466872938, 0.00483727031678427, 0.029714216288994066, 0.01490921618824359, 0.051045466389041394, 0.01689053897280246, 0.031153767558862455, 0.0163864314527018, 0.0588476983102737, 0.0041063944718189305, 0.03861264485749416, 0.01613359843759099, 0.023156924107752275, 0.05305494625645224, 0.056586982900626026, 0.013745064788963646, 0.029139046273485292, 0.06176930735819042, 0.022047721322451252, 0.061913751560496166, 0.05433806392829865, 0.033102291126851924, 0.029381693311734125, 0.10887355398153886, 0.031888122684904374, 0.06091808252676856, 0.007356472979154205, 0.1181007651030086, 0.2202762581873685, 0.11349741602316499, 0.1300845798687078, 0.15139713155804202, 0.1011556782759726, 0.1408901164541021, 0.13354024209547788, 0.09096074369153939, 0.10596325897495262, 0.21872046432690695, 0.16767134657129645, 0.09526609821477905, 0.10749675129773095, 0.1798375218641013, 0.06520397422718816, 0.20811873633647338, 0.09723628507344984, 0.1358440169133246, 0.11483005349873565, 0.14214634982636198, 0.08073331788182259, 0.08944656205130741, 0.20358298206701875, 0.17099685093853623, 0.13318122073542327, 0.1871853627380915, 0.08438582735834643, 0.1466131437337026, 0.18949997291201726, 0.1160961425921414, 0.08956394012784585, 0.1715942204464227, 0.09492960103671066, 0.13308125344337896, 0.11099593306425959, 0.14555368339642882, 0.16115739766974002, 0.1046351486002095, 0.1422054841532372, 0.23394317482598126, 0.13475766114424914, 0.12904195144074038, 0.10560814873315394, 0.1386540848761797, 0.09252236341126263, 0.15857957740081474, 0.13847867085132748, 0.28799827268812805, 0.13845971639966592, 0.21767054800875485, 0.18006467842496932, 0.16273594577796757, 0.12891684018541127, 0.11998407615465112, 0.1094101341732312, 0.2144553416292183, 0.1462500257184729, 0.19680119206896052, 0.1679586319369264, 0.16104585287394002, 0.08452943293377757, 0.11732507235137746, 0.1393852339242585, 0.11417453672038391, 0.20237455784808844, 0.12691366486251354, 0.2148947969544679, 0.22072825580835342, 0.17400933225871995, 0.17776764230802655, 0.14191301859682426, 0.12006520773866214, 0.1653475040802732, 0.16672395053319633, 0.16640803311020136, 0.12573813262861222, 0.12848255020799115, 0.14093341334955767, 0.06420162957510911, 0.17355310439597815, 0.21509185200557113, 0.20375435880851, 0.1997894051601179, 0.17706895479932427, 0.08216822330723517, 0.05217479993007146, 0.11583688072278164, 0.19326252804603428, 0.12576149543747306, 0.15049111767439172, 0.1213879078568425, 0.22545423737028614, 0.2515631855931133, 0.10988049252773635, 0.19123230886179954, 0.16563703073188663, 0.12557036272482947, 0.11298690005787648, 0.15384690166683868, 0.10001340910093859, 0.1271582322078757, 0.07716942825936712, 0.1843996372190304, 0.2001358545385301, 0.16561389056732878, 0.11983526812400669, 0.14667999639641494, 0.22617230977630243, 0.20325297868112102, 0.13483298913342878, 0.09463151742238551, 0.15184337011305615, 0.13452961400616914, 0.16246961866272613, 0.11436250788392499, 0.08351867974852212, 0.1976534744608216, 0.17053045565262437, 0.1128784500178881, 0.10535854220506735, 0.18927709112176672, 0.15216149913612753, 0.13952502486063167, 0.15468584024347365, 0.15240556182106957, 0.09592415313818492, 0.1261170583893545, 0.15035435470053926, 0.11417655536206439, 0.13031283480813727, 0.2115381372277625, 0.19658703793538734, 0.16261647484498098, 0.14709337265230715, 0.11828238348243758, 0.16902529110666364, 0.1425337212276645, 0.16863486205693334, 0.12336585015873425, 0.11427092686062679, 0.07343243269133382, 0.13479312096023932, 0.1866946546942927, 0.07745125883957371, 0.11354114336427301, 0.08982794432085939, 0.06859414192149416, 0.13489737786585465, 0.07579255136079155, 0.09433439860004, 0.17111011751694605, 0.11451918267994188, 0.0889091135468334, 0.16201717575313523, 0.11091257503721863, 0.1641930636833422, 0.09201579567161389, 0.10816368230734952, 0.1352624996798113, 0.17329364956822246, 0.16775252268416807, 0.13370689877774566, 0.16478105244459584, 0.12627881689695641, 0.07583377024275251, 0.0978795564151369, 0.11301566570182331, 0.23585628310684115, 0.17706070211715996, 0.10576387358014472, 0.15824513597181067, 0.19764379685511813, 0.1916321335011162, 0.11879695157404058, 0.12564736796775833], [0.014706984657095745, 0.05838642013259232, 0.027314348189975135, 0.022255685944401193, 0.06230645900359377, 0.01660362097027246, 0.04545152456557844, 0.02717322695389157, 0.035008894483326, 0.02122054578649113, 0.07793392200255767, 0.09963291740859859, 0.02340746945264982, 0.052811265777563676, 0.07629259562236257, 0.05786303532659076, 0.04657350713387132, 0.019936175740440376, 0.0407184888899792, 0.0204084877987043, 0.040660003942321055, 0.06547778219101019, 0.04536597349215299, 0.02547107415011851, 0.010923933259618934, 0.01847843999712495, 0.01846296807343606, 0.0890603187144734, 0.022384168405551463, 0.034083284190273844, 0.0505661985516781, 0.030261828505899757, 0.03219923841243144, 0.024074435714283027, 0.02151916745788185, 0.04265791743819136, 0.025784585159271955, 0.05536389384360518, 0.04354636468633544, 0.012697674555965932, 0.02265214494400425, 0.014808478917984758, 0.07419844041578472, 0.0252220706170192, 0.05518436460988596, 0.02910792245529592, 0.018638827386894263, 0.01635923359572189, 0.04449326348549221, 0.07813338903361, 0.027741598896682262, 0.0030608756105721113, 0.019534339880920015, 0.09886030456982553, 0.044025613970006816, 0.00595197566326533, 0.02319233382877428, 0.032427404294139706, 0.061580323163070716, 0.09408986836206168, 0.007177778197728912, 0.018705201364355162, 0.012364298108877847, 0.027402789928601123, 0.04982819205906708, 0.015447648966073757, 0.057335602105013095, 0.039550997826154344, 0.06082771491492167, 0.07996253072633408, 0.13158601883333176, 0.06831652674009092, 0.06392227034666575, 0.057902617772924714, 0.025154520335490815, 0.1311975935823284, 0.05735610022384208, 0.06642016131081618, 0.09089664439670742, 0.24037939117988572, 0.8932788076344877, 1.0669454606249928, 1.2885002908296883, 1.0541476286016405, 1.6114285751245916, 2.5657522352412343, 1.5334324166178703, 0.8302711823489517, 0.2906031516613439, 0.41470324562396854, 0.15398909716168419, 0.36716055299621075, 0.2208944968879223, 0.05352626940293703, 0.08070832234807312, 0.23665446293307468, 0.32042718725278974, 0.33747146953828633, 0.4332566406810656, 0.35045062308199704, 0.10415863784146495, 0.1279460368095897, 0.0362863273039693, 0.036094730749027804, 0.008377656122320332, 0.060555183445103467, 0.019616378740465734, 0.014461152877629502, 0.05731941586418543, 0.017034840311680455, 0.034651965979719535, 0.07930768188089132, 0.006962804918657639, 0.019872573684551753, 0.03829462715657428, 0.016016760273487307, 0.03526147331285756, 0.013306097425811458, 0.04928854679747019, 0.03553316986653954, 0.012944828285981202, 0.018954611223307438, 0.040323109715245664, 0.09988713267375715, 0.035247684209025465, 0.03641913834144361, 0.03646978992037475, 0.029141172526578885, 0.01902680920466082, 0.023134880466386676, 0.07073144559399225, 0.006488127264674404, 0.02701294346479699, 0.013824414290866116, 0.04119697005080525, 0.016461755731143057, 0.005249136765996809, 0.042849176315939985, 0.0361438646359602, 0.035184508888050914, 0.0838962325360626, 0.03486357454676181, 0.04459565017896239, 0.019924674306821544, 0.01752061678416794, 0.014227439442038303, 0.08009884841158055, 0.046795502057648264, 0.050911063444800675, 0.03222876104700845, 0.07449033451848663, 0.016143545071827248, 0.03141974586469587, 0.08716525946510956, 0.0347033411526354, 0.03354176129505504, 0.02810324189340463, 0.0751708319876343, 0.01908143312903121, 0.0776176038198173, 0.023327708986471407, 0.03089671543420991, 0.011922518006031169, 0.04422577490913682, 0.0561081195337465, 0.013918478725827299, 0.040767040190985426, 0.02725407095567789, 0.0404091506061377, 0.03404650335141923, 0.03976672902354039, 0.033076252875616774, 0.029982929409015924, 0.05511164526978973, 0.018959681947308127, 0.043678492947947234, 0.05279023702314589, 0.01370701023915899, 0.016850685642566532, 0.03884884819854051, 0.027159022247360554, 0.045649203020730056, 0.08713811912457459, 0.07071884392644279, 0.03625489734986331, 0.03705583425471559, 0.004563095453704591, 0.03316590060421731, 0.05345066310837865, 0.0369662199227605, 0.029360510561673436, 0.004826948434129008, 0.03159639185469132, 0.11025112849893048, 0.02485554614395369, 0.019459423783700913, 0.04906539783405606, 0.05621573836833704, 0.02083706138364505, 0.04245622767484747, 0.08145240703015588, 0.07056761649437249, 0.0041532838258717675, 0.019112466034130193, 0.07372639738605358, 0.002747630614976515, 0.042954475939041004, 0.0179731134994654, 0.045879899626015685, 0.017717970549711026, 0.08351873169885948, 0.02805505610012915, 0.007940162849990884, 0.04889736075710971, 0.05556139047257602, 0.03822741084150039, 0.09913563393638469, 0.017316457524430007, 0.004610577134371852, 0.03763462038477883, 0.01934971209266223, 0.049819534906418994, 0.01096591191526386, 0.03216013836208731, 0.03269929380621761, 0.06684852894977666, 0.09485398360993713, 0.01135543368945946, 0.003919479013347882, 0.06476778435171582, 0.04242572911607567, 0.009795167461561505, 0.05188493560126517, 0.05056019828771241, 0.031192359238048084, 0.043022311947424896, 0.052947917429264635, 0.031475893047172576, 0.0320247149647912, 0.010862359122256748, 0.053611527328030206, 0.035200554120820016, 0.030677021168230567, 0.009291725091316039, 0.07644299927051179, 0.07485567155526951, 0.01877239170426037, 0.030415211876970716, 0.04332214703026693, 0.019533660815795884, 0.0015630897519258724, 0.12345021008513868, 0.07136523970984854, 0.25166132720187306, 0.378141162218526, 0.9706745983567089, 1.8256158381700516, 1.7838666471652687, 2.4639065377414227, 2.3739520646631718, 2.5447761733084917, 3.4498467575758696, 2.333776820451021, 1.0545036219991744, 0.6114874128252268, 0.6281360413413495, 0.3546257974812761, 0.36349597619846463, 0.2009126011398621, 0.1065700760227628, 0.07350534870056435, 0.2601477858843282, 0.3084860311355442, 0.32452220970299095, 0.37376056134235114, 0.3257347602630034, 0.2539599366718903, 0.05860426274011843, 0.0006840762443971471, 0.05043085679062642, 0.06765145109966397, 0.05587248393567279, 0.08739322496694513, 0.08097185898805037, 0.05813095805933699, 0.014715960005560191, 0.052349835459608585, 0.08998830759082921, 0.04619289669790305, 0.016560377880523447, 0.05156898478162475, 0.04861842084210366, 0.017399008465872612, 0.033458280813647434, 0.03430704171478283, 0.059010774130001664, 0.0328057734441245, 0.06517028814414516, 0.10782885496155359, 0.06148585147457197, 0.05096143671835307, 0.03692434424010571, 0.027352782162779476, 0.025387968453287613, 0.051043815110460855, 0.08264437783509493, 0.049471660604467615, 0.030057318581384607, 0.07089820617693476, 0.05568962988036219, 0.07365517347352579, 0.02867719293135451, 0.023733259295113385, 0.029757559568679426, 0.0286916258482961, 0.01745513338391902, 0.08052177610807121, 0.04553514234430622, 0.07194884979980998, 0.019673572351166513, 0.023940376013342757, 0.01832090059906477, 0.07977291199495085, 0.025539722810208332, 0.013307610479387222, 0.016600197814113926, 0.07180733708082698, 0.016972013800113928, 0.06895017242641188, 0.0692529983643908, 0.027522620803210884, 0.0345275263680378, 0.029014896099397447, 0.006530220489366911, 0.044117603174527176, 0.0620390112453606, 0.061217030743137, 0.036303029337432235, 0.03317924441944342, 0.04803279953193851, 0.04826243115530815, 0.05617643422738183, 0.027851241939060856, 0.025219116869266145, 0.03559602235327475, 0.0319497766031418, 0.046856988992658444, 0.035822930294671096, 0.016636646541883238, 0.05027151026297361, 0.06817887318902649, 0.004197264888716745, 0.17330724571365863, 0.08587968899519183, 0.1521008211420849, 0.0853564303542953, 0.1524519015219994, 0.10849361889995635, 0.16254079062491655, 0.11993646738119423, 0.13945778628112748, 0.10339771382859908, 0.137130233051721, 0.12373640449368395, 0.12344180897343904, 0.21189123624935746, 0.20800474245334044, 0.18202935112640262, 0.1587089040549472, 0.21974666160531342, 0.10292144055711105, 0.10956574769807048, 0.16518463235115632, 0.12627973716007546, 0.10028090138803236, 0.1434596988838166, 0.20244145503966138, 0.18012633605394512, 0.16017166228266433, 0.16177483485080302, 0.14119138388196006, 0.09918503870721906, 0.07302857819013298, 0.15326695778639987, 0.15934106544591486, 0.08729195149498992, 0.2476550656137988, 0.10170081543037668, 0.10584442628896795, 0.15904708590824157, 0.18114681879524142, 0.08998215518658981, 0.13567207613959908, 0.059539131325436756, 0.1611176779260859, 0.1352323091123253, 0.15711420681327581, 0.22230255883187056, 0.07264525149366818, 0.07483945562853478, 0.18494060350349173, 0.24826095497701317, 0.27579772111494094, 0.11502567620482296, 0.10478023104951717, 0.2151618810603395, 0.12847587087890133, 0.14702460524858907, 0.08628352865343913, 0.1125944968953263, 0.1469715268467553, 0.1497925934381783, 0.0833842990687117, 0.08373649267014116, 0.10374363628216088, 0.13529000367270783, 0.15190505742793903, 0.10598845488857478, 0.0794509683328215, 0.13720235496293753, 0.15724837227026, 0.20644289266783744, 0.2099472694681026, 0.1162686622410547, 0.24766481743426993, 0.16253050445811823, 0.10342477253288962, 0.2270719560328871, 0.24730275326874107, 0.29316804371774197, 0.7824081787839532, 1.244070224929601, 2.2256486350670457, 2.4226827872917056, 2.8311679931357503, 2.874509417451918, 3.6885706102475524, 4.139615194872022, 3.00944278948009, 1.6718745441175997, 1.0393357858993113, 1.0288281622342765, 0.6507347943261266, 0.689717911882326, 0.2802260569296777, 0.1455637172330171, 0.1749992385157384, 0.5057188414502889, 0.9099530254025012, 0.8400801185052842, 0.9001372614875436, 0.6393026327714324, 0.4169104225002229, 0.2235142039717175, 0.13341795100132003, 0.14625165844336152, 0.15263933833921328, 0.15325325774028897, 0.19223584095016122, 0.17367996711982414, 0.14628646516939625, 0.08425155800068751, 0.12493710295530036, 0.15164181764703244, 0.09084761812118813, 0.15830971766263247, 0.15222337940940633, 0.12241874355822802, 0.12395081095746718, 0.10361436899984255, 0.11228129573282786, 0.13346905529033393, 0.09394615146447904, 0.1531618251465261, 0.12074940852471627, 0.20946141507010907, 0.11391355306841433, 0.09999613190302625, 0.19727119419258088, 0.1235597139748279, 0.13732617488130927, 0.17469476500991732, 0.1790960569633171, 0.15378506592242047, 0.13341453712200746, 0.1208958268398419, 0.14908710785675794, 0.09651471715187654, 0.12271074156160466, 0.1274630767875351, 0.10188444503000937, 0.1350429278681986, 0.2829215372912586, 0.19604730361606926, 0.15521375957177952, 0.14924800547305495, 0.08068457362242043, 0.12136437435401604, 0.23093905008863658, 0.11132865271065384, 0.11520655985805206, 0.12122849453589879, 0.13665947393747047, 0.08399645215831697, 0.12963359156856313, 0.15196281136013567, 0.07643747027032077, 0.10223735109320842, 0.10329290031222627, 0.1878452507662587, 0.1676531639532186, 0.12002669769572094, 0.1437396666733548, 0.10411050214315765, 0.08756953699048609, 0.20570268941810355, 0.09184404043480754, 0.06472420544014312, 0.10522956436034292, 0.2801079663913697, 0.19156517693772912, 0.10294475141563453, 0.18272095854626969, 0.1202647786703892, 0.07329452681005932, 0.13780615146970376, 0.10956781829008833, 0.10612333280732855], [0.04894625715678558, 0.006113877498137299, 0.01367032216876396, 0.00982771805865923, 0.046488182415487245, 0.05045214529673103, 0.06309451593551785, 0.03835446281300392, 0.026446310002938844, 0.034580174324219115, 0.031205461855279282, 0.032397510585724376, 0.06686550186714157, 0.01848923824582016, 0.04814237392565701, 0.09403497911989689, 0.06869579388876446, 0.0393544103280874, 0.013108251059748, 0.04003622510936111, 0.015074393213581061, 0.04417097843543161, 0.00627186821475334, 0.01799566365662031, 0.0634484387410339, 0.02788819718261948, 0.01300187810556963, 0.014374092461366672, 0.014428413960558828, 0.006448149624702637, 0.0148031799835735, 0.040894556004786864, 0.06378855017828755, 0.012763689519488253, 0.021726976228819694, 0.017929952045960817, 0.028756172287103254, 0.044921352819073945, 0.011344782942614984, 0.022988907439867035, 0.02764772278169403, 0.01883346489194082, 0.022590216431126464, 0.029834353299520444, 0.06735846603987738, 0.04101156671822537, 0.03683598784846254, 0.11876817108714022, 0.017347798420814797, 0.061342268163571134, 0.08411394897848368, 0.061347559676505625, 0.013275019991851877, 0.059387729488662444, 0.02610510946396971, 0.06480817202827893, 0.03468414921371732, 0.06720599179971032, 0.029054435872239992, 0.04465216843527742, 0.13618415803648531, 0.036400974277057685, 0.02895518104196526, 0.008635032008896815, 0.0794596663035918, 0.031954604273778386, 0.02878094332118053, 0.039319844800047576, 0.029522669829020742, 0.12165164487669244, 0.015119460131245432, 0.03742259992577601, 0.059098803976667114, 0.25164960126858205, 0.6627518276218325, 3.120178347453475, 6.399135449901223, 11.823650747537613, 16.03486977517605, 22.578247860074043, 26.568320654332638, 29.046617969870567, 29.702173992991447, 35.52362501621246, 31.744877882301807, 32.31906697154045, 31.417468450963497, 20.218941159546375, 18.269854746758938, 8.938519712537527, 7.073211679235101, 6.129568414762616, 4.554677372798324, 3.4844101779162884, 2.818880877457559, 5.716571900993586, 5.3606184013187885, 5.982263144105673, 10.621755290776491, 10.597878322005272, 10.231534279882908, 6.271068546921015, 1.6527320025488734, 0.21555265149800107, 0.06591812067199498, 0.06859407512820326, 0.02763142707408406, 0.03712542173161637, 0.032303268963005394, 0.04145934151893016, 0.04275007733667735, 0.03183534114214126, 0.07930688036140054, 0.017709038802422583, 0.06505524041131139, 0.06325497568468563, 0.08524582808604464, 0.05499758088262752, 0.012814153706131037, 0.036134335459792055, 0.008767952513153432, 0.021232798644632567, 0.035592541680671275, 0.0860455293150153, 0.0416182613116689, 0.0566060226992704, 0.03521935643220786, 0.06274684201343916, 0.020018938193970826, 0.04285324699594639, 0.011579694946703967, 0.014593451833206927, 0.057145289465552196, 0.015262958095263457, 0.026167412761424202, 0.04057423022459261, 0.026911206150543876, 0.043057760631199926, 0.040125568557414226, 0.045057614843244664, 0.03857150019030087, 0.02488258629455231, 0.012176165528217098, 0.045514811208704486, 0.030124549739412032, 0.0505500865256181, 0.04908884227916133, 0.04590587479469832, 0.04092743314686231, 0.01584237968927482, 0.05307792314852122, 0.05604194964689668, 0.11352783665643074, 0.02446387028612662, 0.03384717732842546, 0.017856759586720727, 0.03518348472425714, 0.059486238460522145, 0.027806327161670197, 0.007838688070478383, 0.003387572264728078, 0.03376695116457995, 0.07418736015097238, 0.03679269095300697, 0.0530961651384132, 0.028880476456834003, 0.035553077977965586, 0.03473357995972037, 0.050938604545081034, 0.02154964746296173, 0.002680634856915276, 0.040410475339740515, 0.04799954760528635, 0.050630572441150434, 0.07416160762659274, 0.0651292919064872, 0.06552594757522456, 0.04731812245154288, 0.04273077778634615, 0.02303799679793883, 0.04155806942435447, 0.0514504563761875, 0.0119935767907009, 0.020510098947852384, 0.036508155244519, 0.04191201449430082, 0.0070324322859960375, 0.05889060928893741, 0.03402196794922929, 0.036212142222211696, 0.06443076767027378, 0.04944633852574043, 0.06096789918956347, 0.007453031030308921, 0.04756738759169821, 0.02124779930454679, 0.018009966697718482, 0.043052665787399746, 0.04631544754374772, 0.03935012442525476, 0.0734724715584889, 0.06204056233400479, 0.04883013702055905, 0.023111421178327873, 0.042676478551584296, 0.040615408288431354, 0.006935407145647332, 0.030330488298204727, 0.015186671807896346, 0.052322717383503914, 0.013442444796964992, 0.037873380424571224, 0.03137294603220653, 0.05096974506159313, 0.05683757277438417, 0.005021210690756561, 0.05303886762703769, 0.016099700842460152, 0.01866643342509633, 0.04005747650808189, 0.014119548795861192, 0.04286106923245825, 0.021948583380435593, 0.10545289143919945, 0.005002217740184278, 0.024427208190900274, 0.009834373267949559, 0.06954433585633524, 0.04395938100060448, 0.12672438751906157, 0.04554411490971688, 0.08044105270528235, 0.038095620257081464, 0.038577396553591825, 0.09015820003696717, 0.04743647274153773, 0.036118086136411875, 0.04908450442599133, 0.02524346302379854, 0.018737455102382228, 0.049388944535166956, 0.0629301747540012, 0.024575164607085753, 0.02250717381684808, 0.0164772387870471, 0.024345766760234255, 0.01759511356794974, 0.0483584056928521, 0.0732493597024586, 0.2624086645664647, 1.2180289160460234, 4.140709061175585, 9.358149245381355, 15.824267975986004, 21.0914446413517, 29.073501527309418, 33.06608408689499, 36.772781386971474, 37.26173534989357, 44.80124518275261, 38.42443495988846, 38.388553485274315, 37.922508493065834, 25.31000867486, 22.333250306546688, 11.388369854539633, 9.39887261018157, 6.856486983597279, 5.387564655393362, 3.8095810543745756, 3.808357995003462, 6.254236875101924, 6.365457382053137, 7.047442412003875, 13.511729165911674, 14.708004724234343, 14.996641036123037, 9.751251451671124, 3.327252985909581, 0.5418689141515642, 0.06544306452269666, 0.11092184446169995, 0.05237094213953242, 0.04125685394683387, 0.026187293042312376, 0.03382779243111145, 0.04873450758168474, 0.0386135428561829, 0.03091281818342395, 0.026045787744806148, 0.07625859041581862, 0.057897259466699325, 0.022376746928784996, 0.05944065946096089, 0.010638360399752855, 0.011655355046968907, 0.03312280779937282, 0.04265424380719196, 0.021611115844279993, 0.028940447555214632, 0.10369113675551489, 0.034941214325954206, 0.04810070604435168, 0.020648670906666666, 0.03235189818951767, 0.044110738308518194, 0.07214727040263824, 0.018729638431977946, 0.11619246593909338, 0.0532045446743723, 0.0618009376921691, 0.04798876791028306, 0.030941262848500628, 0.029984122411406133, 0.03870438915328123, 0.05806716304505244, 0.04987140360753983, 0.01650323065405246, 0.04222465904604178, 0.05819696467369795, 0.030615298601333052, 0.049258634535362944, 0.018432274700899143, 0.05086551413114648, 0.01619088667212054, 0.019315718018333428, 0.0671955497818999, 0.066589200287126, 0.027814370187115856, 0.029723242660111282, 0.05572279646003153, 0.04525741584075149, 0.0844786774541717, 0.025861217472993303, 0.04126806037675124, 0.019321816616866272, 0.09906434323056601, 0.02798642042762367, 0.038367413289961405, 0.036072815128136426, 0.062308492488227785, 0.02711102570174262, 0.03320480769616552, 0.07935972869745456, 0.07470885248039849, 0.013103476267133374, 0.06943944070371799, 0.037934307038085535, 0.05608545063296333, 0.028680647628789302, 0.004308492416384979, 0.04824159535928629, 0.20902190037304536, 0.08549370541004464, 0.15238586522173136, 0.11188088479684666, 0.12989126524189487, 0.24709314107894897, 0.14235648151952773, 0.09991646234993823, 0.1434784455341287, 0.11672892738715746, 0.1528484607115388, 0.13539632374886423, 0.11413441621698439, 0.12768822954967618, 0.13760923000518233, 0.2237497764872387, 0.2129592461278662, 0.08053760611801408, 0.16989208990707994, 0.12453445815481246, 0.12144715350586921, 0.13508233590982854, 0.14451161900069565, 0.12718497921014205, 0.21990800451021641, 0.12293537482037209, 0.1549355432507582, 0.09657284957938828, 0.06420080579118803, 0.15601634775521234, 0.08687623747391626, 0.1574750241707079, 0.16929583362070844, 0.06107689470809419, 0.19104337290627882, 0.13980399817228317, 0.138742326234933, 0.14916835818439722, 0.10155751413549297, 0.0641968278796412, 0.16202159895328805, 0.13455903274007142, 0.155250035750214, 0.11417213958338834, 0.14728129928698763, 0.18273369380040094, 0.15709394618170336, 0.23387160210404545, 0.14274412009399384, 0.19632822135463357, 0.1523719128454104, 0.2336110785836354, 0.07922415315988474, 0.26877730095293373, 0.14935724961105734, 0.1226053862774279, 0.09794600831810385, 0.16333997977199033, 0.17020932835293934, 0.18608981918077916, 0.3242882253834978, 0.13243325462099165, 0.09168746953946538, 0.15165639342740178, 0.21946697583189234, 0.14813465037150308, 0.10991028975695372, 0.18322346673812717, 0.2096660845563747, 0.2608295524260029, 0.19539235829142854, 0.13600466219941154, 0.17727196187479421, 0.47808550705667585, 1.6321502882055938, 5.613319091498852, 10.999556668102741, 18.15059434622526, 25.540764592587948, 33.948613330721855, 39.50760863721371, 43.628035336732864, 43.65505948662758, 51.06981821358204, 46.31816178560257, 44.98959347605705, 42.79366470873356, 31.572198048233986, 27.94042892754078, 16.664570085704327, 14.993964079767466, 10.346808694303036, 7.683098427951336, 5.557975061237812, 5.943055897951126, 8.312624897807837, 9.130932837724686, 10.393343847244978, 17.17464331537485, 17.918901778757572, 15.650074873119593, 11.459063161164522, 4.351602019742131, 0.5863527115434408, 0.21137484989594668, 0.13065207051113248, 0.23765502643072978, 0.1208796925493516, 0.10507543513085693, 0.15282459324225783, 0.12094981066184118, 0.15373001340776682, 0.16102103545563295, 0.09914841371937655, 0.18587593222036958, 0.1784390484681353, 0.15989941282896325, 0.11212372293812223, 0.08464879996608943, 0.1740976923611015, 0.1208998789661564, 0.1377172421780415, 0.12356973296846263, 0.23123216873500496, 0.21247544005746022, 0.12317562286625616, 0.16394797683460638, 0.17090801586164162, 0.09197587554808706, 0.14459012338193133, 0.16578801325522363, 0.12985338602447882, 0.37922413379419595, 0.197566227579955, 0.13313741917954758, 0.14473015180556104, 0.17256515740882605, 0.0835575682867784, 0.09310163193731569, 0.21597643266431987, 0.12488154578022659, 0.10868284429307096, 0.16127698734635487, 0.20694078470114619, 0.11080823649535887, 0.24578451208071783, 0.139641452988144, 0.09629375010263175, 0.17063199629774317, 0.08407903835177422, 0.23789834696799517, 0.20493783202255145, 0.18307799095055088, 0.10499088224605657, 0.1402704676729627, 0.11500049513415433, 0.20780341263161972, 0.12212422967422754, 0.09953390006558038, 0.09100622992264107, 0.23153935850132257, 0.08645595924463123, 0.14308472134871408, 0.09968810350983404, 0.1396553756785579, 0.13557452824898064, 0.0984708328905981, 0.14111038588453084, 0.1704259612597525, 0.0771702297788579, 0.14887345838360488, 0.208620635967236, 0.11778935251641087, 0.16490969632286578, 0.15518934291321784, 0.1871358763310127], [0.02521159334719414, 0.021348009649955202, 0.03766469963011332, 0.03383774463145528, 0.03705461342178751, 0.020652517087000888, 0.028029481691191904, 0.060242479521548375, 0.023078260164766107, 0.04108441964490339, 0.046629127391497605, 0.01620176470169099, 0.0807523910771124, 0.03837402582576033, 0.033076082181651145, 0.010936761282209773, 0.06963688167161308, 0.016580736846663058, 0.029321688816708047, 0.01780249560397351, 0.024592497466073837, 0.06425070780096576, 0.009164956063614227, 0.06572666883585043, 0.019309667659399565, 0.06663220032351092, 0.022403850161936134, 0.11290623602690175, 0.01954060917341849, 0.01775516884663375, 0.004449156303962809, 0.012478869011829374, 0.022363378993759397, 0.04396973024995532, 0.067639183398569, 0.026483231849852018, 0.05073452877695672, 0.03723078814800829, 0.04081168408447411, 0.0783551947097294, 0.04852788624702953, 0.05847498061484657, 0.06922458895132877, 0.019213913910789415, 0.04077411656908225, 0.049819134146673605, 0.050543310717330314, 0.03848410116916057, 0.1161681383382529, 0.019693231843120884, 0.060593956950469874, 0.025659614912001416, 0.010448546854604501, 0.08266316901426762, 0.02073181556625059, 0.08585755072999746, 0.0864061017637141, 0.09183158719679341, 0.15445613069459796, 0.0418112308398122, 0.05390222657297272, 0.011063028432545252, 0.014286174864537315, 0.09946444246452302, 0.05154176280484535, 0.03112872007477563, 0.06884878021082841, 0.05629350802337285, 0.03469398638117127, 0.4019996663555503, 1.1441196757368743, 1.5286476421169937, 3.235505959019065, 8.224530424922705, 19.501877836883068, 32.18741163611412, 43.178739845752716, 54.56746593117714, 68.39427039027214, 70.34634724259377, 67.17009007930756, 74.38103154301643, 75.73430612683296, 75.7085283100605, 71.40014469623566, 77.8209413588047, 75.79413771629333, 66.04126945137978, 60.676751509308815, 49.37615789473057, 37.89736144244671, 43.583668917417526, 31.554291509091854, 34.81196120381355, 28.494127616286278, 35.16498886048794, 40.59366635978222, 41.27207815647125, 51.408269852399826, 47.94827051460743, 56.70852944254875, 42.855848371982574, 33.598332926630974, 12.711199522018433, 5.184235190972686, 0.4035429476061836, 0.07112672828952782, 0.037581553115160204, 0.05581375036854297, 0.031184284671326168, 0.006061251342543983, 0.039278232579817995, 0.03979897162935231, 0.041615040390752256, 0.022193006007000804, 0.02535146220907336, 0.03744515750440769, 0.030966009762778413, 0.013430011968011968, 0.042511662395554595, 0.026397628826089203, 0.031863290423643775, 0.08120570229948498, 0.029998547906870954, 0.010781452037917916, 0.023331317679549102, 0.07134554311051033, 0.040281786932609975, 0.03352416868438013, 0.015396278431580868, 0.0385635258135153, 0.026364083751104772, 0.1548514430760406, 0.013674530146090547, 0.054165269684745, 0.0189430225873366, 0.01608031780051533, 0.015657302901672665, 0.025307469550170936, 0.011726230150088668, 0.029485172817658167, 0.012424592041497817, 0.05112608960189391, 0.03129079399514012, 0.029775918446830474, 0.062325821636477485, 0.056527607375755906, 0.06722178470226936, 0.05735932485549711, 0.02689011802431196, 0.057172897359123453, 0.03187183254340198, 0.026752805861178786, 0.022753333068976644, 0.025651293581177015, 0.046955119469203055, 0.0013943625936008175, 0.02338602138479473, 0.02130714143277146, 0.046506394719472155, 0.04479612282011658, 0.04503084557654802, 0.03344402044604067, 0.05014971269702073, 0.04995918112399522, 0.05408365570474416, 0.08356687481864356, 0.08951550014899112, 0.07707009179284796, 0.028769482705683913, 0.026132346283702645, 0.030789666197961196, 0.057517758541507646, 0.02262929792777868, 0.031235259084496647, 0.01786068740329938, 0.03316268339403905, 0.03178692342771683, 0.0372198303375626, 0.028524985864351038, 0.020947919692844152, 0.04909007795504294, 0.09313277245382778, 0.13428035628749058, 0.03965931427956093, 0.03147782634187024, 0.02137621497240616, 0.07382151845376939, 0.037815292525920086, 0.03715986109455116, 0.06314544210908934, 0.030697660295118112, 0.03930058235710021, 0.03962872666306794, 0.04275876788597088, 0.04814534622710198, 0.026962041411024984, 0.05101858951093163, 0.0395396318344865, 0.039640222530579194, 0.08896970248315483, 0.04121698577364441, 0.016207668486458715, 0.022803318570367992, 0.03310164174763486, 0.00751830709305068, 0.01820519049942959, 0.022719685948686674, 0.02927620073023718, 0.03220038503059186, 0.05644453136483207, 0.07592145499074832, 0.03543781873304397, 0.028100251038267743, 0.05252496004686691, 0.07166872615925968, 0.05445265524031129, 0.03519814956234768, 0.01938078952662181, 0.006500715480797226, 0.02536075760872336, 0.011385209581931122, 0.05352692249289248, 0.058473629906075075, 0.08678684578626417, 0.010068017127196072, 0.03561040146450978, 0.06005035604175646, 0.02111207904818002, 0.06736723822541535, 0.052364741495694034, 0.055545842478750274, 0.056780646336846985, 0.04035631711303722, 0.06441710473154671, 0.011723595525836572, 0.08750265464186668, 0.08487447223160416, 0.0535671543184435, 0.09653219472966157, 0.011577054756344296, 0.03493726238957606, 0.057298973406432196, 0.009253742900909856, 0.1953222995507531, 0.3643609641585499, 1.1364972847513855, 2.0710617676377296, 4.810898574069142, 10.15124648809433, 24.67675745487213, 39.71874810755253, 52.05946370959282, 64.25862550735474, 77.86859840154648, 81.1449345946312, 75.91022908687592, 82.82777309417725, 86.46398037672043, 85.17372161149979, 80.62197625637054, 88.38273301720619, 84.13110315799713, 74.22736778855324, 68.43799844384193, 56.77792511880398, 42.178648710250854, 48.047156408429146, 37.008326947689056, 40.12260563671589, 32.6957331597805, 44.14401724934578, 49.17585924267769, 51.24308131635189, 60.73493778705597, 59.617090970277786, 69.48426470160484, 54.36343587934971, 44.42030802369118, 19.755442030727863, 8.246242459863424, 0.6635398103389889, 0.10919574997387826, 0.03142271074466407, 0.05598375413683243, 0.05554184230277315, 0.03708330856170505, 0.053272636723704636, 0.02983213242259808, 0.009546928340569139, 0.034380610813968815, 0.07726883894065395, 0.07642539552762173, 0.009072042885236442, 0.02313216606125934, 0.0460121132346103, 0.017749161161191296, 0.02268768825160805, 0.01134738880864461, 0.04997548239771277, 0.013681751242984319, 0.07914683621493168, 0.04139153519645333, 0.037566647079074755, 0.03779305407078937, 0.07510040217312053, 0.050784393679350615, 0.022261335543589666, 0.07929145111120306, 0.024570555870013777, 0.0483727922255639, 0.014713705731992377, 0.02943254898127634, 0.024252376751974225, 0.05916476235142909, 0.016811973364383448, 0.05416832733317278, 0.025970804854296148, 0.029853504420316312, 0.03580334872822277, 0.053649039182346314, 0.06261608301429078, 0.020845249127887655, 0.04839536464714911, 0.036862849883618765, 0.026947975857183337, 0.07671618383028544, 0.03828983288258314, 0.02493668329407228, 0.028485793045547325, 0.012551901909318985, 0.025447607440582942, 0.0331874154653633, 0.0029313084542081924, 0.021667164692189544, 0.08234043867560104, 0.050353684564470313, 0.07989023812115192, 0.036222732669557445, 0.04775483554112725, 0.004645438593797735, 0.06774502107873559, 0.03864622332912404, 0.04016494320239872, 0.09208265575580299, 0.11578674122574739, 0.00721701415386633, 0.028685642282653134, 0.0736833899281919, 0.019588026843848638, 0.049044521219911985, 0.06251826052903198, 0.15417605900438502, 0.1468952785944566, 0.12454731215257198, 0.11774065278586932, 0.08034328217036091, 0.12826424004742876, 0.26130256766919047, 0.1984839525539428, 0.1497431960888207, 0.11995651278994046, 0.17312405398115516, 0.171939586289227, 0.14889124024193734, 0.20846931205596775, 0.17920984304510057, 0.15163700853008777, 0.14023710071342066, 0.11916865623788908, 0.1169539539841935, 0.2086347813019529, 0.07733809616183862, 0.11725700256647542, 0.1422486623050645, 0.10659246661816724, 0.20079969079233706, 0.19105380750261247, 0.15583855885779485, 0.1795902382582426, 0.1661286293528974, 0.09472445657593198, 0.13020698970649391, 0.14768115361221135, 0.07388207770418376, 0.10842451752978377, 0.12366228620521724, 0.12455997319193557, 0.11683321397867985, 0.14364153990754858, 0.18357806489802897, 0.17030053830239922, 0.14109987707342952, 0.14879666094202548, 0.15349325345596299, 0.13498833548510447, 0.08545008196961135, 0.10908164476859383, 0.11478529457235709, 0.18410035874694586, 0.22684959374601021, 0.091482124698814, 0.12932316603837535, 0.14595521497540176, 0.13824453810229897, 0.13497016770998016, 0.09815567987971008, 0.15340953919803724, 0.13467789511196315, 0.1169477125222329, 0.35599951283074915, 0.1353722930070944, 0.20305856567574665, 0.1986792858224362, 0.16138437611516565, 0.20741335465572774, 0.07628443199791946, 0.11811803487944417, 0.1527575624641031, 0.1693777964101173, 0.3337246924638748, 0.6181764195207506, 1.5523716690950096, 2.781823603436351, 6.4325841050595045, 13.429826460778713, 30.09199507534504, 45.741614922881126, 60.99108584225178, 74.06678840517998, 89.06899139285088, 90.3884705901146, 86.49490311741829, 93.74371334910393, 97.37001076340675, 98.05364727973938, 92.2552040219307, 99.24768000841141, 97.14542761445045, 86.4013521373272, 79.20056372880936, 67.70344465970993, 51.685951352119446, 60.303619131445885, 47.40828149020672, 48.284157291054726, 39.63237874209881, 54.18288096785545, 57.17072144150734, 61.889540031552315, 69.11835953593254, 71.35406836867332, 80.94777837395668, 62.83610723912716, 52.20718078315258, 23.086552284657955, 9.110727421939373, 0.8002889505587518, 0.22893936285981908, 0.32166081480681896, 0.19983417150797322, 0.17394682858139277, 0.1088684776914306, 0.087508205906488, 0.15292604482965544, 0.11461212925496511, 0.09438452325412072, 0.14625486452132463, 0.2463916630949825, 0.10694480864913203, 0.130739287706092, 0.1335357446805574, 0.11054580565541983, 0.13648775580804795, 0.16759919497417286, 0.1575981909991242, 0.07110286824172363, 0.1625390539993532, 0.15175202657701448, 0.1639642150257714, 0.10654601559508592, 0.12369068819680251, 0.10921604771283455, 0.12430109723936766, 0.23188389313872904, 0.1093061815481633, 0.12364923182758503, 0.07906351529527456, 0.11985753997578286, 0.1061353852855973, 0.12046880248817615, 0.12749501882353798, 0.12754079449223354, 0.1257739932043478, 0.08786861508269794, 0.14400559302885085, 0.17822459747549146, 0.19035574339795858, 0.12019958841847256, 0.11930320019018836, 0.13561870087869465, 0.12406110894517042, 0.1621660208911635, 0.1742792662116699, 0.12113295786548406, 0.13468470802763477, 0.0975191843463108, 0.11989504069788381, 0.1141240335709881, 0.12648578704101965, 0.15921472222544253, 0.17196470056660473, 0.19174921471858397, 0.15386263519758359, 0.08672564086737111, 0.15592945710523054, 0.07951626248541288, 0.2503440744476393, 0.12321848931605928, 0.17312403913820162, 0.14037546672625467, 0.19404490012675524, 0.20374301879201084, 0.1711345193325542, 0.15074131049914286, 0.077693184139207, 0.16676557017490268, 0.07235446319100447], [0.019209234669688158, 0.09899209515424445, 0.03597490729589481, 0.027777476170740556, 0.026090529972861987, 0.031137596160988323, 0.03801637372816913, 0.004958377685397863, 0.03322608507005498, 0.04301492386730388, 0.042213293054373935, 0.059614262645482086, 0.0538646071072435, 0.024307631501869764, 0.03007964238349814, 0.05269526067422703, 0.035644332456286065, 0.07025635975878686, 0.03614879249653313, 0.014815010745223844, 0.028381313495629, 0.04020923086500261, 0.06042347078619059, 0.019844071503030136, 0.05876559080206789, 0.026027974345197435, 0.053450177001650445, 0.049933224509004503, 0.026871961381402798, 0.028083014658477623, 0.06869464355986565, 0.05923948177951388, 0.05018037452828139, 0.07484038331313059, 0.007054595134832198, 0.06985852407524362, 0.02514931602490833, 0.028294754956732504, 0.033999799998127855, 0.05804339947644621, 0.008947158912633313, 0.014289946830103872, 0.0729361733829137, 0.02175633744627703, 0.010619169388519367, 0.01632542876905063, 0.029848340927856043, 0.0696870285901241, 0.028211766148160677, 0.012997402955079451, 0.03160229192872066, 0.03595442402001936, 0.008586208896304015, 0.035587502497946844, 0.04722023688373156, 0.012613395338121336, 0.1029196371382568, 0.021581943874480203, 0.09412830419023521, 0.025044224203156773, 0.043368442202336155, 0.021011287972214632, 0.14199023164110258, 0.13129482977092266, 0.0638834189157933, 0.07215906312922016, 0.48254584427922964, 1.1859677801840007, 2.778799678198993, 6.596867339685559, 10.359869543462992, 23.540065549314022, 34.33572515845299, 47.32286587357521, 59.761589616537094, 71.55919656157494, 69.05191630125046, 73.22514116764069, 74.44691240787506, 70.1610691845417, 67.12213665246964, 66.67961239814758, 70.6589412689209, 63.97785097360611, 66.35230556130409, 63.537845984101295, 68.29503491520882, 66.46703660488129, 64.1824471950531, 69.97537314891815, 65.18258392810822, 58.607876524329185, 62.22340151667595, 70.27413591742516, 63.97849693894386, 71.89876154065132, 67.90162682533264, 70.71892485022545, 71.69506207108498, 71.94422990083694, 69.0418316423893, 70.66176071763039, 65.71083918213844, 57.65196941792965, 44.831708148121834, 17.51308925449848, 3.3785146102309227, 0.15441316034412012, 0.030005156731931493, 0.028037953306920826, 0.03348780715896282, 0.02369110530707985, 0.022101640206528828, 0.0597816429217346, 0.054260168108157814, 0.06893152225529775, 0.05106856573547702, 0.05579520780884195, 0.01203820120281307, 0.07848205743357539, 0.02966938314784784, 0.03502496569126379, 0.035629207486636005, 0.07499995990656316, 0.05580379074672237, 0.010832260395545745, 0.025239097340090666, 0.0388552455115132, 0.058802972780540586, 0.042198041919618845, 0.04492684100114275, 0.04419661963765975, 0.013998933100083377, 0.03139302854833659, 0.011437834345997544, 0.06934976699994877, 0.03569423446606379, 0.061418501572916284, 0.012827021619159495, 0.13207432231865823, 0.07213191536720842, 0.014406507616513409, 0.031165905384114012, 0.021225670316198375, 0.011841031118819956, 0.04603962093824521, 0.064167438831646, 0.04620947998773772, 0.04430237568158191, 0.023918124570627697, 0.04669204667152371, 0.02146204249584116, 0.04533000901574269, 0.006417098165911739, 0.029466761989169754, 0.04124179577047471, 0.10242319229291752, 0.020197343073959928, 0.05107701137603726, 0.020022253738716245, 0.04903486216790043, 0.1149685234122444, 0.0020998920081183314, 0.1136049754859414, 0.03632500061939936, 0.034308622489334084, 0.029178320728533436, 0.023381857936328743, 0.055373259747284465, 0.042377292847959325, 0.04887658804364037, 0.02384985811659135, 0.041164638387272134, 0.0286416292146896, 0.08490258478559554, 0.042267803801223636, 0.055433622328564525, 0.07841565748094581, 0.03115434643405024, 0.03977532309363596, 0.0033962370707740774, 0.01994302019738825, 0.055016995465848595, 0.03634493470599409, 0.06737692325259559, 0.020729444404423703, 0.03489049966447055, 0.04586103794281371, 0.0321256804454606, 0.046344918227987364, 0.06782863885746337, 0.029432940464175772, 0.0039852708687249105, 0.035635007370729, 0.039786629713489674, 0.031714070501038805, 0.015311809966078727, 0.013671343549503945, 0.06081078652641736, 0.020347904428490438, 0.016766006592661142, 0.02792954594042385, 0.03609070088714361, 0.028849883274233434, 0.02953305247501703, 0.08847968463669531, 0.10416022603749298, 0.009828341462707613, 0.018602040981932078, 0.03551161789800972, 0.03890237559971865, 0.07024392878520302, 0.032236768820439465, 0.048189600493060425, 0.05072127401945181, 0.05203696826356463, 0.08899386681150645, 0.04520599242823664, 0.010485176480869995, 0.0644596446363721, 0.05009701650124043, 0.01838512976974016, 0.03681092923216056, 0.061526283679995686, 0.04000112894573249, 0.06927830560016446, 0.061320901731960475, 0.05170592216018122, 0.02778656005830271, 0.059256402746541426, 0.027496103866724297, 0.01630250011658063, 0.06331257376587018, 0.02666798209247645, 0.06966005894355476, 0.0287903778735199, 0.05813441275677178, 0.0753260447527282, 0.07095559645676985, 0.10395958641311154, 0.07501242798753083, 0.29062927525956184, 0.8195936365518719, 1.44439488183707, 3.3352194959297776, 8.848910070955753, 15.844230204820633, 29.49796725064516, 42.71568149328232, 58.507485911250114, 71.30166918039322, 80.68842709064484, 79.2266683280468, 82.87843957543373, 83.13389986753464, 79.18297067284584, 76.63270711898804, 77.31682240962982, 78.19965943694115, 70.90138345956802, 77.50080093741417, 72.92969182133675, 78.42694044113159, 75.05927994847298, 73.9862859249115, 76.75930112600327, 75.85354372859001, 68.282670378685, 70.3606952726841, 78.84590595960617, 74.48438599705696, 82.32015833258629, 78.71045842766762, 82.54411831498146, 81.56741112470627, 80.71531444787979, 81.40963599085808, 79.85286712646484, 76.41791984438896, 69.65464755892754, 57.613051906228065, 26.40571027994156, 6.641590939834714, 0.6180072098504752, 0.07226685265777633, 0.011221358217881061, 0.07387110134004615, 0.013651954013766954, 0.024282268605020363, 0.03219940910639707, 0.04750755935674533, 0.11412195555749349, 0.04757727299875114, 0.05676676817529369, 0.014772349313716404, 0.02050323037110502, 0.012718509424303193, 0.03242242819396779, 0.03661851631477475, 0.03961451453506015, 0.04395827891130466, 0.04324000241467729, 0.06888463336508721, 0.027690010356309358, 0.03925061726476997, 0.029187753425503615, 0.07650620056665502, 0.033481142672826536, 0.019826764619210735, 0.05547018052311614, 0.0564503238274483, 0.026388643273094203, 0.01775259730493417, 0.026926789396384265, 0.02799613885144936, 0.029500559394364245, 0.004747052062157309, 0.03971825564804021, 0.09359095958643593, 0.05124010203871876, 0.031028322337078862, 0.03052967516850913, 0.005597507379206945, 0.01951496426045196, 0.06190546919242479, 0.017494834573881235, 0.04346503643319011, 0.035776141594396904, 0.04001415734819602, 0.023967271445144434, 0.015072601854626555, 0.01951216079760343, 0.026675433255149983, 0.002822441651915142, 0.03609598126786295, 0.07187432333012111, 0.028598126373253763, 0.045640983735211194, 0.08058252089540474, 0.004712754171123379, 0.02411241326626623, 0.04184658304438926, 0.09966557932784781, 0.01987972056667786, 0.03739064675755799, 0.014869877722958336, 0.019042845160583965, 0.01431486351066269, 0.01977166200958891, 0.0498366859392263, 0.03629771927080583, 0.02807909982948331, 0.16313376661855727, 0.21353343094233423, 0.11451373531599529, 0.07359903742326424, 0.0647449707321357, 0.1811896258732304, 0.09768567775608972, 0.11836037578177638, 0.1771735679358244, 0.08919842497562058, 0.15006843488663435, 0.14926071104127914, 0.1873609994072467, 0.10727256332756951, 0.20806751330383122, 0.110461490257876, 0.10503646495635621, 0.19296563928946853, 0.15233636397169903, 0.07617694674991071, 0.08384391854633577, 0.12696031626546755, 0.11261238265433349, 0.18657812266610563, 0.10893240629229695, 0.17666748259216547, 0.17561039712745696, 0.19264421513071284, 0.07238771140691824, 0.21633575088344514, 0.1443115359870717, 0.14846842386759818, 0.07081455129082315, 0.2146700004232116, 0.19358359597390518, 0.19299980776850134, 0.1250510523095727, 0.10602638605632819, 0.24020056327572092, 0.32321638602297753, 0.14087401184951887, 0.10682584237656556, 0.1406331403995864, 0.16113596444483846, 0.09177237123367377, 0.1492237372440286, 0.11402796997572295, 0.1567741992766969, 0.13584342319518328, 0.17302524443948641, 0.14951221004594117, 0.2404579846188426, 0.05205234556342475, 0.15547763759968802, 0.17058072873624042, 0.08718174256500788, 0.1886031319736503, 0.08742205740418285, 0.21322661224985495, 0.13176033447962254, 0.1687463029520586, 0.21836239291587844, 0.2374141401378438, 0.30231495446059853, 0.4639636242063716, 0.6722813006490469, 1.3686611456796527, 2.1186323650181293, 4.762177588418126, 10.811030734330416, 19.424259401857853, 37.00092114508152, 49.25084441900253, 69.5976734161377, 82.56782904267311, 92.16066509485245, 93.16605314612389, 95.49301028251648, 95.71777582168579, 91.40890583395958, 90.17223939299583, 86.56774520874023, 92.1680822968483, 87.46704295277596, 90.01792967319489, 84.05104145407677, 88.23398619890213, 86.12947672605515, 85.09217038750648, 90.97310721874237, 86.47072121500969, 77.89847239851952, 80.70173397660255, 89.44637194275856, 87.77829185128212, 94.82988506555557, 90.16773283481598, 91.94457828998566, 94.29446339607239, 93.97331982851028, 95.01653864979744, 95.01706302165985, 91.96265012025833, 81.66683658957481, 65.70795893669128, 28.942361064255238, 7.099009919911623, 0.855971637647599, 0.17714601941406727, 0.13433045125566423, 0.11898645898327231, 0.08281566551886499, 0.1235623263346497, 0.15439962357049808, 0.0946718011982739, 0.26651185064110905, 0.20986414892831817, 0.1627706189174205, 0.07948627229779959, 0.1310351226129569, 0.08293482474982738, 0.18259596603456885, 0.12963672343175858, 0.13839164661476389, 0.1410677272360772, 0.1062444067792967, 0.15140878327656537, 0.13773137266980484, 0.37336149369366467, 0.1588130570598878, 0.13359004020458087, 0.10500326126930304, 0.09970915081794374, 0.21722473989939317, 0.10916616796748713, 0.10370811709435657, 0.06014843085722532, 0.14014902262715623, 0.07545398359070532, 0.19763814168982208, 0.11542271779035218, 0.10139272024389356, 0.19590604322729632, 0.09804379369597882, 0.16217669297475368, 0.09956537454854697, 0.15602614410454407, 0.13700049079488963, 0.1476045639719814, 0.09154925937764347, 0.18243521684780717, 0.17307867907220498, 0.1667190226726234, 0.0638959241041448, 0.137973238597624, 0.14597814733861014, 0.12291661332710646, 0.2051870006835088, 0.11859004080179147, 0.1229450450045988, 0.1079621521057561, 0.1382773113436997, 0.2063785633072257, 0.20508274377789348, 0.23656819568714127, 0.15101063589099795, 0.17905501619679853, 0.18527942360378802, 0.1361083402298391, 0.15129432926187292, 0.09790515308850445, 0.08855643754941411, 0.1103247792343609, 0.13772132399026304, 0.08197098271921277, 0.20423129259143025], [0.024608470339444466, 0.009202178480336443, 0.06077361977077089, 0.04018263229227159, 0.028702234849333763, 0.04808621190022677, 0.07158405453083105, 0.008322522899106843, 0.035964621129096486, 0.04100699879927561, 0.04370334747363813, 0.03162589964631479, 0.034218815198983066, 0.0059018825504608685, 0.013657235322170891, 0.0504199731949484, 0.04889007286692504, 0.039720047934679314, 0.01988899370189756, 0.002412250601082633, 0.015389305954158772, 0.0351411340670893, 0.057380784055567347, 0.06700710364384577, 0.04378188154078089, 0.0706921711389441, 0.04338580845796969, 0.02145496240700595, 0.05067523488833103, 0.009158191387541592, 0.021668736189894844, 0.03601642674766481, 0.00788623468906735, 0.0494159587105969, 0.037395633989945054, 0.057696846197359264, 0.06571077203261666, 0.02773861360765295, 0.01854039634054061, 0.042415405841893516, 0.023995504598133266, 0.02930819657194661, 0.029757958473055623, 0.018079877008858602, 0.03030311047041323, 0.015242536046571331, 0.07564234809251502, 0.0058433832236914895, 0.043377381371101364, 0.019555719300115015, 0.052599434566218406, 0.039553098104079254, 0.04064932443725411, 0.03253949456848204, 0.07322118035517633, 0.09889874039799906, 0.20451770222280174, 0.45697072288021445, 0.48356125073041767, 1.131230411119759, 3.3984865760430694, 2.636958039365709, 2.9207052011042833, 6.092051127925515, 7.2942861914634705, 7.396585252135992, 9.055580031126738, 25.594873689115047, 26.507981792092323, 42.4063590914011, 52.8573676943779, 63.472785875201225, 65.15648692846298, 75.43796762824059, 70.63036680221558, 68.07796776294708, 57.28171728551388, 56.63425862789154, 52.88842722773552, 57.85917229950428, 49.90151010453701, 45.58325842022896, 47.57923811674118, 40.840235128998756, 42.528438940644264, 35.863718166947365, 44.687741473317146, 37.2959791123867, 48.82949262857437, 44.84710872173309, 47.95763701200485, 62.54600040614605, 52.248499765992165, 55.19360013306141, 60.066808238625526, 57.52223297953606, 61.00872069597244, 67.26749405264854, 60.37921987473965, 47.29003943502903, 67.0931214094162, 65.88857844471931, 62.90418438613415, 67.3930849134922, 73.1020125746727, 68.17374542355537, 38.83080035448074, 10.55675882846117, 2.261462425813079, 0.1296526350779459, 0.017558855943207163, 0.1244895879062824, 0.040089303511194885, 0.05982183021842502, 0.010952357515634503, 0.021714528556913137, 0.028137492008681875, 0.0848967069759965, 0.06584773538634181, 0.03490863033221103, 0.07069988947478123, 0.04075070180988405, 0.028924949656357057, 0.03390897596545983, 0.04702505946625024, 0.016771275841165334, 0.008927239668992115, 0.10437527074827813, 0.04182934666459914, 0.09819257204071619, 0.03942121104046237, 0.06424028062610887, 0.053920947248116136, 0.054145710382726975, 0.059581786263152026, 0.03605733763833996, 0.01762918742315378, 0.02092554950650083, 0.09112216081121005, 0.03512510367727373, 0.09865984306088649, 0.010338420488551492, 0.01274986423595692, 0.044552509134518914, 0.06250210397411138, 0.023456163617083803, 0.01908380614622729, 0.004663941263061133, 0.059292767982697114, 0.07460871449438855, 0.01008456980343908, 0.09556815231917426, 0.05678484318195842, 0.05626487596600782, 0.044241860960028134, 0.04605192945746239, 0.05615024012513459, 0.03709729804540984, 0.019043524225708097, 0.026424665265949443, 0.022635168315900955, 0.02871068976673996, 0.03380301954166498, 0.11871055074152537, 0.028451299876905978, 0.0051374379745539045, 0.0417292977363104, 0.042646570000215434, 0.048503406505915336, 0.0340787793538766, 0.07305038248887286, 0.04013773606857285, 0.05980762180115562, 0.08164068247424439, 0.042549166828393936, 0.04819640969799366, 0.03835036244709045, 0.0239716612486518, 0.01845048514951486, 0.03578929987270385, 0.02499665253708372, 0.027734220093407203, 0.08342204469954595, 0.024880619603209198, 0.02896096422773553, 0.036763045864063315, 0.07252561728819273, 0.041896826442098245, 0.01763157528330339, 0.08176845803973265, 0.027511458902154118, 0.0253478683589492, 0.07862735510570928, 0.04311563701776322, 0.019727938379219268, 0.013067312338534975, 0.003894617530022515, 0.054899598835618235, 0.040002453679335304, 0.04548096185317263, 0.030595739299315028, 0.009045765291375574, 0.0433711770165246, 0.02173405075154733, 0.0737950460461434, 0.05365349948988296, 0.0032504699902347056, 0.027332425052009057, 0.021477254667843226, 0.029363822395680472, 0.05295383605698589, 0.01385792782457429, 0.07094785585650243, 0.035602582938736305, 0.04326477901486214, 0.017553213765495457, 0.026881989651883487, 0.013009335762035334, 0.01830173649068456, 0.04245973061188124, 0.05178638581128325, 0.024150734061549883, 0.11392379470635206, 0.043745007933466695, 0.051737548783421516, 0.015125875070225447, 0.01895214543765178, 0.051753200677921996, 0.01572762139403494, 0.02027871028985828, 0.07757490806397982, 0.053766506316605955, 0.21353665186325088, 0.3774255240568891, 0.7257155771367252, 1.5641287132166326, 4.184074234217405, 3.2738679880276322, 3.413263508118689, 7.00563183054328, 8.322870098054409, 8.569717202335596, 12.797684781253338, 32.68906831741333, 32.91943095624447, 52.914011254906654, 65.05766943097115, 76.02682203054428, 75.52369862794876, 82.5689385831356, 79.50945675373077, 74.59783270955086, 65.64810454845428, 66.28780022263527, 64.42393943667412, 68.40067684650421, 58.177264630794525, 55.01198127865791, 55.56632973253727, 49.564414992928505, 52.872517481446266, 44.51153352856636, 52.99061894416809, 46.80276118218899, 59.410100877285004, 53.12170051038265, 58.087414652109146, 70.43463930487633, 62.53745086491108, 63.13480541110039, 68.66877526044846, 65.32830610871315, 71.38254404067993, 75.90812399983406, 69.42372635006905, 56.56501114368439, 74.21469926834106, 72.85678133368492, 71.31114587187767, 74.84779089689255, 81.65213897824287, 79.71036717295647, 52.508781999349594, 17.478604204952717, 4.022298390045762, 0.23154254973633215, 0.048408868024125695, 0.044551926548592746, 0.04791225248482078, 0.06396572309313342, 0.08316724313772283, 0.02700847759115277, 0.0012589337461577088, 0.02814827355905436, 0.02489169801265234, 0.021273442362144124, 0.11827020483906381, 0.10390307928901166, 0.027218076793360524, 0.008020030927582411, 0.055147186722024344, 0.033522294761496596, 0.016623994779365603, 0.07441440538968891, 0.02748209582932759, 0.026593830407364294, 0.010196041312156012, 0.016698248509783298, 0.06113986593845766, 0.04884107256657444, 0.052867483464069664, 0.00428750448008941, 0.014039824509382015, 0.024040072421485092, 0.03113558494078461, 0.04885326976364013, 0.07201323853223585, 0.005483601626110612, 0.008026868890738115, 0.07056254020426422, 0.08063508721534163, 0.05619944822683465, 0.06435100905946456, 0.023652368909097277, 0.020903090262436308, 0.07043742152745835, 0.015855170604481827, 0.03639521892182529, 0.039852409972809255, 0.058681178925326094, 0.04273019891115837, 0.012722865831165109, 0.0632029511325527, 0.04956905264407396, 0.02879215717257466, 0.09038018382852897, 0.05322012977558188, 0.011909281802218175, 0.06381025799782947, 0.04879175314272288, 0.0683756239595823, 0.04817003748030402, 0.06286445015575737, 0.028958953007531818, 0.018171183437516447, 0.03769087888940703, 0.1045906642684713, 0.06080106810259167, 0.04583436144457664, 0.041401257331017405, 0.04903841334453318, 0.027290159741824027, 0.11986020428594202, 0.0860540269059129, 0.18007181788561866, 0.11944687998038717, 0.09877437129034661, 0.1606959747732617, 0.17494185565738007, 0.10383364395238459, 0.14675012935185805, 0.1160068844910711, 0.17896195087814704, 0.13989462924655527, 0.15952863584971055, 0.11932607318158261, 0.15530493983533233, 0.24278835800942034, 0.11625012339209206, 0.11474567130790092, 0.0662261268007569, 0.06915660080267116, 0.0632997346110642, 0.13684775680303574, 0.22611599561059847, 0.2959646045928821, 0.15287326328689232, 0.11744360817829147, 0.07622638120665215, 0.07915773094282486, 0.09581217789673246, 0.09398479509400204, 0.1212863672117237, 0.11150932856253348, 0.14770215639146045, 0.10568556215730496, 0.06934636796358973, 0.16725745081203058, 0.1248105667764321, 0.12647180497879162, 0.09750620418344624, 0.11675623100018129, 0.12715195363853127, 0.09919967385940254, 0.11629016968072392, 0.12198450553114526, 0.12250904066604562, 0.10531960913795047, 0.25057274498976767, 0.17105359554989263, 0.3123977134237066, 0.11128310710773803, 0.11247856600675732, 0.12428557893144898, 0.1399712188867852, 0.12633038131752983, 0.13934376271208748, 0.15988099272362888, 0.545097969006747, 0.9678154299035668, 1.4223864628002048, 3.260916145518422, 6.388200111687183, 4.960056720301509, 5.482247024774551, 9.753601625561714, 13.01426650956273, 13.247056268155575, 18.221504241228104, 40.40257081389427, 41.66090369224548, 64.95184510946274, 77.6000364124775, 87.6220290362835, 85.54250702261925, 94.98662665486336, 91.63559406995773, 87.98713624477386, 75.34687891602516, 75.7038089632988, 74.63788256049156, 77.97731056809425, 71.069266051054, 66.1954727768898, 69.89836648106575, 62.57656216621399, 62.40039981901646, 52.876925244927406, 66.00254952907562, 54.823142811656, 69.6131081879139, 62.886792719364166, 69.19984236359596, 81.74050703644753, 71.94713294506073, 74.50112029910088, 81.00832432508469, 76.3585214316845, 80.92657551169395, 84.7598934173584, 80.3620246052742, 68.83006900548935, 85.5422106385231, 82.96949028968811, 81.9155104458332, 85.62395945191383, 91.04287907481194, 89.88213256001472, 59.65179830789566, 20.021435357630253, 4.428943544626236, 0.36213852872606367, 0.14343868126161397, 0.35683621012140065, 0.1719316007802263, 0.1370534356101416, 0.17669664899585769, 0.18844781530788168, 0.09186907307594083, 0.16758255602326244, 0.1497311139246449, 0.16735528071876615, 0.1578501649782993, 0.14412010641535744, 0.12345028429990634, 0.1619891670998186, 0.1598898836527951, 0.17706701037241146, 0.08668572074384429, 0.1660064866882749, 0.14590537233743817, 0.11313253169646487, 0.12607301934622228, 0.17418517672922462, 0.12188847162178718, 0.19041228020796552, 0.16383478447096422, 0.06590146687813103, 0.2026521210791543, 0.08820824412396178, 0.1732521635130979, 0.10320042871171609, 0.25548415957018733, 0.0999610431608744, 0.180688290274702, 0.19940241967560723, 0.12588886282173917, 0.28020204103086144, 0.2171155106043443, 0.07463353191269562, 0.12541862321086228, 0.2047126050456427, 0.15199433779343963, 0.17072709510102868, 0.19432409608270973, 0.10606993528199382, 0.16518758609890938, 0.14582373609300703, 0.14670761913293973, 0.10747916981927119, 0.08653274926473387, 0.24258532124804333, 0.08483689729473554, 0.13100245327223092, 0.2352011002949439, 0.20871192013146356, 0.1519519166322425, 0.1479185072821565, 0.10557803980191238, 0.1700199767947197, 0.10995211720000952, 0.1829364337027073, 0.19659762096125633, 0.16801913181552663, 0.20067548495717347, 0.17931565846083686, 0.09985372118535452, 0.10856368506210856], [0.026137621098314412, 0.01574079451529542, 0.05830316600622609, 0.04518644054769538, 0.039775475233909674, 0.027479338750708848, 0.042482136050239205, 0.038555673891096376, 0.015695542060711887, 0.056519848221796565, 0.015844595000089612, 0.029205210594227538, 0.06072425210732035, 0.015560191950498847, 0.043831085931742564, 0.0427322064206237, 0.012690945131907938, 0.066515059734229, 0.07602810903335921, 0.024972861137939617, 0.018381608279014472, 0.07701058639213443, 0.07996460873982869, 0.0712066724372562, 0.07826958055375144, 0.02725660910073202, 0.029112380907463375, 0.03256494281231426, 0.04544456322037149, 0.04569082637317479, 0.09250894538126886, 0.010323560836695833, 0.02640840109961573, 0.016810305387480184, 0.018256960865983274, 0.08707499204319902, 0.03300743723229971, 0.023236107554112095, 0.05128732118464541, 0.03728755131305661, 0.03990742909081746, 0.03827169108262751, 0.04275111263268627, 0.04384711632155813, 0.09658699491410516, 0.006694700359730632, 0.018380372603132855, 0.02217866771388799, 0.058188274124404415, 0.03880756994476542, 0.028591935006261338, 0.03986548661487177, 0.04069146729307249, 0.08466534985927865, 0.6145949335768819, 2.509091575630009, 4.220931306481361, 10.594028178602457, 12.7444439381361, 18.735211975872517, 23.586732745170593, 30.266686901450157, 30.858963020145893, 37.101657539606094, 37.165988087654114, 35.67920006811619, 48.461216390132904, 62.06835463643074, 63.676994517445564, 65.92879548668861, 67.70757883787155, 64.43654716014862, 64.7086201608181, 54.42887216806412, 44.98044736683369, 41.70206308364868, 32.185238152742386, 35.941777378320694, 28.984402008354664, 27.94745285063982, 27.60612666606903, 22.064553424715996, 16.527914218604565, 20.658324882388115, 44.35283124446869, 23.2996828481555, 23.22983119636774, 32.1101313829422, 28.590387850999832, 38.90514716506004, 43.66808518767357, 38.11259709298611, 26.40559058636427, 38.85473906993866, 38.50356571376324, 33.40894728899002, 47.23315268754959, 47.431844025850296, 44.86141875386238, 32.2454459220171, 47.03982666134834, 61.366581693291664, 56.983657479286194, 58.16088370978832, 61.48952029645443, 67.14785367250443, 64.02313694357872, 53.43361437320709, 32.36337639391422, 11.859500873833895, 4.7970454674214125, 1.0272125364281237, 0.06775521076633595, 0.03434594509599265, 0.03007158822583733, 0.0587566924514249, 0.04349419170466717, 0.10031700687250122, 0.03903357617673464, 0.028611900634132326, 0.07287094602361321, 0.048945151356747374, 0.017620882790652104, 0.06898782157804817, 0.08472489236737601, 0.05137774074682966, 0.01663958730205195, 0.030041258505661972, 0.03419813154323492, 0.031976267564459704, 0.031921241024974734, 0.055348861642414704, 0.07732462618150748, 0.023954649368533865, 0.046613531158072874, 0.02569867043348495, 0.02924173910287209, 0.04529202589765191, 0.010468503205629531, 0.03266741114202887, 0.04555284256639425, 0.03774195720325224, 0.05001554724003654, 0.037448456350830384, 0.013306807104527252, 0.0263990463281516, 0.015298859489121241, 0.06492434782558121, 0.027793482440756634, 0.024535973643651232, 0.04287961921363603, 0.02935282747785095, 0.038274377657216974, 0.05793612574052531, 0.02217299770563841, 0.06619244071771391, 0.03213703901565168, 0.042041604610858485, 0.020697667496278882, 0.03729460913746152, 0.011897079966729507, 0.028462244699767325, 0.018612071107781958, 0.07018875752692111, 0.0419319597131107, 0.02368234610912623, 0.04002572371973656, 0.016652402337058447, 0.030587714827561285, 0.04847635151236318, 0.042182378892903216, 0.06852484759292565, 0.04190618121356238, 0.049574080694583245, 0.020920233873766847, 0.049318058299832046, 0.04009101787232794, 0.020007327293569688, 0.011619015785981901, 0.03174934106937144, 0.03436066188442055, 0.015768651028338354, 0.09399443559232168, 0.03344284414197318, 0.036955677715013735, 0.04084464657353237, 0.012571233928611036, 0.03759514926059637, 0.05100923102872912, 0.02648228004545672, 0.01023535936838016, 0.08049104377278127, 0.03182604574249126, 0.08395624259719625, 0.017988834042625967, 0.06947910107555799, 0.03349437516590115, 0.04158708739851136, 0.03669008903671056, 0.06943385233171284, 0.017927057670021895, 0.014710155483044218, 0.041053026798181236, 0.02064290256384993, 0.014327942008094396, 0.027255501445324626, 0.05708891592803411, 0.04169998661382124, 0.013706343233934604, 0.007694697969782283, 0.07703941140789539, 0.02442303917632671, 0.028883404229418375, 0.028331548783171456, 0.032657503470545635, 0.03053742133488413, 0.10342088367906399, 0.024019542761379853, 0.039283464720938355, 0.044259557471377775, 0.07817191391950473, 0.029623186310345773, 0.055920927625265904, 0.031676269209128805, 0.014184720494085923, 0.03184785746270791, 0.06001764959364664, 0.020563414836942684, 0.08797966263955459, 0.16213265393162146, 1.1437554890289903, 3.6080885538831353, 5.7186242658644915, 13.007596917450428, 14.397712424397469, 22.04641319811344, 26.260844953358173, 35.08495755493641, 35.41609078645706, 43.277036771178246, 43.96981559693813, 42.430837377905846, 60.138460993766785, 73.56778398156166, 71.8221652507782, 74.47691559791565, 76.14249542355537, 73.48958417773247, 72.52877533435822, 68.20507854223251, 54.367326870560646, 51.26823216676712, 42.54014611244202, 46.45270116627216, 40.31082093715668, 42.2814179956913, 38.26410636305809, 34.80501517653465, 27.192351669073105, 37.006294056773186, 59.535239562392235, 31.68312929570675, 37.194862738251686, 43.5482320189476, 35.51852948963642, 41.67073756456375, 44.54505912959576, 46.43759697675705, 37.275160029530525, 50.32121278345585, 47.98450917005539, 40.6161193549633, 54.505704045295715, 55.293454974889755, 54.22769196331501, 41.84978775680065, 58.762315437197685, 71.31847187876701, 67.06934228539467, 65.39911910891533, 71.51377379894257, 73.6936104297638, 72.40083619952202, 64.83948513865471, 42.56436601281166, 17.885562367737293, 7.59660366922617, 1.7327693640254438, 0.1621444392367266, 0.0129049471252074, 0.010251412022626027, 0.05365436780266464, 0.11418891954235733, 0.03467473878117744, 0.05177765815460589, 0.005372844898374751, 0.0677483162144199, 0.015351885940617649, 0.04411052679643035, 0.05272569243970793, 0.0395419770211447, 0.08351180746103637, 0.05434952268842608, 0.07184788060840219, 0.050733474927255884, 0.01943969193234807, 0.019951348949689418, 0.011536209731275449, 0.09514749559457414, 0.01138596007876913, 0.03488188704068307, 0.028316121388343163, 0.11932962064747699, 0.04988897395378444, 0.07794203367666341, 0.06900238251546398, 0.04508774232817814, 0.04905088142550085, 0.018642317336343694, 0.06047189963283017, 0.05408348130004015, 0.029129791691957507, 0.05143842245161068, 0.020404914357641246, 0.04814120133232791, 0.013016090233577415, 0.026706030148488935, 0.03097970980888931, 0.03632657397247385, 0.04133145834202878, 0.034857600257964805, 0.06169334483274724, 0.07492157426895574, 0.006708282589897863, 0.058367157689644955, 0.07307548192329705, 0.01330742494246806, 0.01602515396371018, 0.029884631949244067, 0.045366107078734785, 0.034604550164658576, 0.0458923565747682, 0.07025379192782566, 0.07568330722278915, 0.02821433954522945, 0.021922086853010114, 0.03490132759907283, 0.029058408217679244, 0.040745729420450516, 0.008802845513855573, 0.07115135274943896, 0.011097398219135357, 0.34149429586250335, 0.08389924565562978, 0.16633638617349789, 0.12588390527525917, 0.16502795013366267, 0.10320972782210447, 0.24009028013097122, 0.1294142275582999, 0.0912195751152467, 0.1107287747436203, 0.13555100216763094, 0.13038454111665487, 0.112046665744856, 0.09650061634602025, 0.11315594645566307, 0.0955158457509242, 0.14500134740956128, 0.17934078758116812, 0.22722880152286962, 0.2679079194786027, 0.11066121704061516, 0.2307191220461391, 0.11853604213683866, 0.2354783221380785, 0.06597447936655954, 0.08247257064795122, 0.18466492532752454, 0.07445767259923741, 0.14388984767720103, 0.14021899231011048, 0.2117474377155304, 0.10454817631398328, 0.10236509697278962, 0.09769157783011906, 0.14846803795080632, 0.10411794588435441, 0.11164010982611217, 0.12198130687465891, 0.13483292976161465, 0.10372882301453501, 0.1308184748631902, 0.09746090348926373, 0.08532439183909446, 0.14434625365538523, 0.2090163342654705, 0.12639295920962468, 0.25669623515568674, 0.10400335828308016, 0.17465425858972594, 0.08691616501891986, 0.17787495686206967, 0.18298137816600502, 0.15048577421111986, 0.2756029518786818, 1.6184611665084958, 5.945993140339851, 8.856522012501955, 16.83196820318699, 19.93095651268959, 27.56830919533968, 32.89013832807541, 43.31232167780399, 42.914186641573906, 52.16267757117748, 53.18492911756039, 53.238703832030296, 73.05391475558281, 84.05700713396072, 83.52999061346054, 86.22660711407661, 85.86985945701599, 85.30824199318886, 84.57624927163124, 73.45627516508102, 63.317317217588425, 61.54843233525753, 50.53333260118961, 53.83750610053539, 45.783674865961075, 45.17689682543278, 44.382154271006584, 37.935534194111824, 33.71093228459358, 36.36775352060795, 60.64453683793545, 36.19022324681282, 38.027523458004, 47.3980600386858, 46.153668612241745, 53.98993492126465, 61.26845195889473, 56.29514962434769, 41.80419020354748, 55.85252657532692, 57.06061094999313, 51.975860595703125, 65.29561266303062, 65.97347348928452, 63.447061255574226, 51.71721987426281, 69.96096432209015, 83.59714061021805, 76.95770367980003, 78.28327015042305, 81.0353484749794, 85.21817162632942, 83.86571019887924, 74.4592997431755, 47.65491105616093, 20.810588411986828, 8.373934607952833, 2.0736800646409392, 0.3467493545031175, 0.12949743715580553, 0.13497003412339836, 0.15781500202137977, 0.21648541238391772, 0.21384090272476897, 0.1963517177500762, 0.14135122764855623, 0.19097781158052385, 0.14695058343932033, 0.08405968314036727, 0.18648510187631473, 0.15861154912272468, 0.1399887929437682, 0.101503107289318, 0.1848014211282134, 0.11243440079852007, 0.1101018009649124, 0.08346862930920906, 0.14662052068160847, 0.19841013854602352, 0.10602784808725119, 0.09604668171959929, 0.11688115671859123, 0.16674824844812974, 0.14439600723562762, 0.1468123955419287, 0.10504224628675729, 0.18839187221601605, 0.1431360631249845, 0.11973230997682549, 0.1512643464957364, 0.10863620773307048, 0.07028873966191895, 0.11876847536768764, 0.18567489925771952, 0.1157841066014953, 0.10367558134021237, 0.14225304097635671, 0.11439534049713984, 0.09964522221707739, 0.1267754621221684, 0.11556215991731733, 0.12736572185531259, 0.159593514399603, 0.11813000572146848, 0.19984684739029035, 0.13922960555646569, 0.1137348439078778, 0.1798629923723638, 0.16037305147619918, 0.11201263827388175, 0.1978493420756422, 0.08478062023641542, 0.17327169683994725, 0.13706927304156125, 0.22138055908726528, 0.10170017718337476, 0.2805625170003623, 0.15420806041220203, 0.12219669297337532, 0.1222852237697225, 0.1495618894114159, 0.1721260286285542], [0.04758632720040623, 0.013182170823711203, 0.046376121827051975, 0.053255994062055834, 0.050072633239324205, 0.013825295591232134, 0.017367140644637402, 0.046313944694702514, 0.020895674351777416, 0.02827761505614035, 0.05876568357052747, 0.03138800791930407, 0.08550166123313829, 0.05974429805064574, 0.07983978692209348, 0.018191111958003603, 0.014621183108829428, 0.02201957908255281, 0.01747287627949845, 0.020391615071275737, 0.0064857417237362824, 0.04353447919129394, 0.053645484294975176, 0.049946445869863965, 0.026269094414601568, 0.049677432180033065, 0.01614343374967575, 0.04559057706501335, 0.011519465952005703, 0.028232251279405318, 0.022133585953270085, 0.035350634934729896, 0.03786207380471751, 0.060585433384403586, 0.046599530542152934, 0.05098747125884984, 0.03328631035401486, 0.03444871028477792, 0.04130748697207309, 0.05489310133270919, 0.033996723796008155, 0.07923573808511719, 0.08433837443590164, 0.04401167272590101, 0.04386735468870029, 0.04142200778005645, 0.03427708492381498, 0.028628472791751847, 0.060319859549053945, 0.04896349724731408, 0.03477840196865145, 0.03372750972630456, 1.669070532079786, 6.655607912689447, 19.138457737863064, 28.516909293830395, 33.21673460304737, 40.72300761938095, 48.93388822674751, 52.847879603505135, 53.82215112447739, 61.56711973249912, 67.02673137187958, 66.21662244200706, 66.88623011112213, 66.5591436624527, 67.04607993364334, 59.66013886034489, 60.51197335124016, 52.435043156147, 58.925835862755775, 37.91243143379688, 39.23460468649864, 23.331768326461315, 25.978723391890526, 29.536514282226562, 14.425128903239965, 14.164037313312292, 18.603283055126667, 13.709295764565468, 18.05859748274088, 32.38218538463116, 24.830782189965248, 15.473666489124298, 42.44819104671478, 49.98969577252865, 12.613946590572596, 30.402508713304996, 38.93644608557224, 28.439173065125942, 46.51364229619503, 54.23709265887737, 21.167451962828636, 24.429537020623684, 22.187514826655388, 32.73051269352436, 31.889078244566917, 37.81065009534359, 32.336682826280594, 27.483220361173153, 30.505025312304497, 32.494245171546936, 35.486702397465706, 33.734396025538445, 45.517715737223625, 56.22126638889313, 57.8290893137455, 67.1526338160038, 60.72013758122921, 47.77344949543476, 29.517359510064125, 20.111072547733784, 12.605128213763237, 4.025159636512399, 0.9268291667103767, 0.18641808594111353, 0.031315091910073534, 0.0928306886635255, 0.038449201674666256, 0.03420380897296127, 0.0883932838041801, 0.030632330890512094, 0.1009250855713617, 0.08317027110024355, 0.06448543426813558, 0.07908445128123276, 0.0713157607242465, 0.028900811303174123, 0.11942013297812082, 0.021577628285740502, 0.04020432155812159, 0.011702686442731647, 0.022682953349431045, 0.02672971022548154, 0.025137669872492552, 0.011375981903256616, 0.03389447068911977, 0.026505397945584264, 0.07830762304365635, 0.0230840377844288, 0.04284305359760765, 0.025774087480385788, 0.034028498848783784, 0.011556229164852994, 0.01564397392940009, 0.04039607767481357, 0.04653169453376904, 0.028031882538925856, 0.06133390786999371, 0.00870349142132909, 0.012646050763578387, 0.055783541247365065, 0.031049095050548203, 0.01565798753290437, 0.03168459610606078, 0.05293213565892074, 0.015830468219064642, 0.0060083941934863105, 0.04667788278311491, 0.031600002403138205, 0.05429067779914476, 0.06173438188852742, 0.04514329950325191, 0.009949230825441191, 0.09376376867294312, 0.02221931699750712, 0.02819273191562388, 0.04759709947393276, 0.06047669019608293, 0.04394011484691873, 0.033959816792048514, 0.06401698323315941, 0.01620689479750581, 0.021608915376418736, 0.027436642994871363, 0.028410923332558013, 0.010085357407660922, 0.06661774328676984, 0.0573216794145992, 0.02918639343988616, 0.03526131375110708, 0.008044924416026333, 0.037125633243704215, 0.07477341932826675, 0.023859570974309463, 0.008778699739195872, 0.07701785943936557, 0.023592132492922246, 0.07751948447548784, 0.07643459815881215, 0.04954938944138121, 0.007415194950226578, 0.02329625862330431, 0.026767630261019804, 0.02796516531816451, 0.048929317636066116, 0.06330532298306935, 0.09215491867507808, 0.032119498355314136, 0.034812811645679176, 0.01393646745782462, 0.06396814991603605, 0.017500914618722163, 0.025286752497777343, 0.011847997102449881, 0.03052766580367461, 0.020077313674846664, 0.039690488192718476, 0.021526151067519095, 0.047397350426763296, 0.06346285124891438, 0.041273166352766566, 0.03843858154141344, 0.11014723524567671, 0.023874098515079822, 0.08833713291096501, 0.04895067664620001, 0.046520981632056646, 0.021933404605078977, 0.07173589794547297, 0.017323246320302133, 0.05086932134872768, 0.062133694445947185, 0.013972935666970443, 0.036135378177277744, 0.0748658983502537, 0.033697623439366, 0.21833178674569353, 1.8936982098966837, 8.221819270402193, 22.776806205511093, 32.18057960271835, 36.7388492077589, 45.14403618872166, 55.468070805072784, 60.70487380027771, 61.54614485800266, 68.53853344917297, 73.75893652439117, 74.61353346705437, 74.51175212860107, 77.55978137254715, 76.66690528392792, 68.50488245487213, 69.64988261461258, 63.01307134330273, 64.62712213397026, 47.64890357851982, 48.044447153806686, 33.17513443529606, 36.312740072607994, 42.72229693830013, 23.226741962134838, 26.391164660453796, 33.51947955787182, 24.439158104360104, 24.749031476676464, 30.29615242034197, 26.927146799862385, 13.428373038768768, 41.02692291140556, 39.04044650495052, 15.136954206973314, 29.943683333694935, 40.719109028577805, 37.10656687617302, 53.01978997886181, 51.233635023236275, 16.547158285975456, 30.106850378215313, 27.14430134743452, 38.158361837267876, 44.76499892771244, 48.220605701208115, 44.67487536370754, 34.29789058864117, 44.105038940906525, 46.8147761374712, 49.48951721191406, 45.275235548615456, 54.346633180975914, 64.80622172355652, 67.91028276085854, 76.13959237933159, 72.02218651771545, 57.82562009990215, 42.53566235303879, 28.934047110378742, 19.009384363889694, 7.412163466215134, 1.7252672603353858, 0.26166509196627885, 0.10908764132182114, 0.028411773091647774, 0.024419764449703507, 0.041784858622122556, 0.05599922049441375, 0.025526130375510547, 0.079904917802196, 0.03226893721148372, 0.04704718659922946, 0.014718314469064353, 0.03620036433858331, 0.08151358968461864, 0.03947572549805045, 0.06459745403844863, 0.06563338829437271, 0.01879963409010088, 0.04041970023536123, 0.03820059333520476, 0.06206126454344485, 0.023434819449903443, 0.028088662402296904, 0.051874348864657804, 0.09954990819096565, 0.011012854611180956, 0.020122252572036814, 0.02009778025239939, 0.04745917503896635, 0.026990055630449206, 0.04403881306643598, 0.029488683176168706, 0.06816203385824338, 0.021438542389660142, 0.08422633240115829, 0.008363427295989823, 0.02831340883858502, 0.019882939632225316, 0.02758900220214855, 0.034427351274644025, 0.03714819082233589, 0.05551766684220638, 0.05842428079631645, 0.005860699848199147, 0.04981413949280977, 0.034068871682393365, 0.0374008030485129, 0.02624256263516145, 0.01771578121406492, 0.010885934370890027, 0.019634168020274956, 0.024064841600193176, 0.028456585823732894, 0.049762675262172706, 0.04772719054017216, 0.015273343524313532, 0.029916746534581762, 0.039248350003617816, 0.04998446238460019, 0.0693896648590453, 0.04158204079431016, 0.05830769310705364, 0.15520074230153114, 0.16649033728754148, 0.15763148374389857, 0.11391316715162247, 0.17914156545884907, 0.1643933544983156, 0.10022017144365236, 0.18646438111318275, 0.12078436368028633, 0.08609721247921698, 0.20916292327456176, 0.10921833352767862, 0.16642709146253765, 0.18944380717584863, 0.2128396267653443, 0.17653679038630798, 0.07173425779910758, 0.1677565451245755, 0.11841726140119135, 0.15644192491890863, 0.15302406769478694, 0.16655156447086483, 0.11326516832923517, 0.08803403237834573, 0.11688234415487386, 0.17640770121943206, 0.12002222996670753, 0.15645157283870503, 0.08547787540010177, 0.14823491452261806, 0.1140400892472826, 0.2044155084877275, 0.17387292551575229, 0.2096946572419256, 0.12573589134262875, 0.21401639096438885, 0.16449767077574506, 0.19740357849514112, 0.11212583805900067, 0.20189977629343048, 0.17109690728830174, 0.14683311630506068, 0.1721579855075106, 0.12152035153121687, 0.1686078033526428, 0.10122837164090015, 0.18079734145430848, 0.2197558048646897, 0.12884878524346277, 0.12902403599582613, 0.07672378342249431, 0.3533562202937901, 2.654166603460908, 11.224716436117887, 28.545987233519554, 41.74023203551769, 49.32798407971859, 57.23506338894367, 65.4564580321312, 70.17481684684753, 74.70415860414505, 79.70982000231743, 87.17682212591171, 84.90682393312454, 86.28162056207657, 86.0301424562931, 84.38706502318382, 76.36432752013206, 80.32207354903221, 72.94639572501183, 79.28014665842056, 55.84012024104595, 56.32201798260212, 37.62262478470802, 40.350616201758385, 45.26120290160179, 26.43086113035679, 25.99711250513792, 30.691604800522327, 24.797784760594368, 32.8578020632267, 45.57923063635826, 40.55982917547226, 26.12603008747101, 54.02150362730026, 59.87228907644749, 22.845390625298023, 43.14109906554222, 51.827064380049706, 45.966308265924454, 64.4571116566658, 66.71989783644676, 33.351308181881905, 37.435275837779045, 37.17467822134495, 48.12128663063049, 48.394982144236565, 55.28743229806423, 48.88925962150097, 41.97903782129288, 47.31842391192913, 49.57561299204826, 52.97063201665878, 52.2750261425972, 64.08655554056168, 76.2246698141098, 79.05494794249535, 87.23895639181137, 85.21538257598877, 66.36635720729828, 48.718781769275665, 31.958010345697403, 20.615354888141155, 9.175173863768578, 2.1364484215155244, 0.4075762233696878, 0.17483417002949864, 0.174704086384736, 0.18041240429738536, 0.14063979004276916, 0.17889628565171733, 0.15300162514904514, 0.1788149611093104, 0.15913422888843343, 0.16113456920720637, 0.1615669296006672, 0.2122904226416722, 0.14890342630678788, 0.2651065494865179, 0.15702730132034048, 0.17676267045317218, 0.09375028384965844, 0.1169591787038371, 0.10234023502562195, 0.08786700462223962, 0.06275257139350288, 0.15650681831175461, 0.14918967266567051, 0.22662809235043824, 0.13720667426241562, 0.07098522299202159, 0.056619218084961176, 0.09141550210188143, 0.08857270542648621, 0.1425946960807778, 0.20974656305043027, 0.15285595640307292, 0.13848104572389275, 0.17134735244326293, 0.16551426466321573, 0.15183517680270597, 0.14507709100143984, 0.22665384487481788, 0.17007341142743826, 0.11252767391852103, 0.16419389488874003, 0.1890885113971308, 0.134138131106738, 0.11127874327939935, 0.07225956476759166, 0.15511055651586503, 0.18600775249069557, 0.12045289084198885, 0.05188328432268463, 0.32931069494225085, 0.13536353566450998, 0.1759081764612347, 0.18412342469673604, 0.17419420124497265, 0.09599552548024803, 0.11379294664948247, 0.18095043167704716, 0.11149717218359001, 0.11267196969129145, 0.14358017913764343, 0.11960057134274393], [0.09743132148287259, 0.043588296030065976, 0.025393894502485637, 0.031239511590683833, 0.020068879166501574, 0.035994307036162354, 0.06363597945892252, 0.017285329995502252, 0.019021797852474265, 0.040957078235805966, 0.0753641985647846, 0.031179998768493533, 0.010804635803651763, 0.029672934324480593, 0.03557734249625355, 0.07717880158452317, 0.0373795998893911, 0.012530436215456575, 0.03242574188334402, 0.04219979338813573, 0.026104319076694082, 0.034468848461983725, 0.02631095896504121, 0.019572462151700165, 0.06684879612294026, 0.046742898630327545, 0.04164900477917399, 0.08046289411140606, 0.008880204204615438, 0.04684833184001036, 0.06010944955050945, 0.021572911937255412, 0.014574581800843589, 0.11468765020254068, 0.07342564946156926, 0.03580366414098535, 0.02381102338404162, 0.0770931874285452, 0.0301372608737438, 0.041123682967736386, 0.04640611572540365, 0.08194992056814954, 0.05205467590712942, 0.027577330074564088, 0.04360729501058813, 0.0535714476427529, 0.05771715135779232, 0.00928494371692068, 0.05317996103258338, 0.24816829041810706, 1.3302487693727016, 5.94328198581934, 12.241223640739918, 26.19133908301592, 41.45804397761822, 52.72579215466976, 54.721087887883186, 59.507748037576675, 65.20421236753464, 62.72880859673023, 59.54557120800018, 64.3053250014782, 57.09287881851196, 62.10915684700012, 57.83056743443012, 50.38647048175335, 48.34980256855488, 47.425745353102684, 38.81613314151764, 30.59351686388254, 26.493601463735104, 26.0960515961051, 22.60529860854149, 17.87306483834982, 15.709449537098408, 15.756821595132351, 24.606119245290756, 24.63566455990076, 17.705216445028782, 40.62927804887295, 62.086323872208595, 76.5260848402977, 66.5468019247055, 57.85163350403309, 86.02201849222183, 90.94471514225006, 63.178031891584396, 61.82957544922829, 31.880163922905922, 20.43837558478117, 13.28682778403163, 35.63721612095833, 61.788594648242, 40.116522163152695, 41.71332187950611, 21.652024760842323, 17.983999885618687, 16.734286844730377, 39.345338344573975, 35.619873851537704, 19.037432558834553, 25.222788155078888, 14.161999672651291, 17.139392606914043, 25.561490580439568, 32.35296495258808, 45.03750130534172, 52.686863243579865, 59.57650534808636, 65.83722040057182, 66.84443235397339, 60.94079174101353, 50.55896982550621, 39.56124275922775, 25.397692769765854, 11.784872878342867, 4.169876296073198, 1.0413414845243096, 0.14673166471766308, 0.09691682760603726, 0.01605937439308036, 0.052552174602169544, 0.07543485102360137, 0.03868501167744398, 0.013574871773016639, 0.06738447089446709, 0.04706785912276246, 0.01978988544578897, 0.04311188175051939, 0.0355152729753172, 0.05797992358566262, 0.03873151836160105, 0.1780634475289844, 0.055767841113265604, 0.02764315857348265, 0.023942005027492996, 0.05255726944596972, 0.01123562693464919, 0.03452592332905624, 0.03729800817382056, 0.03408962213143241, 0.01903545893583214, 0.06072093470720574, 0.0711670788587071, 0.04974584706360474, 0.05244246291113086, 0.03427003823162522, 0.05177799583179876, 0.05804355903819669, 0.026569135443423875, 0.10465166880749166, 0.04641150371753611, 0.09016659372719005, 0.02637308785779169, 0.07133942781365477, 0.04366221393865999, 0.07661403462407179, 0.023456300914403982, 0.023566990385006648, 0.04872784309554845, 0.06661450752289966, 0.011362598197592888, 0.0333510144992033, 0.08020234090508893, 0.032584160726401024, 0.0538739247713238, 0.04458849216462113, 0.03193960175849497, 0.014373055309988558, 0.049178972403751686, 0.07283698534592986, 0.034585643952596, 0.08108365611406043, 0.03536425705533475, 0.019805164411081932, 0.03660817819763906, 0.03565803992387373, 0.06735745671903715, 0.0809608974668663, 0.03746278722246643, 0.02813822116877418, 0.05225751599937212, 0.022288717082119547, 0.02201463266828796, 0.055756864749128, 0.008892468194972025, 0.03853122383588925, 0.0617426197277382, 0.041164868453051895, 0.06092623130825814, 0.01036703306454001, 0.05432296122307889, 0.04994888382498175, 0.012801098400814226, 0.027002874376194086, 0.06748509869794361, 0.014494051356450655, 0.034273318524356, 0.006286844754868071, 0.026835972785193007, 0.054138021732796915, 0.021202912357694004, 0.018854157824534923, 0.03141769011563156, 0.01871222393674543, 0.054247121152002364, 0.05809691203467082, 0.07350501473410986, 0.049283043772447854, 0.10963012158754282, 0.03814055729890242, 0.00288068888039561, 0.06363242457155138, 0.054554581802221946, 0.043868646025657654, 0.013595156524388585, 0.028666665566561278, 0.04278062784578651, 0.04549746350676287, 0.0033985998834396014, 0.030419731556321494, 0.05794840457383543, 0.04637703095795587, 0.020476993595366366, 0.029570835213235114, 0.1485580307780765, 1.9208757765591145, 7.410606499761343, 14.400709513574839, 31.643883101642132, 48.08540515601635, 60.6890020519495, 63.31956289708614, 67.96203598380089, 74.21273857355118, 72.27629408240318, 69.51945841312408, 72.60297775268555, 65.20696341991425, 71.34785190224648, 66.91624090075493, 59.617630541324615, 57.73300766944885, 57.197308614850044, 48.549755439162254, 43.79960373044014, 35.19309975206852, 36.57329969108105, 36.89723610877991, 28.11790220439434, 30.062012784183025, 22.27187979966402, 18.441193252801895, 18.629214763641357, 18.41200891882181, 29.12199642509222, 63.42852585017681, 90.87542206048965, 69.64916065335274, 52.46744401752949, 77.54810079932213, 96.76596477627754, 62.749768272042274, 58.55579271912575, 43.90472128987312, 29.193271100521088, 28.108997382223606, 50.95209673047066, 61.8712592124939, 48.726525753736496, 48.88455167412758, 38.71136136353016, 29.00639522820711, 32.0139167457819, 43.01229737699032, 47.27327473461628, 26.986993588507175, 40.305417627096176, 26.80347863584757, 29.65297993272543, 41.27822242677212, 44.69354376196861, 53.903554156422615, 59.87619526684284, 67.59800031781197, 76.3087061047554, 76.74745336174965, 72.08093896508217, 61.40676073729992, 50.08198522031307, 34.03052173554897, 18.43927625566721, 6.773592531681061, 2.078994079492986, 0.4802594950888306, 0.05086637131171301, 0.012933082871313673, 0.07831974973669276, 0.022889470783411525, 0.044056286933482625, 0.02949971520138206, 0.06764484598534182, 0.05150427321495954, 0.019763752570725046, 0.03042350166651886, 0.06583857728401199, 0.003114853634542669, 0.008024701819522306, 0.05156081744644325, 0.014268660179368453, 0.039990404911804944, 0.044266040131333284, 0.021794212952954695, 0.028067629937140737, 0.025594790167815518, 0.038543164992006496, 0.016374709230149165, 0.025314412341685966, 0.08178494113963097, 0.052377135361894034, 0.025759075688256416, 0.04258428525645286, 0.05919487499340903, 0.12857389374403283, 0.08561728784115985, 0.04447991224878933, 0.0992542588210199, 0.03043233693460934, 0.02384190785960527, 0.018470675277058035, 0.02238361365016317, 0.0525204477889929, 0.04171505592239555, 0.0309101297534653, 0.050741289742290974, 0.02299408763065003, 0.040607630580780096, 0.012139309546910226, 0.02257523618027335, 0.011966006004513474, 0.04304846894228831, 0.05180462037969846, 0.013264178141980665, 0.07030040622339584, 0.02657422472111648, 0.033516658149892464, 0.08960107719758525, 0.05061133226263337, 0.045559325226349756, 0.010161374666495249, 0.052338647583383135, 0.07951186897116713, 0.20729492272948846, 0.1314460943103768, 0.22579158801818267, 0.1212480130197946, 0.10930624091997743, 0.15445960394572467, 0.10557677072938532, 0.09264207183150575, 0.10338437743484974, 0.13503886089893058, 0.14736875396920368, 0.18693750025704503, 0.1826868939679116, 0.10472018388099968, 0.26749267301056534, 0.1831601170124486, 0.13686589489225298, 0.09898043601424433, 0.14417478785617277, 0.2683787082787603, 0.09646511200116947, 0.19654761505080387, 0.1571900097769685, 0.1369447258184664, 0.13635670737130567, 0.16812549642054364, 0.15480589005164802, 0.19519929599482566, 0.06435411865822971, 0.12965407484443858, 0.2145967207616195, 0.1900957096950151, 0.10948123934213072, 0.33277967129833996, 0.10645601534633897, 0.12574832973768935, 0.2294056987739168, 0.20666089112637565, 0.19903646665625274, 0.10861474482226186, 0.1800182051374577, 0.19871841184794903, 0.10722004895797, 0.11202009685803205, 0.15848345443373546, 0.20533249131403863, 0.1572580201900564, 0.09205898124491796, 0.2611689217155799, 0.5414275440853089, 3.1534631364047527, 10.223122481256723, 21.189908757805824, 38.57223562896252, 57.80404105782509, 71.25369295477867, 73.45663234591484, 79.55011457204819, 85.04749238491058, 81.41437813639641, 78.81534039974213, 82.06493362784386, 73.87641102075577, 80.94508811831474, 74.98241007328033, 68.11287268996239, 66.48481965065002, 66.94204151630402, 54.68460224568844, 47.46528223156929, 42.49835215508938, 41.69910304248333, 35.48831731081009, 28.29466301947832, 26.146493889391422, 27.870719768106937, 38.676851615309715, 39.50386963784695, 27.842928059399128, 54.93386507034302, 77.25890591740608, 92.03519582748413, 80.28941810131073, 76.50416761636734, 97.87279218435287, 103.60810562968254, 78.69486406445503, 77.23403245210648, 45.68558692932129, 31.60584144294262, 24.459927789866924, 50.6866467744112, 76.73896461725235, 51.5738345682621, 57.86113299429417, 35.392083674669266, 28.917548395693302, 30.84859147667885, 53.9339829236269, 50.189143270254135, 29.574639536440372, 40.32306768000126, 25.551145635545254, 30.98518654704094, 41.282774582505226, 48.85014832019806, 61.74103640019894, 72.37556755542755, 80.55801048874855, 86.80469289422035, 88.2572029531002, 80.69127693772316, 71.04281187057495, 55.95818750560284, 39.12452079355717, 20.66639754921198, 7.41475397720933, 2.2884295787662268, 0.5930522864218801, 0.16759814112447202, 0.16221178171690553, 0.13996277324622497, 0.13276091282023117, 0.16255086899036542, 0.077066054509487, 0.17288695264142007, 0.36738260358106345, 0.12521116324933246, 0.1723505579866469, 0.12497075193095952, 0.19962276332080364, 0.09944967372575775, 0.2683449554024264, 0.26040819066111, 0.0952690742269624, 0.1652475367882289, 0.1562083265162073, 0.19615270342910662, 0.09482037916313857, 0.1491839432856068, 0.2043883310398087, 0.12329309742199257, 0.13874486437998712, 0.24694088206160814, 0.15390104876132682, 0.16701600048691034, 0.14973299897974357, 0.14852027030428872, 0.22895750094903633, 0.09523619708488695, 0.2403591453912668, 0.11582743318285793, 0.18350748665397987, 0.12770523957442492, 0.1264247825019993, 0.14238533622119576, 0.17369638342643157, 0.14922443486284465, 0.10463132653967477, 0.09383339696796611, 0.1428793097147718, 0.15357701224274933, 0.09094918103073724, 0.1264469578745775, 0.14733871183125302, 0.12454760901164263, 0.22398245462682098, 0.10811278581968509, 0.11061095137847587, 0.10478065407369286, 0.18161143292672932, 0.14887259749229997, 0.24642462929477915, 0.16447936941403896, 0.13336270552827045, 0.21775536064524204], [0.01302105798458797, 0.06818993861088529, 0.06541285911225714, 0.07220981860882603, 0.020710937096737325, 0.018607716556289233, 0.060093626962043345, 0.026441090849402826, 0.017247103824047372, 0.004729255360871321, 0.012305133168410975, 0.07417151529807597, 0.03178189537720755, 0.006495739844467607, 0.009592347778379917, 0.0174202134803636, 0.029844047603546642, 0.021691553520213347, 0.0515765212912811, 0.01927535075083142, 0.03596095120883547, 0.03773732249101158, 0.028574741299962625, 0.03163516164931934, 0.0037506786839003325, 0.032110878310049884, 0.020939290370733943, 0.024108997531584464, 0.011883940242114477, 0.0449943764397176, 0.10085236994200386, 0.020417089290276635, 0.07708641904173419, 0.04893770761555061, 0.033699193081702106, 0.08140988196828403, 0.030156029788486194, 0.05385453987400979, 0.05399543289968278, 0.039589878942933865, 0.0807737500872463, 0.08525655211997218, 0.03588252846384421, 0.053745848636026494, 0.07590031862491742, 0.03105456467892509, 0.09943490498699248, 0.08862018803483807, 0.9877694060560316, 4.876543851569295, 18.16627610474825, 39.37908053398132, 54.371776431798935, 58.5290801525116, 60.613234117627144, 60.09194388985634, 58.50027769804001, 61.46105982363224, 54.970563501119614, 55.97488380968571, 50.40129728615284, 53.78582887351513, 36.530635580420494, 38.842317536473274, 32.964344546198845, 29.188867136836052, 29.98226646333933, 25.964419059455395, 20.92427261173725, 13.507944568991661, 14.375388622283936, 14.671520981937647, 19.823099300265312, 34.20980751514435, 30.199702195823193, 54.42251890897751, 63.40754717588425, 77.34431013464928, 55.703768357634544, 90.2401265501976, 67.94679120182991, 28.40334478765726, 28.384913876652718, 35.927672535181046, 41.352808624506, 21.381969451904297, 36.062515899538994, 31.853394359350204, 30.444566756486893, 45.974808409810066, 38.16125728189945, 21.652984209358692, 26.378517039120197, 30.6461763381958, 27.865141667425632, 26.398553363978863, 33.366400972008705, 19.51812006533146, 56.27579726278782, 27.242355085909367, 27.892807982861996, 24.65995855629444, 20.39220616221428, 20.952307507395744, 12.40818003192544, 19.960684217512608, 20.383419133722782, 34.88658919930458, 38.30115057528019, 41.53295315802097, 43.11331495642662, 57.50224985182285, 62.09203876554966, 61.09146125614643, 57.46829107403755, 57.11920380592346, 34.76619265973568, 25.46494536101818, 10.624538641422987, 3.4104856196790934, 0.33364255155902356, 0.17958867974812165, 0.10903281145147048, 0.06373274809448048, 0.07653295499039814, 0.010137782719539246, 0.023417735210387036, 0.05171505057660397, 0.04460856354853604, 0.041844015213428065, 0.04619878935045563, 0.03944707859773189, 0.024836983175191563, 0.03838148440991063, 0.02326072644791566, 0.09738926397403702, 0.06150967070425395, 0.04157973271503579, 0.07704734496655874, 0.06906723880092613, 0.0485401539481245, 0.05269891204079613, 0.051486090596881695, 0.030344429542310536, 0.06015501741785556, 0.056668448451091535, 0.025248954916605726, 0.08388563466724008, 0.05194302349991631, 0.012266731664567487, 0.07882710415287875, 0.03873165936965961, 0.02390087891399162, 0.05909575746045448, 0.03437621358898468, 0.049207385527552105, 0.025766599210328422, 0.07768063442199491, 0.03057566977076931, 0.018425382004352286, 0.01792819872207474, 0.0504371910210466, 0.0027149134984938428, 0.029292722792888526, 0.06601336048333906, 0.060461368557298556, 0.06312443932984024, 0.02308685794560006, 0.03290847183961887, 0.08485091646434739, 0.07177025196142495, 0.019501371825754177, 0.10133151532500051, 0.022645120516244788, 0.10196554692811333, 0.020286033432057593, 0.042666058798204176, 0.03672925216960721, 0.022209093913261313, 0.02133066565875197, 0.056896929745562375, 0.10685738365282305, 0.06231182473129593, 0.01569971293065464, 0.04684627980168443, 0.03520169702824205, 0.014157387195155025, 0.073286719416501, 0.07761620116070844, 0.04887238006631378, 0.023781903364579193, 0.011649120078800479, 0.09179617933114059, 0.021178640417929273, 0.06473986475612037, 0.03869730906444602, 0.07127537304768339, 0.0259235857083695, 0.08059561980189756, 0.07620604636031203, 0.04028000206744764, 0.049706602294463664, 0.04394282368593849, 0.048615500490996055, 0.009126523946179077, 0.018096681087627076, 0.1617454012739472, 0.025642706932558212, 0.06489422405138612, 0.05630059924442321, 0.0354968825558899, 0.032466675038449466, 0.03867760504363105, 0.038416231764131226, 0.0756790695595555, 0.08407369488850236, 0.10110544972121716, 0.12443064653780311, 0.07817738354788162, 0.03878729447023943, 0.058110526733798906, 0.16423100227257237, 0.06973785086302087, 0.05849933790159412, 1.0654234047979116, 6.259778402745724, 24.321499317884445, 46.41152277588844, 62.75204434990883, 66.75134494900703, 69.54619377851486, 66.84531390666962, 66.43741339445114, 68.18205937743187, 63.226198107004166, 62.87956930696964, 57.577953189611435, 60.6504113227129, 46.59968487918377, 50.012821331620216, 40.61758607625961, 38.47777649760246, 40.989905297756195, 36.33311077952385, 29.6915003657341, 24.84934039413929, 29.40816666930914, 22.348658479750156, 27.24000111222267, 34.961513578891754, 22.568472884595394, 45.35748973488808, 69.31863158941269, 73.69136095046997, 38.3793655782938, 78.0369445681572, 77.06659063696861, 37.47383996844292, 40.7618947327137, 47.7456159889698, 53.96273598074913, 31.448450088500977, 36.596486046910286, 36.55867427587509, 35.66457085311413, 38.972927927970886, 35.2702622115612, 29.726802371442318, 44.73539851605892, 35.36879852414131, 36.5029426664114, 26.460184156894684, 35.36203868687153, 24.224292933940887, 54.66851390898228, 35.22670514881611, 28.800697065889835, 34.74015645682812, 20.847341939806938, 30.39729919284582, 21.506351977586746, 30.058678463101387, 33.06796878576279, 47.082893550395966, 47.01075442135334, 49.38489742577076, 50.09280323982239, 66.2022516131401, 69.07020092010498, 69.90076795220375, 67.06101313233376, 67.18945384025574, 44.491994976997375, 35.93467555940151, 16.168706193566322, 5.32609392888844, 0.6599731673486531, 0.23968404333572835, 0.0964134065725375, 0.041233736046706326, 0.050021105926134624, 0.02649747737450525, 0.07448046395438723, 0.038179980183485895, 0.005743321771660703, 0.11809467207058333, 0.031079049986146856, 0.023947406007209793, 0.11532705495483242, 0.0244085895610624, 0.07929533254355192, 0.08110605413094163, 0.05700121262634639, 0.03861283781589009, 0.08612945137429051, 0.008985883250716142, 0.013830837579007493, 0.03931850522349123, 0.0462504947790876, 0.008212528264266439, 0.041270090150646865, 0.08412861381657422, 0.026033033936982974, 0.033296507463091984, 0.11235162906814367, 0.04773003296577372, 0.04793925181729719, 0.0067131148989574285, 0.021078650861454662, 0.024836012817104347, 0.01630422932066722, 0.005734624728575, 0.00315702803163731, 0.06516087029012851, 0.01605061890586512, 0.03696072060847655, 0.01643778436118737, 0.027809961829916574, 0.07558853496448137, 0.04357396515842993, 0.04033703982713632, 0.028468708806030918, 0.11358706746250391, 0.062259503320092335, 0.02185271274356637, 0.11130129714729264, 0.07462625144398771, 0.037165605317568406, 0.055209007623489015, 0.03954115694796201, 0.1125262861023657, 0.03313453002192546, 0.19155450485413894, 0.20581991906510666, 0.1079449120152276, 0.11975621455349028, 0.16750712413340807, 0.22651565697742626, 0.1654940188745968, 0.07806020585121587, 0.13922121928771958, 0.1528405791032128, 0.10439949444844387, 0.2097848875564523, 0.1720356647274457, 0.15271362732164562, 0.06687969173071906, 0.07291935631656088, 0.14837282040389255, 0.1511661900440231, 0.1204333575151395, 0.22233433759538457, 0.18135258666006848, 0.09476697421632707, 0.1389875466702506, 0.13468271907186136, 0.0890541217813734, 0.1731969477259554, 0.1380441730725579, 0.15165075310505927, 0.09894403367070481, 0.10565084448899142, 0.23201765783596784, 0.04761202777444851, 0.1474742725258693, 0.21911193238338456, 0.13255003897938877, 0.1645309486775659, 0.17207909520948306, 0.21254720573779196, 0.15817261330084875, 0.14865450997604057, 0.28227865928784013, 0.2375119848875329, 0.19652825983939692, 0.18175306438934058, 0.14765985397389159, 0.23356031568255275, 0.35971532750409096, 0.1716758418479003, 1.6816001222468913, 9.023998975753784, 29.945623129606247, 56.929719373583794, 73.76815482974052, 77.80931398272514, 80.78782215714455, 77.40568444132805, 77.56627142429352, 79.17062133550644, 71.28379493951797, 72.31154099106789, 67.7671368420124, 71.78041309118271, 53.34621146321297, 56.05477452278137, 50.531216114759445, 45.904447585344315, 44.70669485628605, 40.43085649609566, 33.54005165398121, 24.11976434290409, 27.228407934308052, 27.566451095044613, 29.920854158699512, 47.027222737669945, 41.236964240670204, 72.34719827771187, 77.79438838362694, 92.22686514258385, 72.34073102474213, 106.56945392489433, 79.72595393657684, 42.02516734600067, 44.80927795171738, 50.34883730113506, 53.135011196136475, 31.04689333587885, 47.67224572598934, 47.88302421569824, 43.22618030011654, 63.79597753286362, 51.88435010612011, 34.79610465466976, 39.073607325553894, 42.80863590538502, 41.661127880215645, 39.56962890923023, 45.953943729400635, 28.87358095496893, 68.77630949020386, 37.73650847375393, 43.86995695531368, 34.518442153930664, 29.69461239874363, 32.504071444272995, 22.521815188229084, 32.101509645581245, 35.83807334303856, 53.676516339182854, 54.74795624613762, 57.503177002072334, 61.66393093764782, 75.07477551698685, 80.55611819028854, 78.52908656001091, 75.40842801332474, 76.0465657711029, 53.378144949674606, 37.55397766828537, 18.812636621296406, 5.742866965010762, 0.9228568954858929, 0.6520152068696916, 0.19464413984678686, 0.1395961077651009, 0.16307448386214674, 0.10236721951514482, 0.25240733404643834, 0.11201595567399636, 0.13252833858132362, 0.15771093807416037, 0.1444558540242724, 0.25389721035026014, 0.2343602618202567, 0.15158216381678358, 0.16331051650922745, 0.17618655605474487, 0.12288472324144095, 0.15099318057764322, 0.1610640503349714, 0.1635948332841508, 0.09868637484032661, 0.12142410982050933, 0.10312376485671848, 0.14979729865444824, 0.13038330915151164, 0.1336174996686168, 0.08852416896843351, 0.24080909468466416, 0.21709309774450958, 0.1273842013324611, 0.26133712206501514, 0.13340681878617033, 0.11515895850607194, 0.18445598107064143, 0.13528397743357345, 0.16153409698745236, 0.10767789470264688, 0.25146798288915306, 0.09465067967539653, 0.09639615906053223, 0.0988811811839696, 0.22691494727041572, 0.18109739175997674, 0.09778373772860505, 0.1647228532237932, 0.242555427539628, 0.19291975972009823, 0.12717742414679378, 0.09394542415975593, 0.22870616521686316, 0.24083738535409793, 0.1568160712486133, 0.25977297162171453, 0.18025695404503495, 0.23878831561887637, 0.11823573950096034], [0.014761647544219159, 0.04502305673668161, 0.041259714926127344, 0.06701721911667846, 0.058158194879069924, 0.028271240007597953, 0.016928664954320993, 0.0317545732104918, 0.03517830824421253, 0.01924515647260705, 0.07701495022047311, 0.040947311572381295, 0.025944577355403453, 0.1885985306580551, 0.06412141083274037, 0.013861142251698766, 0.016705391681171022, 0.07082926065777428, 0.032504658156540245, 0.03153631500026677, 0.012873150735686067, 0.019843980589939747, 0.029086993890814483, 0.02848644242476439, 0.06746998857124709, 0.007070880174069316, 0.06740495417034253, 0.02170405314245727, 0.010594937339192256, 0.007206950167528703, 0.009446855292480905, 0.05492164062161464, 0.032307584551745094, 0.015083382477314444, 0.030398648996197153, 0.042159023505519144, 0.03325213816424366, 0.03828769920801278, 0.05165782727999613, 0.06645478992140852, 0.051756069078692235, 0.05951423227088526, 0.008171019017026993, 0.017604885797481984, 0.00456901593679504, 0.2057339486782439, 0.6454374035820365, 2.6233637938275933, 15.113196931779385, 39.37486656010151, 51.428275778889656, 65.84442481398582, 59.37651067972183, 62.58740298449993, 55.05969911813736, 57.29307107627392, 44.75180223584175, 38.36459197103977, 34.963846653699875, 34.10132713615894, 30.936311669647694, 29.206167608499527, 31.383724361658096, 12.670347914099693, 18.995520807802677, 12.641177829355001, 17.875593602657318, 16.102905124425888, 18.835923671722412, 16.855008266866207, 19.784257784485817, 25.71344632655382, 40.278678461909294, 81.23179793357849, 96.24590948224068, 72.02607750892639, 31.657826453447342, 31.41707517206669, 37.911481484770775, 24.090562909841537, 21.75502773374319, 34.52429763972759, 19.225720055401325, 15.917739160358906, 22.933338806033134, 30.495280735194683, 40.495494827628136, 33.33702854812145, 38.70506130158901, 41.19445212185383, 48.30431140959263, 45.20682401955128, 35.56589774787426, 53.33160124719143, 48.95466551184654, 66.42424330115318, 44.78167623281479, 56.84841513633728, 37.884985506534576, 40.959848910570145, 45.358405485749245, 43.656359016895294, 42.47792445123196, 24.954209066927433, 32.07864627242088, 20.304064191877842, 13.101138398051262, 22.86043591797352, 20.957410633563995, 30.792001113295555, 33.057086169719696, 39.00838762521744, 50.65979741513729, 50.68894565105438, 56.36765353381634, 56.50810919702053, 61.53226040303707, 66.49170488119125, 48.70958626270294, 33.58697533607483, 14.303709268569946, 3.7554871570318937, 1.1404134496115148, 0.06780201802030206, 0.05089812410005834, 0.023506592551711947, 0.02178280057705706, 0.01730375937768258, 0.010231953838228947, 0.024462725523335394, 0.04602682631229982, 0.042173057518084534, 0.08632723373011686, 0.10221096774330363, 0.07155465063988231, 0.015090833639987977, 0.031523505531367846, 0.05698054010281339, 0.024240003294835333, 0.0015354584343185707, 0.02902073123550508, 0.04748824125272222, 0.10025534924352542, 0.04600697386194952, 0.022880715296196286, 0.009219080893672071, 0.04350700859504286, 0.05271887952403631, 0.05479895247844979, 0.037985741582815535, 0.002311514258508396, 0.05000851539080031, 0.023138711803767364, 0.043607836778392084, 0.047079492287593894, 0.012746955944749061, 0.045283172075869516, 0.04340558669355232, 0.035018041453440674, 0.023135533556342125, 0.024346417994820513, 0.005477015993164969, 0.01611953844985692, 0.03631149353168439, 0.04226520628435537, 0.055075038835639134, 0.025902349152602255, 0.004957754745191778, 0.08409660498728044, 0.05780246123322286, 0.059886018570978194, 0.01727567465422908, 0.018657097207324114, 0.01361403861665167, 0.009670358631410636, 0.036461292329477146, 0.06767874729121104, 0.03487494424916804, 0.021358113990572747, 0.058637317997636274, 0.08501229647663422, 0.041442431684117764, 0.03709558368427679, 0.029823016993759666, 0.01656278986047255, 0.040083885833155364, 0.05354677494324278, 0.03973009661422111, 0.015786291878612246, 0.029807589598931372, 0.010530868657951942, 0.08427053471677937, 0.011734544987120898, 0.06327810842776671, 0.014284976296039531, 0.04316906051826663, 0.051395719274296425, 0.03432572899328079, 0.01980368011572864, 0.05887484236154705, 0.03794269330683164, 0.0690673798089847, 0.04457108509086538, 0.043209503855905496, 0.03299930700450204, 0.02292548906552838, 0.03871405562676955, 0.04507308862230275, 0.04189076309558004, 0.013285693930811249, 0.04524869189481251, 0.029391632524493616, 0.009431991929886863, 0.04664637861424126, 0.055462232121499255, 0.029500373857445084, 0.010167903710680548, 0.044431557616917416, 0.014660381493740715, 0.03100916750554461, 0.036135908812866546, 0.15928259905194864, 1.1777387280017138, 4.297028873115778, 22.357542403042316, 49.2945496737957, 60.431037694215775, 74.98123973608017, 66.83968260884285, 70.71106687188148, 63.94560590386391, 66.99833929538727, 55.86574986577034, 47.07807540893555, 44.88956764340401, 45.36036238074303, 41.394328996539116, 40.06512612104416, 38.208937123417854, 22.41045456379652, 29.012786485254765, 22.561314068734646, 30.39980135858059, 23.178256563842297, 27.02595479786396, 21.109233386814594, 27.41360429674387, 29.77778233587742, 35.81610672175884, 71.91432550549507, 67.2124046087265, 76.47115498781204, 42.97379024326801, 42.94086501002312, 39.35394108295441, 30.97878009080887, 19.64257288724184, 21.90862499177456, 16.154612749814987, 12.726269513368607, 15.99410556256771, 16.56257215887308, 24.663925543427467, 24.227260574698448, 22.877259515225887, 27.06384066492319, 29.952952936291695, 31.815495193004608, 27.277119420468807, 35.49931012094021, 36.94170892238617, 48.788413032889366, 38.40265452861786, 38.220454305410385, 40.719899386167526, 32.77034215629101, 46.51934579014778, 29.683467596769333, 35.74200689792633, 32.659247517585754, 35.456140637397766, 26.64938360452652, 22.422209233045578, 35.64274102449417, 32.98938140273094, 41.711653769016266, 43.890787437558174, 44.29399520158768, 57.823435217142105, 56.937687546014786, 64.93768706917763, 64.30527940392494, 70.14166742563248, 76.07839286327362, 62.54734933376312, 45.17812795937061, 23.133664056658745, 8.85827086865902, 3.036977299489081, 0.029750282810709905, 0.11728065481293015, 0.02588046878372552, 0.0828363343316596, 0.040597173720016144, 0.03222844563424587, 0.01960245419468265, 0.05618492439680267, 0.033393880949006416, 0.055837432300904766, 0.060467242656159215, 0.006788125156163005, 0.018220851670776028, 0.02726776358031202, 0.05630743442452513, 0.03249751498515252, 0.06724104343447834, 0.03893232125847135, 0.09605622573872097, 0.07405498326988891, 0.01618140759092057, 0.010334856324334396, 0.054928817189647816, 0.010343505127821118, 0.044264388852752745, 0.017389334570907522, 0.029308949851838406, 0.018879444651247468, 0.025059864965442102, 0.03054830121982377, 0.049653802198008634, 0.051015012359130196, 0.019613224612839986, 0.02787394609185867, 0.05162082379683852, 0.03254532042774372, 0.04692653565143701, 0.03344120770634618, 0.012423096613929374, 0.028526099085866008, 0.07205033849459141, 0.08173322086804546, 0.04892270138952881, 0.017409320607839618, 0.07287056752829812, 0.07164799055317417, 0.04085299944563303, 0.05488878203323111, 0.07722589827608317, 0.015093215934030013, 0.022911813139216974, 0.01629607126233168, 0.029471409688994754, 0.15814310550922528, 0.10055399689008482, 0.10188558793743141, 0.2027317980537191, 0.21089824265800416, 0.1585819968022406, 0.09614070440875366, 0.16497171018272638, 0.17350876849377528, 0.15738409623736516, 0.13047707208897918, 0.11414137014071457, 0.16070955607574433, 0.2767479373142123, 0.10306571406545117, 0.16302901989547536, 0.12303993600653484, 0.17950358509551734, 0.08348612172994763, 0.14255086483899504, 0.182749041414354, 0.08711375441635028, 0.10119205835508183, 0.1319163932930678, 0.15038102748803794, 0.11591203059651889, 0.14763865823624656, 0.11342739438987337, 0.09828834619838744, 0.1314523135079071, 0.09202363275107928, 0.11226174014154822, 0.12635297229280695, 0.09718273169710301, 0.11777163002989255, 0.10915131759247743, 0.150810107588768, 0.14711553318193182, 0.27490230510011315, 0.24383579555433244, 0.15011351293651387, 0.15054326097015291, 0.09516898819128983, 0.12953936849953607, 0.0881592846417334, 0.3239598101936281, 1.797955222427845, 6.496509499847889, 27.83500738441944, 59.34135116636753, 71.21923640370369, 85.48602685332298, 77.32115417718887, 78.74201193451881, 72.74627566337585, 75.207988768816, 59.84160952270031, 56.57933257520199, 50.97457252442837, 49.73441407084465, 46.529666036367416, 45.95050111413002, 45.223269537091255, 23.334561176598072, 32.21499815583229, 23.69398009032011, 30.40718626230955, 27.1513594686985, 32.56921894848347, 26.18455834686756, 31.109633669257164, 41.44818350672722, 57.28118151426315, 100.03577291965485, 113.20501506328583, 85.24274870753288, 45.202560648322105, 45.36430276930332, 50.49115106463432, 34.43494163453579, 31.029174886643887, 46.65994584560394, 27.366948500275612, 24.670810773968697, 30.80314591526985, 42.09109380841255, 51.04280926287174, 43.38570334017277, 49.043557941913605, 53.75052496790886, 62.137054949998856, 58.19046512246132, 48.748108595609665, 69.7391626238823, 65.97036525607109, 85.37733748555183, 60.327930226922035, 69.387848675251, 50.61332210898399, 59.002728536725044, 64.84304174780846, 57.40061290562153, 60.80608896911144, 36.10660493373871, 46.77072890102863, 30.38299486041069, 23.13116569072008, 36.4670991897583, 31.80020861327648, 44.3875727802515, 48.31962838768959, 54.99903917312622, 69.1022028028965, 67.10115417838097, 74.62116345763206, 73.51614475250244, 80.71723714470863, 84.82537150382996, 71.77548855543137, 50.76038181781769, 25.525542609393597, 9.579134937375784, 2.7550067799165845, 0.14055046514840797, 0.18394649669062346, 0.12047905896906741, 0.20219740719767287, 0.1126703221234493, 0.13848839298589155, 0.0812867002969142, 0.191594862844795, 0.1055439306946937, 0.12960114487214014, 0.1600785821210593, 0.311190506326966, 0.09293502720538527, 0.20213582378346473, 0.25670873292256147, 0.11127511417726055, 0.22108990437118337, 0.12790955282980576, 0.16332512197550386, 0.1468358325655572, 0.13218141422839835, 0.12648615811485797, 0.1678807954885997, 0.12811520195100456, 0.17613653530133888, 0.25653367512859404, 0.11322224250761792, 0.10340667897253297, 0.09408477722899988, 0.14207170461304486, 0.15293168515199795, 0.1908963089226745, 0.17754093103576452, 0.14379134983755648, 0.14887212251778692, 0.14299921109341085, 0.148036360333208, 0.10415454860776663, 0.1798735753982328, 0.11882375794812106, 0.39157323364634067, 0.16593115869909525, 0.1500072967610322, 0.12501330667873845, 0.20533706294372678, 0.14912470505805686, 0.18286201113369316, 0.1267272818950005, 0.17493729887064546, 0.16024782147724181, 0.0699375628028065, 0.10635792568791658, 0.07995950276381336], [0.02082907401927514, 0.027200482327316422, 0.036006519076181576, 0.02566038860095432, 0.04669071451644413, 0.042583776885294355, 0.05794024094939232, 0.09770431308425032, 0.05556818483455572, 0.02344427255593473, 0.015791629775776528, 0.016350934529327787, 0.05011603032471612, 0.01122435742217931, 0.10524416982661933, 0.05074523425719235, 0.027329899894539267, 0.026152246973651927, 0.042712888316600583, 0.02089385608996963, 0.019212390652683098, 0.04937040197546594, 0.043197236154810525, 0.028436037609935738, 0.0457871200342197, 0.022480942607217003, 0.03032668108062353, 0.0565253735112492, 0.07655756460735574, 0.01411142227880191, 0.05694504317943938, 0.030121338095341343, 0.04112697068194393, 0.050578944938024506, 0.04783225267601665, 0.027937249433307443, 0.08911407247069292, 0.02988315507536754, 0.04835509571421426, 0.033124154797405936, 0.08070398078416474, 0.0738791016920004, 0.02044341883447487, 0.056954631727421656, 0.41643515112809837, 3.8623711466789246, 19.643484838306904, 39.86727453768253, 56.05516970157623, 67.72032335400581, 70.36976158618927, 64.68897521495819, 58.764355927705765, 47.56623521447182, 55.27768202126026, 33.167508244514465, 49.626807644963264, 39.9762336909771, 25.31194467097521, 20.476662330329418, 18.268264532089233, 14.906939249485731, 14.976760502904654, 19.693721942603588, 13.13749199733138, 17.658587247133255, 16.917345821857452, 16.529508233070374, 26.54925137758255, 41.44483208656311, 44.58756744861603, 35.36109633743763, 42.55202807486057, 36.921262219548225, 28.41719314455986, 19.503152668476105, 17.792712450027466, 12.981953043490648, 4.5033487770706415, 1.8226946261711419, 2.8278063610196114, 2.329010688699782, 2.8802292980253696, 3.324108417145908, 4.387752329930663, 6.200047032907605, 3.3211450511589646, 5.907597150653601, 9.87271098420024, 6.616994384676218, 8.892407286912203, 14.12420880049467, 29.39529486000538, 28.853453435003757, 33.03509674966335, 24.234761372208595, 36.36706195771694, 37.197271808981895, 28.73430322855711, 46.50150194764137, 36.00253611803055, 69.2353780567646, 44.934192448854446, 42.987530305981636, 47.84615859389305, 42.5527386367321, 35.712151899933815, 18.03037829697132, 15.45327203348279, 12.818749900907278, 14.377842340618372, 31.12169422209263, 30.364786237478256, 33.6995404958725, 33.20757709443569, 49.447347074747086, 50.92116259038448, 60.6284599006176, 61.87789745628834, 59.643389359116554, 54.7751247882843, 45.503018125891685, 23.68381753563881, 13.831125777214766, 3.59188218601048, 0.9741833538282663, 0.18576607952127233, 0.12296294560655951, 0.04491333762416616, 0.04097609577002004, 0.029136626872059423, 0.07918910894659348, 0.04609228373738006, 0.020999382068112027, 0.03192679971107282, 0.027350206910341512, 0.04148726482526399, 0.023110905385692604, 0.06188074083183892, 0.04327925089455675, 0.028715344888041727, 0.036743111777468584, 0.019588596442190465, 0.039743804081808776, 0.049814325029728934, 0.05749500800448004, 0.012924119582748972, 0.06897402505273931, 0.02447946651955135, 0.01618518141185632, 0.04353690230345819, 0.08231239291490056, 0.024932846390584018, 0.03596933376684319, 0.057065530854742974, 0.028868360896012746, 0.02384317878750153, 0.07786047164699994, 0.06420928111765534, 0.045959943963680416, 0.05573724607529584, 0.042602976245689206, 0.08079478255240247, 0.044138053053757176, 0.040375301250605844, 0.019438513772911392, 0.04071467054018285, 0.02666714532097103, 0.05404505289334338, 0.03327483304019552, 0.04837815424252767, 0.030073449161136523, 0.010850404978555162, 0.01882679669506615, 0.02291210628754925, 0.07091287843650207, 0.05483301334606949, 0.05084082658868283, 0.08495965594192967, 0.00931370193939074, 0.014015977449162165, 0.03580187556508463, 0.07565975145553239, 0.06627987313549966, 0.040271849575219676, 0.02925055396190146, 0.005028901196055813, 0.03180749947205186, 0.040421195662929676, 0.02272801284561865, 0.03613622422562912, 0.07447558804415166, 0.0325013481779024, 0.03607713442761451, 0.04385638574603945, 0.04049544753797818, 0.04687312328314874, 0.01791915750800399, 0.016265552294498775, 0.03585588536225259, 0.056772612588247284, 0.08428139975876547, 0.057105673622572795, 0.06522575626149774, 0.042156682029599324, 0.02341855528356973, 0.01315516406975803, 0.05881185999896843, 0.027014121624233667, 0.05693654929928016, 0.03978448119596578, 0.06974384741624817, 0.027051160359405912, 0.10387755683041178, 0.030591258582717273, 0.0012302037021072465, 0.01353259533061646, 0.07131495920475572, 0.022864879720145836, 0.04952341798343696, 0.492422315874137, 5.8864265866577625, 25.03049947321415, 50.636451467871666, 66.20114967226982, 76.60510540008545, 77.43749633431435, 71.26162692904472, 67.22877413034439, 56.34094476699829, 62.79354192316532, 43.8531656563282, 55.93346603214741, 52.113671600818634, 34.680051282048225, 30.200954228639603, 27.196003273129463, 23.70236624032259, 23.94181039184332, 22.817515321075916, 21.287012547254562, 25.20864151418209, 26.575015895068645, 24.35939848423004, 32.824200466275215, 35.61797775328159, 31.978772431612015, 33.905386850237846, 34.13492493331432, 31.253797933459282, 29.21936810016632, 21.545134596526623, 13.420878890901804, 9.13287928327918, 3.6184308864176273, 1.413273720536381, 1.2543561542406678, 1.1869309097528458, 1.1116189509630203, 2.040039044804871, 2.2434523422271013, 2.9508496960625052, 2.669506617821753, 3.740067584440112, 4.2836820892989635, 4.581980332732201, 5.0077237375080585, 8.266934249550104, 16.164070442318916, 18.753031119704247, 24.42085638642311, 20.409535132348537, 20.063269212841988, 23.011289723217487, 23.026124127209187, 33.76034863293171, 31.20296996086836, 50.961888805031776, 38.39230768382549, 30.88455844670534, 40.74935540556908, 38.176661655306816, 40.32513476908207, 29.57988515496254, 19.810991249978542, 20.757898539304733, 22.54517823457718, 41.39606550335884, 42.6019573956728, 41.10363319516182, 40.47861993312836, 55.516537204384804, 58.33608090877533, 65.16043111681938, 70.11155784130096, 68.52917075157166, 66.46366238594055, 56.338615491986275, 36.636676490306854, 21.705079413950443, 6.882707001641393, 1.2513940944336355, 0.09938639821484685, 0.09319083066657186, 0.05406000345828943, 0.05304146514390595, 0.01529730190668488, 0.034104539299733005, 0.051707157836062834, 0.004849471224588342, 0.018548632324382197, 0.02121282373991562, 0.006363247466651956, 0.02786564888083376, 0.0700525808497332, 0.026395714085083455, 0.021235047352092806, 0.04478061193367466, 0.07747616531560197, 0.016585779740125872, 0.031136494071688503, 0.02160813797672745, 0.011370653282938292, 0.09338032323285006, 0.04175460126134567, 0.012702330604952294, 0.02772633477434283, 0.06058647239115089, 0.04227711775456555, 0.04172166845819447, 0.046190455032046884, 0.0261953434892348, 0.03181036045134533, 0.025696603552205488, 0.04630949180864263, 0.0657143269199878, 0.02184777560614748, 0.03152947982016485, 0.07387265242869034, 0.01770419443346327, 0.07274040224729106, 0.09920762968249619, 0.026211435106233694, 0.05727938070776872, 0.05667960664140992, 0.033878477406688035, 0.02513043949875282, 0.061896318511571735, 0.04469588093343191, 0.009172173449769616, 0.012204734503029613, 0.008544641204935033, 0.1133719485369511, 0.09815000244998373, 0.18655924242921174, 0.1121718215290457, 0.15660369826946408, 0.10218128925771452, 0.20564310980262235, 0.287009435123764, 0.29409789538476616, 0.12959802785189822, 0.12895746534923092, 0.12688145565334707, 0.21164487290661782, 0.17138178809545934, 0.26501945103518665, 0.1677915596519597, 0.11539033788722008, 0.18845410872017965, 0.14854531036689878, 0.12257754831807688, 0.14595659537008032, 0.1879055131576024, 0.11620631441473961, 0.17626745015149936, 0.13195418345276266, 0.22354212356731296, 0.146144611062482, 0.20326188445324078, 0.1799274404766038, 0.13032234914135188, 0.08072474607615732, 0.278780828230083, 0.12923694332130253, 0.2218720834935084, 0.1954158695298247, 0.1483545041992329, 0.15695923153543845, 0.13756810018094257, 0.21144415164599195, 0.08999635247164406, 0.19756260589929298, 0.22247561282711104, 0.12390965886879712, 0.3091121662873775, 1.0093002975918353, 7.549438225105405, 30.79769890755415, 60.33541202545166, 78.48915070295334, 85.57698637247086, 87.24829629063606, 79.79501143097878, 76.19069963693619, 64.77854400873184, 70.92902317643166, 49.948942959308624, 64.71233636140823, 55.509188398718834, 37.03032396733761, 33.73533457517624, 29.682430252432823, 28.13532616943121, 26.30427662283182, 32.03293092548847, 23.2423173263669, 26.63905195891857, 25.135987512767315, 29.328866824507713, 41.5829698741436, 57.70867757499218, 59.585799649357796, 51.58661708235741, 56.30860090255737, 47.501319497823715, 35.14582648873329, 24.290663972496986, 26.155909784138203, 16.87824971973896, 7.417411459609866, 3.3493537874892354, 4.156300574541092, 3.2359970826655626, 4.3945772387087345, 4.810219360515475, 6.521841790527105, 8.678382821381092, 4.771851394325495, 7.666456270962954, 13.17746015265584, 8.58209028840065, 12.141084764152765, 18.30337844789028, 36.20614819228649, 35.29498748481274, 42.508022636175156, 31.760857924818993, 46.78582549095154, 46.208533868193626, 37.696751207113266, 58.604198321700096, 46.278206929564476, 88.69707494974136, 58.73539388179779, 57.201906368136406, 61.98400676250458, 59.743016213178635, 47.27846525609493, 30.789709836244583, 25.514348410069942, 21.73100732266903, 23.978225737810135, 46.895791590213776, 45.78097701072693, 50.187076181173325, 47.690967321395874, 66.02599427103996, 67.56281420588493, 76.12384602427483, 80.24996101856232, 80.78152969479561, 77.4506664276123, 66.8663039803505, 44.83144596219063, 24.102366976439953, 7.33188564889133, 1.5578419505618513, 0.33077275555115193, 0.2622431062627584, 0.1460492005571723, 0.21413811802631244, 0.13218457577750087, 0.18466505891410634, 0.1533975757774897, 0.05604835809208453, 0.1138366962550208, 0.12739494763081893, 0.1412196151795797, 0.06806470861192793, 0.15702877077274024, 0.12333393038716167, 0.08661319807288237, 0.1338294570450671, 0.12443342959159054, 0.08370489202206954, 0.20042590069351718, 0.09945437894202769, 0.13388597901212052, 0.20130967983277515, 0.13088268548017368, 0.13570369163062423, 0.17756074637873098, 0.15181739494437352, 0.1460790794226341, 0.11333388378261589, 0.23686429776716977, 0.15853887802222744, 0.12935841805301607, 0.19417240109760314, 0.13784017151920125, 0.11466326322988607, 0.16773200972238556, 0.11115130910184234, 0.21320289321010932, 0.11428198486100882, 0.14888111734762788, 0.14251887827413157, 0.12622542679309845, 0.172121204668656, 0.14684622263303027, 0.12080555941793136, 0.10644490539561957, 0.12587817589519545, 0.09045470287674107, 0.09159674198599532, 0.12483971833717078, 0.1582918022177182], [0.03534627852786798, 0.0683360081166029, 0.011456507709226571, 0.036378836011863314, 0.08888773969374597, 0.02049937676929403, 0.02398508855549153, 0.06846437740023248, 0.03282171477621887, 0.01669021847192198, 0.026762513152789325, 0.06333523895591497, 0.05281259051116649, 0.0521677309734514, 0.013206974326749332, 0.08905260037863627, 0.035665620962390676, 0.016384910049964674, 0.04542825452517718, 0.03102484166447539, 0.011474956572783412, 0.042079899430973455, 0.032467673227074556, 0.026114005959243514, 0.0421601627022028, 0.014118562667135848, 0.014507630803564098, 0.02479052473063348, 0.0619380012358306, 0.024020385098992847, 0.07530031449277885, 0.026887735730269924, 0.04469946550671011, 0.02894414159527514, 0.038935338088776916, 0.023571873716718983, 0.03666279655590188, 0.06564938899828121, 0.03453413148235995, 0.036104786850046366, 0.050101988890673965, 0.08328101437655278, 0.10464337159646675, 1.1878191120922565, 11.248967684805393, 27.007273100316525, 61.703331023454666, 64.1973651945591, 65.58172211050987, 62.83567786216736, 63.3031439781189, 55.43695047497749, 42.65836536884308, 31.400589756667614, 30.936013385653496, 28.53750988841057, 47.84955941140652, 28.42574268579483, 15.41103444993496, 16.558512076735497, 18.056509494781494, 25.451229996979237, 15.946353524923325, 23.85075207799673, 30.879269130527973, 35.38527064025402, 39.38555918633938, 32.50872999429703, 36.257327646017075, 46.52780033648014, 43.13451401889324, 27.475668266415596, 16.199585236608982, 14.819808024913073, 3.444373388774693, 2.6582010369747877, 1.796630162280053, 0.48303281189873815, 0.24766481743426993, 0.03831264279142488, 0.053245989911374636, 0.041435466628172435, 0.03505522676277906, 0.0517560542357387, 0.1449220860376954, 0.13052189780864865, 0.11580033737118356, 0.18691746226977557, 0.06264362411457114, 0.21129199652932584, 0.4531696205958724, 1.0184523439966142, 0.9980905428528786, 2.7068113535642624, 2.7676900243386626, 4.592738505452871, 5.798545377328992, 4.562309263274074, 5.785555774345994, 6.260089986026287, 13.234464693814516, 13.316148910671473, 23.091562315821648, 49.72972512245178, 48.82364094257355, 49.418559819459915, 57.80108481645584, 42.99193426966667, 51.337772235274315, 37.970632910728455, 36.619843393564224, 24.160327166318893, 15.089224968105555, 14.979224670678377, 22.587133683264256, 33.829504922032356, 38.648201152682304, 41.69915243983269, 49.319506734609604, 59.21108275651932, 61.42553932964802, 66.48572400212288, 61.284141317009926, 52.90924251079559, 37.65251398086548, 20.58474563062191, 5.442093154415488, 1.7540289857424796, 0.2907375991344452, 0.15976564813172445, 0.03225161548471078, 0.059018511019530706, 0.012108043792977696, 0.02329749615455512, 0.026701415845309384, 0.03141699991829228, 0.021069403701403644, 0.056203277708846144, 0.06969557813135907, 0.014728926253155805, 0.01187089514132822, 0.04224208096275106, 0.06792294356273487, 0.04677379794884473, 0.037858222058275715, 0.01880633382825181, 0.020751757074322086, 0.028923624922754243, 0.031819796859053895, 0.033734185344656, 0.027156949799973518, 0.06137406177003868, 0.07568180066300556, 0.026241753694193903, 0.03540870427968912, 0.03998344727733638, 0.04967789602233097, 0.0356276378442999, 0.03532506052579265, 0.04180982075922657, 0.03274029746535234, 0.048668126182747073, 0.034398511415929534, 0.05120985581015702, 0.023638863676751498, 0.0860094757808838, 0.022755837817385327, 0.06890554708661512, 0.06557389031513594, 0.02484221160557354, 0.036209066020091996, 0.06360883911838755, 0.026775022051879205, 0.05021902557928115, 0.02493427316949237, 0.0536110634857323, 0.010797331215144368, 0.05217724530666601, 0.018165513429266866, 0.024005295381357428, 0.02662117298314115, 0.08146688633132726, 0.07848858833312988, 0.04129442517296411, 0.05926254401856568, 0.06738536147167906, 0.016581712770857848, 0.04599705134751275, 0.05699442568584345, 0.09764017668203451, 0.04296987550333142, 0.020843848324147984, 0.022847116415505297, 0.022951484643272124, 0.03074594813369913, 0.024896495997381862, 0.11266803630860522, 0.04330800911702681, 0.019414948728808668, 0.06818778638262302, 0.0936971980263479, 0.017580675084900577, 0.07863593433285132, 0.03593788525904529, 0.019234682913520373, 0.0386866666667629, 0.03281385914306156, 0.029636778745043557, 0.03731087701453362, 0.103829435975058, 0.06917801176314242, 0.04963944164046552, 0.022316796239465475, 0.04653280404454563, 0.01839621560066007, 0.03914739194442518, 0.05224101805652026, 0.04355439101345837, 0.10771597429993562, 1.9681750447489321, 15.132147464901209, 34.250708520412445, 69.71060335636139, 73.72781619429588, 73.73822763562202, 69.40718963742256, 70.56318640708923, 63.479629307985306, 50.691993087530136, 39.16452884674072, 41.684948801994324, 39.45694215595722, 55.0295515358448, 39.291852414608, 23.619832769036293, 24.166099056601524, 28.860669247806072, 35.368787124753, 20.73129426687956, 29.17248621582985, 31.307131871581078, 24.67415649443865, 19.690552912652493, 27.397495061159134, 28.17116964608431, 36.41119658946991, 31.88809409737587, 21.113479658961296, 13.16170334815979, 11.479144133627415, 3.6836028518155217, 2.0058123813942075, 1.253885691985488, 0.4635787761071697, 0.19068899739068002, 0.026557888195384294, 0.10584588089841418, 0.08982053026556969, 0.06758623116184026, 0.10973691663821228, 0.12888310215203092, 0.14830918866209686, 0.08786111196968704, 0.027610893703240436, 0.02806098771543475, 0.04284094589820597, 0.19771085731917992, 0.6332562072202563, 0.4826395626878366, 1.2920937105081975, 2.096623471006751, 2.9731267131865025, 3.0456500966101885, 2.8325724927708507, 3.643532101996243, 5.358568886294961, 9.601964112371206, 12.314958684146404, 19.194504730403423, 32.13605359196663, 35.74937090277672, 44.09913785755634, 44.89277087152004, 32.87311144173145, 43.51415164768696, 37.51475237309933, 35.60874804854393, 34.75294277071953, 22.723272778093815, 22.699809037148952, 30.0208742916584, 42.11095534265041, 48.68792362511158, 51.954859122633934, 56.38559237122536, 65.31354010105133, 68.57093051075935, 73.32323670387268, 70.09319722652435, 65.58159291744232, 47.7065122872591, 30.094626434147358, 9.239881541579962, 2.457068804651499, 0.39456699800211936, 0.18182108964538202, 0.02644815423991531, 0.07930276886327192, 0.0046008220670046285, 0.030232172284740955, 0.005866352230441407, 0.0172566367109539, 0.061206648097140715, 0.08531069921446033, 0.0362069175025681, 0.02787129476928385, 0.06693184244795702, 0.02687746069568675, 0.04316369479056448, 0.04202887306746561, 0.06989836256252602, 0.0384760822635144, 0.021064691063656937, 0.05164763759239577, 0.06499060677015223, 0.012929817421536427, 0.0165587729861727, 0.07487331982702017, 0.09598912816727534, 0.039778562568244524, 0.03338699752930552, 0.04148787338635884, 0.023048629918775987, 0.044357020015013404, 0.07538552046753466, 0.04139126802328974, 0.0911611903575249, 0.06735281087458134, 0.06296842504525557, 0.05177086750336457, 0.012714723543467699, 0.043302699050400406, 0.0466341962601291, 0.07710989317274652, 0.025430591849726625, 0.030513464807881974, 0.05052106855146121, 0.08936390906455927, 0.017510490179120097, 0.04518839981756173, 0.06379737431416288, 0.005190053461774369, 0.185952284373343, 0.17224546987563372, 0.09831950155785307, 0.09528227703412995, 0.1011892753012944, 0.14832636195933446, 0.13568829948781058, 0.14833632158115506, 0.12443837971659377, 0.12143723841290921, 0.13007629750063643, 0.16259164258372039, 0.1886537909740582, 0.22420668712584302, 0.105775718257064, 0.1260440013720654, 0.10163201834075153, 0.07101257855538279, 0.18589062674436718, 0.13414960470981896, 0.2544541476527229, 0.11435638516559266, 0.11605904262978584, 0.17075111099984497, 0.17666816536802799, 0.10631296638166532, 0.09109147300478071, 0.12898655753815547, 0.16974775702692568, 0.15556739293970168, 0.14061338442843407, 0.12143674117396586, 0.16944770672125742, 0.13923779886681587, 0.11164759809616953, 0.14789061737246811, 0.09551416849717498, 0.16364072769647464, 0.11369274187018164, 0.10281894254148938, 0.1354024835745804, 0.2355768793495372, 0.3206167317694053, 3.170213825069368, 19.892114996910095, 41.033819541335106, 80.541070997715, 83.78510892391205, 83.69595810770988, 79.37136456370354, 81.96806162595749, 73.38429182767868, 60.85353322327137, 47.06099532544613, 44.35420677065849, 44.71306711435318, 61.404784843325615, 40.44783778488636, 24.984799325466156, 25.799424313008785, 27.327880896627903, 38.19635979831219, 25.12633603066206, 34.431103840470314, 41.387819945812225, 48.716209307312965, 53.28447997570038, 48.39173711836338, 51.343749314546585, 60.38849517703056, 56.41077741980553, 36.80973060429096, 22.850991524755955, 19.603381790220737, 5.324196880683303, 4.103149501606822, 2.648501582443714, 1.127571682445705, 0.6006738462019712, 0.16817964351503178, 0.11496388498926535, 0.20165918685961515, 0.2265138312941417, 0.18864381650928408, 0.37793944648001343, 0.6744527060072869, 0.809420810546726, 0.7462609559297562, 0.22315907146548852, 0.6730030244216323, 0.8144756080582738, 1.9821605505421758, 1.7692396882921457, 3.865221943706274, 4.267364339902997, 5.9613205678761005, 8.97350823506713, 5.865110205486417, 7.823548866435885, 8.74842256307602, 18.668650947511196, 17.648278400301933, 30.47316402196884, 62.630530670285225, 63.264914229512215, 66.19518399238586, 73.196080327034, 56.55962683260441, 70.22738322615623, 50.9404731541872, 49.109757989645004, 35.90270787477493, 26.256321296095848, 27.004461251199245, 36.78720161318779, 49.46329861879349, 56.71194165945053, 60.64127281308174, 66.53860956430435, 73.76815482974052, 77.3189502954483, 82.13122487068176, 80.7120694220066, 77.37685158848763, 54.85184267163277, 33.28528672456741, 11.291505452245474, 3.153018797747791, 0.6645851698704064, 0.35361525951884687, 0.10327318144845776, 0.14341723319375888, 0.08924964800826274, 0.18029567931080237, 0.1604461678653024, 0.10879983645281754, 0.19036874582525343, 0.20011393149616197, 0.17004893539706245, 0.10672339631128125, 0.14373460522620007, 0.14987519447458908, 0.15766165946843103, 0.16230512905167416, 0.09856074408162385, 0.13104600249789655, 0.15693880763137713, 0.12245829260791652, 0.1865509749040939, 0.1269027849775739, 0.18231688882224262, 0.17754765489371493, 0.18026367790298536, 0.09928700237651356, 0.12903179886052385, 0.21527154080104083, 0.14115636935457587, 0.1459678017999977, 0.12180884659755975, 0.10266390047036111, 0.14797603857005015, 0.1914753028540872, 0.12347651179879904, 0.10985298853483982, 0.12376269878586754, 0.15240750624798238, 0.12243354940437712, 0.18242686026496813, 0.23123648803448305, 0.1066518755396828, 0.1834556253743358, 0.22050142579246312, 0.12535181507701054, 0.12109542745747603, 0.12330580299021676, 0.11304314743028954], [0.030607949483965058, 0.017614331482036505, 0.0030484847593470477, 0.07822419080184773, 0.02774956028588349, 0.046745306899538264, 0.050309159414609894, 0.0658653094433248, 0.024377074259973597, 0.037180797080509365, 0.04150577398831956, 0.023698432160017546, 0.05178068240638822, 0.04362249790574424, 0.015079579898156226, 0.037091171616339125, 0.0679539208067581, 0.015835049125598744, 0.10743231803644449, 0.027628736788756214, 0.01550876111650723, 0.035093655169475824, 0.04655772165278904, 0.027246571553405374, 0.08149952598614618, 0.0219997952808626, 0.017586872018000577, 0.07880316246883012, 0.019802049246209208, 0.06153182752314024, 0.027137796823808458, 0.06900432694237679, 0.010376524205639726, 0.02306239490280859, 0.01727159284200752, 0.04182509415841196, 0.07232079195091501, 0.039554474788019434, 0.011954746696574148, 0.06746108279912733, 0.024702583941689227, 0.14186529850121588, 4.559340672567487, 20.85256475955248, 49.05282944440842, 61.83102697134018, 67.38996148109436, 70.95464900135994, 48.13591964542866, 44.467957466840744, 61.12346313893795, 42.80632562935352, 35.509022399783134, 28.114032112061977, 20.01541458070278, 15.997677370905876, 21.537331715226173, 35.84836319088936, 36.04627937078476, 30.78378025442362, 35.277554020285606, 39.915151968598366, 41.80008262395859, 42.88971595466137, 57.71399728953838, 59.89237479865551, 59.13013570010662, 40.18574304878712, 27.384340167045593, 17.28361576795578, 8.227765951305628, 4.065257934853435, 1.6648850566707551, 0.4820120916701853, 0.08627041490399279, 0.09812384174438193, 0.06971748633077368, 0.026553598581813276, 0.13375208072829992, 0.09504068570095114, 0.03301684024336282, 0.13515423517674208, 0.09999289613915607, 0.20572513196384534, 0.11358978372300044, 0.13417872658465058, 0.11104672565124929, 0.10616412124363706, 0.07169076052377932, 0.10667861512047239, 0.06953150412300602, 0.1363825934822671, 0.02601909825898474, 0.06615528880502097, 0.17279517865972593, 0.09703135583549738, 0.0358365190186305, 0.05356010020477697, 0.07914435002021492, 0.5117723322473466, 0.8654401951935142, 1.9156713620759547, 3.635177300311625, 6.305873254314065, 11.863903887569904, 15.878501515835524, 36.96778692305088, 57.491789013147354, 49.033860862255096, 60.665998086333275, 51.603491976857185, 32.11511291563511, 21.220092438161373, 22.559676356613636, 18.819307163357735, 17.427726835012436, 26.337724328041077, 26.469772942364216, 38.10784734785557, 35.24154335260391, 45.73151886463165, 44.6424251049757, 56.608013436198235, 61.3602664321661, 63.95548537373543, 61.00783534348011, 44.21581819653511, 26.556491889059544, 9.731441214680672, 0.9988467022776604, 0.22229782392969355, 0.08784247664152645, 0.08091119583696127, 0.025158511234621983, 0.03279502714576665, 0.008786107300693402, 0.025201605894835666, 0.04273488557373639, 0.04967982189555187, 0.022648951853625476, 0.10025115610915236, 0.005667838395311264, 0.02991537727211835, 0.043207782073295675, 0.08844456620863639, 0.08600614353781566, 0.025851419268292375, 0.026426665353938006, 0.036375084455357864, 0.05200670348131098, 0.026600277815305162, 0.05897706207178999, 0.03026227750524413, 0.047610395049559884, 0.04647518369893078, 0.031536875321762636, 0.03720509870618116, 0.02585407615697477, 0.10955169142107479, 0.05804419728519861, 0.07091872656019405, 0.03234555282688234, 0.021543559996644035, 0.021056104415038135, 0.012272118729015347, 0.07282569727976806, 0.04228968973620795, 0.019167275495419744, 0.026043190227937885, 0.016822984980535693, 0.05205901004956104, 0.052460968363448046, 0.059766959529952146, 0.014635684674431104, 0.050715333127300255, 0.04140242621360812, 0.013471622332872357, 0.023970945076143835, 0.019307853108330164, 0.0555118855118053, 0.0029067607601973577, 0.030498848209390417, 0.029918885775259696, 0.09600630146451294, 0.03358801193826366, 0.037163393717492, 0.021281657936924603, 0.027774156915256754, 0.04093774528882932, 0.02055865767033538, 0.00425038039793435, 0.004000262251793174, 0.02807149096042849, 0.04247077005857136, 0.12942340050358325, 0.035511569658410735, 0.10932510631391779, 0.08414285563048907, 0.02969395380205242, 0.05411178310168907, 0.025345545436721295, 0.05058706032286864, 0.061441363432095386, 0.11594671857892536, 0.02374979063461069, 0.021093965078762267, 0.04149108688579872, 0.03140200482448563, 0.005302509243847453, 0.03437893727095798, 0.06736947208992206, 0.04086146735062357, 0.02454601304634707, 0.04550852521788329, 0.04260215617250651, 0.03842500766040757, 0.06264847776037641, 0.4982842435128987, 7.6575367245823145, 26.352325044572353, 58.50294515490532, 71.1294624209404, 76.5371498465538, 78.93919855356216, 56.82564675807953, 53.83132003247738, 69.43598449230194, 54.647014662623405, 47.326103299856186, 39.9109797924757, 30.4930217564106, 24.073034450411797, 26.544446535408497, 27.97491017729044, 22.297916002571583, 14.994655642658472, 18.66890363395214, 26.65057674050331, 26.34792298078537, 26.405066214501858, 40.61599016189575, 41.41454391181469, 45.73793672025204, 29.03066262602806, 18.21144998073578, 12.07633338868618, 7.63053584843874, 3.867829078808427, 1.61573457531631, 0.5129831610247493, 0.11863924519275315, 0.018721318956522737, 0.07160937660955824, 0.08271903046988882, 0.09832335330429487, 0.10924406378762797, 0.174371708126273, 0.3074479743372649, 0.3713514906121418, 0.2561525674536824, 0.12914451624965295, 0.1332789912703447, 0.12686094269156456, 0.04818464665731881, 0.09557614524965174, 0.10296165753970854, 0.2310493926052004, 0.010380386156612076, 0.09031278197653592, 0.10380687468568794, 0.0965284246194642, 0.13481633533956483, 0.1289034666842781, 0.08564993491745554, 0.037496989098144695, 0.2569187310291454, 0.6956965941935778, 0.8538393583148718, 2.766314260661602, 5.203903885558248, 9.217020068317652, 14.673864506185055, 25.20488541573286, 44.921706318855286, 45.50106883049011, 52.90086776018143, 47.408809661865234, 35.46374022960663, 24.931615479290485, 28.77707753330469, 30.98941572010517, 30.24328775703907, 40.48139378428459, 33.25580030679703, 48.2931400090456, 43.77757251262665, 52.523601204156876, 51.33130118250847, 61.80241450667381, 68.47763031721115, 71.07261747121811, 70.8514541387558, 55.44277176260948, 34.402916952967644, 12.02083071693778, 1.2315725767984986, 0.1784009169205092, 0.03366103184816893, 0.05449205214972608, 0.04281475179595873, 0.027230654341110494, 0.11528003247804008, 0.0438352159835631, 0.03290693188318983, 0.024472147088090423, 0.030040254750929307, 0.024569199595134705, 0.04936165576509666, 0.019496249151416123, 0.045656743241124786, 0.02894215635024011, 0.040346750829485245, 0.0966648239409551, 0.017926233886100817, 0.0492341659264639, 0.04311028984375298, 0.03136932064080611, 0.05848348191648256, 0.037284849895513617, 0.0675212858186569, 0.061640110579901375, 0.01043895737893763, 0.023550483165308833, 0.10490293774637394, 0.043730502657126635, 0.019457614798739087, 0.0709117652149871, 0.009023909042298328, 0.03181925509124994, 0.03959041328926105, 0.0720322597771883, 0.03848008615022991, 0.04606011905707419, 0.024436078711005393, 0.04520544323895592, 0.0275130786394584, 0.027855281077791005, 0.0117433310879278, 0.0390913931914838, 0.021177619964873884, 0.016063747498265002, 0.03315395944810007, 0.08665694767842069, 0.08460696510155685, 0.09724541348987259, 0.10631273631588556, 0.09522128733806312, 0.16606890130788088, 0.1836503203958273, 0.23899978317786008, 0.11039128308766522, 0.16342544549843296, 0.1382023247424513, 0.10146073807845823, 0.13817899161949754, 0.15196885244222358, 0.08708293302333914, 0.19453655811958015, 0.13664615980815142, 0.12793468195013702, 0.18236088333651423, 0.10254210661514662, 0.15535619255388156, 0.19105184823274612, 0.09774801073945127, 0.21867394651053473, 0.098758660024032, 0.11563767344341613, 0.0940335170889739, 0.21503749710973352, 0.0957327161449939, 0.18478962098015472, 0.1445397612405941, 0.1574198974412866, 0.07740147557342425, 0.1654585442156531, 0.22421710687922314, 0.1780542152118869, 0.12488567212130874, 0.1141453703166917, 0.12940419372171164, 0.19542315742000937, 0.16458091005915776, 0.9204195044003427, 10.268471147865057, 33.239856362342834, 71.08071103692055, 80.65704837441444, 86.7435009777546, 88.16206365823746, 67.20922037959099, 64.55522999167442, 78.38318958878517, 59.449101984500885, 51.17296747863293, 40.425270795822144, 32.84720063209534, 27.539717629551888, 31.16338938474655, 46.82011105120182, 49.799751564860344, 44.65242236852646, 48.099669590592384, 53.98061782121658, 57.129600048065186, 57.89585553109646, 74.34836849570274, 77.03996166586876, 74.43707093596458, 50.97163148224354, 37.351383939385414, 23.603533543646336, 12.04870792105794, 6.5289027616381645, 2.6943332981318235, 1.0484539903700352, 0.271553200436756, 0.37119255226571113, 0.3463293582899496, 0.20155034348135814, 0.2822778280824423, 0.3072947356849909, 0.26921068551018834, 0.17547974945046008, 0.7008350465912372, 0.4768347507342696, 0.500976755283773, 0.44463830650784075, 0.36129838787019253, 0.5182338261511177, 0.48105020890943706, 0.5723827017936856, 0.43179377855267376, 0.3957080648979172, 0.2010602439986542, 0.34448081685695797, 0.4516508005326614, 0.379782110103406, 0.20875883870758116, 0.22799603379098698, 0.3388324793195352, 0.8365560451056808, 1.398672410286963, 2.833575876429677, 5.027432329952717, 8.951957691460848, 15.091142915189266, 21.653088703751564, 47.09623083472252, 67.57274687290192, 58.3730985224247, 74.39288690686226, 63.71751934289932, 46.087031587958336, 33.5063436627388, 35.45406974852085, 30.648222528398037, 30.58987855911255, 39.646396189928055, 38.19417491555214, 54.38634864985943, 51.91980980336666, 63.85224491357803, 61.6555105894804, 74.66328039765358, 78.75516682863235, 80.99268436431885, 80.98657429218292, 66.05532869696617, 40.12121871113777, 15.142328068614006, 2.19358429312706, 0.3012942639179528, 0.17352267634123564, 0.240497600461822, 0.13264691893709823, 0.14364854578161612, 0.17077598778996617, 0.21225668460829183, 0.11722063733031973, 0.13238359009847045, 0.16740251099690795, 0.20590296539012343, 0.1238684325653594, 0.17015859513776377, 0.11534163815667853, 0.173789419059176, 0.16163836873602122, 0.17113625595811754, 0.14850855921395123, 0.1220687318709679, 0.12416294644935988, 0.10896273044636473, 0.16252501256531104, 0.1739886708674021, 0.0926649670873303, 0.1391624115058221, 0.07916858114185743, 0.14073288504732773, 0.20002350822323933, 0.16150377283338457, 0.17302135558566079, 0.18699969223234802, 0.14597949804738164, 0.14347602613270283, 0.1575645271805115, 0.13044168648775667, 0.14964245696319267, 0.14946781477192417, 0.13779426226392388, 0.16455511300591752, 0.08915150639950298, 0.20598234550561756, 0.13555162557167932, 0.19141195312840864, 0.21184569806791842, 0.1264146892935969, 0.13882645609555766], [0.05357522517442703, 0.04595764330588281, 0.030220040025596973, 0.029262001589813735, 0.022857339499751106, 0.024825179316394497, 0.028468037162383553, 0.07706769465585239, 0.04368399597296957, 0.046695159981027246, 0.0178943233913742, 0.07985134216141887, 0.03169526447891258, 0.10118257370777428, 0.026263407708029263, 0.026459004438947886, 0.03700049972394481, 0.07699370253249072, 0.018300079645996448, 0.028988553567614872, 0.03353525265993085, 0.029562458221334964, 0.014316341312223813, 0.04323685199778993, 0.03718717212905176, 0.03013503628608305, 0.02272506280860398, 0.012993292384635424, 0.038463476885226555, 0.009425006464880425, 0.020765195513376966, 0.03721338478499092, 0.014524058242386673, 0.03024389450729359, 0.01952739152329741, 0.04919703627820127, 0.020681113892351277, 0.06989690795307979, 0.04848467469855677, 0.05705305164156016, 1.5259015769697726, 16.295984163880348, 40.86437903344631, 60.313935577869415, 71.36478379368782, 71.61038741469383, 63.76270651817322, 61.97246678173542, 40.13505756855011, 40.64090922474861, 45.48002935945988, 19.410063363611698, 13.10953214764595, 10.64658410847187, 17.370169423520565, 29.595384523272514, 42.10661977529526, 56.76674231886864, 71.1622242629528, 64.37467128038406, 66.75550952553749, 57.628520876169205, 48.32556366920471, 40.73597252368927, 31.51772417128086, 15.03818990662694, 5.3715812880545855, 6.537314560264349, 3.6826958879828453, 2.117044050246477, 0.6570862722583115, 0.045807729475200176, 0.06675073615042493, 0.059291988727636635, 0.021764241319033317, 0.04985999308701139, 0.05607205857813824, 0.060005838313372806, 0.028261920488148462, 0.02451483171171276, 0.10266615659929812, 0.040686836291570216, 0.09203514346154407, 0.1971825520740822, 0.09020619472721592, 0.10619644919643179, 0.06477288290625438, 0.05958496636594646, 0.032425073950435035, 0.07730702986009419, 0.2073148568160832, 0.06004465263686143, 0.03823633145657368, 0.07336891227168962, 0.07452221718267538, 0.07094450134900399, 0.061404823791235685, 0.041029890344361775, 0.04555975196126383, 0.03468811228231061, 0.057721025368664414, 0.03737152903340757, 0.0696683487331029, 0.26667170925065875, 0.6632275739684701, 1.525968904606998, 2.6181882340461016, 5.161898089572787, 10.90959269553423, 23.090445175766945, 34.39856618642807, 41.1627846211195, 46.36373654007912, 41.490061059594154, 32.949312552809715, 26.69249229133129, 19.9363674223423, 23.455843068659306, 23.073697574436665, 26.597447991371155, 26.526925675570965, 34.26979869604111, 41.00863829255104, 43.729083314538, 55.68938232958317, 60.607283636927605, 64.50973123311996, 56.47067740559578, 36.54730148613453, 13.770045954734087, 1.9392686896026134, 0.4346982476999983, 0.07481238950276747, 0.0608606180321658, 0.018093821963702794, 0.06289708238909952, 0.0486243877094239, 0.05667040772095788, 0.010795900725497631, 0.019857196384691633, 0.02933718486019643, 0.027180401666555554, 0.024085298900899943, 0.03273162918048911, 0.043577186079346575, 0.019565907132346183, 0.029249546496430412, 0.017436408998037223, 0.130818385805469, 0.03348960686707869, 0.018721558299148455, 0.04968366993125528, 0.051587571870186366, 0.035615919332485646, 0.10520494732190855, 0.008677737969264854, 0.028102815158490557, 0.051871699397452176, 0.015179164056462469, 0.043617729606921785, 0.010035293980763527, 0.1272830317611806, 0.05828705026942771, 0.05123521128552966, 0.07589991044369526, 0.009647981023590546, 0.05154958875209559, 0.004878882073171553, 0.04396321048261598, 0.03827217347861733, 0.08872387348674238, 0.031780043718754314, 0.046396434408961795, 0.04826640535611659, 0.08956804420449771, 0.02452519580401713, 0.006543946510646492, 0.021136104223842267, 0.029550867729994934, 0.023912270880828146, 0.07251666698721237, 0.015323973766498966, 0.018303131728316657, 0.02748602921201382, 0.04447423852980137, 0.01286125410842942, 0.037531209527514875, 0.03296188420790713, 0.046314634892041795, 0.031030515383463353, 0.04440557131601963, 0.014687484726891853, 0.02515017506084405, 0.07422992974170484, 0.031283717617043294, 0.004189685705568991, 0.01781821614713408, 0.029843166303180624, 0.0263376744260313, 0.07387493082205765, 0.05444273272587452, 0.01564063612022437, 0.04974854105967097, 0.051189969963161275, 0.050401527114445344, 0.04170480686298106, 0.02990601322380826, 0.03283667276264168, 0.07600237877340987, 0.059342644017306156, 0.021026715367042925, 0.11638019219390117, 0.06205236248206347, 0.07798847727826796, 0.04469756189791951, 0.06321646564174443, 2.8452248638495803, 21.642226986587048, 49.18079137802124, 70.13016924262047, 79.31369125843048, 78.637555539608, 70.27136206626892, 72.66454964876175, 51.25365234911442, 49.6243529766798, 58.66537503898144, 32.083905190229416, 26.55251920223236, 15.808583367615938, 24.267705604434013, 34.18857805430889, 38.766401410102844, 62.46101036667824, 67.90906682610512, 59.62662845849991, 54.84996177256107, 50.81418313086033, 40.27950681746006, 34.394918382167816, 25.90963739901781, 17.76336282491684, 8.059814963489771, 6.7397653218358755, 2.30241852812469, 1.3666585343889892, 0.6555589917115867, 0.07021796845947392, 0.04734815716801677, 0.06176771916216239, 0.1167361781699583, 0.069028758443892, 0.07505827787099406, 0.19791944534517825, 0.1755070307990536, 0.14437543490203097, 0.7068168162368238, 0.6363393855281174, 0.18159626342821866, 0.5458482506219298, 0.18345528398640454, 0.07759836735203862, 0.19754708016989753, 0.08206176964449696, 0.05221128390985541, 0.06997358665103093, 0.29225674574263394, 0.029392610304057598, 0.04674626798077952, 0.20168412302155048, 0.08628326890175231, 0.25386696041096, 0.07274795731063932, 0.16581458214204758, 0.010954387289530132, 0.03863441204885021, 0.07824359796359204, 0.04242166585754603, 0.032714596891310066, 0.12546454730909318, 0.16245295002590865, 1.1156618152745068, 2.3733521718531847, 4.4015574641525745, 9.009450506418943, 17.802409529685974, 28.662758767604828, 38.23516711592674, 39.96461771428585, 38.41466948390007, 31.9961678981781, 27.21863865852356, 25.088148079812527, 33.05329017341137, 36.80540643632412, 37.10394121706486, 41.679933071136475, 43.65801952779293, 51.41517028212547, 51.932539120316505, 63.70813384652138, 67.91492611169815, 73.46370756626129, 64.4096066057682, 44.804953783750534, 18.62365946173668, 3.6115102702751756, 0.3784227033611387, 0.11392523447284475, 0.024407574674114585, 0.04282455556676723, 0.03887724276864901, 0.08256990331574343, 0.03614179775468074, 0.03579906282539014, 0.03594587818952277, 0.04647613735869527, 0.050662889261730015, 0.043018545547965914, 0.043813196461996995, 0.0488597821095027, 0.05571929723373614, 0.03735690872417763, 0.05815018339490052, 0.04482996475417167, 0.08877144515281543, 0.03510987480694894, 0.028252545307623222, 0.029994911383255385, 0.03015305377630284, 0.050137986763729714, 0.013388012903305935, 0.06468215535278432, 0.09799672669032589, 0.0717460059968289, 0.047972537140594795, 0.021436777933558915, 0.07510607960284688, 0.024451530225633178, 0.017373458176734857, 0.04289504846383352, 0.009658558483351953, 0.06495378140243702, 0.06476461538113654, 0.013669568888872163, 0.023846407129894942, 0.0871113572793547, 0.038932317547732964, 0.04667478802730329, 0.04896822472801432, 0.045002291444689035, 0.07389121354208328, 0.165332987671718, 0.09602000151062384, 0.1458083587931469, 0.12967041693627834, 0.18215967225842178, 0.08392772186198272, 0.16401913395384327, 0.25295307976193726, 0.11610606510657817, 0.1018286874750629, 0.10178996963077225, 0.12748584587825462, 0.09256468067178503, 0.1734910163213499, 0.13016496930504218, 0.0989804211712908, 0.18588071165140718, 0.1891711718053557, 0.13001977553358302, 0.05622457363642752, 0.09001374099170789, 0.13427011464955285, 0.07397612265776843, 0.1271769343293272, 0.11410691222408786, 0.105914752202807, 0.11768064272473566, 0.1367843328625895, 0.1224909842130728, 0.10801459968206473, 0.20408028038218617, 0.1712623320054263, 0.15087553532794118, 0.1423565112054348, 0.08852543804096058, 0.1842796616256237, 0.15430243191076443, 0.23804192285751924, 0.13235054968390614, 0.19909284019377083, 4.10543080419302, 27.67785731703043, 60.206986516714096, 80.43141648173332, 88.50328534841537, 89.06934857368469, 82.2057692706585, 80.69214329123497, 57.39302471280098, 57.22877852618694, 63.420683071017265, 32.879039123654366, 23.98187354207039, 19.846477545797825, 26.838529855012894, 40.68429909646511, 56.106064170598984, 68.32607164978981, 84.33392867445946, 79.47244673967361, 84.18810769915581, 73.19757744669914, 61.71661131083965, 53.09731341898441, 40.83473302423954, 21.507182233035564, 9.022041130810976, 9.858471248298883, 5.086455512791872, 3.471628613770008, 1.5267958352342248, 0.33167986781336367, 0.22188238450326025, 0.16697405430022627, 0.24830938753439113, 0.23406530264765024, 0.21493390813702717, 0.29396736645139754, 0.18253868707688525, 0.1652884142822586, 0.5703679192811251, 0.5001371784601361, 0.24959640519227833, 0.7528677920345217, 0.5109304992947727, 0.3970606141956523, 0.3695073426933959, 0.43819008220452815, 0.1882368969381787, 0.44446669227909297, 0.7438390015158802, 0.38357816578354686, 0.2602176071377471, 0.34620034333784133, 0.3252370760310441, 0.46891095873434097, 0.22912567161256447, 0.3240625828038901, 0.1737682381644845, 0.16390000440878794, 0.21114024217240512, 0.28954600682482123, 0.27266749064438045, 0.7362211821600795, 0.9965297766029835, 2.284521725960076, 4.115761024877429, 6.586111066862941, 15.16515914350748, 29.607236087322235, 44.85340118408203, 54.57756198942661, 62.31258653104305, 56.22528277337551, 46.427516117691994, 36.610454097390175, 31.50997258722782, 36.29561819136143, 34.76487793028355, 39.248903319239616, 41.336290910840034, 49.6579659730196, 57.066512033343315, 62.689374312758446, 72.74758279323578, 77.42094442248344, 81.71346008777618, 76.17109268903732, 52.966741025447845, 23.899581357836723, 4.784405445680022, 0.5516085040289909, 0.26611854205839336, 0.1897346251644194, 0.095136504387483, 0.10465580257005058, 0.14018477930221707, 0.10923997455392964, 0.1250348289613612, 0.07204034918686375, 0.12599021050846204, 0.24559054436394945, 0.14529320440487936, 0.19590726034948602, 0.18981829489348456, 0.24305260711116716, 0.10369897383498028, 0.16516379284439608, 0.2191499006585218, 0.12052340229274705, 0.07604394646477886, 0.14208025415427983, 0.12143662985181436, 0.14427015383262187, 0.25455819675698876, 0.17043655912857503, 0.20212838746374473, 0.13387198210693896, 0.14494947128696367, 0.14497002877760679, 0.08202112963772379, 0.3203942655818537, 0.11736154148820788, 0.20249956520274282, 0.1552382207592018, 0.15442559873918071, 0.12033897117362358, 0.15181181399384513, 0.13928911095717922, 0.16873533400939777, 0.20155259961029515, 0.11588949157157913, 0.17092331894673407, 0.11403266777051613, 0.1891439052997157, 0.2893977554049343], [0.028194672631798312, 0.053752472304040566, 0.048780773067846894, 0.03761637468414847, 0.07600165146868676, 0.012722091214527609, 0.035698279170901515, 0.02072193758067442, 0.011874290466948878, 0.03178216255037114, 0.03523697130731307, 0.04402461207064334, 0.03694461229315493, 0.01108353861127398, 0.049546561858733185, 0.05602724770142231, 0.03957681714382488, 0.07902758050477132, 0.014723553103976883, 0.08671120609506033, 0.027968892754870467, 0.0026033378571810317, 0.02476047146046767, 0.0395855114038568, 0.04100296522665303, 0.030876098571752664, 0.03864505444653332, 0.026186179820797406, 0.03847338826744817, 0.02817735461576376, 0.057208245852962136, 0.06663339518127032, 0.03108859214989934, 0.024101169728965033, 0.0003955966587909643, 0.0373640630277805, 0.07113601255696267, 0.1080240991723258, 0.14461566810496151, 3.2731322525069118, 28.769561536610126, 58.07330600917339, 69.25882279872894, 67.98098176717758, 62.60543681681156, 57.60791078209877, 52.42205925285816, 40.16374222934246, 37.055429220199585, 41.169821843504906, 24.254083335399628, 23.40919677168131, 24.3936650454998, 54.87662874162197, 47.33428046107292, 43.68227742612362, 63.6115962266922, 31.96654848754406, 23.576085716485977, 21.745085567235947, 15.800908729434013, 10.409928057342768, 6.842625327408314, 3.4657636284828186, 2.0488415099680424, 0.5316108895931393, 0.742318726843223, 0.026213043711322825, 0.06331275188131258, 0.06546316930325702, 0.029440779399010353, 0.01674323564657243, 0.025649597773735877, 0.05554251394642051, 0.06085602042730898, 0.03515159463859163, 0.05006275896448642, 0.15352577436715364, 0.13748141733231023, 0.09359012095956132, 0.2850385580677539, 0.8913267811294645, 0.4858412768226117, 0.11358209507307038, 0.1474877944565378, 0.08972382842330262, 0.019091548601863906, 0.059216100416961126, 0.1011657046910841, 0.04898377643257845, 0.03979970635555219, 0.030546403177140746, 0.02027349670242984, 0.10522559387027286, 0.0588755622447934, 0.05986313444736879, 0.016561327829549555, 0.08066908500040881, 0.03868659616273362, 0.11858670855872333, 0.14598982874304056, 0.09445999225135893, 0.10912486744928174, 0.05377535642764997, 0.06859087647171691, 0.033554173714946955, 0.068034770374652, 0.557522886665538, 1.6547496942803264, 3.5116839269176126, 6.07477393001318, 19.01846207678318, 29.085759669542313, 38.627697452902794, 57.4552121758461, 59.049173444509506, 59.40095476806164, 28.072515539824963, 25.263698659837246, 17.927120737731457, 13.081358559429646, 16.451682709157467, 17.29965090751648, 31.924773529171944, 36.609792932868004, 43.719971403479576, 59.86838288605213, 61.981878876686096, 59.02317903935909, 41.94356292486191, 19.623376317322254, 3.002011813223362, 0.1682198530761525, 0.08203958685044199, 0.05006803934520576, 0.12058566106134094, 0.07407137731206603, 0.030117542009975296, 0.04837901513383258, 0.0327989790821448, 0.026949901730404235, 0.032775222935015336, 0.0566070617060177, 0.11832038886495866, 0.021272926569508854, 0.12399303916026838, 0.04407269581861328, 0.05307282830472104, 0.013236081358627416, 0.061086739297024906, 0.03195050019712653, 0.03898903989465907, 0.04215707536786795, 0.028738763357978314, 0.03417342544707935, 0.009584934650774812, 0.03793850388319697, 0.08105691653327085, 0.04560255903925281, 0.052171768256812356, 0.054467386871692725, 0.09767959956661798, 0.02370411886658985, 0.09951016618288122, 0.027468056250654627, 0.012605948813870782, 0.03301214244856965, 0.018431890639476478, 0.053056415708852, 0.03993304431787692, 0.07332880661124364, 0.03047009184228955, 0.07945274206576869, 0.031415471094078384, 0.02098006210871972, 0.0067183488954469794, 0.013107169379509287, 0.014131168973108288, 0.014993662389315432, 0.05429373173683416, 0.03110211964667542, 0.029662586930498946, 0.025868496086332016, 0.016958662563411053, 0.010461465790285729, 0.07454262624378316, 0.04069957525643986, 0.13923370221164078, 0.06392998868250288, 0.04014635240309872, 0.010860569618671434, 0.07614670423208736, 0.0496983607445145, 0.017979946824198123, 0.030575415585190058, 0.06214504188392311, 0.030329716464621015, 0.04503222597122658, 0.009810659794311505, 0.003419579238652659, 0.022805745393270627, 0.04761356773087755, 0.027457083597255405, 0.027212891036469955, 0.02108009433868574, 0.025626142196415458, 0.09763406138517894, 0.06032034565578215, 0.054288239844026975, 0.012742218259518268, 0.05863585596671328, 0.05513231779332273, 0.04651545634260401, 0.0458135887311073, 0.24847358028637245, 5.241652010008693, 36.005955934524536, 67.39467322826385, 78.34687113761902, 75.44796109199524, 72.15368986129761, 66.2974365055561, 64.38707381486893, 48.640893548727036, 45.15963435173035, 52.168400064110756, 43.18645343184471, 32.457421347498894, 25.96775148063898, 48.01962688565254, 34.398493990302086, 33.09517912566662, 62.08313584327698, 36.05560027062893, 32.75307588279247, 29.563777819275856, 21.682174243032932, 13.977519571781158, 8.675868306308985, 4.887634506449103, 2.5253703771159053, 0.8434114116244018, 0.4224919667467475, 0.12320802503381856, 0.06987600165302865, 0.11029555345885456, 0.12002836010651663, 0.03630517043347936, 0.1760003512026742, 0.11755294879549183, 0.08222637057770044, 0.18649339908733964, 0.21478599810507149, 0.5827041354496032, 0.5473630037158728, 0.6455290142912418, 1.0691810469143093, 1.0079172905534506, 1.1890318407677114, 0.6255931465420872, 0.1928525508265011, 0.03292290661192965, 0.029145439875719603, 0.19256565137766302, 0.13597424898762256, 0.19559009611839429, 0.05265116968075745, 0.22325310157611966, 0.4004527040524408, 0.13882779196137562, 0.19671119924169034, 0.3215510363224894, 0.2527544810436666, 0.33714136225171387, 0.3259362978860736, 0.5316359444987029, 0.5462878989055753, 0.41206936351954937, 0.2179807360516861, 0.041838608667603694, 0.10392580385087058, 0.0331974641449051, 0.04115887561056297, 0.2566943649435416, 1.2616436881944537, 2.6159608410671353, 5.76367512345314, 12.828828860074282, 23.894172348082066, 36.08369216322899, 45.86877889931202, 48.75948518514633, 53.388674184679985, 28.82375232875347, 25.18484529107809, 22.30322241783142, 20.603436827659607, 27.767929583787918, 25.56761585175991, 39.70760330557823, 46.15374080836773, 50.38070239126682, 66.47566214203835, 68.69854286313057, 67.12349697947502, 49.76521521806717, 24.77949634194374, 5.493542393669486, 0.39935471140779555, 0.04086700748302974, 0.029006921722611878, 0.14243681158404797, 0.036716190370498225, 0.0482846399245318, 0.023732160916551948, 0.024409734323853627, 0.022287119609245565, 0.014822141856711823, 0.06669491922366433, 0.06952728872420266, 0.01594928606209578, 0.04119594217627309, 0.026988996214640792, 0.028483199239417445, 0.03342836113006342, 0.043456208586576395, 0.016970279029919766, 0.044051411023247056, 0.05098691093735397, 0.058841612699325196, 0.0048127511490747565, 0.04318429681006819, 0.049775699953897856, 0.018798997698468156, 0.025001498761412222, 0.07522026644437574, 0.05786053057818208, 0.05184167210245505, 0.02610568091768073, 0.09827303569181822, 0.011881293557962636, 0.028770057870133314, 0.03866010520141572, 0.02967162257846212, 0.037387451811810024, 0.07631814034539275, 0.0692037791304756, 0.009092959389818134, 0.03561725890904199, 0.026467279385542497, 0.04913320786727127, 0.07593845759402029, 0.13011248462134972, 0.11371321030310355, 0.0769719501840882, 0.11742670205421746, 0.1994593275594525, 0.10687323592719622, 0.1084757257194724, 0.11552667783689685, 0.1392602562555112, 0.1246764458483085, 0.12672256183577701, 0.22355632827384397, 0.15689082036260515, 0.08438475866569206, 0.12732992065139115, 0.1921146037057042, 0.18042843468720093, 0.22230297443456948, 0.09273641364416108, 0.12127246678574011, 0.1324764030869119, 0.15776830608956516, 0.09168305376078933, 0.12066457362379879, 0.13850317656761035, 0.09115972090512514, 0.1111750652489718, 0.17076832882594317, 0.233141967037227, 0.09270726950489916, 0.1442235172726214, 0.3240822645602748, 0.2035480269114487, 0.09605175058823079, 0.12498145370045677, 0.132673398766201, 0.21947224508039653, 0.20791681279661134, 0.5709917983040214, 8.571865987032652, 45.58609686791897, 80.14845326542854, 86.85374066233635, 85.00598341226578, 81.9261422753334, 78.18121522665024, 70.67439123988152, 55.67034915089607, 52.26881727576256, 56.889236345887184, 39.14559826254845, 34.147164076566696, 34.62605997920036, 70.23805305361748, 60.49058809876442, 58.59304592013359, 75.04636064171791, 43.68261180818081, 33.38554434478283, 31.42413329333067, 23.000276014208794, 15.159808080643415, 8.98367078974843, 5.652061337605119, 3.3866912964731455, 1.1067922599613667, 1.4978329581208527, 0.39220679027494043, 0.22166806709719822, 0.12957024184288457, 0.32619029050692916, 0.183254933799617, 0.20571383647620678, 0.20960025605745614, 0.15697861643275246, 0.2963082189671695, 0.20345908793387935, 0.3956073703011498, 0.8332986698951572, 0.6047576176933944, 0.7798031810671091, 2.457611463032663, 1.7802611156366765, 2.1735237445682287, 0.5131627013906837, 0.29371669865213335, 0.16858240705914795, 0.6759922171477228, 0.7558362639974803, 0.4054157721111551, 0.13534477417124435, 0.17945248080650344, 0.26007799431681633, 0.26078187685925514, 0.2766178239835426, 0.2658938494278118, 0.20162213884759694, 0.18046114855678752, 0.38889277435373515, 1.0588752874173224, 0.6393843283876777, 0.45014171744696796, 0.23330314666964114, 0.14743085688678548, 0.22474873694591224, 0.16793932125438005, 0.20666954456828535, 1.1688869842328131, 2.769715078175068, 4.78092435747385, 8.696475550532341, 23.596859201788902, 37.7801301330328, 51.668654680252075, 72.37688228487968, 76.32870063185692, 74.69878569245338, 38.44535283744335, 36.72667846083641, 29.577979557216167, 23.468766175210476, 28.23851153254509, 28.956783190369606, 45.96700742840767, 53.157779574394226, 60.08088268339634, 76.50273129343987, 78.60666319727898, 74.18724954128265, 58.184020668268204, 30.623324364423752, 6.268438138067722, 0.7303610653616488, 0.21736141381552443, 0.1430893226643093, 0.20918451977195218, 0.1829229117720388, 0.1434298645472154, 0.10405174631159753, 0.15474322310183197, 0.1143682817928493, 0.1711743578198366, 0.14635483181336895, 0.21837168460479006, 0.13673780020326376, 0.23819876834750175, 0.10572477724053897, 0.17678867530776188, 0.16547506442293525, 0.20625973062124103, 0.1087657421885524, 0.17901369341416284, 0.14678646490210667, 0.10543949567363597, 0.07885911298217252, 0.13339013530639932, 0.22792606410803273, 0.1394717238144949, 0.14821824588580057, 0.10403788299299777, 0.13329153356608003, 0.20474307762924582, 0.08742466234252788, 0.2550932258600369, 0.14109493436990306, 0.16208031767746434, 0.12104368492146023, 0.13941904617240652, 0.10897234868025407, 0.09245226756320335, 0.15110962354810908, 0.12137523197452538, 0.1455369108589366, 0.13894809409976006, 0.17756885063135996, 0.21314660873031244], [0.04554875704343431, 0.04019378306111321, 0.02837871783412993, 0.055344913416774943, 0.0529616471612826, 0.07489775132853538, 0.05493255019246135, 0.04998677417461295, 0.029758958517049905, 0.02597697952296585, 0.03051262247026898, 0.042751127475639805, 0.07048546816804446, 0.009653775341575965, 0.023105573054635897, 0.03651337625342421, 0.0392564097273862, 0.05079558897705283, 0.05733564292313531, 0.02542152094974881, 0.05562687016208656, 0.03194521981640719, 0.02362090741371503, 0.047437444954994135, 0.07326814346015453, 0.021248378179734573, 0.05350745967007242, 0.01697574680292746, 0.052850677529932, 0.0404891355719883, 0.04018309242383111, 0.019953213595726993, 0.010246829260722734, 0.03759395069209859, 0.023229038597492035, 0.07650974061107263, 0.060901829492649995, 0.38102835416793823, 11.785696484148502, 34.38148230314255, 60.220012217760086, 70.49054950475693, 63.460497334599495, 58.63631419837475, 52.48471409082413, 49.90701600909233, 36.56661584973335, 41.94792129099369, 50.118569657206535, 28.83746199309826, 12.378534972667694, 24.36920765787363, 37.534568309783936, 42.27178551256657, 56.96952223777771, 81.72649338841438, 49.65559110045433, 30.5337555706501, 18.33883624523878, 9.703943990170956, 5.791202746331692, 2.9703103518113494, 0.9198712650686502, 0.19018068560399115, 0.0923651023185812, 0.11430263140937313, 0.042736841132864356, 0.05492965581652243, 0.07552801282145083, 0.027245645724178758, 0.131569454097189, 0.040622948508826084, 0.04221747876727022, 0.1017930124362465, 0.15740463888505474, 0.12960185733390972, 0.130850387213286, 0.5262514553032815, 0.556103247217834, 0.6914555467665195, 1.7870971863158047, 1.2064666114747524, 0.2025994285941124, 0.5182324012275785, 0.2645430515985936, 0.05999540371703915, 0.1012043037917465, 0.1551165827549994, 0.02956283300591167, 0.017653197755862493, 0.06002170543069951, 0.2970345737412572, 0.33857818983960897, 0.131447994208429, 0.08855301624862477, 0.15069403569214046, 0.12599714216776192, 0.684934324817732, 0.6057838001288474, 0.3918344993144274, 0.19260513363406062, 0.10187765437876806, 0.08530231294571422, 0.029729441448580474, 0.041542261678841896, 0.024461415632686112, 0.10955438541714102, 0.04464766359888017, 0.11095231704530306, 0.11878460965817794, 0.009873241397144739, 1.2658520811237395, 2.7700321236625314, 9.447651542723179, 18.473343327641487, 34.60437074303627, 37.36530639231205, 61.124435886740685, 68.85934263467789, 57.15404033660889, 56.758534759283066, 39.80806991457939, 32.85705730319023, 28.21317069232464, 18.528332076966763, 27.654382176697254, 42.28417284786701, 55.61278223991394, 62.43228390812874, 58.76409374177456, 55.25228038430214, 32.4628284573555, 5.679863970726728, 0.3931802208535373, 0.0217403423084761, 0.09732773993164301, 0.01082152522940305, 0.0235043456996209, 0.050108723880839534, 0.12453521514544263, 0.028252901538508013, 0.0028761100611518486, 0.020701665816886816, 0.07510842478950508, 0.021609787399938796, 0.02920187278505182, 0.07358850634773262, 0.019589425792219117, 0.048988863854901865, 0.036530089419102296, 0.033137283389805816, 0.012039833000017097, 0.07189805721282028, 0.0452799437334761, 0.027889601697097532, 0.039030436892062426, 0.057613350872998126, 0.07126221476937644, 0.04105807711312082, 0.06205650366609916, 0.019621649844339117, 0.04498830567172263, 0.03778087171667721, 0.00749983364585205, 0.027257739020569716, 0.042686519809649326, 0.028152511222288013, 0.043826484616147354, 0.03160965032293461, 0.024156327999662608, 0.032221677247434855, 0.03947395547584165, 0.028628641630348284, 0.05079051268694457, 0.07310035871341825, 0.07194321689894423, 0.011383975761418696, 0.0363416581240017, 0.05422385111160111, 0.040583562731626444, 0.01385391744406661, 0.0864734071365092, 0.0457899958564667, 0.05248081710305996, 0.03148341471387539, 0.04228669517033268, 0.031416023994097486, 0.032734011474531144, 0.042281047426513396, 0.062116803164826706, 0.06529035279527307, 0.06370223098201677, 0.01304775118114776, 0.026508097507758066, 0.04547652381006628, 0.016102294648590032, 0.032384689984610304, 0.08291911348351277, 0.018014946508628782, 0.04904943794826977, 0.030220053013181314, 0.04605027446814347, 0.036372375616338104, 0.04077026853337884, 0.029258762115205172, 0.014646905019617407, 0.054373735256376676, 0.09163632072159089, 0.00815412402516813, 0.01966713236470241, 0.016957176412688568, 0.08896405473933555, 0.025085515444516204, 0.4326436563860625, 15.390005428344011, 42.574918046593666, 72.90215849876404, 78.98318499326706, 75.73062032461166, 67.59552285075188, 64.20423522591591, 61.2235763669014, 48.72201919555664, 47.42628112435341, 56.858230009675026, 43.93262319266796, 17.052096091210842, 25.424810014665127, 25.720574744045734, 41.96644149720669, 46.96872487664223, 60.81075131893158, 52.658231779932976, 25.74176050722599, 12.076119650155306, 8.092711698263884, 3.4632966108620167, 1.5650273649953306, 0.3996769222430885, 0.17321174615062773, 0.01696572780929273, 0.13479289831593633, 0.06277735912590288, 0.1976594710140489, 0.06890031494549476, 0.46161876409314573, 0.4517893149750307, 0.6018104602117091, 0.3942091640783474, 0.6978283391799778, 0.6625127966981381, 0.48473221133463085, 1.0389423882588744, 2.4584224820137024, 2.1406246349215508, 2.587618874385953, 2.8065453143790364, 1.5906698140315711, 2.1187900565564632, 1.1527241952717304, 0.36717753333505243, 0.26900977129116654, 0.3902836481574923, 0.9302439959719777, 0.0982031476451084, 0.27941254433244467, 0.9479804348666221, 2.625594986602664, 1.4549994003027678, 1.1167788365855813, 0.7555749686434865, 1.6272633941844106, 1.9840790913440287, 1.4008728484623134, 1.9489841745235026, 1.3537284219637513, 1.0812418372370303, 1.066221718210727, 0.5607422045432031, 0.3709997422993183, 0.16666008130414411, 0.3011958848219365, 0.23662830964894965, 0.1800083345733583, 0.03587707738915924, 0.0755797405145131, 0.08804307915852405, 0.744211619021371, 1.7932957224547863, 6.900845803320408, 16.822126731276512, 31.632970087230206, 34.73648205399513, 50.116570964455605, 56.631716564297676, 51.9411114603281, 52.311511784791946, 42.2406841814518, 40.336047783493996, 35.29403753578663, 30.044218339025974, 35.90588070452213, 50.619857758283615, 60.99843464791775, 69.96339619159698, 68.34886282682419, 63.831118047237396, 39.58762474358082, 8.625322468578815, 0.9713503683451563, 0.015765977441333234, 0.11047827763832174, 0.05148775671841577, 0.042235635410179384, 0.024009764965740032, 0.07315238326555118, 0.026468468677194323, 0.05933686639764346, 0.012937636874994496, 0.060039899180992506, 0.008268421261163894, 0.05214275770413224, 0.05522277075215243, 0.039547257401864044, 0.07981093222042546, 0.0371628630819032, 0.06461171069531702, 0.04543586153886281, 0.04107272710825782, 0.021157053197384812, 0.04321954140323214, 0.058138583626714535, 0.08762693469179794, 0.0463447994843591, 0.05312971392413601, 0.07002395621384494, 0.022975068241066765, 0.039254591465578414, 0.06322782050119713, 0.02547695938119432, 0.026091971594723873, 0.04877819781540893, 0.03562680663890205, 0.040283427078975365, 0.03664179748739116, 0.008642769826110452, 0.015906280459603295, 0.03932121777324937, 0.06866782976430841, 0.07260323851369321, 0.0758379782200791, 0.016969392163446173, 0.12537686998257414, 0.16012508509447798, 0.13560856314143166, 0.15719294868176803, 0.1000970417226199, 0.20756222947966307, 0.15346147469244897, 0.11022035163477995, 0.1263238355750218, 0.15965898666763678, 0.1163887046277523, 0.17835805047070608, 0.17316034500254318, 0.14999763399828225, 0.17847581446403638, 0.19936394674004987, 0.12378701154375449, 0.15750980121083558, 0.13622586673591286, 0.08804963974398561, 0.25891139754094183, 0.13604571780888364, 0.1478375686565414, 0.22293415619060397, 0.17237257008673623, 0.14404575806111097, 0.15424052195157856, 0.11993024818366393, 0.10113554380950518, 0.07994404382770881, 0.21129768138052896, 0.1931600077659823, 0.08957498328527436, 0.17733290704200044, 0.15185717405984178, 0.17710797692416236, 0.2484797252691351, 0.6781932490412146, 21.841473095119, 55.123056918382645, 86.58427432179451, 89.96746078133583, 83.3184027671814, 78.74325826764107, 71.45851716399193, 67.1073630452156, 52.574472874403, 55.8140042424202, 62.274531573057175, 42.438357174396515, 20.491194650530815, 34.53895725309849, 53.08894246816635, 53.70208516716957, 72.65058919787407, 92.16381892561913, 57.35276207327843, 41.40651874244213, 25.72226945310831, 13.645848669111729, 7.68690962344408, 4.369078231975436, 1.819769258145243, 0.7225675054360181, 0.3442877990892157, 0.3117701830342412, 0.27444837789516896, 0.29549482511356473, 0.16364786715712398, 0.4063776845578104, 0.44885851442813873, 0.33424259279854596, 0.2868718112586066, 0.5165136465802789, 0.38515748572535813, 0.41287521715275943, 0.5419676494784653, 1.2317705224268138, 1.2118863081559539, 3.198642712086439, 4.247816288843751, 4.080106588080525, 2.9668986098840833, 2.677015489898622, 1.4684756146743894, 0.4207643063273281, 0.5661281186621636, 0.9563516231719404, 0.10068393210531212, 0.21906718087848276, 0.574283906025812, 2.2800574405118823, 1.5657028974965215, 0.7799568946938962, 0.662919731112197, 0.6417937553487718, 1.4886798430234194, 1.7267908598296344, 2.1113312942907214, 1.1323279584757984, 1.090807467699051, 0.5934298317879438, 0.33723000437021255, 0.2898634976008907, 0.2341506496304646, 0.24960979353636503, 0.5365642800461501, 0.21052308700745925, 0.1645730432937853, 0.2817142114508897, 0.3706447879085317, 2.1857785619795322, 3.3664982300251722, 11.975799333304167, 26.009013466537, 46.382712721824646, 50.45970015227795, 73.74022632837296, 79.29582461714745, 69.30499792098999, 68.21267813444138, 50.72374418377876, 46.30971483886242, 41.19548946619034, 30.47547809779644, 41.841215416789055, 58.807506412267685, 70.07907718420029, 79.37906295061111, 77.61397406458855, 75.50389409065247, 49.68857333064079, 11.658423263579607, 1.5319385030306876, 0.1429331599501893, 0.22798867168603465, 0.15490461053559557, 0.17667536420049146, 0.14675386977614835, 0.16966318187769502, 0.08658095917780884, 0.061856060710852034, 0.09759639739058912, 0.16891818435397, 0.16299603885272518, 0.10310276207746938, 0.21647653629770502, 0.16326923825545236, 0.17676332354312763, 0.05797655052447226, 0.18391661782516167, 0.1761579536832869, 0.1617627526866272, 0.15289671515347436, 0.14418261009268463, 0.17719575815135613, 0.22370106191374362, 0.1503307098755613, 0.08673567470395938, 0.13530276861274615, 0.08501493110088632, 0.11839154598419555, 0.21163871308090165, 0.10509803352761082, 0.12464707164326683, 0.1582257659174502, 0.11997889596386813, 0.12267424273886718, 0.14879226742777973, 0.08749544838792644, 0.15599671052768826, 0.16527054336620495, 0.10252485910314135, 0.12766057712724432, 0.16991905955364928, 0.17981488635996357], [0.015074523089424474, 0.02789565762213897, 0.032990174877340905, 0.020045277015015017, 0.08071800737525336, 0.03953422528866213, 0.06440717479563318, 0.01514720532213687, 0.027013169819838367, 0.05245353946520481, 0.0014524622042699775, 0.04816393702640198, 0.040589128839201294, 0.02845773986337008, 0.037218449942884035, 0.03271773617598228, 0.049998867471003905, 0.0198109698612825, 0.06259274989133701, 0.04243480187142268, 0.037864500627620146, 0.02571961384091992, 0.03329655199195258, 0.014932676403986989, 0.06866284253192134, 0.14171713613905013, 0.022332036242005415, 0.040391621078015305, 0.04850460507441312, 0.04147433290199842, 0.0787955999840051, 0.02684111586859217, 0.0650041138578672, 0.18380231224000454, 0.025333325975225307, 0.07396574001177214, 1.2374633294530213, 10.868746787309647, 47.347420156002045, 67.6404820382595, 69.88801583647728, 67.41801157593727, 49.42057751119137, 53.58129724860191, 28.97545348852873, 30.45182056725025, 22.07426380366087, 43.070392459630966, 60.79887695610523, 24.85392674803734, 41.34993597865105, 62.22858443856239, 66.80803030729294, 44.751703441143036, 31.410896703600883, 25.27830697596073, 14.532466493546963, 6.8859753012657166, 3.94949643407017, 0.8157562580890954, 0.11684451688779518, 0.03805971886322368, 0.01653785369853722, 0.0800161063671112, 0.01657968485233141, 0.11185800438397564, 0.14523812220431864, 0.0997750906390138, 0.22883054916746914, 0.1426826702663675, 0.362915201112628, 0.34284482651855797, 0.22245658416068181, 0.4595172393601388, 0.8086495706811547, 0.6159449892584234, 1.5558142843656242, 3.1857618782669306, 1.461631825659424, 0.6044246011879295, 2.170774592086673, 0.2202663430944085, 1.426501760724932, 1.259430544450879, 0.301425505313091, 0.182456768816337, 0.4067344794748351, 0.12558231130242348, 0.10428132227389142, 0.40274959173984826, 0.6552715133875608, 1.845665699802339, 2.354071056470275, 0.3645859536482021, 0.7450977433472872, 1.4450764702633023, 1.5714364335872233, 1.2010818254202604, 1.1772030754946172, 0.9951348952017725, 0.9420427191071212, 1.1173485685139894, 1.3199172425083816, 0.5783249891828746, 0.3993568191071972, 0.1820362382568419, 0.032791012126835994, 0.1336422428721562, 0.20870228705462068, 0.04986611209460534, 0.2448198982165195, 0.06928117029019631, 0.2415303434827365, 0.6853847787715495, 4.9588374607265, 8.258392307907343, 21.077563986182213, 40.873935520648956, 48.79131607711315, 49.63390566408634, 70.55673435330391, 74.67040881514549, 34.239696711301804, 19.822322241961956, 14.542387761175632, 23.873117677867413, 28.945490196347237, 38.98927845060825, 46.86248637735844, 52.94330768287182, 60.93110226094723, 54.018152207136154, 28.446050696074963, 15.398944448679686, 2.8639630833640695, 0.6715418840758502, 0.14012836123583838, 0.038110285095172, 0.05697072148905136, 0.06800974515499547, 0.050217274110764265, 0.043938029411947355, 0.04607774506439455, 0.06862962400191464, 0.01719641328236321, 0.06503836397314444, 0.024763480869296473, 0.050317434361204505, 0.09370290514198132, 0.015992430817277636, 0.05794428194349166, 0.021159695243113674, 0.03171965516230557, 0.0531071415025508, 0.02061743762169499, 0.047864239240880124, 0.0782039004843682, 0.08474927191855386, 0.05248440909781493, 0.0428294314770028, 0.06240349481231533, 0.04310831202019472, 0.10203513811575249, 0.013766556457994739, 0.043000140285585076, 0.011725469448720105, 0.0632053853769321, 0.05831543370732106, 0.027947060625592712, 0.00392015436773363, 0.013578812577179633, 0.021090981645102147, 0.013917617834522389, 0.02175087338400772, 0.026155712803301867, 0.08863736133207567, 0.021247339172987267, 0.007918874343886273, 0.014681083703180775, 0.0404097035061568, 0.04154802816628944, 0.03927088160708081, 0.012260373314347817, 0.07207160102552734, 0.03552365553332493, 0.056381393151241355, 0.060077091911807656, 0.08356050719157793, 0.040698079828871414, 0.019099890341749415, 0.044777572838938795, 0.030026170643395744, 0.047349426240543835, 0.11549801609362476, 0.1030798074498307, 0.06275229679886252, 0.03948054574721027, 0.049900061640073545, 0.014658939871878829, 0.024695802567293867, 0.019394565642869566, 0.06290638892096467, 0.060242765248403884, 0.06234549597138539, 0.05612727065454237, 0.007526793087890837, 0.02149289914086694, 0.0370661686611129, 0.012882942446594825, 0.07930806779768318, 0.013947901170467958, 0.037369584606494755, 2.29904193431139, 15.42957840487361, 55.78443802893162, 76.22368946671486, 78.26113253831863, 75.70323899388313, 59.80934925377369, 65.25114744901657, 37.52457104623318, 45.31998574733734, 33.239221796393394, 50.5990918725729, 62.467002645134926, 32.734924256801605, 27.60894801467657, 41.28285437822342, 55.25860704481602, 36.95714749395847, 34.453879818320274, 31.12419828772545, 13.552921805530787, 4.815489202737808, 2.8720925096422434, 0.38750299892853945, 0.20886217535007745, 0.06679265265120193, 0.12724896718282253, 0.2000673394650221, 0.1740381572744809, 0.296325555536896, 0.2894014958292246, 0.5936578789260238, 0.9607365285046399, 1.3379742298275232, 1.2780274590477347, 1.752737055066973, 3.1028042547404766, 2.1006063697859645, 3.3881060080602765, 4.303995324298739, 4.972420781850815, 5.718999495729804, 4.893472893163562, 4.391925456002355, 5.109533099457622, 2.0443017035722733, 0.9537972696125507, 0.5806305748410523, 0.12951412063557655, 0.03979070039349608, 0.579516818979755, 1.1145411129109561, 1.7370580276474357, 4.481916502118111, 4.053101912140846, 5.524861738085747, 5.51031706854701, 3.4431892773136497, 3.878104677423835, 5.523831518366933, 4.4759398978203535, 3.034540442749858, 2.695548520423472, 2.8200543019920588, 2.914139390923083, 3.0089982133358717, 1.8337516766041517, 1.3582569477148354, 1.2556558032520115, 0.8400829683523625, 0.2295102525386028, 0.9232331940438598, 0.49273734271992, 0.26719801069702953, 0.37840569333638996, 0.07662358606467023, 0.038351657494786195, 0.5715498339850456, 2.888832511380315, 9.20033611357212, 17.001674696803093, 39.83347535133362, 54.8228844255209, 58.31882983446121, 67.28195607662201, 75.62134578824043, 43.99582140147686, 28.88951539993286, 21.57475970685482, 27.640345729887486, 37.85594366490841, 47.983878403902054, 54.0253110229969, 60.5898729711771, 69.4202533364296, 62.45149187743664, 35.523138642311096, 19.074436873197556, 4.00315074250102, 0.8277956151869148, 0.07332326276809908, 0.03722071349329781, 0.03910420637112111, 0.005366850200516637, 0.030920835233700927, 0.030801338325545657, 0.11375515648978762, 0.05532782546652015, 0.01881472195236711, 0.03141088833217509, 0.051357747288420796, 0.08804179524304345, 0.02883495868445607, 0.0488895719172433, 0.037363524970714934, 0.03832627604424488, 0.008845573738653911, 0.039315837202593684, 0.02083753079205053, 0.020260112069081515, 0.06252926657907665, 0.00984391172096366, 0.014363514073920669, 0.02108109252731083, 0.07964163349242881, 0.0048810978478286415, 0.13172033271985129, 0.06076650999602862, 0.0669662187283393, 0.03380382106115576, 0.046463060716632754, 0.03483620414044708, 0.07168205513153225, 0.0587144197197631, 0.09576577140251175, 0.05729909586079884, 0.012944588943355484, 0.018727946335275192, 0.017875509947771206, 0.07073166081681848, 0.11165322357555851, 0.08139074197970331, 0.14763699582545087, 0.18509189772885293, 0.15659734548535198, 0.13906260748626664, 0.1272015884751454, 0.15412771550472826, 0.19004254223546013, 0.1644765937817283, 0.20850033382885158, 0.29095792793668807, 0.08736318282899447, 0.14287531696027145, 0.07649220366147347, 0.13822876004269347, 0.2127473778091371, 0.1387917681131512, 0.23398056422593072, 0.1709828243474476, 0.059657834135578014, 0.14347550662932917, 0.11854384210892022, 0.09286108703236096, 0.16389344382332638, 0.20466840273002163, 0.1474834603141062, 0.19247371412348002, 0.13680791831575334, 0.08591941616032273, 0.2638900507008657, 0.09831173127167858, 0.17081594502087682, 0.2835719852009788, 0.13282583589898422, 0.20632171479519457, 4.308981606736779, 25.34942016005516, 70.1293408870697, 90.44936612248421, 88.23596209287643, 86.90158769488335, 68.1219694018364, 72.19377011060715, 43.07275973260403, 46.47506296634674, 33.88082876801491, 56.69876776635647, 68.54911208152771, 34.0125373005867, 56.25764183700085, 77.76232570409775, 79.54891383647919, 56.86028949916363, 41.66740894317627, 31.941960006952286, 19.20845378190279, 9.446174371987581, 5.03819715231657, 1.424678808543831, 0.27708303183317184, 0.24856222240487114, 0.1540067751193419, 0.19744374352740124, 0.31635683379136026, 0.29361048247665167, 0.3317127004265785, 0.3752857045037672, 0.7858883764129132, 1.1268431902863085, 0.8082398457918316, 1.2113994592800736, 2.7462211763486266, 2.2241712268441916, 3.7411507638171315, 3.6668440885841846, 5.022287406027317, 7.2127914894372225, 6.203426476567984, 4.641096610575914, 9.323851335793734, 4.110687347128987, 4.3624969851225615, 2.7547692926600575, 0.48863293952308595, 0.5455468792933971, 0.9335983253549784, 1.534038009122014, 1.489112307317555, 3.5429469868540764, 4.2826509196311235, 6.2011076509952545, 7.133064167574048, 2.6817203499376774, 4.441432999446988, 5.943260136991739, 5.737274140119553, 3.9866107050329447, 3.8068345142528415, 4.266845192760229, 3.27888585627079, 3.1171874329447746, 3.6876332480460405, 1.3925718376412988, 0.8506769186351448, 0.482358526205644, 0.29300438531208783, 0.845644207438454, 0.5512826121412218, 0.32566663110628724, 0.5610873328987509, 0.19047573383431882, 0.5690712388604879, 1.312153902836144, 5.885736923664808, 11.788960509002209, 26.99246909469366, 47.69828572869301, 57.348935678601265, 60.18797613680363, 77.56071612238884, 81.48491755127907, 48.15306052565575, 30.70852529257536, 24.102230183780193, 35.596565902233124, 44.968971982598305, 56.04910522699356, 63.05694378912449, 71.98015317320824, 79.75185334682465, 70.65248161554337, 43.830933049321175, 24.922431372106075, 5.575121641159058, 1.1874545691534877, 0.2613724779803306, 0.11550233539310284, 0.13876277982490137, 0.17058564175385982, 0.18756650009891018, 0.12639569031307474, 0.19590809155488387, 0.18763283325824887, 0.08544263080693781, 0.16427988011855632, 0.07947371515911072, 0.1310997933614999, 0.25276982865761966, 0.12278008784051053, 0.2016808427288197, 0.07826892746379599, 0.1795164094073698, 0.24170929013052955, 0.1650352231808938, 0.1966753980377689, 0.15348543121945113, 0.27272766397800297, 0.11695974273607135, 0.13110173778841272, 0.1568033211515285, 0.14849108905764297, 0.3011525433976203, 0.1562338267103769, 0.13931671885075048, 0.143214478448499, 0.22321137803373858, 0.1376713180798106, 0.1364414903218858, 0.11135872453451157, 0.22377502435119823, 0.0901545857777819, 0.15806188486749306, 0.1703295117476955, 0.10477371499291621, 0.15845550515223294], [0.015653586597181857, 0.02921236118709203, 0.017112724999606144, 0.0711383280577138, 0.13543539040256292, 0.04960146965458989, 0.03713567079103086, 0.038531401951331645, 0.04945407541526947, 0.10941557411570102, 0.04464872115931939, 0.08356055172043853, 0.005261379419607692, 0.03413022874156013, 0.05032695611589588, 0.008823037496767938, 0.04065290901053231, 0.05453929727082141, 0.04818397501367144, 0.06989523812080733, 0.030927221414458472, 0.01942532580869738, 0.021717955423810054, 0.09170263903797604, 0.06573618316906504, 0.028937341667187866, 0.10434041207190603, 0.04219381167786196, 0.05192683354835026, 0.021149047279322986, 0.07491483556805179, 0.06140689809399191, 0.024306132363562938, 0.049569156544748694, 0.14372914301929995, 1.926137781701982, 8.095089420676231, 43.14564362168312, 63.33347775042057, 65.38428470492363, 64.04861077666283, 55.591339990496635, 40.969728380441666, 36.23815007507801, 29.88986872136593, 18.251005858182907, 21.936542093753815, 23.91607817262411, 52.28802144527435, 40.1558842509985, 54.39714767038822, 77.26514518260956, 49.49629224836826, 30.259119607508183, 10.22257151082158, 4.878538744524121, 2.289537931792438, 1.202600437682122, 0.030823118504486047, 0.11743047216441482, 0.09481911751208827, 0.07714631778071634, 0.09635319613153115, 0.12027796663460322, 0.2112003116053529, 0.16798174241557717, 0.04007098359579686, 0.6771822657901794, 0.6286624318454415, 2.7911630272865295, 1.3557017035782337, 4.099315507337451, 2.2782520623877645, 2.527126595377922, 3.8005489390343428, 1.415124696213752, 3.8116524182260036, 7.061628475785255, 4.688927968963981, 1.5049078222364187, 2.217905125580728, 1.1844200757332146, 2.3105441546067595, 1.3009848771616817, 0.3219249006360769, 0.34352775081060827, 0.295641414122656, 0.8319899369962513, 2.262694272212684, 2.842498035170138, 3.2842663675546646, 5.411133365705609, 3.484294996596873, 3.9771057525649667, 1.8822787539102137, 6.722008874639869, 4.574238248169422, 2.7697559259831905, 1.7060237866826355, 2.6246293634176254, 2.3227118141949177, 3.1156402034685016, 2.7668507443740964, 1.836280559655279, 0.7994127413257957, 1.5253282827325165, 0.4494465031893924, 0.7118158636149019, 0.20890477462671697, 0.0943221160559915, 0.07880836492404342, 0.10626130548189394, 0.05475110992847476, 0.07433349644998088, 0.03403406124562025, 0.41410347155760974, 3.257501316256821, 6.913252612575889, 20.457855239510536, 27.737937793135643, 58.047342002391815, 46.877689361572266, 24.914831779897213, 23.582678362727165, 24.632187746465206, 20.925990119576454, 24.082682132720947, 31.757876984775066, 30.08006751537323, 35.703191980719566, 54.69830811023712, 63.42959739267826, 62.86784693598747, 48.03126186132431, 20.11573299765587, 2.12004232686013, 0.6687693390995264, 0.08151292175170965, 0.009782176166481804, 0.07128197074052878, 0.03126978379441425, 0.06751295150024816, 0.0832962803542614, 0.03674015802971553, 0.013472344999172492, 0.04086310749698896, 0.03625839286542032, 0.08374510900466703, 0.017910897404362913, 0.05696310334315058, 0.00530199205968529, 0.014645303836005041, 0.03182131826179102, 0.018149518291465938, 0.027929371535719838, 0.062121037117321976, 0.014871326766296988, 0.010986480538122123, 0.028343818339635618, 0.028691382794931997, 0.03965647927543614, 0.03448779178143013, 0.05735254904720932, 0.05129484285134822, 0.02011981647228822, 0.022091344762884546, 0.0680768649908714, 0.06433047383325174, 0.023502421681769192, 0.008729532455618028, 0.014043453611520818, 0.054716481317882426, 0.024846519772836473, 0.043404454918345436, 0.03180958861776162, 0.04310388510930352, 0.03818342003796715, 0.035155431542079896, 0.02134423026291188, 0.003827006948995404, 0.15945743420161307, 0.08114243421005085, 0.009066897946468089, 0.030779760381847154, 0.07259021382196806, 0.037010771047789603, 0.0285325854565599, 0.03161860804539174, 0.015991577347449493, 0.037322053758543916, 0.013258341150503838, 0.00909390098968288, 0.010540780040173559, 0.021235904532659333, 0.04044627283292357, 0.03304931662569288, 0.04436174007423688, 0.010831167583091883, 0.007899650863691932, 0.1545463758520782, 0.023069901726557873, 0.02285569193190895, 0.04251624886819627, 0.053317306592362, 0.03316456844913773, 0.04245682510372717, 0.04292591809644364, 0.06753332345397212, 0.0044954867280466715, 0.05402518560003955, 0.19696847215527669, 3.038986916653812, 18.209456987679005, 55.47279395163059, 74.97670277953148, 74.14174318313599, 74.21399250626564, 65.95849469304085, 50.15225104987621, 49.712664037942886, 40.35360664129257, 27.2305928170681, 26.71282310038805, 34.45993289351463, 52.63447545468807, 27.339510172605515, 54.25592064857483, 79.94632691144943, 58.21541838347912, 33.30960541963577, 12.012709602713585, 4.059053817763925, 2.0854371087625623, 0.70908386958763, 0.06069002796721179, 0.13301684986799955, 0.23394430289044976, 0.20257894531823695, 0.2670904586557299, 0.7159723062068224, 0.6118383596185595, 0.9369259374216199, 1.444115478079766, 2.8740047570317984, 2.2525034565478563, 3.3337993221357465, 5.34532992169261, 5.245434232056141, 5.517311543226242, 8.392931688576937, 9.059150889515877, 6.663851095363498, 9.288856163620949, 9.896627850830555, 9.311983622610569, 8.035134337842464, 4.898551795631647, 1.1702943337149918, 0.4380679246969521, 0.6041555874980986, 0.34335061500314623, 0.1266967350966297, 0.26086657075211406, 1.8203591764904559, 4.305478194728494, 5.952791450545192, 7.020327067002654, 7.337345480918884, 7.155054537579417, 6.376312924548984, 5.089122969657183, 8.487065937370062, 7.893846994265914, 4.475785531103611, 5.330121237784624, 6.63757455535233, 6.147784162312746, 5.01482080668211, 4.695757627487183, 3.7924855342134833, 3.9508871594443917, 2.4335727654397488, 2.8729899739846587, 1.2670440296642482, 1.1377306748181581, 0.6177081540226936, 0.5452725815121084, 0.5037538718897849, 0.2855330362217501, 0.12290012280573137, 0.04874257843766827, 0.12410810173605569, 3.310792981646955, 7.574232369661331, 21.246660612523556, 26.340897157788277, 53.2679508626461, 47.67270550131798, 23.51790513843298, 25.297520644962788, 20.427967943251133, 32.84129574894905, 32.74180568754673, 40.139058753848076, 40.715294033288956, 44.951367527246475, 61.11090861260891, 73.80147144198418, 73.12832996249199, 58.17971169948578, 27.011070996522903, 4.925651466473937, 0.540866955416277, 0.03047093232453335, 0.03721176319231745, 0.013151172242942266, 0.021041688196419273, 0.03880726937495638, 0.04980523372069001, 0.052683538451674394, 0.06270997211686336, 0.05160682318091858, 0.011165498617629055, 0.052918814108124934, 0.00852270239192876, 0.04396013428049628, 0.03002468449267326, 0.012656258077186067, 0.051650858513312414, 0.04794398300873581, 0.024531539311283268, 0.03800375350692775, 0.012396015645208536, 0.07905240534455515, 0.03801376136834733, 0.015977567454683594, 0.05298559626680799, 0.026440686378919054, 0.04178302551736124, 0.07516223791753873, 0.041067762140301056, 0.04573670965328347, 0.04293722100555897, 0.03403125221666414, 0.08437018288532272, 0.018753424265014473, 0.028367131053528283, 0.02973531369207194, 0.02446793168928707, 0.06270479192608036, 0.044472924928413704, 0.033888199541252106, 0.20500348240602762, 0.1107004024379421, 0.11946368962526321, 0.11659102892735973, 0.300511535606347, 0.16163148160558194, 0.12409961898811162, 0.13634931558044627, 0.16360792476916686, 0.14930678356904536, 0.13384170248173177, 0.18287774466443807, 0.09115091903368011, 0.10193608366535045, 0.1418125763302669, 0.1332168438239023, 0.07637664384674281, 0.13357829942833632, 0.1948139729211107, 0.12126298213843256, 0.08354754929314367, 0.12894137558760121, 0.11334708658978343, 0.18589555460494012, 0.1938816424808465, 0.1513817542581819, 0.17881787032820284, 0.12622201291378587, 0.13059931865427643, 0.08730139161343686, 0.19482464500470087, 0.13854170887498185, 0.09662478507380001, 0.12044471979606897, 0.3396890067961067, 5.516340220347047, 33.22092957794666, 70.67293971776962, 86.63570076227188, 85.05040302872658, 85.06639257073402, 74.50248822569847, 58.71332086622715, 52.292053028941154, 43.74926783144474, 28.782524541020393, 31.341406032443047, 34.38258044421673, 64.44173768162727, 53.71586702764034, 71.87134221196175, 85.29019296169281, 57.993609085679054, 35.41104845702648, 13.588084168732166, 7.077766684815288, 3.628132240846753, 1.7324837855994701, 0.3594596131006256, 0.2631664864020422, 0.2968493930529803, 0.47443197341635823, 0.29321278037969023, 0.43112139275763184, 0.30768623342737556, 0.9466850606258959, 1.0899490700103343, 2.5925265485420823, 1.6909619886428118, 5.94475963152945, 5.162705071270466, 9.039145912975073, 5.535334451124072, 8.111952915787697, 13.547585941851139, 7.341473009437323, 15.542199611663818, 18.090453073382378, 16.915615014731884, 12.66826942563057, 9.775478951632977, 4.16183402761817, 7.631671987473965, 5.099160131067038, 2.0551498839631677, 0.3210985934128985, 1.9997213082388043, 3.1910694809630513, 7.9121301881968975, 12.824708931148052, 10.107134655117989, 14.223532620817423, 12.661162856966257, 15.47022957354784, 9.369512535631657, 15.72134954854846, 9.388464968651533, 6.534573482349515, 6.076913690194488, 7.573111429810524, 7.8495218977332115, 9.135426096618176, 7.59962878189981, 5.675191646441817, 3.6663472652435303, 3.7548084184527397, 2.132693510502577, 1.9252297491766512, 0.9484152146615088, 0.6593698309734464, 0.6161993381101638, 0.44372386182658374, 0.4638601985061541, 0.15231212542857975, 0.2352310682181269, 0.823627773206681, 4.968344075605273, 10.260488726198673, 28.92043624073267, 39.18065518140793, 69.79431286454201, 53.41523475944996, 36.67562060058117, 33.99243637919426, 35.33280685544014, 34.19276922941208, 35.367111414670944, 46.77908465266228, 46.26156382262707, 52.87615388631821, 71.43818065524101, 82.14190229773521, 81.32315263152122, 65.27138516306877, 32.97691807150841, 7.436798019334674, 1.246688284445554, 0.17664619779679924, 0.17450349871069193, 0.19373613700736314, 0.16294981789542362, 0.16405616712290794, 0.20176044548861682, 0.1815330918179825, 0.1801029287162237, 0.08155742834787816, 0.21742704935604706, 0.15993752953363582, 0.11578615492908284, 0.1838010802748613, 0.09559059486491606, 0.13007873174501583, 0.13204138580476865, 0.08699011261342093, 0.1052910290309228, 0.11028193504898809, 0.12649323820369318, 0.1422367137274705, 0.09759195934748277, 0.12757693708408624, 0.09427912344108336, 0.11454585546744056, 0.17256046703550965, 0.1856027328176424, 0.17242138856090605, 0.12283964519156143, 0.11351868597557768, 0.11485983588499948, 0.11212232770049013, 0.12571099970955402, 0.11119312912342139, 0.14892107457853854, 0.1586904691066593, 0.16182289633434266, 0.12571736733661965, 0.16749407717725262], [0.053775022461195476, 0.05571816174779087, 0.024637399255880155, 0.053207991950330324, 0.0362629125447711, 0.03968079203332309, 0.08825272845569998, 0.040895005004131235, 0.06067582326068077, 0.040446061320835724, 0.055464940960519016, 0.06482760887593031, 0.013556426620198181, 0.017909422385855578, 0.05593482434051111, 0.022451807744801044, 0.05254783303826116, 0.024253916708403267, 0.018033169944828842, 0.03821056779997889, 0.07691173974308185, 0.036990840671933256, 0.03413127145904582, 0.032747084405855276, 0.04872623634582851, 0.02243079012259841, 0.04720429555163719, 0.011995102831861004, 0.022926283163542394, 0.004810059936062316, 0.018375379804638214, 0.047819966421229765, 0.05650331688229926, 0.05231352959526703, 0.4128121049143374, 23.462110832333565, 30.891105495393276, 57.97551445662975, 69.34127077460289, 57.19012700021267, 59.708578661084175, 45.41053868830204, 32.61009715497494, 20.994851924479008, 20.360508263111115, 27.489746510982513, 27.819268628954887, 31.521618962287903, 49.256213530898094, 69.7551217675209, 53.117045760154724, 22.066020146012306, 12.607641778886318, 4.426701664924622, 3.1850344548001885, 1.0873582027852535, 0.10778138719615526, 0.04323184250097256, 0.09216461112373509, 0.1174090760468971, 0.1671534462366253, 0.2283474852447398, 0.22580984485102817, 1.7394676920957863, 0.6602242507506162, 1.1174873798154294, 0.9088444942608476, 1.7224237066693604, 2.511460273526609, 1.288234661333263, 4.56122157163918, 2.56693824660033, 6.547185480594635, 5.17221643589437, 4.174529621377587, 7.697111126035452, 7.258231351152062, 6.146258544176817, 7.292341170832515, 6.759833944961429, 2.739018900319934, 1.833885619416833, 0.25400764192454517, 0.07749507523840293, 0.19633513817097992, 0.12187262676889077, 0.36685300699900836, 0.9156917862128466, 3.104767086915672, 8.621246237307787, 5.800371179357171, 6.65083346888423, 5.161301996558905, 4.110708720982075, 5.133975762873888, 6.625369610264897, 5.908519076183438, 2.9137363750487566, 2.2930263821035624, 3.0756309628486633, 3.144724555313587, 3.3262232411652803, 1.9529379811137915, 2.0043116994202137, 4.5460570603609085, 3.1227123364806175, 3.431397322565317, 1.3202596991322935, 0.9591039817314595, 0.7773831265512854, 0.7269901118706912, 0.06326709495624527, 0.07568993460154161, 0.053655811279895715, 0.10207128812908195, 0.10480107797775418, 0.03009026993822772, 1.141851197462529, 6.546647334471345, 19.562963359057903, 28.85083917528391, 43.44352863729, 44.98021177947521, 33.920418843626976, 33.714948669075966, 17.045435048639774, 19.472395218908787, 39.45102587342262, 20.763746425509453, 29.365287870168686, 46.29606977105141, 51.5328461676836, 56.45973399281502, 65.07567286491394, 55.92075951397419, 35.288014858961105, 11.73429949209094, 4.714296357706189, 0.43153390812221915, 0.0885297499189619, 0.0819490670983214, 0.06570438214112073, 0.056197036246885546, 0.017926250584423542, 0.007414597521346877, 0.016828653133416083, 0.025042444904102013, 0.02161629974580137, 0.031764094965183176, 0.03581231016141828, 0.025799517170526087, 0.01786370423360495, 0.028499238906078972, 0.03886810693074949, 0.015122392542252783, 0.03685569186927751, 0.050108575451304205, 0.004740486838272773, 0.042736540563055314, 0.044376609002938494, 0.0035743622538575437, 0.0676774707972072, 0.04692669892392587, 0.027826636032841634, 0.04219782669679262, 0.00578871940888348, 0.04159743293712381, 0.03281311328464653, 0.08990922433440574, 0.015366950610768981, 0.016207900407607667, 0.006338402217807015, 0.02504361378669273, 0.07056835122057237, 0.058035291513078846, 0.037554653972620144, 0.01746409481711453, 0.024962383868114557, 0.05477946739119943, 0.023890969387139194, 0.003551634677023685, 0.056623544805916026, 0.11203122907318175, 0.021210146442172118, 0.042947214024025016, 0.11536281905137002, 0.05509274276846554, 0.0684672049828805, 0.032366614977945574, 0.06973955780267715, 0.01385598246997688, 0.038952103204792365, 0.07564737985376269, 0.0347666389279766, 0.058227589397574775, 0.06607898118090816, 0.04800564063771162, 0.010784442893054802, 0.04106183238036465, 0.08840648661134765, 0.02207312689279206, 0.0017776652862266928, 0.06429110289900564, 0.048009225210989825, 0.02206745873991167, 0.012552092084661126, 0.030538785031239968, 0.031760124475113116, 0.06326843082206324, 0.03842217265628278, 0.8311744057573378, 29.400933757424355, 41.953833773732185, 70.78240424394608, 77.21121847629547, 70.19074559211731, 70.57663768529892, 55.025960728526115, 44.50754374265671, 30.652242712676525, 29.335280880331993, 29.3204502761364, 28.03380511701107, 31.14818450063467, 53.48986655473709, 60.46900525689125, 59.12022203207016, 26.776997856795788, 14.552712757140398, 3.911149366758764, 1.4728350494988263, 0.765505617018789, 0.09299546029069461, 0.1010183957987465, 0.1994113699765876, 0.440530875348486, 0.5186148744542152, 0.8806355204433203, 1.467450144700706, 2.816605274565518, 4.380992017686367, 4.217051714658737, 3.958197492174804, 5.659577809274197, 5.948158074170351, 5.990887256339192, 7.339475266635418, 9.814236871898174, 10.160490442067385, 8.451783880591393, 10.391687136143446, 7.122284146025777, 8.38017102330923, 11.308520939201117, 6.689851200208068, 5.933535033836961, 3.9969019778072834, 1.17996612098068, 0.5134799249935895, 0.20879622810753062, 0.29598238645121455, 0.22333552449708804, 0.6011642573866993, 1.8535070540383458, 2.169744847342372, 6.004996849223971, 4.3952730763703585, 7.839575931429863, 4.767976077273488, 6.248387563973665, 8.195001259446144, 7.218895861878991, 9.156643208116293, 7.083978401497006, 7.032522512599826, 5.739117516204715, 6.467879461124539, 7.347386917099357, 4.8378415033221245, 6.339080622419715, 7.261608419939876, 5.228771651163697, 5.508541138842702, 4.219181975349784, 3.4343946492299438, 2.7254719147458673, 2.1206790301948786, 0.7839928718749434, 0.5083519220352173, 0.39300388656556606, 0.118746663647471, 0.06886821705847979, 0.08591682606493123, 0.758359981700778, 4.470145208761096, 15.797096583992243, 29.727613627910614, 36.07722491025925, 37.324048206210136, 34.48465056717396, 34.3302458524704, 25.84829919040203, 25.614900514483452, 41.79662860929966, 29.210837557911873, 37.066175043582916, 57.541885524988174, 56.574981808662415, 64.84094426035881, 72.1050600707531, 66.19183257222176, 48.38615141808987, 20.159377455711365, 7.88068687543273, 0.3381405008258298, 0.11547269401489757, 0.059191301552345976, 0.06104452222643886, 0.027974881886621006, 0.023698866316408385, 0.03393090271856636, 0.04187825048575178, 0.0315110114752315, 0.0547844546235865, 0.08043736423132941, 0.018560725620773155, 0.06626715272432193, 0.042321164219174534, 0.0843611583695747, 0.0208389315957902, 0.033319206049782224, 0.030958831339376047, 0.009595011160854483, 0.02075954220345011, 0.02838375516148517, 0.014255017649702495, 0.030671111817355268, 0.06237282927031629, 0.029245904406707268, 0.06447157837101258, 0.025202912074746564, 0.03996536855993327, 0.03241666541725863, 0.07329264175496064, 0.07497907587094232, 0.03352368999912869, 0.06674736679997295, 0.0313411709794309, 0.022400234047381673, 0.01862336659542052, 0.06482461802079342, 0.021633792166539934, 0.10510041582165286, 0.16724446322768927, 0.1346713345265016, 0.14065530092921108, 0.13622671278426424, 0.1456938305636868, 0.2239423934952356, 0.24109583086101338, 0.1426821359200403, 0.2394877007463947, 0.1472547452431172, 0.2413112614885904, 0.10473982853000052, 0.1355602196417749, 0.10504859907086939, 0.20333734602900222, 0.14593577070627362, 0.08996930861030705, 0.14487500418908894, 0.12346685645752586, 0.12150697060860693, 0.15828537521883845, 0.1472994522191584, 0.1597949184360914, 0.1710420032031834, 0.17889947688672692, 0.1746421615825966, 0.20814166869968176, 0.10107163005159236, 0.1315795473055914, 0.13525608752388507, 0.08584641109337099, 0.2179186331341043, 0.3699261514702812, 2.2493356140330434, 38.146244287490845, 63.2796498388052, 82.88752868771553, 90.52277818322182, 76.9980651140213, 78.27538177371025, 62.005091831088066, 48.55822518467903, 32.201436683535576, 30.96022378653288, 39.847226813435555, 39.895917400717735, 42.05050438642502, 64.4016270339489, 83.391814827919, 62.56050422787666, 30.693350806832314, 18.902355507016182, 6.107016149908304, 4.666525321081281, 1.6719995811581612, 0.3387300035683438, 0.2396110160043463, 0.2702666132245213, 0.2695657586446032, 0.5136738333385438, 0.4307637072633952, 0.992747435811907, 3.069850285537541, 3.671785010956228, 4.228989724069834, 6.644163401797414, 8.547400049865246, 9.980697389692068, 7.974507641047239, 15.876169390976429, 13.187126833945513, 18.312195874750614, 15.112825501710176, 14.71952760592103, 18.488572910428047, 19.081741981208324, 17.931750789284706, 18.4005943313241, 15.949938632547855, 7.484313994646072, 6.8709485325962305, 1.6748387413099408, 1.7142609134316444, 0.5289286491461098, 0.7067840429954231, 0.8249232661910355, 4.374563237652183, 12.205063831061125, 21.125107035040855, 13.969966527074575, 18.798647671937943, 15.496275275945663, 14.224749505519867, 15.60174336656928, 15.6692467443645, 15.48014609143138, 8.475031983107328, 10.995069108903408, 10.425205137580633, 10.053797867149115, 13.601412903517485, 6.871893731877208, 10.648029930889606, 10.441565159708261, 8.48608274012804, 8.1466213054955, 5.71146497502923, 4.009008128196001, 2.8990857861936092, 2.611578251235187, 0.4737221833784133, 0.46159700432326645, 0.43535582022741437, 0.3437515231780708, 0.36497703578788787, 0.2286773847299628, 1.5976331778801978, 9.069412238895893, 26.70838113874197, 38.06278556585312, 57.958734557032585, 61.43616735935211, 49.07203361392021, 48.7854377925396, 24.127090349793434, 30.111833810806274, 52.13230960071087, 32.1578112244606, 45.71616008877754, 63.621221110224724, 69.02449697256088, 74.57143172621727, 83.04286435246468, 76.48208320140839, 60.00867895781994, 25.081426240503788, 10.350342504680157, 0.6604831712320447, 0.24979485548101366, 0.17612461640965194, 0.20447444985620677, 0.10724094783654436, 0.096571936737746, 0.1285082136746496, 0.1314639949123375, 0.165070237708278, 0.1342551232664846, 0.21608998125884682, 0.14353228092659265, 0.15060110396007076, 0.12289630816667341, 0.17164679418783635, 0.27512260421644896, 0.09654665176640265, 0.11211096541956067, 0.14089960110140964, 0.11550173425348476, 0.1526436724816449, 0.16368531592888758, 0.1605752867180854, 0.18493325624149293, 0.20503797743003815, 0.1775104139233008, 0.07361030322499573, 0.13994315086165443, 0.08370063951588236, 0.17093155678594485, 0.1854300350532867, 0.08164593687979504, 0.14187487220624462, 0.09837998659349978, 0.11676190100843087, 0.15698851668275893, 0.1104784631752409, 0.08014539591385983], [0.01770344486430986, 0.022492822536150925, 0.055879259743960574, 0.05470404663356021, 0.026943394950649235, 0.04258476765244268, 0.034254226775374264, 0.021265273171593435, 0.058936136338161305, 0.019294737503514625, 0.04800128794158809, 0.026960310351569206, 0.0704430989571847, 0.04321881780924741, 0.01811798443668522, 0.08826446923194453, 0.084859191410942, 0.03363004718266893, 0.060025345665053464, 0.04266393254511058, 0.12811321299523115, 0.04333015480369795, 0.051017903024330735, 0.018527833635744173, 0.08798182228929363, 0.06169690714159515, 0.03351509592903312, 0.073974578990601, 0.04377686091174837, 0.11967291589826345, 0.014023145668033976, 0.058611327986000106, 0.011345234725013142, 0.1501281777746044, 18.79626139998436, 33.67796145379543, 52.94990032911301, 66.29213199019432, 54.50965963304043, 47.72567845880985, 47.7764817327261, 37.32183292508125, 26.105129308998585, 28.65833580493927, 34.127834513783455, 68.55367183685303, 75.59980854392052, 58.85749652981758, 56.41531057655811, 58.7709029763937, 22.03761477023363, 14.76109642535448, 5.382873807102442, 2.476193653419614, 0.1556025113677606, 0.034646010244614445, 0.06068433940527029, 0.04553556165774353, 0.181236544449348, 0.5218416138086468, 0.7302895816974342, 0.7683460239786655, 1.2360807973891497, 4.0239593759179115, 3.910118672065437, 2.234287946484983, 2.4492642609402537, 5.363597916439176, 4.870832758024335, 4.012875845655799, 6.371615901589394, 7.288976451382041, 7.4235400557518005, 11.483570896089077, 9.84426761046052, 4.286469239741564, 3.7443561293184757, 7.9598622769117355, 7.282497799023986, 5.129682468250394, 4.040954913944006, 0.7608549040742218, 0.10965371446218342, 0.3427730459952727, 0.1734914319240488, 1.5684121521189809, 7.831300450488925, 6.287611434236169, 10.373338870704174, 4.4983520451933146, 5.631506340578198, 3.7085924483835697, 3.827904383651912, 4.811380673199892, 2.9641805682331324, 6.130374446511269, 7.497466513887048, 5.099015738815069, 5.806556297466159, 6.228055329993367, 4.749051667749882, 4.126650765538216, 4.987786207348108, 3.146922024898231, 4.323839759454131, 1.7880389420315623, 6.967712240293622, 1.0245569539256394, 2.0560183748602867, 1.0668667335994542, 1.6230971552431583, 0.9993375884369016, 0.3422162274364382, 0.0049333515380567405, 0.19594230456277728, 0.05118438530189451, 0.1632590263034217, 0.10558107518590987, 0.2253636359819211, 0.4606928309658542, 8.04284792393446, 25.965895280241966, 39.18541632592678, 38.24278570711613, 30.48040833324194, 24.895716905593872, 41.55008263885975, 118.36846679449081, 39.55465391278267, 27.177009992301464, 25.4685627669096, 40.43566703796387, 55.17691522836685, 50.991257429122925, 52.65562132000923, 60.52523843944073, 54.60548669099808, 31.176595576107502, 12.66980929300189, 1.8711398891173303, 0.05936910900345538, 0.07845988206099719, 0.03744412220839877, 0.022380283262464218, 0.014994321973063052, 0.15857438236707821, 0.14619532943470404, 0.056759955259622075, 0.009747149579197867, 0.05008120875572786, 0.04227644982165657, 0.05038518502260558, 0.07597557982080616, 0.038514154439326376, 0.01917313475132687, 0.006486148513431544, 0.05601312092039734, 0.047535389894619584, 0.09104990531341173, 0.10467486092238687, 0.021773212029074784, 0.05296749899571296, 0.04618917853804305, 0.006326068651105743, 0.014578689588233829, 0.029077147446514573, 0.04519421454460826, 0.004279174800103647, 0.03780671700951643, 0.05800662976980675, 0.05514672287972644, 0.01339657914286363, 0.06875316932564601, 0.0918059608375188, 0.026351316955697257, 0.04254340034094639, 0.02040521678281948, 0.027950498624704778, 0.023069137314450927, 0.012704058881354285, 0.04929544134938624, 0.013561632786149858, 0.03439181724388618, 0.05052317996160127, 0.06437121774069965, 0.04548150362097658, 0.008867962478689151, 0.01492322793637868, 0.04443546502443496, 0.0038066616662035813, 0.04947051769704558, 0.024955901208159048, 0.061434788003680296, 0.02694761034945259, 0.0701231145649217, 0.025202806318702642, 0.0669784790079575, 0.05441082779725548, 0.04740608550491743, 0.016600572598690633, 0.11317280805087648, 0.03407382551813498, 0.03683430317323655, 0.1043117132212501, 0.012588202207552968, 0.09193536912789568, 0.0053954094346408965, 0.038285647169686854, 0.05472922770422883, 0.2842882467666641, 22.831817753612995, 42.959343418478966, 65.87586432695389, 78.43904659152031, 63.779364824295044, 56.29509262740612, 58.744110614061356, 48.78195717930794, 38.214116245508194, 34.07694764435291, 39.115807861089706, 63.59078474342823, 56.86664275825024, 46.52153827250004, 57.88202807307243, 64.74880680441856, 26.994900964200497, 12.869547475129366, 4.99208995141089, 2.14480132330209, 0.2441528855706565, 0.05249646899756044, 0.10958291357383132, 0.7118079671636224, 0.30932450958061963, 2.3373954137787223, 2.6612254371866584, 2.4975910177454352, 3.765932796522975, 9.318147841840982, 7.118997322395444, 7.986640390008688, 6.816705018281937, 9.976419769227505, 7.455365248024464, 6.118797892704606, 9.082972761243582, 11.565827932208776, 8.91193063929677, 15.499525051563978, 13.506896775215864, 10.488647483289242, 6.908287703990936, 5.202814294025302, 6.5352564956992865, 2.8117215866222978, 3.3782946970313787, 1.6205567540600896, 0.36567842471413314, 0.4736816027434543, 0.4756345198256895, 2.121276785619557, 6.337132751941681, 6.325514875352383, 7.766803186386824, 3.9006298687309027, 2.663258803077042, 3.503998126834631, 4.326939918100834, 4.846763424575329, 7.365888599306345, 8.004507031291723, 9.101105388253927, 7.208119165152311, 5.647019483149052, 4.365530647337437, 7.029525898396969, 5.3503247536718845, 5.811362564563751, 9.240879938006401, 7.093654107302427, 7.449257075786591, 9.10301573574543, 5.851650852710009, 5.114924060180783, 7.070688139647245, 3.6807142943143845, 1.9776167068630457, 2.3158410703763366, 0.5649454914964736, 0.5200492381118238, 0.2436485220096074, 0.40127503336407244, 0.12509636784670874, 0.113132368423976, 0.43485389091074467, 6.0515927989035845, 20.45068122446537, 34.65969577431679, 38.18760886788368, 34.727438539266586, 26.95925697684288, 40.116256177425385, 112.27100998163223, 39.62326683104038, 38.37470322847366, 33.28494854271412, 48.148470371961594, 61.33544996380806, 58.93104538321495, 58.980416133999825, 68.31752210855484, 66.70414388179779, 42.00464464724064, 20.452117547392845, 3.8145219767466187, 0.09032161353388801, 0.023865760485932697, 0.08348192859557457, 0.041810024849837646, 0.10502069431822747, 0.12535114714410156, 0.06903151923324913, 0.034813015736290254, 0.06130437039246317, 0.021201108938839752, 0.035337758672540076, 0.0495819474599557, 0.08392605202971026, 0.00543741731235059, 0.0414703549904516, 0.08609392476500943, 0.07090647370205261, 0.0734691764228046, 0.0594166658265749, 0.06786563491914421, 0.05169871590624098, 0.0243078226048965, 0.10447341977851465, 0.035205567328375764, 0.06505034223664552, 0.05324593425029889, 0.04684924839239102, 0.07167562071117572, 0.014116582060523797, 0.04043440960231237, 0.038531494719791226, 0.032286399946315214, 0.05390293161326554, 0.05342496253433637, 0.06369579656166025, 0.07519612438045442, 0.1035382914415095, 0.13022481609368697, 0.10558200287050568, 0.0746812742727343, 0.07942477051983587, 0.18927738798083737, 0.12254781046067365, 0.0766643151291646, 0.16917098953854293, 0.15379766758996993, 0.1093915656383615, 0.09317402102169581, 0.20745509304106236, 0.10335699960705824, 0.1313515001675114, 0.1356793788727373, 0.19577731029130518, 0.08220547169912606, 0.1695367941283621, 0.17237384658074006, 0.41608987434301525, 0.09107026242418215, 0.10913811478530988, 0.10611337318550795, 0.2148686139844358, 0.10898812673985958, 0.1298715834855102, 0.17278450657613575, 0.1683250450878404, 0.19215791544411331, 0.08222826305427589, 0.1467492981464602, 0.06242254574317485, 0.6348621554207057, 28.925404474139214, 60.502770245075226, 79.670689702034, 87.93152242898941, 73.68936225771904, 65.52433758974075, 64.30894240736961, 50.05792871117592, 38.26532989740372, 39.786171689629555, 44.050827249884605, 79.20972883701324, 84.23832580447197, 70.68172484636307, 65.92359736561775, 67.09398776292801, 30.801046527922153, 20.787022076547146, 7.099420297890902, 3.661911003291607, 0.3681220201542601, 0.26431452948600054, 0.16874320077477023, 0.4266207420732826, 0.31591884791851044, 2.086825934238732, 2.676530540920794, 2.6485647540539503, 5.029942095279694, 11.355094090104103, 12.897985149174929, 10.550526212900877, 9.51278479769826, 12.40309115499258, 17.313134483993053, 13.364065289497375, 13.815059289336205, 20.31115271151066, 21.93240601569414, 24.28399533033371, 28.93721044063568, 17.223252207040787, 16.621066220104694, 18.931110464036465, 15.330920498818159, 13.619134202599525, 11.952153202146292, 2.6423003152012825, 0.8817287336569279, 0.5492832069285214, 1.6115580056793988, 2.199144819751382, 5.165402926504612, 3.354043923318386, 9.046717006713152, 10.084596164524555, 13.715654723346233, 12.211128305643797, 14.20928243547678, 13.399281799793243, 11.596929263323545, 17.63858512043953, 18.438571393489838, 16.940868459641933, 13.954602051526308, 18.477656096220016, 14.161437302827835, 12.956900037825108, 10.564645305275917, 12.45650488883257, 13.967447262257338, 9.859000369906425, 16.543196998536587, 8.169174045324326, 7.980400174856186, 6.997230956330895, 4.359363578259945, 3.421991877257824, 1.853181696496904, 0.7962035166565329, 0.38494063017424196, 0.2364550923812203, 0.4723472805926576, 0.3477912407834083, 0.5830933176912367, 1.1187191074714065, 10.819441583007574, 33.781688287854195, 51.96987211704254, 50.42066104710102, 43.59905809164047, 34.770999401807785, 50.77623836696148, 120.29548019170761, 47.80168958008289, 43.33623759448528, 36.68572425842285, 60.28585888445377, 69.61384534835815, 70.12126252055168, 67.7916531264782, 77.93565720319748, 75.81543937325478, 49.82623994350433, 23.554922752082348, 4.48803654871881, 0.18631218146765605, 0.11431363003794104, 0.16974466969259083, 0.12729594513075426, 0.23474607471143827, 0.20819179335376248, 0.3145443310495466, 0.1162774937984068, 0.12623151240404695, 0.1481525064446032, 0.16764578700531274, 0.1417731386027299, 0.21243822877295315, 0.14198705524904653, 0.11240412117331289, 0.14629701850935817, 0.16901556897209957, 0.21270598081173375, 0.16424773028120399, 0.18233070761198178, 0.11575457654544152, 0.15692025393946096, 0.25770505133550614, 0.08444447928923182, 0.22530830145115033, 0.14470518595771864, 0.09974717846489511, 0.2204203832661733, 0.09883998456643894, 0.12707122281426564, 0.225840866623912, 0.12036916174110956, 0.15346469561336562, 0.14904140640283003, 0.11323557890136726, 0.20886358543066308], [0.05115060645039193, 0.06509182829177007, 0.03949217891204171, 0.048044592258520424, 0.025439349192311056, 0.040703705308260396, 0.040842653907020576, 0.024539686237403657, 0.034804811293724924, 0.13672525790752843, 0.04481179697904736, 0.017130068990809377, 0.05880459437321406, 0.06827619843534194, 0.06462307297624648, 0.10227962382487021, 0.06127856962848455, 0.06370784903992899, 0.0730810480308719, 0.05087139565148391, 0.025063620232685935, 0.03991908823081758, 0.07399886206258088, 0.037344819138525054, 0.010955938378174324, 0.06416284493752755, 0.04958317942509893, 0.05166597977222409, 0.16018761845771223, 0.10381530548329465, 0.12385036126943305, 0.12870292353909463, 0.043208182833041064, 5.172839127480984, 30.0548729673028, 53.182406052947044, 65.66571280360222, 58.59600216150284, 53.10028485953808, 43.716034814715385, 55.063365921378136, 34.677254632115364, 21.853073872625828, 38.55580151081085, 40.06923750042915, 68.08736085891724, 112.83898070454597, 78.41496348381042, 46.80122226476669, 19.40536681562662, 9.37529107555747, 3.5572487069293857, 0.3269501309841871, 0.09852458664681762, 0.04845273637329228, 0.12741704878862947, 0.16980064247036353, 0.44372418837156147, 0.8660835481714457, 2.052573384717107, 1.2894882378168404, 3.953089853748679, 3.238537246361375, 5.186257632449269, 7.838745675981045, 7.017859574407339, 3.1371456244960427, 6.2220649514347315, 4.086703984066844, 4.396369317546487, 5.37168150767684, 8.122896328568459, 7.551643056795001, 7.272428339347243, 9.014200251549482, 4.50149305164814, 5.697695938870311, 7.968748100101948, 4.588861763477325, 1.2457591155543923, 3.8514479203149676, 1.653722443152219, 0.238286312087439, 0.3205511556006968, 3.291250867769122, 17.071742936968803, 33.97788695991039, 37.20770604908466, 30.478696525096893, 14.259081613272429, 5.10107047855854, 4.207048751413822, 3.1454101810231805, 4.216152112931013, 8.66268491372466, 4.477778524160385, 6.299288207665086, 7.4117473885416985, 4.664583150297403, 3.4806939773261547, 3.3580553205683827, 4.806438088417053, 3.2392297592014074, 4.789042146876454, 4.517322052270174, 5.089126769453287, 4.290234837681055, 8.218478299677372, 6.08545420691371, 5.448179477825761, 3.960195234976709, 2.3269922845065594, 1.8373502022586763, 0.7210947282146662, 0.08598367872764356, 0.21250318153761327, 0.1365092335618101, 0.022429628661484458, 0.05664199830789585, 0.577898818301037, 0.2505835209740326, 2.9920290363952518, 12.046036664396524, 32.06790804862976, 43.61543521285057, 50.84029532968998, 31.404697336256504, 28.569682762026787, 20.772573351860046, 15.782976541668177, 19.18641686439514, 31.90162517130375, 45.113797411322594, 41.13756537437439, 45.77099874615669, 51.60979203879833, 59.49351020157337, 59.967454969882965, 52.297866716980934, 23.58941350132227, 3.588603911921382, 0.15601576888002455, 0.10962538668536581, 0.05001732468372211, 0.060784822489949875, 0.09440176334464923, 0.08996134536573663, 0.1901970276958309, 0.11441106660640799, 0.07239297323394567, 0.04532310333161149, 0.01168594730188488, 0.05173816105525475, 0.16846496961079538, 0.13455342210363597, 0.03010578453540802, 0.022222615843929816, 0.07798248072504066, 0.2818163903430104, 0.056722510198596865, 0.04549576769932173, 0.043506058646016754, 0.04221232084091753, 0.03448998853855301, 0.029357786879700143, 0.035726224741665646, 0.04224208838422783, 0.09304721024818718, 0.06615335179958493, 0.08244765675044619, 0.022989137505646795, 0.03315794478112366, 0.046118214377202094, 0.04081503859197255, 0.05580127486609854, 0.1089107058942318, 0.016647569100314286, 0.04940240709402133, 0.057432125831837766, 0.023703779334027786, 0.05651399267662782, 0.10053584395791404, 0.0767882983200252, 0.055431291984859854, 0.014563897657353664, 0.04417497861140873, 0.0178546852839645, 0.007799928480380913, 0.07585387502331287, 0.028766348987119272, 0.060528328831424005, 0.07021920042461716, 0.046573458894272335, 0.08327101022587158, 0.044447105610743165, 0.026268450601492077, 0.023524530261056498, 0.025840888192760758, 0.0407352428737795, 0.05943150878010783, 0.027770702217821963, 0.09737257307278924, 0.036585379421012476, 0.05795686134661082, 0.06186019818414934, 0.08767014252953231, 0.12714756012428552, 0.07371586631052196, 0.08808194543235004, 8.17515017464757, 40.49015611410141, 63.75769838690758, 79.80401694774628, 67.57146254181862, 61.093676537275314, 49.722687900066376, 58.42100255191326, 42.916732504963875, 26.287401728332043, 36.54791325330734, 41.04763559997082, 74.96783405542374, 112.50089004635811, 77.7658823132515, 57.627388536930084, 25.98177082836628, 8.12032101675868, 2.4266212759539485, 0.11670716761727817, 0.042385441629448906, 0.10488528947462328, 0.7134325581137091, 0.5378205876331776, 1.1281762062571943, 2.1352194249629974, 2.705596131272614, 4.072424350306392, 7.849333332851529, 6.112264143303037, 6.525740856304765, 8.063326925039291, 8.819267861545086, 7.214437751099467, 7.051093066111207, 8.934109099209309, 7.176386592909694, 7.059566136449575, 9.299546889960766, 7.21172422170639, 9.522347934544086, 9.287492986768484, 3.895165524445474, 3.8818272901698947, 3.2139098178595304, 1.9048653356730938, 2.4027842050418258, 3.358653550967574, 3.056916017085314, 0.6479735893663019, 1.1832281271927059, 3.5968299955129623, 18.649990148842335, 32.97032542526722, 37.367316484451294, 31.185338906943798, 14.832859374582767, 4.554203348234296, 2.780036274343729, 2.3678023321554065, 2.40632395260036, 5.250386316329241, 2.28909264318645, 3.8824433321133256, 4.0428453125059605, 3.423097380436957, 5.17148070037365, 4.220299590379, 7.493997775018215, 6.442514397203922, 8.280975446105003, 10.425110142678022, 5.917521743103862, 12.39316513761878, 9.319531917572021, 8.224863857030869, 5.310701904818416, 8.14102990552783, 5.135903684422374, 5.18485170789063, 4.867173079401255, 2.0595908956602216, 0.8425295620691031, 0.33295431348960847, 0.3358767426107079, 0.05472729440953117, 0.3329506324371323, 0.3329957550158724, 2.8198481630533934, 11.83213759213686, 26.240789629518986, 41.379407197237015, 39.45697635412216, 29.09200083464384, 42.956299781799316, 27.639215290546417, 24.620324783027172, 25.47121312469244, 42.38644815981388, 49.99147787690163, 51.08339108526707, 53.09160612523556, 61.381032317876816, 67.35462337732315, 73.89817625284195, 65.41185602545738, 35.336302667856216, 6.211918545886874, 0.13446865399600938, 0.0414375112450216, 0.00933966690354282, 0.06813346859416924, 0.0476425931265112, 0.10471361587406136, 0.059375702985562384, 0.07626686536241323, 0.013181428676034557, 0.025460980941716116, 0.007326915092562558, 0.052529776585288346, 0.07882126345066354, 0.09569126719725318, 0.04105760213860776, 0.01946301021234831, 0.04516416498518083, 0.12101899366825819, 0.07635901041794568, 0.014403908244275954, 0.02787481997074792, 0.03839880242594518, 0.11362125078449026, 0.029615453131555114, 0.023897305472928565, 0.0567068991222186, 0.07261955091962591, 0.06376347300829366, 0.0935819350706879, 0.04018685140181333, 0.06082121741201263, 0.05079361115349457, 0.019826063289656304, 0.045741685753455386, 0.04450299675227143, 0.1466933253686875, 0.1389254882815294, 0.12835924979299307, 0.20034141460200772, 0.15890696842689067, 0.205626723181922, 0.14959341584471986, 0.1532717075315304, 0.07161279048887081, 0.2579480898566544, 0.22853446193039417, 0.1548005614313297, 0.16011659492505714, 0.14891589438775554, 0.1346796317375265, 0.22661042923573405, 0.20796211349079385, 0.14671132987132296, 0.27779380150604993, 0.11055270020733587, 0.1063387114845682, 0.17512261314550415, 0.17295960889896378, 0.13789354678010568, 0.11219166655791923, 0.22790420043747872, 0.09366239872178994, 0.11349507825798355, 0.1989600106026046, 0.20101092086406425, 0.26300033438019454, 0.24107352190185338, 0.2288740241783671, 12.834184672683477, 53.88787239789963, 76.29397809505463, 87.34048694372177, 77.13974431157112, 71.2770389020443, 61.17159515619278, 67.20878720283508, 45.26017315685749, 29.84527811408043, 50.2478539198637, 49.13742810487747, 74.24632877111435, 112.45316460728645, 83.12260687351227, 56.59715361893177, 29.26228489726782, 13.0192356929183, 3.878978630527854, 0.43323330755811185, 0.11126092431368306, 0.1772207536851056, 0.47283763240557164, 0.4411525873001665, 1.0183466621674597, 1.6564838262274861, 5.702996654435992, 5.4242402873933315, 11.818295884877443, 8.731433674693108, 12.47218569740653, 17.53893356770277, 16.437933146953583, 14.480299092829227, 16.77812699228525, 14.291978348046541, 16.678441241383553, 14.463371001183987, 17.38956168293953, 18.484514728188515, 16.960540004074574, 18.719173036515713, 14.542945381253958, 14.445238374173641, 20.707803927361965, 15.115815941244364, 11.853286307305098, 11.822803393006325, 3.2392276218160987, 0.9315689373761415, 1.8660323694348335, 6.200930010527372, 18.508483842015266, 21.683044396340847, 26.278058029711246, 19.806712679564953, 11.206404268741608, 7.851807000115514, 10.0940035097301, 9.275479931384325, 12.172795962542295, 18.908060900866985, 13.45431424677372, 16.344518959522247, 16.201654225587845, 13.677177038043737, 10.665750280022621, 15.713834501802921, 14.427537973970175, 10.9905388019979, 14.2317876778543, 18.727072812616825, 17.394058741629124, 17.719705067574978, 18.28923560678959, 16.13329779356718, 14.197171535342932, 10.093052610754967, 9.656452238559723, 6.86885342001915, 4.268537051975727, 1.4106338121928275, 0.35141900705639273, 0.1862169342348352, 0.31343746231868863, 0.16424284694949165, 0.8244293520692736, 0.7122236886061728, 4.60722760297358, 17.08410557359457, 41.10332541167736, 59.23151046037674, 65.02244532108307, 39.79163199663162, 38.07638503611088, 27.749492973089218, 25.50777856260538, 31.784504055976868, 46.1240454018116, 59.74706679582596, 59.90207947790623, 62.04692758619785, 71.74022644758224, 77.19988748431206, 81.5547426044941, 72.09967955946922, 42.54988878965378, 7.940960191190243, 0.3090895456261933, 0.262437638011761, 0.156822468561586, 0.19175218330929056, 0.220597593288403, 0.30564206186681986, 0.29778120398987085, 0.16635467269225046, 0.10537495851167478, 0.22981034737313166, 0.10471238390891813, 0.09099083777982742, 0.24956096021924168, 0.22330579406116158, 0.09859570665867068, 0.13603580271592364, 0.1790861863992177, 0.3412771731382236, 0.19784962409175932, 0.14599445974454284, 0.1600379272713326, 0.22092813102062792, 0.14699229213874787, 0.11825594076071866, 0.15321059909183532, 0.12589683348778635, 0.23537914152257144, 0.1600075140595436, 0.20984958799090236, 0.11514140671351925, 0.2808082866249606, 0.15799938119016588, 0.11431686580181122, 0.12361933069769293, 0.24368640122702345], [0.057368353081983514, 0.09764133443241008, 0.13413755223155022, 0.024048119157669134, 0.07458250925992616, 0.037453955665114336, 0.007068707536745933, 0.04638395519577898, 0.10277520777890459, 0.02823868013365427, 0.1703968393849209, 0.09339918862679042, 0.07240078062750399, 0.05032221008150373, 0.025455778486502822, 0.110797141387593, 0.07174389087595046, 0.167477794457227, 0.054208585133892484, 0.18853639805456623, 0.06663633408606984, 0.021988327243889216, 0.160329932696186, 0.06132751797849778, 0.10221941338386387, 0.09691483865026385, 0.0837910182599444, 0.11492147124954499, 0.1073349111538846, 0.25815645523834974, 0.1718010421609506, 0.13974977686302736, 4.534478131681681, 27.47833952307701, 53.40445853769779, 64.51614528894424, 56.67503423988819, 52.177857756614685, 45.00467486679554, 34.380904734134674, 52.68374361097813, 52.56967753171921, 50.00729262828827, 74.93989795446396, 82.21957013010979, 42.47771166265011, 33.97593006491661, 30.866501815617085, 16.736678816378117, 8.019253090023994, 2.200030884705484, 0.12132409799960442, 0.2258344247820787, 0.03289462336397264, 0.07467783812899143, 0.31745316402520984, 0.3635694785043597, 1.5888555301353335, 2.9744687536731362, 4.381840797141194, 5.5177119467407465, 3.887245086953044, 6.5307000651955605, 12.08726730197668, 4.902894962579012, 5.090973470360041, 6.020820625126362, 5.737319262698293, 6.704400144517422, 1.1465695942752063, 6.395823452621698, 5.156627772375941, 3.8394218031316996, 11.707190796732903, 5.472793132066727, 5.834904201328754, 4.370741592720151, 4.154448173940182, 4.507251167669892, 1.1102463933639228, 3.154204096645117, 3.2015205826610327, 2.9579481901600957, 3.4910781076177955, 14.885240513831377, 39.252710714936256, 70.71859806776047, 55.627920627593994, 63.85780021548271, 47.811656445264816, 18.21672409772873, 6.883676899597049, 4.512969860807061, 5.3702504094690084, 6.328558512032032, 7.20904441550374, 4.832020215690136, 2.620320632122457, 1.8477131961844862, 2.5142436241731048, 2.9812851129099727, 3.1834485149011016, 3.880793508142233, 7.3713921289891005, 3.6365134036168456, 4.8834143579006195, 7.668660627678037, 7.892696605995297, 7.541333734989166, 9.053646884858608, 8.907748013734818, 1.5316126705147326, 4.442768152803183, 1.0593116702511907, 1.4701147517189384, 1.3268639822490513, 0.6320300605148077, 0.287104994058609, 0.021100677804497536, 0.1727258917526342, 0.06068040973332245, 0.46482071571517736, 1.3868971983902156, 9.795067850500345, 23.1054562702775, 60.33351592719555, 42.57108025252819, 18.042644038796425, 25.08547682315111, 22.556881606578827, 19.88357115536928, 23.168230801820755, 35.09802885353565, 23.162065632641315, 34.99821960926056, 47.46049448847771, 53.42601478099823, 52.848514169454575, 60.18381156027317, 54.40661296248436, 25.788475200533867, 4.178968258202076, 0.02074067495414056, 0.04130081506446004, 0.1837947274907492, 0.11081257063779049, 0.19944026920711622, 0.28358561103232205, 0.08718160897842608, 0.22853305184980854, 0.14847777492832392, 0.03769558039493859, 0.07406661272398196, 0.07406608579913154, 0.04167246777797118, 0.019692857058544178, 0.12789030151907355, 0.0446713381097652, 0.25458084710408, 0.185669036291074, 0.02116481049597496, 0.07181817985838279, 0.006761204676877242, 0.012574443717312533, 0.053399614480440505, 0.04758840150316246, 0.1492583064828068, 0.027361615575500764, 0.0208466332333046, 0.008990834303403972, 0.03900863630406093, 0.04986420848581474, 0.0680373159411829, 0.03512663992296439, 0.046273827902041376, 0.046978207683423534, 0.006317444895103108, 0.039926290774019435, 0.056024772638920695, 0.02128284722857643, 0.03570589731680229, 0.04877501029113773, 0.018027644655376207, 0.07827683875802904, 0.007850398233131273, 0.010418327528896043, 0.07501514424802735, 0.10075947531731799, 0.058435943647054955, 0.054899023671168834, 0.031331597274402156, 0.06171113040181808, 0.020108773314859718, 0.044748194923158735, 0.015078496362548321, 0.019136969895043876, 0.09119716225541197, 0.058097557703149505, 0.10607737902319059, 0.008466929066344164, 0.029249874896777328, 0.017740700677677523, 0.10529772320296615, 0.05797774167149328, 0.013974723315186566, 0.12843595817685127, 0.07497995902667753, 0.07378180613159202, 5.831975983455777, 33.31493653357029, 62.845192551612854, 75.47610998153687, 67.97864109277725, 62.30912871658802, 56.74059972167015, 47.3990061879158, 59.86124686896801, 52.15024083852768, 41.54252104461193, 67.2682236135006, 59.873797595500946, 37.78730034828186, 45.73217622935772, 42.41427406668663, 19.695131666958332, 7.7863341383636, 1.8762143980711699, 0.1723689929349348, 0.24980955000501126, 0.43372734042350203, 0.7279987202491611, 1.035590493120253, 1.7543096956796944, 4.46573649533093, 4.928554035723209, 5.954826716333628, 6.2735341396182775, 9.697847217321396, 7.8289341274648905, 9.480577725917101, 10.348474904894829, 6.704374495893717, 8.576078061014414, 8.607224989682436, 7.883731462061405, 6.670697377994657, 9.262842759490013, 5.588759109377861, 6.769437454640865, 11.094171591103077, 4.929038034752011, 5.1598556991666555, 2.230449914932251, 2.717708693817258, 3.725109212100506, 3.0041064508259296, 4.91037723608315, 4.107204833999276, 3.9600292313843966, 6.784182088449597, 18.231725692749023, 47.33303792774677, 78.06605860590935, 65.17034858465195, 70.76146736741066, 48.789450377225876, 20.72613224387169, 7.252135053277016, 3.8142892392352223, 2.567282603122294, 2.9932551831007004, 5.501519590616226, 2.961746798828244, 2.1299464954063296, 1.9860822963528335, 3.6940154805779457, 3.050131481140852, 5.562135362997651, 4.077933104708791, 7.714932169765234, 5.240339180454612, 8.92634516581893, 5.9905533492565155, 10.322713237255812, 12.676826566457748, 10.30836045742035, 7.603721637278795, 4.850235963240266, 5.143805835396051, 4.585950644686818, 2.572256298735738, 5.190081177279353, 2.250244952738285, 1.134043091442436, 0.12245950973010622, 0.3342568420339376, 0.24907862360123545, 0.22401588095817715, 1.6403010883368552, 7.63448478654027, 20.08262537419796, 46.08865790069103, 33.81742537021637, 19.97557371854782, 24.399416036903858, 20.960820950567722, 26.318539157509804, 34.15935382246971, 49.85458642244339, 34.74510759115219, 43.24271321296692, 54.38843093812466, 62.02192112803459, 62.10102528333664, 69.39386755228043, 66.08178287744522, 35.09101063013077, 6.6818896774202585, 0.061848201366956346, 0.062310110370162874, 0.1561070975731127, 0.13984330231323838, 0.09517285478068516, 0.12484271661378443, 0.08924578141886741, 0.09264169333619066, 0.0815087508817669, 0.05507329107786063, 0.023174950874818023, 0.0869690281979274, 0.007072492489896831, 0.04489219754759688, 0.1135698496364057, 0.10683357555535622, 0.20195218676235527, 0.08664743334520608, 0.005240439259068808, 0.08436950753093697, 0.021279550237522926, 0.013939093732915353, 0.03621206429670565, 0.047141636023297906, 0.030297655684989877, 0.06458061470766552, 0.06520246766740456, 0.06838969507953152, 0.031579964415868744, 0.03917887013813015, 0.04375388773041777, 0.020422195266291965, 0.01875095476862043, 0.07410593912936747, 0.2302661893190816, 0.14720821258379146, 0.21094208874274045, 0.07458390449755825, 0.20285063073970377, 0.11790006610681303, 0.18425448797643185, 0.3154572023777291, 0.2180184519966133, 0.16991358250379562, 0.2820872742449865, 0.24293942959047854, 0.12522367585916072, 0.254971127724275, 0.15081910241860896, 0.25269879028201103, 0.1163592710508965, 0.22023153636837378, 0.1416473594144918, 0.40404612373095006, 0.1690889525343664, 0.1447133198962547, 0.2707611507503316, 0.14000072667840868, 0.2294532852829434, 0.2332723475410603, 0.33902941562701017, 0.3587469435296953, 0.18680919776670635, 0.33563515869900584, 0.29915218823589385, 0.23359380138572305, 8.441297393292189, 45.057074055075645, 75.10159447789192, 82.59245172142982, 74.46338832378387, 70.81100150942802, 61.48945190012455, 48.54999482631683, 67.62080669403076, 64.68424066901207, 64.17697548866272, 89.37161475419998, 91.74494460225105, 52.9835969209671, 46.3030081987381, 42.24043719470501, 24.24031477421522, 11.260505765676498, 2.8582674264907837, 0.634358444949612, 0.36384968378115445, 0.33523350837640464, 0.46150862937793136, 0.6075650139246136, 1.3946629129350185, 6.335355872288346, 6.91116557456553, 12.098454851657152, 16.9124136865139, 15.41753115132451, 18.27761583030224, 25.237789750099182, 15.693503692746162, 14.597669094800949, 15.161108560860157, 20.33830415457487, 18.305740021169186, 12.286583706736565, 21.41752414405346, 15.008930526673794, 11.413136925548315, 25.99929738789797, 23.455919064581394, 17.234260216355324, 13.097169511020184, 10.24995094165206, 14.736482296139002, 6.7576557118445635, 6.967154145240784, 6.301074111834168, 5.64087426289916, 8.389147091656923, 24.065609648823738, 39.63685490190983, 62.49088816344738, 50.55214539170265, 53.38512897491455, 41.92295663058758, 22.984909638762474, 13.181102257221937, 10.298883765935898, 12.968155033886433, 16.564179472625256, 15.715534910559654, 12.449200730770826, 8.10568230226636, 8.355989120900631, 10.81686532124877, 12.068834491074085, 10.896646790206432, 10.688136778771877, 20.34838881343603, 11.168429106473923, 17.61372495442629, 18.50363340228796, 18.33769630640745, 23.386665880680084, 22.393547371029854, 21.076089665293694, 10.519822910428047, 9.769742209464312, 5.460614785552025, 4.960011597722769, 3.0635193502530456, 1.431486380752176, 0.5104320135433227, 0.17453538137488067, 0.4754574137041345, 0.36771529354155064, 0.8231201441958547, 2.549419761635363, 13.818230219185352, 30.497822798788548, 77.38942891359329, 57.356679663062096, 27.597643621265888, 33.5586516559124, 32.802617624402046, 29.13657434284687, 35.38522884249687, 48.72497923672199, 35.36017678678036, 48.81033405661583, 63.05244483053684, 73.8439379632473, 70.88706582784653, 81.23122796416283, 73.85261669754982, 41.9874619692564, 9.091749340295792, 0.24828547553624958, 0.16056326392572373, 0.37280043005011976, 0.39522418461274356, 0.423573839943856, 0.3809790755622089, 0.27027786418329924, 0.3635070490418002, 0.28187706833705306, 0.13660724158398807, 0.19939795194659382, 0.355749320005998, 0.15299748396500945, 0.1435402812785469, 0.17732517386320978, 0.2455437000025995, 0.4005646496079862, 0.3569076640997082, 0.13708585262065753, 0.148024189111311, 0.17822007037466392, 0.11581014114199206, 0.2640484250150621, 0.29668347851838917, 0.2770010393578559, 0.10963280816213228, 0.14545720419846475, 0.17097111325711012, 0.12681063992204145, 0.13827201240928844, 0.17394237569533288, 0.12328072582022287, 0.13854197604814544, 0.1600751979276538], [0.04394764022435993, 0.07483570036129095, 0.03160930151352659, 0.05203702763537876, 0.03961970956879668, 0.004038803372168331, 0.06640945954131894, 0.0290928772665211, 0.06571112084202468, 0.1124360780522693, 0.10357406295952387, 0.07498038947232999, 0.059278103144606575, 0.0640247757837642, 0.07644165598321706, 0.11170638361363672, 0.08096059318631887, 0.08501421863911673, 0.07060778152663261, 0.11416041365009733, 0.0233056894649053, 0.07249731177580543, 0.08953089971328154, 0.024272106747957878, 0.12299473921302706, 0.11519649633555673, 0.05596121511189267, 0.10676865247660317, 0.2384874044219032, 0.09422770745004527, 0.03901019481418189, 0.7961300737224519, 15.844737477600574, 52.57402069866657, 72.07217663526535, 62.52706982195377, 56.361057087779045, 55.55338382720947, 33.742500990629196, 22.496415451169014, 23.806689642369747, 59.30564068257809, 79.27225828170776, 77.80442744493484, 59.25481840968132, 40.909007638692856, 41.12879924476147, 16.74928653985262, 7.701339349150658, 0.824368674075231, 0.11343880119966343, 0.021394137838797178, 0.06113471543358173, 0.15200803783955052, 0.8665610163006932, 2.1058716997504234, 2.0855950377881527, 2.5984544679522514, 6.049462538212538, 2.4751133238896728, 3.463551909662783, 8.291368838399649, 5.5103702656924725, 3.499188059940934, 4.298734981566668, 5.421632202342153, 5.901061501353979, 5.317855970934033, 8.149490151554346, 4.898383179679513, 5.008452823385596, 6.2499326560646296, 4.53443918377161, 4.6724810265004635, 6.384877664968371, 3.9085001964122057, 7.194496896117926, 10.284123457968235, 9.110457636415958, 13.395717591047287, 14.960486926138401, 15.458707641810179, 11.942698359489441, 22.6362232491374, 29.95189469307661, 56.56403839588165, 49.48636718094349, 50.39145581424236, 56.71065732836723, 59.25270572304726, 42.910018265247345, 28.70482251048088, 17.447003200650215, 15.565696600824594, 17.922203801572323, 8.025709893554449, 9.269314762204885, 6.079664267599583, 2.4114517774432898, 3.792804954573512, 0.8999000710900873, 4.736098637804389, 5.060795014724135, 5.464495327323675, 6.683753477409482, 2.7386916428804398, 8.03814947605133, 7.681827871128917, 7.39134818315506, 7.759820586070418, 11.197501346468925, 2.0014316914603114, 4.566588783636689, 5.469966558739543, 5.394709222018719, 3.9533558394759893, 2.927066059783101, 1.9486038386821747, 0.23042076383717358, 0.11930694803595543, 0.15014398552011698, 0.02316095768037485, 0.11202166278962977, 1.7625465849414468, 6.864491254091263, 20.92100478708744, 38.26665222644806, 60.00110976397991, 51.60673700273037, 37.468839436769485, 26.054160743951797, 18.94312161952257, 14.289497081190348, 21.93827860057354, 29.518964923918247, 31.51551838964224, 36.25373683869839, 49.86158184707165, 55.16450509428978, 61.35704040527344, 62.80973665416241, 33.402005061507225, 3.4676217287778854, 0.1520893326960504, 0.19774303684243932, 0.1703252221341245, 0.023662202365812846, 0.1962672613444738, 0.07194744714070112, 0.21859453670913354, 0.08161721576470882, 0.15608621353749186, 0.02234033716376871, 0.0649880018318072, 0.11117962945718318, 0.013493336646206444, 0.021170758809603285, 0.06331477052299306, 0.1348489453084767, 0.08119857768178917, 0.01194298736663768, 0.07952334257424809, 0.062481524219037965, 0.04420149554789532, 0.031383443711092696, 0.03703818598296493, 0.16717508726287633, 0.05011246059439145, 0.05477189006342087, 0.03988032585766632, 0.054410916854976676, 0.013114323683112161, 0.07437038861098699, 0.020176169600745197, 0.00917525985641987, 0.03003382960741874, 0.03179252664267551, 0.1173742396349553, 0.06788720173062757, 0.05650159509968944, 0.017268290284846444, 0.011105348476121435, 0.040334575896849856, 0.023102480154193472, 0.06786864061723463, 0.07852301656384952, 0.05431680510810111, 0.08982396640931256, 0.10725773521699011, 0.05519748949154746, 0.02846510753442999, 0.07406699864077382, 0.034585246903588995, 0.14960218803025782, 0.07138161890907213, 0.030415375149459578, 0.07053883600747213, 0.04789696424268186, 0.06627363909501582, 0.10021663882071152, 0.07028545194771141, 0.09678166767116636, 0.01509723373601446, 0.05975965308607556, 0.09503736087935977, 0.059832060724147595, 0.06642646956606768, 1.2157742120325565, 20.8752229437232, 62.93346181511879, 81.7753055691719, 72.96426996588707, 62.38259017467499, 64.17230173945427, 41.87102101743221, 33.822163715958595, 37.25185967981815, 56.49012476205826, 69.80827331542969, 78.99991169571877, 63.539115116000175, 39.291563630104065, 38.41559283435345, 15.328154247254133, 6.6332237888127565, 0.5758345790673047, 0.021224187876214273, 0.10046866475022398, 0.42775996844284236, 0.654441851656884, 2.371159689500928, 4.880002615973353, 3.7167757842689753, 6.790410904213786, 6.928757205605507, 6.944403341040015, 9.532959815114737, 8.188869338482618, 10.303810201585293, 8.275507539510727, 7.146961446851492, 7.079294677823782, 7.243652008473873, 7.823952119797468, 9.058108795434237, 4.3582055903971195, 6.054883897304535, 7.562276786193252, 3.773311525583267, 2.7462085895240307, 5.223942110314965, 5.053575402125716, 7.914028661325574, 9.927513543516397, 12.446445878595114, 15.926529038697481, 16.4438646286726, 17.290250211954117, 14.202994722872972, 26.832604072988033, 39.50376704335213, 67.88239225745201, 60.40220484137535, 60.93156583607197, 72.67395794391632, 72.1443347632885, 46.889692917466164, 29.783043153584003, 18.69383029639721, 17.76182770729065, 17.430810369551182, 9.693133570253849, 9.794023856520653, 5.066232047975063, 2.5562995299696922, 2.78197820764035, 2.3359123058617115, 4.229038646444678, 7.411419181153178, 4.898344231769443, 4.190190006047487, 5.235981289297342, 9.190127961337566, 6.990672033280134, 6.949892146512866, 11.4017622359097, 12.402470838278532, 5.278205098584294, 12.740094121545553, 9.214381109923124, 5.990893431007862, 9.053646884858608, 4.157239124178886, 3.8404992828145623, 3.181861862540245, 1.9774187612347305, 0.2788503229385242, 0.24826202366966754, 0.04756196249218192, 1.0612068185582757, 5.243108756840229, 19.13288913667202, 37.55138240754604, 49.2635053396225, 34.98365879058838, 33.95034983754158, 26.67827345430851, 25.595730543136597, 23.167425245046616, 28.54312028735876, 41.24763786792755, 45.31342729926109, 45.64449593424797, 61.68388366699219, 66.2472715973854, 70.883007645607, 72.99820214509964, 40.59576764702797, 4.91330592893064, 0.2922656515147537, 0.10351554461522028, 0.06843328883405775, 0.0293828714711708, 0.10617428866680712, 0.08195846268790774, 0.054144493260537274, 0.04640612314688042, 0.10758721167803742, 0.024065826801233925, 0.049313019117107615, 0.05235413249465637, 0.041297872448922135, 0.026806221940205432, 0.07632697190274484, 0.16587459220318124, 0.0688430508307647, 0.04630304625607096, 0.11965054014581256, 0.054855544949532486, 0.05794372904347256, 0.03608867853472475, 0.04458409865037538, 0.05690877813322004, 0.020710050230263732, 0.06312895900919102, 0.10372880817158148, 0.022535865246027242, 0.02011207030591322, 0.080426476924913, 0.09357147078844719, 0.016969872704066802, 0.016922514405450784, 0.167732662812341, 0.2956098283175379, 0.23947686539031565, 0.18034948501735926, 0.18480617087334394, 0.14158080361085013, 0.14362539077410474, 0.16108183219330385, 0.16375993145629764, 0.24043631390668452, 0.1949271949706599, 0.22865528357215226, 0.16286383266560733, 0.299760244670324, 0.20083436393179, 0.25741395133081824, 0.2467104748939164, 0.2534493984421715, 0.16350406862329692, 0.1934404208441265, 0.10970024712150916, 0.2318179904250428, 0.20809371111681685, 0.15984189638402313, 0.2717660187045112, 0.178308890608605, 0.12325331088504754, 0.18450092553393915, 0.3191471903119236, 0.28175761224702, 0.21906099136685953, 1.5926965302787721, 30.84036111831665, 74.73101556301117, 87.25490033626556, 82.3678457736969, 72.49430358409882, 73.59689801931381, 49.179260060191154, 33.48977655172348, 35.12371547520161, 71.09426110982895, 90.29257133603096, 86.79039806127548, 69.17122229933739, 56.77373394370079, 55.674433931708336, 23.929658643901348, 10.290548913180828, 1.2891156203113496, 0.49590471026021987, 0.145423065405339, 0.32252865261398256, 0.5453780852258205, 2.787161604501307, 4.947093715891242, 8.374312687665224, 7.652435498312116, 14.215382058173418, 9.14203679189086, 12.121656406670809, 19.99246571213007, 16.532988846302032, 14.129909444600344, 13.030187655240297, 16.836261972784996, 16.483450904488564, 13.030756674706936, 17.75929894298315, 16.837836988270283, 12.431698869913816, 17.015456557273865, 12.260803990066051, 11.827453393489122, 13.29536972567439, 9.412064552307129, 14.559001419693232, 14.188117571175098, 12.940909545868635, 16.45254146307707, 21.21579296886921, 21.032891683280468, 16.86856023967266, 29.669577442109585, 44.599464610219, 64.05486524105072, 59.84696723520756, 56.01189762353897, 67.17391267418861, 65.01566648483276, 53.03219251334667, 36.21258124709129, 25.33350471407175, 21.91966339945793, 22.881847769021988, 13.674341440200806, 13.61731979995966, 10.177440382540226, 7.811483088880777, 8.328721784055233, 6.497315056622028, 15.659749154001474, 16.1091747879982, 14.6507284976542, 16.43840242177248, 9.511189833283424, 19.047262631356716, 21.238804534077644, 18.01437735557556, 22.48999759554863, 26.360684596002102, 9.62952308356762, 18.895620368421078, 19.291897304356098, 15.354851614683867, 15.330498721450567, 5.37280909717083, 4.234111849218607, 2.1715910732746124, 1.0079037537798285, 0.6231387751176953, 0.28744608513079584, 0.42223996308166534, 2.217687824741006, 8.80246326327324, 27.710282877087593, 51.82655520737171, 79.63156700134277, 66.68508410453796, 52.74919509887695, 37.07588352262974, 29.591278843581676, 21.88404031097889, 32.032178565859795, 43.67989495396614, 47.5673371553421, 52.45026893913746, 70.2497336268425, 75.81549257040024, 80.40196806192398, 83.87363657355309, 49.7050454467535, 7.4923880863934755, 0.4406473628478125, 0.36643292172811925, 0.2908006520010531, 0.21969858527882025, 0.2845167985651642, 0.26036143535748124, 0.42946293018758297, 0.15856777725275606, 0.40195543435402215, 0.12055932224029675, 0.20648976671509445, 0.17962583166081458, 0.16501680307555944, 0.1713333258521743, 0.175830117368605, 0.4235394933493808, 0.1942098350264132, 0.19430705637205392, 0.29159920290112495, 0.16599133203271776, 0.12798400508472696, 0.16133674507727847, 0.10971538693411276, 0.207155680982396, 0.23280469060409814, 0.14205939980456606, 0.22900109470356256, 0.16380441578803584, 0.11592496623052284, 0.23626412294106558, 0.22746441856725141, 0.11612565780524164, 0.2120179357007146], [0.08309595985338092, 0.044348815572448075, 0.015523374931945, 0.12352915975498036, 0.11913254333194345, 0.024870953129720874, 0.044678113918052986, 0.03947427459934261, 0.10324783710530028, 0.07901796969235875, 0.1301794857135974, 0.06977981189265847, 0.03356948422151618, 0.04640872066374868, 0.058485771442065015, 0.17650636233156547, 0.04714971059001982, 0.06146794716187287, 0.07249990929267369, 0.08167339634383097, 0.09134347666986287, 0.02738764826062834, 0.01907687448692741, 0.07477373845176771, 0.10534975517657585, 0.06577936874236912, 0.0826331862481311, 0.021196843445068225, 0.20730520889628679, 0.07483797133318149, 0.09419822934432887, 8.879178296774626, 41.66235901415348, 60.099649876356125, 66.83665797114372, 57.51183293759823, 44.78578381240368, 38.2953254878521, 34.47243042290211, 25.80746278166771, 33.5665438324213, 73.51802185177803, 67.68291056156158, 53.498283103108406, 23.80355291068554, 32.02657766640186, 18.402520827949047, 6.760871289297938, 0.6235287291929126, 0.0577005124068819, 0.14624965464463457, 0.1749583610217087, 0.6381772994063795, 1.2184218387119472, 1.7823297483846545, 4.3981818202883005, 2.576265321113169, 5.910676885396242, 4.76674921810627, 7.061491208150983, 5.822086539119482, 5.916032223030925, 4.632095843553543, 6.743056895211339, 10.072794947773218, 4.430062584578991, 5.145487720146775, 4.583024801686406, 3.81808381062001, 2.90998550131917, 4.753351137042046, 3.1203894736245275, 4.395428393036127, 12.777899242937565, 13.002071063965559, 17.95576550066471, 21.110684908926487, 30.047033987939358, 40.69876492023468, 46.666318103671074, 47.628643065690994, 36.17870606482029, 21.75693143159151, 35.26769734919071, 30.971822664141655, 51.329617872834206, 43.18982005119324, 50.09480953216553, 37.72416293621063, 55.93764200806618, 48.431247398257256, 45.180195048451424, 37.64674589037895, 42.80097171664238, 31.942548975348473, 27.341962940990925, 29.204220212996006, 12.887261174619198, 10.44352300465107, 7.4096594005823135, 6.189903952181339, 3.9912198577076197, 3.441073978319764, 1.593019631691277, 2.5764246750622988, 5.2319910284131765, 3.356783101335168, 5.3968836553394794, 5.884808348491788, 4.457580232992768, 3.816087730228901, 2.363334009423852, 3.7482454581186175, 5.251182373613119, 0.9809049556497484, 11.50356637313962, 7.380306450650096, 7.258269349113107, 2.589234975166619, 0.5258582951501012, 0.4454424977302551, 0.24642568314448, 0.01865499136329163, 0.04157336508797016, 0.7939969631843269, 4.729681732133031, 10.57749716565013, 26.963185966014862, 46.08738876879215, 39.51265476644039, 44.20487478375435, 36.608774587512016, 28.664062097668648, 21.977893374860287, 15.721743777394295, 16.041416823863983, 23.633639328181744, 32.65410639345646, 53.13685029745102, 56.676212176680565, 62.3939173668623, 52.29185163974762, 21.05437573045492, 3.090893318876624, 0.18592860986245796, 0.012478919106797548, 0.17517385102109984, 0.14030588296009228, 0.02098152970575029, 0.10462581238243729, 0.06316511644399725, 0.035748912196140736, 0.07456751787685789, 0.15560957661364228, 0.09560694437823258, 0.023843852286518086, 0.05935059241892304, 0.056700935965636745, 0.12625880859559402, 0.019986218758276664, 0.047547416397719644, 0.15406577585963532, 0.031205944251269102, 0.08253577194409445, 0.06705257503199391, 0.015248711642925628, 0.10168999491725117, 0.012845949167967774, 0.045396368150250055, 0.020345720658951905, 0.04880117099673953, 0.007047038216114743, 0.04495843793847598, 0.10234186775051057, 0.018963778602483217, 0.051418028233456425, 0.009927223363774829, 0.06745861886884086, 0.05780334438895807, 0.07004566403338686, 0.027101832347398158, 0.05881867291464005, 0.04480574105400592, 0.008920398922782624, 0.06144469567516353, 0.11929576387046836, 0.03189915471011773, 0.021989154738548677, 0.06506848774733953, 0.03768096379644703, 0.011929614793189103, 0.060242846884648316, 0.02959582703624619, 0.02433801317238249, 0.05737878767831717, 0.06715657960739918, 0.04648336958780419, 0.06766115096979775, 0.004566214793157997, 0.024825455766404048, 0.08904649992473423, 0.048136099067050964, 0.061441155630745925, 0.032626210813759826, 0.1897278567776084, 0.027275574684608728, 0.11336096475133672, 12.10800563916564, 49.51112665235996, 71.37512683868408, 77.07817241549492, 67.57593110203743, 53.961326256394386, 49.965441673994064, 43.27711656689644, 26.603727154433727, 28.899138383567333, 64.5375457406044, 67.45049223303795, 57.11653634905815, 28.208158761262894, 33.27750474214554, 19.38454393297434, 6.268782019615173, 0.5798461544327438, 0.14965488051529974, 0.37111658602952957, 1.0791558679193258, 2.245969707146287, 4.05763316899538, 4.734756834805012, 5.0912803038954735, 5.905370945110917, 8.108321260660887, 9.37026584520936, 9.586266204714775, 8.405103385448456, 8.963300082832575, 7.656115600839257, 5.709004607051611, 6.785149136558175, 8.724518995732069, 8.654238916933537, 7.024262230843306, 7.130912058055401, 5.657999943941832, 1.887969661038369, 1.4875282673165202, 3.314712233841419, 8.288552239537239, 13.801912944763899, 19.62996706366539, 24.24334891140461, 33.76517437398434, 43.274430111050606, 45.16919083893299, 51.35081693530083, 39.065958335995674, 25.649664849042892, 39.13177840411663, 40.289663672447205, 58.97274814546108, 51.72259658575058, 56.707803681492805, 48.568363040685654, 68.52908715605736, 54.13630686700344, 47.68863804638386, 41.120230704545975, 46.34951010346413, 32.45771013200283, 31.9012413918972, 30.658666267991066, 15.579298920929432, 11.343809645622969, 7.003721008077264, 5.3029626701027155, 4.558516591787338, 6.179499635472894, 3.7678944412618876, 3.3056269213557243, 2.885187081992626, 4.8904211819171906, 6.977326199412346, 4.695067014545202, 6.41144061461091, 7.995831146836281, 6.04033637791872, 8.965424168854952, 9.091406408697367, 9.415736105293036, 16.600222438573837, 8.063021041452885, 7.201392101123929, 6.900918949395418, 3.256187061779201, 1.967528248205781, 0.794113272568211, 0.27497266069985926, 0.04987385640561115, 0.5277089145965874, 3.485536342486739, 10.299242846667767, 25.887875966727734, 41.2284716963768, 40.114044696092606, 37.14930318295956, 25.64639512449503, 21.948965527117252, 26.092985160648823, 23.654403313994408, 25.514821484684944, 35.69096423685551, 41.973410323262215, 62.64544866979122, 66.49553507566452, 67.81381353735924, 60.60305826365948, 25.44461265206337, 4.100489169359207, 0.17892950418172404, 0.03195334633346647, 0.09334300804766826, 0.12191456553409807, 0.0948774280550424, 0.07573879018309526, 0.03278800271800719, 0.02958067609142745, 0.05969447025563568, 0.15116387454327196, 0.05258894801954739, 0.07015123454038985, 0.039340235307463445, 0.0319864053017227, 0.09583856124663725, 0.14716300094733015, 0.04459682648302987, 0.04802752657269593, 0.06719794691889547, 0.057708805907168426, 0.09902210018481128, 0.027083018903795164, 0.011309235924272798, 0.034846583075704984, 0.06209581522853114, 0.01731473945255857, 0.06803531956393272, 0.015038082710816525, 0.04090792950592004, 0.073146891372744, 0.023476626483898144, 0.011211618457309669, 0.22460576961748302, 0.138640251243487, 0.17924754414707422, 0.2568207081640139, 0.16983561246888712, 0.13301456405315548, 0.11863375329994597, 0.12541774747660384, 0.24042862525675446, 0.209986662666779, 0.35241292091086507, 0.2945387607906014, 0.12578718859003857, 0.20191945804981515, 0.21463694516569376, 0.21479392424225807, 0.10030206001829356, 0.21435706643387675, 0.21586761897196993, 0.23140206118114293, 0.24217624944867566, 0.1890149645623751, 0.15378491749288514, 0.18048227007966489, 0.2245107153430581, 0.21721691766288131, 0.20586714934324846, 0.2197696384973824, 0.5357436428312212, 0.2275638811988756, 0.3045241499785334, 14.863889459520578, 62.00637996196747, 79.09818962216377, 84.56275999546051, 74.5597967505455, 61.22464790940285, 54.81785349547863, 48.11571232974529, 34.27960976958275, 45.83499111235142, 83.83070647716522, 74.88032475113869, 63.07611756026745, 34.15612779557705, 43.10892999172211, 24.476485401391983, 8.234239853918552, 0.8540336228907108, 0.26252301468048245, 0.46043961017858237, 0.6710439326707274, 2.3114233324304223, 4.396549807861447, 7.102401237934828, 12.412385456264019, 9.448828529566526, 16.142109520733356, 16.100953929126263, 17.49480653554201, 17.748878002166748, 18.801212534308434, 15.016247034072876, 16.33111897855997, 18.159094490110874, 14.406467154622078, 17.08039317280054, 13.390035945922136, 12.229477521032095, 12.751939035952091, 13.826098646968603, 10.083311833441257, 10.215488690882921, 20.817464143037796, 16.287244632840157, 20.447496995329857, 27.670151330530643, 40.38066118955612, 51.341442838311195, 52.5480604916811, 53.62001337110996, 43.83273035287857, 31.619315519928932, 47.322527691721916, 46.438337936997414, 64.95316743850708, 59.84407179057598, 57.143526300787926, 54.20042842626572, 67.547607421875, 63.32273952662945, 50.86223915219307, 46.1855299025774, 52.58197747170925, 40.23142419755459, 33.44534933567047, 35.754401832818985, 16.90888937562704, 13.370206709951162, 12.724563404917717, 12.724833190441132, 10.973463468253613, 8.39822955429554, 6.2305608205497265, 10.360441412776709, 11.910246200859547, 10.252087377011776, 13.150768484920263, 15.872741024941206, 11.545298583805561, 11.23478589579463, 7.980598714202642, 11.15325652062893, 10.332402717322111, 10.730969980359077, 29.800603911280632, 16.195846237242222, 15.282585192471743, 9.067543689161539, 3.2962841726839542, 1.15635110065341, 0.5427707126364112, 0.417782089789398, 0.2682319114683196, 1.209140361752361, 6.735045025125146, 14.537941049784422, 36.875204890966415, 60.32938934862614, 56.4261019974947, 61.08166538178921, 53.47676105797291, 41.09566122293472, 32.62932412326336, 23.056647889316082, 26.755190826952457, 37.837298065423965, 49.043018370866776, 73.2447101175785, 76.62288844585419, 76.56737342476845, 73.32323670387268, 32.44543299078941, 5.697876429185271, 0.40788979560602456, 0.14508664986351505, 0.25094937009271234, 0.26838553603738546, 0.28843646636232734, 0.20111223886488006, 0.23677814926486462, 0.20861962664639577, 0.1463452581083402, 0.2927222801372409, 0.16124213609145954, 0.21262245951220393, 0.1479680827469565, 0.15166458673775196, 0.4719611559994519, 0.383403820451349, 0.2391700615407899, 0.22625430225161836, 0.2380795794306323, 0.22295036469586194, 0.208638877957128, 0.16608196310698986, 0.26939574745483696, 0.1377057982608676, 0.1563994592288509, 0.12962787703145295, 0.15363417245680466, 0.17134040594100952, 0.17278974613873288, 0.17906583670992404, 0.1620746179833077, 0.16088501462945715], [0.08505092526320368, 0.02283929417899344, 0.08615766040747985, 0.04331030977482442, 0.012242187913216185, 0.06323175388388336, 0.033196989170392044, 0.030437966124736704, 0.14287418889580294, 0.10229580264422111, 0.048202131656580605, 0.022159162217576522, 0.05140645072970074, 0.06869639502838254, 0.031023251613078173, 0.030381728029169608, 0.06701900027110241, 0.021324227527657058, 0.035674007231136784, 0.06583313734154217, 0.05449024502013344, 0.051986765683977865, 0.03228159082937054, 0.01943797014973825, 0.011806629790953593, 0.06166548089822754, 0.07417075088596903, 0.05221578503551427, 0.06912853277754039, 0.005920740986766759, 4.33853262104094, 37.41380698978901, 61.24178119003773, 71.69757753610611, 64.44445833563805, 52.387367114424706, 50.27774691581726, 31.013327836990356, 24.63247463107109, 35.359249636530876, 74.51994448900223, 80.782890021801, 97.51419022679329, 39.76246856153011, 43.29619154334068, 21.558901257812977, 3.8953225035220385, 0.591300877276808, 0.06378577454597689, 0.024608158637420274, 0.048248059465549886, 1.4565657475031912, 1.1025801859796047, 2.0911220787093043, 3.488465747795999, 3.5865135490894318, 3.4995281416922808, 6.2024907767772675, 4.754820708185434, 5.189483659341931, 9.088197480887175, 5.926087433472276, 8.526149690151215, 4.911842532455921, 4.09547058865428, 6.5883643459528685, 5.093609103932977, 6.589796869084239, 5.526158893480897, 3.242075094021857, 3.989345608279109, 8.965984638780355, 12.792247273027897, 22.876364663243294, 41.84788405895233, 44.64221611618996, 44.018361791968346, 48.34566459059715, 56.5448722243309, 59.92437668144703, 64.19392257928848, 62.48037412762642, 32.557401582598686, 41.296871826052666, 38.27029623091221, 38.81938956677914, 44.79457274079323, 57.0628946274519, 29.548213854432106, 34.98235546052456, 37.58282192051411, 48.451587706804276, 51.35555148124695, 48.66050809621811, 43.1174111366272, 48.24610233306885, 46.26083426177502, 35.34696489572525, 30.38970910012722, 23.623032197356224, 16.262494660913944, 11.260620709508657, 17.01826650649309, 12.312751952558756, 8.650977741926908, 9.713765513151884, 10.656116846948862, 7.100305175408721, 2.1811385359615088, 5.279330313205719, 7.863933574408293, 5.007253512740135, 12.093030642718077, 8.233364000916481, 6.849954659119248, 8.442309089004993, 5.593122700229287, 6.404415741562843, 7.094861017540097, 7.443955885246396, 0.2339726232457906, 0.6810004671569914, 0.07285391373443417, 0.011726390639523743, 0.05716967643820681, 0.6875746487639844, 3.2189728086814284, 10.98516209051013, 20.065556690096855, 38.04515451192856, 40.71341313421726, 44.27724190056324, 53.357272669672966, 51.4448618888855, 36.28258489072323, 25.439703315496445, 17.967181988060474, 24.551985450088978, 28.82054340094328, 44.14559416472912, 64.16712641716003, 55.809535682201385, 40.523389130830765, 8.207648880779743, 0.31404863577336073, 0.08759477001149207, 0.12110961732105352, 0.18354879459366202, 0.023155534436227754, 0.07870639383327216, 0.19648387940833345, 0.0769484241027385, 0.06693999865092337, 0.22084058728069067, 0.04750704356411006, 0.02381133323069662, 0.0503696667146869, 0.038975399220362306, 0.05474361052620225, 0.10054238970042206, 0.06189370986248832, 0.036815396961173974, 0.04915531273582019, 0.04467993960133754, 0.026455388324393425, 0.0769829933415167, 0.05803479056339711, 0.03326971964270342, 0.08623580113635398, 0.04372056901047472, 0.052607846810133196, 0.019726131249626633, 0.0758268237404991, 0.10105407825903967, 0.02503788440662902, 0.02872894845495466, 0.08511734748026356, 0.008731771886232309, 0.05784728695289232, 0.0762593028775882, 0.03189273142197635, 0.043017662392230704, 0.10618724656524137, 0.04132802590902429, 0.22176321042934433, 0.05312353554472793, 0.12198289507068694, 0.005213572121647303, 0.018515671690693125, 0.09814045100938529, 0.04035901110910345, 0.08962810621596873, 0.13589403766673058, 0.10029144730651751, 0.019586837552196812, 0.0427413237048313, 0.04647563640901353, 0.0842024500889238, 0.04651078081224114, 0.04770367930177599, 0.059951097500743344, 0.034957600946654566, 0.05738234998716507, 0.033520020078867674, 0.02007624127145391, 0.035686241535586305, 6.923661204054952, 45.60858406126499, 71.85756415128708, 81.03629842400551, 73.94182071089745, 62.159306555986404, 59.98869203031063, 42.33644664287567, 35.76205462217331, 34.68450844287872, 61.24138221144676, 82.93273866176605, 91.34322255849838, 46.72417379915714, 32.007791474461555, 20.87629448622465, 3.1509153731167316, 0.6403496547136456, 0.10918778672930785, 0.2940968860639259, 0.5198337777983397, 2.478979853913188, 5.175194526091218, 6.209609694778919, 5.567456502467394, 6.944157779216766, 6.041285376995802, 9.723029416054487, 10.175348594784737, 7.847346514463425, 10.273118298500776, 10.62698096036911, 12.823388502001762, 7.645030170679092, 8.449746239930391, 9.141971245408058, 9.946178141981363, 5.001635039225221, 4.321485785767436, 3.974214820191264, 3.9724866254255176, 6.907150615006685, 14.372172094881535, 26.570516936481, 42.33798176050186, 46.23863585293293, 48.678367137908936, 50.81031113862991, 60.77299654483795, 62.10155725479126, 63.512942120432854, 68.33693146705627, 36.0668970644474, 46.61732733249664, 46.612946167588234, 43.134723007678986, 50.40524907410145, 61.48162052035332, 38.91924820840359, 42.84811198711395, 44.39093939960003, 52.05051138997078, 57.96884961426258, 54.136652648448944, 48.31262156367302, 51.2995994836092, 50.24283058941364, 38.962945863604546, 31.147844418883324, 25.437987707555294, 15.95705185085535, 11.177277881652117, 11.923093311488628, 11.124310623854399, 10.405555441975594, 9.851070195436478, 10.775043815374374, 6.913420278578997, 4.872894622385502, 5.747814774513245, 7.252706922590733, 5.774305053055286, 14.136440344154835, 11.60919975489378, 10.86368165910244, 11.328314077109098, 6.315209828317165, 9.396160505712032, 6.624576402828097, 6.485766051337123, 2.904177037999034, 1.717000922653824, 0.31744280364364386, 0.36944129155017436, 0.07589123473735526, 0.47945423517376184, 1.8719966243952513, 8.395494651049376, 19.86229419708252, 36.20553642511368, 39.89353872835636, 42.672546207904816, 40.86425743997097, 34.027231112122536, 30.1119402050972, 31.270340345799923, 28.124506250023842, 35.510986894369125, 40.443468019366264, 52.47238755226135, 71.35483592748642, 62.51931443810463, 48.55375662446022, 10.295116268098354, 0.5103536427486688, 0.020979815344617236, 0.048191596870310605, 0.13085320737445727, 0.07900778742623515, 0.07074939072481357, 0.11695892637362704, 0.03952536033466458, 0.026405241405882407, 0.03726244074641727, 0.03307511367893312, 0.03350116952788085, 0.04941900522680953, 0.09986212229705416, 0.17463156371377409, 0.14290755585534498, 0.10580219808616675, 0.016495994714205153, 0.03515984361001756, 0.024618897514301352, 0.03888861618179362, 0.03430375400057528, 0.0731331690622028, 0.030078536583459936, 0.005632481552311219, 0.08256000306573696, 0.062491105345543474, 0.08522524090949446, 0.046048994263401255, 0.011485213981359266, 0.040541460693930276, 0.024461810826323926, 0.1378966638003476, 0.13830868934746832, 0.2842583233723417, 0.1558662558090873, 0.12028296128846705, 0.13038532779319212, 0.1641017201473005, 0.12280774026294239, 0.34728750062640756, 0.3936769551364705, 0.21341139217838645, 0.0809374604432378, 0.1441783204791136, 0.2022941832547076, 0.13022794795688242, 0.1873240849818103, 0.2627347642555833, 0.18465529225068167, 0.11016771852155216, 0.105621017573867, 0.22682559269014746, 0.15028224763227627, 0.08698205288965255, 0.16875203233212233, 0.2381083302316256, 0.10685699031455442, 0.2533519099233672, 0.25173830275889486, 0.2228487201500684, 0.1656544118304737, 9.076705947518349, 58.184818625450134, 82.73630440235138, 88.42491075396538, 81.91249340772629, 70.79188093543053, 66.7319355905056, 45.61084873974323, 35.03059387207031, 51.882537603378296, 84.72536846995354, 88.26194509863853, 102.30834737420082, 52.04357296228409, 56.51461824774742, 29.110568538308144, 6.12711944617331, 0.8941720565780997, 0.2713428164133802, 0.25888901436701417, 0.3949551412370056, 2.32758576516062, 5.614053402096033, 10.178514774888754, 10.9814496897161, 12.530250381678343, 11.538317408412695, 15.933051388710737, 15.543867722153664, 12.525231800973415, 23.78318600356579, 15.759444404393435, 18.442412987351418, 15.254297610372305, 12.868992704898119, 17.670182324945927, 15.991658493876457, 15.730309467762709, 15.065940767526627, 11.727277468889952, 10.001335982233286, 14.37721822410822, 15.503337197005749, 25.27830697596073, 43.74582141637802, 49.24504213035107, 47.80140079557896, 52.71019399166107, 65.36201789975166, 75.51497429609299, 68.7319278717041, 69.397963732481, 38.40530678629875, 54.207689836621284, 54.084105268120766, 51.591940596699715, 58.47012631595135, 67.55814045667648, 42.78264909982681, 50.28242826461792, 49.45199802517891, 58.629212379455566, 60.79346224665642, 59.815520122647285, 54.76009659469128, 56.111528277397156, 53.38594973087311, 41.5380334854126, 35.42848192155361, 26.973563209176064, 20.047074481844902, 14.650639202445745, 21.004188023507595, 18.17127663642168, 13.35448695346713, 15.74664669111371, 16.001526564359665, 10.804168302565813, 6.495662620291114, 13.330026715993881, 15.799460057169199, 12.428629584610462, 23.138750083744526, 20.673801451921463, 12.540949657559395, 15.658580716699362, 17.321737222373486, 16.972325071692467, 15.891533866524696, 16.91339783370495, 3.0493185622617602, 2.0625528367236257, 0.31024955213069916, 0.35230631881859154, 0.29745026549790055, 1.1819722945801914, 4.6998191345483065, 14.143991488963366, 27.65148863196373, 49.85700689256191, 55.99485173821449, 61.68587476015091, 72.20285922288895, 67.53228664398193, 51.91342614591122, 37.185268253088, 29.09454669803381, 38.54166626930237, 44.51341062784195, 62.5031691044569, 82.66193479299545, 71.98774516582489, 60.75045995414257, 14.1049400344491, 0.8948581572622061, 0.20038388029206544, 0.16628363431664184, 0.31489696993958205, 0.18429716146783903, 0.21816061780555174, 0.30462071823421866, 0.16998620907543227, 0.16108533513033763, 0.30737729219254106, 0.15113598463358358, 0.07578021686640568, 0.15116286522243172, 0.22123695351183414, 0.40975368465296924, 0.26968557096552104, 0.2561463334131986, 0.10024574585258961, 0.11927715822821483, 0.23561982001410797, 0.1295043688151054, 0.20053976099006832, 0.24483579501975328, 0.12963595159817487, 0.1796557698980905, 0.11279570797341876, 0.1352590264286846, 0.20736349717481062, 0.13995964138302952, 0.24249786656582728, 0.12365358823444694, 0.10836820336407982], [0.13614187046186998, 0.044693673044093885, 0.08672193755046465, 0.10228085579001345, 0.056749984505586326, 0.06430271751014516, 0.018164068096666597, 0.09178039385005832, 0.0948205943859648, 0.09799252613447607, 0.0392626066604862, 0.015789720600878354, 0.05416934407548979, 0.02742383352597244, 0.029374954610830173, 0.1093457083334215, 0.15089153603184968, 0.0650983740342781, 0.03094548752414994, 0.03729080191988032, 0.04080209182575345, 0.02081850583635969, 0.14233727473765612, 0.015891153634584043, 0.13603929081000388, 0.09900361328618601, 0.09905609796987846, 0.07203394445241429, 0.16677164094289765, 0.9873108775354922, 22.281806766986847, 63.20955879986286, 66.27305701375008, 64.1494345664978, 52.72476240992546, 56.43876671791077, 42.04301118850708, 21.41676228493452, 22.719368487596512, 48.92630763351917, 77.2762405872345, 84.00973007082939, 54.38849173486233, 29.467741772532463, 24.185932092368603, 7.508990820497274, 0.816935085458681, 0.26486932940315455, 0.2984695608029142, 0.5029682640451938, 0.4814080725191161, 1.6382312681525946, 3.372408812865615, 5.702237170189619, 3.5800313344225287, 2.329152706079185, 3.349340963177383, 6.937594581395388, 6.95945480838418, 5.979003394022584, 3.818141520023346, 8.29502709209919, 8.367300163954496, 4.120307005941868, 6.73782505095005, 6.652161497622728, 6.727882409468293, 4.0242761839181185, 3.692690064199269, 8.836999610066414, 15.001484826207161, 21.217109598219395, 41.73291742801666, 52.94415503740311, 57.28479132056236, 59.45083849132061, 52.536702901124954, 60.201324820518494, 66.22612953186035, 71.86172112822533, 59.52597565948963, 70.16705006361008, 44.79142650961876, 45.24253450334072, 47.89063900709152, 35.45540347695351, 47.423670664429665, 51.7610277235508, 35.6542582064867, 21.689714938402176, 37.912716418504715, 47.894852980971336, 55.51083371043205, 49.529247879981995, 60.67109361290932, 59.13373030722141, 61.248940005898476, 44.85976584255695, 45.26127889752388, 45.427075400948524, 41.56795307993889, 36.589840203523636, 39.617335349321365, 34.039466455578804, 32.65290945768356, 25.9649795293808, 24.567496217787266, 20.387437418103218, 15.339063461869955, 11.231481973081827, 7.65104572288692, 7.29317712597549, 10.784109178930521, 11.163223385810852, 9.23306280747056, 11.580413449555635, 4.155579563230276, 5.470234444364905, 5.6836894154548645, 5.308178840205073, 5.377262458205223, 1.346716491971165, 0.5161983822472394, 0.2019833421218209, 0.02584170641057426, 0.10148040499188937, 0.49048525106627494, 1.4147345046512783, 8.228884041309357, 19.05582547187805, 34.91131827235222, 36.73227936029434, 51.8375214189291, 78.2943807542324, 84.64931935071945, 56.60192236304283, 29.29633866995573, 20.072288028895855, 23.438656590878963, 42.20200605690479, 44.22346718609333, 50.476350858807564, 43.15481252968311, 16.109978444874287, 3.224610281176865, 0.12449254907551222, 0.03244895997340791, 0.15905762440524995, 0.05013493282604031, 0.03040580515516922, 0.08091544834314846, 0.023795224915375, 0.10140320679056458, 0.11885053463629447, 0.09313767804997042, 0.07750022574327886, 0.07152863836381584, 0.05731939359975513, 0.038665574829792604, 0.1356694637797773, 0.010267314391967375, 0.017761430717655458, 0.050188137392979115, 0.03642992174718529, 0.022607706996495835, 0.09308123771916144, 0.05599025163974147, 0.05270332781947218, 0.04038356135424692, 0.05499693150341045, 0.04820897425815929, 0.026042006502393633, 0.05112762584758457, 0.012690823605225887, 0.031029828896862455, 0.08334611557074822, 0.12853585125412792, 0.03930644161300734, 0.05161864188266918, 0.032202514994423836, 0.08762012919760309, 0.05378977264626883, 0.022873186208016705, 0.05244243693596218, 0.023645376022614073, 0.06901554079377092, 0.037081163754919544, 0.017630350739636924, 0.0728406960843131, 0.054900652685319073, 0.07726264200755395, 0.0745869473030325, 0.06552803301019594, 0.051446727084112354, 0.04912081400107127, 0.024518583268218208, 0.03083145282289479, 0.06267706528888084, 0.014814221285632811, 0.09442157868761569, 0.062251035415101796, 0.04796207285835408, 0.08538313282770105, 0.11106477468274534, 0.04936185243423097, 1.6957707493565977, 27.38941289484501, 70.22517174482346, 75.70570886135101, 75.12554839253426, 61.22991822659969, 60.54274410009384, 49.572432562708855, 25.180766209959984, 21.293204315006733, 39.244366362690926, 75.40408104658127, 85.17769619822502, 65.087209045887, 29.108218364417553, 21.144548691809177, 5.515276752412319, 0.9103758714627475, 0.22566585335880518, 0.4042852733982727, 0.7367849769070745, 2.726033334620297, 6.763950074091554, 7.193811507895589, 9.70098964869976, 7.517016939818859, 4.080886021256447, 8.757167793810368, 9.304728861898184, 9.015736319124699, 6.557525200769305, 5.641619022935629, 6.53130660764873, 11.71571183949709, 6.796608371660113, 10.205325186252594, 10.05121210590005, 7.219876209273934, 4.849673118442297, 2.836864124983549, 7.22886367700994, 14.035536758601665, 24.308876395225525, 41.995088160037994, 51.32697321474552, 58.59140060842037, 64.60173189640045, 55.49382962286472, 63.025264889001846, 70.00795260071754, 74.78024572134018, 61.701408326625824, 73.48939418792725, 48.38964343070984, 48.692205995321274, 52.33180269598961, 42.6131933927536, 53.61527882516384, 56.38615474104881, 42.648767083883286, 29.226779602468014, 43.6410990357399, 52.444390654563904, 61.15128144621849, 55.22276356816292, 65.07714718580246, 62.480765506625175, 65.00079408288002, 48.62926237285137, 50.88583208620548, 46.84398137032986, 43.410242423415184, 36.1542733758688, 36.24124690890312, 32.56750524044037, 32.80942305922508, 26.015340127050877, 24.7020260989666, 20.536539517343044, 17.46525552123785, 12.606873270124197, 12.012209929525852, 9.04359357431531, 10.211117025464773, 11.224692687392235, 8.846435453742743, 9.38988134264946, 11.39329344034195, 8.225240986794233, 10.201631784439087, 8.265836108475924, 6.537452777847648, 5.1643499080091715, 3.198749106377363, 0.3976741328369826, 0.11835319921374321, 0.06004063761793077, 0.061235614120960236, 1.3903569127433002, 5.9625008795410395, 17.619627937674522, 32.54401870071888, 37.7383703738451, 47.28241324424744, 68.55216711759567, 73.31861615180969, 51.94966100156307, 31.089506149291992, 24.87864252179861, 28.87733895331621, 50.77584318816662, 52.67932824790478, 57.75805592536926, 51.6414063423872, 19.636014439165592, 3.6183002684265375, 0.07750735778245144, 0.011928658350370824, 0.05798918929940555, 0.019347942070453428, 0.029582082461274695, 0.09025024861330166, 0.02928561301814625, 0.02197344718297245, 0.013401656360656489, 0.08938778395531699, 0.03279642238339875, 0.029480955563485622, 0.08124878397211432, 0.038281264787656255, 0.09530040770187043, 0.040840516521711834, 0.034580185456434265, 0.016200230311369523, 0.021025589157943614, 0.035424434099695645, 0.056441629567416385, 0.013966829646960832, 0.007478329916921211, 0.06548735589603893, 0.04334717596066184, 0.014967338411224773, 0.04156722381594591, 0.11604146115132608, 0.029628283009515144, 0.0397069712926168, 0.021839439432369545, 0.2090626591234468, 0.10034834776888601, 0.19418074283748865, 0.1940353264217265, 0.12272385531105101, 0.12773268419550732, 0.1476044303853996, 0.24352529580937698, 0.1915598928462714, 0.27458727825433016, 0.15018358652014285, 0.1749962253961712, 0.16509806824615225, 0.14365611568791792, 0.2054951700847596, 0.21729313622927293, 0.29648998577613384, 0.16828011546749622, 0.22687056683935225, 0.09931614651577547, 0.2150268101831898, 0.19149222382111475, 0.1788712604320608, 0.21493200823897496, 0.21676447475329041, 0.16860949544934556, 0.2048296417342499, 0.3181169705931097, 0.30692084168549627, 2.562810955569148, 37.27476865053177, 83.9378759264946, 84.34867948293686, 85.2178980410099, 69.81648847460747, 69.82891380786896, 55.23387037217617, 33.40971864759922, 34.3532308191061, 63.52225922048092, 83.07591497898102, 92.70161926746368, 64.93882700800896, 40.24051330983639, 29.133148826658726, 8.513345327228308, 1.4171629305928946, 0.5157143832184374, 0.6050916435196996, 0.8754665509331971, 2.3193202586844563, 9.834549631923437, 12.636271342635155, 17.262422405183315, 11.989126168191433, 10.075326561927795, 11.57149912789464, 17.387699782848358, 16.63940593600273, 14.39704841002822, 12.59082768112421, 21.22362244874239, 18.832889534533024, 11.346229165792465, 16.20316654443741, 14.63492514565587, 14.472899939864874, 10.198970027267933, 10.66207492724061, 15.787706337869167, 18.098426945507526, 25.076807588338852, 45.843453258275986, 54.4105039536953, 61.56005211174488, 64.76620987057686, 57.236720100045204, 62.079412043094635, 71.57081633806229, 74.66699659824371, 70.45774966478348, 78.89582768082619, 51.204068809747696, 56.123311445117, 61.34014271199703, 49.1902756690979, 58.90494078397751, 65.91906040906906, 49.66829001903534, 36.99902884662151, 52.431984320282936, 54.802832901477814, 66.8396446108818, 61.137925162911415, 68.73687520623207, 63.61205980181694, 64.93881940841675, 52.05419339239597, 50.878107100725174, 50.152296647429466, 44.27308112382889, 39.189672097563744, 40.283876582980156, 38.079873248934746, 37.52645954489708, 29.605281092226505, 29.63450912386179, 24.027946069836617, 19.587054066359997, 18.424135968089104, 13.488414566963911, 14.363229274749756, 20.06965856999159, 19.847645983099937, 17.50237762928009, 20.87086647748947, 14.280432667583227, 12.168768178671598, 17.36063953489065, 13.740259353071451, 17.508455403149128, 7.289999071508646, 3.569375518709421, 0.20577647374011576, 0.1446778155514039, 0.17511207464849576, 0.9672267583664507, 2.089691930450499, 11.044208072125912, 25.44813696295023, 46.07005789875984, 50.1592692732811, 58.31852205097675, 84.57817956805229, 89.19488623738289, 64.72050592303276, 42.26395793259144, 32.77861811220646, 37.474155351519585, 60.474480763077736, 61.672168895602226, 67.94261902570724, 62.6191920787096, 28.216265626251698, 5.366389816626906, 0.21353487070882693, 0.14003226795466617, 0.26067272177897394, 0.2538423507940024, 0.09689173559308983, 0.29525172722060233, 0.11821796506410465, 0.2061795341433026, 0.18010021245572716, 0.1860872216639109, 0.14337200671434402, 0.2559740067226812, 0.20924384705722332, 0.14938329899450764, 0.23252681567100808, 0.15190952515695244, 0.1090950405341573, 0.12629392702365294, 0.1395238225813955, 0.1735253629158251, 0.22638962545897812, 0.11097965776571073, 0.21039230574388057, 0.14173563045915216, 0.15150364459259436, 0.1099219785828609, 0.12723072519293055, 0.33107368159107864, 0.1741805754136294, 0.10557638481259346, 0.17472802806878462], [0.018952876453113277, 0.040710588727961294, 0.09288123634178191, 0.05846434192790184, 0.06943719941773452, 0.036818899898207746, 0.005446020195449819, 0.06177667688461952, 0.10454763454617932, 0.04624303990567569, 0.03829782210232224, 0.043738235835917294, 0.0500350768561475, 0.050496043331804685, 0.0800693999917712, 0.04884992267761845, 0.023725453756924253, 0.04680738384195138, 0.035377211243030615, 0.04738265590276569, 0.04029534225992393, 0.028512998324004002, 0.03287533123511821, 0.0518547858519014, 0.07197197512141429, 0.049203919697902165, 0.07420435533276759, 0.07957800917210989, 0.2159793715691194, 6.83907869271934, 46.502421498298645, 68.75235557556152, 67.13976010680199, 58.079214692115784, 58.539445996284485, 47.01083801686764, 38.21723587810993, 39.07831147313118, 43.046381548047066, 70.84910586476326, 77.98389941453934, 69.43790718913078, 26.039561927318573, 24.582408517599106, 3.9863366447389126, 1.1816304316744208, 0.04452054112334736, 0.2526029938599095, 0.17169101134641096, 0.40532796119805425, 2.421775348484516, 6.875209528952837, 5.971717284992337, 4.946565544232726, 3.2293624011799693, 4.066220233216882, 5.140231652185321, 6.02332754060626, 8.49071279168129, 7.247888306155801, 5.823731375858188, 8.11589140444994, 12.936557829380035, 6.247480362653732, 8.861668836325407, 7.27466119453311, 8.192517142742872, 7.080893917009234, 8.536325544118881, 22.927694208920002, 41.930499225854874, 55.05700886249542, 60.53539149463177, 56.09379842877388, 58.700393959879875, 62.63189099729061, 55.45001417398453, 57.06733658909798, 62.445340007543564, 74.26831439137459, 64.86414581537247, 70.71140125393867, 61.37880563735962, 53.19067440927029, 55.50435125827789, 38.08002144098282, 39.6114494651556, 45.27169793844223, 37.05154962837696, 28.89567866921425, 45.45713558793068, 47.4621170014143, 55.885786190629005, 67.27152943611145, 61.99456639587879, 62.36412696540356, 58.433009907603264, 51.35638743638992, 55.77061057090759, 53.15950088202953, 51.564756855368614, 50.5106820166111, 53.16557675600052, 53.424620255827904, 56.174829080700874, 48.77114295959473, 48.09116184711456, 34.198381528258324, 32.59947292506695, 20.450819917023182, 23.69300164282322, 7.999837081879377, 15.222801100462675, 11.25471867620945, 13.552086800336838, 8.80925539880991, 3.963007559068501, 8.088408429175615, 4.131772415712476, 5.639901040121913, 4.069204498082399, 2.716802442446351, 1.7701827501878142, 0.9803461481351405, 0.13954136695247144, 0.07501098822103813, 0.031052219492266886, 0.07910470449132845, 0.8611182833556086, 4.5221116952598095, 22.135210633277893, 53.032948672771454, 72.58805975317955, 90.73836341500282, 88.50061029195786, 74.19710621237755, 61.176067516207695, 38.39213669300079, 25.652556493878365, 31.825175173580647, 47.88257583975792, 53.409280478954315, 45.86475111544132, 39.61790531873703, 8.468480184674263, 0.24317515053553507, 0.07202353212051094, 0.03394312589080073, 0.04489028280659113, 0.05879027463379316, 0.07951370949740522, 0.05031111497373786, 0.028935170885233674, 0.05229230417171493, 0.11041874997317791, 0.057049188762903214, 0.007743764135739184, 0.023531088991148863, 0.043126832315465435, 0.1394439971772954, 0.03365106851560995, 0.018777397490339354, 0.09460876317461953, 0.04086741195351351, 0.06467475614044815, 0.06443746184231713, 0.023578567888762336, 0.015990258179954253, 0.08899359963834286, 0.09394476364832371, 0.10489666659850627, 0.05042648183007259, 0.16211479785852134, 0.04564679846225772, 0.05448319832794368, 0.043698438166757114, 0.07496315680327825, 0.02980139081046218, 0.11702733012498356, 0.04258537621353753, 0.08538925554603338, 0.01697577092272695, 0.0628332576889079, 0.02532058144424809, 0.06374626260367222, 0.04679600300733, 0.013785721494059544, 0.009984959669964155, 0.013894316252844874, 0.037164250898058526, 0.045277709868969396, 0.04901074978988618, 0.0454522184736561, 0.03225914828362875, 0.06994908835622482, 0.02013638677453855, 0.021722504789067898, 0.052242468955228105, 0.0698134014965035, 0.010024961429735413, 0.05148387899680529, 0.006654723647443461, 0.046441441954812035, 0.07915315189165995, 0.19872972217854112, 8.663499020040035, 53.47640387713909, 78.21147680282593, 75.37318110466003, 65.62309429049492, 68.61222669482231, 60.42473763227463, 46.040149703621864, 37.714758440852165, 31.6486993432045, 62.02881395816803, 80.16723945736885, 77.74711892008781, 31.758372858166695, 19.50905755162239, 5.305519932880998, 0.8689961512573063, 0.15379211632534862, 0.32140293333213776, 0.6624160800129175, 3.3210502937436104, 5.014140168204904, 8.401323538273573, 7.914718324318528, 9.710560385137796, 8.42983815819025, 12.818826846778393, 10.60704343020916, 10.650199614465237, 9.767702668905258, 10.891328025609255, 7.808287460356951, 6.613222612068057, 10.302328281104565, 7.384213116019964, 5.248205233365297, 5.297689978033304, 4.590514674782753, 5.578027060255408, 9.593536164611578, 23.614254668354988, 43.722851648926735, 57.47600466012955, 63.52383233606815, 61.41728237271309, 62.31006346642971, 64.68626976013184, 57.01560616493225, 56.96118928492069, 63.5319335013628, 73.51169899106026, 63.966124802827835, 72.19671875238419, 64.11228775978088, 61.380602940917015, 58.930388018488884, 45.35861447453499, 47.90265776216984, 50.01917839050293, 43.92730347812176, 34.7554924339056, 51.36393383145332, 50.431752651929855, 61.75329454243183, 69.86650139093399, 65.56921318173409, 64.43719312548637, 58.789780363440514, 53.42181980609894, 57.15339817106724, 56.40313982963562, 56.71219244599342, 52.60180480778217, 54.93232615292072, 54.70990128815174, 56.79622493684292, 50.98930053412914, 46.68535888195038, 36.342823058366776, 31.54447853565216, 20.565970838069916, 23.197627924382687, 9.888466838747263, 10.693763326853514, 7.18373634852469, 8.149121571332216, 11.08725881204009, 8.169355485588312, 10.369619820266962, 8.424270506948233, 9.422326851636171, 9.759497009217739, 6.783572221174836, 5.846242792904377, 2.078490131534636, 1.271876182872802, 0.46047790499869734, 0.17985819809837267, 0.05086071614641696, 0.6648879661224782, 3.495989106595516, 18.67631133645773, 51.66599862277508, 72.69962176680565, 93.1983134150505, 89.60175320506096, 74.79728400707245, 62.513804733753204, 40.332669764757156, 33.48342329263687, 41.764364540576935, 55.97098521888256, 60.46368174254894, 53.653622567653656, 45.94665952026844, 10.928398836404085, 0.3117467014817521, 0.10313094142475165, 0.0324177786387736, 0.05643114673148375, 0.05173956000362523, 0.03408706543268636, 0.0333101147407433, 0.029412243820843287, 0.04035806858155411, 0.058715262057376094, 0.0741185036895331, 0.06983171027968638, 0.024394306929025333, 0.024606457263871562, 0.06952199721126817, 0.04346532958152238, 0.014207693675416522, 0.08310721081215888, 0.06624517031013966, 0.04457958639250137, 0.0718810100806877, 0.03275229057180695, 0.03566286017303355, 0.0583661075506825, 0.01885986865090672, 0.04394954383315053, 0.04499474751355592, 0.08109970134682953, 0.022483206157630775, 0.041126584765152074, 0.023191892250906676, 0.22182310174684972, 0.30189198965672404, 0.26148955919779837, 0.15102426172234118, 0.22267514665145427, 0.14503346756100655, 0.13505123992217705, 0.15117494738660753, 0.22624153731158003, 0.08819461087114178, 0.12670241994783282, 0.16043987445300445, 0.17295612080488354, 0.14306610828498378, 0.1844785868888721, 0.17647339613176882, 0.21210558334132656, 0.2217864544945769, 0.14287865662481636, 0.19180846778908744, 0.0817344083043281, 0.1089689348009415, 0.15493181766942143, 0.16911353246541694, 0.18418009509332478, 0.15349096764111891, 0.2229777944739908, 0.3197966585867107, 0.4314534296281636, 11.838813833892345, 64.47514548897743, 87.67382025718689, 87.11543262004852, 75.99079236388206, 76.27657502889633, 64.02837306261063, 49.51209180057049, 53.12096334993839, 58.9699362963438, 78.3521756529808, 86.35246396064758, 77.73576512932777, 37.00247526168823, 31.002169735729694, 5.664164163172245, 1.589914367068559, 0.289557168725878, 0.49051211681216955, 0.3977772913640365, 2.158001814968884, 7.458435483276844, 16.124090887606144, 15.802423898130655, 12.52553578466177, 10.144534148275852, 12.619284354150295, 11.760499086230993, 12.71670637652278, 17.6065319404006, 18.821153864264488, 14.5633483864367, 20.241922326385975, 25.082231797277927, 15.047332216054201, 16.27501878887415, 15.553120225667953, 15.306678749620914, 12.078403327614069, 12.385688088834286, 28.914139978587627, 48.80459636449814, 57.948839887976646, 64.83411222696304, 61.43402047455311, 62.90439337491989, 66.65447294712067, 56.17614760994911, 58.49965453147888, 64.31426212191582, 69.92932721972466, 64.55998733639717, 77.64675110578537, 66.80929943919182, 62.660731449723244, 66.75559312105179, 52.466456070542336, 50.680551901459694, 56.903428584337234, 49.542110189795494, 43.619185611605644, 59.18771781027317, 54.18624758720398, 65.69776028394699, 70.5624720454216, 66.32164880633354, 64.39680889248848, 61.314874067902565, 52.07598142325878, 58.5747043043375, 55.511779859662056, 56.80789031088352, 54.086084961891174, 56.58212922513485, 57.66891270875931, 60.72652883827686, 52.15115658938885, 52.912270948290825, 38.847986832261086, 37.081283032894135, 23.547887429594994, 28.82149524986744, 12.802127692848444, 24.024592749774456, 19.818444550037384, 24.0404511988163, 17.423070184886456, 10.199698638170958, 17.0011655241251, 11.840611137449741, 14.325683489441872, 12.016172166913748, 11.674219015985727, 8.63844696432352, 1.428958447650075, 1.3083370076492429, 0.4820359591394663, 0.1428015623241663, 0.4504687077132985, 1.3148040231317282, 6.928548691794276, 28.77844735980034, 62.175873667001724, 80.52657097578049, 92.31634274125099, 89.13085967302322, 80.59761196374893, 71.7953234910965, 50.5418099462986, 37.39084482192993, 48.49769063293934, 64.93429765105247, 69.77738097310066, 64.07076358795166, 57.08019509911537, 16.077188104391098, 0.6589323200751096, 0.1662978538661264, 0.1676555091398768, 0.19694236340001225, 0.11942596625885926, 0.18276453745784238, 0.08904857793822885, 0.07208630297100171, 0.2577554283197969, 0.21241069509414956, 0.1473182433983311, 0.17057255026884377, 0.10770205160952173, 0.18569646606920287, 0.23398617486236617, 0.19013765588169917, 0.10713755924371071, 0.18791017384501174, 0.22282967664068565, 0.14562804659362882, 0.1668386420351453, 0.1908100862056017, 0.11173140141181648, 0.1756262790877372, 0.1966650821850635, 0.15453166648512706, 0.21264828625135124, 0.27904648741241544, 0.12024511175695807, 0.19793489685980603, 0.24149144010152668], [0.04139877113630064, 0.019493302825139835, 0.02262757614516886, 0.008593686961830826, 0.009099906819756143, 0.037844544276595116, 0.07362596996244974, 0.026946886755467858, 0.04310286465624813, 0.027776223796536215, 0.034818043786799535, 0.05586987899732776, 0.053176398723735474, 0.028052063389623072, 0.08200669486541301, 0.02412100919173099, 0.06795376495574601, 0.021872225661354605, 0.023355927296506707, 0.05475998230394907, 0.04020916036097333, 0.05707567972422112, 0.03582272620406002, 0.052909084552084096, 0.10460069810505956, 0.09795889200177044, 0.12863831216236576, 0.0512695949873887, 0.7565873768180609, 27.339287884533405, 65.2808390557766, 70.91384679079056, 65.71458578109741, 59.87514652311802, 34.922094494104385, 21.735576577484608, 15.663071125745773, 15.19655590876937, 38.94913740456104, 62.479074597358704, 68.97152781486511, 28.754007071256638, 21.235394217073917, 6.398860439658165, 0.4418408253695816, 0.08522175281541422, 0.24949381069745868, 0.08795842979452573, 1.5818121330812573, 2.509423582814634, 4.65467375703156, 6.667313184589148, 5.95336047001183, 8.740628231316805, 6.983669959008694, 3.7183961598202586, 11.347464099526405, 11.375271957367659, 7.669801041483879, 4.323680642992258, 5.002777827903628, 3.578935330733657, 10.017055738717318, 8.558595199137926, 13.041258361190557, 12.182912919670343, 12.332338001579046, 18.014438152313232, 28.108205124735832, 49.90333780646324, 59.29554842412472, 62.130519300699234, 60.099041908979416, 67.34970644116402, 66.30405575037003, 67.6791563630104, 61.09003633260727, 67.04875499010086, 69.69778284430504, 68.15495923161507, 70.23054465651512, 65.27196273207664, 64.53094929456711, 59.90451894700527, 61.126400381326675, 40.367183312773705, 31.487947069108486, 45.80860912799835, 44.49831783771515, 36.72080397605896, 48.70926707983017, 49.15778361260891, 61.11045643687248, 68.73071193695068, 69.44882020354271, 64.70507875084877, 60.9736979752779, 52.59147696197033, 57.53420613706112, 54.04976651072502, 52.5509787350893, 52.50744827091694, 57.68968239426613, 59.542322382330894, 63.41970652341843, 57.29415401816368, 58.96400101482868, 52.73844547569752, 49.16470684111118, 38.67411956191063, 46.04018770158291, 36.46474711596966, 22.09661040455103, 16.26159980893135, 2.6153970463201404, 7.288498627021909, 21.981296092271805, 9.607149884104729, 9.463587887585163, 6.937271123751998, 6.343550132587552, 6.418590405955911, 5.184444654732943, 2.718247789889574, 1.39333761529997, 0.20527035871054977, 0.007162053016145364, 0.03100027472100919, 0.07456146937329322, 0.6065129453781992, 2.3259409284219146, 19.000259153544903, 36.62714280188084, 45.60215100646019, 49.37249109148979, 41.5677896887064, 33.179925978183746, 22.20472600311041, 17.562431506812572, 32.07483887672424, 37.621579840779305, 45.814365819096565, 53.39062727987766, 45.0820729136467, 13.43865243718028, 0.6352376227732748, 0.10443063496495597, 0.033528673520777375, 0.005750634709329461, 0.06837809531134553, 0.008730025983822998, 0.04436353236087598, 0.04679504934756551, 0.0538682584738126, 0.026441063018864952, 0.07326144928811118, 0.07624123900313862, 0.004713742619060213, 0.06351593707222492, 0.12055031998897903, 0.07805831337464042, 0.010698243368096882, 0.03763781161978841, 0.03866588282107841, 0.04236628308717627, 0.04524579751887359, 0.04036290367366746, 0.016601101378910244, 0.06342540989862755, 0.07026537685305811, 0.051407549108262174, 0.010020063255069545, 0.0908387939853128, 0.028188091637275647, 0.03771231211430859, 0.03419350425247103, 0.04927428642986342, 0.07649003659025766, 0.07492338510928676, 0.053313866737880744, 0.03682895599922631, 0.01691710600425722, 0.07637199058081023, 0.01233279486768879, 0.024825719228829257, 0.06447786436183378, 0.03357853842317127, 0.034960157645400614, 0.002391258026364085, 0.03147994517348707, 0.0330846576980548, 0.04534622123173904, 0.02211757226177724, 0.04727142280898988, 0.010299173864041222, 0.08184355596313253, 0.04144949692999944, 0.02491089737304719, 0.04622343236405868, 0.0523555871041026, 0.06807931407820433, 0.00901307275853469, 0.09417678127647378, 0.0940605386858806, 1.266564424149692, 33.15383277833462, 74.82531890273094, 79.93162930011749, 73.27430292963982, 67.947558760643, 42.66818404197693, 29.649693109095097, 26.945224329829216, 26.950739733874798, 42.290134727954865, 61.77592612802982, 77.74166241288185, 37.99104921519756, 18.085004165768623, 6.149880224838853, 0.28487632458563894, 0.03771792646148242, 0.5195254599675536, 1.6608214122243226, 3.9223549654707313, 5.919795446097851, 9.913279507309198, 9.791486542671919, 6.448143795132637, 10.546104200184345, 15.484528206288815, 14.436437096446753, 20.629925206303596, 15.953696630895138, 10.916744861751795, 7.011081213131547, 7.6073727663606405, 3.9868206437677145, 5.681205298751593, 5.335429552942514, 5.793676413595676, 9.00921206921339, 10.295128617435694, 17.327113933861256, 30.366781130433083, 53.34410637617111, 61.84962697327137, 66.22512638568878, 63.38710427284241, 67.9534712433815, 65.02148017287254, 66.7302180826664, 61.469578966498375, 67.42424324154854, 69.56263929605484, 68.27859699726105, 69.17959704995155, 64.45176154375076, 67.12557926774025, 66.13869622349739, 61.761521100997925, 45.437171459198, 39.50510457158089, 50.95757983624935, 51.33615352213383, 43.359408751130104, 52.97028623521328, 53.06893274188042, 62.52977527678013, 67.37177565693855, 69.58640322089195, 63.54438163340092, 61.41766995191574, 53.44853617250919, 58.46979573369026, 55.47356531023979, 55.7978019118309, 56.340184807777405, 60.03672145307064, 60.11241339147091, 64.75150465965271, 58.17537233233452, 59.6963395178318, 56.02705501019955, 48.19285199046135, 37.91249603033066, 35.994336158037186, 27.65398319810629, 20.465084351599216, 15.970155447721481, 7.171454932540655, 7.689253622666001, 7.277706731110811, 12.326495815068483, 8.875762280076742, 6.3266058918088675, 8.906021006405354, 8.596172332763672, 7.542714010924101, 3.1081287190318108, 4.279059637337923, 1.808876667637378, 0.7291318313218653, 0.19330218841787428, 0.08708682929864153, 0.4797619889723137, 2.8870751056820154, 22.330590449273586, 48.04985046386719, 61.02353610098362, 60.73755204677582, 47.838179022073746, 40.051720440387726, 32.8343041241169, 24.057886563241482, 37.71392248570919, 45.310170873999596, 54.39794942736626, 61.55316688120365, 53.0221002548933, 17.29733493179083, 0.7597727340180427, 0.008433005496044643, 0.03564111153536942, 0.06620602202019654, 0.07433392689563334, 0.07785566995153204, 0.03321773219795432, 0.030626844563812483, 0.05837699856783729, 0.021838359607500024, 0.09645069207181223, 0.0688984447333496, 0.0922608825203497, 0.05956822351436131, 0.02439173353195656, 0.027267930563539267, 0.0653883905033581, 0.06895643615280278, 0.04766812671732623, 0.026854333518713247, 0.026294397939636838, 0.060007686261087656, 0.015076961972226854, 0.009946001555363182, 0.06543585826875642, 0.045512684955610894, 0.008640984960948117, 0.03654234227724373, 0.021488203201442957, 0.050709674251265824, 0.07777979277307168, 0.08640965665108524, 0.18331840226892382, 0.13776761916233227, 0.15415527886943892, 0.11926238948944956, 0.12449850109987892, 0.2897117135580629, 0.15774878760566935, 0.18027742247795686, 0.12684224057011306, 0.08910758609999903, 0.13084620150038972, 0.1463306526420638, 0.14043060829862952, 0.1281556489993818, 0.08162947604432702, 0.10822355136042461, 0.12237139453645796, 0.19248143245931715, 0.16932955681113526, 0.15814450074685737, 0.19971728324890137, 0.14388811105163768, 0.12985046196263283, 0.22559858509339392, 0.2141308449790813, 0.18394109385553747, 0.20757126883836463, 1.8241573101840913, 42.889043390750885, 83.84233385324478, 88.7752215564251, 83.00058022141457, 75.86009457707405, 49.353739097714424, 31.60468440502882, 22.819897793233395, 22.87162061780691, 50.01670092344284, 71.80095478892326, 79.63821664452553, 40.74487924575806, 29.388677515089512, 7.789700757712126, 0.9498311730567366, 0.21685651590814814, 0.6018307653721422, 0.7871639204677194, 4.063328113406897, 7.880785670131445, 15.672583915293217, 17.69224014133215, 17.222049571573734, 18.412905670702457, 17.030129469931126, 12.051469422876835, 22.86013763397932, 23.401219099760056, 16.342894546687603, 13.64474767819047, 15.410741865634918, 10.862758308649063, 18.26356988400221, 16.742182821035385, 21.5489723905921, 19.36983872205019, 17.906881123781204, 22.357850186526775, 33.34622785449028, 55.07841691374779, 63.088634088635445, 66.95944458246231, 65.07167547941208, 70.30860006809235, 67.09242984652519, 66.83048710227013, 64.71764847636223, 67.9385456442833, 72.14469194412231, 69.99377176165581, 70.52270337939262, 66.25319927930832, 67.30350852012634, 66.75720423460007, 68.50381091237068, 52.96335160732269, 43.11984300613403, 57.999517768621445, 57.59172745049, 51.79919667541981, 59.59536373615265, 57.0002131909132, 65.35189524292946, 66.2333795428276, 69.47309330105782, 67.30432167649269, 62.082592472434044, 53.255989104509354, 57.79183231294155, 56.58231921494007, 55.58887392282486, 58.14936272799969, 62.032849341630936, 64.30527940392494, 68.36320325732231, 62.0372799038887, 62.85429686307907, 56.80826649069786, 52.970985397696495, 42.74089314043522, 48.64235267043114, 41.89712181687355, 28.945976570248604, 25.443508811295033, 10.86450906470418, 16.66110847145319, 33.47147673368454, 23.20067536085844, 15.291026439517736, 17.80386295169592, 18.314380757510662, 16.397005543112755, 14.757417272776365, 9.64126730337739, 4.329291991889477, 1.0326410201378167, 0.4341936169657856, 0.20169258350506425, 0.12479953846195713, 1.2887112982571125, 3.545324234291911, 26.572091951966286, 50.1406616717577, 56.94704644382, 56.2347936630249, 48.79451930522919, 43.15187148749828, 31.92725859582424, 29.069350250065327, 45.88026948273182, 54.27516661584377, 62.845621928572655, 69.13389310240746, 60.74032969772816, 24.194876812398434, 1.513921651057899, 0.20909045997541398, 0.10319915221771225, 0.16049647063482553, 0.20301897951867431, 0.24202084372518584, 0.22898856725078076, 0.11000184109434485, 0.14413146127481014, 0.17092996858991683, 0.32873449148610234, 0.24519263446563855, 0.17494285013526678, 0.15118777169845998, 0.16031413979362696, 0.1188074826495722, 0.3023284615483135, 0.14167170185828581, 0.24463041307171807, 0.281283498625271, 0.15440777235198766, 0.16750016278820112, 0.10847610421478748, 0.18495900876587257, 0.11716657187207602, 0.15830985124921426, 0.08584372451878153, 0.14510738546960056, 0.12879474204964936, 0.11489626791444607, 0.16732210671762004], [0.06528398516820744, 0.06215395136678126, 0.007752629089736729, 0.0126350038954115, 0.07930034946184605, 0.04696230716945138, 0.010811995125550311, 0.027833588101202622, 0.04634559358237311, 0.05785643392300699, 0.01356700593532878, 0.022477528727904428, 0.03216259858163539, 0.042763625242514536, 0.02271856716106413, 0.02315535632078536, 0.06217958143679425, 0.02087461034534499, 0.05624620724120177, 0.020838343443756457, 0.041514683471177705, 0.08832844978314824, 0.05999065026117023, 0.0723411787475925, 0.033516784314997494, 0.0630158037529327, 0.033325692420476116, 0.04575127430143766, 7.787270313128829, 61.069331243634224, 75.43260991573334, 56.85334727168083, 55.8068872243166, 51.41473710536957, 37.835223376750946, 33.91978047788143, 34.377184733748436, 30.32397262752056, 21.802536584436893, 55.107150971889496, 49.04151365160942, 20.612098462879658, 7.999352607876062, 0.5611928959842771, 0.29065658629406244, 0.12452981231035665, 0.2571766421897337, 1.0037402459420264, 1.3627858296968043, 7.442315798252821, 6.2643153592944145, 5.603925520554185, 5.5049413070082664, 9.987328983843327, 15.699039045721292, 25.310348756611347, 16.978883519768715, 12.226421535015106, 9.482757858932018, 8.670343402773142, 9.961243383586407, 9.695802927017212, 16.144493892788887, 18.708569705486298, 16.401234716176987, 25.357321836054325, 34.74147118628025, 46.291779801249504, 62.27942191064358, 65.34613475203514, 61.37355051934719, 60.63873074948788, 59.65977028012276, 63.609722927212715, 65.27703925967216, 65.2269047498703, 67.71017789840698, 62.51801110804081, 66.93406194448471, 67.22264885902405, 66.05276003479958, 65.02398803830147, 66.68778955936432, 66.36856108903885, 60.845846235752106, 49.7683272510767, 23.438441902399063, 39.16995495557785, 40.52744351327419, 44.21699993312359, 49.154599383473396, 54.21451047062874, 59.399203062057495, 64.50698778033257, 59.151441156864166, 59.86345835030079, 57.47065834701061, 61.72347754240036, 55.64543768763542, 53.890460059046745, 55.65843679010868, 58.28202120959759, 59.79638434946537, 57.9361941665411, 61.22924566268921, 59.25362527370453, 59.371582344174385, 59.2264149338007, 58.042257875204086, 51.026321947574615, 48.2403988391161, 35.21633170545101, 35.92414252460003, 26.82229522615671, 17.28506349027157, 26.45068846642971, 13.232374805957079, 15.987397022545338, 9.757054690271616, 6.895409720018506, 8.511400781571865, 5.158364279195666, 4.4911599811166525, 3.589248927310109, 2.1498476900160313, 1.5065760514698923, 0.8305434021167457, 0.20400107838213444, 0.038359839672921225, 0.09098691181861795, 0.1687303467770107, 3.542014374397695, 19.202678091824055, 33.68811450898647, 28.742582984268665, 28.833751492202282, 31.852613501250744, 19.443205185234547, 27.057166323065758, 30.941167809069157, 37.562926188111305, 47.43867985904217, 52.78009504079819, 57.984322383999825, 30.967948772013187, 3.5314996261149645, 0.06976427874178626, 0.025320698332507163, 0.06579891691217199, 0.03435000835452229, 0.019163421893608756, 0.03346974328451324, 0.028472157937358133, 0.020554497932607774, 0.02628002253914019, 0.041815854419837706, 0.033668334581307136, 0.06556354477652349, 0.052053210165468045, 0.08062276756390929, 0.06882739893626422, 0.10911660734564066, 0.042245839940733276, 0.061155399089329876, 0.03753076794964727, 0.02310111274709925, 0.03604825004003942, 0.05028398576541804, 0.025677079502202105, 0.021752749162260443, 0.10346435126848519, 0.04396886935865041, 0.007991411857801722, 0.02707656407437753, 0.016426143774879165, 0.03270727189374156, 0.0007012689650309767, 0.06191531749209389, 0.0378364251810126, 0.03600586598622613, 0.06742281024344265, 0.04414942646690179, 0.020601984251698013, 0.04656123201129958, 0.019617859325080644, 0.04462530640012119, 0.0994293017720338, 0.03761244130146224, 0.10261954230372794, 0.02958859666250646, 0.06895269572851248, 0.05610762600554153, 0.10768366861157119, 0.08221310097724199, 0.08778247400186956, 0.02694589227758115, 0.014130141098576132, 0.016025617806008086, 0.09901890152832493, 0.05867786152521148, 0.03100019122939557, 0.03481062602077145, 0.06778061448130757, 0.029290923084772658, 10.742317121475935, 69.2833086848259, 82.43247270584106, 66.79275512695312, 64.81568321585655, 59.838740676641464, 44.65263895690441, 41.6587720066309, 33.28331083059311, 27.43080597370863, 27.840543687343597, 63.67018148303032, 53.69800038635731, 20.314975306391716, 7.4619118217378855, 0.4669701831880957, 0.3051859972765669, 0.2820710954256356, 1.0709276469424367, 3.009977610781789, 9.685134999454021, 7.998158521950245, 10.5158806219697, 10.826481655240059, 12.939560618251562, 12.670642398297787, 17.612317129969597, 24.09150715917349, 17.28045243769884, 19.345075450837612, 8.541545514017344, 6.925916383042932, 10.099740251898766, 10.919516813009977, 12.697411961853504, 16.41913365572691, 16.776361986994743, 25.740402080118656, 32.71234966814518, 46.00376285612583, 62.49548211693764, 68.79791513085365, 64.97311636805534, 64.35342282056808, 62.801795080304146, 67.42343008518219, 67.19526752829552, 67.17139720916748, 69.04102608561516, 63.59437935054302, 68.84171158075333, 67.68354892730713, 65.96794098615646, 66.731076836586, 65.81480160355568, 69.64790672063828, 61.429935693740845, 51.915979608893394, 30.06303682923317, 43.597807958722115, 45.354256108403206, 48.61188590526581, 54.397664442658424, 58.73817153275013, 62.77540549635887, 65.2353934943676, 59.582129046320915, 59.23503287136555, 57.76878274977207, 60.24182304739952, 57.05085687339306, 55.45441813766956, 56.30415894091129, 59.05146852135658, 59.88840401172638, 61.165013909339905, 63.57835941016674, 62.27294325828552, 61.37290075421333, 61.6408471763134, 56.96115508675575, 52.033366709947586, 46.76365748047829, 38.4798663854599, 30.963805094361305, 24.48559921234846, 16.89312592148781, 20.264715403318405, 10.570113211870193, 20.794690065085888, 11.931563057005405, 12.010971195995808, 12.469901069998741, 8.044982459396124, 7.847577827051282, 6.155902901664376, 6.775489104911685, 4.636081829667091, 2.8846938209608197, 0.34870336996391416, 0.31487705069594085, 0.1264553886721842, 0.07033801084617153, 4.2106101103127, 20.82572679966688, 35.50525680184364, 29.954649545252323, 26.785923577845097, 25.78874498605728, 22.930293269455433, 37.05237418413162, 36.86266176402569, 44.89169932901859, 53.262585550546646, 60.937504917383194, 62.51335635781288, 38.11112277209759, 4.4532104674726725, 0.05879784454009496, 0.044355379868648015, 0.025662551961431745, 0.04355540033429861, 0.005415126906882506, 0.04455984526430257, 0.01118061152737937, 0.06859424582216889, 0.01819421970139956, 0.07557399629149586, 0.025828247562458273, 0.047730055230204016, 0.0679675763240084, 0.03333622349600773, 0.05530422888114117, 0.11410594001063146, 0.02268553973408416, 0.062169005832402036, 0.04407807638926897, 0.02829084940458415, 0.030963935460022185, 0.017402131052222103, 0.021679534438590053, 0.019446126352704596, 0.06042407563654706, 0.11423739662859589, 0.07777584454743192, 0.05521310798940249, 0.007143676511986996, 0.08644949513836764, 0.10480221346369945, 0.14252500841394067, 0.1015249932243023, 0.131170371605549, 0.22700988280121237, 0.1825785997789353, 0.14125439221970737, 0.08875021972926334, 0.09691502418718301, 0.15905412146821618, 0.15188700839644298, 0.20821484446059912, 0.27019827626645565, 0.19491814076900482, 0.19105079438304529, 0.1432597346138209, 0.2582447708118707, 0.1535220636287704, 0.26652794040273875, 0.17457421054132283, 0.09145788615569472, 0.19004729198059067, 0.2131478110095486, 0.0837029550166335, 0.11395477195037529, 0.14765376836294308, 0.15564335917588323, 0.13665064238011837, 15.878084488213062, 80.99917441606522, 91.00489631295204, 75.15255734324455, 73.08346956968307, 66.74129828810692, 51.815881580114365, 47.449893057346344, 45.393865182995796, 45.07458731532097, 32.8759802877903, 69.01183605194092, 60.985389947891235, 26.51970226317644, 10.062614344060421, 1.0220349580049515, 0.44315104256384075, 0.3239034960279241, 0.8105923351831734, 2.4459083285182714, 8.94396387040615, 19.929605685174465, 16.314282082021236, 16.60029463469982, 15.605367422103882, 22.403305247426033, 27.772154957056046, 36.81133791804314, 26.378076262772083, 18.698663637042046, 19.088482819497585, 19.172581806778908, 17.497295401990414, 17.498547434806824, 21.471612341701984, 24.855186380445957, 19.56651996821165, 29.480725675821304, 38.578452095389366, 49.72555294632912, 66.66716426610947, 69.98408228158951, 66.72617509961128, 65.46003744006157, 65.5857802927494, 67.60059177875519, 69.15904775261879, 68.4444808959961, 71.31869986653328, 68.32523569464684, 70.21450951695442, 71.46806225180626, 69.37603130936623, 69.72875878214836, 68.37541580200195, 70.12892290949821, 63.43410015106201, 57.89210133254528, 32.94881097972393, 49.85055863857269, 52.24008321762085, 55.66846825182438, 59.358222261071205, 60.387784615159035, 65.23773416876793, 63.20816047489643, 59.95320953428745, 59.71682421863079, 58.67625005543232, 60.985424146056175, 55.75438164174557, 54.645924121141434, 58.10874290764332, 58.12397249042988, 61.17155335843563, 61.60921387374401, 64.60173949599266, 63.66117976605892, 65.0218677520752, 63.63628730177879, 59.62201550602913, 53.86802986264229, 50.939128026366234, 38.19444850087166, 37.93454624712467, 29.457803405821323, 25.053792223334312, 33.73147778213024, 21.48177869617939, 25.333892293274403, 18.524743169546127, 21.023223102092743, 18.940370567142963, 14.993471056222916, 14.262546077370644, 11.485163010656834, 10.390432253479958, 5.229530660435557, 2.5585520965978503, 0.4488859442062676, 0.6408502778504044, 0.21961539052426815, 0.6104195513762534, 4.902004385367036, 27.586124539375305, 48.88358652591705, 43.65226663649082, 42.97162435948849, 44.328516349196434, 34.058925211429596, 39.223193898797035, 43.71254280209541, 53.424912840127945, 61.947217136621475, 68.37257355451584, 71.19090512394905, 48.6875132471323, 7.573285745456815, 0.19765246513998136, 0.12929545424412936, 0.09755166072864085, 0.08644442626973614, 0.1284722491982393, 0.1297082516248338, 0.12643775524338707, 0.14584644581191242, 0.18690874945605174, 0.12374478334095329, 0.1276184676680714, 0.21545654337387532, 0.18012124492088333, 0.18473001167876646, 0.24785118555882946, 0.23692439688602462, 0.14858189824735746, 0.15289094124455005, 0.12197702468256466, 0.13043981627561152, 0.184283624694217, 0.17984994541620836, 0.10000721958931535, 0.09606492370949127, 0.27329267584718764, 0.2157360065029934, 0.18769722199067473, 0.19368417182704434, 0.1432327798102051, 0.20902406744426116], [0.046775352748227306, 0.061625100643141195, 0.048057939784484915, 0.07043373305350542, 0.004174840432824567, 0.03224061685614288, 0.06861748988740146, 0.022442833324021194, 0.07070662817568518, 0.017124875812442042, 0.05656418783473782, 0.043538215904845856, 0.042441406985744834, 0.025701501726871356, 0.03150087744870689, 0.056983824106282555, 0.023508611193392426, 0.010484669965080684, 0.06699277277220972, 0.020491237264650408, 0.01800716509023914, 0.055359812031383626, 0.009339355201518629, 0.056458591352566145, 0.05525269043573644, 0.022592676650674548, 0.0602885965781752, 1.2203611596487463, 28.231158927083015, 70.94708740711212, 68.41202303767204, 65.99054217338562, 48.919904977083206, 31.423126347362995, 17.131392136216164, 15.751248244196177, 24.560286104679108, 42.017434760928154, 28.677197992801666, 43.56001518666744, 27.163769602775574, 7.896049451082945, 0.3805357462260872, 0.08493845278280787, 0.08983611536677927, 0.6699022126849741, 1.4136062026955187, 6.061060465872288, 7.773563973605633, 3.9334456203505397, 9.529929477721453, 6.274704951792955, 4.929514434188604, 10.174371097236872, 16.3003159314394, 23.232168070971966, 27.98587828874588, 32.444593235850334, 19.144545011222363, 21.77847247570753, 29.56020411103964, 32.1014716476202, 41.03225402534008, 43.94333101809025, 48.34727570414543, 55.044575929641724, 56.46425575017929, 60.18986463546753, 64.26706865429878, 60.17990157008171, 60.89085482060909, 57.68327213823795, 57.38731361925602, 59.48047310113907, 64.56992000341415, 63.50756920874119, 59.8785625398159, 63.054462522268295, 62.47491382062435, 62.462404891848564, 62.3673339933157, 62.23599024116993, 64.96933177113533, 69.03241574764252, 60.31680442392826, 57.38192930817604, 24.976850152015686, 35.58869652450085, 34.58693727850914, 43.505617305636406, 54.675714522600174, 60.762056931853294, 56.17317616939545, 58.92744317650795, 62.01061673462391, 64.99898537993431, 61.20991989970207, 61.74609012901783, 61.59941799938679, 55.10322958230972, 53.36972080171108, 56.526310220360756, 59.28124979138374, 59.027632400393486, 61.346294581890106, 60.547129064798355, 58.63709315657616, 60.5763228982687, 56.76211416721344, 59.03259113430977, 50.26366867125034, 54.55788664519787, 44.87993896007538, 46.66482478380203, 30.324806682765484, 25.98193421959877, 14.183976743370295, 21.980976909399033, 19.068273603916168, 7.301492504775524, 8.525887504220009, 7.1789671294391155, 5.3627158887684345, 1.4376245951279998, 6.988341333344579, 4.69326876103878, 1.94081841269508, 0.33898785535711795, 0.11031582151190378, 0.10807832790305838, 0.015867668371356558, 0.06528625614009798, 5.011286521330476, 28.79711765795946, 42.83727116882801, 44.86305646598339, 48.58848296105862, 39.42131146788597, 14.291679114103317, 18.511215895414352, 26.52555774897337, 36.99797250330448, 52.33438655734062, 56.12233869731426, 41.69158324599266, 12.070445604622364, 0.17564639128977433, 0.01497955601735157, 0.009713520084915217, 0.02121071232977556, 0.03626176592661068, 0.04376491233415436, 0.036851387412752956, 0.058242669838364236, 0.030918031770852394, 0.0547794302838156, 0.04346871006418951, 0.0076664972857543034, 0.026344693287683185, 0.061140121979406103, 0.016360754998459015, 0.031069589458638802, 0.08869147131917998, 0.023383585285046138, 0.05042761731601786, 0.13595067837741226, 0.03066454937652452, 0.01597301623405656, 0.02663129587745061, 0.03476842750387732, 0.0873248880088795, 0.0777428931905888, 0.041175128644681536, 0.06734223527018912, 0.02928299509221688, 0.03090620750299422, 0.033185088832397014, 0.08734518574783579, 0.059112541130161844, 0.039233017232618295, 0.0825449894182384, 0.03706565286847763, 0.04012080025859177, 0.03445058420766145, 0.09517344107734971, 0.03588879219023511, 0.019518341032380704, 0.04250405167113058, 0.019478910726320464, 0.03439731655817013, 0.0044903014349984005, 0.05931421233981382, 0.03067706013098359, 0.036653898205258884, 0.09763905603904277, 0.11031162095605396, 0.054900032992009073, 0.011309655237710103, 0.06970538932364434, 0.08655517696752213, 0.033209349639946595, 0.02409874476143159, 0.02384667986916611, 1.7927540140226483, 35.18557235598564, 79.41572338342667, 76.18313044309616, 72.660301476717, 57.82808996737003, 41.342207193374634, 26.288714557886124, 25.239273570477962, 34.12608660757542, 43.33854027092457, 29.866610169410706, 51.61614149808884, 32.79101304709911, 7.8462170250713825, 0.32084448204841465, 0.054444688285002485, 0.12164652405772358, 0.9605552663560957, 3.2766988361254334, 8.104574661701918, 9.310536850243807, 10.897706933319569, 11.192888393998146, 16.882970966398716, 13.489628601819277, 15.838837344199419, 14.258514493703842, 20.635045431554317, 15.835963748395443, 13.631022814661264, 14.094197060912848, 18.031624630093575, 24.103296026587486, 27.831315882503986, 36.19643211364746, 42.53542296588421, 45.31526640057564, 54.073359444737434, 56.379185914993286, 61.26508913934231, 67.29546815156937, 63.02391596138477, 62.4360267072916, 60.956576094031334, 59.00139860808849, 61.38285622000694, 66.34248688817024, 64.77655291557312, 60.484402030706406, 65.83475813269615, 63.60055401921272, 64.20423522591591, 64.07129555940628, 64.63108912110329, 67.05602020025253, 71.89579769968987, 61.600812524557114, 57.48039722442627, 31.87860980629921, 40.24418771266937, 41.80405721068382, 48.63784611225128, 58.1483443826437, 63.583010360598564, 56.79711028933525, 58.94610397517681, 61.68613314628601, 65.14418318867683, 61.86683624982834, 62.84099757671356, 61.7780502140522, 56.33087530732155, 54.57829535007477, 57.513630241155624, 60.30991919338703, 60.46950303018093, 62.56632551550865, 61.356215849518776, 60.46409972012043, 62.360368967056274, 57.867854833602905, 59.22730788588524, 51.06365114450455, 52.214354798197746, 46.23841926455498, 44.92198750376701, 32.59885735809803, 28.406796902418137, 20.125342682003975, 15.341050755232573, 13.578738570213318, 11.768447309732437, 10.179867502301931, 7.694416120648384, 8.748888038098812, 6.706755068153143, 13.060339987277985, 11.75937719643116, 5.3373076021671295, 2.165002226829529, 0.4096571757690981, 0.25079167855437845, 0.13690230465726927, 0.14571223582606763, 4.695295952260494, 26.178995445370674, 41.85613341629505, 42.39277482032776, 46.68047234416008, 38.727590292692184, 21.691723130643368, 26.39814868569374, 34.88790772855282, 41.7591018229723, 57.661776691675186, 64.72368255257607, 50.574195608496666, 15.566711146384478, 0.26599202072247863, 0.06155616254545748, 0.013585260912805097, 0.04763559096318204, 0.01992515299207298, 0.03638682152086403, 0.030526329937856644, 0.03503947096760385, 0.0586022997595137, 0.08738828968489543, 0.029864224743505474, 0.06555932195624337, 0.06974779564188793, 0.07530686765676364, 0.08932856057072058, 0.020611439213098492, 0.034308370159124024, 0.07693774459767155, 0.08449782486422919, 0.05139014574524481, 0.056776308483676985, 0.015502371225011302, 0.07050360625726171, 0.026211800613964442, 0.07057799914036877, 0.03845699793600943, 0.0447258488566149, 0.0199786636949284, 0.029049550685158465, 0.013778518950857688, 0.13762735325144604, 0.17585417779628187, 0.18643180083017796, 0.1861231416114606, 0.1789768977323547, 0.13940018077846617, 0.15137676702579483, 0.07835213706130162, 0.23972095776116475, 0.05338230388588272, 0.09047377607203089, 0.18263724428834394, 0.12102528708055615, 0.09059049363713712, 0.09592281727236696, 0.14267300750361755, 0.15114037814782932, 0.19552820100216195, 0.21152397705009207, 0.2636093704495579, 0.1091931969858706, 0.14563978736987337, 0.1522244481020607, 0.16907302604522556, 0.2766313013853505, 0.17573568649822846, 0.16047276643803343, 2.4958654353395104, 45.306526869535446, 89.08741280436516, 84.63108032941818, 83.59645664691925, 64.83177155256271, 45.85012570023537, 28.389093652367592, 22.79693942517042, 37.05177381634712, 56.89185820519924, 40.4392122477293, 57.86362186074257, 36.15912191569805, 10.143452156335115, 0.6056455231737345, 0.30163339572027326, 0.18005535705015063, 0.8243098366074264, 2.486979612149298, 15.420283153653145, 17.759918309748173, 14.021993335336447, 23.319472186267376, 16.589752100408077, 13.976764362305403, 19.16335590183735, 30.760025829076767, 32.331606298685074, 40.85693143308163, 43.01688753068447, 29.41172707825899, 28.975407890975475, 35.649630054831505, 34.494587033987045, 45.23849532008171, 48.85077528655529, 51.58056400716305, 57.316572815179825, 56.35831743478775, 61.02466844022274, 70.05541205406189, 65.15365228056908, 64.9471865594387, 62.12105020880699, 62.35836647450924, 63.6479526758194, 67.92969971895218, 66.01374372839928, 63.30780632793903, 67.05572381615639, 66.24873831868172, 68.35366576910019, 65.34302651882172, 66.391162276268, 69.93689641356468, 71.14392444491386, 61.803463250398636, 61.22288100421429, 36.12929731607437, 43.68235722184181, 46.81317262351513, 54.70615468919277, 61.00307419896126, 66.13368809223175, 59.51505124568939, 59.32159602642059, 63.39296355843544, 67.77871862053871, 64.46358650922775, 63.921773582696915, 62.47361809015274, 56.93388395011425, 56.13220676779747, 57.13802419602871, 60.28953328728676, 60.4733332246542, 62.986195385456085, 63.15807916224003, 61.44423432648182, 65.36907032132149, 61.37400269508362, 60.662327483296394, 54.540639370679855, 55.18240973353386, 48.97182919085026, 48.760826513171196, 36.23905822634697, 33.10066983103752, 22.971158176660538, 27.793789096176624, 31.14084329456091, 14.80690486729145, 19.718019738793373, 14.304889105260372, 13.637780752032995, 10.924499295651913, 16.057619154453278, 13.491885680705309, 7.099775578826666, 1.3066142750903964, 0.21358196740038693, 0.2633769594831392, 0.23685166641371325, 0.37648923054803163, 6.403495240956545, 37.21615679562092, 57.37252861261368, 58.270416632294655, 67.43611380457878, 49.740619137883186, 26.577991135418415, 29.681599996984005, 40.13849638402462, 52.10783511400223, 68.2166375219822, 71.38865411281586, 60.67491240799427, 22.20146007835865, 1.0312139592133462, 0.1293103417265229, 0.13034284726018086, 0.12913397775264457, 0.09344278980279341, 0.14117728307610378, 0.10661956985131837, 0.12799311865819618, 0.10724419102189131, 0.1617890692432411, 0.15304774220567197, 0.14223272097297013, 0.10802498232806101, 0.1528146633063443, 0.15575157915009186, 0.16509722219780087, 0.1667892001569271, 0.17428646504413337, 0.17164556222269312, 0.15977496950654313, 0.18808112014085054, 0.09005582818645053, 0.20009413099614903, 0.07039174233796075, 0.184819485002663, 0.17172259715152904, 0.18031798826996237, 0.1038518562563695, 0.12514257396105677, 0.0985243491595611], [0.04474671804928221, 0.02670408386620693, 0.014062696573091671, 0.056577457435196266, 0.06147726482595317, 0.05923038304899819, 0.06516707464470528, 0.03992596051830333, 0.029992063391546253, 0.03646824254246894, 0.05313407033099793, 0.029564688375103287, 0.030786788520345, 0.021293283680279274, 0.0743417713965755, 0.12070790020516142, 0.07201170970802195, 0.010325052553525893, 0.07719753339188173, 0.027046432878705673, 0.07383636140730232, 0.01767835099599324, 0.07078168899170123, 0.03712973732035607, 0.04885324007773306, 0.05711894693376962, 0.22367706085788086, 6.16195360198617, 49.49562348425388, 68.26643005013466, 70.93773230910301, 54.08172659575939, 42.684713155031204, 29.26547672599554, 28.28367780894041, 30.121582187712193, 35.89285500347614, 37.90712311863899, 37.9520633071661, 30.6826638802886, 8.651285525411367, 0.7426420657429844, 0.0779155018972233, 0.06441917532356456, 0.15399783966131508, 0.5932811053935438, 3.9395252941176295, 5.459250658750534, 12.59679526090622, 7.813377762213349, 7.795962821692228, 17.16830525547266, 19.65591587126255, 13.708911035209894, 14.494540728628635, 25.505515784025192, 19.557664543390274, 36.633306071162224, 29.67694904655218, 36.32030546665192, 52.77442194521427, 58.36986109614372, 54.470400139689445, 57.34895087778568, 60.0111298263073, 60.15902929008007, 60.479899272322655, 60.65604642033577, 64.96338129043579, 62.07246221601963, 55.92859849333763, 55.25712512433529, 52.29396052658558, 52.9830801486969, 54.667533561587334, 57.04882398247719, 55.6468740105629, 55.962010100483894, 57.29560934007168, 58.21109801530838, 58.61050218343735, 63.61344672739506, 59.27202008664608, 64.94823530316353, 61.34545102715492, 60.57569593191147, 35.65601371228695, 36.60221993923187, 47.3173713684082, 46.42169862985611, 58.42074416577816, 59.35071386396885, 57.41438336670399, 64.73692864179611, 60.51281310617924, 60.60340404510498, 61.03767894208431, 62.19750590622425, 59.57438886165619, 57.74649694561958, 56.35156139731407, 60.412703678011894, 58.50817367434502, 57.373288571834564, 57.512885481119156, 58.49667549133301, 56.500824987888336, 56.16064064204693, 53.36893804371357, 60.66778399050236, 58.64254966378212, 54.70581270754337, 51.75603859126568, 46.891296431422234, 49.25769545137882, 47.15557225048542, 40.40414772927761, 48.16727176308632, 28.538269847631454, 19.686715118587017, 13.054302111268044, 7.947156708687544, 6.576297143474221, 5.921208970248699, 7.134174657985568, 9.003296736627817, 4.797403123229742, 1.5746260061860085, 1.761396077927202, 0.09181196481222287, 0.019064220869040582, 0.10709421039791778, 0.08435441224719398, 3.410007795318961, 19.3950142711401, 38.96089397370815, 51.11661270260811, 30.432804487645626, 31.082503125071526, 15.880898237228394, 24.61057260632515, 44.555329978466034, 43.2439823448658, 54.14411164820194, 59.99495029449463, 39.356733933091164, 5.655740015208721, 0.07276268152054399, 0.03467178874416277, 0.04440391632670071, 0.0369756934378529, 0.08247130157542415, 0.04224209951644298, 0.011360992375557544, 0.08448568332823925, 0.02351475617615506, 0.09548903937684372, 0.03431372104387265, 0.037068703095428646, 0.017819641070673242, 0.04978987868526019, 0.11186817922862247, 0.02028970149694942, 0.02171712421841221, 0.07840278864023276, 0.04104005405679345, 0.03989107957750093, 0.015992633052519523, 0.10152108210604638, 0.051711232226807624, 0.04685543790401425, 0.03596649505198002, 0.03870697553793434, 0.0775457861891482, 0.06013165460899472, 0.05680681446392555, 0.02356904798944015, 0.020798117184313014, 0.028773848389391787, 0.08321281100506894, 0.0409273923287401, 0.03217523735656869, 0.0512653016630793, 0.013991134055686416, 0.017455231718486175, 0.047713301246403717, 0.06142278747574892, 0.023944437416503206, 0.02224884148745332, 0.01597851369297132, 0.08817027584882453, 0.08130550631904043, 0.04045446614327375, 0.0627428047300782, 0.04754325665999204, 0.01834939535910962, 0.04540445013844874, 0.11384623285266571, 0.0957206117163878, 0.07193832614575513, 0.10144303043489344, 0.009722495433379663, 0.24704755836864933, 8.445334676653147, 59.89927902817726, 76.08693480491638, 77.9598619043827, 64.08448845148087, 50.13881877064705, 39.78674165904522, 30.527962781488895, 20.62641989439726, 24.151238054037094, 35.02207092940807, 33.38545694947243, 35.9331214427948, 10.184418708086014, 1.0087699885480106, 0.10513793880818412, 0.15639500634279102, 0.8272086654324085, 3.5674639837816358, 5.378580512478948, 9.987361282110214, 14.61272768676281, 13.315166663378477, 13.552079200744629, 13.99563129991293, 20.47344960272312, 12.7814881503582, 11.979956310242414, 11.979799568653107, 16.467307470738888, 21.092521883547306, 26.336111314594746, 34.82061713933945, 47.62998819351196, 55.15531338751316, 53.67530420422554, 57.514196410775185, 61.79918847978115, 60.24957463145256, 61.11034244298935, 62.15860739350319, 66.6794604063034, 63.48636634647846, 60.77188320457935, 56.28830999135971, 54.841765612363815, 56.44060581922531, 58.036520183086395, 58.23774218559265, 57.92272008955479, 57.49350652098656, 58.88738952577114, 61.04511134326458, 62.12245233356953, 64.88152608275414, 63.18876251578331, 66.8221427500248, 63.3891561627388, 61.45028360188007, 41.92165710031986, 43.42378489673138, 51.57358758151531, 50.334835052490234, 61.65959157049656, 60.206230357289314, 58.88227500021458, 64.54091995954514, 62.4958772957325, 61.5638443082571, 63.73667411506176, 64.9705021083355, 61.78193360567093, 59.37201552093029, 56.875465884804726, 59.62504394352436, 57.25029297173023, 57.942897006869316, 59.05664764344692, 60.00362902879715, 58.691141456365585, 58.24855260550976, 56.604164242744446, 60.59714198112488, 59.689309895038605, 55.50285413861275, 53.44568632543087, 46.38825282454491, 50.24516746401787, 43.266952112317085, 38.22451248764992, 36.18086814880371, 20.151109099388123, 12.469734828919172, 10.633576456457376, 7.5399700831621885, 8.849748875945807, 12.722450718283653, 11.871663071215153, 9.31254219263792, 8.273262809962034, 3.83046330884099, 3.6652797600254416, 0.5210771423298866, 0.031101165986910928, 0.14667103125248104, 0.13342777703655884, 4.071617368608713, 21.955594271421432, 38.63484866917133, 48.10466252267361, 32.88924917578697, 28.214365728199482, 19.63039454072714, 28.301656544208527, 49.32057447731495, 51.33364945650101, 59.63009387254715, 66.70494183897972, 45.80989345908165, 7.057164665311575, 0.11496020393678918, 0.0999908107041847, 0.07948139638756402, 0.008819618979032384, 0.0651739098248072, 0.03954708299716003, 0.0103618565844954, 0.03461435393546708, 0.024616901137051173, 0.09216780978022143, 0.028929892359883524, 0.035619040063465945, 0.018789837740769144, 0.014822661360085476, 0.05880373348190915, 0.08191437169443816, 0.05305764025251847, 0.024538090619898867, 0.09379370691021904, 0.04111001631827094, 0.00993490273685893, 0.07068853461532854, 0.03904253389919177, 0.07940594223327935, 0.03582548328267876, 0.040864443362806924, 0.027492253975651693, 0.0210666688872152, 0.013572453299275367, 0.0888050273351837, 0.10417713216156699, 0.16934267798205838, 0.2213068341370672, 0.1436378588550724, 0.11088504135841504, 0.15373961679870263, 0.14780014957068488, 0.11353738809702918, 0.11792215242167003, 0.1793015279690735, 0.13463265378959477, 0.14436777593800798, 0.1211847820377443, 0.17752268904587254, 0.2676127228187397, 0.12353245489066467, 0.11159132103784941, 0.15300910599762574, 0.16047477023676038, 0.1705097348894924, 0.2715119963977486, 0.20715796679724008, 0.19581321539590135, 0.15265625930624083, 0.20820218342123553, 0.3370073897531256, 12.456825971603394, 71.61601111292839, 86.01014032959938, 86.6140191257, 70.7255744934082, 57.5290460139513, 42.21836797893047, 39.747326374053955, 41.9537577778101, 48.4047894179821, 54.02482084929943, 51.13762177526951, 42.06603415310383, 12.176858894526958, 1.522736109327525, 0.23667947330977768, 0.17517738364404067, 0.6254170497413725, 2.9711729055270553, 10.287149995565414, 14.828489609062672, 27.14101642370224, 19.195249490439892, 18.77299714833498, 30.39269383996725, 30.14644805341959, 22.731297947466373, 25.71634367108345, 33.805003836750984, 28.862164467573166, 44.33317489922047, 35.02970851957798, 40.170692056417465, 56.0293310880661, 61.92028038203716, 54.95013199746609, 58.697889894247055, 59.575183019042015, 59.504936188459396, 60.46039491891861, 63.12151372432709, 67.93731451034546, 66.36614441871643, 61.667605340480804, 61.27978295087814, 57.094432935118675, 57.63150751590729, 58.83627466857433, 61.0625372081995, 60.63370741903782, 60.50279684364796, 60.74456267058849, 64.84722912311554, 64.71362829208374, 67.39751547574997, 65.00084728002548, 68.2541111111641, 63.660119622945786, 62.645349875092506, 45.773248225450516, 47.96400927007198, 54.69368375837803, 55.90736523270607, 63.64333592355251, 63.61432448029518, 59.63916018605232, 67.59175345301628, 63.31984028220177, 64.99861299991608, 66.75510674715042, 67.23042324185371, 63.159747272729874, 62.55766578018665, 58.857078552246094, 61.270412653684616, 58.074354752898216, 57.42950655519962, 59.16299633681774, 59.72528636455536, 59.69027504324913, 59.4762097299099, 57.571212351322174, 63.666241094470024, 61.44861549139023, 57.51010403037071, 53.614553064107895, 48.72133143246174, 52.0688796043396, 52.86939784884453, 44.74615953862667, 56.68230704963207, 38.20321083068848, 25.710866264998913, 25.063337311148643, 18.575848527252674, 20.8864114433527, 16.194210425019264, 17.617562748491764, 15.800070874392986, 15.307471957057714, 3.4025571076199412, 3.9086685748770833, 0.38065045257098973, 0.11980400144238956, 0.31851859122980386, 0.4563948162831366, 4.937689220532775, 28.045960664749146, 51.87444403767586, 64.57641005516052, 46.64002351462841, 43.04991915822029, 24.74758755415678, 35.66242776811123, 58.37152920663357, 58.48988525569439, 68.84471341967583, 76.12016022205353, 55.4842883348465, 10.293325614184141, 0.3032797761261463, 0.19639324833406135, 0.1500799084897153, 0.11040337267331779, 0.13160335540305823, 0.17803198046749458, 0.11531262018252164, 0.18739142746198922, 0.11399889262975194, 0.28832060226704925, 0.13083183352136984, 0.13099777774186805, 0.10470940047525801, 0.12253727938514203, 0.16260635195067152, 0.15757752960780635, 0.13597122102510184, 0.1237627952650655, 0.2258357754908502, 0.10311626174370758, 0.06268937751883641, 0.22521867969771847, 0.14588862948585302, 0.1735213107895106, 0.11568305577384308, 0.09795121819479391, 0.17616113007534295, 0.1829139466281049, 0.14425819041207433], [0.05058086338976864, 0.00793716271800804, 0.017339059631922282, 0.05717867868952453, 0.014750856717000715, 0.03265738472691737, 0.028452465048758313, 0.04194786393782124, 0.06185748192365281, 0.036846897419309244, 0.027034807135351002, 0.02161577282095095, 0.03210117843991611, 0.016848678133101203, 0.0034506552810853464, 0.016954731036094017, 0.011859508740599267, 0.05384469899581745, 0.027242647447565105, 0.06188934974488802, 0.07531776238465682, 0.061623241563211195, 0.11207701216335408, 0.03802296028879937, 0.07479629974113777, 0.05359872528060805, 0.042122498707612976, 17.407137639820576, 63.70099402964115, 68.19655179977417, 57.051084861159325, 45.09020447731018, 34.35770317912102, 21.002438217401505, 17.750169932842255, 40.985839515924454, 50.10896377265453, 38.409570157527924, 37.94055752456188, 12.047215551137924, 1.18897175649181, 0.10612338475766592, 0.0567535097070504, 0.07331962624448352, 0.444343228591606, 3.926192047074437, 3.7695003300905228, 7.1587849874049425, 6.985771721228957, 15.860687121748924, 10.703560151159763, 17.594974860548973, 16.02129690349102, 16.58096507191658, 13.80007954314351, 28.636695966124535, 39.44494239985943, 34.26240049302578, 48.49796801805496, 59.722512513399124, 61.28282658755779, 58.27743485569954, 61.49436503648758, 61.337881833314896, 62.75483340024948, 60.32178595662117, 60.22677205502987, 60.47967508435249, 64.23388123512268, 60.18565446138382, 55.63423588871956, 49.43577289581299, 49.701344445347786, 49.60876241326332, 50.97354657948017, 50.25087095797062, 49.433591812849045, 52.62417420744896, 54.45387862622738, 51.09408751130104, 52.4546767026186, 60.59842251241207, 57.36820824444294, 59.6743007004261, 60.480758026242256, 65.20842254161835, 42.4072140455246, 48.765705451369286, 50.00588670372963, 52.26543165743351, 58.96055459976196, 57.30700112879276, 60.49841187894344, 58.76988463103771, 60.767722427845, 57.92400822043419, 61.07705242931843, 58.39159972965717, 61.11212454736233, 55.9810508787632, 54.9817007035017, 56.60620853304863, 55.74370801448822, 55.8178686350584, 59.6626353263855, 57.916655614972115, 57.02017731964588, 53.16475600004196, 53.931938633322716, 54.0365432202816, 53.54276351630688, 55.51076911389828, 57.34159827232361, 58.884589076042175, 58.926265239715576, 60.16018062829971, 53.62987004220486, 43.52870486676693, 32.337370589375496, 31.520114243030548, 16.68985392898321, 12.218448612838984, 7.03971172682941, 5.770984031260014, 16.28483936190605, 10.989432111382484, 6.609340645372868, 7.447596564888954, 2.780437390320003, 0.43243923923000693, 0.20529269735561684, 0.025176612216455396, 0.06541812836076133, 0.3637693834025413, 7.461177036166191, 21.896879822015762, 39.729353338479996, 37.18474768102169, 32.6744619011879, 16.99987169355154, 25.04805263131857, 48.03940102458, 42.04432591795921, 45.94371847808361, 50.02290219068527, 46.882944479584694, 15.312401242554188, 0.5851519759744406, 0.031219143347698264, 0.02840876182744978, 0.011293015359115088, 0.056124498732970096, 0.048559475762885995, 0.07265364518389106, 0.04300302724004723, 0.06378109159413725, 0.07426294047036208, 0.04586130140523892, 0.04037094855448231, 0.11366877050022595, 0.048539853378315456, 0.016537551273358986, 0.02635709457535995, 0.04654952834243886, 0.025489464569545817, 0.012034005285386229, 0.032366065788664855, 0.028799697392969392, 0.022722637841070537, 0.09518230974208564, 0.07327393963350914, 0.03426843890338205, 0.05226074063102715, 0.05284367907734122, 0.006643268598054419, 0.07850352776586078, 0.051522240610211156, 0.022500292252516374, 0.0337247340939939, 0.027919122476305347, 0.04264923802111298, 0.021923600834270474, 0.026139556248381268, 0.0365349579078611, 0.02811836871842388, 0.023718911725154612, 0.018750513190752827, 0.06029633717844263, 0.032369153122999705, 0.05503064356162213, 0.02701269113458693, 0.012474148024921305, 0.013363568414206384, 0.016812420508358628, 0.03834159026155248, 0.05343796125089284, 0.03781463201448787, 0.0509765691094799, 0.047434921652893536, 0.03159102983772755, 0.03646756347734481, 0.03155128411890473, 0.3397888405015692, 26.10044416040182, 74.22506511211395, 76.47379964590073, 65.86070314049721, 53.59478272497654, 46.02846913039684, 30.419178418815136, 27.82174989581108, 35.79099386930466, 44.61525276303291, 36.834756061434746, 39.778420105576515, 15.553899183869362, 1.6089545516297221, 0.07861988910008222, 0.032811462006065995, 0.5472294765058905, 1.6847229609265924, 7.104180017486215, 12.203770950436592, 11.36592160910368, 11.868637483567, 12.742742579430342, 13.133439514786005, 17.4937691912055, 17.053796499967575, 14.095547888427973, 12.8542485460639, 16.577813141047955, 28.51627092808485, 33.86637434363365, 44.516640454530716, 55.73743835091591, 62.78241232037544, 59.32388350367546, 61.686547324061394, 61.40019468963146, 60.90247459709644, 60.90278998017311, 60.109833329916, 62.11897552013397, 66.73346310853958, 61.84260495007038, 58.88397350907326, 51.90033584833145, 51.657198294997215, 51.265226528048515, 51.955615282058716, 52.26956583559513, 50.39133042097092, 55.47448106110096, 56.69542394578457, 52.40556053817272, 55.321573466062546, 61.931257992982864, 60.764021426439285, 61.197255179286, 61.27583496272564, 61.4907818287611, 46.11596703529358, 53.32817003130913, 52.1404829621315, 54.86586391925812, 60.52889384329319, 60.16002103686333, 61.27558797597885, 60.69167710840702, 62.66708470880985, 60.32173655927181, 62.18026243150234, 61.095777824521065, 62.65113316476345, 58.16010855138302, 57.51428380608559, 57.57653966546059, 56.1224564909935, 57.15192385017872, 59.28210474550724, 57.66212247312069, 57.17100642621517, 55.732855796813965, 55.1583494246006, 56.83405190706253, 55.16048111021519, 56.53064198791981, 56.91163994371891, 58.06645877659321, 57.293694242835045, 62.3678507655859, 53.593183010816574, 47.79565930366516, 34.16350319981575, 25.378346107900143, 12.590048722922802, 8.581758756190538, 6.763629466295242, 6.050849463790655, 11.12345851957798, 12.52499146386981, 6.743765557184815, 12.421618960797787, 5.418791379779577, 0.9920854400843382, 0.6522609468083829, 0.00905759326997213, 0.10730835711001419, 0.3222009795717895, 6.883393339812756, 23.636494874954224, 45.12056104838848, 38.16218823194504, 31.59388918429613, 21.45969808101654, 32.54052668809891, 53.37202347815037, 46.974443569779396, 51.938189417123795, 57.044731602072716, 56.70813046395779, 20.624873377382755, 0.8888094162102789, 0.13303329586051404, 0.049336912561557256, 0.04930956813041121, 0.02885441037506098, 0.028148336641606875, 0.023908101866254583, 0.04885914386250079, 0.02866577313398011, 0.021715194634452928, 0.027055110440414865, 0.014930384095350746, 0.10060174667160027, 0.018252738045703154, 0.02885701531340601, 0.04553944309009239, 0.05821457212732639, 0.07650838990230113, 0.046310226534842514, 0.03742821798368823, 0.040181122021749616, 0.0360395780444378, 0.06470856096711941, 0.057141708603012376, 0.027356776772649027, 0.019305068199173547, 0.04055419223732315, 0.03433361060160678, 0.02890370011300547, 0.09843189240200445, 0.22814723895862699, 0.14761685393750668, 0.11875823372974992, 0.19621869520051405, 0.16383491805754602, 0.14533397799823433, 0.13225528760813177, 0.10337598374462686, 0.0986703073431272, 0.11311590016703121, 0.09674924323917367, 0.10638752995873801, 0.07582688311231323, 0.12485641665989533, 0.1557160896481946, 0.1343133521731943, 0.11127026795293204, 0.15590477327350527, 0.2537014614790678, 0.1676234632031992, 0.20873270026640967, 0.17783059127395973, 0.14257330738473684, 0.15172753570368513, 0.24158134387107566, 0.5461227858904749, 35.265204682946205, 84.41764578223228, 84.9026669561863, 73.60265851020813, 61.172028332948685, 49.27702121436596, 31.943989098072052, 29.491589292883873, 59.10857945680618, 69.15282368659973, 53.56579028069973, 51.01826637983322, 17.143682576715946, 2.008870504796505, 0.19073296221904457, 0.10073145924252458, 0.4822058812715113, 1.121253096498549, 10.4639146104455, 16.515200100839138, 20.554411858320236, 14.156303778290749, 26.800362803041935, 17.74069894105196, 32.15192534029484, 31.559805013239384, 28.54616392403841, 25.646966993808746, 36.246205642819405, 41.72400690615177, 42.152836695313454, 51.032143235206604, 64.80815961956978, 65.80841034650803, 60.365943387150764, 63.27042393386364, 62.58543089032173, 61.93048283457756, 61.31993539631367, 59.05172310769558, 62.68338583409786, 69.20959264039993, 64.50995922088623, 61.06281079351902, 54.280554726719856, 54.110996425151825, 53.694971948862076, 54.17410723865032, 54.951382130384445, 53.629680052399635, 57.82878912985325, 60.18494009971619, 55.223523527383804, 58.50611038506031, 65.50142481923103, 64.11323010921478, 65.01570448279381, 64.44071173667908, 64.69269141554832, 50.07473140954971, 58.585305735468864, 58.11830319464207, 57.88219906389713, 62.0593187212944, 60.66845655441284, 65.42605966329575, 62.88146160542965, 65.4448914527893, 63.21432374417782, 64.56528425216675, 65.27320146560669, 65.50406947731972, 61.2260652333498, 57.76343263685703, 58.09549681842327, 57.602298483252525, 57.33518421649933, 59.22404006123543, 57.82058537006378, 57.18957602977753, 57.048170417547226, 55.80046936869621, 59.42598782479763, 56.88227131962776, 56.30396895110607, 57.19857394695282, 60.24425111711025, 60.73304928839207, 64.63944107294083, 58.68289589881897, 50.93847066164017, 38.697818890213966, 37.93655253946781, 23.051409870386124, 22.609582878649235, 16.69062528759241, 14.838416576385498, 29.019134044647217, 23.084903173148632, 15.599111057817936, 19.042347595095634, 7.3932404816150665, 0.5872741620987654, 0.7143193949013948, 0.23196909169200808, 0.36808598146308213, 0.8377438969910145, 9.714789558202028, 30.91529879719019, 52.7238542586565, 51.8753369897604, 46.36255860328674, 25.59874188154936, 36.157495602965355, 60.361406430602074, 55.528149381279945, 58.860201984643936, 64.76173371076584, 64.85564187169075, 27.50438142567873, 1.4556526090018451, 0.3132446820382029, 0.1880161080043763, 0.29255001281853765, 0.13020820682868361, 0.1505806206841953, 0.16831018729135394, 0.11756079329643399, 0.21872551093110815, 0.23789689235854894, 0.12647560477489606, 0.10315198131138459, 0.2845140971476212, 0.19065920758293942, 0.132670919992961, 0.08160362704074942, 0.1818535808706656, 0.14850044011836872, 0.09910308333928697, 0.12688659131526947, 0.1492206795956008, 0.07683886084123515, 0.18650372978299856, 0.11358156072674319, 0.08802393916994333, 0.14569988648872823, 0.122177508455934, 0.0901632392196916, 0.16782142367446795], [0.02871058401069604, 0.06761391327017918, 0.044743571343133226, 0.013755192321696086, 0.0051689361134776846, 0.04102237238839734, 0.014712033116666134, 0.02071126364171505, 0.033024692165781744, 0.045293717994354665, 0.0836084944603499, 0.1368220488075167, 0.013546661812142702, 0.04250237070664298, 0.04849360273510683, 0.10041829518740997, 0.0350493749283487, 0.012912741531181382, 0.03508923568006139, 0.12151139380875975, 0.021254909079289064, 0.01144509904406732, 0.03247650478442665, 0.03159961648634635, 0.019326030160300434, 0.2626837638672441, 4.046647483482957, 41.645427122712135, 67.42999613285065, 64.20801222324371, 51.29214808344841, 32.51994699239731, 18.75039216130972, 21.196317113935947, 18.951355777680874, 34.71427604556084, 24.21753879636526, 32.34099179506302, 17.875521406531334, 2.7101095765829086, 0.039229024478117935, 0.11757930988096632, 0.0861844742030371, 1.1972491373308003, 3.350858981721103, 5.9500128496438265, 7.071322230622172, 8.798080198466778, 12.772988956421614, 6.065425956621766, 15.036079119890928, 7.294336538761854, 26.422127299010754, 19.780894964933395, 27.642357721924782, 30.93916341662407, 47.52678193151951, 54.59340713918209, 61.84034787118435, 61.61547213792801, 62.385109439492226, 62.31501080095768, 62.62233451008797, 58.0799176543951, 58.67865912616253, 59.378201588988304, 59.01031292974949, 58.96554373204708, 61.341860219836235, 57.44143411517143, 55.13055771589279, 48.26598286628723, 48.19431111216545, 48.01328122615814, 52.27868154644966, 52.7377463132143, 55.060371682047844, 50.274380296468735, 50.621126890182495, 49.104236885905266, 49.43035438656807, 53.3302067220211, 57.27535642683506, 58.493715450167656, 61.2483624368906, 64.23953533172607, 48.36235709488392, 38.14499035477638, 42.29240320622921, 52.73522324860096, 58.785665184259415, 58.18426385521889, 59.23655278980732, 60.6065958738327, 56.71789973974228, 55.96309684216976, 53.973356410861015, 53.41081939637661, 58.33755902945995, 58.66400711238384, 59.31683488190174, 57.14846223592758, 56.39006853103638, 55.46658128499985, 55.81861339509487, 57.71664194762707, 54.96315389871597, 58.08966413140297, 52.65120595693588, 52.64669179916382, 55.72477363049984, 52.43617169559002, 56.23785249888897, 52.79779069125652, 59.00758847594261, 63.48784826695919, 63.024748116731644, 60.55943660438061, 50.71883864700794, 43.996151983737946, 33.11070129275322, 19.594889245927334, 14.7362239100039, 13.296965640038252, 11.640143394470215, 8.939801193773746, 5.621247366070747, 2.7117057284340262, 6.615974139422178, 2.7070082304999232, 0.08058801278821193, 0.03926958284864668, 0.032785182556835935, 0.17211758298799396, 0.34039529389701784, 7.430450934916735, 24.315066263079643, 46.06182374060154, 50.16998089849949, 26.365147456526756, 24.691287875175476, 43.95674429833889, 37.29865416884422, 37.845513224601746, 54.96452942490578, 55.07827632129192, 36.32510840892792, 3.352984255179763, 0.18940454756375402, 0.025129259483946953, 0.03841463985736482, 0.0356144684337778, 0.017065229403669946, 0.057220431917812675, 0.025250125654565636, 0.040801249488140456, 0.07993381703272462, 0.05858115968294442, 0.034774939849739894, 0.07169371427153237, 0.018445683454046957, 0.007278997863977565, 0.029391860734904185, 0.08690360045875423, 0.03902954631485045, 0.02511620696168393, 0.06082505060476251, 0.03640704875579104, 0.02485274639184354, 0.026534078242548276, 0.04503155061684083, 0.02407908526947722, 0.031245723366737366, 0.02456790640280815, 0.045941431089886464, 0.040203683311119676, 0.054449404633487575, 0.041136811560136266, 0.05547451466554776, 0.04831423677387647, 0.059167374711250886, 0.09858128672931343, 0.04890560972853564, 0.018170714029110968, 0.062028977408772334, 0.05594357426161878, 0.08816199348075315, 0.0761884797248058, 0.003665341209853068, 0.02382458798820153, 0.0857803005783353, 0.008484870486427099, 0.025990805734181777, 0.019658549426821992, 0.018296051639481448, 0.1009239352424629, 0.049739160313038155, 0.007706975411565509, 0.07881925965193659, 0.05438994376163464, 0.0354781581700081, 0.31170187576208264, 6.059304960072041, 52.65904873609543, 73.81138890981674, 71.06287479400635, 56.246774420142174, 40.798163786530495, 27.81744472682476, 23.141962811350822, 16.73198226839304, 32.81713284552097, 26.77601370960474, 32.451600059866905, 23.361543528735638, 3.1072778021916747, 0.11701948562404141, 0.14531140186591074, 0.31095209880732, 2.9190323408693075, 6.517168041318655, 12.708574812859297, 9.507055655121803, 12.94813770800829, 15.213519148528576, 10.950190667062998, 4.7711085341870785, 8.216312415897846, 16.767164580523968, 13.408061228692532, 24.090160131454468, 29.314822778105736, 46.06352984905243, 55.020249634981155, 64.46180820465088, 62.90783978998661, 64.45255190134048, 63.90181705355644, 63.75288784503937, 59.65426817536354, 60.56418634951115, 59.90324981510639, 59.38480943441391, 60.581232234835625, 63.98438662290573, 59.99199025332928, 57.08970218896866, 49.82071503996849, 50.46653978526592, 49.38452884554863, 55.461048781871796, 54.57408897578716, 56.67977638542652, 52.48764753341675, 51.026990711688995, 51.91307656466961, 51.488798931241035, 55.9681049734354, 59.69980113208294, 60.15674941241741, 63.04814726114273, 64.51682925224304, 51.29142992198467, 44.81599599123001, 45.91434985399246, 56.092286109924316, 60.21526627242565, 59.527598172426224, 61.51297643780708, 61.9561542570591, 58.896311447024345, 59.04566243290901, 54.9136995524168, 54.91956263780594, 61.73769637942314, 60.25036878883839, 60.6172239035368, 56.802369207143784, 55.847944021224976, 55.901023373007774, 55.86000457406044, 57.23889358341694, 56.65614925324917, 56.96757294237614, 53.4911622852087, 55.30424639582634, 55.94325810670853, 53.180057778954506, 55.92757634818554, 53.58508564531803, 60.006155893206596, 63.135230988264084, 64.92439538240433, 60.45355148613453, 52.32912003993988, 44.290127009153366, 33.66116635501385, 19.68957256525755, 13.755364492535591, 9.922373369336128, 8.889667633920908, 9.174375906586647, 7.0868524722754955, 9.51275059953332, 6.647735685110092, 4.843881754204631, 1.46445756778121, 0.2797437796834856, 0.054278265379252844, 0.0796729966532439, 0.4340475029312074, 7.532213274389505, 24.4437862560153, 42.40064799785614, 45.2966284006834, 27.208248116075993, 28.721591010689735, 48.61478894948959, 44.183896109461784, 45.0018972158432, 61.63046233355999, 63.29427145421505, 45.78554816544056, 5.217340914532542, 0.2342973425402306, 0.11121840667328797, 0.02097174077789532, 0.022086285171099007, 0.05534411560802255, 0.025299031331087463, 0.0588749202870531, 0.014845952737232437, 0.10067708208225667, 0.04117112846870441, 0.02366783155594021, 0.0196508236695081, 0.022294270202110056, 0.06569471195689403, 0.060019927987013943, 0.08140661651850678, 0.05919912007811945, 0.06707609369186684, 0.04374062926217448, 0.017835805047070608, 0.021964441220916342, 0.07471122735296376, 0.022449225070886314, 0.029586225500679575, 0.060838609642814845, 0.031115175879676826, 0.034343533116043545, 0.016792419628473, 0.12351436133030802, 0.11615881696343422, 0.08814605214865878, 0.10291763333952986, 0.19190085033187643, 0.12586266500875354, 0.12236932394444011, 0.1351473035174422, 0.08246960205724463, 0.12107868460589088, 0.27363385597709566, 0.31659316329751164, 0.2139694575453177, 0.09367935679620132, 0.15332221810240299, 0.19529451354173943, 0.12421138642821461, 0.15136637695832178, 0.09642549615819007, 0.23168655607150868, 0.10839655340532772, 0.07585718500195071, 0.19315169571200386, 0.13678281888132915, 0.10234922985546291, 0.4996585822664201, 9.818667434155941, 66.83528244495392, 84.17073503136635, 81.65219977498055, 65.80372899770737, 46.0198587924242, 29.309890642762184, 30.41652426123619, 27.419484481215477, 52.766415774822235, 36.70578718185425, 43.51944096386433, 23.623754158616066, 4.1951007675379515, 0.1392237574327737, 0.2884386037476361, 0.3203275613486767, 3.371522272937, 9.677542056888342, 16.90339107066393, 15.995904766023159, 20.749499090015888, 22.51668356359005, 13.870551511645317, 26.596950218081474, 17.72840280085802, 34.6120311319828, 28.741766028106213, 37.86223612725735, 33.276155814528465, 52.1529994904995, 57.278757244348526, 65.56565657258034, 65.85650816559792, 66.37570470571518, 66.58722415566444, 64.7680489718914, 57.792736664414406, 57.529494389891624, 58.170516192913055, 60.10893277823925, 60.48905298113823, 67.24529564380646, 63.40714059770107, 60.2961715310812, 52.23896987736225, 52.901646718382835, 52.094737216830254, 58.951628878712654, 56.123721823096275, 59.42521646618843, 55.27778461575508, 53.12873013317585, 54.183644726872444, 53.55122186243534, 57.23626032471657, 62.10959382355213, 64.09273400902748, 65.5699123442173, 66.3399638235569, 53.826239705085754, 49.79006588459015, 53.61443527042866, 59.91716846823692, 60.610217079520226, 60.406350418925285, 63.58434408903122, 63.973002433776855, 62.491420134902, 61.91055290400982, 57.710756063461304, 57.490478083491325, 64.26244050264359, 62.60364331305027, 65.07559686899185, 58.890102580189705, 57.42712788283825, 58.193189576268196, 56.330263540148735, 58.499263152480125, 57.47658982872963, 57.90965639054775, 54.35239367187023, 56.47424541413784, 59.566565081477165, 54.065212681889534, 57.34220623970032, 55.24664148688316, 60.87668918073177, 67.11971998214722, 67.45613113045692, 65.54160386323929, 57.037295401096344, 52.21746303141117, 41.22275300323963, 29.856189228594303, 23.602917976677418, 21.51612125337124, 20.304795652627945, 18.51329628378153, 15.83611574023962, 13.668989427387714, 14.255047179758549, 7.406755406409502, 1.1938447575084865, 0.2976522484095767, 0.24167662078980356, 0.3418248484376818, 0.863264633808285, 10.39185717701912, 32.58992783725262, 61.6676889359951, 66.38885200023651, 38.40699389576912, 34.787239730358124, 56.36992581188679, 48.85251559317112, 50.752611234784126, 72.70640060305595, 71.03566065430641, 57.53275841474533, 7.983753494918346, 0.4896248644217849, 0.17785269243177027, 0.17893233918584883, 0.13697968097403646, 0.13469051162246615, 0.163833107217215, 0.09931325213983655, 0.14008565805852413, 0.17989635933190584, 0.17403082485543564, 0.10875115898670629, 0.13353690243093297, 0.11956451780861244, 0.17329652910120785, 0.06756894654245116, 0.13009229820454493, 0.07308254716917872, 0.14249578263843432, 0.15304588683648035, 0.16204889514483511, 0.1179893761582207, 0.1617508931667544, 0.10652133176336065, 0.08826486999168992, 0.18490395625121891, 0.12843435513786972, 0.10804642297443934, 0.10804485704284161], [0.04331447693402879, 0.021147505467524752, 0.06884008966153488, 0.03112890561169479, 0.016417616498074494, 0.0430897471960634, 0.07878597432863899, 0.048023511553765275, 0.06421777128707618, 0.038488850914291106, 0.09232509313733317, 0.03199041660991497, 0.010423156127217226, 0.035355017316760495, 0.021126278188603465, 0.028677957343461458, 0.08012598875211552, 0.031542541619273834, 0.006679804064333439, 0.09374654342536815, 0.0539835882227635, 0.022670442594971973, 0.043138777182321064, 0.06961728897294961, 0.09222871041856706, 0.5921115400269628, 15.731409508734941, 58.9846833050251, 64.12849768996239, 58.22291538119316, 49.685411900281906, 35.98635658621788, 26.08359206467867, 26.24736897647381, 52.41415187716484, 37.6473044604063, 38.099510595202446, 29.051185324788094, 5.208066562190652, 0.30309587193187326, 0.07831929702661, 0.09632721354137175, 0.4574078181758523, 1.762032425031066, 4.2299482226371765, 9.24148790538311, 11.321062166243792, 7.637452902272344, 12.824359349906445, 8.615952171385288, 8.878283444792032, 20.651779733598232, 30.995869673788548, 34.0960568189621, 40.82866095006466, 53.913399428129196, 65.56642413139343, 58.12343671917915, 58.50897543132305, 59.72252011299133, 58.89786556363106, 59.22625534236431, 63.78800556063652, 60.31422056257725, 60.66827416419983, 58.1594055891037, 58.006361201405525, 59.30569767951965, 60.56247264146805, 57.02768951654434, 52.06642113626003, 46.5999698638916, 45.15631712973118, 48.86555269360542, 53.74445669353008, 54.63437274098396, 55.132833793759346, 53.658611699938774, 50.218994468450546, 47.454574406147, 50.92569574713707, 56.21137551963329, 55.56295171380043, 56.7331825196743, 57.31778874993324, 61.381632685661316, 53.13442602753639, 28.396275267004967, 48.605126067996025, 54.22600105404854, 57.730944380164146, 59.775903448462486, 58.34483563899994, 57.63504512608051, 55.46834819018841, 53.649378195405006, 51.20876535773277, 50.768285393714905, 56.02825574576855, 55.865514278411865, 56.17798291146755, 56.439982652664185, 55.96976928412914, 57.875203639268875, 55.416328981518745, 54.615818336606026, 53.827406242489815, 54.80263151228428, 56.066850274801254, 47.83078841865063, 57.45085760951042, 51.72814428806305, 57.82709062099457, 56.85427442193031, 57.32114017009735, 60.52297756075859, 60.71160323917866, 60.59730917215347, 61.204432994127274, 58.485766276717186, 50.515796542167664, 36.041894406080246, 25.996196754276752, 24.57668412476778, 8.449708241969347, 12.846519760787487, 5.136131197214127, 13.906771168112755, 4.413599967956543, 3.2572431676089764, 1.6478286031633615, 0.15464162308489904, 0.12810262996936217, 0.07563738312455826, 0.17789134348277003, 0.6507607991807163, 12.094849795103073, 37.693886160850525, 44.682611748576164, 27.14722529053688, 17.33260653913021, 52.43855036795139, 57.76733882725239, 33.50557990372181, 37.50768855214119, 48.15046526491642, 52.68445797264576, 16.94872833788395, 0.6293807120528072, 0.09553045863867737, 0.04649029011488892, 0.01654422503634123, 0.03380086360266432, 0.07478824743884616, 0.07277203258126974, 0.06547977856826037, 0.04588809664710425, 0.06248286008485593, 0.04970211230101995, 0.030687930739077274, 0.01717460898362333, 0.038001211651135236, 0.02712264031288214, 0.0633046698931139, 0.042400599995744415, 0.04953368930728175, 0.10593346174573526, 0.06138985467259772, 0.052340643960633315, 0.01249170445589698, 0.02738525112363277, 0.08155471208738163, 0.01933888972416753, 0.06366711255395785, 0.02245607323857257, 0.02605982361274073, 0.0795068297884427, 0.025156813571811654, 0.019707700012077112, 0.07371536907157861, 0.06178652518428862, 0.06015043465595227, 0.07563164632301778, 0.07829876922187395, 0.08366478636162356, 0.0684153956535738, 0.0066294400676270016, 0.0672351878893096, 0.02228261662821751, 0.04307609538955148, 0.0715464424865786, 0.011614531358645763, 0.05521736791706644, 0.03821714693913236, 0.025593973805371206, 0.03443936293479055, 0.03541765829140786, 0.04718494776170701, 0.028863746592833195, 0.07462091540219262, 0.03930198501620907, 0.5865524976979941, 21.21025286614895, 69.95169281959534, 71.66088670492172, 66.88162475824356, 60.365232825279236, 39.49270963668823, 35.45017495751381, 31.515695080161095, 39.30120751261711, 45.75807183980942, 38.586674854159355, 30.913208909332752, 5.951849101111293, 0.5855096911545843, 0.023324976027652156, 0.45978515467140824, 1.7950058681890368, 4.6114059537649155, 8.798312935978174, 10.016470570117235, 12.177770845592022, 19.140361435711384, 15.51275024190545, 11.225849725306034, 6.226525912061334, 11.446626428514719, 23.139924220740795, 29.84792087227106, 41.66277319192886, 49.566257894039154, 64.54842075705528, 61.375587210059166, 60.92381805181503, 60.91093294322491, 62.69469402730465, 62.37337946891785, 64.33563217520714, 60.00720463693142, 60.61809405684471, 57.547064647078514, 59.3306053429842, 61.34880244731903, 61.20176173746586, 58.076969012618065, 53.7716556340456, 48.25030870735645, 47.64387644827366, 49.74871650338173, 56.85851879417896, 57.42240093648434, 57.275918796658516, 55.40105000138283, 53.179757595062256, 48.840591832995415, 52.601626217365265, 58.232145085930824, 57.88505271077156, 58.565565794706345, 60.414033606648445, 61.80956192314625, 53.235599398612976, 33.918382152915, 53.35733346641064, 56.6217041015625, 59.82041046023369, 61.507310941815376, 60.90404391288757, 59.8004425317049, 58.02851781249046, 55.611224323511124, 52.43952311575413, 53.18004257977009, 58.86888451874256, 55.85711672902107, 58.91022250056267, 57.55732789635658, 56.604069247841835, 56.49438813328743, 55.61671122908592, 55.44772669672966, 54.924730360507965, 56.91316746175289, 54.88406494259834, 50.71306675672531, 56.93214364349842, 51.016879454255104, 57.92394742369652, 55.991363525390625, 58.264842331409454, 63.45414787530899, 63.37882071733475, 63.215376287698746, 64.24433827400208, 59.210824370384216, 55.163608342409134, 39.088529124855995, 25.95761362463236, 15.471625048667192, 9.463268704712391, 8.796679023653269, 10.038925465196371, 14.399221893399954, 8.003506734967232, 5.028882902115583, 4.246268821880221, 0.5795531545300037, 0.0812235138437245, 0.040100643527694046, 0.045777375635225326, 0.8764718344900757, 10.972186736762524, 37.10188552737236, 47.90915921330452, 32.06069603562355, 21.266736835241318, 53.202377781271935, 58.26394557952881, 38.3655609190464, 46.9797632843256, 53.93820449709892, 64.18437749147415, 23.767781630158424, 0.9636117867194116, 0.13082176999887452, 0.04839199158595875, 0.013475847936206264, 0.017218822431459557, 0.017458513866586145, 0.08067334492807277, 0.05159832930075936, 0.011113497257611016, 0.08442361009656452, 0.0044882925340061774, 0.006492900665762136, 0.04148227017140016, 0.054126318063936196, 0.06265159478061832, 0.014916448417352512, 0.01814832714444492, 0.036100400757277384, 0.025181052114930935, 0.08617429935839027, 0.025068909890251234, 0.028947121318196878, 0.006762591565347975, 0.0397064183925977, 0.06317370309261605, 0.031377439736388624, 0.035675751278176904, 0.05524376982066315, 0.19009410665603355, 0.12343912982032634, 0.1516384186106734, 0.12702394800726324, 0.163024804496672, 0.11453609622549266, 0.22351040417561308, 0.12430721253622323, 0.2003941813018173, 0.11530885749380104, 0.14457159937592223, 0.17683586105704308, 0.10021947382483631, 0.1038868262548931, 0.17121015902375802, 0.13257071521366015, 0.1408183210878633, 0.1402875519124791, 0.12291853548958898, 0.19961739017162472, 0.0817453846684657, 0.08977525183581747, 0.1696674566483125, 0.19523693772498518, 0.27503431832883507, 0.8541663188952953, 26.829845421016216, 81.86492756009102, 79.33781236410141, 73.97686243057251, 64.94001254439354, 49.088517129421234, 36.63865618407726, 39.49745178222656, 71.37766510248184, 53.278757482767105, 51.6480103880167, 38.36597889661789, 7.332398146390915, 0.9892263903748244, 0.1900631294120103, 0.38611001742538065, 1.2136614066548645, 6.314826048910618, 11.458933018147945, 18.77769749611616, 22.870674468576908, 19.978928938508034, 23.97054824978113, 19.219212904572487, 16.08625441789627, 30.918766111135483, 40.96128523349762, 36.70041806995869, 43.71524065732956, 55.45949846506119, 69.71853733062744, 63.065185546875, 64.05730471014977, 65.1167942583561, 64.56949442625046, 63.28023120760918, 66.55187085270882, 61.3582069426775, 60.11461727321148, 58.535767793655396, 59.31632570922375, 61.87958836555481, 65.18528178334236, 62.39137530326843, 55.287436097860336, 50.58417767286301, 49.2474739998579, 53.38862478733063, 58.76785174012184, 58.974963426589966, 59.857469871640205, 58.91215659677982, 55.699155405163765, 52.29564003646374, 55.191289857029915, 60.49781531095505, 62.02086478471756, 61.32786177098751, 63.668102994561195, 63.881959319114685, 56.04731172323227, 39.197047501802444, 56.00098080933094, 59.026629254221916, 60.88006719946861, 64.24008250236511, 63.20213779807091, 61.74430802464485, 60.40628582239151, 59.587281569838524, 55.56531898677349, 55.90668126940727, 60.68440429866314, 58.38194064795971, 61.57900169491768, 59.67281877994537, 58.49726065993309, 59.47464421391487, 58.14126916229725, 55.44902242720127, 56.36880487203598, 56.93413093686104, 56.61719374358654, 52.67689637839794, 59.44434463977814, 54.203472062945366, 57.908938229084015, 57.56731376051903, 59.086681231856346, 63.64688493311405, 65.7798358798027, 65.93688145279884, 67.16278687119484, 62.876081094145775, 56.618493273854256, 42.078858464956284, 31.0593718662858, 35.78951574862003, 15.990243069827557, 22.468625642359257, 16.14708535373211, 22.870123498141766, 13.625175878405571, 10.182244274765253, 5.119780674576759, 0.4114016384119168, 0.3651985520264134, 0.13799168838886544, 0.2973469882272184, 1.1742809135466814, 16.404734328389168, 46.81807056069374, 58.563791289925575, 39.493629187345505, 28.167953118681908, 62.20845311880112, 68.17459657788277, 44.449213072657585, 52.87253648042679, 62.56472960114479, 73.23157042264938, 31.55483677983284, 1.4018368092365563, 0.1958424857002683, 0.19140656513627619, 0.08100360064418055, 0.1622254669200629, 0.14352834754390642, 0.26401410810649395, 0.17282863467698917, 0.0818720247480087, 0.15252644283464178, 0.1567157477256842, 0.06456857707235031, 0.17578380735358223, 0.13076466915663332, 0.19930025562644005, 0.15912091475911438, 0.2019965523504652, 0.10402871746919118, 0.21044805587735027, 0.23455620364984497, 0.16511470719706267, 0.07688072539167479, 0.08715832780580968, 0.18384511931799352, 0.14395199512364343, 0.13427413708996028, 0.09646066653658636, 0.15624237625161186], [0.05437912324850913, 0.028318180848145857, 0.07226164278108627, 0.026928685583698098, 0.07694906234974042, 0.03203777676390018, 0.027653628421830945, 0.029367347597144544, 0.022012024019204546, 0.04762171651236713, 0.04615378551534377, 0.016500197125424165, 0.033245818776777014, 0.0528673424560111, 0.01896899404528085, 0.07277698270627297, 0.03390666046470869, 0.017930601425177883, 0.03299244955996983, 0.08730738816666417, 0.010008808585553197, 0.013844458771927748, 0.08661129817483015, 0.032132638079929166, 0.03842283687845338, 1.4239506726153195, 29.05455194413662, 67.92179614305496, 62.19385430216789, 45.631508231163025, 37.88983404636383, 31.35864570736885, 19.968870878219604, 29.637155681848526, 29.56232249736786, 28.215138986706734, 22.60938908904791, 7.155292499810457, 0.5748830270022154, 0.09107403253437951, 0.13776318111922592, 0.6641757418401539, 1.870315452106297, 3.5706087900325656, 7.720739208161831, 9.5511076413095, 6.6431645303964615, 13.467998262494802, 15.350524596869946, 14.218825623393059, 9.18247802183032, 27.69016295671463, 49.778674095869064, 48.03754672408104, 60.016343146562576, 58.488954305648804, 63.5393089056015, 59.56826739013195, 59.86659698188305, 54.09072831273079, 56.288606375455856, 62.82399728894234, 62.72555597126484, 59.53093819320202, 58.575247675180435, 57.8149426728487, 57.27947540581226, 60.17121523618698, 56.64947301149368, 57.358313575387, 49.85353007912636, 46.03595852851868, 43.68569724261761, 51.19959644973278, 57.36631214618683, 57.13836997747421, 56.14688158035278, 52.92304717004299, 49.42258380353451, 49.8283564299345, 51.71528957784176, 52.587692365050316, 55.58027498424053, 56.02504871785641, 58.04669603705406, 57.92615130543709, 52.41844564676285, 29.61295288056135, 49.23865467309952, 54.59851786494255, 60.88731341063976, 57.18524806201458, 57.56254501640797, 57.2929684817791, 56.4561165869236, 50.30896604061127, 51.00329898297787, 49.03853841125965, 55.10352976620197, 55.86598925292492, 57.63890191912651, 56.473709642887115, 57.93530881404877, 56.49840831756592, 57.96205557882786, 53.301233276724815, 57.046532705426216, 52.28416845202446, 55.174688547849655, 51.2810792773962, 50.07175236940384, 51.68810583651066, 50.54538935422897, 55.31110122799873, 56.804728880524635, 61.2329276651144, 61.49525038897991, 57.98974469304085, 59.590104818344116, 58.96097257733345, 63.877885937690735, 58.42291384935379, 48.439394161105156, 31.802750676870346, 22.349076457321644, 7.770112808793783, 4.890101049095392, 8.645991459488869, 5.527651738375425, 4.94485848583281, 2.2522605070844293, 1.7028166400268674, 0.10309814591892064, 0.024222733518399764, 0.06293138445471413, 0.0643070887599606, 1.1296337842941284, 12.960861325263977, 40.55177740752697, 45.49368962645531, 35.946777909994125, 67.34175726771355, 86.06018364429474, 37.48661108314991, 36.724520176649094, 43.29143799841404, 48.675433695316315, 37.39100061357021, 3.5997627256438136, 0.08972120864200406, 0.052139392064418644, 0.04581348111969419, 0.010089697116200114, 0.047719357171445154, 0.039362982133752666, 0.017776015774870757, 0.04883844907453749, 0.022414566774386913, 0.011101689688075567, 0.06868404569104314, 0.024723007845750544, 0.017386913314112462, 0.10198003365076147, 0.03676563595945481, 0.04342694199294783, 0.02592626857222058, 0.05131034260557499, 0.029853964551875833, 0.044401686172932386, 0.066286789951846, 0.0664531571965199, 0.02701245179196121, 0.028150342295703012, 0.04149506850808393, 0.019407935433264356, 0.04240234033204615, 0.09172893333015963, 0.030505286340485327, 0.04797214009158779, 0.046591956925112754, 0.06465180151280947, 0.04050753341289237, 0.03670571866678074, 0.08141800848534331, 0.043609465792542323, 0.00400261346840125, 0.0327133946120739, 0.011104786299256375, 0.03346326433529612, 0.023109831126930658, 0.04475646244827658, 0.05327073682565242, 0.03727462681126781, 0.03330712017486803, 0.08492236302117817, 0.005456623166537611, 0.011551767001947155, 0.0767117680516094, 0.08170052184141241, 0.0652308993448969, 0.06483692282927223, 2.264186404645443, 36.70302473008633, 77.26691588759422, 68.10153409838676, 53.75718601047993, 44.13769818842411, 40.02555884420872, 20.876315385103226, 30.992400459945202, 37.848283275961876, 35.757882446050644, 26.423687115311623, 8.842779099941254, 0.7806740468367934, 0.10472934940480627, 0.18011171574471518, 0.9880564687773585, 4.151393137872219, 7.837228132411838, 12.32536917552352, 12.204434014856815, 13.691706508398056, 14.486330319195986, 11.103028915822506, 10.601451080292463, 12.30559028685093, 26.53582289814949, 42.29706935584545, 47.6566893607378, 53.3573904633522, 61.345040649175644, 65.66515803337097, 62.335012927651405, 61.796258836984634, 56.85987912118435, 58.642272278666496, 64.75727275013924, 63.72351162135601, 60.87134666740894, 58.54313559830189, 58.10199446976185, 57.468207478523254, 61.863583624362946, 59.68722380697727, 57.74830184876919, 51.039526239037514, 47.02379912137985, 45.84600292146206, 54.24421727657318, 59.309455677866936, 61.22489109635353, 59.59547773003578, 54.44618783891201, 52.32847787439823, 52.302498668432236, 51.88643619418144, 55.44410929083824, 57.50704899430275, 59.77959305047989, 59.960543140769005, 60.10357886552811, 52.30300784111023, 33.31214368343353, 52.78648629784584, 56.3979759067297, 62.22976237535477, 59.42603722214699, 60.223929807543755, 59.6209629625082, 57.33402907848358, 52.743810787796974, 52.139544412493706, 51.20482496917248, 57.49637916684151, 57.85892151296139, 59.03706729412079, 58.158330246806145, 58.681820556521416, 58.036915361881256, 59.386143162846565, 55.88957838714123, 56.58266119658947, 52.96559348702431, 55.48262022435665, 52.482928186655045, 51.291046142578125, 53.16938795149326, 51.11657090485096, 55.86733058094978, 59.01459529995918, 62.95145004987717, 62.22467444837093, 60.382810682058334, 61.558083817362785, 61.79961785674095, 63.19440521299839, 58.52677367627621, 48.727509900927544, 33.36503304541111, 19.654994420707226, 13.641383908689022, 9.108026716858149, 12.047640178352594, 8.617990761995316, 8.77278970554471, 5.877811498939991, 2.586352117359638, 0.4712160397320986, 0.07572653732495382, 0.07110507984180003, 0.04448608691745903, 1.4250903739593923, 14.480891861021519, 39.098135009408, 34.70835216343403, 20.818269699811935, 63.695594519376755, 88.34429427981377, 41.981196105480194, 39.1350994259119, 49.25040744245052, 55.26190146803856, 45.054311603307724, 5.573323387652636, 0.031861854367889464, 0.05322415221598931, 0.04060685132571962, 0.003906586516677635, 0.0531500339275226, 0.015268489878508262, 0.010716748820414068, 0.1594900293275714, 0.014943258502171375, 0.02537918699090369, 0.10909129268839024, 0.04843457601964474, 0.04109372246603016, 0.09670364568592049, 0.11677142276312225, 0.02144019366824068, 0.0352636997558875, 0.0023396694859911804, 0.026543969215708785, 0.03982234928116668, 0.03160831816785503, 0.02922321880760137, 0.014387617175088963, 0.05725666727812495, 0.06421371916076168, 0.04517308188951574, 0.05654233158566058, 0.2065060642780736, 0.13496841624146327, 0.1795475053950213, 0.13519350963179022, 0.179510872985702, 0.15884263906627893, 0.16212569258641452, 0.08879063709173352, 0.13965445541543886, 0.18077978224027902, 0.11174171726452187, 0.13050751498667523, 0.09929867635946721, 0.08855024803779088, 0.10795601454447024, 0.13600697770016268, 0.11223811015952379, 0.18627085868502036, 0.21399957389803603, 0.13872901210561395, 0.1292899326654151, 0.17868461029138416, 0.25576665066182613, 0.13365236576646566, 0.16119192237965763, 4.335006885230541, 48.00380453467369, 86.32048487663269, 76.3272263109684, 62.194629460573196, 52.19800807535648, 45.153664872050285, 28.03217500448227, 44.35676783323288, 42.54720613360405, 40.79714924097061, 31.778321787714958, 9.436239805072546, 1.1433638725429773, 0.31029817764647305, 0.31091448676306754, 1.3431163039058447, 4.871267834678292, 11.213816720992327, 17.862566001713276, 21.107683070003986, 16.354436427354813, 26.422087401151657, 22.01978612691164, 27.54351742565632, 14.074869398027658, 38.023738861083984, 60.38633309304714, 51.24750807881355, 61.573020815849304, 60.671177208423615, 68.15182819962502, 63.69722083210945, 64.57197949290276, 58.136147037148476, 61.490854024887085, 67.66144171357155, 66.15474656224251, 60.265674367547035, 58.827785924077034, 58.30473259091377, 58.72045308351517, 63.197239860892296, 61.53175123035908, 61.03558525443077, 53.88897053897381, 51.15968719124794, 48.47932621836662, 55.632381588220596, 62.13283337652683, 61.76600106060505, 60.34001737833023, 56.713092997670174, 54.05483923852444, 54.856926798820496, 56.721840128302574, 56.95710450410843, 60.46411111950874, 61.58783242106438, 63.95665571093559, 61.11777104437351, 54.83337566256523, 38.056641295552254, 53.81636023521423, 58.64966668188572, 65.76090529561043, 61.84767007827759, 61.99478678405285, 62.10537984967232, 61.01591370999813, 55.846108719706535, 55.642242059111595, 54.81254518032074, 59.14561226963997, 59.85468842089176, 61.66544705629349, 61.807270646095276, 61.18519842624664, 60.7654919475317, 60.925645753741264, 55.922826603055, 59.03868980705738, 54.82338219881058, 55.909325927495956, 53.13319869339466, 53.303771540522575, 55.263432785868645, 52.22252435982227, 56.19404084980488, 59.50910836458206, 65.25059267878532, 66.23111486434937, 62.83356137573719, 65.32010614871979, 65.78645512461662, 68.40535059571266, 63.65048713982105, 54.758937656879425, 37.97361955046654, 26.673261523246765, 15.758662596344948, 12.74538153782487, 22.7482982352376, 17.06323329359293, 12.84980183467269, 8.523660823702812, 3.4921430004760623, 0.42253245832398534, 0.19020122825168073, 0.13995401590364054, 0.2748169284313917, 1.8074710993096232, 18.15091732889414, 53.6943943798542, 56.14839389920235, 46.86478905379772, 73.74800831079483, 89.79173541069031, 46.901715472340584, 51.055614575743675, 59.99038673937321, 64.17512118816376, 58.564159870147705, 9.062199275940657, 0.16255037917289883, 0.1539452956058085, 0.12496485927840695, 0.12727908353554085, 0.18564879050245509, 0.1511549687711522, 0.06916745100170374, 0.191423827491235, 0.12294385756831616, 0.1549664165941067, 0.2529086993308738, 0.08781522497883998, 0.13746470416663215, 0.17954625858692452, 0.20831208064919338, 0.1042718747339677, 0.17946799169294536, 0.12768132757628337, 0.17892242409288883, 0.1208277051046025, 0.2013596857432276, 0.18285861209733412, 0.09542119223624468, 0.1398627762682736, 0.15727246238384396, 0.16444494860479608, 0.11106581368949264], [0.056529533248976804, 0.06705690917442553, 0.03847636056889314, 0.06164329810417257, 0.05595661008555908, 0.04504629338043742, 0.0129566915165924, 0.04054902688949369, 0.03740827647561673, 0.015464953994523967, 0.06861202768050134, 0.03583673053071834, 0.06669741283985786, 0.05887970342882909, 0.04249670440913178, 0.031555944806314074, 0.024163649286492728, 0.07559482095530257, 0.08827029509120621, 0.05709333541744854, 0.02291876149683958, 0.004475383339013206, 0.03423807393119205, 0.07628764549735934, 0.07426673284498975, 5.394668374210596, 45.14240987598896, 60.172685757279396, 54.50476549565792, 43.87797072529793, 41.63492448627949, 25.864032246172428, 41.5597303211689, 47.80976414680481, 36.58687636256218, 37.554049864411354, 14.371273443102837, 1.871021264232695, 0.09591083158738911, 0.18430367752444, 0.04632287273125257, 0.5688650999218225, 4.743475941941142, 4.211104558780789, 8.59916752204299, 7.448704680427909, 13.139260802417994, 25.286723524332047, 19.746140129864216, 14.576779715716839, 32.39099711179733, 45.013391599059105, 55.02960093319416, 65.4132467508316, 62.64275461435318, 58.909679129719734, 61.39842018485069, 54.70327824354172, 55.305048152804375, 51.43858842551708, 56.30002096295357, 55.18752805888653, 62.636849731206894, 58.81327450275421, 58.56255255639553, 57.00430177152157, 57.015248984098434, 57.66377538442612, 57.33191259205341, 52.60939680039883, 45.32990701496601, 43.82920414209366, 47.48534515500069, 54.42041762173176, 59.290262907743454, 57.9391960054636, 56.37323543429375, 53.44128616154194, 48.30055721104145, 48.03337074816227, 50.145050436258316, 50.50000078976154, 53.034236803650856, 53.39348092675209, 58.304690793156624, 57.306412160396576, 57.08930321037769, 27.87046518176794, 47.267464846372604, 57.97961063683033, 55.15715628862381, 58.34132842719555, 57.46291056275368, 55.118649154901505, 57.14622415602207, 51.65210656821728, 48.49263310432434, 47.82577648758888, 51.959730461239815, 54.786489978432655, 56.538879945874214, 55.75174458324909, 55.95330476760864, 55.95091089606285, 58.61093915998936, 56.3017650693655, 55.590283647179604, 56.21489033102989, 54.600254371762276, 54.07597370445728, 47.85236366093159, 51.951405107975006, 51.46720089018345, 54.2250245064497, 55.118246376514435, 58.12584958970547, 59.32894863188267, 56.04422628879547, 54.13211949169636, 54.4792802631855, 58.41312177479267, 58.72426427900791, 61.29795737564564, 43.25055219233036, 35.38469687104225, 25.092485547065735, 13.141147401183844, 14.805945418775082, 5.75959556736052, 4.347106385976076, 6.283346163108945, 0.9079809312243015, 0.14713807962834835, 0.38668761611916125, 0.05544917032239027, 0.033669124968582764, 0.13483341957908124, 2.933218404650688, 23.030790276825428, 69.97208252549171, 52.40638129413128, 36.85991071164608, 25.59606682509184, 30.132001228630543, 40.11233098804951, 41.8040382117033, 47.77910739183426, 50.60743622481823, 11.219879295676947, 0.21732533059548587, 0.033993784891208634, 0.037315051595214754, 0.004885877278866246, 0.04825982250622474, 0.015574243589071557, 0.032898619829211384, 0.047036046962602995, 0.008564626314182533, 0.029811999811499845, 0.011022006219718605, 0.0519754701963393, 0.025628010553191416, 0.059700192214222625, 0.0381264416500926, 0.031361947403638624, 0.050533833491499536, 0.0529815218760632, 0.03627492791565601, 0.030077527262619697, 0.026225474684906658, 0.04439802738488652, 0.013253776942292461, 0.06904142690473236, 0.01770380109519465, 0.05287797001074068, 0.07655586508917622, 0.015705844925832935, 0.07262460494530387, 0.07210445590317249, 0.06987938584643416, 0.021363657833717298, 0.1483609460410662, 0.020870751177426428, 0.04983994396752678, 0.03444608679274097, 0.09209507930791005, 0.0567212188616395, 0.06587054158444516, 0.01597419810423162, 0.08591989113483578, 0.018325793207623065, 0.04035354148072656, 0.09972509957151487, 0.056678018445381895, 0.05609831205219962, 0.03273335096309893, 0.05533426359761506, 0.02160952950362116, 0.05864697333890945, 0.06225027100299485, 0.10191667650360614, 7.12231881916523, 58.35788793861866, 68.56698632240295, 62.592654302716255, 49.27195608615875, 47.732514292001724, 29.459338523447514, 34.24903281033039, 36.139100790023804, 36.8687604367733, 35.83728298544884, 16.375388503074646, 2.355613773688674, 0.12616691587027162, 0.03257527721871156, 0.44792186468839645, 2.7373168291524053, 6.721402332186699, 8.80390053614974, 12.180340457707644, 12.206555251032114, 8.977082893252373, 10.127479713410139, 13.882110491394997, 17.041800543665886, 31.87925197184086, 44.074442982673645, 53.54061663150787, 60.07845841348171, 61.62761628627777, 60.68280078470707, 62.578830644488335, 57.18482628464699, 56.7667993158102, 53.608131408691406, 58.71521316468716, 56.9388160854578, 62.86994442343712, 57.64655090868473, 58.14821898937225, 57.67864778637886, 55.167503133416176, 59.954832047224045, 58.461933955550194, 56.1154268682003, 46.83796629309654, 45.52169032394886, 49.83113408088684, 56.124329790472984, 60.409188866615295, 59.772943407297134, 57.3874694108963, 56.06185354292393, 49.80176165699959, 49.403098449110985, 52.80755236744881, 51.456572860479355, 55.086757466197014, 56.04945860803127, 59.903371408581734, 59.47911277413368, 56.61323435604572, 31.577700152993202, 47.85818114876747, 60.87872967123985, 59.266517981886864, 60.475784093141556, 57.2582383453846, 56.50695785880089, 58.6649114638567, 54.15239900350571, 50.60519814491272, 50.60609869658947, 53.3696486055851, 56.172780990600586, 58.78309652209282, 56.109153404831886, 58.34425047039986, 58.79852369427681, 60.10304309427738, 56.80349014699459, 56.803588941693306, 56.560508385300636, 55.312499552965164, 54.157361537218094, 49.04145285487175, 53.59789855778217, 52.114127576351166, 54.2655873298645, 56.187444403767586, 60.219788029789925, 61.16890870034695, 58.459452688694, 56.838824450969696, 57.57042579352856, 60.54516077041626, 62.085784301161766, 60.73027543723583, 43.10113660991192, 30.934398472309113, 17.57937479764223, 10.058087836951017, 7.843702035024762, 12.05387944355607, 12.23856758326292, 5.741670029237866, 5.464035077020526, 2.175518637523055, 0.966038015903905, 0.08958310980233364, 0.020653561659855768, 0.03214723983546719, 3.306913864798844, 23.952449820935726, 54.6712763607502, 50.397288501262665, 51.92870132625103, 42.700045332312584, 36.05443753302097, 42.46281646192074, 48.39776739478111, 54.41156409680843, 59.16154481470585, 17.268954254686832, 0.3211869386723265, 0.0037481217532331357, 0.0651687518984545, 0.056673532162676565, 0.07463756919605657, 0.04591892175085377, 0.027133915391459595, 0.041793612253968604, 0.028986143443034962, 0.02212391762441257, 0.006587899279111298, 0.016391487333748955, 0.029893795617681462, 0.046084168352535926, 0.040073191485134885, 0.0214144058918464, 0.07541066443081945, 0.059749975480372086, 0.02114169445121661, 0.02493387055437779, 0.05061044910689816, 0.07045507722068578, 0.03421737172175199, 0.009198690386256203, 0.022629019622399937, 0.06952125506359152, 0.018354067178734113, 0.09043603044119664, 0.1792731779278256, 0.20152367069385946, 0.11568332294700667, 0.2125259060994722, 0.20022326469188556, 0.11889274799614213, 0.10403761581983417, 0.13878160068998113, 0.19869114534230903, 0.22040844953153282, 0.13776546693407, 0.14640801411587745, 0.26633893023245037, 0.10422238090541214, 0.15807392250280827, 0.17622829444007948, 0.17141163727501407, 0.14304571406682953, 0.1800836477195844, 0.15207380696665496, 0.1299238603678532, 0.153239750652574, 0.11029095214325935, 0.26084448443725705, 11.795787792652845, 70.99510923027992, 78.47876206040382, 72.18368545174599, 58.09271916747093, 56.10707111656666, 37.21955381333828, 55.575954616069794, 63.108408227562904, 50.60104116797447, 48.26354719698429, 19.42917063832283, 2.6742138527333736, 0.25001649046316743, 0.33675069571472704, 0.5049317493103445, 2.43678311817348, 10.658002495765686, 15.492703467607498, 20.47294232994318, 17.521587498486042, 24.002392441034317, 38.37496921420097, 31.461329497396946, 23.03615938872099, 35.49384981393814, 48.85862946510315, 54.25296060740948, 65.42555049061775, 62.65895314514637, 60.52997678518295, 67.25705221295357, 58.560318276286125, 59.371890127658844, 56.33990362286568, 62.37697787582874, 57.60307364165783, 65.06137043237686, 59.51996438205242, 58.09174261987209, 57.26364925503731, 55.92020094394684, 60.792542695999146, 61.79583705961704, 59.04248960316181, 49.13257576525211, 48.605399653315544, 52.39804074168205, 59.905259907245636, 61.9321471452713, 61.72318495810032, 60.899981930851936, 58.143803626298904, 53.14587481319904, 52.4882896989584, 55.0003083050251, 54.66453552246094, 58.28900903463364, 58.42430077493191, 61.77280269563198, 61.94877505302429, 59.4353923201561, 35.419643595814705, 52.752284333109856, 62.676682993769646, 61.366676688194275, 63.42913381755352, 61.77937634289265, 58.566105365753174, 62.44707651436329, 57.29616791009903, 52.64269441366196, 53.77085007727146, 56.19024485349655, 60.18758475780487, 61.39461278915405, 59.13814187049866, 60.83703450858593, 60.834458246827126, 62.243035063147545, 59.083250015974045, 58.95375296473503, 60.24924784898758, 57.0863925665617, 54.65728551149368, 50.541076585650444, 54.14449542760849, 54.18211720883846, 56.017817705869675, 58.24544817209244, 62.03393988311291, 63.74434970319271, 62.00804807245731, 59.69306409358978, 59.03532698750496, 64.29464757442474, 64.24465745687485, 62.917457073926926, 46.52625381946564, 36.90508268773556, 30.812176130712032, 18.342278860509396, 25.60089446604252, 17.20336977392435, 11.724484618753195, 14.239486064761877, 6.120352009311318, 2.016218123026192, 0.9747284464538097, 0.12145912434789352, 0.1436851336620748, 0.2348328911466524, 4.191266298294067, 29.510225392878056, 84.09074932336807, 65.05105778574944, 46.577273681759834, 34.72843788564205, 42.434979155659676, 53.18448454141617, 57.02736273407936, 63.50648246705532, 65.69817826151848, 23.62260092049837, 0.48689465154893696, 0.10959843188175, 0.1401337789138779, 0.11644205020274967, 0.15774334024172276, 0.12498940952355042, 0.10203592479228973, 0.17362988699460402, 0.12059238491929136, 0.06299279717495665, 0.1261590194189921, 0.14067839656490833, 0.13249688636278734, 0.16776917647803202, 0.31085829134099185, 0.13883956242352724, 0.13146582059562206, 0.22322685923427343, 0.14431066025281325, 0.12450010413886048, 0.13945661368779838, 0.18980701424879953, 0.1339010297670029, 0.14555685978848487, 0.13928014581324533, 0.16341426875442266, 0.16308392398059368], [0.02427331459330162, 0.07736923667835072, 0.01750437859300291, 0.03333008964546025, 0.02990921744640218, 0.06534904925501905, 0.014931872101442423, 0.039469072144129314, 0.023234704895003233, 0.05975491818389855, 0.0302175334218191, 0.019561155531846453, 0.03373630788701121, 0.06555152198416181, 0.03531376503815409, 0.05294239585055038, 0.03075363678362919, 0.042602642279234715, 0.047113163527683355, 0.03374987805727869, 0.010072424556710757, 0.017764963340596296, 0.005124638246343238, 0.021151514920347836, 0.4621361300814897, 19.762929528951645, 59.430323392152786, 60.85985228419304, 47.98360101878643, 37.0981465280056, 24.991452768445015, 24.21780478209257, 52.34947554767132, 46.629376485943794, 42.376606687903404, 30.233412086963654, 5.0758574064821005, 0.1456495391903445, 0.09147453252808191, 0.026664384531613905, 0.2858812519116327, 1.6337951249442995, 7.782805552706122, 9.461991973221302, 9.738250449299812, 11.707860510796309, 8.699922915548086, 11.997439172118902, 25.51617991179228, 43.258109986782074, 62.43105657398701, 64.04119357466698, 65.78678950667381, 62.56221413612366, 58.01703482866287, 61.26371741294861, 59.7382702678442, 57.15126648545265, 53.05404894053936, 48.957883939146996, 53.50098475813866, 59.74137470126152, 60.059345439076424, 58.030413910746574, 56.11577644944191, 57.008964121341705, 56.78610987961292, 56.14848129451275, 58.36213231086731, 52.737921103835106, 43.976719826459885, 42.66391687095165, 48.329690247774124, 53.830571472644806, 58.34591098129749, 58.39080177247524, 58.05945195257664, 53.49540665745735, 47.96182058751583, 46.2076523154974, 47.208435013890266, 49.079933390021324, 51.76659822463989, 54.26049180328846, 56.10794506967068, 55.38110867142677, 59.455155059695244, 28.239809162914753, 47.971137687563896, 57.75318078696728, 54.83617231249809, 54.07074898481369, 53.72428357601166, 53.562879636883736, 53.711402267217636, 50.256141275167465, 46.951941177248955, 44.96218554675579, 48.860658556222916, 52.30156011879444, 54.09912586212158, 51.288542076945305, 52.47849002480507, 53.10811623930931, 54.841226041316986, 54.23888996243477, 55.28833284974098, 56.66994631290436, 55.45502610504627, 54.43836025893688, 50.43377794325352, 51.893864795565605, 52.15135037899017, 52.1759844571352, 55.264367535710335, 56.91829338669777, 62.51489147543907, 59.05751399695873, 55.58966048061848, 52.11871773004532, 55.60129925608635, 60.69542370736599, 62.06392027437687, 56.14694997668266, 42.21258848905563, 38.0926975607872, 23.23303822427988, 5.824597254395485, 5.247729308903217, 15.324615687131882, 3.7032950576394796, 5.044646356254816, 3.375141341239214, 0.33149661670904607, 0.1623221390764229, 0.07840233593015, 0.04061441381054465, 0.23414524679537863, 3.9233474247157574, 25.132109820842743, 36.11138127744198, 26.05881929397583, 16.252489797770977, 21.318902336061, 31.150213591754436, 49.40541252493858, 51.468553617596626, 53.986089527606964, 32.32059068977833, 2.2374272905290127, 0.09563582876580767, 0.03505363856675103, 0.05102651193737984, 0.026960742652590852, 0.06560739828273654, 0.05163354420801625, 0.0586090941214934, 0.03853143905871548, 0.02685953597392654, 0.05958607216598466, 0.019329486713104416, 0.029371974887908436, 0.04275609244359657, 0.027598490560194477, 0.06612619661609642, 0.044185079241287895, 0.02515023443265818, 0.006039710506229312, 0.024348946863028686, 0.03156203412800096, 0.056092675440595485, 0.06252568942727521, 0.029693784963455983, 0.0731579790590331, 0.04095112621143926, 0.03154728023218922, 0.09462514237384312, 0.08002516799024306, 0.016717091639293358, 0.010869018969970057, 0.017543183639645576, 0.11677266957121901, 0.04145874409005046, 0.011160918638779549, 0.06846419186331332, 0.016713208351575304, 0.01940923604706768, 0.07512830692576244, 0.029126140325388405, 0.017289062998315785, 0.06398216166417114, 0.1464165042852983, 0.03891142980137374, 0.10172900962061249, 0.024879910852178, 0.03318169721751474, 0.045989147474756464, 0.05511035393283237, 0.0551680002536159, 0.016816253701108508, 0.5635994137264788, 27.427714839577675, 70.24485468864441, 67.95396521687508, 56.48586519062519, 45.6962301582098, 35.093666687607765, 31.749067157506943, 54.99775104224682, 47.31780834496021, 36.10998295247555, 26.331207677721977, 5.034660967066884, 0.2746302931336686, 0.062360843585338444, 0.446894554188475, 1.1011668993160129, 4.107282729819417, 9.27467817440629, 11.676972918212414, 11.885754615068436, 12.755754981189966, 7.519322941079736, 15.864718705415726, 30.476903021335602, 42.96590946614742, 59.85023505985737, 62.849702909588814, 66.50285348296165, 62.772426456213, 58.922602236270905, 63.168513402342796, 63.71925204992294, 59.27853673696518, 56.418536603450775, 50.87582342326641, 58.083907440304756, 61.54858812689781, 61.884756088256836, 58.12546581029892, 57.38024219870567, 56.47369064390659, 55.96470035612583, 56.30086071789265, 60.11362552642822, 55.480366945266724, 46.33467189967632, 45.695599392056465, 50.941692888736725, 56.06333166360855, 59.49331261217594, 59.16514702141285, 59.56694886088371, 54.51706163585186, 51.16941086947918, 48.34626875817776, 50.10536916553974, 50.79282067716122, 53.59569847583771, 55.58739200234413, 58.6288134008646, 58.48641984164715, 60.06029158830643, 29.9397524446249, 48.97415466606617, 60.34261643886566, 58.15841004252434, 56.734900027513504, 55.81866279244423, 56.02733999490738, 55.42675942182541, 52.68614888191223, 50.029266849160194, 47.70319506525993, 51.1517608165741, 54.096640795469284, 55.34023426473141, 53.93774852156639, 54.212287589907646, 56.214077174663544, 55.65337546169758, 56.49965085089207, 56.696347296237946, 58.96073319017887, 57.91577786207199, 56.16480141878128, 51.9194146245718, 53.047140911221504, 53.490349128842354, 51.23221009969711, 55.983475148677826, 58.796456605196, 64.0185771882534, 62.258059456944466, 58.00731495022774, 54.70261707901955, 58.37730869650841, 62.0507425814867, 64.81254458427429, 57.95895494520664, 42.625356540083885, 31.7417848482728, 13.636685460805893, 7.951252413913608, 9.056424535810947, 11.097216177731752, 13.513932097703218, 10.58269813656807, 5.811141226440668, 2.081491257995367, 0.1859580137534067, 0.1270638607093133, 0.08000913017895073, 0.25463962520007044, 4.687295481562614, 31.234641261398792, 45.237693563103676, 32.98458606004715, 22.11812674999237, 28.77543982118368, 40.21945483982563, 54.68604616820812, 58.79583343863487, 59.564600586891174, 39.83988180756569, 3.6614011181518435, 0.13500933826435357, 0.033574360131751746, 0.012504093683674, 0.03629702165198978, 0.029190172826929484, 0.08646867965580896, 0.0051623087347252294, 0.022878204981680028, 0.05867680025403388, 0.0351000116643263, 0.033495577445137314, 0.10188799249590375, 0.09832101553911343, 0.024106418568408117, 0.04417537937115412, 0.03593406319851056, 0.029360382541199215, 0.05354939101380296, 0.02756225334451301, 0.02550076191255357, 0.06302902140305378, 0.11520652275066823, 0.04328321396315005, 0.06508220263640396, 0.09869749963399954, 0.06468513136496767, 0.17602473817532882, 0.24113053368637338, 0.08134884032187983, 0.12813979672500864, 0.19563288835342973, 0.1418705825926736, 0.11086233906098641, 0.09221452797646634, 0.24711346108233556, 0.15127644350286573, 0.08935408302932046, 0.1362823144881986, 0.12917724496219307, 0.12353712299955077, 0.1294105761917308, 0.2040793898049742, 0.20338419039035216, 0.1483829878270626, 0.1920035041985102, 0.19609181763371453, 0.1320652532740496, 0.16741144645493478, 0.1387733331648633, 0.08159733362845145, 1.2862939154729247, 35.4584851115942, 82.6665173470974, 75.49038201570511, 66.73325791954994, 53.135569766163826, 38.12979876995087, 36.401176527142525, 64.82908889651299, 61.552372723817825, 57.71827585995197, 38.52880395948887, 6.9040680304169655, 0.4509502131259069, 0.23371849703835323, 0.362894925638102, 1.4236297085881233, 5.25050600990653, 15.95291767269373, 16.68574444949627, 21.853919327259064, 26.11450530588627, 20.32436840236187, 20.29457800090313, 32.23126508295536, 47.170144468545914, 69.36163768172264, 66.24327421188354, 68.93679767847061, 63.573545068502426, 58.91518883407116, 64.05022948980331, 64.29697304964066, 60.57216592133045, 59.621848315000534, 52.08735801279545, 59.48201201856136, 63.7151824682951, 63.46373476088047, 58.893567994236946, 57.596963569521904, 56.06292128562927, 56.76616474986076, 59.121084585785866, 64.04613330960274, 56.66521556675434, 49.09480199217796, 47.54403680562973, 53.07356469333172, 58.5333701223135, 63.238452449440956, 60.503344014286995, 62.51184403896332, 57.700363621115685, 55.22991098463535, 51.98436453938484, 52.4172069132328, 54.58007365465164, 57.674080431461334, 59.65399459004402, 60.972664430737495, 60.32658509910107, 61.01580731570721, 34.412120059132576, 51.718895584344864, 61.59420847892761, 60.57964771986008, 58.332733288407326, 58.282636776566505, 57.66404137015343, 59.76886622607708, 54.84973378479481, 52.40582652390003, 49.58651460707188, 54.192023277282715, 56.51364549994469, 57.29369044303894, 56.22926875948906, 57.57532373070717, 59.26687516272068, 58.45218367874622, 58.69096286594868, 60.31454734504223, 60.97597025334835, 60.577063858509064, 57.350265607237816, 55.22749051451683, 54.300602450966835, 54.39056262373924, 52.528335750103, 56.783324629068375, 58.60429711639881, 66.59562930464745, 65.82408830523491, 61.91352814435959, 57.773141115903854, 61.21604137122631, 65.2774952352047, 68.58947351574898, 61.382567435503006, 48.45319502055645, 44.831423163414, 28.11134945601225, 12.028356213122606, 14.420996624976397, 27.008464336395264, 14.63483490049839, 13.587373606860638, 8.261098712682724, 1.4912271313369274, 0.29840757662896067, 0.18612164247315377, 0.11335495335515589, 0.6895815348252654, 6.197405224665999, 35.23242384195328, 49.724572598934174, 36.17316596210003, 27.4502020329237, 31.538516655564308, 45.51132068037987, 62.044811099767685, 66.87435954809189, 67.60764420032501, 49.860738292336464, 5.8234297670423985, 0.29664966627024114, 0.20677706692367792, 0.0794411422975827, 0.1184602094872389, 0.20807717606658116, 0.24462054250761867, 0.1332424330757931, 0.09816313104238361, 0.1526994671439752, 0.21449951425893232, 0.06375969547661953, 0.20003599114716053, 0.16694804944563657, 0.0822994795453269, 0.09475435770582408, 0.24755232268944383, 0.10114316566614434, 0.1068542740540579, 0.09080226547666825, 0.1366797197260894, 0.151333351386711, 0.17056223441613838, 0.23188073158962652, 0.19806367432465777, 0.21606454043649137, 0.19467691308818758], [0.020496170691330917, 0.014315790267573902, 0.03502563733491115, 0.019473001375445165, 0.05359733375371434, 0.0044439153498387896, 0.03899359668139368, 0.01177005304271006, 0.039410238387063146, 0.026034432885353453, 0.04892342127277516, 0.03975816463935189, 0.01110612216507434, 0.03755643883778248, 0.04924828157527372, 0.03473463380942121, 0.052123350542387925, 0.05793382508272771, 0.09478094143560156, 0.03808710411249194, 0.09079710755031556, 0.04261929607309867, 0.043763231369666755, 0.07846240536309779, 2.227571331895888, 44.47285160422325, 64.08516481518745, 57.16084577143192, 49.7074431180954, 34.68918599188328, 26.385795548558235, 23.739824630320072, 34.87260214984417, 43.00111077725887, 30.927834324538708, 12.64491492882371, 0.9372518886812031, 0.2032530528958887, 0.05279712415358517, 0.07666368430363946, 1.3947957870550454, 4.690731922164559, 6.3371911738067865, 7.711979728192091, 8.108268063515425, 6.641000546514988, 2.116499016992748, 28.320796117186546, 57.32423700392246, 61.71389825642109, 61.49899318814278, 59.37643848359585, 62.1719940751791, 59.708073288202286, 59.85188417136669, 59.002557545900345, 60.848658084869385, 55.163232162594795, 48.704350143671036, 47.955277338624, 52.399602457880974, 56.28150835633278, 61.41520768404007, 57.8471839427948, 58.7764772772789, 55.38778491318226, 55.63463106751442, 56.87814474105835, 58.87136958539486, 50.73441781103611, 42.26590342819691, 41.708746924996376, 48.89411196112633, 53.66184912621975, 57.25391797721386, 58.41035172343254, 57.44159750640392, 54.043553844094276, 47.307408303022385, 43.06548312306404, 46.92509561777115, 45.764029920101166, 49.43323463201523, 49.97514255344868, 57.52605937421322, 54.646516889333725, 62.15481899678707, 31.834235787391663, 47.77289852499962, 58.327554166316986, 51.0333401709795, 54.496915116906166, 51.68963335454464, 53.8646936416626, 51.98109671473503, 51.75601579248905, 45.73287159204483, 43.894750624895096, 45.56529678404331, 49.24071416258812, 50.374307334423065, 49.449284970760345, 48.49863678216934, 47.26407542824745, 49.96171407401562, 50.32250091433525, 50.964776650071144, 52.71990247070789, 53.61290395259857, 56.27477511763573, 55.47727771103382, 54.19557988643646, 53.753952383995056, 53.82144056260586, 53.61834146082401, 53.70359368622303, 57.01395325362682, 60.30846767127514, 60.03006801009178, 54.95935030281544, 49.90917049348354, 54.24941919744015, 58.15636955201626, 61.2736576795578, 58.67648184299469, 35.84459379315376, 21.466835997998714, 13.142896257340908, 12.67515940591693, 13.478497099131346, 6.320862025022507, 6.448910878971219, 5.230743745341897, 2.6455227797850966, 0.4243919241707772, 0.03680128502310254, 0.02905253968492616, 0.06605662769288756, 1.0893533332273364, 12.712905630469322, 37.38401658833027, 43.81888009607792, 33.60769562423229, 12.829978298395872, 18.87394443154335, 35.43328106403351, 43.31922210752964, 43.18132370710373, 45.8291432261467, 9.36035692691803, 0.2182080113561824, 0.10626676768879406, 0.02526655123801902, 0.08417291261139326, 0.012392096177791245, 0.032059859368018806, 0.03742867069377098, 0.03870918713801075, 0.02122240672179032, 0.023652068339288235, 0.020734591198561247, 0.030262975124060176, 0.037443339242599905, 0.024213785072788596, 0.052889725629938766, 0.0931595936708618, 0.0634262188395951, 0.039933897787705064, 0.04467793209187221, 0.0221513325595879, 0.070380135148298, 0.057851094170473516, 0.03441548804403283, 0.08447194617474452, 0.04386991509818472, 0.044679375569103286, 0.05583225211012177, 0.014109148523857584, 0.046375205274671316, 0.03488049180305097, 0.026369414226792287, 0.003124396494058601, 0.047565261338604614, 0.05172452038095798, 0.05813089868752286, 0.03887321290676482, 0.015790377401572186, 0.10455367562826723, 0.04181008422165178, 0.022199891282070894, 0.04539614550594706, 0.02315056204679422, 0.02156017111701658, 0.03241375248762779, 0.056889159459387884, 0.07448685384588316, 0.031529160696663894, 0.06199828589160461, 0.061650600837310776, 0.02620526785904076, 3.767018588259816, 52.349722534418106, 69.61855709552765, 65.3553606569767, 57.40396052598953, 42.08965748548508, 32.88317330181599, 24.20284118503332, 37.84236319363117, 45.6783103197813, 32.10315875709057, 13.876761328428984, 1.301209065131843, 0.129220022354275, 0.1369863306172192, 0.9359221975319088, 3.189353635534644, 6.482072174549103, 9.179715570062399, 9.918662868440151, 12.304648887366056, 8.352101929485798, 8.535040263086557, 28.30874126404524, 50.53744778037071, 62.332071885466576, 61.8593430519104, 63.19866858422756, 63.92989754676819, 61.37788608670235, 59.0777251124382, 61.220528930425644, 61.94535903632641, 57.57456377148628, 51.707602590322495, 49.59311105310917, 55.118519961833954, 57.87646137177944, 63.139604553580284, 57.6504684984684, 57.61166878044605, 55.848449394106865, 55.93746721744537, 59.290392100811005, 58.94747570157051, 54.27448645234108, 45.36675363779068, 44.05917540192604, 51.16193287074566, 54.908539429306984, 58.52458879351616, 60.23884400725365, 58.53007949888706, 55.96205569803715, 49.768015667796135, 45.49870155751705, 48.03901344537735, 47.968778014183044, 51.89521752297878, 52.27387100458145, 59.620647579431534, 56.98770046234131, 63.324932008981705, 34.93667051196098, 48.89033116400242, 59.84045058488846, 54.01434861123562, 57.69816353917122, 53.82811680436134, 56.77069030702114, 53.76982033252716, 53.754028379917145, 47.532489225268364, 44.64161194860935, 48.11965651810169, 51.29714101552963, 51.584094017744064, 51.17981091141701, 50.61895340681076, 49.51518103480339, 52.8392730653286, 52.89442330598831, 53.58858145773411, 55.903983414173126, 55.768022909760475, 58.04444655776024, 57.09862791001797, 53.901179283857346, 55.42720779776573, 53.74277338385582, 54.310652911663055, 54.710000082850456, 58.81727188825607, 61.88329316675663, 62.03560419380665, 56.889555528759956, 53.25365982949734, 55.822371393442154, 61.72808289527893, 61.28426291048527, 58.240694627165794, 37.09442652761936, 22.032277956604958, 7.959545943886042, 9.78822061792016, 12.060990761965513, 11.290704645216465, 8.65053316578269, 9.110024459660053, 4.7460355795919895, 1.4687239076010883, 0.18786416068905964, 0.054658460212522186, 0.02028105918725487, 1.1039913352578878, 12.487662266939878, 41.991668343544006, 44.87110063433647, 29.31623250246048, 17.58277751505375, 27.324685268104076, 42.609465792775154, 50.08182942867279, 50.28243586421013, 53.51489961147308, 12.130321841686964, 0.2589523937785998, 0.11086216094554402, 0.03357437868544366, 0.06719359793351032, 0.016032445564633235, 0.04092779308848549, 0.0246415719811921, 0.01601558025868144, 0.038216898319660686, 0.019335243923706003, 0.055424694292014465, 0.029905161609349307, 0.037359532216214575, 0.024437856154690962, 0.043674281259882264, 0.029465927073033527, 0.04033938872453291, 0.0874175970966462, 0.02399464927293593, 0.024976575587061234, 0.03660115005914122, 0.05143747250258457, 0.028363670789985918, 0.052908464858774096, 0.02247723372420296, 0.01461049061617814, 0.15609367954311892, 0.10169943503569812, 0.11829124472569674, 0.10899855391471647, 0.09393003201694228, 0.05772581964265555, 0.12315121362917125, 0.16954728809650987, 0.12199088800116442, 0.12023380142636597, 0.06397523742634803, 0.19691030262038112, 0.11751698431908153, 0.1319564098957926, 0.1613491983152926, 0.12675873411353678, 0.12998850143048912, 0.15811336023034528, 0.2601311617763713, 0.18458078062394634, 0.21284982387442142, 0.1297647735918872, 0.16617767047137022, 0.29201807104982436, 5.993707654997706, 64.57476854324341, 76.95393428206444, 74.03664842247963, 64.03955966234207, 48.25600080192089, 37.0137682557106, 34.44342277944088, 46.08825512230396, 56.511612609028816, 40.74505403637886, 15.83931801840663, 1.3443495752289891, 0.4067663918249309, 0.13859557395335287, 0.8659604704007506, 5.363961271941662, 15.856886375695467, 15.917922500520945, 20.135930813848972, 21.970713660120964, 19.80089709162712, 13.2281693816185, 33.647924065589905, 60.38605950772762, 66.48080706596375, 64.30239915847778, 63.10056544840336, 63.41765843331814, 60.989976301789284, 60.36961019039154, 61.52297370135784, 65.9474828839302, 60.43235242366791, 53.456751331686974, 51.699292436242104, 57.2980298101902, 58.998544961214066, 65.19728913903236, 58.573241382837296, 59.39133368432522, 55.562947914004326, 55.699824169278145, 61.08698129653931, 63.56778457760811, 56.30465671420097, 47.11955018341541, 46.066896468400955, 53.38047042489052, 56.801153272390366, 60.90034291148186, 61.640448197722435, 61.38589225709438, 60.34366898238659, 51.0323978215456, 48.612448275089264, 51.01208031177521, 50.94254404306412, 52.692980915308, 56.33104629814625, 63.812499046325684, 59.86594721674919, 62.44833804666996, 40.13865977525711, 51.80706225335598, 61.920265182852745, 57.65864945948124, 59.13796707987785, 56.863975301384926, 59.22322690486908, 56.73723690211773, 56.34328544139862, 49.61787432432175, 46.26180320978165, 50.13243891298771, 53.72868373990059, 54.45800520479679, 54.852861016988754, 53.280721977353096, 51.647543013095856, 56.26385450363159, 55.617904365062714, 57.03016698360443, 59.188861548900604, 58.47148284316063, 60.30983179807663, 59.17202465236187, 56.04565121233463, 54.87793207168579, 53.41317906975746, 53.58236879110336, 55.105315670371056, 59.67349894344807, 63.983961045742035, 64.56735134124756, 59.81432318687439, 55.235314294695854, 58.92995484173298, 63.337596729397774, 64.93782386183739, 60.86647532880306, 37.78240241110325, 24.943947717547417, 20.137868709862232, 21.403799280524254, 26.702141873538494, 15.19072512164712, 15.192357134073973, 15.23226449266076, 7.130945306271315, 1.6894237836822867, 0.16580867464654148, 0.21380217745900154, 0.17914258962264284, 1.7002684017643332, 16.02429874241352, 51.27217635512352, 59.5234601944685, 46.214662939310074, 22.323671020567417, 29.883659854531288, 47.55086123943329, 59.140664935112, 59.36150148510933, 62.22003109753132, 16.465821750462055, 0.46098790888208896, 0.24235994584159926, 0.12696419027633965, 0.23735849390504882, 0.140003576525487, 0.1556931424420327, 0.0846512193675153, 0.14450967457378283, 0.10065305134048685, 0.15663126163417473, 0.09002002698252909, 0.18354336207266897, 0.11293126866803505, 0.10978166814311408, 0.13756268250290304, 0.12919787666760385, 0.21310325246304274, 0.17259484331589192, 0.08046418544836342, 0.1130989495140966, 0.10294987965608016, 0.17054234485840425, 0.2832332096295431, 0.20800956641323864, 0.21003822708735242, 0.1281835834379308], [0.027572526523726992, 0.02323784417967545, 0.039661017508478835, 0.026871948393818457, 0.08053019206272438, 0.040658786820131354, 0.036354129915707745, 0.033811368703027256, 0.019662612685351633, 0.03145489397866186, 0.029212101435405202, 0.03961482252634596, 0.02549914403061848, 0.023333263961831108, 0.03146955510601401, 0.03492563664622139, 0.0028887666940136114, 0.03877950934111141, 0.009585394782334333, 0.026620545868354384, 0.09254039759980515, 0.04152240180701483, 0.014334227071230998, 0.07660507690161467, 16.641121543943882, 53.037151247262955, 59.2704963684082, 55.93905933201313, 42.8695922344923, 29.52045064419508, 22.533917538821697, 35.57880565524101, 41.986667811870575, 36.608987376093864, 18.14498394727707, 2.623417228460312, 0.09364611600176431, 0.1295303736696951, 0.12481261510401964, 1.3657382712699473, 2.020145687274635, 3.0909056682139635, 4.794367086142302, 10.553477704524994, 10.249093137681484, 6.8637835420668125, 12.187601868063211, 48.2382595539093, 64.15161564946175, 65.21561935544014, 60.41921652853489, 60.06025359034538, 62.67987482249737, 61.20714604854584, 58.185445591807365, 59.96519409120083, 58.296433836221695, 55.80334201455116, 49.39788892865181, 46.68188586831093, 51.09700195491314, 57.35500015318394, 59.75115917623043, 56.67953319847584, 58.38546685874462, 56.769124791026115, 55.55882513523102, 56.73214517533779, 55.781648978590965, 49.74174007773399, 42.649443447589874, 42.3091147094965, 47.793972194194794, 53.04060146212578, 57.12148368358612, 56.38431563973427, 58.277860432863235, 55.05897715687752, 48.48683461546898, 44.05058406293392, 42.31058143079281, 45.142877250909805, 48.95384855568409, 49.11571227014065, 59.04574602842331, 53.869914561510086, 62.701662853360176, 29.69150986522436, 44.690716713666916, 59.16273035109043, 52.12937615811825, 54.512425884604454, 49.07576881349087, 52.366460636258125, 49.91276130080223, 48.9227282255888, 43.5940233618021, 43.32179456949234, 42.74286523461342, 48.056006133556366, 46.895457208156586, 46.580267921090126, 45.361707508563995, 46.99784271419048, 46.37901932001114, 47.60537691414356, 48.84558856487274, 50.42384907603264, 51.19582325220108, 53.73890899121761, 56.15683704614639, 55.52874594926834, 52.12799683213234, 50.23002527654171, 54.649613723158836, 53.86954218149185, 58.294769525527954, 57.70531855523586, 59.85214255750179, 57.33147941529751, 53.469803631305695, 48.76873768866062, 60.40592484176159, 61.1737572401762, 61.395171359181404, 56.37383580207825, 34.47538286447525, 14.66855239123106, 12.453835532069206, 8.188366815447807, 18.761759251356125, 9.531013369560242, 4.910058528184891, 3.7983486196026206, 0.5710296181496233, 0.15515262144617736, 0.009549793030600995, 0.0976292448467575, 0.02689756547624711, 2.1598273795098066, 21.063158959150314, 47.58151039481163, 37.48571053147316, 25.272673778235912, 22.87570919841528, 42.05287165939808, 36.66417181491852, 49.023947194218636, 44.98089574277401, 28.230507262051105, 1.0595674440264702, 0.02936642547865631, 0.016657979576848447, 0.029243028584460262, 0.013601318205473945, 0.013426535006146878, 0.048222778204944916, 0.059176440045121126, 0.051691539338207804, 0.08027974690776318, 0.08134327421430498, 0.06890733566251583, 0.13242099434137344, 0.019236933476349805, 0.0284281448693946, 0.08520735515048727, 0.03397792890609708, 0.040645268600201234, 0.030030462112335954, 0.03768396578379907, 0.02152919943910092, 0.05095924367196858, 0.06437564836232923, 0.014688867904624203, 0.011468726243037963, 0.043031859677284956, 0.045241444822750054, 0.015526119950663997, 0.020743322565976996, 0.0337124070210848, 0.04209774066112004, 0.014169916503306013, 0.0751561151992064, 0.02318043349077925, 0.030691971733176615, 0.03434430494962726, 0.08103858548565768, 0.090702550514834, 0.06239976923097856, 0.01991186298255343, 0.07847524451790377, 0.03979669694672339, 0.023919903869682457, 0.007943328109831782, 0.00572195858694613, 0.032706711572245695, 0.024690861719136592, 0.06311056116828695, 0.06746475643012673, 0.07886645282269455, 21.48948658257723, 62.88607835769653, 68.30257371068001, 63.63760203123093, 51.225009486079216, 37.3761548101902, 32.840406596660614, 41.300379037857056, 46.81200608611107, 39.055634289979935, 21.895844377577305, 3.198625138029456, 0.11811871023382992, 0.07672583175008185, 0.38925188477151096, 1.5077168215066195, 4.497818648815155, 7.333526685833931, 11.242372188717127, 12.987940572202206, 11.111545208841562, 12.314999531954527, 19.411148205399513, 47.46907062828541, 63.05239923298359, 67.44910910725594, 62.46719643473625, 63.082022443413734, 63.37351620197296, 61.67713142931461, 58.41047331690788, 62.59294308722019, 60.67269712686539, 58.333238661289215, 51.44813731312752, 49.846675246953964, 54.30592976510525, 59.62595969438553, 61.413832157850266, 57.054865658283234, 56.27279922366142, 56.911214366555214, 56.27639003098011, 57.933017536997795, 58.304158821702, 50.19895054399967, 44.45143215358257, 44.93139199912548, 49.14771415293217, 55.630067512393, 58.98439072072506, 59.338155537843704, 58.18810544908047, 56.7136287689209, 50.69596007466316, 44.95646305382252, 46.15633986890316, 47.265998125076294, 50.270067527890205, 50.79905614256859, 60.62085650861263, 56.456302776932716, 63.07312332093716, 33.34000378847122, 45.617977157235146, 60.61653234064579, 55.29172986745834, 56.025227308273315, 51.43402487039566, 55.15708029270172, 52.767977491021156, 51.04912452399731, 44.869801104068756, 45.49542613327503, 44.090941697359085, 51.059155985713005, 47.972809597849846, 48.81822623312473, 47.10597351193428, 49.07981179654598, 48.442274406552315, 50.016328543424606, 51.89510352909565, 52.22129702568054, 51.80869236588478, 56.997180953621864, 59.404640570282936, 56.308190524578094, 52.75022104382515, 51.41504488885403, 54.257315173745155, 54.028761237859726, 57.812423408031464, 59.12144176661968, 61.9603606313467, 61.21104843914509, 54.53053191304207, 51.466357335448265, 61.241367012262344, 63.655753657221794, 61.386177241802216, 56.306777000427246, 33.260960429906845, 16.478632763028145, 9.031896851956844, 6.28036237321794, 11.955489423125982, 12.567866463214159, 7.2259677574038506, 6.814522035419941, 2.8859840892255306, 0.9053136524744332, 0.06247457771678455, 0.10118090387550183, 0.0922195820021443, 3.0411734618246555, 23.15166749060154, 45.753610879182816, 36.68795473873615, 22.24419068545103, 26.187373995780945, 45.94743087887764, 44.918328300118446, 56.37517333030701, 53.114507496356964, 33.02934765815735, 1.6528281848877668, 0.025335828868264798, 0.03354586908244528, 0.040623935565236025, 0.06754279325832613, 0.03738182262168266, 0.03534888346621301, 0.051055567018920556, 0.05891427266760729, 0.006563445513165789, 0.07509115501306951, 0.058433706071809866, 0.05444470312795602, 0.07993113787961192, 0.05194799217861146, 0.016410595781053416, 0.024885862876544707, 0.021003404508519452, 0.013040967951383209, 0.039651284241699614, 0.021436110000649933, 0.025513805157970637, 0.0405200311797671, 0.1524510109447874, 0.03546455831383355, 0.008644131667097099, 0.09384395030792803, 0.12132118878071196, 0.11752804231946357, 0.163218816742301, 0.20776152581674978, 0.0877982001111377, 0.15475818479899317, 0.18426624359562993, 0.08391403665882535, 0.08979675185400993, 0.20825055660679936, 0.19194291526218876, 0.21198749280301854, 0.12869517551735044, 0.14408102491870522, 0.12810040352633223, 0.13027839915594086, 0.11630619264906272, 0.12437378318281844, 0.08669698654557578, 0.12768401415087283, 0.1548848397214897, 0.20961269445251673, 0.16005768324248493, 26.55018612742424, 74.44602325558662, 74.70101237297058, 72.8234115242958, 58.58682565391064, 44.67036880552769, 32.49751299619675, 50.09494252502918, 55.19575081765652, 49.35793787240982, 24.5857048407197, 4.228234989568591, 0.2751562086632475, 0.17334196338197216, 0.5059115623589605, 2.6124189561232924, 6.676032291725278, 12.084802184253931, 18.37344478815794, 25.72050254791975, 21.465798653662205, 13.418129738420248, 19.35298092663288, 49.90102753043175, 67.87770330905914, 69.91293489933014, 64.76545751094818, 66.54672592878342, 66.08823493123055, 63.05484250187874, 57.805059403181076, 64.26269128918648, 63.19345906376839, 59.40288506448269, 54.30592216551304, 50.842370018363, 56.31463497877121, 62.1429218351841, 64.19036597013474, 58.309132754802704, 57.38128714263439, 58.508591651916504, 58.286554366350174, 60.63164032995701, 60.336650758981705, 53.61188180744648, 47.81896725296974, 47.37391233444214, 53.351508378982544, 57.30125583708286, 61.72465927898884, 60.60894034802914, 61.12716794013977, 60.713316947221756, 53.05851370096207, 47.74996675550938, 47.90647275745869, 49.74621243774891, 53.18353459239006, 54.62572440505028, 63.462872207164764, 60.68233720958233, 64.40071508288383, 35.69743908941746, 48.78780886530876, 64.4080562889576, 57.57750101387501, 57.76616469025612, 53.44553433358669, 57.08581119775772, 55.2456421405077, 53.172347992658615, 47.528571635484695, 48.00239861011505, 46.27551667392254, 53.65414693951607, 51.225522458553314, 50.1586689054966, 49.05407577753067, 51.98674701154232, 50.839793756604195, 52.01507069170475, 55.159056186676025, 55.64704120159149, 54.72916625440121, 58.48773457109928, 63.33443909883499, 58.55390802025795, 55.20633704960346, 51.76747977733612, 56.471779346466064, 55.49928233027458, 60.5107232183218, 60.30606620013714, 65.5169203877449, 64.1584324836731, 59.722831696271896, 53.55660617351532, 64.67229411005974, 64.33814764022827, 66.01932942867279, 60.23576617240906, 35.45195706188679, 18.82096767425537, 18.356453999876976, 15.63619801774621, 30.769293531775475, 22.538264505565166, 14.224222283810377, 10.846581626683474, 2.5822443002834916, 0.7113085908349603, 0.18090517551172525, 0.26661735435482115, 0.1443185715470463, 3.5566010791808367, 28.39994966983795, 61.16780295968056, 50.58414727449417, 37.294728979468346, 31.613857112824917, 55.49710124731064, 49.39532786607742, 65.83687841892242, 61.27698250114918, 40.84283038973808, 2.6966677978634834, 0.1397186957183294, 0.15672671666834503, 0.13350819615880027, 0.13302784849656746, 0.11717088375007734, 0.09283486695494503, 0.1885982189560309, 0.2641283394768834, 0.14519699238007888, 0.20421257562702522, 0.28825808374676853, 0.18577085895230994, 0.214162030024454, 0.15070032910443842, 0.2818136295536533, 0.0844921993848402, 0.1388394585228525, 0.15973293426213786, 0.15708285849541426, 0.088913892977871, 0.1121310553571675, 0.15512047160882503, 0.24934321409091353, 0.17203627328854054, 0.1502148012514226], [0.0338339782319963, 0.05075306762591936, 0.08737066367757507, 0.03831842783256434, 0.032475658736075275, 0.019520615715009626, 0.03648392412287649, 0.03387807293620426, 0.047543182445224375, 0.022765463472751435, 0.029301387367013376, 0.060093166830483824, 0.05333378227078356, 0.04425219536642544, 0.0334557871974539, 0.05631153107970022, 0.0896636105608195, 0.028545430177473463, 0.15524476650170982, 0.04461187723791227, 0.10093566117575392, 0.035312752006575465, 0.04479509123484604, 0.8196000487077981, 29.084809720516205, 59.46159951388836, 59.580559730529785, 45.04889689385891, 35.10464809834957, 15.875831209123135, 15.161367896944284, 23.7759929895401, 47.10201792418957, 27.179428562521935, 10.114266872406006, 0.6433986942283809, 0.23309997632168233, 0.036718301780638285, 0.9670481679495424, 1.9600989343598485, 2.145448951050639, 3.4960506157949567, 8.703263886272907, 5.329627264291048, 11.262961383908987, 21.011329740285873, 37.74670332670212, 58.619108721613884, 59.031713381409645, 62.64898627996445, 54.77314129471779, 59.421644657850266, 60.008933544158936, 59.775713458657265, 57.55692131817341, 59.301248118281364, 57.090823128819466, 53.31577509641647, 46.37843415141106, 46.82478480041027, 51.980602741241455, 55.26458412408829, 58.11474658548832, 57.91711539030075, 58.20277266204357, 55.64432814717293, 57.501090914011, 57.30356991291046, 54.232977479696274, 46.97270326316357, 42.911895364522934, 43.662704676389694, 47.78583683073521, 51.991055980324745, 55.71641407907009, 55.772225484251976, 55.487613156437874, 54.44071613252163, 49.04779851436615, 41.32085233926773, 43.54032464325428, 43.11199642717838, 44.926026687026024, 49.00885060429573, 57.009898871183395, 53.503872603178024, 63.703148514032364, 28.20470094680786, 39.546434953808784, 60.51782123744488, 51.326889619231224, 54.80907216668129, 47.30000250041485, 51.2437728792429, 47.271401435136795, 51.5681766718626, 44.4682614505291, 41.046621054410934, 41.219154596328735, 44.206569492816925, 45.12707009911537, 45.71927972137928, 45.14670364558697, 44.3337182700634, 42.69878759980202, 42.75984652340412, 41.87933497130871, 44.59797129034996, 46.91843457520008, 49.9273145198822, 53.949774876236916, 53.41685347259045, 52.722053155303, 51.95776976644993, 51.67555510997772, 53.26895400881767, 52.25018687546253, 54.545259922742844, 58.39079797267914, 58.071018531918526, 55.84489658474922, 49.08804215490818, 50.61423026025295, 54.695344269275665, 59.88667510449886, 60.47743320465088, 50.3240892291069, 29.637315273284912, 19.13821455091238, 9.946595169603825, 9.544374402612448, 6.142516694962978, 6.487115928903222, 4.691081503406167, 3.8794714165851474, 1.3586841872893274, 0.1168823367333971, 0.07797422062139958, 0.07402721952530555, 0.4894957604119554, 10.06791315972805, 37.39622913300991, 49.98494602739811, 33.859937489032745, 19.68178678303957, 36.961110681295395, 35.58641664683819, 50.93943201005459, 45.6759924441576, 30.125393383204937, 6.3489078450948, 0.1781686840695329, 0.044817967936978675, 0.031870841776253656, 0.029632071673404425, 0.0702063538483344, 0.07886608174885623, 0.026640062496881, 0.07915131878689863, 0.024074777102214284, 0.14632815902587026, 0.08997242563054897, 0.08303048016387038, 0.006458203870352008, 0.043382535586715676, 0.06281149791902862, 0.0844441082153935, 0.02398796994384611, 0.04478368442505598, 0.03119819622952491, 0.04078023928741459, 0.008229477989516454, 0.10868069948628545, 0.032796452069305815, 0.07179791180533357, 0.04880739019426983, 0.01416533374140272, 0.022787872621847782, 0.053622414634446613, 0.06349348710500635, 0.0666959211230278, 0.022355651381076314, 0.04114487128390465, 0.10453375638462603, 0.07236536534037441, 0.029688025897485204, 0.051175590851926245, 0.02967845219245646, 0.03322240401757881, 0.055159996190923266, 0.08313286685734056, 0.019630898859759327, 0.06028805852110963, 0.06594521648366936, 0.01342708141237381, 0.05490133546118159, 0.05374085027142428, 0.023028488030831795, 0.17841446853708476, 1.4280581334605813, 35.659422129392624, 70.78617364168167, 66.40500873327255, 51.89471215009689, 43.60752023756504, 24.029579982161522, 19.40310213714838, 28.34126751869917, 49.57562439143658, 32.7072237432003, 10.572983007878065, 0.6151396699715406, 0.18950182828120887, 0.09125872340518981, 1.4429620024748147, 4.027694100514054, 7.036707988008857, 8.73065946623683, 12.395812645554543, 12.265675328671932, 16.14031031727791, 18.793567344546318, 35.65007463097572, 56.73810325562954, 62.594086825847626, 63.763056099414825, 58.98654140532017, 60.87463729083538, 62.55063995718956, 59.68542270362377, 59.77435313165188, 60.713282749056816, 59.583029597997665, 54.83006604015827, 49.3525155633688, 49.81336623430252, 53.539830073714256, 56.751493737101555, 59.90030877292156, 57.64392904937267, 58.77845697104931, 55.72548419237137, 58.73824752867222, 59.21858735382557, 55.52319444715977, 47.45831720530987, 42.964058965444565, 45.91154180467129, 48.49302068352699, 53.76098960638046, 58.53763349354267, 58.124021887779236, 55.84228612482548, 56.33397214114666, 50.660033002495766, 42.80808873474598, 45.37824422121048, 46.787341609597206, 47.89050601422787, 51.59034848213196, 60.40518768131733, 56.53121575713158, 63.87029394507408, 30.08233979344368, 42.359697595238686, 63.38061422109604, 53.81318740546703, 56.275014504790306, 49.471468180418015, 53.21644842624664, 49.996258020401, 52.76232339441776, 47.01602093875408, 43.335819616913795, 42.45527006685734, 46.57293051481247, 47.31234423816204, 49.420205131173134, 47.79546171426773, 47.34954044222832, 45.54746814072132, 45.07769554853439, 44.396251514554024, 46.84664882719517, 49.23918664455414, 52.24406540393829, 55.80323562026024, 55.462317913770676, 55.67996643483639, 53.50494034588337, 52.13004112243652, 54.714088663458824, 54.31310378015041, 56.9735462218523, 58.51635463535786, 60.590374544262886, 58.06551642715931, 51.97145663201809, 52.65063598752022, 56.89740590751171, 64.05317813158035, 61.516863629221916, 52.02541373670101, 31.780084893107414, 18.099156506359577, 10.532517079263926, 7.79989798553288, 12.204946987330914, 12.73366391658783, 11.789081152528524, 3.8676690123975277, 1.833594103809446, 0.17555494385305792, 0.18482702522305772, 0.1645932742394507, 0.4726211627712473, 11.064164601266384, 36.51968456804752, 46.36266119778156, 35.43543554842472, 23.24146807193756, 43.62954385578632, 39.549060612916946, 56.342552080750465, 52.51764312386513, 36.68008156120777, 8.438299354165792, 0.055334493663394824, 0.05515974014997482, 0.029030145378783345, 0.020402500522322953, 0.03543967781297397, 0.0253382185837836, 0.04673460513004102, 0.030932583431422245, 0.030881137754477095, 0.0045310666791920085, 0.019006042057299055, 0.04180143449048046, 0.03634054861322511, 0.032086643477668986, 0.029228241292003077, 0.026357948045188095, 0.027423434621596243, 0.06273113074712455, 0.08880375826265663, 0.04013504949398339, 0.01948765137058217, 0.015983050070644822, 0.028932647583133075, 0.026426572585478425, 0.0572964278399013, 0.10055985985673033, 0.14280654955655336, 0.1991190083208494, 0.19191006780602038, 0.1356210609083064, 0.16185133543331176, 0.11725309144821949, 0.19850568263791502, 0.1591341249877587, 0.11450210586190224, 0.14990354451583698, 0.137854480126407, 0.14356573694385588, 0.13163036957848817, 0.13065820065094158, 0.1484271010849625, 0.14303527947049588, 0.12093150187865831, 0.29432612063828856, 0.13729690457694232, 0.13492636615410447, 0.14891430619172752, 0.3741071739932522, 2.265029246918857, 43.995080441236496, 77.79099136590958, 77.47517511248589, 59.4401990622282, 50.96127323806286, 26.86487954109907, 23.74964140355587, 36.29071265459061, 62.324259504675865, 36.70265235006809, 14.185161329805851, 0.7196759793441743, 0.3735931031405926, 0.27403699059505016, 2.241485472768545, 4.66143311932683, 10.810013338923454, 13.345022611320019, 15.127079486846924, 14.03359791263938, 19.53944832086563, 27.636420540511608, 43.63943852484226, 63.13444443047047, 63.62777575850487, 67.13254049420357, 59.547630697488785, 62.839337065815926, 61.750596687197685, 60.62457650899887, 58.10962826013565, 62.41194359958172, 61.484337374567986, 57.46862545609474, 50.58774948120117, 53.22255849838257, 55.84550455212593, 58.10000717639923, 61.45576290786266, 59.13182660937309, 57.82070696353912, 56.66421242058277, 61.91814109683037, 61.797493770718575, 58.129972368478775, 51.660903096199036, 45.43507017195225, 48.62231254577637, 51.76486551761627, 56.59162491559982, 59.676721170544624, 60.446225479245186, 56.94917052984238, 57.60161072015762, 52.718986719846725, 45.25981977581978, 48.23594927787781, 48.674027770757675, 50.11019490659237, 55.59797063469887, 61.20254449546337, 58.663459941744804, 63.8989520072937, 33.122659251093864, 44.46334831416607, 65.8743368089199, 58.2845176756382, 59.363101199269295, 53.11947762966156, 55.847119465470314, 51.318632662296295, 54.93152439594269, 48.55263188481331, 45.81137157976627, 44.13046717643738, 47.83646531403065, 51.420505195856094, 51.39562413096428, 50.5722501128912, 49.79959577322006, 47.19616927206516, 45.95158025622368, 47.750411331653595, 48.4005032479763, 53.084435909986496, 55.71112096309662, 58.5820797085762, 58.15950818359852, 56.155415922403336, 53.613952696323395, 52.93609566986561, 54.97548043727875, 54.512194097042084, 56.43288843333721, 60.692452266812325, 62.094083055853844, 61.82029254734516, 53.817116394639015, 56.362721398472786, 60.370685532689095, 66.8783949315548, 64.16239187121391, 54.649081751704216, 32.752733901143074, 27.36333679407835, 16.62598505616188, 24.781506434082985, 14.934894349426031, 15.289504621177912, 15.712525472044945, 11.221975833177567, 2.5991305941715837, 0.31436214863788337, 0.32703645760193467, 0.3666406637057662, 1.0584193118847907, 14.205013364553452, 47.19426177442074, 64.7789315879345, 47.05786049365997, 30.743793100118637, 46.8770319968462, 46.510062888264656, 66.66197374463081, 61.6146931797266, 47.87070907652378, 10.9972919896245, 0.3477988997474313, 0.174168448720593, 0.130449716525618, 0.13243996363598853, 0.19387962383916602, 0.1530749790254049, 0.09022305632242933, 0.22423266229452565, 0.11879134093760513, 0.2182537573389709, 0.14497114199912176, 0.15828209492610767, 0.12156719589256682, 0.12582950585056096, 0.2294943854212761, 0.18083395902067423, 0.29602777620311826, 0.14489893103018403, 0.22018009069142863, 0.08274633408291265, 0.10243418350000866, 0.19507620338117704, 0.10025989860878326, 0.10240146963042207, 0.1650427040294744], [0.012677895392698701, 0.03373362873389851, 0.03316343296319246, 0.05098003864986822, 0.01382553771691164, 0.016303329466609284, 0.017930052235897165, 0.09115356107940897, 0.039194859709823504, 0.0015704970815022534, 0.0618894647777779, 0.06730845270794816, 0.052644672177848406, 0.045727751930826344, 0.021022846922278404, 0.06339538260363042, 0.03159808766213246, 0.015103876885405043, 0.058357917951070704, 0.05242506696959026, 0.05084159842226654, 0.019585405207180884, 0.07105953423888423, 2.8256354900076985, 33.665916100144386, 62.7122338861227, 51.14142157137394, 43.49328316748142, 30.43203692883253, 21.96936283260584, 36.85250870883465, 55.99560409784317, 38.57417732477188, 14.221913907676935, 2.218998041935265, 0.03411498873902019, 0.22480371524579823, 0.05905221194552723, 0.5910040182061493, 3.669227510690689, 3.3195868972688913, 7.141267452389002, 10.965843927115202, 13.154029659926891, 22.03629244118929, 34.465104416012764, 53.85336644947529, 65.47193840146065, 61.86597369611263, 57.90899142622948, 53.864750638604164, 61.17664508521557, 61.658755615353584, 57.82916530966759, 55.99489353597164, 59.592008516192436, 57.761908918619156, 50.781113505363464, 46.09292507171631, 47.84625358879566, 53.01396109163761, 56.39781251549721, 59.42389413714409, 57.00463615357876, 54.82549108564854, 56.615415439009666, 58.47033530473709, 54.309991747140884, 49.316250309348106, 41.8695542961359, 44.06345397233963, 43.512939512729645, 46.906533613801, 50.396961718797684, 55.86790055036545, 54.06718857586384, 55.56491240859032, 54.781979620456696, 49.7201344370842, 40.567603558301926, 43.37225966155529, 39.16400067508221, 46.04179501533508, 51.451120153069496, 58.18414606153965, 53.30033652484417, 60.41100516915321, 27.498406246304512, 38.539979159832, 61.18884243071079, 52.28491321206093, 53.27119588851929, 47.0367906242609, 48.115138560533524, 42.58209966123104, 49.07729633152485, 43.23608256876469, 41.119622737169266, 40.241402462124825, 44.737321212887764, 46.98578216135502, 48.671162724494934, 47.87097126245499, 47.93408587574959, 44.32043798267841, 42.99998603761196, 41.75966799259186, 42.530274242162704, 40.54635889828205, 48.58579270541668, 51.256050020456314, 54.62051868438721, 52.199091017246246, 50.663316026329994, 52.036186158657074, 59.06034104526043, 51.83576211333275, 53.670421466231346, 55.5737317353487, 56.33553385734558, 60.36056287586689, 55.42523190379143, 50.68317376077175, 51.83787479996681, 56.85996271669865, 61.872440949082375, 56.768068447709084, 48.06820347905159, 28.33394531160593, 14.030875358730555, 8.732933644205332, 13.166190907359123, 5.13953628949821, 6.49130092933774, 2.8668799018487334, 2.313741920515895, 0.09200577667797916, 0.07411694517941214, 0.04951956252625678, 0.13827530754497275, 1.27390515524894, 17.638647817075253, 45.62757924199104, 38.38490568101406, 24.13492552936077, 23.864613734185696, 37.10897594690323, 42.344536408782005, 49.14318859577179, 42.65616908669472, 15.979331955313683, 0.6074662192258984, 0.06539348163641989, 0.00929160542000318, 0.022100033456808887, 0.009928379258781206, 0.024475227000948507, 0.026427860211697407, 0.0750680519558955, 0.061755165734211914, 0.01896614605357172, 0.028175957522762474, 0.07554149022325873, 0.06141004851087928, 0.015464715579582844, 0.06622720291488804, 0.03410251694731414, 0.03393905521079432, 0.019561569279176183, 0.0600779008527752, 0.029539863535319455, 0.06567188349436037, 0.05096452405268792, 0.06898107545566745, 0.03219393205654342, 0.0139844760633423, 0.01806567786843516, 0.008432004524365766, 0.039876347946119495, 0.07601415665703826, 0.035714803088922054, 0.034493372731958516, 0.042709526387625374, 0.020367064826132264, 0.05644214164931327, 0.04068210881086998, 0.06223662290722132, 0.048833621403900906, 0.06505627199658193, 0.01813912265788531, 0.018158732054871507, 0.08419338846579194, 0.07130186029826291, 0.03642859330284409, 0.06505701414425857, 0.06487431965069845, 0.028262345367693342, 0.04076329976669513, 0.04445257152838167, 3.700636625289917, 42.33645424246788, 73.24477091431618, 57.65041150152683, 50.07190056145191, 38.973630890250206, 23.054079227149487, 26.181056834757328, 50.21640680730343, 42.756711691617966, 16.65322009474039, 3.1002142187207937, 0.09574970390531234, 0.11155750878970139, 0.05736055310990196, 1.8850277876481414, 8.687254395335913, 6.941738734021783, 10.452138092368841, 13.715554978698492, 11.656442619860172, 22.467027828097343, 31.954814717173576, 50.253929793834686, 65.42126432061195, 63.474799767136574, 60.399936363101006, 56.40987306833267, 62.48173825442791, 63.24658781290054, 58.71451020240784, 57.92365483939648, 60.30146464705467, 59.1534398496151, 54.008401930332184, 48.242971301078796, 48.643526807427406, 55.21304748952389, 58.50985698401928, 60.43642960488796, 58.208160772919655, 55.54953843355179, 58.372916132211685, 59.66901518404484, 55.905389338731766, 52.54676856100559, 44.56825688481331, 45.68219751119614, 45.10058172047138, 49.866080805659294, 55.46503096818924, 57.92167894542217, 56.58638119697571, 56.79156258702278, 57.26804181933403, 51.890262588858604, 43.04573178291321, 45.5981270223856, 41.78350031375885, 48.81318770349026, 53.13046284019947, 59.933762177824974, 54.62896183133125, 62.79028929769993, 29.695286862552166, 40.81615202128887, 62.72944316267967, 53.25693525373936, 55.49304686486721, 49.414486438035965, 51.57715938985348, 45.91618895530701, 49.30335760116577, 45.935206934809685, 42.92221561074257, 42.89764232933521, 46.00402124226093, 49.177819937467575, 51.19594104588032, 49.80450130999088, 50.54970592260361, 46.62987805902958, 44.248492643237114, 42.058339565992355, 44.07172232866287, 43.33717614412308, 51.60069912672043, 53.40211406350136, 57.30716831982136, 53.17454807460308, 51.04691304266453, 54.10741701722145, 59.10398170351982, 53.707260489463806, 54.72085230052471, 56.39711335301399, 58.36154714226723, 61.42117716372013, 56.77184924483299, 52.22865343093872, 56.472953483462334, 58.8104322552681, 63.3196996897459, 59.19144161045551, 49.719161689281464, 29.968811385333538, 13.465725034475327, 5.719682984054089, 10.988405216485262, 17.531579062342644, 10.288800057023764, 8.83580457419157, 8.751131817698479, 1.1248744209297001, 0.14684387744637206, 0.07973199739353731, 0.13207671203417704, 1.9459847104735672, 19.23993319272995, 48.25912803411484, 42.520626559853554, 27.59599070996046, 29.985298700630665, 43.94314102828503, 47.06726498901844, 54.579811468720436, 51.16851791739464, 20.704416409134865, 0.9113301546312869, 0.04663961393816862, 0.0021642436331603676, 0.06233064559637569, 0.010140841295651626, 0.03210363494872581, 0.020245308078301605, 0.02222137089120224, 0.058326335856691, 0.03294756817922462, 0.024097479399642907, 0.02776461660687346, 0.045627190920640714, 0.044029870186932385, 0.08619280109996907, 0.029319267559912987, 0.015647712498321198, 0.04027863651572261, 0.06662350977421738, 0.05909241779590957, 0.048982370062731206, 0.008083773991529597, 0.025041340959433, 0.0292890547279967, 0.09804438741412014, 0.12741734564770013, 0.10490514934645034, 0.1222319746739231, 0.12094627061742358, 0.09628030980820768, 0.16336288244929165, 0.15172345389146358, 0.24500482657458633, 0.18023935030214489, 0.05805213455460034, 0.17464645119616762, 0.12350498800515197, 0.10843925658264197, 0.11421945149777457, 0.18516667652875185, 0.1541867310879752, 0.11860581143992022, 0.09453483042307198, 0.16485094791278243, 0.15869415015913546, 0.10020636749686673, 0.12306893171626143, 0.13922392070526257, 5.084649659693241, 51.48438736796379, 77.69986465573311, 67.00172111392021, 56.4785847812891, 44.386425241827965, 33.30557003617287, 48.768509700894356, 70.63396140933037, 52.96551749110222, 20.36305222660303, 3.7756804609671235, 0.19484886870486662, 0.42766823899000883, 0.19040007930016145, 2.7536165295168757, 9.438192900270224, 13.353737443685532, 20.690927132964134, 21.51813894510269, 23.784023858606815, 29.978799149394035, 39.47206534445286, 55.67782334983349, 70.43593883514404, 66.08341678977013, 63.77165883779526, 58.735431879758835, 66.34649947285652, 65.38063690066338, 58.95898908376694, 57.33633175492287, 62.901095151901245, 61.479963809251785, 56.28199853003025, 50.533530190587044, 51.15817487239838, 56.77274979650974, 61.53664156794548, 62.709346041083336, 59.2507716268301, 54.3683186173439, 61.47786632180214, 61.623588502407074, 60.14468125998974, 54.49750408530235, 47.6452823728323, 49.297452718019485, 47.81962841749191, 51.45156852900982, 55.69659434258938, 59.58213284611702, 59.70741592347622, 57.56468430161476, 59.38013568520546, 53.76692108809948, 45.77551290392876, 46.27231724560261, 43.68773013353348, 50.77381029725075, 56.797893047332764, 61.70431137084961, 58.13323639333248, 60.815292075276375, 32.48806670308113, 43.41182693839073, 65.19364133477211, 56.66072800755501, 57.391656786203384, 52.168837040662766, 55.11579930782318, 47.82351940870285, 52.761734426021576, 48.67518290877342, 44.288333505392075, 44.35614086687565, 48.22142265737057, 52.62619949877262, 53.2276464253664, 52.47702330350876, 53.623231798410416, 49.269866198301315, 46.218591928482056, 46.09267048537731, 46.839444413781166, 45.374509021639824, 55.38658417761326, 56.29033528268337, 59.105494022369385, 55.10964743793011, 52.089713886380196, 53.72875973582268, 61.59040108323097, 55.75050964951515, 56.46816574037075, 57.24971920251846, 61.076140478253365, 65.63616558909416, 61.57287262380123, 57.75114789605141, 57.88784556090832, 60.475464910268784, 67.86375805735588, 61.10102914273739, 53.86239856481552, 30.80376148223877, 19.777573943138123, 15.778374038636684, 23.973407596349716, 20.70531126111746, 18.093530908226967, 12.859764900058508, 8.457589969038963, 1.1104180966503918, 0.16984230664093047, 0.28034275223035365, 0.24655423796502873, 2.0413566241040826, 24.56047609448433, 59.59381341934204, 49.59941491484642, 35.08129835128784, 33.997680097818375, 50.315942466259, 56.056484431028366, 64.64545994997025, 58.61882373690605, 26.137767657637596, 1.4934520306997001, 0.07401760871289298, 0.14363981812493876, 0.1532755815424025, 0.13173910905607045, 0.13219502521678805, 0.15122385491849855, 0.20476660371059552, 0.11854055439471267, 0.0981325248721987, 0.1771512589766644, 0.10721106897108257, 0.21746187092503533, 0.13921989826485515, 0.18279371870448813, 0.10554526656051166, 0.11964563454966992, 0.1432510811719112, 0.1923304796218872, 0.1415484311291948, 0.16804619051981717, 0.14769445289857686, 0.17004022258333862, 0.14113861718215048, 0.16594972723396495], [0.07431933627231047, 0.015053990646265447, 0.07369784696493298, 0.07141551279346459, 0.028757871805282775, 0.012496206509240437, 0.04264410235919058, 0.014034089563210728, 0.033299286806141026, 0.07083278585923836, 0.031893391933408566, 0.011199487125850283, 0.06238526766537689, 0.025833129038801417, 0.021505209515453316, 0.029640619359270204, 0.032199483321164735, 0.06353922566631809, 0.03322313503304031, 0.039382812319672666, 0.049025529660866596, 0.028087144710298162, 0.20085555966943502, 5.698827803134918, 48.51984344422817, 62.35416769981384, 55.45609004795551, 37.46962979435921, 24.274788424372673, 30.11820036917925, 39.369607642292976, 38.67835633456707, 26.868443749845028, 9.030934553593397, 0.13971160078654066, 0.2205521144787781, 0.053209242469165474, 0.34534684382379055, 1.9529576925560832, 5.827790508046746, 6.15770922973752, 6.587293753400445, 13.170272838324308, 20.427711457014084, 45.66806986927986, 49.44196656346321, 58.5213665664196, 62.98437528312206, 57.93844364583492, 55.3846462816, 54.13649685680866, 59.79418806731701, 60.54414242506027, 57.80368007719517, 55.7443767786026, 56.85674428939819, 55.84406442940235, 49.54264976084232, 46.93330317735672, 49.7251957654953, 54.76195469498634, 57.3818951100111, 56.017388328909874, 53.93614120781422, 57.62760132551193, 58.0848003923893, 53.72252807021141, 50.602165907621384, 43.9800750464201, 42.10242860019207, 44.46652874350548, 43.91103275120258, 49.46670703589916, 53.242484629154205, 56.97079136967659, 53.052415028214455, 54.97496746480465, 53.31010960042477, 47.96274393796921, 40.4639907181263, 44.02807027101517, 40.823246240615845, 49.489775598049164, 52.88817264139652, 59.54974718391895, 50.546916872262955, 60.20819865167141, 26.56141072511673, 35.529149919748306, 61.03172846138477, 49.47698928415775, 55.982916578650475, 44.71635773777962, 47.91671320796013, 44.37401130795479, 47.81585901975632, 44.59094166755676, 42.74728439748287, 38.25859285891056, 42.987264320254326, 47.64922276139259, 50.9897793084383, 50.47350861132145, 51.62621095776558, 46.49283841252327, 46.0509829223156, 42.38867484033108, 42.83832371234894, 40.02675577998161, 43.474154993891716, 50.62861628830433, 53.824328407645226, 53.18174488842487, 52.99472652375698, 53.768057227134705, 55.08910574018955, 55.10536506772041, 57.650559693574905, 53.817142993211746, 55.162563398480415, 53.394453674554825, 56.45275756716728, 52.24013261497021, 49.97158594429493, 50.44220969080925, 54.626640155911446, 58.77743862569332, 58.609214052557945, 46.85880437493324, 32.6197562366724, 5.59189441613853, 13.170258589088917, 19.375690408051014, 10.667638778686523, 2.4717474170029163, 3.8502049120143056, 1.0931796091608703, 0.18781788035994396, 0.13932837056927383, 0.07379063768894412, 0.17458228510804474, 6.276812888681889, 30.30430868268013, 42.10147105157375, 24.334053844213486, 14.622877892106771, 22.42455180734396, 33.607843816280365, 44.226541221141815, 45.014599934220314, 25.20270813256502, 4.112502224743366, 0.054275133516057394, 0.005203666305533261, 0.0370004811702529, 0.08827681114780717, 0.02167092367017176, 0.008745118484512204, 0.07172250960138626, 0.03522773156873882, 0.05437116000393871, 0.01901397932670079, 0.04025596390420105, 0.04457431714399718, 0.00983391035333625, 0.01651681752264267, 0.04997569019906223, 0.06199227078468539, 0.0201624918190646, 0.030152350591379218, 0.08286683660116978, 0.015682756711612456, 0.049870832153828815, 0.03893370907462668, 0.030140377893985715, 0.0221810778384679, 0.0938546891848091, 0.059168280131416395, 0.05330949919880368, 0.0318176706059603, 0.029231441803858615, 0.02877146609534975, 0.05744749571022112, 0.0020499136962826014, 0.07414222272927873, 0.05449591131764464, 0.03217712241166737, 0.02807207354635466, 0.028412006868165918, 0.06186278085806407, 0.07132244747481309, 0.04794640983163845, 0.034515759616624564, 0.010920650183834368, 0.09401183153386228, 0.04336912497819867, 0.07659908034838736, 0.0644077017204836, 0.17471046885475516, 8.824126850813627, 59.22614894807339, 69.83417272567749, 60.22521033883095, 44.58049222826958, 31.88981920480728, 40.146380960941315, 47.2230414301157, 46.614610478281975, 27.817518822848797, 9.799587707966566, 0.44843207637313753, 0.10858494759304449, 0.14001309085870162, 1.0142166400328279, 2.9381742887198925, 11.17576651275158, 8.962166793644428, 5.227013295516372, 12.180975023657084, 10.94249228015542, 29.38709869980812, 46.85681328177452, 60.69189369678497, 65.04608005285263, 60.89901678264141, 58.43949235975742, 57.18410812318325, 63.63238871097565, 61.0476990044117, 57.30198159813881, 56.292926743626595, 57.94018015265465, 58.40769566595554, 51.445211470127106, 50.08422710001469, 51.48948289453983, 57.74242356419563, 58.991899117827415, 57.77949437499046, 53.70818383991718, 57.16058738529682, 59.3285496532917, 56.470331624150276, 53.246162831783295, 46.786988228559494, 43.64369049668312, 46.20737113058567, 46.66495777666569, 50.70330128073692, 54.54503953456879, 59.515568017959595, 55.487407967448235, 57.12762415409088, 56.15325003862381, 50.31215026974678, 42.49055877327919, 47.07849718630314, 41.03250481188297, 51.14942394196987, 55.222641974687576, 61.674646362662315, 51.975894793868065, 59.820767641067505, 28.488697707653046, 38.07892329990864, 61.98673501610756, 52.268505692481995, 57.7049195766449, 46.54631294310093, 49.34356704354286, 47.00928010046482, 49.18074198067188, 46.13612115383148, 43.018555641174316, 42.15966872870922, 44.27702531218529, 50.46887286007404, 53.12692902982235, 52.88530379533768, 53.391771018505096, 49.013965129852295, 45.5620251595974, 45.54471328854561, 44.86771501600742, 43.50065857172012, 46.51033267378807, 52.0152872800827, 56.00622072815895, 54.86477717757225, 54.52825963497162, 55.489106476306915, 56.42822228372097, 58.55827398598194, 58.5125358402729, 55.763991326093674, 54.93281252682209, 56.40700802206993, 58.73854771256447, 55.461056381464005, 50.70201314985752, 53.87409433722496, 57.021628841757774, 63.1706602871418, 58.247545659542084, 48.022776916623116, 26.482756845653057, 10.582037921994925, 13.087706118822098, 11.12130118533969, 11.957697104662657, 9.108900669962168, 7.784304097294807, 2.4131065886467695, 1.568853878416121, 0.18914261396275833, 0.08155147632351145, 0.23545791307697073, 7.133756205439568, 34.45015221834183, 44.197248592972755, 33.060661777853966, 23.569506369531155, 28.501601815223694, 41.72668196260929, 51.161997467279434, 53.67505721747875, 30.997788570821285, 5.066247247159481, 0.031667122239014134, 0.05490879404533189, 0.03484129898424726, 0.057560791974538006, 0.020450354204513133, 0.03480752384348307, 0.03361692601174582, 0.024157049738278147, 0.08417292745434679, 0.02514722687919857, 0.05833874827658292, 0.07865937877795659, 0.020078449160791934, 0.003854743790725479, 0.023211193656607065, 0.013993584998388542, 0.048911413323367015, 0.015077555690368172, 0.07512334937928244, 0.01822292040742468, 0.050690994394244626, 0.02204692536906805, 0.032011545554269105, 0.03239034143916797, 0.16058466746471822, 0.19430873362580314, 0.15761358314193785, 0.16473845316795632, 0.16741658211685717, 0.1069571654079482, 0.17384067177772522, 0.16722354950616136, 0.21411977213574573, 0.21815174171933904, 0.11504869020427577, 0.08774390458711423, 0.16529451473616064, 0.17842848028521985, 0.1215837309428025, 0.16188211971893907, 0.13576085184467956, 0.10665251378668472, 0.14312941348180175, 0.16277398826787248, 0.1301554698147811, 0.2104085439350456, 0.30823990528006107, 12.545155081897974, 71.52213335037231, 78.17854017019272, 69.58899468183517, 48.97052966058254, 36.20209001004696, 41.20764881372452, 51.413680762052536, 52.69586496055126, 36.78807936608791, 12.28371961042285, 0.5392742471303791, 0.3905688406666741, 0.19646786386147141, 1.208196587394923, 5.086153903976083, 14.367137365043163, 17.009101398289204, 16.67708471417427, 21.959566958248615, 29.453399442136288, 57.36073784530163, 56.90502069890499, 63.125473111867905, 68.30064341425896, 61.953862980008125, 61.1944205313921, 58.53524722158909, 63.69326904416084, 60.74910722672939, 57.21226841211319, 56.885060369968414, 60.1087199896574, 60.31578607857227, 53.499525636434555, 51.85948804020882, 53.58484245836735, 59.493487402796745, 60.19420400261879, 57.861706763505936, 53.9518191665411, 59.97972071170807, 61.405753791332245, 58.07744778692722, 55.78330188989639, 49.09627631306648, 45.884031280875206, 48.75951938331127, 47.88559287786484, 52.744175568223, 58.307719230651855, 62.197517305612564, 57.2843923419714, 59.40008841454983, 58.43375846743584, 52.65450797975063, 44.26624149084091, 47.9758570343256, 44.91601042449474, 53.636189103126526, 58.21442283689976, 62.49414458870888, 53.97707641124725, 58.57677519321442, 30.618415027856827, 41.1476082354784, 63.51225055754185, 55.52604429423809, 61.04842856526375, 49.22616094350815, 51.57679840922356, 48.171941712498665, 53.19922015070915, 49.364093542099, 46.970575377345085, 43.619649186730385, 46.52705557644367, 53.11972461640835, 56.10560439527035, 56.17487847805023, 56.55568644404411, 52.183644846081734, 49.947537034749985, 48.70143190026283, 48.2379137724638, 44.92659665644169, 47.55934238433838, 55.21504618227482, 58.35267461836338, 55.25198020040989, 55.17677083611488, 57.37320117652416, 60.32880797982216, 62.288431227207184, 61.350519955158234, 58.18552918732166, 56.902554631233215, 57.004658952355385, 61.075395718216896, 57.458981573581696, 56.19975194334984, 56.08916647732258, 58.916488364338875, 64.07870516180992, 62.021856531500816, 50.650582909584045, 36.18717961013317, 11.451366674154997, 23.523832820355892, 30.439678318798542, 19.8003214225173, 11.091175451874733, 10.23622227832675, 3.5841370141133666, 0.8594716060906649, 0.3019464039243758, 0.3631287021562457, 0.3574698558077216, 9.086987245827913, 40.634335577487946, 54.367258474230766, 33.576818481087685, 23.57547964900732, 32.28452302515507, 48.9302746206522, 58.043542206287384, 62.173559591174126, 37.02673316001892, 6.673899181187153, 0.18180207582190633, 0.18705936090555042, 0.25612599856685847, 0.134405838616658, 0.15239281172398478, 0.08996384640340693, 0.18598336551804096, 0.12832833192078397, 0.13827183429384604, 0.1854205652489327, 0.2244801982305944, 0.12033808801788837, 0.11078658804763108, 0.07114852516679093, 0.1333291901391931, 0.11068728126701899, 0.1431960435002111, 0.13625380117446184, 0.2094456963823177, 0.13488314347341657, 0.1273748799576424, 0.2140900565427728, 0.1571591809624806, 0.14520517084747553], [0.050553971668705344, 0.06303779358859174, 0.017245968338102102, 0.028671780819422565, 0.02224349431344308, 0.035786412918241695, 0.01928136400238145, 0.04696239251643419, 0.038561644469155, 0.03172143260599114, 0.04045550143928267, 0.020831432193517685, 0.011793315661634551, 0.02828014021361014, 0.08483495286782272, 0.07992725644726306, 0.04217934350890573, 0.011849698475998593, 0.027677507023327053, 0.026964891258103307, 0.08194321897462942, 0.015360749039246002, 0.14016515691764653, 21.2122705578804, 61.41048453748226, 51.2170223146677, 50.92272810637951, 29.662192538380623, 18.28733380883932, 17.237290553748608, 25.192522779107094, 36.94819897413254, 23.512938804924488, 1.659316811710596, 0.06852361562778242, 0.07550590424216352, 0.1587816938990727, 0.4143735836260021, 0.6851196836214513, 10.768149085342884, 3.5667683836072683, 5.320217069238424, 21.274171136319637, 24.41046204417944, 39.76440265774727, 51.43171079456806, 61.569737792015076, 59.62822437286377, 55.32870188355446, 52.7166498452425, 57.79209829866886, 60.973504185676575, 62.45496869087219, 57.665960267186165, 57.0125625282526, 57.90872544050217, 54.62015390396118, 48.48377197980881, 48.22129726409912, 52.24907733500004, 56.26704253256321, 57.78743214905262, 55.33815957605839, 54.03994403779507, 56.5440134704113, 54.80821721255779, 51.00702278316021, 43.87239262461662, 42.728756591677666, 41.407833471894264, 47.08599418401718, 47.65262357890606, 53.2022637873888, 52.648181319236755, 58.71278889477253, 53.68888467550278, 54.85479511320591, 51.428746953606606, 44.7879458963871, 40.70238992571831, 43.426741138100624, 40.92865638434887, 49.68847073614597, 53.371704295277596, 60.829457715153694, 51.377491503953934, 59.400567188858986, 30.252017788589, 33.34764897823334, 62.06936918199062, 50.40789373219013, 54.7095251083374, 47.048702985048294, 52.94100880622864, 51.13742038607597, 53.64460185170174, 51.23254828155041, 47.10875876247883, 38.915721997618675, 40.34353718161583, 46.693133264780045, 52.34889417886734, 53.067637011408806, 51.73522710800171, 47.898162603378296, 44.90743428468704, 41.9899508357048, 41.32223926484585, 39.26870405673981, 43.22771541774273, 49.34653848409653, 54.82695020735264, 51.92797936499119, 51.587038859725, 55.158934593200684, 50.91618485748768, 50.78677140176296, 53.82523275911808, 56.34854435920715, 54.29305985569954, 54.03561607003212, 58.662285804748535, 57.15084470808506, 56.108765825629234, 49.30476352572441, 51.792805418372154, 55.3340557962656, 59.84398439526558, 55.35481408238411, 36.47536754608154, 20.263332277536392, 12.52685146406293, 14.210619013756514, 9.001049157232046, 6.184781352058053, 13.047678116708994, 2.917488911189139, 1.4617150649428368, 0.04375578762846999, 0.09572571769240312, 0.05060742856585421, 0.6209445116110146, 17.17994023114443, 48.918635845184326, 20.958713963627815, 16.151590012013912, 24.72656138241291, 29.711426496505737, 41.58685706555843, 46.65464513003826, 34.02595438063145, 9.289635121822357, 0.21015817299485207, 0.005868286452823668, 0.13836138183251023, 0.019005884350917768, 0.02424084748781752, 0.06209480961842928, 0.07891046960139647, 0.009017200954986038, 0.03244858147809282, 0.01546281753689982, 0.0031062584048413555, 0.055145661608548835, 0.01773542957380414, 0.04606102818797808, 0.021469354505825322, 0.006106693508627359, 0.05567466818320099, 0.05837386299390346, 0.031145243992796168, 0.09936733986251056, 0.06462032702984288, 0.07570125235361047, 0.028336873692751396, 0.03194277815055102, 0.01121220475397422, 0.04349331225967035, 0.040570322817075066, 0.07263765190145932, 0.03496942706988193, 0.07830626491340809, 0.09176810388453305, 0.03220009559299797, 0.029633401973114815, 0.04400779871502891, 0.04583123700285796, 0.04287038689653855, 0.05013648762542289, 0.033031623825081624, 0.026490272975934204, 0.05264656094368547, 0.005019155869376846, 0.057396491611143574, 0.02889278683142038, 0.03987582473200746, 0.06538976347655989, 0.03311567947093863, 0.3723004600033164, 28.37441883981228, 72.2707311809063, 56.96789592504501, 59.7161440551281, 37.27027349174023, 24.95348710566759, 23.782291151583195, 24.532669186592102, 33.30189183354378, 24.573718383908272, 2.3991881730034947, 0.09126974429818802, 0.047589488749508746, 0.2547820581821725, 1.7693666252307594, 6.643910715356469, 12.394693605601788, 13.22927987203002, 11.063693426549435, 9.556594546884298, 18.405416272580624, 35.09867861866951, 55.44233478605747, 62.60209679603577, 63.190206438302994, 57.09705859422684, 55.437809228897095, 59.2988770455122, 64.18990239501, 60.44754400849342, 57.28622764348984, 57.22964867949486, 60.07826842367649, 57.274794057011604, 51.18411608040333, 50.30535623431206, 54.00346599519253, 58.49896676838398, 58.70268903672695, 55.46090058982372, 56.04866825044155, 57.970627918839455, 57.0575787127018, 53.17728392779827, 46.68019495904446, 45.05308046936989, 45.17342761158943, 48.22893865406513, 50.677508264780045, 56.060436218976974, 54.74048584699631, 60.54096579551697, 55.423316806554794, 56.728873550891876, 52.71471194922924, 48.209107518196106, 41.58560313284397, 46.01155623793602, 43.71495567262173, 50.81074811518192, 57.08438627421856, 63.1240975856781, 52.34444081783295, 58.61876294016838, 31.76781915128231, 34.959929063916206, 63.43834452331066, 53.01233857870102, 57.455481961369514, 49.36876729130745, 55.08850157260895, 53.16655710339546, 56.35492421686649, 53.401631489396095, 49.08529110252857, 41.24813564121723, 42.720507234334946, 48.741489350795746, 55.1038983464241, 54.36396785080433, 54.1426183283329, 49.78883475065231, 46.99036851525307, 43.59451733529568, 43.011343628168106, 40.648535415530205, 44.55003306269646, 52.260290533304214, 56.639297157526016, 53.094786554574966, 52.45249941945076, 56.63844220340252, 53.67160700261593, 52.45582424104214, 55.9954597055912, 58.87726306915283, 54.55427683889866, 56.15261547267437, 60.01887761056423, 59.765484407544136, 57.166112288832664, 51.25070370733738, 55.012444853782654, 57.26598992943764, 62.53182716667652, 57.82966688275337, 38.40961955487728, 20.27902353554964, 9.671016857028008, 6.305350782349706, 10.698090344667435, 12.544536665081978, 8.046049252152443, 8.356563840061426, 1.0007684491574764, 0.1270687291980721, 0.08454598282696679, 0.05787511749076657, 1.1121662403456867, 18.48755456507206, 42.256099954247475, 21.939673125743866, 18.626877889037132, 27.65005800873041, 35.5034215003252, 48.05204674601555, 54.46216598153114, 41.562975347042084, 10.937828980386257, 0.25038827676326036, 0.05086118741019163, 0.02773849671939388, 0.07494883335311897, 0.025736019015312195, 0.02562247413152363, 0.06355423931381665, 0.05479830680997111, 0.025774657078727614, 0.02161502696253592, 0.028796047881769482, 0.009281935235776473, 0.013652376110258047, 0.006419420160455047, 0.03378188317583408, 0.04154482579906471, 0.0395463148743147, 0.012694663291767938, 0.05338674563972745, 0.042252103667124175, 0.02850358789146412, 0.01881016702100169, 0.055272286845138296, 0.0300748703739373, 0.13548199727665633, 0.10659182837116532, 0.13001351180719212, 0.23971329879714176, 0.09128907724516466, 0.15311327384551987, 0.15270648786099628, 0.11909093853319064, 0.15060762001667172, 0.12691191339399666, 0.1462206811993383, 0.14693125791382045, 0.10773724425234832, 0.1574409892782569, 0.14838007860817015, 0.13523615343729034, 0.1392087512067519, 0.09508517745416611, 0.06772136883228086, 0.1657760053058155, 0.2342909452272579, 0.15613221185049042, 0.6564278388395905, 35.11529892683029, 80.18984824419022, 66.2207718193531, 67.4957250058651, 40.6176620721817, 27.49369639903307, 25.43437410145998, 36.935857236385345, 49.442673325538635, 32.15339966118336, 2.5582155771553516, 0.20714195125037804, 0.1726122689433396, 0.5096036579925567, 1.3542272639460862, 7.22604850307107, 23.39054547250271, 12.5012930855155, 15.793000403791666, 34.905193001031876, 31.30854159593582, 48.14120516180992, 58.688029423356056, 65.89522048830986, 64.68271315097809, 59.952396377921104, 57.10330545902252, 61.58753603696823, 64.94497507810593, 62.96606786549091, 57.95809619128704, 57.429354563355446, 61.05769246816635, 60.351838544011116, 53.09208869934082, 53.020257353782654, 56.615749821066856, 59.86940123140812, 61.740519627928734, 56.791068613529205, 57.67591953277588, 59.28744725883007, 59.56457398831844, 55.946480333805084, 48.740417808294296, 47.434294894337654, 46.24994404613972, 52.099179178476334, 52.743408009409904, 58.62505920231342, 59.08297263085842, 61.68902099132538, 56.67798288166523, 58.94695892930031, 56.567967385053635, 48.62250633537769, 44.00469772517681, 48.102200254797935, 44.806944876909256, 53.243932351469994, 59.161970391869545, 67.71032989025116, 55.54511547088623, 58.617573603987694, 34.18128624558449, 38.508193865418434, 64.23530995845795, 56.013683527708054, 58.93364064395428, 52.861745059490204, 58.28158423304558, 56.00768364965916, 58.16481649875641, 57.70091839134693, 51.97967939078808, 43.602987080812454, 43.533769994974136, 51.59225597977638, 57.74510242044926, 57.55825884640217, 54.00231085717678, 52.01585724949837, 50.06431996822357, 45.650682002305984, 45.77701762318611, 44.182748571038246, 47.71639935672283, 55.210361033678055, 59.2680910974741, 54.555241987109184, 53.43144088983536, 58.349266201257706, 57.23966494202614, 55.25540381669998, 58.21061544120312, 61.88984401524067, 57.23746865987778, 57.69559487700462, 62.6927637308836, 62.98950880765915, 60.94618745148182, 54.80306088924408, 56.09330825507641, 60.62018774449825, 64.55203056335449, 61.556522101163864, 41.11796222627163, 24.319798909127712, 19.581272676587105, 22.21254788339138, 17.701319754123688, 20.31752496957779, 23.590089865028858, 10.169097930192947, 2.724682269617915, 0.16434455086709931, 0.13714761415030807, 0.14639260713011026, 1.430599840823561, 24.135201014578342, 59.758948758244514, 31.018894538283348, 26.526456400752068, 36.53267987072468, 45.787524059414864, 56.81227147579193, 62.749973461031914, 50.011388808488846, 13.661116249859333, 0.3651214577257633, 0.08699414989678189, 0.1910514771589078, 0.1576156314695254, 0.09948256571078673, 0.1140412618406117, 0.23936578072607517, 0.09134317238931544, 0.16591303545283154, 0.15914688992779702, 0.09915113740134984, 0.1279007806442678, 0.1399156468687579, 0.13789951364742592, 0.10427194894873537, 0.19252989470260218, 0.1563228399027139, 0.09452009137021378, 0.08913159457733855, 0.17821266374085099, 0.1897587301209569, 0.26152826962061226, 0.22051990526961163, 0.1401529263239354], [0.04153881069214549, 0.01996700455492828, 0.03744226312846877, 0.024306395825988147, 0.05628515515127219, 0.062185002825572155, 0.02844565769919427, 0.028520779742393643, 0.04204266588203609, 0.041163744099321775, 0.09364221230498515, 0.054868899896973744, 0.012095687034161529, 0.011673110002448084, 0.05133330836542882, 0.01388541790220188, 0.014218900105333887, 0.013785938572254963, 0.03751530901354272, 0.03880566262523644, 0.03242958620830905, 0.04078003148606513, 1.0752905253320932, 41.291407719254494, 61.422389298677444, 57.99192197620869, 44.249495789408684, 30.036160871386528, 22.87264086306095, 38.439413756132126, 51.22754015028477, 39.396137818694115, 10.866548605263233, 0.26281343190930784, 0.2113594429101795, 0.04237364148139022, 0.35180759557988495, 1.8525077076628804, 4.946678588166833, 7.988822422921658, 14.007284324616194, 6.080663613975048, 13.99447426199913, 26.3864092156291, 45.09944558143616, 60.60135595500469, 60.75665362179279, 59.84547011554241, 52.52487413585186, 52.132032215595245, 60.59164747595787, 59.22989934682846, 57.47093193233013, 56.610243916511536, 56.7478421330452, 56.70846864581108, 52.503705471754074, 46.600520834326744, 47.16693364083767, 52.38758750259876, 59.05760519206524, 55.40913216769695, 56.966809183359146, 57.12066672742367, 56.14310458302498, 50.295294374227524, 45.64329519867897, 40.65847188234329, 42.76266597211361, 42.067367881536484, 49.26482766866684, 51.626473143696785, 56.281360164284706, 55.9756475687027, 56.87831953167915, 55.431231781840324, 54.73338022828102, 44.81730692088604, 42.423420175909996, 38.256863951683044, 44.06481049954891, 42.001433819532394, 47.15252861380577, 50.210023149847984, 56.81186109781265, 50.206371545791626, 57.393989861011505, 31.92546509206295, 35.239358469843864, 61.256133019924164, 51.310109719634056, 56.47133857011795, 50.90189382433891, 56.116312220692635, 54.63947966694832, 56.39631159603596, 54.4748193025589, 51.36962592601776, 42.84895174205303, 38.7468970566988, 44.30519700050354, 52.86720536649227, 53.59016977250576, 54.48232389986515, 52.07843989133835, 47.56645940244198, 43.544891998171806, 42.87477895617485, 40.18136948347092, 40.046925097703934, 49.22195456922054, 53.26993055641651, 54.425319358706474, 54.09574404358864, 55.07267162203789, 48.029722943902016, 47.900700867176056, 47.7658499032259, 52.598119005560875, 56.92623496055603, 52.406533285975456, 52.96630024909973, 57.750862911343575, 57.66117252409458, 55.262927412986755, 51.05396546423435, 51.74446441233158, 52.45034873485565, 63.12471315264702, 48.326578214764595, 37.13413059711456, 18.535802476108074, 6.6476853378117085, 10.53412914276123, 12.721232883632183, 3.9255225704982877, 2.1410043770447373, 2.787805194966495, 0.7553576678037643, 0.045146587217459455, 0.07574304268928245, 0.18207770946901292, 5.804682523012161, 41.71103060245514, 52.890095338225365, 23.558562956750393, 17.779016084969044, 24.687155596911907, 40.0680785626173, 50.71379251778126, 39.040978476405144, 9.687882252037525, 0.6944274029228836, 0.034149379862356, 0.049587725079618394, 0.021421857054519933, 0.09787193455849774, 0.021801651128043886, 0.05097945606394205, 0.051827344941557385, 0.0642441472155042, 0.06445080565754324, 0.015552087697869865, 0.014938556996639818, 0.013701956213481026, 0.07595505943754688, 0.05766415830294136, 0.05773737117124256, 0.04672915776609443, 0.04019873318611644, 0.03633294902101625, 0.0374881798052229, 0.059091838920721784, 0.01608122322068084, 0.022766923648305237, 0.08783622033661231, 0.022037364651623648, 0.04387973000120837, 0.05444354537758045, 0.04295923310564831, 0.04156983246502932, 0.022560391371371225, 0.07336607726756483, 0.12731255439575762, 0.024070936487987638, 0.06551393220433965, 0.04975954710971564, 0.005462484277813928, 0.029916670464444906, 0.016785460138635244, 0.05348837163182907, 0.01161783855422982, 0.04238946406985633, 0.053857463935855776, 0.05333776760380715, 0.02314904806553386, 0.016950849603745155, 0.004731004510176717, 1.739317481406033, 51.00999042391777, 68.56904581189156, 63.437120988965034, 53.37210327386856, 33.26981395483017, 28.2275453209877, 30.67608453333378, 39.28407043218613, 39.99479569494724, 13.254750855267048, 0.32537265156861395, 0.17692928260657936, 0.019296724603918847, 1.2092883163131773, 3.4911633655428886, 6.425772495567799, 10.735607631504536, 10.187105163931847, 10.194024592638016, 19.47010774165392, 30.01591745764017, 47.30958938598633, 62.564835995435715, 63.69386941194534, 59.078397676348686, 54.18484166264534, 54.44820553064346, 61.45893953740597, 60.58260776102543, 58.12055267393589, 58.20389360189438, 56.95317171514034, 58.04596267640591, 54.88403834402561, 49.15500596165657, 49.388203248381615, 54.498792216181755, 58.91092546284199, 57.04851619899273, 57.61563956737518, 57.49215379357338, 57.73076958954334, 53.62380176782608, 48.970385268330574, 43.50675344467163, 45.15078082680702, 45.696309953927994, 51.14538475871086, 53.036790266633034, 57.86453761160374, 56.14962883293629, 58.84666331112385, 56.24283783137798, 58.009294643998146, 47.61408984661102, 44.06652420759201, 41.031813248991966, 46.09368123114109, 43.78172188997269, 49.77116949856281, 52.716387659311295, 58.70474852621555, 53.369173631072044, 59.33865711092949, 32.70374312996864, 36.79162837564945, 62.38711953163147, 53.161594569683075, 57.30633236467838, 51.812993735075, 58.34767408668995, 57.317070588469505, 58.229059651494026, 56.74179285764694, 54.11357268691063, 43.21239463984966, 40.54264269769192, 46.52969263494015, 54.25145208835602, 55.68104177713394, 56.015537828207016, 53.3424686640501, 49.45283778011799, 45.212945491075516, 44.33587655425072, 41.87631793320179, 44.222175255417824, 51.18452645838261, 55.03535382449627, 54.30973336100578, 55.79614520072937, 55.61852753162384, 51.848046854138374, 48.5306690633297, 51.069077253341675, 54.37833867967129, 58.18476542830467, 53.57286550104618, 55.63209280371666, 59.22136500477791, 60.02311058342457, 56.31475657224655, 53.801955208182335, 53.702955320477486, 57.04222373664379, 62.93076016008854, 50.82305185496807, 33.054753094911575, 16.957426071166992, 4.90007028914988, 12.3004843108356, 15.224472060799599, 9.147585444152355, 10.33086284995079, 5.9785759169608355, 1.41230073524639, 0.16051545477239415, 0.19830298726446927, 0.11954563015024178, 7.002076646313071, 38.44845727086067, 38.110879585146904, 26.608697287738323, 26.696696765720844, 33.49469728767872, 44.86811779439449, 55.44771909713745, 47.383563816547394, 12.566759772598743, 0.9722192748449743, 0.04840651170525234, 0.09693936663097702, 0.028965905075892806, 0.0689159965259023, 0.01979446635232307, 0.040684160849195905, 0.012133293512306409, 0.033939355780603364, 0.05273012677207589, 0.039693916914984584, 0.03690157143864781, 0.012080786564183654, 0.06927249458385631, 0.04654537602618802, 0.03944093732570764, 0.010478321819391567, 0.021119851189723704, 0.01890439565613633, 0.04366813627711963, 0.04236188586219214, 0.03280858989455737, 0.041263021194026805, 0.024861798738129437, 0.11870415342855267, 0.14853042288450524, 0.14941648783860728, 0.10048102893051691, 0.13301331724505872, 0.13001680694287643, 0.11009255380486138, 0.21492253843462095, 0.12706294044619426, 0.09984822187107056, 0.1427368470467627, 0.14359171211253852, 0.09020441357279196, 0.12632955011213198, 0.13893271679989994, 0.15785660682013258, 0.2045669362996705, 0.1745715833385475, 0.23143584374338388, 0.2736304420977831, 0.124085147108417, 0.17151792766526341, 3.238031161017716, 62.65324965119362, 75.20883992314339, 73.79516378045082, 57.9134713858366, 42.34819561243057, 33.0390827357769, 53.06259848177433, 66.60601794719696, 49.49699901044369, 14.630945809185505, 0.6722171790897846, 0.5187505390495062, 0.12442554056178778, 1.1331897997297347, 3.8063996750861406, 12.660501692444086, 18.601136170327663, 33.74419569969177, 13.646411038935184, 20.24452518671751, 29.793961867690086, 49.0984345972538, 64.48177233338356, 66.62677243351936, 63.91217529773712, 56.70246496796608, 55.98196282982826, 64.37828108668327, 60.85508354008198, 56.653831377625465, 57.171720787882805, 58.95644702017307, 60.047539472579956, 56.30577005445957, 50.65496027469635, 51.412548422813416, 57.618067637085915, 62.84501776099205, 58.70553508400917, 61.23449318110943, 60.95341086387634, 60.00720463693142, 55.6137739866972, 50.24535745382309, 45.23260563611984, 48.377077504992485, 47.34234742820263, 54.56199802458286, 56.07767969369888, 59.75675627589226, 59.168323650956154, 59.411252215504646, 59.600162878632545, 61.24150760471821, 50.01856282353401, 46.89663514494896, 43.25226590037346, 47.56265580654144, 46.69058360159397, 51.92320682108402, 55.79204902052879, 62.34956234693527, 55.91987036168575, 59.294260293245316, 35.27598090469837, 41.10484153032303, 63.55083368718624, 57.642808109521866, 60.92007525265217, 55.46064980328083, 59.5304100215435, 59.65345501899719, 60.29600813984871, 60.24107068777084, 56.621103733778, 46.6712312400341, 42.71817035973072, 47.95635648071766, 56.84866212308407, 58.35714317858219, 57.095428481698036, 56.04033149778843, 51.72000892460346, 47.7492143958807, 47.67614431679249, 44.73963148891926, 45.4163371771574, 54.47377435863018, 58.28984498977661, 57.69356958568096, 56.63136698305607, 59.71164129674435, 52.97191634774208, 51.858500093221664, 52.645669654011726, 58.176424875855446, 61.98152929544449, 54.17877718806267, 55.2440120279789, 60.95351725816727, 64.50542986392975, 60.49106307327747, 56.641919016838074, 56.066774278879166, 59.764849841594696, 67.02610060572624, 52.94538617134094, 40.6029986590147, 22.770728431642056, 12.698431257158518, 18.775605708360672, 23.662489280104637, 15.09635528549552, 10.977480802685022, 7.173864953219891, 2.4436044646427035, 0.4688257008092478, 0.4857972823083401, 0.3223850321955979, 8.364474065601826, 54.302110970020294, 67.29238271713257, 33.24560925364494, 27.98808217048645, 37.76987448334694, 54.18688975274563, 64.64846178889275, 56.676177978515625, 17.39255402237177, 1.2655992759391665, 0.25357660255394876, 0.33656723680906, 0.06902921115397476, 0.20677602791693062, 0.15768049517646432, 0.16046715580159798, 0.16662536363583058, 0.15315192489651963, 0.20763374282978475, 0.20631693536415696, 0.14659519860288128, 0.08448362757917494, 0.22412810852983966, 0.12205660517793149, 0.12708045513136312, 0.11239229133934714, 0.13082764780847356, 0.1199451950378716, 0.09492468801909126, 0.13766800810117275, 0.11786846545874141, 0.18991312652360648, 0.12447017332306132], [0.022442352783400565, 0.022301463468465954, 0.04562667883874383, 0.05417053893324919, 0.11743373761419207, 0.07747487397864461, 0.024376718029088806, 0.02605191973998444, 0.03348212601849809, 0.04278137370420154, 0.06367344307363965, 0.09470102697378024, 0.03783842155826278, 0.07196576334536076, 0.037503482890315354, 0.0708460331952665, 0.055206116958288476, 0.060921934273210354, 0.06763831508578733, 0.05778856822871603, 0.010822464973898605, 0.05879457537957933, 3.2214015908539295, 44.034928902983665, 61.870100274682045, 46.13481402397156, 41.40002869069576, 24.440353140234947, 17.87372600287199, 37.28269122540951, 40.559791177511215, 28.73959444463253, 3.2206088583916426, 0.10214817462838255, 0.09213075434672646, 0.14233540452551097, 0.5966024240478873, 4.391022529453039, 5.840839957818389, 9.86801728606224, 14.061264228075743, 19.996765181422234, 26.61456037312746, 39.03247833251953, 50.01958116889, 63.13217595219612, 58.5819049179554, 58.00640679895878, 46.99343495070934, 56.688930094242096, 60.384474992752075, 61.60879589617252, 58.25334794819355, 55.648116543889046, 55.380493104457855, 58.280767276883125, 53.82114037871361, 46.24588206410408, 45.95620460808277, 51.956523433327675, 53.366129994392395, 56.16949796676636, 54.15399111807346, 52.14721240103245, 46.96384213864803, 42.26683057844639, 40.94499550759792, 43.09771679341793, 44.65920880436897, 45.25343231856823, 50.08301496505737, 54.27592657506466, 55.339812487363815, 54.0161345154047, 54.42737504839897, 54.24610197544098, 49.14786994457245, 40.07719427347183, 40.36747209727764, 39.47413623332977, 41.56836345791817, 43.62971864640713, 45.36540471017361, 47.98559211194515, 58.04081775248051, 49.09069441258907, 60.59276841580868, 35.01156449317932, 30.68824578076601, 59.46799837052822, 52.283761873841286, 55.58127053081989, 51.97390370070934, 55.52172392606735, 51.22848629951477, 58.427154421806335, 53.3656170219183, 54.62216019630432, 45.59093400835991, 40.24578742682934, 41.656393334269524, 53.57452981173992, 53.233642503619194, 53.527180552482605, 51.97668895125389, 50.33351272344589, 45.74829876422882, 43.01247216761112, 39.135950580239296, 41.45607568323612, 44.60039176046848, 50.75690880417824, 53.30651119351387, 54.84469525516033, 54.627574905753136, 50.93193121254444, 44.11928057670593, 46.68499410152435, 51.73035956919193, 55.548626482486725, 54.038956090807915, 55.70428133010864, 54.33445863425732, 56.86787769198418, 56.01538963615894, 57.057369723916054, 50.90071588754654, 54.26803059875965, 53.78831394016743, 57.99522779881954, 40.18807992339134, 23.626436814665794, 4.708443721756339, 11.756201516836882, 12.04635489732027, 6.109652258455753, 13.564838916063309, 0.20947795012034476, 0.5064428807236254, 0.16534689551917836, 0.05233004980254918, 0.09030101893586107, 0.9470640902873129, 19.351559802889824, 50.634323582053185, 29.08484011888504, 13.007346130907536, 21.229208149015903, 39.41789165139198, 47.34550505876541, 44.01850238442421, 19.4198839366436, 2.1712942142039537, 0.06511720974231139, 0.07072419481119141, 0.12797894363757223, 0.05884297082957346, 0.034341892969678156, 0.05091868159070145, 0.027970087612629868, 0.01601991811185144, 0.03796289827732835, 0.04255888154148124, 0.029924492700956762, 0.04926816742226947, 0.031237919683917426, 0.04951248243742157, 0.042891775592579506, 0.06690200811135583, 0.05542884289752692, 0.03071431037824368, 0.04410461559018586, 0.06627894545090385, 0.04282763176888693, 0.04176876514975447, 0.01224314064529608, 0.01822022270062007, 0.05569404936977662, 0.03569847212929744, 0.016641359179629944, 0.11806005830294453, 0.015574015378660988, 0.030462904142041225, 0.031164647443802096, 0.03174199751811102, 0.024571116191509645, 0.03587689185224008, 0.03006447288498748, 0.03246302738261875, 0.025454505703237373, 0.06853163824416697, 0.010916237188212108, 0.060246758002904244, 0.01773877851519501, 0.04671261158364359, 0.058968705488950945, 0.042011766563518904, 0.05141727866430301, 5.3502188343554735, 54.40249018371105, 65.94078004360199, 56.18114434182644, 50.09947948157787, 33.99033509194851, 19.609109982848167, 34.486672058701515, 43.76919016242027, 33.32443222403526, 3.7319730687886477, 0.1211659685941413, 0.07997822714969516, 0.20475941972108558, 1.2050978536717594, 7.503798874095082, 7.903925953432918, 8.564602676779032, 10.109110549092293, 8.533212561160326, 21.648304760456085, 34.0732466429472, 53.88668306171894, 63.20654176175594, 61.87378987669945, 59.03606414794922, 52.17571847140789, 57.00539991259575, 63.38903456926346, 61.523577868938446, 58.93647909164429, 54.69278320670128, 56.069080755114555, 59.904537945985794, 55.81082001328468, 48.31427067518234, 48.36968690156937, 54.46826845407486, 56.054827719926834, 58.404446840286255, 57.86735326051712, 55.16895845532417, 49.68184009194374, 44.85417254269123, 43.69721442461014, 43.54456141591072, 46.864610463380814, 45.675825253129005, 52.93099254369736, 56.90744876861572, 58.14064219594002, 54.774870201945305, 56.10990956425667, 56.010100319981575, 51.882150024175644, 41.80630289018154, 42.366582825779915, 41.097120344638824, 44.20902036130428, 45.08920133113861, 47.81054310500622, 50.6067218631506, 60.52733972668648, 52.81495817005634, 60.79424500465393, 36.19892098009586, 34.11177657544613, 59.44210276007652, 53.56958247721195, 57.37099729478359, 55.664778649806976, 57.42419824004173, 53.80792088806629, 58.316036984324455, 56.807833313941956, 56.38731747865677, 47.80463062226772, 41.22510127723217, 43.43506269156933, 56.18996746838093, 55.62702387571335, 55.22598199546337, 54.2725333571434, 52.585290893912315, 46.12986668944359, 43.96050609648228, 40.618232041597366, 42.58434534072876, 46.94725222885609, 53.60475338995457, 54.46376949548721, 55.16224041581154, 56.812643855810165, 51.537394523620605, 46.46195366978645, 48.09988617897034, 53.36240239441395, 58.226658180356026, 55.07215864956379, 55.641170516610146, 56.394046917557716, 57.72291541099548, 58.18210557103157, 58.74849557876587, 54.63759496808052, 55.055846124887466, 56.28822259604931, 60.51858879625797, 41.55982531607151, 22.3112228885293, 7.053128331899643, 8.717721160501242, 14.228506553918123, 7.802317980676889, 9.068722575902939, 5.59202978387475, 1.690453765913844, 0.244092712237034, 0.179733962577302, 0.11805783928139135, 1.21484195580706, 23.847902230918407, 50.38219951093197, 24.492607936263084, 16.272427327930927, 25.86594734340906, 45.40394604206085, 53.86716730892658, 52.771321311593056, 25.007751993834972, 2.0625447621569037, 0.07466368537279777, 0.0315617150045, 0.06011284116539173, 0.021685699830413796, 0.011825067522295285, 0.05293781308864709, 0.055727460858179256, 0.006232871137399343, 0.0355593602580484, 0.10066019822261296, 0.05706405398086645, 0.019326636866026092, 0.02154888861696236, 0.04042750762891956, 0.02733731580519816, 0.019771270526689477, 0.045592762689921074, 0.0797671009786427, 0.04006407791166566, 0.059310991418897174, 0.04842991162149701, 0.057363636733498424, 0.06060538602469023, 0.075828924018424, 0.12514563160948455, 0.18541634985012934, 0.13294763717567548, 0.16499860561452806, 0.1667791069485247, 0.12752455630106851, 0.15347192413173616, 0.08615424652816728, 0.15502908354392275, 0.09371732507133856, 0.20401914225658402, 0.12318606488406658, 0.10579270601738244, 0.1982171504641883, 0.24107733654091135, 0.16903850133530796, 0.1365592988440767, 0.18008835293585435, 0.28590532718226314, 0.282211005105637, 0.15757546643726528, 9.829234667122364, 64.87056747078896, 73.66543874144554, 60.698490142822266, 54.189374819397926, 34.566824957728386, 26.737379282712936, 52.314889803528786, 51.70975707471371, 37.183987721800804, 4.547099154442549, 0.3426628519082442, 0.3186202951474115, 0.40596594102680683, 1.4163687732070684, 10.043497569859028, 14.595516510307789, 18.270563408732414, 21.90168086439371, 26.54508490115404, 32.31903277337551, 43.07495601475239, 52.915451377630234, 66.45956620573997, 63.975738286972046, 63.157433196902275, 53.57418403029442, 61.45767420530319, 64.61442321538925, 64.02365371584892, 58.63943003118038, 56.042421385645866, 56.545689180493355, 62.86476530134678, 58.85224141180515, 51.91997319459915, 49.89323414862156, 57.23460741341114, 58.97651754319668, 63.018619045615196, 57.57913872599602, 58.15055966377258, 50.30327394604683, 46.33450850844383, 45.460912585258484, 46.061246171593666, 47.51266948878765, 49.46854993700981, 53.54059003293514, 59.50409643352032, 59.15712185204029, 56.39653958380222, 56.523916348814964, 59.82014827430248, 54.27958957850933, 44.56064589321613, 45.5612576007843, 42.75311328470707, 45.34572936594486, 48.93318146467209, 49.36070792376995, 52.48622640967369, 62.9463355243206, 55.09397327899933, 60.778529047966, 38.64100433886051, 36.38429783284664, 60.89790724217892, 55.44385850429535, 58.34903061389923, 56.0895274579525, 59.83871407806873, 55.08418880403042, 60.75772896409035, 57.4745075404644, 58.24734807014465, 49.66105900704861, 45.14526352286339, 46.799595952034, 59.27148811519146, 57.51089058816433, 57.100786194205284, 56.49287201464176, 55.38575582206249, 49.311454966664314, 47.686646953225136, 42.86912865936756, 44.76064436137676, 49.54072706401348, 56.433139219880104, 56.9250114262104, 58.36188532412052, 58.693440333008766, 54.291452541947365, 49.24212388694286, 51.41648881137371, 56.886245906353, 60.11220060288906, 58.24617773294449, 58.749992698431015, 56.93517588078976, 60.51771104335785, 61.45703963935375, 63.39253418147564, 57.90741831064224, 58.24357487261295, 57.928336188197136, 64.31737035512924, 43.9796456694603, 27.944584004580975, 8.586287163197994, 18.63269917666912, 22.80920896679163, 14.202587194740772, 22.188882753252983, 8.577611278742552, 3.4942041523754597, 0.24841778562404215, 0.2969703928101808, 0.19483046344248578, 1.8118878873065114, 29.78973649442196, 63.328344225883484, 37.16895952820778, 23.52938812226057, 31.32218286395073, 54.616487100720406, 60.458624213933945, 60.950291231274605, 30.830622240900993, 3.543993830680847, 0.22217997087864205, 0.16501454694662243, 0.1686613864148967, 0.12173053517471999, 0.14114847290329635, 0.13460342801408842, 0.23918309365399182, 0.08211645108531229, 0.1275092680589296, 0.24834518873831257, 0.13025815336732194, 0.0784347380977124, 0.11834435281343758, 0.35084669245406985, 0.14316502172732726, 0.20473773416597396, 0.17867049464257434, 0.16837680246680975, 0.07918875271570869, 0.23323347384575754, 0.19043776555918157, 0.12745574436848983, 0.12128724294598214], [0.05709567689336836, 0.06726160092512146, 0.06812736071879044, 0.1166455025668256, 0.07860673082177527, 0.008962268111645244, 0.009870595640677493, 0.09798941653571092, 0.08273788844235241, 0.1111320429481566, 0.013422949505184079, 0.028273214120417833, 0.005934214213993982, 0.0297086538921576, 0.029960817118990235, 0.06496590809547342, 0.09807768758037128, 0.029548101374530233, 0.07745476177660748, 0.10461616446264088, 0.057231541868532076, 0.2987236127955839, 21.324189752340317, 61.299978867173195, 54.20508697628975, 43.57598192989826, 29.944205805659294, 14.765142258256674, 35.015409886837006, 47.825366109609604, 46.83600179851055, 17.752751894295216, 0.46135954675264657, 0.09220321022439748, 0.05921556607063394, 0.36092027847189456, 1.9398577767424285, 6.857233643531799, 6.016794266179204, 5.953858243301511, 8.967053331434727, 12.040723599493504, 38.900063037872314, 45.22361531853676, 60.93974679708481, 60.515830144286156, 58.463822454214096, 51.70958988368511, 49.09450560808182, 58.15553739666939, 60.369184613227844, 58.83990727365017, 56.30970664322376, 56.01062469184399, 56.589010655879974, 56.841894686222076, 52.936247661709785, 45.04664361476898, 41.376139372587204, 46.209252029657364, 45.9395918995142, 45.680301412940025, 45.611133724451065, 42.65173852443695, 41.95677101612091, 42.67765313386917, 44.00635443627834, 46.40927329659462, 47.96997494995594, 47.106509283185005, 50.02710856497288, 53.13786864280701, 55.6550207734108, 54.34273838996887, 55.38149245083332, 50.568518713116646, 41.06467008590698, 39.37500715255737, 38.57655219733715, 40.83385907113552, 48.80544751882553, 47.98364281654358, 50.12244924902916, 46.75353482365608, 54.23647329211235, 51.345987394452095, 60.54035022854805, 34.98944967985153, 29.874800629913807, 59.928016886115074, 51.29255846142769, 59.56612050533295, 52.23873808979988, 53.76937575638294, 50.2822420746088, 55.087943002581596, 52.21758842468262, 56.63496159017086, 50.25003880262375, 41.301982551813126, 39.079284220933914, 51.889825612306595, 52.09584295749664, 54.64780122041702, 52.89521746337414, 51.567287519574165, 45.89747875928879, 44.65189799666405, 40.89072301983833, 40.68402551114559, 40.278636664152145, 47.851983681321144, 52.16511324048042, 54.71920698881149, 50.854278579354286, 49.25978533923626, 40.90302295982838, 42.151696756482124, 48.080161437392235, 54.439211413264275, 54.85410735011101, 56.200846284627914, 53.624295741319656, 54.42626930773258, 55.02026863396168, 56.7211751639843, 54.68991816043854, 53.310656771063805, 55.86164228618145, 60.16011983156204, 51.730378568172455, 36.966582387685776, 12.838202007114887, 16.02553367614746, 16.23031798750162, 7.245712922886014, 12.31582123786211, 7.0851425640285015, 0.9622167865745723, 0.1459153022733517, 0.20333952794317156, 0.026001765399996657, 0.49847073038108647, 6.853202534839511, 36.61768890917301, 50.145958587527275, 25.29342256486416, 26.434803418815136, 36.50926172733307, 42.91814982891083, 48.07602345943451, 30.983495637774467, 5.1646852400153875, 0.07263872059411369, 0.00941285936278291, 0.0629303973983042, 0.0182720487282495, 0.0251962420225027, 0.01323228063483839, 0.03469829825917259, 0.05419579792942386, 0.06393878313247114, 0.09217778424499556, 0.07650034502148628, 0.06342770313494839, 0.04548860226350371, 0.025249335267290007, 0.033812927213148214, 0.038201324350666255, 0.048851670435396954, 0.0621008915186394, 0.11652219473035075, 0.0528334374394035, 0.009445803298149258, 0.02219024892838206, 0.07402357558021322, 0.049715140703483485, 0.09072302636923268, 0.026379846967756748, 0.07935407353215851, 0.059761103984783404, 0.0544770644773962, 0.00736228817004303, 0.016276927563012578, 0.048944464870146476, 0.0867908014333807, 0.05089937461889349, 0.10228577622910962, 0.08125903303152882, 0.027266433280601632, 0.02982442150823772, 0.0287594822657411, 0.02821209083776921, 0.005625270196105703, 0.02169246265111724, 0.051484231516951695, 0.04743499215692282, 0.5178519466426224, 29.36494778841734, 68.44831869006157, 62.59954713284969, 47.816877365112305, 39.87649284303188, 20.117893181741238, 26.92575417459011, 47.86258891224861, 49.9839086830616, 21.47336784750223, 0.683776990044862, 0.09828973401454277, 0.10493490204680711, 0.6406791682820767, 4.267910560593009, 9.694106318056583, 7.38115475513041, 9.067009817808867, 5.923238061368465, 13.115644119679928, 33.27861428260803, 47.654831260442734, 59.17956344783306, 63.25175553560257, 59.831931442022324, 54.52072083950043, 51.726631969213486, 60.713453739881516, 60.450530648231506, 58.82622420787811, 56.940199211239815, 56.3937733322382, 58.187615275382996, 58.58804538846016, 53.24938885867596, 47.94664420187473, 44.06708277761936, 48.35775554180145, 49.22827363014221, 49.08424615859985, 47.166671454906464, 44.96435523033142, 43.134928196668625, 45.13548664748669, 44.95585888624191, 49.175308272242546, 49.18100796639919, 49.69160556793213, 52.43869476020336, 55.60431249439716, 55.82118205726147, 54.723128378391266, 57.9948478192091, 53.83981257677078, 42.65480875968933, 42.34081640839577, 41.910383105278015, 42.84371942281723, 50.22385060787201, 50.43850488960743, 51.51752918958664, 49.312355518341064, 56.43531270325184, 52.84221790730953, 60.894544422626495, 36.8295731395483, 30.697804167866707, 58.913657516241074, 52.79547281563282, 59.8991422355175, 52.995193898677826, 54.856839403510094, 50.381431952118874, 55.256289169192314, 54.52895499765873, 58.790673315525055, 51.69468708336353, 41.38579085469246, 40.325678139925, 54.41013537347317, 55.41915982961655, 56.2795552611351, 54.94551904499531, 53.17899003624916, 47.03634224832058, 45.872255712747574, 43.23976457118988, 42.851569801568985, 42.53436282277107, 49.966247230768204, 54.270538464188576, 57.07107178866863, 54.2921707034111, 50.75908988714218, 44.09846529364586, 44.436460956931114, 49.97032441198826, 56.47406302392483, 56.90350078046322, 59.04406651854515, 53.868326246738434, 56.08776435256004, 56.45454727113247, 59.67099107801914, 55.916982516646385, 55.00767230987549, 57.69322380423546, 61.28907725214958, 53.14219281077385, 35.51472209393978, 12.421822249889374, 9.283877480775118, 7.135790521278977, 7.385429050773382, 13.867114596068859, 10.982616227120161, 4.466821337118745, 0.7251669222023338, 0.30348309490364045, 0.05547321961785201, 0.39284387952648103, 9.659671615809202, 38.38688537478447, 42.510268315672874, 27.215931303799152, 33.05768273770809, 43.60081359744072, 48.29652562737465, 55.246497094631195, 37.06869050860405, 6.855222126469016, 0.11029841814888641, 0.0388436939829262, 0.07619627969688736, 0.05584485006693285, 0.06625265858019702, 0.026218184939352795, 0.04913105563900899, 0.059104589017806575, 0.07005065868725069, 0.050074080427293666, 0.044048691052012146, 0.03121931033092551, 0.012708009890047833, 0.04535061845672317, 0.04013307909190189, 0.11096782051026821, 0.011276258592261001, 0.04224575088301208, 0.06680314661934972, 0.053334799013100564, 0.035331365070305765, 0.019856508042721543, 0.07856572716264054, 0.12293068444705568, 0.24261819839011878, 0.16341723734512925, 0.16148481838172302, 0.20749782590428367, 0.28505669615697116, 0.059780384981422685, 0.16112547047669068, 0.1335937954718247, 0.17391766217770055, 0.15555066493107006, 0.18930897378595546, 0.19843133428366855, 0.1463192087248899, 0.10703552135964856, 0.21636542194755748, 0.24001800979021937, 0.17424116434995085, 0.18637700064573437, 0.21324273169739172, 0.18274323781952262, 0.7333827938418835, 36.14418871700764, 78.11510637402534, 69.92256358265877, 56.64730332791805, 42.343643456697464, 23.93565282225609, 46.92261815071106, 61.84386648237705, 55.56517079472542, 24.403289929032326, 0.7974486623425037, 0.26594577007927, 0.3187082248041406, 0.8589945535641164, 5.499130468815565, 13.520537093281746, 12.631445601582527, 14.54938318580389, 15.622371509671211, 17.834928184747696, 41.3118202239275, 49.189884290099144, 64.50812011957169, 64.7813330590725, 63.32459382712841, 56.1663631349802, 54.09441791474819, 61.998145803809166, 63.09947490692139, 59.11002717912197, 58.12963418662548, 54.56568002700806, 58.92210066318512, 60.995508804917336, 55.47989957034588, 50.40439032018185, 45.345353186130524, 51.96735665202141, 51.16893209517002, 51.014341190457344, 48.93592871725559, 47.29128576815128, 45.077421963214874, 46.20959781110287, 47.57753200829029, 50.637952387332916, 52.197099924087524, 52.07680597901344, 55.98577782511711, 57.475814670324326, 57.91125230491161, 55.02404183149338, 59.70475606620312, 56.23131304979324, 46.25070780515671, 44.802115336060524, 42.84994348883629, 45.551723912358284, 52.86770313978195, 53.471562936902046, 53.450664058327675, 51.62007048726082, 59.011939242482185, 55.673472583293915, 62.38073207437992, 38.27090799808502, 33.29919397830963, 57.934328466653824, 54.80176895856857, 60.78398555517197, 53.54744866490364, 54.727201759815216, 51.01560652256012, 56.57853841781616, 56.664626598358154, 60.80703891813755, 53.652524426579475, 45.29725916683674, 41.85486048460007, 55.66978298127651, 57.938082665205, 57.731423154473305, 58.320410549640656, 55.600831881165504, 49.1108675301075, 48.202271685004234, 46.80961221456528, 44.43685993552208, 43.91853354871273, 53.01519602537155, 57.49570660293102, 61.63475230336189, 56.71575665473938, 53.538838326931, 45.17632685601711, 46.02950267493725, 51.47462949156761, 58.56879562139511, 60.280132591724396, 61.31141625344753, 55.485435873270035, 59.17340397834778, 58.44494886696339, 60.894080847501755, 58.12714911997318, 57.469279021024704, 61.71041004359722, 64.90575358271599, 55.608070492744446, 41.22179165482521, 17.406124994158745, 22.820361368358135, 24.02613166719675, 16.003394164144993, 22.802107147872448, 17.54780799150467, 7.597549818456173, 0.7830939232371747, 0.867213987512514, 0.1574895702651702, 0.9473800077103078, 10.9116037376225, 51.21400147676468, 65.06016969680786, 37.703233659267426, 37.859967648983, 50.01101642847061, 55.9972570091486, 62.300738766789436, 46.240569949150085, 9.74332032725215, 0.2744156640255824, 0.18423416797304526, 0.15424029930727556, 0.17587872804142535, 0.19245406205300242, 0.1276762067573145, 0.1691126122022979, 0.20070840662810951, 0.18185649008955806, 0.16482377046486363, 0.19181450887117535, 0.09497428574832156, 0.11446341028204188, 0.09425360098248348, 0.17052719020284712, 0.200471795105841, 0.1349572543404065, 0.16817670461023226, 0.1895278034498915, 0.15026688517536968, 0.14616494590882212, 0.11344795930199325, 0.17260692548006773], [0.008760480941418791, 0.019200093265681062, 0.022103549381427, 0.03438903047936037, 0.030270374336396344, 0.013336996744328644, 0.02795193653582828, 0.027928223062190227, 0.04339471794082783, 0.011165891955897678, 0.011139542930322932, 0.02457388625771273, 0.018563126468507107, 0.03347924277477432, 0.033100179716711864, 0.01991259770875331, 0.06707095060846768, 0.03508692389004864, 0.021589964635495562, 0.05291890316584613, 0.030288916896097362, 1.1984484479762614, 30.274704471230507, 56.70760229229927, 50.16974151134491, 45.08549652993679, 26.47826548665762, 35.18035903573036, 50.011628195643425, 50.81034153699875, 38.57653319835663, 8.82144134491682, 0.11459325643954799, 0.10592166159767658, 0.08715265037608333, 0.3744409029604867, 2.0369512354955077, 6.903385492041707, 6.759463464841247, 10.173730831593275, 10.663044825196266, 17.65722692012787, 39.52420994639397, 47.21374332904816, 63.267957866191864, 56.284001022577286, 57.4141401797533, 47.171945571899414, 52.974131628870964, 57.441411316394806, 59.37394581735134, 53.103446289896965, 55.47516882419586, 52.19356991350651, 57.74592697620392, 54.4105077534914, 52.81180053949356, 43.215423077344894, 40.89222013950348, 39.66902777552605, 41.066892966628075, 39.044246301054955, 41.12993158400059, 43.303232565522194, 47.590766698122025, 50.14326833188534, 54.11535479128361, 51.07737600803375, 53.90057511627674, 51.82957224547863, 51.349160224199295, 53.09868894517422, 58.26478913426399, 54.40712973475456, 53.83728951215744, 43.49450670182705, 40.48241212964058, 39.626097679138184, 42.60113283991814, 49.847997575998306, 53.259925693273544, 52.07550264894962, 54.048174396157265, 50.049854144454, 55.2175198495388, 50.60167953372002, 59.75304387509823, 33.54677349328995, 26.57477080821991, 54.34797830879688, 47.39921897649765, 51.683078706264496, 50.66754899919033, 53.2564602792263, 50.41545532643795, 53.9689714461565, 54.09198224544525, 55.87982811033726, 51.09914503991604, 44.72972922027111, 38.753531500697136, 49.76278334856033, 53.66171233355999, 53.82770262658596, 52.32077568769455, 52.16834306716919, 49.55235444009304, 49.102409183979034, 41.887641325592995, 41.53543822467327, 39.63495880365372, 40.89980833232403, 44.45611350238323, 48.32167647778988, 47.068898901343346, 43.30967701971531, 37.8826904296875, 39.47970673441887, 43.5610069334507, 50.68078748881817, 53.139719143509865, 54.196294248104095, 53.674905225634575, 56.067621633410454, 52.23817192018032, 53.0317859351635, 57.00013339519501, 55.00586740672588, 53.79082940518856, 57.581262812018394, 53.93766112625599, 44.53553684055805, 25.27715753763914, 11.648038420826197, 12.91978932917118, 5.775417443364859, 6.465357346460223, 5.296171959489584, 1.5911700809374452, 1.6481892275623977, 0.09536161262076348, 0.006783463541069068, 0.1503409366705455, 2.956449408084154, 29.637410268187523, 63.69302585721016, 45.68997949361801, 18.14867164939642, 33.99505063891411, 37.470040172338486, 48.812929317355156, 38.58377180993557, 7.9164306074380875, 0.3229112148983404, 0.12330397730693221, 0.01485898113969597, 0.07418791676172987, 0.01570675591210602, 0.04108926957997028, 0.08084127810434438, 0.007595341558044311, 0.07125543153961189, 0.028932632740179542, 0.05823278072057292, 0.025507042337267194, 0.016785504667495843, 0.011696186156768817, 0.014440761442529038, 0.017045417771441862, 0.023634926583326887, 0.02153683057258604, 0.016840479256643448, 0.0911116148927249, 0.018762721520033665, 0.05181424232432619, 0.03648250662081409, 0.08810233965050429, 0.06324591406155378, 0.02065827058686409, 0.03533728369802702, 0.02471894087648252, 0.04480088740820065, 0.031219800148392096, 0.012929259883094346, 0.024200663901865482, 0.009166842974082101, 0.044075348996557295, 0.04977842363587115, 0.07204852023278363, 0.04516668457654305, 0.027685522218234837, 0.03751118638319895, 0.08550700469641015, 0.07324098085518926, 0.03175691468641162, 0.01494782549343654, 0.03620928124291822, 1.7223169561475515, 36.86487704515457, 63.16751025617123, 56.72541953623295, 51.35711319744587, 32.38859184086323, 30.5723861977458, 48.876632899045944, 53.33170764148235, 46.79064743220806, 9.871055223047733, 0.2728323661722243, 0.048706120433053, 0.24111189093673602, 1.427396375220269, 6.286395974457264, 9.206463284790516, 9.466983005404472, 6.895241104066372, 11.16412678733468, 20.824144184589386, 41.17863357067108, 51.65314771234989, 64.07280787825584, 59.77689519524574, 59.96609464287758, 51.80192492902279, 54.02881823480129, 60.920329838991165, 60.75241684913635, 55.08565552532673, 55.46492077410221, 52.78520196676254, 58.2300665974617, 58.29754717648029, 54.65042307972908, 45.285688787698746, 41.81915000081062, 42.768715247511864, 42.421961054205894, 41.27560816705227, 41.48431956768036, 44.285666048526764, 51.13645903766155, 53.59685741364956, 55.599133372306824, 54.31835509836674, 55.25535821914673, 53.74585881829262, 54.258257523179054, 54.35721941292286, 58.33025202155113, 54.8082210123539, 55.89133009314537, 45.53032346069813, 42.72597134113312, 41.61836877465248, 43.5094702988863, 52.87584990262985, 55.08609630167484, 53.050347939133644, 57.27825187146664, 51.27253733575344, 57.32672207057476, 53.193429261446, 61.30176477134228, 35.55089995265007, 28.181569688022137, 55.6570840626955, 47.92557813227177, 53.13689589500427, 50.33187501132488, 54.96215455234051, 51.3015715777874, 55.071090906858444, 53.75820055603981, 57.51868396997452, 54.40562881529331, 45.643523186445236, 39.456026405096054, 51.91505245864391, 55.718363374471664, 53.72545771300793, 53.12652625143528, 54.94742274284363, 52.96484112739563, 50.53397476673126, 42.79681473970413, 42.984836250543594, 40.89723587036133, 43.253797218203545, 46.596037074923515, 50.396414548158646, 50.86876340210438, 45.3600811958313, 39.593700617551804, 41.851041689515114, 46.57283931970596, 52.37360805273056, 55.675383880734444, 57.241264656186104, 55.65784402191639, 57.55375608801842, 54.26732763648033, 56.47603131830692, 58.87195475399494, 56.38807363808155, 55.136356204748154, 59.58508148789406, 55.496797263622284, 45.565110594034195, 26.768096834421158, 12.077968250960112, 7.778239147737622, 5.074290465563536, 11.149026397615671, 7.902220794931054, 6.067550042644143, 4.771916465833783, 0.06330121148494072, 0.07137379667256027, 0.018659783781913575, 3.0373028945177794, 31.313956305384636, 56.57416485249996, 40.42226895689964, 21.73618644475937, 40.19349463284016, 44.77924816310406, 55.38421310484409, 45.392603650689125, 10.48086455091834, 0.5129735427908599, 0.05313925794325769, 0.09558724777889438, 0.03922371812222991, 0.09982177914935164, 0.03374671650817618, 0.07678535941522568, 0.060354918605298735, 0.016370979938074015, 0.05145436378370505, 0.06371562674758025, 0.02247341166366823, 0.058537744043860584, 0.05523949505004566, 0.06355111487209797, 0.030343531543621793, 0.005246257696853718, 0.029902430505899247, 0.024469187774229795, 0.05065553828899283, 0.02738433271588292, 0.017563399742357433, 0.0322453703120118, 0.14189440553309396, 0.1248971902532503, 0.08395314041990787, 0.08089626382570714, 0.10438191296998411, 0.1473827360314317, 0.10551404440775514, 0.12854825996328145, 0.12243715624208562, 0.09919436008203775, 0.12249015300767496, 0.22265166509896517, 0.16727438662201166, 0.18308121187146753, 0.16297822730848566, 0.18905955279478803, 0.2774601022247225, 0.2518078568391502, 0.15427299833390862, 0.15494615596253425, 0.1329120437731035, 3.1282346276566386, 44.19586546719074, 72.48887747526169, 61.76679901778698, 59.20312978327274, 37.4142249673605, 45.987317338585854, 62.19752490520477, 58.966223895549774, 48.06187681853771, 11.77762096747756, 0.6104615272488445, 0.18259106785990298, 0.27301217371132225, 2.1446956414729357, 6.223787683993578, 17.12768353521824, 16.184201762080193, 19.78180691599846, 22.23556324839592, 22.622908763587475, 42.578296065330505, 54.15258139371872, 68.60804691910744, 60.89629612863064, 63.65817412734032, 52.2174858301878, 57.82822296023369, 62.040308341383934, 64.1910195350647, 53.778141885995865, 56.28482177853584, 53.25407400727272, 60.18198765814304, 59.756478890776634, 58.97253915667534, 46.430913135409355, 44.784510880708694, 44.08352829515934, 44.428967759013176, 41.98495410382748, 44.38503071665764, 46.510534062981606, 54.16038617491722, 55.08092097938061, 58.70659902691841, 54.783343747258186, 57.00594708323479, 57.61497840285301, 54.72207963466644, 56.127468422055244, 60.13665609061718, 57.629155442118645, 57.40817070007324, 48.65820161998272, 44.890149012207985, 44.51542071998119, 47.325244545936584, 56.154249384999275, 57.729375064373016, 55.333166643977165, 58.75934399664402, 54.45607490837574, 59.23239581286907, 55.3952819108963, 62.59019963443279, 38.504489064216614, 31.153504215180874, 55.09961977601051, 49.720913395285606, 51.60441912710667, 51.85541085898876, 54.74567636847496, 53.173727318644524, 56.081015914678574, 56.151110753417015, 59.60922159254551, 58.05177256464958, 47.47611925005913, 42.73768611252308, 52.37443260848522, 58.81482481956482, 56.44432581961155, 55.62121018767357, 56.19785204529762, 54.95233967900276, 54.96044464409351, 45.09794846177101, 44.51819457113743, 43.87635201215744, 44.50024053454399, 49.48597580194473, 53.15991885960102, 53.24255682528019, 47.919547855854034, 41.83352082967758, 43.75924229621887, 47.93907880783081, 53.782412856817245, 58.33074979484081, 60.94077654182911, 60.308764055371284, 60.50706021487713, 56.67559660971165, 59.06268171966076, 62.93978847563267, 60.094409957528114, 58.20103235542774, 61.326235458254814, 60.47757379710674, 47.998465821146965, 31.348572447896004, 17.987531796097755, 24.390818998217583, 13.808025866746902, 15.419033970683813, 14.104294069111347, 5.6347584910690784, 3.1325576081871986, 0.23915281402878463, 0.15977924427716061, 0.31195984629448503, 4.447880778461695, 39.652612656354904, 73.41669648885727, 51.03421792387962, 31.623673886060715, 45.29430292546749, 52.138453871011734, 60.40251262485981, 57.01135039329529, 13.953887689858675, 0.9874535480048507, 0.23657432582695037, 0.2765649830689654, 0.17505326686659828, 0.3965653938939795, 0.21682139748008922, 0.1875418162671849, 0.11475782026536763, 0.2244842503569089, 0.08244797587394714, 0.11726228665793315, 0.1575397839769721, 0.17221789166796952, 0.1176418135582935, 0.09299049532273784, 0.06129180212155916, 0.13994239387102425, 0.11165948730194941, 0.1352013912401162, 0.14288477192167193, 0.10480936034582555, 0.10978054007864557, 0.1093145455524791], [0.045565496184281074, 0.06825494332588278, 0.03927521574951243, 0.02427445007924689, 0.09574896917911246, 0.022288958280114457, 0.04618514867615886, 0.04508433587034233, 0.11862181214382872, 0.036960601864848286, 0.04610059208062012, 0.06279425040702336, 0.029091897631587926, 0.060692306360579096, 0.007008455813775072, 0.01732253200316336, 0.02935420416179113, 0.016727041984268, 0.07343626959482208, 0.024115038613672368, 0.05098292189359199, 4.335311343893409, 41.294675543904305, 56.203350350260735, 38.34208197891712, 32.794478461146355, 22.14081723242998, 33.34614805877209, 51.800773590803146, 53.00548754632473, 26.774507090449333, 2.7490762481465936, 0.03393699575099163, 0.04722565827250946, 0.13066467217868194, 1.0018460475839674, 7.138360133394599, 7.587847989052534, 4.572744453325868, 8.893814161419868, 14.052763134241104, 38.806637451052666, 55.035787001252174, 59.79062005877495, 55.90086758136749, 54.263786226511, 51.0883916169405, 47.17357188463211, 52.837289571762085, 57.66339920461178, 59.03020106256008, 54.716885313391685, 54.739034324884415, 54.54620987176895, 53.53134132921696, 55.196924954652786, 54.44130130112171, 48.50337512791157, 45.89607283473015, 41.77430100739002, 41.13274343311787, 42.288326025009155, 47.13203251361847, 50.46126946806908, 55.9664710611105, 53.599220886826515, 55.93393340706825, 56.12062118947506, 55.68982690572739, 54.47085611522198, 54.0951968729496, 53.78075994551182, 55.33069297671318, 55.63352532684803, 52.56498098373413, 38.3122231811285, 41.76615424454212, 38.60630840063095, 49.236070811748505, 52.258113250136375, 59.44008506834507, 53.30476328730583, 56.22874438762665, 51.98613904416561, 57.539605647325516, 49.80471409857273, 57.39454083144665, 32.2881518304348, 23.36674924939871, 58.872695714235306, 45.339292511343956, 53.18362198770046, 50.454323440790176, 54.34243820607662, 53.8323687762022, 56.46290682256222, 52.9939703643322, 55.906187295913696, 52.39209406077862, 46.158950328826904, 36.33826330304146, 45.55831655859947, 54.24286834895611, 51.44476309418678, 50.75025536119938, 54.714354649186134, 52.725564166903496, 51.537462919950485, 45.88602617383003, 40.69480173289776, 37.555550783872604, 37.536050230264664, 37.910873517394066, 38.41449089348316, 38.59627693891525, 37.51314125955105, 37.686408162117004, 39.263437539339066, 37.19021558761597, 43.54354307055473, 46.257137060165405, 49.53545294702053, 48.65755945444107, 52.281497195363045, 54.08780246973038, 53.725902289152145, 53.863644897937775, 51.20343804359436, 53.345557898283005, 56.516635939478874, 56.509948298335075, 50.67802503705025, 27.4942359700799, 19.64207511395216, 4.670113753527403, 3.562081572599709, 10.610276106745005, 9.081379696726799, 5.741377444937825, 2.0490744849666953, 0.29668356757611036, 0.14650829310994595, 0.1717934277257882, 0.5614429700654, 13.831520956009626, 45.47928839921951, 49.55477871000767, 27.31459490954876, 39.32738810777664, 36.25728964805603, 45.981830433011055, 47.38544091582298, 18.285992480814457, 0.5872301675844938, 0.041057995476876386, 0.04234722473483998, 0.020557130701490678, 0.094263976207003, 0.06864653012598865, 0.03491336894512642, 0.03283250189269893, 0.08857968161464669, 0.004278787491784897, 0.026296817341062706, 0.06542368704685941, 0.06838148692622781, 0.01931031703861663, 0.030701797768415418, 0.08579674657084979, 0.02877895993151469, 0.06531635764986277, 0.03240340323827695, 0.03860416210955009, 0.027302175112708937, 0.012126041801820975, 0.08304513015900739, 0.032036311022238806, 0.0769916467834264, 0.0936937693040818, 0.034868216680479236, 0.02745611509453738, 0.04139955039136112, 0.02711518172873184, 0.05775827376055531, 0.0456587544613285, 0.06372115574777126, 0.03152136072458234, 0.04808662379218731, 0.0245653274396318, 0.03528080625983421, 0.006995173689574585, 0.047711887455079705, 0.011837257297884207, 0.0360837543848902, 0.033422891501686536, 0.013284854376252042, 0.030665666308777872, 5.8575809095054865, 47.306712940335274, 63.95166277885437, 43.470226004719734, 39.151685535907745, 24.982475750148296, 33.368931636214256, 55.434902384877205, 56.888635978102684, 31.974862441420555, 3.180650915019214, 0.10442897997563705, 0.07738062864518724, 0.36216106032952666, 1.9205495878122747, 6.936573861166835, 9.920520018786192, 9.739737119525671, 6.614591013640165, 16.043457314372063, 34.956668838858604, 54.63868550956249, 60.92063382267952, 60.07355287671089, 55.9610715508461, 54.92618568241596, 48.28074887394905, 55.79004652798176, 59.34198573231697, 59.945469349622726, 54.50828030705452, 54.70639407634735, 53.060698583722115, 55.336510464549065, 58.88858646154404, 56.38001807034016, 49.44626413285732, 46.55083850026131, 43.70637193322182, 42.62135535478592, 42.86992661654949, 48.0919636040926, 52.435096353292465, 56.62189029157162, 56.59918271005154, 57.80756726861, 57.81822569668293, 58.12152162194252, 55.86601585149765, 56.706644743680954, 55.788131430745125, 56.08612284064293, 56.52363896369934, 54.16985146701336, 41.391334757208824, 43.198042809963226, 40.79694405198097, 51.36049121618271, 55.42202867567539, 59.774702712893486, 56.44177995622158, 59.46384139358997, 54.38391678035259, 59.75819639861584, 52.039419785141945, 59.594786167144775, 32.796777337789536, 24.891979806125164, 59.40953090786934, 46.37623026967049, 55.32571144402027, 51.635288670659065, 55.55077336728573, 55.41207700967789, 59.18154314160347, 54.71147060394287, 57.659553810954094, 54.75589022040367, 46.82814002037048, 39.18913632631302, 50.21293759346008, 56.47778682410717, 52.974887788295746, 51.218629628419876, 55.96917651593685, 54.84242297708988, 53.734417632222176, 47.781109884381294, 42.83265061676502, 39.896920546889305, 38.73839691281319, 40.622149631381035, 40.34272402524948, 39.69640150666237, 39.16175879538059, 39.83916364610195, 41.48734800517559, 40.905363634228706, 46.45721532404423, 48.67506131529808, 52.32274778187275, 51.86416178941727, 55.20685762166977, 56.20325155556202, 56.22704587876797, 55.92453271150589, 54.18028950691223, 55.47112964093685, 58.55626009404659, 60.23819424211979, 51.37310653924942, 30.107496343553066, 24.04600840061903, 8.799384478479624, 6.3412360567599535, 13.873036578297615, 9.84438730403781, 7.861306015402079, 4.73516721278429, 0.9746747743338346, 0.13759104738710448, 0.024446624629490543, 0.7556512020528316, 16.573430076241493, 53.456846326589584, 49.713013619184494, 30.595279969274998, 48.47404070198536, 44.1307407617569, 50.245551243424416, 54.345717430114746, 23.21920696645975, 1.0548020247370005, 0.026764897302200552, 0.05002952559152618, 0.018063217648887075, 0.03839115088339895, 0.0562327446823474, 0.05355118330044206, 0.02322927422937937, 0.027883772127097473, 0.035028702404815704, 0.02627202404255513, 0.07116188382497057, 0.0831026243395172, 0.026711959908425342, 0.04125240848225076, 0.025278907996835187, 0.05498986254679039, 0.04061332285345998, 0.05741572065744549, 0.038710263252141885, 0.006124999044914148, 0.04610887073795311, 0.0801883811072912, 0.13132524298271164, 0.15556025347905234, 0.17122002958785743, 0.11053030219045468, 0.20882264856481925, 0.12315350686549209, 0.13617679593153298, 0.11567934503545985, 0.16711014934116974, 0.13759043882600963, 0.13971280306577682, 0.16690739459590986, 0.13453696126816794, 0.27124256710521877, 0.128688896948006, 0.12791636574547738, 0.15060773876029998, 0.129207183199469, 0.1860828578355722, 0.07285976185812615, 0.10677356549422257, 8.849542737007141, 56.905092895030975, 72.7984544634819, 50.922116339206696, 43.52476067841053, 30.715836100280285, 45.04536688327789, 59.70081947743893, 59.866954162716866, 35.74589028954506, 4.164412189275026, 0.1594364462653175, 0.3677879349561408, 0.638128852006048, 2.2870186669752, 16.399585604667664, 18.164256513118744, 10.37595883011818, 13.59986923635006, 19.822348840534687, 40.543592646718025, 59.43566210567951, 64.63577806949615, 60.59326618909836, 59.67822588980198, 54.36444282531738, 51.842901930212975, 58.12149502336979, 63.13985154032707, 60.398530438542366, 53.249936029314995, 53.20779249072075, 53.5212604701519, 56.11172206699848, 61.16039715707302, 58.35844270884991, 52.488893866539, 49.74318400025368, 45.8953470736742, 44.53587882220745, 46.34439177811146, 50.63782699406147, 55.534932017326355, 59.305484890937805, 58.30530636012554, 59.765028432011604, 60.14025069773197, 59.221456199884415, 57.23125979304314, 58.38442571461201, 57.64110580086708, 58.09874564409256, 59.683196023106575, 56.78890272974968, 43.365412428975105, 45.76204262673855, 43.17886523902416, 53.79578433930874, 57.968587428331375, 63.106975704431534, 58.771826326847076, 60.82819238305092, 55.43745204806328, 60.913155823946, 53.07180918753147, 59.04002733528614, 34.754432290792465, 28.146394975483418, 59.114780724048615, 47.242587581276894, 57.145274206995964, 55.175684094429016, 59.105836004018784, 57.978767082095146, 62.53348767757416, 56.84535630047321, 58.36806379258633, 56.29291534423828, 49.530741199851036, 40.16568012535572, 49.99897487461567, 59.174190536141396, 54.63554307818413, 51.91837728023529, 57.255852073431015, 56.5909219533205, 56.44883617758751, 51.977061331272125, 45.46653248369694, 41.4949019998312, 41.15979038178921, 43.10047924518585, 42.98221439123154, 42.72198535501957, 41.50942862033844, 41.4960153400898, 44.20645169913769, 41.20536133646965, 47.878798842430115, 50.849886015057564, 54.96239013969898, 54.292911663651466, 57.52456225454807, 58.79717096686363, 59.475119188427925, 58.88897404074669, 56.92826025187969, 57.96057365834713, 61.28174364566803, 60.274668484926224, 55.28479143977165, 31.522948890924454, 26.16739846765995, 11.626010052859783, 10.561579819768667, 20.482010543346405, 19.4033757224679, 14.586173761636019, 5.321795409545302, 1.445278690662235, 0.3495477559044957, 0.46922138426452875, 1.0516924853436649, 18.968080580234528, 58.94535541534424, 58.863021433353424, 37.80158758163452, 52.04133488237858, 49.744160547852516, 60.452673733234406, 60.51206834614277, 31.269327700138092, 1.5988802234642208, 0.13563113927375525, 0.18362804112257436, 0.1705321774352342, 0.32519305183086544, 0.1565326302079484, 0.164425311377272, 0.12346726463874802, 0.17597807192942128, 0.09048539810464717, 0.0919669252471067, 0.21400427911430597, 0.1362464835983701, 0.19545837974874303, 0.15657951909815893, 0.20944643852999434, 0.12877097848104313, 0.10274047526763752, 0.1590228918939829, 0.1629039234830998, 0.18919201131211594, 0.0996202118403744, 0.13049513596342877], [0.08714335126569495, 0.02270090590172913, 0.028665305580943823, 0.0275437757227337, 0.008472268818877637, 0.0042824583397305105, 0.046869234429323114, 0.012972922286280664, 0.010309942426829366, 0.0882656492467504, 0.026080323586938903, 0.024334265326615423, 0.02353279407543596, 0.02849892534868559, 0.035622643190436065, 0.03327584978251252, 0.044174752256367356, 0.04369298338133376, 0.01677583819400752, 0.025506183301331475, 0.08533142739906907, 6.527036111801863, 52.816151306033134, 48.06611739099026, 46.89082145690918, 29.535222351551056, 37.86085680127144, 51.428686156868935, 58.58868755400181, 41.76354758441448, 14.49034670367837, 1.2919444497674704, 0.0612605205969885, 0.05029314386774786, 0.33509371744003147, 1.99123291997239, 7.458048854023218, 5.113064534962177, 9.071487877517939, 10.36672817543149, 25.47369059175253, 42.890981286764145, 58.76865729689598, 58.987559750676155, 55.407281666994095, 52.65551492571831, 49.780365005135536, 49.61726635694504, 55.37978634238243, 58.410021141171455, 56.88284508883953, 52.55239225924015, 54.10433918237686, 54.274893030524254, 54.29941691458225, 54.76543910801411, 53.74890245497227, 52.54532463848591, 51.4229978621006, 47.96732649207115, 41.86368741095066, 43.16352166235447, 49.06348027288914, 53.403595983982086, 54.40116785466671, 53.8589521497488, 55.29756635427475, 53.88031080365181, 53.867391496896744, 54.177565053105354, 57.27930821478367, 55.32267540693283, 53.465000689029694, 53.72256226837635, 46.10193058848381, 38.02479900419712, 40.826985239982605, 40.82266107201576, 51.86039999127388, 53.0184980481863, 51.78087405860424, 47.232692912220955, 59.846157878637314, 49.8551943898201, 57.8086806088686, 48.43095101416111, 59.62937191128731, 28.262927122414112, 28.636994250118732, 57.1938394010067, 47.045188173651695, 59.08863052725792, 48.92454832792282, 55.18063522875309, 49.972653687000275, 51.073184832930565, 49.27142791450024, 53.64017128944397, 46.776785776019096, 41.635874435305595, 38.56997475028038, 42.51683056354523, 53.010636270046234, 54.58011545240879, 48.03297556936741, 51.81542560458183, 53.35381865501404, 52.585667073726654, 46.93258881568909, 44.847230315208435, 37.869155555963516, 37.579193115234375, 38.12414467334747, 37.59506866335869, 39.82849381864071, 39.203548952937126, 37.836104929447174, 40.04079982638359, 39.776087030768394, 41.23765580356121, 40.69369979202747, 42.92283497750759, 41.98485150933266, 44.7729367017746, 43.54434862732887, 50.06683923304081, 47.382389679551125, 53.22582632303238, 54.132195487618446, 57.892200127243996, 53.88945311307907, 52.503139302134514, 39.07779470086098, 19.66411203145981, 11.210907977074385, 2.9854273656383157, 12.282663267105818, 6.882294248789549, 9.760708194226027, 9.686919953674078, 0.29639917658641934, 0.17148018203442916, 0.06393836010829546, 0.01849071883043507, 5.428156452253461, 25.89155226945877, 43.25794279575348, 23.420856446027756, 21.018456257879734, 33.57579633593559, 49.283458068966866, 48.16447891294956, 26.0390717536211, 2.724614585749805, 0.06759424635674804, 0.02402633341262117, 0.0459307998244185, 0.026287807668268215, 0.03339955837873276, 0.02831939054885879, 0.04579149499477353, 0.03034705117897829, 0.05001348035875708, 0.00848703013616614, 0.039496386889368296, 0.04664926556870341, 0.04046634792757686, 0.015912199087324552, 0.06487005230155773, 0.05902763943595346, 0.03406120158615522, 0.04407492968311999, 0.016901329800020903, 0.039104488387238234, 0.040591804281575605, 0.013609247125714319, 0.04324510839069262, 0.0459203763603, 0.01995424147025915, 0.06424132705433294, 0.05067175792646594, 0.011586824202822754, 0.044714282485074364, 0.05163203022675589, 0.04903200861008372, 0.03146083116007503, 0.060457386935013346, 0.03486677691398654, 0.037525725056184456, 0.021072997551527806, 0.008615842853032518, 0.03166062473610509, 0.0790780688112136, 0.03554752671334427, 0.05446903815027326, 0.004966950882590027, 0.05433328820799943, 10.021061673760414, 60.390159487724304, 56.34162873029709, 51.50292657315731, 38.54274161159992, 36.10228456556797, 45.38372352719307, 61.76661282777786, 51.147626638412476, 17.22692470997572, 1.3758281548507512, 0.13798952131764963, 0.15087562438566238, 0.735358331585303, 5.285869287326932, 6.052441578358412, 10.928613524883986, 6.34006286971271, 8.473457917571068, 26.207579411566257, 42.571718618273735, 59.99141648411751, 60.653238371014595, 59.36221584677696, 55.10661140084267, 51.88832089304924, 51.233969405293465, 57.33505882322788, 59.35507223010063, 57.777275294065475, 52.296494990587234, 56.91706225275993, 53.64120103418827, 55.232863426208496, 58.58050279319286, 55.54928384721279, 54.319871217012405, 54.23632889986038, 48.64907070994377, 44.757258743047714, 45.60729593038559, 50.609077736735344, 55.68373963236809, 57.17372328042984, 54.669771641492844, 54.838668778538704, 52.49782718718052, 53.748207092285156, 54.696108028292656, 56.60359047353268, 54.598863646388054, 55.269041284918785, 54.951853305101395, 49.05546650290489, 38.738267719745636, 42.81481817364693, 43.27621981501579, 53.41662548482418, 54.633715376257896, 55.68756602704525, 50.83763927221298, 60.73297709226608, 51.557408049702644, 60.412129908800125, 49.35953378677368, 59.30964186787605, 30.35840068012476, 29.335453771054745, 57.153892144560814, 48.7506240606308, 58.517570570111275, 51.31474167108536, 56.55154466629028, 51.74185395240784, 53.99001091718674, 52.90610007941723, 54.63090732693672, 50.9588223695755, 43.68790492415428, 40.06172150373459, 45.03731891512871, 56.348795145750046, 54.83844459056854, 48.171907514333725, 51.75621338188648, 54.233228266239166, 56.93065792322159, 48.71102258563042, 47.03067675232887, 40.372765213251114, 40.16770921647549, 39.01326656341553, 40.45150838792324, 41.108842715620995, 40.02911925315857, 38.42778258025646, 42.77877330780029, 41.43521100282669, 44.01470258831978, 43.05492728948593, 44.64066579937935, 44.08642753958702, 46.4586478471756, 44.98074375092983, 53.2610048353672, 48.823295161128044, 56.30109250545502, 55.231240913271904, 60.3126360476017, 55.56606374680996, 55.45576326549053, 39.61954303085804, 20.010634437203407, 11.044054180383682, 4.831932820379734, 8.426737524569035, 9.849422983825207, 12.76344196870923, 7.550636110827327, 1.5857551340013742, 0.03705127746798098, 0.2615741640329361, 0.1072693127207458, 6.69137111864984, 29.66870728880167, 47.42931716144085, 28.269240483641624, 26.73346359282732, 38.05110119283199, 56.12073518335819, 53.87798152863979, 33.08526165783405, 4.228992573916912, 0.049501784378662705, 0.05922158117755316, 0.050708802227745764, 0.003843599283754884, 0.07567711028968915, 0.05255705793388188, 0.06691621281788684, 0.026766424271045253, 0.07219441162305884, 0.029052788304397836, 0.022649731108685955, 0.016951183570199646, 0.0718586565926671, 0.04215866356389597, 0.046640144573757425, 0.07799869665177539, 0.027713404706446454, 0.06177494396979455, 0.03782604253501631, 0.08872797756339423, 0.03848858374112751, 0.04018137806269806, 0.17218836903339252, 0.14156216086121276, 0.16689905285602435, 0.1936714514158666, 0.10251364525174722, 0.1271173992427066, 0.08267198572866619, 0.14155937038594857, 0.19728189596207812, 0.13423695549136028, 0.14618185203289613, 0.14902093796990812, 0.121355795126874, 0.08659032508148812, 0.12457695353077725, 0.13704323850106448, 0.11877470940817147, 0.13634443224873394, 0.10652901299181394, 0.13020226964727044, 0.21213194442680106, 14.396212454885244, 69.49644684791565, 62.28843882679939, 60.398332849144936, 41.57042294740677, 47.32177533209324, 59.241488724946976, 64.76449236273766, 51.570023372769356, 21.22207783162594, 1.813698133919388, 0.2200490570976399, 0.19139388925395906, 1.4423315925523639, 4.979078024625778, 13.596074189990759, 15.890201088041067, 15.963906683027744, 13.702648971229792, 28.94011538475752, 46.19981713593006, 63.004768788814545, 62.888411432504654, 60.59249483048916, 57.11889982223511, 53.721589520573616, 53.56300123035908, 60.95591872930527, 62.42028795182705, 60.00753901898861, 53.855935111641884, 56.57585956156254, 53.8577514141798, 55.16549304127693, 60.218005925416946, 58.043610602617264, 56.614788472652435, 56.16667091846466, 51.90657511353493, 47.21869446337223, 47.287368178367615, 52.58280202746391, 58.065007254481316, 58.510521948337555, 56.09666347503662, 55.50077185034752, 55.73438711464405, 54.022765159606934, 56.48538261651993, 58.27334627509117, 57.56063371896744, 56.179795414209366, 57.099809646606445, 51.7921594530344, 41.402722746133804, 44.37955901026726, 46.22355826199055, 56.288013607263565, 57.69706539809704, 58.7993748486042, 52.108055502176285, 61.68946176767349, 53.543071299791336, 60.85565350949764, 51.19743436574936, 59.52227845788002, 32.32496425509453, 31.605068184435368, 56.70374549925327, 50.60307785868645, 60.50404317677021, 53.93039591610432, 58.56982156634331, 54.494813829660416, 55.14744780957699, 54.32520613074303, 57.35832877457142, 51.82000055909157, 46.02744318544865, 42.76404149830341, 47.24793389439583, 57.979367449879646, 57.33212158083916, 49.34844218194485, 52.714974135160446, 56.958008855581284, 58.14179353415966, 50.43587163090706, 50.38823738694191, 42.298805862665176, 42.29675777256489, 42.130953669548035, 42.164475470781326, 44.676592871546745, 44.204965978860855, 42.366719618439674, 44.87851023674011, 44.63344618678093, 46.81159570813179, 45.199653804302216, 47.96962916851044, 46.78386479616165, 49.873045831918716, 47.667454183101654, 56.02776937186718, 52.5285105407238, 57.53718137741089, 59.71908889710903, 63.03270488977432, 56.72573871910572, 55.023566856980324, 43.96200701594353, 21.70723769813776, 14.938617199659348, 8.91969932243228, 23.453561291098595, 12.13536037132144, 22.547731697559357, 17.117646373808384, 1.6259834566153586, 0.22833550698123872, 0.2920518832979724, 0.29495008871890604, 7.622596649453044, 36.772165820002556, 55.44811047613621, 31.26845944672823, 31.67190469801426, 45.99179349839687, 62.05154813826084, 60.92251852154732, 42.84337744116783, 6.685812966898084, 0.17216804903000593, 0.12679800856858492, 0.10368012328399345, 0.15407042170409113, 0.20291561319027096, 0.09919191841618158, 0.15747730998555198, 0.12163864987087436, 0.10973779237247072, 0.07963347728946246, 0.1187577735981904, 0.16895107633899897, 0.20379556284751743, 0.125781295937486, 0.2042743965284899, 0.12111562129575759, 0.10225625359453261, 0.13276095734909177, 0.11387616366846487, 0.11800078296801075, 0.15790030447533354, 0.09422069415450096], [0.015548159881291213, 0.04750989712192677, 0.03763652028283104, 0.02034380962868454, 0.04652954972698353, 0.03463300410658121, 0.027263422016403638, 0.04428746222401969, 0.030398407798202243, 0.03786211091210134, 0.04482874763198197, 0.02247386993985856, 0.07548297930043191, 0.024705567375349347, 0.03973951446823776, 0.005870451204827987, 0.11211393401026726, 0.17106008192058653, 0.054740623381803744, 0.055272884274018, 0.33182363666128367, 15.92977786436677, 55.9732498973608, 51.88746593892574, 40.16587391495705, 21.799985021352768, 46.38519398868084, 65.59594854712486, 40.36081485450268, 28.218819089233875, 9.713070150464773, 0.060021890967618674, 0.037891191968810745, 0.0811122362210881, 0.5599631869699806, 3.934635668992996, 3.2681908551603556, 8.17377844825387, 10.083953998982906, 13.461192827671766, 31.825446859002113, 51.30148038268089, 58.450059592723846, 57.00795717537403, 53.000449016690254, 50.576080307364464, 49.261977821588516, 49.66256372630596, 53.954756408929825, 54.2767359316349, 54.56931643188, 51.989296674728394, 52.51160904765129, 51.78605318069458, 51.63027673959732, 50.7863762229681, 55.32251961529255, 54.436741545796394, 53.888658955693245, 52.26668179035187, 47.64301769435406, 44.71614494919777, 50.091454312205315, 53.24624262750149, 56.9124872982502, 51.832748875021935, 50.295826345682144, 52.26298838853836, 54.593281745910645, 55.73098249733448, 57.616000548005104, 53.42888742685318, 53.11969801783562, 49.05492313206196, 41.717433258891106, 39.40645046532154, 42.39642262458801, 40.79964950680733, 52.34129838645458, 49.92170602083206, 53.024923503398895, 50.622019842267036, 51.89860314130783, 50.90433329343796, 59.989125207066536, 46.15197390317917, 57.55591817200184, 26.46766595542431, 30.55464304983616, 55.20322881639004, 49.020884558558464, 56.76813684403896, 49.64682877063751, 50.56440733373165, 44.0890683978796, 45.643591582775116, 43.471126556396484, 45.07296480238438, 40.843445956707, 40.72375997900963, 38.801097348332405, 41.29306063055992, 49.453734531998634, 54.6064518392086, 51.28284998238087, 51.38331279158592, 52.3213304579258, 53.74646298587322, 49.8928427696228, 42.93717920780182, 38.74538853764534, 39.37247268855572, 42.125766947865486, 48.207572400569916, 48.72040808200836, 49.835572242736816, 43.72098594903946, 40.428736209869385, 39.86002452671528, 43.36658276617527, 46.91859796643257, 48.95845390856266, 48.54970224201679, 46.786106675863266, 50.91095633804798, 48.3150078356266, 51.527705043554306, 53.01192820072174, 54.902296364307404, 55.53232155740261, 61.14113599061966, 52.064065262675285, 39.996083825826645, 33.26247274875641, 13.958824574947357, 6.921250708401203, 12.531170882284641, 10.533297937363386, 7.077357731759548, 3.2307559764012694, 1.290436761919409, 0.31505421618930995, 0.04025934438686818, 0.021727493876824155, 1.373808088246733, 24.326959624886513, 41.93047262728214, 33.34976926445961, 23.344638235867023, 29.54361990094185, 38.99913132190704, 48.10878910124302, 43.33838827908039, 9.831283707171679, 0.07236916513647884, 0.04142560719628818, 0.05296177703712601, 0.06978786419495009, 0.006663334879704053, 0.023242851821123622, 0.06386809356627055, 0.07784386980347335, 0.04033275392430369, 0.07661906638531946, 0.04017769701022189, 0.03141517052426934, 0.10894859253312461, 0.027528129394340795, 0.0014767849347663287, 0.0650017241423484, 0.04528078236035071, 0.0244293492869474, 0.011477063344500493, 0.03137620777124539, 0.048082541979965754, 0.028944757577846758, 0.06641176019911654, 0.03416979263420217, 0.029596474560094066, 0.030070500979491044, 0.041712261736392975, 0.020614778877643403, 0.08305513430968858, 0.04121746445889585, 0.016582456773903687, 0.040059569364530034, 0.05879292781173717, 0.035135464058839716, 0.02365415191889042, 0.058565322251524776, 0.06579526554560289, 0.03598843664804008, 0.011305639291094849, 0.029711574243265204, 0.11432571962359361, 0.07002953716437332, 0.6274406192824244, 19.924276471138, 65.38782611489296, 58.083512261509895, 47.732977867126465, 26.35481011122465, 48.1648550927639, 65.32470390200615, 48.97096663713455, 34.783063754439354, 9.658770114183426, 0.15577204758301377, 0.04123741338844411, 0.2983924368163571, 0.6101748801302165, 7.783179832622409, 8.072892911732197, 6.61085438914597, 7.981916293501854, 14.72540969029069, 32.59673707187176, 51.48176930844784, 61.35753057897091, 58.11179034411907, 53.828967958688736, 51.17724224925041, 50.97567826509476, 52.143564596772194, 56.29605397582054, 56.362892389297485, 58.24503779411316, 53.1812547147274, 53.213370591402054, 50.609541311860085, 52.59006343781948, 52.47342109680176, 57.49990917742252, 56.81683503091335, 55.28466984629631, 52.8494793176651, 49.79958437383175, 45.425601080060005, 52.662210166454315, 54.84692573547363, 58.248609602451324, 52.639270797371864, 50.0400772690773, 53.4702368080616, 55.0687350332737, 56.28403142094612, 58.35229463875294, 55.05200453102589, 54.05886322259903, 50.94116471707821, 44.49393667280674, 41.01600609719753, 43.72639685869217, 44.0401042252779, 54.28197585046291, 52.50966355204582, 55.06929740309715, 51.03467769920826, 53.70083503425121, 51.425976902246475, 60.615054219961166, 46.95004127919674, 57.867486253380775, 28.169564232230186, 32.21765801310539, 56.12895414233208, 51.42303206026554, 60.09735479950905, 51.839763298630714, 51.858199909329414, 45.602318197488785, 47.46156603097916, 45.28217397630215, 46.41603693366051, 43.084352910518646, 42.76464946568012, 39.591762721538544, 42.635441198945045, 50.84992401301861, 56.32444225251675, 52.25468963384628, 50.277150347828865, 54.65337552130222, 55.93666926026344, 51.7239835113287, 44.03203345835209, 41.442966386675835, 40.83763986825943, 44.03868310153484, 50.64943917095661, 50.80142341554165, 48.772298097610474, 45.0277928262949, 42.14613385498524, 42.91147738695145, 46.54996834695339, 49.331650882959366, 50.32191574573517, 50.368835628032684, 48.35331358015537, 52.03129202127457, 50.701477378606796, 53.54985013604164, 55.42987905442715, 58.396094888448715, 56.80016912519932, 60.33460646867752, 52.89353795349598, 43.83680373430252, 30.87637558579445, 15.243552736938, 10.934105180203915, 7.2246098052710295, 9.790168963372707, 11.441832985728979, 9.209016747772694, 3.9642458176240325, 0.6944179034326226, 0.07594679191242903, 0.010414852422400145, 1.4001279696822166, 27.76629377156496, 50.02617001533508, 36.80973060429096, 24.84581608325243, 34.60629723966122, 43.61824706196785, 54.05936099588871, 51.69653758406639, 14.225943591445684, 0.16257000155746937, 0.038691408990416676, 0.03891325177391991, 0.03114545179414563, 0.03386658449016977, 0.06291927260463126, 0.06954773489269428, 0.017334632721031085, 0.04925706118228845, 0.047661840726505034, 0.03693066362757236, 0.06624618705245666, 0.02607073689432582, 0.02849429063644493, 0.05557105323532596, 0.02495728160283761, 0.02845293074642541, 0.030752493876207154, 0.03751451491552871, 0.01495432114097639, 0.03450378877460025, 0.0371454003470717, 0.12135459284763783, 0.18316722678719088, 0.12488521198974922, 0.14907220553141087, 0.1506272572441958, 0.12465581414289773, 0.1147577608935535, 0.2105286531150341, 0.16805646184366196, 0.1448417262872681, 0.11666868726024404, 0.09069866166100837, 0.20059801958268508, 0.19127507141092792, 0.15813195845112205, 0.15548491064691916, 0.15383639285573736, 0.24852202768670395, 0.15905256295809522, 0.14874288492137566, 1.0713639110326767, 28.160860799252987, 73.94630447030067, 65.35598382353783, 53.516829907894135, 31.49875368922949, 55.885280817747116, 70.34583047032356, 49.02806617319584, 38.28909382224083, 14.35286058112979, 0.3071265056496486, 0.27483108860906214, 0.4963990399846807, 1.5316352318041027, 7.302410630509257, 13.982843086123466, 13.443732764571905, 15.465086549520493, 15.9581233933568, 35.048741698265076, 54.74028445780277, 63.02418194711208, 60.3933285176754, 56.778438091278076, 54.36047963798046, 52.79535122215748, 55.59995412826538, 59.49249565601349, 58.01005460321903, 60.07344648241997, 53.98681528866291, 52.59207732975483, 51.145456954836845, 52.33015738427639, 53.63440699875355, 59.62020680308342, 61.166146248579025, 58.389209657907486, 55.71802519261837, 51.68493680655956, 48.65216754376888, 56.40708401799202, 57.447688579559326, 58.85648958384991, 54.1292430460453, 50.1399777084589, 53.94426517188549, 56.54739148914814, 59.386074766516685, 60.63224069774151, 55.92361316084862, 56.790407449007034, 53.37500251829624, 46.64543442428112, 43.811432495713234, 47.209616750478745, 45.7404749840498, 56.67379170656204, 55.14979228377342, 56.23332694172859, 52.77265504002571, 55.390680357813835, 53.57944294810295, 62.13071309030056, 47.95567251741886, 57.85064935684204, 30.688515566289425, 34.2429531365633, 56.75810158252716, 52.423476576805115, 61.86023220419884, 54.171477779746056, 54.61478479206562, 47.91879549622536, 49.86124746501446, 48.041015937924385, 48.120800256729126, 44.240912050008774, 44.93188597261906, 43.055162876844406, 45.67171387374401, 53.66458497941494, 58.9021061360836, 53.226046711206436, 50.53779736161232, 55.11810578405857, 58.823302164673805, 54.36835661530495, 46.631367579102516, 44.44779574871063, 44.51317884027958, 47.92002283036709, 54.13969628512859, 53.44058319926262, 53.52796331048012, 48.99583250284195, 45.396984815597534, 45.16479827463627, 48.975222408771515, 52.18308247625828, 53.170873671770096, 52.96119712293148, 51.08751766383648, 55.510081350803375, 53.879277259111404, 56.606333926320076, 58.50566200911999, 60.595382675528526, 59.4774978607893, 60.516996681690216, 55.796243995428085, 45.33271886408329, 35.65331965684891, 18.98066360503435, 12.891607191413641, 22.913545668125153, 20.140420272946358, 16.02025765925646, 10.93903161585331, 6.382493767887354, 0.5970028869342059, 0.2356898639118299, 0.06132318754680455, 2.2007032111287117, 31.902924701571465, 55.3996516764164, 43.46024014055729, 32.65601769089699, 42.51381732523441, 50.2867828309536, 60.01389987766743, 62.15700387954712, 19.349350221455097, 0.6922177027445287, 0.19432641158346087, 0.11546812238520943, 0.15963142330292612, 0.0905736097774934, 0.10635177328367718, 0.16473751806188375, 0.18405254959361628, 0.24667888908879831, 0.14785092731472105, 0.08947373207774945, 0.2030013015610166, 0.1541059705778025, 0.11756555046304129, 0.1317703683162108, 0.09776600039913319, 0.08455885908915661, 0.14660784479929134, 0.14142507134238258, 0.12406112378812395, 0.10716060292907059, 0.14727724716067314], [0.05553250608500093, 0.03835591742245015, 0.014063280086702434, 0.03530465517542325, 0.03611493200878613, 0.026852056980715133, 0.016616690190858208, 0.03518040852213744, 0.06524586846353486, 0.06306757597485557, 0.060969984624534845, 0.004472239879760309, 0.025130550820904318, 0.028729204495903105, 0.06257686793105677, 0.08017471074708737, 0.005254405550658703, 0.05151604738784954, 0.006178187377372524, 0.04021340915642213, 2.4361635139212012, 28.396085277199745, 48.79511967301369, 51.17392122745514, 29.198748506605625, 24.521404691040516, 36.86349391937256, 45.954551696777344, 43.126986622810364, 31.45238857716322, 3.6517420364543796, 0.14496671879896894, 0.06816325098043308, 0.20834026741795242, 0.21485957462573424, 11.350127756595612, 4.882485782727599, 8.639295268803835, 7.0710063725709915, 18.368448056280613, 43.204061686992645, 50.409953221678734, 59.31562654674053, 51.59292094409466, 51.8652219325304, 52.48022273182869, 53.327455669641495, 51.6600177437067, 54.432455375790596, 56.9948972761631, 56.017107143998146, 53.45254875719547, 53.1259410828352, 54.885052889585495, 50.69234646856785, 46.51475943624973, 51.14106819033623, 50.59466131031513, 55.10533846914768, 51.19853250682354, 51.36980451643467, 47.01182596385479, 50.21755814552307, 52.644476518034935, 54.441544488072395, 50.54953493177891, 51.87042385339737, 53.77010531723499, 54.39953774213791, 53.27413693070412, 55.146965235471725, 53.98419342935085, 52.479325979948044, 40.489320158958435, 40.12705519795418, 39.81224209070206, 39.980812445282936, 38.14445838332176, 49.35225337743759, 50.757756158709526, 56.817515194416046, 51.62746109068394, 56.71728037297726, 50.683143362402916, 57.682690769433975, 51.193896755576134, 56.94945931434631, 24.704837948083878, 33.81483390927315, 56.105011627078056, 51.480591371655464, 56.428218483924866, 47.99384526908398, 45.90345963835716, 42.107904106378555, 41.50701954960823, 39.59297865629196, 39.75870296359062, 39.72038581967354, 39.63231034576893, 40.00924251973629, 39.25170756876469, 46.664836183190346, 54.944272711873055, 52.26845249533653, 51.226662397384644, 51.767912954092026, 53.71747814118862, 48.94928500056267, 44.23645108938217, 42.8127396851778, 45.251350030303, 50.06710521876812, 52.995330691337585, 54.9993659555912, 51.837388426065445, 50.18454551696777, 49.00075703859329, 48.49797181785107, 49.12069380283356, 52.83637002110481, 51.2497765570879, 54.55699369311333, 55.034688860177994, 53.481655195355415, 55.216535702347755, 54.06204745173454, 54.186973348259926, 56.60764865577221, 57.58641913533211, 50.33060967922211, 50.708423405885696, 51.7734644562006, 30.56272331625223, 21.474367193877697, 9.542732890695333, 2.3296003695577383, 7.728485567495227, 10.245940256863832, 10.244004260748625, 3.128779185935855, 0.10314453014871106, 0.0998342472303193, 0.08833103987853974, 0.4491516330745071, 8.03061543032527, 32.11160570383072, 31.9366554915905, 23.814593218266964, 16.640217192471027, 31.00541476160288, 42.85075284540653, 47.82243266701698, 24.329938665032387, 1.3718267320655286, 0.035704316542251036, 0.007248866204463411, 0.060633595057879575, 0.031683212000643834, 0.04092099130502902, 0.08709653659025207, 0.009963888242054963, 0.023991901471163146, 0.012648696520045632, 0.04351088631665334, 0.10482153156772256, 0.05276510048133787, 0.06530326616484672, 0.0044874404557049274, 0.042424285638844594, 0.06993561837589368, 0.043323939316906035, 0.05135815175890457, 0.015114193665795028, 0.014050666359253228, 0.048703623106121086, 0.025434849922021385, 0.0688280446047429, 0.07057293769321404, 0.028379790237522684, 0.042503825316089205, 0.08318195992615074, 0.038535821440746076, 0.07494164194213226, 0.10080821957672015, 0.06140011486422736, 0.032024685278884135, 0.023142923491832335, 0.09826484238146804, 0.05436919702333398, 0.050036037937388755, 0.04414559698489029, 0.031519052645307966, 0.037585490208584815, 0.04012142737337854, 0.03912147614755668, 2.895737453363836, 35.65205432474613, 56.13028027117252, 56.84121452271938, 34.49511520564556, 25.79552762210369, 42.576855942606926, 53.28624688088894, 44.36940975487232, 29.40641686320305, 4.711031382903457, 0.08458470809273422, 0.08062411827268079, 0.7053059816826135, 2.502680132165551, 6.126994052901864, 10.10271169245243, 4.100485844537616, 8.474644403904676, 20.202928818762302, 41.84744328260422, 54.636937603354454, 59.98173460364342, 54.763387218117714, 55.67579425871372, 54.684959426522255, 56.02070935070515, 53.83692853152752, 56.64044849574566, 59.009264186024666, 57.18148246407509, 52.4220934510231, 52.56119638681412, 53.97722080349922, 51.02738209068775, 50.020907297730446, 52.55296602845192, 52.61204905807972, 57.21900925040245, 53.031569346785545, 53.885083347558975, 49.82772946357727, 52.808289527893066, 54.16453555226326, 55.03686614334583, 51.82406634092331, 51.53700314462185, 56.39195702970028, 57.21599981188774, 54.30256314575672, 56.01472847163677, 55.23499131202698, 54.74452123045921, 43.36230419576168, 42.15024143457413, 41.26784138381481, 41.80232830345631, 40.276364386081696, 50.721019729971886, 52.33183689415455, 59.19792026281357, 52.96086274087429, 59.56504516303539, 52.4099987000227, 59.58909787237644, 52.58240304887295, 57.276997938752174, 26.50652077049017, 35.458412915468216, 57.645422369241714, 52.380120903253555, 57.31445252895355, 50.30759431421757, 47.80670911073685, 44.94666337966919, 42.9374223947525, 40.80625735223293, 41.22519627213478, 42.19115003943443, 41.948301270604134, 41.624247059226036, 40.69403037428856, 49.874295964837074, 57.429491356015205, 55.06955198943615, 50.0704338401556, 53.67920279502869, 55.324377715587616, 51.237735003232956, 45.94546638429165, 43.18331100046635, 47.16618128120899, 51.15592539310455, 55.03793768584728, 56.00821182131767, 54.80778783559799, 52.67188064754009, 50.524346083402634, 48.60658138990402, 52.64683619141579, 53.734265640378, 54.48594890534878, 55.82994818687439, 57.4191103130579, 57.47162729501724, 57.18131147325039, 57.26234592497349, 57.425083592534065, 58.02171237766743, 57.11120903491974, 52.2543590515852, 53.13715808093548, 52.73730553686619, 33.137915432453156, 17.22727619111538, 10.176808666437864, 9.00621972978115, 10.463122352957726, 9.324374757707119, 8.74322159215808, 6.623236974701285, 1.3956017000600696, 0.12879386631539091, 0.0648603227455169, 0.3451223886804655, 9.811842050403357, 35.608485862612724, 38.113881424069405, 31.055473275482655, 23.75376608222723, 36.001521572470665, 48.57617162168026, 52.90102355182171, 30.677974931895733, 2.037985729984939, 0.042119259233004414, 0.03726022914634086, 0.023180737771326676, 0.04105880070710555, 0.06382196908816695, 0.05710405202989932, 0.05896943279367406, 0.02048157635726966, 0.03886614023940638, 0.06661939085461199, 0.07119878340745345, 0.06643853688728996, 0.06004086397297215, 0.052293832995928824, 0.038053332682466134, 0.01799746707547456, 0.019738011178560555, 0.07871895839343779, 0.012137768662796589, 0.015422850101458607, 0.034269630050403066, 0.15282855631085113, 0.21373251947807148, 0.1864476382615976, 0.09605704952264205, 0.28779109474271536, 0.1402366702677682, 0.09186546623823233, 0.17996224720263854, 0.22277486161328852, 0.13182055234210566, 0.13488985248841345, 0.09069132182048634, 0.18621965049533173, 0.20500553073361516, 0.12121404492063448, 0.10189519132836722, 0.1207795694062952, 0.13739543210249394, 0.07846802342101, 0.1568148541264236, 4.355448838323355, 46.15379020571709, 63.937930315732956, 66.21894791722298, 42.16941140592098, 36.63504257798195, 49.37556512653828, 53.26988875865936, 52.205239087343216, 41.2156055867672, 5.565323866903782, 0.25287690572440624, 0.19003798544872552, 0.6413347518537194, 2.010048204101622, 20.16143884509802, 13.024849891662598, 15.694233253598213, 10.391718484461308, 21.553575843572617, 48.303399458527565, 56.78769439458847, 63.97117853164673, 56.32283113896847, 57.56438031792641, 56.421907022595406, 59.54493284225464, 55.73960803449154, 58.95086511969566, 61.31092607975006, 57.65084847807884, 51.21389888226986, 53.23445565998554, 55.389521420001984, 52.06305451691151, 48.98531846702099, 53.33246760070324, 55.08318565785885, 59.7734297811985, 54.96642932295799, 56.38192556798458, 51.496113538742065, 54.189614206552505, 56.423913314938545, 56.72663927078247, 51.35551728308201, 53.98130938410759, 59.41941797733307, 60.10885298252106, 57.567971125245094, 58.54781694710255, 58.83956529200077, 56.019326224923134, 44.822174459695816, 44.83111537992954, 43.593631982803345, 42.585876658558846, 42.062325552105904, 53.07413846254349, 55.66760189831257, 60.94413936138153, 57.45135918259621, 61.0155413299799, 54.76032078266144, 61.38900049030781, 54.60518270730972, 56.52843050658703, 28.50342571735382, 37.7407718449831, 55.83625204861164, 55.11176012456417, 60.81563025712967, 52.32066169381142, 49.81552451848984, 47.967284694314, 46.75446957349777, 42.8946328908205, 43.189937844872475, 44.37936142086983, 43.90332296490669, 43.47461476922035, 43.062751069664955, 52.037310898303986, 59.43589009344578, 56.889304742217064, 50.95597252249718, 55.17534211277962, 57.4895129352808, 53.880633786320686, 47.95823357999325, 46.344235986471176, 49.399925619363785, 53.39949980378151, 59.56085778772831, 60.09612746536732, 56.04928761720657, 55.50689332187176, 52.918221428990364, 52.08719842135906, 55.542349219322205, 56.562617272138596, 57.97415792942047, 59.453646540641785, 59.64645579457283, 60.46031892299652, 60.09642764925957, 58.695686012506485, 60.023828744888306, 60.95508277416229, 59.023661613464355, 52.80397675931454, 55.97592495381832, 50.72290062904358, 37.01452821493149, 23.579053357243538, 15.035456903278828, 8.74388275668025, 17.34638649970293, 16.465230882167816, 19.159734696149826, 8.508477788418531, 1.3960998295806348, 0.6055024371016771, 0.15089310938492417, 0.7977683795616031, 12.64559319242835, 43.978650122880936, 44.88097630441189, 34.3575169891119, 27.02591300010681, 44.249849170446396, 55.775542706251144, 60.612952932715416, 37.21397191286087, 3.745565889403224, 0.15453652013093233, 0.1463290792889893, 0.19361184211447835, 0.11725166652468033, 0.163079782796558, 0.1566267790622078, 0.11925550978048705, 0.1555776791065, 0.09809481634874828, 0.1923147906200029, 0.21456452639540657, 0.16821284720208496, 0.15070132358232513, 0.09680293762357906, 0.12195660819998011, 0.16476898512337357, 0.12303362775128335, 0.19378220953512937, 0.1513099143630825, 0.1075607689563185, 0.14073180151171982], [0.07127721357392147, 0.05960677437542472, 0.03541028876497876, 0.05847456501214765, 0.07376161971478723, 0.03338475995406043, 0.05425348506832961, 0.022470682415587362, 0.04175019661488477, 0.029144658765289932, 0.015090623055584729, 0.05957151122856885, 0.04787263664184138, 0.03599611416575499, 0.08746889434405603, 0.02919905076851137, 0.018631057100719772, 0.04178542265435681, 0.09759317646967247, 0.050686827235040255, 4.111557500436902, 35.50158239901066, 50.307050943374634, 44.03642602264881, 31.917603313922882, 27.89316326379776, 28.87161076068878, 27.650418989360332, 31.975367814302444, 22.722018845379353, 0.6818348786327988, 0.07077248636051081, 0.05969042184005957, 1.4687252137809992, 0.7917378656566143, 5.100290570408106, 7.422327445819974, 1.541911899112165, 10.645013842731714, 23.300416208803654, 42.55229786038399, 58.750053495168686, 58.713583052158356, 56.440978199243546, 54.59996558725834, 51.30754105746746, 54.02267776429653, 54.28245082497597, 56.98972575366497, 56.75072617828846, 55.40484219789505, 50.57194232940674, 54.47741076350212, 49.720913395285606, 51.58562533557415, 52.30475954711437, 48.929472863674164, 48.452283069491386, 50.11424168944359, 53.7925773113966, 53.90254721045494, 51.25675678253174, 52.05017700791359, 52.61384256184101, 54.14061203598976, 50.73690667748451, 52.52800516784191, 51.78396709263325, 50.06862513720989, 45.4077572375536, 48.39322663843632, 44.80450160801411, 42.56142117083073, 37.6779156178236, 39.8336311429739, 38.00731614232063, 39.29119125008583, 39.18559871613979, 41.47126726806164, 43.734349831938744, 44.20754984021187, 45.392637848854065, 48.604894280433655, 48.0104997754097, 54.209935516119, 49.40933011472225, 60.7646331936121, 24.585752338171005, 33.986865878105164, 55.999270901083946, 50.37487730383873, 56.33356936275959, 50.63914552330971, 50.80654174089432, 48.75460624694824, 49.864374697208405, 46.21006898581982, 42.67915025353432, 39.71517629921436, 39.36848670244217, 38.94580498337746, 41.63790352642536, 43.34024257957935, 52.282637134194374, 54.6561873704195, 49.91287909448147, 49.944261610507965, 54.0780445933342, 50.90049929916859, 46.075943782925606, 47.33360789716244, 51.84802405536175, 52.02843077480793, 52.427181378006935, 51.04133874177933, 52.7257389575243, 54.58494499325752, 51.90787084400654, 49.08961907029152, 48.74124996364117, 52.75484159588814, 53.97463694214821, 51.26560650765896, 52.13398151099682, 54.36563216149807, 51.90533638000488, 53.949303701519966, 52.629984095692635, 51.89482994377613, 52.43918113410473, 57.91762076318264, 53.61803747713566, 52.69034005701542, 46.331012696027756, 26.54799934476614, 22.50595673918724, 10.065990462899208, 9.016109649091959, 11.808298621326685, 6.968295983970165, 4.407818578183651, 1.5292291296646, 0.07807893765857443, 0.07019703989499249, 0.03796942546614446, 4.984260471537709, 38.75999495387077, 39.094472005963326, 12.638362180441618, 20.569745935499668, 34.4317802041769, 40.491626635193825, 45.25114104151726, 34.56568881869316, 7.846597479656339, 0.056825572246452793, 0.05704380448150914, 0.010293453760823468, 0.06660894141532481, 0.04333572833274957, 0.04270165962225292, 0.017080706893466413, 0.028535611563711427, 0.06427695014281198, 0.008387593479710631, 0.09337292402051389, 0.05226206165389158, 0.021276149345794693, 0.02773958767647855, 0.007668310909139109, 0.04732056782813743, 0.02173946842958685, 0.03587718128983397, 0.06605294664041139, 0.04531617167231161, 0.01612562220543623, 0.04729117878014222, 0.034959723489009775, 0.0196926974967937, 0.018450902607582975, 0.061353712080745026, 0.009586063642927911, 0.0601187338179443, 0.10601913527352735, 0.07194583668024279, 0.04599869891535491, 0.05069159182312433, 0.039650586622883566, 0.0157369483349612, 0.07706447373493575, 0.05076864530565217, 0.033929477795027196, 0.07920146570540965, 0.0018990645276062423, 0.017615982760617044, 0.03817665536189452, 5.900334790349007, 41.53625138103962, 57.22218208014965, 51.1397610604763, 38.80200169980526, 32.22000248730183, 36.22354745864868, 39.81717422604561, 39.5079430192709, 23.795083165168762, 1.0657234699465334, 0.07701192967942916, 0.3213026840239763, 1.4313174085691571, 2.8494198387488723, 10.985128842294216, 10.206280834972858, 5.374147575348616, 10.463624875992537, 23.24101399630308, 43.89570817351341, 59.85296331346035, 62.22297213971615, 58.8485936075449, 55.81259831786156, 53.5597638040781, 56.532260701060295, 55.87848678231239, 58.19999121129513, 58.73409055173397, 54.840025305747986, 51.28942742943764, 53.15480813384056, 51.47218242287636, 51.00346997380257, 51.625716984272, 49.0824830532074, 49.86244440078735, 51.0768174380064, 53.58213700354099, 54.644974172115326, 52.546384781599045, 53.73441383242607, 55.00314675271511, 54.8689379543066, 50.290844812989235, 54.50615242123604, 54.75913904607296, 51.19727857410908, 47.71031968295574, 50.33863104879856, 48.35564665496349, 44.453183859586716, 39.58916366100311, 41.471290066838264, 41.250092536211014, 41.92414216697216, 39.94984410703182, 43.0513858795166, 47.489213347435, 48.539328798651695, 48.01465295255184, 52.00609937310219, 50.2312184125185, 55.93186631798744, 51.679442301392555, 60.500547364354134, 24.582294523715973, 34.55005265772343, 56.10221117734909, 52.568389400839806, 58.385007083415985, 51.19591064751148, 53.145764619112015, 50.42036086320877, 51.58697806298733, 47.54662066698074, 45.01521550118923, 40.94620764255524, 41.77610211074352, 42.18951612710953, 42.980352491140366, 45.97516939043999, 55.61911650002003, 55.90445838868618, 49.073580130934715, 49.82201837003231, 55.81943415105343, 51.973329931497574, 48.594209253787994, 49.357033520936966, 53.66543233394623, 54.584287628531456, 55.66775009036064, 52.25277453660965, 53.99754971265793, 55.889867171645164, 53.615814596414566, 52.976628094911575, 51.232536882162094, 55.51895387470722, 57.16456197202206, 53.4012059122324, 54.64707165956497, 56.08382396399975, 53.2369939237833, 55.66328912973404, 54.650890454649925, 51.50169923901558, 52.97170735895634, 59.134383872151375, 53.59990485012531, 53.3427232503891, 45.721608996391296, 26.34691033512354, 14.54982491210103, 8.930511642247438, 7.474772706627846, 10.446611288934946, 13.425915520638227, 8.246947322040796, 3.797735902480781, 0.13398576818872243, 0.08216660542530008, 0.001023897548293462, 5.547989197075367, 33.826449885964394, 40.044345036149025, 19.70865324139595, 23.45799945294857, 38.49460959434509, 44.919399842619896, 54.530786499381065, 42.39799194037914, 10.151418428868055, 0.02664904619450681, 0.035935046544182114, 0.10506203194381669, 0.036571983655449, 0.028768165393557865, 0.04184852747130208, 0.038241455986280926, 0.023638410966668744, 0.027286564036330674, 0.03339988492371049, 0.07258660698425956, 0.0715836908784695, 0.0022866356130180066, 0.061322805340751074, 0.017953635833691806, 0.08067353046499193, 0.07750566568574868, 0.08415202115429565, 0.07535732627729885, 0.052322316623758525, 0.021034624805906788, 0.0913906549976673, 0.10491703113075346, 0.16253034118562937, 0.11821218373370357, 0.18163108499720693, 0.1189896502182819, 0.22588213003473356, 0.27585738978814334, 0.1893050700891763, 0.13608187524368986, 0.12273755535716191, 0.15513958933297545, 0.10170663386816159, 0.13424068107269704, 0.1522632921114564, 0.1516482891747728, 0.13043410173850134, 0.13495158433215693, 0.20783297979505733, 0.14233706693630666, 7.922906884923577, 50.13588912785053, 65.69738790392876, 57.57319204509258, 45.921873450279236, 39.748397916555405, 39.85101900994778, 36.686077639460564, 43.7409994751215, 28.78783855587244, 1.4841217501088977, 0.2822332992218435, 0.32923903316259384, 2.73740541189909, 2.1479936270043254, 12.516064792871475, 19.173178374767303, 7.221545744687319, 11.922454945743084, 25.866578109562397, 43.797164261341095, 62.824217677116394, 63.90637680888176, 61.403515711426735, 58.85531544685364, 55.41879504919052, 58.385675847530365, 59.138989225029945, 60.996838733553886, 60.87545804679394, 54.63685400784016, 51.07456035912037, 53.236773535609245, 50.789587050676346, 51.19482010602951, 51.72070048749447, 49.41283732652664, 47.46351532638073, 51.68444283306599, 55.63131004571915, 58.03579822182655, 54.338547214865685, 56.73748008906841, 56.244255155324936, 55.92047452926636, 51.823367178440094, 56.410082057118416, 56.762589141726494, 52.8432210534811, 49.32946600019932, 53.14578741788864, 49.7033279389143, 46.26923941075802, 40.901066064834595, 43.176672756671906, 43.969861194491386, 43.85854996740818, 42.63397827744484, 45.11090576648712, 49.880995005369186, 48.46123158931732, 50.989627316594124, 53.263220116496086, 51.52168616652489, 58.308232203125954, 53.97020637989044, 62.455158680677414, 27.805699557065964, 37.49804466962814, 56.27284862101078, 54.07163433730602, 59.77813012897968, 54.634957909584045, 55.62241092324257, 53.692570477724075, 55.78620493412018, 52.47646473348141, 47.7253744751215, 43.736040741205215, 42.92334035038948, 43.676201552152634, 43.84196385741234, 48.2669860124588, 56.128490567207336, 58.065254241228104, 51.34503364562988, 51.2786778062582, 58.24534557759762, 54.412954822182655, 50.19864276051521, 52.086286470294, 57.379729226231575, 57.138225585222244, 56.56748481094837, 53.87055292725563, 55.91830104589462, 58.223356157541275, 57.65090547502041, 55.23028336465359, 52.81241990625858, 57.96669892966747, 57.97783613204956, 54.257752150297165, 55.522001311182976, 57.42625392973423, 53.13738986849785, 57.33126662671566, 55.563050508499146, 54.58009645342827, 53.98116119205952, 59.75862197577953, 53.96284617483616, 54.87197019159794, 47.27241978049278, 31.330164335668087, 28.37682031095028, 18.04422475397587, 19.094725884497166, 22.39123709499836, 18.073549680411816, 14.125991854816675, 4.665136495605111, 0.3570692741777748, 0.248938713921234, 0.09368542756419629, 7.222469570115209, 49.44212235510349, 51.196564212441444, 20.578114986419678, 31.26185730099678, 46.30682699382305, 52.79807187616825, 61.516248062253, 50.21350376307964, 13.695823587477207, 0.3435569617431611, 0.14894109772285447, 0.12323518021730706, 0.1610189871280454, 0.11977626738371328, 0.10914767364738509, 0.12259621333214454, 0.13241441891295835, 0.2115164219867438, 0.16915167885599658, 0.23878803360275924, 0.21864109905436635, 0.079663014766993, 0.15965986240189523, 0.0919471841189079, 0.13961240532808006, 0.1603338957647793, 0.1117022053222172, 0.2626975974999368, 0.1322911778697744, 0.06659012055024505], [0.02121766439813655, 0.024101427625282668, 0.060777397302445024, 0.05842423997819424, 0.020469223309191875, 0.04128341541218106, 0.08905929455067962, 0.025565430805727374, 0.04621955093170982, 0.05031744920415804, 0.04273710088455118, 0.02323280685232021, 0.06317446008324623, 0.05817285600642208, 0.03171034491970204, 0.03552231966750696, 0.03426387469517067, 0.028618989999813493, 0.0020504176609392744, 0.29831531282979995, 7.174140913411975, 43.13261792063713, 51.96140997111797, 42.79612697660923, 23.884233981370926, 23.39422557502985, 28.64322591573, 28.874563202261925, 33.49028952419758, 10.200785379856825, 0.12931880221003667, 0.0671903695911169, 0.06430324443499558, 1.0384391527622938, 4.402689328417182, 4.988494869321585, 8.327845931053162, 1.7913700570352376, 11.683753654360771, 28.089652620255947, 41.9491296261549, 54.28189605474472, 54.94312137365341, 57.25843593478203, 56.25875137746334, 56.430087983608246, 54.76578488945961, 57.49357871711254, 56.16409845650196, 53.17747011780739, 51.06288358569145, 56.25172175467014, 53.162270933389664, 49.249218106269836, 54.21978838741779, 53.54075342416763, 54.56878826022148, 51.880538910627365, 50.21700717508793, 49.40098576247692, 53.65420773625374, 53.9195740967989, 53.00205633044243, 52.2634519636631, 52.11589068174362, 48.827737122774124, 51.67262926697731, 53.49046312272549, 50.220837369561195, 40.339391604065895, 37.842743173241615, 38.31489823758602, 37.631398513913155, 38.934595584869385, 39.1925485432148, 39.02426317334175, 39.81017120182514, 40.97499869763851, 41.13286502659321, 40.600840374827385, 41.8861898034811, 38.76734755933285, 42.90715701878071, 45.04703879356384, 53.79706107079983, 51.125287637114525, 59.32782009243965, 23.945724181830883, 34.78020250797272, 57.06612065434456, 47.731606140732765, 54.84782248735428, 49.73311834037304, 54.20393943786621, 51.542197465896606, 53.62577386200428, 50.93735732138157, 51.590492874383926, 45.73531486093998, 40.627799928188324, 37.89893835783005, 40.41442237794399, 39.20694597065449, 50.69220207631588, 55.19051469862461, 50.44384740293026, 48.9736644923687, 53.45846123993397, 51.86906732618809, 51.38728737831116, 49.95707832276821, 52.236735597252846, 52.77773156762123, 53.45871962606907, 49.56413380801678, 51.11828841269016, 51.96900196373463, 56.21392518281937, 55.08902594447136, 54.29721683263779, 48.402828723192215, 48.294420540332794, 53.12472514808178, 51.87332309782505, 50.07069982588291, 51.43380828201771, 50.47889672219753, 48.75076085329056, 50.59290200471878, 53.91524612903595, 51.48657225072384, 68.26575368642807, 59.35520902276039, 46.48510582745075, 34.11683410406113, 14.746749345213175, 15.731303114444017, 6.734807062894106, 4.694718383252621, 4.804447470232844, 6.588956639170647, 1.95723234442994, 0.04911862837616354, 0.038629001792287454, 0.06816065346356481, 0.45240176492370665, 18.9129626378417, 41.68662451207638, 36.14475108683109, 29.805693738162518, 32.001685202121735, 37.82244846224785, 49.46764938533306, 42.22565598785877, 12.998807989060879, 1.0375674557872117, 0.04479276460187975, 0.03900187904946506, 0.09371227846713737, 0.05953671563474927, 0.046368833936867304, 0.007609467411384685, 0.04451919412531424, 0.03123868409602437, 0.034359107085037977, 0.03472158314252738, 0.11152155915624462, 0.03448817027674522, 0.050715574325295165, 0.055778906535124406, 0.04768111430166755, 0.044508410719572566, 0.008282094404421514, 0.027289343379379716, 0.06642028005444445, 0.0779351984965615, 0.029612887155963108, 0.02378494245931506, 0.03404501905606594, 0.051262507477076724, 0.029748713168373797, 0.016766010303399526, 0.04546762545942329, 0.08475614420603961, 0.052223176826373674, 0.015868584923737217, 0.06313937134109437, 0.05376093278755434, 0.04562563612125814, 0.04738252973766066, 0.03312647771963384, 0.06812183914007619, 0.02573307639977429, 0.011714567299350165, 0.05050162428233307, 0.21854128019185737, 10.194931793957949, 50.39365589618683, 58.748962953686714, 48.21632333099842, 29.58849359303713, 28.090680465102196, 33.94091874361038, 32.58990503847599, 35.8442822098732, 12.12430676445365, 0.1869096845621243, 0.11884105741046369, 0.11531927724718116, 3.0239501735195518, 6.789820035919547, 7.480553621426225, 11.209472604095936, 4.16210618801415, 11.491624563932419, 29.015032164752483, 47.0012891292572, 57.46845826506615, 56.61413870751858, 59.48518864810467, 58.90320047736168, 60.1496247947216, 56.942703276872635, 58.78456324338913, 56.65921948850155, 54.07234489917755, 51.29139192402363, 54.223212003707886, 53.68429832160473, 49.96457152068615, 55.448460057377815, 55.80175369977951, 54.59434948861599, 51.32059335708618, 50.60232549905777, 50.6881058961153, 55.25853864848614, 55.411225855350494, 53.77734772861004, 54.04731184244156, 53.36791969835758, 50.38518615067005, 52.20247283577919, 55.81931255757809, 51.689629554748535, 43.13407704234123, 41.34735591709614, 40.29822461307049, 39.86819788813591, 40.7156778126955, 42.25925758481026, 40.28062015771866, 40.981116369366646, 42.20836691558361, 43.48296292126179, 41.62594936788082, 44.92044858634472, 41.44376814365387, 45.85131883621216, 46.78028538823128, 55.76887026429176, 52.53064222633839, 60.75675241649151, 25.18453560769558, 34.75151784718037, 54.90397587418556, 48.1575632840395, 56.86193861067295, 52.68831096589565, 56.561785116791725, 54.07841317355633, 55.51944024860859, 52.09066763520241, 53.458316847682, 46.42492465674877, 40.434473901987076, 40.06885752081871, 41.05146199464798, 40.993549302220345, 52.390213161706924, 56.483741104602814, 51.011453345417976, 50.10026603937149, 55.42580187320709, 53.50483775138855, 53.56952168047428, 52.543006762862206, 52.834124341607094, 54.25689719617367, 53.93793471157551, 50.74098005890846, 52.65294246375561, 54.0481173992157, 57.68584080040455, 56.41677349805832, 56.047805696725845, 50.64146339893341, 49.79709930717945, 53.50655525922775, 53.0260444432497, 50.45972675085068, 52.51732774078846, 50.495209246873856, 49.91982512176037, 52.83101610839367, 56.597347408533096, 52.27753400802612, 67.1395093202591, 57.78959423303604, 48.50277476012707, 33.95965173840523, 17.176077738404274, 11.026656813919544, 8.165161460638046, 12.53946678712964, 9.32343240827322, 7.492591850459576, 6.383771924301982, 0.8436872530728579, 0.2680426341248676, 0.062010067485971376, 0.636457297950983, 23.88212889432907, 38.124224469065666, 30.971974655985832, 33.098047971725464, 38.46051022410393, 44.14471261203289, 55.305219143629074, 48.757224306464195, 16.240680031478405, 1.1203477950766683, 0.009731819591252133, 0.03066542325541377, 0.05392122926423326, 0.06948607726371847, 0.05631983200146351, 0.04377319470222574, 0.009281355432904093, 0.04841265297727659, 0.09800895728403702, 0.06155326816951856, 0.0494560829247348, 0.06516236942843534, 0.02717266106628813, 0.058454890677239746, 0.044870263373013586, 0.03779790400585625, 0.0322434444387909, 0.0412545236031292, 0.022493330907309428, 0.051638832010212354, 0.12257884707651101, 0.12270015111425892, 0.07006711210124195, 0.16492681024828926, 0.19329199130879715, 0.12417758902302012, 0.19919724552892148, 0.15491307101910934, 0.1310825755354017, 0.11045562729123048, 0.09469810291193426, 0.1365865653497167, 0.16435041383374482, 0.1706480563734658, 0.17269185686018318, 0.10687664238503203, 0.1238298557291273, 0.18579097115434706, 0.15728417347418144, 0.5283738789148629, 14.860363248735666, 59.3045349419117, 66.81877613067627, 55.82096926867962, 35.344464629888535, 35.242702290415764, 38.55493515729904, 38.310441076755524, 44.62421268224716, 15.101421363651752, 0.2927452273434028, 0.33521358913276345, 0.32021920778788626, 2.3242196207866073, 11.533983740955591, 13.652085084468126, 18.746193386614323, 6.955021871253848, 15.364567693322897, 30.823377929627895, 46.06278508901596, 58.33196572959423, 57.98049598932266, 61.184658855199814, 59.85713168978691, 61.204315200448036, 58.46140198409557, 60.65719775855541, 59.52633284032345, 55.163927525281906, 51.82627022266388, 54.643978625535965, 52.47751347720623, 51.935255974531174, 56.98163218796253, 55.649298280477524, 56.60360187292099, 51.9886165112257, 49.89991419017315, 50.02139367163181, 56.580392718315125, 58.55350524187088, 55.73200084269047, 54.36130799353123, 53.513527885079384, 50.04701189696789, 54.79962207376957, 57.45115779340267, 54.42145876586437, 46.2163120508194, 43.03061239421368, 42.168788239359856, 42.29128606617451, 42.991618886590004, 44.23901975154877, 42.34168656170368, 43.33492286503315, 45.160284116864204, 45.048627108335495, 44.21085186302662, 46.4790565520525, 42.89614900946617, 48.144955560564995, 47.57309004664421, 57.62852467596531, 53.96321475505829, 61.89457096159458, 27.91527807712555, 37.154353111982346, 55.03479525446892, 49.514345079660416, 58.1979963183403, 53.56376498937607, 58.71260650455952, 57.43352293968201, 58.63517425954342, 54.54756639897823, 57.58207596838474, 51.07262246310711, 44.50150586664677, 41.906773298978806, 44.37944881618023, 43.30080069601536, 53.268646225333214, 60.33393770456314, 51.94441348314285, 51.71682469546795, 56.989866346120834, 56.054329946637154, 55.50376608967781, 55.51771894097328, 55.10284200310707, 56.63052722811699, 56.316774263978004, 50.61016447842121, 53.2381072640419, 56.10138662159443, 58.90242911875248, 58.58881674706936, 56.57322250306606, 51.273517683148384, 48.01926590502262, 54.38020057976246, 52.574332281947136, 51.44149526953697, 52.377453446388245, 51.391676142811775, 49.565125554800034, 53.42683933675289, 58.741659745574, 56.105361208319664, 66.85158357024193, 61.94279797375202, 50.07081761956215, 34.97023031115532, 17.912470623850822, 21.572605222463608, 12.928298972547054, 16.108897402882576, 14.752723574638367, 16.47535163909197, 7.629776364192367, 1.2544600549153984, 0.4367489798460156, 0.255650756880641, 0.9397847496438771, 29.271869882941246, 53.12152951955795, 47.19604007899761, 40.98848417401314, 43.53543430566788, 52.154686599969864, 61.41886688768864, 59.39467370510101, 21.353421583771706, 1.4806993212550879, 0.127917775826063, 0.09707964738481678, 0.16738679230911657, 0.10721187049057335, 0.157422554329969, 0.1700686468393542, 0.12693993689026684, 0.15633556031389162, 0.14840577176073566, 0.1214982577948831, 0.17286566784605384, 0.09636087735998444, 0.17774910345906392, 0.20951648242771626, 0.10948739916784689, 0.18603671109303832, 0.11974370194366202, 0.11584796840907075, 0.16608727688435465, 0.1105073252983857], [0.012891119986306876, 0.08532115607522428, 0.04308432951802388, 0.024317821189470123, 0.08821024792268872, 0.0448213706840761, 0.07100809598341584, 0.11840465973364189, 0.025448026754020248, 0.012889439949503867, 0.02851722114428412, 0.04426353167218622, 0.034853091710829176, 0.021705841718357988, 0.020495224453043193, 0.09477019513724372, 0.07794210789143108, 0.037945988442515954, 0.08778478208114393, 1.2341415951959789, 13.055425900965929, 51.34773150086403, 50.94918608665466, 44.423758238554, 24.686329141259193, 16.90904326736927, 25.429964438080788, 39.15641628205776, 36.122533679008484, 4.893886595964432, 0.03807178247370757, 0.06491380190709606, 0.7814794848673046, 2.9784181667491794, 5.305533232167363, 12.889819387346506, 6.055612983182073, 5.924323853105307, 11.30833949893713, 22.900941744446754, 42.06216216087341, 53.023319989442825, 52.56720386445522, 53.09063337743282, 53.972463458776474, 52.81536094844341, 55.020025447010994, 52.90234588086605, 54.37412470579147, 53.14080208539963, 55.687775015830994, 49.79355029761791, 48.039678409695625, 54.18519124388695, 53.48310671746731, 51.48630626499653, 52.51413971185684, 53.73937636613846, 52.44898460805416, 50.954874381423, 49.95719611644745, 51.15839526057243, 54.269406124949455, 52.58666642010212, 51.13305062055588, 49.074815064668655, 51.317895501852036, 50.983110666275024, 50.27279198169708, 41.135589480400085, 39.374254792928696, 39.227628260850906, 37.714819237589836, 38.02045963704586, 39.808552488684654, 43.33835028111935, 47.9913792014122, 46.30509428679943, 50.37766635417938, 49.29715633392334, 49.90282863378525, 50.062051489949226, 51.11829221248627, 48.9367950707674, 52.330529764294624, 48.46067301928997, 58.21037985384464, 20.360198579728603, 31.48687932640314, 52.28276252746582, 47.062500044703484, 54.52447883784771, 50.217740535736084, 53.13336968421936, 51.655765771865845, 51.45450957119465, 50.61451904475689, 53.147136345505714, 52.087756991386414, 45.82247078418732, 36.92196898162365, 39.05444875359535, 37.352577075362206, 46.446537896990776, 52.639692574739456, 55.227718502283096, 49.15449298918247, 50.14427147805691, 51.93213254213333, 51.8827959895134, 53.17025430500507, 53.98316368460655, 51.890262588858604, 49.9874272942543, 47.759055867791176, 49.19600956141949, 51.9387099891901, 48.389461040496826, 51.748051419854164, 46.905207484960556, 47.58607015013695, 46.69898875057697, 49.95130643248558, 51.27735547721386, 50.36220118403435, 47.205037996172905, 49.76285174489021, 51.094418093562126, 52.043553963303566, 49.39519487321377, 49.89705674350262, 46.96806751191616, 62.826858535408974, 59.53624650835991, 42.20056973397732, 24.284675493836403, 8.73042007908225, 8.157217986881733, 12.300282921642065, 14.365336261689663, 4.838961493223906, 5.825829338282347, 0.19358442717930302, 0.1414964214200154, 0.06888457399327308, 0.4517064616084099, 11.530114598572254, 40.39560578763485, 34.54132832586765, 19.245093315839767, 27.99196556210518, 39.15103957056999, 42.58308760821819, 50.37773855030537, 17.53656629472971, 0.9638181037735194, 0.14673797297291458, 0.003577183806555695, 0.03175282916345168, 0.050550795276649296, 0.029388326256594155, 0.03271796624176204, 0.09088942329981364, 0.026315886825614143, 0.038062019521021284, 0.03231742914067581, 0.049282253385172226, 0.05609484622254968, 0.016659586326568387, 0.022453952551586553, 0.059713068476412445, 0.0579347564780619, 0.07108680816600099, 0.05348728438548278, 0.023090867398423143, 0.04058039005030878, 0.023971815244294703, 0.05175035825232044, 0.04912421303743031, 0.038822657807031646, 0.021901156433159485, 0.0498501856054645, 0.03937572480936069, 0.043825545799336396, 0.05137974825629499, 0.028187961761432234, 0.0514827249571681, 0.0394621256418759, 0.04156234048423357, 0.033529797874507494, 0.036547578129102476, 0.06497557827970013, 0.023921727697597817, 0.03492376272333786, 0.05495252138643991, 1.0652125161141157, 16.56364180147648, 56.22086741030216, 55.49339644610882, 50.39753928780556, 30.20929478108883, 24.40628606826067, 32.58453972637653, 37.78458349406719, 36.189189702272415, 6.8162124697119, 0.09355334012070671, 0.031068880707607605, 1.0716978181153536, 3.4332245495170355, 9.429054390639067, 13.636921048164368, 12.324838154017925, 7.459387332201004, 13.42141181230545, 25.626066215336323, 41.90836921334267, 53.617030531167984, 55.82199901342392, 54.86401341855526, 53.222923278808594, 53.48057605326176, 56.882024332880974, 54.63070213794708, 53.87437932193279, 53.26097443699837, 54.868348985910416, 52.040396332740784, 49.46258805692196, 56.53821498155594, 56.90203785896301, 53.35341587662697, 54.15417730808258, 56.487848684191704, 51.4460664242506, 50.57188153266907, 51.75845146179199, 52.58361138403416, 55.33524893224239, 54.30001728236675, 52.36831493675709, 49.99691918492317, 52.49610207974911, 54.7016329318285, 51.82451851665974, 43.593837171792984, 41.20338924229145, 40.08534863591194, 40.51631011068821, 39.75505515933037, 41.321061328053474, 45.05606330931187, 50.17724230885506, 49.13474164903164, 51.54628984630108, 50.118938237428665, 52.4386415630579, 50.71592800319195, 54.10238228738308, 50.46748973429203, 53.13609793782234, 51.705425307154655, 59.37153294682503, 20.430344715714455, 33.52479547262192, 53.317902982234955, 46.992655992507935, 52.67255321145058, 49.52025756239891, 53.31541791558266, 51.72097027301788, 53.71464729309082, 53.11947762966156, 55.513683557510376, 53.46034973859787, 46.91755302250385, 39.447195678949356, 41.084128841757774, 39.197252690792084, 47.849848195910454, 55.401031002402306, 55.44890843331814, 50.751478895545006, 51.612508893013, 53.371882885694504, 54.158896654844284, 55.79596661031246, 55.830673947930336, 53.66075478494167, 51.109731271862984, 49.14274021983147, 49.33124050498009, 52.287432476878166, 50.34705899655819, 53.39004211127758, 48.14171053469181, 48.74889135360718, 47.18147166073322, 50.33132404088974, 51.55769683420658, 51.21098443865776, 47.96218916773796, 50.076593309640884, 51.31350673735142, 52.42305099964142, 53.512646332383156, 53.50567750632763, 49.34127576649189, 60.118523463606834, 60.28774358332157, 42.678720876574516, 23.552920259535313, 10.69362748414278, 6.252488968893886, 7.205931432545185, 9.230118915438652, 6.2166450172662735, 5.1849818509072065, 1.4185250387527049, 0.34989285457413644, 0.157085441169329, 0.46445741958450526, 12.750118933618069, 45.13586662709713, 32.673576548695564, 27.296627573668957, 33.53451535105705, 45.5545661598444, 50.29410503804684, 57.19867654144764, 25.426516123116016, 1.9206800870597363, 0.14039361965842545, 0.11039901626645587, 0.025974816162488423, 0.029381739695963915, 0.09225326066371053, 0.06027333060046658, 0.080845389602473, 0.002746550558185845, 0.04628606591722928, 0.03975638348492794, 0.013298725116328569, 0.024621034899610095, 0.047638685718993656, 0.011352286055625882, 0.04748501662106719, 0.06715833107591607, 0.05693321334547363, 0.04738741678011138, 0.1012153024203144, 0.03268255095463246, 0.07737994586932473, 0.1412386290030554, 0.10634055943228304, 0.14523939869832247, 0.1493458799086511, 0.13936173752881587, 0.1522664091316983, 0.24799050152068958, 0.1525820593815297, 0.14385262154974043, 0.12506035884143785, 0.20567401283187792, 0.14020478760357946, 0.13446768920402974, 0.09078944858629256, 0.16308052494423464, 0.18919999682111666, 0.18023604032350704, 0.20798014767933637, 1.5342333423905075, 21.92153859883547, 64.42489698529243, 63.534399569034576, 58.227703124284744, 36.46484971046448, 28.420603461563587, 36.167150884866714, 50.47548070549965, 46.542904525995255, 8.076939694583416, 0.3698402998270467, 0.1907699360162951, 2.124887304380536, 5.277804220095277, 9.35728669166565, 22.38463304936886, 14.150427393615246, 11.497106719762087, 14.805196858942509, 25.149949863553047, 44.684781432151794, 54.88910347223282, 57.198216766119, 56.61419190466404, 54.99946855008602, 51.37452766299248, 55.98017692565918, 54.804292023181915, 53.58354292809963, 54.078762754797935, 55.56159518659115, 50.8215357363224, 51.20513275265694, 59.63091462850571, 58.662084415555, 56.140247136354446, 55.20316042006016, 58.32581005990505, 54.012209326028824, 50.68909764289856, 51.586434692144394, 51.56115084886551, 56.649055033922195, 54.32840175926685, 52.94690988957882, 51.304508820176125, 53.428522646427155, 56.22032403945923, 54.639407470822334, 45.237864553928375, 43.000468611717224, 42.80699819326401, 41.05896279215813, 40.96214398741722, 44.663901552557945, 48.938390985131264, 53.0696053057909, 50.3318902105093, 55.85729531943798, 52.218914553523064, 53.80352072417736, 54.06562305986881, 57.66362339258194, 54.35795657336712, 55.329967215657234, 53.80932301282883, 59.2481953650713, 23.912943340837955, 34.33048903942108, 54.06940005719662, 48.21246273815632, 54.5356198400259, 52.20423974096775, 54.852648228406906, 52.694443836808205, 55.277891010046005, 54.83272969722748, 57.505673468112946, 56.02052316069603, 50.04417344927788, 41.38060413300991, 43.39174881577492, 41.47210702300072, 50.34931227564812, 57.45510958135128, 58.480663150548935, 50.898398011922836, 54.41705100238323, 54.67390961945057, 57.254480347037315, 57.536603808403015, 57.93393328785896, 55.16288258135319, 51.455698907375336, 49.76964958012104, 49.26140405237675, 51.44490368664265, 50.68617179989815, 53.85557413101196, 47.51186013221741, 48.255430832505226, 47.017499059438705, 50.69275684654713, 52.674806490540504, 51.27841182053089, 49.36945125460625, 49.8972999304533, 51.69443629682064, 54.60245445370674, 56.07364051043987, 56.11859209835529, 53.15556429326534, 60.78373096883297, 61.786603555083275, 46.50895334780216, 27.36595295369625, 14.833593685179949, 12.826989758759737, 21.21988344937563, 23.649993650615215, 10.30354231595993, 13.970151767134666, 1.1177401850000024, 0.3685906418832019, 0.2946964226430282, 0.6612343434244394, 15.406005419790745, 55.38962781429291, 45.793725326657295, 29.64906994253397, 38.38576823472977, 51.364750787615776, 55.135379657149315, 63.868865221738815, 33.131147995591164, 2.7593055367469788, 0.2639308094512671, 0.22727349365595728, 0.19585799658671021, 0.08176499963155948, 0.19755307672312483, 0.15801959729287773, 0.2503303892444819, 0.10052605503005907, 0.1703791317413561, 0.15888878580881283, 0.20888311875751242, 0.1264340296620503, 0.10160289646591991, 0.11024737323168665, 0.2149540203390643, 0.17046069377101958, 0.18993200676050037, 0.2944735705386847, 0.21892004268011078, 0.2179017270100303], [0.01850382144766627, 0.0274714923943975, 0.010896855073951883, 0.07882108533522114, 0.045693947104155086, 0.055131479166448116, 0.04204670687613543, 0.08246248486102559, 0.06979362326092087, 0.057696111471159384, 0.06046086018614005, 0.029383567234617658, 0.09768839401658624, 0.08856227825162932, 0.027629532742139418, 0.023850934230722487, 0.02729035641095834, 0.014755387528566644, 0.009271087819797685, 2.3209377843886614, 20.07600422948599, 48.518756702542305, 47.71640695631504, 35.26813432574272, 11.522722095251083, 13.199655711650848, 18.85718733072281, 33.48223775625229, 26.410114243626595, 1.7269320460036397, 0.020426484879862983, 0.38017800136003643, 0.3278138127643615, 4.580871742218733, 12.08421416580677, 4.775831205770373, 15.369777213782072, 3.3171448158100247, 12.190500162541866, 30.938525050878525, 43.72567109763622, 49.328785836696625, 50.89556336402893, 48.72251696884632, 48.85691575706005, 49.589721634984016, 44.62333872914314, 49.23809230327606, 51.62882141768932, 52.47078023850918, 49.95518982410431, 50.27211181819439, 54.89922992885113, 50.48385925590992, 48.82476568222046, 50.31754978001118, 51.695982813835144, 52.993863970041275, 55.31103663146496, 51.698110699653625, 48.49152356386185, 48.70193727314472, 51.47440530359745, 51.19864270091057, 51.52323268353939, 50.059030652046204, 51.57405495643616, 53.39512623846531, 49.80865828692913, 40.30564941465855, 38.89682941138744, 38.74180153012276, 39.52591985464096, 37.99631953239441, 43.83794367313385, 51.48648865520954, 53.41957412660122, 52.538428008556366, 53.455732986330986, 51.86368301510811, 54.4845087826252, 51.122156605124474, 56.152740865945816, 52.27140113711357, 54.67989809811115, 52.26952783763409, 54.22966405749321, 21.56702522188425, 36.77976921200752, 51.90179876983166, 46.677234917879105, 50.00017561018467, 47.039955854415894, 49.886679500341415, 48.062298595905304, 47.90248677134514, 46.23429648578167, 50.329313948750496, 51.16292081773281, 52.90823556482792, 39.62476775050163, 39.21142213046551, 37.07706905901432, 40.776862129569054, 50.65985441207886, 52.07373954355717, 52.23255582153797, 49.376936852931976, 50.61213277280331, 51.562689766287804, 51.93586774170399, 48.72056007385254, 46.580617502331734, 47.45158776640892, 51.641497537493706, 51.622023582458496, 48.160321936011314, 46.75969809293747, 47.924153208732605, 47.054113894701004, 46.23916022479534, 49.04368333518505, 50.474105179309845, 53.347959369421005, 53.65634322166443, 55.573769733309746, 51.11498638987541, 53.712310418486595, 49.40588369965553, 48.931042179465294, 43.552616983652115, 48.29986944794655, 37.8553356975317, 38.12538340687752, 38.35860729217529, 29.793272204697132, 17.719644270837307, 10.83662711083889, 9.355191104114056, 7.787322560325265, 7.480143243446946, 4.135095337405801, 0.9149767714552581, 0.19131373730488122, 0.047180146066239104, 0.040921514519141056, 3.5413665091618896, 27.250175066292286, 37.65694074332714, 23.07652272284031, 16.73692960292101, 30.286504738032818, 42.26080410182476, 52.60317653417587, 31.248696707189083, 3.7407311238348484, 0.33752407296560705, 0.13197956490330398, 0.11524306610226631, 0.05155856502824463, 0.07138161890907213, 0.05217913778324146, 0.029779721953673288, 0.08149887289619073, 0.04391032132843975, 0.055598920880584046, 0.016862443117133807, 0.024519694634363987, 0.007411452206724789, 0.05357057561923284, 0.04716443479992449, 0.025881097753881477, 0.020731843396788463, 0.025535132626828272, 0.027131392089358997, 0.018712277742451988, 0.012899324428872205, 0.02787649351375876, 0.04661583181587048, 0.04602611756126862, 0.0487977905140724, 0.08621027125627734, 0.04911304742563516, 0.07296340278116986, 0.040811921571730636, 0.039997692801989615, 0.04172555360128172, 0.02991788016515784, 0.03897325812431518, 0.010180780900554964, 0.02651636317750672, 0.01879015500890091, 0.03488829177513253, 0.0596137282991549, 0.035647935583256185, 2.5059766927734017, 24.626339860260487, 54.78758051991463, 54.014200419187546, 41.33942574262619, 17.652148492634296, 19.994606897234917, 26.85166385024786, 35.042859613895416, 28.075243793427944, 2.113443505950272, 0.08213395092752762, 0.42303438764065504, 1.1443197587504983, 4.8011174239218235, 10.669909156858921, 7.493025977164507, 13.086547181010246, 4.941417770460248, 12.51434538513422, 29.532642289996147, 47.78453350067139, 52.3554640263319, 53.186848014593124, 50.749917179346085, 51.51222087442875, 50.63349522650242, 47.35352262854576, 50.08151404559612, 51.458449959754944, 52.55945608019829, 51.393709033727646, 49.37538653612137, 56.554702296853065, 51.59180760383606, 51.580510810017586, 51.97462946176529, 52.930072993040085, 54.96252693235874, 55.11138014495373, 52.0807159692049, 48.62374506890774, 49.096185117959976, 51.153379529714584, 52.54439748823643, 52.61260382831097, 50.523764714598656, 52.705231457948685, 54.68359909951687, 51.72071188688278, 42.128339409828186, 41.29106193780899, 41.328531727194786, 38.985790237784386, 39.99453350901604, 44.98949848115444, 53.11758533120155, 55.757166892290115, 55.21508038043976, 55.00884644687176, 53.32142159342766, 56.632582917809486, 54.226194843649864, 57.32245869934559, 53.80185641348362, 57.97084830701351, 52.16262437403202, 56.154986545443535, 23.475503213703632, 36.194669008255005, 51.814373061060905, 50.26838421821594, 51.52263231575489, 47.358397766947746, 50.58475524187088, 48.95005635917187, 47.80683450400829, 47.94509768486023, 51.89118213951588, 54.19170409440994, 54.879436790943146, 43.029195070266724, 41.30681589245796, 40.94727538526058, 43.60150896012783, 53.29192757606506, 52.84629128873348, 53.34726020693779, 49.601683393120766, 53.15453454852104, 52.797809690237045, 53.31449456512928, 49.20729115605354, 47.87352092564106, 47.863842844963074, 50.6809850782156, 50.13533815741539, 49.06167916953564, 47.4985608458519, 47.3277448117733, 47.229888662695885, 45.813928842544556, 48.60845468938351, 51.40845224261284, 53.237571492791176, 54.17809322476387, 55.72729289531708, 51.640304401516914, 52.47842162847519, 49.28739085793495, 50.96170261502266, 48.832574263215065, 52.188584581017494, 40.659330636262894, 40.68953901529312, 40.96286974847317, 28.79371114075184, 17.70393781363964, 8.61939288675785, 7.934526661410928, 9.412360936403275, 6.389064090326428, 6.517019849270582, 3.752329763956368, 0.7150591083336622, 0.12016577617032453, 0.06515089582535438, 5.091489292681217, 31.031240075826645, 38.732830211520195, 27.418979108333588, 24.851437881588936, 36.91576391458511, 47.14614875614643, 56.802988573908806, 39.65464934706688, 5.685357050970197, 0.38756875321269035, 0.0700946754659526, 0.09613267437089235, 0.038422714424086735, 0.06932331685675308, 0.1569012549589388, 0.06671558803645894, 0.06553132072440349, 0.09117961788433604, 0.03670339945529122, 0.014074011542106746, 0.021006679235142656, 0.057195978151867166, 0.03564444006769918, 0.05468312549055554, 0.07356549976975657, 0.019309600866108667, 0.014945155617169803, 0.048350891447626054, 0.008899395215848926, 0.08658156773890369, 0.11372936685802415, 0.09464879462029785, 0.09558467994793318, 0.20116062689339742, 0.27449952671304345, 0.2280364659964107, 0.14282177842687815, 0.17715971946017817, 0.166852920956444, 0.1236353165586479, 0.21513491141377017, 0.17213241109857336, 0.13982011761981994, 0.12501664634328336, 0.10192515183007345, 0.1375392751651816, 0.16588677826803178, 0.1823979165055789, 3.5388332325965166, 31.62905629724264, 62.375024780631065, 61.33759684860706, 47.15783312916756, 21.151468120515347, 21.03737734258175, 27.58184976875782, 44.828622713685036, 34.57974046468735, 2.8109846636652946, 0.2666435670107603, 0.7737039146013558, 1.293600567150861, 8.87622395530343, 22.06240464001894, 9.756917897611856, 23.214941695332527, 8.598594702780247, 13.918464090675116, 35.24396002292633, 47.701713144779205, 52.4615391343832, 51.72231540083885, 50.84183044731617, 52.75233753025532, 54.11137640476227, 49.631473794579506, 49.75685566663742, 51.554432809352875, 52.05608569085598, 51.97568200528622, 52.29634299874306, 60.127312391996384, 54.69543546438217, 54.18339014053345, 54.29601229727268, 54.87338371574879, 58.80181811749935, 57.53056973218918, 53.813343197107315, 47.69249863922596, 49.71580266952515, 51.77264750003815, 52.133833318948746, 53.87442111968994, 50.36668874323368, 55.48328138887882, 57.177827060222626, 54.69480089843273, 44.64544214308262, 42.92986460030079, 43.80330093204975, 43.682608008384705, 41.808544769883156, 47.80126020312309, 55.68811319768429, 57.98623368144035, 57.144673839211464, 57.171686589717865, 55.98843388259411, 59.42059211432934, 55.32588243484497, 59.55983184278011, 56.40420377254486, 59.18528974056244, 55.014409348368645, 55.48682279884815, 26.622678637504578, 38.96387681365013, 52.06929758191109, 52.54779830574989, 53.69211830198765, 48.933040872216225, 52.59346805512905, 49.09674748778343, 47.92470037937164, 47.67662689089775, 52.255419194698334, 55.936034694314, 58.39622028172016, 44.58896957337856, 43.66985969245434, 42.462470680475235, 46.119994819164276, 54.908497631549835, 57.3060891777277, 55.071847066283226, 49.398519694805145, 53.94638925790787, 53.37740018963814, 54.568792060017586, 49.9978843331337, 46.195378974080086, 48.7969321757555, 51.249027997255325, 52.23675459623337, 50.191483944654465, 47.81028091907501, 47.88285322487354, 46.725796312093735, 45.5577389895916, 49.04586061835289, 52.58709579706192, 56.131268218159676, 55.77466495335102, 57.98136234283447, 53.629182279109955, 55.12429565191269, 49.756566882133484, 53.531295731663704, 47.81856827437878, 56.657733768224716, 45.6639014929533, 41.561991199851036, 40.19393540918827, 34.89940211176872, 21.338184401392937, 15.219887606799603, 15.896817483007908, 18.58724031597376, 16.52646079659462, 9.896241221576929, 5.402554851025343, 0.7484105718322098, 0.3794884274248034, 0.12490807013818994, 5.778694292530417, 38.03115986287594, 50.458609610795975, 32.194684445858, 25.765148252248764, 41.96032762527466, 55.78865200281143, 62.793811708688736, 49.490805342793465, 8.662129193544388, 0.6579808867536485, 0.3142738330643624, 0.30509777076076716, 0.14615467458497733, 0.284641984035261, 0.3351376228965819, 0.22014286456396803, 0.13927189313108101, 0.3260440280428156, 0.12004807154880837, 0.1151068894250784, 0.11049154723878019, 0.09785949616343714, 0.09463533948292024, 0.20796949043869972, 0.1901845447719097, 0.09010457244585268, 0.12193823262350634, 0.1901060700765811, 0.13219744461821392], [0.09805069566937163, 0.042914299774565734, 0.039734208112349734, 0.052487336870399304, 0.0625448368373327, 0.10099555991473608, 0.022307985091174487, 0.02545860050304327, 0.016842451514094137, 0.06968135116039775, 0.004864129105044412, 0.04262135553290136, 0.07383499585557729, 0.05684529853169806, 0.035373251885175705, 0.021420137127279304, 0.027394244098104537, 0.058939097507391125, 0.06432665919419378, 4.483910445123911, 19.845037423074245, 48.41923624277115, 48.221472054719925, 40.46269878745079, 22.39368226379156, 16.38677269220352, 22.626284882426262, 45.233886167407036, 17.887623757123947, 1.0778533690609038, 0.03621967131039128, 0.13706455298233777, 0.5350148538127542, 1.4076950261369348, 6.326065845787525, 11.821478214114904, 12.46513707563281, 6.3178459368646145, 15.403516553342342, 25.550940446555614, 43.600106835365295, 53.641812801361084, 53.856391087174416, 57.28037975728512, 55.34997694194317, 48.0615234375, 51.5580540150404, 50.48172377049923, 51.23549312353134, 48.78523640334606, 50.87702415883541, 55.58893471956253, 48.71338985860348, 48.91581639647484, 48.35037253797054, 42.63736389577389, 45.08660227060318, 51.04098156094551, 51.660500317811966, 53.109252378344536, 52.57996737957001, 50.37962704896927, 50.591575875878334, 53.41210372745991, 51.87906078994274, 50.20091503858566, 52.36234165728092, 50.89426763355732, 45.26287101209164, 37.30430826544762, 37.584980204701424, 39.58673559129238, 40.22300384938717, 42.87192150950432, 52.56043642759323, 51.553524658083916, 56.003351882100105, 52.615028098225594, 50.687832310795784, 52.05751821398735, 54.70224849879742, 52.6448754966259, 51.97967939078808, 51.218002662062645, 51.165831461548805, 47.1753615885973, 48.839562088251114, 18.72204188257456, 37.09088891744614, 50.99956378340721, 54.16127152740955, 55.68699985742569, 47.198726534843445, 50.69249086081982, 49.648075103759766, 49.84915651381016, 48.31754609942436, 46.28981150686741, 51.15711472928524, 50.36021389067173, 42.03279733657837, 39.87704001367092, 39.638773798942566, 38.774745762348175, 47.43595540523529, 51.14424481987953, 52.674601301550865, 52.434495985507965, 49.419863149523735, 49.98126782476902, 49.192886129021645, 48.29510450363159, 50.06029598414898, 51.42430119216442, 48.705866262316704, 44.1841696947813, 45.58233506977558, 48.08166615664959, 46.761590391397476, 45.659136548638344, 50.47367960214615, 50.38859076797962, 50.51807641983032, 51.215206012129784, 53.46857629716396, 54.37925823032856, 52.86657080054283, 53.25432859361172, 54.32740621268749, 55.74286065995693, 55.177663788199425, 40.32063581049442, 43.02311159670353, 27.558399327099323, 23.811788968741894, 28.450631350278854, 24.267004542052746, 7.784206727519631, 3.7469105422496796, 3.4055807953700423, 4.582725567743182, 2.5980915874242783, 2.4732082011178136, 0.052618964182329364, 0.07559165940620005, 0.20299901574617252, 1.0562819265760481, 24.93028935045004, 39.836526587605476, 28.47289815545082, 17.270935848355293, 27.062512636184692, 38.83398078382015, 51.21137581765652, 41.92105293273926, 9.356625527143478, 0.7400371273979545, 0.04585341608617455, 0.032172216815524735, 0.07764061781927012, 0.028231835676706396, 0.031078575011633802, 0.022133136953925714, 0.027705847787729, 0.013657213985425187, 0.03235140837205108, 0.06401007383828983, 0.0798463549290318, 0.01471171306548058, 0.0077312366829573875, 0.027230704436078668, 0.018535158633312676, 0.025589402175683063, 0.014681173688586568, 0.06555603424203582, 0.02463277010974707, 0.08450293084024452, 0.005326256577973254, 0.047406679223058745, 0.05616664158878848, 0.08378502170671709, 0.037033699700259604, 0.059469506741152145, 0.016312328007188626, 0.02364572854276048, 0.010505776645004516, 0.06525082601001486, 0.020418187668838073, 0.024686701981408987, 0.02921522031101631, 0.019580388288886752, 0.05570901106693782, 0.007810710030753398, 0.028715363441733643, 0.0344469439733075, 5.000529773533344, 24.890657477080822, 55.49543313682079, 52.56309628486633, 44.16966587305069, 20.811409167945385, 16.60357005894184, 19.633160792291164, 44.7408702224493, 21.798343509435654, 1.1918284907005727, 0.08010568359168246, 0.2700716955587268, 0.4973617539508268, 4.557111617177725, 11.318842135369778, 14.103707950562239, 17.588997781276703, 7.409771969541907, 16.117693930864334, 29.269491210579872, 44.24790747463703, 54.55832742154598, 54.22285482287407, 54.885489866137505, 54.366726502776146, 51.806028708815575, 52.70556204020977, 51.32449194788933, 52.583113610744476, 49.00041885674, 52.24291406571865, 56.65524110198021, 52.429829835891724, 50.83071604371071, 50.64128860831261, 45.364941135048866, 48.131090104579926, 51.51403337717056, 54.10520553588867, 54.62194360792637, 53.272575214505196, 50.10554015636444, 50.19086837768555, 53.23064066469669, 51.41992762684822, 49.40219409763813, 53.55388931930065, 53.59435714781284, 48.59516300261021, 39.222601130604744, 39.53527495265007, 40.490931272506714, 41.90482400357723, 44.094585701823235, 54.56472247838974, 54.08702731132507, 57.41732820868492, 54.40809868276119, 54.51209530234337, 53.778115287423134, 54.99316468834877, 54.11607675254345, 54.472167044878006, 51.92044056952, 50.704365223646164, 49.29474726319313, 50.10989472270012, 21.006213314831257, 38.01575928926468, 52.64276660978794, 54.540141597390175, 55.93417279422283, 48.432584926486015, 51.98428474366665, 50.742697566747665, 49.87276844680309, 48.8451211899519, 46.475100964307785, 51.8168581277132, 52.91213035583496, 45.34639813005924, 40.35172574222088, 41.57517649233341, 40.57383142411709, 49.391778856515884, 53.235018029809, 54.30728629231453, 53.72265346348286, 50.465521439909935, 50.141790211200714, 50.15195846557617, 50.320996195077896, 51.801286563277245, 50.93965619802475, 48.96499715745449, 47.697594165802, 48.22388872504234, 48.93420360982418, 48.45256045460701, 45.899576246738434, 49.20566484332085, 51.9596316665411, 51.67619347572327, 52.31708228588104, 54.42018583416939, 56.24050855636597, 56.53324864804745, 54.818784445524216, 55.00457167625427, 56.346538066864014, 54.37231980264187, 44.627894684672356, 47.52691872417927, 30.6048421561718, 25.46566352248192, 31.1315755918622, 26.570556834340096, 9.780550729483366, 5.29792414046824, 9.545644484460354, 10.900285094976425, 10.652860421687365, 4.409763123840094, 0.5567929102107882, 0.22627349419053644, 0.1412139748572372, 1.570005810353905, 25.032957941293716, 42.00355410575867, 25.906700156629086, 18.877360448241234, 30.944053754210472, 47.37124867737293, 56.17419071495533, 49.579446986317635, 12.208348754793406, 0.890164696611464, 0.0802731269504875, 0.046285520438686945, 0.03525550644553732, 0.07295378454728052, 0.07434963816194795, 0.0646530780068133, 0.029285559212439694, 0.030903758415661287, 0.1016070821788162, 0.0637009619094897, 0.06726405743393116, 0.13485143892467022, 0.05898201219679322, 0.03324387806060258, 0.060755997474188916, 0.03476257566944696, 0.07005241757724434, 0.009636559370846953, 0.01505619668023428, 0.2519283816218376, 0.15073319140356034, 0.12685678666457534, 0.16332537430571392, 0.11074999274569564, 0.15039355494081974, 0.1701944853994064, 0.13241866399766877, 0.1029819849645719, 0.22075708082411438, 0.19922166218748316, 0.21447762090247124, 0.1255592008237727, 0.16410890413681045, 0.10060622182209045, 0.13088258157949895, 0.09731279307743534, 0.13860376726370305, 0.19623496307758614, 6.173712546005845, 31.98916867375374, 62.63271555304527, 61.10042117536068, 52.58951246738434, 34.35762718319893, 26.550395116209984, 30.877298936247826, 57.86053642630577, 25.612424947321415, 1.5788158751092851, 0.21563952730502933, 0.3760786447674036, 1.2777126696892083, 6.035885866731405, 13.402821309864521, 24.128376580774784, 22.0131915807724, 11.656612660735846, 19.111351892352104, 30.38246288895607, 46.68842911720276, 52.97516517341137, 53.84398855268955, 56.23099006712437, 55.896178632974625, 52.24009841680527, 55.466501489281654, 53.055751249194145, 51.89167231321335, 51.131796687841415, 52.706139609217644, 58.97727370262146, 53.70259813964367, 52.88747727870941, 52.03943878412247, 47.83244892954826, 48.90659049153328, 55.53560458123684, 56.63069821894169, 57.726099640131, 56.1008470505476, 51.52519717812538, 49.85685110092163, 54.21728052198887, 51.862341687083244, 51.40291593968868, 56.24045915901661, 54.3789504468441, 50.331164449453354, 41.60769894719124, 41.56066507101059, 43.15080374479294, 43.306507989764214, 47.264728993177414, 56.60476841032505, 56.85487858951092, 60.226604864001274, 54.83612671494484, 55.3446876257658, 54.1333582252264, 56.545791774988174, 53.52629519999027, 54.95890952646732, 53.34184169769287, 52.624675780534744, 49.69073161482811, 50.19666686654091, 22.61393364518881, 39.454191103577614, 54.75087448954582, 55.348206236958504, 59.369378462433815, 51.37350171804428, 55.71106016635895, 54.20192174613476, 52.09754526615143, 50.94645403325558, 47.57268346846104, 54.27916020154953, 55.07011815905571, 46.79156318306923, 43.33336494863033, 42.084185779094696, 43.81405435502529, 51.79660141468048, 55.8088593184948, 56.5385227650404, 54.34433810412884, 51.2638396024704, 51.16314880549908, 49.89627778530121, 50.839759558439255, 53.940856754779816, 52.4250952899456, 52.84393921494484, 49.35900181531906, 48.2142448425293, 48.89847792685032, 48.491367772221565, 46.92381128668785, 51.432588547468185, 53.42362470924854, 54.624280482530594, 54.428321197628975, 57.911210507154465, 58.587707206606865, 59.0563702583313, 57.12700858712196, 56.699527725577354, 57.092802822589874, 57.33860403299332, 46.662579104304314, 53.23264315724373, 34.946105405688286, 29.686592929065228, 32.15762883424759, 31.95745177567005, 12.367590609937906, 7.863845229148865, 11.01302219554782, 15.042413379997015, 13.588759582489729, 5.851230025291443, 0.9619929548352957, 0.2727038261946291, 0.27671905292663723, 1.6301354463212192, 32.48985640704632, 55.149777084589005, 37.989396303892136, 28.645574189722538, 38.71781721711159, 54.11996394395828, 60.77078506350517, 58.16098630428314, 16.636252105236053, 1.4107998157851398, 0.23983645078260452, 0.1889077984378673, 0.21310573123628274, 0.13954924856079742, 0.11960433403146453, 0.25225379853509367, 0.14101933920755982, 0.11742652393877506, 0.12864755932241678, 0.18545045895734802, 0.12806967861251906, 0.21705069142626598, 0.1139977497223299, 0.12589337507961318, 0.17067327455151826, 0.10927300754701719, 0.14483051985735074, 0.16196060925722122, 0.06414465489797294], [0.0736067928664852, 0.052042998213437386, 0.04915091922157444, 0.06165349892398808, 0.02396717682131566, 0.032251927186734974, 0.09901000317768194, 0.0224950415577041, 0.07393589083221741, 0.09421955124707893, 0.01725717847875785, 0.0672995692002587, 0.020107919845031574, 0.015165699642238906, 0.027754797993111424, 0.08532799867680296, 0.10233167806291021, 0.024951643135864288, 0.07578346005175263, 2.911972557194531, 23.91907051205635, 52.12105080485344, 47.005518302321434, 36.734870821237564, 20.891793854534626, 14.555679447948933, 35.997577384114265, 40.47589547932148, 9.98201496899128, 0.21913927310379222, 0.037428960131364875, 0.3777745709521696, 0.8802286454010755, 6.815474834293127, 7.093983264639974, 7.656876984983683, 13.129790760576725, 4.904786786064506, 14.473804291337729, 34.874809831380844, 53.532849848270416, 55.72803385555744, 52.823465913534164, 49.87659104168415, 55.70392794907093, 51.2333994358778, 50.38914933800697, 52.76315554976463, 52.1224757283926, 52.85467743873596, 53.64686273038387, 50.2845523506403, 50.16715005040169, 47.22260445356369, 45.761791840195656, 43.65891247987747, 38.095178827643394, 43.472920060157776, 49.839060455560684, 51.929579079151154, 52.77768976986408, 52.582752630114555, 50.29648371040821, 50.11833406984806, 47.23475240170956, 53.80584239959717, 52.81603731215, 48.915770798921585, 41.255366653203964, 38.82761612534523, 37.575609907507896, 40.64043425023556, 41.42250828444958, 46.65576606988907, 53.86490263044834, 56.42487086355686, 51.553627252578735, 50.230097472667694, 50.47385439276695, 45.60668796300888, 48.8640745729208, 47.53632701933384, 49.144180342555046, 47.963237911462784, 47.30634815990925, 42.708997651934624, 49.72921594977379, 15.679953619837761, 37.208994179964066, 51.18010729551315, 54.69296559691429, 49.04839128255844, 53.73751446604729, 50.6511452794075, 51.27305790781975, 50.91119572520256, 52.02587351202965, 52.929343432188034, 50.82791559398174, 51.57755836844444, 45.54980121552944, 37.43439428508282, 37.9993137717247, 37.414027377963066, 41.01963110268116, 47.052244395017624, 53.21084372699261, 52.133977711200714, 52.080837562680244, 50.89126959443092, 52.86016434431076, 51.95751138031483, 52.96236366033554, 49.84154552221298, 46.50656707584858, 49.604753628373146, 52.130858078598976, 48.516587018966675, 51.36478878557682, 50.24413011968136, 53.51287052035332, 51.14030063152313, 50.37041254341602, 49.903683587908745, 48.510431349277496, 50.54913975298405, 49.810945764184, 51.54119051992893, 52.68859975039959, 52.77641303837299, 61.24796725809574, 57.41658344864845, 38.86912129819393, 40.264417827129364, 25.421551689505577, 18.236623629927635, 16.1448909714818, 12.150730546563864, 9.466173648834229, 7.7428739704191685, 5.944835627451539, 9.036706443876028, 4.838250456377864, 0.882092445390299, 0.0882223375083413, 0.023420852230628952, 0.5016105493996292, 12.934925816953182, 37.04084940254688, 40.272085815668106, 32.35719792544842, 28.107443265616894, 40.53047575056553, 47.59037911891937, 46.463146805763245, 19.617811515927315, 1.991226626560092, 0.09162484711850993, 0.021148492523934692, 0.019996076334791724, 0.02249978388135787, 0.09002144448459148, 0.036831085963058285, 0.016693858706275932, 0.05888338077056687, 0.028410706254362594, 0.0925693339377176, 0.04409746499732137, 0.083354576054262, 0.026129129073524382, 0.024950789666036144, 0.09202636385452934, 0.03412692247366067, 0.10953748671454377, 0.03868280749884434, 0.028889818240713794, 0.048206206047325395, 0.08244923010352068, 0.02257527143228799, 0.04568812495563179, 0.04266435556928627, 0.03938141708204057, 0.04238587207510136, 0.045541721483459696, 0.08180883087334223, 0.06836323751485907, 0.03442444205575157, 0.05971034108370077, 0.052254335896577686, 0.033397001679986715, 0.02414695652987575, 0.03916026449587662, 0.05610967433312908, 0.04605993723089341, 0.03056897930946434, 3.901544432155788, 29.229994229972363, 57.843243554234505, 54.789233431220055, 43.28113675117493, 28.124671541154385, 18.24703697115183, 28.361028358340263, 44.967797845602036, 11.942414324730635, 0.2997918601613492, 0.017667714164417703, 0.27911987097468227, 2.1534916944801807, 7.592400619760156, 10.080010760575533, 12.103538978844881, 12.37463353201747, 5.422629173845053, 14.598924927413464, 34.21513482928276, 55.299010276794434, 55.11713683605194, 52.872601076960564, 51.27741627395153, 55.022119134664536, 51.021716594696045, 53.8732697814703, 53.60994391143322, 53.99139404296875, 53.08138847351074, 55.00462867319584, 53.97828474640846, 51.53981879353523, 49.275748282670975, 48.01706962287426, 45.043121203780174, 41.274627819657326, 45.83408676087856, 51.86896853148937, 53.53976167738438, 54.79245185852051, 55.11431358754635, 51.985740065574646, 51.929202899336815, 48.244814202189445, 54.226761013269424, 54.387701377272606, 50.8595222979784, 43.76410223543644, 40.16817659139633, 40.12540228664875, 41.827486753463745, 43.5067268460989, 48.00118267536163, 55.47954618930817, 57.80023746192455, 53.39913882315159, 50.621161088347435, 50.658969059586525, 46.22666269540787, 48.18399466574192, 48.729098215699196, 48.40807244181633, 48.265222907066345, 47.17849262058735, 43.87930825352669, 51.640406996011734, 18.212211839854717, 37.8023437410593, 53.064103201031685, 56.41935355961323, 53.39506924152374, 55.39481073617935, 53.82004223763943, 53.16623032093048, 52.35835187137127, 53.49209323525429, 54.77372266352177, 51.980807930231094, 52.953054159879684, 47.180153131484985, 40.462797582149506, 40.1449104398489, 39.774038940668106, 43.31204429268837, 51.552057936787605, 53.78901690244675, 53.07537339627743, 52.69214875996113, 51.118976175785065, 54.01946313679218, 54.39026243984699, 55.26892349123955, 52.63353690505028, 49.10281956195831, 50.506775826215744, 50.66982887685299, 49.91578973829746, 51.184397265315056, 51.18449226021767, 55.3093571215868, 52.524646148085594, 52.0935782790184, 52.0811415463686, 50.8087532222271, 51.83751381933689, 51.53302475810051, 54.48263928294182, 54.09906126558781, 53.87363076210022, 60.41209191083908, 55.936927646398544, 44.704813957214355, 45.55225968360901, 28.10978963971138, 20.066964514553547, 17.158809565007687, 13.815830647945404, 9.124974757432938, 13.956584595143795, 12.909217346459627, 9.134096167981625, 6.995032774284482, 2.386926468461752, 0.1545653006178327, 0.013432518571789842, 0.4555133229587227, 15.856887325644493, 41.9195482134819, 41.411599069833755, 36.37115053832531, 34.41093072295189, 45.58916710317135, 51.159630194306374, 53.73279131948948, 22.967299483716488, 2.7308049285784364, 0.13991484534926713, 0.032061410456663, 0.05227895664575044, 0.034312526186113246, 0.04307440700358711, 0.06752386849257164, 0.016201287871808745, 0.00822045347376843, 0.04138189098739531, 0.15502645634114742, 0.03918373120541219, 0.1277643590583466, 0.029440996477205772, 0.07373456101049669, 0.004898085608147085, 0.052368942051543854, 0.02547806332586333, 0.06839388821390457, 0.0343915908888448, 0.12392541466397233, 0.15159170783590525, 0.12243055112776347, 0.1410706661408767, 0.11902429367182776, 0.12926343799335882, 0.14309580903500319, 0.21166706312214956, 0.22732024895958602, 0.1623594542616047, 0.16192485258216038, 0.203880553599447, 0.15716029418399557, 0.07562186481663957, 0.1963033148786053, 0.1785112000652589, 0.15320394944865257, 0.12589043617481366, 0.14854100591037422, 5.138743557035923, 39.00605455040932, 65.00973120331764, 60.71154624223709, 48.07703800499439, 31.863858997821808, 23.906381092965603, 47.41944909095764, 51.72412410378456, 14.485662505030632, 0.4889648873358965, 0.10960802785120904, 0.5938194890040904, 2.173596890643239, 13.750076126307249, 17.304081469774246, 15.915864910930395, 20.00749960541725, 10.872157104313374, 18.87256320565939, 39.79729749262333, 54.14011426270008, 56.31876155734062, 52.80499130487442, 50.65324276685715, 56.52069792151451, 51.92161090672016, 52.11806796491146, 54.939230382442474, 55.17737880349159, 54.325821697711945, 55.98858967423439, 55.6894963234663, 55.53922198712826, 52.989558801054955, 50.721901282668114, 48.15245635807514, 41.66633740067482, 47.993757873773575, 53.76353546977043, 56.82660810649395, 57.680125907063484, 56.89419887959957, 53.41574773192406, 54.558639004826546, 48.75800706446171, 57.03269004821777, 55.60908883810043, 52.935825884342194, 44.80957053601742, 42.736652567982674, 42.50761605799198, 44.434625655412674, 45.924290120601654, 50.073591470718384, 57.262429520487785, 59.22436684370041, 52.94211454689503, 50.81173986196518, 51.50059349834919, 46.193517073988914, 48.044933527708054, 47.86254711449146, 47.83927336335182, 48.229216039180756, 47.0705746114254, 45.05376063287258, 55.03640256822109, 20.985312536358833, 43.194687590003014, 56.25723525881767, 57.640277445316315, 55.37162058055401, 56.81143172085285, 55.49839697778225, 55.154724419116974, 54.86066199839115, 56.34341463446617, 57.172860726714134, 54.962177351117134, 55.94498701393604, 49.85829122364521, 43.731484785676, 41.88484847545624, 43.61802667379379, 45.223569720983505, 52.04260401427746, 57.0687311142683, 55.269573256373405, 54.57328721880913, 52.77203567326069, 55.1783287525177, 56.93263001739979, 57.387017235159874, 54.458506777882576, 52.76790909469128, 51.85620881617069, 52.435088753700256, 51.735052317380905, 52.78202913701534, 52.49929390847683, 57.92404621839523, 54.89021301269531, 54.41414795815945, 54.45898935198784, 51.78219638764858, 55.66885583102703, 54.14448402822018, 57.06963166594505, 55.75144059956074, 57.588030248880386, 63.597837164998055, 58.72945100069046, 46.47665128111839, 49.88910757005215, 35.62419421970844, 25.28537079691887, 21.011067554354668, 14.417318422347307, 13.668920081108809, 14.587867520749569, 14.490926172584295, 17.066898196935654, 11.241236049681902, 2.877212972380221, 0.8309015328995883, 0.11046048093703575, 1.0793616506271064, 16.716600693762302, 52.147869765758514, 51.9823544472456, 43.49002294242382, 37.72543206810951, 53.06143954396248, 60.325623750686646, 61.65059745311737, 29.867434725165367, 4.089324893429875, 0.2352732073632069, 0.08217846494517289, 0.14332722552353516, 0.12738233112031594, 0.2020367470686324, 0.13803621724946424, 0.07637314090970904, 0.1392887844122015, 0.10785154983750544, 0.2472036171820946, 0.12520662130555138, 0.22978735563810915, 0.1171091444848571, 0.18118986336048692, 0.13465212774462998, 0.21803366602398455, 0.1881447370396927, 0.16681915323715657, 0.0745199758966919], [0.05402742688602302, 0.048281096169375814, 0.07785408175550401, 0.004563209558909875, 0.009605255581845995, 0.03385717034689151, 0.011884221330547007, 0.0510154539369978, 0.01927753080963157, 0.03897579626936931, 0.07072478852933273, 0.027056934268330224, 0.04398978308017831, 0.05423847142083105, 0.04161765275057405, 0.052494246265268885, 0.11219180014450103, 0.0767227889446076, 0.14918008411768824, 6.509319087490439, 30.35709735006094, 46.68504349887371, 42.56837859749794, 30.313291400671005, 14.17658993974328, 16.68245952576399, 28.221161663532257, 34.2262302339077, 5.004385616630316, 0.18986506504006684, 0.06687307919492014, 0.12452795694116503, 1.1876211664639413, 4.290361180901527, 10.552384313195944, 17.303237915039062, 17.33202137053013, 9.085331484675407, 22.580660730600357, 39.49523650109768, 52.13093027472496, 54.04355764389038, 53.06632228195667, 54.19565588235855, 52.82314293086529, 52.540734484791756, 50.56412994861603, 49.31052781641483, 49.22846741974354, 52.479884549975395, 52.726061940193176, 50.76662868261337, 50.95206633210182, 48.76652240753174, 49.83724035322666, 47.43401750922203, 43.51567156612873, 37.44828633964062, 39.73148122429848, 45.02374604344368, 51.415291875600815, 52.33046516776085, 51.06804370880127, 51.983714774250984, 53.39962139725685, 52.42987923324108, 51.776770278811455, 44.43321593105793, 38.63768331706524, 36.345334723591805, 37.81410790979862, 38.94170880317688, 43.10752026736736, 51.03861428797245, 55.67569926381111, 44.84315313398838, 48.952670618891716, 50.84959723055363, 52.53644071519375, 48.53299833834171, 51.543550193309784, 50.65618000924587, 51.34586200118065, 46.58173464238644, 51.127723306417465, 41.74260310828686, 45.460536405444145, 16.89853113144636, 39.836009815335274, 57.058768048882484, 46.64801828563213, 48.737628757953644, 43.40583086013794, 45.41555441915989, 45.85019029676914, 48.7685476988554, 50.39401687681675, 51.33134678006172, 47.799348905682564, 48.68396423757076, 43.003497049212456, 35.81667669117451, 36.75746440887451, 38.926612213253975, 36.34365901350975, 39.58524987101555, 45.68895734846592, 51.86378560960293, 51.5461378544569, 53.29552598297596, 52.13114686310291, 50.84141246974468, 49.40632067620754, 50.13342685997486, 51.44243001937866, 49.36454191803932, 49.818849340081215, 52.611703276634216, 52.1594325453043, 53.38250331580639, 51.956447437405586, 47.52321392297745, 42.865993827581406, 41.89980827271938, 41.29581928253174, 41.23724542558193, 42.16487064957619, 45.681878328323364, 51.12434908747673, 52.33866132795811, 49.64769512414932, 56.207286939024925, 52.45901606976986, 40.3207042068243, 47.5386068969965, 23.709443360567093, 22.39606473594904, 9.79786355048418, 4.240519255399704, 16.28146894276142, 16.8873293325305, 12.414528541266918, 5.474046589806676, 1.3035053294152021, 0.07522828163928352, 0.15071440022438765, 0.17609703820198774, 8.891694825142622, 33.34405057132244, 29.434949532151222, 12.784205954521894, 23.552175499498844, 43.395176231861115, 43.52890245616436, 52.941324189305305, 32.35590599477291, 3.8896209094673395, 0.050731077790260315, 0.02051370764093008, 0.036581969252438284, 0.032193252991419286, 0.057999416094389744, 0.014812067202001344, 0.10981799627188593, 0.02898953876865562, 0.029367329043452628, 0.009886550888040802, 0.06166049366584048, 0.03155470170895569, 0.023987513523024973, 0.08158309923601337, 0.04431296241818927, 0.04117236043384764, 0.015871440336923115, 0.02763150871032849, 0.04818196008272935, 0.020370623424241785, 0.045545127941295505, 0.08310493241879158, 0.03317186376079917, 0.013402203694568016, 0.09671449588495307, 0.03028535829798784, 0.04194501038000453, 0.05723398724512663, 0.07957250243634917, 0.07354348766966723, 0.025334563506476115, 0.05972857565211598, 0.018910290164058097, 0.0416628792299889, 0.011189879096491495, 0.056864523867261596, 0.1056987649644725, 0.08863460796419531, 7.93618812225759, 37.27388709783554, 51.205018758773804, 48.20845015347004, 35.525745302438736, 18.50917350500822, 18.066398464143276, 33.20860303938389, 37.340991497039795, 7.147523341700435, 0.17492284183390439, 0.04811963823158294, 0.7389201654586941, 3.054590541869402, 8.260485045611858, 11.456575244665146, 7.359963292255998, 7.975458540022373, 8.086120951920748, 20.830349251627922, 41.904345229268074, 52.2904647141695, 54.18037310242653, 53.71852308511734, 53.222984075546265, 52.012597024440765, 52.86921925842762, 50.374299734830856, 49.730815663933754, 48.93646448850632, 54.33539338409901, 53.75046417117119, 52.097765654325485, 53.08356195688248, 51.14559754729271, 51.281732842326164, 50.190541595220566, 45.1766612380743, 40.606448873877525, 42.89625160396099, 48.100174963474274, 53.42382989823818, 52.838824689388275, 51.42719283699989, 53.45290593802929, 53.99398550391197, 54.7864443808794, 53.77306155860424, 47.12723717093468, 39.691674560308456, 39.23738993704319, 38.99495914578438, 41.15852124989033, 43.866905719041824, 51.855756640434265, 57.2471809387207, 46.15187510848045, 48.08852098882198, 50.44262006878853, 52.39500090479851, 47.93989956378937, 50.71413069963455, 50.11538542807102, 51.66927024722099, 47.08536721765995, 50.33906042575836, 42.488693073391914, 46.509929895401, 18.265467882156372, 41.81889161467552, 59.51633557677269, 49.929324612021446, 52.452735006809235, 46.02701760828495, 48.65276791155338, 47.46199920773506, 50.88522411882877, 52.87217929959297, 53.14949221909046, 50.197358429431915, 50.27242340147495, 44.88937005400658, 37.19356320798397, 39.016120210289955, 41.16168648004532, 39.02443416416645, 42.82701551914215, 49.0137979388237, 53.936217203736305, 55.57138346135616, 54.88949105143547, 53.537709787487984, 53.31009820103645, 51.426147893071175, 52.27310724556446, 52.9092501103878, 51.86878614127636, 51.78997837007046, 52.982312589883804, 52.390178963541985, 53.42747390270233, 53.43007676303387, 49.12005163729191, 45.046164840459824, 43.90202343463898, 44.13758039474487, 43.709689155220985, 45.94941057264805, 48.041015937924385, 53.21399375796318, 53.37055295705795, 51.54539689421654, 57.28316880762577, 51.88140146434307, 46.24669902026653, 47.9265470802784, 27.89837848395109, 22.87477444857359, 10.119266454130411, 5.447186306118965, 12.773367036134005, 11.999343819916248, 10.633215475827456, 8.167472686618567, 6.990429796278477, 0.8584922086447477, 0.22793183801695704, 0.09860498350462876, 9.780174549669027, 38.40745747089386, 35.94626493752003, 20.131808035075665, 32.16648615896702, 50.48142358660698, 49.33705039322376, 56.05644643306732, 37.30275794863701, 4.525383794680238, 0.05036796719650738, 0.019395675153646152, 0.06224861601367593, 0.016995491641864646, 0.07559259451227263, 0.04069818001880776, 0.03229264140827581, 0.0217041125142714, 0.0311078119193553, 0.03315569236292504, 0.006134864506748272, 0.039627750738873146, 0.028372168380883522, 0.033665406808722764, 0.06789428181946278, 0.024776314457994886, 0.0164096254229662, 0.062135208427207544, 0.03241427941247821, 0.1131574901228305, 0.17729041166603565, 0.23374398238956928, 0.15187970566330478, 0.07164154871134087, 0.1989447817322798, 0.1451329598785378, 0.13249280455056578, 0.10393643140560016, 0.23996481264475733, 0.16287610778817907, 0.27294187748339027, 0.13694606168428436, 0.22894985682796687, 0.14996437093941495, 0.09023861915920861, 0.2567724685650319, 0.2368345673312433, 0.42823826777748764, 10.904414523392916, 44.07342463731766, 58.84543597698212, 56.30937986075878, 42.921440452337265, 23.09627216309309, 24.881819151341915, 38.36688704788685, 44.027743488550186, 8.286922127008438, 0.4710162238916382, 0.19617961370386183, 0.6877116789110005, 3.060842868871987, 12.617999073117971, 21.481782495975494, 30.066969618201256, 27.469362504780293, 12.316164169460535, 26.8531134724617, 42.05776199698448, 55.4178337007761, 54.082201570272446, 55.18320769071579, 54.87371429800987, 52.92199842631817, 53.2879263907671, 51.607367768883705, 49.46443095803261, 49.70835126936436, 54.30709630250931, 55.77399238944054, 54.00083653628826, 55.08981250226498, 52.265488654375076, 55.39132632315159, 52.4978955835104, 48.57822731137276, 41.54096692800522, 43.998785242438316, 49.11203786730766, 56.037797033786774, 54.3799763917923, 53.095238730311394, 55.041319504380226, 56.15442417562008, 56.732817739248276, 56.353100314736366, 49.638222232460976, 41.768076941370964, 40.642755925655365, 41.017184033989906, 43.420053496956825, 47.24717013537884, 54.435670003294945, 58.34932699799538, 45.9688351303339, 49.20558884739876, 50.07049463689327, 53.0080334097147, 49.190150275826454, 51.84962376952171, 51.93603493273258, 51.57270222902298, 47.967539280653, 51.557639837265015, 43.00766542553902, 47.7053115516901, 21.077383495867252, 43.78537729382515, 61.61528214812279, 53.31320643424988, 53.10616314411163, 48.63882265985012, 50.0838965177536, 49.27506811916828, 53.41678887605667, 56.04688614606857, 55.18006145954132, 52.58869931101799, 52.835488468408585, 46.88941553235054, 39.27604526281357, 40.934268683195114, 41.67323023080826, 41.33676968514919, 43.80653455853462, 50.61629734933376, 56.07594318687916, 58.10395136475563, 57.04116739332676, 57.42403864860535, 55.904959961771965, 54.496090561151505, 54.870799854397774, 56.86339773237705, 53.534400165081024, 54.74629193544388, 56.134809628129005, 54.21215459704399, 55.85878863930702, 55.656483694911, 51.14148236811161, 46.8555061519146, 46.53699964284897, 45.603511333465576, 44.48320984840393, 47.57797658443451, 49.70853365957737, 55.552563071250916, 56.14393673837185, 55.629189759492874, 59.19815205037594, 54.23492677509785, 48.278377801179886, 51.21019408106804, 34.16916109621525, 24.88448090851307, 14.56067617982626, 9.228431805968285, 25.468308180570602, 26.03595782071352, 22.148943096399307, 11.230755262076855, 3.858468043617904, 0.22199853061465546, 0.2111369470367208, 0.30191918194759637, 12.440302558243275, 45.5706886947155, 40.64628593623638, 24.88438591361046, 34.249275997281075, 56.160560846328735, 56.473314464092255, 64.55096662044525, 42.566607892513275, 6.581410244107246, 0.20117193722398952, 0.14919654495315626, 0.16820265009300783, 0.07036684328340925, 0.17945812112884596, 0.10349562537157908, 0.17066960834199563, 0.10930486794677563, 0.08224045654060319, 0.16545668884646147, 0.1927932829130441, 0.14747703331522644, 0.18602939351694658, 0.11000799349858426, 0.1575121167115867, 0.29770508932415396, 0.08707736691576429, 0.1551378972362727, 0.25095257617067546], [0.04835796782572288, 0.06700646539684385, 0.030659105723316316, 0.10758513366454281, 0.05009004031307995, 0.066371068242006, 0.019214865715184715, 0.053203850766294636, 0.04964089996065013, 0.017650231020525098, 0.006458190418925369, 0.024570476089138538, 0.020300021060393192, 0.030613055459980387, 0.027561201350181364, 0.023931895120767877, 0.028092825850762893, 0.020885380763502326, 0.18290446198079735, 6.422846177592874, 28.628714494407177, 47.18403272330761, 45.143014043569565, 30.186765789985657, 19.139075204730034, 29.197948649525642, 34.24478463828564, 29.227087385952473, 2.2820273973047733, 0.043019855438615195, 0.12744394422043115, 0.6913771166000515, 4.387356201186776, 7.373400796204805, 8.728350140154362, 3.357673203572631, 5.807394152507186, 8.111890219151974, 27.667364180088043, 44.30571377277374, 53.68122048676014, 53.92577916383743, 53.60359065234661, 52.16220639646053, 52.04583004117012, 48.6955726146698, 50.16199752688408, 50.277211144566536, 51.22737675905228, 53.89447644352913, 52.20944546163082, 47.96832963824272, 49.73673194646835, 52.34213434159756, 52.437539622187614, 50.9992104023695, 47.34733276069164, 41.87280312180519, 37.43023730814457, 36.97916731238365, 41.058575212955475, 46.575198993086815, 50.58039307594299, 51.60595424473286, 52.18828819692135, 53.908664882183075, 47.82377019524574, 38.39255087077618, 35.42817793786526, 35.82810267806053, 38.1666149944067, 38.28926861286163, 42.56987951695919, 52.46695764362812, 45.430050641298294, 33.581226244568825, 52.47658632695675, 50.99469244480133, 54.45236250758171, 50.937011539936066, 54.37947101891041, 49.0081362426281, 54.209251552820206, 47.011050805449486, 52.61690519750118, 44.89342823624611, 49.62909132242203, 21.227562837302685, 45.81414543092251, 55.091484412550926, 49.14510749280453, 47.21774451434612, 42.312781512737274, 43.83833885192871, 40.47007039189339, 41.88117787241936, 42.68236868083477, 44.82102692127228, 46.767206490039825, 45.766815170645714, 39.60953816771507, 37.25740738213062, 37.671866342425346, 38.24660450220108, 37.31712497770786, 37.81664617359638, 38.50911341607571, 43.193581849336624, 45.54524526000023, 48.449152037501335, 46.72711484134197, 47.336066365242004, 45.33318243920803, 46.25034682452679, 46.40421196818352, 49.08481992781162, 50.98907634615898, 49.94172714650631, 51.37352451682091, 49.96726557612419, 48.25796529650688, 40.79185992479324, 37.537201568484306, 37.51931972801685, 38.89262303709984, 40.334375873208046, 39.80249561369419, 41.485045328736305, 47.01765485107899, 47.40798510611057, 55.961915105581284, 51.699645817279816, 54.85559307038784, 43.133248686790466, 57.983893007040024, 43.217284977436066, 30.4690982401371, 24.607371278107166, 10.17739288508892, 15.319555308669806, 11.484539844095707, 3.954978114925325, 7.5315093621611595, 12.370917331427336, 2.20657033380121, 0.45444887538906187, 0.1438009086996317, 3.1871319422498345, 29.00020156055689, 43.39803367853165, 24.08848062157631, 15.34461211413145, 23.952962793409824, 47.67050921916962, 49.051199331879616, 39.17391814291477, 9.161184914410114, 0.13246061018435284, 0.030032193171791732, 0.017196120134030934, 0.039454796933569014, 0.014298617898020893, 0.031229095548042096, 0.04579876804200467, 0.04562116468150634, 0.014529667951137526, 0.03730949290911667, 0.05649267077387776, 0.04181052579951938, 0.056541136727901176, 0.03170477139065042, 0.05167518240341451, 0.01907052912429208, 0.011099569001089549, 0.05470907468406949, 0.02241049980511889, 0.028581498554558493, 0.0620450745918788, 0.04234875726979226, 0.06330533040454611, 0.025591769626771566, 0.07109486046829261, 0.030363858968485147, 0.03544473183865193, 0.028691082225122955, 0.059814720443682745, 0.01898505783174187, 0.03953882660425734, 0.04056764366396237, 0.06256543885683641, 0.012327237109275302, 0.07156484032748267, 0.03516758792102337, 0.03206219342246186, 0.32445149787236005, 8.312583100050688, 34.54778037965298, 55.6584519892931, 49.9225115776062, 34.89339083433151, 22.748670615255833, 28.05044822394848, 34.6183767914772, 33.254538774490356, 3.1190184596925974, 0.023700024066783953, 0.11772909754654393, 1.258326347451657, 5.3242695517838, 9.701763857156038, 5.943452501669526, 6.885203942656517, 2.320963670499623, 6.790976598858833, 28.39146852493286, 45.567873045802116, 54.14147078990936, 54.71237115561962, 53.22826959192753, 52.32924543321133, 52.046966180205345, 50.02977602183819, 51.12984359264374, 51.70919470489025, 52.351926416158676, 54.52629514038563, 55.020660012960434, 51.22877888381481, 51.6052170842886, 54.32764180004597, 54.65060546994209, 51.6645585000515, 48.721346631646156, 43.20790708065033, 40.77586658298969, 39.117289781570435, 44.03048314154148, 48.49103718996048, 51.20978370308876, 53.75321142375469, 55.12486942112446, 55.123588889837265, 51.35059654712677, 39.74217765033245, 37.43456147611141, 37.676958069205284, 39.43893872201443, 38.939603716135025, 43.869975954294205, 54.1761477291584, 49.3195029348135, 35.66775128245354, 52.349095568060875, 51.943068355321884, 55.25274395942688, 51.82220444083214, 54.76619526743889, 50.31134471297264, 55.08655607700348, 48.79459910094738, 52.25068084895611, 44.96312029659748, 49.819681495428085, 21.984031945466995, 46.12436458468437, 56.075065433979034, 51.58366084098816, 51.05860881507397, 44.06519427895546, 45.00508524477482, 43.04485023021698, 43.87442171573639, 44.651818200945854, 47.506361827254295, 47.760522589087486, 47.16921731829643, 42.446545735001564, 39.891551434993744, 39.621408730745316, 39.7358737885952, 39.60239075124264, 39.714233949780464, 41.82172626256943, 46.267487704753876, 47.690667137503624, 50.59332758188248, 49.94101658463478, 49.97481197118759, 47.7557348459959, 48.73143509030342, 49.90255504846573, 51.886576786637306, 52.28906638920307, 51.409470587968826, 54.31130267679691, 52.512410804629326, 50.41916772723198, 42.915326580405235, 40.24386093020439, 39.881656765937805, 40.7116424292326, 40.707618445158005, 41.91759891808033, 44.17805962264538, 48.50068487226963, 50.22806458175182, 58.53882662951946, 54.351272732019424, 54.26784820854664, 44.57833394408226, 60.13858638703823, 45.18127799034119, 33.67642633616924, 24.09097708761692, 11.63752818480134, 9.27536878734827, 10.28772946447134, 12.655176278203726, 3.6440695356577635, 3.4048210736364126, 1.2466487428173423, 0.46448490873444825, 0.0683533372648526, 4.0456742607057095, 34.78950060904026, 42.79013849794865, 24.18309934437275, 22.19853613525629, 29.33327078819275, 54.216060787439346, 55.78089661896229, 43.65757495164871, 11.317210122942924, 0.1784734841203317, 0.028174217186460737, 0.011022106409654953, 0.008821963238005992, 0.07125700489268638, 0.053737863127025776, 0.03438996929617133, 0.04451560213055927, 0.032628251719870605, 0.04270522193110082, 0.0662189799186308, 0.02236427699244814, 0.03218609497707803, 0.0189358961142716, 0.03864742560836021, 0.007951210645842366, 0.014607239081669832, 0.026610862696543336, 0.027033584447053727, 0.19243112968979403, 0.175896821601782, 0.1352658393443562, 0.2591982821468264, 0.15246574999764562, 0.1700966406497173, 0.12113722521462478, 0.13678353134309873, 0.1079613134788815, 0.08389274444198236, 0.1390085494494997, 0.19978376483777538, 0.09760734406881966, 0.1571358775254339, 0.08226063553593121, 0.09888298460282385, 0.11541945234057494, 0.1077391515718773, 0.6184858060441911, 10.720532890409231, 42.61157467961311, 62.073830142617226, 57.655814811587334, 42.82887361943722, 30.94785165041685, 39.19964276254177, 47.66145430505276, 40.14799207448959, 3.7076752725988626, 0.11872969815158285, 0.27594929735641927, 1.4604612509720027, 9.607792999595404, 16.20604109019041, 15.876587368547916, 14.159040581434965, 16.329895444214344, 13.193502891808748, 33.294087052345276, 46.99470028281212, 54.92907352745533, 55.36463275551796, 53.37623365223408, 52.71526671946049, 55.143887400627136, 49.678275883197784, 50.23367688059807, 52.20435373485088, 51.96547955274582, 55.11917732656002, 56.277602165937424, 52.89555564522743, 55.02575933933258, 54.96588975191116, 55.9488932043314, 53.917548805475235, 51.44548885524273, 44.76244926452637, 41.38372376561165, 40.544766783714294, 46.2288323789835, 51.12982079386711, 53.30909885466099, 55.30886694788933, 56.078625842928886, 58.77129055559635, 52.79856964945793, 42.775353491306305, 38.424465358257294, 39.02077496051788, 41.304015442728996, 42.51933082938194, 46.097363233566284, 56.02485492825508, 51.77598752081394, 38.049524277448654, 52.03307792544365, 54.44963425397873, 57.62282118201256, 55.71457877755165, 57.696856409311295, 52.72823162376881, 58.767828941345215, 50.69858193397522, 53.6773256957531, 47.504294738173485, 49.221316203475, 26.13175828009844, 47.42864839732647, 59.93160769343376, 53.24217304587364, 54.667396768927574, 45.554117783904076, 48.88876564800739, 45.064491257071495, 46.36430650949478, 46.90729737281799, 49.73833166062832, 49.85752746462822, 51.16073593497276, 42.88395546376705, 40.63343122601509, 41.747470647096634, 42.4011267721653, 40.85198409855366, 42.52599187195301, 43.091975301504135, 47.8341094404459, 49.54217478632927, 52.70406872034073, 51.376248970627785, 52.49085076153278, 50.854354575276375, 51.04169212281704, 50.85126154124737, 54.14512999355793, 56.021085530519485, 53.38264010846615, 56.56811937689781, 56.2952484190464, 51.5941596776247, 44.3520674854517, 42.93180249631405, 41.95243164896965, 42.8398322314024, 44.34667557477951, 44.7671952098608, 46.47242210805416, 50.795100554823875, 52.816725075244904, 60.42476803064346, 57.663114219903946, 56.65392257273197, 46.174214109778404, 61.50794170796871, 48.96544173359871, 35.492044910788536, 26.68295480310917, 14.150739926844835, 24.14749525487423, 22.869891710579395, 12.347455490380526, 20.14433976262808, 22.822247967123985, 4.7352128103375435, 0.9935082856100053, 0.2022241838858463, 4.492090456187725, 39.7507955878973, 56.71443052589893, 34.11309510469437, 25.85803046822548, 36.224535405635834, 59.72135357558727, 63.42248037457466, 50.88522031903267, 14.799213130027056, 0.37568937346804887, 0.15853654767852277, 0.10537187859881669, 0.15244462847476825, 0.2029431171831675, 0.13498597545549273, 0.1511308638146147, 0.2837652404559776, 0.14733458549017087, 0.06779708273825236, 0.13107651961036026, 0.10796918766573071, 0.15573016076814383, 0.12968408729648218, 0.17904685257235542, 0.10012611906859092, 0.08717438046005554, 0.11639705378911458, 0.13536694954382256], [0.0739746457838919, 0.13879466248909011, 0.030430095648625866, 0.0060420668251026655, 0.11464502866147086, 0.05213997465034481, 0.03065703327592928, 0.09649459010688588, 0.04314811340009328, 0.031535405869362876, 0.06281965412199497, 0.03524043342622463, 0.03493100608466193, 0.026989638172381092, 0.0773783576732967, 0.08255028835264966, 0.010432139824843034, 0.03102724065684015, 0.23890656942967325, 8.247467894107103, 33.688528686761856, 49.09674368798733, 46.29871062934399, 35.964218974113464, 20.611300505697727, 28.387138657271862, 40.4071419686079, 23.76228142529726, 1.8031883728690445, 0.05762898792454507, 0.09041382538271137, 0.6448785960674286, 3.700950820930302, 5.221263254061341, 4.33086653240025, 3.439533873461187, 4.886820400133729, 20.599454641342163, 38.39275985956192, 49.86948922276497, 53.158695325255394, 61.521905958652496, 56.434081569314, 51.37695953249931, 51.789419800043106, 53.741534650325775, 49.25285071134567, 52.8229795396328, 50.878604874014854, 52.887393683195114, 51.14919975399971, 46.80902324616909, 47.38464295864105, 47.350429594516754, 54.35201749205589, 50.45396625995636, 51.20580531656742, 48.21536958217621, 43.69260147213936, 38.22450488805771, 38.803206235170364, 38.69834706187248, 40.493290945887566, 46.23311094939709, 47.114519253373146, 44.27096463739872, 39.94186833500862, 37.77816943824291, 39.84361320734024, 36.6169061511755, 37.672200724482536, 35.30252628028393, 45.0894521176815, 52.12970294058323, 47.9748272895813, 52.5634990632534, 51.85574144124985, 52.02396601438522, 53.632955476641655, 49.703058153390884, 47.31139048933983, 48.23561869561672, 48.46279710531235, 46.189709678292274, 50.45747347176075, 48.33869196474552, 49.83642339706421, 24.68763057142496, 39.86606240272522, 55.2583334594965, 46.3975927233696, 49.43097375333309, 44.04493376612663, 42.51816049218178, 38.505458012223244, 38.840850815176964, 39.40217189490795, 41.20970070362091, 41.50594040751457, 40.25890052318573, 38.712128922343254, 39.05341520905495, 36.36864647269249, 39.767229706048965, 37.802130952477455, 38.943186923861504, 37.69400015473366, 36.260758861899376, 37.14252434670925, 38.215009197592735, 39.172257632017136, 38.84773224592209, 40.2726823836565, 41.274198442697525, 41.66613221168518, 41.06169104576111, 41.87659911811352, 41.50790490210056, 42.99585945904255, 39.76915620267391, 39.36659060418606, 37.832016348838806, 39.36697818338871, 41.43297292292118, 43.60060080885887, 43.70259873569012, 45.67165307700634, 46.92472703754902, 48.25837567448616, 49.20221082866192, 52.58540868759155, 51.18378929793835, 55.60378432273865, 49.233198165893555, 48.727202117443085, 48.85921083390713, 39.4730456918478, 26.305986531078815, 15.139987394213676, 8.604689575731754, 5.076750833541155, 10.026633124798536, 3.753472315147519, 49.46068815886974, 48.751581609249115, 2.7397370617836714, 0.16081041394500062, 1.064619985409081, 26.051592081785202, 41.07185550034046, 24.790681041777134, 22.709707506000996, 32.954465076327324, 44.36679169535637, 55.04963345825672, 49.01732034981251, 11.874098740518093, 0.4686598159605637, 0.05269314926408697, 0.09420851551112719, 0.13642090314533561, 0.03780591920076404, 0.0038084411971794907, 0.020588757324730977, 0.034241064786328934, 0.07637950853677467, 0.1067241161945276, 0.1782284418004565, 0.021446130849653855, 0.057089721158263274, 0.06855221799924038, 0.04494755434279796, 0.05634712077153381, 0.047261889922083355, 0.04065896493557375, 0.027279290989099536, 0.040153202426154166, 0.05178697581868619, 0.019733693734451663, 0.026283126571797766, 0.07894511305494234, 0.0420905566716101, 0.0233644935360644, 0.051802820671582595, 0.04226240467687603, 0.020565041995723732, 0.052535168288159184, 0.014801989764237078, 0.01891753538075136, 0.015149023583944654, 0.018907978374045342, 0.06275648993323557, 0.011461701815278502, 0.03552934780600481, 0.25637666636612266, 9.664891585707664, 40.11448547244072, 55.332258492708206, 51.41935385763645, 39.25578474998474, 23.53666853159666, 27.25104331970215, 39.35129262506962, 28.18387046456337, 1.7884027725085616, 0.01779608901415486, 0.2634837693767622, 2.1319470880553126, 6.30066848360002, 9.200933631509542, 11.150391474366188, 5.626142928376794, 5.721042836084962, 21.396114192903042, 40.01773126423359, 51.622304767370224, 54.74678970873356, 59.31441821157932, 56.49749256670475, 53.31566110253334, 53.27036373317242, 54.38882231712341, 49.96595464646816, 52.49767139554024, 52.040217742323875, 54.18779030442238, 52.26405993103981, 48.396920040249825, 49.898736253380775, 50.71566581726074, 55.04143349826336, 52.27013200521469, 53.13557356595993, 49.6125166118145, 44.48752261698246, 39.44540597498417, 40.55496163666248, 40.58645434677601, 43.070065677165985, 48.65179896354675, 50.61689391732216, 46.25836439430714, 42.42531247437, 38.71012642979622, 41.1668998003006, 38.72581198811531, 39.03523698449135, 38.40944856405258, 46.058115139603615, 54.805431962013245, 51.282960176467896, 50.34426994621754, 52.36234925687313, 54.66389715671539, 55.241488963365555, 51.67802877724171, 51.30813382565975, 49.58255521953106, 51.33285529911518, 48.966775462031364, 53.6115588247776, 50.20892880856991, 49.468432143330574, 26.576096937060356, 41.23160272836685, 57.459220960736275, 50.856797844171524, 51.09146185219288, 45.502425357699394, 44.53593961894512, 39.12803940474987, 41.84229835867882, 41.27884939312935, 44.26877975463867, 43.02533067762852, 42.455490455031395, 41.1505226790905, 39.23225261271, 38.57761234045029, 40.6989549100399, 41.28264918923378, 40.17229937016964, 39.8775339871645, 37.84403510391712, 40.61679191887379, 40.92867538332939, 41.57784014940262, 41.759717389941216, 43.06131474673748, 43.18354658782482, 43.546442314982414, 44.78275537490845, 44.286824986338615, 44.398216009140015, 45.67915767431259, 43.73428903520107, 42.193030938506126, 39.31400902569294, 40.93120604753494, 43.18364538252354, 45.2178206294775, 44.89738382399082, 46.95049345493317, 48.55644308030605, 50.2269284427166, 50.96532762050629, 55.42276583611965, 53.92167158424854, 56.57509960234165, 49.57434006035328, 52.42334358394146, 51.870651841163635, 40.10600432753563, 26.804557777941227, 19.552177637815475, 9.375652056187391, 6.914953971281648, 7.705695815384388, 9.383589830249548, 37.09318779408932, 35.05530394613743, 2.784764883108437, 0.1523952608113177, 1.3793120929040015, 27.823159620165825, 47.304125279188156, 28.102520629763603, 22.802755013108253, 36.64710313081741, 52.66607075929642, 59.55849431455135, 56.228535398840904, 14.771294128149748, 0.4829976934706792, 0.10089763352880254, 0.060111011771368794, 0.03435351871303283, 0.04959273457643576, 0.039001277909846976, 0.009972797724913107, 0.04891067488642875, 0.03639805763668846, 0.03471493721008301, 0.08481959041091613, 0.019271476739959326, 0.052362103160703555, 0.07064307064865716, 0.06355409088428132, 0.07938753697089851, 0.05648288184602279, 0.05630433966871351, 0.09540348459267989, 0.13620548736071214, 0.30270161340013146, 0.13774741790257394, 0.09582513579516672, 0.2126480487640947, 0.20441773493075743, 0.12421329374774359, 0.23323099507251754, 0.14438748738029972, 0.18338204885367304, 0.18684122886043042, 0.12508293497376144, 0.054436506106867455, 0.08334940328495577, 0.15266176604200155, 0.15192637190921232, 0.12045962212141603, 0.1882084578392096, 0.576987995300442, 14.251981694251299, 50.85284225642681, 63.6281481385231, 58.50348852574825, 47.22952388226986, 30.52583869546652, 38.52079778909683, 51.21841304004192, 32.939064502716064, 2.7485908241942525, 0.21508998179342598, 0.9073351440019906, 1.855680774897337, 10.25260889902711, 15.952699184417725, 16.73957996070385, 8.517445307224989, 8.49649703130126, 26.04472205042839, 43.12828615307808, 52.70389772951603, 55.12229695916176, 60.25977708399296, 57.04090900719166, 55.65161615610123, 53.26568618416786, 54.41391237080097, 51.5389334410429, 51.94575101137161, 51.59520082175732, 55.16304597258568, 55.70250302553177, 50.16624569892883, 50.991215631365776, 52.75587514042854, 57.0959110558033, 54.27216857671738, 55.16444809734821, 51.75771050155163, 47.41773158311844, 42.08402618765831, 41.69116146862507, 42.10026651620865, 45.23049674928188, 49.83502887189388, 51.12493805587292, 48.092894554138184, 43.87540206313133, 42.6913096010685, 43.36927682161331, 41.050686836242676, 40.92254251241684, 39.19612415134907, 47.5636475533247, 57.269709929823875, 52.70695276558399, 51.591845601797104, 54.55108880996704, 57.95707404613495, 59.695929139852524, 53.890555053949356, 52.895137667655945, 52.60855704545975, 55.24861738085747, 51.255981624126434, 54.62382450699806, 51.37599818408489, 48.52796360850334, 28.667223528027534, 43.33165504038334, 58.229675218462944, 52.02113516628742, 55.12110762298107, 48.36837597191334, 46.37360081076622, 44.458431378006935, 43.06197211146355, 43.95388305187225, 46.11637361347675, 44.86310586333275, 44.17076401412487, 42.06839382648468, 42.92987979948521, 40.581966787576675, 43.34706701338291, 41.60210184752941, 42.72373706102371, 42.07295358181, 39.66154217720032, 40.94426214694977, 42.823922485113144, 43.24809372425079, 44.40911002457142, 45.175008326768875, 45.86625203490257, 45.43998330831528, 46.20321795344353, 47.42906257510185, 45.39574608206749, 46.36139586567879, 45.200998932123184, 42.51681536436081, 41.73232086002827, 42.84322924911976, 45.822375789284706, 48.88965480029583, 49.06554736196995, 49.88542556762695, 51.86749801039696, 54.37867686152458, 54.988931715488434, 58.162342831492424, 56.29783608019352, 57.094296142458916, 50.18725477159023, 52.87627547979355, 53.3627025783062, 41.16793714463711, 30.725886560976505, 21.960640400648117, 14.734865482896566, 13.134189024567604, 19.462593644857407, 11.61280196160078, 52.23912946879864, 54.47149448096752, 3.8376411236822605, 0.23901545733679086, 1.981975429225713, 32.40164794027805, 55.33819757401943, 34.29406799376011, 35.013308599591255, 43.82609210908413, 56.83054469525814, 66.29343152046204, 63.95412504673004, 19.544483050704002, 0.9625331789720803, 0.1618586530094035, 0.30983590870164335, 0.3396273194812238, 0.15011238487204537, 0.10482928701094352, 0.1338556845439598, 0.05731977209507022, 0.12924573034979403, 0.16907595010707155, 0.2876546879997477, 0.09752919591846876, 0.14589496742701158, 0.13391944987233728, 0.1611554977716878, 0.2899543661624193, 0.09268268215237185, 0.13792234210995957, 0.14977261482272297], [0.041745669514057226, 0.03833879978628829, 0.05466462745971512, 0.07330882057431154, 0.02306614460394485, 0.006302836181930616, 0.020936288383381907, 0.030895669005985837, 0.020654645195463672, 0.013571263079938944, 0.05927178375713993, 0.025787477679841686, 0.037749374969280325, 0.047363426856463775, 0.019458301285339985, 0.03899566727341153, 0.048960194690153, 0.04841129484702833, 0.5173251405358315, 9.4059506803751, 31.557371243834496, 49.91265490651131, 43.41963171958923, 33.547183871269226, 19.515842087566853, 28.121627904474735, 33.1053663790226, 17.698846086859703, 0.6198534357827157, 0.055796209708205424, 0.03134049191430677, 2.5306537561118603, 5.259425081312656, 8.17571634426713, 5.815263530239463, 5.228200256824493, 6.90778280608356, 20.480270236730576, 39.62622307240963, 53.21952626109123, 62.33939029276371, 55.78539177775383, 44.669149070978165, 51.614640578627586, 50.00728502869606, 48.88118505477905, 49.34869296848774, 50.789267867803574, 50.97103111445904, 50.93685954809189, 51.58647648990154, 50.047395676374435, 46.2154570966959, 46.03568114340305, 48.80141593515873, 49.67117786407471, 50.51124818623066, 48.823732137680054, 49.33678060770035, 42.44645074009895, 37.318120524287224, 36.463493183255196, 37.41519011557102, 35.77197968959808, 37.45614051818848, 37.9937394708395, 37.796127274632454, 36.546096950769424, 40.45295611023903, 36.244206950068474, 38.09107884764671, 34.994032233953476, 44.00885850191116, 53.54047603905201, 52.62741543352604, 50.69018438458443, 51.807822212576866, 50.29174916446209, 48.77649687230587, 43.31896752119064, 44.4668935239315, 42.50187836587429, 45.30394300818443, 44.72430691123009, 48.46649810671806, 46.30213804543018, 54.4435203820467, 21.977213211357594, 38.23596507310867, 54.06546346843243, 48.256775960326195, 50.65047651529312, 45.61041176319122, 46.537109836936, 41.16028055548668, 39.521584287285805, 36.74442730844021, 37.84578301012516, 36.90441772341728, 38.60665798187256, 36.41022004187107, 36.837799698114395, 36.419681534171104, 37.53596283495426, 38.156268149614334, 38.51820632815361, 41.456060484051704, 41.374991834163666, 37.148786410689354, 37.73582451045513, 37.563758343458176, 38.12477543950081, 37.41946868598461, 39.23417150974274, 37.4404663592577, 37.96990714967251, 38.93859677016735, 36.81119732558727, 37.070590406656265, 38.68373304605484, 38.69005210697651, 41.56448386609554, 45.318017452955246, 44.175148978829384, 48.16532626748085, 46.58378653228283, 48.39633867144585, 48.210711032152176, 47.54228509962559, 47.04946294426918, 53.016742542386055, 51.57405115664005, 51.95875771343708, 48.972881734371185, 48.63781191408634, 47.75420732796192, 47.889183685183525, 29.5264695212245, 20.62814310193062, 11.335662882775068, 4.143395991995931, 19.430819749832153, 4.115647030994296, 23.365615010261536, 23.018285147845745, 0.756745187100023, 0.055804978183005005, 0.5511312140151858, 17.75249730795622, 39.14192005991936, 34.77090820670128, 28.081648349761963, 23.10868799686432, 38.38743634521961, 44.28216263651848, 47.671725153923035, 18.017749674618244, 1.0891107399947941, 0.08072628232184798, 0.03803525396506302, 0.05245134641882032, 0.02071736966172466, 0.014048057710169815, 0.07522117928601801, 0.023618797858944163, 0.0238672206614865, 0.03726657079823781, 0.03333701388328336, 0.017113289031840395, 0.0633417624339927, 0.06037507533619646, 0.01679969824181171, 0.03317250571853947, 0.019638513294921722, 0.09026054962305352, 0.05197827180381864, 0.020757410384248942, 0.039221781116793863, 0.03603771154303104, 0.06467576546128839, 0.02884107583668083, 0.03695112834975589, 0.028515022531792056, 0.0434342966764234, 0.019473107131489087, 0.033072616352001205, 0.02380090420047054, 0.07086307290592231, 0.03699746805068571, 0.05606811035249848, 0.02558822958235396, 0.029853975684090983, 0.04532174520136323, 0.0850664584140759, 0.4521793284220621, 11.686135176569223, 38.04628685116768, 57.12567485868931, 48.641965091228485, 40.33353231847286, 24.136453047394753, 27.930222675204277, 36.84763357043266, 19.980036579072475, 0.7874443929176778, 0.09621041434002109, 0.08210062849684618, 1.6251635318621993, 8.249398190528154, 10.39791690185666, 9.265770502388477, 6.792463744059205, 9.800063632428646, 21.48656453937292, 41.97178781032562, 52.810964584350586, 60.301844626665115, 57.54121296107769, 49.43307884037495, 53.3272884786129, 51.46532379090786, 50.66616207361221, 51.60892188549042, 51.00202605128288, 50.75500130653381, 52.340204045176506, 53.96045610308647, 50.97765415906906, 48.396372869610786, 49.18644927442074, 50.62600202858448, 52.25060485303402, 52.24929392337799, 51.12294316291809, 50.16277648508549, 44.29584950208664, 37.5287052243948, 38.667709305882454, 38.55981409549713, 37.150785103440285, 39.415417984128, 40.13194553554058, 39.96109530329704, 38.70155408978462, 42.106539979577065, 37.713189125061035, 39.1400695592165, 36.65407195687294, 45.007688105106354, 55.3526595979929, 55.540282130241394, 52.13803209364414, 54.393746852874756, 50.95720365643501, 49.584044739603996, 46.42890304327011, 46.19000606238842, 45.21744064986706, 47.76215650141239, 46.79719068109989, 50.40593683719635, 47.52027288079262, 55.19361533224583, 23.67502860724926, 40.40030613541603, 54.37306456267834, 50.70077821612358, 52.930939346551895, 47.92753502726555, 49.40755560994148, 43.29587236046791, 41.79819792509079, 40.14989197254181, 40.47944828867912, 40.5486311763525, 40.26008985936642, 38.34721930325031, 39.05953288078308, 38.90311427414417, 40.160375609993935, 39.94544394314289, 40.82356162369251, 41.96034662425518, 43.009344935417175, 37.8475347161293, 40.37408374249935, 39.84874293208122, 40.133484452962875, 39.38302092254162, 40.9460024535656, 38.96654047071934, 39.02272045612335, 39.54573579132557, 38.96630108356476, 39.09128777682781, 41.56208239495754, 40.46038091182709, 44.22268822789192, 46.38872019946575, 47.93188579380512, 51.20908074080944, 49.450253918766975, 49.42981481552124, 50.524965450167656, 49.86328795552254, 50.10169856250286, 56.47874057292938, 53.48107382655144, 52.85018227994442, 49.269900396466255, 50.023479759693146, 51.014477983117104, 47.31815032660961, 31.191885955631733, 16.532306782901287, 15.66199578344822, 6.872158767655492, 10.43788980692625, 7.139175189658999, 25.57260688394308, 30.26774324476719, 1.7549222940579057, 0.045912398272776045, 0.575392555911094, 19.289098754525185, 42.951633632183075, 33.45517560839653, 29.32064786553383, 27.69306980073452, 42.946420311927795, 50.010435059666634, 54.45652708411217, 22.92458977550268, 1.5502150473184884, 0.019165896956110373, 0.04777236877998803, 0.01867265262262663, 0.05739069914852735, 0.020810073183383793, 0.08585418137954548, 0.06932334654266015, 0.04013518679130357, 0.04412198926729616, 0.07288454216904938, 0.024800758947094437, 0.015248035360855283, 0.03152938334096689, 0.04955323376634624, 0.031951962228049524, 0.037531576890614815, 0.1088955438171979, 0.11443407318438403, 0.21662665792973712, 0.1182976271957159, 0.1538835489191115, 0.29661511187441647, 0.12474525778088719, 0.16971401899354532, 0.18253935500979424, 0.0995568027428817, 0.29473925940692425, 0.11376541297067888, 0.17949263099581003, 0.12168975415988825, 0.09763308917172253, 0.1522991675301455, 0.11009898822521791, 0.18207526038167998, 0.18560166412498802, 0.2928461891133338, 0.9511142573319376, 14.175332207232714, 46.807313337922096, 64.1823559999466, 55.58208368718624, 46.222133338451385, 28.03022190928459, 38.66996258497238, 45.19314855337143, 24.533119462430477, 1.2348181963898242, 0.21834369079442695, 0.19362217281013727, 5.8712943736463785, 13.092204127460718, 23.290325850248337, 12.669902388006449, 10.887627024203539, 9.624374359846115, 21.7053434997797, 42.6102789491415, 55.48432633280754, 61.466782316565514, 57.530163154006004, 51.90931096673012, 53.05683419108391, 50.718215480446815, 50.34419395029545, 51.246292144060135, 52.01935686171055, 51.98317900300026, 53.14408890902996, 54.95917171239853, 54.44212965667248, 51.52416743338108, 50.11328414082527, 53.94061356782913, 54.08319711685181, 54.25635002553463, 53.48832383751869, 53.857633620500565, 47.094323337078094, 39.90937627851963, 39.005074203014374, 40.84484048187733, 39.01437230408192, 41.050120666623116, 41.64796158671379, 42.04061731696129, 40.59578664600849, 44.626469761133194, 40.460259318351746, 41.82131588459015, 38.6870426684618, 47.307298108935356, 57.10848078131676, 56.35965496301651, 54.84982118010521, 57.53612883388996, 54.25804853439331, 53.168608993291855, 47.727027386426926, 47.536555007100105, 46.990220323204994, 49.58273001015186, 49.973949417471886, 53.262995928525925, 49.84156832098961, 56.798512414097786, 26.566525250673294, 42.560098841786385, 56.093125864863396, 53.273053988814354, 55.07127329707146, 50.83729349076748, 50.22137314081192, 44.98642064630985, 44.246349558234215, 42.09129139780998, 41.886364594101906, 40.97071252763271, 42.44007848203182, 40.86626373231411, 41.70489773154259, 41.08566015958786, 42.28141039609909, 42.35274016857147, 42.583535984158516, 44.443262591958046, 45.23521989583969, 39.383385702967644, 42.44081184267998, 41.63519807159901, 42.15586893260479, 42.06561237573624, 43.07314731180668, 41.553947031497955, 41.14339426159859, 42.00205318629742, 40.773408114910126, 41.04805737733841, 43.97938348352909, 42.72734686732292, 46.28840558230877, 49.72623310983181, 47.59601041674614, 53.89371648430824, 52.78072960674763, 55.130732506513596, 52.903645411133766, 51.93841740489006, 53.80525343120098, 57.69125930964947, 58.132810816168785, 55.98738133907318, 48.583516627550125, 50.501418113708496, 52.23825551569462, 50.29426082968712, 33.6521228402853, 25.987614914774895, 20.392236560583115, 11.46532142534852, 32.94980652630329, 9.433728139847517, 28.823146261274815, 26.21219616383314, 1.6458992566913366, 0.12172053844551556, 0.7634077733382583, 23.149410411715508, 50.274045914411545, 43.369330018758774, 38.56108322739601, 33.203051537275314, 52.23539046943188, 57.344691306352615, 62.32648618519306, 28.559495508670807, 2.489184681326151, 0.17278189421631396, 0.14949938573408872, 0.1434390968643129, 0.07765251444652677, 0.1513561946921982, 0.20970411220332608, 0.13854441029252484, 0.11022396589396521, 0.13993708009365946, 0.1415697456104681, 0.16513893089722842, 0.16311022569425404, 0.1962586969602853, 0.126318521797657, 0.1634649425977841, 0.09851517621427774, 0.17148769256891683, 0.186169748485554], [0.03670768164738547, 0.028147347729827743, 0.08360221589100547, 0.028341508404992055, 0.05566223349887878, 0.020864769467152655, 0.013629045770358061, 0.0449087919696467, 0.0927765118831303, 0.04413256116094999, 0.02830712099239463, 0.0367270183051005, 0.05429428092611488, 0.0807427208928857, 0.023848616874602158, 0.08567564291297458, 0.009524715860607103, 0.03577076844521798, 0.4092622047755867, 7.562960274517536, 31.895762085914612, 42.17451453208923, 44.371754229068756, 30.033292025327682, 20.741519518196583, 26.71250581741333, 33.384674191474915, 13.255842346698046, 0.16217019176110625, 0.17440035502659157, 0.4065429460024461, 1.9061686657369137, 5.495466515421867, 5.457309912890196, 9.71976064145565, 6.156470971181989, 14.082268550992012, 31.052813418209553, 42.00124002993107, 63.39912302792072, 53.72280925512314, 43.539025112986565, 48.877921029925346, 53.59475612640381, 53.36063928902149, 52.82922640442848, 53.49231742322445, 48.06689254939556, 54.999384954571724, 49.9309167265892, 49.406529664993286, 49.295849204063416, 46.34843476116657, 44.96575355529785, 49.01607021689415, 48.281052857637405, 49.46008399128914, 49.3141870200634, 48.82252000272274, 49.33830052614212, 40.21362215280533, 36.157495602965355, 36.71836070716381, 37.475690469145775, 38.42836394906044, 38.1733900308609, 37.29901894927025, 37.07758203148842, 38.32901827991009, 37.630619555711746, 37.85458713769913, 36.084718108177185, 38.16778153181076, 46.71889208257198, 50.21713636815548, 52.4534759670496, 48.269794061779976, 43.018905222415924, 40.37190645933151, 36.70156180858612, 40.65156005322933, 39.860510900616646, 43.7524900585413, 44.45378802716732, 49.64180164039135, 47.410405576229095, 53.537109419703484, 25.649837739765644, 38.906313702464104, 56.652357056736946, 46.703191325068474, 48.685579150915146, 45.62717646360397, 44.99068781733513, 43.89171838760376, 42.3392128944397, 37.62970380485058, 39.110214561223984, 38.1630127876997, 37.83581994473934, 37.339353784918785, 38.34661893546581, 36.43569007515907, 38.18606995046139, 38.12996216118336, 38.2665990293026, 40.414011999964714, 38.71961452066898, 37.16996267437935, 38.78095842897892, 38.015242516994476, 38.71701925992966, 38.91944959759712, 37.55697190761566, 36.92922279238701, 37.81501226127148, 36.580329313874245, 37.697723954916, 37.48661868274212, 40.082187205553055, 44.88422892987728, 47.257338389754295, 49.45453628897667, 49.921109452843666, 46.18826575577259, 45.5987273901701, 47.89373964071274, 46.49856850504875, 45.717904195189476, 47.24778190255165, 49.241679310798645, 51.88290238380432, 54.10770580172539, 53.084633499383926, 46.56030759215355, 52.650161013007164, 49.87670123577118, 36.27383776009083, 19.33014415204525, 15.83693079650402, 3.382673249579966, 2.0968457590788603, 7.901030508801341, 0.31905881536658853, 1.6365016484633088, 0.19537687709089369, 0.06510877152322792, 0.022375231092155445, 10.473063569515944, 38.58778819441795, 35.62401182949543, 28.57854388654232, 31.29602126777172, 42.49216228723526, 47.23955534398556, 50.048193633556366, 23.930505998432636, 1.7713705427013338, 0.027243476797593758, 0.06377845696988516, 0.08718896366190165, 0.06060973501007538, 0.03649831807706505, 0.11224597692489624, 0.014437762238230789, 0.034936575902975164, 0.06315756880212575, 0.03529945643094834, 0.06711427718983032, 0.04110367466637399, 0.033937760163098574, 0.05967155273538083, 0.027411467490310315, 0.025061636843020096, 0.025332611658086535, 0.053812419282621704, 0.05095911008538678, 0.031436414501513354, 0.062414471176452935, 0.024528544745408, 0.0384554987977026, 0.03559478667739313, 0.09575742966262624, 0.02597924307337962, 0.05794404074549675, 0.060607682971749455, 0.0250178148780833, 0.02283113240991952, 0.026512112526688725, 0.06342893510009162, 0.0069007548790978035, 0.07384575699688867, 0.03132046876999084, 0.01695932307484327, 0.4936491750413552, 9.773789942264557, 38.406853303313255, 50.33863104879856, 51.000080555677414, 34.801922142505646, 22.85512950271368, 33.04582737386227, 38.35164986550808, 14.108381699770689, 0.3407169703859836, 0.21262530935928226, 1.0543882031925023, 2.862947112880647, 7.766887256875634, 9.690946787595749, 15.270721279084682, 9.677048083394766, 11.784710437059402, 30.38658756762743, 45.15893518924713, 62.26122848689556, 54.890068620443344, 47.1432913094759, 50.093665793538094, 55.05569413304329, 51.1181516200304, 52.87114955484867, 51.34714253246784, 49.522970616817474, 53.5292362421751, 51.95879191160202, 53.559714406728745, 50.212724804878235, 47.48710826039314, 46.76025666296482, 51.251893043518066, 51.053144708275795, 51.79832272231579, 50.308354273438454, 51.037622541189194, 50.50595127046108, 41.98734797537327, 38.26259404420853, 38.42660844326019, 38.20063836872578, 41.1514688283205, 37.90664814412594, 39.608158841729164, 39.389594569802284, 40.56087791919708, 39.11343298852444, 39.3440768122673, 38.50016109645367, 41.411564871668816, 49.48583520948887, 53.74134846031666, 52.73569442331791, 50.653531551361084, 44.9403291195631, 42.677151560783386, 39.79690991342068, 42.418693229556084, 41.09424389898777, 45.41189901530743, 47.3203694075346, 51.418962478637695, 49.074009507894516, 53.926364332437515, 27.99981404095888, 40.43647639453411, 60.18993683159351, 48.48792515695095, 51.14919975399971, 48.0014980584383, 47.60749340057373, 44.56793770194054, 42.779537066817284, 39.26220640540123, 40.645070001482964, 39.343324452638626, 39.954544454813, 38.972608745098114, 39.91690747439861, 39.33117650449276, 41.21840223670006, 40.09499251842499, 38.90996150672436, 41.75425708293915, 39.371914118528366, 40.25320842862129, 40.85686683654785, 41.144644394516945, 40.79025641083717, 40.49547582864761, 39.58028353750706, 39.65085335075855, 40.141175240278244, 38.84041763842106, 40.89099660515785, 38.30777741968632, 43.25965650379658, 47.57235288619995, 49.30543228983879, 50.74592739343643, 52.010925114154816, 49.78164553642273, 50.083041563630104, 49.93432894349098, 49.77503389120102, 49.10667635500431, 49.92949180305004, 50.84321357309818, 54.675030559301376, 55.701298490166664, 52.87873014807701, 48.556393682956696, 53.20082746446133, 50.359419733285904, 36.18246406316757, 22.24979728460312, 15.332030989229679, 6.456948397681117, 10.926471389830112, 9.135139212012291, 3.6075853183865547, 3.493139259517193, 0.2658261655597016, 0.09561121914885007, 0.29972221702337265, 12.867616228759289, 43.59060354530811, 41.914353892207146, 34.4773093611002, 34.85551066696644, 49.147592559456825, 53.07008408010006, 57.0440324395895, 29.563175551593304, 2.087086932733655, 0.02781678402243415, 0.014031410410098033, 0.09311187357525341, 0.032435263638035394, 0.07646084050065838, 0.054192588140722364, 0.061801045303582214, 0.030396313086384907, 0.07404707939713262, 0.004179875904810615, 0.03168811759678647, 0.040290933902724646, 0.0817765029205475, 0.06917068676557392, 0.06521512128529139, 0.07024107151664793, 0.012717629979306366, 0.019881065709341783, 0.16384011309128255, 0.10773715519462712, 0.18501331913284957, 0.10965633424348198, 0.13218009320553392, 0.18869456456741318, 0.21072742994874716, 0.14018716901773587, 0.23344278917647898, 0.15944787533953786, 0.1090545192710124, 0.08676339391968213, 0.13562923937570304, 0.22594328300328925, 0.14031844009878114, 0.1289521367289126, 0.1514896922162734, 0.1362914132187143, 0.5752410390414298, 12.833250872790813, 46.66370764374733, 58.36000822484493, 55.73135107755661, 42.72095561027527, 28.351819552481174, 38.08665208518505, 43.70225675404072, 18.068539649248123, 0.5205646448303014, 0.42741564160678536, 1.0670899716205895, 3.660091613419354, 13.61366344615817, 12.835843283683062, 16.710842102766037, 13.108037877827883, 16.958799697458744, 35.372909903526306, 46.08779914677143, 59.850584641098976, 54.55935336649418, 50.92018984258175, 51.66786432266235, 53.533457815647125, 51.72014191746712, 53.180924132466316, 52.3233937472105, 49.99623902142048, 54.53502707183361, 53.75233367085457, 53.93626660108566, 53.05601343512535, 50.10281190276146, 48.57982322573662, 53.59773896634579, 53.56093794107437, 52.798778638243675, 52.18809060752392, 52.501596584916115, 54.10259887576103, 44.53961782157421, 39.54969137907028, 40.683976113796234, 39.51774649322033, 43.1354221701622, 41.2275293469429, 40.48312649130821, 41.37526921927929, 40.987925603985786, 40.386341884732246, 40.875539034605026, 40.78369416296482, 42.36943647265434, 50.6754981726408, 56.00918456912041, 56.8730416148901, 52.251296415925026, 47.44416296482086, 43.45083184540272, 41.233757212758064, 45.53131900727749, 43.42142902314663, 47.707819417119026, 49.669923931360245, 55.402102544903755, 50.91461934149265, 55.56545577943325, 30.488783083856106, 43.462611213326454, 61.92953668534756, 51.06618940830231, 53.59077014029026, 50.74408829212189, 50.07177896797657, 47.85039156675339, 46.73059165477753, 41.548140943050385, 43.334052711725235, 41.75877884030342, 41.542901024222374, 41.1826803535223, 43.1608010083437, 42.56024323403835, 43.48770506680012, 42.49007239937782, 41.75782889127731, 42.84751161932945, 42.266682386398315, 42.487853318452835, 42.56487138569355, 41.80793300271034, 42.971441969275475, 42.96788915991783, 41.7573881149292, 40.802373960614204, 42.499473094940186, 40.434986874461174, 42.68372900784016, 40.726750418543816, 44.951169937849045, 50.60024321079254, 52.023255452513695, 52.85278134047985, 54.112189561128616, 52.421196699142456, 53.039491921663284, 52.49693423509598, 50.54965652525425, 51.58721745014191, 52.19143062829971, 54.97933343052864, 56.50571912527084, 58.896509036421776, 54.870457872748375, 48.60133767127991, 54.57543410360813, 55.860213562846184, 38.26967306435108, 24.503446854650974, 19.254465512931347, 11.115822829306126, 9.702999740839005, 14.479219950735569, 2.6122066425159574, 2.4823165498673916, 1.169755356386304, 0.38620254839770496, 0.6543165177572519, 14.46044135838747, 51.33565574884415, 48.56681652367115, 38.60869087278843, 44.26681146025658, 55.20973786711693, 58.4531906247139, 62.912475541234016, 37.08654195070267, 3.1218419456854463, 0.10549279671977274, 0.2938761713448912, 0.19507850403897464, 0.15558428422082216, 0.1354623303632252, 0.19394702569115907, 0.14429755392484367, 0.1524225718458183, 0.20236226788256317, 0.0919969376991503, 0.12322324648266658, 0.12719542864942923, 0.156410769559443, 0.15002914558863267, 0.06657068370259367, 0.15633195347618312, 0.09394384338520467, 0.24684499658178538], [0.03974074643338099, 0.015604378495481797, 0.03222612271201797, 0.015709620602137875, 0.0045484324709832435, 0.03052645239222329, 0.031926944429869764, 0.03008034371305257, 0.01661444519413635, 0.10505970160011202, 0.02416030220047105, 0.10149398629437201, 0.043383808369981125, 0.08541884497390129, 0.015423900240421062, 0.08202315570088103, 0.04425298946443945, 0.07913353692856617, 0.29972960881423205, 8.654896281659603, 30.802480950951576, 40.50451934337616, 38.591227009892464, 25.92012293636799, 23.28937590122223, 25.705491453409195, 31.433503590524197, 8.512907400727272, 0.24612091277958825, 0.05444133377750404, 0.13408119353698567, 1.3580408343113959, 8.880178593099117, 6.7719510197639465, 10.953718777745962, 6.822260320186615, 17.624001502990723, 29.779169261455536, 49.50147897005081, 59.61133807897568, 42.0026383548975, 41.60745196044445, 52.96896770596504, 54.62542422115803, 53.343980982899666, 50.24028852581978, 54.248875826597214, 47.59920224547386, 44.68395307660103, 54.118071645498276, 48.038941249251366, 54.21513743698597, 44.98034477233887, 45.92951484024525, 45.87660647928715, 51.31921783089638, 47.34736315906048, 49.865309447050095, 50.30149944126606, 50.27385212481022, 47.824328765273094, 41.5109371393919, 37.97966122627258, 35.43615370988846, 38.41028831899166, 34.7167307138443, 39.14043813943863, 35.88292233645916, 38.11991170048714, 38.123323917388916, 36.91754221916199, 38.94982896745205, 38.72944459319115, 37.24729232490063, 39.755678325891495, 40.692115277051926, 38.58078517019749, 37.152947187423706, 38.76982502639294, 37.54794359207153, 42.944824397563934, 42.58332319557667, 44.070738181471825, 43.06614428758621, 47.2794646024704, 46.20048590004444, 53.851219564676285, 25.035435408353806, 39.62949089705944, 53.3349184691906, 43.917036429047585, 48.55561852455139, 42.3796883225441, 44.89524453878403, 41.03963702917099, 38.512027859687805, 38.701531291007996, 38.16531926393509, 39.40251387655735, 38.85438948869705, 37.12227143347263, 40.147581696510315, 38.01924370229244, 39.21683683991432, 38.45747798681259, 38.57235722243786, 37.58637472987175, 38.31302493810654, 38.274863585829735, 38.539853766560555, 37.743975073099136, 38.08473698794842, 38.33343744277954, 37.41315722465515, 35.50798885524273, 37.58176177740097, 36.21418856084347, 35.36191329360008, 41.86551511287689, 46.79024465382099, 49.02977228164673, 52.64904007315636, 47.61823542416096, 47.58226275444031, 46.438493728637695, 48.42464715242386, 46.03090859949589, 45.505959168076515, 43.336283192038536, 45.747360214591026, 49.62823636829853, 53.46828751266003, 51.22009254992008, 50.408239513635635, 46.85204453766346, 54.44938346743584, 52.18763843178749, 45.40185995399952, 26.32224015891552, 21.488884314894676, 9.583348911255598, 5.083120716735721, 6.791098192334175, 3.4190446604043245, 3.1148840440437198, 0.2347582607762888, 0.07404037038213573, 0.11213626523385756, 6.117019588127732, 30.238800197839737, 29.921551421284676, 29.551821760833263, 25.44906411319971, 28.68697676807642, 41.16404615342617, 46.76729388535023, 30.153082497417927, 2.23702403716743, 0.042946709363604896, 0.03695666848216206, 0.033148022266686894, 0.03212339463061653, 0.04223132353217807, 0.0596570845664246, 0.0608241674490273, 0.03366009674209636, 0.0416541812592186, 0.028650701970036607, 0.053980931334081106, 0.03157003447995521, 0.05521049191884231, 0.0508363180415472, 0.019790824262599926, 0.024148335069185123, 0.023299935965042096, 0.033461345883551985, 0.05759350213338621, 0.031116585960262455, 0.03904775861883536, 0.06009232449287083, 0.024189268224290572, 0.07843307568691671, 0.016062222384789493, 0.008697404882695992, 0.005675471384165576, 0.07025348764727823, 0.053771898019476794, 0.027370350653654896, 0.026289805900887586, 0.01354611540591577, 0.0403602616279386, 0.037959655091981404, 0.008890010758477729, 0.14545769401593134, 0.41824441810604185, 10.85671378299594, 37.372685596346855, 50.358648374676704, 45.558730736374855, 30.47387458384037, 25.519930310547352, 31.276629008352757, 37.83084221184254, 9.650007784366608, 0.31942905799951404, 0.0375080545200035, 0.7781304395757616, 4.690132979303598, 5.942704891785979, 4.986463403329253, 11.705888416618109, 8.655100520700216, 17.38170750439167, 31.816564835608006, 49.095497354865074, 60.53983725607395, 45.33410958945751, 46.28345064818859, 52.93272905051708, 53.60397443175316, 53.621423095464706, 51.86166912317276, 54.96673330664635, 47.93080285191536, 48.72971758246422, 54.05693292617798, 50.0295290350914, 55.172021090984344, 47.388032376766205, 47.55410246551037, 48.55469897389412, 52.05743841826916, 50.40412053465843, 51.80425800383091, 51.529050171375275, 53.099870681762695, 49.07336734235287, 42.789845913648605, 39.23962041735649, 37.649166360497475, 40.160614997148514, 37.86657929420471, 39.780547991395, 37.453739047050476, 40.25303743779659, 40.42760007083416, 37.66686201095581, 41.07080675661564, 40.29221713542938, 40.347367376089096, 42.2126454859972, 44.32966768741608, 40.6164575368166, 38.73803973197937, 39.41297471523285, 40.17862983047962, 45.23442193865776, 44.30060304701328, 46.795188188552856, 45.93147933483124, 49.2370967566967, 47.87740811705589, 54.94181804358959, 27.168116569519043, 40.61035506427288, 55.83084113895893, 47.33253635466099, 50.98947912454605, 45.5589435249567, 47.35450677573681, 44.214416071772575, 42.21774481236935, 41.349977776408195, 39.6469509601593, 42.92231820523739, 41.27594634890556, 39.5096605271101, 40.3912740200758, 39.780726581811905, 41.61842197179794, 39.155131950974464, 39.84653905034065, 40.979512855410576, 40.60305565595627, 39.823250100016594, 40.44216848909855, 40.23542158305645, 40.384187400341034, 40.318511724472046, 38.0783761292696, 40.08581221103668, 39.09635290503502, 38.81074123084545, 37.05040968954563, 43.89514200389385, 49.39198784530163, 52.66923978924751, 53.29888500273228, 49.88933555781841, 49.334052354097366, 50.3518695384264, 50.9920933842659, 48.13148148357868, 47.847465723752975, 46.74575664103031, 47.52021588385105, 52.329621613025665, 53.666294887661934, 53.480359464883804, 49.66794803738594, 49.41775046288967, 54.68334451317787, 56.082079857587814, 42.950166910886765, 27.511450946331024, 17.30486422777176, 13.597128633409739, 7.202923893928528, 8.103454671800137, 6.925058579072356, 1.897148306015879, 0.5311815720051527, 0.023318350504268892, 0.136513018514961, 6.805786779150367, 36.35306730866432, 36.206794157624245, 33.00729364156723, 29.488235972821712, 34.02956798672676, 47.76581950485706, 53.75009939074516, 36.06307066977024, 3.47551794257015, 0.05772744865680579, 0.04829814701224677, 0.0581219929154031, 0.018327908328501508, 0.022593060712097213, 0.08062331675319001, 0.03413952043047175, 0.02125984992744634, 0.06740585216903128, 0.05577249808993656, 0.06701203892589547, 0.09657629314460792, 0.12227210259879939, 0.06854713428765535, 0.04607473936630413, 0.033425117944716476, 0.04454000394616742, 0.06703324950649403, 0.09112063940847293, 0.09250657793018036, 0.1483366035972722, 0.14202086749719456, 0.14837154390988871, 0.24059121496975422, 0.09401859249919653, 0.09786384514882229, 0.21494864718988538, 0.1452107963268645, 0.13028242159634829, 0.22996996849542484, 0.08803320117294788, 0.1624396804254502, 0.20492981682764366, 0.16846391576109454, 0.13426169869489968, 0.24049442406976596, 0.7552923588082194, 14.2805590108037, 45.41053868830204, 59.54283155500889, 52.162430584430695, 38.286817744374275, 30.994855128228664, 34.31869447231293, 41.50784030556679, 12.267603725194931, 0.35500853788107634, 0.10009181700297631, 0.2889224246609956, 4.725231695920229, 13.80919810384512, 11.542954109609127, 15.718139670789242, 9.789041373878717, 21.135533675551414, 31.066338792443275, 51.66139326989651, 58.58433298766613, 49.061891958117485, 46.576536521315575, 55.324537307024, 55.29931806027889, 55.556575655937195, 52.66065984964371, 55.1450577378273, 50.28117433190346, 47.79503233730793, 55.839162692427635, 52.34606333076954, 56.73647694289684, 50.11431768536568, 49.14271742105484, 50.16944132745266, 54.45397362112999, 51.96201413869858, 52.39612564444542, 55.722060576081276, 55.62893137335777, 51.61502055823803, 44.853712767362595, 40.650807693600655, 38.99684764444828, 40.9555247426033, 39.18370641767979, 43.986762687563896, 39.247983768582344, 41.82003915309906, 42.355050444602966, 40.19822157919407, 42.722650319337845, 43.18500190973282, 41.93248651921749, 41.4787832647562, 46.08658321201801, 42.73156464099884, 40.11924281716347, 41.87482461333275, 41.057442873716354, 47.827288806438446, 47.34593443572521, 48.411241471767426, 48.684876188635826, 51.2677837908268, 50.58315172791481, 55.28541460633278, 30.011327303946018, 44.58523817360401, 57.5240682810545, 48.42321462929249, 54.10470016300678, 47.98575550317764, 50.477114617824554, 46.65791295468807, 44.66959364712238, 44.038272723555565, 42.0431973785162, 44.15092907845974, 42.949669137597084, 41.76537528634071, 43.155241906642914, 41.46836802363396, 43.98853339254856, 41.503736525774, 42.62841917574406, 43.260633051395416, 42.49711722135544, 42.45788432657719, 42.04771913588047, 42.326441779732704, 41.72380551695824, 42.668351233005524, 41.80923253297806, 41.15583099424839, 41.07348181307316, 41.26669764518738, 40.194908156991005, 47.01567895710468, 51.60410374403, 53.56604866683483, 55.878171399235725, 49.78135675191879, 52.01718717813492, 50.95884136855602, 55.12437164783478, 50.65144166350365, 51.39844357967377, 48.6405211687088, 51.331700161099434, 54.90242175757885, 57.439070641994476, 55.48404134809971, 50.74929021298885, 49.572922736406326, 58.390786573290825, 57.494353875517845, 46.55799351632595, 27.47221615165472, 28.612648956477642, 18.066168576478958, 10.32310176640749, 18.1515271961689, 11.661286409944296, 9.137666076421738, 0.8803104003891349, 0.09784894282347523, 0.32517304352950305, 9.237005095928907, 41.152430176734924, 40.54899975657463, 39.57166559994221, 35.815259367227554, 40.516382306814194, 55.78223794698715, 59.56632189452648, 43.800766468048096, 4.933704184368253, 0.15101495519047603, 0.10007055447204039, 0.13563357351813465, 0.11985753997578286, 0.07202192908152938, 0.16279389266856015, 0.1987913204357028, 0.08714833849808201, 0.2576997078722343, 0.1760908486903645, 0.2770941343624145, 0.13840599975083023, 0.21670327725587413, 0.1541455418919213, 0.12701001047389582, 0.09638230316340923, 0.1268190410337411, 0.2310444350587204], [0.05955460139375646, 0.03973278318881057, 0.03229674548492767, 0.02602934546303004, 0.06652906406088732, 0.06073418575397227, 0.025929706571332645, 0.014601439197576838, 0.018476805416867137, 0.06028080031683203, 0.04970031259290408, 0.010047476334875682, 0.030148652840580326, 0.02844988979632035, 0.10107304755365476, 0.039761166626703925, 0.029950363968964666, 0.056354460612055846, 0.5294175166636705, 8.859888631850481, 35.42647182941437, 42.58104331791401, 38.370211869478226, 23.862347155809402, 21.15896511822939, 33.90525005757809, 33.38973551988602, 5.111972568556666, 0.1093206311634276, 0.6486408098135144, 9.448367804288864, 3.016654090024531, 14.496009349822998, 10.134355444461107, 20.54513655602932, 18.804242871701717, 17.508871480822563, 40.437088161706924, 51.90969094634056, 46.32799185812473, 31.12685814499855, 53.048881217837334, 53.04432526230812, 57.963974475860596, 50.31921409070492, 55.14962129294872, 48.95124949514866, 57.15067371726036, 42.111506313085556, 47.809631153941154, 50.214962884783745, 46.9888561964035, 50.16400381922722, 44.98110853135586, 47.66326680779457, 48.75076085329056, 52.25455664098263, 46.12211890518665, 48.085811734199524, 49.807290360331535, 49.696712493896484, 47.9075101017952, 45.34715048968792, 43.072938323020935, 40.491516441106796, 35.268746092915535, 36.972335278987885, 36.798456609249115, 37.23984092473984, 37.11436405777931, 37.3914185911417, 37.850802540779114, 37.34508387744427, 36.01916402578354, 38.121127635240555, 38.0672275274992, 36.03783622384071, 36.6443482786417, 40.87315276265144, 44.154835268855095, 44.47620302438736, 43.00688646733761, 44.58527237176895, 41.73916809260845, 47.377005368471146, 47.3044216632843, 57.94980123639107, 29.216757640242577, 37.936700731515884, 55.70517048239708, 47.05057628452778, 46.741850450634956, 38.82573142647743, 38.603644743561745, 39.300808534026146, 37.49300234019756, 37.24766090512276, 37.92152814567089, 37.91044034063816, 40.97197026014328, 39.1832884401083, 37.225834876298904, 37.749393582344055, 41.1817342042923, 38.79764713346958, 37.6146300137043, 37.96460263431072, 38.16845029592514, 38.13474230468273, 40.0480954349041, 44.159945994615555, 45.53565837442875, 42.110210582613945, 42.08651885390282, 40.22857815027237, 37.83010125160217, 35.96131972968578, 39.165756180882454, 46.030984595417976, 50.68764612078667, 50.93823507428169, 47.758223712444305, 49.98233936727047, 48.85673336684704, 48.543067798018456, 44.27441485226154, 45.0137297809124, 42.57712572813034, 42.631546407938, 41.35807514190674, 49.02810417115688, 51.48135133087635, 54.72590982913971, 49.73390869796276, 49.29550722241402, 55.00342793762684, 56.07216998934746, 44.63212385773659, 40.4725706577301, 19.662962593138218, 9.72632858902216, 17.19523061066866, 6.595244351774454, 9.047022890299559, 4.454260161146522, 0.4639556386973709, 0.09155612424365245, 0.03689161181682721, 4.376456011086702, 27.268621176481247, 48.100535944104195, 62.58443534374237, 42.19013549387455, 31.915057450532913, 40.0757921487093, 46.085435673594475, 34.17999051511288, 4.763739304617047, 0.03601320211600978, 0.1293284649727866, 0.0868462843936868, 0.01102387735954835, 0.055775221771909855, 0.06427784072002396, 0.05527049826923758, 0.04524040952674113, 0.01194495498566539, 0.05278606615320314, 0.032413700537290424, 0.06339302999549545, 0.027621450753940735, 0.04568167569232173, 0.024583541598985903, 0.02546477146097459, 0.026383253425592557, 0.0566003341373289, 0.03740139305591583, 0.06401034101145342, 0.009475858423684258, 0.036884780347463675, 0.021234273663139902, 0.03785389904805925, 0.014872076335450402, 0.07143441529478878, 0.030473635597445536, 0.029939690030005295, 0.026206293878203724, 0.004999232914997265, 0.018579498246253934, 0.0397038728260668, 0.064147608645726, 0.007754047983326018, 0.02782646904961439, 0.06375360244419426, 0.6821449776180089, 10.997635871171951, 42.904873341321945, 50.99729910492897, 43.142182007431984, 30.296655893325806, 20.375462360680103, 29.268170781433582, 37.23489359021187, 6.000536838546395, 0.06981967264437117, 1.045753879006952, 4.57336999475956, 5.864392044022679, 14.440261591225863, 6.7762519139796495, 17.910249643027782, 10.767245683819056, 20.229607187211514, 39.41650092601776, 53.480093479156494, 46.66933134198189, 37.09553226828575, 53.48791725933552, 51.27047024667263, 57.72693179547787, 53.42186540365219, 54.82976585626602, 51.77559994161129, 57.676181718707085, 44.13378059864044, 50.510404631495476, 52.442950531840324, 49.62273046374321, 51.751490235328674, 48.81288751959801, 48.523130267858505, 51.00953824818134, 52.72478140890598, 47.81876966357231, 50.51217533648014, 51.4925417304039, 52.07155466079712, 50.25955729186535, 45.60801029205322, 43.25507014989853, 42.60719731450081, 37.148512825369835, 37.96794645488262, 39.05727960169315, 39.16757248342037, 39.09574493765831, 38.88429008424282, 37.323782220482826, 39.15928512811661, 38.226438984274864, 39.9412489682436, 38.04157130420208, 38.6635485291481, 39.437555596232414, 42.45547145605087, 45.14256566762924, 47.01138898730278, 44.99353006482124, 47.54064358770847, 45.26044674217701, 49.23935003578663, 50.07787004113197, 58.616904839873314, 30.582104176282883, 39.22100141644478, 56.74997001886368, 50.14236018061638, 49.68508131802082, 42.93629765510559, 40.608128383755684, 41.39741063117981, 39.64683696627617, 39.29074287414551, 39.83994260430336, 39.636037945747375, 41.474934071302414, 41.22482769191265, 39.4086467474699, 40.42210936546326, 41.60307839512825, 40.434549897909164, 41.21109142899513, 39.774354323744774, 40.35007283091545, 40.18203064799309, 40.55810786783695, 46.306169629096985, 46.826050132513046, 44.995281770825386, 44.031216502189636, 42.36954286694527, 40.753102004528046, 37.68084146082401, 41.635669246315956, 48.49739044904709, 53.011939600110054, 53.35690028965473, 50.08628658950329, 49.705896601080894, 51.18421867489815, 51.23586170375347, 46.78171031177044, 47.57271386682987, 45.06447985768318, 44.306891709566116, 44.31239761412144, 50.87541684508324, 55.40721707046032, 56.908763498067856, 50.62731675803661, 49.61126267910004, 54.42058861255646, 57.78586283326149, 47.165565714240074, 36.14195063710213, 21.777026653289795, 13.321424927562475, 6.826589712873101, 11.033751983195543, 9.621500764042139, 4.989940216764808, 0.9724452439695597, 0.09149173551122658, 0.05859995086211711, 5.017773248255253, 29.951699003577232, 40.209769159555435, 49.92099165916443, 46.035038977861404, 38.48272003233433, 44.97300736606121, 52.33148731291294, 40.69654203951359, 6.303336415439844, 0.04337844264227897, 0.06959867590921931, 0.027039781380153727, 0.03474740246019792, 0.01857548693806166, 0.04256503394572064, 0.03783443622523919, 0.012373167701298371, 0.03942266193917021, 0.0074899296851071995, 0.06298882668488659, 0.02088764616928529, 0.035811619964079, 0.03653850908449385, 0.047063588062883355, 0.036966338666388765, 0.0378017446200829, 0.02057796278677415, 0.1255025897989981, 0.19051411771215498, 0.1177513471338898, 0.0991491336026229, 0.1618845242774114, 0.16213400464039296, 0.18487174704205245, 0.16905165219213814, 0.07004859551670961, 0.1180660845420789, 0.2623150055296719, 0.14157111116219312, 0.07814101831172593, 0.1842409066739492, 0.20910631224978715, 0.10514715628232807, 0.14850000967271626, 0.1571804063860327, 0.9548367513343692, 14.977732300758362, 52.39744797348976, 57.57627747952938, 52.14791536331177, 36.71297639608383, 31.14839728921652, 42.62680806219578, 43.725484907627106, 6.7725969851017, 0.18286282749613747, 1.3345179590396583, 12.912711258977652, 9.65401941910386, 26.559890806674957, 15.823200233280659, 27.842867262661457, 25.290238335728645, 19.045778810977936, 44.285419061779976, 52.99018956720829, 49.96128849685192, 41.10050216317177, 56.08475871384144, 51.35567307472229, 60.41788659989834, 55.263356789946556, 57.82886512577534, 56.09849497675896, 59.201184287667274, 48.87561455368996, 52.04097770154476, 54.308977201581, 51.113496869802475, 53.487244695425034, 50.68804509937763, 50.954813584685326, 51.88658818602562, 54.956629648804665, 48.6004713177681, 51.02885641157627, 54.13429297506809, 54.752257615327835, 52.235569059848785, 49.2232882976532, 46.997835114598274, 44.743830263614655, 38.076347038149834, 40.4791709035635, 41.09859846532345, 40.78332558274269, 41.22334197163582, 41.252930983901024, 41.08548916876316, 41.80143915116787, 40.304129496216774, 43.311877101659775, 41.232507079839706, 39.5102608948946, 41.89987666904926, 45.2640413492918, 49.818351566791534, 49.60440784692764, 48.710068836808205, 49.641136676073074, 46.635421961545944, 52.74327501654625, 52.08293505012989, 58.62029805779457, 33.91653165221214, 42.12499178946018, 59.55082252621651, 53.23285974562168, 51.613284051418304, 44.64949272572994, 42.92639158666134, 44.860419407486916, 41.898086965084076, 42.20168687403202, 41.646768450737, 41.5380334854126, 43.68806831538677, 43.17923381924629, 41.44228242337704, 40.672812312841415, 46.35610654950142, 43.30688796937466, 42.45550185441971, 42.476336136460304, 42.36861191689968, 42.13286876678467, 42.77760297060013, 50.20235516130924, 51.18196539580822, 46.38309270143509, 47.04687148332596, 45.58734320104122, 42.9444520175457, 39.82213295996189, 44.14617173373699, 50.68100027740002, 54.6427208930254, 55.2234361320734, 50.725298300385475, 51.43393747508526, 53.05494949221611, 53.011365830898285, 48.512487038969994, 50.63784599304199, 47.08561420440674, 47.54554532468319, 46.32721669971943, 55.21999351680279, 57.7291052788496, 57.939139008522034, 49.89093907177448, 51.041217148303986, 57.03727260231972, 60.3270448744297, 49.58292379975319, 43.57785902917385, 23.802373073995113, 13.712404947727919, 27.98969328403473, 15.240124370902777, 17.5841511413455, 10.202057361602783, 2.1578234620392323, 0.35491918330080807, 0.17439104849472642, 6.137057337909937, 36.49741776287556, 59.59200091660023, 70.39135962724686, 53.43681380152702, 45.46983830630779, 52.279585897922516, 59.19131621718407, 47.70525835454464, 8.764966875314713, 0.1937824915512465, 0.229193281265907, 0.13002329331357032, 0.12872177409008145, 0.14624981791712344, 0.1750266831368208, 0.13901534752221778, 0.07756987630273215, 0.09943926881533116, 0.08620028937002644, 0.13932088972069323, 0.11120287352241576, 0.0743465062987525, 0.14772992755752057, 0.19494591193506494, 0.11769245029427111, 0.16217899363255128, 0.18490563350496814], [0.028548532354761846, 0.05447567666124087, 0.041614877118263394, 0.02800137099256972, 0.01906343975861091, 0.059606343929772265, 0.06423961269319989, 0.05952451843768358, 0.02696498588193208, 0.015779373206896707, 0.07712682156125084, 0.06323113047983497, 0.017753884931153152, 0.017129983643826563, 0.0963053572922945, 0.10554077656706795, 0.060587429761653766, 0.07943205841002055, 1.3622914999723434, 12.319265753030777, 34.40807327628136, 48.22896905243397, 35.544447898864746, 20.378678888082504, 16.876948289573193, 32.155557945370674, 27.282680422067642, 4.122554585337639, 0.04843490998609923, 1.7204637243412435, 23.179977871477604, 11.497270110994577, 14.583364762365818, 3.8871600665152073, 6.943576410412788, 12.011087089776993, 27.186304293572903, 43.429735377430916, 47.78585962951183, 31.084851399064064, 42.51078508794308, 54.807704240083694, 55.275215953588486, 52.05116495490074, 49.592506885528564, 48.89869451522827, 52.716927230358124, 50.72795815765858, 52.51711115241051, 42.99930967390537, 45.62828220427036, 48.062967360019684, 51.77355945110321, 47.85350739955902, 50.58827005326748, 51.30736626684666, 50.60656987130642, 47.84074008464813, 45.70819951593876, 48.52359764277935, 50.12230105698109, 51.694098114967346, 51.48759439587593, 49.89350013434887, 47.80103601515293, 44.7942079603672, 38.60810570418835, 35.16897104680538, 36.97613127529621, 34.99219313263893, 36.88397482037544, 35.765748023986816, 37.050687074661255, 36.00096680223942, 37.64473579823971, 34.86489236354828, 37.671075984835625, 38.50861944258213, 44.671748131513596, 46.583148166537285, 45.465422943234444, 43.012354373931885, 44.83659468591213, 42.644857093691826, 47.75430232286453, 46.169137582182884, 56.53154253959656, 32.05420598387718, 37.34922185540199, 53.957860842347145, 47.97908306121826, 47.12695598602295, 40.902471989393234, 39.29826267063618, 35.42584106326103, 38.224972262978554, 35.95398612320423, 37.3254769295454, 35.01997724175453, 37.456987872719765, 36.83236978948116, 37.47627183794975, 36.330876499414444, 39.81405459344387, 39.14622902870178, 39.81638386845589, 41.29435636103153, 43.32715608179569, 45.200132578611374, 47.41334281861782, 49.40109595656395, 50.25599308311939, 49.40102756023407, 47.361080422997475, 44.99557815492153, 43.26472543179989, 42.522446662187576, 45.29560625553131, 48.803281635046005, 51.42225690186024, 47.449448481202126, 48.56004908680916, 53.14292997121811, 46.988635808229446, 44.53747093677521, 43.08944083750248, 41.070289984345436, 40.12189507484436, 41.21149800717831, 45.00268377363682, 52.785657942295074, 50.184803903102875, 54.667294174432755, 49.138879626989365, 49.85567316412926, 53.42874303460121, 58.62740367650986, 53.66361603140831, 41.15336112678051, 28.33332784473896, 23.102384135127068, 5.010997736826539, 5.647397562861443, 4.817634662613273, 0.6071405054535717, 0.7323509710840881, 0.04299481908674352, 0.057584429378039204, 1.6403553541749716, 27.72337507456541, 66.8529362976551, 68.12504723668098, 21.858722269535065, 25.447891876101494, 41.52643270790577, 48.1459891051054, 38.56754668056965, 3.5305990744382143, 0.024480008287355304, 0.013059502161922865, 0.015057335876917932, 0.10650492287822999, 0.048673083729227073, 0.07258920450112782, 0.03141310364298988, 0.01973315011127852, 0.08306636300403625, 0.005681196589648607, 0.03066356232011458, 0.05844151346536819, 0.05980830828775652, 0.04065378103405237, 0.04551536410872359, 0.050559203809825704, 0.04162477365753148, 0.020737172017106786, 0.042168704821961, 0.10298742490704171, 0.038613015931332484, 0.017865492809505668, 0.09294011833844706, 0.016472537281515542, 0.027638397696136963, 0.044381889383657835, 0.042809193109860644, 0.041160025939461775, 0.03681365662487224, 0.02323294600500958, 0.06647070156759582, 0.060050330066587776, 0.039366685450659133, 0.021472568005265202, 0.013455953740049154, 0.08352388220373541, 1.5235145925544202, 15.979121066629887, 42.521922290325165, 54.488133788108826, 42.92954161763191, 24.93088211864233, 21.867750585079193, 35.91973856091499, 30.37180446088314, 4.606007393449545, 0.02603899709356483, 2.060891375876963, 23.693265728652477, 7.908476209267974, 16.849965937435627, 8.605244345963001, 8.8239112123847, 12.200172543525696, 26.26699112355709, 44.59932021796703, 48.84792543947697, 34.76513631641865, 45.894750505685806, 55.14348082244396, 55.11246308684349, 54.861547350883484, 50.271944627165794, 51.98772735893726, 52.211094573140144, 53.401023522019386, 53.91414798796177, 45.4759331792593, 48.50060887634754, 50.13531915843487, 53.50347742438316, 48.96913893520832, 51.04996807873249, 53.06473396718502, 52.74549789726734, 48.240372240543365, 46.04456126689911, 49.99063812196255, 52.80216805636883, 53.421645015478134, 53.30163985490799, 50.54418861865997, 50.07238693535328, 45.55127553641796, 41.204335391521454, 37.32597470283508, 38.74301366508007, 37.394124045968056, 37.47155249118805, 37.682558968663216, 38.46018724143505, 38.34718510508537, 39.134749844670296, 37.15958543121815, 40.607588812708855, 40.72260104119778, 47.98874594271183, 48.79995681345463, 47.644568011164665, 45.84047041833401, 47.50267222523689, 45.777690187096596, 49.5740170776844, 49.90144930779934, 57.9632943123579, 33.469405844807625, 38.77745121717453, 55.48955485224724, 49.40161272883415, 49.26252119243145, 43.22843357920647, 41.13741338253021, 37.44211167097092, 38.19675877690315, 38.363531827926636, 37.703807428479195, 37.55322150886059, 39.66072902083397, 39.18918952345848, 38.820734694600105, 38.81971634924412, 42.270197197794914, 40.263114497065544, 42.04584203660488, 43.33930402994156, 44.73059557378292, 46.613177955150604, 48.24547536671162, 51.91471807658672, 51.71402424573898, 51.74006424844265, 49.19762447476387, 47.88994364440441, 44.60286922752857, 43.46271760761738, 46.92250415682793, 51.29976287484169, 53.67319531738758, 49.8261259496212, 48.78062345087528, 53.22349704802036, 50.3643062710762, 45.5130647867918, 45.59815362095833, 44.435594603419304, 41.12964279949665, 43.03318865597248, 46.07376649975777, 54.470905512571335, 52.664440646767616, 55.44668175280094, 47.623532339930534, 50.70690728724003, 55.22546902298927, 59.210299998521805, 55.45379877090454, 42.016363218426704, 21.72159142792225, 14.702253732830286, 7.426346205174923, 5.9451476857066154, 10.710566025227308, 5.229143556207418, 1.912406743504107, 0.03562764155503828, 0.0711931059777271, 1.9856055406853557, 27.097921036183834, 59.36476930975914, 70.31432256102562, 30.62763713300228, 29.799703359603882, 48.03366333246231, 54.161898493766785, 44.95187669992447, 4.7398314625024796, 0.07856297379476018, 0.05300702207023278, 0.011397881753509864, 0.053126674829400145, 0.09610983106540516, 0.026546483240963425, 0.02945866886875592, 0.06425923507777043, 0.0634668068960309, 0.04990623259800486, 0.04790033730387222, 0.040825198593665846, 0.05381018912885338, 0.09925341277266853, 0.04139529788517393, 0.05938691312621813, 0.021127461914147716, 0.026182984875049442, 0.15531920391367748, 0.14781312231207266, 0.16426070302259177, 0.16829216794576496, 0.1837945939041674, 0.08716864365851507, 0.3188235842389986, 0.11287391549558379, 0.1390496050589718, 0.06843236114946194, 0.14643735863501206, 0.11735383799532428, 0.14387919043656439, 0.10985393848386593, 0.32030357513576746, 0.1210966297367122, 0.14629087352659553, 0.3884343942627311, 2.216155081987381, 20.574596375226974, 50.267339274287224, 62.91695550084114, 49.00391086935997, 29.85629942268133, 25.917854458093643, 41.35407775640488, 36.48308873176575, 6.0192047618329525, 0.20963834307622164, 2.533867433667183, 28.113980814814568, 17.985844686627388, 21.93150546401739, 8.181006610393524, 13.422580249607563, 13.980308622121811, 31.022380851209164, 46.052438244223595, 50.07621333003044, 40.08725233376026, 50.35690426826477, 55.726175755262375, 56.967082768678665, 58.447965905070305, 54.201815351843834, 52.3649825155735, 56.01095527410507, 57.44832694530487, 55.75328350067139, 50.13838179409504, 49.46456015110016, 50.92159956693649, 56.008120626211166, 50.044583827257156, 53.783845379948616, 54.41012017428875, 52.176983803510666, 49.67390991747379, 45.42087033390999, 49.446180537343025, 54.49253015220165, 55.852815359830856, 56.31881095468998, 52.9783646017313, 53.33478547632694, 48.049162700772285, 42.5670562684536, 38.96177552640438, 40.65406791865826, 39.63755406439304, 39.49470832943916, 40.343772768974304, 41.05595715343952, 41.678090170025826, 40.79596750438213, 39.14251282811165, 42.52259485423565, 42.97942154109478, 49.86219361424446, 51.618858352303505, 49.16524641215801, 48.068765848875046, 50.956021919846535, 49.21039178967476, 51.92779317498207, 51.9805571436882, 58.69022570550442, 36.10621735453606, 42.706417590379715, 56.320034489035606, 51.82186245918274, 50.95580533146858, 45.98849907517433, 42.784442603588104, 39.326935932040215, 41.527587845921516, 39.90520030260086, 39.5499649643898, 39.03750166296959, 40.796533674001694, 40.230212062597275, 41.63012154400349, 39.48828287422657, 46.14884287118912, 42.78271369636059, 42.79003590345383, 45.630265697836876, 47.23537176847458, 49.86207962036133, 51.47459529340267, 55.98692536354065, 54.225792065262794, 55.99042497575283, 51.102933436632156, 50.06710521876812, 47.760222405195236, 45.49238249659538, 50.82301385700703, 53.14823068678379, 57.33098164200783, 51.55473679304123, 49.65458035469055, 56.15529052913189, 51.872160360217094, 48.36601249873638, 47.73737423121929, 45.86170747876167, 43.88802878558636, 45.56012146174908, 49.52765956521034, 58.36371302604675, 54.64031182229519, 58.54690499603748, 49.05305363237858, 50.79571232199669, 57.98537492752075, 64.19810995459557, 58.02313730120659, 45.88252656161785, 30.198642052710056, 33.51140879094601, 14.375939592719078, 12.065642662346363, 15.734456945210695, 5.933655202388763, 2.2469417424872518, 0.21647062880219892, 0.17093652917537838, 2.658069469034672, 36.963109374046326, 72.26981163024902, 71.32844254374504, 31.872167252004147, 37.68334932625294, 55.23645043373108, 61.53538763523102, 52.645582258701324, 7.528867078945041, 0.17081595986383036, 0.1468906327500008, 0.066028997534886, 0.22016486182110384, 0.17705601174384356, 0.20838648837525398, 0.14654649887233973, 0.13221896690083668, 0.13417811802355573, 0.23457450501155108, 0.14815952716162428, 0.17438600189052522, 0.18254765222081915, 0.18348332232562825, 0.17361292149871588, 0.1369522957247682, 0.1134943583747372, 0.1224750057735946], [0.042812028113985434, 0.06896602470078506, 0.06560183959663846, 0.04215756889607292, 0.05407104290497955, 0.013108862403896637, 0.06684191641397774, 0.0681725204049144, 0.04041136220621411, 0.048979316125041805, 0.044723110331688076, 0.04975163952622097, 0.022074510998209007, 0.09796956408536062, 0.05803306878078729, 0.10522499273065478, 0.0519798303139396, 0.0060773847053496866, 0.9907268348615617, 10.005644001066685, 41.030122339725494, 46.26176901161671, 33.16269010305405, 23.355081975460052, 19.924692548811436, 30.97669780254364, 23.99171881377697, 2.714448943734169, 0.36375498573761433, 0.03823815713985823, 0.9786766720935702, 3.55468004476279, 4.095156630501151, 7.85367127507925, 15.952731482684612, 16.17148194462061, 28.146683759987354, 51.11071161925793, 37.9182793200016, 32.768031880259514, 51.26964569091797, 53.00096578896046, 54.09527666866779, 49.038150832057, 48.66222180426121, 43.69668245315552, 50.09415976703167, 50.75355738401413, 47.82130792737007, 49.727259054780006, 45.30471816658974, 49.12490397691727, 51.59601017832756, 48.86469013988972, 49.72939074039459, 52.19508223235607, 48.92486371099949, 49.79246735572815, 48.82606901228428, 48.929465264081955, 52.43337884545326, 49.70313034951687, 50.284468755126, 50.87611220777035, 50.57979270815849, 49.980029091238976, 42.44852162897587, 36.14076130092144, 36.240296959877014, 37.17262253165245, 37.69287161529064, 36.21694341301918, 37.142706736922264, 35.707409754395485, 35.91997794806957, 35.1959154009819, 38.91105964779854, 41.639526039361954, 46.652076467871666, 45.3465311229229, 45.76419711112976, 42.49118573963642, 44.0522787719965, 40.783732160925865, 47.79154792428017, 45.400245040655136, 56.70124903321266, 33.68119888007641, 36.87346838414669, 55.77225588262081, 47.19310663640499, 49.499028101563454, 40.05294017493725, 38.53880502283573, 37.98612467944622, 40.19057638943195, 37.98260986804962, 36.86040088534355, 36.29827044904232, 37.29613870382309, 36.543763875961304, 36.79059863090515, 37.19049297273159, 40.6816316395998, 41.948935836553574, 45.659858509898186, 48.22638899087906, 49.60520580410957, 49.613747745752335, 51.5820687264204, 50.91123752295971, 49.27072115242481, 51.87870740890503, 52.20370776951313, 49.74276602268219, 48.141319155693054, 49.0608736127615, 47.611912563443184, 50.93637317419052, 50.71162663400173, 46.968037113547325, 51.220480129122734, 50.70908457040787, 48.471867218613625, 44.36701588332653, 41.84734828770161, 40.328835770487785, 40.17028547823429, 39.02368940412998, 48.904956579208374, 51.613884419202805, 54.889787435531616, 54.81601819396019, 54.16279524564743, 52.539944127202034, 54.44694399833679, 54.47296500205994, 58.2872611284256, 40.10316587984562, 30.814161524176598, 14.780151452869177, 3.215561304241419, 10.365245305001736, 11.629041340202093, 5.706248329952359, 1.0963163408450782, 0.14612567145377398, 0.041239439451601356, 1.3876845873892307, 19.26439817994833, 53.04976277053356, 35.774065777659416, 26.490128450095654, 35.798882246017456, 43.3952484279871, 52.18502417206764, 37.739369720220566, 5.24642170406878, 0.019139276118949056, 0.03028726376214763, 0.06204264776897617, 0.05021724813559558, 0.0207053876874852, 0.03169911993609276, 0.036330960065242834, 0.037159590210649185, 0.0504590138734784, 0.025460053257120308, 0.0167300291286665, 0.08633403180283494, 0.022432491496147122, 0.05054385619587265, 0.011575525004445808, 0.04264244365913328, 0.04034724064695183, 0.05072651358204894, 0.05960432899883017, 0.02325242181541398, 0.06313255842542276, 0.032695742629584856, 0.04641596031433437, 0.013813382265652763, 0.04509037695243023, 0.026141836497117765, 0.09795564139494672, 0.058202768268529326, 0.014278583621489815, 0.031748005203553475, 0.029602385766338557, 0.083888751687482, 0.0752689884393476, 0.15560745407128707, 0.11101575582870282, 0.02813045273796888, 1.1328829661943018, 13.349669761955738, 48.219192177057266, 51.4874842017889, 38.24241332709789, 25.086687058210373, 19.438358545303345, 31.616076193749905, 26.612419188022614, 3.337233862839639, 0.3584680147469044, 0.2673915331251919, 1.26936131156981, 5.001845927909017, 5.595314707607031, 8.310335520654917, 8.924371171742678, 12.356051579117775, 28.296036645770073, 51.68434023857117, 38.93902614712715, 36.47459238767624, 52.30852514505386, 52.963609993457794, 56.54613375663757, 51.56464286148548, 51.34924381971359, 45.8618138730526, 51.93955734372139, 51.55146896839142, 51.40137322247028, 50.23795165121555, 47.452492117881775, 49.22699309885502, 52.49065317213535, 50.28236746788025, 51.0285410284996, 52.197099924087524, 49.41427364945412, 50.627643540501595, 47.95144334435463, 48.26137751340866, 52.75251992046833, 50.66462315618992, 51.969241350889206, 49.824362844228745, 52.153349071741104, 52.161564230918884, 44.32483434677124, 38.207497000694275, 37.713865488767624, 38.15081924200058, 38.12624976038933, 39.02616687119007, 38.43531757593155, 37.51810759305954, 38.046378046274185, 37.75181405246258, 40.96638835966587, 45.672188848257065, 48.49520556628704, 47.952613681554794, 48.68981972336769, 45.35145565867424, 46.12038239836693, 42.15592212975025, 50.25674544274807, 48.45639064908028, 56.482730358839035, 36.15199349820614, 39.165224209427834, 57.93183200061321, 49.51978258788586, 51.27544417977333, 42.02171333134174, 41.69805809855461, 39.46220487356186, 41.787144318223, 40.63191130757332, 37.73051619529724, 37.78645299375057, 38.47130544483662, 38.01445595920086, 38.864192962646484, 39.067520052194595, 41.15862004458904, 43.5641797631979, 47.24025070667267, 49.84962768852711, 51.73099793493748, 52.28247754275799, 53.4814690053463, 54.19554568827152, 53.16799342632294, 52.63960137963295, 54.32817377150059, 51.88613221049309, 49.60453703999519, 51.74447201192379, 50.29814422130585, 53.18681761622429, 50.98475977778435, 48.568663224577904, 50.7356945425272, 52.35155023634434, 50.2545415610075, 46.01347133517265, 44.22949366271496, 42.00789727270603, 41.02983355522156, 42.55696401000023, 49.39824230968952, 55.60388691723347, 56.89385309815407, 55.24200953543186, 53.01179900765419, 55.02210393548012, 54.916944578289986, 56.556108221411705, 57.179704159498215, 45.32595902681351, 28.07416845113039, 20.17002258449793, 5.446289554238319, 9.42398926243186, 10.533975251019001, 5.662968652322888, 2.365613649599254, 0.17085196886910126, 0.036924370215274394, 1.4913966972380877, 22.991289496421814, 61.02220617234707, 46.499985828995705, 25.19220169633627, 39.76099044084549, 48.838551342487335, 58.70462313294411, 43.60531635582447, 7.544583510607481, 0.14082853303989395, 0.008492436681990512, 0.03684343901113607, 0.06097316101659089, 0.019862903500325046, 0.025849356097751297, 0.02180458075599745, 0.053072568553034216, 0.032690543885109946, 0.020606015968951397, 0.012634049307962414, 0.024911656219046563, 0.08112130526569672, 0.019927347893826663, 0.012148405494372128, 0.05346988844394218, 0.054696454462828115, 0.05109011028253008, 0.1571479596896097, 0.15825747046619654, 0.0972931706928648, 0.11697975845891051, 0.09133327956078574, 0.13337242766283453, 0.13290781353134662, 0.15784060611622408, 0.177361776586622, 0.14054253901122138, 0.09169484648737125, 0.1701045667869039, 0.09946172620402649, 0.2015272478456609, 0.1099073508521542, 0.20998758292989805, 0.2081043238285929, 0.142309726215899, 1.4069939637556672, 18.676866106688976, 56.23827047646046, 59.01733875274658, 44.75252039730549, 32.68249846994877, 27.19568219035864, 41.10553689301014, 33.31200689077377, 4.274587277323008, 0.5066817335318774, 0.19998589617898688, 1.3305991818197072, 7.620355719700456, 9.235336035490036, 15.10806530714035, 23.77213429659605, 19.748503603041172, 31.401364915072918, 55.07564686238766, 44.466509744524956, 41.03524826467037, 52.482859790325165, 55.199607610702515, 58.17013241350651, 53.421781808137894, 53.10649372637272, 47.09498070180416, 54.29794259369373, 55.93455657362938, 51.10190749168396, 53.22801120579243, 50.719587206840515, 50.672697722911835, 54.40625578165054, 53.11124727129936, 53.04875582456589, 54.24861364066601, 51.3005418330431, 51.49406924843788, 48.24145898222923, 49.447354674339294, 53.041798397898674, 50.920349434018135, 51.87337249517441, 51.12939141690731, 52.64339357614517, 54.80066701769829, 47.39238314330578, 40.01229375600815, 39.17364075779915, 39.87167850136757, 39.674377888441086, 40.65323956310749, 40.867760851979256, 38.81501220166683, 39.691245183348656, 39.02103714644909, 42.94379845261574, 47.315228283405304, 51.399100944399834, 50.042797923088074, 50.66253326833248, 48.012631461024284, 48.79622161388397, 45.06417207419872, 53.13149258494377, 51.05677731335163, 58.74038681387901, 38.67316581308842, 41.45728021860123, 60.244775488972664, 52.646919786930084, 53.243719562888145, 44.59154583513737, 44.022701159119606, 43.911393731832504, 44.01663288474083, 42.37654209136963, 40.488111823797226, 40.38632668554783, 40.54868817329407, 40.66093795001507, 41.54502511024475, 40.97389675676823, 43.07485722005367, 47.249396815896034, 49.92321453988552, 52.56324827671051, 52.580111771821976, 54.05957378447056, 55.98817549645901, 55.929434448480606, 55.246462896466255, 54.15751352906227, 58.09685714542866, 54.50855389237404, 52.34978333115578, 54.33918938040733, 51.840131878852844, 55.184077844023705, 52.55494572222233, 48.378551825881004, 54.45889435708523, 55.5402023345232, 53.25943171977997, 49.15890455245972, 46.68285481631756, 44.08922798931599, 44.015796929597855, 44.720412120223045, 53.02875369787216, 58.744555190205574, 60.0706422328949, 56.378490552306175, 53.83452706038952, 56.17938123643398, 56.48170441389084, 59.143670573830605, 63.72785098850727, 48.76592963933945, 38.963417038321495, 21.783554702997208, 8.112783171236515, 22.577497400343418, 20.039290599524975, 13.401997704058886, 4.856734564527869, 0.2206066474900581, 0.1735386622021906, 1.6048612212762237, 26.304084733128548, 60.65188184380531, 44.51863534748554, 37.19548590481281, 46.55620381236076, 56.18195749819279, 65.83541169762611, 50.90510845184326, 10.39801949635148, 0.38075340329669416, 0.0983345003623981, 0.17608440684853122, 0.11975734261795878, 0.10829613340320066, 0.14039534144103527, 0.10675841083866544, 0.13156253728084266, 0.16704267327440903, 0.11307678156299517, 0.12084889342077076, 0.1533101507811807, 0.20937560795573518, 0.11885618238011375, 0.10201193857938051, 0.12380614411085844, 0.16732899384805933, 0.23125412146328017], [0.05270209214359056, 0.03493172967864666, 0.008735664450796321, 0.03168511189869605, 0.007502585622205515, 0.02296056853083428, 0.08876000123564154, 0.03295068891020492, 0.03864621219690889, 0.004662125784307136, 0.031230446256813593, 0.0953374186065048, 0.030036371463211253, 0.03142889654554892, 0.02216233675426338, 0.08041121836868115, 0.09054361958988011, 0.03621025345637463, 0.8227596979122609, 10.776640679687262, 48.223812729120255, 43.72422717511654, 37.26608231663704, 16.605253368616104, 29.652151577174664, 37.37895905971527, 20.01970835030079, 1.0870391386561096, 0.5106778722256422, 0.7322489703074098, 22.156742177903652, 15.260843709111214, 5.149545902386308, 8.665707651525736, 7.059271652251482, 16.65254183113575, 30.135139860212803, 42.217547222971916, 25.452026054263115, 43.86204198002815, 49.65370260179043, 54.35566529631615, 48.34790267050266, 48.03355313837528, 41.13231025636196, 38.88844706118107, 42.16215379536152, 49.10112485289574, 47.665140107274055, 49.05849874019623, 48.41854467988014, 49.824062660336494, 47.233954444527626, 48.00719775259495, 47.741158828139305, 50.94445154070854, 49.381823390722275, 49.133605509996414, 49.62242268025875, 51.589368134737015, 50.27772031724453, 51.32384978234768, 50.32335586845875, 49.68244805932045, 52.2932081669569, 47.9948066174984, 43.19611631333828, 38.138963878154755, 36.82247132062912, 35.60559041798115, 36.18833474814892, 35.99367119371891, 35.97375646233559, 36.04170821607113, 35.99547989666462, 34.99540016055107, 40.21742194890976, 42.76546262204647, 45.89106470346451, 43.06783139705658, 42.97590672969818, 38.92544187605381, 41.391387954354286, 41.87646992504597, 47.89788521826267, 46.28608010709286, 56.11783213913441, 37.46654435992241, 38.03098887205124, 55.81655390560627, 47.61900298297405, 47.07206793129444, 39.46936748921871, 43.84729877114296, 44.905849769711494, 47.01936475932598, 45.28284654021263, 43.35757724940777, 36.91062279045582, 36.53443157672882, 36.81309722363949, 36.98237054049969, 36.329626366496086, 39.70812387764454, 44.67354543507099, 48.88678975403309, 50.48591114580631, 52.926231399178505, 51.51515431702137, 49.691723361611366, 48.026797100901604, 48.014698550105095, 48.12483184039593, 48.53379629552364, 50.92258371412754, 50.92621631920338, 52.638670429587364, 51.260655373334885, 51.713074296712875, 47.31253802776337, 48.315988183021545, 53.48395027220249, 50.37169307470322, 46.634050235152245, 43.906704783439636, 41.36111877858639, 38.92729997634888, 38.63484486937523, 44.33710388839245, 51.78066127002239, 54.42158415913582, 51.45725682377815, 43.33176523447037, 45.53980395197868, 53.25099617242813, 52.94885918498039, 55.01860052347183, 58.916951939463615, 48.27849179506302, 21.027545370161533, 19.6005642414093, 5.038494486361742, 3.009506673552096, 7.835583295673132, 2.6317732175812125, 2.4917844543233514, 0.06883314315928146, 0.007234418908410589, 0.39609027095139027, 13.150870129466057, 26.122598871588707, 28.682734295725822, 24.235033057630062, 28.498911559581757, 44.25123609602451, 47.89032742381096, 37.768506556749344, 7.995558511465788, 0.08858850575052202, 0.03463065891992301, 0.033900029375217855, 0.029521109463530593, 0.003773183384510048, 0.006483690149252652, 0.040557984611950815, 0.009970908959076041, 0.030348453838087153, 0.07254406707943417, 0.03303193181636743, 0.019275599370303098, 0.0384042201039847, 0.012302947543503251, 0.005398196663009003, 0.06810692939325236, 0.05594552982074674, 0.047567053625243716, 0.0410052733059274, 0.04540190828265622, 0.05293600966979284, 0.06012031088175718, 0.017557041392137762, 0.08620165492175147, 0.005273161477816757, 0.010023777704191161, 0.02910738439823035, 0.03380665977601893, 0.07205056856037118, 0.0018403318881610176, 0.043676463174051605, 0.02668228142283624, 0.04742101009469479, 0.15113218483747914, 0.07272053495398723, 0.03842343430733308, 0.6993139407131821, 15.76456842944026, 53.792273327708244, 51.46481841802597, 42.25024826824665, 24.804198816418648, 33.37167128920555, 38.821232467889786, 23.4912533685565, 1.3950228248722851, 0.5498708691447973, 1.826437662821263, 18.70364896953106, 14.809602722525597, 6.447476930916309, 8.204785734415054, 8.15882720053196, 17.110120877623558, 35.14888912439346, 43.33477847278118, 29.00677140802145, 46.74895986914635, 53.11456449329853, 54.52388986945152, 50.381887927651405, 50.784483924508095, 44.17529337108135, 41.34541802108288, 43.54109600186348, 50.625268667936325, 50.331464633345604, 50.51313668489456, 51.386060044169426, 49.269197434186935, 49.59299325942993, 48.43731947243214, 49.42803651094437, 51.734881326556206, 50.44901132583618, 49.81998547911644, 51.39816999435425, 52.2946634888649, 51.872787326574326, 52.288511618971825, 50.3721072524786, 50.760773196816444, 52.44842603802681, 48.571152091026306, 44.73182670772076, 40.12824833393097, 37.577228620648384, 36.2528058886528, 39.915649741888046, 37.270744666457176, 38.35156247019768, 38.53248976171017, 37.89364904165268, 37.18951642513275, 41.65653392672539, 45.32581463456154, 48.45175489783287, 45.767305344343185, 45.801210924983025, 42.362817227840424, 43.04457284510136, 44.14066582918167, 51.26404099166393, 48.5055486112833, 58.464506417512894, 38.01324762403965, 40.7498037815094, 56.86234898865223, 49.06695708632469, 49.42608721554279, 41.21266454458237, 44.44719918072224, 47.29673847556114, 48.04603546857834, 46.976647451519966, 44.392995089292526, 38.91846165060997, 37.97117628157139, 38.19743514060974, 38.34615536034107, 39.08946767449379, 42.6357451826334, 48.044264763593674, 51.752417385578156, 54.492951929569244, 54.48458097875118, 53.012893348932266, 51.7764662951231, 48.3457937836647, 49.2038257420063, 48.01757499575615, 50.76979771256447, 52.812077924609184, 52.21520975232124, 54.88064132630825, 53.55792850255966, 52.70340375602245, 48.79440911114216, 49.598981738090515, 54.27220657467842, 52.44969516992569, 50.295586958527565, 45.1144053786993, 42.75152496993542, 41.909885331988335, 41.48383319377899, 46.50815539062023, 54.229994639754295, 54.61839459836483, 54.179134368896484, 43.98680068552494, 47.82179430127144, 55.73483169078827, 53.75601187348366, 57.59787172079086, 59.537409245967865, 50.71636877954006, 30.014737620949745, 21.1016907915473, 11.585124246776104, 11.010234095156193, 8.963791206479073, 5.368790812790394, 1.6892014956101775, 0.301333122770302, 0.1584497164003551, 0.42516788409557194, 15.003330577164888, 37.15504847466946, 34.02778968214989, 32.01998122036457, 35.08387081325054, 49.007980450987816, 55.06043627858162, 45.603142753243446, 9.51380219310522, 0.08675644741742872, 0.0284994763933355, 0.016662107773299795, 0.00690648333147692, 0.04851810102991294, 0.03568307627574541, 0.0559589292970486, 0.02453971406794153, 0.03304943908005953, 0.11491226861835457, 0.07854901399696246, 0.07572626273031346, 0.017865938098111656, 0.014720566887262976, 0.07534975637099706, 0.08666710025863722, 0.057256125510321, 0.03650606609880924, 0.2241788714309223, 0.16252257832093164, 0.07120947033399716, 0.2883758774260059, 0.09349013140308671, 0.1758483742014505, 0.19019572151592, 0.09881353442324325, 0.1175934552156832, 0.11323746395646594, 0.16811834211694077, 0.19543166243238375, 0.11129371981951408, 0.13967070844955742, 0.2991264802403748, 0.19844941300107166, 0.17107384133851156, 0.22519929480040446, 1.1318276915699244, 20.22347241640091, 63.45209218561649, 56.68170668184757, 49.428583681583405, 26.37602247297764, 40.34261763095856, 47.04994931817055, 28.752755038440228, 1.6091008437797427, 0.7661089533939958, 2.004607133567333, 29.17288899421692, 21.762061156332493, 13.368246015161276, 16.991650834679604, 12.02628057450056, 22.10529673844576, 33.97721439599991, 47.80794024467468, 32.23555505275726, 50.4070083796978, 52.529817670583725, 57.020059525966644, 52.49631866812706, 53.49687717854977, 45.94068244099617, 41.95112831890583, 46.21688961982727, 51.570570543408394, 53.21468912065029, 52.67793372273445, 50.5879432708025, 51.88913404941559, 50.50565868616104, 50.65040431916714, 51.83349743485451, 54.738905131816864, 52.281823977828026, 52.084078788757324, 54.303817078471184, 56.46587446331978, 53.252774477005005, 55.053646042943, 51.53036490082741, 52.16928541660309, 55.075757056474686, 50.253595411777496, 47.0399634540081, 43.115188255906105, 39.52280022203922, 38.873377069830894, 40.926087722182274, 39.517408311367035, 40.54177634418011, 40.93977838754654, 39.13671053946018, 39.10176381468773, 43.23740489780903, 47.92937032878399, 49.73973758518696, 48.25510784983635, 46.53663486242294, 44.16627645492554, 46.26841485500336, 44.659459590911865, 54.03672941029072, 50.19829697906971, 59.42800551652908, 42.76190601289272, 43.51909518241882, 58.10210466384888, 51.85891427099705, 51.54603525996208, 43.30111987888813, 46.76275692880154, 50.00473536550999, 51.051807180047035, 50.23394666612148, 47.644765600562096, 41.68928436934948, 40.883761793375015, 40.896126329898834, 41.77952192723751, 41.099495217204094, 44.378381073474884, 50.045594573020935, 54.08107303082943, 55.52104376256466, 57.58251674473286, 55.20590767264366, 52.97555275261402, 48.71591292321682, 49.04964901506901, 49.134593456983566, 52.390984520316124, 54.02933120727539, 53.386512100696564, 55.329693630337715, 56.36387273669243, 54.04813639819622, 48.398618549108505, 51.20643228292465, 56.60742066800594, 54.481985718011856, 52.265066877007484, 48.32410454750061, 45.678029134869576, 43.587852492928505, 43.840949311852455, 49.07539643347263, 57.2297702729702, 58.243954852223396, 55.1989958435297, 44.84832465648651, 47.91335418820381, 56.8589823693037, 56.00615233182907, 59.769227206707, 61.11612193286419, 52.26292759180069, 27.112303264439106, 24.147139973938465, 11.968954000622034, 7.62817332521081, 14.586530942469835, 11.350815519690514, 6.750382427126169, 0.4706734704086557, 0.27797651826404035, 0.8979874674696475, 16.690948270261288, 38.854579478502274, 40.37294380366802, 34.78999838232994, 40.260773822665215, 57.740778252482414, 60.731187388300896, 54.02286395430565, 12.624135743826628, 0.21523873787373304, 0.10717664074036293, 0.1468761163414456, 0.11669088489725254, 0.1329988008365035, 0.0950090924743563, 0.20908367674564943, 0.15746574732474983, 0.21436554176034406, 0.26371490384917706, 0.20460526080569252, 0.12783775746356696, 0.09891675232211128, 0.09828466514591128, 0.16946017480222508, 0.1938913794583641, 0.1863100886112079, 0.16188171895919368], [0.035369648758205585, 0.10855797794647515, 0.01855320395407034, 0.056434490106767043, 0.026672292115108576, 0.03586822727811523, 0.039585218255524524, 0.0017723138216751977, 0.07608299085404724, 0.0304361961025279, 0.08168193104211241, 0.07315005292184651, 0.024912977241910994, 0.0222009080243879, 0.06719295226503164, 0.03294399102742318, 0.037860574666410685, 0.026886381310760044, 0.6510957749560475, 13.264710120856762, 44.237002059817314, 41.84514060616493, 30.254440158605576, 12.395033687353134, 17.92623158544302, 35.38742512464523, 18.37665941566229, 1.26661037793383, 0.1848154774052091, 0.6796048732940108, 9.578843303024769, 10.40117047727108, 5.048381555825472, 5.01805585809052, 7.155734226107597, 15.603452324867249, 34.153448939323425, 27.114737033843994, 27.95924361795187, 48.254598677158356, 50.65295398235321, 55.76385833323002, 46.68492950499058, 45.67463591694832, 38.755818977952, 40.07130078971386, 37.82305642962456, 42.65111155807972, 46.330659314990044, 50.34146569669247, 47.59882606565952, 51.56000331044197, 46.045355424284935, 51.862744465470314, 50.227015838027, 48.26607786118984, 47.27772429585457, 45.90483896434307, 45.48317939043045, 48.019269704818726, 47.250563353300095, 49.91251431405544, 47.42969714105129, 49.10275876522064, 48.80500674247742, 44.81078267097473, 39.441723972558975, 34.263399839401245, 36.745875030756, 36.8354856222868, 33.77239778637886, 33.62760275602341, 35.2229243516922, 35.5124232172966, 36.60650230944157, 36.220891401171684, 39.21801097691059, 42.26860888302326, 43.62046234309673, 41.82378575205803, 38.80413718521595, 36.70974276959896, 38.94761748611927, 41.524061635136604, 46.818306148052216, 43.42692352831364, 54.84410248696804, 35.7556139677763, 34.88612562417984, 53.09170871973038, 45.592233538627625, 48.462409526109695, 45.9871881455183, 50.776637345552444, 50.184530317783356, 53.58607739210129, 50.29722847044468, 50.71146324276924, 44.103306233882904, 35.06635755300522, 36.94195590913296, 38.73481750488281, 36.26536421477795, 40.33910281956196, 44.07254308462143, 49.51556861400604, 50.18903687596321, 49.062955901026726, 50.66824436187744, 47.960897237062454, 48.390479385852814, 48.990383595228195, 49.360506534576416, 49.71977345645428, 47.54192031919956, 48.73416714370251, 47.35379621386528, 51.00977383553982, 47.552669942379, 47.82001219689846, 52.7605564892292, 49.96807873249054, 47.981134951114655, 42.88397066295147, 39.85097721219063, 37.502676621079445, 38.67329880595207, 39.128685370087624, 44.364078640937805, 51.36051781475544, 51.392937675118446, 48.670896738767624, 48.35189625620842, 46.49167187511921, 49.97603550553322, 56.384433433413506, 52.75108739733696, 54.305747374892235, 52.79885843396187, 36.28066599369049, 23.166346102952957, 10.226626843214035, 16.373192220926285, 9.762496948242188, 4.048293745145202, 0.45043456892017275, 0.6119009375106543, 0.06579606706509367, 0.3423622524132952, 11.0325350984931, 38.16568024456501, 43.39115984737873, 22.135463319718838, 27.64545265585184, 43.95224153995514, 51.208510771393776, 41.389085277915, 5.180256329476833, 0.04447178202099167, 0.011486265975690912, 0.01627833022212144, 0.0774269609246403, 0.015282490494428203, 0.049664797115838155, 0.07326114500756375, 0.05724830327380914, 0.06353418648359366, 0.07401030597975478, 0.05103730647533666, 0.08129625173751265, 0.021011842727602925, 0.017230155026481953, 0.0830173961003311, 0.02838873682776466, 0.022885385260451585, 0.0167657060228521, 0.03474642653600313, 0.10522858472540975, 0.06641904066782445, 0.03104382394667482, 0.02452929245919222, 0.03398824104806408, 0.03216141114535276, 0.017983473881031387, 0.043372976724640466, 0.08416600321652368, 0.04166496837569866, 0.018900959512393456, 0.04463630131795071, 0.05688867706339806, 0.0712057670170907, 0.13771298225037754, 0.03360674745636061, 0.06386148103047162, 1.0494849225506186, 17.03816033899784, 51.06753073632717, 48.196131214499474, 34.062603414058685, 15.119679383933544, 20.73832768946886, 39.90338779985905, 20.25817785412073, 1.2960161687806249, 0.17091027199057862, 0.25468831008765846, 10.016471520066261, 13.583974689245224, 3.3703723596408963, 6.148527497425675, 9.76525655016303, 15.416377913206816, 36.96481928229332, 27.929012440145016, 31.995856314897537, 50.99710151553154, 51.81469604372978, 57.33497902750969, 49.30950567126274, 49.5028430968523, 41.40980176627636, 41.35173708200455, 39.360807314515114, 45.35595461726189, 50.24055831134319, 51.42602249979973, 48.500061705708504, 53.13440702855587, 49.54491823911667, 52.081206142902374, 51.83689445257187, 50.07697328925133, 50.08434109389782, 48.12073566019535, 46.59746579825878, 52.06876941025257, 50.678777396678925, 51.948171481490135, 49.85728047788143, 49.86753232777119, 51.822227239608765, 48.058012425899506, 41.64264567196369, 36.478851959109306, 38.202146887779236, 38.85161183774471, 37.16973088681698, 36.67283535003662, 37.74721249938011, 36.95657752454281, 38.974573239684105, 39.22978654503822, 41.82077631354332, 43.99161122739315, 46.576992496848106, 42.711193934082985, 41.47743433713913, 39.03350807726383, 40.86343288421631, 42.6963747292757, 48.67788456380367, 47.20347248017788, 56.95293992757797, 37.341162487864494, 38.57733495533466, 55.41229359805584, 47.49739430844784, 50.53704500198364, 46.934842094779015, 52.37877577543259, 50.3480127453804, 54.201480969786644, 51.41730196774006, 51.47506266832352, 45.37435322999954, 37.18616120517254, 38.62563416361809, 40.21670758724213, 37.046039924025536, 42.22558379173279, 47.137234434485435, 51.7452547699213, 51.919574216008186, 50.82786239683628, 50.26350148022175, 49.05364640057087, 48.749077543616295, 48.393268436193466, 49.899617806077, 50.11831887066364, 50.09752258658409, 48.691024258732796, 49.44016546010971, 51.01662486791611, 49.11588326096535, 48.245954141020775, 53.29814784228802, 52.55711920559406, 49.12139296531677, 45.59786483645439, 41.92457154393196, 40.18070071935654, 39.85240213572979, 40.75279042124748, 48.110027834773064, 53.37623365223408, 53.860000893473625, 50.82546092569828, 48.13448712229729, 46.803384348750114, 52.53007225692272, 56.587365344166756, 53.8323649764061, 57.099577859044075, 54.56360153853893, 35.767100751399994, 21.14529725164175, 12.79304713010788, 14.657556731253862, 8.558076526969671, 4.822253314778209, 2.6891750749200583, 0.5541929590981454, 0.0793531903764233, 0.19732535613002256, 12.603397406637669, 37.431844621896744, 44.78370912373066, 25.325646735727787, 30.409521237015724, 50.8407399058342, 53.97559069097042, 48.130995109677315, 7.007142249494791, 0.0822303633322008, 0.01852002624218585, 0.020022070057166275, 0.040710072935326025, 0.05127290125528816, 0.05127462303789798, 0.025018013402586803, 0.04896433587418869, 0.044712423405144364, 0.03054271284781862, 0.003984194290751475, 0.050955577462445945, 0.048837072390597314, 0.0653869284724351, 0.04719825446954928, 0.03261455538449809, 0.013460238715197193, 0.030674874506075867, 0.14780936704482883, 0.2298525013611652, 0.15316847478970885, 0.10634607358952053, 0.07641523552592844, 0.157533876481466, 0.11313701426843181, 0.26440809946507215, 0.2288496372057125, 0.15498483669944108, 0.1619996313820593, 0.1711114088539034, 0.20275254850275815, 0.1724047792959027, 0.17619359161471948, 0.252011472475715, 0.15323878586059436, 0.19845711649395525, 1.4153804699890316, 22.785367146134377, 60.48857040703297, 54.44818273186684, 41.148656979203224, 20.173062421381474, 25.546593479812145, 45.76627939939499, 25.566738098859787, 1.6961244866251945, 0.29522379278205335, 1.0727383685298264, 15.600143652409315, 14.384660124778748, 7.846176652237773, 9.573187306523323, 10.467694457620382, 15.997798964381218, 40.39149820804596, 34.85220864415169, 36.761583387851715, 52.78045602142811, 52.714054584503174, 60.803193524479866, 52.29760833084583, 51.01633608341217, 41.71079121530056, 44.31683957576752, 41.5334889292717, 46.677193120121956, 51.143484860658646, 54.66410234570503, 51.04392260313034, 54.960231855511665, 49.37920153141022, 54.210718274116516, 54.77128319442272, 52.50558257102966, 53.20568360388279, 49.98342230916023, 50.63483655452728, 53.617117926478386, 52.51309856772423, 55.10980322957039, 51.60937026143074, 52.696583122015, 53.56977626681328, 48.97277534008026, 42.66314931213856, 37.83684968948364, 40.66753439605236, 40.934158489108086, 37.259159088134766, 39.068333208560944, 39.71558667719364, 38.74983049929142, 40.880786553025246, 41.61475136876106, 44.26604390144348, 46.910265013575554, 48.60701836645603, 45.46929873526096, 42.803848162293434, 40.72515070438385, 42.35188901424408, 45.958378091454506, 50.786858797073364, 49.75940153002739, 57.980317398905754, 39.913529455661774, 41.81922219693661, 56.20466887950897, 50.0831213593483, 53.003089874982834, 50.11467486619949, 55.98613120615482, 52.502592131495476, 57.6316025108099, 52.63643994927406, 53.99582840502262, 48.836415857076645, 39.464363157749176, 40.10264910757542, 43.206599950790405, 40.27715854346752, 44.32220868766308, 49.43893052637577, 54.53755773603916, 53.510640040040016, 51.049037128686905, 52.81747363507748, 49.00524839758873, 49.90842193365097, 50.117866694927216, 52.36436314880848, 52.044462114572525, 50.55749550461769, 48.894263952970505, 49.556758403778076, 52.63330511748791, 48.68628591299057, 50.077315270900726, 54.853263795375824, 53.03135275840759, 52.37225532531738, 46.5583772957325, 43.99889163672924, 41.02523200213909, 42.3983833193779, 43.00042301416397, 48.927629962563515, 54.87635895609856, 56.961029693484306, 51.54131971299648, 51.75970159471035, 49.24465835094452, 53.170641884207726, 58.87325048446655, 55.91085724532604, 56.92083165049553, 58.43286171555519, 37.52834424376488, 29.868977442383766, 13.204631544649601, 22.046890072524548, 15.889427829533815, 10.426284279674292, 4.222512496635318, 1.1097200028598309, 0.26555017568171024, 0.5936985486187041, 14.471839796751738, 51.23892053961754, 54.44233864545822, 32.05638326704502, 38.53315472602844, 57.316979393363, 63.21419835090637, 55.52509054541588, 10.65248804166913, 0.3156332694925368, 0.10022455753642134, 0.14248381921788678, 0.21495436172699556, 0.18462789215845987, 0.09936913585988805, 0.1729242826695554, 0.1154725975356996, 0.28647692932281643, 0.24485623376676813, 0.1376173787866719, 0.1857311392086558, 0.13427394413156435, 0.14721581217600033, 0.24492186930729076, 0.1029098333674483, 0.1212159002898261, 0.10409010050352663], [0.010526966816541972, 0.032599241167190485, 0.03783595020649955, 0.05016727933252696, 0.030648491156171076, 0.042394232368678786, 0.04916432611935306, 0.03844653365376871, 0.019263270442024805, 0.061880918947281316, 0.10652323166141286, 0.06155703456897754, 0.0525952080351999, 0.04016918828710914, 0.042645471621653996, 0.019738393384614028, 0.009036346509674331, 0.05414942483184859, 0.2814246551133692, 16.83948989957571, 44.643492847681046, 41.898121163249016, 27.947715036571026, 21.62543948739767, 36.61967620253563, 39.22494940459728, 15.597498994320631, 1.112902332097292, 0.14973074285080656, 1.4398654061369598, 6.157877845689654, 16.317865289747715, 7.087993361055851, 6.984697803854942, 11.344975233078003, 18.095613196492195, 25.915739871561527, 20.61284512281418, 38.1673027575016, 49.85199116170406, 54.938048645853996, 49.88017424941063, 49.43597428500652, 45.27731403708458, 41.53038449585438, 39.04064029455185, 38.94534520804882, 38.188726007938385, 40.072908103466034, 40.18036253750324, 46.347545608878136, 48.090322092175484, 49.86310936510563, 44.942225217819214, 46.97085276246071, 42.05509454011917, 40.78606143593788, 36.92401707172394, 36.88441559672356, 38.04675042629242, 39.593985602259636, 37.55550138652325, 39.19475242495537, 37.63128452003002, 36.9132674485445, 34.45142135024071, 36.82563275098801, 33.80034148693085, 38.70115511119366, 41.950489953160286, 35.05066439509392, 35.776235461235046, 35.854534059762955, 35.454844906926155, 34.491585195064545, 34.55760285258293, 36.79156377911568, 38.799459636211395, 40.653475150465965, 37.98234008252621, 36.91940411925316, 35.14770358800888, 40.7058971375227, 46.3586600124836, 46.26803107559681, 45.553027242422104, 53.63201692700386, 37.63241305947304, 34.95712861418724, 54.024197682738304, 48.19415532052517, 47.884749323129654, 49.6890065073967, 50.36504343152046, 50.009097531437874, 50.766089111566544, 50.51770783960819, 49.466950222849846, 49.294751062989235, 41.00862689316273, 35.984851866960526, 37.880748733878136, 38.79266180098057, 38.198803067207336, 39.95438486337662, 45.85711732506752, 49.94905695319176, 52.2968939691782, 51.09132505953312, 51.48399978876114, 51.103849187493324, 48.88014771044254, 49.14269842207432, 49.808289706707, 50.63829056918621, 50.45660711824894, 50.76814480125904, 49.33671221137047, 50.21849289536476, 52.46063478291035, 48.953605368733406, 52.88374587893486, 48.233536407351494, 44.12582762539387, 40.070757418870926, 37.19688042998314, 37.638979107141495, 39.574580043554306, 41.38716258108616, 46.20118886232376, 49.18113715946674, 52.74986766278744, 51.30416303873062, 55.7904265075922, 45.84513656795025, 50.31059615314007, 52.20573306083679, 54.74884159862995, 43.66134434938431, 26.871418990194798, 17.36271422356367, 15.609420854598284, 15.539937783032656, 8.033429179340601, 4.805006040260196, 1.4526835433207452, 0.5241672671400011, 0.17245622497284785, 0.15089094231370836, 7.947727628052235, 40.06837874650955, 38.0583132058382, 26.91018830984831, 25.251119434833527, 39.20607961714268, 47.21888065338135, 41.01123735308647, 6.988120945170522, 0.13291679351823404, 0.08820543880574405, 0.02447176488203695, 0.05720837943954393, 0.05133861843205523, 0.032992961641866714, 0.017278309278481174, 0.0898334287921898, 0.027294354731566273, 0.013448420013446594, 0.0629612707416527, 0.05711499499739148, 0.056726651382632554, 0.05927760219492484, 0.051816947452607565, 0.07212553289718926, 0.05652165906212758, 0.03228351299185306, 0.01328558539171354, 0.06377950339810923, 0.04578177657094784, 0.004766758402183768, 0.028674812492681667, 0.03855434544675518, 0.01886054586066166, 0.017033793883456383, 0.012444484382285737, 0.018653256593097467, 0.11811622403911315, 0.0011753845001294394, 0.0568861018109601, 0.04004873029771261, 0.02469832030328689, 0.039943308220244944, 0.05106040582177229, 0.027713176496035885, 0.6996984919533134, 21.333501152694225, 53.36569681763649, 47.69832752645016, 36.875812858343124, 22.750173434615135, 30.15485890209675, 41.76382876932621, 18.58835745602846, 1.1606415454298258, 0.16252432978944853, 0.5405769834760576, 7.424108125269413, 10.094844214618206, 1.878605301026255, 5.2046790439635515, 9.215549547225237, 21.75400748848915, 27.57728811353445, 21.741534657776356, 41.1997452378273, 51.98872670531273, 54.463385716080666, 52.88903519511223, 50.62089890241623, 47.10015222430229, 42.7280992269516, 39.54564079642296, 40.547092258930206, 39.962075650691986, 41.37249156832695, 43.22626769542694, 48.84047023952007, 49.37828578054905, 52.41135522723198, 47.826920226216316, 48.22225101292133, 44.544945135712624, 42.77904309332371, 40.29941774904728, 38.59286472201347, 41.21479243040085, 41.46264933049679, 41.66575223207474, 40.57881295681, 40.192711874842644, 40.112270191311836, 37.660812735557556, 38.353291377425194, 35.8222471922636, 40.10881997644901, 42.32116386294365, 36.48606017231941, 36.77859127521515, 38.224588483572006, 37.99590155482292, 37.014680206775665, 38.15757907927036, 39.12211172282696, 41.045891493558884, 42.80289441347122, 40.62744274735451, 38.882082402706146, 37.0258592069149, 42.1208082139492, 46.75124354660511, 48.926585018634796, 46.55491568148136, 55.99205128848553, 39.00427244603634, 37.48207412660122, 54.65504363179207, 49.59138594567776, 51.00097730755806, 51.79023675620556, 54.002443850040436, 51.955185905098915, 53.33354294300079, 51.00065432488918, 52.58060194551945, 49.7919087857008, 41.389499455690384, 36.48177780210972, 40.526630356907845, 39.351547211408615, 40.12298561632633, 41.86157092452049, 50.09839653968811, 51.12271897494793, 54.55687589943409, 52.417233511805534, 52.71742880344391, 51.89287684857845, 52.591043785214424, 51.469761952757835, 51.38892509043217, 52.054375782608986, 51.96541875600815, 50.894693210721016, 50.0424787402153, 50.664448365569115, 51.62867322564125, 50.47177970409393, 53.681577667593956, 49.70560781657696, 45.513505563139915, 41.73503391444683, 39.43562150001526, 39.77825291454792, 40.985197350382805, 43.7614119797945, 49.19512040913105, 52.926531583070755, 54.47543486952782, 53.69652606546879, 56.76721349358559, 47.90392689406872, 52.0743665099144, 54.23826299607754, 56.516069769859314, 48.03141385316849, 31.198662891983986, 16.89431145787239, 16.208748444914818, 17.814751267433167, 7.812087731435895, 8.265584371984005, 1.7922485223971307, 0.5011155072133988, 0.04528932448010892, 0.14198147429851815, 8.416658565402031, 44.5426082611084, 48.180791437625885, 29.183667115867138, 28.74798059463501, 46.81487873196602, 55.5377134680748, 47.896996065974236, 9.006910342723131, 0.09495536098256707, 0.03893187596986536, 0.12512215005699545, 0.01085962987417588, 0.047744823968969285, 0.037108511896803975, 0.03630770857853349, 0.08544248237740248, 0.03947601864638273, 0.05617997427179944, 0.08213625900680199, 0.04772440006490797, 0.041125976204057224, 0.029532740772992838, 0.05243582068942487, 0.06924534682184458, 0.055344445863738656, 0.0766694730555173, 0.11251053772866726, 0.13170566788176075, 0.10926391623797826, 0.18184115731855854, 0.15326438995543867, 0.14321657130494714, 0.20167382201179862, 0.12099284038413316, 0.11492705962155014, 0.16934111947193742, 0.2037901451694779, 0.0870829404448159, 0.1435559257515706, 0.10099359322339296, 0.11083694276749156, 0.07196393024059944, 0.12470443965867162, 0.11532926655490883, 1.0420661768876016, 28.878072313964367, 60.44560991227627, 55.48536367714405, 40.58690272271633, 30.568935982882977, 44.08968776464462, 51.257687732577324, 22.30071645230055, 1.7444158578291535, 0.3844649135135114, 3.11605058144778, 12.956341467797756, 26.6518097743392, 12.336033303290606, 15.613289047032595, 18.044281750917435, 24.792071767151356, 31.3288477063179, 25.59236202389002, 46.678735837340355, 53.990558087825775, 57.057362124323845, 55.087848007678986, 53.144590482115746, 49.94543194770813, 44.781459644436836, 42.904812544584274, 42.33566388487816, 41.530578285455704, 42.68257386982441, 43.0597872287035, 51.64125815033913, 51.81898221373558, 55.494825169444084, 49.2557917535305, 49.84260946512222, 45.99072955548763, 44.31695356965065, 41.884324103593826, 40.13340085744858, 42.625193148851395, 43.73278811573982, 42.41813085973263, 42.11387358605862, 40.73516696691513, 39.338597506284714, 38.486877009272575, 40.67656651139259, 38.02193395793438, 41.655511781573296, 43.921341598033905, 38.979212790727615, 38.91564220190048, 40.10287709534168, 39.3079749494791, 38.344658240675926, 39.4034980237484, 40.38465857505798, 43.53645645081997, 45.537850856781006, 43.376998007297516, 41.238389164209366, 38.961247354745865, 45.269558653235435, 49.209118857979774, 50.17944619059563, 50.39812445640564, 56.43386498093605, 40.82456476986408, 38.904565796256065, 55.0347800552845, 51.76687180995941, 53.10907378792763, 54.43230718374252, 54.043861627578735, 54.636371433734894, 55.23025296628475, 51.869014129042625, 53.851151168346405, 53.02821412682533, 46.09019301831722, 38.90778802335262, 42.696830704808235, 42.12832801043987, 43.03121656179428, 42.26830489933491, 51.670034006237984, 53.00004243850708, 57.37951643764973, 54.1776030510664, 55.567792654037476, 55.62994211912155, 54.647117257118225, 52.81329765915871, 54.356710240244865, 53.2711236923933, 54.09025713801384, 52.76394210755825, 51.86531312763691, 51.67207829654217, 53.95417504012585, 50.51272250711918, 57.430152520537376, 52.35004931688309, 48.87746125459671, 44.14553716778755, 41.80949851870537, 42.07052171230316, 42.55275383591652, 46.08929626643658, 51.91341854631901, 54.73029859364033, 56.86821587383747, 54.81625758111477, 57.83613033592701, 49.266058802604675, 53.7526186555624, 57.772464752197266, 59.294894859194756, 48.204312175512314, 35.069921761751175, 19.8289642855525, 23.26709009706974, 26.183910481631756, 15.695128105580807, 11.648216061294079, 4.910280341282487, 0.9004573349375278, 0.3129967156564817, 0.38916493474971503, 10.999588016420603, 50.69776497781277, 48.09710472822189, 38.04687961935997, 34.91060011088848, 53.30363094806671, 61.82621642947197, 55.75490601360798, 12.698000930249691, 0.1700579302269034, 0.22359241149388254, 0.18045507778879255, 0.22387793054804206, 0.16638404689729214, 0.14744143991265446, 0.09874161289189942, 0.2609520067926496, 0.11500332271680236, 0.1532544451765716, 0.21392950031440705, 0.15143039461690933, 0.12808674800908193, 0.14952496014302596, 0.15785559749929234, 0.15690380794694647, 0.18034920300124213, 0.10545879893470556], [0.036615250864997506, 0.0224556910325191, 0.05141763118444942, 0.02450912830681773, 0.06525673350552097, 0.02749834329733858, 0.029862341543775983, 0.06529826408950612, 0.08205595120671205, 0.019133079185849056, 0.06961789011256769, 0.09167181022348814, 0.0706578245444689, 0.057365462416782975, 0.10607694115606137, 0.05680002010194585, 0.07454279693774879, 0.09056920884177089, 0.8312382898293436, 16.261121034622192, 46.49721957743168, 42.56104879081249, 18.167053163051605, 15.597577840089798, 33.570773005485535, 39.57212157547474, 17.10655476897955, 1.3537793629802763, 0.2713101025437936, 17.24327903240919, 11.267533488571644, 8.214268125593662, 10.910687986761332, 2.68854858353734, 12.597128693014383, 17.413492798805237, 18.14566981047392, 27.773108705878258, 49.40540872514248, 47.29339845478535, 54.33326929807663, 46.596276462078094, 48.54829251766205, 43.68873707950115, 42.65960790216923, 41.26016579568386, 39.61352035403252, 37.27636456489563, 37.65643157064915, 37.31001555919647, 39.985596388578415, 39.98031087219715, 42.643131986260414, 38.8776670396328, 39.58721436560154, 38.692476376891136, 36.959465369582176, 32.5228538364172, 34.2941439896822, 35.333445221185684, 35.61698980629444, 33.15406836569309, 37.4202286452055, 34.63096931576729, 35.85256576538086, 33.19859437644482, 35.32263100147247, 34.219907373189926, 36.68067432940006, 35.295663848519325, 37.22110033035278, 36.62594586610794, 38.297278583049774, 35.78285850584507, 35.68094037473202, 33.006123304367065, 35.98190322518349, 36.25240311026573, 36.88510715961456, 35.92383474111557, 38.27821500599384, 36.89455345273018, 44.66011695563793, 45.156134739518166, 49.98650014400482, 46.493830159306526, 54.56390932202339, 37.09993623197079, 30.010405853390694, 52.03903220593929, 49.99568045139313, 52.30437196791172, 52.594072222709656, 48.23389358818531, 49.392550215125084, 43.54966074228287, 48.228254690766335, 50.54251290857792, 49.57156240940094, 42.06955276429653, 35.72364628314972, 35.05541034042835, 38.25090207159519, 37.86541275680065, 38.00320856273174, 37.78474688529968, 40.26810362935066, 45.406503304839134, 49.08108852803707, 48.37315231561661, 48.50981578230858, 48.54176066815853, 48.31079766154289, 47.7531623840332, 47.96037286520004, 49.432417675852776, 50.16761362552643, 50.58941379189491, 48.457477390766144, 48.38645160198212, 49.830947890877724, 53.08590643107891, 49.23107787966728, 47.19263166189194, 41.20964750647545, 38.70717778801918, 37.49063886702061, 36.92822344601154, 40.55249556899071, 42.74519070982933, 44.28760014474392, 46.4864357560873, 50.40432192385197, 53.59878771007061, 51.14479199051857, 47.13835917413235, 49.97827358543873, 42.740676552057266, 44.2119500041008, 39.7261007130146, 27.794997431337833, 20.90368341654539, 18.567488975822926, 5.343196336179972, 6.327418573200703, 0.4959268856327981, 0.709998729871586, 0.12069280492141843, 0.11716883542248979, 6.768008256331086, 33.61056827008724, 44.56433929502964, 31.201980113983154, 28.837277702987194, 44.88210864365101, 47.396479323506355, 40.20760327577591, 9.595551956444979, 0.05908032449951861, 0.05660972972691525, 0.01583501016284572, 0.0645827669359278, 0.0441942410543561, 0.042658678139559925, 0.011663719051284716, 0.011877225661010016, 0.08090522896964103, 0.01835900060541462, 0.05988315759168472, 0.03581844401196577, 0.045063295983709395, 0.07383449119515717, 0.019300108797324356, 0.02888329476263607, 0.04283897920686286, 0.01772978182998486, 0.04704482285887934, 0.038580253822146915, 0.03286316743469797, 0.05864830920472741, 0.05999209373840131, 0.0514684942754684, 0.07488362825824879, 0.04005015151051339, 0.10613468024530448, 0.023013674763205927, 0.04590425320202485, 0.030170457139320206, 0.03298585186712444, 0.09366779413539916, 0.03192338212102186, 0.05112426762934774, 0.051378505158936605, 0.04703399863501545, 1.0403601871803403, 21.10497761517763, 52.6128888130188, 49.68594007194042, 24.3562750518322, 18.655102774500847, 36.721237152814865, 40.6795759499073, 19.816998727619648, 1.2776747904717922, 0.44139372592326254, 20.427696257829666, 18.476523756980896, 13.936635665595531, 13.5356973297894, 4.948753276839852, 13.522529136389494, 19.949073940515518, 18.55594329535961, 31.260542571544647, 50.56446053087711, 50.1843137294054, 55.85473045706749, 48.86311702430248, 51.18128523230553, 46.24330960214138, 44.54858914017677, 41.16955205798149, 42.151423171162605, 37.77475342154503, 39.17897567152977, 39.04674656689167, 41.01224809885025, 42.281121611595154, 43.9320570230484, 40.73797881603241, 41.48973807692528, 40.22573970258236, 38.86531010270119, 34.47996161878109, 37.57726661860943, 36.74415372312069, 37.11773067712784, 35.46597830951214, 38.53175640106201, 35.29871128499508, 36.54477842152119, 35.955034866929054, 37.84690015017986, 37.00408257544041, 38.00845228135586, 37.403976917266846, 38.83074715733528, 38.22606660425663, 39.16894041001797, 38.01633305847645, 37.4551297724247, 35.1249086111784, 38.45535010099411, 38.45463573932648, 38.71538534760475, 37.343237176537514, 39.33027595281601, 37.96176418662071, 47.11267255246639, 48.18815544247627, 52.495311722159386, 48.017878979444504, 53.48941057920456, 37.05685794353485, 32.93916329741478, 52.12422363460064, 52.30591468513012, 53.091389536857605, 53.611209243535995, 49.02799777686596, 50.26273012161255, 45.61833433806896, 48.71654748916626, 52.49118134379387, 51.242830529809, 44.530847892165184, 38.31002689898014, 37.70443059504032, 41.39331065118313, 39.05602566897869, 40.40442891418934, 40.38083977997303, 43.797335252165794, 47.773126512765884, 51.27733647823334, 51.30692549049854, 50.3331745415926, 51.57573826611042, 49.13429707288742, 50.41125275194645, 51.03856489062309, 51.35986045002937, 53.18001598119736, 51.103207021951675, 52.01225504279137, 49.15629789233208, 50.441700518131256, 51.43874801695347, 51.28777451813221, 49.29520323872566, 43.685780838131905, 40.598826482892036, 39.927782490849495, 39.80059951543808, 42.07088649272919, 44.0028016269207, 47.30908401310444, 48.65634731948376, 53.021518886089325, 55.794135108590126, 51.87157519161701, 47.48399242758751, 51.17355264723301, 45.95944203436375, 46.391912028193474, 41.19839251041412, 26.257647424936295, 14.350257720798254, 13.193601686507463, 9.531349651515484, 9.005318228155375, 4.511177306994796, 0.5947522202041, 0.2313903352478519, 0.1706207453389652, 7.962718773633242, 36.527591943740845, 38.73142808675766, 33.31168010830879, 33.27656239271164, 47.455923333764076, 53.63475278019905, 46.5347121655941, 11.489586923271418, 0.15124842000659555, 0.06750538901542313, 0.02912904954428086, 0.06105000669776928, 0.013447242781694513, 0.060510906914714724, 0.024766349270066712, 0.07267783919814974, 0.03816173077211715, 0.0353356287087081, 0.029083116169204004, 0.12179448604001664, 0.02216995861090254, 0.03157259117870126, 0.024031264983932488, 0.0399200789979659, 0.016697409882908687, 0.0783815557952039, 0.13836329657351598, 0.13768296979833394, 0.1472912440658547, 0.14016316796187311, 0.12022885130136274, 0.11234457866521552, 0.17881098319776356, 0.1986366420169361, 0.24638459784910083, 0.14489568042336032, 0.25661430205218494, 0.17384254198987037, 0.24171325319912285, 0.21880829008296132, 0.16823870362713933, 0.11585206506424583, 0.13650721492012963, 0.22856793279061094, 1.9850454269908369, 29.576716125011444, 59.77679260075092, 57.127506360411644, 29.39186554402113, 25.608199574053288, 43.56622785329819, 49.87588047981262, 24.47150196880102, 1.443743691779673, 0.46170746558345854, 24.649704806506634, 20.962888039648533, 10.91906463727355, 14.53028541058302, 7.9351854510605335, 18.946322947740555, 22.163509614765644, 23.888058476150036, 35.05946472287178, 52.7310586720705, 52.12698608636856, 58.559641912579536, 50.17934359610081, 53.62568646669388, 48.27632591128349, 47.23968453705311, 44.584409818053246, 44.081347212195396, 40.43081849813461, 41.33309908211231, 41.4571700245142, 43.79537835717201, 43.05583544075489, 46.22024863958359, 42.656723856925964, 43.31276625394821, 43.11142645776272, 41.68976694345474, 36.801621839404106, 39.85073782503605, 38.38459029793739, 39.08721439540386, 37.8668262809515, 41.24975435435772, 37.70508795976639, 38.64697381854057, 38.045538291335106, 39.25915136933327, 39.99428652226925, 39.528868496418, 39.872609451413155, 41.322957426309586, 40.30958980321884, 41.58046580851078, 39.69058021903038, 39.378567561507225, 37.87485145032406, 40.4580782353878, 40.443821400403976, 39.90588426589966, 39.13321852684021, 41.5107661485672, 41.193908751010895, 49.263786524534225, 49.59953270852566, 54.657631292939186, 51.31564982235432, 56.16939157247543, 39.79832723736763, 36.5472786873579, 53.94466035068035, 52.689694091677666, 55.03669515252113, 56.081722676754, 49.46761138737202, 50.703225284814835, 47.14352309703827, 51.0449181497097, 55.12284033000469, 54.457469433546066, 47.35581770539284, 41.16610184311867, 40.25159731507301, 43.26689891517162, 41.28583341836929, 42.39529028534889, 42.08099015057087, 45.92123508453369, 49.38785746693611, 53.85162614285946, 53.5754569619894, 53.411852940917015, 54.25096191465855, 52.614978700876236, 52.76874125003815, 53.788921907544136, 54.418544322252274, 56.486503556370735, 53.77583160996437, 52.41262435913086, 50.14674514532089, 52.49107114970684, 54.97574642300606, 54.079473316669464, 52.48012013733387, 46.59943789243698, 42.761134654283524, 41.97446666657925, 41.31888024508953, 43.82495976984501, 46.4780268073082, 50.20756088197231, 50.202108174562454, 55.73801212012768, 58.522909283638, 55.75958736240864, 49.208940267562866, 52.00452245771885, 47.757022976875305, 51.53300955891609, 39.6967700868845, 35.02923734486103, 30.431558154523373, 23.77349842339754, 9.888094458729029, 10.628294739872217, 4.6156370267271996, 2.4082048516720533, 0.4073770606191829, 0.2974168985383585, 9.524736106395721, 44.457857608795166, 55.47059006989002, 45.56885339319706, 40.09585127234459, 56.753861010074615, 59.8019814491272, 54.35606427490711, 15.897167064249516, 0.25342894485220313, 0.19907627545762807, 0.1418083015596494, 0.19921686791349202, 0.1465781292063184, 0.1305918229627423, 0.11366518592694774, 0.14544760080752894, 0.19464431796222925, 0.151132125465665, 0.19348009605892003, 0.20618851413019001, 0.12680035375524312, 0.1238495523284655, 0.1488406109274365, 0.18825969571480528, 0.06984310966799967, 0.17262305977055803], [0.03227955363399815, 0.06540560090797953, 0.03732094424776733, 0.038813336432212964, 0.01579592495545512, 0.023730962348054163, 0.011869971167470794, 0.024668818077770993, 0.014088118841755204, 0.035710995871340856, 0.03807626504567452, 0.03857931871607434, 0.04074782227689866, 0.08166720683220774, 0.046340732515091076, 0.05983997201838065, 0.029868599704059307, 0.03835275216260925, 1.4313638373278081, 16.8348503485322, 42.5926972925663, 42.6745031028986, 31.434736624360085, 23.02353646606207, 45.79576201736927, 53.43282401561737, 12.817410472780466, 0.6841259775683284, 0.27389348892029375, 0.9894310450181365, 2.675614315085113, 2.8252186998724937, 2.400045027025044, 3.06378913577646, 7.431172896176577, 12.315728142857552, 20.062991827726364, 39.34282287955284, 50.34463092684746, 50.76105058193207, 49.59568351507187, 49.69201974570751, 47.78680577874184, 45.16317956149578, 44.44789074361324, 43.322938308119774, 43.19893956184387, 41.422299295663834, 41.36057920753956, 37.39550717175007, 36.579865738749504, 34.63546447455883, 35.385342836380005, 33.981910943984985, 33.7303302437067, 34.44387495517731, 34.66477230191231, 33.640240877866745, 33.32714527845383, 35.566194131970406, 34.43771168589592, 34.73880372941494, 36.48332431912422, 35.05072899162769, 35.54037071764469, 32.98419088125229, 34.23893675208092, 35.58962747454643, 38.037228137254715, 39.47987012565136, 41.31433568894863, 38.93124036490917, 39.12277668714523, 38.03003512322903, 37.59416811168194, 35.179298892617226, 36.981690376996994, 33.71939443051815, 36.068553775548935, 34.60402116179466, 38.96677605807781, 39.304262548685074, 47.65686795115471, 48.03463988006115, 52.85535380244255, 45.12663692235947, 49.22473601996899, 35.50748348236084, 28.05111698806286, 46.282827481627464, 43.37685361504555, 49.25591714680195, 46.27679720520973, 46.42089307308197, 45.251129642128944, 44.53941263258457, 42.9865575581789, 48.06091167032719, 48.94284054636955, 45.315186604857445, 36.0066094994545, 35.99963687360287, 35.28719790279865, 37.11940258741379, 36.285016760230064, 35.07496789097786, 34.92799177765846, 35.60036189854145, 37.38836355507374, 40.12194067239761, 40.14622896909714, 40.15868090093136, 39.934162348508835, 41.5632489323616, 42.15242251753807, 43.180727139115334, 44.55431543290615, 46.53862975537777, 48.676873818039894, 51.09119586646557, 48.660006523132324, 51.65605455636978, 51.974815651774406, 48.53380769491196, 44.06752735376358, 39.81573790311813, 35.87605610489845, 40.15549287199974, 44.24775168299675, 45.756183341145515, 45.35194203257561, 47.41811916232109, 48.01989667117596, 53.525474444031715, 52.89967082440853, 48.548915684223175, 46.26128263771534, 53.82497437298298, 56.58848248422146, 48.41566443443298, 28.312058486044407, 17.242467775940895, 15.89855968952179, 4.9985491298139095, 10.022088568657637, 2.1096866950392723, 0.6584125198423862, 0.11131979888887145, 0.016848832128744107, 3.789245020598173, 33.68394993245602, 51.42870515584946, 35.444391667842865, 33.85290026664734, 50.583919286727905, 48.540366142988205, 37.40836948156357, 9.915700927376747, 0.03705221628479194, 0.04060625389683992, 0.01316863776082755, 0.05786160298157483, 0.02537659318477381, 0.04259667170117609, 0.0502921159932157, 0.0487867473566439, 0.0131703530496452, 0.02926132809079718, 0.05695814950740896, 0.06016647988872137, 0.03039876031834865, 0.034804640599759296, 0.03787657537031919, 0.024771733551460784, 0.01737857899570372, 0.031472505143028684, 0.00550535119145934, 0.10455020979861729, 0.05605151964118704, 0.01957710428541759, 0.06482269585831091, 0.05692493468814064, 0.09148302269750275, 0.05437060710391961, 0.07732981379376724, 0.08315105689689517, 0.07194496836746112, 0.031850358500378206, 0.0900148022628855, 0.03468172981229145, 0.036257446627132595, 0.018579843344923574, 0.050106293347198516, 0.045950748753966764, 2.1337002189829946, 21.92762777209282, 49.36776414513588, 50.27472227811813, 33.029465451836586, 26.692518889904022, 43.82068119943142, 56.173689141869545, 15.884129963815212, 1.144480062648654, 0.26610645989421755, 3.9087543077766895, 5.24691472761333, 2.0416401838883758, 4.550495697185397, 3.935876302421093, 11.08270475640893, 12.10908668115735, 20.99457833915949, 42.148550525307655, 52.559212893247604, 51.39728084206581, 53.05446311831474, 50.15180267393589, 50.09868532419205, 45.657764822244644, 46.4661068469286, 44.271097630262375, 45.163054168224335, 42.21142195165157, 43.410964384675026, 38.987367153167725, 39.081009328365326, 37.819435223937035, 37.22987785935402, 35.87102897465229, 35.713223442435265, 35.57546943426132, 37.122366428375244, 35.350836887955666, 36.522352024912834, 36.03543855249882, 36.10333330929279, 35.84653168916702, 36.271546483039856, 35.284351855516434, 36.73367388546467, 34.563617929816246, 36.54147259891033, 37.64183275401592, 39.93040814995766, 40.98211191594601, 43.710384517908096, 41.278898790478706, 41.55553534626961, 39.906378239393234, 39.663065895438194, 37.90137782692909, 38.18765826523304, 35.128028243780136, 36.4873369038105, 35.48064172267914, 40.89450381696224, 42.855077013373375, 48.661397248506546, 51.24630354344845, 54.743844866752625, 47.326753064990044, 49.69365745782852, 36.72326624393463, 29.70649816095829, 47.36272193491459, 45.198954641819, 50.428940802812576, 47.98845335841179, 48.29390376806259, 47.53837130963802, 44.95306983590126, 45.17098054289818, 51.12221360206604, 51.075483709573746, 47.318195924162865, 38.591895774006844, 37.19537191092968, 36.90576285123825, 38.72282534837723, 37.8571368008852, 36.63758464157581, 37.03951567411423, 37.44127571582794, 41.629768162965775, 43.66417899727821, 42.94053442776203, 43.87396574020386, 43.13420243561268, 45.015819668769836, 45.061952993273735, 47.26773843169212, 48.232894241809845, 49.59758721292019, 50.91445975005627, 52.11651384830475, 49.5589204877615, 51.123212948441505, 52.48181104660034, 49.61742214858532, 45.22502884268761, 42.20703698694706, 37.55546718835831, 41.15097865462303, 45.95993980765343, 47.73838497698307, 46.37832395732403, 48.38143207132816, 51.81412987411022, 56.32218897342682, 54.22103472054005, 49.689781665802, 48.64776358008385, 53.15793916583061, 58.635231256484985, 46.12768180668354, 30.885546393692493, 15.69249864667654, 10.697883255779743, 12.518498562276363, 14.371845312416553, 8.052652347832918, 1.1280689807608724, 0.20422373752808198, 0.11287308429018594, 4.807453108951449, 36.59759558737278, 56.10681273043156, 40.03117874264717, 37.6636815816164, 54.82292242348194, 54.36708748340607, 43.52832868695259, 12.575486954301596, 0.08835288128466345, 0.05360111499612685, 0.06441271121730097, 0.05108284094603732, 0.014771022724744398, 0.03356683846504893, 0.028808638417103793, 0.04884544381638989, 0.048218380979960784, 0.04919513266941067, 0.07829586742445827, 0.0372506591520505, 0.016606231474725064, 0.009531346022413345, 0.019856316939694807, 0.06486720987595618, 0.06818226480390877, 0.02668949880899163, 0.14508755528368056, 0.25828036421444267, 0.16570173116633669, 0.062162140966393054, 0.18757070065476, 0.10800613919855095, 0.20267576590413228, 0.08934164463425986, 0.2797729312442243, 0.1311571613769047, 0.17462074320064858, 0.1658924185903743, 0.16072655125753954, 0.20646195102017373, 0.24325076054083183, 0.22360188129823655, 0.18143211520509794, 0.22481414984213188, 2.9794885218143463, 28.09673923999071, 60.06159111857414, 57.418745532631874, 41.56501583755016, 35.551367327570915, 55.50812445580959, 63.206758350133896, 17.42772113531828, 1.2917645531706512, 0.6565928331110626, 3.1470989529043436, 5.014484999701381, 5.983112398535013, 4.209976494312286, 5.535607086494565, 10.024726577103138, 15.763593781739473, 25.12574516236782, 46.511332020163536, 55.548884868621826, 55.467941612005234, 55.818051025271416, 53.75291503965855, 52.707298547029495, 48.13341177999973, 48.48126031458378, 46.96264520287514, 48.27241592109203, 44.06063452363014, 45.207773968577385, 40.91868191957474, 40.96548020839691, 38.59852261841297, 38.38910825550556, 37.30322152376175, 37.18329235911369, 38.242371529340744, 39.0739569067955, 37.73789159953594, 37.50039294362068, 38.67905929684639, 37.72795893251896, 37.24073767662048, 38.92666541039944, 36.750624775886536, 38.541852459311485, 36.10842123627663, 38.467232063412666, 39.35118243098259, 42.80180387198925, 43.060152009129524, 45.81247352063656, 43.84626142680645, 42.96855412423611, 42.60975457727909, 42.14149430394173, 39.85359527170658, 41.37782648205757, 37.31614463031292, 40.05877286195755, 38.39847095310688, 43.02657701075077, 44.563013166189194, 51.7965330183506, 53.696138486266136, 56.49026535451412, 48.13353717327118, 50.723770782351494, 38.66454407572746, 32.73832127451897, 47.08611577749252, 43.061858117580414, 50.385839715600014, 49.72789742052555, 48.2151035964489, 47.13985249400139, 45.729265585541725, 48.26043516397476, 52.437402829527855, 53.99987518787384, 49.13708612322807, 42.30912610888481, 39.85488340258598, 40.18945924937725, 41.72089487314224, 40.23430824279785, 38.02518658339977, 39.37971509993076, 39.02155011892319, 42.22557619214058, 44.077718406915665, 43.923887461423874, 45.332996249198914, 43.28272886574268, 46.767814457416534, 46.72757841646671, 48.39761160314083, 49.97307546436787, 52.48153746128082, 53.98953594267368, 54.32345062494278, 51.251805648207664, 52.784510403871536, 54.12671998143196, 52.94640451669693, 47.39097721874714, 43.89354608952999, 38.946507945656776, 42.80020035803318, 48.520728796720505, 52.17593505978584, 49.40198510885239, 52.16093346476555, 53.19752164185047, 58.41498367488384, 56.25193454325199, 50.46603821218014, 51.658159643411636, 56.02439135313034, 53.6539189517498, 49.38341170549393, 32.020456194877625, 22.049810215830803, 21.73244934529066, 16.048816926777363, 17.01315578073263, 5.537873189896345, 1.6447266633622348, 0.49749453901313245, 0.3222243126947433, 5.21732809022069, 46.441031992435455, 64.3089348077774, 45.562530532479286, 45.10777473449707, 61.569635197520256, 62.367941960692406, 50.17588958144188, 16.226884871721268, 0.4866202350240201, 0.1632241898914799, 0.08457366493530571, 0.1299040301819332, 0.08571425685659051, 0.13642538571730256, 0.13507944153388962, 0.14437322330195457, 0.24473416531691328, 0.1609268123866059, 0.14132364944089204, 0.1615068898536265, 0.11410123479436152, 0.1797038016957231, 0.09924170910380781, 0.23606399539858103, 0.14837531402008608, 0.11899259654455818], [0.021713916285079904, 0.04082605577423237, 0.022124737697595265, 0.04915624413115438, 0.07171688412199728, 0.09646806574892253, 0.04646844128728844, 0.07160150242270902, 0.027029793927795254, 0.03888396291586105, 0.013877715337002883, 0.03189357004885096, 0.08178689298802055, 0.02847706724423915, 0.06335112833767198, 0.04164035133726429, 0.0482511764857918, 0.06688332825433463, 0.36058274970855564, 21.708681620657444, 49.29173402488232, 45.848529785871506, 33.23137901723385, 22.974596992135048, 55.93573831021786, 40.09529270231724, 10.089611895382404, 0.4763265873771161, 1.5736729698255658, 1.0589453461579978, 0.6155230337753892, 4.440759010612965, 4.484566384926438, 3.013274408876896, 13.927111476659775, 14.129047840833664, 28.085013069212437, 47.12573625147343, 51.378145068883896, 50.01146860420704, 48.354430720210075, 46.798797994852066, 44.670573994517326, 46.433158814907074, 46.728463768959045, 48.38742054998875, 47.6444236189127, 47.42926016449928, 46.99019752442837, 42.44859002530575, 35.50428405404091, 34.83200892806053, 35.322349816560745, 35.41403889656067, 40.30410289764404, 42.43612289428711, 43.68369475007057, 40.55325172841549, 40.744252279400826, 40.40176145732403, 41.03911265730858, 42.01990082859993, 45.62502197921276, 43.2409843057394, 42.31573015451431, 39.61979001760483, 35.7984908670187, 34.949551820755005, 38.72306473553181, 41.15039348602295, 43.00442799925804, 40.58989696204662, 38.913525715470314, 37.10701905190945, 35.246004313230515, 34.866218492388725, 35.911903381347656, 35.93915171921253, 36.72663666307926, 34.40834306180477, 40.32989211380482, 43.819039687514305, 48.84894758462906, 47.23002925515175, 50.75963705778122, 46.85476899147034, 52.46786579489708, 39.44832801818848, 26.855887323617935, 44.702180698513985, 43.28773319721222, 45.548209100961685, 42.73112766444683, 43.23847644031048, 45.11831536889076, 45.25124363601208, 46.43102712929249, 51.653554290533066, 48.88624258339405, 44.26884435117245, 34.32403318583965, 36.66924074292183, 37.56344676017761, 36.2816197425127, 35.278872549533844, 35.689710304141045, 36.61126725375652, 34.69063751399517, 35.77890291810036, 34.3979050219059, 35.2270433306694, 34.64910574257374, 34.875847175717354, 35.51279179751873, 35.47372229397297, 39.392862394452095, 39.96747516095638, 44.91525426506996, 46.11102730035782, 47.35413059592247, 53.65472070872784, 49.18475076556206, 51.15516923367977, 51.14779382944107, 46.77005633711815, 39.86874505877495, 38.68633210659027, 46.60208635032177, 55.19167743623257, 52.51915164291859, 52.00487203896046, 50.07495939731598, 51.32646024227142, 51.73143491148949, 54.26682986319065, 54.28457871079445, 60.68300597369671, 56.582167223095894, 50.41637867689133, 46.77289858460426, 40.5966529995203, 21.076517142355442, 9.183175284415483, 10.188599433749914, 11.089951917529106, 12.434143088757992, 0.5165185744408518, 0.016218835953623056, 0.10214593334239908, 4.022327363491058, 27.2343223169446, 27.908670231699944, 24.077854491770267, 30.77397108078003, 44.071475341916084, 47.73844197392464, 40.855377316474915, 10.59427136555314, 0.19206581491744146, 0.03597308161261026, 0.01676343505096156, 0.005608576511804131, 0.03355477856530342, 0.023875798033259343, 0.032210352073889226, 0.022710908197041135, 0.03715703722264152, 0.015672481677029282, 0.04863639936957043, 0.04439590855326969, 0.014755933007108979, 0.09765484152012505, 0.04467232145543676, 0.06336843522149138, 0.05904048230149783, 0.04320415297115687, 0.04514600463153329, 0.07035920658381656, 0.041633642322267406, 0.06662091967882589, 0.008286066749860765, 0.052664454124169424, 0.01335596232820535, 0.027552653664315585, 0.04389754896692466, 0.01282877772609936, 0.011970145333179971, 0.01650316200539237, 0.03734452599019278, 0.04255558269505855, 0.025047174240171444, 0.10735814779764041, 0.06865398871013895, 0.07164294394897297, 0.9797432273626328, 28.00614070147276, 56.23412489891052, 51.45578630268574, 39.45974640548229, 27.772669829428196, 59.53150436282158, 48.491599559783936, 12.818239778280258, 0.41431151039432734, 1.858599849510938, 2.275260672904551, 3.338629575446248, 9.751668479293585, 6.060754107311368, 6.022509159520268, 10.958035346120596, 11.285516023635864, 31.89490333199501, 48.155135214328766, 53.69536712765694, 53.57836000621319, 50.85834816098213, 48.23406457901001, 47.78270959854126, 48.22562523186207, 49.260340109467506, 50.576141104102135, 48.065722212195396, 49.013501554727554, 48.27523157000542, 43.41053120791912, 37.43272237479687, 35.64665101468563, 36.538508757948875, 37.06526309251785, 40.03267966210842, 43.350783213973045, 44.8181276768446, 41.32510431110859, 40.869508758187294, 41.7562747746706, 42.31068402528763, 42.96197287738323, 45.40770024061203, 44.76558029651642, 42.565802335739136, 38.899257481098175, 37.58189097046852, 36.498565301299095, 40.40814511477947, 43.54408644139767, 46.00115239620209, 45.78265272080898, 41.5446375310421, 39.47936475276947, 36.90993882715702, 36.153893396258354, 37.62997359037399, 36.883127465844154, 39.528100937604904, 36.321316212415695, 41.99907414615154, 45.108439698815346, 50.76255150139332, 48.851303458213806, 53.21174427866936, 47.87460386753082, 53.3117663115263, 40.34552067518234, 28.484341241419315, 45.04268042743206, 43.21202225983143, 45.577509328722954, 44.56709414720535, 42.621549144387245, 45.45685440301895, 47.76730142533779, 47.256464436650276, 52.70640179514885, 50.43761573731899, 47.87864685058594, 37.34274320304394, 39.40273806452751, 39.04643878340721, 37.423948645591736, 38.09747010469437, 36.87028415501118, 38.915858790278435, 36.89777188003063, 36.60244032740593, 35.41733331978321, 37.26686507463455, 38.02425563335419, 37.28750176727772, 37.88304381072521, 38.25828127563, 41.1395450681448, 43.78695800900459, 46.665702536702156, 48.462485522031784, 52.19407148659229, 53.36143724620342, 50.85975408554077, 51.726373583078384, 52.076425999403, 48.28771770000458, 41.359659656882286, 39.19665612280369, 47.84459687769413, 55.632130801677704, 54.012794494628906, 54.61832620203495, 52.61677220463753, 52.1911646425724, 54.55166257917881, 53.78395177423954, 55.20455114543438, 58.23707342147827, 57.452533319592476, 49.152061119675636, 46.734072268009186, 37.51505635678768, 21.617811396718025, 6.003202395513654, 8.649853002279997, 12.173506524413824, 15.334343165159225, 1.3717288873158395, 0.07400400514598005, 0.04881879700405989, 3.924807021394372, 34.121013879776, 36.592412665486336, 30.83079133182764, 35.791199058294296, 49.76430706679821, 54.657004326581955, 47.540765181183815, 12.995495516806841, 0.22637496062088758, 0.045861089893151075, 0.011178625354659744, 0.05352468120690901, 0.08360650550457649, 0.017635653384786565, 0.060183345194673166, 0.10654273530235514, 0.031608793142368086, 0.018141185828426387, 0.08578885011957027, 0.1367783808382228, 0.002600164943942218, 0.03061577728658449, 0.04813472980458755, 0.06056874990463257, 0.014560964318661718, 0.03923532160115428, 0.11680480456561781, 0.13089255604427308, 0.14461044338531792, 0.14619313267758116, 0.12287076344364323, 0.15629600384272635, 0.1517217469518073, 0.1508783851750195, 0.1628772952244617, 0.11995695807854645, 0.13140199589543045, 0.08786372432950884, 0.22334459354169667, 0.16097469575470313, 0.17279338266234845, 0.2033421996748075, 0.15514454687945545, 0.1387801906093955, 1.9908499717712402, 35.861841067671776, 64.7468613088131, 59.496899619698524, 42.454658299684525, 35.12170158326626, 64.82640624046326, 48.32338638603687, 15.54968236014247, 0.6704804941546172, 2.186563932336867, 2.3029766231775284, 3.701673257164657, 15.020786840468645, 12.129118256270885, 6.8114688992500305, 19.989203587174416, 16.446955762803555, 33.33575941622257, 52.83134289085865, 55.81299349665642, 57.02526144683361, 53.81898209452629, 51.80600970983505, 49.6063457429409, 50.413057655096054, 52.847682014107704, 54.86418820917606, 51.250658109784126, 52.10927903652191, 51.07683643698692, 46.06121577322483, 39.02272045612335, 37.91822612285614, 38.51615823805332, 38.99536952376366, 43.64224657416344, 46.802844777703285, 48.37994635105133, 45.79028271138668, 43.36290456354618, 45.668237060308456, 46.66465379297733, 46.90931126475334, 48.694694861769676, 49.00174878537655, 46.19846820831299, 42.54894644021988, 40.57122476398945, 38.447902500629425, 42.59277328848839, 44.78569641709328, 47.76326984167099, 46.318184584379196, 43.522382006049156, 42.12840400636196, 39.83516626060009, 38.06890703737736, 39.529997035861015, 39.276326447725296, 41.47554583847523, 38.24517957866192, 45.27589291334152, 48.927800953388214, 52.92470008134842, 52.26626381278038, 54.018349796533585, 49.8604267090559, 54.428416192531586, 41.98762156069279, 32.593271657824516, 43.46569664776325, 43.88606809079647, 45.94163998961449, 45.61375178396702, 44.5354912430048, 45.89090131223202, 50.077117681503296, 51.2348547577858, 55.43373204767704, 53.65979723632336, 48.9292448759079, 40.680932477116585, 40.8089704066515, 41.844095662236214, 38.768468499183655, 40.022838190197945, 38.288531452417374, 41.78038068115711, 38.58833536505699, 38.968200981616974, 38.733533173799515, 39.13928300142288, 38.609716817736626, 39.63088542222977, 39.935534074902534, 39.92168001830578, 43.58011230826378, 46.04500584304333, 48.880835473537445, 49.704095497727394, 53.318545147776604, 58.04723180830479, 52.403907626867294, 53.395688608288765, 55.5374588817358, 51.089615151286125, 43.46526347100735, 42.81706765294075, 50.63371181488037, 59.0418816357851, 57.944097742438316, 55.86429834365845, 54.81024630367756, 55.26306800544262, 55.483095198869705, 56.47409722208977, 55.89107930660248, 59.213514626026154, 52.27232448756695, 50.88933929800987, 49.55168567597866, 42.21472777426243, 26.252844482660294, 20.874677672982216, 24.71970845013857, 18.639586307108402, 22.25093152374029, 1.3705657934769988, 0.17899304686579853, 0.2545277390163392, 5.249256351962686, 38.239620476961136, 37.53909386694431, 36.24370537698269, 42.658722549676895, 56.321216225624084, 61.62510462105274, 53.99185001850128, 16.620441153645515, 0.4833142342977226, 0.1446346819284372, 0.16308800579281524, 0.12487422820413485, 0.17615688499063253, 0.14646407595137134, 0.18551582732470706, 0.20307872240664437, 0.178663355181925, 0.11016137315891683, 0.15929160872474313, 0.19058315228903666, 0.14350541518069804, 0.1836980108055286, 0.1718693642760627, 0.14993652555858716, 0.15121137199457735, 0.14886110904626548], [0.0627318951592315, 0.014831093085376779, 0.07289358152775094, 0.04718404605227988, 0.015119385916477768, 0.02306363428942859, 0.012156804750702577, 0.026835737153305672, 0.07901210672571324, 0.029775276489090174, 0.044468382984632626, 0.02193111507949652, 0.05703992675989866, 0.003064323814214731, 0.0070073829465400195, 0.0573973042628495, 0.03598640687414445, 0.031477922821068205, 1.0349262412637472, 26.634416207671165, 49.67754252254963, 41.2311277538538, 21.962981075048447, 37.52072185277939, 47.913228794932365, 30.708502493798733, 13.773852400481701, 0.6467524892650545, 0.5633324186783284, 5.453488267958164, 4.00489579886198, 4.318439299240708, 5.29047274030745, 4.374027941375971, 7.2723594680428505, 15.729065034538507, 35.83260923624039, 44.28332917392254, 51.837859600782394, 48.565680384635925, 48.21698069572449, 43.700839430093765, 45.021435767412186, 46.46626263856888, 48.85574921965599, 50.459434166550636, 49.97868776321411, 49.932839423418045, 48.487070202827454, 41.73824094235897, 34.78377051651478, 38.773476630449295, 37.30170160531998, 38.1317974627018, 46.57507359981537, 51.6754525154829, 49.90703120827675, 47.89544954895973, 49.287634044885635, 46.68590225279331, 47.65374451875687, 48.67487892508507, 48.52469578385353, 48.743503242731094, 48.38361315429211, 47.07462139427662, 43.32391485571861, 36.475625932216644, 39.31702606379986, 44.90540139377117, 46.40330381691456, 43.584911450743675, 39.87843073904514, 34.31631959974766, 36.15708142518997, 34.055759981274605, 35.45035734772682, 35.09576037526131, 35.933896601200104, 35.76305776834488, 40.41389800608158, 42.0205619931221, 46.63828320801258, 47.464290484786034, 47.861836552619934, 46.22703127563, 53.16414423286915, 42.96684421598911, 27.115914970636368, 45.306963846087456, 43.15787896513939, 47.045530155301094, 45.72467543184757, 48.36899533867836, 45.82896463572979, 46.445173770189285, 51.2279087305069, 49.22567076981068, 47.20284931361675, 40.01226715743542, 36.22857078909874, 37.003634199500084, 36.600874811410904, 37.236117124557495, 36.1051420122385, 37.056337371468544, 37.63686262071133, 38.08126777410507, 36.89713351428509, 34.65958558022976, 34.05210077762604, 35.781019404530525, 35.15110820531845, 35.095707178115845, 34.40964259207249, 36.555212661623955, 37.498227059841156, 38.01265865564346, 43.36867265403271, 48.034035712480545, 51.54793135821819, 49.546544551849365, 47.79107294976711, 49.510066509246826, 45.80386318266392, 39.67291496694088, 38.64378198981285, 49.27212327718735, 52.75542676448822, 52.520728558301926, 52.4722545593977, 52.955619022250175, 52.63614356517792, 51.7200393229723, 51.55476339161396, 53.202875554561615, 53.85111317038536, 50.077425464987755, 54.93039205670357, 49.73701313138008, 42.975644543766975, 26.518155746161938, 8.784505426883698, 7.836207412183285, 18.501769602298737, 14.826426319777966, 2.118946798145771, 0.1377094941562973, 0.13958500523585826, 1.8599373777396977, 27.026690058410168, 46.80290937423706, 31.086926087737083, 35.81343166530132, 45.413639321923256, 51.39973171055317, 50.03929831087589, 14.871332310140133, 0.16814826551126316, 0.025802593372645788, 0.026909515909210313, 0.02650383386935573, 0.029612850048579276, 0.014017497924214695, 0.07482998582418077, 0.10282600778737105, 0.06687302724458277, 0.03188512069755234, 0.05324102494341787, 0.03402643938898109, 0.0036557865223585395, 0.07865632855100557, 0.06823057861765847, 0.03411715952097438, 0.013099477018840844, 0.03254580653447192, 0.05821424558234867, 0.026890958506555762, 0.05665819568093866, 0.027681663050316274, 0.015538651114184177, 0.01658428431255743, 0.02254869326861808, 0.03934720407414716, 0.031696752485004254, 0.035326923316461034, 0.04481812007725239, 0.06174217072839383, 0.06528872749186121, 0.05592759211140219, 0.025892274497891776, 0.08981518680229783, 0.08371595744392835, 0.02610420033306582, 1.8104704446159303, 32.47790224850178, 56.20062209665775, 47.152171432971954, 25.495854802429676, 36.80788770318031, 56.79855041205883, 37.15648099780083, 14.754622522741556, 0.6413504853844643, 0.7918814267031848, 4.607618032023311, 2.793862782418728, 6.128128292039037, 8.352869488298893, 4.63737566024065, 9.110792968422174, 17.670079730451107, 39.17982682585716, 48.29433314502239, 53.46330218017101, 52.23537527024746, 50.52365452051163, 46.60302110016346, 46.62513591349125, 47.974447309970856, 49.92906242609024, 50.64262993633747, 51.222478821873665, 51.07589028775692, 49.60032306611538, 43.14481146633625, 37.050550282001495, 40.48743546009064, 38.055030182003975, 39.02694582939148, 48.22464868426323, 52.17687740921974, 51.61045700311661, 50.36228857934475, 52.11197689175606, 49.42579463124275, 49.34075899422169, 51.448562890291214, 50.47587588429451, 51.46228775382042, 52.16959699988365, 48.168795481324196, 43.886645659804344, 38.324918299913406, 40.65533705055714, 46.71833351254463, 47.57573090493679, 44.34011712670326, 41.50761231780052, 37.67261490225792, 38.63692715764046, 35.96676103770733, 38.69062967598438, 37.670809999108315, 37.23743185400963, 36.75997607409954, 41.74185074865818, 44.832806289196014, 48.84610153734684, 48.956124633550644, 49.41189877688885, 47.3166798055172, 53.18354979157448, 43.85950371623039, 29.66785803437233, 45.5727481842041, 42.952226400375366, 46.57593995332718, 44.115860760211945, 47.81838968396187, 45.50469383597374, 48.718454986810684, 51.77388623356819, 52.20058813691139, 48.593643084168434, 42.90339142084122, 37.572889253497124, 37.95494355261326, 37.99224615097046, 39.46569308638573, 37.21351973712444, 37.999420166015625, 38.41705195605755, 39.56374682486057, 37.93934538960457, 37.56097309291363, 35.37270091474056, 37.76704363524914, 36.705946773290634, 37.264706790447235, 37.137048840522766, 38.97719509899616, 39.29327733814716, 39.51151862740517, 45.51630221307278, 50.254013389348984, 53.988190814852715, 50.11467106640339, 49.52870450913906, 52.48260520398617, 48.28961379826069, 41.701903492212296, 41.12398110330105, 51.45255647599697, 54.674601182341576, 54.9623217433691, 54.25305560231209, 55.73560684919357, 54.85919527709484, 53.613207936286926, 54.406951144337654, 53.06221470236778, 53.623095005750656, 50.18675319850445, 55.65613031387329, 50.941153317689896, 41.160877123475075, 28.085679933428764, 9.59529547020793, 10.62696386128664, 14.223308432847261, 12.537299953401089, 1.5794816706329584, 0.3247108042705804, 0.165127249492798, 2.3486796207726, 31.29598516970873, 45.16442969441414, 30.147342905402184, 39.50165055692196, 52.14638024568558, 56.37901112437248, 56.617687717080116, 17.24643286317587, 0.21321497537428513, 0.04849093842494767, 0.027070905198343098, 0.03436989791225642, 0.025047051785804797, 0.02483518903318327, 0.015794991704751737, 0.03432575496844947, 0.07455536149791442, 0.014461691862379666, 0.011066044335166225, 0.021501665760297328, 0.01397488844304462, 0.05250383110251278, 0.020799933590751607, 0.03114183753496036, 0.034759748086798936, 0.012794382892025169, 0.20458338229218498, 0.13230072188889608, 0.27662883745506406, 0.1682724416605197, 0.10556210589129478, 0.1506725579383783, 0.1459389174124226, 0.1813283926458098, 0.1076436742732767, 0.12286228811717592, 0.11728063996997662, 0.1105271332198754, 0.179045086260885, 0.11006347645889036, 0.0585824695735937, 0.2628908527549356, 0.21909275528742, 0.12869048514403403, 3.240442844107747, 42.584307342767715, 62.84333445131779, 54.00946967303753, 31.48484643548727, 46.440507620573044, 55.807966366410255, 41.96554854512215, 18.963304236531258, 1.2682770635001361, 0.978904184885323, 7.505697347223759, 9.781561475247145, 8.984143864363432, 10.050732381641865, 9.510849751532078, 11.279917024075985, 16.686386615037918, 43.72140012681484, 48.11955012381077, 56.24050475656986, 54.920717775821686, 54.2897692322731, 47.83688709139824, 49.764166474342346, 49.41892459988594, 52.94935695827007, 52.44981676340103, 53.46902847290039, 53.542136549949646, 53.842103853821754, 45.66590778529644, 38.550538793206215, 42.88354508578777, 40.14085225760937, 41.80285647511482, 51.146897077560425, 55.011141523718834, 52.35590100288391, 51.45715802907944, 53.62730138003826, 52.395350486040115, 51.85691177845001, 52.919475361704826, 51.76342159509659, 52.617585361003876, 54.6000187844038, 51.31937362253666, 48.2906549423933, 41.94238878786564, 44.575062319636345, 50.20391307771206, 49.52911488711834, 47.58744187653065, 43.2374656945467, 38.511085510253906, 40.513365268707275, 38.21822762489319, 39.908205941319466, 39.53186273574829, 39.043801724910736, 38.43726307153702, 44.90787886083126, 47.76449717581272, 51.43570438027382, 51.98931187391281, 51.68277472257614, 49.84845735132694, 55.02808481454849, 46.223334074020386, 32.627253234386444, 44.930863827466965, 42.5664559006691, 45.44542461633682, 46.13050885498524, 49.965700060129166, 49.30447094142437, 50.6190750002861, 54.75623980164528, 54.844645857810974, 50.85767939686775, 43.72197389602661, 39.54043887555599, 38.980318531394005, 40.74403569102287, 41.699665412306786, 40.25075376033783, 40.86594834923744, 43.122563660144806, 42.863763347268105, 40.401940047740936, 38.63729573786259, 37.49284274876118, 38.60074169933796, 39.006343334913254, 39.43680703639984, 38.76212663948536, 41.29660964012146, 41.72819808125496, 41.06927923858166, 47.83092901110649, 52.75164216756821, 56.18277445435524, 52.43462137877941, 50.34610524773598, 54.769862070679665, 51.076399460434914, 44.67401280999184, 44.439952969551086, 54.466121569275856, 56.49794474244118, 56.67943820357323, 55.32078690826893, 57.23289370536804, 56.87299221754074, 55.942638739943504, 54.38888691365719, 52.31238953769207, 52.741359919309616, 51.96421042084694, 56.35483682155609, 52.0880001783371, 46.35066144168377, 26.3289961963892, 13.94015047699213, 16.55166294425726, 29.852522425353527, 24.39416091889143, 5.000098021700978, 0.3176206222269684, 0.2908629330340773, 3.007034668698907, 36.464025154709816, 58.6885841935873, 40.88691182434559, 47.4430800229311, 56.3311754912138, 62.83493310213089, 62.27239988744259, 21.323184706270695, 0.39844905375503004, 0.11740201080101542, 0.10314832252333872, 0.09495139049249701, 0.26810755720362067, 0.07571802489110269, 0.1081207935931161, 0.1703817886300385, 0.11783543988713063, 0.16598885325947776, 0.1320726895937696, 0.1118285559641663, 0.1672095971298404, 0.20734644262120128, 0.17647431639488786, 0.12738399353111163, 0.12473327951738611, 0.11773297897889279], [0.04491853265790269, 0.08073503224295564, 0.06767221639165655, 0.04650617207516916, 0.0340601885545766, 0.021746717357018497, 0.03365740274603013, 0.023949944152263924, 0.04339452127169352, 0.0884220123407431, 0.03973984843469225, 0.032265779373119585, 0.03840709963697009, 0.03254818882851396, 0.05420459609013051, 0.023695252057223115, 0.05464625559397973, 0.01757962309056893, 2.126304153352976, 26.440554410219193, 49.00228835642338, 42.46819697320461, 30.931539125740528, 27.267785221338272, 29.041186161339283, 36.39399491250515, 16.09437458217144, 0.5908172344788909, 0.5466150376014411, 6.826394973322749, 3.9418191835284233, 7.707886872813106, 8.859269265085459, 4.218547409400344, 5.902641741558909, 14.375879745930433, 34.67879734933376, 50.601215958595276, 51.1958384513855, 49.25452642142773, 44.91258680820465, 43.46047192811966, 45.17214708030224, 46.54245615005493, 49.45784971117973, 50.411419942975044, 51.83586850762367, 50.237807258963585, 48.52428160607815, 39.593848809599876, 35.095133408904076, 36.48051247000694, 34.86206531524658, 39.82813663780689, 47.2405356913805, 50.129391476511955, 47.59737454354763, 48.254306092858315, 47.44107373058796, 48.36929552257061, 49.8740603774786, 50.141619220376015, 48.813134506344795, 49.057142212986946, 48.84033724665642, 47.116061970591545, 49.21260327100754, 44.83011223375797, 46.45707093179226, 49.736948534846306, 47.81339295208454, 43.46099629998207, 39.024179577827454, 35.12455143034458, 33.91120433807373, 36.136520728468895, 34.923724606633186, 35.528283566236496, 38.70429754257202, 35.02745524048805, 38.60104188323021, 38.745985105633736, 41.05289451777935, 42.030547857284546, 45.69141581654549, 45.5486498773098, 50.65253600478172, 46.15698583424091, 27.488135397434235, 44.36114899814129, 42.75488778948784, 47.60852314531803, 49.32395629584789, 48.532846346497536, 46.39983080327511, 51.47027872502804, 47.890650406479836, 47.659729197621346, 41.361365765333176, 37.96603515744209, 36.58541724085808, 34.79281023144722, 35.33580869436264, 37.16601088643074, 38.66951420903206, 39.72406782209873, 41.379904970526695, 45.330640375614166, 46.376135274767876, 38.31373929977417, 34.20079059898853, 34.463056325912476, 33.926635310053825, 36.12267427146435, 35.49450717866421, 36.79768145084381, 34.879544377326965, 35.37009805440903, 36.07316292822361, 42.72513538599014, 49.79266494512558, 50.71432448923588, 49.33043874800205, 50.78394055366516, 48.65814842283726, 39.93879809975624, 39.06523257493973, 45.450143963098526, 50.97193546593189, 52.600315287709236, 51.814802438020706, 51.236139088869095, 49.3598909676075, 51.888324692845345, 51.87121041119099, 53.469461649656296, 55.66323973238468, 55.811541974544525, 54.75005753338337, 57.37877167761326, 44.48553532361984, 31.955422684550285, 10.218655820935965, 7.025293400511146, 14.80399327352643, 13.945748526602983, 1.1765036755241454, 0.657790481345728, 0.3396392532158643, 1.5367621066980064, 23.03850006312132, 43.345946073532104, 36.57209515571594, 23.306117802858353, 37.37146966159344, 47.84237019717693, 44.64193873107433, 13.034313283860683, 0.10506960185011849, 0.04510112325078808, 0.04208667523926124, 0.05551358874072321, 0.017041207938746084, 0.041969731319113635, 0.028129382189945318, 0.1104489182762336, 0.028665570898738224, 0.04530184451141395, 0.06659457343630493, 0.0671434955438599, 0.07114384221495129, 0.00838703594126855, 0.07951761319418438, 0.06593317142687738, 0.08984951855381951, 0.03506550179736223, 0.030388347986445297, 0.03682046211906709, 0.05328230319719296, 0.012545218869490782, 0.008408740050072083, 0.03564589096640702, 0.04087112640263513, 0.04003033245680854, 0.03877951305184979, 0.028905440449307207, 0.06489229446742684, 0.015618416218785569, 0.04931626972393133, 0.06109974543505814, 0.059630029572872445, 0.05322940291080158, 0.049814094963949174, 0.03061722447455395, 3.028475255705416, 32.54955120384693, 57.38013580441475, 45.93193531036377, 33.61547000706196, 36.76935017108917, 36.83344513177872, 37.24381931126118, 18.499180041253567, 0.6413834961131215, 0.8073690987657756, 4.826954137533903, 7.022453527897596, 7.808460351079702, 9.617623072117567, 5.49483859911561, 5.1546727772802114, 16.798666790127754, 37.1880991011858, 52.83339478075504, 53.435073494911194, 50.83573177456856, 48.22826988995075, 45.30171252787113, 47.821292728185654, 48.01163591444492, 51.13244265317917, 52.29513466358185, 53.24637562036514, 52.40292347967625, 50.08949361741543, 42.35793448984623, 37.275767996907234, 38.043668791651726, 37.03885070979595, 41.68704628944397, 49.46649804711342, 50.9153451025486, 47.58814103901386, 49.126146510243416, 47.714583054184914, 49.86080288887024, 52.018847689032555, 51.65428765118122, 50.11942461133003, 49.7269968688488, 49.14450712502003, 49.03878539800644, 50.38075938820839, 47.146513536572456, 48.08440200984478, 52.472167164087296, 49.05874952673912, 46.07768788933754, 40.09204387664795, 36.299972757697105, 36.05706699192524, 38.10884669423103, 37.2443512827158, 37.48869717121124, 39.86985459923744, 37.74127721786499, 38.807906582951546, 40.39514601230621, 43.499853014945984, 45.267381370067596, 47.9623943567276, 47.353226244449615, 52.09968835115433, 47.54570111632347, 30.528221167623997, 43.60789641737938, 42.98053488135338, 47.75681398808956, 51.092795580625534, 49.54527162015438, 49.9236249178648, 53.1792826205492, 49.78705644607544, 49.69948634505272, 44.642394706606865, 39.4784452021122, 38.186085149645805, 37.56650559604168, 36.51894360780716, 37.89644569158554, 40.58791346848011, 42.57215939462185, 43.809487000107765, 46.51566758751869, 45.71139894425869, 40.219888016581535, 35.40195934474468, 36.83314494788647, 36.8292311578989, 38.94222557544708, 37.052617371082306, 38.97449344396591, 37.629521414637566, 37.345638647675514, 37.95010261237621, 45.025448352098465, 52.099171578884125, 52.624633982777596, 51.98048114776611, 52.567618042230606, 50.51396504044533, 41.617867201566696, 41.193942949175835, 48.85315775871277, 54.10997807979584, 54.171956554055214, 53.37268844246864, 52.81104438006878, 51.321505308151245, 51.92098394036293, 51.17424800992012, 52.205915451049805, 57.220384776592255, 56.24935828149319, 56.80631339550018, 58.40438984334469, 45.461915731430054, 30.25469284504652, 15.800938177853823, 10.908371061086655, 14.443977791815996, 5.386011963710189, 2.9428392508998513, 0.17399704229319468, 0.28087879065424204, 1.7845458607189357, 27.889443263411522, 44.523130506277084, 41.069286838173866, 35.08226349949837, 42.893287762999535, 55.68462498486042, 49.84017379581928, 15.890208687633276, 0.08961685525719076, 0.025274887411796954, 0.06077305573853664, 0.04469526124012191, 0.00841187005789834, 0.03138899126497563, 0.034331699571339414, 0.029268762555147987, 0.048826630372786894, 0.0226043506336282, 0.030249946721596643, 0.10864707277505659, 0.02269738441100344, 0.045617220166604966, 0.03390873476746492, 0.02858126477804035, 0.014345856525324052, 0.0289962273745914, 0.07441331443260424, 0.1994456275133416, 0.17174269451061264, 0.11217356557608582, 0.12005406810203567, 0.11467973890830763, 0.15198957320535555, 0.14494761591777205, 0.12214840884553269, 0.14037433866178617, 0.1409052117378451, 0.14115754194790497, 0.18273057678015903, 0.14283075841376558, 0.13719772396143526, 0.16876010689884424, 0.08887986550689675, 0.11625400482444093, 4.23272967338562, 40.484878197312355, 64.86321866512299, 52.89359875023365, 41.30680829286575, 38.467676639556885, 37.931985184550285, 47.16339223086834, 22.010974399745464, 1.0630467510782182, 1.0753126116469502, 10.422388538718224, 7.292124582454562, 15.057742707431316, 17.473054602742195, 9.67717157676816, 8.538503777235746, 17.995068691670895, 39.48203980922699, 55.9207709133625, 57.150016352534294, 54.725134670734406, 49.29685615003109, 48.28100346028805, 49.28300969302654, 50.64452603459358, 52.62228570878506, 53.59986685216427, 53.91030639410019, 54.62515443563461, 53.15002799034119, 43.75627085566521, 39.57597836852074, 40.13790361583233, 38.63946162164211, 43.661503940820694, 52.047342360019684, 52.68751300871372, 49.980036690831184, 49.10421408712864, 49.04323495924473, 50.55605538189411, 52.463625222444534, 53.670189678668976, 50.645282194018364, 51.37596778571606, 50.576243698596954, 51.07203349471092, 53.07641454041004, 49.0410690754652, 52.78690427541733, 55.100014954805374, 51.18856564164162, 48.276918679475784, 42.63269394636154, 38.56612175703049, 36.842773631215096, 39.33924347162247, 39.863330349326134, 40.89081421494484, 43.01603637635708, 40.57216711342335, 41.24183177947998, 42.61266142129898, 45.89984983205795, 48.71685907244682, 49.784609377384186, 50.85352621972561, 55.118778347969055, 50.42087383568287, 32.839901223778725, 42.534203231334686, 42.31167197227478, 49.37392361462116, 54.68166880309582, 52.58029416203499, 50.94937987625599, 55.409880727529526, 53.57475399971008, 53.661476746201515, 46.39629699289799, 41.343100145459175, 40.43316297233105, 38.60846668481827, 38.94996955990791, 39.87912230193615, 42.253432497382164, 45.1389254629612, 45.448616445064545, 48.51582705974579, 48.70431214570999, 41.896681040525436, 38.12529981136322, 38.092864751815796, 38.128981813788414, 41.66951783001423, 39.80272740125656, 41.172599494457245, 39.80466149747372, 39.04106207191944, 40.03484554588795, 46.2123716622591, 54.81547102332115, 55.86186647415161, 52.65858516097069, 54.61451880633831, 51.919923797249794, 45.38241259753704, 43.7434009462595, 49.53775182366371, 55.9615883231163, 57.24224120378494, 57.03001879155636, 55.279331132769585, 52.63197518885136, 53.5494701564312, 52.841773331165314, 54.31571424007416, 59.45293217897415, 57.0175326615572, 59.57869403064251, 62.823480516672134, 47.673465460538864, 37.090691328048706, 16.904732398688793, 17.682742550969124, 24.407895281910896, 23.438227213919163, 4.2415817733854055, 0.894844620488584, 0.5736587208230048, 2.326905601657927, 30.71982018649578, 55.173161029815674, 50.02280719578266, 34.79259364306927, 51.35258764028549, 60.87192803621292, 58.88620778918266, 20.963402912020683, 0.23359069920843467, 0.1445334975142032, 0.12311086305999197, 0.14156471384922042, 0.08142957114614546, 0.1457452168688178, 0.11233930199523456, 0.12404258493916132, 0.21208754915278405, 0.14051120553631335, 0.1761585325584747, 0.24980990623589605, 0.2114518848247826, 0.11609367866185494, 0.17667561653070152, 0.21212559164268896, 0.18671772064408287, 0.10283287265338004], [0.07567101725726388, 0.02960763460578164, 0.061524769698735327, 0.01037822743455763, 0.09341443976154551, 0.015395085429190658, 0.01839286480390001, 0.03699848479300272, 0.02401897687377641, 0.019278430663689505, 0.03958576744480524, 0.09180865483358502, 0.0223195347643923, 0.050402321212459356, 0.017811952420743182, 0.01877783906820696, 0.057359024285688065, 0.030485591596516315, 2.422204250469804, 24.69524346292019, 47.49386049807072, 42.857307493686676, 23.885339722037315, 11.00158290937543, 27.28585135191679, 38.00067789852619, 15.345040541142225, 0.6064217502716929, 1.9359296187758446, 6.30155811086297, 4.454613542184234, 4.763610111549497, 6.635869396850467, 1.588043561205268, 5.201864819973707, 13.799250237643719, 35.49187771975994, 51.25756993889809, 50.166941061615944, 49.020181596279144, 44.68560218811035, 43.81071053445339, 45.031391233205795, 46.33497208356857, 50.58975577354431, 50.729782059788704, 50.9264063090086, 48.04019138216972, 45.11396840214729, 35.51454730331898, 34.06179025769234, 34.92006540298462, 34.165273904800415, 37.851927280426025, 41.11754044890404, 48.52800540626049, 49.00171458721161, 46.35528199374676, 47.011031806468964, 49.11304101347923, 47.44566768407822, 47.79724381864071, 47.25809454917908, 46.792159751057625, 49.49875071644783, 48.45940388739109, 47.94842630624771, 49.66496899724007, 51.84491202235222, 47.8876181691885, 47.733251452445984, 44.42072220146656, 39.07384291291237, 35.6075245141983, 35.74421837925911, 34.58878017961979, 36.77312716841698, 35.4290746897459, 36.27864070236683, 35.617757365107536, 35.92638820409775, 36.630699411034584, 37.62522004544735, 38.5814843326807, 43.35416883230209, 43.1162142008543, 48.39317724108696, 47.734512984752655, 30.44556800276041, 46.14580303430557, 48.4256237000227, 50.07442742586136, 49.658741131424904, 49.2849475890398, 48.98049272596836, 46.86319313943386, 45.199627205729485, 42.900963351130486, 35.58159850537777, 36.137497276067734, 35.936469063162804, 36.30935065448284, 36.68751776218414, 36.73751547932625, 39.417564868927, 42.403961420059204, 46.46408535540104, 51.56763710081577, 49.78363662958145, 45.53978115320206, 34.660550728440285, 36.13493241369724, 35.81908196210861, 33.4971671551466, 35.591489374637604, 33.759752064943314, 33.87076310813427, 33.35766904056072, 33.37144710123539, 35.90611629188061, 43.69745001196861, 51.81424006819725, 53.25695425271988, 50.3336077183485, 46.749936416745186, 43.25807958841324, 38.532170578837395, 42.90014639496803, 46.462443843483925, 49.69382084906101, 51.27237394452095, 52.284506633877754, 49.38274674117565, 50.87691776454449, 51.70129492878914, 56.450496688485146, 56.56228668987751, 55.828606858849525, 53.6381421983242, 59.68854233622551, 49.61573883891106, 36.92722409963608, 22.32048489153385, 12.188289631158113, 13.630064316093922, 13.172623012214899, 0.8198637189343572, 0.5340694170445204, 0.08760024706134573, 1.0232773725874722, 22.158345691859722, 46.74810491502285, 26.908400505781174, 17.383263520896435, 34.99471239745617, 46.88141316175461, 43.951876759529114, 13.288172911852598, 0.06008076925354544, 0.08173687965609133, 0.03794233707594685, 0.034661157478694804, 0.005730246057282784, 0.10553578191320412, 0.020540289515338372, 0.037192882955423556, 0.09459238397539593, 0.10515316767850891, 0.023161282369983383, 0.15039756253827363, 0.03961639216868207, 0.03577499868697487, 0.007407509547192603, 0.02189733993873233, 0.07666628924198449, 0.006663569583906792, 0.057495471846777946, 0.033263218429055996, 0.08189832646166906, 0.05867749045137316, 0.038437060138676316, 0.024357956535823178, 0.0652679473569151, 0.010370064737799112, 0.062310065841302276, 0.07646859594387934, 0.09107588790357113, 0.039838008597143926, 0.010271213450323557, 0.026494545891182497, 0.016936299798544496, 0.09126707256655209, 0.021022295877628494, 0.07079109942424111, 3.1088437931612134, 31.407406590878963, 52.562180534005165, 48.821862637996674, 31.43180888146162, 17.53299828618765, 31.689233668148518, 42.78353065252304, 17.810246609151363, 0.7681030745152384, 2.0870971446856856, 8.393795192241669, 5.591517286375165, 8.296070136129856, 8.61956387758255, 6.341092139482498, 8.516865838319063, 15.891977492719889, 35.448206663131714, 50.73474079370499, 52.44026407599449, 49.28221553564072, 47.872308790683746, 45.48403814435005, 47.56997041404247, 47.96086683869362, 52.427439764142036, 52.35766030848026, 52.22576558589935, 50.80839604139328, 47.300754860043526, 38.06876644492149, 35.059932097792625, 35.66270135343075, 34.6046557277441, 40.132325515151024, 43.6512216925621, 51.34920962154865, 52.21463218331337, 46.9722168892622, 48.80537532269955, 50.83217516541481, 49.83363434672356, 49.910587817430496, 50.453137904405594, 48.640346378088, 49.05911810696125, 49.7800762206316, 50.14503903687, 51.40544280409813, 53.365932404994965, 50.210289135575294, 49.934572130441666, 45.844551399350166, 40.70213533937931, 36.732351556420326, 37.61114940047264, 36.08493089675903, 38.49901355803013, 38.26926648616791, 38.33660647273064, 38.09202499687672, 38.04747238755226, 37.6290350407362, 40.68539343774319, 40.887439996004105, 45.97538597881794, 45.14537371695042, 49.845432713627815, 49.77882228791714, 32.040127739310265, 45.31363628804684, 49.660800620913506, 51.964062228798866, 51.60648241639137, 51.25184744596481, 51.121814623475075, 48.10425214469433, 48.40274512767792, 46.08651101589203, 38.3047603815794, 37.82712981104851, 37.3387648165226, 38.03270258009434, 38.107106387615204, 37.85630464553833, 41.87468782067299, 44.11222815513611, 48.39954189956188, 52.02881835401058, 52.78904356062412, 46.57504700124264, 37.17232994735241, 38.37196737527847, 36.57859280705452, 35.94003327190876, 36.83012031018734, 36.47947892546654, 37.75168105959892, 35.31067304313183, 34.49415385723114, 38.25341373682022, 47.619812339544296, 52.58136570453644, 54.544249176979065, 50.55332712829113, 49.26684536039829, 45.61231926083565, 40.66592328250408, 44.64819319546223, 48.60187724232674, 51.464795619249344, 54.95105154812336, 52.55622625350952, 50.03308564424515, 51.208457574248314, 53.882252499461174, 56.811940893530846, 58.777852803468704, 57.714624255895615, 57.98476696014404, 59.33597445487976, 53.29622134566307, 35.42237564921379, 22.226909212768078, 7.925436599180102, 10.880121476948261, 13.20998640730977, 1.1303918436169624, 0.3263452212559059, 0.06644487482844852, 1.399946054443717, 22.682576961815357, 50.65307937562466, 32.444885820150375, 22.345928326249123, 40.014828220009804, 54.45786841213703, 51.314798668026924, 16.392521783709526, 0.07509410876082256, 0.07962031158967875, 0.02280775846884353, 0.02411861947621219, 0.031022412986203562, 0.0013194793132242921, 0.019657139346236363, 0.04030594755022321, 0.06095665194152389, 0.04524525204033125, 0.02804228373861406, 0.014672748457087437, 0.012845373075833777, 0.030585464264731854, 0.015600415426888503, 0.030067825537116732, 0.06682539620669559, 0.05393995365011506, 0.16336154658347368, 0.13846749410731718, 0.1856745281838812, 0.16764394647907466, 0.19744383258512244, 0.13499170483555645, 0.1392337615834549, 0.11956395377637818, 0.1475106822908856, 0.06491033607744612, 0.12373918754747137, 0.09247614245396107, 0.07742031870293431, 0.08725022053113207, 0.087825488881208, 0.26796824124176055, 0.13654905720613897, 0.18897438392741606, 4.316882807761431, 39.310372620821, 59.89954501390457, 56.224864795804024, 36.65847972035408, 20.36387298256159, 38.35966743528843, 48.565080016851425, 21.182166673243046, 0.8554200734943151, 2.6618267549201846, 9.828373063355684, 9.245686680078506, 14.919219240546227, 16.921641491353512, 7.522209836170077, 10.511778742074966, 15.52401663735509, 37.14029386639595, 53.390501886606216, 55.88615097105503, 53.160420432686806, 49.18537773191929, 47.25328780710697, 49.39019054174423, 50.56411474943161, 53.651031106710434, 54.43174101412296, 54.19909469783306, 52.17703320086002, 49.00763086974621, 38.88250418007374, 36.60810202360153, 37.911105304956436, 37.07363784313202, 41.396171897649765, 44.68076504766941, 52.50456042587757, 51.6364362090826, 47.15065151453018, 48.830465376377106, 53.41754503548145, 52.288279831409454, 51.918878853321075, 51.91522724926472, 50.14999017119408, 50.547407045960426, 51.3622011244297, 50.98135516047478, 53.33319716155529, 55.53478382527828, 52.45168246328831, 50.88471494615078, 49.27281863987446, 42.429644241929054, 38.8442250341177, 39.61501367390156, 38.07893089950085, 40.38748562335968, 38.792677000164986, 40.023867934942245, 39.16655033826828, 39.83829729259014, 39.817394614219666, 42.71706461906433, 42.48170144855976, 49.61459890007973, 48.295176699757576, 53.06888334453106, 52.55161330103874, 35.5572684109211, 47.03549109399319, 51.72230780124664, 53.891558200120926, 53.65153647959232, 53.78129191696644, 53.341716304421425, 49.845303520560265, 50.255548506975174, 49.27862472832203, 39.92299094796181, 39.96738776564598, 39.49490211904049, 39.59518253803253, 40.03674924373627, 39.877951964735985, 44.022005796432495, 46.879258677363396, 51.25641480088234, 54.65975917875767, 55.14555171132088, 50.190070420503616, 40.35436660051346, 40.47151431441307, 39.08187188208103, 36.80267058312893, 39.78229969739914, 37.61865019798279, 38.864690735936165, 36.8963735550642, 35.42429454624653, 40.85562810301781, 48.96870955824852, 55.87450459599495, 56.95674732327461, 52.56515957415104, 49.56688866019249, 48.94770048558712, 43.24693478643894, 46.86470165848732, 51.84217616915703, 54.62979018688202, 57.3942406475544, 55.24415262043476, 51.38143949210644, 51.61939412355423, 55.15008106827736, 58.76703858375549, 60.33232659101486, 61.7295154184103, 59.067625254392624, 62.79791168868542, 52.01345957815647, 41.68426863849163, 27.979101352393627, 20.52072286605835, 23.590540140867233, 22.535175271332264, 1.6087775048799813, 0.6242400628980249, 0.1562880034907721, 1.9313380401581526, 28.569910749793053, 60.9722388535738, 37.215605825185776, 27.84823067486286, 47.87322074174881, 60.1124931871891, 59.81794059276581, 20.239906534552574, 0.6514286727178842, 0.2016998565522954, 0.2506772393826395, 0.125840118562337, 0.1616246983758174, 0.21912419266300276, 0.1541939892922528, 0.12773137801559642, 0.21430988068459556, 0.24990959151182324, 0.10978734557284042, 0.21549544675508514, 0.11646645943983458, 0.08298914995975792, 0.12298907662625425, 0.1620904405717738, 0.21364815213019028, 0.17361016070935875], [0.06837496344815008, 0.02121570327290101, 0.052265442136558704, 0.04604782167007215, 0.009130775524681667, 0.03051158902962925, 0.020163152330496814, 0.05520479964616243, 0.028697520356217865, 0.0815817188413348, 0.09394869703100994, 0.0858942350896541, 0.16500771918799728, 0.04356328565336298, 0.04569978038489353, 0.034333595758653246, 0.07141404334106483, 0.015675517061026767, 2.948675500229001, 29.2691720277071, 46.258079409599304, 36.8564110994339, 42.03088603913784, 37.251673489809036, 27.18920163810253, 35.86822472512722, 17.502237036824226, 0.5865090969018638, 3.242556005716324, 23.96432228386402, 17.177356369793415, 5.910633187741041, 5.369355557486415, 4.169960841536522, 2.98663807567209, 11.035319399088621, 34.04562972486019, 52.62458078563213, 50.181357488036156, 48.484326750040054, 44.58868458867073, 44.64074559509754, 46.329108998179436, 49.92140203714371, 51.52621552348137, 51.88710495829582, 49.461847096681595, 48.09420548379421, 38.96056339144707, 34.518210366368294, 33.52479167282581, 34.86263528466225, 34.496619924902916, 37.0797099173069, 40.20848862826824, 45.60797609388828, 49.88278470933437, 49.111213311553, 48.31623896956444, 45.888826623559, 42.541935816407204, 43.77044789493084, 43.134164437651634, 45.49568831920624, 46.60019405186176, 49.38725709915161, 48.190104737877846, 50.29962994158268, 46.29435606300831, 47.422994300723076, 47.66961246728897, 39.91033762693405, 36.88169874250889, 34.7900477796793, 35.08526153862476, 35.43057940900326, 34.83147695660591, 36.31335183978081, 34.7507730871439, 35.81232212483883, 35.96337541937828, 34.633420184254646, 34.68153320252895, 37.12208904325962, 39.549695178866386, 41.39097757637501, 46.93309038877487, 48.06655816733837, 32.593518644571304, 49.53839398920536, 49.73741210997105, 46.88828319311142, 45.95281518995762, 44.76385518908501, 45.03978878259659, 44.481017366051674, 40.36672733724117, 38.12963917851448, 37.067512571811676, 38.23806256055832, 35.21826960146427, 34.77008365094662, 35.6566596776247, 36.44671328365803, 38.146476075053215, 42.60660834610462, 47.658038288354874, 51.2606667727232, 49.03965175151825, 46.3581470400095, 37.115078419446945, 35.94773545861244, 36.21371738612652, 38.96967150270939, 41.801530346274376, 42.17282362282276, 40.19253708422184, 36.50710344314575, 33.64676512777805, 34.3636878579855, 36.83594919741154, 43.52442629635334, 49.233156368136406, 48.55092577636242, 47.1813652664423, 42.29201942682266, 40.638021379709244, 39.47474420070648, 43.03036920726299, 46.52632601559162, 49.92391750216484, 51.608431711792946, 50.9457016736269, 48.41269679367542, 52.75541916489601, 53.37704300880432, 55.57311236858368, 53.5221154242754, 54.37563702464104, 55.577858313918114, 54.339421167969704, 36.49340517818928, 25.313658379018307, 10.205056350678205, 6.971185253933072, 4.627224029973149, 2.8122055856510997, 0.16696547507308424, 0.05704686584067531, 1.129853103775531, 17.877765186131, 38.37637133896351, 37.26146936416626, 35.32460309565067, 32.98824146389961, 52.520823553204536, 42.76429608464241, 15.76988909393549, 0.17759858106728643, 0.039363668620353565, 0.03318103670608252, 0.07742017027339898, 0.06864234441309236, 0.1031046397110913, 0.027885692434210796, 0.05563926031754818, 0.035819920885842294, 0.023469327461498324, 0.0038729836933271145, 0.010600894929666538, 0.01414238931829459, 0.012559263086586725, 0.09452239944948815, 0.029627754229295533, 0.05435017206764314, 0.019161787313350942, 0.022589344407606404, 0.05881319957552478, 0.05459417538077105, 0.07186712449765764, 0.05169024057977367, 0.03760826301004272, 0.04403710612677969, 0.07663564596441574, 0.035005395257030614, 0.032556678997934796, 0.08625346425105818, 0.044254759486648254, 0.08975200034910813, 0.0617202439752873, 0.06179891533975024, 0.07857908582082018, 0.043715733918361366, 0.05493422744621057, 4.04263679869473, 34.219443798065186, 52.94778384268284, 43.81539188325405, 43.608869165182114, 35.123111307621, 30.033455416560173, 42.17603825032711, 19.88300498574972, 0.8303002745378762, 2.959053455851972, 22.427300959825516, 11.565237063914537, 10.705249160528183, 9.217671733349562, 8.684088215231895, 9.108867421746254, 13.58055867254734, 34.02220778167248, 54.66252163052559, 52.655693516135216, 49.52988624572754, 45.81552855670452, 46.65567487478256, 48.16891327500343, 51.66058771312237, 54.15587581694126, 52.605141028761864, 51.806758269667625, 50.430825501680374, 41.60961024463177, 35.257331505417824, 34.27196457982063, 35.209492072463036, 35.26130609214306, 38.203347623348236, 43.653364777565, 46.93496748805046, 51.37740030884743, 49.62914451956749, 50.354498997330666, 49.41844962537289, 45.69668993353844, 45.30646227300167, 45.40095180273056, 48.008748069405556, 50.03182031214237, 50.61832644045353, 49.48317915201187, 50.14120124280453, 48.56292173266411, 49.44455802440643, 49.444406032562256, 42.74691961705685, 39.20851148664951, 35.648087337613106, 36.919863894581795, 36.41177415847778, 37.32107296586037, 37.291385158896446, 36.48041367530823, 37.48371563851833, 37.36295431852341, 36.07153281569481, 37.194611951708794, 38.10018315911293, 40.815528854727745, 45.3289532661438, 50.01174598932266, 49.93424914777279, 35.05952171981335, 49.73959319293499, 51.79424174129963, 49.4735162705183, 48.411910235881805, 46.73548199236393, 46.239464208483696, 46.408498138189316, 43.649637177586555, 38.304593190550804, 39.38634194433689, 40.157305374741554, 37.323782220482826, 37.29407921433449, 37.25923128426075, 38.78581836819649, 39.518882632255554, 45.632150396704674, 49.920987859368324, 52.17353358864784, 51.440142542123795, 48.728805631399155, 38.40393126010895, 37.03032776713371, 38.14444698393345, 39.67950001358986, 43.55341114103794, 42.814764976501465, 40.74065387248993, 37.022731974720955, 35.77586308121681, 35.86655281484127, 38.168085515499115, 47.076684683561325, 52.43825398385525, 51.8220866471529, 49.503804445266724, 44.70757260918617, 42.358892038464546, 41.1238519102335, 44.787649512290955, 48.50157022476196, 52.189450934529305, 53.38332027196884, 51.86287745833397, 49.05632525682449, 52.69064024090767, 54.9185024946928, 57.97294579446316, 54.26554553210735, 55.26551887392998, 58.39100316166878, 56.25720106065273, 37.172755524516106, 23.95527306944132, 9.302490781992674, 3.593664290383458, 6.8917210679501295, 1.343357115983963, 0.3242565208347514, 0.019394300325075164, 1.2619197671301663, 21.620708741247654, 44.005138501524925, 35.91544859111309, 31.274081245064735, 38.63811269402504, 58.11343565583229, 50.98247990012169, 18.710154220461845, 0.23000542831141502, 0.008836754241201561, 0.03604067271226086, 0.048596104461466894, 0.022654356544080656, 0.04479580369661562, 0.008964687513071112, 0.03607261103752535, 0.12132438001572154, 0.045377810747595504, 0.08410402646404691, 0.006083055641283863, 0.04282831825548783, 0.017263703812204767, 0.031833808607188985, 0.013337147956917761, 0.025581854533811565, 0.012630576984520303, 0.08632845827378333, 0.15151730010984465, 0.15660464821849018, 0.12536570808151737, 0.11263086955295876, 0.15973882691469043, 0.1790728425839916, 0.24761176871834323, 0.11259609993430786, 0.16428890463430434, 0.30925335246138275, 0.1751074436469935, 0.20005890866741538, 0.14714483317220584, 0.1379279379034415, 0.24418016691925004, 0.29767380037810653, 0.1393681496847421, 5.400546658784151, 41.31284236907959, 60.19650287926197, 51.06763333082199, 52.619120478630066, 46.28709465265274, 37.40233160555363, 47.915261685848236, 23.968885838985443, 0.9816998254973441, 3.716798108071089, 28.054635599255562, 21.3478871807456, 14.372184444218874, 15.181034691631794, 11.632975079119205, 5.850869519636035, 14.415651261806488, 37.39849001169205, 57.502268850803375, 55.43016403913498, 53.54639612138271, 49.01349015533924, 48.49753864109516, 51.014572978019714, 53.07450704276562, 55.5636128783226, 55.49199812114239, 54.67739023268223, 52.567420452833176, 43.601520359516144, 38.19582782685757, 36.6251365095377, 37.14930318295956, 37.78303697705269, 40.521082654595375, 45.56216575205326, 49.82889600098133, 52.79842525720596, 50.455410182476044, 52.34440661966801, 51.387207582592964, 48.463986441493034, 47.29698546230793, 46.71111769974232, 49.31279629468918, 52.61198826134205, 51.55045062303543, 50.71016751229763, 51.15235358476639, 49.21053998172283, 52.42927126586437, 51.363413259387016, 43.53172190487385, 39.977989196777344, 37.41675943136215, 37.652065604925156, 38.79007413983345, 38.495057970285416, 40.639883279800415, 36.86937600374222, 39.20111708343029, 38.8776670396328, 38.65854039788246, 38.15291292965412, 40.23607514798641, 43.07101562619209, 47.52106323838234, 52.11567409336567, 51.86636187136173, 38.14679525792599, 50.439941212534904, 54.26743023097515, 50.81050492823124, 49.96403194963932, 48.669243827462196, 48.55619989335537, 48.550458401441574, 45.85720852017403, 40.12689560651779, 42.86244481801987, 41.928983107209206, 39.07272957265377, 39.014987871050835, 39.021873101592064, 41.48420937359333, 41.389750242233276, 47.371130883693695, 52.58204206824303, 53.234911635518074, 52.183998227119446, 50.82357242703438, 42.5346440076828, 40.19266627728939, 39.99679438769817, 43.06709423661232, 46.07120543718338, 46.45138643682003, 42.704555690288544, 38.81651312112808, 36.329265385866165, 37.8389547765255, 41.0055186599493, 47.82777138054371, 54.91088390350342, 52.514227107167244, 52.12509758770466, 46.91925533115864, 45.98061449825764, 43.654979690909386, 47.817812114953995, 50.25866433978081, 54.144320636987686, 54.814574271440506, 53.840158358216286, 50.927705839276314, 55.883008539676666, 55.02822160720825, 60.642348155379295, 57.1488194167614, 58.140786588191986, 58.64017479121685, 58.189929351210594, 40.04572816193104, 27.83896677196026, 17.53709066659212, 12.931839432567358, 8.055485095828772, 4.950080830603838, 0.8647575974464417, 0.2612335776211694, 1.7510516080074012, 25.643492080271244, 51.475248858332634, 47.959662303328514, 45.07423773407936, 46.67442686855793, 65.30549213290215, 59.18239429593086, 24.013275057077408, 0.5515467573422939, 0.1671519470983185, 0.15702961682109162, 0.11519656312884763, 0.15314405813114718, 0.21927695634076372, 0.18951652280520648, 0.21293539350153878, 0.23848900746088475, 0.11745085153961554, 0.13465387921314687, 0.10187919062445872, 0.1885843407944776, 0.08313825484947301, 0.16780897043645382, 0.13538565166527405, 0.15750140009913594, 0.10010691228671931], [0.021045447174401488, 0.025033553974935785, 0.0254430135464645, 0.029288683654158376, 0.07251247385283932, 0.03657737535831984, 0.06396531491191126, 0.01724059704429237, 0.04514904743700754, 0.035178913094569, 0.023675399606872816, 0.05913427492487244, 0.024228301481343806, 0.027993365074507892, 0.04731742483272683, 0.07697648470639251, 0.00610850805969676, 0.06714995965012349, 3.615444959141314, 26.939351744949818, 48.65537837147713, 39.21627826988697, 39.467680379748344, 26.981848664581776, 26.821491569280624, 41.523719653487206, 19.40573539584875, 0.9827099775429815, 1.1298730527050793, 24.201646149158478, 37.63013318181038, 9.22933615744114, 3.960763067007065, 6.166769368574023, 9.376309420913458, 15.434795524924994, 36.26248016953468, 53.99292916059494, 48.91473725438118, 49.15150634944439, 47.41138592362404, 49.555591866374016, 50.14068067073822, 52.260746508836746, 50.41986308991909, 49.59638647735119, 47.5615918636322, 40.032759457826614, 34.175187572836876, 34.06188905239105, 37.52001889050007, 40.8810905367136, 39.88009124994278, 42.43427999317646, 43.601976335048676, 47.533321380615234, 48.42969328165054, 47.853287011384964, 48.57769533991814, 43.974352553486824, 43.65251362323761, 39.939273074269295, 39.44651551544666, 41.42025500535965, 43.64760048687458, 46.95485562086105, 49.66282971203327, 49.675806015729904, 48.39460976421833, 48.40240314602852, 43.30777332186699, 38.828581273555756, 36.44061081111431, 34.477092772722244, 35.12811563909054, 35.66093064844608, 35.298141315579414, 36.259634122252464, 36.473277658224106, 35.64236864447594, 34.52512979507446, 34.103044643998146, 34.55072142183781, 35.000324696302414, 38.087290450930595, 44.6016912907362, 45.55622287094593, 49.56504575908184, 36.76138959825039, 47.88433514535427, 48.477133736014366, 44.79961887001991, 41.82914346456528, 40.28687082231045, 36.88899055123329, 37.212303802371025, 35.66991336643696, 37.37357094883919, 38.2329898327589, 37.27447226643562, 36.08564145863056, 36.449506133794785, 34.91715855896473, 35.28709530830383, 36.34273946285248, 43.14289636909962, 48.86425696313381, 49.445853754878044, 48.802878856658936, 48.53988356888294, 42.61320099234581, 39.695763140916824, 44.25279401242733, 47.43147164583206, 50.704323425889015, 48.79295378923416, 49.139384999871254, 46.604218035936356, 41.950695142149925, 36.664768382906914, 34.04219850897789, 35.576457381248474, 41.523161083459854, 43.51268492639065, 44.002729430794716, 41.00151747465134, 39.7842375934124, 39.779028072953224, 41.48156851530075, 45.76461508870125, 51.40755549073219, 50.92968173325062, 48.50942440330982, 49.25829201936722, 53.96722353994846, 54.75155085325241, 52.99278862774372, 48.329245671629906, 53.95128719508648, 53.289776891469955, 58.541429489851, 35.002384185791016, 23.595405779778957, 6.027977541089058, 0.34253867575898767, 3.55722994543612, 1.2298478255979717, 0.35232926602475345, 0.19987356470664963, 1.0609755059704185, 16.4769209548831, 45.67707158625126, 36.19602553546429, 24.647527523338795, 35.093176513910294, 52.98073187470436, 46.10331371426582, 14.476711135357618, 0.17654952564043924, 0.043438445281935856, 0.01750259929394815, 0.014661799923487706, 0.07378937603789382, 0.024170232136384584, 0.04385503503726795, 0.05269957626296673, 0.0640258147905115, 0.033886477758642286, 0.08814088680082932, 0.11633613830781542, 0.027502221018949058, 0.03910626212018542, 0.08352112883585505, 0.03392088372493163, 0.10161935730138794, 0.0024032903274928685, 0.012730997914331965, 0.03019049883732805, 0.04306091846956406, 0.03740555650438182, 0.03409246826777235, 0.06289780969382264, 0.0531841393240029, 0.10209131869487464, 0.03307910643343348, 0.0812284491257742, 0.04886668408289552, 0.04844687340664677, 0.0523417312069796, 0.036761071751243435, 0.00017507333268440561, 0.06680172169581056, 0.03428926727792714, 0.05885409933398478, 4.848182173445821, 33.115576431155205, 56.161932572722435, 43.37542489171028, 49.40752521157265, 36.14082209765911, 30.46711664646864, 45.77484793961048, 21.13276742398739, 1.0077909473329782, 1.5297798626124859, 27.692570127546787, 35.071749463677406, 7.426628340035677, 9.878172241151333, 7.634175103157759, 11.429501697421074, 14.081716630607843, 38.55127975344658, 54.5147817581892, 51.52901977300644, 50.19641228020191, 50.393215119838715, 50.76679967343807, 51.33785203099251, 55.06081245839596, 52.438432574272156, 53.324488028883934, 49.1356498003006, 43.868201449513435, 36.67606517672539, 35.88009528815746, 37.61192835867405, 41.14688627421856, 41.91782310605049, 43.23072865605354, 44.588790982961655, 50.08643478155136, 50.19063279032707, 47.85570748150349, 51.39248929917812, 46.12666346132755, 45.30525013804436, 43.09589669108391, 43.830230087041855, 43.483183309435844, 47.22920089960098, 48.99533472955227, 51.515150517225266, 49.960927516222, 49.95418667793274, 48.57690878212452, 45.77059216797352, 40.2654779702425, 37.13400520384312, 36.15385539829731, 36.794915199279785, 37.092036455869675, 37.042540311813354, 38.032459393143654, 36.88655108213425, 37.9610688239336, 35.70565424859524, 36.076837331056595, 38.02892938256264, 36.9644621014595, 39.948715567588806, 44.9577359855175, 47.88338139653206, 50.331491231918335, 37.58600614964962, 50.33063247799873, 49.61137667298317, 47.56419472396374, 44.974451288580894, 43.21343198418617, 41.03650979697704, 40.39008088409901, 37.821297124028206, 38.67847792804241, 39.71454553306103, 38.52124996483326, 37.77799844741821, 38.08361604809761, 37.15528026223183, 37.28679500520229, 38.0161202698946, 44.31773252785206, 49.6603674441576, 51.18684433400631, 51.30497619509697, 51.81227557361126, 44.64780941605568, 41.87259793281555, 45.7841232419014, 50.01732029020786, 51.85535006225109, 51.85807451605797, 52.22437106072903, 48.20799797773361, 43.23972277343273, 37.86115698516369, 36.164209842681885, 38.08906115591526, 44.07745622098446, 46.52949884533882, 46.138712614774704, 42.92716674506664, 41.632469817996025, 40.31395196914673, 43.764235228300095, 47.56997041404247, 53.32192696630955, 53.318271562457085, 52.65429139137268, 50.94890110194683, 55.05736984312534, 55.56278832256794, 56.72907114028931, 52.398257330060005, 56.04265697300434, 55.575886219739914, 60.37593685090542, 35.66935479640961, 26.65692239999771, 9.457430317997932, 1.9531719060614705, 4.482830353081226, 1.5463469736278057, 0.14591225946787745, 0.10015515930717811, 1.1636037239804864, 19.02352150529623, 49.13721151649952, 44.02604877948761, 29.318022206425667, 39.06712867319584, 59.361463487148285, 52.98422008752823, 17.41466123610735, 0.3176341886864975, 0.046981031555333175, 0.07920559946796857, 0.04341013605881017, 0.026055287235067226, 0.029077850631438196, 0.03399435263418127, 0.024397611341555603, 0.04678468525526114, 0.024097672358038835, 0.12352307414403185, 0.09649470885051414, 0.021996427785779815, 0.03588804633182008, 0.0029405660507109133, 0.050629392426344566, 0.033195545693160966, 0.021721630910178646, 0.14692337630549446, 0.14119776635197923, 0.17843866255134344, 0.10737056392827071, 0.096952428430086, 0.16643357783323154, 0.18574791174614802, 0.1771545986412093, 0.13989902276080102, 0.1112349565664772, 0.0986446141905617, 0.21336763515137136, 0.10787031875224784, 0.11100543997599743, 0.1386294752592221, 0.21538310043979436, 0.09422453847946599, 0.1998589889262803, 6.261576181277633, 38.81570756435394, 62.79350772500038, 51.5362773835659, 50.83704270422459, 36.077677085995674, 34.48555491864681, 52.061690390110016, 25.83071943372488, 1.287732613272965, 1.4089522836729884, 28.80963608622551, 45.25240257382393, 16.5011465549469, 18.26949566602707, 14.461498651653528, 14.775321912020445, 17.919008173048496, 38.43796223402023, 57.60078236460686, 53.801818415522575, 53.70968095958233, 52.75564335286617, 54.53300178050995, 54.26244109869003, 55.93942031264305, 54.074628576636314, 55.82564301788807, 52.39084392786026, 46.20735593140125, 37.82776057720184, 37.80614733695984, 40.87813429534435, 46.134631633758545, 43.97551529109478, 46.94950930774212, 47.74047486484051, 51.53340093791485, 49.69665929675102, 48.90584193170071, 52.9136198759079, 48.43247853219509, 47.09656901657581, 45.83932667970657, 45.04744917154312, 45.706782191991806, 49.331324100494385, 51.58722124993801, 53.93582582473755, 51.013406440615654, 51.41631782054901, 52.20640182495117, 47.22847133874893, 42.590292021632195, 40.014813020825386, 37.22082294523716, 38.456159457564354, 39.27891790866852, 38.795025274157524, 41.058917194604874, 40.27455188333988, 40.38890674710274, 37.939333990216255, 37.57019139826298, 39.66992072761059, 39.15740802884102, 43.21507349610329, 49.30168569087982, 50.52321374416351, 54.43517982959747, 42.29090988636017, 52.27024979889393, 52.73914463818073, 49.640160128474236, 45.917328894138336, 44.94831249117851, 41.83969169855118, 41.93405583500862, 39.04269978404045, 41.88249260187149, 41.309468150138855, 41.646669656038284, 39.26011651754379, 39.54939119517803, 39.969800636172295, 38.65518517792225, 38.707447573542595, 46.94549672305584, 53.34565669298172, 53.54442022740841, 53.82403962314129, 54.50235642492771, 46.41825221478939, 44.291095957159996, 48.040510565042496, 53.44834238290787, 54.388541132211685, 54.29735742509365, 53.53114753961563, 52.92773611843586, 45.53855001926422, 40.67114420235157, 38.195174261927605, 39.09055821597576, 45.24156555533409, 47.60668784379959, 48.015709295868874, 44.25037734210491, 44.178922176361084, 42.240501791238785, 45.66374570131302, 50.73436461389065, 56.525253877043724, 54.624880850315094, 54.165208116173744, 53.67388688027859, 56.58986561000347, 57.719263806939125, 57.192190289497375, 54.30510900914669, 59.42598782479763, 57.95647367835045, 62.58331440389156, 36.58272698521614, 27.17139769345522, 10.22134892642498, 6.215263791382313, 13.14628567546606, 3.866084972396493, 1.0476675513200462, 0.3512751788366586, 1.8100499734282494, 22.632632441818714, 57.71769069135189, 49.13709372282028, 35.4448476433754, 48.40270712971687, 66.76613375544548, 62.82560460269451, 23.22107646614313, 0.6104245386086404, 0.1990355463931337, 0.17642279650317505, 0.10884841743973084, 0.12038796034175903, 0.2303076456882991, 0.1112830254714936, 0.0853810399712529, 0.16458514030091465, 0.14791818073717877, 0.1791060165851377, 0.19122554047498852, 0.17922231112606823, 0.16480551363201812, 0.11316026575514115, 0.14984107052441686, 0.12091882599634118, 0.12116570142097771], [0.06331333817797713, 0.0534840708860429, 0.05035434507590253, 0.004627637717931066, 0.02280073404108407, 0.024296916744788177, 0.007679459822611534, 0.05498577702383045, 0.07694600470131263, 0.09216121950885281, 0.034178453497588634, 0.039866525621619076, 0.08585685311118141, 0.048430612951051444, 0.020744927460327744, 0.05445763505122159, 0.04238576817442663, 0.01525893379948684, 2.884448734112084, 22.749683260917664, 46.407665982842445, 38.00261579453945, 26.685054190456867, 14.38102561980486, 22.71088544279337, 34.911683052778244, 20.453517772257328, 0.9120947448536754, 0.12504995393101126, 11.661900077015162, 38.642816841602325, 29.080690741539, 7.744342591613531, 6.048614708706737, 13.35077265277505, 11.365930158644915, 39.41271632909775, 54.275846779346466, 51.3491640239954, 48.21294531226158, 50.49876965582371, 50.958499386906624, 50.67766025662422, 51.40575438737869, 49.97591771185398, 47.97089450061321, 41.07810236513615, 35.08705124258995, 33.458542227745056, 38.97287093102932, 44.25436332821846, 48.92785795032978, 47.797445207834244, 48.66252198815346, 50.942088067531586, 50.33418148756027, 48.149731904268265, 47.85533890128136, 45.67994423210621, 42.91420944035053, 41.23651586472988, 35.202082470059395, 34.403946697711945, 37.70949952304363, 38.89754757285118, 43.71255420148373, 46.03182055056095, 48.801085352897644, 47.6531707495451, 43.74986059963703, 37.95320324599743, 34.93092902004719, 34.804707393050194, 35.4437381029129, 33.61258216202259, 36.191127598285675, 35.75425364077091, 35.600107312202454, 36.550143733620644, 34.480368196964264, 36.64714492857456, 36.623787581920624, 38.56057405471802, 38.02074082195759, 39.9660350382328, 41.745156571269035, 46.102698147296906, 49.2904344946146, 36.086697801947594, 48.48620384931564, 46.4787145704031, 42.41542920470238, 36.034348011016846, 35.42065054178238, 35.37831321358681, 35.27273967862129, 34.277668073773384, 34.534674882888794, 36.26513622701168, 36.27751976251602, 36.81338220834732, 35.94412565231323, 36.09102576971054, 37.41819575428963, 36.287794411182404, 39.94034081697464, 47.665482088923454, 50.08765071630478, 48.11264589428902, 48.860263377428055, 48.13406154513359, 48.39135333895683, 49.409307315945625, 48.9399679005146, 48.429051116108894, 49.079196229577065, 49.76872242987156, 49.072808772325516, 47.44904190301895, 43.12792897224426, 39.02436576783657, 36.0313081741333, 34.222194850444794, 37.0416359603405, 39.27752338349819, 38.84992852807045, 39.41956356167793, 37.999146580696106, 41.9282079488039, 45.89239843189716, 50.63149653375149, 51.53947301208973, 50.28162270784378, 48.59485521912575, 49.9472900480032, 53.73657211661339, 56.394096314907074, 51.885281056165695, 52.08947829902172, 54.70830537378788, 55.5939694494009, 39.46008458733559, 23.41195922344923, 13.164460100233555, 1.4604956866241992, 2.467913660220802, 0.5554633378051221, 0.23091852228390053, 0.05893245899642352, 0.8850931562483311, 19.45455327630043, 38.5627893358469, 26.768011339008808, 25.468978844583035, 42.160151302814484, 50.21738715469837, 49.888085424900055, 12.974612787365913, 0.38545300893019885, 0.050341706300969236, 0.06683537809294648, 0.04219527370878495, 0.043993423314532265, 0.032733851912780665, 0.0286050673093996, 0.00454139088105876, 0.017732511078065727, 0.07464717258699238, 0.022450802134699188, 0.02951215359644266, 0.04098345787497237, 0.042375663833809085, 0.0435271838796325, 0.07861654943553731, 0.005473753326441511, 0.015162243089434924, 0.008062400138442172, 0.08439039898803458, 0.03997735053417273, 0.06410902438801713, 0.03307931052404456, 0.012286155524634523, 0.006987567603573552, 0.06645349116297439, 0.049467263379483484, 0.006066064170227037, 0.02125577739207074, 0.032235737235168926, 0.0644636299693957, 0.06736291892593727, 0.03280870121670887, 0.04415946772496682, 0.028138994857727084, 0.03619205228460487, 4.171814667060971, 29.728120900690556, 54.396155923604965, 44.65817146003246, 31.446757279336452, 17.469454295933247, 28.141778223216534, 38.901024386286736, 24.60419274866581, 0.9008450922556221, 0.24775650235824287, 13.460312224924564, 45.34987114369869, 15.794072896242142, 7.79861650429666, 13.360292091965675, 10.111632663756609, 18.174221478402615, 38.77565011382103, 56.47022522985935, 52.056955844163895, 52.23492689430714, 51.8844261020422, 53.97663563489914, 51.062560603022575, 53.59641283750534, 52.037086710333824, 51.84992395341396, 44.54505532979965, 36.84342719614506, 34.86533313989639, 39.69593793153763, 45.551587119698524, 51.08342528343201, 48.63546743988991, 50.89368626475334, 52.004484459757805, 52.00209058821201, 47.89555214345455, 48.89328360557556, 48.69945600628853, 45.68600870668888, 42.96475052833557, 38.043737187981606, 36.07013829052448, 39.90580826997757, 42.36269183456898, 46.11591763794422, 48.952036052942276, 50.49364373087883, 50.56493930518627, 45.96916191279888, 40.68092867732048, 37.004002779722214, 36.349047124385834, 36.335945427417755, 35.706311613321304, 38.207204416394234, 37.64192774891853, 37.43182562291622, 38.44686895608902, 36.738739013671875, 38.25084127485752, 38.61608527600765, 38.456801623106, 39.969234466552734, 42.263414561748505, 44.26146134734154, 47.46823847293854, 50.71051329374313, 39.13768708705902, 50.79305246472359, 49.516678154468536, 45.12327030301094, 38.66722673177719, 37.60182090103626, 37.31134548783302, 35.96773378551006, 36.64355032145977, 37.92275168001652, 37.997740656137466, 37.772108763456345, 37.43267297744751, 37.5289636105299, 37.34766773879528, 39.07670795917511, 37.36000947654247, 41.343837305903435, 50.14704532921314, 50.372738018631935, 49.54087905585766, 50.86566276848316, 50.89156977832317, 51.841872185468674, 52.37166255712509, 52.500430047512054, 50.3310314565897, 50.28934009373188, 51.69591061770916, 51.436266750097275, 49.706926345825195, 45.341572389006615, 39.696287512779236, 37.634537145495415, 36.12905412912369, 38.95927146077156, 43.10698829591274, 41.818534433841705, 41.54793955385685, 40.227339416742325, 43.543930649757385, 47.27392449975014, 52.39086672663689, 53.03115516901016, 53.22326526045799, 51.05349808931351, 53.16509038209915, 55.692577958106995, 57.53119669854641, 52.6943526417017, 55.033404529094696, 56.23706214129925, 58.5879959911108, 38.77807438373566, 24.294150285422802, 10.658351127058268, 3.615912809036672, 4.759949957951903, 0.854667832609266, 0.14964167028665543, 0.0627257872838527, 1.0636193328537047, 22.042731195688248, 44.77233253419399, 36.15094855427742, 33.73818442225456, 46.49249643087387, 56.19224734604359, 55.84235832095146, 16.85847368091345, 0.4517641116399318, 0.035881110961781815, 0.018071125232381746, 0.02158180101105245, 0.022935443121241406, 0.04069750095368363, 0.047298529752879404, 0.05399938112532254, 0.032997841262840666, 0.09447718781302683, 0.025701421945996117, 0.00980546661594417, 0.04695480776717886, 0.009318972115579527, 0.06026090333762113, 0.029450137881212868, 0.018345211501582526, 0.023200163486762904, 0.0931471552758012, 0.14235431444831192, 0.17476455657742918, 0.12847978941863403, 0.14371950994245708, 0.06897362429299392, 0.13952590059489012, 0.15846392110688612, 0.15051042835693806, 0.21449700579978526, 0.1300461366190575, 0.13043410173850134, 0.22177354112500325, 0.18872177170123905, 0.15616606862749904, 0.14477310731308535, 0.10844721240573563, 0.14945528731914237, 5.047268690541387, 37.14048005640507, 60.72901390492916, 50.653128772974014, 37.94939585030079, 24.226648807525635, 31.366496086120605, 46.172329410910606, 27.241576127707958, 1.5899618645198643, 0.27558549656532705, 13.16519346088171, 49.11134250462055, 36.83140084147453, 11.550747491419315, 15.771473608911037, 19.011272862553596, 14.727019853889942, 43.55827488005161, 56.632822304964066, 54.36538517475128, 52.65598230063915, 55.266039445996284, 55.753925666213036, 53.059490248560905, 55.30415900051594, 54.47721317410469, 53.493548557162285, 46.21008038520813, 38.39157432317734, 37.28065833449364, 42.348036020994186, 48.659664541482925, 54.079123735427856, 51.52403064072132, 54.57227647304535, 55.77725261449814, 52.16674715280533, 49.067895635962486, 51.030866503715515, 50.11506624519825, 47.5611624866724, 45.93165032565594, 39.568937346339226, 37.66628824174404, 42.98813447356224, 43.579869121313095, 47.767252027988434, 50.822155103087425, 51.71563155949116, 52.955748215317726, 48.51396135985851, 42.41463124752045, 37.699091881513596, 38.32906387746334, 38.82460668683052, 37.874015495181084, 39.21427957713604, 38.59010607004166, 38.904258012771606, 40.26244193315506, 38.04735079407692, 39.97571311891079, 41.083494275808334, 41.22553065419197, 42.3110032081604, 44.092176631093025, 47.83445902168751, 49.717911556363106, 53.94389659166336, 41.884297505021095, 52.9086459428072, 51.88860967755318, 47.627898305654526, 40.40123328566551, 38.74695025384426, 39.65603247284889, 39.492082670331, 38.26438754796982, 39.07302975654602, 39.11986984312534, 39.505017176270485, 39.98203977942467, 39.51735511422157, 40.32347045838833, 42.42321878671646, 40.81747815012932, 43.18177588284016, 51.759397611021996, 52.757573649287224, 51.200364008545876, 52.7496662735939, 53.45311872661114, 54.33966815471649, 56.26525662839413, 52.55765497684479, 50.64589776098728, 51.08785964548588, 54.25316199660301, 54.399621337652206, 51.7501375079155, 47.420790418982506, 43.043911680579185, 40.72037436068058, 37.596497386693954, 40.697997361421585, 44.000840932130814, 43.29248674213886, 44.197943955659866, 42.94362746179104, 47.32758902013302, 52.1325945854187, 54.486093297600746, 56.46771736443043, 56.65085233747959, 52.17998944222927, 53.85861396789551, 56.12688705325127, 59.26690936088562, 56.621639505028725, 55.807742178440094, 58.21701429784298, 59.782659485936165, 42.15789422392845, 26.9064512103796, 20.65758392214775, 5.22599590010941, 8.76960452646017, 3.341052895411849, 0.6439050170592964, 0.182840978668537, 1.457380447536707, 25.261848159134388, 48.178021386265755, 38.95838990807533, 36.51570238173008, 52.60647855699062, 62.80530609190464, 62.82223418354988, 21.180582158267498, 0.9477801143657416, 0.17781635688152164, 0.10868481098441407, 0.09974865533877164, 0.09391712606884539, 0.2131531247869134, 0.09250852235709317, 0.19486322184093297, 0.1211239185067825, 0.17263303423533216, 0.116197816823842, 0.09754619110026397, 0.13984196644742042, 0.1316567455069162, 0.11089107501902618, 0.1847783403354697, 0.20796822878764942, 0.1115855471289251], [0.006449960465033655, 0.005378656842367491, 0.02955064694106113, 0.003058087918361707, 0.04639491671696305, 0.03658310844912194, 0.02073835945338942, 0.029934138765383977, 0.007924002584331902, 0.04010036151157692, 0.03926777200831566, 0.05918896378716454, 0.05699282635760028, 0.038885647591087036, 0.04181083379080519, 0.060263604755164124, 0.06551580983796157, 0.05451336663099937, 1.5235940320417285, 23.671012222766876, 40.766306295990944, 40.0119935721159, 30.468028597533703, 29.107336811721325, 35.584072172641754, 40.070054456591606, 20.885290503501892, 3.049065163359046, 0.0538342643994838, 2.7880429197102785, 30.426817908883095, 14.376140981912613, 2.8972592717036605, 8.82445553317666, 6.069923490285873, 18.031373843550682, 41.341667622327805, 52.94211074709892, 50.568989887833595, 52.05637447535992, 53.18616405129433, 51.87217935919762, 48.875063583254814, 50.089189633727074, 48.06208200752735, 41.88989840447903, 33.49556364119053, 33.83857503533363, 36.993807926774025, 44.428941160440445, 51.93226933479309, 47.580579444766045, 45.85812047123909, 48.78954537212849, 47.19301164150238, 49.593905210494995, 45.854582861065865, 46.87736637890339, 47.278845235705376, 43.31169471144676, 39.00011546909809, 35.370884612202644, 35.43906435370445, 34.021717607975006, 34.87915299832821, 36.96570463478565, 39.30203586816788, 41.043113842606544, 38.82206842303276, 36.20442308485508, 34.6855153888464, 36.32325790822506, 36.251445561647415, 35.07401414215565, 35.54196663200855, 35.513756945729256, 34.92315463721752, 34.74302150309086, 35.86076192557812, 38.4072370827198, 43.89023266732693, 44.64235670864582, 44.9805461615324, 46.05915628373623, 43.444877564907074, 43.43266502022743, 48.16214583814144, 49.30906109511852, 35.670939311385155, 47.195211723446846, 47.86999091506004, 41.605688855051994, 37.96714089810848, 36.28592871129513, 36.08905367553234, 34.25633601844311, 34.509816616773605, 35.5797366052866, 34.765656888484955, 35.9232609719038, 36.26021549105644, 36.316976845264435, 36.61523424088955, 35.482895001769066, 33.58864724636078, 36.830013915896416, 44.24205958843231, 50.24198703467846, 46.90253242850304, 47.3637630790472, 47.349316254258156, 48.793291971087456, 48.42740960419178, 49.63878460228443, 51.33312128484249, 49.995057284832, 49.419270381331444, 49.877461194992065, 48.44777271151543, 50.0347613543272, 48.14698465168476, 43.805242627859116, 38.77576790750027, 34.231698140501976, 36.03637710213661, 37.04545095562935, 37.33114242553711, 37.75143027305603, 39.648273289203644, 43.928827196359634, 48.001296669244766, 50.56415654718876, 50.56622363626957, 48.92039895057678, 51.59145042300224, 50.32611832022667, 56.800792291760445, 53.39506544172764, 54.00642603635788, 54.95461195707321, 58.679795265197754, 34.25524167716503, 24.937936440110207, 7.636475879698992, 2.682525906711817, 3.687719930894673, 0.44095743214711547, 0.13395424175541848, 0.14812958892434835, 0.6084131402894855, 17.983656004071236, 49.75223131477833, 34.6062858402729, 23.065995387732983, 32.40521214902401, 42.624379992485046, 47.091975063085556, 13.652520161122084, 0.22018800198566169, 0.02483194213709794, 0.029107339869369753, 0.024735698571021203, 0.014567115795216523, 0.041788413509493694, 0.04055412544403225, 0.048048091484815814, 0.030713627602381166, 0.07547765068011358, 0.009610407014406519, 0.017033936746884137, 0.010695857363316463, 0.06059688101231586, 0.09148164230282418, 0.08364451830857433, 0.036241048874217086, 0.05590745393419638, 0.06402886501746252, 0.044674900418613106, 0.021990227141941432, 0.04185393772786483, 0.007275483794728643, 0.04141569210332818, 0.03150654745695647, 0.017781798960641026, 0.03684744289785158, 0.0872727892419789, 0.10572678103926592, 0.03721844252140727, 0.022521120627061464, 0.08443373299087398, 0.027006386590073816, 0.042856130239670165, 0.014906589913152857, 0.04658139616367407, 2.2825132962316275, 27.461723014712334, 47.041380777955055, 47.27193720638752, 36.629422679543495, 31.055697463452816, 33.10773745179176, 43.14489126205444, 24.263656921684742, 2.8392534842714667, 0.11806083013652824, 3.0380554916337132, 30.089857690036297, 15.201089065521955, 5.230657774955034, 15.104000475257635, 8.49079828709364, 18.10227993875742, 45.00290036201477, 54.61309768259525, 51.64339363574982, 52.38354451954365, 55.79554483294487, 52.93044917285442, 50.95553934574127, 51.6076223552227, 51.053273901343346, 44.81849245727062, 36.5322694927454, 34.86664406955242, 38.47521163523197, 47.588889598846436, 55.11515714228153, 50.68933703005314, 47.26136617362499, 49.39148247241974, 48.4589859098196, 51.207644417881966, 46.55167445540428, 47.862170934677124, 49.88789163529873, 44.27014388144016, 41.545902863144875, 37.76185691356659, 36.42106465995312, 36.59730680286884, 36.68826252222061, 39.676460176706314, 42.63178579509258, 43.158939108252525, 42.43632048368454, 38.83344881236553, 37.14467503130436, 37.368612214922905, 37.88712479174137, 36.59799836575985, 38.00270318984985, 37.193206027150154, 38.523168861866, 36.640373691916466, 37.633765786886215, 38.947226107120514, 43.543166890740395, 45.96693903207779, 46.494867503643036, 47.517012655735016, 44.8082672059536, 45.15665911138058, 50.207716673612595, 51.864366978406906, 38.40521179139614, 49.29436348378658, 49.6806051582098, 44.42652069032192, 38.174431174993515, 37.59814269840717, 37.562994584441185, 37.252821028232574, 36.59098394215107, 36.40907250344753, 37.96637713909149, 38.45277763903141, 39.165756180882454, 37.977974116802216, 36.82927295565605, 35.86937606334686, 36.56441196799278, 40.803057923913, 46.325533390045166, 51.14554435014725, 48.56261394917965, 47.388803735375404, 50.5600755661726, 52.34219893813133, 48.0836496502161, 50.652418211102486, 51.266203075647354, 51.75242878496647, 51.90258912742138, 49.31895196437836, 50.076661705970764, 51.281998828053474, 51.37081906199455, 45.94816043972969, 39.19320210814476, 36.27451032400131, 37.75504767894745, 39.22940656542778, 39.220697432756424, 38.80876533687115, 42.92727693915367, 46.41548976302147, 49.96031194925308, 54.93757747113705, 52.05011621117592, 51.28487527370453, 52.65629768371582, 53.08852829039097, 58.73363457620144, 54.342878982424736, 56.24254144728184, 56.76122881472111, 59.6622059494257, 37.49361030757427, 26.1316404864192, 8.502552956342697, 4.639737233519554, 2.243843008764088, 1.8339449912309647, 0.4494587337831035, 0.14260185038438067, 0.7658841123338789, 19.3221702799201, 50.13506077229977, 34.98803995549679, 25.62987931072712, 39.56107556819916, 50.63816137611866, 53.52172404527664, 17.041148878633976, 0.48951060336548835, 0.04829720077395905, 0.0508945246838266, 0.025327767289127223, 0.08926688809879124, 0.03774342294491362, 0.03267620559199713, 0.042133007518714294, 0.011159488149132812, 0.03752079348487314, 0.04106670829060022, 0.031050655416038353, 0.039856862858869135, 0.041425403105677105, 0.04026999420602806, 0.07959452195791528, 0.1065133982046973, 0.07137570399208926, 0.1749110416858457, 0.08218517396016978, 0.1473813853226602, 0.1148507148900535, 0.16806680738227442, 0.11873340146848932, 0.11218119485420175, 0.13775721425190568, 0.18053258769214153, 0.14848494407488033, 0.1396554647362791, 0.1452054231776856, 0.13251164025859907, 0.21045936620794237, 0.11368753941496834, 0.14750953938346356, 0.20959918736480176, 0.14142973202979192, 2.7013246854767203, 33.19815739989281, 55.71894854307175, 54.3925005197525, 43.91677424311638, 39.541179835796356, 44.61452700197697, 51.4473507553339, 28.046116456389427, 3.9807811053469777, 0.2537559944903478, 3.127862485125661, 35.68183332681656, 20.703223273158073, 9.84892901033163, 19.254533909261227, 11.51441004127264, 23.191609047353268, 44.38066095113754, 54.93027426302433, 53.910868763923645, 54.08823944628239, 56.88287928700447, 53.49222622811794, 51.00213244557381, 54.96010646224022, 54.567161947488785, 47.15244501829147, 36.85285069048405, 38.20791117846966, 41.45644426345825, 49.93586786091328, 56.53535753488541, 53.72855834662914, 46.204441487789154, 49.726776480674744, 49.11242164671421, 50.62246061861515, 46.247325986623764, 50.36720551550388, 50.92985652387142, 47.74080544710159, 43.4090530872345, 38.92164587974548, 39.75896894931793, 37.442419454455376, 37.66383737325668, 41.71073421835899, 44.87313732504845, 44.28310878574848, 43.126815631985664, 40.54223991930485, 38.80377620458603, 38.4431641548872, 39.26141604781151, 38.65109659731388, 40.170152485370636, 40.02590462565422, 39.71451513469219, 39.38476122915745, 40.10771803557873, 42.040476724505424, 47.137508019804955, 49.22412045300007, 50.28341621160507, 51.781512424349785, 47.818815261125565, 48.56280013918877, 53.57274390757084, 52.81388282775879, 43.41897055506706, 51.487032026052475, 52.47161619365215, 46.164695620536804, 39.95247356593609, 40.23993954062462, 39.2099554091692, 39.51084986329079, 38.65095600485802, 38.521021977066994, 39.88878518342972, 40.971210300922394, 39.86252099275589, 40.159843638539314, 38.69293235242367, 37.590691298246384, 37.83493459224701, 41.7753953486681, 47.58673891425133, 53.86449225246906, 49.95417147874832, 47.7143170684576, 50.795366540551186, 52.421633675694466, 49.95202839374542, 51.99099138379097, 54.182607382535934, 54.017681032419205, 53.18773716688156, 52.175980657339096, 51.47730074822903, 52.85774387419224, 53.88761021196842, 48.44979040324688, 44.39171835780144, 38.635175451636314, 40.013517290353775, 40.47955468297005, 41.3516990840435, 40.73531895875931, 44.09048192203045, 48.220898285508156, 52.54366032779217, 55.46434320509434, 55.588003769516945, 54.251140505075455, 55.19227400422096, 54.687839671969414, 61.035589054226875, 57.91789814829826, 59.48766991496086, 58.929506465792656, 62.49873474240303, 36.53779439628124, 27.76334322988987, 12.35851289704442, 7.14397338218987, 8.231143020093441, 2.627649726346135, 0.6115949945524335, 0.53386464365758, 1.0927565256133676, 23.77252947539091, 61.33695088326931, 44.44094471633434, 35.35312816500664, 46.866077184677124, 58.0190297216177, 60.95010504126549, 22.361680381000042, 0.726173393195495, 0.0739065685775131, 0.19113346963422373, 0.17737310176016763, 0.17414529371308163, 0.13604346167994663, 0.07246227498399094, 0.1355025399243459, 0.07926155740278773, 0.17857720667961985, 0.12706807610811666, 0.17863249668153003, 0.1506757046445273, 0.1225197795429267, 0.20028554572490975, 0.0957018205372151, 0.17244405375095084, 0.19027100497623906], [0.009383863653056324, 0.026466806266398635, 0.022300498676486313, 0.03011662731296383, 0.034202781098429114, 0.08308523581945337, 0.014318412831926253, 0.08361584914382547, 0.013896327473048586, 0.09096407593460754, 0.06820775757660158, 0.05202115680731367, 0.05628478407743387, 0.03248064596846234, 0.016103958914754912, 0.021718539865105413, 0.019462950840534177, 0.09040261153131723, 0.7778380333911628, 17.800080254673958, 41.458838135004044, 42.83420853316784, 33.84594663977623, 19.2708046361804, 21.304457411170006, 32.38814726471901, 26.62799835205078, 3.1487480644136667, 0.2148596488405019, 0.16918853390961885, 7.377823758870363, 21.62753127515316, 12.575793787837029, 18.86388637125492, 8.3214470744133, 17.30753928422928, 37.704871371388435, 54.418194741010666, 52.6868062466383, 51.58842958509922, 49.27178129553795, 49.84491594135761, 50.702693313360214, 47.99929037690163, 45.64127370715141, 37.097884342074394, 34.466468542814255, 37.401301860809326, 42.86898426711559, 48.745536133646965, 47.43368312716484, 46.51998035609722, 46.435621082782745, 46.822345331311226, 48.976518139243126, 49.72698546946049, 46.86538562178612, 50.46414211392403, 46.256236508488655, 43.74584801495075, 38.29006277024746, 36.27221904695034, 36.50172293186188, 34.63712118566036, 34.219375401735306, 34.17478859424591, 37.69178107380867, 39.06900577247143, 34.16862532496452, 34.51946049928665, 34.67388801276684, 34.684227257966995, 34.174123629927635, 35.956691578030586, 36.597967967391014, 35.13392552733421, 35.907427221536636, 37.38820396363735, 36.719926223158836, 45.5784896761179, 46.68115250766277, 47.62692175805569, 49.79006968438625, 46.12108536064625, 47.323006466031075, 47.83784084022045, 50.26117220520973, 48.476780354976654, 29.684875421226025, 48.79268020391464, 49.703761115670204, 44.15982060134411, 38.18793945014477, 37.062941417098045, 37.94706277549267, 36.71848990023136, 35.904706567525864, 35.30928231775761, 35.287190303206444, 33.98356765508652, 34.436617344617844, 36.22754864394665, 34.79508250951767, 35.329698622226715, 34.67987269163132, 36.035822331905365, 40.33498004078865, 47.074917778372765, 50.37586525082588, 48.18964496254921, 46.26306094229221, 46.89133062958717, 51.455543115735054, 49.79054465889931, 45.98570242524147, 45.62438361346722, 47.387390211224556, 49.59903113543987, 49.97976690530777, 47.761559933423996, 50.30349053442478, 50.939044430851936, 48.598807007074356, 41.027276292443275, 35.11936470866203, 35.55768258869648, 36.167477667331696, 36.82757444679737, 38.4571436047554, 42.69394285976887, 46.663711443543434, 48.28939341008663, 52.89063110947609, 50.360939651727676, 53.241857662796974, 49.99674819409847, 54.124611094594, 55.949371978640556, 54.79755878448486, 54.99635651707649, 54.6054220944643, 32.9681633412838, 23.66490215063095, 7.0352336671203375, 7.432254888117313, 4.701526192948222, 0.7817100849933922, 0.44827141624409705, 0.04673662748245988, 0.9037365589756519, 18.20794276893139, 40.14310173690319, 39.133393317461014, 36.13791145384312, 40.228616148233414, 51.049842685461044, 43.99676375091076, 12.55895784124732, 0.12260389456059784, 0.09403395495610312, 0.011991277988272486, 0.02136106588295661, 0.021261293404677417, 0.027574090599955525, 0.03155601902108174, 0.027702999796019867, 0.046157785691320896, 0.038981733450782485, 0.050623195493244566, 0.036892595162498765, 0.016629299279884435, 0.02375123782258015, 0.03205624881957192, 0.04697484204370994, 0.013671518881892553, 0.01890636791358702, 0.07217682272312231, 0.09380496529047377, 0.03132935598841868, 0.03580261029128451, 0.01624214681214653, 0.11273309297394007, 0.09151607795502059, 0.09882785045192577, 0.03652255290944595, 0.02812868457112927, 0.05159885622560978, 0.025036676561285276, 0.0777341729553882, 0.014812097815593006, 0.03772064272197895, 0.06771560234483331, 0.024036066679400392, 0.0570168570993701, 1.1209599184803665, 22.477646358311176, 48.857956901192665, 48.92746277153492, 38.00057150423527, 24.630755223333836, 29.15075708180666, 42.232313230633736, 29.150443598628044, 3.9479083567857742, 0.40441274468321353, 0.17264795140363276, 8.90975620597601, 23.120828345417976, 10.865368768572807, 9.876943957060575, 6.967956377193332, 16.207397617399693, 40.79171933233738, 53.281991109251976, 54.28387574851513, 51.63567624986172, 50.814943090081215, 51.054448038339615, 53.385562151670456, 49.838486686348915, 48.058852180838585, 39.472490921616554, 36.76047384738922, 38.0944112688303, 43.8704889267683, 50.336860343813896, 48.88432368636131, 46.47602051496506, 46.94928891956806, 46.90974824130535, 49.64685156941414, 49.3243058770895, 47.84094147384167, 51.649059131741524, 48.62698249518871, 45.82373611629009, 41.23613968491554, 37.19963148236275, 37.89955772459507, 36.20659276843071, 35.81828400492668, 35.35989560186863, 38.88705633580685, 39.90753337740898, 35.894853696227074, 35.764794275164604, 35.532022565603256, 36.9166112691164, 36.46351598203182, 37.959776893258095, 37.06034615635872, 36.662446707487106, 36.424218490719795, 38.2079491764307, 39.45591241121292, 46.41232453286648, 48.395111337304115, 50.88736340403557, 50.1414330303669, 48.35940085351467, 49.41635213792324, 49.87210348248482, 52.25721649825573, 49.09089960157871, 32.567064464092255, 50.427876859903336, 50.27513265609741, 45.62941454350948, 40.15447452664375, 38.66214260458946, 38.662598580121994, 38.392421677708626, 38.39879013597965, 36.562466472387314, 37.01517418026924, 36.07413947582245, 36.866955533623695, 37.90966518223286, 36.84671401977539, 37.67246291041374, 36.09895974397659, 38.071905076503754, 42.77419455349445, 49.9334017932415, 50.52876904606819, 49.25776764750481, 46.10298313200474, 47.53144808113575, 51.918278485536575, 51.703384816646576, 49.28746685385704, 47.870549485087395, 49.69386264681816, 50.39545699954033, 50.11921942234039, 49.32475805282593, 51.39547973871231, 52.237104177474976, 49.967698752880096, 41.8913347274065, 36.98983334004879, 37.482560500502586, 39.31147836148739, 39.20482948422432, 40.687707513570786, 44.14917357265949, 49.7035027295351, 50.83918198943138, 53.72649505734444, 53.46837870776653, 55.37265792489052, 51.968272402882576, 57.02890545129776, 55.742005705833435, 57.18558244407177, 55.87181434035301, 56.46150849759579, 34.357615783810616, 25.293760746717453, 8.800136838108301, 8.881974946707487, 4.795251013711095, 1.8430235353298485, 0.5344511184375733, 0.0762689285329543, 1.223027785308659, 20.147339701652527, 48.13599944114685, 42.4017271399498, 37.71220117807388, 44.12415571510792, 56.09558813273907, 49.91365425288677, 15.272753220051527, 0.28085806989111006, 0.05059481205535121, 0.005917053904340719, 0.06401293110684492, 0.008924842531996546, 0.05061996715085115, 0.04178235758445226, 0.061374206488835625, 0.03139115091471467, 0.06075463934394065, 0.027562210671021603, 0.065555551846046, 0.07490969990612939, 0.04965533844369929, 0.040928101079771295, 0.01646276690735249, 0.05135518316819798, 0.05809813657833729, 0.1816956073162146, 0.25996144744567573, 0.09341266602859832, 0.1426878949860111, 0.12571181607199833, 0.136557859077584, 0.1213162683416158, 0.20461248932406306, 0.12519983807578683, 0.08779421477811411, 0.17051819537300617, 0.1918024563929066, 0.16065150528447703, 0.12464103056117892, 0.17795414401916787, 0.13364245067350566, 0.1319877730566077, 0.14244677120586857, 1.7943532532081008, 26.478010900318623, 55.268775299191475, 55.84241531789303, 46.70096464455128, 28.072251453995705, 29.78032059967518, 43.24327938258648, 35.28665453195572, 4.435615986585617, 0.5046005733311176, 0.5836316419299692, 10.267790034413338, 27.298101894557476, 20.94553057104349, 24.440168850123882, 13.960206750780344, 20.896074324846268, 41.972939148545265, 55.70070192217827, 54.129930809140205, 51.89723141491413, 50.56523568928242, 51.71289950609207, 54.57997106015682, 53.64359490573406, 49.70795229077339, 43.0044811964035, 39.11176107823849, 40.4645948857069, 46.60384565591812, 52.965684682130814, 49.6161188185215, 46.58643878996372, 48.55585791170597, 49.143211394548416, 51.95889450609684, 51.79962605237961, 48.23364280164242, 52.90150612592697, 51.20563052594662, 49.51198920607567, 44.03959505259991, 39.60508480668068, 39.751133769750595, 38.0439043790102, 37.24896423518658, 37.20251552760601, 41.817109510302544, 42.60109484195709, 37.55661852657795, 37.13907413184643, 38.038573265075684, 38.727590292692184, 37.41327881813049, 40.13747423887253, 40.11499464511871, 39.11064773797989, 38.618574142456055, 41.75405949354172, 41.17510735988617, 49.49544869363308, 50.291840359568596, 52.50408545136452, 53.33124786615372, 50.15505149960518, 51.17909274995327, 53.79585273563862, 54.68833364546299, 49.714651331305504, 36.45711712539196, 53.57179015874863, 53.76225493848324, 48.3719439804554, 42.57901802659035, 40.12208506464958, 42.809278070926666, 41.43184058368206, 40.557028725743294, 39.229341968894005, 39.512555971741676, 38.68838779628277, 38.5675922781229, 39.81404699385166, 38.7759654968977, 38.34517501294613, 38.724246472120285, 39.062306731939316, 44.48839657008648, 51.57728858292103, 54.722072035074234, 50.65006233751774, 47.50586025416851, 47.34398514032364, 54.21515643596649, 54.47638861835003, 50.3603582829237, 51.14256910979748, 52.823253124952316, 53.12060996890068, 52.98130564391613, 48.6019342392683, 52.61483810842037, 55.84596052765846, 52.18931034207344, 45.59464640915394, 38.3521818369627, 39.651362523436546, 41.41826771199703, 39.690215438604355, 42.41539880633354, 47.2864980250597, 52.075187265872955, 52.923419550061226, 55.72973996400833, 56.656335443258286, 57.46188081800938, 52.97660909593105, 57.92919494211674, 58.20634067058563, 60.083006769418716, 57.59974882006645, 58.56047786772251, 36.19871199131012, 34.93811063468456, 15.193471424281597, 12.346174009144306, 7.834088075906038, 1.742335231974721, 1.4556096238084137, 0.20098916109418496, 1.5751136862672865, 23.865599781274796, 52.79976278543472, 50.52333153784275, 49.531691148877144, 52.449622973799706, 63.52217562496662, 59.39768314361572, 20.1973944157362, 0.5055098526645452, 0.0997277935675811, 0.0765814988699276, 0.13922432146500796, 0.0878666558128316, 0.18384954251814634, 0.15426817437401041, 0.09652969369199127, 0.10325413793907501, 0.21352140814997256, 0.15915714640868828, 0.21049166447483003, 0.15173359162872657, 0.12194270035251975, 0.11081539079896174, 0.08018144944799133, 0.21226533805020154, 0.13311843504197896], [0.03650828140962403, 0.04868691736191977, 0.08432764298049733, 0.025744542581378482, 0.03290778535301797, 0.033286800171481445, 0.004821416650884203, 0.019749716702790465, 0.02819803085003514, 0.019545642790035345, 0.04577226594847161, 0.02520382491638884, 0.031150346258073114, 0.06054547615349293, 0.03386662530829199, 0.02374840281845536, 0.08989016598206945, 0.06045006193744484, 0.38052770134527236, 12.562650293111801, 39.352481961250305, 44.87423926591873, 40.83445183932781, 29.813555516302586, 25.626786276698112, 39.74514149129391, 26.514929719269276, 4.972239341586828, 0.1963774554315023, 0.2614057558821514, 0.48357371881138533, 14.148264359682798, 8.557160776108503, 6.833548564463854, 4.93603678420186, 11.806998141109943, 43.73517818748951, 46.84083513915539, 51.83852456510067, 52.30603247880936, 53.161894753575325, 51.39940872788429, 49.57125082612038, 45.17099194228649, 38.2370176166296, 34.443263188004494, 36.42656296491623, 42.51263938844204, 49.35910440981388, 48.90783682465553, 46.17004573345184, 50.883810594677925, 47.92042940855026, 46.68352738022804, 48.343308717012405, 49.087042808532715, 50.652159824967384, 48.40357728302479, 47.26195514202118, 44.79241065680981, 42.21253529191017, 39.06033843755722, 35.361160933971405, 32.397232577204704, 34.56407390534878, 33.53862293064594, 35.8182992041111, 36.4817626029253, 35.35398691892624, 35.870724990963936, 34.81755070388317, 38.680522218346596, 42.434747368097305, 36.6924536973238, 35.82973659038544, 35.453739166259766, 36.12577870488167, 35.769958198070526, 40.82763880491257, 48.438957184553146, 48.578276708722115, 50.61797685921192, 50.97438633441925, 51.35281562805176, 48.93916234374046, 47.8421688079834, 42.59298987686634, 51.90554156899452, 26.67235717177391, 44.265413135290146, 52.495714500546455, 45.57663917541504, 45.67115530371666, 43.20235937833786, 44.76531811058521, 43.313077837228775, 44.905302599072456, 39.41126100718975, 35.78924596309662, 34.80808921158314, 36.32251314818859, 36.726116091012955, 35.48506088554859, 36.06823079288006, 35.43038181960583, 33.68991941213608, 38.791689053177834, 43.28485295176506, 48.146714866161346, 48.38769033551216, 50.37334978580475, 50.09880691766739, 48.570027351379395, 43.97291623055935, 42.623848021030426, 42.79991157352924, 45.23477531969547, 45.00983498990536, 49.4266913831234, 47.311310693621635, 50.152699425816536, 51.474082320928574, 50.737362653017044, 47.15333417057991, 38.81908558309078, 36.11690238118172, 38.526516482234, 36.900785118341446, 37.28798434138298, 38.07468272745609, 42.13003411889076, 47.85793796181679, 49.5942547917366, 52.77376838028431, 54.718530625104904, 52.83393815159798, 54.30362708866596, 53.47297266125679, 59.222983717918396, 52.87317864596844, 54.624538868665695, 34.90776166319847, 22.416566535830498, 6.1554293520748615, 8.084594383835793, 9.845649786293507, 2.352177808061242, 0.6282262271270156, 0.02386897584074177, 1.30921725416556, 15.790901016443968, 46.27511389553547, 31.59924879670143, 31.87927857041359, 40.830226466059685, 52.742260470986366, 43.64730790257454, 8.464779183268547, 0.22952191910007969, 0.012983134238311322, 0.071072729624575, 0.16500941128470004, 0.05267770517093595, 0.09026467596413568, 0.04016471313661896, 0.03324116551084444, 0.03940196715120692, 0.005434662089101039, 0.05652038256812375, 0.06236700341105461, 0.054912200503167696, 0.06025768612744287, 0.042955143871949986, 0.10253495973302051, 0.10631891840603203, 0.0251625132659683, 0.031879506350378506, 0.04361300954769831, 0.02479239679814782, 0.032733989210100845, 0.010011320755438646, 0.04695454059401527, 0.027302967355353758, 0.04903639099211432, 0.04689982575655449, 0.060673118132399395, 0.022890823347552214, 0.023328530915023293, 0.018668266529857647, 0.06856643754872493, 0.031915218496578746, 0.017136941278295126, 0.02228418812592281, 0.08305704905069433, 0.5583494016900659, 16.06602620333433, 45.2617234736681, 49.02750760316849, 47.22005099058151, 30.397850163280964, 26.930988393723965, 43.5460889339447, 31.62523940205574, 5.19803605042398, 0.30104840523563325, 0.35141072468832135, 0.592757505364716, 19.7348490357399, 13.45594435930252, 12.321727070957422, 7.795859277248383, 17.562752589583397, 43.76608952879906, 48.96675266325474, 51.25839449465275, 52.309881672263145, 52.110757157206535, 52.89978101849556, 51.844642236828804, 48.362942263484, 40.88034197688103, 37.44444094598293, 37.82139591872692, 44.764736741781235, 51.021108627319336, 49.46746699512005, 47.887272387742996, 51.23593010008335, 49.497546181082726, 47.686456963419914, 50.49416050314903, 49.51277196407318, 51.25850848853588, 50.48697508871555, 49.22978974878788, 47.732909470796585, 43.54885518550873, 40.26832401752472, 36.88286527991295, 34.72126767039299, 35.894538313150406, 34.228095933794975, 36.84833273291588, 36.98910377919674, 37.05851845443249, 37.09374636411667, 35.96868373453617, 38.248606994748116, 43.1826688349247, 38.17132294178009, 36.828315407037735, 37.31851950287819, 37.8097989410162, 37.80651971697807, 43.30448269844055, 51.49376526474953, 50.22133134305477, 52.86899507045746, 51.85880787670612, 52.050773575901985, 50.91475613415241, 49.167039915919304, 43.9980024844408, 52.411659210920334, 30.126354731619358, 47.00347401201725, 54.135033935308456, 47.436354383826256, 47.44560308754444, 44.50652539730072, 47.15265020728111, 46.390137523412704, 46.3735856115818, 42.37663708627224, 37.73862116038799, 36.677949875593185, 37.86198154091835, 38.73525068163872, 37.66895949840546, 37.0427493005991, 37.24593959748745, 36.541313007473946, 39.770866110920906, 46.531250551342964, 50.12217566370964, 50.553213134408, 51.26352421939373, 52.79802247881889, 50.878338888287544, 45.79349733889103, 46.214184165000916, 46.16402305662632, 46.1284189671278, 47.86975912749767, 51.06267839670181, 48.292638435959816, 51.2722447514534, 53.59386697411537, 53.224055618047714, 50.04097022116184, 39.823200702667236, 37.083555310964584, 40.070704221725464, 38.86884771287441, 40.21636180579662, 38.78772206604481, 44.59999278187752, 49.22353148460388, 51.91647358238697, 54.8379772156477, 56.693516448140144, 54.50558245182037, 55.7095592468977, 54.825289696455, 61.550647616386414, 55.93710623681545, 56.4423993229866, 36.656101047992706, 26.85916654765606, 4.786059306934476, 12.410036232322454, 14.2667106539011, 1.0230579343624413, 0.5751586309634149, 0.03436805367527995, 1.240576549898833, 19.159527607262135, 49.65023338794708, 35.69122262299061, 36.87197506427765, 47.680764868855476, 59.976502284407616, 51.13986365497112, 11.592425554990768, 0.2538551454199478, 0.019142990568070672, 0.018527525644458365, 0.06338358245557174, 0.03230099056963809, 0.023633100900042336, 0.09579516787198372, 0.05264217485091649, 0.020879920411971398, 0.02244869257992832, 0.01057923163898522, 0.03842445104965009, 0.07477047300199047, 0.023222299896588083, 0.03549789187673014, 0.0310241087936447, 0.02104279956256505, 0.0022810479367763037, 0.20528269320493564, 0.20583770092343912, 0.17190096492413431, 0.163183891272638, 0.10250082836137153, 0.14366120682097971, 0.11954263929510489, 0.11950384723604657, 0.13125206722179428, 0.2247512008761987, 0.0898027112998534, 0.14022267336258665, 0.11562317187781446, 0.2636511385207996, 0.1153451633581426, 0.16419962426880375, 0.13028424727963284, 0.12588010547915474, 0.8305613917764276, 19.472034238278866, 53.27863208949566, 55.896547213196754, 53.93756993114948, 39.42908585071564, 35.68628668785095, 51.13502271473408, 36.387816444039345, 6.5796984359622, 0.6467789690941572, 1.4702260144986212, 1.3950735284015536, 21.097256429493427, 15.4234179854393, 15.565234925597906, 9.464382994920015, 16.471684835851192, 46.44345626235008, 48.908729776740074, 54.50204864144325, 54.091514870524406, 53.95186096429825, 56.010468900203705, 55.32562404870987, 48.71071480214596, 42.693992257118225, 38.700896725058556, 39.09996651113033, 48.50347392261028, 52.96061955392361, 50.186597406864166, 47.84589260816574, 53.530129194259644, 53.8270528614521, 50.818974673748016, 51.802145317196846, 51.84287533164024, 52.1662949770689, 51.775774732232094, 51.495752558112144, 50.8629497140646, 46.683101803064346, 42.708389684557915, 39.69030663371086, 35.64941726624966, 37.332039177417755, 35.46412780880928, 38.862855434417725, 39.78221230208874, 39.6992589533329, 38.36257807910442, 38.25787469744682, 40.924339815974236, 45.44047348201275, 40.31794935464859, 39.42636899650097, 39.45626579225063, 40.797058045864105, 40.10259971022606, 46.377533599734306, 53.574548810720444, 53.05056072771549, 54.798675924539566, 53.94263505935669, 54.48708884418011, 52.537029683589935, 50.948536321520805, 44.978285282850266, 54.45849917829037, 34.56063888967037, 49.88068342208862, 57.641102001070976, 49.13017429411411, 50.60070298612118, 46.502980068325996, 50.91386318206787, 49.01694416999817, 50.78964784741402, 44.39039222896099, 39.926737546920776, 38.49503897130489, 39.86387751996517, 40.245981216430664, 39.68752518296242, 39.66822221875191, 38.090060502290726, 37.456680089235306, 41.51082694530487, 47.52417527139187, 51.7106082290411, 53.06614749133587, 55.06782688200474, 55.87167374789715, 53.66804659366608, 47.48659908771515, 47.8230444341898, 48.22440169751644, 50.02404972910881, 49.95950259268284, 52.7837086468935, 52.105422243475914, 51.11996412277222, 54.24878463149071, 55.95230162143707, 51.00800313055515, 43.43816712498665, 40.08801609277725, 43.670148476958275, 39.44233573973179, 41.29831574857235, 40.48525057733059, 46.485212221741676, 51.804698780179024, 54.798314943909645, 57.23913297057152, 60.08469767868519, 56.596693843603134, 57.606808841228485, 57.167920991778374, 64.15064290165901, 56.49487070739269, 58.75725790858269, 37.94650800526142, 28.08658618479967, 9.186729993671179, 14.57018231973052, 13.76552989706397, 2.376112723723054, 0.9837917319964617, 0.13859368889825419, 1.6117339837364852, 22.240189500153065, 58.9463509619236, 41.661086082458496, 42.80048154294491, 55.319798961281776, 66.70607417821884, 59.426523596048355, 16.261081136763096, 0.6586783868260682, 0.10750078115961514, 0.2601937990402803, 0.19394080649362877, 0.24616314098238945, 0.17091424990212545, 0.3519886499270797, 0.13853241718607023, 0.12887866410892457, 0.08229403960285708, 0.17842840607045218, 0.12870583275798708, 0.21452373795909807, 0.15042430954053998, 0.09624611906474456, 0.27658151811920106, 0.17460690956795588, 0.1504646972171031], [0.11234236706513911, 0.018236440482723992, 0.1158916215354111, 0.022952416038606316, 0.030465087911579758, 0.014388500330824172, 0.021522126771742478, 0.10240122472168878, 0.022261754857026972, 0.023393029114231467, 0.0045912748009868665, 0.009497732298768824, 0.006788185919504031, 0.11487508701975457, 0.02856535869796062, 0.013996866218803916, 0.08133959316182882, 0.011893356240761932, 0.16474867996294051, 9.53909458592534, 36.17041490972042, 48.1777174025774, 38.04336480796337, 24.37275666743517, 22.449347376823425, 31.728918738663197, 33.64432945847511, 8.266731910407543, 0.05601601900707465, 0.18230053188744932, 0.42769943887833506, 13.122549299150705, 11.054219584912062, 7.573470985516906, 4.397236621007323, 9.038762133568525, 34.01585832238197, 47.97710716724396, 51.918947249650955, 49.331194907426834, 52.29283958673477, 49.16554659605026, 48.112463504076004, 43.40276822447777, 36.466605216264725, 36.15985907614231, 42.41209678351879, 50.0927272439003, 48.861258924007416, 48.14117856323719, 50.445154532790184, 48.05198214948177, 43.92889179289341, 44.478247314691544, 42.56872817873955, 44.4179293513298, 47.47819393873215, 49.81981448829174, 48.771021366119385, 47.330818846821785, 45.387587919831276, 41.814065873622894, 36.4847644418478, 36.418568193912506, 33.911379128694534, 35.30433498322964, 32.291655242443085, 35.91406546533108, 35.46487636864185, 37.08379089832306, 34.51591528952122, 43.57396803796291, 43.2273468375206, 37.18877166509628, 34.557572454214096, 37.0010769367218, 35.08673585951328, 36.31614089012146, 42.30284124612808, 47.62842267751694, 49.78625848889351, 50.11194661259651, 50.40655240416527, 50.2169805765152, 47.65904523432255, 47.26690627634525, 44.961725771427155, 49.303969368338585, 29.87284753471613, 40.59540666639805, 51.14213973283768, 47.62337654829025, 50.203403905034065, 48.00396792590618, 49.329823181033134, 45.519148260354996, 44.83797401189804, 46.68105751276016, 40.72242625057697, 33.20831425487995, 35.01201666891575, 36.02007977664471, 36.57436363399029, 35.065187215805054, 34.45957191288471, 34.31956082582474, 36.332043036818504, 37.055695205926895, 43.730569034814835, 45.712132304906845, 47.82206028699875, 46.72582671046257, 44.80696387588978, 42.06524379551411, 39.26371872425079, 38.11005502939224, 41.70341581106186, 43.12499552965164, 44.58520397543907, 50.69642744958401, 46.240911930799484, 50.57170294225216, 51.05784125626087, 45.90090237557888, 42.9744666069746, 35.620371624827385, 36.23495824635029, 38.34049366414547, 38.62947955727577, 38.1285410374403, 39.472817704081535, 40.24243600666523, 47.499886974692345, 50.86777925491333, 52.707435339689255, 53.61242137849331, 53.83518062531948, 51.46258033812046, 56.44551895558834, 56.092688888311386, 52.3167859017849, 30.595688447356224, 18.43514397740364, 6.124567408114672, 3.0480698542669415, 10.910142716020346, 0.6570674513932317, 0.3433539695106447, 0.06361425679642707, 0.9695717075373977, 18.56271643191576, 51.41730956733227, 36.281897127628326, 34.67295706272125, 42.428728491067886, 51.67601488530636, 40.73513276875019, 11.961533948779106, 0.2824658586177975, 0.03848387481411919, 0.01352784558548592, 0.09115651482716203, 0.06214496766915545, 0.04703989870904479, 0.043826028195326217, 0.01621856506972108, 0.043080859977635555, 0.052298998343758285, 0.058667593912105076, 0.06318538449704647, 0.017774822772480547, 0.006463902172981761, 0.11246117748669349, 0.016094782258733176, 0.017122126155300066, 0.08186285922420211, 0.04906612513877917, 0.03150153424940072, 0.0712538581865374, 0.05117835906276014, 0.04860597873630468, 0.035090983437839895, 0.045385978082777, 0.02909882372478023, 0.059234906439087354, 0.05173360797925852, 0.0644360072328709, 0.024102550123643596, 0.039078257177607156, 0.018771595750877168, 0.014310143451439217, 0.05136179199325852, 0.05195860860112589, 0.051526359529816546, 0.22922568343346938, 12.708602361381054, 42.11844854056835, 52.5919633358717, 42.76725992560387, 28.786126747727394, 27.87357721477747, 38.3509811013937, 37.02541463077068, 9.408961068838835, 0.04995770796085708, 0.2605435880832374, 0.8262936864048243, 13.41685300692916, 13.878313545137644, 8.411647584289312, 8.784318286925554, 13.291537631303072, 36.32597096264362, 48.982803001999855, 52.73115746676922, 49.913160279393196, 54.6497543156147, 52.01959624886513, 50.02014733850956, 45.11193551123142, 38.07583786547184, 37.41017438471317, 42.669468373060226, 51.612949669361115, 50.49091547727585, 48.24573755264282, 50.28566189110279, 51.07722021639347, 46.88109777867794, 46.90766595304012, 44.70135234296322, 47.04532116651535, 49.60855342447758, 50.40234223008156, 50.568381920456886, 48.99920292198658, 46.32335610687733, 44.378734454512596, 37.2969214618206, 36.15258626639843, 35.834683924913406, 36.14645339548588, 35.464158207178116, 36.72252908349037, 37.246672958135605, 38.9547611027956, 35.74920751154423, 44.86806459724903, 45.304303988814354, 39.52884569764137, 36.7679138481617, 37.61882118880749, 36.84005677700043, 37.963139712810516, 44.131253734230995, 49.71748597919941, 51.628471836447716, 51.33566714823246, 51.572759225964546, 52.44117982685566, 48.673332408070564, 48.191613256931305, 45.46820059418678, 48.737826347351074, 32.576419562101364, 43.79902236163616, 53.67880381643772, 48.58943670988083, 52.33892731368542, 49.73369210958481, 52.08454616367817, 48.015838488936424, 46.58035911619663, 49.155507534742355, 41.91086567938328, 35.85580699145794, 35.93156732618809, 37.24183201789856, 39.4040147960186, 36.677110120654106, 36.04989297688007, 36.109853759408, 37.670407220721245, 39.59454797208309, 47.71390289068222, 48.42533491551876, 50.95825619995594, 49.75534334778786, 47.603887394070625, 44.97727833688259, 42.448115050792694, 40.73297828435898, 44.3821656703949, 44.34887185692787, 47.3932608962059, 51.73625685274601, 48.016663044691086, 52.131234258413315, 51.969651728868484, 47.70446039736271, 44.64501656591892, 37.29025661945343, 37.89750203490257, 39.837746322155, 40.91363199055195, 40.84883026778698, 41.15383230149746, 43.35805222392082, 49.40648406744003, 52.437874004244804, 56.448232010006905, 54.96184676885605, 56.09094098210335, 53.29256974160671, 60.26199996471405, 58.12658295035362, 55.08989989757538, 32.61005915701389, 21.57446712255478, 8.887134119868279, 7.30649066157639, 12.363728117197752, 0.4493328952230513, 0.2737213106593117, 0.12141065468313172, 0.9485789621248841, 20.319723151624203, 56.45403429865837, 39.3205750733614, 39.762263372540474, 50.19200071692467, 55.801388919353485, 48.339964896440506, 13.919936511665583, 0.2391624916344881, 0.034198996145278215, 0.051659786549862474, 0.05164379697816912, 0.03206425659300294, 0.039395020648953505, 0.04180569441814441, 0.039178243023343384, 0.01882841643237043, 0.01895529028843157, 0.02234364343166817, 0.05841485923156142, 0.007404034440696705, 0.04702177546278108, 0.054707427116227336, 0.03822585233137943, 0.03666344593511894, 0.009934123481798451, 0.13622497615870088, 0.16880680283065885, 0.16730346396798268, 0.08752257388550788, 0.10646765222190879, 0.11264837681665085, 0.1569513202412054, 0.10729965171776712, 0.12508667539805174, 0.15229468495817855, 0.12799967924365774, 0.15309267182601616, 0.09497783321421593, 0.2342701650923118, 0.11198358319234103, 0.11567135952645913, 0.18366833974141628, 0.09492415367276408, 0.4264552134554833, 15.583545193076134, 48.46048302948475, 60.60143955051899, 49.09276530146599, 34.244955629110336, 32.082814648747444, 42.28389926254749, 44.37491945922375, 11.535709798336029, 0.12713307340163738, 0.6709347479045391, 2.094737347215414, 19.930464439094067, 15.203308146446943, 13.751061223447323, 10.256419144570827, 11.817158795893192, 36.257886216044426, 51.71534277498722, 52.58676141500473, 51.26324683427811, 55.443356931209564, 51.883035376667976, 53.76814462244511, 47.01647311449051, 39.96557526290417, 40.76982870697975, 47.01104320585728, 54.678484573960304, 51.463150307536125, 48.66612419486046, 53.028996884822845, 53.49268980324268, 50.33401809632778, 49.402368888258934, 47.364355847239494, 48.876317515969276, 52.931547313928604, 51.9475407153368, 51.78639516234398, 50.46233341097832, 49.82916198670864, 46.9584996253252, 40.656784772872925, 38.695417419075966, 38.39221648871899, 38.00662457942963, 37.066775411367416, 38.40925097465515, 39.63599614799023, 40.69968067109585, 38.154930621385574, 46.16085022687912, 45.79299196600914, 41.90215274691582, 39.10704553127289, 39.755712524056435, 38.395035937428474, 39.283409267663956, 45.06006069481373, 52.004948034882545, 53.96651677787304, 53.33209902048111, 55.3608937561512, 53.42593498528004, 51.32248945534229, 50.18972463905811, 47.105684727430344, 48.972292765975, 34.79993864893913, 46.04641556739807, 54.52271953225136, 51.151605024933815, 55.34542478621006, 51.68491020798683, 54.335803762078285, 50.47559089958668, 48.14404360949993, 52.04014554619789, 45.129851549863815, 37.102489694952965, 38.27041782438755, 39.081385508179665, 41.05016626417637, 38.60776372253895, 37.20384545624256, 37.974542900919914, 40.29755584895611, 40.09533450007439, 49.05154511332512, 49.57895681262016, 53.575004786252975, 50.965437814593315, 49.85349968075752, 46.72717943787575, 45.099434182047844, 43.81782375276089, 45.49056239426136, 45.87486617267132, 49.55958925187588, 53.68673399090767, 48.81087742745876, 52.20963925123215, 53.939192444086075, 50.707667246460915, 47.40808390080929, 40.48343047499657, 39.51873064041138, 42.260500118136406, 43.789754658937454, 42.383305728435516, 43.690925762057304, 45.70379555225372, 52.46509574353695, 56.15858495235443, 58.17533053457737, 58.14755402505398, 57.519470527768135, 54.25788514316082, 60.06127953529358, 59.85728748142719, 55.75270593166351, 32.862437814474106, 21.413427963852882, 11.9782929494977, 7.6703686360269785, 18.989834412932396, 3.299970687367022, 1.014263543765992, 0.3130499424878508, 1.245907188858837, 25.41304014623165, 64.03139770030975, 47.14494042098522, 46.19433023035526, 56.50766842067242, 64.91897687315941, 55.853750109672546, 18.63943051546812, 0.4966323118424043, 0.20740289037348703, 0.11080126772867516, 0.17605482484214008, 0.17229798424523324, 0.08399297890719026, 0.14010499842697755, 0.14472271548584104, 0.11317775817587972, 0.1590712057077326, 0.11852437557536177, 0.18653528590220958, 0.15074607508722693, 0.11103881435701624, 0.17855630780104548, 0.20066591125214472, 0.08100454317172989, 0.09460169792873785], [0.04819741159735713, 0.02709559088543756, 0.03264673119701911, 0.029460923142323736, 0.03584796664654277, 0.04445667931577191, 0.08139447498251684, 0.02882063708966598, 0.04735977548989467, 0.02625251483550528, 0.002912497329816688, 0.0517016102821799, 0.019865716240019538, 0.01648892019147752, 0.02574310652562417, 0.010358081835875055, 0.020952637896698434, 0.05648862977977842, 0.09623330217436887, 4.838258530944586, 30.442100688815117, 51.34966179728508, 40.828288570046425, 26.99901234358549, 26.697511821985245, 43.10907818377018, 42.50551097095013, 10.731675792485476, 0.38976251205895096, 0.20117840875172988, 0.26043621415738016, 6.232874421402812, 13.888924475759268, 11.656558513641357, 10.848824456334114, 11.996632665395737, 29.06301598995924, 45.716437473893166, 52.04706497490406, 52.95111246407032, 54.8976644128561, 50.84995441138744, 47.617323473095894, 38.384875282645226, 35.44882223010063, 37.415767684578896, 46.0418938100338, 52.684556767344475, 48.11542734503746, 48.74362863600254, 46.879095286130905, 43.51592615246773, 42.78098098933697, 40.918431133031845, 41.753766909241676, 42.9142702370882, 45.93142233788967, 47.46823087334633, 50.42268253862858, 48.12193259596825, 46.0538137704134, 43.98832060396671, 36.97645045816898, 33.72158691287041, 34.29393120110035, 33.953982442617416, 35.74639946222305, 36.42012991011143, 36.75741121172905, 36.57406724989414, 35.33503733575344, 35.62099479138851, 35.67529007792473, 37.12219923734665, 36.3519349694252, 35.61067454516888, 35.97811482846737, 35.98116606473923, 38.445896208286285, 42.46829956769943, 45.17009139060974, 47.77884520590305, 46.669851914048195, 48.592776730656624, 48.690123707056046, 51.012756675481796, 48.2575511187315, 44.902232363820076, 30.104390010237694, 40.4585038125515, 44.26167033612728, 51.71998232603073, 50.17133742570877, 49.801655262708664, 47.32992209494114, 50.13435781002045, 51.10547550022602, 47.752676010131836, 41.38332098722458, 34.48395520448685, 34.41903568804264, 35.61137370765209, 35.30841216444969, 34.23319146037102, 35.27549833059311, 35.18722906708717, 35.38983799517155, 35.705935433506966, 35.86930766701698, 39.37476396560669, 39.77614402770996, 42.386520355939865, 39.669248163700104, 38.23411077260971, 36.33362755179405, 36.04006290435791, 38.20208229124546, 42.5668016821146, 44.09840449690819, 48.41978341341019, 50.109780728816986, 48.83648045361042, 53.40205326676369, 46.26292034983635, 41.04138873517513, 38.31088945269585, 36.821627765893936, 36.32135421037674, 37.04799301922321, 36.069522723555565, 38.4216383099556, 40.00418119132519, 40.82772620022297, 47.58460722863674, 49.78498175740242, 55.09852923452854, 53.6445676535368, 51.23555772006512, 54.06444892287254, 57.68975839018822, 48.98620001971722, 31.366838067770004, 18.567910753190517, 6.537928227335215, 9.960531871765852, 6.742685465142131, 0.16765926440712065, 0.17546973045682535, 0.12929410353535786, 1.1437259218655527, 22.057943679392338, 50.46271339058876, 31.569412797689438, 23.178239464759827, 36.36426530778408, 51.32674902677536, 43.14572721719742, 12.218444813042879, 0.4237591690616682, 0.05184295601793565, 0.03187632253684569, 0.012172793394711334, 0.046548901227652095, 0.058325304271420464, 0.029336826773942448, 0.02645657761604525, 0.04503384385316167, 0.033655205988907255, 0.03903609576809686, 0.03547929365595337, 0.04016453131043818, 0.022707611205987632, 0.042112112350878306, 0.023466778184229042, 0.05444113339763135, 0.08618233681772836, 0.04638021477148868, 0.026109313730557915, 0.05675138716469519, 0.026155742489208933, 0.01866111037088558, 0.04303620495193172, 0.05808158668514807, 0.06703775434289128, 0.06280242145294324, 0.038826717354822904, 0.0859042392403353, 0.05457826002384536, 0.050754845069604926, 0.030258570477599278, 0.05315786358551122, 0.015131019081309205, 0.011043430167774204, 0.005564663633776945, 0.08212285581976175, 7.541790660470724, 37.180883288383484, 56.561785116791725, 45.538527220487595, 30.28127431869507, 24.89312544465065, 39.57281693816185, 44.865632727742195, 11.473106257617474, 0.2621977758826688, 0.4457162314793095, 0.3940863534808159, 10.031428467482328, 11.102484595030546, 8.387093301862478, 12.898064944893122, 8.23485067114234, 33.20615977048874, 48.75101923942566, 52.61977404356003, 53.65859270095825, 57.36540399491787, 52.091864570975304, 49.52314920723438, 41.00849390029907, 37.00605846941471, 38.93727444112301, 47.33687952160835, 53.23192119598389, 48.88352192938328, 48.059220761060715, 50.26558756828308, 46.09596110880375, 46.126785054802895, 43.67036886513233, 44.367190673947334, 44.79812175035477, 48.39838296175003, 49.10142503678799, 51.50518365204334, 50.685860216617584, 48.55393521487713, 44.86549973487854, 38.69524642825127, 35.0648832321167, 36.17859207093716, 35.34585155546665, 37.39427603781223, 38.45198728144169, 38.116146102547646, 36.93082630634308, 37.58938416838646, 37.72787533700466, 37.71982356905937, 38.70621643960476, 38.48520129919052, 37.41678602993488, 38.27978432178497, 37.21419610083103, 42.29567103087902, 46.029886454343796, 48.32003116607666, 50.23872680962086, 49.36356157064438, 50.487260073423386, 51.532523185014725, 52.07257680594921, 50.63056938350201, 44.61073100566864, 31.218383833765984, 42.53637671470642, 48.01439456641674, 51.43198437988758, 51.87668591737747, 51.029631569981575, 48.47915902733803, 51.23959310352802, 51.92746639251709, 50.61448484659195, 42.94070161879063, 36.96172244846821, 37.37260200083256, 38.00587221980095, 37.43452727794647, 36.003064289689064, 36.931525468826294, 37.13539592921734, 38.03878605365753, 38.114705979824066, 39.28206793963909, 41.50448888540268, 43.5304793715477, 46.13217316567898, 43.38416442275047, 41.04079216718674, 38.55008281767368, 38.337590619921684, 40.83117261528969, 44.40554961562157, 45.69064445793629, 49.72337186336517, 50.53900569677353, 49.50072281062603, 55.32462850213051, 47.750076949596405, 43.65381695330143, 38.55876915156841, 38.73588904738426, 37.84438468515873, 39.780323803424835, 39.2863655090332, 40.41950650513172, 41.256430596113205, 44.924176186323166, 50.077398866415024, 53.30769672989845, 56.741169691085815, 57.599623426795006, 51.910697892308235, 55.97580336034298, 57.25531630218029, 51.29943989217281, 31.548633612692356, 19.0183499827981, 7.847567377611995, 12.960942070931196, 10.822241082787514, 1.5937911090441048, 0.08507622507750057, 0.0665360847779084, 1.2046085111796856, 24.62448175996542, 59.951685816049576, 35.623236671090126, 28.42586237937212, 43.81593145430088, 57.41847574710846, 50.154215544462204, 15.371210686862469, 0.5030117835849524, 0.030904504274076317, 0.018148345698136836, 0.05242936771537643, 0.011738407865777845, 0.057702839039848186, 0.027958502687397413, 0.0132580841818708, 0.03504404259729199, 0.020537766213237774, 0.06199924697284587, 0.05048150836955756, 0.004938254814987886, 0.06790221537812613, 0.037142134897294454, 0.0643096343264915, 0.045160758527345024, 0.020919896196573973, 0.14930203382391483, 0.16483116225572303, 0.20236893236869946, 0.11492492965771817, 0.12249410865479149, 0.1144638704136014, 0.20332812855485827, 0.16730141564039513, 0.1464896503603086, 0.15419179253512993, 0.1375052848015912, 0.13432963489321992, 0.09957761998521164, 0.13362364465137944, 0.11657803392154165, 0.0929786877532024, 0.09311433008406311, 0.2056365937460214, 0.29951643431559205, 9.240333717316389, 44.34201702475548, 64.68069165945053, 51.87157139182091, 36.77917644381523, 35.7965187728405, 53.33773411810398, 52.28316530585289, 14.717385470867157, 0.6585523998364806, 0.5852199567016214, 1.1797143844887614, 11.90804136916995, 21.473850421607494, 20.463237650692463, 19.028732925653458, 15.303610414266586, 33.35614152252674, 48.723033741116524, 55.31668312847614, 55.48933066427708, 59.316067323088646, 55.411628633737564, 52.376176714897156, 43.1819012761116, 39.8765042424202, 42.07076869904995, 50.59149228036404, 56.14307798445225, 48.951599076390266, 50.407905131578445, 51.40401788055897, 48.42231407761574, 47.613276690244675, 45.36393038928509, 45.83191327750683, 47.8714956343174, 51.554364413022995, 51.710912212729454, 54.11052145063877, 51.698779463768005, 52.014363929629326, 47.052495181560516, 40.42808264493942, 37.469344809651375, 37.39859260618687, 36.74943543970585, 40.01419745385647, 40.57964511215687, 39.5505615323782, 39.16443385183811, 38.84530417621136, 39.44751866161823, 39.24453355371952, 40.94879910349846, 41.69863946735859, 39.5243239402771, 39.616168811917305, 39.4171316921711, 44.124512895941734, 47.70089238882065, 51.079838275909424, 52.8289870172739, 51.52840040624142, 52.497078627347946, 53.33056390285492, 56.20634838938713, 51.54943607747555, 47.164091393351555, 35.90558432042599, 45.7402203977108, 48.006756976246834, 54.05483543872833, 54.677386432886124, 54.49035666882992, 50.63539892435074, 52.47912839055061, 56.19231194257736, 53.225427344441414, 46.174381300807, 39.24876272678375, 38.81891459226608, 39.57612656056881, 39.64795410633087, 36.89853183925152, 38.86259704828262, 38.46505478024483, 40.20386427640915, 39.43201929330826, 39.314803183078766, 43.318256959319115, 44.692601412534714, 48.95533427596092, 44.98429276049137, 42.294903472065926, 40.65075449645519, 40.2183149009943, 42.982195392251015, 47.037770971655846, 49.01160545647144, 53.30596782267094, 52.57530502974987, 50.44159792363644, 57.38205470144749, 51.388298124074936, 45.775733292102814, 41.27909637987614, 40.068450942635536, 40.54513156414032, 41.41662620007992, 41.07352741062641, 42.721639573574066, 44.892155304551125, 46.21001198887825, 52.89707936346531, 54.93803344666958, 60.09171970188618, 59.08374398946762, 53.45371149480343, 57.44330361485481, 60.41184112429619, 52.37454280257225, 34.23821099102497, 22.50151477754116, 10.518679171800613, 19.51277945190668, 16.438869796693325, 1.1341474670916796, 0.4783038469031453, 0.385159237193875, 1.6222337703220546, 29.007652960717678, 64.99945655465126, 42.13042929768562, 32.89051450788975, 50.97756676375866, 63.42428907752037, 58.23466435074806, 18.142134100198746, 0.7232043868862092, 0.29964331188239157, 0.13406915590167046, 0.12222358098370023, 0.12022729279124178, 0.1111059267714154, 0.1308734976919368, 0.19506498210830614, 0.16408686235081404, 0.08790162581135519, 0.12869527941802517, 0.14418544509680942, 0.12456092314096168, 0.11697506066411734, 0.13258625578600913, 0.2237825794145465, 0.15758432768052444, 0.21895333542488515], [0.00771105397689098, 0.09195549617288634, 0.06969813111936674, 0.04668735258746892, 0.06446447601774707, 0.04412071648403071, 0.02657848464878043, 0.05422470458142925, 0.05220005892624613, 0.022807120221841615, 0.0648934744822327, 0.04048447488457896, 0.03005057431437308, 0.003938693216696265, 0.038386853848351166, 0.011362901550455717, 0.002808798426485737, 0.04122431819268968, 0.0997438165359199, 3.7195467855781317, 30.35441469401121, 45.65711125731468, 44.29785959422588, 31.62362828850746, 44.34175103902817, 58.58953110873699, 40.973167195916176, 15.909153521060944, 0.3564484528033063, 0.10467221145518124, 0.8316712884698063, 6.526589635759592, 5.602363329380751, 4.197871768847108, 7.832760522142053, 9.300611782819033, 21.132440641522408, 43.88161092996597, 52.76300735771656, 51.857960522174835, 50.108458399772644, 46.337502747774124, 40.765424743294716, 35.516671389341354, 36.69822558760643, 38.38585563004017, 46.18910551071167, 48.02981413900852, 47.98844575881958, 50.55490784347057, 45.431304574012756, 40.770132690668106, 38.974497243762016, 36.51311092078686, 38.13106410205364, 39.961038306355476, 41.66328616440296, 44.23053100705147, 47.62246459722519, 48.888210877776146, 47.208579406142235, 43.180487751960754, 37.1129809319973, 36.5603081882, 35.25671973824501, 33.93863506615162, 36.12672485411167, 35.3850806504488, 36.59569948911667, 35.594647005200386, 34.243093729019165, 36.06784701347351, 37.21298396587372, 36.70528180897236, 36.277325972914696, 34.5009820908308, 36.08063332736492, 37.75152146816254, 37.05795608460903, 38.98030333220959, 40.47369919717312, 42.218386977910995, 43.06753121316433, 45.801047533750534, 44.42660428583622, 47.27890983223915, 48.911568224430084, 43.23331631720066, 29.938274323940277, 38.71425300836563, 44.29456137120724, 49.87515851855278, 50.68456828594208, 48.28457526862621, 48.506194576621056, 47.71796107292175, 47.291536554694176, 45.352352410554886, 38.05930495262146, 34.26244609057903, 36.345232129096985, 35.48968143761158, 35.39318561553955, 34.63743656873703, 35.52020139992237, 35.802670642733574, 35.2387011051178, 34.87574078142643, 36.14252060651779, 35.022732093930244, 35.36864273250103, 34.51340362429619, 35.204852521419525, 36.03695847094059, 36.111430674791336, 35.04624143242836, 37.96327270567417, 43.83179560303688, 43.27360935509205, 47.55020007491112, 48.00525605678558, 47.43658997118473, 49.85484100878239, 47.46474266052246, 46.568382158875465, 40.59029594063759, 42.90324702858925, 41.73564948141575, 39.9069482088089, 36.56834475696087, 37.72608183324337, 36.51629514992237, 39.385221004486084, 43.27635280787945, 51.650484055280685, 51.17520555853844, 56.58735014498234, 49.19871501624584, 54.59433428943157, 53.193193674087524, 45.06171740591526, 26.146478690207005, 13.768594432622194, 6.907143015414476, 13.849478792399168, 8.76464294269681, 1.4540425641462207, 0.31871534942183644, 0.06919599400134757, 2.2272557113319635, 20.958508774638176, 49.55655701458454, 43.08675058186054, 34.912781193852425, 38.4820094704628, 53.66782620549202, 41.17414601147175, 8.97147724404931, 0.2628766925772652, 0.0947348318004515, 0.005969371604805929, 0.058415345338289626, 0.03168754243233707, 0.0725542641885113, 0.027451957212178968, 0.08336335566127673, 0.0790678420162294, 0.02556496881879866, 0.08174666116246954, 0.06479489500634372, 0.04463672805286478, 0.059588658550637774, 0.06627503433264792, 0.030084401405474637, 0.08733988681342453, 0.033551223677932285, 0.05941710369370412, 0.028372546876198612, 0.04839411412831396, 0.01076774920875323, 0.0373188254161505, 0.09245453111361712, 0.06665624590823427, 0.04457151182577945, 0.06873108301078901, 0.017749101789377164, 0.014221305591490818, 0.013874685519112973, 0.046923411209718324, 0.01713323981675785, 0.017126471429946832, 0.028666166472248733, 0.02085403430100996, 0.02137200513971038, 0.03949263904360123, 4.665962951257825, 34.601372703909874, 51.6468970477581, 49.11230385303497, 35.46612270176411, 43.25454957783222, 57.68073007464409, 46.005609557032585, 17.564832977950573, 0.5562950181774795, 0.22535271156812087, 0.30900425801519305, 7.345181135460734, 9.464253801852465, 7.084700362756848, 11.528784669935703, 7.485741293057799, 28.69373470544815, 48.870887607336044, 55.274543389678, 53.91549691557884, 51.577045395970345, 49.86936762928963, 44.95311163365841, 37.228365540504456, 37.98628807067871, 39.9150075763464, 49.22413185238838, 49.7031569480896, 49.4296096265316, 50.91910310089588, 48.21967855095863, 44.76087614893913, 40.42658932507038, 38.97306092083454, 40.87482467293739, 42.35316954553127, 44.55494239926338, 46.85776703059673, 49.81230229139328, 51.89777858555317, 50.49166023731232, 45.67096911370754, 38.48587766289711, 38.10508869588375, 36.86502903699875, 35.50984315574169, 36.88023202121258, 36.424963250756264, 38.02664950489998, 36.77206702530384, 36.19969613850117, 36.601072400808334, 39.01099808514118, 39.27691921591759, 38.3315185457468, 37.02470786869526, 37.931677401065826, 39.32621017098427, 39.28663529455662, 40.14108024537563, 42.99774415791035, 45.57867206633091, 46.262916550040245, 48.78845863044262, 47.47638903558254, 50.077022686600685, 51.569362208247185, 44.22161288559437, 32.22749948501587, 43.51251773536205, 44.79700841009617, 51.659265384078026, 50.49169063568115, 49.326118379831314, 50.08121766149998, 49.95687693357468, 50.237575471401215, 46.932159438729286, 40.9349412471056, 36.8916542083025, 38.75265374779701, 35.789261162281036, 37.31498949229717, 36.28980450332165, 36.27582885324955, 36.30263641476631, 36.08272701501846, 37.63826094567776, 36.63510337471962, 36.35959915816784, 38.13002675771713, 35.90946391224861, 37.18712255358696, 37.94012814760208, 37.653102949261665, 38.335249945521355, 39.325959384441376, 45.01624904572964, 46.59856013953686, 50.0234417617321, 49.430943354964256, 47.91018135845661, 52.91648872196674, 48.56354869902134, 48.63813489675522, 42.937714979052544, 44.0594831854105, 41.55903495848179, 41.19051553308964, 38.85698474943638, 40.07430262863636, 39.99720096588135, 41.34431228041649, 46.451922208070755, 54.03355658054352, 54.68654774129391, 57.981639727950096, 50.13177014887333, 54.173415675759315, 56.136139556765556, 48.1426452845335, 28.171680718660355, 14.189694486558437, 6.408135741949081, 13.961802665144205, 13.028087317943573, 2.955148215405643, 0.2863765018992126, 0.01479768252465874, 2.466967273503542, 22.83321987837553, 54.372042417526245, 42.621940523386, 34.00492250919342, 45.49571491777897, 57.64387205243111, 47.32546113431454, 11.256933957338333, 0.33187965396791697, 0.0768763838277664, 0.014075929993850878, 0.06886052098707296, 0.03549001397914253, 0.05165970120287966, 0.05350203085981775, 0.028304375045991037, 0.05677106892107986, 0.03179785155225545, 0.05334601657523308, 0.05409171542851254, 0.03907289887138177, 0.025810142869886477, 0.024402836061199196, 0.11102596035925671, 0.06128199092927389, 0.032360213954234496, 0.25824429583735764, 0.31115523946937174, 0.2630299609154463, 0.08548651399905793, 0.11009344438207336, 0.20222808758262545, 0.13740242313360795, 0.15829175768885761, 0.15391314576845616, 0.09220063497195952, 0.15765359974466264, 0.11359419208019972, 0.17383209255058318, 0.11485579118016176, 0.1467081089504063, 0.11728597601177171, 0.1546591822989285, 0.13470778882037848, 0.1736556988907978, 6.987374285236001, 40.31868651509285, 60.05403712391853, 55.27254469692707, 42.67190784215927, 51.73746898770332, 66.46778896450996, 50.127050802111626, 20.80278553068638, 0.6734996696468443, 0.3510650619864464, 1.4995098556391895, 11.45055826753378, 12.653144337236881, 11.329673454165459, 14.386083148419857, 12.968201581388712, 26.517878361046314, 48.427918776869774, 57.24038690328598, 56.09066739678383, 55.635356828570366, 51.00850470364094, 47.12513968348503, 38.735832050442696, 41.61771520972252, 43.040868043899536, 51.19760535657406, 51.48320183157921, 49.236826971173286, 52.24272407591343, 50.86355768144131, 44.874121472239494, 43.8671413064003, 41.07261165976524, 43.10285411775112, 44.42648269236088, 46.89902521669865, 49.18934851884842, 52.10281178355217, 53.400928527116776, 50.866206139326096, 47.433189153671265, 40.74457906186581, 39.58352476358414, 38.77477616071701, 38.14638867974281, 39.802138432860374, 37.95350342988968, 40.21226182579994, 38.992949053645134, 37.66362838447094, 39.32091325521469, 40.95940813422203, 41.47901125252247, 39.915664941072464, 38.10554087162018, 39.689288288354874, 40.911777690052986, 40.78903667628765, 43.09539511799812, 45.28233356773853, 46.759325712919235, 46.952704936265945, 51.21935918927193, 48.58940251171589, 52.13431589305401, 53.49243141710758, 46.727225035429, 36.468079537153244, 45.4383759945631, 47.29329966008663, 50.34497290849686, 54.83068160712719, 50.18658220767975, 54.1597668081522, 50.76698586344719, 52.050746977329254, 48.865564092993736, 43.62642802298069, 38.506309166550636, 39.446158334612846, 38.322387635707855, 39.735733196139336, 37.85601206123829, 38.83584268391132, 38.68597112596035, 38.83861653506756, 38.92549507319927, 38.82096268236637, 39.20193403959274, 39.905470088124275, 37.15974122285843, 38.69996577501297, 39.85468201339245, 40.49875505268574, 40.10288469493389, 41.74851939082146, 48.73262822628021, 48.58010821044445, 52.28688910603523, 51.09913744032383, 47.407703921198845, 53.372836634516716, 51.75183981657028, 51.8885450810194, 44.70096476376057, 46.82641491293907, 45.494012609124184, 43.74780111014843, 42.99419514834881, 42.16804347932339, 41.48196369409561, 43.882025107741356, 48.23939949274063, 56.67979158461094, 56.46251544356346, 60.308068692684174, 51.789685785770416, 55.788595005869865, 55.87066300213337, 47.868516594171524, 28.287958279252052, 15.361219123005867, 11.472797524183989, 23.22022531181574, 15.869382005184889, 4.1184185072779655, 0.7106835837475955, 0.22340417315717787, 3.303439663723111, 27.324595972895622, 62.287112697958946, 54.79713700711727, 45.448118671774864, 52.091249004006386, 65.82471147179604, 55.48829711973667, 14.536767862737179, 0.5219449801370502, 0.15675916336476803, 0.12928423297125846, 0.2082081206026487, 0.14790917106438428, 0.16216352727496997, 0.10863417424843647, 0.1926385154365562, 0.19453900720691308, 0.09484983500442468, 0.1501652257866226, 0.14915783453034237, 0.16027014527935535, 0.09776332866749726, 0.2164492549491115, 0.1699365593958646, 0.17326598230283707, 0.117457256274065], [0.019802850765699986, 0.06802468458772637, 0.060680406022584066, 0.054205486667342484, 0.020182377666060347, 0.049787255193223245, 0.11211601944523863, 0.03412601334275678, 0.03144949114357587, 0.06762930541299284, 0.026336991650168784, 0.067004840093432, 0.011614219656621572, 0.010706860630307347, 0.04676956399634946, 0.06735546034178697, 0.005656678349623689, 0.05765790199802723, 0.11112675885669887, 3.074872666038573, 24.517648592591286, 45.96928350627422, 47.024623677134514, 39.96351957321167, 29.11248743534088, 34.96770344674587, 39.851771369576454, 18.6518482491374, 2.2799819195643067, 0.29730712005402893, 0.18460395047441125, 7.450442612171173, 8.63249458372593, 8.4053342230618, 15.50671711564064, 3.9001976419240236, 26.381420083343983, 45.45650862157345, 52.43657827377319, 48.29299181699753, 45.68616829812527, 41.51732839643955, 39.19038645923138, 38.76016594469547, 37.11165100336075, 37.74855762720108, 49.10540722310543, 50.71473866701126, 47.719959765672684, 49.598654955625534, 44.95074816048145, 42.37792521715164, 37.17230714857578, 33.74523304402828, 36.40341080725193, 38.588354364037514, 41.31916143000126, 41.786068975925446, 45.85756190121174, 45.90595990419388, 45.32469369471073, 39.63474981486797, 34.91698756814003, 35.3572129458189, 34.246171563863754, 37.45463579893112, 37.839912325143814, 36.40659123659134, 35.70931725203991, 38.260827139019966, 36.71308659017086, 37.2620203346014, 35.83242304623127, 35.82635097205639, 34.852600023150444, 35.622309520840645, 34.84984137117863, 34.929139316082, 34.313925728201866, 35.182874500751495, 36.13199897110462, 38.719496726989746, 39.044075310230255, 42.85719349980354, 44.632902815937996, 49.110529348254204, 47.957416623830795, 47.88898229598999, 31.437016502022743, 42.728369012475014, 48.81629213690758, 48.104814514517784, 47.5234305113554, 46.31895214319229, 45.71677565574646, 47.204703614115715, 44.99645210802555, 41.6868980973959, 37.14002788066864, 36.78900271654129, 36.33095249533653, 34.7698974609375, 37.03868351876736, 35.222893953323364, 37.76631787419319, 33.83443705737591, 35.80691501498222, 34.7756427526474, 35.50502881407738, 35.32540485262871, 37.32699304819107, 37.076472491025925, 36.45109064877033, 35.94799384474754, 34.80237051844597, 34.937692657113075, 38.8094948977232, 43.2156016677618, 44.00608465075493, 49.149127677083015, 48.76535587012768, 48.005575239658356, 51.126925349235535, 50.82915812730789, 49.416329339146614, 46.545381993055344, 49.68939408659935, 48.38156506419182, 49.07230719923973, 47.2046884149313, 39.03723947703838, 35.706904381513596, 37.535879239439964, 38.78214776515961, 48.9930434525013, 51.59669414162636, 55.26810273528099, 55.56068703532219, 55.707731544971466, 50.2741789072752, 46.266355365514755, 22.32459057122469, 10.984862856566906, 3.477031923830509, 12.069308515638113, 12.3280755802989, 4.575179172679782, 0.24081439361907542, 0.041140036191791296, 1.9129053479991853, 22.82235436141491, 47.79049538075924, 38.638101294636726, 34.558609798550606, 43.00847478210926, 54.54337902367115, 43.892991319298744, 8.50434836000204, 0.20084470947040245, 0.056972083330038004, 0.02022462442255346, 0.06734534486895427, 0.05696936335880309, 0.03400303205125965, 0.031917029336909764, 0.09568394219968468, 0.030760998888581526, 0.07126705357222818, 0.023349808288912755, 0.047881119389785454, 0.09015942458063364, 0.019726997707039118, 0.029072510878904723, 0.06641124811721966, 0.03347078600199893, 0.05408512515714392, 0.03510039758111816, 0.0679950432095211, 0.038460114956251346, 0.026006442785728723, 0.024380504837608896, 0.019246106421633158, 0.13427312776912004, 0.06010582786984742, 0.039812771865399554, 0.03452764511166606, 0.00430657999459072, 0.02633673560922034, 0.06930724193807691, 0.04549734105239622, 0.057556866013328545, 0.05317290320817847, 0.029024660907452926, 0.027290376820019446, 0.11107672326033935, 4.335244372487068, 29.66634951531887, 53.239680379629135, 51.512072682380676, 42.24605329334736, 36.15820616483688, 46.24961346387863, 46.89039967954159, 21.122944951057434, 1.969749704003334, 0.1857259590178728, 0.2641206211410463, 10.555516295135021, 9.671925008296967, 5.151822930201888, 7.239362513646483, 7.580283069983125, 25.90063378214836, 45.780467838048935, 53.84119190275669, 49.388940408825874, 48.90062481164932, 45.23109711706638, 40.02147026360035, 40.58568678796291, 37.86640830338001, 41.32135771214962, 50.307791903615, 53.75693142414093, 48.775292336940765, 51.60336658358574, 47.02146604657173, 43.93864206969738, 39.25553396344185, 36.07405588030815, 38.454856127500534, 39.70287635922432, 43.65217164158821, 44.561641439795494, 48.5724326223135, 47.72764295339584, 47.74320311844349, 42.85237915813923, 36.41206294298172, 35.82065507769585, 36.12461976706982, 38.786528930068016, 39.83737774193287, 37.88691960275173, 38.11522275209427, 40.03994107246399, 38.917967677116394, 38.74572291970253, 37.74603456258774, 38.36472496390343, 37.55435764789581, 37.66695320606232, 37.17364847660065, 36.178360283374786, 35.8068922162056, 37.31635741889477, 39.03183996677399, 40.22428058087826, 41.91398151218891, 44.52066443860531, 46.562446877360344, 48.98426212370396, 50.15358477830887, 48.50361451506615, 32.36543968319893, 46.07377789914608, 50.49894444644451, 49.877058416604996, 49.803646355867386, 49.04794290661812, 48.71451459825039, 49.211915507912636, 47.40604721009731, 42.67319597303867, 38.844616413116455, 37.80901998281479, 37.39016845822334, 36.77046351134777, 38.354081735014915, 37.540116012096405, 38.30769382417202, 35.91555118560791, 37.984114587306976, 35.34007206559181, 37.512700483202934, 37.51367323100567, 38.94745409488678, 39.60446164011955, 38.02316129207611, 37.428003028035164, 36.69743523001671, 38.02873559296131, 41.044314578175545, 45.55153772234917, 47.22256265580654, 53.0354755371809, 50.134904980659485, 47.82469354569912, 52.739258632063866, 51.204547584056854, 51.280798092484474, 47.92951852083206, 50.64573436975479, 51.31056189537048, 51.73043176531792, 48.037132546305656, 39.79696311056614, 37.77178958058357, 39.15206931531429, 42.1641942858696, 50.336062386631966, 54.03269402682781, 56.86466306447983, 57.22899131476879, 55.90993009507656, 51.05469882488251, 47.589489966630936, 25.69428015500307, 13.459497168660164, 5.231642872095108, 14.618844408541918, 9.080349002033472, 3.1526400055736303, 0.4134183208225295, 0.08238927199272439, 2.205582861788571, 26.820866502821445, 53.882689476013184, 44.38553608953953, 39.063883647322655, 49.46763038635254, 60.33499784767628, 49.442517533898354, 11.372234970331192, 0.2547819691244513, 0.012141088845964987, 0.05281665005895775, 0.055408352200174704, 0.028619023396458942, 0.04276317995390855, 0.035781010083155707, 0.029770007240585983, 0.024089775906759314, 0.016898268440854736, 0.051415883426670916, 0.043727278025471605, 0.05744944384787232, 0.06870893732411787, 0.03777801444812212, 0.05792281903268304, 0.03212769908714108, 0.03446140843152534, 0.16003550786990672, 0.14690287818666548, 0.2518620336195454, 0.15914838906610385, 0.12419459904776886, 0.1558354269945994, 0.21894487494137138, 0.09662125245085917, 0.1028182300797198, 0.07498685357859358, 0.12111347648897208, 0.119879463018151, 0.10591394326183945, 0.1484279174474068, 0.1813213125569746, 0.15886135603068396, 0.1825175210251473, 0.15773516177432612, 0.25705831416416913, 5.318938912823796, 33.24363715946674, 59.5741418749094, 58.56073245406151, 52.25107982754707, 40.790978372097015, 46.80353254079819, 50.37927746772766, 24.71381686627865, 3.043385655619204, 0.4149014287395403, 0.6793302192818373, 11.70664457604289, 15.684502925723791, 15.21646874025464, 24.161415807902813, 6.691348794847727, 28.50236177444458, 48.41170124709606, 58.16263161599636, 53.07263754308224, 50.02047412097454, 46.913156658411026, 42.190766260027885, 43.36366832256317, 39.07034710049629, 43.70876960456371, 51.67752720415592, 56.07996717095375, 48.2858520001173, 55.003921911120415, 49.16238896548748, 46.553179174661636, 42.0743253082037, 37.14677631855011, 39.33619603514671, 43.04149881005287, 46.684807911515236, 48.250095918774605, 50.86416944861412, 49.74086232483387, 50.95229811966419, 43.56291443109512, 37.37704396247864, 36.780027598142624, 36.90535247325897, 41.4180663228035, 40.897061079740524, 39.11510109901428, 39.82149459421635, 44.087871462106705, 41.919343024492264, 40.94455473124981, 39.29926201701164, 39.35013368725777, 38.17378140985966, 38.25020290911198, 39.71160069108009, 38.42503912746906, 37.35461376607418, 39.79563318192959, 40.47958888113499, 42.796035781502724, 43.245513662695885, 47.81115107238293, 48.90684127807617, 52.432641685009, 53.36025930941105, 49.14786994457245, 36.67132683098316, 45.27417540550232, 52.305147126317024, 53.83347071707249, 51.68404385447502, 53.009994104504585, 50.34771256148815, 53.12619186937809, 51.67677104473114, 45.75415425002575, 41.18924260139465, 40.550648868083954, 38.81886139512062, 39.56695385277271, 41.546058654785156, 39.79273773729801, 42.266845777630806, 37.58699029684067, 40.22921271622181, 37.81536564230919, 39.223262295126915, 39.06610272824764, 41.487944573163986, 42.367046400904655, 40.08080407977104, 39.15443278849125, 38.06000791490078, 39.380505457520485, 43.9324826002121, 48.31190340220928, 50.79549953341484, 55.67009836435318, 50.72692461311817, 48.24293330311775, 53.74477207660675, 54.17456701397896, 55.04648342728615, 50.23771606385708, 53.98133598268032, 53.470138013362885, 54.98763598501682, 50.68387292325497, 43.75619485974312, 39.18237268924713, 42.37645469605923, 43.55669416487217, 52.56129518151283, 56.934085339307785, 59.67479467391968, 56.97487995028496, 57.0870803296566, 51.44680358469486, 50.460908487439156, 25.96634365618229, 15.689542405307293, 7.6100782211869955, 19.600843526422977, 17.994589917361736, 6.323161851614714, 0.7786595018114895, 0.1572202003444545, 2.8107654629275203, 30.387450121343136, 61.849091202020645, 51.43521420657635, 46.93392634391785, 57.604065388441086, 65.74362382292747, 57.5092338770628, 16.676134765148163, 0.4927836824208498, 0.13955567555967718, 0.14137671299977228, 0.10199780066614039, 0.15053150535095483, 0.15854230674449354, 0.1198683753318619, 0.21173044253373519, 0.16197753022424877, 0.11269545866525732, 0.1405961369164288, 0.12368645053356886, 0.2101448440225795, 0.13087443279800937, 0.11469377292087302, 0.12471108930185437, 0.08306366900797002, 0.13961433491203934], [0.02033077380474424, 0.029697666395804845, 0.044233300286578014, 0.1420299959136173, 0.05623998433293309, 0.05922250515141059, 0.12253959488589317, 0.06559485598700121, 0.05651884632243309, 0.04274725717550609, 0.03387899691006169, 0.04726828352431767, 0.009946704740286805, 0.05116361258842517, 0.03513674426358193, 0.03350312508700881, 0.009877831580524798, 0.06454241636674851, 0.039638537855353206, 1.4070756593719125, 18.911758102476597, 47.34837010502815, 47.66864351928234, 36.058305725455284, 23.557430617511272, 29.356962516903877, 39.69754904508591, 27.30918399989605, 3.304273006506264, 0.12379527906887233, 0.14908529701642692, 6.3145942613482475, 7.551711928099394, 2.5022448180243373, 6.874652383849025, 6.291713789105415, 20.766425281763077, 37.17170298099518, 52.01685279607773, 49.20812711119652, 43.716901168227196, 41.92313142120838, 39.46230746805668, 34.95506912469864, 37.596653178334236, 41.82373255491257, 49.58319738507271, 51.74188435077667, 45.88384889066219, 48.346720933914185, 45.086393281817436, 40.97896568477154, 36.06771782040596, 34.53334115445614, 33.94433096051216, 36.25086419284344, 38.24796482920647, 40.25851674377918, 40.5059252679348, 41.04754440486431, 39.11111131310463, 34.187107533216476, 34.6612498909235, 36.023594588041306, 34.75208401679993, 33.90229381620884, 37.91023135185242, 36.996577978134155, 38.29538248479366, 39.14220504462719, 40.01637853682041, 40.213952735066414, 37.64671549201012, 36.263897493481636, 35.47654174268246, 35.41121184825897, 35.88661573827267, 37.37913005053997, 34.021322429180145, 35.57530604302883, 34.61595632135868, 36.22841119766235, 35.105062276124954, 39.1684540361166, 41.8428835272789, 46.167458072304726, 48.69029849767685, 49.377776607871056, 36.44544415175915, 43.03112156689167, 51.79613783955574, 44.938486218452454, 45.24478778243065, 43.046054765582085, 43.475511521101, 41.191172897815704, 40.905774012207985, 36.76261693239212, 35.08677765727043, 35.72684571146965, 35.385814011096954, 35.18679969012737, 34.70475755631924, 35.17597787082195, 36.243496388196945, 35.38026250898838, 37.543885409832, 36.0456258058548, 36.411466374993324, 34.77105639874935, 35.47075845301151, 35.73188044130802, 36.370519772171974, 35.69732129573822, 34.12301257252693, 37.342887595295906, 41.75229638814926, 45.18912456929684, 46.941959112882614, 44.52892139554024, 43.09075176715851, 47.34842710196972, 46.518449038267136, 49.033275693655014, 49.730918258428574, 49.37539413571358, 50.021454468369484, 49.26473647356033, 50.31530410051346, 50.3016172349453, 49.449490159749985, 35.75246773660183, 36.07013449072838, 37.781783044338226, 44.35645245015621, 50.28962507843971, 52.10182763636112, 49.43893812596798, 54.488004595041275, 47.66831673681736, 39.731720611453056, 18.69191899895668, 6.565757934004068, 3.0516141140833497, 13.87111958116293, 9.130972735583782, 1.6026643454097211, 0.10900272478465922, 0.07129885460017249, 2.1525830682367086, 24.409023821353912, 43.40878710150719, 31.571724973618984, 25.040865316987038, 43.1094391644001, 55.240413621068, 42.249241322278976, 9.592231884598732, 0.2971522189909592, 0.03768909773498308, 0.06401066755643114, 0.054454751807497814, 0.02965602820040658, 0.008658264014229644, 0.0923224956204649, 0.030548752074537333, 0.07248086578329094, 0.11187039825017564, 0.025692872404761147, 0.02523578365071444, 0.041475171528873034, 0.025645152309152763, 0.030355400340340566, 0.0959074919228442, 0.017725427278492134, 0.02055782275419915, 0.019945053682022262, 0.0258914507139707, 0.019716594651981723, 0.013534224344766699, 0.08390771356062032, 0.12179164361441508, 0.021530440681090113, 0.05186583643080667, 0.01674011491559213, 0.04301736182242166, 0.01208321524245548, 0.040797598121571355, 0.04639079408661928, 0.08989122725324705, 0.01897483289212687, 0.03936929409974255, 0.032139109607669525, 0.01183531565402518, 0.03907786755007692, 2.1596749126911163, 22.99619123339653, 53.699755892157555, 52.55576267838478, 42.79973678290844, 31.044404469430447, 34.316539987921715, 43.63529674708843, 27.51702144742012, 3.7693915609270334, 0.02973198515974218, 0.20241932419594377, 6.917752521112561, 5.825565727427602, 5.208404744043946, 6.72153627499938, 5.979557689279318, 19.87406026571989, 42.383613511919975, 53.75464394688606, 51.84555038809776, 45.69104343652725, 43.84053513407707, 41.314149498939514, 36.99188522994518, 38.93898434937, 43.339592814445496, 52.13528864085674, 53.046669736504555, 46.81642144918442, 51.22843310236931, 46.59510612487793, 43.310144394636154, 38.16906966269016, 36.064343601465225, 35.798787251114845, 38.49459059536457, 39.565069153904915, 42.219234332442284, 42.691761776804924, 43.886938244104385, 40.89201495051384, 36.14282079041004, 36.10240995883942, 37.25281722843647, 35.263008400797844, 36.232408583164215, 39.402388483285904, 38.51707398891449, 39.37633328139782, 41.36536695063114, 41.31941221654415, 41.19531087577343, 39.658616334199905, 38.43240313231945, 37.56374314427376, 37.27902062237263, 37.150006145238876, 39.03761185705662, 36.07381649315357, 36.692940071225166, 34.89421159029007, 37.09650121629238, 37.713652700185776, 40.57010002434254, 44.68714490532875, 48.63641358911991, 51.51340641081333, 50.46165704727173, 38.700999319553375, 45.85656635463238, 53.84658761322498, 47.728896886110306, 46.932425424456596, 46.80100567638874, 44.639495462179184, 43.39042268693447, 43.732404336333275, 38.447036147117615, 37.56808631122112, 37.198730930686, 36.33628360927105, 37.30680093169212, 37.441081926226616, 37.204947397112846, 36.244670525193214, 37.87167102098465, 39.00948956608772, 38.46176415681839, 37.97807291150093, 37.11977876722813, 37.3040346801281, 39.49968986213207, 38.39692063629627, 36.15603648126125, 36.78123593330383, 38.61752539873123, 42.45341956615448, 46.767609268426895, 47.858819514513016, 47.13755361735821, 44.90282133221626, 48.3415912091732, 47.440195977687836, 49.86585661768913, 51.07450716197491, 51.332087740302086, 51.91640518605709, 52.312359139323235, 52.305869087576866, 54.636071249842644, 49.7276808321476, 39.17595483362675, 38.88769470155239, 39.67592440545559, 48.06497365236282, 52.410314083099365, 53.899773359298706, 54.813981503248215, 55.45451693236828, 50.67663811147213, 41.90860100090504, 22.345580644905567, 12.382679600268602, 7.606359645724297, 15.93266760930419, 8.390094190835953, 3.2244554394856095, 0.14340823836391792, 0.06775525529519655, 2.0391703164204955, 28.998022377490997, 50.65777212381363, 34.6564469486475, 31.13189287483692, 50.63479855656624, 60.06148472428322, 48.903140276670456, 11.884558629244566, 0.26096649351529777, 0.03182012711477, 0.11679966148221865, 0.05245777341770008, 0.0069957924551999895, 0.052646115655079484, 0.056114123508450575, 0.020731420372612774, 0.06994798997766338, 0.03492681295028888, 0.06601647750358097, 0.02941186718089739, 0.015635936470062006, 0.04098969562619459, 0.0279127585599781, 0.01774198088241974, 0.041977616638178006, 0.03600200310756918, 0.14114360441453755, 0.061070720039424486, 0.1818493803148158, 0.19491726503474638, 0.1104600504913833, 0.2352233201963827, 0.14848877355689183, 0.10619048975058831, 0.12028417841065675, 0.14607836696086451, 0.13130159815773368, 0.1694234978640452, 0.11744964926037937, 0.19834238046314567, 0.10036995910922997, 0.11934738024137914, 0.14155855402350426, 0.11752508857171051, 0.13736185734160244, 2.487523932941258, 26.585184149444103, 62.39119291305542, 60.74457786977291, 47.87472926080227, 34.774233028292656, 40.08971460163593, 50.85951469838619, 33.79192113876343, 4.561711270362139, 0.29379818646702915, 0.2451388436020352, 10.138532370328903, 17.98733990639448, 11.67319592088461, 16.062615886330605, 11.72887908294797, 24.39128827303648, 42.07285098731518, 57.128870487213135, 55.55729761719704, 47.89622090756893, 46.78815096616745, 44.37126025557518, 38.57743754982948, 41.55631810426712, 45.02560794353485, 54.666522815823555, 54.098510295152664, 47.33358509838581, 51.85134507715702, 49.22192797064781, 46.277579963207245, 40.59202864766121, 38.320354744791985, 37.903935089707375, 40.41412979364395, 40.7936230301857, 44.109876081347466, 44.25082191824913, 46.331415474414825, 41.775691732764244, 38.06013710796833, 38.58300045132637, 38.840208649635315, 37.731367349624634, 37.90227837860584, 41.384115144610405, 41.187118515372276, 41.25038892030716, 43.70031125843525, 44.33746486902237, 44.22713778913021, 42.10215121507645, 40.15497989952564, 40.53937867283821, 40.736371502280235, 39.10087086260319, 41.19531087577343, 37.93629415333271, 39.511936604976654, 37.34832510352135, 39.32077646255493, 39.27968926727772, 43.17769110202789, 46.7652153968811, 51.08437903225422, 55.907395631074905, 52.43417680263519, 41.56400129199028, 47.66914129257202, 55.27250289916992, 49.08688701689243, 48.81038345396519, 49.090892001986504, 48.64063896238804, 44.77407284080982, 45.59751145541668, 40.55898182094097, 38.87069821357727, 39.9578844755888, 38.18881720304489, 39.22898858785629, 37.760386392474174, 40.091242119669914, 38.63485246896744, 39.4161057472229, 40.37077032029629, 40.0450935959816, 40.838946998119354, 39.27606426179409, 38.877477049827576, 41.289401426911354, 39.620986953377724, 39.457664117217064, 37.93223217129707, 41.906944289803505, 45.714096799492836, 48.98569464683533, 52.244152799248695, 46.49512208998203, 45.4145360738039, 49.04598221182823, 47.04724386334419, 50.281292125582695, 53.576908484101295, 52.95713514089584, 53.48247595131397, 51.685214191675186, 54.12356615066528, 56.67970798909664, 53.3379203081131, 41.80091477930546, 40.54321646690369, 41.92394457757473, 51.78180120885372, 55.297057181596756, 58.98249462246895, 55.50900600850582, 59.24495033919811, 51.78587079048157, 43.22380542755127, 20.984354987740517, 9.777206908911467, 8.28760989010334, 20.125276185572147, 16.631418764591217, 6.876410264521837, 0.6449447956401855, 0.21275965293170884, 2.9079644847661257, 32.339316084980965, 56.93022854626179, 43.263771682977676, 38.3634178340435, 56.595219522714615, 68.21213096380234, 56.41601733863354, 15.190178900957108, 0.7073467096779495, 0.19243062502937391, 0.2036588592454791, 0.1587845734320581, 0.11625581566477194, 0.08979820646345615, 0.1638650195673108, 0.12812786299036816, 0.29225205536931753, 0.27849777310620993, 0.09582481667166576, 0.10236163114313968, 0.1247458960278891, 0.09182468522340059, 0.0908193422947079, 0.21239950350718573, 0.10728248584200628, 0.1298521985881962], [0.010991363869834458, 0.032196637184824795, 0.10645932532497682, 0.04793788626557216, 0.02133966419933131, 0.02163801313145086, 0.02676732969121076, 0.03779974453209434, 0.01921583607327193, 0.011123875265184324, 0.016202490151044913, 0.05473157660162542, 0.04675409392802976, 0.06069390568882227, 0.043194620084250346, 0.04058018224895932, 0.02983463531563757, 0.02758830272796331, 0.08361967862583697, 0.6680105079431087, 10.155492760241032, 46.19538277387619, 48.18443924188614, 36.57798483967781, 20.929687321186066, 28.37616104632616, 41.2163807451725, 30.760702192783356, 5.992664135992527, 0.23675581061979756, 0.04415892966790125, 3.760954588651657, 3.9728585304692388, 2.8560044104233384, 2.031157733872533, 6.120198117569089, 14.67526663094759, 29.836183302104473, 47.881766483187675, 50.6567195802927, 46.39428690075874, 42.418146058917046, 35.79878345131874, 37.589973136782646, 35.97080402076244, 43.48409906029701, 48.657004684209824, 48.52169394493103, 43.59390176832676, 46.81937389075756, 46.30634821951389, 42.83213384449482, 38.9134307205677, 33.901062682271004, 35.685671120882034, 33.8231136649847, 35.184185430407524, 35.28697371482849, 37.095665261149406, 35.10791592299938, 35.44173941016197, 36.75554931163788, 36.778443083167076, 33.73410724103451, 34.76295903325081, 34.99920755624771, 35.388447269797325, 39.42397512495518, 39.522382244467735, 42.069906145334244, 41.66181944310665, 42.45682418346405, 41.215415596961975, 37.920031026005745, 36.959814950823784, 35.38697674870491, 35.35820089280605, 36.58121466636658, 34.74285431206226, 35.571810230612755, 34.02490943670273, 34.63935546576977, 35.16265578567982, 36.50205731391907, 42.77848072350025, 46.04193180799484, 47.876184582710266, 51.80664047598839, 37.10973210632801, 45.428257137537, 53.758443742990494, 43.0119363963604, 43.97289723157883, 39.739453196525574, 38.652779906988144, 37.62086547911167, 37.8375868499279, 35.50508201122284, 36.63282349705696, 36.27025455236435, 38.024263232946396, 33.24855409562588, 35.18633991479874, 35.04969164729118, 36.03035442531109, 35.529575496912, 38.32239143550396, 35.40935754776001, 36.37332782149315, 34.53575402498245, 37.253987565636635, 34.29023019969463, 35.06392188370228, 34.60030496120453, 34.38351899385452, 37.189364433288574, 45.57082548737526, 43.9972273260355, 50.00533573329449, 42.70827189087868, 43.983270674943924, 47.85692721605301, 50.97710318863392, 50.47465994954109, 49.56031881272793, 49.17996682226658, 52.033400908112526, 48.53731490671635, 46.87095232307911, 52.63233236968517, 52.603237330913544, 45.40036663413048, 36.55707076191902, 36.58172383904457, 40.36225497722626, 46.24796815216541, 52.04205684363842, 51.97534382343292, 52.7643296867609, 53.116574585437775, 34.07265767455101, 18.555371426045895, 8.076018244028091, 5.111346552148461, 11.435997448861599, 6.175260487943888, 0.7747805630788207, 0.04641924431780353, 0.17418551811715588, 2.1476179221644998, 23.655590750277042, 51.274486631155014, 43.11950862407684, 29.845171719789505, 36.58631019294262, 54.52105902135372, 43.87342996895313, 8.8230524584651, 0.429392188671045, 0.07628635416040197, 0.03206665372999851, 0.027407599045545794, 0.05011899149394594, 0.055085425192373805, 0.030681423959322274, 0.0046372874930966645, 0.04244546282279771, 0.0838081247638911, 0.054491313712787814, 0.02160790976631688, 0.03670731057354715, 0.03748088449356146, 0.055303935732808895, 0.05587927829765249, 0.06068399430660065, 0.042349028153694235, 0.052584676959668286, 0.11381417207303457, 0.048684330977266654, 0.04317328333854675, 0.048557672344031744, 0.03475571451417636, 0.0309156401999644, 0.03170964359014761, 0.018374522624071687, 0.08924601890612394, 0.03721488392329775, 0.08229829953052104, 0.06778336784918793, 0.11140920541947708, 0.03988212556578219, 0.039597408031113446, 0.04389053938211873, 0.04682794875407126, 0.057999312193715014, 0.9643311949912459, 14.891056101769209, 52.9629298299551, 56.00831061601639, 41.6587720066309, 26.40499021857977, 35.08138194680214, 44.88644801080227, 33.85401740670204, 5.916060721501708, 0.22819467703811824, 0.1341736948234029, 4.1120106261223555, 4.148202259093523, 4.202030170708895, 6.854787999764085, 7.88402309641242, 14.090788643807173, 33.174556866288185, 50.098134353756905, 51.838486567139626, 46.92807465791702, 44.66766715049744, 37.62262858450413, 40.69119952619076, 37.74173319339752, 46.4310385286808, 50.92387944459915, 53.31297844648361, 45.057245045900345, 48.35315778851509, 48.856448382139206, 44.453115463256836, 40.95674827694893, 35.300098210573196, 36.862813755869865, 35.959803611040115, 37.557215094566345, 37.72200085222721, 39.391334876418114, 36.94802798330784, 36.20085507631302, 36.738963201642036, 38.52617830038071, 36.33643940091133, 36.843921169638634, 36.711779460310936, 36.69361263513565, 40.50390377640724, 41.58021122217178, 43.250563591718674, 44.64753583073616, 44.94940683245659, 41.689014583826065, 38.42466674745083, 37.32819378376007, 37.244263887405396, 38.38196463882923, 39.534568190574646, 36.60913936793804, 36.896977722644806, 36.753607615828514, 36.79796643555164, 36.89349330961704, 38.895423486828804, 43.91200549900532, 48.173545226454735, 51.11045703291893, 52.43912033736706, 39.327365309000015, 45.52727982401848, 54.17694568634033, 47.75017574429512, 45.63590459525585, 42.34484039247036, 42.00251676142216, 39.53662768006325, 39.361168295145035, 37.728213518857956, 37.30561539530754, 38.14272187650204, 39.352953135967255, 36.10885061323643, 38.08405302464962, 36.858481988310814, 37.119596377015114, 36.991493850946426, 40.23253753781319, 38.47186021506786, 37.3613204061985, 36.52401253581047, 38.03749792277813, 36.52528926730156, 37.532911598682404, 36.093328446149826, 37.05431967973709, 39.349882900714874, 46.91292867064476, 46.13221496343613, 52.05634407699108, 44.44732457399368, 44.78555582463741, 49.290943667292595, 50.511939749121666, 51.72819368541241, 52.00603857636452, 50.90738832950592, 52.90406718850136, 51.46018646657467, 50.04674211144447, 52.98418588936329, 54.30300012230873, 46.56176671385765, 38.596337735652924, 38.66151183843613, 43.26877221465111, 48.050716817379, 55.300864577293396, 54.04708005487919, 54.243388921022415, 54.783282950520515, 35.41714332997799, 19.861467741429806, 9.249856006354094, 9.43773502483964, 15.045744851231575, 5.75816304422915, 2.650608569383621, 0.14551792672136799, 0.21746516606071964, 2.4663479067385197, 27.38586388528347, 52.970119044184685, 45.35851567983627, 34.50498707592487, 44.16958227753639, 62.35684275627136, 49.58039693534374, 11.464530117809772, 0.5574956943746656, 0.0929401777102612, 0.03561423836799804, 0.02393898077571066, 0.05834870047692675, 0.029422016050375532, 0.047105452613322996, 0.004823443177883746, 0.10629178548697382, 0.03972656028054189, 0.07215958263259381, 0.03298131734482013, 0.029311278340173885, 0.0511666591046378, 0.022860172648506705, 0.04280343775462825, 0.05858517099113669, 0.026374141707492527, 0.18890569073846564, 0.2119711210252717, 0.19655013835290447, 0.14995552453910932, 0.08381224368349649, 0.1148975889373105, 0.26807172631379217, 0.1784886684617959, 0.10192228714004159, 0.20425919734407216, 0.11734999367035925, 0.2516059629851952, 0.13362560392124578, 0.17458203277783468, 0.10844131233170629, 0.15241650107782334, 0.14654611295554787, 0.16516906209290028, 0.256658504367806, 1.0001005162484944, 17.808762788772583, 59.43777099251747, 62.82102584838867, 47.86917395889759, 32.0033723115921, 39.9005189538002, 52.67622381448746, 39.375668317079544, 8.07909607887268, 0.46884564973879606, 0.2445525024086237, 7.778629576787353, 10.390017125755548, 8.10745395720005, 8.810355439782143, 12.388121858239174, 17.984326668083668, 33.45372788608074, 52.99348399043083, 56.10583998262882, 50.741873010993004, 45.69447465240955, 40.48436902463436, 43.57294589281082, 39.72163215279579, 48.23506772518158, 52.83988103270531, 54.91373375058174, 47.29549214243889, 49.89270217716694, 51.936688497662544, 48.36729682981968, 42.56446860730648, 37.04891636967659, 40.374832302331924, 36.76445983350277, 39.21475075185299, 39.68149110674858, 41.1602957546711, 38.87702867388725, 37.97696717083454, 40.24965941905975, 40.99766068160534, 37.438517063856125, 37.73638688027859, 36.84791475534439, 38.679123893380165, 42.15784102678299, 43.58318634331226, 47.213997915387154, 47.21160024404526, 47.93450005352497, 45.032804757356644, 40.969633385539055, 39.8846510052681, 38.75472843647003, 40.28207167983055, 40.609629303216934, 37.36961156129837, 39.98624995350838, 38.71899515390396, 39.648805260658264, 39.08392757177353, 40.747998878359795, 47.10021682083607, 50.74132964015007, 53.27105529606342, 53.78840133547783, 42.94697888195515, 48.861224725842476, 56.70004069805145, 50.17609477043152, 47.13236689567566, 44.58263151347637, 42.50869520008564, 41.81114763021469, 41.91630698740482, 39.7282437980175, 39.92233358323574, 39.93554927408695, 42.82672293484211, 37.06456393003464, 39.32619497179985, 39.09031882882118, 39.58269640803337, 38.462866097688675, 41.79834231734276, 39.801367074251175, 39.45436589419842, 38.17274786531925, 39.92655895650387, 39.08732458949089, 38.66307735443115, 37.51093737781048, 38.86184848845005, 42.32695855200291, 49.979994893074036, 50.19360423088074, 54.48406420648098, 48.31924460828304, 45.92437371611595, 49.74580965936184, 53.23045827448368, 55.02971112728119, 52.187034264206886, 53.1643608212471, 53.711349070072174, 54.59141604602337, 50.753245800733566, 55.35046711564064, 57.06938847899437, 51.393640637397766, 41.13634563982487, 41.30918696522713, 44.974185302853584, 50.93089006841183, 56.93242862820625, 57.211934030056, 56.57911978662014, 55.5215909332037, 37.550945430994034, 21.655609868466854, 14.149130713194609, 9.742755107581615, 19.288910664618015, 12.862885482609272, 4.581121578812599, 0.43593318143393844, 0.5389057856518775, 3.5003486601635814, 32.131102457642555, 61.440689116716385, 57.73627549409866, 41.03345476090908, 50.57916574180126, 68.03920984268188, 59.67218421399593, 14.675650410354137, 0.833548684604466, 0.14747700362931937, 0.11559217979083769, 0.09960922063328326, 0.16471390292281285, 0.13184358860598877, 0.17279618798056617, 0.15988160128472373, 0.23401842860039324, 0.18269425607286394, 0.12025128642562777, 0.08171606983523816, 0.1036560999637004, 0.10639397180057131, 0.1197507226606831, 0.11522200395120308, 0.17454649874707684, 0.10280260044964962], [0.05959450667432975, 0.08508765415172093, 0.02159532294172095, 0.05189282834180631, 0.02853623311239062, 0.06099322868976742, 0.037297277158359066, 0.035874958557542413, 0.013067934814898763, 0.05050224397564307, 0.013663653044204693, 0.09084375895326957, 0.039630043975193985, 0.06071444462577347, 0.04854856619203929, 0.04330953051976394, 0.07339029354625382, 0.032497622596565634, 0.038635900054941885, 0.2316092688124627, 5.4057443048805, 37.63737939298153, 46.3946782797575, 38.81180137395859, 25.075213573873043, 30.32093469053507, 36.48419447243214, 35.57719834148884, 8.953506108373404, 0.1715814258204773, 0.23036361846607178, 1.4507340104319155, 3.9613130874931812, 2.5292554311454296, 3.3124926779419184, 2.451195032335818, 6.62672471255064, 22.964744120836258, 42.1433562040329, 49.63239334523678, 45.418294072151184, 46.07984997332096, 38.58889773488045, 38.15467223525047, 35.85776388645172, 43.8020583987236, 48.67767937481403, 49.17171746492386, 49.84262466430664, 48.711030185222626, 46.550143137574196, 44.684097468853, 40.296746492385864, 35.81364445388317, 33.87579023838043, 34.54580448567867, 34.790370762348175, 35.27427859604359, 34.34349574148655, 34.98553588986397, 35.75560636818409, 37.82611906528473, 35.64523369073868, 37.361890375614166, 33.83948318660259, 35.25974437594414, 35.46057119965553, 37.153330966830254, 38.74574951827526, 41.723444536328316, 42.39456072449684, 44.34328615665436, 43.04290473461151, 40.724846720695496, 34.54876072704792, 36.90043553709984, 35.21816320717335, 34.88822691142559, 36.455973386764526, 34.58093360066414, 34.459488317370415, 34.32521492242813, 34.85792353749275, 38.15219856798649, 42.04133927822113, 45.584276765584946, 44.90359269082546, 51.805720925331116, 38.450516760349274, 42.99108311533928, 49.12503696978092, 43.78418415784836, 42.288386821746826, 37.40792490541935, 37.073394656181335, 34.701694920659065, 35.66872023046017, 34.65248756110668, 34.91834029555321, 37.2022495418787, 34.95019778609276, 35.411162450909615, 35.64843691885471, 36.94278426468372, 36.83871924877167, 36.08420513570309, 35.38579121232033, 37.050079107284546, 36.43748737871647, 36.78631626069546, 36.07488043606281, 36.82482339441776, 34.10430617630482, 34.030601531267166, 36.25513516366482, 37.584896609187126, 45.46468958258629, 47.713435515761375, 42.886178344488144, 50.08086808025837, 45.33557251095772, 51.660466119647026, 49.88991692662239, 49.22008506953716, 47.53854990005493, 50.10927155613899, 45.70836290717125, 52.937387600541115, 49.74151208996773, 49.28819641470909, 49.014831483364105, 51.06805510818958, 43.090010806918144, 37.50715658068657, 37.55229435861111, 42.59614750742912, 46.66275009512901, 52.651285752654076, 51.812666952610016, 51.9182974845171, 33.33565682172775, 13.042547442018986, 6.293591363355517, 12.339389473199844, 19.516195468604565, 5.293156821280718, 2.54051280207932, 0.04460032570932526, 0.06869440607260913, 2.8413153486326337, 23.607504330575466, 40.81789992749691, 32.835691049695015, 37.029480412602425, 41.070255786180496, 51.77210032939911, 37.94295899569988, 7.407804625108838, 0.1937223330605775, 0.02590182779385941, 0.09135537329711951, 0.0623798870947212, 0.04716415649454575, 0.02677085118193645, 0.02493078136467375, 0.061038046987960115, 0.039550470901303925, 0.019049314832955133, 0.002625777619869041, 0.026820100101758726, 0.023830538157199044, 0.05265678402793128, 0.10233396387775429, 0.04391088164993562, 0.013777703516097972, 0.0477919392142212, 0.014693567554786569, 0.05118207722262014, 0.06152401641884353, 0.031804211757844314, 0.017461818279116414, 0.03396906024136115, 0.03139850188745186, 0.017178058114950545, 0.002861618236238428, 0.10558148336713202, 0.047224340960383415, 0.07159136468544602, 0.01951210699189687, 0.06069862203730736, 0.0373381694953423, 0.051346303371246904, 0.052658672793768346, 0.06209135121025611, 0.05972063838271424, 0.22494429285870865, 7.535684863105416, 44.1724207252264, 52.717124819755554, 44.12051551043987, 26.56440496444702, 31.8911225348711, 43.957048282027245, 39.77543726563454, 10.316086392849684, 0.11019830984878354, 0.337539836182259, 1.891831203829497, 1.8453130312263966, 5.12978601269424, 6.086261188611388, 6.004297211766243, 10.037165209650993, 29.194321744143963, 47.32335604727268, 52.941153198480606, 48.564076870679855, 48.105107098817825, 41.13650143146515, 41.19584284722805, 37.47599445283413, 44.93051424622536, 51.29103474318981, 50.04475861787796, 49.34404581785202, 48.45317222177982, 50.23385547101498, 47.270827665925026, 42.053863406181335, 38.149622306227684, 35.650367215275764, 38.243538066744804, 36.03233031928539, 36.387140080332756, 36.638716980814934, 37.747695073485374, 37.57497154176235, 39.222395941615105, 37.09553986787796, 36.73317611217499, 36.15621507167816, 37.45931334793568, 36.206691563129425, 38.92527848482132, 40.15903428196907, 44.680468663573265, 43.521454855799675, 47.24714733660221, 45.44999577105045, 41.792859211564064, 36.578349620103836, 39.71773736178875, 35.92499367892742, 37.464507669210434, 37.3511977493763, 36.90901167690754, 36.401469111442566, 36.07441686093807, 37.91457451879978, 40.505511090159416, 43.66862095892429, 48.51993463933468, 47.3122264444828, 54.75899085402489, 40.76034061610699, 45.2787883579731, 51.55175395309925, 46.4245218783617, 44.7584442794323, 40.65051890909672, 38.66010971367359, 37.81879685819149, 37.264801785349846, 37.45215833187103, 36.93366475403309, 37.997953444719315, 37.69367717206478, 37.36856661736965, 37.28402875363827, 38.303650841116905, 38.30934673547745, 36.77230641245842, 37.37384833395481, 37.90314853191376, 37.266070917248726, 38.00189383327961, 37.904166877269745, 39.591283947229385, 35.9862045943737, 35.25116063654423, 37.48758003115654, 40.48327088356018, 48.079766258597374, 49.577535688877106, 46.86538942158222, 52.08689823746681, 47.70493917167187, 53.54599714279175, 52.056382074952126, 51.13942667841911, 49.100095108151436, 53.05710397660732, 49.81685824692249, 54.61451880633831, 51.00476950407028, 49.86655957996845, 51.61610350012779, 53.96004192531109, 43.3385668694973, 39.8514673858881, 39.12784941494465, 45.26366136968136, 49.86993379890919, 55.42052775621414, 53.02752636373043, 51.99291408061981, 34.61725205183029, 17.830372229218483, 8.027179464697838, 13.977041747421026, 11.47537188604474, 3.7712403992190957, 2.720213234424591, 0.21525331365410239, 0.0540554281178629, 3.1118824426084757, 27.066635414958, 51.7218404263258, 42.31877379119396, 40.006898045539856, 43.72905671596527, 58.51221285760403, 47.03008018434048, 9.65848607942462, 0.4709616315085441, 0.015008465452410746, 0.06180586184200365, 0.02698853237234289, 0.03607828475651331, 0.03598950162995607, 0.03581136763386894, 0.05641061521600932, 0.0621301061619306, 0.040249826342915185, 0.055546488147228956, 0.0344866266095778, 0.03941749288060237, 0.024514083997928537, 0.05884020632947795, 0.030360343043867033, 0.06258021501707844, 0.06877437990624458, 0.2539360988885164, 0.125632792187389, 0.1549814228201285, 0.10336197199649177, 0.13717590481974185, 0.12761578109348193, 0.13314492971403524, 0.09066361002624035, 0.10821585528901778, 0.15365167229902, 0.2351275534601882, 0.16615807777270675, 0.10163526152609847, 0.16934500832576305, 0.15164491982432082, 0.16129806434037164, 0.14066267787711695, 0.08556054322980344, 0.10866777127375826, 0.43981980881653726, 11.536830738186836, 50.13435021042824, 59.41505201160908, 52.9502347111702, 34.933292493224144, 39.928751438856125, 48.16938824951649, 43.42481844127178, 12.467625942081213, 0.3307572001358494, 0.5948396748863161, 4.087944617494941, 8.956447150558233, 8.227051589637995, 11.048520840704441, 7.062286315485835, 9.147284310311079, 27.131376340985298, 47.18255840241909, 53.196864277124405, 51.08456902205944, 50.92673309147358, 43.0924578756094, 42.32817828655243, 40.21095849573612, 47.91741617023945, 54.40910562872887, 51.307210475206375, 48.70655782520771, 49.413620084524155, 50.864439234137535, 49.12277229130268, 45.45096851885319, 39.92124684154987, 38.19702856242657, 39.21699643135071, 38.92062373459339, 37.3367927223444, 37.381877303123474, 39.40965749323368, 39.35094304382801, 40.66317602992058, 39.4866793602705, 39.64410871267319, 37.28775255382061, 39.38841663300991, 38.708724305033684, 41.777888014912605, 41.909379959106445, 46.06038361787796, 46.3021494448185, 49.09682348370552, 46.80700935423374, 43.485087007284164, 38.45866732299328, 41.23410299420357, 38.93507435917854, 38.54132428765297, 39.42878566682339, 37.81615599989891, 37.31459051370621, 38.74414220452309, 40.09129911661148, 41.80732503533363, 45.250400081276894, 51.39282368123531, 50.28289943933487, 55.82768350839615, 43.98785702884197, 48.339930698275566, 53.40863071382046, 48.45202848315239, 46.05193667113781, 42.87662945687771, 41.6091238707304, 39.49293002486229, 39.35677573084831, 39.54323172569275, 39.29569400846958, 39.50182914733887, 39.827521070837975, 40.19982509315014, 39.39453810453415, 40.40838070213795, 40.62798231840134, 38.79180304706097, 38.788371831178665, 40.63962109386921, 38.78240995109081, 39.882701709866524, 39.294307082891464, 41.54382437467575, 37.91089251637459, 37.6430980861187, 39.773016795516014, 42.97045402228832, 51.30456201732159, 53.04531700909138, 48.63688476383686, 54.12510506808758, 50.41475236415863, 54.9665243178606, 55.360418781638145, 52.816390693187714, 52.31753446161747, 54.93876300752163, 51.76602065563202, 55.64011037349701, 52.398926094174385, 50.71795329451561, 51.71294890344143, 54.68842104077339, 46.775319054722786, 40.856236070394516, 42.08021879196167, 48.24944615364075, 51.902224346995354, 58.25997859239578, 56.41912177205086, 55.41988179087639, 34.93331529200077, 16.89859002828598, 9.301095306873322, 20.420911721885204, 29.734268970787525, 9.829065576195717, 5.628717765212059, 0.6693360430654138, 0.1823983172653243, 4.3228123895823956, 31.039996705949306, 53.49802851676941, 47.71004989743233, 50.03729581832886, 54.79565508663654, 66.83763831853867, 54.88221824169159, 12.082053031772375, 0.5081867496483028, 0.13938498159404844, 0.16219088283833116, 0.13496782252332196, 0.29249714221805334, 0.16498779994435608, 0.07390288752503693, 0.19212123850593343, 0.16202832281123847, 0.06368436748743989, 0.14233797235647216, 0.1953593030339107, 0.09600707329809666, 0.14405418885871768, 0.23894568061223254, 0.20463583728997037, 0.14086808951105922, 0.12905251962365583], [0.06004842645779718, 0.011349120795784984, 0.013252596927486593, 0.015333587361965328, 0.041071881059906445, 0.02482482679624809, 0.051076165327685885, 0.04242196642735507, 0.034112817957066, 0.07955831999424845, 0.03709198426804505, 0.036593917830032296, 0.0346012253430672, 0.11816622252808884, 0.03408202996070031, 0.027321337365719955, 0.06720158344251104, 0.04636958350602072, 0.014332620321511058, 0.17804435949074104, 5.810275822877884, 30.45391995459795, 53.721931502223015, 42.39505469799042, 36.28495596349239, 38.746859058737755, 30.734343007206917, 37.99610674381256, 15.809994041919708, 0.797829651273787, 0.13295928889419883, 0.8837675023823977, 1.9785512192174792, 2.96618424821645, 7.000486431643367, 6.873179487884045, 8.88129098340869, 19.41093161702156, 35.65016582608223, 49.99133348464966, 48.12647335231304, 45.99693842232227, 42.957318127155304, 38.60749773681164, 37.82618746161461, 42.33646184206009, 47.82311663031578, 52.43899494409561, 47.226183861494064, 45.133993327617645, 46.486146971583366, 46.535160541534424, 44.38149310648441, 37.97292038798332, 33.65035593509674, 33.85667346417904, 34.29808437824249, 33.476359471678734, 34.653597101569176, 34.877579882740974, 35.10210983455181, 35.53153999149799, 35.18179535865784, 36.70007988810539, 34.909273982048035, 37.18678817152977, 38.887774497270584, 38.25418509542942, 37.86050722002983, 39.184416979551315, 41.43696270883083, 41.773438453674316, 41.52879238128662, 42.71361820399761, 38.79804991185665, 34.293327033519745, 35.43379783630371, 35.679044276475906, 34.16197568178177, 35.005351826548576, 36.03418081998825, 36.21570847928524, 35.75142279267311, 40.503048822283745, 40.178436040878296, 46.57028965651989, 46.052438244223595, 51.880778297781944, 41.725390031933784, 40.342290848493576, 52.91292071342468, 45.762905180454254, 45.02264030277729, 40.404846891760826, 37.94783033430576, 35.132272616028786, 36.50993049144745, 34.31851968169212, 35.199578404426575, 35.460453405976295, 36.17324195802212, 38.087598234415054, 35.159600749611855, 36.73711650073528, 37.67055921256542, 35.77131472527981, 37.07393802702427, 39.82812903821468, 38.862323462963104, 38.19117307662964, 36.102854534983635, 36.45255357027054, 35.53818203508854, 35.95439650118351, 34.71049904823303, 37.195136323571205, 42.678401693701744, 50.14701493084431, 46.043478325009346, 51.296681240200996, 49.18582230806351, 45.32840609550476, 46.15365721285343, 43.40958505868912, 45.031718015670776, 46.880140230059624, 46.78636886179447, 45.82171842455864, 51.430760845541954, 50.719226226210594, 48.8895446062088, 52.69443243741989, 48.72819386422634, 39.38329450786114, 37.336386144161224, 39.49332520365715, 44.782272800803185, 50.476480051875114, 52.41529181599617, 54.07259188592434, 31.455354318022728, 14.151111356914043, 4.745140727609396, 12.332933619618416, 9.06784387305379, 2.675499846227467, 1.6707587102428079, 0.1597660340485163, 0.08463824662612751, 3.20533225312829, 28.780679740011692, 40.07318928837776, 31.44486878067255, 34.95530851185322, 43.039272129535675, 53.56106333434582, 39.50488418340683, 7.779275067150593, 0.3332568722544238, 0.08564583084080368, 0.014309039506770205, 0.017888788825075608, 0.027852872808580287, 0.04629548377124593, 0.05890835032914765, 0.03475348807114642, 0.04141666060604621, 0.10030283185187727, 0.11071246975916438, 0.026314675269532017, 0.016448831229354255, 0.016129839459608775, 0.014889584526827093, 0.10823345161043108, 0.06710333051159978, 0.06367481604684144, 0.04806638171430677, 0.04314382378652226, 0.0481378171389224, 0.07323674319195561, 0.04098810371942818, 0.005219590011620312, 0.01525859519460937, 0.0826813219464384, 0.04186913320154417, 0.04742651311971713, 0.012050466120854253, 0.030409545579459518, 0.041067751008085907, 0.11472830505226739, 0.0338121553795645, 0.03638104761193972, 0.030507765113725327, 0.06334712816169485, 0.009298648401454557, 0.3696131135802716, 7.506205569952726, 36.436978206038475, 59.72624011337757, 48.139012679457664, 36.3488495349884, 38.946583941578865, 38.12488563358784, 42.4369702488184, 16.8691074103117, 0.824559316970408, 0.030406923942791764, 0.9440095291938633, 3.6040807189419866, 6.45963485352695, 5.20451090298593, 5.356789631769061, 10.668800566345453, 19.838397279381752, 38.279579132795334, 53.138879388570786, 52.584333345294, 49.442570731043816, 45.49683965742588, 39.710092172026634, 39.33543607592583, 43.018073067069054, 50.66884092986584, 53.970723152160645, 47.028484269976616, 46.58875286579132, 47.239331156015396, 48.01832355558872, 45.43536275625229, 38.93975950777531, 35.54941803216934, 35.81604592502117, 36.31352663040161, 35.261207297444344, 36.68043874204159, 35.13369373977184, 37.38628126680851, 36.20280057191849, 36.61725573241711, 38.30327086150646, 36.461160108447075, 38.345995768904686, 40.10296069085598, 40.52204020321369, 38.867863565683365, 41.933778449893, 43.55557322502136, 44.67966690659523, 46.49757295846939, 44.810151904821396, 40.69147691130638, 36.32130481302738, 36.85014523565769, 37.27143622934818, 36.13546058535576, 36.74518346786499, 38.704677522182465, 38.06168742477894, 38.35554465651512, 42.33495332300663, 42.56672188639641, 48.44519644975662, 48.954179137945175, 53.6718425899744, 43.48541758954525, 43.255469128489494, 54.85835172235966, 49.28631171584129, 47.96329490840435, 42.179978638887405, 38.9912049472332, 36.08577445149422, 37.74362549185753, 36.12969249486923, 35.939866080880165, 37.31992922723293, 37.53348916769028, 39.61214862763882, 37.000195384025574, 38.39855454862118, 39.78755861520767, 37.95494355261326, 37.27471545338631, 41.559889912605286, 40.57815559208393, 40.30373431742191, 37.042137533426285, 38.049121499061584, 37.63425596058369, 37.48915694653988, 38.350050151348114, 39.494187757372856, 45.6326899677515, 53.58386591076851, 48.24679769575596, 54.14818502962589, 51.623524501919746, 47.3567296564579, 49.01236541569233, 45.526633858680725, 46.8660543859005, 48.078147545456886, 47.58853241801262, 49.650176391005516, 53.27062971889973, 50.47087915241718, 50.01347869634628, 54.48552332818508, 50.68762332201004, 40.68070448935032, 39.467946365475655, 43.16237032413483, 48.67100693285465, 52.4295524507761, 55.022255927324295, 54.47139948606491, 32.82449685037136, 19.390861093997955, 7.464651949703693, 15.518382489681244, 12.675812970846891, 3.39518787804991, 3.002439052797854, 0.0683815537195187, 0.15546546637779102, 3.780872644856572, 32.594221606850624, 44.87051546573639, 38.22521165013313, 44.649975299835205, 49.29983898997307, 61.049427911639214, 42.87793278694153, 9.445854239165783, 0.2955739974277094, 0.09041706856805831, 0.03187435584550258, 0.04483712647925131, 0.036516856926027685, 0.012005921489617322, 0.01164450299256714, 0.08606318500824273, 0.04137914133025333, 0.03952866289182566, 0.0263711378647713, 0.010403659907751717, 0.020525825057120528, 0.005063298349341494, 0.011959886996919522, 0.012728020974464016, 0.09022121579619125, 0.034136210451833904, 0.16222570440731943, 0.14964167028665543, 0.07255111006088555, 0.17609595466637984, 0.17133705143351108, 0.17794182436773553, 0.18078803492244333, 0.18372152204392478, 0.27123134583234787, 0.235772836022079, 0.1406181787024252, 0.17360270954668522, 0.22380512586096302, 0.2838636195519939, 0.11481746667413972, 0.14446190994931385, 0.15080985525855795, 0.1318483383511193, 0.12482659716624767, 0.5084826587699354, 9.085900504142046, 43.82201112806797, 67.14610576629639, 55.87641969323158, 47.468561455607414, 49.438007175922394, 42.75146037340164, 47.58591055870056, 20.936270467936993, 1.1817813548259437, 0.40921286679804325, 2.4775036331266165, 7.508139191195369, 10.221806801855564, 15.012770220637321, 16.02776225656271, 11.96328280493617, 20.05525354295969, 42.1417298913002, 54.65242937207222, 54.18722793459892, 51.65643073618412, 49.413224905729294, 42.35223099589348, 41.73575207591057, 46.06745883822441, 51.723637729883194, 56.42460107803345, 48.246151730418205, 46.13465063273907, 47.81085468828678, 50.7043120265007, 47.700922787189484, 41.66005253791809, 36.59584388136864, 36.97582349181175, 37.51621149480343, 37.3688630014658, 38.73844251036644, 37.96293452382088, 37.96974755823612, 37.75010794401169, 37.944642305374146, 39.732328578829765, 38.23656924068928, 40.57713724672794, 42.14153990149498, 42.35189661383629, 40.50415076315403, 43.68573144078255, 46.002805307507515, 46.451595425605774, 47.69437573850155, 47.7449282258749, 43.540826216340065, 38.62705908715725, 39.65419717133045, 39.92138743400574, 37.80875399708748, 38.82495626807213, 41.25051811337471, 39.97695565223694, 40.12765936553478, 44.50085610151291, 46.25750184059143, 50.843996331095695, 51.23267747461796, 54.46886122226715, 46.85612931847572, 44.85806353390217, 56.14137567579746, 51.96861058473587, 49.4785737991333, 44.821840077638626, 42.430700585246086, 38.23310002684593, 40.134650990366936, 38.30496557056904, 37.543288841843605, 38.77566531300545, 39.99835230410099, 42.34558895230293, 39.720667004585266, 40.95920294523239, 42.91321389377117, 39.42400172352791, 40.55396229028702, 44.00917008519173, 41.24593935906887, 43.01145002245903, 39.42504666745663, 40.9965967386961, 40.00168092548847, 39.00453843176365, 39.685180708765984, 41.769045889377594, 47.633290216326714, 55.58368340134621, 52.75153577327728, 54.295028150081635, 54.064570516347885, 50.602485090494156, 51.9486540555954, 47.9009098559618, 48.65084521472454, 50.701655969023705, 51.13338880240917, 50.99427066743374, 55.67128390073776, 52.79709532856941, 50.507702976465225, 56.70715391635895, 54.8398657143116, 43.821707144379616, 41.3534089922905, 45.74113994836807, 50.168263390660286, 56.15529052913189, 57.3595105111599, 58.95136669278145, 34.4677072763443, 17.504655607044697, 11.703571490943432, 18.520048521459103, 17.25896269083023, 8.042910620570183, 6.068692831322551, 0.6431191717274487, 0.264150247676298, 4.8421067744493484, 39.31502357125282, 52.10033431649208, 45.0628687441349, 50.08091747760773, 56.077037528157234, 68.93308907747269, 52.31895938515663, 12.156301997601986, 0.6261739216279238, 0.2101023931754753, 0.20935377397108823, 0.13349025102797896, 0.1423511083703488, 0.15711417712736875, 0.1481502057868056, 0.17221075220732018, 0.26942436466924846, 0.26553720294032246, 0.18211487622465938, 0.16046528558945283, 0.02395930263446644, 0.06709285138640553, 0.0639640235749539, 0.31145423592533916, 0.25059711711946875, 0.1687274524010718], [0.037417278726934455, 0.07795862809871323, 0.04916720194160007, 0.013370956494327402, 0.05925840283452999, 0.06574543775059283, 0.06807508383644745, 0.085101094446145, 0.061612487843376584, 0.03189738097717054, 0.07495641068089753, 0.05355679022613913, 0.0490885825274745, 0.012095961628801888, 0.04566987554426305, 0.02425479244266171, 0.06419655328500085, 0.07488463757908903, 0.05957830559054855, 0.032071277310024016, 2.872989736497402, 26.326387636363506, 51.386128440499306, 46.60823442041874, 35.49097336828709, 31.36122576892376, 30.967449098825455, 41.69496886432171, 22.332887426018715, 1.4731542323715985, 0.12768814049195498, 0.18932797276647761, 1.2908954685553908, 4.136223401874304, 3.5850378032773733, 4.691801564767957, 6.290195770561695, 17.405942603945732, 24.317836314439774, 45.03220818936825, 46.67516402900219, 46.8575656414032, 45.23526169359684, 40.77636815607548, 38.67959886789322, 46.333524361252785, 48.458199352025986, 51.24587416648865, 46.27488970756531, 44.08576637506485, 50.55692933499813, 48.19804251194, 44.48406100273132, 40.37799373269081, 33.636528477072716, 33.468402698636055, 33.750431165099144, 34.41070273518562, 34.905561581254005, 33.69447536766529, 35.06197638809681, 33.940173983573914, 35.250719860196114, 35.188661590218544, 38.61239567399025, 42.35109105706215, 42.62819878757, 41.248986795544624, 38.101414293050766, 39.128145799040794, 39.400477185845375, 42.79140003025532, 43.09569910168648, 42.47972935438156, 38.44755671918392, 36.91474936902523, 34.3472271412611, 34.87164840102196, 33.56772556900978, 35.42722798883915, 33.985684141516685, 35.86397275328636, 35.8817557990551, 40.72778396308422, 39.68959987163544, 43.52915704250336, 44.554653614759445, 53.855258747935295, 36.13316170871258, 42.11088314652443, 47.89661608636379, 48.90727065503597, 49.02221068739891, 43.492701798677444, 45.0362853705883, 39.71249744296074, 37.05293655395508, 34.50616121292114, 34.218208864331245, 35.13593561947346, 37.317136377096176, 36.539622098207474, 34.8110606521368, 36.09972730278969, 35.50636254251003, 37.40893565118313, 41.88886485993862, 44.344570487737656, 43.49041432142258, 40.15306480228901, 37.50569745898247, 35.84380343556404, 35.24932913482189, 35.5541867762804, 35.28924599289894, 34.32835355401039, 38.21928396821022, 45.861221104860306, 47.037546783685684, 45.90044640004635, 45.129053592681885, 42.97422342002392, 42.34280750155449, 41.1645021289587, 40.582479760050774, 41.27701789140701, 43.92368987202644, 46.587631925940514, 48.112661093473434, 53.36945481598377, 50.55872663855553, 49.51672375202179, 51.581684947013855, 45.335397720336914, 36.67988397181034, 40.00441677868366, 43.546932488679886, 49.35808606445789, 53.6356533318758, 52.84225590527058, 36.38446122407913, 20.76642908155918, 6.029585329815745, 15.743806343525648, 8.994342517107725, 0.8526975789573044, 2.686389349400997, 0.018141851905966178, 0.22409104567486793, 4.153675865381956, 30.200543850660324, 48.09971138834953, 37.295876517891884, 34.37473766505718, 41.45534612238407, 49.577809274196625, 37.11559139192104, 6.325505375862122, 0.1782758056651801, 0.02887696238758508, 0.021860128654225264, 0.11014414791134186, 0.022547092085005715, 0.06344359993818216, 0.03835219184111338, 0.04066295769007411, 0.044571856924449094, 0.04274118640751112, 0.10166495485464111, 0.08307869007694535, 0.05804065353004262, 0.027300933870719746, 0.04214748310914729, 0.011491530585772125, 0.0018004165190177446, 0.05464943198603578, 0.017023539257934317, 0.06424287072150037, 0.06599862885195762, 0.03573266287276056, 0.023765551995893475, 0.03500806327792816, 0.07051819688058458, 0.02735330352152232, 0.020232405840943102, 0.05005210172384977, 0.08162441459717229, 0.12415088654961437, 0.053207498422125354, 0.03629058723163325, 0.08619217027444392, 0.050012489591608755, 0.05448568823339883, 0.004113747299925308, 0.01753143544192426, 0.056842456106096506, 3.884456749074161, 31.032906286418438, 57.667890563607216, 51.76382817327976, 41.25761613249779, 39.08125251531601, 35.570438504219055, 44.338798597455025, 24.723493047058582, 1.8425776530057192, 0.15595281991409138, 0.3534014616161585, 1.2084002327173948, 6.187884835526347, 6.6037435457110405, 5.213578166440129, 9.742353279143572, 16.35372966527939, 30.37819191813469, 50.066174268722534, 49.624998942017555, 48.89958366751671, 46.369797214865685, 43.24639901518822, 40.464332699775696, 45.88264435529709, 49.83757093548775, 52.488776072859764, 45.29442451894283, 43.451576605439186, 51.94207280874252, 50.18023654818535, 46.70683532953262, 42.16846905648708, 35.81143297255039, 34.5646058768034, 36.27992503345013, 35.974398627877235, 35.92648319900036, 34.876405745744705, 36.48131802678108, 36.25102758407593, 37.39067003130913, 36.68666660785675, 38.81834842264652, 43.58379051089287, 43.82505476474762, 42.539321556687355, 40.63838616013527, 40.89788943529129, 42.194436863064766, 44.67658147215843, 45.13147406280041, 43.341435715556145, 40.15881769359112, 39.418074041604996, 35.674446523189545, 36.06541894376278, 35.23948386311531, 37.205958142876625, 36.067208647727966, 37.77778185904026, 37.728152722120285, 41.88348814845085, 42.10866026580334, 47.182752192020416, 47.04885117709637, 54.866821467876434, 40.14291934669018, 42.9712899774313, 51.76770396530628, 51.51990786194801, 49.49710540473461, 45.83903029561043, 45.55487394332886, 40.90716473758221, 37.87197880446911, 35.36498732864857, 36.075970977544785, 36.710046753287315, 38.73187266290188, 38.2648017257452, 38.27486738562584, 37.830044254660606, 37.05763690173626, 38.35125848650932, 43.60040321946144, 46.70005649328232, 45.22106945514679, 42.2177030146122, 38.585679307579994, 37.83070161938667, 37.258190140128136, 37.173697873950005, 37.08840765058994, 36.708203852176666, 40.4422976821661, 48.029593750834465, 49.266822561621666, 49.38577897846699, 48.27277310192585, 45.77557750046253, 45.98010152578354, 44.297312423586845, 43.3062420040369, 44.321631118655205, 46.12399600446224, 49.05019998550415, 51.69175744056702, 54.5728350430727, 51.760408356785774, 51.772423312067986, 53.96812029182911, 46.25864177942276, 38.717935010790825, 42.406628876924515, 45.54162785410881, 52.682155296206474, 54.59282577037811, 57.80768506228924, 35.73925964534283, 19.831187166273594, 8.700490985065699, 15.198263917118311, 7.929552728310227, 2.73164302110672, 2.0427506742998958, 0.14987599599407986, 0.3669193253153935, 4.669627379626036, 33.28541211783886, 49.17489789426327, 40.91279223561287, 38.492519706487656, 48.7079219520092, 55.53869001567364, 45.563738867640495, 8.47498543560505, 0.28831650561187416, 0.04418752090714406, 0.03994529717601836, 0.06029612566635478, 0.052254391557653435, 0.0013160751745999733, 0.023243842588271946, 0.015195257528830552, 0.019191534447600134, 0.0523963087471202, 0.06140461970062461, 0.04121358673728537, 0.049069928645621985, 0.018755415076157078, 0.02773383974272292, 0.035517410360625945, 0.08954054763307795, 0.015375221846625209, 0.282652672030963, 0.1868956579710357, 0.18922095507150516, 0.0643558701267466, 0.08142232778482139, 0.1050445692089852, 0.1675147088826634, 0.1563750277273357, 0.21335685916710645, 0.12103519475203939, 0.22540647274581715, 0.15371168236015365, 0.12083310793968849, 0.16060537338489667, 0.17927690350916237, 0.11605271211010404, 0.12863117270171642, 0.1348781562410295, 0.11560994680621661, 0.22237015364225954, 4.887501513585448, 35.682635083794594, 64.77617293596268, 58.301844745874405, 46.7016714066267, 42.617707550525665, 40.30032590031624, 52.17156529426575, 29.369414448738098, 2.616062010638416, 0.4885404382366687, 0.853180984267965, 3.815902965143323, 11.573428474366665, 11.514226701110601, 11.071164775639772, 8.985842373222113, 20.427943244576454, 27.396774999797344, 50.17816945910454, 50.54765783250332, 51.74942694604397, 50.80658733844757, 46.71014875173569, 42.31038764119148, 51.54857352375984, 53.71751233935356, 53.37847553193569, 46.09271988272667, 45.59519737958908, 55.09640894830227, 53.61202999949455, 48.939584121108055, 43.692821860313416, 36.22249111533165, 35.63242457807064, 37.02784650027752, 37.712649554014206, 38.15424665808678, 37.069655656814575, 37.04095579683781, 37.30078965425491, 38.76760974526405, 39.24977347254753, 42.207071185112, 46.08023755252361, 46.91881075501442, 46.50326505303383, 43.27513687312603, 42.12709307670593, 43.31466995179653, 47.61306770145893, 47.9999515414238, 45.96010319888592, 42.222236171364784, 40.39297632873058, 37.21303716301918, 38.33890914916992, 37.11429946124554, 40.146346762776375, 38.29581566154957, 42.07463689148426, 41.86954669654369, 44.834368005394936, 43.58649596571922, 48.680818006396294, 48.36898773908615, 58.5686170309782, 41.82809852063656, 47.12987042963505, 55.69400668144226, 53.75305563211441, 54.327983781695366, 47.969917953014374, 48.134433925151825, 43.42576839029789, 40.364242270588875, 37.80783824622631, 37.95706383883953, 39.836226403713226, 41.453180238604546, 39.98589277267456, 39.858743995428085, 39.6638448536396, 37.92088218033314, 41.315186843276024, 45.653117671608925, 49.3032968044281, 47.38327123224735, 44.28147867321968, 40.13126917183399, 40.124532133340836, 40.013927668333054, 39.412138760089874, 39.367745742201805, 38.06451067328453, 43.26910279691219, 50.81557385623455, 50.1471783220768, 51.792505234479904, 50.72408236563206, 47.67501957714558, 47.135167345404625, 46.42255358397961, 45.07329538464546, 45.569655150175095, 47.97752134501934, 51.893264427781105, 53.52296657860279, 56.982680931687355, 53.950675427913666, 52.10486747324467, 57.05010451376438, 48.89036916196346, 41.89435936510563, 44.335618168115616, 49.14014495909214, 53.4650082886219, 58.11598911881447, 58.57085131108761, 40.61060585081577, 24.69722505658865, 15.716858189553022, 28.158852607011795, 18.705915547907352, 6.542324116453528, 4.651534175500274, 0.4663816897664219, 0.6971604062709957, 5.819758689031005, 40.56288041174412, 60.22588290274143, 47.67527036368847, 48.304626792669296, 54.845804795622826, 64.8961628973484, 51.53503865003586, 10.968120954930782, 0.3570931119611487, 0.12637161504244432, 0.09984660398913547, 0.16758255602326244, 0.09887368549243547, 0.12768987711751834, 0.0986244500381872, 0.16666536539560184, 0.1553792436607182, 0.11391392414225265, 0.1717082885443233, 0.23275615414604545, 0.1696148532209918, 0.22017292154487222, 0.14341187488753349, 0.06983680883422494, 0.20645944256102666, 0.15431187202921137], [0.011856694145535585, 0.04044491841341369, 0.016565634141443297, 0.05771417163487058, 0.02032167321885936, 0.035708023569895886, 0.0806747104797978, 0.018202728424512316, 0.07239126629428938, 0.06659712642431259, 0.06489729654276744, 0.09350323030957952, 0.0232978765052394, 0.008044280602916842, 0.040655977791175246, 0.08971704519353807, 0.03154691286908928, 0.09827805261011235, 0.04678362398408353, 0.04838093358557671, 1.715898981783539, 21.757083423435688, 45.75044184923172, 42.71511152386665, 28.82133185863495, 26.007732935249805, 27.15283188968897, 39.17149767279625, 27.58699469268322, 4.5834779273718596, 0.09274082200136036, 0.28476491337642074, 1.86711780494079, 5.701158503070474, 3.0378830758854747, 1.3765837205573916, 7.177999606356025, 9.967589993029833, 19.815581403672695, 38.27195294201374, 51.37539781630039, 48.797365352511406, 45.523734614253044, 42.08237327635288, 45.512107238173485, 47.50742197036743, 52.189990505576134, 49.43697363138199, 49.76140782237053, 52.17674061655998, 47.283853366971016, 45.24657368659973, 41.88782371580601, 36.998926252126694, 34.05039466917515, 34.99731905758381, 33.806109577417374, 32.67521046102047, 35.21866858005524, 35.44072866439819, 36.524711698293686, 34.06895287334919, 35.434341207146645, 37.326894253492355, 43.49702976644039, 45.45523189008236, 45.330150201916695, 44.30494241416454, 38.98444510996342, 36.988989785313606, 37.38970868289471, 39.648660868406296, 40.78611083328724, 42.51107007265091, 37.66066834330559, 37.014782801270485, 35.80821454524994, 35.91704070568085, 34.36464920639992, 33.26550118625164, 32.56478078663349, 38.58381360769272, 34.62991677224636, 39.00679551064968, 39.110704734921455, 46.09138235449791, 45.35150125622749, 53.89919959008694, 41.716403514146805, 33.67859221994877, 42.876952439546585, 47.02507585287094, 50.830104276537895, 45.87816819548607, 46.735915169119835, 44.045853316783905, 40.57300306856632, 34.499405175447464, 39.41695310175419, 38.12230557203293, 35.25622196495533, 35.933528020977974, 35.6717524677515, 35.8000373840332, 37.00847513973713, 40.093670189380646, 45.56026205420494, 47.29763902723789, 47.70517855882645, 44.469853565096855, 39.57848243415356, 37.23505698144436, 37.155595645308495, 34.838658571243286, 35.34721188247204, 34.616362899541855, 34.791674092411995, 37.98526592552662, 40.6750275939703, 41.764862313866615, 41.245908960700035, 39.27887611091137, 38.01550850272179, 38.066554963588715, 37.251517698168755, 38.342769742012024, 39.64061290025711, 45.11267267167568, 46.930700317025185, 52.1558341383934, 52.33681842684746, 49.85156558454037, 49.970047026872635, 50.3567598760128, 42.192096188664436, 41.09062649309635, 44.22538608312607, 48.17860275506973, 53.79044562578201, 55.04010356962681, 34.15227860212326, 20.71961559355259, 6.360336681827903, 14.599113967269659, 11.432993710041046, 2.511518457904458, 0.9068592195399106, 0.0982514169299975, 0.28833470307290554, 4.483443070203066, 32.29555003345013, 49.36495989561081, 38.90484698116779, 34.071958512067795, 40.57817079126835, 51.625280007719994, 32.79752969741821, 4.930746043100953, 0.19327913731103763, 0.02970513240143191, 0.020488665722950827, 0.03697371561429463, 0.09796774582355283, 0.02630373230203986, 0.009360319945699302, 0.025186228594975546, 0.14483562583336607, 0.0458136332599679, 0.018194496151409112, 0.07820672064553946, 0.016733120173739735, 0.05757128594268579, 0.04203869910270441, 0.03370206519321073, 0.02840508819645038, 0.02660874386492651, 0.0884491675242316, 0.050547811842989177, 0.021379536083259154, 0.018812885136867408, 0.0495967310416745, 0.03861782875901554, 0.1085733255604282, 0.04942645267874468, 0.03261429563281126, 0.10988660782459192, 0.05321318698406685, 0.009709075548016699, 0.01937889333930798, 0.030253930199251045, 0.03296568029327318, 0.05690518984920345, 0.049037760254577734, 0.06919527411810122, 0.056387946315226145, 0.0747046222386416, 2.376669868826866, 26.451328732073307, 53.5758863389492, 50.030038207769394, 34.435682594776154, 32.08786837756634, 33.52488286793232, 43.67547579109669, 30.197219029068947, 4.601507009938359, 0.13541318534407765, 0.3424975014058873, 1.4745437703095376, 3.6404357431456447, 6.557832509279251, 5.231366911903024, 7.724545653909445, 11.375645287334919, 23.97503960877657, 41.26993507146835, 52.1954508125782, 50.58526821434498, 47.216433584690094, 44.14648711681366, 46.054417937994, 49.35708671808243, 55.20417116582394, 50.385695323348045, 48.9841291308403, 53.515184596180916, 50.017897859215736, 47.807119488716125, 44.26907233893871, 38.38638000190258, 34.741106405854225, 36.73965856432915, 35.919901952147484, 35.80253005027771, 36.6199915856123, 35.51346056163311, 36.12173572182655, 36.03291168808937, 36.66900895535946, 39.39408592879772, 44.64297227561474, 47.78895266354084, 47.63473033905029, 45.5873242020607, 39.323918893933296, 39.976875856518745, 39.74511109292507, 42.09256812930107, 42.564943581819534, 43.77955600619316, 39.78365622460842, 39.1756584495306, 37.53172606229782, 38.147186636924744, 36.247698962688446, 35.18556855618954, 33.45254994928837, 40.631839111447334, 37.672405913472176, 41.49118199944496, 41.53985358774662, 47.20800183713436, 46.82382345199585, 55.18616773188114, 43.19238871335983, 38.14237989485264, 45.76890125870705, 49.766104370355606, 52.4210637062788, 47.48221792280674, 50.46058550477028, 45.67723497748375, 41.37003690004349, 36.1766541749239, 39.30083513259888, 39.11915548145771, 36.65195547044277, 36.05714678764343, 37.92432479560375, 37.80141659080982, 38.97162839770317, 42.34392464160919, 47.01565235853195, 48.79027113318443, 49.73387449979782, 46.03427901864052, 40.74393689632416, 38.26009377837181, 37.61815622448921, 36.63983032107353, 36.81352660059929, 36.14471308887005, 36.664160415530205, 40.399150997400284, 43.195683136582375, 44.73951369524002, 44.24895241856575, 41.94928161799908, 40.66987507045269, 39.8919428139925, 39.52077113091946, 40.29869958758354, 42.69597955048084, 45.89488349854946, 47.85696521401405, 53.5576169192791, 53.9907518774271, 50.18321558833122, 54.190282970666885, 50.86191236972809, 45.28310492634773, 42.750160843133926, 47.195150926709175, 49.83434870839119, 56.890942454338074, 55.66148802638054, 36.51291713118553, 14.553518313914537, 5.745128318667412, 11.902246680110693, 12.429897766560316, 3.0785952787846327, 1.7415002267807722, 0.1586923244758509, 0.1818352349800989, 5.040798112750053, 36.42644137144089, 56.15560971200466, 41.34069487452507, 38.93847897648811, 47.83836141228676, 57.22734980285168, 38.68986211717129, 6.3095091842114925, 0.08084653993137181, 0.027156246615049895, 0.025928799295797944, 0.034014913835562766, 0.08566103744669817, 0.0213976519080461, 0.046779735130257905, 0.01930791804625187, 0.059206805017311126, 0.040486615980626084, 0.03809897847531829, 0.022779486353101674, 0.054505106527358294, 0.0359553665475687, 0.05512297786481213, 0.046247708014561795, 0.029899734654463828, 0.015079398071975447, 0.1346949496655725, 0.19400123215746135, 0.09723860057420097, 0.1371202289010398, 0.14280876115662977, 0.12571433937409893, 0.279712401679717, 0.06309049349511042, 0.20767185953445733, 0.1679117133608088, 0.14907060249242932, 0.21254315361147746, 0.10616812141961418, 0.0785819134034682, 0.12339926164713688, 0.17617364268517122, 0.11674169974867254, 0.2911434054840356, 0.15101090306416154, 0.2215818443801254, 3.197159841656685, 30.556301660835743, 61.62900321185589, 57.50707559287548, 38.2732068747282, 35.06810925900936, 37.12205484509468, 50.30209220945835, 35.53997553884983, 7.232203222811222, 0.24718769069295377, 1.3867795234546065, 4.77538900449872, 13.909745458513498, 10.871706828474998, 6.866884650662541, 13.907493129372597, 13.304944261908531, 25.709350146353245, 41.9065111130476, 54.616889879107475, 51.60750076174736, 51.232468485832214, 47.47667782008648, 49.37879875302315, 50.72668522596359, 57.07449160516262, 50.304812863469124, 52.15241052210331, 55.800951942801476, 52.4337512254715, 50.267031490802765, 46.503732427954674, 40.44427737593651, 36.96693576872349, 37.935636788606644, 38.1244258582592, 36.783056035637856, 40.293163284659386, 38.621002212166786, 39.31478038430214, 37.547233030200005, 38.073132410645485, 40.38703724741936, 47.64818921685219, 49.70794469118118, 50.728246942162514, 48.23187589645386, 43.43484230339527, 40.80645874142647, 41.66097208857536, 44.15022611618042, 43.78082513809204, 46.207872703671455, 40.84002614021301, 40.39844423532486, 39.64887745678425, 38.47706213593483, 37.95435458421707, 37.04023763537407, 35.69137841463089, 42.45723836123943, 39.311200976371765, 42.474896013736725, 43.97992305457592, 48.84645491838455, 50.19885554909706, 55.38510225713253, 48.417218551039696, 40.82741841673851, 45.980888083577156, 51.8924018740654, 54.25815872848034, 49.56900134682655, 51.94113425910473, 47.49408848583698, 43.514550626277924, 37.995551973581314, 43.64244416356087, 42.0722696185112, 38.93780641257763, 38.322748616337776, 39.33986283838749, 39.55981783568859, 39.775539860129356, 44.52025406062603, 48.38822230696678, 51.46305151283741, 53.06349903345108, 47.935943976044655, 44.619113355875015, 41.72719493508339, 41.12375311553478, 38.52503456175327, 38.312173783779144, 37.97016553580761, 38.223900720477104, 42.23403833806515, 44.91537965834141, 46.12041659653187, 46.48460425436497, 43.55798229575157, 42.32896864414215, 42.31719687581062, 42.032785937190056, 41.80488936603069, 44.28589403629303, 49.65989246964455, 50.39951518177986, 56.70336551964283, 56.19494140148163, 52.821725606918335, 56.089386865496635, 55.224313884973526, 46.326646730303764, 45.58480493724346, 48.74111317098141, 52.037481889128685, 58.37663613259792, 57.225126922130585, 38.11346724629402, 22.623328641057014, 11.860828902572393, 26.20755661278963, 23.074009157717228, 9.19250663369894, 3.4099560230970383, 0.24162916786735877, 0.5314004165120423, 7.385287983343005, 41.256996765732765, 62.59272649884224, 49.63281512260437, 45.73397733271122, 55.963818803429604, 65.46265929937363, 45.35338215529919, 8.6539501324296, 0.2828594046877697, 0.1261893435730599, 0.11901855687028728, 0.15399178373627365, 0.22916315007023513, 0.20122511952649802, 0.16839421325130388, 0.1326334266923368, 0.264682041015476, 0.11784055328462273, 0.08088324655545875, 0.1310629234649241, 0.16138060600496829, 0.16073792095994577, 0.10351170771173202, 0.07410558289848268, 0.11077046117861755, 0.08798821960226633], [0.06299538727034815, 0.034699841926340014, 0.03966710311942734, 0.04712599897175096, 0.07085399643983692, 0.051554267993196845, 0.06778769457014278, 0.055670790461590514, 0.06385210028383881, 0.008326262395712547, 0.0591941736638546, 0.03457392544078175, 0.0722405657870695, 0.058416480824234895, 0.0037898065647823387, 0.07756828068522736, 0.030022144492249936, 0.03465057074208744, 0.046143313811626285, 0.02263958223920781, 0.6034323794301599, 14.054981265217066, 43.19075480103493, 45.63605658710003, 31.586365588009357, 26.107184998691082, 39.20348435640335, 39.36866529285908, 30.867271274328232, 6.78708465769887, 0.1721931781503372, 0.08834286971250549, 0.33238576899748296, 2.7440875908359885, 5.775854894891381, 4.995220508426428, 5.45253736898303, 8.298639748245478, 18.59682910144329, 30.761127769947052, 45.78119359910488, 49.22636993229389, 46.14797651767731, 44.722357615828514, 48.32061253488064, 51.27089962363243, 50.04468262195587, 49.252569526433945, 51.734752133488655, 46.94327384233475, 46.35719709098339, 42.05772019922733, 36.33385933935642, 35.47792486846447, 33.9045736938715, 33.039162531495094, 33.68697077035904, 38.682064935564995, 37.5409671664238, 38.37407246232033, 35.13350374996662, 36.34103715419769, 35.22398829460144, 38.50935660302639, 43.841249495744705, 48.41623440384865, 50.10954514145851, 49.778210520744324, 44.291342943906784, 36.52945004403591, 34.95140612125397, 35.67625902593136, 39.32097025215626, 39.85492900013924, 37.697188183665276, 36.22631751000881, 35.35944722592831, 34.38539609313011, 34.07069317996502, 35.48514448106289, 34.16466973721981, 37.03591726720333, 35.145203322172165, 36.14531725645065, 37.29428060352802, 45.05801260471344, 44.38774757087231, 49.628281965851784, 43.80378730595112, 33.857638612389565, 35.572205409407616, 46.024141162633896, 48.228022903203964, 48.597940653562546, 47.955110147595406, 47.35083997249603, 43.021907061338425, 37.23580554127693, 39.81121614575386, 35.99836774170399, 35.91334730386734, 34.72871907055378, 35.24407021701336, 37.64445461332798, 37.88474231958389, 45.096914917230606, 50.31030356884003, 51.22959963977337, 49.60166059434414, 45.93348942697048, 40.713956505060196, 36.48805886507034, 36.181643307209015, 36.94024600088596, 34.263631626963615, 36.45368590950966, 37.097652554512024, 34.81703393161297, 34.81854245066643, 34.898186177015305, 35.29775753617287, 36.09789200127125, 33.895670771598816, 35.84809720516205, 35.95050171017647, 36.8849665671587, 36.85948133468628, 41.06012932956219, 48.37076224386692, 49.27209287881851, 53.95303510129452, 51.810797452926636, 52.086712047457695, 52.68908992409706, 44.75497506558895, 42.7780931442976, 44.12205062806606, 48.21067303419113, 50.44281005859375, 55.300268009305, 36.09341584146023, 15.088812690228224, 6.323740370571613, 10.880128126591444, 4.474788559600711, 1.1183455400168896, 1.546873007901013, 0.10574365747743286, 0.17593989585293457, 6.7172980774194, 36.4996862411499, 44.847325310111046, 36.19476020336151, 29.904452338814735, 46.828827783465385, 52.66887880861759, 29.140566028654575, 6.040111239999533, 0.07546621418441646, 0.03997156549303327, 0.017356989919790067, 0.09616325827664696, 0.0434127409971552, 0.015824562578927726, 0.09579431440215558, 0.030901361278665718, 0.02991703040606808, 0.02803193263389403, 0.029089875279169064, 0.010497428411326837, 0.08008534132386558, 0.11205181624973193, 0.054500438418472186, 0.06414446193957701, 0.01982318932277849, 0.03000938697368838, 0.008153451453836169, 0.052978694293415174, 0.05162815250514541, 0.05350053543224931, 0.07024161328445189, 0.018542626494308934, 0.05610659070953261, 0.028570024951477535, 0.018941627349704504, 0.029163260696805082, 0.022309122432488948, 0.033389346426702105, 0.07340888434555382, 0.08842472860123962, 0.08851150792906992, 0.014593519554182421, 0.01057326291629579, 0.04031740259961225, 0.05754337747930549, 0.018931194608740043, 0.8783400873653591, 18.899724148213863, 48.301161378622055, 51.62517361342907, 36.75846755504608, 29.250313639640808, 40.465480238199234, 45.23226745426655, 35.579956993460655, 7.7661937940865755, 0.32288918795529753, 0.13479125074809417, 0.6219638069160283, 3.4194457763805985, 5.822287453338504, 5.874241590499878, 4.307716749608517, 9.85620466992259, 18.404413126409054, 32.753858640789986, 47.87103205919266, 52.01692879199982, 49.62876833975315, 47.640186846256256, 49.549683183431625, 53.42987917363644, 50.186339020729065, 50.08364953100681, 52.09338068962097, 49.55251403152943, 48.91619257628918, 45.45919507741928, 38.75709570944309, 37.35911652445793, 35.57884365320206, 34.24544580280781, 35.44293254613876, 39.157902002334595, 38.31126183271408, 38.50692093372345, 36.14176444709301, 38.672873228788376, 35.993933379650116, 41.22888587415218, 44.98524270951748, 50.2618333697319, 50.91452814638615, 51.40487663447857, 45.638325065374374, 37.05689214169979, 38.080139234662056, 38.56488682329655, 41.05764426290989, 41.70032277703285, 38.64333361387253, 39.07728172838688, 36.95052444934845, 36.9072599709034, 37.44390897452831, 36.688232123851776, 36.27572625875473, 39.691108390688896, 37.74698071181774, 39.08180348575115, 38.65619972348213, 46.31336264312267, 46.652574241161346, 51.96717046201229, 45.47388508915901, 36.45935520529747, 35.85973598062992, 46.18258886039257, 48.502782359719276, 50.832669138908386, 49.14220444858074, 48.75972077250481, 46.109138801693916, 38.995472118258476, 40.588046461343765, 37.299102544784546, 37.616727501153946, 36.026999205350876, 35.71916252374649, 37.551196217536926, 39.17612202465534, 46.72522634267807, 51.80567152798176, 52.02373802661896, 52.209114879369736, 47.52933919429779, 42.90304943919182, 38.76954384148121, 37.636304050683975, 38.52590091526508, 37.489977702498436, 37.04380564391613, 38.44301596283913, 36.149219647049904, 37.1324472874403, 37.51984030008316, 38.28304834663868, 38.13625082373619, 36.499097272753716, 37.52882681787014, 38.53881262242794, 37.93746069073677, 38.503683507442474, 43.92026245594025, 51.28408871591091, 51.255168467760086, 55.40915496647358, 52.5715546309948, 54.49366249144077, 55.40817841887474, 47.71422207355499, 44.32359181344509, 46.98054984211922, 49.998670890927315, 55.383004769682884, 54.79189708828926, 39.482465386390686, 12.53257205709815, 4.323986526578665, 8.913208320736885, 10.355883557349443, 4.541390910744667, 0.45799084939062595, 0.25168961787130684, 0.17690449487417936, 8.791305162012577, 39.16403867304325, 51.74498498439789, 40.96526741981506, 35.72907619178295, 51.82380795478821, 59.6670126914978, 35.98190322518349, 6.974823558703065, 0.0443527934839949, 0.04221135975967627, 0.0135814091663633, 0.03594839778088499, 0.05034174711909145, 0.03935157161322422, 0.06972521208808757, 0.07404359130305238, 0.028811280462832656, 0.05905900259676855, 0.01573264573380584, 0.010107002144650323, 0.15787514566909522, 0.05974679166683927, 0.04379612706543412, 0.07167834439314902, 0.04037651466205716, 0.010777634615806164, 0.23475885449443012, 0.21303191722836345, 0.12090478456229903, 0.2742810978088528, 0.18520160199841484, 0.19297493097838014, 0.1366353838238865, 0.13107552513247356, 0.11976024441537447, 0.11802504377556033, 0.11966949459747411, 0.13329353736480698, 0.15475356864044443, 0.20645104144932702, 0.19106605293927714, 0.21313612960511819, 0.08590952333179303, 0.13082911726087332, 0.16021984250983223, 0.14932713325833902, 1.027873819693923, 23.076047748327255, 56.71416074037552, 58.554417192935944, 43.54739226400852, 37.49691992998123, 50.10479919612408, 50.25354981422424, 40.90846806764603, 9.874922465533018, 0.44709950569085777, 0.3191665158374235, 2.622024603188038, 9.864108245819807, 13.355540446937084, 12.633101362735033, 11.487251948565245, 11.677639782428741, 22.261534854769707, 33.49114067852497, 50.88770538568497, 55.374291837215424, 52.88199797272682, 49.26741912961006, 53.63027662038803, 54.98102433979511, 51.49757646024227, 54.028168469667435, 56.580119132995605, 51.50678716599941, 50.37265822291374, 46.218086555600166, 40.51444061100483, 39.42417271435261, 36.34352222084999, 35.37437282502651, 38.09906601905823, 42.13630758225918, 40.50155930221081, 42.399477660655975, 38.26017737388611, 40.718166679143906, 38.63947682082653, 42.48106688261032, 45.99178969860077, 51.71526677906513, 54.540483579039574, 54.57639545202255, 48.733076602220535, 38.69178481400013, 38.874733597040176, 40.58908760547638, 42.942954897880554, 44.58298109471798, 41.865895092487335, 40.987291038036346, 38.083346262574196, 38.84025804698467, 38.911211639642715, 39.77359056472778, 39.64391492307186, 40.292809903621674, 39.653874188661575, 40.01206576824188, 42.02194891870022, 49.243309423327446, 49.70392070710659, 53.293113112449646, 48.22853207588196, 38.237587586045265, 35.88848143815994, 48.01605887711048, 49.05029498040676, 53.32945056259632, 52.39429034292698, 51.005518063902855, 47.34366215765476, 42.51351714134216, 42.030528858304024, 40.09970046579838, 40.10170675814152, 38.843039497733116, 38.574359714984894, 41.22097089886665, 41.83506354689598, 50.485451370477676, 54.23083059489727, 54.69332277774811, 54.026120379567146, 51.85009494423866, 44.78459067642689, 41.146924272179604, 39.805714040994644, 40.456022545695305, 39.04697835445404, 39.227111488580704, 41.4632572978735, 37.398729398846626, 38.14632028341293, 39.60429444909096, 39.99636881053448, 40.589847564697266, 38.21840241551399, 38.23637165129185, 39.59610588848591, 40.87810009717941, 41.192544624209404, 46.236162185668945, 52.71763399243355, 54.373645931482315, 57.25699961185455, 53.35459761321545, 54.91627961397171, 58.00315037369728, 49.30187948048115, 46.94919392466545, 50.708791986107826, 53.04866082966328, 55.84619611501694, 59.529433473944664, 39.95160721242428, 17.621396742761135, 11.099969130009413, 20.94448372721672, 14.011572394520044, 4.438538029789925, 3.5221663769334555, 0.5571399384643883, 0.3122222697129473, 11.257370933890343, 46.54101602733135, 58.21438863873482, 50.871119275689125, 41.507847905159, 59.85831342637539, 67.84693256020546, 41.375402212142944, 8.893648870289326, 0.2564446470933035, 0.27380214538425207, 0.09324075494077988, 0.1927581347990781, 0.15596769255353138, 0.0748685329745058, 0.2170657570241019, 0.12684201792581007, 0.10607756456010975, 0.24081454204861075, 0.12606417294591665, 0.10540762785240076, 0.23110641923267394, 0.20536958385491744, 0.10634939098963514, 0.22265414387220517, 0.12189636065158993, 0.13556309917476028], [0.09576836891938001, 0.015898077872407157, 0.05303821824782062, 0.01465332923544338, 0.01364085797831649, 0.015525231228821212, 0.04688138338678982, 0.007177834786489257, 0.008140644767991034, 0.04427775493240915, 0.06021643384883646, 0.038101887694210745, 0.027398555976105854, 0.011543325999809895, 0.05053481312643271, 0.04030042597150896, 0.030295735377876554, 0.096863192593446, 0.03424323185754474, 0.04225954369758256, 0.13802431320073083, 9.713309537619352, 42.289731949567795, 45.06193779408932, 32.6463358104229, 27.90342841297388, 31.392952166497707, 39.57798086106777, 38.39370220899582, 10.45189205557108, 0.7255721348337829, 0.053888459733570926, 0.31323019531555474, 1.0513939638622105, 5.093605779111385, 3.5769580118358135, 1.3445061980746686, 2.516545350663364, 10.669764764606953, 26.91163033246994, 41.47958882153034, 47.50534348189831, 46.62922069430351, 48.86292323470116, 51.89687803387642, 49.46531631052494, 49.86810229718685, 52.321303859353065, 46.880938187241554, 45.93174152076244, 39.98667173087597, 35.8116989582777, 34.35986526310444, 33.7867496162653, 35.89867629110813, 41.09809689223766, 45.943285301327705, 46.577942445874214, 46.05380617082119, 42.50450022518635, 38.05409163236618, 38.013141229748726, 35.565738156437874, 39.63596574962139, 46.43905609846115, 47.90676534175873, 50.58296173810959, 50.06260626018047, 49.10987578332424, 39.9629458039999, 35.14384299516678, 35.50078824162483, 36.027968153357506, 36.279605850577354, 34.996148720383644, 36.19194835424423, 34.9239905923605, 35.752593129873276, 34.99031603336334, 35.28295353055, 34.96677629649639, 36.50272987782955, 33.72369959950447, 36.58295877277851, 36.22437201440334, 41.441663056612015, 47.0520506054163, 50.39124682545662, 42.89722815155983, 36.917549818754196, 47.05255217850208, 48.679465278983116, 49.40813697874546, 49.821927174925804, 49.8407019674778, 48.17549452185631, 44.06390994787216, 38.02374266088009, 34.91158425807953, 35.32689817249775, 35.76542504131794, 34.34891425073147, 35.981508046388626, 35.86557626724243, 40.00875614583492, 48.32747496664524, 51.31308116018772, 49.583983942866325, 49.49908509850502, 48.198183104395866, 43.059551641345024, 36.09992489218712, 35.957538932561874, 36.102744340896606, 36.47425800561905, 34.50533285737038, 34.5777303725481, 36.46844431757927, 36.27180106937885, 36.2456850707531, 34.69448670744896, 36.11331157386303, 35.73324836790562, 35.63711732625961, 36.66569173336029, 35.8534587174654, 35.62105938792229, 40.12442573904991, 44.7066530585289, 48.952146247029305, 51.3073168694973, 52.392485439777374, 53.80798928439617, 53.90909805893898, 51.93122059106827, 45.44754110276699, 45.06211258471012, 47.47031696140766, 56.56971909105778, 48.63960161805153, 39.21181730926037, 12.109471410512924, 2.7947224862873554, 5.460058115422726, 7.725505577400327, 5.826094374060631, 0.9659668290987611, 0.1741058856714517, 0.1679799909470603, 7.684263540431857, 38.12330111861229, 43.40641222894192, 36.54032506048679, 30.55899191647768, 36.937939524650574, 49.69908356666565, 26.565516404807568, 3.141332524828613, 0.0597576307336567, 0.06602098976145498, 0.03259354518377222, 0.0305856312479591, 0.025303380316472612, 0.053060174686834216, 0.06728068896336481, 0.010820179159054533, 0.07402876319247298, 0.027785357779066544, 0.01925745942571666, 0.009322220867034048, 0.03875901493302081, 0.030918265547370538, 0.03703106878674589, 0.017525121620565187, 0.08479697717120871, 0.027970347364316694, 0.03293744528491516, 0.014120253836154006, 0.02874834262911463, 0.04314410951337777, 0.029594995830848347, 0.028864134364994243, 0.01929666152136633, 0.05345179859432392, 0.023201842595881317, 0.11668462859233841, 0.06468329083872959, 0.0017662922209638054, 0.006404275709428475, 0.04202833501040004, 0.02848016571078915, 0.05995016239467077, 0.033875275039463304, 0.05227871173701715, 0.07757841100101359, 0.052110003016423434, 0.1634379432653077, 12.93823828920722, 48.70790675282478, 52.218811959028244, 37.96865701675415, 32.57920101284981, 41.11667789518833, 45.38324095308781, 41.54947467148304, 11.218552216887474, 0.6451353791635484, 0.010095731704495847, 0.6865710276179016, 1.2571050692349672, 8.669444750994444, 5.586999328806996, 3.5693453578278422, 5.6046888045966625, 11.159485336393118, 28.133734054863453, 44.953066036105156, 51.31507985293865, 48.46393324434757, 50.30741572380066, 54.06722277402878, 52.03403927385807, 50.26330009102821, 53.8065567612648, 49.027788788080215, 48.77556212246418, 43.910751566290855, 38.44768971204758, 35.41696093976498, 34.862186908721924, 36.16022765636444, 41.37353651225567, 47.26423121988773, 46.71992942690849, 46.438201144337654, 43.48415605723858, 39.803597554564476, 39.08050015568733, 37.546085491776466, 41.29875272512436, 48.14977750182152, 51.74622371792793, 51.356398835778236, 51.689739748835564, 51.430221274495125, 40.47292023897171, 36.72268487513065, 37.8311537951231, 38.292734026908875, 37.79237687587738, 38.09460885822773, 38.08113098144531, 37.00899191200733, 38.054600805044174, 36.71982742846012, 36.57657511532307, 37.60582588613033, 37.65202380716801, 36.13294892013073, 38.98449830710888, 38.40420104563236, 43.72982047498226, 50.10544516146183, 50.98378702998161, 46.45056948065758, 39.12334285676479, 46.069590523839, 50.095425099134445, 49.54888142645359, 52.47115261852741, 51.58619910478592, 50.60254588723183, 46.40466034412384, 40.83397686481476, 37.23990552127361, 36.631318777799606, 37.879289612174034, 35.94554677605629, 38.34014408290386, 38.538037464022636, 41.15072786808014, 50.65814070403576, 53.8568090647459, 51.6980005055666, 52.12244153022766, 47.274471670389175, 44.752106219530106, 37.4835180491209, 37.94637121260166, 38.09147022664547, 38.30574832856655, 36.55853368341923, 36.65998063981533, 38.167279958724976, 37.03921169042587, 37.630737349390984, 35.74730761349201, 36.991037875413895, 36.933584958314896, 36.05675160884857, 38.19425091147423, 36.9747481495142, 38.050390630960464, 42.508357018232346, 47.091853469610214, 51.710414439439774, 54.68041867017746, 53.61861504614353, 53.47415439784527, 56.08809493482113, 55.93178652226925, 47.922488898038864, 46.90405994653702, 50.8155320584774, 57.06060715019703, 53.53015959262848, 39.87168610095978, 12.66354912891984, 5.281977346166968, 10.206088945269585, 12.490047588944435, 9.006218779832125, 1.1612743302248418, 0.015279558083420852, 0.31228538195136935, 8.246303256601095, 45.676425620913506, 47.62006692588329, 43.16415622830391, 35.09037226438522, 44.95339661836624, 56.489668786525726, 31.55569553375244, 4.850258762016892, 0.011124947668577079, 0.10775710412417538, 0.06684500374831259, 0.007687488468945958, 0.007835124833945883, 0.03208556736353785, 0.0664752435113769, 0.05751705350121483, 0.03393658385903109, 0.02256522831885377, 0.03814741474343464, 0.02397334777924698, 0.002622556930873543, 0.03486133697151672, 0.04590809010551311, 0.04041533640702255, 0.015706806007074192, 0.017954782451852225, 0.21059442224213853, 0.12341745168669149, 0.07519032078562304, 0.09605082290363498, 0.08086680798442103, 0.06670328322798014, 0.1390926050953567, 0.1291042027878575, 0.1571565240737982, 0.1419650431489572, 0.15178285539150238, 0.1746370704495348, 0.0699955022719223, 0.1245872545405291, 0.27313323284033686, 0.15124047902645543, 0.09691876461147331, 0.14988447132054716, 0.1626357261557132, 0.15265695692505687, 0.49170881509780884, 16.064821667969227, 54.25933666527271, 61.52606673538685, 43.16147357225418, 36.723498031497, 40.735052973032, 50.11711813509464, 49.73168581724167, 14.825651161372662, 1.1631052382290363, 0.1359271671390161, 1.7978032305836678, 6.351697845384479, 10.782291926443577, 10.447269603610039, 5.6361249927431345, 4.474880704656243, 12.128522638231516, 30.325182862579823, 45.395681485533714, 52.40268029272556, 51.81838184595108, 53.020576536655426, 56.677678897976875, 52.63791427016258, 53.39440807700157, 56.08085252344608, 51.178591176867485, 50.19496835768223, 44.166154861450195, 39.80091489851475, 37.5290510058403, 36.555151864886284, 39.925552010536194, 45.24413421750069, 50.09280323982239, 49.60286892950535, 48.74200612306595, 45.984703078866005, 41.59872382879257, 41.53259977698326, 39.77071411907673, 42.1394158154726, 51.919357627630234, 51.13160289824009, 54.256722405552864, 53.99400070309639, 52.58128210902214, 44.43464085459709, 38.26579347252846, 38.798285499215126, 38.94926659762859, 39.93766576051712, 40.032159090042114, 38.8977375626564, 38.73278081417084, 38.681867346167564, 38.90144616365433, 39.12634089589119, 39.08506751060486, 38.350943103432655, 37.90866203606129, 41.204586178064346, 40.186400413513184, 45.764561891555786, 52.42236703634262, 53.9717148989439, 46.92937418818474, 41.399644911289215, 47.98912592232227, 52.072622403502464, 53.03369723260403, 53.105718567967415, 55.606645569205284, 53.327824249863625, 49.386573135852814, 42.67934404313564, 38.348173052072525, 38.60392212867737, 39.226340129971504, 37.832263335585594, 39.84956368803978, 39.145366474986076, 44.716973304748535, 53.100334256887436, 55.65926514565945, 53.58395330607891, 54.93000827729702, 50.312583446502686, 47.38551311194897, 39.07455727458, 41.01737022399902, 39.48803588747978, 40.425890162587166, 37.58481301367283, 38.016519248485565, 39.672481790184975, 40.21904446184635, 39.825754165649414, 37.82624065876007, 39.01900805532932, 40.474751740694046, 38.24123919010162, 41.06983780860901, 38.36689464747906, 39.5199503749609, 44.70851495862007, 50.425182804465294, 53.311815708875656, 56.41451641917229, 53.06177772581577, 54.46363650262356, 56.64906643331051, 57.65744112432003, 49.409736692905426, 48.00957642495632, 52.506863102316856, 60.95538675785065, 52.75363706052303, 44.1521830111742, 14.678236171603203, 7.529238034039736, 11.65040759369731, 21.71038582921028, 12.871717158704996, 1.931125964038074, 0.7566411676816642, 0.40578266023658216, 10.437125097960234, 51.04375921189785, 57.093566581606865, 48.17572630941868, 43.720655366778374, 50.77063366770744, 64.26560193300247, 38.04599046707153, 5.4253588523715734, 0.126478053862229, 0.21569919597823173, 0.1531790429726243, 0.12535997870145366, 0.12170464164228179, 0.1111110179044772, 0.20771512674400583, 0.11941181350266561, 0.1602255570469424, 0.12061156201525591, 0.1029430741618853, 0.08066945607424714, 0.1747769207577221, 0.12231328437337652, 0.11322880309307948, 0.09785551825189032, 0.17635484546190128, 0.08872099395375699], [0.09789287796593271, 0.032209673008765094, 0.07033771398710087, 0.05225164190051146, 0.05827863802551292, 0.02249421777378302, 0.05743908717704471, 0.051726208766922355, 0.061729357548756525, 0.05210731644183397, 0.03684478971990757, 0.006895211035953253, 0.036262875437387265, 0.03197715814167168, 0.06172163179144263, 0.05022664001444355, 0.005200059467824758, 0.013175650128687266, 0.032829099145601504, 0.04923576896544546, 0.026157488391618244, 5.226695537567139, 33.109694346785545, 46.434465944767, 41.34854145348072, 24.441107399761677, 21.76602814346552, 40.505921468138695, 39.03673030436039, 15.798497758805752, 1.6353171807713807, 0.04900851963611785, 0.4211584758013487, 1.5338172647170722, 6.862000962719321, 3.9013252314180136, 2.739459676668048, 3.7879723263904452, 3.394477553665638, 14.258610438555479, 32.53404803574085, 49.739152416586876, 49.56650108098984, 52.37762823700905, 50.90036630630493, 51.456409469246864, 50.41925132274628, 47.000107392668724, 45.67595824599266, 39.920065104961395, 33.91705222427845, 34.27062325179577, 35.86508609354496, 38.84027324616909, 40.6107160449028, 46.09338104724884, 46.963861137628555, 50.640840232372284, 47.462952956557274, 44.28102269768715, 41.19695998728275, 38.46146397292614, 37.98909991979599, 43.22956211864948, 47.84655377268791, 49.5521492511034, 50.05228601396084, 52.262426018714905, 48.18974755704403, 40.79344443976879, 34.40539442002773, 36.49601183831692, 34.84195679426193, 35.45546807348728, 35.24138756096363, 36.59497752785683, 35.99218167364597, 36.34648226201534, 34.82637383043766, 35.87909214198589, 32.69480600953102, 37.1483988314867, 37.01804302632809, 37.58256733417511, 37.9932226985693, 43.56489032506943, 44.18334133923054, 50.63220329582691, 47.44277223944664, 39.219283908605576, 53.39096546173096, 48.82667697966099, 48.7642577290535, 46.752543076872826, 47.27846905589104, 46.45661115646362, 41.59753069281578, 34.710886627435684, 35.53020626306534, 32.9720239341259, 36.43967606127262, 35.16297496855259, 35.64169228076935, 36.425529420375824, 42.79805727303028, 47.262612506747246, 50.360620468854904, 51.39176733791828, 49.76621836423874, 48.87493059039116, 42.577087730169296, 38.884062096476555, 36.886839866638184, 38.32089051604271, 39.29217539727688, 41.98869310319424, 40.72869971394539, 36.08961224555969, 34.960168451070786, 35.868167728185654, 35.22160582244396, 35.01355938613415, 35.579459220170975, 35.86316339671612, 36.09946891665459, 37.35449977219105, 36.135893762111664, 35.34345008432865, 42.21852757036686, 46.88774362206459, 51.28205202519894, 53.02229404449463, 54.61747504770756, 52.71394819021225, 54.801590368151665, 52.39260323345661, 46.902239844202995, 49.15671966969967, 54.63096432387829, 49.99043673276901, 30.572868771851063, 11.276642549782991, 3.95295781083405, 6.374050620943308, 10.513177067041397, 8.213259279727936, 0.1612249034224078, 0.08071060074144043, 0.2898510592058301, 9.22162352129817, 34.68893900513649, 45.96553310751915, 38.95738676190376, 37.327255234122276, 43.893215507268906, 46.76173858344555, 24.223593771457672, 1.0254448000341654, 0.08045234077144414, 0.07252500130562112, 0.0590093492064625, 0.04506153709371574, 0.06316761006019078, 0.020586703431035858, 0.022748861629224848, 0.019152196909999475, 0.04547631600871682, 0.049210150027647614, 0.07348856874159537, 0.01360410125926137, 0.017451769599574618, 0.03571799803467002, 0.07141809546737932, 0.12152759489254095, 0.014575582772522466, 0.03466848247626331, 0.018297515525773633, 0.028451880607462954, 0.04867862386163324, 0.0551754811021965, 0.01725239162624348, 0.06783628297853284, 0.053706696635345, 0.017172009611385874, 0.017598371596250217, 0.013005518339923583, 0.02824375271302415, 0.0577623926801607, 0.024597542214905843, 0.017232002974196803, 0.06038180290488526, 0.02401582274615066, 0.03005660055350745, 0.08869209472322837, 0.01401728641212685, 0.047948380233719945, 0.11040422614314593, 7.254322785884142, 40.38542993366718, 53.400499150156975, 45.779130309820175, 28.178934529423714, 24.833453446626663, 45.87048500776291, 44.77573335170746, 19.153767116367817, 1.3685980928130448, 0.09558753721648827, 0.32427590573206544, 1.233107338193804, 5.394296944141388, 6.954277586191893, 5.033665420487523, 4.549115896224976, 5.876228883862495, 20.16784530133009, 38.392094895243645, 52.14077174663544, 53.52714255452156, 55.11802598834038, 52.366487234830856, 50.57275928556919, 53.433488979935646, 49.80233922600746, 48.290244564414024, 42.32894964516163, 36.170357912778854, 35.79371452331543, 37.45893716812134, 39.05890591442585, 42.931327521800995, 47.80736647546291, 48.548117727041245, 52.65667386353016, 50.10690048336983, 45.36871053278446, 43.04568998515606, 40.334812849760056, 40.48908457159996, 44.42074880003929, 48.39540012180805, 51.12309515476227, 51.35214306414127, 52.992389649152756, 49.74028095602989, 42.78154335916042, 37.62970760464668, 38.11155214905739, 37.501741871237755, 37.111005038022995, 37.486117109656334, 38.56010288000107, 37.78612621128559, 36.88335545361042, 35.7910280674696, 36.31318084895611, 35.625037774443626, 37.72098250687122, 38.908749371767044, 38.99356082081795, 39.3681675195694, 45.357573330402374, 46.28785841166973, 52.14226886630058, 48.55143114924431, 41.213751286268234, 54.8631052672863, 50.79445838928223, 51.25001214444637, 48.49973492324352, 49.52116571366787, 47.674453407526016, 44.17818121612072, 35.98413370549679, 37.54344843327999, 34.96260032057762, 38.12571778893471, 37.82605066895485, 37.35543072223663, 38.67065414786339, 44.68266114592552, 49.75622870028019, 53.17506104707718, 51.760408356785774, 51.78784288465977, 49.5325993001461, 43.8286417722702, 39.141616076231, 39.11609284579754, 38.973843678832054, 41.567717492580414, 43.01727890968323, 40.49711354076862, 36.582069620490074, 37.08666734397411, 38.181042820215225, 37.48185753822327, 37.33689531683922, 38.01004819571972, 38.467916026711464, 38.93861576914787, 38.60121667385101, 37.98993967473507, 38.56208637356758, 43.35587494075298, 49.296586364507675, 52.63851843774319, 54.36434783041477, 54.536041617393494, 55.986682176589966, 58.05171176791191, 54.026625752449036, 49.62705083191395, 52.388567849993706, 55.78092701733112, 53.0676294118166, 34.35191988945007, 13.084402196109295, 3.4145599510520697, 6.096973288804293, 10.501233357936144, 7.398198265582323, 0.7096328807529062, 0.17399928357917815, 0.4853701317915693, 10.092147309333086, 39.07885104417801, 48.86226586997509, 41.12636737525463, 42.173674777150154, 49.37766261398792, 53.31102915108204, 29.191861376166344, 1.7494395445100963, 0.07243283398565836, 0.027134843076055404, 0.03602723612857517, 0.06506825768155977, 0.03988884942373261, 0.03722847264725715, 0.06929528593900613, 0.03984396062151063, 0.05079197471786756, 0.04172953522356693, 0.038038519414840266, 0.026420937829243485, 0.012390636002237443, 0.019043438878725283, 0.013427446920104558, 0.038544530543731526, 0.015235370610753307, 0.016674902399245184, 0.19290944386739284, 0.19707572733750567, 0.15710441046394408, 0.15900015248917043, 0.15367803338449448, 0.2612327761016786, 0.15649654698790982, 0.1276219854480587, 0.21349581889808178, 0.1717034645844251, 0.15200900263153017, 0.12726354296319187, 0.11709676546161063, 0.31436110963113606, 0.16968054813332856, 0.0880947920086328, 0.10760368735645898, 0.1701367908390239, 0.079312268353533, 0.14230358123313636, 0.1195103039208334, 9.328458588570356, 44.99667629599571, 61.29411578178406, 53.40079553425312, 34.011948332190514, 30.96810456365347, 51.57086692750454, 50.16049660742283, 22.29955941438675, 3.001365610398352, 0.27713415096513927, 1.3244897034019232, 3.983867014758289, 13.175938334316015, 9.694932773709297, 6.135778706520796, 8.049570713192225, 5.665315501391888, 17.478613704442978, 36.77504226565361, 54.47714477777481, 55.12342929840088, 55.47999456524849, 50.985409542918205, 53.239338397979736, 55.11154733598232, 51.59512482583523, 49.54586058855057, 44.22156348824501, 37.95030780136585, 38.062542378902435, 39.90862011909485, 42.61449672281742, 44.742089956998825, 50.21891467273235, 51.637731939554214, 55.407505854964256, 53.02170127630234, 47.81238980591297, 44.49163019657135, 42.53333307802677, 42.83342957496643, 46.863736510276794, 51.52208894491196, 52.46029280126095, 52.92594261467457, 56.59436076879501, 53.02010916173458, 45.868870094418526, 38.84599193930626, 39.93766576051712, 37.4326653778553, 38.40862400829792, 38.11520375311375, 40.95257610082626, 41.58002123236656, 39.24750119447708, 38.33481676876545, 38.15797045826912, 36.520182341337204, 39.633963257074356, 42.204966098070145, 41.63557805120945, 41.67833335697651, 48.157681077718735, 48.259238228201866, 53.80300015211105, 51.590337082743645, 43.27117368578911, 54.955523908138275, 53.73916357755661, 52.06940017640591, 50.74859865009785, 51.36078380048275, 50.04649132490158, 45.30423939228058, 38.201580718159676, 40.00441677868366, 35.96464455127716, 39.87617366015911, 39.455179050564766, 39.40911792218685, 41.62943758070469, 45.90927332639694, 51.90654091536999, 53.43629702925682, 55.21971233189106, 54.08298812806606, 52.68829196691513, 46.26274175941944, 42.75053322315216, 39.96925726532936, 42.12504878640175, 44.324564561247826, 47.137739807367325, 44.504823088645935, 39.578455835580826, 39.087655171751976, 40.08587300777435, 39.572976529598236, 38.733996748924255, 39.1092836111784, 40.303582325577736, 40.15601344406605, 40.826753452420235, 39.46942828595638, 39.69572514295578, 46.08138509094715, 50.768224596977234, 56.03720426559448, 57.05181062221527, 55.89786194264889, 56.19348227977753, 59.906107261776924, 57.07770623266697, 53.76108080148697, 54.280965104699135, 59.1847387701273, 54.06807392835617, 33.63541133701801, 13.837888464331627, 8.77159371972084, 11.572159342467785, 20.306486561894417, 14.314248953014612, 0.5040972784627229, 0.3807513549691066, 0.7684091362170875, 13.081063125282526, 45.55561490356922, 59.81622688472271, 49.70719613134861, 48.34663353860378, 56.33439391851425, 60.90548023581505, 34.51267026364803, 2.567631471902132, 0.18290979060111567, 0.14833256631391123, 0.1294015219900757, 0.20798978075617924, 0.18969696859130636, 0.14077624131459743, 0.1219732100435067, 0.13605667190859094, 0.11236565565923229, 0.08371870339033194, 0.22769249539123848, 0.07140419504139572, 0.11209501666598953, 0.07817162448191084, 0.2185112825827673, 0.13304836145834997, 0.18232914910186082, 0.14485489198705181], [0.045691386694670655, 0.011277023004367948, 0.013063411424809601, 0.054464908098452725, 0.016662669950164855, 0.01941171482030768, 0.044214490553713404, 0.023198753406177275, 0.08998517572763376, 0.022175873527885415, 0.021709088614443317, 0.016768659770605154, 0.02433780722640222, 0.019184997981938068, 0.02199604186898796, 0.019743059638130944, 0.05415753650595434, 0.04564820854284335, 0.034199489673483185, 0.04171093700279016, 0.023413132039422635, 2.22878560423851, 24.047060944139957, 43.78230705857277, 49.09461960196495, 36.94804698228836, 37.44575947523117, 38.39172251522541, 37.2857728600502, 23.630510196089745, 2.5203544087707996, 0.07318007279536687, 0.1396208064397797, 0.3150101623032242, 7.679505720734596, 5.649685990065336, 2.891473132185638, 2.3171026026830077, 1.4052162528969347, 9.319476820528507, 21.779133640229702, 37.74052485823631, 50.070813819766045, 50.51938734948635, 49.68259625136852, 51.436232551932335, 46.87074713408947, 46.97018399834633, 40.345178693532944, 36.037760227918625, 36.61945961415768, 36.42911642789841, 41.658855602145195, 44.48151893913746, 48.17636467516422, 48.525676131248474, 51.579249277710915, 48.822155222296715, 48.72040048241615, 46.28156594932079, 46.21897950768471, 45.777219012379646, 44.07177932560444, 45.4165917634964, 45.70803612470627, 48.037740513682365, 52.99482151865959, 50.44121794402599, 48.20472255349159, 39.97543193399906, 35.974193438887596, 35.796024799346924, 36.99349254369736, 37.06372797489166, 36.00814461708069, 35.26256762444973, 34.581100791692734, 35.345159992575645, 33.79488117992878, 34.92280885577202, 37.26136676967144, 41.089908331632614, 38.063743114471436, 38.99815857410431, 39.10855405032635, 44.20432761311531, 45.556929633021355, 51.05542078614235, 46.35071083903313, 41.92671462893486, 48.546240627765656, 46.53169512748718, 46.283823028206825, 43.08998420834541, 45.32015673816204, 42.773913368582726, 37.37816110253334, 35.633792504668236, 35.51332376897335, 34.280308932065964, 35.38622438907623, 36.53467856347561, 35.60641497373581, 36.856262907385826, 43.47905293107033, 49.44960795342922, 47.71818146109581, 49.357934072613716, 48.42228747904301, 47.51548133790493, 45.36844074726105, 39.61191304028034, 39.53780181705952, 45.65664388239384, 47.44778797030449, 48.01497593522072, 47.98191770911217, 45.07631242275238, 40.93721352517605, 38.36282506585121, 36.6149340569973, 36.84113211929798, 36.515595987439156, 36.9436202198267, 36.28155894577503, 36.65556147694588, 36.4307427406311, 36.50228530168533, 36.90032534301281, 42.93708801269531, 46.92961357533932, 52.17330180108547, 52.864610105752945, 54.95673984289169, 53.5892616212368, 54.770755022764206, 51.5222143381834, 50.03436617553234, 53.08508947491646, 50.8131267875433, 25.45370176434517, 9.333823900669813, 4.733116747811437, 10.821678712964058, 10.154426917433739, 6.091439835727215, 2.830087188631296, 0.10992218638421036, 0.765536252874881, 10.447179358452559, 37.542559280991554, 45.78706808388233, 38.176635056734085, 36.62262104451656, 46.17488667368889, 47.636463046073914, 17.9076486825943, 0.8908086433075368, 0.11926538776606321, 0.04376502365630586, 0.02749838968156837, 0.02779748447210295, 0.036550780496327206, 0.009017763131851098, 0.045383677424979396, 0.0749888870632276, 0.10930932083283551, 0.04982708254829049, 0.022178356011863798, 0.0719775709148962, 0.049847710542962886, 0.026723635746748187, 0.03222980747523252, 0.014241630233300384, 0.02384681902185548, 0.058100448368350044, 0.042414841809659265, 0.02254963394079823, 0.01278055482544005, 0.04925607041514013, 0.0032744993404776324, 0.023411074434989132, 0.050562613978399895, 0.036017131787957624, 0.10342378547647968, 0.016352702696167398, 0.023946170331328176, 0.007224715791380731, 0.06181061529787257, 0.0058042984801431885, 0.020521945480140857, 0.023870185541454703, 0.01984489157621283, 0.05707981719751842, 0.005329678342604893, 0.023634817116544582, 0.0804760301252827, 3.3605240005999804, 29.947312138974667, 50.420330464839935, 52.854293659329414, 39.99475009739399, 34.153122156858444, 43.50918531417847, 42.55219526588917, 25.691948980093002, 2.5734667712822556, 0.10116775301867165, 0.21384449471952394, 1.2975014140829444, 5.90632944367826, 8.133036084473133, 6.570082576945424, 3.690562890842557, 3.077842681668699, 11.918514557182789, 25.413796305656433, 43.1479386985302, 52.58581146597862, 50.18177546560764, 50.01030966639519, 54.11369048058987, 49.87084574997425, 48.57437051832676, 41.65969915688038, 36.86349391937256, 37.86578893661499, 37.016591504216194, 42.393139600753784, 45.986511781811714, 47.31533847749233, 49.72043842077255, 52.45093770325184, 50.33701613545418, 50.89604593813419, 48.718257397413254, 47.906377762556076, 45.49375042319298, 46.15943670272827, 46.5095879137516, 48.40400665998459, 49.59429278969765, 54.591180458664894, 53.08765433728695, 50.536953806877136, 41.35988384485245, 37.277740091085434, 36.79229713976383, 39.220131263136864, 37.708515375852585, 37.51013182103634, 38.13468910753727, 36.303023993968964, 37.537988126277924, 35.544394701719284, 36.422717571258545, 38.210928216576576, 42.705372646450996, 41.348503455519676, 41.717262268066406, 40.72076573967934, 44.85419914126396, 47.97682598233223, 52.31330528855324, 48.12469504773617, 43.70409965515137, 51.52113899588585, 49.02146592736244, 48.38786132633686, 46.02912649512291, 47.29182913899422, 44.25047613680363, 38.92789274454117, 37.74400167167187, 36.50115676224232, 36.02648623287678, 38.58399599790573, 37.696861401200294, 37.00135052204132, 38.250810876488686, 43.88218469917774, 50.67629233002663, 50.009595304727554, 51.8114548176527, 50.30966520309448, 50.684283301234245, 47.21109867095947, 42.489491030573845, 39.54585738480091, 47.115503400564194, 48.98270420730114, 49.75682906806469, 49.26649197936058, 46.75120174884796, 41.74653209745884, 38.50684493780136, 37.90912561118603, 37.74942398071289, 37.153528556227684, 38.69523502886295, 37.72830091416836, 39.74609524011612, 37.41527371108532, 38.32996442914009, 39.36546206474304, 45.377598255872726, 49.58042733371258, 54.702119305729866, 55.266905799508095, 55.43014504015446, 55.51026374101639, 56.55388914048672, 52.1855865418911, 51.116076931357384, 55.96576049923897, 50.767023861408234, 29.028736129403114, 11.52242761105299, 4.885034020990133, 6.934967497363687, 8.987193200737238, 5.661093452945352, 1.725858247373253, 0.07176426282967441, 0.5546089773997664, 11.549505908042192, 38.70257243514061, 52.79085226356983, 43.82012262940407, 42.24036879837513, 52.78377324342728, 53.14846247434616, 22.631241716444492, 1.5096306125633419, 0.11846902620163746, 0.04451813285413664, 0.05779762243037112, 0.03643292002379894, 0.05205301349633373, 0.02650852795341052, 0.01098396465749829, 0.06953917792998254, 0.03104709496255964, 0.06639390412601642, 0.017029977389029227, 0.07358251721598208, 0.04171844382653944, 0.011854826716444222, 0.05113926272315439, 0.020683271686721127, 0.07469626565580256, 0.025153557398880366, 0.14745093940291554, 0.10445258769323118, 0.10453058741404675, 0.1230179239064455, 0.1021836641302798, 0.13303452782565728, 0.13655382179422304, 0.13456259504891932, 0.1677154449862428, 0.10324973700335249, 0.1544355583610013, 0.0704580606543459, 0.16745480272220448, 0.0870865695469547, 0.10201325960224494, 0.1323051896179095, 0.11969109109486453, 0.2743252704385668, 0.12136240024119616, 0.16117869730805978, 0.13643304468132555, 4.352700160816312, 34.8337834328413, 56.34505994617939, 60.872273817658424, 48.93606171011925, 47.706934064626694, 49.981811195611954, 47.64549896121025, 31.608351208269596, 3.691818010993302, 0.3522006666753441, 0.5538398749195039, 3.1271141627803445, 16.205507218837738, 15.6879198923707, 8.955571297556162, 4.931412907317281, 2.942162174731493, 11.140307765454054, 26.484504751861095, 43.01029868423939, 51.294218972325325, 50.25842495262623, 51.86373621225357, 56.34526513516903, 50.620184540748596, 51.65583036839962, 42.11099714040756, 39.30833972990513, 39.540929049253464, 39.33960825204849, 45.73993161320686, 49.44863140583038, 52.167507112026215, 51.66526906192303, 55.20227126777172, 53.47920812666416, 51.21814325451851, 52.063198909163475, 50.5914580821991, 49.213253036141396, 48.67804415524006, 49.99361336231232, 49.73254457116127, 51.33637011051178, 55.760484114289284, 55.534065663814545, 53.97932209074497, 42.80810013413429, 38.771409541368484, 39.46253925561905, 41.178037002682686, 40.519205555319786, 38.80497694015503, 39.22456182539463, 38.81313890218735, 38.83312962949276, 36.16794504225254, 38.09452906250954, 40.55430807173252, 45.337233021855354, 42.96799935400486, 43.76161336898804, 42.410675659775734, 46.82851999998093, 50.45517459511757, 55.85808947682381, 49.4031136482954, 47.70128756761551, 51.936954483389854, 51.50365613400936, 51.82258442044258, 47.63209328055382, 49.85444203019142, 46.72604709863663, 41.8114098161459, 38.96162733435631, 39.04823988676071, 39.19331610202789, 41.364948973059654, 40.80688811838627, 38.39983507990837, 40.564894303679466, 46.67367070913315, 53.34567189216614, 51.62790186703205, 51.917377933859825, 53.11532065272331, 52.66757547855377, 49.70104806125164, 44.027477502822876, 42.82185919582844, 49.57836024463177, 51.740695014595985, 53.19667428731918, 53.00230331718922, 48.77041719853878, 45.12139320373535, 41.71559035778046, 41.04225888848305, 40.14150582253933, 39.04094807803631, 41.47588022053242, 40.60519874095917, 41.93698547780514, 40.051488652825356, 40.44887512922287, 40.50831153988838, 47.76432618498802, 52.40598991513252, 57.45792143046856, 57.44827374815941, 55.54379694163799, 56.66344866156578, 59.227133095264435, 56.93258821964264, 54.72932204604149, 56.327596083283424, 54.98145371675491, 27.868314497172832, 12.644266113638878, 9.578191637992859, 20.3608388453722, 17.702826373279095, 11.38805827125907, 5.980221703648567, 0.31352417485322803, 0.7836888881865889, 14.160566199570894, 46.684971302747726, 59.13507163524628, 52.9775932431221, 49.826293140649796, 60.024763494729996, 61.19773395359516, 27.022624276578426, 2.78826710768044, 0.392421122523956, 0.1470123152830638, 0.11435173932113685, 0.14288891310570762, 0.1596383104333654, 0.10503565601538867, 0.10528365208301693, 0.167328400129918, 0.1539455182501115, 0.21077047451399267, 0.11671936110360548, 0.1522787584690377, 0.19450371066341177, 0.07876509771449491, 0.06320739659713581, 0.10433421513880603, 0.15612229675753042, 0.14547062222845852], [0.0456073644454591, 0.050114464393118396, 0.04532204577117227, 0.04831241109059192, 0.06639234561589547, 0.07468601659638807, 0.014938537515263306, 0.023387286746583413, 0.03658414745586924, 0.07150499353883788, 0.08450243360130116, 0.05175739381229505, 0.06883029331220314, 0.0484564062935533, 0.03860212491417769, 0.02365114436543081, 0.022879110401845537, 0.0750655731826555, 0.06426591440686025, 0.07188839445007034, 0.04978083561582025, 1.0332421003840864, 14.682656284421682, 43.46964843571186, 47.8322247415781, 38.36008541285992, 28.31379309296608, 32.306379452347755, 34.03046473860741, 27.90669623762369, 5.538412760943174, 0.3858147020218894, 0.10594218940241262, 0.7052173395641148, 2.5517072388902307, 5.003445642068982, 6.282050907611847, 1.968887981493026, 0.787403960712254, 5.3545278031378984, 16.21290162205696, 31.429342813789845, 43.18972885608673, 46.13824523985386, 54.80671629309654, 48.43744866549969, 46.458609849214554, 43.36723253130913, 37.90236957371235, 37.572710663080215, 40.0838553160429, 44.108846336603165, 46.371727511286736, 46.957876458764076, 48.96194212138653, 46.977057829499245, 45.211254581809044, 45.606315582990646, 46.97136573493481, 48.45151171088219, 47.08716072142124, 47.0409893989563, 45.99911190569401, 45.97745306789875, 48.015538305044174, 47.13312305510044, 50.988574773073196, 49.628806337714195, 47.928192391991615, 39.88440401852131, 36.82166576385498, 36.8547847867012, 35.8956478536129, 37.17809043824673, 43.59979905188084, 37.2399815171957, 35.941367000341415, 35.3914263099432, 34.90584276616573, 33.87010954320431, 37.18779131770134, 41.48373819887638, 41.51019997894764, 44.53512646257877, 41.462664529681206, 44.96489480137825, 46.101007238030434, 50.01802705228329, 46.164380237460136, 40.7849632948637, 50.79365663230419, 46.72143414616585, 45.31444564461708, 40.02947263419628, 39.22627933323383, 37.0813362300396, 34.982249066233635, 33.16793382167816, 35.70669159293175, 34.864109605550766, 35.20339719951153, 34.16827954351902, 36.19592294096947, 34.12093408405781, 42.1557055413723, 47.454327419400215, 47.26169295608997, 49.8555401712656, 50.243484154343605, 46.8806342035532, 47.058008685708046, 45.63406549394131, 45.571026876568794, 45.10747455060482, 48.73780734837055, 50.445439517498016, 47.23322108387947, 47.39979274570942, 47.63429716229439, 45.58881752192974, 43.27284939587116, 42.96540409326553, 43.92158478498459, 44.21009950339794, 42.05759480595589, 40.47507852315903, 36.17700755596161, 35.04016935825348, 36.682391837239265, 38.8294780254364, 44.58606652915478, 50.750954523682594, 52.31107480823994, 53.93396772444248, 52.16514743864536, 55.34032925963402, 53.73608574271202, 52.82294154167175, 52.59904995560646, 38.69797848165035, 26.516937911510468, 9.574997909367085, 2.168433917686343, 3.808289598673582, 4.681116538122296, 4.310769885778427, 1.1176212038844824, 0.2710487478179857, 0.5356077407486737, 13.698836825788021, 36.63417622447014, 32.79929660260677, 29.180009812116623, 32.349358946084976, 50.481659173965454, 39.09859858453274, 14.519067462533712, 1.0950896004214883, 0.07117413668311201, 0.05203751374210697, 0.04076748176885303, 0.022677144188492093, 0.01809107416193001, 0.03276954550528899, 0.02731757838773774, 0.02271784542244859, 0.06597427156521007, 0.0699275809165556, 0.0072175883906311356, 0.019317517726449296, 0.014379148342413828, 0.007995647665666183, 0.005673633640981279, 0.04418686781718861, 0.03694473474752158, 0.018212483955721837, 0.02617061141791055, 0.04168850187852513, 0.0621419471281115, 0.03493467971566133, 0.02756282850896241, 0.08149307672283612, 0.08495663540088572, 0.06128243992861826, 0.08868275850545615, 0.07925968719064258, 0.05213322481722571, 0.030530597286997363, 0.03633903463196475, 0.047272973897634074, 0.06995635398197919, 0.023204260141937993, 0.027732292364817113, 0.0567881902679801, 0.08839217058266513, 0.016268676736217458, 0.01998079736949876, 1.2215741258114576, 19.523852057754993, 50.64142920076847, 53.94554950296879, 44.813127145171165, 32.68203489482403, 39.11789394915104, 44.82948146760464, 30.838394723832607, 6.482534324750304, 0.23862309870310128, 0.2914309431798756, 0.5790465942118317, 3.44352840911597, 9.870635345578194, 6.9699902180582285, 7.082006307318807, 5.178977223113179, 7.9007379245013, 18.455246798694134, 34.53469768166542, 45.85097685456276, 48.99386040866375, 55.66813386976719, 51.13497331738472, 48.40114161372185, 46.873760372400284, 38.25049549341202, 39.74306680262089, 41.33876457810402, 46.00856579840183, 45.4131643474102, 49.88322548568249, 50.5776572227478, 50.185970440506935, 48.22669297456741, 48.24626572430134, 48.65176096558571, 50.322375521063805, 50.080925077199936, 48.559935092926025, 46.694641783833504, 46.58785991370678, 50.241238474845886, 48.55674706399441, 51.39102257788181, 51.92246966063976, 49.34195972979069, 42.404322400689125, 37.53972843289375, 37.07831159234047, 37.948757484555244, 39.4444028288126, 43.39298754930496, 39.76146161556244, 37.53382734954357, 37.840915471315384, 36.99509605765343, 36.613300144672394, 39.804300516843796, 43.70414525270462, 44.56451028585434, 45.712827667593956, 44.08651873469353, 47.85361759364605, 48.13835151493549, 51.99336625635624, 46.88856437802315, 43.80813807249069, 52.29623660445213, 48.37933078408241, 46.39794610440731, 41.9677372276783, 40.110879465937614, 39.60492141544819, 36.987162083387375, 35.490524992346764, 37.041392773389816, 36.457455307245255, 36.58581621944904, 35.95537684857845, 36.96152105927467, 37.07583412528038, 44.315524846315384, 50.84658019244671, 50.15752516686916, 50.767848417162895, 51.91428869962692, 49.7512661665678, 48.18614535033703, 48.78639534115791, 48.18294212222099, 47.421630173921585, 49.74000737071037, 54.296468272805214, 50.645369589328766, 49.440040066838264, 48.65363426506519, 47.06461653113365, 44.14826542139053, 44.11097802221775, 44.37686875462532, 45.351493656635284, 42.315464168787, 41.137998551130295, 37.51863196492195, 37.070187628269196, 38.89618344604969, 40.58986656367779, 46.98248773813248, 53.904188722372055, 54.30869221687317, 55.50389148294926, 52.8554829955101, 56.87805354595184, 55.60672536492348, 54.27633695304394, 55.037553906440735, 43.12425836920738, 26.43851011991501, 10.812589600682259, 6.130439518019557, 5.162715995684266, 4.865349652245641, 4.890637770295143, 0.9014833986293525, 0.11525148205691949, 0.8584245841484517, 15.1125462166965, 40.368049666285515, 41.060744896531105, 35.316767916083336, 38.06746691465378, 53.94377499818802, 47.18581102788448, 18.017132207751274, 1.3618321996182203, 0.04611445539921988, 0.02286830287630437, 0.05699491550331004, 0.055519704037578776, 0.024850330701156054, 0.061002093643764965, 0.05614620284177363, 0.017442516873416025, 0.1266710864729248, 0.02477754827850731, 0.04234002219163813, 0.020205835098749958, 0.034576348552946, 0.02584794972790405, 0.016709334340703208, 0.060033620611648075, 0.03826376865617931, 0.030479943852697033, 0.10114009317476302, 0.13327927328646183, 0.14596336375689134, 0.12841161573305726, 0.15798930282471702, 0.2780424209777266, 0.2667846641270444, 0.11310266025247984, 0.1686910871649161, 0.15090689848875627, 0.17462344461819157, 0.09909132029861212, 0.18186325847636908, 0.17445119214244187, 0.1626991797820665, 0.1144834111619275, 0.10610091252601705, 0.13883979991078377, 0.34015391778666526, 0.1556483909371309, 0.1110031244752463, 1.8454352184198797, 22.80846230685711, 59.13047768175602, 60.918391942977905, 52.80561067163944, 40.00211030244827, 42.73317575454712, 46.6777440905571, 36.13228775560856, 8.541710805147886, 0.5114630644675344, 0.43226554698776454, 2.8655570978298783, 5.8417348098009825, 13.24544420465827, 16.473556235432625, 6.040817527100444, 4.8824981320649385, 7.771409014239907, 18.418734557926655, 34.68355089426041, 47.059346213936806, 49.0521302819252, 57.42030344903469, 52.38558880984783, 50.82477316260338, 48.25254298746586, 41.992071121931076, 42.2859625518322, 43.00534375011921, 48.738316521048546, 49.0577045828104, 53.297467678785324, 53.348704129457474, 51.11941695213318, 50.28440035879612, 47.60668024420738, 50.44670484960079, 52.63753429055214, 51.44736975431442, 50.830111876130104, 48.82070749998093, 49.130622670054436, 52.69730128347874, 48.8428071141243, 53.96392911672592, 55.330689176917076, 51.51514671742916, 43.68218623101711, 40.358101800084114, 39.49567727744579, 39.591462537646294, 41.25283978879452, 45.04684120416641, 42.31967054307461, 40.11924281716347, 39.515428617596626, 38.193623945117, 37.000411972403526, 42.18814440071583, 46.63262531161308, 46.0630738735199, 48.57240982353687, 46.107774674892426, 49.90881711244583, 50.22054858505726, 53.545856550335884, 48.264793530106544, 46.653018817305565, 53.42254936695099, 50.818708688020706, 48.900780603289604, 43.70259113609791, 42.22108103334904, 42.03286953270435, 38.62185716629028, 37.06540748476982, 39.08194787800312, 38.302852883934975, 38.53509642183781, 38.67305941879749, 38.96235689520836, 38.35854269564152, 45.37735126912594, 52.57948860526085, 52.31832101941109, 52.55124092102051, 53.47719803452492, 50.91883331537247, 51.45038299262524, 51.40562519431114, 50.83050325512886, 50.37141568958759, 52.97751344740391, 57.63397738337517, 51.25538885593414, 51.41132488846779, 51.40427626669407, 50.51977872848511, 48.263558596372604, 47.0795801281929, 49.073572531342506, 48.75066205859184, 47.73269288241863, 46.551685854792595, 40.791852325201035, 39.188592955470085, 40.96590578556061, 42.86000154912472, 48.99019740521908, 56.579587161540985, 56.772005036473274, 56.42377272248268, 52.91422784328461, 57.57562771439552, 59.08015698194504, 57.61487200856209, 58.51854331791401, 42.952404990792274, 29.51356541365385, 11.822588704526424, 5.648659570142627, 8.263817466795444, 10.05361832678318, 9.583183620125055, 3.279663152061403, 0.5968631850555539, 1.4543732651509345, 17.6273700222373, 49.03110221028328, 46.523327976465225, 41.881398260593414, 45.126283541321754, 62.69191637635231, 51.57250463962555, 20.470512360334396, 2.0060211326926947, 0.2256680649588816, 0.1846181700238958, 0.17783180839614943, 0.12156838332884945, 0.14020416419953108, 0.1176608051173389, 0.1273082647821866, 0.08841366317938082, 0.17437196045648307, 0.15778970962855965, 0.11766752155381255, 0.1216917356941849, 0.1271314109908417, 0.12175449170172215, 0.08080881656496786, 0.19026572088478133, 0.1199588950839825, 0.1302532700356096], [0.08988562403828837, 0.009475079168623779, 0.03526846434397157, 0.01263555308469222, 0.10106912901392207, 0.08972532756160945, 0.08000360117875971, 0.054534992814296857, 0.03380825168278534, 0.024052466287685093, 0.049398388364352286, 0.08265582917374559, 0.061401632556226104, 0.017805289789976086, 0.030509666867146734, 0.024606837614555843, 0.05972630468022544, 0.07256167082232423, 0.035377292879275046, 0.03227280751161743, 0.03985211682447698, 0.37547397252637893, 7.801332883536816, 37.406446784734726, 47.314920499920845, 40.998755022883415, 31.347100026905537, 29.681966677308083, 35.101691856980324, 29.720143228769302, 10.82814121618867, 0.35679227497894317, 0.1871336202020757, 0.3551761741982773, 3.028628909960389, 7.849787408486009, 3.895900547504425, 8.072375189512968, 4.1283677984029055, 4.345378903672099, 11.234290022403002, 26.597647480666637, 40.56716278195381, 51.49971194565296, 52.244855761528015, 48.70544068515301, 43.215920850634575, 42.5464803725481, 39.96110290288925, 42.91310369968414, 44.837103858590126, 46.35550618171692, 48.0496034771204, 51.12291656434536, 50.038606747984886, 51.349228620529175, 49.4274665415287, 50.47529451549053, 47.48303487896919, 47.816235199570656, 49.57010708749294, 48.69078487157822, 48.18258114159107, 50.539670661091805, 48.39272886514664, 46.10348090529442, 49.362151846289635, 50.120112374424934, 45.247622430324554, 42.63700291514397, 35.51246501505375, 36.94045878946781, 36.98724187910557, 36.08934625983238, 37.99855001270771, 39.13414567708969, 37.069724053144455, 36.37560769915581, 35.27639888226986, 36.05670601129532, 39.80124168097973, 46.564943343400955, 45.20949527621269, 45.944391041994095, 44.071699529886246, 47.78277799487114, 45.70467330515385, 51.56362071633339, 46.78108714520931, 43.87672059237957, 50.39552919566631, 46.712565422058105, 44.015086367726326, 38.6981912702322, 35.61901889741421, 36.75635866820812, 35.52892953157425, 35.183843448758125, 36.32587216794491, 35.42733058333397, 36.34200990200043, 35.89001655578613, 35.355039462447166, 36.22326247394085, 40.487218871712685, 46.411275789141655, 49.458032101392746, 49.822022169828415, 49.72185954451561, 49.80471029877663, 49.570031091570854, 45.44335372745991, 48.835420310497284, 51.232692673802376, 49.46122393012047, 50.93899883329868, 46.25776782631874, 53.06241989135742, 49.07524064183235, 48.838156163692474, 49.62150312960148, 49.37722563743591, 46.76257073879242, 47.35387980937958, 49.320870861411095, 47.49691553413868, 41.57183267176151, 38.69252197444439, 36.501608937978745, 35.77498532831669, 40.698590129613876, 47.385368719697, 52.04996041953564, 56.00928716361523, 54.57801416516304, 53.10429364442825, 55.9928834438324, 52.45946444571018, 47.93012648820877, 31.273326985538006, 17.935164906084538, 6.780846817418933, 4.212761269882321, 5.155602777376771, 3.767030700109899, 2.7926425728946924, 0.8588918996974826, 0.058147144300164655, 1.275974737945944, 12.78147580102086, 44.923917800188065, 45.951295271515846, 36.50564432144165, 38.96176412701607, 50.26321269571781, 35.54230481386185, 9.556813035160303, 0.8107870747335255, 0.0051257533232274, 0.028844925727753434, 0.012109055896871723, 0.025957848811231088, 0.052398950792849064, 0.039052686479408294, 0.05476648722833488, 0.009634951693442417, 0.03181627907906659, 0.03517535449645948, 0.024718488166399766, 0.01027064199661254, 0.01606517798791174, 0.02918281443271553, 0.047920538563630544, 0.05257114389678463, 0.05501085048308596, 0.08456161987851374, 0.04712529764219653, 0.028717294881062116, 0.09886365907732397, 0.08985115127870813, 0.024133879887813237, 0.07461868153768592, 0.09340645425254479, 0.05383944087952841, 0.05580234355875291, 0.020146596871200018, 0.08162596568581648, 0.018946147029055282, 0.10487760082469322, 0.00038831482754630997, 0.01910761980980169, 0.066309098911006, 0.021926875560893677, 0.0393908831756562, 0.03329124934680294, 0.0320465155527927, 0.02023544493567897, 0.5678227089811116, 11.339341085404158, 45.78508839011192, 52.74452514946461, 45.655895322561264, 35.02829119563103, 31.492879204452038, 38.5073085129261, 33.97110432386398, 12.415047213435173, 0.5282715812791139, 0.31425554654560983, 0.7106200559064746, 1.7881281184963882, 6.813709354028106, 6.700163846835494, 9.03732581064105, 8.138029966503382, 4.943789793178439, 13.230573702603579, 30.951279066503048, 42.332624047994614, 53.04968297481537, 53.61877463757992, 49.95667554438114, 46.167287081480026, 44.66176986694336, 41.569237411022186, 44.371925219893456, 46.833645924925804, 49.65792037546635, 50.43952703475952, 52.81693026423454, 49.807119369506836, 49.62380200624466, 50.23795165121555, 49.77976083755493, 47.22863852977753, 50.270709693431854, 50.687095150351524, 50.69960027933121, 49.39901366829872, 51.604966297745705, 51.50413490831852, 47.67176695168018, 51.4834526181221, 52.6960701495409, 46.82007685303688, 43.22055660188198, 36.70682832598686, 38.430442437529564, 37.539508044719696, 37.76727922260761, 41.31934382021427, 39.92954179644585, 39.24552910029888, 38.31066906452179, 36.3674533367157, 38.89856971800327, 41.306097730994225, 47.5932327657938, 47.64599673449993, 48.98366175591946, 45.584223568439484, 48.20959769189358, 47.65661336481571, 53.95845741033554, 48.41573663055897, 46.63131818175316, 51.86672665178776, 46.89020588994026, 47.54108056426048, 40.86379386484623, 38.026166930794716, 39.23583202064037, 37.4183439463377, 36.77757292985916, 36.707535088062286, 37.45512217283249, 37.93722130358219, 37.62032210826874, 36.578494012355804, 37.023229748010635, 43.04824344813824, 48.63199822604656, 52.959339022636414, 52.183200269937515, 51.64272867143154, 51.71186216175556, 51.28066509962082, 46.363143771886826, 50.708260014653206, 52.329192236065865, 52.50300630927086, 53.70760627090931, 48.58267307281494, 53.82334046065807, 50.628604888916016, 50.39796486496925, 50.87010093033314, 50.02585083246231, 48.550416603684425, 49.940005838871, 52.394012957811356, 48.31059627234936, 42.402555495500565, 39.63793784379959, 37.64874458312988, 38.68643470108509, 43.68584543466568, 49.881010204553604, 54.17370446026325, 58.07741358876228, 53.95474500954151, 55.16642399132252, 58.36481496691704, 54.59176182746887, 50.44007420539856, 34.59176681935787, 19.755742214620113, 5.978950671851635, 6.917127454653382, 5.614593448117375, 4.0195615869015455, 3.6932384222745895, 0.737140792189166, 0.18607145844725892, 1.3520389376208186, 16.142726987600327, 48.79322737455368, 45.05525015294552, 39.3685133010149, 40.59108629822731, 55.55825136601925, 41.38361357152462, 13.284974433481693, 0.896997501840815, 0.024685898606549017, 0.02363299143326003, 0.031270407198462635, 0.008609467804490123, 0.029663744680874515, 0.0248448759157327, 0.0012155381682532607, 0.010105430646945024, 0.05495647703355644, 0.030623400998592842, 0.06823358431574889, 0.01290239320951514, 0.04632525502529461, 0.03457241145952139, 0.025376335288456175, 0.023514774729846977, 0.024317446404893417, 0.04021789543912746, 0.23720023833448067, 0.12918359774630517, 0.1632031425833702, 0.1050255999143701, 0.30755012354347855, 0.24273801071103662, 0.22786923043895513, 0.25525747798383236, 0.14142406202154234, 0.15205176518065855, 0.13706959958653897, 0.15222900488879532, 0.19323460845043883, 0.11659337411401793, 0.14893563551595435, 0.291016943519935, 0.12304594740271568, 0.19895417732186615, 0.08685625143698417, 0.13760068046394736, 0.1520460654865019, 0.7478913653176278, 13.09974292293191, 52.201731875538826, 60.46756513416767, 53.65218244493008, 43.47614988684654, 39.30400416254997, 47.85970866680145, 40.68807229399681, 15.903578270226717, 0.8417533349711448, 0.8121402771212161, 1.391447929199785, 8.725244756788015, 17.10562191903591, 11.562888789921999, 13.524337839335203, 7.2215257957577705, 7.657586121931672, 14.573238305747509, 32.99503169953823, 43.09401959180832, 55.65074600279331, 56.13401547074318, 52.41621896624565, 48.428811728954315, 46.44148796796799, 43.760298639535904, 46.89342051744461, 49.46874372661114, 51.763710379600525, 52.234744504094124, 54.15499426424503, 52.15687148272991, 51.868010982871056, 51.13445274531841, 51.083330288529396, 49.48548562824726, 50.56243143975735, 53.07507321238518, 52.9825633764267, 51.0498046875, 53.66864316165447, 51.567317917943, 47.09556967020035, 52.79628977179527, 56.166382133960724, 49.23569843173027, 44.98286023736, 38.93227770924568, 41.10779017210007, 40.60631588101387, 39.45130705833435, 40.69361999630928, 41.994248405098915, 41.63575664162636, 40.996277555823326, 39.12351004779339, 40.56915767490864, 43.110316917300224, 50.20194098353386, 49.84282985329628, 52.235732451081276, 48.974261060357094, 50.249529629945755, 51.31522424519062, 54.49238955974579, 51.41367316246033, 50.085709020495415, 54.44671981036663, 51.41675479710102, 48.71913895010948, 41.910709887742996, 38.9534729719162, 40.591124296188354, 39.191336408257484, 40.21079130470753, 40.58452025055885, 38.958074524998665, 40.88132232427597, 40.071699768304825, 38.86284403502941, 39.227601662278175, 44.88472290337086, 51.15289695560932, 54.523335099220276, 53.72121334075928, 53.61890383064747, 54.331635385751724, 55.62516197562218, 48.79594802856445, 53.73798944056034, 54.202852696180344, 54.420877397060394, 54.410192370414734, 51.39286547899246, 56.97676844894886, 54.83373284339905, 53.561644703149796, 53.84278401732445, 53.56964707374573, 49.8585420101881, 52.563791647553444, 55.20657643675804, 52.81412221491337, 45.50829604268074, 41.8364542722702, 39.65474434196949, 39.724189415574074, 45.609256625175476, 53.78979206085205, 57.08964139223099, 61.03506088256836, 56.15434817969799, 54.20128718018532, 59.614301919937134, 55.51588363945484, 52.08003580570221, 34.87428165972233, 20.266189724206924, 8.628375604748726, 12.468482796102762, 9.420870579779148, 12.336572874337435, 8.304294794797897, 1.4717264589853585, 0.2450578604475595, 1.8423780449666083, 17.955235429108143, 57.76894994080067, 55.7200238853693, 47.03190788626671, 50.33551521599293, 64.7717347741127, 49.894191697239876, 15.01191146671772, 1.3251639297232032, 0.21948251640424132, 0.10673576791305095, 0.13430355582386255, 0.11647158768028021, 0.11031124988221563, 0.12887866410892457, 0.09084705408895388, 0.10357499806559645, 0.15785785362822935, 0.16703875473467633, 0.17991682776482776, 0.10021810085163452, 0.08638085389975458, 0.08821991810691543, 0.14546769816661254, 0.15772508340887725, 0.10621549270581454, 0.1779460842953995], [0.027369875679141842, 0.025643935186963063, 0.06407059598132037, 0.04463617515284568, 0.03211366136383731, 0.04536801439826377, 0.05091602470201906, 0.04868687654379755, 0.012158846584497951, 0.049306065193377435, 0.08228759776102379, 0.051200033485656604, 0.018673289014259353, 0.012905052881251322, 0.02908187307184562, 0.09124910517130047, 0.008145383380906424, 0.029634593120135833, 0.03402147442102432, 0.06583514856174588, 0.04687128646764904, 0.06758497693226673, 5.434555308893323, 27.5575652718544, 47.90753290057182, 44.62546281516552, 32.87505693733692, 34.603576585650444, 32.57860824465752, 32.72886358201504, 17.715287804603577, 1.0314174857921898, 0.22935659828362986, 0.2517439430812374, 0.9677367622498423, 7.156628603115678, 4.679096946492791, 9.602650925517082, 12.981707006692886, 3.903947090730071, 8.311271220445633, 26.810130178928375, 39.59025800228119, 49.139001220464706, 48.95091891288757, 49.69556875526905, 46.13801345229149, 42.95435428619385, 45.97589895129204, 47.61549577116966, 47.53214344382286, 47.68479265272617, 50.13919495046139, 51.82493269443512, 51.89315423369408, 51.50305196642876, 48.557499423623085, 50.76583452522755, 51.327208802103996, 48.56332831084728, 46.48602157831192, 48.34761768579483, 49.35150861740112, 50.16428120434284, 48.80599848926067, 47.29474738240242, 48.47351633012295, 49.48228619992733, 46.95977635681629, 45.226210579276085, 41.81591637432575, 37.23920255899429, 35.423116609454155, 35.405056178569794, 34.674081802368164, 35.7424970716238, 34.615333154797554, 34.63175967335701, 36.752467676997185, 37.759751826524734, 41.35748617351055, 47.12083451449871, 47.55832403898239, 47.7680803835392, 46.23146563768387, 48.089953511953354, 47.72385835647583, 51.56926341354847, 44.67474237084389, 42.57524482905865, 51.04087516665459, 46.89437806606293, 45.75803384184837, 36.91533073782921, 36.86977118253708, 36.8119040876627, 34.888899475336075, 34.91844289004803, 34.619060754776, 35.96388079226017, 36.66506476700306, 35.58159090578556, 34.78408969938755, 35.69851443171501, 38.74841697514057, 44.716802313923836, 45.902665480971336, 48.22600521147251, 51.673294231295586, 52.66085363924503, 50.56055434048176, 51.014531180262566, 46.46857671439648, 50.82792319357395, 49.67600740492344, 43.293698877096176, 47.392573133111, 46.972779259085655, 52.67289139330387, 50.26621833443642, 51.630341336131096, 50.97014956176281, 49.263999313116074, 51.55698627233505, 51.03193424642086, 47.741990983486176, 48.62033665180206, 45.02576373517513, 43.12305383384228, 41.54295042157173, 40.90791329741478, 47.36145660281181, 50.2850691229105, 55.979306772351265, 51.82793453335762, 52.98459246754646, 55.41670896112919, 56.012099012732506, 38.929811641573906, 27.163891196250916, 12.160575818270445, 2.767776232212782, 5.604498339816928, 3.265780359506607, 3.8604850228875875, 3.1382041051983833, 0.3863637725589797, 0.12966146663529798, 1.767807046417147, 16.975879780948162, 34.09080930054188, 35.50806105136871, 33.3814899623394, 45.140031203627586, 51.73258624970913, 37.94488549232483, 6.2999203987419605, 0.15132649394217879, 0.023308062482101377, 0.0329055440670345, 0.03157521095999982, 0.01664602357777767, 0.07494407618651167, 0.018015284185821656, 0.01063203173544025, 0.04733209338155575, 0.06859621993498877, 0.04022781053208746, 0.031000740418676287, 0.040721928744460456, 0.046403124870266765, 0.043833486779476516, 0.026926065802399535, 0.049363017606083304, 0.04088547211722471, 0.05610644227999728, 0.04009112548374105, 0.024209517723647878, 0.009667601552791893, 0.07683859366807155, 0.01821380683395546, 0.08472488494589925, 0.0060013363690814, 0.03855323222524021, 0.04052403506648261, 0.032831993521540426, 0.0549430961109465, 0.010763093159766868, 0.01237745917023858, 0.01594848268723581, 0.03048451733775437, 0.10550596241955645, 0.03402419068152085, 0.06854115257738158, 0.06635441444814205, 0.03432828569202684, 0.024300503173435573, 0.0638599373633042, 7.05244199372828, 32.72213414311409, 56.18072256445885, 49.49168689548969, 35.75436383485794, 37.43191301822662, 39.339285269379616, 37.3701511323452, 18.99252276867628, 1.3249499537050724, 0.23603481415193528, 0.2613388141617179, 2.7381520718336105, 8.317501936107874, 8.308722507208586, 10.108172949403524, 9.283951576799154, 6.900446824729443, 12.610582821071148, 30.935230627655983, 42.072034031152725, 52.311355993151665, 50.79938292503357, 53.29398326575756, 47.59801670908928, 44.320757165551186, 46.954103261232376, 50.19885554909706, 48.13144348561764, 50.45959755778313, 50.897470861673355, 52.71916151046753, 51.85197964310646, 53.56802076101303, 50.546077117323875, 52.50289611518383, 52.406651079654694, 49.076521173119545, 47.44632124900818, 48.20219188928604, 50.94051115214825, 51.153835505247116, 48.53451445698738, 47.037675976753235, 49.489270225167274, 52.53033064305782, 48.24667610228062, 47.419726476073265, 42.79204219579697, 39.45640258491039, 38.59767146408558, 37.17576116323471, 36.152856051921844, 36.81484892964363, 37.844947054982185, 36.20463207364082, 37.542939260602, 39.07645337283611, 44.17986452579498, 49.83877167105675, 48.71723145246506, 51.181593015789986, 49.4699140638113, 51.539461612701416, 48.33694785833359, 51.770648807287216, 47.14289613068104, 44.404922649264336, 51.22519947588444, 48.3860070258379, 48.324408531188965, 39.50532115995884, 38.55930872261524, 38.710825592279434, 36.77519805729389, 36.54914438724518, 36.81931748986244, 36.64753630757332, 38.19824829697609, 36.85546875, 37.17782445251942, 36.629768460989, 41.03557504713535, 46.57559037208557, 49.66100201010704, 51.245494186878204, 51.75681374967098, 53.67015168070793, 51.806587278842926, 52.813236862421036, 49.82195757329464, 53.17395530641079, 50.563347190618515, 44.06662680208683, 48.14483016729355, 47.969936951994896, 55.7987442612648, 53.9073121547699, 53.52244980633259, 53.41477498412132, 51.713750660419464, 53.1425765901804, 52.15656369924545, 50.65933384001255, 50.983171463012695, 46.83254398405552, 42.844350188970566, 42.96699620783329, 43.86841043829918, 50.5062248557806, 53.01432587206364, 58.14639888703823, 53.64526681602001, 53.8905930519104, 57.73263908922672, 57.43211701512337, 43.17929081618786, 29.25586324185133, 16.192263029515743, 6.50899562984705, 8.194607980549335, 9.9946597404778, 6.1373978946357965, 2.9990664962679148, 0.3724889358272776, 0.1420070041785948, 2.041373485699296, 18.19222491234541, 42.601919397711754, 42.695553973317146, 38.220454305410385, 49.84118454158306, 59.43001560866833, 43.2182577252388, 8.573464751243591, 0.2672803000314161, 0.029956789112475235, 0.05630495565128513, 0.030974457258707844, 0.03409054610528983, 0.043581271602306515, 0.036998733412474394, 0.12294408021261916, 0.01112699692384922, 0.05845105377375148, 0.1021264297014568, 0.020481682113313582, 0.08468046740745194, 0.04240204347297549, 0.011430864651629236, 0.04247837336151861, 0.012654078946070513, 0.04735153393994551, 0.047990690072765574, 0.22398111876100302, 0.1159808796364814, 0.19476027111522853, 0.1824968002620153, 0.1721788547001779, 0.20296658389270306, 0.15142205287702382, 0.13790555472951382, 0.12002676448901184, 0.1836219703545794, 0.21443450212245807, 0.1400271026068367, 0.08535044864402153, 0.0751594771281816, 0.11310577727272175, 0.13564249413320795, 0.15560438157990575, 0.08665509230922908, 0.1257441588677466, 0.14983195695094764, 0.15050469897687435, 0.20310584048274904, 7.769677732139826, 37.1564581990242, 62.259241193532944, 56.47910915315151, 42.41550900042057, 43.93963761627674, 44.618152007460594, 43.78348879516125, 23.05047322064638, 2.2496281983330846, 0.6017311394680291, 1.1917630629613996, 5.4948770720511675, 17.0027082413435, 10.688531007617712, 19.15247518569231, 20.297524742782116, 9.840852543711662, 11.031657345592976, 31.228039115667343, 43.36507044732571, 52.822128385305405, 54.50900986790657, 55.05626790225506, 50.6916207075119, 46.4646515250206, 51.39386102557182, 53.62663261592388, 50.72331860661507, 50.9010274708271, 52.1648358553648, 55.01867271959782, 55.026895478367805, 56.64730712771416, 51.87774986028671, 55.441084653139114, 53.70903879404068, 49.48013551533222, 47.47267663478851, 49.5480340719223, 51.03799112141132, 53.891729190945625, 49.34279948472977, 48.37444044649601, 50.81220343708992, 53.73991973698139, 50.333968698978424, 49.07980799674988, 45.83010457456112, 40.58995395898819, 39.57063965499401, 38.40283311903477, 37.83858239650726, 39.204954877495766, 38.95371995866299, 37.22271144390106, 39.63593915104866, 42.14744098484516, 45.01946747303009, 51.83244489133358, 50.96717432141304, 52.18856938183308, 51.72695115208626, 53.852462098002434, 51.61373242735863, 54.396326914429665, 47.19209209084511, 46.75814777612686, 53.63844618201256, 50.58500982820988, 50.436031222343445, 41.139165088534355, 41.072125285863876, 40.5030108243227, 38.26649263501167, 38.844521418213844, 37.74216257035732, 39.840444177389145, 40.42020186781883, 38.648569732904434, 38.81710208952427, 38.90137016773224, 44.244841039180756, 49.9656430631876, 52.05064818263054, 54.143154099583626, 53.79115618765354, 55.92648580670357, 54.49133321642876, 56.085921451449394, 50.34926287829876, 54.936923906207085, 51.29306763410568, 44.05474863946438, 48.47241438925266, 49.29739952087402, 56.84180349111557, 56.92705191671848, 56.567898988723755, 55.266503021121025, 53.004488199949265, 56.55257061123848, 54.68497842550278, 52.07086689770222, 53.329161778092384, 49.12714205682278, 47.83835381269455, 46.45979918539524, 45.823781713843346, 52.57047548890114, 55.819095969200134, 60.91982826590538, 54.068480506539345, 53.186213448643684, 58.04388798773289, 58.91049988567829, 43.796898275613785, 30.410038009285927, 15.451941154897213, 5.901925005018711, 9.299980066716671, 10.823093187063932, 13.634992651641369, 8.916721232235432, 1.388451314996928, 0.3110854479018599, 2.4525517970323563, 22.65325203537941, 45.54099328815937, 47.01418183743954, 45.87711565196514, 57.16920152306557, 67.00561970472336, 49.886405915021896, 10.953261852264404, 0.4066496074665338, 0.08580667650676332, 0.1494847357389517, 0.16814786475151777, 0.08034535276237875, 0.14094797428697348, 0.17552533216075972, 0.12493043846916407, 0.13945778628112748, 0.16729216848034412, 0.19713935907930136, 0.10017105611041188, 0.16257932293228805, 0.12189935150672682, 0.127000852371566, 0.1061872391437646, 0.13305615400895476, 0.09113074745982885, 0.13584447704488412], [0.03936615110433195, 0.033652382116997615, 0.0432441176235443, 0.03132643563731108, 0.06461684635723941, 0.0430500645597931, 0.02907684502133634, 0.010389327180746477, 0.009541013423586264, 0.026867321103054564, 0.04302202993130777, 0.017349217778246384, 0.046430172442342155, 0.021423422986117657, 0.02688852426217636, 0.01670400015427731, 0.04339502222137526, 0.04957367251336109, 0.030220270091376733, 0.05704880655684974, 0.02600074680231046, 0.03767523441638332, 1.3597775786183774, 17.038715109229088, 39.08309541642666, 44.24229517579079, 36.943506225943565, 25.419211015105247, 31.001894250512123, 36.52900546789169, 24.044315591454506, 2.742145420052111, 0.23028383759083226, 0.28666558326222, 1.7666382528841496, 4.453831734135747, 9.563168194144964, 5.179459322243929, 6.365584675222635, 6.207215823233128, 12.691876608878374, 27.535615749657154, 36.326521933078766, 46.16226755082607, 51.781246438622475, 48.2731606811285, 47.36740328371525, 47.82890371978283, 47.851383313536644, 50.48940695822239, 50.642394348978996, 51.36210612952709, 52.32586361467838, 48.6887101829052, 47.28661581873894, 46.36378213763237, 47.22592927515507, 45.87495356798172, 48.93614150583744, 51.232631877064705, 51.644309386610985, 50.77401548624039, 49.57398287951946, 47.49786928296089, 49.35247376561165, 50.06158031523228, 49.175676852464676, 50.091610103845596, 50.46153545379639, 47.598305493593216, 46.13775506615639, 44.90918979048729, 36.18481233716011, 34.31145966053009, 36.2002395093441, 35.80025777220726, 34.46536660194397, 35.26267021894455, 36.15243047475815, 35.139663219451904, 41.674195379018784, 48.113219663500786, 48.35444211959839, 52.163692116737366, 46.58715695142746, 50.53688161075115, 46.687011793255806, 51.115529760718346, 44.706193283200264, 44.120895490050316, 50.19199691712856, 46.0930884629488, 45.776865631341934, 37.586405128240585, 35.79072788357735, 36.195337772369385, 35.40306128561497, 35.806770622730255, 33.69981028139591, 37.952667474746704, 37.44573287665844, 35.218383595347404, 36.50427259504795, 36.67088985443115, 36.71814411878586, 41.79692879319191, 45.16986720263958, 47.23588094115257, 47.47458793222904, 48.770607188344, 50.230363458395004, 49.25826162099838, 49.296628162264824, 49.124721586704254, 49.96988743543625, 49.78560492396355, 49.931536093354225, 49.98011268675327, 47.381926104426384, 47.269873917102814, 53.66498775780201, 51.519429087638855, 51.77935034036636, 52.28106401860714, 49.93372477591038, 50.94276063144207, 49.94475178420544, 47.559243589639664, 46.83213360607624, 46.36668898165226, 47.394568026065826, 47.791084349155426, 50.75014516711235, 56.27519689500332, 53.7136859446764, 47.51715324819088, 52.16864325106144, 46.049839183688164, 35.710814371705055, 16.95110321044922, 8.2118134573102, 2.3903415352106094, 6.124011687934399, 6.133859334513545, 4.492189725860953, 1.964396859984845, 0.520106116309762, 0.0035409922793405713, 2.746873078867793, 17.282249741256237, 43.49816210567951, 31.533778309822083, 31.872176751494408, 39.73428547382355, 45.72245255112648, 28.41390062123537, 4.069749293848872, 0.0744915145332925, 0.048764557141112164, 0.033003002899931744, 0.06439069169573486, 0.03714181948453188, 0.12323037110036239, 0.057117551696137525, 0.03972687198256608, 0.02356110700930003, 0.005705276962544303, 0.02630207916809013, 0.04670875241572503, 0.04021468565042596, 0.028377174166962504, 0.04174762507318519, 0.05156529259693343, 0.04329080242314376, 0.012919427354063373, 0.03446838461968582, 0.059572869358817115, 0.0029555697256000713, 0.01218996205352596, 0.06098118734371383, 0.07455271203070879, 0.039112325466703624, 0.05844621126016136, 0.04657243473047856, 0.023478348266507965, 0.05382796727644745, 0.05119479392305948, 0.04710475870524533, 0.08472046174574643, 0.043629596548271365, 0.021168957246118225, 0.03238782555854414, 0.010274192245560698, 0.057668778172228485, 0.0391101175773656, 0.012261585798114538, 0.03600279349484481, 0.028823297689086758, 2.1621048822999, 22.438782043755054, 45.94786025583744, 50.37328138947487, 39.71687860786915, 30.86706418544054, 33.37585486471653, 42.372723296284676, 27.193345315754414, 3.4583407267928123, 0.15741777489893138, 0.2068089199019596, 2.121287710033357, 5.911153284832835, 9.389883242547512, 8.71150754392147, 9.046023543924093, 6.4912705309689045, 13.555186484009027, 27.580878920853138, 39.651069939136505, 48.614367172122, 53.07561278343201, 51.256950572133064, 48.34753409028053, 49.73927021026611, 50.801206827163696, 51.357819959521294, 51.78239777684212, 51.27886779606342, 54.128935262560844, 51.39679826796055, 49.572037383913994, 48.45803216099739, 48.83422717452049, 49.018399491906166, 50.92367425560951, 53.52496147155762, 51.9625461101532, 51.77377603948116, 51.15573540329933, 48.501030653715134, 50.74474185705185, 51.78316533565521, 51.04393780231476, 50.41125275194645, 51.39363303780556, 49.17233683168888, 47.86017224192619, 44.91491608321667, 38.78246694803238, 37.01670169830322, 38.02626572549343, 36.4402574300766, 37.95872434973717, 37.66277723014355, 37.877043932676315, 37.20424063503742, 44.16835114359856, 50.46885386109352, 51.40497922897339, 52.01628662645817, 49.259705543518066, 51.98190227150917, 50.01588776707649, 52.13138625025749, 45.98798610270023, 46.17429010570049, 52.34166696667671, 48.56714330613613, 48.79428751766682, 40.29329627752304, 38.74870575964451, 38.73792573809624, 37.090432941913605, 38.192541003227234, 35.76975300908089, 39.0588641166687, 40.51662169396877, 35.97039744257927, 37.97757513821125, 38.265953063964844, 38.41331675648689, 44.37020391225815, 47.747675478458405, 50.40073111653328, 51.80578552186489, 51.114234030246735, 52.02952891588211, 48.91627997159958, 50.814916491508484, 51.03433571755886, 50.07222734391689, 51.21851183474064, 50.02420552074909, 49.67953361570835, 48.02733287215233, 48.954445123672485, 53.93573462963104, 53.33630919456482, 53.48568677902222, 52.3255330324173, 51.332251131534576, 51.94774590432644, 52.921413257718086, 51.96432441473007, 49.3852774053812, 47.81742073595524, 50.085845813155174, 49.98766288161278, 52.74356760084629, 57.65275977551937, 54.45775821805, 48.42758059501648, 53.17074067890644, 49.01030212640762, 37.623981311917305, 21.625097505748272, 9.717868342995644, 3.467854941263795, 9.301172252744436, 7.5112915970385075, 4.77021130733192, 2.798938360065222, 0.2835512941237539, 0.04160887314355932, 2.9143680911511183, 20.958565771579742, 45.0271088629961, 33.68613861501217, 37.80234754085541, 47.63626165688038, 52.87692904472351, 36.38155058026314, 5.7663302309811115, 0.1552226801868528, 0.050261031137779355, 0.0060761202712456, 0.031377384075312875, 0.03071093360631494, 0.05191561227547936, 0.04510896775173023, 0.053649658875656314, 0.024587295010860544, 0.0635216070804745, 0.028579665449797176, 0.024617383533040993, 0.03667063363536727, 0.045583329992950894, 0.049949488675338216, 0.03965845338825602, 0.05565468956774566, 0.02732658806053223, 0.01928341604070738, 0.17885432462207973, 0.15227481024339795, 0.10945400252239779, 0.09984980264562182, 0.15904080733889714, 0.1621649818844162, 0.14291570463683456, 0.23365933302557096, 0.11173439226695336, 0.2020901520154439, 0.0845682027284056, 0.14957665815018117, 0.15093198308022693, 0.1137697471131105, 0.13698486116481945, 0.14987938018748537, 0.09305463914643042, 0.25457517709583044, 0.10782437981106341, 0.12143199885031208, 0.11613694587140344, 0.15516690036747605, 2.1984767680987716, 25.185363963246346, 54.10415679216385, 56.91368043422699, 48.95590044558048, 36.12213470041752, 42.94552356004715, 47.18384273350239, 31.372817046940327, 4.0916437190026045, 0.4237365780863911, 1.0338104073889554, 3.8829831406474113, 7.471255995333195, 19.716074243187904, 17.849470004439354, 16.340380981564522, 10.07692152634263, 15.796963591128588, 32.23262540996075, 40.66716581583023, 51.056625321507454, 53.57185855507851, 56.1764819920063, 51.2417171895504, 54.03182007372379, 51.85384914278984, 54.59638237953186, 53.18045295774937, 53.19247931241989, 56.497994139790535, 52.41560719907284, 52.033074125647545, 51.24149300158024, 51.049732491374016, 50.37345618009567, 51.25681757926941, 57.08838365972042, 53.507501408457756, 53.6016945540905, 51.475001871585846, 49.63104821741581, 53.479382917284966, 53.25166493654251, 51.84616215527058, 53.675437197089195, 55.07433593273163, 52.12675429880619, 49.22973655164242, 47.22276784479618, 39.78845916688442, 37.797286212444305, 39.72729004919529, 39.37644727528095, 38.70793394744396, 40.61738848686218, 40.05370773375034, 38.78863021731377, 47.45009444653988, 52.08094775676727, 53.160667419433594, 55.81720747053623, 49.169965758919716, 55.11554852128029, 52.04013794660568, 52.9576975107193, 46.763269901275635, 49.591040164232254, 54.732114896178246, 51.409519985318184, 50.658197700977325, 41.489624083042145, 39.30253364145756, 39.78326864540577, 39.09508377313614, 39.55773934721947, 36.91570311784744, 42.13681675493717, 42.12161757051945, 37.72780694067478, 40.5215310305357, 39.28586393594742, 40.55679313838482, 46.442840695381165, 49.81511794030666, 52.53017485141754, 53.48909519612789, 52.466934844851494, 53.26890081167221, 52.044188529253006, 51.67011380195618, 52.74207428097725, 52.23654180765152, 51.807100251317024, 51.85617081820965, 51.31609819829464, 50.41173532605171, 49.209643229842186, 57.57585950195789, 55.297304168343544, 55.43676808476448, 54.50549125671387, 51.98322840034962, 54.92514833807945, 54.38839673995972, 54.0791617333889, 52.222011387348175, 50.53748577833176, 52.28126160800457, 53.613052144646645, 55.89650921523571, 60.91490373015404, 55.620442628860474, 49.918381199240685, 53.058384507894516, 47.60311223566532, 38.83043557405472, 21.055356077849865, 10.970024652779102, 5.092072561383247, 11.510644443333149, 15.159394852817059, 11.74951197579503, 6.3129897974431515, 1.35497439885512, 0.2045660457224585, 3.9831030182540417, 25.21075990051031, 55.27527675032616, 43.15371058881283, 44.54482354223728, 52.85292573273182, 60.44441297650337, 40.86329989135265, 7.164359288290143, 0.3252710070228204, 0.1514360646251589, 0.14711355906911194, 0.13673961104359478, 0.1252356095938012, 0.20829823217354715, 0.15726748999441043, 0.12110621086321771, 0.08054637830355205, 0.19698977179359645, 0.11797312312410213, 0.10589576806523837, 0.10256215202389285, 0.10471510759089142, 0.12017612913041376, 0.13843193039065227, 0.17214538383996114, 0.1477903829072602, 0.1715172894182615], [0.04357079247711226, 0.05338809634849895, 0.04075729950272944, 0.014821599161223276, 0.11246652094996534, 0.039310560532612726, 0.016192361690627877, 0.019214502062823158, 0.048527032777201384, 0.070222510403255, 0.06663747699349187, 0.0975228802417405, 0.09918847485096194, 0.06162645877338946, 0.06321313339867629, 0.050129299925174564, 0.02105489285895601, 0.09182682260870934, 0.020109942197450437, 0.054132834120537154, 0.012758996363118058, 0.034836842387448996, 0.33815860922914, 12.331445999443531, 38.667359724640846, 47.67846219241619, 36.42774470150471, 26.342878751456738, 33.22409100830555, 35.81617131829262, 32.66824163496494, 5.343847526237369, 0.2904969948576763, 0.11051072433474474, 1.8604489252902567, 8.05115807801485, 5.410663615912199, 8.214845694601536, 7.089890409260988, 7.04329683445394, 14.620560016483068, 20.049384757876396, 38.14942851662636, 46.09387122094631, 51.44370295107365, 53.37152570486069, 48.61015699803829, 50.598453506827354, 49.06560815870762, 51.30456201732159, 52.58036255836487, 50.696150064468384, 47.71787367761135, 46.86927281320095, 45.94868861138821, 44.40173082053661, 44.794063568115234, 44.986010268330574, 48.221479654312134, 49.21212449669838, 49.48240019381046, 49.93480771780014, 46.81046336889267, 46.74000754952431, 45.72293892502785, 49.90292742848396, 51.29528671503067, 50.21364815533161, 51.226278617978096, 50.90638518333435, 48.29987704753876, 50.61427965760231, 42.757456451654434, 35.20219266414642, 34.88937824964523, 35.02371624112129, 36.18006259202957, 34.70690444111824, 36.73889480531216, 37.00874872505665, 38.88519823551178, 46.910025626420975, 47.32493296265602, 49.28705267608166, 47.8988503664732, 51.44827410578728, 47.946233823895454, 49.62618447840214, 43.54153297841549, 42.82784767448902, 51.98959305882454, 45.36480434238911, 46.057351380586624, 38.99205230176449, 35.48672139644623, 35.08427359163761, 35.59093840420246, 35.38518324494362, 35.76150365173817, 35.34814663231373, 35.72091802954674, 35.38657397031784, 35.311098620295525, 36.07362650334835, 36.36236160993576, 37.052146196365356, 43.616700544953346, 46.18529811501503, 47.53047153353691, 47.78726175427437, 47.858184948563576, 49.494863525033, 50.72179488837719, 49.147702753543854, 50.34302741289139, 48.802415281534195, 51.71878919005394, 49.19233895838261, 49.19772706925869, 51.684526428580284, 50.36992236971855, 48.369873091578484, 46.86967559158802, 48.616745844483376, 50.175483003258705, 48.01971808075905, 50.63861355185509, 52.84430779516697, 50.80079644918442, 51.54532849788666, 50.44529892504215, 52.003488913178444, 53.483988270163536, 55.565793961286545, 49.692597314715385, 53.13316449522972, 52.577786296606064, 36.40108533203602, 27.309626676142216, 13.226069044321775, 4.329380337148905, 4.636579602956772, 12.063467279076576, 8.734340518712997, 3.4281945694237947, 1.9580424134619534, 0.2532709564547986, 0.04369276444776915, 2.7446794090792537, 18.731497675180435, 40.55085025727749, 30.97747676074505, 29.8386512696743, 41.860628575086594, 46.01255178451538, 23.93531274050474, 3.1410691514611244, 0.10735008065239526, 0.06026423186995089, 0.07543063562479801, 0.03251897418522276, 0.04732047877041623, 0.011756427211366827, 0.04177934446488507, 0.021753038599854335, 0.036114713075221516, 0.08513071355991997, 0.05179208179470152, 0.049149408951052465, 0.02916134224506095, 0.05036700611526612, 0.02619253074954031, 0.049568629619898275, 0.052522603727993555, 0.026671165906009264, 0.024754063015279826, 0.06872667465358973, 0.01838362692069495, 0.012807653420168208, 0.042293508086004294, 0.04326982190832496, 0.038789914251537994, 0.01029468387059751, 0.08655949626700021, 0.035878817725460976, 0.010074476595036685, 0.12489135697251186, 0.05932033876888454, 0.05198593076784164, 0.029561415503849275, 0.03953032901335973, 0.03017129762156401, 0.04139194337767549, 0.05929250080953352, 0.08915472732041962, 0.08276012318674475, 0.031118890328798443, 0.027757809257309418, 0.4822280566440895, 14.97644891962409, 44.52879220247269, 53.37686441838741, 41.69431909918785, 28.416226096451283, 41.722312197089195, 42.327042147517204, 34.319002255797386, 6.270059226080775, 0.4370778106385842, 0.2735108375782147, 1.1227112682536244, 4.750773450359702, 6.213405216112733, 7.259841989725828, 6.544286711141467, 5.2786563243716955, 12.7237549982965, 22.353313229978085, 39.17645640671253, 47.523263320326805, 53.59246484935284, 54.866589680314064, 50.36106124520302, 53.02540607750416, 51.417788341641426, 52.446381747722626, 53.52882206439972, 52.647048979997635, 49.788887947797775, 49.324207082390785, 47.894222214818, 47.13652387261391, 46.53399780392647, 47.43701554834843, 49.453434348106384, 50.63096836209297, 50.60633048415184, 52.12858200073242, 47.83052243292332, 49.523263201117516, 48.20689603686333, 51.83496415615082, 51.37369550764561, 50.64768746495247, 51.60443812608719, 53.01418527960777, 51.37038968503475, 51.62169300019741, 44.207709431648254, 37.67266809940338, 36.77235580980778, 37.59547524154186, 37.10987649857998, 36.621815487742424, 36.42660476267338, 38.2563965767622, 41.12006351351738, 48.29473212361336, 49.18201111257076, 50.50066575407982, 49.11747917532921, 51.84936158359051, 48.48443694412708, 51.05478622019291, 43.680430725216866, 44.077391624450684, 54.26187492907047, 48.79246361553669, 48.13538387417793, 40.46557903289795, 38.59337389469147, 37.67872117459774, 37.49491363763809, 36.870607137680054, 36.7090056091547, 38.1774178147316, 37.54623368382454, 36.45402029156685, 37.14305251836777, 36.88722364604473, 37.68284775316715, 39.45994019508362, 44.56597700715065, 47.96885021030903, 48.14677946269512, 51.05904199182987, 50.166059508919716, 48.88427048921585, 52.03896380960941, 52.0460694283247, 51.17373503744602, 51.48880273103714, 52.52622306346893, 51.85227982699871, 52.396859005093575, 52.439013943076134, 52.8638007491827, 49.82519119977951, 50.45640952885151, 50.030106604099274, 52.40183673799038, 50.53862951695919, 51.2128197401762, 55.642139464616776, 53.55326235294342, 53.265670984983444, 51.045495718717575, 53.41615051031113, 55.53047485649586, 56.60378806293011, 50.5997796356678, 53.51031705737114, 52.17433154582977, 38.57374794781208, 29.352022781968117, 15.128638353198767, 6.271270411089063, 6.193476235494018, 6.3199785724282265, 6.302876165136695, 7.438739715144038, 2.679569902829826, 0.3181499516358599, 0.06613585937884636, 3.01166377030313, 21.770859584212303, 48.99029240012169, 34.931020215153694, 33.58872324228287, 46.98400765657425, 51.95764437317848, 28.5075655952096, 4.291407549753785, 0.05630499275866896, 0.005199445804464631, 0.07776540995109826, 0.10037662359536625, 0.05034105692175217, 0.008605708826507907, 0.04138828458962962, 0.047377679802593775, 0.05211878633417655, 0.008086230500339298, 0.04356532284873538, 0.01923123563756235, 0.01786897348210914, 0.025427411746932194, 0.029305908901733346, 0.02859202963009011, 0.031317066022893414, 0.031771872672834434, 0.04329370793129783, 0.12059765416779555, 0.12614620995009318, 0.10411685492726974, 0.12848801241489127, 0.13108673156239092, 0.11304479499813169, 0.09732218866702169, 0.12396518635796383, 0.08581078058341518, 0.1938457225332968, 0.23695483978372067, 0.1180063268111553, 0.13703115633688867, 0.15308384026866406, 0.1889388498966582, 0.12986552756046876, 0.1362280931789428, 0.20728634350234643, 0.10433958828798495, 0.10597966043860652, 0.17539038002723828, 0.09166253337753005, 0.774650895036757, 17.353714406490326, 51.72103866934776, 60.573849231004715, 49.20160286128521, 36.15834675729275, 45.71296826004982, 47.23451681435108, 42.264307513833046, 8.46413416787982, 0.5215294961817563, 0.49072843801695853, 4.153415579348803, 16.34920410811901, 15.478601474314928, 13.129382282495499, 14.317863509058952, 12.315275967121124, 19.454087801277637, 24.38694130629301, 42.68949709832668, 48.48874591290951, 54.81099106371403, 57.22233787178993, 53.96633438766003, 54.66795913875103, 53.629721850156784, 53.24872009456158, 55.67742437124252, 54.74028065800667, 52.46441178023815, 52.49002240598202, 50.80980196595192, 48.50247457623482, 49.50233392417431, 50.12363098561764, 52.08158612251282, 53.14406231045723, 52.62513555586338, 53.252808675169945, 50.43377034366131, 51.877974048256874, 49.98017728328705, 53.55674296617508, 54.39425602555275, 53.178230077028275, 55.14243587851524, 54.333607479929924, 54.00316961109638, 54.70430038869381, 47.01008565723896, 40.30447147786617, 39.362008050084114, 38.52552853524685, 39.20535385608673, 38.00054490566254, 38.88400509953499, 40.5482017993927, 43.71411971747875, 48.95804353058338, 51.56658075749874, 51.986587420105934, 51.62133201956749, 53.63886035978794, 49.763315320014954, 51.07613727450371, 45.79521104693413, 46.146327406167984, 55.61335600912571, 50.89544557034969, 50.832247361540794, 43.21711018681526, 39.49883870780468, 38.099757581949234, 39.14798453450203, 39.404121190309525, 39.73048947751522, 39.70026209950447, 39.07826587557793, 40.03876693546772, 39.507126063108444, 39.51862424612045, 38.53759288787842, 40.36930739879608, 48.1684572994709, 49.33235004544258, 51.378848031163216, 53.66963490843773, 50.16815319657326, 52.157080471515656, 55.524820759892464, 53.24134089052677, 54.84840005636215, 52.32449568808079, 54.454011619091034, 53.933815732598305, 55.01873351633549, 54.17739786207676, 54.32972028851509, 52.82565459609032, 51.35137930512428, 51.38637162744999, 54.58345927298069, 50.21330617368221, 53.51857781410217, 56.29602737724781, 56.142363622784615, 57.681995406746864, 55.48896208405495, 57.032519057393074, 56.997868716716766, 56.68411575257778, 50.461455658078194, 53.76767344772816, 53.978296145796776, 37.90705852210522, 29.013730734586716, 15.386044140905142, 8.05590022355318, 10.69702260196209, 22.926402278244495, 18.00025351345539, 10.404194165021181, 4.303050599992275, 0.8832835033535957, 0.27131277427542955, 4.0274936612695456, 26.60902976989746, 53.78287263214588, 39.862380400300026, 41.15123324096203, 56.552593410015106, 59.83195424079895, 34.43253256380558, 5.939835095778108, 0.18938076915219426, 0.07406787437503226, 0.18181271821958944, 0.2144162156037055, 0.10112599236890674, 0.13781870860839263, 0.097732225258369, 0.11520918706082739, 0.12640453671338037, 0.109819265344413, 0.1758378802333027, 0.1385622812085785, 0.0919771297776606, 0.12062055684509687, 0.1214325257751625, 0.1721211601397954, 0.13840384752256796, 0.13678170565981418, 0.18342347553698346], [0.05230798946286086, 0.021470319297804963, 0.028815121077059302, 0.0063494597543467535, 0.020363027542771306, 0.06047353977919556, 0.05884059595700819, 0.047966076745069586, 0.030757212080061436, 0.03393876948393881, 0.017437004571547732, 0.05609469037153758, 0.008520667051925557, 0.01323074902757071, 0.05253096402157098, 0.03486521098238882, 0.032106852158904076, 0.04963558247254696, 0.05847029766300693, 0.04438859839865472, 0.0414057287707692, 0.09366959755425341, 0.038086588319856673, 8.552808109670877, 33.71766172349453, 46.82958014309406, 44.26493436098099, 27.36138179898262, 24.024241268634796, 38.00016492605209, 36.58215321600437, 9.883192721754313, 0.3022925416007638, 0.24326829006895423, 0.45176031184382737, 2.925599100999534, 5.668430384248495, 5.261627063155174, 4.684486482292414, 2.8227362455800176, 6.94872940890491, 20.679314956068993, 32.75463379919529, 49.447776451706886, 53.59549328684807, 47.09271602332592, 49.44980174303055, 51.57414235174656, 51.992967277765274, 51.07496313750744, 49.374037608504295, 46.58589541912079, 45.758865997195244, 43.47231589257717, 41.176467686891556, 36.716099828481674, 38.11121016740799, 40.32894216477871, 44.38955247402191, 47.36809104681015, 49.0609610080719, 47.52554699778557, 45.530733838677406, 43.680799305438995, 46.0218308866024, 47.71226517856121, 50.90669296681881, 50.77460065484047, 48.64659704267979, 49.80390094220638, 52.018281519412994, 49.583109989762306, 46.8400751799345, 36.42072267830372, 35.50440564751625, 36.91895194351673, 35.13238660991192, 35.23571826517582, 34.216134175658226, 36.36236160993576, 35.395290702581406, 44.24226477742195, 48.78734149038792, 49.877339601516724, 47.002147883176804, 46.93385794758797, 48.90290088951588, 48.087878823280334, 44.141972959041595, 42.09152698516846, 50.04480801522732, 48.08983951807022, 43.53122413158417, 39.712022468447685, 37.513559237122536, 35.63163422048092, 36.74779772758484, 36.864922642707825, 35.61362698674202, 35.49168013036251, 34.76613946259022, 35.866093039512634, 36.095110550522804, 36.59948408603668, 36.63084000349045, 39.985888972878456, 46.21576488018036, 47.21376612782478, 47.78894506394863, 50.6189876049757, 47.90163181722164, 50.19688345491886, 47.01383225619793, 45.4302254319191, 47.440332770347595, 46.527606546878815, 46.68001636862755, 49.44349028170109, 49.18489135801792, 50.408239513635635, 47.85443834960461, 48.30743104219437, 47.580613642930984, 46.658068746328354, 49.34121876955032, 49.54730451107025, 50.886922627687454, 51.42425559461117, 49.481811225414276, 55.03266356885433, 52.200162559747696, 54.358724132180214, 50.037037432193756, 49.87952448427677, 52.35197201371193, 48.29633563756943, 48.73994283378124, 31.938973367214203, 19.43583358079195, 9.158491808921099, 2.6167450239881873, 1.7676854529418051, 4.710652828216553, 3.6461940966546535, 3.3635711995884776, 3.063640706241131, 0.039986033661989495, 0.12115484380046837, 4.086168212816119, 23.279543928802013, 34.70004200935364, 28.15352339297533, 35.508156046271324, 48.86635825037956, 44.31429371237755, 19.539315328001976, 2.599478275515139, 0.030666391758131795, 0.03287949839432258, 0.004889775873380131, 0.06833201536210254, 0.07269086388987489, 0.05794324664748274, 0.035131296899635345, 0.05018301286327187, 0.04666827568144072, 0.07311423687497154, 0.03640394286776427, 0.052620971691794693, 0.02925937995314598, 0.06766970051103272, 0.04019078849523794, 0.02956398147944128, 0.01978037482331274, 0.10497828057850711, 0.01671976893703686, 0.01986782950552879, 0.04902166678220965, 0.018383690003247466, 0.054464436834678054, 0.06358425918733701, 0.02778164518531412, 0.07087578589562327, 0.02432284552924102, 0.05531411799893249, 0.02176152505853679, 0.03378768677066546, 0.01679820466961246, 0.05930128041654825, 0.02226808723207796, 0.0281719016857096, 0.03782339677854907, 0.04377860124805011, 0.05196591875574086, 0.021163895798963495, 0.05677072382241022, 0.037794026284245774, 0.099394242715789, 0.12850525992689654, 11.0682731308043, 40.752235651016235, 54.37716454267502, 49.12396542727947, 32.48748153448105, 30.093355402350426, 41.825659051537514, 41.47153705358505, 10.377087369561195, 0.5409670562949032, 0.1752077671699226, 0.6685491884127259, 2.2619269508868456, 4.900263603776693, 5.477992203086615, 5.153309600427747, 3.382042720913887, 8.293040748685598, 22.959587797522545, 35.76936922967434, 49.538602977991104, 52.306252866983414, 50.85092335939407, 49.102914556860924, 52.021849527955055, 52.712682858109474, 52.50360667705536, 52.17797175049782, 49.888712391257286, 48.92754256725311, 46.015538424253464, 41.848959401249886, 40.208473429083824, 39.39482308924198, 44.045355543494225, 46.4143156260252, 49.48532983660698, 49.85092341899872, 49.94461499154568, 47.244080901145935, 47.13962830603123, 48.02398905158043, 51.71797603368759, 52.92204022407532, 51.758694648742676, 49.986921921372414, 51.5692064166069, 53.044199869036674, 51.031432673335075, 47.80302710831165, 36.805273443460464, 36.81898690760136, 37.98840455710888, 36.72876074910164, 37.06439293920994, 35.33744640648365, 37.233354672789574, 37.44140490889549, 46.29633955657482, 51.32891111075878, 50.59235103428364, 49.053916186094284, 50.51568254828453, 49.804227724671364, 50.76667807996273, 46.05057634413242, 44.25315119326115, 51.92264065146446, 50.100372433662415, 45.92500068247318, 41.29615746438503, 39.19125281274319, 37.610191851854324, 38.213097900152206, 37.420483231544495, 36.333714947104454, 37.63911210000515, 36.4507220685482, 38.29094432294369, 38.39825056493282, 36.93052612245083, 39.052735045552254, 40.63830256462097, 47.9503034055233, 48.71318466961384, 49.34192173182964, 51.56974978744984, 50.17727650702, 53.23245696723461, 49.60630014538765, 46.86790868639946, 49.745300486683846, 50.551951602101326, 49.79368329048157, 51.152779161930084, 50.64883500337601, 52.46003061532974, 50.31537629663944, 48.90022203326225, 49.01103928685188, 49.39206004142761, 52.523069232702255, 50.75342059135437, 52.23125249147415, 51.923020631074905, 52.11813636124134, 55.52997328341007, 53.35549436509609, 53.83183300495148, 51.33052222430706, 51.30962334573269, 53.81388656795025, 50.51568254828453, 50.07188156247139, 33.24464790523052, 21.779335029423237, 10.591761600226164, 4.555305764079094, 5.255483742803335, 8.295393772423267, 4.81502135284245, 4.400779930874705, 3.3531134482473135, 0.1929980266140774, 0.1030757553235162, 4.049888234585524, 29.423821829259396, 39.40421998500824, 27.965741269290447, 38.12444865703583, 54.35914970934391, 52.21886895596981, 25.034424662590027, 3.5819131834432483, 0.06903386441990733, 0.03035033332707826, 0.018201657876488753, 0.03656364933704026, 0.05616179907519836, 0.06651902280282229, 0.041668334015412256, 0.0173288087171386, 0.008489188858220587, 0.056673784492886625, 0.023177502007456496, 0.045755203973385505, 0.023928458977025002, 0.01283940342545975, 0.03512902221700642, 0.05519040940271225, 0.03546402767824475, 0.05478779428813141, 0.0420472671976313, 0.17691255459794775, 0.09524257955490611, 0.10002529830671847, 0.11039955803425983, 0.10813099070219323, 0.13451144623104483, 0.22943569638300687, 0.08382503088796511, 0.15855137578910217, 0.10766385326860473, 0.09951830754289404, 0.1175393229641486, 0.14095349586568773, 0.11287069457466714, 0.12204408514662646, 0.12361139713902958, 0.112040691456059, 0.16520894510904327, 0.13937267678556964, 0.0901138641347643, 0.1482260087504983, 0.19931392598664388, 0.2521882817381993, 11.608665883541107, 46.66376084089279, 60.993741899728775, 55.807966366410255, 38.07044975459576, 35.849320739507675, 48.51141169667244, 46.729200929403305, 13.61968707293272, 0.788970545399934, 0.47931114910170436, 1.806620538700372, 9.476486295461655, 13.803923986852169, 13.789227325469255, 11.405346393585205, 6.24563698656857, 10.25187173858285, 23.45449224114418, 37.915649861097336, 51.30709648132324, 54.96345028281212, 50.650392919778824, 50.3323195874691, 53.86151701211929, 54.507676139473915, 54.453833028674126, 53.182200863957405, 51.59249536693096, 51.78292214870453, 48.32268342375755, 44.45769801735878, 40.40269620716572, 40.926319509744644, 44.64762322604656, 48.57235662639141, 50.530513152480125, 53.64329092204571, 52.072793394327164, 49.328554049134254, 47.694535329937935, 51.0990272462368, 52.6257511228323, 53.65901067852974, 52.71109074354172, 51.26780278980732, 51.781975999474525, 54.342442005872726, 54.31546725332737, 50.589998960494995, 37.853333204984665, 37.74058945477009, 41.45501174032688, 39.202887788414955, 38.231868892908096, 37.61871479451656, 40.944524332880974, 40.33108524978161, 48.70657682418823, 54.90255855023861, 52.0169971883297, 52.537690848112106, 51.27023845911026, 53.13913017511368, 50.29306009411812, 46.73894740641117, 47.37766653299332, 54.141831770539284, 53.60385283827782, 47.51223251223564, 43.611099645495415, 41.384989097714424, 39.75595571100712, 41.712151542305946, 41.82699277997017, 38.51126030087471, 38.40286731719971, 38.522944673895836, 38.671911880373955, 40.79658307135105, 39.944683983922005, 40.62054231762886, 42.76347532868385, 51.476681381464005, 51.53196461498737, 51.8256850540638, 54.700086414813995, 50.38600690662861, 52.979105561971664, 53.139582350850105, 49.566945657134056, 51.739270091056824, 52.52420537173748, 51.277959644794464, 52.75496318936348, 54.08468283712864, 55.52890554070473, 51.9068942964077, 52.54663936793804, 50.90306416153908, 52.188079208135605, 52.82486043870449, 53.14748972654343, 52.26836510002613, 53.59794795513153, 51.030805706977844, 56.451507434248924, 54.84073966741562, 55.83567447960377, 52.041889652609825, 50.381116569042206, 55.69800786674023, 52.27198250591755, 49.77401174604893, 34.22960065305233, 22.372557297348976, 11.423848550766706, 5.928665595129132, 7.286923611536622, 11.688890028744936, 13.616817276924849, 8.141865860670805, 6.028236877173185, 0.3670660627540201, 0.2255188042181544, 6.003472181037068, 32.24641107022762, 47.694071754813194, 39.007699862122536, 47.14309751987457, 61.011243760585785, 58.43662731349468, 28.4404231980443, 4.2804033402353525, 0.17464395757997409, 0.14852451538899913, 0.13966319791506976, 0.13528231502277777, 0.14376289589563385, 0.2862336830003187, 0.1691164416843094, 0.13078279240289703, 0.15240590320900083, 0.23234586522448808, 0.10024313349276781, 0.182042368396651, 0.1321200979873538, 0.09932449567713775, 0.08885387549526058, 0.11487380310427397, 0.14761572587303817, 0.21089227579068393, 0.15205427363980561], [0.029828007936885115, 0.028269792819628492, 0.09951470070518553, 0.04700934448919725, 0.059036997918155976, 0.08161720834323205, 0.058915675326716155, 0.06772372144041583, 0.06105950989876874, 0.02962525875773281, 0.022224833010113798, 0.06630855714320205, 0.03210397633665707, 0.0364965369226411, 0.08022027119295672, 0.05313542846124619, 0.015685571306676138, 0.0259744228242198, 0.01269475142180454, 0.07931617947178893, 0.018115308994310908, 0.03657624729385134, 0.03715813560120296, 4.486945057287812, 25.358761958777905, 44.238829761743546, 45.91488942503929, 25.2610881999135, 25.275915004312992, 32.66173258423805, 40.51752984523773, 14.431716799736023, 0.826947963796556, 0.1135157396493014, 0.6277129577938467, 1.4731303649023175, 1.4084194810129702, 4.0368259605020285, 3.713960610330105, 1.8170942016877234, 6.863068705424666, 21.60062301903963, 32.03219376504421, 50.76456159353256, 44.50663559138775, 47.036999613046646, 51.52599133551121, 53.46725016832352, 49.99558925628662, 48.84245753288269, 46.28110237419605, 43.773856312036514, 39.44511339068413, 39.34506095945835, 37.87658415734768, 36.697887405753136, 36.15153752267361, 37.19658404588699, 38.124273866415024, 40.40147267282009, 39.09752704203129, 40.63234828412533, 36.19825221598148, 37.58879519999027, 42.693255096673965, 46.982195153832436, 47.8699567168951, 51.12834267318249, 49.9768752604723, 46.230219304561615, 51.272875517606735, 49.51447807252407, 49.42697636783123, 36.85749404132366, 34.59378831088543, 35.05581311881542, 35.58304622769356, 35.93117594718933, 34.967688247561455, 36.6289135068655, 35.5725359916687, 40.28085194528103, 48.59363168478012, 48.775489926338196, 47.84033730626106, 47.32119396328926, 46.49788834154606, 46.9379161298275, 45.39206027984619, 42.392934411764145, 51.467360481619835, 47.4163256585598, 43.2367817312479, 40.81518307328224, 38.41591961681843, 40.334923043847084, 40.37612043321133, 35.17642244696617, 35.633439123630524, 35.27862936258316, 36.85929134488106, 35.4905591905117, 36.81033477187157, 35.30422478914261, 37.122898399829865, 44.40741151571274, 47.31049373745918, 48.83553430438042, 50.51475539803505, 49.335990250110626, 50.45184977352619, 49.34235870838165, 47.133461236953735, 45.031786412000656, 42.54645377397537, 43.1968192756176, 43.015561401844025, 43.30081969499588, 44.1381161659956, 43.334789872169495, 41.92265644669533, 42.09817282855511, 41.24647133052349, 45.420421957969666, 48.210711032152176, 49.28810901939869, 50.73399603366852, 50.090185180306435, 50.965540409088135, 46.47560253739357, 49.582251235842705, 50.34556947648525, 51.32038816809654, 51.78493984043598, 54.61202993988991, 53.45872342586517, 45.61775676906109, 30.858818627893925, 13.54385169222951, 4.162299502640963, 2.902613184414804, 5.12841428630054, 5.856763478368521, 1.575103118084371, 5.57796198874712, 6.017104899510741, 0.37586152204312384, 0.17500787711469457, 4.450211003422737, 26.481958888471127, 43.16263251006603, 37.66972325742245, 42.25752867758274, 52.79910162091255, 43.50613407790661, 11.909710429608822, 1.0571041074581444, 0.02381558202614542, 0.021377745651989244, 0.08007377866306342, 0.03448147610470187, 0.05991949685267173, 0.04186125530395657, 0.026186009126831777, 0.04890619973593857, 0.0041162464822264155, 0.025466777115070727, 0.03711280893185176, 0.0745275458029937, 0.09759643449797295, 0.024199808576668147, 0.029002027258684393, 0.017235472514585126, 0.050804832426365465, 0.05127840056957211, 0.024140180721587967, 0.019055814191233367, 0.045058809701004066, 0.03312585802632384, 0.04420669800310861, 0.046235818808781914, 0.07504249238991179, 0.06081625244405586, 0.024393227104155812, 0.00802674829174066, 0.033303312957286835, 0.007336802818826982, 0.07359013165114447, 0.07073733824654482, 0.06004707945976406, 0.04861884757701773, 0.07498548802686855, 0.02924183372670086, 0.02704873539187247, 0.04185620498901699, 0.04797009547473863, 0.02923056235886179, 0.05876322335097939, 0.009989180634875083, 5.689395284280181, 31.508443169295788, 52.04561725258827, 50.78599624335766, 29.21907551586628, 29.69848059117794, 38.13364036381245, 44.71915818750858, 16.19167786091566, 1.1533790663816035, 0.1421417633537203, 0.15947252948535606, 2.233424917794764, 2.8159673837944865, 6.388907348737121, 5.275602713227272, 4.370353538542986, 7.87256671115756, 21.337918415665627, 34.03820492327213, 51.19861990213394, 49.35515262186527, 47.711376026272774, 52.69008547067642, 54.9943920224905, 50.92092700302601, 52.19646915793419, 48.1738568097353, 47.45344966650009, 41.77842378616333, 41.86200030148029, 39.71101552248001, 38.77011001110077, 37.7093019336462, 39.67734172940254, 40.50051435828209, 43.39406669139862, 42.312276139855385, 42.991869673132896, 37.97462649643421, 41.53161562979221, 44.29038159549236, 48.44733193516731, 50.42699910700321, 52.950474098324776, 50.20322911441326, 47.45986372232437, 51.187836080789566, 51.26948609948158, 51.89178630709648, 37.947051376104355, 35.70746295154095, 36.78654424846172, 36.89054846763611, 38.182251155376434, 36.12524293363094, 38.089897111058235, 36.67445406317711, 43.22811059653759, 51.956413239240646, 48.569616973400116, 50.33604338765144, 50.148895829916, 50.66328942775726, 47.51754082739353, 45.249689519405365, 45.866141840815544, 54.64001543819904, 49.45881865918636, 46.63466960191727, 42.27821856737137, 39.945189356803894, 42.321030870079994, 40.648596212267876, 37.344103530049324, 37.28883549571037, 37.184588089585304, 37.780521512031555, 38.16527746617794, 37.98865154385567, 37.56630040705204, 39.80469189584255, 46.468728706240654, 49.615187868475914, 48.5496224462986, 50.59662960469723, 50.703346878290176, 51.24583996832371, 51.98189467191696, 50.26952035725117, 46.60745166242123, 45.180111452937126, 44.939816147089005, 46.1152108758688, 45.88178940117359, 47.60424457490444, 44.85971264541149, 45.66916801035404, 43.78131911158562, 43.84398154914379, 48.61714482307434, 51.169714853167534, 51.84099443256855, 55.08772261440754, 50.97968325018883, 49.901179522275925, 48.9084941893816, 50.430586114525795, 51.67696863412857, 50.7206017524004, 51.20650067925453, 56.347157433629036, 53.97347420454025, 45.798528268933296, 31.998390778899193, 15.924609191715717, 6.65345105342567, 4.3173302337527275, 5.346126453951001, 6.23178387992084, 4.943400789052248, 5.813230164349079, 3.3741123089566827, 0.28385723708197474, 0.2300691936397925, 5.021464750170708, 28.629913330078125, 42.726586908102036, 39.19819504022598, 44.886736795306206, 58.24157997965813, 48.245817348361015, 16.412871591746807, 1.5088723157532513, 0.03928835918486584, 0.03136453378829174, 0.05703552953491453, 0.045874919815105386, 0.060500179170048796, 0.01696835686743725, 0.045177204519859515, 0.008633274974272354, 0.03250055779062677, 0.036885400040773675, 0.09378267859574407, 0.15340946498326957, 0.053248709882609546, 0.04495536915783305, 0.061130804315325804, 0.027901678295165766, 0.10322282672859728, 0.047666879909229465, 0.055184438824653625, 0.12904664181405678, 0.13086666993331164, 0.15314754622522742, 0.12518343661213294, 0.31966841546818614, 0.22470696887467057, 0.21202639618422836, 0.12097981569240801, 0.13429833110421896, 0.10444686573464423, 0.11085341844591312, 0.186474637594074, 0.13912741182139143, 0.12843598786275834, 0.19479979790048674, 0.15301482053473592, 0.09014744631713256, 0.12839278002502397, 0.15678464871598408, 0.18278070143423975, 0.1129836865584366, 0.2009465469745919, 0.19005061680218205, 5.982988905161619, 36.14806830883026, 59.60615515708923, 57.81286038458347, 36.66715085506439, 36.20703734457493, 42.53468580543995, 48.510446548461914, 19.5293028652668, 1.1861889995634556, 0.41752346616704017, 1.2759433896280825, 4.837818704545498, 7.703790217638016, 12.256797105073929, 9.638864882290363, 5.217560352757573, 9.324649292975664, 24.192042164504528, 34.78074207901955, 52.809300273656845, 51.23016580939293, 48.783309906721115, 53.427082523703575, 58.587502017617226, 54.0528367459774, 54.48190212249756, 50.991918593645096, 49.44783724844456, 43.06031160056591, 43.277215361595154, 41.90609313547611, 40.11213339865208, 39.706919342279434, 42.18430280685425, 41.93371005356312, 43.40307220816612, 43.087628334760666, 43.288268968462944, 39.46831114590168, 41.5667599439621, 46.58761292695999, 51.30373366177082, 52.28438884019852, 53.334333300590515, 53.43060113489628, 47.450117245316505, 53.59566427767277, 52.806195840239525, 53.30222122371197, 40.72449333965778, 38.83648104965687, 38.62269312143326, 39.53910514712334, 39.7647750377655, 38.92329499125481, 39.71494451165199, 39.667766243219376, 45.296639800071716, 54.287234768271446, 50.9732273966074, 50.990546867251396, 50.861942768096924, 51.59390889108181, 48.690800070762634, 46.383757665753365, 47.627761512994766, 55.277256444096565, 52.62167014181614, 48.220905885100365, 45.75053684413433, 43.651377484202385, 43.93371373414993, 42.4340596050024, 37.96015687286854, 39.37627248466015, 39.70407709479332, 39.11529488861561, 40.54932653903961, 40.2073372900486, 39.664437621831894, 41.027910858392715, 49.08708080649376, 52.60604918003082, 51.39807499945164, 53.788724318146706, 51.51794336736202, 53.784985318779945, 55.08032441139221, 51.8223412334919, 48.33752542734146, 46.80700175464153, 47.28044494986534, 46.30366936326027, 47.74903200566769, 48.58209550380707, 46.87396936118603, 45.843631848692894, 46.1833830177784, 45.52884913980961, 51.04739561676979, 53.274110332131386, 54.4898246973753, 58.4611663967371, 52.85982996225357, 53.056883588433266, 49.93680641055107, 51.29502832889557, 52.73687236011028, 53.03948812186718, 54.92257207632065, 55.99906951189041, 57.20744267106056, 48.028195425868034, 34.8866917937994, 16.73681750893593, 7.505539180710912, 6.432956960052252, 12.250435296446085, 16.055951043963432, 8.627923429012299, 14.862400889396667, 9.761227816343307, 0.7735238398890942, 0.3750765969743952, 6.1396972462534904, 34.44056533277035, 55.68436659872532, 50.48882178962231, 55.29236443340778, 65.62116399407387, 56.129672303795815, 19.684074260294437, 1.656507218722254, 0.1612786646001041, 0.14051012200070545, 0.22123646369436756, 0.14873697742586955, 0.12063592672348022, 0.21115829120390117, 0.1882658406975679, 0.24855414783814922, 0.0803856662241742, 0.14531996625009924, 0.23545199073851109, 0.2248527415213175, 0.1870864344527945, 0.16160007391590625, 0.14270217390730977, 0.11008531786501408, 0.16287037840811536, 0.1532613768358715, 0.11252264215727337], [0.024863884173100814, 0.0358314946788596, 0.04458890776732005, 0.04832929123949725, 0.016170685412362218, 0.101332866033772, 0.03417750725930091, 0.013635458853968885, 0.06147361345938407, 0.05493044991453644, 0.021836285304743797, 0.016302123476634733, 0.13177921471651644, 0.11485706025268883, 0.012304221254453296, 0.04079544589330908, 0.007225921317512984, 0.08331608085427433, 0.057560469140298665, 0.003456607073530904, 0.01654369440075243, 0.13005574000999331, 0.012320272053329973, 1.9695467711426318, 21.092557981610298, 46.63729526102543, 51.8617033213377, 25.94704259186983, 21.163034699857235, 28.756775222718716, 43.32453802227974, 18.004319295287132, 2.883427538909018, 0.3884182154433802, 0.12774797243764624, 0.9434728079941124, 2.306059682741761, 3.1950364680960774, 3.3557013468816876, 2.364835641346872, 5.781976841390133, 18.07324379682541, 35.62620431184769, 43.83765488862991, 45.59287190437317, 58.578454703092575, 49.39717456698418, 48.886485770344734, 46.42466627061367, 45.21109499037266, 39.73418667912483, 38.93513895571232, 35.396506637334824, 37.59991720318794, 36.55502647161484, 35.69076284766197, 35.425962656736374, 36.77065350115299, 34.96543876826763, 36.31253108382225, 35.43014623224735, 35.87019681930542, 35.32433331012726, 37.081446424126625, 40.52612118422985, 45.72018027305603, 46.32085204124451, 50.01043125987053, 50.5531295388937, 47.09164448082447, 48.83379019796848, 49.95723411440849, 44.83014263212681, 37.02511064708233, 34.68570537865162, 36.78172990679741, 33.33739332854748, 35.02881936728954, 33.796781077980995, 35.636535957455635, 34.183334335684776, 36.79414004087448, 43.69124494493008, 48.239274099469185, 47.33830824494362, 49.77673999965191, 47.33925439417362, 51.18970938026905, 44.92933630943298, 39.713667780160904, 50.435465052723885, 47.441533505916595, 47.628198489546776, 44.28494028747082, 38.453921377658844, 37.90932320058346, 35.72755627334118, 34.78714473545551, 34.95511092245579, 36.02781996130943, 35.35881265997887, 35.28477743268013, 35.68273767828941, 34.672497287392616, 40.031619518995285, 48.26164349913597, 49.22317810356617, 52.80562587082386, 47.931460216641426, 47.188410088419914, 51.428317576646805, 49.914444610476494, 46.39061629772186, 42.45123468339443, 38.87635610997677, 36.7534214258194, 36.74328736960888, 36.1679108440876, 36.83028370141983, 36.64847105741501, 37.10402861237526, 36.65126010775566, 35.43152175843716, 37.018555998802185, 42.523920983076096, 46.98381386697292, 48.48108932375908, 50.47849394381046, 50.53911209106445, 50.2612330019474, 51.54612645506859, 52.047771736979485, 53.199710324406624, 56.284335404634476, 55.86303301155567, 53.920250460505486, 42.6379718631506, 27.073114067316055, 11.952784918248653, 2.420223131775856, 3.568440293893218, 3.0423853592947125, 6.081406474113464, 3.690790878608823, 3.5586294578388333, 2.7408425649628043, 0.07238018602947704, 0.2399011660600081, 6.9791994988918304, 28.301219567656517, 37.7654667198658, 34.942940175533295, 51.15086026489735, 48.855445235967636, 36.22214913368225, 11.080479975789785, 0.623701976146549, 0.02588338542409474, 0.0803261979308445, 0.07694906234974042, 0.04085492902959231, 0.04980559737305157, 0.05096499531646259, 0.008561843260395108, 0.02354357191507006, 0.008157427510013804, 0.05383008981880266, 0.057412065580138005, 0.04420065692102071, 0.0655793673649896, 0.0442172142356867, 0.08030282027903013, 0.08235013112425804, 0.06762481541954912, 0.022607248720305506, 0.025701520280563273, 0.05208646951359697, 0.04825002244615462, 0.025101178471231833, 0.039817580982344225, 0.04767898062709719, 0.10305887146387249, 0.03193256619852036, 0.007476452283299295, 0.034890904134954326, 0.09255963406758383, 0.06940214036148973, 0.054286347367451526, 0.01681992733210791, 0.0499730629962869, 0.012458527671697084, 0.03575205148081295, 0.031023847186588682, 0.044297818894847296, 0.030053002992644906, 0.018054126339848153, 0.05886696817469783, 0.05842087062774226, 0.03171505384671036, 2.6739032194018364, 25.881000235676765, 50.56610584259033, 56.163733676075935, 31.717084273695946, 24.708386957645416, 31.605710349977016, 46.39730393886566, 20.150092653930187, 2.482422231696546, 0.07272494331118651, 0.14321866416139528, 1.3799656578339636, 3.0284158838912845, 4.858872899785638, 6.435001250356436, 3.966375128366053, 6.8255960661917925, 20.0727117061615, 35.18562935292721, 49.217941984534264, 47.183937728405, 57.98073157668114, 52.3895063996315, 52.22159720957279, 50.03223069012165, 48.41175064444542, 43.22161294519901, 41.60370536148548, 37.13550232350826, 39.95267875492573, 37.646525502204895, 37.22429595887661, 37.21613019704819, 38.536912724375725, 37.070924788713455, 37.91179306805134, 37.03650243580341, 38.39301824569702, 37.241759821772575, 39.35140281915665, 42.85139501094818, 48.064228892326355, 48.758569434285164, 52.55795516073704, 51.60072572529316, 47.53396354615688, 49.98124122619629, 51.67314223945141, 46.865005642175674, 37.57291965186596, 36.95895999670029, 37.70796440541744, 35.34000746905804, 36.602075546979904, 36.848948299884796, 39.19260174036026, 36.85003504157066, 38.829747810959816, 46.97585329413414, 49.54676494002342, 49.272172674536705, 52.23265081644058, 49.503454864025116, 50.69238066673279, 45.17155431210995, 43.742264807224274, 52.285262793302536, 49.20790672302246, 48.218660205602646, 46.862733364105225, 39.95939299464226, 39.63224954903126, 37.5147295743227, 36.625911667943, 36.06628529727459, 37.397794649004936, 37.057674899697304, 38.69366951286793, 36.773735135793686, 36.23622737824917, 41.493731662631035, 49.52047795057297, 51.42863295972347, 52.314897403120995, 49.43587549030781, 45.97451202571392, 52.12747246026993, 52.909493297338486, 48.57641480863094, 45.28948478400707, 40.9872492402792, 38.92778255045414, 39.96941685676575, 38.18893499672413, 39.979387521743774, 39.6556106954813, 39.69079680740833, 38.87279190123081, 38.68317827582359, 40.4517325758934, 44.781493842601776, 48.84516678750515, 50.62912546098232, 50.69155231118202, 52.77938447892666, 51.69624499976635, 52.59184934198856, 53.12277965247631, 56.799583956599236, 57.09148429334164, 56.161043420434, 56.14557445049286, 43.87856349349022, 29.397462643682957, 13.475490510463715, 4.209075467661023, 4.540646625682712, 4.391337912529707, 8.818952478468418, 4.270669212564826, 4.933156538754702, 3.926992854103446, 0.25005716015584767, 0.3595980384852737, 7.632344076409936, 31.5106413513422, 43.89474302530289, 39.02180850505829, 53.7322099506855, 57.42817662656307, 43.96158143877983, 13.787587713450193, 0.7412724767345935, 0.06617665523663163, 0.0063928146300895605, 0.11807545786723495, 0.045259831531438977, 0.05298237534589134, 0.022112837359600235, 0.027287669836368877, 0.06382729028700851, 0.010667669666872825, 0.048288176258211024, 0.057981641657534055, 0.024951563354989048, 0.03087920445977943, 0.028303796170803253, 0.06640873223659582, 0.04897384649666492, 0.02950928519567242, 0.045500647320295684, 0.008969332429842325, 0.18236481671920046, 0.12617525761015713, 0.1352343277540058, 0.134542393789161, 0.09307473650551401, 0.14268381317378953, 0.13160470611182973, 0.11265223598456942, 0.20202401181450114, 0.2412208530586213, 0.13603408093331382, 0.1116686973546166, 0.1531645710929297, 0.1745872723404318, 0.08258277215645649, 0.07818141340976581, 0.13044380903011188, 0.14244775084080175, 0.1455283464747481, 0.12104958499548957, 0.13341355748707429, 0.22688536526402459, 0.18310831510461867, 3.0567438388243318, 28.13413493335247, 59.46474954485893, 64.85919088125229, 38.57057511806488, 31.552399210631847, 39.80974942445755, 52.6770331710577, 24.10109404474497, 3.873527110554278, 0.8914034301415086, 0.6125256477389485, 3.5305653512477875, 7.287684995681047, 8.70500324293971, 9.766564629971981, 5.759973647072911, 8.54556854814291, 21.40692461282015, 39.53972831368446, 51.92754998803139, 49.07532423734665, 61.07422158122063, 53.89295652508736, 54.22260023653507, 52.43099257349968, 50.056853368878365, 44.39138397574425, 42.3898109793663, 38.099681586027145, 41.85133807361126, 39.285784140229225, 39.402510076761246, 38.44895124435425, 40.46778291463852, 38.68809141218662, 39.28102299571037, 38.610522374510765, 39.73033748567104, 38.14505115151405, 40.76267369091511, 44.46676813066006, 49.34681586921215, 49.98757168650627, 54.242119789123535, 52.774125561118126, 48.23296643793583, 52.50482261180878, 54.886063635349274, 48.85367073118687, 40.22835396230221, 38.419920802116394, 39.681289717555046, 36.278671100735664, 38.2141200453043, 38.01330842077732, 39.99846629798412, 38.06659676134586, 41.77793741226196, 48.88540282845497, 51.8089659512043, 51.41694858670235, 53.50472755730152, 51.42809338867664, 52.399294674396515, 46.2832872569561, 46.56541831791401, 55.89141748845577, 51.5069467574358, 51.07722021639347, 50.80555759370327, 40.71108005940914, 40.606559067964554, 38.1203106790781, 38.335713520646095, 38.45706380903721, 40.468447878956795, 39.57490682601929, 40.1518564671278, 39.49664242565632, 38.46465580165386, 43.54680709540844, 52.07036912441254, 53.426318764686584, 56.11174866557121, 49.42750073969364, 47.638332545757294, 55.21850399672985, 54.62647296488285, 50.17877742648125, 45.530749037861824, 43.699570298194885, 40.80138221383095, 41.97836525738239, 39.37627248466015, 40.03929890692234, 40.72580046951771, 41.622309163212776, 40.25217868387699, 39.72600571811199, 41.905108988285065, 47.23949834704399, 50.91438755393028, 52.87173852324486, 53.809733390808105, 55.92836290597916, 54.63211186230183, 56.48893542587757, 58.08082580566406, 58.799549639225006, 59.48124825954437, 58.36077198386192, 57.64739066362381, 47.54448138177395, 30.195701010525227, 14.223206788301468, 5.0719094183295965, 7.874191123992205, 9.569493904709816, 15.679791178554296, 12.239554580301046, 7.901150202378631, 5.418902998790145, 0.7031597499735653, 0.5947186751291156, 9.226599354296923, 39.639184176921844, 50.28625085949898, 49.75166134536266, 63.389057368040085, 64.81470286846161, 50.19725203514099, 17.845793701708317, 1.2306595570407808, 0.1898066431749612, 0.17679155484074727, 0.1949090271955356, 0.10470649867784232, 0.1717003178782761, 0.1233379305631388, 0.08877641754224896, 0.14451454306254163, 0.055179596311063506, 0.15805896080564708, 0.17349242640193552, 0.14748623594641685, 0.15054489369504154, 0.11158398119732738, 0.1433732089935802, 0.1414957089582458, 0.1482578320428729, 0.32577222387772053, 0.08987590932520106], [0.01796715776436031, 0.03997915766376536, 0.037134182784939185, 0.03305265629023779, 0.026931357315334026, 0.04158775904215872, 0.040088501991704106, 0.01498689029176603, 0.02177126945753116, 0.05314140646078158, 0.06919683262822218, 0.0037670513893317548, 0.007749669312033802, 0.10407551730168052, 0.013536714250221848, 0.046725717911613174, 0.03311967593617737, 0.05155190054210834, 0.030244174668041524, 0.014010236936883302, 0.011768507520173443, 0.10652148019289598, 0.019949489869759418, 0.9460803586989641, 14.795561525970697, 38.216339126229286, 51.010963171720505, 35.08175812661648, 30.159186869859695, 30.8946431055665, 43.58206160366535, 27.422663010656834, 8.560387752950191, 0.2467547811102122, 0.11774602593504824, 1.4270679303444922, 1.2918971898034215, 5.422917483374476, 3.8449728302657604, 4.39721904695034, 3.780586472712457, 16.36684276163578, 28.79275929182768, 40.33584639430046, 53.689029067754745, 51.39199912548065, 47.987180426716805, 48.35645221173763, 43.08196283876896, 39.60556738078594, 37.2532694041729, 37.090030163526535, 38.469751328229904, 39.07177582383156, 41.52458220720291, 44.31841269135475, 41.37274235486984, 37.974413707852364, 35.131106078624725, 36.32660932838917, 35.983160957694054, 36.352588534355164, 37.19928950071335, 39.49090473353863, 45.39316602051258, 48.612167090177536, 47.40780271589756, 51.21365189552307, 46.881204172968864, 51.28395192325115, 49.59659926593304, 47.964301854372025, 40.229235514998436, 34.013080671429634, 34.30012866854668, 33.751529306173325, 35.18508218228817, 34.93982434272766, 35.20177088677883, 35.24940513074398, 35.946470126509666, 34.459685906767845, 38.91126103699207, 45.18726646900177, 47.006103470921516, 48.979554176330566, 46.91885255277157, 50.84994301199913, 43.494442105293274, 36.553601548075676, 51.27242714166641, 47.88997784256935, 46.46078713238239, 45.73225982487202, 43.7351705878973, 41.85381554067135, 37.94965423643589, 35.75253613293171, 35.60801088809967, 33.67179438471794, 35.53425304591656, 33.41202512383461, 34.57228906452656, 35.76818749308586, 39.92182061076164, 47.89501257240772, 48.75565119087696, 51.28691576421261, 49.59034860134125, 49.0318887680769, 51.99561193585396, 48.776759058237076, 47.96264514327049, 43.465339466929436, 38.01012799143791, 37.76865474879742, 37.06002697348595, 34.48615528643131, 35.99903270602226, 38.012685254216194, 37.417466193437576, 34.533097967505455, 36.06557093560696, 35.731584057211876, 36.80112026631832, 39.58448611199856, 43.772784769535065, 45.26727497577667, 49.02972288429737, 48.703559786081314, 48.476179987192154, 48.875458762049675, 52.30055317282677, 50.94113051891327, 53.03516775369644, 50.5122247338295, 42.80104771256447, 25.59544175863266, 11.010025106370449, 3.182615409605205, 2.568684252910316, 3.4832407906651497, 3.2981686340644956, 3.3528970973566175, 2.86623393651098, 4.340087687596679, 0.27454031514935195, 0.2924227196490392, 7.444537254050374, 28.71057540178299, 37.856179252266884, 49.70632217824459, 46.842761635780334, 42.96016037464142, 31.860167495906353, 6.485477741807699, 0.07858860757551156, 0.017656285090197343, 0.03441524684603792, 0.03143927548080683, 0.034344082305324264, 0.04088119734660722, 0.01520667825388955, 0.09248365298844874, 0.08405169020988978, 0.09558108795317821, 0.023584877999383025, 0.03417255342355929, 0.08469237145618536, 0.06608957162825391, 0.06132222275482491, 0.05636589710775297, 0.020042614560225047, 0.045266165761859156, 0.012859473881690064, 0.03699771667015739, 0.09275035859900527, 0.022124585557321552, 0.029552303785749245, 0.04685827290813904, 0.017693570589472074, 0.0035017136497117463, 0.02848996577085927, 0.047334438568213955, 0.05209032868151553, 0.018333780571992975, 0.056809931484167464, 0.037977833999320865, 0.04933171752782073, 0.02051401934295427, 0.010136778964806581, 0.050772712274920195, 0.039147558927652426, 0.03279035161540378, 0.017559271545906086, 0.028648733423324302, 0.0039030186417221557, 0.07099654074409045, 0.039081778668332845, 1.1442274949513376, 18.673415891826153, 46.52241602540016, 56.302635222673416, 38.36208410561085, 33.74371312558651, 36.27414554357529, 46.68689399957657, 28.82871486246586, 7.462427169084549, 0.5538386874832213, 0.07167174670030363, 0.9538988547865301, 3.6291467864066362, 5.809502089396119, 5.703531475737691, 4.543760558590293, 5.254990244284272, 17.182035818696022, 31.8611516430974, 45.262757018208504, 54.46798726916313, 53.66551212966442, 50.76165474951267, 49.54636596143246, 45.895624458789825, 42.49221168458462, 38.087856620550156, 38.72603237628937, 39.236287996172905, 39.953404515981674, 42.697070091962814, 43.96703414618969, 41.21696591377258, 39.232678189873695, 37.00099714100361, 37.50183306634426, 37.76802018284798, 37.74844743311405, 38.0072895437479, 41.002072244882584, 46.1502829939127, 50.77607877552509, 49.59944911301136, 52.73562602698803, 47.3304008692503, 51.523141488432884, 52.05515094101429, 50.9097708016634, 42.303589805960655, 36.84762977063656, 36.852121129631996, 36.69443339109421, 36.271227300167084, 36.472985073924065, 37.87667915225029, 37.75309458374977, 37.68394589424133, 37.312299236655235, 40.338757038116455, 48.2668150216341, 48.840059861540794, 50.73883697390556, 49.387063309550285, 51.7997020483017, 44.570259377360344, 40.25440916419029, 53.37952047586441, 51.3241271674633, 50.06347641348839, 46.850163638591766, 44.33106601238251, 43.422557562589645, 38.29932287335396, 37.05363191664219, 37.76410259306431, 35.62917195260525, 36.58248759806156, 36.791571378707886, 36.2640380859375, 37.73150034248829, 41.72635518014431, 50.631621927022934, 50.45572556555271, 53.21334779262543, 50.42301692068577, 50.47521471977234, 54.136645048856735, 50.72978585958481, 49.12821739912033, 44.969967529177666, 41.18454225361347, 39.239358231425285, 39.98952157795429, 36.35779805481434, 36.25662088394165, 39.86183322966099, 38.374900817871094, 36.63321867585182, 37.903627306222916, 37.156127616763115, 40.188220515847206, 43.663571029901505, 46.536783054471016, 49.01158265769482, 50.44092535972595, 50.96008390188217, 50.91346800327301, 52.82117083668709, 53.959403559565544, 53.290111273527145, 54.600288569927216, 52.367421984672546, 45.29666259884834, 26.37459944933653, 12.975244503468275, 3.5731791146099567, 4.435193259268999, 6.964551284909248, 7.633325373753905, 6.2444153521209955, 3.555170218460262, 4.323687292635441, 0.7923356804531068, 0.24312691093655303, 9.001407288014889, 33.383192270994186, 40.79437159001827, 52.23078511655331, 54.60314221680164, 49.20181185007095, 37.861077189445496, 9.06947398558259, 0.17168756778119132, 0.06555850559379905, 0.042455099610378966, 0.022454323625424877, 0.057656992867123336, 0.07904936996055767, 0.0796764699043706, 0.03543861283105798, 0.05599561736744363, 0.01731881198793417, 0.089572007273091, 0.036904725566273555, 0.08363784640096128, 0.07087687685270794, 0.014463403440458933, 0.0476687315676827, 0.06332127173664048, 0.028236811776878312, 0.03853449299640488, 0.05655269938870333, 0.12667111615883186, 0.13724624557653442, 0.0888248352566734, 0.06506808698759414, 0.11960502422880381, 0.11389956358470954, 0.09827075729845092, 0.08037122403038666, 0.17775334854377434, 0.2584326529176906, 0.11679337549139746, 0.16699183615855873, 0.1348533685086295, 0.2601283713011071, 0.09256015357095748, 0.12439477111911401, 0.10610819299472496, 0.20335969951702282, 0.1568912508082576, 0.1421347277937457, 0.08459193661110476, 0.2156087281764485, 0.12191922622150742, 1.1960341525264084, 20.18952503800392, 50.904827266931534, 64.66937586665154, 47.286691814661026, 40.269349962472916, 39.708583652973175, 53.28281186521053, 35.00658296048641, 10.690674092620611, 0.614634653320536, 0.45029219530988485, 3.972384030930698, 5.391169711947441, 13.102975599467754, 9.794218596071005, 8.284240420907736, 6.37878374196589, 18.720254078507423, 33.92328388988972, 47.35714763402939, 55.60960181057453, 56.41721807420254, 52.93144091963768, 52.303938791155815, 47.46379271149635, 45.08129395544529, 41.29051856696606, 41.537858694791794, 41.87955155968666, 43.19340705871582, 46.27200186252594, 49.3793611228466, 45.41034869849682, 42.01837331056595, 38.52512575685978, 39.44782264530659, 39.105103835463524, 40.46641118824482, 40.173769891262054, 42.42424853146076, 47.945694252848625, 53.84127929806709, 50.10082080960274, 55.05206152796745, 46.82762324810028, 54.16897751390934, 55.01569747924805, 51.75912782549858, 43.074199855327606, 38.700965121388435, 37.176338732242584, 38.1014446914196, 39.39444310963154, 38.3671872317791, 38.53309012949467, 39.22206535935402, 39.11181427538395, 39.657142013311386, 41.90938375890255, 49.59425859153271, 51.59798987209797, 53.32713268697262, 50.93210220336914, 54.054090678691864, 46.76717609167099, 43.465442061424255, 56.4225909858942, 53.92899379134178, 51.7353904992342, 49.81749281287193, 47.76803478598595, 46.912803277373314, 42.16997757554054, 39.42220062017441, 39.78928752243519, 37.385103330016136, 38.680788204073906, 37.1387929469347, 37.851634696125984, 39.65422376990318, 43.6306381970644, 51.57740257680416, 52.8825793415308, 55.531098023056984, 51.06000334024429, 51.841298416256905, 55.55687204003334, 53.77702474594116, 51.36584132909775, 46.902635022997856, 43.1730667501688, 41.08633652329445, 41.314620673656464, 37.70568072795868, 39.441887363791466, 41.97840325534344, 40.16750402748585, 36.95501960813999, 39.87345300614834, 39.378362372517586, 41.46382726728916, 44.30184558033943, 47.8790420293808, 49.685590490698814, 53.33025611937046, 53.88123795390129, 52.75513418018818, 55.57655118405819, 57.382799461483955, 56.24442994594574, 56.631218791007996, 54.003576189279556, 46.2236038595438, 29.036829695105553, 14.470751155167818, 6.316865114495158, 8.94809614866972, 9.294342119246721, 10.831927713006735, 10.336040072143078, 8.308569565415382, 8.365132380276918, 0.9737229847814888, 0.6276068009901792, 10.852932035923004, 38.548042327165604, 53.026671409606934, 60.58568559587002, 59.34540554881096, 57.56716176867485, 43.43959964811802, 11.675685737282038, 0.18987616756930947, 0.12340584449702874, 0.12390126517857425, 0.09664739831350744, 0.1257527677807957, 0.1508256926899776, 0.18538666394306347, 0.1635237503796816, 0.13167823810363188, 0.17521334812045097, 0.16368121927371249, 0.10802260003401898, 0.2033950702752918, 0.2614135335898027, 0.14628037955844775, 0.145423288049642, 0.19053142459597439, 0.15699933719588444, 0.12018004024866968, 0.16452553099952638], [0.11564893182367086, 0.03362565366842318, 0.0783255830174312, 0.04966873792000115, 0.061958161677466705, 0.06525914548547007, 0.10105806359206326, 0.03503839485347271, 0.05879713578906376, 0.04529261961579323, 0.14950400189263746, 0.01110683462684392, 0.036754667016793974, 0.029919746666564606, 0.01627604811801575, 0.06733328496920876, 0.12970504554687068, 0.034914567513624206, 0.06836288870545104, 0.0825006609375123, 0.030761809684918262, 0.020585313759511337, 0.047602398408344015, 0.06341449290630408, 8.20499187335372, 29.52373366802931, 50.768593177199364, 38.61062876880169, 24.684742726385593, 25.935168229043484, 37.75482349097729, 37.34832890331745, 13.760286178439856, 0.9694822342135012, 0.027213868816033937, 0.5407927406486124, 2.854226818308234, 2.98799816519022, 5.511799464002252, 2.650104621425271, 3.8967773504555225, 13.665021490305662, 25.48999171704054, 42.57814787328243, 53.535403311252594, 51.402927339076996, 49.736458361148834, 45.26452012360096, 39.594859555363655, 38.460669815540314, 41.710548028349876, 44.500878900289536, 45.158578008413315, 49.19342949986458, 51.0329145938158, 52.30611987411976, 50.2266738563776, 44.54852074384689, 35.546598583459854, 33.770171105861664, 35.240688398480415, 37.52431645989418, 40.818728283047676, 45.513239577412605, 47.58548118174076, 50.286608040332794, 50.51371045410633, 49.57662373781204, 50.31484812498093, 50.7223154604435, 48.04750978946686, 46.822611317038536, 37.27886103093624, 35.183482468128204, 34.68254014849663, 34.21819746494293, 34.265561923384666, 37.68103905022144, 36.34634546935558, 37.778310030698776, 35.36339521408081, 36.306618601083755, 33.93076568841934, 41.93902216851711, 44.45062659680843, 48.7521705776453, 46.81088134646416, 52.09641672670841, 48.022689521312714, 35.4643177986145, 50.94486951828003, 49.06939655542374, 50.056477189064026, 47.073838636279106, 46.38701409101486, 47.372400015592575, 41.85798391699791, 36.601706966757774, 35.280244275927544, 36.1132887750864, 36.12465016543865, 35.64387336373329, 35.81808641552925, 35.501795187592506, 38.260439559817314, 47.44793236255646, 48.53789247572422, 52.20124550163746, 46.36866867542267, 47.73203171789646, 50.06556250154972, 48.44402611255646, 46.69404521584511, 43.506696447730064, 38.70896749198437, 34.80015903711319, 34.9956851452589, 35.92092789709568, 39.91444520652294, 43.530053794384, 44.69257481396198, 42.95475326478481, 41.90433382987976, 38.15007068216801, 36.395921409130096, 36.30699098110199, 36.73713929951191, 38.122069984674454, 40.63876233994961, 42.77246564626694, 44.39118638634682, 47.015724554657936, 47.85017877817154, 49.52007137238979, 51.44553825259209, 54.70464617013931, 40.974348932504654, 24.63097371160984, 10.25984751060605, 1.7380665172822773, 3.5424900613725185, 3.6223356518894434, 6.092791613191366, 2.9691877495497465, 1.5154997538775206, 3.7526237731799483, 1.9566031219437718, 0.19296229962492362, 11.402241960167885, 32.54901543259621, 50.86593635380268, 40.512301325798035, 43.61160881817341, 48.97515781223774, 29.463890679180622, 5.090622464194894, 0.044858121837023646, 0.08981448918348178, 0.01444731182346004, 0.04217907633574214, 0.026448208045621868, 0.029237386406748556, 0.008883517893991666, 0.00812120049886289, 0.019427934457780793, 0.07972196355694905, 0.012387027309159748, 0.016421635227743536, 0.05241571590886451, 0.07526125526055694, 0.020217548044456635, 0.05184209512663074, 0.014793872524023755, 0.07194340985734016, 0.01588395665748976, 0.06092938914662227, 0.07170297627453692, 0.027955804980592802, 0.059133391769137233, 0.005013485861127265, 0.05051148371421732, 0.06572199330548756, 0.043529529066290706, 0.0552282218268374, 0.021555107814492658, 0.06145343817479443, 0.09952334672561847, 0.01388299664540682, 0.06836281449068338, 0.024799727361823898, 0.01423362617060775, 0.07924806515802629, 0.03032723398064263, 0.03979655222792644, 0.02013207304116804, 0.087205572926905, 0.012341194124019239, 0.039526911423308775, 0.03855567760183476, 0.10810092629981227, 9.83420005068183, 35.404018834233284, 56.32433585822582, 45.963093638420105, 29.360211342573166, 29.110910519957542, 43.58506344258785, 39.93184447288513, 14.906037747859955, 0.8785358362365514, 0.1536241386202164, 0.546837622532621, 2.7030676044523716, 5.49547933973372, 6.691218176856637, 4.250637162476778, 3.9831809140741825, 14.754803963005543, 27.95316394418478, 45.93235328793526, 55.52081577479839, 52.626868262887, 51.810033693909645, 46.42510324716568, 41.15520782768726, 39.97008942067623, 42.601843401789665, 45.54117947816849, 47.54487656056881, 49.3682087212801, 52.651259154081345, 53.82388383150101, 52.52218008041382, 46.43739178776741, 37.87256017327309, 36.596288457512856, 37.037900760769844, 37.645127177238464, 41.048114374279976, 47.64164216816425, 50.0149530172348, 50.90695135295391, 53.03519815206528, 50.70496179163456, 51.62812985479832, 53.99942301213741, 50.0019159168005, 47.31620103120804, 39.132477566599846, 36.94475635886192, 37.47518129646778, 36.02386437356472, 36.926502138376236, 38.90434540808201, 38.592629134655, 39.99006874859333, 38.21676090359688, 38.24836380779743, 37.342184633016586, 44.22531768679619, 46.392007023096085, 49.95270095765591, 49.01904545724392, 54.201078191399574, 47.86494858562946, 40.32265730202198, 51.425144746899605, 52.01301880180836, 52.35046349465847, 49.223972260951996, 49.85870540142059, 48.102466240525246, 43.70128020644188, 38.20043317973614, 38.728593438863754, 36.58075109124184, 38.10916967689991, 35.750286653637886, 36.35867200791836, 36.93258561193943, 41.45246587693691, 49.125090166926384, 50.34130610525608, 52.084705755114555, 47.49241277575493, 48.61649505794048, 51.70124173164368, 51.475739032030106, 49.34971131384373, 45.99938929080963, 40.299071967601776, 37.18993820250034, 37.056759148836136, 36.13698810338974, 40.516572296619415, 45.57710275053978, 45.464051216840744, 44.550204053521156, 41.98335058987141, 40.168085396289825, 37.49674893915653, 37.417568787932396, 38.8907041400671, 40.635707303881645, 44.552407935261726, 44.4784677028656, 47.01971814036369, 48.76485049724579, 50.32249331474304, 50.66172011196613, 54.91930045187473, 55.64546048641205, 43.88136774301529, 25.702977888286114, 11.58926222473383, 4.144642800092697, 3.148441230878234, 9.293143283575773, 8.909405674785376, 5.339333843439817, 3.0939103569835424, 4.311811504885554, 1.7270683636888862, 0.4424612014554441, 12.032809574157, 36.750898361206055, 55.0521869212389, 50.381314158439636, 48.715008571743965, 55.15970215201378, 34.440546333789825, 6.196565944701433, 0.025226048528566025, 0.06395672826329246, 0.01596106023498578, 0.01671116002398776, 0.05704057613911573, 0.03580270305974409, 0.058921482632285915, 0.016738166777940933, 0.013540063191612717, 0.06072133546695113, 0.034192799212178215, 0.07133673381758854, 0.05194639656110667, 0.0541696520667756, 0.04897471852018498, 0.04171918968495447, 0.1193402185162995, 0.049910459129023366, 0.017975900263991207, 0.01481498940847814, 0.21408466855064034, 0.13948963925940916, 0.1113810928654857, 0.10382051535998471, 0.21311244025127962, 0.2201970710302703, 0.22454390418715775, 0.1883442560210824, 0.23281862813746557, 0.23656390607357025, 0.2339190401835367, 0.1301757898181677, 0.12592968094395474, 0.15292061230866238, 0.09923932680976577, 0.292344645713456, 0.2275803717202507, 0.1223831353127025, 0.1806853513699025, 0.22926160338101909, 0.11578954654396512, 0.14446636283537373, 0.19676429248647764, 0.22815758449723944, 11.105847414582968, 41.69768571853638, 64.37029391527176, 52.85123482346535, 35.066475346684456, 36.62581667304039, 47.92881555855274, 46.84032216668129, 18.900717794895172, 1.2767015676945448, 0.4405971639789641, 1.6351115168072283, 7.396092703565955, 9.63613947853446, 12.208855077624321, 6.908925594761968, 5.489220600575209, 15.786957778036594, 31.524261720478535, 48.9360237121582, 58.28167162835598, 55.28381489217281, 53.899138793349266, 49.8676311224699, 43.12827095389366, 42.52206288278103, 46.482586562633514, 49.869185239076614, 49.26210321485996, 53.38910736143589, 57.245623022317886, 57.259925454854965, 55.024623200297356, 48.78040686249733, 40.12809254229069, 37.25828893482685, 38.22026051580906, 41.46752446889877, 42.88194537162781, 49.84306924045086, 52.41370730102062, 52.860836908221245, 54.477080181241035, 51.42411880195141, 52.81462758779526, 55.55013120174408, 52.88513280451298, 50.67367047071457, 42.01564505696297, 37.98835515975952, 39.17415373027325, 37.906294763088226, 37.66618564724922, 41.54722899198532, 40.720944330096245, 41.34158402681351, 39.27308902144432, 41.27314209938049, 38.38172525167465, 46.04419268667698, 48.2643261551857, 50.97861550748348, 51.93466320633888, 56.15475855767727, 50.42686611413956, 42.49114394187927, 54.28198724985123, 54.64157335460186, 53.74726474285126, 52.373980432748795, 52.07832969725132, 51.58109977841377, 45.318849608302116, 40.69113872945309, 40.53730018436909, 39.861221462488174, 40.44621527194977, 38.91031488776207, 38.60376253724098, 39.258231818675995, 41.76206946372986, 52.64663480222225, 52.67110548913479, 55.32851569354534, 48.57033893465996, 48.959829434752464, 53.477239832282066, 52.92258359491825, 51.137781366705894, 48.511947467923164, 41.60968244075775, 38.85294936597347, 37.97140046954155, 38.44504125416279, 43.38269390165806, 47.93682172894478, 49.51430708169937, 47.6189573854208, 45.57326875627041, 42.33762837946415, 40.18830791115761, 39.11608524620533, 40.54908715188503, 42.222802340984344, 45.45674800872803, 45.96430577337742, 49.23489287495613, 50.33033229410648, 51.73824034631252, 52.68171451985836, 56.23971439898014, 58.35736356675625, 45.318663418293, 27.8887801989913, 14.285366702824831, 5.471852207556367, 8.36109984666109, 13.408598899841309, 14.34433288872242, 9.930464085191488, 6.877224845811725, 7.860746970400214, 2.53651802893728, 0.5509488831739873, 14.614090863615274, 43.60993690788746, 62.42777734994888, 55.08345164358616, 56.83054469525814, 64.36961755156517, 41.281573846936226, 7.876744586974382, 0.14699457795359194, 0.20621603296604007, 0.12765214632963762, 0.12624101189430803, 0.2961633517406881, 0.15243647969327867, 0.13157248205970973, 0.1274907440529205, 0.10340996668674052, 0.165134463168215, 0.14332511782413349, 0.15125879523111507, 0.06917372957104817, 0.16050879028625786, 0.08692691873875447, 0.11270708811935037, 0.30633047805167735, 0.18384406546829268, 0.11758736218325794, 0.12898361863335595], [0.014899336347298231, 0.05675263026205357, 0.0227643205653294, 0.04785269884450827, 0.041317494833492674, 0.010055192815343617, 0.014928770851838635, 0.02367329376284033, 0.047939244395820424, 0.03339024442539085, 0.07425912583130412, 0.016170013768714853, 0.027638488609227352, 0.07282883656444028, 0.046070787429925986, 0.03577863521059044, 0.016281321077258326, 0.023569973818666767, 0.056806651191436686, 0.02474987915775273, 0.04596259714162443, 0.04315986530855298, 0.06360240469803102, 0.0695184720098041, 4.455961994826794, 23.557656705379486, 41.57772995531559, 45.868645906448364, 32.45593562722206, 27.8662284091115, 36.42579920589924, 40.33612757921219, 19.38711639493704, 1.8772602919489145, 0.04619806946720928, 0.44914655678439885, 2.538674413226545, 4.816350806504488, 4.8563759587705135, 3.2047456596046686, 3.9033334236592054, 8.909938596189022, 25.07278550416231, 47.432820573449135, 53.17330554127693, 49.9830537289381, 47.723725363612175, 44.20845419168472, 43.52931283414364, 46.325335800647736, 47.502999007701874, 49.73793648183346, 49.45640578866005, 49.57972437143326, 49.169870764017105, 51.1898347735405, 45.17160750925541, 49.101045057177544, 37.98098735511303, 33.51371146738529, 37.06411175429821, 38.91251876950264, 45.40980152785778, 49.16670173406601, 49.114921912550926, 51.73974886536598, 47.324670776724815, 50.97146809101105, 49.67252679169178, 48.117874413728714, 47.41276144981384, 37.571680918335915, 34.87298972904682, 34.90422785282135, 33.58869284391403, 35.244169011712074, 37.21336394548416, 42.58289761841297, 42.40125596523285, 41.99082858860493, 41.61129355430603, 38.405952751636505, 36.30952924489975, 35.19600659608841, 38.63188102841377, 45.07211744785309, 45.26454672217369, 49.725621342659, 50.86494840681553, 31.924412548542023, 51.211732998490334, 46.96641840040684, 50.947293788194656, 49.74756136536598, 49.14703778922558, 48.90548475086689, 46.62814915180206, 42.549440413713455, 35.11792838573456, 35.4091789573431, 35.91474562883377, 35.278975144028664, 35.540150329470634, 35.854534059762955, 38.93757462501526, 44.706793650984764, 48.61106134951115, 50.60684725642204, 48.60893726348877, 49.20042872428894, 52.4532213807106, 48.163418769836426, 47.25646823644638, 41.70484073460102, 37.01613172888756, 37.412062883377075, 36.9783503562212, 37.846858352422714, 47.98212289810181, 52.013866156339645, 50.41885994374752, 49.53693486750126, 48.48276503384113, 46.12277626991272, 43.54208014905453, 43.36599759757519, 40.979965031147, 39.90623004734516, 38.32704998552799, 39.66654270887375, 42.42738336324692, 42.41625376045704, 49.44926977157593, 50.03635346889496, 52.520367577672005, 53.24194885790348, 42.33376398682594, 22.4751802906394, 9.176283404231071, 2.383154220879078, 1.5274302824400365, 8.681504353880882, 6.5660851914435625, 4.0291679464280605, 2.34880477655679, 1.5993872587569058, 0.04774821187311318, 0.7311807526275516, 12.291016168892384, 34.826495423913, 34.90652672946453, 31.12507414072752, 42.28224255144596, 43.32736127078533, 25.854870937764645, 3.6746989795938134, 0.10329881522920914, 0.009531038958812132, 0.05972067177935969, 0.02058779438812053, 0.0582534124259837, 0.00910854541871231, 0.09695789805846289, 0.04000458364316728, 0.02541222369472962, 0.06620777348871343, 0.06138562814157922, 0.020147511568211485, 0.03007431932928739, 0.04556414918624796, 0.02807477125315927, 0.03000049604452215, 0.022848511653137393, 0.03421642177272588, 0.09001697675557807, 0.10487899606232531, 0.041692305385367945, 0.01927097764564678, 0.01919187583553139, 0.01487270066718338, 0.022726580500602722, 0.04937075820635073, 0.018764222513709683, 0.03017935363459401, 0.025981313665397465, 0.0255397079672548, 0.01586163285537623, 0.08733507769647986, 0.01672986585617764, 0.08541876333765686, 0.08003388822544366, 0.04059934821270872, 0.07552122959168628, 0.04987944848835468, 0.04981966478226241, 0.03567158040823415, 0.05007160536479205, 0.04642855827114545, 0.03130020071694162, 0.05804608605103567, 5.999116664752364, 28.99835865944624, 49.66170497238636, 51.85120828449726, 34.482503682374954, 30.929196551442146, 43.99941220879555, 44.277238100767136, 21.636880673468113, 2.292738310061395, 0.13296461751451716, 0.41629533050581813, 3.5058258287608624, 4.687465997412801, 6.082793399691582, 3.3040573680773377, 4.829256813973188, 9.114550966769457, 27.778715305030346, 49.38374988734722, 55.96519812941551, 51.39166094362736, 48.89502391219139, 46.679636389017105, 44.498108848929405, 48.10736417770386, 50.18230363726616, 51.26428037881851, 52.32187382876873, 51.267609000205994, 52.53424063324928, 53.83199259638786, 48.31644035875797, 51.74643650650978, 39.44197095930576, 35.24378143250942, 37.02521704137325, 41.62880301475525, 46.98887899518013, 50.85892952978611, 50.532990619540215, 53.52996200323105, 49.474177435040474, 52.26171925663948, 50.769349336624146, 51.14714026451111, 49.62643526494503, 40.41384860873222, 36.27738296985626, 36.51722609996796, 35.33745780587196, 38.17916952073574, 38.82365673780441, 44.13992866873741, 43.52822229266167, 42.54944421350956, 42.46707983314991, 38.62821042537689, 38.515740260481834, 37.40463808178902, 40.382713079452515, 47.76654526591301, 46.99397832155228, 52.7571252733469, 52.49567650258541, 36.62355199456215, 52.527347803115845, 47.93822765350342, 52.500722631812096, 50.967067927122116, 51.60799853503704, 52.37659849226475, 48.79518426954746, 44.994252026081085, 37.67861098051071, 38.27851518988609, 37.72410213947296, 38.707025796175, 38.67728479206562, 37.108740359544754, 40.644393637776375, 48.35900567471981, 49.503264874219894, 51.7287902534008, 49.81980688869953, 50.911241322755814, 53.23376789689064, 50.85483334958553, 48.32119010388851, 43.49702976644039, 39.144439324736595, 38.24093900620937, 38.57851669192314, 40.8657393604517, 48.82276698946953, 53.664425387978554, 52.11225427687168, 51.641394942998886, 49.72735404968262, 47.56566144526005, 44.72622200846672, 44.90581937134266, 41.282250210642815, 40.86680710315704, 39.91793341934681, 42.87561111152172, 43.42418007552624, 46.002239137887955, 50.51750265061855, 51.40845224261284, 51.87146119773388, 54.47244442999363, 42.73795589804649, 24.66619022190571, 10.057209134101868, 3.963968432508409, 6.44210496917367, 9.582780841737986, 7.558385794982314, 5.926439389586449, 2.312302985228598, 1.1554764350876212, 0.1768944610375911, 0.8044194476678967, 15.13800485059619, 39.50955793261528, 45.75985014438629, 38.29968765377998, 47.970886901021004, 51.67649365961552, 30.27953401207924, 4.499888112768531, 0.0645042180258315, 0.04579919477691874, 0.016846349644765723, 0.03560821583960205, 0.07259550533490255, 0.010854085103346733, 0.045637369476025924, 0.06578176587936468, 0.046627372212242335, 0.04120269943086896, 0.03127441479591653, 0.053358659060904756, 0.049137530877487734, 0.0235982515005162, 0.05491524701938033, 0.025768150298972614, 0.039498438927694224, 0.041988229349954054, 0.06792655040044338, 0.03637802707089577, 0.18559127405751497, 0.18499987141694874, 0.154930274002254, 0.077889007225167, 0.10442879443871789, 0.14974925201386213, 0.09377385445986874, 0.10835989131010137, 0.14341686211992055, 0.06817031622631475, 0.1586526195751503, 0.1865486297174357, 0.10495463575352915, 0.2806679910281673, 0.2019263303373009, 0.09795744481380098, 0.2641426183981821, 0.12434333286364563, 0.1151197508443147, 0.0742078953771852, 0.1662394023151137, 0.1876761598396115, 0.09651441287132911, 0.2565369108924642, 6.1873946618288755, 31.993006467819214, 56.80222101509571, 59.7019100189209, 44.76538650691509, 37.86773443222046, 49.00297611951828, 51.74134477972984, 25.26294630020857, 2.901630224660039, 0.46293206862173975, 1.0212848545052111, 7.7509646862745285, 14.630468934774399, 11.152381617575884, 7.109607076272368, 5.8679101802408695, 11.37588182464242, 32.63835243880749, 51.37740030884743, 57.279638797044754, 53.43635782599449, 51.87184497714043, 49.31981451809406, 47.92455218732357, 50.709605142474174, 51.77804321050644, 55.062765553593636, 55.52238509058952, 54.49215017259121, 53.33429530262947, 56.48222118616104, 52.314031049609184, 52.880801036953926, 41.99753522872925, 37.40272678434849, 39.21631246805191, 43.33747252821922, 49.03475761413574, 52.80862011015415, 53.42489764094353, 57.35949531197548, 49.07102286815643, 53.992932960391045, 55.30702404677868, 50.9821455180645, 52.048166915774345, 42.08968788385391, 39.60652872920036, 38.39297264814377, 36.71443931758404, 38.487272188067436, 40.978011935949326, 47.58230835199356, 45.37478640675545, 45.73351375758648, 45.07302559912205, 42.09508739411831, 40.431745648384094, 38.73184226453304, 43.64678353071213, 48.83043497800827, 50.18468990921974, 55.330901965498924, 55.18185876309872, 39.75969471037388, 51.29869893193245, 49.25698108971119, 55.28288014233112, 52.29579582810402, 53.341142535209656, 54.03587445616722, 51.664642095565796, 47.938706427812576, 40.36847144365311, 40.739407539367676, 40.389856696128845, 41.24583296477795, 40.99821165204048, 39.60479602217674, 43.204396069049835, 48.52076679468155, 52.97584153711796, 55.1493439078331, 51.167940348386765, 51.32268324494362, 55.437980219721794, 53.08151386678219, 50.8534350246191, 46.2107415497303, 39.85717847943306, 40.84968522191048, 41.734574139118195, 43.10635752975941, 52.49336242675781, 55.4845505207777, 54.26083378493786, 54.51612688601017, 52.88449443876743, 50.32919995486736, 47.736709266901016, 49.13430467247963, 45.27233250439167, 43.63755762577057, 43.43215584754944, 44.50597062706947, 46.287630423903465, 46.728060990571976, 55.00747092068195, 53.39167982339859, 56.25792682170868, 55.97620613873005, 44.780190512537956, 25.451594777405262, 12.47750636190176, 5.9573326818645, 6.909682704135776, 17.418360337615013, 14.624246768653393, 12.720763608813286, 7.272591730579734, 3.0469353776425123, 0.11041860896511935, 1.4978152653202415, 17.670866288244724, 45.89484930038452, 48.29724378883839, 43.4527013450861, 53.99305835366249, 57.617064490914345, 34.97469127178192, 4.826389392837882, 0.13224531314335763, 0.11954879169934429, 0.11825137655250728, 0.19169548322679475, 0.17641659214859828, 0.1526136155007407, 0.19296010286780074, 0.2120447569177486, 0.13088614388834685, 0.16492675087647513, 0.1416504170629196, 0.15837961313081905, 0.24530656897695735, 0.11765726507292129, 0.12857438356149942, 0.15610997710609809, 0.11856871147756465, 0.1630185852991417, 0.14481294580036774, 0.2464795036939904], [0.02699034877878148, 0.04222601717629004, 0.06204824356245808, 0.05164282105397433, 0.019083971274085343, 0.08546965982532129, 0.038122211408335716, 0.016826749524625484, 0.021971721689624246, 0.07804896973539144, 0.025163068021356594, 0.08259906229795888, 0.047370655374834314, 0.05118530185427517, 0.1062180011649616, 0.07464899084880017, 0.053798411245225, 0.0218209914964973, 0.04546857911918778, 0.057951150520239025, 0.020631972583942115, 0.0282924542989349, 0.04480460185732227, 0.033200833495357074, 1.6415792447514832, 14.159225821495056, 37.648353204131126, 47.467455714941025, 30.500855036079884, 21.300777308642864, 23.86030476540327, 40.69690681993961, 22.435573115944862, 3.7158289225772023, 0.25724304956384003, 0.20342417730716988, 1.4061341411434114, 2.5532810669392347, 5.114180725067854, 1.6385396453551948, 2.9281748877838254, 9.213606901466846, 31.812844835221767, 46.54932618141174, 52.78875857591629, 51.256118416786194, 48.22804570198059, 47.86057502031326, 47.316516414284706, 50.36451905965805, 51.04449637234211, 53.111163675785065, 50.70267051458359, 52.80773475766182, 49.92227219045162, 45.89444272220135, 49.16470304131508, 48.22420030832291, 38.46850499510765, 34.775080382823944, 36.1426118016243, 43.81812393665314, 48.99272806942463, 49.09350626170635, 51.740858405828476, 46.39482647180557, 50.84388993680477, 49.39881607890129, 46.74652799963951, 45.06889522075653, 39.990733712911606, 35.37896677851677, 35.18216393887997, 34.650302678346634, 35.035510808229446, 34.753273352980614, 44.11023326218128, 48.035133853554726, 50.067101418972015, 48.80255587399006, 46.34857155382633, 43.687623739242554, 41.98067173361778, 39.799068197607994, 37.59815409779549, 41.271926164627075, 45.685077756643295, 49.57252375781536, 49.127723425626755, 34.12317596375942, 43.80509063601494, 46.77298977971077, 47.71084785461426, 48.26199308037758, 48.447179943323135, 50.72337940335274, 47.88772836327553, 44.106615856289864, 39.74255383014679, 34.92902532219887, 34.26205851137638, 36.274821907281876, 34.2769119143486, 34.6421255171299, 39.046913757920265, 46.00396424531937, 47.48821020126343, 51.30682669579983, 48.88437308371067, 49.89346593618393, 49.50269490480423, 48.271614164114, 44.39026303589344, 39.16242755949497, 36.09746642410755, 35.075161680579185, 34.409520998597145, 41.715236976742744, 51.45737461745739, 50.300990268588066, 49.74017836153507, 50.76015003025532, 52.21831038594246, 48.864310160279274, 47.91604444384575, 46.29312872886658, 49.49145130813122, 48.01437556743622, 47.34439171850681, 44.67274747788906, 45.955839827656746, 46.611540243029594, 50.913232415914536, 51.217341497540474, 55.67077472805977, 51.64854995906353, 37.661359906196594, 20.98759811371565, 7.102774567902088, 3.1374885560944676, 4.785182503983378, 7.284577237442136, 7.543540466576815, 3.121377183124423, 2.5618246709927917, 1.6692855767905712, 0.1823907473590225, 0.9978980594314635, 14.376216027885675, 37.88880430161953, 35.772701650857925, 32.16377690434456, 46.91307686269283, 40.94556167721748, 21.129397004842758, 1.1429150216281414, 0.06477164351963438, 0.029731413706031162, 0.029956835496705025, 0.06136245829111431, 0.04233712410496082, 0.04963177154422738, 0.04433180554769933, 0.01596469861397054, 0.031997659971239045, 0.07641822638106532, 0.09703459902084433, 0.06598028296139091, 0.02681580121134175, 0.021236064094409812, 0.03177706399583258, 0.03650070408184547, 0.04232766914356034, 0.07932912252726965, 0.01771431547240354, 0.05417768952611368, 0.016277714239549823, 0.02142014454875607, 0.061199979900266044, 0.06811769053456374, 0.09220394495059736, 0.06858928085421212, 0.07178964428021573, 0.025403772488061804, 0.045400843300740235, 0.062439429602818564, 0.04494958782743197, 0.01563276007800596, 0.08178307834896259, 0.042761317163240165, 0.06031629352946766, 0.03787500943872146, 0.057861135428538546, 0.016453144962724764, 0.036132969908067025, 0.07479684893041849, 0.0073396025709371315, 0.059856996886082925, 0.03629338512837421, 0.037468011942110024, 2.3941574804484844, 18.722393363714218, 44.24561619758606, 53.42261776328087, 34.92319643497467, 26.772392503917217, 32.479125782847404, 45.95579423010349, 26.20869655162096, 3.099695546552539, 0.3863404394360259, 0.22438432759372517, 2.4784098844975233, 5.006783762946725, 6.177432546392083, 5.443090125918388, 3.430643775500357, 10.02211706712842, 33.661120757460594, 50.738855972886086, 54.18543443083763, 54.15483847260475, 49.86078388988972, 49.41833183169365, 50.89745946228504, 51.06463149189949, 53.26840303838253, 55.479090213775635, 52.18040741980076, 54.89462077617645, 50.81495448946953, 48.54746416211128, 50.73008984327316, 50.58602437376976, 40.6553028523922, 36.832791566848755, 37.71874822676182, 43.94324742257595, 50.05567543208599, 49.93867211043835, 52.100440710783005, 49.178994074463844, 50.43803371489048, 51.51145711541176, 48.79962623119354, 47.91672080755234, 41.97101265192032, 37.12174326181412, 37.34364375472069, 36.03359565138817, 36.793604269623756, 36.10269494354725, 44.59522023797035, 49.6258082985878, 50.66456995904446, 50.82991048693657, 46.8350974470377, 46.688356921076775, 43.12480553984642, 40.36393068730831, 40.16994349658489, 42.44553118944168, 47.88802854716778, 50.1662191003561, 51.237674206495285, 35.62046281993389, 45.90252868831158, 49.46126952767372, 49.59031440317631, 49.612117633223534, 50.85433937609196, 51.53945781290531, 49.87213768064976, 46.18781737983227, 40.470085591077805, 36.66097618639469, 35.93657545745373, 37.50732757151127, 36.12650826573372, 36.67536601424217, 40.59666059911251, 47.981324940919876, 50.108853578567505, 53.845174089074135, 48.617319613695145, 49.7020398080349, 51.19565226137638, 49.634019657969475, 48.07025156915188, 40.76058380305767, 38.08897376060486, 36.972491070628166, 37.19201669096947, 43.00230771303177, 52.89665758609772, 51.82690478861332, 50.25271385908127, 52.35573001205921, 53.5030822455883, 50.99280394613743, 50.2704893052578, 47.95017421245575, 49.107785895466805, 48.64783577620983, 48.387435749173164, 46.51505962014198, 47.57694683969021, 47.8257916867733, 52.89510726928711, 53.33331495523453, 57.75547966361046, 53.131530582904816, 40.783363580703735, 21.692114509642124, 7.3314510472118855, 4.133226312696934, 5.662622870877385, 7.974493391811848, 8.169915955513716, 5.63823957927525, 3.9124025870114565, 1.3336197822354734, 0.1783910018275492, 1.362750087864697, 16.339060552418232, 42.478232234716415, 38.39809097349644, 34.366894885897636, 51.87317870557308, 46.01116485893726, 25.397394485771656, 1.7550732172094285, 0.07767647097352892, 0.02412269386695698, 0.1118483416212257, 0.11906393177923746, 0.019704722144524567, 0.034430368104949594, 0.038026077309041284, 0.0305772876527044, 0.061359975807135925, 0.040227483987109736, 0.051653270493261516, 0.049848133567138575, 0.055983631682465784, 0.012948146613780409, 0.035215137322666124, 0.05810090478917118, 0.04155246992013417, 0.057287770687253214, 0.06323957612039521, 0.06763709796359763, 0.14404667832423002, 0.11189973534783348, 0.10837412570253946, 0.19678390002809465, 0.08463818725431338, 0.162303704128135, 0.1555612776428461, 0.05823561572469771, 0.09675332505139522, 0.3882134420564398, 0.15338470693677664, 0.17949433793546632, 0.191867305256892, 0.20975778432330117, 0.14341383415739983, 0.14408670976990834, 0.1505673659266904, 0.1325642882147804, 0.12267760466784239, 0.1415838167304173, 0.11234096440603025, 0.17734979832312092, 0.20070833241334185, 0.10220102296443656, 2.2478244826197624, 19.626429453492165, 51.0085579007864, 60.85843116044998, 43.21608044207096, 33.49569283425808, 33.13092760741711, 51.32707580924034, 30.964937433600426, 5.804354315623641, 0.5409970984328538, 0.9562579344492406, 4.708414748311043, 9.568550605326891, 13.388582523912191, 6.8684188183397055, 5.695690596476197, 11.003399211913347, 35.16926363110542, 50.807001516222954, 55.903896018862724, 55.775979682803154, 52.23911426961422, 51.94765470921993, 53.92316110432148, 54.97122086584568, 56.86022490262985, 56.41206555068493, 54.093726351857185, 55.08354663848877, 52.95651197433472, 49.96327959001064, 54.33156318962574, 52.75221213698387, 43.22341024875641, 38.463561460375786, 40.697689577937126, 46.5610371530056, 53.23957398533821, 52.16539062559605, 55.20672082901001, 47.77788005769253, 52.9148206114769, 54.12133947014809, 51.21077544987202, 49.40548092126846, 44.07756641507149, 39.435773491859436, 38.92304800450802, 37.98300504684448, 38.69259037077427, 37.49927580356598, 47.69732438027859, 53.01708072423935, 53.28649006783962, 53.7167713791132, 49.31803621351719, 48.9535977691412, 46.67051687836647, 44.84346851706505, 42.01611243188381, 45.085507929325104, 49.560641795396805, 52.55892790853977, 52.66247995197773, 39.237059354782104, 47.13101036846638, 49.38826784491539, 51.244149059057236, 50.43561704456806, 51.98091812431812, 54.09855969250202, 52.79017210006714, 47.90693253278732, 43.06765280663967, 38.57306018471718, 37.572437077760696, 40.68053349852562, 37.038561925292015, 38.63294497132301, 43.79754804074764, 49.905811473727226, 52.471034824848175, 54.697616547346115, 49.08144570887089, 50.36677993834019, 53.68921905755997, 51.70153431594372, 50.01892380416393, 42.805314883589745, 39.56150874495506, 37.86744184792042, 39.04273018240929, 44.56949561834335, 56.63504518568516, 53.31265166401863, 52.72381626069546, 54.26137335598469, 56.001318991184235, 52.91676990687847, 51.75818167626858, 49.23112727701664, 54.08765807747841, 52.27757580578327, 50.93065828084946, 49.26977500319481, 50.15831932425499, 50.210494324564934, 55.169714614748955, 56.18297964334488, 60.4854279756546, 54.41404156386852, 41.708712726831436, 23.68950393050909, 9.555125925689936, 7.051049843430519, 12.370317913591862, 15.182821545749903, 15.014774613082409, 8.946439437568188, 6.596115930005908, 4.144835164770484, 0.5722256633453071, 1.8359297909773886, 20.649743042886257, 49.83028672635555, 48.72814066708088, 45.93729302287102, 58.30881357192993, 54.79795016348362, 27.95101135969162, 2.3180043417960405, 0.12884359020972624, 0.1036077416210901, 0.1805991880246438, 0.2297524004825391, 0.11957018781686202, 0.11352399975294247, 0.1696031421306543, 0.10295501531800255, 0.14939661312382668, 0.21068809612188488, 0.19749769766349345, 0.1564765238435939, 0.10120603299583308, 0.1321474090218544, 0.11439433859777637, 0.16375381615944207, 0.1186287883319892, 0.2239719161298126, 0.09254988966858946, 0.21470314473845065], [0.06083621992729604, 0.038417482282966375, 0.048356939951190725, 0.01762832467647968, 0.002468681655045657, 0.03403979804716073, 0.05503789805516135, 0.019887377675331663, 0.056396184154436924, 0.019499015506880824, 0.05964229356322903, 0.06559977642609738, 0.045341994700720534, 0.004939966393067152, 0.005551843032662873, 0.025099783233599737, 0.04551401339995209, 0.029130741640983615, 0.01296524569625035, 0.04413450929860119, 0.0410567746439483, 0.03257942582422402, 0.02179400144086685, 0.04985501698683947, 0.17344415711704642, 8.18110540509224, 29.412221051752567, 47.98847995698452, 45.11040799319744, 27.50505968928337, 34.38445374369621, 40.39705350995064, 34.230128824710846, 8.567945547401905, 0.4021922388346866, 0.2869622642174363, 1.680453890003264, 2.690368923358619, 2.6114238845184445, 5.151289533823729, 2.797388043254614, 11.257906705141068, 26.84940867125988, 42.790309488773346, 53.81657302379608, 51.559509336948395, 50.42747788131237, 49.6793208271265, 49.70023110508919, 52.64433592557907, 51.86001241207123, 52.72054463624954, 50.91050796210766, 50.69439075887203, 53.751695305109024, 51.20892874896526, 51.95745438337326, 44.35964047908783, 36.119558438658714, 35.70820011198521, 39.06212814152241, 48.97076904773712, 47.51244530081749, 50.514614805579185, 48.768175318837166, 49.526436030864716, 51.21260695159435, 46.97709962725639, 46.66131377220154, 42.21203751862049, 35.33175051212311, 37.12201684713364, 37.493519112467766, 35.855639800429344, 33.86971816420555, 36.40371099114418, 46.51689112186432, 50.06015919148922, 50.35614050924778, 50.081996619701385, 47.84233599901199, 46.79506279528141, 47.20505319535732, 44.84125703573227, 44.467923268675804, 44.7373516112566, 45.4099877178669, 47.06453673541546, 48.62570196390152, 29.404999539256096, 43.32503579556942, 48.67817334830761, 48.66339214146137, 51.11210994422436, 48.47521863877773, 49.776762798428535, 47.48223312199116, 47.3409529030323, 39.70415309071541, 35.80468833446503, 34.21057127416134, 34.5332195609808, 33.06967869400978, 35.505636781454086, 37.71728150546551, 44.44218344986439, 48.1221491843462, 51.81851863861084, 49.59552392363548, 49.84031058847904, 49.09416362643242, 46.55805431306362, 45.22940240800381, 38.74317325651646, 33.96945521235466, 36.58047370612621, 33.7489378452301, 41.429811492562294, 51.46659292280674, 49.658072367310524, 48.49439240992069, 46.616814360022545, 50.5295480042696, 50.598924681544304, 51.30468361079693, 50.1488122344017, 49.94350165128708, 49.84497673809528, 50.24516746401787, 49.608439430594444, 47.113884687423706, 49.05697502195835, 51.857128366827965, 53.72738040983677, 52.22187839448452, 50.2468241751194, 37.5311940908432, 16.432689428329468, 4.574456736445427, 2.983128963969648, 5.447561535984278, 7.865381296724081, 5.692776627838612, 4.86520336009562, 4.722414622083306, 0.8608509914483875, 0.14454718271736056, 1.7332905298098922, 16.866791434586048, 36.79325848817825, 36.484931632876396, 41.81751228868961, 42.57000871002674, 39.04665917158127, 12.39512013271451, 0.29019437672104686, 0.006749863268851186, 0.05746915900090244, 0.03277266994700767, 0.0981352708186023, 0.03724684822373092, 0.06068948991014622, 0.07080194220179692, 0.039914757799124345, 0.049960012329393066, 0.011332627491356106, 0.051723306969506666, 0.034050429312628694, 0.12875386455561966, 0.017603958112886176, 0.04842146598093677, 0.024879810662241653, 0.008379467890335945, 0.017227952703251503, 0.01136289227360976, 0.047594308998668566, 0.03626328361860942, 0.033071376965381205, 0.07068849008646794, 0.018565720274636988, 0.024006198946153745, 0.02337882440770045, 0.046079062376520596, 0.04096806573215872, 0.025025013710546773, 0.12026758398860693, 0.03644673510279972, 0.08448545326245949, 0.02330201954464428, 0.029651489967363887, 0.04397623517434113, 0.009752815876709064, 0.025589222204871476, 0.023014387224975508, 0.04206121215247549, 0.017049508860509377, 0.05481232969032135, 0.0122393074525462, 0.12953941302839667, 0.06113424416980706, 0.4271756310481578, 10.457821637392044, 35.750552639365196, 54.344113916158676, 46.80910304188728, 31.444004327058792, 30.78266691416502, 42.16466166079044, 35.27701824903488, 9.458515159785748, 0.3118610812816769, 0.32485279196407646, 2.072725365869701, 3.919237945228815, 4.829983050003648, 6.165275573730469, 2.5376952532678843, 11.956938095390797, 29.713318794965744, 44.44744236767292, 56.22539296746254, 52.03352630138397, 53.28702963888645, 51.442741602659225, 51.97080686688423, 53.340671360492706, 52.87062518298626, 52.59065240621567, 51.106140464544296, 52.308517545461655, 54.87815625965595, 51.740634217858315, 53.57934795320034, 45.79840287566185, 37.88841672241688, 38.04426155984402, 40.78017555177212, 49.7889943420887, 49.46597747504711, 52.105441242456436, 49.19151820242405, 50.42465843260288, 54.7701470553875, 49.860498905181885, 48.68937894701958, 44.51723702251911, 38.516340628266335, 38.51070173084736, 38.148740753531456, 36.94817617535591, 35.953834131360054, 38.7097692489624, 47.630934342741966, 51.94802328944206, 51.896163672208786, 51.12730152904987, 51.117296665906906, 49.53726924955845, 48.13161067664623, 47.18674957752228, 45.94006307423115, 46.56284585595131, 46.467520371079445, 49.74876970052719, 50.321011394262314, 32.732461988925934, 45.90133935213089, 50.03936670720577, 50.63509874045849, 52.34033323824406, 50.905427634716034, 52.76051849126816, 50.30163623392582, 47.15781792998314, 41.462303549051285, 37.55241975188255, 37.189835608005524, 35.69325931370258, 36.22117638587952, 38.48172068595886, 40.59974983334541, 47.08217918872833, 50.5802258849144, 53.82367104291916, 47.913399785757065, 50.50783596932888, 51.03735655546188, 49.400560185313225, 46.79777204990387, 40.004469975829124, 35.771808698773384, 38.786202147603035, 35.55460475385189, 42.135832607746124, 54.07904773950577, 52.64844350516796, 49.25154358148575, 46.55711956322193, 52.99942307174206, 51.75436668097973, 52.89039172232151, 51.92758798599243, 53.002405911684036, 52.198300659656525, 52.559171095490456, 52.42601104080677, 49.32987257838249, 51.64267547428608, 54.621392637491226, 55.38139745593071, 55.69670453667641, 51.97780229151249, 37.962873727083206, 17.802160643041134, 5.6139683816581964, 3.600393016822636, 7.651352556422353, 5.079816794022918, 6.700665419921279, 5.210320316255093, 3.94404586404562, 1.4493707148358226, 0.0894012613571249, 2.102427422069013, 20.34002546221018, 43.74856486916542, 40.28367139399052, 46.41179256141186, 49.509876519441605, 46.03095419704914, 15.211175624281168, 0.5990946746896952, 0.07859760240535252, 0.00443173160419974, 0.03196707235474605, 0.023996320960577577, 0.02629474674904486, 0.03134726772259455, 0.034426111888024025, 0.011378326162230223, 0.030778636028117035, 0.02952007231215248, 0.04597122089762706, 0.04169873980572447, 0.07463199566700496, 0.09278338417061605, 0.08260894028353505, 0.056471901771146804, 0.002538524013289134, 0.05126330528582912, 0.02328778886294458, 0.06465760510764085, 0.12176252173958346, 0.11223246983718127, 0.1755654823500663, 0.15660352015402168, 0.14976182399550453, 0.09059428601176478, 0.07379853414022364, 0.13937849522335455, 0.18655936117284, 0.1704787724884227, 0.11334906070260331, 0.21005554881412536, 0.13917643809691072, 0.10008859608205967, 0.10705809007049538, 0.14468410896370187, 0.09441912217880599, 0.14710138784721494, 0.18675579281989485, 0.11868091678479686, 0.1902631382108666, 0.12148928522947244, 0.2561736444476992, 0.181680690147914, 0.5763976613525301, 11.590483859181404, 41.115214973688126, 60.81243082880974, 56.12320505082607, 39.843617007136345, 43.237454295158386, 50.54500937461853, 42.82983496785164, 10.871572885662317, 0.8511356846429408, 0.8836023299954832, 2.774599716067314, 8.302208706736565, 10.113574359565973, 11.773288249969482, 4.910225244238973, 13.007844854146242, 29.99967522919178, 46.45748890936375, 56.87697820365429, 54.52574796974659, 55.525440126657486, 53.661894723773, 53.6668686568737, 56.79155498743057, 53.86529020965099, 53.61556001007557, 52.15957313776016, 52.9937993735075, 57.39957936108112, 54.79400597512722, 56.97327643632889, 47.03329101204872, 39.66926336288452, 39.67516824603081, 41.46362587809563, 53.29381987452507, 51.62705451250076, 53.41296248137951, 49.38677832484245, 50.31878851354122, 56.20664857327938, 51.084341034293175, 50.54023303091526, 46.523757353425026, 39.32859264314175, 41.0272116959095, 42.120166048407555, 39.40200090408325, 36.247071996331215, 39.70995917916298, 50.34795194864273, 54.6476948261261, 55.290848314762115, 52.816090509295464, 53.62773455679417, 49.9820201843977, 51.50708734989166, 49.08178389072418, 48.82948882877827, 49.05475214123726, 50.44024899601936, 50.93319274485111, 53.03240530192852, 36.47790960967541, 47.7113988250494, 51.57838672399521, 51.72355033457279, 54.37544323503971, 54.3984168022871, 54.66634802520275, 51.71926036477089, 50.808658227324486, 42.36998364329338, 40.04238434135914, 38.41287977993488, 37.172599732875824, 37.5732996314764, 42.89654038846493, 42.12884858250618, 48.76509748399258, 53.216269835829735, 55.79091668128967, 50.21727696061134, 51.44586503505707, 53.90488028526306, 50.8560074865818, 48.14796879887581, 43.08732055127621, 38.00692856311798, 41.74659289419651, 38.73151548206806, 43.49469669163227, 56.14250801503658, 54.950010403990746, 50.06204389035702, 46.93917766213417, 53.481020629405975, 54.63282622396946, 54.90824684500694, 54.69148747622967, 56.888104006648064, 56.40636205673218, 54.909569174051285, 54.9062405526638, 51.21620535850525, 54.49618175625801, 56.752018108963966, 58.14809739589691, 57.70781122148037, 54.09835450351238, 40.316444635391235, 19.64031580835581, 6.183971045538783, 7.6281358022242785, 13.011254221200943, 17.718287743628025, 13.010492362082005, 11.812979970127344, 10.225454606115818, 1.941462003160268, 0.25442826154176146, 2.9657688830047846, 23.617469295859337, 48.51423494517803, 48.207253217697144, 56.72388441860676, 53.11885066330433, 51.53663456439972, 17.380649261176586, 0.9810828929767013, 0.1608300066436641, 0.18774954340187833, 0.08734632123378105, 0.16511274792719632, 0.15274847857654095, 0.19680908852024004, 0.21085231855977327, 0.13842205982655287, 0.09440446476219222, 0.08859809429850429, 0.14030465099494904, 0.14167826244374737, 0.27276055596303195, 0.1816770833102055, 0.2061062544817105, 0.15535316459136084, 0.1412930284277536, 0.13880485959816724, 0.16723070380976424, 0.17652153183007613], [0.03935826207452919, 0.04134273898671381, 0.030017613680684008, 0.0798281426250469, 0.057792727966443636, 0.08110551236313768, 0.0662992283469066, 0.03560277589713223, 0.06486847152700648, 0.009489335825492162, 0.004119541617910727, 0.00817377702333033, 0.051501297202776186, 0.045213102202978916, 0.03936525681638159, 0.017760731243470218, 0.010953467954095686, 0.08791004918748513, 0.03282150697486941, 0.030392583794309758, 0.01252451480468153, 0.01617479505512165, 0.03704580412886571, 0.020637342022382654, 0.054748979964642785, 2.887957370840013, 20.857550092041492, 45.814373418688774, 43.85077178478241, 34.451900124549866, 42.19769328832626, 42.19600237905979, 34.49020206928253, 12.965123746544123, 1.6488290182314813, 0.04733367786684539, 2.347101755440235, 3.8912821328267455, 3.099446422420442, 6.006706282496452, 1.9050035532563925, 6.528115728870034, 21.979892067611217, 40.7754448056221, 53.56965847313404, 55.371138006448746, 52.31260232627392, 53.10843922197819, 51.559345945715904, 52.47747167944908, 48.05849879980087, 52.115096524357796, 53.93611840903759, 53.58898803591728, 49.00123581290245, 47.149203792214394, 46.09282627701759, 37.64580734074116, 36.149622425436974, 38.61678063869476, 40.208275839686394, 48.40659812092781, 50.20575597882271, 50.332699567079544, 48.9868725836277, 51.15181781351566, 50.63004121184349, 48.19250240921974, 44.029647186398506, 38.30819919705391, 36.791202798485756, 35.10422632098198, 34.5917934179306, 33.88801418244839, 35.97732447087765, 36.30542926490307, 46.98137439787388, 48.96533153951168, 49.53443460166454, 50.41602149605751, 48.8907453417778, 49.412882924079895, 48.84021185338497, 47.45639070868492, 46.61672696471214, 48.0221651494503, 48.32180567085743, 50.3449235111475, 50.413384437561035, 33.607175052165985, 49.86570082604885, 50.34821413457394, 49.25926096737385, 49.475214779376984, 48.46958354115486, 48.64606127142906, 46.01301535964012, 44.7332364320755, 38.630228117108345, 35.51760233938694, 34.100418984889984, 35.990494564175606, 36.15469515323639, 36.56030438840389, 40.63182011246681, 48.128981217741966, 49.626712650060654, 50.502318665385246, 48.77855636179447, 51.89301744103432, 47.99890659749508, 46.85212053358555, 43.2504115998745, 38.2138654589653, 38.845551162958145, 37.419738471508026, 33.28880913555622, 36.2154994904995, 46.487860679626465, 52.16125264763832, 49.61874067783356, 51.50663897395134, 49.989384189248085, 49.44703549146652, 49.43218968808651, 51.228421702980995, 51.32299482822418, 54.814179092645645, 53.43180187046528, 50.847640335559845, 51.94358892738819, 50.24206303060055, 52.58489191532135, 53.620298355817795, 57.46460907161236, 43.846257627010345, 37.0457511395216, 13.914469555020332, 2.850572601892054, 3.3211616752669215, 3.9563493663445115, 2.4325807811692357, 5.404952047392726, 3.83999343495816, 3.6379167158156633, 0.6183972232975066, 0.2160928162629716, 1.721610075328499, 22.846699655056, 37.64843299984932, 33.337176740169525, 34.46849383413792, 37.26246491074562, 31.94284535944462, 8.87036181986332, 0.18046598735963926, 0.033878373506013304, 0.032076130955829285, 0.05462398745294195, 0.07473494639270939, 0.028194654078106396, 0.05315697671903763, 0.008620584249001695, 0.048754092858871445, 0.07521694904426113, 0.01083105997167877, 0.08745603292481974, 0.03474237812042702, 0.050124709741794504, 0.045484134534490295, 0.05476457248732913, 0.010331882167520234, 0.02578058498329483, 0.04077311838045716, 0.01790103426174028, 0.06578784406883642, 0.014043343217053916, 0.10965959227178246, 0.05350948573322967, 0.13155474473023787, 0.03337677444505971, 0.022489642433356494, 0.040266443029395305, 0.059295821920386516, 0.019826443640340585, 0.035072897298960015, 0.028931165143148974, 0.04722412944829557, 0.09324142287368886, 0.026706670250860043, 0.04866490526183043, 0.03612317355873529, 0.021615099321934395, 0.05836703894601669, 0.020513312447292265, 0.06008674725308083, 0.023012902929622214, 0.0008352628003649443, 0.019789156285696663, 0.03501545135804918, 0.1259107858641073, 4.263189788907766, 24.76960927248001, 52.7182761579752, 50.997166112065315, 38.06614838540554, 42.842951864004135, 47.11148701608181, 40.51187954843044, 14.79963205754757, 1.1388405715115368, 0.05807122630358208, 0.5373121274169534, 2.8939608111977577, 4.00838116183877, 4.870907803997397, 3.4435875434428453, 9.102568309754133, 24.886245913803577, 40.65907984972, 54.903094321489334, 55.81106320023537, 53.4718669205904, 53.88865515589714, 53.513759672641754, 52.86887347698212, 49.13517862558365, 50.72580747306347, 55.304671972990036, 55.7968557626009, 52.36946627497673, 50.68663917481899, 47.81389832496643, 39.87885631620884, 37.71615296602249, 39.32637356221676, 42.52467334270477, 50.307738706469536, 51.69210322201252, 51.486895233392715, 50.45750007033348, 52.27824077010155, 53.071512803435326, 50.118611454963684, 46.567542403936386, 40.527299121022224, 38.96740682423115, 37.20755785703659, 36.887440234422684, 36.47423520684242, 37.26375684142113, 39.16183099150658, 48.46921496093273, 52.27706663310528, 52.40446999669075, 51.18391469120979, 49.40133914351463, 52.020572796463966, 50.53571507334709, 48.10663841664791, 49.16965417563915, 49.42728795111179, 48.663684725761414, 50.809095203876495, 50.593281984329224, 36.93766973912716, 51.00921906530857, 52.481290474534035, 52.65751741826534, 50.75211726129055, 51.30782224237919, 51.87209956347942, 47.859951853752136, 46.06475718319416, 42.34170936048031, 37.221822291612625, 36.03404402732849, 36.34381860494614, 38.08776542544365, 38.55268947780132, 42.909486293792725, 49.02841195464134, 50.25373600423336, 51.83999888598919, 48.99504974484444, 52.43772201240063, 50.29190115630627, 48.60057771205902, 44.45859096944332, 38.71719405055046, 39.92456026375294, 37.7349391579628, 35.20844712853432, 37.61708848178387, 49.2329777777195, 52.746478244662285, 50.8391097933054, 50.552696362137794, 50.11870265007019, 49.52373057603836, 52.1907314658165, 51.97781749069691, 52.462827265262604, 55.07891848683357, 55.31601816415787, 51.19367636740208, 54.925364926457405, 52.85979576408863, 54.72378954291344, 55.46858757734299, 58.32000017166138, 46.177645325660706, 39.417637065052986, 15.720659885555506, 3.848138297908008, 3.852746025659144, 4.961715331301093, 6.364914486184716, 6.587826199829578, 6.440001307055354, 1.8918227730318904, 0.7506812468636781, 0.14866892248392105, 2.273580925539136, 23.995283022522926, 42.961828485131264, 37.30014368891716, 41.56962879002094, 44.49498921632767, 37.8042284399271, 10.729054883122444, 0.27729923429433256, 0.06272051061387174, 0.019975928880739957, 0.07332999404752627, 0.03807289198448416, 0.041488541319267824, 0.08022908048587851, 0.09194162543280981, 0.07739261433016509, 0.12345438095508143, 0.03424326525419019, 0.043056220674770884, 0.008219562896556454, 0.05267316322715487, 0.047553234835504554, 0.10965194072923623, 0.039483592263422906, 0.03984635404776782, 0.09071416512597352, 0.058427932162885554, 0.021518499524972867, 0.11165032177814282, 0.16321200382662937, 0.1653748596436344, 0.20735727797728032, 0.19521204609191045, 0.2255295356735587, 0.14619402325479314, 0.14278991060564294, 0.0841776846209541, 0.10646909940987825, 0.10004803029005416, 0.10828400671016425, 0.17027359834173694, 0.11219983018236235, 0.16653372324071825, 0.07988392244442366, 0.15750024234876037, 0.14771900314372033, 0.11842633786727674, 0.1520404251641594, 0.07080778290401213, 0.11730299345799722, 0.13608042063424364, 0.10057784951641224, 0.15688112791394815, 4.594975635409355, 29.036550410091877, 59.51263077557087, 55.73049612343311, 46.957644671201706, 51.88087709248066, 52.7654430270195, 44.53587882220745, 17.51247178763151, 2.264781310223043, 0.3048775903880596, 4.748082719743252, 10.013789813965559, 8.628649190068245, 14.242847934365273, 4.855171898379922, 7.654551509767771, 24.879278987646103, 43.38800221681595, 56.72045700252056, 57.60821096599102, 55.461022183299065, 56.53710924088955, 53.91118794679642, 54.18220080435276, 49.04388852417469, 53.898204043507576, 56.90244823694229, 57.97731935977936, 54.999438151717186, 51.012840270996094, 49.713416397571564, 40.92613331973553, 40.61788626015186, 41.01200491189957, 44.64123956859112, 53.40032435953617, 53.84604424238205, 53.68133068084717, 50.78825332224369, 52.25137621164322, 56.066876873373985, 51.19801193475723, 47.3263730853796, 42.11467534303665, 40.33262796700001, 37.977039366960526, 36.767336279153824, 37.82602407038212, 40.25299943983555, 39.9560833722353, 49.46724280714989, 55.22276356816292, 51.46866001188755, 53.487776666879654, 49.694132432341576, 52.50207915902138, 52.73281417787075, 50.06413757801056, 50.592503026127815, 52.535220980644226, 51.514147371053696, 53.15004698932171, 51.39650568366051, 39.82434444129467, 52.15733885765076, 55.354502499103546, 53.024596720933914, 51.84912599623203, 53.003545850515366, 53.657505959272385, 47.6259034126997, 48.06206300854683, 43.845220282673836, 40.12515909969807, 37.81221941113472, 39.37947951257229, 41.63645960390568, 40.470685958862305, 44.4339644908905, 53.166063129901886, 52.325187250971794, 54.04986150562763, 49.16034087538719, 54.82641823589802, 52.331764698028564, 51.38932406902313, 47.04194314777851, 41.51306502521038, 42.91313409805298, 40.32423421740532, 37.6792873442173, 41.5160858631134, 50.10880798101425, 57.662023678421974, 54.24492783844471, 53.934682086110115, 51.61570072174072, 50.29206074774265, 51.847165301442146, 51.95458933711052, 52.8703173995018, 56.921967789530754, 56.80398032069206, 54.09661039710045, 56.63601793348789, 55.25606118142605, 56.77805811166763, 56.723804622888565, 60.62424972653389, 47.82494433224201, 41.13382637500763, 18.96219279617071, 5.138393500819802, 7.960129212588072, 9.364245068281889, 9.756012596189976, 13.178671337664127, 10.328340735286474, 8.955980725586414, 1.2152744201011956, 0.6021140282973647, 2.4634990096092224, 29.384349547326565, 49.79267254471779, 46.484482660889626, 47.21942402422428, 52.719826474785805, 43.45397807657719, 11.9862250238657, 0.39010110951494426, 0.09751206715009175, 0.1931868289830163, 0.11574751129955985, 0.1765203443937935, 0.14614455169066787, 0.1735257636755705, 0.1498521730536595, 0.13678583200089633, 0.18912731087766588, 0.07022955338470638, 0.15650543791707605, 0.14706010959343985, 0.19829455646686256, 0.10720534701249562, 0.17441832984331995, 0.14882882562233135, 0.1565803651465103, 0.21177842980250716, 0.18885417084675282, 0.15827204624656588], [0.01977569001610391, 0.054937114400672726, 0.034835380356526, 0.011637717907433398, 0.04299655571230687, 0.023362211431958713, 0.01144576048318413, 0.06440551980631426, 0.07440905450494029, 0.027403190688346513, 0.11760459485230967, 0.04115699055546429, 0.06367417037836276, 0.04535116764600389, 0.06035015772795305, 0.014716781934112078, 0.0059365617198636755, 0.0414628964063013, 0.020747300477523822, 0.06986862470512278, 0.026008628410636447, 0.044606734154513106, 0.0319795886753127, 0.010736105887190206, 0.0396033711876953, 0.7759064307902008, 15.391069371253252, 36.24513790011406, 52.8987892717123, 38.6443405598402, 32.11562588810921, 28.427957966923714, 40.01764766871929, 22.84704353660345, 2.652105689048767, 1.5256199170835316, 1.7553571332246065, 2.3125939071178436, 3.7523053027689457, 2.3983253818005323, 8.061487823724747, 7.641477361321449, 19.095214158296585, 39.38109442591667, 47.50072292983532, 53.39349612593651, 54.11812484264374, 51.96199133992195, 48.50816287100315, 51.136702224612236, 52.305568903684616, 54.13228668272495, 50.00418819487095, 48.330822587013245, 46.634848192334175, 42.04297699034214, 36.75449676811695, 36.6206793487072, 35.21495997905731, 36.45421028137207, 42.417313903570175, 49.98358190059662, 50.440602377057076, 53.279323652386665, 47.81313456594944, 49.58362676203251, 49.89491365849972, 46.863204538822174, 43.202526569366455, 37.55219556391239, 38.436275124549866, 34.07665506005287, 35.331560522317886, 38.0282986164093, 37.414076775312424, 35.573884919285774, 42.56699547171593, 48.93730044364929, 49.442441537976265, 51.29003159701824, 49.68016818165779, 46.4456981420517, 47.349221259355545, 49.02064897119999, 46.88552834093571, 51.50709114968777, 45.20972706377506, 48.24727647006512, 38.899360075592995, 29.08339999616146, 52.86069631576538, 49.36701558530331, 50.76011963188648, 45.66149242222309, 46.81781217455864, 44.243818894028664, 43.89206796884537, 38.01567189395428, 39.224094450473785, 35.71418099105358, 34.400105103850365, 33.812972009181976, 34.22906868159771, 34.632151052355766, 40.889165103435516, 46.882404908537865, 47.98559591174126, 51.49310030043125, 47.80707009136677, 49.700383096933365, 49.26746852695942, 46.62559948861599, 45.56906618177891, 42.03716330230236, 37.49235637485981, 35.61811834573746, 35.57269178330898, 34.56527844071388, 39.33175027370453, 45.753911063075066, 48.864044174551964, 45.24271309375763, 52.16198980808258, 49.3185605853796, 49.21350382268429, 46.57481521368027, 50.0841549038887, 48.03653597831726, 48.22586461901665, 52.75733806192875, 54.22693960368633, 53.21181647479534, 55.15039265155792, 56.460391357541084, 53.87963064014912, 42.69051544368267, 28.049528673291206, 15.213116370141506, 2.760665863752365, 1.3375935377553105, 4.984810017049313, 3.2303227996453643, 4.520325791090727, 3.540835725143552, 0.38548667274881154, 1.0695645888336003, 0.2962666883831844, 3.9298963733017445, 23.56725689023733, 47.25891150534153, 39.61223982274532, 36.30957864224911, 45.80689162015915, 26.691036969423294, 5.097531443461776, 0.1046486927953083, 0.057624939508968964, 0.06711247377097607, 0.08505330013576895, 0.023243464092956856, 0.09039557597134262, 0.044663894368568435, 0.04913767930702306, 0.01197841842440539, 0.02981091627589194, 0.012202397665532771, 0.048979052662616596, 0.030446356104221195, 0.07583380735013634, 0.06262433569645509, 0.008685470220370917, 0.05057231755927205, 0.020695765742857475, 0.019646710316010285, 0.03433394456806127, 0.03910718238330446, 0.039006728984531946, 0.028675866342382506, 0.023307806441152934, 0.09367581675178371, 0.028027631888107862, 0.0019172222141605744, 0.023911118696560152, 0.03962185437558219, 0.06492552784038708, 0.034367263288004324, 0.0761255381803494, 0.05288680156809278, 0.0326146852603415, 0.016613541629340034, 0.060134482191642746, 0.03700785440742038, 0.09558174104313366, 0.030989821570983622, 0.01878550730907591, 0.016863005293998867, 0.02094072086038068, 0.05155718834430445, 0.057571541983634233, 0.031136119287111796, 0.0534134703775635, 1.3080725655891001, 20.49162782728672, 44.67498555779457, 56.176254004240036, 43.311181738972664, 36.230463087558746, 38.761058896780014, 42.7603404968977, 24.07755620777607, 2.916048550978303, 1.0123764700256288, 1.075632032006979, 3.096101889386773, 3.651552996598184, 4.403968434780836, 9.187891781330109, 8.395297061651945, 19.8126270622015, 41.59106723964214, 50.36563999950886, 54.689709171652794, 56.16514340043068, 54.283932745456696, 49.1120682656765, 51.14727705717087, 52.85455584526062, 56.50511875748634, 50.685860216617584, 52.049238458275795, 49.5000958442688, 44.54919710755348, 38.454023972153664, 38.07506650686264, 38.33115376532078, 38.22734333574772, 43.79917815327644, 51.084865406155586, 52.20716558396816, 54.8721069842577, 48.89187388122082, 51.13674022257328, 52.906183674931526, 50.016028359532356, 44.87458884716034, 38.4164933860302, 39.044314697384834, 36.65740057826042, 36.51874981820583, 39.287995621562004, 40.11739231646061, 38.18385846912861, 45.51485449075699, 50.27248799800873, 50.85836336016655, 52.39011436700821, 49.89482246339321, 47.8184998780489, 50.1163087785244, 51.09441049396992, 48.32595884799957, 53.65574285387993, 47.442844435572624, 50.17934359610081, 41.1542958766222, 34.31971661746502, 53.57547216117382, 51.2317731231451, 51.94777250289917, 49.51228179037571, 48.22816349565983, 47.613071501255035, 45.148930326104164, 41.93724386394024, 39.80063371360302, 37.45211273431778, 36.570503041148186, 36.004265025258064, 36.31081737577915, 36.87680460512638, 43.009078949689865, 48.79600502550602, 51.36740304529667, 50.069742277264595, 47.65048049390316, 51.21708311140537, 50.588353648781776, 48.114386200904846, 46.49023935198784, 43.83409067988396, 39.51118804514408, 37.19913370907307, 37.32728563249111, 35.172318667173386, 42.53506198525429, 50.09898170828819, 50.78841291368008, 47.03225366771221, 51.914034113287926, 50.50878591835499, 49.731845408678055, 48.042414262890816, 49.815684109926224, 50.0213822722435, 51.60171367228031, 53.356911689043045, 55.91282173991203, 54.04583752155304, 55.81901617348194, 56.429350823163986, 55.88550880551338, 43.62961605191231, 31.239178217947483, 16.54302030801773, 3.1644929945468903, 3.358168127015233, 5.325394291430712, 7.4607666581869125, 7.8116346057504416, 7.348794266581535, 2.7013607835397124, 0.46474742121063173, 0.3551022266037762, 4.376788018271327, 26.500083915889263, 51.63788013160229, 44.21849325299263, 41.56395569443703, 50.892994701862335, 31.52507107704878, 6.349143907427788, 0.10879401801503263, 0.038443646699306555, 0.05664541960868519, 0.03263077873270959, 0.04778141184942797, 0.04877455758105498, 0.02272514258947922, 0.07330856824410148, 0.054032903935876675, 0.021639875922119245, 0.051729032638831995, 0.041853529546642676, 0.031381365697598085, 0.09452848506043665, 0.01608091151865665, 0.047644882652093656, 0.03414191014599055, 0.010612066107569262, 0.03718431857123505, 0.0318382986006327, 0.050846366721089, 0.10201565673924051, 0.10722107312176377, 0.12581231771036983, 0.18386640411335975, 0.05928316088102292, 0.1396157153067179, 0.11833503886009566, 0.1773907055030577, 0.10892704798607156, 0.10568284589680843, 0.1989413530100137, 0.22841059748316184, 0.21545836905715987, 0.16775503114331514, 0.1439482398563996, 0.13983653392642736, 0.10666231013601646, 0.17803966911742464, 0.1274350384483114, 0.12932209734572098, 0.1293969206744805, 0.12311387617955916, 0.17745202174410224, 0.11484345668577589, 0.1443376744282432, 1.440457224380225, 22.578534744679928, 50.2644058316946, 65.85248038172722, 49.0738271176815, 43.048748821020126, 40.290967002511024, 50.56558147072792, 28.320874013006687, 3.9440073911100626, 2.1132107684388757, 3.7468027230352163, 6.681970423087478, 8.357421644032001, 7.300956733524799, 13.009846396744251, 11.345220319926739, 21.37644074857235, 43.062355890870094, 51.238635554909706, 55.23988164961338, 56.61520265042782, 53.36492545902729, 50.21673358976841, 51.65485382080078, 55.677572563290596, 57.48526096343994, 54.02884483337402, 54.68288853764534, 52.44887441396713, 44.93724748492241, 40.52533082664013, 41.3131957501173, 39.285913333296776, 40.13763003051281, 46.8990708142519, 52.30972968041897, 53.907635137438774, 54.80905696749687, 49.02550891041756, 51.91164404153824, 54.80044282972813, 50.64281612634659, 46.7511485517025, 40.30557341873646, 41.644587367773056, 38.83675083518028, 39.56565052270889, 41.95523589849472, 41.73813834786415, 38.73381815850735, 46.92731849849224, 54.211599826812744, 53.417161256074905, 53.49858708679676, 51.420041620731354, 48.70561167597771, 49.95283395051956, 51.91409111022949, 49.995403066277504, 55.65161615610123, 50.585515201091766, 50.80236956477165, 46.8308986723423, 38.44985939562321, 54.233338460326195, 54.81970399618149, 55.35984121263027, 52.291357666254044, 51.08295790851116, 48.33709605038166, 47.019668743014336, 43.27818810939789, 42.00742989778519, 37.92758122086525, 39.095372557640076, 37.965222001075745, 37.7827899903059, 39.48508344590664, 44.24903601408005, 51.63295939564705, 53.21509949862957, 52.639194801449776, 49.86111827194691, 51.330062448978424, 54.13796737790108, 49.42639499902725, 47.61725887656212, 47.192012295126915, 40.381041169166565, 39.828592613339424, 39.343829825520515, 37.341884449124336, 44.477608948946, 51.49025045335293, 52.95891344547272, 47.51016162335873, 54.620302096009254, 52.80745357275009, 51.6270013153553, 48.808297365903854, 52.90288545191288, 51.60017095506191, 54.06100630760193, 54.16138552129269, 56.043990701437, 55.5737317353487, 58.1341977417469, 58.27070161700249, 57.00490213930607, 47.205106392502785, 32.8166388720274, 17.77809463441372, 4.737389143556356, 4.893285753205419, 10.29752628877759, 12.050309535115957, 13.207778725773096, 10.555373802781105, 3.724838951602578, 1.5938040520995855, 0.5797893949784338, 5.432284455746412, 30.644145347177982, 58.39061178267002, 51.941955015063286, 50.038238167762756, 59.69817101955414, 36.67242117226124, 7.37823698669672, 0.1896282160305418, 0.15590466937283054, 0.17695285321678966, 0.15880049992119893, 0.14396191021660343, 0.0953175216272939, 0.0897689806879498, 0.1682765086297877, 0.08822799267363735, 0.1653587253531441, 0.21179104631301016, 0.2149991280748509, 0.13193604536354542, 0.12595046107890084, 0.11268209258560091, 0.13451980281388387, 0.15488329605432227, 0.19258657994214445, 0.1157778428751044, 0.12905455310828984, 0.13012548704864457], [0.04270238692697603, 0.045218171071610413, 0.0638674627407454, 0.02365702217502985, 0.024355357163585722, 0.023294434795388952, 0.08735131588764489, 0.10096027079271153, 0.055477472124039195, 0.043242852261755615, 0.039051205894793384, 0.017528435309941415, 0.04028552364616189, 0.06331516386126168, 0.027793962981377263, 0.028149357094662264, 0.04072265233844519, 0.05434496590169147, 0.037486936707864515, 0.022215912395040505, 0.04857106068811845, 0.04318158797104843, 0.06879182037664577, 0.06672235642326996, 0.04612310884112958, 0.3079783427529037, 5.357252256944776, 32.30430096387863, 47.317234575748444, 41.070324182510376, 40.27922563254833, 43.7336278706789, 53.40465232729912, 26.63424141705036, 4.462222158908844, 1.1852732487022877, 3.0390429636463523, 2.4808773770928383, 4.5499171782284975, 2.0989451464265585, 5.3706826362758875, 16.194717697799206, 24.150132313370705, 33.99953059852123, 49.64855007827282, 56.4134980738163, 53.939553424715996, 48.92103351652622, 53.78886491060257, 53.71162265539169, 51.200337409973145, 49.81529653072357, 48.07487592101097, 45.4463479667902, 40.587719678878784, 37.562736198306084, 36.63931354880333, 38.51671300828457, 38.27507637441158, 36.840071976184845, 43.73442582786083, 49.00103062391281, 51.258048713207245, 52.125188782811165, 48.037071749567986, 49.21346202492714, 49.863363951444626, 48.19811090826988, 42.402684688568115, 37.08602137863636, 38.26897390186787, 35.967452600598335, 37.44500331580639, 34.60377037525177, 35.228863433003426, 33.824770376086235, 37.46041148900986, 46.61328814923763, 49.856930896639824, 50.3514439612627, 52.36002758145332, 46.372525468468666, 46.05001397430897, 47.329523116350174, 49.83568623661995, 50.376176834106445, 50.63447177410126, 37.84411869943142, 38.76888647675514, 34.041833728551865, 48.506699949502945, 49.95441846549511, 48.35098810493946, 45.58230087161064, 41.49365186691284, 38.94604817032814, 40.21177925169468, 33.752927631139755, 34.07059818506241, 36.589908599853516, 36.418541595339775, 34.956224262714386, 36.082890406250954, 34.427562430500984, 40.080883875489235, 48.58466796576977, 48.89087833464146, 49.031003415584564, 50.00502794981003, 48.861498311161995, 50.77816866338253, 47.866878882050514, 47.523707896471024, 44.625895991921425, 43.212577030062675, 36.41715846955776, 34.27969716489315, 35.23348778486252, 35.13402432203293, 39.897547513246536, 44.42585572600365, 47.417788580060005, 47.61285871267319, 49.89717833697796, 49.79923099279404, 48.22034351527691, 48.5699475556612, 43.24385315179825, 48.18082943558693, 51.13305062055588, 49.66836221516132, 53.95476780831814, 53.889183327555656, 54.565163254737854, 50.80012388527393, 38.52996289730072, 24.33562695980072, 8.482458684593439, 4.576146695762873, 1.477871323004365, 2.996176751330495, 4.883298464119434, 5.762470588088036, 6.712678475305438, 0.27233714587055147, 0.30413280066568404, 0.21468528866535053, 6.409138888120651, 22.207784838974476, 42.41813085973263, 43.94494213163853, 40.26342988014221, 43.82302947342396, 22.15035282075405, 2.4924757797271013, 0.03128781798295677, 0.07601769670145586, 0.07108712728950195, 0.04899152816506103, 0.07577661745017394, 0.019005941867362708, 0.046993243595352396, 0.05453062527521979, 0.13896836957428604, 0.05000874545658007, 0.017597601618035696, 0.006823066396464128, 0.02586207465355983, 0.06252428676816635, 0.0494492885627551, 0.017808779739425518, 0.037374312087194994, 0.043745683287852444, 0.040617233971715905, 0.02957829194201622, 0.022952861327212304, 0.047459375418839045, 0.05259744561044499, 0.061434316739905626, 0.016267435494228266, 0.006901535061842878, 0.024517811434634496, 0.033518034833832644, 0.03372413295437582, 0.07656397676328197, 0.011344918384565972, 0.027944181092607323, 0.008041260989557486, 0.04984882005373947, 0.0433771958341822, 0.03571400528016966, 0.04022896086098626, 0.015781056026753504, 0.0329586595762521, 0.04384687512356322, 0.05619490999379195, 0.046293483683257364, 0.09128196747042239, 0.030088633502600715, 0.032308779409504496, 0.012985504472453613, 0.3417144762352109, 8.02302248775959, 38.57195824384689, 57.627886310219765, 46.93273700773716, 43.266051560640335, 41.99736423790455, 51.9580053538084, 28.200116492807865, 4.83876627869904, 2.0165368309244514, 2.571584447287023, 2.2342133754864335, 4.651798736304045, 3.5162158962339163, 7.387940715998411, 19.193870164453983, 25.264245830476284, 36.93844109773636, 50.34362018108368, 56.49686940014362, 54.07662346959114, 50.7891196757555, 55.467607229948044, 56.67312674224377, 53.144153505563736, 51.99706345796585, 49.45325195789337, 47.29646109044552, 44.28399793803692, 39.982860535383224, 39.4329996407032, 40.82668885588646, 40.77413767576218, 38.897653967142105, 44.144879803061485, 52.40779101848602, 52.360844537615776, 52.718428149819374, 49.274916127324104, 50.75143709778786, 51.4037898927927, 50.10305128991604, 43.07355768978596, 39.91100259125233, 40.001433938741684, 37.73291766643524, 38.80322143435478, 35.48100270330906, 37.49100744724274, 36.974504962563515, 39.63522858917713, 48.789997547864914, 50.657836720347404, 52.38167501986027, 52.01428033411503, 47.00536631047726, 46.12922452390194, 47.31025815010071, 50.225123539566994, 51.78436987102032, 50.34930847585201, 41.493499875068665, 42.85462483763695, 36.777645125985146, 52.78831399977207, 52.23847210407257, 49.84624586999416, 47.7249488979578, 44.025288820266724, 41.96938253939152, 42.0467995852232, 35.77934369444847, 36.640271097421646, 38.45298282802105, 37.82106153666973, 37.267503440380096, 37.716000974178314, 35.38844347000122, 41.947951689362526, 50.837992653250694, 51.86939790844917, 52.13630698621273, 48.93555633723736, 50.317572578787804, 53.90698917210102, 50.544678792357445, 48.77230949699879, 46.220408231019974, 43.99386830627918, 37.317185774445534, 34.60342839360237, 36.87807373702526, 36.901959255337715, 42.37896256148815, 45.86209125816822, 49.29517284035683, 49.174723103642464, 51.95524290204048, 49.93383876979351, 50.77596478164196, 49.871012941002846, 47.80699409544468, 50.254632756114006, 52.47115261852741, 50.762198120355606, 54.70507934689522, 55.021948143839836, 56.720734387636185, 52.69912898540497, 42.58516989648342, 25.25061596184969, 11.140758041292429, 4.110939558595419, 3.0807390762493014, 6.639414131641388, 8.60249899327755, 8.079420011490583, 5.272474531084299, 1.868153011891991, 0.2750005357665941, 0.27005762443877757, 7.328522829338908, 27.091575376689434, 47.81514085829258, 51.79060533642769, 43.77023130655289, 49.52019676566124, 27.111512906849384, 3.232742794789374, 0.027854520376422442, 0.027198905263503548, 0.06854062565253116, 0.03805053849646356, 0.02536742580559803, 0.05889716987439897, 0.02709947046241723, 0.04376860451884568, 0.08249824895756319, 0.06304980153799988, 0.0254655878234189, 0.01423269199221977, 0.054834130278322846, 0.027174195456609596, 0.037168117487453856, 0.004691432732215617, 0.033626711228862405, 0.04138658878218848, 0.0416791248426307, 0.02853648729796987, 0.03265325096435845, 0.16864623175933957, 0.16625976684736088, 0.18591580039355904, 0.04831239995837677, 0.1341383982799016, 0.061222518925205804, 0.1256413120427169, 0.13097199553158134, 0.11899974342668429, 0.13485991425113752, 0.13263231347082183, 0.07208484094007872, 0.1590581884374842, 0.32745013071689755, 0.10963231834466569, 0.06525445511215366, 0.15641958627384156, 0.1918041188037023, 0.11683457210892811, 0.17772618593880907, 0.13844144472386688, 0.1373749488266185, 0.10678585545974784, 0.11224306770600379, 0.09342745703179389, 0.46889994526281953, 8.797184396535158, 44.59027670323849, 61.38665221631527, 54.04870256781578, 50.43321177363396, 55.327326357364655, 62.78037942945957, 32.66530439257622, 6.698463913053274, 2.4247641256079078, 4.355545258149505, 6.0679057985544205, 11.754117328673601, 7.477597380056977, 9.614785574376583, 22.92728193104267, 34.06739495694637, 42.75813281536102, 55.542976185679436, 58.41832749545574, 55.57022072374821, 49.73123364150524, 59.54502783715725, 58.90646070241928, 55.7917982339859, 54.22893829643726, 52.51252479851246, 49.62765119969845, 44.72436770796776, 42.08130933344364, 41.872738525271416, 41.630471125245094, 42.47571296989918, 40.88450275361538, 47.112296372652054, 53.53814296424389, 55.814372822642326, 54.04478117823601, 48.583208844065666, 51.752527579665184, 55.297741144895554, 50.37266202270985, 46.07762709259987, 41.46676830947399, 43.000202625989914, 39.532105922698975, 41.274935603141785, 37.971799448132515, 38.115887716412544, 36.85972072184086, 41.81136801838875, 50.57677946984768, 52.701887637376785, 54.73989687860012, 54.84946019947529, 46.840660348534584, 46.79058663547039, 47.62943722307682, 53.25272887945175, 52.73630619049072, 52.28035345673561, 45.82907482981682, 42.61623702943325, 42.20293700695038, 54.76299203932285, 55.41485086083412, 51.14656649529934, 50.16154155135155, 44.8448022454977, 44.17803682386875, 43.066756054759026, 36.5853488445282, 37.64847859740257, 40.25823935866356, 39.5547679066658, 38.75569358468056, 39.923306331038475, 37.17237174510956, 44.14467841386795, 52.486974969506264, 54.992302134633064, 53.693212643265724, 49.93442013859749, 50.23441404104233, 55.15433683991432, 52.848274782299995, 52.26378634572029, 49.226757511496544, 46.7588659375906, 39.272853434085846, 36.55960522592068, 38.70156928896904, 38.72515842318535, 44.30408366024494, 46.94849096238613, 52.901080548763275, 53.67487482726574, 54.44029055535793, 52.21775561571121, 51.473132371902466, 52.24463537335396, 48.0750697106123, 50.486066937446594, 52.53223434090614, 51.370735466480255, 54.72867988049984, 56.47743724286556, 57.570611983537674, 55.071991458535194, 43.716213405132294, 28.10655601322651, 11.0620984621346, 6.935101440176368, 5.331707177683711, 8.946913462132215, 13.751999773085117, 13.329437747597694, 14.29822901263833, 3.6632174206897616, 0.805735127069056, 0.49744333082344383, 8.567411676049232, 30.98692875355482, 55.11039599776268, 56.36209823191166, 50.013771280646324, 57.8902318328619, 32.41055466234684, 4.185718121007085, 0.1315003601484932, 0.17726007266901433, 0.15947589883580804, 0.1697893618256785, 0.26099929644260556, 0.15564508095849305, 0.06664069791440852, 0.12753264571074396, 0.23568821634398773, 0.18765852641081437, 0.10335304395994172, 0.11283435160294175, 0.120093876903411, 0.1353928801836446, 0.21875525620998815, 0.180031638010405, 0.11311842346913181, 0.20224822947056964, 0.1036560331704095, 0.12490997003624216, 0.10444096566061489], [0.05691519399988465, 0.032394868539995514, 0.013026695523876697, 0.04923354252241552, 0.03649069622042589, 0.017974323200178333, 0.02211818082287209, 0.021955871270620264, 0.07311405875952914, 0.09614617403713055, 0.027198146417504176, 0.02103640596033074, 0.029899257824581582, 0.023848258788348176, 0.04240272624883801, 0.03805660926445853, 0.019707369756361004, 0.04491778679948766, 0.03920203627785668, 0.05998100976285059, 0.05201388747082092, 0.04729711225081701, 0.06665220862487331, 0.024286738189402968, 0.009592210481059738, 0.03599841111281421, 2.483658352866769, 21.335779130458832, 42.75259651243687, 39.661230593919754, 41.800595596432686, 69.24319043755531, 57.904188483953476, 30.476663634181023, 7.6948340982198715, 1.701421996112913, 2.416539704427123, 1.9232884095981717, 1.4293873496353626, 2.891428959555924, 11.18319796398282, 18.540791608393192, 21.657815650105476, 41.104624941945076, 44.0130040794611, 48.955843448638916, 47.748431637883186, 54.4731055945158, 53.35312709212303, 50.57111777365208, 48.07602345943451, 48.78820404410362, 42.18797340989113, 36.86920501291752, 38.25740732252598, 38.169081062078476, 39.04207281768322, 36.75209529697895, 36.579025983810425, 35.73942683637142, 39.272097274661064, 46.873418390750885, 50.17193019390106, 50.27451328933239, 48.233202025294304, 51.21207498013973, 51.139472275972366, 47.12175026535988, 43.39752830564976, 38.36443617939949, 38.10492530465126, 39.05318722128868, 35.01941107213497, 34.13141772150993, 36.73288352787495, 34.43313293159008, 35.55859073996544, 42.89156265556812, 46.6265532374382, 47.91870430111885, 50.73930814862251, 50.16612410545349, 49.057510793209076, 51.04206830263138, 49.02938470244408, 50.431931242346764, 48.67228366434574, 52.37249471247196, 51.240554451942444, 37.27971598505974, 47.629631012678146, 48.61687123775482, 47.55354389548302, 43.65880608558655, 37.00284384191036, 35.94175457954407, 35.46238370239735, 35.03584139049053, 35.64761236310005, 35.2009729295969, 34.392722100019455, 35.974527820944786, 35.46483837068081, 35.22923581302166, 36.515474393963814, 43.39429847896099, 50.5107656121254, 49.786889255046844, 49.36210624873638, 48.59506040811539, 51.03583663702011, 50.959677323699, 49.42627340555191, 47.292281314730644, 48.47261197865009, 43.31171751022339, 35.37079721689224, 34.529822543263435, 35.420373156666756, 34.65144261717796, 36.7487058788538, 40.04364587366581, 43.12563009560108, 46.38294830918312, 44.873521104454994, 47.47868791222572, 48.1537064909935, 53.37650343775749, 50.40005475282669, 46.63444921374321, 54.94469068944454, 49.31089639663696, 55.11263407766819, 54.311466068029404, 44.201568961143494, 32.89610780775547, 16.736903004348278, 2.478450732305646, 1.6831889119930565, 2.415422801859677, 4.291029470041394, 7.028219243511558, 7.528144167736173, 4.837210737168789, 3.2645475631579757, 0.2826088259462267, 0.43574532901402563, 9.394507594406605, 30.162538290023804, 35.46672686934471, 38.61360780894756, 50.32067321240902, 43.46020594239235, 14.974287785589695, 0.9442848956678063, 0.07748641437501647, 0.03323394812468905, 0.016719214181648567, 0.07743767753709108, 0.007744126860416145, 0.027275138672848698, 0.015452623210876482, 0.04994381124561187, 0.02149544656276703, 0.08053093421040103, 0.02697487685509259, 0.056044383891276084, 0.021301536362443585, 0.016908205798245035, 0.06542382063344121, 0.05945121651166119, 0.07409929690766148, 0.06366971749230288, 0.03355207714776043, 0.06263010218390264, 0.04753340093884617, 0.0498633327515563, 0.02983342004881706, 0.06647131755016744, 0.06321127802948467, 0.024134293635142967, 0.02898577236919664, 0.027293530947645195, 0.07487116759875789, 0.030374332527571823, 0.03544937768310774, 0.0162603015996865, 0.06285295428824611, 0.08601241468568332, 0.0662102596834302, 0.04767301747051533, 0.037759256665594876, 0.030860105289320927, 0.01808792003430426, 0.053021178537164815, 0.06792666172259487, 0.03319536757771857, 0.03471087395155337, 0.02020015581365442, 0.06132731017714832, 0.03448937997745816, 0.04541291062196251, 3.8027996057644486, 29.32690992951393, 48.81297491490841, 44.873718693852425, 45.61268784105778, 65.62272191047668, 63.20507884025574, 34.94679316878319, 8.590399492532015, 2.002366678789258, 2.9240922443568707, 2.7322552632540464, 3.460773308761418, 4.4062459375709295, 14.132411610335112, 24.19639103114605, 28.838641829788685, 43.66878055036068, 47.8305908292532, 54.15767312049866, 51.45958609879017, 55.957438945770264, 55.916477143764496, 52.78801381587982, 52.10484467446804, 52.23157547414303, 45.86105391383171, 39.675422832369804, 40.426437333226204, 40.78901007771492, 42.2153053432703, 38.099252209067345, 38.35289239883423, 39.12221811711788, 43.130452036857605, 48.63401971757412, 52.57400169968605, 52.252436354756355, 48.80040518939495, 51.39353804290295, 52.29492947459221, 48.44151824712753, 44.24536921083927, 39.89289276301861, 40.32484598457813, 39.71960686147213, 37.64525257050991, 36.568804532289505, 37.55946457386017, 35.963215827941895, 36.62083514034748, 44.83500637114048, 49.2418996989727, 49.40736182034016, 52.55566768348217, 51.22558705508709, 51.19366876780987, 51.79475851356983, 49.471639171242714, 52.26380154490471, 49.301396906375885, 51.54953867197037, 51.42429359257221, 40.79801559448242, 49.077319130301476, 50.42686991393566, 49.68388058245182, 44.783629328012466, 38.62305790185928, 37.67022863030434, 37.827186807990074, 36.42179422080517, 36.1042832583189, 36.082214042544365, 36.54741548001766, 37.31413073837757, 37.76465356349945, 37.24737972021103, 39.78769160807133, 46.15977868437767, 51.77426241338253, 52.56002224981785, 50.88015519082546, 49.95470345020294, 52.71643325686455, 52.11237587034702, 51.23442158102989, 49.171774461865425, 50.16946032643318, 43.39248597621918, 36.241163313388824, 36.823615059256554, 37.82118313014507, 37.24418789148331, 39.012354612350464, 43.05599503219128, 45.38988299667835, 48.50335992872715, 49.410679042339325, 50.02557344734669, 51.02062605321407, 54.30835023522377, 50.798246785998344, 48.6992584168911, 55.08410520851612, 49.86283577978611, 55.47877483069897, 53.694439977407455, 48.3808659017086, 34.549604281783104, 19.108445048332214, 4.538514940068126, 2.554371845908463, 2.847962616942823, 5.841485448181629, 7.7460202015936375, 7.526080878451467, 4.077958753332496, 2.071192623116076, 0.06456294417148456, 0.576796461828053, 9.564090594649315, 34.458853751420975, 40.811987444758415, 45.38901284337044, 54.963636472821236, 48.39623987674713, 19.058861508965492, 1.245401103515178, 0.06997525648330338, 0.03924064651073422, 0.050054673265549354, 0.07791571712004952, 0.05051359512435738, 0.03584759557270445, 0.05058005444880109, 0.03916796798876021, 0.018088270699081477, 0.04298265899706166, 0.030377455113921314, 0.050708998896880075, 0.03792862960835919, 0.011405999921407783, 0.01098080867450335, 0.07168356169131584, 0.0768554923706688, 0.046728667948627844, 0.046996557284728624, 0.051205989220761694, 0.03293194968136959, 0.1287720471736975, 0.11613562484853901, 0.20767947396961972, 0.14966898132115602, 0.16652886959491298, 0.1743429127964191, 0.10122575185960159, 0.2170116247725673, 0.16672274825396016, 0.11482143716420978, 0.0984001655888278, 0.1724830610328354, 0.13524725596653298, 0.09055957576492801, 0.20441596861928701, 0.14538399875164032, 0.15603435225784779, 0.11770514101954177, 0.15809134813025594, 0.15579852741211653, 0.1914528603083454, 0.16553580178879201, 0.10926301081781276, 0.18526244326494634, 0.10195118637057021, 0.14414818928344175, 4.605460222810507, 32.644481509923935, 57.56213843822479, 51.57826133072376, 52.481951639056206, 73.92447844147682, 65.2170404791832, 36.974512562155724, 10.389204919338226, 3.023581593297422, 3.3677417133003473, 5.707854218780994, 6.451809173449874, 8.36229583248496, 20.02101168036461, 34.09646339714527, 32.4894118309021, 46.99203662574291, 48.442772179841995, 56.06141276657581, 52.15621791779995, 56.42488606274128, 57.58879400789738, 54.359951466321945, 54.158049300312996, 53.47755901515484, 46.067040860652924, 39.795887768268585, 42.047730535268784, 41.635745242238045, 43.05451311171055, 39.33493450284004, 39.186062291264534, 40.233403891325, 44.90189038217068, 49.92900162935257, 53.77547062933445, 53.03158074617386, 49.43291924893856, 52.617095187306404, 53.887887597084045, 51.16464592516422, 47.41072475910187, 41.659429371356964, 43.842115849256516, 41.10428296029568, 39.88417603075504, 38.41069869697094, 41.47610440850258, 38.10948126018047, 39.61906045675278, 46.9084183126688, 51.38746976852417, 51.22766554355621, 55.14607608318329, 53.93967501819134, 51.48492693901062, 55.05378283560276, 51.68087102472782, 53.627373576164246, 49.95874643325806, 55.95913365483284, 50.22447757422924, 44.46773327887058, 52.88507200777531, 52.314684614539146, 52.04937905073166, 48.065669015049934, 39.10178281366825, 39.57162760198116, 38.54734316468239, 38.36376741528511, 38.18795844912529, 38.23887951672077, 37.701029777526855, 38.549159467220306, 39.302222058176994, 39.428493082523346, 41.52796022593975, 46.87837712466717, 54.130572974681854, 55.39640665054321, 53.63678567111492, 52.69557237625122, 53.296757116913795, 53.63427020609379, 53.366593569517136, 51.44626401364803, 52.52005219459534, 47.62464188039303, 38.9704504609108, 37.419214099645615, 39.63335528969765, 39.16014768183231, 41.021694391965866, 44.289636835455894, 46.11337557435036, 51.478680074214935, 51.61086358129978, 52.20567986369133, 52.99538768827915, 55.12493021786213, 52.71644465625286, 48.18077623844147, 55.394651144742966, 50.26736967265606, 55.346560925245285, 56.57914258539677, 47.75811731815338, 35.25590658187866, 19.33345567435026, 4.170593032613397, 3.495225110091269, 6.0266343131661415, 10.583160761743784, 17.83616501837969, 15.060174576938152, 10.772286113351583, 5.925601534545422, 0.8082074287813157, 0.9353359008673579, 11.57753985375166, 40.65920904278755, 47.46788889169693, 52.1401409804821, 60.070049464702606, 55.37767745554447, 21.733976863324642, 1.6084798146039248, 0.18311836378416047, 0.21523593255551532, 0.07150721256039105, 0.13258805178338662, 0.12309141136938706, 0.08497573086060584, 0.17689365951810032, 0.2282792521873489, 0.13433321204502136, 0.10496887014596723, 0.16156992787728086, 0.12295125678065233, 0.11209796299226582, 0.198578012350481, 0.1655923979706131, 0.1709409969043918, 0.16301530500641093, 0.13941186218289658, 0.24528301320970058, 0.13148762489436194, 0.11372788256267086], [0.0322380453144433, 0.03610864601796493, 0.022327093538478948, 0.03610710606153589, 0.052921753012924455, 0.024480110332660843, 0.05412998056272045, 0.026805810048244894, 0.054500609112437814, 0.04264456620148849, 0.06659482576651499, 0.04148124600760639, 0.008992123784992145, 0.04873029960435815, 0.005921474785282044, 0.027715456744772382, 0.0456370874599088, 0.039278629628825, 0.09048521256772801, 0.03890415304340422, 0.028536516983876936, 0.04062091131345369, 0.05354701614123769, 0.026468181094969623, 0.05579332275374327, 0.034878346996265464, 1.3191411341540515, 14.781932607293129, 42.56327547132969, 45.822941958904266, 55.24422861635685, 58.604042530059814, 39.99590903520584, 26.159734278917313, 14.44922436028719, 1.2251092423684895, 0.7305195881053805, 1.5478141698986292, 1.5340134291909635, 6.619758261367679, 15.406185910105705, 8.24664143845439, 8.752270806580782, 21.590241976082325, 34.16389837861061, 50.684214904904366, 57.1580795198679, 55.77179230749607, 51.632492020726204, 48.77537973225117, 47.95963950455189, 42.922451198101044, 40.211099088191986, 42.176042050123215, 38.75603936612606, 37.154619097709656, 37.45163016021252, 39.28874798119068, 39.62880693376064, 38.26890930533409, 38.535567596554756, 44.31112848222256, 48.47296915948391, 50.4786117374897, 50.640258863568306, 49.43570829927921, 51.26204989850521, 47.275072038173676, 46.89291134476662, 47.352318093180656, 45.02426661550999, 40.298669189214706, 35.65557673573494, 33.99129644036293, 37.3829298466444, 36.17240980267525, 34.05847303569317, 37.925031557679176, 43.864135667681694, 47.071984335780144, 48.54372136294842, 50.84678538143635, 48.961896523833275, 50.18130049109459, 48.426547050476074, 46.46063134074211, 49.48781110346317, 46.346705853939056, 51.823959946632385, 33.926813900470734, 46.909220069646835, 48.10078673064709, 45.87216831743717, 45.35114787518978, 40.657324343919754, 35.68678446114063, 35.51952123641968, 35.26077792048454, 36.44236631691456, 34.87765587866306, 36.95474982261658, 35.30265547335148, 33.47969949245453, 37.242272794246674, 36.07864983379841, 37.52657733857632, 42.75369465351105, 45.7351590692997, 49.65952768921852, 48.35460551083088, 47.64578774571419, 48.62832002341747, 49.76290114223957, 51.43575757741928, 49.326213374733925, 47.03287683427334, 39.47391964495182, 34.075800105929375, 34.905439987778664, 36.00720226764679, 36.42416149377823, 34.218843430280685, 38.64824675023556, 40.6232325732708, 42.44763247668743, 44.15011212229729, 48.05104359984398, 48.71662728488445, 54.02146562933922, 47.21731133759022, 46.95260614156723, 58.297273591160774, 49.19234275817871, 50.562404841184616, 44.16741259396076, 24.35329981148243, 11.062044315040112, 2.443232797086239, 0.6572541757486761, 2.4228837015107274, 3.733773222193122, 5.139295952394605, 5.661941757425666, 3.164593926630914, 1.0147364996373653, 0.13743046147283167, 1.025004261173308, 11.040162239223719, 29.285794235765934, 34.18754830956459, 38.557845801115036, 47.46633477509022, 30.35299737006426, 9.651084076613188, 0.42686386965215206, 0.017510132092866115, 0.048537715993006714, 0.05964421943644993, 0.03576592222088948, 0.010361362128605833, 0.08924641224439256, 0.04715556984592695, 0.018815679322869983, 0.06269255391089246, 0.018100133929692674, 0.00945127385421074, 0.07113481769920327, 0.06626065893215127, 0.06834371160948649, 0.04680157653638162, 0.0376430140750017, 0.03408647171454504, 0.04073134288773872, 0.007910773801995674, 0.015531179542449536, 0.04713981776149012, 0.03940898415748961, 0.03388643322978169, 0.013938932315795682, 0.07185519076301716, 0.023504742748627905, 0.0214562351902714, 0.04151592656853609, 0.02507305849576369, 0.020488719528657384, 0.05900914882658981, 0.038144887730595656, 0.03155026366584934, 0.010401057752460474, 0.016870436047611292, 0.10619714681524783, 0.05958982743322849, 0.07618389325216413, 0.04981504491297528, 0.11162951937876642, 0.028950676205568016, 0.027493279994814657, 0.01110461467760615, 0.10867438380955718, 0.034903309133369476, 0.02929573591245571, 0.05376101813453715, 1.7036362085491419, 18.948087953031063, 49.21769879758358, 49.65864613652229, 56.3283484429121, 65.6456270813942, 51.652216762304306, 32.82328471541405, 13.690014649182558, 1.850690336432308, 0.7746078504715115, 1.805617748759687, 3.6643585469573736, 6.91193075850606, 21.745564341545105, 10.869625490158796, 10.847771912813187, 27.819154635071754, 38.63690435886383, 53.57833720743656, 55.28791107237339, 56.535570323467255, 53.03671047091484, 52.72408224642277, 50.30285596847534, 45.83367258310318, 42.36889310181141, 43.426543548703194, 39.982457756996155, 39.153889417648315, 39.16309252381325, 39.83127146959305, 41.19238883256912, 39.05404977500439, 40.96827305853367, 44.975085854530334, 50.02148486673832, 52.74056576192379, 50.91833174228668, 52.28040285408497, 51.67942330241203, 49.78667266666889, 48.59338089823723, 48.10843952000141, 46.00337527692318, 41.30709707736969, 38.1867653131485, 37.014114037156105, 39.41403105854988, 38.490992188453674, 35.45682840049267, 39.80967342853546, 46.16119600832462, 50.70895157754421, 50.58437906205654, 51.22777573764324, 51.36047221720219, 50.98412521183491, 51.8263766169548, 49.62113834917545, 50.03689303994179, 49.20308858156204, 51.96530096232891, 37.25347459316254, 50.57655908167362, 49.072208404541016, 48.46654750406742, 48.139183670282364, 42.13374651968479, 38.41848447918892, 37.62191042304039, 37.75038152933121, 37.67258830368519, 35.97372226417065, 37.81624719500542, 37.88490191102028, 34.966951087117195, 38.26727919280529, 38.821266666054726, 40.12628383934498, 45.58024898171425, 49.67856086790562, 51.797049790620804, 51.11135758459568, 50.10951094329357, 50.64380407333374, 51.84088043868542, 52.99284562468529, 51.02818004786968, 48.850034326314926, 41.519406884908676, 35.10897606611252, 36.219743862748146, 37.50643461942673, 37.99271732568741, 37.04165875911713, 40.12306921184063, 42.82253935933113, 44.68844063580036, 46.73310711979866, 50.46129606664181, 49.60468143224716, 54.53351095318794, 47.20469981431961, 50.75725078582764, 56.52298539876938, 51.16257883608341, 51.414288729429245, 45.66422067582607, 26.498204916715622, 12.94128192588687, 3.364812070503831, 2.03071482013911, 5.912992861121893, 6.691291322931647, 7.452789936214685, 5.713829398155212, 4.17845718562603, 1.4977651555091143, 0.1367015388677828, 0.9777366381604224, 12.635453436523676, 33.198362588882446, 39.84570689499378, 42.80078552663326, 51.72822028398514, 38.202017694711685, 12.181165963411331, 0.44757733005099, 0.027411400697019417, 0.04655032615119126, 0.0320103952253703, 0.08686132772709243, 0.022076711466070265, 0.04293476820748765, 0.018811668014677707, 0.03628256090451032, 0.01406146182489465, 0.02840232555172406, 0.04169250576524064, 0.04768405320646707, 0.04548743338091299, 0.04843399343371857, 0.027698135017999448, 0.09217533515766263, 0.07710087607847527, 0.008874388549884316, 0.02842043395503424, 0.04010596101579722, 0.02910442322900053, 0.10219487798167393, 0.14226016559405252, 0.1155744944117032, 0.2370872686151415, 0.15384681260911748, 0.17956785508431494, 0.19196561013814062, 0.16015189146855846, 0.14492327347397804, 0.16605591372353956, 0.17521550034871325, 0.12181751488242298, 0.0872043558047153, 0.19797969289356843, 0.18043518823105842, 0.20080463349586353, 0.16454727592645213, 0.13954812049632892, 0.27157709759194404, 0.09150259313173592, 0.09994000327424146, 0.15251790813636035, 0.2167861454654485, 0.1127645600354299, 0.12137358440668322, 0.0904446245112922, 2.3455654503777623, 24.24924999475479, 56.6383396089077, 57.40606181323528, 63.432310447096825, 64.21109765768051, 49.58437152206898, 35.683664828538895, 18.682679794728756, 2.2992580477148294, 1.8886152701452374, 5.182370441034436, 8.602092415094376, 14.411907512694597, 23.960919566452503, 11.284364685416222, 10.109337586909533, 27.121939547359943, 39.72164735198021, 53.57870198786259, 56.290217489004135, 60.32368965446949, 55.426181852817535, 54.526884108781815, 52.794876247644424, 47.70521655678749, 44.150085523724556, 46.66265890002251, 41.83395400643349, 41.506962552666664, 40.75120970606804, 42.67723135650158, 44.024810045957565, 42.14649863541126, 43.3712413161993, 49.27222967147827, 52.08030179142952, 53.54031644761562, 51.291372925043106, 53.34669403731823, 55.513219982385635, 52.5407724827528, 49.54689793288708, 51.14629290997982, 47.710201889276505, 45.631439834833145, 38.9641921967268, 38.06445747613907, 42.2182197868824, 41.08634032309055, 36.42821587622166, 42.52979166805744, 46.432919427752495, 50.043649077415466, 52.68842875957489, 54.83572393655777, 52.20776975154877, 54.803699254989624, 53.83011929690838, 49.82602335512638, 52.8020578622818, 51.37529142200947, 54.5174416154623, 41.34038329124451, 53.06474916636944, 52.27200150489807, 49.03696909546852, 48.65291990339756, 45.02927474677563, 40.29614992439747, 39.55032594501972, 39.65919770300388, 39.1423000395298, 37.114143669605255, 40.16069479286671, 37.93325051665306, 37.80314549803734, 40.77957898378372, 39.86146464943886, 41.592853143811226, 46.187539994716644, 50.7088565826416, 55.834583938121796, 53.19415122270584, 51.05431504547596, 52.49358281493187, 51.95010557770729, 54.59070548415184, 53.14178243279457, 50.9815489500761, 44.253922551870346, 36.70004568994045, 37.22007438540459, 39.099985510110855, 40.605248138308525, 38.58615428209305, 41.12124145030975, 45.23948326706886, 47.59757213294506, 48.30809220671654, 52.594338208436966, 52.267931923270226, 56.39074869453907, 49.67634178698063, 51.69695556163788, 60.73510117828846, 53.08626361191273, 50.86926117539406, 46.82764984667301, 27.352286987006664, 13.89839356765151, 3.480745987035334, 2.379527552984655, 7.742375722154975, 14.173154924064875, 13.624992538243532, 13.965356424450874, 7.90740561671555, 2.8599673602730036, 0.29342254099901766, 1.4665862848050892, 14.255003482103348, 38.72364230453968, 46.453320533037186, 49.66213054955006, 60.60501515865326, 42.41226017475128, 13.817858789116144, 0.7581518834922463, 0.17224193725269288, 0.20058273134054616, 0.12634287908440456, 0.1890041885781102, 0.07514466386055574, 0.15776109241414815, 0.12601174763403833, 0.1305990811670199, 0.15974884590832517, 0.10078558407258242, 0.11411696832510643, 0.185273100505583, 0.15629149158485234, 0.13046461885096505, 0.12984537082957104, 0.1436389423906803, 0.10660140949767083, 0.07750566568574868, 0.0852743413997814, 0.130134244391229, 0.19165199337294325], [0.01878764098364627, 0.02238238539575832, 0.034217301217722706, 0.03128579191979952, 0.03792751638684422, 0.014208928423613543, 0.012399402621667832, 0.024484360983478837, 0.016074035520432517, 0.012718990892608417, 0.03547604304912966, 0.026043754260172136, 0.06171801753225736, 0.054379438661271706, 0.017420078038412612, 0.04723188489151653, 0.04881232918705791, 0.0330765571561642, 0.019927175344491843, 0.03449259347689804, 0.048780153374536894, 0.04727140054455958, 0.04984103492461145, 0.03673475519462954, 0.03123617934761569, 0.037576469403575175, 0.6467074854299426, 15.766076948493719, 36.95454083383083, 50.447590202093124, 47.03400917351246, 36.028473526239395, 29.67878434807062, 32.546819150447845, 17.388691529631615, 1.8179558054544032, 0.2767045662039891, 0.322284575086087, 3.0347102461382747, 5.0359695218503475, 3.0245571909472346, 0.5224413878750056, 4.580652778968215, 14.86202185973525, 35.699065402150154, 46.87727898359299, 54.50605362653732, 55.24124197661877, 51.117665246129036, 49.13880743086338, 47.48077780008316, 42.43881314992905, 41.13153889775276, 39.23005633056164, 39.23674397170544, 42.90833495557308, 47.72724777460098, 48.26907590031624, 49.23095628619194, 49.364321529865265, 46.85393683612347, 45.02643629908562, 46.78883112967014, 50.40060572326183, 50.19025281071663, 50.18475830554962, 52.298664674162865, 51.30050763487816, 51.165060102939606, 49.65288944542408, 48.82816269993782, 47.98361621797085, 44.11492981016636, 36.31664626300335, 35.0593089312315, 34.645191952586174, 36.15848734974861, 34.50928844511509, 39.198738411068916, 43.01054947078228, 45.04564806818962, 47.64783963561058, 48.36866855621338, 46.267529502511024, 46.887371242046356, 44.76566769182682, 49.38417166471481, 46.2684490531683, 48.775805309414864, 33.161238580942154, 44.4723766297102, 49.65392678976059, 48.436821699142456, 46.27196006476879, 44.321870505809784, 43.06880034506321, 38.447910100221634, 35.21051801741123, 33.337742909789085, 37.757650539278984, 36.69108957052231, 35.754409432411194, 33.72904971241951, 35.722228959202766, 34.62613597512245, 35.41997417807579, 35.10259620845318, 41.54731638729572, 44.37417469918728, 48.85091207921505, 49.290917068719864, 47.55853682756424, 45.28901360929012, 46.382043957710266, 48.693440929055214, 47.651118859648705, 42.653421834111214, 34.04835417866707, 34.67907853424549, 34.84365150332451, 34.95993286371231, 36.21192008256912, 34.581290781497955, 38.52588191628456, 38.457789570093155, 38.37291732430458, 42.922246009111404, 47.47599005699158, 49.28461700677872, 53.66633288562298, 44.78127725422382, 47.92684726417065, 53.01277935504913, 45.52988648414612, 36.16217315196991, 19.37512993812561, 5.6762427650392056, 1.6490859794430435, 2.110253102146089, 2.891606125049293, 5.504152374342084, 6.084778793156147, 4.185228422284126, 3.5923880338668823, 1.3137625227682292, 0.3183666290715337, 1.1826509144157171, 13.566236291080713, 32.98914581537247, 39.62211549282074, 40.57851657271385, 53.094338178634644, 28.00481267273426, 5.816544536501169, 0.2107715728925541, 0.03458955507085193, 0.017266603754251264, 0.04516484776104335, 0.021965407868265174, 0.034297505117137916, 0.06054657082131598, 0.02390839686995605, 0.017119508229370695, 0.015505686769756721, 0.009992135310312733, 0.04378198544145562, 0.05279466393403709, 0.010667123260645894, 0.02951629663584754, 0.01159125389676774, 0.014190804249665234, 0.027773893452831544, 0.016005314500944223, 0.046892497048247606, 0.05351477724616416, 0.0269843466594466, 0.09058134295628406, 0.10747614185675047, 0.027952815980825108, 0.026487577124498785, 0.04698899108916521, 0.05491314303071704, 0.11248240291024558, 0.00844992831844138, 0.03139911044854671, 0.023622102271474432, 0.059866889714612626, 0.014527649309457047, 0.028340935095911846, 0.05544900704990141, 0.050433350406819955, 0.06630984848015942, 0.04125455699977465, 0.03739875843166374, 0.05037091723352205, 0.020953270577592775, 0.04794341526576318, 0.03280039658420719, 0.044264433381613344, 0.06284873146796599, 0.02944440107967239, 0.06745041813701391, 0.9002326126210392, 19.094984270632267, 43.61068546772003, 53.27950604259968, 55.43225012719631, 43.466555401682854, 34.12491247057915, 35.984988659620285, 18.714371994137764, 1.9516762113198638, 0.4096894443500787, 0.8822866505943239, 4.008028255775571, 6.286728456616402, 4.386215312406421, 2.085597412660718, 7.102365139871836, 16.839700788259506, 37.607611790299416, 48.983642756938934, 56.69816739857197, 56.48987017571926, 53.323674872517586, 50.12186788022518, 49.430187195539474, 46.1487402766943, 42.37467639148235, 41.63705237209797, 40.89393764734268, 43.16458560526371, 47.705562338232994, 49.81104835867882, 49.486226588487625, 47.67725005745888, 47.833976447582245, 46.97917051613331, 47.32735723257065, 53.18602725863457, 50.432353019714355, 50.521424040198326, 52.546445578336716, 53.372878432273865, 53.758838921785355, 52.74696461856365, 49.071668833494186, 48.30785281956196, 46.11233443021774, 37.85057835280895, 36.28142975270748, 37.81793810427189, 36.781118139624596, 37.16519013047218, 41.4488560706377, 46.408566534519196, 47.61465981602669, 49.21821556985378, 50.15182547271252, 48.81676331162453, 47.34098330140114, 47.24346153438091, 50.095751881599426, 47.75235302746296, 52.115867882966995, 38.02983373403549, 47.44680382311344, 51.72482706606388, 49.75195772945881, 49.19458083808422, 46.774897277355194, 44.47424992918968, 40.45995153486729, 36.55976481735706, 34.77625451982021, 38.932391703128815, 39.86212581396103, 37.69981004297733, 36.51138201355934, 37.627412527799606, 36.22327767312527, 37.32621408998966, 38.057158067822456, 44.52315330505371, 48.075521886348724, 49.56892915070057, 49.33071233332157, 48.66456247866154, 47.15936824679375, 48.0402559787035, 49.48031410574913, 50.51837280392647, 44.652445167303085, 35.973574072122574, 35.816555097699165, 36.13099582493305, 36.67600058019161, 38.15931178629398, 36.643424928188324, 40.04088722169399, 40.41737861931324, 41.220989897847176, 45.99775157868862, 50.133772641420364, 52.18104958534241, 54.502641409635544, 46.98361627757549, 52.08247907459736, 52.892933785915375, 46.762969717383385, 38.06248918175697, 21.974180974066257, 6.336867241188884, 3.4606244042515755, 3.888194798491895, 6.491581639274955, 7.824744852259755, 7.170919636264443, 4.596229093149304, 2.7780228573828936, 0.9577050036750734, 0.19705763377714902, 1.5922253555618227, 15.104107819497585, 36.96260780096054, 43.03691625595093, 43.67212437093258, 59.30701620876789, 32.17867590487003, 6.887709908187389, 0.19787307595834136, 0.0828399634337984, 0.07453453683410771, 0.01704193895420758, 0.059499778944882564, 0.03514890435326379, 0.03021898060978856, 0.030874198673700448, 0.05614967980363872, 0.03117605796433054, 0.02142024659406161, 0.054635290362057276, 0.012844812754337909, 0.06206805519468617, 0.026648122220649384, 0.038065233020461164, 0.04315761660109274, 0.006490656596724875, 0.03577106159355026, 0.04024054578621872, 0.0370523795572808, 0.027949496725341305, 0.20844437589403242, 0.15623823506757617, 0.14503501122817397, 0.12698391656158492, 0.10929283773293719, 0.13425182813080028, 0.14181342237861827, 0.10327037613024004, 0.09697867077193223, 0.14454503048909828, 0.16032684536185116, 0.12853019608883187, 0.13003295607632026, 0.1490726656629704, 0.13884548476198688, 0.1714423918747343, 0.20624689146643505, 0.10237429960398003, 0.09297667653299868, 0.08806912112049758, 0.17419139592675492, 0.08252402374637313, 0.1580898489919491, 0.15235837607178837, 0.09148421013378538, 0.13146576122380793, 1.2668228102847934, 22.339172288775444, 49.786144495010376, 61.40908621251583, 57.689534202218056, 48.33995349705219, 41.93098559975624, 44.33562196791172, 21.59437235444784, 2.9904673201963305, 0.6487162713892758, 2.7165637677535415, 8.888886775821447, 11.870620027184486, 8.059376087039709, 1.6281716641969979, 6.285920524969697, 18.066309168934822, 38.93082998692989, 51.42744742333889, 56.73392727971077, 58.11825379729271, 54.94221322238445, 52.88931258022785, 52.90440917015076, 48.602895587682724, 44.92219649255276, 43.04684892296791, 42.83549286425114, 46.51035167276859, 51.98830112814903, 52.7455472946167, 53.269539177417755, 52.143420204520226, 51.412309035658836, 49.48086507618427, 49.57085944712162, 55.510689318180084, 50.00536613166332, 50.501486510038376, 54.67507615685463, 54.77566435933113, 55.57205602526665, 53.89457903802395, 51.242021173238754, 51.28754273056984, 49.47203814983368, 40.285761281847954, 38.65642011165619, 39.4846198707819, 39.550466537475586, 38.23078215122223, 43.12198229134083, 48.291300907731056, 48.99096116423607, 50.1741074770689, 52.70394332706928, 49.493541195988655, 49.28224593400955, 49.48208101093769, 52.8779511898756, 50.27833968400955, 53.923970460891724, 41.525193974375725, 50.013265907764435, 53.14490586519241, 52.409113347530365, 51.092256009578705, 49.88050863146782, 47.31845051050186, 42.44866222143173, 38.57400253415108, 36.735942363739014, 41.11717186868191, 40.502782836556435, 39.3241810798645, 38.083654046058655, 38.95234823226929, 38.44512104988098, 39.475895538926125, 38.97871121764183, 45.90763941407204, 49.74806293845177, 53.30825909972191, 53.42494323849678, 50.157578364014626, 48.286034390330315, 47.84673996269703, 52.65429139137268, 51.88212722539902, 46.9382581114769, 38.528492376208305, 37.66072154045105, 38.31140622496605, 38.08504477143288, 40.01897379755974, 37.808579206466675, 42.149682864546776, 42.54305675625801, 43.0028510838747, 47.29085259139538, 51.51176109910011, 53.930513709783554, 56.716387420892715, 49.48724873363972, 50.79646088182926, 56.132415756583214, 49.667549058794975, 38.254078701138496, 22.36260563135147, 6.47547097876668, 3.270353889092803, 6.146300816908479, 8.11001406982541, 11.971519812941551, 15.833307690918446, 13.666371367871761, 9.128585513681173, 2.2409575385972857, 0.7104769698344171, 1.8725668312981725, 18.467816524207592, 41.931122392416, 52.9635301977396, 52.41947919130325, 65.05706906318665, 38.48133310675621, 8.36955914273858, 0.3068259358406067, 0.16187288740184158, 0.11841755083878525, 0.12817277776775882, 0.19804783689323813, 0.11806594353402033, 0.13572965195635334, 0.07635072062839754, 0.15926495078019798, 0.07965252079884522, 0.11700078350258991, 0.1526818930869922, 0.14695640187710524, 0.12172261645901017, 0.12105027519282885, 0.07801512037985958, 0.24299584765685722, 0.06932680495083332, 0.12423443011357449, 0.08920924548874609, 0.11353870911989361, 0.06958521335036494], [0.01642438302951632, 0.04241822971380316, 0.013863329731975682, 0.09630338317947462, 0.027834385909955017, 0.006874981481814757, 0.04550044694042299, 0.06559440327691846, 0.03390892030438408, 0.021194019573158585, 0.08084422443062067, 0.0538473892811453, 0.05823486986628268, 0.04508298145083245, 0.027289816498523578, 0.0372104013513308, 0.05778007805929519, 0.09071926368051209, 0.022135055405669846, 0.05796350727905519, 0.011529033163242275, 0.034826708360924385, 0.023169293854152784, 0.04028497445688117, 0.030662272838526405, 0.043813563825096935, 0.20149708696408197, 5.246274461969733, 26.73292402178049, 48.8510412722826, 42.676232010126114, 31.351435594260693, 32.93011598289013, 30.621114782989025, 21.593844182789326, 4.014575779438019, 0.17221798072569072, 1.0742365568876266, 1.8914822163060308, 2.339379619807005, 4.159957403317094, 0.6110235408414155, 2.2082237200811505, 7.833914235234261, 23.155256398022175, 42.34576754271984, 52.626381888985634, 55.34517019987106, 53.23957018554211, 49.68040756881237, 48.95481750369072, 44.79400277137756, 42.481199875473976, 41.74283489584923, 42.436077296733856, 47.81617060303688, 51.210695654153824, 51.203810423612595, 49.212721064686775, 47.48500697314739, 50.408068522810936, 49.77649301290512, 49.887690246105194, 50.24642139673233, 50.01496821641922, 46.86832286417484, 49.52134430408478, 50.5611889064312, 52.851025834679604, 51.23035579919815, 51.06177404522896, 48.33889715373516, 47.00573489069939, 45.868011340498924, 39.50032822787762, 33.38155835866928, 35.42708359658718, 35.44402688741684, 35.861719474196434, 40.47768898308277, 43.077809661626816, 42.72339887917042, 43.540499433875084, 40.81367835402489, 42.21493676304817, 40.53522169589996, 48.78196857869625, 45.645974054932594, 50.404595509171486, 29.99783042818308, 43.21489870548248, 51.74348406493664, 46.538223177194595, 49.42201003432274, 45.587852373719215, 46.15304924547672, 41.78284294903278, 39.685412496328354, 35.186108127236366, 34.69825990498066, 33.89967955648899, 36.75021059811115, 33.30738253891468, 35.76747693121433, 35.3533523529768, 37.303844690322876, 36.81759998202324, 36.601999551057816, 38.54081131517887, 44.527941048145294, 46.80583901703358, 48.70227165520191, 50.055249854922295, 44.86005462706089, 47.17286132276058, 47.376876175403595, 45.652809888124466, 35.034275874495506, 33.87732155621052, 35.54428070783615, 36.16496600210667, 39.42745193839073, 38.56588616967201, 37.548528760671616, 37.46451526880264, 37.45147816836834, 38.41887965798378, 43.00204172730446, 48.4960301220417, 52.277526408433914, 50.448464155197144, 44.8952217400074, 44.97392691671848, 46.79234214127064, 28.769506439566612, 12.104855608195066, 2.6883129961788654, 1.734070556703955, 1.992823015898466, 6.800972912460566, 7.748613087460399, 4.203257029876113, 2.526375660672784, 1.4227177575230598, 0.9793722722679377, 0.22358628135407344, 3.7154527427628636, 14.993878584355116, 27.21235189586878, 33.785461485385895, 45.02205893397331, 41.88568443059921, 25.315421484410763, 1.8820558721199632, 0.13054493407253176, 0.06403785984730348, 0.0639107076858636, 0.054619118964183144, 0.06370554096065462, 0.02555148399551399, 0.024171115292119794, 0.043867443746421486, 0.011670453113765689, 0.08010120844119228, 0.013221911904111039, 0.03794800337345805, 0.041306937782792374, 0.0423670957388822, 0.10657528589945287, 0.012128542839491274, 0.011186791762156645, 0.061940476298332214, 0.058113209597649984, 0.021270594370434992, 0.030447489734797273, 0.0174167829027283, 0.06038180290488526, 0.014451912211370654, 0.04566937088384293, 0.07462420311640017, 0.04224023301503621, 0.04719402793853078, 0.05090687773190439, 0.027625558541330975, 0.025752489127626177, 0.049794680380728096, 0.10077820712467656, 0.024425132032774854, 0.01728007002384402, 0.044813262720708735, 0.01796274013031507, 0.022219025704544038, 0.021751073763880413, 0.09921128104906529, 0.042702698629000224, 0.03800568309088703, 0.03995138278696686, 0.05477425380377099, 0.026326518091082107, 0.04726878818473779, 0.07434381972416304, 0.07950933824758977, 0.2623455523280427, 8.608820904046297, 33.23450244963169, 55.927374958992004, 46.12122215330601, 38.60678717494011, 36.47624909877777, 34.09196823835373, 22.7053377404809, 4.192391512915492, 0.2637154085095972, 0.573396059917286, 1.7668812023475766, 5.2740552462637424, 7.005443265661597, 3.4026627894490957, 5.216274596750736, 10.512594748288393, 26.46012905985117, 42.78319627046585, 54.61710266768932, 56.5705930441618, 53.27076271176338, 51.336905881762505, 51.337730437517166, 46.8429022282362, 44.32601608335972, 42.59092278778553, 44.52276572585106, 49.094384014606476, 53.04994896054268, 53.01625236868858, 51.00072272121906, 50.00616408884525, 52.89455629885197, 50.393986478447914, 52.52713121473789, 52.426539212465286, 50.34439533948898, 49.64341655373573, 50.11189341545105, 50.23488521575928, 52.759469747543335, 53.021811470389366, 52.89847768843174, 51.896745041012764, 50.50248585641384, 47.92006462812424, 39.7519925236702, 36.06968991458416, 37.64400243759155, 37.704631984233856, 37.805398777127266, 43.15521150827408, 45.7385028898716, 46.14152446389198, 45.44072046875954, 44.845729395747185, 44.39797282218933, 43.12305003404617, 50.11388450860977, 47.616981491446495, 52.15451180934906, 34.24771048128605, 47.04676128923893, 53.760674223303795, 48.84421303868294, 50.579883903265, 47.313351184129715, 48.63363593816757, 44.871385619044304, 40.0715097784996, 35.62121897935867, 35.477252304553986, 35.89690178632736, 37.290059030056, 35.55977247655392, 37.08964638411999, 38.63895624876022, 38.741003572940826, 38.959902226924896, 38.66993598639965, 41.50322735309601, 46.836681962013245, 49.81384880840778, 50.18683299422264, 50.437566339969635, 45.62474079430103, 47.982309088110924, 48.26951287686825, 46.58282518386841, 36.36772692203522, 34.41191107034683, 37.056097984313965, 37.46274456381798, 40.53923808038235, 39.61817890405655, 39.371826723217964, 38.27722325921059, 38.71511176228523, 40.70954114198685, 45.61714120209217, 50.513756051659584, 55.561298802495, 51.12859345972538, 47.38078996539116, 50.46232961118221, 48.02457042038441, 31.55240871012211, 13.122542649507523, 3.9217336988076568, 3.819477860815823, 5.232359133660793, 8.605170249938965, 13.987066559493542, 6.277381908148527, 4.0875109657645226, 2.8261938225477934, 0.5266661080531776, 0.33639131812378764, 3.293773219920695, 18.310497365891933, 33.13484899699688, 39.073641523718834, 49.1165292263031, 48.3800033479929, 29.83421690762043, 3.2578850956633687, 0.08295518928207457, 0.015913739043753594, 0.036070599817321636, 0.058998862659791484, 0.038747845610487275, 0.015446367833646946, 0.024386904005950782, 0.05001583296689205, 0.05959625072136987, 0.023940865830809344, 0.033881965500768274, 0.03276204239227809, 0.04312976379878819, 0.05839268385898322, 0.0606418662937358, 0.03113837170531042, 0.035948323566117324, 0.018644196825334802, 0.04809915495570749, 0.06193060202349443, 0.01371368307445664, 0.024445262788503896, 0.2334065129980445, 0.18155446567106992, 0.07465258284355514, 0.18985547649208456, 0.13640842022141442, 0.057251405451097526, 0.15276367776095867, 0.11200617416761816, 0.1508379974984564, 0.18628950143465772, 0.1631523945252411, 0.12249814593815245, 0.1284982985816896, 0.11448373028542846, 0.13822181354044005, 0.13003625121200457, 0.17949672765098512, 0.17017642152495682, 0.12044993709423579, 0.1828591909725219, 0.1507758055231534, 0.1278574243769981, 0.11600009383982979, 0.1011498153093271, 0.13340438454179093, 0.17695258604362607, 0.391763579682447, 9.299410097301006, 38.58426198363304, 61.98056034743786, 53.331494852900505, 44.52653132379055, 44.370466098189354, 42.80337318778038, 28.541210889816284, 5.589959844946861, 0.5292090028524399, 1.760765549261123, 5.82080315798521, 9.273674078285694, 10.000354684889317, 2.138091358356178, 3.3903108397498727, 10.425765607506037, 26.913144551217556, 45.97863860428333, 54.6091078966856, 59.892766177654266, 57.56613202393055, 54.8980899900198, 52.68576130270958, 48.38433511555195, 45.681114569306374, 45.12341849505901, 46.1432533711195, 52.24286466836929, 54.878680631518364, 54.868683367967606, 52.874299585819244, 50.89101120829582, 55.82519844174385, 53.34105134010315, 54.99298609793186, 53.06950271129608, 52.42419853806496, 49.200896099209785, 50.24390213191509, 52.92079769074917, 53.979975655674934, 55.19021451473236, 53.51029425859451, 53.448083996772766, 51.5068593621254, 50.39074145257473, 42.99544908106327, 39.298483058810234, 38.5482133179903, 39.6340886503458, 38.72137762606144, 46.37822896242142, 48.102637231349945, 47.965665981173515, 46.965301260352135, 45.73118448257446, 45.47416627407074, 44.64958392083645, 51.905279383063316, 50.919422283768654, 54.72000874578953, 41.45815037190914, 47.178910598158836, 57.33742609620094, 50.8389388024807, 53.58551122248173, 50.03987967967987, 50.778096467256546, 46.36262319982052, 41.94121465086937, 37.586978897452354, 37.045215368270874, 38.70279282331467, 40.03179430961609, 35.67856550216675, 40.24532005190849, 39.89456847310066, 41.549565866589546, 40.76164774596691, 39.30885650217533, 42.39672660827637, 47.639130502939224, 50.73436081409454, 53.22654448449612, 52.63487063348293, 47.239072769880295, 49.00812104344368, 50.175483003258705, 49.22753646969795, 38.13462071120739, 36.106962114572525, 38.78285452723503, 38.71992990374565, 44.862228110432625, 42.70987160503864, 40.6295782327652, 40.153319388628006, 40.28807535767555, 42.37114638090134, 47.72764295339584, 53.19327726960182, 57.84462668001652, 53.775577023625374, 49.71602685749531, 51.17202892899513, 52.46991388499737, 35.308355167508125, 14.893422424793243, 4.272161107510328, 4.298717407509685, 6.413902407512069, 12.418079450726509, 16.664476990699768, 11.550017930567265, 8.314636889845133, 3.8772207498550415, 2.4904576130211353, 0.5842276162002236, 4.573312997817993, 19.847661182284355, 38.136923387646675, 45.37151478230953, 57.21679776906967, 53.28439258038998, 33.05175505578518, 4.426786210387945, 0.15466406563064083, 0.17393759626429528, 0.1909787763725035, 0.11993559906841256, 0.09343178375274874, 0.20892644533887506, 0.1102085440652445, 0.17248074553208426, 0.1804589369567111, 0.143729840638116, 0.08713423769222572, 0.17488456185674295, 0.16650664969347417, 0.18517099582822993, 0.21123404963873327, 0.11087677383329719, 0.14867411751765758, 0.09691906147054397, 0.21407954773167148, 0.11376542039215565, 0.14908451033988968, 0.07593724047183059], [0.06772903521778062, 0.03735314974619541, 0.056675150044611655, 0.030511691074934788, 0.06625441747019067, 0.014047918557480443, 0.016311396611854434, 0.0246921660436783, 0.03216459124814719, 0.017427456841687672, 0.032715008783270605, 0.03087114659138024, 0.06809068378061056, 0.08237179441493936, 0.07252022187458351, 0.01109137105231639, 0.002737260028879973, 0.03431773235206492, 0.07267770561156794, 0.07763792382320389, 0.03311257729365025, 0.02219363126641838, 0.02289483465574449, 0.02654037351021543, 0.041512835523462854, 0.10513852510484867, 0.0826803274685517, 2.9472586512565613, 17.045873925089836, 38.719546124339104, 45.65484657883644, 33.35635431110859, 23.275909423828125, 33.5150071978569, 21.546164341270924, 6.70619934797287, 0.5096638016402721, 0.6240570789668709, 1.8684503459371626, 3.4301460022106767, 6.455734837800264, 5.633206749334931, 3.227703315205872, 3.725639283657074, 17.766854837536812, 35.856927931308746, 49.60414566099644, 54.72197324037552, 54.517263025045395, 51.9177009165287, 48.877567648887634, 47.517312839627266, 43.51141959428787, 42.60675273835659, 50.420041680336, 51.70965448021889, 52.45851069688797, 51.529376953840256, 50.10952614247799, 51.11768804490566, 52.44719110429287, 49.97042700648308, 51.759431809186935, 50.2483668923378, 50.41758321225643, 48.28268676996231, 49.300332963466644, 50.16243450343609, 50.5960900336504, 49.66890938580036, 48.98459650576115, 53.6629206687212, 49.9333181977272, 49.147387370467186, 45.54686397314072, 37.6768858730793, 36.31902873516083, 35.27626968920231, 34.67201091349125, 36.284211203455925, 37.30121523141861, 37.02862165868282, 38.67884270846844, 38.05423602461815, 37.15705096721649, 43.28734561800957, 48.70210826396942, 44.642018526792526, 49.13932420313358, 30.607779398560524, 39.25280191004276, 50.74635297060013, 45.78476540744305, 48.696210980415344, 46.4746829867363, 49.086332246661186, 45.63890643417835, 42.62092597782612, 35.112266689538956, 35.028769969940186, 34.848443046212196, 35.914517641067505, 34.74420703947544, 34.47669759392738, 34.498899802565575, 35.779415890574455, 36.20691195130348, 37.749154195189476, 36.72955870628357, 40.273499339818954, 45.56385286152363, 48.56006808578968, 47.61708028614521, 48.98010514676571, 48.34588497877121, 48.910831063985825, 44.13594648241997, 37.98427037894726, 35.96978947520256, 36.058537513017654, 39.79284033179283, 44.6498879045248, 45.47081105411053, 43.134259432554245, 38.9383839815855, 39.722475707530975, 39.26721453666687, 44.160436168313026, 46.45704813301563, 49.35235217213631, 49.1064977645874, 49.44935716688633, 46.57486081123352, 32.17750556766987, 19.38983514904976, 7.171137174591422, 1.2351089995354414, 3.9893076103180647, 4.5545268058776855, 7.579564433544874, 13.865920510143042, 5.962248668074608, 2.9535458888858557, 2.5626893620938063, 0.1757062232354656, 0.5660652439109981, 5.642469702288508, 17.656795643270016, 27.604620046913624, 31.88128486275673, 34.853922352194786, 36.17416150867939, 12.882986404001713, 0.8073370379861444, 0.03349940692714881, 0.024079586219158955, 0.017471078426751774, 0.05889086161914747, 0.061451152359950356, 0.057684912462718785, 0.007536203520430718, 0.0333051571942633, 0.06999639284913428, 0.004840488918489427, 0.012944969294039765, 0.026508639275562018, 0.041448457923252136, 0.0556817037431756, 0.07803103202604689, 0.03564605794963427, 0.01325553675997071, 0.01719170806609327, 0.14987507573096082, 0.027795881433121394, 0.039100551293813623, 0.048962053770083, 0.063432259921683, 0.04745834012283012, 0.031099529551283922, 0.023308954914682545, 0.042304157905164175, 0.030337911630340386, 0.04963220198987983, 0.021450327694765292, 0.07407947414321825, 0.02795512591546867, 0.00976474590061116, 0.062297798140207306, 0.03472909738775343, 0.02773053533019265, 0.08849275385728106, 0.04627507471013814, 0.06575197607162409, 0.03087313554715365, 0.07284720471943729, 0.018422428256599233, 0.03579067655664403, 0.01944228759384714, 0.012076304919901304, 0.02496062126738252, 0.01669874574872665, 0.07936243753647432, 0.07287691289093345, 3.670881846919656, 22.0544820651412, 45.14511913061142, 51.73142351210117, 38.880159705877304, 28.482669331133366, 36.407753974199295, 26.061925627291203, 6.9294587429612875, 0.6203872477635741, 0.30893675226252526, 1.5443083830177784, 5.712090041488409, 6.2495441269129515, 6.283300565555692, 6.481525003910065, 6.953951278701425, 20.713649913668633, 38.20006839931011, 51.74696087837219, 56.37146092951298, 55.27636729180813, 54.66095231473446, 50.24092309176922, 49.20570284128189, 44.78087067604065, 43.737978637218475, 50.934636667370796, 53.243780359625816, 54.82945427298546, 52.313525676727295, 51.45634867250919, 52.01212204992771, 54.2197921872139, 50.380257815122604, 54.07831437885761, 51.02219916880131, 50.3980028629303, 48.49576033651829, 50.44146493077278, 51.23774640262127, 49.848647341132164, 50.08211441338062, 50.53044855594635, 54.54790458083153, 52.23452791571617, 51.87399946153164, 46.290871649980545, 39.664129838347435, 37.47570186853409, 37.46858485043049, 36.60016804933548, 38.193597346544266, 39.607292488217354, 38.91193360090256, 40.78806392848492, 40.350950583815575, 39.4698728621006, 45.33209569752216, 51.22086010873318, 48.3192104101181, 52.0842307806015, 34.98737119138241, 41.18687152862549, 51.23124875128269, 47.14899480342865, 50.78139089047909, 48.47034730017185, 49.268133491277695, 46.575388982892036, 43.811854273080826, 37.83664830029011, 36.14744134247303, 37.257331386208534, 37.36434504389763, 35.693209916353226, 36.27853810787201, 36.298498436808586, 38.40100161731243, 38.11234250664711, 39.203024581074715, 37.936658933758736, 42.63845443725586, 46.864876449108124, 50.21230682730675, 50.760507211089134, 48.843662068247795, 50.13266310095787, 49.637553468346596, 47.306465953588486, 38.30269709229469, 36.57924257218838, 37.75730475783348, 41.31486766040325, 47.99382247030735, 46.412468925118446, 43.942719250917435, 41.0185481607914, 40.55763669312, 41.77589692175388, 44.97667416930199, 49.25649091601372, 51.811808198690414, 52.40659028291702, 50.58155961334705, 48.33063639700413, 36.51118442416191, 23.72533980756998, 7.90243785828352, 2.76271419133991, 7.5569969695061445, 9.95846288278699, 9.212894439697266, 17.038705609738827, 6.592612043023109, 4.019344998523593, 0.7949426968116313, 0.2528229961171746, 0.4409881867468357, 6.962804803624749, 18.754330649971962, 28.236613534390926, 35.96263445913792, 42.113991379737854, 42.62542113661766, 16.26057956367731, 1.498182776849717, 0.10489965003216639, 0.031140857900027186, 0.07502468826714903, 0.04482190874114167, 0.046572379069402814, 0.04403146209369879, 0.019551943623810075, 0.0376647701341426, 0.03359362257469911, 0.014177431676216656, 0.024072979249467608, 0.01257571928363177, 0.028392777821864, 0.011716957942553563, 0.041483583772787824, 0.0033027519748429768, 0.06719635130139068, 0.0370443903375417, 0.08844924916047603, 0.03561171506589744, 0.03205809676728677, 0.015714312830823474, 0.18272653949679807, 0.09202283865306526, 0.2475128701189533, 0.1151330501306802, 0.13253826851723716, 0.10037654195912182, 0.12317714426899329, 0.147795696684625, 0.13322509650606662, 0.11078859184635803, 0.1505062574869953, 0.14276466274168342, 0.1412344878190197, 0.13786739349598065, 0.25556858628988266, 0.1369560361490585, 0.1498386956518516, 0.18939433561172336, 0.19750586128793657, 0.24032911809626967, 0.16630983212962747, 0.10803106051753275, 0.13702947908313945, 0.12727745081065223, 0.13756468630163, 0.16681762441294268, 0.2237163798417896, 4.52844500541687, 25.29585063457489, 50.37657581269741, 57.25169889628887, 45.895255878567696, 35.851934999227524, 44.13459375500679, 29.962788708508015, 9.20744363218546, 1.115680814255029, 1.1065000318922102, 6.283753216266632, 10.391153264790773, 13.104407172650099, 11.273634061217308, 6.811737734824419, 6.137111485004425, 20.193448327481747, 39.44949835538864, 53.17028850317001, 56.03797182440758, 58.37303012609482, 55.23523449897766, 52.55374878644943, 52.67925605177879, 47.18421131372452, 47.36958056688309, 53.82077939808369, 56.43074154853821, 56.34692944586277, 53.4717833250761, 52.24232889711857, 53.086510598659515, 55.225085243582726, 51.47568203508854, 54.596188589930534, 52.60599598288536, 51.30094841122627, 51.40929959714413, 51.16311840713024, 50.16203172504902, 51.65271833539009, 50.53742118179798, 49.76447805762291, 56.728375777602196, 54.970890283584595, 53.63662987947464, 49.532926082611084, 41.40482023358345, 39.462501257658005, 38.89924608170986, 38.282546773552895, 40.643417090177536, 41.37167081236839, 39.65702801942825, 42.30584688484669, 43.04466784000397, 40.95000743865967, 48.46606492996216, 53.01375970244408, 50.01784086227417, 53.592301458120346, 39.78006161749363, 43.51159058511257, 53.20762149989605, 51.30573235452175, 52.07750514149666, 50.73453940451145, 52.69883640110493, 49.150936380028725, 45.698076859116554, 40.47736220061779, 37.40382492542267, 40.214518904685974, 38.5398955643177, 38.84596914052963, 38.84762205183506, 38.755176812410355, 40.01310311257839, 40.15691019594669, 41.060110330581665, 40.0853980332613, 44.435792192816734, 49.3766974657774, 53.62135089933872, 51.67354501783848, 49.40056398510933, 50.592161044478416, 52.74231366813183, 50.29991872608662, 41.09612099826336, 39.87029917538166, 39.30982165038586, 42.765705808997154, 50.591233894228935, 50.17243556678295, 46.838483065366745, 42.90895812213421, 43.34059216082096, 44.72369894385338, 47.16113895177841, 50.79909794032574, 52.7658724039793, 54.060170352458954, 51.841932982206345, 49.80596423149109, 38.67139890789986, 23.545033782720566, 7.870204662904143, 2.895484291948378, 7.903447654098272, 11.071916185319424, 18.145736306905746, 26.84205036610365, 14.682040717452765, 7.130232844501734, 5.423854133114219, 1.7585627362132072, 0.8718221902381629, 7.895345538854599, 24.443478472530842, 37.69797474145889, 42.55392797291279, 46.50663547217846, 46.64209060370922, 17.96228975057602, 1.7677361564710736, 0.2776109066326171, 0.15904278145171702, 0.13098566589178517, 0.1303301565349102, 0.16176395496586338, 0.22647693171165884, 0.14990216412115842, 0.16165842156624421, 0.1920583043829538, 0.05968002064037137, 0.10818175360327587, 0.0704579270677641, 0.13400003226706758, 0.13843228662153706, 0.11799818545114249, 0.18591706204460934, 0.1015201024711132, 0.096534532494843, 0.24245977954706177, 0.11381622040062211, 0.10536087997024879, 0.08910686621675268], [0.026963466334564146, 0.03883020544890314, 0.008005457002582261, 0.07193736135377549, 0.030376724098459817, 0.04134410082770046, 0.010694702395994682, 0.02175895351683721, 0.0709426608227659, 0.05235271870333236, 0.0382746596733341, 0.040168876585084945, 0.06324173577013426, 0.05514955417311285, 0.03568588159396313, 0.027841081937367562, 0.010109197974088602, 0.048084931695484556, 0.0522134546918096, 0.019971552064816933, 0.03995200990175363, 0.049179143097717315, 0.03135669670882635, 0.008647177255625138, 0.046828026679577306, 0.014543628676619846, 0.004843917640755535, 0.4793708771467209, 9.27461452782154, 28.06691274046898, 42.18304127454758, 40.899196565151215, 27.363743372261524, 21.571178399026394, 20.25575928390026, 10.166821852326393, 1.3232079846784472, 0.28173436818178743, 1.0482730250805616, 3.0893107037991285, 6.034526014700532, 7.7517759427428246, 6.7102057579904795, 2.3181584710255265, 9.912577494978905, 28.753972873091698, 45.2991134673357, 55.922264233231544, 54.97103847563267, 52.03254975378513, 50.38888715207577, 46.569658890366554, 46.03225752711296, 49.82307851314545, 49.5978569984436, 52.28716269135475, 53.05376395583153, 52.91572876274586, 52.89525166153908, 52.38484025001526, 52.069981545209885, 51.494878605008125, 54.13947209715843, 51.23418979346752, 51.212181374430656, 52.49085456132889, 51.63433112204075, 51.391212567687035, 51.32757358253002, 52.584595531225204, 49.38009828329086, 51.21981896460056, 50.24933584034443, 51.41121469438076, 49.26761291921139, 43.556758761405945, 36.10113322734833, 35.60238718986511, 35.4288163036108, 35.78611113131046, 37.33404166996479, 36.004291623830795, 37.57727041840553, 37.15524226427078, 40.147570297122, 45.726795718073845, 48.2434006780386, 47.2242421656847, 49.006316140294075, 32.11165890097618, 42.31522478163242, 47.70580172538757, 44.59077447652817, 45.26793614029884, 48.343882486224174, 48.40888939797878, 45.50551079213619, 42.00608856976032, 36.34886093437672, 33.63150514662266, 34.17962573468685, 35.451200902462006, 35.617909356951714, 36.422607377171516, 41.50063969194889, 43.412241116166115, 43.45547139644623, 45.69100923836231, 43.47306065261364, 44.66355197131634, 45.73153406381607, 48.90573933720589, 50.72033956646919, 47.7289804816246, 48.25932942330837, 47.42050543427467, 45.747402012348175, 36.22019983828068, 34.524609223008156, 35.99313162267208, 45.285027623176575, 51.083303689956665, 48.928272128105164, 48.72087545692921, 45.429708659648895, 44.89226169884205, 43.08018073439598, 40.99236376583576, 46.96979261934757, 48.926661014556885, 50.39767228066921, 43.02395515143871, 42.588817700743675, 34.835991114377975, 16.553553342819214, 4.107665084302425, 1.5797116770409048, 5.28702917508781, 10.026720520108938, 7.676885761320591, 11.466437615454197, 2.2549533750861883, 2.294127610512078, 0.9074291889555752, 0.2556571690365672, 1.151804644614458, 7.821027701720595, 22.727019377052784, 29.126225598156452, 36.0152730345726, 43.61035868525505, 25.403240472078323, 5.98061403259635, 0.13374510454013944, 0.02349648450035602, 0.10998745085089467, 0.03735466001671739, 0.04482888492930215, 0.03251800197176635, 0.04056361380207818, 0.032046226115198806, 0.06831456004874781, 0.05550656802370213, 0.020527775050140917, 0.03133833597530611, 0.01870884716481669, 0.05599217380222399, 0.047945155602064915, 0.023826450778869912, 0.03230262329452671, 0.02193845677538775, 0.015982467484718654, 0.07253430783748627, 0.060152635123813525, 0.10782550787553191, 0.02376530708716018, 0.10075292957480997, 0.052423875822569244, 0.059405874999356456, 0.013703290223929798, 0.040032521792454645, 0.030803583322267514, 0.011181816589669324, 0.03708625117724296, 0.024786585781839676, 0.03976099964347668, 0.03450673881161492, 0.039334350076387636, 0.028650870808633044, 0.0760560212074779, 0.04261390808096621, 0.051492435959517024, 0.01727389721054351, 0.028899241660838015, 0.030901472600817215, 0.007954127286211587, 0.03845846367767081, 0.056053300795610994, 0.030091999142314307, 0.032231948571279645, 0.020326348749222234, 0.06352898402838036, 0.09566951484885067, 0.771065253065899, 12.496622186154127, 34.5747247338295, 50.738229006528854, 42.70513325929642, 30.678938180208206, 28.32759965211153, 22.650204598903656, 10.798053480684757, 1.2574040656909347, 0.14661103603430092, 1.048101915512234, 4.716922491788864, 6.393838534131646, 8.892831914126873, 5.811310792341828, 2.402546717785299, 11.30131272599101, 29.397776126861572, 45.36071956157684, 55.25707572698593, 57.08031669259071, 53.39870944619179, 51.48399978876114, 49.024042189121246, 48.05811122059822, 51.401973590254784, 53.043128326535225, 54.79131951928139, 54.87344071269035, 53.736226335167885, 55.629448145627975, 53.69626387953758, 53.04240636527538, 52.74003379046917, 55.76807610690594, 52.77561888098717, 53.197962418198586, 52.85761468112469, 53.76963034272194, 54.48907993733883, 53.674931824207306, 52.94546216726303, 50.84616981446743, 51.20292507112026, 51.861741319298744, 53.58911342918873, 50.724602937698364, 45.07356517016888, 37.31554426252842, 37.204518020153046, 36.90615803003311, 37.56915405392647, 37.876614555716515, 37.413297817111015, 39.65924710035324, 39.543767496943474, 42.023446038365364, 47.96648673713207, 50.77157601714134, 50.02096429467201, 49.97748322784901, 34.954122975468636, 42.77096472680569, 48.013136833906174, 47.73048900067806, 47.330742850899696, 51.87892399728298, 50.90393051505089, 47.65400670468807, 43.32602374255657, 36.846144050359726, 35.2425616979599, 35.474748238921165, 37.265580743551254, 37.83605553209782, 38.11700485646725, 43.08493807911873, 44.756016209721565, 43.36836487054825, 45.218098014593124, 44.288633689284325, 45.857052728533745, 47.601478323340416, 50.49583241343498, 51.89652845263481, 48.93105357885361, 50.24810470640659, 50.40193185210228, 48.027663454413414, 38.181343004107475, 37.014809399843216, 37.86633610725403, 47.06721179187298, 51.28001153469086, 50.13254530727863, 50.64435124397278, 47.206546515226364, 45.606486573815346, 44.59717333316803, 43.10279332101345, 49.66784544289112, 51.32071115076542, 51.86259627342224, 46.12984389066696, 47.103575840592384, 36.11563704907894, 18.518034629523754, 4.6419876627624035, 2.6184221589937806, 7.9718563333153725, 12.357692141085863, 7.151881707832217, 4.754832107573748, 1.528899259865284, 0.9165527962613851, 0.8409972349181771, 0.08963327898527496, 1.4185618492774665, 10.436582677066326, 26.508834846317768, 31.38898517936468, 40.58979816734791, 44.32809837162495, 30.77532760798931, 8.172693606466055, 0.1777798283728771, 0.06258390349103138, 0.02610467345220968, 0.0329011839494342, 0.022077641006035265, 0.04476361304114107, 0.058056657944689505, 0.07743261608993635, 0.07465366637916304, 0.038180611009011045, 0.0408362083544489, 0.04059782680997159, 0.0558857832220383, 0.028552905459946487, 0.013162603172531817, 0.08102005405817181, 0.06461188138928264, 0.07972410094225779, 0.06484562822151929, 0.03616094516473822, 0.052956203508074395, 0.015406206512125209, 0.06182364741107449, 0.17704743251670152, 0.14748979825526476, 0.15896558325039223, 0.14038576773600653, 0.08677563193487003, 0.14393464371096343, 0.113324695994379, 0.08390230330405757, 0.10474253736902028, 0.10161067417357117, 0.12681470689130947, 0.09270127295167185, 0.1390696133603342, 0.14983560831751674, 0.1770509799825959, 0.1624932634877041, 0.06662101615802385, 0.11535792087670416, 0.20752626500325277, 0.11083273479016498, 0.1870139266247861, 0.11272631716565229, 0.09362275319290347, 0.14056042477022856, 0.13666299171745777, 0.20106177282286808, 0.10230090862023644, 0.7702750142198056, 13.21714997291565, 39.790640249848366, 56.62625625729561, 52.33465634286404, 39.18049179017544, 32.69849941134453, 29.863418340682983, 13.77785548567772, 2.3007903154939413, 0.572561351582408, 2.989200563170016, 9.857248663902283, 15.302133243530989, 16.44230481237173, 10.11300629004836, 4.311516545712948, 13.070126362144947, 31.056221835315228, 46.76853261888027, 58.671245723962784, 60.20919419825077, 56.64599619805813, 52.90952369570732, 51.43553338944912, 51.6655882447958, 53.34073215723038, 54.65173780918121, 57.47938647866249, 57.066238448023796, 56.77242301404476, 57.24883385002613, 56.40480414032936, 53.5469014942646, 56.30223624408245, 57.62417770922184, 53.95290970802307, 55.854392275214195, 55.06210818886757, 56.522305235266685, 55.68690866231918, 55.10058872401714, 54.885516464710236, 51.40311732888222, 51.66316017508507, 52.57334053516388, 56.52542866766453, 53.623471185564995, 48.48879151046276, 39.2795866727829, 40.042175352573395, 38.37015487253666, 40.05382552742958, 40.40201224386692, 39.425970017910004, 42.75226593017578, 40.719865188002586, 43.617608696222305, 51.17122337222099, 52.68074557185173, 54.6702466160059, 52.4470467120409, 40.1203865557909, 45.01482792198658, 48.65433342754841, 47.864994183182716, 49.50585253536701, 52.5870805978775, 53.055109083652496, 49.579249396920204, 46.77891366183758, 38.63064609467983, 35.68320505321026, 38.19322496652603, 39.20736014842987, 40.05202442407608, 40.27078628540039, 45.04895009100437, 48.63607540726662, 47.024555280804634, 49.62875314056873, 47.97922745347023, 47.897243052721024, 49.50786642730236, 53.212831020355225, 53.630451411008835, 48.83867673575878, 51.959601268172264, 51.76436394453049, 50.38526214659214, 40.011408403515816, 37.92575351893902, 39.433767199516296, 50.413015857338905, 55.18953815102577, 53.00633490085602, 53.157726377248764, 49.695006385445595, 49.22846361994743, 46.29192799329758, 44.411344304680824, 52.1980232745409, 52.0951209962368, 53.37225526571274, 46.92415326833725, 48.333927020430565, 40.3031225502491, 22.18064669519663, 6.123696779832244, 3.641540533863008, 11.470966022461653, 17.06443402916193, 14.403693303465843, 23.56004487723112, 10.389224868267775, 6.3434128649532795, 3.079757303930819, 0.3188627993222326, 1.8867354397661984, 10.41928505524993, 30.42499590665102, 41.177968606352806, 46.36633940041065, 54.50679838657379, 33.169753924012184, 9.252475965768099, 0.2639036171603948, 0.20358664827654138, 0.161507349985186, 0.18668381933821365, 0.12260342700756155, 0.11751374855521135, 0.18598195543745533, 0.21341106563340873, 0.2090901482733898, 0.1676492899423465, 0.19122649042401463, 0.13964137877337635, 0.15295040211640298, 0.14923794195055962, 0.2081757629639469, 0.12939062726218253, 0.12896689062472433, 0.2109366562217474, 0.10220042924629524, 0.23087233101250604, 0.13135944114765152, 0.28958703274838626, 0.11136634639115073], [0.012218839019624284, 0.035207563705625944, 0.042478955947444774, 0.031649544471292756, 0.04693798327934928, 0.05465161390020512, 0.00810069310318795, 0.06782972981454805, 0.02091436163027538, 0.10875469903112389, 0.04456091395695694, 0.0759008752356749, 0.04955861433700193, 0.06980413949349895, 0.04410711662785616, 0.024494574790878687, 0.03866671773721464, 0.057988825647043996, 0.022046151680115145, 0.04760645424539689, 0.035759079619310796, 0.06452804838772863, 0.07955365188536234, 0.056251431960845366, 0.04741884673421737, 0.06379938553436659, 0.01992830897506792, 0.014589373731723754, 2.943696342408657, 17.455421648919582, 35.339414700865746, 45.74741341173649, 32.27770239114761, 29.603498987853527, 23.107544258236885, 15.407999362796545, 2.0592610258609056, 0.2899361390154809, 0.36741315037943423, 5.940329544246197, 2.6878646202385426, 3.39188514277339, 2.204720308072865, 1.7532595270313323, 10.46602064743638, 21.74887776374817, 45.81310048699379, 51.29784017801285, 55.146809443831444, 52.038675025105476, 51.70661084353924, 49.791255220770836, 49.57587517797947, 52.137135341763496, 54.53772492706776, 56.62315182387829, 52.27092616260052, 52.39774435758591, 48.99857975542545, 48.026162534952164, 48.960327208042145, 49.22899939119816, 51.74661509692669, 49.2968675494194, 49.932170659303665, 48.49033422768116, 49.27792176604271, 49.308874905109406, 51.47595942020416, 49.83205363154411, 52.773669585585594, 51.00940525531769, 51.360890194773674, 50.28448015451431, 50.15602044761181, 45.14445796608925, 38.33938032388687, 35.09501941502094, 36.588312685489655, 36.11831210553646, 39.43045377731323, 38.14479656517506, 37.405922412872314, 37.95434698462486, 43.55018891394138, 46.315695717930794, 49.002748131752014, 46.678686439991, 49.01550404727459, 30.148790627717972, 43.69421638548374, 49.112623035907745, 47.04077661037445, 48.9534267783165, 46.6603372246027, 48.40310610830784, 42.95128785073757, 38.513308390975, 35.59333607554436, 35.92486448585987, 34.17797662317753, 33.18693660199642, 38.14716383814812, 45.656966865062714, 47.55940318107605, 47.574689760804176, 47.7081385999918, 48.151567205786705, 48.113766834139824, 46.29600517451763, 50.09279944002628, 49.75377023220062, 45.78573435544968, 47.738586366176605, 48.35080571472645, 47.69790954887867, 46.09614349901676, 37.61762045323849, 34.1216978430748, 36.80647037923336, 49.572728946805, 49.19547379016876, 51.57164208590984, 50.519330352544785, 48.3995570987463, 48.20796377956867, 45.280980840325356, 44.169259294867516, 47.50573106110096, 48.94307613372803, 53.76830421388149, 48.20667564868927, 36.25523775815964, 24.3687953799963, 15.902758464217186, 3.053787834942341, 3.7824820959940553, 10.550492964684963, 13.628581445664167, 6.646289387717843, 4.399782959371805, 1.0545317642390728, 1.2068246235139668, 0.14301596878794953, 0.8073183952365071, 1.4913534745573997, 14.270260613411665, 20.17645373940468, 24.872452653944492, 35.710153207182884, 33.74129645526409, 18.796660378575325, 2.8776855720207095, 0.09499978594249114, 0.04033626428281423, 0.022182495340530295, 0.037145693495403975, 0.09249339738744311, 0.023326044720306527, 0.036671917550847866, 0.0035589830986282323, 0.0755623223085422, 0.022703232534695417, 0.0482804133935133, 0.1294827277888544, 0.035258252391940914, 0.03789805312408134, 0.03788105052080937, 0.015579162172798533, 0.010821064170158934, 0.060791594587499276, 0.03763831628020853, 0.0862859925837256, 0.02461734457028797, 0.02534985545935342, 0.018246129220642615, 0.02014680467254948, 0.08115630495012738, 0.03667148710519541, 0.01584828904015012, 0.05496412486536428, 0.011638192881946452, 0.05290280227200128, 0.07575569630716927, 0.06286527393967845, 0.06760442120139487, 0.05133704878971912, 0.07574783696327358, 0.049980747935478576, 0.01223710976773873, 0.06000901099469047, 0.006029665073583601, 0.06377254947437905, 0.08523610595148057, 0.05602486169664189, 0.009171417386824032, 0.08194093315978535, 0.05172384873731062, 0.0320117459341418, 0.013010859020141652, 0.07696465487242676, 0.0865525720291771, 0.010414376520202495, 0.04890108262770809, 4.789306707680225, 22.212399691343307, 43.257631212472916, 51.89474634826183, 36.25560253858566, 32.405318543314934, 26.48045986890793, 18.010932840406895, 2.4480616254732013, 0.46144124236889184, 0.5064224568195641, 3.7436619540676475, 4.76606952957809, 4.824145138263702, 3.052682806737721, 3.618661486543715, 13.65836139768362, 25.541319362819195, 46.44113838672638, 53.15405197441578, 57.19650685787201, 53.51868040859699, 54.33337189257145, 50.7467595487833, 51.90399885177612, 52.569571137428284, 56.39718554913998, 57.929639518260956, 52.092860117554665, 53.011023849248886, 51.6650752723217, 50.80536000430584, 50.96378870308399, 51.41364276409149, 52.57698453962803, 51.85997061431408, 52.48992741107941, 49.31782342493534, 52.00138382613659, 51.039818823337555, 55.16571342945099, 52.34717287123203, 53.70497301220894, 51.78536541759968, 52.829382196068764, 51.24744348227978, 52.012004256248474, 47.89838679134846, 38.9885450899601, 36.654744520783424, 37.322041913867, 36.870401948690414, 39.79054145514965, 38.60401712357998, 38.28772969543934, 38.686358705163, 45.11780619621277, 48.026413321495056, 49.47982773184776, 47.88044035434723, 49.61469769477844, 33.872389420866966, 44.177987426519394, 51.08306810259819, 49.610696509480476, 50.24866707623005, 50.38518615067005, 50.44121794402599, 45.95831349492073, 40.66886052489281, 37.51544773578644, 37.18433730304241, 36.83110825717449, 34.620341286063194, 39.22679990530014, 47.09527708590031, 50.718610659241676, 49.94594871997833, 51.256737783551216, 49.864564687013626, 49.58974443376064, 49.64880846440792, 50.63633367419243, 50.67704848945141, 47.30936519801617, 49.18462157249451, 51.4215387403965, 49.1428542137146, 48.476772755384445, 38.84766384959221, 36.16479121148586, 39.561132565140724, 50.63237048685551, 52.74379558861256, 53.236815333366394, 51.306910291314125, 51.1441346257925, 48.902513310313225, 47.660637348890305, 46.275015100836754, 49.235462844371796, 51.30385145545006, 56.43550269305706, 48.74018222093582, 38.103264793753624, 29.353865683078766, 16.391790322959423, 2.7260404592379928, 5.720304250717163, 6.1153030302375555, 9.399645868688822, 4.519499335438013, 0.4635761637473479, 0.8008378429803997, 0.4536118812393397, 0.09165557203232311, 0.5605062015820295, 2.017863909713924, 14.560377895832062, 24.084333144128323, 31.40286583453417, 41.56666114926338, 42.45764493942261, 22.35709022730589, 3.8569205766543746, 0.030981904710642993, 0.029129502254363615, 0.02909299044404179, 0.07098133413819596, 0.041567680236767046, 0.05239727353909984, 0.02317173366463976, 0.028935870359418914, 0.04388319212011993, 0.04488866121391766, 0.024738075298955664, 0.00418911703491176, 0.028012360344291665, 0.06628912029555067, 0.074488924437901, 0.04021915709017776, 0.029483966827683616, 0.01691487956122728, 0.023415232317347545, 0.043341346390661784, 0.012308322548051365, 0.04296852850529831, 0.04996178606234025, 0.07013930080574937, 0.17953943082829937, 0.2326474740402773, 0.20226224121870473, 0.1519225721131079, 0.2228810332599096, 0.1376142172375694, 0.1725252892356366, 0.15440320072229952, 0.1937120023649186, 0.17489987978478894, 0.2054329781094566, 0.15703025506809354, 0.1580383291002363, 0.1081012083159294, 0.18006405502092093, 0.18620813236339018, 0.2182657949742861, 0.22398481465643272, 0.20472676522331312, 0.22254448413150385, 0.12598387256730348, 0.16393749770941213, 0.11177851294633001, 0.1635198763688095, 0.20576038397848606, 0.08261938230134547, 0.12090431700926274, 4.6013678424060345, 26.8330467492342, 50.27355194091797, 58.89171749353409, 43.71789671480656, 41.83378301560879, 32.05900892615318, 21.653096303343773, 2.8856810554862022, 0.6010659970343113, 1.2509470246732235, 10.656923353672028, 8.514397870749235, 11.173917911946774, 9.916618578135967, 6.026293281465769, 15.130560100078583, 25.692883729934692, 49.90937568247318, 52.724173441529274, 59.168677031993866, 55.66977918148041, 57.33177959918976, 53.73319409787655, 54.506741389632225, 56.436133459210396, 59.164801239967346, 59.215813502669334, 54.97575022280216, 54.622008204460144, 53.03143635392189, 51.016605868935585, 53.14878545701504, 52.260651513934135, 55.95496907830238, 54.981514513492584, 55.65671928226948, 52.50769905745983, 53.5322342813015, 53.2913576066494, 56.49056173861027, 53.338406682014465, 56.3429244607687, 53.43732677400112, 54.02219519019127, 52.285741567611694, 53.33770751953125, 48.28255757689476, 41.35013356804848, 38.19321736693382, 39.73162941634655, 38.440553694963455, 41.01703964173794, 40.457816049456596, 39.19786065816879, 40.5479434132576, 46.98766686022282, 51.15889683365822, 52.96821914613247, 50.04414305090904, 51.27459682524204, 39.153118059039116, 47.29154035449028, 52.97791242599487, 52.802852019667625, 52.19496823847294, 52.34556935727596, 52.635866180062294, 47.33752928674221, 43.28739121556282, 39.186183884739876, 40.56997463107109, 38.26647363603115, 36.43686041235924, 41.22260861098766, 51.574944108724594, 51.598860025405884, 52.76779890060425, 54.32413838803768, 53.48453164100647, 51.828170120716095, 51.2621258944273, 53.3277178555727, 51.697251945734024, 46.25969052314758, 48.554368391633034, 52.36278623342514, 51.30395025014877, 49.69301149249077, 41.5576746314764, 37.301116436719894, 40.169825702905655, 53.33819769322872, 53.53245846927166, 53.9184607565403, 55.132833793759346, 53.27993541955948, 51.28788851201534, 49.3507144600153, 47.22127452492714, 51.560170501470566, 51.83240309357643, 57.490717470645905, 50.10176695883274, 39.86714914441109, 28.893311396241188, 20.205932557582855, 4.970420664176345, 8.543055932968855, 16.0422470793128, 24.405691400170326, 13.210885059088469, 15.37132278084755, 4.39720194786787, 4.993519149720669, 1.56470806337893, 1.235020060557872, 2.4076576810330153, 17.106577567756176, 30.6169331073761, 36.47403001785278, 49.35117423534393, 43.47184471786022, 25.224963538348675, 3.9068615343421698, 0.1303127605933696, 0.1558065426070243, 0.09606427061953582, 0.2538618544349447, 0.1509929876192473, 0.1569899416062981, 0.08606253191828728, 0.06994527371716686, 0.1993629671051167, 0.09450250989175402, 0.12179911704151891, 0.18646789889317006, 0.14616510918131098, 0.16693789686542004, 0.1303273215307854, 0.15250290191033855, 0.15644375060219318, 0.09593535956810229, 0.1115696800115984, 0.17154799948912114, 0.0664133187092375, 0.1451867210562341, 0.17213146114954725], [0.056680244888411835, 0.05650255247019231, 0.03891091029800009, 0.05439149485027883, 0.1005792076466605, 0.12289276070077904, 0.026707284378062468, 0.08779592913924716, 0.007867320127843414, 0.046065610949881375, 0.055187789621413685, 0.13227676536189392, 0.01066651562723564, 0.06891077180625871, 0.09605821469449438, 0.03933032392524183, 0.07890868102549575, 0.01482555109760142, 0.010390928364358842, 0.05294412505463697, 0.05939891365414951, 0.06586317947949283, 0.046397718324442394, 0.021966509957564995, 0.017174722161144018, 0.05285449587972835, 0.054260754404822364, 0.016148994291143026, 0.24505241308361292, 11.277243867516518, 33.34128051996231, 41.57253563404083, 37.193962186574936, 23.136907182633877, 26.56968668103218, 16.798778884112835, 4.156374195590615, 0.4626926814671606, 0.22338772716466337, 2.8425566945225, 9.829317312687635, 18.468401692807674, 34.04187552630901, 19.658674523234367, 7.572565209120512, 14.663036037236452, 31.19484979659319, 42.82132722437382, 51.216862723231316, 53.30702416598797, 55.383304953575134, 51.61100797355175, 54.92130294442177, 53.58210660517216, 55.30664786696434, 50.59760235249996, 52.40249790251255, 50.86761586368084, 46.508998945355415, 46.21087834239006, 47.03381538391113, 46.430441960692406, 46.31686985492706, 41.066763773560524, 42.35563941299915, 43.30825209617615, 45.813757851719856, 46.93059392273426, 48.68396803736687, 46.98640152812004, 49.75897595286369, 50.90078428387642, 50.53729958832264, 51.1391568928957, 50.68722054362297, 49.4820050150156, 43.488328233361244, 37.33098663389683, 39.75564032793045, 38.574986681342125, 37.24107965826988, 37.49561659991741, 39.152190908789635, 39.67476926743984, 45.358542278409004, 47.507836148142815, 48.04116792976856, 46.80689916014671, 51.658201441168785, 32.42605023086071, 41.56207859516144, 49.925688207149506, 49.31723065674305, 46.606361120939255, 47.494571059942245, 42.308263555169106, 38.177980184555054, 36.09214290976524, 36.31200671195984, 38.01298923790455, 34.075834304094315, 36.17471627891064, 43.32203395664692, 48.69932681322098, 48.22060950100422, 50.19543193280697, 49.735884591937065, 51.104954928159714, 50.1886834949255, 49.19744588434696, 49.258136227726936, 49.09754924476147, 47.88634143769741, 47.11684472858906, 49.687596783041954, 45.97469441592693, 44.37469147145748, 36.97759799659252, 34.90869641304016, 37.61508598923683, 47.15894266963005, 48.51697079837322, 50.5988334864378, 48.803042247891426, 50.12192867696285, 49.58090230822563, 46.9523211568594, 45.25955758988857, 48.75270634889603, 50.49725353717804, 52.928693667054176, 41.93427622318268, 29.571160823106766, 11.998925842344761, 2.1480959840118885, 0.07952430736622773, 1.4002885110676289, 3.2322625955566764, 9.99044006690383, 4.114175559952855, 0.37115740415174514, 0.05928865648456849, 0.11501029890496284, 0.27016042673494667, 0.4373077576747164, 6.133258966729045, 18.426915518939495, 31.60893827676773, 33.76039043068886, 38.62295910716057, 24.099232144653797, 8.05601991713047, 0.6500793888699263, 0.04011145661934279, 0.06997678530751728, 0.03384305469808169, 0.045015063806204125, 0.02738830320595298, 0.058599631738616154, 0.004826513350053574, 0.0452824447711464, 0.049568536851438694, 0.03615315261413343, 0.0368763643928105, 0.019482024035823997, 0.051256047081551515, 0.01887712915049633, 0.023247837198141497, 0.0648344069486484, 0.019713364454219118, 0.01943981995282229, 0.0829452222387772, 0.014090495569689665, 0.040343663495150395, 0.024475913487549406, 0.017153821427200455, 0.016709063456801232, 0.029558417227235623, 0.040715167779126205, 0.023184487472462934, 0.04827046119316947, 0.060144683011458255, 0.07405683121760376, 0.027142307226313278, 0.002031270946645236, 0.05972257909888867, 0.07345837817410938, 0.06704154671751894, 0.08722724363906309, 0.032769656827440485, 0.06766886930563487, 0.02126752744516125, 0.04864812901359983, 0.02456455746141728, 0.030417974521697033, 0.06710707093589008, 0.07623994024470448, 0.011270084851275897, 0.04629408853361383, 0.02536996951675974, 0.04083267202076968, 0.011999066828138893, 0.06932900912943296, 0.0287144431786146, 0.8573042973876, 14.64294271543622, 38.46375145018101, 47.48335026204586, 41.66173204779625, 28.377553671598434, 27.16986447572708, 18.98577243089676, 3.9395533176138997, 0.5339341680519283, 0.15293343662051484, 0.8727881102822721, 8.099906612187624, 14.454692266881466, 26.924876421689987, 13.32660784944892, 8.634601570665836, 18.91042437404394, 37.77526639401913, 45.950900092720985, 52.48873047530651, 55.60903564095497, 56.931307688355446, 53.636462688446045, 57.37265020608902, 55.63854105770588, 56.768395230174065, 52.079595029354095, 55.16906104981899, 54.049538522958755, 49.83597882091999, 49.28484119474888, 49.138340055942535, 48.672219067811966, 48.895301297307014, 44.124368503689766, 46.15014240145683, 46.96460969746113, 48.28787349164486, 49.727232456207275, 50.26660591363907, 49.81020100414753, 51.475138664245605, 52.34651930630207, 52.64361396431923, 52.03443445265293, 52.81279608607292, 52.842658683657646, 44.95723441243172, 37.9040452837944, 41.46541178226471, 39.53975111246109, 38.94236236810684, 39.750799387693405, 40.20221136510372, 41.24653972685337, 47.07666948437691, 49.29761990904808, 49.8573412746191, 49.38447564840317, 52.38772049546242, 34.1609763354063, 44.01252530515194, 52.05748401582241, 51.428146585822105, 48.917872086167336, 49.24549050629139, 45.530638843774796, 41.336378306150436, 37.812325805425644, 37.52809725701809, 37.69099831581116, 35.626375302672386, 36.2510009855032, 45.226845145225525, 51.23659886419773, 50.291220992803574, 51.82390294969082, 51.067131757736206, 52.60427847504616, 51.29581108689308, 51.003040596842766, 51.207857206463814, 49.79230396449566, 47.831077203154564, 47.468158677220345, 50.890190452337265, 47.39266812801361, 46.66310727596283, 37.76904612779617, 37.51962371170521, 38.938893154263496, 49.14919227361679, 48.94480124115944, 52.83963404595852, 50.53219646215439, 51.19522288441658, 50.98545894026756, 49.252535328269005, 47.89369024336338, 50.48612393438816, 52.07634620368481, 54.61397163569927, 45.485379472374916, 33.65445591509342, 14.945323839783669, 3.9516946161165833, 1.4745055348612368, 2.1353790163993835, 6.072007678449154, 4.115392919629812, 1.1423664260655642, 0.05760361018474214, 0.21202725707553327, 0.0369265595509205, 0.1200876577058807, 0.5535836855415255, 7.082226695492864, 18.99856824427843, 32.32938341796398, 36.183915585279465, 41.963215470314026, 29.013333655893803, 10.844953414052725, 1.2899855361320078, 0.09810135466977954, 0.08642861852422357, 0.050667928444454446, 0.00785285566962557, 0.041952955070883036, 0.04413349255628418, 0.027006714990420733, 0.012371320681268116, 0.033296370165771805, 0.04657943318306934, 0.054690866090822965, 0.04645719032851048, 0.015540225394943263, 0.022355196815624367, 0.018999589083250612, 0.03804736952588428, 0.08807551101199351, 0.03420390545215923, 0.07140000190702267, 0.054960800043772906, 0.0486932404601248, 0.07425179341225885, 0.06262567156227306, 0.10580667323665693, 0.19824952294584364, 0.22550425812369213, 0.09320082739577629, 0.17729578481521457, 0.1463383561349474, 0.1441218875697814, 0.1847805519355461, 0.13447922217892483, 0.15633882576366886, 0.11649256077362224, 0.2130219279206358, 0.21347321307985112, 0.15372213179944083, 0.19219129724660888, 0.12416705052601174, 0.16591606341535226, 0.13361205230467021, 0.10445843581692316, 0.21250269172014669, 0.16403939458541572, 0.16418950137449428, 0.10566235519945621, 0.1806166730239056, 0.15057432727189735, 0.13374465925153345, 0.17795197694795206, 0.1056913731736131, 1.0063252947293222, 16.01577389985323, 46.4505884796381, 54.97728914022446, 50.00959910452366, 33.33124525845051, 37.42377385497093, 22.846661657094955, 6.256904331967235, 0.8750754094216973, 0.5171262449584901, 5.897406097501516, 22.18024391680956, 27.52707190811634, 37.92841337621212, 25.177268497645855, 10.575253386050463, 19.90023136138916, 40.36097064614296, 50.75127370655537, 54.973325952887535, 58.00639919936657, 58.43268312513828, 55.80144591629505, 59.74303901195526, 58.59506741166115, 57.88359738886356, 54.32688184082508, 56.71456351876259, 54.59532983601093, 50.1416952162981, 51.5284688025713, 51.123212948441505, 50.14062747359276, 50.366529151797295, 44.399914517998695, 45.90372182428837, 47.2720891982317, 49.07086327672005, 50.76350525021553, 51.77931234240532, 51.46791145205498, 54.22407075762749, 55.65423421561718, 53.75318102538586, 54.17541816830635, 53.82342025637627, 55.654059424996376, 47.725260481238365, 39.704483672976494, 42.38398589193821, 42.10563562810421, 39.727879017591476, 41.12129084765911, 42.9460821300745, 44.70315724611282, 48.575464859604836, 52.0888627320528, 53.256315886974335, 52.04777933657169, 53.28785799443722, 38.11296567320824, 47.1892574429512, 52.44957357645035, 53.98667089641094, 50.0086073577404, 50.758603513240814, 47.61971354484558, 42.6253679394722, 39.55624222755432, 40.08376032114029, 40.14959938824177, 37.29147635400295, 39.067998826503754, 47.123684361577034, 53.2267876714468, 51.930848211050034, 53.72797317802906, 53.52888286113739, 54.204946383833885, 53.09561111032963, 51.147873625159264, 51.961197182536125, 50.84337316453457, 48.269125297665596, 49.19488102197647, 51.519265696406364, 49.8501368612051, 48.565543591976166, 39.681836888194084, 39.165509194135666, 41.54715299606323, 51.81662634015083, 51.43229216337204, 54.82888050377369, 51.72152504324913, 51.50016412138939, 54.05960038304329, 50.679145976901054, 49.81569550931454, 53.009857311844826, 53.61848585307598, 55.483566373586655, 46.20004512369633, 33.06673765182495, 14.164061062037945, 3.270290717482567, 1.0040531354025006, 4.560489635914564, 10.685855001211166, 21.12380750477314, 10.7611527107656, 2.0340816769748926, 0.3728107607457787, 0.3286909422604367, 0.8067175524774939, 0.7950460037682205, 8.82977619767189, 24.921376928687096, 41.96226932108402, 46.35213956236839, 49.88348387181759, 34.92271386086941, 11.599403880536556, 1.2832665466703475, 0.17193203122587875, 0.20044647302711383, 0.10697872479795478, 0.20276013325201347, 0.19374939176486805, 0.09775152109796181, 0.11716766282916069, 0.1430928404442966, 0.12992748204851523, 0.15171686362009495, 0.14787543303100392, 0.15078386524692178, 0.20584225771017373, 0.12297967361519113, 0.07188141084043309, 0.18140378000680357, 0.21214861306361854, 0.11113496701000258, 0.20464929984882474, 0.0861234102922026, 0.11409336802898906, 0.1775513804750517, 0.16491910675540566], [0.0720870599616319, 0.05727176998334471, 0.03102241113083437, 0.05610921791230794, 0.020094720748602413, 0.11489972632261924, 0.008463390877295751, 0.011717121215042425, 0.01794512525520986, 0.014418694609048543, 0.06134604198450688, 0.038238702618400566, 0.009732052440085681, 0.07369009894318879, 0.023976511183718685, 0.042003710550488904, 0.06865666044177487, 0.03525910586176906, 0.03442988199822139, 0.06061918997147586, 0.01251438077815692, 0.02452527744026156, 0.01588127935974626, 0.035761038889177144, 0.07892431065556593, 0.047776049832464196, 0.14619573019444942, 0.04790899816725869, 0.1886529746116139, 4.151498582214117, 24.717080891132355, 47.072474509477615, 37.192218080163, 36.24019056558609, 35.43948993086815, 21.438822001218796, 8.630186207592487, 1.3889414886943996, 0.29711469600442797, 0.3498922608559951, 4.745645625516772, 11.023730970919132, 48.47523383796215, 30.298728682100773, 4.493388561531901, 1.8899864028207958, 14.172351267188787, 30.601015761494637, 45.52097216248512, 48.59418645501137, 54.704235792160034, 55.71505755186081, 56.04386530816555, 53.914744555950165, 50.670493841171265, 53.79359185695648, 52.42111690342426, 50.92436961829662, 43.534187972545624, 41.38647481799126, 38.95161487162113, 37.744959220290184, 38.30655388534069, 36.23186141252518, 36.60535477101803, 37.5068373978138, 39.26881045103073, 40.71666195988655, 43.31274725496769, 43.64845544099808, 47.367733865976334, 48.778867945075035, 49.585260674357414, 49.394309520721436, 50.493613332509995, 48.6430898308754, 45.50035446882248, 35.909965485334396, 37.1238711476326, 37.198609337210655, 36.60860359668732, 35.3184550255537, 39.539694115519524, 39.23757992684841, 45.909592509269714, 46.1656341701746, 51.084933802485466, 47.10732243955135, 49.52943027019501, 33.49157765507698, 41.706121265888214, 50.9997233748436, 48.18237975239754, 48.218572810292244, 43.55441428720951, 38.002327010035515, 37.16516733169556, 36.474444195628166, 33.76871578395367, 35.24321906268597, 34.088423028588295, 37.68105044960976, 47.31587044894695, 49.5620971173048, 50.210205540061, 46.802654787898064, 49.79332610964775, 51.57769896090031, 50.39539620280266, 49.76555719971657, 48.52366603910923, 50.04544638097286, 48.839090913534164, 49.718853905797005, 47.74317651987076, 46.69382482767105, 41.38941206037998, 34.86783340573311, 35.35002753138542, 35.30924052000046, 43.21785494685173, 48.99231009185314, 50.32623611390591, 50.73987431824207, 50.15795074403286, 51.254248917102814, 49.672325402498245, 51.41218364238739, 51.59824825823307, 50.815801844000816, 48.83480854332447, 36.20522104203701, 19.71503309905529, 8.017286695539951, 7.411537924781442, 17.234294414520264, 25.98441168665886, 14.414568319916725, 5.399644207209349, 3.4045218396931887, 0.5855866963975132, 0.16610128863248974, 0.09783150235307403, 0.28203015855979174, 3.1909186765551567, 7.89079955779016, 19.312340207397938, 24.257263764739037, 42.22064785659313, 39.53801080584526, 19.760286770761013, 4.12183927372098, 0.03875871807395015, 0.03456537589954678, 0.049934282069443725, 0.030514028840116225, 0.03343924843647983, 0.010899249427893665, 0.062450977420667186, 0.05164213456737343, 0.05226447734457906, 0.031126543726713862, 0.030415371438721195, 0.012332217847870197, 0.06815574786742218, 0.016158584694494493, 0.04803696669114288, 0.009846362663665786, 0.03113082035270054, 0.026864990759349894, 0.06498078073491342, 0.010148260917048901, 0.034698134986683726, 0.06641310348641127, 0.041913591558113694, 0.03548965774825774, 0.030597251425206196, 0.13357641437323764, 0.017467824109189678, 0.022594121983274817, 0.0684535049367696, 0.08922870460082777, 0.06133712508017197, 0.06384266758686863, 0.016443239146610722, 0.05496425845194608, 0.05563654034631327, 0.044337123035802506, 0.05661172610416543, 0.015579818973492365, 0.04715480543382, 0.02441451375489123, 0.02748028313362738, 0.0715776275319513, 0.04167155122559052, 0.04231545339280274, 0.03538708922860678, 0.011859142305183923, 0.031382616216433235, 0.013595849504781654, 0.0656116136815399, 0.060258224184508435, 0.056411220066365786, 0.019144933139614295, 0.14977901213569567, 6.1428881250321865, 30.77257465571165, 52.21571512520313, 41.12501464784145, 33.24740655720234, 33.74817408621311, 22.241158448159695, 9.990005940198898, 1.393430947791785, 0.20254900708096102, 1.0185530385933816, 4.138204520568252, 16.063476540148258, 51.26690983772278, 31.239848881959915, 5.791054554283619, 3.4333323687314987, 18.463049679994583, 36.879738047719, 49.874090775847435, 50.94583846628666, 56.82256132364273, 57.60115094482899, 59.024809151887894, 54.181399047374725, 50.90256258845329, 55.613291412591934, 55.38884125649929, 51.01476676762104, 44.905712977051735, 42.17178627848625, 41.83404140174389, 40.207572877407074, 40.35692386329174, 38.445466831326485, 38.86975586414337, 39.86657157540321, 41.851205080747604, 43.310497775673866, 45.54220162332058, 45.05148455500603, 49.86866846680641, 50.608496367931366, 50.403170585632324, 52.07109868526459, 51.20427019894123, 50.00974729657173, 46.89321532845497, 37.04776123166084, 39.07180242240429, 39.084417745471, 38.139461651444435, 37.44340360164642, 41.25549204647541, 41.552487909793854, 47.55577437579632, 48.93946252763271, 51.110324040055275, 49.54613037407398, 49.614306315779686, 35.14024458825588, 44.47103150188923, 52.90412798523903, 49.87694822251797, 51.03082850575447, 45.47291234135628, 40.043805465102196, 38.54363456368446, 37.442727237939835, 35.37831321358681, 37.32098937034607, 35.245267152786255, 38.8634330034256, 48.85216601192951, 51.70718841254711, 51.138355135917664, 48.407434076070786, 50.25158531963825, 52.13767111301422, 52.273643016815186, 50.11370591819286, 49.1377966850996, 52.726856097579, 50.62231242656708, 51.53376951813698, 50.20627275109291, 48.678074553608894, 42.41626515984535, 36.67429827153683, 36.366541385650635, 36.55971921980381, 44.40204240381718, 50.519132763147354, 50.6687231361866, 51.927257403731346, 50.753048211336136, 52.24721543490887, 51.32863752543926, 52.180016040802, 53.886044695973396, 53.01950879395008, 50.55168181657791, 38.09756509959698, 21.792660914361477, 9.735754933208227, 5.620145425200462, 12.153594642877579, 20.909723192453384, 14.547390192747116, 4.553277147933841, 1.7031410476192832, 0.7400194345973432, 0.2943947841413319, 0.05414533559815027, 0.381909788120538, 4.18742660433054, 10.055275037884712, 22.72185355424881, 31.038478687405586, 47.64552175998688, 45.408938974142075, 25.36982126533985, 5.342681938782334, 0.03300683238194324, 0.011066762363043381, 0.05944986209215131, 0.013972959786769934, 0.0269776190907578, 0.041849132321658544, 0.04201272764476016, 0.04115387724596076, 0.02619955332193058, 0.03890396379574668, 0.02160049756639637, 0.04640495797502808, 0.08394047195906751, 0.01837022373365471, 0.042328819472459145, 0.0232316583787906, 0.023142992140492424, 0.015173485699051525, 0.05868576539796777, 0.020851781882811338, 0.03904418888851069, 0.07435712643200532, 0.053954915347276255, 0.026715294006862678, 0.2024836535565555, 0.17827822506660596, 0.18584862118586898, 0.2693273511249572, 0.14227618114091456, 0.2112901708460413, 0.17205080454004928, 0.1342784712323919, 0.10885861454880796, 0.10017843305831775, 0.11436764354584739, 0.16088304051663727, 0.13024779298575595, 0.1531923422589898, 0.07590073422761634, 0.12253673761733808, 0.10911437348113395, 0.18348980869632214, 0.08656989375595003, 0.1313672336982563, 0.1524950796738267, 0.16731946467189118, 0.11481663546874188, 0.12175938245491125, 0.16221458703512326, 0.11813482968136668, 0.2165704921935685, 0.1957978677819483, 0.3281316003995016, 6.384214125573635, 34.43298473954201, 59.77345257997513, 50.004511177539825, 47.92463578283787, 45.80259405076504, 28.04031226783991, 10.63968462869525, 1.8718628003261983, 0.5954254965763539, 1.7698201071470976, 9.890327788889408, 17.746052853763103, 51.4996587485075, 32.311300188302994, 8.197988849133253, 2.906379969790578, 18.10901127755642, 37.06164948642254, 50.061698108911514, 52.166975140571594, 58.132176250219345, 60.53350679576397, 59.54971298575401, 55.46967051923275, 52.51151405274868, 57.31266662478447, 59.360992312431335, 55.26546947658062, 46.161378398537636, 44.82281282544136, 42.35884644091129, 41.56395569443703, 41.909053176641464, 40.287417992949486, 40.639024525880814, 42.56235972046852, 42.61459171772003, 44.38444174826145, 46.335333064198494, 47.30084985494614, 52.37499877810478, 52.614815309643745, 53.66944871842861, 54.43421088159084, 53.680411130189896, 51.838209182024, 48.38728755712509, 40.1459401845932, 40.41067957878113, 40.494370087981224, 40.03706842660904, 38.735326677560806, 42.55279563367367, 44.08449724316597, 51.06191843748093, 51.32696941494942, 53.10804784297943, 52.15714506804943, 48.450618758797646, 39.66272011399269, 46.72737702727318, 54.57894131541252, 52.723489478230476, 51.46019406616688, 48.2392892986536, 41.42980769276619, 39.522279649972916, 39.5665130764246, 37.278838232159615, 39.289162158966064, 36.892345771193504, 40.79485036432743, 51.58227391541004, 53.200078904628754, 50.948502123355865, 48.02243493497372, 50.09088434278965, 51.671759113669395, 53.25847417116165, 50.61837963759899, 49.38235156238079, 52.97003164887428, 51.86676844954491, 53.004514798521996, 52.3409678041935, 52.007452100515366, 44.66430053114891, 37.75343656539917, 39.285449758172035, 39.02829855680466, 46.483050137758255, 52.80513569712639, 53.04535120725632, 52.610749527812004, 50.12277603149414, 52.8745199739933, 52.84865476191044, 53.56177769601345, 55.785292983055115, 53.927872851490974, 50.82905553281307, 37.688638642430305, 21.40019327402115, 10.668973457068205, 10.610715933144093, 20.990529656410217, 32.67407812178135, 24.001843370497227, 9.428827352821827, 5.583429420366883, 1.264011673629284, 0.6585286511108279, 0.22977733664447442, 0.6767546106129885, 9.843716640025377, 11.173356492072344, 27.960792034864426, 36.24232605099678, 54.25352677702904, 50.59584304690361, 28.83124552667141, 6.003626072779298, 0.09952443768270314, 0.10466625943081453, 0.10908200842095539, 0.09981650990084745, 0.12467597087379545, 0.12757904478348792, 0.16465580760268494, 0.1280330610461533, 0.08127029883326031, 0.1526316348463297, 0.18167846370488405, 0.1233378860342782, 0.18473756674211472, 0.1272111918660812, 0.10777167248306796, 0.1294491530279629, 0.058030756990774535, 0.12438326783012599, 0.14994549070252106, 0.12792959081707522, 0.12178458579001017, 0.1685324011486955, 0.11072041816078126, 0.14180497673805803], [0.053658772449125536, 0.03787257148360368, 0.0852038299490232, 0.11074078269302845, 0.01750110757711809, 0.019283412329968996, 0.050960342050530016, 0.032581648556515574, 0.01146770671766717, 0.02562334615504369, 0.050545366466394626, 0.053877821046626195, 0.02924586173321586, 0.00686652424519707, 0.02525371208321303, 0.08461019344395027, 0.028772707337338943, 0.014740398000867572, 0.036564398906193674, 0.05958583838946652, 0.05953254105406813, 0.011078813913627528, 0.03911592117219698, 0.0558051562984474, 0.05565868974372279, 0.037882675824221224, 0.03771723626414314, 0.023681650345679373, 0.05230073868006002, 0.6902039889246225, 9.43700261414051, 36.73773966729641, 48.830294385552406, 38.922143653035164, 19.590274393558502, 20.561671368777752, 9.691084530204535, 3.471918348222971, 0.14740345679456368, 0.662520396290347, 0.5152157787233591, 3.154797339811921, 3.6181753501296043, 6.188090024515986, 8.308808002620935, 0.30642143567092717, 6.311849383637309, 20.137445032596588, 39.216377064585686, 50.55781848728657, 53.55732433497906, 52.61248603463173, 55.62216393649578, 53.691867515444756, 54.17507238686085, 51.911564245820045, 50.02817630767822, 46.465487480163574, 42.28552557528019, 38.99422198534012, 39.21384260058403, 42.60682113468647, 42.84927852451801, 44.223797768354416, 45.55852934718132, 39.019258841872215, 39.29774969816208, 38.76012794673443, 40.419688895344734, 41.517218202352524, 44.89360302686691, 46.527667343616486, 49.80861648917198, 51.159193217754364, 50.39279714226723, 47.85823814570904, 46.846268847584724, 38.81994813680649, 36.7988745868206, 35.37892498075962, 36.84386417269707, 39.0172753483057, 41.125463023781776, 43.63598830997944, 48.65013845264912, 48.292577639222145, 50.29145658016205, 47.40633599460125, 55.98810330033302, 33.76055762171745, 40.33911041915417, 50.77993556857109, 48.678864911198616, 47.35279306769371, 42.734870463609695, 38.11108097434044, 35.976644307374954, 37.06345058977604, 34.49464023113251, 36.483043134212494, 34.498728811740875, 42.8049311041832, 47.8997091203928, 51.02924399077892, 47.46984198689461, 47.73715004324913, 48.98921325802803, 48.245783150196075, 50.2013786137104, 47.52795226871967, 49.578333646059036, 49.610533118247986, 46.88388682901859, 48.60012173652649, 46.69906474649906, 44.24930199980736, 39.09367024898529, 34.3497160077095, 36.53649866580963, 36.815065518021584, 41.336651891469955, 44.34690736234188, 48.15034367144108, 50.11213280260563, 50.38948372006416, 47.4675203114748, 51.42589330673218, 50.00685565173626, 50.55294714868069, 49.32287335395813, 39.74776715040207, 30.641565285623074, 10.728654004633427, 9.430607557296753, 11.836537756025791, 12.618632689118385, 11.259153988212347, 9.537116792052984, 2.5710460636764765, 2.790315910242498, 0.9071987075731158, 0.10125369371962734, 0.08296600979520008, 0.21993451402522624, 4.491126257926226, 12.970101479440928, 19.242319464683533, 25.749595686793327, 34.88209404051304, 28.592627830803394, 8.458109591156244, 0.9899780969135463, 0.0184013215766754, 0.07445803625159897, 0.007691773444093997, 0.030733880812476855, 0.06709118897560984, 0.04127436121052597, 0.08665250963531435, 0.029413249430945143, 0.02247348031232832, 0.0814110842475202, 0.11295782271190546, 0.048165109619731084, 0.03161266715324018, 0.04850922123296186, 0.06552336490130983, 0.037693673075409606, 0.05298456468153745, 0.015955635135469493, 0.029155277043173555, 0.040443961042910814, 0.040836583139025606, 0.02666711192432558, 0.012596136693900917, 0.015437268175446661, 0.0967121878056787, 0.07883017664426006, 0.026275118798366748, 0.07165543429437093, 0.05960855552984867, 0.054475053257192485, 0.010222448781860294, 0.05149042102857493, 0.03727583280124236, 0.034488311284803785, 0.05574110153247602, 0.05996588850393891, 0.027594724160735495, 0.03218182020646054, 0.07864277693443, 0.06707146269036457, 0.03193734562955797, 0.007707495842623757, 0.02372525523242075, 0.04734273948997725, 0.016618044610368088, 0.05681438808096573, 0.11066590741393156, 0.09551818351610564, 0.008718045864952728, 0.06373685217113234, 0.035215701354900375, 0.051108433908666484, 0.00793660703493515, 1.3400174514390528, 13.797721769660711, 44.171394780278206, 50.120617747306824, 46.06726884841919, 25.90910542756319, 23.203378915786743, 13.08574827387929, 3.0074630957096815, 0.14716172445332631, 0.49088001425843686, 1.181316354777664, 3.9621217316016555, 11.191870048642159, 10.233589019626379, 7.517876168712974, 2.3591297725215554, 8.172095138579607, 23.152666836977005, 41.758611649274826, 51.46747067570686, 53.90629380941391, 53.53018619120121, 54.86462898552418, 54.03488650918007, 54.30023767054081, 55.978714004158974, 52.84942992031574, 49.18172612786293, 43.45612496137619, 40.85534691810608, 41.267791986465454, 43.68874087929726, 44.11244474351406, 45.974481627345085, 46.71475030481815, 41.880284920334816, 41.39539673924446, 40.782470628619194, 43.141273856163025, 43.53338621556759, 45.58740019798279, 47.84631818532944, 52.15046502649784, 52.204038351774216, 51.881473660469055, 50.38465037941933, 47.58162438869476, 40.97151808440685, 36.75610788166523, 37.01834321022034, 38.165205270051956, 39.601307809352875, 42.55072474479675, 45.780160054564476, 50.92955633997917, 50.62718376517296, 51.108085960149765, 49.16851043701172, 55.14710582792759, 36.53786279261112, 43.888473361730576, 51.83249808847904, 50.77309973537922, 48.422937244176865, 43.804452270269394, 40.757851749658585, 38.508296459913254, 38.37186478078365, 35.60062028467655, 36.779446229338646, 36.695193350315094, 43.47325064241886, 49.86229620873928, 53.09697903692722, 50.43871387839317, 46.3265935331583, 49.30883690714836, 50.940013378858566, 50.677474066615105, 49.44991193711758, 52.099901139736176, 51.02477543056011, 50.34026876091957, 49.332961812615395, 48.28841686248779, 45.83843752741814, 41.00058272480965, 35.747353211045265, 38.33055719733238, 38.6259875446558, 43.73938836157322, 46.25148296356201, 51.63450591266155, 52.759135365486145, 50.7392967492342, 49.05442535877228, 52.64197625219822, 52.0135697722435, 53.245767652988434, 51.146931275725365, 42.195010632276535, 31.261749006807804, 13.380032032728195, 11.378585379570723, 15.702859740704298, 18.03855735808611, 19.0096028521657, 10.026491582393646, 3.012000764720142, 3.3025177381932735, 0.9227333427406847, 0.5119587597437203, 0.030543028260581195, 0.4759337834548205, 7.954223854467273, 15.5843516997993, 25.425581373274326, 30.049167573451996, 41.02148540318012, 34.43333052098751, 11.925303842872381, 1.6855887207202613, 0.05542629733099602, 0.10624286311212927, 0.0221330070780823, 0.031170243237284012, 0.09475935978116468, 0.02450323194352677, 0.023050796989991795, 0.031074400430952664, 0.0493229601852363, 0.03629548540629912, 0.037253152768244036, 0.09474832404521294, 0.033599893722566776, 0.05484933688421734, 0.05156315892236307, 0.025760977441677824, 0.04078819511050824, 0.07438184737111442, 0.02175635043386137, 0.045751782672596164, 0.01662774262513267, 0.013705721685255412, 0.02275682672916446, 0.007926515681901947, 0.2740039798663929, 0.17665531137026846, 0.20222713763359934, 0.19178175047272816, 0.13621611491544172, 0.1322603490552865, 0.10607788368361071, 0.18654012470506132, 0.12753074581269175, 0.10851419865502976, 0.11848814392578788, 0.17461302486481145, 0.1496814048732631, 0.16149103757925332, 0.13729326805332676, 0.19883779372321442, 0.08489110376103781, 0.1236738266015891, 0.18208431458333507, 0.1687830244190991, 0.17411290638847277, 0.08703254119609483, 0.22231933136936277, 0.263193441205658, 0.10935382000752725, 0.1313154021045193, 0.10965269029838964, 0.12650201038923115, 0.06673453506664373, 1.4229154656641185, 15.426762755960226, 48.969606310129166, 59.85265173017979, 53.31158772110939, 28.537464290857315, 29.035503566265106, 13.841728158295155, 4.738123454153538, 0.288128504762426, 1.575249054003507, 1.9791017146781087, 6.258631814271212, 6.787411440163851, 9.208484776318073, 12.108192779123783, 1.7944375611841679, 7.096203770488501, 22.796648740768433, 42.41923280060291, 51.35650523006916, 53.513717874884605, 52.50745587050915, 53.82469318807125, 55.02193294465542, 55.55166631937027, 57.14010648429394, 55.463587045669556, 50.19403740763664, 45.919103398919106, 43.744092509150505, 44.57881651818752, 48.20822216570377, 46.83416269719601, 50.01721389591694, 50.68683676421642, 43.361966013908386, 44.220837727189064, 42.492895647883415, 44.921869710087776, 45.07817432284355, 48.66518184542656, 48.8773662596941, 53.24614763259888, 55.22790089249611, 52.618561908602715, 51.772491708397865, 49.205543249845505, 43.366388976573944, 39.996813386678696, 39.27965126931667, 40.282375663518906, 43.17745931446552, 46.200292110443115, 48.33532154560089, 52.44024507701397, 52.40638889372349, 54.30244915187359, 50.62307998538017, 54.96749326586723, 41.916189193725586, 45.35968601703644, 54.28388714790344, 53.47764641046524, 50.841868445277214, 48.671599701046944, 42.06543758511543, 40.06563149392605, 40.96732310950756, 39.040009528398514, 39.220518842339516, 38.67856152355671, 46.544808223843575, 52.54081428050995, 52.891588658094406, 50.058696269989014, 46.7826222628355, 50.186339020729065, 51.70363940298557, 53.661803528666496, 50.569016486406326, 55.72948157787323, 52.73454308509827, 52.95304276049137, 52.27937310934067, 50.44841095805168, 47.48682327568531, 43.87126408517361, 37.66357518732548, 39.781885519623756, 41.21461383998394, 45.36163531243801, 46.53970129787922, 53.04146781563759, 53.48122201859951, 51.19287461042404, 47.851136326789856, 52.32377752661705, 51.98078133165836, 53.58164303004742, 51.663319766521454, 42.482408210635185, 33.295758962631226, 12.785951010882854, 12.822392955422401, 15.230166055262089, 17.249098420143127, 17.07504875957966, 14.691643752157688, 6.210718285292387, 3.84582897182554, 0.9803823055699468, 0.9606237220577896, 0.1346157625084743, 2.955845477990806, 14.072485975921154, 18.63831527531147, 29.749867133796215, 35.14441296458244, 46.79040044546127, 38.4770355373621, 13.566914554685354, 1.7250563716515899, 0.20283268560888246, 0.1909892406547442, 0.1581042614998296, 0.12132397183449939, 0.2586135291494429, 0.10116693665622734, 0.1600846677320078, 0.08698242396349087, 0.08399428508710116, 0.14901310089044273, 0.1933905782061629, 0.20484034350374714, 0.14981902873842046, 0.10292175968061201, 0.18540895805926993, 0.21412928646896034, 0.150923908513505, 0.16529475222341716, 0.10239642302622087, 0.10182199330301955, 0.10738637167378329, 0.10231840846245177, 0.11938407944398932, 0.14134989178273827], [0.035358872773940675, 0.01935497948579723, 0.036279996784287505, 0.05400126989115961, 0.014015590604685713, 0.007183885145423119, 0.08495503978338093, 0.01589006082213018, 0.030078853851591703, 0.017932978153112344, 0.05499411876371596, 0.06975092750508338, 0.05727680545533076, 0.042422519327374175, 0.038251716177910566, 0.05259985016891733, 0.043121195703861304, 0.04457901493879035, 0.1010493136709556, 0.07984776500961743, 0.07818127982318401, 0.1109052351966966, 0.021543563707382418, 0.06858424909296446, 0.08931331685744226, 0.016453018797619734, 0.04806251512491144, 0.03400993773539085, 0.02470934861776186, 0.0444879756832961, 2.3460397124290466, 17.998112328350544, 43.898102045059204, 38.22019971907139, 25.26180826127529, 21.383477970957756, 19.67703703790903, 9.204023815691471, 0.9603403403889388, 0.5069031310267746, 0.6671167840249836, 0.8042545721400529, 3.181424648500979, 0.3702511824667454, 5.933592980727553, 1.7762275133281946, 0.6685142184142023, 7.943212520331144, 26.98010265827179, 42.43796959519386, 52.412962540984154, 54.17226813733578, 52.39372417330742, 52.85811245441437, 54.12326216697693, 50.3257991373539, 50.16212671995163, 42.33646184206009, 40.769144743680954, 42.44212657213211, 45.59861719608307, 49.44873780012131, 49.530156031250954, 51.937478855252266, 49.455862417817116, 46.80054970085621, 40.69276504218578, 39.48018170893192, 39.85780544579029, 40.467315539717674, 44.785650819540024, 44.68399107456207, 49.346211701631546, 49.3564597517252, 51.29878632724285, 48.001501858234406, 46.24573767185211, 38.18583056330681, 36.8474093824625, 36.37761779129505, 38.09754990041256, 40.37277661263943, 46.40519231557846, 44.52310010790825, 50.21704137325287, 46.81999705731869, 57.065972462296486, 44.94013153016567, 50.505274906754494, 40.275273844599724, 38.19475248456001, 51.9638342410326, 43.404618725180626, 50.86438983678818, 43.003060072660446, 43.35427522659302, 38.68734285235405, 37.13286146521568, 31.58615279942751, 35.82606598734856, 33.80671374499798, 47.41105914115906, 48.92198346555233, 50.61397187411785, 45.33519633114338, 47.283963561058044, 49.08339120447636, 49.16336931288242, 47.607121020555496, 45.63533082604408, 45.19650377333164, 44.894883558154106, 43.662336096167564, 44.64060500264168, 39.948122799396515, 37.707888409495354, 36.098883748054504, 35.57217501103878, 37.44324781000614, 36.620367765426636, 39.26051549613476, 46.03998251259327, 47.85783916711807, 49.993054792284966, 51.17292948067188, 51.50650218129158, 47.236868888139725, 53.017745688557625, 46.91335044801235, 45.62981732189655, 32.390389144420624, 15.429320018738508, 6.611564476042986, 2.8194114239886403, 1.4485244289971888, 2.054156712256372, 3.082607388496399, 0.3226246271515265, 0.20171087002381682, 0.09988981182686985, 0.053488998746615835, 0.10877627326408401, 0.2707246073987335, 1.4344634022563696, 11.231462974101305, 16.054735109210014, 26.840471550822258, 35.27758061885834, 36.30772054195404, 20.45074962079525, 3.593882778659463, 0.2138993691187352, 0.033708291812217794, 0.07803887652698904, 0.038846733077662066, 0.05146654984855559, 0.0014057437761039182, 0.05550659028813243, 0.05931762992986478, 0.004627428061212413, 0.03604339268349577, 0.012878288252977654, 0.03215412325516809, 0.06186911879922263, 0.08077890059212223, 0.08404434294789098, 0.038914105243748054, 0.057577601619414054, 0.04554607417958323, 0.03493177049676888, 0.04028586503409315, 0.0809981235943269, 0.017431258493161295, 0.03103258968621958, 0.059872522615478374, 0.026513800912653096, 0.06456278832047246, 0.03970860030676704, 0.057774378365138546, 0.02456524580338737, 0.021841105553903617, 0.024956370616564527, 0.03231533628422767, 0.05932224237767514, 0.006591321971427533, 0.047763333132024854, 0.02457808681356255, 0.06283271592110395, 0.024202157474064734, 0.0432639923383249, 0.007830343547539087, 0.03395124127564486, 0.07920627482235432, 0.03738735533261206, 0.02450769410643261, 0.0173179640842136, 0.005682412784153712, 0.027104602413601242, 0.05342049851606134, 0.04256949796399567, 0.04011935678136069, 0.024677050350874197, 0.03708439580805134, 0.04860835360886995, 0.05357868729333859, 0.13209149561589584, 3.9463103050366044, 24.70907662063837, 51.28937043249607, 41.389149874448776, 25.28864812105894, 23.737717643380165, 19.251000098884106, 7.8087367862463, 0.7731326390057802, 0.3077362244948745, 0.3408677747938782, 1.2199131399393082, 3.488614889793098, 1.056182300671935, 6.31997287273407, 2.0446208864450455, 3.060036124661565, 9.978382363915443, 29.667681343853474, 44.943228363990784, 52.69938737154007, 53.68459850549698, 55.70538707077503, 53.84658381342888, 57.413471415638924, 50.834949016571045, 52.52273105084896, 44.02589298784733, 41.82840630412102, 43.41962791979313, 48.371469005942345, 50.475013330578804, 53.13926696777344, 53.049397990107536, 51.5503404289484, 48.5048608481884, 42.34249211847782, 40.59336997568607, 42.29970641434193, 42.56322227418423, 45.53672231733799, 46.83239959180355, 50.83493761718273, 50.88356360793114, 53.7034796923399, 49.93839852511883, 47.81892165541649, 40.77572979032993, 38.12327452003956, 37.92218171060085, 40.09750798344612, 42.090668231248856, 46.88495837152004, 47.67536535859108, 50.9981806576252, 48.48444074392319, 59.07061189413071, 44.40334193408489, 49.43625167012215, 42.31986813247204, 40.84581322968006, 52.97211393713951, 46.67952239513397, 52.61559046804905, 46.21544189751148, 45.23047395050526, 40.043718069791794, 38.576461002230644, 33.954058438539505, 37.468280866742134, 35.30770540237427, 48.339862301945686, 50.563673973083496, 52.450394332408905, 46.39233760535717, 47.15486168861389, 51.20054639875889, 49.69849079847336, 50.026565194129944, 48.35684359073639, 47.25011497735977, 48.47545422613621, 46.26664035022259, 47.18387693166733, 42.747493386268616, 39.69446741044521, 38.698856234550476, 37.20313109457493, 39.87613186240196, 38.32712598145008, 41.695265248417854, 48.24612893164158, 50.05629099905491, 51.20392441749573, 51.80273048579693, 50.99625036120415, 48.23847234249115, 54.299831092357635, 49.55150328576565, 46.78262986242771, 34.92054037749767, 17.08252865821123, 5.923816580325365, 2.2519420366734266, 2.98670647200197, 1.9113993225619197, 1.5543203707784414, 0.49881431506946683, 0.26169082964770496, 0.1189360003627371, 0.03942766401451081, 0.2521976921707392, 0.20955811691237614, 1.2895476096309721, 11.038763914257288, 20.86543656885624, 28.554753363132477, 37.75372534990311, 41.587408035993576, 24.62539941072464, 6.068998239934444, 0.24902765289880335, 0.0758959844824858, 0.06489332605269738, 0.07316101444303058, 0.05682157578121405, 0.022263432110776193, 0.044563915944308974, 0.11199554661288857, 0.038649807902402245, 0.021625127592415083, 0.030716481160197873, 0.04561563939205371, 0.06519035581732169, 0.07210398092865944, 0.05102374001580756, 0.08288317869300954, 0.03811649316048715, 0.047537297214148566, 0.05202735374041367, 0.048754378585726954, 0.08861937909387052, 0.03789143687754404, 0.02881358112063026, 0.018803068378474563, 0.027885866838914808, 0.11440153000876307, 0.09396756984642707, 0.0988590280758217, 0.20272085879696533, 0.08418808210990392, 0.08040672095376067, 0.15302158892154694, 0.20189706003293395, 0.09420875299838372, 0.136109201121144, 0.19077720906352624, 0.20116225961828604, 0.10950988624244928, 0.09556231903843582, 0.08238888607593253, 0.12824347475543618, 0.18933365761768073, 0.2061886922456324, 0.18976831866893917, 0.13790467899525538, 0.20870724460110068, 0.21821127680595964, 0.11147576122311875, 0.202046706690453, 0.21582205110462382, 0.11244188164710067, 0.14228824846213683, 0.13659916701726615, 0.1298310176935047, 0.31171743117738515, 4.20080378651619, 27.282655723392963, 56.441019997000694, 50.12597545981407, 32.65463836491108, 30.44309053570032, 26.110122241079807, 10.347002483904362, 1.8004349456168711, 1.0837303474545479, 1.243487549945712, 4.21862768009305, 6.786883268505335, 1.7464530235156417, 11.629958041012287, 5.754234530031681, 3.157849763520062, 9.890448432415724, 29.411884769797325, 44.18985798954964, 52.415527403354645, 54.37018811702728, 54.626982137560844, 53.96615579724312, 58.90146777033806, 53.616327568888664, 54.26728963851929, 45.89647941291332, 44.83733184635639, 45.89383855462074, 50.29746025800705, 53.33941362798214, 54.863546043634415, 55.883460715413094, 53.47562871873379, 50.661936700344086, 44.3775375187397, 42.91214995086193, 44.414011761546135, 42.930958941578865, 48.796164616942406, 48.762327432632446, 53.145635426044464, 54.481453746557236, 54.715376794338226, 52.98100546002388, 49.75176393985748, 42.303889989852905, 39.17208284139633, 40.14750950038433, 42.20671400427818, 42.60335572063923, 49.9832209199667, 50.02274639904499, 53.31704042851925, 50.32623611390591, 59.66616153717041, 45.622897893190384, 46.74199864268303, 49.35574159026146, 41.91561922430992, 54.1168899089098, 49.43114094436169, 54.158083498477936, 48.428184762597084, 46.6906064003706, 42.41974197328091, 41.10882371664047, 35.29350936412811, 39.5171195268631, 36.59851513803005, 50.23983255028725, 51.457302421331406, 52.57993698120117, 47.63751558959484, 47.2302458435297, 53.765116184949875, 52.02080458402634, 51.591864600777626, 50.37058733403683, 48.66760611534119, 49.63982954621315, 48.35115149617195, 48.986549600958824, 43.90319377183914, 42.092165350914, 39.340922981500626, 39.028484746813774, 41.992017924785614, 40.11182561516762, 42.70018972456455, 51.33975952863693, 50.673959255218506, 53.36029730737209, 51.81262895464897, 51.5606302767992, 47.7140586823225, 53.85262168943882, 50.237670466303825, 47.874090895056725, 33.77059668302536, 18.51147048175335, 9.106324408203363, 4.359284732490778, 2.883703736588359, 3.9809148106724024, 5.301550095900893, 2.259846800006926, 0.7440095173660666, 0.289078097557649, 0.24518843390978873, 0.7870552700478584, 0.4913900775136426, 3.9540882501751184, 18.466678485274315, 26.30589723587036, 35.532432943582535, 47.12270401418209, 45.587122812867165, 28.369602598249912, 6.827899692580104, 0.4868432355578989, 0.22001617995556444, 0.16718473518267274, 0.12203569145640358, 0.09379020397318527, 0.14680528576718643, 0.10423277097288519, 0.19323257496580482, 0.09238571175956167, 0.14947321760701016, 0.12198975251521915, 0.19174734450643882, 0.23895060847280547, 0.1289308667764999, 0.20213595737004653, 0.27396811929065734, 0.1932478038361296, 0.1605310695595108, 0.1404577263747342, 0.2437821085914038, 0.16258423594990745, 0.17945849220268428, 0.17855587735539302, 0.21653440897352993, 0.13032828632276505], [0.057433387482888065, 0.0393400683242362, 0.06504628268885426, 0.047290280781453475, 0.03617357280745637, 0.02838915985194035, 0.022796082630520687, 0.01638553530938225, 0.08970527473138645, 0.04740353993838653, 0.0021131379526195815, 0.03431286015256774, 0.04215552056848537, 0.022015165159245953, 0.03231809336284641, 0.042801103700185195, 0.023987168424355332, 0.03648175705166068, 0.05002047138987109, 0.06002874841215089, 0.017428275059501175, 0.014625125768361613, 0.054714425568818115, 0.07043697623885237, 0.043421769223641604, 0.016798586875665933, 0.01763661075528944, 0.03683492657728493, 0.017639299185248092, 0.03959666959417518, 0.23357726633548737, 8.454040959477425, 31.056029945611954, 42.99393676221371, 37.14781366288662, 27.80491679906845, 38.148721754550934, 14.913063570857048, 2.487103817984462, 0.11063816593377851, 0.6463375396560878, 0.4844212217722088, 0.37652642698958516, 2.306603528559208, 0.7712464558426291, 4.961407072842121, 2.82567847520113, 1.1653212318196893, 12.526996806263924, 31.54607255011797, 48.50876323878765, 51.38528108596802, 54.50138367712498, 56.99979521334171, 52.76803068816662, 50.36210618913174, 46.354001462459564, 45.15057943761349, 47.1241669356823, 50.69094054400921, 51.62054166197777, 52.22883962094784, 51.6582128405571, 50.92441901564598, 50.7494156062603, 51.47060930728912, 45.8989454805851, 41.55944913625717, 42.39388816058636, 40.294466614723206, 46.52196004986763, 46.096789464354515, 48.24739046394825, 49.23047371208668, 50.911138728260994, 47.45953693985939, 45.16873486340046, 38.85292276740074, 37.59349934756756, 37.43928462266922, 38.91380690038204, 43.71994100511074, 49.30319420993328, 47.79635086655617, 52.08512373268604, 48.37371848523617, 48.64375859498978, 48.15987356007099, 38.37451323866844, 37.7501155436039, 37.78455309569836, 53.717215955257416, 47.21267558634281, 50.29060922563076, 47.42594674229622, 47.39635393023491, 47.83893138170242, 41.775357350707054, 34.0690478682518, 34.628419652581215, 35.68747982382774, 50.74300155043602, 46.021044328808784, 50.840865299105644, 45.26723697781563, 47.95953691005707, 48.84943775832653, 47.106748670339584, 43.679993748664856, 41.512004882097244, 37.846611365675926, 38.18800024688244, 37.05849185585976, 35.682851672172546, 34.17467080056667, 33.95107179880142, 36.054285541176796, 37.17670351266861, 36.37787237763405, 37.897863015532494, 40.531440898776054, 43.33084188401699, 46.18306763470173, 49.988620430231094, 48.75981956720352, 49.45016272366047, 49.38497722148895, 46.880501210689545, 51.72458007931709, 36.09009101986885, 19.600368551909924, 5.246327184140682, 1.7284051794558764, 1.0399245168082416, 1.5933874994516373, 1.244917935691774, 0.433278905111365, 0.21005309972679242, 0.11320639765472151, 0.10989831149345264, 0.030657311581308022, 0.20218649762682617, 0.6081061880104244, 2.75172280613333, 10.483494959771633, 14.633751008659601, 33.39497163891792, 35.28364509344101, 30.53245224058628, 10.24279497563839, 1.6615912271663547, 0.030956313603383023, 0.05064836543169804, 0.06764173638657667, 0.04778064372658264, 0.08511077947332524, 0.016456269404443447, 0.09851957715000026, 0.01619470502191689, 0.022880425858602393, 0.06566666619619355, 0.04066254579811357, 0.0372667711781105, 0.05898523682844825, 0.05275484028970823, 0.06308305717539042, 0.04346980473201256, 0.04062277410412207, 0.00730597354049678, 0.050448842739569955, 0.005916636910114903, 0.06853794649941847, 0.0684451409324538, 0.05328723847924266, 0.0421450896828901, 0.034020684033748694, 0.033590115926926956, 0.02554613682150375, 0.040040462772594765, 0.0872417600476183, 0.045884834908065386, 0.014693672383145895, 0.02568045998486923, 0.016705887064745184, 0.018492329290893395, 0.02089345347485505, 0.012703821394097758, 0.03140375258226413, 0.006104292660893407, 0.05893739427847322, 0.03459793391812127, 0.049024472100427374, 0.04315932725148741, 0.07237425626954064, 0.019987907144241035, 0.04988386426703073, 0.03866363411361817, 0.0536676336923847, 0.04045723064336926, 0.02421155306365108, 0.015576585064991377, 0.01298289118494722, 0.02942126648122212, 0.015664132515667006, 0.014259424151532585, 0.021309499607014004, 0.547933685593307, 11.660308912396431, 36.68907567858696, 50.20109362900257, 37.59857587516308, 24.46688711643219, 30.71624267846346, 17.75352705270052, 2.789341025054455, 0.21551523241214454, 0.8325316454283893, 0.09171739293378778, 1.1623309110291302, 1.022936103399843, 1.570078837685287, 5.643160790205002, 4.004012821242213, 2.757396139204502, 16.498579792678356, 34.39677648246288, 49.69717226922512, 53.06578271090984, 56.47598572075367, 57.48481638729572, 55.53460143506527, 51.45525433123112, 49.91268530488014, 46.75977408885956, 48.81319150328636, 52.95553922653198, 53.357116878032684, 54.4365743547678, 55.295959040522575, 51.85968562960625, 52.796369567513466, 52.84111216664314, 46.64030469954014, 43.05881068110466, 44.20642130076885, 43.27685058116913, 47.789496034383774, 47.306997925043106, 49.20538745820522, 49.6593376994133, 53.413053676486015, 50.53559347987175, 47.26046182215214, 39.330313950777054, 39.300439953804016, 39.12822559475899, 41.457295417785645, 44.58117999136448, 52.14286923408508, 49.570563063025475, 53.941088542342186, 48.74835938215256, 50.39614096283913, 48.55292446911335, 38.8979085534811, 40.732161328196526, 40.336845740675926, 54.617919623851776, 48.934910371899605, 52.52616606652737, 48.807594403624535, 49.34236630797386, 48.51250223815441, 41.661599054932594, 35.7775653898716, 36.00518077611923, 37.43273377418518, 50.61163879930973, 48.79526786506176, 53.41593012213707, 45.64908228814602, 49.49003018438816, 50.43656699359417, 49.38614755868912, 45.13361714780331, 42.86888167262077, 40.79872615635395, 41.28373213112354, 39.20313857495785, 39.121499955654144, 36.8911412358284, 36.25466778874397, 36.97644665837288, 38.79693657159805, 38.63425590097904, 39.50209133327007, 42.29075789451599, 47.862497717142105, 47.88885310292244, 51.498925387859344, 49.61694337427616, 50.104848593473434, 50.13004504144192, 48.993427231907845, 51.5583997964859, 38.16983342170715, 22.345654740929604, 6.830674968659878, 2.969356602989137, 2.2747393883764744, 1.9806799362413585, 1.1039010901004076, 0.5816867400426418, 0.1895012048771605, 0.12206890998641029, 0.08032149271457456, 0.05782234336948022, 0.18441615742631257, 0.5070327396970242, 2.6617977814748883, 16.06023721396923, 18.325540758669376, 37.791309133172035, 41.358895897865295, 35.73488228023052, 14.67502249404788, 2.372789327055216, 0.01746732130413875, 0.0047098509821807966, 0.07365679135546088, 0.0668980524642393, 0.0629153021145612, 0.04670165006245952, 0.09012120397528633, 0.03408501339436043, 0.01829995533626061, 0.0546455542644253, 0.05071017520094756, 0.03276430223195348, 0.01645097047003219, 0.03770857540075667, 0.04067284309712704, 0.032003467276808806, 0.07434157843817957, 0.04858114647504408, 0.04494867869652808, 0.008653934510221006, 0.12444325562682934, 0.027274882631900255, 0.03128461561573204, 0.03843044018140063, 0.05149017240910325, 0.09764324175193906, 0.12424471628037281, 0.17635340569540858, 0.20380610134452581, 0.1415870079654269, 0.123201241804054, 0.13150313578080386, 0.15261115157045424, 0.22360421164194122, 0.11948836603551172, 0.06737414019880816, 0.16017283487599343, 0.08384356973692775, 0.15088408486917615, 0.11821815802250057, 0.1117453389451839, 0.12760746903950348, 0.13710125960642472, 0.1672876562224701, 0.1355951451114379, 0.07957204972626641, 0.16277168761007488, 0.2319028921192512, 0.16158070386154577, 0.2671612298581749, 0.10841570823686197, 0.11502756125992164, 0.15115550311747938, 0.20580093492753804, 0.10242707372526638, 0.5825361725874245, 13.940436411648989, 40.81040292978287, 54.147542864084244, 48.77618528902531, 34.62329752743244, 45.242614299058914, 19.504429399967194, 3.6462518060579896, 0.3985142143210396, 2.6578904036432505, 1.4938144362531602, 1.0338930529542267, 5.368404658511281, 1.7712032329291105, 11.277339812368155, 6.58835532143712, 2.7711530635133386, 15.333191826939583, 35.86507089436054, 51.364758387207985, 53.91592629253864, 56.44827380776405, 59.4177270680666, 57.376693189144135, 53.98042783141136, 51.385794058442116, 50.07285051047802, 50.58019548654556, 55.579393431544304, 57.09234304726124, 57.52611257135868, 55.747648403048515, 55.47342851758003, 53.49714316427708, 55.98167784512043, 48.72908681631088, 45.65708465874195, 46.40507832169533, 44.44088391959667, 50.404432117938995, 49.1223581135273, 50.174179673194885, 52.478349432349205, 55.522977858781815, 51.05429224669933, 48.92677880823612, 41.33938014507294, 41.03639580309391, 40.50973266363144, 43.12219887971878, 47.06166788935661, 53.13435383141041, 51.450930163264275, 55.230469554662704, 52.06539899110794, 48.40722128748894, 51.075259521603584, 40.34010976552963, 43.33452008664608, 43.844714909791946, 55.173693001270294, 53.384205624461174, 53.824191614985466, 50.801753997802734, 51.58684886991978, 51.45642466843128, 46.079956367611885, 37.62022331357002, 38.27163755893707, 40.6493865698576, 53.505012542009354, 49.218200370669365, 54.343323558568954, 46.01869225502014, 49.71194967627525, 52.700147330760956, 50.57611830532551, 47.79950849711895, 44.805014580488205, 42.62207351624966, 42.361130118370056, 41.61631688475609, 39.10470865666866, 38.723482713103294, 37.14890420436859, 39.48930121958256, 39.65628705918789, 39.807218760252, 39.49582926928997, 45.07299140095711, 48.00386533141136, 50.457830652594566, 52.57712513208389, 51.35669142007828, 48.62901158630848, 50.99118523299694, 49.30009737610817, 54.536907970905304, 39.61426891386509, 22.596023306250572, 8.458317629992962, 3.329233154654503, 2.8160174936056137, 3.0319979041814804, 5.343447122722864, 1.8843845534138381, 0.8446132752578706, 0.2591550297802314, 0.3269653004826978, 0.15727345686173066, 0.5960092996247113, 2.2909545432776213, 3.655019598081708, 22.039600163698196, 27.93686091899872, 45.40630951523781, 45.9860710054636, 40.301344245672226, 15.723751969635487, 2.758003156632185, 0.07682832976570353, 0.06927608657861128, 0.1909859009901993, 0.13181793998228386, 0.20044259901624173, 0.085562146268785, 0.18244781851535663, 0.1348965021315962, 0.09144665746134706, 0.21507742465473711, 0.18903176678577438, 0.15460263064596802, 0.07851215152186342, 0.13739610003540292, 0.12034104176564142, 0.17827415809733793, 0.174790843448136, 0.11779129694332369, 0.12967587914317846, 0.1316234824480489, 0.21462423959746957, 0.13588623027317226, 0.10651506061549298, 0.11697446694597602, 0.1386206882307306], [0.10159432466025464, 0.06040639396815095, 0.07081724528688937, 0.01919824531796621, 0.049086211365647614, 0.02187223308283137, 0.024050262109085452, 0.0413853456848301, 0.017046466055035125, 0.01857935723819537, 0.022747917246306315, 0.015985966711014044, 0.005766803324149805, 0.005605311062026885, 0.05680845832102932, 0.05089219062938355, 0.09172946767648682, 0.048416534409625456, 0.05817695637233555, 0.04714997405244503, 0.1003303803736344, 0.03603213430324104, 0.07850711976061575, 0.030791308199695777, 0.019844509370159358, 0.016988422685244586, 0.0778544825152494, 0.03471564967185259, 0.02326949677808443, 0.07073928267345764, 0.0672684064193163, 2.6190913980826735, 19.694318510591984, 40.14956898987293, 35.64063973724842, 40.231283605098724, 36.84476472437382, 14.858684688806534, 4.838174460455775, 0.7538965868297964, 0.08730920642847195, 0.4595985490595922, 1.1131721176207066, 0.42370059876702726, 1.7155906045809388, 2.034991253167391, 2.478284016251564, 1.3205544208176434, 3.422834719531238, 16.016474962234497, 36.50967210531235, 49.365317076444626, 59.68157351016998, 57.12662100791931, 54.19367998838425, 51.080260053277016, 48.83805736899376, 48.745072558522224, 52.7343986928463, 51.97545401751995, 55.88517062366009, 48.685012981295586, 48.46879318356514, 51.214966624975204, 50.692205876111984, 49.78383041918278, 47.01147258281708, 44.22369137406349, 43.61184820532799, 42.126279920339584, 45.69410987198353, 46.89228817820549, 48.58243368566036, 47.83537857234478, 48.59813444316387, 46.108983010053635, 43.56956027448177, 38.474090695381165, 38.23110893368721, 36.439850851893425, 39.568944945931435, 46.082760617136955, 50.388499572873116, 51.0630963742733, 48.89427915215492, 47.43537783622742, 49.35806706547737, 46.88834398984909, 52.67880007624626, 33.38829539716244, 41.444056928157806, 47.03818514943123, 49.09795202314854, 49.219040125608444, 49.87030617892742, 49.475131183862686, 48.783439099788666, 46.214716136455536, 34.55049343407154, 34.31003473699093, 36.16018205881119, 49.18996408581734, 49.19906459748745, 45.019402876496315, 45.324241518974304, 50.0188098102808, 50.98339185118675, 46.98817603290081, 46.82572714984417, 43.250563591718674, 42.15010844171047, 38.86757858097553, 40.044208243489265, 38.471647426486015, 35.27871675789356, 35.8571445196867, 35.7950596511364, 36.692723482847214, 38.82849007844925, 39.31775562465191, 44.196348041296005, 48.1814070045948, 46.92897140979767, 49.83018793165684, 52.88862481713295, 49.83494147658348, 53.93591322004795, 48.64528991281986, 40.962721556425095, 25.55307973176241, 11.66192952543497, 1.3946553133428097, 1.6830997355282307, 1.6468414873816073, 0.6691420753486454, 0.41498529142700136, 0.26724200521130115, 0.0068488499982777284, 0.05032406173995696, 0.12278533482458442, 0.03740491454664152, 0.4635043832240626, 0.4252988880034536, 4.979666043072939, 9.798157084733248, 21.96005903184414, 29.669847227633, 29.824721217155457, 22.51700084656477, 5.0787746999412775, 0.2247392968274653, 0.05665342367137782, 0.04137775722483639, 0.002757052411652694, 0.08531383107765578, 0.042867388619924895, 0.057517780805937946, 0.020486747271206696, 0.06264329014811665, 0.05313643778208643, 0.041135364372166805, 0.10175695148063824, 0.06200390023877844, 0.00396574171645625, 0.03893703018547967, 0.018402414389129262, 0.037658510118490085, 0.004941772131132893, 0.03639351940364577, 0.03962763941672165, 0.04981976126146037, 0.0499643872899469, 0.04235719177813735, 0.06203132259543054, 0.053867653623456135, 0.07282490318175405, 0.023240653208631556, 0.0705797654518392, 0.04882143533905037, 0.049807037139544263, 0.008544203337805811, 0.061540005990536883, 0.01008772393106483, 0.05521242150280159, 0.017686021092231385, 0.030188166638254188, 0.07389958496787585, 0.033668241812847555, 0.05539157966268249, 0.04674712887208443, 0.018799385470629204, 0.049244771216763183, 0.012018696634186199, 0.04694742339779623, 0.04926963316393085, 0.04848493816098198, 0.066123413562309, 0.06336841295706108, 0.027605143914115615, 0.037814272072864696, 0.018700726213864982, 0.04137189425819088, 0.02477103964338312, 0.035931729144067504, 0.11042216385249048, 0.04642214611521922, 0.05724524562538136, 4.2935349605977535, 25.663714595139027, 44.44985143840313, 39.297240525484085, 37.668476924300194, 42.61539347469807, 21.694781966507435, 6.6435435600578785, 0.8935536397621036, 0.1374416975886561, 0.44163786282297224, 0.6697390589397401, 0.6106796592939645, 0.4863526759436354, 3.2471820199862123, 2.3159401025623083, 1.9046293920837343, 4.624171843752265, 18.78505390137434, 39.20096889138222, 51.69584982097149, 60.31162530183792, 57.30992317199707, 55.01622565090656, 51.9726649671793, 49.78962130844593, 50.80279514193535, 53.03612910211086, 53.9622800052166, 56.571242809295654, 50.67533478140831, 50.85622027516365, 51.67718142271042, 52.94115699827671, 52.04667739570141, 48.6649614572525, 45.4051049798727, 45.34906558692455, 44.12528045475483, 47.53627382218838, 48.89918848872185, 49.273415207862854, 50.22635467350483, 51.60535387694836, 47.64047183096409, 45.148295760154724, 39.8246256262064, 39.080253168940544, 38.73565346002579, 42.33540549874306, 47.43779830634594, 51.43421486020088, 51.4958855509758, 51.878471821546555, 49.890897274017334, 48.75274054706097, 46.27104431390762, 52.88404606282711, 36.34494334459305, 42.178014144301414, 49.6229812502861, 50.57864896953106, 50.80424666404724, 52.64390654861927, 51.44881747663021, 48.78222696483135, 46.29217877984047, 35.922759398818016, 36.2466312199831, 38.926783204078674, 51.743867844343185, 50.61282813549042, 47.206048741936684, 47.780904695391655, 52.31474541127682, 50.44781818985939, 48.31576779484749, 47.72368736565113, 43.94373759627342, 41.58699385821819, 40.752509236335754, 39.54956218600273, 39.09595772624016, 36.937871128320694, 36.85899496078491, 37.78291158378124, 39.055641889572144, 40.93106925487518, 41.48748479783535, 44.9946054071188, 49.52104791998863, 49.47776064276695, 51.05188697576523, 53.007619231939316, 50.048338025808334, 54.20400023460388, 50.35620130598545, 42.08785258233547, 28.723631501197815, 10.916866455227137, 2.4676156137138605, 2.4813606636598706, 3.312089662067592, 3.285743063315749, 0.4894446115940809, 0.5291400721762329, 0.01873915462056175, 0.03447064074862283, 0.13779491535387933, 0.06064366600185167, 1.0168620105832815, 0.2668740483932197, 6.939837411046028, 13.633499331772327, 22.356744445860386, 33.54700148105621, 34.4269772619009, 27.355300225317478, 6.75214315764606, 0.6100428372155875, 0.008426722288277233, 0.002882896537812485, 0.04819183064682875, 0.020771702293131966, 0.052154290679027326, 0.04559257344226353, 0.06324094909359701, 0.07792380652972497, 0.03831253889075015, 0.0845429919718299, 0.08626305279904045, 0.060610287910094485, 0.02463245840772288, 0.04762702286825515, 0.023371523529931437, 0.058993548882426694, 0.06189117542817257, 0.0868438056204468, 0.06581754481885582, 0.055257391941268, 0.036305645407992415, 0.027734650539059658, 0.016027716228563804, 0.016880315888556652, 0.04543215822195634, 0.20874455978628248, 0.14769648638321087, 0.11223741254070774, 0.22249382513109595, 0.14438681944739074, 0.09503025110461749, 0.12624819588381797, 0.1244211544690188, 0.08134385308949277, 0.13576383527833968, 0.1394563019857742, 0.08733050606679171, 0.113618207979016, 0.1821596871013753, 0.15246156428474933, 0.15143127035116777, 0.19804310199106112, 0.14076061168452725, 0.14203177706804127, 0.20319552160799503, 0.19632691517472267, 0.2072924142703414, 0.15154146443819627, 0.12772288784617558, 0.1284421031596139, 0.13349431799724698, 0.18292432185262442, 0.19371336791664362, 0.17780667927581817, 0.1466549711767584, 0.12407953647198156, 4.936453811824322, 28.571996837854385, 53.40128570795059, 47.064696326851845, 48.75230357050896, 47.03003078699112, 24.001345597207546, 6.5977066196501255, 1.7898934800177813, 0.3306658269139007, 1.6381311672739685, 2.761281905695796, 1.5579428826458752, 6.14108607172966, 7.984632197767496, 6.271026749163866, 3.9056508243083954, 5.829197382554412, 18.319065906107426, 39.03288871049881, 51.51096314191818, 62.86574184894562, 60.01738429069519, 57.810785695910454, 54.15002033114433, 55.239319279789925, 52.623577639460564, 56.49660721421242, 55.580947548151016, 60.25650165975094, 50.520926266908646, 51.689336970448494, 55.97594015300274, 54.91125248372555, 54.639468267560005, 50.40645360946655, 47.79892712831497, 47.816911563277245, 44.34355974197388, 51.12116865813732, 51.22123248875141, 52.72553376853466, 50.84301978349686, 53.1697641313076, 50.2074658870697, 47.02163323760033, 40.740281492471695, 41.54858931899071, 40.80131761729717, 43.72871473431587, 48.42385679483414, 54.215202033519745, 54.3183246999979, 53.63121896982193, 48.74518275260925, 50.17348051071167, 45.71734942495823, 51.542642042040825, 39.28752064704895, 45.91110862791538, 47.42160737514496, 51.366730481386185, 53.69649566709995, 54.26204591989517, 53.88753041625023, 50.978934690356255, 49.42508786916733, 36.85661628842354, 38.26275743544102, 40.88849253952503, 54.60772857069969, 53.082547411322594, 48.24000746011734, 48.981260284781456, 52.50665411353111, 53.04758548736572, 51.33024103939533, 50.44128254055977, 47.23520837724209, 45.79979360103607, 43.43209125101566, 43.711300268769264, 44.03571166098118, 38.05824100971222, 38.40309910476208, 39.71124351024628, 40.68018011748791, 43.66084657609463, 43.34147751331329, 48.27051222324371, 52.63700991868973, 51.06542944908142, 53.110168129205704, 55.45665621757507, 49.711729288101196, 54.11838702857494, 51.034347116947174, 43.38241271674633, 32.65523113310337, 14.947402328252792, 3.4943765681236982, 4.108188031241298, 2.9617076134309173, 3.1690183142200112, 1.0326957609504461, 0.7698762731160969, 0.21795841224957258, 0.14622016169596463, 0.3078663971973583, 0.14706871850648895, 2.917936099693179, 1.8427949538454413, 6.865544747561216, 20.36763098090887, 30.331082046031952, 43.642330169677734, 40.46146385371685, 30.163739025592804, 7.622780939564109, 0.555510122794658, 0.15807944408152252, 0.13427648227661848, 0.1448445612913929, 0.12651499797357246, 0.21762389660580084, 0.14083568734349683, 0.13101354095852003, 0.16395539831137285, 0.14432254945859313, 0.08965431887190789, 0.18937851302325726, 0.28649402840528637, 0.137162457103841, 0.16732084506656975, 0.1594796689460054, 0.1675318376510404, 0.13916860101744533, 0.18678265856578946, 0.13510654476704076, 0.10760176519397646, 0.13258530583698303, 0.09704607262392528, 0.22160643915412948, 0.15137583191972226, 0.13843709573848173], [0.014689314120914787, 0.02701613469980657, 0.08625459231552668, 0.027917445222556125, 0.02204486034315778, 0.0358619487087708, 0.026029605214716867, 0.032028288405854255, 0.04370780035969801, 0.04338560807809699, 0.06177873263368383, 0.07625463476870209, 0.030330477165989578, 0.012639096839848207, 0.0485314782417845, 0.018681139081309084, 0.02293765101057943, 0.05953490108367987, 0.02187029236665694, 0.03433230442169588, 0.0850078287476208, 0.05778721380920615, 0.06097219622461125, 0.09070847285329364, 0.0609815695497673, 0.05260234007437248, 0.036731545405928046, 0.028952889661013614, 0.04923455184325576, 0.03162805187457707, 0.0447880185674876, 0.2687186119146645, 8.207418043166399, 41.48061856627464, 40.04082642495632, 32.449171990156174, 15.744592901319265, 16.773242354393005, 11.082666758447886, 2.5701353000476956, 0.05722911133489106, 0.07688263271120377, 0.7231440651230514, 0.08260531860287301, 0.2300613120314665, 1.477887590881437, 0.952320930082351, 0.6665982306003571, 0.5377572379074991, 5.83311022259295, 20.767548121511936, 37.15813770890236, 53.67421366274357, 57.55606636404991, 52.464791759848595, 50.8468309789896, 48.38792972266674, 50.64973555505276, 54.659816175699234, 53.82620170712471, 54.12153705954552, 54.03910428285599, 50.407612547278404, 53.47464457154274, 51.27428524196148, 50.6795297563076, 48.690663278102875, 47.52875782549381, 45.525022745132446, 44.76472154259682, 44.79351259768009, 45.864302739501, 47.66453593969345, 47.14850462973118, 45.11236868798733, 42.3697442561388, 40.50765037536621, 38.13209384679794, 38.468140214681625, 40.2007332444191, 38.5203418135643, 44.168221950531006, 53.744502291083336, 50.21009914577007, 53.386470302939415, 48.82724314928055, 51.30128279328346, 47.37578943371773, 52.99824133515358, 33.11822108924389, 42.34306588768959, 44.496170952916145, 45.3534771502018, 50.42144760489464, 50.89900217950344, 52.21357204020023, 49.688797518610954, 46.67918041348457, 35.72479382157326, 34.18585740029812, 37.89052940905094, 48.99189591407776, 51.773665845394135, 47.416416853666306, 48.15725550055504, 51.02774307131767, 48.362421691417694, 48.096196576952934, 47.29461818933487, 48.15028287470341, 48.084930181503296, 46.910052224993706, 46.45387910306454, 44.01024542748928, 42.32853166759014, 40.04896558821201, 36.53344362974167, 36.49427533149719, 40.03975108265877, 42.1719990670681, 44.22381676733494, 47.588802203536034, 48.775421530008316, 49.42226082086563, 50.353005677461624, 52.037421092391014, 47.52710111439228, 42.657358422875404, 26.739271581172943, 11.365691721439362, 1.3608256098814309, 1.5591742540709674, 3.8149337796494365, 2.4606831232085824, 2.6432471768930554, 0.6305769947357476, 0.3750612790463492, 0.01874111760116648, 0.05843515325977933, 0.1440295940847136, 0.07366260237176903, 0.23895387392258272, 3.0973365856334567, 7.405645865947008, 18.229255825281143, 28.460147939622402, 28.264935314655304, 25.97254492342472, 12.246995531022549, 1.990059851668775, 0.02656858068803558, 0.02933368563390104, 0.093523617106257, 0.07198050239821896, 0.054713898643967696, 0.04627841066394467, 0.023205080215120688, 0.025485271435172763, 0.029091502437950112, 0.01408306481607724, 0.04818206769414246, 0.03998191103164572, 0.02280048171087401, 0.041461297078058124, 0.022077828398323618, 0.01659937588556204, 0.036445362129597925, 0.059759853465948254, 0.06150540335511323, 0.053931801157887094, 0.011486880102893338, 0.0296965030793217, 0.02522509115806315, 0.0230945725706988, 0.05101166527310852, 0.06387753368471749, 0.07536079210694879, 0.0726048118667677, 0.0803065235959366, 0.012109468716516858, 0.021584161040664185, 0.06171627348521724, 0.032580765400780365, 0.03590546082705259, 0.09511441065114923, 0.06387967107002623, 0.055038629070622846, 0.037960000190651044, 0.04346073939814232, 0.06085078086471185, 0.03064637417992344, 0.1517843100009486, 0.012627962769329315, 0.06830178768723272, 0.012935011527588358, 0.013125884488545125, 0.0651665180339478, 0.015741245370008983, 0.04628330883861054, 0.06102794635808095, 0.01054388500051573, 0.013280005368869752, 0.059734401511377655, 0.017546875824336894, 0.07372985579422675, 0.059465306185302325, 0.02975492494442733, 0.30186476767994463, 11.596584431827068, 46.2673395127058, 45.24207852780819, 39.95852664113045, 22.74423625320196, 18.762737698853016, 10.095456931740046, 2.7383278124034405, 0.029280939343152568, 0.2581928204745054, 0.5107602209318429, 0.19907960027921945, 0.5195099639240652, 1.2229022732935846, 0.8680891280528158, 1.219226683024317, 1.3022044929675758, 6.184215657413006, 24.545808881521225, 40.31600385904312, 56.842065677046776, 59.07848887145519, 55.10587804019451, 53.8678664714098, 52.47751347720623, 53.19678448140621, 56.12064018845558, 55.49943432211876, 54.729474037885666, 53.16776543855667, 48.59722249209881, 54.19507451355457, 53.40013436973095, 52.833345383405685, 49.516077786684036, 48.47745291888714, 47.17809744179249, 47.352565079927444, 46.03976972401142, 47.47953526675701, 49.73619617521763, 48.96114036440849, 46.70063026249409, 45.5993277579546, 40.969325602054596, 38.82479667663574, 40.99753908813, 40.58794766664505, 41.287121549248695, 47.80076242983341, 56.25066541135311, 52.49553970992565, 52.914904206991196, 49.02891352772713, 51.62954717874527, 48.54701578617096, 51.80444039404392, 35.500465258955956, 45.217353254556656, 44.430571272969246, 47.05232799053192, 51.67241647839546, 53.29142600297928, 54.4721632450819, 50.554721653461456, 48.60472708940506, 37.05405369400978, 34.952519461512566, 37.89008103311062, 49.36201125383377, 53.13710868358612, 48.15836884081364, 49.607341289520264, 51.97483465075493, 50.28360240161419, 50.06413757801056, 49.38569538295269, 49.77214604616165, 50.76040081679821, 48.35698038339615, 48.28511483967304, 44.661526679992676, 43.08757893741131, 41.349309012293816, 38.336348086595535, 38.78628574311733, 41.46995633840561, 43.396908938884735, 45.88853023946285, 49.3997660279274, 49.777758345007896, 51.00432112812996, 51.54179848730564, 51.025824174284935, 48.64161930978298, 43.12404938042164, 30.90372271835804, 11.948170065879822, 3.0573263950645924, 2.1701481007039547, 6.785438396036625, 3.2813234254717827, 4.263291908428073, 0.8910961216315627, 0.5722771387081593, 0.14714682212797925, 0.12253729422809556, 0.1232263189740479, 0.05588462176092435, 0.2428341782069765, 3.2251562643796206, 9.37736101448536, 17.719528377056122, 30.301483534276485, 32.18146875500679, 31.838977932929993, 15.810525063425303, 3.364607593975961, 0.059761371157946996, 0.05329566927684937, 0.03146657538309228, 0.04665553671657108, 0.05912497581448406, 0.039592417087988, 0.018936936976388097, 0.02881258107663598, 0.04434511225554161, 0.008075320001807995, 0.020771815470652655, 0.0472473401168827, 0.01521428712294437, 0.08210812418838032, 0.02941901962913107, 0.06036647755536251, 0.014456506105489098, 0.0224859669469879, 0.03626016288762912, 0.07021152661764063, 0.02342743508052081, 0.06234010055777617, 0.08085725654382259, 0.040207379206549376, 0.05515052267583087, 0.12957092461874709, 0.20224693813361228, 0.28187326854094863, 0.2664160542190075, 0.24729562865104526, 0.1496312505332753, 0.09233598044374958, 0.18702477682381868, 0.138414682878647, 0.1444403431378305, 0.14861195522826165, 0.23132153815822676, 0.13483067363267764, 0.13427294965367764, 0.15887406159890816, 0.15588814916554838, 0.2617664693389088, 0.13176962616853416, 0.2689922566059977, 0.15732058323919773, 0.09862186736427248, 0.15593005082337186, 0.08656666541355662, 0.19527751835994422, 0.15327289496781304, 0.09306931882747449, 0.09351043656351976, 0.1381700116326101, 0.12572447711136192, 0.1211328168574255, 0.16205319960135967, 0.1363776359357871, 0.8137900417204946, 14.248048905283213, 52.69237294793129, 52.09656871855259, 45.188410207629204, 25.255869179964066, 23.46183344721794, 14.187979828566313, 7.806479232385755, 0.17897222220199183, 0.7859165186528116, 1.9751848373562098, 0.6385417236015201, 1.627472739201039, 7.925388626754284, 6.007371246814728, 1.4517065207473934, 1.7999249417334795, 9.035658650100231, 23.253057450056076, 40.5753855407238, 58.41808430850506, 61.081653982400894, 56.3647048920393, 54.724241718649864, 54.565790221095085, 54.73219469189644, 58.17522034049034, 56.748982071876526, 55.80082654953003, 54.530562311410904, 48.30258250236511, 53.66312585771084, 55.53641393780708, 54.27515521645546, 52.6308960467577, 51.9205317646265, 50.196233689785004, 49.48320955038071, 48.68413522839546, 49.615419656038284, 51.01873755455017, 50.86177557706833, 48.29576566815376, 46.15085296332836, 43.18939447402954, 40.76445959508419, 41.28657437860966, 43.018228858709335, 42.67736814916134, 49.56357143819332, 60.263006910681725, 54.48949411511421, 53.91425438225269, 49.71908949315548, 51.84134781360626, 50.10582514107227, 52.28027746081352, 38.68176095187664, 47.57340542972088, 43.81865590810776, 47.22552269697189, 52.56061501801014, 54.628490656614304, 55.852222591638565, 52.312146350741386, 50.480842217803, 39.39822010695934, 38.12596097588539, 40.151491686701775, 53.45298193395138, 56.64351113140583, 49.882632717490196, 49.826129749417305, 53.38115058839321, 51.87545098364353, 52.0152872800827, 52.65076898038387, 51.62044286727905, 52.774604335427284, 50.734277218580246, 50.07959894835949, 47.30529561638832, 47.297110855579376, 44.54001300036907, 40.189960822463036, 41.04489214718342, 43.18473972380161, 45.722114369273186, 47.691731080412865, 52.23977543413639, 52.127255871891975, 52.94648811221123, 52.3426017165184, 51.70342281460762, 49.11926507949829, 45.79643838107586, 31.23591799288988, 15.781471822410822, 2.625872609205544, 3.4684600587934256, 9.11103805527091, 9.279833547770977, 7.844934593886137, 2.0938168466091156, 1.8211738765239716, 0.2526732307160273, 0.33192970440723, 0.4005576140480116, 0.1963601930765435, 0.7027301948983222, 4.43773627281189, 11.239324752241373, 27.780208624899387, 39.9291618168354, 38.65672409534454, 35.99821574985981, 16.43107071518898, 3.6051104636862874, 0.14802813733695075, 0.2766187145607546, 0.18882714182836935, 0.1505414946586825, 0.18028399790637195, 0.16704797220882028, 0.12312742037465796, 0.09684801567345858, 0.15126820566365495, 0.11491999437566847, 0.1328269936493598, 0.1294667270849459, 0.08039105421630666, 0.2045762279885821, 0.14018341375049204, 0.15833161101909354, 0.13602094491943717, 0.2065608199336566, 0.10134830270544626, 0.16607100900728256, 0.10368437579018064, 0.19669859757414088, 0.14271762542193756, 0.13840049301506951, 0.19771109480643645, 0.24053070024820045], [0.022570779583475087, 0.009196491773764137, 0.047898404009174556, 0.0269016621314222, 0.04820812449906953, 0.05478018727444578, 0.06925224879523739, 0.03723773836100008, 0.03801319733611308, 0.06667036155704409, 0.05833239549247082, 0.03982257934694644, 0.04015980382973794, 0.010281225950166117, 0.023134318289521616, 0.024153500417014584, 0.020785589731531218, 0.1371458626817912, 0.017253454752790276, 0.0948959965899121, 0.011724006490112515, 0.040925930297817104, 0.03498403624689672, 0.028114312881371006, 0.03766030240512919, 0.044298126886133105, 0.03852677094982937, 0.07308488493436016, 0.029270896229718346, 0.06973929062951356, 0.03446957576670684, 0.15227963420329615, 3.1798470206558704, 20.531371794641018, 34.224227741360664, 38.52838598191738, 25.128887593746185, 30.164212100207806, 14.62586073204875, 4.61878658272326, 0.33229495980776846, 0.23097609810065478, 0.29001851740758866, 0.0706788941170089, 0.02800351765472442, 0.23408909590216354, 0.7436001487076283, 1.469933905173093, 0.766108597163111, 0.7837142993230373, 8.023870792239904, 22.623811215162277, 41.16121530532837, 57.16901533305645, 56.8709859251976, 53.82460959255695, 52.53575675189495, 52.12430723011494, 53.78218486905098, 55.14172911643982, 54.72737655043602, 53.86282034218311, 53.617931082844734, 50.26594094932079, 54.19973686337471, 50.63962049782276, 49.507562443614006, 48.281189650297165, 47.33578138053417, 44.32715982198715, 43.54311749339104, 44.05612796545029, 42.5391049683094, 40.650841891765594, 39.245608896017075, 37.348572090268135, 37.360792234539986, 37.96643413603306, 39.615002274513245, 40.05486287176609, 41.410774514079094, 41.965092569589615, 50.75989544391632, 49.82628934085369, 50.50798416137695, 51.74745485186577, 53.4679189324379, 47.06253424286842, 55.2695694565773, 35.31779766082764, 39.6113620698452, 49.00534339249134, 46.738111451268196, 52.731909826397896, 49.95158761739731, 49.56206291913986, 47.984866350889206, 41.56851164996624, 35.135426446795464, 34.831454157829285, 36.60840980708599, 47.6046397536993, 49.45332035422325, 50.517297461628914, 49.79720190167427, 51.46136820316315, 48.97678792476654, 49.026116877794266, 48.01601327955723, 50.014166459441185, 48.72895762324333, 49.34071719646454, 47.44827814400196, 47.969583570957184, 45.56577555835247, 45.05742363631725, 40.52538022398949, 38.73570665717125, 39.100927859544754, 42.2521747648716, 45.00445447862148, 48.039781004190445, 48.6504690349102, 49.04597081243992, 50.34828633069992, 50.340682938694954, 40.84276959300041, 28.397703990340233, 11.771612539887428, 1.8605390517041087, 0.5918061907868832, 1.6826878138817847, 3.2552250009030104, 2.0570070343092084, 2.2325566643849015, 0.42644084547646344, 0.323075081105344, 0.14516803377773613, 0.08842606446705759, 0.03646978992037475, 0.022730706841684878, 0.4616720206104219, 4.070208119228482, 14.540694952011108, 21.79898377507925, 26.706122159957886, 31.30821481347084, 18.740022517740726, 6.478417720645666, 0.3500693669775501, 0.021767248872492928, 0.0563041207351489, 0.03331547304696869, 0.02850502023648005, 0.014514309204969322, 0.04727014631498605, 0.027552492247195914, 0.06597680228878744, 0.01298017585213529, 0.012725519936793717, 0.07933338987641037, 0.026842073239095043, 0.021301951965142507, 0.01597738006239524, 0.012479643628466874, 0.009981484563468257, 0.07436446627252735, 0.08838533540256321, 0.09364859477500431, 0.04237045766785741, 0.03308503619336989, 0.06524407988763414, 0.03968866993091069, 0.03924534801626578, 0.0995866816083435, 0.035444572276901454, 0.08870453311828896, 0.03612943728512619, 0.046842472584103234, 0.029289648446138017, 0.014122096217761282, 0.007845865566196153, 0.06532976825837977, 0.008105452125164447, 0.012914003182231681, 0.08696246019098908, 0.016317890404025093, 0.04416671479702927, 0.05323775578290224, 0.028075572772650048, 0.030488152006000746, 0.059948481430183165, 0.016789636574685574, 0.05001023717341013, 0.03745936592167709, 0.07873027614550665, 0.01687565334577812, 0.04011041019111872, 0.03938553600164596, 0.03937481938919518, 0.10973356213071384, 0.07467945601092651, 0.013732351799262688, 0.10660201805876568, 0.03538530436344445, 0.004153340414632112, 0.05565061517700087, 0.2669543190859258, 4.293119357898831, 26.633335165679455, 39.96339038014412, 41.725245639681816, 25.159139670431614, 26.657879948616028, 18.846403509378433, 7.0942288264632225, 0.34013877797406167, 0.30657235882245004, 0.16959413245785981, 0.29081398097332567, 0.0641723741136957, 0.5498600634746253, 0.3119362163124606, 1.3897951366379857, 1.128123365342617, 1.8891443917527795, 8.337325472384691, 24.14614822715521, 43.75947408378124, 57.29758903384209, 58.87492619454861, 56.13555058836937, 52.89065010845661, 54.11562077701092, 56.050043776631355, 57.45492719113827, 55.53577557206154, 54.46603797376156, 53.47856976091862, 50.652847588062286, 54.322040900588036, 52.597442641854286, 51.83853596448898, 50.892154946923256, 50.379820838570595, 46.65891990065575, 46.58613480627537, 46.87063694000244, 44.54254366457462, 43.33953581750393, 42.982837557792664, 39.86520364880562, 39.275957867503166, 39.20580983161926, 41.691811233758926, 42.16062247753143, 42.29705795645714, 44.85336698591709, 52.833474576473236, 51.07717461884022, 52.837487161159515, 53.832285180687904, 54.139928072690964, 49.18834537267685, 55.98631739616394, 37.451166585087776, 41.39421880245209, 48.48594546318054, 48.22382032871246, 53.5106286406517, 50.98059140145779, 50.717615112662315, 50.62117628753185, 43.79737704992294, 36.64169602096081, 35.875166952610016, 39.08894710242748, 48.59551638364792, 50.63630327582359, 50.89394465088844, 51.54661662876606, 52.02464237809181, 50.437429547309875, 51.10069915652275, 51.42406940460205, 51.02918699383736, 50.5187413841486, 49.73971478641033, 49.227126091718674, 49.013999328017235, 47.64266051352024, 45.7361926138401, 41.33714206516743, 39.6737053245306, 39.985596388578415, 44.021413028240204, 46.07249736785889, 49.46813955903053, 49.572295770049095, 51.522560119628906, 51.28818489611149, 49.12179194390774, 43.148656859993935, 31.70430175960064, 13.445201385766268, 3.4293934050947428, 2.6815203856676817, 3.778894138522446, 6.541619254276156, 5.778965977951884, 2.092572175897658, 0.9047397645190358, 0.38778041373007, 0.2259423182113096, 0.08630736643681303, 0.11952322471188381, 0.05137530650245026, 0.6997014605440199, 4.88261497579515, 16.101915277540684, 25.053872019052505, 31.478206291794777, 36.931688860058784, 22.887186482548714, 8.353576250374317, 0.8441502938512713, 0.01396435365677462, 0.03934525593649596, 0.03205250468454324, 0.034425250996719114, 0.06265052608796395, 0.02636572389747016, 0.0372210697241826, 0.07335107104154304, 0.05149212054675445, 0.02363668732868973, 0.022795069598942064, 0.018528854088799562, 0.07012797563220374, 0.009066814454854466, 0.04473313674679957, 0.006416809656002442, 0.0219830412970623, 0.03090681420871988, 0.01935277530719759, 0.028365145808493253, 0.041001395584316924, 0.025451802430325188, 0.026734630664577708, 0.016395168386225123, 0.08120936108753085, 0.031312486971728504, 0.11556877245311625, 0.08596079089329578, 0.13816017075441778, 0.12322824855800718, 0.1239700400037691, 0.12829230807255954, 0.13572804891737178, 0.15692506305640563, 0.1385696284705773, 0.3114878403721377, 0.13695226603886113, 0.20598316186806187, 0.2212536073056981, 0.09859574376605451, 0.10566853728960268, 0.12362891182419844, 0.14161501661874354, 0.24944592732936144, 0.1888348304782994, 0.1848743445589207, 0.13221991684986278, 0.2286211447790265, 0.07488149829441682, 0.06998980257776566, 0.2630141086410731, 0.209183762781322, 0.10707151552196592, 0.2241141116246581, 0.23794628970790654, 0.12818857067031786, 0.10130686860065907, 0.29342827037908137, 5.408872961997986, 30.338132567703724, 48.6781657487154, 50.83424985408783, 36.27920687198639, 39.24877792596817, 22.80751045793295, 12.257149536162615, 1.5038492227904499, 0.9851390565745533, 1.1264862469397485, 0.7238979090470821, 0.31714725075289607, 1.6305142384953797, 2.2694289358332753, 4.293080409988761, 1.9077859539538622, 1.9851777073927224, 10.00119348987937, 24.83470357954502, 43.991341441869736, 60.725749880075455, 60.32244332134724, 58.4024253487587, 54.972733184695244, 56.28868617117405, 57.15758174657822, 59.67921003699303, 55.2317500859499, 55.005088448524475, 55.140061005949974, 51.687923446297646, 54.48533333837986, 55.91203138232231, 52.697472274303436, 53.41308407485485, 51.156054586172104, 49.40668545663357, 47.275509014725685, 48.24456721544266, 46.64845526218414, 44.52989414334297, 43.40106971561909, 40.2509019523859, 40.46072669327259, 41.981196105480194, 43.75986546278, 42.86008894443512, 43.01431126892567, 45.525474920868874, 54.20146197080612, 54.744205847382545, 53.02780754864216, 56.21158450841904, 54.10669505596161, 49.91833180189133, 54.37754452228546, 39.529506862163544, 43.890255466103554, 50.940689742565155, 50.77829025685787, 55.48825912177563, 53.14734913408756, 53.006418496370316, 52.78450660407543, 45.65083019435406, 37.433801516890526, 38.22116866707802, 40.309464409947395, 51.28705255687237, 52.82763808965683, 52.765952199697495, 52.18014523386955, 52.77922488749027, 52.87001721560955, 52.20755696296692, 53.1461787968874, 53.04322712123394, 51.95587366819382, 52.22530961036682, 52.55385138094425, 51.69973321259022, 49.24885332584381, 48.70173968374729, 43.676254749298096, 42.207375168800354, 41.767366379499435, 45.68950071930885, 48.19841869175434, 51.5548849850893, 51.72131225466728, 52.503390088677406, 52.06702150404453, 50.61095103621483, 44.03956085443497, 33.34485612809658, 13.243768494576216, 3.0466240318492055, 2.113824672996998, 5.57688569650054, 8.912081681191921, 8.377026692032814, 4.93261031806469, 1.566496342420578, 0.9633988793939352, 0.5157103459350765, 0.2001102949725464, 0.189162741007749, 0.11903004531632178, 1.0855424939654768, 5.938836699351668, 21.42122894525528, 32.375828325748444, 38.44113126397133, 43.14820848405361, 26.600981801748276, 10.060894936323166, 1.0882557858712971, 0.2403900187346153, 0.1395305315963924, 0.13378991541685537, 0.1856262143701315, 0.13090912078041583, 0.12244343481143005, 0.10815816815011203, 0.13694908964680508, 0.1067140007216949, 0.11690071230987087, 0.13181231450289488, 0.15971491491654888, 0.1992247049929574, 0.09322249810793437, 0.10288573583238758, 0.10485762963071465, 0.20037910086102784, 0.19034030672628433, 0.19847571471473202, 0.1425709028262645, 0.10164356615860015, 0.16069735516794026, 0.14204890583641827, 0.12175955314887688, 0.2306874917121604, 0.11403356576920487], [0.0775929051451385, 0.04364737469586544, 0.04336333251558244, 0.10243595723295584, 0.05213430093135685, 0.018311165476916358, 0.07152698337449692, 0.09067879436770454, 0.08217625334509648, 0.02449764357152162, 0.11574622738407925, 0.010277371420670534, 0.039452366399927996, 0.04430997898452915, 0.009969308703148272, 0.06704687533783726, 0.036360913145472296, 0.01421192113411962, 0.034407680650474504, 0.02014844852965325, 0.018728790528257377, 0.014061338442843407, 0.029598422697745264, 0.01749361188558396, 0.021005530761613045, 0.07875877461628988, 0.06707328837364912, 0.06444358456064947, 0.08656239064293914, 0.012602440310729435, 0.02392995997070102, 0.040208043428719975, 0.6564714177511632, 11.512316353619099, 27.09008015692234, 38.63030031323433, 28.73440582305193, 23.987736627459526, 13.672742675989866, 6.246275352314115, 2.052197204902768, 0.07210820374893956, 0.05594721449597273, 0.04007932533568237, 0.13372707035159692, 0.12101053318474442, 0.21081886254251003, 1.0842435574159026, 1.762182991951704, 0.3102143743308261, 2.0936662796884775, 11.70167539268732, 27.402117513120174, 44.09818410873413, 55.60629218816757, 55.59051923453808, 54.359358698129654, 54.17765624821186, 56.72979310154915, 55.83769977092743, 56.64872445166111, 54.37697075307369, 53.99247318506241, 53.329515159130096, 52.69861601293087, 52.1301095187664, 52.08265386521816, 51.20987109839916, 46.74680158495903, 45.05629509687424, 45.295549258589745, 42.73188762366772, 40.38783140480518, 41.19138948619366, 40.66317982971668, 38.42236787080765, 39.658658131957054, 40.23496560752392, 39.414145052433014, 38.39922331273556, 38.908578380942345, 38.04033637046814, 45.43681047856808, 48.147501423954964, 50.671189203858376, 48.92693839967251, 52.425038293004036, 51.90204195678234, 55.8431638777256, 37.73307725787163, 39.17161546647549, 49.27021957933903, 50.66650405526161, 51.53813548386097, 48.32899108529091, 48.99102956056595, 45.64608804881573, 37.25382037460804, 34.771299585700035, 35.595125779509544, 36.30336597561836, 46.975488513708115, 49.755350947380066, 50.61407446861267, 50.90370252728462, 46.50413900613785, 47.62648098170757, 47.903083339333534, 48.66562262177467, 49.60247375071049, 50.7292614877224, 50.84672838449478, 49.756566882133484, 48.05923216044903, 47.726168632507324, 46.07478104531765, 43.73579755425453, 39.62078556418419, 40.51037862896919, 43.82448859512806, 47.414212971925735, 47.06134110689163, 48.48371118307114, 50.73059901595116, 51.174852177500725, 43.771686628460884, 28.326284922659397, 11.114637292921543, 4.09377540461719, 0.6726196606177837, 2.976831514388323, 1.6570936935022473, 6.782978503033519, 2.0124176144599915, 2.7157774474471807, 0.8320257382001728, 0.24192083190428093, 0.5486029840540141, 0.30569956346880645, 0.1088238375086803, 0.37227460357826203, 2.7315644128248096, 9.830253012478352, 18.31456884741783, 23.919066712260246, 30.169879496097565, 26.428415961563587, 14.318733662366867, 3.239618525840342, 0.09011392350657843, 0.07303865655558184, 0.1271350623574108, 0.07083767661242746, 0.03385889212950133, 0.02796065677102888, 0.05331407824996859, 0.009997398065024754, 0.04510028462391347, 0.03180182946380228, 0.01716148039122345, 0.06701271428028122, 0.015664117672713473, 0.059555863044806756, 0.0891494654933922, 0.026592501963023096, 0.09889781271340325, 0.059590588134597056, 0.051465306751197204, 0.016816999559523538, 0.03849761938909069, 0.0952247680106666, 0.08338402447407134, 0.038501678936881945, 0.016336805892933626, 0.018167109046771657, 0.02147539002180565, 0.016428327544417698, 0.028070889820810407, 0.12243721561389975, 0.08967011177446693, 0.07467334813554771, 0.04007652372820303, 0.09739145330968313, 0.030639104843430687, 0.0645554781658575, 0.04859750340983737, 0.07695106614846736, 0.04608127026585862, 0.029711290371778887, 0.045638723895535804, 0.03047078203962883, 0.07914332585642114, 0.050825419602915645, 0.020616569308913313, 0.012603248324012384, 0.05074449953099247, 0.023096242402971257, 0.05519371938135009, 0.01277400351682445, 0.01586309303093003, 0.039600977761438116, 0.06164080819871742, 0.04560739042062778, 0.03218845129595138, 0.11027838016161695, 0.06909427524078637, 0.023303171728912275, 0.016655671497574076, 1.0566272330470383, 14.108450096100569, 33.34291823208332, 46.20544083416462, 31.789920665323734, 30.392209365963936, 14.503071270883083, 6.912206718698144, 2.275862228125334, 0.11869944821228273, 0.254419504199177, 0.18111352605046704, 0.0800548613187857, 0.07475989739759825, 0.09673721302533522, 0.2921452751616016, 1.0550421243533492, 1.2687624874524772, 2.193823680281639, 12.422777898609638, 31.08704198151827, 47.64308609068394, 58.5259985178709, 57.65393391251564, 55.66525362432003, 55.965775698423386, 56.97374381124973, 56.69250190258026, 58.99318724870682, 55.749327912926674, 54.325555711984634, 53.677177503705025, 53.71015593409538, 53.436008244752884, 54.46828745305538, 53.011905401945114, 48.47637377679348, 46.88032642006874, 45.24295628070831, 44.13184270262718, 42.408369183540344, 43.121188133955, 42.5828368216753, 40.48696808516979, 40.986759066581726, 41.77235551178455, 41.02617435157299, 40.79543173313141, 41.28380812704563, 40.80063745379448, 47.984737157821655, 51.88733294606209, 52.645487263798714, 50.729440078139305, 54.78945381939411, 52.72060923278332, 55.7616126537323, 41.82877488434315, 40.38676366209984, 52.16498404741287, 51.98512449860573, 52.63350650668144, 51.228995472192764, 51.50327615439892, 47.18643419444561, 37.973505556583405, 35.094198659062386, 37.29425020515919, 38.883222341537476, 49.18002761900425, 52.35425189137459, 51.547376587986946, 51.84797465801239, 50.06574109196663, 49.7762194275856, 50.6658960878849, 50.471506118774414, 51.91151104867458, 52.50368267297745, 52.661643996834755, 50.40759734809399, 50.91930449008942, 48.684591203927994, 48.36445838212967, 44.18738432228565, 40.85157372057438, 41.53628557920456, 46.4324064552784, 48.37343730032444, 48.12332332134247, 49.651160538196564, 53.58685255050659, 49.92907762527466, 47.32562452554703, 28.89204416424036, 13.053728342056274, 3.1925131659954786, 2.306028096936643, 3.7350627779960632, 5.611725552007556, 4.949531285092235, 4.67411351390183, 3.2362887170165777, 1.4460938656702638, 2.120245140977204, 0.8345402532722801, 0.6072374596260488, 0.2975840895669535, 0.28443866525776684, 2.4525812454521656, 10.331748202443123, 21.276646703481674, 28.314022980630398, 34.35517631471157, 32.93429955840111, 17.284337729215622, 4.425443932414055, 0.2383653211290948, 0.09172471050987951, 0.11129447681014426, 0.0634567582164891, 0.018106364259438124, 0.021729113614128437, 0.06764058605767787, 0.03126235489617102, 0.03561162229743786, 0.022138638123578858, 0.03042592292331392, 0.04001836903626099, 0.07368400591076352, 0.006559937473866739, 0.04528386598394718, 0.045409760205075145, 0.05337176909961272, 0.029167648644943256, 0.07045372651191428, 0.06091501003538724, 0.02870881769922562, 0.03220909413357731, 0.07346669022808783, 0.029791494271194097, 0.04788537560671102, 0.03547108921338804, 0.1007753869635053, 0.20133685728069395, 0.1072508555080276, 0.19314700533868745, 0.34132600645534694, 0.2200240021920763, 0.19796139153186232, 0.1627309585455805, 0.1495104585774243, 0.24967447912786156, 0.17631448747124523, 0.22381977585610002, 0.18472947733243927, 0.15190145059023052, 0.09626888815546408, 0.15988359024049714, 0.2403083528042771, 0.12467190390452743, 0.12744332081638277, 0.1012266127509065, 0.21240095811663195, 0.08445729617960751, 0.14149526366963983, 0.10433358431328088, 0.06498599803308025, 0.180608969531022, 0.26946681551635265, 0.11045834355172701, 0.09716750282677822, 0.22533237672178075, 0.19157095084665343, 0.12380946151097305, 0.09720273257698864, 1.5197900799103081, 15.719967372715473, 40.24505026638508, 55.80247566103935, 40.65403372049332, 36.55903905630112, 20.322145521640778, 13.219077419489622, 5.554945673793554, 0.5734123871661723, 0.4208899074001238, 0.2589555404847488, 0.43258698598947376, 0.4155824234476313, 0.423633775790222, 3.6483077332377434, 4.138968279585242, 1.8021279922686517, 3.2431587483733892, 13.791296314448118, 31.500013321638107, 48.89489471912384, 59.91567134857178, 60.10421723127365, 56.97747901082039, 57.919117882847786, 60.65611481666565, 58.91494944691658, 60.04413105547428, 57.50148229300976, 55.406320318579674, 54.7379057854414, 54.689975157380104, 54.45211932063103, 56.741177290678024, 55.62054522335529, 51.94080747663975, 49.64015632867813, 48.02647791802883, 46.91267028450966, 43.764064237475395, 45.00998318195343, 45.50873301923275, 41.53921902179718, 43.26320931315422, 43.59962426126003, 43.243131190538406, 41.77907735109329, 42.215343341231346, 41.585185155272484, 48.7317618727684, 53.67679752409458, 54.64235991239548, 52.00616776943207, 57.61737607419491, 54.89498935639858, 55.71734502911568, 44.80026103556156, 42.88802124559879, 52.84353643655777, 52.84400761127472, 56.32125422358513, 55.40678009390831, 53.280524387955666, 48.69705073535442, 39.90379437804222, 37.383815199136734, 40.724880918860435, 39.82852801680565, 50.035502314567566, 55.13847269117832, 53.24021615087986, 54.49087344110012, 50.13688087463379, 52.338950112462044, 51.79505489766598, 53.046061769127846, 53.66092957556248, 53.64132642745972, 53.87293919920921, 52.94355846941471, 51.904147043824196, 50.97637362778187, 50.75718238949776, 46.64149783551693, 42.23448671400547, 43.63699905574322, 47.26350545883179, 52.64313519001007, 50.46560123562813, 53.036018908023834, 52.807001397013664, 51.00790433585644, 46.1219023168087, 33.43983583152294, 13.188783545047045, 5.789440115913749, 2.7199961710721254, 7.858301801607013, 7.043638341128826, 15.520495176315308, 6.285191914066672, 4.764047563076019, 2.0832645753398538, 1.918785294983536, 2.8317282255738974, 1.4435450336895883, 0.7544801523908973, 0.5598606518469751, 3.167940597049892, 13.043475542217493, 26.12567290663719, 35.284439250826836, 40.989012345671654, 36.58172003924847, 19.491124413907528, 4.439626671373844, 0.3717337263515219, 0.18684682465391234, 0.2564749267185107, 0.23543394170701504, 0.07859284523874521, 0.1421016428503208, 0.20487604080699384, 0.14914048311766237, 0.20544305647490546, 0.0967638635484036, 0.09028349682921544, 0.12706141162198037, 0.12486132967751473, 0.09751334364409558, 0.14511608344037086, 0.12253183202119544, 0.15530385629972443, 0.24570704670622945, 0.1439819482038729, 0.1209233605186455, 0.15765818621730432, 0.1908444328000769, 0.17980278935283422, 0.17294996097916737, 0.18112253572326154, 0.11685397927067243, 0.2220841299276799], [0.04866188101004809, 0.08143380138790235, 0.03786459710681811, 0.016977507548290305, 0.039501080973423086, 0.08077177597442642, 0.0518390708748484, 0.11136691784486175, 0.08116899567539804, 0.06649794580880553, 0.032648185806465335, 0.028996420332987327, 0.021201177587499842, 0.01971495265024714, 0.02611770742078079, 0.06594114209292457, 0.09440978596103378, 0.08219885916332714, 0.057944114960264415, 0.044911378354299814, 0.0435063369513955, 0.010002977160183946, 0.06666768982540816, 0.03188567730830982, 0.06302029374637641, 0.019774409811361693, 0.030828810777165927, 0.03677553992019966, 0.04646353940188419, 0.05404468181950506, 0.05497398800798692, 0.010402892712590983, 0.015810847689863294, 3.111398918554187, 16.789019107818604, 38.32639642059803, 31.564408466219902, 24.546629637479782, 27.19798866659403, 16.817850060760975, 3.8947135861963034, 1.019077766686678, 0.32381259778048843, 0.026473908619664144, 0.05843484526849352, 0.13605708751128986, 0.05474797806527931, 0.339588193455711, 1.3529248838312924, 1.0243890504352748, 1.0394791094586253, 1.5757154789753258, 13.573162369430065, 25.670352838933468, 45.167093351483345, 54.85723838210106, 59.73010070621967, 54.6802818775177, 55.13276159763336, 53.7562170624733, 53.72820496559143, 51.883875131607056, 54.189845994114876, 54.91694077849388, 52.87453517317772, 51.53243578970432, 53.51880960166454, 51.425000354647636, 51.56473785638809, 49.541509822010994, 48.982776403427124, 48.02807383239269, 46.40530250966549, 43.92053224146366, 44.208036214113235, 40.89627832174301, 40.22949010133743, 38.42886932194233, 39.22209195792675, 38.78560557961464, 38.412040024995804, 37.29573592543602, 39.26506385207176, 41.697222143411636, 48.90073120594025, 47.933466508984566, 50.91985926032066, 46.9536092877388, 59.14123870432377, 39.05165210366249, 36.37754939496517, 49.57145981490612, 48.65340627729893, 51.372768357396126, 46.901441887021065, 44.812218993902206, 37.87055768072605, 36.62156470119953, 33.66726502776146, 35.87830938398838, 35.02710185945034, 43.939915001392365, 48.808092176914215, 50.48108920454979, 50.106315314769745, 47.064190953969955, 44.61856998503208, 45.88484823703766, 46.62767797708511, 47.87206180393696, 49.462371468544006, 49.07756991684437, 49.953677505254745, 50.411720126867294, 47.55177699029446, 49.988681226968765, 47.2415616363287, 44.627070128917694, 40.206706523895264, 43.60420301556587, 45.13946123421192, 50.39383448660374, 47.57885813713074, 51.8403484672308, 44.47677679359913, 33.65498788654804, 12.8169896453619, 3.835106184706092, 0.2770282019628212, 1.894631297327578, 4.650189047679305, 5.044243577867746, 3.5409316699951887, 4.663313068449497, 1.4244056981988251, 1.2059230031445622, 0.408740445272997, 0.15862950909649953, 0.2963185199769214, 0.37671377474907786, 0.9834379353560507, 7.539713596925139, 19.07698653638363, 25.008998326957226, 27.307715378701687, 30.90272717177868, 20.05564872175455, 6.475830534473062, 1.0653447965160012, 0.02154685884306673, 0.04140377321164124, 0.03079534919379512, 0.019591865602706093, 0.04153722620685585, 0.006036720578777022, 0.07184863759903237, 0.007220340830826899, 0.028892022419313435, 0.013363605521590216, 0.02981127065140754, 0.026012732487288304, 0.021756331880169455, 0.020521240439848043, 0.05795057906652801, 0.037562183060799725, 0.015486063457501587, 0.056659438778297044, 0.06995955263846554, 0.02310773270437494, 0.0846561323851347, 0.07577223877888173, 0.02325691737496527, 0.08204093013773672, 0.027057600345870014, 0.10758609103504568, 0.025456446419411805, 0.027144448322360404, 0.046687690264661796, 0.030495677383441944, 0.054290811385726556, 0.0662100593035575, 0.02624921969982097, 0.03725235124875326, 0.0977306964341551, 0.05673623993061483, 0.131631423428189, 0.017907581859617494, 0.009540559785818914, 0.03995855564426165, 0.016885750264918897, 0.03858728196064476, 0.0810427192482166, 0.021391089467215352, 0.042252897765138187, 0.023119777761166915, 0.02452528671710752, 0.07388354715658352, 0.020973789105482865, 0.07164920767536387, 0.04420635290443897, 0.02883976965676993, 0.03326102167193312, 0.06954587952350266, 0.004580419035846717, 0.021695633477065712, 0.03285750113718677, 0.08747646425035782, 0.08280501569970511, 0.09779904823517427, 4.749614512547851, 21.315457820892334, 43.87875348329544, 36.15723341703415, 28.57583463191986, 27.937674075365067, 17.173710465431213, 5.821516094729304, 1.1800313112325966, 0.2361218532314524, 0.043232833268120885, 0.044588933742488734, 0.2794272091705352, 0.07554502284619957, 0.21558282722253352, 0.26273984054569155, 0.37393912207335234, 1.5894498419947922, 2.881989791058004, 12.292665280401707, 27.426213920116425, 48.76246802508831, 56.63604453206062, 58.13430413603783, 56.73632115125656, 57.66820974647999, 55.78136779367924, 54.797277599573135, 54.679753705859184, 55.68931773304939, 56.446499302983284, 52.13290996849537, 51.53958700597286, 54.33244474232197, 52.76701234281063, 54.960326850414276, 50.34042455255985, 50.283154025673866, 49.43916991353035, 48.248021230101585, 47.34520107507706, 44.38209347426891, 42.217877805233, 41.26436077058315, 40.74369750916958, 40.50478532910347, 40.90160183608532, 39.846394658088684, 37.145339995622635, 40.954772382974625, 43.140012323856354, 48.791893646121025, 50.606258288025856, 51.460475251078606, 50.10185815393925, 58.48690241575241, 41.32173769176006, 39.510830864310265, 52.69036665558815, 51.12707734107971, 53.873018994927406, 49.14691619575024, 48.708320930600166, 39.6520084887743, 38.24165336787701, 36.0625234991312, 36.368103101849556, 37.31666520237923, 46.06237471103668, 50.87934583425522, 52.58152149617672, 51.143416464328766, 48.03225740790367, 47.23145417869091, 48.46334807574749, 48.04527930915356, 49.61299538612366, 50.62220223248005, 50.46397112309933, 51.146802082657814, 51.904413029551506, 49.698350206017494, 50.245756432414055, 48.351223692297935, 46.4071986079216, 43.08557644486427, 46.883142068982124, 46.95803984999657, 51.795180290937424, 49.90716800093651, 51.88837788999081, 46.18187069892883, 34.62908461689949, 14.995840229094028, 3.046940127387643, 0.9202685812488198, 4.880974413827062, 8.80617281422019, 5.2818728517740965, 4.953978471457958, 3.9473685482516885, 3.1012525130063295, 4.763389248400927, 7.67324460670352, 0.8360536408144981, 0.32862682070117444, 0.3734478203114122, 1.1149194301106036, 7.500620819628239, 20.30216619372368, 26.724866554141045, 32.166311368346214, 36.79285570979118, 25.408997163176537, 9.803090170025826, 1.554062340874225, 0.052626723336288705, 0.030116109664959367, 0.01662787992245285, 0.04806126460607629, 0.037559785923804156, 0.02466772340994794, 0.042564128525555134, 0.031948129035299644, 0.012260845505807083, 0.04292431505746208, 0.013897787648602389, 0.020840452998527326, 0.030617402589996345, 0.025601410125091206, 0.012476940355554689, 0.04997144511435181, 0.050534338151919656, 0.03974501378252171, 0.008998213106679032, 0.049868594578583725, 0.05423685353889596, 0.047695556495455094, 0.032085333587019704, 0.0998814997728914, 0.024037656730797607, 0.03173857621732168, 0.06392977345967665, 0.13493824051693082, 0.19958941120421514, 0.11677970513119362, 0.08932266791816801, 0.24053718661889434, 0.17003907967591658, 0.1525889168260619, 0.235502649738919, 0.19373301998712122, 0.2156394234043546, 0.20079878537217155, 0.13893461669795215, 0.12426117711584084, 0.11925466373213567, 0.13900709484005347, 0.2409622591221705, 0.21513085928745568, 0.15463792718946934, 0.1299360315897502, 0.1460396416950971, 0.18689927965169773, 0.0718586788570974, 0.1933747110888362, 0.15610653354087844, 0.1547890729852952, 0.06299630011199042, 0.14525682432577014, 0.16586656216531992, 0.11752903679735027, 0.12129413749789819, 0.18226444866741076, 0.13925310195190832, 0.2844935841858387, 5.161918513476849, 23.897367976605892, 53.747538328170776, 45.88784247636795, 35.664198473095894, 36.892311573028564, 21.02902729064226, 8.883948940783739, 3.834128687158227, 0.5608933058101684, 0.2565139043144882, 0.2921930991578847, 0.5235202331095934, 0.1719558541662991, 1.0871077724732459, 2.9135361732915044, 4.064390631392598, 1.9277510326355696, 3.094155681319535, 15.625848323106766, 29.842143282294273, 49.12200853228569, 57.683933302760124, 62.193348929286, 58.13138209283352, 59.23470988869667, 58.4337242692709, 56.77643559873104, 55.90715244412422, 57.2762493789196, 56.72785900533199, 53.06941531598568, 51.445485055446625, 55.819833129644394, 53.936027213931084, 56.92068725824356, 53.17693814635277, 52.636861726641655, 52.43130795657635, 51.7320466786623, 49.63091902434826, 47.26200453937054, 44.442343041300774, 44.66653101146221, 41.38869769871235, 43.22171553969383, 42.72596374154091, 41.33813761174679, 38.487443178892136, 42.73243859410286, 45.44205419719219, 51.60191126167774, 52.83405214548111, 55.165675431489944, 51.06865927577019, 59.64435450732708, 44.0770648419857, 44.19693700969219, 54.899845495820045, 53.572603315114975, 54.714818224310875, 51.89942769706249, 48.73625323176384, 41.229642033576965, 39.43703122437, 36.830443292856216, 38.10887709259987, 38.395507112145424, 46.64371311664581, 53.54353107511997, 54.54950049519539, 52.00694292783737, 49.37278367578983, 49.234159514307976, 49.749852642416954, 49.7379706799984, 51.29647225141525, 51.64185471832752, 51.335397362709045, 51.615814715623856, 52.45001055300236, 50.9963795542717, 52.680380791425705, 50.998032465577126, 48.930392414331436, 43.73548977077007, 49.360574930906296, 48.70745077729225, 53.26647274196148, 50.62000975012779, 53.07614475488663, 47.46935561299324, 36.37975327670574, 15.08592864498496, 5.085801472887397, 2.9400148149579763, 4.224769100546837, 11.18659783154726, 11.87745776027441, 10.984324235469103, 10.201034266501665, 4.579706629738212, 3.5920510394498706, 7.943320814520121, 2.048935554921627, 0.8016452996525913, 0.9938094194512814, 2.000859584659338, 9.816987924277782, 22.88120750337839, 34.95089694857597, 37.248071283102036, 41.25324256718159, 28.765210770070553, 9.715217035263777, 1.671775511931628, 0.11513405203004368, 0.1797117872047238, 0.09215417652740143, 0.2022667831624858, 0.1205115056654904, 0.14555487083271146, 0.1444555720081553, 0.13177848741179332, 0.11623002603300847, 0.13909823057474568, 0.12740910780848935, 0.18642788229044527, 0.1285849220585078, 0.09263676547561772, 0.07370157996774651, 0.1580993039533496, 0.14539456693455577, 0.12322414448135532, 0.07482205968699418, 0.12529069179436192, 0.12358782652881928, 0.16003724449547008, 0.15750045015010983, 0.2287600451381877, 0.11978041598922573, 0.19774585700361058, 0.1603020724724047], [0.03272577734605875, 0.004812477018276695, 0.030839571918477304, 0.041709497236297466, 0.057183870012522675, 0.06809516635257751, 0.059550330333877355, 0.021063572276034392, 0.032819885382195935, 0.06983508705161512, 0.02516166536224773, 0.05362986208638176, 0.0728627378703095, 0.062175028360798024, 0.03909562343324069, 0.0365081997733796, 0.01641561455471674, 0.019488220968923997, 0.037283309939084575, 0.040337822792935185, 0.09599345488823019, 0.07676298366277479, 0.048496664094273, 0.0507317011943087, 0.004544503726719995, 0.05487757189257536, 0.04092155162652489, 0.042656292134779505, 0.04574864338792395, 0.0811865994182881, 0.04319254578149412, 0.014365413044288289, 0.018461394720361568, 0.8400097629055381, 5.716366237029433, 26.962106823921204, 37.49608397483826, 30.352854877710342, 19.74691528826952, 13.68959192186594, 5.010736500844359, 1.5668525733053684, 0.24311422021128237, 0.1051855253172107, 0.06789071951061487, 0.10834130051080137, 0.15794137492775917, 0.06766324382624589, 0.3337872406700626, 1.6016708174720407, 1.0934246960096061, 0.7845640880987048, 2.317525567486882, 13.044110108166933, 23.913424015045166, 36.8310322612524, 46.57137639820576, 55.0261165201664, 54.22183267772198, 57.25579507648945, 53.594015166163445, 54.98938389122486, 53.97100433707237, 54.1889226436615, 54.216668754816055, 52.46549852192402, 52.292421609163284, 53.15505512058735, 52.87956990301609, 51.82888828217983, 52.00188919901848, 49.4255780428648, 50.81128768622875, 50.383825823664665, 47.33138121664524, 44.36477020382881, 42.12202414870262, 39.38428245484829, 40.27166783809662, 38.709290474653244, 40.080610290169716, 36.69851817190647, 37.003068029880524, 36.92285813391209, 41.01514734327793, 41.96898736059666, 49.72830779850483, 47.467147931456566, 56.08310580253601, 40.63422918319702, 38.9567331969738, 55.06267435848713, 47.68784008920193, 50.142580568790436, 44.270333871245384, 43.326137736439705, 36.43344819545746, 37.80661091208458, 34.96979333460331, 39.65822875499725, 34.17163096368313, 38.21185536682606, 44.986378848552704, 51.822732612490654, 48.76141548156738, 47.21917703747749, 44.072565883398056, 42.40624889731407, 41.97686053812504, 47.70383343100548, 45.89343197643757, 49.750882387161255, 49.0042794495821, 49.875352308154106, 48.192855790257454, 47.35526293516159, 47.30317912995815, 46.93818971514702, 45.162814781069756, 43.85303646326065, 45.8141378313303, 49.31479498744011, 50.61046466231346, 48.44279117882252, 31.77946362644434, 18.950411528348923, 3.279428514651954, 0.21588026516838, 0.7552937243599445, 5.701237348839641, 2.348967930302024, 3.6004585633054376, 2.0109570678323507, 0.7225246983580291, 3.449882143177092, 5.921340538188815, 7.972478549927473, 0.08572843929869123, 0.1508462947094813, 0.6926765281241387, 1.2981378799304366, 11.24228099361062, 30.08676465600729, 31.52822870761156, 30.497976690530777, 25.257189609110355, 16.570525132119656, 3.753659692592919, 0.18315189401619136, 0.03325155186757911, 0.05276478506857529, 0.022822707178420387, 0.0191261864893022, 0.027208473402424715, 0.044986275897827, 0.023155039052653592, 0.043884702390641905, 0.04603317167493515, 0.07073258850141428, 0.03552030473656487, 0.03855916940665338, 0.014374923666764516, 0.03269538268796168, 0.04052787568070926, 0.09409159756614827, 0.06292420788668096, 0.06473986475612037, 0.059773293760372326, 0.02413824557152111, 0.018078838002111297, 0.03966637210396584, 0.05845149906235747, 0.028322756188572384, 0.04875008526141755, 0.03466289410425816, 0.029391960924840532, 0.014504065711662406, 0.08359340659808367, 0.05165095499251038, 0.06127628010290209, 0.06924916888237931, 0.030811951037321705, 0.012685228739428567, 0.020058123591297772, 0.01483177215050091, 0.025021794644999318, 0.062366135098272935, 0.04917166967061348, 0.040001251400099136, 0.02977201103931293, 0.06711891561280936, 0.04820468835532665, 0.028075622867618222, 0.016346284974133596, 0.06663365493295714, 0.07158380962209776, 0.019655066898849327, 0.04221104063617531, 0.11293383649899624, 0.08628989628050476, 0.006977290249778889, 0.023583877955388743, 0.04281391316908412, 0.02613713499158621, 0.04782363634149078, 0.05643512835376896, 0.0394646044151159, 0.037365684620453976, 0.03679165936773643, 0.9879462153185159, 6.858277162536979, 36.216673627495766, 45.224067494273186, 35.61950147151947, 24.9429901689291, 19.697132259607315, 7.246715119108558, 3.401823746971786, 0.48382794891949743, 0.07766306036501192, 0.10024059534771368, 0.031088356518012006, 0.006660114422629704, 0.13918164797360078, 0.7709918101318181, 1.435999944806099, 1.3963830331340432, 2.870314917527139, 2.0474047120660543, 13.084993064403534, 26.982063353061676, 40.000191405415535, 50.980108827352524, 55.069874972105026, 54.87628296017647, 57.18193843960762, 55.497165843844414, 55.43675288558006, 56.74957104027271, 56.01822428405285, 55.616832822561264, 52.451690062880516, 52.828869223594666, 53.279787227511406, 55.641136318445206, 52.96568848192692, 53.18318881094456, 50.74278116226196, 52.443455904722214, 51.64390280842781, 49.403432831168175, 45.25646835565567, 43.8416750729084, 40.21807551383972, 41.59845784306526, 39.27959427237511, 41.94533362984657, 38.64466734230518, 39.733863696455956, 38.222631588578224, 43.12517412006855, 44.421257972717285, 51.31379172205925, 50.086043402552605, 57.501934468746185, 43.06434318423271, 41.95641003549099, 56.128342375159264, 50.45094162225723, 51.77118077874184, 47.88107872009277, 45.466521084308624, 38.656511306762695, 37.57460296154022, 35.532972514629364, 39.99155446887016, 35.61951287090778, 40.513844043016434, 46.93612642586231, 52.69248314201832, 48.92616704106331, 50.40814831852913, 44.72417771816254, 45.82567401230335, 45.2317126840353, 48.00522945821285, 47.799915075302124, 50.599912628531456, 50.72825454175472, 50.12307621538639, 48.372232764959335, 50.209852159023285, 50.16289807856083, 49.12145376205444, 47.087179720401764, 45.332551673054695, 45.96166871488094, 50.77007129788399, 50.78943505883217, 50.80296993255615, 35.22551201283932, 22.367117889225483, 3.9101806562393904, 1.1810862296260893, 3.0066542141139507, 6.243729488924146, 7.094004638493061, 6.365441707894206, 4.7296518087387085, 3.790891282260418, 2.937018913216889, 8.692740350961685, 7.7653383649885654, 1.036018563900143, 0.11372987151844427, 0.4430444701574743, 1.609378110151738, 10.838755946606398, 31.169309467077255, 35.71268007159233, 34.598553255200386, 29.410163462162018, 19.36006184667349, 4.7412060387432575, 0.32549189985729754, 0.058597431270754896, 0.0480907872406533, 0.08149980800226331, 0.011928794720006408, 0.023387401779473294, 0.037325037192204036, 0.03715826176630799, 0.055604828376090154, 0.06878126703668386, 0.027530995939741842, 0.08772092769504525, 0.043520185427041724, 0.032124993958859704, 0.027619795764621813, 0.03323680910398252, 0.04093291390745435, 0.06493651162600145, 0.003631004819908412, 0.01955109943082789, 0.049826674367068335, 0.026425082724017557, 0.04904741930658929, 0.06322500776150264, 0.038395414521801285, 0.06777990201953799, 0.06867013784358278, 0.026797813407029025, 0.11268369562458247, 0.19624898966867477, 0.19320569437695667, 0.22669181314995512, 0.14110882737440988, 0.12276232824660838, 0.14407369249965996, 0.23649570270208642, 0.1509661367163062, 0.2125317245372571, 0.10955550606013276, 0.16254249756457284, 0.14975195343140513, 0.1582265377510339, 0.09927883133059368, 0.1395442761713639, 0.09752138110343367, 0.13435681234113872, 0.24344072066014633, 0.16573866043472663, 0.15142818301683292, 0.10169699336984195, 0.1579152068006806, 0.14515091985231265, 0.1426609995542094, 0.12742539052851498, 0.18778645782731473, 0.12621444300748408, 0.10215829010121524, 0.14115167898125947, 0.1367625137208961, 0.16726220055716112, 0.10076533086248673, 1.061801842879504, 10.122099202126265, 39.42293018102646, 55.02612791955471, 43.35672989487648, 30.835582874715328, 23.383493050932884, 7.201171237975359, 7.09232322871685, 1.0969810676760972, 0.48715122684370726, 0.406550100306049, 0.33881330222357064, 0.43602318910416216, 0.2845346397953108, 1.077511387411505, 3.5757717629894614, 3.598455833271146, 1.9786810060031712, 3.1326951133087277, 15.502019617706537, 26.61243248730898, 40.473729595541954, 49.57363709807396, 56.61660857498646, 56.389604955911636, 61.01383522152901, 58.465501964092255, 59.90232266485691, 58.20976808667183, 57.80626393854618, 56.91021502017975, 53.561044335365295, 53.639293536543846, 55.751026421785355, 57.71811246871948, 56.65373258292675, 55.58751359581947, 53.615856394171715, 55.205352902412415, 54.781550243496895, 51.31177023053169, 48.32028575241566, 46.03017143905163, 42.257232293486595, 44.422971680760384, 41.95587806403637, 43.933261558413506, 40.37111610174179, 40.62673598527908, 41.6285864263773, 43.37073974311352, 46.022982224822044, 53.79404403269291, 53.368326276540756, 57.37247161567211, 48.45017038285732, 43.91548231244087, 56.889623925089836, 53.536391258239746, 52.00637295842171, 49.505468755960464, 46.905481070280075, 39.79968376457691, 40.453408285975456, 38.45773257315159, 42.21609190106392, 36.83905743062496, 42.896255403757095, 49.1047802567482, 54.972923174500465, 52.30073556303978, 50.50167270004749, 48.34865503013134, 46.49524748325348, 46.44145376980305, 50.5235443264246, 49.28278550505638, 52.968576326966286, 53.7554457038641, 51.33401803672314, 50.005924701690674, 49.917746633291245, 52.032344564795494, 49.801552668213844, 50.681779235601425, 47.00429856777191, 50.47430656850338, 52.814813777804375, 53.84212285280228, 51.031261682510376, 34.98535729944706, 21.366257295012474, 4.146650992333889, 1.4348647557199001, 5.2550453413277864, 12.001917231827974, 8.928092122077942, 7.764709498733282, 6.391978058964014, 4.621876766905189, 8.031531181186438, 12.463466115295887, 13.577858917415142, 3.0660189036279917, 0.25421081227250397, 1.0002614138647914, 1.8677522521466017, 15.365043617784977, 36.97961948812008, 37.932251170277596, 40.141760408878326, 34.95187349617481, 22.201359383761883, 5.824174527078867, 0.508651037234813, 0.1196144346613437, 0.15515685168793425, 0.27586023963522166, 0.08569453057134524, 0.12254626679350622, 0.11783949201344512, 0.10088857190567069, 0.22813852614490315, 0.1544571845442988, 0.14470811001956463, 0.16970150638371706, 0.27290693717077374, 0.12454688170691952, 0.09225281537510455, 0.15014947741292417, 0.24611199216451496, 0.2206186851253733, 0.13779240689473227, 0.21495599445188418, 0.16271066822810099, 0.1766043555107899, 0.20799221500055864, 0.11600962301599793, 0.14310820290120319, 0.2146709058433771, 0.1576314540579915, 0.10840919218026102], [0.015118884039111435, 0.06576752406544983, 0.056377790024271235, 0.03000371882080799, 0.04424276638019364, 0.030535775622411165, 0.031573021624353714, 0.04094547104614321, 0.03589013918826822, 0.034553987643448636, 0.03335602770675905, 0.0793669572158251, 0.08966172550572082, 0.033121342057711445, 0.04186736317933537, 0.05993452163238544, 0.02777012334263418, 0.06910501411766745, 0.06551799175213091, 0.026573944560368545, 0.048983138185576536, 0.08237993577495217, 0.028956297974218614, 0.05009617416362744, 0.051738431939156726, 0.04676222044508904, 0.0322794311796315, 0.0161282846602262, 0.002917265164796845, 0.014502711292152526, 0.005086822111479705, 0.05125392082845792, 0.06508859994937666, 0.03046358877327293, 2.8970533702522516, 13.811047654598951, 29.230212718248367, 37.52906620502472, 25.19033219665289, 20.93688413500786, 13.815266378223896, 5.5814749002456665, 1.0496467701159418, 0.09864770152489655, 0.16127311333548278, 0.008475325539620826, 0.1074418101052288, 0.1032048741762992, 0.24742045789025724, 0.3976502950536087, 1.3392406306229532, 1.1507006851024926, 0.6740829383488744, 1.0440243780612946, 7.954874569550157, 18.373896963894367, 30.014872513711452, 41.034264117479324, 52.117308005690575, 53.58956940472126, 56.228767186403275, 50.866179540753365, 52.147725373506546, 54.21285755932331, 56.71856090426445, 54.616597294807434, 51.281854435801506, 49.86021012067795, 52.095656767487526, 52.13489346206188, 54.05879482626915, 52.297653928399086, 52.521294727921486, 50.26324689388275, 49.69665549695492, 46.8885263800621, 44.898766949772835, 42.44581237435341, 43.259147331118584, 39.21956889331341, 39.531592950224876, 35.830610543489456, 38.90024922788143, 37.20226854085922, 38.03574241697788, 41.4230440557003, 47.80985914170742, 46.68116010725498, 59.73076947033405, 42.63529300689697, 40.92201814055443, 53.22099678218365, 48.798402696847916, 51.35404676198959, 43.53221967816353, 40.0486958026886, 37.61160537600517, 41.06328696012497, 43.21169547736645, 39.091599360108376, 34.28011134266853, 35.90946391224861, 38.66001471877098, 41.62629894912243, 44.299250319600105, 42.942673712968826, 41.81318052113056, 40.0130233168602, 40.759120881557465, 41.183618903160095, 43.29318970441818, 44.4966459274292, 48.14884655177593, 48.489901050925255, 49.49218086898327, 50.4695226252079, 47.1673022210598, 49.07683655619621, 47.78833709657192, 45.544530898332596, 46.60414583981037, 46.20862506330013, 47.025148048996925, 37.73745462298393, 20.85404857993126, 6.779067562893033, 0.5423952452838421, 1.2867561844177544, 0.6722266192082316, 4.314371142536402, 10.478426981717348, 5.32796960324049, 6.136581413447857, 3.26983236707747, 1.7510953056626022, 9.304878953844309, 7.606922490522265, 0.41026098711881787, 0.1364378389553167, 1.1129641975276172, 3.5706410882994533, 10.78858818858862, 25.522025898098946, 33.25067438185215, 32.76036009192467, 25.84914654493332, 10.118732582777739, 1.9539481331594288, 0.10385265777586028, 0.044333070909488015, 0.038352551782736555, 0.09552262898068875, 0.09239172315574251, 0.03939058260584716, 0.025831522289081477, 0.056877411261666566, 0.042080931016243994, 0.06981881917454302, 0.04350089329818729, 0.01585273079399485, 0.047211832061293535, 0.032463665629620664, 0.008775618898653192, 0.051133358938386664, 0.02807075437885942, 0.022003795456839725, 0.07941915246192366, 0.015209003031486645, 0.028315002600720618, 0.0011417519908718532, 0.05517416007933207, 0.02359430698561482, 0.010772834775707452, 0.06075862838770263, 0.08562047907616943, 0.004850853010793799, 0.009646772250562208, 0.142978772346396, 0.07004397935816087, 0.029191664543759543, 0.0704170273093041, 0.03255248586356174, 0.01721463671856327, 0.04313519260904286, 0.05754062040068675, 0.02858757859939942, 0.026914979971479625, 0.04613412973412778, 0.07308276239200495, 0.08182160323485732, 0.0455212493397994, 0.0547335729788756, 0.029211119945102837, 0.07563285602373071, 0.005737241262977477, 0.012456232580007054, 0.08372832162422128, 0.06295105878962204, 0.029745232495770324, 0.10351838704082184, 0.058838729455601424, 0.07659140654141083, 0.05334239860530943, 0.02868862200557487, 0.03247919135901611, 0.03641967639850918, 0.025338797458971385, 0.05905667225306388, 0.031144598324317485, 0.0891471648355946, 4.228871455416083, 16.652940809726715, 36.86314053833485, 43.05330477654934, 26.076019071042538, 21.1380947381258, 16.105156503617764, 5.2621405106037855, 1.5066975262016058, 0.20940377988154069, 0.28860389487817883, 0.006191518668856588, 0.24070819228654727, 0.18184596643550321, 0.5642628343775868, 1.3045588228851557, 0.07387677134829573, 4.400396626442671, 1.9925582176074386, 2.294941241852939, 9.873607736080885, 22.06375926733017, 31.602613516151905, 42.34157636761665, 53.396991938352585, 55.68761922419071, 56.89192280173302, 52.30469115078449, 54.06974583864212, 55.48010095953941, 57.092400044202805, 54.348392486572266, 51.57625503838062, 50.92967413365841, 52.19860464334488, 52.71591268479824, 55.71901313960552, 53.59794035553932, 53.22579972445965, 51.86851255595684, 52.31714688241482, 49.89525564014912, 46.88120797276497, 43.68841029703617, 44.01144616305828, 40.652916580438614, 40.980223417282104, 37.78906725347042, 39.61426891386509, 37.70976550877094, 39.82725888490677, 42.961923480033875, 49.47890058159828, 48.92979584634304, 60.14325633645058, 45.52391320466995, 43.099932074546814, 55.26455372571945, 51.951070725917816, 52.339953258633614, 44.100160002708435, 42.85762667655945, 37.739609107375145, 41.83350183069706, 43.831731006503105, 40.927683636546135, 36.724246591329575, 38.21870259940624, 40.200360864400864, 44.11403685808182, 45.924924686551094, 45.92259921133518, 44.16439175605774, 41.511628702282906, 42.56742864847183, 42.598362788558006, 45.833642184734344, 47.17224195599556, 49.89749751985073, 49.60234455764294, 49.933002814650536, 51.100429370999336, 49.937205389142036, 50.60248889029026, 49.40287806093693, 48.07201847434044, 49.371909722685814, 48.59632954001427, 48.76999542117119, 39.4633562117815, 23.30546233803034, 8.458017446100712, 1.4002384012565017, 3.0660286406055093, 4.147701635956764, 7.006371840834618, 7.5098201259970665, 7.92153088375926, 5.690497700124979, 5.911487191915512, 4.116793144494295, 6.297081001102924, 4.5398173201829195, 0.9742325730621815, 0.1401684817392379, 1.492319453973323, 4.787455732002854, 14.728353582322598, 33.82094778120518, 37.89913594722748, 35.20916908979416, 30.915021412074566, 13.082303758710623, 2.3781365901231766, 0.04535542015219107, 0.0774071530031506, 0.04619230669050012, 0.11484639559057541, 0.14817065937677398, 0.01878769850009121, 0.014286695295595564, 0.038350796603481285, 0.060488876260933466, 0.04375374301162083, 0.015011252216936555, 0.04251054546330124, 0.0388050948822638, 0.04639575163309928, 0.017669747649051715, 0.09420084170415066, 0.011635089776973473, 0.041881415745592676, 0.04476199515920598, 0.01563851172249997, 0.009432823135284707, 0.019433539528108668, 0.04506475059315562, 0.03376847627805546, 0.047054648894118145, 0.042063869041157886, 0.03643106836534571, 0.05738609783293214, 0.10394656172138639, 0.27506807120516896, 0.14569106977432966, 0.1475660316646099, 0.12783391313860193, 0.08333410762134008, 0.10796669404953718, 0.21455275593325496, 0.16916190565098077, 0.13499617256456986, 0.11363985642674379, 0.22542504128068686, 0.2763204008806497, 0.14547960221534595, 0.16481971833854914, 0.1444029834237881, 0.08930760974180885, 0.1550144187058322, 0.08561385911889374, 0.07386939440038987, 0.24094363121548668, 0.22046786587452516, 0.13073480513412505, 0.13345431623747572, 0.17076196119887754, 0.0811978652200196, 0.17548491479828954, 0.08294456914882176, 0.13760508882114664, 0.1736206843634136, 0.12034124214551412, 0.12975240941159427, 0.09573698349413462, 0.2500417234841734, 4.369053058326244, 22.369870841503143, 44.58590313792229, 53.83846364915371, 37.07295387983322, 29.91265419870615, 20.79119425266981, 6.922251479700208, 1.876535362098366, 0.8143443369772285, 0.7472867821343243, 0.1305598660837859, 0.3216553822858259, 0.23884013236965984, 0.8955789904575795, 1.9669462856836617, 3.0971385212615132, 3.0431068455800414, 1.024024982471019, 1.9913712562993169, 10.012454185634851, 20.203557685017586, 32.66552858054638, 42.275566309690475, 56.062203124165535, 56.134612038731575, 59.7335547208786, 53.938189297914505, 56.948148384690285, 57.44160130620003, 61.05821684002876, 54.81860585510731, 51.11762344837189, 51.09764412045479, 52.30636686086655, 53.573496267199516, 55.966212674975395, 56.88536435365677, 55.921800658106804, 54.90454584360123, 54.155347645282745, 52.850007489323616, 48.73597204685211, 46.39024391770363, 47.33226276934147, 43.665740713477135, 42.30605207383633, 39.31042201817036, 42.65651486814022, 40.28732679784298, 41.105206310749054, 46.69822119176388, 51.121016666293144, 52.7345734834671, 62.023125663399696, 49.37760941684246, 46.04861944913864, 54.57235626876354, 53.911298140883446, 54.185267239809036, 47.7152594178915, 44.19927768409252, 40.3931625187397, 42.983354330062866, 45.141000151634216, 41.625831574201584, 38.67388017475605, 39.09265570342541, 41.298741325736046, 43.74998599290848, 48.214233443140984, 45.86144909262657, 46.83068968355656, 42.66041725873947, 44.17374685406685, 43.75883191823959, 47.054733261466026, 46.996866166591644, 50.97632423043251, 52.00429446995258, 51.99476458132267, 51.85163386166096, 50.795263946056366, 53.184302151203156, 51.12536363303661, 48.55160214006901, 50.24526245892048, 50.086670368909836, 50.04651792347431, 40.508588925004005, 24.029589481651783, 7.993188388645649, 1.447043102234602, 4.0531394351273775, 5.1787858083844185, 11.536978930234909, 16.967229545116425, 14.14360010996461, 11.801085658371449, 10.512640345841646, 9.049560204148293, 20.414197482168674, 13.50444020703435, 1.921022068709135, 0.4855107539333403, 1.5874567301943898, 5.072687901556492, 15.941318795084953, 36.907240971922874, 42.61168487370014, 42.366807013750076, 35.2963288128376, 14.598562996834517, 2.4190663313493133, 0.19552162557374686, 0.1977765522315167, 0.149573645030614, 0.14153039694065228, 0.23426013125572354, 0.1629690098343417, 0.12501127319410443, 0.16105705930385739, 0.12862014438724145, 0.14662926318123937, 0.12477832788135856, 0.11524857283802703, 0.12235187605256215, 0.1575432126992382, 0.14987550617661327, 0.21104655344970524, 0.10365805181208998, 0.13547971146181226, 0.19965828250860795, 0.09291252528782934, 0.13083256082609296, 0.08562866496504284, 0.1971170649630949, 0.1416516787139699, 0.11111341504147276, 0.20911272440571338, 0.08701298560481519, 0.1732502636150457], [0.02339465070690494, 0.019472082967695314, 0.05781977924925741, 0.051571816075011156, 0.061374366050586104, 0.036799284935113974, 0.045572728413389996, 0.05853542854310945, 0.023021053566480987, 0.048689151226426475, 0.030299550016934518, 0.04729336069431156, 0.03242040584154893, 0.13940693432232365, 0.06837743479991332, 0.03903446675394662, 0.06730586261255667, 0.05293248075759038, 0.015116213235160103, 0.06788672675611451, 0.03670383361168206, 0.06027993942552712, 0.034384614700684324, 0.02632387047924567, 0.09927635997883044, 0.022233054151001852, 0.03317428687296342, 0.07970395163283683, 0.03499418882711325, 0.041851885689538904, 0.02712852739932714, 0.05241040955297649, 0.060659221417154185, 0.03259307020925917, 0.4726932698395103, 9.47021758183837, 23.270732201635838, 39.097618237137794, 32.66126520931721, 19.942445196211338, 16.345024332404137, 11.584963705390692, 3.2027495792135596, 0.2973768225638196, 0.03168910836393479, 0.025048268907994498, 0.12131516996305436, 0.07200721229310147, 0.2186876317136921, 0.7488138845656067, 0.1979979348834604, 5.098909819498658, 3.237008065916598, 0.5139979440718889, 1.472093139309436, 4.4643946923315525, 11.248022485524416, 22.165037132799625, 38.94892081618309, 50.02023473381996, 54.11655552685261, 56.03072561323643, 51.37429587543011, 54.216170981526375, 56.220080852508545, 54.410948529839516, 55.555006340146065, 52.84477137029171, 50.55754870176315, 50.898071229457855, 52.18728885054588, 51.113531067967415, 52.50898338854313, 51.78837105631828, 49.85471561551094, 49.74828712642193, 50.505860075354576, 46.80729813873768, 47.808483615517616, 45.78209415078163, 45.121233612298965, 40.44450916349888, 39.549565985798836, 37.49289594590664, 40.19617348909378, 38.9162577688694, 47.93043427169323, 48.65966074168682, 54.13295164704323, 44.97766211628914, 38.28488364815712, 55.29711037874222, 48.121742606163025, 50.44812597334385, 44.57533210515976, 40.04030965268612, 39.58865828812122, 43.05689938366413, 37.60970927774906, 35.882857739925385, 36.41524717211723, 38.94185699522495, 35.72065584361553, 38.0783761292696, 37.353580221533775, 37.58677750825882, 37.566228210926056, 38.0510213971138, 37.14906759560108, 40.14410488307476, 41.92034237086773, 45.27483657002449, 45.43775662779808, 49.784111604094505, 48.95253762602806, 49.17739436030388, 47.9962657392025, 50.68615660071373, 46.90439812839031, 51.29981607198715, 45.15888959169388, 47.15217523276806, 39.030346646904945, 24.762098975479603, 9.819855820387602, 2.412337842397392, 1.5089169633574784, 1.9542423798702657, 2.85866498015821, 4.791562836617231, 6.180012607946992, 6.284519350156188, 4.29500263184309, 3.3418152295053005, 3.9864230901002884, 4.067563936114311, 3.579328847117722, 0.8826963161118329, 0.3633512574015185, 1.8927089567296207, 8.479406498372555, 12.093792501837015, 16.96340885013342, 24.87165279686451, 29.657193906605244, 18.003088161349297, 6.394848329946399, 0.7623042888008058, 0.02268412965349853, 0.006657683425146388, 0.03914854969480075, 0.03152728306304198, 0.052379213375388645, 0.061377316087600775, 0.10823471326148137, 0.019381414786039386, 0.027249293380009476, 0.113406272866996, 0.06306272975052707, 0.046172461661626585, 0.08021764399018139, 0.021131085450178944, 0.029148985486244783, 0.02938497917057248, 0.016632646365906112, 0.054815825205878355, 0.04016526603663806, 0.01498065810665139, 0.034508783428464085, 0.0213421448279405, 0.06249397003557533, 0.05987850803649053, 0.028806734808313195, 0.12177970245829783, 0.020675807536463253, 0.03494609765766654, 0.0014577707634089165, 0.06474459965829737, 0.06258884619455785, 0.10022452042903751, 0.019223125818825793, 0.03994751248683315, 0.04517957197094802, 0.04306855516915675, 0.009604111746739363, 0.07581933547044173, 0.02948181459942134, 0.07779078398016281, 0.012183814287709538, 0.02054655138636008, 0.06803419892094098, 0.028404648473951966, 0.06960531070944853, 0.04206016572425142, 0.023085095344868023, 0.06485199584858492, 0.04366633656900376, 0.019077750221185852, 0.02671174097486073, 0.012926613198942505, 0.017055149182851892, 0.03784685235586949, 0.026227146372548304, 0.040168520354200155, 0.05486580885190051, 0.04300080079701729, 0.033449972470407374, 0.03288904241344426, 0.017351006354147103, 0.026121497940039262, 0.5774244968779385, 12.470608782023191, 28.801517821848392, 46.45757630467415, 36.53431378304958, 21.914615370333195, 17.9615867882967, 12.521842382848263, 3.8736403919756413, 0.478063034825027, 0.08228543068980798, 0.03589205392927397, 0.11125656048534438, 0.8506135689094663, 0.8054382086265832, 0.5378360243048519, 2.1019638469442725, 10.16630508005619, 4.216112215071917, 2.663565636612475, 2.5962384743615985, 7.244383469223976, 17.152349911630154, 26.188272647559643, 42.46208310127258, 51.95213466882706, 55.65140336751938, 55.71309685707092, 53.55937622487545, 54.45495396852493, 57.58628994226456, 56.90465971827507, 56.45081587135792, 51.7464555054903, 50.10231412947178, 49.6873763948679, 52.13008292019367, 51.54818594455719, 54.58143398165703, 52.71693862974644, 52.088950127363205, 50.88075555860996, 50.9203190356493, 49.300598949193954, 48.93238350749016, 47.08611197769642, 45.84079720079899, 41.812754943966866, 40.28772957623005, 40.10678708553314, 41.411496475338936, 41.51194788515568, 50.55816426873207, 50.216471403837204, 55.9366312623024, 46.67237117886543, 41.07902191579342, 55.667727291584015, 49.62444797158241, 52.33981266617775, 47.30147682130337, 41.92001938819885, 41.35650582611561, 44.6562297642231, 39.42799150943756, 38.06010290980339, 38.264718130230904, 40.92997871339321, 38.452215269207954, 39.70580220222473, 39.312899485230446, 38.89798454940319, 40.68073108792305, 40.2814257144928, 39.622309282422066, 41.25228501856327, 44.35547210276127, 47.92662687599659, 48.184598833322525, 51.72673836350441, 50.847366750240326, 50.0902383774519, 48.80686104297638, 51.498651802539825, 50.04562497138977, 50.83946317434311, 47.718261256814, 48.26431855559349, 41.63556285202503, 26.945967189967632, 12.057932876050472, 2.978376131504774, 2.7951119653880596, 5.114821940660477, 7.4504981841892, 6.315498612821102, 6.15082542411983, 10.111318230628967, 6.43082907423377, 5.559956654906273, 4.0452600829303265, 2.0205506030470133, 1.880824025720358, 0.6439637357834727, 0.4420319135533646, 2.7021228801459074, 8.280541319400072, 15.177070554345846, 22.41243615746498, 30.455945245921612, 35.05113936960697, 22.784962467849255, 7.9696619510650635, 0.9313134604599327, 0.07186725066276267, 0.00694280403877201, 0.004959022890034248, 0.047949619620339945, 0.04850357348914258, 0.07747557901893742, 0.05634137283777818, 0.003510675546749553, 0.03159754218359012, 0.05045810845331289, 0.017980121228902135, 0.059173857371206395, 0.03584247475373559, 0.014126612186373677, 0.027192806664970703, 0.033074267630581744, 0.05830628673720639, 0.0245359365362674, 0.08169678141712211, 0.03634261178376619, 0.021045812682132237, 0.0271960609825328, 0.0331632474262733, 0.09598178090527654, 0.01967874326510355, 0.08050922639085911, 0.024390833677898627, 0.10007206845330074, 0.08561987793655135, 0.11921584940864705, 0.15576499718008563, 0.222702739702072, 0.1088446844369173, 0.186120840953663, 0.1349512132583186, 0.19703679427038878, 0.0903309126442764, 0.21009871212299913, 0.06704657105728984, 0.15475131251150742, 0.13009813148528337, 0.14099241408985108, 0.17798393382690847, 0.19076762051554397, 0.20394623366883025, 0.14159748709062114, 0.109462321997853, 0.15394958521937951, 0.24537264980608597, 0.1835326899890788, 0.1594760621082969, 0.2200627571437508, 0.16643184120766819, 0.10958187456708401, 0.11576189412153326, 0.149662658222951, 0.15966842678608373, 0.14593988220440224, 0.07867077816626988, 0.11557509555132128, 0.10787707971758209, 0.09166489340714179, 0.8827986137475818, 13.493323903530836, 37.03871011734009, 55.41230499744415, 45.60356453061104, 31.190231144428253, 24.97264377772808, 16.476730965077877, 4.897531075403094, 0.858274195343256, 0.2746086224215105, 0.10896877152845263, 0.2934980619465932, 0.8085218025371432, 0.5641942005604506, 1.162885562516749, 2.609313097782433, 10.253107622265816, 6.112569076940417, 2.1298009157180786, 2.3246468603610992, 6.051720567047596, 12.653770353645086, 25.40537405759096, 42.798859030008316, 55.63048169016838, 56.787002831697464, 59.46262165904045, 54.563320353627205, 57.848388478159904, 59.72467079758644, 59.24139752984047, 58.46465840935707, 54.060136154294014, 51.149427741765976, 50.6755817681551, 52.076171413064, 52.64888048171997, 55.10170206427574, 53.15930709242821, 54.00925688445568, 54.323120042681694, 53.77987839281559, 50.667579397559166, 52.737962901592255, 50.80488882958889, 49.189036935567856, 45.21261490881443, 43.3335967361927, 42.60690473020077, 43.04967977106571, 44.19303461909294, 52.37336106598377, 54.99574854969978, 56.079944372177124, 50.64978875219822, 45.08167773485184, 56.544644236564636, 53.558076694607735, 54.02699813246727, 48.28518703579903, 43.38447980582714, 43.54030564427376, 45.76154865324497, 41.179484724998474, 38.56153920292854, 39.706318974494934, 42.983662113547325, 40.15137389302254, 41.8642383813858, 41.41461230814457, 40.74379250407219, 42.136501371860504, 42.11391158401966, 40.998899415135384, 43.60831059515476, 46.50918893516064, 49.842419475317, 48.54964904487133, 54.1417595744133, 52.40560233592987, 50.54079920053482, 49.97050680220127, 53.28659646213055, 51.414786502718925, 53.07388387620449, 51.42956770956516, 50.448217168450356, 42.056272476911545, 26.397793404757977, 11.551160719245672, 3.330264324322343, 3.1945681432262063, 6.201534178107977, 6.636383794248104, 13.601329308003187, 11.965620629489422, 13.36997302249074, 11.33433485403657, 9.843224566429853, 8.920031804591417, 12.111137621104717, 10.954481586813927, 2.01262422837317, 0.871462159557268, 2.6829377096146345, 12.58970009163022, 18.67055844515562, 26.73727098852396, 35.30226789414883, 40.69722980260849, 25.47183059155941, 8.371156957000494, 0.9028688399121165, 0.1594218407990411, 0.05160314954991918, 0.15087183943251148, 0.17092036519898102, 0.17516072985017672, 0.24356026580790058, 0.3142068616580218, 0.10030893972725607, 0.15864172484725714, 0.19923369982279837, 0.1247524269274436, 0.12741785030812025, 0.2019236734486185, 0.08242424941272475, 0.10801632146467455, 0.14579427283024415, 0.11543362736119889, 0.11558223501197062, 0.19152548687998205, 0.11224543515709229, 0.07666637829970568, 0.1377858908381313, 0.15449929400347173, 0.18471485702320933, 0.17113373265601695, 0.22100895090261474, 0.2536205970682204, 0.17649999470449984], [0.01786885659385007, 0.018814671857398935, 0.017161543473775964, 0.002778248381218873, 0.0344270915229572, 0.07906761937192641, 0.02198708043579245, 0.03742661123396829, 0.05441118773887865, 0.008021424309845315, 0.04812606894120108, 0.05899371586565394, 0.003764702260014019, 0.11395482390071265, 0.04144980492128525, 0.032169841942959465, 0.0751669357123319, 0.02371178339672042, 0.06618366853217594, 0.046022818714845926, 0.05413672297436278, 0.04014726153400261, 0.10643307556165382, 0.02757699981884798, 0.08103736094199121, 0.018607981874083634, 0.029984330212755594, 0.06154820672236383, 0.03351702180225402, 0.004502634537857375, 0.08581472138757817, 0.007722650962023181, 0.05596486276772339, 0.06646750291110948, 0.04090326139703393, 1.3252430129796267, 16.157656386494637, 36.96199983358383, 34.75072368979454, 31.90071702003479, 14.739219099283218, 11.981239691376686, 6.748553300276399, 1.0258327354677022, 0.19709244050318375, 0.03717966901604086, 0.3557554353028536, 0.8408513583708555, 1.308329883031547, 0.22010707820300013, 0.4605184559477493, 7.315472429618239, 7.002547346055508, 2.8333963360637426, 1.0988722974434495, 1.9432416139170527, 3.1390234362334013, 5.713130235671997, 18.799479827284813, 34.15781490504742, 48.70146989822388, 55.255210027098656, 53.579781129956245, 51.23609349131584, 50.9669691324234, 51.562579572200775, 56.6118398308754, 54.04731564223766, 54.13400039076805, 49.13492403924465, 51.86731941998005, 51.839162930846214, 51.7371916025877, 50.86352728307247, 51.17010623216629, 47.59633719921112, 50.03466635942459, 49.43430617451668, 51.08056403696537, 49.858184829354286, 50.6961652636528, 44.5559873431921, 41.40210337936878, 36.7388454079628, 38.27524356544018, 38.77762220799923, 50.65847888588905, 48.44074688851833, 57.04235292971134, 46.35331369936466, 37.16062277555466, 54.8643933981657, 48.951709270477295, 50.256183072924614, 43.2497276365757, 41.45029999315739, 37.644295021891594, 36.89042687416077, 36.59166030585766, 39.65963087975979, 40.62296278774738, 40.0878830999136, 37.259827852249146, 37.80250333249569, 40.67093141376972, 38.09886083006859, 36.89784027636051, 38.44905003905296, 39.63609494268894, 39.738134667277336, 42.631299421191216, 46.46607644855976, 48.68824660778046, 49.07082907855511, 49.88155737519264, 48.77774700522423, 48.09262476861477, 48.52531895041466, 49.840063601732254, 47.08512783050537, 43.239270597696304, 41.80048920214176, 25.297465547919273, 15.954789072275162, 4.234096650034189, 0.7838063256349415, 2.095224908553064, 4.378920653834939, 6.277016177773476, 4.412928828969598, 3.5302917659282684, 9.00458961725235, 4.699142295867205, 4.200717816129327, 2.6745819579809904, 1.2551606423221529, 0.8950070617720485, 0.12744949548505247, 1.100857809651643, 4.864188814535737, 12.324276734143496, 20.516381599009037, 24.580896198749542, 26.284308694303036, 24.666779190301895, 14.326133765280247, 2.337673748843372, 0.044580558605957776, 0.05182104781852104, 0.008632683111500228, 0.05285811756039038, 0.004323098346503684, 0.0292651965355617, 0.04412272770423442, 0.028206370734551456, 0.037831909212400205, 0.017986802413361147, 0.0346241317311069, 0.05516876837646123, 0.01090604935598094, 0.03905437857611105, 0.06414524861611426, 0.01587215836480027, 0.03354861131811049, 0.03878047413309105, 0.0594841010752134, 0.08013510232558474, 0.033355998020851985, 0.03368973069882486, 0.05504953121999279, 0.11250614421442151, 0.013701721509278286, 0.012136338173149852, 0.046383869848796166, 0.021664776832039934, 0.07688153433264233, 0.01861703236500034, 0.03731458775291685, 0.006861817173557938, 0.020015700574731454, 0.042123370731133036, 0.08201499207643792, 0.0052736387715413, 0.03527537744957954, 0.0448561625671573, 0.027036189385398757, 0.044634022924583405, 0.08213683788198978, 0.054617308123852126, 0.04626845475286245, 0.016854990099091083, 0.04589331765600946, 0.0309469569765497, 0.05622924545605201, 0.004238648434693459, 0.031395744808833115, 0.044562067996594124, 0.0072726599228190025, 0.032269853763864376, 0.06733361151418649, 0.05311496373906266, 0.08388662914512679, 0.02491541890776716, 0.054783831219538115, 0.006143849595900974, 0.04108680193894543, 0.03126523813989479, 0.03624941658927128, 0.015599339312757365, 0.06852590144262649, 0.09751359597430564, 2.0978147070854902, 19.640285409986973, 42.52614006400108, 39.28797662258148, 33.15667122602463, 22.66655322164297, 15.508823152631521, 7.749045789241791, 1.5203636116348207, 0.1927785883890465, 0.08382927597267553, 0.170544482243713, 1.5023274044506252, 2.871011230163276, 0.8410002035088837, 2.679040306247771, 12.891904525458813, 7.573282420635223, 6.669353675097227, 2.564042564481497, 3.5145625099539757, 6.199887916445732, 9.619155339896679, 24.706642851233482, 37.252376452088356, 50.96332512795925, 56.82932496070862, 54.95840035378933, 50.7621943205595, 53.246387019753456, 53.017643094062805, 57.069692462682724, 54.58387345075607, 54.002451449632645, 50.516415908932686, 52.07400932908058, 51.512954235076904, 53.074024468660355, 51.98909908533096, 53.10825303196907, 50.242822989821434, 51.184636652469635, 51.20958611369133, 52.112558260560036, 52.57712513208389, 52.45264761149883, 47.77901239693165, 42.82752089202404, 38.50557200610638, 39.88170236349106, 41.113140285015106, 53.32424484193325, 50.86058244109154, 57.32563152909279, 48.299789652228355, 40.964214876294136, 55.51381655037403, 51.34604059159756, 50.90309455990791, 45.08510895073414, 43.6871487647295, 39.97732423245907, 39.01794411242008, 38.25243718922138, 41.637846529483795, 42.011750265955925, 40.592883601784706, 39.31684747338295, 39.81744781136513, 41.6344191133976, 40.00458016991615, 38.15398067235947, 40.014357045292854, 41.89877472817898, 43.03823098540306, 44.97312515974045, 48.04029017686844, 49.56159934401512, 51.18655174970627, 51.69664777815342, 48.06518264114857, 49.03038404881954, 49.13065306842327, 52.43894934654236, 49.62518133223057, 48.236108869314194, 44.775148183107376, 29.423373453319073, 18.33901483565569, 6.885163094848394, 1.6018958366476, 4.053078163415194, 6.05677287094295, 9.388457369059324, 7.976237498223782, 7.154457019641995, 9.274882413446903, 5.809686379507184, 4.909203574061394, 1.9755164883099496, 0.586930577410385, 0.27138749370351434, 0.2269208844518289, 1.296869341749698, 6.068016467615962, 15.159973371773958, 22.81117346137762, 27.420081049203873, 28.63010711967945, 30.40224462747574, 17.681228332221508, 3.4212760906666517, 0.1037872523011174, 0.05854945884493645, 0.05302063676936086, 0.041900785799953155, 0.05584454949712381, 0.0481800453417236, 0.05501744817593135, 0.038974067065282725, 0.004966415144735947, 0.06968155896174721, 0.07386085228063166, 0.057411089655943215, 0.03765073241083883, 0.06363061373122036, 0.040200688745244406, 0.02426678369374713, 0.08208767059841193, 0.08286219817819074, 0.04601758286298718, 0.09190266267978586, 0.03428326701396145, 0.056944690659292974, 0.029904801667726133, 0.03385360061656684, 0.06691957474686205, 0.014454992124228738, 0.05870541004696861, 0.06416260745027103, 0.015963544574333355, 0.10966844609356485, 0.06162779092846904, 0.10427480621729046, 0.09701479109935462, 0.2316570928087458, 0.18629710102686659, 0.10976285469951108, 0.11773133141105063, 0.16914995707338676, 0.09263728497899137, 0.18676677660550922, 0.27754066977649927, 0.24683861411176622, 0.14864698459859937, 0.16433487326139584, 0.15768557146657258, 0.14516718772938475, 0.11410848557716236, 0.15357585449237376, 0.18000913609284908, 0.1624726169393398, 0.057809021818684414, 0.14569375634891912, 0.16007077472750098, 0.16548370302189142, 0.11561102292034775, 0.13867516187019646, 0.19243510760134086, 0.1068368113192264, 0.13155103399185464, 0.1792622238281183, 0.20063383562956005, 0.084818291652482, 0.17380607285303995, 0.2317213627975434, 2.737702508457005, 23.475854694843292, 51.242389753460884, 47.73193672299385, 43.756825625896454, 27.66664031893015, 19.719613753259182, 9.140074197202921, 1.2846608343534172, 0.49706747755408287, 0.1506629990763031, 1.3096083956770599, 3.172024190425873, 3.6449802992865443, 0.386221042717807, 1.8035788019187748, 13.857998885214329, 11.563990730792284, 4.717528559267521, 2.7391305193305016, 3.9675863133743405, 4.619272006675601, 7.908257720991969, 21.928834207355976, 36.02881170809269, 52.00897961854935, 58.70657242834568, 56.831646636128426, 53.2915323972702, 55.148302763700485, 56.350945830345154, 60.36381930112839, 56.42350293695927, 56.29511162638664, 50.473178029060364, 52.62027181684971, 50.89002326130867, 53.27903486788273, 52.88440704345703, 55.215866938233376, 50.49352213740349, 53.03304746747017, 53.301662653684616, 55.48692539334297, 53.921922370791435, 54.30295832455158, 50.254647955298424, 44.65105824172497, 40.65578542649746, 41.09408050775528, 43.42695772647858, 54.504032135009766, 54.50428292155266, 59.52670142054558, 51.85903586447239, 44.283549562096596, 56.97437457740307, 55.529718697071075, 54.04407821595669, 46.90652221441269, 45.95376893877983, 40.67136079072952, 40.99691592156887, 40.967129319906235, 44.318013712763786, 45.39065055549145, 42.97880977392197, 41.867027431726456, 42.0255321264267, 44.58667829632759, 41.62860542535782, 39.67223480343819, 41.12520843744278, 43.42683993279934, 44.68586437404156, 45.95758393406868, 50.42171359062195, 51.69730134308338, 54.44895789027214, 52.219446524977684, 48.83659064769745, 48.887154534459114, 51.177949011325836, 53.27521227300167, 52.22483463585377, 49.747606962919235, 43.86675752699375, 28.174407072365284, 18.06762009859085, 5.67604280076921, 1.6783993877470493, 5.7539210468530655, 10.783556308597326, 14.287105109542608, 10.393900517374277, 10.669091250747442, 17.956272773444653, 12.699673790484667, 13.366360366344452, 7.495545716956258, 3.713493710383773, 1.4569945307448506, 0.4720046161673963, 1.481696292757988, 7.776227155700326, 18.926617205142975, 29.33821812272072, 35.90352863073349, 36.17932543158531, 33.76440681517124, 21.361737437546253, 3.4500645333901048, 0.18608692480484024, 0.1626617310103029, 0.11397042384487577, 0.11637636271188967, 0.17178079637233168, 0.10738148092059419, 0.1835907853092067, 0.09574658688507043, 0.11988294369075447, 0.1881643891101703, 0.1642015835386701, 0.14795093913562596, 0.10893555299844593, 0.14262717246310785, 0.20386677933856845, 0.05634497225400992, 0.152815880428534, 0.1423303727642633, 0.21766339370515198, 0.18342859635595232, 0.19801806192845106, 0.1257768430514261, 0.12041465539368801, 0.26030464621726424, 0.18734712124569342, 0.11383783916244283, 0.146689495886676, 0.1967261906247586, 0.1061622287670616], [0.026284915147698484, 0.03837652315269224, 0.07659199283807538, 0.025192850407620426, 0.025265831354772672, 0.0337240698718233, 0.03979449647886213, 0.029203041667642538, 0.052848228442599066, 0.06136421347036958, 0.04439252435986418, 0.010663317898433888, 0.040301754415850155, 0.0610521255293861, 0.05057824731920846, 0.032498357322765514, 0.03103084378381027, 0.07179211563197896, 0.033053350198315457, 0.03791275135881733, 0.07060218573315069, 0.06477459726738743, 0.07791688971337862, 0.01686923005763674, 0.030509713251376525, 0.05497936115716584, 0.03908764905645512, 0.03588899999158457, 0.015477295910386601, 0.11373602392268367, 0.038783075360697694, 0.05425538125564344, 0.06163698242744431, 0.015222242018353427, 0.08241287971031852, 0.3049491631099954, 4.935032213106751, 24.015520736575127, 40.495434030890465, 28.466539196670055, 15.552773494273424, 13.401763066649437, 12.350389882922173, 4.693175666034222, 0.798190631903708, 0.04013689744169824, 0.23212394822621718, 0.5276625452097505, 2.418689914047718, 1.3219375465996563, 4.107722556218505, 21.352939009666443, 3.0421317229047418, 11.728131473064423, 2.939420146867633, 2.2160584246739745, 4.221009677276015, 1.388917383737862, 4.614959713071585, 14.50291832908988, 28.91258966177702, 47.75070011615753, 54.077288433909416, 54.00219686329365, 51.69080749154091, 48.18913199007511, 54.736119881272316, 54.040122628211975, 57.46020890772343, 53.679252192378044, 52.688500955700874, 52.590462416410446, 52.42439992725849, 49.90967206656933, 51.01706184446812, 53.15637364983559, 53.63671347498894, 53.05294319987297, 52.666617929935455, 52.43694685399532, 52.114290967583656, 52.461508736014366, 49.63929757475853, 38.432235941290855, 38.046883419156075, 41.300386637449265, 48.44009332358837, 49.03131499886513, 54.87252876162529, 46.30919046700001, 37.892642095685005, 52.915409579873085, 49.23170484602451, 50.51409423351288, 44.12873826920986, 41.31599999964237, 37.04966872930527, 37.91065692901611, 40.03858834505081, 43.73129099607468, 46.98354788124561, 47.32586391270161, 44.628305062651634, 38.63694615662098, 38.886668756604195, 38.25095146894455, 37.8587631136179, 40.26591494679451, 42.03714810311794, 43.73355187475681, 47.21323415637016, 47.793869599699974, 46.469097286462784, 49.365993440151215, 48.69685314595699, 46.39639958739281, 49.542341977357864, 47.649317756295204, 48.0241334438324, 45.314012467861176, 39.61755573749542, 29.96668539941311, 16.75367910414934, 8.777580298483372, 1.8155917385593057, 1.6708913468755782, 2.5416605779901147, 4.4399909768253565, 11.564646195620298, 4.57454270683229, 4.103805441409349, 7.797750625759363, 4.440804133191705, 2.6098821172490716, 0.9505623963195831, 0.3453031461685896, 0.06743297766661271, 0.7710276707075536, 4.65282135643065, 8.095447551459074, 17.667039893567562, 21.90713357180357, 22.31318738311529, 25.41811667382717, 18.58202889561653, 7.898787679150701, 0.19352661387529224, 0.043194950339966454, 0.027874263359990437, 0.006903997136760154, 0.03732957542524673, 0.045655203284695745, 0.014552690299751703, 0.025155689218081534, 0.09205260619637556, 0.156663827074226, 0.03968963472289033, 0.026675527878978755, 0.026481793938728515, 0.03446773152973037, 0.016930173369473778, 0.05825003936479334, 0.06749629028490745, 0.02254256312880898, 0.029102959342708346, 0.03866853970976081, 0.05052006665209774, 0.03286925675638486, 0.03241805323341396, 0.023875892657088116, 0.0259124534932198, 0.04954303665726911, 0.04336345868068747, 0.0204714534629602, 0.018422932917019352, 0.06568127908394672, 0.05680344140273519, 0.030389711682801135, 0.042778646311489865, 0.05481301617692225, 0.03147301351418719, 0.045642304758075625, 0.03340323572047055, 0.030639123397122603, 0.05402862545452081, 0.034542888824944384, 0.0605086990253767, 0.024571427893533837, 0.057434099944657646, 0.023753625682729762, 0.034546985480119474, 0.026725895586423576, 0.01565004469739506, 0.020608652448572684, 0.01171387988506467, 0.09540980026940815, 0.017082950034819078, 0.13137527857907116, 0.09136794527876191, 0.058676303015090525, 0.005512952639037394, 0.06359441176755354, 0.010754019476735266, 0.005175799587959773, 0.06560802168678492, 0.13213608384830877, 0.07009053428191692, 0.07247305838973261, 0.13843170774634928, 0.005963955782135599, 0.05028006351494696, 0.6170602887868881, 7.300343541428447, 30.98141334950924, 46.46914668381214, 33.64018388092518, 19.44416843354702, 22.303900681436062, 12.588526904582977, 4.766487507149577, 0.5676174606196582, 0.07681298215175048, 0.225211480865255, 1.7441883450374007, 3.514368482865393, 4.325539693236351, 7.2727384977042675, 10.726451072841883, 10.74351690709591, 10.784894786775112, 6.4386120066046715, 3.4345138678327203, 6.777589917182922, 4.20468907803297, 7.606289349496365, 18.472807556390762, 32.49362200498581, 49.653888791799545, 55.14486014842987, 55.735299065709114, 53.64846624433994, 51.0624086111784, 55.416895151138306, 55.51538206636906, 57.19912491738796, 54.72074590623379, 52.74439595639706, 52.684590965509415, 53.26654113829136, 51.06828309595585, 53.334067314863205, 54.85755756497383, 54.73527252674103, 53.99377651512623, 53.88301245868206, 54.295791909098625, 52.604628056287766, 53.57265651226044, 49.98225957155228, 40.411792919039726, 41.47057570517063, 43.201694414019585, 51.07432097196579, 50.935571417212486, 57.65471667051315, 48.8289150595665, 41.51236966252327, 55.18293410539627, 51.416990384459496, 53.11416931450367, 46.9969117641449, 43.022910207509995, 39.59068737924099, 39.80041712522507, 41.75141103565693, 44.70955990254879, 47.83706188201904, 48.86500172317028, 45.802438259124756, 39.62873473763466, 39.332244247198105, 39.4316241145134, 39.436442255973816, 41.45227208733559, 44.969127774238586, 45.27023881673813, 48.295321092009544, 49.85111340880394, 50.23536019027233, 49.19039726257324, 49.613086581230164, 47.916565015912056, 49.94521535933018, 46.85206353664398, 49.94671627879143, 46.7079296708107, 42.14313581585884, 33.144234493374825, 19.17813900858164, 10.40868267416954, 3.7807942740619183, 2.7501827012747526, 4.198030410334468, 6.202307911589742, 12.153172865509987, 6.04328834451735, 7.079322701320052, 9.041237700730562, 4.963110331445932, 4.029762139543891, 0.9413268731441349, 0.32452292216476053, 0.09549454611260444, 1.1242086254060268, 4.5058252941817045, 10.329667814075947, 20.414995439350605, 28.023372776806355, 27.628963440656662, 30.734890177845955, 23.611944392323494, 10.601247791200876, 0.5623058800119907, 0.038056535049690865, 0.04529254911176395, 0.019188011101505253, 0.03431706441915594, 0.0009136876906268299, 0.05683146860974375, 0.025573271595931146, 0.04683894367190078, 0.046174150047590956, 0.04183397766610142, 0.014288960701378528, 0.0598770534270443, 0.047095708214328624, 0.04661912695155479, 0.1369715025066398, 0.04760054674989078, 0.05471487827890087, 0.011862755636684597, 0.027381271356716752, 0.06608419847907498, 0.04274574319424573, 0.08788092731265351, 0.014218798060028348, 0.059068980772281066, 0.01338888585451059, 0.04947051027556881, 0.04326188463892322, 0.04523465417150874, 0.02681858983123675, 0.18913496984168887, 0.13733472442254424, 0.1293992658611387, 0.13919614953920245, 0.17341119091724977, 0.1757985315634869, 0.1524789008544758, 0.1349869105615653, 0.13090107589960098, 0.1017085337662138, 0.09024253027746454, 0.0706576241645962, 0.17876235768198967, 0.17839089792687446, 0.18824750964995474, 0.1617998006986454, 0.226666520757135, 0.13201555906562135, 0.11286277585895732, 0.16770125512266532, 0.1684230679529719, 0.20549736684188247, 0.2126795455114916, 0.09864851788734086, 0.12674841826083139, 0.1717502495739609, 0.11654367990558967, 0.11852978583192453, 0.18588362087029964, 0.17401687247911468, 0.15287638030713424, 0.2605643088463694, 0.24370820552576333, 0.12099036903236993, 0.20296636124840006, 0.6761544803157449, 8.398664630949497, 35.851764008402824, 55.40491819381714, 41.081024408340454, 24.041211158037186, 23.876224011182785, 17.538365498185158, 6.8057934287935495, 1.0867254179902375, 0.4419972700998187, 0.7127369579393417, 4.384149173274636, 9.494383335113525, 7.305748276412487, 13.09446595609188, 32.96711079776287, 11.498505994677544, 17.504807598888874, 7.526561552658677, 5.295398700982332, 7.584263356402516, 3.775298581458628, 6.466753296554089, 17.394148036837578, 31.270648129284382, 50.83503261208534, 57.903569117188454, 58.51134270429611, 55.63046649098396, 52.218770161271095, 57.926063910126686, 57.6431804895401, 59.23217162489891, 54.75875526666641, 52.47887380421162, 52.8797522932291, 53.36403630673885, 51.05649992823601, 53.55306476354599, 57.31145069003105, 56.80844508111477, 56.68828032910824, 56.69041961431503, 56.37856274843216, 55.5503173917532, 56.302969604730606, 53.45680832862854, 42.51542463898659, 42.68122114241123, 47.12636321783066, 52.01798893511295, 53.66227090358734, 58.27364645898342, 51.59129463136196, 46.27656541764736, 56.54972456395626, 54.41507510840893, 53.430221155285835, 49.55621123313904, 45.637321919202805, 42.12147697806358, 40.9261979162693, 43.16047802567482, 46.77837789058685, 49.9348609149456, 51.491903364658356, 49.66083861887455, 41.228836476802826, 41.896164268255234, 41.80370382964611, 41.37114644050598, 44.364789202809334, 46.9917706400156, 46.498108729720116, 50.890129655599594, 52.18907095491886, 51.34449027478695, 53.345618695020676, 50.743176341056824, 45.92031933367252, 51.000012159347534, 48.039712607860565, 51.2190818041563, 49.3217334151268, 41.92568488419056, 33.369110226631165, 18.607690818607807, 11.066337134689093, 3.754128492437303, 3.6602531047537923, 6.693148473277688, 9.151109755039215, 16.061181463301182, 12.604172565042973, 9.982381649315357, 16.169091872870922, 12.457313295453787, 7.533000307157636, 5.148329492658377, 1.4268837589770555, 0.599473585607484, 1.2151713506318629, 6.937333345413208, 12.839129157364368, 26.40978366136551, 32.00836904346943, 32.39106930792332, 35.04072792828083, 26.702706143260002, 10.382844060659409, 0.7341460778843611, 0.10463525250088423, 0.17316148790996522, 0.1687629715888761, 0.07058700881316327, 0.19070982205448672, 0.15043321531265974, 0.1333780531422235, 0.16508879140019417, 0.2125403779791668, 0.1789848683984019, 0.08336727420100942, 0.17523501883260906, 0.08447711152257398, 0.1550574929569848, 0.21230769983958453, 0.25421612604986876, 0.15712624444859102, 0.09553743482683785, 0.17529847245896235, 0.16712899989215657, 0.3529096848797053, 0.1693053776398301, 0.06256498614675365, 0.12419451741152443, 0.11949426610954106, 0.22238927136640996, 0.15161312621785328, 0.14530849264701828, 0.17164124292321503], [0.08946118978201412, 0.042712795548141, 0.0231839197294903, 0.026817942307388876, 0.011453136503405403, 0.0299624628314632, 0.01806964835850522, 0.04017410130472854, 0.0554821402329253, 0.061608149990206584, 0.06847425538580865, 0.06315440725302324, 0.0076676202479575295, 0.017027416979544796, 0.045109038255759515, 0.07140035813790746, 0.02539582594181411, 0.05270150213618763, 0.04163453289947938, 0.01981230943783885, 0.017780526177375577, 0.06294173741480336, 0.03457373248238582, 0.028453515187720768, 0.03265233070123941, 0.023190443207568023, 0.021220436319708824, 0.024879753145796712, 0.035286680358694866, 0.05842071848746855, 0.04847649623116013, 0.06737394724041224, 0.07598985132062808, 0.023478290750063024, 0.021811402948515024, 0.03478947110124864, 1.7622583941556513, 8.94070839509368, 35.82290455698967, 38.47526863217354, 23.56660522520542, 16.363073363900185, 11.830197796225548, 8.240069691091776, 3.27465383335948, 0.3477886877954006, 0.03697137042763643, 0.9318365855142474, 2.905986928381026, 4.302095426246524, 4.205566830933094, 5.083694960922003, 8.921133745461702, 11.471280455589294, 7.5939499866217375, 3.0995867773890495, 5.782916815951467, 1.0655945143662393, 0.9969185432419181, 2.6180868269875646, 10.341456681489944, 24.99016273766756, 38.98585103452206, 53.05326238274574, 53.93864147365093, 51.55261650681496, 53.86039987206459, 51.93111799657345, 57.04918496310711, 53.81816513836384, 55.76524145901203, 54.24669474363327, 52.760062515735626, 49.12781082093716, 53.19041982293129, 51.601854264736176, 52.51954682171345, 52.828276455402374, 53.737427070736885, 53.24939265847206, 53.7934360653162, 51.87304571270943, 52.861874252557755, 41.973102539777756, 37.85218186676502, 40.757217183709145, 51.67250767350197, 50.27110867202282, 56.474469602108, 44.61443580687046, 37.33442544937134, 55.04296101629734, 49.69549275934696, 51.46839402616024, 44.1905951499939, 39.78876695036888, 37.4827428907156, 38.45406956970692, 42.22590297460556, 49.199702963232994, 50.15146069228649, 50.13208173215389, 48.61563630402088, 46.024988517165184, 39.614033326506615, 38.104355335235596, 39.16226036846638, 40.81074871122837, 43.73616233468056, 45.800105184316635, 48.34008648991585, 46.620845943689346, 48.635551035404205, 49.23206962645054, 48.64783197641373, 47.24340833723545, 49.820487052202225, 46.10488682985306, 44.775497764348984, 38.3832223713398, 31.949438005685806, 17.259789146482944, 10.511706545948982, 2.9399846540763974, 2.7520132530480623, 2.595931403338909, 2.8478429233655334, 5.237556779757142, 11.951076909899712, 7.344871452078223, 8.464522697031498, 7.082099402323365, 3.39627034496516, 4.164562281221151, 0.6110734131652862, 0.1738030300475657, 0.4855693835997954, 1.9941467698663473, 9.381579738110304, 19.587097764015198, 20.22670604288578, 21.356900297105312, 26.9432370364666, 23.79872526973486, 14.106562547385693, 2.3950409330427647, 0.12478751566959545, 0.06142826452560257, 0.06683210522169247, 0.04460811454919167, 0.07791608819388784, 0.006680032738586306, 0.06547824232256971, 0.010884454713959713, 0.04311555538151879, 0.03380786947673187, 0.022584078869840596, 0.058107116565224715, 0.06304062859271653, 0.05743852314481046, 0.01038459691699245, 0.08634786543552764, 0.026781402666529175, 0.040557279571658, 0.04120295176107902, 0.026317888768971898, 0.03132743382593617, 0.08257200359366834, 0.0504576854291372, 0.013460668233165052, 0.04853184560488444, 0.06686701584840193, 0.017122317258326802, 0.03930774408217985, 0.06055666774045676, 0.1119390172243584, 0.05405662668636069, 0.025014673738041893, 0.01705869293800788, 0.003427375499995833, 0.019641110811789986, 0.10709044770919718, 0.03755306577659212, 0.03460429041297175, 0.05716157589631621, 0.06591155266505666, 0.004110909048904432, 0.05292148212902248, 0.020882096760033164, 0.034742430070764385, 0.06376592951710336, 0.03843343845801428, 0.03608156504924409, 0.0984335177054163, 0.024126901844283566, 0.07572579517727718, 0.04591941527905874, 0.02139722517313203, 0.028525134293886367, 0.04200056013360154, 0.050214164511999115, 0.05732566103688441, 0.05022299235861283, 0.06276359228650108, 0.07638341223355383, 0.038266907940851524, 0.02484743261447875, 0.036121952725807205, 0.054089667100925, 0.05964171468804125, 0.033354736369801685, 0.04675677679188084, 2.5289177242666483, 12.86875331774354, 42.632481157779694, 40.06769858300686, 23.042096570134163, 20.341841764748096, 18.02164636552334, 10.796643756330013, 3.767571933567524, 0.24652202875586227, 0.23527973826276138, 0.6381762307137251, 2.216313723474741, 4.758820468559861, 7.484193351119757, 9.222826156765223, 7.587333116680384, 9.976477716118097, 6.520095309242606, 6.129155661910772, 5.981793869286776, 3.3475218107923865, 3.2644988782703876, 4.905747659504414, 13.374921306967735, 29.969425052404404, 44.14433263242245, 55.05812980234623, 54.25172947347164, 53.68473529815674, 54.94381673634052, 55.087677016854286, 56.70091085135937, 54.672404900193214, 55.63873864710331, 54.32521753013134, 53.147197142243385, 50.29248632490635, 51.71816982328892, 52.000908851623535, 54.3198674172163, 54.42817680537701, 55.8071456104517, 54.71278913319111, 54.43421468138695, 54.123113974928856, 54.568621069192886, 43.766173124313354, 39.452940970659256, 41.77382603287697, 52.109925001859665, 52.62371823191643, 57.5323062390089, 47.241603434085846, 40.158266723155975, 58.01805317401886, 49.507064670324326, 53.341606110334396, 46.14005774259567, 41.2002582103014, 40.64313970506191, 39.904740527272224, 43.91589269042015, 50.8268478512764, 52.88680091500282, 53.65553766489029, 51.0552915930748, 46.824256628751755, 40.72318620979786, 40.008999332785606, 40.105555951595306, 42.95498885214329, 45.07798433303833, 48.92287641763687, 49.31604132056236, 49.640802294015884, 50.83290092647076, 50.282937437295914, 49.516951739788055, 48.81693810224533, 49.99971583485603, 48.334253802895546, 46.95925198495388, 43.75603526830673, 32.368403524160385, 21.410701610147953, 11.796490754932165, 5.214156685397029, 2.059400430880487, 3.730940711684525, 5.093921162188053, 8.670781329274178, 11.40103742480278, 8.023687452077866, 6.719317194074392, 7.783348923549056, 3.797172107733786, 2.6758199790492654, 0.32986837439239025, 0.07948442435008474, 0.6218094995710999, 2.3455253150314093, 10.615191143006086, 21.05470821261406, 25.322730392217636, 24.931030310690403, 29.89249248057604, 26.87887419015169, 17.080909945070744, 3.7478609662503004, 0.166402006871067, 0.024361863943340722, 0.054275192887871526, 0.06969735186430626, 0.07724520153715275, 0.0018525343034525577, 0.05711776320822537, 0.012492351052060258, 0.018606857520353515, 0.06120031015598215, 0.014666914248664398, 0.0786503691051621, 0.05617138391244225, 0.053303242893889546, 0.01806006723199971, 0.029176819734857418, 0.01679708031588234, 0.07196495440439321, 0.019010483811143786, 0.05401334092312027, 0.0314161316055106, 0.03618135793658439, 0.08717880366020836, 0.07833269279217348, 0.030213202990125865, 0.011778948610299267, 0.11353677953593433, 0.0487515361601254, 0.05074315995443612, 0.03828740605968051, 0.1599247645935975, 0.09555790325975977, 0.13505983399227262, 0.061173837748356164, 0.06289785422268324, 0.2238526233122684, 0.23313834535656497, 0.20906935329549015, 0.08702605482540093, 0.2167795700370334, 0.19895481556886807, 0.15047977765789255, 0.24366458208533004, 0.11515568563481793, 0.2353656047489494, 0.15049852430820465, 0.10989436326781288, 0.25415794167201966, 0.15795826620887965, 0.13464347430272028, 0.08229965023929253, 0.10006234631873667, 0.1108989269414451, 0.16043876123148948, 0.17378756368998438, 0.14602064271457493, 0.14729626098414883, 0.20363597141113132, 0.1941511608310975, 0.3171253722393885, 0.1891048831748776, 0.18769380811136216, 0.14832183485850692, 0.1202736102277413, 0.12805257953004912, 0.1046934443002101, 2.61642892844975, 16.3645438849926, 50.315053313970566, 50.37654161453247, 33.14268417656422, 27.72063922137022, 19.802922382950783, 11.258774008601904, 4.778734249994159, 0.5135561584029347, 0.49189752840902656, 2.932673371396959, 9.699872508645058, 12.299545761197805, 11.653774213045835, 15.052747875452042, 16.842810921370983, 21.68235283344984, 14.957765322178602, 9.037992674857378, 9.981418401002884, 4.171717772260308, 3.213130384683609, 4.2026671115309, 11.931280922144651, 27.89348054677248, 43.3977372944355, 56.08994543552399, 57.60709382593632, 56.736606135964394, 57.20808103680611, 57.710121497511864, 60.30197761952877, 56.234573274850845, 58.44047270715237, 54.81656536459923, 52.88219936192036, 50.24084709584713, 53.31113174557686, 51.87377907335758, 55.06697952747345, 54.685696586966515, 57.4035919457674, 56.508139595389366, 56.467971950769424, 56.05119131505489, 58.128995820879936, 45.598039627075195, 40.63660405576229, 45.387732312083244, 56.76966816186905, 55.975001603364944, 58.306313306093216, 49.12182614207268, 44.78756591677666, 58.72816286981106, 55.25771029293537, 55.7021876424551, 49.21328343451023, 41.994787976145744, 41.48768238723278, 41.179955899715424, 46.59712761640549, 54.44289341568947, 55.74883013963699, 54.795947670936584, 53.731921166181564, 48.92585165798664, 42.88929797708988, 41.844190657138824, 43.66663746535778, 45.213751047849655, 47.30001010000706, 50.434351712465286, 51.82441972196102, 51.079222708940506, 52.82284274697304, 50.72324261069298, 49.80364255607128, 48.12065206468105, 50.34227505326271, 48.877921029925346, 47.29348585009575, 40.293539464473724, 33.610416278243065, 18.806009776890278, 11.894229110330343, 5.229025287553668, 4.654997689649463, 6.3187887612730265, 7.536222534254193, 11.088636238127947, 22.197863571345806, 17.591509446501732, 16.51506520807743, 16.018581949174404, 8.363212533295155, 8.24101584032178, 1.883005346171558, 0.7341787323821336, 0.8585134637542069, 3.3201364427804947, 13.687818367034197, 28.198446482419968, 28.25947690755129, 30.829011127352715, 36.68274901807308, 33.27236741781235, 18.784945607185364, 3.6009582364931703, 0.2500790683552623, 0.17500530928373337, 0.16685605281963944, 0.1573630192433484, 0.2083889819914475, 0.13606541440822184, 0.09863517407211475, 0.09825681976508349, 0.11780110071413219, 0.17113540990976617, 0.12068052237736993, 0.1459405352943577, 0.2139060929766856, 0.24502526532160118, 0.18733471253653988, 0.296927674789913, 0.1225517141574528, 0.18602581636514515, 0.1229399984003976, 0.1645767837180756, 0.09405613775015809, 0.256608008639887, 0.14934611739590764, 0.18775580712826923, 0.1550497894641012, 0.11090009211329743, 0.2784985746257007, 0.11052136673242785, 0.1263005321379751, 0.25539082707837224], [0.04850437500863336, 0.04138505995797459, 0.04053950513480231, 0.039616893118363805, 0.033812938345363364, 0.021223080220806878, 0.05366020850487985, 0.031145655884756707, 0.04329010109358933, 0.04176084643404465, 0.07607794424984604, 0.05372443396481685, 0.06141209683846682, 0.01652007926168153, 0.08171826659236103, 0.056882769567891955, 0.028195995510031935, 0.01952355647517834, 0.042963923478964716, 0.056761710438877344, 0.059181735268794, 0.041403287104913034, 0.05204523949942086, 0.05789470276795328, 0.03175691468641162, 0.06144970888271928, 0.024787650763755664, 0.03826011728961021, 0.03834057722997386, 0.011663751520245569, 0.10390206996817142, 0.02944680007203715, 0.054881935720914043, 0.035801882986561395, 0.10487270265002735, 0.02563495891081402, 0.18256478098919615, 3.9792797109112144, 16.006601192057133, 37.18874506652355, 31.704016774892807, 22.094607912003994, 12.049578074365854, 9.533101357519627, 9.254028182476759, 2.4493371695280075, 0.3421436157077551, 0.5810803163331002, 0.8866093342658132, 3.0680693686008453, 6.968043772503734, 8.251827210187912, 8.367803636938334, 8.373269643634558, 5.081200869753957, 3.625743119046092, 6.673198593780398, 3.888267707079649, 2.6457844907417893, 0.9082533291075379, 1.1094537796452641, 6.75519771873951, 16.05477500706911, 32.033550292253494, 48.00011873245239, 49.06494699418545, 53.927994444966316, 55.35726115107536, 53.90181764960289, 55.797752514481544, 56.468006148934364, 51.79034695029259, 52.20226004719734, 51.75771050155163, 51.817990466952324, 51.79139569401741, 52.46190391480923, 53.17366272211075, 52.82662734389305, 51.256274208426476, 53.05863909423351, 53.09949830174446, 51.42916113138199, 42.93253965675831, 38.35972063243389, 41.983992755413055, 51.678610146045685, 50.64114801585674, 56.77136667072773, 47.563867941498756, 38.93695145845413, 53.74624639749527, 48.357698544859886, 51.43347389996052, 45.830203369259834, 40.12749597430229, 40.07995292544365, 42.16159902513027, 45.466243699193, 48.41954402625561, 51.41718417406082, 53.63850697875023, 50.5359810590744, 48.85049030184746, 46.29118323326111, 42.243682220578194, 39.87139731645584, 41.53242498636246, 45.48016235232353, 49.64679837226868, 49.52627643942833, 51.90419644117355, 49.11765396595001, 46.48021548986435, 50.30559182167053, 50.74566900730133, 47.9048540443182, 46.64986118674278, 40.12919828295708, 29.62564989924431, 20.344723910093307, 12.365840803831816, 5.366491936147213, 2.574108224362135, 1.0108804190531373, 2.8790088510140777, 4.069301867857575, 8.095155917108059, 9.313390497118235, 3.7582289474084973, 5.131367677822709, 5.412420546635985, 1.58730901312083, 1.7640135437250137, 0.5045036191586405, 0.4355572984786704, 2.2495754761621356, 5.95210368745029, 15.238116178661585, 22.19953928142786, 17.800813615322113, 20.17367608845234, 26.303205080330372, 21.31619308143854, 7.038570838049054, 0.6211245863232762, 0.05751761011197232, 0.017500231842859648, 0.01332864294454339, 0.16667490941472352, 0.11429230071371421, 0.013308524248714093, 0.0717013880785089, 0.027429093497630674, 0.004712144218501635, 0.04181963195151184, 0.06351074203848839, 0.01786132008419372, 0.021857223146071192, 0.03639801681856625, 0.030327721942740027, 0.014560707350028679, 0.07395963213639334, 0.05502690684807021, 0.036514148087007925, 0.06616219819989055, 0.06315919410553761, 0.04676316668337677, 0.04218004483846016, 0.049780345798353665, 0.060083734133513644, 0.091853940684814, 0.040413907772745006, 0.053528198986896314, 0.03135873761493713, 0.11151920654810965, 0.03672760460176505, 0.020650346305046696, 0.011717053494066931, 0.029152360402804334, 0.02233105289633386, 0.02312405067641521, 0.05445012451673392, 0.019638517005660105, 0.018400187946099322, 0.03198655373125803, 0.037677512809750624, 0.005857922824361594, 0.033877891110023484, 0.019388262953725643, 0.026928258848784026, 0.05172425320779439, 0.021165344842302147, 0.03936772816814482, 0.1194863770797383, 0.014669065549242077, 0.03997340601927135, 0.07169880540459417, 0.04849660472245887, 0.041413168801227584, 0.09080170886591077, 0.046607772092102095, 0.05062683572759852, 0.10153318653465249, 0.03151620279822964, 0.015174142499745358, 0.06497370806755498, 0.0383546223747544, 0.03513749012199696, 0.04263673283276148, 0.00833894569950644, 0.030051880494283978, 0.3895657538669184, 5.41974370367825, 22.454207316040993, 45.926794186234474, 32.45055511593819, 24.506627283990383, 22.476987093687057, 15.555397253483534, 10.869793631136417, 2.2074670856818557, 0.1281113873119466, 0.21594425314106047, 0.9154411777853966, 2.4394864356145263, 4.348052060231566, 4.155764803290367, 7.030988344922662, 11.56319372355938, 8.48826952278614, 9.864930901676416, 6.473451862111688, 4.275410883128643, 3.9895721711218357, 2.7079128194600344, 2.8336969949305058, 8.874308858066797, 19.988287836313248, 38.44448268413544, 52.80976004898548, 51.938360407948494, 55.689595118165016, 55.0250031799078, 56.037892028689384, 55.6101755797863, 56.79987654089928, 51.6245998442173, 51.73673942685127, 51.70598767697811, 52.34951354563236, 52.87489615380764, 51.56607538461685, 51.94971799850464, 52.21668787300587, 53.00682507455349, 54.02484364807606, 54.806169122457504, 53.64957578480244, 45.60271717607975, 40.924545004963875, 43.54812182486057, 54.23305727541447, 53.02230164408684, 57.48475179076195, 49.73054587841034, 41.39744482934475, 55.69525681436062, 51.30710408091545, 53.19672368466854, 46.53470076620579, 43.47110755741596, 41.49454861879349, 44.755484238266945, 48.294112756848335, 50.68035811185837, 52.74525851011276, 54.50459450483322, 52.75748245418072, 50.62450870871544, 47.256567031145096, 43.7909059971571, 41.548080146312714, 43.43078792095184, 46.69630229473114, 50.624675899744034, 51.800720393657684, 51.92367799580097, 51.251642256975174, 48.626366928219795, 51.63521267473698, 51.616578474640846, 50.04955016076565, 48.2767590880394, 40.76802760362625, 32.74922288954258, 22.708377577364445, 12.724388614296913, 8.856196179986, 2.4242411786690354, 2.220896752551198, 4.102424215525389, 5.290543036535382, 9.586530290544033, 7.316396730020642, 7.2432763036340475, 5.4244340769946575, 6.149944821372628, 2.4406019132584333, 0.5371706443838775, 0.13108607847243547, 0.6881342874839902, 2.7952772565186024, 8.564508631825447, 18.489653952419758, 29.0866906195879, 21.984776705503464, 25.69553218781948, 30.669239200651646, 26.27862799912691, 9.103171527385712, 0.9157505643088371, 0.0321901508141309, 0.047177162632578984, 0.06691589369438589, 0.07892457782872953, 0.10959705148707144, 0.046949082097853534, 0.08191820859792642, 0.04482332253246568, 0.015059820216265507, 0.026949239363602828, 0.06325412963633426, 0.017286734509980306, 0.03223953703127336, 0.00984423733825679, 0.06336821257718839, 0.010639281590556493, 0.019508229270286392, 0.04254199026036076, 0.009741973099153256, 0.04020611013402231, 0.030595147436542902, 0.03571402012312319, 0.043458835789351724, 0.09245726221706718, 0.10208819425315596, 0.02132752451871056, 0.03303724559373222, 0.08110554204904474, 0.05593589674390387, 0.003339047866575129, 0.10861738686799072, 0.11078042080043815, 0.09896972682327032, 0.17211243248311803, 0.14065978350117803, 0.13904044695664197, 0.15271846612449735, 0.13414869928965345, 0.09873575734673068, 0.09086033853236586, 0.09070307001820765, 0.10833381966222078, 0.0991702254395932, 0.10876612068386748, 0.20918086840538308, 0.20895731868222356, 0.08995025025797077, 0.21444225014420226, 0.2213636232772842, 0.07698140514548868, 0.21621276217047125, 0.16337273817043751, 0.10832530722836964, 0.12154554744483903, 0.2227927473722957, 0.16748441441450268, 0.16002406395273283, 0.25513181753922254, 0.10440171346999705, 0.1237830039463006, 0.17239821871044114, 0.1523148565320298, 0.19018831488210708, 0.11639608899713494, 0.15052838833071291, 0.22119478468084708, 0.43125055613927543, 6.942170010879636, 27.816530875861645, 55.380827486515045, 42.71672643721104, 33.152605444192886, 26.520082242786884, 15.964748337864876, 12.127216458320618, 3.0359694035723805, 0.38741690979804844, 1.4607195183634758, 2.409096616320312, 7.821095623075962, 16.642909348011017, 15.171737540513277, 17.057706490159035, 20.57607639580965, 13.889633137732744, 8.831644747406244, 15.260722115635872, 10.269562639296055, 7.041417835280299, 3.0758753372356296, 2.0700115989893675, 8.12776766717434, 18.657473847270012, 37.097850143909454, 54.00403596460819, 53.764671608805656, 57.49493144452572, 57.97570824623108, 57.97207184135914, 58.068978041410446, 58.1494615226984, 54.24237437546253, 51.09707035124302, 51.95586606860161, 51.92477993667126, 55.08037380874157, 51.7972207814455, 53.72741460800171, 53.062704876065254, 53.34085755050182, 55.34904599189758, 57.50210165977478, 56.602499932050705, 48.10395196080208, 42.461167350411415, 45.43510437011719, 55.825073048472404, 56.16694450378418, 59.23182964324951, 51.30526877939701, 46.00872918963432, 57.42651231586933, 53.59237365424633, 55.42254164814949, 49.29226979613304, 45.74318803846836, 44.714210852980614, 47.226047068834305, 50.04491060972214, 53.322284147143364, 54.223424792289734, 56.6018121689558, 55.053942427039146, 52.64272101223469, 49.81147013604641, 46.2064515799284, 43.88071037828922, 45.12078143656254, 48.47230799496174, 54.05862383544445, 54.745748564600945, 54.594414085149765, 50.911834090948105, 48.835652098059654, 52.26446270942688, 51.23585410416126, 48.90723265707493, 48.84138599038124, 40.55236637592316, 32.258752807974815, 22.584652416408062, 15.265203975141048, 7.711246367543936, 4.1564905643463135, 2.4862797372043133, 7.472313763573766, 8.221225552260876, 16.904956586658955, 20.202974416315556, 11.002235524356365, 14.017358534038067, 14.040739629417658, 6.797339357435703, 4.168493645265698, 1.497862406540662, 0.7908149901777506, 3.32318102940917, 9.694167114794254, 21.355999745428562, 32.27773278951645, 27.568825967609882, 29.628079868853092, 36.86007410287857, 28.60462948679924, 9.934027343988419, 0.8478357992134988, 0.10041278845164925, 0.15150598977925256, 0.15573345590382814, 0.26741056179162115, 0.14604465861339122, 0.12440403312211856, 0.18815698247635737, 0.1500102801946923, 0.12999289494473487, 0.2029173943446949, 0.20464055734919384, 0.07653705164557323, 0.0749427848495543, 0.22054546483559534, 0.13563811546191573, 0.07354497196502052, 0.1343733028625138, 0.23039763851556927, 0.10217621296760626, 0.19183378986781463, 0.13083247176837176, 0.12801113800378516, 0.20294500223826617, 0.16660253517329693, 0.20783407817361876, 0.15424322336912155, 0.10963299369905144, 0.274174376972951, 0.2422413061140105, 0.16056522319559008], [0.02483404427039204, 0.062230607800302096, 0.07443277354468592, 0.05784179506008513, 0.08447496671578847, 0.04856697516515851, 0.04466403908736538, 0.036191681210766546, 0.0156696893463959, 0.007296519506780896, 0.08052394317928702, 0.07241732309921645, 0.038238654378801584, 0.021734963593189605, 0.05209305978496559, 0.02035221259575337, 0.036264081427361816, 0.08075701465713792, 0.03784799155255314, 0.04742299533972982, 0.09535744175082073, 0.027880263623956125, 0.017220475565409288, 0.018277317976753693, 0.04176896552962717, 0.05134942781296559, 0.02380869489570614, 0.01794193402020028, 0.022118611268524546, 0.05196762198465876, 0.02635694243508624, 0.049071453759097494, 0.05736979284847621, 0.013867233428754844, 0.059110567017341964, 0.09371056410600431, 0.05562185324379243, 0.871070483699441, 8.214242476969957, 24.05190948396921, 34.84418347477913, 24.363321773707867, 11.58442223444581, 9.389538411051035, 11.823110226541758, 6.579679911956191, 1.6463143844157457, 0.12638123327633366, 0.6408198201097548, 2.0340244425460696, 3.5320612834766507, 4.329412160441279, 3.559346431866288, 5.384133914485574, 4.37306659296155, 10.818589478731155, 3.0677007883787155, 2.56931786891073, 2.2224855422973633, 2.345359311439097, 1.0097302682697773, 0.327752303564921, 2.6129143545404077, 7.817123886197805, 22.19751589000225, 36.17208682000637, 47.32619449496269, 49.331821873784065, 56.523179188370705, 54.51155573129654, 56.475689336657524, 50.47364920377731, 52.132632583379745, 49.09580893814564, 51.71763025224209, 45.465673729777336, 53.62026035785675, 50.78378476202488, 54.49850723147392, 54.805526956915855, 53.35483320057392, 50.826657861471176, 48.64545710384846, 40.29268451035023, 40.12018896639347, 42.36944407224655, 51.22138828039169, 46.65478952229023, 57.7513112872839, 46.551780849695206, 38.11760142445564, 55.817621648311615, 49.90850932896137, 52.06036426126957, 43.502159491181374, 41.08247973024845, 41.30871199071407, 43.02653141319752, 45.3645421564579, 50.03117814660072, 49.43748280405998, 53.5748527944088, 51.909101977944374, 50.28732620179653, 47.473801374435425, 42.62967310845852, 42.588209733366966, 44.26549293100834, 48.084971979260445, 48.50321173667908, 51.66739694774151, 48.745137155056, 48.14217410981655, 47.746911719441414, 50.00450357794762, 48.7823523581028, 44.455551132559776, 35.71364901959896, 26.675351411104202, 20.806986205279827, 10.968846715986729, 4.757253527641296, 4.811898870393634, 1.3387223146855831, 0.9495995042379946, 1.4435766194947064, 4.160170191898942, 6.648842850700021, 4.744585007429123, 8.246737383306026, 3.474572030827403, 5.427751773968339, 2.22131235525012, 0.581790046999231, 0.180590029922314, 0.7132778351660818, 6.595227252691984, 12.916451208293438, 15.690944530069828, 15.02780981361866, 16.103294603526592, 26.042358577251434, 24.201978631317616, 11.57571880146861, 2.499953778460622, 0.04503814830968622, 0.08992079441668466, 0.039837904696469195, 0.0037741896903753513, 0.04031664560898207, 0.06052648459444754, 0.02529417397454381, 0.01965088118595304, 0.02944062725873664, 0.07041713120997883, 0.03612433501984924, 0.024655748857185245, 0.00635399984275864, 0.01993105121073313, 0.01700318400253309, 0.036108709100517444, 0.037541640413110144, 0.02626441517350031, 0.09876559910480864, 0.05858702636032831, 0.019776626977545675, 0.06614474288653582, 0.06520316528622061, 0.09859515746938996, 0.013771591929980787, 0.05724453687435016, 0.03470601288427133, 0.019544728093023878, 0.01320875640885788, 0.018956147468998097, 0.047485127943218686, 0.014737393230461748, 0.034099258919013664, 0.0496663148078369, 0.02364737982134102, 0.017642605453147553, 0.023749256288283505, 0.07364889490418136, 0.0038312742981361225, 0.05615777292405255, 0.08618731662863865, 0.05802003295684699, 0.02750264960923232, 0.11065754340961576, 0.03075128603086341, 0.09283281862735748, 0.018114937920472585, 0.013301304079504916, 0.05682407310814597, 0.03654357424238697, 0.04481837611820083, 0.03609252657042816, 0.023372798168566078, 0.014644944822066464, 0.05232441319094505, 0.04362097279226873, 0.024314184665854555, 0.02522067166864872, 0.02051787480013445, 0.037174084354774095, 0.044538924121297896, 0.03547451793565415, 0.04038114937429782, 0.045347067280090414, 0.009769268363015726, 0.01816215706639923, 0.015738551373942755, 0.07746800169115886, 1.5202131634578109, 11.54026860371232, 32.601133435964584, 40.95442660152912, 26.96045771241188, 15.363099072128534, 15.341218896210194, 20.713722109794617, 9.394134264439344, 1.6182483779266477, 0.0039057743288140045, 0.33848037477582693, 0.3466955042677, 1.9417970976792276, 3.2229193719103932, 4.467260213568807, 7.8187900967895985, 7.073928415775299, 10.164574272930622, 5.983989201486111, 5.058247726410627, 5.461284974589944, 4.06610956415534, 2.5244380021467805, 1.1513452255167067, 3.599847271107137, 12.098004575818777, 26.147029660642147, 40.27044430375099, 49.865548834204674, 53.54810982942581, 56.871453300118446, 56.55238822102547, 56.603776663541794, 51.72779470682144, 51.26192070543766, 50.95917575061321, 53.2358767837286, 47.12374895811081, 53.700124472379684, 51.66619621217251, 53.47657106816769, 55.73260501027107, 54.434940442442894, 53.063537031412125, 51.769885048270226, 42.44809605181217, 41.966422498226166, 45.133590549230576, 52.27677784860134, 50.6799553334713, 59.04867187142372, 48.00760053098202, 41.56086266040802, 55.829146429896355, 51.32302522659302, 53.68065431714058, 46.336096823215485, 41.617703810334206, 42.24616348743439, 44.68202278017998, 48.53336691856384, 52.37500637769699, 52.258390635252, 54.96297910809517, 53.98670509457588, 51.76453113555908, 49.78589370846748, 45.07222384214401, 44.840284287929535, 46.02327100932598, 48.89504291117191, 49.8825491219759, 51.84659533202648, 51.2190818041563, 49.240144193172455, 48.08769263327122, 51.225651651620865, 48.83186750113964, 46.19697488844395, 38.3187360316515, 30.545730628073215, 25.63263986259699, 15.652440246194601, 6.133291264995933, 5.789756923913956, 1.7710905452258885, 2.778679747134447, 4.925425378605723, 7.824208606034517, 8.014629688113928, 5.304973712190986, 8.186070788651705, 6.493882890790701, 3.4757777536287904, 0.19333024160005152, 0.1871850955649279, 0.08479115131194703, 0.8172107487916946, 7.326574958860874, 14.844569396227598, 20.1479172706604, 20.53569406270981, 21.265336610376835, 29.229046180844307, 28.323695361614227, 14.663705751299858, 3.381872442550957, 0.054262635749182664, 0.0560728192795068, 0.09224527515470982, 0.05104525858769193, 0.025882426198222674, 0.025421994068892673, 0.04923450731439516, 0.01722106371744303, 0.057091936469078064, 0.012603149061760632, 0.048521340504521504, 0.02764475233561825, 0.032841619176906534, 0.02975407518533757, 0.03970072611991782, 0.02634388249134645, 0.04225831544317771, 0.05327982442395296, 0.09610557113774121, 0.002443287448841147, 0.027747118620027322, 0.07601811972563155, 0.13615932577522472, 0.04882304208877031, 0.02335721677809488, 0.012690754956565797, 0.018508439461584203, 0.025671205403341446, 0.016632130573270842, 0.07944442259031348, 0.06337038706988096, 0.11301314239972271, 0.12268657723325305, 0.11368773979484104, 0.1769469605642371, 0.14026467892108485, 0.12486312567489222, 0.17819173517636955, 0.18575490277726203, 0.2587494906038046, 0.22159529209602624, 0.1691248724819161, 0.13805609196424484, 0.08963018422946334, 0.15220725996186957, 0.17953365691937506, 0.11566082102945074, 0.1151296214084141, 0.36172636959236115, 0.10406672285171226, 0.20443965797312558, 0.15118428360437974, 0.10701088947826065, 0.08737659343751147, 0.08052592471358366, 0.18793505063513294, 0.06794996515964158, 0.147180515632499, 0.10216588227194734, 0.23300839529838413, 0.14191463647875935, 0.16717780352337286, 0.19216456508729607, 0.11502812529215589, 0.08418063836870715, 0.12487405008869246, 0.17053400311851874, 0.12827292317524552, 1.675591457169503, 14.273983463644981, 39.23648178577423, 49.48502205312252, 37.01900437474251, 20.99575437605381, 17.930831238627434, 18.948251344263554, 8.784725815057755, 2.765237018465996, 0.3709467232692987, 1.885822182521224, 6.2656547874212265, 9.785833396017551, 11.230985149741173, 9.192298594862223, 13.36950184777379, 10.327127650380135, 21.929440274834633, 10.070954896509647, 7.4299113638699055, 7.8922914527356625, 5.2332069631665945, 2.3734540538862348, 0.728925276780501, 3.1173095013946295, 9.783320780843496, 25.50527449697256, 41.12721472978592, 50.224051997065544, 53.23109284043312, 60.265434980392456, 58.1478276103735, 58.686543703079224, 52.00050227344036, 52.25366748869419, 52.661780789494514, 56.429358422756195, 47.39669971168041, 53.95052343606949, 52.981248646974564, 54.8708226531744, 59.34774622321129, 56.00748986005783, 56.02811135351658, 53.53762999176979, 44.37776930630207, 44.00173768401146, 46.6972978413105, 55.10042533278465, 52.149465680122375, 58.86678323149681, 50.249856412410736, 45.61024457216263, 58.27276490628719, 56.3150529563427, 54.29392620921135, 47.682702764868736, 43.51319029927254, 44.270360469818115, 47.08933040499687, 50.57284668087959, 53.65333378314972, 54.722691401839256, 55.889737978577614, 55.403132289648056, 53.27275760471821, 51.69161304831505, 46.798076033592224, 47.66004078090191, 48.97888161242008, 52.00972817838192, 53.161491975188255, 54.705573320388794, 51.56998537480831, 51.22133508324623, 48.37581217288971, 50.95574453473091, 49.46169510483742, 45.488252118229866, 38.40141959488392, 29.01673447340727, 23.828380778431892, 12.419209890067577, 5.572028132155538, 8.139357045292854, 3.2669031992554665, 4.509618440642953, 7.558082761242986, 10.87694389745593, 14.948501419275999, 12.25909123197198, 17.291466146707535, 10.78087080270052, 14.07073711976409, 5.035983296111226, 1.205613675992936, 0.4938228672835976, 1.4958409150131047, 9.820875115692616, 19.84372079372406, 23.933137357234955, 23.39654915034771, 26.186608336865902, 36.73239715397358, 33.800698667764664, 16.227276250720024, 3.484708461910486, 0.25917334598489106, 0.17915588890900835, 0.19974805269157514, 0.14502491801977158, 0.18094263912644237, 0.12178896446130238, 0.14188934408593923, 0.10882546281209216, 0.09798664090340026, 0.16882406518561766, 0.17098600073950365, 0.18810475012287498, 0.09748097116244026, 0.14293733082013205, 0.07525471693952568, 0.08168971617124043, 0.18131362390704453, 0.17016331519698724, 0.19191576750017703, 0.16052274266257882, 0.09506833070190623, 0.14895628206431866, 0.20628051075618714, 0.2838968380820006, 0.1455642218934372, 0.15367279382189736, 0.10765399012598209, 0.12894870800664648, 0.10352672135923058, 0.15673948160838336, 0.14174383861245587], [0.009309741653851233, 0.037726331283920445, 0.009070991818589391, 0.028276839511818253, 0.03657176101114601, 0.07663504482479766, 0.044108626898378134, 0.05518650570593309, 0.041607225575717166, 0.04864083370193839, 0.00846054937937879, 0.03674286315799691, 0.020770299634023104, 0.07325992046389729, 0.011231796524953097, 0.017036229983204976, 0.030298843121272512, 0.04308652256440837, 0.06284965173108503, 0.041235042226617225, 0.02218368277681293, 0.034671888934099115, 0.011500340806378517, 0.03546668456692714, 0.054560259231948294, 0.08464361235382967, 0.06894008663948625, 0.03218279613065533, 0.05037701026594732, 0.014855815879855072, 0.022654042986687273, 0.007023482448857976, 0.03856549250485841, 0.08955791388871148, 0.21921203326201066, 0.05005894803616684, 0.04737085575470701, 0.23240314418217167, 2.603314882144332, 15.271506886929274, 33.221541345119476, 35.80444514751434, 24.640950076282024, 18.2208164781332, 14.835985656827688, 14.968090318143368, 7.424425883218646, 0.8806051220744848, 0.22807637869846076, 0.7528365624602884, 1.0075769713148475, 1.479100319556892, 3.2939254492521286, 8.26788229867816, 7.376844836398959, 9.265799950808287, 4.506030483171344, 2.81803494784981, 3.058894998393953, 3.868547002784908, 2.3606658400967717, 0.9520294738467783, 0.3329693345585838, 1.3978716032579541, 4.328403314575553, 16.912539079785347, 29.64103527367115, 39.11456152796745, 45.64711779356003, 52.368466928601265, 54.81416009366512, 53.603970631957054, 54.974887669086456, 49.30918648838997, 50.6407680362463, 52.60063827037811, 51.49058863520622, 52.85724990069866, 55.803463608026505, 53.081973642110825, 52.45305418968201, 49.49320301413536, 46.36402152478695, 41.32180988788605, 42.79039688408375, 42.93532110750675, 51.362949684262276, 49.61346656084061, 54.504442512989044, 49.60551738739014, 38.68074260652065, 56.32010668516159, 49.08049575984478, 51.52484379708767, 46.289173141121864, 42.21706084907055, 42.8702761977911, 47.777861058712006, 49.26911383867264, 48.62136259675026, 51.633677557110786, 52.187642231583595, 53.12067076563835, 50.11597439646721, 48.69057968258858, 46.34488955140114, 43.03679086267948, 45.003143548965454, 48.07261884212494, 48.900180235505104, 48.05958554148674, 52.30879493057728, 46.42004951834679, 47.2111214697361, 47.10072219371796, 40.75849011540413, 35.948012843728065, 27.326269783079624, 19.14544176310301, 17.184441089630127, 8.807079065591097, 2.7408962370827794, 3.2253576535731554, 0.726216200273484, 2.2754164645448327, 3.9613826712593436, 6.984931491315365, 5.919699026271701, 2.5777833396568894, 5.391175886616111, 3.196768700145185, 2.0998509228229523, 0.339394403854385, 0.21295142389135435, 1.4675644948147237, 7.9138476960361, 26.513985469937325, 48.844596818089485, 40.82366801798344, 23.323328979313374, 19.189350306987762, 24.517422504723072, 19.948876351118088, 7.3902353178709745, 0.2565583144314587, 0.009950386720447568, 0.06271365316933952, 0.015356333260569954, 0.007113101883078343, 0.030651554370706435, 0.03846631560008973, 0.042203218399663456, 0.06452398883993737, 0.02071070146484999, 0.01689742424787255, 0.0425283050572034, 0.04460157251742203, 0.0326557853986742, 0.04200693147140555, 0.0339219078887254, 0.08429001609329134, 0.03370471837115474, 0.07619875847012736, 0.04103244333236944, 0.01515581237981678, 0.041463237794232555, 0.003770584244193742, 0.02822039918100927, 0.013773982573184185, 0.017157610091089737, 0.03967265067331027, 0.01278768779229722, 0.02320192794286413, 0.03147565555991605, 0.020314240609877743, 0.022663034105789848, 0.017605266148166265, 0.03348136160639115, 0.03276088093116414, 0.021679866549675353, 0.02745453060924774, 0.06564331823028624, 0.03992162266513333, 0.05061859788838774, 0.06496506204712205, 0.04533623192401137, 0.024835710391926114, 0.04535399151791353, 0.025426085157960188, 0.052175965101923794, 0.05181554108276032, 0.0209957585320808, 0.01641539747652132, 0.060482263725134544, 0.052111127370153554, 0.057211674575228244, 0.004347215362940915, 0.04950586248014588, 0.03115719257039018, 0.03152192475681659, 0.06970883288886398, 0.10063201887533069, 0.054979791602818295, 0.030899190496711526, 0.043312476846040227, 0.06560640380484983, 0.030848548194626346, 0.02109224886226002, 0.03917987574823201, 0.012429551443347009, 0.03992563026258722, 0.030751137601328082, 0.02847990039299475, 0.32742089009843767, 3.863235362805426, 20.58742828667164, 41.806580275297165, 38.68373304605484, 24.10401038825512, 18.721686601638794, 16.81000918149948, 17.369817942380905, 8.47160266712308, 0.8666556549724191, 0.14019821217516437, 0.33741414605174214, 0.8926011377479881, 1.2412627693265676, 5.195873491466045, 6.527291648089886, 7.017339002341032, 9.361158683896065, 4.51795756816864, 8.633264992386103, 5.40899645537138, 5.539403082802892, 4.992821412160993, 1.954922543372959, 1.3099394529126585, 2.739464188925922, 7.738539827987552, 21.876140534877777, 34.49496701359749, 42.00966417789459, 49.40760500729084, 54.900548458099365, 56.54929518699646, 54.6684455126524, 53.24718877673149, 51.12892784178257, 52.54135765135288, 51.65317431092262, 51.40930339694023, 53.47567431628704, 57.281945273280144, 54.96105261147022, 53.906958773732185, 51.606208831071854, 48.796404004096985, 43.14179442822933, 44.73307304084301, 44.5169672369957, 54.323051646351814, 52.67577163875103, 58.42217668890953, 49.05898131430149, 42.00088284909725, 57.030417770147324, 50.93510404229164, 53.11559043824673, 47.715605199337006, 45.04783295094967, 44.39568154513836, 48.14621329307556, 50.24514086544514, 50.98084218800068, 52.813271060585976, 53.5454385727644, 54.71110202372074, 52.21008762717247, 50.02471849322319, 46.821615770459175, 45.295815244317055, 44.6198733150959, 50.26357747614384, 49.882932901382446, 51.05239614844322, 51.732384860515594, 47.85337060689926, 48.93661268055439, 47.30866223573685, 43.51425044238567, 37.227438390254974, 30.3939800709486, 19.924042783677578, 16.787204705178738, 11.864815838634968, 3.1873900908976793, 4.551903521642089, 1.245115406345576, 3.4542400343343616, 4.217720003798604, 6.764422198757529, 8.149583246558905, 4.600177556276321, 5.07876425050199, 4.35344017110765, 1.745974130462855, 0.39533161791041493, 0.12234550842549652, 1.2458195560611784, 6.37135561555624, 23.092896044254303, 41.95809714496136, 35.32947063446045, 23.145361728966236, 21.426206678152084, 29.53549973666668, 24.131731800734997, 9.340630285441875, 0.5083702085539699, 0.04179433213721495, 0.026694285661506, 0.03776364275836386, 0.03581097429560032, 0.07234971344587393, 0.019930622620449867, 0.12087310227798298, 0.026445647636137437, 0.0561558581830468, 0.10362734174123034, 0.016356591549993027, 0.025786433106986806, 0.02458634877257282, 0.06691581947961822, 0.03190361130691599, 0.006429146933442098, 0.023590523887833115, 0.0385143696621526, 0.030589403213525657, 0.0597673231823137, 0.05293895228533074, 0.030302097438834608, 0.026185090719081927, 0.06050551892258227, 0.019503002695273608, 0.03714635400683619, 0.056319872819585726, 0.02028382554271957, 0.011216159473406151, 0.08567967277485877, 0.04068754133186303, 0.11886344058439136, 0.15979539341060445, 0.11283334228210151, 0.12672184937400743, 0.1311610799166374, 0.19471053237793967, 0.08688424524734728, 0.11176319501828402, 0.10936534556094557, 0.07738511863863096, 0.15389524516649544, 0.16122671426273882, 0.07143928378354758, 0.16114482568809763, 0.1464884332381189, 0.08919353422243148, 0.13583328545792028, 0.23586125549627468, 0.16548953630262986, 0.24965049291495234, 0.046921036337153055, 0.11588977358769625, 0.12551317282486707, 0.10848461664863862, 0.1111516950186342, 0.144061773607973, 0.1292688853573054, 0.16025264543714002, 0.21260072942823172, 0.1578372812946327, 0.13087495230138302, 0.09009220084408298, 0.183153304096777, 0.18776248645735905, 0.3594194777542725, 0.09943722790922038, 0.16106835479149595, 0.5047145078424364, 5.04244769923389, 25.49983698874712, 50.623425766825676, 51.26490734517574, 36.085592061281204, 28.785399086773396, 23.13197124749422, 20.49456126987934, 10.053207948803902, 1.4240822405554354, 0.748633750481531, 1.4088391209952533, 2.6905650878325105, 7.117616571485996, 9.672929104417562, 19.447892233729362, 19.153320640325546, 19.776709489524364, 14.09707635641098, 11.752196531742811, 9.972040504217148, 10.769969187676907, 6.4586264826357365, 2.159919524565339, 0.7703084999229759, 2.1111313300207257, 6.148952124640346, 20.256004370748997, 32.34917275607586, 43.189508467912674, 48.4841101616621, 54.32293005287647, 55.65429501235485, 56.31065659224987, 54.18689355254173, 51.46328330039978, 50.05520045757294, 53.58686774969101, 52.4531339854002, 54.621100053191185, 59.300374165177345, 57.33737289905548, 54.44497190415859, 55.280034095048904, 51.28214322030544, 45.70102170109749, 47.30555780231953, 47.06497751176357, 55.11519894003868, 56.860878467559814, 58.75300973653793, 51.99145495891571, 45.96886932849884, 59.23258580267429, 54.66008596122265, 53.56024257838726, 49.67063449323177, 46.46583706140518, 46.01204641163349, 50.99754989147186, 52.74819575250149, 52.18128517270088, 55.77612027525902, 54.30078864097595, 55.204239562153816, 54.306872114539146, 52.47366048395634, 49.96343158185482, 47.398914992809296, 47.246079593896866, 53.92534598708153, 53.15906010568142, 53.575434163212776, 53.51948596537113, 48.653387278318405, 47.35334403812885, 48.074674531817436, 42.75812141597271, 38.13269801437855, 29.408797435462475, 20.26912696659565, 20.378595292568207, 11.888471469283104, 4.100160012021661, 6.588427042588592, 1.9004492601379752, 8.111980464309454, 10.545052606612444, 15.094962660223246, 11.077421139925718, 9.893249832093716, 12.445751465857029, 7.688412917777896, 4.969693478196859, 0.7669269782491028, 0.3524508298141882, 2.0424811262637377, 9.708010721951723, 29.995168671011925, 54.44684520363808, 47.33922019600868, 32.15037502348423, 28.61909721046686, 34.87930119037628, 25.833143703639507, 9.594689402729273, 0.4750652628717944, 0.16747555317124352, 0.13441278511891142, 0.12067535702954046, 0.11555433025932871, 0.19432008848525584, 0.1292141297017224, 0.1553356202202849, 0.1381060978746973, 0.17455586465075612, 0.2478640543995425, 0.08521744835888967, 0.1542935409815982, 0.08278336725197732, 0.3324636648176238, 0.10633293015416712, 0.1835882174782455, 0.13335779251065105, 0.11262869506026618, 0.0745483704668004, 0.08870880046742968, 0.12469612760469317, 0.10378070655860938, 0.07771260614390485, 0.15039478690596297, 0.097453140624566, 0.19437702605500817, 0.21811077516758814, 0.09450406098039821, 0.10780886150314473, 0.17904812906635925, 0.10669074923498556], [0.018994015554198995, 0.06300130218733102, 0.09149094141321257, 0.04546682022919413, 0.013194344828661997, 0.040543572104070336, 0.01075320404197555, 0.02825878676958382, 0.04698918404756114, 0.021040921928943135, 0.01642856132093584, 0.04205638077110052, 0.047186469164444134, 0.027313513273838907, 0.02358417295909021, 0.04564128801575862, 0.030141999486659188, 0.03968301847635303, 0.028066598351870198, 0.07805868444847874, 0.038723402976756915, 0.0338445352826966, 0.0592610114836134, 0.057446664504823275, 0.020010930420539808, 0.038325444838847034, 0.017593527227290906, 0.03456543156062253, 0.02206249933806248, 0.012169846140750451, 0.05598870055109728, 0.007319896230910672, 0.0337922806647839, 0.022999176908342633, 0.008358033737749793, 0.006257028044274193, 0.04915937970508821, 0.05343247306882404, 0.7678637467324734, 5.952676506713033, 21.85315366834402, 40.24122767150402, 28.59313130378723, 23.351483568549156, 27.695361077785492, 18.855304531753063, 13.254047892987728, 5.694947261363268, 1.294597063679248, 0.15292708383640274, 0.5411219573579729, 1.174206817522645, 4.195750532671809, 2.9784737387672067, 4.766229595988989, 4.491687677800655, 3.5020238952711225, 6.529467981308699, 5.194747326895595, 4.726807186380029, 3.0542951077222824, 1.8494931631721556, 1.1982396966777742, 1.0299904248677194, 1.3814798765815794, 6.327387699857354, 12.659911774098873, 23.382421508431435, 34.45217750966549, 43.80943760275841, 51.30881778895855, 55.346697717905045, 52.43870235979557, 53.03639128804207, 53.76058302819729, 51.633430570364, 55.00839427113533, 54.25034634768963, 53.55129025876522, 51.08323909342289, 51.33118338882923, 46.69168934226036, 43.256430476903915, 41.947419717907906, 42.46622487902641, 45.844832584261894, 51.61830358207226, 50.16121096909046, 55.88730990886688, 50.773156732320786, 38.3476372808218, 56.59005180001259, 50.163202062249184, 53.28706003725529, 45.33537492156029, 44.91642080247402, 44.99327167868614, 48.359043672680855, 48.30088399350643, 51.254336312413216, 53.30258220434189, 54.37965340912342, 50.90851686894894, 52.86684438586235, 48.31737890839577, 46.58236920833588, 45.21517977118492, 45.99559709429741, 47.77961276471615, 49.197293892502785, 45.277637019753456, 46.36589102447033, 46.22417762875557, 41.21805265545845, 38.82122106850147, 34.01804320514202, 23.00425250083208, 18.390452675521374, 12.369752693921328, 9.722873624414206, 6.698257774114609, 1.091305478475988, 2.7860461268574, 0.6746541545726359, 1.757636892143637, 3.8163936138153076, 6.675310805439949, 8.147021234035492, 2.8082647221162915, 3.0534833762794733, 4.681790051981807, 1.5721143409609795, 0.13962399767478928, 0.7873607974033803, 3.555674641393125, 13.911117184907198, 25.739391334354877, 24.79838702827692, 34.230144023895264, 40.58746509253979, 34.94146965444088, 21.257824413478374, 11.265041772276163, 1.4222933677956462, 0.043764285219367594, 0.059022926798206754, 0.035934771949541755, 0.05084755044663325, 0.06556718872161582, 0.12511229433584958, 0.026022432357422076, 0.06476423688582145, 0.02442785757011734, 0.0421339797321707, 0.029822052201780025, 0.08010140139958821, 0.03698763088323176, 0.06324031826807186, 0.0359026926162187, 0.0685293746937532, 0.06368475340423174, 0.030026367312530056, 0.07708506091148593, 0.027761223136621993, 0.07663270705961622, 0.02691799123567762, 0.020615055327652954, 0.04143862446653657, 0.018534410919528455, 0.061037713021505624, 0.07948260608827695, 0.030977557580627035, 0.1161160395713523, 0.058657322588260286, 0.03192288859281689, 0.055931647948455065, 0.004800070628334652, 0.07746495888568461, 0.05054919594840612, 0.10964060813421384, 0.03547379434166942, 0.0061519139580923365, 0.036760934453923255, 0.043256288845441304, 0.05843396582349669, 0.012347255615168251, 0.01581162323418539, 0.010745124836830655, 0.007450078210240463, 0.022113675986474846, 0.016424249442934524, 0.09836901022936217, 0.005735433205700247, 0.03634284556028433, 0.024779357263469137, 0.0472962290950818, 0.01528469096228946, 0.030851062219880987, 0.05211338720982894, 0.03663304385554511, 0.03684500865347218, 0.04122765785723459, 0.010105233050126117, 0.0476141540275421, 0.0554580167226959, 0.02585759764770046, 0.021413422546174843, 0.07539482699939981, 0.034448513615643606, 0.0802259857300669, 0.028801454427593853, 0.05608024075627327, 0.11254955985350534, 0.13332435133634135, 1.0928613762371242, 8.232438750565052, 30.190597884356976, 46.63247711956501, 32.14078813791275, 23.597854748368263, 27.079058848321438, 24.6407999843359, 18.995551206171513, 8.037933837622404, 1.1341694346629083, 0.05719827880966477, 0.2890575845958665, 0.6143158266786486, 2.7190352976322174, 4.2763052601367235, 5.720793949440122, 7.529194336384535, 4.52281940728426, 8.505298309028149, 6.579812904819846, 4.900359073653817, 7.198865236714482, 3.8999321311712265, 1.9094829191453755, 2.0484211575239897, 3.0382205452769995, 7.716283472254872, 16.221677251160145, 27.369498163461685, 37.08986297249794, 47.335158213973045, 52.641064301133156, 55.12427285313606, 53.156818225979805, 52.86619082093239, 53.135645762085915, 52.28404685854912, 54.54584889113903, 55.47689013183117, 56.97009980678558, 53.52005213499069, 52.85392887890339, 49.38178539276123, 45.60930982232094, 44.638458117842674, 43.55978719890118, 47.87888623774052, 54.505377262830734, 52.59078919887543, 56.875078305602074, 51.42154633998871, 42.791628018021584, 58.38225983083248, 51.54220886528492, 52.495509311556816, 46.947172433137894, 46.39262638986111, 46.144647896289825, 49.68496732413769, 49.03028905391693, 52.821288630366325, 54.12247560918331, 54.592776373028755, 51.57139889895916, 53.55714574456215, 49.648751467466354, 47.9744017124176, 46.44291669130325, 46.18046477437019, 48.40758986771107, 51.16861671209335, 47.41646625101566, 51.086503118276596, 47.03141011297703, 45.314947217702866, 41.209696903824806, 36.35653652250767, 25.130198523402214, 19.87036306411028, 13.558177873492241, 13.848344553261995, 9.080937970429659, 2.8056084271520376, 2.1065839240327477, 2.8838117932900786, 4.214232740923762, 4.574280995875597, 8.345177751034498, 8.20533575490117, 4.235171992331743, 3.7622954417020082, 2.6753585413098335, 0.2596738503780216, 0.060098009344073944, 0.7095338485669345, 4.681089939549565, 16.044718846678734, 32.214640974998474, 36.49532027542591, 41.7706798017025, 43.28217029571533, 36.09071418642998, 25.79588670283556, 14.527316819876432, 2.3897672910243273, 0.04427417035913095, 0.08345061738509685, 0.032316067299689166, 0.032135369183379225, 0.043829720380017534, 0.1355786991189234, 0.04105415857338812, 0.08258795234723948, 0.08073985620285384, 0.029472135138348676, 0.028984657292312477, 0.01747303769661812, 0.044438029144657776, 0.053681159333791584, 0.03594159228669014, 0.03977750129706692, 0.053769018486491404, 0.06893161131301895, 0.07283876650035381, 0.0455005545518361, 0.03779987069719937, 0.06912695200298913, 0.053428202008944936, 0.045393982145469636, 0.05861538753379136, 0.044729489090968855, 0.06083921078243293, 0.01098703436582582, 0.057531803686288185, 0.01705873746686848, 0.01766387726092944, 0.024983483126561623, 0.07696562708588317, 0.23008905351161957, 0.18599914357764646, 0.24352773005375639, 0.08793569038971327, 0.14049106364836916, 0.07676940324017778, 0.16697463317541406, 0.12658939085667953, 0.09570413603796624, 0.07682308278162964, 0.07292198351933621, 0.12712176307104528, 0.15010575007181615, 0.10285464726621285, 0.14999015314970165, 0.18392234720522538, 0.0888757169013843, 0.12045348456013016, 0.2528253709897399, 0.11004419546225108, 0.11339078424498439, 0.15447204234078526, 0.1518587622558698, 0.07457481318851933, 0.13050022709649056, 0.1521156937815249, 0.09656000300310552, 0.10474357637576759, 0.08032335550524294, 0.16739715269068256, 0.21009785123169422, 0.13204922288423404, 0.12851113773649558, 0.11400805815355852, 0.20102417562156916, 0.26364526071120054, 0.20721401378978044, 1.5468274103477597, 10.262163486331701, 36.153517216444016, 56.721395552158356, 41.10065035521984, 35.401009395718575, 39.486778154969215, 26.40199027955532, 18.640623651444912, 8.046159446239471, 1.7302426183596253, 0.42545096890535206, 1.7009559273719788, 2.587684658356011, 8.640704043209553, 9.68997023999691, 12.448676358908415, 11.95577535778284, 11.100000478327274, 15.041562225669622, 11.794940438121557, 11.450197286903858, 9.276083149015903, 4.3062870763242245, 3.895018044859171, 2.4969749758020043, 2.664051535539329, 8.115066848695278, 14.481076151132584, 26.892680749297142, 38.25716033577919, 47.33894281089306, 54.273221120238304, 57.61269472539425, 53.362151607871056, 52.14633084833622, 53.315767496824265, 51.62465304136276, 55.6397607922554, 57.08566300570965, 58.071523904800415, 55.37009686231613, 55.897284373641014, 50.41260547935963, 46.55227102339268, 47.137029245495796, 45.41953660547733, 50.76750263571739, 56.37711502611637, 53.97556409239769, 58.89289163053036, 51.769679859280586, 46.47184833884239, 60.43853849172592, 54.101082757115364, 56.80515445768833, 49.108986631035805, 48.19550804793835, 48.63648198544979, 52.30141952633858, 53.021689876914024, 54.981704503297806, 56.45753011107445, 55.30838057398796, 53.86955738067627, 54.053345918655396, 52.050378397107124, 50.75033515691757, 50.045997351408005, 47.760005816817284, 52.20742017030716, 53.31740900874138, 49.30858992040157, 49.7303406894207, 49.343236461281776, 45.824081897735596, 40.08170463144779, 37.10797280073166, 24.520175457000732, 20.619823448359966, 14.664771594107151, 11.888936944305897, 8.111866470426321, 2.7132683945819736, 5.299472082406282, 5.185980722308159, 4.694371651858091, 10.394584480673075, 16.199562437832355, 17.83240132033825, 8.679353669285774, 8.253594115376472, 10.911987517029047, 2.9201368940994143, 0.3967601334443316, 1.277528260834515, 4.848322765901685, 18.43235492706299, 32.55796015262604, 33.72606687247753, 41.76854811608791, 47.565410658717155, 44.91131007671356, 30.922191627323627, 16.179374121129513, 2.4247667379677296, 0.12501176301157102, 0.21894631470786408, 0.08326798968482763, 0.09480482374783605, 0.12963900924660265, 0.3089975786861032, 0.149717191234231, 0.191029257257469, 0.14619694731663913, 0.15679508331231773, 0.1849170625791885, 0.09956127047189511, 0.1603477739263326, 0.13708370039239526, 0.12283181553357281, 0.203543885727413, 0.1029731756716501, 0.17366315005347133, 0.2140300316386856, 0.08326456096256152, 0.19461602729279548, 0.11753365295589902, 0.17868208698928356, 0.11909454537089914, 0.0745224546699319, 0.18655076710274443, 0.19054401142057031, 0.10020444533438422, 0.15437995665706694, 0.10290880920365453, 0.07133121966035105, 0.14285683748312294], [0.04477806265640538, 0.01754587392497342, 0.05149041360709816, 0.08362669192138128, 0.009869605801213766, 0.05800782462756615, 0.03811324626440182, 0.03685311661683954, 0.06502418895252049, 0.03616970621806104, 0.012832186966988957, 0.10541421070229262, 0.05306909530190751, 0.09234553930582479, 0.019666295593196992, 0.0563983809115598, 0.01141222654041485, 0.005567390098804026, 0.019055595257668756, 0.036718828705488704, 0.034352219954598695, 0.03645543307357002, 0.028971424799237866, 0.03805735512287356, 0.019777727211476304, 0.02350730686885072, 0.06018662177666556, 0.020996534076402895, 0.07077068294165656, 0.04237404224113561, 0.02438372390315635, 0.04362384119303897, 0.05885238497285172, 0.032447486810269766, 0.03090055975917494, 0.05308008650899865, 0.019593407414504327, 0.05499068633071147, 0.2584593999199569, 2.7477163961157203, 10.948722995817661, 28.990318290889263, 36.40508271753788, 24.470662213861942, 17.81857766211033, 14.798073191195726, 15.652501042932272, 10.806798711419106, 5.174673004075885, 1.050191328395158, 0.045369424478849396, 0.6047702045179904, 2.0435685804113746, 2.073243325576186, 3.3080540411174297, 6.208365261554718, 2.125066607259214, 7.148654730990529, 4.551957193762064, 2.252885573543608, 7.931892927736044, 3.9319822238758206, 2.3930636141449213, 0.9648583573289216, 1.971472199074924, 2.3695649625733495, 6.317901983857155, 12.721965294331312, 20.53367257118225, 31.581895127892494, 39.3422757089138, 47.70428940653801, 54.20969232916832, 53.93727354705334, 53.461375683546066, 55.21375045180321, 55.29460251331329, 55.53530439734459, 54.30806905031204, 51.51305302977562, 50.10918416082859, 47.17977695167065, 47.72627882659435, 45.84246151149273, 49.872213676571846, 49.52605605125427, 52.057617008686066, 53.27739715576172, 55.661244839429855, 50.0287576764822, 36.85428321361542, 57.38696023821831, 51.36307127773762, 51.77808880805969, 48.720187693834305, 49.32746350765228, 51.411115899682045, 52.93319642543793, 49.191780388355255, 51.01435258984566, 51.84048905968666, 53.78653563559055, 53.23368430137634, 52.78968192636967, 51.763976365327835, 48.003644943237305, 46.388997584581375, 47.36073464155197, 47.73450158536434, 49.767886474728584, 47.83960774540901, 44.02737870812416, 40.57130075991154, 29.907419979572296, 28.31498622894287, 20.494129993021488, 14.5847431384027, 10.475265551358461, 6.4833303820341825, 4.8843486327677965, 6.506539061665535, 0.7126711145974696, 2.1089853951707482, 1.6757898777723312, 2.82216580118984, 1.3710312684997916, 3.8759456807747483, 4.916398013010621, 3.376775016076863, 2.4324026657268405, 1.219315503258258, 0.3500965592684224, 0.25790106737986207, 1.2771518435329199, 8.181831166148186, 19.254953786730766, 18.499119244515896, 17.248862832784653, 19.213089533150196, 32.92956881225109, 38.059601336717606, 19.19774405658245, 4.5140827260911465, 0.3927736129844561, 0.03909597966412548, 0.009672792875790037, 0.02836366151313996, 0.045673760687350295, 0.020191259318380617, 0.01677956934145186, 0.06834624975454062, 0.06204409495694563, 0.09667288366472349, 0.026755086109915283, 0.07868617030908354, 0.026214210738544352, 0.10893361599300988, 0.006398357545549516, 0.029654623685928527, 0.012900887577416142, 0.027780207274190616, 0.08058076942688785, 0.029189942761149723, 0.02083080507873092, 0.027529704602784477, 0.04804271833563689, 0.05785740984720178, 0.04727862906293012, 0.07344323094002903, 0.02865864666091511, 0.03476087986200582, 0.023314253849093802, 0.027691014111042023, 0.047803141933400184, 0.08243918142397888, 0.06100920341850724, 0.039924854718265124, 0.07483403795049526, 0.024429403092653956, 0.08422333412454464, 0.0637954447302036, 0.03505465901980642, 0.05289391505357344, 0.039745284666423686, 0.07432690617861226, 0.10021165158832446, 0.046903777692932636, 0.04173191380687058, 0.032293468902935274, 0.02777679339487804, 0.027703988707799, 0.04826267235330306, 0.012168688390374882, 0.022546034524566494, 0.03942203111364506, 0.01843849018769106, 0.044038122869096696, 0.064526638307143, 0.044687925110338256, 0.08978008321719244, 0.04350467825133819, 0.08169201682903804, 0.006109169962655869, 0.009980218273994979, 0.0608521204412682, 0.05221817846177146, 0.0314996788802091, 0.0192761077414616, 0.08463921141810715, 0.064406640449306, 0.02504052459698869, 0.05891334869374987, 0.04990149769582786, 0.05734932441555429, 0.28445484407711774, 3.7547160359099507, 14.453586526215076, 37.755815237760544, 42.012358233332634, 27.97321166843176, 23.18874780088663, 16.330083534121513, 18.110947273671627, 14.312680587172508, 6.13880286924541, 0.8264886634424329, 0.1740083229378797, 0.25859705347102135, 0.6809989828616381, 1.4979993179440498, 4.683114280924201, 5.231507504358888, 5.3039848152548075, 8.2834168151021, 7.063523149117827, 5.422868086025119, 6.872833706438541, 5.517383264377713, 3.364565558731556, 3.5316879535093904, 3.2071905909106135, 3.926455182954669, 7.608804339542985, 16.108302734792233, 24.377709701657295, 35.36040097475052, 43.53126972913742, 50.00986509025097, 54.459844306111336, 54.09014694392681, 54.50383834540844, 53.54742966592312, 56.14068031311035, 57.30487324297428, 55.78441143035889, 53.45175839960575, 52.907331213355064, 50.76432980597019, 48.359241262078285, 48.28204080462456, 51.08154058456421, 51.20600290596485, 55.79902924597263, 55.88126063346863, 56.21953368186951, 51.00119769573212, 39.96938265860081, 58.463993445038795, 53.77542123198509, 55.19313655793667, 50.61446584761143, 52.39878550171852, 52.83767335116863, 55.34918278455734, 51.92372739315033, 53.85013282299042, 54.05646175146103, 55.16742713749409, 54.14866380393505, 54.10835936665535, 52.12942935526371, 51.2693265080452, 49.16263595223427, 48.77135194838047, 48.858359679579735, 52.49689243733883, 50.17294093966484, 46.55678138136864, 43.50467875599861, 33.07883620262146, 30.462222509086132, 24.11493670195341, 17.70546343177557, 12.388721276074648, 7.216640682891011, 6.048089386895299, 4.237320777028799, 2.4127517826855183, 2.4172925390303135, 2.6047590421512723, 5.52715633995831, 4.88887039013207, 5.724936677142978, 7.105346554890275, 3.003987707197666, 1.8533780984580517, 0.6459959736093879, 0.28838436759542674, 0.6032255874015391, 2.153074429370463, 8.297293670475483, 23.552836664021015, 23.623332381248474, 17.56843328475952, 22.255856059491634, 37.53187045454979, 42.45177045464516, 23.245655447244644, 6.1186259519308805, 0.46151943504810333, 0.0577655579400016, 0.005247723902357393, 0.03632192441727966, 0.0255740118882386, 0.07219648221507668, 0.029484553124348167, 0.06218551490746904, 0.03582005447242409, 0.014125344041531207, 0.029567977944680024, 0.00734909974198672, 0.016243887148448266, 0.04029028823424596, 0.01166997257314506, 0.08423428080277517, 0.032278518337989226, 0.019864313580910675, 0.06403371866326779, 0.04241924274538178, 0.026489564224903006, 0.034001647945842706, 0.02410897155641578, 0.010687019312172197, 0.0019782591061812127, 0.024868132968549617, 0.057257268417743035, 0.11391241758246906, 0.03194774311850779, 0.020138898944424, 0.07297092073713429, 0.09099662653170526, 0.04719854019640479, 0.09209245210513473, 0.16092232981463894, 0.1337093478650786, 0.12491838599089533, 0.13014953263336793, 0.2190020351554267, 0.24827388318954036, 0.11702344127115794, 0.26278490375261754, 0.29181926453020424, 0.12191134461318143, 0.20705881586764008, 0.14074072212679312, 0.09933920504408889, 0.15392266010167077, 0.1776556225377135, 0.14277120848419145, 0.12990581133635715, 0.1202723708411213, 0.1787987377610989, 0.15236588660627604, 0.15193766739685088, 0.14294737949967384, 0.22282278951024637, 0.1441963843535632, 0.14237280876841396, 0.15334391850046813, 0.09764269256265834, 0.11223341978620738, 0.11023418526747264, 0.19246127572841942, 0.15353766357293352, 0.12046583389746957, 0.1638565442408435, 0.12695972254732624, 0.19075121905189008, 0.2132007706677541, 0.16758657846366987, 0.3257283481070772, 4.345442550256848, 18.98674327880144, 48.14447298645973, 51.40195079147816, 36.00212574005127, 29.22769535332918, 24.42211601883173, 23.74414499849081, 15.383943803608418, 6.696326527744532, 1.5014312462881207, 0.4134641558630392, 1.823809272609651, 5.4392575565725565, 7.364601418375969, 9.05700970441103, 15.368984006345272, 8.842936791479588, 16.116620488464832, 12.372515145689249, 7.968157231807709, 17.21509214490652, 10.577119085937738, 5.59159898199141, 3.143013222143054, 3.721257643774152, 3.940867097117007, 7.788928924128413, 15.125025697052479, 23.37181057780981, 34.80067580938339, 42.09680490195751, 50.75472392141819, 54.85651642084122, 53.8724984228611, 54.869257137179375, 54.1070332378149, 57.30941019952297, 59.0246419608593, 59.06125299632549, 57.2919425368309, 53.83208379149437, 53.44814099371433, 50.6964198499918, 50.56864030659199, 54.80418562889099, 52.914938405156136, 56.25639550387859, 58.949785977602005, 59.022897854447365, 52.72345907986164, 43.60598511993885, 60.265032202005386, 57.15810611844063, 55.31970016658306, 52.617995738983154, 53.64719331264496, 55.34548178315163, 57.714324072003365, 53.182706236839294, 55.656536892056465, 55.07460951805115, 55.14853075146675, 55.474272072315216, 54.30356249213219, 55.7538116723299, 51.36572353541851, 52.43309386074543, 51.991166174411774, 53.65841031074524, 53.538131564855576, 52.375815734267235, 47.90873363614082, 44.16995085775852, 33.32089841365814, 29.728592075407505, 22.243008948862553, 16.68038673698902, 11.500170305371284, 8.780831024050713, 6.221390487626195, 10.024871919304132, 2.2910533379763365, 4.830690287053585, 4.607169656082988, 7.828869530931115, 7.62752640992403, 10.363792832940817, 11.870253346860409, 8.808763325214386, 6.849350966513157, 3.1558990431949496, 0.868585417047143, 0.7683652604464442, 2.376963165588677, 12.633052915334702, 27.082938440144062, 26.070959642529488, 26.04202039539814, 28.70641652494669, 42.831271290779114, 45.75710669159889, 25.848466381430626, 6.886547170579433, 0.5576057103462517, 0.26784831017721444, 0.13813757977914065, 0.08571727739763446, 0.1379025267669931, 0.11948240658966824, 0.12343209426035173, 0.1737592730205506, 0.14112444216152653, 0.17232100566616282, 0.1786704352707602, 0.15051768656121567, 0.07466073162504472, 0.1781392059638165, 0.09080075891688466, 0.14125771704129875, 0.09730735313496552, 0.10872689075767994, 0.19013422715943307, 0.14606373180868104, 0.21859045489691198, 0.0789043765689712, 0.1531316345790401, 0.18710350384935737, 0.15851787524297833, 0.22620463772909716, 0.18578764633275568, 0.18532616406446323, 0.15658118150895461, 0.15617877419572324, 0.1477543293731287, 0.22815311676822603, 0.14850578358164057], [0.007408952096739085, 0.05735304257541429, 0.03666048476588912, 0.0473636643437203, 0.04847294505452737, 0.021207977515587118, 0.04546005555312149, 0.06344216759316623, 0.029783273130306043, 0.03029633837286383, 0.029458720819093287, 0.05562544894928578, 0.02989123335282784, 0.04077694786246866, 0.020310021500336006, 0.03129694639937952, 0.06339635481708683, 0.062149038349161856, 0.04047951733809896, 0.013842281496181386, 0.06393453804776073, 0.09620079610613175, 0.07485268812160939, 0.05976895219646394, 0.06326050468487665, 0.08006605290574953, 0.0566499763954198, 0.03474283454124816, 0.03161219217872713, 0.028719465663016308, 0.05114038707688451, 0.017363864062645007, 0.026687005192798097, 0.07050707208691165, 0.04163918245467357, 0.06749308420694433, 0.009255523127649212, 0.011951168617088115, 0.03057829882891383, 0.2047205311828293, 3.7950625084340572, 12.868932858109474, 25.807175897061825, 31.92073054611683, 29.00802344083786, 21.404570639133453, 13.388432431966066, 16.019269712269306, 10.429778192192316, 4.181600566953421, 1.1758944019675255, 0.0326781166222645, 0.4161960311466828, 0.4422206268645823, 3.2701919227838516, 4.052330078557134, 3.519288506358862, 5.252581173554063, 5.379378944635391, 3.7645931309089065, 4.889073679223657, 3.669147239997983, 0.43990272155497223, 3.172254078090191, 1.788248405791819, 1.45722774323076, 2.0820061303675175, 7.03075940720737, 13.466295003890991, 19.819046817719936, 28.388759270310402, 39.1109973192215, 47.30958938598633, 50.5533043295145, 55.03822647035122, 57.277066335082054, 55.66002130508423, 54.78213921189308, 54.777381867170334, 52.80216425657272, 54.443850964307785, 52.047327160835266, 53.06505315005779, 51.44739255309105, 52.18228831887245, 50.9714262932539, 54.64746683835983, 53.28408479690552, 53.03786180913448, 47.9731135815382, 41.203434839844704, 53.626480624079704, 51.00946605205536, 53.749020248651505, 50.723402202129364, 50.23259773850441, 50.889658480882645, 52.00106084346771, 51.51789776980877, 55.38965821266174, 52.30259366333485, 53.35756905376911, 53.46540726721287, 53.82162295281887, 52.57335193455219, 51.34147323668003, 48.40234614908695, 47.766302078962326, 47.04454220831394, 48.45181569457054, 47.64137238264084, 37.701877132058144, 27.801928259432316, 20.544558987021446, 17.021838314831257, 11.531462576240301, 6.918367613106966, 3.969595218077302, 1.1450288956984878, 4.67944510281086, 2.297883233986795, 2.3194603761658072, 0.3950198565144092, 2.4241727823391557, 5.04758027382195, 4.367792000994086, 6.361777754500508, 6.232250779867172, 3.1109693041071296, 1.1350937350653112, 0.5671086441725492, 0.2174925958388485, 2.3426374699920416, 7.613935014232993, 16.854387000203133, 22.63406116515398, 27.165732197463512, 25.462931469082832, 24.9387438967824, 30.642482936382294, 25.63112184405327, 10.420286301523447, 1.8805098300799727, 0.037008719009463675, 0.019844817361445166, 0.03502853542158846, 0.034100086413673125, 0.014420960014831508, 0.08931053380365483, 0.033773682444007136, 0.020201497245579958, 0.06491749038104899, 0.01868462346465094, 0.016027797864808235, 0.03432117591728456, 0.07613032503286377, 0.03713584519573487, 0.029124819302523974, 0.027062043955083936, 0.03265896550146863, 0.044579374880413525, 0.029191302746767178, 0.038179223192855716, 0.03673345643619541, 0.03764645392948296, 0.017494504318165127, 0.05069358077889774, 0.03380694550287444, 0.015948234067764133, 0.03839831260847859, 0.08417713543167338, 0.00763597599870991, 0.07259267033077776, 0.05139696608239319, 0.03946249300497584, 0.018325412856938783, 0.00783898771260283, 0.03186063353496138, 0.015593981006531976, 0.04479712100874167, 0.05586879917245824, 0.05134273364092223, 0.1228408919996582, 0.11230099975364283, 0.025600879489502404, 0.06196809532411862, 0.020708951851702295, 0.07052845336147584, 0.012702917829301441, 0.034163502932642587, 0.023817942055757158, 0.059915593155892566, 0.05954933585599065, 0.01830344528571004, 0.04534923435130622, 0.0478936134459218, 0.043405783362686634, 0.013628340730065247, 0.06469849002314731, 0.10794802903546952, 0.008093850501609268, 0.05808142712339759, 0.020889028419333044, 0.06704038896714337, 0.01979160908376798, 0.045599731456604786, 0.0340166319074342, 0.02144578204024583, 0.01748392685840372, 0.018517222779337317, 0.06450167988077737, 0.016276118622045033, 0.019849118107231334, 0.011788098363467725, 0.016258646610367578, 0.3697411488974467, 5.839761765673757, 20.51580213010311, 33.8435185700655, 36.766633316874504, 27.74140700697899, 20.252727046608925, 17.846141383051872, 19.183418825268745, 16.366426683962345, 7.051786528900266, 1.448317696340382, 0.04856772473431192, 0.1305223282543011, 0.6079632206819952, 1.8138998793438077, 2.762541538104415, 4.839376145973802, 7.116199247539043, 6.445875791832805, 5.034264363348484, 8.23644943535328, 5.547540346160531, 4.0436299704015255, 6.851030001416802, 4.1172286961227655, 2.5634673703461885, 4.275600872933865, 8.292564824223518, 14.320164285600185, 23.10622002929449, 30.616657622158527, 42.307723984122276, 49.91071321070194, 50.84873087704182, 55.463096871972084, 57.44762398302555, 56.055257096886635, 54.966516718268394, 57.10802860558033, 54.59640137851238, 55.22297255694866, 53.44812959432602, 54.09194424748421, 52.47913219034672, 54.56833988428116, 52.87881754338741, 56.74074411392212, 55.70915266871452, 54.71729949116707, 49.25378546118736, 42.31468141078949, 55.391957089304924, 52.84640148282051, 55.34855201840401, 51.53528183698654, 51.14907816052437, 52.925433441996574, 54.06343437731266, 53.63891735672951, 56.93202584981918, 53.51069703698158, 53.619724586606026, 54.35763739049435, 53.74342314898968, 52.910230457782745, 52.02054239809513, 49.43501673638821, 49.68624405562878, 49.04337555170059, 50.76206132769585, 50.161195769906044, 41.93476639688015, 31.867970377206802, 24.37068957835436, 21.4408415928483, 12.443679627031088, 9.889363590627909, 5.657235234975815, 2.748517678119242, 3.2663227804005146, 4.29230572655797, 5.837733149528503, 2.6800529519096017, 2.5263894349336624, 8.20007398724556, 4.269601469859481, 4.883394883945584, 4.539541359990835, 1.9904121640138328, 0.8605650567915291, 0.2369512923178263, 0.2463841822464019, 2.1920931106433272, 6.760707898065448, 17.55497630685568, 27.48698215931654, 28.68225172162056, 29.71116241067648, 30.032691657543182, 33.84907767176628, 30.673474073410034, 12.958382908254862, 2.3538846289739013, 0.07035554779577069, 0.1017061663151253, 0.06429625340388156, 0.06376903169439174, 0.02483742846379755, 0.039075422173482366, 0.045251140982145444, 0.030645388978882693, 0.008015689363674028, 0.03926903737010434, 0.04479752547922544, 0.05867394298547879, 0.0477790369768627, 0.03718358013429679, 0.03797416778979823, 0.03662111012090463, 0.011532496209838428, 0.015483762799703982, 0.01635481781704584, 0.03584171776310541, 0.05679909612808842, 0.03521950857248157, 0.030523266723321285, 0.11914753471501172, 0.062440706096822396, 0.016661732988723088, 0.04474718931305688, 0.0635399529710412, 0.148633744684048, 0.038205087039386854, 0.04877486928307917, 0.0543624212150462, 0.06477923569036648, 0.2227747577126138, 0.14423292770516127, 0.12578163732541725, 0.26488150062505156, 0.1318095240276307, 0.11728501121979207, 0.1924858705024235, 0.17651415488217026, 0.09394984735990874, 0.2552916167769581, 0.09630625529098324, 0.3443311108276248, 0.13956210255855694, 0.18835526949260384, 0.20399557164637372, 0.08715043135453016, 0.1303198406822048, 0.11882896782481112, 0.14729019021615386, 0.1927608807454817, 0.10422733845189214, 0.2801484282827005, 0.15375579561805353, 0.17109882202930748, 0.1218341315689031, 0.2532093581976369, 0.0984414215781726, 0.15875985991442576, 0.06862924550659955, 0.11263717038673349, 0.14933212049072608, 0.15885071363300085, 0.11745177922421135, 0.16032435174565762, 0.10049081785837188, 0.15283694257959723, 0.11215880425879732, 0.0872157551930286, 0.13667744875419885, 0.4263606044696644, 7.052591610699892, 25.002052299678326, 43.652912601828575, 47.59857527911663, 37.53866828978062, 31.693725027143955, 25.19317254424095, 23.967183530330658, 14.930285196751356, 6.192925740033388, 1.6988336225040257, 0.29599239060189575, 1.303026673849672, 3.1708279671147466, 8.87080829590559, 9.447467252612114, 12.014488857239485, 14.653967823833227, 12.42013894021511, 10.945199634879827, 12.5945495814085, 10.06135756149888, 5.994150806218386, 8.784459829330444, 4.261638047173619, 2.440754142589867, 3.517373646609485, 9.04617553576827, 15.193381179124117, 22.512403093278408, 30.768100395798683, 42.412837743759155, 47.969944551587105, 51.44173465669155, 54.80347126722336, 59.40884314477444, 56.93284660577774, 57.50186987221241, 59.15968671441078, 58.4623671323061, 58.94385829567909, 56.440685614943504, 57.52764768898487, 54.6506130695343, 56.751125156879425, 55.60174003243446, 58.39824177324772, 59.41364988684654, 57.66926608979702, 52.793572917580605, 47.484991773962975, 56.69921234250069, 55.03182001411915, 57.75147847831249, 54.33078423142433, 52.89050571620464, 55.626841485500336, 54.942137226462364, 55.37974074482918, 58.80921632051468, 52.94417403638363, 53.47002401947975, 54.21007610857487, 55.05110017955303, 55.15693210065365, 55.08796580135822, 51.071322932839394, 52.04777933657169, 52.107078954577446, 53.25852356851101, 53.277796134352684, 40.83732828497887, 32.681312933564186, 23.53242225944996, 19.67418909072876, 13.10274001210928, 8.652871940284967, 5.074060577899218, 2.8090629167854786, 6.968043297529221, 4.600037913769484, 8.544764891266823, 4.745429512113333, 5.782824195921421, 12.005646731704473, 11.15717126056552, 14.719541855156422, 13.396859429776669, 7.29242904111743, 3.4491734812036157, 1.5602499525994062, 0.6221851450391114, 3.522738008759916, 10.415548905730247, 23.130622319877148, 32.136349976062775, 37.149576768279076, 36.981675177812576, 36.3850349932909, 40.06489433348179, 31.581902727484703, 13.81843350827694, 2.5536703085526824, 0.10543289798079059, 0.1683886768296361, 0.15308964386349544, 0.1117080682888627, 0.1253959580208175, 0.196589813567698, 0.14155007869703695, 0.1698188844602555, 0.12434264266630635, 0.14796667266637087, 0.059015950610046275, 0.16858362418133765, 0.15640030527720228, 0.12488641426898539, 0.07622746474226005, 0.07013346752501093, 0.13971780514111742, 0.12858060275902972, 0.1870911693549715, 0.17900275415740907, 0.16382353351218626, 0.18164365697884932, 0.08666184585308656, 0.2665249421261251, 0.1049366757797543, 0.08356559090316296, 0.17229200253495947, 0.15620161750121042, 0.2843027631752193, 0.1956596947275102, 0.20847599138505757, 0.10974497636198066, 0.17561381100676954], [0.043178519190405495, 0.006726707797497511, 0.06195062516781036, 0.04070353461429477, 0.025282694805355277, 0.03636524357716553, 0.10703945474233478, 0.044019966226187535, 0.04926851994241588, 0.11796461811172776, 0.038002187575330026, 0.10938995517790318, 0.04566181210975628, 0.01573543620907003, 0.05968568322714418, 0.04182023309112992, 0.05010899476474151, 0.011772217330872081, 0.08741613506572321, 0.04550209821900353, 0.051728090111282654, 0.04500811359321233, 0.03571479937818367, 0.03359197871759534, 0.0902661305735819, 0.06967150286072865, 0.02954310486529721, 0.07156622072216123, 0.023121210106182843, 0.03609066749049816, 0.04665881329856347, 0.060581485158763826, 0.06706618602038361, 0.030331427115015686, 0.041058281203731894, 0.04854669597989414, 0.03163945126289036, 0.06867577074444853, 0.029484885235433467, 0.01610676608834183, 1.2887194915674627, 5.485148169100285, 17.840483486652374, 27.127513848245144, 39.985432997345924, 22.080105990171432, 17.11297832429409, 20.05780890583992, 12.918057572096586, 8.550510182976723, 3.8995400397107005, 0.920263712760061, 0.3440442855935544, 0.5973377439659089, 1.1597176012583077, 1.9193452899344265, 2.7964167203754187, 5.817175777629018, 4.7147490084171295, 3.8318632962182164, 4.9306529480963945, 3.91312169842422, 3.5374477319419384, 5.468039587140083, 3.9814398949965835, 2.0954469591379166, 1.3972366810776293, 2.438690853305161, 5.515873795375228, 12.22407516092062, 17.97275248914957, 24.93498209863901, 31.324666030704975, 39.726986065506935, 45.10281220078468, 56.399765610694885, 55.59606313705444, 56.95225216448307, 54.93162699043751, 54.126602187752724, 55.737495347857475, 54.678940549492836, 57.03387938439846, 55.68699985742569, 55.88837385177612, 54.883620366454124, 55.44659435749054, 54.04169574379921, 53.715715035796165, 53.52174684405327, 38.24545696377754, 50.229462906718254, 51.16409495472908, 51.769121289253235, 55.12210316956043, 53.81179668009281, 54.73433017730713, 57.691240310668945, 56.145392060279846, 55.174654349684715, 55.823195949196815, 54.202366322278976, 55.756558924913406, 54.927036836743355, 55.216664895415306, 52.82234117388725, 51.09297797083855, 50.70536457002163, 48.27311888337135, 48.09421308338642, 40.03654785454273, 24.429708011448383, 16.625840663909912, 11.76561551168561, 7.153820553794503, 3.3648277446627617, 3.5920310905203223, 3.88700807467103, 0.9195151529274881, 0.7636133779305965, 3.102810666896403, 3.5270590893924236, 1.9555406039580703, 1.2151149474084377, 6.3640357833355665, 2.67646926920861, 3.896046602167189, 4.2980472184717655, 1.3957802904769778, 0.7190858828835189, 0.1858827006071806, 1.517638920340687, 7.072716755792499, 15.041676219552755, 20.031810700893402, 26.149300038814545, 24.856907688081264, 20.70267990231514, 21.662804782390594, 17.110204473137856, 9.383883364498615, 2.2024283185601234, 0.11907917549251579, 0.10617570616886951, 0.03078198311413871, 0.03345658129546791, 0.0658369371376466, 0.048835732814040966, 0.043359020637581125, 0.019396443276491482, 0.037241630925564095, 0.025983644009102136, 0.021664667365257628, 0.07545950516941957, 0.052605998862418346, 0.07177877923822962, 0.04960523234331049, 0.020746181689901277, 0.02601383086584974, 0.03545102896168828, 0.06251786719076335, 0.04263347109372262, 0.025921236810972914, 0.03912433341611177, 0.055720113596180454, 0.040047372167464346, 0.06070540897781029, 0.033085032482631505, 0.07990629077539779, 0.03071825860388344, 0.030892897084413562, 0.031742899227538146, 0.02362759787502, 0.01938604393217247, 0.04160828684689477, 0.02735848927841289, 0.04579597014526371, 0.10302393857273273, 0.016407309922215063, 0.046877416607458144, 0.09162959686364047, 0.010177441236010054, 0.07024649661616422, 0.04494912769587245, 0.05124812465510331, 0.007205813753898838, 0.02663271894562058, 0.038578543171752244, 0.006185184902278706, 0.05525338063307572, 0.03041126736206934, 0.03506113054754678, 0.003324972108202928, 0.026914043010037858, 0.053804994095116854, 0.036942790320608765, 0.029080572458042298, 0.06976030083023943, 0.030472197686322033, 0.0740963951102458, 0.0620772763795685, 0.028135356478742324, 0.021155600443307776, 0.019443608616711572, 0.03781508101383224, 0.08879563916707411, 0.04328138085838873, 0.01610069717571605, 0.002740634249676077, 0.03566929830412846, 0.013853803338861326, 0.04345585606642999, 0.06554346226039343, 0.06172308640088886, 0.01240142590177129, 0.09334801754448563, 1.7103888024576008, 8.654322512447834, 22.45259430259466, 37.84147024154663, 42.70859867334366, 25.908774845302105, 17.543421126902103, 18.712857775390148, 15.20260613411665, 12.665802408009768, 5.251739518716931, 0.8688609022647142, 0.032428413614979945, 0.20819379715248942, 0.6983432709239423, 1.6621172614395618, 2.2448314307257533, 3.6242597736418247, 6.949103688821197, 5.096954824402928, 6.577801862731576, 6.228452883660793, 4.366678185760975, 8.872884884476662, 5.91793829575181, 4.582934081554413, 3.878557803109288, 3.5539623582735658, 8.756501879543066, 14.242883082479239, 20.20363748073578, 26.70822534710169, 34.14557956159115, 42.78725825250149, 46.85273230075836, 56.71433553099632, 56.705770790576935, 58.801050558686256, 57.630492970347404, 55.742708668112755, 57.62026011943817, 55.79688236117363, 57.11212858557701, 58.59443664550781, 56.34773500263691, 56.73126362264156, 58.09739671647549, 55.33545032143593, 54.04796160757542, 53.526777774095535, 41.243363097310066, 54.750122129917145, 53.70495021343231, 54.971585646271706, 55.14357201755047, 53.72985787689686, 56.747446954250336, 56.687634363770485, 56.39113627374172, 55.06693013012409, 54.51398380100727, 54.22815553843975, 56.06546714901924, 54.37893524765968, 55.284536853432655, 55.07931366562843, 54.249761179089546, 52.074731290340424, 50.252463072538376, 51.083562076091766, 42.32799969613552, 29.494936913251877, 21.237512603402138, 14.178505036979914, 9.192556980997324, 5.7969119399785995, 4.299261728301644, 3.664558748714626, 2.935809390619397, 2.401671577244997, 4.22088760882616, 6.118577979505062, 4.780756691470742, 5.1316973101347685, 7.641189051792026, 6.315946988761425, 4.636891661211848, 3.9117445098236203, 1.5278287860564888, 0.08415803997195326, 0.3789381100796163, 1.3226798130199313, 8.408927880227566, 17.302400059998035, 26.59805405884981, 28.164119124412537, 28.782302252948284, 23.67089442908764, 26.190592423081398, 23.756994009017944, 13.082913625985384, 3.872889932245016, 0.19673782750032842, 0.03514836629619822, 0.051664343336597085, 0.016293852240778506, 0.011994834731012816, 0.013240370044513838, 0.03361711154866498, 0.019772541454585735, 0.03400521396542899, 0.06401880891644396, 0.022543526065419428, 0.051810739387292415, 0.0636725896038115, 0.02955563602881739, 0.06680188496829942, 0.011813393539341632, 0.019010641517525073, 0.06900346605107188, 0.04379441641503945, 0.06678442965494469, 0.06030245989677496, 0.025294858605775516, 0.021069520589662716, 0.029899389555794187, 0.03352107392856851, 0.04981234349543229, 0.05890823529625777, 0.023125970983528532, 0.011631090528680943, 0.03392607504792977, 0.049473048420622945, 0.019414095258980524, 0.02962119735457236, 0.06232403306057677, 0.1302050898084417, 0.16608873149380088, 0.12733996933093295, 0.15025744505692273, 0.14854125824058428, 0.2549229178112, 0.2680850256001577, 0.11471083489595912, 0.17324622633168474, 0.23041001753881574, 0.11476046973257326, 0.1630189860588871, 0.14340875786729157, 0.1260582060785964, 0.12473482318455353, 0.1055414296570234, 0.15267944399965927, 0.0780538679100573, 0.19621866551460698, 0.1281431660754606, 0.10159517813008279, 0.16721069550840184, 0.08674192358739674, 0.14055266190553084, 0.08225305078667589, 0.1351827336475253, 0.16586895188083872, 0.16366769734304398, 0.0831821899919305, 0.21568027121247724, 0.18941753514809534, 0.15555133286397904, 0.15019557962659746, 0.07561352307675406, 0.1064029146800749, 0.0816561488318257, 0.1722534850705415, 0.14620046509662643, 0.1422395635745488, 0.1955582431401126, 1.7752444348298013, 10.6421934440732, 29.769540578126907, 46.818142756819725, 52.15825840830803, 32.830872908234596, 26.073818989098072, 29.536860063672066, 20.58865562081337, 13.77877313643694, 5.47468020580709, 1.5653691091574728, 0.6019400688819587, 1.1512607987970114, 3.711749128997326, 6.122825676575303, 9.98135855421424, 13.847980722784996, 14.398580677807331, 11.890457812696695, 13.917053416371346, 11.63501936942339, 10.784872937947512, 13.395633045583963, 10.35796394571662, 5.563622508198023, 3.256717133335769, 5.059419488534331, 7.162171555683017, 14.950884841382504, 20.374531410634518, 27.55546398460865, 33.283899798989296, 40.713192746043205, 47.11309053003788, 56.61707974970341, 57.45900437235832, 59.070258513092995, 58.38069811463356, 57.48899236321449, 60.55873364210129, 58.711379170417786, 61.617835611104965, 60.0045295804739, 59.71461273729801, 60.13483598828316, 57.83006206154823, 56.44901096820831, 54.20215353369713, 55.0051112473011, 47.04516537487507, 56.4117843657732, 56.44988872110844, 57.690313160419464, 57.65574261546135, 56.15844056010246, 59.33419235050678, 58.41549664735794, 56.2798136472702, 54.47620242834091, 55.58690942823887, 53.92013266682625, 57.78528906404972, 55.65009243786335, 56.455736607313156, 57.00972028076649, 56.54038466513157, 54.2818770557642, 52.39363297820091, 50.49420230090618, 44.35696542263031, 30.02820409834385, 20.801195316016674, 14.360642563551664, 8.82735762745142, 4.578341078013182, 5.165106542408466, 6.045479401946068, 1.99890720192343, 4.0043063554912806, 5.884185181930661, 8.080632146447897, 7.404828434810042, 6.910205176100135, 13.449143674224615, 10.319068282842636, 10.123044401407242, 9.149704780429602, 4.253934435546398, 1.0663125570863485, 0.6091342109721154, 2.0119637763127685, 9.104311466217041, 19.912044927477837, 29.2476898804307, 36.76844961941242, 34.46372129023075, 30.35408791154623, 32.575253024697304, 25.609525702893734, 13.81003500893712, 3.7909646658226848, 0.3105069586308673, 0.1948976278072223, 0.09430270889424719, 0.11563546184333973, 0.15585693443426862, 0.12583027768414468, 0.15207575139356777, 0.1800977039965801, 0.1772580688702874, 0.11713216590578668, 0.21634559176163748, 0.18669661396415904, 0.20036203146446496, 0.1964518631575629, 0.19822970760287717, 0.07655748297111131, 0.11391884458134882, 0.16417933395132422, 0.17705862410366535, 0.21230021899100393, 0.12361637694993988, 0.12876268127001822, 0.13196436571888626, 0.08586757714510895, 0.19225623516831547, 0.11635303701041266, 0.09653796121710911, 0.1397370416088961, 0.12000182832707651, 0.07489438939956017, 0.08514367145835422, 0.09723740571644157, 0.07910126092610881, 0.14170744369039312], [0.03524580657540355, 0.010218770512437914, 0.026391854917164892, 0.05363224809116218, 0.08234509194153361, 0.04601856620865874, 0.015613258292432874, 0.04685349718783982, 0.025106961657002103, 0.06182571429235395, 0.02584956760983914, 0.09139124871580862, 0.006740572971466463, 0.035877415066352114, 0.03790340029809158, 0.0617111934843706, 0.002115962520292669, 0.05147803087311331, 0.019000238462467678, 0.030316073934955057, 0.05096806780784391, 0.032359019096475095, 0.05848162283655256, 0.0421407073008595, 0.01706981402094243, 0.02344539690966485, 0.05850864443345927, 0.06733221627655439, 0.011698872731358279, 0.028470861034293193, 0.050470498608774506, 0.027789844061771873, 0.02856793209502939, 0.028432475301087834, 0.024694949097465724, 0.042169892258243635, 0.054958491964498535, 0.060670041930279694, 0.06867960764793679, 0.0012481278440645838, 0.1289631353574805, 2.7209565695375204, 11.063485387712717, 25.276141092181206, 36.94005601108074, 34.055091217160225, 27.283294089138508, 33.06305944919586, 36.57870680093765, 28.371483497321606, 14.806327298283577, 4.493707744404674, 1.3055562693625689, 0.33673128113150597, 0.33774089883081615, 1.2747090496122837, 2.199698402546346, 3.069053515791893, 4.021695647388697, 1.7106297332793474, 7.981997989118099, 3.8990843016654253, 3.7270421208813787, 9.098335336893797, 3.6171239940449595, 6.797354081645608, 3.3806213596835732, 0.8340050163678825, 2.919726991094649, 3.3426832454279065, 6.487386664375663, 13.276188354939222, 18.08603771030903, 23.21806512773037, 36.39993779361248, 42.0960259437561, 50.62108129262924, 56.44684508442879, 55.06960518658161, 56.70466884970665, 56.32522501051426, 56.44084520637989, 56.620533764362335, 55.058665573596954, 55.4105456918478, 53.780619353055954, 55.17316862940788, 53.116042613983154, 57.714282274246216, 54.5369915664196, 43.837381303310394, 46.4589062333107, 54.628475457429886, 49.576395750045776, 51.53367452323437, 57.67786122858524, 55.54326117038727, 55.17365500330925, 53.372509852051735, 53.0402784794569, 53.60251151025295, 54.13110874593258, 54.780820682644844, 56.10648214817047, 54.18166123330593, 52.88291372358799, 52.17241644859314, 52.11633525788784, 47.58451223373413, 36.02286122739315, 21.212052069604397, 15.59980547055602, 9.604122396558523, 3.9911305624991655, 3.1442177575081587, 1.593075916171074, 1.317181270569563, 0.752684926846996, 2.2215234814211726, 3.2071575801819563, 5.873223720118403, 5.661717569455504, 2.3836885672062635, 3.1252270890399814, 6.712828567251563, 3.46339825540781, 2.406740505248308, 1.6353323799557984, 0.749088479205966, 0.6425962841603905, 1.62684494163841, 8.866026252508163, 15.566483158618212, 20.27325924485922, 18.199632614850998, 22.552034966647625, 22.935132309794426, 28.090575970709324, 20.060575157403946, 9.494519177824259, 2.6195236248895526, 0.13402395910816267, 0.05927350925048813, 0.032952098990790546, 0.03676831511256751, 0.031463647610507905, 0.027323426511429716, 0.06688261579256505, 0.08366350986761972, 0.10991131392074749, 0.06714402989018708, 0.018564774036349263, 0.008918840412661666, 0.032501652458449826, 0.049739000751287676, 0.017054280870070215, 0.06532090701512061, 0.03438863714109175, 0.06512736974400468, 0.06166094637592323, 0.03179430408636108, 0.041373853528057225, 0.11205240254639648, 0.028466558433137834, 0.047198484535329044, 0.11125829711090773, 0.014869692186039174, 0.02191153722378658, 0.046623631787952036, 0.006700823541905265, 0.019373056347831152, 0.045392512693069875, 0.03496258446830325, 0.11082631521276198, 0.07923473618575372, 0.08975982258561999, 0.011335916133248247, 0.042153780232183635, 0.06996039126534015, 0.021934035430604126, 0.07272565577295609, 0.08366089750779793, 0.004344616454545758, 0.04169976025877986, 0.04164910496911034, 0.08183284677215852, 0.03275310322351288, 0.04769025385030545, 0.05342614997061901, 0.025336834478366654, 0.0397756459278753, 0.02408652344456641, 0.03890526626491919, 0.02822394293616526, 0.01898765349324094, 0.00853218147312873, 0.006258324947339133, 0.024971254388219677, 0.05523858591914177, 0.04775244953634683, 0.04205245109915268, 0.029528915001719724, 0.04261470588971861, 0.01785980424756417, 0.058780548788490705, 0.03267682528530713, 0.07771516655338928, 0.027436544660304207, 0.04366322697023861, 0.02946967120806221, 0.03486719993816223, 0.038226802280405536, 0.019630876595329028, 0.03387087410374079, 0.04047387701575644, 0.020623087220883463, 0.16628863639198244, 3.582273689098656, 14.680808633565903, 30.720893628895283, 43.114587888121605, 37.762153297662735, 28.648555129766464, 34.53728914260864, 32.12360545992851, 22.811629436910152, 14.061650857329369, 7.902042204514146, 1.7943980195559561, 0.13773355458397418, 0.10740514801000245, 0.6334619899280369, 2.4388181464746594, 2.5226734718307853, 5.068249264732003, 6.203854903578758, 8.542210478335619, 8.010261822491884, 4.7836231626570225, 5.854556271806359, 5.322540169581771, 6.8199115712195635, 4.3479993380606174, 2.1595818176865578, 3.057661014609039, 4.073054641485214, 9.144814442843199, 16.472743079066277, 21.73400916159153, 29.635061994194984, 38.71287368237972, 47.09219165146351, 52.18952313065529, 57.556780725717545, 57.43904784321785, 58.1319634616375, 59.06474880874157, 58.80634747445583, 56.94945931434631, 56.72569692134857, 56.89703352749348, 55.16892425715923, 55.679784044623375, 54.18513044714928, 55.838759914040565, 54.608005955815315, 43.96818928420544, 50.222250893712044, 56.59394659101963, 51.73643924295902, 54.57381919026375, 59.66288611292839, 56.018323078751564, 56.09678506851196, 53.741302862763405, 53.061804324388504, 53.547916039824486, 54.137374609708786, 54.44633223116398, 56.48892022669315, 53.111566454172134, 54.13676284253597, 53.80327753722668, 53.90416972339153, 48.98730956017971, 40.3281632065773, 25.80079033970833, 19.19344838708639, 12.24182115867734, 5.930273858830333, 3.8624098571017385, 3.828344685025513, 3.6647100280970335, 3.4578320290893316, 6.380377281457186, 5.25439272634685, 7.346344823017716, 8.192748930305243, 5.166567089036107, 4.736404996365309, 6.118432637304068, 4.634116385132074, 3.0495800357311964, 1.6782415774650872, 0.0938945499365218, 0.15485720214201137, 1.5426074992865324, 8.795866817235947, 18.98214742541313, 23.53824734687805, 20.398086346685886, 26.37165080755949, 27.477904446423054, 31.384184136986732, 23.903808631002903, 12.83623181283474, 4.072370203211904, 0.262551661580801, 0.024738823012739886, 0.03221812978154048, 0.059570078883552924, 0.03167959403072018, 0.045233114215079695, 0.057016497157746926, 0.00890846611582674, 0.1062367923441343, 0.08270305945188738, 0.04455337744730059, 0.050935725012095645, 0.02079216887068469, 0.07340023832512088, 0.06115155847510323, 0.02201455474278191, 0.0419878211687319, 0.06473416506196372, 0.03193208009179216, 0.024950930674094707, 0.019576662707549985, 0.01919403362990124, 0.047680984425824136, 0.07168320546043105, 0.05024092264648061, 0.05660585571604315, 0.07266465123393573, 0.0671671329473611, 0.024925933284976054, 0.01643265797611093, 0.0133577221458836, 0.06887513387482613, 0.0738025046302937, 0.031510903863818385, 0.05485146313731093, 0.0970477944065351, 0.15596565906889737, 0.16413585894042626, 0.1802189857698977, 0.19792202801909298, 0.1694362034322694, 0.09601283236406744, 0.1752187212696299, 0.18177028221543878, 0.1743904102477245, 0.11437246750574559, 0.19373258954146877, 0.2045439148787409, 0.2424745334428735, 0.12340306144324131, 0.1331935403868556, 0.11833936558105052, 0.1578088867245242, 0.12169615889433771, 0.17546729621244594, 0.1836735347751528, 0.2589095273287967, 0.17473953135777265, 0.17579746287083253, 0.1229025273642037, 0.12002238581771962, 0.1535455897101201, 0.15109581960132346, 0.12842769065173343, 0.22800299513619393, 0.18124965077731758, 0.09987524346797727, 0.12956081656739116, 0.12195231858640909, 0.12387432521791197, 0.1251313230022788, 0.17287135269725695, 0.14365194481797516, 0.16927304968703538, 0.10679360348149203, 0.20823345752432942, 3.601796803995967, 17.5572656840086, 37.7833067625761, 52.87907972931862, 47.64823481440544, 37.154926881194115, 45.0132130086422, 47.829800471663475, 34.73009079694748, 21.186572536826134, 6.590179223567247, 1.8258160399273038, 0.5983132822439075, 1.2835169769823551, 4.484972013160586, 6.878176219761372, 9.713645819574594, 12.288269866257906, 10.137260388582945, 17.39444252103567, 11.347062271088362, 9.288610126823187, 16.295619383454323, 7.235571267083287, 14.249288588762283, 9.13685766980052, 3.0597019800916314, 5.302333803847432, 4.850319558754563, 8.271968979388475, 15.685883201658726, 21.957553066313267, 25.83415824919939, 37.401643842458725, 47.828565537929535, 51.917009353637695, 59.096678495407104, 59.13270816206932, 59.403584226965904, 59.04680997133255, 59.95832785964012, 58.531736209988594, 58.780915439128876, 56.803022772073746, 56.53997428715229, 55.98803110420704, 53.65054853260517, 56.43796496093273, 55.45955926179886, 50.05470268428326, 52.365164905786514, 57.61099621653557, 57.002816051244736, 55.29677599668503, 60.01513101160526, 56.14491708576679, 56.551392674446106, 53.650130555033684, 53.47519554197788, 53.977061212062836, 53.42405408620834, 53.92851881682873, 56.239163428545, 53.69665525853634, 53.266503140330315, 54.506878182291985, 54.002744033932686, 49.95393209159374, 40.749929174780846, 26.662867181003094, 17.308048456907272, 11.54542587697506, 6.910901488736272, 4.566289074718952, 3.2701116520911455, 3.898560404777527, 2.47522019315511, 6.18034983985126, 6.6229030676186085, 13.286942727863789, 11.086761988699436, 7.810997189953923, 8.206223007291555, 13.11762286350131, 8.9896041713655, 8.324028085917234, 6.895269602537155, 1.3775251200422645, 1.0003809886984527, 2.427899669855833, 11.303097680211067, 21.822895891964436, 29.188850037753582, 26.522527411580086, 32.79903061687946, 33.98242011666298, 37.70356424152851, 26.802479289472103, 13.90039511024952, 4.449739353731275, 0.29416252160444856, 0.250488615129143, 0.1031600781425368, 0.1399567915359512, 0.07409398313029669, 0.17198043409734964, 0.22392006969312206, 0.1930289890151471, 0.20706119074020535, 0.16434628749266267, 0.1307763802469708, 0.1293729493045248, 0.1457690991810523, 0.13297861441969872, 0.10157367811189033, 0.1540756761096418, 0.15094681119080633, 0.13558485894463956, 0.16317526751663536, 0.12505649967351928, 0.09484284397331066, 0.14193874143529683, 0.24628243379993364, 0.13141250470653176, 0.20037242153193802, 0.21266139257932082, 0.20442900073248893, 0.21746295446064323, 0.09323049103841186, 0.09670291838119738, 0.10890958525124006, 0.15023247920908034, 0.2830726682441309, 0.19841551169520244, 0.15664795995689929], [0.07688745667110197, 0.029461589219863527, 0.04588211122609209, 0.04507170080614742, 0.06568820332176983, 0.01862696972239064, 0.03640023212938104, 0.04006251569080632, 0.04001471766969189, 0.0510979844693793, 0.041120458336081356, 0.06858085005660541, 0.035545285427360795, 0.037846930281375535, 0.0065424251079093665, 0.019055827178817708, 0.017649186447670218, 0.04087008739588782, 0.046705464701517485, 0.0589159536320949, 0.02088336583256023, 0.02464555360347731, 0.0689212435099762, 0.04887452116236091, 0.10293137791450135, 0.030101300108071882, 0.07294457449461333, 0.13293120602611452, 0.07373952597845346, 0.032814593869261444, 0.050357977888779715, 0.04892475713859312, 0.02189167178585194, 0.046637457999167964, 0.05450131415273063, 0.02933457806648221, 0.0880871998379007, 0.11007374778273515, 0.05084893826278858, 0.015581175248371437, 0.0743426545523107, 0.36898973921779543, 4.681977666914463, 16.997937597334385, 34.76808115839958, 35.73122687637806, 27.252574637532234, 16.325369887053967, 15.34103175625205, 33.47910292446613, 32.69666790962219, 8.523882161825895, 4.181304657831788, 1.2951700016856194, 0.3138666017912328, 0.2888972806977108, 1.2467375630512834, 0.817118544364348, 3.4023450314998627, 3.8155457843095064, 3.5752274421975017, 5.264734346419573, 2.572954511269927, 3.8936130702495575, 5.87998260743916, 5.290638506412506, 7.987816426903009, 1.5181629359722137, 1.8783098668791354, 1.172446443233639, 2.2370577603578568, 2.186763659119606, 8.286658991128206, 13.496742770075798, 19.09110277891159, 28.62684689462185, 41.86915151774883, 53.45974177122116, 56.06012083590031, 55.472873747348785, 57.67225652933121, 54.2782748490572, 56.65680281817913, 54.350565969944, 54.50782433152199, 57.48550035059452, 54.08449284732342, 57.17440724372864, 50.9190309047699, 53.63461598753929, 51.33130118250847, 53.16825181245804, 48.63910764455795, 54.86590951681137, 50.230424255132675, 53.921492993831635, 53.76802682876587, 57.113496512174606, 57.807529270648956, 55.67024275660515, 54.02596838772297, 55.30741162598133, 53.09444077312946, 55.381967425346375, 53.58483865857124, 53.70644733309746, 52.9490377753973, 46.236933544278145, 33.33540603518486, 23.08425910770893, 14.889985509216785, 8.427025359123945, 3.126394576393068, 0.9809776267502457, 1.1552936886437237, 2.1693665301427245, 1.730573675595224, 3.9509731298312545, 8.221832569688559, 2.478538127616048, 3.4644299000501633, 6.448952676728368, 5.590890794992447, 4.4663772359490395, 3.0217161308974028, 5.847694789990783, 2.5731259770691395, 1.7142524826340377, 0.7375461829360574, 1.5316417627036572, 7.330187140032649, 12.748792804777622, 17.08154071122408, 15.834854207932949, 16.173828318715096, 19.66046992689371, 27.877473905682564, 21.459549888968468, 10.29273759573698, 1.7869579000398517, 0.24568303080741316, 0.08039965570787899, 0.010429876274429262, 0.07035749964416027, 0.02260914676298853, 0.021691024739993736, 0.0877203859272413, 0.08417918375926092, 0.05556042568059638, 0.020701309586002026, 0.035438709310255945, 0.040991298665176146, 0.018948603537864983, 0.024983588882605545, 0.029451928312482778, 0.03583442987292074, 0.03473299366305582, 0.03011075321410317, 0.057693154012667947, 0.013034528892603703, 0.09740263005369343, 0.03224937419872731, 0.04533906692813616, 0.09194370344630443, 0.06506778270704672, 0.058081538445549086, 0.014590039809263544, 0.02829839890182484, 0.048287753234035335, 0.022760973479307722, 0.045119034984963946, 0.05373629348468967, 0.04472690270631574, 0.014462957224168349, 0.029869974532630295, 0.06131050053227227, 0.03174261721142102, 0.02690863831958268, 0.025617644605517853, 0.033694992525852285, 0.04609662530128844, 0.0450084735348355, 0.03169755029375665, 0.05688217956048902, 0.060467428193078376, 0.017213286009791773, 0.08659425846417435, 0.022377446402970236, 0.06759879572200589, 0.014215934297681088, 0.03540242571034469, 0.056139953958336264, 0.016193430383282248, 0.056478087572031654, 0.02524032002838794, 0.0680893701792229, 0.05499935090483632, 0.037480416940525174, 0.0931929903163109, 0.022955939384701196, 0.011752552272810135, 0.03151123411953449, 0.07818430036422797, 0.07709379598964006, 0.027398452075431123, 0.03371799539308995, 0.017763221148925368, 0.022866438230266795, 0.03268335247412324, 0.04547090946289245, 0.0424526579445228, 0.040569035190856084, 0.021356215947889723, 0.029580497975985054, 0.02170073574234266, 0.028328873340797145, 0.061948706716066226, 0.6831238407175988, 6.672568777576089, 21.114706993103027, 39.281581565737724, 40.58232016861439, 32.0909234136343, 21.842335648834705, 22.268579676747322, 37.99635753035545, 31.411284282803535, 8.70468595996499, 7.747666938230395, 1.88825678313151, 0.15827324852580205, 0.2959451306378469, 0.328431932721287, 0.9899917524307966, 3.8412894029170275, 4.421371500939131, 5.379953188821673, 7.112786080688238, 6.247767247259617, 6.063090981915593, 6.643115608021617, 6.064549153670669, 4.847581805661321, 5.026302365586162, 4.1104688588529825, 3.1871074810624123, 3.9489288395270705, 4.225774146616459, 12.42984551936388, 16.386271119117737, 25.164860263466835, 31.645581610500813, 43.76731686294079, 55.60826428234577, 57.00817756354809, 56.53345003724098, 59.12407502532005, 57.413429617881775, 57.16873034834862, 55.90186692774296, 56.80398792028427, 56.54513821005821, 56.41882158815861, 55.197696313261986, 51.54460273683071, 53.9137452095747, 52.3714953660965, 53.1315153837204, 53.19244511425495, 55.642834827303886, 51.281193271279335, 54.24232117831707, 56.07396349310875, 55.75539618730545, 57.592187225818634, 56.27374157309532, 54.2795629799366, 55.106516405940056, 54.31721895933151, 54.91191744804382, 54.39538836479187, 53.337848111987114, 55.60996279120445, 48.37562598288059, 38.59282672405243, 27.09919586777687, 19.529523253440857, 10.588515624403954, 5.695496331900358, 2.1715996228158474, 2.0355521980673075, 6.44383292645216, 4.030964775010943, 7.988216355443001, 5.732296407222748, 8.509387839585543, 6.995350057259202, 11.433043107390404, 7.445177519693971, 7.321478007361293, 4.084757063537836, 3.768047383055091, 1.8448358005844057, 0.5400569457560778, 0.282202425878495, 1.4402502542361617, 7.651750585064292, 16.61057498306036, 22.850520350039005, 21.07669573277235, 17.21733022481203, 22.580856420099735, 30.66232357174158, 25.30614048242569, 14.297776836901903, 3.308534952811897, 0.5269377341028303, 0.03793953546846751, 0.044171149129397236, 0.04582195273542311, 0.06287565658567473, 0.013775907518720487, 0.038309585142997093, 0.09367773891426623, 0.07236341349198483, 0.010349051754019456, 0.06828465891885571, 0.06610452590393834, 0.018026737379841506, 0.022106182150309905, 0.020808093504456338, 0.03566473409591708, 0.04583461006404832, 0.08349585128598846, 0.023064613924361765, 0.07132768703741021, 0.0459649497497594, 0.06369694689055905, 0.07216742713353597, 0.05280866454995703, 0.029136435769032687, 0.012737927718262654, 0.027720937505364418, 0.03712704703502823, 0.01855158607213525, 0.003976082616645726, 0.05537654004001524, 0.043675108754541725, 0.03383358860446606, 0.03277114112279378, 0.010364007885073079, 0.07207951974123716, 0.11602859973208979, 0.17408157291356474, 0.12239644202054478, 0.19857397506712005, 0.15645135019440204, 0.13638228178024292, 0.11068284322391264, 0.12967871414730325, 0.13746997341513634, 0.15726024663308635, 0.19317629048600793, 0.20733115437906235, 0.14348749973578379, 0.10190869841608219, 0.11848915324662812, 0.1450316864065826, 0.11783084599301219, 0.13606930326204747, 0.211006106401328, 0.17507700074929744, 0.11693107357132249, 0.2615621709264815, 0.15686439990531653, 0.09938682123902254, 0.24585053353803232, 0.2254381772945635, 0.15418395545566455, 0.22198640392161906, 0.17631273600272834, 0.09864852530881763, 0.14691507909446955, 0.14895732107106596, 0.11632011533947662, 0.10046790033811703, 0.16520467033842579, 0.1473726428230293, 0.16588983591645956, 0.1811396941775456, 0.1440359023399651, 0.15144400560529903, 0.15407030296046287, 0.8191604004241526, 6.912933429703116, 23.94207637757063, 45.8994622528553, 49.45551283657551, 39.98602196574211, 25.07392544299364, 22.566250003874302, 41.22211083769798, 41.15915581583977, 12.236837726086378, 6.231850376352668, 1.6492573264986277, 0.6283684226218611, 1.0751527827233076, 3.392001511529088, 4.182997941970825, 9.599589239805937, 10.322452001273632, 9.286479391157627, 11.859658565372229, 10.105642285197973, 10.388077329844236, 12.125681340694427, 10.999020896852016, 13.276235852390528, 6.049800245091319, 6.268996233120561, 4.0943140257149935, 3.6507130041718483, 3.760815658606589, 10.796287525445223, 16.851681545376778, 22.238012216985226, 30.707106068730354, 44.98471073806286, 57.37831190228462, 58.64486753940582, 57.07618251442909, 59.73197400569916, 57.1714624017477, 57.84738913178444, 56.7121734470129, 57.22860373556614, 58.55751022696495, 57.09664821624756, 58.51380497217178, 53.300727903842926, 56.168871000409126, 56.97687864303589, 56.3088820874691, 52.94736586511135, 57.76741102337837, 56.23581200838089, 57.851185128092766, 57.2440081089735, 56.65796935558319, 59.353487715125084, 56.095139756798744, 55.44225499033928, 56.554162725806236, 53.15580368041992, 54.80245292186737, 54.61269490420818, 53.269409984350204, 55.57032711803913, 50.979690849781036, 41.000658720731735, 27.20887128263712, 18.078016340732574, 10.228552389889956, 5.357146337628365, 3.1338550010696054, 2.3251097230240703, 4.6220434829592705, 6.046541919931769, 8.753897119313478, 14.882192127406597, 11.409576516598463, 8.662094045430422, 13.577439039945602, 12.322144098579884, 12.812641728669405, 11.683274880051613, 11.103739477694035, 6.782019529491663, 2.723139552399516, 1.5770995547063649, 2.25325676612556, 9.352332707494497, 16.641552820801735, 24.40996427088976, 23.366257175803185, 25.347753949463367, 30.90456247329712, 37.58371487259865, 28.72716911137104, 14.453003257513046, 3.1247818004339933, 0.4543057596310973, 0.18788381275953725, 0.19869497482432052, 0.1650356239406392, 0.22018595365807414, 0.07934604349429719, 0.23539756162790582, 0.25519599847029895, 0.16525038663530722, 0.08390471528400667, 0.1301959020202048, 0.13587612222181633, 0.14497065218165517, 0.0815966582740657, 0.17865035275463015, 0.17889772541821003, 0.10501658282009885, 0.15830088610528037, 0.14745855383807793, 0.11045475897844881, 0.19993580121081322, 0.16066676384070888, 0.13594071875559166, 0.22544234816450626, 0.15268429764546454, 0.12779959623003379, 0.09811535899643786, 0.19923031562939286, 0.10022160378866829, 0.10958600090816617, 0.09777498038602062, 0.16346409654943272, 0.1732007326791063, 0.15645500156097114, 0.08922768785851076, 0.1566152906161733], [0.03304810692497995, 0.02962000249681296, 0.002225819393970596, 0.07474002268281765, 0.030530485964845866, 0.0755688977369573, 0.012765249884978402, 0.031157437479123473, 0.05502145206264686, 0.08257173642050475, 0.06336311402264982, 0.023619797902938444, 0.037598585404339246, 0.02360009944823105, 0.025628995754232164, 0.08531832107109949, 0.033463995350757614, 0.049778178727137856, 0.0026691494258557213, 0.03881673917931039, 0.038523943367181346, 0.0801612927170936, 0.05950340433628298, 0.024187398012145422, 0.0836033810628578, 0.029652989105670713, 0.03805772619671188, 0.018676983054319862, 0.15642908576410264, 0.04175715053861495, 0.09223383123753592, 0.026720136520452797, 0.012746428092214046, 0.015788000673637725, 0.02817392032739008, 0.05962008479400538, 0.07785592970321886, 0.044901511500938796, 0.04805784330528695, 0.04601841777912341, 0.09712929706438445, 0.06330915246508084, 0.5370067188050598, 4.432023279368877, 21.397096440196037, 36.166911497712135, 34.40191760659218, 28.11128295958042, 21.245381981134415, 13.871472012251616, 13.34675531834364, 21.621628291904926, 15.945014096796513, 6.399933407083154, 2.4758820701390505, 0.23607423703651875, 0.2107542214798741, 0.5650243966374546, 2.031387621536851, 4.811744978651404, 5.314779561012983, 5.6810457073152065, 4.818274453282356, 2.5170103507116437, 5.178809557110071, 3.7648337054997683, 2.989440900273621, 5.458001475781202, 2.6206877874210477, 2.882439591921866, 1.9416294316761196, 1.7418536078184843, 2.3628412233665586, 7.288240240886807, 7.088384740054607, 14.858008325099945, 28.94570678472519, 42.00739189982414, 53.04047606885433, 53.97491812705994, 55.34323610365391, 55.959274247288704, 55.15705369412899, 56.59659504890442, 52.99249604344368, 57.43641458451748, 55.8158053457737, 54.38275404274464, 54.62586119771004, 55.860566943883896, 54.77438762784004, 57.6527863740921, 54.08857002854347, 61.46658852696419, 54.22887369990349, 53.82578372955322, 53.410146832466125, 53.415557742118835, 53.32816623151302, 54.79118272662163, 54.47356157004833, 57.023965716362, 55.66864304244518, 53.90693597495556, 51.915147453546524, 49.61486108601093, 43.292213156819344, 31.84083603322506, 22.183200158178806, 15.20255958661437, 6.953347586095333, 1.6399072157219052, 2.532064192928374, 0.4860013135476038, 0.9483085828833282, 6.971521535888314, 4.375278549268842, 8.656871225684881, 5.080720195546746, 9.471322372555733, 8.001494742929935, 9.791428595781326, 4.982892069965601, 3.206748627126217, 3.977179848589003, 1.7633443046361208, 1.4189736521802843, 0.1804019697010517, 0.7138652598951012, 6.010118974372745, 16.145162656903267, 23.516444116830826, 19.427886307239532, 19.253226779401302, 23.017437793314457, 24.165852069854736, 24.49899159371853, 11.583382990211248, 3.303539170883596, 0.10055275750346482, 0.06981084108701907, 0.027679931990860496, 0.08049346317420714, 0.08004468647413887, 0.010065021633636206, 0.02157009919756092, 0.04956925302394666, 0.003931197989004431, 0.009644482724979753, 0.038077500721556135, 0.06545707627083175, 0.02510296704713255, 0.02102383026794996, 0.03553809401637409, 0.029851409708498977, 0.09589845998561941, 0.03241327380237635, 0.02663728315383196, 0.014057842927286401, 0.01213444847962819, 0.025491633496130817, 0.0594222430663649, 0.03043715903913835, 0.05051300140621606, 0.044285376789048314, 0.03948726589442231, 0.0715874313027598, 0.07223652108223177, 0.07320794786210172, 0.028226156391610857, 0.05784187298559118, 0.02805362004437484, 0.02337122852622997, 0.06160413868201431, 0.02459100945998216, 0.031896616565063596, 0.03590602857002523, 0.06509957631351426, 0.04077692559803836, 0.07901756893261336, 0.021460999778355472, 0.04655892393202521, 0.046945560607127845, 0.01726726612105267, 0.12631430639885366, 0.03819167643086985, 0.01885738060082076, 0.02870055759558454, 0.04721439618151635, 0.08533773565432057, 0.11489693584735505, 0.03855630100588314, 0.02900064500863664, 0.010870008809433784, 0.031192719179671258, 0.08241782983532175, 0.03860599892504979, 0.08851092905388214, 0.0492056822986342, 0.02607249578431947, 0.028810341646021698, 0.053719843781436794, 0.05167096700461116, 0.0680779930553399, 0.10660394764272496, 0.04471780026506167, 0.1370903945644386, 0.06801678071497008, 0.020129152690060437, 0.020988348187529482, 0.05871938097698148, 0.09238662460120395, 0.04426829254953191, 0.027018884356948547, 0.04929387170705013, 0.09554530159221031, 0.019985383842140436, 0.04394358809804544, 0.9768519387580454, 6.430707480758429, 26.78402367979288, 41.52866318821907, 38.393322229385376, 25.550330579280853, 13.863544687628746, 15.603331681340933, 26.866933330893517, 19.646935053169727, 10.543617233633995, 7.90065242908895, 1.8118882435373962, 0.16373772639781237, 0.1350373320747167, 0.38228893652558327, 1.3350321189500391, 1.6758709796704352, 5.090970145538449, 6.340901674702764, 4.1145579144358635, 5.502843344584107, 5.6085313484072685, 6.791951721534133, 4.250355027616024, 3.926306515932083, 3.8071895577013493, 3.485105778090656, 3.149617505259812, 2.206393643282354, 3.373035779222846, 10.093088708817959, 10.80727843567729, 18.659520037472248, 32.15466499328613, 44.17498558759689, 54.03509169816971, 56.27334639430046, 58.40185537934303, 56.95477902889252, 56.463161408901215, 56.18847414851189, 52.806059047579765, 57.547193840146065, 55.660412684082985, 55.73275700211525, 55.680779591202736, 54.56721134483814, 52.5423151999712, 59.086149260401726, 55.66062547266483, 59.91070881485939, 56.21068395674229, 55.57859547436237, 54.652596563100815, 54.26744922995567, 55.047741159796715, 55.46742103993893, 56.12141914665699, 57.39351108670235, 55.83968706429005, 56.27272702753544, 52.60631136596203, 51.053821071982384, 46.957982853055, 37.494685649871826, 27.537870928645134, 18.775109834969044, 9.188219513744116, 3.642818690277636, 3.433674112893641, 2.4857765017077327, 1.5673187607899308, 9.803760834038258, 6.503285961225629, 10.950664691627026, 7.170359641313553, 6.872047148644924, 8.253148589283228, 13.448052182793617, 6.411865716800094, 5.197430457919836, 3.6842982145026326, 1.5262743132188916, 0.37585386307910085, 0.3715711663244292, 1.0670923464931548, 6.594748953357339, 17.952904254198074, 24.06922895461321, 17.510374300181866, 16.410946995019913, 24.765805676579475, 27.995305582880974, 29.767868667840958, 15.013394337147474, 4.868651200085878, 0.1782165525946766, 0.023006067749520298, 0.02363465384405572, 0.02693285274290247, 0.06379948201356456, 0.09448526980122551, 0.06770240695914254, 0.021797255758428946, 0.03253594710258767, 0.02305568032170413, 0.015805834482307546, 0.03772251664486248, 0.04244866890076082, 0.043624364407151006, 0.016562797281949315, 0.028234783858351875, 0.046474504633806646, 0.03828527238511015, 0.050038698536809534, 0.005431286244856892, 0.03270633678766899, 0.031073250102053862, 0.05224261367402505, 0.025214059132849798, 0.009022061094583478, 0.027516479531186633, 0.07446893097949214, 0.07155956365750171, 0.02681328718608711, 0.0859414876322262, 0.05897516217373777, 0.010935469017567812, 0.018815786934283096, 0.036949848145013675, 0.04229425765515771, 0.05711046418582555, 0.0028981476725675748, 0.09855583848548122, 0.17620208178414032, 0.12361248809611425, 0.17749430931871757, 0.14463965431787074, 0.10722286169766448, 0.10647305505699478, 0.0871090566215571, 0.1424720635986887, 0.14357578562339768, 0.10433971445308998, 0.11892149137565866, 0.10914655300439335, 0.12588858080562204, 0.1630402114824392, 0.16504304541740566, 0.17539441731059924, 0.10288042205502279, 0.0756655253644567, 0.17157820489956066, 0.1271188835380599, 0.32407864287961274, 0.12993154901778325, 0.10662581873475574, 0.15524320799158886, 0.20663093804614618, 0.22628489357884973, 0.22198943188413978, 0.3124626068165526, 0.18960184010211378, 0.19175267312675714, 0.17594801494851708, 0.0959498759766575, 0.0617227227485273, 0.11741862748749554, 0.2119713881984353, 0.12808468483854085, 0.10830451967194676, 0.08025613176869228, 0.28724908945150673, 0.20446128415642306, 0.17849041993031278, 1.1676030093804002, 6.750451298430562, 28.477077931165695, 49.39124308526516, 47.547745406627655, 39.12147715687752, 27.8277687728405, 20.245180651545525, 24.882924892008305, 27.531337179243565, 19.401382729411125, 10.032821092754602, 2.990099214948714, 0.5646216776221991, 0.8929563593119383, 2.764701247215271, 6.626143818721175, 11.82572828605771, 12.906325701624155, 15.266769491136074, 9.851237386465073, 8.244792837649584, 12.788797058165073, 9.750636834651232, 7.692811656743288, 11.164637859910727, 7.532904837280512, 5.39510297589004, 4.1503040213137865, 4.600364221259952, 3.8627397269010544, 10.43169803917408, 11.122895199805498, 18.290181756019592, 30.357992202043533, 45.391007736325264, 54.16879892349243, 56.62403717637062, 58.010974153876305, 58.61042618751526, 55.85580199956894, 56.430901139974594, 54.12511646747589, 59.6024389564991, 57.396965101361275, 55.721323415637016, 58.61676424741745, 58.00954543054104, 57.447395995259285, 61.907368674874306, 56.173312962055206, 60.2903388440609, 55.1215597987175, 56.12058699131012, 55.91429226100445, 58.473572731018066, 57.940066158771515, 58.01364541053772, 57.430023327469826, 58.234751746058464, 56.940867975354195, 57.196031883358955, 53.3642490953207, 53.95875759422779, 47.81340815126896, 37.3361049592495, 25.854612551629543, 17.82203357666731, 8.482646774500608, 2.558846343308687, 4.122676178812981, 1.875653809402138, 3.6016987217590213, 14.943817220628262, 8.289868868887424, 14.076462462544441, 11.09728267416358, 15.627864114940166, 15.116873234510422, 16.38204764574766, 14.064046628773212, 10.949072577059269, 6.3705657329410315, 4.6694492641836405, 2.8668343042954803, 0.951813479186967, 1.7236015247181058, 8.050530161708593, 22.19169270247221, 30.75858760625124, 26.245651468634605, 28.744342289865017, 32.19815365970135, 33.939197435975075, 32.63386867940426, 16.403980068862438, 4.930233070626855, 0.2011724715703167, 0.18294053035788238, 0.17276852071518078, 0.21019956999225542, 0.2467404428170994, 0.10200778255239129, 0.14572629210306332, 0.07013533773715608, 0.17142754892120138, 0.10438633617013693, 0.13929253967944533, 0.19721064978512004, 0.17570323980180547, 0.0881453174224589, 0.14643400412751362, 0.17958666110644117, 0.2195828250842169, 0.09164172355667688, 0.2016570494743064, 0.06524226162582636, 0.0817244486825075, 0.18341661809245124, 0.16367039876058698, 0.14090568671235815, 0.22294907335890457, 0.10258837210130878, 0.1833640443510376, 0.17854860430816188, 0.1548871849081479, 0.2372075559105724, 0.11613322029006667, 0.2596534264739603, 0.1311889401404187, 0.09223491477314383, 0.2057180815609172, 0.11847287052660249, 0.12467843480408192], [0.03965303199947812, 0.05242188686679583, 0.06293980783084407, 0.02850150802260032, 0.03975957471993752, 0.05996107938699424, 0.030010058617335744, 0.10572135593974963, 0.013145034681656398, 0.053528933713096194, 0.02371100414165994, 0.04933687916491181, 0.01518632114311913, 0.02982034897286212, 0.054341659633792005, 0.011686252510116901, 0.02166247802961152, 0.006276306721701985, 0.03999471307906788, 0.07166622512158938, 0.08540282200556248, 0.0492299393954454, 0.03225637636205647, 0.03476302466879133, 0.0149158537715266, 0.04726771578134503, 0.03736546939762775, 0.030787072391831316, 0.04266862291842699, 0.07757410654448904, 0.017937384654942434, 0.04988704436982516, 0.028967534090043046, 0.028280516853556037, 0.08418943281867541, 0.03900690338923596, 0.03167917842802126, 0.040530109545215964, 0.04789822218299378, 0.010352649314882001, 0.037155170721234754, 0.023693051589361858, 0.06865544331958517, 0.5806306342128664, 4.713916378095746, 20.647930540144444, 36.175890415906906, 35.1017564535141, 35.6014334410429, 23.76535926014185, 9.353677835315466, 5.30391214415431, 16.33066490292549, 21.269030012190342, 9.161321707069874, 3.1266814609989524, 0.3623227297794074, 0.04931613613734953, 0.9568564617075026, 1.1433386988937855, 3.1084505142644048, 4.230127288028598, 3.710822928696871, 4.794317213818431, 3.908468848094344, 6.888640383258462, 2.240784172900021, 2.57921586278826, 3.420405462384224, 2.7887632185593247, 3.913699979893863, 0.26550128299277276, 1.3614569697529078, 1.4590826374478638, 4.80922618880868, 8.020050097256899, 16.250166222453117, 27.48031161725521, 42.24726162850857, 49.955547004938126, 54.85213525593281, 55.157623663544655, 59.12168115377426, 55.53297892212868, 57.65636198222637, 54.91907626390457, 59.35815006494522, 55.828074887394905, 49.37235809862614, 53.712652400135994, 51.82307839393616, 48.736823201179504, 55.53180478513241, 60.86209036409855, 60.66363841295242, 57.35149674117565, 57.48828940093517, 56.04591719806194, 55.89393675327301, 50.333360731601715, 54.41336899995804, 51.46194577217102, 53.940134793519974, 52.66503341495991, 52.70404972136021, 41.666504591703415, 35.280802845954895, 20.910838432610035, 10.632439367473125, 3.8674362748861313, 2.950186631642282, 1.9447160535492003, 2.2246357519179583, 2.702422351576388, 1.0255368263460696, 9.421726483851671, 6.71962165273726, 11.156669687479734, 5.17725876532495, 5.929113971069455, 6.810052525252104, 14.11577420309186, 5.879693822935224, 4.857728211209178, 2.4471613112837076, 1.4314942178316414, 0.9494155703578144, 0.7449988299049437, 5.056684585288167, 10.433595087379217, 19.22228693962097, 17.85274352878332, 21.215893663465977, 32.09736026823521, 28.923022001981735, 27.090150453150272, 12.63610890135169, 2.3015980096533895, 0.3891698329243809, 0.04757269023684785, 0.060147080148453824, 0.03785881577641703, 0.012793702899216441, 0.007657366550120059, 0.03347431862493977, 0.09849872280028649, 0.09103014192078263, 0.0065616212214081315, 0.018438633051118813, 0.08068136754445732, 0.06797400332288817, 0.06334965146379545, 0.04071418443345465, 0.045022555786999874, 0.03938545807613991, 0.044632393910433166, 0.05164294350834098, 0.008606309966125991, 0.011777257441281108, 0.04162803539657034, 0.038169159670360386, 0.07402832532534376, 0.032031776499934494, 0.04472391927265562, 0.08045634094742127, 0.017193346357089467, 0.03424512433412019, 0.054399105574702844, 0.038066806373535655, 0.02666742177098058, 0.035536928844521753, 0.05095673150208313, 0.037120812994544394, 0.058465792826609686, 0.020922436196997296, 0.03381468981388025, 0.029863718227716163, 0.022198811457201373, 0.08342744011315517, 0.011223488181713037, 0.045206845898064785, 0.03206788940588012, 0.07029581975075416, 0.16892015846678987, 0.025402649989700876, 0.06353292483254336, 0.02590202075225534, 0.05530851107323542, 0.03367612342117354, 0.06015880237100646, 0.010170720161113422, 0.012882966566394316, 0.07482482789782807, 0.03414856349991169, 0.01209296242450364, 0.015196037711575627, 0.04143984529946465, 0.06833709907368757, 0.02517475684726378, 0.04083552928932477, 0.051161397277610376, 0.0992107689671684, 0.024659791706653778, 0.058941208917531185, 0.06194128523929976, 0.08155760646332055, 0.07189620184362866, 0.022558215023309458, 0.04804151234566234, 0.032816100429045036, 0.04005583265097812, 0.03196990735887084, 0.02233597704616841, 0.01795801450498402, 0.007751802058919566, 0.06691334812785499, 0.019219971691200044, 0.08673661723150872, 0.10337661457015201, 0.9168624796438962, 7.984378561377525, 26.343216933310032, 40.9206236153841, 39.717931151390076, 34.26298566162586, 19.23629868775606, 9.913283307105303, 13.656471949070692, 23.668084479868412, 20.98038800060749, 9.274783618748188, 2.0861759316176176, 0.1250653460738249, 0.056080522772390395, 0.32966259168460965, 0.8015169971622527, 2.477808566763997, 3.964009042829275, 5.146358823403716, 5.303643783554435, 3.5486918035894632, 8.43895386904478, 3.276674374938011, 4.479221496731043, 4.86697643995285, 4.431172600015998, 4.317541122436523, 2.8799056028947234, 2.8543526865541935, 3.234900366514921, 5.720488540828228, 10.205773562192917, 20.877575017511845, 29.932361841201782, 45.03221198916435, 50.77288694679737, 55.44050708413124, 56.19795843958855, 59.750425815582275, 55.799770206213, 56.93562425673008, 55.53543359041214, 60.14940060675144, 56.90224304795265, 53.32522138953209, 54.211026057600975, 50.18209844827652, 52.704262509942055, 58.50051328539848, 59.24538351595402, 60.29849700629711, 58.68470840156078, 58.85158784687519, 55.651528760790825, 57.88325920701027, 52.98657216131687, 54.97477747499943, 53.948410749435425, 52.53094621002674, 53.51173438131809, 52.648789286613464, 45.029392540454865, 37.95791119337082, 24.139029309153557, 13.82316805422306, 6.538338605314493, 5.165092768147588, 3.5235278913751245, 3.682543896138668, 3.205759492702782, 4.380657160654664, 3.7164207408204675, 10.494384225457907, 15.522992592304945, 10.336538795381784, 6.79317525587976, 8.77420037984848, 10.780149791389704, 4.961896296590567, 2.1863095834851265, 1.0020278440788388, 0.42466132377739996, 0.5072374537121505, 0.9213920740876347, 5.617249505594373, 14.06506022438407, 25.17135601490736, 23.815125189721584, 21.44399542361498, 30.194080397486687, 31.233501322567463, 30.195588916540146, 17.03261263668537, 3.9549553161486983, 0.6219063943717629, 0.02177259975724155, 0.028463519338401966, 0.05144605915120337, 0.02616108595248079, 0.03112384601990925, 0.05900213182030711, 0.034470488608349115, 0.0656781843281351, 0.005198651706450619, 0.05422753958555404, 0.026352138884249143, 0.012240473552083131, 0.06740145123330876, 0.03136438906949479, 0.026884204962698277, 0.03456120874034241, 0.03098786972259404, 0.022600387565034907, 0.08178688556654379, 0.02977367530547781, 0.09218060440616682, 0.08964401044067927, 0.03010202184668742, 0.014814292717346689, 0.04394936571770813, 0.05296297931636218, 0.07337861956330016, 0.019779463837039657, 0.05185202135180589, 0.02168411905586254, 0.057150061475113034, 0.004029065930808429, 0.02643438183440594, 0.075237959244987, 0.06254571257159114, 0.02472124895575689, 0.06462113597081043, 0.1150846027303487, 0.14749431051313877, 0.1745094804209657, 0.08548389421775937, 0.14712565607624128, 0.12784194317646325, 0.1860943462816067, 0.22139574342872947, 0.06765859056031331, 0.2178201946662739, 0.16427858878159896, 0.199574479192961, 0.07826812594430521, 0.11939263640670106, 0.26560061203781515, 0.09134979234659113, 0.08950758885475807, 0.14369965007063001, 0.1345780465635471, 0.12709163187537342, 0.12957942963112146, 0.1322848250856623, 0.13425582088530064, 0.1896746299462393, 0.17119335680035874, 0.18216215103166178, 0.12394802790367976, 0.11500827284180559, 0.21623562031891197, 0.1967866756604053, 0.14334248407976702, 0.1465669524623081, 0.09830967552261427, 0.208514716650825, 0.21028855349868536, 0.14534561487380415, 0.11973645858233795, 0.20250661560567096, 0.15152993146330118, 0.14224944898160174, 0.14250597974751145, 0.22656598943285644, 0.11551928604603745, 1.010213317349553, 8.934806361794472, 27.903662100434303, 49.359005615115166, 48.52728344500065, 47.70868577063084, 31.06807339936495, 14.649934340268373, 15.918232183903456, 23.675733469426632, 27.94837050139904, 11.697867047041655, 4.298851350322366, 0.8581127633806318, 0.48350612400099635, 2.912850072607398, 3.770565460436046, 7.606186280027032, 10.010410845279694, 9.636413063853979, 11.532260533422232, 9.921202082186937, 13.42243680730462, 8.464340306818485, 7.84141075797379, 8.20078169927001, 8.478706385940313, 9.030475728213787, 2.010110425762832, 4.0867353323847055, 2.6904617808759212, 6.542468508705497, 11.160637624561787, 19.43830154836178, 29.80262540280819, 45.81819601356983, 52.33734279870987, 57.127669751644135, 56.17179684340954, 61.28549784421921, 56.988992393016815, 58.64984907209873, 57.07274749875069, 60.84160566329956, 59.01599742472172, 55.30506335198879, 55.67739017307758, 53.99194121360779, 54.249271005392075, 57.64825701713562, 60.215509459376335, 60.72980046272278, 57.50115931034088, 59.96322959661484, 57.96348810195923, 60.41455417871475, 56.162027567625046, 58.649670481681824, 55.37774585187435, 54.24443766474724, 54.067667350173, 52.75243632495403, 43.30725274980068, 37.53721296787262, 22.553100809454918, 12.38628275692463, 5.632666703313589, 5.58778683654964, 4.4719477370381355, 5.98574043251574, 5.671845925971866, 6.0400209948420525, 18.146900944411755, 17.20539316534996, 20.04312839359045, 12.226734068244696, 16.36774331331253, 16.415200866758823, 21.709808260202408, 13.53540189564228, 9.405307564884424, 6.465852269902825, 3.3706625690683722, 2.09936217404902, 1.2991663184948266, 7.228316981345415, 14.963536262512207, 28.695017136633396, 28.21321628987789, 30.03326542675495, 41.164840310812, 40.29387764632702, 35.52402399480343, 18.77059757709503, 4.158021407201886, 0.6018354557454586, 0.13939872616901994, 0.19906192232156172, 0.13509631797205657, 0.15012679737992585, 0.15695419977419078, 0.11893253453308716, 0.22653204359812662, 0.244419465016108, 0.1179679503547959, 0.1332409042515792, 0.15359375509433448, 0.149945238372311, 0.14888672798406333, 0.14471076690824702, 0.15355253621237352, 0.09893419279251248, 0.14740960177732632, 0.13147294521331787, 0.09976592511520721, 0.07489151728805155, 0.19859481457388029, 0.09859639685600996, 0.1538892337703146, 0.08497766044456512, 0.12266766731045209, 0.13335669413208961, 0.19810152385616675, 0.07353624430834316, 0.09426295204320922, 0.1862676822929643, 0.1438791459077038, 0.11923377969651483, 0.11745454743504524, 0.18671924946829677, 0.13422505144262686, 0.15682371536968276, 0.2171903636190109], [0.07469363845302723, 0.015007974707259564, 0.07481103137251921, 0.09723849667352624, 0.051102823272231035, 0.070922763843555, 0.04238323374011088, 0.056000593467615545, 0.06068104426958598, 0.03774870703637134, 0.06423796512535773, 0.02717606010264717, 0.029923197653261013, 0.03683025475766044, 0.017307455273112282, 0.0274922966491431, 0.013955023005109979, 0.06416133095626719, 0.06381531202350743, 0.02285192924318835, 0.02848929783795029, 0.044178963944432326, 0.028425812670320738, 0.02965236755699152, 0.013724600994464708, 0.004130830611757119, 0.044562034599948674, 0.015580169638269581, 0.05624904595606495, 0.039342127784038894, 0.09588648172211833, 0.06359012957545929, 0.05461116314108949, 0.05299503267451655, 0.13340916397282854, 0.023290974531846587, 0.024267854241770692, 0.022281108213064726, 0.045664840072277, 0.031938893007463776, 0.022573269488930237, 0.02996563180204248, 0.1283530454384163, 0.1150726096238941, 0.6132437498308718, 4.546839343383908, 18.809522688388824, 32.146408036351204, 35.7311736792326, 29.91820950061083, 29.55603763461113, 19.552377127110958, 3.6957158893346786, 12.360008116811514, 20.412462875247, 11.902365423738956, 4.416025187820196, 1.1773845157586038, 0.1545475929742679, 0.23079833888914436, 1.7787981941364706, 2.927523460239172, 2.421696027740836, 4.775793682783842, 1.3522487576119602, 8.171241134405136, 3.395785870961845, 2.4569253623485565, 2.8493982274085283, 2.342848121188581, 2.5493789138272405, 2.778441309928894, 1.2917346297763288, 2.3445428302511573, 1.1472955928184092, 2.3057317128404975, 7.154517816379666, 14.766359142959118, 29.715834259986877, 37.195512503385544, 47.71341271698475, 51.6559861600399, 53.7062269449234, 54.697589948773384, 53.30056831240654, 52.64636881649494, 55.10713957250118, 52.4503905326128, 53.42707112431526, 46.380448043346405, 45.71729622781277, 44.42392162978649, 53.76013845205307, 55.30391961336136, 59.15127396583557, 58.28796409070492, 56.31658047437668, 53.42929780483246, 52.126028537750244, 59.87006239593029, 56.022662445902824, 52.531257793307304, 55.70584684610367, 53.7144611030817, 43.852648884058, 30.584988221526146, 15.493979249149561, 9.472359716892242, 4.301268495619297, 2.6956105045974255, 2.4622408021241426, 2.429943960160017, 1.9636253826320171, 3.4590163780376315, 3.128599883057177, 3.715666956268251, 5.6767538376152515, 14.307771250605583, 7.805804293602705, 2.9372796742245555, 5.49886210821569, 12.352687809616327, 2.211691509000957, 1.8781291390769184, 1.0463446285575628, 0.4106179007794708, 0.9749810735229403, 3.9508406119421124, 12.912297081202269, 20.674950890243053, 22.546682953834534, 17.619717232882977, 19.478780776262283, 26.57961744815111, 20.10781992226839, 13.83111722767353, 4.275726741179824, 0.39886287529952824, 0.04261899179255124, 0.05438130145194009, 0.06336120670312084, 0.06493141307146288, 0.10462938953423873, 0.037431438904604875, 0.15290156879927963, 0.0045879629669798305, 0.01593653596501099, 0.027613700876827352, 0.05626706901239231, 0.02636233599332627, 0.03534497234795708, 0.03678908040456008, 0.03811505710473284, 0.02104612809489481, 0.027614016289589927, 0.030955261609051377, 0.06426337626180612, 0.04502021431108005, 0.014526058330375236, 0.015838333129067905, 0.026563240935502108, 0.055657090415479615, 0.01011855367323733, 0.016348105091310572, 0.05467650182254147, 0.07991181977558881, 0.04631933268683497, 0.034623805186129175, 0.06092744843044784, 0.03548400629370008, 0.027994114643661305, 0.027242281939834356, 0.06934397824807093, 0.035994021309306845, 0.057924778302549385, 0.033328193458146416, 0.03169612908095587, 0.06925069028511643, 0.04058881342643872, 0.018716081249294803, 0.003080611868426786, 0.06879294844111428, 0.07530155387939885, 0.0010976414000651857, 0.05952541272563394, 0.08886029507266358, 0.05724881535570603, 0.08101395360426977, 0.1418499805731699, 0.022058604918129276, 0.002160489061679982, 0.0288216723856749, 0.020119074324611574, 0.05205601548368577, 0.020386629694257863, 0.042542153532849625, 0.0386030971276341, 0.008761561693972908, 0.030409597529796883, 0.03126697847619653, 0.007905521251814207, 0.004495075763770728, 0.04447377839824185, 0.06451322027714923, 0.062069224077276886, 0.04634852877643425, 0.01960084558959352, 0.023422967351507396, 0.0937977219291497, 0.03353411717398558, 0.047821617699810304, 0.020276233371987473, 0.06070934978197329, 0.049163606236106716, 0.04024157366075087, 0.06261756730964407, 0.04072991796419956, 0.027160684658156242, 0.15111983550013974, 0.16151917981915176, 0.9791049803607166, 7.201913623139262, 24.42545223981142, 36.74634240567684, 39.11583065986633, 29.644033312797546, 20.631002448499203, 13.905167654156685, 9.023462254554033, 25.620425418019295, 24.335965141654015, 13.998453598469496, 4.369792118668556, 0.3327073861146346, 0.06892682446050458, 0.354653256945312, 0.45717831642832607, 0.5762889515608549, 3.874461385421455, 2.795950770378113, 2.5571532966569066, 12.703642677515745, 6.070390390232205, 2.7697262400761247, 3.841577712446451, 4.2631209176033735, 4.332857150584459, 4.704764569178224, 4.8847542610019445, 4.518196005374193, 3.0567082157358527, 4.336173897609115, 8.891848716884851, 17.92787879705429, 33.75785976648331, 39.95686613023281, 50.63744701445103, 52.135908007621765, 56.226168125867844, 54.88242343068123, 53.87342557311058, 55.266761407256126, 56.55237302184105, 53.97655203938484, 57.42800943553448, 49.35612916946411, 42.59976111352444, 48.66644337773323, 58.17412979900837, 54.82136830687523, 59.370708391070366, 57.50672221183777, 58.80388900637627, 55.10958284139633, 58.25766831636429, 61.19658641517162, 56.9880348443985, 52.51637019217014, 56.68205626308918, 53.298299834132195, 45.490490198135376, 31.608446203172207, 18.248758278787136, 12.173349782824516, 5.651981541886926, 3.8326714653521776, 3.2841996336355805, 3.680878160521388, 2.658313843421638, 4.2307409550994635, 5.359810944646597, 5.110367154702544, 5.115347737446427, 12.790961991995573, 14.861280899494886, 7.515611490234733, 8.326242417097092, 4.760296689346433, 2.769222529605031, 1.6716787358745933, 0.5772578995674849, 0.22554374038008973, 1.071059808600694, 3.8617600919678807, 13.349126391112804, 23.080318719148636, 23.338455967605114, 17.956996634602547, 20.510136634111404, 31.47549133747816, 24.880850203335285, 18.977517373859882, 6.054117288440466, 0.5847572721540928, 0.02888086237362586, 0.00972004170762375, 0.09073953173356131, 0.02309675077412976, 0.05549347653868608, 0.047568337540724315, 0.10850910752196796, 0.03445239504799247, 0.0462803959089797, 0.03245493055146653, 0.04828426885069348, 0.06644840745138936, 0.005344621949916473, 0.02714488990022801, 0.05118560613482259, 0.019589683688536752, 0.02787111294310307, 0.05581884521234315, 0.02923593550804071, 0.0971497580758296, 0.0034524306374805747, 0.0380688547011232, 0.03505200213112403, 0.059433471760712564, 0.03126142721157521, 0.02302317981957458, 0.04909300201688893, 0.024763022593106143, 0.06341970278299414, 0.03535398944222834, 0.037112426725798286, 0.09748261873028241, 0.026166633506363723, 0.02507257795514306, 0.06805873432313092, 0.0059383289590186905, 0.034511354970163666, 0.1061625849979464, 0.1064477107138373, 0.20967959164408967, 0.16756087046815082, 0.16338317276677117, 0.20078642119187862, 0.14140221319394186, 0.11673812259687111, 0.18004314129939303, 0.0980855395027902, 0.20353447529487312, 0.23739644733723253, 0.153799730760511, 0.23438890872057527, 0.11331878107739612, 0.1628291595261544, 0.20155160513240844, 0.06745909384335391, 0.18203220097348094, 0.11091382926679216, 0.11493237339891493, 0.13857157289749011, 0.13096064067212865, 0.13491418008925393, 0.20510864473180845, 0.10866911456105299, 0.08113669740851037, 0.2510532410815358, 0.2112299678265117, 0.1632356783375144, 0.21187847130931914, 0.17517364321975037, 0.1574445961159654, 0.1961102822679095, 0.18454892764566466, 0.2957251580664888, 0.12890466896351427, 0.21576003724476323, 0.23119219666114077, 0.18030615843599662, 0.2597875474020839, 0.1467639036127366, 0.13198061875300482, 0.20493944990448654, 0.26189008145593107, 1.6503907344304025, 7.332051889970899, 27.624363787472248, 43.88978809118271, 49.80847589671612, 42.16088846325874, 37.10673026740551, 27.129297852516174, 8.171075843274593, 19.63097970932722, 25.618436224758625, 14.920977596193552, 5.545406760647893, 1.4704448590055108, 0.5327551031950861, 1.4520613267086446, 4.585701758041978, 6.423796126618981, 8.491654191166162, 12.423478960990906, 6.3184458296746016, 16.541730277240276, 12.6399333961308, 6.742450827732682, 6.182512873783708, 7.121165106073022, 7.456507561728358, 6.951337968930602, 5.693893767893314, 6.660078372806311, 5.190911432728171, 3.3907000813633204, 7.984601799398661, 17.106300182640553, 32.32664376497269, 39.742850214242935, 51.86078757047653, 52.85262554883957, 55.24086579680443, 55.583356618881226, 55.984744280576706, 57.09613524377346, 57.33315512537956, 56.91536754369736, 60.7226150482893, 50.69966487586498, 48.46223473548889, 51.012703478336334, 59.00292992591858, 61.225031688809395, 61.201476752758026, 57.322557494044304, 60.13831280171871, 58.39270167052746, 61.60639822483063, 61.69527925550938, 60.03528133034706, 53.023430183529854, 56.45749971270561, 54.44491110742092, 44.162108078598976, 32.471947968006134, 16.572533324360847, 11.955264285206795, 6.47707924246788, 4.723245352506638, 6.203031772747636, 5.143035901710391, 4.940430773422122, 7.707240432500839, 7.171482006087899, 12.713197264820337, 14.949246179312468, 23.51538397371769, 13.288010470569134, 6.906182141974568, 13.336056042462587, 24.853356778621674, 8.693659901618958, 4.932084046304226, 3.054065932519734, 0.8305100945290178, 1.864585834555328, 5.923527795821428, 18.099498488008976, 29.119562655687332, 32.496825233101845, 26.668167896568775, 29.098857566714287, 37.68728971481323, 29.62625976651907, 19.583603851497173, 6.3707685470581055, 0.7710672123357654, 0.17117070645326748, 0.12838718423154205, 0.196126728260424, 0.15826063201529905, 0.1502608589362353, 0.10768514548544772, 0.3193751483922824, 0.08843705567414872, 0.1361088894191198, 0.1407961902441457, 0.09676876172306947, 0.1401119597721845, 0.11806281909230165, 0.15298314567189664, 0.18688557960558683, 0.07481059350538999, 0.12130751842050813, 0.1151333173038438, 0.17112855246523395, 0.13957759860204533, 0.14294035878265277, 0.11584462132304907, 0.10635772530804388, 0.2123848386690952, 0.14840243209619075, 0.18296450172783807, 0.14652585232397541, 0.2098407712765038, 0.15036139026051387, 0.17284551111515611, 0.11460282272309996, 0.1600834951386787, 0.12391233802190982, 0.11901942518306896, 0.14267553080571815, 0.12596782733453438, 0.12328244018135592, 0.14821411954471841], [0.01058085415934329, 0.018054710781143513, 0.030612693662988022, 0.0030440369755524443, 0.060564545638044365, 0.0387133580079535, 0.05114194187626708, 0.0516359005268896, 0.027115129778394476, 0.04235774096741807, 0.022649091006314848, 0.081971197942039, 0.037407408162835054, 0.029781902012473438, 0.003381081487532356, 0.0737986306194216, 0.021770948478661012, 0.03280527249444276, 0.0331206221744651, 0.02357582936383551, 0.012920442241011187, 0.11728650293662213, 0.07061417141812854, 0.05112312843266409, 0.026402966723253485, 0.03557408075721469, 0.04945315144141205, 0.01639860638533719, 0.015215038547466975, 0.01578355520905461, 0.08265858996310271, 0.07999396068044007, 0.09454630402615294, 0.016273214969260152, 0.04424033955729101, 0.048971490177791566, 0.06960749262361787, 0.0485073102026945, 0.09682789604994468, 0.034233561673318036, 0.010436239263071911, 0.04132310175918974, 0.031984668676159345, 0.13523539644666016, 0.043044116246164776, 0.5300206749234349, 4.3824777379632, 18.31006608903408, 32.90765538811684, 38.49894516170025, 29.477630741894245, 23.445870503783226, 34.6563633531332, 11.64936549961567, 11.099352613091469, 10.522256679832935, 8.991690259426832, 3.693273332901299, 0.9046796802431345, 0.5966089549474418, 0.5884411744773388, 0.552715907106176, 3.016164628788829, 0.7634197664447129, 2.515236558392644, 9.45754336193204, 2.690695943310857, 3.017616388387978, 4.305085390806198, 4.403565656393766, 3.6902567697688937, 4.910681219771504, 5.123431803658605, 2.665175562724471, 1.9452806795015931, 2.2019709181040525, 2.2109106509014964, 5.216073207557201, 12.394055239856243, 22.37022802233696, 32.90795557200909, 38.8499741256237, 46.470161229372025, 51.77651569247246, 56.33439011871815, 51.835116147994995, 54.56372693181038, 53.872684612870216, 47.65664756298065, 37.849294021725655, 38.56068804860115, 49.4849194586277, 49.68127392232418, 44.536961764097214, 55.03123864531517, 52.91335768997669, 49.823564887046814, 48.85406970977783, 65.50204798579216, 49.18170712888241, 60.674437433481216, 49.02272365987301, 47.15873368084431, 39.53147515654564, 25.4315185546875, 12.994786854833364, 6.109500266611576, 3.9451827155426145, 1.8187871295958757, 2.3466918524354696, 2.518736645579338, 2.3984873481094837, 1.6609647357836366, 1.7518602521158755, 4.719003830105066, 4.0660535171628, 5.106486612930894, 13.12148630619049, 21.15121353417635, 4.829831058159471, 5.668145399540663, 3.7699076207354665, 2.401799582876265, 0.7430984568782151, 0.2849508955841884, 1.4166763192042708, 3.531720251776278, 11.788242347538471, 16.623963564634323, 22.162183485925198, 22.327750101685524, 24.842322170734406, 29.914842881262302, 30.51953863352537, 16.83707132935524, 3.47478695679456, 0.19483806303469464, 0.06453583351685666, 0.04656879078538623, 0.03273265334428288, 0.026073666522279382, 0.02378752142249141, 0.03324022669403348, 0.07335948699619621, 0.01428361538273748, 0.06654700919170864, 0.03833356764516793, 0.021914617136644665, 0.027356025348126423, 0.026192087316303514, 0.05168402138224337, 0.014706493911944563, 0.03887543563905638, 0.012432497769623296, 0.0363018419011496, 0.07915669193607755, 0.06062558728444856, 0.05018478288548067, 0.007708470375291654, 0.08191248663933948, 0.0166079718110268, 0.07794800054398365, 0.049954973146668635, 0.06482823227997869, 0.01723987159493845, 0.015534326248598518, 0.01797978355170926, 0.057292865531053394, 0.02147376842913218, 0.007871963189245434, 0.06530029015266337, 0.0264826826605713, 0.07557838238426484, 0.06644331631832756, 0.01947427972481819, 0.03964833049394656, 0.02708280739170732, 0.053543119865935296, 0.016666065275785513, 0.0609281868673861, 0.05548895314859692, 0.08050213888054714, 0.021405735751613975, 0.08543543939595111, 0.03765961591852829, 0.06186358237755485, 0.026181576649833005, 0.030054093949729577, 0.07949393868329935, 0.020948327874066308, 0.051651077446877025, 0.05745962982473429, 0.06269742239965126, 0.025982337829191238, 0.026866849839279894, 0.038497816058225, 0.02015848978771828, 0.16175978409592062, 0.02854871047020424, 0.05320729433151428, 0.026230649309582077, 0.027971182280452922, 0.04842126931180246, 0.029956631406093948, 0.06278040193137713, 0.023429104912793264, 0.040151822031475604, 0.06397496283170767, 0.05525552543986123, 0.052797183525399305, 0.0663772429106757, 0.027812409061880317, 0.01760132348863408, 0.038179004259291105, 0.04198090435238555, 0.027373287703085225, 0.022238291858229786, 0.009835392793320352, 0.0324120455479715, 0.03470548224868253, 0.11172852187883109, 0.9307611838448793, 6.316661350429058, 23.8168103992939, 40.378974080085754, 41.03475049138069, 31.855786330997944, 22.130350694060326, 15.51551079377532, 9.830962624400854, 21.130474247038364, 20.283581390976906, 12.725423108786345, 4.684768617153168, 0.8271197264548391, 0.2935387910110876, 0.2678299939725548, 0.5693771224468946, 2.3770633852109313, 3.490823758766055, 1.4223592705093324, 13.913744743913412, 3.8590095145627856, 3.0198908038437366, 4.274461409077048, 4.930746043100953, 2.898398023098707, 5.00590268522501, 3.9715483132749796, 6.286864299327135, 3.673765892162919, 4.066098164767027, 3.39220788795501, 6.746118105947971, 16.609216555953026, 24.073931202292442, 35.793744921684265, 42.71023638546467, 50.41002921760082, 54.10069897770882, 57.37791292369366, 53.67151580750942, 55.952054634690285, 54.83252830803394, 54.27410647273064, 44.57276724278927, 37.72794373333454, 50.32817021012306, 57.42968514561653, 48.06997798383236, 56.4365628361702, 55.958974063396454, 56.509921699762344, 53.09220649302006, 62.30528712272644, 56.14445351064205, 59.163471311330795, 51.82878188788891, 49.669350162148476, 42.31670670211315, 28.18410225212574, 16.817378886044025, 8.405252527445555, 5.224022381007671, 3.4727519284933805, 3.370721465907991, 3.3365900348871946, 4.391180695965886, 4.931263765320182, 3.572595133446157, 6.645229244604707, 5.046337740495801, 7.556093567982316, 9.377681147307158, 9.621156882494688, 5.09552420116961, 6.424885718151927, 2.8814438078552485, 0.8023360313382, 0.49671326531097293, 0.38817680964712054, 1.943262037821114, 4.6213932428509, 13.183457180857658, 21.7490316554904, 24.374350681900978, 24.313711635768414, 23.570743203163147, 30.847407840192318, 34.54150311648846, 20.76748162508011, 5.156838661059737, 0.8314758364576846, 0.03795469012402464, 0.07921253112726845, 0.10363031033193693, 0.05444896676635835, 0.015891099828877486, 0.0035396536304688198, 0.028898675773234572, 0.07859717195970006, 0.01745905748975929, 0.04103164181287866, 0.034914081406896, 0.010076577800646191, 0.08258295027189888, 0.02791828941553831, 0.01646438664465677, 0.02685445040697232, 0.032581166160525754, 0.05193324570427649, 0.06622182976570912, 0.055047245405148715, 0.06271016507525928, 0.03381748771062121, 0.07433925551595166, 0.024141266112565063, 0.04805185046279803, 0.07072110005537979, 0.038696986230206676, 0.052812894791713916, 0.04367016976175364, 0.020217008132021874, 0.04220945615088567, 0.045029294487903826, 0.020292645967856515, 0.022447583069151733, 0.01706980288872728, 0.04175012240011711, 0.054813702663523145, 0.028162890157545917, 0.053806062787771225, 0.16091925732325763, 0.18498333636671305, 0.12297821158426814, 0.1995559106580913, 0.13250933960080147, 0.13842056068824604, 0.1309666075394489, 0.18034452747087926, 0.1463316471199505, 0.1179755647899583, 0.110870265198173, 0.2375037470483221, 0.13056813360890374, 0.11375278161722235, 0.1530848495895043, 0.18875255598686635, 0.1396866497816518, 0.10252223932184279, 0.07381808231002651, 0.12602197442902252, 0.17630135145736858, 0.20742849446833134, 0.19192360457964242, 0.10385281362687238, 0.11454995212261565, 0.12252504879143089, 0.18584492529043928, 0.13932314584963024, 0.12978720129467547, 0.06322477769572288, 0.22940319031476974, 0.16996443446259946, 0.2197695494396612, 0.09394832595717162, 0.19764410855714232, 0.10679428625735454, 0.12080301385140046, 0.10545159268076532, 0.19830306147923693, 0.10197240437264554, 0.17191834602272138, 0.08799994553555734, 0.16701482789358124, 0.27330849843565375, 0.19690215383889154, 1.0651345015503466, 7.0893812365829945, 26.13762516528368, 44.87659893929958, 51.24415285885334, 41.36626750230789, 37.325195744633675, 40.42203716933727, 19.56351812928915, 20.12867510318756, 16.394286789000034, 12.747171241790056, 4.929287871345878, 1.4617314515635371, 0.9855330479331315, 1.5625962079502642, 2.4849498085677624, 8.479798827320337, 6.910067433491349, 7.856812756508589, 16.142744086682796, 7.827305914834142, 8.45554567873478, 11.81953176856041, 12.222663536667824, 8.056897670030594, 11.090458240360022, 10.116254165768623, 7.674745051190257, 5.0957403145730495, 4.970098156481981, 3.8535777060315013, 6.722718961536884, 15.198660045862198, 25.58838363736868, 35.77746279537678, 42.552218064665794, 51.32014498114586, 54.25880469381809, 58.80292005836964, 56.81923650205135, 58.00033852458, 60.69655604660511, 57.42181956768036, 45.068674832582474, 41.20635688304901, 52.21001923084259, 58.27110819518566, 53.094801753759384, 58.29069994390011, 57.9462294280529, 58.65188956260681, 55.38448669016361, 66.20660617947578, 55.439944714307785, 63.005369156599045, 55.04203386604786, 51.86139553785324, 41.855658441782, 27.327417321503162, 15.015358831733465, 8.540945146232843, 5.837322771549225, 3.494688863866031, 4.550305707380176, 4.249895727261901, 6.471568588167429, 7.4908192455768585, 6.076544634997845, 11.833658460527658, 10.445507448166609, 13.146555460989475, 24.687360785901546, 33.28498654067516, 12.938573621213436, 11.362684182822704, 8.704042844474316, 5.292839063331485, 1.8447379558347166, 1.3581684837117791, 2.3824821319431067, 5.560306711122394, 17.385813184082508, 25.559016913175583, 31.82949934154749, 32.07203842699528, 32.82239556312561, 40.81724636256695, 41.06098808348179, 22.479933835566044, 5.867542074993253, 0.532805094262585, 0.10718097488279454, 0.14995233330409974, 0.22733648715075105, 0.17596659832634032, 0.11952182205277495, 0.2265356801217422, 0.3609639167552814, 0.15662851568777114, 0.17849429394118488, 0.13088771724142134, 0.15953476598951966, 0.14119176979875192, 0.14177301985910162, 0.09392108913743868, 0.11033396702259779, 0.176139964023605, 0.11865444437717088, 0.13523616828024387, 0.21387707500252873, 0.25320974411442876, 0.17807351105147973, 0.08442692749667913, 0.217203484789934, 0.15389957930892706, 0.18571702355984598, 0.17621364444494247, 0.12222814519191161, 0.0671002283343114, 0.1517757456167601, 0.08427791166468523, 0.19625798449851573, 0.1272329071070999, 0.11931166067370214, 0.1320279826177284, 0.11460081150289625, 0.1860218236106448, 0.15738752495963126, 0.08297974694869481, 0.11528139060828835], [0.08266008910140954, 0.06142001184343826, 0.004305388383727404, 0.058973503473680466, 0.026698773799580522, 0.04885882473899983, 0.04893166282272432, 0.03685208874230739, 0.030824554560240358, 0.05026355815061834, 0.054544355007237755, 0.061664096792810597, 0.006281992500589695, 0.047873753574094735, 0.03243478495278396, 0.024447270297969226, 0.0892385900078807, 0.04364575681393035, 0.02443411201966228, 0.044720238220179453, 0.01467364645577618, 0.08667832153150812, 0.07700712798396125, 0.07890245440648869, 0.06754710513632745, 0.037063192648929544, 0.046530206527677365, 0.02630867500556633, 0.023788929647707846, 0.025345582544105127, 0.020374595769681036, 0.028685712786682416, 0.051185461416025646, 0.025975315256800968, 0.037116738603799604, 0.029576594279205892, 0.035177083700546063, 0.0497101794462651, 0.056772293464746326, 0.08171365785528906, 0.01615469027456129, 0.024621589654998388, 0.04617351180058904, 0.0326539263187442, 0.007460564293069183, 0.05506687521119602, 0.5114117078483105, 4.681661808863282, 16.414912082254887, 29.99832060188055, 33.41463938355446, 33.90387073159218, 32.71818235516548, 29.13458324968815, 19.114150442183018, 19.665755443274975, 16.974217370152473, 12.157485634088516, 4.9876821879297495, 1.4730771677568555, 0.02612462794786552, 0.06008275078784209, 0.95610445830971, 1.5707599511370063, 0.7463017443660647, 13.029570188373327, 2.192959701642394, 2.322341096587479, 2.7630001259967685, 3.283183188177645, 1.6558097186498344, 2.78809136711061, 3.027724795974791, 4.745695497840643, 2.7086708787828684, 3.0678432807326317, 1.6672146879136562, 0.3228070173645392, 3.4156158193945885, 5.8430305402725935, 15.271860267966986, 22.46068026870489, 28.912175484001637, 35.62409542500973, 43.64201478660107, 54.59121085703373, 49.84206609427929, 51.67482174932957, 50.53821913897991, 31.075975075364113, 32.7332067489624, 46.914304196834564, 52.9455191642046, 48.05065222084522, 51.07199549674988, 41.46664671599865, 57.87280976772308, 55.35208962857723, 62.23022595047951, 44.37765531241894, 46.92828744649887, 49.355335012078285, 28.988577984273434, 22.57549110800028, 11.12345851957798, 4.987838929519057, 2.029289184138179, 1.2096083303913474, 2.207611477933824, 1.758182281628251, 2.463802043348551, 4.747873255982995, 3.641139417886734, 5.161995934322476, 3.7419565580785275, 4.094213806092739, 4.068046985194087, 2.38973974250257, 10.231700520962477, 10.369615070521832, 6.6888874769210815, 1.4549364661797881, 0.69050298538059, 1.0377234849147499, 1.4013925893232226, 7.822037972509861, 9.884539749473333, 12.10009541362524, 11.828235201537609, 15.930089447647333, 17.503969743847847, 26.096965447068214, 23.81434243172407, 16.04619886726141, 5.521808126941323, 0.35056244989391416, 0.015427683338202769, 0.03786080844292883, 0.023469006482628174, 0.03758092971111182, 0.02704872611502651, 0.04130477442231495, 0.06961524806683883, 0.0361790313036181, 0.06550551624968648, 0.03470916701189708, 0.07811250499798916, 0.04987609027011786, 0.06933389988262206, 0.08482096338411793, 0.05468568590003997, 0.059010202676290646, 0.00916979764951975, 0.03514079267915804, 0.07763111832900904, 0.034863567125285044, 0.016047273675212637, 0.04783492440765258, 0.053804801136720926, 0.019281193308415823, 0.02162661745387595, 0.06412039409042336, 0.03205247128789779, 0.04545803320070263, 0.06604075315408409, 0.020475774617807474, 0.03741091852134559, 0.031957105311448686, 0.016924104456848, 0.04984706858522259, 0.09918703508446924, 0.037854756228625774, 0.029235445690574124, 0.042293771548429504, 0.05719670916732866, 0.03923172960639931, 0.07223244669148698, 0.08002101938473061, 0.04348370144725777, 0.08691913360962644, 0.010455544379510684, 0.06587938798475079, 0.01654315448831767, 0.002743472500696953, 0.08400094957323745, 0.04123180275200866, 0.06148049687908497, 0.054296262460411526, 0.015901779333944432, 0.013808535113639664, 0.03929677142878063, 0.020384976560308132, 0.017322342755505815, 0.033963824389502406, 0.03132934114546515, 0.01743019907735288, 0.04422439080371987, 0.04973589115252253, 0.0716095176176168, 0.045011312249698676, 0.044433390721678734, 0.11609663983108476, 0.06765990416170098, 0.06689454952720553, 0.050434589793439955, 0.021111704263603315, 0.07616902061272413, 0.010746523785201134, 0.06292220408795401, 0.035536472423700616, 0.05284777573251631, 0.03438280014961492, 0.050468706322135404, 0.03234643598261755, 0.01811343878216576, 0.04067686924827285, 0.04135575254622381, 0.026822404470294714, 0.059020381231675856, 0.06259382600546815, 0.04312005650717765, 0.0896229779755231, 0.7380257290787995, 6.86611139215529, 21.73991784453392, 36.76942236721516, 37.083513513207436, 34.06440831720829, 30.29312778264284, 17.836541198194027, 14.57948612049222, 16.943629011511803, 18.09590008109808, 14.332227688282728, 5.545688895508647, 1.4935607998631895, 0.13996560825034976, 0.16754199023125693, 0.6443784479051828, 0.6382473581470549, 1.1891390662640333, 10.494709108024836, 4.987111743539572, 2.260750913992524, 3.567834938876331, 4.146405905485153, 3.507237690500915, 4.251140160486102, 5.149599574506283, 8.718618862330914, 5.391298430040479, 6.162323132157326, 3.2724848622456193, 1.710203681141138, 3.2168919453397393, 9.39569978043437, 17.628325670957565, 24.348314478993416, 32.543182745575905, 41.3096809387207, 47.33137361705303, 60.9220777451992, 54.532184824347496, 58.23918230831623, 53.66645447909832, 38.401544988155365, 34.20018643140793, 48.00488367676735, 56.725769117474556, 52.32889965176582, 53.23565259575844, 51.42636448144913, 61.44095130264759, 59.36725437641144, 63.433135002851486, 48.96496295928955, 53.998898640275, 52.977125868201256, 34.019262939691544, 25.68734362721443, 14.22837546095252, 6.937092058360577, 3.413825877942145, 2.782765715382993, 3.4236875362694263, 3.83271302562207, 3.629663083702326, 6.059873029589653, 4.639389552175999, 5.378287928178906, 5.637421198189259, 7.56541209295392, 6.070292545482516, 4.843197790905833, 8.213448319584131, 3.9217821462079883, 1.9324820162728429, 0.6354002421721816, 0.051206987409386784, 0.31235645001288503, 1.2910520914010704, 6.566405324265361, 10.79070657491684, 18.718555569648743, 17.94784102588892, 19.225832149386406, 19.33898437768221, 28.130082450807095, 30.723597183823586, 20.804791823029518, 7.721523866057396, 0.703725207131356, 0.06054026627680287, 0.068489847908495, 0.033386270224582404, 0.02566582668805495, 0.08398008038057014, 0.01610380862985039, 0.0302741685663932, 0.04910629759251606, 0.027391932308091782, 0.05131070254719816, 0.014384264522959711, 0.06532311119372025, 0.061729439185000956, 0.06980415433645248, 0.00772341259107634, 0.059200871546636336, 0.03843982092803344, 0.03138584455882665, 0.03409234952414408, 0.03233039074984845, 0.02363829222304048, 0.08702089689904824, 0.05428301512438338, 0.024893156332836952, 0.030678720686410088, 0.029173281545809004, 0.01648303496040171, 0.03641551666078158, 0.08134317773510702, 0.05515026663488243, 0.019387023567105643, 0.06542058486957103, 0.00630562387414102, 0.05708036267606076, 0.06103708961745724, 0.011368696796125732, 0.010797404502227437, 0.06030324657331221, 0.04779300048539881, 0.05310379070579074, 0.1870228472398594, 0.15172618499491364, 0.15067573433043435, 0.14505110098980367, 0.13358488969970495, 0.14098347863182425, 0.11356355622410774, 0.12708498223219067, 0.25921606400515884, 0.17105582199292257, 0.16751646035118029, 0.15426311292685568, 0.07405522075714543, 0.0973976353998296, 0.12494002701714635, 0.1689191788318567, 0.2386173396371305, 0.11968251928919926, 0.08994121089926921, 0.10007974226027727, 0.16077332140412182, 0.1944234993425198, 0.14808077045017853, 0.20000112504931167, 0.13761207985226065, 0.21432960696984082, 0.10059063672088087, 0.26868379034567624, 0.16488096036482602, 0.1071712007978931, 0.21117829950526357, 0.10871559527004138, 0.06894770849612541, 0.10771226356155239, 0.18757469340926036, 0.16292378335492685, 0.2066460927017033, 0.14789302193094045, 0.08983705789432861, 0.12849777907831594, 0.16429401061031967, 0.09709782258141786, 0.17201798676978797, 0.20463050866965204, 0.09521198822767474, 0.19060767284827307, 0.7150962157174945, 7.6142290234565735, 23.979126289486885, 44.975807815790176, 44.86221291124821, 46.06280788779259, 46.96418032050133, 36.87966205179691, 30.461804531514645, 29.109557792544365, 24.244243763387203, 18.525047153234482, 6.843139249831438, 2.640138231217861, 0.23346345056779683, 0.970001321984455, 2.2950485860928893, 2.237614430487156, 4.133111843839288, 24.07251387834549, 9.965093526989222, 6.550541650503874, 8.132255226373672, 9.59782613441348, 6.494028232991695, 9.052166864275932, 10.234488621354103, 10.772164519876242, 8.548623584210873, 7.470970060676336, 4.983944613486528, 1.435272165108472, 4.4351794850081205, 7.228367803618312, 17.26224571466446, 24.611064679920673, 33.161230981349945, 40.882002487778664, 47.939793169498444, 63.50927151739597, 59.752834886312485, 62.19194680452347, 59.94240291416645, 39.98531520366669, 39.664498418569565, 49.03852321207523, 61.181007251143456, 59.01888146996498, 58.69334153831005, 57.26263090968132, 66.46527349948883, 61.78959019482136, 65.863606184721, 52.55047336220741, 54.126628786325455, 57.454300224781036, 34.9751852452755, 23.284861743450165, 13.94164189696312, 6.55025951564312, 3.258501375094056, 2.5341999158263206, 4.88545342348516, 4.47525498457253, 7.531314147636294, 12.238679677248001, 9.36067420989275, 11.604606751352549, 10.24283392354846, 11.932580452412367, 11.165372170507908, 8.670364301651716, 22.525711879134178, 21.025692969560623, 14.00507664307952, 4.340875670313835, 1.8793799844570458, 1.9335133046843112, 2.1808787249028683, 10.28447113931179, 13.891207203269005, 20.407146960496902, 21.45525611937046, 24.305669367313385, 26.49851270020008, 36.401039734482765, 37.04571694135666, 23.362829759716988, 7.703351341187954, 0.7346109591890126, 0.1670376118272543, 0.17294693301664665, 0.19585894653573632, 0.12401701053022407, 0.12194050359539688, 0.14468237233813852, 0.10052204743260518, 0.1329708070261404, 0.1419078977778554, 0.10769980290206149, 0.13663115358212963, 0.23271147685591131, 0.14693482022266835, 0.21074697811855003, 0.13586179877165705, 0.22045480407541618, 0.11061830606195144, 0.14009782928042114, 0.19044919463340193, 0.1268009771592915, 0.09520878214971162, 0.16860579955391586, 0.2644992055138573, 0.13264196139061823, 0.20061513350810856, 0.14006186480401084, 0.18344069336308166, 0.09616790412110277, 0.14032183913514018, 0.14193707902450114, 0.09212041622959077, 0.1254833533312194, 0.14279301278293133, 0.1396438872325234, 0.21377333760028705, 0.06968266476178542, 0.16363663104129955, 0.16737517027650028, 0.15312376781366765, 0.07286955820745789], [0.051696682421606965, 0.05210618466662709, 0.021972513932269067, 0.023243317518790718, 0.060759047701139934, 0.061136359290685505, 0.04667652465286665, 0.03982563328463584, 0.04248115270456765, 0.026023920363513753, 0.11226668284507468, 0.040863192843971774, 0.017243999791389797, 0.006106116488808766, 0.022344545141095296, 0.02586650341982022, 0.03971197707869578, 0.03379167210368905, 0.0751945361844264, 0.029759439057670534, 0.02761014227871783, 0.05696875108696986, 0.022834305091237184, 0.015183804334810702, 0.1282392890425399, 0.04657727724406868, 0.010272415729559725, 0.06931188778253272, 0.02287975792569341, 0.0674929135129787, 0.04010195341834333, 0.06976064221817069, 0.025896402694343124, 0.0729397134273313, 0.07981099901371635, 0.053036451936350204, 0.018317785434192047, 0.015958366238919552, 0.036226461961632594, 0.014836598893452901, 0.050240351192769594, 0.07030655120615847, 0.05764253954112064, 0.026022237543656956, 0.027425228763604537, 0.038277019702945836, 0.025484301077085547, 0.14774295967072248, 3.3143864013254642, 13.42954432591796, 28.066747449338436, 35.4970720410347, 38.837567791342735, 29.530550502240658, 21.442561000585556, 16.827319152653217, 20.803277604281902, 22.506627403199673, 12.830844651907682, 7.003887724131346, 3.019135594367981, 0.44332862365990877, 0.840653768973425, 1.701367017813027, 0.6189458188600838, 9.265446569770575, 2.9121418856084347, 1.4370385953225195, 3.0553388642147183, 2.126648984849453, 1.81928122183308, 2.324167611077428, 2.32689515221864, 9.064918030053377, 4.547457285225391, 6.509957453235984, 3.418122734874487, 2.2449758229777217, 0.934082146268338, 0.9318407415412366, 3.5334325348958373, 9.36730770394206, 15.17561998218298, 17.373524643480778, 21.77842877805233, 28.386644683778286, 33.78056734800339, 39.93074253201485, 48.2797609269619, 38.810486644506454, 23.799800612032413, 38.38094249367714, 55.63307695090771, 51.31825648248196, 47.94694818556309, 53.149245232343674, 62.18867897987366, 49.20369654893875, 49.05289024114609, 49.92764130234718, 31.163852959871292, 34.38623204827309, 15.736306495964527, 6.827423768118024, 2.4258492048829794, 1.305473386310041, 1.1269884137436748, 1.8249460053630173, 3.303248011507094, 4.308459609746933, 2.678910163231194, 4.2431415896862745, 3.8858063891530037, 3.1363680912181735, 3.6018970236182213, 3.8161606388166547, 4.936418663710356, 4.487029602751136, 2.3981406167149544, 1.6614045621827245, 1.8623515544459224, 0.5203919915948063, 0.17262816574657336, 1.4215252152644098, 7.578030740842223, 12.398409806191921, 17.068942487239838, 17.480992376804352, 19.018895253539085, 17.90366269648075, 30.977773144841194, 27.76939820498228, 19.25198994576931, 5.743217021226883, 0.5527806223835796, 0.005311671520757955, 0.005584659875239595, 0.03390917263459414, 0.06122496059106197, 0.052351661142893136, 0.07692659753956832, 0.031299714610213414, 0.04126796389755327, 0.07057596565573476, 0.02113001490215538, 0.008105548604362411, 0.008565348980482668, 0.014285260167525848, 0.08205499383620918, 0.02512527229555417, 0.03525572537910193, 0.13266211812151596, 0.036988818319514394, 0.04784774500876665, 0.017965983315662015, 0.022659874412056524, 0.04483313372475095, 0.027922105909965467, 0.04377497585664969, 0.0464303171611391, 0.027013039943994954, 0.05240179321845062, 0.08225618264987133, 0.04949695670802612, 0.024324355799762998, 0.009126975728577236, 0.041623957295087166, 0.04038625535031315, 0.05247783366939984, 0.020126991184952203, 0.034387531341053545, 0.023557980712212157, 0.061130370158934966, 0.04119821314816363, 0.025074798832065426, 0.04950183632900007, 0.0930017685459461, 0.011030223649868276, 0.046516079746652395, 0.04246833952493034, 0.04876015991612803, 0.04391246613522526, 0.014837412472843425, 0.029710689232160803, 0.05726475297706202, 0.043763001303886995, 0.0829852611059323, 0.053936736439936794, 0.05718710206565447, 0.045309314227779396, 0.04033891746075824, 0.03863601137709338, 0.020821218386117835, 0.06365451830788516, 0.04586260758514982, 0.04651918192394078, 0.032008573252824135, 0.09137324421317317, 0.025701028607727494, 0.02222527273261221, 0.07133568738936447, 0.06578343571163714, 0.021244214731268585, 0.030061148063396104, 0.003833000023405475, 0.05765441761468537, 0.02347213277971605, 0.06881735767819919, 0.03123036090983078, 0.006005020668453653, 0.02314123325049877, 0.01912230876769172, 0.051062019992969, 0.019981847508461215, 0.09023625912959687, 0.03047704947675811, 0.025196781934937462, 0.024487353693984915, 0.04408035478263628, 0.03300609765574336, 0.04107204433239531, 0.09013174247229472, 0.08810032843030058, 0.46677695761900395, 5.482484037056565, 18.397227711975574, 35.068911015987396, 43.80045108497143, 39.73558500409126, 28.794370405375957, 21.67141892015934, 16.410297229886055, 23.63357663154602, 30.074377320706844, 20.968046262860298, 9.79054894298315, 2.9484211513772607, 0.5666152050253004, 0.054661580943502486, 0.4925552196800709, 0.601603965042159, 4.73214827477932, 1.6022625169716775, 1.4662497653625906, 2.294709454290569, 3.9399943314492702, 2.5922959484159946, 4.733332386240363, 4.123839866369963, 6.8389124516397715, 5.9721248131245375, 5.4881794564425945, 4.962950265035033, 2.7933046873658895, 1.862946697510779, 1.9840257754549384, 4.0518612787127495, 11.321276854723692, 18.275316953659058, 21.177544221282005, 28.327502757310867, 37.64833800494671, 42.59444899857044, 44.712272956967354, 57.91856691241264, 41.632169634103775, 29.986630529165268, 40.13840138912201, 64.17737066745758, 53.93890365958214, 55.81554315984249, 58.6744299530983, 63.82483318448067, 53.62045034766197, 55.6681414693594, 53.0275871604681, 38.18764686584473, 40.18307939171791, 18.95998701453209, 9.721538946032524, 4.298746855929494, 3.3150679897516966, 2.659478480927646, 3.848466742783785, 4.76713347248733, 5.2029335126280785, 5.023025516420603, 5.517453560605645, 4.997375942766666, 4.664208870381117, 7.227548472583294, 6.919214017689228, 6.78105010651052, 4.231504239141941, 3.006263547576964, 1.7057854682207108, 0.7522663555573672, 0.4622839658986777, 0.3818781132576987, 1.5015161479823291, 7.749821897596121, 15.796663407236338, 21.20565891265869, 18.613707795739174, 18.134775795042515, 19.506933465600014, 30.368352346122265, 33.42750549316406, 23.496255800127983, 8.123253509402275, 0.8616554795298725, 0.078450894652633, 0.056695622188271955, 0.032199401684920304, 0.10001506409025751, 0.06244535936275497, 0.07263923267601058, 0.016835519854794256, 0.0340068726654863, 0.044634642617893405, 0.03682217276946176, 0.01645524152991129, 0.03879864190821536, 0.018108588847098872, 0.01602656218892662, 0.04496598929108586, 0.06547719589434564, 0.03261271114752162, 0.03296925744507462, 0.044706916669383645, 0.007595339238832821, 0.05151727193151601, 0.02390264893620042, 0.02661444912519073, 0.006302019819486304, 0.04578753563691862, 0.011473230151750613, 0.05694086859875824, 0.05782873326097615, 0.06744279628037475, 0.03660923946881667, 0.03757373087864835, 0.03722717388882302, 0.020779426195076667, 0.08765999737079255, 0.05280758843582589, 0.018893402593676, 0.04572827885567676, 0.03279714968812186, 0.0485604702407727, 0.02958662069431739, 0.038894367826287635, 0.12123186388635077, 0.1178366421663668, 0.16368224343750626, 0.1466095814248547, 0.14764259161893278, 0.23618463892489672, 0.09627918916521594, 0.11743437586119398, 0.1390730420826003, 0.15835464728297666, 0.23886529117589816, 0.24628583283629268, 0.12085667854989879, 0.19009556126547977, 0.11247744536376558, 0.09559683632687666, 0.13916465279180557, 0.17488276585936546, 0.10957394100842066, 0.16534747439436615, 0.12497121206251904, 0.16753507341491058, 0.10051918274257332, 0.1503016028436832, 0.2518156939186156, 0.14031475904630497, 0.10028565855463967, 0.1337145725847222, 0.17833952646469697, 0.12681292573688552, 0.13695688219740987, 0.22808523994171992, 0.14256600465159863, 0.20249416236765683, 0.16963006724836305, 0.16306836856529117, 0.1458321520476602, 0.0967666985525284, 0.20450124138733372, 0.09184372873278335, 0.07485777183319442, 0.13028978370130062, 0.10526575148105621, 0.1169454341288656, 0.22983179544098675, 0.19264697592006996, 0.17058823927072808, 0.42666530061978847, 5.5817660596221685, 20.38929171860218, 43.73946435749531, 51.356604024767876, 52.19706192612648, 40.623392164707184, 33.3380126953125, 26.761249601840973, 30.636513456702232, 33.476720452308655, 19.219013415277004, 10.618103686720133, 3.919700332917273, 0.8378561097197235, 1.1413098452612758, 2.8201989317312837, 1.9198788050562143, 17.84094326198101, 8.186171483248472, 6.208611773326993, 8.475718796253204, 9.107385501265526, 5.799864856526256, 7.919975817203522, 8.11420714482665, 16.3508228212595, 10.99576922133565, 12.82756257802248, 9.523018598556519, 4.83952671289444, 2.2132836235687137, 2.072023591026664, 4.769453248009086, 10.045726150274277, 17.513248845934868, 22.03929428011179, 29.599190019071102, 38.043600395321846, 46.776234805583954, 47.87763610482216, 60.40718637406826, 47.2084654122591, 37.18396492302418, 46.20266318321228, 61.949565410614014, 59.11269083619118, 59.24516312777996, 64.18649017810822, 67.232725918293, 56.40009619295597, 56.68560907244682, 56.90959185361862, 41.253926530480385, 40.24676397442818, 20.338330753147602, 8.178150113672018, 3.5425788816064596, 2.8691270062699914, 3.585934080183506, 4.902534931898117, 7.023683236911893, 11.652930658310652, 8.925017137080431, 9.71126714721322, 11.75215283408761, 9.726102501153946, 12.30240035802126, 9.415889047086239, 11.867461446672678, 10.810166280716658, 7.175769601017237, 3.6034938879311085, 5.049715284258127, 2.11732832249254, 0.6312027736566961, 2.545082769356668, 10.00398064032197, 17.71221186965704, 25.341793969273567, 26.359398365020752, 29.52800463885069, 26.44108448177576, 38.934690579771996, 37.460297495126724, 26.927199997007847, 8.761409316211939, 0.9969405108131468, 0.18648606666829437, 0.14773415779927745, 0.13743311836151406, 0.17550168733578175, 0.16100764711154625, 0.1405302490456961, 0.09709346617455594, 0.1515383622609079, 0.14462159044342116, 0.08565283671487123, 0.0827767769806087, 0.11042777448892593, 0.09524602312012576, 0.1792173387366347, 0.14289344020653516, 0.1604962776764296, 0.14596287393942475, 0.1431432768004015, 0.1458666767575778, 0.1660347922006622, 0.13698769616894424, 0.18223461433080956, 0.08836275184876285, 0.11055077804485336, 0.1170260833168868, 0.13130654086126015, 0.14672283316031098, 0.14455840399023145, 0.11546471592737362, 0.1350889855530113, 0.14704247616464272, 0.0988367859099526, 0.09365804973640479, 0.12844321638112888, 0.1132182645960711, 0.136929675063584, 0.22374124178895727, 0.1641657971777022, 0.2648568613221869, 0.13383128272835165, 0.1720925874542445], [0.07653743756236508, 0.035146069349139, 0.039638834714423865, 0.024953433567134198, 0.06035323764081113, 0.04564607857901137, 0.03900538198649883, 0.04975408119207714, 0.03661832706711721, 0.0484539943136042, 0.04566260249703191, 0.04536146123427898, 0.018756819590635132, 0.014083721616771072, 0.020687746837211307, 0.011017405831807991, 0.042657691083149984, 0.03996686398750171, 0.04262467293301597, 0.05197031226998661, 0.15640723693650216, 0.02249403223686386, 0.018711941920628306, 0.04854177183005959, 0.035625960590550676, 0.04001652108854614, 0.049522486588102765, 0.0125407001178246, 0.058757160004461184, 0.04821928640012629, 0.061315291095525026, 0.01606149693543557, 0.03084773739828961, 0.04589555523125455, 0.021798938578285743, 0.021431673812912777, 0.0075031227515864884, 0.04796971697942354, 0.07608890577103011, 0.029947115217510145, 0.012925632636324735, 0.00663014649944671, 0.07790644027409144, 0.051383369936957024, 0.01749458595440956, 0.040055368808680214, 0.07282907405169681, 0.04602998786140233, 0.07891471468610689, 1.9658847176469862, 12.327914088964462, 27.05714352428913, 41.21756628155708, 41.0922946035862, 28.330373503267765, 23.809510990977287, 14.736312255263329, 12.628406714648008, 14.70561845228076, 11.12282395362854, 7.14351455681026, 2.7066968847066164, 1.0365132498554885, 0.42280260007828474, 0.5461123364511877, 4.544671084731817, 1.9852142804302275, 0.4375816695392132, 1.434145881794393, 2.772036516107619, 2.9143158439546824, 3.4131523640826344, 2.03381379134953, 5.23516433313489, 3.4363387199118733, 3.808278674259782, 2.820206768810749, 1.7374577187001705, 1.4918730966746807, 0.59011468780227, 0.2893763518659398, 0.6280490022618324, 3.0146235739812255, 3.202674058265984, 5.426075588911772, 12.839128207415342, 21.035749129951, 33.38167995214462, 32.801424488425255, 37.51720704138279, 24.074381478130817, 24.55862559378147, 46.31015181541443, 51.821748465299606, 51.33721366524696, 58.374614641070366, 50.35788841545582, 37.65114985406399, 37.39840641617775, 38.37920218706131, 22.08606217056513, 10.992190763354301, 4.217851096764207, 1.6009157267399132, 0.9060028404928744, 0.8676746534183621, 2.2565041668713093, 2.763622342608869, 2.413696269504726, 2.4355443846434355, 3.4230940556153655, 3.6262147687375546, 3.342379736714065, 3.3078303281217813, 5.490950932726264, 6.256722891703248, 3.1617060815915465, 1.9909140933305025, 3.0818640533834696, 1.0746138053946197, 0.2527520467992872, 0.7230576791334897, 3.102309093810618, 7.748663434758782, 10.962113477289677, 12.639953345060349, 12.407784853130579, 18.053353764116764, 18.693296425044537, 24.781531132757664, 29.953469708561897, 19.19644832611084, 6.012065419927239, 0.5588415346574038, 0.04743044279166497, 0.006122335662439582, 0.013735594056925038, 0.005697963561033248, 0.01906971647258615, 0.03523545732605271, 0.008696115401107818, 0.04491511877859011, 0.04168783394561615, 0.03490428876830265, 0.020833094604313374, 0.016330484650097787, 0.06167264262330718, 0.033283415978075936, 0.040945693690446205, 0.06622998596867546, 0.04570870099996682, 0.08663386688567698, 0.13131685671396554, 0.03692937229061499, 0.0338221372658154, 0.03806140724918805, 0.04163214318396058, 0.04227950004860759, 0.0545494127436541, 0.007955205255711917, 0.02977610954985721, 0.018758311307465192, 0.03741599110071547, 0.027884315750270616, 0.05214629774854984, 0.02244138242531335, 0.01853610301623121, 0.026768845527840313, 0.03709790289576631, 0.024870515262591653, 0.16205288789933547, 0.023226396551763173, 0.025572687154635787, 0.0027133939511259086, 0.026092086627613753, 0.018561933466116898, 0.05669580030371435, 0.025342938643007074, 0.007837890261725988, 0.024861741221684497, 0.05827272681926843, 0.036620839237002656, 0.025751661632966716, 0.06411816022591665, 0.04009751537523698, 0.04412249763845466, 0.05015112277760636, 0.005967086253804155, 0.04007940326118842, 0.029593194267363288, 0.0260280485599651, 0.028127599180152174, 0.06267667937208898, 0.035164084983989596, 0.033428387105232105, 0.0032824231584527297, 0.09623314632335678, 0.013592866071121534, 0.06129169079940766, 0.051094767259201035, 0.08687951034517027, 0.03892069551511668, 0.02937369852588745, 0.018385630719421897, 0.0611341476906091, 0.012082375687896274, 0.01591553689650027, 0.026277113320247736, 0.03508356567181181, 0.05050580257375259, 0.017013256801874377, 0.016002765223674942, 0.08361901069292799, 0.03633855223597493, 0.02490499544364866, 0.050643552604014985, 0.059511853687581606, 0.05170484975678846, 0.07777565158903599, 0.025383335596416146, 0.044268990168347955, 0.017442733951611444, 0.04858982218138408, 0.02688662993023172, 0.1581847548368387, 3.223478179425001, 15.850011594593525, 31.009210757911205, 46.887971609830856, 42.131022065877914, 29.38452623784542, 20.23170467466116, 15.511247422546148, 22.528246343135834, 22.149866446852684, 19.667134769260883, 12.32338473200798, 3.6127960262820125, 1.2495899037458003, 0.14657101943157613, 0.32267782429698855, 0.8117795339785516, 0.9964391752146184, 0.5631810799241066, 1.4805260743014514, 1.8874246277846396, 3.5700264712795615, 3.862737352028489, 6.384884789586067, 5.814479347318411, 6.347883325070143, 4.636392937973142, 3.909110063686967, 5.0290244445204735, 4.868860663846135, 3.1902268761768937, 0.8348925656173378, 1.2847393238916993, 5.096319308504462, 5.7230842765420675, 7.870750883594155, 14.8929987475276, 26.117212660610676, 37.864421010017395, 39.94937293231487, 44.22133170068264, 26.569817773997784, 29.50311027467251, 53.7108588963747, 55.70995442569256, 56.59634046256542, 64.68849644064903, 57.85311922430992, 47.51676566898823, 43.058746084570885, 42.25383907556534, 26.539814583957195, 14.954062420874834, 6.956150410696864, 3.8427207386121154, 2.670190818607807, 2.062715752981603, 4.381499290466309, 3.646694482304156, 3.3444503881037235, 4.096810016781092, 1.884307013824582, 6.242643222212791, 2.3993603512644768, 4.445124501362443, 3.430540943518281, 3.6393639631569386, 6.17004906758666, 3.5538481269031763, 1.691981521435082, 0.8419448090717196, 0.1371573214419186, 0.6518947414588183, 2.7458827570080757, 7.7781441528350115, 15.265019685029984, 17.917049378156662, 17.317783534526825, 19.840139485895634, 20.864564515650272, 26.88038270920515, 33.99389170110226, 23.69048237800598, 8.963564168661833, 1.1270765215158463, 0.03548590248101391, 0.061104847700335085, 0.061624629379366525, 0.016391116259910632, 0.06516419511171989, 0.036663319770013914, 0.062243458087323233, 0.030010676455276553, 0.021052430784038734, 0.08859421286615543, 0.024263431041617878, 0.009393867803737521, 0.049545437505003065, 0.021225638774922118, 0.043765205482486635, 0.04728758678538725, 0.02675357027328573, 0.06416297852410935, 0.07098525267792866, 0.07482920656912029, 0.023504731616412755, 0.10710125337936915, 0.03375779306225013, 0.05287769541610032, 0.007399164096568711, 0.02623018361191498, 0.03240329562686384, 0.04648214133339934, 0.060938907190575264, 0.0670119647111278, 0.017400448232365306, 0.037436363054439425, 0.021616290468955413, 0.03576491290004924, 0.027803453194792382, 0.030812696895736735, 0.055513711195089854, 0.07511095551308244, 0.04905205401882995, 0.003634211129792675, 0.062163807087927125, 0.031115895762923174, 0.1522543269675225, 0.14403980603674427, 0.10289630401530303, 0.17379629134666175, 0.13620657089632004, 0.11643189020105638, 0.13224848953541368, 0.1247074527782388, 0.18539735086960718, 0.12358320294879377, 0.15890799259068444, 0.1291857796604745, 0.1579181308625266, 0.1321781487786211, 0.14200007251929492, 0.06001101108267903, 0.14241698139812797, 0.1113264930609148, 0.1433468033792451, 0.11962391930865124, 0.18629960948601365, 0.10095158766489476, 0.12761673104250804, 0.19878956896718591, 0.16622567258309573, 0.21278301574056968, 0.14510701439576223, 0.22300881624687463, 0.28483405185397714, 0.11606094994931482, 0.16946979303611442, 0.14136403711745515, 0.17324068991001695, 0.09067473481991328, 0.05251206523098517, 0.1325107496813871, 0.1111143353045918, 0.2058548593777232, 0.2527528186328709, 0.11008971137925982, 0.1270429024589248, 0.1489809065242298, 0.16125078953336924, 0.1212405989645049, 0.09331027933512814, 0.11690051192999817, 0.19157025322783738, 0.26059366820845753, 0.25953388132620603, 3.5112566873431206, 18.480399549007416, 39.04603600502014, 54.94475148618221, 53.04395288228989, 38.98418292403221, 32.09500439465046, 22.22727209329605, 23.03020130842924, 22.08894431591034, 17.139318510890007, 11.302151530981064, 4.408432245254517, 1.8665282428264618, 0.8993633498903364, 0.750090794172138, 5.80546148121357, 3.937030015513301, 3.954165196046233, 4.9927416164428, 7.5077316630631685, 5.5008256528526545, 10.601191744208336, 9.324812684208155, 12.77145478874445, 11.248856540769339, 10.621095076203346, 9.30781239643693, 6.402040394023061, 4.81008636765182, 3.7304360512644053, 1.381313398014754, 1.0337572102434933, 3.257266916334629, 4.386836104094982, 7.321483232080936, 15.587688870728016, 26.2328689545393, 38.66568401455879, 42.08878733217716, 46.16621933877468, 35.277219638228416, 35.72456203401089, 59.51605059206486, 62.04673379659653, 59.44787845015526, 67.55693212151527, 61.71134479343891, 54.28421773016453, 46.967273354530334, 42.6774213463068, 27.49291744083166, 13.974448386579752, 5.881233690306544, 3.6267619393765926, 2.202474628575146, 2.375629674643278, 6.1256579495966434, 6.470018271356821, 7.309449752792716, 6.00350352935493, 8.690091893076897, 12.484034411609173, 8.615272007882595, 8.721235021948814, 11.989546995609999, 12.313020788133144, 10.658810902386904, 5.987333497032523, 7.158837234601378, 3.228509109467268, 1.261580279096961, 1.4377673249691725, 4.082480510696769, 10.257833618670702, 15.323551744222641, 19.734811037778854, 21.91864125430584, 28.08843668550253, 26.19170006364584, 34.477985724806786, 39.2909936606884, 27.513937912881374, 9.259542636573315, 1.3925370457582176, 0.10968320741085336, 0.09308186854468659, 0.1337407555547543, 0.05631273706967477, 0.10816269525093958, 0.12734589166939259, 0.10601036308798939, 0.13298609526827931, 0.11742475762730464, 0.16310652979882434, 0.10358821571571752, 0.12387537164613605, 0.14208414300810546, 0.10348120544222184, 0.13426561723463237, 0.1923584140604362, 0.11818626793683507, 0.21258505526930094, 0.23415873904014006, 0.25890433229506016, 0.183326818223577, 0.19619092403445393, 0.2595061546890065, 0.11256912286626175, 0.12642513873288408, 0.11156075197504833, 0.11169877659995109, 0.1584176704636775, 0.2184474133537151, 0.21881493972614408, 0.15330375346820801, 0.07352281143539585, 0.10966492831357755, 0.13608804991235957, 0.049003012900357135, 0.10872441198443994, 0.2228916756575927, 0.11474358587292954, 0.13178874389268458, 0.1454834168544039, 0.11264134125667624, 0.16187058674404398], [0.05393000516050961, 0.029321145193534903, 0.06801473238738254, 0.027467195359349716, 0.03156528473482467, 0.025727274660312105, 0.08758408308494836, 0.048390496158390306, 0.0365391844388796, 0.019447452941676602, 0.04621563981345389, 0.005466819811772439, 0.025261988885176834, 0.018124437410733663, 0.0747744063846767, 0.03049012055271305, 0.08802128228126094, 0.02011145061260322, 0.02713290050451178, 0.0198748205366428, 0.05665209893777501, 0.03941110298910644, 0.008770289350650273, 0.050395066718920134, 0.04541605361737311, 0.05820903941639699, 0.04766259771713521, 0.05411420621385332, 0.022686200245516375, 0.04284154703782406, 0.01809000918001402, 0.03624486722401343, 0.03668429657409433, 0.04721746496215928, 0.03537635777320247, 0.017724386416375637, 0.050525476908660494, 0.03332258653244935, 0.03508489411615301, 0.038457164919236675, 0.033512732188683, 0.041004059894476086, 0.022376529850589577, 0.032904323234106414, 0.06320738917565905, 0.0353449018439278, 0.048034769934020005, 0.05661057948600501, 0.04560658519039862, 0.03940543298085686, 0.5185527121648192, 11.096251979470253, 25.388115383684635, 38.72279495000839, 38.94709311425686, 32.197009921073914, 24.028812423348427, 18.19376952946186, 27.429857924580574, 19.671390540897846, 17.84556571394205, 13.340405859053135, 5.655413707718253, 2.8898900421336293, 1.1258252011612058, 1.7328616278246045, 0.4549832217162475, 0.45722432958427817, 0.8705487241968513, 1.7803341429680586, 2.8510680003091693, 3.4648690139874816, 4.5657898765057325, 3.7853737408295274, 4.813595479354262, 3.51420936640352, 2.036936511285603, 3.139145029708743, 4.5101879350841045, 2.396790264174342, 0.9905910515226424, 0.8401924499776214, 1.3473832374438643, 1.0866006184369326, 1.1401626630686224, 2.2729902947321534, 5.665224781259894, 11.309351194649935, 14.362152982503176, 17.306102961301804, 21.71875488013029, 16.26535400748253, 33.30590821802616, 36.42166502773762, 40.04825882613659, 35.787167474627495, 25.40115248411894, 20.297387950122356, 17.235272862017155, 14.814472161233425, 7.026282772421837, 2.8835125593468547, 1.1936149885877967, 1.333410437218845, 1.4714072761125863, 3.4611314395442605, 2.8589072171598673, 2.566157625988126, 3.5580184031277895, 4.095829194411635, 2.087572831660509, 4.517616061493754, 1.5246924106031656, 2.357937111519277, 2.2163260728120804, 3.322365260683, 6.092165596783161, 2.0756013365462422, 0.5817446869332343, 0.4612869647098705, 0.8174327993765473, 2.4428046075627208, 13.349995594471693, 16.40790145844221, 17.05088395625353, 21.03278148919344, 22.66767416149378, 19.772926792502403, 23.998564146459103, 27.083037234842777, 19.918227195739746, 7.756237853318453, 1.4412683621048927, 0.03837104610283859, 0.1132975630753208, 0.03121489455224946, 0.025643167064117733, 0.07091581734130159, 0.12722343730274588, 0.049732321422197856, 0.043376487083151005, 0.06480625728727318, 0.04584175694617443, 0.024910374158935156, 0.0031045779041960486, 0.05048516715760343, 0.01674211129284231, 0.020789176160178613, 0.016731339019315783, 0.052918610017513856, 0.03890675427101087, 0.03308861705590971, 0.034354286835878156, 0.019910254377464298, 0.04086781642399728, 0.01641710812691599, 0.009814488348638406, 0.034117998147848994, 0.028064115867891815, 0.054315758679877035, 0.0215191340612364, 0.06113535368058365, 0.06251446073292755, 0.01353937856038101, 0.008359401144844014, 0.03714085469255224, 0.035315171408001333, 0.06196992842887994, 0.06742980869603343, 0.03660283102362882, 0.05189557057747152, 0.0525276837288402, 0.06653565433225594, 0.012253642962605227, 0.02275320133776404, 0.06643924934905954, 0.06387864690623246, 0.02145567301340634, 0.01462962596633588, 0.018492169729142915, 0.0664086506003514, 0.02497388530173339, 0.05348833081370685, 0.01993119964026846, 0.013284649357956368, 0.006309722384685301, 0.0369680344738299, 0.03823324412223883, 0.045386371421045624, 0.00999905212665908, 0.008354184774361784, 0.0005921663569097291, 0.024408882709394675, 0.0572968916821992, 0.04073383279319387, 0.09659774863393977, 0.061049004798405804, 0.03246213680540677, 0.03229779191315174, 0.025637278122303542, 0.09408632831764407, 0.08685988053912297, 0.07951129009597935, 0.06419915080186911, 0.013376248934946489, 0.0328726780571742, 0.05262886072159745, 0.04989404282241594, 0.029117123231117148, 0.060345326346578076, 0.0696897522720974, 0.05433677630207967, 0.02645505064720055, 0.033612847910262644, 0.08585108662373386, 0.022847663749416824, 0.04271546356903855, 0.04414924464072101, 0.007737319047009805, 0.04262223868863657, 0.024210337796830572, 0.06401670121704228, 0.04247523036610801, 0.11621576195466332, 0.013706939735129708, 0.13789581775199622, 1.7524209595285356, 15.017769802361727, 31.509632505476475, 45.95495447516441, 42.269520834088326, 34.11742307245731, 21.501326747238636, 12.90208037942648, 19.76339690387249, 19.459462612867355, 22.048886865377426, 15.979159064590931, 6.481575351208448, 2.50013783108443, 0.17137371352873743, 0.14102628570981324, 0.42470813845284283, 0.38204586831852794, 0.4972007079049945, 1.0173311666585505, 1.4923641015775502, 3.7628376251086593, 3.624807894229889, 5.35522174090147, 5.961383264511824, 5.777967106550932, 4.350313413888216, 6.0158647410571575, 5.2171053271740675, 4.731648601591587, 2.2750751953572035, 2.2203327203169465, 3.2449800381436944, 2.6497362786903977, 2.8155501186847687, 3.4896092489361763, 8.441776167601347, 15.283764079213142, 17.805550061166286, 23.92813302576542, 24.71070483326912, 20.651962123811245, 39.271249920129776, 44.386280849575996, 44.91919845342636, 41.62119582295418, 33.47460016608238, 28.468984365463257, 22.560481913387775, 19.69489987939596, 9.105730690062046, 4.3456463143229485, 2.043420863337815, 1.7096585291437805, 4.095718050375581, 2.58276819717139, 3.2382410997524858, 6.269515855237842, 5.364694157615304, 6.08914808370173, 5.315610766410828, 5.580710666254163, 3.849334283731878, 2.7543496526777744, 2.973761516623199, 2.9852316761389375, 2.5602743541821837, 0.7754638732876629, 0.3496796207036823, 0.2644776238594204, 1.3167352695018053, 3.407265767455101, 13.33833497017622, 18.480374850332737, 16.390435695648193, 19.484725557267666, 19.755151346325874, 20.305728502571583, 25.60986578464508, 29.733636304736137, 24.984303452074528, 10.470029432326555, 2.1120777167379856, 0.028588292916538194, 0.15635451476555318, 0.037476687648450024, 0.012780178185494151, 0.04872521589277312, 0.04078524136275519, 0.026172123543801717, 0.030547766873496585, 0.05468534080137033, 0.026078008086187765, 0.028554886994243134, 0.07521464096498676, 0.021561026442213915, 0.06344373352476396, 0.006316937915471499, 0.06669258145848289, 0.021143150916032027, 0.07747974246740341, 0.01696018582151737, 0.020973293721908703, 0.07914650224847719, 0.056077928966260515, 0.008884646886144765, 0.031691108451923355, 0.02904099557781592, 0.018858705334423576, 0.03533697199600283, 0.04874831152847037, 0.0344109794968972, 0.03451557036896702, 0.015159104732447304, 0.029526480757340323, 0.021479694478330202, 0.008308054730150616, 0.008478247746097622, 0.012351401437626919, 0.022947495599510148, 0.007752745514153503, 0.11252067546593025, 0.023259355330083054, 0.024821125334710814, 0.0411125915707089, 0.06754124216968194, 0.11490864693769254, 0.10910680357483216, 0.11910025248653255, 0.12836383626563475, 0.15507254371186718, 0.12023559742374346, 0.2562696486711502, 0.2069614757783711, 0.11350146814947948, 0.1309730642242357, 0.10692618816392496, 0.10608969125314616, 0.12494125898228958, 0.08062044464168139, 0.11820390878710896, 0.15334369585616514, 0.18544168677181005, 0.13033201190410182, 0.09164439528831281, 0.10476457173353992, 0.20955330779543146, 0.20286909537389874, 0.16426816902821884, 0.12304939838941209, 0.13798227795632556, 0.17475484928581864, 0.15120225842110813, 0.11048859349102713, 0.10589250261546113, 0.09406113982549869, 0.14504592079902068, 0.13125763332936913, 0.12551522115245461, 0.15635071496944875, 0.20377277891384438, 0.16791241097962484, 0.07793683864292689, 0.17278656974667683, 0.2825829101493582, 0.10535259018070064, 0.137103189190384, 0.16530637425603345, 0.08188145002350211, 0.1263909850968048, 0.14375499944435433, 0.12634445243747905, 0.17713597073452547, 0.22021927608875558, 0.1558876593480818, 0.37013891036622226, 1.7154237697832286, 15.640773922204971, 35.4391023516655, 53.820091634988785, 50.34021556377411, 44.753177762031555, 33.01623076200485, 26.109457276761532, 37.88261443376541, 28.53495642542839, 25.414432771503925, 18.26717209070921, 7.7374982088804245, 3.6867015855386853, 1.3255790574476123, 2.5203092861920595, 1.4836668432690203, 2.436728971078992, 3.7865880131721497, 4.570379555225372, 8.082216661423445, 10.371846500784159, 11.161143947392702, 11.631120778620243, 13.376364279538393, 8.22382366284728, 7.018184931948781, 8.369914423674345, 10.03312412649393, 6.528002684935927, 2.029173052869737, 3.3059325674548745, 3.511396092362702, 2.3473741533234715, 2.1666335267946124, 3.0972368409857154, 7.588924756273627, 14.022946134209633, 18.535314202308655, 24.606879204511642, 27.117653377354145, 24.804884679615498, 40.995057821273804, 43.92829902470112, 50.21668419241905, 42.743632793426514, 35.08699044585228, 30.962224379181862, 22.656128481030464, 18.37953396141529, 9.331194441765547, 4.077664269134402, 2.2733004530891776, 3.566502872854471, 6.397130582481623, 7.590669337660074, 6.779345897957683, 7.189516788348556, 10.476699024438858, 12.497979663312435, 7.6830594800412655, 11.496302112936974, 8.052628599107265, 7.4588449113070965, 9.20841732993722, 10.036616139113903, 11.646835785359144, 4.970603054389358, 1.3905356219038367, 1.0395942907780409, 1.2314476585015655, 3.0674051167443395, 16.555192954838276, 22.760011106729507, 23.83052196353674, 31.781747303903103, 33.12554329633713, 28.239079602062702, 32.87393219769001, 37.08530701696873, 27.217356227338314, 11.60749839618802, 2.113036927767098, 0.12659381405683234, 0.18195650191046298, 0.15082066092872992, 0.13245642447145656, 0.23895641206763685, 0.21603460219921544, 0.1956576612428762, 0.11026528125512414, 0.19768584694247693, 0.11457499960670248, 0.13413636479526758, 0.2039934491040185, 0.06248506426345557, 0.14064488117583096, 0.08220883362810127, 0.16490178502863273, 0.17940832301974297, 0.13160589354811236, 0.15517732012085617, 0.10182414553128183, 0.1251902643707581, 0.1520162311499007, 0.12293691848753951, 0.19220389891415834, 0.16777765180449933, 0.13381140801357105, 0.10102951317094266, 0.10640243970556185, 0.1779748944682069, 0.07609152555232868, 0.08420575264608487, 0.13349210639717057, 0.14919212175300345, 0.12361884830170311, 0.06839828914962709, 0.2290647116024047, 0.14795038994634524, 0.22336760011967272, 0.1667719823308289, 0.11850907249026932, 0.10048773052403703, 0.09533862088574097, 0.23948667658260092], [0.07142047033994459, 0.051860533785657026, 0.018934218860522378, 0.04548861339571886, 0.04949784357449971, 0.03622283285949379, 0.05927142752625514, 0.0821212305163499, 0.024031511748034973, 0.040013838224695064, 0.06129005065304227, 0.013652659981744364, 0.04928399001073558, 0.025289990117016714, 0.015855487872613594, 0.04568094838759862, 0.07838799763703719, 0.018820985678758007, 0.036846452130703256, 0.02448077455483144, 0.08944494416937232, 0.04476539419556502, 0.1167012749647256, 0.04477063746890053, 0.06549250640091486, 0.04350634437287226, 0.03655361921119038, 0.04959265665092971, 0.06500693401903845, 0.02045100543909939, 0.04268904682248831, 0.014937814848963171, 0.06664631597232074, 0.03799931917455979, 0.01601387331902515, 0.014519828000629786, 0.007729129447398009, 0.05578341137152165, 0.006682748535240535, 0.03268626911449246, 0.11026732216123492, 0.05007509716961067, 0.07942379830637947, 0.028001101964036934, 0.07272795643075369, 0.0411969589185901, 0.05454933852888644, 0.027893425613001455, 0.10953186865663156, 0.07421791437081993, 0.04496732886764221, 0.9215519623830914, 7.419137991964817, 21.66653048247099, 38.75573918223381, 36.8986002355814, 33.24166126549244, 29.024218171834946, 23.607230745255947, 23.379558362066746, 18.097402900457382, 15.458165220916271, 14.594011791050434, 7.533476706594229, 4.685966977849603, 1.3102499675005674, 0.2983566059265286, 0.15460392198292539, 0.19829241908155382, 0.9063130582217127, 1.9956923369318247, 1.7238223878666759, 3.5777331702411175, 4.8019106313586235, 3.1753988843411207, 5.5313014425337315, 2.556812264956534, 6.784798605367541, 4.7228036262094975, 3.898955346085131, 1.6396551229991019, 1.5151162119582295, 1.2505193101242185, 0.653677973896265, 0.8067893923725933, 0.500204327981919, 1.0058832122012973, 1.4380125305615366, 2.351195798255503, 5.675265267491341, 7.4942205380648375, 8.148098476231098, 13.012093026190996, 12.447231486439705, 17.778733000159264, 18.146946541965008, 12.702786773443222, 12.902271319180727, 3.6053930735215545, 1.9561262475326657, 0.7490885979495943, 0.33476025564596057, 1.2110836012288928, 0.7125159166753292, 3.0982625484466553, 0.6179471255745739, 2.604153687134385, 6.14555605687201, 2.3929717065766454, 4.3869980704039335, 2.196107357740402, 4.240838913246989, 1.0153694031760097, 2.412424525246024, 1.1303103854879737, 1.722587097901851, 3.0471643153578043, 2.2250202437862754, 1.006089944858104, 1.8051978712901473, 3.76661011017859, 8.641426004469395, 33.70807483792305, 28.009079843759537, 17.7295009419322, 18.414271697402, 21.4844461530447, 29.341086968779564, 28.65835290402174, 25.179985351860523, 9.594702702015638, 1.8958506756462157, 0.01257596512004966, 0.10771920264232904, 0.024174052341550123, 0.1068753213621676, 0.042246882658218965, 0.009929428470059065, 0.038605705776717514, 0.0520828329899814, 0.019703850121004507, 0.0224082177010132, 0.07972778941621073, 0.0553961141849868, 0.026895762057392858, 0.02619834918732522, 0.06440855519031174, 0.06360733255860396, 0.06779989547794685, 0.013323005405254662, 0.0366135921649402, 0.05582589561527129, 0.040470470557920635, 0.05377996516472194, 0.05040006508352235, 0.03595117341319565, 0.03738549625268206, 0.011043932972825132, 0.03151172764773946, 0.02957061442430131, 0.06508499311166815, 0.05060532086645253, 0.033558934592292644, 0.03575923547032289, 0.024070437393675093, 0.05991424615785945, 0.0065789777363534085, 0.07510172319598496, 0.047043357117217965, 0.033257318355026655, 0.015274939141818322, 0.03900012387020979, 0.07269268957315944, 0.03771387433516793, 0.02052952280791942, 0.05164936308574397, 0.046207405684981495, 0.008672709918755572, 0.06360685016261414, 0.01564122983836569, 0.051448530502966605, 0.094794433680363, 0.0654005617252551, 0.018655035892152227, 0.02060947252175538, 0.017683907826722134, 0.03412912294152193, 0.02812597573210951, 0.023137426032917574, 0.011253434768150328, 0.0277827120225993, 0.05801657083793543, 0.08674633194459602, 0.09723355396999978, 0.05912413718760945, 0.019803260802291334, 0.03521524493407924, 0.023879690597823355, 0.08407985471421853, 0.02179315168177709, 0.037963926151860505, 0.05386540120525751, 0.08020398105145432, 0.053237978427205235, 0.00829424336188822, 0.03863568483211566, 0.02857834999304032, 0.04697565469541587, 0.08924167734221555, 0.04688745044404641, 0.016767938031989615, 0.04070896342454944, 0.04378215242468286, 0.03149822798150126, 0.039481503117713146, 0.038827363023301587, 0.17110971675720066, 0.01643235740630189, 0.04466754573513754, 0.022769914503442124, 0.12641330889891833, 0.011437915982241975, 0.016683453795849346, 0.033274016677751206, 0.054983153531793505, 0.08928920447942801, 0.06612779965507798, 1.8716240068897605, 11.57950909808278, 28.031529039144516, 42.57810987532139, 41.07552990317345, 33.87602582573891, 24.656428545713425, 22.733946405351162, 20.665020123124123, 23.31965647637844, 25.735899321734905, 22.163426019251347, 11.89754918217659, 4.949158905074, 1.2200412643142045, 0.3180078451987356, 0.12810150190489367, 0.1776367868296802, 0.4457278089830652, 0.9045324975159019, 1.7191598005592823, 2.2150524286553264, 2.809318690560758, 3.779734130948782, 3.355452222749591, 4.836591370403767, 4.866539938375354, 6.3853540644049644, 4.81583783403039, 4.911701465025544, 4.521954003721476, 5.762693351134658, 3.500119959935546, 3.1313331238925457, 1.3815203681588173, 1.8895116657949984, 2.3219984024763107, 3.758727670647204, 7.104597995057702, 10.740145538002253, 10.577851496636868, 16.691064164042473, 15.971777960658073, 22.641784250736237, 20.242121815681458, 14.100014548748732, 15.018405318260193, 4.863919029012322, 2.350177690386772, 2.1129245962947607, 1.9405162101611495, 1.7766204359941185, 2.5323981000110507, 3.4729041578248143, 5.0539392326027155, 3.7956562265753746, 6.364394389092922, 5.83072442561388, 3.55487905908376, 4.961447920650244, 4.4003144558519125, 1.8639705050736666, 2.5527495704591274, 1.5420315926894546, 1.9060913636349142, 0.941619873046875, 0.7874132820870727, 0.8496623730752617, 2.376749189570546, 6.238445397466421, 9.59213213995099, 37.83634051680565, 27.69939076155424, 18.948302641510963, 20.64054563641548, 23.295504972338676, 29.29939940571785, 33.183809369802475, 28.15245945006609, 12.464222274720669, 2.8158902004361153, 0.06247456287383102, 0.037869376537855715, 0.04407197222462855, 0.05294937203871086, 0.02660991460288642, 0.027565233067434747, 0.043247787543805316, 0.02869306190405041, 0.0837860607134644, 0.036077301410841756, 0.06085495915613137, 0.06206420344824437, 0.06548826131620444, 0.04075762233696878, 0.04272091464372352, 0.011963350043515675, 0.060779119085054845, 0.049023325482266955, 0.08785200581769459, 0.023028372997941915, 0.05407693926827051, 0.022503541003970895, 0.04474424298678059, 0.0657850387506187, 0.06712360598612577, 0.04702694452134892, 0.013841159925505053, 0.07266497035743669, 0.03677211861941032, 0.02442330263875192, 0.016215206851484254, 0.09477148647420108, 0.00770601247495506, 0.01163779490525485, 0.037321857089409605, 0.03615537905716337, 0.005514383592526428, 0.0808850277098827, 0.019261906745668966, 0.018064444047922734, 0.061875304600107484, 0.0366278673755005, 0.02136146849807119, 0.05234311531239655, 0.22681680566165596, 0.11590098001761362, 0.14097623527050018, 0.13692105130758137, 0.12258776027010754, 0.1790181314572692, 0.14042376569705084, 0.2393942346679978, 0.14411068113986403, 0.11806483031250536, 0.164842190570198, 0.136597074160818, 0.09740675639477558, 0.16068368480773643, 0.16305239754728973, 0.13619076315080747, 0.1327875559218228, 0.2914631523890421, 0.17773758532712236, 0.14802862715441734, 0.17790928861359134, 0.18049366946797818, 0.18905532255303115, 0.13498683634679765, 0.2023324929177761, 0.24588931817561388, 0.11172038051881827, 0.20573351823259145, 0.13112812855979428, 0.06847828524769284, 0.34397544397506863, 0.11697297522914596, 0.2139501617057249, 0.08946257759816945, 0.0950115044543054, 0.1616590894991532, 0.11794750418630429, 0.13541130028897896, 0.12988843023777008, 0.10773288042400964, 0.32855435740202665, 0.0886349864595104, 0.15127035789191723, 0.1735529411234893, 0.13621189951663837, 0.0927774395677261, 0.08720226294826716, 0.24324140948010609, 0.20983357244404033, 0.18258959840750322, 0.2530655002919957, 1.7977766320109367, 12.911068797111511, 31.42189711332321, 50.06896711885929, 49.23027612268925, 42.58098632097244, 37.884419336915016, 33.91000360250473, 32.34541855752468, 26.73706579953432, 23.12637984752655, 21.37716270983219, 10.87386416271329, 6.456830129027367, 2.304809312336147, 0.7973378151655197, 0.2821261330973357, 0.7720659056212753, 2.364752283319831, 4.1203302796930075, 6.094074994325638, 9.058902952820063, 11.323939561843872, 10.33722085878253, 13.397263158112764, 10.598235502839088, 15.021795686334372, 13.622563518583775, 11.12763924524188, 5.177931804209948, 2.6138702407479286, 3.8675220077857375, 3.9021827979013324, 2.448979988694191, 1.4279309590347111, 2.5247472105547786, 2.0357307884842157, 3.711262042634189, 7.552649052813649, 10.840590298175812, 10.719087067991495, 16.119134053587914, 15.711346585303545, 21.400208473205566, 20.520587973296642, 15.843200460076332, 13.942126370966434, 4.592880522832274, 2.48670460190624, 1.2974514230154455, 1.393210559617728, 2.613720861263573, 4.246756145730615, 6.570971254259348, 5.261434698477387, 7.860235897824168, 12.247569300234318, 9.603332038968801, 10.35511314868927, 5.688052531331778, 10.455744098871946, 6.238835826516151, 9.460863433778286, 3.849424528889358, 4.01249966584146, 5.639909589663148, 3.4360534977167845, 1.4189128554426134, 2.4207781394943595, 5.578891988843679, 10.838205926120281, 41.673492416739464, 34.55819942057133, 25.028762966394424, 28.77233348786831, 29.713145904242992, 39.424400702118874, 39.598469361662865, 31.776245199143887, 12.701461594551802, 2.8264728700742126, 0.10976341131026857, 0.1345295991632156, 0.14961291948566213, 0.27600507717579603, 0.09548207803163677, 0.12014922627713531, 0.10579088033409789, 0.16776801872765645, 0.1896629633847624, 0.20692892518127337, 0.19154412962961942, 0.11352636720403098, 0.16984049580059946, 0.15155390283325687, 0.12534794106613845, 0.20957825880032033, 0.11384701952920295, 0.116857170505682, 0.1984306366648525, 0.10056751139927655, 0.1374095625942573, 0.19544839044101536, 0.11509310032124631, 0.2001923171337694, 0.1926020166138187, 0.09126272358116694, 0.1634219870902598, 0.29248033999465406, 0.18030716775683686, 0.16771317401435226, 0.1252507048775442, 0.17919753823662177, 0.0635648965544533, 0.07751745099085383, 0.1596699407673441, 0.16220571094891056, 0.11548454611329362, 0.15604897256707773, 0.12017694549285807, 0.11525897774845362, 0.21226608019787818, 0.186663024360314, 0.12850845116190612, 0.200804841297213], [0.03579006799554918, 0.023593486912432127, 0.03823527389613446, 0.07384364187601022, 0.062048555264482275, 0.023164471749623772, 0.018876596659538336, 0.01957298351044301, 0.011602256236074027, 0.03107827444182476, 0.08582012422266416, 0.07765278161969036, 0.03258109194575809, 0.021897208207519725, 0.03535400428518187, 0.054291074848151766, 0.09692675754195079, 0.028280032602197025, 0.04167252343904693, 0.015570497598673683, 0.031494598879362457, 0.06481125936261378, 0.07140755697037093, 0.010181241032114485, 0.012721259081445169, 0.029511361353797838, 0.01603305783646647, 0.06341445579892024, 0.0854073565278668, 0.048572786181466654, 0.04366149405541364, 0.039127394775277935, 0.04971698494045995, 0.026161503410548903, 0.02372174301854102, 0.039304656747845, 0.04233442639815621, 0.012610496323759435, 0.05752306118665729, 0.031527349856332876, 0.026024579019576777, 0.03209960137610324, 0.018220736637886148, 0.037101420675753616, 0.02416229857772123, 0.07571323803858832, 0.018019896633632015, 0.08073766686720774, 0.02536862994020339, 0.03591648914152756, 0.029647404444403946, 0.01870680440333672, 0.40318725106772035, 5.393065810203552, 18.989634923636913, 33.77048268914223, 39.988161250948906, 36.645279228687286, 24.52891878783703, 17.22859852015972, 16.34305413812399, 19.830030128359795, 19.83891025185585, 20.28021477162838, 13.486147988587618, 7.178829861804843, 3.3979106694459915, 0.9310461685527116, 0.4690456436946988, 0.26882660924457014, 0.40954241005238146, 1.1718207830563188, 0.7043506891932338, 2.2928701154887676, 2.9723149817436934, 2.699017971754074, 3.9681040355935693, 3.7484914949163795, 3.1375177670270205, 3.880354156717658, 6.6261376440525055, 5.560961700975895, 6.614992367103696, 4.227969003841281, 4.265474416315556, 0.8836614643223584, 1.6164472745731473, 1.2781090359203517, 0.3512691822834313, 0.3649819042766467, 0.7544014847371727, 0.7485359057318419, 2.229338474571705, 3.265549996867776, 4.547728970646858, 3.2314330525696278, 1.809861408546567, 3.458738042972982, 1.0956094600260258, 0.09609754852135666, 0.28286649961955845, 1.9434231729246676, 1.816450492478907, 1.7704736720770597, 2.651791493408382, 5.2816971112042665, 2.727045980282128, 5.163035653531551, 3.3784785121679306, 1.7679647379554808, 7.917133569717407, 2.6646452536806464, 1.4217214984819293, 1.4163484680466354, 1.351074620615691, 2.4296390265226364, 0.8991848782170564, 0.5363809398841113, 1.049403939396143, 3.968295925296843, 6.976078916341066, 21.97450775653124, 52.57620558142662, 24.79470882564783, 14.181858357042074, 21.0914883390069, 23.705056495964527, 33.29687610268593, 21.280550993978977, 8.741370141506195, 1.5102708782069385, 0.10169318615226075, 0.07731246980256401, 0.04897083708783612, 0.03438615094637498, 0.09112491417909041, 0.07953003674629144, 0.0038129798940644832, 0.04746071499539539, 0.034687737497733906, 0.022370204897015356, 0.042743186495499685, 0.010007687014876865, 0.03938697947887704, 0.060661481256829575, 0.022412713260564487, 0.030162952170940116, 0.01425040427420754, 0.01994874586671358, 0.05103890580357984, 0.04065735818585381, 0.01977337265998358, 0.032275534904329106, 0.021044723580416758, 0.0666636525420472, 0.06770017309463583, 0.04042923312226776, 0.019469375984044746, 0.009675170531409094, 0.040364399101235904, 0.04571517994918395, 0.036548071657307446, 0.059817763249157, 0.01986445644433843, 0.02986223393236287, 0.01845252605562564, 0.04043914821522776, 0.05527864705072716, 0.01418692560037016, 0.019587084316299297, 0.024220165687438566, 0.04441661076270975, 0.041558306911611, 0.07207638787804171, 0.03871237095154356, 0.059130920417374, 0.03147915849694982, 0.0027641705355563317, 0.02988516258483287, 0.03502070205286145, 0.050952111632796004, 0.023673572068219073, 0.03630911865911912, 0.031272574269678444, 0.046065161950537004, 0.021252176120469812, 0.02512703118554782, 0.018995804130099714, 0.06434150214772671, 0.026072067194036208, 0.0193458232388366, 0.03302649187389761, 0.04875875725701917, 0.012330855079198955, 0.031011661121738143, 0.010753328351711389, 0.05508159571036231, 0.061712488532066345, 0.023206738915177993, 0.048749777270131744, 0.03522735307342373, 0.053833511119592004, 0.04189649618638214, 0.011668885326798772, 0.019601600724854507, 0.08557909692171961, 0.04763362798257731, 0.036539611173793674, 0.02900204581237631, 0.06388781985151581, 0.018057926135952584, 0.039771345182089135, 0.03649150887213182, 0.02240506171801826, 0.020760731495101936, 0.053870340198045596, 0.06565540039446205, 0.011573243828024715, 0.02580124266387429, 0.035845328311552294, 0.038313147451845, 0.05489840026712045, 0.04685542306106072, 0.09719076173496433, 0.018891189138230402, 0.07269047055160627, 0.022923843353055418, 0.06330495933070779, 0.7601736125070602, 8.143424727022648, 25.05238439887762, 39.63282331824303, 42.970138639211655, 37.88109451532364, 24.99391883611679, 17.53372974693775, 12.980492021888494, 15.63705487176776, 20.51047671586275, 22.78673507273197, 16.256705671548843, 7.015090472996235, 2.4719566432759166, 0.7272395328618586, 0.3347868542186916, 0.12260450312169269, 0.22985866118688136, 0.4049256577854976, 0.34306658024434, 0.6867210008203983, 1.4612418715842068, 2.3881792137399316, 2.464448008686304, 3.302374533377588, 2.9579828632995486, 5.834726560860872, 5.30188400298357, 12.725481055676937, 12.245467063039541, 3.0791108636185527, 7.626309050247073, 3.436296209692955, 5.09108223952353, 1.4150839671492577, 1.312250322662294, 1.0408853902481496, 2.0810583187267184, 0.8935501368250698, 3.1287286011502147, 6.212859945371747, 6.847659107297659, 4.486328540369868, 3.1332641327753663, 5.491549400612712, 2.6398418471217155, 0.4257903975667432, 3.202700656838715, 3.954861033707857, 2.7752884291112423, 3.2960616471245885, 5.465346956625581, 3.4736064076423645, 5.7035628240555525, 6.155187590047717, 3.0215691262856126, 4.571162313222885, 4.728493820875883, 2.4340629391372204, 1.3049177848733962, 1.5782073140144348, 0.5774861841928214, 0.6493770203087479, 0.3511762950802222, 0.7521679170895368, 2.0578258903697133, 7.590163014829159, 10.558700524270535, 23.724391758441925, 54.697950929403305, 27.892731986939907, 13.102055098861456, 19.962815903127193, 24.822829216718674, 36.20282717049122, 25.460324808955193, 12.131102699786425, 2.45531068649143, 0.19574661506339908, 0.05200091844017152, 0.019164100958732888, 0.01160565712780226, 0.06925720634171739, 0.006985563804846606, 0.005735434133384842, 0.054900882751098834, 0.038995871364022605, 0.015452189982170239, 0.04581003013299778, 0.042127845881623216, 0.006732707597620902, 0.03226907079806551, 0.03986186864494812, 0.10717937926528975, 0.01978198157303268, 0.051790634606732056, 0.04177853923465591, 0.023938182966958266, 0.034896789366030134, 0.04886563023319468, 0.04252247919794172, 0.06591983503312804, 0.03238312776375096, 0.03205404835171066, 0.046866514458088204, 0.06460528369643725, 0.00981849780146149, 0.05865824656211771, 0.03899062437994871, 0.03980214059993159, 0.024303711106767878, 0.03812372910033446, 0.022140697583381552, 0.08413161209318787, 0.04825257543416228, 0.04428591484611388, 0.027024845658161212, 0.0775816616078373, 0.06145421000837814, 0.09924502650392242, 0.01640829512325581, 0.034857347927754745, 0.04400717902171891, 0.16381897672545165, 0.13777428364846855, 0.11076648326707073, 0.21793979918584228, 0.17671560344751924, 0.10814559616846964, 0.1381454910733737, 0.12816520786145702, 0.17101672565331683, 0.11215265927603468, 0.16334738640580326, 0.13039525772910565, 0.150515133573208, 0.136133766209241, 0.16412518685683608, 0.08717160482774489, 0.15772742859553546, 0.11350618820870295, 0.1604358371696435, 0.09224638837622479, 0.17460640490753576, 0.17478170018875971, 0.1761337893549353, 0.12962170236278325, 0.09070929663721472, 0.1207917183637619, 0.08685904933372512, 0.13712046638829634, 0.12271455620066263, 0.1351516376598738, 0.1305269295698963, 0.1264557894319296, 0.12616097868885845, 0.1633597505860962, 0.13383763551246375, 0.2368426715838723, 0.15019853337435052, 0.12206680970848538, 0.136029657733161, 0.15527623356319964, 0.24710123048862442, 0.08249208913184702, 0.09460053275688551, 0.14183843275532126, 0.10567592165898532, 0.26797667203936726, 0.10061732435133308, 0.18339565984206274, 0.07615814072778448, 0.14633736165706068, 0.12943246954819188, 0.11597268632613122, 0.7741052086930722, 8.9909758977592, 27.02761720865965, 45.60603819787502, 53.40088672935963, 47.73398861289024, 34.774472415447235, 26.176766864955425, 24.853835552930832, 28.311610110104084, 26.429869383573532, 27.720890007913113, 19.465741775929928, 8.842005841434002, 4.536139592528343, 1.3675932842306793, 1.326228347606957, 0.8106688654515892, 1.368858735077083, 3.3168747927993536, 3.2281343545764685, 6.164819123223424, 7.958325259387493, 8.394606448709965, 10.664795581251383, 11.173963509500027, 10.698850303888321, 11.615192033350468, 13.220065366476774, 13.102230839431286, 16.459971964359283, 11.698089335113764, 12.757619731128216, 3.3716749772429466, 3.582484102807939, 3.6310804076492786, 1.1578878806903958, 0.9962136810645461, 1.4052381017245352, 1.2782755144871771, 2.6597368670627475, 4.477276476100087, 6.414278112351894, 4.464527685195208, 4.052986968308687, 5.661864336580038, 1.7586723365820944, 0.2301365658058785, 1.7085539759136736, 3.934064987115562, 5.451888553798199, 4.419120121747255, 7.0504100527614355, 10.89466804638505, 7.4569502379745245, 13.448563255369663, 10.743472259491682, 8.644717577844858, 17.350087501108646, 8.56877675279975, 4.595919884741306, 3.921233550645411, 3.7813889421522617, 4.141864199191332, 1.5948527958244085, 0.9007505723275244, 2.140991552732885, 6.745252702385187, 10.052009113132954, 26.372059285640717, 63.393601924180984, 30.702700205147266, 21.690976470708847, 29.60198476910591, 33.33803929388523, 42.84939631819725, 29.119944535195827, 13.238636869937181, 2.3185087647289038, 0.30879515048582107, 0.16916854045121, 0.1173073350219056, 0.12934899277752265, 0.1322178091504611, 0.1331928576109931, 0.051424878256511874, 0.16160359169589356, 0.08469544394756667, 0.1266486884560436, 0.07196703983936459, 0.15678543539252132, 0.10614824670483358, 0.1731946025392972, 0.09939951938576996, 0.21851122321095318, 0.08162969868863001, 0.09473758516833186, 0.1413116860203445, 0.13215830374974757, 0.1495944696944207, 0.18218684970634058, 0.0766173074953258, 0.17328377900412306, 0.15555980819044635, 0.1064746655174531, 0.17382769903633744, 0.12412897092872299, 0.19778293470153585, 0.10219852192676626, 0.07392773462925106, 0.1014581776689738, 0.13733324012719095, 0.1877205105847679, 0.08581034271628596, 0.15262949746102095, 0.13522724766517058, 0.10908844284131192, 0.10302186055923812, 0.18552266992628574, 0.1603265039739199, 0.20270145905669779, 0.1191170621314086, 0.1578211470041424, 0.19771726947510615], [0.019799281035375316, 0.058259308789274655, 0.020522331396932714, 0.04371452050691005, 0.03413669655856211, 0.009662499287514947, 0.0278569861620781, 0.07690979531616904, 0.027006054478988517, 0.02004689860768849, 0.022164281181176193, 0.026572977913019713, 0.038062583553255536, 0.065932325378526, 0.030261002866609488, 0.038201817878871225, 0.005176012027732213, 0.04421847217599861, 0.032796370433061384, 0.0636592235241551, 0.001933350474701001, 0.017988798790611327, 0.0577916073234519, 0.010935421705653425, 0.08134599047480151, 0.016506520223629195, 0.056535834082751535, 0.025477766466792673, 0.038840799606987275, 0.03613238732214086, 0.025210864187101834, 0.011929108277399791, 0.02040333543845918, 0.07442714064382017, 0.06818970854510553, 0.035270635125925764, 0.07412218474200927, 0.027460812889330555, 0.03824989791610278, 0.04356402037956286, 0.03551992624124978, 0.008400048573093954, 0.05502005682501476, 0.038084491752670147, 0.07422739901812747, 0.01522815044154413, 0.05818504207127262, 0.08126011656713672, 0.052866025143885054, 0.03375631247763522, 0.0193143079377478, 0.06888469273690134, 0.07770007869112305, 0.5487641191575676, 3.9222027361392975, 14.615548085421324, 33.209055215120316, 42.74245485663414, 38.44338834285736, 29.051681198179722, 24.90648552775383, 26.509921588003635, 31.458449251949787, 27.27281805127859, 21.044232174754143, 16.156212463974953, 11.890793144702911, 5.1986150443553925, 2.1187658328562975, 0.5620073585305363, 0.12428900023223832, 0.18308180558960885, 0.6380694801919162, 0.44533803302329034, 0.8288311189971864, 0.5902068922296166, 1.9939083326607943, 1.6159426141530275, 2.724757553078234, 2.565609742887318, 4.560929937288165, 16.132501736283302, 13.376885801553726, 1.1902630934491754, 4.947812827304006, 4.313525687903166, 3.994331890717149, 1.8346607778221369, 0.9132434113416821, 1.2033398542553186, 0.21019566629547626, 0.1832105385256, 0.5681534099858254, 1.4835758856497705, 1.0608192393556237, 0.3851115022553131, 0.10045213712146506, 1.3304870878346264, 0.6834953301586211, 0.7391649554483593, 4.71684412099421, 4.398302938789129, 1.3382661016657948, 3.4577170852571726, 2.5654919492080808, 2.980866185389459, 4.549351008608937, 3.252912349998951, 3.1922110822051764, 1.794243415351957, 2.571540749631822, 2.3061352036893368, 0.6446371308993548, 1.0105298878625035, 0.9372943395283073, 1.2657911656424403, 1.4578691963106394, 5.750800464302301, 9.371011555194855, 15.671871453523636, 15.132330805063248, 35.04877209663391, 52.36907869577408, 14.56779794767499, 22.332551144063473, 28.43568105250597, 34.74908597767353, 26.100077480077744, 8.949166741222143, 1.507953240070492, 0.05689537865691818, 0.043397144763730466, 0.030707727528351825, 0.03586166298191529, 0.04862387191678863, 0.05311504537530709, 0.04395608957565855, 0.05477720013004728, 0.008523159740434494, 0.05657927198626567, 0.023650359544262756, 0.017452626780141145, 0.007095449900589301, 0.027372519580239896, 0.03613849148678128, 0.07737017920590006, 0.008174088725354522, 0.03055542583751958, 0.060709668905474246, 0.031073875361471437, 0.027788823608716484, 0.021070563307148404, 0.015136138044908876, 0.020786623172170948, 0.0059923508160864, 0.01962615096999798, 0.015748366276966408, 0.029402668260445353, 0.025531612991471775, 0.019899459839507472, 0.01681055215158267, 0.03318895542179234, 0.09293620722019114, 0.06556116990395822, 0.026132194143428933, 0.06548859528265893, 0.04174761394097004, 0.025722031386976596, 0.14146044210065156, 0.030767390635446645, 0.045124623356969096, 0.16235160233918577, 0.04460313473828137, 0.023490983330702875, 0.06865235598525032, 0.04599561158102006, 0.05931214174779598, 0.054243703561951406, 0.02358130455831997, 0.02317022896022536, 0.04632663170923479, 0.04685457330197096, 0.04566768249787856, 0.0193558051250875, 0.008375103134312667, 0.015736176501377486, 0.10384018227341585, 0.030597848854085896, 0.009374310357088689, 0.05018697222112678, 0.050869911356130615, 0.043752477649832144, 0.05785208864836022, 0.046524458593921736, 0.009615685539756669, 0.008972643336164765, 0.027927397422899958, 0.04825129894015845, 0.07581598096294329, 0.027970454975729808, 0.03897666458215099, 0.0498578000406269, 0.06981623650062829, 0.020733542914967984, 0.019257006715633906, 0.05546318207052536, 0.01658508954278659, 0.006732617612215108, 0.02948992627352709, 0.029747618500550743, 0.0634869933128357, 0.036011302217957564, 0.06786962767364457, 0.0358214459993178, 0.004773500349983806, 0.03850356399198063, 0.040386010441579856, 0.051944307415396906, 0.02092559774609981, 0.017681636854831595, 0.07117517568985932, 0.05476769321830943, 0.015527532814303413, 0.03938844150980003, 0.04585163122101221, 0.05862481652002316, 0.012016682630928699, 0.045259486432769336, 0.07306463914574124, 0.9136334841605276, 5.307813109830022, 19.50369603931904, 39.26762491464615, 49.19236555695534, 42.358128279447556, 28.819365464150906, 20.645006597042084, 22.762916050851345, 28.891396299004555, 32.85842902958393, 31.202572882175446, 23.168367594480515, 16.067711412906647, 6.776378732174635, 1.6747679701074958, 0.5862488108687103, 0.06965920547372662, 0.2134178191772662, 0.11868913235957734, 0.2575643401360139, 0.27960764011368155, 0.6278462475165725, 0.4397483845241368, 1.886008728761226, 2.024740590713918, 3.503360948525369, 5.4631411749869585, 14.617232345044613, 8.95045867189765, 3.8815848156809807, 4.6077837981283665, 4.849637020379305, 6.866067694500089, 3.393319803290069, 2.222487679682672, 3.1356527796015143, 1.1027129413560033, 1.1429903050884604, 1.2171293143182993, 2.8437878284603357, 2.4539964320138097, 0.9019331401214004, 0.43046447332017124, 2.4483380606397986, 2.2410057485103607, 2.4889148958027363, 6.448180368170142, 6.560200732201338, 3.389486758969724, 5.263424841687083, 8.166450541466475, 4.603241141885519, 5.007701888680458, 3.692428353242576, 2.18487611040473, 2.279450660571456, 2.1889423672109842, 0.5809415050316602, 0.6878763169515878, 0.4846022167475894, 0.3970375779317692, 0.9000651841051877, 1.7868029396049678, 6.7591457068920135, 11.248422414064407, 18.684942573308945, 16.490680016577244, 29.668555296957493, 58.20781499147415, 17.422504015266895, 22.1683581545949, 30.08209850639105, 37.80965834856033, 31.212630942463875, 11.999571807682514, 2.380199641920626, 0.14396973245311528, 0.02909536717197625, 0.03384082825505175, 0.043321037519490346, 0.04518873378401622, 0.05456414808577392, 0.018773987321765162, 0.03196804456820246, 0.02976089181174757, 0.03236498225305695, 0.040265307543450035, 0.015512984864471946, 0.05694038249203004, 0.08011714977328666, 0.05835028125147801, 0.015052997096063336, 0.0552722423162777, 0.07130682526621968, 0.039803257532184944, 0.019898487626051065, 0.04327062713855412, 0.03827947992249392, 0.01388764434523182, 0.03900395335222129, 0.06386680965078995, 0.040699066885281354, 0.10824401979334652, 0.06032446457538754, 0.1278048357926309, 0.005365706365410006, 0.034847273273044266, 0.0365684658754617, 0.0355196553573478, 0.0626339390873909, 0.03187569913279731, 0.03089633693889482, 0.03132760823064018, 0.028515224767033942, 0.07227833368233405, 0.03261249221395701, 0.07497555809095502, 0.058293232359574176, 0.040855971747078, 0.017231548408744857, 0.03514571682899259, 0.020941346119798254, 0.1483941645710729, 0.2092582150362432, 0.15838258172152564, 0.12954386591445655, 0.1261947612510994, 0.17906567343743518, 0.11674285007757135, 0.16978234110865742, 0.12664074747590348, 0.09891558715025894, 0.23028753348626196, 0.06755287162377499, 0.09896712930640206, 0.24329712992766872, 0.12197004107292742, 0.15432172775035724, 0.17486905097030103, 0.15856394777074456, 0.11426974684582092, 0.14556481561157852, 0.13479742541676387, 0.16919065645197406, 0.18276550224982202, 0.09142447466729209, 0.12333467995631509, 0.13435264147119597, 0.1716395211406052, 0.08811004314338788, 0.10484005557373166, 0.1294169289758429, 0.15500563167734072, 0.15244085836457089, 0.10899583023274317, 0.14057976513868198, 0.2321091794874519, 0.09748975819093175, 0.11603874489082955, 0.18744119588518515, 0.13207987358327955, 0.17672771529760212, 0.11212190467631444, 0.16200148675125092, 0.12879779969807714, 0.10107147420058027, 0.2020326058845967, 0.13256177975563332, 0.1545120737864636, 0.23841192800318822, 0.11432638013502583, 0.18431929231155664, 0.12623191316379234, 0.20867257146164775, 0.14031533792149276, 0.8556874247733504, 5.8289917185902596, 21.733110509812832, 45.8309481292963, 54.97260399162769, 51.521332785487175, 41.579827442765236, 34.30142059922218, 37.74817384779453, 42.78976991772652, 38.52898254990578, 31.07790157198906, 25.267074778676033, 15.891815051436424, 7.246097177267075, 2.8461952367797494, 0.9404906211420894, 0.5470269592478871, 0.5612872971687466, 1.2780377897433937, 1.375060121063143, 2.349607483483851, 3.912503281608224, 5.189249971881509, 5.688349390402436, 6.990811200812459, 8.612907584756613, 13.089716210961342, 27.71201368421316, 26.535944491624832, 7.605006918311119, 14.462343156337738, 8.820654787123203, 8.424202110618353, 3.450675350613892, 2.6889765355736017, 3.035112787038088, 1.1253889370709658, 0.8224980463273823, 1.4723563939332962, 2.8564397245645523, 1.454757519531995, 1.9037420209497213, 0.6990617292467505, 2.3254564544185996, 1.4792176382616162, 2.767015560530126, 10.419934820383787, 11.262872088700533, 6.452726349234581, 11.00587097927928, 10.151367131620646, 7.752364911139011, 11.76120774820447, 10.609575044363737, 8.967658448964357, 7.576964423060417, 6.057959832251072, 7.2118928376585245, 2.741071740165353, 2.643040562979877, 1.6200308385305107, 1.7623646697029471, 2.4381242087110877, 8.109791781753302, 12.13571660220623, 22.22932018339634, 22.42081470787525, 42.22192458808422, 64.53984841704369, 20.7875844463706, 31.73205927014351, 38.79226662218571, 43.65192085504532, 35.13147085905075, 13.978123739361763, 2.587779415771365, 0.20226046006428078, 0.09737157117342576, 0.07801537271006964, 0.10582634757156484, 0.20745237678056583, 0.18500137055525556, 0.12647383846342564, 0.15854235127335414, 0.10706131099141203, 0.1332059342530556, 0.1339386121253483, 0.15875156270340085, 0.12048537464579567, 0.10131639035535045, 0.08206905011320487, 0.25185885722748935, 0.11261734020081349, 0.21766293357359245, 0.07737073581665754, 0.05673935324011836, 0.22009492182405666, 0.06319402309600264, 0.07892586916568689, 0.08914867139537819, 0.10581749374978244, 0.14599803689634427, 0.2798019937472418, 0.1713069944526069, 0.276985751115717, 0.0697230598598253, 0.09362071970826946, 0.10524729426833801, 0.09193190329824574, 0.11838598729809746, 0.08206481244997121, 0.14378674852196127, 0.08806236015516333, 0.11174493818543851, 0.25446287530940026, 0.16807819192763418, 0.11934819660382345, 0.32845642359461635, 0.16098507097922266, 0.07290412002475932, 0.19399854558287188, 0.1480693116900511], [0.021096174823469482, 0.04532841710897628, 0.06374033284373581, 0.018109796692442615, 0.045333055531955324, 0.03871834524034057, 0.025097896323131863, 0.04911291012831498, 0.03351745966938324, 0.023745296930428594, 0.046990649789222516, 0.030150339371175505, 0.047900916179060005, 0.028205624876136426, 0.04596233367919922, 0.0633278397435788, 0.038002187575330026, 0.05683424053131603, 0.0220053947850829, 0.03345049939525779, 0.0465772735333303, 0.07639741656021215, 0.050432983043720014, 0.042005180002888665, 0.03819515339273494, 0.03363216601428576, 0.023335087789746467, 0.03124806855339557, 0.038032411539461464, 0.030098908537183888, 0.019296232931083068, 0.02945375585113652, 0.055082957551348954, 0.02330324779904913, 0.041068541395361535, 0.06675371958408505, 0.010558833710092586, 0.0623402489873115, 0.0014163048854243243, 0.04560390974802431, 0.0427656253305031, 0.07320540971704759, 0.011640592801995808, 0.06775220506824553, 0.0463007344660582, 0.06739455668139271, 0.02417583720671246, 0.07649656006833538, 0.07103996380465105, 0.04043147811898962, 0.03713311038154643, 0.038564601927646436, 0.034948030952364206, 0.04471355518035125, 0.40314515645150095, 3.602098887786269, 11.772495992481709, 30.594949387013912, 35.96282444894314, 37.35612988471985, 33.96306775510311, 22.569175846874714, 21.82297758758068, 11.121312584728003, 15.777587480843067, 23.040973730385303, 17.880103960633278, 15.784812793135643, 10.44156800955534, 4.680056869983673, 1.566816356498748, 1.2934629432857037, 0.4603380843764171, 0.11019524477887899, 0.29614910250529647, 0.4219690791796893, 0.42055724712554365, 1.1557041853666306, 1.1456303321756423, 4.714503446593881, 2.580895135179162, 14.01668881997466, 5.592149002477527, 1.896320900414139, 3.73709115665406, 5.22708929143846, 11.934951525181532, 1.9247539434581995, 1.580656401347369, 2.435563621111214, 1.7894199304282665, 2.1582390647381544, 1.6067535197362304, 3.161724368110299, 5.565417911857367, 0.9438435849733651, 1.3095966400578618, 1.00834334269166, 3.686765944585204, 3.4006175491958857, 5.948067829012871, 6.043086005374789, 1.7917142948135734, 2.552163451910019, 8.598471209406853, 1.5116779902018607, 4.206945206969976, 3.7357845017686486, 0.8482286031357944, 2.0453668339177966, 1.0577759589068592, 0.4345893894787878, 0.7763057062402368, 1.091793158557266, 1.332853410858661, 3.2552998093888164, 5.781725579872727, 7.715957164764404, 10.530466139316559, 14.031461477279663, 19.13686752319336, 46.439230889081955, 33.52957561612129, 21.45591538399458, 27.03571457415819, 30.424158051609993, 25.60790129005909, 12.066151835024357, 2.6701958058401942, 0.1596314529888332, 0.011555269938980928, 0.03565821061783936, 0.01439365547412308, 0.08149625311489217, 0.0520239398611011, 0.036951696092728525, 0.04290902681532316, 0.0286798071465455, 0.07586702588014305, 0.014168123288982315, 0.06589806784177199, 0.0447661066573346, 0.05562196827668231, 0.03317510323540773, 0.017092462512664497, 0.02672052800335223, 0.04997200914658606, 0.03266203057137318, 0.018476918594387826, 0.021808443634654395, 0.04189855193544645, 0.024983132461784407, 0.027218800387345254, 0.03560888006177265, 0.029107983682479244, 0.06219340764801018, 0.06516124136396684, 0.011712056057149312, 0.004997904470656067, 0.03710795157530811, 0.029500884083972778, 0.003329607284285885, 0.06750438711605966, 0.06391060378518887, 0.05132086625962984, 0.03185743116773665, 0.10528579688980244, 0.05128224118379876, 0.08496121445205063, 0.05468569332151674, 0.06497613489045762, 0.05155755570740439, 0.01902407624584157, 0.026873234164668247, 0.033532792440382764, 0.043796705940621905, 0.03245359468564857, 0.07650716535863467, 0.036929008638253435, 0.03604776393331122, 0.04482735981582664, 0.08303442096803337, 0.05553037241043057, 0.006400382681022165, 0.052973829515394755, 0.10461570433108136, 0.028312119356996845, 0.041435607636231, 0.005746504657508922, 0.04516612796578556, 0.08636826707515866, 0.032036021584644914, 0.0738332666514907, 0.031223703845171258, 0.020368818150018342, 0.054818270582472906, 0.0446676867431961, 0.05000387696782127, 0.034077755190082826, 0.0802519905846566, 0.021231767059362028, 0.04122594720683992, 0.025728929649631027, 0.013192598926252685, 0.058093861807719804, 0.016313589658238925, 0.020808364388358314, 0.06965794382267632, 0.034893657502834685, 0.03722502908203751, 0.02525366569898324, 0.014883052699588006, 0.044119035519543104, 0.07817128309397958, 0.02623443797347136, 0.015606979723088443, 0.053915462776785716, 0.07803238273481838, 0.0411318911210401, 0.04925999637634959, 0.04075312121130992, 0.08253943815361708, 0.09182495981804095, 0.11507550399983302, 0.055822559661464766, 0.028552465737448074, 0.012639579235838028, 0.055625990717089735, 0.018827791172952857, 0.010878213251999114, 0.6485396402422339, 5.5376029293984175, 17.043804936110973, 35.68076938390732, 40.57691305875778, 42.139776796102524, 36.86089865863323, 26.19045563042164, 24.239853098988533, 15.340157803148031, 18.343162313103676, 30.896062329411507, 23.47911112010479, 18.779886178672314, 11.382895298302174, 3.943361663259566, 1.8684638827107847, 0.6873940397053957, 0.28824971232097596, 0.10051461853436194, 0.1579568412853405, 0.1570590800838545, 0.23472827801015228, 0.6491992610972375, 0.7308185251895338, 1.6423101117834449, 2.892861245200038, 4.9696421809494495, 2.2309711994603276, 3.611152614466846, 2.6288708858191967, 4.304138766601682, 5.415551578626037, 3.3344357879832387, 3.6841471726074815, 5.212623467668891, 2.4100838508456945, 2.5100883096456528, 2.4500009464100003, 2.3833261616528034, 3.241016138345003, 2.3988811019808054, 2.0188627811148763, 2.452614256180823, 6.843240894377232, 3.716514310799539, 8.77010514959693, 7.411711290478706, 3.715892331674695, 4.7755685448646545, 4.078167742118239, 3.9426484890282154, 2.3024479765444994, 2.6432220032438636, 1.31627406924963, 0.5159376806113869, 0.46441645303275436, 0.1487392038688995, 0.16781398735474795, 0.7651473674923182, 1.8159838300198317, 3.984269080683589, 8.831876534968615, 13.185976445674896, 17.13479485362768, 17.338629215955734, 14.720383509993553, 43.18220905959606, 40.49144804477692, 23.155786469578743, 28.926626108586788, 35.11955849826336, 29.468659423291683, 13.99985857307911, 3.037960259243846, 0.12185242550913244, 0.08641724140034057, 0.04997076604922768, 0.015057450909807812, 0.09897468436975032, 0.03219354242901318, 0.023612452496308833, 0.06168927044200245, 0.046748015738558024, 0.033237258103326894, 0.01684888222371228, 0.04519231464655604, 0.06879297070554458, 0.032707275604479946, 0.04833525810681749, 0.014113125507719815, 0.04651465111237485, 0.07008050044532865, 0.03858294781821314, 0.03318412404041737, 0.11897783522726968, 0.027841295304824598, 0.024786480025795754, 0.07772791665047407, 0.07737676947726868, 0.047427563258679584, 0.030755623884033412, 0.03797331803070847, 0.036459511175053194, 0.031014889464131556, 0.05763865068729501, 0.10546809062361717, 0.08221465948736295, 0.005190316924199578, 0.03548895641870331, 0.04908244496618863, 0.04572044548694976, 0.04044046552735381, 0.04742009725305252, 0.12732667004456744, 0.00019153940087335286, 0.0823232727998402, 0.026383798904134892, 0.013203085472923703, 0.011827862635982456, 0.04473206434340682, 0.07658669390366413, 0.11825128007330932, 0.17131861648522317, 0.110466225160053, 0.08359441591892391, 0.12614114850293845, 0.19494214182486758, 0.12963102373760194, 0.17738568858476356, 0.13289740862092003, 0.16503556456882507, 0.08028852651477791, 0.10284232761478052, 0.194891631253995, 0.18330217892071232, 0.18696604325668886, 0.15466120094060898, 0.16602789022726938, 0.1753199502127245, 0.13844315166352317, 0.19498223264236003, 0.13057490199571475, 0.11968936189077795, 0.1527443077065982, 0.1929669306264259, 0.1382114680018276, 0.17219801695318893, 0.21325747075024992, 0.1534651409019716, 0.19456327543593943, 0.07602938552736305, 0.10545096927671693, 0.1920950406929478, 0.11651824650471099, 0.15961377503117546, 0.1572198886424303, 0.10976290664984845, 0.11755175393773243, 0.15111392800463364, 0.0513829765986884, 0.10694272321416065, 0.19061469356529415, 0.22433596925111488, 0.10261146031552926, 0.1610043371329084, 0.09240108905942179, 0.1898102945415303, 0.2089573780540377, 0.23277423286344856, 0.31449739763047546, 0.10785664097056724, 0.12677463091677055, 0.15092245390405878, 0.09128660589340143, 0.23474046407500282, 0.6469143368303776, 5.497414385899901, 18.731881454586983, 40.053555741906166, 48.535160422325134, 50.14433607459068, 47.229014709591866, 33.22783760726452, 32.92461767792702, 18.943100720643997, 23.4933964535594, 35.77772878110409, 25.820281393826008, 21.763303689658642, 14.424153305590153, 6.182772684842348, 2.747520231641829, 1.6336672380566597, 1.0591848520562053, 0.4211370722623542, 1.212981480639428, 1.146996240131557, 1.1296848440542817, 4.354394869878888, 3.479113024659455, 8.25313813984394, 6.784488447010517, 21.248454116284847, 15.400983989238739, 4.903189446777105, 9.43608496338129, 15.88199257850647, 22.579912170767784, 9.32164080440998, 9.89770034328103, 7.068833839148283, 5.972595037892461, 3.15644811373204, 3.575956765562296, 5.2228430192917585, 9.832115862518549, 4.711891086772084, 3.749389909207821, 3.6040059104561806, 10.973501466214657, 12.369070630520582, 19.09281648695469, 16.81647263467312, 6.814147280529141, 10.633068233728409, 16.72256637364626, 8.209286592900753, 10.81748278811574, 10.63816661015153, 4.612123165279627, 4.964363314211369, 3.7465490866452456, 1.296398404520005, 1.865313732996583, 2.024805899709463, 2.3345441417768598, 4.469984667375684, 8.532884828746319, 11.528811268508434, 17.478343918919563, 19.966537803411484, 26.930446922779083, 55.96453316509724, 44.22612704336643, 28.914010785520077, 38.53925719857216, 41.76224425435066, 34.34305876493454, 16.112121529877186, 3.6102608498185873, 0.291832237271592, 0.14048686309251934, 0.13234091660706326, 0.20696061488706619, 0.19468173704808578, 0.1647219478036277, 0.11794572303188033, 0.16071899619419128, 0.18266514904098585, 0.13476172811351717, 0.13316796597791836, 0.10960344880004413, 0.16404417401645333, 0.10441591817652807, 0.2076465671416372, 0.11611538648139685, 0.07353418113780208, 0.23520325252320617, 0.13354249822441489, 0.10920032160356641, 0.2215972513658926, 0.1380127653828822, 0.194802618061658, 0.11002798695699312, 0.18033476080745459, 0.142674105882179, 0.10290897989762016, 0.11161906993947923, 0.06857778498670086, 0.11464440525742248, 0.12553497712360695, 0.1482893733191304, 0.10546182689722627, 0.18586658115964383, 0.16144683526363224, 0.2021959822741337, 0.09667795995483175, 0.17235271021490917, 0.1691964452038519, 0.23701243044342846, 0.153653483139351, 0.175001984462142, 0.18205369357019663, 0.15433339431183413, 0.07435642881318927, 0.2088343893410638, 0.17781433823984116], [0.0355005784513196, 0.04558817992801778, 0.03625690485932864, 0.058532408002065495, 0.04588963660353329, 0.08003903873031959, 0.04373335621494334, 0.0283714651959599, 0.054124755843076855, 0.02131431614543544, 0.007865905408834806, 0.039273033835343085, 0.058704155817395076, 0.05262132050120272, 0.02005596579692792, 0.08135319672874175, 0.027716358454199508, 0.011825742876681034, 0.03583341313060373, 0.02401968933554599, 0.020125996707065497, 0.027197890376555733, 0.010810008952830685, 0.07143182519939728, 0.04358287464128807, 0.03535929208737798, 0.03781435370910913, 0.02847422110789921, 0.04728268118924461, 0.04543802861007862, 0.017237155334441923, 0.023228097925311886, 0.035299612281960435, 0.09469241806073114, 0.047836204612394795, 0.03814966345089488, 0.002238199344901659, 0.04622429325536359, 0.052884961041854694, 0.11057488300139084, 0.02409999713563593, 0.04159602656727657, 0.03158679959597066, 0.0662495192955248, 0.019229345016356092, 0.08388148606172763, 0.05671647653798573, 0.0010800572545122122, 0.030020138838153798, 0.008856267158989795, 0.07600720273330808, 0.10761404773802496, 0.040793204607325606, 0.02003167159273289, 0.029070559030515142, 0.38786115939728916, 1.7587326583452523, 13.251903858035803, 24.87870901823044, 36.20142124593258, 43.97780276834965, 42.554543539881706, 29.241057336330414, 20.075770542025566, 28.476150780916214, 25.19320484250784, 27.54530142992735, 25.790865272283554, 17.901263125240803, 15.623797383159399, 9.34806078672409, 5.8599871303886175, 3.8603845657780766, 1.5835156291723251, 0.6750936841126531, 0.6533651438076049, 0.24114065658068284, 0.39324837969616055, 0.7601374550722539, 0.9161690762266517, 3.463661866262555, 4.843695089221001, 1.5391363855451345, 4.205519808456302, 1.6593739273957908, 2.3328826809301972, 2.825869177468121, 3.1936863530427217, 2.24117673933506, 5.561968171969056, 1.9238790404051542, 1.9786967989057302, 1.3529343833215535, 2.2570366133004427, 3.0425841361284256, 0.6387407972943038, 1.4076529908925295, 2.5723308697342873, 3.7874641036614776, 3.131663231179118, 4.259426090866327, 3.909460832364857, 3.43095060903579, 4.2027592565864325, 5.5147994030267, 3.374206116423011, 0.9727610426489264, 1.030484635848552, 1.0207513393834233, 0.5616432311944664, 1.0808214847929776, 0.6978069653268903, 1.9555968884378672, 3.269203738309443, 5.54528184235096, 10.051147509366274, 13.584628254175186, 16.102656237781048, 21.24975934624672, 19.45207390934229, 21.39276847243309, 32.27457515895367, 33.81060853600502, 24.30707149207592, 36.243899166584015, 24.1878167912364, 12.277458496391773, 2.7549409959465265, 0.1064274797681719, 0.017787819633667823, 0.05592172914475668, 0.028051048502675258, 0.026903014695562888, 0.03224882129870821, 0.018892085281549953, 0.010537127745919861, 0.03316617519885767, 0.025129402347374707, 0.10219190196949057, 0.01694859347480815, 0.0948824969236739, 0.06921370164491236, 0.033163848565891385, 0.04570083423459437, 0.022788666719861794, 0.008147833395923954, 0.031000553026387934, 0.022502392530441284, 0.024619270443508867, 0.020490888455242384, 0.019018239254364744, 0.053898957412457094, 0.04419652686920017, 0.037593386659864336, 0.04147343490330968, 0.024505553010385484, 0.016626991200610064, 0.03750680400116835, 0.033822385885287076, 0.01139862853960949, 0.029685120389331132, 0.08047513212659396, 0.016923596085689496, 0.08907727678888477, 0.03727533185156062, 0.029634834318130743, 0.0290981223952258, 0.05155936654773541, 0.08851891456288286, 0.04841887959628366, 0.06258453431655653, 0.058106188880628906, 0.031096460770640988, 0.01718142746540252, 0.050773743860190734, 0.0662919256137684, 0.005731591663789004, 0.019783890747930855, 0.02577200204541441, 0.028043597340001725, 0.030444304065895267, 0.029307743861863855, 0.09013316739583388, 0.07071431682561524, 0.022438057603721973, 0.0034973076117239543, 0.0331664349505445, 0.01641973532969132, 0.07370290099061094, 0.05296873838233296, 0.05451142220408656, 0.05851393965713214, 0.0238058042305056, 0.03579090662242379, 0.0852210700395517, 0.027586716387304477, 0.06291622237768024, 0.08171154273441061, 0.034473965570214204, 0.011435693249950418, 0.008700329872226575, 0.006973618010306382, 0.11158873094245791, 0.05462764253024943, 0.014697857168357586, 0.027488845662446693, 0.06338575694826432, 0.04889153118710965, 0.059981807571602985, 0.01403686426783679, 0.007122764645828283, 0.00903041767742252, 0.036661323392763734, 0.08042925255722366, 0.026461449815542437, 0.05999273569614161, 0.04060853229020722, 0.025214190864062402, 0.022904426914465148, 0.021100937556184363, 0.0298000586553826, 0.025258100031351205, 0.08905399561626837, 0.02689474160433747, 0.08088661590591073, 0.019895146106136963, 0.047008572655613534, 0.07823083302355371, 0.1000946520071011, 0.00940242198339547, 0.07631034037331119, 0.30376644688658416, 2.782024755142629, 16.61971729248762, 31.760445646941662, 41.28246299922466, 49.36981223523617, 43.82210232317448, 30.901832319796085, 17.091251090168953, 22.04296488314867, 29.017338640987873, 26.487489491701126, 33.81895288825035, 27.959538102149963, 18.018631227314472, 11.08643140643835, 7.318968242034316, 4.317513098940253, 1.9338612235151231, 0.64822603831999, 0.27238517766818404, 0.1682129956316203, 0.13221945671830326, 0.1382038535666652, 0.17727834434481338, 0.030753610808460508, 1.5256175422109663, 0.8518497494515032, 1.1494136229157448, 0.7455849484540522, 1.1613467638380826, 2.726962147280574, 1.9408103381283581, 2.327739894390106, 2.774779493920505, 2.0139976171776652, 3.250965429469943, 3.021095101721585, 2.137120272964239, 3.2482457254081964, 1.0455321846529841, 2.9094502050429583, 2.4400169821456075, 7.136645000427961, 3.6045651929453015, 2.9483012203127146, 4.782832330092788, 1.219686339609325, 3.4701861161738634, 1.5377895953133702, 1.2677554227411747, 0.6015621672850102, 0.7011662819422781, 0.2409709125640802, 0.08884848008165136, 0.45657376293092966, 0.7613032800145447, 2.492636083625257, 4.672303386032581, 6.435002200305462, 11.537063475698233, 17.87702612578869, 17.372644990682602, 16.485379301011562, 14.222915153950453, 19.388522319495678, 38.37274633347988, 36.25335305929184, 26.816263049840927, 37.79734320938587, 29.986085258424282, 14.576634373515844, 3.480029250495136, 0.26399297174066305, 0.00820231631223578, 0.03891758591635153, 0.07468783485819586, 0.07424606403219514, 0.053907737019471824, 0.057166770930052735, 0.09212998993461952, 0.0662125158123672, 0.11220673957723193, 0.11429921753006056, 0.045680291586904787, 0.04547882817860227, 0.01925078009662684, 0.03272746573202312, 0.032113152992678806, 0.059888545583817177, 0.03250903311709408, 0.04191136140434537, 0.019991640147054568, 0.07483293215045705, 0.056920570859801956, 0.03594012283429038, 0.031896961663733236, 0.030949073952797335, 0.014513092082779622, 0.019220307513023727, 0.0713974043901544, 0.02724638230574783, 0.003592633233893139, 0.03156681726977695, 0.07262787039508112, 0.016854071691341233, 0.035344990901649, 0.0035823765210807323, 0.07046506652841344, 0.03839079465251416, 0.009579914021742297, 0.03201192033884581, 0.01102279289625585, 0.06277375228819437, 0.10372365766670555, 0.06627367620239966, 0.03974698789534159, 0.05859393575519789, 0.04912956021144055, 0.07703909228439443, 0.02242198825115338, 0.12744786276016384, 0.15851143340114504, 0.1946459655300714, 0.12086078262655064, 0.1567741102189757, 0.2020623066346161, 0.2020007825922221, 0.20388583769090474, 0.1436754857422784, 0.1192086431547068, 0.11555332093848847, 0.08813012565951794, 0.16792676411569118, 0.12132791263866238, 0.15610346104949713, 0.21815944521222264, 0.10261269970214926, 0.10364971749368124, 0.27941393957007676, 0.11673398883431219, 0.09581090140272863, 0.15245332644553855, 0.15541422850219533, 0.14044769253814593, 0.08466379134915769, 0.09383837677887641, 0.2660820580786094, 0.13150227488949895, 0.13096297101583332, 0.13759796420345083, 0.143201861937996, 0.12578049441799521, 0.12629250210011378, 0.22474688157672063, 0.0842209963593632, 0.1000850931450259, 0.08006445728824474, 0.1760858911438845, 0.25922508852090687, 0.18323350057471544, 0.14033813669811934, 0.18432773795211688, 0.13894091011025012, 0.116284573887242, 0.09314479524618946, 0.2038905577501282, 0.21507368423044682, 0.1400708151049912, 0.2591894654324278, 0.10590550504275598, 0.2002705098129809, 0.22093616105848923, 0.16826917621074244, 0.131423206476029, 0.13727858837228268, 0.6051682925317436, 3.520994852297008, 16.942874751985073, 34.71396826207638, 48.61722081899643, 55.45471832156181, 56.41483560204506, 41.463641077280045, 28.2322171702981, 38.334839567542076, 40.25310203433037, 34.77072201669216, 37.72161707282066, 26.312014907598495, 22.485175654292107, 13.929512947797775, 8.24338311329484, 4.951087301596999, 2.9727455461397767, 1.026114751584828, 1.1072361236438155, 0.6090198014862835, 0.9856387891341001, 1.421187745872885, 2.7934341179206967, 5.31470593996346, 9.54799085855484, 4.749159961938858, 10.434832870960236, 4.839919516816735, 8.944619335234165, 8.851457834243774, 11.528820767998695, 9.816686790436506, 13.610488716512918, 6.203668713569641, 7.001272514462471, 5.429723393172026, 7.034800015389919, 7.136933784931898, 3.0096038058400154, 5.63914155587554, 7.588836411014199, 8.011448308825493, 5.57506606914103, 11.046538297086954, 10.849573966115713, 9.945957753807306, 10.880503356456757, 9.465041309595108, 8.258818835020065, 4.826870542019606, 3.0576814385131, 2.137309075333178, 1.8069023173302412, 2.071808190084994, 1.2705823522992432, 2.836364689283073, 4.98604447580874, 7.838802672922611, 14.275841563940048, 19.300503842532635, 24.29767269641161, 29.742932505905628, 28.375450484454632, 31.809487715363503, 42.895886823534966, 43.21608804166317, 32.51721493899822, 46.129125729203224, 34.00350138545036, 17.449302077293396, 3.5711837466806173, 0.26113549538422376, 0.1475439453497529, 0.1262436094111763, 0.18942019203677773, 0.2061047256574966, 0.13625250983750448, 0.12536183407064527, 0.2068989275721833, 0.11966942780418321, 0.1831625067279674, 0.20798090466996655, 0.16044723655795678, 0.15607420558808371, 0.15498572727665305, 0.1105767086846754, 0.1833713916130364, 0.17840566666563973, 0.1476508888299577, 0.12187850457848981, 0.11435713473474607, 0.1258636001148261, 0.1675907790195197, 0.07653206441318616, 0.18154351157136261, 0.1257173970225267, 0.11075795599026605, 0.13526126771466807, 0.16699771396815777, 0.09004219493363053, 0.12350621254881844, 0.08278705572593026, 0.08322746842168272, 0.11803321482148021, 0.14817575050983578, 0.08639839084935375, 0.24269958230433986, 0.07897422008682042, 0.09773075580596924, 0.16101083834655583, 0.0925185858795885, 0.2583146811230108, 0.2104399516247213, 0.15608103334670886, 0.1446003798628226, 0.11325949832098559, 0.09804082510527223, 0.13127088808687404, 0.12256024143425748], [0.027489433814480435, 0.03529623179929331, 0.0937593900016509, 0.020519552053883672, 0.020132590689172503, 0.049799374464782886, 0.026925260572170373, 0.027935954385611694, 0.03465369518380612, 0.03887725390086416, 0.027152513612236362, 0.05001912439183798, 0.02989585878822254, 0.046966192312538624, 0.0050016402565233875, 0.03545605330145918, 0.011602358281379566, 0.05637048358039465, 0.011158816505485447, 0.028318731892795768, 0.028232685435796157, 0.05242352701316122, 0.007876299187046243, 0.02590392621641513, 0.04348141934315208, 0.034621304148458876, 0.0621816074999515, 0.027038033622375224, 0.043980294722132385, 0.08068478884524666, 0.029731864560744725, 0.02726350550801726, 0.038522473914781585, 0.021148566738702357, 0.052034426407772116, 0.009963157226593466, 0.0644150712469127, 0.057024137568078004, 0.021196220041019842, 0.052729143426404335, 0.03264875354943797, 0.058147682357230224, 0.047257125333999284, 0.05506435933057219, 0.05299061318510212, 0.045051406777929515, 0.04334512021159753, 0.04896655860648025, 0.01167898688436253, 0.03430704542552121, 0.01846646729973145, 0.01134989634010708, 0.09305062412749976, 0.05003433099773247, 0.013704197499464499, 0.09813285883865319, 0.104251050070161, 1.1183097981847823, 8.981794640421867, 19.95397187769413, 33.70059683918953, 38.90231251716614, 38.8516878336668, 35.03948159515858, 25.995016917586327, 25.932329781353474, 21.36795960366726, 31.50475736707449, 23.226206190884113, 23.46652429550886, 23.016867823898792, 17.329144924879074, 16.120712868869305, 8.96600553765893, 6.643691277131438, 4.273118181154132, 1.5935210860334337, 1.2544031767174602, 0.6471924937795848, 0.2471378628979437, 0.6591217161621898, 0.7631779450457543, 0.5402780463919044, 1.011787976603955, 0.6164408032782376, 1.5801954385824502, 1.4546622871421278, 0.6772642582654953, 1.538164943922311, 1.5033123828470707, 0.7101557089481503, 3.625316354446113, 2.8397526824846864, 1.2148649920709431, 2.2898364532738924, 2.723615476861596, 1.6862406232394278, 1.042291671037674, 6.561443740502, 4.236132390797138, 3.362985081039369, 3.79454811103642, 1.1801808094605803, 2.6926526008173823, 0.5210355226881802, 0.5659389006905258, 0.6906809820793569, 1.3906247983686626, 0.9387434867676347, 0.606727396370843, 1.7178951809182763, 4.024701286107302, 5.820839731022716, 9.789333008229733, 12.209449745714664, 13.141727820038795, 15.46494785696268, 11.280690282583237, 16.18636004626751, 18.559737391769886, 22.763440422713757, 32.61561065912247, 32.813154458999634, 27.81313955783844, 23.140575885772705, 11.571787912398577, 1.85582279227674, 0.10338359817978926, 0.055083269253373146, 0.03914363667718135, 0.02345768687519012, 0.07753409736324102, 0.042679933249019086, 0.03869933141686488, 0.04437535106262658, 0.056371593091171235, 0.02845335562597029, 0.009502698194410186, 0.06179138996230904, 0.01651327376748668, 0.02964897037600167, 0.004454616191651439, 0.006962656952964608, 0.05669513608154375, 0.08158586744684726, 0.044955573248444125, 0.017864609653770458, 0.043679183145286515, 0.06789422986912541, 0.03854325404972769, 0.05219133869104553, 0.0023331130751103046, 0.0993187291896902, 0.053060953941894695, 0.04778480717504863, 0.02455383899359731, 0.0430413665890228, 0.03577194474928547, 0.03976735613832716, 0.03481038111203816, 0.05270059671602212, 0.020686344178102445, 0.12994394288398325, 0.023114130017347634, 0.03784914188145194, 0.025578206877980847, 0.007464502778020687, 0.0925123666820582, 0.017467004036006983, 0.01740623698424315, 0.056743624299997464, 0.0639679421146866, 0.019456603622529656, 0.03487798705464229, 0.05400079120590817, 0.033033323343261145, 0.055257365966099314, 0.002401463484602573, 0.027517640992300585, 0.03522149010677822, 0.04795826935151126, 0.0753678276669234, 0.021944740910839755, 0.027399110731494147, 0.09358491850434802, 0.06280283705564216, 0.03890739622875117, 0.04281488167180214, 0.05753552926762495, 0.11736273634596728, 0.03413556107261684, 0.0696451120893471, 0.019639747115434147, 0.02130271081114188, 0.025017683146870695, 0.06690499896649271, 0.032177152097574435, 0.014690807693114039, 0.04057462727359962, 0.04818590830836911, 0.03214554031728767, 0.020038883412780706, 0.008817727430141531, 0.02613402539282106, 0.031370040524052456, 0.03681772359414026, 0.023105073960323352, 0.016542681369173806, 0.00732250812689017, 0.039263359940377995, 0.028662657969107386, 0.03639232454588637, 0.07574581090011634, 0.014422435961023439, 0.06317034858511761, 0.05094250453112181, 0.04680018872022629, 0.009758340238477103, 0.02554807568230899, 0.033416189908166416, 0.04811058774066623, 0.037627102428814396, 0.04374777985503897, 0.04095665521163028, 0.053330817390815355, 0.018376617335889023, 0.02591447213490028, 0.02312761112989392, 0.03653653497167397, 0.05020331431296654, 0.02518385743314866, 0.07472188459360041, 0.20625351142371073, 1.975867731962353, 11.786540038883686, 25.27731142938137, 40.69356679916382, 45.73182664811611, 42.82650634646416, 34.145001992583275, 28.21811232715845, 24.165694378316402, 25.06453424692154, 30.395452491939068, 27.71657343953848, 30.16821328550577, 28.428885117173195, 19.949098639190197, 17.008542828261852, 10.019610151648521, 6.307349000126123, 4.339180011302233, 2.1777902031317353, 0.9913005447015166, 0.6886124087031931, 0.36297418700996786, 0.21424515056423843, 0.29498348536435515, 0.1316406112164259, 0.17294461751589552, 0.1978277604212053, 0.11286662760539912, 0.42676839977502823, 0.4957827605539933, 0.8378103340510279, 1.6551822773180902, 0.9046488662716001, 2.4647028325125575, 1.9123219605535269, 1.4581509749405086, 1.2385229975916445, 0.5788723973091692, 2.1507532289251685, 1.1859113769605756, 2.2936091758310795, 2.0324104791507125, 0.7954277645330876, 0.5639364081434906, 0.5000496644061059, 0.578914670040831, 0.5134390771854669, 0.11787433584686369, 0.2707552432548255, 0.19129120570141822, 0.841136461822316, 0.9402194106951356, 2.1578875835984945, 4.888508934527636, 7.4854164104908705, 14.196750707924366, 17.780387811362743, 18.936639167368412, 16.196609996259212, 13.771193493157625, 18.896579816937447, 22.34004434198141, 26.92642103880644, 36.3060562312603, 37.344525307416916, 31.281582042574883, 27.972351014614105, 14.917630925774574, 2.6538310339674354, 0.10625079667079262, 0.03259008677559905, 0.005981674094073242, 0.03243857732741162, 0.037744131695944816, 0.02423132573312614, 0.047533979814033955, 0.08093587966868654, 0.06605428992770612, 0.03091829152253922, 0.0482945327530615, 0.03179796658514533, 0.003874883823300479, 0.01934862299094675, 0.013382488541537896, 0.050349933007964864, 0.01955552819708828, 0.02522934737498872, 0.038364581996575, 0.034866390997194685, 0.06854565741377883, 0.03732658085937146, 0.03510283553623594, 0.042611362514435314, 0.07479145351680927, 0.015422368633153383, 0.09023833714309148, 0.020018964169139508, 0.0417113488947507, 0.07255473916302435, 0.025155997209367342, 0.06260885449592024, 0.008871554473444121, 0.02613920372823486, 0.061587288219016045, 0.03779959981329739, 0.031361743313027546, 0.03898633847711608, 0.035254007307230495, 0.012065416685800301, 0.04710134111519437, 0.009874574479908915, 0.04797428860911168, 0.058788122405530885, 0.014279391634772765, 0.04630060830095317, 0.06571085366886109, 0.037417794519569725, 0.057220880917157046, 0.14198533346643671, 0.09098011374589987, 0.13263902248581871, 0.11898839598870836, 0.0811119690479245, 0.22561969177331775, 0.09984506032196805, 0.1095747276849579, 0.1952846726635471, 0.1725158342742361, 0.10607305230223574, 0.11482798290671781, 0.17059763486031443, 0.29534972039982677, 0.22946900397073478, 0.185986987198703, 0.1626620872411877, 0.14955636783270165, 0.1197704637888819, 0.16909956524614245, 0.13544644840294495, 0.18562985089374706, 0.10012334343628027, 0.1360449311323464, 0.13792076875688508, 0.11256856625550427, 0.18249064043629915, 0.08939795137848705, 0.12385657304548658, 0.2557794452877715, 0.15288595401216298, 0.10044074515462853, 0.09312673137173988, 0.09923826553858817, 0.1436020279652439, 0.15529551455983892, 0.16710906580556184, 0.10000536422012374, 0.11004903426510282, 0.16268996230792254, 0.17575465579284355, 0.17310829076450318, 0.09537395453662612, 0.16281591961160302, 0.13676194968866184, 0.1510156676522456, 0.13084157049888745, 0.09656825568526983, 0.29026589007116854, 0.15416313079185784, 0.09952618172974326, 0.18260325392475352, 0.19569669821066782, 0.14092573954258114, 0.1442931010387838, 0.1380332635017112, 0.23307640571147203, 1.6676946496590972, 11.820772401988506, 28.434744402766228, 46.33107349276543, 52.6681986451149, 55.416705161333084, 45.44881023466587, 37.824580147862434, 35.343317091464996, 33.89661692082882, 40.93812547624111, 35.835994854569435, 35.34588575363159, 32.320484295487404, 23.189720548689365, 20.69658312946558, 12.432810310274363, 8.511554673314095, 6.232181433588266, 2.569143553264439, 1.7521458305418491, 1.3887177756987512, 0.5839340225793421, 1.1829391052015126, 1.6779117076657712, 1.0997436381876469, 2.685087681747973, 1.3763093040324748, 3.5260238824412227, 7.0278392639011145, 3.775610877200961, 4.254521504044533, 6.759863393381238, 5.5953907035291195, 10.389252416789532, 10.96477523446083, 4.5872587244957685, 5.705027645453811, 6.132299518212676, 9.756480921059847, 5.571098607033491, 12.307723872363567, 10.094988606870174, 8.012307062745094, 7.94552612118423, 4.608363267034292, 6.158776022493839, 1.9191618310287595, 3.3325541764497757, 1.8131344579160213, 2.037587701343, 1.5515865362249315, 1.359086965676397, 2.29637305252254, 5.833994625136256, 9.05040280893445, 14.904209095984697, 19.917094856500626, 21.02166708558798, 23.62505178898573, 18.68927624076605, 26.420945562422276, 29.24154371023178, 33.137349262833595, 44.36558336019516, 42.60720111429691, 39.04078088700771, 30.23056223988533, 16.357831545174122, 3.092355290427804, 0.3228260460309684, 0.15171906037721783, 0.17381839250447229, 0.12171324313385412, 0.10232086497126147, 0.11388403785531409, 0.1522428830503486, 0.1340253246598877, 0.1343225548043847, 0.09018627548357472, 0.1332197233568877, 0.13759414956439286, 0.11938977913814597, 0.11061594603233971, 0.11102568576461636, 0.13703367963898927, 0.1417122082784772, 0.1688459436991252, 0.11653064779238775, 0.08041884764679708, 0.14367060241056606, 0.13666397135239094, 0.1641765731619671, 0.10674917852156796, 0.1274238171754405, 0.19621493993327022, 0.20934363623382524, 0.12509877240518108, 0.18099304579664022, 0.15309816371882334, 0.10976804973324761, 0.1385121268685907, 0.11872483708430082, 0.07974380496307276, 0.17564054316608235, 0.13916030380642042, 0.09207246606820263, 0.16392890363931656, 0.14721434272360057, 0.0907198573986534, 0.2872148319147527, 0.07344619953073561, 0.12387911949190311, 0.17779287532903254, 0.10203689700574614, 0.1759287784807384, 0.17199061636347324, 0.18953941063955426, 0.13449305581161752], [0.02820165995217394, 0.0041515263274050085, 0.03981493893661536, 0.04073739881278016, 0.016912751452764496, 0.04726466184365563, 0.0204899997333996, 0.03395992811420001, 0.03585869068047032, 0.03731075456016697, 0.011987679499725346, 0.05769481271272525, 0.036567523347912356, 0.05820831211167388, 0.003441182461756398, 0.04707289088401012, 0.023554602084914222, 0.03076898996368982, 0.07362231117440388, 0.045721992864855565, 0.0687484789523296, 0.01823052742111031, 0.04491843246796634, 0.02540065917855827, 0.039117720880312845, 0.11379356263205409, 0.04024556270451285, 0.07219804072519764, 0.006170252891024575, 0.0508549088408472, 0.04363130348792765, 0.02713365749514196, 0.05011482062400319, 0.05050966174167115, 0.05074856278952211, 0.06699840567307547, 0.041970213715103455, 0.06051547854440287, 0.02833291990100406, 0.02295767601026455, 0.03031729291251395, 0.01040732426190516, 0.04814020314370282, 0.03243988350732252, 0.03845312021439895, 0.04146114122704603, 0.07292730471817777, 0.023149111148086376, 0.04065592584083788, 0.014390364976861747, 0.020357368666736875, 0.02017883391090436, 0.03773627235204913, 0.10725672589614987, 0.06299863045569509, 0.03929528713342734, 0.07538736099377275, 0.08565289608668536, 0.47245937457773834, 5.761515414342284, 12.279217801988125, 30.608541257679462, 42.70158804953098, 43.201960399746895, 37.40502566099167, 35.914407446980476, 27.020986564457417, 29.099239446222782, 23.550957664847374, 24.734282568097115, 40.86787864565849, 30.509841553866863, 27.766683250665665, 20.47888521105051, 14.684808868914843, 12.722501065582037, 11.184311304241419, 7.438526451587677, 5.309222834184766, 3.5487352637574077, 2.069722102023661, 1.2747585657052696, 0.909932185895741, 1.2263949983753264, 0.35106440889649093, 0.33865065313875675, 0.1960675642476417, 0.41337242641020566, 0.9778934391215444, 0.6436666392255574, 0.4871471005026251, 0.9377819602377713, 1.3219507271423936, 0.5770525918342173, 1.0616084095090628, 0.3095121245132759, 1.6712216916494071, 0.5184942902997136, 4.8809288162738085, 0.885424807202071, 0.6989435793366283, 0.6379362498410046, 0.0397391285514459, 0.6933571072295308, 1.539631902705878, 0.8123569248709828, 1.2358491285704076, 2.1066544577479362, 2.8308025002479553, 5.5574145913124084, 8.230156023055315, 10.132549591362476, 13.77638591453433, 12.743553835898638, 15.733554493635893, 11.859202589839697, 13.034188840538263, 15.176609829068184, 20.418192967772484, 23.182022161781788, 31.818821914494038, 27.979990504682064, 24.19526819139719, 13.596221432089806, 8.17413467913866, 1.588296010158956, 0.07651287247426808, 0.043385804747231305, 0.07446598465321586, 0.052388980038813315, 0.05857338568603154, 0.020880926022073254, 0.008456308005406754, 0.04964103354723193, 0.028701412920781877, 0.039171726966742426, 0.03271127578045707, 0.09612157926312648, 0.08085091860266402, 0.02404712839052081, 0.014796004343224922, 0.055017559498082846, 0.03201680367055815, 0.025615065642341506, 0.007352918091783067, 0.01796822645701468, 0.04021340915642213, 0.024327459832420573, 0.028032949376211036, 0.04884269044850953, 0.008690315517014824, 0.029189000233600382, 0.06643768341746181, 0.0537339854054153, 0.018948811339214444, 0.07330399661441334, 0.05027938816056121, 0.0632291563670151, 0.021793845589854755, 0.046398968843277544, 0.04640891362214461, 0.0380663759278832, 0.006671104238193948, 0.031211005698423833, 0.012939060870849062, 0.017581535976205487, 0.07109944694093429, 0.030221635643101763, 0.02580775872047525, 0.042313991361879744, 0.02342334955756087, 0.007933654214866692, 0.02073589181236457, 0.05163749614439439, 0.035074641346000135, 0.06571528429049067, 0.056479501363355666, 0.02495592532795854, 0.009497513365204213, 0.04481672112888191, 0.04280784611182753, 0.035830745109706186, 0.015857085345487576, 0.012227254974277457, 0.013761241752945352, 0.07309294465812854, 0.043646569465636276, 0.013402785352809587, 0.056245658051921055, 0.04264933450031094, 0.01841042216256028, 0.04309609255869873, 0.017646913620410487, 0.01327459882304538, 0.02513461407943396, 0.027274439198663458, 0.06084724453103263, 0.03208825764886569, 0.03742861132195685, 0.021629342991218437, 0.030412345331569668, 0.0733488668629434, 0.011457145956228487, 0.03345543096656911, 0.031555670211673714, 0.06566293319338001, 0.02217260807810817, 0.026150578996748663, 0.059354577751946636, 0.02994327831402188, 0.023554229155706707, 0.032496832209290005, 0.0545803528802935, 0.03750700067030266, 0.03181582265824545, 0.049920901146833785, 0.0166024391000974, 0.04618374972778838, 0.02569854612374911, 0.03338481932587456, 0.024754374717304017, 0.049470328449388035, 0.04216913897835184, 0.03409094315429684, 0.050284408789593726, 0.0273596154875122, 0.018728100330918096, 0.07063242825097404, 0.05501616426045075, 0.05895212962059304, 0.09323331862105988, 0.08756467592320405, 0.04130383560550399, 0.10482939833309501, 1.0136172221973538, 7.958237864077091, 17.913426272571087, 36.80006392300129, 46.391931027173996, 48.13129149377346, 41.1646731197834, 34.14381265640259, 27.60325402021408, 29.702018201351166, 25.850060395896435, 29.720179326832294, 45.01125991344452, 34.05887961387634, 34.662849605083466, 27.263527549803257, 19.514426663517952, 17.48744823038578, 12.294644974172115, 7.5814087595790625, 4.6793197095394135, 2.9110019467771053, 2.0254117297008634, 1.4521874324418604, 0.6585606525186449, 0.5315985402557999, 0.2493124594911933, 0.10272524639731273, 0.09117738401982933, 0.24665800505317748, 0.13946010178187862, 0.22368083096807823, 0.07580522724310867, 0.19444110308540985, 0.23331991920713335, 0.24598094372777268, 0.2086064757895656, 0.18040185095742345, 0.12644955539144576, 0.23493791988585144, 0.25327463750727475, 0.33088553231209517, 0.16696474776836112, 0.24544478656025603, 0.08118830635794438, 0.10197711701039225, 0.46436827280558646, 0.5360771936830133, 1.3583576423116028, 2.510836631990969, 3.6220214562490582, 6.517607867717743, 10.835471972823143, 13.15097937360406, 18.922192342579365, 16.991726830601692, 20.536077842116356, 13.755810968577862, 14.156960193067789, 14.699479881674051, 20.965506099164486, 25.640302151441574, 36.206227988004684, 34.1490563750267, 28.742427192628384, 16.96013532578945, 10.136245843023062, 2.665735795162618, 0.11145179727463983, 0.037762800420750864, 0.03730411975993775, 0.06945547851501033, 0.06611537610297091, 0.01093258762921323, 0.06583846596186049, 0.019083824699919205, 0.028649314153881278, 0.034693567067733966, 0.03163973698974587, 0.10111451134434901, 0.013754168157902313, 0.025807947968132794, 0.010406004166725324, 0.10939702784526162, 0.06749927371856757, 0.04768015322042629, 0.028618546566576697, 0.013262798674986698, 0.013119834129611263, 0.016463982174172997, 0.08775750815402716, 0.016866825499164406, 0.011744103849196108, 0.059082543521071784, 0.05937257483310532, 0.029663379173143767, 0.02666029344254639, 0.14394530095160007, 0.05146158116986044, 0.0313485182414297, 0.007679895834371564, 0.05333567474735901, 0.043202330998610705, 0.032305521381204017, 0.05232100302237086, 0.026810253657458816, 0.0634175431332551, 0.026081357027578633, 0.04935059405397624, 0.05294962436892092, 0.046775582814007066, 0.04363347055914346, 0.05202219581406098, 0.01279561764022219, 0.05439711661892943, 0.03850618748401757, 0.02311175143404398, 0.048826058919075876, 0.13236818311270326, 0.07565203311969526, 0.12250717045390047, 0.17773558152839541, 0.1266086718533188, 0.12469629087718204, 0.1037179802369792, 0.17977917421376333, 0.10470998677192256, 0.17391828558174893, 0.14821167045738548, 0.15685706748627126, 0.17403095844201744, 0.13070137880276889, 0.19369638757780194, 0.12767714186338708, 0.21209874073974788, 0.10751943133072928, 0.13299213635036722, 0.15175763721344993, 0.14573032938642427, 0.13975063775433227, 0.13027502980548888, 0.08667771297041327, 0.10142742306925356, 0.20736147853313014, 0.12126958725275472, 0.32687306636944413, 0.13975008856505156, 0.13828108145389706, 0.1375442327116616, 0.10239830065984279, 0.08519197785062715, 0.13213310041464865, 0.1298205682542175, 0.2593442774377763, 0.11487608891911805, 0.17553313955431804, 0.10745032253907993, 0.18135527323465794, 0.2302040864014998, 0.09990545629989356, 0.08932976284995675, 0.11575342621654272, 0.12284246535273269, 0.22296302573522553, 0.10388503767899238, 0.1778450483107008, 0.12324505820288323, 0.1223744818707928, 0.1279952412005514, 0.11158122040797025, 0.13567329326178879, 0.2354026972898282, 0.13762956485152245, 0.21229382167803124, 0.2067359519423917, 0.1855690689990297, 0.8605612569954246, 7.958218865096569, 18.542364723980427, 41.26320943236351, 54.30373728275299, 58.15577298402786, 53.08712616562843, 45.730002745985985, 41.130246967077255, 42.58049234747887, 33.376280441880226, 34.15666736662388, 53.779034838080406, 40.69676622748375, 38.10329519212246, 30.22614497691393, 21.652951911091805, 19.06230602413416, 16.693836115300655, 9.603971354663372, 7.107722377404571, 5.150158619508147, 2.897243360057473, 1.9315433478914201, 1.4709958294406533, 1.8205003626644611, 1.0157901118509471, 0.7845399831421673, 0.6562339304946363, 1.6612352337688208, 2.0063510024920106, 2.0475624036043882, 1.6939247609116137, 2.5964904483407736, 3.2662389473989606, 2.5757504487410188, 3.673717682249844, 1.1976331542246044, 4.781787861138582, 3.096551215276122, 8.740157056599855, 2.984886607155204, 1.955261912662536, 1.4916518772952259, 1.1338971555233002, 1.108963843435049, 2.3839597776532173, 1.5065492154099047, 2.0997979631647468, 2.970952754840255, 4.368792772293091, 7.448460543528199, 12.102046608924866, 15.56153392419219, 21.807407923042774, 19.09906905144453, 25.69474373012781, 20.465810112655163, 21.335171163082123, 23.42246375977993, 28.306776769459248, 33.22999209165573, 43.65920506417751, 40.11234998703003, 34.41658481955528, 20.13628039509058, 10.727754402905703, 2.5157915661111474, 0.16036169661674649, 0.19571304030250758, 0.1376952152349986, 0.15976357011822984, 0.22356483328621835, 0.13199644134147093, 0.13830572075676173, 0.2780793799320236, 0.11611459980485961, 0.09563384723151103, 0.08526973266270943, 0.34001997497398406, 0.17130300169810653, 0.09394226261065342, 0.08112724244710989, 0.3378434042679146, 0.26924215257167816, 0.2928067365428433, 0.16796802752651274, 0.1806971663609147, 0.1048623793758452, 0.14356199651956558, 0.16569485887885094, 0.1636204670649022, 0.1946876445435919, 0.1527996570803225, 0.17919977952260524, 0.17081230849726126, 0.12857123685535043, 0.2988946926780045, 0.10071726195747033, 0.08917681363527663, 0.06921676671481691, 0.14442618296016008, 0.13467862241668627, 0.11361532844603062, 0.10367771872552112, 0.06868360040243715, 0.21668242290616035, 0.12818407325539738, 0.16246080194832757, 0.16776436736108735, 0.16005211713491008, 0.1893752921023406, 0.14158433623379096, 0.152959203987848, 0.1777390399365686, 0.09869289089692757, 0.079828075831756, 0.18771918956190348], [0.07467783812899143, 0.017691010179987643, 0.03363972107763402, 0.02865979513444472, 0.007528808482675231, 0.048325565658160485, 0.018117325780622195, 0.03511815346428193, 0.01843212070525624, 0.0735274498583749, 0.051033911149716005, 0.05185353904380463, 0.016897810164664406, 0.030287154295365326, 0.007312531806746847, 0.02252356229291763, 0.06666207918897271, 0.041101236711256206, 0.014357374657265609, 0.029524230194510892, 0.022453332858276553, 0.08660386185511015, 0.03455326776020229, 0.07255989708937705, 0.04929180482577067, 0.014068448217585683, 0.04970828696968965, 0.012361250664980616, 0.019395344897930045, 0.02253772247058805, 0.010804326884681359, 0.05005342645745259, 0.05876197654288262, 0.04644329361326527, 0.049467964709037915, 0.03641193579824176, 0.04984835992217995, 0.030216672530514188, 0.052370103512657806, 0.04761450283695012, 0.08655569647089578, 0.006249503594517591, 0.10501137294340879, 0.017660339071881026, 0.020089087847736664, 0.02918903363024583, 0.008908978197723627, 0.025180376760545187, 0.008529262049705721, 0.009410250713699497, 0.04565117342281155, 0.026654920293367468, 0.05597664807282854, 0.07562165701529011, 0.055158478498924524, 0.06580773362657055, 0.0323520020901924, 0.017632590170251206, 0.025907764975272585, 0.18698946543736383, 2.563461195677519, 8.817425910383463, 25.9694841876626, 34.08329330384731, 39.66927856206894, 50.8670648932457, 40.070335641503334, 34.40512463450432, 22.546348571777344, 21.55627179890871, 48.74148555099964, 24.480089507997036, 24.262175001204014, 26.447582133114338, 24.37817707657814, 25.06375338882208, 24.86582960933447, 19.3824103474617, 17.50060312449932, 12.609683219343424, 9.249438028782606, 7.521345857530832, 5.767911421135068, 2.7088349824771285, 3.407054403796792, 1.8371507129631937, 1.596024795435369, 0.7530370017047971, 0.7566833810415119, 0.8768683194648474, 0.4928782023489475, 0.7778431393671781, 0.7417231088038534, 0.5457008897792548, 0.39322819327935576, 0.3554997208993882, 0.6020918232388794, 0.690279925474897, 0.4981368826702237, 0.4903747304342687, 0.7526807114481926, 0.6328402482904494, 1.7568025994114578, 2.145138317719102, 3.558316924609244, 4.996702428907156, 8.536166902631521, 10.54279362782836, 13.520288206636906, 10.970466379076242, 15.15937965363264, 14.917993806302547, 14.814019985496998, 20.37778403609991, 22.823758386075497, 27.135601714253426, 21.183982975780964, 30.136555284261703, 30.258025266230106, 27.549802288413048, 23.230898939073086, 16.329507865011692, 8.60225960612297, 2.76350739877671, 0.2753549558110535, 0.09713956096675247, 0.05032058106735349, 0.09275645163143054, 0.0691154487140011, 0.13282779516885057, 0.032755930806160904, 0.0037844243706786074, 0.025750741369847674, 0.043904050180572085, 0.05791031013359316, 0.007892801768321078, 0.07097544890712015, 0.039763381937518716, 0.05175062171474565, 0.009120396589423763, 0.02852237164916005, 0.020103947499592323, 0.02361190887313569, 0.02459285740769701, 0.06054113830032293, 0.07025888306088746, 0.05432332487544045, 0.06542565373820253, 0.030752929887967184, 0.04369934358692262, 0.007152556308938074, 0.06590607561520301, 0.046176135292625986, 0.0413363676489098, 0.03426164454140235, 0.012713225332845468, 0.01247966682058177, 0.03858616873912979, 0.02968053948279703, 0.013779785240330966, 0.05203559157962445, 0.08378343351068906, 0.03150300370180048, 0.04177186361630447, 0.017289200295635965, 0.013138740341673838, 0.02738031769695226, 0.05250206479104236, 0.05806189750728663, 0.019334293974679895, 0.02319565122888889, 0.03814115101704374, 0.04485529054363724, 0.04216263405396603, 0.046618499836768024, 0.02379246783675626, 0.00796689686467289, 0.06517529764096253, 0.0508251858263975, 0.038226390388445, 0.04212576415739022, 0.013009075082663912, 0.021016169448557775, 0.08174108021194115, 0.02801589111186331, 0.06914445926668122, 0.0021217269204498734, 0.021811404803884216, 0.037361929353210144, 0.046929849340813234, 0.03435551880102139, 0.0026534710923442617, 0.03956973334425129, 0.009056712897290708, 0.015482477956538787, 0.03367087643709965, 0.03773609052586835, 0.06297290761722252, 0.004102720840819529, 0.0347835042339284, 0.058683958268375136, 0.037729797113570385, 0.0834302454313729, 0.04195751927909441, 0.03138533989840653, 0.04525117437879089, 0.05371293067582883, 0.024030324311752338, 0.013784906986984424, 0.019268422802269924, 0.03960449554142542, 0.011804574969573878, 0.03889396335580386, 0.08792524095042609, 0.06837891167378984, 0.05646015357342549, 0.04052380128996447, 0.01030350336804986, 0.03103688301052898, 0.029821801726939157, 0.0280178856337443, 0.02713052563194651, 0.011656139868136961, 0.06783041259041056, 0.02107024974975502, 0.02507600667740917, 0.05269186534860637, 0.015560659503535135, 0.035941967071266845, 0.0863602221943438, 0.042493761793593876, 0.0745274790097028, 0.030791063290962484, 0.06852875871118158, 0.05105500669742469, 0.3860987664666027, 4.161184262484312, 14.6097400970757, 34.041199162602425, 41.26210369169712, 44.416173845529556, 54.33022566139698, 43.296537324786186, 36.65787935256958, 22.802910804748535, 24.734472557902336, 52.49028839170933, 28.70681930333376, 32.121488973498344, 33.58526922762394, 28.267044201493263, 29.82931137084961, 28.504208475351334, 24.553653560578823, 22.785042263567448, 16.756050176918507, 11.54542587697506, 8.108727838844061, 6.414194041863084, 3.766858521848917, 2.898867060430348, 2.0259296894073486, 1.2510550813749433, 0.7111102889757603, 0.9892198594752699, 0.7965675846207887, 0.7613098109140992, 0.4260055610211566, 0.44916353712324053, 0.5132329976186156, 0.5707142944447696, 0.514165610074997, 0.7083833415526897, 0.4101651016389951, 0.5084841430652887, 0.4013725812546909, 0.7189266476780176, 0.7933924393728375, 1.774031943641603, 2.2716910019516945, 3.6654690373688936, 5.388869885355234, 9.242068324238062, 9.594108983874321, 15.899875368922949, 15.37226228043437, 17.419882155954838, 18.588686138391495, 18.806197866797447, 20.121502988040447, 21.89434725791216, 25.12592375278473, 21.236876137554646, 32.20190405845642, 33.916223868727684, 31.780559867620468, 29.535716325044632, 20.30595649033785, 12.255944050848484, 3.7719811219722033, 0.7289328763727099, 0.03066949764615856, 0.006662037048954517, 0.009281976981583284, 0.01780928811058402, 0.04299304164305795, 0.02142698529496556, 0.034739984694169834, 0.021162817829463165, 0.06247986922971904, 0.016750146896811202, 0.025801589617913123, 0.018049217032967135, 0.06701405014609918, 0.02509155652660411, 0.05032290398958139, 0.0626090177684091, 0.044736513518728316, 0.03627587044320535, 0.07461926783435047, 0.03961758702644147, 0.09712071041576564, 0.06093422052799724, 0.06794671455281787, 0.030129210426821373, 0.029544542776420712, 0.007065701374813216, 0.013618290195154259, 0.017482967632531654, 0.022923566903045867, 0.025579444409231655, 0.03596064692828804, 0.03316307673230767, 0.030275971985247452, 0.02034977835137397, 0.06507040990982205, 0.04109417517611291, 0.1403060313896276, 0.04279086577298585, 0.041803757412708364, 0.07466338109225035, 0.0287730487252702, 0.007080017867338029, 0.02128981413989095, 0.05073197949968744, 0.046945857466198504, 0.07095173728885129, 0.021148830201127566, 0.03345071090734564, 0.019638170051621273, 0.03502275409118738, 0.05162177745660301, 0.22331241401843727, 0.13349810295039788, 0.19216634624172002, 0.20814322720980272, 0.08406386885326356, 0.14554688532371074, 0.10393236443633214, 0.1747006576624699, 0.07403503434034064, 0.12323552160523832, 0.12285298158531077, 0.15562436019536108, 0.12250823914655484, 0.13634030590765178, 0.14801111246924847, 0.1471522101201117, 0.14947093179216608, 0.141233493341133, 0.09894801158225164, 0.11596115335123613, 0.1470038399565965, 0.13769558630883694, 0.09567170418449678, 0.15902342624031007, 0.1572004146873951, 0.1558396127074957, 0.14329350233310834, 0.10474733164301142, 0.148809737584088, 0.16827422281494364, 0.11639750649919733, 0.14473151735728607, 0.14196036761859432, 0.12792145687853917, 0.18183713487815112, 0.08247314210166223, 0.12293605017475784, 0.1954676565947011, 0.21846074232598767, 0.15060505218571052, 0.13860709208529443, 0.03788672423979733, 0.14651710982434452, 0.086349379416788, 0.11308647401165217, 0.1264555667876266, 0.19096037111012265, 0.1846494886558503, 0.1412951509701088, 0.05420531226263847, 0.19149912579450756, 0.08191188549972139, 0.16270636377157643, 0.3757840418256819, 0.14215733361197636, 0.1546013096231036, 0.20730785094201565, 0.18218098673969507, 0.18242104182718322, 0.33554627909325063, 4.665996674448252, 15.002814754843712, 36.08568325638771, 48.151901587843895, 52.27558471262455, 61.86691224575043, 52.58280582726002, 48.47296915948391, 34.963212087750435, 29.906319938600063, 62.96992465853691, 33.86560298502445, 36.59036077558994, 38.56777086853981, 35.11905312538147, 36.14497907459736, 33.72024178504944, 28.611444421112537, 25.105041973292828, 18.101126700639725, 14.070910010486841, 10.108488332480192, 8.47887072712183, 3.829258535988629, 4.5499784499406815, 3.0875366739928722, 2.2389837820082903, 1.276351511478424, 1.6150616551749408, 1.2841444183140993, 1.043124538846314, 1.232066669035703, 1.354619236662984, 1.381906047463417, 1.0853396798484027, 1.0651664435863495, 1.3409577822312713, 1.6929245833307505, 1.2399336718954146, 0.6571027776226401, 1.4068683329969645, 1.1556632188148797, 2.388165914453566, 2.840927531942725, 4.6187652088701725, 7.119721183553338, 10.9691658988595, 14.425573479384184, 19.289113953709602, 17.48338244855404, 23.401790969073772, 22.93673012405634, 23.07595655322075, 30.327508337795734, 31.079468987882137, 37.17559777200222, 30.389034636318684, 42.1881178021431, 42.38846205174923, 38.967000246047974, 34.00494530797005, 24.163963571190834, 12.959772683680058, 4.727015700191259, 0.9198794583790004, 0.14936676394427195, 0.15884712163824588, 0.1740817807149142, 0.17528074997244403, 0.1606018259190023, 0.08472374945995398, 0.12613470666110516, 0.11347993844537996, 0.15369373722933233, 0.12126057757996023, 0.19520334812114015, 0.13859984872397035, 0.12721478386083618, 0.16633309103781357, 0.1252772589214146, 0.1561288721859455, 0.09586531567038037, 0.11272138188360259, 0.15977971925167367, 0.2420060007716529, 0.22143412730656564, 0.16593961918260902, 0.17652803304372355, 0.19080609345110133, 0.12606841803062707, 0.08354510762728751, 0.11678255497827195, 0.11402534277294762, 0.1657902990700677, 0.11800624517491087, 0.21173434623051435, 0.18955278414068744, 0.15149277955060825, 0.07807098183548078, 0.1456318167038262, 0.10672742617316544, 0.244263747590594, 0.22718397580320016, 0.13580091297626495, 0.20567298866808414, 0.14751354698091745, 0.059838855086127296, 0.2078508655540645, 0.1971982856048271, 0.1340145041467622, 0.2981270448071882, 0.15773962950333953, 0.25868706114124507, 0.12352351201116107, 0.20843937381869182, 0.1690421675448306], [0.030551177042070776, 0.05549873094423674, 0.00955681003688369, 0.017534359503770247, 0.03048549511731835, 0.02957912871352164, 0.09814972785534337, 0.07953030391945504, 0.022337828704621643, 0.03428986841754522, 0.006532392199005699, 0.10551113518886268, 0.012732648265227908, 0.013197645530453883, 0.05291081375617068, 0.019574276702769566, 0.04089582136657555, 0.06627361683058552, 0.03148278388835024, 0.0142988600237004, 0.031388549687108025, 0.051398899377090856, 0.0059117688851983985, 0.015471051665372215, 0.07275543815921992, 0.06881129433168098, 0.013874588112230413, 0.02251872905617347, 0.021081022023281548, 0.10082603112095967, 0.017790383753890637, 0.04764363213325851, 0.013895842294004979, 0.011022698272427078, 0.06051259158994071, 0.026522519292484503, 0.012338333144725766, 0.07607185121742077, 0.03754464982193895, 0.011050589109800057, 0.03561927755072247, 0.016839406853250694, 0.023182433578767814, 0.04935801924148109, 0.051131982254446484, 0.11223243272979744, 0.05840560836077202, 0.023782792086421978, 0.02823260751029011, 0.033961861408897676, 0.03459018589637708, 0.08222702366765589, 0.013774593917332822, 0.07091414750902914, 0.01692308400379261, 0.01746391299093375, 0.02168156235711649, 0.044930659350939095, 0.018773989177134354, 0.0565068495052401, 0.14328017336083576, 1.0756743047386408, 3.997375052422285, 16.76359847187996, 26.285587325692177, 34.081777185201645, 44.30253714323044, 51.02652333676815, 35.195607617497444, 35.18537096679211, 43.2080514729023, 32.06424884498119, 24.34945821762085, 27.378923557698727, 24.43597387522459, 23.997762389481068, 23.699740581214428, 27.703836522996426, 22.951306141912937, 18.729115203022957, 22.4420802667737, 19.492484740912914, 15.817141458392143, 18.15642323344946, 13.519513048231602, 11.978897117078304, 9.010439403355122, 6.509131947532296, 5.424570394679904, 4.5971818920224905, 4.61432752199471, 3.2649838272482157, 3.382988632656634, 2.869279235601425, 3.431697506457567, 3.346668044105172, 3.389944159425795, 3.9102633018046618, 4.476068140938878, 5.491504753008485, 6.053592441603541, 8.068583942949772, 8.434354215860367, 12.624076846987009, 14.313032068312168, 17.095427066087723, 18.03335163742304, 24.640737287700176, 20.1129287481308, 16.23409118503332, 19.561363644897938, 21.728248670697212, 23.901447057724, 24.423666335642338, 29.47024203836918, 30.11004790663719, 36.34949550032616, 27.69992083311081, 24.751681834459305, 17.46943149715662, 9.735902175307274, 4.344529649242759, 1.3200087938457727, 0.1110850130498875, 0.04778938993695192, 0.07945363264298066, 0.015031120437924983, 0.05502401247213129, 0.04242807059199549, 0.037185606197454035, 0.050145285786129534, 0.03083114297623979, 0.03133135978714563, 0.01945866122696316, 0.03493276868539397, 0.03371497856278438, 0.03459260529780295, 0.018304129916941747, 0.007924878318590345, 0.024188848910853267, 0.0572263579670107, 0.03541281577781774, 0.03769034083234146, 0.03498215490253642, 0.07169582939241081, 0.05910704181587789, 0.06353591568768024, 0.04012418816273566, 0.02327449885342503, 0.0919521416653879, 0.03481046645902097, 0.033525267062941566, 0.06365094857756048, 0.0060502054020616924, 0.027354134726920165, 0.02564558461017441, 0.016615818167338148, 0.004304533522372367, 0.05995049636112526, 0.042983189632650465, 0.03617018119257409, 0.02695694100111723, 0.06998264827416278, 0.04296821680327412, 0.04290026205126196, 0.015346871805377305, 0.03409530327189714, 0.03664732648758218, 0.07951231425977312, 0.03751470416318625, 0.029174541341490112, 0.039521783182863146, 0.04028562383609824, 0.056441815104335546, 0.03237790675484575, 0.006506988484034082, 0.06923074877704494, 0.043983437717542984, 0.038038782877265476, 0.032934999908320606, 0.025055195001186803, 0.046197446063160896, 0.07449457218172029, 0.020269407468731515, 0.03834521194221452, 0.018493141942599323, 0.03517885001201648, 0.14187435270287097, 0.03010403863299871, 0.058886401311610825, 0.03608372098824475, 0.058822457867790945, 0.08630142183392309, 0.053967587518855, 0.03914936605724506, 0.09217434067977592, 0.0390723608143162, 0.0396102100785356, 0.041505710905767046, 0.013713307362195337, 0.00852704488352174, 0.04512860126851592, 0.04126931831706315, 0.038522555551026016, 0.03406759147765115, 0.07004289582255296, 0.032757077424321324, 0.04265976538590621, 0.027357841754565015, 0.02414870057691587, 0.08581046888139099, 0.010682975535019068, 0.017366075662721414, 0.06468490129918791, 0.010877301338041434, 0.021870930613658857, 0.02061177874566056, 0.04731683853606228, 0.05928501625021454, 0.05119073066452984, 0.04533832106972113, 0.06132495014753658, 0.044338922743918374, 0.14833557943347842, 0.014090465883782599, 0.037557559480774216, 0.024862796926754527, 0.017446934507461265, 0.030769685727136675, 0.10192967150942422, 0.03415832274185959, 0.03833396469417494, 0.015010709521448007, 0.04614980389305856, 0.07045645761536434, 0.055980807810556144, 0.19982741796411574, 1.6539828479290009, 6.67087834328413, 22.838034220039845, 33.21575425565243, 43.40410955250263, 49.49184648692608, 55.101078897714615, 37.113816887140274, 35.06232976913452, 47.326635271310806, 31.969656720757484, 23.245552852749825, 27.034635432064533, 26.222256124019623, 26.924471743404865, 29.338130727410316, 36.026227846741676, 30.598735883831978, 27.243673615157604, 27.275348715484142, 23.6215540766716, 20.473947376012802, 20.463266149163246, 16.773491241037846, 13.846203368157148, 10.466251485049725, 7.632777728140354, 5.948102027177811, 4.842501003295183, 5.0137245655059814, 3.940088851377368, 4.47536850348115, 2.852506935596466, 4.608442112803459, 3.7080645142123103, 4.58767575211823, 4.802912827581167, 4.946518046781421, 4.231142308562994, 7.570486720651388, 8.612967431545258, 11.525246109813452, 13.578002359718084, 16.1500795930624, 19.48709663003683, 24.050015285611153, 31.289700306952, 23.472166992723942, 18.646794520318508, 23.55331163853407, 23.805038630962372, 18.398797027766705, 23.253032751381397, 30.670175850391388, 35.01628004014492, 38.44438388943672, 32.82545439898968, 31.08893048018217, 21.38209104537964, 13.286595046520233, 6.904907785356045, 1.9595296774059534, 0.09541677645756863, 0.018314685112272855, 0.04559518951282371, 0.024065554061962757, 0.025682393279566895, 0.027424019062891603, 0.010701594164856942, 0.07846453532692976, 0.023628486596862786, 0.030316070224216674, 0.03448090094025247, 0.02353317257075105, 0.05285102262860164, 0.008183885074686259, 0.038482364543597214, 0.03405491188459564, 0.03659284542663954, 0.060660505332634784, 0.014130042764008977, 0.06732475769240409, 0.01601432046300033, 0.0747791190224234, 0.033719962084433064, 0.017518507229397073, 0.010224829220533138, 0.015923514984024223, 0.03685446361487266, 0.008186147697415436, 0.048486812083865516, 0.08327831295900978, 0.04042251668579411, 0.010244045279250713, 0.042071602219948545, 0.008120485254039522, 0.03147351075313054, 0.0482209896290442, 0.012993969594390364, 0.017669356166152284, 0.05196388898184523, 0.06514236854854971, 0.027243094591540284, 0.05455238133436069, 0.03026684542419389, 0.05407533251855057, 0.007240687737066764, 0.1140099432086572, 0.008315965096699074, 0.015536352311755763, 0.02756267822405789, 0.03738495819561649, 0.029458546414389275, 0.0013918827767156472, 0.05314025613188278, 0.1918264722917229, 0.18418644787743688, 0.11624025282799266, 0.0969338821596466, 0.13371126260608435, 0.11108784063253552, 0.20241024030838162, 0.12378825835185125, 0.1396578099229373, 0.11725074626156129, 0.09034378890646622, 0.17209113284479827, 0.09886386687867343, 0.14234769449103624, 0.10332646023016423, 0.09966032492229715, 0.20101915870327502, 0.17575719393789768, 0.15034574578749016, 0.12653162208152935, 0.16694147401722148, 0.19097769283689559, 0.13237236882559955, 0.05925202036451083, 0.13227470219135284, 0.10066720409668051, 0.18121007946319878, 0.16363842703867704, 0.2703337330603972, 0.18623927287990227, 0.08951593801612034, 0.11589813759201206, 0.18986598530318588, 0.07568126631667838, 0.26816491037607193, 0.08626706781797111, 0.06534087820909917, 0.1827425995725207, 0.13400533120147884, 0.11103113312856294, 0.08383016654988751, 0.10363948327722028, 0.16218617762206122, 0.12174925213912502, 0.11090858228271827, 0.27428703499026597, 0.1272386810160242, 0.20055037370184436, 0.13147615129128098, 0.17117996845627204, 0.09495824793702923, 0.14635437168180943, 0.1014844719611574, 0.21647582383593544, 0.16182792809559032, 0.13866806693840772, 0.09502702276222408, 0.09310128312790766, 0.1972429925808683, 0.14103502820944414, 0.4123506374889985, 1.8865615990944207, 7.0958594139665365, 24.308445118367672, 36.54714949429035, 48.80307264626026, 58.213271498680115, 64.32728782296181, 48.461303785443306, 45.7704021781683, 55.32025873661041, 40.95158815383911, 35.86888208985329, 40.7112168520689, 35.17071895301342, 38.165410459041595, 35.44959358870983, 41.58117637038231, 31.91475346684456, 30.422094762325287, 31.031053885817528, 26.462507732212543, 23.19416631013155, 25.43204292654991, 18.107358366250992, 16.368662863969803, 11.355154886841774, 9.175483547151089, 8.219744581729174, 6.385744968429208, 5.977113945409656, 4.926752457395196, 5.000697914510965, 3.8861001608893275, 4.8830443527549505, 4.6948048286139965, 5.012186598032713, 5.52502560429275, 5.766538269817829, 7.1275948360562325, 7.865956490859389, 10.78653059899807, 12.004880122840405, 16.422046199440956, 18.931794427335262, 23.569538667798042, 25.417715795338154, 38.02345767617226, 29.045793414115906, 25.098700113594532, 32.05366261303425, 33.78931827843189, 30.383882112801075, 32.1375697106123, 41.46448463201523, 40.398809015750885, 46.035905331373215, 38.430358842015266, 34.231302961707115, 24.281605258584023, 13.840998597443104, 6.919100023806095, 2.0208270382136106, 0.26418744411785156, 0.2140729277743958, 0.1681443172856234, 0.10552603009273298, 0.13876181503292173, 0.17313395423116162, 0.13496633822796866, 0.15961907396558672, 0.14580737915821373, 0.10777060379041359, 0.1386273675598204, 0.11123598073027097, 0.14619807538110763, 0.0880511685681995, 0.1359984281589277, 0.1030410302337259, 0.10205697210039943, 0.1549431576859206, 0.10526463825954124, 0.13881600665627047, 0.14326484058983624, 0.19422420300543308, 0.16218221455346793, 0.12092402845155448, 0.14324740011943504, 0.16099123080493882, 0.17118485178798437, 0.16997570026433095, 0.09906798717565835, 0.11298684068606235, 0.10684707522159442, 0.11315089985146187, 0.15886690729530528, 0.12907004915177822, 0.18747604714008048, 0.1531456908560358, 0.07115821761544794, 0.10614548591547646, 0.16558853880269453, 0.17208746663527563, 0.11272271774942055, 0.1319445503759198, 0.17840364802395925, 0.19234124076319858, 0.17011526855640113, 0.27448848355561495, 0.09197401275741868, 0.18473130301572382, 0.10095446719788015, 0.10767887433758005, 0.1671866053948179, 0.07978992201969959, 0.15047937689814717], [0.002241190663880843, 0.04442469646164682, 0.057789191632764414, 0.021134298949618824, 0.034609196009114385, 0.05110450794745702, 0.059242736097075976, 0.017146622594736982, 0.09012670328957029, 0.013017625551583478, 0.05915378969802987, 0.0834905968804378, 0.052258191353757866, 0.03942145223845728, 0.01004615995043423, 0.08072821932728402, 0.03642037401732523, 0.02607043817988597, 0.01993312922422774, 0.0014290588092080725, 0.061927395945531316, 0.0659349377383478, 0.059309718635631725, 0.06336817546980456, 0.0061576804455398815, 0.004017096016468713, 0.027811659492726903, 0.022920845076441765, 0.08479190830257721, 0.024922432203311473, 0.03909107035724446, 0.04070689654326998, 0.018308269245608244, 0.03491503135592211, 0.07640737618203275, 0.053631825066986494, 0.03368842451891396, 0.04718496260466054, 0.05178412226086948, 0.031248647428583354, 0.11478121276013553, 0.03191970849002246, 0.04149067870457657, 0.05140361943631433, 0.05702690948965028, 0.07855074320104904, 0.05940068367635831, 0.04669092231779359, 0.06026129667588975, 0.03967132965044584, 0.02020301308220951, 0.02539237309974851, 0.04764089360833168, 0.03820097554125823, 0.012061350644216873, 0.029478753240255173, 0.012517058075900422, 0.03553124770405702, 0.006255547459659283, 0.13718941190745682, 0.006924954923306359, 0.050062547452398576, 0.02766405374131864, 1.9294253177940845, 8.538153246045113, 17.019100561738014, 31.57303210347891, 40.85475035011768, 38.225359842181206, 40.98277308046818, 50.20129881799221, 42.523499205708504, 32.19072885811329, 27.929645106196404, 22.07832768559456, 19.11290980875492, 19.441014602780342, 21.783106327056885, 26.13778855651617, 35.033812299370766, 28.29068463295698, 22.725854739546776, 25.810305029153824, 19.782601073384285, 24.173909537494183, 20.927225053310394, 19.748917780816555, 17.91189305484295, 14.865320082753897, 13.575741481035948, 15.538713298738003, 14.660739060491323, 13.160736300051212, 11.370036788284779, 9.61519405245781, 13.058498036116362, 10.629193391650915, 11.204347629100084, 17.28322058916092, 16.691579036414623, 14.031424429267645, 19.58148166537285, 24.44478180259466, 25.004212483763695, 23.616933524608612, 22.656643353402615, 23.527539521455765, 16.042535863816738, 25.331614315509796, 24.26989048719406, 21.99649717658758, 27.469696886837482, 32.313960045576096, 33.4039581567049, 33.84980723261833, 28.215422071516514, 22.11224466562271, 16.958301924169064, 6.192371919751167, 3.2663313299417496, 1.1338250781409442, 0.10285942669725046, 0.03830996734905057, 0.048848390142666176, 0.09164861810859293, 0.06905884511070326, 0.05313825233315583, 0.09197707782732323, 0.06090443072025664, 0.018745338566077407, 0.029715134696743917, 0.044363380220602266, 0.07129645746317692, 0.05603060963039752, 0.060472600962384604, 0.07542839433881454, 0.05426209398137871, 0.028159723042335827, 0.021958973447908647, 0.04660282938857563, 0.026199831627309322, 0.009779248393897433, 0.011870967500726692, 0.012790722248610109, 0.02013497483858373, 0.016149934963323176, 0.01634994005144108, 0.02256908377603395, 0.03763386339414865, 0.0684063414519187, 0.03477507343632169, 0.11785124021116644, 0.10422760562505573, 0.05203994798648637, 0.02669670691830106, 0.049156982568092644, 0.03899758943589404, 0.0621597178542288, 0.0756206180085428, 0.03432575496844947, 0.07998650951776654, 0.016901162816793658, 0.04243361072440166, 0.04912248012260534, 0.06402341765351593, 0.06640682491706684, 0.026763567002490163, 0.02696156458114274, 0.06055853053112514, 0.036122665187576786, 0.04200430426863022, 0.014999568029452348, 0.07325865881284699, 0.06996932672336698, 0.07015974697424099, 0.023185806639958173, 0.03653701365692541, 0.07944657481857575, 0.033387591247446835, 0.03347258942085318, 0.03635628956544679, 0.009590265126462327, 0.07148414661060087, 0.08762097524595447, 0.015862820291658863, 0.021639298902300652, 0.07137828666600399, 0.05279982557112817, 0.02576865124865435, 0.049063030382967554, 0.011964042096224148, 0.08512965228874236, 0.02935690186859574, 0.0314767724921694, 0.02813149731082376, 0.028657390575972386, 0.034097848838428035, 0.05557300508371554, 0.07330439737415873, 0.03743735753232613, 0.03573720852728002, 0.06138464479590766, 0.05745092814322561, 0.029040097579127178, 0.04395693933474831, 0.035832682115142234, 0.02331244857487036, 0.07899098520283587, 0.03568991145584732, 0.0539291887980653, 0.0970479057286866, 0.045587474887724966, 0.045369676809059456, 0.05335097412171308, 0.04083687628735788, 0.03614453256886918, 0.07313831956707872, 0.02201215389504796, 0.02900544484873535, 0.047595181022188626, 0.030182355621946044, 0.027611548648565076, 0.020989266595279332, 0.050615024447324686, 0.02425311518891249, 0.011767218966269866, 0.0357280504249502, 0.04590012686094269, 0.030027410030015744, 0.04185560013866052, 0.04451689346751664, 0.056305597609025426, 0.07624486810527742, 0.05877645955479238, 0.04506748911808245, 0.055868899362394586, 0.04636632918845862, 0.03234599069401156, 0.13762969843810424, 3.0200876807793975, 11.575885992497206, 21.525746136903763, 39.212531670928, 48.67839753627777, 43.90078090131283, 46.83549262583256, 54.46639135479927, 46.398858055472374, 36.01710073649883, 29.12187483161688, 24.04850486665964, 23.142069205641747, 22.037096098065376, 25.063122622668743, 23.11358403414488, 30.364554449915886, 35.350521504879, 25.585467293858528, 29.86537143588066, 31.914612874388695, 31.798489205539227, 27.350341491401196, 20.77533010393381, 21.237288415431976, 23.2351566106081, 18.570036739110947, 19.773948937654495, 16.81231375783682, 17.414064668118954, 16.994662173092365, 12.592346649616957, 16.827778927981853, 16.144592687487602, 13.328427001833916, 20.895943231880665, 19.918183498084545, 19.731628708541393, 26.28617439419031, 28.010348975658417, 32.34776683151722, 27.811701335012913, 27.329573705792427, 26.702290065586567, 25.441090241074562, 29.26648747175932, 24.38962586224079, 24.430336877703667, 29.25715707242489, 32.60570839047432, 37.18261979520321, 39.72994990646839, 34.874733835458755, 29.132128581404686, 21.949089020490646, 10.239659193903208, 5.64438764937222, 2.0842636842280626, 0.2545549313072115, 0.012100441417715047, 0.02115527389833005, 0.07791565774823539, 0.03507494933728594, 0.06515189772471786, 0.05845005558512639, 0.03456619968346786, 0.03797260927967727, 0.06317869032500312, 0.054495673830388114, 0.028247704649402294, 0.071490625559818, 0.060761756540159695, 0.02009011572226882, 0.012528963052318431, 0.023779344810463954, 0.047222044013324194, 0.014460501643043244, 0.07374109933152795, 0.051416696078376845, 0.03400694316951558, 0.007598613965456025, 0.030107122256595176, 0.051912873750552535, 0.09085544035769999, 0.05556963573326357, 0.017477783731010277, 0.0377206315897638, 0.04462932512979023, 0.05135862302267924, 0.020286473154556006, 0.04380127014883328, 0.10142368264496326, 0.07314888032851741, 0.046689812807017006, 0.04526162752881646, 0.007688018640692462, 0.09919428586727008, 0.020791367351193912, 0.043649289436871186, 0.0316547580587212, 0.012478263233788311, 0.08628667535958812, 0.10288460776791908, 0.032873075106181204, 0.020370406346046366, 0.013416951096587582, 0.03589058076613583, 0.03213483112631366, 0.037363113078754395, 0.016524316924915183, 0.04939757571264636, 0.012695445329882205, 0.01196781962789828, 0.14983409433625638, 0.16243893827777356, 0.10984642794937827, 0.11019286248483695, 0.11980207927990705, 0.11521925058332272, 0.31995627970900387, 0.20800429716473445, 0.17154845962068066, 0.11055129754822701, 0.16150732029927894, 0.3008108289213851, 0.12226867387653328, 0.14815756789175794, 0.1010120430146344, 0.16357429063646123, 0.1442192870308645, 0.07676099470700137, 0.12052932463120669, 0.13268852373585105, 0.10831814550329, 0.11624483930063434, 0.22600771626457572, 0.1441564568085596, 0.13668881845660508, 0.11314734496409073, 0.15649201988708228, 0.04947567191265989, 0.18489781126845628, 0.12640438828384504, 0.1396078782272525, 0.18717420083703473, 0.13672494620550424, 0.16084725415566936, 0.24691361555596814, 0.186663692293223, 0.1187165844021365, 0.14835114969173446, 0.13624731480376795, 0.135729503526818, 0.16552217595744878, 0.16379246721044183, 0.10602752154227346, 0.13617168995551765, 0.10760930541437119, 0.20405047573149204, 0.1549208041979, 0.15296993544325233, 0.10873914361582138, 0.13600963458884507, 0.1583107715123333, 0.18783208506647497, 0.11261021558311768, 0.20628196536563337, 0.15262954198988155, 0.1702147163450718, 0.20169745199382305, 0.1341632750700228, 0.15975635644281283, 0.20200271217618138, 0.15179450711002573, 0.16099759843200445, 0.2803183801006526, 2.975347456522286, 11.500690877437592, 25.456414818763733, 42.27234028279781, 54.47011895477772, 52.63380669057369, 54.46885742247105, 62.369511276483536, 56.98701269924641, 45.02618171274662, 42.22341790795326, 35.23162968456745, 33.117506727576256, 29.242558255791664, 36.32958836853504, 34.6119399368763, 47.6427099108696, 42.28300251066685, 31.498413607478142, 37.720872312784195, 30.13104747980833, 33.512951508164406, 32.05219589173794, 26.70001018792391, 25.55805366486311, 23.952223733067513, 19.707190319895744, 22.86801651120186, 19.582002237439156, 19.763923175632954, 17.685050927102566, 13.45510745421052, 18.945969566702843, 16.19028713554144, 15.697353836148977, 24.989207088947296, 21.91864315420389, 19.795195497572422, 26.93322267383337, 34.05059985816479, 32.97770082950592, 34.17112939059734, 32.42071531713009, 33.7311851978302, 28.73796623200178, 39.03274051845074, 33.58050048351288, 31.30734845995903, 39.140958711504936, 45.09767107665539, 44.19176548719406, 45.73681578040123, 40.55648535490036, 31.480305679142475, 22.94021263718605, 10.160424895584583, 5.338121708482504, 1.9894751580432057, 0.3479112312197685, 0.08399499012739398, 0.11324754232191481, 0.11043013451853767, 0.1727058834512718, 0.12736328761093318, 0.19970422144979239, 0.29858563269954175, 0.1259292653412558, 0.16125466354424134, 0.10314400322386064, 0.18684256472624838, 0.1351491588866338, 0.18357805005507544, 0.2601097879232839, 0.09554716438287869, 0.17523654765682295, 0.15510439669014886, 0.08204879690310918, 0.09350513020763174, 0.22989312652498484, 0.15720304189017043, 0.14714299264596775, 0.1305963352206163, 0.1102666393853724, 0.1391063496703282, 0.13105320133036003, 0.19107920379610732, 0.11316138639813289, 0.21026483445893973, 0.2559322683373466, 0.2716376568423584, 0.10130795955774374, 0.14191708556609228, 0.11955708148889244, 0.11183259324752726, 0.1113811373943463, 0.12411203511874191, 0.23142086720326915, 0.1925487897824496, 0.10752006215625443, 0.12376367842080072, 0.16655986168188974, 0.2741944446461275, 0.31803762016352266, 0.11047159830923192, 0.17655611591180786, 0.1534992500091903, 0.12934407975990325, 0.16974747501080856, 0.12121551437303424, 0.14423142856685445, 0.20518728269962594, 0.1705628726631403, 0.21273801190545782], [0.0458954773057485, 0.025404579573660158, 0.03440537257120013, 0.05728287993406411, 0.050837561138905585, 0.015086679468367947, 0.06585845942026936, 0.005221961173447198, 0.028789233110728674, 0.051964939120807685, 0.0479066047410015, 0.03424142843869049, 0.020283730918890797, 0.02960521149361739, 0.0285607815021649, 0.07366035366430879, 0.027826255682157353, 0.031055510917212814, 0.0055483554024249315, 0.028003385923511814, 0.011981077168456977, 0.05094955122331157, 0.04665426764404401, 0.07169387754402123, 0.03303152363514528, 0.03368302910530474, 0.022301162898656912, 0.08061188767896965, 0.012224148158566095, 0.03136372113658581, 0.04301119457522873, 0.03147471303236671, 0.03761176223633811, 0.026258312864229083, 0.03224358173611108, 0.03644677221018355, 0.0838381149515044, 0.02425506703730207, 0.04830079276871402, 0.027547594072530046, 0.042105548054678366, 0.056137144929380156, 0.0673775169707369, 0.07356973001151346, 0.03666307486128062, 0.06551716054673307, 0.05237060075160116, 0.05153616330062505, 0.035832500288961455, 0.01098320117307594, 0.06407489301636815, 0.0641425843059551, 0.060416587366489694, 0.029086051363265142, 0.0022271496936809854, 0.05268618049740326, 0.046613256563432515, 0.03715483675478026, 0.04621870117262006, 0.026721301692305133, 0.06524467360577546, 0.05161231507372577, 0.05612501823634375, 0.04492793195822742, 0.7929091528058052, 3.3905274281278253, 10.664468798786402, 24.92468275129795, 34.45766061544418, 37.18809150159359, 37.90629856288433, 43.863193318247795, 40.029681622982025, 43.2462964206934, 37.446371242403984, 33.75669322907925, 26.09293196350336, 26.191369481384754, 29.229308366775513, 25.682527385652065, 21.980766020715237, 31.347451508045197, 21.127911284565926, 24.428687766194344, 18.75517800450325, 18.08685466647148, 21.60703707486391, 21.53457686305046, 14.539450518786907, 17.643332965672016, 17.507731541991234, 16.00637700408697, 21.455575302243233, 18.906550481915474, 22.692152447998524, 18.93951751291752, 18.302633687853813, 22.81166173517704, 51.26962289214134, 27.13083676993847, 20.061181224882603, 24.563654623925686, 25.36808855831623, 24.131595008075237, 24.292877353727818, 29.43539220839739, 25.576435178518295, 18.450479954481125, 24.339791536331177, 27.813314348459244, 31.276938691735268, 38.33948291838169, 35.56612953543663, 29.161027930676937, 24.317596927285194, 10.434811022132635, 4.664194146171212, 1.795408884063363, 0.3654067392926663, 0.11003288513165899, 0.05249693655059673, 0.03205495006113779, 0.01734378340188414, 0.02212946146755712, 0.061770361207891256, 0.06538071669638157, 0.0055090382738853805, 0.025735560739121865, 0.02438339921354782, 0.024324845617229585, 0.05526992681552656, 0.06831895356299356, 0.01972802187083289, 0.03205840846931096, 0.027764327169279568, 0.05538465171412099, 0.014154453856463078, 0.08794668159680441, 0.015363185138994595, 0.0823876986396499, 0.02943732284620637, 0.06432036578189582, 0.07763821326079778, 0.013400902153080096, 0.04229033169394825, 0.07855553005356342, 0.023325239490077365, 0.0365967936522793, 0.07891204295447096, 0.05096046079415828, 0.04690556255809497, 0.004066251240146812, 0.0092511435286724, 0.03625867117079906, 0.09781610278878361, 0.03265769642894156, 0.03902495613147039, 0.026121499795408454, 0.04781971780175809, 0.05318478499248158, 0.040047186630545184, 0.022715661652910057, 0.048715464072301984, 0.03941219394619111, 0.029811539679940324, 0.0619980892224703, 0.07866820291383192, 0.06169738953758497, 0.03411544887057971, 0.04216832632664591, 0.015508544038311811, 0.027035751518269535, 0.05735511316743214, 0.06376041535986587, 0.01376870497551863, 0.02662323800905142, 0.07562629543826915, 0.03510997870762367, 0.042338411731179804, 0.02738734026934253, 0.02520137953979429, 0.013246080870885635, 0.038534099658136256, 0.03939261980121955, 0.0659247554722242, 0.03656161956314463, 0.051325167005416006, 0.02518433982913848, 0.047750905869179405, 0.03813110233750194, 0.02721094660955714, 0.055306908034253865, 0.07115275540854782, 0.04085122200194746, 0.03698730062751565, 0.016725991845305543, 0.03210159033187665, 0.019009257412108127, 0.08027429212233983, 0.06577798834769055, 0.07001124322414398, 0.09255771190510131, 0.029120067702024244, 0.04707569249148946, 0.05188943301618565, 0.03839499891910236, 0.020505798202066217, 0.06752791319740936, 0.05934832886850927, 0.056596987051307224, 0.03265500614361372, 0.006639963257839554, 0.02212416995462263, 0.022012816261849366, 0.018010501044045668, 0.014944370796001749, 0.03874915921187494, 0.014847686579742003, 0.019468470563879237, 0.04225968470564112, 0.033723416781867854, 0.034904652420664206, 0.09875176547211595, 0.007100698740032385, 0.04706907624495216, 0.021631317104038317, 0.058876705152215436, 0.04351366565970238, 0.10497608382138424, 0.028928150168212596, 0.01836166306020459, 0.05323775578290224, 0.044673853990389034, 0.1038604651694186, 0.014734000687894877, 0.02103176939272089, 0.024200207481044345, 0.019884429493686184, 0.049285811983281747, 0.0316839281731518, 1.0056128329597414, 4.5839177537709475, 14.666562248021364, 31.419716030359268, 39.38201017677784, 46.29917800426483, 46.47345945239067, 49.99493949115276, 43.29398386180401, 45.79709954559803, 39.40181091427803, 33.759334087371826, 26.681759767234325, 27.76492964476347, 31.55656948685646, 28.32622602581978, 24.77426402270794, 26.973521411418915, 27.45749954134226, 20.535475574433804, 23.165510147809982, 26.068615168333054, 28.05350136011839, 27.352499775588512, 21.54809083789587, 23.77175811678171, 25.97616232931614, 25.114541463553905, 27.220891937613487, 22.817788906395435, 26.737061999738216, 27.85004697740078, 22.646551094949245, 26.657944545149803, 54.567864909768105, 32.24314324557781, 22.64474429190159, 28.498430885374546, 33.30846548080444, 26.949852481484413, 28.73006645590067, 31.93732425570488, 28.827658519148827, 20.883527398109436, 27.95130394399166, 29.339407458901405, 31.871986761689186, 39.9835254997015, 42.88869760930538, 34.651659205555916, 29.914081022143364, 15.784289371222258, 7.991661820560694, 3.909529228694737, 1.0995416552759707, 0.279195006005466, 0.04452860084711574, 0.03955180676712189, 0.011512695709825493, 0.01742036190989893, 0.010122494477400323, 0.029035403495072387, 0.000535381159352255, 0.04456076923815999, 0.046663874745718203, 0.028911409171996638, 0.05500018582097255, 0.1005805360910017, 0.08237579459091648, 0.02582915112725459, 0.06449864449677989, 0.008810755880404031, 0.020254314040357713, 0.06554841238539666, 0.010601833746477496, 0.03220042213797569, 0.07712524078669958, 0.0716107124753762, 0.04742817553051282, 0.03201543811883312, 0.035063349569099955, 0.013587279554485576, 0.03964535819250159, 0.03842596503091045, 0.055293193145189434, 0.018997896986547858, 0.010482795114512555, 0.03554238734068349, 0.08969291797257029, 0.022844769373477902, 0.028892137452203315, 0.018498791541787796, 0.04611435149854515, 0.011567564542929176, 0.06047119459253736, 0.08296010972117074, 0.02467651414917782, 0.051619380319607444, 0.02488957547029713, 0.0371293996431632, 0.10408913571154699, 0.07570442874566652, 0.06130528694484383, 0.05363412943552248, 0.028590339388756547, 0.02522792430681875, 0.019009160932910163, 0.02966160544019658, 0.0440714304568246, 0.08491824410157278, 0.042116149634239264, 0.0710035688825883, 0.17171496787341312, 0.12044909104588442, 0.18593190499814227, 0.16955745551967993, 0.1279209670610726, 0.13979411276523024, 0.10743093022028916, 0.1461096410639584, 0.11465200484963134, 0.09585019070073031, 0.18387519114185125, 0.16381790803279728, 0.16947049065493047, 0.07490995223633945, 0.09543727457639761, 0.14517849805997685, 0.15717798698460683, 0.12437765719369054, 0.20649888028856367, 0.10774209789815359, 0.2114896452985704, 0.10817767179105431, 0.21868120471481234, 0.12979529070435092, 0.13587063032900915, 0.18259605509229004, 0.14651141013018787, 0.16836274618981406, 0.1546047383453697, 0.1062032398476731, 0.09395801840582862, 0.16400334105128422, 0.10982113555655815, 0.09266246604966, 0.13358196563785896, 0.25223013886716217, 0.14436212077271193, 0.181058295420371, 0.14317487744847313, 0.08699267302290536, 0.19227366079576313, 0.10105410794494674, 0.1067734022217337, 0.14704312925459817, 0.102362002216978, 0.2003579051233828, 0.21065955312224105, 0.08940921718021855, 0.12932301760884002, 0.12789715896360576, 0.1767982341698371, 0.26611106120981276, 0.2940574038075283, 0.31047854921780527, 0.11496950304717757, 0.21853653044672683, 0.11083244535257109, 0.16445291927084327, 0.15693894121795893, 0.0981278567633126, 0.15438961941981688, 0.17128628853242844, 0.12314903913647868, 0.14070685050683096, 1.0201772139407694, 4.612060943618417, 15.849169939756393, 31.742833591997623, 45.02518616616726, 52.47445844113827, 53.37645784020424, 59.60198678076267, 54.53710176050663, 55.24490498006344, 52.574142292141914, 46.5846186876297, 36.382105350494385, 43.462611213326454, 40.701675564050674, 38.64121712744236, 34.24257315695286, 42.45105229318142, 39.17363315820694, 33.59213545918465, 31.705095916986465, 33.22786420583725, 34.08323630690575, 32.67423391342163, 25.56819722056389, 26.33939053863287, 27.80338168144226, 24.48745921254158, 32.01748475432396, 29.190934225916862, 35.713960602879524, 29.322101287543774, 28.552460186183453, 30.457945838570595, 64.39634531736374, 34.87628415226936, 28.861769288778305, 33.388910964131355, 42.07866467535496, 35.77151991426945, 36.40516251325607, 39.99414972960949, 35.10634660720825, 27.885996848344803, 35.046537816524506, 39.1843181848526, 41.48573309183121, 51.015199944376945, 49.51399929821491, 40.71277476847172, 32.77279682457447, 18.132085539400578, 8.648000601679087, 3.3026718674227595, 1.0595962987281382, 0.2979796542786062, 0.1505309116328135, 0.11355534064932726, 0.15085119288414717, 0.12247973325429484, 0.16382749658077955, 0.19859935651766136, 0.13037660013651475, 0.1022454330814071, 0.12428303336491808, 0.13353351823752746, 0.10049735617940314, 0.19841295870719478, 0.12282865398447029, 0.20872606546618044, 0.13713462656596676, 0.13621011836221442, 0.08546150362235494, 0.13071853725705296, 0.10954546480206773, 0.1554687466705218, 0.29010629863478243, 0.1594439271138981, 0.16816128278151155, 0.19263173220679164, 0.15566234331345186, 0.22934883541893214, 0.07753710306133144, 0.12144680469646119, 0.21836583648109809, 0.1266548631247133, 0.12036797430482693, 0.20811722235521302, 0.13681640848517418, 0.16697806189768016, 0.2308139982051216, 0.13706625992199406, 0.16206740430789068, 0.07917873372207396, 0.150942150503397, 0.12124809465603903, 0.18940595764433965, 0.11219028616324067, 0.17605724424356595, 0.1674387723323889, 0.19687337335199118, 0.19012362929061055, 0.17276322178076953, 0.15328790119383484, 0.15527320560067892, 0.14884976902976632, 0.08163245205651037, 0.10291967424564064, 0.20741813408676535, 0.1540891089825891, 0.09242108251783065, 0.1955103746149689], [0.012156734246673295, 0.015622405262547545, 0.022602612152695656, 0.07113307365216315, 0.007127614117052872, 0.06359139122650959, 0.03240090962208342, 0.11257652950007468, 0.01588740764418617, 0.036317901976872236, 0.04477438902540598, 0.019569135474739596, 0.04084337007952854, 0.0246689275445533, 0.02861091728846077, 0.013378105231822701, 0.013027747518208344, 0.08846756536513567, 0.030858980935590807, 0.047183418937493116, 0.014485329265880864, 0.08790315463556908, 0.06227963778655976, 0.008738644173718058, 0.052343430725159124, 0.05664728239935357, 0.03334896617161576, 0.04953954114171211, 0.018032579937425908, 0.012281066246941919, 0.016249139698629733, 0.04270402707334142, 0.030675826310471166, 0.009355235306429677, 0.010852829018404009, 0.1081851749040652, 0.04154806898441166, 0.012907245927635813, 0.0667900922417175, 0.0743824930395931, 0.014967019287723815, 0.07616982955369167, 0.09752578203915618, 0.07122749710106291, 0.02952830272988649, 0.03980081957706716, 0.038954685878707096, 0.046277623987407424, 0.023382857980323024, 0.061378555474220775, 0.07327461498789489, 0.008414464791712817, 0.05282428304781206, 0.017020251543726772, 0.05832140799611807, 0.007369835811914527, 0.012432722269295482, 0.025582566995581146, 0.07135326144634746, 0.023191051768662874, 0.051564895547926426, 0.024424939074378926, 0.011713321418937994, 0.009358074948977446, 0.03881134376570117, 0.04153440233494621, 0.3843361360486597, 4.55573134124279, 12.294207997620106, 17.789678312838078, 30.698497630655766, 36.69969230890274, 45.212174132466316, 46.9304533302784, 48.039344027638435, 50.26017665863037, 41.20793379843235, 44.50971722602844, 36.306747794151306, 27.332588844001293, 26.905468963086605, 29.96685639023781, 30.317281186580658, 38.59972335398197, 22.413785085082054, 18.580075800418854, 25.63272725790739, 15.772725641727448, 23.161431066691875, 23.896820805966854, 19.99573353677988, 18.751855082809925, 29.618793167173862, 27.343608252704144, 25.960695259273052, 36.01434588432312, 32.49242886900902, 28.49412191659212, 84.85991165041924, 41.190374940633774, 19.296346865594387, 25.175305902957916, 21.33487857878208, 36.01493485271931, 32.2392750531435, 35.37991672754288, 32.36998803913593, 38.22448968887329, 36.741406470537186, 34.54399958252907, 34.575724080204964, 22.586265429854393, 17.51312915235758, 10.858496837317944, 6.532820826396346, 1.7690453049726784, 0.2678000705782324, 0.022879622483742423, 0.06373095951857977, 0.023791534586052876, 0.044392034542397596, 0.03740510750503745, 0.021506183584278915, 0.013919039975007763, 0.021364828571677208, 0.03120020373899024, 0.04140231118071824, 0.019626503490144387, 0.061999647732591256, 0.0559768113453174, 0.07371159153990448, 0.026811997704498935, 0.1161855565442238, 0.04611299707903527, 0.0349464835744584, 0.051597761557786725, 0.04500764604017604, 0.0514543081226293, 0.02450566247716779, 0.02897423939430155, 0.026744107890408486, 0.05329394378350116, 0.0102352396970673, 0.050587731966516, 0.018085491356032435, 0.00894423577847192, 0.023767848942952696, 0.08703326850081794, 0.010456822728883708, 0.07046318147331476, 0.01946265583683271, 0.016717039688955992, 0.0939699298760388, 0.06725817220285535, 0.015703674143878743, 0.028607989515876397, 0.057081665145233274, 0.05715860359487124, 0.023972972994670272, 0.006649530005233828, 0.030966115518822335, 0.07096797548001632, 0.01654793206398608, 0.02926571232819697, 0.019528671728039626, 0.018853745932574384, 0.04384586580272298, 0.05930976687523071, 0.02348382717173081, 0.09444215102121234, 0.03411720404983498, 0.022145374969113618, 0.028929517575306818, 0.03400436420633923, 0.006327640148811042, 0.03271290479460731, 0.031498417229158804, 0.027690687566064298, 0.016448372953163926, 0.035036691624554805, 0.04099638608749956, 0.02232411381555721, 0.026876273259404115, 0.025058202554646414, 0.03698827655171044, 0.07416498439852148, 0.046476189309032634, 0.012491566230892204, 0.05070954437542241, 0.013005264154344331, 0.014939388202037662, 0.041931792729883455, 0.028890998255519662, 0.005768005603385973, 0.0781521579483524, 0.054277786694001406, 0.004732500865429756, 0.025474671710981056, 0.041305045306216925, 0.030426826488110237, 0.06584857401321642, 0.044938518694834784, 0.04031800002849195, 0.021339877566788346, 0.04084679138031788, 0.007911903721833369, 0.02603700999316061, 0.044072836826671846, 0.013299548900249647, 0.03309531122795306, 0.022268619723035954, 0.028435416061256547, 0.04198669681500178, 0.015762203620397486, 0.06496440153568983, 0.09043826430570334, 0.018635767883097287, 0.07720645400695503, 0.04706149520643521, 0.062132789025781676, 0.05392498082073871, 0.03563373458746355, 0.011154674393765163, 0.03958348905143794, 0.04372768620669376, 0.03080518450587988, 0.036596901263692416, 0.03683244409330655, 0.04012875237094704, 0.04238301480654627, 0.04380879552627448, 0.04666075030399952, 0.012829662737203762, 0.05787683556263801, 0.06896916398545727, 0.02998485157149844, 0.03784054038987961, 0.004444772994247614, 0.0406892519822577, 0.05051557665865403, 0.042296057363273576, 0.05664406518917531, 0.99008520366624, 6.720242919400334, 17.508643493056297, 23.5566383600235, 36.67142562568188, 44.3467515707016, 51.94675795733929, 53.32452602684498, 52.9961172491312, 52.98876844346523, 44.48523513972759, 47.262886092066765, 40.275232046842575, 31.285911910235882, 27.892017625272274, 31.5650487318635, 33.064605966210365, 33.72585788369179, 20.626218505203724, 21.761700175702572, 27.074014618992805, 18.052014335989952, 23.78094032406807, 22.42387354373932, 21.749020256102085, 18.15090212970972, 30.380118414759636, 29.380990527570248, 28.361828215420246, 31.94203220307827, 29.80264250189066, 29.595437720417976, 84.83579814434052, 41.2790659815073, 16.835359521210194, 23.901424258947372, 23.89983594417572, 36.345095336437225, 32.117278799414635, 37.72643141448498, 33.79382483661175, 35.67516468465328, 38.60857307910919, 40.52287615835667, 42.60162681341171, 31.466333828866482, 24.91050001233816, 16.57353837043047, 9.726240243762732, 2.898988416418433, 0.690421408507973, 0.09445706076803617, 0.04502482304815203, 0.03677517997857649, 0.12077133898856118, 0.05725326082028914, 0.02183237418648787, 0.04391684851725586, 0.03265074250521138, 0.06530063896207139, 0.06358469705446623, 0.012867857367382385, 0.023861789995862637, 0.08539578644558787, 0.057208082580473274, 0.04266653377271723, 0.023819062698748894, 0.011010319249180611, 0.02889018189307535, 0.03391898382687941, 0.04555467938189395, 0.015113783629203681, 0.059903106521232985, 0.04446944425581023, 0.031213391703204252, 0.03967434648075141, 0.05089549318654463, 0.06522369309095666, 0.021022433174948674, 0.026457479325472377, 0.04407394633744843, 0.06143204947875347, 0.026249125075992197, 0.05786325426015537, 0.05122101400047541, 0.025482644232397433, 0.05857192736584693, 0.023139112563512754, 0.04439448362973053, 0.048873578634811565, 0.028788515082851518, 0.0695022931904532, 0.0962484345654957, 0.03382347684237175, 0.015601504528603982, 0.018985202550538816, 0.04743746350868605, 0.024159777130989823, 0.055431214059353806, 0.04944275766320061, 0.12449046364054084, 0.058649530037655495, 0.005702949865735718, 0.03406530937354546, 0.01282410590647487, 0.026338166098867077, 0.012646856921492144, 0.0255089663551189, 0.05082433235656936, 0.017831261247920338, 0.0842269929125905, 0.10329197262763046, 0.07594297727337107, 0.15705335070379078, 0.21131494373548776, 0.16244913538685068, 0.1223646780999843, 0.18078042048728094, 0.11951227803365327, 0.14487392065348104, 0.10523603588808328, 0.12953245168318972, 0.11899114193511195, 0.10261284071020782, 0.09010792695335113, 0.13689702056581154, 0.18797016906319186, 0.27789425861556083, 0.15334608557168394, 0.15956967661622912, 0.065193428308703, 0.13835590478265658, 0.12098383813281544, 0.08154150185873732, 0.10544947755988687, 0.11647323524812236, 0.09941347176209092, 0.11579741330933757, 0.09395053755724803, 0.13903940794989467, 0.29861154849641025, 0.12940860207891092, 0.09433231316506863, 0.15864628163399175, 0.12461723730666563, 0.22340497467666864, 0.12116107041947544, 0.12137831188738346, 0.19126601720927283, 0.20123929454712197, 0.10628476476995274, 0.1648604028741829, 0.2471800020430237, 0.20625658391509205, 0.1379775578971021, 0.12882479903055355, 0.10285920405294746, 0.09655854097218253, 0.0874017299793195, 0.2115494475583546, 0.13845107780070975, 0.17940014455234632, 0.12587204575538635, 0.09105304459808394, 0.25679310027044266, 0.11693347812979482, 0.14194234827300534, 0.09758569562109187, 0.15335055330069736, 0.1416682286071591, 0.142443134682253, 0.14039822097402066, 0.21905146219069138, 0.13961149990791455, 0.22956008033361286, 0.22905102639924735, 0.9353741363156587, 6.312151467427611, 18.531088829040527, 28.33736702799797, 42.67323017120361, 51.22272960841656, 60.171321630477905, 60.77973358333111, 64.7540657222271, 63.34203489124775, 54.181494042277336, 58.64224947988987, 52.09549717605114, 38.915292620658875, 42.84796379506588, 41.11353546380997, 45.12389346957207, 49.054337963461876, 32.060939222574234, 32.626276686787605, 40.200592651963234, 25.2838546782732, 37.843548730015755, 36.254549995064735, 33.654467314481735, 29.99440871179104, 45.06217338144779, 38.3527822047472, 38.10652121901512, 48.05682688951492, 43.45600716769695, 35.40043942630291, 97.48164877295494, 49.867745116353035, 27.112516053020954, 36.54173098504543, 31.540674939751625, 49.94004763662815, 42.28723548352718, 47.84672476351261, 43.54932636022568, 49.59691844880581, 49.948676973581314, 49.59788739681244, 47.96843223273754, 36.97045437991619, 27.78003193438053, 17.44880810379982, 8.84301658719778, 3.1045312620699406, 0.6238826445769519, 0.23507889825850725, 0.20431742625078186, 0.19740197545615956, 0.1610228166100569, 0.13879540463676676, 0.11568996516871266, 0.11060579345212318, 0.11363884710590355, 0.1360909442882985, 0.09220744788763113, 0.15618716046446934, 0.15027264424134046, 0.18044936325168237, 0.2038385035120882, 0.10501779252081178, 0.1977969316067174, 0.11469548728200607, 0.1380332635017112, 0.1079723343718797, 0.0585229122225428, 0.11631194429355673, 0.07114910404197872, 0.1570290676318109, 0.10394816476036794, 0.0957017982727848, 0.10670402625692077, 0.10422097824630328, 0.11873416588059627, 0.06726888881530613, 0.1428334746742621, 0.14966638380428776, 0.15898403304163367, 0.18717424536589533, 0.10977671059663408, 0.12033019156660885, 0.2002156205708161, 0.09460166082135402, 0.1736071179038845, 0.12563092197524384, 0.1600988130667247, 0.13938575342763215, 0.13002740481169894, 0.08229608793044463, 0.15689181484049186, 0.14334760489873588, 0.05308265062922146, 0.09738728986121714, 0.18107644835254177, 0.10404288506833836, 0.2863053744658828, 0.18161167041398585, 0.08397712663281709, 0.22867780033266172, 0.1383449655259028, 0.1366368681192398, 0.06984978899708949, 0.15088619256857783, 0.1107090558798518, 0.1067377939762082], [0.039232913331943564, 0.04776048328494653, 0.06059121842554305, 0.033935192332137376, 0.02262058696942404, 0.05065724522864912, 0.027411545415816363, 0.0850017654011026, 0.04557789376121946, 0.019083995393884834, 0.02456691934639821, 0.04838515640585683, 0.0050048987486661645, 0.05207492540648673, 0.028713769679598045, 0.05432381840364542, 0.015613056057190988, 0.030321029626065865, 0.028134658859926276, 0.03897086840879638, 0.014619564299209742, 0.028449273813748732, 0.0649829997564666, 0.018623166215547826, 0.010721305607148679, 0.04352454925538041, 0.02345964985579485, 0.02006745238759322, 0.08473698937450536, 0.07698583576711826, 0.03602082397264894, 0.01956238193088211, 0.03171176242176443, 0.016681160559528507, 0.06400525729986839, 0.048222993427771144, 0.07309590582735837, 0.009624916929169558, 0.008661877345730318, 0.04149978485656902, 0.02971474692458287, 0.03147456460283138, 0.02236249954876257, 0.012482898873713566, 0.027544378717720974, 0.012074267724528909, 0.02434689668007195, 0.02326971571164904, 0.08750384949962609, 0.027137403485539835, 0.04764762117702048, 0.05098341171105858, 0.04599645020789467, 0.009239423161488958, 0.0622539112373488, 0.024187193921534345, 0.03338901988172438, 0.08650010960991494, 0.015500314548262395, 0.028999003006902058, 0.012149804442742607, 0.008952897569542984, 0.03613861765188631, 0.032919117948040366, 0.049403160373913124, 0.07767818533466198, 0.08319010870764032, 0.0859549427696038, 0.7464029733091593, 4.491488188505173, 7.888360563665628, 16.56519591808319, 24.81992617249489, 32.74806775152683, 37.53752455115318, 45.112984254956245, 47.09232084453106, 48.66065248847008, 48.95597644150257, 50.313989371061325, 43.39230738580227, 43.68395693600178, 44.91681598126888, 40.378537103533745, 36.442354917526245, 34.34657737612724, 36.377663388848305, 32.43458457291126, 25.359425023198128, 37.345733642578125, 31.54888439923525, 32.151408568024635, 28.94433505833149, 23.480264358222485, 27.148927599191666, 37.73702524602413, 28.65092620253563, 34.80718106031418, 92.47515141963959, 59.89921823143959, 32.44486302137375, 29.68214336782694, 37.59397052228451, 34.62205119431019, 50.3442357480526, 45.89912787079811, 44.95624266564846, 39.85672250390053, 33.34246605634689, 26.166281327605247, 14.267434515058994, 10.443679746240377, 5.539407357573509, 1.6728538228198886, 0.4389671405078843, 0.0422884169529425, 0.07022446967312135, 0.023477828763134312, 0.06539147783769295, 0.031000413873698562, 0.03210734939784743, 0.04453539149835706, 0.062131961531122215, 0.005148115624251659, 0.03155232683639042, 0.027273941959720105, 0.031826383419684134, 0.0370102626766311, 0.07901336837676354, 0.07294128678040579, 0.06951776696951129, 0.027922298868361395, 0.060290804467513226, 0.014294801403593738, 0.03427641328016762, 0.09169862401904538, 0.03881694326992147, 0.01218772447828087, 0.02863197572878562, 0.03905110199411865, 0.007273174787769676, 0.0475974668370327, 0.021250174177112058, 0.02778966965706786, 0.030996239293017425, 0.036858504608972, 0.03175338948494755, 0.061068252398399636, 0.041871237190207466, 0.01023269876895938, 0.05040497810114175, 0.049640469514997676, 0.021346065223042388, 0.028174955623399, 0.04896029488008935, 0.049862709347507916, 0.026087533551617526, 0.0831746646144893, 0.03226835462555755, 0.05427689240605105, 0.0858920680184383, 0.023142224017647095, 0.03679610112158116, 0.022519493468280416, 0.033058066546800546, 0.0854059612902347, 0.0523926573805511, 0.039483451255364344, 0.012621686983038671, 0.0051940874982392415, 0.018581566982902586, 0.012963240042154212, 0.03781448358495254, 0.05475116558955051, 0.034442190517438576, 0.05601376287813764, 0.021307640527084004, 0.05513696734851692, 0.005037291639382602, 0.028554265445563942, 0.06801959345466457, 0.04407999855175149, 0.0488203221175354, 0.10789452018798329, 0.0422977346170228, 0.04154251029831357, 0.01766474000760354, 0.05071189698355738, 0.05169910553377122, 0.08817185662337579, 0.05790156021248549, 0.040715134382480755, 0.03036120207980275, 0.03270611043262761, 0.04794612781552132, 0.026469264630577527, 0.04121288911846932, 0.026615913011482917, 0.060913432971574366, 0.08362702588783577, 0.006321856499198475, 0.01972724261577241, 0.12012086139293388, 0.03607504528190475, 0.032700525771360844, 0.03652239705843385, 0.027523656099219806, 0.025560092908563092, 0.04675718868384138, 0.07328246691031381, 0.015996757538232487, 0.015663980375393294, 0.03293074369139504, 0.03034020115592284, 0.01883866178104654, 0.011789656873588683, 0.06303584174020216, 0.04562250425806269, 0.0650212426262442, 0.012104166999051813, 0.02630643743032124, 0.05627806021948345, 0.03515320880978834, 0.03176232123223599, 0.06894375284900889, 0.044780660173273645, 0.06893135898280889, 0.020914226188324392, 0.004944292186337407, 0.017455046181567013, 0.021369687783590052, 0.051511542551452294, 0.03971375081164297, 0.029147287823434453, 0.008159330191119807, 0.03130076474917587, 0.05776460428023711, 0.016208418055612128, 0.014643447539128829, 0.02916715882747667, 0.060061610711272806, 0.01811277455999516, 0.01249640967216692, 0.07121040544006974, 1.2711702520027757, 6.1366132367402315, 12.396033983677626, 22.104521580040455, 31.479484923183918, 40.496307983994484, 45.70246182382107, 52.948912382125854, 52.5698409229517, 56.11724317073822, 52.80926987528801, 53.34994666278362, 46.51685692369938, 46.41252972185612, 47.23975293338299, 42.998283728957176, 37.48288348317146, 33.51784564554691, 39.37621928751469, 33.89629013836384, 26.43450703471899, 38.003569543361664, 32.77031175792217, 34.107991978526115, 31.63354005664587, 27.427260763943195, 28.524392992258072, 39.55136328935623, 30.252836644649506, 34.06736835837364, 94.95302125811577, 59.56815339624882, 28.50990816950798, 28.333485536277294, 37.29191713035107, 39.555223882198334, 51.13308481872082, 50.57831458747387, 48.87772724032402, 45.24030402302742, 38.746197894215584, 31.2408634275198, 20.2537339925766, 13.920490331947803, 8.819606993347406, 2.8903954150155187, 0.839381905971095, 0.17631000489927828, 0.04059088030771818, 0.06031609314959496, 0.028948381113877986, 0.025133602903224528, 0.018374693318037316, 0.022232276751310565, 0.12166973843704909, 0.02008660536375828, 0.026403319243399892, 0.0024048826981015736, 0.054186840206966735, 0.029448083987517748, 0.04078622841916513, 0.03755282457859721, 0.07911358799901791, 0.030356398528965656, 0.033663135836832225, 0.019784100404649507, 0.027542610550881363, 0.04687347209255677, 0.03957673550758045, 0.021722747842432, 0.03603049786761403, 0.028769026284862775, 0.028046751467627473, 0.08077108577708714, 0.027509861429280136, 0.022111549733381253, 0.06074470198655035, 0.03148161500575952, 0.04911573028948624, 0.04533136714599095, 0.029156432938179933, 0.06118725948908832, 0.0654438734636642, 0.047211750425049104, 0.04420660152391065, 0.05139065040566493, 0.04807067132787779, 0.04895476216915995, 0.007062186377879698, 0.01925895114254672, 0.026809188675542828, 0.03868945343128871, 0.061106498978915624, 0.012320301739237038, 0.03048117952857865, 0.01189660777527024, 0.021925458058831282, 0.08533170199370943, 0.038167449019965716, 0.04884614514594432, 0.036787028366234154, 0.0879683523089625, 0.02809976493153954, 0.026996126398444176, 0.06338597217109054, 0.062047601604717784, 0.05852074515132699, 0.007208678443930694, 0.1268956603598781, 0.2394167662714608, 0.12050044766510837, 0.17423611774574965, 0.1370738446712494, 0.166319984709844, 0.1800196003750898, 0.19210476282751188, 0.25792484579142183, 0.12384216795908287, 0.18825246719643474, 0.10286680364515632, 0.11463611546787433, 0.20960196299711242, 0.13414730405202135, 0.22967944736592472, 0.16448612295789644, 0.07174253274570219, 0.18506323598558083, 0.10781062039313838, 0.12546534882858396, 0.1353166319313459, 0.14215227216482162, 0.14393293677130714, 0.09971700274036266, 0.14576426037820056, 0.1863718798267655, 0.14293396146968007, 0.17644191422732547, 0.16251298977294937, 0.1033545950485859, 0.14751040027476847, 0.12155354037531652, 0.19137604802381247, 0.20271864719688892, 0.1187290673260577, 0.10951583826681599, 0.09786326627363451, 0.09844068685197271, 0.15749898069771007, 0.10116289937286638, 0.11245402318309061, 0.20854845468420535, 0.07339208212215453, 0.1512921621906571, 0.15764718758873641, 0.10167314816499129, 0.16307727433741093, 0.23696252843365073, 0.13761454378254712, 0.18145130714401603, 0.11751271696994081, 0.11812763084890321, 0.16872863983735442, 0.1372236991301179, 0.14070572244236246, 0.16193136863876134, 0.2277738941484131, 0.11338428303133696, 0.12123029053327627, 0.15726340818218887, 0.13902964128647, 0.09221745203831233, 0.19062027451582253, 0.11539056053152308, 0.15921058104140684, 0.20645853714086115, 0.2201117092045024, 1.5279899211600423, 6.401733560487628, 12.30176579207182, 23.838195651769638, 34.469968155026436, 45.88365890085697, 51.69784851372242, 60.04857301712036, 65.31081944704056, 63.59403356909752, 63.89822244644165, 64.73610788583755, 56.59312583506107, 57.83717907965183, 59.28606033325195, 57.685160636901855, 48.44458468258381, 47.8571742027998, 51.36191613972187, 45.11445477604866, 38.55753801763058, 51.0739029943943, 46.24071054160595, 44.4301038980484, 44.979064241051674, 35.65477877855301, 41.941271647810936, 51.36994510889053, 42.58691780269146, 41.331883147358894, 99.08231288194656, 70.45792445540428, 41.73053115606308, 40.63681684434414, 48.992097303271294, 46.760594844818115, 62.52753719687462, 60.75110971927643, 56.99687696993351, 54.86165374517441, 44.4305332750082, 36.06188893318176, 24.074174389243126, 15.529370550066233, 8.12377218157053, 2.5888355216011405, 0.8883644244633615, 0.1898004239774309, 0.14092388417338952, 0.15568998089293018, 0.15752985404105857, 0.08341247841599397, 0.22848261549370363, 0.17624987609451637, 0.1958820124855265, 0.09827350324485451, 0.1816596873686649, 0.09526154142804444, 0.19197239336790517, 0.22359490511007607, 0.12235551257617772, 0.14755013486137614, 0.14633797021815553, 0.12364634487312287, 0.10105644571012817, 0.07747221708996221, 0.10610417055431753, 0.357445246190764, 0.13073231151793152, 0.1430086512118578, 0.09740413661347702, 0.10101511550601572, 0.155508496100083, 0.23187451239209622, 0.11388521787011996, 0.10641991728334688, 0.18804453226039186, 0.136287450150121, 0.12445043219486251, 0.11949675972573459, 0.10353072895668447, 0.09660639465437271, 0.20542600192129612, 0.14494481059955433, 0.14505225874017924, 0.15744165721116588, 0.16672193189151585, 0.1641678306623362, 0.12785549479303882, 0.2895902388263494, 0.10360679909354076, 0.1109883186290972, 0.18031637038802728, 0.15066874329932034, 0.15128984668990597, 0.059642033811542206, 0.11189787997864187, 0.23590939119458199, 0.16278185503324494, 0.09416230939677916, 0.1423512419569306, 0.13328001543413848, 0.12579754897160456, 0.1204558223253116, 0.20061896299012005, 0.12632822908926755, 0.1461901789298281, 0.12191371206426993], [0.023524858661403414, 0.04321652828366496, 0.07579499302664772, 0.03773999051190913, 0.04096995820873417, 0.12816491100238636, 0.056100720321410336, 0.07153182959882542, 0.033779063014662825, 0.01448634600819787, 0.05096717351989355, 0.028946878264832776, 0.03415932835196145, 0.036463481665123254, 0.03091911716182949, 0.02778965666948352, 0.03813803028606344, 0.0689086715283338, 0.0075318661311030155, 0.04261743699316867, 0.021348044901969843, 0.11615572962909937, 0.0173815271773492, 0.06970474365516566, 0.025731798050401267, 0.026871484551520552, 0.05126439624291379, 0.010125314638571581, 0.051923419669037685, 0.02309673964191461, 0.05691166137694381, 0.01627462319447659, 0.0457578163332073, 0.05664826945576351, 0.05155930346518289, 0.013222708785178838, 0.03616211033659056, 0.012993857344554272, 0.029495416310965084, 0.02564859030826483, 0.08713584073120728, 0.0299735727821826, 0.11354850546922535, 0.07695000487728976, 0.01686492560111219, 0.02104820239765104, 0.020706172508653253, 0.03466990739980247, 0.04341504907642957, 0.018903738855442498, 0.0037424378297146177, 0.002577677405497525, 0.02104937313561095, 0.022343719501805026, 0.06578569926205091, 0.04485783611016814, 0.03605879595852457, 0.011831387837446528, 0.050129863957408816, 0.039412004698533565, 0.03091952905379003, 0.041450016433373094, 0.1044679649930913, 0.02968056174722733, 0.028144948737462983, 0.033740630897227675, 0.022425296374422032, 0.019391509849810973, 0.07049432198982686, 0.06431760499253869, 0.5903881543781608, 1.7208393104374409, 4.2424452770501375, 8.374027702957392, 15.773965325206518, 18.635376133024693, 25.229088217020035, 31.77890695631504, 37.54355102777481, 41.56519062817097, 45.19579321146011, 53.636428490281105, 47.775991559028625, 56.414524018764496, 46.22218273580074, 50.423434898257256, 49.70748871564865, 49.87531051039696, 50.71198381483555, 43.817804753780365, 48.26164349913597, 40.433736741542816, 47.21786990761757, 45.041688680648804, 39.7205226123333, 40.728901103138924, 38.17497454583645, 41.21219716966152, 59.47549156844616, 53.51403705775738, 44.30873081088066, 45.82513824105263, 37.737105041742325, 43.96628178656101, 38.14058259129524, 33.5519640147686, 23.89067843556404, 18.963705115020275, 14.976077489554882, 5.755754923447967, 3.172391108237207, 0.7652048987802118, 0.1797526646987535, 0.015337578261096496, 0.045335786635405384, 0.046677200007252395, 0.0615461101551773, 0.011362940513208741, 0.031406624693772756, 0.04297058054362424, 0.03519733691064175, 0.011798791783803608, 0.11786327784648165, 0.016562830678594764, 0.04118099532206543, 0.020939898931828793, 0.024368535850953776, 0.039485759334638715, 0.028815998666686937, 0.05244327927357517, 0.08881800007657148, 0.00578697768105485, 0.06439135220716707, 0.035356349471840076, 0.045015612995484844, 0.041297390052932315, 0.023941025392559823, 0.03326966027088929, 0.0616794332745485, 0.06252976381802, 0.02724856236454798, 0.015665230894228444, 0.017147349899460096, 0.03196973666490521, 0.05651591854984872, 0.028922088677063584, 0.011773722035286482, 0.005688117580575636, 0.012533142271422548, 0.05336366484698374, 0.047436984823434614, 0.05494276214449201, 0.03661010036012158, 0.05291050947562326, 0.08261120383394882, 0.016146034977282397, 0.03845176950562745, 0.040535286025260575, 0.01906343790324172, 0.037598837734549306, 0.030510106589645147, 0.024095436638162937, 0.02640709306433564, 0.04897971317404881, 0.06349518662318587, 0.028282457569730468, 0.011324994502501795, 0.024028988445934374, 0.0565674681274686, 0.07265408305102028, 0.019240701731177978, 0.03317210495879408, 0.05636423469695728, 0.005900949299757485, 0.050194701689179055, 0.03686811171064619, 0.0475967580860015, 0.02056986038951436, 0.03402753034606576, 0.04356771256425418, 0.03407684234844055, 0.058564817591104656, 0.026112401064892765, 0.019901871819456574, 0.07087073929142207, 0.061961200772202574, 0.06897490820847452, 0.04583168229146395, 0.038010332646081224, 0.024436162202619016, 0.010864362920983694, 0.09440347770578228, 0.04592124838382006, 0.035006660618819296, 0.05980669411655981, 0.03162802961014677, 0.04434043672517873, 0.06538286892464384, 0.07316841365536675, 0.059902267894358374, 0.06580383735126816, 0.028830741430283524, 0.054608194550382905, 0.014648768737970386, 0.026516886391618755, 0.05395111184043344, 0.02007092749408912, 0.07262145823915489, 0.03963922063121572, 0.02897574409871595, 0.07825412903912365, 0.007556006339655141, 0.06069579074392095, 0.018271727749379352, 0.028688328857242595, 0.05776655612862669, 0.06654039665590972, 0.06977187833399512, 0.10961631764075719, 0.02638566726091085, 0.014571860901924083, 0.07190991673269309, 0.01965712450328283, 0.021935998411208857, 0.01986100174690364, 0.06322858491330408, 0.04232579893141519, 0.011203125504835043, 0.03584617435990367, 0.05594240537902806, 0.02981725050631212, 0.03864905833324883, 0.00857537632327876, 0.01137688825110672, 0.0038930789651203668, 0.04312793069402687, 0.04574242790113203, 0.026335258735343814, 0.08983923238702118, 0.03704151080455631, 0.046511029431712814, 0.09014725335873663, 0.027663432192639448, 0.028084669647796545, 0.07761545159155503, 0.0765862337721046, 0.8980468986555934, 3.0509178014472127, 7.02287245541811, 12.305928468704224, 20.671513974666595, 24.336576908826828, 33.04705090820789, 39.73193719983101, 45.916698127985, 49.00867201387882, 54.054014682769775, 59.5733667165041, 55.16642779111862, 62.739812806248665, 50.11304475367069, 54.96467001736164, 52.294427901506424, 53.58016110956669, 52.136918753385544, 48.97069685161114, 51.10292203724384, 45.38061149418354, 49.37928132712841, 46.936403810977936, 42.94330447912216, 45.51936864852905, 42.66346089541912, 44.6322226524353, 65.42938828468323, 60.48709988594055, 49.609134793281555, 49.99624282121658, 44.0345299243927, 49.719446673989296, 46.21727339923382, 40.91221086680889, 32.75260470807552, 23.91911420971155, 19.7499418258667, 8.93168767914176, 5.526953525841236, 1.8830638867802918, 0.41710875404533, 0.025952427422453184, 0.025627743380027823, 0.03600781783461571, 0.040263136761495844, 0.005593106907326728, 0.051746372919296846, 0.08614839098299854, 0.008879656870703911, 0.0507539656246081, 0.04632980810129084, 0.030990582272352185, 0.08900134023861028, 0.027069309580838308, 0.07015422539552674, 0.024704476418264676, 0.05443380468932446, 0.048189704393735155, 0.041589963220758364, 0.022648146623396315, 0.06918802333530039, 0.028750032870448194, 0.03507641136820894, 0.017366997781209648, 0.04106805157789495, 0.06198443741595838, 0.10728811874287203, 0.024790316929284018, 0.021961103411740623, 0.024309180735144764, 0.04325471178162843, 0.0220838082532282, 0.0141174002783373, 0.025766981416381896, 0.038147585437400267, 0.005854942173755262, 0.029078217994538136, 0.03892228000040632, 0.06822645227657631, 0.01979318058147328, 0.01177018570160726, 0.09171916666673496, 0.03548444787156768, 0.021749218394688796, 0.018500799051253125, 0.01002896346108173, 0.05119936184200924, 0.0008037713871544838, 0.005319167676134384, 0.006492564380096155, 0.01595652571268147, 0.055325175999314524, 0.07202159511507489, 0.010540904349909397, 0.027286807089694776, 0.008971533825388178, 0.025973381962103304, 0.01396698735334212, 0.013664545476785861, 0.018783603700285312, 0.0020417999348865123, 0.04331811716838274, 0.02098366338032065, 0.016755488504713867, 0.09416822431376204, 0.10943206463707611, 0.14437916048336774, 0.16104984562844038, 0.11211360746528953, 0.2382962717092596, 0.1435674587264657, 0.07569413515739143, 0.1604447132558562, 0.13103871460771188, 0.27825057855807245, 0.14235710492357612, 0.12277985777473077, 0.09037797222845256, 0.10798129951581359, 0.21338915743399411, 0.141268641455099, 0.20416319312062114, 0.12161657097749412, 0.20503382140304893, 0.1402902088011615, 0.20047641126438975, 0.16865693352883682, 0.1444254704983905, 0.16651595622533932, 0.12684375455137342, 0.1555610995274037, 0.11358155330526643, 0.06983878294704482, 0.16113765654154122, 0.13666125509189442, 0.23203790362458676, 0.15355305571574718, 0.12732177186990157, 0.12385111083858646, 0.0903791819291655, 0.20924868586007506, 0.10712365881772712, 0.1103211278677918, 0.12839845003327355, 0.1587310348986648, 0.1215629508078564, 0.2885999466525391, 0.1671748497756198, 0.1539563832920976, 0.19288695679279044, 0.1263923803344369, 0.1027624131529592, 0.15098365140147507, 0.2123523474438116, 0.09421116497833282, 0.09042794103152119, 0.1869448772049509, 0.11363318451913074, 0.16370275639928877, 0.11217520572245121, 0.12377117411233485, 0.10856177774257958, 0.1264445236301981, 0.13457111490424722, 0.14162660896545276, 0.13036551245022565, 0.20176135090878233, 0.18293462286237627, 0.20563825615681708, 0.2028014263487421, 0.1632641174364835, 0.11701635376084596, 0.15122228156542405, 0.1573517089127563, 0.9702659421600401, 2.85253400914371, 7.241040598601103, 12.194985821843147, 20.921753346920013, 25.010284557938576, 34.362760707736015, 43.596428632736206, 50.71433208882809, 55.76971001923084, 60.79829938709736, 68.24721068143845, 61.83017961680889, 73.25354844331741, 60.8666805177927, 66.4720219373703, 64.95379820466042, 62.360737547278404, 65.82254558801651, 56.33969843387604, 63.53894792497158, 56.36732295155525, 60.14921821653843, 56.99526585638523, 52.95219160616398, 55.78093081712723, 51.921690702438354, 54.710117876529694, 69.16811406612396, 68.15331771969795, 59.36111010611057, 60.446225479245186, 53.302699998021126, 62.1570760756731, 53.27396593987942, 47.298189997673035, 36.86394229531288, 27.30300933122635, 20.743463113904, 9.678304865956306, 5.108576025813818, 1.6110553639009595, 0.41446789575275034, 0.07952922038384713, 0.11394243745598942, 0.13297564582899213, 0.10517783666728064, 0.09103886957745999, 0.16708843410015106, 0.16300377203151584, 0.09762269910424948, 0.09187427553115413, 0.11741781112505123, 0.08537718080333434, 0.17012646014336497, 0.09719015317386948, 0.1683493281598203, 0.13801552617223933, 0.13584088505012915, 0.11622543213889003, 0.22215432225493714, 0.14991065429057926, 0.19218975357944146, 0.12528399762231857, 0.09665374367614277, 0.15854244033107534, 0.22072975494666025, 0.1444299827562645, 0.1825702580390498, 0.16013844375265762, 0.1472450527944602, 0.12750906025758013, 0.11309108274872415, 0.04394870520627592, 0.11668393097352237, 0.15365597675554454, 0.09014220675453544, 0.08346391667146236, 0.16699435946065933, 0.18769876565784216, 0.20745751244248822, 0.19559738400857896, 0.13184664625441656, 0.16916208376642317, 0.1278536394238472, 0.09284277082770132, 0.09630719781853259, 0.13487270887708291, 0.1522337249480188, 0.07531174356699921, 0.10208150008111261, 0.10740554134827107, 0.15129520499613136, 0.16161809326149523, 0.17868725233711302, 0.10843897456652485, 0.10520368567085825, 0.16159769904334098, 0.13958513882244006, 0.14152546908007935, 0.06619745021453127, 0.12633048521820456, 0.24312422436196357, 0.14007031044457108, 0.10564402415184304, 0.19184045435395092], [0.03559469390893355, 0.06509914586786181, 0.01714161495328881, 0.06565188261447474, 0.025600792287150398, 0.026357113129051868, 0.009213127013936173, 0.0378859338525217, 0.06940060411579907, 0.018778297344397288, 0.02612547585158609, 0.06163379119243473, 0.06150872075522784, 0.008790278170636157, 0.005492048658197746, 0.010587496381049277, 0.03642023672000505, 0.020979592700314242, 0.025851808895822614, 0.04623927721695509, 0.022492308598884847, 0.01940275338711217, 0.06367227790178731, 0.033900704729603603, 0.009834807424340397, 0.03192600190232042, 0.03915895089448895, 0.023151586210587993, 0.04441304103238508, 0.04801332928764168, 0.08366322043002583, 0.011785242022597231, 0.023633225209778175, 0.038304779736790806, 0.015213821425277274, 0.061357701124507, 0.015971133034327067, 0.018526126696087886, 0.02872746601497056, 0.03339840433909558, 0.03421209134103265, 0.12020867972751148, 0.0259518040184048, 0.01038094740579254, 0.03554192720912397, 0.07995087158633396, 0.04237435023242142, 0.019498466317600105, 0.06561913163750432, 0.045740754358121194, 0.012120283663534792, 0.08563554467400536, 0.03858347103232518, 0.09317567601101473, 0.044104645276092924, 0.025023612906807102, 0.01811191552405944, 0.027645134541671723, 0.03954436302592512, 0.060112666760687716, 0.021233689221844543, 0.03302738245110959, 0.02482462085026782, 0.017780928792490158, 0.04241631868353579, 0.01514114568635705, 0.041005388338817284, 0.08236697787651792, 0.044477526244008914, 0.022724070186086465, 0.007235677776407101, 0.09274743453715928, 0.04363138883491047, 0.20315289264544845, 1.0587874171324074, 1.828132253140211, 3.434682721272111, 6.875411393120885, 9.818312153220177, 15.34715797752142, 18.760721907019615, 27.693852558732033, 33.18236164748669, 33.965180441737175, 43.83083425462246, 40.4698234051466, 48.50587919354439, 46.885167360305786, 43.94099794328213, 46.6572517901659, 44.52442243695259, 49.780235812067986, 44.127609729766846, 46.511434614658356, 39.68990385532379, 42.817174047231674, 46.730409264564514, 43.36725912988186, 44.37107406556606, 40.46889245510101, 39.92088966071606, 40.83886340260506, 35.938038378953934, 24.62331712245941, 17.729223556816578, 8.342042919248343, 4.030793309211731, 2.6542836846783757, 1.0484054242260754, 0.600651225540787, 0.08604080183431506, 0.1032668657717295, 0.039922780415508896, 0.07429647812386975, 0.02199555947299814, 0.05723349742766004, 0.048700969928177074, 0.05671760089171585, 0.06557696280651726, 0.06302068708464503, 0.015591055089316797, 0.03823558188742027, 0.0031481078804063145, 0.040385802640230395, 0.023016153536445927, 0.03657863700937014, 0.0502793028135784, 0.015185366555670043, 0.06147233325464185, 0.05432571088022087, 0.061738860749755986, 0.017914788113557734, 0.028241854670341127, 0.008903664420358837, 0.08272901977761649, 0.07522271553170867, 0.02739511055551702, 0.013881574504921446, 0.02684657993086148, 0.058145723087363876, 0.03230191083275713, 0.013236457070888719, 0.009521404954284662, 0.037992947836755775, 0.034176813351223245, 0.03731764169060625, 0.009138783298112685, 0.030642073434137274, 0.06299843749729916, 0.03247384047426749, 0.03941503266105428, 0.02680358917132253, 0.05791460716864094, 0.03342329597217031, 0.07966248042066582, 0.1078383470303379, 0.04752822445880156, 0.12254858229425736, 0.03712350699061062, 0.041948606085497886, 0.099075720354449, 0.06744449579855427, 0.050005880766548216, 0.04437626761500724, 0.016679633590683807, 0.0429001433076337, 0.015365675044449745, 0.06620362488320097, 0.032868188063730486, 0.023551791200588923, 0.05505154615093488, 0.018202604114776477, 0.03371822174813133, 0.024259790807263926, 0.03579829470254481, 0.03280956581875216, 0.03294588721473701, 0.028208342992002144, 0.013247307269921293, 0.048247428640024737, 0.04159353666182142, 0.0281824142075493, 0.05975287356704939, 0.05037463539338205, 0.02056813675153535, 0.012107490892958594, 0.04914760182145983, 0.043294216302456334, 0.0978377735009417, 0.02513169001758797, 0.024895076639950275, 0.053708726409240626, 0.021070101320219692, 0.022358673777489457, 0.013932301226304844, 0.047398222450283356, 0.019847481671604328, 0.01663225302763749, 0.02740445976087358, 0.018283574281667825, 0.03695416002301499, 0.0422944357706001, 0.05218911224801559, 0.032336791773559526, 0.09829331858782098, 0.04537173626886215, 0.039925348246470094, 0.04792419735167641, 0.0199550708202878, 0.010901252298936015, 0.0709714338881895, 0.02550765831983881, 0.02652475315699121, 0.015471939459530404, 0.04138495234656148, 0.02354909163841512, 0.04943954416376073, 0.03431913872191217, 0.03434684680541977, 0.07907284409157, 0.05330711690476164, 0.048264134384226054, 0.024021977005759254, 0.032034945470513776, 0.024391748374910094, 0.059010822369600646, 0.04707295767730102, 0.06402896891813725, 0.01854206988355145, 0.06568450000486337, 0.023676293894823175, 0.03175566416757647, 0.0249251261993777, 0.03223744046408683, 0.10674583143554628, 0.02179418512241682, 0.03745607078599278, 0.02454424673487665, 0.020848425519943703, 0.060364789169398136, 0.017865331392385997, 0.03531705275236163, 0.027875556552316993, 0.029883114257245325, 0.0422221097687725, 0.028510200427263044, 0.050727990455925465, 0.04219446847855579, 0.09629596170270815, 0.5984136206097901, 2.0791662577539682, 3.3457793667912483, 5.65257478505373, 10.86909256875515, 14.756575617939234, 20.96400897949934, 26.45725641399622, 35.918891206383705, 41.21500141918659, 42.599065750837326, 51.208142191171646, 48.82575362920761, 55.94448544085026, 54.29814778268337, 52.391619086265564, 53.927831053733826, 51.99980691075325, 55.33818617463112, 53.17857205867767, 53.38523916900158, 48.32048714160919, 50.15408255159855, 52.887454479932785, 49.75980430841446, 51.59700192511082, 47.71144822239876, 46.70145481824875, 45.744255781173706, 41.67825736105442, 32.25319750607014, 22.16839425265789, 12.30477238073945, 6.025957949459553, 4.547390788793564, 2.4339247215539217, 1.0662310989573598, 0.15367616317234933, 0.09242344996891916, 0.027535085173440166, 0.1305206213146448, 0.014855182271276135, 0.05280224868329242, 0.02815668394759996, 0.026591160531097557, 0.05839497709530406, 0.016667753661749884, 0.08292328435345553, 0.030735166583326645, 0.020751317351823673, 0.008046758448472247, 0.020241215133864898, 0.04375628115667496, 0.049028650391846895, 0.0643308820144739, 0.04416726398630999, 0.019866382317559328, 0.03201156410796102, 0.05172179669898469, 0.03289878681243863, 0.026492501274333335, 0.04892341385129839, 0.061655684548895806, 0.0711747600871604, 0.037596288457280025, 0.019801158668997232, 0.032284025073749945, 0.06874444909044541, 0.023381047139992006, 0.014821190052316524, 0.030679127012263052, 0.10831543666427024, 0.051266949230921455, 0.040573168953415006, 0.050470038477214985, 0.05091656275908463, 0.039632478219573386, 0.04016051629150752, 0.07778528466587886, 0.030187333577487152, 0.08465386141324416, 0.03324358862300869, 0.14485361549304798, 0.02911901941843098, 0.02997930958372308, 0.03774558259465266, 0.028707400197163224, 0.05538672601687722, 0.02090249654429499, 0.052990895201219246, 0.041444865928497165, 0.02117517273291014, 0.014509377633658005, 0.05585711776802782, 0.0691043387632817, 0.06635823650867678, 0.0333200298337033, 0.044549848535098135, 0.011535673529579071, 0.020729539028252475, 0.0436662400898058, 0.026663464268494863, 0.030036736970942002, 0.08079040388111025, 0.1389666329487227, 0.1016517446259968, 0.09721541588078253, 0.1322756224544719, 0.11786508868681267, 0.11141527618747205, 0.12443063911632635, 0.13725923316087574, 0.11165933887241408, 0.08455885908915661, 0.11956396861933172, 0.16012967156711966, 0.18332901498069987, 0.1734618647606112, 0.15941477555315942, 0.10030830148025416, 0.09679303737357259, 0.12109249597415328, 0.09919906529830769, 0.09062530036317185, 0.08215684618335217, 0.16706250346032903, 0.10813023371156305, 0.05526227527298033, 0.10396110781584866, 0.11677938600769266, 0.10069263007608242, 0.22337920730933547, 0.16978032246697694, 0.16273440211080015, 0.1668665319448337, 0.12240356663824059, 0.12590499711222947, 0.17985341866733506, 0.1328671141527593, 0.06553008875926025, 0.1680250689969398, 0.13991539453854784, 0.24757258332101628, 0.08944155997596681, 0.23331279458943754, 0.12770201865350828, 0.1900313951773569, 0.12205676102894358, 0.15520062355790287, 0.12274066495592706, 0.1440740338875912, 0.22168999013956636, 0.17836897488450631, 0.09500277679762803, 0.2604995638830587, 0.12741477781673893, 0.22615676920395344, 0.10166462830966339, 0.1993487327126786, 0.23976020253030583, 0.13012345356401056, 0.1772847565007396, 0.062178438529372215, 0.0916520542523358, 0.130676873086486, 0.11314813164062798, 0.09151981095783412, 0.09870998255792074, 0.13129355327691883, 0.18231831374578178, 0.18758113525109366, 0.08621144384960644, 0.15072185138706118, 0.18240199831780046, 0.1756544955424033, 0.12464833329431713, 0.5191445897798985, 1.657837622333318, 3.1644310103729367, 5.978465722873807, 9.770429972559214, 14.378754291683435, 21.20076857507229, 26.75473865121603, 36.02134890854359, 44.11260433495045, 47.03804835677147, 56.69319726526737, 52.981233447790146, 62.900536581873894, 59.051179736852646, 58.273521065711975, 60.75918048620224, 58.21775905787945, 62.52326242625713, 59.956374764442444, 60.90402491390705, 55.79953081905842, 59.5492722094059, 61.54932528734207, 58.382639810442924, 59.26552623510361, 55.797984302043915, 54.12219062447548, 54.90364149212837, 50.53921088576317, 37.979114055633545, 27.725675851106644, 14.185499511659145, 6.658943658694625, 4.139471277594566, 2.011685916222632, 1.015082518570125, 0.19860659987898543, 0.17470343329478055, 0.18313513632165268, 0.16286205151118338, 0.12437205397873186, 0.14030482911039144, 0.08768502259044908, 0.11314979405142367, 0.1523582573281601, 0.0859239803685341, 0.24580425320891663, 0.18642908456968144, 0.16368292621336877, 0.17351630871417, 0.08385087247006595, 0.16310494160279632, 0.12280825234483927, 0.07045611622743309, 0.11686362719046883, 0.21225754549959674, 0.1339748437749222, 0.11764290451537818, 0.09575285061146133, 0.08566442164010368, 0.18453573225997388, 0.20542448794003576, 0.14534286892740056, 0.1739469770109281, 0.09844143642112613, 0.1735801631002687, 0.1722972866264172, 0.12969299306860194, 0.11197322281077504, 0.18958808068418875, 0.2194725864683278, 0.13318318000528961, 0.09194241953082383, 0.1374265132471919, 0.18252936570206657, 0.12184556064312346, 0.15750456164823845, 0.15532963851001114, 0.09090528299566358, 0.18883858574554324, 0.17422970558982342, 0.23673109710216522, 0.0905338380835019, 0.2254059532424435, 0.09077147376956418, 0.1210631885624025, 0.15836672944715247, 0.14533132110955194, 0.12284724478377029, 0.07138239816413261, 0.10105886511155404, 0.12352130783256143, 0.15747039316920564, 0.17170012491988018, 0.1275351393269375, 0.10983358137309551, 0.2667698805453256, 0.128808545996435, 0.08629059389932081, 0.11959645242313854, 0.12052147270878777, 0.15048336965264753], [0.06085398323193658, 0.03982898037065752, 0.012272577005205676, 0.07486371643608436, 0.025699592551973183, 0.02055153305263957, 0.025902634879457764, 0.04863637710514013, 0.11039472665288486, 0.050784887207555585, 0.01367901550111128, 0.031714129872852936, 0.018437291619193275, 0.028085090816603042, 0.0228300303206197, 0.02095019066473469, 0.0835616204130929, 0.009342820103483973, 0.03115046871243976, 0.024347232501895633, 0.022551255533471704, 0.03044306839001365, 0.033056493193726055, 0.0487643938686233, 0.017794946106732823, 0.03662683579022996, 0.012989216138521442, 0.025851797763607465, 0.018535054732637946, 0.07207376809674315, 0.03908682527253404, 0.020326371013652533, 0.028933966750628315, 0.030142125651764218, 0.029732289440289605, 0.022323104494716972, 0.035711040400201455, 0.08075868448941037, 0.06691561909974553, 0.0325607719423715, 0.03633999571320601, 0.0464934813498985, 0.013071479497739347, 0.10297074884874746, 0.0540987843851326, 0.0073457322469039354, 0.03523840736306738, 0.0324475239176536, 0.09725341384182684, 0.040531304402975366, 0.03566952465916984, 0.04995714392862283, 0.04190174688119441, 0.12553807930089533, 0.04005670467449818, 0.04834271669096779, 0.044707387933158316, 0.027614726895990316, 0.02563467132858932, 0.03358071291586384, 0.05651498715451453, 0.04621716863766778, 0.01530711495433934, 0.028818442187912297, 0.03630702580267098, 0.04788761318195611, 0.055744938435964286, 0.04277559979527723, 0.02422267043584725, 0.020803182342206128, 0.013749396148341475, 0.014833820478088455, 0.006493919727290631, 0.049591547140153125, 0.029415778299153317, 0.05072079904493876, 0.027934312383877113, 0.034908415109384805, 0.3279431542614475, 1.1351800616830587, 1.37607098557055, 2.754803728312254, 4.2747625429183245, 6.421252163127065, 10.395637974143028, 10.843558888882399, 11.84683995321393, 17.396236024796963, 18.58298074454069, 16.774482987821102, 23.324358724057674, 18.069998770952225, 14.112483579665422, 22.32159063220024, 19.756946749985218, 16.48093543946743, 25.169497914612293, 23.43720316886902, 20.683432035148144, 21.28473836928606, 16.77772991359234, 15.117831733077765, 8.831713143736124, 4.899966744706035, 2.440676484256983, 0.7629145123064518, 0.2109250341891311, 0.06104848158429377, 0.038579715765081346, 0.02085744261421496, 0.02227940312877763, 0.10364977686549537, 0.07979307614732534, 0.012227002644067397, 0.0785487839311827, 0.07177421503001824, 0.04115271207410842, 0.056032116190181114, 0.04317501625337172, 0.06594831866095774, 0.0034724303577604587, 0.05171839024114888, 0.046035223713261075, 0.027435724587121513, 0.06519538015709259, 0.022595407754124608, 0.08424922023550607, 0.030626458647020627, 0.04167738079559058, 0.043135244559380226, 0.03231201146263629, 0.028284051331866067, 0.024371073996007908, 0.06589099517441355, 0.05038114031776786, 0.014093151530687464, 0.012906201354780933, 0.0050278181242902065, 0.03577457937353756, 0.03272325775469653, 0.05226410627074074, 0.1415945333428681, 0.09132145714829676, 0.014665404905827018, 0.02352549876377452, 0.04810941514733713, 0.04810608661500737, 0.05585115461144596, 0.0274446025287034, 0.031742531864438206, 0.025220779280061834, 0.028930777370987926, 0.03070695383939892, 0.0424297515564831, 0.04303720314055681, 0.06348150142002851, 0.04752485881908797, 0.029206010258349124, 0.050457507313694805, 0.01677296979323728, 0.0538831756421132, 0.06313892605248839, 0.03893130080541596, 0.0111987087984744, 0.023779252042004373, 0.038526307107531466, 0.03388381715922151, 0.04443613295734394, 0.008456502819171874, 0.06137544216471724, 0.04916270081594121, 0.031305455122492276, 0.012601523758348776, 0.049487256837892346, 0.033740285798558034, 0.06256414751987904, 0.060193705576239154, 0.07408677687635645, 0.03150686286971904, 0.055708947984385304, 0.0034422506905684713, 0.020951296464772895, 0.024619372488814406, 0.043490132156875916, 0.12053710233885795, 0.040513069834560156, 0.057348444970557466, 0.07145542549551465, 0.01629439586395165, 0.0024995969761221204, 0.03872428984323051, 0.02837899428413948, 0.04700163357483689, 0.007938606195239117, 0.051492706843419, 0.06414898161892779, 0.07952388434205204, 0.01828175601986004, 0.0625532676349394, 0.026300650533812586, 0.046424261236097664, 0.04095040261745453, 0.0322769969352521, 0.04510257414949592, 0.07972753708600067, 0.0654181135178078, 0.0326215464156121, 0.06550265155965462, 0.03705219402036164, 0.0051266995615151245, 0.10071575539768673, 0.03294541224022396, 0.07244347638334148, 0.09600001547369175, 0.02360544847761048, 0.01804931536753429, 0.05395661115471739, 0.012783216352545423, 0.04794510736246593, 0.03761730979022104, 0.04586468930938281, 0.06180301199492533, 0.02805859243380837, 0.05920378076552879, 0.0684278563130647, 0.04159917698416393, 0.0493427903711563, 0.024933885397331323, 0.047031594076543115, 0.042512122527114116, 0.027739706420106813, 0.02263865084387362, 0.028643067125813104, 0.025032266348716803, 0.0472317587264115, 0.02655713862623088, 0.056207467132480815, 0.0727725075557828, 0.03031833934073802, 0.047120852177613415, 0.03555749746738002, 0.03392021208128426, 0.03466706497420091, 0.05505415851075668, 0.030089702195255086, 0.018600187468109652, 0.021631845884257928, 0.015151947645790642, 0.0037678842181776417, 0.06386755921994336, 0.014799777236476075, 0.039068638943717815, 0.09311041154433042, 0.21731911139795557, 0.9132264903746545, 2.1744888927787542, 2.8140938468277454, 4.683148479089141, 7.236316027119756, 9.241877384483814, 15.768725406378508, 15.951198264956474, 18.42431265860796, 22.80072972178459, 24.36412923038006, 23.620788417756557, 28.784327544271946, 26.459251306951046, 20.733171366155148, 29.88145027309656, 27.043665647506714, 21.777839809656143, 31.53889663517475, 30.619914047420025, 27.022255696356297, 25.195997692644596, 22.01133158057928, 19.190733432769775, 13.246477749198675, 6.540657430887222, 3.753154557198286, 1.150802329648286, 0.3712027345318347, 0.09800023704883642, 0.08919864761992358, 0.05117583576065954, 0.03642805524577852, 0.04714375485491473, 0.07041762102744542, 0.06203703713254072, 0.09840571685344912, 0.06331106720608659, 0.009670792787801474, 0.020937284716637805, 0.07780032057780772, 0.04062862222781405, 0.020064726850250736, 0.08575300438678823, 0.06968694695387967, 0.013371491768339183, 0.047515273981844075, 0.04330522606323939, 0.04774256041855551, 0.07023764279438183, 0.04415589428390376, 0.09342321194708347, 0.03531438473146409, 0.03450351417995989, 0.04949621084961109, 0.025738898548297584, 0.025590606310288422, 0.05392780098190997, 0.04779620285262354, 0.02997893294377718, 0.04243368864990771, 0.03612544824136421, 0.058176555612590164, 0.06876593426568434, 0.01805547704861965, 0.05199601284402888, 0.027772989888035227, 0.02308931445440976, 0.052573106877389364, 0.03021231241291389, 0.08309051248943433, 0.10347220319090411, 0.0203378650257946, 0.06188645165821072, 0.04012678939034231, 0.04690308378485497, 0.11896398675162345, 0.05323210061760619, 0.06293649043072946, 0.03893396140483674, 0.06614201920456253, 0.057542947033653036, 0.008007232590898639, 0.04447542225534562, 0.04079569822351914, 0.04790962899278384, 0.005433591541077476, 0.03808837689575739, 0.02246411626401823, 0.02578927367721917, 0.022756015932827722, 0.06628723524045199, 0.06382182808010839, 0.02322065603948431, 0.03503559324599337, 0.015957293835526798, 0.012903416445624316, 0.05204582950682379, 0.11494913109345362, 0.1419532875297591, 0.08676881159772165, 0.1847571594407782, 0.08260865826741792, 0.14105886599281803, 0.13468789926264435, 0.15363668091595173, 0.23408338136505336, 0.09891992871416733, 0.14315748150693253, 0.1911166970967315, 0.06974920572247356, 0.1398523268289864, 0.13585201726527885, 0.15347634733188897, 0.1588462310610339, 0.09963860968127847, 0.1803069599554874, 0.21187437465414405, 0.10327870302717201, 0.10717595054302365, 0.22968013014178723, 0.1418980717426166, 0.15476478991331533, 0.15734694432467222, 0.084153980424162, 0.10631988319801167, 0.19862404034938663, 0.1977378863375634, 0.1336187167908065, 0.12752822251059115, 0.09479774365900084, 0.06943411208339967, 0.27492275869008154, 0.14036046050023288, 0.2092164766509086, 0.16953955491771922, 0.20060554496012628, 0.09445458199479617, 0.16108242591144517, 0.12651829310925677, 0.20744829496834427, 0.17055962205631658, 0.21742008801084012, 0.1296381335123442, 0.1362367020919919, 0.11787452880525962, 0.2371642441721633, 0.16626885073492303, 0.110978091834113, 0.1477844754117541, 0.1945546516799368, 0.2522852359106764, 0.08304110771859996, 0.10349063813919201, 0.11600401980103925, 0.1084766088752076, 0.16791818488854915, 0.15354452101746574, 0.22475614357972518, 0.20071875216672197, 0.18901806673966348, 0.24317176634212956, 0.09563512372551486, 0.2245705176028423, 0.19980742450570688, 0.13539467618102208, 0.14674625534098595, 0.14078205975238234, 0.10170020686928183, 0.1008659735089168, 0.19903759472072124, 0.17149600462289527, 0.11152547769597732, 0.22471872449386865, 0.19498576526530087, 0.21422015503048897, 0.7440761919133365, 1.7596769076772034, 2.5179356010630727, 4.404428210109472, 7.102676248177886, 9.290855806320906, 14.45292916148901, 16.20575800538063, 17.89073009043932, 23.97450003772974, 25.973895750939846, 24.765444695949554, 30.873713828623295, 27.561224475502968, 22.079841904342175, 29.75277017802, 30.619838051497936, 26.361444555222988, 36.02946147322655, 34.2227154225111, 32.61504828929901, 28.757449686527252, 23.60683746635914, 19.749588444828987, 12.704090103507042, 7.549508521333337, 3.4421773441135883, 1.0073546832427382, 0.33371970523148775, 0.11396903602872044, 0.17602242267457768, 0.14658865286037326, 0.07675051558180712, 0.17883572640130296, 0.16229147353442386, 0.11202678360859863, 0.19658522709505633, 0.16618201945675537, 0.07728270968073048, 0.18099766195518896, 0.1668846106622368, 0.18934232590254396, 0.08117821314954199, 0.24168191972421482, 0.1477846535271965, 0.09611409841454588, 0.14804292091866955, 0.11325470404699445, 0.2675670658936724, 0.17110060318373144, 0.13857541722245514, 0.24254359770566225, 0.11278231220785528, 0.1714104349957779, 0.17172682739328593, 0.15698173345299438, 0.08257926921942271, 0.1625525314011611, 0.16405983333243057, 0.1774159088381566, 0.16350304445950314, 0.12246799247805029, 0.12202753525343724, 0.19086427782895043, 0.2312860041274689, 0.13941839308245108, 0.14116971316980198, 0.1281425723573193, 0.16975207632640377, 0.16051897255238146, 0.2001999315689318, 0.24649183818837628, 0.20874027017271146, 0.12347418887657113, 0.0929486975655891, 0.1459299522684887, 0.16396406659623608, 0.1930412047659047, 0.19188887206837535, 0.19774702959693968, 0.157410160463769, 0.13898922392399982, 0.1437229831935838, 0.11669858839013614, 0.12726367654977366, 0.06240509042982012, 0.13662898651091382, 0.107980809698347, 0.13012465584324673, 0.1136284347740002, 0.08532302628736943, 0.12586244236445054, 0.1639548342791386, 0.19793327897787094, 0.11564162909053266, 0.13468001765431836, 0.10011910577304661, 0.13989537139423192], [0.0359312430373393, 0.011147893019369803, 0.024379410169785842, 0.02479433751432225, 0.01754520599206444, 0.03138111707812641, 0.03991424942796584, 0.010127161658601835, 0.06082736610551365, 0.018421708373352885, 0.020857116069237236, 0.058645789613365196, 0.09913012720062397, 0.04277300598914735, 0.02383261245995527, 0.050308242862229235, 0.06307189527433366, 0.015061910289659863, 0.016966972762020305, 0.027546781420824118, 0.07745610506390221, 0.07285616244189441, 0.06325802591163665, 0.01611701514775632, 0.03877477072819602, 0.005492029176821234, 0.03040581999812275, 0.06773870540200733, 0.03429819902521558, 0.04837137843423989, 0.03608811821322888, 0.02802489707391942, 0.037566268583759665, 0.029947117072879337, 0.08335135513334535, 0.032004832828533836, 0.043469095980981365, 0.031236609793268144, 0.035455396500765346, 0.018677098087209743, 0.013733085597777972, 0.037654253901564516, 0.05150873723323457, 0.020903307340631727, 0.04038870814838447, 0.031973421428119764, 0.02614651202748064, 0.03508928020892199, 0.04031338386994321, 0.03287902341980953, 0.007641233187314356, 0.018503231440263335, 0.07284596533281729, 0.05697485896234866, 0.013346033319976414, 0.10109736773301847, 0.02984212915180251, 0.06516207256936468, 0.01422864635969745, 0.03753646764380392, 0.06074100238038227, 0.01748978982504923, 0.015717789792688563, 0.0808169950323645, 0.06713686074363068, 0.017551011442265008, 0.019660517973534297, 0.05351310370315332, 0.02818537537677912, 0.023927726106194314, 0.057847123680403456, 0.05270423323963769, 0.04464727026061155, 0.00809025572380051, 0.021561588619078975, 0.038062375751906075, 0.15753433661302552, 0.046381550637306646, 0.09001487647765316, 0.01674345458013704, 0.035714539626496844, 0.05346750243916176, 0.040926494330051355, 0.049330760157317854, 0.259761008201167, 0.4916958720423281, 0.5859740381129086, 1.4190345676615834, 1.2404664745554328, 1.1583429062739015, 1.696288709063083, 1.7414907272905111, 1.512098223902285, 1.2483531888574362, 2.7088238205760717, 1.0793820745311677, 1.6781241400167346, 2.483433927409351, 3.693729783408344, 2.3391483072191477, 1.464706810656935, 0.7465561525896192, 0.2898856729734689, 0.061773366905981675, 0.07035921400529332, 0.08195729009457864, 0.06562780734384432, 0.03371365382918157, 0.028192646568641067, 0.08816464294795878, 0.03823496590484865, 0.0335810543037951, 0.06818924099206924, 0.006809192873333814, 0.026215086472802795, 0.01083662607925362, 0.013796209896099754, 0.09030042521771975, 0.0439938574709231, 0.009731954105518525, 0.05868132364412304, 0.041300291850348, 0.06529944410431199, 0.04459232906810939, 0.10286341945175081, 0.027231244348513428, 0.0743675536068622, 0.04453976274817251, 0.022448282543336973, 0.062367686186917126, 0.06387883986462839, 0.00719015490176389, 0.02422576890239725, 0.025513402542856056, 0.031703836284577847, 0.013234751058917027, 0.02232764458312886, 0.08293639068142511, 0.0033961060353249195, 0.025774497516977135, 0.01848310996138025, 0.03879425581544638, 0.026595253475534264, 0.03798400495725218, 0.010329870019631926, 0.048860438910196535, 0.03904794044501614, 0.06052244731108658, 0.05348467944713775, 0.014390352916962001, 0.011019701851182617, 0.01789664074749453, 0.08826720033539459, 0.005905023690502276, 0.031073415229911916, 0.02175629106204724, 0.01826183492084965, 0.01941385962709319, 0.04791765531990677, 0.07607064151670784, 0.024951871346274856, 0.06769952742615715, 0.08853699328028597, 0.020067962614120916, 0.04803642492333893, 0.04893608973361552, 0.04086503337020986, 0.11980538925854489, 0.034172223167843185, 0.03756329999305308, 0.02383759041549638, 0.020560355333145708, 0.04262304391886573, 0.02561323253758019, 0.05574035567406099, 0.01993519239476882, 0.04437015231815167, 0.009650615647842642, 0.03852363908663392, 0.01875501617178088, 0.04392500843096059, 0.04551782432827167, 0.06344738489133306, 0.036416440634639, 0.012737704146275064, 0.07068805221933872, 0.062135783591656946, 0.04706355837697629, 0.05209118957282044, 0.016217058509937488, 0.03462550841504708, 0.0709648584597744, 0.016316792025463656, 0.02819001008901978, 0.030649387299490627, 0.03508663816319313, 0.03295831447758246, 0.06021966219122987, 0.03364325741131324, 0.06838979155872948, 0.08056809354457073, 0.053960366421961226, 0.038486082703457214, 0.013090216871205484, 0.019064703265030403, 0.044751441819244064, 0.009847225410339888, 0.048058203246910125, 0.01933567808009684, 0.013381493135966593, 0.04576859973894898, 0.01727529615891399, 0.01621547588001704, 0.03717960222274996, 0.054051587503636256, 0.036103558595641516, 0.05912929882470053, 0.06629675699514337, 0.026494380763324443, 0.019819727203866933, 0.11893029324710369, 0.04748065650346689, 0.041211608913727105, 0.03012184090039227, 0.0953003038011957, 0.04016420847619884, 0.013703668719244888, 0.08785790589172393, 0.06563361836015247, 0.021260330468066968, 0.0677335548971314, 0.07179836451541632, 0.013480878769769333, 0.058258058270439506, 0.02267160776682431, 0.05245426305918954, 0.03983624599641189, 0.03013753732375335, 0.02774244494503364, 0.09589625580701977, 0.08514730056049302, 0.04763798067870084, 0.041301601740997285, 0.015566556794510689, 0.05561036479775794, 0.03879010720993392, 0.033098161075031385, 0.02259507935377769, 0.05082679257611744, 0.022237674020288978, 0.04873947626037989, 0.0336695591249736, 0.026782493623613846, 0.09135154381510802, 0.07263930689077824, 0.031716560406493954, 0.02328270515135955, 0.053965439001331106, 0.11632361827651039, 0.2219640207476914, 0.44302743044681847, 1.0105848661623895, 1.1222447245381773, 2.188874683342874, 2.2952468879520893, 1.9538280833512545, 3.207658678293228, 2.956925807520747, 2.7938352338969707, 2.895336337387562, 4.5976141188293695, 2.553040967322886, 3.6843960592523217, 3.987276144325733, 4.985864935442805, 3.5246975161135197, 1.981032604817301, 1.318581139203161, 0.5157757736742496, 0.15932040405459702, 0.022235430878936313, 0.030054273920541164, 0.04344936598499771, 0.039183545668493025, 0.06201657983183395, 0.020554327238642145, 0.02184625049267197, 0.06202518503414467, 0.02499124970199773, 0.012393430188240018, 0.02371498576394515, 0.0500387059582863, 0.06136833610071335, 0.05193281525862403, 0.02074446176266065, 0.0171949772266089, 0.0493130450922763, 0.05460749693156686, 0.03448044451943133, 0.10729992631240748, 0.026381854477222078, 0.055454532339354046, 0.03394210172700696, 0.02855692418961553, 0.018706292321439832, 0.01660971400269773, 0.07152575140935369, 0.034582860898808576, 0.03732636563654523, 0.06928133356268518, 0.021843027716386132, 0.01098886468753335, 0.019372197311895434, 0.01825336516048992, 0.07893261528806761, 0.030479886336252093, 0.06302948895609006, 0.05522652230865788, 0.011481214733066736, 0.057680277750478126, 0.035275845002615824, 0.01749056165863294, 0.07912628614576533, 0.018632756618899293, 0.02984347058372805, 0.0283137891892693, 0.017761863018677104, 0.02700892659049714, 0.0979030602320563, 0.04263979419192765, 0.044976884018979035, 0.06018339343427215, 0.07820872444426641, 0.02101732348819496, 0.030847355192236137, 0.043782074499176815, 0.008311504789162427, 0.06859565590275452, 0.07624353966093622, 0.045286545137059875, 0.033706915128277615, 0.01571553737448994, 0.016599528025835752, 0.017585667883395217, 0.010697823126974981, 0.005530759081011638, 0.02026052952714963, 0.04581580404192209, 0.03875369373417925, 0.06741053512087092, 0.048780646902741864, 0.0508276423352072, 0.11454597421106882, 0.1847821698174812, 0.1301656966097653, 0.18545186903793365, 0.1012415521836374, 0.0972316466504708, 0.13738017354626209, 0.12484348844736814, 0.11536232923390344, 0.10646814203937538, 0.1709814291098155, 0.11088950908742845, 0.2047263496206142, 0.0971732396283187, 0.17091551155317575, 0.13559982064180076, 0.17931096808752045, 0.19852037716191262, 0.10426935143186711, 0.1839148811995983, 0.1549342815997079, 0.13915766176069155, 0.09237617516191676, 0.14528769766911864, 0.16235667862929404, 0.07687756384257227, 0.15710651816334575, 0.2381374966353178, 0.1242872784496285, 0.0821235534385778, 0.14399161096662283, 0.11731791062629782, 0.19080009689787403, 0.10886006173677742, 0.2761536551406607, 0.09265580156352371, 0.13094366033328697, 0.15671540633775294, 0.21034333884017542, 0.1661362437880598, 0.21946020744508132, 0.23371119430521503, 0.12189570014015771, 0.14028293575393036, 0.1827338570728898, 0.10771051951451227, 0.167966112785507, 0.22744766087271273, 0.14537491486407816, 0.1712622429477051, 0.08655966696096584, 0.18019119976088405, 0.19183766387868673, 0.08473526017041877, 0.17675340845016763, 0.26481547916773707, 0.09153691004030406, 0.17476038570748642, 0.07931865082355216, 0.14085473085287958, 0.15363679965958, 0.13061546778772026, 0.10968321483233012, 0.19193647342035547, 0.3726240067044273, 0.18892635212978348, 0.22196468868060037, 0.12605676631210372, 0.14669568539829925, 0.10860166075872257, 0.16684411908499897, 0.15413280663779005, 0.1811179195647128, 0.08897177307517268, 0.1807850069599226, 0.07417913715471514, 0.2614072401775047, 0.17410077969543636, 0.1838387962197885, 0.1037244888721034, 0.12872880965005606, 0.18850966589525342, 0.23163803445640951, 0.27237778587732464, 0.5516867560800165, 1.0714814672246575, 1.118310154415667, 2.0109385438263416, 2.3959628585726023, 2.3210125928744674, 2.5262376805767417, 2.7478040289133787, 2.577879996970296, 2.404528073966503, 4.477913416922092, 3.4997029323130846, 4.145335787907243, 4.654258629307151, 5.0351501908153296, 3.2943477015942335, 2.449772721156478, 1.27842916874215, 0.9627269092015922, 0.2026946164551191, 0.1409382076235488, 0.233469165104907, 0.10530524115893058, 0.08445642786682583, 0.15310451650293544, 0.2636691281804815, 0.12872915103798732, 0.1882299652788788, 0.1948256543255411, 0.04568004667817149, 0.12216558956424706, 0.05450334392662626, 0.09533005650155246, 0.15197910892311484, 0.16787885106168687, 0.1494580035796389, 0.17877797246910632, 0.12876728258561343, 0.15258084225934, 0.16838927054777741, 0.17646196705754846, 0.1536106166895479, 0.17870917537948117, 0.19226744159823284, 0.08890977405826561, 0.16291815787553787, 0.17089439003029838, 0.051481901173247024, 0.11866933185956441, 0.10446667365613393, 0.14976896345615387, 0.0701085090986453, 0.10040736335213296, 0.14265412726672366, 0.1355128557770513, 0.04908412964141462, 0.16425573063315824, 0.098028661304852, 0.12322229653364047, 0.1003548786684405, 0.1534604505286552, 0.10518848648644052, 0.16124304151162505, 0.1372341634123586, 0.11809974836069159, 0.20817174052353948, 0.073010558844544, 0.08985489170299843, 0.140350604779087, 0.09652974564232863, 0.12269618062418886, 0.15590138908009976, 0.16217074095038697, 0.06731052329996601, 0.2234116243198514, 0.18239564553368837, 0.0931542131002061, 0.08358035964192823, 0.23614156467374414, 0.08920425083488226, 0.1314168536919169, 0.1504655135795474, 0.10042422494734637, 0.19008149014553055, 0.16000889445422217, 0.11750329911592416, 0.09894114671624266, 0.11328208187478594, 0.08638233077363111, 0.16042489791288972, 0.1253893825924024, 0.15339337522163987], [0.02577433053374989, 0.03979286746471189, 0.056978005668497644, 0.018045877368422225, 0.015216480169328861, 0.07747380528599024, 0.05191895936150104, 0.00980730343144387, 0.04753617657115683, 0.060389747595763765, 0.0765763854724355, 0.025329375894216355, 0.03901885938830674, 0.028808527094952296, 0.077585357503267, 0.0434621606109431, 0.034400452132103965, 0.032711049425415695, 0.048065064402180724, 0.058632716682041064, 0.022428135089285206, 0.08443042301223613, 0.04279586784832645, 0.022708247597620357, 0.053357245269580744, 0.0455428495479282, 0.049344337749062106, 0.05537405755603686, 0.03919096714525949, 0.08249122081906535, 0.017616383520362433, 0.027227156970184296, 0.020650940023188014, 0.017616398363315966, 0.04808852740097791, 0.028507174320111517, 0.011760278030124027, 0.035923892064602114, 0.014727695215697167, 0.012839846858696546, 0.055928044821484946, 0.05874164911801927, 0.011605349136516452, 0.0428542192094028, 0.061984760250197724, 0.044315719496808015, 0.034108806648873724, 0.03303073324786965, 0.052841204014839604, 0.09374830973683856, 0.03600534277211409, 0.032817269311635755, 0.04355505523562897, 0.05010803368350025, 0.04695386152889114, 0.07795879879267886, 0.03419335211219732, 0.05062356656708289, 0.007468224184776773, 0.06842817543656565, 0.01719024974590866, 0.02913926335168071, 0.06885312177473679, 0.052275898997322656, 0.02806747408612864, 0.06315776176052168, 0.03056413865124341, 0.029357341591094155, 0.08665921122883447, 0.041629523402662016, 0.025423040497116745, 0.030268711925600655, 0.08809635794023052, 0.04978154436685145, 0.029630852695845533, 0.021448646730277687, 0.034176034096162766, 0.016862144402693957, 0.07244386230013333, 0.06163574675156269, 0.025769480598683003, 0.06671279756119475, 0.07286123873200268, 0.051533784717321396, 0.04501989889831748, 0.01850712586019654, 0.035973237463622354, 0.10553590807830915, 0.046566675664507784, 0.07570428773760796, 0.009766038165253121, 0.02461141295498237, 0.06777242117095739, 0.0462332992174197, 0.03437765335547738, 0.04204074743029196, 0.050917330881929956, 0.025910188087436836, 0.018819321412593126, 0.12076444443664514, 0.0254755251808092, 0.021442308789119124, 0.07285990286618471, 0.039130114746512845, 0.018817460477293935, 0.047428160687559284, 0.05816793185658753, 0.029345660186663736, 0.03067456837015925, 0.02657757737324573, 0.04467084458156023, 0.04408992106618825, 0.03882881021127105, 0.02427467828965746, 0.034825561742763966, 0.058553295748424716, 0.031062281159393024, 0.04592278091877233, 0.03848884349281434, 0.06062914959329646, 0.07498778868466616, 0.03281244535173755, 0.02168064209399745, 0.060276069125393406, 0.028648659208556637, 0.005880754069949035, 0.00656494140457653, 0.07715166866546497, 0.037857119968975894, 0.050905452808365226, 0.03428421696298756, 0.07160754350479692, 0.0249297516347724, 0.01951654689037241, 0.03724815069290344, 0.058563392667565495, 0.03390919118828606, 0.031449094094568864, 0.012054734397679567, 0.04152069115662016, 0.033518231502966955, 0.030952447013987694, 0.05700490110029932, 0.054155751640792005, 0.06737675998010673, 0.02415305883914698, 0.06930059971637093, 0.06043590547051281, 0.04928721464239061, 0.017718000235618092, 0.03302405762951821, 0.027967558744421694, 0.0927366733958479, 0.0049050822053686716, 0.009634510115574813, 0.037471960167749785, 0.06458088188082911, 0.033371204626746476, 0.09515186684438959, 0.027190235123271123, 0.05392708109866362, 0.03698685533890966, 0.007975152329890989, 0.0243701908402727, 0.04991491572582163, 0.05172244236746337, 0.06203711134730838, 0.035421884822426364, 0.02610288116557058, 0.03536244621500373, 0.021554211671173107, 0.02454280882375315, 0.03811335387581494, 0.027945181136601605, 0.03674074432638008, 0.04221854374918621, 0.07016434086835943, 0.04629731316526886, 0.06363686261465773, 0.07354615197982639, 0.030742109374841675, 0.07449008960975334, 0.06412083195755258, 0.01946936856256798, 0.08540663664462045, 0.01190220727949054, 0.030724067764822394, 0.026263710133207496, 0.07313293899642304, 0.01951874921360286, 0.0781332109181676, 0.01762556017638417, 0.049429784921812825, 0.04831031081266701, 0.047191014818963595, 0.02288728330313461, 0.038685579420416616, 0.009925580434355652, 0.051558205086621456, 0.0035162843278158107, 0.014898551526130177, 0.04013271915027872, 0.02505988351913402, 0.016514737653778866, 0.06191609674715437, 0.09062291806912981, 0.05400176713010296, 0.047162727860268205, 0.006846344786026748, 0.030637069503427483, 0.029535813264374156, 0.020679885637946427, 0.06790147323044948, 0.07922229779069312, 0.02036598129052436, 0.0010290959448866488, 0.05212694624788128, 0.0221336267713923, 0.03758618782740086, 0.06408819972421043, 0.08299079752760008, 0.01332723100858857, 0.04196893722109962, 0.03003555324539775, 0.018668802731554024, 0.0724465043458622, 0.008561627109884284, 0.028091120766475797, 0.009795537607715232, 0.07627220140420832, 0.014504789305647137, 0.11388506201910786, 0.01098130220270832, 0.04116864227398764, 0.04957287841534708, 0.037046301367809065, 0.050119351435569115, 0.04718755270005204, 0.030957794187997933, 0.0379678446915932, 0.05623629214824177, 0.06738643016433343, 0.005266706184556824, 0.0641401277971454, 0.013447217734210426, 0.02595836645923555, 0.04874064885370899, 0.06219037597475108, 0.018114338636223692, 0.017574522680661175, 0.007818128724466078, 0.049928474763873965, 0.049477293505333364, 0.03400426772714127, 0.021611073170788586, 0.08039300606469624, 0.08072277196333744, 0.09311372894444503, 0.1264666990027763, 0.04627436966984533, 0.02792191295156954, 0.02105750892951619, 0.01988865973544307, 0.03203044063411653, 0.044986810244154185, 0.033453679498052225, 0.03585176273190882, 0.05200116334890481, 0.05024533471441828, 0.019466952871880494, 0.03214895419660024, 0.1463407903793268, 0.05346391786588356, 0.10251981249894015, 0.02760099716397235, 0.0383930656244047, 0.10583583964034915, 0.02133958441845607, 0.05651648258208297, 0.06042260989488568, 0.006762014545529382, 0.060656052446574904, 0.062290257919812575, 0.02181791714974679, 0.04046805857797153, 0.014644879884144757, 0.0737564914743416, 0.052950303434045054, 0.0320359807665227, 0.07682062627281994, 0.1220018049934879, 0.00828566506243078, 0.014522962646879023, 0.03417515465116594, 0.03787648631259799, 0.010860302445507841, 0.05198771563300397, 0.028721953713102266, 0.028492899109551217, 0.04957567260134965, 0.021869479714951012, 0.05089206446427852, 0.04498425725614652, 0.0234355374777806, 0.024108227553369943, 0.0790707438136451, 0.009675539749878226, 0.029041084635537118, 0.08222691976698115, 0.02085990839987062, 0.07026439721812494, 0.08385157751035877, 0.04115926152735483, 0.041052889500861056, 0.028574698626471218, 0.04682919185142964, 0.014072360263526207, 0.026015270632342435, 0.11013615498086438, 0.02856355898984475, 0.03818238474195823, 0.04563035246974323, 0.06633551936829463, 0.04693344504630659, 0.006409681791410549, 0.054477186931762844, 0.029751841320830863, 0.08468719868687913, 0.09642971897847019, 0.04135730734560639, 0.06679154685116373, 0.027705552784027532, 0.027052527766500134, 0.031386393748107366, 0.022972878905420657, 0.010618430023896508, 0.07791184310917743, 0.0018909011350842775, 0.006685616472168476, 0.0359989009302808, 0.05988987773889676, 0.03257195610785857, 0.05804777072626166, 0.030187328011379577, 0.02364971202041488, 0.04434465583472047, 0.033946424737223424, 0.014787648688070476, 0.011438579276727978, 0.05352416912501212, 0.017334287622361444, 0.026818369042302947, 0.16762370069045573, 0.07348222337896004, 0.112133422808256, 0.09342300414573401, 0.11090602187323384, 0.14712017902638763, 0.15307454857975245, 0.07565201827674173, 0.15211134479613975, 0.17862449632957578, 0.18175036297179759, 0.0795538151578512, 0.1581696595530957, 0.10697571909986436, 0.2167353083495982, 0.13042504753684625, 0.12399767016177066, 0.09512577293207869, 0.16286947298794985, 0.12891272868728265, 0.09081640338990837, 0.1191355193441268, 0.16891996550839394, 0.0786204011819791, 0.10463200189406052, 0.12241606440511532, 0.11487031501019374, 0.06464754158514552, 0.11777547435485758, 0.19316668709507212, 0.16087625728687271, 0.1349017713801004, 0.09139699293882586, 0.135938388411887, 0.10119265207322314, 0.154801377793774, 0.18315138935577124, 0.11017925149644725, 0.051638075019582175, 0.12993131153052673, 0.18432870274409652, 0.1323989822412841, 0.08417414457653649, 0.14007353136548772, 0.14340688765514642, 0.1039867712825071, 0.09139349000179209, 0.13466609496390447, 0.16927805176237598, 0.23099353857105598, 0.12339158784016035, 0.08534067455912009, 0.11128098456538282, 0.15629186265869066, 0.17133565619587898, 0.1987960553378798, 0.13868463167455047, 0.1513507918571122, 0.08564272124203853, 0.1031242027238477, 0.11178645392647013, 0.19405652215937153, 0.1280578487785533, 0.15617004653904587, 0.18415984930470586, 0.12024266266962513, 0.11679550545522943, 0.10634717196808197, 0.1881569082615897, 0.11060980104957707, 0.09227414469933137, 0.08691560840816237, 0.15380182361695915, 0.16690729069523513, 0.08355790967470966, 0.1191903417930007, 0.09555126845953055, 0.07126576965674758, 0.22156695689773187, 0.21586640184978023, 0.18744456523563713, 0.1834166923072189, 0.22562797414138913, 0.13107096834573895, 0.16346158809028566, 0.14286275982158259, 0.13872877461835742, 0.1303020736668259, 0.16853048640768975, 0.11218044528504834, 0.1115559577010572, 0.13479218585416675, 0.13124789635185152, 0.07056048445519991, 0.09272010865970515, 0.18476449185982347, 0.1551251916680485, 0.20957006548997015, 0.13036874821409583, 0.10630206423229538, 0.15513764490606263, 0.10619203341775574, 0.1061638466489967, 0.11896041702129878, 0.14450486545683816, 0.23065807297825813, 0.16922057984629646, 0.14047550823306665, 0.10258282825816423, 0.08720117199118249, 0.1866311120102182, 0.10866512180655263, 0.21127829648321494, 0.19295447738841176, 0.24394990818109363, 0.1273126879823394, 0.09295046387705952, 0.13283039268571883, 0.1333408270147629, 0.1482963198213838, 0.22382169059710577, 0.17209102894412354, 0.08952423522714525, 0.1613876415649429, 0.15668641804950312, 0.18426171649480239, 0.10895402505411766, 0.22871765366289765, 0.1850012518116273, 0.12822192278690636, 0.09979782262234949, 0.2042177112889476, 0.11048381405998953, 0.14074055885430425, 0.16222270613070577, 0.1489745092112571, 0.09901041878038086, 0.18023197335423902, 0.16259792115306482, 0.16268081904854625, 0.12321388800046407, 0.20633364852983505, 0.18061336304526776, 0.15703709766967222, 0.21033095981692895, 0.12149777539889328, 0.13395885791396722, 0.20314104796852916, 0.20742589695146307, 0.18674317630939186, 0.13957304181531072, 0.16867940576048568, 0.1860137638868764, 0.07680382404942065, 0.14069102791836485, 0.07173261023126543, 0.13076017174171284, 0.170821436913684, 0.19696073897648603, 0.11632909532636404, 0.17451541760237888, 0.0813697392004542, 0.10649309304426424, 0.25625631969887763, 0.19224401941755787, 0.08844116717227735, 0.21999645367031917, 0.15093281428562477, 0.09967670412152074, 0.2500179747585207, 0.11087364197010174, 0.17230782512342557, 0.1019467854348477, 0.09669422783190385, 0.14440129132708535, 0.17534141312353313], [0.019548513046174776, 0.021870375858270563, 0.03097930904914392, 0.030465861600532662, 0.030774765727983322, 0.08596187442890368, 0.06319063890259713, 0.045636705253855325, 0.02513323739549378, 0.07683589225052856, 0.007853219321987126, 0.09798256651265547, 0.024237643265223596, 0.041003106234711595, 0.02714695678150747, 0.06966391068999656, 0.01858276555140037, 0.08087901631370187, 0.017632154158491176, 0.07846442400477827, 0.02985834322316805, 0.0771886647271458, 0.08327970077516511, 0.02359127531235572, 0.09310436304076575, 0.04624488043191377, 0.008238879145210376, 0.02740940617513843, 0.008639608277007937, 0.07121229791664518, 0.026501121319597587, 0.03480173138086684, 0.05655343411490321, 0.043437640051706694, 0.0548222559154965, 0.038970567838987336, 0.019392348476685584, 0.08357109763892367, 0.039164910340332426, 0.04510330516495742, 0.0739080083440058, 0.03710132048581727, 0.027042315814469475, 0.023588330841448624, 0.020623929558496457, 0.07300897806999274, 0.03762487227504607, 0.036077175245736726, 0.05514003612915985, 0.05857842857949436, 0.01574878187966533, 0.030715978355146945, 0.04775993038492743, 0.001646044700009952, 0.002499588858881907, 0.03267276944825426, 0.062495788297383115, 0.048949812044156715, 0.06340333100524731, 0.02885310419515008, 0.02956939544674242, 0.07347368125920184, 0.08436011936282739, 0.07990640951902606, 0.03637839443399571, 0.030989329898147844, 0.013811046355840517, 0.034966562379850075, 0.03687073149194475, 0.04364429849374574, 0.08497288101352751, 0.0029844047139704344, 0.04578264488372952, 0.04141566241742112, 0.06393280884367414, 0.022949026279093232, 0.07506122419727035, 0.04758170362038072, 0.01251182871783385, 0.02497717858204851, 0.02740061543590855, 0.058696982960100286, 0.055774821012164466, 0.020749113173224032, 0.0755054886394646, 0.05004041660868097, 0.0755142088746652, 0.0265839579878957, 0.033167210494866595, 0.04436879047716502, 0.053422472628881223, 0.07514645243645646, 0.05439819273306057, 0.013376400147535605, 0.06178832489240449, 0.053181493567535654, 0.0657922301616054, 0.02705147948290687, 0.037355973618105054, 0.045056742819724604, 0.027351772841939237, 0.003081438435401651, 0.13770367571851239, 0.014330938429338858, 0.027244463854003698, 0.04072353178344201, 0.046877175409463234, 0.0027622894231171813, 0.038591694028582424, 0.04195214241917711, 0.02566690836829366, 0.048976711186696775, 0.025803877288126387, 0.05567102794884704, 0.07476116647012532, 0.03568438616639469, 0.03356776614964474, 0.018040537615888752, 0.02794642794469837, 0.057748982071643695, 0.050406325099174865, 0.03126777628494892, 0.03951317798055243, 0.03330701256345492, 0.03865866172418464, 0.06421542610041797, 0.08164229293470271, 0.039883394638309255, 0.03729855736310128, 0.06352946642437018, 0.0537895796878729, 0.02435379494272638, 0.03983987509855069, 0.0342690474644769, 0.023121475423977245, 0.015075605697347783, 0.024302625715790782, 0.030960080002842005, 0.03713549638632685, 0.04830057754588779, 0.024947587298811413, 0.04175863854470663, 0.05840382720634807, 0.029781397352053318, 0.07049930180073716, 0.08923068613512442, 0.0349636346072657, 0.08011899029952474, 0.05434719605545979, 0.013991961550345877, 0.011671317715808982, 0.045964875534991734, 0.064938337309286, 0.015570043033221737, 0.018947410535474773, 0.04867186660703737, 0.03775988006964326, 0.025693961506476626, 0.04638989608793054, 0.019591646669141483, 0.0536556814040523, 0.05173905534320511, 0.033497161930426955, 0.02734056270128349, 0.014512184807244921, 0.03373750274477061, 0.03724018002685625, 0.044831590057583526, 0.021326871428755112, 0.01383686938424944, 0.012777478623320349, 0.04450740139873233, 0.034105021695722826, 0.02961828256957233, 0.020040818562847562, 0.02792554205370834, 0.04805181706615258, 0.032804300280986354, 0.02529408120608423, 0.019363859282748308, 0.035048580830334686, 0.04896574595477432, 0.023532803352281917, 0.03605867350415792, 0.028926623199367896, 0.03811730581219308, 0.012182675091025885, 0.0653200015949551, 0.061084364424459636, 0.05169455616851337, 0.04930960523779504, 0.036919780031894334, 0.05107509292429313, 0.039782696330803446, 0.07285750572918914, 0.046197787451092154, 0.03063572436076356, 0.026654927714844234, 0.02206723980634706, 0.09318486379925162, 0.027619818029052112, 0.043659649818437174, 0.05982419024803676, 0.006904749488967354, 0.09739488203194924, 0.05794172524474561, 0.048190390880336054, 0.08641859210911207, 0.02285427999595413, 0.028643523546634242, 0.06404284707969055, 0.018938699577120133, 0.023634805984329432, 0.042378877333248965, 0.01113494439778151, 0.020176512844045646, 0.05343802062270697, 0.028805044566979632, 0.03602080912969541, 0.04464224221010227, 0.10182712896494195, 0.023921286119730212, 0.02732084940362256, 0.04976518001058139, 0.005428186850622296, 0.018725079789874144, 0.05457647144794464, 0.056264067025040276, 0.025690532784210518, 0.04703941631305497, 0.04423127422342077, 0.003340451917210885, 0.029013482308073435, 0.06976917691645212, 0.018397549611108843, 0.03632998043030966, 0.018275061847816687, 0.07466483570169657, 0.033475966192781925, 0.05970518686808646, 0.11991717896307819, 0.057265394934802316, 0.029637003244715743, 0.05834316405525897, 0.05685132848157082, 0.054930950864218175, 0.11265808410826139, 0.04070094080816489, 0.08664369292091578, 0.06328248709905893, 0.04244679868861567, 0.048916634332272224, 0.03754961478989571, 0.025827479439612944, 0.017898757723742165, 0.08418661265750416, 0.04034873236378189, 0.0462104150938103, 0.08717179778614081, 0.01105447703594109, 0.030151165010465775, 0.023029384174151346, 0.021393306633399334, 0.03463919732894283, 0.020367285615066066, 0.024690060199645814, 0.0468810345773818, 0.05802829306048807, 0.010473831825947855, 0.05479696352267638, 0.08777440685662441, 0.03626164347224403, 0.027858355424541514, 0.06586105693713762, 0.09111695835599676, 0.09369902370963246, 0.028924715879838914, 0.02264749909954844, 0.05378018780902494, 0.030078733252594247, 0.07791936848661862, 0.030219260770536494, 0.047946899649105035, 0.06616281418246217, 0.04259059722244274, 0.02694532638997771, 0.0635575715568848, 0.019198651643819176, 0.03737347346032038, 0.05390971855376847, 0.011364271740603726, 0.04421276134962682, 0.04424579063197598, 0.06477064904174767, 0.03485223453026265, 0.010486737774044741, 0.026198710984317586, 0.04142898767895531, 0.025364793036715128, 0.035961934554507025, 0.0324276046740124, 0.011302482380415313, 0.07517838705098256, 0.06753589128493331, 0.029549069877248257, 0.07545376094640233, 0.04952488743583672, 0.021297024104569573, 0.015523934325756272, 0.030817318620393053, 0.03318198294437025, 0.09203909168718383, 0.027181297809875105, 0.011727321107173339, 0.04585864080581814, 0.041488244460197166, 0.024512534764653537, 0.04428505024407059, 0.04355356722953729, 0.04172249224211555, 0.05965888798527885, 0.03446481117862277, 0.04782637857715599, 0.033650500772637315, 0.09134923573583364, 0.045386523561319336, 0.03964326904679183, 0.014342440790642286, 0.028666101534327026, 0.0711832131491974, 0.010425895579828648, 0.035513807233655825, 0.016146684356499463, 0.04339216495282017, 0.032523089394089766, 0.012216541144880466, 0.048258846582029946, 0.03206227134796791, 0.04719067714177072, 0.10311969046597369, 0.029128459536877926, 0.03021958917088341, 0.03124884780845605, 0.009867598291748436, 0.07378323847660795, 0.016772010567365214, 0.021906562978983857, 0.030911306057532784, 0.07226036628708243, 0.1058895414462313, 0.032682335731806234, 0.048276632151100785, 0.13971105159725994, 0.15399598429212347, 0.15645889041479677, 0.11292956172837876, 0.08355084442882799, 0.1779563704621978, 0.14298871712526307, 0.12826695630792528, 0.11867049703141674, 0.19160556461429223, 0.08106114677502774, 0.1189178103231825, 0.11963316646870226, 0.08710373542271554, 0.08718154218513519, 0.1267975039081648, 0.08394680990022607, 0.16205505497055128, 0.1723721099551767, 0.15943877660902217, 0.13202290632762015, 0.1511746208416298, 0.10620271292282268, 0.17814273858675733, 0.160436965234112, 0.12188812281237915, 0.12794384005246684, 0.1628475944744423, 0.22466920840088278, 0.12496036186348647, 0.11342727564624511, 0.13690625288290903, 0.15836650680284947, 0.13506943738320842, 0.17854913865448907, 0.10370281073846854, 0.10307646778528579, 0.1932689847308211, 0.10163070473936386, 0.06325265276245773, 0.17051357921445742, 0.17450931714847684, 0.08027802512515336, 0.13230302254669368, 0.18708086834521964, 0.16468144138343632, 0.2545228408416733, 0.18930121092125773, 0.21175729343667626, 0.1398824728676118, 0.07583939572214149, 0.16374226834159344, 0.1268726834678091, 0.13889679685235023, 0.1592688396340236, 0.08983440100564621, 0.13125188910635188, 0.09838518904871307, 0.17104299768107012, 0.17457142006605864, 0.05384703676099889, 0.26170181343331933, 0.2277148637222126, 0.20177865779260173, 0.2874286298174411, 0.11392495987820439, 0.11972498497925699, 0.09642167409765534, 0.14902463386533782, 0.12556975416373461, 0.26760755747091025, 0.10728507593739778, 0.11752988284570165, 0.1608313573524356, 0.1582563720876351, 0.11099720213678665, 0.13766707299510017, 0.0870657003542874, 0.0908973123296164, 0.15728075959486887, 0.13977882452309132, 0.12758122669765726, 0.20797415112610906, 0.12780192657373846, 0.16529298591194674, 0.14319552399683744, 0.11825528767076321, 0.1651320734526962, 0.06266392185352743, 0.1112076677964069, 0.15484326460864395, 0.20726968970848247, 0.18259354663314298, 0.12789760425221175, 0.15132490574615076, 0.24916367372497916, 0.14734957687323913, 0.22388118115486577, 0.15447128535015509, 0.15559482271783054, 0.2165480051189661, 0.13258487539133057, 0.2131564644514583, 0.10023482886026613, 0.16999331885017455, 0.13980980176711455, 0.1325376154272817, 0.0791004000348039, 0.11317654105369002, 0.1250053953845054, 0.1671638511470519, 0.15999127586837858, 0.17864278284832835, 0.12236563547048718, 0.1634538994403556, 0.18687971663894132, 0.15474227315280586, 0.08463066929834895, 0.10141321836272255, 0.10055395978270099, 0.1256144166109152, 0.158324827789329, 0.1292339598876424, 0.11055862254579552, 0.17168384219985455, 0.1426265193731524, 0.17152569052996114, 0.14991924836067483, 0.20590627536876127, 0.16808371350634843, 0.1264310462283902, 0.16781502636149526, 0.1044780136726331, 0.11713937958120368, 0.14463919418631122, 0.16470952425152063, 0.14060878311283886, 0.13386450125835836, 0.13591480295872316, 0.22571815992705524, 0.051864559936802834, 0.13362207129830495, 0.12976462516235188, 0.16150021052453667, 0.17008740833261982, 0.1486396076506935, 0.1751666225027293, 0.20528125343844295, 0.13859082420822233, 0.11192899823072366, 0.1570972561603412, 0.13333625538507476, 0.18679180182516575, 0.11589998553972691, 0.07210570271126926, 0.12068359486875124, 0.10207136234384961, 0.11191663405043073, 0.2148916947771795, 0.045601130404975265, 0.14547075581504032, 0.12123135180445388, 0.1553247106494382, 0.19047160749323666, 0.16749147966038436, 0.09694905165815726, 0.10470305511262268, 0.09038086660439149, 0.1304530116613023, 0.05696296975656878, 0.14437484118388966, 0.1728141331113875, 0.16000258619897068, 0.1415423900471069, 0.10588894030661322, 0.12662018998526037], [0.03339116468850989, 0.0268489882000722, 0.01513096249254886, 0.03490162816888187, 0.026918581243080553, 0.0011284142055956181, 0.025417934521101415, 0.017247027753910515, 0.07145794879761524, 0.04933440410241019, 0.023320224427152425, 0.023771817577653565, 0.054161915177246556, 0.02677277705515735, 0.01362553355647833, 0.01687219864834333, 0.09332809830084443, 0.016951690085988957, 0.025447095358686056, 0.030675813322886825, 0.010114465367223602, 0.007863640003051842, 0.02805834010359831, 0.018055031760013662, 0.03831355563306715, 0.03491426323307678, 0.019009003226528876, 0.029494570262613706, 0.0033083591324611916, 0.04537332075415179, 0.030294599891931284, 0.020252874273865018, 0.04807753619388677, 0.013433628082566429, 0.02430381500744261, 0.019630460992630105, 0.0879693245224189, 0.028191533347126096, 0.025916453669196926, 0.037900602401350625, 0.06383925370755605, 0.01407735677275923, 0.050580217721289955, 0.07416736669256352, 0.023384451742458623, 0.056048436017590575, 0.032735069034970365, 0.004208045975246932, 0.05850278517755214, 0.05408729222835973, 0.013042952268733643, 0.04605067151715048, 0.018217736505903304, 0.031409333532792516, 0.012014637086394941, 0.03354727174155414, 0.03454323763435241, 0.078774374560453, 0.07131557518732734, 0.07348281709710136, 0.031537023751297966, 0.05891352309845388, 0.008838035373628372, 0.06076900732296053, 0.021126098217791878, 0.05026151724450756, 0.03747174865566194, 0.04415560113557149, 0.025743464611878153, 0.05011874658521265, 0.05018459734856151, 0.007191986614998314, 0.027708847919711843, 0.02533067650801968, 0.03509015965391882, 0.06769633619114757, 0.024571162575739436, 0.020500068822002504, 0.028185321571072564, 0.02429899846902117, 0.04250736536050681, 0.05685788535629399, 0.006504343191409134, 0.015215321491268696, 0.024982345785247162, 0.037013917753938586, 0.006789447106712032, 0.022903721874172334, 0.017546224589750636, 0.07048761297482997, 0.05349981183826458, 0.053802366892341524, 0.020354422340460587, 0.05287412568577565, 0.0796629257092718, 0.007158398402680177, 0.05748501869675238, 0.05652981897583231, 0.026799778243002947, 0.059604737180052325, 0.051297555401106365, 0.06666069879429415, 0.06515963090350851, 0.03628605270932894, 0.018934499021270312, 0.05954305728664622, 0.03392825325136073, 0.04158043404459022, 0.06341165790217929, 0.02943428004073212, 0.02894889134040568, 0.01641988190385746, 0.017569797055330127, 0.03566425912140403, 0.10516946524148807, 0.015815517654118594, 0.021565169481618796, 0.015833687284612097, 0.04708125859906431, 0.06659739359747618, 0.0327846593427239, 0.06304073991486803, 0.040719746830291115, 0.07480309039237909, 0.0209442349296296, 0.026096940273419023, 0.04045313769893255, 0.09286404078011401, 0.03630454702943098, 0.029682187050639186, 0.047725327749503776, 0.08756233815802261, 0.03099714100244455, 0.03660108326585032, 0.05076621106127277, 0.04527658922597766, 0.02451149204716785, 0.07147172305849381, 0.059030274060205556, 0.01047927269610227, 0.011018451332347468, 0.11996489905868657, 0.05345429221051745, 0.07052984859910794, 0.014999964150774758, 0.04495320208661724, 0.045740386995021254, 0.018851361783163156, 0.08412462848355062, 0.023894665282568894, 0.039577199349878356, 0.03845283077680506, 0.026649664032447618, 0.034882914915215224, 0.05125844421854708, 0.06486175509053282, 0.008519140083080856, 0.028367056838760618, 0.03546094776538666, 0.025058779574465007, 0.05905500613152981, 0.04297836196201388, 0.031307577664847486, 0.037941743357805535, 0.053026778041385114, 0.05017884941480588, 0.04287416442821268, 0.018257270712638274, 0.0268012495507719, 0.010554280634096358, 0.03256755888287444, 0.04068907015607692, 0.019751933868974447, 0.043671116000041366, 0.011881712871399941, 0.0122915166139137, 0.07540341364801861, 0.03924271710275207, 0.04046535716042854, 0.024408925382886082, 0.03623017270001583, 0.03705709219502751, 0.06887770170578733, 0.007871673751651542, 0.05136538398801349, 0.037887611106270924, 0.07303715741727501, 0.01593372693605488, 0.030248814946389757, 0.012418114947649883, 0.02087528569973074, 0.037256191862979904, 0.029057322826702148, 0.13790720229735598, 0.04638369173335377, 0.04288984229788184, 0.021855195227544755, 0.026869844405155163, 0.020651068043662235, 0.024810612812871113, 0.09941252181306481, 0.03501336963381618, 0.018038157177215908, 0.047505737384199165, 0.022802602397860028, 0.04407454747706652, 0.04085810542164836, 0.00254827397839108, 0.08739633456571028, 0.05182109605812002, 0.036137296629021876, 0.05679518129909411, 0.04514542204560712, 0.033299617061857134, 0.04747278602735605, 0.022779979881306645, 0.019612757059803698, 0.021107173452037387, 0.022401464157155715, 0.05432453457615338, 0.049785692972363904, 0.014083207679504994, 0.040077392040984705, 0.02052062816801481, 0.025225161662092432, 0.01557228431920521, 0.04790161379787605, 0.04397201235406101, 0.018722177992458455, 0.020763646280101966, 0.05926418787566945, 0.06498731163446791, 0.01590761632542126, 0.02673599992704112, 0.03052065621886868, 0.07639464092790149, 0.036512404039967805, 0.060494327335618436, 0.02408360865956638, 0.011190043296664953, 0.02964640068967128, 0.04583347457810305, 0.02592119784821989, 0.034884855631389655, 0.05689193509169854, 0.05055742265540175, 0.028592161361302715, 0.034622784733073786, 0.0723348259634804, 0.046769222608418204, 0.09418475936399773, 0.06301510613411665, 0.015523917627433548, 0.037902357580605894, 0.043492484765010886, 0.024841962986101862, 0.044231660140212625, 0.0581112800136907, 0.013477591983246384, 0.0025752287820068887, 0.03463187975285109, 0.07199023937573656, 0.03751275973627344, 0.021451537395478226, 0.018873255139624234, 0.03360321854415815, 0.030327272943395656, 0.06989963905652985, 0.07048027313430794, 0.04902996028249618, 0.07788614253513515, 0.034216095227748156, 0.001279254561268317, 0.032073032489279285, 0.027303735478199087, 0.0599733285343973, 0.00733685198611056, 0.08105164728476666, 0.057109402914647944, 0.06525946460897103, 0.028110078928875737, 0.03397059648705181, 0.029799377734889276, 0.07632211083546281, 0.045016600051894784, 0.05336660375178326, 0.021501055343833286, 0.026123292082047556, 0.03842491489194799, 0.04587548384733964, 0.03486892914224882, 0.06849477576906793, 0.014344388928293483, 0.06190926898852922, 0.006280736879489268, 0.03926953089830931, 0.03138830106763635, 0.030904860504961107, 0.019783228381129447, 0.06505671728518791, 0.005753672876380733, 0.017933770395757165, 0.023056457721395418, 0.07010181492660195, 0.01993081001273822, 0.010643332789186388, 0.03948328798287548, 0.03546472900779918, 0.014163398591335863, 0.07811934759956785, 0.07001318022958003, 0.023549191828351468, 0.035062774404650554, 0.13647904299432412, 0.051288924223626964, 0.06660879298578948, 0.02682702433958184, 0.024897765069908928, 0.033609923848416656, 0.012218993942951784, 0.03344762728374917, 0.10225699574220926, 0.03334610890306067, 0.03535394491336774, 0.02116859544912586, 0.09554104908602312, 0.025756468894542195, 0.048077172541525215, 0.02132558565790532, 0.015697640483267605, 0.056048699480015785, 0.008633010584162548, 0.015672119880036917, 0.02508394951291848, 0.01517970582426642, 0.023284256240003742, 0.05650589213473722, 0.039620529641979374, 0.0610503109783167, 0.0209319301211508, 0.02658356650499627, 0.05280782592308242, 0.06086758308811113, 0.03727925039129332, 0.014851511423330521, 0.03269687069405336, 0.0479995142086409, 0.01638213998376159, 0.01625840912311105, 0.03425901733862702, 0.01358836309009348, 0.023891316341178026, 0.17281410342548043, 0.10070187723613344, 0.17662938073044643, 0.23423096485203132, 0.09604307488189079, 0.11295694697764702, 0.17167820187751204, 0.06635937941609882, 0.18821218342054635, 0.11833451193524525, 0.10208761537796818, 0.0978226336883381, 0.12548261118354276, 0.09749517586897127, 0.11206943483557552, 0.08083781969617121, 0.17369846143992618, 0.18471864197636023, 0.22424207272706553, 0.05297752170008607, 0.15697282768087462, 0.1152272212493699, 0.1157651373068802, 0.09327512379968539, 0.16020937822759151, 0.187761343549937, 0.1460341498022899, 0.10732200520578772, 0.10575403270195238, 0.09915550865116529, 0.08256487155449577, 0.12444272128050216, 0.1402947655878961, 0.22991700883721933, 0.15593162417644635, 0.12133927491959184, 0.15273077093297616, 0.11116445995867252, 0.11480265340651385, 0.11440838745329529, 0.2647243731189519, 0.14717616664711386, 0.1159758330322802, 0.1648027973715216, 0.15472970117116347, 0.13597708399174735, 0.08219973489758559, 0.13730199571000412, 0.1436717898468487, 0.1161188523110468, 0.1269181474344805, 0.12244875601027161, 0.10159180135815404, 0.09409892256371677, 0.09092961059650406, 0.10856882814550772, 0.09870997513644397, 0.1583876580116339, 0.1714267474017106, 0.14882410556310788, 0.1502936618635431, 0.19589373841881752, 0.1316662598401308, 0.08225423080148175, 0.12366498020128347, 0.09082893826416694, 0.14056545653147623, 0.10989307935233228, 0.1443940628087148, 0.14776745054405183, 0.09232540483935736, 0.12337959473370574, 0.1460548854083754, 0.14244485646486282, 0.142207651224453, 0.19507396209519356, 0.09920424548909068, 0.17205064126756042, 0.11769229444325902, 0.09271915871067904, 0.09069300649571232, 0.327526957844384, 0.10533508291700855, 0.1333101763157174, 0.15169197198702022, 0.10972857489832677, 0.11722355397068895, 0.18658247165149078, 0.07478142710169777, 0.1803104332066141, 0.15464163792785257, 0.07977140543516725, 0.1341965381288901, 0.11577544573810883, 0.18782849307172, 0.06517508983961307, 0.1400285423733294, 0.22138532367534935, 0.1045297562086489, 0.16845499514602125, 0.26514226163271815, 0.18387248972430825, 0.10464207283803262, 0.10238844493869692, 0.20504679414443672, 0.11964443227043375, 0.07777378137689084, 0.13297641766257584, 0.11508045412483625, 0.19607614347478375, 0.07065202094963752, 0.11411516490625218, 0.15576452220557258, 0.13364374201046303, 0.18594667373690754, 0.0924913861672394, 0.11763867427362129, 0.15986281010555103, 0.10242765260045417, 0.15129924227949232, 0.11058099829824641, 0.20023890916490927, 0.15378341835457832, 0.1314355558133684, 0.08106904322630726, 0.1074972485366743, 0.0872378637723159, 0.2868379990104586, 0.14984625071519986, 0.1261054363567382, 0.09476990569964983, 0.20490201597567648, 0.15416940936120227, 0.13998859998537228, 0.13690421939827502, 0.1262730429880321, 0.18090937606757507, 0.16698523104423657, 0.177904850570485, 0.08075269535765983, 0.1002494862768799, 0.22706763673340902, 0.1318463493953459, 0.09927476436132565, 0.18624737713253126, 0.13700553739909083, 0.14470968337263912, 0.15603436710080132, 0.13165077863959596, 0.17059420613804832, 0.12807061371859163, 0.09046367544215173, 0.09652789027313702, 0.15455284737981856, 0.14248134044464678, 0.1800109024043195, 0.09778267645742744, 0.14748984278412536, 0.1272424659691751, 0.12000343136605807, 0.15416001377161592, 0.19991491717519239, 0.09489138043136336, 0.10806057573063299, 0.14712515141582116, 0.09366194601170719, 0.10273913198034279, 0.1553294010227546, 0.09689468191936612, 0.13994108769111335, 0.11671271888189949, 0.13816903199767694, 0.09044814971275628, 0.19231784826843068, 0.0680820229172241, 0.10300558526068926], [0.0782947764673736, 0.015877646546869073, 0.03368806828802917, 0.060103553187218495, 0.027114222502859775, 0.017984049045480788, 0.034642603786778636, 0.09498867599177174, 0.047874213705654256, 0.03336314119223971, 0.04175274589215405, 0.12181248312117532, 0.08586342111811973, 0.011521855667524505, 0.014596861074096523, 0.031575225802953355, 0.06044707108230796, 0.03544504725141451, 0.024539064688724466, 0.016630525678920094, 0.030649841864942573, 0.03688066513859667, 0.05577506963163614, 0.06611642253119498, 0.039738293635309674, 0.01687718216999201, 0.02627947149449028, 0.01695062695944216, 0.027299559042148758, 0.025301881178165786, 0.060349742125254124, 0.035462866217130795, 0.006922567063156748, 0.04184816010820214, 0.028908488820889033, 0.029856558358005714, 0.04555014857032802, 0.008705289274075767, 0.047328367800218984, 0.02579730557044968, 0.07177409628638998, 0.04295967097277753, 0.028674879285972565, 0.03658636276668403, 0.06996919313678518, 0.018587921622383874, 0.01398106311171432, 0.040943649073597044, 0.04429459797393065, 0.02215039188740775, 0.02095515934342984, 0.04176571863354184, 0.01629311009310186, 0.021534737716137897, 0.05116508204082493, 0.04749368119519204, 0.04933852673275396, 0.10041128931334242, 0.03898640155966859, 0.06890941367601044, 0.024345458768948447, 0.047267456029658206, 0.08965818546130322, 0.040652901589055546, 0.009830043763940921, 0.07342860320932232, 0.030331130255945027, 0.041570181274437346, 0.029111807598383166, 0.06918589337146841, 0.04368134650576394, 0.05630300751363393, 0.024950342522060964, 0.04114087481866591, 0.031256362053682096, 0.047175281288218684, 0.01771485352946911, 0.05600900200079195, 0.023782855168974493, 0.06411312104319222, 0.03735692356713116, 0.026927887774945702, 0.027918261585000437, 0.010971052215609234, 0.018438417828292586, 0.03355743545398582, 0.06808712147176266, 0.07841677812393755, 0.07144315037294291, 0.02342979882087093, 0.02165096731914673, 0.024242693580163177, 0.011405984150769655, 0.020474522243603133, 0.04125579638639465, 0.005501839441421907, 0.013119857321726158, 0.034862305474234745, 0.03431897173868492, 0.004980690355296247, 0.021606995069305412, 0.039734174715704285, 0.03477114005363546, 0.1192743974388577, 0.01830703542509582, 0.04379082442028448, 0.010001253522204934, 0.025478684874542523, 0.0050022260893456405, 0.0426961751509225, 0.00863409226440126, 0.017780672751541715, 0.03832895519735757, 0.027429635265434626, 0.004411722838995047, 0.062849748210283, 0.041397090171813034, 0.020401721267262474, 0.06440188328269869, 0.09025837513036095, 0.06556348540470935, 0.019163802244293038, 0.020062500407220796, 0.005077476153019234, 0.0504329199611675, 0.015898098281468265, 0.02471138952387264, 0.04807440433069132, 0.06817501402110793, 0.0251356011358439, 0.027359272244211752, 0.06371527793817222, 0.025617024912207853, 0.02821847145241918, 0.07785882407915778, 0.011372236840543337, 0.018736048732534982, 0.046605957541032694, 0.04747726117784623, 0.013091159398754826, 0.017029068258125335, 0.0824237299093511, 0.012682255510299001, 0.04685101470386144, 0.025998965647886507, 0.07268885266967118, 0.013105768575769616, 0.014343892617034726, 0.024796209581836592, 0.027067370720033068, 0.062455014704028144, 0.058875740360235795, 0.04685274019720964, 0.04740656047943048, 0.05220722065132577, 0.06013357677147724, 0.03887539482093416, 0.004195554702164372, 0.06608836934901774, 0.07993228820851073, 0.03909296283381991, 0.015790835677762516, 0.04525548996753059, 0.01740978073939914, 0.031013139850983862, 0.029824362136423588, 0.01135046501076431, 0.01405712397172465, 0.019578933679440524, 0.03282260164269246, 0.04561900132102892, 0.014354172290040879, 0.053821944748051465, 0.08345638387254439, 0.018019802009803243, 0.07002935162745416, 0.014802678106207168, 0.03317114016681444, 0.02281349341501482, 0.037579868439934216, 0.035113396297674626, 0.041650440834928304, 0.03457807033555582, 0.024704259340069257, 0.032626852771500126, 0.04488552935072221, 0.026282620056008454, 0.023112272792786825, 0.041519537116982974, 0.03335872541356366, 0.03182885848218575, 0.04017668397864327, 0.06158542542834766, 0.020246901840437204, 0.05804289110528771, 0.10382333552115597, 0.03900254698237404, 0.02485265547875315, 0.02804131894663442, 0.05950086248049047, 0.10243330034427345, 0.08681166320457123, 0.01459634157072287, 0.04820078094780911, 0.027704675194399897, 0.030370109707291704, 0.04105104526388459, 0.06257083427044563, 0.016410707103204913, 0.09271484683267772, 0.04519160218478646, 0.03626119076216128, 0.02507306035113288, 0.05425198964076117, 0.1111209552618675, 0.018355722168053035, 0.02696936826396268, 0.029810046107741073, 0.06343513203319162, 0.03967345961427782, 0.020291519758757204, 0.05630380161164794, 0.09586138970917091, 0.024938681526691653, 0.08487721817800775, 0.11989420949248597, 0.044006655807606876, 0.044228572805877775, 0.049110438776551746, 0.03443257599428762, 0.040360417478950694, 0.05707268515834585, 0.028348929881758522, 0.04324989153246861, 0.043885975173907354, 0.11678642898914404, 0.030369525265996344, 0.045122704905224964, 0.06290123099461198, 0.03194314551365096, 0.015594422584399581, 0.06294397870078683, 0.05311019915097859, 0.026267598987033125, 0.06440356795792468, 0.05666532029863447, 0.03925409051589668, 0.018613913489389233, 0.015837507489777636, 0.05669993035553489, 0.03853396607155446, 0.04936159268254414, 0.013672919685632223, 0.01665449519350659, 0.06695213276543655, 0.008974194424808957, 0.06617010207264684, 0.027879554872924928, 0.048167762797675095, 0.04528176941676065, 0.03622783493483439, 0.03669077552331146, 0.0551915263349656, 0.03901536387274973, 0.05488538299687207, 0.07720407171291299, 0.05101578419271391, 0.03221653045329731, 0.04770516730786767, 0.07637184957275167, 0.011843611009680899, 0.009600892681191908, 0.045615372218890116, 0.04548784898361191, 0.028546671419462655, 0.01218607783812331, 0.01778644109435845, 0.011560148632270284, 0.04466005375434179, 0.05833829185576178, 0.08720330937649123, 0.03790909257077146, 0.02226668828370748, 0.004462589640752412, 0.04980166027962696, 0.0477498000691412, 0.024882270881789736, 0.05566484585870057, 0.010777924053400056, 0.026245635126542766, 0.05498984028236009, 0.031077268831722904, 0.05855136245372705, 0.030419384602282662, 0.037015272173448466, 0.012296395307203056, 0.03121839377854485, 0.03218589459720533, 0.007793817821948323, 0.040977056851261295, 0.038048868664191104, 0.02561447377956938, 0.047706276818644255, 0.04323326742451172, 0.05981012283882592, 0.041310956512461416, 0.037394004975794815, 0.02686284038645681, 0.038579348401981406, 0.029396155914582778, 0.05991525176796131, 0.04852031262998935, 0.020570120141201187, 0.029415501849143766, 0.03713441656145733, 0.0065931100834859535, 0.0370189161185408, 0.03222871651814785, 0.048744545129011385, 0.01632572562812129, 0.05486559362907428, 0.06504537726868875, 0.04851733290706761, 0.03700240333273541, 0.040789690538076684, 0.09538257087115198, 0.024764586669334676, 0.030197137348295655, 0.03547344924299978, 0.03506102664687205, 0.03221738392312545, 0.027039608830818906, 0.04429709901160095, 0.06381961648003198, 0.015788548007549252, 0.05265961903205607, 0.008984580781543627, 0.05172446843062062, 0.06674727774225175, 0.015943929611239582, 0.014010120976308826, 0.015116019349079579, 0.037100511544849724, 0.05047049118729774, 0.05403622875746805, 0.021823683637194335, 0.03800566082645673, 0.030853780335746706, 0.058179850748274475, 0.025637519320298452, 0.03124662507616449, 0.05805821645481046, 0.16737108846427873, 0.07608157335198484, 0.07677159257582389, 0.13911133690271527, 0.16634259052807465, 0.09947327402187511, 0.10229569874354638, 0.11699592985678464, 0.15027853689389303, 0.1287040812894702, 0.10896042236709036, 0.3021223226096481, 0.11762143418309279, 0.06851724800071679, 0.12589849589858204, 0.17794887477066368, 0.15515532286372036, 0.1706441823625937, 0.1319752901326865, 0.14957891427911818, 0.1634555618511513, 0.12426976376445964, 0.18845143698854372, 0.15920906706014648, 0.1664724960573949, 0.13876298762625083, 0.10059156440547667, 0.19661645666928962, 0.12161850798293017, 0.09215980200679041, 0.2022388338809833, 0.12904638948384672, 0.15218202694086358, 0.17778552806703374, 0.1696946786250919, 0.1664447397342883, 0.08789113926468417, 0.14626289455918595, 0.1791743832291104, 0.0997253593232017, 0.1167273020837456, 0.1824233721708879, 0.134460371627938, 0.154798899020534, 0.07939301402075216, 0.11606947722611949, 0.1330893428530544, 0.1298679766478017, 0.1474264040007256, 0.14269913110183552, 0.14211590692866594, 0.12666399154113606, 0.07468218711437657, 0.12663997564231977, 0.11481115099741146, 0.15075328876264393, 0.1951875552185811, 0.194923410017509, 0.1688522964832373, 0.1746665485552512, 0.11344657148583792, 0.16911553626414388, 0.28762342873960733, 0.14455751341301948, 0.15403071680339053, 0.21773322980152443, 0.16036657994845882, 0.05750988064392004, 0.09508157803793438, 0.09780554202734493, 0.22326779610011727, 0.0847601963323541, 0.1111530902562663, 0.11623332859016955, 0.18706614413531497, 0.1619106627185829, 0.13208474207203835, 0.11063055892009288, 0.19427821651333943, 0.08830864186165854, 0.15490671823499724, 0.16236922092502937, 0.14571621373761445, 0.18057499401038513, 0.11984690499957651, 0.14178823388647288, 0.20365730073535815, 0.09932333050528541, 0.11574699921766296, 0.26478113257326186, 0.09320683137048036, 0.101100306637818, 0.0774539157282561, 0.1422112135333009, 0.10173059781664051, 0.0666143442504108, 0.1758332789177075, 0.1053481521375943, 0.12813880224712193, 0.1434820523718372, 0.07617505427333526, 0.15555358899291605, 0.12776146468240768, 0.20818073535338044, 0.11357907453202643, 0.15700186049798504, 0.14581913477741182, 0.12025599164189771, 0.16393516736570746, 0.26609618857037276, 0.09894781120237894, 0.13233572157332674, 0.1930579327745363, 0.2505936735542491, 0.1684220734750852, 0.16303526877891272, 0.1820030197268352, 0.16141280037118122, 0.22944109921809286, 0.21839623484993353, 0.21517405228223652, 0.09187077259412035, 0.10455645126057789, 0.14328793622553349, 0.13603602536022663, 0.08060903041041456, 0.15411788946948946, 0.1631369281676598, 0.12730918504530564, 0.14959056599764153, 0.1114007894648239, 0.08822418545605615, 0.09720773465232924, 0.1962286845082417, 0.15802397596416995, 0.16175484139239416, 0.2104174200212583, 0.12350368924671784, 0.14067832235014066, 0.10317008971469477, 0.23618466861080378, 0.18097593187121674, 0.15129189501749352, 0.11649503212538548, 0.13167185563361272, 0.20682359958300367, 0.14090365322772413, 0.23070631257724017, 0.12592193292221054, 0.20078453613677993, 0.14245410362491384, 0.2340247665415518, 0.08761376899201423, 0.1429838634794578, 0.19060900871409103, 0.13251527678221464, 0.131770680018235, 0.12076397688360885, 0.159606353554409, 0.17858375242212787, 0.1176321656384971, 0.1558810839196667, 0.2551797009073198, 0.08970687777036801, 0.10067823241115548, 0.12857232039095834, 0.11908811837201938, 0.16345513140549883, 0.14041837770491838, 0.08661031853989698, 0.18458921142155305, 0.09362676821183413, 0.10191930370638147, 0.11253027885686606, 0.10654866506229155, 0.17383048951160163], [0.0493520189775154, 0.06652395808487199, 0.062015414659981616, 0.03398087152163498, 0.048098965708049946, 0.06961213104659691, 0.06059945255401544, 0.007887322863098234, 0.029893521023041103, 0.03455628830124624, 0.061510468513006344, 0.02630286955536576, 0.02843273319740547, 0.04140966586419381, 0.0067548625611379975, 0.015137340324145043, 0.09943929850123823, 0.017927977933140937, 0.019030493967875373, 0.028902592457598075, 0.046005730764591135, 0.018422008943161927, 0.11043005288229324, 0.007331306751439115, 0.03288181389507372, 0.009272328134102281, 0.044059901192667894, 0.04894453908491414, 0.04404690989758819, 0.01242580638063373, 0.05368291451304685, 0.01821200712583959, 0.012074790010956349, 0.03766931207792368, 0.049149869082611986, 0.07529241804149933, 0.02069024045340484, 0.022201720676093828, 0.040515663640690036, 0.06354694400215521, 0.057969110494013876, 0.0632460624910891, 0.03407352494832594, 0.00715869665327773, 0.03514473348332103, 0.06187417653563898, 0.07544896667241119, 0.05758008781413082, 0.041058143906411715, 0.04067102483531926, 0.06726170482579619, 0.025523028198222164, 0.04439732976607047, 0.029427988483803347, 0.02122532150679035, 0.03865198239509482, 0.04855418053921312, 0.05416821972175967, 0.061838790934416465, 0.06170892251248006, 0.024765759262663778, 0.05011113957152702, 0.016248328902292997, 0.02050369235803373, 0.05443625748739578, 0.0306962687682244, 0.02914587403211044, 0.03641735718701966, 0.04663763611461036, 0.10174538139835931, 0.038172254426172, 0.0449384481908055, 0.04745893013023306, 0.02186975059885299, 0.023689628433203325, 0.056311542211915366, 0.021256708787404932, 0.024375775501539465, 0.04789474522112869, 0.023785072335158475, 0.03789893627981655, 0.049251060918322764, 0.02050290939223487, 0.02690363809961127, 0.03218573874619324, 0.02522097223845776, 0.01920932743814774, 0.07000820041866973, 0.024173378842533566, 0.05908750848902855, 0.08648404953419231, 0.06559211004059762, 0.06005347677273676, 0.02980168952490203, 0.049270249146502465, 0.030522797314915806, 0.029757683878415264, 0.04595484169840347, 0.01900409577501705, 0.020182650405331515, 0.08376221550861374, 0.07149075172492303, 0.013783675949525787, 0.07096177854691632, 0.015338362154579954, 0.015437693054991541, 0.03557494535925798, 0.032794811922940426, 0.04944103588059079, 0.05435879582364578, 0.05534331037779339, 0.06854894512798637, 0.020859006690443493, 0.08798560724244453, 0.0813883077353239, 0.03463732711679768, 0.12723186810035259, 0.013479097615345381, 0.015691120715928264, 0.036971756344428286, 0.06192118416947778, 0.05226718989433721, 0.0052333856092445785, 0.029441297047014814, 0.021561317735177, 0.04361165512818843, 0.0490253070165636, 0.06433129761717282, 0.013103374221827835, 0.043214082907070406, 0.08063694258453324, 0.027095312580058817, 0.03822476508503314, 0.009865462761808885, 0.050579438466229476, 0.0648638627899345, 0.04062451444042381, 0.08546146651497111, 0.06921790962223895, 0.024786652575130574, 0.03618668284616433, 0.06168888081447221, 0.0035019975211980636, 0.029236946684250142, 0.06266823373152874, 0.02644527285156073, 0.02904561915784143, 0.04314945668738801, 0.049133252396131866, 0.046646501068607904, 0.033183723280671984, 0.022843420520075597, 0.07325357510126196, 0.03004154423251748, 0.0611761532491073, 0.005715376200896571, 0.018883812190324534, 0.05461841021315195, 0.1297837874153629, 0.09809626353671774, 0.015284132496162783, 0.02750023948465241, 0.07383620555629022, 0.019756301408051513, 0.08132736256811768, 0.06894145219121128, 0.044882163711008616, 0.030769984441576526, 0.02164782432373613, 0.02024406498094322, 0.016796247255115304, 0.045059050898998976, 0.03623817305197008, 0.0539625854435144, 0.04241638176608831, 0.018209487534477375, 0.026672713283915073, 0.03739496605703607, 0.03259600169258192, 0.021654600132023916, 0.06584621398360468, 0.0477543160377536, 0.05419793160399422, 0.055894406978040934, 0.030759382862015627, 0.07942605443531647, 0.025070943374885246, 0.04171792803390417, 0.027250890852883458, 0.03205382570740767, 0.011165952255396405, 0.017121371020039078, 0.0600598629534943, 0.05140734130691271, 0.01963027174497256, 0.05369930855522398, 0.013589522695838241, 0.012065555838489672, 0.06827398683526553, 0.03846057879854925, 0.021359616839617956, 0.030808427691226825, 0.012044534505548654, 0.06425015119020827, 0.027748899774451274, 0.0557406191364862, 0.03744858993741218, 0.041501295127091, 0.009011912225105334, 0.03075277774769347, 0.03974754821683746, 0.03266318090027198, 0.03965672047343105, 0.03387252538232133, 0.057962535065598786, 0.04788565020135138, 0.03279829630628228, 0.03964213727158494, 0.025046591654245276, 0.018798936471284833, 0.06316962870187126, 0.01709278720227303, 0.025264627220167313, 0.0030199489492588327, 0.10341991888708435, 0.05113177074235864, 0.02408414671663195, 0.0435625731915934, 0.011487163974379655, 0.05978003246127628, 0.03451147371379193, 0.04553381018922664, 0.05156953397090547, 0.06650101830018684, 0.01865644968347624, 0.03684327944938559, 0.04635197234165389, 0.01685433144302806, 0.06199017050676048, 0.058291588502470404, 0.006836532666056883, 0.02757384198048385, 0.03545935956935864, 0.059666925444616936, 0.11734209721907973, 0.07140003159292974, 0.029510224012483377, 0.022250106849242002, 0.04828749719308689, 0.01580042422574479, 0.03089357243879931, 0.036912562645738944, 0.0484087567019742, 0.05209950904827565, 0.05752292388933711, 0.04278767453797627, 0.0134094442728383, 0.012897912492917385, 0.055362264829454944, 0.012260957755643176, 0.051188571014790796, 0.022188243274285924, 0.009912484310916625, 0.08720772515516728, 0.028921886441821698, 0.037176151236053556, 0.03090247635554988, 0.04531690639851149, 0.02088842727971496, 0.08997086712042801, 0.015249086427502334, 0.04259032633854076, 0.029101261679898016, 0.08313455153256655, 0.04096907876373734, 0.04073563621204812, 0.07098583155311644, 0.03920878982171416, 0.06195433590619359, 0.06157602241728455, 0.07968582096509635, 0.02542479011026444, 0.007575509516755119, 0.0833410986524541, 0.02035388428339502, 0.024529696929675993, 0.0235278049876797, 0.012924573220516322, 0.07585268758703023, 0.053655915180570446, 0.032775579165900126, 0.060030084277968854, 0.08071740623563528, 0.04431441331689712, 0.0023284268763745786, 0.007840280904929386, 0.06984400766668841, 0.04703786893514916, 0.03915566689101979, 0.10136447410332039, 0.02951443941128673, 0.10037886488134973, 0.027913634294236545, 0.044698493293253705, 0.03743575078260619, 0.018528573928051628, 0.03639317430497613, 0.10179647826589644, 0.06569581033545546, 0.03842351594357751, 0.03323439712403342, 0.047502995148533955, 0.050901092690764926, 0.04679317913542036, 0.02826258471031906, 0.03141963454254437, 0.044042056251782924, 0.06389130052411929, 0.03881820863171015, 0.033588071310077794, 0.04206054793030489, 0.033217153322766535, 0.057430129454587586, 0.03972706865170039, 0.022294203408819158, 0.0359417778236093, 0.07204103938420303, 0.005641767211272963, 0.07090195402270183, 0.0020165560135865235, 0.009299427656515036, 0.03183119624736719, 0.02704106900637271, 0.053269846248440444, 0.12313714250922203, 0.023608888332091738, 0.024530717382731382, 0.04312495468184352, 0.03672269900562242, 0.018583611599751748, 0.09697147193946876, 0.06855041458038613, 0.029100951833243016, 0.008427393931924598, 0.023205683210107964, 0.05474618206790183, 0.055968180167838, 0.0704024663718883, 0.048475037910975516, 0.047485413670074195, 0.033306630357401446, 0.05061787429440301, 0.09724871604703367, 0.13282700849231333, 0.11621860438026488, 0.14067173207877204, 0.15779377659782767, 0.12303480776608922, 0.2318149624625221, 0.12367584524326958, 0.07534631280577742, 0.11820997213362716, 0.15840043779462576, 0.20694618753623217, 0.0995444534055423, 0.1208660370321013, 0.11265304492553696, 0.16309744591126218, 0.21035006269812584, 0.20230169378919527, 0.10746942542027682, 0.1586665422655642, 0.11461042231530882, 0.08798031572951004, 0.19093843322480097, 0.07922464297735132, 0.18709918454987928, 0.1924247175338678, 0.16831876651849598, 0.12760438170516863, 0.11067882078350522, 0.16639093402773142, 0.18089227698510513, 0.22842305072117597, 0.13761657726718113, 0.15903936757240444, 0.1121670643624384, 0.1382364783785306, 0.11965223224251531, 0.25741139834281057, 0.17130923573859036, 0.12965177418664098, 0.16413431527325884, 0.14068835618672892, 0.11505113187013194, 0.0987128472479526, 0.16972767451079562, 0.1706348906736821, 0.1638767306576483, 0.16225127881625667, 0.17944088845979422, 0.2311583695700392, 0.15539813874056563, 0.19676263007568195, 0.10159189783735201, 0.09057412928086706, 0.14889679150655866, 0.0941499303735327, 0.1533166816807352, 0.10161369471461512, 0.19096384436124936, 0.1498777326196432, 0.17044469306711107, 0.11922569028683938, 0.15320722974138334, 0.1800776511663571, 0.11043437960324809, 0.08541701929061674, 0.08152405396685936, 0.1226956165919546, 0.1353909505996853, 0.23840465495595708, 0.0818631709262263, 0.16667680931277573, 0.09316606519860215, 0.11420002207159996, 0.22742579720215872, 0.11077932242187671, 0.17522709269542247, 0.11481927009299397, 0.17508560966234654, 0.12258461356395856, 0.13609587214887142, 0.09206115573761053, 0.1373228945885785, 0.1665974291972816, 0.1189722097478807, 0.06034511483449023, 0.11263558219070546, 0.26564184576272964, 0.09232992451870814, 0.10311053236364387, 0.12663112924201414, 0.17616582044865936, 0.17176389024825767, 0.21674461488146335, 0.11101185213192366, 0.12529380881460384, 0.11637386909569614, 0.16425121837528422, 0.18694728176342323, 0.15676751994760707, 0.2214824262773618, 0.16879665025044233, 0.2356390267959796, 0.15710188716184348, 0.16020060604205355, 0.07286414795089513, 0.13117231603246182, 0.12583419622387737, 0.2446419608895667, 0.0956830961513333, 0.1682504592463374, 0.12490582885220647, 0.14932400139514357, 0.22472693264717236, 0.13986898062285036, 0.2157152263680473, 0.22118464694358408, 0.10176072901231237, 0.10754515416920185, 0.12393347438774072, 0.2000167843652889, 0.13715301698539406, 0.11493785787024535, 0.1637588776065968, 0.11931877786992118, 0.1873614446958527, 0.1102308752888348, 0.18782025523250923, 0.07988301702425815, 0.23425097315339372, 0.19010758405784145, 0.15759068046463653, 0.13946961611509323, 0.15138751332415268, 0.1873801468173042, 0.12884756812127307, 0.16701470914995298, 0.13131707935826853, 0.2257446842850186, 0.07515495744883083, 0.1981518414686434, 0.287916220840998, 0.13473035010974854, 0.10778256721096113, 0.15894187905360013, 0.06856105697806925, 0.08530837629223242, 0.23232529289089143, 0.13868801586795598, 0.1345542978378944, 0.16274336725473404, 0.13050194887910038, 0.12844661541748792, 0.09452757964027114, 0.15082685044035316, 0.1591860901680775, 0.10891504003666341, 0.1264478187658824, 0.23249289952218533, 0.1323001430137083, 0.13928845786722377, 0.11766687588533387, 0.2049001754494384, 0.08993339608423412, 0.2301394601818174, 0.15538414183538407, 0.15417395130498335, 0.1244893875264097, 0.0841888613649644, 0.14162187406327575, 0.14522783603752032, 0.16445142013253644, 0.11911523644812405, 0.11077679169829935, 0.13431893312372267, 0.12371523844194598], [0.023116840711736586, 0.05233859192230739, 0.035834704467561096, 0.03530451416736469, 0.05062398216978181, 0.06538664645631798, 0.030201313784345984, 0.023505909775849432, 0.10466732070199214, 0.02145865830243565, 0.028640417658607475, 0.07269742447533645, 0.015150874314713292, 0.05940836861554999, 0.06704992556478828, 0.025668756316008512, 0.06416798802092671, 0.05704280629288405, 0.029540004543378018, 0.012539189847302623, 0.04553940598270856, 0.034244864582433365, 0.014816177772445371, 0.0422332865127828, 0.03378524139407091, 0.029650757096533198, 0.01409767399309203, 0.03586134756915271, 0.16795834992080927, 0.03966125499573536, 0.014303843545349082, 0.029681266787520144, 0.04481214578845538, 0.0286506592965452, 0.0468834910861915, 0.0489992576331133, 0.03175675883539952, 0.03053495369385928, 0.03391381476831157, 0.06847962853498757, 0.01419954953234992, 0.02404033217317192, 0.033540941221872345, 0.013916625212004874, 0.005879404752704431, 0.028910945329698734, 0.015105573620530777, 0.05848570464877412, 0.0337731592298951, 0.03414332022657618, 0.02156829763407586, 0.02782902018225286, 0.07223765656817704, 0.034006972855422646, 0.04210725128359627, 0.030544082110282034, 0.04248013596225064, 0.06528783691464923, 0.10530093670240603, 0.010015289390139515, 0.015187776680249954, 0.029831713109160773, 0.04691902140621096, 0.07764535272144713, 0.022369846810761373, 0.043555151714826934, 0.032967223960440606, 0.028215115089551546, 0.046243897086242214, 0.001218134177634056, 0.012324109884502832, 0.03776249985094182, 0.03189952207321767, 0.05130731835379265, 0.011107085101684788, 0.028381213305692654, 0.04443182850081939, 0.024030932872847188, 0.017700988355500158, 0.031311674320022576, 0.05205909539654385, 0.014389280513569247, 0.011494585451146122, 0.021117706382938195, 0.06065411173040047, 0.042297296749893576, 0.016226316802203655, 0.04572337325953413, 0.05037693234044127, 0.025999316312663723, 0.0404276300832862, 0.04498650225286838, 0.021013590485381428, 0.02552909525547875, 0.006553359262397862, 0.07689438833040185, 0.033211290356121026, 0.021094629300932866, 0.09818165504839271, 0.023571714154968504, 0.004493857250054134, 0.004673586399803753, 0.017510547695565037, 0.031348121192422695, 0.012832443935621995, 0.045899707547505386, 0.03177320111717563, 0.01913852283905726, 0.03884470330376644, 0.05262172126094811, 0.05862071986484807, 0.03820494603132829, 0.05585214908933267, 0.015919778270472307, 0.041736166313057765, 0.06150530687591527, 0.10096628961036913, 0.10228177605313249, 0.02558627773396438, 0.03496495934086852, 0.012962502532900544, 0.04395827891130466, 0.03957437176723033, 0.017069160930986982, 0.014405830406758469, 0.0413432955974713, 0.04889708245173097, 0.06926803427631967, 0.04964326370100025, 0.02881019507185556, 0.036749286446138285, 0.012870539303548867, 0.0366352814307902, 0.02204809796239715, 0.012680924282904016, 0.00369290828530211, 0.008297297299577622, 0.015153342883422738, 0.0732459755090531, 0.05005501094274223, 0.01959225337486714, 0.048300032067345455, 0.05533035619009752, 0.032911403322941624, 0.06729404020006768, 0.032154969303519465, 0.014049699711904395, 0.029315029896679334, 0.015363322436314775, 0.018362310584052466, 0.032570642506470904, 0.02819997342157876, 0.02981299057864817, 0.0322273769415915, 0.025407030516362283, 0.09826202222029679, 0.034401669254293665, 0.019582147178880405, 0.03405615127121564, 0.018498689496482257, 0.0201187366474187, 0.03652080144092906, 0.004644907030524337, 0.043402974333730526, 0.035018123089685105, 0.018550120330473874, 0.005772011809312971, 0.019558934654924087, 0.02766591282124864, 0.012051608100591693, 0.08549733451218344, 0.028159103349025827, 0.03668170276796445, 0.04910277981252875, 0.055325465436908416, 0.019577410421334207, 0.037585215613944456, 0.07033349858829752, 0.0672585358552169, 0.04612275632098317, 0.04036632126371842, 0.0387152616167441, 0.014509080774587346, 0.019315276440465823, 0.07385856646578759, 0.051220197638031095, 0.025161464982375037, 0.04441521923581604, 0.018854022382583935, 0.10375482786912471, 0.030919228483980987, 0.025051788543350995, 0.026446475130796898, 0.02537106047384441, 0.013383880996116204, 0.009781968365132343, 0.021373339150159154, 0.026555786062090192, 0.03396788764803205, 0.04053759039379656, 0.06734103299095295, 0.03714299207786098, 0.03444905909418594, 0.029300916103238706, 0.01886547928734217, 0.006956825527595356, 0.012003950159851229, 0.05855469098605681, 0.014602137744077481, 0.01736867503495887, 0.03233498464396689, 0.026541963561612647, 0.011094546516687842, 0.006625099431403214, 0.05172664292331319, 0.04235589301970322, 0.01042967960529495, 0.021199401999183465, 0.0801043477258645, 0.030517197810695507, 0.04217387016979046, 0.05951869999989867, 0.02275074668432353, 0.07641358053660952, 0.010275295262545114, 0.04595544654875994, 0.032305899876519106, 0.021952370188955683, 0.0371099887706805, 0.042766801634570584, 0.06641875865170732, 0.07534660966484807, 0.048680349354981445, 0.04013381381810177, 0.09063971287105232, 0.009458708318561548, 0.03580811702704523, 0.036155093330307864, 0.06090881310228724, 0.031496316951233894, 0.04180240670393687, 0.017279090388910845, 0.05441970388346817, 0.04891908713034354, 0.020161078027740587, 0.028946909806109034, 0.0031786532872501994, 0.08642522690934129, 0.05670695849403273, 0.05568240136199165, 0.04910501738777384, 0.017124159639934078, 0.06408627014025114, 0.05792727191874292, 0.03361512630362995, 0.05313810761435889, 0.045997340785106644, 0.017352258728351444, 0.03685113137180451, 0.049955362774198875, 0.026679719157982618, 0.018083276045217644, 0.03768173191929236, 0.027210479056520853, 0.11677640999550931, 0.034558188199298456, 0.07318545336602256, 0.030594601958000567, 0.018681382134673186, 0.02720913391385693, 0.010343191570427734, 0.06916725804330781, 0.049365154991392046, 0.06222634416189976, 0.0723337201634422, 0.03378033208718989, 0.003579428803277551, 0.02312565742613515, 0.039754453900968656, 0.0360986047598999, 0.05402291462814901, 0.04313818717491813, 0.019184673292329535, 0.024998244443850126, 0.007711975167694618, 0.03269244378316216, 0.05389217047195416, 0.03933332220185548, 0.022809860602137633, 0.01891905121738091, 0.029729111192864366, 0.0691169552737847, 0.01258079835679382, 0.08299329114379361, 0.052659786015283316, 0.059543239112826996, 0.01805960710044019, 0.04180044372333214, 0.05154077945917379, 0.01205115075208596, 0.02184234679589281, 0.018593244676594622, 0.024952546700660605, 0.1026099908631295, 0.05012308443838265, 0.02710804412345169, 0.04942612242302857, 0.0287166788984905, 0.0537709888885729, 0.015639079465472605, 0.009878348300844664, 0.03054839213291416, 0.04381734135677107, 0.02046491328655975, 0.015894732641754672, 0.0342331275169272, 0.04489493978326209, 0.05120291301864199, 0.038845998351462185, 0.028405034390743822, 0.042679220787249506, 0.0042505144483584445, 0.011011175502062542, 0.047015734380693175, 0.032163633877644315, 0.03901967575075105, 0.014990393228799803, 0.0216781076596817, 0.026106903605978005, 0.08566552001866512, 0.034324931184528396, 0.02335174343897961, 0.05792106756416615, 0.022152796445880085, 0.06760761243640445, 0.03414243707084097, 0.013319765002961503, 0.07761346263578162, 0.017544808943057433, 0.015086326020536944, 0.020881786913378164, 0.018290238767804112, 0.016794403018138837, 0.05097290289995726, 0.01660590678511653, 0.024068962375167757, 0.037094626313773915, 0.04319410058087669, 0.04460880845726933, 0.05978182474791538, 0.0747480452992022, 0.06744934202288277, 0.09172480698907748, 0.15328312176279724, 0.13908463442930952, 0.20086594973690808, 0.1535968275857158, 0.1884507096838206, 0.08820795468636788, 0.12409447590471245, 0.15248829644406214, 0.12175660682260059, 0.20263272133888677, 0.1828071812633425, 0.09801731386687607, 0.1448702099150978, 0.1359352862345986, 0.15873266762355343, 0.10263023665174842, 0.09151881647994742, 0.1437139289919287, 0.12429403199348599, 0.08729942492209375, 0.10982493535266258, 0.14407624548766762, 0.131111103692092, 0.1456244694418274, 0.11333989517879672, 0.11941527933231555, 0.07813658769009635, 0.15387952647870407, 0.13128883321769536, 0.21245201787678525, 0.17534899787278846, 0.10383688713773154, 0.127828539989423, 0.14942110399715602, 0.11550307754077949, 0.14555789879523218, 0.11188084768946283, 0.11159594461787492, 0.11300198049866594, 0.06571377030923031, 0.10030880614067428, 0.15085451770573854, 0.09779842483112589, 0.13409948005573824, 0.18869469815399498, 0.10936602833680809, 0.19340795930474997, 0.0757632810564246, 0.1331150805344805, 0.1592057422385551, 0.15489680314203724, 0.12876467022579163, 0.14259211340686306, 0.17310918134171516, 0.14887182565871626, 0.14360297791427, 0.0914751114032697, 0.2134363431832753, 0.10661293505108915, 0.09181548259221017, 0.06643345317570493, 0.10243975702906027, 0.1592583753517829, 0.1460095847141929, 0.14366424962645397, 0.12011130995233543, 0.17356825905153528, 0.1355967333074659, 0.1250198227353394, 0.13674191170139238, 0.12780885823303834, 0.11334615148371086, 0.07336794005823322, 0.1346886859391816, 0.15448134887265041, 0.18296229012776166, 0.09412215920747258, 0.12340830100583844, 0.17188624071422964, 0.15844116685912013, 0.09172784237307496, 0.1153378606250044, 0.1358041784260422, 0.18506847554817796, 0.12417039761203341, 0.1534461122355424, 0.08887528645573184, 0.32278775121085346, 0.13487097225151956, 0.14436704863328487, 0.1071267387305852, 0.08868999444530345, 0.11149793659569696, 0.09370541360112838, 0.2680563786998391, 0.13111212785588577, 0.12164313986431807, 0.18555351358372718, 0.0840943562798202, 0.1006117879296653, 0.062436446169158444, 0.13486586627550423, 0.07782395798130892, 0.1071382049121894, 0.1785157123231329, 0.11299775025690906, 0.13609602057840675, 0.12780170392943546, 0.16340586764272302, 0.14677902858238667, 0.1465967867989093, 0.12484347360441461, 0.09208025861880742, 0.14267796505009755, 0.14807934552663937, 0.1514504326041788, 0.14177699777064845, 0.15348635148257017, 0.08939801817177795, 0.12791171990102157, 0.1434647454880178, 0.27853140723891556, 0.16603473282884806, 0.07109996644430794, 0.08986657310742885, 0.14147124777082354, 0.23080090672010556, 0.19485856115352362, 0.14745996391866356, 0.089656285563251, 0.11208340205485001, 0.133555174106732, 0.12378687795717269, 0.13708919228520244, 0.10547256577410735, 0.08157512114848942, 0.13368784042540938, 0.1647664766642265, 0.20843714737566188, 0.12797211587894708, 0.10695171804400161, 0.16047101496951655, 0.11076727736508474, 0.12835617730161175, 0.08327880277647637, 0.16717526537831873, 0.1360538072185591, 0.21018239669501781, 0.12984259519726038, 0.10414012867840938, 0.1571695858729072, 0.13595231110230088, 0.16653548955218866, 0.14420036226511002, 0.18394818878732622, 0.12097361133783124, 0.07369028448010795, 0.15046380663989112, 0.08949761438998394, 0.0481657033378724, 0.17610613693250343, 0.11092378888861276, 0.15763129078550264, 0.08976980447187088, 0.06702326762024313, 0.10347445189836435, 0.13913048431277275, 0.15848097566049546, 0.09918408875819296, 0.2678964607184753, 0.08697034922079183, 0.17844385758507997, 0.2206723572453484, 0.16098170162877068, 0.1673011781531386], [0.060781037536798976, 0.07509066519560292, 0.047049565182533115, 0.0734750839183107, 0.04384050007502083, 0.03590803979022894, 0.06747991850716062, 0.053526569972746074, 0.04259837121935561, 0.021755600864707958, 0.06735700400895439, 0.015440528059116332, 0.06483029545051977, 0.012969460167369107, 0.02923719715909101, 0.020402860463946126, 0.07906656552222557, 0.016253625981335063, 0.05359635040804278, 0.017235984596482012, 0.011648983709164895, 0.04478840077354107, 0.027168560700374655, 0.011485432914923877, 0.048294855587300844, 0.0560078850685386, 0.0089704447236727, 0.07233170894323848, 0.011345896164129954, 0.03757694808882661, 0.022684487739752512, 0.015286117741197813, 0.016542614575882908, 0.0663079485821072, 0.04945510700054001, 0.04881390625087079, 0.030660042684758082, 0.036064102314412594, 0.018992429213540163, 0.018799500503519084, 0.06853290731669404, 0.027375009485695045, 0.036332500021671876, 0.047760854358784854, 0.016846520338731352, 0.015184395269898232, 0.033077629559556954, 0.026925379315798637, 0.03730054260813631, 0.028507756906037685, 0.010760671902971808, 0.03918534537660889, 0.029678570936084725, 0.03407876822166145, 0.03615177221945487, 0.057797065819613636, 0.05927083009737544, 0.026394921842438634, 0.017874385594041087, 0.05778962207841687, 0.03851562018098775, 0.026871312002185732, 0.05672154911735561, 0.06330028380034491, 0.06550231759320013, 0.032480467853019945, 0.02842247671651421, 0.05423216316557955, 0.04266937619831879, 0.023649658214708325, 0.06161427270853892, 0.008853127874317579, 0.021052718366263434, 0.011746805266739102, 0.07544757143477909, 0.012935034719703253, 0.0378619884577347, 0.014761126185476314, 0.013466704676829977, 0.06953563788556494, 0.03376153348654043, 0.05580190940236207, 0.028827284877479542, 0.012348440268397098, 0.014818932995694922, 0.04561550580547191, 0.05891081425943412, 0.07153331389417872, 0.016834620000736322, 0.03858234667859506, 0.007081108824422699, 0.07318381321965717, 0.031581445000483654, 0.03099323730566539, 0.0190170982023119, 0.03853868242003955, 0.055491450475528836, 0.04177964503469411, 0.035905037802876905, 0.03986259594967123, 0.06455074326368049, 0.03919849252270069, 0.031619602523278445, 0.042449889733688906, 0.05111410762765445, 0.01314801533226273, 0.025039407664735336, 0.01716424860205734, 0.02388113036431605, 0.05064005708845798, 0.029511461543734185, 0.04042775995912962, 0.06367523164954036, 0.15816112485481426, 0.04239583169692196, 0.021251894104352687, 0.04495555840549059, 0.027435453703219537, 0.02038745162280975, 0.1707503985380754, 0.05788288406620268, 0.07328999970923178, 0.019937346478400286, 0.06115486474300269, 0.048616843778290786, 0.058430882199900225, 0.026041323726531118, 0.010027445769082988, 0.05718814107240178, 0.04396303236717358, 0.022189393603184726, 0.06473991670645773, 0.023503575721406378, 0.10940854597720318, 0.028546728935907595, 0.08062093445914797, 0.03534467548888642, 0.05745837559516076, 0.014948808839108096, 0.024402171839028597, 0.10259251328534447, 0.07442597547196783, 0.0459499880525982, 0.032790169789223, 0.02474531123880297, 0.013747557477472583, 0.06890531702083535, 0.02771526935248403, 0.0184505649303901, 0.05867303014383651, 0.013288666232256219, 0.029847261102986522, 0.008636771417513955, 0.048541296855546534, 0.07625954036484472, 0.03952206148824189, 0.01816728530684486, 0.022148972529976163, 0.030023691870155744, 0.0060056640177208465, 0.04630500181519892, 0.04087179433554411, 0.07540348786278628, 0.08718957964447327, 0.0429080657340819, 0.02707163064769702, 0.01673275837674737, 0.05547711960389279, 0.08878042513970286, 0.04566858791804407, 0.03977406886406243, 0.02375559794018045, 0.014325244301289786, 0.02174535551603185, 0.07266258064191788, 0.02689999786525732, 0.06889205484185368, 0.057380416692467406, 0.05065332297817804, 0.014868647613184294, 0.04574789752950892, 0.0271913687538472, 0.012185317136754747, 0.10529029430472292, 0.02210470713180257, 0.04389188266941346, 0.06169084008433856, 0.031159675054368563, 0.03394301456864923, 0.0027838186633744044, 0.028985562712477986, 0.013802536705043167, 0.07068999664625153, 0.019110135690425523, 0.0935078390466515, 0.028036817820975557, 0.03626635982072912, 0.037029662416898645, 0.03256253825384192, 0.02865221038518939, 0.0783365148527082, 0.07443649912602268, 0.0509231864270987, 0.04344922868767753, 0.049574986114748754, 0.024889594023989048, 0.010768576703412691, 0.03977480359026231, 0.055867244373075664, 0.010051512690552045, 0.024690739264769945, 0.07327746483497322, 0.016971004479273688, 0.06147766929643694, 0.034466874349163845, 0.02533992737880908, 0.024987308897834737, 0.022979441346251406, 0.06498316302895546, 0.08215563648263924, 0.02271155572088901, 0.024202983113355003, 0.019608035145211034, 0.04864878210355528, 0.016295093482767697, 0.012246133355802158, 0.024296868505189195, 0.010243086053378647, 0.03353943095135037, 0.017523971291666385, 0.08008884426089935, 0.023691532041993923, 0.03024915076821344, 0.0831315977848135, 0.023325178262894042, 0.024469670170219615, 0.07286655993084423, 0.031291784762288444, 0.036922373838024214, 0.027796323010989, 0.06513664658996277, 0.009141196205746382, 0.10275260196067393, 0.04205255871056579, 0.001945423477991426, 0.037417070925584994, 0.03782256186241284, 0.031930124532664195, 0.035592348722275347, 0.0012936613870806468, 0.028683057753369212, 0.05987825199554209, 0.03141964567475952, 0.013992509811942, 0.001571571688145923, 0.032912323586060666, 0.04111059519345872, 0.04822402501304168, 0.03441922104684636, 0.010262324376526522, 0.033419837563997135, 0.027429848632891662, 0.04604182882758323, 0.06873756196000613, 0.01800969024770893, 0.02601417410915019, 0.018070631704176776, 0.04887512972345576, 0.020721152759506367, 0.0452855655021267, 0.04710394234280102, 0.029409865237539634, 0.0681921056821011, 0.030203039277694188, 0.02429182561172638, 0.01438780363969272, 0.03257181881053839, 0.023176971371867694, 0.02634171542013064, 0.012135519955336349, 0.016832133806019556, 0.041928263817681, 0.04498388989304658, 0.04271930789400358, 0.011187676773261046, 0.0636430447048042, 0.015213211008813232, 0.030640355362265836, 0.05829409325087909, 0.034745242810458876, 0.03591040353057906, 0.0366315187420696, 0.037147415278013796, 0.027052164114138577, 0.06110909649578389, 0.11833663447760046, 0.0939984135038685, 0.030348993750521913, 0.03301092532637995, 0.05103272371343337, 0.06454652044340037, 0.061433236915036105, 0.037213882023934275, 0.05986952062812634, 0.027381024592614267, 0.04640396720787976, 0.015310528833651915, 0.006168308000269462, 0.045591675443574786, 0.056490563074476086, 0.06657457997789606, 0.058154751313850284, 0.0979268980154302, 0.012431424438545946, 0.048022468836279586, 0.019258867650933098, 0.05388219600718003, 0.07066995865898207, 0.044324291302473284, 0.05917764603509568, 0.02356793476792518, 0.05033621069742367, 0.009712503342598211, 0.02857314197171945, 0.03793134215811733, 0.032183694129344076, 0.0881133160146419, 0.028023891463817563, 0.03789766720728949, 0.04510855214903131, 0.02090560614306014, 0.05108568708237726, 0.018086929267155938, 0.04075700264365878, 0.019191469509678427, 0.03542531354469247, 0.03062392421270488, 0.011567748224479146, 0.038510595841216855, 0.09810381117858924, 0.015310885992221301, 0.02347328125324566, 0.03959297369874548, 0.024432130485365633, 0.02454538222082192, 0.01571084143506596, 0.040422260644845665, 0.047464010131079704, 0.02587889914138941, 0.03486320718366187, 0.02975752988277236, 0.019924431253457442, 0.09774894584552385, 0.1506862134556286, 0.1305125467479229, 0.1445093034999445, 0.1675197554868646, 0.12408498383592814, 0.17823951464379206, 0.18377140921074897, 0.1786835861275904, 0.12315132495132275, 0.12981059378944337, 0.10019534660386853, 0.1333480852190405, 0.07604605416418053, 0.12882042035926133, 0.11578634788747877, 0.16130757867358625, 0.16126138740219176, 0.20052687730640173, 0.0758329538803082, 0.14222700643585995, 0.19122668338241056, 0.1069622120121494, 0.0791684104478918, 0.15238947205943987, 0.16359225061023608, 0.1431613852037117, 0.24990522768348455, 0.13283805164974183, 0.1817481662146747, 0.2282289939466864, 0.13563113927375525, 0.13958657858893275, 0.1429844571975991, 0.1509904643171467, 0.16716779937269166, 0.12375875798170455, 0.20909017795929685, 0.12009057434624992, 0.10551868283073418, 0.10429912639665417, 0.10138169935089536, 0.1272258863900788, 0.12367530347546563, 0.10293501443811692, 0.08450635956251062, 0.09092785912798718, 0.17241629742784426, 0.08929903793614358, 0.15016812016256154, 0.10722499908297323, 0.07606181738083251, 0.11371298765880056, 0.10175013856496662, 0.15903421706752852, 0.1043685914191883, 0.16360372421331704, 0.19663915154524148, 0.09545089298626408, 0.12603466515429318, 0.12240772266522981, 0.10064331436296925, 0.10807757833390497, 0.10647401984897442, 0.18587750557344407, 0.08733797949389555, 0.3365009184926748, 0.11518736791913398, 0.2066081392695196, 0.16174189833691344, 0.11728205005056225, 0.17310984927462414, 0.09901910190819763, 0.09911261993693188, 0.14623282273532823, 0.1493389779352583, 0.10676192119717598, 0.12713022355455905, 0.148727938067168, 0.10509931002161466, 0.11623414495261386, 0.13966627040645108, 0.09460962406592444, 0.051035425130976364, 0.10589381621684879, 0.0943767826538533, 0.14982054271968082, 0.1873127746512182, 0.11645799895632081, 0.18816369149135426, 0.07236144680064172, 0.19975108065409586, 0.12329516801401041, 0.07646156038390473, 0.07066721271257848, 0.1327929290710017, 0.27498118055518717, 0.11678031369228847, 0.14680196094559506, 0.16206557862460613, 0.11413729574996978, 0.1263267596368678, 0.10775308910524473, 0.18080327863572165, 0.16701441229088232, 0.12002151008346118, 0.14000241877511144, 0.1141069270670414, 0.07124975410988554, 0.17716598318656906, 0.11866349857882597, 0.1405884779524058, 0.11967957296292298, 0.17378952295985073, 0.08962533058365807, 0.11785938157117926, 0.15786307834787294, 0.11732731363736093, 0.12197000396554358, 0.21693246730137616, 0.11658678384264931, 0.110310062445933, 0.14944509021006525, 0.23745144048007205, 0.18747269263258204, 0.193805483286269, 0.11640627126325853, 0.2345544076524675, 0.16610470251180232, 0.18487562105292454, 0.06276979664107785, 0.0674719107337296, 0.20108374039409682, 0.1954682354698889, 0.2284533006604761, 0.1628798630554229, 0.2323253225767985, 0.11501171640702523, 0.14700931700645015, 0.11099975512479432, 0.23358005681075156, 0.20082389964954928, 0.13700200477615, 0.12177199154393747, 0.09905146696837619, 0.1974437732133083, 0.1769320879247971, 0.09076551432372071, 0.09825392538914457, 0.16169453447218984, 0.16834212932735682, 0.09265244705602527, 0.12873327737906948, 0.22666750039206818, 0.22894011985044926, 0.18096566054737195, 0.17274708749027923, 0.051999975912622176, 0.10061045206384733, 0.10234168963506818, 0.13661303033586591, 0.10614079554216005, 0.21506008808501065, 0.1182096975389868, 0.16091329045593739, 0.15042166749481112, 0.19677635980769992, 0.1662847030092962, 0.13893307303078473, 0.10270050319377333, 0.12886852637166157, 0.13586108630988747, 0.1087978994473815, 0.09581740261637606, 0.19352964183781296, 0.06942318766959943], [0.04958917597832624, 0.023199143033707514, 0.05890848391572945, 0.056885945959948, 0.0755304767517373, 0.009806465732253855, 0.036893066426273435, 0.03652916544524487, 0.046107772359391674, 0.021012130309827626, 0.037235983181744814, 0.016951150173554197, 0.08635582868009806, 0.04925381799694151, 0.025430272726225667, 0.03413655183976516, 0.08561126902350225, 0.031374675236293115, 0.05687421260518022, 0.07485406109481119, 0.041449018244748004, 0.03155017089738976, 0.024015060189412907, 0.1476584587362595, 0.08744978404138237, 0.011295775220787618, 0.024100288428599015, 0.03249082452384755, 0.10029252342064865, 0.036897497047903016, 0.01888066362880636, 0.013450803235173225, 0.015440379629581003, 0.01295161429879954, 0.04978607517841738, 0.025432610491407104, 0.00956402927840827, 0.02049158421868924, 0.0228607051394647, 0.06843509967438877, 0.023850136421970092, 0.06528483863803558, 0.022039555842638947, 0.022192731412360445, 0.07162292080465704, 0.07652420506929047, 0.06474646244896576, 0.04427526131621562, 0.023044190020300448, 0.033157054203911684, 0.03683518632897176, 0.09786647977307439, 0.033421767147956416, 0.007631049529663869, 0.01373921202684869, 0.017307403322774917, 0.024156693507393356, 0.06246676290174946, 0.04115146155527327, 0.06453001507907175, 0.018025737335847225, 0.04808782607142348, 0.00840701455672388, 0.013162828599888599, 0.01681907942838734, 0.0165510045553674, 0.056333951361011714, 0.07117403278243728, 0.047416408779099584, 0.041099674490396865, 0.05326288861397188, 0.013302069419296458, 0.006347423022816656, 0.01755056800902821, 0.01385208712235908, 0.09698960260720924, 0.016233074056799524, 0.051035506767220795, 0.0339437084767269, 0.03200317041773815, 0.05551100977754686, 0.02397853539150674, 0.006325395152089186, 0.04839164648728911, 0.026892082860285882, 0.0373820786626311, 0.038891005897312425, 0.04963237268384546, 0.057723504141904414, 0.008503189474140527, 0.02104365859850077, 0.020516307013167534, 0.06009738594002556, 0.06679470097878948, 0.051744743905146606, 0.06536830056575127, 0.038030244468245655, 0.009504979370831279, 0.016775901276560035, 0.05124350849655457, 0.02011680891882861, 0.09262274630600587, 0.07486915637855418, 0.023467789360438474, 0.08960930761531927, 0.06702908605802804, 0.018545747225289233, 0.024856401469151024, 0.017638994904700667, 0.03465640402282588, 0.04664479041821323, 0.008841982671583537, 0.02263147798657883, 0.04519233320024796, 0.0413158064475283, 0.04248293014825322, 0.04566936717310455, 0.12265945915714838, 0.0027683942835210473, 0.0402313876838889, 0.008950183164415648, 0.04555681676720269, 0.03915247194527183, 0.06344613808323629, 0.014434737058763858, 0.07524958127760328, 0.029445545842463616, 0.02389021981798578, 0.0477288195543224, 0.033095671169576235, 0.026728969933174085, 0.006191738993948093, 0.12961134198121727, 0.022078396141296253, 0.02080938298604451, 0.015504599523410434, 0.03402493653993588, 0.0301381013559876, 0.03534246017807163, 0.012822404532926157, 0.03439717555011157, 0.03124285867670551, 0.015615494012308773, 0.027216082271479536, 0.03337694884976372, 0.047267225963878445, 0.023252837418112904, 0.05894951355003286, 0.07657191774342209, 0.007770840466037043, 0.05345460020180326, 0.031785494793439284, 0.020536554657155648, 0.0500224826100748, 0.02579301410150947, 0.024328736326424405, 0.016768824898463208, 0.0560951727675274, 0.027085547772003338, 0.016241196863120422, 0.024301263874804135, 0.00795796882812283, 0.010020736754086101, 0.03633452237409074, 0.035491416638251394, 0.01997852639760822, 0.03937281930120662, 0.07724131268332712, 0.054502928323927335, 0.035663888047565706, 0.044453625378082506, 0.042287919713999145, 0.009576475094945636, 0.03763169632293284, 0.024890911336115096, 0.02682671634829603, 0.037920870454399846, 0.03060646147787338, 0.02169256840716116, 0.01578451814566506, 0.03456011778325774, 0.03673561237519607, 0.08454144830466248, 0.018202027094957884, 0.02747597867710283, 0.012316093761910452, 0.04111422800633591, 0.037785409949719906, 0.021777961774205323, 0.1301177538698539, 0.024468393676215783, 0.051521973437047563, 0.033240783304790966, 0.0572207584627904, 0.06009435426676646, 0.036720012431032956, 0.0285056065331446, 0.05828486835525837, 0.06229451784747653, 0.03900138923199847, 0.033986545240622945, 0.051986272155772895, 0.058070691957254894, 0.01188544680189807, 0.09389978949911892, 0.02076140128338011, 0.01121637655160157, 0.042250244587194175, 0.014469782199739711, 0.0194422078129719, 0.04086146735062357, 0.05239570760750212, 0.019641969847725704, 0.05082880750705954, 0.04065516513946932, 0.019762258998525795, 0.016566712110943627, 0.039978690110729076, 0.007664934601052664, 0.01264006998098921, 0.01444061022993992, 0.05078757749288343, 0.009459033935854677, 0.05204039698583074, 0.021837259373569395, 0.02273978701850865, 0.030736138796783052, 0.04107639702851884, 0.017798508415580727, 0.07238519552629441, 0.05744227841205429, 0.06935538505786099, 0.02384476327279117, 0.018480603357602376, 0.02577683342678938, 0.07357183771091513, 0.07460278473445214, 0.04456785674847197, 0.03904633740603458, 0.042772163651534356, 0.01580069882038515, 0.05106743396027014, 0.03717043669894338, 0.03748967523279134, 0.049041994207073, 0.011174704959557857, 0.028852662617282476, 0.02154920217435574, 0.0436190988693852, 0.02717518807912711, 0.03886567268637009, 0.03767485592106823, 0.026170171695412137, 0.023103266830730718, 0.08321158646140248, 0.03412912294152193, 0.037289807441993617, 0.058327519582235254, 0.06510358391096815, 0.09331220149761066, 0.05703750364773441, 0.07234130491269752, 0.0649630805128254, 0.04122624777664896, 0.0080210513806378, 0.017791869904613122, 0.03893154200341087, 0.04132364352699369, 0.04248818826454226, 0.04321567110309843, 0.05225273285759613, 0.0370889859914314, 0.05475677993672434, 0.016605121963948477, 0.01027517466354766, 0.04780129027494695, 0.04653769479773473, 0.06289844794082455, 0.03267406078521162, 0.019135203583573457, 0.029271079911268316, 0.04359344282420352, 0.04094174175406806, 0.021331853095034603, 0.033401202235836536, 0.08653914657770656, 0.02965894298540661, 0.017036267090588808, 0.013360228749661474, 0.11108234873972833, 0.009690102542663226, 0.03474767705483828, 0.006731516914442182, 0.058524363121250644, 0.02911239575041691, 0.08519062714185566, 0.08962746796896681, 0.0432581924542319, 0.01982821737328777, 0.05781003485026304, 0.06050409399904311, 0.06240785864065401, 0.02743423101492226, 0.035465998080326244, 0.02438603012706153, 0.03138696891255677, 0.03726656337676104, 0.03567234853107948, 0.018596287482068874, 0.03557812175131403, 0.06225685385288671, 0.005844771039846819, 0.057763910372159444, 0.016809628177725244, 0.0308961198606994, 0.06355300734867342, 0.04527375422185287, 0.0048487332514923764, 0.04269244956958573, 0.045449134850059636, 0.006474155406976934, 0.08299053035443649, 0.0290296017556102, 0.03789394904742949, 0.014690152747789398, 0.04607529226632323, 0.047043564918567427, 0.06379996440955438, 0.027958749451499898, 0.060387751218513586, 0.014331000584206777, 0.04967857137671672, 0.029659855827048887, 0.05775643694505561, 0.030834555000183173, 0.02761756561085349, 0.02211186885688221, 0.01983622514671879, 0.02657668308529537, 0.05804481326777022, 0.05316574519383721, 0.017828248128353152, 0.05624311619612854, 0.05372901672672015, 0.05695591193216387, 0.053631320406566374, 0.0427290856896434, 0.007208572224044474, 0.07426658441545442, 0.03394801664398983, 0.039281030476558954, 0.06310826051048934, 0.10867568998946808, 0.14633270096965134, 0.14948510681279004, 0.07916623595519923, 0.19907605281332508, 0.0807886449911166, 0.24135568644851446, 0.13063672289717942, 0.11775418213801458, 0.11779388703871518, 0.11716674998751841, 0.17781551083317026, 0.215369192592334, 0.25097780919168144, 0.1427877286914736, 0.09084843448363245, 0.14880862436257303, 0.11796509308624081, 0.14039939356734976, 0.1562584363273345, 0.08376363301067613, 0.14415877230931073, 0.1292166084749624, 0.20992571749957278, 0.16155645047547296, 0.17562629393069074, 0.14480142766842619, 0.14328962832223624, 0.21600491629214957, 0.12864047923358157, 0.0878689564706292, 0.16296466084895656, 0.15486006683204323, 0.059395303105702624, 0.14037438319064677, 0.159252111625392, 0.1384105416946113, 0.11126521392725408, 0.08911910423194058, 0.13215851155109704, 0.14324585645226762, 0.12969947943929583, 0.08994657662697136, 0.09491068369243294, 0.09944759571226314, 0.24019251839490607, 0.15171009523328394, 0.1080653996905312, 0.1145776713383384, 0.11143309515318833, 0.08348776929778978, 0.2524363965494558, 0.11705003984388895, 0.12985120411030948, 0.10548819540417753, 0.17111848894273862, 0.10708437694120221, 0.13669621024746448, 0.14722293679369614, 0.14729535556398332, 0.12681443971814588, 0.19616744248196483, 0.11040014433092438, 0.08459262680844404, 0.10990594077156857, 0.11221906665014103, 0.10796182556077838, 0.19709546846570447, 0.13767914031632245, 0.1232834643451497, 0.22624214587267488, 0.07370353923761286, 0.11996892892057076, 0.10707072142395191, 0.11274878197582439, 0.1689488350530155, 0.09419511974556372, 0.14346703130286187, 0.23871629760833457, 0.11827041264041327, 0.14242530829505995, 0.22883019293658435, 0.1335889715119265, 0.18999703373992816, 0.13948040694231167, 0.21141286269994453, 0.11391384250600822, 0.09501094784354791, 0.11025436426280066, 0.11857928708195686, 0.09320643803221174, 0.09813450640649535, 0.08919626532588154, 0.20343792188214138, 0.10146810760488734, 0.13153773470548913, 0.21813210449181497, 0.07055277354083955, 0.10991360715706833, 0.12424223750713281, 0.14620340400142595, 0.18798165750922635, 0.18682591093238443, 0.12023745279293507, 0.21638019068632275, 0.15627405111445114, 0.06849438985227607, 0.07683831165195443, 0.08987180524854921, 0.1362083965796046, 0.07811270537786186, 0.08907957744668238, 0.12667534640058875, 0.14386632159585133, 0.11931004279176705, 0.16217982483794913, 0.11237773040193133, 0.20963194576324895, 0.15009074384579435, 0.1396899894461967, 0.13145937875378877, 0.14860928349662572, 0.09571296759531833, 0.14095918071689084, 0.12604885501787066, 0.307806312921457, 0.0931285199476406, 0.22167939227074385, 0.07742037807474844, 0.08887847026926465, 0.1482764451066032, 0.0958790528238751, 0.2509654895402491, 0.09452022495679557, 0.10599684857879765, 0.14437818084843457, 0.11474579005152918, 0.09608556283637881, 0.13430630177026615, 0.08748534033657052, 0.19243896676925942, 0.11967072656261735, 0.10768213236588053, 0.1770944253075868, 0.21770318766357377, 0.16060604131780565, 0.1279098793747835, 0.10677429279894568, 0.0890156117384322, 0.1398599857930094, 0.1246875335345976, 0.13562137261033058, 0.13297355297254398, 0.14324094343464822, 0.1487616018857807, 0.08601262248703279, 0.2041099069174379, 0.12596150423632935, 0.07546156091848388, 0.12577791174408048, 0.15277970815077424, 0.10299103916622698, 0.12522314151283354, 0.22464597917860374, 0.19810377998510376, 0.10070273070596159, 0.16120829415740445, 0.12403356784489006, 0.17111520865000784, 0.14778928452869877, 0.09679538998170756, 0.08904498594347388, 0.09093286120332778, 0.14387055183760822, 0.09162560410914011, 0.15020399558125064], [0.058002848527394235, 0.02841838933818508, 0.023003358910500538, 0.03169923867972102, 0.0276720522379037, 0.03367597499163821, 0.05733362428145483, 0.004263292839823407, 0.054038262242102064, 0.046640467407996766, 0.02226928023446817, 0.021561692519753706, 0.04936178564094007, 0.04243003357260022, 0.053833284764550626, 0.01965132832992822, 0.037326758974813856, 0.026261140446877107, 0.03471986507065594, 0.09608827909687534, 0.02167171591281658, 0.046780046832282096, 0.05230327682511415, 0.023184339042927604, 0.04547953692963347, 0.03436424274696037, 0.0212990984073258, 0.05210411036387086, 0.0865027293912135, 0.08608411357272416, 0.05012511792301666, 0.08219943803851493, 0.03673782397527248, 0.008752847024879884, 0.03438307474425528, 0.034594163807923906, 0.013143248888809467, 0.0693686175509356, 0.049803801375674084, 0.05634485722112004, 0.031024030868138652, 0.023919662671687547, 0.09921730728819966, 0.04732331377454102, 0.03503856925817672, 0.0345411596208578, 0.022767576738260686, 0.04971867332642432, 0.007973792344273534, 0.03571743771317415, 0.014423307984543499, 0.022099283887655474, 0.05634795568767004, 0.021792229563288856, 0.05525318025320303, 0.08335430145962164, 0.007984239000506932, 0.06528796307975426, 0.03969264784245752, 0.0504540563269984, 0.022495551784231793, 0.011772030866268324, 0.02529472501919372, 0.023084293825377245, 0.053317974525270984, 0.026969665123033337, 0.07888753723818809, 0.023583397414768115, 0.03345352364704013, 0.015055884978210088, 0.010364168374508154, 0.04986021573131438, 0.08857734384946525, 0.016917532739171293, 0.034306039815419354, 0.06914987694472075, 0.024260395657620393, 0.03810605485341512, 0.047514413090539165, 0.055861255241325125, 0.08404306645388715, 0.03898096161719877, 0.04398969031171873, 0.016915805390453897, 0.0272595795468078, 0.04421222329256125, 0.08964818873209879, 0.04644050313800108, 0.06450188026065007, 0.009438571069040336, 0.003575159598767641, 0.033778996221371926, 0.08044919406529516, 0.05105755968543235, 0.043768934774561785, 0.05786395187897142, 0.048543078009970486, 0.02559789048973471, 0.019001579894393217, 0.03620603063609451, 0.030037829783395864, 0.06736161274602637, 0.005400860509325867, 0.054729810290155, 0.04878957865003031, 0.036363447579788044, 0.04543448856566101, 0.010206552906311117, 0.024506334120815154, 0.06337422397336923, 0.03823332204774488, 0.03132354868284892, 0.03855330644000787, 0.009796774211281445, 0.024347570179088507, 0.05035804468207061, 0.02224952982942341, 0.046183408339857124, 0.04914319346426055, 0.009276794935431099, 0.01890912499220576, 0.05944789169006981, 0.022070675950089935, 0.022116074978839606, 0.018846955281333067, 0.043962702111457475, 0.11369336527423002, 0.022926618985366076, 0.0022695935831507086, 0.017995472553593572, 0.014066667990846327, 0.012066586496075615, 0.05836189957335591, 0.040247978395200334, 0.020158933220955078, 0.03786874200159218, 0.052979028259869665, 0.07458936670445837, 0.021563043228525203, 0.049501409594086, 0.007111283621270559, 0.039072564904927276, 0.05379335350880865, 0.046526603400707245, 0.009056953167601023, 0.01379063358399435, 0.01947956010553753, 0.01809984263672959, 0.05870447865163442, 0.024947392485046294, 0.019038221580558456, 0.020336412271717563, 0.041926215490093455, 0.05016494156734552, 0.025069807888939977, 0.036923787629348226, 0.03959933761507273, 0.03557633317541331, 0.008802136762824375, 0.04494419241382275, 0.022522718099935446, 0.04263117785740178, 0.030592824514314998, 0.047547026770189404, 0.021237101245787926, 0.04212284380628262, 0.05139092871104367, 0.021870576238143258, 0.017739693212206475, 0.04970976384356618, 0.008034244910959387, 0.030490226308756974, 0.030639134529337753, 0.010462471400387585, 0.013479633817041758, 0.018403473804937676, 0.025486512677161954, 0.06067400870961137, 0.057890743410098366, 0.0421909692522604, 0.09712726357975043, 0.042736737232189626, 0.025658555496193003, 0.004918029435430071, 0.02381645219429629, 0.086724913562648, 0.008232831569330301, 0.05519247999473009, 0.027933247401961125, 0.020207469679007772, 0.029934127633168828, 0.0358964734186884, 0.02271057979669422, 0.047936572664184496, 0.036810302117373794, 0.06411945898435079, 0.027033295009459835, 0.08246394689194858, 0.018213433904747944, 0.05177627033845056, 0.04189203216810711, 0.01978227843210334, 0.030969488580012694, 0.035952639154857025, 0.03460573760094121, 0.05685539545083884, 0.008934963570936816, 0.020643828393076546, 0.04134395610890351, 0.02801676128001418, 0.028076168346160557, 0.0420838513673516, 0.03674375744594727, 0.01712071793008363, 0.06723457190673798, 0.025366223526361864, 0.013919196753704455, 0.005601887905868352, 0.033133439064840786, 0.04460309763089754, 0.014927870070096105, 0.02332249168830458, 0.02863904468540568, 0.04171089247392956, 0.007845704149076482, 0.018791604052239563, 0.018350241407461, 0.011332243429933442, 0.06051474752894137, 0.029241664888104424, 0.042919877014355734, 0.025183373181789648, 0.031244628698914312, 0.08218263581511565, 0.031593081876053475, 0.031015806016512215, 0.03191003459505737, 0.04988852124370169, 0.0361656206951011, 0.04044364934088662, 0.04014674203062896, 0.03909523751644883, 0.06609761650906876, 0.04901209678791929, 0.045918216710560955, 0.03772741481952835, 0.023560845402244013, 0.020315069959906396, 0.006819866812293185, 0.024178124876925722, 0.03718388070410583, 0.043280056124785915, 0.049653950627543963, 0.02402541314950213, 0.06735789458616637, 0.020595366149791516, 0.01936568682140205, 0.0289168175731902, 0.018747411013464443, 0.02344149321288569, 0.023461065502488054, 0.0792032913886942, 0.014981783388066106, 0.05130096556968056, 0.04713665250164922, 0.04123197344597429, 0.025681914594315458, 0.018082036658597644, 0.01826781106501585, 0.04344873144873418, 0.01667273903876776, 0.019170835948898457, 0.022288323743850924, 0.010737282191257691, 0.10252545282128267, 0.035613956351880915, 0.033826471408247016, 0.037093798819114454, 0.01275210181120201, 0.038745366837247275, 0.04063873398990836, 0.06488446480943821, 0.05353909371478949, 0.04044377550599165, 0.021654837619280443, 0.05700971021724399, 0.06575686682481319, 0.021284366775944363, 0.04329269861045759, 0.0159479316425859, 0.02986010025779251, 0.030259859959187452, 0.0294715544077917, 0.08837012879666872, 0.011448396035120822, 0.04492070715059526, 0.021163116543903016, 0.11424607975641266, 0.00932294631638797, 0.08143272527377121, 0.03819881589151919, 0.03488823611405678, 0.01735748715873342, 0.025233759442926385, 0.012753975734085543, 0.01941374830494169, 0.009856564411165891, 0.006258950206756708, 0.04717807547422126, 0.047357986913993955, 0.025851050049823243, 0.038799992616986856, 0.10615692241117358, 0.004367365136204171, 0.04958471196005121, 0.06453578156651929, 0.019842696674459148, 0.043850504225702025, 0.036036494420841336, 0.10615039893309586, 0.0590267896768637, 0.03697240572364535, 0.05235878204985056, 0.038115854913485236, 0.05313660476531368, 0.05884796177269891, 0.048885434443945996, 0.03099156376265455, 0.02948562181700254, 0.034129234263673425, 0.030585616405005567, 0.009171742076432565, 0.009053557841980364, 0.025432360016566236, 0.06983618543017656, 0.041655216555227526, 0.04191504245682154, 0.13493245176505297, 0.023454465954273473, 0.08205940219340846, 0.004068008738613571, 0.014904534164088545, 0.0393252402136568, 0.020687099313363433, 0.023555258885608055, 0.047820081454119645, 0.03940206363040488, 0.08229194674640894, 0.04171245098405052, 0.022955846616241615, 0.018305623489141, 0.08466638886602595, 0.08795478584943339, 0.076052013610024, 0.12142448089434765, 0.08272767649032176, 0.31070938683114946, 0.08641338965389878, 0.1799516344908625, 0.10508901643333957, 0.15240280103171244, 0.14793011447181925, 0.0919222850643564, 0.10086382870213129, 0.13581933308159932, 0.12623215065104887, 0.15864745422732085, 0.18606048950459808, 0.06567167569301091, 0.08182389647117816, 0.10359672814956866, 0.24507708207238466, 0.14197899552527815, 0.14321683847811073, 0.12478730786824599, 0.09847356399404816, 0.14266859914641827, 0.24356770212762058, 0.12354543505352922, 0.12860969494795427, 0.15520274610025808, 0.129110288398806, 0.2324124358710833, 0.1765986706595868, 0.14049380959477276, 0.08864263800205663, 0.11864386877277866, 0.2200024650665, 0.1739902887493372, 0.15348112676292658, 0.13706238591112196, 0.20110547047806904, 0.12039619075949304, 0.10585312425973825, 0.15912223578197882, 0.1894026921945624, 0.1361189826275222, 0.09383658820297569, 0.1383613669895567, 0.14087534771533683, 0.09947421654942445, 0.13761783891823143, 0.09511317126452923, 0.19674164213938639, 0.14263959601521492, 0.15545231552096084, 0.2733977639582008, 0.16930335899814963, 0.13186174153815955, 0.16173127078218386, 0.12473019218305126, 0.17147684236988425, 0.07136384447221644, 0.10249228624161333, 0.11745718205929734, 0.16547908686334267, 0.104999639588641, 0.15763126109959558, 0.20306062884628773, 0.1198993154685013, 0.12621335947187617, 0.13835787889547646, 0.0910821145225782, 0.10813792978296988, 0.1448583058663644, 0.10503374869585969, 0.13977906201034784, 0.15130028128623962, 0.12570150021929294, 0.17412912973668426, 0.34790164267178625, 0.08034458092879504, 0.11602290745940991, 0.15831538767088205, 0.1326579027227126, 0.10452548885950819, 0.13294290227349848, 0.12677765887929127, 0.15392297180369496, 0.15137437731027603, 0.20322922995546833, 0.15984493918949738, 0.09668307335232385, 0.12126992121920921, 0.11062040633987635, 0.1033785664185416, 0.15179820300545543, 0.09157848515314981, 0.13664046011399478, 0.1790387334767729, 0.23720860976027325, 0.20005104190204293, 0.17934400850208476, 0.1977378863375634, 0.09278417084715329, 0.08755975548410788, 0.12347833006060682, 0.14236693095881492, 0.2182254518265836, 0.11500323365908116, 0.18863176403101534, 0.2900364180095494, 0.14343728602398187, 0.11979754475760274, 0.1845403335755691, 0.06952485447982326, 0.11920907360035926, 0.09966806552256458, 0.12856749643106014, 0.12000275601167232, 0.10716328950366005, 0.34962452366016805, 0.10330846314900555, 0.23595163424033672, 0.1504927355563268, 0.162006028695032, 0.06851814599940553, 0.1866586011601612, 0.22277667245361954, 0.050453054427634925, 0.20908588834572583, 0.13692056149011478, 0.22016373375663534, 0.10827831443748437, 0.13037844066275284, 0.16120217886054888, 0.09832519383053295, 0.1020907323982101, 0.18180961604230106, 0.12380209198454395, 0.18005234393058345, 0.16716089739929885, 0.1227339485194534, 0.13851448689820245, 0.11117348447442055, 0.2637249673716724, 0.18557879113359377, 0.14029247977305204, 0.12668980343732983, 0.2240717943641357, 0.09339357799035497, 0.14722964580869302, 0.10927530078333803, 0.18828320695320144, 0.1868924222071655, 0.13634339324198663, 0.11579014026210643, 0.1394123668433167, 0.08813328720862046, 0.1710148702841252, 0.12368997573503293, 0.1937359440489672, 0.21500665345229208, 0.1965566395665519, 0.09211130265612155, 0.1807259616907686, 0.11431223480030894, 0.13400920521235093, 0.14696987927891314, 0.11137392371892929, 0.07722245471086353, 0.12341480221948586, 0.1532148293335922, 0.21800455899210647, 0.07967005774844438, 0.13324845931492746, 0.15818506653886288, 0.20270643144613132], [0.033354276238242164, 0.06841615264420398, 0.04148779917159118, 0.015010002625786, 0.05934455504757352, 0.03316122878459282, 0.07886820429121144, 0.029139476719137747, 0.01968844313523732, 0.07634029345354065, 0.012893124712718418, 0.05369159764086362, 0.04380979371489957, 0.024446936331514735, 0.05800068516691681, 0.06821307877544314, 0.012678930688707624, 0.004226040273351828, 0.023344885994447395, 0.08938555751228705, 0.06635093377553858, 0.025216894136974588, 0.14363805181346834, 0.07537636978668161, 0.04649818656616844, 0.04562879024888389, 0.047083692843443714, 0.05917008355027065, 0.05223863947321661, 0.009817361387831625, 0.0911934144096449, 0.02997895520820748, 0.05337511989637278, 0.056381222457275726, 0.04236335902533028, 0.025994984025601298, 0.047314207622548565, 0.04076475808687974, 0.04193843495158944, 0.06411580761778168, 0.05542498372960836, 0.015955418057274073, 0.015785529321874492, 0.05168780262465589, 0.019071651622653008, 0.012170309983048355, 0.061049865689710714, 0.02766185141808819, 0.06256975815631449, 0.0566400835668901, 0.020205725631967653, 0.04374664065835532, 0.02042668897047406, 0.01427972003511968, 0.03168434377585072, 0.032873271775315516, 0.01639291411265731, 0.08553161431336775, 0.007407672355839168, 0.02875333171687089, 0.019670811561809387, 0.057523287541698664, 0.06647614151006564, 0.05526053122594021, 0.018151536933146417, 0.010892787176999263, 0.04934679796861019, 0.07424573748721741, 0.013039140412729466, 0.030643841600976884, 0.039601597454748116, 0.03118473367067054, 0.022931112689548172, 0.025448828273511026, 0.02903443313698517, 0.01014190256682923, 0.03373876810655929, 0.01474145834436058, 0.005645357350658742, 0.033297576155746356, 0.030887529501342215, 0.04217765141220298, 0.007870781319070375, 0.016298626105708536, 0.01655547042901162, 0.06859281347715296, 0.04135321811190806, 0.03201210587576497, 0.10176600568229333, 0.017853241806733422, 0.04907132388325408, 0.03583483434340451, 0.045455754807335325, 0.024029630403674673, 0.03232916620618198, 0.011802667650044896, 0.05333151129889302, 0.028533370277727954, 0.012386149719532114, 0.04393009214254562, 0.04969241614162456, 0.02548735501477495, 0.014079639804549515, 0.023695977506577037, 0.04009884753031656, 0.055139980468084104, 0.07486356800654903, 0.04405767846037634, 0.027587298973230645, 0.043602753066807054, 0.037135707898414694, 0.05036882808781229, 0.04996289928385522, 0.051543521694839, 0.0345917740924051, 0.03443123270699289, 0.03603521050536074, 0.051274856814416125, 0.0525536885834299, 0.03726070041011553, 0.015906820372038055, 0.07117663772078231, 0.07688750119996257, 0.036944063103874214, 0.060819180216640234, 0.015046352091303561, 0.05725060393160675, 0.03633971369708888, 0.06028788411640562, 0.024713573293411173, 0.08323619607836008, 0.019226925614930224, 0.009480380886088824, 0.05156861741852481, 0.049141527342726476, 0.023106645458028652, 0.05077204063127283, 0.043878939613932744, 0.047327336214948446, 0.022313849913189188, 0.02623464577482082, 0.0800844730110839, 0.0740019790828228, 0.036976955088903196, 0.041352082625962794, 0.027630940967355855, 0.03487226880679373, 0.05199884042667691, 0.02644012049131561, 0.04474930443393532, 0.013345585248316638, 0.016508113985764794, 0.01838300537201576, 0.016185546919587068, 0.05332716602424625, 0.061543245465145446, 0.0738717321655713, 0.03796866105403751, 0.08135481461067684, 0.03630134466220625, 0.0466206520650303, 0.034692657936830074, 0.04056003293953836, 0.044170985856908374, 0.014498495893349173, 0.09777590807061642, 0.00590777381148655, 0.025399907754035667, 0.0333701804629527, 0.06680521721136756, 0.072668042848818, 0.019315241188451182, 0.08440222140052356, 0.0442146909335861, 0.024647976715641562, 0.015389576838060748, 0.06708370812702924, 0.01714298050501384, 0.0657949093147181, 0.033159510712721385, 0.018287169987161178, 0.025357514423376415, 0.04259676446963567, 0.03660706497612409, 0.03675424770335667, 0.01564270114613464, 0.013407899677986279, 0.030897296164766885, 0.019422988043515943, 0.036686834719148465, 0.027914910788240377, 0.05247575565590523, 0.030011607850610744, 0.02763630483968882, 0.014138557980913902, 0.04841575886530336, 0.051065344814560376, 0.045709621263085864, 0.06638412261963822, 0.03996818129962776, 0.04081066363141872, 0.03727207382326014, 0.07298411612282507, 0.04479461997107137, 0.04119835786696058, 0.030900105193722993, 0.07594623530167155, 0.022234699863474816, 0.04320164451200981, 0.0937569557572715, 0.008506851972924778, 0.12259886279935017, 0.04647855676012114, 0.016578567920078058, 0.06880316039314494, 0.04440585333213676, 0.03271776586188935, 0.03714062833751086, 0.035305568017065525, 0.043872401292901486, 0.09186341048916802, 0.0474505327292718, 0.03625727222242858, 0.0168066057813121, 0.08410634938627481, 0.04551385012746323, 0.022153700010676403, 0.047852086572675034, 0.038464107710751705, 0.042171669701929204, 0.03298649382486474, 0.03447412884270307, 0.05091923820145894, 0.037851060333196074, 0.020201898005325347, 0.011911018427781528, 0.02599194493086543, 0.02776634952169843, 0.08175101014785469, 0.011017044034815626, 0.05737696941650938, 0.04752832464873791, 0.03386775708349887, 0.05662888826918788, 0.06830577302025631, 0.03983745198638644, 0.04714351365691982, 0.017228655888175126, 0.039278173208003864, 0.09375728972372599, 0.0553998768737074, 0.00843144141981611, 0.009805384052015143, 0.04196264380880166, 0.0159317750876653, 0.03548646651324816, 0.04424374601512682, 0.08836851091473363, 0.021534233055717777, 0.024311789384228177, 0.03428040974540636, 0.05048537495895289, 0.043916225113207474, 0.03477566715446301, 0.035629712147056125, 0.00841158247567364, 0.006850209520052886, 0.05770780400780495, 0.01360873133307905, 0.025099261874856893, 0.023646021691092756, 0.01859109615907073, 0.03440353575570043, 0.04876864637481049, 0.025239232782041654, 0.02923780386481667, 0.013455401767714648, 0.04033391167467926, 0.06681338825728744, 0.02249716781079769, 0.005551490048674168, 0.0800336804240942, 0.0843297952087596, 0.015922863749437965, 0.02371462953306036, 0.05979165078315418, 0.09713852938148193, 0.04418080818140879, 0.0429353767685825, 0.017585398854862433, 0.03711569217557553, 0.03438172774622217, 0.05832212416862603, 0.014962998702685582, 0.03132370453386102, 0.0554470403585583, 0.07543021260062233, 0.044151077745482326, 0.05937756948696915, 0.02726092468947172, 0.033398708619643, 0.041807649977272376, 0.03459796360402834, 0.05348208564100787, 0.029558921887655742, 0.053082309241290204, 0.022997293708613142, 0.0359348498750478, 0.026241809355269652, 0.029363974535954185, 0.06742869547451846, 0.02096946795063559, 0.03376101769390516, 0.0337471321108751, 0.10781106568174437, 0.009759921940712957, 0.04105828491447028, 0.03332745502120815, 0.050165186476078816, 0.016845058307808358, 0.02525311465433333, 0.006473667444879538, 0.03161418855597731, 0.01103523778510862, 0.03493819007417187, 0.03149489202769473, 0.044193124122102745, 0.03834120063402224, 0.037313010689103976, 0.10929237760137767, 0.03554716306098271, 0.043327427410986274, 0.03918397982488386, 0.042168704821961, 0.005317314626154257, 0.08136308213579468, 0.08222096774261445, 0.021389633002399933, 0.023787129939591978, 0.03919122689694632, 0.01472743360864115, 0.029841960313206073, 0.05836635617015418, 0.009868134493444813, 0.040141450517694466, 0.09012994647491723, 0.03192298878275324, 0.026754629689094145, 0.03146259747154545, 0.08545953693101183, 0.008589349108660826, 0.07599201097036712, 0.1419663938577287, 0.18502465914934874, 0.1974932150915265, 0.1576740384916775, 0.16937821201281622, 0.07411675964249298, 0.17824298789491877, 0.11832070056698285, 0.12575653789099306, 0.16746268433053046, 0.08685242937644944, 0.22876250906847417, 0.08350879434146918, 0.10468116917763837, 0.15216204832540825, 0.12875439890194684, 0.11882347593200393, 0.06546013391925953, 0.10809454382979311, 0.14274064684286714, 0.12070811542798765, 0.16776702424976975, 0.25731836271006614, 0.16486669628648087, 0.15523866604780778, 0.10586207456071861, 0.21088480978505686, 0.12412174983182922, 0.1565924473106861, 0.10926638016826473, 0.20847919746302068, 0.1277292109443806, 0.12127234062063508, 0.17510327277705073, 0.1503377454355359, 0.3066935366950929, 0.14517086878186092, 0.15149632701650262, 0.10285084004863165, 0.17709837353322655, 0.21315950725693256, 0.15824538830202073, 0.11257635880610906, 0.09576933371135965, 0.2090182193205692, 0.07967598008690402, 0.19724728219443932, 0.1889764322550036, 0.15607895533321425, 0.1584176704636775, 0.06630630843574181, 0.17001973930746317, 0.18563258199719712, 0.18328243779251352, 0.16238407872151583, 0.1141276404086966, 0.13384444842813537, 0.33165404107421637, 0.10892420556047, 0.09681550960522145, 0.2828827378107235, 0.14554489636793733, 0.12927281873999164, 0.1286591961979866, 0.12395090743666515, 0.13037587283179164, 0.10455968702444807, 0.15560686035314575, 0.13224203285062686, 0.08000494446605444, 0.22692621307214722, 0.08174878370482475, 0.12169213645393029, 0.2035250054905191, 0.17892757459776476, 0.07764144902466796, 0.11808039314928465, 0.11186069838004187, 0.10783153411466628, 0.0974976917495951, 0.10817192756803706, 0.2197038396843709, 0.08887652584235184, 0.07494497418520041, 0.1348556691664271, 0.15710999141447246, 0.12663798668654636, 0.11198574284208007, 0.1572831196244806, 0.046909080338082276, 0.08532875566743314, 0.16488299384946004, 0.18373281753156334, 0.14287617785157636, 0.08244713724707253, 0.12900656583951786, 0.1041804718261119, 0.12175923402537592, 0.2908565505640581, 0.11759516957681626, 0.23774789879098535, 0.19785202865023166, 0.15664812322938815, 0.1128126957337372, 0.10637586339726113, 0.15547364484518766, 0.2602356858551502, 0.09820787512580864, 0.118251925741788, 0.16615911677945405, 0.16299621696816757, 0.16796370822703466, 0.10137917604879476, 0.08716333730262704, 0.11989932288997807, 0.10400853105238639, 0.21965080581139773, 0.1726490943110548, 0.1387494508526288, 0.1822269256808795, 0.12343887006863952, 0.1502587809227407, 0.09566289489157498, 0.16982057655695826, 0.2346275537274778, 0.10570515485596843, 0.17493781837401912, 0.21322581073036417, 0.12425146240275353, 0.1344841203535907, 0.1387853262713179, 0.11018963414244354, 0.1448441605316475, 0.15635308984201401, 0.1493143237894401, 0.09433750819880515, 0.10330990291549824, 0.2122104784939438, 0.13459585810778663, 0.07378864131169394, 0.16824188001919538, 0.11492936027934775, 0.14221587422071025, 0.14837268681731075, 0.10427144428831525, 0.17382884194375947, 0.11109510625828989, 0.13333150563994423, 0.13206001371145248, 0.16134605160914361, 0.07864924846217036, 0.06508592079626396, 0.07801491257851012, 0.17428613849915564, 0.1395534342736937, 0.15170344559010118, 0.2412957209162414, 0.1388954313006252, 0.12587384175276384, 0.1898440474178642, 0.20535068877507, 0.09302935417508706, 0.16160017781658098, 0.08243616088293493, 0.07991628750460222, 0.19003696128493175, 0.1694187184330076, 0.13857492740498856, 0.10478844662429765, 0.1498132399865426, 0.15837076673051342, 0.1529457265860401, 0.195893723575864, 0.20923713804222643, 0.06277896216488443, 0.15403600089484826], [0.04512570318183862, 0.05548252986045554, 0.018185981862188783, 0.06504130287794396, 0.04563386282825377, 0.045582068341900595, 0.01877870181488106, 0.040691148169571534, 0.021954758049105294, 0.032259764266200364, 0.009661150434112642, 0.06999609599006362, 0.046497488947352394, 0.08942766697145998, 0.02823701772285858, 0.05920886447711382, 0.06792981585022062, 0.027691220057022292, 0.06758028655895032, 0.04679151301388629, 0.010782298086269293, 0.05413775455963332, 0.04371473201899789, 0.026575324955047108, 0.032668071653461084, 0.019917673998861574, 0.018971259451063816, 0.030212585152185056, 0.025611082164687105, 0.041405628580832854, 0.03985628027294297, 0.07855663585360162, 0.05303444813762326, 0.016127633425639942, 0.043531673873076215, 0.027548065336304717, 0.012950175459991442, 0.03379458503331989, 0.016831642133183777, 0.049533767232787795, 0.05330642670742236, 0.02835026018146891, 0.040263162736664526, 0.038105249623185955, 0.013822152595821535, 0.044602763664443046, 0.05722758622141555, 0.018725233785517048, 0.006859168170194607, 0.08114558091619983, 0.033002086347551085, 0.046223128083511256, 0.027686815410561394, 0.057003550391527824, 0.027540684677660465, 0.031141451618168503, 0.03336682595545426, 0.020430353324627504, 0.021889716226723976, 0.07108818856067955, 0.09305118815973401, 0.04909505405521486, 0.05506058922037482, 0.07432420476106927, 0.02054369597317418, 0.00741456598007062, 0.07569671040982939, 0.02888818551582517, 0.04957828496117145, 0.04225359909469262, 0.06285061652306467, 0.045570386937470175, 0.03630380117101595, 0.06068251372198574, 0.06653376927715726, 0.02313796223461395, 0.057799533460638486, 0.025119704332610127, 0.032008573252824135, 0.013613251012429828, 0.021339254162739962, 0.02636812103446573, 0.026913375077128876, 0.050270567735424265, 0.04445219303306658, 0.011224560585105792, 0.04277693937183358, 0.011685390691127395, 0.023272565558727365, 0.03958456145483069, 0.0260699223872507, 0.033920560890692286, 0.09486745359026827, 0.02699834541999735, 0.08712087161256932, 0.025058362116396893, 0.03612033113313373, 0.11379140298231505, 0.06678456324152648, 0.03170320916979108, 0.04571764016873203, 0.05440143220766913, 0.04517248446063604, 0.02682919326616684, 0.024941555493569467, 0.07669002312468365, 0.07299938952201046, 0.01618034075363539, 0.025682964733277913, 0.010989769180014264, 0.05486128917254973, 0.026322191370127257, 0.030275548961071763, 0.08450943947536871, 0.02359515488933539, 0.05537064738746267, 0.03556576499249786, 0.03588830979424529, 0.02965008174214745, 0.06676327844616026, 0.02191821469750721, 0.017453326254326385, 0.04157974384725094, 0.019958113625762053, 0.02585308724519564, 0.048887200755416416, 0.01238692062543123, 0.02583878977020504, 0.057475252033327706, 0.02643329273269046, 0.04805576529179234, 0.040742757119005546, 0.012074657352059148, 0.057516392989782616, 0.03183371954946779, 0.1337262539891526, 0.029284633383213077, 0.08607652882346883, 0.06935451674507931, 0.02964436906040646, 0.03724395755853038, 0.018635856940818485, 0.02105559418851044, 0.015016954694146989, 0.08233911023125984, 0.08668980255606584, 0.05541137645195704, 0.015547842613159446, 0.03146539536828641, 0.060777363905799575, 0.05051254127465654, 0.013588834353868151, 0.06931242212885991, 0.07118279012502171, 0.01542240666822181, 0.06076078432670329, 0.056225267544505186, 0.04950651557010133, 0.005547789514821488, 0.03911101186531596, 0.023515348038927186, 0.058330755346105434, 0.047653465589974076, 0.07034042282612063, 0.005119192273923545, 0.02950827587483218, 0.006433121598092839, 0.017177000554511324, 0.060501418556668796, 0.03036310383322416, 0.051691324115381576, 0.052241285229683854, 0.06886229472002015, 0.03526566273649223, 0.022649142956652213, 0.04814656334929168, 0.06762154254829511, 0.02625396202347474, 0.08133431649184786, 0.037290653490344994, 0.03333713633765001, 0.029029995093878824, 0.040332909775315784, 0.026069310115417466, 0.02217641900642775, 0.0423187151318416, 0.03247076427214779, 0.0062703454204893205, 0.04806638171430677, 0.10120816295966506, 0.02308588387677446, 0.04798399218998384, 0.0552343519666465, 0.07839686630177312, 0.08018890803214163, 0.06379503654898144, 0.05221699844696559, 0.02174791592551628, 0.028084072218916845, 0.04152323672315106, 0.025948731527023483, 0.04868122879997827, 0.02569679094449384, 0.0352135045977775, 0.028080079464416485, 0.03343397918797564, 0.023688661785854492, 0.04467212478630245, 0.018596090812934563, 0.03233475457818713, 0.04314183483074885, 0.050605350552359596, 0.016835929891385604, 0.08571940736146644, 0.053932053488097154, 0.05011560730054043, 0.02841794404957909, 0.042549957215669565, 0.023870517652540002, 0.029228632774902508, 0.028867051005363464, 0.05012313638872001, 0.032129101746249944, 0.07045894381008111, 0.01820336667151423, 0.08557389446650632, 0.022507889989356045, 0.019690022054419387, 0.010179200126003707, 0.04863029891566839, 0.04284359165467322, 0.02271457440656377, 0.0695569375238847, 0.06188133826071862, 0.022246713378990535, 0.03565055907529313, 0.07591682398924604, 0.035244322280050255, 0.040513344429200515, 0.042254983200109564, 0.046102013293420896, 0.019476240850053728, 0.08328741911100224, 0.04520928385318257, 0.043071241743746214, 0.04641894374799449, 0.07332660985412076, 0.052760495455004275, 0.037230751040624455, 0.07961459705256857, 0.04350388786406256, 0.017044230335159227, 0.02155281643354101, 0.03252606540627312, 0.042739776326925494, 0.05092098595923744, 0.04262998671038076, 0.027242868236498907, 0.005080658111182856, 0.059466189341037534, 0.10992174109560438, 0.024052041408140212, 0.03563790174666792, 0.0576346913294401, 0.05652668340189848, 0.02730829412030289, 0.04462538803636562, 0.031105340567592066, 0.05464617766847368, 0.0024864048373274272, 0.04687274849857204, 0.033730188879417256, 0.05550179601414129, 0.05734423699323088, 0.001359895979931025, 0.03632925683632493, 0.010356633720220998, 0.02868409861548571, 0.04631504307326395, 0.033056927350116894, 0.07812454263330437, 0.018067959972540848, 0.08440074452664703, 0.01915578148327768, 0.024772848628344946, 0.03105767613305943, 0.030189094322849996, 0.032664468526490964, 0.06455961934989318, 0.010193549551331671, 0.024231008464994375, 0.02892515745770652, 0.03924018266843632, 0.032338201854145154, 0.01127588937379187, 0.05016720140702091, 0.04967340602888726, 0.00793789744420792, 0.05049875588156283, 0.04902942222543061, 0.036845016074948944, 0.047393353961524554, 0.019834748272842262, 0.00962651440204354, 0.10846703517017886, 0.020178932245471515, 0.01887317164801061, 0.0742622057441622, 0.053954844843246974, 0.033309762220596895, 0.038458656636066735, 0.07222987143904902, 0.00771148998865101, 0.011986240660917247, 0.040674646515981294, 0.033196736840181984, 0.048904333234531805, 0.024565403509768657, 0.055801133858039975, 0.022288358995865565, 0.07952851534355432, 0.03801667800871655, 0.07354851200943813, 0.04893041972536594, 0.0322764662996633, 0.03164019712130539, 0.052129684772808105, 0.04153715941356495, 0.08334664991707541, 0.06305081085884012, 0.055214814929058775, 0.05262252649117727, 0.06322882982203737, 0.033929429555428214, 0.06790892439312302, 0.022740117274224758, 0.050540349548100494, 0.08863828159519471, 0.03565478189557325, 0.05074800988950301, 0.012852339059463702, 0.01450976169508067, 0.009712161026982358, 0.034398158895783126, 0.03178922779625282, 0.06359906503348611, 0.08379913735552691, 0.05506698653334752, 0.06429312896216288, 0.0726967045920901, 0.03414593629713636, 0.07433809034409933, 0.10059142339741811, 0.09612234367523342, 0.15142356685828418, 0.12209622844238766, 0.05358006397727877, 0.13947049184935167, 0.12057549363817088, 0.1645543857011944, 0.12982506566913798, 0.11103229830041528, 0.0778642862860579, 0.14886015909723938, 0.11166021460667253, 0.2392305911052972, 0.16545504127861932, 0.15453948872163892, 0.19290634169010445, 0.25355591147672385, 0.16307114419760182, 0.19108723383396864, 0.15324395120842382, 0.1474909411626868, 0.1071391325967852, 0.08631772681837901, 0.09741423724335618, 0.20173083379631862, 0.16878854599781334, 0.15321822836995125, 0.13685563841136172, 0.10417046025395393, 0.11557433113921434, 0.3342311637243256, 0.18454996665241197, 0.10619558088365011, 0.15052957576699555, 0.16168570291483775, 0.08306116797029972, 0.1904627462499775, 0.19417011528275907, 0.1987178626586683, 0.13660672208061442, 0.10786559869302437, 0.249417339800857, 0.07331161104957573, 0.12104788547731005, 0.1600837177829817, 0.09441590125788935, 0.15482754592085257, 0.09927361403242685, 0.18800390709657222, 0.08460749944788404, 0.15962913748808205, 0.1448005370912142, 0.18808652297593653, 0.10090243522427045, 0.05476483223901596, 0.17035633296472952, 0.2015941747231409, 0.06248356512514874, 0.12959213519934565, 0.1615395295084454, 0.1650738445459865, 0.13308144640177488, 0.15697224880568683, 0.10892554142628796, 0.09389906961587258, 0.22522014915011823, 0.12474549526814371, 0.21863094647414982, 0.2055124324397184, 0.13936953007942066, 0.1276058511575684, 0.08410407099290751, 0.11663125333143398, 0.10116521487361751, 0.0871873606229201, 0.09703139294288121, 0.1156055681349244, 0.15418030408909544, 0.1591579627711326, 0.11096805057604797, 0.0918332273431588, 0.1884994687861763, 0.18358895962592214, 0.14202527585439384, 0.0853230782377068, 0.07942693759105168, 0.1124816681840457, 0.2397625774028711, 0.15252896613674238, 0.10280557646183297, 0.10669274561223574, 0.24101161194266751, 0.10241682466585189, 0.14968008385039866, 0.16046690347138792, 0.1327694475185126, 0.26544354390352964, 0.1304506219457835, 0.10391014453489333, 0.10030783392721787, 0.13801782683003694, 0.28116920788306743, 0.10549135695328005, 0.14982146298279986, 0.2571979269850999, 0.16833947243867442, 0.07296237861737609, 0.1321564632235095, 0.19356970296939835, 0.16644785675453022, 0.08717443241039291, 0.12493321410147473, 0.15761061455123127, 0.1257251450442709, 0.11878829813213088, 0.15028468187665567, 0.0850475336483214, 0.08735112292924896, 0.18047989520709962, 0.13548783055739477, 0.12391756274155341, 0.1289857114898041, 0.12984347093151882, 0.2620782604208216, 0.15944214595947415, 0.08094426593743265, 0.06434680850361474, 0.1613129666657187, 0.17964537983061746, 0.09231183837982826, 0.26553295785561204, 0.13744615047471598, 0.13729417347349226, 0.1791012816829607, 0.263165031792596, 0.10033621365437284, 0.20359444082714617, 0.12304657822824083, 0.08286450625746511, 0.15685579099226743, 0.1177125031244941, 0.15281766158295795, 0.14547072612913325, 0.2340455021476373, 0.1250400091521442, 0.13763660041149706, 0.13850516552338377, 0.19391305017052218, 0.2081660259864293, 0.30995958019047976, 0.14593007101211697, 0.16550865402678028, 0.20080414367839694, 0.1945098556461744, 0.11413413420086727, 0.17447718215407804, 0.14960791741032153, 0.17657333373790607, 0.19215160718886182, 0.08958361446275376, 0.22761321917641908, 0.15646821178961545, 0.16274427267489955, 0.08473974274238572, 0.11449757133959793, 0.09005127139971592, 0.10253916028887033, 0.18485623615561053, 0.14018534333445132, 0.16279600036796182, 0.09200761720421724, 0.15499997651204467, 0.21168100065551698, 0.08399602171266451, 0.16548774030525237], [0.010218568277196027, 0.02218110195826739, 0.0400694473501062, 0.05597402087005321, 0.03855413764540572, 0.00975380849922658, 0.04979067649401259, 0.07562556813354604, 0.02875611105991993, 0.008396086432185257, 0.037879911324125715, 0.06288405027589761, 0.03406288997211959, 0.07480011438019574, 0.056637935049366206, 0.009230945051967865, 0.059369461523601785, 0.06591453609871678, 0.08667023212183267, 0.017516911611892283, 0.019050737901125103, 0.02960748617624631, 0.00515531492055743, 0.0400874852493871, 0.04094791271199938, 0.068629898596555, 0.09477790605160408, 0.0383737883385038, 0.04537754357443191, 0.020101520676689688, 0.062109570935717784, 0.019727569160750136, 0.06787843696656637, 0.023102840095816646, 0.02570142751210369, 0.04160055366810411, 0.08092580872471444, 0.054138296327437274, 0.023991315174498595, 0.021464311612362508, 0.06073882417695131, 0.023636486948817037, 0.016353378050553147, 0.005735291269957088, 0.029615590428875294, 0.0761810656695161, 0.08745664890739135, 0.014507333944493439, 0.01894079799967585, 0.026409037491248455, 0.009851355462160427, 0.02587302318715956, 0.0452856990887085, 0.0355408585164696, 0.03965221934777219, 0.005504940691025695, 0.019595823105191812, 0.022301519129541703, 0.056219883263111115, 0.01006933443932212, 0.08724960454856046, 0.07220166240585968, 0.03171982956700958, 0.029395001874945592, 0.014947848685551435, 0.005667076766258106, 0.060510483890539035, 0.03557885647751391, 0.041711838712217286, 0.0651615382230375, 0.0721959256043192, 0.013214759455877356, 0.04323649205616675, 0.016497434480697848, 0.07467524061212316, 0.058216653851559386, 0.10623106296407059, 0.026051819550048094, 0.047939704527379945, 0.038297124483506195, 0.02093206927384017, 0.035323078991496004, 0.03713461694133002, 0.08448349399259314, 0.01827894513553474, 0.03703154005052056, 0.07721689602476545, 0.04979171550075989, 0.03337683010613546, 0.04070194641826674, 0.038205810633371584, 0.06464725956902839, 0.073155344434781, 0.032430858991574496, 0.038855223247082904, 0.014856624820822617, 0.0486511013150448, 0.037740458064945415, 0.0435209869465325, 0.09952870503184386, 0.06392549868905917, 0.05169022573682014, 0.026952243206324056, 0.04799009264388587, 0.04254434286849573, 0.026674724504118785, 0.05979321671475191, 0.007227462201626622, 0.02711842676944798, 0.00674584546686674, 0.012331598154560197, 0.03781781953875907, 0.032686343329260126, 0.019728994084289297, 0.015412738339364296, 0.03496084413200151, 0.04625984212907497, 0.03545441686583217, 0.028545927416416816, 0.010633832371240715, 0.08221598793170415, 0.030870215196046047, 0.039234141586348414, 0.0058545381671137875, 0.04364128166344017, 0.012659533731493866, 0.09282892977353185, 0.0032539075255044736, 0.0677968304080423, 0.01869741994596552, 0.022160401604196522, 0.04871282202657312, 0.03396062944375444, 0.12244648503838107, 0.0038031026042517624, 0.017129106054198928, 0.06900318403495476, 0.021703810089093167, 0.017098091702791862, 0.04573266865918413, 0.02364197513088584, 0.02782300321996445, 0.029367230708885472, 0.028852464092778973, 0.04123670092667453, 0.07067819649819285, 0.052039061120012775, 0.020374319319671486, 0.0833295879419893, 0.02649718979228055, 0.04019364947453141, 0.015219013675960014, 0.06480458745500073, 0.09960906478227116, 0.05551456837565638, 0.04739762131066527, 0.024619083051220514, 0.02023518147325376, 0.029961551845190115, 0.043301827026880346, 0.025662572370492853, 0.050989786759600975, 0.08912184275686741, 0.05636628673528321, 0.07731969832093455, 0.007780281048326287, 0.0139691163894895, 0.03942215356801171, 0.05709424083761405, 0.016148151953530032, 0.020768208632944152, 0.03284068778157234, 0.026214912068098783, 0.0027200141403227462, 0.040709865133976564, 0.03442520275712013, 0.02414338679955108, 0.023004787544778083, 0.029640884677064605, 0.03851360525004566, 0.03166821690683719, 0.05883972022274975, 0.020708447191282175, 0.021624947621603496, 0.04806112359801773, 0.04729072235932108, 0.03796496144786943, 0.03348163249029312, 0.05613329689367674, 0.029856892324460205, 0.011043109188904054, 0.04185930345556699, 0.06340339037706144, 0.062467007810482755, 0.016991040611173958, 0.01816418498492567, 0.001370944007703656, 0.013605749754788121, 0.03957369641284458, 0.05480648156662937, 0.04999119737476576, 0.002038547936535906, 0.02493866668373812, 0.02757341895630816, 0.028860488564532716, 0.048427629517391324, 0.026065831298183184, 0.04827666183700785, 0.02244311534013832, 0.010989187521772692, 0.06579439723282121, 0.04268631571903825, 0.11392513057217002, 0.10926940813078545, 0.025757951334526297, 0.06727929372573271, 0.05457490180560853, 0.04498275440710131, 0.025349378629471175, 0.07363212978816591, 0.034439526207279414, 0.06962817627936602, 0.04598780047672335, 0.012612014943442773, 0.040773144355625845, 0.014195453804859426, 0.01100388575650868, 0.014832319484412437, 0.05143555776157882, 0.01986421710171271, 0.019631885916169267, 0.026089390776178334, 0.07173109625000507, 0.009369392701046309, 0.03201494830136653, 0.02033321918133879, 0.09044032005476765, 0.06214057786564808, 0.04870485507126432, 0.023651469055039342, 0.012415275305102114, 0.024659099653945304, 0.06170754582853988, 0.021869071533728857, 0.04014962898509111, 0.0872629409423098, 0.034290766416233964, 0.02011632837820798, 0.015438148548128083, 0.023993723443709314, 0.045333916423260234, 0.011804815239884192, 0.06466625854955055, 0.006487916216428857, 0.05141834735695738, 0.04708751861471683, 0.04842322116019204, 0.020589237865351606, 0.05839256140461657, 0.03959828747611027, 0.018885328026954085, 0.07470194308552891, 0.045557581179309636, 0.03466332454991061, 0.02850715391105041, 0.005777550550192245, 0.040296462902915664, 0.01463760219849064, 0.04733139205200132, 0.03471040639851708, 0.043062465847469866, 0.026437615742906928, 0.08012572157895193, 0.006872787971587968, 0.019945066669606604, 0.09553883748594671, 0.045286901367944665, 0.014501943169307197, 0.09940676274709404, 0.01852577788667986, 0.038404227525461465, 0.02813994109601481, 0.0853094227204565, 0.06998492666753009, 0.07147992379032075, 0.03056943944102386, 0.0542005254101241, 0.11243857166846283, 0.07132093349355273, 0.03795206292124931, 0.01266981989829219, 0.05012038673157804, 0.04554566970909946, 0.024470712887705304, 0.02376241456659045, 0.059763779427157715, 0.052369929107953794, 0.048167313798330724, 0.04174344678176567, 0.008974532102001831, 0.02011193300859304, 0.028074847323296126, 0.011591569309530314, 0.034783259325195104, 0.029516383838199545, 0.012863161427958403, 0.00811455642178771, 0.0032828781877469737, 0.01953100392711349, 0.08478769290377386, 0.028987904188397806, 0.02338335893000476, 0.08878280743374489, 0.03804148800554685, 0.04063339423737489, 0.06924559915205464, 0.020778713733307086, 0.0892412691609934, 0.025743972983036656, 0.027065543181379326, 0.013810803302476415, 0.0757648098806385, 0.03136309031106066, 0.04108204477233812, 0.01026861036734772, 0.030993597247288562, 0.0192730983326328, 0.029795418377034366, 0.02894990066124592, 0.03155263482767623, 0.055495510023320094, 0.04844923343625851, 0.017596499528735876, 0.004567301575661986, 0.023889904405223206, 0.019731736319954507, 0.017330270748061594, 0.028957090216863435, 0.05653993444866501, 0.0371440719027305, 0.0632089031569194, 0.03147950359561946, 0.04936842044116929, 0.06957765086553991, 0.06727198357111774, 0.036784690601052716, 0.06751521505066194, 0.04032888733490836, 0.08436004514805973, 0.020643060270231217, 0.053596194557030685, 0.04217978137603495, 0.09858394361799583, 0.0883389511727728, 0.13814572856063023, 0.14386280381586403, 0.11756428881199099, 0.08225523270084523, 0.07337781062233262, 0.08514413158991374, 0.13399528252193704, 0.16997749626170844, 0.2420411934144795, 0.13431983854388818, 0.14433320669922978, 0.12321422196691856, 0.12392381162499078, 0.15929269226035103, 0.15296466619474813, 0.12020603026030585, 0.11338319949572906, 0.1239219043054618, 0.11827501395600848, 0.16502961254445836, 0.12881826813099906, 0.14353142003528774, 0.16559959680307657, 0.14446667453739792, 0.13235149963293225, 0.10643231114954688, 0.17693765403237194, 0.13253501791041344, 0.12259038747288287, 0.21406795538496226, 0.11913694426766597, 0.150393451040145, 0.1555607284535654, 0.08606242801761255, 0.17638598597841337, 0.21184747922234237, 0.13612003647722304, 0.3257504937937483, 0.22278397518675774, 0.1273803718504496, 0.14414621517062187, 0.18369645229540765, 0.12292291416088119, 0.17436816066037863, 0.18454999633831903, 0.15883839398156852, 0.1373389398213476, 0.1636271018651314, 0.08033446545596235, 0.13559263665229082, 0.13244177447631955, 0.10965859779389575, 0.1811498764436692, 0.10680192295694724, 0.15970684034982696, 0.09737364918692037, 0.14731227653101087, 0.1175141344720032, 0.14022430608747527, 0.1411964898579754, 0.09715878259157762, 0.08761048127780668, 0.10725795043981634, 0.12833327462431043, 0.18051600811304525, 0.0814681182964705, 0.14517002273350954, 0.14594242034945637, 0.13055801071459427, 0.1299969173851423, 0.10805851256009191, 0.09549642374622636, 0.20406254305271432, 0.10360814238083549, 0.25376255507580936, 0.17743422504281625, 0.13995852816151455, 0.18008038226980716, 0.12231303204316646, 0.11407179379602894, 0.19231419690186158, 0.227529579133261, 0.11282775391009636, 0.1273811436840333, 0.1544459632714279, 0.18810325098456815, 0.09336252653156407, 0.12720648664981127, 0.1723750340170227, 0.08265802593086846, 0.22870543791214004, 0.19311576092150062, 0.18034678359981626, 0.12329623670666479, 0.2550696849357337, 0.11726192300557159, 0.1276625067112036, 0.2481983622419648, 0.12187860105768777, 0.12940876535139978, 0.20427591050975025, 0.12868787278421223, 0.1319165268796496, 0.10473987305886112, 0.13275323901325464, 0.19623423577286303, 0.2715342311421409, 0.09818747348617762, 0.11613267852226272, 0.1649322427692823, 0.32124117482453585, 0.23513081890996546, 0.07297906209714711, 0.10278151603415608, 0.08588657612563111, 0.1719114588922821, 0.15178147499682382, 0.112237308640033, 0.1462475024163723, 0.17960135563043877, 0.1823847953346558, 0.13335874245967716, 0.18037615780485794, 0.1312038573087193, 0.18140688218409196, 0.13458536413963884, 0.17168479214888066, 0.1628872993751429, 0.1290660712402314, 0.10149587877094746, 0.1560995721956715, 0.2220366770052351, 0.16083149093901739, 0.09338332893094048, 0.2400078868959099, 0.09182491528918035, 0.09597224430763163, 0.13199105334933847, 0.13159600814105943, 0.17442345066228881, 0.13264927896670997, 0.12049741970258765, 0.08249525068094954, 0.12653350713662803, 0.0797884377243463, 0.13051303656538948, 0.20256894116755575, 0.16172757488675416, 0.1181342508061789, 0.08086273359367624, 0.12423406646121293, 0.20207424036925659, 0.20426075585419312, 0.11918977776076645, 0.14085612609051168, 0.1025638886494562, 0.175014155684039, 0.14223891048459336, 0.07388268626527861, 0.12169524605269544, 0.1654182159109041, 0.13293194817379117, 0.12692948745097965, 0.08148819339112379, 0.1492458235588856, 0.11998638423392549, 0.2334350856835954, 0.11935334710869938, 0.1317026696051471, 0.13510851887986064, 0.11378805589629337, 0.15140533971134573, 0.1593592035351321, 0.14850734209176153], [0.023081783510860987, 0.039740097054163925, 0.044005301388096996, 0.05148169708263595, 0.1402360320207663, 0.07643572622328065, 0.05520812817849219, 0.023076961406331975, 0.06445946652092971, 0.0332079321378842, 0.07248629830428399, 0.05029031999583822, 0.028802959132008255, 0.051513115904526785, 0.024003694197745062, 0.03894765402947087, 0.05792826268589124, 0.023553995379188564, 0.0562792216805974, 0.05470530828461051, 0.08976411962066777, 0.08841710674460046, 0.05273286529700272, 0.04504331365751568, 0.01974363851331873, 0.05064356744696852, 0.027385546127334237, 0.041550477253622375, 0.005943658970863908, 0.02711658067710232, 0.01817131331335986, 0.09461065565119497, 0.037782300350954756, 0.08213079679990187, 0.05449851254525129, 0.032441724033560604, 0.055547979864059016, 0.027741519115807023, 0.014842551845504204, 0.029190538334660232, 0.04458759787667077, 0.06835945256170817, 0.026049854714074172, 0.04673106508562341, 0.04236542961734813, 0.021922318774159066, 0.008192889181373175, 0.04812190178199671, 0.06664751083008014, 0.07442346701282077, 0.0581602135207504, 0.056177744118031114, 0.03942869559978135, 0.06229756065295078, 0.04361291306850035, 0.010925145743385656, 0.057388457862543873, 0.08321859233547002, 0.060455628045019694, 0.015973691588442307, 0.0232653426064644, 0.025293340913776774, 0.031965896050678566, 0.0793695250467863, 0.02250428315164754, 0.024543604777136352, 0.06962054700125009, 0.024657275826029945, 0.03560573706636205, 0.08206314261769876, 0.06817868023063056, 0.07915439869975671, 0.03527617525833193, 0.05370170940295793, 0.048866223951335996, 0.01890198367618723, 0.02575041482486995, 0.077630420710193, 0.027173978378414176, 0.012735086220345693, 0.05573041460593231, 0.034965241356985644, 0.022911930027476046, 0.05255632691842038, 0.017993119945458602, 0.0829081296978984, 0.045013675990048796, 0.05774966855824459, 0.06140954385045916, 0.03266203428211156, 0.00971723546172143, 0.009097055117308628, 0.0895374380343128, 0.054616721827187575, 0.032755953070591204, 0.030923232370696496, 0.02938130739494227, 0.014770572797715431, 0.012927718071296113, 0.03659364694613032, 0.028507881215773523, 0.03136070059554186, 0.02383423961873632, 0.013894338517275173, 0.08410129536059685, 0.041509737056912854, 0.023033939105516765, 0.01968722601304762, 0.04661625484004617, 0.06918696948559955, 0.071664139686618, 0.03976561209128704, 0.015417062277265359, 0.06347350848955102, 0.019669418179546483, 0.06044175730494317, 0.04437993011379149, 0.03485167420876678, 0.027086900336144026, 0.005963743342363159, 0.020037421381857712, 0.03297832648968324, 0.10266736630001105, 0.01801135265850462, 0.07666211837204173, 0.008525087469024584, 0.018015041132457554, 0.06799948867410421, 0.025096645804296713, 0.03999172222393099, 0.014605431952077197, 0.04000446118880063, 0.026711182508734055, 0.06286103627644479, 0.01826604475354543, 0.01863929493993055, 0.03480741994280834, 0.027196758601348847, 0.04245912205078639, 0.011882364105986198, 0.09994153951993212, 0.027324009097355884, 0.03860923468891997, 0.015600990591337904, 0.05055776775407139, 0.015923232967907097, 0.03634526867244858, 0.01928843295900151, 0.053206960365059786, 0.04196576453978196, 0.022828421715530567, 0.02128539465047652, 0.016689452204445843, 0.008401852919632802, 0.013418878825177671, 0.038865450042067096, 0.029813376495440025, 0.026028504980786238, 0.08640013489639387, 0.04605324676958844, 0.08181215569493361, 0.011426729961385718, 0.034280736290384084, 0.027132217728649266, 0.01915998389449669, 0.04752684777486138, 0.024874096125131473, 0.04148650412389543, 0.009799882882361999, 0.05120628607983235, 0.05087224912131205, 0.07982579743838869, 0.034786955220624804, 0.02972894235426793, 0.04767577825987246, 0.020981902634957805, 0.018575870999484323, 0.024255694152088836, 0.04615743317117449, 0.02412548434222117, 0.0886054860893637, 0.020680677880591247, 0.017494235289632343, 0.031648405274609104, 0.038644998785457574, 0.029753062153758947, 0.032765972064225934, 0.04663768435420934, 0.040830397338140756, 0.036484977972577326, 0.017467788857175037, 0.0703426641121041, 0.054769281414337456, 0.032238672429230064, 0.06540809452417307, 0.015792236481502187, 0.028359561147226486, 0.05385799828218296, 0.06497370064607821, 0.024965942466224078, 0.05173960453248583, 0.009918762880261056, 0.015807007075636648, 0.031892048646113835, 0.037180604122113436, 0.030019951445865445, 0.0353912897844566, 0.05069460494269151, 0.056241561396745965, 0.031626912677893415, 0.0830406995373778, 0.02058376638160553, 0.0072112560155801475, 0.01722081138723297, 0.0346556470321957, 0.045728408731520176, 0.021405036277428735, 0.05667034834914375, 0.01869462019385537, 0.029899343171564396, 0.02435011017951183, 0.027825270481116604, 0.061597270105266944, 0.043107885285280645, 0.09360892698168755, 0.08983317646197975, 0.042795619228854775, 0.05621114818495698, 0.046074483325355686, 0.011669914129015524, 0.03945410673622973, 0.04401486396091059, 0.02552410245698411, 0.03350845741806552, 0.08048809744650498, 0.05303007688780781, 0.020508664747467265, 0.02075350483210059, 0.006861032352389884, 0.04530336591415107, 0.030500176653731614, 0.03622943055233918, 0.09383383483509533, 0.07319014373933896, 0.02952292958070757, 0.10554545951890759, 0.013515537066268735, 0.08061571716098115, 0.026066443570016418, 0.055641538710915484, 0.02129868465999607, 0.030303067796921823, 0.06107284629251808, 0.051067007225356065, 0.07742404428427108, 0.025301424757344648, 0.033419804167351685, 0.05943529002252035, 0.021253209561109543, 0.040160957869375125, 0.05912894630455412, 0.05033722372900229, 0.03874586778692901, 0.014273729975684546, 0.053509207427850924, 0.020161365609965287, 0.09399399030371569, 0.008643003602628596, 0.05026228536735289, 0.06299701999523677, 0.023253906110767275, 0.052069919620407745, 0.0082184459643031, 0.03942685136280488, 0.0447128352971049, 0.013757794476987328, 0.07105744880391285, 0.025260302354581654, 0.026106506556971, 0.05076789573649876, 0.025924255496647675, 0.02009430514590349, 0.034756304521579295, 0.03267861015046947, 0.03963182512961794, 0.013688046510651475, 0.056339439543080516, 0.04626436180842575, 0.038426811079261824, 0.025523339900246356, 0.005836582367919618, 0.03721639790455811, 0.025515970373817254, 0.013391315460467013, 0.07533775584306568, 0.055062084647943266, 0.05450141805340536, 0.03857275070913602, 0.024225995257438626, 0.04166922088188585, 0.07255703982082196, 0.06394201147486456, 0.055152741697384045, 0.05149882585101295, 0.043358078110031784, 0.010292734805261716, 0.048974199016811326, 0.03538731558364816, 0.015109673058759654, 0.011292989383946406, 0.023490847888751887, 0.05121743684867397, 0.09513249679002911, 0.01653826744586695, 0.02161076889024116, 0.011424603708292125, 0.07292823240277357, 0.03860453318338841, 0.012958585848537041, 0.04826775235414971, 0.04848480457440019, 0.016525430146430153, 0.028972469372092746, 0.08605217153672129, 0.02039176721154945, 0.029065492017252836, 0.05597257368208375, 0.03333617154567037, 0.05317485505656805, 0.03570228676835541, 0.028604603467101697, 0.01052659295964986, 0.05964152172964532, 0.048231921464321204, 0.028993063970119692, 0.07450016055372544, 0.015065288916957797, 0.050717767371679656, 0.11256154553848319, 0.04604464156727772, 0.041031344953808, 0.062004430874367245, 0.07024872305919416, 0.08909715150366537, 0.03745892805454787, 0.030996870118542574, 0.047152527040452696, 0.05309128922817763, 0.032124619174283, 0.03583851539588068, 0.0673564251337666, 0.04590542579535395, 0.12332692451309413, 0.08434488307102583, 0.1518213580129668, 0.12733741634292528, 0.19552591518731788, 0.18118310981662944, 0.16285776189761236, 0.08492132401443087, 0.0996213176404126, 0.12400712512317114, 0.1103284083364997, 0.1071071979822591, 0.1105504589213524, 0.11310696470900439, 0.10814788940479048, 0.16711721458705142, 0.14582912408513948, 0.09506543632596731, 0.2487772671156563, 0.10230982181383297, 0.17165148456115276, 0.21680777164874598, 0.20259184384485707, 0.160034958680626, 0.14124698558589444, 0.08866119911544956, 0.10071391487144865, 0.15168450598139316, 0.10762763646198437, 0.17318109545158222, 0.11659907380817458, 0.2621882763924077, 0.10123393032699823, 0.09369451887323521, 0.12464181723771617, 0.10206038597971201, 0.14925057330401614, 0.09427380966371857, 0.09163279552012682, 0.22836499992990866, 0.10044443362858146, 0.13675812020665035, 0.09262370367650874, 0.14553008310031146, 0.1297665695892647, 0.1829209376592189, 0.12724258471280336, 0.14540853415383026, 0.1864175367518328, 0.15617173863574862, 0.1570961726247333, 0.16553563851630315, 0.20614097215002403, 0.21348964422941208, 0.11427495672251098, 0.060136122338008136, 0.16339862428139895, 0.12030823883833364, 0.19929759873775765, 0.20964362716767937, 0.04994417860871181, 0.11448299555922858, 0.11319508732412942, 0.1982519423472695, 0.11995399690931663, 0.10505175319849513, 0.189613877737429, 0.10896841529756784, 0.14833161636488512, 0.21621979773044586, 0.20414446131326258, 0.2261928969528526, 0.11564664600882679, 0.11848307505715638, 0.11855999124236405, 0.07337068600463681, 0.16483586747199297, 0.2353493368718773, 0.1630388607736677, 0.08587954798713326, 0.10037631931481883, 0.1615881104953587, 0.16187426779652014, 0.12786109058652073, 0.14966807590099052, 0.10617543157422915, 0.11992148341960274, 0.17111479304730892, 0.16124722722452134, 0.08964223670773208, 0.18553129368228838, 0.10517657501623034, 0.18978040083311498, 0.11431521823396906, 0.1952476691803895, 0.08388006855966523, 0.18022248870693147, 0.11742819377104752, 0.11227707291254774, 0.1859502212028019, 0.17453126987675205, 0.10677976242732257, 0.12964883528184146, 0.20952915831003338, 0.14646042458480224, 0.10043920890893787, 0.13516275503206998, 0.07381957402685657, 0.12500910612288862, 0.1158222158846911, 0.10938896812149324, 0.09410583195858635, 0.27542545984033495, 0.11505810805829242, 0.06606428665691055, 0.17208804551046342, 0.1086341222980991, 0.10999580743373372, 0.09592381917173043, 0.23767976963426918, 0.14197467622580007, 0.2524605015059933, 0.13440004986478016, 0.09034272021381184, 0.20471993746468797, 0.1231320142687764, 0.11637262970907614, 0.15347278502304107, 0.1436443006969057, 0.12399707644362934, 0.11495662678498775, 0.11413745902245864, 0.09862180799245834, 0.12332859434536658, 0.11618194228503853, 0.15173307212535292, 0.1463809554115869, 0.08902704823412932, 0.08127593173412606, 0.08580514026107267, 0.17563996429089457, 0.15948283049510792, 0.14387832954525948, 0.13691644999198616, 0.21058708982309327, 0.09020329292980023, 0.1462593619362451, 0.13932356145232916, 0.2207903884118423, 0.15008210524683818, 0.12903531664051116, 0.11072326058638282, 0.20570711261825636, 0.10983439773553982, 0.19335266930283979, 0.1195185120741371, 0.1654655797756277, 0.1271653568255715, 0.14470653666649014, 0.13389927829848602, 0.1336289435857907, 0.2018133012461476, 0.20642772316932678, 0.1254648293252103, 0.1820502945338376, 0.18614037428051233, 0.2006423257989809, 0.18893458996899426, 0.12669146584812552, 0.09675496519776061, 0.15522946341661736, 0.16189856571145356, 0.12426952627720311, 0.13500166445737705, 0.12889298755908385, 0.09523017826722935], [0.03404374627280049, 0.006995556823312654, 0.015689688370912336, 0.013842284279235173, 0.03830909532553051, 0.02845830204023514, 0.027930631331400946, 0.02142928038665559, 0.02610927476780489, 0.0520468907780014, 0.04634935627109371, 0.020565971535688732, 0.03782312589464709, 0.04224041855195537, 0.09416968634468503, 0.051200883244746365, 0.02649186488270061, 0.03451000426139217, 0.018410967641102616, 0.10084278881549835, 0.050861120616900735, 0.011214920086786151, 0.017262963519897312, 0.04283054840925615, 0.028343675476207864, 0.05140382723766379, 0.03802061881287955, 0.010557434761722106, 0.06498628004919738, 0.01907817138999235, 0.014903192732163006, 0.01113104905016371, 0.04004989175882656, 0.03617256719735451, 0.012331930265645497, 0.052031394734513015, 0.04587418137816712, 0.028172400780022144, 0.028664171950367745, 0.0364275728497887, 0.058333486449555494, 0.055327873706119135, 0.03773329262912739, 0.050418845130479895, 0.035222414080635644, 0.014215675473678857, 0.011840208262583474, 0.05397048931627069, 0.02675573734450154, 0.03846390733087901, 0.03648857738880906, 0.12719243037281558, 0.03354591732204426, 0.05703109520254657, 0.047727060664328746, 0.04927162954118103, 0.028858085861429572, 0.057774114902713336, 0.024713818202144466, 0.03744678651855793, 0.02464061832142761, 0.02485794513631845, 0.008633986508357339, 0.05977913817332592, 0.0013662491119248443, 0.022866647886985447, 0.02882382832467556, 0.030529452524206135, 0.03396720487216953, 0.033643602509982884, 0.05068140584626235, 0.04001089931989554, 0.0032365902052333695, 0.01225324591359822, 0.046768157626502216, 0.029107803711667657, 0.04171581291302573, 0.05491444549988955, 0.02820676407282008, 0.02118219530530041, 0.05800402483146172, 0.024112513456202578, 0.04347795351350214, 0.011323402595735388, 0.025415889904252253, 0.035332708357600495, 0.03201354564225767, 0.06475775793660432, 0.0889909798570443, 0.04426767656696029, 0.037517817472689785, 0.022126251678855624, 0.04545815194433089, 0.027301394002279267, 0.058895236579701304, 0.0070298231730703264, 0.025343011002405547, 0.007958539354149252, 0.03651874198112637, 0.05041095238993876, 0.02948159381048754, 0.025755767564987764, 0.04969759262166917, 0.02382931732427096, 0.06184966710861772, 0.04745973536046222, 0.004648321837521507, 0.014490018711512676, 0.012056505347572966, 0.034845295449486, 0.04230240643664729, 0.11830064773675986, 0.050954167381860316, 0.012346635921858251, 0.026764422327687498, 0.04115899806492962, 0.010187099360337015, 0.04983096769137774, 0.041383553398191, 0.0056598408264108, 0.06449353852076456, 0.022500741251860745, 0.0351855738699669, 0.0922771058685612, 0.01788254736311501, 0.0601199732045643, 0.09699877555249259, 0.06567914169863798, 0.035532568726921454, 0.023066255926096346, 0.027737415039155167, 0.01708744930510875, 0.02505502987332875, 0.056991227029357105, 0.02789156282233307, 0.046359056141227484, 0.0834782030142378, 0.06537529159686528, 0.03552242727892008, 0.02321782103535952, 0.044372950214892626, 0.06522708470583893, 0.030900472556822933, 0.026223120221402496, 0.046822345539112575, 0.07099625872797333, 0.033335455373162404, 0.06716797899571247, 0.0049040269641409395, 0.023565177689306438, 0.012231958335178206, 0.02198566849983763, 0.03464201006863732, 0.15137246256927028, 0.04008302123111207, 0.019586943308240734, 0.02799371945002349, 0.00281438378351595, 0.032313781484845094, 0.08043589477892965, 0.050276786932954565, 0.0012430732385837473, 0.020873858920822386, 0.03077210141782416, 0.043358204275136814, 0.05188228242332116, 0.013363878260861384, 0.04761696676723659, 0.016123217646963894, 0.02350583741645096, 0.037419950458570383, 0.047676702233729884, 0.023473657893191557, 0.05325838006683625, 0.022162483328429516, 0.07174949409090914, 0.04410445973917376, 0.017574118210177403, 0.023611010874446947, 0.0772720375971403, 0.06448395739425905, 0.00902644069356029, 0.05258615383354481, 0.030676919122925028, 0.06307986594038084, 0.08699293277459219, 0.01959806995728286, 0.02053155258181505, 0.0919259586953558, 0.06681669823592529, 0.03668243749416433, 0.059217844464001246, 0.010434658488520654, 0.02090520538331475, 0.03203825544915162, 0.09453548351302743, 0.01602937492862111, 0.05149747143150307, 0.026997903842129745, 0.10602717273286544, 0.05596885552222375, 0.04803165291377809, 0.05507656023837626, 0.03342105097544845, 0.047111348976613954, 0.054857723152963445, 0.05788604561530519, 0.04196853275061585, 0.02868913594284095, 0.0260962593529257, 0.03173990095092449, 0.03327003876620438, 0.04889959091087803, 0.015201088026515208, 0.01202725916300551, 0.030298492456495296, 0.04042232743813656, 0.07000161756877787, 0.029894804938521702, 0.018350590216869023, 0.024049325147643685, 0.013935560182289919, 0.023846765216148924, 0.053968466963851824, 0.032142081909114495, 0.0298586642020382, 0.04171030246652663, 0.05063174874521792, 0.05375550768803805, 0.022932172105356585, 0.012467021551856305, 0.06869794611702673, 0.033263433651882224, 0.011588272318476811, 0.01650984318985138, 0.03561718469427433, 0.015406211150548188, 0.05831996451888699, 0.039802916144253686, 0.012482404417824, 0.025478100433247164, 0.018273397581651807, 0.05303785088472068, 0.0410668455879204, 0.045745355673716404, 0.036261854984331876, 0.03374725456524175, 0.034801267538568936, 0.00957956150159589, 0.030117425121716224, 0.0478850045328727, 0.04241024791554082, 0.00542342550943431, 0.0578144246537704, 0.012360182900010841, 0.05834739429701585, 0.005297328589222161, 0.02274316007969901, 0.027411803312133998, 0.04963269180734642, 0.011343484184180852, 0.0501198857818963, 0.007654453156646923, 0.06501298252260312, 0.0549392888933653, 0.060859712612000294, 0.0715598976239562, 0.050545251433504745, 0.012485174484027084, 0.01255760438652942, 0.025013146769197192, 0.013801405857520876, 0.02055685610685032, 0.02147116534615634, 0.0362957117613405, 0.0320582006679615, 0.057221422684961, 0.034680048847803846, 0.034012984251603484, 0.08779425930697471, 0.0580480712960707, 0.11562363943085074, 0.030271224095486104, 0.07143920956877992, 0.012456565618776949, 0.05782414307759609, 0.08459089760435745, 0.03300381184089929, 0.03917385321983602, 0.03380154266778845, 0.010497911735001253, 0.05761163651186507, 0.04691825699410401, 0.006916890561114997, 0.033366499410476536, 0.014650373632321134, 0.09380310992128216, 0.06760705582564697, 0.01948005177837331, 0.023546642551082186, 0.04232163177221082, 0.08530116261681542, 0.0271188869010075, 0.03279212905908935, 0.03541362842952367, 0.023768544706399553, 0.02670892637979705, 0.035133282144670375, 0.04791843457496725, 0.024674831329321023, 0.05616271562757902, 0.010756745014077751, 0.02749868839600822, 0.021334229822969064, 0.023217273701447994, 0.01816127205529483, 0.1002187242556829, 0.04422250945935957, 0.04202320305921603, 0.03484529173874762, 0.0316634115006309, 0.012311652935750317, 0.013483613583957776, 0.020752298842126038, 0.019222058981540613, 0.06230007653357461, 0.04968889094016049, 0.06336945938528515, 0.03453307021118235, 0.03320134557725396, 0.014312659332063049, 0.02096759773849044, 0.03343577147461474, 0.04802408300747629, 0.019103205886494834, 0.05019818236178253, 0.04052988690091297, 0.008439376833848655, 0.041060852745431475, 0.034579083367134444, 0.03754117286007386, 0.013165753589419182, 0.046836275651003234, 0.036377518699737266, 0.018591929219837766, 0.03982665002695285, 0.09592176342266612, 0.01725060305034276, 0.01255751811186201, 0.040694651106605306, 0.043468005023896694, 0.0068339963763719425, 0.12022160794003867, 0.10521746735321358, 0.0857864975114353, 0.19100305944448337, 0.15857546590268612, 0.08045473048696294, 0.22094013897003606, 0.10650382449966855, 0.1308691783924587, 0.08577457119827159, 0.11752219419577159, 0.08569429308408871, 0.2511400426737964, 0.09945971498382278, 0.14412007672945037, 0.1440058453590609, 0.09851108698057942, 0.12029073899611831, 0.1088856064598076, 0.22264747938606888, 0.19817710417555645, 0.10182718091527931, 0.12168935340014286, 0.20179776067379862, 0.22281318611931056, 0.19183827243978158, 0.13537443039240316, 0.14959368301788345, 0.1398380330647342, 0.06969419773668051, 0.1432824443327263, 0.0808246094675269, 0.14058055181521922, 0.18838580144802108, 0.15327236062148586, 0.132556228491012, 0.11408035818021744, 0.13356433220906183, 0.08638187806354836, 0.10832707353984006, 0.12395415804348886, 0.248678442731034, 0.09445807008887641, 0.12876410619355738, 0.08101877014269121, 0.09692829378764145, 0.12352454359643161, 0.1771334177465178, 0.15843260247493163, 0.12329500474152155, 0.10770320193842053, 0.32757685985416174, 0.09547623732942156, 0.12403582397382706, 0.18654383544344455, 0.19062175881117582, 0.12543812685180455, 0.20966828131349757, 0.10379625455243513, 0.1016021246323362, 0.16240108874626458, 0.12298994493903592, 0.13948984706075862, 0.18242224410641938, 0.15178147499682382, 0.12204093101900071, 0.17593563592527062, 0.10857119559659623, 0.12388962830300443, 0.13544855610234663, 0.18177909892983735, 0.19684263359522447, 0.10570473925326951, 0.09970319137210026, 0.151603315025568, 0.12642056710319594, 0.11998274028883316, 0.22317896102322266, 0.09915043236105703, 0.1857615078915842, 0.16057991771958768, 0.15507589821936563, 0.1925112519529648, 0.07716729087405838, 0.09089820290682837, 0.20242665661498904, 0.11525273628649302, 0.15705853089457378, 0.13114113098708913, 0.1592413950129412, 0.11872482224134728, 0.09760150336660445, 0.11666229736874811, 0.08058318882831372, 0.10797217109939083, 0.15308808535337448, 0.14783742022700608, 0.21408846834674478, 0.10833192718564533, 0.10875471387407742, 0.11816910206107423, 0.18671838857699186, 0.20646713121095672, 0.14694323617732152, 0.15204974653897807, 0.30384368961676955, 0.08115009317407385, 0.08563996787415817, 0.11842974432511255, 0.12381225940771401, 0.20555084600346163, 0.1849753360147588, 0.06754003989044577, 0.1383850711863488, 0.11407822821638547, 0.15312237257603556, 0.10646777096553706, 0.10291922895703465, 0.07330188149353489, 0.09863568615401164, 0.1482505293097347, 0.09261456041713245, 0.07261045218911022, 0.10270497834426351, 0.20282593206502497, 0.24387924087932333, 0.09007999993627891, 0.12534708017483354, 0.1897464698413387, 0.13908896857174113, 0.13336049392819405, 0.0925296067725867, 0.0803424435434863, 0.1403671398293227, 0.08099485814454965, 0.16444374632555991, 0.13068206812022254, 0.1536427962128073, 0.13981922704260796, 0.09645131547586061, 0.19115753006190062, 0.12186014384496957, 0.20726160029880702, 0.10682480336981826, 0.2495685894973576, 0.17646226391661912, 0.1080555068620015, 0.17604013031814247, 0.09647599930758588, 0.196899660222698, 0.06326524700853042, 0.10004201889387332, 0.13942225225036964, 0.16466625704197213, 0.1472189143532887, 0.10765781218651682, 0.11135981549159624, 0.11828174523543566, 0.08015073195565492, 0.1407038522302173, 0.09009792280266993, 0.08502503915224224, 0.12696799007244408, 0.0962024659384042, 0.10142938976059668, 0.10598433596896939, 0.11841818908578716, 0.0883349658397492, 0.0816563714761287, 0.176541302644182, 0.16761231614509597, 0.08808518119622022, 0.06106174747401383, 0.10957824546494521, 0.09075302397832274, 0.1571953235543333], [0.0302450652452535, 0.0521800803107908, 0.042976706972694956, 0.06362340747728013, 0.009626728697185172, 0.03379279274668079, 0.024896464456105605, 0.05355977365979925, 0.024545940686948597, 0.04216408866341226, 0.04115333176741842, 0.018093463877448812, 0.055267466595978476, 0.018608694335853215, 0.04080618477019016, 0.015363565489678876, 0.06946111883735284, 0.08736377654713579, 0.012893687817268074, 0.034865474444814026, 0.02652271225088043, 0.05181390093639493, 0.017375005554640666, 0.0523460690601496, 0.024308260472025722, 0.035405338639975525, 0.025483865065325517, 0.1028712787956465, 0.04159450145380106, 0.0405993741878774, 0.019016912665392738, 0.05770182971900795, 0.028218330444360618, 0.03241299920773599, 0.04647476438549347, 0.03873496192682069, 0.04506827208388131, 0.03165686204738449, 0.05641065232339315, 0.027419280449976213, 0.02018391947785858, 0.0491436907032039, 0.08619525760877877, 0.014363637455971912, 0.021980002202326432, 0.035382996284170076, 0.04065588131197728, 0.01167463140518521, 0.009570716028974857, 0.023334020952461287, 0.0454640817042673, 0.015661317920603324, 0.1046288626093883, 0.017422540113329887, 0.05112790044222493, 0.01222254233653075, 0.03184720808349084, 0.11162246897583827, 0.028761118701368105, 0.04140680859563872, 0.004545051060631522, 0.037474669006769545, 0.03257509910326917, 0.002262383618472086, 0.014405566944333259, 0.022681322479911614, 0.03732137840415817, 0.04613417055225, 0.024245662170869764, 0.038599445761065, 0.04642818348656874, 0.05610020081803668, 0.04668217239668593, 0.07083469317876734, 0.024733648388064466, 0.03567636726074852, 0.059928432310698554, 0.02549791392084444, 0.05536536700674333, 0.024487259070156142, 0.004647839905373985, 0.03346805118781049, 0.030583597763325088, 0.021529822843149304, 0.04863824731728528, 0.027794137386081275, 0.00586601965551381, 0.012583804982568836, 0.03800180536927655, 0.07399110661935993, 0.03489704540697858, 0.056012850036495365, 0.042399635203764774, 0.021777805923193227, 0.005592518755292986, 0.05615332745946944, 0.06481997217633761, 0.04703455153503455, 0.05655387198203243, 0.027068860581493936, 0.03039350591279799, 0.04440007200173568, 0.09456543659325689, 0.00544918035302544, 0.0193098810268566, 0.06744489655829966, 0.04029425130283926, 0.056464420922566205, 0.01959228677151259, 0.05117709741170984, 0.06699449455481954, 0.01225503448949894, 0.022776894402340986, 0.07631483778823167, 0.00964860442763893, 0.03272352121712174, 0.024039419331529643, 0.00958237887971336, 0.028640298914979212, 0.023474014124076348, 0.057128372209263034, 0.08363022454432212, 0.05320696407579817, 0.019865222711814567, 0.006672386298305355, 0.02879244104406098, 0.02533594761189306, 0.04406554522574879, 0.04234796317177825, 0.005597866856987821, 0.06517812522361055, 0.07748600619379431, 0.03696166313602589, 0.020496089055086486, 0.001209537672366423, 0.030682297838211525, 0.015927904787531588, 0.030777858628425747, 0.04669110043323599, 0.018385087096248753, 0.03518774465192109, 0.04883163986960426, 0.008399762846238445, 0.02536222520575393, 0.08079947292571887, 0.08739251992665231, 0.04302305038436316, 0.06824957759818062, 0.042790283187059686, 0.014406243226403603, 0.008254247168224538, 0.05120748835906852, 0.03271335379395168, 0.02844898252078565, 0.07310373548534699, 0.022979441346251406, 0.007417105052809347, 0.053238642649375834, 0.03900907788192853, 0.017839109459600877, 0.04860414192080498, 0.012661231394304195, 0.04526315264229197, 0.0867003039456904, 0.06350605908664875, 0.029717943725700025, 0.05998825312417466, 0.03867348983476404, 0.03306410391815007, 0.03932396743039135, 0.042806658675544895, 0.032265100307995453, 0.029208398118498735, 0.009669289011071669, 0.03950582700781524, 0.028175577172078192, 0.019551886107365135, 0.04763422541145701, 0.027365033165551722, 0.10063651629025117, 0.035759710444835946, 0.050155223143519834, 0.011001622206094908, 0.02178426817408763, 0.037341160350479186, 0.043022861136705615, 0.007394135582217132, 0.02209783484431682, 0.06600184977287427, 0.034719178584055044, 0.028648482948483434, 0.06459634823841043, 0.022242249360715505, 0.038656624528812245, 0.04273288919648621, 0.016412209952250123, 0.046301977563416585, 0.03494938537187409, 0.03840258366835769, 0.015751127066323534, 0.007423318220389774, 0.025176092713081744, 0.02159566432965221, 0.015772829319757875, 0.08314866718137637, 0.021061134320916608, 0.02891851338063134, 0.018502923448977526, 0.02709088752453681, 0.00788876448496012, 0.020937253175361548, 0.0219647158155567, 0.003450516360317124, 0.06988337117945775, 0.03574549460608978, 0.03071036029723473, 0.06201961150509305, 0.033225632359972224, 0.06386581517290324, 0.013894114017602988, 0.032329607784049585, 0.017677840769465547, 0.03234184579923749, 0.028663732227869332, 0.007257142542584916, 0.026521187137404922, 0.026948447120958008, 0.04571489422232844, 0.0645108379831072, 0.020320615658420138, 0.020238662145857234, 0.10810948326252401, 0.05162025976460427, 0.04532758961431682, 0.04781035931955557, 0.04186339268926531, 0.021252077785902657, 0.013275913352117641, 0.048858475929591805, 0.026684929034672678, 0.04138377233175561, 0.046252583924797364, 0.04268335454980843, 0.07344765414018184, 0.06676799108390696, 0.04045187233714387, 0.030945079342927784, 0.0329215670353733, 0.07509711445891298, 0.02076348857372068, 0.03459416009718552, 0.0633369162096642, 0.07891417291830294, 0.02285755101183895, 0.046712452021893114, 0.03303455901914276, 0.012012303031951888, 0.0076467004964797525, 0.01748848364513833, 0.04534724539553281, 0.012613976068678312, 0.03353865169628989, 0.05079139213194139, 0.027141169884998817, 0.08119052537949756, 0.12415260833222419, 0.04149343949393369, 0.042351599695393816, 0.06616580503759906, 0.0063784452595427865, 0.0386191868892638, 0.030387210645130835, 0.037561403805739246, 0.03479655861156061, 0.04428649743204005, 0.02407137435511686, 0.019357601122464985, 0.029643315210705623, 0.0367090694635408, 0.034821728550014086, 0.05424856091849506, 0.03075044554861961, 0.03951449900341686, 0.041481565131107345, 0.0716516790271271, 0.010099003648065263, 0.07240469916723669, 0.050379244130454026, 0.035213211449445225, 0.017934803836396895, 0.013744312436756445, 0.017284827190451324, 0.012996589375688927, 0.057265532232122496, 0.015081819328770507, 0.023543241659353953, 0.03426997885981109, 0.044752773974323645, 0.04685525236709509, 0.03529305540723726, 0.036189669990562834, 0.059488899059942923, 0.024518856007489376, 0.08719409932382405, 0.05317486989952158, 0.03732188306457829, 0.03632394676969852, 0.03311390202725306, 0.0508121277380269, 0.011829908180516213, 0.03157816099701449, 0.024488936323905364, 0.0190322806884069, 0.03557062977051828, 0.00957338219450321, 0.027825467150250915, 0.018842417048290372, 0.023881408669694792, 0.009188214971800335, 0.025867763215501327, 0.013589856662292732, 0.0549863410560647, 0.06425017345463857, 0.049992807835224085, 0.03923897667846177, 0.008294012368423864, 0.026366254533058964, 0.0465779154910706, 0.027185520630155224, 0.009586334526829887, 0.04004292670288123, 0.14400059095351025, 0.018751875031739473, 0.043641600786941126, 0.02074235035252059, 0.004548730721580796, 0.013883243409509305, 0.025476070659351535, 0.07517499543610029, 0.07477113351342268, 0.0654042798851151, 0.054130448115756735, 0.01834942690038588, 0.03394515937543474, 0.01994449892663397, 0.08489301850204356, 0.004728464973595692, 0.05064229466370307, 0.010452585993334651, 0.08033725593122654, 0.028214862759341486, 0.04485548350203317, 0.10076589489472099, 0.15577074140310287, 0.16518181218998507, 0.24291116860695183, 0.09387344325659797, 0.11184487579157576, 0.09715231848531403, 0.17445387871703133, 0.07266865883138962, 0.1547439504065551, 0.10578524743323214, 0.12710813723970205, 0.15253779769409448, 0.1336396305123344, 0.14789373439271003, 0.13071834429865703, 0.10846940262126736, 0.17545034555951133, 0.10985580127453431, 0.10153509385418147, 0.08246049590525217, 0.12174692921689712, 0.1438862705253996, 0.11121743445983157, 0.1802758639678359, 0.0857182421896141, 0.1344233236159198, 0.1816028091707267, 0.18083569564623758, 0.12984979402972385, 0.12721246836008504, 0.17025569773977622, 0.09999167901696637, 0.11028641762095504, 0.13445112446788698, 0.12172768532764167, 0.08591570542193949, 0.19620092818513513, 0.19521943788276985, 0.12073187899659388, 0.1154441807011608, 0.10851050275960006, 0.16695817233994603, 0.15655821945983917, 0.1724465176812373, 0.1937354393885471, 0.14067991054616868, 0.107059945439687, 0.11566148896235973, 0.09847259920206852, 0.10511914762901142, 0.10305607356713153, 0.1338333755847998, 0.14307131816167384, 0.10166552630835213, 0.22750161500880495, 0.13957546121673658, 0.21449485357152298, 0.11302873492240906, 0.11429217454860918, 0.06003493421303574, 0.08779944691923447, 0.09290323359891772, 0.15398632152937353, 0.1327098679030314, 0.13373993919230998, 0.19640684447949752, 0.14616375847253948, 0.15982359502231702, 0.19082062470261008, 0.12821778160287067, 0.23389747337205335, 0.20288325555156916, 0.1711031116428785, 0.1625576670630835, 0.20119032764341682, 0.13126351113896817, 0.12043162831105292, 0.13244322908576578, 0.11923655532882549, 0.04644931985239964, 0.12314172898186371, 0.09087020909646526, 0.16070381185272709, 0.26892593828961253, 0.13866279768990353, 0.09522372158244252, 0.12568362930323929, 0.14255555521231145, 0.22234726580791175, 0.15484077099245042, 0.13260198931675404, 0.11964346747845411, 0.17667316744336858, 0.07016589195700362, 0.13489647244568914, 0.10587339973426424, 0.12288882731809281, 0.1818873782758601, 0.09123641444602981, 0.10094090815982781, 0.0935533846495673, 0.16013243235647678, 0.14418455451959744, 0.16266383870970458, 0.16709882416762412, 0.14892508217599243, 0.2446614348446019, 0.1866586456890218, 0.09883751321467571, 0.1456575543852523, 0.18429825984640047, 0.12338820364675485, 0.1353433047188446, 0.1544844955787994, 0.12627436401089653, 0.0950758857652545, 0.13062245881883428, 0.08168436528649181, 0.07985318268765695, 0.1239452077425085, 0.12968159368028864, 0.15404713310999796, 0.08649229479487985, 0.08989655587356538, 0.1636563870124519, 0.17414511559763923, 0.19521915586665273, 0.2348705180338584, 0.15032729599624872, 0.1952751583303325, 0.19253768725320697, 0.13332957605598494, 0.07691959908697754, 0.11319876095512882, 0.0893861883378122, 0.10222676064586267, 0.19181384093826637, 0.0959037737629842, 0.08145044776028953, 0.13062560552498326, 0.07376095920335501, 0.08148975190124474, 0.16285704943584278, 0.1624000645824708, 0.19108002015855163, 0.15357395459432155, 0.1127780374372378, 0.1310111809289083, 0.09540030077914707, 0.14780672499909997, 0.1519514713436365, 0.08318693231558427, 0.07192316406872123, 0.24951126601081342, 0.21672702598152682, 0.14530878950608894, 0.17298901278991252, 0.11206172392121516, 0.11942430384806357, 0.13809463911456987, 0.12572327483212575, 0.19693750975420699, 0.1297933017485775, 0.2095503095188178, 0.13891297567170113, 0.1401614461792633, 0.18023745040409267, 0.11127354082418606, 0.18632269027875736, 0.08909692885936238, 0.20577249582856894, 0.1695734413806349, 0.2520416333572939, 0.1310729721444659, 0.13959420786704868], [0.051735515298787504, 0.02245775791379856, 0.014807079969614279, 0.014283250802691327, 0.04704082268290222, 0.035236047333455645, 0.04473566004890017, 0.02274341240990907, 0.058815103184315376, 0.075882440287387, 0.03495593111438211, 0.03469986419077031, 0.01649710608035093, 0.03883321114699356, 0.03540219935530331, 0.034104643200407736, 0.04774925087986048, 0.028766271061613224, 0.024784492925391532, 0.024385440119658597, 0.010086694201163482, 0.08719655583263375, 0.028338593619992025, 0.03354871521878522, 0.02674314866453642, 0.032579021353740245, 0.021525496122194454, 0.010867414075619308, 0.03648857367807068, 0.04659133352106437, 0.01973627269762801, 0.03485239780275151, 0.009912283003359335, 0.028274596370465588, 0.02433158802887192, 0.03224558553483803, 0.020894113986287266, 0.0423683796543628, 0.025602341520425398, 0.06947895264602266, 0.07703003808273934, 0.011386812620912679, 0.05877956544281915, 0.038012492295820266, 0.05125374642375391, 0.05529231370019261, 0.05263146937068086, 0.026070742460433394, 0.01361388369332417, 0.03713705860718619, 0.010349184412916657, 0.023792477113602217, 0.04132498310355004, 0.037947699092910625, 0.03346214369230438, 0.053597433943650685, 0.08571021957322955, 0.030207488453015685, 0.02483168980688788, 0.019380793237360194, 0.04606353664712515, 0.009368633855046937, 0.05763612367445603, 0.024764330628386233, 0.053371360918390565, 0.05709196244424675, 0.04534451800282113, 0.05041190976044163, 0.05223041647695936, 0.06589227166841738, 0.07114942316547967, 0.04805784330528695, 0.01929119560372783, 0.03970466321334243, 0.03144494548905641, 0.016792401074781083, 0.05050149811722804, 0.03954536121455021, 0.09215332305757329, 0.024593081907369196, 0.01806788019166561, 0.014127254144113977, 0.012391372583806515, 0.038896353071322665, 0.028920634067617357, 0.004466529517230811, 0.015700495896453504, 0.027676911449816544, 0.0672090271837078, 0.0408801620505983, 0.03784524931688793, 0.009807813657971565, 0.01797584831365384, 0.01844717702624621, 0.05827428904012777, 0.02493855165084824, 0.007249025302371592, 0.010531127481954172, 0.03870499771437608, 0.018850074156944174, 0.0633555960666854, 0.042622242399374954, 0.03574583228328265, 0.023678681754972786, 0.03612760418036487, 0.04697717980889138, 0.1273133559152484, 0.039723536028759554, 0.09256871795514598, 0.06255482614506036, 0.02207460747740697, 0.024034771631704643, 0.024500118634023238, 0.018629788028192706, 0.0329470189899439, 0.039470897827413864, 0.02582330856967019, 0.06706059764837846, 0.026527640111453366, 0.07037273593596183, 0.08560734306229278, 0.03369777186890133, 0.01644841377128614, 0.023953294949023984, 0.045477295643649995, 0.026146977725147735, 0.034518743050284684, 0.02747783775703283, 0.04875442311458755, 0.054971724457573146, 0.02700224726140732, 0.02456081518175779, 0.050141753163188696, 0.044748517757398076, 0.14249863248551264, 0.0870708805450704, 0.07319375799852423, 0.06226884695934132, 0.06629749172134325, 0.04712541638582479, 0.016705130074115004, 0.04654104188375641, 0.061948992442921735, 0.012242981083545601, 0.0641004451608751, 0.07657650421606377, 0.03386299991689157, 0.03373632272996474, 0.05806079912872519, 0.05070825674920343, 0.052085642018937506, 0.029216968068794813, 0.03968416138377506, 0.025812285821302794, 0.04586466704495251, 0.02206444005423691, 0.02206535846198676, 0.04512020015681628, 0.018595213223306928, 0.007180356233220664, 0.010762273086584173, 0.037816472540725954, 0.016444758693978656, 0.004561928890325362, 0.007924376441224013, 0.06631433847360313, 0.07464775146218017, 0.029083585577609483, 0.03233267656469252, 0.045243764034239575, 0.03704660935909487, 0.0362882754416205, 0.013948743508080952, 0.07573277878691442, 0.09632384419091977, 0.06826945973443799, 0.036877655729767866, 0.07125969888875261, 0.043936537695117295, 0.03858240605040919, 0.034273622804903425, 0.04176605631073471, 0.012664706500800094, 0.02701956342207268, 0.03864508784317877, 0.04584761991281994, 0.05393256928073242, 0.10347110481234267, 0.026326518091082107, 0.03673033570521511, 0.013788242013106355, 0.03397130152734462, 0.06458323448896408, 0.05796077617560513, 0.03583277117286343, 0.03384587856999133, 0.00622636714069813, 0.026380347917438485, 0.04054801756865345, 0.04342654865467921, 0.02635245615238091, 0.022650096616416704, 0.027855785738211125, 0.01965540272067301, 0.00992218789178878, 0.05840845078637358, 0.01701027522358345, 0.03696223458973691, 0.0235495610468206, 0.012324071849434404, 0.027530528386705555, 0.024419395231234375, 0.020267795152904, 0.03183052460371982, 0.07222413463750854, 0.044685331304208376, 0.07518764905398712, 0.043655794361256994, 0.044968126676394604, 0.03653070540167391, 0.046765125953243114, 0.010741574587882496, 0.027170755602128338, 0.03970893798395991, 0.03268751592258923, 0.05457783328893129, 0.0327407279110048, 0.027230871419305913, 0.06598645020858385, 0.04020771317300387, 0.025620661435823422, 0.07731792458798736, 0.024201057240134105, 0.041363422642461956, 0.06823356947279535, 0.04438828298589215, 0.004712738864327548, 0.05848334461916238, 0.04463182245672215, 0.06558292225236073, 0.06447643943829462, 0.03720355874975212, 0.04521660514001269, 0.030688928927702364, 0.01867631326604169, 0.05482317246787716, 0.04973270733898971, 0.04010420212580357, 0.060331451895763166, 0.01981253950361861, 0.024965248558146413, 0.014119982024567435, 0.04579523912980221, 0.06306503040832467, 0.07097980531398207, 0.024838808858476114, 0.031125400819291826, 0.021887270850129426, 0.0057114831724902615, 0.007129071509552887, 0.027330582670401782, 0.03065440421778476, 0.042298740227124654, 0.013184752569941338, 0.014232000867195893, 0.01028882554237498, 0.03920346491213422, 0.028240077226655558, 0.07666148012503982, 0.014162138795654755, 0.02990953656990314, 0.0350834357959684, 0.019427502156759147, 0.023391320319205988, 0.055501009337604046, 0.02276950817758916, 0.016536491857550573, 0.05629229832265992, 0.044367450900608674, 0.050371392208035104, 0.08474331989418715, 0.009987133234972134, 0.14427073270780966, 0.09718996763695031, 0.07485562702640891, 0.04146772778767627, 0.055417339608538896, 0.0295986583296326, 0.011264233016845537, 0.015606718116032425, 0.03208926696970593, 0.015305181659641676, 0.026367761092842557, 0.08022114692721516, 0.014791738849453395, 0.05621639887976926, 0.03826674095762428, 0.07719050525338389, 0.029662102679139934, 0.05544308842218015, 0.028975501045351848, 0.03602511358621996, 0.024715994550206233, 0.0475161088979803, 0.07428428463754244, 0.03474805555015337, 0.02022726090217475, 0.007527132156610605, 0.03533371025696397, 0.09037748983246274, 0.047350160966743715, 0.04063827385834884, 0.03778036705625709, 0.10095311648910865, 0.01694165068329312, 0.03826087428024039, 0.05014392394514289, 0.05689924153557513, 0.04200285336992238, 0.06592078498215415, 0.04343417051131837, 0.01111464944187901, 0.014454510655923514, 0.042261721901013516, 0.021868895273655653, 0.03983344809967093, 0.0764860883646179, 0.055107262887759134, 0.0928868395567406, 0.05454600999655668, 0.09396798544912599, 0.02976805353682721, 0.01974819715542253, 0.09547466397634707, 0.015291408326447709, 0.005413233966464759, 0.017492550614406355, 0.005343036073099938, 0.05155455000931397, 0.03705098803038709, 0.05297458279528655, 0.03236150529119186, 0.05149805030669086, 0.0059067287747893715, 0.027433802424638998, 0.030535979713022243, 0.040076794612105004, 0.027585566058405675, 0.007359493056355859, 0.06926864283741452, 0.07381088347756304, 0.03301007927802857, 0.20200376602588221, 0.19096666452242061, 0.0857020188414026, 0.2602543879766017, 0.26485742535442114, 0.0994252496457193, 0.12393809054628946, 0.0673742218350526, 0.17324448970612139, 0.15453585219802335, 0.24017515213927254, 0.16438928752904758, 0.17385094310157, 0.17354973504552618, 0.12827240367187187, 0.17539725231472403, 0.18420271575450897, 0.09087584199733101, 0.08847887569572777, 0.12877347209723666, 0.07493444310966879, 0.27866386575624347, 0.11619897457421757, 0.10292772654793225, 0.10932089091511443, 0.14646754920249805, 0.06268669836572371, 0.17211747908731923, 0.166612034663558, 0.0879977413569577, 0.11757811502320692, 0.1850566011853516, 0.14073019847273827, 0.16102305409731343, 0.09116283050389029, 0.08838496432872489, 0.18672825914109126, 0.09668140352005139, 0.18965815426781774, 0.1703671831637621, 0.29452783637680113, 0.09569016139721498, 0.1467346481513232, 0.16216189455008134, 0.2008554557687603, 0.11270091345068067, 0.09569107423885725, 0.16392780526075512, 0.0828586210263893, 0.13925807434134185, 0.07720972687820904, 0.07477793158614077, 0.1274864247534424, 0.09284512343583629, 0.1749695822945796, 0.18784853105898947, 0.1692752167582512, 0.10354003548854962, 0.1737692771712318, 0.1693974039517343, 0.10377792350482196, 0.20755305653437972, 0.18089548306306824, 0.1552502138656564, 0.15437130321515724, 0.11042318801628426, 0.15073424525326118, 0.15391188411740586, 0.12909670709632337, 0.15817739273188636, 0.2465891485917382, 0.17993183399084955, 0.11336457158904523, 0.1498744820128195, 0.09035531445988454, 0.08849373349221423, 0.13941073411842808, 0.16529009153600782, 0.1789581956109032, 0.07676530658500269, 0.07982000868651085, 0.1350943438592367, 0.06854810650111176, 0.09101777031901293, 0.07096277302480303, 0.098134009167552, 0.14290056482423097, 0.059808260048157535, 0.11989006830845028, 0.078152202477213, 0.1573517534416169, 0.1773977855918929, 0.18994438578374684, 0.09596512711141258, 0.24348247388843447, 0.12842859607189894, 0.1527563453419134, 0.08602743575465865, 0.11541316634975374, 0.16313131753122434, 0.07484217931050807, 0.1120674904086627, 0.10933480618405156, 0.1624484229250811, 0.18510118941776454, 0.06874934726511128, 0.23136912466725335, 0.16480689402669668, 0.1510931775555946, 0.14015252556419, 0.1395860145566985, 0.0973555630480405, 0.12420774990459904, 0.09272890310967341, 0.15954287024214864, 0.1200825443083886, 0.17159843584522605, 0.21096462034620345, 0.12880063470220193, 0.09542858402710408, 0.13025616441154853, 0.1598962809657678, 0.03937916837458033, 0.17592520132893696, 0.08409964037127793, 0.10637120270985179, 0.12494160037022084, 0.14327447366667911, 0.15190661593805999, 0.14673249592306092, 0.15921399492071941, 0.07647709353477694, 0.18978497246280313, 0.18537475989433005, 0.2772774448385462, 0.1433429738972336, 0.18568662519101053, 0.22330082167172804, 0.21698912285501137, 0.08596047176979482, 0.18986089417012408, 0.15791234211064875, 0.2010149136185646, 0.09988389690988697, 0.207505633297842, 0.1592954678926617, 0.1189128082478419, 0.0875492169870995, 0.12491927656810731, 0.1842312587541528, 0.18499285069992766, 0.1505215308861807, 0.18505397398257628, 0.14047053584363312, 0.2391812382848002, 0.11295277610770427, 0.04118983801163267, 0.19588900351664051, 0.15963955724146217, 0.10138957353774458, 0.09277689779992215, 0.07541614890214987, 0.14304599608294666, 0.09855487369350158, 0.18339515518164262, 0.18182745727244765, 0.2025830716593191, 0.23611771204741672, 0.14487772044958547, 0.13646985520608723, 0.17771441547665745, 0.1754606020404026, 0.07190004616859369, 0.2299591331393458, 0.2708066295599565, 0.17825879564043134], [0.10892941543716006, 0.019281714667158667, 0.0352351715991972, 0.024092562671285123, 0.04618404658685904, 0.02614667344460031, 0.04941494196827989, 0.02964807423268212, 0.02266145333123859, 0.013992244494147599, 0.04918466096569318, 0.01890612671559211, 0.09900680452119559, 0.0375310054369038, 0.06675453594652936, 0.035110412864014506, 0.017645718762651086, 0.05112750339321792, 0.02865152946469607, 0.08473500784020871, 0.02165316964237718, 0.06264760944759473, 0.011536294150573667, 0.02615883724502055, 0.0790715379116591, 0.1042731809138786, 0.006278188066062285, 0.03593418194213882, 0.06261465066927485, 0.01969723016372882, 0.04040832311147824, 0.06471217522630468, 0.05504124885192141, 0.026025209845101926, 0.08355310055776499, 0.03889603394782171, 0.03817990596871823, 0.049339369070366956, 0.04080454462382477, 0.09405113567481749, 0.047851641284069046, 0.04641662824724335, 0.06402438986697234, 0.054258505697362125, 0.0174586344655836, 0.01317719843427767, 0.05893897876376286, 0.02547913016314851, 0.02079313180729514, 0.03035733363503823, 0.044328985386528075, 0.008639445004519075, 0.04067324014613405, 0.0174248389157583, 0.036301177678979, 0.024909077255870216, 0.024122541726683266, 0.042772620072355494, 0.04040776278998237, 0.03240482445107773, 0.059581188834272325, 0.038108426015242, 0.04116052317840513, 0.06325330585241318, 0.058725555645651184, 0.024142321817635093, 0.04897984676063061, 0.03733862591616344, 0.027438437136879656, 0.040237558641820215, 0.022908256396476645, 0.06815329135861248, 0.036576944912667386, 0.012313140941841993, 0.000930595786030608, 0.03695552186400164, 0.015217997861327603, 0.08577889049774967, 0.10024702234659344, 0.032714953122194856, 0.020713757257908583, 0.02393000635493081, 0.03759558341698721, 0.029328201162570622, 0.07089658829499967, 0.035830526176141575, 0.025398955949640367, 0.019359864672878757, 0.027259210328338668, 0.06086573514039628, 0.052221800142433494, 0.03976429106842261, 0.04063032545673195, 0.044290976293268614, 0.06182785909913946, 0.05007416577427648, 0.06699600111460313, 0.06313024292467162, 0.04718409800261725, 0.025461676705162972, 0.04150056040089112, 0.05205542918702122, 0.04444350990524981, 0.06549301848281175, 0.005464376754389377, 0.034460436218068935, 0.05696273969078902, 0.06951752206077799, 0.03342121053719893, 0.020544525323202834, 0.05680086243955884, 0.08466617364319973, 0.033888058533193544, 0.03003308745974209, 0.024606887709524017, 0.029356196828302927, 0.05025643724366091, 0.02312835513293976, 0.009746420419105561, 0.02913314434408676, 0.019486738528939895, 0.024037122384470422, 0.021627047899528407, 0.13790916156722233, 0.044416477176127955, 0.12373250821838155, 0.03598088900616858, 0.05098122979688924, 0.05635144378175028, 0.019549899006960914, 0.009296229000028688, 0.02982715446705697, 0.0559186714963289, 0.025065264089789707, 0.04717390831501689, 0.07738199419691227, 0.053539572400040925, 0.026372753891337197, 0.051121057840646245, 0.05811628951050807, 0.03303117482573725, 0.0915552707738243, 0.027095507393823937, 0.031894204585114494, 0.02380057023401605, 0.04860629043832887, 0.022164373949635774, 0.044051121585653163, 0.02139003190677613, 0.14692656754050404, 0.036256919702282175, 0.0724972078751307, 0.04815124259039294, 0.12409865419613197, 0.04269453500455711, 0.01640730806684587, 0.026484499067009892, 0.024268627930723596, 0.012732883897115244, 0.015567801747238263, 0.03626056364737451, 0.01279959462408442, 0.023559049404866528, 0.023486955324187875, 0.061684476168011315, 0.04574199003400281, 0.021075324184494093, 0.09134778112638742, 0.035815653536701575, 0.08356643695151433, 0.0847613689256832, 0.02546051709941821, 0.05550817106268369, 0.009544435652060201, 0.007291080028153374, 0.05151648525497876, 0.02831712699844502, 0.0042500009749346646, 0.0004677619972426328, 0.0204289822067949, 0.09887817548587918, 0.06315800666925497, 0.05310388718498871, 0.010183896065427689, 0.01589137813425623, 0.007009811624811846, 0.036260923588997684, 0.029641823493875563, 0.024107416757033207, 0.03130916957161389, 0.05360945302527398, 0.012222251971252263, 0.02105354029481532, 0.062262026622192934, 0.003283569776613149, 0.14315105450805277, 0.027480494645715225, 0.06680293881800026, 0.04180899697530549, 0.09777429018868133, 0.06378506950568408, 0.04942466410284396, 0.06573959704837762, 0.0454027320665773, 0.05484653898747638, 0.07807131580193527, 0.043740762848756276, 0.06456635062932037, 0.0640558717714157, 0.05299540003761649, 0.06797271940740757, 0.06888373536639847, 0.07827675712178461, 0.07575790790724568, 0.014540472693624906, 0.09539470498566516, 0.02662714170583058, 0.07753684330964461, 0.020550687004288193, 0.02020077550696442, 0.03355358370754402, 0.01863737834355561, 0.05122983071487397, 0.04385467509564478, 0.027975980265182443, 0.04065901317517273, 0.04007603391073644, 0.018570436623122077, 0.026102231786353514, 0.020484108936216217, 0.030970876396168023, 0.03565839615475852, 0.054178164500626735, 0.09021834368468262, 0.03156675418722443, 0.05641785486659501, 0.033966570335906, 0.030052277543290984, 0.03661144364741631, 0.05128706143295858, 0.00908447942492785, 0.044040174907422625, 0.030913163282093592, 0.031049570025061257, 0.04148916472331621, 0.04603659297572449, 0.031395169644383714, 0.04908306094876025, 0.038208909099921584, 0.03864476500893943, 0.04259412984538358, 0.049630565554252826, 0.04824392199225258, 0.009018900473165559, 0.02767170713923406, 0.037576250470010564, 0.014975876820244594, 0.02380868561886018, 0.031031459766381886, 0.04358561687695328, 0.0417503450444201, 0.04817614535568282, 0.0669639625994023, 0.022104599520389456, 0.02225024229119299, 0.05003063881304115, 0.07369536819169298, 0.0613088121463079, 0.02158045030228095, 0.006371063673213939, 0.03731472876097541, 0.03163843080983497, 0.062295890820678324, 0.05830683221574873, 0.042631422766135074, 0.0187065427962807, 0.009323367485194467, 0.03054836986848386, 0.05805178574519232, 0.011151410799357109, 0.019185519340680912, 0.05368931553675793, 0.08728543543838896, 0.06533362000482157, 0.1012027749675326, 0.03677334316307679, 0.03795658631133847, 0.047671859720139764, 0.0588909432553919, 0.02850311662768945, 0.056819019082468, 0.05016827752115205, 0.12998066435102373, 0.05934806540608406, 0.013969586725579575, 0.035768167217611335, 0.0480213815899333, 0.062063702498562634, 0.04606285016052425, 0.028038992313668132, 0.03300187483546324, 0.08059803920332342, 0.05608713530818932, 0.015593519019603264, 0.01451543170333025, 0.061962143299751915, 0.009606224084564019, 0.04504595199250616, 0.07289905115612783, 0.03190562623785809, 0.049458153516752645, 0.04093866555194836, 0.04588486459397245, 0.038629242990282364, 0.04683872844907455, 0.03221923558157869, 0.01029275150358444, 0.07555357238743454, 0.03943515970604494, 0.06548724457388744, 0.019872124685207382, 0.016347118034900632, 0.015160314433160238, 0.01381548532663146, 0.06250799662666395, 0.022911317755642813, 0.01465767822082853, 0.03456727208686061, 0.01917437228257768, 0.065196352370549, 0.03896833768521901, 0.024513365970051382, 0.01910900948132621, 0.05785017019661609, 0.043445696064736694, 0.03445446192927193, 0.05844774379511364, 0.04135242401389405, 0.015918217904982157, 0.02079811161820544, 0.026245935696351808, 0.07860618163249455, 0.03988730946730357, 0.04569902339426335, 0.038600451371166855, 0.04778240261657629, 0.05131108104251325, 0.043176511680940166, 0.05215984936512541, 0.05916825044550933, 0.027557232715480495, 0.034596275218063965, 0.15906691609416157, 0.15776649524923414, 0.1280199844040908, 0.17394141090335324, 0.27903345529921353, 0.16336432221578434, 0.1290377657278441, 0.15172732790233567, 0.13764353207079694, 0.05357351081329398, 0.09382198273669928, 0.09819154787692241, 0.11784853137214668, 0.08590865501901135, 0.1450572905014269, 0.11771970937843435, 0.07440388915711083, 0.1378987418138422, 0.15322468505473807, 0.29898639244493097, 0.12906437914352864, 0.1544742687838152, 0.10250623119645752, 0.2445701655233279, 0.1702920184470713, 0.2171454339986667, 0.163213191262912, 0.09512562450254336, 0.18225456326035783, 0.15699037205195054, 0.16763183462899178, 0.20193134725559503, 0.1440679928055033, 0.23594192694872618, 0.18712536751991138, 0.1249913391075097, 0.19154693494783714, 0.21592513541691005, 0.15641801292076707, 0.2902505127713084, 0.15352605638327077, 0.2618845598772168, 0.1409076459822245, 0.14922755188308656, 0.10271309743984602, 0.12892880360595882, 0.11563264168216847, 0.1548490533605218, 0.10077992890728638, 0.15300676081096753, 0.1253555406583473, 0.08140421196003444, 0.11054033602704294, 0.13363360427320004, 0.16918311623157933, 0.08648634277051315, 0.07525271314079873, 0.26533741678576916, 0.12132134463172406, 0.13206621806602925, 0.18339310685405508, 0.1477223724941723, 0.1613768210518174, 0.17327358189504594, 0.13950526888947934, 0.09439355519134551, 0.09265738233807497, 0.1649372448446229, 0.10705290987971239, 0.22693624690873548, 0.14101032953476533, 0.17260502558201551, 0.1116340835869778, 0.09738967957673594, 0.159004234301392, 0.088736660691211, 0.09754036524100229, 0.26792519667651504, 0.1691048196516931, 0.10927485549473204, 0.08803173914202489, 0.10431483766296878, 0.1507534075062722, 0.1124448205519002, 0.18318432586966082, 0.11556016354006715, 0.13858889462426305, 0.09093887259950861, 0.12343116657575592, 0.17881295731058344, 0.1138801415800117, 0.16166771325515583, 0.07848102584830485, 0.09679285183665343, 0.12873545929323882, 0.14377325627719983, 0.2752372215036303, 0.15033614239655435, 0.1961124493391253, 0.0906009653408546, 0.1566260220715776, 0.22092056111432612, 0.11567053574253805, 0.11683158125379123, 0.15466446639038622, 0.13725149998208508, 0.26790216041263193, 0.2107667044037953, 0.2964081714162603, 0.0741964737244416, 0.14294717169832438, 0.25437470816541463, 0.1520611162413843, 0.15645132050849497, 0.13862595747923478, 0.07108245918061584, 0.1633387923357077, 0.3184037661412731, 0.2023091894807294, 0.13400384690612555, 0.11138650312204845, 0.14506684936350212, 0.07615284921485, 0.16705436952179298, 0.10286155666108243, 0.22944383032154292, 0.20836692536249757, 0.14379425905644894, 0.14817802148172632, 0.12442683932022192, 0.10639148560585454, 0.12490657099988312, 0.13849789247615263, 0.1546983083244413, 0.11452528313384391, 0.15088188811205328, 0.1361179436207749, 0.1262807019520551, 0.16765449981903657, 0.146464150166139, 0.11255405726842582, 0.11618346368777566, 0.10990297218086198, 0.16027577075874433, 0.06949851565877907, 0.12612721096957102, 0.12851756473537534, 0.11423069503507577, 0.1818405042286031, 0.2078451361740008, 0.21596343023702502, 0.09769729236722924, 0.09369719060487114, 0.16540197771973908, 0.1203010548488237, 0.09773189871339127, 0.07428242184687406, 0.17924932530149817, 0.10487625011592172, 0.1050082262372598, 0.11068875814089552, 0.12960519699845463, 0.16672387631842867, 0.15744872245704755, 0.1404187933076173, 0.18196637247456238, 0.08898634885554202, 0.17070247064111754, 0.09657281989348121, 0.16703240195056424, 0.2335114378365688, 0.1292219222523272, 0.2604037377750501, 0.18810504698194563, 0.10880727277253754, 0.07616611139383167], [0.02357394801947521, 0.03990672776126303, 0.051416421483736485, 0.00886742256625439, 0.030538013197656255, 0.03999438282335177, 0.07841490049031563, 0.06354663230013102, 0.038679323115502484, 0.14864165597828105, 0.03565562794392463, 0.048653405683580786, 0.061258828500285745, 0.044474360984168015, 0.01775816341250902, 0.07349780848016962, 0.031545102028758265, 0.09354209658340551, 0.045913763824501075, 0.04657854631659575, 0.025773360175662674, 0.02771535098872846, 0.0695492785598617, 0.03592938024667092, 0.04107338761969004, 0.054014394772821106, 0.012106543726986274, 0.031018299632705748, 0.015791718833497725, 0.003709402517415583, 0.03979509761848021, 0.04833383689401671, 0.057026089416467585, 0.027683269800036214, 0.009333020971098449, 0.036642962659243494, 0.018204737789346837, 0.05621647309453692, 0.04328686532971915, 0.061882180598331615, 0.06105627784563694, 0.01563101603096584, 0.04620405117748305, 0.02303838642546907, 0.07297221949556842, 0.07336782873608172, 0.022857445255795028, 0.06268573357374407, 0.011480355697131017, 0.034510917103034444, 0.008569960500608431, 0.01567611820064485, 0.037647678473149426, 0.06539383044582792, 0.015062150559970178, 0.03864689126203302, 0.05986392483464442, 0.04659358965000138, 0.03530613204929978, 0.10295585394487716, 0.03264307240897324, 0.026565886691969354, 0.07260923506692052, 0.012259379764145706, 0.02117650117725134, 0.03533476039592642, 0.027142785911564715, 0.10040117384050973, 0.073179909522878, 0.03802165781962685, 0.0541676594002638, 0.03609612969739828, 0.07756732331472449, 0.017378022384946235, 0.11610835092142224, 0.028345000209810678, 0.054989981290418655, 0.011357393887010403, 0.04218436042719986, 0.1954284860403277, 0.02069647078315029, 0.03289625979959965, 0.10040567867690697, 0.03924252785509452, 0.1451946620363742, 0.011001638904417632, 0.04005740600405261, 0.05155443497642409, 0.025552947881806176, 0.03449240051850211, 0.03595883237721864, 0.0449428305728361, 0.037218564975773916, 0.054276053779176436, 0.07699146866798401, 0.008937599122873507, 0.01626560424483614, 0.05202707543503493, 0.04152539266215172, 0.05043809273047373, 0.02472984302585246, 0.035094449267489836, 0.018023100856225938, 0.05932021260377951, 0.015782031950948294, 0.028723671784973703, 0.04387810098705813, 0.05570624285610393, 0.0157545428010053, 0.02647304401762085, 0.020610928986570798, 0.032628218323225155, 0.026830519855138846, 0.04122747603105381, 0.009447682787140366, 0.0719159800792113, 0.02334885091840988, 0.025623869369155727, 0.005329755340426345, 0.17674282542429864, 0.0288260325032752, 0.04455988608242478, 0.055925933411344886, 0.027103871398139745, 0.03851030269288458, 0.02306363428942859, 0.0463355263491394, 0.010832906991709024, 0.03022669337951811, 0.0014391471472663397, 0.021551768149947748, 0.053453319997061044, 0.06752951623639092, 0.018566666512924712, 0.02473552416631719, 0.06717426498653367, 0.055882335946080275, 0.013627445514430292, 0.014627617529185954, 0.0438521035539452, 0.025919368454196956, 0.010634719237714307, 0.02833450067555532, 0.027450532288639806, 0.0377997742180014, 0.03900143005012069, 0.03647400902991649, 0.0658841006224975, 0.027063416928285733, 0.004562403400996118, 0.008254005970229628, 0.03049824335903395, 0.035611499843071215, 0.10035096755018458, 0.018097927895723842, 0.03024545487278374, 0.04795002409082372, 0.07360494491877034, 0.04770903760800138, 0.015404327950818697, 0.028308720320637804, 0.00911644001462264, 0.0409509629389504, 0.013840941919625038, 0.04290099677746184, 0.025956650242733303, 0.04332012467784807, 0.04365964239696041, 0.06276348096434958, 0.020056540961377323, 0.053861067062825896, 0.019606257701525465, 0.019966503605246544, 0.026560138758213725, 0.023606763934367336, 0.02867837294616038, 0.035297961003379896, 0.03241878053813707, 0.04750441265059635, 0.030357099858520087, 0.07295998890185729, 0.06262388298637234, 0.015112570217752364, 0.044509672370622866, 0.015955777998897247, 0.09022474099765532, 0.022747180664737243, 0.0871749890211504, 0.0364890783384908, 0.05557213306019548, 0.014036617503734306, 0.008911813201848418, 0.033604094278416596, 0.015310154049075209, 0.02165929978218628, 0.07085875360644422, 0.062394433189183474, 0.03179774394084234, 0.030824766072328202, 0.03370227670529857, 0.011395515230105957, 0.021305770314938854, 0.01941772807185771, 0.05295870083500631, 0.02479426886566216, 0.026108005695277825, 0.04367593995993957, 0.03154182915750425, 0.02778351539745927, 0.026419316236570012, 0.013240180796856293, 0.03217664372641593, 0.06685222484520636, 0.03235453652450815, 0.09167333904770203, 0.048761736979940906, 0.058079174705198966, 0.0414962707873201, 0.04466930833586957, 0.07538366509834304, 0.04654178774217144, 0.06883349939016625, 0.10457504205987789, 0.11005529799149372, 0.02757990161626367, 0.04403168844874017, 0.033510828579892404, 0.07220408922876231, 0.008986372140498133, 0.04712311572802719, 0.007617843939442537, 0.06578909829840995, 0.030673590590595268, 0.08594721701228991, 0.06519717615447007, 0.013259637125884183, 0.042108427587663755, 0.029379088373389095, 0.07112696577678435, 0.016662764573993627, 0.021152791414351668, 0.015251992863341002, 0.051320725251571275, 0.10069870826555416, 0.10495564507436939, 0.049254307814408094, 0.032491507299710065, 0.03828965105640236, 0.016468607609567698, 0.018654160157893784, 0.05294141621561721, 0.0356088466651272, 0.030228363211790565, 0.027143895422341302, 0.013510615699487971, 0.054922998751862906, 0.06561659349245019, 0.04751361899252515, 0.03545661733369343, 0.06354213488521054, 0.08283794479211792, 0.02954054631118197, 0.013343243772396818, 0.028582852974068373, 0.01749327791912947, 0.05303790283505805, 0.06126042782852892, 0.009564161937305471, 0.04388403074699454, 0.057942842176998965, 0.00939852478040848, 0.008522814641764853, 0.04290782453608699, 0.017445672856410965, 0.030020044214325026, 0.08253814681665972, 0.02213534855400212, 0.018362093505857047, 0.023689617300988175, 0.09403404401382431, 0.011384584322513547, 0.0332737086864654, 0.11086527796578594, 0.02719254876865307, 0.022227539993764367, 0.03640377217379864, 0.03287148691015318, 0.035772839037235826, 0.006383246491168393, 0.029280764938448556, 0.0599739482277073, 0.015565959365630988, 0.058746053764480166, 0.0159602809799253, 0.0417864208429819, 0.010945398025796749, 0.05319929026882164, 0.06557230954058468, 0.05381088674766943, 0.010475389408384217, 0.07554835508926772, 0.028003870174870826, 0.047207872703438625, 0.07391407911200076, 0.043534427240956575, 0.06697435266687535, 0.04065527275088243, 0.021836687919858377, 0.030727509474672843, 0.07343952020164579, 0.06340079286019318, 0.03271267472882755, 0.04652044357499108, 0.0684674721560441, 0.04605932866979856, 0.06977451295824721, 0.01985833001526771, 0.05642284952045884, 0.028566802175191697, 0.028768350930477027, 0.05895335416425951, 0.05728598953282926, 0.03942838389775716, 0.03582128643756732, 0.03009114010637859, 0.027573645311349537, 0.029487787032849155, 0.005377225888878456, 0.04597440471115988, 0.05463616609631572, 0.036227129894541577, 0.024181490516639315, 0.007689322501391871, 0.042140696168644354, 0.03797819765168242, 0.02747312140854774, 0.012884130810562056, 0.017899087979458272, 0.04891384385700803, 0.009989885675167898, 0.034867537615355104, 0.05872151465155184, 0.04900765874481294, 0.003135342708446842, 0.055579250256414525, 0.048146177432499826, 0.04068387141160201, 0.03544322898960672, 0.034252115365234204, 0.038057659403420985, 0.030560032719222363, 0.07467498086043634, 0.10121689803781919, 0.15678469324484468, 0.12793379137292504, 0.07761735148960724, 0.1953690845402889, 0.1577714379527606, 0.15760944195790216, 0.14216882205801085, 0.10724639520049095, 0.16985346854198724, 0.12766586121870205, 0.17812482314184308, 0.17097351781558245, 0.1804785296553746, 0.1171770213113632, 0.09806628819205798, 0.11154936742968857, 0.12317396787693724, 0.15005526918685064, 0.13027649925788864, 0.098348200408509, 0.12842933821957558, 0.1619094901252538, 0.10997866382240318, 0.11453907965915278, 0.11383694116375409, 0.12969615461770445, 0.12367568939225748, 0.09548876478220336, 0.06400915357517079, 0.10654759636963718, 0.09617062780307606, 0.16299269918818027, 0.20446305046789348, 0.08676679295604117, 0.17451369581976905, 0.17320940096396953, 0.15115790767595172, 0.2302729428629391, 0.14080229069804773, 0.13323323044460267, 0.09143987423158251, 0.11269191862083972, 0.17588999384315684, 0.10742092606960796, 0.20347716665128246, 0.1395019589108415, 0.2570719103096053, 0.11838034697575495, 0.11740348025341518, 0.1111344326636754, 0.11486002142191865, 0.1851112677832134, 0.12212501635076478, 0.11219850915949792, 0.15393414854770526, 0.12664456211496145, 0.16611850645858794, 0.12544893252197653, 0.17783498478820547, 0.1607674139086157, 0.1316015445627272, 0.14762621984118596, 0.1282714685657993, 0.11783358451793902, 0.18695593520533293, 0.15278994978871197, 0.18800772173563018, 0.2095016691600904, 0.12692586577031761, 0.11790332413511351, 0.20988722972106189, 0.07203120592748746, 0.0857669122342486, 0.17225680989213288, 0.11606066051172093, 0.14531100110616535, 0.11460248875664547, 0.15307922411011532, 0.24791235337033868, 0.14729078393429518, 0.15208801167318597, 0.1990694328560494, 0.1412738364888355, 0.17539202759508044, 0.08995022799354047, 0.20961282803909853, 0.1168339783907868, 0.07610960426973179, 0.1513846783200279, 0.10530311861657538, 0.1777873537503183, 0.18428163573844358, 0.15944376384140924, 0.15870127477683127, 0.06709718552883714, 0.0886686057492625, 0.1787237511598505, 0.1166898755764123, 0.14615860796766356, 0.09589555076672696, 0.14743011473910883, 0.09448902506846935, 0.16239936696365476, 0.12332237514783628, 0.1958230117452331, 0.12733136041788384, 0.09819617887842469, 0.12195635586977005, 0.10795409238198772, 0.1822631128015928, 0.105762085004244, 0.09471332436078228, 0.12732215778669342, 0.1509296675794758, 0.18213190109236166, 0.14117250364506617, 0.13034734467510134, 0.07939037939650007, 0.3078764904057607, 0.17529550386825576, 0.21241191221633926, 0.19849023112328723, 0.1449963601771742, 0.1882628127350472, 0.0963018172478769, 0.14831080654403195, 0.10295987638528459, 0.10135520467883907, 0.1262554689310491, 0.18706555041717365, 0.10409093170892447, 0.1271012649522163, 0.16787396772997454, 0.10517185495700687, 0.20792669820366427, 0.12103841567295603, 0.12647523370105773, 0.09625466118450277, 0.16345735784852877, 0.13305011292686686, 0.13770704506896436, 0.08816076151560992, 0.12464321247534826, 0.15934145136270672, 0.17003821878461167, 0.11986464232904837, 0.10491307548363693, 0.07306074287043884, 0.05761447893746663, 0.08559134235838428, 0.19945462234318256, 0.1116092958545778, 0.20861109194811434, 0.10568567347945645, 0.09750983328558505, 0.13526793220080435, 0.1724046457093209, 0.13214843318564817, 0.11616735908319242, 0.17465764278313145, 0.09671273699495941, 0.1098388951504603, 0.10243295153486542, 0.1374629230122082, 0.12496787239797413, 0.1549843914108351, 0.1066753793566022, 0.15955986542394385, 0.1262914334074594, 0.18547837855294347, 0.0997651087527629, 0.13236117723863572, 0.12190047957119532, 0.1213421173451934, 0.19375938107259572], [0.018071169761242345, 0.022947799880057573, 0.04854239523410797, 0.05685098338290118, 0.04611252952599898, 0.025734364025993273, 0.009494768346485216, 0.030895411109668203, 0.037958909233566374, 0.044923234163434245, 0.06257528715650551, 0.01244585364474915, 0.032200240311794914, 0.031562431177007966, 0.02611934756714618, 0.007454350661646458, 0.03191178977431264, 0.030025938722246792, 0.037851453671464697, 0.05942040996160358, 0.015725821685919072, 0.048786157349240966, 0.032305658678524196, 0.03868461833917536, 0.0635996661731042, 0.019178995862603188, 0.018159524297516327, 0.07212703945697285, 0.032109397725434974, 0.019853678604704328, 0.030031382375454996, 0.030743994429940358, 0.02643653962877579, 0.0268480586601072, 0.022180215091793798, 0.04704563179984689, 0.0850838098267559, 0.017253094811167102, 0.01670101672061719, 0.07496760968933813, 0.04320045707572717, 0.05077878675365355, 0.04648895424907096, 0.030298661295091733, 0.023797661015123595, 0.01104631712223636, 0.045290860725799575, 0.015804810318513773, 0.04858273096033372, 0.036500318165053613, 0.027414532560214866, 0.0057613378703536, 0.022434159473050386, 0.032532084223930724, 0.014599615369661478, 0.06192452383402269, 0.053659277109545656, 0.04722572506580036, 0.026906061211775523, 0.017521679910714738, 0.04955799464369193, 0.012719032638415229, 0.006794191285734996, 0.03562577134289313, 0.022373750507540535, 0.016518476222699974, 0.017137707545771264, 0.049567735331947915, 0.028547994297696277, 0.02815868403558852, 0.033880588816828094, 0.037490591785172, 0.04704444436356425, 0.010011949725594604, 0.06435171409975737, 0.10274002255755477, 0.027803952289104927, 0.04384996245789807, 0.03697300315252505, 0.03661738082882948, 0.06173855275847018, 0.013650556920765666, 0.01986613184271846, 0.015292196858354146, 0.01418118230503751, 0.014876479126542108, 0.05193635530304164, 0.03739741885510739, 0.0365758131374605, 0.02430782074952731, 0.060366945108398795, 0.049163936491822824, 0.006086694020268624, 0.03886293416144326, 0.0322788114863215, 0.015714678338554222, 0.043336860107956454, 0.048077643805299886, 0.09563879735651426, 0.022299585834844038, 0.021930166985839605, 0.06688377354294062, 0.04438519936229568, 0.028808367533201817, 0.04451261869689915, 0.0550284802011447, 0.03558456359314732, 0.025454934293520637, 0.025071160453080665, 0.05138374472153373, 0.016620545648038387, 0.04785733726748731, 0.03342898824485019, 0.08726442523766309, 0.05321726137481164, 0.02676559306564741, 0.028714907020912506, 0.07498661609133705, 0.008614896614744794, 0.017647896966082044, 0.018754927114059683, 0.02444871934130788, 0.04211785286315717, 0.03334640947286971, 0.016793735085229855, 0.039902386197354645, 0.05687076903996058, 0.062339328724192455, 0.03726481561898254, 0.05443563037260901, 0.0474100968131097, 0.02344063232158078, 0.06814915017457679, 0.01370414647681173, 0.023756312257319223, 0.013577924783021444, 0.03161968044878449, 0.07849478526622988, 0.10943134475382976, 0.006434119322875631, 0.02665687399712624, 0.08088769202004187, 0.03536899195751175, 0.0481819489505142, 0.03367397119291127, 0.034200992522528395, 0.052943130576750264, 0.039715802849968895, 0.0433065285324119, 0.04637707919755485, 0.029886119955335744, 0.06074530312616844, 0.1244289247551933, 0.06756041926564649, 0.02246258001832757, 0.03320059600810055, 0.11082283454015851, 0.08241678340709768, 0.028477269479481038, 0.026812838186742738, 0.03411838777537923, 0.049378762269043364, 0.0642946948937606, 0.07921254597022198, 0.1096106921613682, 0.05870738787052687, 0.0755242352897767, 0.038876166654517874, 0.020372586404846516, 0.03492936222755816, 0.03979221437475644, 0.05184121197089553, 0.02318368966371054, 0.03716101884492673, 0.0009256801013179938, 0.0712425701203756, 0.017749617582012434, 0.08575817715609446, 0.06479341071099043, 0.03315254194603767, 0.01898300393804675, 0.028756612009601668, 0.0636514755024109, 0.0413420562108513, 0.016966269577096682, 0.0037312358062990825, 0.03973126549681183, 0.0078261355702125, 0.03912522770406213, 0.059106952758156694, 0.053858413884881884, 0.033290414430666715, 0.06466011356678791, 0.050443161599105224, 0.010634242407832062, 0.04681427468312904, 0.03510198577714618, 0.06974161355174147, 0.027350121563358698, 0.020037139365740586, 0.03762926207855344, 0.0177648742828751, 0.009181422465189826, 0.021633174328599125, 0.08965577348135412, 0.013225049333414063, 0.053925812026136555, 0.02099758235999616, 0.09882462210953236, 0.026510424140724353, 0.062065171950962394, 0.023575651248393115, 0.058324892379459925, 0.03280482720583677, 0.04379226047603879, 0.07254875003127381, 0.00805656871307292, 0.055193092266563326, 0.06505155193735845, 0.04818728870304767, 0.02578802315838402, 0.03188839356880635, 0.007769414150970988, 0.02545281360653462, 0.031562030417262577, 0.014581849281967152, 0.08448954991763458, 0.035012983717024326, 0.019619124686869327, 0.05438873035018332, 0.028626086786971428, 0.05060887946456205, 0.03359439811902121, 0.025598070460546296, 0.03315210407890845, 0.048249617975670844, 0.0772733437770512, 0.06315488964901306, 0.02390144294622587, 0.07213374847196974, 0.051336584947421215, 0.008242203039117157, 0.015742039468022995, 0.018041020011878572, 0.01917028861498693, 0.03302440272818785, 0.08078203987679444, 0.038156717564561404, 0.047436962559004314, 0.01403184271111968, 0.029111729672877118, 0.024426499439869076, 0.03130967052129563, 0.05449782605865039, 0.009501092372374842, 0.04576152336085215, 0.045837667712476104, 0.07645754536497407, 0.06579605222214013, 0.014375876398844412, 0.018681896071939263, 0.0274495600751834, 0.026694035186665133, 0.07512943499023095, 0.05745454240241088, 0.019518402259564027, 0.05531030707061291, 0.07747431736788712, 0.008531041348760482, 0.026448213611729443, 0.04824598516279366, 0.050815010981750675, 0.025555242973496206, 0.029213296293164603, 0.07374941138550639, 0.05256839795038104, 0.011692776915879222, 0.01215581676660804, 0.053366677966550924, 0.03697150772495661, 0.04463148106879089, 0.04613585893821437, 0.020425317852641456, 0.03680043155327439, 0.01473318339776597, 0.016646331569063477, 0.010304997867933707, 0.05127176205860451, 0.018043103591480758, 0.0022213298643691815, 0.021985354942444246, 0.029799557705700863, 0.023794445660314523, 0.029679934632440563, 0.02501574985217303, 0.07528078858740628, 0.05427647309261374, 0.012567865505843656, 0.01845203438278986, 0.010815240166266449, 0.011124706470582169, 0.06768468447262421, 0.010302847495040623, 0.010443336977914441, 0.0637918378924951, 0.034024576598312706, 0.017483832234574948, 0.026089921411767136, 0.02641448114445666, 0.05209885224758182, 0.011095867539552273, 0.06276643471210264, 0.07334047317272052, 0.04720505625300575, 0.01265005836103228, 0.013550534895330202, 0.02741205749771325, 0.03260407997004222, 0.030251672214944847, 0.04725570783193689, 0.03475600766250864, 0.03544945931935217, 0.06761091499356553, 0.04044333392812405, 0.017269826530537102, 0.04103657709492836, 0.035166411616955884, 0.05559399302001111, 0.05351054700440727, 0.05011449036828708, 0.033521411605761386, 0.04377628574729897, 0.010910004075412871, 0.02846591276465915, 0.015406854963657679, 0.06650199793512002, 0.025145330691884737, 0.020558353389787953, 0.019268174182798248, 0.08261889248387888, 0.06296628765994683, 0.02455569807352731, 0.009746399082359858, 0.03485041997919325, 0.048872086917981505, 0.027822164593089838, 0.05617044880636968, 0.12286438097362407, 0.032501021632924676, 0.03117166445008479, 0.06967056033317931, 0.032620874771964736, 0.06145043247670401, 0.11338803087710403, 0.12707879272056744, 0.1449707115534693, 0.17810597259085625, 0.10351825345424004, 0.1506840463844128, 0.09048631094628945, 0.15280516381608322, 0.10157096927287057, 0.19683889317093417, 0.13536594022298232, 0.20993684971472248, 0.16686755610862747, 0.12272082734853029, 0.09081563897780143, 0.12236991766258143, 0.18482714396668598, 0.09868577370070852, 0.16778044227976352, 0.12305359152378514, 0.2103142169653438, 0.1733006109134294, 0.1664811494993046, 0.13386484264628962, 0.15665863204048946, 0.06857627842691727, 0.09941132695530541, 0.1847244455711916, 0.14849264756776392, 0.149682488408871, 0.17594195902347565, 0.2098726836265996, 0.13852318486897275, 0.12872385210357606, 0.127707525389269, 0.2307468486833386, 0.08664183755172417, 0.07199887055321597, 0.1550582202617079, 0.19279638509033248, 0.11241408079513349, 0.2528851287206635, 0.15039575169794261, 0.10972455245791934, 0.08045844122534618, 0.20888163446215913, 0.1399943738942966, 0.10129165457328781, 0.083832979289582, 0.2516125829424709, 0.09793492063181475, 0.10553889151196927, 0.14888347737723961, 0.14635713247116655, 0.13641302153700963, 0.10433621893753298, 0.14484034589258954, 0.11550102921319194, 0.1311174564762041, 0.13310814887518063, 0.14162638632114977, 0.08791833897703327, 0.17278242856264114, 0.18116298277163878, 0.08709749396075495, 0.1530678989365697, 0.15899759950116277, 0.16759851219831035, 0.1785433795885183, 0.17923768842592835, 0.10965639361529611, 0.13859394122846425, 0.06741560398950242, 0.13037312688538805, 0.3152895363746211, 0.1503537461394444, 0.13941463781520724, 0.10854733554879203, 0.13639564043842256, 0.0890984279976692, 0.16803257953142747, 0.10773055750178173, 0.10882045331527479, 0.13400003226706758, 0.09811550000449643, 0.06858141408883967, 0.13059192686341703, 0.14773907081689686, 0.1651251269504428, 0.118240771262208, 0.14105436857789755, 0.14113293233094737, 0.1206542355066631, 0.09514230056083761, 0.1933916172129102, 0.1275247344165109, 0.1279911000165157, 0.23187993007013574, 0.2083659011987038, 0.0982987585302908, 0.16910456732148305, 0.15980728261638433, 0.12452169321477413, 0.13443631120026112, 0.13245844311313704, 0.09260840801289305, 0.12540248892037198, 0.1039832980313804, 0.09137233137153089, 0.09503277440671809, 0.1487806305522099, 0.12072045734385028, 0.12163033039541915, 0.11349656997481361, 0.10090337033034302, 0.06807754776673391, 0.11546496083610691, 0.10463745667948388, 0.11398437622119673, 0.11702810195856728, 0.10649748655850999, 0.13925572915468365, 0.1339093566639349, 0.10306280484655872, 0.13027329317992553, 0.11034042370738462, 0.08799829796771519, 0.13639936601975933, 0.1301775116007775, 0.17581004969542846, 0.10183696984313428, 0.13793810532661155, 0.2199693801230751, 0.136031913862098, 0.19573960918933153, 0.1289521367289126, 0.19172617845470086, 0.23707269283477217, 0.07624941747053526, 0.17392266425304115, 0.15738437825348228, 0.08380625455174595, 0.19660156918689609, 0.11786065064370632, 0.054764954693382606, 0.32069385575596243, 0.13135147048160434, 0.1158036250853911, 0.12934538593981415, 0.17302972701145336, 0.19093194685410708, 0.21688915556296706, 0.18845937796868384, 0.10092176074977033, 0.15344897692557424, 0.15518263389822096, 0.10987564630340785, 0.12176931239082478, 0.15552461554761976, 0.2088909558369778, 0.183098548441194, 0.12116824698750861, 0.18952476064441726, 0.16968096373602748, 0.22037157963495702, 0.14561464340658858, 0.11211570774321444, 0.16211114649195224, 0.11207312330952846, 0.11655447815428488, 0.2113951847422868, 0.16191811388125643, 0.12406582158291712, 0.16191159782465547, 0.08932902812375687], [0.040764962177490816, 0.02441992957756156, 0.04758256451168563, 0.03985371615272015, 0.05828237844980322, 0.019424266392888967, 0.01839989850850543, 0.04369218186184298, 0.04853918173466809, 0.04978323275281582, 0.03143686721159611, 0.07163468384533189, 0.07674782900721766, 0.039661373739363626, 0.034603551976033486, 0.046087634182185866, 0.0487315723876236, 0.07904994141426869, 0.07184877118561417, 0.006972227874939563, 0.06392946175765246, 0.06604521346162073, 0.020122657042520586, 0.052963869893574156, 0.04327479429775849, 0.017296829573751893, 0.030993552718427964, 0.006333899700621259, 0.04213191285089124, 0.020467705617193133, 0.044050101132597774, 0.04092385228432249, 0.022464407556981314, 0.04494956927374005, 0.051640071396832354, 0.054260836041066796, 0.05352232859877404, 0.04600007559929509, 0.062377415742957965, 0.010633338843035745, 0.012719065107376082, 0.011872515806317097, 0.060903551275259815, 0.07674979569856077, 0.09145816817181185, 0.005153161764610559, 0.04905114859866444, 0.01619782946363557, 0.02760037561529316, 0.0076220236223889515, 0.044566750948433764, 0.04527966542809736, 0.024642445860081352, 0.023431368463207036, 0.02401789890427608, 0.023828499106457457, 0.031601713053532876, 0.0841589157062117, 0.0819973809120711, 0.06753790250513703, 0.02486872112058336, 0.009240467734343838, 0.013893974864913616, 0.0671151009737514, 0.032331466863979585, 0.047873742441879585, 0.03620723662606906, 0.03777419980906416, 0.04745529731735587, 0.022183792243595235, 0.03900189389241859, 0.06451148365158588, 0.051891162220272236, 0.09657048954977654, 0.019160306728736032, 0.0777058897074312, 0.04189901577774435, 0.08628721712739207, 0.03236563163227402, 0.11832461168523878, 0.020748738388647325, 0.07927286031190306, 0.01903521773783723, 0.038594725701841526, 0.004025625148642575, 0.04328983763116412, 0.04000935565272812, 0.03519659105222672, 0.06170773507619742, 0.12033008766593412, 0.05323443467204925, 0.06035949023498688, 0.03000796390551841, 0.05657599169353489, 0.02878039227653062, 0.028183006070321426, 0.03806612359767314, 0.0594233488664031, 0.005417085249064257, 0.06371316281729378, 0.06715781157254241, 0.031992784061003476, 0.06045572823495604, 0.053574802150251344, 0.043782579159596935, 0.08719899007701315, 0.06725466926582158, 0.028969734557904303, 0.10731931863119826, 0.022157945095386822, 0.022499112237710506, 0.009637034345360007, 0.03986980962508824, 0.02326606434507994, 0.021672706679964904, 0.04098168785276357, 0.05794574768515304, 0.06937316691619344, 0.045722864888375625, 0.05269808454613667, 0.0541441110544838, 0.06544803691213019, 0.034860906525864266, 0.0692236315808259, 0.09152228230959736, 0.04421873563842382, 0.05491327290656045, 0.1596050919033587, 0.07992444370756857, 0.03577709154342301, 0.045648041559616104, 0.03258470991568174, 0.03582648889278062, 0.009562157210893929, 0.003294582552371139, 0.027745977567974478, 0.03109750719886506, 0.014545642679877346, 0.03448962859692983, 0.050541934033390135, 0.02287311013787985, 0.044428904438973404, 0.01345763655990595, 0.06405015723430552, 0.03644654956588056, 0.031554189627058804, 0.0727116217603907, 0.0676704352372326, 0.023419937533617485, 0.04035933023260441, 0.03873556306643877, 0.0541973601502832, 0.09865174622973427, 0.006056353167878115, 0.059123064784216695, 0.045452118283719756, 0.02258103235362796, 0.01989173408219358, 0.060945426957914606, 0.07422417809721082, 0.048743880906840786, 0.032215732644544914, 0.056484733504476026, 0.05480408814037219, 0.06412860224372707, 0.008652546694065677, 0.013567126534326235, 0.03268660308094695, 0.048014824715210125, 0.0489175917027751, 0.007244950447784504, 0.03636793757323176, 0.03713834623340517, 0.040899550658650696, 0.03356253400852438, 0.025097235811699647, 0.03639582748292014, 0.006136042202342651, 0.014575360128219472, 0.049349191394867375, 0.06027862211340107, 0.11247256203205325, 0.009687082001619274, 0.051063738064840436, 0.009819060906011146, 0.064186029630946, 0.020243484250386246, 0.0414064375218004, 0.03500889077258762, 0.075737432052847, 0.006391216229530983, 0.048642214096616954, 0.02339956372452434, 0.0613201002124697, 0.09281685503083281, 0.02132504574547056, 0.038220776041271165, 0.06533648469485343, 0.06438576383516192, 0.016347201526514255, 0.04195412024273537, 0.04010770506283734, 0.05635537345369812, 0.06397764940629713, 0.06900267195305787, 0.01217008548337617, 0.005422586882559699, 0.05731349352572579, 0.018826377381628845, 0.04466776466870215, 0.053302563828765415, 0.04211524050333537, 0.03911003965185955, 0.02598930474050576, 0.019266185227024835, 0.05831360802403651, 0.03795150259975344, 0.021232763392617926, 0.056508775378460996, 0.07312712798011489, 0.022574150789296255, 0.021431312015920412, 0.04429877626535017, 0.038585623260587454, 0.0990136842301581, 0.03871257504215464, 0.0360328727401793, 0.04468936487683095, 0.034227858268423006, 0.03195154291461222, 0.022577008057851344, 0.07729255055892281, 0.10068454066640697, 0.04890686766884755, 0.04697547286923509, 0.028813666467613075, 0.10017026943387464, 0.08354377918294631, 0.012735548207274405, 0.07214109573396854, 0.02521545065974351, 0.06256374676013365, 0.017973096801142674, 0.04335894642281346, 0.04210603787214495, 0.06261373040615581, 0.00380223777028732, 0.028266169283597264, 0.05904804478632286, 0.05676713182765525, 0.011975383968092501, 0.05467501010571141, 0.003834384824585868, 0.023720245735603385, 0.04336963334935717, 0.07931716652819887, 0.01798235323803965, 0.06258478664676659, 0.027097574275103398, 0.0725242962653283, 0.007577226197099662, 0.054734819786972366, 0.036237349268049, 0.022172233293531463, 0.0690885161748156, 0.02548134176322492, 0.02109111152094556, 0.02914155844337074, 0.008654279608890647, 0.0373584857879905, 0.039743377346894704, 0.03277538991824258, 0.020163230256002862, 0.0570789377525216, 0.04632898802810814, 0.09028097352711484, 0.05658763227984309, 0.03075006705330452, 0.028944774276169483, 0.015327040691772709, 0.07979399641044438, 0.018798136807163246, 0.04503050789935514, 0.012927610459882999, 0.055255402985494584, 0.008337778672284912, 0.0388986908365041, 0.019465596597001422, 0.018174005454056896, 0.014405168967641657, 0.024144151211658027, 0.002708269653339812, 0.006618638108193409, 0.030958488096075598, 0.061049546566209756, 0.027746756823034957, 0.035520612727850676, 0.026227372727589682, 0.036530007782857865, 0.036292104923631996, 0.054772814037278295, 0.029431691800709814, 0.04203580472676549, 0.022065165503590833, 0.0516624805459287, 0.09943852666765451, 0.044479971620603465, 0.03441247121372726, 0.014463363550021313, 0.06028770229022484, 0.021680130012100562, 0.02107946351316059, 0.010934906840702752, 0.01624131931748707, 0.049239724612561986, 0.04328791917941999, 0.05014068818127271, 0.04289101489121094, 0.03916864334314596, 0.05517690602573566, 0.030600121681345627, 0.015428124916070374, 0.04658139245293569, 0.05888038249395322, 0.04026953778520692, 0.028029926979797892, 0.007990011054062052, 0.08175584152922966, 0.13139779533958063, 0.022407727883546613, 0.035045515760430135, 0.05976147505862173, 0.022001789802743588, 0.030282768202596344, 0.028915756302012596, 0.01930422029545298, 0.0028858122504971107, 0.027802833501482382, 0.03368523328390438, 0.08471874738461338, 0.06948278954951093, 0.02700265915336786, 0.03193528245901689, 0.05941727438766975, 0.014777617634536, 0.04184780016657896, 0.04988030566892121, 0.03993122234533075, 0.015139858060138067, 0.039548151689814404, 0.03243269951781258, 0.02599153303890489, 0.1310030321474187, 0.1137162976374384, 0.21307513990905136, 0.12093991041183472, 0.1378037320682779, 0.23288942902581766, 0.1283236563904211, 0.24042383098276332, 0.11982409880147316, 0.137863949930761, 0.15324122010497376, 0.23058102320646867, 0.19909159338567406, 0.1612082199426368, 0.06867984513519332, 0.18580496805952862, 0.2810643572593108, 0.1398547610733658, 0.15758541121613234, 0.11703251031576656, 0.1530526255373843, 0.11081027740146965, 0.10684381719329394, 0.10465454091900028, 0.1839051442220807, 0.0774924925644882, 0.07878493532189168, 0.2156293747248128, 0.18991324526723474, 0.11215082617127337, 0.16296515066642314, 0.10695417455281131, 0.19194537919247523, 0.08526243735104799, 0.2630533534102142, 0.09364008234115317, 0.21443044999614358, 0.13654822600074112, 0.10755309514934197, 0.14351623569382355, 0.10709110079915263, 0.10976323319482617, 0.14763068757019937, 0.24824669089866802, 0.19053234485909343, 0.19244187598815188, 0.19537433894583955, 0.15607151901349425, 0.11585006126551889, 0.11316160162095912, 0.10500636344659142, 0.12571462139021605, 0.14617529144743457, 0.11965675192186609, 0.07826149856555276, 0.2543723926646635, 0.18622754694661126, 0.14722231338964775, 0.23774734960170463, 0.1469848261331208, 0.1706771188764833, 0.16269523155642673, 0.11364268400939181, 0.18293511267984286, 0.08884377486538142, 0.15178699657553807, 0.11389776758733205, 0.09710900674690492, 0.16289806051645428, 0.11794811274739914, 0.14510973065625876, 0.16041666007367894, 0.11508627256262116, 0.25977095298003405, 0.10816255424288101, 0.15462814568309113, 0.18880529300076887, 0.21113823837367818, 0.09297911819885485, 0.3300464601488784, 0.13849951035808772, 0.11230524483835325, 0.052511861140374094, 0.24791521806037053, 0.13263636559713632, 0.2078235545195639, 0.09819269078434445, 0.1562269395799376, 0.18386828916845843, 0.17465416953200474, 0.12279942820896395, 0.10186081504798494, 0.13336959265870973, 0.17228682234417647, 0.0827074603876099, 0.1512282929616049, 0.11225473426748067, 0.12348130607279018, 0.12788883206667379, 0.2089417929528281, 0.16198386816540733, 0.10775943446788006, 0.14653290272690356, 0.08574362364015542, 0.13693636923562735, 0.17640409438172355, 0.2622958581196144, 0.11828163391328417, 0.20685672905528918, 0.07211851960164495, 0.13936789735453203, 0.16671053250320256, 0.14823090692516416, 0.08252553772763349, 0.12612122925929725, 0.17037073062965646, 0.20025461300974712, 0.12753264571074396, 0.17065497318981215, 0.10059903041110374, 0.19446351594524458, 0.1493478094926104, 0.19986023573437706, 0.16034188127378002, 0.24732807534746826, 0.09645130063290708, 0.16956089908489957, 0.28239152510650456, 0.09874791372567415, 0.15818916319403797, 0.19004052359377965, 0.16395467100664973, 0.18187565234256908, 0.16750581795349717, 0.14640434790635481, 0.09162788250250742, 0.11682718773954548, 0.07805829853168689, 0.14690989890368655, 0.17112504952820018, 0.13835686957463622, 0.1372009894112125, 0.09910421140375547, 0.121206846088171, 0.2089470176724717, 0.08983211519080214, 0.1566475591971539, 0.20702758629340678, 0.08593627775553614, 0.16160746570676565, 0.07583635291666724, 0.1947378137265332, 0.3182179917348549, 0.10331286408472806, 0.12284318523597904, 0.17200418282300234, 0.07869952154578641, 0.058872849695035256, 0.1596736811916344, 0.18085297284414992, 0.17025222448864952, 0.19008398376172408, 0.2229636491392739, 0.2523831994039938, 0.16964790847850963, 0.12467601540265605, 0.1649477833416313, 0.14799741242313758, 0.09531328396406025, 0.11776532919611782, 0.1709102126187645, 0.1195819211716298, 0.14142437372356653, 0.13180959824239835, 0.11242886437685229, 0.09889416876831092], [0.04424284059496131, 0.02954335905087646, 0.041253358431276865, 0.005778401236966602, 0.04004845199233387, 0.10372784337960184, 0.05219414772000164, 0.0433121725654928, 0.0445902250794461, 0.09591303576598875, 0.059563655595411547, 0.0659322363208048, 0.03504655476717744, 0.011133201278425986, 0.05132152306032367, 0.04600570107868407, 0.0201565379393287, 0.05733339050493669, 0.03267046507971827, 0.06143304024590179, 0.04202122894639615, 0.05116300402733032, 0.028992444276809692, 0.04088376517756842, 0.041904147728928365, 0.024387332596234046, 0.03589392043068074, 0.019250971199653577, 0.028339122400211636, 0.017726861478877254, 0.054433522673207335, 0.07943287477246486, 0.03789619033341296, 0.011866425556945615, 0.026333804125897586, 0.04845391638809815, 0.012470768469938776, 0.07009330991422758, 0.044474234819062985, 0.057806153417914174, 0.09089311919524334, 0.05692619633919094, 0.03918944945326075, 0.03146886119793635, 0.0546511537686456, 0.03190399722370785, 0.008374492717848625, 0.05604560843494255, 0.03814927753410302, 0.016543987549084704, 0.013254558052722132, 0.036762964227818884, 0.11107466751127504, 0.06350415176711977, 0.008930691583373118, 0.05076592162367888, 0.01691169945843285, 0.05236801065620966, 0.038144498103065416, 0.00935651829422568, 0.006373118958435953, 0.04657708799641114, 0.010431582286400953, 0.04642737083486281, 0.010256009627482854, 0.015845390953472815, 0.042052851858898066, 0.027654615478240885, 0.03961437352700159, 0.02331920768483542, 0.024204864457715303, 0.04985670908354223, 0.03616098598286044, 0.03553756709152367, 0.09846583823673427, 0.02795137250359403, 0.044902921581524424, 0.05149611330125481, 0.04241947281116154, 0.04671160597354174, 0.026597422402119264, 0.013118808110448299, 0.03541297533956822, 0.03603449804359116, 0.02728495172050316, 0.07302627753233537, 0.028136525361333042, 0.046148924448061734, 0.012163249375589658, 0.05545583109778818, 0.034619638026924804, 0.029578332760138437, 0.09437486049137078, 0.02387592234299518, 0.007695517579122679, 0.04159246054769028, 0.044368404560373165, 0.009681291394372238, 0.028955292364116758, 0.009788329498405801, 0.05774578341515735, 0.049080589596997015, 0.05877431103726849, 0.011876502067025285, 0.03406385476409923, 0.013090043394186068, 0.04118591947189998, 0.01747626232827315, 0.08299755849293433, 0.018203567051386926, 0.015025877164589474, 0.04378551064291969, 0.014834389148745686, 0.03734506404725835, 0.08329970165505074, 0.04892972581728827, 0.03096503012784524, 0.007651936812180793, 0.07831589799025096, 0.05627819009532686, 0.03720833075931296, 0.026231564006593544, 0.08614286940428428, 0.015866503199504223, 0.0249050306956633, 0.08709185363841243, 0.08080997431534342, 0.0175594014217495, 0.04586726827255916, 0.027904852831852622, 0.05700336114387028, 0.02047236259386409, 0.043005201732739806, 0.05059441129560582, 0.0911126984283328, 0.040393535819021054, 0.02612409916764591, 0.0048602652987028705, 0.020496992619882803, 0.032062831669463776, 0.03193549768184312, 0.021381831174949184, 0.051697242743102834, 0.02379951452894602, 0.06721975863911211, 0.03900923373294063, 0.022036481495888438, 0.010214545836788602, 0.02452945387631189, 0.06290456323768012, 0.015884546664892696, 0.047384255231008865, 0.07011928508291021, 0.04399616183945909, 0.05527869529032614, 0.08187272236682475, 0.04320593783631921, 0.04239151981892064, 0.0736327086633537, 0.015483579118154012, 0.01445974558009766, 0.025507149948680308, 0.054277293165796436, 0.018724940637184773, 0.01191293224110268, 0.03302515971881803, 0.05018771807954181, 0.046199761563912034, 0.011810579871962545, 0.028349564418022055, 0.04352743620984256, 0.007597989169880748, 0.039787171481293626, 0.027889859593415167, 0.005820955984745524, 0.03455422141996678, 0.05992927464831155, 0.016841759461385664, 0.07764492227579467, 0.022331038053380325, 0.015366683437605388, 0.057571475190343335, 0.04305667338485364, 0.05891927103220951, 0.04853285863646306, 0.03161054461088497, 0.01992859655729262, 0.029003684103372507, 0.07840947539079934, 0.0594669500424061, 0.02221452828962356, 0.0663154739595484, 0.05661832008627243, 0.0505332657485269, 0.04179871451924555, 0.04651203133107629, 0.10004797091824003, 0.029620844834425952, 0.09747233256348409, 0.06822349110734649, 0.01703270107100252, 0.02096697804518044, 0.007670737732041744, 0.02215541993791703, 0.01628029134735698, 0.033824152196757495, 0.09307713364250958, 0.04013906080217566, 0.0553143146680668, 0.07477198698325083, 0.06832995961303823, 0.05263738057692535, 0.06405380117939785, 0.026816276185854804, 0.006090656161177321, 0.038641584906145, 0.03897573689755518, 0.04548577839159407, 0.03528989014739636, 0.0183880204349407, 0.040576734973001294, 0.055903691245475784, 0.03389438905287534, 0.025913436838891357, 0.04362260922789574, 0.05001403325877618, 0.07370913503109477, 0.046510272441082634, 0.16403186920797452, 0.01790314567188034, 0.035687941053765826, 0.043642621239996515, 0.04490637256822083, 0.06806625970057212, 0.07031017288682051, 0.041787552618188784, 0.027802801960206125, 0.01846892380854115, 0.02144413818314206, 0.05516907636774704, 0.07998519591637887, 0.05147929994564038, 0.04753269960929174, 0.06452913192333654, 0.04361804873042274, 0.04346569323388394, 0.015850439413043205, 0.08185387923731469, 0.05685855328920297, 0.07840292964829132, 0.022041902884666342, 0.06179023963341024, 0.0511730118887499, 0.020331284031271935, 0.017076890399039257, 0.06467212151619606, 0.027305177100060973, 0.014436377205129247, 0.03707980562467128, 0.016739085185690783, 0.038221340073505417, 0.061002965667285025, 0.045528236660175025, 0.0573634215106722, 0.03171841206494719, 0.10869207661016844, 0.030284413915069308, 0.027641523993224837, 0.04847606578550767, 0.027313025311741512, 0.010837537065526703, 0.008933755725593073, 0.040877033898141235, 0.01588241855642991, 0.03745674614037853, 0.04809325488167815, 0.06156090857984964, 0.03743736866454128, 0.10489652559044771, 0.05452169352793135, 0.023372165487671737, 0.0009193167068133334, 0.04591242424794473, 0.003607205767366395, 0.0519383999198908, 0.03938894617022015, 0.04968100562109612, 0.17701243283227086, 0.04249024401360657, 0.03760801067983266, 0.03507382127281744, 0.03758415434276685, 0.009075108882825589, 0.008046982020459836, 0.06371392722940072, 0.011422817915445194, 0.03765566769288853, 0.05640861141728237, 0.08075662131886929, 0.06951528819627129, 0.03888683131663129, 0.03669074583740439, 0.0523479058756493, 0.04242482369591016, 0.08121952851070091, 0.08649366034660488, 0.029955505196994636, 0.06794878514483571, 0.010387076617917046, 0.024267063854495063, 0.045631977773155086, 0.025431352551095188, 0.053780436428496614, 0.018051395236398093, 0.004572142233882914, 0.009780020227481145, 0.05015557195292786, 0.042361733721918426, 0.046775605078437366, 0.04261318448698148, 0.026768648858706, 0.05081773837446235, 0.023315437574638054, 0.018642820141394623, 0.0021920437893641065, 0.02173151446186239, 0.0818953504494857, 0.07907570878160186, 0.05355537272407673, 0.059120059086126275, 0.0408038507157471, 0.048030190882855095, 0.04112439171876758, 0.003933098350898945, 0.029440901853377, 0.06507998361485079, 0.019612836840678938, 0.05360562354326248, 0.02580832089734031, 0.007007361145952018, 0.02126411913195625, 0.0402895497973077, 0.03154128367896192, 0.02794889558572322, 0.0017113933540713333, 0.06890658609336242, 0.0945068069268018, 0.032611980132060125, 0.03331454536237288, 0.0072927619203255745, 0.024231360985140782, 0.02994397778820712, 0.13697205169592053, 0.0723793770885095, 0.1446615922031924, 0.1266893878346309, 0.17794105253415182, 0.10522814685828052, 0.10563750067376532, 0.17814974446082488, 0.1167336548678577, 0.1872660787194036, 0.12833251763368025, 0.10183688820688985, 0.2301954329595901, 0.17277223145356402, 0.21549645607592538, 0.28451397840399295, 0.09379442679346539, 0.2097404032247141, 0.13319892837898806, 0.1318701871787198, 0.1588189200265333, 0.1183782318548765, 0.19705828686710447, 0.17854790668934584, 0.11136042405269109, 0.12425824563251808, 0.13157205161405727, 0.13163838477339596, 0.10250093968352303, 0.102711509243818, 0.23327029921347275, 0.21231544786132872, 0.1455307807191275, 0.18730547191808, 0.0871155652566813, 0.14257485105190426, 0.15094793925527483, 0.19304807705339044, 0.1970319406245835, 0.13253969344077632, 0.2692910749465227, 0.12386387577862479, 0.11159138040966354, 0.1273961499100551, 0.16510988323716447, 0.09053107729414478, 0.09546722023515031, 0.20213261770550162, 0.15761307848151773, 0.1141056431515608, 0.15099347743671387, 0.07929207451525144, 0.19502149225445464, 0.20523010462056845, 0.08536941793863662, 0.10382978478446603, 0.16349424258805811, 0.16116391372634098, 0.155307270179037, 0.16395499755162746, 0.11520036292495206, 0.16950249206274748, 0.10284783435054123, 0.13154454762116075, 0.11494846316054463, 0.14800410659518093, 0.14005764940520748, 0.21391499874880537, 0.13362391182454303, 0.11703621363267303, 0.10077769504277967, 0.1672548384522088, 0.19236717140302062, 0.07430723926518112, 0.24353491404326633, 0.1264207303756848, 0.18010404193773866, 0.07996247877599671, 0.1676147207035683, 0.13248985080281273, 0.0958866449946072, 0.13714887580135837, 0.16573570668697357, 0.1173842660500668, 0.12837397400289774, 0.2646647935034707, 0.11684423487167805, 0.11366801350959577, 0.12126878573326394, 0.20287847612053156, 0.09371411899337545, 0.14193562441505492, 0.17019837425323203, 0.14524214464472607, 0.16084734321339056, 0.10035547238658182, 0.09571192116709426, 0.11643756020930596, 0.2687503461493179, 0.12400619743857533, 0.15563976718112826, 0.16165088134584948, 0.14224101818399504, 0.14599359885323793, 0.07841185026336461, 0.12243444740306586, 0.1121992438856978, 0.12394218720146455, 0.10026228832430206, 0.08685824781423435, 0.1539515148033388, 0.213090754696168, 0.12660096836043522, 0.22753045486751944, 0.16891491890419275, 0.1093271843274124, 0.07233531578094698, 0.045981195362401195, 0.22216653800569475, 0.14438447426073253, 0.1007356820628047, 0.23627209360711277, 0.2521291474113241, 0.15748035279102623, 0.12569992686621845, 0.15786687814397737, 0.11163143411977217, 0.15399172436445951, 0.213175478274934, 0.08215776644647121, 0.10645655711414292, 0.17362504819175228, 0.12093441109755076, 0.1275113460724242, 0.18625687662279233, 0.10955917226965539, 0.1383019209606573, 0.09656481212005019, 0.15257407387252897, 0.10285814278176986, 0.13350890862056985, 0.1268258094205521, 0.08999283469165675, 0.1372236100723967, 0.13745832169661298, 0.11414633510867134, 0.12066606534062885, 0.08174557762686163, 0.1481924785184674, 0.1552256487775594, 0.16591953666647896, 0.19156140682753175, 0.22482750850031152, 0.2187888606567867, 0.15752176463138312, 0.2043326254351996, 0.09259873782866634, 0.1341541763395071, 0.1439517576363869, 0.19335655815666541, 0.10429212052258663, 0.11881914178957231, 0.10145153544726782, 0.0893913239997346, 0.1473120687296614, 0.09951907937647775, 0.20202788582537323, 0.08225779311032966, 0.11408891514292918, 0.12802495679352432, 0.23359767539659515, 0.1151481008855626, 0.12208865111460909, 0.08632749348180369, 0.10424716863781214, 0.08467647465295158], [0.023782131574989762, 0.04321362648624927, 0.054059676913311705, 0.028233392331458163, 0.03647288838692475, 0.033167462825076655, 0.037557065952569246, 0.029236709196993615, 0.017424796242266893, 0.05010932502045762, 0.04109626061108429, 0.15694991016061977, 0.04384869338537101, 0.03578574498533271, 0.07458611609763466, 0.06684003878035583, 0.035336897781235166, 0.04262800146534573, 0.012856289140472654, 0.042714910669019446, 0.04431254681549035, 0.03959441717597656, 0.046445356783806346, 0.012466167154343566, 0.010715170828916598, 0.01903507116367109, 0.009958189475582913, 0.04098418889043387, 0.025619268053560518, 0.05179592983040493, 0.04227463898132555, 0.0351938079984393, 0.10111831114045344, 0.06518352063721977, 0.04741660915897228, 0.007494351029890822, 0.04395102441776544, 0.022684894065605476, 0.014046992728253826, 0.014853473476250656, 0.0031446601406059926, 0.016651641635689884, 0.011255613899265882, 0.03705909228301607, 0.05615425885480363, 0.013870402399334125, 0.018688200616452377, 0.03622335978434421, 0.029383578366832808, 0.03408201882848516, 0.03502120300254319, 0.056881162818172015, 0.049190034114872105, 0.04681148420786485, 0.04285125804017298, 0.015533455152763054, 0.017590139323147014, 0.09152683909633197, 0.01812278056604555, 0.010451845701027196, 0.04887369737843983, 0.012588510198838776, 0.029164067782403436, 0.06326276823529042, 0.047915651521179825, 0.06069530834793113, 0.019182311407348607, 0.028846833047282416, 0.06816428256570362, 0.024283992242999375, 0.01764442742569372, 0.027580424830375705, 0.07960631468449719, 0.04322992033849005, 0.031373884849017486, 0.05916352296480909, 0.030627963351435028, 0.006433960688809748, 0.03748849892872386, 0.018228293556603603, 0.0513397316535702, 0.034701404147199355, 0.04226751436362974, 0.04051703661389183, 0.061547924706246704, 0.04264664792572148, 0.05143111600773409, 0.06035176447767299, 0.04232883431541268, 0.04833978149690665, 0.01326958839854342, 0.05055581590568181, 0.052041562157683074, 0.013508838255802402, 0.0304712087745429, 0.038892200755071826, 0.027845803851960227, 0.04759594543429557, 0.07006840343819931, 0.026579657242109533, 0.01661527083342662, 0.04979833545803558, 0.017256610735785216, 0.03190886571246665, 0.025443744561925996, 0.01570349788380554, 0.027922245062654838, 0.020861672855971847, 0.009548906164127402, 0.057555890089133754, 0.09584774161339737, 0.0036199203805153957, 0.055201363502419554, 0.023540560650872067, 0.058214679738739505, 0.015104343510756735, 0.028672697371803224, 0.03244808052841108, 0.00786552598583512, 0.07181271765148267, 0.033067829499486834, 0.05876602495845873, 0.04432716341398191, 0.05654037231579423, 0.06370778966811486, 0.040785664386930875, 0.018020863280980848, 0.015232845453283517, 0.056649178586667404, 0.05405355419497937, 0.018867555445467588, 0.02847582600224996, 0.05603721474471968, 0.026966434925270732, 0.03006264905707212, 0.02923211159213679, 0.013689058614545502, 0.03772732205106877, 0.049732814950402826, 0.054087218013592064, 0.04291536104574334, 0.02070991107757436, 0.02672610524314223, 0.04993566617486067, 0.04213785745378118, 0.0489393254974857, 0.02177924197894754, 0.008287208729598206, 0.05643158088787459, 0.022069310398364905, 0.052452760210144334, 0.05867835505341645, 0.024020910168474074, 0.032580568731646053, 0.02860595046513481, 0.05496871504874434, 0.034803319576894864, 0.045709012701991014, 0.008464213733532233, 0.05841635094839148, 0.030409428691200446, 0.033611931357881986, 0.08395009019295685, 0.05157535240869038, 0.11341934950905852, 0.017859904437500518, 0.027394732060201932, 0.020372734834381845, 0.08460331373498775, 0.06344473542412743, 0.04740129123092629, 0.01785723270586459, 0.046567332465201616, 0.03076479126320919, 0.051790196739602834, 0.017523956448712852, 0.022689404468110297, 0.007937659956951393, 0.031683601628174074, 0.05532107563340105, 0.01654279083595611, 0.04100591155292932, 0.0412694407714298, 0.08620118736871518, 0.0318554941623006, 0.06818674737587571, 0.030345206942001823, 0.060574438466574065, 0.02778473251964897, 0.06262879600399174, 0.12121077947085723, 0.04871884826570749, 0.03865173006488476, 0.05592063447693363, 0.06685096319415607, 0.01777477824361995, 0.012510358337749494, 0.02057512778264936, 0.013851944258931326, 0.0178456329376786, 0.019355465592525434, 0.015933246395434253, 0.04323016153648496, 0.09760332162841223, 0.01603383894689614, 0.04157238916377537, 0.08262986142653972, 0.08436305826762691, 0.06926545160240494, 0.004672661498261732, 0.040903888511820696, 0.05714118538890034, 0.03613566390413325, 0.04205418401397765, 0.07790405055857264, 0.014167011922836537, 0.03342184136272408, 0.04663782165152952, 0.03446477778197732, 0.06339740866678767, 0.08041452092584223, 0.013726718898396939, 0.0275254725056584, 0.025308914882771205, 0.048936753955786116, 0.07304040802409872, 0.02478752088791225, 0.007510949162679026, 0.0237535069391015, 0.03462400927674025, 0.013326634507393464, 0.03433358091569971, 0.04336333993705921, 0.052435961697483435, 0.01059402913597296, 0.03148574505758006, 0.07208282971987501, 0.03102456892520422, 0.0224646765855141, 0.051037365847150795, 0.052647470074589364, 0.035667732372530736, 0.05770384464995004, 0.03672555256343912, 0.021368988309404813, 0.0603866862365976, 0.07360700066783465, 0.06093028714531101, 0.014056160107429605, 0.041455504615441896, 0.036302179578342475, 0.056178879603976384, 0.0646445804159157, 0.022496566671179608, 0.049360149205313064, 0.028283945575822145, 0.010604358903947286, 0.03912047795893159, 0.016659654975228477, 0.06387506975443102, 0.09545689696096815, 0.023819623020244762, 0.050494354945840314, 0.0520108149794396, 0.03960879628721159, 0.01321236602962017, 0.013415907451417297, 0.012264706529094838, 0.03140299188089557, 0.08783685858361423, 0.07394017302431166, 0.006999566739978036, 0.03431449658819474, 0.06016356324835215, 0.016333579405909404, 0.03552363326889463, 0.036638602541643195, 0.12055859493557364, 0.03496054356219247, 0.014367119983944576, 0.021898861341469456, 0.03946253011235967, 0.13330483285244554, 0.047412404892384075, 0.018176140983996447, 0.021495099608728196, 0.040791575593175367, 0.030035848249099217, 0.0568959055817686, 0.04882050765445456, 0.0324071325303521, 0.06272493381402455, 0.027859264555445407, 0.04034314399177674, 0.044963124601054005, 0.029291926839505322, 0.07589949484099634, 0.031237244329531677, 0.07568525164970197, 0.05423355098173488, 0.030008616995473858, 0.030618124328611884, 0.04077342266100459, 0.00584100835112622, 0.0514994344121078, 0.03928919781174045, 0.026464559414307587, 0.030202428861230146, 0.06244443167815916, 0.0162748421280412, 0.033985179688897915, 0.14258881827117875, 0.025873659578792285, 0.07403127165162005, 0.042917364844470285, 0.025293776925536804, 0.009732660073495936, 0.014708180442539742, 0.008442490143352188, 0.04941876402881462, 0.018056126427836716, 0.05109662262839265, 0.01408539515978191, 0.0247850755113177, 0.030108834762359038, 0.02376331070991, 0.07283095910679549, 0.03981043410021812, 0.05667018507665489, 0.06329495518002659, 0.007992340470082127, 0.05831959344504867, 0.028566032196977176, 0.05997189618938137, 0.028107663238188252, 0.0025615579579607584, 0.03903601784259081, 0.04934223004966043, 0.04327415976149496, 0.018658392255019862, 0.040667280700290576, 0.05313029651006218, 0.024538682482670993, 0.05653572647133842, 0.07611359702423215, 0.103046143631218, 0.009384140103065874, 0.02823215108946897, 0.048860060414881445, 0.05320478587236721, 0.1099170655652415, 0.010055284656118602, 0.13392921653576195, 0.13645936123793945, 0.24982406641356647, 0.23437685624230653, 0.13735410931985825, 0.12559078662889078, 0.23010417848126963, 0.13426831865217537, 0.11627765707089566, 0.09865277039352804, 0.07044758152915165, 0.2547509176656604, 0.15969670261256397, 0.10582956849248149, 0.2327575790695846, 0.15204122668365017, 0.17099181917728856, 0.12599723122548312, 0.08930357987992465, 0.19269344920758158, 0.1582876907195896, 0.10308018594514579, 0.17662708007264882, 0.05902570985199418, 0.12255849738721736, 0.11999663329333998, 0.14437979873036966, 0.13992152467835695, 0.13100554060656577, 0.10265123943099752, 0.10724436171585694, 0.18940037669381127, 0.23037884733639657, 0.2437957641086541, 0.06862391688628122, 0.1092701502784621, 0.1250908462679945, 0.12389615178108215, 0.1680261080036871, 0.1297662578872405, 0.0945016935293097, 0.12748988316161558, 0.130647350451909, 0.06604968861211091, 0.1585366070503369, 0.08975464981631376, 0.0957660682615824, 0.06233683510799892, 0.15676134527893737, 0.13911089161410928, 0.15405476238811389, 0.07543790867202915, 0.14295843750005588, 0.13444116484606639, 0.1648059589206241, 0.10938776584225707, 0.07950799496029504, 0.16452728246804327, 0.1023236925539095, 0.15460684604477137, 0.19456185051240027, 0.18679995060665533, 0.09305350366048515, 0.15766180789796636, 0.18229579698527232, 0.11128253565402701, 0.10355487102060579, 0.12760550976963714, 0.14992389420513064, 0.10873789680772461, 0.1355810888344422, 0.09951656349585392, 0.16045915544964373, 0.14903202565619722, 0.14335652551380917, 0.1511088665574789, 0.1660888353944756, 0.12827813305193558, 0.09331762659712695, 0.12840101786423475, 0.1694010107894428, 0.24089375889161602, 0.13062094483757392, 0.10677704616682604, 0.16343354975106195, 0.1215652737300843, 0.2371671682340093, 0.09604989521903917, 0.18378067121375352, 0.17972421075683087, 0.10989728732965887, 0.16939237219048664, 0.10407722424133681, 0.17705804522847757, 0.1660213147988543, 0.07206047623185441, 0.215391501551494, 0.16563220677198842, 0.15431304462254047, 0.16745460976380855, 0.08973305331892334, 0.16332706640241668, 0.12615346815437078, 0.1097237212525215, 0.08898998537915759, 0.1074131260975264, 0.18519560544518754, 0.13325175445061177, 0.13596486824098974, 0.15999001421732828, 0.1381461590062827, 0.09534426120808348, 0.1568346843123436, 0.12760898302076384, 0.13152936327969655, 0.12256663874723017, 0.18682635622099042, 0.10961396503262222, 0.1613019235082902, 0.1398473247536458, 0.08497484770487063, 0.13474879990098998, 0.14802862715441734, 0.12704481719993055, 0.08812097497866489, 0.15033237228635699, 0.11223736059037037, 0.210403541859705, 0.2002438370254822, 0.23876578401541337, 0.18705375026911497, 0.17444948520278558, 0.11079976116889156, 0.10542045216425322, 0.1518269834923558, 0.18932705250335857, 0.06138155746157281, 0.20553779904730618, 0.1735430260305293, 0.09499842781224288, 0.16131933429278433, 0.1096938201226294, 0.09338545889477246, 0.1678059424739331, 0.0988664421311114, 0.17521144822239876, 0.06251255341339856, 0.0747975984995719, 0.08568618883145973, 0.17729392944602296, 0.20247137843398377, 0.14296600740635768, 0.15543641871772707, 0.1834006470744498, 0.12001979572232813, 0.16211601498071104, 0.08916102815419436, 0.19480754592223093, 0.0802131911041215, 0.17211155674885958, 0.10844575037481263, 0.10752532398328185, 0.17084104445530102, 0.09810859803110361, 0.15560209576506168, 0.13702992437174544, 0.12646082119317725, 0.11114449618617073, 0.1848768233321607, 0.30285001324955374, 0.1677750691305846, 0.09363249017042108, 0.17716188653139398, 0.11937259099795483, 0.15042588289361447, 0.18096580897690728], [0.0760970322880894, 0.011746210620913189, 0.0474951951764524, 0.034723828139249235, 0.05363002164813224, 0.0024746445797063643, 0.05562707796343602, 0.06518217734992504, 0.018138128179998603, 0.07840209102141671, 0.05072675849078223, 0.04705267107055988, 0.04976438591256738, 0.013480205270752776, 0.03792001327383332, 0.016239992728515062, 0.005134031516718096, 0.016960569882940035, 0.02955658968858188, 0.04188706348941196, 0.02505155476683285, 0.052507627187878825, 0.053628522509825416, 0.04487719132157508, 0.021354060008889064, 0.028163745482743252, 0.031950069751474075, 0.003114177120551176, 0.03596437250962481, 0.09865789863397367, 0.058966994838556275, 0.01229983145094593, 0.053708704144810326, 0.06796978792408481, 0.027908070042030886, 0.00479764983538189, 0.018204262814833783, 0.027787389408331364, 0.041617289098212495, 0.02155980375391664, 0.023496786925534252, 0.06204548277310096, 0.08408513880567625, 0.025822354909905698, 0.07116054053767584, 0.1199142549012322, 0.03140507731586695, 0.006178627563713235, 0.020977785570721608, 0.03924369673768524, 0.026303001286578365, 0.04133236376219429, 0.03438886720687151, 0.022516452518175356, 0.0031089735057321377, 0.019417434923525434, 0.04955306678311899, 0.04564515460515395, 0.055246797783183865, 0.04525144897343125, 0.1419288114993833, 0.013429698410618585, 0.06308089010417461, 0.01579100266098976, 0.04752737841045018, 0.024994042032631114, 0.01699845837720204, 0.0511178591841599, 0.03241577484004665, 0.012492690584622324, 0.045351898661465384, 0.07579075536341406, 0.045428421508404426, 0.0425641582114622, 0.016239682881860062, 0.06876026425743476, 0.0602863181848079, 0.005989300589135382, 0.057625010012998246, 0.11325811050483026, 0.035647638724185526, 0.027586538271862082, 0.09875295290839858, 0.0030652841996925417, 0.03567835250578355, 0.0852871137612965, 0.03539160890795756, 0.0752864066453185, 0.07407649070955813, 0.03238238190533593, 0.035973489793832414, 0.04810090642422438, 0.038946466593188234, 0.09170326244202442, 0.023712028305453714, 0.024134827981470153, 0.02055483746516984, 0.04582792331348173, 0.016274309637083206, 0.06672306146356277, 0.08100035003735684, 0.10100733779836446, 0.0406612989900168, 0.03380826281500049, 0.03278758340456989, 0.036902050123899244, 0.015282503482012544, 0.01385571900755167, 0.05216048019065056, 0.05854051225469448, 0.031295606822823174, 0.022192798205651343, 0.02127763920725556, 0.058929100778186694, 0.020681963651441038, 0.021087035274831578, 0.01997826293518301, 0.04053277756611351, 0.018161773004976567, 0.0479941373487236, 0.028412797255441546, 0.022772094562242273, 0.02478081929439213, 0.0025610428610889358, 0.05708330529159866, 0.030223541107261553, 0.04054611395986285, 0.029316926083993167, 0.04744956793729216, 0.06937170488527045, 0.03326229445519857, 0.06746986982761882, 0.051193732651881874, 0.016445263354398776, 0.04691906593507156, 0.024626558333693538, 0.02430378161079716, 0.029401686770142987, 0.048385905975010246, 0.054663840783177875, 0.03146735834889114, 0.02359800102567533, 0.08308137665153481, 0.04797099718416575, 0.054100565539556555, 0.01140178916102741, 0.0680458357965108, 0.02200427228672197, 0.033437957099522464, 0.009359354226035066, 0.011178720906173112, 0.09138021297985688, 0.015891502443992067, 0.05294817347021308, 0.08524613236659206, 0.04456876959011424, 0.07023987665888853, 0.08199495408916846, 0.018443844783178065, 0.027078701459686272, 0.03134394661174156, 0.08421563805313781, 0.0623538822401315, 0.02417643463559216, 0.03947800760215614, 0.042959904749295674, 0.028815740770369302, 0.04147742394707166, 0.011088245682913112, 0.03557526448275894, 0.06399434772902168, 0.014422783842746867, 0.015612132083333563, 0.07972920691827312, 0.05753811936301645, 0.032448106503579766, 0.09152375918347389, 0.01142543027526699, 0.005381408818720956, 0.045362203381955624, 0.03135532002488617, 0.10442981860251166, 0.054803809834993444, 0.018343131632718723, 0.011356058021192439, 0.004765403982673888, 0.05414555453171488, 0.0869117937691044, 0.04930505958327558, 0.016687708157405723, 0.059606147260637954, 0.024666315184731502, 0.041184320143656805, 0.06817069472162984, 0.05669729202054441, 0.0831870139518287, 0.02516658765671309, 0.035155015939380974, 0.03398495704459492, 0.02227023203886347, 0.027873116741830017, 0.02074612788419472, 0.06368853835738264, 0.04190229607047513, 0.03174672870954964, 0.061597181047545746, 0.06935701778274961, 0.01448789987989585, 0.023571821766381618, 0.03356304609042127, 0.020630491999327205, 0.03486497349513229, 0.023668017092859372, 0.04175016321823932, 0.033519033022457734, 0.006144576900624088, 0.07787797891069204, 0.04081167295225896, 0.004861891529799323, 0.018001641656155698, 0.08826980527373962, 0.11140582864754833, 0.03310590167529881, 0.02622343563416507, 0.07342702985624783, 0.033586442295927554, 0.023596216160512995, 0.033656103987596, 0.0444965623319149, 0.03489408423774876, 0.05147935931745451, 0.03293921901786234, 0.018693523670663126, 0.029871876286051702, 0.048640173190506175, 0.048325862517231144, 0.027097765378130134, 0.011177687465533381, 0.04203098447760567, 0.019902988751709927, 0.09725029682158493, 0.013391308038990246, 0.02481315652403282, 0.017096445990318898, 0.012510166307038162, 0.04467995073355269, 0.04402007754833903, 0.01804263603844447, 0.05461964959977195, 0.026977695160894655, 0.021141770521353465, 0.03158609826641623, 0.09144586336333305, 0.06975631549721584, 0.04150523222051561, 0.010231078103970503, 0.029940057393105235, 0.10226719285128638, 0.0450797382654855, 0.04713650036137551, 0.07677428657189012, 0.05259645484329667, 0.02385507912549656, 0.05633750253764447, 0.02915494864282664, 0.019156336238665972, 0.009647249080444453, 0.09262533640139736, 0.06015376689902041, 0.06688726905849762, 0.03449558062129654, 0.01285329550228198, 0.026948949926008936, 0.015724329969089013, 0.051563541128416546, 0.03846700579742901, 0.01199781259856536, 0.0405510603741277, 0.03229906469641719, 0.050487987318774685, 0.054067436067271046, 0.012586749453475932, 0.06972714167204686, 0.03142837333143689, 0.016995803343888838, 0.005298597197906929, 0.030042969156056643, 0.009986569202737883, 0.03596109221689403, 0.050364486523903906, 0.01998307205212768, 0.06491811378509738, 0.04818505854927935, 0.041765072965063155, 0.05503307038452476, 0.06261026457650587, 0.0530738784436835, 0.013087799325148808, 0.04885531438048929, 0.01033577844282263, 0.06447733743698336, 0.0720247343997471, 0.03252307084039785, 0.050501082514529116, 0.08836746448650956, 0.07475611244444735, 0.061669306669500656, 0.08396530422032811, 0.03938088644645177, 0.07091026607668027, 0.04352910604211502, 0.05373972591769416, 0.036801915848627687, 0.02450158994179219, 0.03162812608934473, 0.015888147936493624, 0.029434641837724485, 0.04509082224103622, 0.035565149009926245, 0.034715382498688996, 0.06769155676010996, 0.03040139865333913, 0.03007454939506715, 0.0765961933939252, 0.02681433361431118, 0.016257045426755212, 0.012570249655254884, 0.01470935396355344, 0.050189651374239475, 0.024622905111755244, 0.06996791664278135, 0.07573794413474388, 0.05172727374883834, 0.009033557889779331, 0.02257996366097359, 0.036358478901092894, 0.041067647107411176, 0.05884669270017184, 0.053249500269885175, 0.026304112652724143, 0.037877651484450325, 0.0186275764281163, 0.02299454776220955, 0.036157401409582235, 0.016097825064207427, 0.049695573979988694, 0.03788408219406847, 0.028498609935923014, 0.09293640760006383, 0.05169814816326834, 0.07440699875587597, 0.048378306382801384, 0.3400984941981733, 0.0839865296438802, 0.1880861964309588, 0.1513840994448401, 0.14273632754338905, 0.15672204113798216, 0.1410074351588264, 0.18165033630793914, 0.14533667941577733, 0.1303037954494357, 0.14123053959337994, 0.22300648590316996, 0.12127094538300298, 0.08550969127099961, 0.15330608381191269, 0.09717852371977642, 0.06512702093459666, 0.08690872869919986, 0.12420900413417257, 0.15222640737192705, 0.22404072806239128, 0.13588116882601753, 0.16710514726582915, 0.16156537109054625, 0.1284556250902824, 0.08447320040431805, 0.16208105982514098, 0.10515432542888448, 0.15511129866354167, 0.20607679121894762, 0.1358314894605428, 0.0880323996534571, 0.10234091780148447, 0.20526394655462354, 0.12037223423249088, 0.06676704855635762, 0.09605342042050324, 0.08231576226535253, 0.08770727217779495, 0.16953158425167203, 0.14155598619254306, 0.15719700080808252, 0.11370882421033457, 0.12643162510357797, 0.10405656285001896, 0.3066809201845899, 0.11936725495615974, 0.10146424843696877, 0.1623685084632598, 0.1254611334297806, 0.16010391904274002, 0.11184198141563684, 0.1560412542312406, 0.14418707782169804, 0.1079658925300464, 0.11838960155728273, 0.1376670878380537, 0.13090692402329296, 0.2420764454291202, 0.10107036840054207, 0.27446639724075794, 0.08580222362070344, 0.14585971541237086, 0.10618392174364999, 0.18261530640302226, 0.1271970762172714, 0.1273714512353763, 0.11478499029180966, 0.1241620336077176, 0.09902981109917164, 0.11478527230792679, 0.11547723595867865, 0.09289565627113916, 0.08475739843561314, 0.17071287555154413, 0.17192162631545216, 0.22502722044009715, 0.16987907263683155, 0.16408031660830602, 0.20897986512864009, 0.13866974419215694, 0.12187395521323197, 0.09918362862663344, 0.12776094517903402, 0.18081374291796237, 0.22030610736692324, 0.09353376226499677, 0.1455928836367093, 0.199852547084447, 0.10061353939818218, 0.2001886657672003, 0.2392008458264172, 0.1480060361791402, 0.19938358396757394, 0.1493663780274801, 0.14579511887859553, 0.07657876776647754, 0.16035095031838864, 0.09852577408310026, 0.16321433417033404, 0.11251131698372774, 0.1416397004504688, 0.14489654131466523, 0.11835257580969483, 0.15071837813593447, 0.14610011188779026, 0.1599597791209817, 0.07817380639608018, 0.17247492709429935, 0.09569131172611378, 0.1366573662380688, 0.0956113675783854, 0.150084272318054, 0.10321803245460615, 0.08983892810647376, 0.1527920871740207, 0.09411096019903198, 0.19730237923795357, 0.1841038023121655, 0.10891542595345527, 0.13263779052067548, 0.12439689366146922, 0.1290207408601418, 0.07941141186165623, 0.09823865941143595, 0.15273071156116202, 0.14386894879862666, 0.11409976534196176, 0.18240737146697938, 0.23862660164013505, 0.25820297305472195, 0.1519682735670358, 0.17004690191242844, 0.13830622541718185, 0.10785353137180209, 0.15090136206708848, 0.14075093407882378, 0.15849034156417474, 0.10241953350487165, 0.10722035323851742, 0.18163956032367423, 0.11466997224488296, 0.17740985291311517, 0.13399756833678111, 0.1461438392288983, 0.07146937045035884, 0.11643315927358344, 0.09534914453979582, 0.1019640032609459, 0.05389041900343727, 0.10029307260992937, 0.2825234195915982, 0.18035503628198057, 0.16431332129286602, 0.1846873975591734, 0.18067398166749626, 0.24094551627058536, 0.13437548477668315, 0.22024387086275965, 0.09451802077819593, 0.10497911920538172, 0.19207270204788074, 0.10649910444044508, 0.1780407823389396, 0.09163212016574107, 0.09591944792191498, 0.15840006672078744, 0.17481647722888738, 0.14338238193886355, 0.14054577477509156, 0.21932132192887366, 0.15718717477284372, 0.28579050209373236, 0.11502837020088919, 0.23373869829811156, 0.1440881792223081], [0.02208420159149682, 0.04321737804275472, 0.01567565806908533, 0.042841647227760404, 0.011943037461605854, 0.058415367602719925, 0.011168365163030103, 0.06014795588271227, 0.04315854428568855, 0.06494149143691175, 0.05506493820575997, 0.07234881544718519, 0.03774464006710332, 0.014062195623409934, 0.0895586411934346, 0.028434900268621277, 0.03867796127451584, 0.009171383990178583, 0.05057110785855912, 0.03046170557354344, 0.03309678810182959, 0.019313215125293937, 0.0275167300060275, 0.03516817421768792, 0.04582837602356449, 0.04466222824703436, 0.034077744057867676, 0.0353603719122475, 0.03709538701514248, 0.06862388720037416, 0.04976511321729049, 0.04575017221213784, 0.035169521215721034, 0.013329483426787192, 0.03938362126064021, 0.051416350979707204, 0.044517464921227656, 0.06869389399071224, 0.010825565295817796, 0.03699298918945715, 0.03176078498654533, 0.0523145982879214, 0.04353543285105843, 0.06188258877955377, 0.022866247127240058, 0.1103297813097015, 0.030656892267870717, 0.04995183386199642, 0.034576949692564085, 0.07166596536990255, 0.0282322995190043, 0.010175001425523078, 0.08205801437725313, 0.04842096874199342, 0.048397631908301264, 0.03279360964370426, 0.06142118072602898, 0.020697192521765828, 0.06309053802397102, 0.009695142653072253, 0.09843163265031762, 0.058048798600793816, 0.00816853653304861, 0.02493219330062857, 0.017596512516320217, 0.018293442990398034, 0.04874247453699354, 0.10144697123905644, 0.025474764479440637, 0.014006322107888991, 0.028971996252948884, 0.025513730943202972, 0.0648998272663448, 0.04859522872720845, 0.01849976004450582, 0.010766333562060026, 0.03796824916207697, 0.05099616180814337, 0.05028159976063762, 0.05237119446974248, 0.06217843481863383, 0.030114280270936433, 0.023440650875272695, 0.023643058666493744, 0.021279661559674423, 0.06399531994247809, 0.014021872884768527, 0.05450906217447482, 0.059140623998246156, 0.02254290822747862, 0.06507456593681127, 0.020749538052768912, 0.041922612363123335, 0.03480089275399223, 0.10037130981800146, 0.05132228747243062, 0.014715635315951658, 0.0891694070014637, 0.056450616975780576, 0.06947420290089212, 0.07421467860694975, 0.05596761984634213, 0.012175643241789658, 0.06599581611226313, 0.014672010947833769, 0.028196763632877264, 0.003220717289877939, 0.04252666491083801, 0.11185263865627348, 0.08857298744260333, 0.05904618199565448, 0.04576760155032389, 0.030354686023201793, 0.01652461192861665, 0.0844106002477929, 0.05356014102289919, 0.014048276643734425, 0.03550648965756409, 0.0671991566196084, 0.07351396503509022, 0.03410913690458983, 0.017987600222113542, 0.05521178696653806, 0.044029536220477894, 0.007052373794067535, 0.03100341957178898, 0.06018843261699658, 0.01782141851435881, 0.09513969562249258, 0.0275567670178134, 0.07033623711322434, 0.07812302865204401, 0.06477936927694827, 0.040987268803291954, 0.037814305469510145, 0.021551419340539724, 0.028643907608056907, 0.04475474437640514, 0.043607710613287054, 0.03296331655292306, 0.04867164767347276, 0.06294276157859713, 0.03589245468901936, 0.05644934790325351, 0.022599502553930506, 0.01811145539249992, 0.07308294050744735, 0.05196670914301649, 0.040041301399469376, 0.009422498933417955, 0.02630914812471019, 0.03657849971204996, 0.05005924860597588, 0.040847296040738, 0.059012232450186275, 0.03789669499383308, 0.05922476128034759, 0.028018227021675557, 0.07684534721192904, 0.05752964774728753, 0.12010422986350022, 0.008087491223705001, 0.006818880683567841, 0.024924695753725246, 0.007317763484024908, 0.08343762237927876, 0.022727615796611644, 0.05989729179418646, 0.02453972334478749, 0.023105355976440478, 0.08088490154477768, 0.035553660563891754, 0.05086893172119744, 0.026130965889024083, 0.0527922927722102, 0.04338239457865711, 0.02644684249389684, 0.024781604115560185, 0.04338762300903909, 0.03986124153016135, 0.046138345132931136, 0.04628729788237251, 0.014435685152420774, 0.040922809566836804, 0.027673978111124597, 0.055570277691003866, 0.02014759877056349, 0.10400373677839525, 0.04347669557319023, 0.023848820965213235, 0.03490755792881828, 0.04705332044977695, 0.05493743723491207, 0.03863925827317871, 0.05616514245048165, 0.021244331619527657, 0.04671063376008533, 0.06407305991160683, 0.032568568203714676, 0.07348131053731777, 0.08294525192468427, 0.04906273723463528, 0.01724788307910785, 0.014368299998750445, 0.05954572530754376, 0.03148280615278054, 0.022046619233151432, 0.07154764476581477, 0.033843384953797795, 0.00893850361535442, 0.058954578707925975, 0.044657697435468435, 0.05197450169362128, 0.05510739647434093, 0.014958115370973246, 0.02339669161301572, 0.036032624120707624, 0.0714436401904095, 0.07986352080479264, 0.034932056223624386, 0.0607770930218976, 0.020519967656582594, 0.018514328403398395, 0.13775166298728436, 0.06490013896836899, 0.02946572483779164, 0.008883727550710319, 0.009114783169934526, 0.07795928861014545, 0.012826798047171906, 0.05958055058727041, 0.020890418090857565, 0.004915309000352863, 0.041210473427781835, 0.09566653883666731, 0.0392589775583474, 0.026888377688010223, 0.06973509749514051, 0.03494752629194409, 0.01866949663963169, 0.026126013908651657, 0.04074418575328309, 0.05601864249911159, 0.030524313151545357, 0.06942945139599033, 0.037420032094814815, 0.03057223919313401, 0.01642416224058252, 0.06869585326057859, 0.030974861729191616, 0.03711347686476074, 0.022133632337499876, 0.044427357061067596, 0.08862912349286489, 0.03478233906207606, 0.03910456631274428, 0.07253372896229848, 0.01458268419810338, 0.021048940834589303, 0.02834371814969927, 0.06467920902650803, 0.05433298763819039, 0.03138001869956497, 0.05084220698336139, 0.05300308868754655, 0.020414551145222504, 0.022191686839505564, 0.04784774500876665, 0.0440453365445137, 0.013428888541966444, 0.021395766852947418, 0.043035403432440944, 0.032615171367069706, 0.11577422861591913, 0.05012454275856726, 0.038739010342396796, 0.036790267840842716, 0.04983240374713205, 0.018194451622548513, 0.061224493038025685, 0.028389523504301906, 0.01276421458896948, 0.07505406247219071, 0.029499012016458437, 0.03886966915160883, 0.035360331094125286, 0.059238075409666635, 0.015625598352926318, 0.045120285503799096, 0.048519744887016714, 0.04617252103344072, 0.03950945982069243, 0.040585366150480695, 0.02119628497894155, 0.07051467910059728, 0.07830080270650797, 0.031744595034979284, 0.032879112477530725, 0.024991416685224976, 0.04916680489259306, 0.051812335004797205, 0.018440241656207945, 0.030895001073076855, 0.060447308569564484, 0.01110368977606413, 0.052082254114793614, 0.03391402256966103, 0.03357188877998851, 0.013691450185433496, 0.03850840650557075, 0.014490587382169906, 0.034587807313073426, 0.01170070954685798, 0.05538141223951243, 0.03225023509003222, 0.012033249222440645, 0.031036829204822425, 0.03004037349455757, 0.026673529646359384, 0.015435718942171661, 0.027114359800179955, 0.051664755228557624, 0.07407856130157597, 0.0298691989883082, 0.05358190079277847, 0.07624756210134365, 0.034553252917248756, 0.027228335129620973, 0.0684870796976611, 0.05035254536778666, 0.03625722027209122, 0.02314940244104946, 0.005867091595064267, 0.009739408051245846, 0.08752287074457854, 0.03503937819914427, 0.10244448450976051, 0.11194664650247432, 0.034606453773449175, 0.07794860168360174, 0.015249155076162424, 0.01067748178684269, 0.005482678116095485, 0.06743685909896158, 0.10800020943861455, 0.018580936157377437, 0.04308240364480298, 0.0145732515011332, 0.06051196076441556, 0.02304978024767479, 0.03404380193387624, 0.034222281028633006, 0.16702827560948208, 0.09203459427226335, 0.0856537940853741, 0.09017198914079927, 0.09844314336078241, 0.1407983127865009, 0.1706444940646179, 0.13719416165258735, 0.11604117913520895, 0.15590521856211126, 0.14418252103496343, 0.1922732897219248, 0.09041640063514933, 0.13307331246323884, 0.13127476209774613, 0.13588443427579477, 0.0961243400524836, 0.15083933336427435, 0.13492848869645968, 0.09057988092536107, 0.1870776919531636, 0.14928538003005087, 0.11271021256106906, 0.1048817865375895, 0.11937593808397651, 0.15916397416731343, 0.09564277526806109, 0.14805124781560153, 0.1972277637105435, 0.16936492756940424, 0.19868075527483597, 0.16503520833794028, 0.13552884163800627, 0.10453702925588004, 0.11465811272501014, 0.0767673400696367, 0.23018841224256903, 0.19327627262100577, 0.13136527442838997, 0.09655742032919079, 0.11014604780939408, 0.16361972491722554, 0.19876696314895526, 0.15942736237775534, 0.20934522442985326, 0.27663726825267076, 0.11211299148271792, 0.20572067907778546, 0.146544138842728, 0.20790244481759146, 0.14744381478521973, 0.09840844795689918, 0.15768239507451653, 0.0898548768600449, 0.15832531760679558, 0.169390962109901, 0.11646732033113949, 0.17458964721299708, 0.24343270546523854, 0.14468982350081205, 0.1677213970106095, 0.19634845230029896, 0.07520743471104652, 0.10493405599845573, 0.0952084778691642, 0.18503213999792933, 0.13434719410724938, 0.32347414875403047, 0.17047587811248377, 0.12663069879636168, 0.15674133697757497, 0.08595559585955925, 0.1548645197181031, 0.1494396576890722, 0.10660239655408077, 0.06848010350950062, 0.0690361724991817, 0.22039330971892923, 0.08368736991542391, 0.08420173762715422, 0.18227328022476286, 0.1531540325959213, 0.165757303184364, 0.08634469646494836, 0.1608053079689853, 0.13754555373452604, 0.12075647377059795, 0.18458287348039448, 0.2039933600462973, 0.10272181025356986, 0.10977046171319671, 0.0965856367838569, 0.14371251891134307, 0.1439481507986784, 0.15185349300736561, 0.14122990134637803, 0.1446365224546753, 0.27903692855034024, 0.16252306813839823, 0.13169907761039212, 0.14311139413621277, 0.11910060129594058, 0.09830631359363906, 0.21352605399442837, 0.1086813748406712, 0.13574434648035094, 0.200351225794293, 0.08776906339335255, 0.17616553843254223, 0.30846275738440454, 0.18741268257144839, 0.15173694613622501, 0.15071981790242717, 0.09526969763101079, 0.14179908408550546, 0.10936245860648341, 0.1532266294816509, 0.1374717545695603, 0.12439953570719808, 0.19855064194416627, 0.12262281932635233, 0.121037050121231, 0.11628667416516691, 0.15276859077857807, 0.13025405671214685, 0.12414728713338263, 0.14125091896858066, 0.18820094730472192, 0.1937814080156386, 0.14631122321588919, 0.1615029713138938, 0.18732893862761557, 0.16667204472469166, 0.20864157937467098, 0.10087122049299069, 0.08926546317525208, 0.1144341028702911, 0.13467835524352267, 0.1741405884968117, 0.10096795944264159, 0.09668653176049702, 0.20700428285636008, 0.10265815624734387, 0.09551050970912911, 0.11195359300472774, 0.19052720919717103, 0.2849667181726545, 0.11747895667213015, 0.14521829201839864, 0.13114070054143667, 0.15479113615583628, 0.17357921315124258, 0.1287629484431818, 0.2645100111840293, 0.1262311264872551, 0.1455754431663081, 0.14668943651486188, 0.13542247703298926, 0.1695577969076112, 0.13160188595065847, 0.25552266219165176, 0.2881742507452145, 0.15088475280208513, 0.1303477751207538, 0.1232932903803885, 0.12064712573192082, 0.10921384353423491, 0.23803076095646247, 0.3022630634950474, 0.14165665110340342, 0.1357739878585562, 0.11904739672900178, 0.12316803811700083, 0.09659960400313139, 0.13344680570298806, 0.14737427554791793], [0.04815580679860432, 0.026786959497258067, 0.05952803621767089, 0.03632339386967942, 0.06284486487857066, 0.0676787992415484, 0.06642924519837834, 0.04019174215500243, 0.04676046526583377, 0.02573135461716447, 0.055135115690063685, 0.017366365100315306, 0.04461557313334197, 0.07043125428026542, 0.02117712087056134, 0.019402690304559655, 0.03258698088757228, 0.02983786180266179, 0.02234119805507362, 0.06788628888898529, 0.03569820866687223, 0.09100070092245005, 0.015168019781413022, 0.03402892929443624, 0.05608757688605692, 0.07121632035705261, 0.039465710215154104, 0.012545986992336111, 0.04324011744756717, 0.029133528405509423, 0.09873408751445822, 0.029009715908614453, 0.027998489604215138, 0.02827991200319957, 0.025127927328867372, 0.04587955823808443, 0.025784663084778003, 0.0603165718348464, 0.06645362474955618, 0.029197692638263106, 0.026256182900397107, 0.07642460885108449, 0.009658504677645396, 0.06297359039308503, 0.058355498549644835, 0.04830317877349444, 0.050977173959836364, 0.04770822124555707, 0.01348267662251601, 0.03963430761359632, 0.03297700546681881, 0.034248512238264084, 0.016423158485849854, 0.0435656271292828, 0.008154946881404612, 0.018039368733298033, 0.012712979496427579, 0.00838050689708325, 0.047350609966088086, 0.03983012698881794, 0.027502352750161663, 0.053120192169444636, 0.0452056918584276, 0.02073125338938553, 0.02223862953542266, 0.040379216079600155, 0.045982149022165686, 0.005314824720699107, 0.022963535266171675, 0.04550826546619646, 0.019544381138985045, 0.030830024188617244, 0.02132125893695047, 0.06029447067703586, 0.030223383400880266, 0.039863208221504465, 0.02065889955702005, 0.019345828804944176, 0.042810937156900764, 0.027640067528409418, 0.024707112897885963, 0.06873230013297871, 0.034079476972692646, 0.02144734055036679, 0.029303149967745412, 0.05654737076838501, 0.006776529562557698, 0.03815229065367021, 0.013981765368953347, 0.04748385515995324, 0.09120894013904035, 0.029303589690243825, 0.05806586428661831, 0.03192262884113006, 0.03068716818233952, 0.040255474086734466, 0.023383748557535, 0.027376428843126632, 0.04912551921734121, 0.044529075821628794, 0.04334485674917232, 0.036389419037732296, 0.025532507279422134, 0.0570966862142086, 0.030827291229797993, 0.05539516423596069, 0.025655089666543063, 0.04519553556747269, 0.011499068950797664, 0.026108430574822705, 0.024990442616399378, 0.05768407754658256, 0.031173668248811737, 0.031077266976353712, 0.07203279412351549, 0.03434663529333193, 0.016439515420643147, 0.009858328867267119, 0.021590567630482838, 0.02779255846689921, 0.05896440845390316, 0.0723570458649192, 0.06089690163207706, 0.021681543803424574, 0.074821080052061, 0.02686809479200747, 0.05572488560574129, 0.044319025764707476, 0.023179179261205718, 0.03914826396794524, 0.03704862800077535, 0.04569519391225185, 0.0077077848163753515, 0.0363173342338996, 0.06752196859451942, 0.041061060546780936, 0.04806925753655378, 0.01341087847322342, 0.033839024836197495, 0.0624392218014691, 0.05660291681124363, 0.08409997433773242, 0.05430037395854015, 0.0406656368431868, 0.021789355596411042, 0.0023210977042253944, 0.03138403742923401, 0.015199816170934355, 0.050120535161113366, 0.027076935148215853, 0.06768272520275787, 0.0336193862312939, 0.050239905904163606, 0.034058544697472826, 0.05472026256029494, 0.0830844565643929, 0.049908073124242947, 0.02521951391827315, 0.02146526712749619, 0.12973238626727834, 0.04902922184555791, 0.06613107994780876, 0.009978746966226026, 0.00874630777616403, 0.049765428630053066, 0.05774042510893196, 0.029098871964379214, 0.04915649275062606, 0.11240773543249816, 0.025624379595683422, 0.05777458987722639, 0.02003783327381825, 0.008775131864240393, 0.02417402636638144, 0.02878475424950011, 0.031630827506887726, 0.0890961496043019, 0.07119467933080159, 0.009205095120705664, 0.04028769442811608, 0.044258399721002206, 0.04987117354176007, 0.01999521173274843, 0.10109425071277656, 0.04860114735492971, 0.03194059623638168, 0.051880820392398164, 0.050266022080904804, 0.008480896285618655, 0.03727650815562811, 0.014640202498412691, 0.04798912414116785, 0.052209877540008165, 0.07330899126827717, 0.07995960666448809, 0.010338568918086821, 0.03704322887642775, 0.05344884113583248, 0.03024270150490338, 0.031078819920367096, 0.04329842056904454, 0.022076583445596043, 0.055137687231763266, 0.053017375030322, 0.02564606515079504, 0.08135289986967109, 0.0537282523146132, 0.07282937091076747, 0.037301730044418946, 0.033853737913887016, 0.011885637904924806, 0.0347510798019357, 0.061219617127790116, 0.03311437329102773, 0.04593001685861964, 0.005251285283520701, 0.027513742861628998, 0.03135812534310389, 0.050952033707289957, 0.04609834708389826, 0.04170211286691483, 0.02683907496248139, 0.023607391049154103, 0.035083261391264386, 0.059323593086446635, 0.03861970268189907, 0.03153138342895545, 0.022759828716516495, 0.014130620711512165, 0.03634728731412906, 0.039285965758608654, 0.06411174806999043, 0.06755365830031224, 0.045542845837189816, 0.010756622559711104, 0.05089711106847972, 0.07530182105256245, 0.057676674623508006, 0.027628608768281993, 0.02045412617007969, 0.03116036154096946, 0.0506572044105269, 0.07320278993574902, 0.02509920250304276, 0.02057931720628403, 0.06665306209470145, 0.024142717011272907, 0.09458566753892228, 0.0323414673039224, 0.0029262303087307373, 0.031759204211994074, 0.05315360365784727, 0.0512417978461599, 0.020896910027659032, 0.03406087133043911, 0.011663831301120808, 0.02344409815123072, 0.06573397156898864, 0.027763980215240736, 0.021398562894319184, 0.02337631409318419, 0.07286287887836806, 0.050019788614008576, 0.02272549882036401, 0.03189795243088156, 0.030869973998051137, 0.06438729265937582, 0.061703319297521375, 0.14899802044965327, 0.06862875568913296, 0.030043755832593888, 0.060660071176243946, 0.03703066431626212, 0.023530897888122126, 0.022099502821220085, 0.039068961777957156, 0.033819528616731986, 0.059408880697446875, 0.06937464379006997, 0.031894939311314374, 0.060837129058199935, 0.031782006699359044, 0.10205551006947644, 0.038285465343506075, 0.05996919106109999, 0.07270725051057525, 0.017874105433293153, 0.021463719749590382, 0.010696695062506478, 0.0525580041721696, 0.03787699097301811, 0.05831689202750567, 0.07166946088545956, 0.010895621253439458, 0.008756375937082339, 0.0015088191594259115, 0.03684012532175984, 0.04939379447023384, 0.056437210078001954, 0.004432242294569733, 0.0351929879252566, 0.060526091256178916, 0.049718491500243545, 0.05247182598395739, 0.013839010480296565, 0.05249312562227715, 0.041998396773124114, 0.040534970612498, 0.04578715714160353, 0.047546132482239045, 0.08767841747612692, 0.06156270086648874, 0.022978359666012693, 0.054836642448208295, 0.01071307890015305, 0.06324343528831378, 0.021400828300102148, 0.10502718068892136, 0.11585269588977098, 0.039026202939567156, 0.03251399437431246, 0.022676079206576105, 0.025557940680300817, 0.011839266662718728, 0.02277711704664398, 0.04095071431947872, 0.004046607982672867, 0.042435005962033756, 0.043559879195527174, 0.04967619650415145, 0.009738345852383645, 0.032044482068158686, 0.0563474992668489, 0.04983505321433768, 0.016948506272456143, 0.07941530813695863, 0.03308958184788935, 0.060989907578914426, 0.03416018924326636, 0.023702228245383594, 0.043623882011161186, 0.021156669135962147, 0.05624085635645315, 0.05446619572467171, 0.0822699346463196, 0.017635978074395098, 0.02704333070141729, 0.051504544098861516, 0.08790596737526357, 0.05182738204894122, 0.0474883562856121, 0.02853188412700547, 0.11745594267267734, 0.13828911149175838, 0.11175604071468115, 0.15133486536797136, 0.13178773457184434, 0.18393724953057244, 0.17824134032707661, 0.20863124867901206, 0.16599286085693166, 0.13068675849353895, 0.11287929606623948, 0.11385096033336595, 0.14345279691042379, 0.1378589478554204, 0.14506863051792607, 0.21535757055971771, 0.14580449962522835, 0.1596852735383436, 0.20131474127992988, 0.18391516321571544, 0.22225212247576565, 0.15623137762304395, 0.08104049280518666, 0.16749989561503753, 0.14096323284320533, 0.11769216085667722, 0.15485291252844036, 0.13446592289255932, 0.11111648011137731, 0.15278934122761711, 0.1398282070294954, 0.27595680789090693, 0.09191249613650143, 0.09017701348057017, 0.17044323845766485, 0.08731181136681698, 0.1811903531779535, 0.14106630231253803, 0.14882680698065087, 0.13964301149826497, 0.10315675332094543, 0.13833683158736676, 0.14767475629923865, 0.2247155481018126, 0.14485158200841397, 0.09333315974799916, 0.12354084115941077, 0.15111680753761902, 0.12146982611739077, 0.1253334098146297, 0.16426402784418315, 0.17523703747428954, 0.09686010525911115, 0.1090752994059585, 0.1483818152337335, 0.12591728707775474, 0.14015446999110281, 0.14156124059809372, 0.15900718804914504, 0.1606992253800854, 0.14870790007989854, 0.13930502260336652, 0.1208537099591922, 0.08791177839157172, 0.10019687542808242, 0.15708095859736204, 0.19521893322234973, 0.14194258576026186, 0.09910328371915966, 0.16015095636248589, 0.12035134277539328, 0.3203949483577162, 0.17783759714802727, 0.1769120350945741, 0.16174744960153475, 0.17974203714402393, 0.11266230692854151, 0.0801700129522942, 0.14765231375349686, 0.11334727212670259, 0.10052528319647536, 0.20420683140400797, 0.061988170418771915, 0.16145002649864182, 0.09589304230757989, 0.18051118415314704, 0.16719371516956016, 0.13088273000903428, 0.13462327304296196, 0.10991184084559791, 0.2573654742445797, 0.18566332175396383, 0.1885913169826381, 0.15645001432858407, 0.08980274840723723, 0.1664565844112076, 0.14986980648245662, 0.1428558726911433, 0.10392488358775154, 0.1773853026679717, 0.19322503474541008, 0.1191542882588692, 0.18776563316350803, 0.12053751794155687, 0.11978299866314046, 0.19112330221105367, 0.1212355523603037, 0.14149688155157492, 0.1389318410656415, 0.1252876638318412, 0.06414268820662983, 0.10421584258438088, 0.10460970035637729, 0.1112841980648227, 0.08908918083761819, 0.1128350046928972, 0.15067215717863292, 0.0745917489985004, 0.14331046782899648, 0.17644543200731277, 0.11150440812343732, 0.12963142449734733, 0.2514158544363454, 0.10609742443193682, 0.17762241885066032, 0.24017899646423757, 0.22841582220280543, 0.1760096280486323, 0.25066486035939306, 0.21061543986434117, 0.1382446420029737, 0.1749058169662021, 0.1155536252190359, 0.18699782202020288, 0.22849460860015824, 0.1784067798871547, 0.11309448920655996, 0.09718524757772684, 0.11181187248439528, 0.11656567716272548, 0.06933410026249476, 0.19524850038578734, 0.18316966103157029, 0.19186231802450493, 0.08538171532563865, 0.12735795899061486, 0.12346575065748766, 0.09193104240694083, 0.07090613973559812, 0.159162430500146, 0.17238803644431755, 0.154288939666003, 0.17208927747560665, 0.14819696109043434, 0.18356049084104598, 0.17577138380147517, 0.15393830457469448, 0.0948897105990909, 0.16903130250284448, 0.21345722721889615, 0.1780017008422874, 0.14715507481014356, 0.11491667697555386, 0.08597080988693051, 0.17303653992712498, 0.16548486077226698, 0.13520443404559046, 0.1557723295991309, 0.14154366654111072, 0.05476136640936602, 0.10702060419134796, 0.18920201546279714, 0.14211543195415288, 0.10526043770369142, 0.15946954605169594, 0.08961088838987052], [0.003206173746548302, 0.0289379316745908, 0.025261775517719798, 0.04972172355337534, 0.04274089325917885, 0.054125661263242364, 0.04926651614368893, 0.04817205983272288, 0.0008739227223486523, 0.06376411125529557, 0.01195342289065593, 0.01608985439816024, 0.03721939247043338, 0.03328352730022743, 0.08426216329098679, 0.055964892453630455, 0.03907017147867009, 0.08319722590385936, 0.07194491641712375, 0.022417015861719847, 0.052761437982553616, 0.10201428376603872, 0.11151549580972642, 0.048961482316371985, 0.04249278958013747, 0.014431189592869487, 0.01394560329572414, 0.07624104604474269, 0.006462359433498932, 0.016003848759282846, 0.09313136237324215, 0.01723576380754821, 0.038305937487166375, 0.07238158126710914, 0.0019171155304320564, 0.07072301479638554, 0.0216786828241311, 0.05737737017625477, 0.024750942284299526, 0.056092263548634946, 0.035962220281362534, 0.01871412754553603, 0.014548579729307676, 0.024589669883425813, 0.05298712509102188, 0.026878885619225912, 0.038856280807522126, 0.01970498931768816, 0.010323808528482914, 0.09032887915964238, 0.028715055450447835, 0.01899551283713663, 0.036562324603437446, 0.021329903102014214, 0.0056769445473037194, 0.045324817692744546, 0.0406192934315186, 0.031341579160653055, 0.062710936908843, 0.0206923741279752, 0.10965116147417575, 0.010230655079794815, 0.0057892560744221555, 0.03501614526612684, 0.033292974840151146, 0.009195853526762221, 0.03136552084470168, 0.0713556437403895, 0.0723422622832004, 0.05489858209330123, 0.04095046941074543, 0.023804754091543145, 0.05264682440611068, 0.012539051622297848, 0.07330418957280926, 0.031683119232184254, 0.05393619467213284, 0.00286618360405555, 0.03756180827622302, 0.07053680994431488, 0.032413288645329885, 0.06293185200775042, 0.01034703032928519, 0.04406514075526502, 0.029618612825288437, 0.0893513296614401, 0.01163284199719783, 0.056581587487016805, 0.027108188842248637, 0.06615233505726792, 0.032149484832189046, 0.018868202969315462, 0.05204613378737122, 0.035131493568769656, 0.013741745533479843, 0.038656405595247634, 0.02973426911921706, 0.07458875072188675, 0.021383347011578735, 0.027870049816556275, 0.05657622175931465, 0.05457035615108907, 0.04242540257109795, 0.007430647856381256, 0.10853652987862006, 0.012320968744461425, 0.0513211631187005, 0.054563899466302246, 0.0238368111604359, 0.016381138084398117, 0.11114336070022546, 0.06706322485115379, 0.07350923755438998, 0.09534966404316947, 0.013912357862864155, 0.09940772011759691, 0.014744923246325925, 0.052622819639509544, 0.06686922744847834, 0.04502218100242317, 0.03291525506938342, 0.03285282931756228, 0.005319027131918119, 0.030238714316510595, 0.06442336845793761, 0.043371002611820586, 0.026764038266264834, 0.03998627857072279, 0.016757620323915035, 0.043562636274145916, 0.08162666330463253, 0.053501967777265236, 0.009235343204636592, 0.06073641590774059, 0.09829875110881403, 0.06217925860255491, 0.06619652995141223, 0.03556848125299439, 0.007213097005660529, 0.039079173729987815, 0.021161155418667477, 0.05180740343348589, 0.04165302721958142, 0.0067910524649050785, 0.05088535544928163, 0.028046244951838162, 0.038727533028577454, 0.028749606135534123, 0.0706103493575938, 0.045667619415326044, 0.046861924274708144, 0.04417024741997011, 0.022427981093642302, 0.06020696404448245, 0.08378273589187302, 0.04895646168733947, 0.022227217159525026, 0.08959047190728597, 0.008033820031414507, 0.03859725271468051, 0.0482679749984527, 0.020325293044152204, 0.009624250851629768, 0.04488420090638101, 0.00344469653100532, 0.06214952816662844, 0.04614796707755886, 0.03692007318022661, 0.013997663099871716, 0.08701539016328752, 0.025978617813962046, 0.014388749877980445, 0.011811640215455554, 0.02680533692910103, 0.05244090069027152, 0.06798224116209894, 0.07123183124349453, 0.0219241704326123, 0.02073124225717038, 0.09499135514488444, 0.04495570312428754, 0.06686306020128541, 0.058785138971870765, 0.026772530291054863, 0.06332789169391617, 0.07615843758685514, 0.034863867695094086, 0.03566960629541427, 0.05034165063989349, 0.0200049561317428, 0.03465989953838289, 0.03167688519170042, 0.012964700217708014, 0.04515050946793053, 0.06502278629341163, 0.032559053870500065, 0.04211619416309986, 0.05064177144959103, 0.05186346526897978, 0.08351543656317517, 0.03860952041577548, 0.019717895265785046, 0.023763522221997846, 0.07848147855838761, 0.0323196444514906, 0.01999864231038373, 0.065481188648846, 0.048700365077820607, 0.08629431205918081, 0.057301426204503514, 0.05330093852535356, 0.06553064537001774, 0.036087902990402654, 0.037744992587249726, 0.04763913471833803, 0.04987951528164558, 0.013111971074977191, 0.030798664738540538, 0.03121638626907952, 0.012585472031787504, 0.04837700391362887, 0.038433397639892064, 0.038773987762397155, 0.05386133794672787, 0.0610882013279479, 0.01872130040283082, 0.027760046832554508, 0.0448252224305179, 0.0424768482480431, 0.005832319193359581, 0.06609392803511582, 0.0459629570832476, 0.0360695237031905, 0.02908274509536568, 0.054690647157258354, 0.021057800222479273, 0.037895299756200984, 0.01328327916780836, 0.026112495688721538, 0.019423618869041093, 0.02632034713315079, 0.07173053963924758, 0.02251936173706781, 0.05289008928230032, 0.02307600218045991, 0.059661403865902685, 0.0422555732075125, 0.037509438625420444, 0.12409443137585185, 0.02523888397263363, 0.018871956381190103, 0.03431956545682624, 0.047672961809439585, 0.011466716878203442, 0.02522903752833372, 0.055075350537663326, 0.03649690799647942, 0.027495858957991004, 0.020631837141991127, 0.016477739736728836, 0.03229169888072647, 0.02731358377786819, 0.04789433332916815, 0.04929119626467582, 0.01354446227196604, 0.032613334551570006, 0.06656246812781319, 0.026582688915368635, 0.05179109102755319, 0.11175944717251696, 0.03175672172801569, 0.018924301912193187, 0.01164567373052705, 0.09868665685644373, 0.06283403694396839, 0.04150571832724381, 0.01682168251136318, 0.030001442282809876, 0.05234756819845643, 0.037396669285953976, 0.05155616418051068, 0.09433936356799677, 0.05151098965143319, 0.018169864270021208, 0.010078644681925653, 0.018835466835298575, 0.08916463499190286, 0.027491302171256393, 0.05688465833372902, 0.05444870701467153, 0.029179433950048406, 0.08168727450538427, 0.019702976242115255, 0.06451730208937079, 0.03622947879193816, 0.030218116007745266, 0.0805122617748566, 0.013269899172883015, 0.061422987855621614, 0.0572584484325489, 0.08654854958876967, 0.034329395202803425, 0.04537272332527209, 0.06635143101448193, 0.0341761379968375, 0.04198707531031687, 0.02319120761967497, 0.08216875765356235, 0.03157479906803928, 0.035025433244300075, 0.053105512488400564, 0.0330225325160427, 0.06093244308431167, 0.031137807673076168, 0.03685113879328128, 0.018924387259176, 0.037212954339338467, 0.08494001129292883, 0.03478325561445672, 0.01775850665580947, 0.051278437676955946, 0.032476623528054915, 0.0426317938399734, 0.018040251889033243, 0.06448396481573582, 0.012129231181461364, 0.02516043525247369, 0.024235379714809824, 0.03312068154627923, 0.023592405232193414, 0.018813194983522408, 0.02205943612352712, 0.005249961477602483, 0.07825794367818162, 0.036623028572648764, 0.011136474149679998, 0.06359339502523653, 0.051395066184340976, 0.07090585771948099, 0.058248992936569266, 0.033228652901016176, 0.029028340104559902, 0.053016851816209964, 0.06642786480369978, 0.02764692311757244, 0.047276235636672936, 0.04246002004947513, 0.08873752900399268, 0.011784278158302186, 0.04381979786558077, 0.018145970825571567, 0.05066552017524373, 0.12058900072588585, 0.10576520202448592, 0.11381757110939361, 0.18300621042726561, 0.1322254681144841, 0.2768866892438382, 0.1234073807427194, 0.11966260004555807, 0.11748629651265219, 0.17493890190962702, 0.11143262017867528, 0.10130539914825931, 0.11712572406395338, 0.1525317269260995, 0.13264423236250877, 0.09656619993620552, 0.1311665866523981, 0.15359133569290861, 0.125074622919783, 0.11864743850310333, 0.11227249386138283, 0.14619147026678547, 0.17582060303539038, 0.16777631593868136, 0.08923772911657579, 0.10640568289090879, 0.12281096118385904, 0.19614988326793537, 0.1369868649635464, 0.043671713428921066, 0.21512092935154215, 0.13889054796891287, 0.12011933999019675, 0.30903424078132957, 0.12798980867955834, 0.16212526214076206, 0.08947353169787675, 0.16672985802870244, 0.11563922453206033, 0.1381883426802233, 0.09207086302922107, 0.15929922315990552, 0.1750421049655415, 0.0877201632829383, 0.18590950698126107, 0.07847733737435192, 0.13352894660783932, 0.1589815691113472, 0.16146492882398888, 0.1842490554554388, 0.12107771981391124, 0.07070862455293536, 0.2687917579896748, 0.12935881881276146, 0.13029294525040314, 0.12924470618600026, 0.12998044170672074, 0.11187033887836151, 0.1479142770403996, 0.19831628655083477, 0.16616210021311417, 0.12341608613496646, 0.11365112964995205, 0.11748081204132177, 0.1912224679836072, 0.1280701090581715, 0.09977853420423344, 0.2985430631088093, 0.13195743405958638, 0.16698083752999082, 0.19230380683438852, 0.14005957898916677, 0.1883937869570218, 0.13092489884002134, 0.10751232897746377, 0.0663689456996508, 0.20948240300640464, 0.1878797309473157, 0.15314585412852466, 0.2026318307616748, 0.12934556405525655, 0.12167197972303256, 0.09490293567068875, 0.11734660947695374, 0.17453051288612187, 0.10683637345209718, 0.09126131350058131, 0.13017261342611164, 0.09820868406677619, 0.11393545384635217, 0.15881001425441355, 0.08017459942493588, 0.1005746285954956, 0.19432566943578422, 0.11641447199508548, 0.1377799388137646, 0.09961464573279954, 0.1803437853232026, 0.19231477577704936, 0.14049922727281228, 0.22902042022906244, 0.1444613459170796, 0.11225703492527828, 0.10269159742165357, 0.15993370005162433, 0.20016963710077107, 0.13166027812985703, 0.10672336662537418, 0.11117752917925827, 0.05726314251660369, 0.18625275028171018, 0.25989812740590423, 0.16667308373143896, 0.2096949244150892, 0.1367726514581591, 0.20046798046678305, 0.08723885082872584, 0.18626180448336527, 0.1782887041918002, 0.294844614691101, 0.16576122172409669, 0.08898581450921483, 0.1473358174553141, 0.14871192252030596, 0.19112720590783283, 0.22138740168884397, 0.1172712146944832, 0.146895901998505, 0.10160964258830063, 0.1816824564593844, 0.19625105283921584, 0.12790462496923283, 0.10016298896516673, 0.138000727747567, 0.143305747769773, 0.17938783974386752, 0.22200506151420996, 0.13055548741249368, 0.12589193531312048, 0.1708505439455621, 0.11380152587662451, 0.23716467461781576, 0.10839430469786748, 0.15041178208775818, 0.14959488529711962, 0.07891290384577587, 0.14670619420940056, 0.07870300963986665, 0.14166695211315528, 0.08777736802585423, 0.10446141925058328, 0.1436014342471026, 0.11792953679105267, 0.09716474203742109, 0.15613829746143892, 0.20545399573165923, 0.10355106380302459, 0.13174069725209847, 0.12117324164137244, 0.10125411674380302, 0.15201633505057544, 0.20743898843647912, 0.19757476227823645, 0.1447450541309081, 0.12353170532151125, 0.104278539220104, 0.13666793442098424, 0.19227253273129463, 0.07458120308001526, 0.12948186689754948, 0.16999420942738652, 0.19312870397698134, 0.11391931213438511, 0.1204644757672213, 0.1570712958346121, 0.18605875287903473], [0.016820597120386083, 0.05585243852692656, 0.014815520971751539, 0.031945561204338446, 0.07100669332430698, 0.01102699809052865, 0.032884942047530785, 0.017563197507115547, 0.01830047298426507, 0.024159942258847877, 0.043214609831920825, 0.041418757173232734, 0.061671072980971076, 0.06851331461803056, 0.02490520510036731, 0.02609560811833944, 0.04897232138318941, 0.0750183429045137, 0.009778871753951535, 0.06290170596912503, 0.01838136522565037, 0.07396697197691537, 0.034247514049638994, 0.045680566181545146, 0.021395670373749454, 0.05457189239677973, 0.04834815663343761, 0.01921432023664238, 0.05613651039311662, 0.07258299272507429, 0.08521747062331997, 0.07747098512481898, 0.1157394886831753, 0.031925419316394255, 0.03392489132238552, 0.026888800712185912, 0.025651859468780458, 0.01941563892614795, 0.037015743437223136, 0.05162572197150439, 0.04124906881770585, 0.035378116663196124, 0.01382887738145655, 0.029111740805092268, 0.03576765884645283, 0.02655288055393612, 0.06945965680642985, 0.01780118385795504, 0.032876244076760486, 0.10789584863232449, 0.028677747686742805, 0.022574206450372003, 0.015065255520312348, 0.03960632864618674, 0.027984925000055227, 0.01953223403688753, 0.03268658823799342, 0.04893064236966893, 0.012624081336980453, 0.041540528764016926, 0.06553756218636408, 0.028423063013178762, 0.01588558381627081, 0.015123230241442798, 0.07828777059330605, 0.06790203726268373, 0.052091389952693135, 0.02966375024698209, 0.03656567168945912, 0.06097004399634898, 0.009140970778389601, 0.027117940662719775, 0.039379851150442846, 0.04209751801681705, 0.034451174215064384, 0.01870625706942519, 0.034950955014210194, 0.050930949291796423, 0.04999403980036732, 0.013391276497713989, 0.02238923541881377, 0.00905806917216978, 0.030852175441395957, 0.016812657995615155, 0.024176805709430482, 0.05600250449788291, 0.016079831693787128, 0.06390012465999462, 0.0660102508845739, 0.042250003389199264, 0.08649397204862908, 0.03555391289410181, 0.015987525221135, 0.0012743752881760884, 0.05950922648480628, 0.05631521584291477, 0.030026938766241074, 0.017296582809649408, 0.04524439857050311, 0.011684514029184356, 0.016275330090138596, 0.03231657938158605, 0.03391531019588001, 0.04201461641059723, 0.05295679351547733, 0.02002320183237316, 0.03829267901892308, 0.03333152941195294, 0.025554528656357434, 0.01666358279180713, 0.02503855048416881, 0.01127358964367886, 0.01851628581789555, 0.013127939309924841, 0.013722939511353616, 0.0712624670995865, 0.0503994565224275, 0.022191881653270684, 0.04201704323349986, 0.04944759275531396, 0.03427852469030768, 0.02730750373302726, 0.07071056155837141, 0.009147473847406218, 0.01879466541140573, 0.022570282344531734, 0.10053569552837871, 0.054333076695911586, 0.008008289223653264, 0.03908833554305602, 0.03939047128369566, 0.02215665746916784, 0.02851079229003517, 0.04331639167503454, 0.023630850337212905, 0.058022804878419265, 0.014147564870654605, 0.05021653196308762, 0.040108376706484705, 0.017582936779945157, 0.05823037616210058, 0.10314895334886387, 0.0722406993736513, 0.04183230412309058, 0.027228381513850763, 0.03213419287931174, 0.07682326089707203, 0.036312621596152894, 0.034475379361538216, 0.013810810723953182, 0.01716185888653854, 0.03492058262054343, 0.1463016346679069, 0.016690817756170873, 0.1259572443086654, 0.049992796703008935, 0.08612655699835159, 0.03238079370930791, 0.03600973999709822, 0.028900874385726638, 0.07328279345529154, 0.07008691260125488, 0.01207386232636054, 0.030948706589697395, 0.042974547322955914, 0.09310015506343916, 0.03224945583497174, 0.04527110475464724, 0.022025124781066552, 0.02938578625617083, 0.01743312499456806, 0.060296129377093166, 0.08340190281160176, 0.0362331227370305, 0.08810284431092441, 0.010928817519015865, 0.03817467011685949, 0.022534651834575925, 0.04187140046269633, 0.05284211685648188, 0.12288806290598586, 0.007862742004363099, 0.05873868052731268, 0.023993267022888176, 0.04837507804040797, 0.08254703032434918, 0.11705738710588776, 0.02817084783600876, 0.05808071466162801, 0.0058317254752182635, 0.018441386418999173, 0.044228149781702086, 0.06526459284941666, 0.04679656332882587, 0.03889348095981404, 0.012661771306738956, 0.012270563929632772, 0.018184193286288064, 0.06825860211392865, 0.006852525484646321, 0.05527609777345788, 0.059098599886056036, 0.057583995221648365, 0.010333629925298737, 0.05318258081388194, 0.07604566824738868, 0.033484664163552225, 0.026584844854369294, 0.03805363696301356, 0.023067562106007244, 0.03582382829335984, 0.03405300456506666, 0.04648594855098054, 0.04116732867259998, 0.06411435300833546, 0.06765358106349595, 0.03757698148547206, 0.06202518503414467, 0.03132053556328174, 0.028233909979462624, 0.08814517641440034, 0.020102964153920766, 0.04121094840229489, 0.03409299148188438, 0.055928033689269796, 0.04686234358814545, 0.06170216896862257, 0.044966382629354484, 0.02447603223117767, 0.09562155726598576, 0.041227539113606326, 0.07858694516471587, 0.029038717184448615, 0.04896300371910911, 0.0037400418523247936, 0.02104448423779104, 0.024451042263535783, 0.05412738675659057, 0.02586411927040899, 0.023109636313165538, 0.017154166525870096, 0.010670153078535805, 0.051148554412066005, 0.019379403565835673, 0.030101350203040056, 0.005744783338741399, 0.026207112096017227, 0.01907515641505597, 0.037910461833234876, 0.0321902844007127, 0.052983195419074036, 0.026249883921991568, 0.03815715172095224, 0.05058696755440906, 0.059816052598762326, 0.02123877107806038, 0.012627836604224285, 0.010107360230904305, 0.059470297128427774, 0.016782382081146352, 0.0345979710255051, 0.03138832333206665, 0.0013787767966277897, 0.09067820807103999, 0.06292323567322455, 0.058242001905455254, 0.0877959885110613, 0.06355147110298276, 0.07513158721849322, 0.015890337272139732, 0.08749400119995698, 0.018619080692587886, 0.012674749614234315, 0.05570004592300393, 0.1155904728511814, 0.026014122158812825, 0.026073937406181358, 0.01782030343747465, 0.10639186410116963, 0.056732172961346805, 0.029795900773024186, 0.02151789281924721, 0.037075942746014334, 0.028479931934271008, 0.01519149576779455, 0.0560079295973992, 0.025354070858156774, 0.0730873340216931, 0.016426685542683117, 0.04849639692110941, 0.03101244779827539, 0.10935736005194485, 0.011368801624485059, 0.05926451070990879, 0.05383731462643482, 0.057913831624318846, 0.03730234602699056, 0.029925732087576762, 0.027609466924332082, 0.015252206230798038, 0.034574426390463486, 0.03892320026352536, 0.06206481200933922, 0.036151056046946906, 0.026238196951453574, 0.029942877554276492, 0.02699840479181148, 0.020952235281583853, 0.025129676942015067, 0.04724272024759557, 0.06055548401491251, 0.045122430310584605, 0.04281352725229226, 0.04227860576065723, 0.0164703553673462, 0.01894711924251169, 0.03469039067567792, 0.08318204156239517, 0.014459069298027316, 0.028344638412818313, 0.03805379652476404, 0.047269370770663954, 0.026046093880722765, 0.009214579768013209, 0.01021464602672495, 0.012993049331271322, 0.022590114385820925, 0.0058360679668112425, 0.052400327476789244, 0.017819596541812643, 0.026775471051223576, 0.006897507519170176, 0.04816613749426324, 0.03964462717704009, 0.02494617165211821, 0.007430742480210029, 0.048764063612907194, 0.0505953464016784, 0.03185224355547689, 0.041839606856228784, 0.08402588573517278, 0.0329054772737436, 0.04595923521264922, 0.0378055295732338, 0.0530495768180117, 0.056154874837375246, 0.042285830568289384, 0.006136012980277883, 0.06273565042647533, 0.023019803047645837, 0.07396011453238316, 0.04323292974731885, 0.06609274802030995, 0.07205473200883716, 0.2350211443263106, 0.09346235281554982, 0.2357194756041281, 0.12271058571059257, 0.07622215096489526, 0.06159630160254892, 0.09132274848525412, 0.17615603894228116, 0.3099259460577741, 0.14375409402418882, 0.1304266505758278, 0.11384591372916475, 0.1176013368240092, 0.1288239232962951, 0.19422976911300793, 0.22216554352780804, 0.18100512796081603, 0.13273737189592794, 0.1386410230770707, 0.14592723600799218, 0.11441368638770655, 0.10166980107896961, 0.15065384097397327, 0.2055209077661857, 0.14944354654289782, 0.1790384663036093, 0.1315172662725672, 0.17253026162507012, 0.13695349800400436, 0.12996930949157104, 0.21721593802794814, 0.11872218019561842, 0.12918276654090732, 0.151167050935328, 0.10655532954842784, 0.11617973068496212, 0.1495090633397922, 0.15772459359141067, 0.0692695334146265, 0.15496234962483868, 0.13206068164436147, 0.13690068677533418, 0.10648311857949011, 0.08814373664790764, 0.14340748137328774, 0.12437176454113796, 0.1610266460920684, 0.2151392010273412, 0.20506965229287744, 0.1539212351781316, 0.19194575026631355, 0.09684713251772337, 0.09104773082071915, 0.15858241240493953, 0.11209864576812834, 0.16691307944711298, 0.08723464285139926, 0.12403542321408167, 0.269439474795945, 0.12844346871133894, 0.10994304073392414, 0.11086450613220222, 0.2332063260837458, 0.17149578197859228, 0.12254052999196574, 0.13560964667703956, 0.15006243833340704, 0.07999320368980989, 0.2828477678121999, 0.10047595264040865, 0.11032952155801468, 0.14971833414165303, 0.14666359493276104, 0.0823889825551305, 0.11028726366930641, 0.10626239643897861, 0.13548504008213058, 0.11051879147998989, 0.0979218736756593, 0.11077622024458833, 0.20926496858010069, 0.11575698852539062, 0.1425153753370978, 0.06853630635305308, 0.06564399358467199, 0.20672438928158954, 0.14949251344660297, 0.16442424268461764, 0.19354528631083667, 0.14460368984146044, 0.0924439777736552, 0.06998827375355177, 0.19184345263056457, 0.1272859558230266, 0.05918479662796017, 0.17264336493099108, 0.14736262382939458, 0.07459506639861502, 0.1798270278959535, 0.13244826084701344, 0.18987269431818277, 0.13711209496250376, 0.2290802076458931, 0.13101189339067787, 0.14009175851242617, 0.10410708826384507, 0.07152773294365034, 0.1657342372345738, 0.10666241403669119, 0.19912625168217346, 0.12633530917810276, 0.1481085119303316, 0.07671837316593155, 0.153817527461797, 0.12702096457360312, 0.09721322654513642, 0.13940277829533443, 0.1845325855538249, 0.16165040637133643, 0.1381186698563397, 0.14479793957434595, 0.1105478465615306, 0.14264967438066378, 0.08893040576367639, 0.20954499574145302, 0.13524557871278375, 0.1547595948795788, 0.09921465039951727, 0.12556613248307258, 0.11808788141934201, 0.08104197710053995, 0.15280887455446646, 0.1466885459376499, 0.1124470321519766, 0.12406824098434299, 0.10889280529227108, 0.11897748641786166, 0.11249753530137241, 0.148234884836711, 0.18801125435857102, 0.15560920553980395, 0.1657533846446313, 0.10761363955680281, 0.1455281238304451, 0.20632590050809085, 0.09066321668797173, 0.07881700352299958, 0.10299803761881776, 0.16760582977440208, 0.13880074810003862, 0.2684916334692389, 0.12278088193852454, 0.1920268521644175, 0.13033536641160026, 0.17643907922320068, 0.12230913576786406, 0.14083255548030138, 0.08515022462233901, 0.18330179300392047, 0.08509055594913661, 0.10575889376923442, 0.1593546912772581, 0.1481088830041699, 0.17559194733621553, 0.15356528630945832, 0.1231715855828952, 0.1730205095373094, 0.12656362348934636, 0.09912896202877164, 0.20367340533994138, 0.16915256943320855, 0.14179660531226546, 0.20542303333058953, 0.11446385557064787], [0.04457034665392712, 0.024491372423653957, 0.024167907358787488, 0.043186274633626454, 0.049806027818704024, 0.026160885572608095, 0.02555633949668845, 0.026081279102072585, 0.05416412306658458, 0.010578331784927286, 0.02053679771051975, 0.0417490611289395, 0.0591012419317849, 0.06210998282767832, 0.008670841561979614, 0.038601668493356556, 0.028208081384946126, 0.0167632049851818, 0.0728551456995774, 0.013926290757808601, 0.027329358126735315, 0.01712890196358785, 0.020103292554267682, 0.05431664925708901, 0.04411397407238837, 0.04090694616024848, 0.05120233414345421, 0.03166273243550677, 0.04596583661623299, 0.03730862830707338, 0.03991022698755842, 0.037493912896024995, 0.11048575106542557, 0.027374618002795614, 0.03859612093947362, 0.020071241051482502, 0.03207471345376689, 0.04359654129075352, 0.04368372137832921, 0.006449711845561978, 0.04645988061383832, 0.03196149140421767, 0.025061260203074198, 0.03988393640611321, 0.014537382576236269, 0.04903450964775402, 0.013225664388301084, 0.08611311670392752, 0.04551475554762874, 0.03255158044339623, 0.019177522699465044, 0.014078013573453063, 0.014721350780746434, 0.06357252583256923, 0.07046204598736949, 0.027789467421825975, 0.013504967027984094, 0.05332371874828823, 0.08937722319387831, 0.060011953610228375, 0.09264685868402012, 0.031143418309511617, 0.03585685386497062, 0.04625160057912581, 0.03387378703337163, 0.014423034317587735, 0.008249626371252816, 0.022341721269185655, 0.039561948215123266, 0.04990824752894696, 0.021625795525324065, 0.029576657361758407, 0.07045656151603907, 0.014189841313054785, 0.05664307813276537, 0.02982046215038281, 0.031066101364558563, 0.0280079928052146, 0.012315356252656784, 0.03473360964562744, 0.07958223941386677, 0.01783186053216923, 0.04417697127792053, 0.03324976329167839, 0.04282418449292891, 0.09300170917413197, 0.07481148408260196, 0.03400191882974468, 0.0556421992223477, 0.060546541135408916, 0.05806773820950184, 0.019309263188915793, 0.0334663219837239, 0.022277213793131523, 0.10150131129194051, 0.030648248102806974, 0.014063996259210398, 0.022222077786864247, 0.09823629196034744, 0.05885901606234256, 0.04507312572968658, 0.06047774033504538, 0.06821333852712996, 0.008636455077066785, 0.07518382699345239, 0.02209709826274775, 0.029721398423134815, 0.044331623721518554, 0.047965857811504975, 0.012542505392048042, 0.0932177335198503, 0.046541487172362395, 0.02643267118401127, 0.04092332164873369, 0.04609104806149844, 0.08453975620795973, 0.07594722977955826, 0.02420791282929713, 0.0494121292285854, 0.1252662602928467, 0.04383692292321939, 0.007850110650906572, 0.03875364920531865, 0.040596509497845545, 0.03547726388205774, 0.0564837872661883, 0.0753245827218052, 0.015469119298359146, 0.025208596925949678, 0.042280527923139744, 0.008887288931873627, 0.018440423482388724, 0.03302427656308282, 0.04176204129180405, 0.04917918020510115, 0.017988132713071536, 0.01762498686730396, 0.06250542137422599, 0.0828700649435632, 0.057951759081333876, 0.01799091576685896, 0.07427065880619921, 0.032093285699374974, 0.05087616766104475, 0.021740405391028617, 0.03030168740224326, 0.04848349097301252, 0.025514100161672104, 0.032781523768790066, 0.07224413551739417, 0.031226108403643593, 0.05266549313091673, 0.05206830544921104, 0.017927308144862764, 0.043222632448305376, 0.05952918283583131, 0.06001160109008197, 0.06296602048678324, 0.01335671282504336, 0.011478599590191152, 0.08842011986416765, 0.06455769718741067, 0.03039741888642311, 0.023690134948992636, 0.13413577107712626, 0.01893933782412205, 0.03458160295849666, 0.05843045175424777, 0.03107573815213982, 0.037103428185218945, 0.012393485849315766, 0.011953844059462426, 0.016099212880362757, 0.03613390872487798, 0.03959118141210638, 0.015343325267167529, 0.037824895916855894, 0.035134016870870255, 0.021268918972054962, 0.008723382834432414, 0.01714856145554222, 0.06394253097823821, 0.030500889115501195, 0.045273394280229695, 0.04969672801962588, 0.014254232828534441, 0.031199532095342875, 0.0755910953739658, 0.03606914891861379, 0.02463701704982668, 0.044557800647453405, 0.025497464921500068, 0.029121782063157298, 0.021792352017655503, 0.03046895821171347, 0.024972721985250246, 0.04179471805400681, 0.03077898483752506, 0.047404029755853117, 0.021011510616517626, 0.021206643505138345, 0.01886767418909585, 0.012680827803706052, 0.026354022083978634, 0.05548536115384195, 0.06305558286840096, 0.04228063553455286, 0.07725510920863599, 0.06410030415281653, 0.05440178843855392, 0.02526654196117306, 0.0256342334614601, 0.01944147123140283, 0.01964872524695238, 0.020941015864082146, 0.01946690277691232, 0.0782241759588942, 0.02354468328121584, 0.03316363334306516, 0.04082341001776513, 0.030566654531867243, 0.02869847958208993, 0.03095185886195395, 0.07336183960433118, 0.026430691505083814, 0.019728730621864088, 0.054542829893762246, 0.021510382284759544, 0.03197918049409054, 0.01976302155526355, 0.06735552713507786, 0.034243729096488096, 0.03559607059287373, 0.03634511282143649, 0.03726091934368014, 0.029412744770525023, 0.06563939226907678, 0.037647229473805055, 0.02398018852545647, 0.038668699271511286, 0.0186021912668366, 0.041299052463728, 0.0077086512737878365, 0.007873017966630869, 0.04896522645140067, 0.06146573927253485, 0.010803556906466838, 0.011518191313371062, 0.03516701646731235, 0.02630174705700483, 0.04702179772721138, 0.05465988884679973, 0.0562973709020298, 0.010917625932052033, 0.02742851647781208, 0.017628541754675098, 0.052331374536152, 0.034698431845754385, 0.016286447462334763, 0.021762009309895802, 0.011697585105139297, 0.14047852135263383, 0.02680686018720735, 0.06767462837160565, 0.04506551871600095, 0.07419163492158987, 0.06018000181938987, 0.016412866752943955, 0.025466845763730817, 0.021714459908253048, 0.07610381551785395, 0.022061658855818678, 0.015040351827337872, 0.05413476741523482, 0.0419938845152501, 0.07543114028521813, 0.006289509065027232, 0.030969865219958592, 0.007808509562892141, 0.03409547025512438, 0.054833132089697756, 0.04769299237523228, 0.0059465821050253, 0.03628041238698643, 0.04484098564716987, 0.058098155132029206, 0.041899947173078544, 0.01997194911382394, 0.004448114514161716, 0.003354558984938194, 0.0689555455755908, 0.04853017577261198, 0.03601121687097475, 0.04578950232826173, 0.05943473712250125, 0.07714494480751455, 0.08690810529515147, 0.04005398841400165, 0.03316163696581498, 0.10558064474025741, 0.04698760327300988, 0.04525784257566556, 0.005169930127522093, 0.04307002091081813, 0.012096786340407562, 0.00536038702193764, 0.022247438828344457, 0.011018571003660327, 0.016199692254303955, 0.008371635449293535, 0.10185451421421021, 0.08092398304142989, 0.06614364450797439, 0.0404375674406765, 0.0909901550039649, 0.027305008261464536, 0.02032063977821963, 0.062036183662712574, 0.030705098470207304, 0.0673056548112072, 0.059041818167315796, 0.02857742045307532, 0.04163830672041513, 0.028048875865351874, 0.03346460762259085, 0.018567586776043754, 0.07930362233310007, 0.022613521723542362, 0.04713879730843473, 0.05551906207983848, 0.03875397946103476, 0.09011574918986298, 0.011442753857409116, 0.03729260162799619, 0.018821143385139294, 0.009653197394072777, 0.05440322078356985, 0.05971586266241502, 0.036616601573769, 0.03933253181457985, 0.09826783323660493, 0.009516504924249602, 0.035432902004686184, 0.035132480625179596, 0.05552527385589201, 0.07898162672063336, 0.04352486466814298, 0.03854135786241386, 0.012014041512884432, 0.03562958969268948, 0.0305679031953332, 0.046236586931627244, 0.20302764780353755, 0.09714662621263415, 0.1689744391478598, 0.14072988677071407, 0.09487075614742935, 0.13164387666620314, 0.11569593945750967, 0.1152830159117002, 0.20555158815113828, 0.11276979217655025, 0.1624834819813259, 0.16702912165783346, 0.12099971267161891, 0.10587646480416879, 0.12764548184350133, 0.17962563870241866, 0.18323197175050154, 0.21844526112545282, 0.10681584564736113, 0.09750345081556588, 0.17198058252688497, 0.08387769368709996, 0.12659004394663498, 0.148445580562111, 0.13121227326337248, 0.15946026920573786, 0.08910604985430837, 0.10731110305641778, 0.14478990953648463, 0.1134325671591796, 0.13248876726720482, 0.16999768267851323, 0.23416526993969455, 0.24837214354192838, 0.10642665598425083, 0.08219501483836211, 0.1524307206273079, 0.1219373123603873, 0.08185885904822499, 0.07060229705530219, 0.10676707170205191, 0.09576643191394396, 0.10348815936595201, 0.1380736957071349, 0.13470254925778136, 0.10454445815412328, 0.1377208044868894, 0.18416115548461676, 0.14890161546645686, 0.09374321860377677, 0.07364544391748495, 0.12996386212762445, 0.11009007503162138, 0.13931144960224628, 0.1722537077148445, 0.15502023714361712, 0.13698370341444388, 0.13979687355458736, 0.20088334567844868, 0.1842213881900534, 0.14576969289919361, 0.16453556483611465, 0.11235457539441995, 0.16933571663685143, 0.14855418645311147, 0.09518043952994049, 0.08497861781506799, 0.0990103445656132, 0.06500377246993594, 0.15156421868596226, 0.09230650975950994, 0.10788036743178964, 0.15034476615255699, 0.2257975548855029, 0.11958235161728226, 0.09815004697884433, 0.18418157938867807, 0.12407686474034563, 0.10864440846489742, 0.21807230223203078, 0.12420071434462443, 0.2262295293621719, 0.0942045079136733, 0.11028062144760042, 0.09543722262606025, 0.2270521703758277, 0.19708490028278902, 0.1482491786009632, 0.1570910814916715, 0.22797645593527704, 0.19752631487790495, 0.1118434286036063, 0.09582869068253785, 0.09431951111764647, 0.2103230485226959, 0.08559133493690751, 0.12051424419041723, 0.20500542683294043, 0.31359102751594037, 0.1181526189611759, 0.1672836040961556, 0.20821621001232415, 0.12905769981443882, 0.12184895225800574, 0.1683851145207882, 0.13682728837011382, 0.08491586180753075, 0.08012661957764067, 0.16944291244726628, 0.089310496696271, 0.13045835512457415, 0.12364781432552263, 0.14150679664453492, 0.0881555219530128, 0.1333072077250108, 0.17832135868957266, 0.10579404930467717, 0.09807230700971559, 0.20499913342064247, 0.24619670090032741, 0.13332406932022423, 0.1444375971914269, 0.12235900067025796, 0.22470921016065404, 0.14420530496863648, 0.19041253253817558, 0.11923671860131435, 0.1649845196516253, 0.08154771363479085, 0.10125373824848793, 0.15382214362034574, 0.11146795382956043, 0.11369729865691625, 0.12476406380301341, 0.17426167731173337, 0.13825184083543718, 0.12574726104503497, 0.12187057101982646, 0.20074266416486353, 0.15193855797406286, 0.09512460033874959, 0.1732893005828373, 0.12175288866274059, 0.1784404437057674, 0.13995597517350689, 0.095440154109383, 0.13616667303722352, 0.07866336411098018, 0.10030531804659404, 0.21548364660702646, 0.17693170200800523, 0.16731891548261046, 0.12889405625173822, 0.08564934119931422, 0.116686135152122, 0.1457579669659026, 0.12785947270458564, 0.18354823056142777, 0.07871385241742246, 0.11465057992609218, 0.24195802834583446, 0.16458580823382363, 0.156735043565277, 0.11468657408840954, 0.28811936150304973, 0.08492842636769637, 0.08723847233341075, 0.13762644783128053, 0.2625618438469246, 0.17962166079087183, 0.1685171722783707, 0.08985832042526454, 0.1163975361851044, 0.08108430920401588, 0.12073385310941376, 0.08833346670144238], [0.05486620219016913, 0.04290224729629699, 0.0562644826277392, 0.04340581675933208, 0.04044955683639273, 0.04850036741117947, 0.10137478253454901, 0.02887635197112104, 0.014913371287548216, 0.04807459728908725, 0.07369485610979609, 0.07501136671635322, 0.035711945820366964, 0.04861145578615833, 0.050594092172104865, 0.051613632385851815, 0.021597781305899844, 0.04829226549190935, 0.0507099673995981, 0.020209582944517024, 0.053243303336785175, 0.04291794371965807, 0.030416349218285177, 0.04369302048871759, 0.019078444129263517, 0.11100088318926282, 0.04953030511387624, 0.00960333341936348, 0.03658228466520086, 0.06396077296813019, 0.05796585988719016, 0.04162677374552004, 0.03170959163981024, 0.03775070341362152, 0.04386672386317514, 0.06836308908532374, 0.01826051389798522, 0.03976445434091147, 0.07816651850589551, 0.04323087399825454, 0.04449974243470933, 0.03125582399661653, 0.08783302910160273, 0.07199053623480722, 0.08281057438580319, 0.04289661439543124, 0.013718109985347837, 0.04562890528177377, 0.0163597846403718, 0.05859709359356202, 0.03767612870433368, 0.07890010921983048, 0.11681864561978728, 0.10404478496639058, 0.04201492069114465, 0.08569035227992572, 0.060155147293698974, 0.06457777228206396, 0.024052709341049194, 0.0011566995408429648, 0.04357783174782526, 0.04282170943042729, 0.045705365046160296, 0.039839856544858776, 0.029463318423950113, 0.054936632004682906, 0.04646776964364108, 0.03308184866909869, 0.08234340726630762, 0.08376840502023697, 0.04559783155855257, 0.04200061579467729, 0.06512204854516312, 0.03112889447947964, 0.04775214154506102, 0.004501603416429134, 0.043559433906921186, 0.06331641809083521, 0.004416283800310339, 0.038707372586941347, 0.04994380011339672, 0.03838329896098003, 0.059140931989531964, 0.015934732546156738, 0.054361604852601886, 0.028605115548998583, 0.062157402353477664, 0.04188232858723495, 0.007250097705764347, 0.05795705801574513, 0.015690155923948623, 0.09271370392525569, 0.04237882167217322, 0.09506006317678839, 0.014385945487447316, 0.0270825903135119, 0.031502079727943055, 0.037293109999154694, 0.03877526425640099, 0.02383686682151165, 0.029520836724259425, 0.02301476757565979, 0.06592164587345906, 0.04535569103609305, 0.04648322115826886, 0.04562871974485461, 0.05254745454294607, 0.04426708284881897, 0.05878185867913999, 0.031412213065777905, 0.02403979226073716, 0.04091725830221549, 0.029083930676279124, 0.0691293491399847, 0.019073263938480522, 0.04515353371971287, 0.031136315956246108, 0.03561289508070331, 0.02548961670981953, 0.027877933280251455, 0.07108343139407225, 0.026687738063628785, 0.02226901862741215, 0.06917939957929775, 0.07224403161671944, 0.05492924763530027, 0.007070929805195192, 0.03318384573503863, 0.04668545268941671, 0.03183170461852569, 0.12043742448440753, 0.028449372148315888, 0.03783934182138182, 0.10489238440641202, 0.06807391124311835, 0.048952943907352164, 0.0575832122558495, 0.038170558618730865, 0.03676179905596655, 0.017901878454722464, 0.012845798883063253, 0.028786335024051368, 0.028303111539571546, 0.03162213324685581, 0.0772880828299094, 0.057164878453477286, 0.04018724102934357, 0.021024199486419093, 0.053695779643021524, 0.011757282536564162, 0.07702826434979215, 0.10694412587326951, 0.020196652876620647, 0.06767068014596589, 0.0756788691796828, 0.05212160278460942, 0.02579354102635989, 0.03891642816597596, 0.07002973754424602, 0.0535725979716517, 0.08347970215254463, 0.0689159297326114, 0.028242930784472264, 0.0019054120934924867, 0.029605261588585563, 0.021072696981718764, 0.03488642527372576, 0.028430271122488193, 0.004813693676624098, 0.017878732724057045, 0.007472853330909857, 0.02502656108845258, 0.03848948916129302, 0.054236519572441466, 0.035065861738985404, 0.07439691296895035, 0.05439782908069901, 0.04869804957706947, 0.015479486173717305, 0.03276316303526983, 0.08656091376906261, 0.02007540449994849, 0.018140170941478573, 0.027421935483289417, 0.05028253115597181, 0.04034234989376273, 0.08150232388288714, 0.038194945591385476, 0.05951083323452622, 0.03015145630342886, 0.016036338129197247, 0.041705790208652616, 0.01347777009868878, 0.032799183172755875, 0.13794552680337802, 0.03764196764677763, 0.05071322913863696, 0.023216885929286946, 0.011263227406743681, 0.03537670287187211, 0.025202442666341085, 0.05088000827527139, 0.026287323416909203, 0.014205528459569905, 0.04720337899925653, 0.026552323943178635, 0.06331005788524635, 0.0316527653922094, 0.03812327267951332, 0.05407872042269446, 0.03749933799554128, 0.024886931569199078, 0.0030288285142887617, 0.01963170408998849, 0.03009893451235257, 0.034184305332018994, 0.026557578348729294, 0.0989989897061605, 0.044333805635687895, 0.04093764509889297, 0.08552318351576105, 0.03756852100195829, 0.009240531744580949, 0.03681261761812493, 0.02359234400501009, 0.06662819272605702, 0.02043465407041367, 0.07207644724985585, 0.025837578214122914, 0.04023959583719261, 0.015065761108417064, 0.01570951299072476, 0.027557201174204238, 0.10374735444202088, 0.060341734351823106, 0.013543588393076789, 0.05514082651643548, 0.048219516465906054, 0.02649911752087064, 0.008704521151230438, 0.025008699449244887, 0.1195771417405922, 0.035163992215530016, 0.0372544218407711, 0.035808755274047144, 0.09800134284887463, 0.04102268037968315, 0.028978404698136728, 0.04988786815374624, 0.04325522015278693, 0.03412974634557031, 0.04687989166995976, 0.03703309856064152, 0.03010181404533796, 0.008210158030124148, 0.02921635765233077, 0.04294328064133879, 0.00954993125560577, 0.03114017512416467, 0.03841766781988554, 0.035667903066496365, 0.027632191486191005, 0.0032622796470604953, 0.05827958426380064, 0.016141993983183056, 0.02736105896474328, 0.05338694973033853, 0.02655365053215064, 0.042817148932954296, 0.00469501962470531, 0.06842109534773044, 0.04438175579707604, 0.0107218983976054, 0.03264910606958438, 0.04936668381560594, 0.010573543077043723, 0.04031366959679872, 0.044854255247628316, 0.09308230641181581, 0.054859077572473325, 0.018639241134223994, 0.056285630125785246, 0.02648774410772603, 0.02830884277500445, 0.06284741044510156, 0.06974291973165236, 0.03118154243566096, 0.011022588805644773, 0.015337003096647095, 0.11391889653168619, 0.055402155267074704, 0.042540190552244894, 0.023404103812936228, 0.0601617375650676, 0.017744947617757134, 0.03832869173493236, 0.04796185763552785, 0.11245659101405181, 0.03637491747213062, 0.018577357150206808, 0.02205850658356212, 0.0026780626194522483, 0.03487216861685738, 0.017458638176321983, 0.007620255455549341, 0.020906348290736787, 0.05698373875929974, 0.03959067675168626, 0.02459493171045324, 0.057687309599714354, 0.04296629093005322, 0.05324153331457637, 0.02375922333158087, 0.03542883503541816, 0.014861880154057872, 0.0267612793322769, 0.0016645551386318402, 0.061739569500787184, 0.018006662285188213, 0.020846419865847565, 0.040545787414885126, 0.039642278279643506, 0.017153441076516174, 0.026015743751486298, 0.05616736147203483, 0.043692515828297473, 0.03460908839770127, 0.054960833440418355, 0.07560049096355215, 0.0421277605346404, 0.10617902356898412, 0.035592404383351095, 0.015337600525526796, 0.04868764466664288, 0.04391345690237358, 0.028315034141996875, 0.06315163904218934, 0.06517008776427247, 0.028233850607648492, 0.08617036597570404, 0.10719048921600915, 0.03306065664219204, 0.034884384367614985, 0.017762952120392583, 0.008280986749014119, 0.011850333939946722, 0.02204756918217754, 0.0421909692522604, 0.014183949588186806, 0.10930635966360569, 0.018716841950663365, 0.019467370329948608, 0.2003583058831282, 0.16245219303527847, 0.1833975300542079, 0.09505170659394935, 0.2090453077107668, 0.14773807633901015, 0.20160385232884437, 0.2355056331725791, 0.08773468711297028, 0.22467283008154482, 0.10346661481889896, 0.22911692911293358, 0.13493121979990974, 0.12660908745601773, 0.11598315060837194, 0.1252831070451066, 0.10716343793319538, 0.12694004079094157, 0.15864438173593953, 0.1472314418060705, 0.12588228739332408, 0.1598259698948823, 0.11920847988221794, 0.13334225193830207, 0.07857425443944521, 0.1294167953892611, 0.16841258882777765, 0.1158172360737808, 0.17180792929138988, 0.15675986098358408, 0.13720020273467526, 0.1689699714188464, 0.12415637844242156, 0.10604951879940927, 0.18646870041266084, 0.14164474705467, 0.1479002949781716, 0.13077718176646158, 0.12650533521082252, 0.11126631230581552, 0.15080547658726573, 0.15115860529476777, 0.150859460409265, 0.1367748185293749, 0.20529539877315983, 0.11170097335707396, 0.19761661940719932, 0.07775447811582126, 0.10347024392103776, 0.09181931949569844, 0.10445136314956471, 0.18806243286235258, 0.17688551073661074, 0.245602285140194, 0.10725828440627083, 0.14635938860010356, 0.21192445477936417, 0.19397987314732745, 0.18587440339615569, 0.15157952177105471, 0.1626032349304296, 0.11644924903521314, 0.08881300542270765, 0.1435827766545117, 0.09217318292940035, 0.25056187994778156, 0.12973183707799762, 0.11725289848982356, 0.1250992770656012, 0.24742047273321077, 0.09862643899396062, 0.06881987355882302, 0.15322894498240203, 0.09692119143437594, 0.20615093177184463, 0.15595231525367126, 0.17528541065985337, 0.12237451897817664, 0.1386616102536209, 0.2130504115484655, 0.14162467938149348, 0.13542063650675118, 0.1526588122942485, 0.10974967415677384, 0.11567486988496967, 0.12675548350671306, 0.15737811452709138, 0.12680652842391282, 0.1054907038633246, 0.16757700475864112, 0.109033494227333, 0.11977227462921292, 0.15975887974491343, 0.25142582890111953, 0.1289925689343363, 0.14230187429348007, 0.15090679458808154, 0.16649281606078148, 0.13049503206275403, 0.09091988846193999, 0.14550545864040032, 0.20301759912399575, 0.15950787055771798, 0.1865588268265128, 0.11728723766282201, 0.20218217832734808, 0.17276547790970653, 0.21889672440011054, 0.16361319401767105, 0.11656146918539889, 0.10229006584268063, 0.17838944331742823, 0.0916746526490897, 0.2246829232899472, 0.09647606610087678, 0.15401050070067868, 0.13821580214425921, 0.11845169705338776, 0.09568078065058216, 0.14359321125084534, 0.16463327599922195, 0.28502365574240685, 0.0828688255569432, 0.19292584533104673, 0.15006962232291698, 0.09883002494461834, 0.09768436415470205, 0.1649705969612114, 0.13456931890686974, 0.09262405990739353, 0.30377609480638057, 0.1251063571544364, 0.07786376678268425, 0.3083791915560141, 0.15978549316059798, 0.10596486201393418, 0.15501560614211485, 0.060349868290359154, 0.10209311469225213, 0.10037009269581176, 0.0627652695402503, 0.16615822620224208, 0.088968425989151, 0.14627136988565326, 0.1278512051794678, 0.1757119080866687, 0.1341392591712065, 0.11314519273582846, 0.08522227231878787, 0.14534882095176727, 0.18324650300201029, 0.19286582042695954, 0.16738259175326675, 0.09157380220131017, 0.18002130731474608, 0.13992732827318832, 0.10722862076363526, 0.15076406474690884, 0.16594840621110052, 0.09389796381583437, 0.16638309694826603, 0.17410253116395324, 0.16918753943173215, 0.08827399098663591, 0.21310631011147052, 0.13997110014315695, 0.09353095694677904, 0.13811032811645418, 0.12374643090879545, 0.06558644003234804, 0.2501167100854218, 0.09488131690886803, 0.14628190838266164, 0.14972013013903052, 0.08932953278417699, 0.10748680651886389], [0.055606850728509016, 0.05493265409313608, 0.027468904154375196, 0.06518609588965774, 0.023880972657934763, 0.017656849122431595, 0.05637196416500956, 0.008409880174440332, 0.015476636326638982, 0.0019329059978190344, 0.044777791772503406, 0.018564297206467018, 0.01459165861888323, 0.07744380025542341, 0.034089113760273904, 0.06432367576053366, 0.019440641881374177, 0.028920461518282536, 0.03171608172124252, 0.012855937548010843, 0.07969641883391887, 0.011161793445353396, 0.021035468998888973, 0.038449405765277334, 0.04658824247599114, 0.036408985761227086, 0.046193876332836226, 0.05900770906009711, 0.032831615026225336, 0.04678581331972964, 0.04506958197453059, 0.05955897635431029, 0.08892838712199591, 0.017385527353326324, 0.04445655315066688, 0.08386090630665421, 0.051912116759922355, 0.03419624648813624, 0.062492344732163474, 0.060718619206454605, 0.0655295024625957, 0.046689708906342275, 0.024239903104898985, 0.03447266681178007, 0.01885574787593214, 0.03467675742285792, 0.0498497885564575, 0.03245342770242132, 0.07654195724171586, 0.060273761046119034, 0.07261304228450172, 0.0504658304998884, 0.06005856048432179, 0.03953460378397722, 0.04261775982740801, 0.027794686575361993, 0.059635881407302804, 0.06530509926960804, 0.03531698224833235, 0.014915104202373186, 0.03327031336084474, 0.012476503416110063, 0.0473229427007027, 0.04256088534020819, 0.027375708959880285, 0.0035097926229354925, 0.039922424184624106, 0.0747371134639252, 0.02200234455813188, 0.021789014208479784, 0.08596929590567015, 0.05523436680960003, 0.014092073561187135, 0.07973789004608989, 0.006311778133749613, 0.06515138564282097, 0.05137802647368517, 0.03912294559995644, 0.021499042268260382, 0.022906618105480447, 0.026301084690203425, 0.03446548282227013, 0.029735514071944635, 0.06138564298453275, 0.0513073740148684, 0.04032505785289686, 0.05213693184487056, 0.04712114532594569, 0.023715457027719822, 0.03465675654297229, 0.04492707477766089, 0.031464393468922935, 0.037180637518758886, 0.016965811300906353, 0.016990350413834676, 0.037019483861513436, 0.046976534140412696, 0.04589062365994323, 0.00442705514615227, 0.07571698588435538, 0.026990068618033547, 0.041804436477832496, 0.07560776401078328, 0.024052432891039643, 0.049124873548862524, 0.024841016747814137, 0.02278445132105844, 0.10829497565282509, 0.01719165054964833, 0.038225974785746075, 0.04192295004031621, 0.07533420095569454, 0.01726434020383749, 0.015547783241345314, 0.07405294236377813, 0.02636438061017543, 0.03946566939703189, 0.11156166481669061, 0.023417358570441138, 0.034079224642482586, 0.023576248677272815, 0.039251344569493085, 0.057213088366552256, 0.04500819894019514, 0.03151491888274904, 0.015691245025664102, 0.01849116411904106, 0.08654356977785937, 0.07480188811314292, 0.08496227572322823, 0.07308806874789298, 0.006334410390991252, 0.0627791477018036, 0.0375072567112511, 0.04205001314403489, 0.026298260818293784, 0.02620936451421585, 0.049166919925482944, 0.07432952595991082, 0.07979533969773911, 0.0066583290936250705, 0.030801657449046616, 0.08931463788030669, 0.042848912853514776, 0.0724561967945192, 0.06123916529759299, 0.07018919539405033, 0.08757983800023794, 0.04850547709793318, 0.04200672367005609, 0.009953669796232134, 0.0364120805170387, 0.04401939477247652, 0.02779700207611313, 0.025133350573014468, 0.02445999070914695, 0.02155761256290134, 0.02580792199296411, 0.034223498150822707, 0.05125470750499517, 0.05497507154359482, 0.0330169107473921, 0.022953495863475837, 0.03808902998571284, 0.06253939689486288, 0.07106097400537692, 0.03966770054830704, 0.022063792530389037, 0.04569727934722323, 0.042741383076645434, 0.06759543379303068, 0.03187365822668653, 0.029917861611465923, 0.02437942872347776, 0.010906348998105386, 0.049069917513406835, 0.005507330406544497, 0.046612707374151796, 0.02553066675318405, 0.04383999912533909, 0.03867411694955081, 0.04817163309780881, 0.0494102701486554, 0.017027060748660006, 0.023957449120644014, 0.01604253877303563, 0.059149563167011365, 0.0422587162029231, 0.024938683382060844, 0.046269582817330956, 0.021211404382484034, 0.04522280207311269, 0.031089662697922904, 0.030154632695484906, 0.022210724782780744, 0.043384598757256754, 0.044915764447068796, 0.042191499887849204, 0.03941075046896003, 0.019428337072895374, 0.058046731719514355, 0.0006430916607769177, 0.05937274552707095, 0.01995281840208918, 0.033410531032131985, 0.02421877972665243, 0.014337489737954456, 0.03996447798272129, 0.05760406289482489, 0.027836198605655227, 0.06483798410044983, 0.036789176883758046, 0.12989580718567595, 0.03127228112134617, 0.02504983112885384, 0.019835119346680585, 0.061586724186781794, 0.03448444098467007, 0.009219332296197535, 0.06806822639191523, 0.033910920392372645, 0.05612068409391213, 0.05594981572357938, 0.0711399904685095, 0.07597248506499454, 0.04220306254865136, 0.04277827523765154, 0.029910171106166672, 0.01588045372045599, 0.026344782345404383, 0.02258852433442371, 0.06696897209621966, 0.052717654980369844, 0.016036174856708385, 0.025692683157103602, 0.04361653845990077, 0.036358593933982775, 0.03230464935768396, 0.056174519486376084, 0.06331638098345138, 0.011323365488351556, 0.04534949781373143, 0.031844814657233655, 0.008969965110736666, 0.038089801819296554, 0.0268384756782325, 0.017552428944327403, 0.042690442060120404, 0.026011038535216358, 0.04897618797258474, 0.015060469595482573, 0.06622224536840804, 0.06905142363393679, 0.04644880034902599, 0.04282066300220322, 0.030386472208192572, 0.043058551018475555, 0.04080254082509782, 0.05406001830124296, 0.038914450342417695, 0.028439681555028073, 0.017445351877540816, 0.03010366199305281, 0.054182984749786556, 0.031176670236163773, 0.0738071727391798, 0.029515159294533078, 0.09827582616708241, 0.021276759762258735, 0.045075942180119455, 0.02948942161310697, 0.002517459079172113, 0.07341816861298867, 0.04335964775236789, 0.10678132835892029, 0.06990121983108111, 0.013492612124537118, 0.038939880032557994, 0.0470452533045318, 0.01910449907882139, 0.02477031604939839, 0.02052271916909376, 0.017758454705472104, 0.05286706415063236, 0.03838721750071272, 0.03111609799816506, 0.004121636329728062, 0.05362437390431296, 0.07308363070478663, 0.04658627949538641, 0.052761334081878886, 0.0030032520180611755, 0.0828747553168796, 0.05969095989712514, 0.042755405956995673, 0.02274219714308856, 0.03659404028439894, 0.0185441831490607, 0.05384240204875823, 0.04671043709095102, 0.024077771668089554, 0.012502856152423192, 0.005796851955892635, 0.053832880294066854, 0.04434868569660466, 0.014875510623824084, 0.029437352532113437, 0.06948247042600997, 0.03356553228513803, 0.03865527382004075, 0.016008186612452846, 0.029254476212372538, 0.07843171013519168, 0.07388093479676172, 0.027148361295985524, 0.054175066034076735, 0.009332148019893793, 0.0054126838494994445, 0.025738601689226925, 0.07639274845132604, 0.049684809127938934, 0.07698691930272616, 0.04137749376241118, 0.04446097264008131, 0.0679877627408132, 0.12416895784554072, 0.058721633395180106, 0.03946819269913249, 0.033266784448642284, 0.06824989672168158, 0.049151475832331926, 0.007798061978974147, 0.0071462304276792565, 0.04565704381093383, 0.08527267898898572, 0.015399299900309416, 0.013551643478422193, 0.02107648007950047, 0.039154820842668414, 0.009752831647347193, 0.015817289531696588, 0.017085345316445455, 0.02538424843805842, 0.05937163230555598, 0.031233860136126168, 0.045742349975625984, 0.09376491158036515, 0.03354709733685013, 0.06689209301839583, 0.04486730591452215, 0.02758375707344385, 0.10725285188527778, 0.09077511771465652, 0.15334249357692897, 0.1337936706840992, 0.12893426581285894, 0.12472882663132623, 0.09824910885072313, 0.20866927632596344, 0.09487611445365474, 0.1165251707425341, 0.09036586779984646, 0.17674098489806056, 0.1492983676143922, 0.07898205716628581, 0.12778280884958804, 0.07540483115008101, 0.111536038457416, 0.12692822579992935, 0.16749937611166388, 0.1236202435393352, 0.08799852803349495, 0.17257726925890893, 0.08543669362552464, 0.10708174231695011, 0.16050496080424637, 0.2620704530272633, 0.135472379042767, 0.12443881016224623, 0.25485790567472577, 0.15405360463773832, 0.0921827343699988, 0.15687815932324156, 0.2718345040921122, 0.22929430240765214, 0.06968104687985033, 0.1567618944682181, 0.12384066139929928, 0.21974767092615366, 0.07014295959379524, 0.11107181766419671, 0.16122218716191128, 0.21780315495561808, 0.13261280982987955, 0.16639206209219992, 0.13974159839563072, 0.1423598508699797, 0.15771723148645833, 0.1896555270650424, 0.2535952749894932, 0.1709003420546651, 0.11618006465141661, 0.19614047283539549, 0.08851160440826789, 0.14402067346964031, 0.20876005582977086, 0.12869603640865535, 0.11510294862091541, 0.12310155652812682, 0.16903539915801957, 0.07972563718794845, 0.06418663819204085, 0.14213413407560438, 0.16613274085102603, 0.13575206481618807, 0.1994044383172877, 0.12419416118063964, 0.10969827300868928, 0.14939714747015387, 0.08377153688343242, 0.13410940999165177, 0.144535441941116, 0.15446681762114167, 0.13728014688240364, 0.1737189744017087, 0.3096944553544745, 0.15622217499185354, 0.18344698677537963, 0.1604285344365053, 0.08492087872582488, 0.15502952883252874, 0.09683148804469965, 0.1279726205393672, 0.1926736338646151, 0.14260860392823815, 0.13914715294959024, 0.09272345574572682, 0.14151240728097036, 0.19340913189807907, 0.11377899427316152, 0.14060076791793108, 0.2382698215660639, 0.14636767096817493, 0.1682799225091003, 0.0894926642649807, 0.2070915445801802, 0.06209159240825102, 0.09115088934777305, 0.18140728294383734, 0.1327831920934841, 0.27830641774926335, 0.2383639258914627, 0.1330315592349507, 0.15510024066315964, 0.16103568545076996, 0.1689769624499604, 0.13454421947244555, 0.06031249744410161, 0.1399727031821385, 0.1999651754158549, 0.09662261058110744, 0.12841464369557798, 0.1768146504764445, 0.13188356067985296, 0.15759664733195677, 0.14737307326868176, 0.13093031651806086, 0.1004641005420126, 0.11510426964377984, 0.2542250615078956, 0.10314974744687788, 0.11027463973732665, 0.08103602507617325, 0.10562381547060795, 0.15990652260370553, 0.12955329118994996, 0.15508119715377688, 0.11939317817450501, 0.09180908527923748, 0.14572274463716894, 0.1312055642483756, 0.14057173510082066, 0.10662434928235598, 0.11333561298670247, 0.11731701262760907, 0.1337502253591083, 0.13705567689612508, 0.1323970378143713, 0.2092988253571093, 0.12501425662776455, 0.21661937003955245, 0.2114427712513134, 0.11701514406013303, 0.13982020667754114, 0.19667415122967213, 0.13716726622078568, 0.14636452426202595, 0.23049870418617502, 0.17422795412130654, 0.1976272024330683, 0.10642057037330233, 0.20477424783166498, 0.11649437161395326, 0.19010434829397127, 0.11662200617138296, 0.17218776047229767, 0.09217995873768814, 0.13633757480420172, 0.0944014590641018, 0.08755723960348405, 0.19220453716116026, 0.10990297960233875, 0.11086846177931875, 0.1736270371475257, 0.21577749255811796, 0.07891226559877396, 0.15695473412051797, 0.10514507826883346, 0.19588319992180914, 0.10833926702616736, 0.1403618705808185, 0.10351535907830112, 0.247272978303954, 0.12450043810531497, 0.10227557912003249, 0.13338939315872267, 0.08468977393931709, 0.2172554054413922], [0.06746742816176265, 0.035539774980861694, 0.03384232368262019, 0.01171212285044021, 0.027883419606951065, 0.03294386486231815, 0.06547482102178037, 0.032429319035145454, 0.04036020225612447, 0.01640136160858674, 0.031900538815534674, 0.03793300085817464, 0.026796687197929714, 0.008927931721700588, 0.035320002789376304, 0.01583245160873048, 0.008542024206690257, 0.07955318433232605, 0.02841832254489418, 0.018077138483931776, 0.005519361084225238, 0.05517811943718698, 0.01626980480068596, 0.02429557531286264, 0.0737377225595992, 0.07827827110304497, 0.04165932805335615, 0.029551980951509904, 0.04920603481878061, 0.03668291989015415, 0.01857102477515582, 0.06581196386832744, 0.05789534843643196, 0.02302063425304368, 0.02264733953779796, 0.041255436444771476, 0.020272851033951156, 0.010443455721542705, 0.02594549019704573, 0.026314844108128455, 0.014619056855735835, 0.047509032519883476, 0.04367045548860915, 0.023084640779416077, 0.007711162052146392, 0.03123153350315988, 0.032258962746709585, 0.012876951459475094, 0.07723662973148748, 0.041498285718262196, 0.04545198840787634, 0.03472668911854271, 0.022403666480386164, 0.01363602195851854, 0.05002291676646564, 0.07887047526310198, 0.04706463078036904, 0.028506291164376307, 0.05394092957430985, 0.015741250936116558, 0.06514101783977821, 0.026921202879748307, 0.05868651867785957, 0.010774798683996778, 0.009510754207440186, 0.00962272109973128, 0.037410313670989126, 0.05907305887376424, 0.04242835260811262, 0.009149901597993448, 0.016900307491596323, 0.03813256436842494, 0.02496979050192749, 0.02485978195181815, 0.03664916330308188, 0.05367846162698697, 0.05217356425418984, 0.03587025334127247, 0.07300456971279345, 0.03935917491617147, 0.021394169380073436, 0.046718511657672934, 0.027804210185422562, 0.0346886020997772, 0.007463877054760815, 0.00922929284570273, 0.024694305284356233, 0.07276997683220543, 0.03385462849109899, 0.007721761776338099, 0.024107461285893805, 0.06128117456682958, 0.034695492940954864, 0.03818635523202829, 0.08350233023520559, 0.009992190043703886, 0.053936324547976255, 0.018549216765677556, 0.007877123898651917, 0.01773410855093971, 0.03681816146126948, 0.027355923302820884, 0.031074652761162724, 0.07138958215364255, 0.024000888879527338, 0.04793082473042887, 0.0274718022410525, 0.01492114992288407, 0.012170504796813475, 0.030590893074986525, 0.024564921113778837, 0.07631200278410688, 0.03496108161925804, 0.06926505826413631, 0.04174450063146651, 0.016998855426209047, 0.028321578029135708, 0.09549152557156049, 0.019798123284999747, 0.07967690035002306, 0.058188515322399326, 0.054196777564357035, 0.003394655600459373, 0.05653571162838489, 0.04285172930394765, 0.010538168608036358, 0.036328080532257445, 0.03329464096168522, 0.025133647432085127, 0.05362388779758476, 0.0618555152323097, 0.04267240045010112, 0.012835060933866771, 0.04746449994854629, 0.012265431050764164, 0.14889716258039698, 0.04727726351120509, 0.0385125551110832, 0.05011087981984019, 0.041034743990167044, 0.041894013702403754, 0.031892460538074374, 0.028238099403097294, 0.0536278174695326, 0.037262218102114275, 0.04692306982178707, 0.023796282475814223, 0.04476748334127478, 0.013820258263876894, 0.061128462839405984, 0.033328764911857434, 0.05813043113448657, 0.027594750135904178, 0.11766718758735806, 0.03181266481988132, 0.04048774775583297, 0.027832998093799688, 0.01794282088667387, 0.04061212057422381, 0.02612890828459058, 0.019556199840735644, 0.009292980248574167, 0.04672122791816946, 0.035266367776785046, 0.03848915148410015, 0.07258072917466052, 0.02495437609468354, 0.028778238192899153, 0.05850768335221801, 0.06257381770410575, 0.043293644848745316, 0.04985455314454157, 0.0190604767340119, 0.013219292122812476, 0.056447206807206385, 0.009520860403426923, 0.008214712033804972, 0.05360862553061452, 0.021807009434269276, 0.0311470956512494, 0.018267115301568992, 0.04245948570314795, 0.03641232913651038, 0.045862340411986224, 0.06393207411747426, 0.037796390024595894, 0.05747590141254477, 0.02703205005673226, 0.01587020837177988, 0.051397359420661815, 0.04220558956149034, 0.028409229380486067, 0.045029327884549275, 0.013640998986375052, 0.03976409068854991, 0.03947904289816506, 0.04270293240551837, 0.02896605721616652, 0.017640924488659948, 0.02949728466774104, 0.07203562170616351, 0.03732649180165026, 0.06907255257829092, 0.11535367579199374, 0.025402349419891834, 0.047442907161894254, 0.009641407450544648, 0.1132096111541614, 0.06722287565935403, 0.06400843369192444, 0.04820369758817833, 0.008444044942734763, 0.01527016805994208, 0.09192638171953149, 0.015154647207964445, 0.017635391777730547, 0.012453968101908686, 0.04171768683590926, 0.03204996282875072, 0.01057136394592817, 0.026302264705009293, 0.0198425742200925, 0.07862791171646677, 0.027274368694634177, 0.030357042342075147, 0.0215827194188023, 0.04946029090206139, 0.021120092387718614, 0.08436047559371218, 0.014952511228329968, 0.05345605481124949, 0.06432949419831857, 0.042687046734499745, 0.034815783947124146, 0.06889471173053607, 0.07178865722380579, 0.0740515990764834, 0.011410205115680583, 0.014740339556738036, 0.010182103778788587, 0.03815583811956458, 0.026985806835000403, 0.0442784080223646, 0.02841810175596038, 0.046043658221606165, 0.030862131352478173, 0.030498326850647572, 0.031107383329072036, 0.004129964618186932, 0.02387887980148662, 0.06217679467226844, 0.05637760448735207, 0.04785170436662156, 0.06033091754943598, 0.13380946358665824, 0.07442875110427849, 0.04048767725180369, 0.039238742901943624, 0.06364432119880803, 0.04105609928956255, 0.06648897324339487, 0.05382020441174973, 0.07713244704063982, 0.053648029861506075, 0.03248133616580162, 0.04710000524937641, 0.026267059074598365, 0.01052341285685543, 0.03732698161911685, 0.028359054631437175, 0.03349605613038875, 0.016443061031168327, 0.02153346864361083, 0.023074311939126346, 0.016195413772948086, 0.014914837956894189, 0.025847830984275788, 0.011051786750613246, 0.0320192267827224, 0.06166769249830395, 0.04466092577786185, 0.0613961443741573, 0.02936067568953149, 0.03321824056911282, 0.028051840745320078, 0.04115213319892064, 0.05706877032935154, 0.00707211213921255, 0.040633390526636504, 0.018086057243635878, 0.032143195130629465, 0.024543870094930753, 0.0045916375256638275, 0.024371875515498687, 0.021129263477632776, 0.01741806867357809, 0.0429044143675128, 0.028052569905412383, 0.09227229675161652, 0.024658986476424616, 0.0652319383516442, 0.033554860201547854, 0.04289351221814286, 0.028385688456182834, 0.02617710892081959, 0.012516446731751785, 0.02259068212879356, 0.029847652585885953, 0.030183081071299966, 0.024036389513639733, 0.03176224330672994, 0.055828422628110275, 0.039798415018594824, 0.04208098667731974, 0.03766577945498284, 0.025829325531958602, 0.07449966331478208, 0.040618807324790396, 0.06791210820665583, 0.03731977536517661, 0.024589393433416262, 0.047200458648148924, 0.0482519742945442, 0.05520514474483207, 0.08267783385235816, 0.01574335492477985, 0.0404055437684292, 0.011585204465518473, 0.066957743401872, 0.018257211340824142, 0.027984941698377952, 0.05244873776973691, 0.007523256290369318, 0.04387984132335987, 0.01868553074018564, 0.04635010212950874, 0.040941378101706505, 0.06283819297095761, 0.04780413270054851, 0.055326348592643626, 0.050457529578125104, 0.028935759037267417, 0.03464516790700145, 0.12115931895095855, 0.016579961302340962, 0.04728402076580096, 0.017337538229185157, 0.021297252314980142, 0.03202017302101012, 0.017080148427339736, 0.052033665706403553, 0.016961514265858568, 0.17887028079712763, 0.16313726955559105, 0.09510393894743174, 0.08087354668532498, 0.11117775182356127, 0.14745396736543626, 0.25919917272403836, 0.18072328995913267, 0.1420173200313002, 0.10354711557738483, 0.11183136870386079, 0.08430736750597134, 0.11541811647475697, 0.08519110211636871, 0.12458241573767737, 0.1358585778507404, 0.10257741800160147, 0.23061786341713741, 0.12106382680940442, 0.11776238286984153, 0.08872461563441902, 0.09882832542643882, 0.16378598083974794, 0.2057030308060348, 0.24863677856046706, 0.15440109302289784, 0.12209890759550035, 0.24471990123856813, 0.09325420265668072, 0.14246529521187767, 0.13001664367038757, 0.17520742578199133, 0.319427247159183, 0.15489321114728227, 0.13355986448004842, 0.10890587451285683, 0.14230361091904342, 0.19030305091291666, 0.19244708586484194, 0.157030908158049, 0.11931004279176705, 0.10128805515705608, 0.08746787760173902, 0.11744193834601901, 0.07231343726743944, 0.09296688018366694, 0.26615161215886474, 0.1270402455702424, 0.19178087473846972, 0.06169689972011838, 0.18475006450898945, 0.08253942331066355, 0.21033707511378452, 0.1296975795412436, 0.15569815936032683, 0.1646131044253707, 0.1294256714754738, 0.08085269975708798, 0.2842338028131053, 0.1449560170294717, 0.16695701458957046, 0.07031547924270853, 0.15884774504229426, 0.1005806696775835, 0.10071875367430039, 0.10184671424212866, 0.10823975986568257, 0.2061195982969366, 0.11208686788449995, 0.10429311500047334, 0.06762360571883619, 0.09522087915684097, 0.1179719579522498, 0.13484039576724172, 0.09963078744476661, 0.16531456756638363, 0.16715399542590603, 0.24343562952708453, 0.1848177335341461, 0.14076680119615048, 0.12060884575475939, 0.1018638578534592, 0.11489800454000942, 0.10361080669099465, 0.12874751177150756, 0.13215046667028219, 0.13908141350839287, 0.19853950972901657, 0.15394626039778814, 0.1476006009033881, 0.14800664474023506, 0.2559640916297212, 0.2087602487881668, 0.21287364681484178, 0.1294054405298084, 0.1319219742435962, 0.06516596884466708, 0.14024143485585228, 0.09993265601224266, 0.1265259223873727, 0.11980590876191854, 0.10102744257892482, 0.13384660065639764, 0.2756434731418267, 0.11816567333880812, 0.20717610488645732, 0.15399804746266454, 0.059970307993353345, 0.11614336544880643, 0.1428413117537275, 0.15010816947324201, 0.15866458299569786, 0.13938360119936988, 0.10242783813737333, 0.09913340007187799, 0.07901226257672533, 0.08023732574656606, 0.21388501598266885, 0.0689385949226562, 0.1093842851696536, 0.14061135094380006, 0.12315411542658694, 0.16954745136899874, 0.14659537671832368, 0.16336270433384925, 0.09207641429384239, 0.13149773294571787, 0.15989593957783654, 0.09786176713532768, 0.07818047830369323, 0.17477951827459037, 0.14146854635328054, 0.17812587699154392, 0.1897632423788309, 0.07473581470549107, 0.2422335432493128, 0.13784254639176652, 0.09783149493159726, 0.13708560029044747, 0.16680984670529142, 0.17240819317521527, 0.1411804446252063, 0.12294648477109149, 0.12331861245911568, 0.10046205963590182, 0.13537713180994615, 0.2080635353922844, 0.17513040569610894, 0.17126216873293743, 0.09852672403212637, 0.09515765559626743, 0.13796419923892245, 0.2473356600967236, 0.18543110374594107, 0.16646792442770675, 0.13972282205941156, 0.12039784574881196, 0.1559038826962933, 0.09498037135927007, 0.21003301721066236, 0.12870612961705774, 0.12711679068161175, 0.14257777511375025, 0.14160640770569444, 0.11533184922882356, 0.17259493237361312, 0.14827141334535554, 0.19993586058262736, 0.15652697504265234, 0.1721609095693566, 0.10523433636990376, 0.14116438454948366, 0.0945651026268024, 0.07746246526949108, 0.1582193686044775, 0.06982388804317452], [0.030738391214981675, 0.008595119306846755, 0.06281724214204587, 0.11604999584960751, 0.05351780149794649, 0.09374980145366862, 0.017437807946407702, 0.04812521918211132, 0.06208645303559024, 0.009236230071110185, 0.025274327090301085, 0.08891941455658525, 0.056679280096432194, 0.05619942596240435, 0.03010569176694844, 0.018045706674456596, 0.030501592300424818, 0.016303745069308206, 0.049342627098667435, 0.05176704544282984, 0.04049664239573758, 0.08225774858146906, 0.03703515059896745, 0.03531375761667732, 0.02220295078586787, 0.038993852722342126, 0.039278210315387696, 0.042277570464648306, 0.06927082475158386, 0.0200332189706387, 0.011266228466411121, 0.02824547264026478, 0.06314251804724336, 0.042937161633744836, 0.041645646560937166, 0.00821037232526578, 0.028007298897136934, 0.08433381022769026, 0.041901668955688365, 0.024279220233438537, 0.037968204633216374, 0.006865529303468065, 0.019918822472391184, 0.006182062779771513, 0.03302056582469959, 0.03309141124191228, 0.03927353478502482, 0.032891929367906414, 0.031590202343068086, 0.019001064101757947, 0.057714427675819024, 0.04099945115740411, 0.03556755356839858, 0.07341264703427441, 0.028704190408461727, 0.05306722508976236, 0.012832806660298957, 0.018692176672630012, 0.03703476468217559, 0.036503739465842955, 0.012209249543957412, 0.06053869663446676, 0.06657230158452876, 0.028472940903156996, 0.04111448775802273, 0.050966145645361394, 0.010045949366030982, 0.01011596172247664, 0.07549854213721119, 0.03040992778551299, 0.03009824617038248, 0.02774246720946394, 0.032984159770421684, 0.06662218132987618, 0.09063063640496694, 0.017626907174417283, 0.020483364933170378, 0.01755570738168899, 0.011068346848333022, 0.012488077209127368, 0.03570915534510277, 0.03315340283734258, 0.09013383532874286, 0.03839809367491398, 0.026811815878318157, 0.050851595151470974, 0.08491778397001326, 0.030598386911151465, 0.018903380769188516, 0.06780991447158158, 0.01802301179850474, 0.009257029687432805, 0.05645441677188501, 0.018004816192842554, 0.02847224513971014, 0.033115627520601265, 0.013741260354436236, 0.06575694846105762, 0.033045004747691564, 0.021951934177195653, 0.05086659024527762, 0.033267830876866356, 0.00999295723886462, 0.03286863706307486, 0.030156350767356344, 0.02582184097263962, 0.03800213562499266, 0.03317109934869222, 0.03139619751891587, 0.020939117821399122, 0.05024282625527121, 0.005824735371788847, 0.03092277594987536, 0.041605997321312316, 0.045374864421319216, 0.02012791886954801, 0.04065346933202818, 0.047435563610633835, 0.05613859211734962, 0.014971285709179938, 0.017939041499630548, 0.005507228825081256, 0.027292738705000374, 0.05599242613243405, 0.02953216746391263, 0.011498896401462844, 0.04129028027819004, 0.07383522592135705, 0.06594036283786409, 0.04017996798211243, 0.03920669696526602, 0.03455738667980768, 0.01955571187863825, 0.05172870238311589, 0.048352052908740006, 0.03526136570144445, 0.012023165290884208, 0.03832204580248799, 0.03831152956990991, 0.06059704057406634, 0.06926919202669524, 0.013440649727272103, 0.01707945451926207, 0.004640397555704112, 0.03616091918956954, 0.027656231504806783, 0.050139074010076, 0.01910875529574696, 0.023881397537479643, 0.02632682051626034, 0.04649260932637844, 0.016316092551278416, 0.035659090062836185, 0.03887617407599464, 0.03083484072703868, 0.09386765450472012, 0.04784875061886851, 0.029677624697797, 0.026955022549373098, 0.06116458316682838, 0.07385815828456543, 0.03118877466476988, 0.046872162201907486, 0.026305044048058335, 0.06050470256013796, 0.04107427448616363, 0.025610488446545787, 0.01871268221293576, 0.03175966805429198, 0.03929003272787668, 0.015860473249631468, 0.026805045636137947, 0.053584602210321464, 0.0351998490805272, 0.07317651790799573, 0.018055400978482794, 0.03471289630397223, 0.06433560949517414, 0.07388358426396735, 0.06866480922326446, 0.026820740204129834, 0.03171498705341946, 0.05591898690909147, 0.006287631431405316, 0.051795499384752475, 0.04697401825978886, 0.07000399986281991, 0.039044667573762126, 0.1127753137552645, 0.05869237422302831, 0.09803082095459104, 0.011124579377792543, 0.025058135761355516, 0.033621167385717854, 0.010220511776424246, 0.09712376064271666, 0.03955843043513596, 0.026370328923803754, 0.03795838973019272, 0.03239599660446402, 0.04253799008438364, 0.0015028365214675432, 0.05059910166892223, 0.03745787420484703, 0.0960139678500127, 0.038954901101533324, 0.04939367943734396, 0.02908591035520658, 0.03187153197359294, 0.02106339787133038, 0.07905685823061503, 0.03250555986596737, 0.0443640592857264, 0.041594371577957645, 0.051321081482456066, 0.01423618658009218, 0.006026444152666954, 0.012796670562238432, 0.09417135617695749, 0.01038444663208793, 0.050731033261399716, 0.03535280571668409, 0.024876979368855245, 0.010810619369294727, 0.036724164747283794, 0.031500955374212936, 0.08911139331758022, 0.05935172790486831, 0.040024343325058, 0.05414179926447105, 0.03652652711025439, 0.032996739173540846, 0.022815604825154878, 0.02222500555944862, 0.05173160046979319, 0.02018707546085352, 0.02855154176359065, 0.025907418021233752, 0.05400542591814883, 0.0622807139006909, 0.02766579778835876, 0.10100135608809069, 0.04340944957220927, 0.05771802338131238, 0.06582568617886864, 0.018162680280511267, 0.020914927517878823, 0.03604971949243918, 0.051123388184350915, 0.02952647519123275, 0.06933514669071883, 0.05977408043690957, 0.017699771233310457, 0.035258853531559, 0.008603556598245632, 0.05197337733989116, 0.05950544524239376, 0.07463894216925837, 0.05699228458979633, 0.05261750215140637, 0.04225671240419615, 0.04146337880229112, 0.030912430411262903, 0.03309334453660995, 0.08011627403902821, 0.036347083223517984, 0.07543423504102975, 0.02391203339357162, 0.05230428614595439, 0.027168941051058937, 0.06601195040275343, 0.023127937674871646, 0.06981625876505859, 0.03006507959071314, 0.01887974522105651, 0.015889478236204013, 0.04186072095762938, 0.024836754964780994, 0.04518742389336694, 0.04218272399157286, 0.07743049354758114, 0.028033031012455467, 0.11407121492084116, 0.007550177697339677, 0.038030611831345595, 0.03690032834128942, 0.03532723872922361, 0.03476787460385822, 0.03619978917413391, 0.10667680428014137, 0.06222886746400036, 0.018363100971328095, 0.054172861855477095, 0.00896646310138749, 0.030909537890693173, 0.013971966236567823, 0.051003353219130076, 0.02899834991694661, 0.017637245291552972, 0.08743015423533507, 0.01760770410328405, 0.03231802285881713, 0.041062388991122134, 0.06039377745764796, 0.009582170150679303, 0.051567500486271456, 0.017286007205257192, 0.06575296312803403, 0.04198432194243651, 0.060620032309088856, 0.04241614427883178, 0.0243110101291677, 0.07308779415325262, 0.07322331774048507, 0.033712722433847375, 0.049449960206402466, 0.07444613220286556, 0.043934092318522744, 0.020174605524516664, 0.0070899533693591366, 0.03769127964915242, 0.0736908930412028, 0.06857725806185044, 0.04583770481985994, 0.06317934341495857, 0.015225571478367783, 0.017965066763281357, 0.028694455286313314, 0.05409729637904093, 0.06554866471560672, 0.07640567666385323, 0.12034497514832765, 0.005193357874304638, 0.005603477957265568, 0.07503174609155394, 0.030236766178859398, 0.05995782506943215, 0.023017663806967903, 0.03392885068024043, 0.07066261881846003, 0.03448953582847025, 0.015446597899426706, 0.0383967837842647, 0.051348496417631395, 0.047816259393584915, 0.04336446429078933, 0.06384029271430336, 0.04752750457555521, 0.03588043189665768, 0.038192477950360626, 0.03587761915696319, 0.01950745743670268, 0.09908381718560122, 0.16721400548703969, 0.11870030910358764, 0.15353975642938167, 0.08342770728631876, 0.16197070246562362, 0.10965042674797587, 0.12130569273722358, 0.16138936334755272, 0.11442110786447302, 0.1791103061987087, 0.2611392654944211, 0.1958902651676908, 0.07546794338850304, 0.1574616358266212, 0.10303182760253549, 0.2259243285516277, 0.10088922499562614, 0.08396689241635613, 0.2381930686533451, 0.08333783320267685, 0.1345122922793962, 0.1285400369670242, 0.09283519349992275, 0.1566558118793182, 0.12543155142338946, 0.11651604974758811, 0.12800986150978133, 0.23297499865293503, 0.09819120648899116, 0.1570431684376672, 0.12286611759918742, 0.09387105354107916, 0.13868488400476053, 0.2101812686305493, 0.14534472429659218, 0.13023238599998876, 0.22987565636867657, 0.17455205001169816, 0.12933732621604577, 0.13377156952628866, 0.14903633011272177, 0.1716472246334888, 0.09031404362758622, 0.13601459213532507, 0.11030297493562102, 0.12719002581434324, 0.13367629260756075, 0.09609829809051007, 0.25232174957636744, 0.25169858301524073, 0.17667873355094343, 0.1427594677079469, 0.12434428281267174, 0.1350370203726925, 0.18831048830179498, 0.08746781080844812, 0.12433868701918982, 0.1113724839524366, 0.14864486205624416, 0.08808709593722597, 0.14758602512301877, 0.19160753872711211, 0.10179922421230003, 0.09502661458100192, 0.25853210070636123, 0.06645810732152313, 0.11352673085639253, 0.21074537507956848, 0.08726473693968728, 0.17790778947528452, 0.17112110130256042, 0.17223055270733312, 0.1773929616319947, 0.13609661429654807, 0.21550013712840155, 0.18930222024209797, 0.22553973278263584, 0.15108206018339843, 0.14512157533317804, 0.16645138937747106, 0.14231803826987743, 0.16656293417327106, 0.12815029069315642, 0.22252302122069523, 0.15977924427716061, 0.118782383215148, 0.1606328328489326, 0.15231822588248178, 0.12276022796868347, 0.16843850462464616, 0.05788050919363741, 0.11060094722779468, 0.10157392302062362, 0.15311637602280825, 0.07398259418550879, 0.11399403898394667, 0.1735760664450936, 0.11678222101181746, 0.17252436897251755, 0.11736718923202716, 0.08073201912338845, 0.08674438009620644, 0.11072547218645923, 0.12231926608365029, 0.12752023700159043, 0.21146726212464273, 0.14987756934715435, 0.14231183391530067, 0.13854341581463814, 0.06500264440546744, 0.1207209620042704, 0.13641453551826999, 0.21825688920216635, 0.12746160733513534, 0.0969278856064193, 0.169975952594541, 0.11836511810543016, 0.15806525421794504, 0.13845996872987598, 0.15381623612483963, 0.1701997991767712, 0.06471423097536899, 0.15414658089866862, 0.12582098599523306, 0.14995877514593303, 0.13241743203252554, 0.22163183544762433, 0.12017729430226609, 0.10044914626632817, 0.15045711246784776, 0.11681066753226332, 0.07915988317108713, 0.1420505385613069, 0.25862255366519094, 0.08181084951502271, 0.2305465578683652, 0.13214439590228721, 0.10093383549246937, 0.18797563127009198, 0.12418621277902275, 0.23747262137476355, 0.08283594099339098, 0.14958526706323028, 0.1344930854975246, 0.13098263792926446, 0.18873980588978156, 0.13551696727517992, 0.0664111293735914, 0.12493897316744551, 0.11275445198407397, 0.10743329767137766, 0.14563355332938954, 0.1920399584923871, 0.12812257889891043, 0.21306896524038166, 0.1360370049951598, 0.12227849991177209, 0.14995181380072609, 0.14195748808560893, 0.12826609541662037, 0.12473549111746252, 0.11688356127706356, 0.12371457793051377, 0.15650619490770623, 0.1166811998700723, 0.10678156584617682, 0.1830825922661461, 0.11935667935176753, 0.1520798183628358, 0.20580142474500462, 0.13571130606578663, 0.15614205272868276, 0.1108688922249712, 0.14031775732291862, 0.14988429320510477], [0.010551076411502436, 0.026923314289888367, 0.0462259296909906, 0.0175100467458833, 0.044057158957002684, 0.02831047364452388, 0.019306307585793547, 0.014143837433948647, 0.0054484423799294746, 0.032767968441476114, 0.023975397962203715, 0.04114936127734836, 0.0539507222129032, 0.02923492433183128, 0.05711615645850543, 0.05626367739751004, 0.03108807450189488, 0.0263841068954207, 0.032578390528215095, 0.027443277795100585, 0.024016735587792937, 0.01424798301741248, 0.044134104828117415, 0.01824359849706525, 0.036700134005513974, 0.034800451176124625, 0.04027359733299818, 0.07700393674895167, 0.025680580583866686, 0.034999439521925524, 0.03977770909841638, 0.03349275728396606, 0.017685449638520367, 0.06874506507301703, 0.048228630039375275, 0.04521252332779113, 0.029163709696149454, 0.006459769338107435, 0.07285763931577094, 0.019558097883418668, 0.027450829147710465, 0.06039390733349137, 0.040047257134574465, 0.047347359359264374, 0.0411813329992583, 0.03675120489788242, 0.02424286798486719, 0.018693072815949563, 0.03839987482933793, 0.04215065207972657, 0.012770481098414166, 0.10467754749697633, 0.029303265000635292, 0.05019337324483786, 0.06095329372328706, 0.0688170682406053, 0.09125870114075951, 0.0778173899743706, 0.013216641727922251, 0.03675998821563553, 0.03160078907967545, 0.06887705603730865, 0.017186410987051204, 0.059058215920231305, 0.07411028811475262, 0.01919741596793756, 0.03228085610317066, 0.043323390127625316, 0.0674783303111326, 0.04959870515449438, 0.02793732735881349, 0.0204723830029252, 0.012383774846966844, 0.04436920607986394, 0.05708175420295447, 0.013638692762469873, 0.03198125479684677, 0.021006814677093644, 0.06801186027587391, 0.03881440141412895, 0.04572443453071173, 0.029841643045074306, 0.05499135426362045, 0.037465395871549845, 0.03877497852954548, 0.0416803642292507, 0.06729143526172265, 0.03464536457613576, 0.01127182147683925, 0.022107939184934366, 0.04295172999263741, 0.01676512158155674, 0.02234640793176368, 0.037145118330954574, 0.02041870160610415, 0.03766601323150098, 0.027674425255099777, 0.009618307176424423, 0.024442125359200872, 0.060539705955307, 0.03994410602899734, 0.01905772336613154, 0.03571989793272223, 0.02933062056399649, 0.03367950761457905, 0.03222510225896258, 0.0226081578512094, 0.031175263866316527, 0.05539138670428656, 0.04934659387799911, 0.02363189862080617, 0.02362420069403015, 0.03219720492779743, 0.036791562888538465, 0.017440190240449738, 0.021962838181934785, 0.025690128313726746, 0.04049703202326782, 0.029094836536387447, 0.008367377376998775, 0.029206392464402597, 0.04016194121504668, 0.047730763981235214, 0.03050162940780865, 0.022191056013980415, 0.06721703495713882, 0.026104445241799112, 0.02487584944901755, 0.07418909677653573, 0.038102748585515656, 0.05146088726178277, 0.0608205383468885, 0.05250000162050128, 0.07565301275462843, 0.04341881547588855, 0.03151951277686749, 0.0025995104624598753, 0.02652047096489696, 0.07946681318571791, 0.03671665421279613, 0.04928416441543959, 0.01960831901669735, 0.029223485980764963, 0.03456357619143091, 0.08718295968719758, 0.019503331095620524, 0.05622763499559369, 0.04832828934013378, 0.017508135715615936, 0.03790013855905272, 0.022619323463004548, 0.003749563375095022, 0.02293610363267362, 0.032182258073589765, 0.09177758111036383, 0.04513262370892335, 0.03890362240781542, 0.04853062106121797, 0.036678630276583135, 0.028654483212449122, 0.026633637353370432, 0.04960411541105714, 0.054553134614252485, 0.050780835081241094, 0.04045548659632914, 0.019545600116543937, 0.06387772664311342, 0.09775956597877666, 0.10549137921771035, 0.0295065670798067, 0.024690587124496233, 0.058668658894021064, 0.01794302497728495, 0.09824234788538888, 0.005320017435224145, 0.005329265986802056, 0.07457670566509478, 0.022771042567910627, 0.16029169724788517, 0.01446636089895037, 0.014922977461537812, 0.05076765453850385, 0.01438602434063796, 0.036084678358747624, 0.04739829666505102, 0.06344166293274611, 0.059453680441947654, 0.031150361101026647, 0.05135576946486253, 0.020388269840623252, 0.049077294461312704, 0.04578621461405419, 0.036967570631532, 0.03761066014703829, 0.06334699457511306, 0.02143228422937682, 0.016286150603264105, 0.05747886258177459, 0.04152361892920453, 0.06099619728047401, 0.05905906196858268, 0.03670172591228038, 0.03473307529930025, 0.0353727435140172, 0.04859600056079216, 0.04574434264213778, 0.030730795333511196, 0.019293140030640643, 0.02653918978467118, 0.011366470353095792, 0.10107609035912901, 0.09492848039371893, 0.044419197147362866, 0.02989636159327347, 0.045152208986110054, 0.06702579092234373, 0.036852660196018405, 0.019057272511417978, 0.018523707294662017, 0.06838138302555308, 0.05683508286892902, 0.018417012433928903, 0.057264545175712556, 0.022681159207422752, 0.0309510295119253, 0.06181383621878922, 0.026360326628491748, 0.060377320332918316, 0.03782325205975212, 0.007324896914724377, 0.057595116304582916, 0.07937011876492761, 0.10502125835046172, 0.06732971523888409, 0.05490277522767428, 0.039704878436168656, 0.022952069084567484, 0.05499655300809536, 0.009115710854530334, 0.04941445957229007, 0.02282450132042868, 0.03109655539446976, 0.04645608081773389, 0.026419162240927108, 0.074770710489247, 0.029724476480623707, 0.05762589687947184, 0.01881752541521564, 0.02988084885146236, 0.05155113984073978, 0.054449979797936976, 0.02821534886606969, 0.03661364782601595, 0.07168183248722926, 0.052389989359653555, 0.04963378647516947, 0.03773990145418793, 0.04237701454258058, 0.04162563825957477, 0.02574176138296025, 0.03754302080778871, 0.030045143648749217, 0.018201669008703902, 0.032858410268090665, 0.018376428088231478, 0.057288138050353155, 0.03636861663835589, 0.031953914076439105, 0.03837159900285769, 0.01852143817814067, 0.06427033760701306, 0.04207649297313765, 0.0388149654463632, 0.04010537842987105, 0.07052432702039368, 0.026201419823337346, 0.032732530889916234, 0.03469639093964361, 0.021731076594733167, 0.05307702514983248, 0.020831580623053014, 0.02741334326856304, 0.024890126514947042, 0.015027001518319594, 0.02633060732478043, 0.05374783759179991, 0.0213607356272405, 0.033695486054057255, 0.021176499321882147, 0.00465696600258525, 0.0067740011581918225, 0.0638956124021206, 0.027335094928275794, 0.038392635178752244, 0.05430834091384895, 0.010248993548884755, 0.02836070219927933, 0.10051235498394817, 0.02751641830400331, 0.01914139309519669, 0.06303095098701306, 0.057473723209113814, 0.01468509501137305, 0.02567784391430905, 0.0635224679717794, 0.028500595180958044, 0.029897330095991492, 0.025383448773936834, 0.05204282009799499, 0.03024170331627829, 0.03240703234041575, 0.058397029133629985, 0.03881592652760446, 0.037423705725814216, 0.02580564731033519, 0.06273218459682539, 0.03937813678930979, 0.033152842515846714, 0.055970206230995245, 0.033857188900583424, 0.03932706589694135, 0.024280261095555034, 0.05489147974003572, 0.052492594986688346, 0.04452881606994197, 0.02139425287168706, 0.05389219644712284, 0.005799705513709341, 0.0728366662224289, 0.03857731120660901, 0.03729889875103254, 0.038437954426626675, 0.039151150922407396, 0.05820607824716717, 0.04480724390305113, 0.030344659608090296, 0.033017407986335456, 0.009264686796086608, 0.031781524303369224, 0.025138855453405995, 0.03048527432838455, 0.008603981477790512, 0.03152510485961102, 0.052371168494573794, 0.0641286393511109, 0.011031219983124174, 0.040978389006340876, 0.03918943461030722, 0.021449117994052358, 0.052368415126693435, 0.04922868145513348, 0.0519073039322393, 0.12457315373467281, 0.07238008955027908, 0.21139073185622692, 0.14541917655151337, 0.1426588770118542, 0.117508071125485, 0.12141679224441759, 0.13366087077884004, 0.17006174486596137, 0.10993125542881899, 0.11009374866262078, 0.11628518986981362, 0.11652746397885494, 0.16025298682507128, 0.14483380015008152, 0.1255791645962745, 0.14626247895648703, 0.09371030435431749, 0.10711172508308664, 0.16822703706566244, 0.07647525300853886, 0.1211002365744207, 0.10856159962713718, 0.2283587510464713, 0.17690835404209793, 0.1396984202438034, 0.20526314503513277, 0.22435027785832062, 0.14490488305455074, 0.13757520995568484, 0.17491154634626582, 0.11369841187843122, 0.07819304286385886, 0.1929087462485768, 0.2404626304632984, 0.1306472613941878, 0.20633433130569756, 0.11677612055791542, 0.1578618463827297, 0.11638460055110045, 0.08947782873292454, 0.13262403110275045, 0.11930063978070393, 0.08119566846289672, 0.16287365870084614, 0.08739969649468549, 0.15661111974623054, 0.11697107533109374, 0.13156942441128194, 0.10662577420589514, 0.13772282312856987, 0.18336033361265436, 0.11380680996808223, 0.09447689837543294, 0.23507889825850725, 0.12110342780943029, 0.18428243725793436, 0.22661115654045716, 0.10217200499027967, 0.13017188612138852, 0.0846125089447014, 0.17197175096953288, 0.07559442761703394, 0.1799335706164129, 0.10259325543302111, 0.17240558081539348, 0.19218944187741727, 0.10495186754269525, 0.1394731635809876, 0.15962070669047534, 0.14240302902180701, 0.10537129972362891, 0.08399869344430044, 0.18356296961428598, 0.16109511663671583, 0.1007405060227029, 0.17435141780879349, 0.06530226426548325, 0.2066628949251026, 0.1358699772390537, 0.09986522447434254, 0.15441948344232515, 0.10959858031128533, 0.13407626567641273, 0.13430652441456914, 0.11571074530365877, 0.1336302497657016, 0.15739794471301138, 0.1003144464630168, 0.0628954273997806, 0.10970646631903946, 0.13083284284221008, 0.18878334027249366, 0.1472487932187505, 0.27393062599003315, 0.19256382569437847, 0.09681522758910432, 0.10898283522692509, 0.18423853180138394, 0.1398038794286549, 0.1239404283114709, 0.1373110944405198, 0.11273876298218966, 0.12665357178775594, 0.17887676716782153, 0.10528601953410544, 0.1437381378491409, 0.14948388969060034, 0.12228649284224957, 0.1554587425198406, 0.180205152137205, 0.12352332647424191, 0.22034551540855318, 0.05117990272992756, 0.1293116033775732, 0.17533937963889912, 0.10874128100113012, 0.1221748960961122, 0.18094194150762632, 0.1300578031805344, 0.06522286188555881, 0.15699961921200156, 0.1372566059581004, 0.1269410055829212, 0.11741897629690357, 0.13032239367021248, 0.11896778654772788, 0.1091610619914718, 0.3211951022967696, 0.11702821328071877, 0.13571299816248938, 0.0953028271032963, 0.19357330980710685, 0.24758666928391904, 0.16564866760745645, 0.07160677909268998, 0.11632125824689865, 0.10502485034521669, 0.18165343848522753, 0.15326344000641257, 0.16803630511276424, 0.15923876781016588, 0.10751854817499407, 0.12220104938023724, 0.19221241876948625, 0.17208887671586126, 0.12743068946292624, 0.158850327716209, 0.14631966885644943, 0.0762703015061561, 0.1055180816911161, 0.1182691658323165, 0.18704221729421988, 0.12205466817249544, 0.1786147296661511, 0.1597882539499551, 0.1532770658377558, 0.08503285396727733, 0.188874535379, 0.12998989666812122, 0.16773647745139897, 0.12578046473208815, 0.13498229440301657, 0.1549513658392243, 0.13158880930859596, 0.06814271575422026, 0.08095637778751552, 0.2869784430367872, 0.20835796021856368, 0.07692650848184712, 0.06955627701245248, 0.12072901430656202, 0.1254243080620654, 0.17182648298330605, 0.22259542514802888, 0.10893410581047647], [0.05137358843057882, 0.08881162502802908, 0.027407092529756483, 0.040067673617159016, 0.038414843947975896, 0.025324501839349978, 0.014753759442101, 0.017961229859793093, 0.02378039494942641, 0.061937196005601436, 0.013847948721377179, 0.015259132323990343, 0.04315173137001693, 0.018389987126283813, 0.015168124609772349, 0.027145134808961302, 0.011310263798804954, 0.042097525438293815, 0.007450822213286301, 0.014243311197787989, 0.017948158783838153, 0.05542347345908638, 0.015220381083054235, 0.014675491620437242, 0.022918023059901316, 0.01626470810151659, 0.027143784100189805, 0.03517781471600756, 0.04430109176610131, 0.03267101426899899, 0.04956410622980911, 0.06005217430356424, 0.057957314056693576, 0.03561785262718331, 0.04664019652409479, 0.02270046061312314, 0.028975781206099782, 0.06587998912436888, 0.04884898386080749, 0.02702265075640753, 0.0031235812912200345, 0.029847531986888498, 0.03058425270864973, 0.050993779514101334, 0.043480020394781604, 0.039174617631942965, 0.02963534640002763, 0.02901751588069601, 0.03111085286946036, 0.030214271682780236, 0.03884776837367099, 0.02866674720280571, 0.00035442459591195075, 0.07763490328215994, 0.01637395780562656, 0.10916619023191743, 0.03787177738558967, 0.07465614515240304, 0.05193901219172403, 0.029322807604330592, 0.01909186401462648, 0.0447265576076461, 0.03539569072017912, 0.030934882233850658, 0.03762483516766224, 0.02046086487098364, 0.023476251699321438, 0.018246001200168394, 0.03505759792460594, 0.021970389534544665, 0.01720832475257339, 0.02231439168099314, 0.05805187480291352, 0.06040316933649592, 0.02722909026488196, 0.06256447406485677, 0.018591790067148395, 0.05930844214162789, 0.04713260037533473, 0.09585268431692384, 0.06419007433578372, 0.025187304709106684, 0.1677866466343403, 0.06284121351200156, 0.055164827572298236, 0.04174400710326154, 0.04959104990120977, 0.09477875209995545, 0.0333995286928257, 0.0045262009734869935, 0.02003033943765331, 0.030529478499374818, 0.016674490507284645, 0.025010649442265276, 0.04060227598529309, 0.019031957854167558, 0.047454785235458985, 0.03835690818959847, 0.05140022039995529, 0.020207584711897653, 0.08434655290329829, 0.0029398002470770734, 0.031022509465401527, 0.037803507220814936, 0.004474684328670264, 0.02169549246900715, 0.016569452491239645, 0.022742753753846046, 0.02152889886929188, 0.013358416053961264, 0.029043183058092836, 0.03435810889641289, 0.02706172668695217, 0.03525114632793702, 0.04259724315488711, 0.013043717608525185, 0.0020233860914231627, 0.07521130130044185, 0.06425435174605809, 0.022108454977569636, 0.0750766386045143, 0.034252542100148275, 0.03255884235841222, 0.02094007890264038, 0.020068534067831933, 0.027134134325024206, 0.020553627764456905, 0.014922495065547992, 0.026901682540483307, 0.02168391310988227, 0.052903507312294096, 0.019888169917976484, 0.0636121713614557, 0.03297671602922492, 0.018908338315668516, 0.027579723500821274, 0.03361977585882414, 0.03561298413842451, 0.04888093702902552, 0.04301576620491687, 0.036820885143242776, 0.018768560366879683, 0.06805445213103667, 0.029796394301229157, 0.037419022773974575, 0.023140583871281706, 0.09323921869508922, 0.024777882244961802, 0.030148109217407182, 0.0209901367634302, 0.057829382640193217, 0.037433446414070204, 0.014134324956103228, 0.018767165129247587, 0.0703243182215374, 0.08370961950276978, 0.09105929348152131, 0.0206341006924049, 0.06518938360386528, 0.025297413449152373, 0.042807771897059865, 0.010538326314417645, 0.0796864517906215, 0.1307456404902041, 0.029772283778584097, 0.02269187581987353, 0.002762955036814674, 0.08325293150846846, 0.009528152004349977, 0.03437277002376504, 0.02989489585161209, 0.09823040672927164, 0.006047544802640914, 0.058383303112350404, 0.0379003203852335, 0.056351247112615965, 0.03214767399185803, 0.009219672756444197, 0.025050287549674977, 0.02944347339507658, 0.04349585411546286, 0.0027662622323987307, 0.05798131140181795, 0.052508695880533196, 0.09873518589301966, 0.05180385596759152, 0.09990449150791392, 0.044133336705272086, 0.03817864431766793, 0.03159917861921713, 0.029896693704358768, 0.03599490075430367, 0.021542788163060322, 0.05908918203203939, 0.05958907786407508, 0.04392643335449975, 0.05074871864053421, 0.0196963265989325, 0.07838721838197671, 0.022901517695572693, 0.029654838908754755, 0.021556929787038825, 0.020331423183961306, 0.02461312360537704, 0.033651510093477555, 0.03176102247380186, 0.010338862066419097, 0.02934640047897119, 0.0323364874930121, 0.021877439248783048, 0.08446355248452164, 0.013278708465804812, 0.01510322008471121, 0.0502351042086957, 0.04072117546456866, 0.02511830723960884, 0.02082735409203451, 0.03783491862122901, 0.008620041553513147, 0.021365960346884094, 0.03212135372450575, 0.027536218804016244, 0.028838198159064632, 0.029001928924117237, 0.02865258702513529, 0.028896770309074782, 0.10228211001958698, 0.03358613801538013, 0.05334962341294158, 0.016941014291660395, 0.0466769328340888, 0.030138999354676344, 0.023261270071088802, 0.09285993670346215, 0.03660136157122906, 0.01372521141092875, 0.029151592279959004, 0.048799927899381146, 0.03700617715367116, 0.04821635491680354, 0.03760309024073649, 0.015051562895678217, 0.020903246113448404, 0.04107256012503058, 0.024949481630756054, 0.0626700816792436, 0.018246646868647076, 0.05473639314004686, 0.008279752000817098, 0.007583453279949026, 0.05321382523106877, 0.06586145769688301, 0.02649363304954022, 0.049037014396162704, 0.00738437587642693, 0.02382109061727533, 0.033033163781510666, 0.06338806502753869, 0.14445114880800247, 0.0795663648750633, 0.026402740368212108, 0.0612423936399864, 0.042109002752113156, 0.08580433132010512, 0.052955030914745294, 0.0403676756832283, 0.04133660884690471, 0.07329713174840435, 0.03311898202809971, 0.013944865786470473, 0.0258245015720604, 0.02361389597353991, 0.035122643457725644, 0.06764756966731511, 0.030153801490087062, 0.047402215204783715, 0.012570485287142219, 0.07247522546094842, 0.0808679434703663, 0.030487057338177692, 0.029426103428704664, 0.045656271977350116, 0.062330296786967665, 0.006325846934487345, 0.029915876366430894, 0.01877833445178112, 0.04946120003296528, 0.05338566952559631, 0.0371112504217308, 0.02996649269334739, 0.03856032344629057, 0.03804171807132661, 0.03719629683473613, 0.04926004090521019, 0.03134249571303371, 0.019678589269460645, 0.06234368513105437, 0.03914133230864536, 0.05335939749784302, 0.06640551873715594, 0.017304453285760246, 0.0632932482403703, 0.03098342796874931, 0.014275202211138094, 0.04261308800778352, 0.08733806855161674, 0.037034608831163496, 0.05450198208563961, 0.04760892559716012, 0.05316510323609691, 0.09589520195731893, 0.0411275977967307, 0.026975626424246002, 0.03516977354593109, 0.05502055035321973, 0.008592098765802803, 0.01269072341528954, 0.025998277305916417, 0.0330671281699324, 0.04765029290865641, 0.029291910141182598, 0.029228632774902508, 0.050192085618618876, 0.0242808659459115, 0.08983536579762585, 0.03657774272141978, 0.037931193728582, 0.01336704630375607, 0.03296563576441258, 0.014617424130847212, 0.09381704745464958, 0.03456079684838187, 0.05546924541704357, 0.012163612100266619, 0.07675928776734509, 0.0814539729617536, 0.03163472378219012, 0.0210927182706655, 0.031212720059556887, 0.08488327410304919, 0.02371533828409156, 0.05965525888314005, 0.054524146326002665, 0.09049746542586945, 0.0491729498753557, 0.021114650589879602, 0.04138129355851561, 0.035244608006905764, 0.090039256028831, 0.04816532484255731, 0.02758355112746358, 0.06851044250652194, 0.18243601836729795, 0.15965641883667558, 0.08988519359263591, 0.15096187678864226, 0.07738577915006317, 0.16694447229383513, 0.15354931529145688, 0.13505610841093585, 0.19286635477328673, 0.11650026426650584, 0.23909519368316978, 0.0878055696375668, 0.1129528577439487, 0.09720842484966852, 0.12853274907683954, 0.11064988444559276, 0.10050114113255404, 0.13411510968580842, 0.1289159050793387, 0.088290258863708, 0.08736557996599004, 0.13818478037137538, 0.11139804351842031, 0.15165701683145016, 0.1546883932314813, 0.1840714001446031, 0.047089696818147786, 0.1605211544665508, 0.14925898925866932, 0.1577096912660636, 0.19192672159988433, 0.20496158074820414, 0.17150966014014557, 0.08733122595003806, 0.1871534949168563, 0.06558906723512337, 0.07767700531985611, 0.13533353805541992, 0.11736579399439506, 0.1613312234985642, 0.0726807929459028, 0.15382143115857616, 0.177011824271176, 0.1376770474598743, 0.11345331018674187, 0.09071272535948083, 0.12794807029422373, 0.08202507044188678, 0.14162120613036677, 0.118116609955905, 0.22870813932968304, 0.08808891419903375, 0.15103880781680346, 0.24841098755132407, 0.19111251138383523, 0.1495865435572341, 0.15718548267614096, 0.16783496044809, 0.11084941084845923, 0.11265693377936259, 0.21312140539521351, 0.12127864145440981, 0.20108330994844437, 0.15782516944454983, 0.13647573301568627, 0.10041370871476829, 0.16040536458604038, 0.1501698567881249, 0.16304132470395416, 0.1728699723025784, 0.09601450961781666, 0.10194263682933524, 0.1447946741245687, 0.18459835468092933, 0.10097650156239979, 0.16019551490899175, 0.13016853161389008, 0.14938194828573614, 0.1344877271912992, 0.12355808124993928, 0.1638310292037204, 0.1360584530630149, 0.33692723780404776, 0.13341088575543836, 0.11252705793594941, 0.13993374042911455, 0.13197900087106973, 0.3454880299977958, 0.19202795054297894, 0.14366095449076965, 0.15688805957324803, 0.14130836119875312, 0.1472468487918377, 0.15463619056390598, 0.1893864688463509, 0.05677189270500094, 0.14992552693001926, 0.15612591843819246, 0.11605265273828991, 0.09895726616377942, 0.24605735525256023, 0.11969112820224836, 0.1270817464683205, 0.14429706410737708, 0.07575585957965814, 0.12501919933129102, 0.2026117779314518, 0.11383799501345493, 0.0916808273177594, 0.0731144001474604, 0.14587169367587194, 0.18036327412119135, 0.09373826105729677, 0.1650728945969604, 0.10830023005837575, 0.12142655890784226, 0.10927753464784473, 0.14384861395228654, 0.1193056047486607, 0.08143462517182343, 0.23841526766773313, 0.08806656071101315, 0.1409301330568269, 0.11764107883209363, 0.057598934654379264, 0.12445263637346216, 0.12546778307296336, 0.09609985660063103, 0.20077037595910951, 0.12292800529394299, 0.10386606096290052, 0.19072142924414948, 0.1395628447062336, 0.08852223196299747, 0.11545013272552751, 0.1104366134677548, 0.13458839210215956, 0.12984676606720313, 0.1337380986660719, 0.11937079500057735, 0.09349191997898743, 0.14453190931817517, 0.18013819557381794, 0.13094514462864026, 0.15057076496304944, 0.14650171768153086, 0.1516103357425891, 0.15461267932550982, 0.2126908558420837, 0.1446529832901433, 0.1862432953203097, 0.06919891806319356, 0.1138760226604063, 0.0990074650326278, 0.208573984564282, 0.21758238086476922, 0.25775026297196746, 0.08416832613875158, 0.13242287939647213, 0.1515194374951534, 0.1320720958756283, 0.0943111619562842, 0.16663723799865693, 0.2653507160721347, 0.12565475975861773, 0.1359873850014992, 0.1746853842632845, 0.18553586531197652, 0.1444327732315287, 0.15625827305484563, 0.12591241858899593, 0.1641244743950665, 0.18280428688740358, 0.13056273077381775, 0.11888755296240561, 0.1650358911138028], [0.023365931447187904, 0.01462834019548609, 0.10739996781921946, 0.027486873404996004, 0.047829662580625154, 0.058850700297625735, 0.04588387382682413, 0.03509750320517924, 0.015023108953755582, 0.03770532479393296, 0.026122924718947615, 0.04647330606530886, 0.031367984774988145, 0.018268423336849082, 0.09019917401019484, 0.022233508716453798, 0.015864230372244492, 0.034947351887240075, 0.019620295424829237, 0.06157035240903497, 0.03403609101951588, 0.0355661546200281, 0.03000190612510778, 0.060762283465010114, 0.0900876143714413, 0.04644835506042, 0.055467167403548956, 0.033571825697436, 0.046714107011212036, 0.026826228386198636, 0.03176039535901509, 0.04098752855497878, 0.026672982312447857, 0.06059674371499568, 0.05876754265045747, 0.03339602204505354, 0.05742389912484214, 0.048243135315715335, 0.02095722251397092, 0.0681212825293187, 0.028925511833222117, 0.02334945762413554, 0.13730155042139813, 0.02785190059512388, 0.049925331768463366, 0.04581352564855479, 0.06312788289505988, 0.028215731072123162, 0.04632067968486808, 0.004702698070104816, 0.05356261979613919, 0.020617636146198492, 0.05213844582613092, 0.043937810478382744, 0.026722565198724624, 0.026381553907413036, 0.0340377237444045, 0.0611452131124679, 0.02158339848392643, 0.041174382786266506, 0.03255467890994623, 0.036829753807978705, 0.00864078272570623, 0.068198146764189, 0.04099473109818064, 0.046034615152166225, 0.03237758392060641, 0.021714821705245413, 0.030572769828722812, 0.046258829097496346, 0.06788001774111763, 0.04222826588375028, 0.06747992592863739, 0.012656274775508791, 0.037323534343158826, 0.03495638753520325, 0.016281022362818476, 0.010578331784927286, 0.04887253220658749, 0.018128895862901118, 0.07615917973453179, 0.03388087825442199, 0.04898137187410612, 0.05216232813836541, 0.03150738979456946, 0.05715630293707363, 0.0204915934955352, 0.12538476643385366, 0.023021933011477813, 0.028321290446911007, 0.01617680441995617, 0.07318077783565968, 0.05621524484013207, 0.02481374096532818, 0.03675024752737954, 0.015400656175188487, 0.028841725215897895, 0.07319445561734028, 0.010879910914809443, 0.019873816781910136, 0.015865783316257875, 0.03531786169332918, 0.023138170035963412, 0.02115062619850505, 0.04721936857094988, 0.011486191760923248, 0.06825697681051679, 0.023315522921620868, 0.05456642647914123, 0.0781892950180918, 0.03466547677817289, 0.04612687152985018, 0.04015603743027896, 0.0034397909348626854, 0.0199950855676434, 0.057388725035707466, 0.034146414982387796, 0.07501164131099358, 0.0641932878352236, 0.06599666958209127, 0.03255107207223773, 0.0710419008100871, 0.03857786410662811, 0.022534930139954668, 0.01449414319722564, 0.05461556036607362, 0.014601347356801853, 0.028790405704057775, 0.043668247599271126, 0.051482992130331695, 0.02689100303541636, 0.011732309267245, 0.015738174733996857, 0.09762731526279822, 0.0448698403488379, 0.06540896283695474, 0.02784888190944912, 0.0301474635489285, 0.033403369307052344, 0.021484909921127837, 0.06192053479026072, 0.054164772445801646, 0.0609488593909191, 0.0588043643074343, 0.03388127530342899, 0.036564870169968344, 0.04243979652528651, 0.06500769100966863, 0.021764155972050503, 0.03573287067411002, 0.03336808018502779, 0.07867514941608533, 0.03119062261248473, 0.027583788614720106, 0.06308054129476659, 0.02361613169341581, 0.04004845570307225, 0.0657787527597975, 0.046729105815757066, 0.04358468177088071, 0.014409987361432286, 0.05072402367659379, 0.037282701377989724, 0.05171303193492349, 0.02041018546151463, 0.059830914105987176, 0.018750331364572048, 0.03223961124604102, 0.09820001578191295, 0.05547809552808758, 0.0553588435286656, 0.04068282498337794, 0.01846141884016106, 0.028993672531214543, 0.02779679427476367, 0.027534971995919477, 0.022453956262324937, 0.057759583651204593, 0.040415536786895245, 0.027362515429558698, 0.01942767656146316, 0.032019694335758686, 0.02783656967949355, 0.0336008844897151, 0.03538238401233684, 0.00974334421698586, 0.03273505419201683, 0.05610439395240974, 0.027058336927439086, 0.009049298842001008, 0.031829125655349344, 0.010272605904901866, 0.039510394926765, 0.07793838973157108, 0.08248742844443768, 0.04190050378383603, 0.10249914368614554, 0.06288155665970407, 0.0557952634699177, 0.04790927647263743, 0.13279172679176554, 0.043044446501880884, 0.03614053981436882, 0.04733685796963982, 0.056712917939876206, 0.04771130486915354, 0.043106668163090944, 0.052906294076819904, 0.02823329770762939, 0.08750441353186034, 0.053658783581340685, 0.04296688464819454, 0.021807846205774695, 0.02207271129009314, 0.037049882230348885, 0.02053709456959041, 0.02089969679218484, 0.029400811035884544, 0.06921615815372206, 0.029939048072264995, 0.10511369284358807, 0.06625716341659427, 0.05792654832475819, 0.02125753071595682, 0.024905694917833898, 0.02989577715197811, 0.02988379703310784, 0.051524099690141156, 0.05666551696776878, 0.07392480314592831, 0.03245259649702348, 0.033618907546042465, 0.05781536347058136, 0.02882878772652475, 0.027206289632886183, 0.01674406314123189, 0.11349397245794535, 0.04285020419047214, 0.013763529423158616, 0.005960989510640502, 0.05973015271592885, 0.048119103885255754, 0.04280083281628322, 0.05793920194264501, 0.02838215954398038, 0.01451594100217335, 0.04023738052637782, 0.035201897408114746, 0.010073342036776012, 0.040001859961193986, 0.009248760306945769, 0.05507046720595099, 0.07329879415920004, 0.042158299911534414, 0.015516376479354221, 0.015165440818236675, 0.09217712373356335, 0.02440814427245641, 0.04751815722556785, 0.05620875846943818, 0.048016706059570424, 0.09159520574030466, 0.07982560447999276, 0.031050942998263054, 0.05042711265559774, 0.03571856206690427, 0.024688548073754646, 0.024619656360300723, 0.06432870752178133, 0.021114919618412387, 0.0846448220545426, 0.020577923824021127, 0.03081971204665024, 0.014663200727227377, 0.015341396610892843, 0.08991839727968909, 0.029608209770231042, 0.009240348063030979, 0.04326538757595699, 0.06231106031918898, 0.05317451366863679, 0.06775497327907942, 0.10275972657836974, 0.028932638306287117, 0.025133222552540246, 0.011145476400997723, 0.04892598539299797, 0.018332943800487556, 0.01860897635197034, 0.013866848439647583, 0.07608338419231586, 0.042874973369180225, 0.04752178261696827, 0.0203653745847987, 0.008181279208656633, 0.07262798913870938, 0.02407103111181641, 0.0724089219875168, 0.011794503097917186, 0.025120422360487282, 0.007117055210983381, 0.02817147680616472, 0.010146960303245578, 0.022348467391566373, 0.07336178765399382, 0.06476805152487941, 0.058809730035136454, 0.04814304928004276, 0.04280516324797645, 0.03393478044017684, 0.032053306204034016, 0.03170100499119144, 0.06773181827156805, 0.043348645413061604, 0.02967681946756784, 0.036966338666388765, 0.049330095935147256, 0.04101387850823812, 0.024656394525663927, 0.0301582636529929, 0.060557042525033467, 0.07376650304649957, 0.02097436983603984, 0.039559755168738775, 0.06403184845112264, 0.013377099621720845, 0.005694371566278278, 0.06893385259900242, 0.03236464457586408, 0.030167091499606613, 0.04838382054003887, 0.009960518891602987, 0.1356291800038889, 0.06530254628160037, 0.03260440280428156, 0.046572783539886586, 0.04042732580273878, 0.014705129287904128, 0.10701335340854712, 0.02885304482333595, 0.02322764335985994, 0.009793113567866385, 0.08645287191029638, 0.03695603765663691, 0.06341540574794635, 0.03120671237411443, 0.06532582003274001, 0.058050794978043996, 0.04134595248615369, 0.05391234204580542, 0.01988751311728265, 0.0575794940959895, 0.07868319429690018, 0.15184950025286525, 0.33788101631216705, 0.16897792724194005, 0.09268007721402682, 0.19635057484265417, 0.12456185824703425, 0.16002379677956924, 0.15550150506896898, 0.14663398324046284, 0.13214412872912362, 0.174039997800719, 0.08332759898621589, 0.11517489983816631, 0.221128273406066, 0.09173563492367975, 0.06937646205187775, 0.19022380438400432, 0.17726047342875972, 0.10926986826234497, 0.20570019580191, 0.1620621350593865, 0.16977177292574197, 0.1047394351917319, 0.3175000083865598, 0.09869872417766601, 0.1146260296809487, 0.09032417394337244, 0.20556677249260247, 0.11872905248310417, 0.12356311301118694, 0.1005424713366665, 0.15516667772317305, 0.2129642036743462, 0.15905631822533906, 0.13978689908981323, 0.11881475569680333, 0.10993670279276557, 0.12219651485793293, 0.13381299620959908, 0.07796523321303539, 0.0974113799748011, 0.23744544392684475, 0.1596256048651412, 0.15533337893430144, 0.15953010530211031, 0.1581695259665139, 0.21993004629621282, 0.20354210457298905, 0.10439578371006064, 0.16812794550787657, 0.08134003102895804, 0.1339769663172774, 0.19566864502849057, 0.09428636680240743, 0.1434918338782154, 0.08536563298548572, 0.16601606039330363, 0.1961544548976235, 0.14285720855696127, 0.251961451722309, 0.11914345290279016, 0.15409951389301568, 0.12540379510028288, 0.33529089123476297, 0.13674621615791693, 0.12337814012425952, 0.10070006639580242, 0.0934966623026412, 0.14708592148963362, 0.2032291260547936, 0.09717388529679738, 0.09373291759402491, 0.09423235329450108, 0.16987628216156736, 0.16510925983311608, 0.14402552711544558, 0.10912166137131862, 0.09176023711916059, 0.07111453480320051, 0.16893470456125215, 0.06008332966302987, 0.20506586733972654, 0.1600187353324145, 0.14050805883016437, 0.15350874949945137, 0.12037640510243364, 0.2017393833375536, 0.1317457141703926, 0.09265377550036646, 0.10358847546740435, 0.16417320381151512, 0.16643776354612783, 0.08839660120429471, 0.24537113582482561, 0.13242054905276746, 0.09616466093575582, 0.1662042542011477, 0.2082963174325414, 0.1942034822423011, 0.06300581444520503, 0.07575304683996364, 0.21294496720656753, 0.17832791927503422, 0.19279965054010972, 0.09615833041607402, 0.19040264713112265, 0.1312139505171217, 0.09783050045371056, 0.15137669281102717, 0.12680459883995354, 0.13836877362336963, 0.1342077148729004, 0.14415604120586067, 0.14279874216299504, 0.141062012698967, 0.12372910918202251, 0.1711229418287985, 0.12223117315443233, 0.1971766445785761, 0.07381526214885525, 0.12100583538995124, 0.13208018528530374, 0.10549003593041562, 0.21386028762208298, 0.13513817510101944, 0.12747702916385606, 0.1347446587169543, 0.11058834556024522, 0.18857222894439474, 0.11780589498812333, 0.09470775083173066, 0.12753413000609726, 0.1603267711470835, 0.10140214551938698, 0.10943913730443455, 0.120224012498511, 0.10278278510668315, 0.1404096352052875, 0.1395000293268822, 0.19908571557607502, 0.1323471061186865, 0.16964905138593167, 0.1989476167364046, 0.1871814887272194, 0.19956655305577442, 0.1043354396824725, 0.17383789614541456, 0.10244556804536842, 0.11906371655641124, 0.072770911938278, 0.21337710495572537, 0.1338679893524386, 0.1275582646485418, 0.17263478570384905, 0.12820344330975786, 0.29781869729049504, 0.11903006015927531, 0.0997601957351435, 0.15652633679565042, 0.14435662887990475, 0.10257996356813237, 0.18152984121115878, 0.1439235411817208, 0.20505469059571624, 0.14679737447295338, 0.2295767786563374, 0.16228290915023535, 0.1359693062840961, 0.170690729864873, 0.11777252802858129, 0.14956500643165782, 0.13124062330462039, 0.13583708525402471, 0.12092919379938394, 0.18075621163006872], [0.03244472602091264, 0.04385827080113813, 0.0191986683421419, 0.03166299960867036, 0.0626264137099497, 0.009171253186650574, 0.02096063082717592, 0.02333221196749946, 0.021871834178455174, 0.04770973522681743, 0.046892289246898144, 0.027903145892196335, 0.06081126892240718, 0.07532372925197706, 0.027668664333759807, 0.04320808264310472, 0.03891406813636422, 0.03538225413649343, 0.031905303403618746, 0.02527039556298405, 0.01605867120815674, 0.028970560197194573, 0.020871181623078883, 0.06086123401473742, 0.05637656548060477, 0.0023279201286641182, 0.02487967150955228, 0.023975217991392128, 0.06919910360011272, 0.04924432963889558, 0.04473442066228017, 0.03233621289837174, 0.11521833774168044, 0.04148494190303609, 0.03917724854545668, 0.07533313968451694, 0.008939088984334376, 0.0303786536824191, 0.04297320774639957, 0.061505362536991015, 0.02213797390140826, 0.07587851432617754, 0.0631399205303751, 0.03917984606232494, 0.044709681169479154, 0.04100393744010944, 0.03649884871265385, 0.034213419785373844, 0.025876322033582255, 0.09551402748911642, 0.015789650096849073, 0.035833164511132054, 0.04463580407900736, 0.0407630845438689, 0.035729883529711515, 0.02381326095928671, 0.03706074727233499, 0.016795538504084107, 0.08606375646195374, 0.016694090627424885, 0.05509844246262219, 0.054993985177134164, 0.09315485134720802, 0.03637894733401481, 0.038728716754121706, 0.045649488747585565, 0.03010975502547808, 0.050353985134279355, 0.020215204713167623, 0.02363855568546569, 0.04180835501756519, 0.05184234003536403, 0.04291158722480759, 0.055043252650648355, 0.006608351941395085, 0.006989683652136591, 0.025602610548958182, 0.038113420669105835, 0.01691074950940674, 0.05275071394862607, 0.015261155604093801, 0.07852786278817803, 0.03034411227417877, 0.00524290643625136, 0.005056696481915424, 0.03193522679794114, 0.09410304148332216, 0.047550952731398866, 0.0567019193113083, 0.052279535520938225, 0.03214191863662563, 0.15744873730000108, 0.004342439642641693, 0.07387868608930148, 0.019384027145861182, 0.0390653660724638, 0.010454663079144666, 0.016870263498276472, 0.010240376286674291, 0.021180859439482447, 0.013215910712460754, 0.04742159268062096, 0.025307963078375906, 0.05023139347031247, 0.05987788463244215, 0.009131586321018403, 0.021554749728238676, 0.05847256863489747, 0.04754674846481066, 0.041262457161792554, 0.09849909387412481, 0.034024450433207676, 0.041907290724338964, 0.04861607194470707, 0.02362939943850506, 0.0076258141416474245, 0.048342675872845575, 0.035385270966799, 0.05802728745038621, 0.04721159457403701, 0.031756977768964134, 0.011457651544333203, 0.04203037591651082, 0.04758854251122102, 0.026620362186804414, 0.08859091030899435, 0.03133667356451042, 0.0061534005726571195, 0.07714029154158197, 0.023465115773433354, 0.06407098189811222, 0.017498296692792792, 0.05053096137999091, 0.06122969549323898, 0.015002894706412917, 0.019813662001979537, 0.03292605331807863, 0.07062550401315093, 0.04348018366727047, 0.015786438452778384, 0.12578714406117797, 0.06022551031492185, 0.07044545156531967, 0.07196178543381393, 0.07030778317130171, 0.053015015000710264, 0.017512427184556145, 0.02660119251231663, 0.024883749611035455, 0.02984912760439329, 0.06194425011926796, 0.017979549775191117, 0.0436672790965531, 0.04534469982900191, 0.030596481446991675, 0.06190218518895563, 0.045592718161060475, 0.03542336911777966, 0.03372958402906079, 0.003238645258534234, 0.017190188518725336, 0.04906126778223552, 0.07866475192713551, 0.042459574760869145, 0.01570051630551461, 0.0480193443945609, 0.030097030903561972, 0.06563292074133642, 0.03009139243658865, 0.026135452171729412, 0.030670297310280148, 0.06665097665973008, 0.11534851044416428, 0.03978165361331776, 0.061611352357431315, 0.04318664941820316, 0.05123846189235337, 0.04709634646133054, 0.01540714254588238, 0.037134550148039125, 0.0358877754479181, 0.017524880422570277, 0.07440827524987981, 0.037023532277089544, 0.01605220153578557, 0.03335908164444845, 0.06272978745982982, 0.05521009115909692, 0.051120586576871574, 0.010461094716447406, 0.07119276458979584, 0.062085495665087365, 0.023911291245894972, 0.08417524295509793, 0.0582569079415407, 0.008007401429495076, 0.02200899791205302, 0.0539750015741447, 0.003753324208446429, 0.047508056595688686, 0.04855584666074719, 0.022449306707130745, 0.04004944647022057, 0.007703397332079476, 0.047850939954514615, 0.013228197894932237, 0.024377977824769914, 0.042381252205814235, 0.05149723023350816, 0.026692704886954743, 0.04180457006441429, 0.010780768334370805, 0.07737279898719862, 0.03312586173706222, 0.015869707422098145, 0.0763733487110585, 0.04313534474931657, 0.08075043180724606, 0.0863911623309832, 0.054090338744572364, 0.007599963746542926, 0.029081232969474513, 0.07348432365688495, 0.0681994306796696, 0.0061124660260247765, 0.026476914317754563, 0.022393936924345326, 0.037492936971830204, 0.014746584729437018, 0.03902650722011458, 0.0516916061314987, 0.023288273114303593, 0.09771935641765594, 0.004885257585556246, 0.10022231625043787, 0.03262978425482288, 0.018928615645563696, 0.017948218155652285, 0.02587742783362046, 0.04698600394476671, 0.039928149853949435, 0.03486731126031373, 0.05192496704694349, 0.0839768371952232, 0.013334469731489662, 0.08378602360608056, 0.04904899265966378, 0.028730468002322596, 0.018261244913446717, 0.10365338370320387, 0.01794551673810929, 0.059738947165897116, 0.06250130987609737, 0.04161506636592094, 0.052461335726547986, 0.05462234730657656, 0.02008949602895882, 0.024397268098255154, 0.018340871793043334, 0.03404551629500929, 0.004206236526442808, 0.022555110990651883, 0.05363717224099673, 0.022293108740996104, 0.11569426962523721, 0.035095974380965345, 0.04860179302340839, 0.07220707266242243, 0.0617004360537976, 0.062015859948587604, 0.055633530937484466, 0.033564111072337255, 0.02164100769732613, 0.05821454615215771, 0.0102256344507623, 0.05293428788718302, 0.08734923787415028, 0.023412464106513653, 0.024852790920704138, 0.08102383158984594, 0.006695290367133566, 0.05245318323432002, 0.040863975809770636, 0.03819707184447907, 0.0379350232105935, 0.1189622278616298, 0.07805029817973264, 0.028603026403288823, 0.028382751406752504, 0.026457765052327886, 0.06336467995424755, 0.0233446856145747, 0.020325569494161755, 0.014245390138967196, 0.01818279990402516, 0.010855168638954638, 0.03940135859011207, 0.009056302860699361, 0.02296967839356512, 0.04689822642831132, 0.07129580437322147, 0.06522836862131953, 0.04077048375620507, 0.030279864549811464, 0.06514738546684384, 0.015415195775858592, 0.04791705418028869, 0.017765525517461356, 0.07167242947616614, 0.06229045829968527, 0.05627043836284429, 0.03724669979419559, 0.02063977997750044, 0.040348724942305125, 0.07119794478057884, 0.042870854449574836, 0.01006864145892905, 0.018388534372206777, 0.03951082908315584, 0.05277213604131248, 0.04494869725021999, 0.03995300809037872, 0.038279235013760626, 0.051188845609431155, 0.03155893566145096, 0.00811639138191822, 0.028878712000732776, 0.019846850846079178, 0.028878828888991848, 0.06733353729941882, 0.0466008218791103, 0.05284123370074667, 0.09099038506974466, 0.0692051075748168, 0.0601257285597967, 0.044923716559424065, 0.06059907405870035, 0.05709705357730854, 0.050873503350885585, 0.03932340710889548, 0.027380482824810315, 0.0020820932195420028, 0.039971539517864585, 0.034807223273674026, 0.06990547975874506, 0.051198174405726604, 0.01740704035910312, 0.039755129255354404, 0.06377525089192204, 0.054352309452951886, 0.024271418405987788, 0.031386082046083175, 0.14129170740488917, 0.1364407778601162, 0.16729169350583106, 0.12626484967768192, 0.1564003201201558, 0.11159267174662091, 0.18427964678267017, 0.08965561763034202, 0.08580543712014332, 0.11022486389265396, 0.11198683379916474, 0.14091527526034042, 0.158497896627523, 0.08516229194356129, 0.13176457956433296, 0.17320873303106055, 0.0982984913571272, 0.17061985476175323, 0.1334524163394235, 0.08957054524216801, 0.16258076269878075, 0.09344468970084563, 0.19535105035174638, 0.13168908830266446, 0.13057879084954038, 0.0778085584170185, 0.16880692157428712, 0.09615343224140815, 0.13525297050364316, 0.08436165560851805, 0.19716577953658998, 0.12832540785893798, 0.18281197553733364, 0.18698251893511042, 0.11930996857699938, 0.07963564436067827, 0.1478741565370001, 0.06488914776127785, 0.09851617811364122, 0.1781146408757195, 0.1555590215139091, 0.2515142335323617, 0.24734992417506874, 0.15961224620696157, 0.15628334280336276, 0.11967962491326034, 0.1732137202634476, 0.17559516825713217, 0.15142086544074118, 0.12109102652175352, 0.12892118917079642, 0.10592389546218328, 0.26708751975093037, 0.1834413464530371, 0.08401189625146799, 0.12026909054839052, 0.25381153682246804, 0.09898102231090888, 0.1338243213831447, 0.0798715211567469, 0.14660977438325062, 0.08771787746809423, 0.18174319382524118, 0.16172356728930026, 0.136585125583224, 0.16945042298175395, 0.17406512692105025, 0.20135434227995574, 0.10098007129272446, 0.15085370134329423, 0.16407439426984638, 0.13376260438235477, 0.11967567668762058, 0.1831756575847976, 0.10451556634507142, 0.11349883352522738, 0.18268465268192813, 0.20155022473772988, 0.11428646743297577, 0.17615436168853194, 0.08825385652016848, 0.09971338105970062, 0.0907049179659225, 0.06133206363301724, 0.1562226944952272, 0.12150453636422753, 0.14900987996952608, 0.12162380691734143, 0.21932970819761977, 0.15928466222248971, 0.18863384204450995, 0.3641422383952886, 0.09638160554459319, 0.16451509640319273, 0.11115680099464953, 0.1926383818499744, 0.07773053643177263, 0.18054324493277818, 0.0831043312791735, 0.11344284590450116, 0.1398349754163064, 0.13860398990800604, 0.11159190733451396, 0.1612525261589326, 0.15397812821902335, 0.11462496098829433, 0.12228849664097652, 0.10978200953104533, 0.11290150854620151, 0.129485251090955, 0.16315377491991967, 0.10760399905848317, 0.09973404245101847, 0.2049132075626403, 0.12423987747752108, 0.0731715900474228, 0.11713957253959961, 0.10012682410888374, 0.13426411809632555, 0.11672359134536237, 0.09866666339803487, 0.07634118403075263, 0.1440997567260638, 0.13572065712651238, 0.185594895738177, 0.10803238154039718, 0.08440576144494116, 0.09729791301651858, 0.19534462335286662, 0.09311277157394215, 0.1720664935419336, 0.1360370495240204, 0.1835988598759286, 0.15844121138798073, 0.14160462655127048, 0.12463147169910371, 0.15469251957256347, 0.18628580553922802, 0.13030700152739882, 0.11409487458877265, 0.2544234524248168, 0.19568268646253273, 0.19056810153415427, 0.16542918485356495, 0.19817968684947118, 0.13618740864330903, 0.08945894107455388, 0.08584555762354285, 0.11319254917907529, 0.09742093141539954, 0.1221133943181485, 0.10928189105470665, 0.10951522970572114, 0.12565011391416192, 0.16581821866566315, 0.1386394794099033, 0.21843666705535725, 0.17640899255638942, 0.1347245613578707, 0.15933956630760804, 0.12800762022379786, 0.21953801420750096, 0.1928129795123823, 0.15739887981908396, 0.10290132093359716, 0.16651516954880208, 0.11399485534639098, 0.10606177907902747, 0.12821971118682995, 0.1406252884771675, 0.07191629178123549, 0.19693802925758064, 0.27594582410529256, 0.15047332097310573, 0.15274690522346646, 0.08463405349175446], [0.018600066869112197, 0.04643067339202389, 0.02989667329529766, 0.03756789388717152, 0.025785579637158662, 0.015185513129836181, 0.030967937491368502, 0.04273170176020358, 0.0619024783372879, 0.026666471821954474, 0.05630274405120872, 0.08347832917934284, 0.027551573839446064, 0.03141343760944437, 0.029071696371829603, 0.02924743137555197, 0.030413623680942692, 0.04871172735875007, 0.014426467678276822, 0.01901391809951747, 0.048622547183185816, 0.0545892067020759, 0.0354267236252781, 0.03275140370533336, 0.05072163767181337, 0.10507919039810076, 0.037175000907154754, 0.008324186237587128, 0.012537680504465243, 0.0290780046270811, 0.055416786708519794, 0.0296122025247314, 0.05985586511087604, 0.03254221082897857, 0.09675434179371223, 0.03464808083663229, 0.08430274392594583, 0.009566563712724019, 0.04964954227034468, 0.072317296435358, 0.014293264230218483, 0.027470004388305824, 0.03997735424491111, 0.06136488140327856, 0.033818756783148274, 0.06306502298684791, 0.038860915519762784, 0.07395735374302603, 0.04244180032401346, 0.050295915789320134, 0.12458438985049725, 0.03723958259797655, 0.033445315493736416, 0.03887047067109961, 0.03220466722268611, 0.06714984090649523, 0.03056327590456931, 0.014493327762465924, 0.04126246458326932, 0.014473115370492451, 0.021874253579881042, 0.08939876774093136, 0.028628571126319002, 0.045104963865014724, 0.018466804976924323, 0.033679707994451746, 0.03602277211030014, 0.08042048779316247, 0.011733418778021587, 0.04578565058181994, 0.04505243465246167, 0.02401161105808569, 0.02348150053876452, 0.07650830084457994, 0.03960546033340506, 0.05626121346722357, 0.01378901106363628, 0.04413497314089909, 0.033000939729390666, 0.061329577438300475, 0.0540932071453426, 0.07781333042657934, 0.02342609364859527, 0.016850633692229167, 0.07038916708552279, 0.08680729937623255, 0.030619261669926345, 0.010095199213537853, 0.027015917621611152, 0.033300834184046835, 0.06703225502860732, 0.038697798881912604, 0.02952904673293233, 0.03151186123432126, 0.07341376025578938, 0.014798927477386314, 0.02205245807999745, 0.01387793519825209, 0.0061544609161501285, 0.07893115325714462, 0.04756490139698144, 0.0026670811530493665, 0.03243040628149174, 0.10461307712830603, 0.017349047084280755, 0.03251216126955114, 0.04048595546919387, 0.011729069792636437, 0.0514772367750993, 0.08365234054508619, 0.04942662337271031, 0.03413404709135648, 0.023723410995444283, 0.06133884315204341, 0.044137203294667415, 0.06680728038190864, 0.01913667489134241, 0.042348100469098426, 0.060416290507419035, 0.017796558422560338, 0.03592306085920427, 0.021327700778783765, 0.010416127061034786, 0.01071309652616037, 0.027056936123699415, 0.025025509094120935, 0.020195253928250168, 0.028926074010087177, 0.06706453103106469, 0.04057130616274662, 0.012411747320584254, 0.03815283613221254, 0.030255319870775566, 0.02308801755134482, 0.03550812238245271, 0.053524402901530266, 0.06716827585478313, 0.05915489178732969, 0.010443888022564352, 0.048354861937696114, 0.04870734497671947, 0.10120327220647596, 0.061514335102401674, 0.023260539055627305, 0.037105194496689364, 0.03961431786592584, 0.059161285389564, 0.04824980722332839, 0.060603782985708676, 0.05011394117900636, 0.03343891447002534, 0.042059920815518126, 0.040935800861916505, 0.03591405118640978, 0.05494408687809482, 0.03168279639794491, 0.085983760363888, 0.03703695772856008, 0.06253846921026707, 0.07440273140673526, 0.0357676885323599, 0.025677528501546476, 0.033942031222977675, 0.022473417229775805, 0.014138243495835923, 0.05520745282410644, 0.04794310727447737, 0.024440026936645154, 0.008739984677959, 0.029478781070793048, 0.01570396914758021, 0.0538882222463144, 0.03320952775538899, 0.05201732361456379, 0.008503062381350901, 0.028508007380878553, 0.029386925452854484, 0.015243533307511825, 0.03134960548777599, 0.050192727576359175, 0.018504313120502047, 0.04585412854794413, 0.0481348299945239, 0.004040764961246168, 0.04148776948568411, 0.06217049012775533, 0.03848472457320895, 0.02997265622980194, 0.028871667163912207, 0.11177695443620905, 0.016123803943628445, 0.024066678415692877, 0.04906657042738516, 0.04264553099346813, 0.023305591130338144, 0.018772614348563366, 0.01517085107479943, 0.04040208164951764, 0.03778136524488218, 0.040475094137946144, 0.018242333135276567, 0.009014187835418852, 0.10932567034615204, 0.020389869168866426, 0.03340081631904468, 0.018324173470318783, 0.05263407059828751, 0.019234996470913757, 0.06895133017678745, 0.061744553022435866, 0.04130056644498836, 0.040726953084231354, 0.03573093737941235, 0.037616578774759546, 0.014836851223662961, 0.034972555222339, 0.016866573168954346, 0.062207898081396706, 0.03701552079292014, 0.09670137471402995, 0.07023548314464279, 0.0396951303264359, 0.021237004766589962, 0.02046442161372397, 0.034573598895804025, 0.015134624991333112, 0.10313779886928387, 0.04191247462586034, 0.04905369416519534, 0.0628361817507539, 0.035611477578640915, 0.026547846937319264, 0.0507837554323487, 0.01693139049166348, 0.050317490022280253, 0.009307996679126518, 0.030467711403616704, 0.09640215561375953, 0.037995092643541284, 0.038909147697268054, 0.040753922730800696, 0.05031117434555199, 0.05142558700754307, 0.025638209517637733, 0.027613806632871274, 0.02202698015025817, 0.027735747062251903, 0.027243807053309865, 0.05627733662549872, 0.03108593897195533, 0.04733210080303252, 0.03945445183489937, 0.034224117844132707, 0.07878500211518258, 0.03463729743089061, 0.04387634580780286, 0.08241734001785517, 0.059408858433016576, 0.04087606168468483, 0.06622856846661307, 0.06526286364533007, 0.058285922204959206, 0.005824918589496519, 0.036251182900741696, 0.10015504056354985, 0.0880700265406631, 0.06904052148456685, 0.06099034544604365, 0.11458421708084643, 0.03137445259199012, 0.07697608394664712, 0.049852883312269114, 0.028937662646058016, 0.014678137376904488, 0.03376854307134636, 0.043960156544926576, 0.04579776985337958, 0.03197218575223815, 0.04721577657619491, 0.04100592268514447, 0.033588828300707974, 0.04518961322901305, 0.04860859480686486, 0.039778254576958716, 0.09002382677863352, 0.027272324077785015, 0.04003340123745147, 0.05994645536702592, 0.03225510357879102, 0.08551890874514356, 0.0322380675788736, 0.09519795421510935, 0.06177897012094036, 0.022188853690749966, 0.0428678079333622, 0.028088545514037833, 0.040914222918218, 0.04832423721381929, 0.06995857300353236, 0.044156803414807655, 0.05847356311278418, 0.07296991883777082, 0.02046843848802382, 0.02175527060899185, 0.05044472753070295, 0.034149513448937796, 0.06466257749707438, 0.012584814303409075, 0.08009302255231887, 0.08378050944884308, 0.05981128058920149, 0.028990681676077656, 0.0698158134764526, 0.04681074948166497, 0.020726071343233343, 0.04827023854886647, 0.0905511449673213, 0.07330500593525358, 0.059200652613071725, 0.07000961792073213, 0.03525103129504714, 0.024674901833350305, 0.06687506072921678, 0.054408538271673024, 0.08869845492881723, 0.05796597120934166, 0.08952727061114274, 0.04587006245856173, 0.022969602323428262, 0.03660264177597128, 0.017592989170225337, 0.020884992991341278, 0.0496743708208669, 0.021972233771521132, 0.0724453317525331, 0.08611451194155961, 0.027418707140896004, 0.01612970958376536, 0.06932466756552458, 0.055002787048579194, 0.023510435021307785, 0.020052761574334, 0.035779136160272174, 0.04299327913031448, 0.027117851604998577, 0.029497670584532898, 0.03140423126751557, 0.06900861655594781, 0.04734904032375198, 0.09893079375615343, 0.0024381251159866224, 0.05542491693631746, 0.13987962302053347, 0.15080982557265088, 0.16883343108929694, 0.1407882195780985, 0.11883715371368453, 0.20880292227957398, 0.10182971906033345, 0.11893686125404201, 0.1397073408588767, 0.08683024658239447, 0.2497545420192182, 0.13162559014745057, 0.09610799796064384, 0.221690954931546, 0.09212915872922167, 0.1128575808252208, 0.14478901895927265, 0.2307188103441149, 0.05567838634306099, 0.14257091766921803, 0.1409587057423778, 0.21021855412982404, 0.21053312084404752, 0.10894944600295275, 0.1035372969636228, 0.2308588832966052, 0.19699649565154687, 0.11371404892997816, 0.14259009476518258, 0.12747070606565103, 0.21344216162106022, 0.08981471924926154, 0.1472564076539129, 0.11895162257133052, 0.1478430605493486, 0.16063638031482697, 0.12865474331192672, 0.1355441744090058, 0.15110833221115172, 0.13135204935679212, 0.04103620602109004, 0.14843348355498165, 0.06882709465571679, 0.1268671322031878, 0.16145832370966673, 0.10149106223252602, 0.13855337543645874, 0.23658354330109432, 0.13325948762940243, 0.0773375915014185, 0.1724961822037585, 0.12689867347944528, 0.09966259589418769, 0.1394888971117325, 0.07118278270354494, 0.1228058552078437, 0.07888705484219827, 0.11107075639301911, 0.162529272492975, 0.21126844076206908, 0.20495401084190235, 0.23820844595320523, 0.12667129427427426, 0.12002907256828621, 0.12790030566975474, 0.1819255988812074, 0.17019398073898628, 0.14879728434607387, 0.1279586978489533, 0.14458322140853852, 0.12107203496270813, 0.10503679150133394, 0.191041428479366, 0.1003586636215914, 0.21255863481201231, 0.12779181852238253, 0.11711398328770883, 0.12400957421050407, 0.19285019079688936, 0.1515723526244983, 0.16245804115897045, 0.1543594288523309, 0.1306360401213169, 0.1289346072007902, 0.1519851796911098, 0.13430361519567668, 0.09880076948320493, 0.17017263657180592, 0.1788196069537662, 0.14874079206492752, 0.18471116112777963, 0.16647239215672016, 0.214801108231768, 0.09198806903441437, 0.26704821560997516, 0.14421544270589948, 0.08738526172237471, 0.1484391832491383, 0.09469946104218252, 0.1251819820026867, 0.08549293357646093, 0.12619418237591162, 0.12925916322274134, 0.17887142370454967, 0.11070809108787216, 0.1744329946814105, 0.17445053905248642, 0.08945608380599879, 0.17782523296773434, 0.1412855030503124, 0.18294115376193076, 0.11324824736220762, 0.09068002633284777, 0.1449369586771354, 0.15599197562551126, 0.21774234337499365, 0.12522021745098755, 0.14785984792979434, 0.2252004822366871, 0.09329206703114323, 0.09691860133898444, 0.18331056518945843, 0.12659452651860192, 0.1192313306091819, 0.11341753124725074, 0.1078223685908597, 0.07878337681177072, 0.12543536606244743, 0.17179054819280282, 0.1626638535526581, 0.18445520923705772, 0.10504229823709466, 0.19256260857218876, 0.129725469450932, 0.1732467458350584, 0.11858666402986273, 0.12014436520985328, 0.11777629071730189, 0.19051937211770564, 0.2346998537541367, 0.109827941050753, 0.08400333186727948, 0.10524453347898088, 0.18364258721703663, 0.11549468385055661, 0.10098784900037572, 0.22737552411854267, 0.16506970336195081, 0.285949885728769, 0.12471517111407593, 0.15717435046099126, 0.08921438115066849, 0.2155909314751625, 0.08495420115650631, 0.14381800778210163, 0.147133641585242, 0.1403866583132185, 0.07247349625686184, 0.21134967624675483, 0.15771751350257546, 0.16543832811294124, 0.11288859517662786, 0.19388334942050278, 0.10487467676284723, 0.11908521657460369, 0.2550491422880441, 0.11744155985070392, 0.10292451304849237, 0.10418590434710495, 0.09569315225235187, 0.13035924872383475, 0.18923312629340217, 0.15066320687765256, 0.1723610667977482, 0.10992873212671839, 0.10426432709209621], [0.01834846581914462, 0.027374150449759327, 0.017448103390051983, 0.0216870486838161, 0.025016477156896144, 0.024384030039072968, 0.05792109725007322, 0.05333719243935775, 0.030033059629204217, 0.05526167413336225, 0.025142953963950276, 0.024474351266690064, 0.055644499880145304, 0.039529000569018535, 0.024289146458613686, 0.02035356330452487, 0.052921166716259904, 0.058092934123123996, 0.0463820033473894, 0.05394851432356518, 0.01859392003098037, 0.03285774975665845, 0.004628363631127286, 0.04758237897476647, 0.03231520269764587, 0.06908837516675703, 0.012446848122635856, 0.010567164317762945, 0.018495359108783305, 0.04305598689825274, 0.05922808610193897, 0.00833467835036572, 0.048374324760516174, 0.021235231033642776, 0.046826453326502815, 0.07066504564136267, 0.035730744421016425, 0.04143564845435321, 0.03755701400223188, 0.028443319934012834, 0.015618175020790659, 0.005386827424445073, 0.06229287027963437, 0.01485336864789133, 0.015977213079167996, 0.04293527657864615, 0.04839420689677354, 0.021940746300970204, 0.012089294359611813, 0.06065028966986574, 0.08597211606684141, 0.0582030614168616, 0.004035101446788758, 0.05083061092591379, 0.0052704953122884035, 0.012615429750439944, 0.015388202937174356, 0.023295583268918563, 0.054870933381607756, 0.05529184614715632, 0.03109027868049452, 0.038050991206546314, 0.02154655085178092, 0.07661557086976245, 0.027870224221260287, 0.05204196662816685, 0.02571369150246028, 0.02214389809523709, 0.06131859736342449, 0.017416374721506145, 0.04685725987656042, 0.1116824196651578, 0.011375359426892828, 0.0072050252219924005, 0.05180514730454888, 0.0422779044311028, 0.08412430936004966, 0.05724835893488489, 0.017874303957796656, 0.06288511896855198, 0.024103618816297967, 0.0520672070706496, 0.01998285311856307, 0.03654725158412475, 0.06501189898699522, 0.04664150641474407, 0.04314967562095262, 0.0286581401451258, 0.041166645896737464, 0.08300503192003816, 0.033090954821091145, 0.02570042561274022, 0.030860435545037035, 0.03336359761306085, 0.05041340889874846, 0.024131171048793476, 0.04574469887302257, 0.009968971025955398, 0.042017195373773575, 0.007427488626490231, 0.015144928784138756, 0.015222947058646241, 0.017617901212361176, 0.040949883114080876, 0.03423451533308253, 0.03850193868856877, 0.004987234706277377, 0.03313931687443983, 0.04135756338655483, 0.05577826457738411, 0.03210943112208042, 0.10417990037240088, 0.014475143289018888, 0.02100331174005987, 0.029258216636662837, 0.027937123268202413, 0.01768351448845351, 0.03682377209770493, 0.017813195518101566, 0.04734256137453485, 0.023758184324833564, 0.05275179006275721, 0.0037559701968348236, 0.018787954541039653, 0.03478491802525241, 0.03817423967120703, 0.11875294221681543, 0.019667644446599297, 0.007930167048471048, 0.07403471521683969, 0.029616636857099365, 0.0651082668628078, 0.046105534784146585, 0.03046342550078407, 0.07523602966102771, 0.04890583237283863, 0.04712101916084066, 0.02183130734920269, 0.046342142595676705, 0.03592390690755565, 0.014841602824162692, 0.07211492018541321, 0.046031345991650596, 0.04613811135641299, 0.026787588467414025, 0.036004337162012234, 0.012461659534892533, 0.023627371519978624, 0.004925668918076553, 0.0347939944913378, 0.08375659002922475, 0.020289580897951964, 0.0349415037635481, 0.03590484855521936, 0.034246437935507856, 0.1287003408651799, 0.017965974038816057, 0.03541223690262996, 0.022142053858260624, 0.03309465442725923, 0.024155233331839554, 0.05765061781858094, 0.03293088841019198, 0.0695531303063035, 0.028372953202051576, 0.0037130367218196625, 0.02220486552687362, 0.039164197878562845, 0.05298899530316703, 0.02249418252176838, 0.028685080105788074, 0.043597728727036156, 0.038660698919557035, 0.023779125876899343, 0.028663682132901158, 0.04577207670081407, 0.027740339101001155, 0.017536500599817373, 0.008593923521402758, 0.02519544792448869, 0.04116385542147327, 0.05677654226019513, 0.02839803037204547, 0.02265542709210422, 0.07107526776962914, 0.025403006220585667, 0.03405535717320163, 0.03115953404631, 0.04721666715340689, 0.0455751403933391, 0.025481512457190547, 0.023964762985997368, 0.07253508709254675, 0.027267420337011572, 0.06671181050478481, 0.04078085898072459, 0.09435441432287917, 0.07355383320827968, 0.03616411042457912, 0.042988421773770824, 0.06543369119754061, 0.05893514557101298, 0.03974336250394117, 0.016648461532895453, 0.0597332177858334, 0.016199874080484733, 0.09156857006018981, 0.03666848140710499, 0.01840041615650989, 0.08198782204999588, 0.04316701219067909, 0.07520865925471298, 0.02365966051002033, 0.05098348963656463, 0.029630186618305743, 0.052723785120178945, 0.03583180267014541, 0.05456870487250853, 0.052658672793768346, 0.045024507635389455, 0.024008586806303356, 0.024976349232019857, 0.033475921663921326, 0.04185806777968537, 0.007047858753139735, 0.07368302627583034, 0.03256868694734294, 0.03863424135488458, 0.05990114725136664, 0.019147788552800193, 0.0760085682850331, 0.03266501771577168, 0.008021838057175046, 0.06390927534084767, 0.06205322337336838, 0.05081583476567175, 0.03959631336329039, 0.0383352560311323, 0.015918904391583055, 0.020732075317937415, 0.0391602236777544, 0.03574376540200319, 0.0415705449267989, 0.02955709620437119, 0.040865786650101654, 0.023157386094680987, 0.024781353640719317, 0.018421298336761538, 0.016820873570395634, 0.010613123668008484, 0.09391186424181797, 0.04392674505652394, 0.03381403301318642, 0.09690851555205882, 0.05844212202646304, 0.05244879343081266, 0.029208579944679514, 0.052611334904213436, 0.0438322733680252, 0.06622817512834445, 0.06777142669307068, 0.027730010260711424, 0.029727819855907, 0.033327562632621266, 0.04080151666130405, 0.08753201400395483, 0.05576917697908357, 0.015347035077866167, 0.03841996847768314, 0.037061151742818765, 0.07590041510411538, 0.04085810542164836, 0.045237255399115384, 0.06694113413686864, 0.04153670299274381, 0.0171106544075883, 0.024271633628814016, 0.036603795815608464, 0.059488520564627834, 0.03889346611686051, 0.0677622166404035, 0.06351889824145474, 0.03359103990078438, 0.05725651513785124, 0.045264636937645264, 0.007126858981791884, 0.11084256082540378, 0.02291201537445886, 0.052054460684303194, 0.07793484968715347, 0.0795936313807033, 0.016156911151483655, 0.026584926490613725, 0.022802016101195477, 0.05873173773579765, 0.01513616123702377, 0.028954062254342716, 0.061272944149095565, 0.038275769184110686, 0.06701132646412589, 0.048780531869851984, 0.055096327341743745, 0.028101145326218102, 0.03812713926890865, 0.043812647272716276, 0.05878582545847166, 0.034633133982424624, 0.07992411716259085, 0.022271317429840565, 0.006755817612429382, 0.013965114358143182, 0.06237936016987078, 0.029400311941572, 0.019829727643809747, 0.04260987450834364, 0.02379140099947108, 0.04068941896548495, 0.034589881615829654, 0.05892844397749286, 0.030132572355796583, 0.019857619408867322, 0.027761453202401754, 0.04056149125972297, 0.06256873399252072, 0.018288053142896388, 0.025467901468800846, 0.02654213982168585, 0.03811220725765452, 0.022390135272871703, 0.07281661339220591, 0.0648724049096927, 0.04682355523982551, 0.0032023424091676134, 0.07411501559545286, 0.05077623747638427, 0.0657350847905036, 0.059995028932462446, 0.041733446341822855, 0.024632259883219376, 0.04565419767459389, 0.04980153411452193, 0.01644024272536626, 0.028338285628706217, 0.04619799896318, 0.020023309443786275, 0.019044160617340822, 0.03516282704367768, 0.05584178870776668, 0.03767113776120823, 0.013279764170874842, 0.02761967702099355, 0.031751767892274074, 0.14451117371208966, 0.1132244392647408, 0.16960812936304137, 0.12865618307841942, 0.09891636640531942, 0.15734629123471677, 0.1379117590840906, 0.16585703298915178, 0.08573272149078548, 0.10174397131777368, 0.16864247649209574, 0.14400672109331936, 0.18415082478895783, 0.18601913703605533, 0.0983988594089169, 0.17408400715794414, 0.12731414259178564, 0.16802527679828927, 0.1558203317108564, 0.14256637572543696, 0.19677178817801178, 0.14702147338539362, 0.13045881525613368, 0.12921441171783954, 0.15113674162421376, 0.1650805535609834, 0.07657550973817706, 0.07702624570811167, 0.11086642087320797, 0.17653140239417553, 0.130752126860898, 0.09468322285101749, 0.12937611085362732, 0.16181743412744254, 0.18433236895361915, 0.2297355537302792, 0.13253154465928674, 0.12872315448476002, 0.17795782507164404, 0.1221838389756158, 0.13661001721629873, 0.09346422302769497, 0.1581313944188878, 0.17343801213428378, 0.04909440838673618, 0.17056655371561646, 0.14928348013199866, 0.08107811969239265, 0.12048699252773076, 0.20885493198875338, 0.15545467555057257, 0.1619190044584684, 0.2661917178193107, 0.12098378618247807, 0.11796629536547698, 0.10196332048508339, 0.12646405695704743, 0.1555449652369134, 0.1337345808860846, 0.10078387713292614, 0.16065846662968397, 0.1301681753830053, 0.09076123213162646, 0.1205440191552043, 0.19871906493790448, 0.13734452077187598, 0.11250680472585373, 0.09229025672539137, 0.16276036243652925, 0.045021167970844544, 0.1479733074666001, 0.19330664130393416, 0.11197605039342307, 0.09741702771862037, 0.21539352019317448, 0.0698940284200944, 0.18794189323671162, 0.29042530339211226, 0.08627253002487123, 0.21070693182991818, 0.10754249728051946, 0.1384235589648597, 0.12361757922917604, 0.12310764213907532, 0.14952147204894572, 0.12853779568104073, 0.09586543441400863, 0.16140509687829763, 0.11055213617510162, 0.2878111327299848, 0.17400725424522534, 0.1408209334476851, 0.17630043119424954, 0.12121023028157651, 0.20440309977857396, 0.09439414890948683, 0.16949000913882628, 0.2533788053551689, 0.13732639752561226, 0.059703602382796817, 0.12706714100204408, 0.1922689555794932, 0.12667067087022588, 0.0674659364449326, 0.1525604331982322, 0.11909108696272597, 0.06625132271437906, 0.19997010327642784, 0.13632483955007046, 0.10696468336391263, 0.13002802821574733, 0.24158294691005722, 0.17110412096371874, 0.14059236680623144, 0.15052950155222788, 0.07768582945573144, 0.068632154725492, 0.08501169533701614, 0.16759431164246053, 0.16292865184368566, 0.14890358957927674, 0.09290353787946515, 0.13908469380112365, 0.21967461390886456, 0.11618203134275973, 0.21232135535683483, 0.2563339186599478, 0.13768014963716269, 0.12932053883560002, 0.10904530921834521, 0.0953522244526539, 0.18548676482168958, 0.14412402495509014, 0.10444763014675118, 0.10259506627335213, 0.1780823277658783, 0.10677919839508832, 0.09797254009754397, 0.10783347112010233, 0.14554311521351337, 0.0886883691418916, 0.1507152759586461, 0.1264094645739533, 0.13788496755296364, 0.12352930076303892, 0.17831016710260883, 0.10229986961348914, 0.07481532098609023, 0.09183015485177748, 0.08594517610617913, 0.11551820993190631, 0.17085912317270413, 0.15389390930067748, 0.16164847678737715, 0.13369733991567045, 0.2024232130497694, 0.1915438921423629, 0.19412232097238302, 0.15057287266245112, 0.13768672506557778, 0.1937303927843459, 0.11760039429645985, 0.14302508236141875, 0.1653153690858744, 0.17762982548447326, 0.09180227978504263, 0.1630259770900011, 0.07339609714108519, 0.10648328927345574, 0.1135749185050372, 0.19728899089386687, 0.271464409888722, 0.12869464117102325, 0.13870594615582377, 0.12556485598906875, 0.13373529334785417], [0.048404771368950605, 0.0644586278940551, 0.03672779013868421, 0.08967466856120154, 0.006475022792074014, 0.0012776138351000554, 0.08195585032808594, 0.06890194024890661, 0.005237744799160282, 0.06221799871127587, 0.03300911819678731, 0.03519322912325151, 0.04329498071456328, 0.03370469239598606, 0.01593385124579072, 0.07357022725045681, 0.0060480939919216326, 0.03437009458139073, 0.04432459558302071, 0.06613133969949558, 0.01583243862114614, 0.07170264230808243, 0.0127275376507896, 0.03298768126114737, 0.03518634199281223, 0.018713546814979054, 0.02528661334508797, 0.1087519976135809, 0.04911057236313354, 0.016916363856580574, 0.03169226991303731, 0.03847676132863853, 0.07215222052764148, 0.012222944951645331, 0.053738827919005416, 0.03374080530193169, 0.031552263753837906, 0.01702707559161354, 0.039152972894953564, 0.026018307871709112, 0.05383843155868817, 0.06928689224878326, 0.029850383689336013, 0.02039364855590975, 0.024411157392023597, 0.042016620209324174, 0.022151989360281732, 0.04910885058052372, 0.04244444236974232, 0.00562165454539354, 0.04128528562432621, 0.0682579712884035, 0.07401716342428699, 0.049491605823277496, 0.03036598707694793, 0.033354933038936, 0.04434353148099035, 0.06924526518560015, 0.0258198538722354, 0.08115021191770211, 0.023140517077990808, 0.11024510968127288, 0.096805164066609, 0.06314067752100527, 0.03594077963498421, 0.007958720252645435, 0.0413203001517104, 0.03281441575381905, 0.034560952699393965, 0.07214565994217992, 0.03846908010018524, 0.031083740359463263, 0.045246116642374545, 0.05236430362856481, 0.015017946388979908, 0.0314738298766315, 0.04622278669558, 0.021663468796759844, 0.009349755473522237, 0.03822733291599434, 0.06316280094324611, 0.03248854984121863, 0.04395566284074448, 0.04147121588175651, 0.04066401153977495, 0.08093389813438989, 0.02261230089061428, 0.01871042237326037, 0.02251388654258335, 0.035008987251785584, 0.011817511531262426, 0.012236768379807472, 0.0548749743757071, 0.08671246774611063, 0.009676151094026864, 0.05458305800857488, 0.03455861493421253, 0.037936154985800385, 0.0756258427281864, 0.01569818410644075, 0.02524393428757321, 0.043450011653476395, 0.03160436994221527, 0.05395690430304967, 0.08161074423696846, 0.02349728787521599, 0.04761595744639635, 0.05214192278799601, 0.02883609602577053, 0.03666128257464152, 0.016941281464823987, 0.05631821040879004, 0.10065931506687775, 0.04716203024145216, 0.07068604842061177, 0.08497725968481973, 0.0693165633128956, 0.0415006309049204, 0.052914316693204455, 0.029940999920654576, 0.03912644853699021, 0.029509131200029515, 0.056246337117045186, 0.03634362481534481, 0.0208008649860858, 0.05036104666942265, 0.06534915315569378, 0.010679343649826478, 0.052258421419537626, 0.06050449846952688, 0.019225333708163816, 0.028480377222876996, 0.07629597239429131, 0.06440530458348803, 0.05643245662213303, 0.02195602897700155, 0.03582055913284421, 0.07551486938609742, 0.047939062569639646, 0.0464798035682179, 0.03330413674120791, 0.0603765930281952, 0.04469015526410658, 0.02317994923942024, 0.0704471065546386, 0.0030251875841713627, 0.03749343792151194, 0.03852180227113422, 0.03230877569876611, 0.054063005445641465, 0.038006317627150565, 0.028130528808105737, 0.01075301386663341, 0.04661474456952419, 0.05174444704607595, 0.08696484990650788, 0.014002784846525174, 0.12658845575060695, 0.042313019148423336, 0.011031683825422078, 0.04188431383226998, 0.024702131231606472, 0.024129330522555392, 0.04998440301278606, 0.019484038966766093, 0.10004190757172182, 0.055110157263698056, 0.06791024541598745, 0.050151460454799235, 0.020287046463636216, 0.010015024072345113, 0.04716144023404922, 0.1145094605453778, 0.05457033017592039, 0.024529216389055364, 0.04444431142474059, 0.0076403579168982105, 0.03646146673418116, 0.028050508590240497, 0.07831496288417839, 0.05135160972713493, 0.015151248171605403, 0.03753573291760404, 0.046455223637167364, 0.03495474738883786, 0.06393461226252839, 0.02595650923467474, 0.025560172689438332, 0.030109176150290295, 0.03627128025982529, 0.019266504350525793, 0.034479691239539534, 0.02902164778788574, 0.02629555940075079, 0.02497661640518345, 0.05029181542340666, 0.03755842037207913, 0.026405534554214682, 0.032613631410640664, 0.00921278005989734, 0.040231395105365664, 0.08597149266279303, 0.022947792458580807, 0.025952638934541028, 0.04795672939508222, 0.014351704649016028, 0.033503644590382464, 0.006617806902795564, 0.050082214365829714, 0.026878477438003756, 0.0676018459489569, 0.03903673030436039, 0.048516119495616294, 0.013364802234718809, 0.09855249882093631, 0.035291177773615345, 0.0022154856833367376, 0.038344440108630806, 0.03356995919602923, 0.013928428143117344, 0.05563712664297782, 0.012748069166264031, 0.00582127557208878, 0.029393011063802987, 0.02916830730100628, 0.01675851090112701, 0.006094354839660809, 0.030034334267838858, 0.05393125939008314, 0.04594578378601, 0.015553124849247979, 0.03511437964334618, 0.059140267767361365, 0.04185380785202142, 0.07903155841631815, 0.03398426684725564, 0.060858187498524785, 0.030222891728044488, 0.015160191978793591, 0.03660528011096176, 0.038323151602526195, 0.020209597787470557, 0.0712144427234307, 0.04417871903569903, 0.015861755309742875, 0.08486973732942715, 0.011151690960105043, 0.031992861986509524, 0.025309497468697373, 0.02035784549661912, 0.02723152079852298, 0.014282260035543004, 0.02037255671893945, 0.020180158644507173, 0.02505976848624414, 0.03020572770765284, 0.030711193358001765, 0.07035073125734925, 0.041277400305261835, 0.04149910950218327, 0.026515634017414413, 0.062337169074453413, 0.03293375681096222, 0.02654273539519636, 0.05338207382010296, 0.03702656766108703, 0.009850758960965322, 0.08611672354163602, 0.07681254428462125, 0.025781074800761417, 0.034367092594038695, 0.032681293014320545, 0.015909354806353804, 0.01924659067299217, 0.026493816731090192, 0.03397334985493217, 0.03744974026631098, 0.06162741614389233, 0.053257578547345474, 0.021555232124228496, 0.04135293609579094, 0.010326407900720369, 0.06326451970380731, 0.06313666250207461, 0.010788853105623275, 0.06917263119248673, 0.060897376606590115, 0.09460196510190144, 0.050449165573809296, 0.0635909459379036, 0.04460923148144502, 0.02687758686079178, 0.0226529965584632, 0.04906263333396055, 0.04174452289589681, 0.016188641675398685, 0.0602303454070352, 0.06215371759026311, 0.0418289793014992, 0.04451208435057197, 0.05851267429534346, 0.04262078036845196, 0.0401445860916283, 0.06212612825038377, 0.02833913909853436, 0.06964056272408925, 0.02303466641023988, 0.030214453508961014, 0.1072136516449973, 0.11556833458598703, 0.01205543758260319, 0.055112784466473386, 0.04368063404399436, 0.03681892587337643, 0.04669443267630413, 0.06383042215020396, 0.052196715550962836, 0.07338428215007298, 0.02572511315520387, 0.07675412984099239, 0.02991547189594712, 0.035386829476919957, 0.01395501372826402, 0.019041275518247858, 0.015962557517923415, 0.015622998980688863, 0.012978413251403254, 0.052353371793287806, 0.023381852370221168, 0.04464941877813544, 0.052446392583078705, 0.04213576830807142, 0.06259225265239365, 0.0834871681581717, 0.1636534629506059, 0.02852069439541083, 0.060711309051839635, 0.023134618859330658, 0.028752949510817416, 0.053845125730731525, 0.0453790723986458, 0.06570450830622576, 0.022710974990332033, 0.05769282375695184, 0.04957074474077672, 0.007944600893097231, 0.02205140051955823, 0.03126890806015581, 0.08922773238737136, 0.01763490381563315, 0.014123412602202734, 0.027271728504274506, 0.13403449760517105, 0.18611794657772407, 0.07009438602835871, 0.3196673170896247, 0.11234716876060702, 0.12059009168297052, 0.16548233747016639, 0.1630853785900399, 0.12378024315694347, 0.195744774537161, 0.1117714773863554, 0.11685060249874368, 0.0845169425883796, 0.0996237741492223, 0.11451666679931805, 0.2774816838791594, 0.09902932128170505, 0.13795199833111838, 0.1726040756329894, 0.1488380876253359, 0.11222749744774774, 0.2210938377538696, 0.1855068324948661, 0.1732015490415506, 0.12504741578595713, 0.22004188795108348, 0.1562063820892945, 0.1793858953169547, 0.1504152108100243, 0.14675302372779697, 0.10951327043585479, 0.10534309069043957, 0.14431355462875217, 0.13980493327835575, 0.14732029172591865, 0.1495248413993977, 0.15737657085992396, 0.0923241135024, 0.16615856759017333, 0.10394690310931765, 0.10495773050934076, 0.15718147507868707, 0.18219850142486393, 0.11287284680292942, 0.13322212791536003, 0.10543199256062508, 0.1069696038030088, 0.2082501706900075, 0.1577055946108885, 0.0741442636353895, 0.12353817684925161, 0.23555652966024354, 0.13880478538339958, 0.11139897862449288, 0.10232260159682482, 0.07959791357279755, 0.10600147215882316, 0.18082328693708405, 0.2148060212493874, 0.1720897969789803, 0.14465742133324966, 0.18148918636143208, 0.14876888977596536, 0.22750160016585141, 0.08889150238246657, 0.12534957379102707, 0.11516221653437242, 0.10693551696022041, 0.11784652757341973, 0.22653934633126482, 0.1195138662296813, 0.12703027110546827, 0.16345569543773308, 0.11561834049643949, 0.09250404720660299, 0.06483704157290049, 0.06899589614477009, 0.11948619154281914, 0.1337397759198211, 0.1308016132679768, 0.15465498174307868, 0.1943186784046702, 0.13893780793296173, 0.10583209921605885, 0.09958355716662481, 0.16907419863855466, 0.15775693638715893, 0.12207714782562107, 0.2079864707775414, 0.1341096029500477, 0.07825835928088054, 0.2007983103976585, 0.16471826675115153, 0.17692374618491158, 0.2126033417880535, 0.1342220531660132, 0.11734131796401925, 0.10355323829571716, 0.19314528355607763, 0.11366858496330678, 0.10736913158325478, 0.14482884260360152, 0.12957064260262996, 0.19486464676447213, 0.1921990601113066, 0.10232301719952375, 0.1906668220181018, 0.10181666468270123, 0.07176499013439752, 0.16176934295799583, 0.11078593495767564, 0.13049834204139188, 0.22446051647420973, 0.24058689567027614, 0.15201869508018717, 0.12089148527593352, 0.2517112885834649, 0.1061612342891749, 0.15508582815527916, 0.10279333844664507, 0.11445937299868092, 0.1698334899265319, 0.14806407212745398, 0.09935148016666062, 0.12395921206916682, 0.08946569461841136, 0.11884637118782848, 0.1610700914170593, 0.09160783709376119, 0.16937141394009814, 0.2303104955353774, 0.1515284471679479, 0.19970275199739262, 0.23587330797454342, 0.14619393419707194, 0.11318159507936798, 0.10561823452007957, 0.17396272538462654, 0.14333552273456007, 0.1827330407104455, 0.13076364499283955, 0.15224139875499532, 0.21996287890942767, 0.10572818369837478, 0.13615230505820364, 0.07358359333011322, 0.10659951702109538, 0.12427100315107964, 0.12119566192268394, 0.16419552761362866, 0.1195546769304201, 0.15270277712261304, 0.11738122324459255, 0.12184337872895412, 0.2202844514977187, 0.16703180823242292, 0.1483720782562159, 0.2545331121655181, 0.21695658710086718, 0.09697211018647067, 0.16785859043011442, 0.11191904603037983, 0.13472472463035956, 0.1333334352239035, 0.18542405334301293, 0.2275616250699386, 0.14087187446421012, 0.2348537603393197, 0.1531430339673534, 0.05795446420961525, 0.09935831534676254, 0.08912957593565807, 0.16803701757453382, 0.1399640942690894, 0.1392776076681912, 0.13040769612416625], [0.054894344430067576, 0.06980039906920865, 0.04549727054836694, 0.04386343985970598, 0.0638464599614963, 0.02672799029824091, 0.031203476610244252, 0.02529956938815303, 0.07049451494822279, 0.012222802088217577, 0.031873676780378446, 0.03274168528150767, 0.07894867536379024, 0.0335741040908033, 0.04153447283897549, 0.024216456804424524, 0.045359954674495384, 0.07567682085209526, 0.06855560961412266, 0.012724358475679765, 0.028993787564104423, 0.024390408798353747, 0.043471047829370946, 0.008949001294240588, 0.04702501493738964, 0.02597579765279079, 0.044151994297862984, 0.03367176701431163, 0.07087663194397464, 0.09718846849864349, 0.0479699693096336, 0.02108856224367628, 0.022977038643148262, 0.01728681985696312, 0.03131696212221868, 0.033684480004012585, 0.03760415522265248, 0.029981712286826223, 0.044020563655067235, 0.02115794562996598, 0.012957807521161158, 0.07445119365002029, 0.02862714434741065, 0.05057734560978133, 0.020046189856657293, 0.047309409637819044, 0.036642851337092, 0.04276686842786148, 0.048853151020011865, 0.024967727331386413, 0.012621263958862983, 0.012381331325741485, 0.04388844652567059, 0.04952010800479911, 0.06528156576678157, 0.02804875526635442, 0.03391978163563181, 0.08696598539245315, 0.03445305927016307, 0.03434109516092576, 0.02341930114198476, 0.03690238780109212, 0.05344967976270709, 0.0347946587135084, 0.0061180432658147765, 0.030918035481590778, 0.03941314389521722, 0.021601362168439664, 0.03010122774867341, 0.065302716975566, 0.01807077271223534, 0.010391055457148468, 0.04085427965037525, 0.03488611357170157, 0.020065233366040047, 0.03746096896065865, 0.01657146556681255, 0.03976918553235009, 0.04235468331899028, 0.028869750567537267, 0.03862844518152997, 0.07460586464731023, 0.011240295971219894, 0.03242317405238282, 0.015431021147378488, 0.05055500325397588, 0.05005954546504654, 0.02869166295567993, 0.02071126364171505, 0.06962544517591596, 0.013195266019465635, 0.02613969540107064, 0.056472065043635666, 0.08250369632150978, 0.05879239346540999, 0.04797073001100216, 0.059427538290037774, 0.05125363139086403, 0.044979340527788736, 0.010163006463699276, 0.04590013799315784, 0.009456951283937087, 0.04147496372752357, 0.010173365917580668, 0.013233610006864183, 0.0487395393429324, 0.02781410115858307, 0.042972747614840046, 0.0455824653909076, 0.02191644838603679, 0.06419115044991486, 0.03538707809639163, 0.03235708580177743, 0.03237145749153569, 0.01438821738702245, 0.003212791848454799, 0.06508164602564648, 0.019268560099590104, 0.05284887782181613, 0.03470846939308103, 0.01892152813525172, 0.053214660147204995, 0.04444831902219448, 0.04797613284608815, 0.08673961550812237, 0.03527041990309954, 0.03004677451826865, 0.07882150835939683, 0.015038689416542184, 0.02863640449504601, 0.075794221193064, 0.03752703494683374, 0.04501380957663059, 0.006215452003743849, 0.061505455305450596, 0.009999210760724964, 0.014979345432948321, 0.03728562543983571, 0.011360693661117693, 0.010824098626471823, 0.04295865051972214, 0.04001728921139147, 0.042278657710994594, 0.08438273260253482, 0.04382254010124598, 0.04014782556623686, 0.03390719852177426, 0.07622385048307478, 0.047744363837409765, 0.0980505027109757, 0.02409513050224632, 0.01132233112002723, 0.07743768495856784, 0.042602712783263996, 0.05963792231341358, 0.045411185128614306, 0.06234692831640132, 0.06557158965733834, 0.037492695773835294, 0.024177577543014195, 0.017908635709318332, 0.048432279072585516, 0.02689847089641262, 0.010503202320251148, 0.05357945541618392, 0.04510166501859203, 0.05012888432247564, 0.04653554628021084, 0.03465637062618043, 0.015000869570940267, 0.03473711258266121, 0.003082730468122463, 0.016476902965223417, 0.03213195159332827, 0.03011154545674799, 0.09245673529221676, 0.031479919198318385, 0.04733555921120569, 0.03957105065637734, 0.04478565482713748, 0.020409139033290558, 0.04069970142154489, 0.04238833971612621, 0.03243456972995773, 0.07433630918967538, 0.10437057295348495, 0.01760062215907965, 0.03001829460117733, 0.06601104498258792, 0.04450130094483029, 0.04927775225951336, 0.05445937538752332, 0.049564466171432287, 0.04996490308258217, 0.060983710645814426, 0.04077078432601411, 0.0536489538353635, 0.07669583414099179, 0.014725132950843545, 0.032669645006535575, 0.024659251794219017, 0.05316584538377356, 0.004360522534625488, 0.041229546623071656, 0.10139798207092099, 0.034010987874353305, 0.06215685687493533, 0.06019262575136963, 0.009411395476490725, 0.042065624220413156, 0.017496393084002193, 0.03941640563425608, 0.04033528464788105, 0.027217512761126272, 0.10371555341407657, 0.00924304576983559, 0.03996277846454177, 0.022003426238370594, 0.03079257541685365, 0.0380087889789138, 0.006764736835975782, 0.04606869457347784, 0.03486979374429211, 0.02283517154864967, 0.03453857694694307, 0.033659636610536836, 0.012098896822863026, 0.010704753858590266, 0.02434608031762764, 0.0332037056068657, 0.015773497252666857, 0.1275548804551363, 0.028107514808652923, 0.0549008011148544, 0.04696665986557491, 0.07051602980936877, 0.031356989857158624, 0.04565542592899874, 0.025756925315363333, 0.04489599363296293, 0.012154126525274478, 0.023822532239137217, 0.09805079957004637, 0.010335755250707734, 0.031605475742253475, 0.02051303043117514, 0.005807545376228518, 0.04256522319337819, 0.03721208973729517, 0.011451840528025059, 0.022863395424792543, 0.02825241543177981, 0.057120145502267405, 0.009791159864107613, 0.05707730131689459, 0.027823467062262353, 0.11052607194869779, 0.04070826209499501, 0.02866429069399601, 0.04431193454365712, 0.02386353775364114, 0.024034150083025452, 0.02783907257253304, 0.03713526632054709, 0.024672595609445125, 0.04063726824824698, 0.021451982684084214, 0.024932796295615844, 0.06405371212167665, 0.06612781449803151, 0.019143877434544265, 0.03829406312434003, 0.03656868851976469, 0.012130033628636738, 0.05848160799359903, 0.05143198803125415, 0.06997118209255859, 0.04350914226961322, 0.027098388782178517, 0.02762175317911897, 0.03148582669382449, 0.050337483480689116, 0.028469213466451038, 0.032181890710489824, 0.0785324937896803, 0.04266238887794316, 0.05264675761281978, 0.03664413154183421, 0.061526235440396704, 0.06403944062185474, 0.020516442455118522, 0.02007810035138391, 0.035073435356025584, 0.0432439395081019, 0.08287323391414247, 0.043506689471541904, 0.023263164403033443, 0.05836038930283394, 0.0435327833838528, 0.01967941119801253, 0.004220988103043055, 0.030039015364309307, 0.05595606089627836, 0.06543667463120073, 0.04080888247699477, 0.010672865628293948, 0.047773007026989944, 0.02118913809681544, 0.019857014558510855, 0.09580904603353702, 0.05679763409716543, 0.02607593563880073, 0.07163517366279848, 0.026593604052322917, 0.02258269476442365, 0.03209640643035527, 0.018464040476828814, 0.06557834320119582, 0.03625145007390529, 0.0313262538111303, 0.08564355244743638, 0.11084112848038785, 0.07587233965750784, 0.09952676060493104, 0.05517398196388967, 0.023100352045730688, 0.07071602376527153, 0.030792029938311316, 0.016412328695878386, 0.016354374383809045, 0.04468892700970173, 0.02652552313520573, 0.03327287748106755, 0.05837850512762088, 0.026977685884048697, 0.08293801598483697, 0.008726962769287638, 0.018045189026452135, 0.026899465374299325, 0.08692159753991291, 0.03002463996381266, 0.05991740770696197, 0.0784038424899336, 0.030613354174420238, 0.010851111874217167, 0.04236513275827747, 0.04076599005202297, 0.045709335536230356, 0.06919640218256973, 0.02741159922152292, 0.022616048736381344, 0.048949110714602284, 0.12991482100915164, 0.16578059177845716, 0.0950102428032551, 0.09747305244673043, 0.11115520537714474, 0.07259425852680579, 0.15352491347584873, 0.08906215924071148, 0.22464550420409068, 0.16226938721956685, 0.199711257009767, 0.06283152106334455, 0.19442640856141225, 0.18930400139652193, 0.12413973949151114, 0.16013246204238385, 0.16010512132197618, 0.1104577498335857, 0.13023536943364888, 0.135473967238795, 0.08949546216172166, 0.26885510771535337, 0.12385387904942036, 0.06652556854533032, 0.13521198910893872, 0.0915206792706158, 0.15846794354729354, 0.10798213072121143, 0.13067086169030517, 0.14228041138267145, 0.20427650422789156, 0.13595621479908004, 0.11634018301265314, 0.09618521100492217, 0.07798570906743407, 0.14250734529923648, 0.1894132752204314, 0.18709862051764503, 0.1734071536338888, 0.05389098674640991, 0.10182214173255488, 0.1974106437410228, 0.16028561163693666, 0.1100933479028754, 0.05542649400013033, 0.14655540464445949, 0.08640437998110428, 0.1438787006190978, 0.20655863801948726, 0.07308335611014627, 0.16176307923160493, 0.10321838126401417, 0.09735725514474325, 0.17879520513815805, 0.17065149993868545, 0.12758177588693798, 0.07847618704545312, 0.22803054365795106, 0.13109973398968577, 0.12988319067517295, 0.08790766689344309, 0.16391432785894722, 0.22062506759539247, 0.08490562016959302, 0.07702341812546365, 0.10645245303749107, 0.3001403430243954, 0.1354183506919071, 0.16164533008122817, 0.19224933319492266, 0.13507709634723142, 0.14541880547767505, 0.10579643902019598, 0.13076018658466637, 0.07309359032660723, 0.08085756082437001, 0.1144202692375984, 0.10063596710097045, 0.16663279995555058, 0.08097199999610893, 0.19720336189493537, 0.18274441041285172, 0.17296613979851827, 0.1755276179756038, 0.11209909847821109, 0.12628365569980815, 0.09879102508421056, 0.14712344447616488, 0.15608705958584324, 0.16783635568572208, 0.10856973356567323, 0.08207081642467529, 0.13202645379351452, 0.12111842661397532, 0.12176324162282981, 0.1522470242343843, 0.13072822970570996, 0.08416483804467134, 0.11324504128424451, 0.1797682052711025, 0.21742537210229784, 0.14819051924860105, 0.20201715436996892, 0.1738719458808191, 0.08746844905545004, 0.1436348754214123, 0.064697896305006, 0.15065597835928202, 0.18794401577906683, 0.1802845174097456, 0.17989730928093195, 0.15827091818209738, 0.23819639347493649, 0.18477866688044742, 0.11526751986821182, 0.15519069362198934, 0.10973935830406845, 0.1521085691638291, 0.17741596820997074, 0.2088655743864365, 0.14299024594947696, 0.1671981977415271, 0.10655717007466592, 0.11019850280717947, 0.14282128860941157, 0.2182199154049158, 0.09296466116211377, 0.19513416511472315, 0.12638685875572264, 0.10200685486779548, 0.20188232098007575, 0.17101601319154724, 0.12373114266665652, 0.15652457048418, 0.16037664347095415, 0.08223101642215624, 0.14717904618009925, 0.13577395817264915, 0.13569548347732052, 0.1056320607312955, 0.12753893912304193, 0.12373169185593724, 0.10933404919342138, 0.1684575926628895, 0.204808505368419, 0.17789275356335565, 0.18647545395651832, 0.19014535937458277, 0.16917311208089814, 0.24790950352326035, 0.1652409168309532, 0.06637045968091115, 0.21094798139529303, 0.1427125491318293, 0.2571884571807459, 0.13770642166491598, 0.1290265444549732, 0.17082483595004305, 0.08859498469973914, 0.16993825149256736, 0.12873336643679067, 0.1288648007903248, 0.08065663176239468, 0.12014550811727531, 0.12901085545308888, 0.1279356615850702, 0.12285267730476335, 0.16590656392509118, 0.09024515748023987, 0.1117369749408681, 0.11567803143407218, 0.1833137118956074, 0.09756026964168996, 0.09640608899644576, 0.12730532587738708, 0.17178133071865886], [0.04896206119155977, 0.02471922845870722, 0.03173449069436174, 0.09597881973604672, 0.026252692950947676, 0.0682192608655896, 0.013622707829199499, 0.10512014210689813, 0.032232568264589645, 0.02485550161509309, 0.01797334356524516, 0.027095021287095733, 0.06952751878998242, 0.0502686789695872, 0.04541357855487149, 0.032305050117429346, 0.0449894634220982, 0.03148872849124018, 0.0044511002670333255, 0.04113901573873591, 0.11413872809498571, 0.07537556084571406, 0.012383943685563281, 0.0980683439411223, 0.04268831580702681, 0.017797473119571805, 0.04943814150465187, 0.028416409659257624, 0.07192268909420818, 0.06269322184380144, 0.006962186616874533, 0.029732348812103737, 0.038867160692461766, 0.06163025856949389, 0.014079371703701327, 0.01984002494282322, 0.08621763336122967, 0.06259101326577365, 0.03941704017051961, 0.042266620075679384, 0.023429372085956857, 0.024559792873333208, 0.026701725691964384, 0.03040579402295407, 0.03159189815050922, 0.07889721484389156, 0.04282396927010268, 0.007968721620272845, 0.077711774938507, 0.05639621755108237, 0.0261046029481804, 0.05959330439509358, 0.051403753022896126, 0.031162153827608563, 0.06488361876108684, 0.02766642861388391, 0.019583928333304357, 0.033126091802841984, 0.02806326239806367, 0.047057149931788445, 0.049135293302242644, 0.013136506477167131, 0.041586764564272016, 0.01027666174195474, 0.05666204742738046, 0.05080486211227253, 0.019365382540854625, 0.012996530931559391, 0.012556054225569824, 0.049135170847876, 0.018524724036979023, 0.053609163587680086, 0.056692846555961296, 0.039584027108503506, 0.055372398855979554, 0.029147905661375262, 0.0837228519958444, 0.037571753055090085, 0.09748131997184828, 0.11993892389000393, 0.08083255044766702, 0.0979517525411211, 0.07543445026385598, 0.04750829408294521, 0.05600576252618339, 0.043482591936481185, 0.020417924206412863, 0.09682508331025019, 0.05269349065201823, 0.011577761652006302, 0.004902265754935797, 0.05396293054218404, 0.007462791199941421, 0.0056680067700654035, 0.09335871189250611, 0.06738649695762433, 0.023714850321994163, 0.014455056134465849, 0.05926248835748993, 0.009309339038736653, 0.0487595921731554, 0.03327573474962264, 0.036370011875987984, 0.04044068446091842, 0.03889024148520548, 0.0866864035197068, 0.015820146800251678, 0.020765243752975948, 0.06642315958742984, 0.012809270374418702, 0.01892928543384187, 0.07249255460919812, 0.029274747976160143, 0.011600381385505898, 0.08027144969673827, 0.014774535866308725, 0.04397027201775927, 0.11418131995014846, 0.042993861716240644, 0.03830220077361446, 0.043348853214411065, 0.04540828333119862, 0.03706288094690535, 0.033792503309086896, 0.06812615843955427, 0.0238551589063718, 0.03764820168726146, 0.038294037149171345, 0.034418812865624204, 0.03591234424675349, 0.03473396587651223, 0.032629123743390664, 0.037975047234795056, 0.030491729157802183, 0.012786399238393642, 0.005394716454247828, 0.018010241292358842, 0.01079167604984832, 0.03772267620661296, 0.026564394975139294, 0.10703207037295215, 0.040370974529650994, 0.020544914950733073, 0.022098551016824786, 0.08508616985636763, 0.052942559123039246, 0.06516817302326672, 0.06543865616549738, 0.020425956099643372, 0.019244564609834924, 0.027807314218080137, 0.037468516602530144, 0.04492423606279772, 0.027001011585525703, 0.035259402720839716, 0.07309378328500316, 0.05860311983269639, 0.02658937381056603, 0.016011934458219912, 0.0336956975661451, 0.024067825033853296, 0.012602076658367878, 0.03899764138623141, 0.02787198496662313, 0.08291627847938798, 0.028181963352835737, 0.011252011699980358, 0.035360583424335346, 0.008610337972640991, 0.04130645909754094, 0.019360770093044266, 0.02204330183303682, 0.023795813067408744, 0.024280897487187758, 0.026190183707512915, 0.016484311454405542, 0.05209415816352703, 0.07970812992425635, 0.019822172580461483, 0.03046985435503302, 0.028235299650987145, 0.07455275655956939, 0.01259140643014689, 0.04809339588973671, 0.016083922782854643, 0.01172295635115006, 0.014136261961539276, 0.03443091729423031, 0.0986482210282702, 0.03785792890994344, 0.029900775516580325, 0.07176392886321992, 0.03053326901863329, 0.04382652543426957, 0.036098426644457504, 0.0329495200276142, 0.05997772575938143, 0.011644728419923922, 0.029797366514685564, 0.08644488640129566, 0.012010006084892666, 0.026719166162365582, 0.08792789041763172, 0.017896902354550548, 0.0018825041979653179, 0.0585327159933513, 0.006853125696579809, 0.02521290323784342, 0.03838300210190937, 0.06228219819604419, 0.061423229053616524, 0.0346072886895854, 0.08093510783510283, 0.04243422670697328, 0.028703053067147266, 0.016866480400494765, 0.022337073569360655, 0.04029413998068776, 0.03195534271071665, 0.05740563487051986, 0.041015028837136924, 0.05626886872050818, 0.006494097378890729, 0.012416129702614853, 0.02654008407262154, 0.049140688715851866, 0.01951903679582756, 0.03756681035156362, 0.058077063295058906, 0.007173480234996532, 0.12060707944328897, 0.037739986801170744, 0.03711383309564553, 0.05322397038980853, 0.048120001883944497, 0.047604186984244734, 0.05292202018608805, 0.10066025017295033, 0.025427790242247283, 0.04447067251021508, 0.024688741032150574, 0.020672952123277355, 0.016144367000379134, 0.061897739724372514, 0.030791167191637214, 0.018443970948283095, 0.029360694243223406, 0.007436276118824026, 0.031827956772758625, 0.005745403032051399, 0.04209738071949687, 0.03627422658610158, 0.08753944290219806, 0.019383322105568368, 0.0204038623633096, 0.021442954457597807, 0.030725346114195418, 0.04288983116566669, 0.09754842496477067, 0.03328140846861061, 0.04649930720916018, 0.03148196752590593, 0.04504425989580341, 0.011274653697910253, 0.051289877883391455, 0.1112136643496342, 0.014996062309364788, 0.06743454359821044, 0.028092836982978042, 0.013538835864892462, 0.07384047290543094, 0.05079100992588792, 0.07129046833142638, 0.01955150019057328, 0.05779247192549519, 0.06776620939490385, 0.028481375411502086, 0.06332791395834647, 0.04659718535549473, 0.029981832885823678, 0.06520293522044085, 0.11554014781722799, 0.051997289338032715, 0.06274068960919976, 0.04701000128989108, 0.02278104115248425, 0.03972602222347632, 0.03483064174361061, 0.029030629630142357, 0.07197322192951106, 0.05102455266751349, 0.019392318790778518, 0.016078592307167128, 0.0668346211023163, 0.006107983917900128, 0.019914518015866634, 0.04621264524757862, 0.03375218242581468, 0.032493344115209766, 0.038787609883002006, 0.003603452819334052, 0.06900206339196302, 0.025430443420191295, 0.027744816106860526, 0.0494809151859954, 0.039236137963598594, 0.016570016523473896, 0.04245481388352346, 0.03688362630782649, 0.06452742498368025, 0.01790831287507899, 0.019376820891920943, 0.04781232972163707, 0.01939755278726807, 0.04051837619044818, 0.02132436853571562, 0.05908349347009789, 0.02790714606817346, 0.032799884502310306, 0.05369753111153841, 0.03656767548818607, 0.017327380082861055, 0.047665469828643836, 0.024148142110789195, 0.016220513207372278, 0.05453333411423955, 0.010699898357415805, 0.0630255852593109, 0.029920332963229157, 0.019848301744787022, 0.008491926455462817, 0.037306145823094994, 0.02854805366951041, 0.013802864177705487, 0.012221533943375107, 0.012569293212436605, 0.035398462641751394, 0.015820508597244043, 0.053796938082086854, 0.03755730343982577, 0.013108139737596503, 0.15195633983239532, 0.033462147403042763, 0.018272007910127286, 0.006070180306778639, 0.01996085215068888, 0.011493960191728547, 0.027402916093706153, 0.03698384221934248, 0.013988778664497659, 0.07816004697815515, 0.031605267940904014, 0.10064571149996482, 0.16028541867854074, 0.10249253857182339, 0.16996556252706796, 0.10104768836754374, 0.14861907984595746, 0.0926412851549685, 0.18763543077511713, 0.14487553853541613, 0.16111303208163008, 0.1910232607042417, 0.1942293980391696, 0.17447308549890295, 0.17615428747376427, 0.13808499119477347, 0.21520673646591604, 0.1038430469634477, 0.1996989967301488, 0.13700500305276364, 0.09401435483596288, 0.15452834166353568, 0.15228576434310526, 0.13662523124367, 0.202530067472253, 0.269074872485362, 0.13239479652838781, 0.17001234751660377, 0.11395748821087182, 0.09461682289838791, 0.11799275293014944, 0.10860867405426688, 0.16402422508690506, 0.10759933837107383, 0.10099671766511165, 0.1447897611069493, 0.13157035951735452, 0.2428180884453468, 0.1354407041799277, 0.07320205520954914, 0.0948689749930054, 0.09479658590862527, 0.1716396101983264, 0.18799013283569366, 0.10802512333611958, 0.12151287068263628, 0.15632346330676228, 0.10383558095782064, 0.08054392179474235, 0.16309906379319727, 0.13206540170358494, 0.1894837644067593, 0.08921034386730753, 0.12672627257416025, 0.09397230474860407, 0.23064786102622747, 0.0699917841120623, 0.11358927164110355, 0.13426444464130327, 0.1593376960954629, 0.25381204148288816, 0.12890318466816097, 0.18519323057262227, 0.15054851537570357, 0.08676134559209459, 0.14461921557085589, 0.09480515029281378, 0.09754956787219271, 0.12774527102010325, 0.0645079139212612, 0.1629918976686895, 0.12440697202691808, 0.11344147293129936, 0.1623801453388296, 0.08243501797551289, 0.23208507453091443, 0.08455979419522919, 0.1437765365699306, 0.14937555097276345, 0.1170855070813559, 0.1750588181312196, 0.2186029971926473, 0.21468432387337089, 0.1983922379440628, 0.21811145794345066, 0.14139476203126833, 0.0991563250136096, 0.15541442146059126, 0.1954795012716204, 0.17666795756667852, 0.2471054607303813, 0.083837936836062, 0.19629972288385034, 0.08990485308459029, 0.10271087841829285, 0.16048268153099343, 0.1894423080375418, 0.11157901622937061, 0.15320837264880538, 0.27888704440556467, 0.1734518160810694, 0.056301189251826145, 0.1382967852987349, 0.08204956873669289, 0.12224125894135796, 0.16461472230730578, 0.19778055982897058, 0.15566798363579437, 0.11276928751613013, 0.21807843237183988, 0.08333505757036619, 0.1334121177205816, 0.16383619455154985, 0.20582113618729636, 0.0993078196188435, 0.19121328019537032, 0.1101114934135694, 0.1098116509092506, 0.2510914171580225, 0.17078890115953982, 0.14784221450099722, 0.12597413558978587, 0.14853394066449255, 0.11537585116457194, 0.1603275875095278, 0.17286882939515635, 0.20108725817408413, 0.11401458905311301, 0.12531120475614443, 0.13733086525462568, 0.21500807837583125, 0.1375695102615282, 0.10352265438996255, 0.10030894714873284, 0.08666185327456333, 0.09001515107229352, 0.11941450749873184, 0.12791265500709414, 0.06379566737450659, 0.10106395624461584, 0.15743073279736564, 0.18385651870630682, 0.14462307473877445, 0.16754773445427418, 0.1304853247711435, 0.25954370736144483, 0.09360930547700264, 0.2327591078937985, 0.19669736560899764, 0.10842539326404221, 0.13177375250961632, 0.19184082542778924, 0.24224844557465985, 0.12834854802349582, 0.14422123145777732, 0.12534397799754515, 0.10847470155567862, 0.10533975844737142, 0.09658142138505355, 0.06653635937254876, 0.1692362836911343, 0.13628606975544244, 0.09843497231486253, 0.11414428678108379, 0.15786805073730648, 0.10119671904249117, 0.1918939483584836, 0.06614755562623031, 0.11604359853663482, 0.13389810570515692, 0.07943942793644965, 0.13741083908826113, 0.07969385100295767, 0.07223351538414136, 0.10011837104684673, 0.16430742864031345, 0.08460716548142955], [0.03407176605833229, 0.04698543249105569, 0.030878616307745688, 0.01580834108608542, 0.04767218626511749, 0.04610098170815036, 0.06198778821271844, 0.04582270601531491, 0.040862424721126445, 0.05757947554229759, 0.012165058360551484, 0.0358054452954093, 0.05898301780689508, 0.025090613999054767, 0.06336325503070839, 0.07370684179477394, 0.04415186071128119, 0.06190970314492006, 0.010785187823785236, 0.059970790389343165, 0.03026103811862413, 0.03358537360327318, 0.0432836889376631, 0.055782669223845005, 0.019621200844994746, 0.038774930289946496, 0.022414256927731913, 0.0649827771121636, 0.012444615185813745, 0.06663137653958984, 0.07160314999055117, 0.07340728130657226, 0.0470149105967721, 0.04750629028421827, 0.031743459549034014, 0.006945783761693747, 0.03384147392353043, 0.10350853874115273, 0.01218355268065352, 0.04303146633901633, 0.045025472427369095, 0.05561914440477267, 0.03609530220273882, 0.0030468248996839975, 0.06912122262292542, 0.0505258739576675, 0.007685331138418405, 0.013886271372030023, 0.042358290156698786, 0.04368087524198927, 0.03249587483878713, 0.039580642915098, 0.025483952267677523, 0.046437942728516646, 0.027600279136095196, 0.019514164596330374, 0.005077877376606921, 0.06236206812900491, 0.06704686049488373, 0.019192625404684804, 0.016009054925234523, 0.0296885138595826, 0.05746494731283747, 0.01789906200428959, 0.0634608326072339, 0.09827814166783355, 0.02181890420615673, 0.06019464439305011, 0.043735942599596456, 0.04219696580548771, 0.03169277828419581, 0.042281574351363815, 0.01663106188061647, 0.1161260659864638, 0.02720967011555331, 0.04319532141380478, 0.04694027651567012, 0.022432599107560236, 0.05403010603913572, 0.06786713405745104, 0.04202904747216962, 0.017382237783749588, 0.025983619889302645, 0.027870257617905736, 0.017250758901354857, 0.08348169852979481, 0.019459646428003907, 0.039870084219728597, 0.030779344779148232, 0.05806544126244262, 0.024745728696871083, 0.005263425427983748, 0.012786086608684855, 0.03413007660128642, 0.010428507939650444, 0.046144323132466525, 0.06443229649448767, 0.018674817838473246, 0.014805451883148635, 0.012153192346886499, 0.042527807818260044, 0.07456814128090627, 0.03476110992778558, 0.03263982551288791, 0.022583414647669997, 0.037115525192348287, 0.04608430193911772, 0.053801483736606315, 0.06592706355149858, 0.010447389104228932, 0.04220023867674172, 0.02692919209948741, 0.0026716513912106166, 0.0980383092246484, 0.026267734428984113, 0.07798926395480521, 0.07731134915957227, 0.028329455926723313, 0.003921826519217575, 0.04718934498669114, 0.06533583902637474, 0.025926574708137196, 0.03349267935846001, 0.008913116598705528, 0.03340771087096073, 0.026836839242605492, 0.011305569714750163, 0.0661232354468666, 0.07111322862328961, 0.013884583913750248, 0.0411653990886407, 0.05956076864094939, 0.06054302335542161, 0.07339862044318579, 0.0499400633998448, 0.03802412174991332, 0.03364537624293007, 0.021851454803254455, 0.06258656780119054, 0.008097114096017322, 0.03624457778641954, 0.025853703227767255, 0.02165639427403221, 0.035310904058860615, 0.009660543728386983, 0.07538045902037993, 0.029246498124848586, 0.041490170333418064, 0.008116344070003834, 0.031944295842549764, 0.04306977229134645, 0.03813276474829763, 0.05829985973832663, 0.0520467571914196, 0.07751427459879778, 0.046934164929552935, 0.024217395621235482, 0.055859544590930454, 0.007722361988271587, 0.052981852131779306, 0.10251473620883189, 0.02796662549371831, 0.07088519632816315, 0.044976550052524544, 0.04475365341932047, 0.034367367188679054, 0.01971746482013259, 0.05423889815574512, 0.021831782323715743, 0.03067018413275946, 0.0662062075571157, 0.06486084224889055, 0.0278151791280834, 0.021437952382257208, 0.038177935566636734, 0.039933278094395064, 0.08747353276703507, 0.0281849152452196, 0.01896880850836169, 0.02778428537567379, 0.059843226335942745, 0.024493697201251052, 0.08163562844856642, 0.0358401926496299, 0.06133963725005742, 0.08482144578010775, 0.016792668247944675, 0.03981797803135123, 0.04121222489629872, 0.019077308643318247, 0.053149213854339905, 0.05498982915014494, 0.0460033484705491, 0.0404464212624589, 0.03799672907916829, 0.022841136560600717, 0.040915915014920756, 0.0473321490426315, 0.021612516648019664, 0.0327672856656136, 0.019669371795316692, 0.0367827684385702, 0.04430793065694161, 0.04972982409526594, 0.01386246049150941, 0.03735192149179056, 0.04580186650855467, 0.022460520558524877, 0.03277024683484342, 0.03666235497803427, 0.03948835685150698, 0.05724441070924513, 0.006875340959595633, 0.05748099625634495, 0.0072807595370250056, 0.010438335830258438, 0.008247083587775705, 0.021330146155378316, 0.07105146709363908, 0.0274774462741334, 0.025859315719571896, 0.06754011410521343, 0.05638742681185249, 0.047642081044614315, 0.05130077261128463, 0.020420885375642683, 0.06811602812376805, 0.08668857801239938, 0.03508103123749606, 0.01568816511280602, 0.08883239774149843, 0.028292142596910708, 0.01605563211342087, 0.022411781865230296, 0.02221688089775853, 0.04942427076457534, 0.010597190685075475, 0.032810063057695515, 0.03941414208384231, 0.025798025453696027, 0.0007444471168582822, 0.04738490461022593, 0.08150026813382283, 0.01770809441950405, 0.021626378111250233, 0.018640673479239922, 0.0191577685836819, 0.03522629551298451, 0.036073030350962654, 0.060527664609253407, 0.039634623026358895, 0.02018951712670969, 0.05574949893343728, 0.02054780190519523, 0.018595890433061868, 0.08712657872820273, 0.06522960800793953, 0.05716857805964537, 0.02044836710410891, 0.018365060241194442, 0.031080474909686018, 0.018213181574537884, 0.07666529476409778, 0.05640467061311938, 0.0456179214961594, 0.14472068200120702, 0.020017012320749927, 0.03780518447456416, 0.016573586253798567, 0.061859114648541436, 0.011300164096610388, 0.07403369105304591, 0.016131583506648894, 0.011735753760149237, 0.018233457049063873, 0.007171391089286772, 0.05447462652227841, 0.04156719413003884, 0.04190541309071705, 0.044489348656497896, 0.07669472834095359, 0.030933837660995778, 0.05742279703554232, 0.0296528592298273, 0.05691817372280639, 0.084727816429222, 0.026091530016856268, 0.020434500074770767, 0.012976172893104376, 0.09524257213342935, 0.044849765254184604, 0.06394230091245845, 0.03328696715470869, 0.016864057288330514, 0.00825757291750051, 0.010378630977356806, 0.059268369877827354, 0.009504043337074108, 0.02180439892981667, 0.02012539371207822, 0.03598599127144553, 0.027364049819880165, 0.0023970882921275916, 0.04918822327454109, 0.027227843456785195, 0.027179614990018308, 0.06075381184928119, 0.03298657546110917, 0.015933033027977217, 0.058818201650865376, 0.022727677023794968, 0.02799232977849897, 0.030627302840002812, 0.07239538521389477, 0.03123076538031455, 0.0377409256179817, 0.057965195665019564, 0.05391599341237452, 0.03296537230198737, 0.022734027952537872, 0.021181078373047058, 0.04383926439913921, 0.04204006465442944, 0.029104035456839483, 0.04317620740039274, 0.0897046884347219, 0.025106846624112222, 0.04482246906263754, 0.050586711513460614, 0.02037623962678481, 0.035759962775046006, 0.04834404513530899, 0.043088697057100944, 0.0549016434524674, 0.036636034710682, 0.07503622866352089, 0.08485226717311889, 0.008226237587223295, 0.041794269054662436, 0.050547225546324626, 0.09693570784293115, 0.018956765306938905, 0.028576149525179062, 0.0058817568969971035, 0.07566977044916712, 0.011119847258669324, 0.03936699344194494, 0.0384977715293644, 0.03450619704381097, 0.03096542346611386, 0.03935153079510201, 0.02699654385651229, 0.14523988851578906, 0.159812091733329, 0.13999444810906425, 0.1372689107665792, 0.1575724533176981, 0.1502631595940329, 0.13461890921462327, 0.13411913212621585, 0.13484091527061537, 0.16630414727842435, 0.14329660451039672, 0.11813888180768117, 0.1311734737828374, 0.12007116718450561, 0.21217461791820824, 0.1406915474217385, 0.231602203566581, 0.2998661046149209, 0.14230564440367743, 0.09186614901409484, 0.11312335875118151, 0.10763305414002389, 0.14446538320044056, 0.20906988764181733, 0.11591011585551314, 0.09808165064896457, 0.11064675258239731, 0.09484342284849845, 0.20015467540360987, 0.1421122852480039, 0.15002426225692034, 0.14819420030107722, 0.1462458400055766, 0.14195800758898258, 0.16315200860844925, 0.11158260822412558, 0.08388957547140308, 0.23658536898437887, 0.15409783663926646, 0.11817584076197818, 0.11714360982296057, 0.1209741753700655, 0.1668566168518737, 0.07457433079252951, 0.13712475600186735, 0.14469062502030283, 0.0813748971268069, 0.12302229515626095, 0.0921023300907109, 0.0925754640775267, 0.15272247372195125, 0.23076805926393718, 0.1349504414247349, 0.1361185818677768, 0.12131925919675268, 0.13514443882741034, 0.06424172039260156, 0.12930048600537702, 0.17691022425424308, 0.249797260039486, 0.12141501108999364, 0.16948001983109862, 0.1295097716501914, 0.08036539817112498, 0.15262770146364346, 0.16753140720538795, 0.21624742046697065, 0.09702242037747055, 0.13073199981590733, 0.07938084279885516, 0.08380903760553338, 0.11777961553889327, 0.11236170743359253, 0.1908262650249526, 0.15637404809240252, 0.15592546435073018, 0.11954793080803938, 0.10878888235311024, 0.21475781133631244, 0.1132427628908772, 0.3055869945092127, 0.16685342561686411, 0.090806881635217, 0.0817727847606875, 0.21624048880767077, 0.15788837074069306, 0.23362390289548784, 0.10886904172366485, 0.1668192571378313, 0.26266191503964365, 0.11803878092905506, 0.19454961991868913, 0.1444041560171172, 0.19197715795598924, 0.11641778939520009, 0.23810178448911756, 0.10098542217747308, 0.08039879481657408, 0.17341561411740258, 0.10250746316160075, 0.15715650923084468, 0.15066334046423435, 0.19442520628217608, 0.1230937046057079, 0.23424865765264258, 0.10508446706808172, 0.13858741032890975, 0.19590448471717536, 0.2432363628759049, 0.23354964359896258, 0.14283846190664917, 0.10365287162130699, 0.10089775227243081, 0.19472804706310853, 0.1162613595079165, 0.16020137787563726, 0.11132058556540869, 0.11352631525369361, 0.08225514364312403, 0.12381719468976371, 0.16894246742594987, 0.08790592284640297, 0.157553929311689, 0.13888130080886185, 0.09349692947580479, 0.09473194484598935, 0.09508396775345318, 0.16438471589935943, 0.1376163397799246, 0.11869601206853986, 0.14604642492486164, 0.0727894582087174, 0.15665259095840156, 0.12241726668435149, 0.15661589917726815, 0.12792276305845007, 0.13268184440676123, 0.07801535044563934, 0.1033933500002604, 0.17063541017705575, 0.24056160327745602, 0.10690512601286173, 0.10228829953121021, 0.09439058660063893, 0.15176679531577975, 0.22577594354515895, 0.06860589011921547, 0.0708631842280738, 0.15267723239958286, 0.23798948270268738, 0.132201541273389, 0.09482486915658228, 0.18760347389616072, 0.12955093116033822, 0.20195888093439862, 0.17894415417686105, 0.16414710989920422, 0.1492878736462444, 0.17523181275464594, 0.1786424859892577, 0.18221972684841603, 0.12626266776351258, 0.08855854524881579, 0.14708051865454763, 0.14330027071991935, 0.12902247748570517, 0.1306826321524568, 0.09169475000817329, 0.2013762653223239, 0.07583420068840496, 0.11652651402982883, 0.16237164032645524, 0.12499228905653581, 0.06866431940579787, 0.0932598281360697, 0.15911710012005642], [0.021013794575992506, 0.06778345690690912, 0.04352351767010987, 0.033397677034372464, 0.03456703831034247, 0.028900983852508944, 0.04577337916998658, 0.008829283597151516, 0.04077207937370986, 0.07231110692373477, 0.02745085697824834, 0.04748010731418617, 0.10627277166349813, 0.019191938918083906, 0.021463239208969753, 0.03561042372894008, 0.03429964621318504, 0.11294968877336942, 0.06486764032160863, 0.039148520008893684, 0.08540774244465865, 0.028841274361184333, 0.051570276118582115, 0.011509612086229026, 0.05815937489387579, 0.11815091202151962, 0.037092470374773256, 0.02085550189804053, 0.008551322389394045, 0.09905628350679763, 0.07196746286354028, 0.0021914881062912173, 0.03630158586020116, 0.03244783933041617, 0.022202507352631073, 0.03444346701144241, 0.027133078619954176, 0.02154091424017679, 0.06261407179408707, 0.01644266398216132, 0.05171412289200816, 0.040104521249304526, 0.04130830704525579, 0.029398196820693556, 0.031046582880662754, 0.041922682867152616, 0.015713353604951408, 0.020621550975192804, 0.05420295594376512, 0.05190794217924122, 0.04471252359508071, 0.061321521425270475, 0.04359158374427352, 0.02697265226743184, 0.019492395549605135, 0.015182677198026795, 0.040508513047825545, 0.045579763973364606, 0.03398156171897426, 0.013630537487188121, 0.06549004989210516, 0.03600665266276337, 0.03907862082996871, 0.006846573924121913, 0.04159405245445669, 0.05685480915417429, 0.03248366650950629, 0.06134038310847245, 0.0248374841248733, 0.053266439790604636, 0.0222464332182426, 0.02156303951778682, 0.02760283026873367, 0.0635835986759048, 0.05535026059078518, 0.017845360198407434, 0.05257502903987188, 0.052663467067759484, 0.027128429064759985, 0.03786675675655715, 0.00851725131724379, 0.03813397815974895, 0.06469651591032743, 0.021502810523088556, 0.124652786180377, 0.04458898940356448, 0.053282689113984816, 0.01590713578480063, 0.024473156408930663, 0.10555630971794017, 0.020815168027183972, 0.009086270783882355, 0.05001801488106139, 0.02471937503287336, 0.08278267705463804, 0.015738319452793803, 0.04495581073570065, 0.029440669932228047, 0.03477578589809127, 0.02369119622017024, 0.066768911347026, 0.015842305474507157, 0.0526419299421832, 0.03189168499375228, 0.06491158288554288, 0.02084366093185963, 0.029677442871616222, 0.027972800162388012, 0.04070571652846411, 0.028563725973071996, 0.017936045078386087, 0.02683264796360163, 0.0870000351278577, 0.02150309253920568, 0.046967914095148444, 0.056737108243396506, 0.03239390374801587, 0.03329648890940007, 0.13357010611798614, 0.012602008009707788, 0.026937635884678457, 0.020598796727426816, 0.10329983939300291, 0.07628005332662724, 0.020700960776594002, 0.004032245105918264, 0.02184221135394182, 0.04748987026687246, 0.031098123181436677, 0.011863301115226932, 0.03783590938837733, 0.0954352188273333, 0.05862339530722238, 0.027196459886908997, 0.04025908463518135, 0.01034739769238513, 0.02670534551725723, 0.05839593075506855, 0.10125180124305189, 0.030732500417798292, 0.03675299718452152, 0.036777436107513495, 0.054849600346642546, 0.025075943594856653, 0.015066586747707333, 0.032279549923259765, 0.024894195339584257, 0.05791815092379693, 0.03891446889610961, 0.05887090155738406, 0.028210721575305797, 0.01714890284347348, 0.044354793571983464, 0.05075551671325229, 0.009013132130348822, 0.030485177849186584, 0.06794997258111835, 0.027214781657676212, 0.0403067898878362, 0.03483913191303145, 0.024172410339815542, 0.011210430093342438, 0.05035141730331816, 0.07331249420531094, 0.015518009204242844, 0.039212637857417576, 0.04635852550563868, 0.02649925296282163, 0.08008761229575612, 0.04517157161899377, 0.021351985706132837, 0.025241921212000307, 0.020174214041617233, 0.0663054252800066, 0.057470350147923455, 0.006896965751366224, 0.025945313936972525, 0.04086605382326525, 0.01646141619858099, 0.028442440489016008, 0.023807459219824523, 0.10123099884367548, 0.043589168053586036, 0.01372611683109426, 0.027025804884033278, 0.04929216105665546, 0.04664434884034563, 0.028704062387987506, 0.07925634752609767, 0.0570064113708213, 0.03672505161375739, 0.025268245190090965, 0.04984253035217989, 0.03505324522848241, 0.04895845064311288, 0.024307746534759644, 0.009939292540366296, 0.044341286484268494, 0.04708536638645455, 0.008568193261453416, 0.0545303803664865, 0.009381300460518105, 0.00910561764612794, 0.02198451074946206, 0.07129627192625776, 0.07769132134853862, 0.11455924381152727, 0.08034164944547229, 0.043545203225221485, 0.05844542458362412, 0.07443391645210795, 0.05472514960274566, 0.01893735257908702, 0.055394525988958776, 0.06314331214525737, 0.08383686814340763, 0.07352343483944423, 0.02747400641965214, 0.04199907212750986, 0.028375903239066247, 0.05224575666943565, 0.04131400302867405, 0.036719622803502716, 0.03177080026944168, 0.09854399380856194, 0.0522594455833314, 0.04845683302846737, 0.050141155734308995, 0.01850028882472543, 0.018191410672443453, 0.03472127515124157, 0.04237864355673082, 0.022488839058496524, 0.02264701484818943, 0.01608232530998066, 0.032672661836841144, 0.08594407030614093, 0.02126810075424146, 0.05551209702389315, 0.036544754257192835, 0.0540370376984356, 0.06590085089555942, 0.04418080447067041, 0.03647648038167972, 0.027081093030574266, 0.027513351378729567, 0.05501467996509746, 0.04480139949009754, 0.06315612903563306, 0.021964109109831043, 0.018259827411384322, 0.030232849494495895, 0.08741485115024261, 0.03387127486348618, 0.030214958169381134, 0.018921387127193157, 0.060383101663319394, 0.0506535753083881, 0.0328260674723424, 0.028819405124522746, 0.04373540454253089, 0.048870721366256475, 0.0336826172133442, 0.004227627541695256, 0.06619932042667642, 0.05838391538418364, 0.004468672932489426, 0.049308384404866956, 0.04302662382542621, 0.054618707072222605, 0.07078641647240147, 0.019798956345766783, 0.025497713540971745, 0.02447058301186189, 0.023437864110746887, 0.045766198891215026, 0.04971548209141474, 0.052300445531727746, 0.005280593159113778, 0.03097546101344051, 0.03980491623224225, 0.054439029408968054, 0.02596200483822031, 0.053565577254630625, 0.019593266406445764, 0.06628008093684912, 0.07290685854968615, 0.03941880648199003, 0.03653161824331619, 0.04410037050547544, 0.05065309662313666, 0.032654601673129946, 0.04526058110059239, 0.09023787701153196, 0.010761153371277032, 0.0497665270086145, 0.014082343077461701, 0.0115383229967847, 0.06919578619999811, 0.045685534860240296, 0.08231163592427038, 0.02660780319274636, 0.049957188457483426, 0.06531300314236432, 0.03810632202657871, 0.03767947950109374, 0.004748464461954427, 0.014882877367199399, 0.03403859205718618, 0.022068922626203857, 0.03819960627879482, 0.026254242184222676, 0.03936193941626698, 0.03631283681897912, 0.015963934201863594, 0.05120215231727343, 0.0417628502327716, 0.042765955586219206, 0.04667537061322946, 0.025022488553076982, 0.04234252694004681, 0.046798693292657845, 0.04930768678605091, 0.07621206517796963, 0.013689816532860277, 0.07137479857192375, 0.017659487457422074, 0.06506934863864444, 0.04552877842797898, 0.040187511913245544, 0.03267233529186342, 0.07610840941197239, 0.04346384899690747, 0.06460281976615079, 0.037220869344309904, 0.020385705720400438, 0.04920043902529869, 0.03266780076955911, 0.033691779026412405, 0.02251629666716326, 0.032726152130635455, 0.04136527430091519, 0.026847258995985612, 0.01996621045691427, 0.03897377391695045, 0.03065214437810937, 0.042050246920553036, 0.02000873180804774, 0.030334642469824757, 0.022622362557740416, 0.029376789570960682, 0.005991445395920891, 0.11356379371136427, 0.19974665745394304, 0.12210618064273149, 0.09682317599072121, 0.12361211702227592, 0.16277671937132254, 0.16332755621988326, 0.10219108560704626, 0.18800160643877462, 0.19190965220332146, 0.18543080688687041, 0.2861833950737491, 0.23561912239529192, 0.15650441375328228, 0.10867252844036557, 0.09122654388193041, 0.1166431573801674, 0.20951324666384608, 0.2513848029775545, 0.15224442671751603, 0.1014931476674974, 0.23782511183526367, 0.11422676907386631, 0.11359040712704882, 0.13053176837274805, 0.18564675701782107, 0.1800870764418505, 0.1110923825763166, 0.14943737187422812, 0.19510156998876482, 0.3088205022504553, 0.14187006308929995, 0.11046172774513252, 0.13543798791943118, 0.13441134535241872, 0.16603400552412495, 0.11168551442096941, 0.11086919650551863, 0.23922259075334296, 0.2013644206454046, 0.2126605316880159, 0.15292929543647915, 0.1360132117406465, 0.10861153132282197, 0.08734063638257794, 0.10069513111375272, 0.09856732693151571, 0.10786527956952341, 0.17977412760956213, 0.13735505926888436, 0.10672191201592796, 0.12578068737639114, 0.14430169510887936, 0.10699648439185694, 0.09049866770510562, 0.16019682108890265, 0.1686340308515355, 0.1483645974076353, 0.08178319709259085, 0.2002626727335155, 0.17671674635494128, 0.11642780096735805, 0.1299476090935059, 0.11370515057933517, 0.20236213429598138, 0.1766197624965571, 0.11991755745839328, 0.11074138383264653, 0.10359322521253489, 0.15487526601646096, 0.12251715234015137, 0.16550556669244543, 0.09720489222672768, 0.09563714236719534, 0.12299459078349173, 0.09961950680008158, 0.1318786179763265, 0.10372596574597992, 0.06829924954217859, 0.16008630045689642, 0.12621263216715306, 0.13026835047639906, 0.128401359252166, 0.1417355117155239, 0.2731686184415594, 0.10820591051015072, 0.20514741452643648, 0.13453525432851166, 0.15164261916652322, 0.12373167701298371, 0.098087929218309, 0.1100796478567645, 0.099146365391789, 0.1638259380706586, 0.24018111900659278, 0.22891401109518483, 0.16068086464656517, 0.08785026177065447, 0.1451872702455148, 0.10795525013236329, 0.1401637468370609, 0.11781715336837806, 0.10456514180987142, 0.09748808093718253, 0.15706947015132755, 0.15137995826080441, 0.1446196311735548, 0.07972752224304713, 0.09728251345222816, 0.13989350118208677, 0.18494643678423017, 0.14147426089039072, 0.1822011879994534, 0.10754246759461239, 0.11453526502009481, 0.24228697788203135, 0.19054870179388672, 0.28523970977403224, 0.2243966472451575, 0.14822989760432392, 0.15295420191250741, 0.10483483827556483, 0.26141513662878424, 0.20954094361513853, 0.11323301849188283, 0.11774337646784261, 0.18376557593001053, 0.17929303779965267, 0.12814436835469678, 0.06798969232477248, 0.09371918786200695, 0.23641323525225744, 0.14460567879723385, 0.23839879198931158, 0.11008528075763024, 0.10604514012811705, 0.10340080116293393, 0.09781101165572181, 0.28986222110688686, 0.16922120325034484, 0.1816846086876467, 0.12019460118608549, 0.14938714331947267, 0.09797933817026205, 0.18200904596596956, 0.1273961499100551, 0.070021507126512, 0.2840488002402708, 0.09201503868098371, 0.1418531421222724, 0.0989496146212332, 0.099824309872929, 0.10767793181003071, 0.23347915441263467, 0.11458831373602152, 0.2008353138808161, 0.14117780257947743, 0.1512254134286195, 0.2176589853479527, 0.1646671030903235, 0.12746705469908193, 0.14881080627674237, 0.1109916582936421, 0.1373128904378973, 0.06742137789842673, 0.16510148212546483, 0.14534926624037325, 0.20624733675504103, 0.20508646935923025, 0.16158984712092206, 0.09289315523346886, 0.16959699714789167, 0.08416142416535877, 0.12161927239503711, 0.13909198169130832, 0.1456856372533366]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04500275899772532, 0.026582152713672258, 0.018865393940359354, 0.02150710570276715, 0.042485442318138666, 0.019805635674856603, 0.00223766128783609, 0.1122621854301542, 0.08530250590411015, 0.07956985296914354, 0.05965379314147867, 0.014322708011604846, 0.010666963698895415, 0.03890073174261488, 0.04073230396897998, 0.006702514247081126, 0.09629713429603726, 0.020408563868841156, 0.020303544406488072, 0.019246952469984535, 0.0541095195512753, 0.02139172956958646, 0.0164546199812321, 0.04273579841537867, 0.05227883048064541, 0.0583797408035025, 0.023199042843771167, 0.07300085155293345, 0.02550313678511884, 0.06378213060088456, 0.06475622911239043, 0.01336797584372107, 0.02902774082031101, 0.0791447730443906, 0.02270526787469862, 0.01942069109645672, 0.009138814839388942, 0.0297133238564129, 0.00822540638182545, 0.05629538936773315, 0.04295879894925747, 0.05071278013929259, 0.005620884103336721, 0.011841910563816782, 0.034868995935539715, 0.013688587350770831, 0.05087197081593331, 0.020893058281217236, 0.02967929824080784, 0.015051074933580821, 0.03963366194511764, 0.0272068610865972, 0.04918876504234504, 0.012285467182664433, 0.10246459671179764, 0.040735261427471414, 0.018758370679279324, 0.04121213954931591, 0.03816445074335206, 0.030549291986972094, 0.016569799445278477, 0.046880975205567665, 0.08109742295346223, 0.038029212882975116, 0.04380118480185047, 0.05648958343954291, 0.03246727246732917, 0.015230006738420343, 0.027613708298304118, 0.04517066990956664, 0.04799698348506354, 0.007716500413152971, 0.05174542668100912, 0.03508849724312313, 0.04036531194287818, 0.08898628948372789, 0.03347981422848534, 0.05346341320546344, 0.012118337381252786, 0.018159784049203154, 0.07632571767317131, 0.05632000269542914, 0.05750614021962974, 0.014455376185651403, 0.011113367381767603, 0.023062513646436855, 0.015651623616577126, 0.022428068295994308, 0.06330746036837809, 0.06632368953432888, 0.056487579640815966, 0.11865698252222501, 0.015127145070437109, 0.03634558779594954, 0.006201114174473332, 0.012698615228146082, 0.07656928311917, 0.06533540115924552, 0.021207810532359872, 0.020581111348292325, 0.06920307409018278, 0.02670291312824702, 0.014186744701873977, 0.035969842138001695, 0.023195517642307095, 0.009968304948415607, 0.07256592332851142, 0.030371605134860147, 0.11333418806316331, 0.02030574672971852, 0.055760371396900155, 0.02880439889850095, 0.07789345268975012, 0.09694008651422337, 0.04039031860884279, 0.05033234410802834, 0.003357048426551046, 0.013343651025934378, 0.0796665548114106, 0.04613608900399413, 0.049102267730631866, 0.03301550808828324, 0.016230932960752398, 0.07795980069204234, 0.011458403896540403, 0.05384390118706506, 0.01114918621169636, 0.03411766047065612, 0.013072541696601547, 0.012706839152087923, 0.03361028379003983, 0.024147307194652967, 0.036327757698018104, 0.028423797739378642, 0.00982572168140905, 0.04857224070292432, 0.008627887909824494, 0.04450084081327077, 0.11800665335613303, 0.03554357848770451, 0.124386763345683, 0.017786506032280158, 0.03206811205018312, 0.009575209733156953, 0.025367624330101535, 0.1169950986513868, 0.03845528728561476, 0.08938920887885615, 0.04544600669760257, 0.044916784900124185, 0.03944113770558033, 0.04861545967287384, 0.017161612122436054, 0.011543489272298757, 0.015828980212972965, 0.05955207809165586, 0.029907015123171732, 0.032651065339450724, 0.06012611818732694, 0.033014194486895576, 0.026560986661934294, 0.04361559222161304, 0.08091904775938019, 0.008627909246570198, 0.028390519837557804, 0.0471084842865821, 0.053227525277179666, 0.03301788296084851, 0.11400957955629565, 0.0434230976679828, 0.035932649407186545, 0.02893751978263026, 0.058663690215325914, 0.10034733844804578, 0.012167548266006634, 0.015524508562521078, 0.0151501201071369, 0.028544973756652325, 0.06266987387789413, 0.049759803150664084, 0.02357420962653123, 0.045461239278665744, 0.07756172009976581, 0.03063150154048344, 0.019941775244660676, 0.034479624446248636, 0.08129858950269409, 0.02442185730615165, 0.02080997855955502, 0.037787521359859966, 0.06693663672194816, 0.026273922085238155, 0.05059740586148109, 0.06619049629080109, 0.045964946039021015, 0.049623863960732706, 0.04087495959538501, 0.05253850424196571, 0.05927014361077454, 0.035571197513490915, 0.040707193402340636, 0.031985737368813716, 0.015582435044052545, 0.04290695251256693, 0.04310665332013741, 0.07909608073532581, 0.03430684133491013, 0.023836323198338505, 0.07020749675575644, 0.043182972076465376, 0.00629890465461358, 0.03691148653160781, 0.021714259528380353, 0.04876746636000462, 0.02328514867258491, 0.018729041003098246, 0.05867774278158322, 0.013451816266751848, 0.03437455488892738, 0.07211498697870411, 0.017197530214616563, 0.015332297880377155, 0.013459446472552372, 0.045833971817046404, 0.049359540644218214, 0.00046629842984202696, 0.04379979698569514, 0.11845913337310776, 0.01771717274095863, 0.045028626554994844, 0.09062147830263712, 0.007837803059373982, 0.0328210653970018, 0.06867755932034925, 0.018427374670864083, 0.07065345329465345, 0.012103363624191843, 0.01142402483310434, 0.03662481714854948, 0.08388689631829038, 0.0325919124588836, 0.02027270631515421, 0.01026400441332953, 0.017741273986757733, 0.05978465604130179, 0.066658605937846, 0.017708367158775218, 0.03740861786354799, 0.03666232900286559, 0.02791708157019457, 0.04120512254303321, 0.021161782533454243, 0.032877275662031025, 0.03152711607981473, 0.012892504091723822, 0.05390118756622542, 0.07106820994522423, 0.10617825915687717, 0.09149563178652897, 0.05076492343505379, 0.08331184319104068, 0.05937720212386921, 0.07667817844776437, 0.01767615794960875, 0.04073726151545998, 0.04366011737147346, 0.02759010614681756, 0.020266103056201246, 0.03349956648889929, 0.03123727030470036, 0.0446756314340746, 0.037567300169030204, 0.03543834936863277, 0.041447537660133094, 0.04164842590398621, 0.0670383257966023, 0.012936585808347445, 0.011177844244230073, 0.05142520851222798, 0.0434282333299052, 0.04240785820002202, 0.03672253944387194, 0.03757046171813272, 0.045645562786376104, 0.01211048174809548, 0.023720305107417516, 0.039912520223879255, 0.01725511345284758, 0.019782354502240196, 0.037288979947334155, 0.06628966948483139, 0.013095173490000889, 0.05359385679184925, 0.03139917353109922, 0.06286192685365677, 0.025839979061856866, 0.04843267612159252, 0.03372047045559157, 0.024322871504409704, 0.06400446320185438, 0.05359496259188745, 0.04424674429174047, 0.04273190214007627, 0.06360403742291965, 0.03859530457702931, 0.03537935976055451, 0.04983659317076672, 0.045308898625080474, 0.03701118293975014, 0.02788007437629858, 0.019383398175705224, 0.03473062621196732, 0.047834059805609286, 0.04879764950601384, 0.07610682863742113, 0.03834221737633925, 0.034346104657743126, 0.09177744752378203, 0.01722417517157737, 0.02567950818047393, 0.05185725720366463, 0.052764592110179365, 0.03405075585760642, 0.05690508594852872, 0.01701759651041357, 0.011809009301941842, 0.06728787295287475, 0.03193693744833581, 0.03276786825153977, 0.038035959005355835, 0.030765546398470178, 0.03492055293463636, 0.0167799589689821, 0.02202595042035682, 0.040451330569339916, 0.020950643374817446, 0.03853239271847997, 0.0344343942560954, 0.027782893848780077, 0.02130023389327107, 0.036548335119732656, 0.07327176514081657, 0.03953136059863027, 0.04839289700612426, 0.02559710937930504, 0.032561888874624856, 0.05245852669759188, 0.043079746756120585, 0.01819759090722073, 0.03795711323618889, 0.022579418182431255, 0.028318041695456486, 0.12647698516957462, 0.20695880404673517, 0.23020184511551633, 0.2107508372864686, 0.08658195365569554, 0.0925497263961006, 0.16660136257996783, 0.1832358309184201, 0.17301195999607444, 0.12549306062282994, 0.2052309803548269, 0.08974858646979555, 0.11340331911924295, 0.14546836609952152, 0.10752509391750209, 0.1218749200052116, 0.23549435252789408, 0.14929290540749207, 0.1007143230526708, 0.14668107993202284, 0.12191140398499556, 0.14189574139891192, 0.14318992820335552, 0.150396597746294, 0.11456030508270487, 0.13290900096762925, 0.10997987352311611, 0.20738838880788535, 0.22559984674444422, 0.1529828636557795, 0.13022129831369966, 0.14156471384922042, 0.10931602242635563, 0.16594318149145693, 0.06471767454058863, 0.06900293912622146, 0.06919422768987715, 0.1285776193253696, 0.059189668827457353, 0.16409300733357668, 0.11144893258460797, 0.11410517559852451, 0.09547684589051642, 0.12395076642860658, 0.11307393171591684, 0.14533273119013757, 0.15201872476609424, 0.10118811755091883, 0.14268927538068965, 0.08211581283831038, 0.1637170056346804, 0.2747213398106396, 0.14593520667403936, 0.06242106144782156, 0.16480723541462794, 0.09154403465799987, 0.10423708285088651, 0.2244129596510902, 0.09897948606521823, 0.2363661237177439, 0.08411574497586116, 0.11478334272396751, 0.13034635019721463, 0.2896783169126138, 0.1386504335096106, 0.09345335798570886, 0.09492419078014791, 0.08278959387098439, 0.12843301927205175, 0.26740726665593684, 0.0814949395135045, 0.20287415682105348, 0.16734046745114028, 0.14845968136796728, 0.11804053981904872, 0.13966172846267, 0.13911728892708197, 0.16748304886277765, 0.0706673388776835, 0.14193134964443743, 0.12971484189620242, 0.22713172860676423, 0.13001744518987834, 0.10961254010908306, 0.11317461146973073, 0.08750171211431734, 0.1590581884374842, 0.08715941134141758, 0.1282786377123557, 0.12023864022921771, 0.11860958897159435, 0.12912988109746948, 0.18363541807048023, 0.12104639376047999, 0.12847938865888864, 0.07150643330533057, 0.15192313614534214, 0.18903757038060576, 0.13075114722596481, 0.12985501874936745, 0.17842807952547446, 0.09437350978259929, 0.12117029531509615, 0.15793073253007606, 0.08905737980967388, 0.08386066139792092, 0.1263612843467854, 0.10852717881789431, 0.14421853004023433, 0.08483943543978967, 0.09624254933441989, 0.0930838797648903, 0.1560775304096751, 0.21508529142010957, 0.1629676591255702, 0.14900428417604417, 0.12634921702556312, 0.07869820052292198, 0.13729501952184364, 0.1430745836114511, 0.144760787661653, 0.0861953392450232, 0.07291356756468304, 0.1465535641182214, 0.11543276646989398, 0.10874651314225048, 0.1637377412407659, 0.13609569403342903, 0.146060778060928, 0.1482473677606322, 0.11381708129192702, 0.09394345004693605, 0.19947587745264173, 0.10699718201067299, 0.11354233080055565, 0.25238714762963355, 0.16072515601990744, 0.12060722045134753, 0.1995857895235531, 0.16148587223142385, 0.2155358492746018, 0.13677097420440987, 0.08240449344157241, 0.11513299818034284, 0.09578624725691043, 0.23620924854185432, 0.1469822583021596, 0.1527220878051594, 0.1761460941634141, 0.1128176310157869, 0.14066389499930665, 0.16476732271257788, 0.11154256935697049, 0.19358102814294398, 0.12227700819494203, 0.16249789448920637, 0.13054196548182517, 0.13602787657873705, 0.18082947644870728, 0.11090234824223444, 0.11401800293242559, 0.17607012792723253, 0.1553978121955879, 0.11287123634247109, 0.1145793337491341, 0.11047953928937204, 0.1678753035957925, 0.11805820293375291, 0.2005977078806609, 0.07971090555656701, 0.1330252955085598, 0.1377209380734712, 0.11510877448017709, 0.2269367515691556, 0.14520208351314068, 0.13136586814653128], [0.03436609811615199, 0.03599559837311972, 0.005422243175416952, 0.03510184476908762, 0.0483571217773715, 0.029562230010924395, 0.04298967971408274, 0.027912719597225077, 0.05323047902493272, 0.017756042725523002, 0.02856432525732089, 0.09691233019111678, 0.02888531525968574, 0.016033911306294613, 0.09860483507509343, 0.07496318648918532, 0.009278437864850275, 0.0011202816585864639, 0.014233858091756701, 0.08733507027500309, 0.04393167662783526, 0.07423810820910148, 0.012266945032024523, 0.02284605143358931, 0.039207253576023504, 0.03418316613533534, 0.08603142850915901, 0.04687633678258862, 0.053446388337761164, 0.07410799487843178, 0.07097265843185596, 0.07320948410779238, 0.029044318544038106, 0.0614903377572773, 0.06432783920899965, 0.017149474297184497, 0.041463445595582016, 0.013475128980644513, 0.0053840995678910986, 0.01502451254054904, 0.036457733731367625, 0.032135473084053956, 0.08892857265891507, 0.05587124083831441, 0.060488356757559814, 0.06101148923335131, 0.04040431922476273, 0.08187868923414499, 0.020867018174612895, 0.035744756169151515, 0.045273921205080114, 0.01772040850482881, 0.04300866385165136, 0.0067900988051405875, 0.01708984829747351, 0.024033801273617428, 0.040292655685334466, 0.020139557600487024, 0.11148438497912139, 0.0283135461359052, 0.024783850967651233, 0.005136156378284795, 0.012194650571473176, 0.017633079987717792, 0.040551702331868, 0.07587771280668676, 0.03655342254205607, 0.03445650283538271, 0.050238388212164864, 0.011889350498677231, 0.016748684865888208, 0.02793963358271867, 0.0058213400461681886, 0.028271904229768552, 0.04793153719219845, 0.02044586421106942, 0.06874069382320158, 0.04321907756093424, 0.0717619621718768, 0.08853126390022226, 0.016631442231300753, 0.04022847475425806, 0.0349166492378572, 0.02230154881544877, 0.03491822259093169, 0.007807362017047126, 0.0058148527477897005, 0.09102422700379975, 0.029978038655826822, 0.035521529280231334, 0.08668457041494548, 0.010048990316136042, 0.06362974541843869, 0.020491086979745887, 0.05039302952354774, 0.05131920755957253, 0.02816091047861846, 0.007239963215397438, 0.10249166283756495, 0.07284954248461872, 0.07519064733060077, 0.029230729342089035, 0.02629783037264133, 0.03470085866865702, 0.02206695036875317, 0.008990574551717145, 0.022041019728931133, 0.01191141176605015, 0.08713982606423087, 0.008722542352188611, 0.02551715781009989, 0.01223875640789629, 0.042800439478014596, 0.052302338008303195, 0.018405403388896957, 0.016598385118413717, 0.005041293670728919, 0.025694968971947674, 0.05520352686289698, 0.049381025819457136, 0.03323309836559929, 0.017019095648720395, 0.05754871352110058, 0.008997847598948283, 0.04176927723165136, 0.03874291403917596, 0.04863550508162007, 0.0767547903524246, 0.025966650682676118, 0.02025112094997894, 0.026282883518433664, 0.018735143312369473, 0.024715079853194766, 0.06390845897840336, 0.07454503822373226, 0.05237954363110475, 0.014920593312126584, 0.03027935617865296, 0.03438383915636223, 0.041560759709682316, 0.03413192825973965, 0.036255658051231876, 0.026902164936473127, 0.027673044860421214, 0.013509572054317687, 0.06033703284629155, 0.02044880311586894, 0.04023964407679159, 0.06243891009944491, 0.029702236170123797, 0.045579775105579756, 0.023651021911064163, 0.025798185015446506, 0.019317577098263428, 0.024833994175423868, 0.03855704686429817, 0.018880301831813995, 0.04574326281726826, 0.01722076314763399, 0.010647837625583634, 0.01400924802510417, 0.07798604303388856, 0.07400160800898448, 0.04117351447348483, 0.061165933875599876, 0.002971364019686007, 0.03632319348980673, 0.0424190831836313, 0.025918459323293064, 0.008289907364087412, 0.03026198250154266, 0.02010779924603412, 0.04164416968706064, 0.08509871215210296, 0.008663559237902518, 0.0501737323065754, 0.02522940303606447, 0.015581360785290599, 0.044426254971767776, 0.011463411537988577, 0.027416289594839327, 0.038686737170792185, 0.025497207025182433, 0.03757934522582218, 0.03673531551612541, 0.023148767904785927, 0.009060474658326712, 0.06100300648540724, 0.04132444504648447, 0.02557946296292357, 0.0016934159862103115, 0.08993976371129975, 0.04496354391449131, 0.04520469738054089, 0.030122211974230595, 0.05618591145321261, 0.05908271050429903, 0.08830035949358717, 0.06570882760570385, 0.021910281138843857, 0.07972964478540234, 0.03710489021614194, 0.019933765615860466, 0.030830688410787843, 0.060575792886083946, 0.006560756619364838, 0.06610777651076205, 0.00497048907163844, 0.03140664324746467, 0.010145348915102659, 0.011762674239435, 0.04161774551903363, 0.005302721219777595, 0.019916770434065256, 0.03351310326252133, 0.014992239321145462, 0.0390320362203056, 0.08766145940171555, 0.0452329360996373, 0.03853055590298027, 0.05414176957856398, 0.017740802722983062, 0.05575837873038836, 0.03925311459170189, 0.044112333926022984, 0.01799638910597423, 0.04532793471298646, 0.04694097784522455, 0.01607568123290548, 0.0039174766061478294, 0.031638857544749044, 0.03227797285944689, 0.019068840738327708, 0.021585431968560442, 0.05567651242017746, 0.0718548493750859, 0.011463735299912514, 0.05172555938770529, 0.008969312948465813, 0.04347727444837801, 0.006389708278220496, 0.08145101921400055, 0.03495225748338271, 0.0605862052179873, 0.04302074230508879, 0.07224143409985118, 0.06399939433322288, 0.0682344006781932, 0.011737457916751737, 0.03581596152798738, 0.030824972018308472, 0.08390345363295637, 0.03199739279807545, 0.024745914233790245, 0.0774789483693894, 0.031044584648043383, 0.06301214496488683, 0.06829352758359164, 0.06095039192587137, 0.02950699195935158, 0.05595591246674303, 0.026763865716930013, 0.008870048841345124, 0.07073021362884901, 0.014892771123413695, 0.045446125441230834, 0.0811692925344687, 0.017996728638536297, 0.0475125465891324, 0.06932547650649212, 0.057596055121393874, 0.038033101736800745, 0.014670037762698485, 0.0277252790692728, 0.04308335730456747, 0.11975927220191807, 0.048152578456210904, 0.04331190910306759, 0.027369204035494477, 0.017634044779697433, 0.07538606965681538, 0.07726238225586712, 0.01685280818492174, 0.06583420603419654, 0.040536569940741174, 0.0105176871875301, 0.057132858491968364, 0.018498066092433874, 0.03162182525557, 0.023180956704891287, 0.03365015938470606, 0.053960607619956136, 0.02122490590409143, 0.045175356572144665, 0.048789404245326295, 0.012332180740486365, 0.05880460550542921, 0.02168443075788673, 0.09464195944019593, 0.0404228951811092, 0.05542817867535632, 0.032590005139354616, 0.053923310988466255, 0.03179471597832162, 0.1169295224826783, 0.08075913719949313, 0.028633649271796457, 0.06653673786786385, 0.053449041515705176, 0.060828831847175024, 0.04436309449374676, 0.05721568588342052, 0.05006042119930498, 0.030030454690859187, 0.004232119854350458, 0.020926258257532027, 0.07428503420669585, 0.017462211617385037, 0.04484277051233221, 0.015147706271818606, 0.031329920020652935, 0.04351362855231855, 0.024863381368049886, 0.07954696513479576, 0.028175911138532683, 0.011278923830104759, 0.041156593506457284, 0.014484767089015804, 0.07092349114827812, 0.04029737945529632, 0.014845151217741659, 0.043231593881500885, 0.055049735310603864, 0.03075375181651907, 0.02512038525310345, 0.07340435724472627, 0.01121766696087434, 0.039122760063037276, 0.028415537635737564, 0.057224172342102975, 0.021637990867020562, 0.019350621223566122, 0.029552762061939575, 0.018741985913948156, 0.05499317623616662, 0.03292036475613713, 0.029261155541462358, 0.011946673985221423, 0.06529741061967798, 0.0622992824355606, 0.04430042012245394, 0.018824933904397767, 0.09881579797365703, 0.08950135481427424, 0.10529586041229777, 0.091564146860037, 0.11392258500563912, 0.204235686105676, 0.10565685588517226, 0.13060478086117655, 0.11928006002563052, 0.11867552879266441, 0.11782996283727698, 0.22849135799333453, 0.1445981237338856, 0.10882417889661156, 0.16990408301353455, 0.3506568510783836, 0.06041082458978053, 0.15212240279652178, 0.13969686173368245, 0.21135803282959387, 0.12646824266994372, 0.22094856976764277, 0.17628462344873697, 0.08743929007323459, 0.21431013301480561, 0.08964398817624897, 0.1563820632873103, 0.12345709721557796, 0.21779533271910623, 0.16870446066604927, 0.19477392663247883, 0.1185728823475074, 0.1168647181475535, 0.08986103668576106, 0.09838857324211858, 0.16715319390641525, 0.1253727139555849, 0.09958446258679032, 0.1045673830958549, 0.12198322903714143, 0.16276897134957835, 0.11383788369130343, 0.21120581834111363, 0.14010297978529707, 0.15144500008318573, 0.13866929890355095, 0.17872608150355518, 0.18578460352728143, 0.13846505986293778, 0.10714680640376173, 0.23758640745654702, 0.21845789247890934, 0.10947729111649096, 0.05003994163416792, 0.09726646821945906, 0.12642770656384528, 0.11206713417777792, 0.18393021397059783, 0.2515376853989437, 0.15137678186874837, 0.0900917332910467, 0.17304782057181, 0.09395786255481653, 0.19330974348122254, 0.16765233274782076, 0.14361526787979528, 0.08298919448861852, 0.142334068659693, 0.1612903460045345, 0.14141802093945444, 0.15776885527884588, 0.1270665175979957, 0.06464391248300672, 0.1380542662809603, 0.17452698026318103, 0.1630930375540629, 0.1141466542321723, 0.12504311132943258, 0.1994260645005852, 0.22352106141624972, 0.10646781549439766, 0.1940647599985823, 0.12772224959917367, 0.09199105988955125, 0.18578821036498994, 0.14523902762448415, 0.10999591133440845, 0.15577307174680755, 0.17872372147394344, 0.1076052310236264, 0.1657768216682598, 0.11894533658050932, 0.08981169870821759, 0.1642749077291228, 0.10559263042523526, 0.15648679516743869, 0.12399810060742311, 0.1680840103654191, 0.12728531757602468, 0.25418456993065774, 0.1498580805491656, 0.10785154983750544, 0.11644872953183949, 0.15960884717060253, 0.12588510755449533, 0.11468695258372463, 0.13464326650137082, 0.10161152022192255, 0.21486114797880873, 0.2211538775009103, 0.13327419699635357, 0.10111136463820003, 0.18782194732921198, 0.12121494291932322, 0.180951930815354, 0.08422747530858032, 0.1200780543149449, 0.12543285760330036, 0.13650077307829633, 0.11954132569371723, 0.15680162905482575, 0.18737115198746324, 0.1872672958415933, 0.08388892238144763, 0.11735237596440129, 0.1685604394879192, 0.1618197644711472, 0.1030030322726816, 0.22605797450523823, 0.19416637485846877, 0.10184566781390458, 0.12102288252208382, 0.13681643817108124, 0.11346321043674834, 0.22148051153635606, 0.13906490814406425, 0.07183851470472291, 0.07930543317343108, 0.12332742175203748, 0.11963747834670357, 0.2075913513544947, 0.18291013198904693, 0.11603172417380847, 0.19655512558529153, 0.09822774241911247, 0.12184253268060274, 0.1445691057597287, 0.2192074022605084, 0.10915983002632856, 0.11607741078478284, 0.147466465132311, 0.11197935295058414, 0.20408415439305827, 0.14415336947422475, 0.11393527573090978, 0.15389854030217975, 0.14771314017707482, 0.15715582645498216, 0.1390389775042422, 0.14930250879842788, 0.09815392841119319, 0.17799646127969027, 0.16751028568251058, 0.15449861122760922, 0.11745060663088225, 0.12698642502073199, 0.15162829571636394, 0.12472186528611928, 0.11011510767275468, 0.10387234695372172, 0.1378286533872597, 0.14825542748440057, 0.17178300797240809, 0.20778607606189325, 0.1113685876771342, 0.17285610898397863], [0.0869443295232486, 0.02169990082620643, 0.005220743123572902, 0.0363273606490111, 0.024645317971589975, 0.07804986031260341, 0.033154623670270666, 0.03757566046260763, 0.009734121176734334, 0.017048304725904018, 0.04906590620521456, 0.03634428903751541, 0.03938514637411572, 0.0423948483512504, 0.015258614675985882, 0.099419030448189, 0.07929401894216426, 0.05150663695530966, 0.017874214900075458, 0.09249345675925724, 0.06500705276266672, 0.04308652256440837, 0.07656443689484149, 0.024463285844831262, 0.031865379569353536, 0.0796964114124421, 0.04829983168747276, 0.037689023520215414, 0.02967848558910191, 0.009821114799706265, 0.014068075288378168, 0.10359142179368064, 0.039724270754959434, 0.05968924924673047, 0.05831224247231148, 0.04175470145128202, 0.021536696986004245, 0.07407922923448496, 0.03021693970367778, 0.03068526271817973, 0.026174470585829113, 0.10720050820964389, 0.04831527578062378, 0.02409225096926093, 0.06258182547753677, 0.012215383394504897, 0.03350897692143917, 0.025876253384922165, 0.023787783029547427, 0.02747093021753244, 0.05928537248109933, 0.06498941933386959, 0.04379464648081921, 0.004905733903797227, 0.019960392019129358, 0.05370760947698727, 0.033874918808578514, 0.027769867301685736, 0.023080976425262634, 0.007925011905172141, 0.02702143548958702, 0.03027807040780317, 0.03822162951109931, 0.057213247928302735, 0.04298654414014891, 0.06696114243823104, 0.01977773277758388, 0.025645961250120308, 0.00375945458017668, 0.047057610063347965, 0.058751675533130765, 0.010056986029667314, 0.020726624243252445, 0.050342808390269056, 0.05498896454810165, 0.042353755634394474, 0.06935132551006973, 0.013505830702342791, 0.014245864185795654, 0.031749623085488565, 0.007688542318646796, 0.03796413766394835, 0.04143434969591908, 0.0361203162901802, 0.08720868252567016, 0.039266744133783504, 0.013786527651973302, 0.03698147105751559, 0.02103552094922634, 0.07077673144522123, 0.06702580576529726, 0.027911914366995916, 0.05679966758179944, 0.010574661864666268, 0.02800950864184415, 0.04427864922035951, 0.04211941879475489, 0.05052828222687822, 0.025770239444682375, 0.02898112466937164, 0.050921735528390855, 0.06279689987422898, 0.0394591162330471, 0.05437920117401518, 0.027933716810366604, 0.025102547733695246, 0.02206226927228272, 0.035821264173137024, 0.03065953616896877, 0.02160889682272682, 0.033955916806007735, 0.04183372533589136, 0.01470847080781823, 0.010638310304784682, 0.013928379903518362, 0.03609978477470577, 0.021200526352913585, 0.05298189294990152, 0.06563793765963055, 0.0340855291869957, 0.03303469260572456, 0.03538105185725726, 0.06183843099279329, 0.02139556461770553, 0.0311943036649609, 0.06670010683592409, 0.03873478381137829, 0.032917132703005336, 0.10919422114966437, 0.068612324539572, 0.016294358756567817, 0.031217091309372336, 0.09194865357130766, 0.03802512364927679, 0.03863837140670512, 0.01227528491654084, 0.011697914433170808, 0.02831275574862957, 0.032829065748956054, 0.055799230249249376, 0.02730776719545247, 0.03436437633354217, 0.05037324386648834, 0.027989307382085826, 0.032952329056570306, 0.019007394621439744, 0.054411076416727155, 0.016040974696807098, 0.0549883114581462, 0.033055046005756594, 0.039697453248663805, 0.05748452887928579, 0.03575183254724834, 0.08861048074322753, 0.026855446740228217, 0.03906187426764518, 0.04857559521042276, 0.020601839532901067, 0.026999221154255792, 0.016278703151328955, 0.052142034110147506, 0.06375679367920384, 0.03418815707846079, 0.04371030881884508, 0.03940777816751506, 0.032774877836345695, 0.006169194866743055, 0.0655740535876248, 0.05139801622135565, 0.014522539622703334, 0.03209048409189563, 0.028823995307902806, 0.09277460456360132, 0.013466803939081728, 0.042738689080579206, 0.06796480811317451, 0.043356875830795616, 0.04150238608417567, 0.04763306395034306, 0.06977728859055787, 0.03785174681979697, 0.06493668231996708, 0.03129402604827192, 0.038038140919525176, 0.0444818010146264, 0.00738205202651443, 0.053015519661130384, 0.014628175995312631, 0.019199211965315044, 0.02383429713518126, 0.0150343478526338, 0.08287533419206738, 0.0556607232283568, 0.024981720525829587, 0.06316341692581773, 0.031019949055917095, 0.08176115530659445, 0.007069360162859084, 0.042317609331803396, 0.020369408157421276, 0.018375713771092705, 0.028668930972344242, 0.0334112806012854, 0.003330424342493643, 0.0026472885383554967, 0.04420857934746891, 0.007683938683840097, 0.051494009312591515, 0.040874243422877043, 0.06534923479193822, 0.05895540249184705, 0.025333079211122822, 0.022158958126965445, 0.02951078804471763, 0.05331748841854278, 0.013150817867426667, 0.022419672750402242, 0.042131274603889324, 0.05094860869576223, 0.004252450526109897, 0.05603992358373944, 0.012626621337403776, 0.04683035331254359, 0.04514652042416856, 0.0033735644592525205, 0.03198696191248018, 0.02783338957669912, 0.07566646789200604, 0.0248291405296186, 0.028451574471546337, 0.026623644334904384, 0.05097220157040283, 0.04516363434959203, 0.030500673892674968, 0.018156448095396627, 0.05967221695755143, 0.025291897436545696, 0.03012331962963799, 0.040397944176220335, 0.05499605576915201, 0.06587532843695953, 0.058962601324310526, 0.020079721944057383, 0.05578150776273105, 0.015007679703558097, 0.01811478392482968, 0.0625275744823739, 0.01788323756045429, 0.039869716856628656, 0.03542309823387768, 0.1073610495950561, 0.017578433798917104, 0.05933952328632586, 0.02114404705935158, 0.023880883600213565, 0.018479349128028844, 0.03618742499384098, 0.049428671700297855, 0.058729032607516274, 0.05377272922487464, 0.026510863863222767, 0.012003571664536139, 0.060156523977639154, 0.06712780654197559, 0.012734366337099345, 0.08113867894280702, 0.07901588425738737, 0.04522194489254616, 0.033065558527596295, 0.0537709443597123, 0.02273204085213365, 0.05397580680437386, 0.052914524494553916, 0.042274401494069025, 0.045331712244660594, 0.03351755614858121, 0.05173471749003511, 0.037698263258789666, 0.028017547956551425, 0.05367930767533835, 0.03532658935000654, 0.013461767539411085, 0.047494237805949524, 0.06018649190082215, 0.0725903177226428, 0.056554413749836385, 0.06440953482524492, 0.024522140010958537, 0.05195377721975092, 0.015299393835448427, 0.08022564434213564, 0.050650231933104806, 0.02223564424639335, 0.007172412006184459, 0.029878613131586462, 0.019052083043789025, 0.018908473757619504, 0.03817022836301476, 0.08214460816816427, 0.022364649921655655, 0.03496022072795313, 0.01708179228444351, 0.08788029648712836, 0.06756211136234924, 0.061066541748004965, 0.0288639005884761, 0.060664305128739215, 0.00808681215858087, 0.05106949342007283, 0.030830090981908143, 0.026653382192307618, 0.022439022395701613, 0.018825859733624384, 0.04909765899355989, 0.02356361917918548, 0.04565188217384275, 0.031707413436379284, 0.022077056564739905, 0.02493888376193354, 0.03764834640605841, 0.03827983986411709, 0.04605848262144718, 0.0898408873763401, 0.021513733081519604, 0.035378758620936424, 0.05639989860355854, 0.07557051561889239, 0.025883639609673992, 0.02675286708836211, 0.025783139826671686, 0.047359066738863476, 0.04592359357047826, 0.04711484820290934, 0.054434465200756676, 0.03921458970580716, 0.02948566820123233, 0.0326549653254915, 0.03922165866242722, 0.05535122167202644, 0.031719120815978386, 0.045270147384144366, 0.014040718797332374, 0.0846525032829959, 0.039638318921788596, 0.020234379953762982, 0.022782746236771345, 0.07116959473933093, 0.027072218799730763, 0.04235426771629136, 0.024699268396943808, 0.01839383887272561, 0.017507733100501355, 0.24232502037193626, 0.11737132299458608, 0.09527201313176192, 0.11291957984212786, 0.13581158505985513, 0.12032846236252226, 0.10329592085327022, 0.1003055035835132, 0.1424754923209548, 0.1358770573278889, 0.16697049199137837, 0.11385561359929852, 0.06570384779479355, 0.17825040937168524, 0.08980471509858035, 0.23610530333826318, 0.1487729122163728, 0.20206123794196174, 0.12026168391457759, 0.15612677932949737, 0.16861279058502987, 0.19816929678199813, 0.13627973181428388, 0.16749940579757094, 0.13845404639141634, 0.11770541561418213, 0.09923125966452062, 0.08493506858940236, 0.1912312550120987, 0.14407489477889612, 0.13232594006694853, 0.19879973639035597, 0.1443438045680523, 0.14294905675342306, 0.15742267307359725, 0.23840089968871325, 0.06338266961392947, 0.14290911436546594, 0.10886936826864257, 0.11298998739221133, 0.10535152890952304, 0.13431462866719812, 0.12733732728520408, 0.15661748737329617, 0.13163979485398158, 0.0908389275718946, 0.12968764960533008, 0.17675464041531086, 0.10426246430142783, 0.09566496548359282, 0.11480669068987481, 0.11536788049852476, 0.16332437982782722, 0.10403475855127908, 0.14071206038352102, 0.13710617262404412, 0.2043586748186499, 0.14954551763366908, 0.10823186341440305, 0.1483439953881316, 0.10551777741056867, 0.1414986330200918, 0.13991061510751024, 0.1683026915998198, 0.09025366249261424, 0.14226215454982594, 0.12572854408062994, 0.20459797291550785, 0.15353427937952802, 0.13069974607788026, 0.1438659059931524, 0.142498112982139, 0.14996463811257854, 0.13602070743218064, 0.3037891862913966, 0.11590702109970152, 0.19895818491932005, 0.08903339359676465, 0.09995624888688326, 0.19492528022965416, 0.11590996000450104, 0.13824910973198712, 0.1701884443173185, 0.10163857150473632, 0.20645988784963265, 0.13935529568698257, 0.07558708035503514, 0.14094570331508294, 0.12171877213404514, 0.2420061343582347, 0.14374184858752415, 0.09578019875334576, 0.12288441896089353, 0.1347770163556561, 0.14099153835559264, 0.17334024159936234, 0.13521708024200052, 0.12064939670381136, 0.10575461157714017, 0.12833423941629007, 0.11210461263544858, 0.12301365655730478, 0.11848802518215962, 0.14914143306668848, 0.10412219096906483, 0.1261615872499533, 0.0964207760989666, 0.14182581624481827, 0.13838266662787646, 0.08687095338245854, 0.1471153847523965, 0.12532771012047306, 0.13331989845028147, 0.08351983007742092, 0.16420277097495273, 0.09757976586115547, 0.07306542582227848, 0.15411269443575293, 0.15203757531708106, 0.12566393270390108, 0.17899365542689338, 0.16369886754546314, 0.10478969343239442, 0.08708455090527423, 0.19092143804300576, 0.2066176536027342, 0.18241979501908645, 0.2272056316724047, 0.19851813587592915, 0.14502224628813565, 0.1628692206577398, 0.14766570209758356, 0.14455708296736702, 0.09237570018740371, 0.08540745300706476, 0.10914287937339395, 0.16331663180608302, 0.12821893935324624, 0.12017759858281352, 0.09983479641960002, 0.08949229319114238, 0.17680823832051829, 0.12283695861697197, 0.14553634682670236, 0.15487094671698287, 0.2162087694159709, 0.21850706718396395, 0.1579390000551939, 0.20381165260914713, 0.19431576918577775, 0.22365813609212637, 0.16180140373762697, 0.07716133884969167, 0.24800338520435616, 0.11984880489762872, 0.1389876802568324, 0.16238358890404925, 0.11894559633219615, 0.1349186329753138, 0.10625496754073538, 0.1967562476056628, 0.14649414777522907, 0.09145827949396335, 0.13378445320995525, 0.14835294568911195, 0.14661437569884583, 0.10372209915658459, 0.20614594453945756, 0.15392444125609472, 0.062077818147372454, 0.14301579067250714, 0.12388280796585605, 0.25340804597362876, 0.08956478617619723, 0.08200792683055624, 0.1859531897935085], [0.010430857764731627, 0.014575631939806044, 0.02886055164708523, 0.04110602356377058, 0.027281122238491662, 0.03879198855429422, 0.031392831879202276, 0.04539297653536778, 0.05990776349790394, 0.06019078522513155, 0.07054963425616734, 0.033690194541122764, 0.019687300227815285, 0.034797593907569535, 0.03986369432823267, 0.06418423363356851, 0.04912181590043474, 0.03130572229565587, 0.019606153800850734, 0.03402430942514911, 0.041352991756866686, 0.008557285545975901, 0.02626725945447106, 0.037318691829568706, 0.025316559003840666, 0.051244447313365526, 0.009327429816039512, 0.04541329282801598, 0.06493699402199127, 0.06806471603340469, 0.048517106552026235, 0.045842339532100596, 0.044570676909643225, 0.023825651114748325, 0.014358614971570205, 0.04815727996174246, 0.027307991695124656, 0.03208686983271036, 0.025549482052156236, 0.08251997162005864, 0.008738197957427474, 0.006857601310912287, 0.025288817523687612, 0.07821639825124294, 0.0283770201713196, 0.07080099225277081, 0.008499516770825721, 0.05410655096056871, 0.026830178467207588, 0.04874654892773833, 0.027598420056165196, 0.04145865503232926, 0.0638758712739218, 0.053367412692750804, 0.025785774450923782, 0.04364215739769861, 0.030805672467977274, 0.020635267719626427, 0.014545023914251942, 0.09288914763601497, 0.03928285244910512, 0.03175177160301246, 0.027740691621147562, 0.04002835092251189, 0.009778304938663496, 0.035904210308217444, 0.014493313847196987, 0.029422108818835113, 0.04552240337943658, 0.04907835573249031, 0.09941755357431248, 0.04014561767689884, 0.026988387653545942, 0.027158712400705554, 0.004592984987539239, 0.05107187571411487, 0.010350908978580264, 0.051109524865751155, 0.02774078067886876, 0.059884467482334, 0.02716486109420657, 0.043317352756275795, 0.13074458664050326, 0.04557654676318634, 0.01710846507194219, 0.019676424053614028, 0.04097056676982902, 0.14020094327861443, 0.01907546626171097, 0.054208952496992424, 0.04649072798201814, 0.1177166443085298, 0.01882110627775546, 0.048150136790354736, 0.04069853624969255, 0.03498439247778151, 0.04642098465410527, 0.00538959238838288, 0.04680280850152485, 0.024572719230491202, 0.1012758765136823, 0.06143985687231179, 0.017991644926951267, 0.06913636243552901, 0.06147294923721347, 0.029661881890206132, 0.016190511887543835, 0.039204040076583624, 0.07287555476068519, 0.02162464148568688, 0.01114684473577654, 0.05719040833355393, 0.05066765756055247, 0.03974921062763315, 0.06618332714424469, 0.07526540386606939, 0.03403864771826193, 0.04457565300981514, 0.037158202394493856, 0.018857697868952528, 0.007840512826078339, 0.029800995616824366, 0.03728764408151619, 0.03000898806931218, 0.016707790673535783, 0.0023669169740969664, 0.030135351698845625, 0.00832993138828897, 0.03439155378146097, 0.021437904142658226, 0.030450903614109848, 0.038988101077848114, 0.05317033537721727, 0.044524693439598195, 0.06297347907093354, 0.05322387019987218, 0.008313507660204777, 0.07732627374934964, 0.06575668128789403, 0.01475802215281874, 0.024261531143565662, 0.052651830192189664, 0.035018594353459775, 0.03038723847566871, 0.06398639190592803, 0.0745064317015931, 0.040339232873520814, 0.00696540521857969, 0.021753138789790682, 0.03624639975896571, 0.08764061989495531, 0.0435731970355846, 0.11256956073339097, 0.05137729174748529, 0.03516588098136708, 0.08999401470646262, 0.02384199877269566, 0.06868094351375476, 0.0729643230442889, 0.0353815082780784, 0.030624208084191196, 0.004213352331134956, 0.020264347876945976, 0.050378817395539954, 0.03512925970426295, 0.03204592183465138, 0.03305778081994504, 0.07254767391714267, 0.024749342956056353, 0.015273484532372095, 0.029624429407704156, 0.06007427546137478, 0.027111732597404625, 0.022175847552716732, 0.013297775167302461, 0.08830076025333256, 0.022201811589184217, 0.026973186613759026, 0.04437475363374688, 0.030541671985702123, 0.014266800171753857, 0.09598895005183294, 0.029491599816537928, 0.03203427382686641, 0.03489671515126247, 0.039002858684398234, 0.0423433915420901, 0.04238199435349088, 0.01841130531829549, 0.030984387194621377, 0.011949920881306753, 0.02093418996082619, 0.05418262480816338, 0.01427926639735233, 0.02290247877681395, 0.01791966031305492, 0.009054761976585723, 0.027003432842320763, 0.01566268903843593, 0.009024343198689166, 0.01634668944461737, 0.020528461536741816, 0.049633641756372526, 0.009136840726569062, 0.08188615523977205, 0.025268391764257103, 0.04528405894234311, 0.05195618919970002, 0.027292083759675734, 0.014171485217957525, 0.042546973782009445, 0.03643211479356978, 0.07304775528609753, 0.0038712612149538472, 0.05531706061447039, 0.01516166606961633, 0.01311354721110547, 0.0564831675728783, 0.013965683956485009, 0.02712158460781211, 0.04862056935962755, 0.04429969652846921, 0.03908725942892488, 0.032386263337684795, 0.028868385015812237, 0.021737262395618018, 0.057933535645133816, 0.030830228279228322, 0.03482095300569199, 0.03725051814399194, 0.027452834801806603, 0.016288265724142548, 0.03198765582055785, 0.0054495031872647814, 0.031077994281076826, 0.03085214575548889, 0.03327567537780851, 0.03875510381476488, 0.028459303939598612, 0.02636907283886103, 0.03678452361782547, 0.07804230524925515, 0.016750874201534316, 0.020715529135486577, 0.05265109917672817, 0.06391603630618192, 0.07322394114453346, 0.02823029200953897, 0.04650121081795078, 0.0536105773790041, 0.06362360785715282, 0.020776129204023164, 0.029049537697574124, 0.049745850774343126, 0.02273207610414829, 0.024014405244088266, 0.02843450136424508, 0.024716996449569706, 0.10913147998508066, 0.04809673184354324, 0.016250703774858266, 0.034146619072998874, 0.05329811465344392, 0.06308193653239869, 0.0406024726544274, 0.05574968075961806, 0.009539002203382552, 0.023344923101831228, 0.05903550249058753, 0.020399635832291096, 0.016652307713229675, 0.010835020257218275, 0.04729815867904108, 0.03768965063500218, 0.01618106063688174, 0.054786940818303265, 0.014408002116397256, 0.01731816075334791, 0.021379161298682448, 0.06719860743032768, 0.051452846091706306, 0.02059337348327972, 0.04097702716535423, 0.08614073944045231, 0.02262279300339287, 0.01242780275788391, 0.01967074476851849, 0.05052838983829133, 0.027936412661802024, 0.027689501985150855, 0.0635737281118054, 0.07872529633459635, 0.014382563149410998, 0.004889799065495026, 0.025910735421348363, 0.06019969099725131, 0.018902586671174504, 0.03889770378009416, 0.042497123722569086, 0.034319903134019114, 0.056741238295217045, 0.03514875963446684, 0.03692353158839978, 0.05082106319605373, 0.011236277241550852, 0.03485526249278337, 0.005909437149966834, 0.03337957234180067, 0.025398234211024828, 0.059153166293981485, 0.04979919634934049, 0.025690618131193332, 0.020796313765458763, 0.02322320160601521, 0.029689918374060653, 0.04298829931940418, 0.019588115901569836, 0.11008817513356917, 0.0562923910911195, 0.01747029175021453, 0.02074612788419472, 0.01017498101646197, 0.07086683559464291, 0.041880176358972676, 0.033351626771036536, 0.015301918992918218, 0.028618086435017176, 0.0473625808081124, 0.08208704719436355, 0.007012303385636187, 0.04135428309382405, 0.023362137217191048, 0.04084214924660046, 0.009215348818543134, 0.039712637590128, 0.010360427022533258, 0.022655321336060297, 0.014984125791670522, 0.026202119297522586, 0.015486632128158817, 0.03281092023826204, 0.044944808396394365, 0.02460342559061246, 0.05334274370397907, 0.025464125792495906, 0.003244164749958145, 0.053161240357439965, 0.021638612415699754, 0.035261981684016064, 0.032587856621830724, 0.017707775296003092, 0.03505941618641373, 0.16824795078719035, 0.06536850094562396, 0.088444165448891, 0.13456206070259213, 0.07468758994946256, 0.16394083737395704, 0.09014333481900394, 0.21273770020343363, 0.10812172869918868, 0.11746466290787794, 0.14505930914310738, 0.12176313030067831, 0.18176715035224333, 0.12684173590969294, 0.1162386497890111, 0.17851464363047853, 0.13080069300485775, 0.08964186563389376, 0.11618022050242871, 0.14119672734523192, 0.1096702272479888, 0.27576708525884897, 0.10360567102907225, 0.1821282645687461, 0.09592404181603342, 0.20559099619276822, 0.0839567398361396, 0.07578514472697861, 0.15359685727162287, 0.14966501825256273, 0.1791616331320256, 0.1520007202634588, 0.13549269904615358, 0.0979828262643423, 0.11179881810676306, 0.12315375919570215, 0.1875458683934994, 0.12133517826441675, 0.16383992013288662, 0.07268565401318483, 0.14673038822365925, 0.0748396931157913, 0.12457514269044623, 0.14802884979872033, 0.12013084327918477, 0.1938628513016738, 0.13630374771310017, 0.1262156749726273, 0.11485003953566775, 0.14338284207042307, 0.17537273175548762, 0.15912771283183247, 0.14859953167615458, 0.1392015820601955, 0.07963712865603156, 0.13108606362948194, 0.1216719500371255, 0.13042449834756553, 0.1566129454295151, 0.204486264847219, 0.08402903244132176, 0.14702991902595386, 0.11378996321582235, 0.11242317952564918, 0.12273345128051005, 0.18078154855174944, 0.1359566007158719, 0.0578082499851007, 0.09584637606167234, 0.09324530430603772, 0.24436726234853268, 0.1151295546151232, 0.12466222629882395, 0.12195830771815963, 0.15069281856995076, 0.10348179173888639, 0.13348372012842447, 0.14950314100133255, 0.0842603895580396, 0.19731268024770543, 0.11773668229579926, 0.14029357815161347, 0.393715487443842, 0.11652196466457099, 0.15768194978591055, 0.10794339803396724, 0.08735101160709746, 0.2583382517332211, 0.12147335131885484, 0.19958852062700316, 0.09170837583951652, 0.17179945396492258, 0.14970571763115004, 0.15295999066438526, 0.1472164355800487, 0.13794414640869945, 0.10784914527903311, 0.09205841721268371, 0.21055133314803243, 0.13701177143957466, 0.18406050541670993, 0.17588931106729433, 0.08974336917162873, 0.145535055489745, 0.1126504028798081, 0.16381721041398123, 0.16116989543661475, 0.20211983792250976, 0.16437598824268207, 0.1531976560363546, 0.08098848309600726, 0.2533940935973078, 0.13976120593724772, 0.19189203361747786, 0.0962372800859157, 0.2770648937439546, 0.22064390330342576, 0.10108825415954925, 0.19004568894160911, 0.1291796495206654, 0.08463344493065961, 0.20479617087403312, 0.16636326676234603, 0.11009513647877611, 0.16108953568618745, 0.07678160414798185, 0.15922720514936373, 0.13699986739084125, 0.11721035116352141, 0.10081760774482973, 0.10279903814080171, 0.14602714392822236, 0.17307983682258055, 0.16106479248264804, 0.15168450598139316, 0.16282313328702003, 0.08254574640886858, 0.12519164476543665, 0.26355495618190616, 0.13965191727038473, 0.1099939520645421, 0.17398574680555612, 0.11831915689981543, 0.20692341844551265, 0.14773636939935386, 0.14550937718013301, 0.13455075037200004, 0.14469994639512151, 0.16070240177214146, 0.11362689110683277, 0.1617919487762265, 0.13688177685253322, 0.31141980027314276, 0.1371889517758973, 0.115316390292719, 0.25469240674283355, 0.17169294093037024, 0.1723133318591863, 0.2017837786115706, 0.1198507790104486, 0.2073777760961093, 0.12769155437126756, 0.10279770969646052, 0.15726826182799414, 0.13478589244186878, 0.0978658118401654, 0.11084215264418162, 0.10374519479228184, 0.10414461125037633, 0.07127668664907105, 0.12810889369575307, 0.14259468123782426, 0.1497471146285534, 0.08763846024521627, 0.09648641163948923, 0.20308203238528222], [0.02511561138817342, 0.01353416868369095, 0.012744915038638283, 0.016744987115089316, 0.05182276960113086, 0.06551181708346121, 0.033768094072001986, 0.03338884918775875, 0.03811055968981236, 0.08136967982864007, 0.06353343691444024, 0.048164823892875575, 0.05687603828846477, 0.06779581366572529, 0.0367593091505114, 0.005505232447831077, 0.014849087383481674, 0.020562650424835738, 0.049532642879057676, 0.0033116459189841407, 0.01514962194050895, 0.02012943099543918, 0.020119675464229658, 0.025210272324329708, 0.0315834933280712, 0.10196221468504518, 0.0082161666432512, 0.005519978458323749, 0.01320087758358568, 0.08084216868155636, 0.04989663662854582, 0.0321492733201012, 0.046785004378762096, 0.015069231576489983, 0.03600476018618792, 0.08483748359140009, 0.00919467629501014, 0.02595540714537492, 0.05952721243374981, 0.057712145571713336, 0.0431566295446828, 0.03602592623792589, 0.03221237442630809, 0.010411009952804307, 0.03851835128443781, 0.024298349089804105, 0.04279705528460909, 0.03822752587439027, 0.028695796718238853, 0.0447940819140058, 0.038098536897450686, 0.021101666716276668, 0.0755749833479058, 0.015799314714968204, 0.0776041486824397, 0.0240797977312468, 0.06616061000386253, 0.02707213716348633, 0.03309363397420384, 0.03235945325286593, 0.023432259040419012, 0.03847118408884853, 0.029600057278003078, 0.04581661298288964, 0.030059739838179667, 0.023618580780748744, 0.01826322088163579, 0.013832310742145637, 0.022632413092651404, 0.028717510103888344, 0.03041590578504838, 0.008584958377468865, 0.08373623291845433, 0.038051521842135116, 0.037158751583774574, 0.034871589741669595, 0.027923688539885916, 0.047191118719638325, 0.027452960966911633, 0.017975096889131237, 0.02084536787151592, 0.05370092643715907, 0.01893096268759109, 0.012591553004313027, 0.0233059325182694, 0.049437358538853005, 0.02864930673240451, 0.035344861025805585, 0.0213112046913011, 0.034944680155604146, 0.014327835324365878, 0.031291395134758204, 0.03293336718343198, 0.05875016526260879, 0.021254178063827567, 0.029860200447728857, 0.026934980851365253, 0.05819095327751711, 0.05419271801656578, 0.04200784060230944, 0.034218388464068994, 0.024196199883590452, 0.07321611148654483, 0.03305525751784444, 0.015817777493793983, 0.06646759196883067, 0.055204176242114045, 0.03665746422484517, 0.043198416169616394, 0.04286195238819346, 0.015046223143144744, 0.05912840453675017, 0.021381233746069483, 0.07762731111142784, 0.02257072392239934, 0.012288733560126275, 0.039012684719637036, 0.04706518739112653, 0.01948176428413717, 0.012062062178301858, 0.04982874866982456, 0.04395321746414993, 0.04941199193126522, 0.06366850037011318, 0.012747121072607115, 0.03635839726484846, 0.040168921113945544, 0.04766495403600857, 0.01542574447739753, 0.04711585752374958, 0.026255628145008814, 0.0483820430963533, 0.14587963465601206, 0.087478460627608, 0.03458536564721726, 0.025724942461238243, 0.03596405338612385, 0.043236941055511124, 0.043069442035630345, 0.05036457929236349, 0.004087521192559507, 0.03789613467233721, 0.04422269128554035, 0.030673232504341286, 0.004640383640435175, 0.06778451817808673, 0.01685865816398291, 0.05111748439958319, 0.025617522151151206, 0.04430185988894664, 0.05418020169599913, 0.04112364586035255, 0.07101174734998494, 0.07090648854500614, 0.01671522513788659, 0.039620080642635, 0.011014987358066719, 0.06766691745724529, 0.0442667006427655, 0.022764019995520357, 0.0273983685838175, 0.014967820807214594, 0.01947178054251708, 0.038938662910368294, 0.017957925447262824, 0.028055384500476066, 0.05556758740567602, 0.00866232170665171, 0.022634847337030806, 0.00950973097133101, 0.030264158849604428, 0.034283181666978635, 0.03663513300125487, 0.033142849497380666, 0.05325996826286428, 0.02773874904960394, 0.05033895664382726, 0.03177028818754479, 0.02585175694548525, 0.03915708439308219, 0.054104914524941705, 0.04339692954090424, 0.03665987620479427, 0.027161168909515254, 0.0945723385666497, 0.0236403461167356, 0.020906784302496817, 0.04965114902006462, 0.04052277341543231, 0.08299358800286427, 0.09685837605502456, 0.06206909049069509, 0.009149200268439017, 0.016779203833721112, 0.042618765437509865, 0.01876294416433666, 0.05610470565443393, 0.021169335741433315, 0.029172470749472268, 0.0149160086948541, 0.005366936475184048, 0.040178813942475244, 0.02881226009776583, 0.010577411521808244, 0.1263297875993885, 0.04313043915317394, 0.032372218192904256, 0.05086274220957421, 0.01831143265007995, 0.06446676925406791, 0.03269529734097887, 0.015370838536910014, 0.043545915686991066, 0.04615905476384796, 0.030382700242626015, 0.030861674931657035, 0.05034119421907235, 0.026400536189612467, 0.05430065226391889, 0.01767379420925863, 0.05510491399036255, 0.01600862633495126, 0.0651144860603381, 0.027335638551448938, 0.029460394362104125, 0.018274130452482495, 0.04894646866887342, 0.01724003301205812, 0.03191928546584677, 0.044911586155649275, 0.051160499278921634, 0.033638440872891806, 0.02776703786366852, 0.014602480059693335, 0.033610484169912525, 0.007784435219946317, 0.035608230682555586, 0.02493669442628743, 0.0265090641551069, 0.011164002262376016, 0.03806170410825871, 0.0542489505460253, 0.01945106534549268, 0.005406529589890852, 0.03256980387959629, 0.036507780459942296, 0.034076423035003245, 0.015975751048245, 0.03348235237353947, 0.029186228312028106, 0.033570423038327135, 0.041393661449546926, 0.05665651842718944, 0.026540904145804234, 0.014326621912914561, 0.04002914130978752, 0.012117221376684029, 0.018786358923534863, 0.10076512306113727, 0.03755931837076787, 0.05654527420119848, 0.04724744772829581, 0.0026195832379016792, 0.04644797656510491, 0.03374491680006031, 0.024686147226020694, 0.036046454042661935, 0.06861984249553643, 0.06246674805879593, 0.05547704909986351, 0.03398335029487498, 0.022416988031181972, 0.037323623400880024, 0.06406618020264432, 0.010437450819154037, 0.021868728290428407, 0.012909708002553089, 0.013949491221865173, 0.060948673853999935, 0.021850883349543437, 0.036720368661917746, 0.10274538086378016, 0.010626800522004487, 0.04372411276563071, 0.06434811468352564, 0.04068709233251866, 0.0464824604569003, 0.03009962285432266, 0.04651170478609856, 0.07804891778505407, 0.011353544923622394, 0.02233593251730781, 0.047067777486518025, 0.0682106964814011, 0.0097449732311361, 0.044382074920577, 0.015836830280022696, 0.03982393376645632, 0.021157116279937327, 0.025983256236941088, 0.0019424293759584543, 0.035635597378131934, 0.017400897231709678, 0.08650608389871195, 0.039038366739987396, 0.08550176513381302, 0.055820058623794466, 0.017987772771448363, 0.0641239267133642, 0.028501467204478104, 0.025525148885208182, 0.05561198639043141, 0.04782993346452713, 0.04597576284140814, 0.062233980861492455, 0.06673047551885247, 0.001575408707594761, 0.01227082553668879, 0.026266851273248903, 0.056040391136775725, 0.014434708300541388, 0.04102628350665327, 0.021697188276448287, 0.04025948539492674, 0.036110464279772714, 0.04718412026704755, 0.04072110496053938, 0.02940511920314748, 0.04112117079785094, 0.0999842798046302, 0.05271900568914134, 0.0036077737422601786, 0.0427501552621834, 0.06578178072231822, 0.024246717875939794, 0.03583645593607798, 0.009052109726326307, 0.02629521430208115, 0.014192718990670983, 0.047646199964219704, 0.07847953413147479, 0.02353172909351997, 0.0457021775218891, 0.01983504513191292, 0.047213954603648745, 0.09128872101427987, 0.07530185815994628, 0.05688115539669525, 0.04617212027369533, 0.015728866346762516, 0.05504231754457578, 0.018359839232289232, 0.12092636621673591, 0.07480494576157071, 0.15038104233099148, 0.08952525939093903, 0.1765761835849844, 0.19837171013932675, 0.27015983301680535, 0.08567885641241446, 0.19218154542613775, 0.24964120122604072, 0.06387198984157294, 0.12389381401590072, 0.18630870821652934, 0.18422434193780646, 0.11353869427694008, 0.11503153917146847, 0.15562741784378886, 0.11989519654889591, 0.1211374181730207, 0.09173254016786814, 0.10499286378035322, 0.13545948051614687, 0.15311722207115963, 0.08012727266759612, 0.15211996855214238, 0.1251737293205224, 0.09436027728952467, 0.14109591400483623, 0.17707934486679733, 0.12446323424228467, 0.10563523712335154, 0.1630211531301029, 0.15813197329407558, 0.11398073969758116, 0.11341259596520104, 0.1436786472913809, 0.11634021269856021, 0.0950609685969539, 0.15310375951230526, 0.1461046835174784, 0.2352320626960136, 0.10123606771230698, 0.10309790101018734, 0.12807837658328936, 0.18617682857438922, 0.08314281163620763, 0.18012039887253195, 0.19675822171848267, 0.08527224854333326, 0.19299142149975523, 0.1138575654476881, 0.09141864880803041, 0.18078298831824213, 0.13338290678802878, 0.20048656384460628, 0.09420605158084072, 0.19922182545997202, 0.11836313657113351, 0.15138357994146645, 0.1016392617020756, 0.08197676404961385, 0.11654379122774117, 0.10504331497941166, 0.09648616673075594, 0.14801877143327147, 0.15747230791021138, 0.17032921488862485, 0.10284876945661381, 0.19370107795111835, 0.09277542092604563, 0.09330736269475892, 0.14402414672076702, 0.14808074076427147, 0.1102196317515336, 0.1166118610126432, 0.09257620622520335, 0.13971155625768006, 0.09877440839773044, 0.08140578531310894, 0.1513051794609055, 0.11660457312245853, 0.21932417177595198, 0.16296379995765164, 0.09243258580681868, 0.18030480772722512, 0.14816445502219722, 0.12220956181408837, 0.12216150033054873, 0.15084862505318597, 0.12846790021285415, 0.10517002927372232, 0.14714253251440823, 0.27048590302001685, 0.1596747647272423, 0.13147717545507476, 0.10982607826008461, 0.20456007885513827, 0.13187282922444865, 0.07211789619759656, 0.15474380197701976, 0.13165833370294422, 0.11774368074839003, 0.17082398990169168, 0.16474112489959225, 0.07171003409894183, 0.22393636725610122, 0.1622785156359896, 0.10236796166282147, 0.15292019670596346, 0.1078371076437179, 0.1140571066935081, 0.10474785856786184, 0.12181168160168454, 0.134872070630081, 0.2230671638972126, 0.08091561903711408, 0.15666593477362767, 0.1532921611214988, 0.12252410626388155, 0.12238761046319269, 0.08847426695865579, 0.17398589523509145, 0.131349511211738, 0.11903190810699016, 0.09997504748753272, 0.14968529372708872, 0.14268908242229372, 0.17390666354913265, 0.08709105954039842, 0.16871588974026963, 0.1353625560295768, 0.14434917771723121, 0.3284369199536741, 0.22607980848988518, 0.1751069983583875, 0.14869687176542357, 0.15839942847378552, 0.09740216992213391, 0.1193243736634031, 0.1774052219116129, 0.10189754393650219, 0.0800287228776142, 0.20181125291856006, 0.19078561017522588, 0.08474829970509745, 0.15274788485839963, 0.07332820547162555, 0.10343510322854854, 0.14575388515368104, 0.12985141191165894, 0.15695716836489737, 0.17088742868509144, 0.20330694766016677, 0.18726119538769126, 0.1272069467813708, 0.1521316499565728, 0.08484662685077637, 0.19869549432769418, 0.09378627801197581, 0.08619278625701554, 0.13916597381467, 0.08428925910266116, 0.08420480269705877, 0.252800167654641, 0.19212542421882972, 0.07120626425603405, 0.13207933923695236, 0.0653349187632557, 0.12214504691655748, 0.17702936864225194, 0.13803793903207406, 0.21439653384732082, 0.15166805998887867, 0.06785815407056361, 0.1268850773340091, 0.05851386915310286], [0.041618149989517406, 0.03523655941535253, 0.03419299959205091, 0.04691834234108683, 0.027182134581380524, 0.04756284564791713, 0.02571150216681417, 0.05002281286579091, 0.024974410371214617, 0.0945599224360194, 0.047586835571564734, 0.037385800533229485, 0.0277123323030537, 0.05217875928792637, 0.03813425646512769, 0.02419391406874638, 0.0288068220106652, 0.027749107575800736, 0.04787229896464851, 0.03183678461937234, 0.06668800240731798, 0.07736145897069946, 0.00724543609067041, 0.08205035541323014, 0.015553796492895344, 0.004752911781906732, 0.0780407022102736, 0.004346265413914807, 0.016716835598344915, 0.041657294568722136, 0.056219942634925246, 0.021754749250249006, 0.08604710266808979, 0.02944684645626694, 0.057143831145367585, 0.06126382315414958, 0.055311130854533985, 0.04591674354742281, 0.02015243942878442, 0.04331112984800711, 0.08465381688438356, 0.012346174862614134, 0.02136203067493625, 0.05081301089376211, 0.050620716720004566, 0.03073584935918916, 0.04759835370350629, 0.06380464736139402, 0.0574692109512398, 0.041631382482592016, 0.07569515189970843, 0.03284524085756857, 0.017436319940316025, 0.03685919851704966, 0.09228698385413736, 0.03741318949323613, 0.04057673126226291, 0.03953046631067991, 0.0340475943085039, 0.12821478332625702, 0.09090777661185712, 0.009384941622556653, 0.09894327668007463, 0.055162679054774344, 0.05027725448599085, 0.05143818867509253, 0.02137682167813182, 0.04307554991100915, 0.008470514567306964, 0.11648453073576093, 0.052493786133709364, 0.022529798188770656, 0.06690784881357104, 0.015216129504551645, 0.05149559750861954, 0.013481841706379782, 0.04823664152354468, 0.04791006685991306, 0.028995542743359692, 0.021206539604463615, 0.008454843191429973, 0.012346465227892622, 0.04616917023668066, 0.0709912418096792, 0.020302733610151336, 0.007538038480561227, 0.04751463944558054, 0.024948197715275455, 0.06107379995228257, 0.07760902459267527, 0.03863827121676877, 0.059416328149382025, 0.017818602063925937, 0.05438779524411075, 0.03660723567008972, 0.04738310490211006, 0.03386845099157654, 0.03542810401995666, 0.029457470300258137, 0.017905494569276925, 0.05013960835640319, 0.06251535131013952, 0.0266016860405216, 0.044516121633932926, 0.04115732452191878, 0.04041764448629692, 0.03383739211130887, 0.028873442752228584, 0.06302123627392575, 0.042061846688739024, 0.0727686780737713, 0.039839363016653806, 0.028734232546412386, 0.05046731108450331, 0.07661175623070449, 0.06184578567626886, 0.01897856218420202, 0.01071813385351561, 0.04584483685903251, 0.021210335689829662, 0.15666452469304204, 0.06646446010563523, 0.007960625716805225, 0.04782816715305671, 0.042413799092173576, 0.06504157747258432, 0.012350941306067398, 0.06535043707117438, 0.025266211705456953, 0.04588256764691323, 0.025955232740670908, 0.041985294155892916, 0.03878219591570087, 0.020210683178447653, 0.012673827495746082, 0.03294836598797701, 0.028400995252013672, 0.038071912349550985, 0.017448726794100367, 0.032548749150009826, 0.05177700877538882, 0.06434424067265354, 0.030413573585974518, 0.0211214894807199, 0.0775173248257488, 0.024288433996844105, 0.04966677493939642, 0.020294597816246096, 0.05262003658572212, 0.0900591530080419, 0.07869211491197348, 0.05981272035569418, 0.020327740276115946, 0.009003062114061322, 0.07615048176376149, 0.02852481517038541, 0.02139921227353625, 0.07268423651112244, 0.02414720700471662, 0.09948319653631188, 0.16974282916635275, 0.0651070497406181, 0.0447090948728146, 0.054870072490302846, 0.017325689841527492, 0.03319097035273444, 0.04265356474206783, 0.024566102983953897, 0.004187649437881191, 0.05792923861008603, 0.038908839705982246, 0.06546100965351798, 0.04426990300999023, 0.015133139768295223, 0.021579344502242748, 0.03002366589498706, 0.017055310599971563, 0.04822451483050827, 0.011316632353555178, 0.07947214180603623, 0.0645130273187533, 0.08260229806182906, 0.022822523496870417, 0.04224546886689495, 0.026012849375547376, 0.046456166164716706, 0.09041401091963053, 0.019232001905038487, 0.03826671127171721, 0.012864488016930409, 0.04747243721794803, 0.00790551383033744, 0.015262111119227484, 0.045188199437689036, 0.04050852789077908, 0.02946499011159176, 0.031086161616258323, 0.09333767942734994, 0.027592186015681364, 0.0883004856586922, 0.07270979607710615, 0.0390426600642968, 0.09658103546826169, 0.06814908338128589, 0.015427405032824026, 0.05993770915665664, 0.04337510297773406, 0.03282012286945246, 0.039923570802784525, 0.013412911957857432, 0.024354088091058657, 0.00043339615331206005, 0.036113321548327804, 0.04567133386444766, 0.03558696073014289, 0.03821458652964793, 0.061275389525690116, 0.017461001916672103, 0.0408814682305092, 0.04282125300960615, 0.029750750363746192, 0.028482353191066068, 0.0003918251570667053, 0.155029424931854, 0.0323160376137821, 0.023827404438634403, 0.03321067808428779, 0.07348794533754699, 0.04442644050868694, 0.0345442358229775, 0.0523009872995317, 0.06573973805643618, 0.03302960889413953, 0.03515303811582271, 0.03588158964703325, 0.08137389522744343, 0.013962733919470338, 0.040052582044154406, 0.029925509443273768, 0.027157450749655254, 0.03664008683699649, 0.036793021208723076, 0.02159362342354143, 0.04747076738567557, 0.0028611843117687386, 0.04185719575616531, 0.02919788003055146, 0.08022159221582115, 0.02428965482977219, 0.01329745882685529, 0.056696401443332434, 0.008217130507546244, 0.03270973211328965, 0.009473492827964947, 0.05949039077677298, 0.04516458429861814, 0.04381257305794861, 0.04277267573343124, 0.06537091292557307, 0.03600017742428463, 0.029900439694756642, 0.017574726771272253, 0.05034000307205133, 0.01869965752121061, 0.017771631537470967, 0.03993949729192536, 0.0670085805177223, 0.0442690903582843, 0.024836259581206832, 0.02869485047995113, 0.02158431503630709, 0.02778100508294301, 0.022152844685479067, 0.07080748604494147, 0.08828133082715794, 0.02152822351490613, 0.06806758814491332, 0.03400332519959193, 0.05521936429431662, 0.06302870227955282, 0.06246150107472204, 0.055132785346359015, 0.008607783129264135, 0.037103702779859304, 0.07040157579467632, 0.02856715098459972, 0.03330929837829899, 0.027320773333485704, 0.044417430835892446, 0.029089392883179244, 0.025285667106800247, 0.04584075875754934, 0.04487778132897802, 0.01583304903761018, 0.008844553285598522, 0.028409973383531906, 0.06700169338728301, 0.0357972779602278, 0.019631644718174357, 0.06891336932312697, 0.03313391403935384, 0.06749633481376804, 0.042743449957924895, 0.07853816379792988, 0.02672921669727657, 0.06317031147773378, 0.03822862054221332, 0.03618358437961433, 0.0203096021868987, 0.013845774228684604, 0.01574217305460479, 0.008698925357748521, 0.04054807694046758, 0.052353932114783674, 0.011369000148988562, 0.05019926218665205, 0.05331812295480631, 0.05943345320702065, 0.017936041367647704, 0.0595424635685049, 0.042974732859875076, 0.06116554053733125, 0.031187605782179162, 0.06361881358316168, 0.04242065653670579, 0.01100900472010835, 0.02172826942114625, 0.02709545358811738, 0.024197559869207907, 0.046376993850572035, 0.04192602253169753, 0.03597349721530918, 0.029399000195553526, 0.05437160900328308, 0.07809376576915383, 0.033205586951225996, 0.054108335825731046, 0.014155119934002869, 0.04735802773211617, 0.12198384501971304, 0.04335319848905783, 0.03911762440111488, 0.027662066640914418, 0.024246764260169584, 0.04774400018504821, 0.06635535697569139, 0.059180651733186096, 0.06532248778967187, 0.03165316615195479, 0.01876200349215651, 0.03756592719582841, 0.09221699190675281, 0.15531472134171054, 0.1464707255945541, 0.06944124412257224, 0.210698738519568, 0.11073894958826713, 0.2612309355754405, 0.1594678094261326, 0.13597159209894016, 0.09090042934985831, 0.16019199712900445, 0.14912853454006836, 0.0738806527806446, 0.11045151579310186, 0.14442873594816774, 0.0895500100159552, 0.05986779884551652, 0.08352493605343625, 0.13254221674287692, 0.2528357016853988, 0.12090784963220358, 0.2002182329306379, 0.15343851264333352, 0.11431073566200212, 0.15000925603089854, 0.1918460353044793, 0.06811196115450002, 0.15490938996663317, 0.20036896312376484, 0.15976731054252014, 0.2612127974862233, 0.14407427137484774, 0.1124889931816142, 0.28920800308696926, 0.05556537209486123, 0.15926489140838385, 0.13393871602602303, 0.13104637357173488, 0.11748645978514105, 0.09603192782378756, 0.16185155807761475, 0.17397617310052738, 0.11755960586015135, 0.18248842883622274, 0.105744733591564, 0.12545673991553485, 0.06174831942189485, 0.16175966535229236, 0.2830415277276188, 0.14920453046215698, 0.13634493690915406, 0.1486662359093316, 0.1756602991372347, 0.20443698624148965, 0.12197856092825532, 0.18576018686871976, 0.2612768596736714, 0.13106759899528697, 0.09090618099435233, 0.10164613398956135, 0.24906879756599665, 0.22399980603950098, 0.13460200309054926, 0.13334576971828938, 0.12044750284985639, 0.11543761269422248, 0.17690682521788403, 0.14370358345331624, 0.15228702599415556, 0.10765288432594389, 0.24720198445720598, 0.09561383150867186, 0.16399793821619824, 0.16094634571345523, 0.12617457483429462, 0.10651134987710975, 0.09742290552821942, 0.12092480028513819, 0.2174317991011776, 0.09649836021708325, 0.11419327594921924, 0.1254713602247648, 0.17290032614255324, 0.1002088536915835, 0.10755416384199634, 0.17390942433848977, 0.17351632355712354, 0.17661677906289697, 0.10460466859512962, 0.1413956526084803, 0.17454854707466438, 0.15605596359819174, 0.1857558824121952, 0.057006225833902135, 0.1113859836186748, 0.10207154045929201, 0.07947280973894522, 0.11553506410564296, 0.18254741473356262, 0.20342438510851935, 0.0980088533833623, 0.16761626437073573, 0.13469282712321728, 0.13870515947928652, 0.18537409196142107, 0.1422791348886676, 0.18917218112619594, 0.14112764823948964, 0.0885001159622334, 0.1103560310730245, 0.16627833538223058, 0.1960133874672465, 0.17241010791622102, 0.17647160013439134, 0.14183289633365348, 0.14187237859005108, 0.1487487627309747, 0.1287911500548944, 0.1559744164114818, 0.10066928953165188, 0.07715516418102197, 0.21731654356699437, 0.28173157770652324, 0.09260210717911832, 0.10802786928252317, 0.097926586313406, 0.14947370742447674, 0.15104023274034262, 0.2410522519494407, 0.08034388330997899, 0.1484226481989026, 0.11564885018742643, 0.13772705337032676, 0.22346882906276733, 0.11363748897565529, 0.13707584846997634, 0.0823204377957154, 0.09272213472286239, 0.1653315033763647, 0.1756351106450893, 0.23060468287440017, 0.16809166932944208, 0.10143288527615368, 0.10585342111880891, 0.14310833648778498, 0.13198251865105703, 0.11599254619795829, 0.1582513254834339, 0.1382846140768379, 0.15863753913436085, 0.13022542465478182, 0.15631203423254192, 0.19476407091133296, 0.11295911404886283, 0.070443121221615, 0.18178653524955735, 0.07083939839503728, 0.09885027073323727, 0.15907650464214385, 0.1132801448693499, 0.21556390245677903, 0.2311065825051628, 0.11944270911044441, 0.11791153970989399, 0.16626380413072184, 0.1093458641844336, 0.1074303884524852, 0.15615570824593306, 0.15907694993074983, 0.1713553527952172, 0.15493502374738455, 0.13309152476722375, 0.11657433060463518, 0.11519313440658152, 0.0581671192048816, 0.0893264751357492, 0.1335705365636386], [0.016534512178623118, 0.06640201580012217, 0.07518837635871023, 0.01627942117920611, 0.06731145098456182, 0.055185770979733206, 0.030961389893491287, 0.01897282723803073, 0.0494121292285854, 0.017956461560970638, 0.035070544690825045, 0.08922881592297927, 0.031222149045788683, 0.016353051505575422, 0.06961393446545117, 0.030024729021533858, 0.04615793041011784, 0.05111819686135277, 0.04726846906123683, 0.010295211723132525, 0.056058878035400994, 0.03106528314674506, 0.006738994052284397, 0.08812611064058729, 0.038618147882516496, 0.026105827491846867, 0.023869439683039673, 0.04149846383370459, 0.04050556672154926, 0.047092416789382696, 0.02458069175190758, 0.06785206103813834, 0.007277783060999354, 0.0582291998580331, 0.06407312670489773, 0.027499601237650495, 0.015441893610841362, 0.03570658380340319, 0.05832485527207609, 0.04530278703896329, 0.03904308679921087, 0.04902543318166863, 0.03773745978833176, 0.0320092003676109, 0.04593633995682467, 0.022582700330531225, 0.03970185418438632, 0.043205878464505076, 0.029489356675185263, 0.01764642194757471, 0.01580914446094539, 0.08126522254315205, 0.061534373089671135, 0.06284163653617725, 0.025414320261916146, 0.029940708627691492, 0.015201672467810567, 0.0488327382481657, 0.037219310834188946, 0.022419845299737062, 0.019419995333009865, 0.0058335312132840045, 0.018719467298069503, 0.006118312758189859, 0.020416833249328192, 0.034055056603392586, 0.03142318571917713, 0.039332260930677876, 0.03750481875613332, 0.04267275297024753, 0.012342432582954643, 0.042732651709229685, 0.04480480965867173, 0.038831378042232245, 0.019559353968361393, 0.05648636622936465, 0.033251466520596296, 0.041464558817096986, 0.05977916043775622, 0.10323925787815824, 0.021853785146959126, 0.034659161101444624, 0.009628105381125351, 0.029965130852360744, 0.0280758269582293, 0.012205911734781694, 0.06208896520547569, 0.0680420731077902, 0.018027433143288363, 0.08524938297341578, 0.027029873708670493, 0.0411535581224598, 0.017118396863224916, 0.034276858568773605, 0.009707867702672957, 0.037902506010141224, 0.024771388452791143, 0.02966873191326158, 0.04305427253711969, 0.07509241666411981, 0.09755396138643846, 0.049312811315758154, 0.0138891536880692, 0.024049703642958775, 0.023192554617708083, 0.05260986916255206, 0.04886915543465875, 0.03882153716403991, 0.021612640957755502, 0.06001490735798143, 0.005809596950712148, 0.01625487464480102, 0.027826932891912293, 0.06787738311686553, 0.024107147728500422, 0.05896509494050406, 0.03463948305579834, 0.0563474770024186, 0.004723013898910722, 0.02785043299809331, 0.05048924154834822, 0.020158486076979898, 0.009128276342380559, 0.02045646764599951, 0.017936961630766746, 0.024130159872584045, 0.027485175742185675, 0.0373456726083532, 0.058918005670420825, 0.07973989384481683, 0.05164346301171463, 0.06131510926934425, 0.011752297159546288, 0.048236340953735635, 0.018476469595043454, 0.015767389377288055, 0.06055687183106784, 0.057475708454148844, 0.0454938715120079, 0.055679410506854765, 0.04328411196183879, 0.05563612103287596, 0.01105212442780612, 0.0632199908432085, 0.03356541725224815, 0.04745674079458695, 0.032635595271131024, 0.04707680571300443, 0.015474322681257036, 0.04234676460328046, 0.015882409279583953, 0.05304297912516631, 0.024305907863890752, 0.07737868421827443, 0.0759268578258343, 0.06387329602148384, 0.031667044313508086, 0.030691767642565537, 0.0667717686155811, 0.019861157597915735, 0.019429027270234656, 0.045124474927433766, 0.08060272957663983, 0.09252846386516467, 0.016606953213340603, 0.009796996855584439, 0.05136857151228469, 0.05199755651119631, 0.05257774158963002, 0.01393393766193185, 0.05236666736891493, 0.0404549633822171, 0.0580895684834104, 0.007900034925114596, 0.024431121164525393, 0.11639648233540356, 0.06201600837812293, 0.035482982129906304, 0.05182412402064074, 0.06927200476638973, 0.056750006770016626, 0.034000052328337915, 0.04277003739844076, 0.057214476182707585, 0.04686376480094623, 0.04941100487485528, 0.041964959309552796, 0.043540809710975736, 0.05414886451035272, 0.0338214062503539, 0.029949638519610744, 0.07110569582437165, 0.10334149614209309, 0.04298687068512663, 0.028382280142977834, 0.04691929600085132, 0.04007216361060273, 0.014411137690331088, 0.015979404270183295, 0.016722704131098, 0.02972220921947155, 0.060410242003854364, 0.06194839130330365, 0.01443604694941314, 0.0484068976220442, 0.021825229159730952, 0.0423831855005119, 0.02643861578690121, 0.07643818273209035, 0.056210324401035905, 0.024456554565404076, 0.03135169463348575, 0.007057067878122325, 0.02765665081824409, 0.02059168509731535, 0.020983360955142416, 0.056077780536725186, 0.010529431674513035, 0.012177243497717427, 0.03631379047874361, 0.03002398687385721, 0.06256041451706551, 0.031451851173187606, 0.0946111603116151, 0.02893875916925026, 0.05423703907581512, 0.02310612781002419, 0.0629448024847079, 0.02789346643112367, 0.03807694782153703, 0.062071220454527065, 0.010568107772996882, 0.020633104359149, 0.02089400266413577, 0.03319035065942444, 0.04547913616988808, 0.04128650645725429, 0.07347451246459968, 0.08201859891414642, 0.0295946080586873, 0.023349754483206198, 0.011119778610009234, 0.028102724245400168, 0.06882494242745452, 0.013293463289301144, 0.013018737845413852, 0.011795915033872006, 0.07434617233229801, 0.0824644292879384, 0.08743309314013459, 0.029769984976155683, 0.04293348058126867, 0.06520320239360444, 0.010619250097079203, 0.05139272841915954, 0.04302953675505705, 0.03933221640181728, 0.03699310793308541, 0.04120056204556022, 0.014392115517694037, 0.0740254161064513, 0.035663691378431395, 0.02748966759099858, 0.08852680359268561, 0.03713026424520649, 0.010267194720654516, 0.04977056429197546, 0.0769944149942603, 0.04952870949637145, 0.037463926419150084, 0.027344241898390464, 0.054030621831770986, 0.0403303382336162, 0.04272609112376813, 0.03022576383955311, 0.020772674506588373, 0.07916596136055887, 0.016308836202370003, 0.011969000570388744, 0.029764018108835444, 0.02860852200683439, 0.08494999317917973, 0.01288094514166005, 0.01627263980481075, 0.028767488183802925, 0.06199981100508012, 0.02777686018816894, 0.057394610266783275, 0.020831005458603613, 0.046258702932391316, 0.00628301156211819, 0.03718614054378122, 0.06346662878058851, 0.05181134423764888, 0.06894781981827691, 0.05583007019595243, 0.05394568303017877, 0.04226939199725166, 0.050195217481814325, 0.05168529416550882, 0.043378795162425376, 0.05842105245392304, 0.06199757342983503, 0.07534672098699957, 0.023594702179252636, 0.031110136696952395, 0.035513933398760855, 0.052095393839408644, 0.03602846438298002, 0.044931843076483347, 0.03060905528400326, 0.011857042954943608, 0.045539940329035744, 0.02249903802294284, 0.028360973083181307, 0.08642179818707518, 0.062298703560372815, 0.05587922263657674, 0.046000049624126405, 0.059612952754832804, 0.017346076638204977, 0.0558238138910383, 0.0231162618365488, 0.027470685308799148, 0.04077612407854758, 0.09235710938810371, 0.01375616731820628, 0.037649385412805714, 0.036741954027093016, 0.06803500044043176, 0.03240516954974737, 0.027793276494776364, 0.03704183363879565, 0.03913071959686931, 0.022121270012576133, 0.07628245046362281, 0.04323490386013873, 0.03549756533175241, 0.05140901484992355, 0.00863077486428665, 0.058618808834580705, 0.04088389134267345, 0.01015594307318679, 0.08851544873323292, 0.04885295064013917, 0.05232328883721493, 0.06198252638569102, 0.01513365834398428, 0.019478908870951273, 0.04335351019108202, 0.05211046685872134, 0.03135535342153162, 0.14668355870526284, 0.1365381624782458, 0.13939305616077036, 0.16537505260203034, 0.14378296356881037, 0.1946769724600017, 0.10076112288516015, 0.12781219789758325, 0.1549245446221903, 0.16798803582787514, 0.13093448738800362, 0.20823188417125493, 0.16866631427546963, 0.11537205136846751, 0.18535185721702874, 0.1368168686167337, 0.1660188360256143, 0.1948363264091313, 0.15253368619596586, 0.20337996014859527, 0.1721331977751106, 0.11830714152893052, 0.0968371432099957, 0.09169821583782323, 0.16162967076525092, 0.15539459127467126, 0.19897486839909106, 0.13446543307509273, 0.18095357838319615, 0.1592148409690708, 0.10774868816952221, 0.09246193032595329, 0.22025486949132755, 0.12841782008763403, 0.08824671705951914, 0.23165243212133646, 0.15226069459458813, 0.13422821299172938, 0.16013768676202744, 0.1713063265196979, 0.11785068360040896, 0.1074232193059288, 0.14750173198990524, 0.19622181222075596, 0.12230197404278442, 0.1309762554592453, 0.15171002101851627, 0.2418661949923262, 0.15888421417912468, 0.1310562144499272, 0.10059520835056901, 0.20825103158131242, 0.2252010759548284, 0.16309769824147224, 0.1627308694878593, 0.1088932876882609, 0.12502706609666348, 0.15102484059752896, 0.1546877104556188, 0.10918586456682533, 0.18314953398657963, 0.1577931531937793, 0.1209155679680407, 0.08961904459283687, 0.1008620104403235, 0.23559863911941648, 0.10310213125194423, 0.22640280600171536, 0.1584207429550588, 0.18550315144238994, 0.15854897123062983, 0.19104648992652074, 0.16451953444629908, 0.2000966394552961, 0.07855079515138641, 0.11076865033828653, 0.10744101600721478, 0.14072722988203168, 0.17112788453232497, 0.1188322258531116, 0.182600092375651, 0.15421137039083987, 0.09297159282141365, 0.08741316647501662, 0.1490424305666238, 0.13831986609147862, 0.23202889395179227, 0.1582591625628993, 0.1476700065541081, 0.2016240535886027, 0.10223507269984111, 0.19064567080931738, 0.09870499532553367, 0.1723691710503772, 0.12461980513762683, 0.1360263625974767, 0.12961993605131283, 0.1410802101599984, 0.1188966739573516, 0.13018772355280817, 0.20867436745902523, 0.10730005247751251, 0.15441069641383365, 0.13867158471839502, 0.07599470496643335, 0.1566272837226279, 0.14106282906141132, 0.09202430068398826, 0.16259042546153069, 0.17588232003618032, 0.09372298023663461, 0.1935754471924156, 0.1752702856902033, 0.14320505317300558, 0.09525210130959749, 0.1137561806535814, 0.13051789021119475, 0.15500097098993137, 0.1262784012942575, 0.11452994382125326, 0.17502948845503852, 0.14440513565205038, 0.13418720191111788, 0.1191592235409189, 0.11579284167964943, 0.12935193168232217, 0.12121157356887124, 0.1899361627874896, 0.19503347051795572, 0.16549634921830148, 0.12362704903353006, 0.14332143677165732, 0.15471611986868083, 0.16893267107661813, 0.12780455377651379, 0.11717650922946632, 0.11473866543383338, 0.2471165484166704, 0.07986033699125983, 0.16257372713880613, 0.11818979313829914, 0.13059553370112553, 0.10410170769318938, 0.12727669382002205, 0.09723598079290241, 0.11477501582703553, 0.17405301507096738, 0.15753601386677474, 0.11085846505011432, 0.19825872557703406, 0.13682345888810232, 0.13686886348295957, 0.13495461229467764, 0.24313795409398153, 0.11778645071899518, 0.2729008218739182, 0.08898222993593663, 0.10521528543904424, 0.10771987799671479, 0.13777242827927694, 0.12669719522818923, 0.09405659046024084, 0.2724652108736336, 0.18124504946172237, 0.1595133327646181, 0.054366688564186916, 0.1693467449513264, 0.14666883449535817, 0.19412341935094446, 0.16562555712880567, 0.12453690724214539, 0.08083357461146079, 0.15656212315661833, 0.11944575933739543, 0.08579396351706237, 0.10566564291366376], [0.08202840268495493, 0.04811478829651605, 0.029943502813694067, 0.0030612659338657977, 0.029168190412747208, 0.06895801692735404, 0.01671352561970707, 0.03952675928303506, 0.046221829325077124, 0.009712009814393241, 0.09901540601276793, 0.014294190987129696, 0.04686913423938677, 0.025026544390129857, 0.020899587325402535, 0.11711488870787434, 0.04408523811434861, 0.06647342524956912, 0.004142364978179103, 0.08684002808877267, 0.047776472856639884, 0.10400768500403501, 0.04680541343986988, 0.027948507813562173, 0.023757108210702427, 0.019673268070619088, 0.03129443422949407, 0.019955521675001364, 0.12524914636742324, 0.02912368938268628, 0.039898760805954225, 0.007780899350109394, 0.012818016584787983, 0.05736918428738136, 0.016314311396854464, 0.026201132241112646, 0.02965351417515194, 0.06474759793491103, 0.03998008163762279, 0.01780511167453369, 0.038662580263917334, 0.040920056198956445, 0.03121998939604964, 0.0109120115848782, 0.041640388444648124, 0.008949058810685528, 0.031833626781008206, 0.04175235626462381, 0.02492837124009384, 0.08265460463007912, 0.031310653866967186, 0.05863918449904304, 0.07081422474584542, 0.06117702527262736, 0.031457220611628145, 0.006249969756026985, 0.08728675646125339, 0.03802525723585859, 0.03336392415803857, 0.004591077668010257, 0.015370203072961885, 0.1018486067187041, 0.06754216243280098, 0.01469546838052338, 0.04383160172437783, 0.03695685030834284, 0.011675296555040404, 0.08027444055187516, 0.054630663071293384, 0.0255994638428092, 0.0641388661460951, 0.02270733475597808, 0.012857091587648029, 0.017542168752697762, 0.058538846133160405, 0.023254685365827754, 0.01607544003491057, 0.04025469854241237, 0.03749091461941134, 0.03755154808459338, 0.014733762272953754, 0.02784052903734846, 0.04798946923983749, 0.02196018129325239, 0.024921845906646922, 0.029167323955334723, 0.029337079104152508, 0.018883190641645342, 0.011908522956218803, 0.00579937386646634, 0.048137820849660784, 0.0707406185392756, 0.06649684743024409, 0.030978772847447544, 0.0053937340362608666, 0.02685907584236702, 0.021987637046549935, 0.0336703124048654, 0.006597132523893379, 0.020914931228617206, 0.04983032944437582, 0.02955036863568239, 0.039079700654838234, 0.058784574939636514, 0.05886474915314466, 0.0923018268076703, 0.06808013786212541, 0.062285129679366946, 0.024081089068204165, 0.02754570345132379, 0.06158798583783209, 0.03887618149747141, 0.0881196020054631, 0.04035215366457123, 0.06095663338783197, 0.0368442961917026, 0.04559032473480329, 0.04203648008115124, 0.03621836884121876, 0.03832620182947721, 0.0550725452194456, 0.025836155145952944, 0.03995426231995225, 0.03299275384051725, 0.09198398722219281, 0.04385622618428897, 0.05452631339721847, 0.03129229684418533, 0.0012357083505776245, 0.018362310584052466, 0.022324384699459188, 0.020402832633408252, 0.0541007993160747, 0.0659698409435805, 0.048853830085135996, 0.04880175729340408, 0.05236024037003517, 0.09179033862892538, 0.04464436475245748, 0.0738398198154755, 0.06619552063057199, 0.04298215062590316, 0.02047962636424927, 0.010372679880674696, 0.01609844661288662, 0.013511019242287148, 0.019412453257245943, 0.005223708467383403, 0.03435055012232624, 0.0461775045550894, 0.017686308674456086, 0.05174725978577044, 0.09142543203779496, 0.048106940084835514, 0.08809577164356597, 0.03892137829097919, 0.020026463571412023, 0.08637057515443303, 0.029794973088428378, 0.010768117499537766, 0.017383853810315486, 0.057188218997907825, 0.00809752598797786, 0.02241074285848299, 0.00220008797441551, 0.05555011724936776, 0.008282931175926933, 0.056833320268196985, 0.03162622619129252, 0.02874234978662571, 0.03635296474385541, 0.017078398814192042, 0.047591911861673, 0.04889406933216378, 0.05776841520855669, 0.052101958135608584, 0.03940341804991476, 0.036164744960842654, 0.009910842309182044, 0.034330990820308216, 0.01842449142714031, 0.0649543602776248, 0.04912535965559073, 0.031060874789545778, 0.004510158987613977, 0.019230747675464954, 0.10025001320173033, 0.01766296070854878, 0.06112593211582862, 0.07589906439534388, 0.03891457279678434, 0.03794376942096278, 0.03488652546366211, 0.04771056643221527, 0.03450115415034816, 0.02967596043163212, 0.06265127565711737, 0.04169481384451501, 0.056382461843895726, 0.02496821529348381, 0.028080689880880527, 0.037239979646983556, 0.05456484570458997, 0.03252038797654677, 0.03700196546560619, 0.012374738271319075, 0.02577408005890902, 0.026237243291689083, 0.049200004868907854, 0.04665548105549533, 0.03831076144706458, 0.04283749120077118, 0.025966971661546268, 0.054182001404115, 0.04379479862109292, 0.03768145361391362, 0.055807468088460155, 0.01677632058999734, 0.0408542685181601, 0.025115826610999648, 0.044653289078269154, 0.06352395968860947, 0.05989309123833664, 0.034871934840339236, 0.02109177574311616, 0.054268788153422065, 0.0168087969723274, 0.06338689985568635, 0.03469463947112672, 0.051573786477092654, 0.02235801326605724, 0.016884828146430664, 0.028763241243723314, 0.018241839607071597, 0.024392193663516082, 0.013514167803805321, 0.07555935371783562, 0.043932659973506816, 0.09730886711622588, 0.06142485435702838, 0.008229630129790166, 0.019367711029190104, 0.044760852251783945, 0.034061884362017736, 0.0636925088474527, 0.03223779669497162, 0.03905901328835171, 0.049974424837273546, 0.0026035382370537263, 0.03183758242812473, 0.030391225664061494, 0.02008898951316951, 0.020729941643367056, 0.016909675250644796, 0.029285633427207358, 0.016328004021488596, 0.05533503914193716, 0.029663184359378647, 0.007718110409768997, 0.005402772467277828, 0.025970422648242675, 0.03823653925792314, 0.017157803049485665, 0.011867913563037291, 0.027295286126900464, 0.045577845521620475, 0.005226067569310544, 0.07194700185209513, 0.022420767418225296, 0.05709241144359112, 0.06607842457015067, 0.007565895457446459, 0.050676648679655045, 0.02708427498873789, 0.05609179599559866, 0.01575466711074114, 0.018047951671178453, 0.02139390035154065, 0.0076928588350710925, 0.03594067944504786, 0.03220985112420749, 0.02839821405359544, 0.0955182799953036, 0.04455024558410514, 0.036111258377786726, 0.025006402502185665, 0.051405968333710916, 0.021046796027803794, 0.04937755256833043, 0.017253599471587222, 0.017343608997180127, 0.04302956644096412, 0.007964443138916977, 0.016815535673231352, 0.06054854122339748, 0.020572274224832654, 0.08128039946313947, 0.054949678960838355, 0.045400212475215085, 0.058544686835375614, 0.04124103135836776, 0.006519339212900377, 0.09104494034545496, 0.052336157677927986, 0.003908918251909199, 0.018431981552566867, 0.06067310328944586, 0.049435614491812885, 0.08211547145037912, 0.013053038983343868, 0.015875138087722007, 0.020731876793433912, 0.028523950568342116, 0.027105099652544595, 0.041630888954387046, 0.0464978859963594, 0.036013896024087444, 0.05104198571643792, 0.008525786015525227, 0.03453268429439049, 0.03324869459902402, 0.025005665920616593, 0.03623625460022595, 0.022767760419810656, 0.06673241994576529, 0.06853514118120074, 0.018546359497122467, 0.01577779057697626, 0.04080452235939447, 0.0644399480370339, 0.0217816409713123, 0.02145818703866098, 0.020895281013508793, 0.04088457782927435, 0.0225597549797385, 0.004820631829716149, 0.054702595734852366, 0.05449583339213859, 0.07386103039607406, 0.012672695720539195, 0.051535287566366605, 0.05980407433526125, 0.03291947788966354, 0.008712458420632174, 0.0357948214514181, 0.022301914323179517, 0.021737134375143796, 0.028642918696277775, 0.03360218324814923, 0.06868862474220805, 0.04915260760753881, 0.040118659162544645, 0.15728162048617378, 0.1357511742389761, 0.03247027074394282, 0.12485611980082467, 0.12101216590963304, 0.12875359738245606, 0.10079133571707644, 0.10629052383592352, 0.10153512354008853, 0.1469681426533498, 0.21306969254510477, 0.0876632628205698, 0.10611306148348376, 0.11192961421329528, 0.09312979644164443, 0.2759895217604935, 0.09900659671984613, 0.147734172642231, 0.08611862343968824, 0.14559424918843433, 0.15382871904876083, 0.1812972521292977, 0.13612147624371573, 0.07288880209671333, 0.24280220648506656, 0.07605648133903742, 0.11629932036157697, 0.12504306680057198, 0.16777852753875777, 0.11961620839429088, 0.1769435466849245, 0.0878505883156322, 0.10181215984630398, 0.14316640212200582, 0.15251879871357232, 0.16708411480067298, 0.11291575036011636, 0.18306147074326873, 0.08139086072333157, 0.20963988674338907, 0.09513286044239067, 0.1949683841667138, 0.15192644612397999, 0.16623821487883106, 0.09600847595720552, 0.11246289184782654, 0.21634033735608682, 0.12847456469899043, 0.10950474315905012, 0.2026485142414458, 0.13588419678853825, 0.21664300002157688, 0.15916796692181379, 0.19652842311188579, 0.11903506223461591, 0.1418060454307124, 0.2057288130163215, 0.07245390355819836, 0.1001888676546514, 0.11868876870721579, 0.25477537885308266, 0.20956913038389757, 0.1602350120083429, 0.19163490913342685, 0.13399011717410758, 0.17409616353688762, 0.20138891151873395, 0.20057036716025323, 0.20578218827722594, 0.17876167490612715, 0.14502631325740367, 0.17972306784940884, 0.06486209647846408, 0.18373412371147424, 0.1020198201877065, 0.1150413132563699, 0.10334211954614148, 0.0964269730320666, 0.13391285960096866, 0.18553365371190012, 0.1552539988188073, 0.21229432633845136, 0.08794015811872669, 0.10619232285534963, 0.09667426405940205, 0.10942563763819635, 0.1245986539288424, 0.08337550461874343, 0.12141374201746657, 0.1306563155958429, 0.14803809695877135, 0.17287746799411252, 0.17574288533069193, 0.1582547987345606, 0.19098895863862708, 0.13971087348181754, 0.12027839708025567, 0.10236284826532938, 0.20893040840746835, 0.13495532475644723, 0.179675139952451, 0.05722641362808645, 0.06872671176097356, 0.15037682693218812, 0.10002667870139703, 0.16893333900952712, 0.19322588079376146, 0.13817222323268652, 0.10327312207664363, 0.16365018265787512, 0.1301971636712551, 0.08506815793225542, 0.1363528482033871, 0.11934953246964142, 0.18316865171073005, 0.12016677064821124, 0.17898379970574751, 0.11279066879069433, 0.17326115834293887, 0.12422252606484108, 0.11168805998750031, 0.16161358100362122, 0.19302544154925272, 0.1553780265385285, 0.1531873847125098, 0.16310482285916805, 0.19732155633391812, 0.14920086425263435, 0.1071156955731567, 0.07634604509803466, 0.13839433318935335, 0.11586052554775961, 0.13973672990687191, 0.1808495886507444, 0.0993908362579532, 0.09196849860018119, 0.20338338887086138, 0.2242098783608526, 0.11457871034508571, 0.10668279341189191, 0.1931225589942187, 0.08783320721704513, 0.15952087298501283, 0.12317140746745281, 0.10821713178302161, 0.07182812463724986, 0.11822923086583614, 0.12978046259377152, 0.13545585883548483, 0.18599549221107736, 0.0848060313728638, 0.1345657862839289, 0.1905466237803921, 0.12064270253176801, 0.2796297561144456, 0.13605517277028412, 0.1453225192381069, 0.14280654955655336, 0.07912089815363288, 0.0922632945002988, 0.11736128915799782, 0.18707221490330994, 0.16143932472914457, 0.08433938375674188, 0.11657526571070775, 0.17985720362048596, 0.23936226294608787, 0.15880060382187366, 0.10411415350972675, 0.09435829575522803, 0.09571693066391163, 0.1304623924079351, 0.10678102407837287, 0.11970080580795184, 0.12072633515344933, 0.1299805159214884], [0.027324803195369896, 0.012577012475958327, 0.046172610091161914, 0.007403009349218337, 0.0028380230423863395, 0.030226708222471643, 0.03478294391243253, 0.0675995007622987, 0.03030634437891422, 0.02872079967346508, 0.04894620520644821, 0.031059071370691527, 0.018623945470608305, 0.01151075313828187, 0.060600064825848676, 0.05996750267513562, 0.05758662984590046, 0.0303519400767982, 0.06587399257114157, 0.018123290792573243, 0.028265801920497324, 0.05190033516555559, 0.025111668728641234, 0.03180979641911108, 0.05809804380987771, 0.022551294496224727, 0.05334055436833296, 0.05290927379974164, 0.13728872610954568, 0.03271441506512929, 0.01886524180008564, 0.02421193155896617, 0.0566512380464701, 0.09381571158883162, 0.03977992069849279, 0.010222105538559845, 0.060572957881959155, 0.05683247421984561, 0.05441518791485578, 0.009813205360842403, 0.042135144904023036, 0.05076981047750451, 0.024899130621633958, 0.019749371604120824, 0.023594587146362755, 0.08694794378243387, 0.05140059147379361, 0.08723605293198489, 0.04875077916949522, 0.045125068645575084, 0.0851443616556935, 0.05785948414995801, 0.1259690592996776, 0.03501583727484103, 0.02283293582877377, 0.02210065500548808, 0.05838089855387807, 0.03642958035925403, 0.01825961775466567, 0.03807243556366302, 0.03165385263855569, 0.06619839274208061, 0.0999262290133629, 0.06731488712830469, 0.040831840815371834, 0.009423658539162716, 0.03826358682999853, 0.053557910869130865, 0.0006488905592050287, 0.013882603307138197, 0.033663685026112944, 0.01423368368705269, 0.02506002452719258, 0.03771479088754859, 0.01978770538698882, 0.05839528137585148, 0.05168866722669918, 0.005061282490714802, 0.062492129509337246, 0.05594585636572447, 0.02634476935782004, 0.015833102843316738, 0.03597117800381966, 0.04260449764842633, 0.07256020136992447, 0.11879005702212453, 0.022149822289065924, 0.0628570064145606, 0.05426398645795416, 0.057627845017123036, 0.02726569855440175, 0.03203057422069833, 0.0745933446160052, 0.036471307612373494, 0.03158715582685545, 0.028013907722197473, 0.056891686472226866, 0.025591129524400458, 0.03093218823778443, 0.028920801050844602, 0.03078999088756973, 0.06637317594140768, 0.08204402489354834, 0.07852342474507168, 0.01790095448086504, 0.044814639404648915, 0.04970497699105181, 0.026391353967483155, 0.07008689033682458, 0.10446252505062148, 0.0272617262089625, 0.019633362790045794, 0.06594035541638732, 0.05117094129673205, 0.020289399071771186, 0.05666332763212267, 0.01776159399014432, 0.04379336256533861, 0.04681369951867964, 0.04472624961636029, 0.00869911367772147, 0.06633868833887391, 0.03775002434849739, 0.02887050013669068, 0.016427305235993117, 0.011509629712236347, 0.02695992629014654, 0.04098044846614357, 0.05876704541151412, 0.0966686534229666, 0.030283822052297182, 0.011359488598827738, 0.037300639087334275, 0.1162015127192717, 0.05590144624875393, 0.030673664805362932, 0.031163311577984132, 0.040560875277151354, 0.022899317227711435, 0.048579639915260486, 0.06231868959730491, 0.03890916625095997, 0.02629443319165148, 0.01860260501416633, 0.03301970864413306, 0.019220361318730284, 0.06100276528741233, 0.026776471095217858, 0.02189528604503721, 0.08747059386223555, 0.07002848331467248, 0.0033111867151092156, 0.03715379032655619, 0.04181850759778172, 0.007686026438022964, 0.027157402510056272, 0.025898445455823094, 0.04729952794150449, 0.023778383729222696, 0.0784334987110924, 0.01581293312483467, 0.07876958770793863, 0.04706318359239958, 0.04543607676168904, 0.04531808641331736, 0.07555226620752364, 0.012187606662337203, 0.02116586249030661, 0.0316932681016624, 0.03743300854694098, 0.04008842777693644, 0.07066554288030602, 0.01098267239285633, 0.03121303547231946, 0.027343612928234506, 0.02729564977926202, 0.054074790750746615, 0.01133490402935422, 0.021880226013308857, 0.04132311660214327, 0.021615802506858017, 0.035422712317085825, 0.017165833087346982, 0.061754431008012034, 0.05749273332185112, 0.060971706407144666, 0.03408316915738396, 0.028184219481772743, 0.026374407025286928, 0.018180972365371417, 0.059607330986182205, 0.06546613047248684, 0.056360520247835666, 0.05386922326579224, 0.022730842283635866, 0.04017400111479219, 0.057104872103082016, 0.0579395804379601, 0.01706304377876222, 0.010072814184240997, 0.015811767952982336, 0.004935241231578402, 0.02215146058006212, 0.007447823008988053, 0.07292677779332735, 0.08121638180455193, 0.06397426521289162, 0.02909608891059179, 0.028593194801942445, 0.07507804126362316, 0.05750968397478573, 0.07321277924347669, 0.036217797387507744, 0.03563420585123822, 0.03164685047522653, 0.010761186767922482, 0.031120190942601766, 0.011579731126403203, 0.006346586251311237, 0.02193929540226236, 0.03169086354319006, 0.06120331585407257, 0.045882905324106105, 0.1150823243369814, 0.03423749134526588, 0.01359096802843851, 0.002068191633952665, 0.03802941326284781, 0.03993150807218626, 0.04756222595460713, 0.05434609396615997, 0.08231248939409852, 0.008958027665357804, 0.04647666428354569, 0.028405442571965978, 0.03813160699792206, 0.06855711617390625, 0.037359209381975234, 0.022257281561905984, 0.016222290651057847, 0.09736981228343211, 0.021978143122396432, 0.06009011289279442, 0.01621003779291641, 0.0497795628325548, 0.013208941945777042, 0.04772399188368581, 0.044152981354272924, 0.062226462905528024, 0.02486989371391246, 0.019601622989284806, 0.04078102967469022, 0.0660474547476042, 0.027775836024375167, 0.056248630353366025, 0.033594234846532345, 0.025724910919961985, 0.020660292939282954, 0.00912417968720547, 0.042238251480739564, 0.03291701024863869, 0.01849231444793986, 0.05868393600394484, 0.06688893146929331, 0.09230088428012095, 0.06147186941234395, 0.0338346424541669, 0.03553695853042882, 0.06871968362247571, 0.014479597102763364, 0.02146897229977185, 0.014328408633446088, 0.024600367942184675, 0.05336020272807218, 0.0258848771409248, 0.028907524028909393, 0.01566026778164087, 0.05440359185740817, 0.05415097592049278, 0.0372147614689311, 0.07655863330001011, 0.055920675295055844, 0.01532159611087991, 0.00345172791639925, 0.0368719820107799, 0.08725105173652992, 0.02195611803472275, 0.0332520416850457, 0.036702820580103435, 0.0749462803651113, 0.00815115636214614, 0.07655610999790952, 0.02351336650463054, 0.036156518253847025, 0.046420877042692155, 0.025754671041795518, 0.025054163415916264, 0.018918310925073456, 0.03598356073780451, 0.015530301952821901, 0.02201025028625736, 0.02107078780682059, 0.06317016304819845, 0.07914083224022761, 0.05239105063083116, 0.054763232910772786, 0.02920178187196143, 0.0238405070558656, 0.05367129990190733, 0.07887424537329935, 0.005963826833976782, 0.06313669218798168, 0.049696171408868395, 0.07581123863928951, 0.02407619460427668, 0.04544750954664778, 0.05664023570716381, 0.02844801030732924, 0.07005422099609859, 0.009596628115104977, 0.044265331380302086, 0.023283803529920988, 0.08820706410915591, 0.05040314128564205, 0.026923967379843816, 0.06070513067243155, 0.043034613045165315, 0.01477951196648064, 0.010529855626373319, 0.021886910908506252, 0.034338460536673665, 0.019663545936055016, 0.047970908126444556, 0.03910269238986075, 0.010447852946526837, 0.0020360332155178185, 0.015292432490241481, 0.06406548258382827, 0.030733112689631525, 0.03608854494814295, 0.0227636786075891, 0.04916017751384061, 0.03724110028997529, 0.09216867067152634, 0.01843638990976615, 0.005697501574104535, 0.0023630000578123145, 0.06810284015955403, 0.054221587561187334, 0.01786331460607471, 0.00900809758604737, 0.04986456100596115, 0.13544629997340962, 0.16824208782054484, 0.11527153488714248, 0.2439129343838431, 0.12259553055628203, 0.18667200434720144, 0.07442412010277621, 0.1830510955187492, 0.16709023009752855, 0.14642496476881206, 0.15464640251593664, 0.1386302025639452, 0.13587116467533633, 0.12463954626582563, 0.14459334430284798, 0.11606931395363063, 0.14889699930790812, 0.12358751482679509, 0.11548677255632356, 0.11880009085871279, 0.11936330673051998, 0.1471296339877881, 0.062121092778397724, 0.06367924666847102, 0.12983952270587906, 0.07940227602375671, 0.13118828705046326, 0.11637219926342368, 0.22723649017279968, 0.21672779781511053, 0.13709658407606184, 0.07281235346454196, 0.15855559118790552, 0.28982282790821046, 0.15015804179711267, 0.2033723605563864, 0.14128188136965036, 0.09001984144560993, 0.206871067348402, 0.0928556322469376, 0.25619196065235883, 0.10822934753377922, 0.09315045041148551, 0.07585348168504424, 0.1354753624764271, 0.1450102383387275, 0.15977629052940756, 0.14216948999091983, 0.1945892654475756, 0.10307463468052447, 0.1512685915804468, 0.21546880365349352, 0.18876725051086396, 0.11367284489097074, 0.1706394474604167, 0.15438613132573664, 0.15050098823849112, 0.13494779937900603, 0.10155669777304865, 0.10574073341558687, 0.12359898842987604, 0.11900087891262956, 0.23310463700909168, 0.14386146795004606, 0.22518338315421715, 0.11254014942096546, 0.16080600558780134, 0.1407623928389512, 0.09136252017924562, 0.10793939043651335, 0.13285093533340842, 0.0976712949341163, 0.11682664597174153, 0.08033964564674534, 0.13990602863486856, 0.2093705316656269, 0.23483439028495923, 0.11215522710699588, 0.19797047541942447, 0.08951691765105352, 0.1276196847902611, 0.0888146307261195, 0.1678292904398404, 0.14031688158866018, 0.22301972581772134, 0.17762025177944452, 0.15663945494452491, 0.22151206765556708, 0.21210620674537495, 0.11581685015698895, 0.11006837463355623, 0.12930946599226445, 0.2269583332235925, 0.07099259251845069, 0.09254331424017437, 0.07224742323160172, 0.12113738106563687, 0.15802361973328516, 0.11356063958373852, 0.15056084987008944, 0.1046971179312095, 0.23858634755015373, 0.24667862191563472, 0.09821551182540134, 0.24170415446860716, 0.11964157500187866, 0.1322786504169926, 0.18020000163232908, 0.07805459521478042, 0.1862551993690431, 0.07957225752761588, 0.1505464522051625, 0.21591263765003532, 0.17114486487116665, 0.12945093418238685, 0.12722514424240217, 0.10369052077294327, 0.2044128515990451, 0.17675002425676212, 0.12349767042906024, 0.07302004349185154, 0.11318624092382379, 0.09401331582921557, 0.12052047823090106, 0.08871415877365507, 0.09246176705346443, 0.11674855719320476, 0.2070162759628147, 0.15193291765172035, 0.1921473175752908, 0.1141490216832608, 0.11068513646023348, 0.1978025125572458, 0.22433316393289715, 0.1339743984863162, 0.10848870588233694, 0.1710594882024452, 0.12120468643843196, 0.13097502349410206, 0.17674748611170799, 0.12115081393858418, 0.16920165508054197, 0.160726313770283, 0.14028580044396222, 0.0994663720484823, 0.12942061002831906, 0.16747728979680687, 0.13390447333222255, 0.10473890084540471, 0.1328290271339938, 0.10378540435340255, 0.16656842606607825, 0.0977841236453969, 0.10023022754467092, 0.1207870502548758, 0.08852539351209998, 0.17848748102551326, 0.16964617185294628, 0.08543019983335398, 0.21680682169971988, 0.09400068447575904, 0.1796024540090002, 0.1215282702469267, 0.17386078397976235, 0.16820775606902316, 0.19170652638422325, 0.10607769814669155, 0.1323007812607102, 0.05184094850847032, 0.0862860148481559, 0.10813784072524868, 0.17976823495700955, 0.12028647164697759, 0.14170962560456246, 0.07549041562015191, 0.13770655525149778], [0.03794893105805386, 0.12791869608918205, 0.06827316305134445, 0.06564863200765103, 0.01696733270364348, 0.08994888470624574, 0.021907867303525563, 0.07820505081326701, 0.053426146259880625, 0.02498390243999893, 0.03357601883180905, 0.07426737109199166, 0.057537095199222676, 0.01616113953787135, 0.044611795601667836, 0.06034767524397466, 0.05080817951238714, 0.015538660391030135, 0.06575665902346373, 0.08692931587575004, 0.036238948596292175, 0.01234234259754885, 0.020139811786066275, 0.039516710603493266, 0.03611128806369379, 0.022900875737832393, 0.06235358538106084, 0.022025622020009905, 0.05414577346527949, 0.05845470885105897, 0.024752454410190694, 0.04930842522298917, 0.07540347301983275, 0.04012818833871279, 0.05124386843817774, 0.04103544903045986, 0.06112434020906221, 0.014772360445931554, 0.016481099810334854, 0.04491408348258119, 0.038906279296497814, 0.050560354138724506, 0.03177909005898982, 0.07347896535065956, 0.0556595061061671, 0.017486338838352822, 0.05568886917899363, 0.06354375276714563, 0.04364584216091316, 0.056860761178541, 0.029704412518185563, 0.03805987842497416, 0.037504035790334456, 0.034324712250963785, 0.05184692650800571, 0.04243790404871106, 0.04221225404762663, 0.0681535956391599, 0.017252992765861563, 0.08856475702486932, 0.020055097484146245, 0.026386350036773365, 0.029967828559165355, 0.04286857976694591, 0.028453921513573732, 0.06068580143619329, 0.014460563797911163, 0.027961467567365617, 0.06515625413157977, 0.036116167684667744, 0.0007798616502441291, 0.07828216737834737, 0.02979448327096179, 0.07469095187843777, 0.06134294351795688, 0.028816121121053584, 0.02101535865222104, 0.007983897612575674, 0.05632347223581746, 0.018647861179488245, 0.10451851267134771, 0.03728843446879182, 0.02554869537561899, 0.02811012902384391, 0.07242767605930567, 0.01885762179881567, 0.012257330508873565, 0.030911677131371107, 0.03925917422748171, 0.042101529325009324, 0.018531267924117856, 0.056047575126285665, 0.007952069681778084, 0.07361548341577873, 0.022067622012400534, 0.017062735787476413, 0.08032708850805648, 0.031890876052784733, 0.02337550886295503, 0.019138663847115822, 0.026058480325446, 0.0704283376398962, 0.013226881510490784, 0.05380858980061021, 0.023212499836517964, 0.02878428484109463, 0.04610890413459856, 0.005876875884496258, 0.030404860772250686, 0.06438995696953498, 0.08582380527514033, 0.06356330093694851, 0.05414375482359901, 0.06345925183268264, 0.010250512168568093, 0.057807956836768426, 0.040718485179240815, 0.027353466794011183, 0.03204805550922174, 0.025758854899322614, 0.01977198669919744, 0.01421541572199203, 0.04805746109923348, 0.07713416140177287, 0.00890488525328692, 0.013862166415492538, 0.04718294396298006, 0.06705969964968972, 0.034846490307245404, 0.0388150099752238, 0.03792936804529745, 0.04870668075454887, 0.009402294890605845, 0.0185893984962604, 0.05244965432211757, 0.020376727588882204, 0.12580905226059258, 0.036600593448383734, 0.053689846172346734, 0.01652611292229267, 0.025313401165476535, 0.027711248767445795, 0.038263809474301524, 0.04124774037336465, 0.04642653962946497, 0.05532326496904716, 0.05902668948692735, 0.015272000237018801, 0.023976622505870182, 0.04841937312448863, 0.00424956589085923, 0.034909699024865404, 0.019296995487820823, 0.07725632633082569, 0.04203475829854142, 0.04148488624196034, 0.1492787155439146, 0.01536148654849967, 0.030325335937959608, 0.009094999368244316, 0.03200941559043713, 0.007855127569200704, 0.019408028201723937, 0.025431543654121924, 0.09804418703424744, 0.10468684660736471, 0.038969855377217755, 0.029238427268865053, 0.03324172954307869, 0.029070495947962627, 0.03296432216302492, 0.05945522410911508, 0.015000221119407797, 0.013861659899703227, 0.026159269546042196, 0.01855420214269543, 0.053983065008651465, 0.05762388937000651, 0.0668878701981157, 0.07538412522990257, 0.039475432349718176, 0.0589752438099822, 0.009984553344111191, 0.03911835541657638, 0.035500771409715526, 0.020371163336676545, 0.02712148070713738, 0.022116180734883528, 0.03675886386190541, 0.023974781979632098, 0.03432409997913055, 0.012605956235347548, 0.07192167977336794, 0.02699448068597121, 0.024485297944920603, 0.033583666663616896, 0.044549458907567896, 0.008433377497567562, 0.047979030932765454, 0.02719984964642208, 0.02914784628956113, 0.017242066496692132, 0.0310671329498291, 0.03427504772844259, 0.03846867934043985, 0.03685506104375236, 0.016004846947907936, 0.023972208582563326, 0.133461871300824, 0.043822239531436935, 0.06873057835036889, 0.03935702639864758, 0.06341518310364336, 0.03085991418629419, 0.025986375112552196, 0.030954838584875688, 0.012103585340810241, 0.006277652328208205, 0.09984191361581907, 0.03374872401764151, 0.042631114774849266, 0.03766714871744625, 0.013156261520634871, 0.03773125914449338, 0.03815122567175422, 0.0037183537460805383, 0.07198505918495357, 0.001619296074295562, 0.06591791287064552, 0.03912835585651919, 0.041373244966962375, 0.054033902124501765, 0.011555549172044266, 0.06283061564317904, 0.023968388377397787, 0.01292781176744029, 0.02866545215510996, 0.023243809191626497, 0.043659067232511006, 0.033388567171641625, 0.0433003538637422, 0.007178402529461891, 0.05032282977481373, 0.09239793493179604, 0.055781006813049316, 0.03838849770545494, 0.01780918606527848, 0.0403509884927189, 0.06725807572365738, 0.04648690592148341, 0.037216728160274215, 0.027450671441329177, 0.005761123575211968, 0.04653825882996898, 0.018758107216854114, 0.012439201218512608, 0.08528190388460644, 0.05118161338032223, 0.02718751329666702, 0.07981640184880234, 0.01001903723590658, 0.03965560725191608, 0.04713795497082174, 0.011418534795666346, 0.05194372854020912, 0.04668284404033329, 0.023699569501332007, 0.017513059865450487, 0.014925983159628231, 0.032948332591331564, 0.042146425548708066, 0.06579629713087343, 0.024094731597870123, 0.041828649045783095, 0.061116863071219996, 0.013726522229262628, 0.028192533391120378, 0.016550564832868986, 0.023971564769453835, 0.010851810420717811, 0.03284999431343749, 0.037735281584900804, 0.08372931610210799, 0.018778419798763935, 0.046794882364338264, 0.04903002336504869, 0.03397159838641528, 0.02983838872751221, 0.06222395815711934, 0.03723200898093637, 0.02754927503701765, 0.05684974399628118, 0.035336645451025106, 0.04028554219985381, 0.04663770290790126, 0.07137404900277033, 0.06720804754877463, 0.02524405859730905, 0.06016309198457748, 0.04012298959423788, 0.02046906745817978, 0.05924067663727328, 0.08136871503666043, 0.032346131702070124, 0.048871741819311865, 0.03551674984919373, 0.02266417144710431, 0.031104442568903323, 0.006218772186912247, 0.07382199342828244, 0.03410973062273115, 0.02745064175542211, 0.07242642182973213, 0.017519666835141834, 0.05041086333221756, 0.03255203686421737, 0.049487509168102406, 0.03197723977791611, 0.005096349432278657, 0.025702071325213183, 0.06822147246566601, 0.04643188680347521, 0.020877142924291547, 0.020358736073831096, 0.05630045823636465, 0.016969386597338598, 0.037988862313795835, 0.03541539474099409, 0.07802994849043898, 0.02560197786806384, 0.014893301759002497, 0.06486961443442851, 0.017980158336285967, 0.005302032877807505, 0.053619535101461224, 0.031124421184358653, 0.01849618103733519, 0.02604482666356489, 0.009310904970334377, 0.02889806350140134, 0.06271488513448276, 0.09369649298605509, 0.03960490743338596, 0.060183378591318615, 0.04407397973409388, 0.030281888757599518, 0.023381436767522246, 0.015896480399533175, 0.07277409575181082, 0.02733236939093331, 0.04680940619437024, 0.03870981054205913, 0.09448615295696072, 0.3129745105979964, 0.2028980985051021, 0.1910651326761581, 0.09527633985271677, 0.130355523142498, 0.16032724612159654, 0.12071667239069939, 0.1707391772652045, 0.07128032317268662, 0.1498807012103498, 0.12099105922970921, 0.144186380202882, 0.09637186114559881, 0.13067247957224026, 0.1378095505060628, 0.17498921952210367, 0.13906459644204006, 0.16372432321077213, 0.19189712475053966, 0.11352695350069553, 0.2512256271438673, 0.196584856021218, 0.12233203102368861, 0.08544295735191554, 0.06438266907935031, 0.09183508271235041, 0.059853245329577476, 0.14760922465939075, 0.12704509921604767, 0.07860299039748497, 0.19298929895740002, 0.23245681630214676, 0.09486448499956168, 0.15528160671237856, 0.10176582756685093, 0.1757081676623784, 0.08655305442516692, 0.15004869375843555, 0.13237213133834302, 0.09526681067654863, 0.14857936010230333, 0.14534028625348583, 0.18467233196133748, 0.11432610554038547, 0.14051040401682258, 0.11325543877319433, 0.15352800081018358, 0.14412025484489277, 0.133285433112178, 0.15506945637753233, 0.11091987777035683, 0.2583675814094022, 0.21238455665297806, 0.1293505512876436, 0.10304178722435609, 0.14245738391764462, 0.20665628981078044, 0.1564790026168339, 0.15703399549238384, 0.1309992471942678, 0.07060092408210039, 0.11299495978164487, 0.16967153846053407, 0.10453803857672028, 0.14118989958660677, 0.09669010891229846, 0.20086876989807934, 0.25768905063159764, 0.20266930921934545, 0.1608596183359623, 0.19287166855065152, 0.13674600835656747, 0.13791759236482903, 0.1394671670277603, 0.11042796744732186, 0.08298238899442367, 0.11646296392427757, 0.1433458979590796, 0.07395290827844292, 0.13442082999972627, 0.1583024743013084, 0.10502847202587873, 0.18625484313815832, 0.16020367853343487, 0.13224541704403237, 0.12070181459421292, 0.08332817786140367, 0.23477289592847228, 0.09120723319938406, 0.11526535279699601, 0.09544377579004504, 0.05643822682031896, 0.4210185958072543, 0.13779926433926448, 0.1521909623988904, 0.21449457155540586, 0.14441466482821852, 0.17948051914572716, 0.13815957703627646, 0.09801454565604217, 0.12347712035989389, 0.23322645312873647, 0.15504076494835317, 0.1308858915581368, 0.12824310368159786, 0.2510427322704345, 0.15500708628678694, 0.1325404059025459, 0.10380268155131489, 0.18885212251916528, 0.1577084296150133, 0.1513304718537256, 0.13178963446989655, 0.055505978016299196, 0.16507279069628567, 0.10469893619301729, 0.1409076459822245, 0.10763476107968017, 0.22691252786898986, 0.17215048981597647, 0.08817115158308297, 0.15620267135091126, 0.1656827618717216, 0.25456977426074445, 0.14292095904238522, 0.29211455024778843, 0.15722684998763725, 0.19496492575854063, 0.13682942575542256, 0.11453164333943278, 0.12877054803539068, 0.09531312811304815, 0.1456818523001857, 0.1707252545747906, 0.1492815653909929, 0.1881426590261981, 0.08963085958384909, 0.13268036011140794, 0.08587709147832356, 0.13158489076886326, 0.18452639604220167, 0.1312589691951871, 0.09538037411402911, 0.18048653000732884, 0.13483031740179285, 0.13622393715195358, 0.10662475746357813, 0.10984951528371312, 0.06585900860955007, 0.11578188757994212, 0.09454965111217462, 0.09387862344738096, 0.08696355114807375, 0.10095882360474207, 0.1343922721571289, 0.2683356043417007, 0.10928035480901599, 0.17914686439326033, 0.1458503198227845, 0.13328348868526518, 0.11698824862833135, 0.07930833497084677, 0.09924515266902745, 0.2928596962010488, 0.3648442210396752, 0.12199723336379975, 0.15467997727682814, 0.1459216105286032, 0.11065427795983851, 0.1215677525033243, 0.16195128788240254, 0.12593242689035833, 0.18179364502429962, 0.08934679513913579, 0.09794223078642972], [0.04493133841606323, 0.020503313862718642, 0.0049890000900632, 0.04622279782779515, 0.0041342713939229725, 0.01585779038578039, 0.046947809314588085, 0.05509229005838279, 0.02371800073888153, 0.03189316928910557, 0.08649324474390596, 0.014848906484985491, 0.034213649851153605, 0.02104447310557589, 0.08514149696566164, 0.052829236883553676, 0.08531256200512871, 0.053473061125259846, 0.023343542707152665, 0.040912022450356744, 0.013726919278269634, 0.05488550174050033, 0.030381726173800416, 0.07383523334283382, 0.01842073801526567, 0.04128299238800537, 0.07348951869062148, 0.030648101528640836, 0.029251292398839723, 0.02006931146752322, 0.035428037226665765, 0.03688005657750182, 0.00291248132725741, 0.050103755202144384, 0.01464654786104802, 0.02766773850453319, 0.03585587051929906, 0.03527946668327786, 0.04822603252250701, 0.018167632260883693, 0.0344989982113475, 0.005485370720634819, 0.022538818993780296, 0.029360061562329065, 0.11516691432916559, 0.022384494950529188, 0.020693962324003223, 0.04608541144989431, 0.03672127779282164, 0.029988473252160475, 0.09605598825146444, 0.046866184202372096, 0.031160454309429042, 0.03195948760549072, 0.014341170790430624, 0.06440131182898767, 0.009629763153498061, 0.011934616868529702, 0.023263708026206587, 0.040759819094091654, 0.032222204172285274, 0.014630908954131883, 0.0642613427771721, 0.06617186838411726, 0.018943143186334055, 0.06256532753468491, 0.048437154982821085, 0.062211222902988084, 0.03417941086809151, 0.031066906594787724, 0.02436783823213773, 0.03866466569888871, 0.0852867352659814, 0.011435448341217125, 0.035910592778236605, 0.011770189412345644, 0.00496819397994841, 0.019746571852010675, 0.010496855102246627, 0.05248367066087667, 0.082541093142936, 0.04790103863342665, 0.05201100793783553, 0.013926204483141191, 0.003904818813680322, 0.031697004815214314, 0.011465391216916032, 0.04736026901809964, 0.06983770683291368, 0.06082937361497898, 0.06954948636121117, 0.05046416066761594, 0.028373942113830708, 0.10071496872114949, 0.06266024080105126, 0.08071696094702929, 0.03974739978730213, 0.03907604928826913, 0.05683386203600094, 0.03509017078613397, 0.04324509725847747, 0.020982683745387476, 0.029578562825918198, 0.03689027224027086, 0.006086069224693347, 0.08170033630449325, 0.021281325825839303, 0.053041468854644336, 0.044781417163903825, 0.0416017299721716, 0.037122683206689544, 0.038642694416921586, 0.009763598354766145, 0.009369751714984886, 0.016672162018949166, 0.030551703966921195, 0.044049173448001966, 0.03293681445939001, 0.0212888289388502, 0.04799833048309665, 0.013246772923594108, 0.032625372186885215, 0.022288290347205475, 0.02745893711107783, 0.015767699223943055, 0.04415498144226149, 0.016796481031633448, 0.02327456935745431, 0.017460074232076295, 0.02912666168413125, 0.07838828707463108, 0.04986150706827175, 0.041364075732417405, 0.026710870806709863, 0.019212809966120403, 0.061884774404461496, 0.0022445820468419697, 0.07215673278551549, 0.021634046352119185, 0.0325943244388327, 0.0340397164109163, 0.044071092779631726, 0.046501607866957784, 0.03446269976848271, 0.0075234274481772445, 0.05772797187091783, 0.030582616273022722, 0.04682536979089491, 0.04364504435216077, 0.03614276254666038, 0.04211999766994268, 0.01131772980443202, 0.09521771760773845, 0.04522289484157227, 0.015890418908384163, 0.023654341166547965, 0.05832106660818681, 0.021905600042373408, 0.05049439576396253, 0.018559655072749592, 0.1235957007156685, 0.0030807097391516436, 0.012479738252295647, 0.01946623669937253, 0.018694956015679054, 0.02444834270136198, 0.04436035225808155, 0.06114193281973712, 0.04114732779271435, 0.028538366786960978, 0.03467004840786103, 0.04952532530296594, 0.05056635811342858, 0.02865134763851529, 0.051785343093797565, 0.016987339149636682, 0.02404137860139599, 0.05234444004599936, 0.04965584310411941, 0.02015311663853936, 0.031645306808059104, 0.02999841803102754, 0.03680350404465571, 0.035278564973850735, 0.01884798130049603, 0.00855199403304141, 0.021745444573753048, 0.07211797041236423, 0.0303702432938735, 0.06792135536670685, 0.07321493889321573, 0.06324466725345701, 0.03527229011524469, 0.015318850164476316, 0.04634132994397078, 0.04921048028336372, 0.06301857938524336, 0.043943458222202025, 0.0570582874934189, 0.02826156054652529, 0.010756406409200281, 0.021582381741609424, 0.0360899067891296, 0.04616224599885754, 0.0369792557467008, 0.026036154667963274, 0.00582523492994369, 0.027255924469500314, 0.03315225992992055, 0.02665516520210076, 0.06370617178617977, 0.046243151227827184, 0.07474644968169741, 0.038495437474921346, 0.07843973275157623, 0.039800459635443985, 0.08006136253243312, 0.01680541277892189, 0.03857155214063823, 0.08176203104085289, 0.04624150365998503, 0.031398052888107486, 0.0642877038626466, 0.032858020640560426, 0.027840415859827772, 0.01907425841636723, 0.06814489024691284, 0.049592578725423664, 0.038392468195525, 0.02443734963890165, 0.04219431633828208, 0.07755625047138892, 0.039038570830598474, 0.011551406132639386, 0.04992928370484151, 0.025418060686206445, 0.009842782728810562, 0.0519012851145817, 0.021929261565674096, 0.09732995153171942, 0.017990709820878692, 0.08496137772453949, 0.05723158268665429, 0.06121364654973149, 0.019812854916381184, 0.04264110408257693, 0.037292249107849784, 0.010058333955385024, 0.035973055637441576, 0.04176198934146669, 0.03416265688429121, 0.04881325687165372, 0.0045630926706508035, 0.013758185032202164, 0.018956709645863157, 0.024594777714810334, 0.04497092457313556, 0.04084117703314405, 0.031444114283658564, 0.036508273988147266, 0.05823188643262256, 0.047364002020913176, 0.06681798215140589, 0.028313291950325947, 0.06705266408971511, 0.043936686124652624, 0.086866203637328, 0.026101430266862735, 0.012983632404939272, 0.16100144275696948, 0.0364921990694711, 0.014545753074344248, 0.04042263171868399, 0.06984397798078135, 0.02592436496342998, 0.04142215249885339, 0.054550277345697396, 0.0028899223570988397, 0.04149750275246333, 0.032263174434774555, 0.02423809597530635, 0.014383778416231507, 0.05619470219244249, 0.0237286969422712, 0.06796439251047559, 0.011291278733551735, 0.05486102199938614, 0.05887928411539178, 0.051101123754051514, 0.033812240726547316, 0.024012863432290033, 0.02522471080737887, 0.07749183947453275, 0.04426375060575083, 0.05928676029725466, 0.060377030895324424, 0.027140559468534775, 0.05680806869349908, 0.019237415872339625, 0.0023441040502802934, 0.04322764194512274, 0.031147051122388802, 0.046511007167282514, 0.04990439578250516, 0.008405163825955242, 0.031252079861587845, 0.03928293037461117, 0.041307364517706446, 0.017899804151966237, 0.009010246103571262, 0.03488883354293648, 0.05138401189469732, 0.017121114979090635, 0.07891052155173384, 0.00960826220762101, 0.008964042772277026, 0.019948346962337382, 0.04010977936559357, 0.020509421738097444, 0.012158525605627801, 0.01936155305884313, 0.036208424062351696, 0.06100718106608838, 0.06520474606077187, 0.021211964703979902, 0.03939230438845698, 0.011699953483912395, 0.05428066993772518, 0.03444478061283007, 0.020662328279286157, 0.025059362160391174, 0.027458059521450195, 0.014187482211127644, 0.06625736379646696, 0.019717735704034567, 0.0168849747205968, 0.04836770851397887, 0.026772235287353396, 0.027902515066671185, 0.01574508598423563, 0.06609662203118205, 0.054863497061887756, 0.06369702852680348, 0.07607787745655514, 0.02461317926645279, 0.03128590324195102, 0.002089445351884933, 0.02535999876272399, 0.01186689589303569, 0.0258387099893298, 0.03972590347984806, 0.025045454312930815, 0.10411202354589477, 0.12017686385661364, 0.09350354201160371, 0.13490218698279932, 0.07568672110210173, 0.1459552298183553, 0.13595342432381585, 0.21591121272649616, 0.12184007617179304, 0.12686070520430803, 0.15276862046448514, 0.12202948710182682, 0.1384345575934276, 0.123212618927937, 0.18198603938799351, 0.17475407745223492, 0.14594497333746403, 0.1439357569324784, 0.1636730704922229, 0.1563300535781309, 0.17779035202693194, 0.2592073363484815, 0.11013771349098533, 0.14771207148442045, 0.1262186435633339, 0.19209646561648697, 0.18857331248000264, 0.10768278545583598, 0.11226294984226115, 0.1953594811493531, 0.16618071327684447, 0.09325889302999713, 0.11996170040220022, 0.11340959026711062, 0.16914825013373047, 0.1351394219091162, 0.13650191598571837, 0.12532738357549533, 0.16975577222183347, 0.12845409626606852, 0.16353442246327177, 0.05306761842803098, 0.129333823279012, 0.16154034587088972, 0.23791013227310032, 0.09230287323589437, 0.16991333017358556, 0.0841888836293947, 0.07151891622925177, 0.18568911880720407, 0.2057748707011342, 0.11692849089740776, 0.10375344747444615, 0.1709151256363839, 0.0905264240282122, 0.20551406516460702, 0.08506944926921278, 0.1221329573309049, 0.15617530094459653, 0.09841036269790493, 0.16802440106403083, 0.08697606375790201, 0.1814337182440795, 0.16566057165618986, 0.10230663057882339, 0.18638091918546706, 0.27451246976852417, 0.11820799802080728, 0.16699464147677645, 0.1757054217159748, 0.08161233243299648, 0.11054274800699204, 0.2567108703078702, 0.1376078199245967, 0.13847596943378448, 0.152548395562917, 0.12526911013992503, 0.1410485352971591, 0.11358092990121804, 0.1675637945299968, 0.11152124745422043, 0.08698107325471938, 0.14890606835251674, 0.1584819849813357, 0.11714841893990524, 0.14312599960248917, 0.21051717951195315, 0.11498030871734954, 0.17643131635850295, 0.13366658531595021, 0.2819937339518219, 0.16324252093909308, 0.16404328343924135, 0.27901602967176586, 0.146067546447739, 0.1290575068560429, 0.12904071947559714, 0.15020209568319842, 0.14980172185460106, 0.11021200247341767, 0.14309398335171863, 0.09481504312134348, 0.1254954800242558, 0.05653410858940333, 0.1701175989001058, 0.10433427451062016, 0.08998740959214047, 0.16373284306610003, 0.22340335679473355, 0.13764862320385873, 0.0625147353275679, 0.1389486136031337, 0.12279750604648143, 0.12760065612383187, 0.21664644358679652, 0.09819432350923307, 0.17985891056014225, 0.13789862307021394, 0.16970239696092904, 0.12542843440314755, 0.07273088049259968, 0.2685780788306147, 0.11657316543278284, 0.1332422549603507, 0.07255340329720639, 0.13424547534668818, 0.101970133400755, 0.102364258345915, 0.1317506717168726, 0.16755632852436975, 0.12178152814158238, 0.12886523123597726, 0.11292237031739205, 0.10073654295410961, 0.13282558356877416, 0.2083383675199002, 0.17013297619996592, 0.1729796765721403, 0.1102160694426857, 0.13194977509556338, 0.1440889955847524, 0.12478102929890156, 0.10922271219897084, 0.06669261856586672, 0.1118507313367445, 0.18540218967245892, 0.09700940310722217, 0.12298981877393089, 0.1227227940398734, 0.10201379394857213, 0.13455315493047237, 0.14381098706508055, 0.2080364470020868, 0.17121663055149838, 0.09415699561941437, 0.12312866718275473, 0.1837968351901509, 0.13256400619866326, 0.08130060814437456, 0.12190988258225843, 0.17152278131106868, 0.11194744060048833, 0.09936777030816302, 0.10126869252417237, 0.12559783703181893, 0.1134436103166081, 0.16125175432534888, 0.1090368561563082, 0.11196166014997289, 0.1102813561738003, 0.10007812437834218, 0.18595351633848622, 0.215503268991597, 0.07775940597639419, 0.17533149803057313, 0.08045552458497696], [0.07955728098750114, 0.014990071322245058, 0.04415369010530412, 0.030783476686337963, 0.011103380857093725, 0.028499789950728882, 0.03889628256729338, 0.03330282685055863, 0.026874766699620523, 0.04471601911063772, 0.04607161492458545, 0.011533495326148113, 0.021051315707154572, 0.03597967930545565, 0.011424160275055328, 0.03481365398329217, 0.007154831919251592, 0.12396059246384539, 0.0034993656799997552, 0.034751187413348816, 0.04601794651534874, 0.05459878040710464, 0.05842962797032669, 0.024968475045170635, 0.03603056466090493, 0.03586064623959828, 0.01985897011763882, 0.04126871717744507, 0.025429153938603122, 0.04558364540571347, 0.08313299302244559, 0.033556181224412285, 0.04109873196284752, 0.02389655219303677, 0.044196623348398134, 0.09273879593820311, 0.025822193492786027, 0.023385865533782635, 0.03097162967605982, 0.09281315913540311, 0.022970424251980148, 0.038727670325897634, 0.08770316810114309, 0.08049372292589396, 0.01967175594472792, 0.024544912812416442, 0.0693806329218205, 0.030431611485255416, 0.020061086615896784, 0.0990855909185484, 0.04601246204401832, 0.04492547544941772, 0.03182080246915575, 0.03450389267527498, 0.020234923576936126, 0.016915002015593927, 0.06869571967399679, 0.08286098105600104, 0.08009829180082306, 0.016985595102596562, 0.03609408136981074, 0.03355803288286552, 0.03541529084031936, 0.04852828700677492, 0.01836913277657004, 0.04375462987809442, 0.0545799335668562, 0.025500216434011236, 0.04289449185307603, 0.020567053215927444, 0.026318256132071838, 0.055580994303454645, 0.06272048092796467, 0.06188488572661299, 0.06162492623843718, 0.01893073262181133, 0.00704537441379216, 0.04274837781849783, 0.005565337132793502, 0.02257146978081437, 0.07692466795560904, 0.07881156358052976, 0.0527540944312932, 0.035551493492675945, 0.02794090636598412, 0.014577687688870355, 0.027071311524196062, 0.027980377490166575, 0.017321377963526174, 0.045191457465989515, 0.02404002232651692, 0.023381529535981826, 0.06895879618241452, 0.006296982492131065, 0.018074704239552375, 0.050676385217229836, 0.0063340541601064615, 0.029950360258226283, 0.03896984795574099, 0.06549515586812049, 0.04328047172748484, 0.059599961459753104, 0.011765452654799446, 0.039723283698549494, 0.011612400467129191, 0.01665366584347794, 0.040116158124874346, 0.05191702606680337, 0.024629536201246083, 0.00534562060238386, 0.04112176080525387, 0.022050194529583678, 0.04351765470346436, 0.07938763345009647, 0.01281849527003942, 0.02728372346609831, 0.03343250973557588, 0.10171550995437428, 0.06170051397930365, 0.02487961213773815, 0.04906818088784348, 0.1024278900877107, 0.06621537308092229, 0.030881456877978053, 0.042260115151293576, 0.02735058169491822, 0.06312537443591282, 0.04491889259952586, 0.05675180276739411, 0.020248323053237982, 0.040493569904356264, 0.06108432360633742, 0.06248902733204886, 0.028515252597571816, 0.06585272261872888, 0.04020302651042584, 0.027303984097670764, 0.0082190879220434, 0.035353707426111214, 0.015225696715788217, 0.05863043828867376, 0.009747404692461714, 0.011030919413315132, 0.015752169783809222, 0.02406584535492584, 0.03686705786094535, 0.018084493167407345, 0.023577486208523624, 0.02553786187490914, 0.08774493617238477, 0.10164431572775356, 0.02489839960617246, 0.03159825093462132, 0.04257058149960358, 0.06288020595093258, 0.014958278643462108, 0.02408559204923222, 0.01631817242014222, 0.0204255293647293, 0.01807166885555489, 0.011579155961953802, 0.03823988634394482, 0.000916450509294009, 0.05526143293536734, 0.03190801966411527, 0.07598766940645874, 0.029112933807482477, 0.02943237643194152, 0.04273128244676627, 0.029127667294233106, 0.009063087018148508, 0.027653099641611334, 0.07002689511864446, 0.0345280570036266, 0.04047924645419698, 0.023702296894043684, 0.04513708030572161, 0.025878902852127794, 0.05349140330508817, 0.018579477837192826, 0.028825225417676847, 0.00650334593046864, 0.05231790084508248, 0.008206656020774972, 0.012740675520035438, 0.03995530874817632, 0.06899523563333787, 0.0308843234233791, 0.01536351817776449, 0.10980137216392905, 0.053159140079515055, 0.030483710252156015, 0.02094261519232532, 0.047704347234684974, 0.028186503441247623, 0.034525849114288576, 0.0027531294654181693, 0.03621938929427415, 0.03968087366956752, 0.01205797387228813, 0.028994260683248285, 0.03200349325197749, 0.034490801190258935, 0.027629621799860615, 0.014501451496471418, 0.056983022586791776, 0.03514105985232163, 0.037117094834684394, 0.017476210377935786, 0.03159839936415665, 0.06680402235360816, 0.05530615846510045, 0.012612203263415722, 0.03450390009675175, 0.03224339248845354, 0.10083558998303488, 0.04940687482303474, 0.05637078786094207, 0.05704145187337417, 0.0959929873351939, 0.014877383619023021, 0.017379374949086923, 0.023130377485358622, 0.03787967383686919, 0.01002179709757911, 0.032745741118560545, 0.06630352538195439, 0.042841246468015015, 0.022427001458709128, 0.05789205701148603, 0.031547888793284073, 0.051880189566873014, 0.03418452797632199, 0.033983480170718394, 0.050033421866828576, 0.0626858152099885, 0.008019950219022576, 0.009423047195014078, 0.048333473241655156, 0.03809211732004769, 0.003724736911863147, 0.03335712979605887, 0.04377077901153825, 0.005285520092002116, 0.0656880771566648, 0.06167232721054461, 0.004134789041927434, 0.05102482726215385, 0.039373171821353026, 0.10744270068244077, 0.03828885324764997, 0.02896886995586101, 0.027082104206783697, 0.016552397937630303, 0.08389134920435026, 0.0033768851062632166, 0.01567562281707069, 0.04061392028233968, 0.07546577631728724, 0.017621259430598002, 0.05391172977397218, 0.054430528107332066, 0.010852721406990895, 0.06808965961681679, 0.020129390177316964, 0.027939626161241904, 0.09555416283546947, 0.039572790992679074, 0.043401861112215556, 0.018200604026787914, 0.030405790312215686, 0.026997367640433367, 0.01907960744574666, 0.03090502377744997, 0.07509010116336867, 0.03608903476560954, 0.003833155874417571, 0.07077216723700985, 0.02275954670039937, 0.04500874441873748, 0.038124037091620266, 0.06203554541571066, 0.03413473728869576, 0.10337059575249441, 0.0399270292109577, 0.04335961435572244, 0.02480660336004803, 0.0383111770497635, 0.1045847345085349, 0.08657225378556177, 0.06530898812343366, 0.013368643776630051, 0.07927676400868222, 0.033292091684415936, 0.029930580167274456, 0.0231317764337291, 0.0399237526289653, 0.06464664358645678, 0.06433393224142492, 0.025133118651865516, 0.028537157086248044, 0.041947273930418305, 0.023745564103592187, 0.10435135875013657, 0.03701646703120787, 0.053155570349190384, 0.013891115740989335, 0.016387804425903596, 0.01994995000131894, 0.04623747379810084, 0.018815868570527527, 0.03530593166942708, 0.031305154552683234, 0.015473501680389745, 0.0759714312152937, 0.028079059011361096, 0.052348596072988585, 0.03405142007977702, 0.01974321548914304, 0.027111090639664326, 0.05664400210662279, 0.08149966699420474, 0.04455600093933754, 0.03148419396893587, 0.04638934689864982, 0.028772872465196997, 0.02143548659660155, 0.08581906295148656, 0.0568725576158613, 0.01612765383470105, 0.03179638209985569, 0.044189083128003404, 0.07229955910588615, 0.03420502238441259, 0.02301385102327913, 0.04195173423795495, 0.037751152412965894, 0.013623579852719558, 0.014584544205717975, 0.022379383408406284, 0.05651398896588944, 0.03381751368578989, 0.030490411845676135, 0.05243890802375972, 0.06508180187665857, 0.04763687487866264, 0.04283713496988639, 0.06545120588270947, 0.07417143366183154, 0.06759428346413188, 0.03130430108285509, 0.049737368026399054, 0.17538197891553864, 0.08841002665576525, 0.15488075790926814, 0.09179688437143341, 0.13997769041452557, 0.10144710482563823, 0.08723398976144381, 0.18077457236358896, 0.12393886980134994, 0.15643721970263869, 0.22202726657269523, 0.14327886718092486, 0.1330956065794453, 0.16549862019019201, 0.15124512487091124, 0.1482489559566602, 0.07245866072480567, 0.20056514244060963, 0.14882732648402452, 0.12464082275982946, 0.11191952842636965, 0.1663832156918943, 0.2070683747297153, 0.08350882402737625, 0.11413285770686343, 0.11551618386874907, 0.0892513178405352, 0.10781269840663299, 0.08616983905085362, 0.1318136800546199, 0.13384565070737153, 0.18113020953023806, 0.11726507713319734, 0.17282204440562055, 0.2132444831659086, 0.1568102082819678, 0.05726834868255537, 0.13019967213040218, 0.1378994542756118, 0.1674563463893719, 0.13454269064823166, 0.18131913064280525, 0.16938287270022556, 0.21035988873336464, 0.12792000226909295, 0.18232766480650753, 0.1274809625465423, 0.14601369621232152, 0.10575632593827322, 0.2966984105296433, 0.18577397597255185, 0.12215720329550095, 0.18419107887893915, 0.1401589674060233, 0.2266882359981537, 0.14801056327996776, 0.2085817771148868, 0.3649849025532603, 0.17741047631716356, 0.14955840131733567, 0.13976537680719048, 0.08885983494110405, 0.13733288389630616, 0.1730402506655082, 0.08658002407173626, 0.17238690837984905, 0.1739844257826917, 0.12002709845546633, 0.1424767094431445, 0.15987232443876565, 0.10754389251815155, 0.14546579826856032, 0.15464117779629305, 0.2293022582307458, 0.15021107567008585, 0.1115258561912924, 0.10283837938914075, 0.14569400867912918, 0.10241448690067045, 0.10422736071632244, 0.1569625415140763, 0.14770738111110404, 0.29254930035676807, 0.14808123058173805, 0.0824583659414202, 0.11137842855532654, 0.16949674783973023, 0.14144178450806066, 0.0918230450770352, 0.08987992434413172, 0.1429885093239136, 0.15074607508722693, 0.1758846058510244, 0.08058592735324055, 0.15038908721180633, 0.1351536117726937, 0.09748437762027606, 0.16433108830824494, 0.22971493686782196, 0.16901047783903778, 0.190433906391263, 0.16805668448796496, 0.26498326391447335, 0.1101872741128318, 0.07194830061052926, 0.12303130482905544, 0.12839781178627163, 0.16228215215960518, 0.11192299425601959, 0.1331393190775998, 0.0966324885666836, 0.11133615582366474, 0.18444615503540263, 0.21722255798522383, 0.08733215363463387, 0.09143923598458059, 0.13862518564565107, 0.14816380193224177, 0.15692461776779965, 0.14542256074491888, 0.2088552140048705, 0.13334856019355357, 0.14512829919112846, 0.10649750882294029, 0.09247950438293628, 0.16906471399124712, 0.14339004090288654, 0.25537637004163116, 0.12864818272646517, 0.14718845661263913, 0.21429503773106262, 0.19524281553458422, 0.11127811987535097, 0.14855472079943866, 0.13214435137342662, 0.07443530426826328, 0.15718995040515438, 0.05215236851654481, 0.1758739337674342, 0.15034320764243603, 0.18399921886157244, 0.10630423872498795, 0.08342922126757912, 0.1639249108848162, 0.15170053637120873, 0.19856972998240963, 0.11205858463654295, 0.12579397181980312, 0.13429205253487453, 0.256147877080366, 0.15681420103646815, 0.1881135074654594, 0.13791342149488628, 0.0676925438165199, 0.1631214321241714, 0.17939974379260093, 0.12933192338095978, 0.14277999551268294, 0.09744368566316552, 0.2292602972011082, 0.09721094073029235, 0.13197821419453248, 0.11841142812045291, 0.14608889061491936, 0.1916080285445787, 0.1760078320512548, 0.08107256100629456, 0.09914480688166805, 0.1390664221253246, 0.07771405333187431, 0.1478317502187565, 0.12970479321666062, 0.15793306287378073, 0.21480523457285017, 0.10189381835516542, 0.16015331639209762], [0.07548530222265981, 0.043553259238251485, 0.02971620710013667, 0.035821160272462294, 0.06157024850836024, 0.05836653057485819, 0.004608617400663206, 0.04245498828822747, 0.017027003232215066, 0.055388822584063746, 0.041663454394438304, 0.03638232039520517, 0.0861147568502929, 0.0372550637985114, 0.023441778939741198, 0.029720340862695593, 0.014579383496311493, 0.07441587484208867, 0.04357575744506903, 0.06150721790618263, 0.07728253898676485, 0.0029059058988423203, 0.027875961022800766, 0.015837767241464462, 0.049830414791358635, 0.030400934811041225, 0.01793676125089405, 0.04724640130007174, 0.012545339468488237, 0.021815670297655743, 0.02448212526360294, 0.04121994694287423, 0.015245705944835208, 0.06385120970662683, 0.06961803854210302, 0.015214382674457738, 0.011983799922745675, 0.05024169076932594, 0.03925280660041608, 0.023467598257411737, 0.06954142663744278, 0.08119747188175097, 0.040328148897970095, 0.01777643323293887, 0.04367890112916939, 0.03654575615655631, 0.0806533069408033, 0.039432948105968535, 0.02953501360025257, 0.05449966658488847, 0.04703854428953491, 0.018642784889379982, 0.060995599851594307, 0.03891507374646608, 0.005851641008121078, 0.02863441925001098, 0.012919117507408373, 0.025005107454489917, 0.020947350094502326, 0.0136882181323017, 0.05042598088039085, 0.012175880729046185, 0.057601643493399024, 0.021788144040328916, 0.05986307507555466, 0.020298059935157653, 0.005856590205439716, 0.028786873081116937, 0.08747953674173914, 0.07318514166399837, 0.029785545957565773, 0.0055474165856139734, 0.046560857226722874, 0.06622988206800073, 0.007736678016954102, 0.05113086532219313, 0.01407484274750459, 0.08897642634110525, 0.07819264952559024, 0.06481995733338408, 0.1002781925490126, 0.036364861371112056, 0.010411425555503229, 0.048513054425711744, 0.019889596696884837, 0.07594351161969826, 0.024849918809195515, 0.028625121994991787, 0.07616936200065538, 0.088818237563828, 0.015043118182802573, 0.11830545685370453, 0.011583140367292799, 0.04210072409478016, 0.034431436797603965, 0.10437559729325585, 0.04900882391666528, 0.02309632774995407, 0.05083655552880373, 0.02491010327503318, 0.03257564087107312, 0.03343158576171845, 0.09376486705150455, 0.02770538023469271, 0.010624729929986643, 0.045919823460280895, 0.019107387888652738, 0.04941738734487444, 0.013749838653893676, 0.037601097574224696, 0.029685350455110893, 0.03730080235982314, 0.022891201842867304, 0.07098078494891524, 0.011593206672841916, 0.02961241774755763, 0.025269597754231654, 0.07033159126876853, 0.06456687013269402, 0.03267387524829246, 0.020590397471096367, 0.07242060339194722, 0.03944837364542764, 0.01746615242154803, 0.023918699735077098, 0.0136615713199717, 0.01597160615347093, 0.01846435960032977, 0.067718504142249, 0.023151886780397035, 0.01499291467553121, 0.048113871744135395, 0.01871031847258564, 0.021042853368271608, 0.07106279968866147, 0.06867528834845871, 0.04939075908623636, 0.04030785115901381, 0.07739621374639682, 0.008390313450945541, 0.06622784116188996, 0.0624418118968606, 0.02713096164370654, 0.008947988262661966, 0.04867486117291264, 0.027201916527701542, 0.04326255999330897, 0.013127607198839542, 0.026199872445431538, 0.0356950730929384, 0.04770231003931258, 0.08255319757154211, 0.10889905417570844, 0.024022578145377338, 0.04112778333364986, 0.03228685265639797, 0.035877288901247084, 0.042970784634235315, 0.11855110031319782, 0.07551877308287658, 0.03036816528037889, 0.020848499734711368, 0.02562493991717929, 0.048962205910356715, 0.048423488333355635, 0.10217644303338602, 0.06404027924872935, 0.027326031449774746, 0.020077933368156664, 0.043759880572906695, 0.043066722064395435, 0.030177672670106404, 0.035256348783150315, 0.01989573982427828, 0.0020851362569374032, 0.041520260710967705, 0.04270371537131723, 0.0534827869705623, 0.016442231681139674, 0.06630961841437966, 0.039509571142843924, 0.010635534672474023, 0.06597326224436983, 0.07923395693069324, 0.028737149186781608, 0.013969389128760668, 0.05235050710325595, 0.0894283942761831, 0.03223149215045851, 0.011606288881012006, 0.04994617498596199, 0.016741404397180304, 0.019351522932993248, 0.016702454631740693, 0.01350050393739366, 0.008348933151864912, 0.050269465646124445, 0.013837396309099859, 0.04183463446679525, 0.04335654557507951, 0.07408124787616543, 0.05456903141748626, 0.03429541226068977, 0.03716921215527691, 0.09391498126205988, 0.03503465442918241, 0.0052107180999882985, 0.0844614150992129, 0.037209462534519844, 0.08465208768029697, 0.04044739718665369, 0.030393570850719698, 0.06712914982927032, 0.03279463380749803, 0.04016300990770105, 0.041924092947738245, 0.07359189054113813, 0.027708508387149777, 0.05085317221528385, 0.0746339549368713, 0.021549194752878975, 0.05614639951090794, 0.04485370976908598, 0.03376539265445899, 0.04154724520049058, 0.011589742698561167, 0.03845107930828817, 0.08478893229039386, 0.019179142436769325, 0.05490440424182452, 0.054470292379846796, 0.020827611988352146, 0.034554963567643426, 0.014817837400187273, 0.016388878684665542, 0.0410771799943177, 0.052002532611368224, 0.04628184309694916, 0.02421373312245123, 0.022035008332750294, 0.01723233322991291, 0.04819128516828641, 0.017829947646532673, 0.0032300152406605775, 0.020655027401517145, 0.046504947531502694, 0.030515485304931644, 0.04593271456542425, 0.04573475038341712, 0.04959223362675402, 0.0429136652383022, 0.04656421173422132, 0.08877331536496058, 0.06677297831629403, 0.0068757830013055354, 0.05210274481214583, 0.054269578540697694, 0.026216127334919292, 0.03721627173945308, 0.01897630419989582, 0.08580861351219937, 0.05649579892633483, 0.04145909289945848, 0.027322244641254656, 0.06942185922525823, 0.07371666783001274, 0.07162698777392507, 0.08505585312377661, 0.02692966521863127, 0.05011540692066774, 0.050044253512169234, 0.07267202076036483, 0.04045132685860153, 0.005643585473080748, 0.027627072522591334, 0.02214983156591188, 0.06936016448889859, 0.04256377229467034, 0.08273563973489217, 0.020500710779742803, 0.05245603679213673, 0.03972250073275063, 0.04090778107638471, 0.031283387361327186, 0.04495045985095203, 0.03187314243405126, 0.07186820803326555, 0.04193978566036094, 0.029220439464552328, 0.02568297215475468, 0.04634223907487467, 0.018148197268601507, 0.03818471137492452, 0.02620915856823558, 0.07275903015397489, 0.08825609780615196, 0.09245353663573042, 0.08918683262891136, 0.020728182753373403, 0.043380364804761484, 0.05491630457981955, 0.06116800075687934, 0.025885780705721118, 0.05773967925051693, 0.04025864676805213, 0.04582200839649886, 0.02264807240862865, 0.08245024684583768, 0.025142434460576624, 0.01792725990526378, 0.018838641371985432, 0.04368967340269592, 0.05851488960615825, 0.03364995900483336, 0.042592326426529326, 0.033528432322782464, 0.03129842327325605, 0.08939850056776777, 0.01797118577087531, 0.03283689911768306, 0.043974854779662564, 0.011920414945052471, 0.010238137783744605, 0.03589793173887301, 0.04554999643005431, 0.034797445478034206, 0.03399482389795594, 0.01380932828396908, 0.05074737164250109, 0.04543352377368137, 0.062318452110048383, 0.01951203834323678, 0.022528785157192033, 0.02519022506021429, 0.011414725722715957, 0.10799047988257371, 0.017465605087636504, 0.021260736793919932, 0.01774113483406836, 0.03735838188731577, 0.0486280168115627, 0.04931672243401408, 0.04468067432753742, 0.021277232881402597, 0.05230012640822679, 0.07045047590509057, 0.008445442963420646, 0.06231106774066575, 0.03786239292821847, 0.057323909568367526, 0.02152520297386218, 0.0346533018455375, 0.23662448016693816, 0.10085843328852206, 0.09535635821521282, 0.1921632737503387, 0.2027162426384166, 0.22160531108966097, 0.10976222387398593, 0.1533553921035491, 0.2458727385965176, 0.16397594095906243, 0.16902999632293358, 0.19145619997289032, 0.14224747486878186, 0.17524420662084594, 0.0821420551801566, 0.1285640973947011, 0.10147132852580398, 0.09634649453801103, 0.12015952728688717, 0.10485800812602974, 0.2460221032379195, 0.07292170150321908, 0.12120289044105448, 0.12610267556738108, 0.14571372012142092, 0.1502578309737146, 0.11765535775339231, 0.10905529852607287, 0.16886801517102867, 0.128128916840069, 0.10089097646414302, 0.1664940480259247, 0.1010652030527126, 0.13484844064805657, 0.14792456320719793, 0.09472211138927378, 0.16133861528942361, 0.15368063090136275, 0.11804822846897878, 0.14823368255747482, 0.20074974425369874, 0.16718049009796232, 0.12735579191939905, 0.15021454892121255, 0.0958866004657466, 0.156311841274146, 0.1468098722398281, 0.1937181325047277, 0.11231827695155516, 0.12649055162910372, 0.13661893783137202, 0.24061681906459853, 0.11732277911505662, 0.19354067015228793, 0.13674382644239813, 0.17846773989731446, 0.11867958834045567, 0.06640134786721319, 0.1325542395352386, 0.12194638882647268, 0.11575235752388835, 0.12965147732757032, 0.14771432761335745, 0.1530169727629982, 0.1434362173313275, 0.08993511786684394, 0.0758364271314349, 0.15425993653479964, 0.23546974291093647, 0.3086092573357746, 0.12229580679559149, 0.10815561516210437, 0.11616940741077997, 0.16081128967925906, 0.138139984337613, 0.1530815099249594, 0.13481801259331405, 0.1984124688897282, 0.25368552014697343, 0.16487668559420854, 0.17792407219531015, 0.08805320947431028, 0.1131758805422578, 0.20265091879991814, 0.10210872947936878, 0.12621560075785965, 0.11209554359083995, 0.12635318009415641, 0.1468549354467541, 0.13492126017808914, 0.14594028296414763, 0.1960614341078326, 0.17674040602287278, 0.13773578102700412, 0.1311916415579617, 0.2614442288177088, 0.19102854479569942, 0.12327884818660095, 0.0796071087825112, 0.11707292767823674, 0.12316445354372263, 0.13549921510275453, 0.14731646224390715, 0.09751863515703008, 0.12983930006157607, 0.1580099345301278, 0.104213868471561, 0.08184573787730187, 0.2875276026315987, 0.11590103196795098, 0.1124160474864766, 0.13180676323827356, 0.1529883110197261, 0.1290597629849799, 0.14311701961560175, 0.07874363480368629, 0.05888965562917292, 0.09831768329604529, 0.19657681114040315, 0.17854772857390344, 0.1362425205297768, 0.2868592244340107, 0.1094036923313979, 0.08578700959333219, 0.13539832754759118, 0.14209638844477013, 0.10376085410825908, 0.19625547603936866, 0.12510092463344336, 0.08217072434490547, 0.07759110914776102, 0.1595724670914933, 0.11812824683147483, 0.1672635364229791, 0.13719583890633658, 0.21909846982453018, 0.08755783332162537, 0.08333538411534391, 0.13620508660096675, 0.12579771224409342, 0.0872231024550274, 0.22945951932342723, 0.13260869833175093, 0.11522033411893062, 0.16177600744413212, 0.11607223801547661, 0.08728076732950285, 0.13661181321367621, 0.23378475598292425, 0.13900564023060724, 0.1204299287928734, 0.1299596467288211, 0.15949166205246001, 0.1999744077329524, 0.07467429066309705, 0.11224271889659576, 0.09923162331688218, 0.14068651566049084, 0.21224947093287483, 0.264839791925624, 0.07404410338494927, 0.11380398238543421, 0.10880634508794174, 0.11986366269411519, 0.1637348617077805, 0.25528383906930685, 0.17649972753133625, 0.10902893744059838, 0.1324692933121696, 0.17404737474862486, 0.13406681071501225, 0.17013149190461263, 0.15078714553965256, 0.14828971470706165, 0.16037040943047032, 0.11739619236323051], [0.017127566097769886, 0.02011406482779421, 0.04618064012902323, 0.031900230824248865, 0.020566121820593253, 0.03768118273001164, 0.030396756519621704, 0.02912441297667101, 0.03945001008105464, 0.009654897839936893, 0.06271293328609318, 0.06544621122884564, 0.03371261111169588, 0.023361803250736557, 0.04141071971389465, 0.028294504481891636, 0.05356639361707494, 0.04714014801720623, 0.02315227269718889, 0.02112864935043035, 0.04474285145988688, 0.03358854628459085, 0.017044634805643, 0.018842808531189803, 0.07895467191701755, 0.04736848459288012, 0.08900894725229591, 0.05807084038679022, 0.020870096232101787, 0.03278795447840821, 0.02663912182470085, 0.028078289033146575, 0.01882026579551166, 0.03253837763622869, 0.056211723349406384, 0.007770867368890322, 0.019518608205544297, 0.04952490227879025, 0.040909521412686445, 0.010234060609946027, 0.017668280052021146, 0.023275537860172335, 0.04334184734034352, 0.025811951854848303, 0.023040987653075717, 0.018893903543357737, 0.032109457097249106, 0.021570861754298676, 0.015838680083106738, 0.0332916352635948, 0.02534977567847818, 0.0906259757175576, 0.053098859134479426, 0.03810635913396254, 0.03234198309655767, 0.038046126428525895, 0.018111713288817555, 0.02276368046295829, 0.03947412616980728, 0.016242202473222278, 0.0501954438368557, 0.05287940235575661, 0.07736807150649838, 0.03278487085481174, 0.04535849635431077, 0.05430960998637602, 0.07674799227970652, 0.036654451105277985, 0.027656598867906723, 0.0648425928375218, 0.03303625853732228, 0.06329197174636647, 0.02282873341755476, 0.005283270920699579, 0.05771673204435501, 0.03824283638095949, 0.034966540115419775, 0.03820555459242314, 0.08758660638704896, 0.03741767577594146, 0.025742779980646446, 0.03454641773714684, 0.023384154883387964, 0.03351898478285875, 0.03090659713052446, 0.019568100178730674, 0.035667858537635766, 0.030590124952141196, 0.03984656184911728, 0.009990701109927613, 0.03209501119272318, 0.039428138989023864, 0.029422973420878407, 0.016923688854149077, 0.03409090233617462, 0.02984280636155745, 0.034932215785374865, 0.06999293444096111, 0.01747888767567929, 0.08227565660490654, 0.04501724200963508, 0.0032924602419370785, 0.032455142063554376, 0.014432304669753648, 0.036797978755203076, 0.048582003655610606, 0.035607726022135466, 0.0245876363987918, 0.034117816321668215, 0.0640691265289206, 0.045305662861210294, 0.01708210213109851, 0.06574527447810397, 0.043870987501577474, 0.032021839142544195, 0.023205779689305928, 0.022804031032137573, 0.028405321972968522, 0.05850931607710663, 0.01397868638377986, 0.050111124728573486, 0.013581255170720397, 0.046091133408481255, 0.04103679602849297, 0.05576011164521333, 0.03411530786252115, 0.029586513082904276, 0.02314179171662545, 0.05917954593314789, 0.06526612909510732, 0.02478492522641318, 0.004642566018446814, 0.016844381098053418, 0.014309108155430295, 0.023595835809828714, 0.024280364996229764, 0.053750461083836854, 0.0372723484179005, 0.02254476730740862, 0.04056271951412782, 0.023065875575412065, 0.009521313113509677, 0.039180309904622845, 0.01775297580024926, 0.042987193519365974, 0.02577374423708534, 0.03107398297288455, 0.03683752038341481, 0.03859120792185422, 0.03949013429519255, 0.02160618798370706, 0.06246360877412371, 0.029381982749328017, 0.051710671905311756, 0.04130345339945052, 0.020643392381316517, 0.04585819551721215, 0.020209918766340706, 0.0135240875351883, 0.023194923924165778, 0.012368832631182158, 0.07990240192157216, 0.02334081902517937, 0.07318290037801489, 0.03333586355438456, 0.07728976750513539, 0.04757250841066707, 0.05232425362919457, 0.05446735718578566, 0.061995217110961676, 0.023076113502611406, 0.020550677727442235, 0.03260376084654126, 0.019383815633773338, 0.014445731976593379, 0.024391826300416142, 0.028729811201628763, 0.03440117943682708, 0.01230071924510412, 0.03548817345290445, 0.041527756402501836, 0.01029464398015989, 0.04321254666137975, 0.05069713566626888, 0.012387994884193176, 0.04121016914723441, 0.07713026512647048, 0.032878229321795516, 0.050206705927848816, 0.017994301815633662, 0.058031469452544115, 0.05813796764414292, 0.03622413903940469, 0.04374423609988298, 0.02152777451556176, 0.052946574141969904, 0.05530734590138309, 0.011389749670343008, 0.012428569953044644, 0.039662772687734105, 0.022368013706000056, 0.06550219884957187, 0.03324057921417989, 0.004422570718816132, 0.014430342616833514, 0.06539645764860325, 0.02662874474481214, 0.024878528602130245, 0.056602234035381116, 0.027091601841675583, 0.0914289423963055, 0.07191740500275046, 0.03216450961190276, 0.04186823520285543, 0.05887968116439879, 0.021621925225190353, 0.01917225159559166, 0.049388254337827675, 0.03318890347145498, 0.016665692346577998, 0.049041033125831746, 0.03815951175056398, 0.026203022862318903, 0.05885593986022286, 0.01433920409908751, 0.060339771371218376, 0.010428815003251657, 0.04971818721969612, 0.01237846199728665, 0.023630514515389223, 0.05689550482202321, 0.02856335118849529, 0.06368512447807007, 0.06672255680314265, 0.04477617017982993, 0.015796192128618713, 0.08665831323014572, 0.1127769761660602, 0.006778635406590183, 0.08087036287179217, 0.017128519757534377, 0.009220334195561009, 0.01610925970453536, 0.0042642933476599865, 0.01904390457639238, 0.052685122936964035, 0.05625438199786004, 0.0011312510650896002, 0.03255142459238414, 0.017345744527119678, 0.11755833678762428, 0.014556971564161358, 0.03241096572310198, 0.03662975243059918, 0.07056787624605931, 0.005171704788153875, 0.0840176033671014, 0.040911725591286086, 0.028679391543846577, 0.01666169959207764, 0.005886608687433181, 0.03628361846494954, 0.07949050253955647, 0.022134214923426043, 0.06492273736512288, 0.0182051886440604, 0.014386197817657376, 0.03666415468615014, 0.018829989785444923, 0.048132232477655634, 0.042390514208818786, 0.08840210051857866, 0.05776216261438094, 0.020370254205772653, 0.03145201444567647, 0.008440131969109643, 0.060088806712883525, 0.10343816087697633, 0.01477505908042076, 0.046616815161542036, 0.02880042840843089, 0.016320202194037847, 0.026858808669203427, 0.08190890948753804, 0.02893694461818086, 0.08217850947403349, 0.041310782107757404, 0.025203960358339828, 0.0752391541027464, 0.03628238649980631, 0.04493747226661071, 0.022619666706304997, 0.015595667537127156, 0.024129068915499374, 0.05142494504980277, 0.02048763784841867, 0.021578329615294933, 0.079945594916353, 0.016221118057728745, 0.03252337141020689, 0.06448763102525845, 0.022188167204149067, 0.025118648627540097, 0.03167781658703461, 0.04906622532871552, 0.017764506919775158, 0.009066006441571517, 0.01715590500680264, 0.037186949484748766, 0.04323163098888472, 0.027558004549064208, 0.04772294545546174, 0.05145363276824355, 0.038427441904786974, 0.014175475189404096, 0.038007234179531224, 0.06383573592756875, 0.01903226955619175, 0.019607120448199566, 0.040323718276340514, 0.05417499181930907, 0.050981983076781034, 0.03976309621066321, 0.02726006379816681, 0.029391313400992658, 0.04386150285426993, 0.04204030956316274, 0.058842748185270466, 0.057445139391347766, 0.06639602666837163, 0.03948775200115051, 0.012332373698882293, 0.07727858333964832, 0.016613999905530363, 0.03926690740627237, 0.05052902066381648, 0.020972744532627985, 0.0793236677418463, 0.05564461862377357, 0.03979922395956237, 0.036391608373378403, 0.03216980483557563, 0.03209777940355707, 0.08692460323800333, 0.07753643512842245, 0.038703825121046975, 0.014127849717624485, 0.01782576749974396, 0.014351391091622645, 0.008249225611507427, 0.02012713590374915, 0.06595026308787055, 0.10021348469308577, 0.11613179536652751, 0.20313408662332222, 0.13660415424965322, 0.12717599922325462, 0.16405435628257692, 0.07731972800684161, 0.219159459520597, 0.1475975729408674, 0.11439853915362619, 0.10975255368975922, 0.16262343619018793, 0.15084515180205926, 0.13983405515318736, 0.1802996126934886, 0.18860819342080504, 0.10088443814311177, 0.11775414503063075, 0.1584425027249381, 0.17310647992417216, 0.2054357240558602, 0.16249497042736039, 0.1340511068701744, 0.1727073677466251, 0.20583260979037732, 0.23854521772591397, 0.18778702185954899, 0.09950403604307212, 0.1475643989397213, 0.16802478698082268, 0.15114754729438573, 0.07710497273365036, 0.1442662946647033, 0.07007347230683081, 0.2130994081380777, 0.09849643698544241, 0.13221202039858326, 0.10856657201657072, 0.18948921177070588, 0.152848327124957, 0.13244150730315596, 0.1594389695674181, 0.1503877216600813, 0.12823531113099307, 0.25474198220763355, 0.0865549394802656, 0.14606585435103625, 0.08646018206491135, 0.1050789158034604, 0.09786820155568421, 0.14305619319202378, 0.22789011447457597, 0.1257311415974982, 0.14229330990929157, 0.14787434949539602, 0.12265638666576706, 0.1192843570606783, 0.23316889215493575, 0.14196474628988653, 0.10011174366809428, 0.28674279630649835, 0.2180578897241503, 0.1128113227605354, 0.18808441527653486, 0.17775162676116452, 0.13760342641035095, 0.24954264401458204, 0.1766269761719741, 0.11352239671396092, 0.15835080295801163, 0.15255183912813663, 0.1561408504494466, 0.16584395634708926, 0.0486585821636254, 0.2310625879908912, 0.11271348543232307, 0.12211565786856227, 0.12083169785910286, 0.14199026132700965, 0.11709864309523255, 0.17869789473479614, 0.10662010419764556, 0.06298415115452372, 0.08930005467846058, 0.0767513838945888, 0.08764643833274022, 0.14750205853488296, 0.12837330606998876, 0.1286093980888836, 0.09882051061140373, 0.17253680736757815, 0.13946715218480676, 0.10308671684470028, 0.15006469446234405, 0.1540766705875285, 0.10825187913724221, 0.1274077274138108, 0.11823340915725566, 0.1118036569096148, 0.136196180828847, 0.11590698399231769, 0.12970507523277774, 0.0753161073953379, 0.1295996902626939, 0.1969842056860216, 0.2617857651785016, 0.09631004024413414, 0.20517398341326043, 0.14750247413758188, 0.18562768382253125, 0.09838165642577223, 0.09441732618142851, 0.2507503260858357, 0.11152532184496522, 0.14633893501013517, 0.09226020716596395, 0.16787371539976448, 0.052579871553462, 0.15999212191672996, 0.11177793407114223, 0.13432869978714734, 0.1968514354666695, 0.08904563161195256, 0.15820746455574408, 0.17131717671873048, 0.1351752082700841, 0.15581062441924587, 0.1359639925067313, 0.18118839390808716, 0.15817909967154264, 0.163577570929192, 0.11541586776729673, 0.10712736955611035, 0.14406153612071648, 0.0684575570630841, 0.2452516055200249, 0.19115232018521056, 0.11623487225733697, 0.13600228732684627, 0.19940708036301658, 0.23590621480252594, 0.1706333173206076, 0.09123432901105843, 0.16496268566697836, 0.1874954320373945, 0.13392301218118519, 0.14427438407437876, 0.2335996346664615, 0.1218055811477825, 0.12872505438281223, 0.10677202924853191, 0.14260058873333037, 0.1690874682390131, 0.16423337714513764, 0.11288893656455912, 0.10110062576131895, 0.15103952027857304, 0.17264437425183132, 0.1092045741097536, 0.12352596851997077, 0.15233131736749783, 0.16444309323560447, 0.17438221693737432, 0.1746686117257923, 0.16271313215838745, 0.18793139926856384, 0.05731340446800459, 0.20863406884018332, 0.2214763851952739, 0.17875414952868596, 0.10273439707816578, 0.16719913284759969, 0.06063829285267275, 0.11232327902689576, 0.10171349873417057, 0.19617082667537034], [0.029178454315115232, 0.037077044835314155, 0.07027585597825237, 0.013916955467720982, 0.003281210442764859, 0.0357502480619587, 0.039856094736023806, 0.028991273538849782, 0.0547136314708041, 0.04234723586705513, 0.01000999880488962, 0.037187981070019305, 0.03376249456778169, 0.04826696196687408, 0.03918366441212129, 0.016404165071435273, 0.03674501538625918, 0.013174038740544347, 0.047614183713449165, 0.04860208246100228, 0.009571553728164872, 0.004488992008191417, 0.08800381212495267, 0.02915618988481583, 0.0399529227433959, 0.05425252027634997, 0.037187684210948646, 0.05928658960328903, 0.00457321649264486, 0.02372384329646593, 0.03055089502595365, 0.06471687302109785, 0.011977260674029822, 0.06152989051770419, 0.01675914172665216, 0.04013854129880201, 0.05571322646574117, 0.019506314529280644, 0.005655778031723457, 0.02497980764019303, 0.03568180349247996, 0.030024836632946972, 0.01794143121514935, 0.07583838640130125, 0.03645655371656176, 0.06397864388418384, 0.034957118550664745, 0.04864938324317336, 0.06029024414601736, 0.05130468744027894, 0.026964672324538697, 0.008148132110363804, 0.04346817200712394, 0.03138135085464455, 0.0396698119584471, 0.020805379099329002, 0.07202158027212135, 0.04859480199229438, 0.033069447381421924, 0.08787315702647902, 0.023604008711117785, 0.04416096686327364, 0.06985876898397692, 0.019727246326510794, 0.05303394718794152, 0.04250564357789699, 0.06702108570607379, 0.08574959050747566, 0.03400318790227175, 0.011643104971881257, 0.009519074610579992, 0.0693994686298538, 0.04341598418250214, 0.027034547383664176, 0.05921882409893442, 0.03038249800738413, 0.03230877569876611, 0.027692769290297292, 0.05333208275260404, 0.049464005351183005, 0.033327321434626356, 0.040210603838204406, 0.04921122614177875, 0.020030927589687053, 0.03989578479377087, 0.035749357484746724, 0.03332089814648498, 0.04869719239650294, 0.01590219122590497, 0.09448630880797282, 0.04919064638670534, 0.016237582603935152, 0.09020768644404598, 0.02323403510672506, 0.06984776293393224, 0.06567445874679834, 0.031654134654672816, 0.022499824699480087, 0.08313877435284667, 0.056776182318571955, 0.0151305552390113, 0.047316664131358266, 0.02138132280379068, 0.03304887504782528, 0.02990689637954347, 0.05703712515241932, 0.05350602361431811, 0.05572053290961776, 0.039067329053068534, 0.0217601947588264, 0.08500779164023697, 0.060560771817108616, 0.05611976383079309, 0.050191992850159295, 0.024155420724127907, 0.04281115237972699, 0.03123343711195048, 0.012771384663210483, 0.06509846309199929, 0.03939049725886434, 0.006344357952912105, 0.042149865403189324, 0.02637470945046516, 0.012239133047842188, 0.03897379989211913, 0.020424503345566336, 0.09681645213277079, 0.07141184658394195, 0.06280057350522839, 0.05348062732082326, 0.02828072651027469, 0.07322975958231837, 0.03190093957528006, 0.03319888906844426, 0.03920457813364919, 0.09025758103234693, 0.002530143310650601, 0.017852238052000757, 0.09562910490785725, 0.006267060025493265, 0.028976545618206728, 0.04230954218655825, 0.026827239562408067, 0.040907250440795906, 0.036268601106712595, 0.03650619226391427, 0.07888262422056869, 0.03469530369329732, 0.09702970084617846, 0.0495528886676766, 0.07767840797896497, 0.026521892177697737, 0.026731324396678247, 0.039231685077538714, 0.006279852332227165, 0.07139324836316518, 0.025386964698554948, 0.010444371346238768, 0.06898656734847464, 0.04980738594895229, 0.05727483505324926, 0.02743568562436849, 0.07232861418742687, 0.03345149758388288, 0.010972366744681494, 0.07414179228362627, 0.02481010258634342, 0.07111116545274854, 0.014246338232624112, 0.10908526644925587, 0.03170129442878533, 0.04910886171273887, 0.06894960097270086, 0.048201753161265515, 0.0649196797166951, 0.02569884483818896, 0.025186206330545247, 0.058760087777045555, 0.03381680122402031, 0.08970138587756082, 0.06390680398908444, 0.04120141180464998, 0.032406690952484496, 0.1120182934391778, 0.04470297586522065, 0.010695355485950131, 0.03554474365955684, 0.05362725343729835, 0.009911602082866011, 0.05386015422118362, 0.048703070206101984, 0.04842082773393486, 0.02192663807363715, 0.02913732449087547, 0.009309006927651353, 0.024193027202272788, 0.027142464932694566, 0.02695814699109178, 0.08222976219258271, 0.1083723668125458, 0.02013194687606301, 0.02575912578322459, 0.025188813124259468, 0.042478143295738846, 0.0377304353605723, 0.03986236217315309, 0.01715056896500755, 0.1139607462391723, 0.03234278461604845, 0.041640043345978484, 0.03344862176163588, 0.03138550688163377, 0.031847156133153476, 0.015365793788078008, 0.03711929530254565, 0.031066860210557934, 0.04845019451749977, 0.08477449009660631, 0.01455343244742835, 0.020108869794057682, 0.04293290541681927, 0.04913556047540624, 0.011386328369553667, 0.04071949078934267, 0.04673247145547066, 0.05026745071518235, 0.04091450864507351, 0.03772421245230362, 0.05267029111564625, 0.012568866477522533, 0.05433323996840045, 0.03662190050818026, 0.052899833681294695, 0.059592996403807774, 0.022194340017449576, 0.022395827545551583, 0.022400760972232092, 0.10427224580780603, 0.037285580910975114, 0.03486037589027546, 0.028098603470425587, 0.015882231164141558, 0.09748246287927032, 0.05927192476519849, 0.024581227953603957, 0.0024126687549141934, 0.023818617410142906, 0.02350753693463048, 0.04286128816602286, 0.013545109795813914, 0.029676171943719964, 0.019908424983441364, 0.016027922174544074, 0.030472932412521914, 0.04169888452452142, 0.006262335791689111, 0.0797597314522136, 0.039580654047313146, 0.0243245988531271, 0.008101348976197187, 0.057222498799092136, 0.04485307894356083, 0.08987631008494645, 0.043597372496151365, 0.026975479850079864, 0.036944189268979244, 0.05114367108035367, 0.06681006343569607, 0.0419264270021813, 0.019316276484460104, 0.03517554374411702, 0.031025253556435928, 0.02070671984256478, 0.030804627895122394, 0.009137863962678239, 0.022007172228768468, 0.043526579029276036, 0.015380041168100433, 0.06555167041369714, 0.06529111720738001, 0.045815818884875625, 0.03459521394688636, 0.038223930168896914, 0.015905571708572097, 0.025397217468707822, 0.06369769645971246, 0.03672731887490954, 0.052648779965238646, 0.021561622015724424, 0.00685352831169439, 0.023659033395233564, 0.11871557508129627, 0.041060782241402194, 0.035734128614421934, 0.023179750714916736, 0.04211393803416286, 0.03153827055939473, 0.02847722495062044, 0.009706278578960337, 0.07140117450035177, 0.0185983840492554, 0.024412819802819286, 0.06573244274477474, 0.10480211698450148, 0.010057879389933078, 0.031093208308448084, 0.02128175627149176, 0.04420426004799083, 0.07159077838878147, 0.037012986358604394, 0.04496598558034748, 0.03167303715599701, 0.05685966279997956, 0.053441994823515415, 0.06426290128729306, 0.08683173829922453, 0.021041680774942506, 0.011413015072321286, 0.02713765024964232, 0.04599227562721353, 0.06627534603467211, 0.02423167825327255, 0.03534069015586283, 0.058564988285070285, 0.009042367182701128, 0.0385937349346932, 0.07404371004668064, 0.05581196179264225, 0.014088129046285758, 0.059194592977291904, 0.0451553408493055, 0.05335601330443751, 0.014734823544131359, 0.035331676772329956, 0.009499142379354453, 0.08688733258168213, 0.02328667378606042, 0.06491349020507187, 0.09697352768853307, 0.10289153942721896, 0.022411126919905655, 0.024441657806164585, 0.03716247345437296, 0.03720194457855541, 0.05161757319001481, 0.027314695144013967, 0.05356791501981206, 0.0464141383417882, 0.04546271615254227, 0.023394377967633773, 0.037436077327583916, 0.013561803480115486, 0.12620329594938084, 0.1954744101385586, 0.16874498192919418, 0.15901674691122025, 0.13095920090563595, 0.08702954291948117, 0.09438398890779354, 0.1928945118561387, 0.1603463341598399, 0.09974389817216434, 0.06422221675165929, 0.1275569139397703, 0.11134641972603276, 0.09622962854336947, 0.16894821164896712, 0.08876434279954992, 0.12969839590368792, 0.10951153381029144, 0.10017850727308542, 0.1289951812941581, 0.15439104434335604, 0.10626455608871765, 0.15657368581742048, 0.20716736238682643, 0.09172519290586933, 0.11003947540302761, 0.2529225032776594, 0.14615028107073158, 0.11433524137828499, 0.14888859819620848, 0.1289589496445842, 0.24515135621186346, 0.08544427837477997, 0.11694333385094069, 0.10937805855064653, 0.15699731855420396, 0.10416633391287178, 0.13993874250445515, 0.13378976698732004, 0.16864084376720712, 0.08203785022487864, 0.16519037657417357, 0.09483463582000695, 0.1936708576977253, 0.2164088375866413, 0.12152810697443783, 0.10284785661497153, 0.1563396569690667, 0.13116155489115044, 0.09607380721718073, 0.16656636289553717, 0.3024249110603705, 0.18085622345097363, 0.16210172121645883, 0.10265077187796123, 0.10425168831716292, 0.16040570597397164, 0.1739989867201075, 0.0667366650304757, 0.18879885115893558, 0.1358738512499258, 0.2614329184871167, 0.07349178224103525, 0.10452052389155142, 0.1961353817023337, 0.17303748987615108, 0.26231565861962736, 0.15210796060273424, 0.13019263657042757, 0.16249884443823248, 0.1517011152463965, 0.1350769033888355, 0.1375879006809555, 0.12339707973296754, 0.09494896366959438, 0.1193640340352431, 0.0892946295789443, 0.10023977898526937, 0.11516925209434703, 0.08375446006539278, 0.17269852134631947, 0.19898251252016053, 0.10186086699832231, 0.07388366590021178, 0.12421275197993964, 0.11052173780626617, 0.13510017713997513, 0.10350435302825645, 0.1329641870688647, 0.12785216997144744, 0.14287451544078067, 0.19697115872986615, 0.2677203342318535, 0.14069421915337443, 0.2865152241429314, 0.1001319449278526, 0.1355632921331562, 0.1072173030115664, 0.1844520031590946, 0.12708009890047833, 0.13442461495287716, 0.13015639007790014, 0.10478183408849873, 0.10619448992656544, 0.07998072076588869, 0.16965809074463323, 0.12483876838814467, 0.1891008162056096, 0.10337421743315645, 0.10088745868415572, 0.23813020874513313, 0.18926407385151833, 0.15088214044226333, 0.18527783540776, 0.13556020479882136, 0.15289184666471556, 0.13264639943372458, 0.1357852091314271, 0.10973797048791312, 0.12512633576989174, 0.15775934094563127, 0.20040997420437634, 0.0653324177255854, 0.11448468765593134, 0.1452339068055153, 0.15256026992574334, 0.16607992962235585, 0.20715910970466211, 0.12123800144763663, 0.18588710896437988, 0.13050337380263954, 0.119860649574548, 0.1463487313594669, 0.10917085091932677, 0.22887899656780064, 0.09124395466642454, 0.08465554608847015, 0.10549687111051753, 0.34246686554979533, 0.0870233608293347, 0.14165099593810737, 0.1824857125757262, 0.10485986349522136, 0.1281964374356903, 0.15484921663301066, 0.12641350185731426, 0.1489371494972147, 0.1692347548669204, 0.17508091928903013, 0.13506859133485705, 0.23307478782953694, 0.18837162642739713, 0.14482985192444175, 0.10844119358807802, 0.0991504843113944, 0.18078010878525674, 0.21911426272708923, 0.11608604938373901, 0.15653708309400827, 0.2573541342280805, 0.10390563227701932, 0.20469598093768582, 0.18464616383425891, 0.19105463870801032, 0.1607823310769163, 0.15088899788679555, 0.17704625992337242, 0.2156428075977601, 0.10228819563053548, 0.12532036285847425, 0.14835043722996488, 0.16528452542843297, 0.12436887758667581, 0.16187354049179703, 0.1033859804738313, 0.1065801469667349], [0.02517599623388378, 0.007413164248646353, 0.039506220346083865, 0.07101002556737512, 0.011664111461868742, 0.04027674403914716, 0.02892748780141119, 0.01893772179755615, 0.012749048801197205, 0.015090315991983516, 0.048858360896701925, 0.017121196615335066, 0.030049281122046523, 0.011649794505501632, 0.02889213374146493, 0.07395913489744999, 0.07200063686468638, 0.030368974221346434, 0.031152253577602096, 0.036028850299771875, 0.04664134685299359, 0.015344421790359775, 0.02780068498395849, 0.0370674080477329, 0.0575306719110813, 0.03117456624750048, 0.014390577416634187, 0.04973293740476947, 0.028123734446126036, 0.02789878948533442, 0.05330277534085326, 0.03579479547624942, 0.09314070601249114, 0.012521876469691051, 0.08248794052633457, 0.05284971644869074, 0.06556485837791115, 0.01999755135329906, 0.0666030339198187, 0.04441937155206688, 0.02083255098114023, 0.0060569301876967074, 0.06390529000782408, 0.06566177544300444, 0.03471393902145792, 0.05793222204374615, 0.03563273639883846, 0.026155089399253484, 0.02507500848878408, 0.006419890032702824, 0.025906319642672315, 0.028594580762728583, 0.03989417804405093, 0.05694846076949034, 0.04628145346941892, 0.0365967936522793, 0.020269737724447623, 0.06041175969585311, 0.06556114763952792, 0.06987823551753536, 0.013013219977437984, 0.059985503467032686, 0.09542963045532815, 0.010767044168460416, 0.019860343090840615, 0.015069397632032633, 0.04359226280939765, 0.10258377820719033, 0.0090252653171774, 0.029662113811355084, 0.023620144856977277, 0.05700648558558896, 0.05952788036665879, 0.050151668256148696, 0.05697228742064908, 0.05564926817896776, 0.01188795433336054, 0.010742464237409877, 0.036781302696908824, 0.042181102398899384, 0.037939802641631104, 0.04209210033877753, 0.0335895964235533, 0.08720644866116345, 0.07402671486488543, 0.025990032045228872, 0.043812899602926336, 0.03522858132782858, 0.02085154254018562, 0.03454285913903732, 0.03253497488913126, 0.017742743439157493, 0.05390749211073853, 0.01847133578849025, 0.019043809952563606, 0.01625647953915177, 0.044574799539987, 0.033985224217758514, 0.054238226512097754, 0.04478340983041562, 0.02896875492297113, 0.04459688214410562, 0.04828981640457641, 0.04935091688821558, 0.07867528300266713, 0.057765060701058246, 0.03737070153874811, 0.029803292563883588, 0.019238015156588517, 0.04622512075002305, 0.04710659552074503, 0.009265639528166503, 0.06982273029279895, 0.002714403271966148, 0.07216522295493633, 0.02078074907331029, 0.09205032780300826, 0.03193265525624156, 0.03392250160686672, 0.03838776668999344, 0.02469934075634228, 0.03784665197599679, 0.006382334113368415, 0.009860927311819978, 0.06692079929052852, 0.03213312418665737, 0.057283354908577166, 0.027004419898730703, 0.03685398492962122, 0.036383990227477625, 0.054390314835472964, 0.032785212242743, 0.00631840272944828, 0.041474930330878124, 0.08558879679185338, 0.02776186138362391, 0.022073564759921283, 0.02862758221453987, 0.07849595043808222, 0.08936612066463567, 0.03707102972839493, 0.03009105104865739, 0.05380136128223967, 0.03250475463573821, 0.030297848643385805, 0.022696573614666704, 0.09181656612781808, 0.014934975206415402, 0.033077492262236774, 0.04027190152555704, 0.08671343995956704, 0.05371449289668817, 0.028125524877395947, 0.00825835866635316, 0.06372553441906348, 0.05389764752180781, 0.0116059140964353, 0.014142754826025339, 0.01932025254063774, 0.056476321260561235, 0.020604008459486067, 0.048193604379775934, 0.02872884455427993, 0.03271837813372258, 0.0901251744653564, 0.01683394093561219, 0.06738222960848361, 0.04223533484037034, 0.11503915360663086, 0.08265889424365014, 0.06365290042595007, 0.10582503397017717, 0.05130571902554948, 0.009622254474379588, 0.04200660121568944, 0.026454538565303665, 0.07805401633959264, 0.025886110961437225, 0.028284242434892803, 0.05859808064997196, 0.01990139870031271, 0.03119930945103988, 0.03295466311101336, 0.019031338160857558, 0.06649469520198181, 0.05338411472621374, 0.022636157227680087, 0.04055399556818884, 0.05988602599245496, 0.030851060364511795, 0.03168101524352096, 0.01631408689718228, 0.060561562204384245, 0.06333702011033893, 0.10451538822962902, 0.029285896889632568, 0.04708102853328455, 0.03606035446864553, 0.015182891493168427, 0.03273703572631348, 0.01977336152776843, 0.05920687923207879, 0.032540874963160604, 0.046864551477483474, 0.041408270626561716, 0.02065986434899969, 0.040275682767969556, 0.05332868742698338, 0.048676197038730606, 0.0482357954751933, 0.02701488418097142, 0.013773566042800667, 0.07909769119578414, 0.037336510795284994, 0.027645837726595346, 0.004863103549723746, 0.024358769187529106, 0.03036293313925853, 0.01573428959090961, 0.015320804795919685, 0.03372850420419127, 0.029160637204768136, 0.03583855250326451, 0.04950516486132983, 0.02262555564811919, 0.01882365369965555, 0.07759568819892593, 0.024551180249545723, 0.04451790649909526, 0.0342003060359275, 0.04800972244993318, 0.008455707793473266, 0.037287729428499006, 0.040610142750665545, 0.003242727070755791, 0.09582407452398911, 0.030500863140332513, 0.09167328709736466, 0.05622877048153896, 0.02141074524843134, 0.01596663561940659, 0.02841197532688966, 0.02689942455617711, 0.017895301170938183, 0.04234680913214106, 0.04021133114292752, 0.007365406117969542, 0.03304648162156809, 0.04317518694733735, 0.046422576560871676, 0.07481086067855358, 0.09374033164931461, 0.08662778127472848, 0.03622584597906098, 0.015205302497633966, 0.04091405964572914, 0.014377312454598723, 0.013967978120490443, 0.03200777544407174, 0.023672677780268714, 0.07320686432649381, 0.02293107743753353, 0.046540800685761496, 0.04855697843595408, 0.027296111766190734, 0.0298580222442979, 0.06972870760364458, 0.012655280297622085, 0.06111827686254401, 0.03498604375636205, 0.022696551350236405, 0.04629291965102311, 0.01023248632918694, 0.05829567031469196, 0.014041485064808512, 0.08662905776873231, 0.013988254522701027, 0.011843020074593369, 0.15919630212010816, 0.026424425923323724, 0.009274580552300904, 0.03629174127127044, 0.03548542379576247, 0.04383259249152616, 0.018430671661917586, 0.0657602287537884, 0.037445669586304575, 0.05113198967592325, 0.0723965058568865, 0.014900611913617468, 0.04005727241747081, 0.04092859831871465, 0.051848863513441756, 0.04847989897825755, 0.00465494968011626, 0.045463558490155265, 0.025374938195454888, 0.0036059726426174166, 0.04883368448645342, 0.08598329281085171, 0.049654065660433844, 0.051272652635816485, 0.04719312993984204, 0.10109369410201907, 0.09750224853632972, 0.06924409259227104, 0.06776909634936601, 0.04203884382150136, 0.015500284862355329, 0.03778241167310625, 0.0616031664685579, 0.04141874975175597, 0.054857389186508954, 0.03989387747424189, 0.048619389344821684, 0.058604188525350764, 0.037461024621734396, 0.019204067466489505, 0.10205421131104231, 0.04483884455112275, 0.002126255180883163, 0.013771972280665068, 0.07630852953298017, 0.016504009909112938, 0.027054511156165972, 0.05777851212769747, 0.062125820259097964, 0.061749714659526944, 0.01674978695518803, 0.040588498013676144, 0.028151093720225617, 0.05240237580437679, 0.017504313655081205, 0.07902277880930342, 0.0207000980299199, 0.06581721085240133, 0.0723693952022586, 0.06808998616179451, 0.08101851781248115, 0.02601557305752067, 0.04294146980100777, 0.020348303332866635, 0.10698508500354365, 0.038370604524970986, 0.03818182442046236, 0.010292775623383932, 0.09287617489462718, 0.012029211011395091, 0.04200909854262136, 0.025181202399835456, 0.04468218088732101, 0.01617157042346662, 0.12728148809401318, 0.11611521578743123, 0.14957155217416584, 0.1890681913937442, 0.07961757306475192, 0.1484132229234092, 0.09979249400203116, 0.12284594602533616, 0.1578314628568478, 0.1792360408580862, 0.098950764950132, 0.0960598028905224, 0.12903778057079762, 0.06698838667944074, 0.1431460227468051, 0.21646736335242167, 0.17916427517775446, 0.1462222693953663, 0.12735286785755306, 0.07966340810526162, 0.0916831725044176, 0.1389450958231464, 0.08998678618809208, 0.0798913290782366, 0.07322751829633489, 0.09302650432800874, 0.07780744519550353, 0.11472958154627122, 0.12533470115158707, 0.07840628415578976, 0.1772302680183202, 0.12937345396494493, 0.18907218414824456, 0.17878665559692308, 0.1695937613840215, 0.06877310341224074, 0.2230969537049532, 0.12638813524972647, 0.09676498419139534, 0.08153763526934199, 0.1427857397357002, 0.19642262253910303, 0.16113875492010266, 0.11222455854294822, 0.10971894924296066, 0.09370719475555234, 0.13591020164312795, 0.11748174714739434, 0.16272552602458745, 0.08330480763106607, 0.1422109908889979, 0.13729641475947574, 0.12629637611098588, 0.10338074833271094, 0.13267400732729584, 0.23584347363794222, 0.1763933480833657, 0.22124943643575534, 0.11416632114560343, 0.1883780088974163, 0.14751283451914787, 0.2427239395910874, 0.21034133504144847, 0.057137634212267585, 0.13263511878903955, 0.10020151385106146, 0.10595458326861262, 0.25125219603069127, 0.17336630582576618, 0.18998845451278612, 0.12591743550729007, 0.13350159104447812, 0.14707832189742476, 0.17453738517360762, 0.17470028658863157, 0.16583463497227058, 0.19975724047981203, 0.09122482209932059, 0.11492221339722164, 0.2107384879491292, 0.06288600212428719, 0.1436006772564724, 0.15400782896904275, 0.15910089161479846, 0.30335820629261434, 0.11975889370660298, 0.11934568072319962, 0.13686167949344963, 0.19973459013272077, 0.1701343120657839, 0.13903700339142233, 0.08763699821429327, 0.245205904066097, 0.1968673916417174, 0.09724720948725007, 0.20439535175682977, 0.09565168104018085, 0.1425073156133294, 0.24745700124185532, 0.10043512709671631, 0.1049821545893792, 0.10769129788968712, 0.24912160879466683, 0.17245000577531755, 0.16456683893920854, 0.0956916827999521, 0.110090691014193, 0.06405127787729725, 0.14351081801578403, 0.13539780804421753, 0.12381216292851605, 0.15790687990374863, 0.2014884483651258, 0.1893729023868218, 0.1452809144393541, 0.12947591487318277, 0.1981326495297253, 0.11280957129201852, 0.14090905606281012, 0.12293941952520981, 0.10925683614914306, 0.0911924199317582, 0.1272821708698757, 0.17148770741187036, 0.13073666050331667, 0.14840338204521686, 0.12751844100421295, 0.18491761176846921, 0.21739495889050886, 0.09790736468858086, 0.16452006879262626, 0.10274371845298447, 0.1208847836824134, 0.16688398725818843, 0.17722862045047805, 0.17334289848804474, 0.17252355261007324, 0.15304318541893736, 0.1064438367029652, 0.1908404697314836, 0.12108172741136514, 0.14270904619479552, 0.2227754850173369, 0.17915713571710512, 0.07198868828709237, 0.07478406172594987, 0.14107952738413587, 0.08525145356543362, 0.0769645361287985, 0.16184398817131296, 0.16044716234318912, 0.1298868568846956, 0.1634212746284902, 0.17233105434570462, 0.1054224040126428, 0.14648709737230092, 0.082086238253396, 0.16724198445444927, 0.10687822315958329, 0.16355040832422674, 0.08777187613304704, 0.10099568607984111, 0.14107897819485515, 0.06700423153233714, 0.1665177967515774, 0.12587433157023042, 0.21042543521616608, 0.12516497197793797, 0.17344780848361552, 0.12907935568364337, 0.15859428676776588, 0.16947908472502604, 0.11015847878297791, 0.10353130783187225, 0.1671592053025961, 0.09168096832581796], [0.021372643386712298, 0.027839397262141574, 0.04049263850902207, 0.06726641004206613, 0.03645120654255152, 0.06678302699583583, 0.025532516556268092, 0.021663802763214335, 0.0402896388550289, 0.04680343561631162, 0.0259161271242192, 0.08918467297917232, 0.02364365238463506, 0.027599633467616513, 0.04522842755250167, 0.011697971021931153, 0.06529001140734181, 0.04396806783915963, 0.05131906655151397, 0.010283628653269261, 0.03663424984551966, 0.012407683134370018, 0.08207569233491085, 0.020565951126627624, 0.048148607966140844, 0.06603189191082492, 0.04595075988618191, 0.025290166377089918, 0.060481840700958855, 0.0229942713122, 0.06325427064439282, 0.02921358944149688, 0.07313598922337405, 0.0562235606048489, 0.04663817417167593, 0.047060088836587965, 0.026173143996857107, 0.01729017993056914, 0.06800344432122074, 0.03365207041497342, 0.12261176874744706, 0.0561727012245683, 0.014674515696242452, 0.06322740489849821, 0.00938315861276351, 0.035544480197131634, 0.07615402922965586, 0.03383662769920193, 0.057118757686112076, 0.011154697585880058, 0.03031996835488826, 0.03819566176389344, 0.022122008449514396, 0.047119909650064074, 0.11004495987435803, 0.05908738974540029, 0.035535403731046245, 0.010883313661906868, 0.08535788496374153, 0.007366836607616278, 0.03999175562057644, 0.020839007665927056, 0.06557870685355738, 0.05575705028604716, 0.013980662351968931, 0.15900132508249953, 0.029829054365109187, 0.009845372824202059, 0.0281201795587549, 0.026168058429902885, 0.07159998101997189, 0.023916202408145182, 0.03287153514975216, 0.0077343986959022, 0.055054221593309194, 0.03005511996889254, 0.07103560739778914, 0.07129590085241944, 0.033528113199281506, 0.04329650953877717, 0.027179908138350584, 0.03903822573192883, 0.012494356706156395, 0.017273479752475396, 0.05022392375394702, 0.11023686442058533, 0.06342520951875485, 0.02076296350423945, 0.0384474427846726, 0.06575207255082205, 0.0662806598120369, 0.06330375705147162, 0.04382768689538352, 0.03980585875979159, 0.011941725715587381, 0.04797927955223713, 0.07513691583881155, 0.052381647619768046, 0.04051568961585872, 0.023748146777506918, 0.01739035502396291, 0.0773167891020421, 0.023357222344202455, 0.05084509393782355, 0.03560776684025768, 0.05503251377376728, 0.04430047578352969, 0.02067940880806418, 0.02564347134466516, 0.04396714015456382, 0.060728820026270114, 0.06331336044240743, 0.03475032281130552, 0.07067592552630231, 0.025891747573041357, 0.037940860202070326, 0.04687130502134096, 0.046859055873937905, 0.041237290934077464, 0.06577431471669115, 0.043073709384771064, 0.026020018522103783, 0.03646129975095391, 0.012476800275180722, 0.04933822616294492, 0.04851943318499252, 0.008569258243369404, 0.0120073427024181, 0.04929239112243522, 0.09997763758292422, 0.05938779257121496, 0.053666197636630386, 0.025185347294609528, 0.03758238432055805, 0.045751278012176044, 0.04065244516823441, 0.0325428676296724, 0.021129721753823105, 0.007012857213339885, 0.019329139759065583, 0.051214182531111874, 0.07072095904732123, 0.03723836547578685, 0.04105582840566058, 0.06385438609868288, 0.030433559622906614, 0.02183631313528167, 0.04801948911335785, 0.003347214505993179, 0.08581062473240308, 0.010015327425207943, 0.026810309318534564, 0.07175739796366543, 0.040770721243461594, 0.04612899778294377, 0.0696832881658338, 0.027550369704840705, 0.06903041343321092, 0.03934620959626045, 0.053528855787590146, 0.0179532387846848, 0.057460435054963455, 0.047310971858678386, 0.029431602742988616, 0.010153363182325847, 0.033716852485667914, 0.03543416736647487, 0.024138017361110542, 0.12209539723698981, 0.025650742536527105, 0.060330624401103705, 0.036623581472667865, 0.08802617303445004, 0.048336293402826414, 0.07763181594782509, 0.1219419582048431, 0.050422025233274326, 0.03625115321483463, 0.03710825585585553, 0.03941290269722231, 0.06094425065384712, 0.03930165104975458, 0.03389563957171049, 0.07668768535950221, 0.058642872972995974, 0.010845269316632766, 0.05871751447557472, 0.07392058774712496, 0.01894861281471094, 0.05811571805679705, 0.028868199478893075, 0.03966485812270548, 0.08828392834402621, 0.021267800184432417, 0.05068566206318792, 0.032508721415069886, 0.03803917992627248, 0.00919019001230481, 0.021124177910678554, 0.034912960763904266, 0.022296609822660685, 0.1013591825903859, 0.04064117565576453, 0.021460990501509514, 0.026265036722179502, 0.03684274139232002, 0.043255142227280885, 0.049534227364347316, 0.016960078210104257, 0.014608865312766284, 0.07637592396349646, 0.02523234379623318, 0.027110997871204745, 0.03417150699533522, 0.015462704359379131, 0.027929185998800676, 0.040719999160501175, 0.03798033874772955, 0.0377317415404832, 0.02900683266489068, 0.01998077510506846, 0.03917097739758901, 0.027120833183289506, 0.03219674850697629, 0.038037851481931284, 0.04407558277307544, 0.05078786693047732, 0.00890492978214752, 0.02708282965613762, 0.029763300080958288, 0.04869285083259456, 0.07034136535366997, 0.013655905950145097, 0.009198552161251428, 0.010442258080729516, 0.005905190673729521, 0.04960941805620678, 0.030962603304942604, 0.04390550479001831, 0.039743002562318, 0.03460562256805133, 0.058719444059534, 0.01946745196619304, 0.03212155410437845, 0.010128671001439216, 0.09820273204240948, 0.09523882428766228, 0.0296652530960273, 0.037392008598544635, 0.03308874693175312, 0.011863528397952905, 0.045436006257659756, 0.028765079914592206, 0.022139406246424187, 0.031960534033714794, 0.034177477573393844, 0.03112659938778961, 0.01739651484967908, 0.022752908189431764, 0.019752817024709657, 0.018110004493792076, 0.07199045459856279, 0.02364107898756629, 0.02601720578240929, 0.05460593099996913, 0.0201332994402037, 0.03818778015556745, 0.036537651903927326, 0.02012468125030864, 0.015424147932208143, 0.05684709452907555, 0.02283929232362425, 0.03734323465323541, 0.013978803272038931, 0.02664816489414079, 0.04708328466222156, 0.08245335644460283, 0.026667904166970402, 0.048969193230732344, 0.03399722103495151, 0.027933742785535287, 0.04828314820770174, 0.01913655058160657, 0.026006776752183214, 0.04585469629091676, 0.049758552631828934, 0.04539878755167592, 0.06201190430147108, 0.04159128053288441, 0.029840496426913887, 0.01229366791449138, 0.010172654383495683, 0.03413907143112738, 0.05647419129672926, 0.0365187122952193, 0.03377006447408348, 0.055510041274828836, 0.043359892661101185, 0.01929852987814229, 0.015473653820663458, 0.01644602405576734, 0.04401305312057957, 0.028090131854696665, 0.02956681277282769, 0.10329923825338483, 0.057012615725398064, 0.08713723596883938, 0.041918445203918964, 0.045597493881359696, 0.05152819263457786, 0.01766138735547429, 0.026636502043402288, 0.01958304888830753, 0.053261812499840744, 0.012562187148432713, 0.017954919749172404, 0.007312157486012438, 0.06997316362685524, 0.017200159272761084, 0.038278073552646674, 0.014495994855678873, 0.06347593531245366, 0.028646681384998374, 0.07730219105724245, 0.0011768553440560936, 0.04081772516656201, 0.019528291377355345, 0.023396604410663713, 0.027736669180740137, 0.06047776259947568, 0.04267301643267274, 0.06482861077529378, 0.026418804154673126, 0.07259564634296112, 0.08269865851616487, 0.05855223076650873, 0.03444734844379127, 0.022798225581937004, 0.02056703837297391, 0.01086244075850118, 0.0726596788445022, 0.03382429691555444, 0.01536643945655669, 0.01778613124770345, 0.06396297714672983, 0.046605820243712515, 0.009397803969477536, 0.09036236486281268, 0.011836008634418249, 0.026958898415614385, 0.02661511149199214, 0.05009780688851606, 0.1434790837811306, 0.09906561230309308, 0.11676177484332584, 0.18665208510356024, 0.13477299391524866, 0.08740928504266776, 0.14793544309213758, 0.08805296456557699, 0.1406360644614324, 0.14150099304970354, 0.14644996030256152, 0.1712800544919446, 0.13857900921721011, 0.12389897194225341, 0.13450806203763932, 0.12445579792256467, 0.1997529063373804, 0.10869273712160066, 0.15925116167636588, 0.16467338165966794, 0.09953754401067272, 0.13055602175882086, 0.18586732330732048, 0.07751905402983539, 0.12634252285351977, 0.1707709560287185, 0.16345001058652997, 0.0846508186077699, 0.19053167692618445, 0.14030683290911838, 0.1674512107274495, 0.12583189556607977, 0.07680403185077012, 0.15334345836890861, 0.13370740343816578, 0.16424853180069476, 0.10441112390253693, 0.09832755386014469, 0.13071546476567164, 0.11587784727453254, 0.11382420590962283, 0.1454013353213668, 0.12190861350973137, 0.15432318235980347, 0.09952920227078721, 0.179095107014291, 0.1639476651325822, 0.14902055205311626, 0.15179423993686214, 0.13946967548690736, 0.1056342500669416, 0.07214681769255549, 0.0649714890460018, 0.09165514900814742, 0.19792115228483453, 0.20257887110346928, 0.18170181167079136, 0.07981083574122749, 0.13687616621609777, 0.1053431500622537, 0.16281247604638338, 0.1396624557673931, 0.14597859262721613, 0.1308524503838271, 0.1545020251069218, 0.28948823804967105, 0.08384659769944847, 0.12078592961188406, 0.09176931358524598, 0.16700522450264543, 0.17789739940781146, 0.09655446658143774, 0.1702205793117173, 0.1727662349003367, 0.12288382524275221, 0.1959567319136113, 0.1407797442516312, 0.14703729597385973, 0.12019582572975196, 0.1401131768943742, 0.1275274803629145, 0.13156722765415907, 0.17194558284245431, 0.11795306287240237, 0.11663089710054919, 0.16182962019229308, 0.09034881324623711, 0.12615990999620408, 0.1499585821875371, 0.1382885771454312, 0.1882177940569818, 0.1849550605402328, 0.10946863025310449, 0.09903208949253894, 0.13162201299564913, 0.06533172752824612, 0.15062097867485136, 0.1162985188420862, 0.10945147922029719, 0.17677150201052427, 0.1583018954261206, 0.1540069977636449, 0.1034897327190265, 0.1505904912482947, 0.2520063961856067, 0.1301430759485811, 0.11390846193535253, 0.16183923842618242, 0.0762134233082179, 0.1633805752499029, 0.1161284334375523, 0.13289164955494925, 0.10447923821629956, 0.22293679823633283, 0.30462517112027854, 0.14673567231511697, 0.12745728803565726, 0.08290870115160942, 0.1275811524828896, 0.2830452978378162, 0.2790617459686473, 0.17172463063616306, 0.15461975941434503, 0.0805777266214136, 0.10207623083260842, 0.16186475346330553, 0.06916987782460637, 0.13774042687145993, 0.16585164499701932, 0.3024128288961947, 0.1926813818863593, 0.16228751046583056, 0.1684755674796179, 0.08767674764385447, 0.09941876327502541, 0.09932984656188637, 0.13093269139062613, 0.14884338655974716, 0.11182192858541384, 0.05584953301877249, 0.14609312085667625, 0.17445497709559277, 0.09450581987039186, 0.10680115112336352, 0.13676754548214376, 0.13651908928295597, 0.1511250453768298, 0.24553129129344597, 0.12821834563510492, 0.1854260274558328, 0.11476668893010356, 0.13160930742742494, 0.10440509766340256, 0.12142946070525795, 0.17495781183242798, 0.13784426817437634, 0.07433782317093574, 0.13123173237545416, 0.10806808626512066, 0.22963460680330172, 0.24709000921575353, 0.20262026810087264, 0.14062764850677922, 0.11994615982985124, 0.08598078435170464, 0.1264272612752393, 0.15220555302221328, 0.1641271758126095, 0.12410351526341401, 0.22358550952048972, 0.10065089911222458, 0.22832093120086938, 0.17648665088927373, 0.11257567603024654, 0.18546519801020622, 0.16610210499493405], [0.03524423693306744, 0.062289545458042994, 0.006171745999381528, 0.057541559217497706, 0.03392241254914552, 0.04673307259508874, 0.021517772220249753, 0.03649975413281936, 0.0331625832041027, 0.05737357780162711, 0.034625296902959235, 0.050582948824740015, 0.021712617526645772, 0.08677026620716788, 0.0877672154456377, 0.009901253761199769, 0.009784290359675651, 0.07235214026877657, 0.030178077140590176, 0.08259406022261828, 0.04965333835571073, 0.10299959612893872, 0.008391334831685526, 0.039696866951999255, 0.02549853361415444, 0.011086903323302977, 0.012039349676342681, 0.06272821410675533, 0.026917664690699894, 0.03815112177107949, 0.029529731364164036, 0.07526717017753981, 0.04099352881894447, 0.04512693143624347, 0.04595681210048497, 0.020104338982491754, 0.007178620999184204, 0.03950425365474075, 0.06369797105435282, 0.08697546261828393, 0.051453443520586006, 0.010546605899435235, 0.10041597968665883, 0.0014440664267567627, 0.06702369064441882, 0.03412628051592037, 0.12078719126293436, 0.04701090671005659, 0.01947633732925169, 0.036538234489853494, 0.01285495976844686, 0.08572047605412081, 0.037177468548179604, 0.10408158064819872, 0.04040141742734704, 0.03577168128686026, 0.019017298582184594, 0.02637703608343145, 0.028801194675907027, 0.02403064900136087, 0.018248205378768034, 0.027444344632385764, 0.026799611259775702, 0.02494089127139887, 0.08138237055391073, 0.02217106997704832, 0.06499307812191546, 0.019736942485906184, 0.0682291759585496, 0.03568089807231445, 0.03622544893005397, 0.024303293648699764, 0.019622299223556183, 0.07170100958319381, 0.028446028773032594, 0.013099381467327476, 0.07614929432747886, 0.03139580789138563, 0.07423773713526316, 0.010216148875770159, 0.06478901719674468, 0.02505096661479911, 0.02283039953908883, 0.027577151959121693, 0.04238439149048645, 0.013213724159868434, 0.021360384962463286, 0.023763282879372127, 0.051977733746753074, 0.046350291377166286, 0.03042078169528395, 0.02785097291052807, 0.06730879409587942, 0.023917877806525212, 0.024338306320714764, 0.02129351931216661, 0.03493217867799103, 0.03578676172764972, 0.028137633016740438, 0.03474098659353331, 0.039445445872843266, 0.03788864269154146, 0.013396182093856623, 0.007912241399026243, 0.015037972316349624, 0.06387927031028084, 0.04952600065735169, 0.0550025421398459, 0.05001916520996019, 0.0635633454658091, 0.030650851185782813, 0.015740408598503564, 0.01982021887670271, 0.03285212798800785, 0.05675347631040495, 0.00522893457855389, 0.023039482948661316, 0.04200611510896124, 0.06020740191161167, 0.011859744372486603, 0.005929421795372036, 0.01665603329456644, 0.042484878285904415, 0.029222892262623645, 0.09931360094924457, 0.039965709947864525, 0.07924441379145719, 0.06291594036156312, 0.09097119313082658, 0.017251970457436983, 0.05507852321898099, 0.026315070463169832, 0.04231310449540615, 0.03590687832911499, 0.026853272247535642, 0.025132131595455576, 0.012097150920453714, 0.049542179476702586, 0.014995346136856824, 0.02773511252598837, 0.05996870866511017, 0.057932170093408786, 0.009783335772226565, 0.09389847589773126, 0.043842459344887175, 0.03950511083530728, 0.018612323437992018, 0.04980374942533672, 0.06473924877354875, 0.02928740344941616, 0.02038356091361493, 0.028262154264666606, 0.028222094988450408, 0.029429246424115263, 0.014301342507678783, 0.061409139379975386, 0.058734368649311364, 0.07157095562433824, 0.012066356430295855, 0.046991154449642636, 0.005651472647514311, 0.04460862292035017, 0.031206563944579102, 0.04669376474339515, 0.03001997927640332, 0.04146874081925489, 0.05097171917441301, 0.050586666984600015, 0.01915054934215732, 0.00533934620762011, 0.05108597280923277, 0.05498767692188267, 0.08115663891658187, 0.026578625656838994, 0.02852497844287427, 0.036716925096698105, 0.06310638287686743, 0.038350176910171285, 0.0322511034028139, 0.03393976396182552, 0.0470594839862315, 0.016700033374945633, 0.0255678817484295, 0.06661863386398181, 0.061636347891180776, 0.03584749167202972, 0.08469005595543422, 0.04209053069644142, 0.0430414333823137, 0.04042876556923147, 0.03060721846850356, 0.053464660013560206, 0.030836953992547933, 0.02490636285074288, 0.01973311671463307, 0.005283037144181435, 0.02621357805765001, 0.05325648016878404, 0.05701368812879082, 0.04593499666952994, 0.020036976093251724, 0.008211615422624163, 0.03422449262870941, 0.030977646638348233, 0.02038979495409876, 0.025004003509820905, 0.03414858947508037, 0.06866402254672721, 0.06104712716478389, 0.019862456356349867, 0.04442754259798676, 0.03392322520085145, 0.019133800924464595, 0.03701713867485523, 0.0664032477652654, 0.029175912459322717, 0.05456465274619404, 0.01923235999129247, 0.052790689733228646, 0.03095397954893997, 0.02310080104507506, 0.034622153907548636, 0.08678660087753087, 0.04414570830704179, 0.11692630156176165, 0.07224377186503261, 0.06067027570679784, 0.06046355418220628, 0.022482951972051524, 0.09341415774542838, 0.029479578879545443, 0.018208018082077615, 0.03256848285673186, 0.10930202552117407, 0.024440670749754645, 0.06770478925318457, 0.01883197317511076, 0.026837117547984235, 0.06857074942672625, 0.0479332070244709, 0.039487881876993924, 0.010928078154393006, 0.03270932393206749, 0.03835789153527003, 0.007079470533426502, 0.02776198940409813, 0.03122827176412102, 0.05157963831152301, 0.04377788136480376, 0.10369901836384088, 0.05986991025565658, 0.05662807190674357, 0.04417661875777412, 0.029945875830890145, 0.028324676495685708, 0.05740084801800549, 0.04115197734790854, 0.020163235822110437, 0.005881779161427403, 0.046580000926041976, 0.07851732429116964, 0.024828563509800006, 0.007820298578735674, 0.03770456780330278, 0.05370697865146212, 0.010002692361013032, 0.016171704010048416, 0.04498201597016305, 0.02387142121733632, 0.021301076230884064, 0.04938274018059019, 0.04465286976483185, 0.05192227676161565, 0.0420366433536401, 0.04149909465922974, 0.06480206415290013, 0.021930384064035024, 0.037592993321595713, 0.031661856701248325, 0.04910553318040911, 0.046529553437721916, 0.035896350964321755, 0.04317165432439651, 0.027022314934583846, 0.028624845544982236, 0.0503554805618478, 0.024006167404877488, 0.04948160538333468, 0.02594046400190564, 0.04595966194756329, 0.033510335051687434, 0.03113864629995078, 0.04500668866967317, 0.021421582459879573, 0.030926980216463562, 0.047435207379749045, 0.030384665078599937, 0.01366370035611908, 0.050667260511545464, 0.026729775163403247, 0.04011164215626195, 0.018091296806233004, 0.05097993845993187, 0.06272917889873497, 0.06250924343476072, 0.01637640132685192, 0.05091850718599744, 0.043159353226656094, 0.04526062562945299, 0.03966839816712309, 0.013148988473403733, 0.02396704880084144, 0.0712601441773586, 0.04938306301482953, 0.03856752970023081, 0.026349315012339503, 0.04978727374691516, 0.13076302158879116, 0.022662080446025357, 0.06660798404482193, 0.024412053535343148, 0.01284724236029433, 0.023506900542997755, 0.052219265708117746, 0.04885880618530791, 0.03781316256208811, 0.031490832479903474, 0.013792309910058975, 0.024015817180043086, 0.040220103328465484, 0.027874391380464658, 0.024030146196309943, 0.03202165360562503, 0.04617811311618425, 0.058862255536951125, 0.018684053866309114, 0.027097127131128218, 0.051560936190071516, 0.026617215480655432, 0.0667170352244284, 0.051120323114446364, 0.061073221077094786, 0.023150621418608353, 0.07827455294318497, 0.0263162059491151, 0.017116309572884347, 0.038947821012698114, 0.042045619629789144, 0.05794115008029621, 0.04855646264331881, 0.01767500947607914, 0.018597818161651958, 0.15074261667905375, 0.18623489420861006, 0.11513912089867517, 0.09695296277641319, 0.11630167296971194, 0.18299843271961436, 0.12762134720105678, 0.12311406913795508, 0.12486377876484767, 0.18102518079103902, 0.18578022485598922, 0.1271050944342278, 0.18037455476587638, 0.11181234003743157, 0.1903484555077739, 0.10190929955570027, 0.11685212390148081, 0.11520739848492667, 0.13435894972644746, 0.16463585867313668, 0.14450431626755744, 0.3107713413191959, 0.2480660966830328, 0.13535063713788986, 0.18219716555904597, 0.08387220921576954, 0.19876142672728747, 0.1344464044086635, 0.1931189966853708, 0.08700217993464321, 0.10237288210191764, 0.1526412382372655, 0.19064314750721678, 0.0899079478404019, 0.10224325858871453, 0.11039481571060605, 0.10459614131832495, 0.11729172765626572, 0.23838892142521217, 0.12481335725169629, 0.14581937226466835, 0.14033362444024533, 0.12709326460026205, 0.07982964176335372, 0.164934350468684, 0.06075548168155365, 0.2330215906840749, 0.15808360010851175, 0.18144649802707136, 0.18026848701993003, 0.10539364579017274, 0.24320735974470153, 0.12279567294172011, 0.24503602646291256, 0.15005850495072082, 0.12321984744630754, 0.1226263445278164, 0.18176584417233244, 0.09425759373698384, 0.24868779379175976, 0.1327372234663926, 0.13033379305852577, 0.23972992290509865, 0.11621092315181158, 0.13263963104691356, 0.08079839681158774, 0.14233856607461348, 0.12141262137447484, 0.11307260327157564, 0.0951388718385715, 0.1026633067522198, 0.1464522906462662, 0.11529759911354631, 0.22904197219759226, 0.08648707749671303, 0.14346624462632462, 0.16309134545736015, 0.1731462887255475, 0.2191575596225448, 0.10670310599380173, 0.2318303397623822, 0.18268920946866274, 0.11939678501221351, 0.08560878282878548, 0.13558759004808962, 0.08134800169500522, 0.11275576558546163, 0.08847250806866214, 0.15750033140648156, 0.09627922627259977, 0.09788921917788684, 0.09705504518933594, 0.11632999332505278, 0.11469838165794499, 0.1653644844191149, 0.07727844975306652, 0.13760563801042736, 0.24402228242252022, 0.1708408960257657, 0.10968639122438617, 0.11578311212360859, 0.096113363688346, 0.1000451656000223, 0.12482851190725341, 0.10899637942202389, 0.11835630881250836, 0.14266456186305732, 0.15135905938223004, 0.11906880768947303, 0.0974978476006072, 0.0929015786095988, 0.115391198778525, 0.11540791194420308, 0.1928182932897471, 0.15315823315177113, 0.1493789500091225, 0.13760269910562783, 0.09608976339222863, 0.1854564406676218, 0.11642184152151458, 0.1438576978398487, 0.16176524630282074, 0.156609294062946, 0.0923762790625915, 0.20198349055135623, 0.1706293542520143, 0.2109777118312195, 0.17368921427987516, 0.19271583238150924, 0.09479152446147054, 0.20769948227098212, 0.10048743366496637, 0.1252322254003957, 0.134651237167418, 0.14570984611054882, 0.08921584318159148, 0.11610280707827769, 0.11683673918014392, 0.08617876708740368, 0.098212090524612, 0.10023170441854745, 0.1885280860005878, 0.10410437942482531, 0.21815521497046575, 0.10693493808503263, 0.10749730790848844, 0.15893384901573882, 0.1798844404402189, 0.13407553837168962, 0.09287376291467808, 0.12014061736408621, 0.09298031305661425, 0.07605272607179359, 0.18359857785981148, 0.1409214350860566, 0.1099912283825688, 0.15346433938248083, 0.24650914507219568, 0.08716492549865507, 0.1453902031062171, 0.09082136835786514, 0.14225259568775073, 0.11973687418503687, 0.2226059784879908, 0.1539998286170885, 0.12073543388396502, 0.15889861184405163, 0.1912408138741739, 0.11553119009477086, 0.1157962778233923, 0.1015104545513168, 0.16943660419201478, 0.14820169599261135, 0.14574837841792032, 0.11756951353163458, 0.10592859325697646], [0.035377578606130555, 0.025092769938055426, 0.023069066810421646, 0.0604238900996279, 0.02349086273170542, 0.09959451868780889, 0.07183562032878399, 0.020705242968688253, 0.023159176525950897, 0.06322822868241929, 0.01915167369588744, 0.028163370698166545, 0.049790721022873186, 0.052139726030873135, 0.030958556744735688, 0.06278288070461713, 0.03112532289378578, 0.015187721019174205, 0.0556763491476886, 0.048711597482906654, 0.015164301621553022, 0.047644159058108926, 0.008021920621104073, 0.05112122482387349, 0.03942167117202189, 0.04998461823561229, 0.013433236599666998, 0.019456508998700883, 0.07442346701282077, 0.0688377593178302, 0.11045026156352833, 0.11234221863560379, 0.04530273137788754, 0.04495842680626083, 0.06990455949562602, 0.01639864349272102, 0.06636697900830768, 0.02156545149773592, 0.020664319090428762, 0.10769581014756113, 0.0983258023916278, 0.04818733694264665, 0.10717258861404844, 0.06006805626384448, 0.042231149127474055, 0.06257441884372383, 0.02216063909145305, 0.10337895975681022, 0.0453536649729358, 0.015288178128685104, 0.01699106473097345, 0.014271472919062944, 0.03022058921487769, 0.05862120226083789, 0.02016700222156942, 0.05359033530112356, 0.03161871194606647, 0.020692173748102505, 0.03462586835667025, 0.046645502879982814, 0.07147003838326782, 0.03955486070481129, 0.014903660285199294, 0.031232253386406228, 0.053405603612191044, 0.044716924530803226, 0.02847748841304565, 0.04542548631434329, 0.02129097374563571, 0.023738638010399882, 0.025667585578048602, 0.050980354062630795, 0.05982156304526143, 0.030888102810422424, 0.016676395971444435, 0.10151443246286362, 0.040020046290010214, 0.08072392229223624, 0.04293460864573717, 0.04392660775920376, 0.02722536097280681, 0.044503427197923884, 0.031021672693896107, 0.05427345255156979, 0.06611337230424397, 0.015287099231500179, 0.07714478895650245, 0.02101472782669589, 0.06400533151463605, 0.02196796271164203, 0.026131934391742107, 0.007879140684963204, 0.0223483950321679, 0.10685949135222472, 0.0427202763967216, 0.03707647338160314, 0.012053878144797636, 0.006131927921160241, 0.05167251809325535, 0.008670855477248551, 0.027018322180083487, 0.021468745944730472, 0.04594681908201892, 0.04264097420673352, 0.021895529098401312, 0.059041402564616874, 0.0994004619133193, 0.03350105820572935, 0.015634442897862755, 0.031669534218963236, 0.020711955694423523, 0.0786678095755633, 0.03108261229499476, 0.017064789681171533, 0.07959330483572558, 0.01792771632608492, 0.01840700271714013, 0.038090825983090326, 0.03997676794824656, 0.025865360512398183, 0.04405340368975885, 0.08978836558526382, 0.013695715679205023, 0.025517794201732613, 0.07761301734717563, 0.019144482284900732, 0.03305097532575019, 0.042151887755608186, 0.03143953894323204, 0.07044898418826051, 0.045874103452661075, 0.0628461413725745, 0.04388732217194047, 0.023138027172535658, 0.02122363312082598, 0.03793378753471188, 0.01780871480150381, 0.12754840892739594, 0.010105228411703138, 0.046775835144217126, 0.0401804169814568, 0.004664481639338192, 0.062244571308838204, 0.025008706870721653, 0.02298853636602871, 0.024211840645875782, 0.027728160457627382, 0.02908092126745032, 0.03373709456354845, 0.06760649921488948, 0.015261904245562619, 0.028173488026368432, 0.02683847753360169, 0.03507009198074229, 0.041441184876021, 0.022954711130296346, 0.027140572456119116, 0.10113703552633524, 0.0062792488733975915, 0.036707882027258165, 0.03941820534237195, 0.04948560555931181, 0.021229561025393195, 0.01664173210883746, 0.030549152834282722, 0.03874042413372081, 0.018994670499523636, 0.08540740847820416, 0.014632614966103574, 0.006739417540302384, 0.027545169104996603, 0.032935812560026534, 0.08240627459599636, 0.03612760418036487, 0.03900769377651159, 0.04972983522748109, 0.0467767479858594, 0.04143171878240537, 0.007799770773999626, 0.03073297910304973, 0.028186868948978372, 0.0712836257298477, 0.01355421594780637, 0.06677493016468361, 0.005579465305345366, 0.0589326408226043, 0.030114467663224787, 0.04651379393180832, 0.04344465705798939, 0.02870701613574056, 0.033048414916265756, 0.06321017222944647, 0.019492473475111183, 0.03374490195710678, 0.061434383533196524, 0.04528426674369257, 0.03677318360132631, 0.03672924474813044, 0.020381948597787414, 0.048345236282330006, 0.02329829952941509, 0.034319216647418216, 0.039696224994258955, 0.048469390167156234, 0.034230266537633725, 0.05159857792023104, 0.05958313697192352, 0.1423462844104506, 0.05633171749650501, 0.0426117632741807, 0.019025753499590792, 0.021553957485593855, 0.05265598992991727, 0.04226679819112178, 0.02413919552054722, 0.0771182868629694, 0.018754915981844533, 0.07486247704946436, 0.050102460154448636, 0.06950852723093703, 0.0417075862060301, 0.013539233841584064, 0.03259449513279833, 0.026759438806038816, 0.05945306445937604, 0.011886551674251677, 0.052620593196479604, 0.03814094692643266, 0.01849506596045103, 0.1147005042003002, 0.018612586900417227, 0.04106439650058746, 0.039813539988244884, 0.029336752559174784, 0.04049620823934674, 0.12265254234080203, 0.027611626574071124, 0.026142452479689382, 0.021353967240429483, 0.013512892237486085, 0.013195228912081802, 0.05580813973210752, 0.012328050688665826, 0.0409736912115477, 0.10534276414546184, 0.04280473651306238, 0.013280409839353524, 0.03013763936905889, 0.044395222066668794, 0.008903580928745214, 0.0016048524889811233, 0.05493919241416734, 0.05082849209429696, 0.06923475637449883, 0.02477292284311261, 0.034002404936472885, 0.024848644170560874, 0.010772474834084278, 0.017798883200157434, 0.026551129085419234, 0.013481872319971444, 0.04080967657500878, 0.11572272356715985, 0.03410692901525181, 0.044934629841009155, 0.02718162621022202, 0.031564026794512756, 0.044025461829733104, 0.014402850683836732, 0.04778508548042737, 0.05031584616517648, 0.032621802456560545, 0.0383347921888344, 0.04407535641803406, 0.01698027946986258, 0.020205278487992473, 0.058301655735704117, 0.02019640611251816, 0.04851260542636737, 0.06868009004392661, 0.024996587599162012, 0.03254429997468833, 0.03633967287896667, 0.02164050118153682, 0.0444812481146073, 0.02957089829578763, 0.00286472064544796, 0.02765017929050373, 0.04208464546536561, 0.03470065457804594, 0.017125846170529258, 0.025386515699210577, 0.053060642239870504, 0.02371095775743015, 0.029159186306060292, 0.03007544368301751, 0.006090833812777419, 0.051675382783287205, 0.01835659975768067, 0.027199463729630224, 0.036537778069032356, 0.0406032036698889, 0.01802487273380393, 0.060531241761054844, 0.02263938371470431, 0.10374719859100878, 0.048957396793412045, 0.03246939129894599, 0.031057338455866557, 0.027693529991665855, 0.0523741556389723, 0.0544558167894138, 0.019476454217510764, 0.08246362776844762, 0.01274414969884674, 0.028248751077626366, 0.045565852415165864, 0.010146066015295219, 0.04206842953863088, 0.07042089389869943, 0.04603262248565443, 0.06048262366675772, 0.03006148759595817, 0.10687322108424269, 0.0776696135289967, 0.04666475419071503, 0.017015516641549766, 0.011705342403729446, 0.022673201528959908, 0.07256219032569788, 0.02143441975931637, 0.03568574429664295, 0.03394661398488097, 0.08422887796768919, 0.039177897924673744, 0.05715151608455926, 0.04281556073692627, 0.07389019679976627, 0.034919706886284985, 0.021978326803946402, 0.04158469397225417, 0.022181280073709786, 0.059199951283517294, 0.08917463172110729, 0.042094003947568126, 0.048747116670710966, 0.011643385132629192, 0.03042924032342853, 0.014954377729736734, 0.10984181179082952, 0.04693831353506539, 0.03174607933033258, 0.08949343609856442, 0.08235154862632044, 0.08713532122783363, 0.1753408639342524, 0.1214684011938516, 0.2510063076624647, 0.11183702386915684, 0.12687756679952145, 0.07478625106159598, 0.17838240775745362, 0.15757076122099534, 0.07957578272907995, 0.15118793497094885, 0.13590488786576316, 0.1896674162708223, 0.13709294755244628, 0.09250213988707401, 0.053230093108140863, 0.10337438070564531, 0.2206605570972897, 0.0835220045701135, 0.12638537446036935, 0.10052108264062554, 0.13250215561129153, 0.09180722991004586, 0.15327299886848778, 0.09075623747776262, 0.13595253374660388, 0.14234508213121444, 0.14826087484834716, 0.19874486199114472, 0.16646307078190148, 0.1549440185772255, 0.12169701236416586, 0.2031045639887452, 0.07321896133362316, 0.17844437708845362, 0.11325320490868762, 0.173207129992079, 0.15796611813129857, 0.13555575191276148, 0.17053737246897072, 0.13165811105864123, 0.10487971594557166, 0.15932326874462888, 0.13161240960471332, 0.11809513962361962, 0.1731114968424663, 0.20621296047465876, 0.08604201895650476, 0.10636238599545322, 0.0926203714334406, 0.08982507220935076, 0.16791858564829454, 0.08603848633356392, 0.133550439204555, 0.10125787201104686, 0.1532812070217915, 0.11492907826323062, 0.17604867985937744, 0.19330221810378134, 0.09698871202999726, 0.10175502189667895, 0.07610507716890424, 0.10800779418786988, 0.08592673373641446, 0.09802511383895762, 0.11604517188970931, 0.18003962351940572, 0.16735422686906531, 0.10876643980736844, 0.18666866468265653, 0.12693448952632025, 0.07769898031256162, 0.1044630519754719, 0.12240459080203436, 0.11379123970982619, 0.1364026463124901, 0.1420639269053936, 0.167251780803781, 0.0984647918085102, 0.08078662634943612, 0.13128058053553104, 0.13774268300039694, 0.18748009926639497, 0.11174976214533672, 0.15756454202346504, 0.09312379988841712, 0.16665599949192256, 0.16401907458202913, 0.14987246337113902, 0.1447092677699402, 0.1574285954120569, 0.14498493110295385, 0.11583547806367278, 0.14117857441306114, 0.0730613959603943, 0.08479319963953458, 0.10421965722343884, 0.08231936910306104, 0.23293441801797599, 0.06336789345368743, 0.17565406509675086, 0.18075168452924117, 0.1385967613896355, 0.14113631652435288, 0.144803817383945, 0.1077752496348694, 0.10020110566983931, 0.16892746119992808, 0.17589597555343062, 0.19038188183913007, 0.12340187400695868, 0.12090499236364849, 0.10056025319499895, 0.14475295058218762, 0.08043205045396462, 0.08943263193941675, 0.10666619898984209, 0.17901909624924883, 0.17096517607569695, 0.15024058346170932, 0.12202067780890502, 0.09698966197902337, 0.13721292314585298, 0.19079464953392744, 0.10764852791908197, 0.11042297279345803, 0.13199730223277584, 0.2622669143602252, 0.1994864604785107, 0.13992376596434042, 0.07935986970551312, 0.08480044300085865, 0.12874593841843307, 0.16114614671096206, 0.07181850640336052, 0.2615833666641265, 0.1084520437871106, 0.11938305528019555, 0.14628149277996272, 0.046564645890612155, 0.11572548435651697, 0.16566710255574435, 0.13887962355511263, 0.14661838329629973, 0.07188159637735225, 0.23469261039281264, 0.12370281488983892, 0.1442687289090827, 0.1604762248462066, 0.10316556261386722, 0.15138340182602406, 0.1886203052708879, 0.11145625016069971, 0.07037706265691668, 0.09766730960109271, 0.18586776859592646, 0.21119835233548656, 0.12712482071947306, 0.15230710851028562, 0.24405653995927423, 0.13360207783989608, 0.11061451368732378, 0.1058378434390761, 0.1911298479535617, 0.14235541282687336, 0.1824577187653631, 0.11791801865911111, 0.13299247773829848, 0.1269621419487521, 0.13025396765442565, 0.12321382120717317, 0.22516989090945572, 0.09230014213244431, 0.16531516128452495], [0.03895614419889171, 0.015038827641546959, 0.06877449122839607, 0.006069161245250143, 0.010444536474096822, 0.03820310921582859, 0.010565166085143574, 0.026229825525661, 0.10139422680367716, 0.031418673461303115, 0.03087126347963931, 0.05799813588964753, 0.008252606094174553, 0.04873934267379809, 0.04036639547848608, 0.0500994804315269, 0.02420665303361602, 0.026170986202487256, 0.020144036461715586, 0.024914541318139527, 0.013890853206248721, 0.048968321207212284, 0.022000513308739755, 0.011577625282370718, 0.018849098232749384, 0.08273885323433205, 0.06231111226952635, 0.06537262728670612, 0.09018350727274083, 0.049929599117604084, 0.04300555054214783, 0.06510228515253402, 0.016961658984655514, 0.02287182622239925, 0.06868638345622458, 0.0356398758594878, 0.06205836274602916, 0.01937941284268163, 0.09271676157368347, 0.06478052702732384, 0.01366300737572601, 0.015292215412046062, 0.022779547580284998, 0.061910192962386645, 0.04295359649404418, 0.025092630785366055, 0.059041358035756275, 0.06211603504198138, 0.057854582264553756, 0.02728086805291241, 0.09973069536499679, 0.06275849373196252, 0.03748347458895296, 0.023443638019671198, 0.05074518601759337, 0.055712666144245304, 0.09421146925888024, 0.03800955710175913, 0.024021943609113805, 0.07476096609025262, 0.021639649567077868, 0.0559390768466983, 0.052396060127648525, 0.03159403924655635, 0.09822321531828493, 0.04965199877915438, 0.019711102759174537, 0.03412693360587582, 0.028834882614319213, 0.02013351651839912, 0.046948703602538444, 0.02841425928636454, 0.025186445673170965, 0.046693575495737605, 0.012044240429531783, 0.05309648055117577, 0.033560084921191446, 0.01913899410283193, 0.0741394396754913, 0.06738055977621116, 0.07910080079454929, 0.026287442160537466, 0.0382082856958732, 0.01648002926231129, 0.01461728497815784, 0.04349159789853729, 0.02203492113039829, 0.013018518911849242, 0.04683051287429407, 0.03367063152836636, 0.0690946463146247, 0.0515472621191293, 0.07224347500596195, 0.05467023809615057, 0.04906359812594019, 0.02307546226802515, 0.03484993016172666, 0.029043735958111938, 0.06460146905737929, 0.03176469239406288, 0.010237168353341985, 0.07043425255687907, 0.04370960006781388, 0.02597211474494543, 0.005464252444653539, 0.04320442385505885, 0.06404551138984971, 0.08216771864681505, 0.05226261826464906, 0.04997462521714624, 0.016901478229556233, 0.064695417531766, 0.06284707647864707, 0.04798136498720851, 0.06452855304814875, 0.03834660346910823, 0.05201069623581134, 0.04988969383703079, 0.10304062947398052, 0.03815312928054482, 0.03957640154112596, 0.04966476000845432, 0.06433934249798767, 0.08628208146546967, 0.026494866870052647, 0.004935455062877736, 0.009257394267478958, 0.02996583960339194, 0.007124247085812385, 0.034171121078543365, 0.07351835854933597, 0.006492062502729823, 0.04137985008128453, 0.03692435166158248, 0.06813360960222781, 0.05725626280764118, 0.027816433357656933, 0.049898017023224384, 0.04556903622869868, 0.045254606811795384, 0.0179944706542301, 0.024252423136204015, 0.006835199119450408, 0.024745830742176622, 0.0809696622309275, 0.038450496722362004, 0.014821086151641794, 0.047341485260403715, 0.07193054843810387, 0.05378470377763733, 0.060368919221218675, 0.03991622354078572, 0.06810353777837008, 0.040653499017935246, 0.0725244521163404, 0.0542254244646756, 0.03343759344716091, 0.03690454745083116, 0.020592922628566157, 0.019289069350634236, 0.06988092951360159, 0.02108678479999071, 0.0580697382974904, 0.029066280549159274, 0.041153565543936566, 0.02759882452664897, 0.026268047986377496, 0.06947596921236254, 0.11761117770220153, 0.017619003301660996, 0.028851972419943195, 0.020546052292047534, 0.028636437891691457, 0.02026710681093391, 0.06577054460649379, 0.0253605052785133, 0.029335340623219963, 0.034122005745302886, 0.021607687122013886, 0.013039840814599302, 0.12034547980874777, 0.06633720404352061, 0.004094396726941341, 0.08034653277718462, 0.040879479274735786, 0.022719908592989668, 0.057274096616311, 0.01964071561815217, 0.03601587384764571, 0.0520560303266393, 0.027713753515854478, 0.07014191316557117, 0.0389234785689041, 0.03591553548176307, 0.05226168686931487, 0.016759147292759735, 0.021996142058924306, 0.01174125492980238, 0.01795687901903875, 0.03858915217278991, 0.04023152869194746, 0.054680490866303444, 0.06414411313016899, 0.08415467062150128, 0.10817306305398233, 0.03397927590413019, 0.060555754898814484, 0.04483790573431179, 0.060280911638983525, 0.021713582318625413, 0.026307086809538305, 0.04728610991151072, 0.10481914185220376, 0.03062881311052479, 0.054300359115586616, 0.06805126089602709, 0.037991352219250984, 0.02451715277857147, 0.02763663695077412, 0.08516710106050596, 0.018868516526708845, 0.0500560573709663, 0.04286972638510633, 0.07058738730847836, 0.005631736157738487, 0.03450859418080654, 0.01774360061972402, 0.06666220535407774, 0.011643569741863757, 0.0820368409040384, 0.02492924697435228, 0.06191970358486287, 0.06925801528268494, 0.02081216047372436, 0.0329934514593333, 0.03509920272335876, 0.023059814084263053, 0.06222994728886988, 0.024121506430674344, 0.0038419790826083045, 0.030236845959734637, 0.07505079702241346, 0.03275226459663827, 0.07832465533283539, 0.019005732210644055, 0.04891584765573498, 0.025656755788077135, 0.02135748687578598, 0.056311586740775965, 0.02473437569278758, 0.020077053923159838, 0.025799385439313482, 0.04875177735812031, 0.023650791845284402, 0.004335142475611065, 0.06609570918953978, 0.04636752033547964, 0.0853663899761159, 0.03210005408618599, 0.04913995770039037, 0.06224276788998395, 0.01511845359345898, 0.04238570138113573, 0.029501164244720712, 0.03914281289326027, 0.019161586933478247, 0.007327987495955313, 0.037891652100370266, 0.08169908207491972, 0.013781423531327164, 0.03410477678698953, 0.03189952578395605, 0.023686802705924492, 0.029957577644381672, 0.06346210910123773, 0.03885737547534518, 0.020787927496712655, 0.03056759149330901, 0.04608368966728449, 0.015321571991080418, 0.05523316081962548, 0.05230483533523511, 0.0400342806824483, 0.046841407602187246, 0.044720516525558196, 0.031345319584943354, 0.020033257933391724, 0.06515648419735953, 0.024038124283833895, 0.05082956078695133, 0.05978539076750167, 0.018113689257006627, 0.037010797022958286, 0.027380703613744117, 0.03250212743296288, 0.017683234327705577, 0.029138704885554034, 0.026161045134358574, 0.09832131239818409, 0.0434306675742846, 0.051391058586887084, 0.020256751995475497, 0.03617073038185481, 0.033808029038482346, 0.02816685137077002, 0.016754536700318567, 0.06118466568295844, 0.027570795464271214, 0.011072212510043755, 0.034206284035462886, 0.0196960835455684, 0.055280409651459195, 0.03150958655169234, 0.019355257791175973, 0.023378564656013623, 0.014888210625940701, 0.030382206714421045, 0.04509614715061616, 0.031168098430498503, 0.031366871553473175, 0.014874857533868635, 0.031189913861453533, 0.0281200682366034, 0.008679677757754689, 0.05444710768642835, 0.08120314931147732, 0.03934484033379704, 0.08765884704189375, 0.07553416522569023, 0.003031842561540543, 0.03068561894906452, 0.028662394506682176, 0.04110674715775531, 0.0662904635828454, 0.051953587972093374, 0.03849593842460308, 0.06535172840813175, 0.023535931504738983, 0.04722415913420264, 0.008767006274865707, 0.015057436994538875, 0.047130503808148205, 0.00816783242044039, 0.052029569051228464, 0.06242412651772611, 0.015540174372290494, 0.04786135599715635, 0.02839735501765972, 0.04516703338595107, 0.03774658449401613, 0.04857236686802935, 0.024577326112193987, 0.17821114975959063, 0.15789080498507246, 0.11282866675173864, 0.1127360096143093, 0.17949350673006848, 0.13265612156828865, 0.06996560114203021, 0.19417195580899715, 0.16475758573506027, 0.1590549823595211, 0.12313565079239197, 0.1231471318169497, 0.1161816157400608, 0.1780653474270366, 0.11709632017300464, 0.20155421749223024, 0.13880917889764532, 0.08842459501465783, 0.16294126835418865, 0.10806277990923263, 0.0886959167837631, 0.10279940921464004, 0.13935865019448102, 0.07015229581156746, 0.10389774324721657, 0.16799334960523993, 0.16042865318013355, 0.20543377962894738, 0.22755359503207728, 0.10148375207791105, 0.17023242398863658, 0.15351591864600778, 0.11837069905595854, 0.05933062122494448, 0.11595290066907182, 0.12332793383393437, 0.2062340671545826, 0.11540518084075302, 0.14515203307382762, 0.14271608175477013, 0.12438642195775174, 0.19293923367513344, 0.14744642714504153, 0.31421309569850564, 0.15205072617391124, 0.09555829659802839, 0.16817464143969119, 0.21011790406191722, 0.11696093017235398, 0.18660850619198754, 0.2100525060086511, 0.1276142374263145, 0.12105573739972897, 0.20315473317168653, 0.07490977412089705, 0.15275722107617185, 0.2128975439700298, 0.08056605263845995, 0.08338850704603828, 0.19281844171928242, 0.10877291875658557, 0.19161070027621463, 0.102577878133161, 0.12467686145100743, 0.12711294635664672, 0.16944147268077359, 0.09872368260403164, 0.1811834512045607, 0.06951027127797715, 0.1625934534240514, 0.1061054618912749, 0.07344241457758471, 0.20498592319199815, 0.10833517779246904, 0.11344654179993086, 0.12893897102912888, 0.13839804392773658, 0.21406598127214238, 0.13485324976500124, 0.14063616836210713, 0.11910676854313351, 0.2407915799994953, 0.1325455415644683, 0.2014748373767361, 0.18134323559934273, 0.27586902666371316, 0.15974973648553714, 0.09688225094578229, 0.1106213043385651, 0.07416301770717837, 0.19350060902070254, 0.12033358318149112, 0.17728012549923733, 0.17289510142290965, 0.17973528360016644, 0.11224416608456522, 0.13541887019528076, 0.10731144444434904, 0.18313526990823448, 0.08715350384591147, 0.0874734585522674, 0.15251867996994406, 0.10936174614471383, 0.1516038493718952, 0.14827764738583937, 0.10252116320771165, 0.11322340767947026, 0.19420682190684602, 0.12608281569555402, 0.11170089172082953, 0.12013832412776537, 0.11135056091006845, 0.16214432049309835, 0.15355102223111317, 0.15310240880353376, 0.14758402132429183, 0.13806453760480508, 0.1254386463551782, 0.17789634555811062, 0.1477445033378899, 0.115244505868759, 0.19479488488286734, 0.17620156228076667, 0.14069849392399192, 0.1707958328188397, 0.12909669225336984, 0.14577778230886906, 0.0967481300176587, 0.18537600670242682, 0.09504239264060743, 0.21106344473082572, 0.10900096589466557, 0.09448554439586587, 0.11579209211049601, 0.17837535735452548, 0.13297263270942494, 0.18645785021362826, 0.18535034323576838, 0.16485673666466027, 0.23023363872198388, 0.08159097342286259, 0.12588160461746156, 0.16901300114113837, 0.11752360427635722, 0.19695526192663237, 0.10792294444399886, 0.11661404292681254, 0.14629237266490236, 0.16373883961932734, 0.13856667472282425, 0.14771704387385398, 0.18016384419752285, 0.14681782806292176, 0.1319387467810884, 0.12774577568052337, 0.15237293700920418, 0.10824388620676473, 0.1534451771294698, 0.09496417769696563, 0.1656078643281944, 0.14416983030969277, 0.1937155646737665, 0.11343359874445014, 0.1211188273737207, 0.10754969611298293, 0.17091316636651754, 0.11907401756616309, 0.0938437350851018, 0.20788798778085038, 0.11850665308884345, 0.1277692275471054, 0.18427733128191903, 0.07588921609567478, 0.1110699400305748, 0.18836024188203737, 0.08926404567318968], [0.0574104736733716, 0.018602692216518335, 0.017080283869290724, 0.03878767296555452, 0.025052269083971623, 0.023278248554561287, 0.01689572658506222, 0.006664877619186882, 0.04412599686475005, 0.014272870012064232, 0.05419298518972937, 0.041667436016723514, 0.08841872462653555, 0.016059864210546948, 0.05052185893873684, 0.048236500515486114, 0.03629224964242894, 0.024484360983478837, 0.04389022396935616, 0.08420386016950943, 0.025949800219677854, 0.05982704009511508, 0.02475520406733267, 0.021561508838203736, 0.056721983273746446, 0.04100879479665309, 0.09549268332193606, 0.031509697873843834, 0.033887498211697675, 0.02275663377076853, 0.08265234850114211, 0.02242124239273835, 0.0235433641137206, 0.09729342302307487, 0.02752095097093843, 0.007181634582593688, 0.04321738917496987, 0.058578517637215555, 0.01121594703363371, 0.012710377341136336, 0.034427054415573366, 0.03650526086858008, 0.005573388043558225, 0.008278095156128984, 0.02019796462263912, 0.08791574146016501, 0.01708184052404249, 0.03592858243791852, 0.026149929617531598, 0.02741162334132241, 0.029132981071597897, 0.06143554128357209, 0.06686222899588756, 0.07556796263088472, 0.07882351957960054, 0.09285753214498982, 0.03519922567647882, 0.058838603290496394, 0.021869353549845982, 0.05121688765939325, 0.01706316994386725, 0.05518648715224117, 0.022552817754331045, 0.025528316000418272, 0.018445427413098514, 0.023698530494584702, 0.04125784842472058, 0.054797750199213624, 0.033989357980317436, 0.06185188241943251, 0.01841500121372519, 0.03656867367681116, 0.058558193923090585, 0.0380819127894938, 0.03981545101851225, 0.010799916672112886, 0.07895967399235815, 0.07806973502738401, 0.05107520795718301, 0.04484343473450281, 0.0733786789351143, 0.03043337037524907, 0.02823476716002915, 0.02584546724392567, 0.05114230181789026, 0.02853980469808448, 0.03857517753203865, 0.13028760178713128, 0.061228073900565505, 0.03446490765782073, 0.037229604422464035, 0.020623128039005678, 0.06868075055535883, 0.031642460671719164, 0.011121175703010522, 0.042963956875610165, 0.062067684120847844, 0.025837669127213303, 0.05071981198852882, 0.06868577489512973, 0.02772814561467385, 0.04310812277253717, 0.061507062055170536, 0.039589556108694524, 0.05126773219672032, 0.0709612293576356, 0.00901973446161719, 0.06898083796841092, 0.011190362420165911, 0.0043090230519737815, 0.06396582699380815, 0.010705841104936553, 0.045044523358228616, 0.03182321073836647, 0.036197648078086786, 0.038546389623661526, 0.019557450359570794, 0.07748870018986054, 0.024275028954434674, 0.021854699843970593, 0.03230596295907162, 0.057223322583013214, 0.046980011102277786, 0.07953895736136474, 0.08757821269682609, 0.0837509348639287, 0.019506019525579177, 0.023557132808491588, 0.023102893901523203, 0.02863453428290086, 0.0465109218202997, 0.06244330361369066, 0.009402217892784392, 0.0335493831516942, 0.033167232759296894, 0.04670908267144114, 0.01720624673907878, 0.013646903698827373, 0.027578452572925016, 0.03851356072118506, 0.019964384773629718, 0.05955360691586975, 0.034026354041998275, 0.013148609050404048, 0.013698450493393466, 0.01744549659633776, 0.011741601883841213, 0.05400236455898266, 0.046024770563235506, 0.015198035016510403, 0.029693412034248468, 0.05867102634510957, 0.019382368445803877, 0.01015015803204733, 0.019743888988159597, 0.06184200072311796, 0.025828546276898123, 0.028190394150442444, 0.029680762127100024, 0.025957809848478064, 0.020415536346263252, 0.0716404354898259, 0.036529480858007446, 0.040951189293991774, 0.047421036069863476, 0.012922991518280469, 0.04139586933888495, 0.03883591998601332, 0.02389829624007689, 0.050152402982348576, 0.14155874698190019, 0.02495596057997318, 0.04564205613860395, 0.06259367757593282, 0.04674472802435048, 0.026557454038993455, 0.03889749226800632, 0.04727162318886258, 0.02513735631509917, 0.04860128836298827, 0.06001455483783502, 0.01936919717991259, 0.008955301200330723, 0.05147266143467277, 0.045375495246844366, 0.04994725481083151, 0.03061178638745332, 0.01569229701999575, 0.018175118675571866, 0.02420835069642635, 0.05244068175670691, 0.013928851167293033, 0.03336084424518049, 0.047762015819898807, 0.018074808140227105, 0.05429567987448536, 0.02449969746521674, 0.029772159468848258, 0.08656047590193339, 0.04205018383800052, 0.002934976055257721, 0.03736813741852529, 0.04384657455375418, 0.020578165022016037, 0.044962527172174305, 0.019500466405588668, 0.06560622568940744, 0.03331107582198456, 0.052934547638869844, 0.0588233966846019, 0.008158403434208594, 0.03369457321241498, 0.027358595034456812, 0.07178795960498974, 0.03619088340201415, 0.030867834757373203, 0.05095130269182846, 0.05406940275861416, 0.04174559158855118, 0.026093570922967046, 0.022279774202615954, 0.06380995371728204, 0.04529956611804664, 0.03318955656141043, 0.020944837924616877, 0.029312003789527807, 0.03739706633496098, 0.043613747984636575, 0.08534442240488715, 0.08779969182796776, 0.04682266837335192, 0.07023667800240219, 0.054749907649238594, 0.008636581242171815, 0.02245701391075272, 0.093708731001243, 0.06796609202865511, 0.043926440775976516, 0.03759862251172308, 0.09973056919989176, 0.04313577890570741, 0.020448415343707893, 0.03014061538124224, 0.01586844948178623, 0.040572122525190935, 0.01015850626572501, 0.02464061832142761, 0.05878548778127879, 0.02887555045163026, 0.0207592342121643, 0.04776581932674162, 0.015201075966615463, 0.039878114257589914, 0.0017645420280132385, 0.034400533768348396, 0.026218394596071448, 0.029734065028605983, 0.04060184925037902, 0.03965906194935087, 0.007298465325220604, 0.029835468376404606, 0.023965987529663835, 0.0450500375154661, 0.04360367704066448, 0.04214250700897537, 0.024898154697439168, 0.035615974993561395, 0.012233899051352637, 0.03399229688511696, 0.03030387859325856, 0.052514673880068585, 0.0439469388948055, 0.021852920544915833, 0.07276890813955106, 0.029581041599158198, 0.019425709870120045, 0.04698153992649168, 0.043172975347260945, 0.005895848426007433, 0.004186777878203429, 0.0038752247473894386, 0.068374584952835, 0.0983405637089163, 0.042813805557671, 0.03659286398033146, 0.038450188731076196, 0.025183877842209768, 0.04658717007259838, 0.0462425055593485, 0.019386222047614865, 0.03820409998297691, 0.1100061455508694, 0.03071454044402344, 0.05335316716809757, 0.01315220290052821, 0.026451248995726928, 0.007452683612427791, 0.03675265208585188, 0.05597885596216656, 0.07930368912639096, 0.04647697598556988, 0.0938015068823006, 0.04580953660479281, 0.038889469651621766, 0.021601499465759844, 0.02384343297308078, 0.0015077263469720492, 0.050849368708441034, 0.05027932136727031, 0.025728345208335668, 0.06412740738596767, 0.06117489901953377, 0.01845578408392612, 0.026980585826095194, 0.04699831246398389, 0.06823378469562158, 0.0562434130551992, 0.0311080549727194, 0.016134405523189344, 0.023407187436532695, 0.03616744637838565, 0.03413223625102546, 0.0183127276977757, 0.046181642028386705, 0.10191175606450997, 0.03531298578309361, 0.034726169615169056, 0.021234012056083884, 0.02180127634346718, 0.040181845615734346, 0.02792916558973957, 0.043108735044370405, 0.04423161932209041, 0.018055276668746956, 0.061458644340746105, 0.14161204802803695, 0.021430664492072538, 0.030957827584643383, 0.038497111017932184, 0.018211678725492675, 0.02084387801005505, 0.04290220276743639, 0.02753291995759355, 0.027897717081941664, 0.0492781418870436, 0.01349034764643875, 0.08640354877570644, 0.062369222432607785, 0.036872419877909124, 0.0413982924510492, 0.04576882238325197, 0.02983339778438676, 0.09324914120952599, 0.07952272659167647, 0.13742085808189586, 0.08453634975012392, 0.10881454581976868, 0.13856156874680892, 0.13626030238810927, 0.19358304678462446, 0.12527434970252216, 0.08670248585985973, 0.08102403196971864, 0.07922162243630737, 0.17370269168168306, 0.08084851404419169, 0.157699954288546, 0.17314049997366965, 0.1523308127070777, 0.10427089509903453, 0.05569565240875818, 0.20284651924157515, 0.18626223492901772, 0.1831366799888201, 0.13298241421580315, 0.08326836818014272, 0.14182869577780366, 0.12905487965326756, 0.14764033548999578, 0.20282155339373276, 0.09553623254760168, 0.08101428757072426, 0.37723152665421367, 0.12315970379859209, 0.1409716042689979, 0.23141619167290628, 0.048860646711545996, 0.10517166942008771, 0.19986284809419885, 0.2165061776759103, 0.11294919895590283, 0.15358418138930574, 0.08675758290337399, 0.29898354259785265, 0.11970039020525292, 0.12715076620224863, 0.15866133238887414, 0.228372139390558, 0.10177667034440674, 0.07838727775379084, 0.12461067672120407, 0.1040438721247483, 0.13714265660382807, 0.09660640207584947, 0.2136854821583256, 0.25911542878020555, 0.259530259645544, 0.17610226292163134, 0.12184734179754741, 0.21963373641483486, 0.1143261649121996, 0.14900118199875578, 0.15125843900023028, 0.18795949697960168, 0.09184870854369365, 0.1676241756649688, 0.08708802415640093, 0.24868930777302012, 0.10590471836621873, 0.2590392844285816, 0.0980543989862781, 0.19600295287091285, 0.09907620275043882, 0.1338519886485301, 0.15885250963037834, 0.07859664503484964, 0.10583170587779023, 0.07642782235052437, 0.19122435303870589, 0.179427262628451, 0.18205948232207447, 0.15464002004591748, 0.14800582837779075, 0.14072819467401132, 0.2022512277471833, 0.0744171513360925, 0.11836635007057339, 0.17822305380832404, 0.23671818373259157, 0.23456646013073623, 0.22429173724958673, 0.2172400281415321, 0.09650163308833726, 0.08784292193013243, 0.20684896619059145, 0.1859512008377351, 0.09617577830795199, 0.15280577237717807, 0.11127360019600019, 0.06783978591556661, 0.14038211636943743, 0.20220680278725922, 0.09966750149033032, 0.12041696347296238, 0.15973695670254529, 0.10881890964810736, 0.12043513124808669, 0.1977264869492501, 0.1758107918431051, 0.11047986583434977, 0.09386799589265138, 0.0812016056443099, 0.1798660500207916, 0.12039817971526645, 0.13869601621991023, 0.0715785774809774, 0.10240915085887536, 0.2336872526211664, 0.09510841409792192, 0.09034827147843316, 0.08518621878465638, 0.1398665166925639, 0.16646608390146866, 0.1330292585771531, 0.1263361849123612, 0.1607319837785326, 0.19652785907965153, 0.1530899852514267, 0.16541215998586267, 0.1301628170767799, 0.07448705422575586, 0.1332033218932338, 0.1787205450818874, 0.13346938183531165, 0.11538447492057458, 0.07461399116436951, 0.09787266928469762, 0.22909365536179394, 0.18470494193024933, 0.10720744729042053, 0.09007136875879951, 0.09350431384518743, 0.11427690114942379, 0.09468059564824216, 0.14555023983120918, 0.1340100957895629, 0.048208235821221024, 0.10047250907518901, 0.1112224959069863, 0.11742344402591698, 0.2045180881395936, 0.08726247338927351, 0.10443888764712028, 0.15532451769104227, 0.09392217267304659, 0.10975974510074593, 0.18194406351540238, 0.18945694318972528, 0.12095492405933328, 0.12341938869212754, 0.2079116622917354, 0.21779632719699293, 0.14441701001487672, 0.1423625077586621, 0.1742558291880414, 0.1558457873761654, 0.13687177270185202, 0.2600521082058549, 0.11149907950311899, 0.14122133696218953, 0.11033698756364174, 0.09299804296460934, 0.17858036822872236, 0.16289862454868853, 0.13929659180575982, 0.20573329558828846, 0.11792910634540021, 0.09995826010708697], [0.00823379450594075, 0.03721857239725068, 0.030121993040665984, 0.01970704321138328, 0.02536525687901303, 0.07460579043254256, 0.027664703120535705, 0.018966335301229265, 0.0726162557839416, 0.04225033364491537, 0.004766778811244876, 0.020629577302315738, 0.02986326551763341, 0.034754994630930014, 0.04128863271034788, 0.04631047886505257, 0.058852203146670945, 0.051491070407791995, 0.009444861698284512, 0.04946179746184498, 0.021413112699519843, 0.07333410554565489, 0.03805894702963997, 0.031033834638947155, 0.03006276037922362, 0.02912652253144188, 0.06624914080020972, 0.058538055745884776, 0.05380604794481769, 0.053772450919495896, 0.06447810927056707, 0.08225701385526918, 0.09768584102857858, 0.007183603129305993, 0.03012959634361323, 0.023107383894966915, 0.031068548596522305, 0.03974820130679291, 0.05270505331282038, 0.05616817783447914, 0.06755683469236828, 0.025248426136386115, 0.06407953886082396, 0.01654374264035141, 0.06281557973125018, 0.07445148308761418, 0.03884347504936159, 0.023752471643092576, 0.030478995759040117, 0.015739701702841558, 0.028984538548684213, 0.018165467045037076, 0.034390492510283366, 0.049537025261088274, 0.039865456928964704, 0.07642282027518377, 0.050662280700635165, 0.02216747798229335, 0.046989811162347905, 0.026831445684365463, 0.02717601371841738, 0.022627711587119848, 0.04410851928696502, 0.030592882030759938, 0.025156997253361624, 0.0364827700832393, 0.10080161446239799, 0.03849624641588889, 0.04906649250187911, 0.01845842612965498, 0.02161487482226221, 0.03718333151482511, 0.04660833983507473, 0.023161985554907005, 0.04636745354218874, 0.03552998976374511, 0.02071980205073487, 0.012766994859703118, 0.04843696944590192, 0.02355830725718988, 0.01736151702061761, 0.044964994813199155, 0.03431228869885672, 0.09409297053935006, 0.02421124321699608, 0.06379244645358995, 0.042935488090734, 0.030110968436929397, 0.062432683480437845, 0.0401841351413168, 0.019950309942942113, 0.0472509914834518, 0.015823772191652097, 0.0231652398724691, 0.025546222168486565, 0.06025761933415197, 0.09501599444774911, 0.04526494492893107, 0.036080295976717025, 0.041007043328136206, 0.02750343999650795, 0.027981459170405287, 0.0816613958158996, 0.055479880393249914, 0.04114461153221782, 0.04092445342394058, 0.04652810253901407, 0.015306670593417948, 0.060545620872289874, 0.08075303674559109, 0.025128077613771893, 0.02447061826387653, 0.014852137610432692, 0.02918634705565637, 0.023612040604348294, 0.04611636271874886, 0.049373415095033124, 0.045628693769685924, 0.02464944431267213, 0.02814153856888879, 0.04262527778337244, 0.015446742618223652, 0.0363130631740205, 0.05502085463376716, 0.06599097730941139, 0.06967153254663572, 0.043667869103956036, 0.08480635049636476, 0.04795079963514581, 0.0684325689508114, 0.021533474209718406, 0.03785665241593961, 0.05618470546323806, 0.025070744850381743, 0.03063891188503476, 0.038032504307921045, 0.08831998929963447, 0.01028462498652516, 0.019678644930536393, 0.034642210448510014, 0.04506034223595634, 0.05094745836686343, 0.0293054320718511, 0.04094950832950417, 0.06920239131432027, 0.02153633518901188, 0.025364908069605008, 0.02464937380864285, 0.03494716263958253, 0.019096344731224235, 0.05165749702428002, 0.03636221190390643, 0.021227965407888405, 0.06361026404192671, 0.0456635784212267, 0.04813614359591156, 0.012781660625478253, 0.05812158473418094, 0.028625042214116547, 0.03264299077272881, 0.029441308179229964, 0.06285008959821425, 0.0519775073917117, 0.04301945838960819, 0.046171255671652034, 0.06205720499565359, 0.10534938410273753, 0.03890619023877662, 0.04223713083774783, 0.02855784445273457, 0.06034338191966526, 0.06177899609610904, 0.11090272673754953, 0.0657154549844563, 0.03442575936787762, 0.015577022932120599, 0.04061991683556698, 0.038571396289626136, 0.07091268547810614, 0.015793954553373624, 0.03922959964256734, 0.04447047584108077, 0.013093553752696607, 0.03154785168590024, 0.06837998036644422, 0.0372018592315726, 0.009337315223092446, 0.03992265053966548, 0.03473357253824361, 0.005451966653708951, 0.027784545127360616, 0.021602260167128406, 0.008295810221170541, 0.04246284021064639, 0.021353876327339094, 0.05459460211568512, 0.017558032159286086, 0.03221715014660731, 0.10178038850426674, 0.024150607896444853, 0.029778538228129037, 0.08006789343198761, 0.01654943491303129, 0.04494495311519131, 0.029188295193307567, 0.045451932746800594, 0.06428605629480444, 0.0543233582720859, 0.04778140071721282, 0.06322103727143258, 0.0228105099813547, 0.03065826153033413, 0.05642706120852381, 0.02130086657416541, 0.038282608074950986, 0.07014256625552662, 0.04037824386614375, 0.03140396780509036, 0.022804826985520776, 0.020222264392941725, 0.08952432428486645, 0.03607334576372523, 0.04755939095048234, 0.013919586381234694, 0.03164921792631503, 0.05104244213725906, 0.0331578260374954, 0.05108078519697301, 0.02649654783454025, 0.01517178061476443, 0.04249254838214256, 0.07786217858665623, 0.02338280602998566, 0.06213344582647551, 0.03625006596848834, 0.014038773442734964, 0.004179163443041034, 0.0737777614267543, 0.01836552779423073, 0.01719801817671396, 0.05134298968187068, 0.051590418006526306, 0.06247675963095389, 0.03296722767117899, 0.005725555683966377, 0.006930426407052437, 0.03681945279822685, 0.024736596569709945, 0.03893277025781572, 0.02399075670837192, 0.02081395090499427, 0.02850307024345966, 0.06886167873744853, 0.05005646926292684, 0.007989679870661348, 0.032507871655980125, 0.006551320211656275, 0.02059779297269415, 0.009113965879805619, 0.05867182415386196, 0.00654594335173897, 0.007917955008451827, 0.0431108167686034, 0.009016959756991128, 0.019070671987719834, 0.025431536232645158, 0.024140685382008087, 0.03137487932690419, 0.040389487403444946, 0.0023115400017559296, 0.012108527116652112, 0.08173385169357061, 0.07125534990336746, 0.025218795890395995, 0.024434967344859615, 0.059035988597315736, 0.06672267554677092, 0.022308118677756283, 0.021359626116463915, 0.02062227085843915, 0.05313542475050781, 0.023572493410028983, 0.12035605541313998, 0.028585988548002206, 0.011367015831638128, 0.0520418219093699, 0.038338951926562004, 0.007028371346677886, 0.011392510459700134, 0.014639048458775505, 0.02658994711964624, 0.026160622110182885, 0.042337918202974834, 0.05919805138546508, 0.022840201454528142, 0.06683166735456325, 0.06064240435080137, 0.03951697777665686, 0.057770485800574534, 0.029527328661060892, 0.09098959839320742, 0.01139336114647449, 0.0179287831633701, 0.08230619598180056, 0.02322232030564919, 0.058293195252190344, 0.055403684091288596, 0.023267535652848892, 0.010158189925277838, 0.02054965170827927, 0.07233581301989034, 0.013397171005635755, 0.0826552502985578, 0.048226232902379707, 0.04112070695555303, 0.019462498130451422, 0.059034886508015916, 0.021116613570484333, 0.016617476867395453, 0.060957520254305564, 0.06746640399796888, 0.03641839990450535, 0.01811484144127462, 0.061885587056167424, 0.02437631912471261, 0.006499753008029074, 0.0171831585248583, 0.0033441329696870525, 0.08140464982716367, 0.0383019707078347, 0.025967240690079052, 0.03815977521298919, 0.006225229799383669, 0.05440405569970608, 0.03145553593640216, 0.04875801510934252, 0.02030370211286936, 0.03889209314365871, 0.010632241392158903, 0.03191597177647054, 0.05141988360264804, 0.06995974559686147, 0.16916843655053526, 0.0107718059734907, 0.015099108586582588, 0.0659495654690545, 0.07243675252539106, 0.037002796671004035, 0.07934435139759444, 0.07507317277486436, 0.06696739874314517, 0.08290734302136116, 0.08818416885333136, 0.09861547005129978, 0.12229546540766023, 0.11106316422228701, 0.13625699240947142, 0.18673841172130778, 0.0890427669219207, 0.14863827178487554, 0.2614079526392743, 0.0766201424994506, 0.07072100357618183, 0.11195898099686019, 0.08859709982061759, 0.17101767560234293, 0.1166605310572777, 0.1610986641026102, 0.12964454566827044, 0.08521232011844404, 0.0887738645542413, 0.3138709062477574, 0.07360608040471561, 0.2197240261011757, 0.16091416619019583, 0.1126540319819469, 0.14970473799621686, 0.13418219983577728, 0.1925947584095411, 0.12865296215750277, 0.15464297379367054, 0.1808199769584462, 0.11221279550227337, 0.2616340998793021, 0.11101545896963216, 0.1267538359388709, 0.1743189711123705, 0.15630893205525354, 0.20787955698324367, 0.20274508249713108, 0.22275846014963463, 0.1713673013728112, 0.1464695084723644, 0.18372965598246083, 0.18588430364616215, 0.09098093010834418, 0.19054889475228265, 0.17813896847655997, 0.17150762665551156, 0.09874795083305798, 0.08725116305868141, 0.0831487042887602, 0.13903747836593539, 0.12311307466006838, 0.08449185057543218, 0.1820335368392989, 0.07534701784607023, 0.27206700411625206, 0.11904836152098142, 0.14806160819716752, 0.17196471540955827, 0.0908986630383879, 0.11696732006384991, 0.19471972016617656, 0.14178771438309923, 0.11561566134332679, 0.1288630344788544, 0.19100501871434972, 0.28756669897120446, 0.25277820008341223, 0.11809306903160177, 0.13576162367826328, 0.08940303509007208, 0.058745319038280286, 0.15918424964183941, 0.08352913660928607, 0.20014024805277586, 0.1772041741060093, 0.1642612522118725, 0.14918026223313063, 0.14792960981139913, 0.0735333796183113, 0.06695574702462181, 0.16597803274635226, 0.1136731194856111, 0.1806209032656625, 0.12303122319281101, 0.15340382466092706, 0.11031582893338054, 0.08960276187281124, 0.1286709518171847, 0.2265460553462617, 0.09640994074288756, 0.2093486679950729, 0.06469502419349737, 0.18586436955956742, 0.12450276102754287, 0.2117927384097129, 0.18426306720357388, 0.08998271921882406, 0.11515208621858619, 0.0931273250898812, 0.20221416489221156, 0.1296264521079138, 0.1798869637423195, 0.08381447012652643, 0.1304967686883174, 0.1794564735610038, 0.1953068925649859, 0.13936173752881587, 0.13543216948164627, 0.22361178154824302, 0.10715598677052185, 0.11153614235809073, 0.06066255737096071, 0.09424278789083473, 0.11805494490545243, 0.14083754271268845, 0.09455546954995953, 0.23653484357055277, 0.1284142874646932, 0.1334181588026695, 0.18620865186676383, 0.18133440404199064, 0.07324905542191118, 0.1850490758079104, 0.1874006597790867, 0.2403637912357226, 0.06764585530618206, 0.23695544834481552, 0.12555390188936144, 0.16054754523793235, 0.1555023659602739, 0.08246621044236235, 0.1675407137372531, 0.13533975725295022, 0.09866850392427295, 0.08541652205167338, 0.16498597426107153, 0.10781574121210724, 0.13666775630554184, 0.0956571803544648, 0.1890494002145715, 0.1811560065834783, 0.0817281223135069, 0.17183449817821383, 0.20961716218153015, 0.126115707680583, 0.13479089451720938, 0.19243739341618493, 0.14757682249182835, 0.06484522004029714, 0.12556178349768743, 0.19747855025343597, 0.20753901510033756, 0.17236356041394174, 0.10579387861071154, 0.1230814443260897, 0.07068769598845392, 0.11610818022745661, 0.08156708368915133, 0.095326130540343, 0.0798029318684712, 0.11673224478727207, 0.08384845306864008, 0.20311424159444869, 0.1385804044548422, 0.10638690655468963, 0.30641674529761076, 0.13956112292362377, 0.09777325118193403, 0.1089975074864924, 0.13797623687423766, 0.11748306074878201, 0.19259891443653032, 0.18364260205999017, 0.15049358160467818, 0.19001393986400217], [0.042150210501858965, 0.05979902773106005, 0.024207632668549195, 0.04532027945970185, 0.029598860564874485, 0.01767378122167429, 0.05504650325747207, 0.025119194106082432, 0.011403048956708517, 0.03541355050401762, 0.020566676575981546, 0.0037423939966174657, 0.03744821144209709, 0.05924026103457436, 0.030004772670508828, 0.06049467614502646, 0.028409719197952654, 0.02584365454822546, 0.048957188992062584, 0.04648147340049036, 0.025219298695446923, 0.02566757259046426, 0.04350570612587035, 0.01629832182516111, 0.03549368761014193, 0.015706043450336438, 0.07789514478645287, 0.024021390709094703, 0.11019224650226533, 0.056565523700555786, 0.07274976072949357, 0.01090527937776642, 0.048180683588725515, 0.0342013673071051, 0.06590659511857666, 0.032469335637870245, 0.02059416387055535, 0.005680958174707484, 0.03359203437867109, 0.04252371858456172, 0.047477632251684554, 0.014279497390816687, 0.02616673184093088, 0.034698075614869595, 0.034327558387303725, 0.07077215981553309, 0.012206592655275017, 0.04725995291664731, 0.049550795811228454, 0.02757090678642271, 0.022990848156041466, 0.04124783314182423, 0.03184702254657168, 0.0662536382151302, 0.03608703838835936, 0.013108584098517895, 0.0011153489276694017, 0.05975594976916909, 0.03912657099135686, 0.03110791582003003, 0.05301766075717751, 0.04154043228481896, 0.07801457119057886, 0.04764269702718593, 0.03409209719393402, 0.054743885120842606, 0.021609798532153945, 0.13344588543986902, 0.030849420218146406, 0.07873257680330426, 0.0377303685672814, 0.0855077468440868, 0.01913408108521253, 0.020035656925756484, 0.04098874567716848, 0.037023843979113735, 0.02352764171519084, 0.025091172465181444, 0.01841341487306636, 0.08135007228702307, 0.03182858017680701, 0.030022359715076163, 0.020143758156336844, 0.014410760122700594, 0.014126584355835803, 0.06789425213355571, 0.02989373439049814, 0.01242072730747168, 0.050623195493244566, 0.019164197437930852, 0.030710584796906915, 0.018864811354433186, 0.0438241728261346, 0.059815054410137236, 0.02213049305282766, 0.05487743459525518, 0.031690807882114314, 0.0685650497325696, 0.0033106268574556452, 0.07391850231215358, 0.025335134960187133, 0.06775771922548302, 0.03425681316002738, 0.08208973376895301, 0.06923798471689224, 0.006069599112379365, 0.028543068292492535, 0.024255794342025183, 0.07027620478766039, 0.032805791997816414, 0.05647659214446321, 0.025998594574048184, 0.005729339709432679, 0.08986807224573568, 0.016145949630299583, 0.011509840296639595, 0.019273298712505493, 0.04306886316044256, 0.01733118358970387, 0.05156090650416445, 0.029353844220167957, 0.05021504024625756, 0.03431455224927049, 0.05399579655204434, 0.01116698476835154, 0.04615809739334509, 0.03607536440540571, 0.02981815592647763, 0.031180347577901557, 0.014979369552747812, 0.027598874621617142, 0.09689460770459846, 0.03587136285204906, 0.03564659971743822, 0.019427915904088877, 0.05863150327058975, 0.02645893022418022, 0.012142791147198295, 0.07590807406813838, 0.12372127210255712, 0.09169454220682383, 0.05109028468723409, 0.033763882383937016, 0.03310052852611989, 0.017941754049388692, 0.003803196300395939, 0.020544846302072983, 0.04810452439414803, 0.029803522629663348, 0.04069895927386824, 0.049169365302077495, 0.07037698102067225, 0.09341028373455629, 0.023645565270271618, 0.03894641835358925, 0.08899508393369615, 0.024645856028655544, 0.018197381250502076, 0.003781651985264034, 0.023154914742917754, 0.04798801091965288, 0.02449418701871764, 0.04627257367246784, 0.03884437304805033, 0.005258879773464287, 0.05654982727719471, 0.07729868069873191, 0.04909877592581324, 0.10078404782689176, 0.019663408638734836, 0.04442621044290718, 0.029699200786126312, 0.031968326584319584, 0.011805235481006093, 0.057281803819932975, 0.025197577888320666, 0.053518951826845296, 0.01616779660253087, 0.12494164489908144, 0.028787511328118853, 0.04845799077884294, 0.051282348795211874, 0.043189465868636034, 0.022443336129072122, 0.05971790727926418, 0.08521551135345362, 0.026851852890104055, 0.010119570415554335, 0.03246293461415917, 0.016640485300740693, 0.04332795804657508, 0.05815659555082675, 0.015469392037630314, 0.048371122393291444, 0.03050864084798377, 0.04857843021454755, 0.10408866073703393, 0.04304124784539454, 0.013501568919309648, 0.05819507590786088, 0.030579705198761076, 0.027769245753006544, 0.015403527359012514, 0.0070037955902080284, 0.044679227139567956, 0.0625656615011394, 0.02911964838858694, 0.06124982253822964, 0.04955138581863139, 0.06918413448147476, 0.0377334447694011, 0.02719547654123744, 0.005960438002148294, 0.020046848512720317, 0.028740325578837655, 0.05391423081164248, 0.012544529599836096, 0.029058109503239393, 0.02530834528442938, 0.0240850873888121, 0.013650136679643765, 0.08462519966997206, 0.018531998939579353, 0.07529206923209131, 0.041848534892778844, 0.03739566367585212, 0.04801036811841186, 0.022772369156882633, 0.027373044649721123, 0.04960536592989229, 0.025193299406964798, 0.05770443094661459, 0.050356052015558816, 0.12160147569375113, 0.04622697611921467, 0.0468618240847718, 0.0161174622917315, 0.04684048362832982, 0.0693832675460726, 0.03460955595073756, 0.061530287566711195, 0.005602431065199198, 0.09404004798852839, 0.09883754290058278, 0.037822806771146134, 0.04864460752287414, 0.07833370953449048, 0.013890232585254125, 0.041740585802472197, 0.020478344304137863, 0.03879295334627386, 0.04609798714227509, 0.022714568840456195, 0.07595203889650293, 0.04559338980470784, 0.05485873989528045, 0.008209647803596454, 0.012097133294446394, 0.025786434962355997, 0.0568012483563507, 0.0329383210191736, 0.062177533109206706, 0.03954878993681632, 0.06487556645879522, 0.015739846421638504, 0.10693739459384233, 0.014665421604149742, 0.019567365452530794, 0.024236264725914225, 0.04920980863971636, 0.025155724470096175, 0.024193897370423656, 0.0349284679396078, 0.06388613517628983, 0.014197998443705728, 0.03394921150174923, 0.05918870403547771, 0.018773521624098066, 0.05415374784206506, 0.06836415777797811, 0.054175422264961526, 0.027045651768276002, 0.029915594350313768, 0.05405589196016081, 0.051933620488853194, 0.04735069160233252, 0.019058305952057708, 0.02076139200653415, 0.042186223217868246, 0.0284755736720399, 0.03352359723066911, 0.03553941132850014, 0.035703169924090616, 0.021311323434929363, 0.05731854755140375, 0.010927571638603695, 0.0253627187339589, 0.025542375988152344, 0.03354810665769037, 0.028296717937337235, 0.03677809290820733, 0.03214350683265366, 0.045514570010709576, 0.05015523798647337, 0.006248920544749126, 0.07399345180601813, 0.07405227443086915, 0.06404659492545761, 0.026195187638222706, 0.028104147313570138, 0.05895675320061855, 0.05170369571715128, 0.038373265124391764, 0.018891567633545492, 0.013787063853669679, 0.03932574487407692, 0.07863137012463994, 0.02688481537916232, 0.025766773615032434, 0.01510155581854633, 0.030282026054919697, 0.03157494749757461, 0.10576403685263358, 0.03927933095837943, 0.02590215804957552, 0.02138189611287089, 0.06399164631147869, 0.04146353465330321, 0.048626402640365995, 0.02015472524362849, 0.0758750930253882, 0.03427940042456612, 0.0641028348763939, 0.01760546838340815, 0.03113766295427922, 0.008715288786333986, 0.07135401843697764, 0.037781851351610385, 0.03077529265283374, 0.053123635734664276, 0.029604998126160353, 0.03325427926029079, 0.038795239161117934, 0.050135315032093786, 0.08382298256037757, 0.023771702544763684, 0.046590224010287784, 0.0026493030054552946, 0.013980158619233407, 0.017442127245885786, 0.0587335856835125, 0.08637531005661003, 0.11115479719592258, 0.087913707975531, 0.23235955042764544, 0.12004191914456896, 0.17826733033871278, 0.10432060415041633, 0.15809948206879199, 0.09484147100010887, 0.1858791382983327, 0.15684516343753785, 0.13833230448653921, 0.19771698745898902, 0.12075533828465268, 0.1216532924445346, 0.14544874371495098, 0.13952569279354066, 0.0864595289749559, 0.17781117669073865, 0.12022734474157915, 0.18102657602867112, 0.16728707734728232, 0.14939670218154788, 0.18916418077424169, 0.11970655745244585, 0.10402701052953489, 0.14752879069419578, 0.13913697068346664, 0.1156402264314238, 0.18678801687201485, 0.1582269385107793, 0.10485685779713094, 0.13493162055965513, 0.1710119759081863, 0.16664219554513693, 0.17300741805229336, 0.13828427268890664, 0.15147400321438909, 0.08962580555817112, 0.1213125501817558, 0.22667881072266027, 0.1728467727662064, 0.151700432470534, 0.19840262801153585, 0.11702039846568368, 0.16313867963617668, 0.23254216328496113, 0.16678988293278962, 0.20077665452845395, 0.1204360811971128, 0.15127617632970214, 0.21086929889861494, 0.10726109714596532, 0.07857379430788569, 0.1725211925804615, 0.11621817393461242, 0.13760437635937706, 0.08133712923154235, 0.22688413329888135, 0.11302783692372032, 0.09375363093568012, 0.16636497370200232, 0.18813854752806947, 0.17957434145500883, 0.10601604051771574, 0.11361955126631074, 0.12062651629094034, 0.20017011207528412, 0.28415121661964804, 0.14451527036726475, 0.15193489176454023, 0.13435084547381848, 0.16862879128893837, 0.13224519439972937, 0.07399878784781322, 0.12990333256311715, 0.10752085625426844, 0.1393433174234815, 0.14439335034694523, 0.15718055481556803, 0.1572890271199867, 0.11418553534895182, 0.07134242609026842, 0.08523565324139781, 0.14672525256173685, 0.10504499223316088, 0.16879832750419155, 0.1031689096998889, 0.1825305086094886, 0.1690976505051367, 0.16561454365728423, 0.10541552430368029, 0.12784716789610684, 0.151953044696711, 0.11368394742021337, 0.10090859504998662, 0.16225700819632038, 0.17335236829239875, 0.19136782502755523, 0.14172509196214378, 0.1452939020236954, 0.10642961715348065, 0.18481601175153628, 0.135308780008927, 0.28654624591581523, 0.14732452196767554, 0.17257620056625456, 0.1098824517976027, 0.12469115521525964, 0.12785582133801654, 0.2010106685338542, 0.09848033980233595, 0.11679673742037266, 0.1007544064486865, 0.2051266937633045, 0.13250377349322662, 0.15551385440630838, 0.11331808345858008, 0.12433630472514778, 0.14002731040818617, 0.19541738351108506, 0.1465063338400796, 0.15778176864841953, 0.22596575523493811, 0.09520913838059641, 0.14047561213374138, 0.08296871121274307, 0.1540937993559055, 0.12705597910098732, 0.13122131262207404, 0.1022717051091604, 0.2095201486372389, 0.2317701664287597, 0.0842145099886693, 0.08002438873518258, 0.12323040820774622, 0.19399798155063763, 0.16196823853533715, 0.08369059825781733, 0.21643147309077904, 0.18222895916551352, 0.2904614608269185, 0.1364144909894094, 0.11349182022968307, 0.11627967571257614, 0.12942877365276217, 0.20421944791451097, 0.17370466579450294, 0.12719268270302564, 0.15493616665480658, 0.10648161944118328, 0.15690388216171414, 0.1942988927476108, 0.2564172470010817, 0.09089847007999197, 0.16269975865725428, 0.19380303419893607, 0.14102520217420533, 0.1565920762368478, 0.1792842656141147, 0.1030634727794677, 0.12042770234984346, 0.10046647541457787, 0.10846984790987335, 0.1876369447563775, 0.1381336760823615, 0.27997800149023533, 0.1852000434882939, 0.11873124924022704, 0.22327048267470673, 0.09399555623531342, 0.13962922239443287, 0.08970289985882118, 0.14951951277907938, 0.057355799654033035, 0.15270972362486646, 0.32431868312414736], [0.007139681438275147, 0.020636937551898882, 0.035985427239211276, 0.03425402639550157, 0.10089947405504063, 0.08258909525466152, 0.044483827077783644, 0.03568548825569451, 0.0061289899440453155, 0.09528540147584863, 0.04708207125077024, 0.033531805383972824, 0.022493651886179578, 0.05542498744034674, 0.02543552156566875, 0.05920524650719017, 0.01650987658649683, 0.058581812772899866, 0.021971409987600055, 0.1416328430059366, 0.0420652383036213, 0.027456122516014148, 0.04649980073736515, 0.010773652065836359, 0.03182987893524114, 0.058493712422205135, 0.05139249835337978, 0.015651061439712066, 0.03575176575395744, 0.04381504069897346, 0.05275085124594625, 0.06355303703458048, 0.04499763446801808, 0.03620551484345924, 0.07015147944912314, 0.04810419042769354, 0.04198812544927932, 0.012638817606784869, 0.04387228997074999, 0.028843777254223824, 0.04271744881407358, 0.04075792290677782, 0.03891066167852841, 0.041662812436698005, 0.05527580091438722, 0.05562435799220111, 0.03661497627035715, 0.07666761026484892, 0.01534863440610934, 0.052463788524619304, 0.06283675320446491, 0.011524645215104101, 0.029439875834214035, 0.06960516970138997, 0.035406073366175406, 0.05488193201017566, 0.04361630097264424, 0.025764292986423243, 0.010754342310974607, 0.030935956492612604, 0.0401320141099859, 0.028902202830067836, 0.06581405672477558, 0.07091089690220542, 0.05976160864520352, 0.03746386333659757, 0.023441535886377096, 0.017515041399747133, 0.061589180695591494, 0.04444520571269095, 0.041494990582577884, 0.0328900962631451, 0.022805942062404938, 0.036222721537342295, 0.025125667489191983, 0.008363449560420122, 0.033812871552072465, 0.022361681330949068, 0.04977194097591564, 0.02216822384070838, 0.006685712023681845, 0.016593242035014555, 0.06530196740641259, 0.07080231327563524, 0.008232208165281918, 0.025834787738858722, 0.029823742443113588, 0.01707571038423339, 0.024774911798886023, 0.020927562582073733, 0.05402885923103895, 0.010982101866829908, 0.03810850023000967, 0.04624365959898569, 0.053989228545106016, 0.04197571302938741, 0.02490254264557734, 0.07135064908652566, 0.014157508721837075, 0.02511202124878764, 0.04412021182361059, 0.032297888392349705, 0.008265813539765077, 0.03208313682989683, 0.03624039949500002, 0.05225212429650128, 0.03929634469386656, 0.04316359460062813, 0.04462684264581185, 0.020428813368198462, 0.023038391991576646, 0.023219822978717275, 0.04175404836132657, 0.017466412173234858, 0.06964582455111668, 0.038477225170936435, 0.0631605448143091, 0.016372399295505602, 0.019001611435669474, 0.08296839208924212, 0.07916941976873204, 0.01202078577989596, 0.049235464684898034, 0.01501619306509383, 0.03373222236405127, 0.008571694343117997, 0.032955264250631444, 0.047498761196038686, 0.026840173341042828, 0.08548187557607889, 0.048858294103411026, 0.03026546874025371, 0.07330734370043501, 0.030822715889371466, 0.05336507863830775, 0.02546861578593962, 0.03328073311422486, 0.019710460801434238, 0.05810520924569573, 0.01111300280172145, 0.013649755401274888, 0.06335687998216599, 0.03379936817509588, 0.02088641791488044, 0.047350242602988146, 0.05437236228317488, 0.028358377421682235, 0.04302823799662292, 0.009334385595138883, 0.02343222007766599, 0.019862178050971124, 0.019115887334919535, 0.0697464300901629, 0.04324912712036166, 0.051393285029917024, 0.024151025354512967, 0.05845696869073436, 0.05970051133772358, 0.046349705080501735, 0.05499493512616027, 0.028478345593612175, 0.04629978080629371, 0.03577286501240451, 0.006899170393808163, 0.034211813035653904, 0.044460289864218794, 0.060771200369345024, 0.03235698561184108, 0.039283464720938355, 0.02142902620107634, 0.06837600245489739, 0.04914029166684486, 0.05070079074357636, 0.030324762628879398, 0.11076689886976965, 0.01988996591535397, 0.07329476429731585, 0.03551196299667936, 0.09674712811829522, 0.07462695648428053, 0.03222869425371755, 0.045673782951780595, 0.03543872786394786, 0.02593928398709977, 0.0324599623127142, 0.04942214822222013, 0.09118687608861364, 0.029086559734423645, 0.08423785053309985, 0.013195591636758763, 0.026217121812806, 0.02020079962676391, 0.048477286618435755, 0.042197641159873456, 0.05551300615479704, 0.031827062484808266, 0.055551226760144345, 0.03607857790484559, 0.08483583602355793, 0.04450742737390101, 0.016556878654228058, 0.09327209583716467, 0.01269970247449237, 0.02476159581419779, 0.04608045761415269, 0.034151854924857616, 0.030253794757300057, 0.015386036793643143, 0.01780946065991884, 0.027576565662457142, 0.016713505210645963, 0.04354156299086753, 0.021139547789061908, 0.024495235302310903, 0.026086106772709172, 0.04236630164086819, 0.05373257903556805, 0.030264567030826584, 0.019880195541190915, 0.025747618783498183, 0.037337624016799964, 0.007349233328568516, 0.018676799372769892, 0.06342322056298144, 0.05642808537231758, 0.029242894997878466, 0.030165186035446823, 0.040097151722875424, 0.04453978130186442, 0.04366839973954484, 0.03184835099091288, 0.0525939686485799, 0.12711008166661486, 0.02334431825147476, 0.04628936847439036, 0.04189326042251196, 0.01228298933710903, 0.0600586235668743, 0.06280465531744994, 0.026261112616339233, 0.04987980100850109, 0.027042668334615882, 0.02339282687898958, 0.06998108976404183, 0.04898921637504827, 0.025637255857873242, 0.015256529241014505, 0.02908383605245035, 0.015149738828768022, 0.01957662188942777, 0.025002205657074228, 0.08430949746980332, 0.05801156134111807, 0.06286252057179809, 0.04548265766061377, 0.01346003555227071, 0.01512281371105928, 0.033546106569701806, 0.04393427414470352, 0.011701276362146018, 0.08325581846293062, 0.044285792391747236, 0.06178868483402766, 0.04044541565235704, 0.021865342241653707, 0.006112116288932157, 0.04506894743826706, 0.010422114337416133, 0.06630011150264181, 0.06817764122388326, 0.08208103579818271, 0.053469131453312, 0.03811535767454188, 0.027558908113860525, 0.05065418386948295, 0.03985717827163171, 0.03898257949913386, 0.016237389645539224, 0.058668981728260405, 0.03357706526003312, 0.024022609686653595, 0.07471700868336484, 0.02557156465627486, 0.048213445697911084, 0.07234280405100435, 0.010370285526732914, 0.06177836527058389, 0.035933176332036965, 0.004432909299794119, 0.05539471523661632, 0.03944262942241039, 0.03318480681627989, 0.03899369316059165, 0.051842058019246906, 0.040829421413945965, 0.011878375062224222, 0.0437151513324352, 0.031198348369798623, 0.017670651213848032, 0.044004013761878014, 0.0963424498331733, 0.012530050298664719, 0.029896120395278558, 0.01967542957572732, 0.020941624425176997, 0.02690398134291172, 0.012633836868189974, 0.07217628095531836, 0.018541366698627826, 0.038463372984551825, 0.025541732175042853, 0.004871010669376119, 0.11149440397275612, 0.018639836707734503, 0.053757611676701345, 0.0194559078590828, 0.015547231269010808, 0.022742223118257243, 0.047564574852003716, 0.03536224212439265, 0.06612791839870624, 0.023012194178591017, 0.04752616870973725, 0.021088810863147955, 0.01731296015350381, 0.035649104465846904, 0.01675030460319249, 0.06804526434279978, 0.05338147639122326, 0.02701906989386771, 0.02082904062262969, 0.04692851347499527, 0.023781777199474163, 0.07975446220370941, 0.025624960326240398, 0.07005697436397895, 0.039329437058768235, 0.024152426158252638, 0.040080535036395304, 0.03692207326821517, 0.0026252263432979817, 0.07330972599447705, 0.0633775042661, 0.029864697862649336, 0.058747166985995136, 0.03917012763849925, 0.10501655313419178, 0.048186008498305455, 0.018613355023262557, 0.027685689201462083, 0.09660730749601498, 0.046480219170916826, 0.18281671043951064, 0.081433081504656, 0.1181330336839892, 0.11282800624030642, 0.1576858534826897, 0.16073974664323032, 0.1658446984947659, 0.07521863371948712, 0.09077517708647065, 0.2647006540792063, 0.2442327851895243, 0.1187859455239959, 0.10722844264819287, 0.19197760324459523, 0.07920881296740845, 0.15204278519377112, 0.10504679565201513, 0.15006840520072728, 0.22075941116781905, 0.1872059202287346, 0.18149084877222776, 0.17559101223014295, 0.15405339683638886, 0.1522738899802789, 0.150721094396431, 0.21478531532920897, 0.07903515041107312, 0.1273370155831799, 0.11468677446828224, 0.1764365707640536, 0.13424488162854686, 0.1650653692195192, 0.12384768953779712, 0.15652811795007437, 0.16579685965552926, 0.12585396703798324, 0.15430311468662694, 0.08210664731450379, 0.08486463877488859, 0.1231496773834806, 0.17097742151236162, 0.1123180691502057, 0.13622194819618016, 0.09340446529677138, 0.26180304237641394, 0.1406975439749658, 0.133461203367915, 0.20754685217980295, 0.1187888473214116, 0.12128250062232837, 0.15724739263532683, 0.11476905638119206, 0.11941487857257016, 0.1215305931691546, 0.13236732222139835, 0.1091475623252336, 0.18437562132021412, 0.17751479259459302, 0.0851393373159226, 0.18302264157682657, 0.10943213885184377, 0.16232311871135607, 0.16182677034521475, 0.16951993253314868, 0.20648164761951193, 0.16391452081734315, 0.09564742853399366, 0.09570489302859642, 0.1586940314155072, 0.14042195485671982, 0.16562364238779992, 0.1951547374483198, 0.08672524010762572, 0.18246990483021364, 0.07703282855800353, 0.15859491017181426, 0.12609549157787114, 0.1560117761255242, 0.15546537732006982, 0.13398979062912986, 0.1302764844149351, 0.09926959901349619, 0.12903571740025654, 0.12693962518824264, 0.12709629256278276, 0.13419696857454255, 0.1184466652921401, 0.09613208065275103, 0.09130727470619604, 0.13261662446893752, 0.10359063511714339, 0.16522994788829237, 0.11723924297257327, 0.25672796939034015, 0.1927160847117193, 0.10422882274724543, 0.09396100183948874, 0.15659051772672683, 0.1707410326343961, 0.09265340442652814, 0.20496307988651097, 0.12647852883674204, 0.14471219183178619, 0.20313300308771431, 0.09266190201742575, 0.16027330682845786, 0.12400066101690754, 0.15890894253971055, 0.252508147386834, 0.11249228089582175, 0.15257359889801592, 0.1641403860412538, 0.09692875391920097, 0.12096944046788849, 0.1584249731968157, 0.10726527543738484, 0.1377655559917912, 0.14735279779415578, 0.12174819086794741, 0.11084092810051516, 0.09902952166157775, 0.24261666956590489, 0.0863271817797795, 0.08827287776512094, 0.12219032534630969, 0.08048543313634582, 0.1384749007411301, 0.14841163472738117, 0.13073755108052865, 0.16939940775046125, 0.0875281028856989, 0.17404263984644786, 0.11854381242301315, 0.15684465877711773, 0.09111482097068802, 0.11453614817583002, 0.233440087758936, 0.1247979057370685, 0.22606633108807728, 0.16777193726738915, 0.12873158528236672, 0.1824217097600922, 0.10209392363321967, 0.15574400924379006, 0.13398930081166327, 0.2771657664561644, 0.15162459982093424, 0.20738442573929206, 0.16893719817744568, 0.13581158505985513, 0.07544860302004963, 0.12417139208992012, 0.24419731053058058, 0.14447290857788175, 0.13685669226106256, 0.12440618535038084, 0.14405184367205948, 0.2023262737202458, 0.09878591910819523, 0.15128569066291675, 0.1330685181892477, 0.19009640731383115, 0.18504738371120766, 0.14599434100091457, 0.12380960251903161, 0.1479869629838504, 0.14676062332000583, 0.1006798206071835, 0.17447443620767444, 0.1858375038136728, 0.17451897991122678, 0.11827487294794992, 0.21965608990285546, 0.14901373913744465, 0.1974861795315519, 0.10187032938119955], [0.03113294289505575, 0.027799139461421873, 0.008201647451642202, 0.07242615465656854, 0.03950701073335949, 0.011927848481718684, 0.05012803456338588, 0.022571751796931494, 0.056560057782917283, 0.05761393716966268, 0.1062789314892143, 0.04762421012856066, 0.03630835795775056, 0.037077504966873676, 0.004668486917580594, 0.06059470651962329, 0.03682411719637457, 0.006342390333884396, 0.047414197179023176, 0.02211952039942844, 0.05982453905744478, 0.014099506170168752, 0.055036595585988835, 0.012998684087506263, 0.030861719460517634, 0.048781199802760966, 0.06655730277998373, 0.05181514032301493, 0.03875240981869865, 0.030410471408686135, 0.06674424235825427, 0.042427406369824894, 0.01808684020943474, 0.026632422086549923, 0.07195844576926902, 0.045421820104820654, 0.032539498279220425, 0.062167558644432575, 0.030319296711240895, 0.008850970079947729, 0.06800733317504637, 0.007873635804571677, 0.013787119514745427, 0.007476904065697454, 0.017104370272136293, 0.028133603154856246, 0.06405611668014899, 0.009082927408599062, 0.029619377237395383, 0.023367113317362964, 0.03215047559933737, 0.04626762725820299, 0.034932249182020314, 0.026556750854069833, 0.048782379817566834, 0.010557618443272077, 0.08256268964032643, 0.06208200386026874, 0.032840543062775396, 0.01716620787192369, 0.017395030554325785, 0.0790074905671645, 0.010468617310834816, 0.030362259640241973, 0.035723478795262054, 0.052526952713378705, 0.0394703152414877, 0.04973796174454037, 0.01771620794897899, 0.05724339767766651, 0.04783808224601671, 0.04347638016042765, 0.052593512227758765, 0.03912712760211434, 0.03626580692071002, 0.008573030208935961, 0.09400736380484886, 0.05528626519662794, 0.07613353111082688, 0.03027084003406344, 0.07917393202660605, 0.029287225333973765, 0.0754759660048876, 0.05389122794440482, 0.06044064037268981, 0.039411774632753804, 0.03329708633827977, 0.021669864254363347, 0.04717356692708563, 0.0410617989837192, 0.09752135883900337, 0.04588827105180826, 0.03211975810700096, 0.09883135338895954, 0.048116361649590544, 0.02262157402583398, 0.08124980071443133, 0.04988583837985061, 0.07681730145122856, 0.01144622989158961, 0.05681529721186962, 0.016539883472432848, 0.037465340210474096, 0.020857514973613434, 0.03743889006727841, 0.04957117147569079, 0.03837972180917859, 0.01761734460160369, 0.02129443957528565, 0.054930590922595, 0.014178754554450279, 0.013309623554960126, 0.020172861477476545, 0.0463938443135703, 0.04776136644068174, 0.018968782533193007, 0.06545176249346696, 0.02082493283523945, 0.03547574990079738, 0.02098935565300053, 0.0338351285608951, 0.03811357652011793, 0.02516362648748327, 0.051442229669191875, 0.015042617233120836, 0.015339103374572005, 0.041341755641042255, 0.02394597922830144, 0.04433276662894059, 0.01786328120942926, 0.058682088056229986, 0.08600635133916512, 0.06866821568110026, 0.09488252660958096, 0.08808437225525267, 0.04798006993951276, 0.03153740966808982, 0.034786290998454206, 0.07431573685607873, 0.035094196937279776, 0.045189197626314126, 0.04519303824054077, 0.04626850670319982, 0.03257095791923348, 0.07409311481751502, 0.020675818668678403, 0.044876311876578256, 0.06484506418928504, 0.05231431256106589, 0.04105665590032004, 0.015847940230742097, 0.026462999048817437, 0.02309183961187955, 0.021171517655602656, 0.047767144060344435, 0.03269077024015132, 0.03617568792833481, 0.09096301466342993, 0.027043276895710733, 0.05400961163104512, 0.07952023297548294, 0.04283422575099394, 0.04352577008830849, 0.010703386451496044, 0.014861949730402557, 0.021308673967723735, 0.05639380186039489, 0.02316426209290512, 0.0232752799638547, 0.06606562994420528, 0.01512023103714455, 0.03255363248172216, 0.028263504973438103, 0.032590164701105095, 0.042366208872408606, 0.053266116956365295, 0.05233612428128254, 0.03821575170150027, 0.02011975895584328, 0.04622205196938012, 0.02019751562329475, 0.035514634728315286, 0.05760425585322082, 0.0042707852844614536, 0.060391458246158436, 0.010231632859358797, 0.04436941017047502, 0.07753584141028114, 0.06631519194343127, 0.015061047542985762, 0.02137848779966589, 0.06654598502791487, 0.02557433286710875, 0.02369798872678075, 0.030400231626117602, 0.04356734520115424, 0.006485132234956836, 0.0011917787742277142, 0.01597912225406617, 0.047094732290133834, 0.08085860725259408, 0.06064399625756778, 0.08001952024642378, 0.005291390480124392, 0.03734146463102661, 0.034772383150993846, 0.0946913642110303, 0.01900398259749636, 0.05821794518851675, 0.05369718601286877, 0.025055623591470066, 0.048387223287136294, 0.026708189798227977, 0.0542248493002262, 0.0425596867717104, 0.03891339278197847, 0.04458039162273053, 0.013170485708542401, 0.02324431941815419, 0.010718717367126374, 0.12178693097666837, 0.061542555267806165, 0.011104660134151345, 0.07801884596119635, 0.02743483586527873, 0.0609083344170358, 0.005479929850480403, 0.010933562625723425, 0.037608912389259785, 0.05324737401679158, 0.04833126535231713, 0.05891823944693897, 0.09896544463117607, 0.009471307203057222, 0.023580426968692336, 0.006104655849412666, 0.03060624068893958, 0.030263258995546494, 0.05872542576980777, 0.0123369091488712, 0.01017074057017453, 0.07962179588503204, 0.038840235574753024, 0.043604304155451246, 0.022089838203100953, 0.01894866847578669, 0.08494611916830763, 0.0638067327963654, 0.008797789632808417, 0.02036973284702981, 0.017673812762950547, 0.01290751681153779, 0.11332183872582391, 0.027617663945420645, 0.028478141503001098, 0.05678299152350519, 0.10448884902871214, 0.039182421314762905, 0.0793417687236797, 0.09001956685096957, 0.05352057713025715, 0.01684244223724818, 0.07862251630285755, 0.03284766396973282, 0.036424659920157865, 0.05009967338992283, 0.03991013050836045, 0.024664574848429766, 0.03938793684937991, 0.030871333983668592, 0.02137675488484092, 0.02543228394642938, 0.05113075771078002, 0.0026109891678061103, 0.025054844336409587, 0.030774416918575298, 0.03340542876685504, 0.030018491270311642, 0.05550068279262632, 0.10622091038385406, 0.051091071363771334, 0.04780251481861342, 0.031997693367884494, 0.04385871237900574, 0.06796608460717835, 0.050034683517878875, 0.00807719578006072, 0.04384251500596292, 0.012191567875561304, 0.03180527302902192, 0.03614586472394876, 0.08285928895929828, 0.05717484178603627, 0.024539326295780484, 0.0553607026085956, 0.009231167696270859, 0.05003015270631295, 0.005438567177407094, 0.04800772978342138, 0.07888850203016773, 0.07661435374757275, 0.026972360974468756, 0.079503133893013, 0.030602682090830058, 0.04783531403518282, 0.03155954793328419, 0.020135460945311934, 0.017796255997382104, 0.04239231762767304, 0.023937490914249793, 0.017059603924280964, 0.023088921116141137, 0.053949256471241824, 0.031707161106169224, 0.030538079990947153, 0.04024959998787381, 0.03169632575009018, 0.04426139799761586, 0.05310630287567619, 0.009442716891499003, 0.04448913343367167, 0.029920191955170594, 0.0232973236052203, 0.05461380147607997, 0.06898484556586482, 0.014358147418533918, 0.019921152816095855, 0.037255297575029545, 0.028039962671755347, 0.022734940794180147, 0.052993774734204635, 0.022138255917525385, 0.028189314325572923, 0.06847412922070362, 0.029325542418519035, 0.07526271729147993, 0.03514631425787229, 0.10334424208849669, 0.05221114661253523, 0.01983667229069397, 0.033604725103941746, 0.012262870641279733, 0.047982392861740664, 0.05957492510788143, 0.04498529255215544, 0.007048923735055723, 0.04808680932910647, 0.044018507906002924, 0.00822798720037099, 0.02421707278699614, 0.04484388373384718, 0.04750069077999797, 0.08535292741726153, 0.13113718276144937, 0.15030356211354956, 0.13341763929929584, 0.13870517432224005, 0.07083207339746878, 0.1112671583541669, 0.21474483859492466, 0.19032345997402444, 0.15914645948214456, 0.1481299303122796, 0.3120885050157085, 0.1429871140862815, 0.08098555903416127, 0.0768507352040615, 0.24716379353776574, 0.1242131156323012, 0.056945930045912974, 0.11192140605999157, 0.12260581672308035, 0.07747561612632126, 0.10098633501911536, 0.24363952717976645, 0.1466889021685347, 0.1876852585701272, 0.10783333753352053, 0.16460262530017644, 0.11046157931559719, 0.26299424876924604, 0.13934392598457634, 0.2276358101516962, 0.13815574755426496, 0.05943418051174376, 0.10584516101516783, 0.21185783960390836, 0.14789842476602644, 0.14408746676053852, 0.26023785292636603, 0.1978193741524592, 0.12667363946093246, 0.09868092005490325, 0.09253923242795281, 0.0724051815632265, 0.07360467032412998, 0.1770117797423154, 0.14832202781690285, 0.16317174973664805, 0.1645322993863374, 0.15447961224708706, 0.14365185576025397, 0.10914805956417695, 0.12300518123083748, 0.17207387048983946, 0.11175687934155576, 0.1478183618746698, 0.1280665912781842, 0.2034569950774312, 0.2075871656415984, 0.06631661686697043, 0.0686061498709023, 0.10249607119476423, 0.18615006672916934, 0.13470536941895261, 0.1275247789453715, 0.13935072405729443, 0.11852480602101423, 0.14247614541091025, 0.18873137509217486, 0.11090058193076402, 0.1598507576272823, 0.11977401867625304, 0.1373371883528307, 0.13944375969003886, 0.16987807815894485, 0.11821887790574692, 0.11829263996332884, 0.18390539655229077, 0.17404519283445552, 0.10446384607348591, 0.1696741656633094, 0.1831058511743322, 0.15487606753595173, 0.18559857679065317, 0.2437742566689849, 0.1447213944629766, 0.13125524361385033, 0.17127534927567467, 0.1379706707666628, 0.10292973776813596, 0.12540162802906707, 0.20545363950077444, 0.15868512564338744, 0.12148402340244502, 0.2053556908504106, 0.1816100673750043, 0.17260907770833, 0.18351456674281508, 0.13854518212610856, 0.17416755814338103, 0.09042840858455747, 0.1006276105181314, 0.08931589953135699, 0.2077585126971826, 0.22664238611469045, 0.16072447324404493, 0.19912414398277178, 0.14582026284188032, 0.13596086064353585, 0.14409680297831073, 0.09642629025620408, 0.14682801032904536, 0.2071493281982839, 0.10056293234811164, 0.18996383005287498, 0.10234227593173273, 0.1789449408533983, 0.16019885457353666, 0.21138604148291051, 0.1951326066046022, 0.06185896250826772, 0.10319936744053848, 0.1993087012670003, 0.13759833527728915, 0.16977876395685598, 0.10525395133299753, 0.14887090539559722, 0.19752144638914615, 0.08495688030961901, 0.11034388211555779, 0.09671626961790025, 0.10402111787698232, 0.13040153629845008, 0.1392386300722137, 0.15758613852085546, 0.1957715512253344, 0.18039662623777986, 0.1749470506911166, 0.16376408748328686, 0.17637366632698104, 0.11625658007687889, 0.22829920111689717, 0.1827159564709291, 0.16644307732349262, 0.08193363042664714, 0.20440339663764462, 0.09422991162864491, 0.11446285367128439, 0.12500316894147545, 0.16588397294981405, 0.10140852056792937, 0.09332515939604491, 0.1196055363107007, 0.12774279224686325, 0.13886400876799598, 0.21291352983098477, 0.07133389881346375, 0.10136978788068518, 0.14178437471855432, 0.09256201636162587, 0.19095618539722636, 0.21227399149211124, 0.24136425083270296, 0.17121250421041623, 0.15592976880725473, 0.12780642398865893, 0.06939117141882889, 0.23043554741889238, 0.14459044992690906, 0.11780629574786872, 0.12270726831047796, 0.10158403107197955, 0.08255448890849948, 0.09631859720684588, 0.21436074748635292, 0.17247724259505048, 0.1736804866231978], [0.0242350086409715, 0.037204976251814514, 0.03522095947118942, 0.011279710506642004, 0.019272907229606062, 0.028763289483322296, 0.033513949310872704, 0.06589532931684516, 0.047555565179209225, 0.0354272319964366, 0.020453951765375677, 0.09916094859363511, 0.026140530317206867, 0.04463656478037592, 0.030764123330300208, 0.02196432433265727, 0.10936663689790294, 0.029959223356854636, 0.04604351350280922, 0.04113834038435016, 0.02006556733249454, 0.047553739495924674, 0.04389967522001825, 0.01216579401443596, 0.03559060838597361, 0.031601345690432936, 0.007887289466452785, 0.012839021219406277, 0.027786658392869867, 0.010919667765847407, 0.06890650445711799, 0.032885205509955995, 0.03202038453309797, 0.02008720279263798, 0.037643670875695534, 0.030505731629091315, 0.06755486800102517, 0.09289222754887305, 0.041963627154473215, 0.039865846556494944, 0.011227120066905627, 0.042794198016054, 0.04303424939280376, 0.04989300010493025, 0.022198368023964576, 0.021076361335872207, 0.02182575608458137, 0.029397102152870502, 0.03258754120906815, 0.012333146460150601, 0.03632236228440888, 0.018208559849881567, 0.030624623686890118, 0.06245093289180659, 0.014338042637973558, 0.0019651970751510817, 0.04602556466124952, 0.03910710074706003, 0.02286601891682949, 0.0208736344211502, 0.08871656333212741, 0.08997221782919951, 0.04026906281069387, 0.12335811697994359, 0.013530400428862777, 0.04442302291863598, 0.03217381985450629, 0.018569757557997946, 0.03564356062270235, 0.02084031941194553, 0.07866295592975803, 0.03556510077032726, 0.018146781621908303, 0.010454653802298708, 0.004026242986583384, 0.05774474069767166, 0.012155194290244253, 0.020753348981088493, 0.047576875949744135, 0.04161704047874082, 0.01999337491724873, 0.017662101672613062, 0.024608253261249047, 0.07199188694357872, 0.026491076350794174, 0.053996111964806914, 0.049929944216273725, 0.027892727994185407, 0.053145072670304216, 0.030303032544907182, 0.036763862226507626, 0.020670723824878223, 0.01737299247906776, 0.048299928166670725, 0.08302873611683026, 0.05314650130458176, 0.029946276590635534, 0.03997914282081183, 0.010112970867339754, 0.11450005753431469, 0.0756282769725658, 0.09052724781213328, 0.059580706438282505, 0.023729082859063055, 0.027070910764450673, 0.07668867983738892, 0.05780025334388483, 0.08741335943341255, 0.057388309433008544, 0.014219348176993662, 0.034789493365678936, 0.05558639713854063, 0.03783216525334865, 0.022243331040954217, 0.007052646069496404, 0.05303862642904278, 0.05242133767751511, 0.04819117013539653, 0.034049501628032885, 0.016193081573874224, 0.022660039539914578, 0.051164254546165466, 0.016976175393210724, 0.042780390358529985, 0.04579617794661317, 0.03270785076892935, 0.04332430296926759, 0.010996723103744444, 0.03166588656313252, 0.005901074537177919, 0.025722272584971506, 0.036037054742337205, 0.019676613301271573, 0.03363724230439402, 0.022081164352130145, 0.027701444996637292, 0.02931415416242089, 0.0399128207936883, 0.01127306735725142, 0.03626142082794104, 0.023668477224418893, 0.04968820445355959, 0.030871686503815, 0.026538429083302617, 0.02581679251306923, 0.014557089380105026, 0.03930610022507608, 0.07696476619457826, 0.08434422255959362, 0.04411954389070161, 0.020480479834077414, 0.04419883494847454, 0.04912631331535522, 0.04717919982795138, 0.029874060055590235, 0.0038559414315386675, 0.0357076005457202, 0.016395214770454913, 0.03407718373637181, 0.015419988194480538, 0.07203858287539333, 0.03518944045936223, 0.01253453843673924, 0.05685418575012591, 0.016888457248569466, 0.08599542692536488, 0.04561205110803712, 0.026679925103962887, 0.08387122958083637, 0.09147309276158921, 0.03127592877717689, 0.027494949827087112, 0.020803143379453104, 0.03245910142140929, 0.06056522841390688, 0.02533058559492929, 0.06374036995111965, 0.013117407306708628, 0.02757295882474864, 0.032795409351820126, 0.030618816381320357, 0.04014385136542842, 0.02240210054878844, 0.029023386268818285, 0.03478443934000097, 0.010419889749755384, 0.03659405883809086, 0.06380668084602803, 0.025044085050467402, 0.07197499566245824, 0.021159476309549063, 0.008935999794630334, 0.05211073032114655, 0.0192063922440866, 0.026252173447574023, 0.04742715507745743, 0.011780580407503294, 0.04539539593679365, 0.04794959364517126, 0.10040509238024242, 0.0288037012796849, 0.03318282528198324, 0.061721795063931495, 0.029696369492739905, 0.01641513401409611, 0.025892361700243782, 0.042314521997468546, 0.036044183070771396, 0.04360510196420364, 0.062196558064897545, 0.012990725481358822, 0.020264038030290976, 0.03654550753708463, 0.021654435004165862, 0.00696642335242359, 0.03874514419294428, 0.03002378834935371, 0.005335305677363067, 0.056188520102296025, 0.037370434365584515, 0.03560466837370768, 0.006745692398908432, 0.025088146358029917, 0.020097386914130766, 0.030873161522322334, 0.024018865551624913, 0.02148725325241685, 0.006828058267274173, 0.04340727136877831, 0.044920272994204424, 0.02125453800545074, 0.024159415333997458, 0.08952625386882573, 0.022719708213116974, 0.00769378883887839, 0.032079860247904435, 0.05909925668674987, 0.03161390653986018, 0.03562744488590397, 0.07427863689372316, 0.02193749198340811, 0.043747223244281486, 0.05380505717766937, 0.05085520569991786, 0.022738543921150267, 0.029223576893855352, 0.02876523205486592, 0.039669452016823925, 0.04983755796274636, 0.02437420956994174, 0.03433358091569971, 0.024901574142859317, 0.037459291706909426, 0.005405444662756054, 0.008571159069106216, 0.030555431403627153, 0.011063545152865117, 0.0252176882349886, 0.06514337044791318, 0.05448860858450644, 0.05125654432049487, 0.001280624751416326, 0.014848236696707318, 0.07016353934886865, 0.021734713118348736, 0.047594008428859524, 0.0592939888156252, 0.008689038095326396, 0.04812319682969246, 0.021166101832932327, 0.03651759536296595, 0.03586103215639014, 0.03266271705797408, 0.02053467331279535, 0.07430090874549933, 0.10213655259576626, 0.04783211166795809, 0.06385217449860647, 0.0719605312042404, 0.04122081896639429, 0.03216096585674677, 0.06859494344098493, 0.06269427569350228, 0.07510603507398628, 0.016507160326000303, 0.05397111272031907, 0.034994507950614206, 0.06370148141286336, 0.039763760432833806, 0.07888187465141527, 0.0803583774541039, 0.02939908554253634, 0.01602485339390114, 0.05523670828551985, 0.029118787497282028, 0.04481107338506263, 0.03652408173365984, 0.046716307479073294, 0.023986769519979134, 0.04160131065873429, 0.051323790321475826, 0.03103967163042398, 0.02336667173949536, 0.04663349493057467, 0.024676866669324227, 0.026700452908698935, 0.07582112404634245, 0.07347932900302112, 0.050007439276669174, 0.02827359076036373, 0.019629642774816602, 0.04290395794669166, 0.10292275415849872, 0.03159139720082749, 0.04145362698181998, 0.017880352461361326, 0.05704187860828824, 0.03802260776865296, 0.07677169647649862, 0.017909312919073272, 0.06621630818699487, 0.02452551678288728, 0.0409972172928974, 0.11178308457601815, 0.046961717162048444, 0.03255064533732366, 0.07417245782562532, 0.03651199956948403, 0.019005223839485552, 0.012866014058090514, 0.01514703926659422, 0.04766354766616132, 0.01471048944949871, 0.005126158721395768, 0.10404094806290232, 0.021788960402773228, 0.015653621849196497, 0.020738917919516098, 0.02091555463266559, 0.0333140110160457, 0.02290360313054407, 0.047492378726019524, 0.11249332732404582, 0.018719868057814892, 0.06364089247654192, 0.05043574383307714, 0.019007192386197858, 0.028491108678281307, 0.03362309325893875, 0.018093178150593303, 0.03180473868269473, 0.05312772867910098, 0.1708235446130857, 0.16081736044725403, 0.17932351038325578, 0.14491928071947768, 0.12878938374342397, 0.11924592865398154, 0.054714047073503025, 0.11805669637396932, 0.10915638646110892, 0.13838775776093826, 0.09398210109793581, 0.2770013065310195, 0.13486004783771932, 0.10638770807418041, 0.08603746959124692, 0.10190050510573201, 0.09898264761432074, 0.08287439166451804, 0.09984417716623284, 0.13568696362199262, 0.05908587576413993, 0.147377229295671, 0.1178043735853862, 0.12868379097199067, 0.12799206480849534, 0.1991955831181258, 0.1500465563731268, 0.17307985166553408, 0.10614104787237011, 0.1259003661107272, 0.16453142365207896, 0.23639340506633744, 0.08986554152215831, 0.19762491661822423, 0.14615261141443625, 0.10843410607776605, 0.16333010920789093, 0.19662441249238327, 0.1609267678577453, 0.11125872755656019, 0.11767923264415003, 0.1315347067429684, 0.11852508061565459, 0.17668861895799637, 0.1207174887531437, 0.11445548414485529, 0.06070741648727562, 0.20512699062237516, 0.10847954778000712, 0.0733278195548337, 0.18204297695774585, 0.12826658523408696, 0.12647748982999474, 0.1501136168371886, 0.07668741076486185, 0.0649397325469181, 0.22053317487007007, 0.09595269613782875, 0.21742253709817305, 0.09931299980962649, 0.1318552700104192, 0.17856583697721362, 0.1768786829779856, 0.18556553637608886, 0.20817948854528368, 0.13395265355939046, 0.12605844356585294, 0.11943203702685423, 0.10791492182761431, 0.09773392477654852, 0.1613696667482145, 0.19458499067695811, 0.11758143242332153, 0.1461028281482868, 0.18585504818474874, 0.1878885179758072, 0.07773918245220557, 0.09890577595797367, 0.1499293712549843, 0.1235014182748273, 0.10405697103124112, 0.1143844606122002, 0.22063682321459055, 0.21932230156380683, 0.13462260511005297, 0.1316496208892204, 0.15307419234886765, 0.14425940753426403, 0.12160107493400574, 0.10116123696207069, 0.15138092305278406, 0.14142011379590258, 0.1881733987829648, 0.1705498553928919, 0.1866668538423255, 0.11042678001103923, 0.18116994411684573, 0.12139845377532765, 0.1593572145793587, 0.2780198893742636, 0.224598555942066, 0.10135213960893452, 0.2176306353067048, 0.14733258169144392, 0.09669497740105726, 0.14751961774891242, 0.23793484579073265, 0.23561309615615755, 0.10687006695661694, 0.07638768700417131, 0.08275514337583445, 0.15603849344188347, 0.10593716506264172, 0.12721680250251666, 0.2265174381318502, 0.12845271587138996, 0.15026237291749567, 0.14323019713629037, 0.09767801879206672, 0.0707954409881495, 0.12790493667125702, 0.1866023612092249, 0.13680745818419382, 0.122938491840614, 0.18221652077045292, 0.14038496621651575, 0.17304672219324857, 0.11906672225450166, 0.143965546740219, 0.1065009152807761, 0.14965449459850788, 0.11538487568031996, 0.1425432800897397, 0.09473587080719881, 0.14248669875087216, 0.10711302384152077, 0.25502821372356266, 0.1788157774717547, 0.08368849055841565, 0.16483093961142004, 0.13703488191822544, 0.1114254213462118, 0.1437550291302614, 0.1575401402078569, 0.08145147192408331, 0.1734343310818076, 0.09650942563894205, 0.25630049232859164, 0.17042688152287155, 0.14604364929255098, 0.3082811686908826, 0.09327743930043653, 0.10040198278147727, 0.17443054559407756, 0.08157575939549133, 0.09295470896176994, 0.1634869398549199, 0.16523267899174243, 0.20615661662304774, 0.10139554782654159, 0.21871086093597114, 0.12401034604408778, 0.05256091710180044, 0.12613136699656025, 0.2018638266599737, 0.12323478687903844, 0.18479981808923185, 0.11180351590155624, 0.2686359960353002, 0.162561719189398, 0.10081047570565715, 0.11622561025433242, 0.07896712515503168, 0.15372967201983556, 0.10891432015341707, 0.14906512544257566], [0.04954746356816031, 0.015470511752937455, 0.06297466650721617, 0.019653860908874776, 0.04523696225078311, 0.03905510588083416, 0.048988611524691805, 0.035911064042011276, 0.03673079583677463, 0.06644031804171391, 0.0393517757038353, 0.04802031660801731, 0.05945296798017807, 0.013656799310410861, 0.005454560459838831, 0.02934376214398071, 0.03315366629976779, 0.02092428971081972, 0.07874243994592689, 0.029954343735880684, 0.041900407304638065, 0.04488666854740586, 0.028872661641798913, 0.07547282672021538, 0.05109728685056325, 0.08655147365061566, 0.03312384680612013, 0.03062639370909892, 0.11537712765857577, 0.03859550124616362, 0.03222118742996827, 0.015251052191160852, 0.06140280886029359, 0.052355735533637926, 0.009008689448819496, 0.037320651099435054, 0.039145536575233564, 0.043731682671932504, 0.02555788501922507, 0.053282388544175774, 0.041014557573362254, 0.05655703724187333, 0.013399095951172058, 0.02796809494611807, 0.04638096805138048, 0.032727436046116054, 0.02204058186180191, 0.021785373974125832, 0.029563664211309515, 0.08133461335091852, 0.06368963673594408, 0.01529510422187741, 0.02495304393960396, 0.01499102683737874, 0.09540726212435402, 0.10068193572806194, 0.02300216961884871, 0.018756086719804443, 0.023843852286518086, 0.05550296489673201, 0.033774346666177735, 0.019886275586031843, 0.01945796360814711, 0.026485753296583425, 0.044479285134002566, 0.054722366548958234, 0.07691384744248353, 0.04776248708367348, 0.010290394257026492, 0.03225115535315126, 0.06890955468406901, 0.04923544613120612, 0.0257568882079795, 0.05515082324563991, 0.006830378870290588, 0.022251839764066972, 0.021178267488721758, 0.09509088456979953, 0.03979637040174566, 0.012502793069870677, 0.04242179944412783, 0.02082456547213951, 0.0675737408164423, 0.018864972771552857, 0.04480262032302562, 0.004630318262570654, 0.015585303444822785, 0.03631181636592373, 0.029218923627922777, 0.055395798772224225, 0.02249480407044757, 0.02390334655501647, 0.06722089412505738, 0.016900979135243688, 0.04543111921520904, 0.013752462145930622, 0.012825203357351711, 0.043956768640782684, 0.02116485502483556, 0.05648302656481974, 0.0059679879632312804, 0.03798604586336296, 0.04175308356934693, 0.09784073467017151, 0.050893608131445944, 0.013338857679627836, 0.03910862957127392, 0.029936038663436193, 0.022161989800224546, 0.011343441510689445, 0.02687266271095723, 0.008330649416166125, 0.08351286131073721, 0.07595570510602556, 0.03642600691819098, 0.013565872304752702, 0.059161508033866994, 0.011854276599478908, 0.06386628272593953, 0.025904675785568543, 0.07967618046677671, 0.02916393605119083, 0.08598065076512285, 0.10570437560090795, 0.023098535639292095, 0.06119142664829269, 0.021704782302549575, 0.06606274298974313, 0.019797637178271543, 0.013285827517393045, 0.03096420634392416, 0.03685171395773068, 0.05081368624814786, 0.0038020183728804113, 0.03820536163402721, 0.009391619096277282, 0.05718945467378944, 0.016423295783170033, 0.0042066219793923665, 0.0648575767991133, 0.053821072724531405, 0.025672899355413392, 0.051821021843352355, 0.008451639896520646, 0.07009201857727021, 0.05333948938641697, 0.061771047694492154, 0.04094645810255315, 0.03344056574860588, 0.028311197238508612, 0.024697945518710185, 0.04784606775501743, 0.00807452868684777, 0.024757365572440904, 0.010404033764643827, 0.04751831307657994, 0.03678611552459188, 0.05040057345468085, 0.013940428671048721, 0.06337569342576899, 0.010566936107352376, 0.02884276236727601, 0.04540556335996371, 0.044735834453604184, 0.08846902739605866, 0.015179850543063367, 0.029065957714919932, 0.08355877056601457, 0.03989773664216045, 0.031638479049433954, 0.0341853443387663, 0.0338560868112836, 0.036586696733138524, 0.03653073508758098, 0.05225840286584571, 0.05111116872285493, 0.024913916058721952, 0.039763908862369135, 0.07651149207958952, 0.02448174676828785, 0.03243959778046701, 0.07646695579751395, 0.05147644267708529, 0.016635679894534405, 0.06159892138384748, 0.04465942292881664, 0.022001214638294186, 0.10413263298687525, 0.06062872656912077, 0.02328402431885479, 0.029986831250425894, 0.024970538215711713, 0.05140745633980259, 0.011109317110822303, 0.07860505356802605, 0.03219560188881587, 0.04347202004282735, 0.03777522026211955, 0.025314792692370247, 0.030891637288732454, 0.08791404194198549, 0.048030465477495454, 0.054738664111937396, 0.024194209072447848, 0.0863354344619438, 0.051535539896576665, 0.05483043809363153, 0.027891008066944778, 0.014783034384890925, 0.012437024870450841, 0.008511178693879629, 0.02928677076852182, 0.034590857540024444, 0.021414047805592418, 0.020271131106710527, 0.07894323542132042, 0.025625223788665608, 0.03709349453856703, 0.055371218841173686, 0.036010868061566725, 0.017420566000510007, 0.04669022840971593, 0.024444093905913178, 0.015350438752648188, 0.032100414027809165, 0.04841290159674827, 0.057807518969639204, 0.017808147058531176, 0.036117510971962474, 0.014687247239635326, 0.05151701960130595, 0.0336187442735536, 0.03629419778008014, 0.02418313808448147, 0.03291733308287803, 0.023047260656312574, 0.06794850312871858, 0.05743299414461944, 0.048917313397396356, 0.014242630277294666, 0.053742935706395656, 0.019126121551380493, 0.08312739722896367, 0.03971831873059273, 0.013921442678110907, 0.04941704966768157, 0.05316757087712176, 0.08378182305023074, 0.03238966608478222, 0.021427909268822987, 0.04035697762446944, 0.005361981247915537, 0.02166806640161667, 0.06870643628644757, 0.020567274004861247, 0.02818434379150858, 0.030553837641491555, 0.06087672263674904, 0.02714847261813702, 0.04820889633265324, 0.04740938435134012, 0.05725718307076022, 0.01818245480535552, 0.05716143117751926, 0.07900426964624785, 0.032279906154144555, 0.031265976576833054, 0.050907964978250675, 0.010148670953640249, 0.021700444449379575, 0.008521039053448476, 0.042440204706508666, 0.03825281084573362, 0.033450432601966895, 0.04252410821209196, 0.021240695095912088, 0.0511493744852487, 0.014003524211148033, 0.04285338058252819, 0.09035880997544155, 0.00697577394930704, 0.018577264381747227, 0.034466473589418456, 0.04795958295289893, 0.03221290506189689, 0.046519007519236766, 0.03969507095462177, 0.021599953943223227, 0.07332720357226208, 0.042945848472299986, 0.0069783051367267035, 0.07647176491445862, 0.050695284007815644, 0.029650543729076162, 0.03730138865648769, 0.04647443784051575, 0.03615347173763439, 0.043371863503125496, 0.04976318734406959, 0.012344708193268161, 0.056578648582217284, 0.03685569186927751, 0.056836348230717704, 0.07493946744943969, 0.05713923354051076, 0.010594443810987286, 0.07011158159002662, 0.06345482863252982, 0.027302197377139237, 0.021502845775103197, 0.03270542394602671, 0.0682044772838708, 0.050264300298294984, 0.02152882094378583, 0.02684030136151705, 0.007186614857346285, 0.02697304189496208, 0.023661671730224043, 0.027322767855366692, 0.07467117364285514, 0.04436727649590466, 0.013503185873560142, 0.03457309794612229, 0.042946776156895794, 0.043833909803652205, 0.02088194276439026, 0.05897311755688861, 0.026345223923271988, 0.059998149663442746, 0.11702543764840811, 0.04289527852961328, 0.011905975534318713, 0.025814940854615998, 0.008836152173898881, 0.061536187640740536, 0.04669934569392353, 0.018051282058877405, 0.011329761873639654, 0.04574965270876419, 0.01821330217353534, 0.07239765618578531, 0.014113352790445788, 0.009280768208554946, 0.03282133999164216, 0.04210493578284513, 0.038887710761628114, 0.010238658214802854, 0.04117059041163884, 0.03525361025822349, 0.03437694460444618, 0.014783834049012512, 0.016329174759448506, 0.23295669729122892, 0.147277187788859, 0.22909387800609693, 0.12635080522159114, 0.1664201746461913, 0.15851680655032396, 0.13468240736983716, 0.1751946163130924, 0.18143591500120237, 0.17009422124829143, 0.15885770466411486, 0.1739029082818888, 0.15814548038179055, 0.10760255929199047, 0.15928212407743558, 0.10682575331884436, 0.16536302980966866, 0.1103098175371997, 0.2219944042735733, 0.14499294629786164, 0.12833621352910995, 0.10538853981415741, 0.06638153994572349, 0.18536146060796455, 0.2305336741846986, 0.14883045834721997, 0.1438232176587917, 0.1137029760866426, 0.21940699545666575, 0.14232106623239815, 0.12171529146144167, 0.10525339472224005, 0.12883443210739642, 0.09506203728960827, 0.09935025562299415, 0.10401422332506627, 0.12451777467504144, 0.09966619531041943, 0.17209120705956593, 0.20001391967525706, 0.1782402567914687, 0.18193610769230872, 0.11872433984535746, 0.1320378977106884, 0.1120254180568736, 0.11941912365728058, 0.15972287073964253, 0.13322687766049057, 0.06388453213730827, 0.2008804216166027, 0.18365227966569364, 0.13010559749091044, 0.08493374014506117, 0.08045939117437229, 0.3175402624765411, 0.25804771576076746, 0.11344704646035098, 0.11278539212071337, 0.1050293626030907, 0.13590203801868483, 0.23732244037091732, 0.10842605377547443, 0.19039200473343953, 0.16878955531865358, 0.12666246271692216, 0.18041351751890033, 0.15660570206819102, 0.23446410312317312, 0.12893202452687547, 0.15725254314020276, 0.13866380701074377, 0.1762428999063559, 0.14654367871116847, 0.17245965369511396, 0.11760342225898057, 0.09636570874135941, 0.10138805955648422, 0.265326522057876, 0.16443326720036566, 0.12301955663133413, 0.1529872720129788, 0.10190400804276578, 0.09357400151202455, 0.09140231413766742, 0.14005626901052892, 0.09120013826759532, 0.24753897887421772, 0.09526666966849007, 0.19430499320151284, 0.13669015432242304, 0.09696928260382265, 0.13386179984081537, 0.1649051098502241, 0.10645415255567059, 0.1266465659136884, 0.16388269752496853, 0.11403861237340607, 0.16402464068960398, 0.15623909595888108, 0.13457153050694615, 0.11572623392567039, 0.20208936533890665, 0.11567942667170428, 0.20508140791207552, 0.170827062393073, 0.10841285838978365, 0.17149744438938797, 0.17024609434884042, 0.1369235449237749, 0.16895851265871897, 0.21264473878545687, 0.21257013810100034, 0.2601115097058937, 0.2593882422661409, 0.14392769720871001, 0.11401863375795074, 0.1375072737573646, 0.08174804897862487, 0.17076994670787826, 0.20105616218643263, 0.12322949536610395, 0.1556114319828339, 0.19204779557185248, 0.20235717674950138, 0.27761452831327915, 0.11068652427638881, 0.15413256915053353, 0.2576054254313931, 0.1435690766084008, 0.1269610138842836, 0.134112898085732, 0.11741008536773734, 0.15858177415793762, 0.07466858354746364, 0.14788039057748392, 0.15027835877845064, 0.135887922369875, 0.09381580064655282, 0.06922389133251272, 0.19870423682732508, 0.10485755541594699, 0.09261957733542658, 0.15170389087870717, 0.17849350726464763, 0.1528968190541491, 0.2196357402135618, 0.22393949911929667, 0.16310937964590266, 0.1255024562124163, 0.07359632858424447, 0.13077906682156026, 0.14933179394574836, 0.18394131649984047, 0.22216716140974313, 0.06516890032798983, 0.1450583740370348, 0.12817846261896193, 0.12298603382078, 0.10226910759229213, 0.15648406406398863, 0.08308511707582511, 0.21094131690915674, 0.20403831935254857, 0.11768498428864405, 0.19145762489642948, 0.16043635667301714, 0.09062405355507508, 0.14392897370271385, 0.16168605914572254, 0.11658915871521458, 0.104205192765221, 0.13636252580909058, 0.12603929615579545, 0.13195657316828147, 0.14827343198703602, 0.09831173127167858], [0.06786023208405823, 0.04852229787502438, 0.033043962030205876, 0.038442385048256256, 0.0932596722850576, 0.060236386489123106, 0.06552471561008133, 0.019310849529574625, 0.04371971182990819, 0.059408650631667115, 0.03666547199827619, 0.03872559231240302, 0.010851723218365805, 0.10962925327476114, 0.06161729324958287, 0.036948790584574454, 0.015590897382935509, 0.04093352617928758, 0.011168352175445762, 0.028224915149621665, 0.01695274950179737, 0.04539542191196233, 0.012564479457068956, 0.08325616727233864, 0.031106208880373742, 0.03659045571112074, 0.04452169516298454, 0.09443323040613905, 0.07327756873564795, 0.033136663696495816, 0.04966877502738498, 0.036050906928721815, 0.01534955095849, 0.03587810155295301, 0.01219921756273834, 0.005529723321160418, 0.04819218687771354, 0.060429523000493646, 0.04021087472210638, 0.02932934592536185, 0.018136578946723603, 0.058485289046075195, 0.04704214741650503, 0.08059892235905863, 0.04665456450311467, 0.0077814907490392216, 0.026363881515862886, 0.05560688041441608, 0.03794148360611871, 0.015520390570600284, 0.09525947825750336, 0.04696158357546665, 0.019664072860905435, 0.03666785058157984, 0.02841845798684517, 0.05070408216852229, 0.03766710789932404, 0.05018014817324001, 0.04108606721274555, 0.023325055808527395, 0.016203584818867967, 0.011391294265195029, 0.04683207138441503, 0.04080907914612908, 0.07442221278324723, 0.03505574626615271, 0.030434055006480776, 0.03179797771736048, 0.09940026153344661, 0.03406713134609163, 0.06231385821592994, 0.015518953587161377, 0.032113909983308986, 0.018917928719019983, 0.024338400944543537, 0.05726542462070938, 0.031147155023063533, 0.028224985653650947, 0.056202773048426025, 0.11262274303589948, 0.014621933605667436, 0.017445318480895367, 0.033185456195496954, 0.04536746891972143, 0.026188046322204173, 0.0324313896271633, 0.03963359515182674, 0.02534244140406372, 0.04073377713211812, 0.05868861895578448, 0.020585115235007834, 0.021258720007608645, 0.04916804056847468, 0.026344724828959443, 0.04546270502032712, 0.004540837981039658, 0.022026230581104755, 0.0363911445310805, 0.018447091679263394, 0.017178434754896443, 0.023665952066949103, 0.03281263831013348, 0.025267842574976385, 0.03953871528210584, 0.030746538141102064, 0.01679276658251183, 0.03887213679263368, 0.04289183496439364, 0.04925853063468821, 0.007576983143735561, 0.07825630353181623, 0.02244512284960365, 0.012245984926266829, 0.023364510234387126, 0.07131951599149033, 0.021445466627483256, 0.1130954762629699, 0.03417897300096229, 0.028811406627937686, 0.03185647750797216, 0.04383455547213089, 0.050308242862229235, 0.06097499412135221, 0.11585365326027386, 0.03035713696590392, 0.04999293028959073, 0.02119659482559655, 0.023016435552563053, 0.04274987324606627, 0.03795266035012901, 0.04409532019053586, 0.06693740113405511, 0.025996028598456178, 0.02311402426130371, 0.03210521572327707, 0.06031691693351604, 0.06648493596003391, 0.058912302265525796, 0.04759144059789833, 0.06616640617721714, 0.040683255429030396, 0.050066814801539294, 0.05460831700474955, 0.0400057302613277, 0.046534703942597844, 0.036974350150558166, 0.0713730619463604, 0.020903003060084302, 0.049915576237253845, 0.028324216364126187, 0.032356529191019945, 0.045840480452170596, 0.026038442338176537, 0.02360408292588545, 0.01971658166439738, 0.004810662003364996, 0.018964420560223516, 0.03897042312019039, 0.03289023727120366, 0.03488266629574355, 0.05773698154371232, 0.018501656231819652, 0.011498510484670987, 0.033005507648340426, 0.028526425630843733, 0.03700072236824781, 0.0007415917616526713, 0.028032270311086904, 0.014937184951122617, 0.006737150279150228, 0.058202252475894056, 0.011390822073735762, 0.052220171128283255, 0.04670654823712539, 0.035209745619795285, 0.06990075227804482, 0.04858941400016192, 0.05285695238853805, 0.07338349547353573, 0.06869681805255823, 0.03053361040656455, 0.019844437010760885, 0.04058911399624776, 0.016470084483444225, 0.04837474778469186, 0.06392795519786887, 0.02722346664086217, 0.013890447808080353, 0.04140230004850309, 0.06310725861112587, 0.05740163840528112, 0.04618894476152491, 0.014464034265984083, 0.011776288010878488, 0.034831825469154865, 0.038184180739335716, 0.008556677912565647, 0.014039103698451072, 0.03191676958522294, 0.009847487017395906, 0.02162595137633616, 0.07240171573357657, 0.036855424696113914, 0.015925385196169373, 0.025147499618469737, 0.04501497474848293, 0.023713956034043804, 0.02624939224915579, 0.012310407983022742, 0.05416693580627907, 0.01700784283457324, 0.05386448836361524, 0.03587527397030499, 0.03081108272454003, 0.03690803925564978, 0.037963855647831224, 0.05445353097456973, 0.0429657862696331, 0.011963709985138848, 0.07592674650368281, 0.05126441108586732, 0.06959460893995129, 0.023273335536941886, 0.01611077368579572, 0.010410524773760699, 0.022499091828649398, 0.056626825098646805, 0.017956133160623722, 0.016465722510474734, 0.024143206828739494, 0.012964590750925709, 0.028274314354348462, 0.05131621299369726, 0.0034414324727549683, 0.03073641153605422, 0.024251308059319854, 0.03374784457264468, 0.017499077803222463, 0.009473497466387926, 0.04159381867793854, 0.01252585623660707, 0.014924953429726884, 0.04897565733699594, 0.0119957234528556, 0.023735843824397307, 0.067895959073212, 0.058952318868250586, 0.08128062952891923, 0.03397701235371642, 0.027556325439945795, 0.013432192026812118, 0.06499238050309941, 0.013883164556318661, 0.020521572550933342, 0.08990859350888059, 0.0617173904174706, 0.012503079724410782, 0.13397343369433656, 0.021880532149225473, 0.023754583053232636, 0.026065606798511, 0.011198709726158995, 0.04192610416794196, 0.03993744154286105, 0.038243315066210926, 0.05677422304870561, 0.06808344041928649, 0.0018499868815524678, 0.04904161571175791, 0.040544410730944946, 0.024224625994975213, 0.026291867216059472, 0.029915247396274935, 0.023652988602407277, 0.026439612120157108, 0.033668642572592944, 0.04140559889492579, 0.03836350959318224, 0.03351745595864486, 0.014605983924411703, 0.02081079492199933, 0.05603112171229441, 0.06592320438358001, 0.03702130212332122, 0.10183690304984339, 0.030642121673736256, 0.0490693942992948, 0.04088469286216423, 0.001161152890745143, 0.03561394150892738, 0.045500936757889576, 0.03381449685548432, 0.0528296747506829, 0.04781815558089875, 0.037313986613298766, 0.005504397995537147, 0.060126069947727956, 0.06604709851671942, 0.03146258262859192, 0.012793146288458956, 0.013573861524491804, 0.03852003224892542, 0.02885047699237475, 0.043665264165611006, 0.024448454023513477, 0.04177377835731022, 0.042960090286214836, 0.008298427219415316, 0.03276784969784785, 0.10832293977728114, 0.05763904031482525, 0.02900708499510074, 0.02787924688163912, 0.03599334966565948, 0.06315245540463366, 0.026950026040140074, 0.025607651587051805, 0.115402130613802, 0.015867289876041468, 0.027220809752179775, 0.06763133889762685, 0.0469899447489297, 0.02783233387162909, 0.029151881717552897, 0.02955066920549143, 0.03365640455740504, 0.00828586636998807, 0.015967227482178714, 0.06504024902824312, 0.029235701731522568, 0.0179535263669095, 0.09470162069192156, 0.03988168769865297, 0.008010883029783145, 0.017197224078699946, 0.020954992360202596, 0.04434342015883885, 0.05146668714587577, 0.028490231088653672, 0.03911632935341913, 0.017896533136081416, 0.04998710071959067, 0.022967474214965478, 0.06516397988889366, 0.01175537521703518, 0.040587269759271294, 0.04095697062439285, 0.05359798684366979, 0.05247532521025278, 0.030142775030981284, 0.05496899706486147, 0.018618505528138485, 0.15685449965531006, 0.2889002492884174, 0.1592790664290078, 0.21574025158770382, 0.13796258135698736, 0.14384761947439983, 0.09516262798570096, 0.12285255113965832, 0.07695623149629682, 0.23779152223141864, 0.137514888192527, 0.12984881439479068, 0.18011725216638297, 0.23303999594645575, 0.2095498493872583, 0.10312337893992662, 0.1512481231475249, 0.1899128148215823, 0.07682766183279455, 0.10926526694674976, 0.10987467408995144, 0.1082001588656567, 0.11160140682477504, 0.1280074124224484, 0.1535917809815146, 0.12131082097766921, 0.1677578067756258, 0.1479410834144801, 0.11533443190273829, 0.14222448313375935, 0.11407384954509325, 0.12990460905712098, 0.06908388517331332, 0.10909436517977156, 0.09970432685804553, 0.16009609680622816, 0.0940779123629909, 0.11446056785644032, 0.1492593454895541, 0.14461382757872343, 0.10090014940942638, 0.18419510131934658, 0.10967120688292198, 0.16673811071086675, 0.16685563721694052, 0.1386205546441488, 0.1212208355718758, 0.17687041545286775, 0.1192968399845995, 0.13641226454637945, 0.18556443799752742, 0.13377995579503477, 0.07613911206135526, 0.11978567039477639, 0.14540605538059026, 0.14467506960500032, 0.15623744839103892, 0.1365935563808307, 0.13627619919134304, 0.07737378604360856, 0.10883043520152569, 0.08353641707799397, 0.16802359954454005, 0.18071656610118225, 0.2045419704518281, 0.1144912259769626, 0.18937895831186324, 0.12643760681385174, 0.23750695312628523, 0.12181787111330777, 0.1366350127500482, 0.22311573004117236, 0.144004984467756, 0.1042933895951137, 0.11691067935316823, 0.19092939386609942, 0.12210215820232406, 0.13379797514062375, 0.14901114162057638, 0.20349301892565563, 0.1245003638905473, 0.18451119685778394, 0.09673892738646828, 0.11133227439131588, 0.23328616633079946, 0.20069351914571598, 0.07820163693395443, 0.11408395759644918, 0.11034369657863863, 0.14925971656339243, 0.18852422683266923, 0.08789687606622465, 0.1303018955513835, 0.09997622750233859, 0.20854360103840008, 0.0889384803303983, 0.1482396642677486, 0.10593171769869514, 0.15800518478499725, 0.1029100560117513, 0.07610687316628173, 0.13000433886190876, 0.16260134987533092, 0.09129441328695975, 0.1246915411320515, 0.12898425688035786, 0.1302054905681871, 0.239803321310319, 0.15972331602824852, 0.11987955949734896, 0.2136006992077455, 0.11176571832038462, 0.07588986918563023, 0.12522873730631545, 0.20486704597715288, 0.14115500380285084, 0.18050297599984333, 0.11884258623467758, 0.1278667160659097, 0.06482012060587294, 0.11353721740306355, 0.15487259428482503, 0.1207817810063716, 0.2523085393477231, 0.10851712271687575, 0.12550451938295737, 0.08622578214271925, 0.19341772596817464, 0.12664502224652097, 0.2480551425833255, 0.15765851276228204, 0.1198596550966613, 0.1481863038497977, 0.24601309356512502, 0.17139971838332713, 0.14884289674228057, 0.11893357353983447, 0.11235577025217935, 0.16256955626886338, 0.2062374068191275, 0.09941061449353583, 0.20341935334727168, 0.14595289947465062, 0.08876455802237615, 0.15685614722315222, 0.165085332992021, 0.13095296686515212, 0.10567529083346017, 0.12463403953006491, 0.10197215204243548, 0.1264279885799624, 0.1158795393712353, 0.1331083566765301, 0.11699419323122129, 0.07060629723127931, 0.20852041634498164, 0.19330627023009583, 0.12672613898757845, 0.08144649211317301, 0.08792811306193471, 0.18578956107376143, 0.17730160325299948, 0.1781745470361784, 0.15494327642954886, 0.09927065286319703, 0.13344834937015548, 0.18160598556278273, 0.1284568422124721, 0.08137394717778079, 0.0662608741549775, 0.1421986415516585, 0.11857616264023818, 0.16739232873078436, 0.14385572372702882, 0.15464675874682143, 0.1194099136046134], [0.020458393519220408, 0.01243563519892632, 0.05396114938776009, 0.024006623825698625, 0.050348211225355044, 0.01683771661191713, 0.015289423081412679, 0.04973551265720744, 0.026245941262459382, 0.059979373327223584, 0.028644837148021907, 0.05437834399344865, 0.01625358887395123, 0.05397136876126751, 0.016562478158448357, 0.10724802792537957, 0.02211291342973709, 0.046075444406596944, 0.031146821056609042, 0.03558266740583349, 0.025650000388850458, 0.02440306983771734, 0.013185583775339182, 0.03358951107657049, 0.04418820368300658, 0.06559199129696935, 0.054677681837347336, 0.01638825528061716, 0.006841007352704764, 0.028236010257387534, 0.0027526136727829, 0.01814055685827043, 0.04609175681252964, 0.026109050268132705, 0.07716352076386102, 0.025327323855890427, 0.010812203854584368, 0.04013707555714063, 0.05507596652023494, 0.0418550064205192, 0.014031646041985368, 0.03638465816038661, 0.020294965179346036, 0.03240851663576905, 0.03501972241792828, 0.1175589750346262, 0.024277459488075692, 0.01715030550258234, 0.040598977138870396, 0.043011788293370046, 0.03395808758796193, 0.03101272610365413, 0.04200833041977603, 0.04910929586912971, 0.060744794755009934, 0.026798811595654115, 0.02961049187433673, 0.041729063959792256, 0.020623341406462714, 0.051619209625641815, 0.04254029074218124, 0.06094692609622143, 0.07101939889253117, 0.041518884027027525, 0.05528528927243315, 0.06795068504288793, 0.03946915749111213, 0.0069166734829195775, 0.03551493900886271, 0.020016778544231784, 0.04422109566803556, 0.07587953848997131, 0.06094804673921317, 0.04560327150102239, 0.03442632711085025, 0.053541112356469966, 0.0515776716201799, 0.01055108661603299, 0.06251722152228467, 0.05922002637817059, 0.04482592747081071, 0.016163404943654314, 0.031246424696291797, 0.07193791796453297, 0.034800165449269116, 0.11192326142918319, 0.013087926417938434, 0.0281786960476893, 0.024531561575713567, 0.020657966306316666, 0.014127306094451342, 0.02377989214437548, 0.046852020313963294, 0.0716047159221489, 0.03722335553902667, 0.04161211632890627, 0.023553787577839103, 0.08259617534349672, 0.0510979399405187, 0.02482040730683366, 0.02865717906388454, 0.03134242149826605, 0.024447995747323148, 0.012421555729815736, 0.03860225850075949, 0.04496493173064664, 0.036564020410878584, 0.01789514903066447, 0.013309717251104303, 0.03422846311877947, 0.030435398293775506, 0.04264800234523136, 0.05753139550506603, 0.05750169475504663, 0.014161391081870534, 0.010817936017701868, 0.025286212585342582, 0.014055856754566776, 0.012016188175039133, 0.0040665926280780695, 0.04400249606987927, 0.020711970537377056, 0.031485622603213415, 0.06768029095837846, 0.01214007674207096, 0.058749634627019987, 0.04805432181456126, 0.037068473029648885, 0.004238030132910353, 0.010777784900710685, 0.04502576186496299, 0.014341047408379382, 0.11366006510797888, 0.07778590064845048, 0.007902521119831363, 0.05116924177855253, 0.02751010633801343, 0.009802714175748406, 0.09790297117433511, 0.04218102818413172, 0.02394431681750575, 0.01134449814344407, 0.045244142529554665, 0.07641169548151083, 0.09065499369171448, 0.030785957314947154, 0.05544895881030243, 0.042564544128254056, 0.01912928681122139, 0.01963886767043732, 0.02456413072650321, 0.04489179307711311, 0.055292848046519794, 0.02238350974948844, 0.07934125664178282, 0.06893259094795212, 0.013672197947016684, 0.0077296146264416166, 0.073375732608838, 0.03831705485936254, 0.01564633581438102, 0.01715639667963842, 0.03081039438256994, 0.014084929462114815, 0.025512760585115757, 0.015796364677953534, 0.053635086806025356, 0.054049405589466915, 0.023193072265712544, 0.04414985320181586, 0.03738506209629122, 0.070208877150435, 0.04788898986589629, 0.05084182106656954, 0.03800205027800985, 0.029755056675639935, 0.05924531134951394, 0.03420240631385241, 0.08469867228996009, 0.06592128964257427, 0.010331206813134486, 0.054328887272276916, 0.012464677292882698, 0.02901463634771062, 0.013853720774932299, 0.02934643387561664, 0.05780637606221717, 0.05573424408794381, 0.020596811482391786, 0.03274642760516144, 0.060670754392049275, 0.022535314201377332, 0.0337098169256933, 0.026181094253843185, 0.08258167377789505, 0.041330393360112794, 0.029833438602508977, 0.048733631847426295, 0.0037455801293617697, 0.03271547262556851, 0.07831964583601803, 0.019339251521159895, 0.020835254254052415, 0.0553340335318353, 0.04393422219436616, 0.022477838574559428, 0.06434629642171785, 0.014800846856815042, 0.0439889221888734, 0.031328992336057127, 0.017420445401512552, 0.0383674800832523, 0.028998262714594603, 0.04988461754692253, 0.012390690735628596, 0.09772429169970565, 0.04158944000664633, 0.045584409817820415, 0.03652379600680433, 0.02109409309923649, 0.020684830196842086, 0.030238738436310086, 0.005432768684840994, 0.06177223513077479, 0.056481991268810816, 0.03844843726255931, 0.03383118033525534, 0.01366040707580396, 0.06565928182681091, 0.034029304079012945, 0.046960904510342516, 0.025214346715074498, 0.04647264926461503, 0.028072583772882354, 0.005379290450946428, 0.031914543142193, 0.01561838282214012, 0.031102386819839012, 0.0008576442348839919, 0.04150417837081477, 0.048555642570136115, 0.080452504043933, 0.04912200885883067, 0.03209301852621138, 0.06982458566199057, 0.033451211857027374, 0.047157644148683175, 0.01632348619750701, 0.026348196224716958, 0.04683295082941186, 0.02297205512149958, 0.05587507774180267, 0.01919198901305208, 0.04262571193976328, 0.08106548833893612, 0.07518167476519011, 0.05515506833035033, 0.027617602718237322, 0.0398768117884174, 0.029800290576531552, 0.04779551636602264, 0.06415183146600612, 0.022071596213208977, 0.022198277110874187, 0.024872929097909946, 0.07921626413008198, 0.06956152399652638, 0.05147290263266768, 0.036267614050302655, 0.07050319065456279, 0.02886011377995601, 0.026980355760315433, 0.07418947527185082, 0.029343509813770652, 0.025086034947889857, 0.0645503647683654, 0.018773770243569743, 0.008036370236368384, 0.024526305314793717, 0.024534459662390873, 0.029892964412283618, 0.040664742555236444, 0.017122239332820754, 0.07092444109730422, 0.03506772452965379, 0.019835533094010316, 0.004995804192731157, 0.006981433289183769, 0.04501292642089538, 0.053445000521605834, 0.04139208438573405, 0.019319809107400943, 0.031717376768938266, 0.020098828535992652, 0.02821386828145478, 0.09056650000275113, 0.06963810621527955, 0.04308751333155669, 0.045785624606651254, 0.023287484582397155, 0.013095894300931832, 0.05197591177420691, 0.016991038755804766, 0.019565281872928608, 0.03080089489230886, 0.07775534642860293, 0.015072497026267229, 0.03351034989464097, 0.053658416218240745, 0.07648077458725311, 0.019099866221949924, 0.045284263032954186, 0.05232926683675032, 0.03259502576838713, 0.029796412854921073, 0.022355374931066763, 0.05444461407023482, 0.04295225691748783, 0.07893471556599252, 0.028432922445063014, 0.10330133110983297, 0.0346742823603563, 0.018471098301233724, 0.05539284502447117, 0.00554924551579461, 0.023085254906618502, 0.02856739032722544, 0.01969568278582301, 0.042017722298623994, 0.03550690154952463, 0.045199628511909395, 0.004689505467467825, 0.05552027920202818, 0.04208182901493274, 0.06447898500482552, 0.03876257724186871, 0.05259357902104966, 0.023656589874008205, 0.024044634774327278, 0.011182931666553486, 0.032578034297330305, 0.04356273646408226, 0.032548118324484676, 0.02945976910268655, 0.04663573992729653, 0.010374502780905459, 0.09254458331270143, 0.08109436530503444, 0.040098302051774226, 0.051677757655852474, 0.04789279708347749, 0.006918108147146995, 0.18586971302283928, 0.11654834059299901, 0.15468572149984539, 0.1635744539089501, 0.15346726344432682, 0.13837013917509466, 0.10630440941895358, 0.10434345487738028, 0.07732015845249407, 0.09922118129907176, 0.10095795529196039, 0.12911149067804217, 0.09854368952801451, 0.12001025912468322, 0.18526383850257844, 0.2036877436330542, 0.16521231445949525, 0.13232211058493704, 0.3662008373066783, 0.10782227211166173, 0.19660398858832195, 0.12922616733703762, 0.1420910152955912, 0.18975401006173342, 0.18304710276424885, 0.17387077328749, 0.1088235703355167, 0.11917702766368166, 0.1230823274818249, 0.0788302805449348, 0.12359386761090718, 0.0644000872853212, 0.16615181404631585, 0.17705647187540308, 0.10164290564716794, 0.14061219699215144, 0.14852696447633207, 0.2005383063806221, 0.11584205349208787, 0.2683239080943167, 0.13003668165765703, 0.13308359863003716, 0.16869662358658388, 0.13859564816812053, 0.09302644495619461, 0.1469097356311977, 0.09152349943178706, 0.19164893572451547, 0.17896744277095422, 0.1994574276614003, 0.06804900476709008, 0.08661892745294608, 0.10152152739465237, 0.07251794348121621, 0.13427018886432052, 0.08323114947415888, 0.12965900270501152, 0.17078703094739467, 0.07965387892909348, 0.10714335541706532, 0.20329410850536078, 0.16516503965249285, 0.14697333768708631, 0.16517544456291944, 0.1826029719086364, 0.2591724554076791, 0.12922109104692936, 0.0876841097488068, 0.15581945597659796, 0.09210123913362622, 0.16112173005240038, 0.14895705389790237, 0.12370949421892874, 0.16028556710807607, 0.10675243654986843, 0.21733515663072467, 0.1219108622171916, 0.12701348372502252, 0.17204479314386845, 0.10348581417929381, 0.18366920063272119, 0.09648877909057774, 0.1264120769337751, 0.17374673072481528, 0.11584649895667098, 0.20194383017951623, 0.1579753652913496, 0.08425163221545517, 0.09385447396198288, 0.12537682545371354, 0.11872549759573303, 0.13807384413667023, 0.12101234402507544, 0.19385606807190925, 0.14253674919018522, 0.16096708131954074, 0.10815008616191335, 0.12869017344200984, 0.13837951992172748, 0.1590681035304442, 0.18936123582534492, 0.08763115751207806, 0.1286838058149442, 0.06595584403839894, 0.14388416282599792, 0.19315938436193392, 0.0931866597966291, 0.16707120143109933, 0.09155410560197197, 0.08845925331115723, 0.09171311074169353, 0.19717796560144052, 0.0690139525977429, 0.13036300399107859, 0.14724597305757925, 0.08195535308914259, 0.08855808511725627, 0.11894176685018465, 0.139896766631864, 0.11014307179721072, 0.3511686361161992, 0.13352011505048722, 0.19587843533372506, 0.09150231853709556, 0.07656610672711395, 0.15378997894003987, 0.17958110984181985, 0.09461806228500791, 0.15321999468142167, 0.15442175441421568, 0.12019285713904537, 0.08322094494360499, 0.20674567407695577, 0.17422412463929504, 0.0816527201095596, 0.3107467613881454, 0.08320995373651385, 0.07954378874273971, 0.14525657199556008, 0.10421002414659597, 0.0812124929507263, 0.12026615906506777, 0.16606608114670962, 0.13013048912398517, 0.2575475082267076, 0.0796620425535366, 0.15806761424755678, 0.13748909113928676, 0.12399767016177066, 0.10393675052910112, 0.09766202550963499, 0.2539815183263272, 0.23893125326139852, 0.05690295969543513, 0.17205957672558725, 0.13914602488512173, 0.11921325189177878, 0.15312557865399867, 0.18193030409747735, 0.1070399594027549, 0.1178103924030438, 0.09694781227153726, 0.13162354181986302, 0.05959701142273843, 0.21855091326870024, 0.13338051707250997, 0.11960005926084705, 0.11264525237493217, 0.14788000466069207, 0.1408653287217021, 0.1992337146657519, 0.17153912340290844, 0.15675107395509258, 0.1329236212768592, 0.13958599971374497, 0.09770653210580349], [0.014198368589859456, 0.09820357809076086, 0.042438379023224115, 0.030975253212091047, 0.0686716147174593, 0.05153169186087325, 0.039547899359604344, 0.06630595220485702, 0.04645182089006994, 0.03897352158674039, 0.04147250721871387, 0.020880224692518823, 0.007106990296961158, 0.01595348476257641, 0.034806740877684206, 0.0327660462789936, 0.025898285894072615, 0.03692254082125146, 0.04507056903094053, 0.05229291273280978, 0.0891196534212213, 0.03343736709211953, 0.023487359794671647, 0.030872315473970957, 0.038186577876331285, 0.09326161671197042, 0.01988989726669388, 0.04780647788720671, 0.014094440084591042, 0.03189111354004126, 0.04290608048904687, 0.0930069710011594, 0.02328279606444994, 0.010264694610668812, 0.056532438757130876, 0.05217967584030703, 0.08683419480803423, 0.04519035908742808, 0.01814929193642456, 0.048123200540430844, 0.05275396826618817, 0.05811137278215028, 0.05455945029098075, 0.004619154042302398, 0.061438528427970596, 0.015112265937204938, 0.052752725168829784, 0.03197795223968569, 0.04600919288350269, 0.07181315551861189, 0.034033204065053724, 0.02647286961291684, 0.03405459276109468, 0.03343868811498396, 0.01201788398248027, 0.00739604151021922, 0.022144053946249187, 0.022202041654963978, 0.058362419076729566, 0.06826570446719415, 0.06710878529702313, 0.01802888775273459, 0.009219471448886907, 0.029934333579149097, 0.061478634088416584, 0.05385681455663871, 0.0398680470243562, 0.038280611697700806, 0.07052327317069285, 0.0273745103913825, 0.047007184839458205, 0.08217683222028427, 0.054719301479053684, 0.04848054093599785, 0.020999094485887326, 0.029566426856035832, 0.008128792669594986, 0.0598429925594246, 0.051446018333081156, 0.04821097434614785, 0.04027647686598357, 0.03736069738806691, 0.04104810635908507, 0.04224318305205088, 0.02055068329354981, 0.02592967688542558, 0.011205172904737992, 0.02223282037448371, 0.013950816883152584, 0.05919676004850771, 0.01868595561973052, 0.022752347867935896, 0.018021230644080788, 0.017911012437252793, 0.046957828308222815, 0.0357942017581081, 0.04414079900016077, 0.020645544609578792, 0.013923461319791386, 0.03444266920269001, 0.0144281987377326, 0.0401074490218889, 0.06521722898469307, 0.03438392450334504, 0.06797726877266541, 0.03572179040929768, 0.0514696668687975, 0.043833449672092684, 0.02722627566981828, 0.04514443869993556, 0.04309316849685274, 0.01520214558695443, 0.013018963272770634, 0.014545213161909487, 0.035186872628401034, 0.03466088659479283, 0.022635880777670536, 0.05785820023447741, 0.026362228381913155, 0.028981532850593794, 0.011382239135855343, 0.011489724383864086, 0.048535882888245396, 0.0119452184480906, 0.061410697890096344, 0.03167790193401743, 0.04648142887162976, 0.019585234513215255, 0.055635779644944705, 0.03584833400964271, 0.04993804846890271, 0.0673131356597878, 0.04175024485448375, 0.05711395227990579, 0.02549426626501372, 0.0364079653081717, 0.019768227721215226, 0.060113227082183585, 0.04237796820234507, 0.02921718143625185, 0.019872289813065436, 0.027985900924250018, 0.014820160322415177, 0.012723461404675618, 0.03216984936443623, 0.02668545781489229, 0.05264791536319535, 0.03574337206373457, 0.02238817043689778, 0.015926342566672247, 0.009849177258729469, 0.03263720573158935, 0.019105686515104026, 0.04795150838617701, 0.03338965070724953, 0.06382125662639737, 0.04543779854429886, 0.05230024515185505, 0.026473556099517737, 0.022772120537410956, 0.04177188588073477, 0.006766463257008581, 0.040941871629911475, 0.04507584570092149, 0.03991513258370105, 0.047801145556150004, 0.05073369757155888, 0.0194301015289966, 0.029740766622126102, 0.02773821099253837, 0.06985980799072422, 0.040619597712066025, 0.03092671304329997, 0.043932589469477534, 0.044402142593753524, 0.029841067880624905, 0.024565186431573238, 0.018751244206214324, 0.05493786768056452, 0.02238163026049733, 0.08367169575649314, 0.005418540322352783, 0.022654484564554878, 0.028826917514379602, 0.009977979771065293, 0.014161999642965384, 0.05322902070474811, 0.021415699084172957, 0.0011760223992496321, 0.03224881387723144, 0.028455442916310858, 0.04205392426229082, 0.08834577893139794, 0.03686438241857104, 0.05030958243878558, 0.031847475256654434, 0.09180333363474347, 0.05079152942926157, 0.018363971139478963, 0.06283235969021916, 0.01977663439902244, 0.02474892735335743, 0.004344504204709665, 0.03785608096222859, 0.02100978326780023, 0.029066167371638585, 0.04802177492820192, 0.025000055284181144, 0.03382581831829157, 0.054222530088736676, 0.044500354706542566, 0.04209656806779094, 0.0493705207190942, 0.03875588306982536, 0.016787723689049017, 0.013261718850117177, 0.024690255013410933, 0.06199014824233018, 0.04521606708294712, 0.0036062249728274764, 0.009871311813185457, 0.0358581637556199, 0.0048337390853703255, 0.06726829509716481, 0.04684236126195174, 0.06933335069334134, 0.020974009894416668, 0.045543591695604846, 0.04466266982490197, 0.03816835072939284, 0.040345099550904706, 0.03136861931125168, 0.020320884686952922, 0.059037513710791245, 0.017979774274863303, 0.07470470387488604, 0.0800002392497845, 0.03017501949216239, 0.02678101860510651, 0.04521837516222149, 0.0451219219394261, 0.03654366701084655, 0.03823518483841326, 0.03617540962295607, 0.011432104038249236, 0.011860902122862171, 0.12746855383738875, 0.05345861522073392, 0.011417061632528203, 0.03170618889271282, 0.019694486072694417, 0.020205074397381395, 0.04149439686443657, 0.029499960110115353, 0.030274127748270985, 0.04124308339669369, 0.006672831586911343, 0.09528100796160288, 0.05564043662161566, 0.04490296239964664, 0.03563888880307786, 0.04519879359577317, 0.08061982865910977, 0.048502671779715456, 0.014207097174221417, 0.048501625351491384, 0.024305724182340782, 0.04070041388331447, 0.027619101856544148, 0.023708870467089582, 0.0686742716061417, 0.05176580234547146, 0.05083780604763888, 0.058248874192941, 0.003286808323537116, 0.0251345825381577, 0.05684062671207357, 0.043467055074870586, 0.034827728813979775, 0.009952898890333017, 0.013647646774188615, 0.020412873891473282, 0.025952933938242495, 0.07794753299094737, 0.0014880983962939354, 0.09702123294118792, 0.05946988152572885, 0.03321646683616564, 0.014585334592993604, 0.03496594639727846, 0.01954149418452289, 0.008747613028390333, 0.059479547999217175, 0.07831037641153671, 0.03211474489944521, 0.06499063645605929, 0.08257096458692104, 0.04410023320815526, 0.0259518040184048, 0.003420161592657678, 0.039024009893182665, 0.023542395611002576, 0.04151902503508609, 0.015184689345915103, 0.019986138977401424, 0.03025440702913329, 0.019059827354794834, 0.019735255955311004, 0.05132674777996726, 0.05417120686615817, 0.043386929100961424, 0.07029462489299476, 0.014781160462007392, 0.05425260933407117, 0.025848122277238872, 0.03282851284893695, 0.09299597979406826, 0.07110194055712782, 0.03330408850160893, 0.0349600945628481, 0.05395586158556398, 0.0208171755366493, 0.03495308497804217, 0.017484411109762732, 0.09483890316914767, 0.03332352534926031, 0.026331909793952946, 0.06070416959119029, 0.04393442999571562, 0.02897138212574646, 0.06611242977669463, 0.05203544315008912, 0.02478788825101219, 0.04862982394115534, 0.026480528576939832, 0.03299313975730911, 0.010745071958808694, 0.03297115734312683, 0.01770825583662372, 0.03315152149298228, 0.025160099430650007, 0.03307797094748821, 0.032819540283526294, 0.04756263784656767, 0.019620134007709567, 0.05235634780547116, 0.014117773207544815, 0.012442669831216335, 0.06273137565585785, 0.0774046964943409, 0.03910582796379458, 0.005472072825796204, 0.12799504824215546, 0.1527081205858849, 0.239902472239919, 0.11181269626831636, 0.14450743328779936, 0.15219955646898597, 0.12553929642308503, 0.1304257451556623, 0.1906791713554412, 0.07966740828123875, 0.15569045586744323, 0.0729904614854604, 0.10135507851373404, 0.07417302927933633, 0.14244013640563935, 0.15522382309427485, 0.19255765102570876, 0.14027174416696653, 0.16276968381134793, 0.22151650569867343, 0.25084570690523833, 0.11732280880096368, 0.0871734379325062, 0.1306175161153078, 0.193433889944572, 0.1625821430934593, 0.1787657567183487, 0.13125272031174973, 0.07486548274755478, 0.12484693201258779, 0.1107156090438366, 0.14552963781170547, 0.14956307684769854, 0.11545083776582032, 0.12993754557101056, 0.11046260347939096, 0.14854168868623674, 0.08456253272015601, 0.1603260586853139, 0.15497023123316467, 0.15364052524091676, 0.27790562831796706, 0.18549151456682011, 0.11802719600382261, 0.11927426385227591, 0.10912684898357838, 0.10952990938676521, 0.15583464031806216, 0.19994582020444795, 0.22095186490332708, 0.12943843641551211, 0.12164371131802909, 0.1552877962240018, 0.0939724754425697, 0.09239927821909077, 0.1190908791613765, 0.15706240490544587, 0.09311469373642467, 0.10355510108638555, 0.20379859081003815, 0.1603756341501139, 0.10397612146334723, 0.13386052334681153, 0.12175867741461843, 0.18166026624385267, 0.1678081095451489, 0.1818981987889856, 0.1276809416594915, 0.18634278763784096, 0.10972805539495312, 0.16123915265779942, 0.1350319737684913, 0.14137628255411983, 0.12158690733485855, 0.13476664113113657, 0.21421680052299052, 0.1267664524493739, 0.25286740623414516, 0.10528290251386352, 0.1888595736818388, 0.10263727221172303, 0.14126665249932557, 0.17165874276543036, 0.1536487927660346, 0.06276451997109689, 0.15570390358334407, 0.18780389829771593, 0.14810141699854285, 0.11054144182708114, 0.23757339018629864, 0.11296209006104618, 0.10072365927044302, 0.21128551015863195, 0.1130827039014548, 0.16756481869379058, 0.22738738363841549, 0.13049865374341607, 0.11010637259460054, 0.105620794929564, 0.13945253187557682, 0.151809275848791, 0.13989388709887862, 0.17000651423586532, 0.06566670330357738, 0.1190883781237062, 0.2053172476007603, 0.11948455139645375, 0.10780671669635922, 0.15933919523376971, 0.15726097393780947, 0.1175292297557462, 0.09424344840226695, 0.1493302354356274, 0.16405343601945788, 0.16478949808515608, 0.14779418270336464, 0.10623973124893382, 0.18269237101776525, 0.10317663545720279, 0.15739804861368611, 0.14405846362933517, 0.1438684738241136, 0.16136441234266385, 0.07632923545315862, 0.12209985012304969, 0.09168778866296634, 0.17127245489973575, 0.10765537052066065, 0.17318651312962174, 0.0684030463162344, 0.16293528664391488, 0.2610413316870108, 0.10001210292102769, 0.1337962385150604, 0.13428322097752243, 0.22577474126592278, 0.05835836323967669, 0.11820107378298417, 0.14601388917071745, 0.10237856695312075, 0.1633437944110483, 0.17364734230795875, 0.16109311283798888, 0.10220154246781021, 0.1151643019693438, 0.08483251120196655, 0.1175526667793747, 0.12050330493366346, 0.13895178999518976, 0.11951602587942034, 0.10375744022894651, 0.12499453034251928, 0.18141562468372285, 0.16744690627092496, 0.2402773904032074, 0.15249613352352753, 0.14202153543010354, 0.1388939470052719, 0.15620414080331102, 0.10105606721481308, 0.09903859812766314, 0.12056852487148717, 0.16285874153254554, 0.10913334277574904, 0.19496299617458135, 0.1382458145963028, 0.09946568927261978, 0.10975392666296102, 0.09712072525871918, 0.0904869195073843, 0.14397500170161948, 0.0781113695120439, 0.132048747909721, 0.21935357566690072, 0.13088691572193056, 0.09714019921375439], [0.03227450702979695, 0.014764872175874189, 0.025366819099872373, 0.024794101882434916, 0.05257180440821685, 0.058132145495619625, 0.013757018932665233, 0.07827674970030785, 0.015757934415887576, 0.09802569271414541, 0.012656168091780273, 0.08771447843173519, 0.07136185551644303, 0.015333267310779775, 0.01797457181965001, 0.036469678598223254, 0.06685663320240565, 0.045847571673220955, 0.04503644508076832, 0.056921914147096686, 0.033104116810136475, 0.08577676795539446, 0.04864937953243498, 0.04332572047132999, 0.042279117842554115, 0.02249447938083904, 0.0544063081179047, 0.01664153915044153, 0.039083763913367875, 0.04348862559709232, 0.02937868019216694, 0.03096130083577009, 0.03799301463004667, 0.04108501707378309, 0.02473956330504734, 0.04609160838299431, 0.021914275748713408, 0.061615608574356884, 0.007012055693849106, 0.016655305989843328, 0.06664159591309726, 0.02710551711061271, 0.05585184109804686, 0.09751622317708097, 0.016476830605824944, 0.009730422498250846, 0.07410691876430064, 0.010690364542824682, 0.027868062716152053, 0.04337643884355202, 0.031323218427132815, 0.04544165400147904, 0.043367054386180826, 0.016478068137075752, 0.02846512979886029, 0.028154669016657863, 0.011992915351584088, 0.013758608984062448, 0.023408458364428952, 0.004544435078059905, 0.01136521148509928, 0.024231778443208896, 0.05013515918108169, 0.01666984837356722, 0.02639281785377534, 0.03954342049837578, 0.08131991140544415, 0.06042204586265143, 0.05833208379044663, 0.016532510235265363, 0.004087560155312531, 0.02139363317837706, 0.011286940880381735, 0.03797338853473775, 0.028200927081343252, 0.039492026771767996, 0.017601707550056744, 0.0074328733717266005, 0.06685353102511726, 0.04717296578746755, 0.057562873698771, 0.03307139180833474, 0.05091605067718774, 0.008921280223148642, 0.060589722997974604, 0.03334755980176851, 0.050837446106015705, 0.02146877934137592, 0.06275624502450228, 0.02963680472021224, 0.025163585669361055, 0.02599080944492016, 0.07947932579554617, 0.0036544154045259347, 0.03961387999879662, 0.06912398341228254, 0.04157615556323435, 0.01405219518346712, 0.03471647716651205, 0.024324224068550393, 0.054949367258814164, 0.02021765565586975, 0.05637434274831321, 0.029684218679904006, 0.015335370371758472, 0.049939102318603545, 0.03555092203896493, 0.017773820873117074, 0.013444350261124782, 0.03483092747046612, 0.031808044950594194, 0.049148399630212225, 0.03773702192120254, 0.04370542177639436, 0.021176402842684183, 0.025618080617277883, 0.054456532961921766, 0.04364650267234538, 0.016944574745139107, 0.024547922221245244, 0.013362323461478809, 0.036696898241643794, 0.04429790424183011, 0.004793338885065168, 0.03398809632926714, 0.040927184527390637, 0.022018415766069666, 0.032173801300814375, 0.007130641615731292, 0.011040716690331465, 0.03251653251936659, 0.02851641591405496, 0.04714933209470473, 0.03280217031715438, 0.028829344337282237, 0.06052141201507766, 0.016224064384005032, 0.02483397376636276, 0.06250177742913365, 0.04381407590699382, 0.02192437823396176, 0.0411194749904098, 0.01151143498645979, 0.04892304648819845, 0.03012354969541775, 0.03918341579264961, 0.03549292319803499, 0.02877356451790547, 0.06918922561453655, 0.016593184518569615, 0.023263249750016257, 0.09414271669811569, 0.06244052798138, 0.07399414200335741, 0.038812820639577694, 0.07879712138674222, 0.048875575012061745, 0.033186580549227074, 0.011686047491821228, 0.029786544146190863, 0.01723528326692758, 0.015657831681892276, 0.05957481007499155, 0.03814212323050015, 0.04292711666494142, 0.020516167860478163, 0.034496241132728755, 0.018154997196688782, 0.02977311312861275, 0.14188226399710402, 0.017895329001476057, 0.019064031621383037, 0.015862074433243833, 0.026772315068228636, 0.004194655311948736, 0.04119812037970405, 0.011994374599453295, 0.052198069970472716, 0.045232735719764605, 0.05891213899303693, 0.05175594662432559, 0.03962753551604692, 0.00731064999854425, 0.005264049759716727, 0.02456001180689782, 0.02737880186032271, 0.05040997275500558, 0.04897729006188456, 0.072497007495258, 0.04212671410641633, 0.09650533640524372, 0.02633022697409615, 0.054933370265644044, 0.04727934894617647, 0.007540441647506668, 0.04954920390446205, 0.032987851955113, 0.04626889633073006, 0.057017194776562974, 0.040475877103745006, 0.01024499337290763, 0.011562281379156047, 0.025501982745481655, 0.06398544195690192, 0.09316094437963329, 0.017998322400671896, 0.029627119693032, 0.01447335471311817, 0.07134991436032578, 0.014383971374627436, 0.027284209572826512, 0.028860778002126608, 0.019607485955930315, 0.03447935727308504, 0.018681565816223156, 0.021162806697248016, 0.04123475278902333, 0.014896671109454473, 0.07614653353812173, 0.022348621387209278, 0.003951987864638795, 0.0689146680815611, 0.08852276630932465, 0.05514078198757488, 0.03310255830001552, 0.00634774307400221, 0.005025525351811666, 0.023441350349457934, 0.12109814371797256, 0.023422048943757545, 0.055091610993258655, 0.07503736414946616, 0.05788543705421034, 0.01631034832826117, 0.026577872376947198, 0.03045221536012832, 0.05329271181835793, 0.036685665836557746, 0.045969213388161734, 0.01862673965661088, 0.013735869579249993, 0.04540374138741754, 0.02538999637181405, 0.031908494638628326, 0.028069737636542413, 0.006559132243637578, 0.038012974691810086, 0.09018326236400753, 0.04619502666173503, 0.02612091164337471, 0.07304182552616112, 0.037611068328260444, 0.06181796998134814, 0.04775018598593306, 0.031145800603553653, 0.06160511831694748, 0.07708932083914988, 0.11752469523344189, 0.030638976822956465, 0.02193786305724643, 0.05704560047888663, 0.025153518436127342, 0.023147168576542754, 0.0326791333645815, 0.04020748681796249, 0.017839395186456386, 0.02522003898775438, 0.07517281352193095, 0.025311855642939918, 0.02982746245834278, 0.03589175335946493, 0.04196726738882717, 0.037782125946250744, 0.026775276237458456, 0.029170847301429603, 0.0166427191652474, 0.0652842820272781, 0.0293953098662314, 0.01042884097842034, 0.01708233405224746, 0.046979506441857666, 0.051275361474836245, 0.021941772320133168, 0.019222402224841062, 0.02829109987942502, 0.043470071905176155, 0.03381094567885157, 0.04869509211857803, 0.06695823321933858, 0.036625496213673614, 0.01723274512187345, 0.020769511102116667, 0.03173918848915491, 0.030859838116157334, 0.05667007375450339, 0.10647452450939454, 0.04532714432571083, 0.02623611708258977, 0.03905812271113973, 0.024739028958720155, 0.04670062589866575, 0.09586697065969929, 0.02913097727287095, 0.04000041648396291, 0.022116128784546163, 0.009226583078998374, 0.05347899459593464, 0.02716072733164765, 0.04519625173998065, 0.024697691333130933, 0.04810657643247396, 0.024484151326760184, 0.02416025396087207, 0.0598462468769867, 0.019940053462050855, 0.05225243228778709, 0.06388650625012815, 0.038904947141418234, 0.025051500961126294, 0.028926895938639063, 0.03139087632007431, 0.05387877841712907, 0.056766070556477644, 0.02572490535385441, 0.03968847326177638, 0.008445622006547637, 0.06765727695892565, 0.02708014493691735, 0.029367509014264215, 0.05199737468501553, 0.03112453436187934, 0.06539966372656636, 0.03672945997095667, 0.021225442105787806, 0.05735298320360016, 0.04578440377372317, 0.04317536506277975, 0.06262793511268683, 0.021955266420263797, 0.036603268890758045, 0.04599139989295509, 0.05018661970098037, 0.03338480448292103, 0.03223808242182713, 0.033537178533151746, 0.04455437563592568, 0.045420870155794546, 0.03318969756946899, 0.02949440142401727, 0.02770281982520828, 0.022371522209141403, 0.03281269768194761, 0.17156711721327156, 0.07612115950905718, 0.09229234216036275, 0.13827976043103263, 0.23189512925455347, 0.18026679492322728, 0.10457062628120184, 0.11375788759323768, 0.048376907434430905, 0.18650390789844096, 0.1400011422811076, 0.22093838750151917, 0.1721829958842136, 0.19141778640914708, 0.09668943355791271, 0.11603449980611913, 0.2363590436289087, 0.21066118584712967, 0.05834976545884274, 0.13315767981112003, 0.08649314084323123, 0.18736557103693485, 0.11237961545703001, 0.12584853451699018, 0.11429951438913122, 0.05878343203221448, 0.10547571248025633, 0.12424330619978718, 0.177761304366868, 0.1556221634382382, 0.08287116332212463, 0.11165913107106462, 0.2056237100623548, 0.10675479657948017, 0.07346361031522974, 0.10772665380500257, 0.15065893210703507, 0.18368894176092, 0.07668231221032329, 0.1179383163980674, 0.2580800140276551, 0.073073322273558, 0.16865645855432376, 0.16226576553890482, 0.09702709590783343, 0.12502151483204216, 0.17213871935382485, 0.14235351292882115, 0.24053840374108404, 0.14284061413491145, 0.10579116235021502, 0.16121170803671703, 0.21177002869080752, 0.16187707311473787, 0.18460340128513053, 0.13679249648703262, 0.10193505208007991, 0.17468205944169313, 0.06544952120748349, 0.1715976936975494, 0.13550052128266543, 0.15824313217308372, 0.1497763255611062, 0.1305268850410357, 0.10329180193366483, 0.16653332248097286, 0.18436787329846993, 0.16732782125473022, 0.1271856323000975, 0.08519070135662332, 0.13712816988117993, 0.12024189083604142, 0.10640019841957837, 0.1344410312594846, 0.1504706492414698, 0.07926060745376162, 0.16231033892836422, 0.12800834752852097, 0.14702126558404416, 0.13580585567979142, 0.1799684515572153, 0.20920528506394476, 0.15791692858329043, 0.19433475332334638, 0.18492253962904215, 0.19435327732935548, 0.1283764824620448, 0.16640589572489262, 0.1548004723736085, 0.09327851541456766, 0.14174256211845204, 0.15367410000180826, 0.11504149879328907, 0.08361889937077649, 0.1277099596336484, 0.20049082377227023, 0.12114353346987627, 0.14473105722572654, 0.11410890117986128, 0.11233455967158079, 0.20484115986619145, 0.07362478252616711, 0.12144914246164262, 0.07980046051670797, 0.1664868788793683, 0.16200401005335152, 0.10538205344346352, 0.11716137683833949, 0.10635988495778292, 0.10441393664223142, 0.1894399628508836, 0.1584207874839194, 0.16193555435165763, 0.07474256082787178, 0.05036944035964552, 0.09371109103085473, 0.10151346767088398, 0.07804332941304892, 0.10801496333442628, 0.19316495046950877, 0.1429857188486494, 0.08538147783838212, 0.13344949227757752, 0.10984090637066402, 0.1836800656747073, 0.10209164523985237, 0.14357887295773253, 0.13601315236883238, 0.08091390467598103, 0.09795014208066277, 0.16723453329177573, 0.14231199718778953, 0.13070997287286445, 0.10754121336503886, 0.1604538268293254, 0.18936948850750923, 0.04969039007846732, 0.11341856283252127, 0.2123181938077323, 0.11744059505872428, 0.15730818937299773, 0.19795830419752747, 0.08965984045062214, 0.21687616797862574, 0.07950541970785707, 0.21892445103731006, 0.12460877682315186, 0.12389365074341185, 0.13380569347646087, 0.12058810272719711, 0.15424804732901976, 0.136716500564944, 0.13605569227365777, 0.14387433679075912, 0.14763589744688943, 0.1596667050034739, 0.06841729555162601, 0.10830197410541587, 0.0806409798678942, 0.10783520774566568, 0.11159421541378833, 0.09600269462680444, 0.1827164611313492, 0.17324073443887755, 0.17281267850194126, 0.1197481548297219, 0.07053125867969356, 0.10145659689442255, 0.09008479421027005, 0.26747450523544103, 0.14464949519606307, 0.10519623450818472, 0.10997255594702438, 0.1608929259236902, 0.13917769974796101, 0.1444647301104851], [0.007791651678417111, 0.04789875281858258, 0.016355589650629554, 0.04123136117414106, 0.04772834086907096, 0.02100746405631071, 0.040706814907025546, 0.022786384615756106, 0.016478435500175692, 0.050096318882424384, 0.10661193315172568, 0.007774956138746347, 0.0265700148884207, 0.037861788077862, 0.03444619811489247, 0.024383473428315483, 0.09750998171512038, 0.0116404174696072, 0.04518843692494556, 0.059901466374867596, 0.06867364820209332, 0.05971327998850029, 0.022480029765574727, 0.04761481082823593, 0.04783964446687605, 0.03452599012234714, 0.04564601920719724, 0.02175424830056727, 0.052733908014488406, 0.028445297757571097, 0.012579687918332638, 0.08286790529382415, 0.045894876166130416, 0.08216599686420523, 0.06294309554505162, 0.054655543572152965, 0.009860284426395083, 0.06968358502490446, 0.00762744408348226, 0.01220626239955891, 0.05591119435848668, 0.0774131940852385, 0.09158759130514227, 0.06309286836767569, 0.06117684344644658, 0.0333604657498654, 0.01592024025740102, 0.012936400271428283, 0.01900523126096232, 0.0856165011646226, 0.025616325438022614, 0.0741568801458925, 0.0817936539533548, 0.02730811229412211, 0.022938838446862064, 0.015895760516286828, 0.01910179951664759, 0.010788720446726074, 0.07313800786505453, 0.03920045179256704, 0.028941688797203824, 0.054345964090316556, 0.04576128958433401, 0.0516141444677487, 0.04772218475409318, 0.06749869484337978, 0.07511756804888137, 0.0780047599982936, 0.029882952840125654, 0.03501251616398804, 0.029536854126490653, 0.0446547622414073, 0.05557332049647812, 0.02298813189554494, 0.010685431116144173, 0.017869355688162614, 0.011717251090885838, 0.024519600010535214, 0.04010974596894812, 0.05695897700206842, 0.0269983342877822, 0.0511771493620472, 0.03798921483394224, 0.01638034955249168, 0.02945990640000673, 0.06644975073868409, 0.032229595963144675, 0.03248024149797857, 0.07109644124284387, 0.07219482722575776, 0.05950613543973304, 0.05456537634017877, 0.04663485677156132, 0.03176873338816222, 0.07236146906507201, 0.04345995272160508, 0.049937792427954264, 0.020286658691475168, 0.07009948458289728, 0.08056536244112067, 0.04034539269923698, 0.016052357386797667, 0.030009563233761583, 0.03385840973351151, 0.047928390486049466, 0.036339598664199, 0.018580913892947137, 0.042959010461345315, 0.02381836879067123, 0.007267030268849339, 0.0484030013467418, 0.03382256028999109, 0.02662366474396549, 0.04413161121192388, 0.07699111243709922, 0.014077733412705129, 0.016454039250675123, 0.10695654942537658, 0.02822292433847906, 0.02896615183999529, 0.02356426113692578, 0.03829303524980787, 0.023549661236756947, 0.06723430473357439, 0.0260026633986854, 0.06835669919382781, 0.023061123974912334, 0.04544035153230652, 0.06370221613906324, 0.04471136584470514, 0.04009645039332099, 0.05063945223810151, 0.054671403268002905, 0.00784370406108792, 0.027653309298329987, 0.03848181906505488, 0.013274615521368105, 0.0912271895504091, 0.033092079174821265, 0.05292105910484679, 0.011593479412113084, 0.07341220174566843, 0.009275472057197476, 0.03018325918674236, 0.043965789445792325, 0.06524549738969654, 0.012116611887904583, 0.02757799615210388, 0.025124146086454857, 0.021555141211138107, 0.09038963878992945, 0.02773837055428885, 0.029920479537395295, 0.045759196727885865, 0.0328347209142521, 0.04198457798338495, 0.039630214669159614, 0.045348733401624486, 0.09306289182859473, 0.0929448680835776, 0.04102490682271309, 0.05973038278170861, 0.0473587290616706, 0.028986688921577297, 0.03258074684708845, 0.005343911807358381, 0.021689761233574245, 0.004934611797580146, 0.02369747293414548, 0.04643099251552485, 0.03636480571003631, 0.03915439039701596, 0.015410163086926332, 0.015038122601254145, 0.0905945902923122, 0.03878673043800518, 0.054349507845472544, 0.029675062432943378, 0.0657652753579896, 0.015799277607584372, 0.026123075003852136, 0.026324334321543574, 0.019081204918620642, 0.013939677246526117, 0.004730932614620542, 0.04753738998260815, 0.022188451075635385, 0.04365955704997759, 0.0196167405374581, 0.0719118388951756, 0.02981884426844772, 0.054071013219072483, 0.07639301562448964, 0.020533864371827804, 0.0322539569606306, 0.023045434973028023, 0.021237123510218225, 0.06287928568781354, 0.08485928789013997, 0.047449026169488207, 0.07262485727551393, 0.02496842495020246, 0.06792274318286218, 0.0697193862288259, 0.03853029244055506, 0.06245379016036168, 0.023378431069431826, 0.017694811831461266, 0.04125405605009291, 0.019251268058724236, 0.024071459702099673, 0.03237941702536773, 0.014874698899802752, 0.05266087697236799, 0.0014419756575989595, 0.03568481290130876, 0.03973627870436758, 0.017580869898665696, 0.03445822461799253, 0.06518775830045342, 0.029330099205253646, 0.02296868206030922, 0.05266821681289002, 0.06405163410818204, 0.05808098925626837, 0.013362381905608345, 0.03848800857667811, 0.03735555430466775, 0.02012436027143849, 0.04437481671629939, 0.014810999437031569, 0.0032803706562845036, 0.008691239490872249, 0.032624900923110545, 0.051446200159261934, 0.050806910439860076, 0.05129597833729349, 0.0032934521686911467, 0.03599656316509936, 0.018982256224262528, 0.055188387050293386, 0.09266221371944994, 0.015501068755838787, 0.01711567132588243, 0.0410060043213889, 0.019964612984040286, 0.05574277507548686, 0.019022449087060522, 0.053936083349981345, 0.02539049175538821, 0.038705602564732544, 0.004498683993006125, 0.04762556454807054, 0.040949998146970756, 0.011875097552547231, 0.030414530956477392, 0.04861022753175348, 0.05944903830823023, 0.02995877064677188, 0.033126655835076235, 0.00986279474091134, 0.03641187271568924, 0.022295533708529547, 0.05117258886457421, 0.017956190677068662, 0.021330635972844902, 0.10280010683345608, 0.025897105879266746, 0.018883218472183216, 0.047624351136619225, 0.031475225114263594, 0.06511727653560229, 0.0910025711345952, 0.041763570116017945, 0.036976955088903196, 0.051628033761517145, 0.04353782627731562, 0.02029808962106472, 0.019547132651496213, 0.04922338994219899, 0.020927642362948973, 0.002455305370858696, 0.10378416496678255, 0.040788992919260636, 0.005600036247415119, 0.03905056764779147, 0.017012648240779527, 0.06555973755894229, 0.03760697538382374, 0.011336953284626361, 0.04302427121729124, 0.02028445822361391, 0.04212483276205603, 0.10509361032745801, 0.02343172654946102, 0.038901963707758114, 0.036955080286134034, 0.01835777049564058, 0.016186693537747487, 0.05429766883025877, 0.009585996849637013, 0.07360614719800651, 0.003973591319663683, 0.015748594487376977, 0.0035469308522806386, 0.01387167611028417, 0.042382332030683756, 0.02341397437703563, 0.0633071709307842, 0.048756033575045876, 0.05356459390895907, 0.036393582486198284, 0.03168124530930072, 0.06798090529628098, 0.02857761712220963, 0.007395848087980994, 0.09032231857418083, 0.016098209125630092, 0.012570065046020318, 0.030895390700607095, 0.04522100236499682, 0.02753161192231346, 0.01637588738958584, 0.00564425108677824, 0.0525214645313099, 0.01723800323816249, 0.048299928166670725, 0.04413325135828927, 0.045036177907604724, 0.02032641183177475, 0.010235241552436491, 0.036449907784117386, 0.019897136917279568, 0.059431382615002804, 0.032589763941359706, 0.03251666610594839, 0.004822468645215849, 0.02641559622134082, 0.027134572192153428, 0.047778643638594076, 0.04166629310930148, 0.07189145951997489, 0.04116244163014926, 0.04875267535680905, 0.021550538040173706, 0.023964887295733206, 0.0230069527606247, 0.06199213348736521, 0.0748238927917555, 0.0367307142005302, 0.0032293531057803193, 0.020709386008093134, 0.1682603743392974, 0.12308296572882682, 0.17382035177433863, 0.10386910376837477, 0.1332764234393835, 0.08544349169824272, 0.15467911638552323, 0.10316119878552854, 0.19726785452803597, 0.21665235108230263, 0.20129106676904485, 0.14099631778663024, 0.09227660120814107, 0.2400903098168783, 0.10952106298645958, 0.0901846650231164, 0.17870847776066512, 0.07679902977542952, 0.13741607865085825, 0.1297047338448465, 0.21850954595720395, 0.09965490724425763, 0.19004692090675235, 0.10330467077437788, 0.15485371404793113, 0.07804973414749838, 0.30192286300007254, 0.12183772356365807, 0.16272810869850218, 0.07772227632813156, 0.12198125492432155, 0.13390227657509968, 0.0914241852296982, 0.16433046490419656, 0.11090781044913456, 0.14395785809028894, 0.06876852436107583, 0.20399469591211528, 0.14491116162389517, 0.14177744305925444, 0.15072669018991292, 0.11603110076976009, 0.17267512885155156, 0.17532717873109505, 0.15240308304782957, 0.16353037033695728, 0.17417052673408762, 0.14861965872114524, 0.1336420202278532, 0.20047448168043047, 0.1539398927707225, 0.12085944676073268, 0.13279619452077895, 0.10296980632119812, 0.1023656535835471, 0.08418283512583002, 0.16262880933936685, 0.09355262765893713, 0.13443751347949728, 0.19250203447882086, 0.11747391006792895, 0.14384788664756343, 0.12960884836502373, 0.20078774221474305, 0.20772683783434331, 0.24128479650244117, 0.1214822348265443, 0.14148721878882498, 0.15677117131417617, 0.15463411255041137, 0.1445860118838027, 0.10650513810105622, 0.16304325428791344, 0.06450219938415103, 0.12447153145330958, 0.08333676451002248, 0.1150996980140917, 0.07374611624982208, 0.07971058643306606, 0.27199151285458356, 0.1129912787291687, 0.16075491614174098, 0.16179999365704134, 0.108657514792867, 0.12341786728939041, 0.17401586315827444, 0.12970828131074086, 0.1375139827723615, 0.1982756910729222, 0.15545872767688707, 0.20961291709681973, 0.11026931111700833, 0.06386131775798276, 0.14367558964295313, 0.14837718423223123, 0.22469758812803775, 0.19241049798438326, 0.11037511168979108, 0.07862295416998677, 0.18775228934828192, 0.12044563263771124, 0.09310328692663461, 0.11780057378928177, 0.1347073435317725, 0.1383158436510712, 0.12762360332999378, 0.10877082590013742, 0.16373342194128782, 0.07654415399883874, 0.07650597050087526, 0.11947498511290178, 0.13208276795921847, 0.19393167807720602, 0.12152965064160526, 0.11403982949559577, 0.06137660733656958, 0.09706498996820301, 0.18928854988189414, 0.11564612650545314, 0.18484903732314706, 0.09127154771704227, 0.15053037728648633, 0.07251556860865094, 0.13306507462402806, 0.13194634637329727, 0.10754041184554808, 0.1031824538949877, 0.12077008475898765, 0.28049138956703246, 0.12580039881868288, 0.22858369600726292, 0.1343463925877586, 0.2118120194063522, 0.13070379820419475, 0.1259598121396266, 0.13237860286608338, 0.13156838540453464, 0.19971709029050544, 0.12637707724934444, 0.16108833340695128, 0.16840743832290173, 0.24167069845134392, 0.10606771626044065, 0.11722595852916129, 0.10581766444374807, 0.18787814275128767, 0.09774752092198469, 0.07977904213475995, 0.09353604065836407, 0.16352894541341811, 0.14744040090590715, 0.18906290730228648, 0.07064811725285836, 0.13296347460709512, 0.10823088377946988, 0.18815769493812695, 0.09994133914005943, 0.1471203868277371, 0.16769185953307897, 0.19151429529301822, 0.08601689725765027, 0.21095339907333255, 0.13390631385846063, 0.11181178342667408, 0.11541926680365577, 0.19199290632968768, 0.07475937047274783, 0.0914338331494946, 0.09014890834805556, 0.19003957364475355, 0.1014397427206859, 0.16419894149294123, 0.13747488643275574, 0.16577505535678938, 0.16345109412213787, 0.2302005686215125], [0.023829762612876948, 0.02238890330772847, 0.033435756631661206, 0.05074876688013319, 0.02851647157513071, 0.05089074715215247, 0.09759347332874313, 0.0849260960239917, 0.05179690575459972, 0.01403126940203947, 0.010469076514709741, 0.0678250691271387, 0.06688270485028625, 0.009055706359504256, 0.04033884695672896, 0.0733464103541337, 0.05810992188344244, 0.06980525271501392, 0.02026483583904337, 0.0469731685006991, 0.036335231125121936, 0.029070881864754483, 0.09736696243635379, 0.024653993677929975, 0.01823080387111986, 0.0475553054275224, 0.04165075624769088, 0.03730647236807272, 0.01791711474652402, 0.040978630204335786, 0.07302434794837609, 0.03021520493348362, 0.06081092382373754, 0.035389950207900256, 0.05046885104093235, 0.021037329934188165, 0.04057259007822722, 0.02070075297524454, 0.013796976163575891, 0.04940094877383672, 0.016131047304952517, 0.024900603784772102, 0.03562590864021331, 0.07136503932997584, 0.05260351266770158, 0.04738671545055695, 0.047776955252629705, 0.019018205857719295, 0.05322741766576655, 0.02960329489724245, 0.020564871301758103, 0.06127531160018407, 0.02827602314937394, 0.030589356829295866, 0.02860015614714939, 0.027956292942690197, 0.015924780345812906, 0.0893391807039734, 0.036357573480927385, 0.01707069717667764, 0.09612863708753139, 0.0264222180339857, 0.03571734494471457, 0.032592264979030006, 0.03773379728954751, 0.05881046105059795, 0.03227040666388348, 0.028163463466626126, 0.015662202931707725, 0.04875574784819037, 0.07159066706662998, 0.035540877070161514, 0.02770312967186328, 0.016840338248584885, 0.021120415221957956, 0.036710316271637566, 0.07080243944074027, 0.057546824755263515, 0.009764098376763286, 0.009467397940170486, 0.008964178214228014, 0.07494092205888592, 0.04438506948645227, 0.021902668559050653, 0.057802769224508666, 0.05033586188801564, 0.034228489093948156, 0.035676545376190916, 0.018095052073476836, 0.02295282421982847, 0.01818225071474444, 0.06649591232417151, 0.0505203857755987, 0.05384618700190913, 0.06811996892793104, 0.0840621990209911, 0.0319360765570309, 0.06365018416545354, 0.05009118322050199, 0.015116343111003516, 0.04090296453796327, 0.04704871171270497, 0.01046134148054989, 0.05845243787916843, 0.013795463110000128, 0.021611809752357658, 0.041711000085342675, 0.04269558143278118, 0.07417121843900532, 0.04292473437089939, 0.04070783907081932, 0.07371614090516232, 0.04772660424350761, 0.034170078361057676, 0.018287943676114082, 0.07175557970185764, 0.06860585301183164, 0.03824830229859799, 0.02282939949509455, 0.019744859346246812, 0.026560762162262108, 0.08103199521428905, 0.05136409636179451, 0.04496436769841239, 0.04057790014485363, 0.04882394379819743, 0.03637785266619176, 0.037556743118329905, 0.015450214941665763, 0.04117794509511441, 0.026795399571710732, 0.03763418993912637, 0.024597957817604765, 0.030210698241717182, 0.03110666530119488, 0.04996662857593037, 0.08003045950317755, 0.03091146376391407, 0.04083772604644764, 0.08927663991926238, 0.007704505915171467, 0.02673472343303729, 0.028340647513687145, 0.02612699354358483, 0.023727210791548714, 0.047671058200648986, 0.03384778217878193, 0.03864925129164476, 0.030858023565087933, 0.020364745614642743, 0.07794955163262784, 0.010243756769341417, 0.056739241917966865, 0.022552322370756883, 0.013660141758009559, 0.029419657876132987, 0.01710476917651249, 0.0212836506034364, 0.06606061302591115, 0.05499898725247476, 0.04091830473043956, 0.018089786535711028, 0.02810890076943906, 0.04240576905431226, 0.05917410227993969, 0.028667255573964212, 0.0277826452293084, 0.046574868974857964, 0.031198823344311677, 0.06483347926405258, 0.03304659294371959, 0.01841247420088621, 0.059386983630247414, 0.036400562385097146, 0.05457217812363524, 0.02236019332485739, 0.02680259098269744, 0.08323490474140272, 0.036872030250378884, 0.04296455059375148, 0.003080877881984634, 0.025470931286690757, 0.0800322406576015, 0.03319088129501324, 0.0912010733736679, 0.056445177033310756, 0.05548626657400746, 0.052967758747399785, 0.060326620514388196, 0.0350629191234475, 0.02211673177953344, 0.06184948899317533, 0.05713734106393531, 0.015580861690978054, 0.010953547734970925, 0.020328877617430408, 0.012225067494000541, 0.03651774379250128, 0.05585065366176423, 0.013759515331912553, 0.03309548563265707, 0.048279181428370066, 0.03876562375808135, 0.05920729112403933, 0.0656956470629666, 0.05631478168652393, 0.0056021829095698195, 0.006970511658437317, 0.03343667689478025, 0.03819406243565027, 0.018242813675897196, 0.03145055983623024, 0.05877246680029202, 0.1395034432061948, 0.041786973743001, 0.01703655467281351, 0.03611173706303816, 0.037703209673054516, 0.04262532602297142, 0.026019528704637196, 0.03679673565784469, 0.014619157973356778, 0.03939096110116225, 0.025861508765956387, 0.0033991977761616, 0.07546536071458831, 0.039359642469207756, 0.06365635883412324, 0.04228288795275148, 0.040731413391768, 0.04704957260400988, 0.014829107840341749, 0.024349590676138178, 0.02042411742877448, 0.038885220856172964, 0.043116950619150884, 0.0956077830051072, 0.04338594946602825, 0.027054099264205433, 0.024509901995770633, 0.025520616218273062, 0.04076582677953411, 0.03865797523758374, 0.021408017855719663, 0.0516328020603396, 0.07901393983047456, 0.0779498039628379, 0.07082222509779967, 0.03436635044636205, 0.05503296277311165, 0.031503719874308445, 0.07541700237197801, 0.11077865448896773, 0.027430848676885944, 0.06840338028268889, 0.006319557696770062, 0.026211600234091748, 0.07593499918584712, 0.042298213302274235, 0.033637602246017195, 0.017708274390315637, 0.11382614291505888, 0.05164443893590942, 0.05666559860401321, 0.01804297000489896, 0.05922793767240364, 0.07137000429793261, 0.01905844510474708, 0.043525109576876275, 0.08097775906207971, 0.028852835166617297, 0.0241603133326862, 0.050864081786130555, 0.06956852987059392, 0.036165594719932415, 0.08447771266219206, 0.03249398236221168, 0.06300968845607713, 0.021694831957574934, 0.07333001631195657, 0.025939222759916447, 0.025479273026576266, 0.03282229365140665, 0.03994638813310303, 0.11299703037366271, 0.0494572777824942, 0.030326476990012452, 0.03204945445759222, 0.051740702911047265, 0.048765006140456535, 0.08001840702490881, 0.0341710468637757, 0.03909425788151566, 0.028528451694000978, 0.06906340189743787, 0.03753696117200889, 0.004643741858672001, 0.030355916132975835, 0.0027197961344427313, 0.0173830318817636, 0.015586229274049401, 0.04554621147690341, 0.045461276386049576, 0.013300415357662132, 0.037493868367164396, 0.034608439018484205, 0.060455802449723706, 0.05758955761848483, 0.006439475773731829, 0.020860225668002386, 0.04499419461353682, 0.024411027516180184, 0.008216047899622936, 0.05835064861457795, 0.04210419734590687, 0.01800437647034414, 0.05141372006619349, 0.050494217648520134, 0.021173823879507836, 0.09453100836253725, 0.042317368133808486, 0.07894200345617719, 0.048927124589681625, 0.05482942135131452, 0.013158031542843673, 0.03321511983813252, 0.052496610005619004, 0.02819214376359014, 0.029049231561657507, 0.05079808259324636, 0.03721945555298589, 0.05154062731890008, 0.0332164965220727, 0.05557051146752201, 0.07575794501462951, 0.010767248259071494, 0.06279867360717617, 0.017054549898603, 0.05327996543201152, 0.02418231058982201, 0.027236161076871213, 0.06698433455312625, 0.033823038975242525, 0.04371346665720921, 0.0069248129875632, 0.08389567592530511, 0.024883278347260784, 0.0485091915470548, 0.028126543475082144, 0.06666120345471427, 0.03246569540351629, 0.044425542509998195, 0.15911981638055295, 0.18316825095098466, 0.16439843078842387, 0.10653389632352628, 0.07032072622678243, 0.10392792639322579, 0.19791615020949394, 0.1882081016083248, 0.14411177951842546, 0.1399016351206228, 0.13570134644396603, 0.14178470126353204, 0.3255232481751591, 0.10166739652049728, 0.19435767084360123, 0.18163561209803447, 0.13531778968172148, 0.10437070654006675, 0.12462146754842252, 0.14893673389451578, 0.15597336256178096, 0.16558001894736663, 0.2019055947312154, 0.14967656607041135, 0.19659304933156818, 0.1197071214846801, 0.127139441028703, 0.1811167915002443, 0.152062110719271, 0.12129522845498286, 0.24262106308015063, 0.09796954924240708, 0.11416825072956271, 0.10230710555333644, 0.22971839527599514, 0.10876494066906162, 0.08469195585348643, 0.20825126906856894, 0.0840633048210293, 0.15773829363752156, 0.09148540499154478, 0.1478663639863953, 0.15701605036156252, 0.18560375698143616, 0.26949534367304295, 0.09810534000280313, 0.14203259343048558, 0.21532531682169065, 0.09873010218143463, 0.10513485889532603, 0.13558911887230352, 0.14534350717440248, 0.20076268730917946, 0.1951574388658628, 0.14217977615771815, 0.09659448318416253, 0.09437281958526, 0.1822092180373147, 0.12671098433202133, 0.11594853684073314, 0.14357252017362043, 0.10967134046950378, 0.12389147625071928, 0.09972325162380002, 0.12319574991124682, 0.11636473325779662, 0.13872356474166736, 0.07344076700974256, 0.16429589566541836, 0.1439913289505057, 0.13728525285841897, 0.16435295197879896, 0.13029064459260553, 0.16791938716778532, 0.07233054377138615, 0.2281121353735216, 0.17573357879882678, 0.22236719989450648, 0.19649063295219094, 0.05434950042399578, 0.1624948368407786, 0.1328277654829435, 0.11647742096101865, 0.18244192586280406, 0.1333416285342537, 0.21421699348138645, 0.1461284322431311, 0.15460749913472682, 0.08402192266657948, 0.10943445435259491, 0.10770965862320736, 0.08879673754563555, 0.13495214836439118, 0.1811954443110153, 0.1743877533590421, 0.17190973710967228, 0.12399375904351473, 0.3220960992621258, 0.1416403238545172, 0.08479173018713482, 0.15407195052830502, 0.17448179831262678, 0.07854535520891659, 0.19317489524837583, 0.11071982444263995, 0.14360173110617325, 0.1099852986226324, 0.11008406363544054, 0.27644558635074645, 0.17448259983211756, 0.10565963893895969, 0.15987376420525834, 0.12771089473972097, 0.08811123057967052, 0.14613224688218907, 0.13188364973757416, 0.13475484098307788, 0.10212342400336638, 0.125141772441566, 0.09479205880779773, 0.14235700102290139, 0.12452945607947186, 0.09370686078909785, 0.16085829731309786, 0.12006312230369076, 0.1770442264387384, 0.14615071151638404, 0.08334425278007984, 0.10517152841202915, 0.21873032004805282, 0.10969655122607946, 0.30805024201981723, 0.12505500053521246, 0.05446057766675949, 0.15430109604494646, 0.1278943388024345, 0.1860590497381054, 0.12960941239725798, 0.15304011292755604, 0.12404930137563497, 0.22907459700945765, 0.17418955540051684, 0.18271531822392717, 0.15277543338015676, 0.09418023226317018, 0.20769473252585158, 0.11683693213853985, 0.19138256408041343, 0.11114433291368186, 0.0772592875000555, 0.12218518226291053, 0.10744321276433766, 0.15757819754071534, 0.16300639923429117, 0.07796592341037467, 0.11295711767161265, 0.10808846564032137, 0.09854845411609858, 0.2152370012481697, 0.16321194445481524, 0.19344199419720098, 0.10557149405940436, 0.11133197011076845, 0.09385261859279126, 0.11739536857930943, 0.29279667302034795, 0.07958569782203995, 0.1429852587170899, 0.13177336659282446, 0.18791297916322947, 0.051662413752637804, 0.11912201225641184, 0.13975608511827886, 0.13999982125824317, 0.12400178908137605, 0.1691962670884095], [0.03422223649977241, 0.025719639816088602, 0.034357440963503905, 0.032794307262520306, 0.03403641385375522, 0.04641389343305491, 0.041718299107742496, 0.01646242551942123, 0.019759206916205585, 0.03896540991263464, 0.08643536464660428, 0.017732494379743002, 0.029318658998818137, 0.08367168833501637, 0.06445294304285198, 0.0838103808928281, 0.029868388191971462, 0.016423891356680542, 0.05901858523429837, 0.03747293238120619, 0.04952588933520019, 0.055869860443635844, 0.05843214014021214, 0.024714962964935694, 0.010313152215530863, 0.04819217574549839, 0.03459816398390103, 0.01893810029287124, 0.03636461646237876, 0.011926428196602501, 0.00850054835609626, 0.04179336734523531, 0.08970091832452454, 0.02329820676095551, 0.045717862813035026, 0.058539948222460225, 0.033971924931393005, 0.0354651891393587, 0.018325622513657436, 0.08654946243041195, 0.011475591109046945, 0.053121695018489845, 0.04382185732538346, 0.03132420177280437, 0.06885210503241979, 0.021606609152513556, 0.031996546749724075, 0.03051412717468338, 0.06526026612846181, 0.06802297022659332, 0.018713133067649323, 0.01461214375012787, 0.04954334093781654, 0.042069535338669084, 0.02699971282709157, 0.018163157110393513, 0.01385312056299881, 0.02828328691975912, 0.06808613441535272, 0.08124626809149049, 0.0609481506398879, 0.029346116607484873, 0.040594524252810515, 0.02643441708642058, 0.09155151550658047, 0.03666780605271924, 0.03816237272985745, 0.03842152327706572, 0.027391444345994387, 0.053454136359505355, 0.061620465930900536, 0.037827385822311044, 0.016652448721288238, 0.09408233556314372, 0.04032998942420818, 0.03581206896342337, 0.04754458510433324, 0.02326437781448476, 0.042021648259833455, 0.037098722968949005, 0.04559390559734311, 0.06847008451586589, 0.021624261135002598, 0.028977703368582297, 0.03102944669080898, 0.014606925524276448, 0.02534030587412417, 0.048211345419986174, 0.02894897112128092, 0.03273331756645348, 0.01433238747267751, 0.049441789160482585, 0.021127864529262297, 0.03146988165099174, 0.01927283487020759, 0.042723838705569506, 0.10662041589966975, 0.027543528958631214, 0.1131115660245996, 0.01774574728187872, 0.06381276645697653, 0.025230499559256714, 0.07495356083381921, 0.03753199620405212, 0.031926751471473835, 0.02686292202270124, 0.05922865755564999, 0.05733231810154393, 0.06052409858966712, 0.014244933718146058, 0.03315055670100264, 0.030688851002196316, 0.006798672002332751, 0.015485643216379685, 0.05167506737052463, 0.020712375007860828, 0.034668857260840014, 0.0007201010203061742, 0.036885771114612, 0.04414402734255418, 0.006104960129960091, 0.05756748614658136, 0.06968230110942386, 0.04977202261216007, 0.010796460119308904, 0.006929428218427347, 0.021323225628293585, 0.04852036086958833, 0.05926681878918316, 0.03620292845880613, 0.028932636450917926, 0.008249760885519208, 0.023049123446980957, 0.03860342738335021, 0.12046446834574454, 0.017765605298336595, 0.03573193556803744, 0.09881714126095176, 0.032515341372345574, 0.02623144526296528, 0.041724919065018184, 0.013191968100727536, 0.06148132808448281, 0.03125508184893988, 0.11323746395646594, 0.04433333066117484, 0.013928308471804485, 0.04798676040081773, 0.05922189659031574, 0.04005376948043704, 0.0502284434332978, 0.0936254694534, 0.08941977052018046, 0.03420602428377606, 0.015391813485621242, 0.033324898322462104, 0.04049165145261213, 0.09482166307861917, 0.02992793255543802, 0.08196399168809876, 0.023672644383623265, 0.05800273720524274, 0.019763921409321483, 0.05396950968133751, 0.08637870909296907, 0.01342077130175312, 0.014019620466569904, 0.0553545502043562, 0.022276286108535714, 0.02343506992474431, 0.023830885111237876, 0.015165775712375762, 0.03117724168987479, 0.05248224573733751, 0.011079155301558785, 0.011561573555809446, 0.02281792589201359, 0.07331811968469992, 0.02230293848697329, 0.03661275353806559, 0.04880943481111899, 0.004570870378302061, 0.023278658591152634, 0.01501803451901651, 0.02270904169563437, 0.013572137886512792, 0.025722261452756356, 0.04715398536063731, 0.07304728773306124, 0.03540180972777307, 0.052747756490134634, 0.04683148508775048, 0.01954289313289337, 0.026819630693353247, 0.022474404286185745, 0.03825997257081326, 0.03422951325774193, 0.06372313728206791, 0.036900135382893495, 0.03449810392339714, 0.024701006877876353, 0.021067557609057985, 0.06083322165068239, 0.08027481904719025, 0.017614561547816265, 0.021052716510894243, 0.04013363941339776, 0.02928250156401191, 0.027254688793618698, 0.060679452362819575, 0.09310444467701018, 0.039664056603214704, 0.014928480486560147, 0.039678324392298236, 0.02907281701482134, 0.047587214066879824, 0.029759518838545773, 0.028269764989090618, 0.03743079323612619, 0.06839366556960158, 0.039559410070069134, 0.07740101544186473, 0.06855864499812014, 0.02943679592135595, 0.04152255394728854, 0.03894741654221434, 0.013373895399126923, 0.042307705371058546, 0.03400559988222085, 0.0365894909191411, 0.0359784287866205, 0.039750446303514764, 0.009114701533690095, 0.06991177317104302, 0.021776416251668707, 0.0586276626563631, 0.03688347416755278, 0.027882074464287143, 0.04389948968309909, 0.03700016575749032, 0.03215334771084599, 0.06206824073160533, 0.011341858880768996, 0.07775948019116186, 0.02193935106333811, 0.029064987356832717, 0.014667873474536464, 0.06612065277295187, 0.08866152566042729, 0.05493093602126464, 0.04682461280026473, 0.03757770507945679, 0.04942903164192103, 0.037857431671000086, 0.025220050119969528, 0.029425448483380023, 0.026271293027093634, 0.03179903156706132, 0.03931015977286734, 0.05293255868309643, 0.09394438515300862, 0.013571094241342507, 0.014102769764576806, 0.04487285346840508, 0.025554526800988242, 0.069637519918615, 0.018458062477293424, 0.0128477804173599, 0.004672522345572361, 0.017380927893100306, 0.025586761985323392, 0.0889600174559746, 0.028214551057317294, 0.024473983903590124, 0.014759088062419323, 0.0133586516858486, 0.07995368432602845, 0.07576497315312736, 0.017481513023085427, 0.008641678869025782, 0.02554062637500465, 0.02895908102800604, 0.03130291326669976, 0.013425640718196519, 0.019868154195137322, 0.06572288388269953, 0.03998685744591057, 0.020315264773671515, 0.017009631410473958, 0.020209861249895766, 0.02861425880837487, 0.04256398751749657, 0.056852081761462614, 0.02986245101055829, 0.07010810833889991, 0.030883377185091376, 0.022581622361030895, 0.011061858622269938, 0.0849646728602238, 0.037432960307342, 0.02102347218169598, 0.021216951936366968, 0.02082084731227951, 0.06575822495506145, 0.049584099688217975, 0.07727132513537072, 0.043547745081014, 0.0531488168053329, 0.04985947358363774, 0.032269059665850364, 0.08039370368351229, 0.058396431704750285, 0.018414249789202586, 0.046764127764618024, 0.020399706336320378, 0.018123279660358094, 0.007693591242059483, 0.06933764772838913, 0.013634011665999424, 0.06477107948740013, 0.07210179159301333, 0.05167376119061373, 0.020689991833933163, 0.014690390235045925, 0.018867928374675103, 0.05705086972739082, 0.010333207828807645, 0.07386293771560304, 0.09915161979733966, 0.018203259060101118, 0.05686082426109351, 0.05201570202189032, 0.03537558593961876, 0.03092548478889512, 0.04280184213712346, 0.04014683850982692, 0.035405086309765466, 0.0295533093958511, 0.04806219971214887, 0.08623319619800895, 0.019129661595798098, 0.0346736849314766, 0.012733174262393732, 0.037572569417534396, 0.03664009054773487, 0.05619093950372189, 0.029473131471604574, 0.04684654326410964, 0.03061712242924841, 0.05708345372113399, 0.033764305408112705, 0.04853313323110342, 0.10330755030736327, 0.2382813990698196, 0.0956990745908115, 0.08101769402856007, 0.09597925760317594, 0.1347410518792458, 0.26515826233662665, 0.15222578396787867, 0.18319470109418035, 0.11013151655788533, 0.15636438532965258, 0.050392910779919475, 0.1262329818564467, 0.26528653514105827, 0.1671822860953398, 0.13509900454664603, 0.17523513757623732, 0.08647903261589818, 0.10146769942366518, 0.2745161805069074, 0.12891548947663978, 0.17478941852459684, 0.13615867268526927, 0.17854823323432356, 0.1396056666271761, 0.17910033173393458, 0.12006377539364621, 0.13796942395856604, 0.11681968462653458, 0.17269386065891013, 0.14752148796105757, 0.22846766863949597, 0.21187913924222812, 0.15775478415889665, 0.18109126162016764, 0.1337476575281471, 0.18326780264033005, 0.13416700065135956, 0.13740611902903765, 0.1831929199397564, 0.09754420214449055, 0.13629886438138783, 0.155381633376237, 0.13734481763094664, 0.14707621419802308, 0.15798689826624468, 0.1412523290491663, 0.07416988999466412, 0.11553108619409613, 0.14771820162422955, 0.11213861784199253, 0.1297113241162151, 0.23890639131423086, 0.24959403031971306, 0.15333823364926502, 0.17561890213983133, 0.16714697470888495, 0.11278753692749888, 0.09134585154242814, 0.2625071327202022, 0.15040531056001782, 0.09449766366742551, 0.13126048317644745, 0.11905461040441878, 0.21528953046072274, 0.13552667456679046, 0.0857840187381953, 0.15700943040428683, 0.10996355369570665, 0.1177833930705674, 0.1572377298725769, 0.1735503732925281, 0.2121106002596207, 0.22631763713434339, 0.11089350184192881, 0.15621159196598455, 0.1913501470698975, 0.146987171319779, 0.1244149352714885, 0.15026272914838046, 0.11309236666420475, 0.1164630900893826, 0.13360332464799285, 0.14123751578154042, 0.13684673263924196, 0.1193637891265098, 0.1339647505665198, 0.19143605808494613, 0.21836537634953856, 0.13647035986650735, 0.09299025783548132, 0.10365773268858902, 0.04677631382946856, 0.11992499377811328, 0.12981889100046828, 0.20780526800081134, 0.14183120423695073, 0.12198638316476718, 0.21277267020195723, 0.1110602030530572, 0.17128704552305862, 0.12721521430648863, 0.16594570479355752, 0.11759108034311794, 0.24827067711157724, 0.14647029514890164, 0.21433156623970717, 0.1214886766683776, 0.10835934212082066, 0.15762746130349115, 0.1068021752871573, 0.16763058782089502, 0.11509315227158368, 0.21287582872901112, 0.12157339282566682, 0.10297185464878567, 0.12256732894456945, 0.13052118534687907, 0.11063802492571995, 0.1504070620285347, 0.06658751561190002, 0.10277109628077596, 0.17846119415480644, 0.20117529173148796, 0.1603599896770902, 0.117520687635988, 0.1254274250823073, 0.10924583752057515, 0.13270672119688243, 0.1765112011344172, 0.1367575561744161, 0.0913511504768394, 0.16737039084546268, 0.11626452847849578, 0.2701787429396063, 0.14328899007523432, 0.12234911526320502, 0.17470481368945912, 0.18550107342889532, 0.1124148971575778, 0.18167257105233148, 0.15855970268603414, 0.14995813689893112, 0.11507207527756691, 0.1409419480478391, 0.15491924568777904, 0.0934158127347473, 0.20427567302249372, 0.13568043272243813, 0.1716462746844627, 0.09331364126410335, 0.13284153974382207, 0.2040627656970173, 0.1145456476660911, 0.19703174766618758, 0.13587545428890735, 0.10154713148949668, 0.19321552041219547, 0.11722446681233123, 0.15258516155881807, 0.13997092202771455, 0.09887907348456793, 0.1280446830787696, 0.20123276364756748, 0.1480991014977917, 0.10259797549224459, 0.08520145507645793, 0.12706666602753103, 0.21909235452767462, 0.11540908453753218, 0.16040802147472277, 0.10665035413694568, 0.08362938591744751, 0.23908881121315062, 0.153971211402677, 0.11055714567191899], [0.03163524699630216, 0.00506908895658853, 0.009614580667403061, 0.020256200950825587, 0.03835660761978943, 0.0262418650163454, 0.021737204879173078, 0.030525008914992213, 0.04497543312027119, 0.04177406779490411, 0.049554250508663245, 0.03523524952470325, 0.001953053219949652, 0.10161039957893081, 0.01256606765309698, 0.03268012784246821, 0.011527014521561796, 0.048839243172551505, 0.05862649377377238, 0.029641226064995863, 0.025138486234936863, 0.09226397727616131, 0.06643291882937774, 0.02527688007830875, 0.019492415958666243, 0.025410299676877912, 0.038864140151417814, 0.035049935249844566, 0.047723201496410184, 0.06525006159790792, 0.020120816516282503, 0.030257121434260625, 0.058390809936099686, 0.02633128267916618, 0.03306570324639324, 0.052675931437988766, 0.04736409478937276, 0.022614239751419518, 0.04017387123894878, 0.08126071028527804, 0.04645248511224054, 0.04828518911381252, 0.04218538830173202, 0.04280822460714262, 0.05504263666807674, 0.020658296562032774, 0.07245227083330974, 0.009149293964583194, 0.06530723665491678, 0.0316771338111721, 0.05284744918753859, 0.04269204509910196, 0.03844419217784889, 0.036174660053802654, 0.0587925456056837, 0.010229182844341267, 0.02358940695557976, 0.053985692211426795, 0.039542852755403146, 0.03138193344057072, 0.015085455852386076, 0.08120542770484462, 0.03831271329545416, 0.013019748093938688, 0.020292219232942443, 0.030165380849211942, 0.013815772908856161, 0.024741567103774287, 0.013953919060440967, 0.01678810775047168, 0.04220056151098106, 0.012639330616366351, 0.059843708731932566, 0.061338883970165625, 0.026379370137874503, 0.06476578055298887, 0.015014799682830926, 0.010905082708632108, 0.017173512460431084, 0.03773531498154625, 0.03746054593648296, 0.06271289617870934, 0.01525001689515193, 0.004376000488264253, 0.04726507744635455, 0.035202895596739836, 0.05335468486009631, 0.014175413962220773, 0.06343395943986252, 0.005152193725734833, 0.015789559183758684, 0.04183906508842483, 0.011937290455534821, 0.04524216099525802, 0.05954736545390915, 0.02856889317627065, 0.036994180336478166, 0.04372095121652819, 0.07484394562197849, 0.010366343794885324, 0.038568386880797334, 0.03187465641531162, 0.02806331991450861, 0.046038975269766524, 0.0463554455927806, 0.04531364837021101, 0.09400427647051401, 0.045544174281531014, 0.016547809609619435, 0.027394930584705435, 0.02750792627921328, 0.016361755042453296, 0.01953592993231723, 0.024809653586999048, 0.015554351248283638, 0.053401955956360325, 0.028190750381327234, 0.0517977295385208, 0.057846800846164115, 0.022549327804881614, 0.03919993599993177, 0.035229861532570794, 0.013781859543087194, 0.041242983206757344, 0.05512691866897512, 0.040093125571729615, 0.050721875159069896, 0.06990547975874506, 0.022768413509766106, 0.027776913993875496, 0.021231960017757956, 0.014649574895884143, 0.023404708663292695, 0.045718849869444966, 0.04297796120226849, 0.013552324398915516, 0.020426534974831156, 0.046440295336651616, 0.05095444939797744, 0.05514116790436674, 0.06200359595823102, 0.04118829434446525, 0.03366166267369408, 0.016381511013605632, 0.005298379192026914, 0.021094182156957686, 0.0012314538730606728, 0.028548970221891068, 0.028050219152646605, 0.03099095705692889, 0.064080459123943, 0.01567612933286, 0.037924403077340685, 0.026350107254984323, 0.032370437038480304, 0.06420970414183103, 0.05210173549130559, 0.0414862666366389, 0.007604752918268787, 0.0323500539525412, 0.027803583070635796, 0.05082767573185265, 0.018128448718925938, 0.0576292031473713, 0.04833574792428408, 0.024933872409746982, 0.03815053547441494, 0.02916923869634047, 0.06507423197035678, 0.02042920114035951, 0.029034919243713375, 0.029759804565401282, 0.013509743675967911, 0.004484774290176574, 0.014389195166586433, 0.03150006479700096, 0.04573451660689898, 0.04616536301909946, 0.11525033172802068, 0.020521559563349, 0.02666093725565588, 0.011351749853929505, 0.03450238611549139, 0.0830485588812735, 0.059826861979672685, 0.017404531899956055, 0.03791734896367416, 0.02108993892761646, 0.05117701206472702, 0.07334554946282879, 0.013740492231590906, 0.032736664652475156, 0.03795363998506218, 0.06562845301232301, 0.048268795071635395, 0.022727200193912722, 0.052929979719920084, 0.06978019038797356, 0.03590141612221487, 0.04040653453557752, 0.0342062580602942, 0.008988464069261681, 0.022821755374025088, 0.05777050064352807, 0.012765490155288717, 0.049613822702667676, 0.05855857983988244, 0.02993968260852853, 0.10244438060908578, 0.08456518218736164, 0.04069656955834944, 0.06162652556668036, 0.014074471673666267, 0.033968655770877376, 0.06228598314919509, 0.024966513919935096, 0.02796765893435804, 0.04768036102177575, 0.023751851949782576, 0.061622748035006225, 0.05441582987259608, 0.09038922318723053, 0.028751144236593973, 0.08071404430666007, 0.03227042150683701, 0.0039963093877304345, 0.03295975795481354, 0.03396175008674618, 0.09848278146819212, 0.031639570006518625, 0.03721961140399799, 0.03628287260653451, 0.06137740514532197, 0.025972556322813034, 0.06615229794988409, 0.04136222036322579, 0.022278479154920205, 0.06374612159561366, 0.055140396070783027, 0.04720255521533545, 0.04472287284443155, 0.06404941508662887, 0.04209857928799465, 0.05883464764337987, 0.043996844615321606, 0.020735941907332744, 0.03871277171128895, 0.029162310747778974, 0.08231057465309277, 0.02693783440918196, 0.020063198026036844, 0.072649674693821, 0.028728898359986488, 0.06530838698381558, 0.03996853010903578, 0.021645464294124395, 0.018084838266076986, 0.002327655970475462, 0.020747341295646038, 0.05993838822178077, 0.0496203684451757, 0.08492427776218392, 0.027340154520061333, 0.07611157838255167, 0.039347281999653205, 0.037374015228124335, 0.032151885679923, 0.04325162815803196, 0.026134953077416867, 0.05468426097650081, 0.05547269269300159, 0.022642927469860297, 0.02645386877702549, 0.03185625857440755, 0.05815620592329651, 0.0154009632387897, 0.012294064963498386, 0.010403402939118678, 0.028417636058293283, 0.040823064919095486, 0.015407055343530374, 0.02830640853062505, 0.037376275067799725, 0.038029750940040685, 0.005293348822306143, 0.022002372388669755, 0.05635214511130471, 0.02727065239014337, 0.051344032399356365, 0.035887756894226186, 0.03186134228599258, 0.11732535436749458, 0.02296164650033461, 0.05024511207011528, 0.07513452612329274, 0.044347334987833165, 0.03516133161610924, 0.04562445610645227, 0.041081977979047224, 0.07302895668544807, 0.012435045191523386, 0.020427208473847713, 0.00867275259224698, 0.04564698399917688, 0.012966389531356981, 0.09014211769681424, 0.018705973197938874, 0.03610514308093116, 0.07088898128131405, 0.043645144542097114, 0.05853010363352951, 0.028879552482976578, 0.025651835348980967, 0.04144101418205537, 0.05234035452303942, 0.014472894581558648, 0.06202915552421473, 0.06018814689014107, 0.045794337420375086, 0.04936108431138564, 0.019277914871054236, 0.12718750251224265, 0.029631472389155533, 0.02096869982779026, 0.007542918565377477, 0.021611075026157778, 0.054573376692133024, 0.02246901814942248, 0.025532269792165607, 0.024615333350084256, 0.05662243900587782, 0.04908194030576851, 0.03901763113390189, 0.028333762238617055, 0.07338535084272735, 0.0021194988539718906, 0.09078847637283616, 0.019484317272144835, 0.07608183310367167, 0.03495166376524139, 0.09054443595232442, 0.04707877982582431, 0.06801810915931128, 0.08742415768210776, 0.006187634917296236, 0.07042478275252506, 0.07157141575589776, 0.02984260041557718, 0.023547512719233055, 0.043767602619482204, 0.00594632745560375, 0.03492656062007882, 0.09552033574436791, 0.11499558211653493, 0.3094365738797933, 0.0808159560256172, 0.1264761688071303, 0.1588231947971508, 0.13766720658168197, 0.15855633333558217, 0.1681742406799458, 0.15818465093616396, 0.17862532753497362, 0.1259272318566218, 0.1643306578625925, 0.1390299529884942, 0.08447718573734164, 0.16002397489501163, 0.07781024309224449, 0.1557585850241594, 0.20207431458402425, 0.08868406468536705, 0.13345888786716387, 0.12395674071740359, 0.19121388875646517, 0.10466294945217669, 0.10515805101022124, 0.06095591721532401, 0.16616915061604232, 0.14194546529324725, 0.0898548768600449, 0.08615660655777901, 0.26237743499223143, 0.11128127400297672, 0.17479762667790055, 0.11947822087677196, 0.12940576707478613, 0.18170662078773603, 0.14096473198151216, 0.128349305014126, 0.1591195195214823, 0.15831709461053833, 0.18822181649738923, 0.19794113090028986, 0.13985076831886545, 0.12431396608008072, 0.2408735131029971, 0.15603320935042575, 0.12998881313251331, 0.14210668945452198, 0.21101094520417973, 0.13396883237874135, 0.16931915190070868, 0.14429050352191553, 0.2333560914848931, 0.10915327686234377, 0.1324218255467713, 0.11284166917903349, 0.18251602188684046, 0.17549361276905984, 0.21111388108693063, 0.11392803236958571, 0.072037417703541, 0.20490419788984582, 0.08876981984940358, 0.1063262953539379, 0.11195189348654822, 0.2271790330996737, 0.09326670042355545, 0.09841819235589355, 0.08619213316706009, 0.18007748789386824, 0.17617659643292427, 0.08019295273697935, 0.189477545209229, 0.15874271630309522, 0.08931287899031304, 0.2696331753395498, 0.11517577557242475, 0.14482283120742068, 0.2160718580125831, 0.11889099652762525, 0.09605269311578013, 0.16827205574372783, 0.09380636052810587, 0.15292411524569616, 0.12978623650269583, 0.19349692796822637, 0.10147959605092183, 0.12028413388179615, 0.1819924812298268, 0.09072843662579544, 0.07633505389094353, 0.14743556210305542, 0.09737443586345762, 0.20217048207996413, 0.16060406720498577, 0.28182879905216396, 0.0840388955839444, 0.13781913905404508, 0.21489620703505352, 0.13520853070076555, 0.08646881324239075, 0.1370841308380477, 0.124345418298617, 0.273695305804722, 0.1844382585841231, 0.08294874001876451, 0.2649562794249505, 0.12552466127090156, 0.18653064005775377, 0.0860913198266644, 0.11809848670964129, 0.10949309886200354, 0.11785181908635423, 0.1948529653600417, 0.09491414210060611, 0.18590052699437365, 0.07757118990411982, 0.11931192042538896, 0.22445949231041595, 0.14648113050498068, 0.10814547000336461, 0.23369353119051084, 0.18138755665859208, 0.13318300188984722, 0.20825104642426595, 0.09657762901042588, 0.12013888815999962, 0.17427744052838534, 0.13179220230085775, 0.1421307647251524, 0.08711520160431974, 0.16137788974447176, 0.17733017593855038, 0.12227295606862754, 0.17579220846528187, 0.17043326399289072, 0.12726183602353558, 0.1640714256791398, 0.1820783774019219, 0.1602569647366181, 0.1059282296046149, 0.1464032198418863, 0.1684829147416167, 0.14015466294949874, 0.16301943134749308, 0.23129210458137095, 0.1334307753131725, 0.10829921331605874, 0.05940781942626927, 0.10408713191282004, 0.16340260219294578, 0.15164478623773903, 0.11831117881229147, 0.11222179775359109, 0.09149979523499496, 0.2235670152003877, 0.1504512198152952, 0.1201136625604704, 0.08743871861952357, 0.10432035924168304, 0.14066462230402976, 0.14530086336890236, 0.08622279870905913, 0.17582921194843948, 0.1200069417245686, 0.0915531482314691, 0.12883107759989798, 0.17981230368604884, 0.1270405572722666, 0.10787192921270616, 0.10644109075656161, 0.10459469413035549, 0.1482419203966856, 0.12594847212312743, 0.05997241569275502, 0.0981375269475393], [0.015795000981597695, 0.03915324377885554, 0.06615432401304133, 0.0038705826136720134, 0.06598748921533115, 0.048215052447631024, 0.026223394816042855, 0.012764199746015947, 0.041588104140828364, 0.007404215803035186, 0.017341467901133, 0.005475562311403337, 0.0609393636113964, 0.04110948197194375, 0.026177446598012466, 0.057622520107543096, 0.024339556839549914, 0.04213697429804597, 0.07747699652099982, 0.030713776031916495, 0.029101963009452447, 0.06928025744855404, 0.011407953625166556, 0.05501641287992243, 0.033162516410811804, 0.033596999346627854, 0.04019711159344297, 0.03742224369489122, 0.002796010526253667, 0.03780113976972643, 0.017954196155187674, 0.05036212278355379, 0.021963929139019456, 0.04726224986370653, 0.047145710414042696, 0.03690927864226978, 0.023628163762623444, 0.009000692807603627, 0.040274844141094945, 0.0263654938316904, 0.02174612549424637, 0.010661696305760415, 0.03073895895795431, 0.07545349377323873, 0.0391089227196062, 0.028572373848874122, 0.05820612277602777, 0.05999398992571514, 0.03152484139718581, 0.05163576322956942, 0.023372668292722665, 0.029194777853263076, 0.030179361056070775, 0.06530020851641893, 0.0803100859047845, 0.024365162789763417, 0.018410474112897646, 0.06686411405098625, 0.018267942796228454, 0.035813141366816126, 0.05445764247269835, 0.013845209268765757, 0.016405558453698177, 0.018001398602791596, 0.04276959953131154, 0.012579175836435752, 0.03549999586539343, 0.03192961245076731, 0.01096458625397645, 0.025584927025192883, 0.037991077624610625, 0.02160689859010745, 0.017078061136999168, 0.05461872191517614, 0.013424371645669453, 0.08513440945534967, 0.05714615406759549, 0.04728751999209635, 0.07903038582298905, 0.01854062640632037, 0.05923474316659849, 0.01988436826650286, 0.07493580866139382, 0.01816122567106504, 0.0580635413643904, 0.024028084881138057, 0.022791705814597663, 0.04972501868905965, 0.04168092826148495, 0.01335064205704839, 0.03337534210004378, 0.03617276386648882, 0.06952204174012877, 0.008674724849697668, 0.05096924040117301, 0.026853094132093247, 0.035441599975456484, 0.03316069443826564, 0.0742521570646204, 0.025748329389898572, 0.042198490918963216, 0.06492313812486827, 0.05041274838731624, 0.0373151295207208, 0.014880778016959084, 0.045390367886284366, 0.025470324580965098, 0.014169116839184426, 0.0585495145060122, 0.07062725548166782, 0.03887067847244907, 0.030964555153332185, 0.018871089923777618, 0.008068129518505884, 0.041795449069468305, 0.037416228587972, 0.05572793954343069, 0.06430438734241761, 0.03935785389330704, 0.035576451919041574, 0.03192704461980611, 0.017824639435275458, 0.0512919930042699, 0.08697716955794021, 0.03268910411861725, 0.02693362272111699, 0.027381584914110135, 0.04756784772325773, 0.025354659010190517, 0.03757499624043703, 0.0090251326582802, 0.007722361988271587, 0.014508599306282122, 0.09735140702105127, 0.0064607499007252045, 0.08089211522019468, 0.053270005810190924, 0.0346421696303878, 0.03289596294052899, 0.0488841282640351, 0.021444136327772867, 0.020605071586032864, 0.08804291588603519, 0.05035782203776762, 0.0357714512210805, 0.07122038732632063, 0.018977296822413336, 0.052136041267658584, 0.026994126310455613, 0.009200787881127326, 0.043737790547311306, 0.025385254048160277, 0.044179939868627116, 0.05503687389136758, 0.013585413980763406, 0.03225307009415701, 0.06509262238978408, 0.04760932635690551, 0.05258949349808972, 0.038437746625277214, 0.05449048621812835, 0.010624857022776268, 0.035533325717551634, 0.04190560975985136, 0.03359854301379528, 0.007645375762876938, 0.01307360111240996, 0.024774421981419437, 0.07276590244146064, 0.05063610886281822, 0.0316882660263218, 0.053375962233985774, 0.0332128451555036, 0.06280987261561677, 0.04029702322441153, 0.03407432646781672, 0.026754757709568366, 0.027904728522116784, 0.00786429309300729, 0.04223241820000112, 0.013917842334194575, 0.026908660584012978, 0.024469775926263537, 0.033835132271633483, 0.04366655179182999, 0.004280692955944687, 0.035586723242886364, 0.025224204291589558, 0.058313392801210284, 0.08035951294004917, 0.0035721928634302458, 0.020047624057042412, 0.025574609317118302, 0.022488642389362212, 0.020411374753166456, 0.015224074195430148, 0.029064775844744872, 0.027049176969740074, 0.05008582862501498, 0.07287843429367058, 0.04427532810950652, 0.038659184938296676, 0.03961861119023524, 0.031666654685977846, 0.005645401415677043, 0.04620161693310365, 0.03999949251010548, 0.05891153043194208, 0.025376183148182463, 0.04436899827851448, 0.02202037318056682, 0.020305407197156455, 0.031774685412528925, 0.004445001668500481, 0.03471846241154708, 0.04205492245091591, 0.03494852076983079, 0.02447718256007647, 0.049161906717927195, 0.05677584464137908, 0.03377983484824654, 0.032425671379314736, 0.04622033389750868, 0.009027942614920903, 0.04951419308781624, 0.036928285044268705, 0.02129995929863071, 0.018224211744382046, 0.03754372213734314, 0.01668408833211288, 0.027288929632049985, 0.07793793702148832, 0.02346141802263446, 0.029433118579618167, 0.022775256111344788, 0.04479978160816245, 0.015641801292076707, 0.01454880886740284, 0.031069164579093922, 0.039979491630219854, 0.04370804897916969, 0.049579624537727796, 0.0012751546591971419, 0.024728204734856263, 0.05444461035949644, 0.037996610335540026, 0.05847730724781286, 0.059624545101542026, 0.021066709705337416, 0.08036045546759851, 0.05219211052462924, 0.03919364629837219, 0.06644723485806026, 0.040967921013361774, 0.06981111568165943, 0.02581184424343519, 0.059510981664061546, 0.013124787037668284, 0.026603138794598635, 0.09351658896775916, 0.03974602310336195, 0.06788850791053846, 0.042149408982368186, 0.027396409313951153, 0.024458883053739555, 0.023301802466448862, 0.0681968851131387, 0.04131496410991531, 0.05113967461511493, 0.015078682827152079, 0.04256896732840687, 0.04740282005514018, 0.052879257636959665, 0.011259355251240777, 0.00831119215945364, 0.06200766292749904, 0.08159197532222606, 0.03535831245244481, 0.016104387505038176, 0.051327267283340916, 0.01375218384055188, 0.03808451030636206, 0.018966470743180253, 0.03478780869045295, 0.04638779952074401, 0.02104103139572544, 0.020300622200011276, 0.06448660686146468, 0.023117642231227364, 0.04433579830219969, 0.03422307512664702, 0.027330170778441243, 0.036552639576257206, 0.033313046224066056, 0.008408912599406904, 0.031556705507682636, 0.09029082182678394, 0.021686217478418257, 0.020593379049387295, 0.06580186323844828, 0.0802297484187875, 0.04336500605859328, 0.029829928243998438, 0.03659035552118439, 0.05704255396267399, 0.009110597457038239, 0.023463783618353773, 0.015671004803152755, 0.046928220326662995, 0.04641627943783533, 0.010066670129162958, 0.032384344885940664, 0.05244384330580942, 0.016176973258552607, 0.09639019961468875, 0.050642290952964686, 0.05290118067932781, 0.008211988351831678, 0.04515820553933736, 0.03451901764492504, 0.045944748490001075, 0.03512393850542139, 0.04050273171742447, 0.04263762712071184, 0.027649379626382142, 0.038898453349247575, 0.05999848734063562, 0.023022233581286855, 0.0274076862478978, 0.046780135890003294, 0.028239882412890438, 0.1053306671383325, 0.03724918969965074, 0.01490909466156154, 0.029315968713490292, 0.041703608294483274, 0.0518919229216408, 0.035415253732935525, 0.028435460590117145, 0.019628546251624357, 0.04389884401462041, 0.046595916282967664, 0.04353101707238238, 0.0737143968581222, 0.03314030764158815, 0.026302587539248634, 0.04574648373818491, 0.08356084857950918, 0.03873413443216123, 0.04146769439103082, 0.0021750845553469844, 0.012302937338972697, 0.053409436804940924, 0.15845400601392612, 0.18148160161217675, 0.1364909767289646, 0.14896713226335123, 0.1379140152130276, 0.11780497472500429, 0.11093204157077707, 0.11118527720100246, 0.19914579985197634, 0.09797630278626457, 0.10886380216106772, 0.2787322917720303, 0.11189360520802438, 0.12114940385799855, 0.15039166988572106, 0.11016336953616701, 0.12955275684362277, 0.17301525513175875, 0.06502287535113283, 0.09722195420181379, 0.17025495559209958, 0.11171383477631025, 0.1765136353787966, 0.09724962146719918, 0.12605897791218013, 0.07172892175731249, 0.16007766185794026, 0.1326127356151119, 0.11891746893525124, 0.11204298469237983, 0.27330781565979123, 0.14148135582217947, 0.16160500177647918, 0.08141480982885696, 0.10987626228597946, 0.08238058144343086, 0.07462524954462424, 0.15181490132817999, 0.08742038015043363, 0.10077445927890949, 0.07002171492786147, 0.0940442485443782, 0.2271798049332574, 0.1985544862691313, 0.12032625076244585, 0.16810924338642508, 0.1424370936001651, 0.1270269908127375, 0.09084361052373424, 0.1478964654961601, 0.13977263501146808, 0.12605448049725965, 0.15872520161792636, 0.09914413894875906, 0.1260243047727272, 0.18484940839698538, 0.1806606526952237, 0.1446644272073172, 0.12306139891734347, 0.1604629255598411, 0.0578244955977425, 0.07540995196904987, 0.16362725029466674, 0.1441573622287251, 0.26921840384602547, 0.0721734607941471, 0.10496308881556615, 0.16996263846522197, 0.12009098994894885, 0.08098578167846426, 0.09675086112110876, 0.19571266922866926, 0.11798870080383494, 0.15571843483485281, 0.12486199761042371, 0.2524839830584824, 0.10503531462745741, 0.21243708586553112, 0.09669122213381343, 0.11039032571716234, 0.13171221362426877, 0.14038003835594282, 0.1234979227592703, 0.186527359765023, 0.17063171428162605, 0.09253068288671784, 0.12303059978876263, 0.2129163796780631, 0.08521171897882596, 0.10034659630036913, 0.12409131435560994, 0.1357865598401986, 0.09838935249717906, 0.09596903822966851, 0.13505330309271812, 0.12465668987715617, 0.12251228385139257, 0.17412771965609863, 0.166148949356284, 0.11580978491110727, 0.15156435227254406, 0.12264962570043281, 0.14244981401134282, 0.11548615657375194, 0.15274090867023915, 0.09274059935705736, 0.2656245685648173, 0.16186941415071487, 0.13368408515816554, 0.1192186250409577, 0.15913088922388852, 0.11665975922369398, 0.12621588277397677, 0.09657553615397774, 0.10175128147238865, 0.10509113155421801, 0.144149198604282, 0.11700430870405398, 0.12240267606102861, 0.16691643395461142, 0.12403375338180922, 0.09876712792902254, 0.1243703173531685, 0.14204687235178426, 0.1165845722425729, 0.13835694378940389, 0.21474955865414813, 0.15125193778658286, 0.1303711676155217, 0.0828807518701069, 0.09933798792189918, 0.15065017476445064, 0.14388389565283433, 0.08723836101125926, 0.1908194669522345, 0.13090616703266278, 0.12616626278031617, 0.165017960825935, 0.1740158483153209, 0.15223664900986478, 0.16638063301797956, 0.1474334395607002, 0.14537850685883313, 0.11445523181464523, 0.1675458048703149, 0.09223516710335389, 0.11927994870347902, 0.1046276454871986, 0.15776984975673258, 0.23405396263115108, 0.19222487200750038, 0.13072656729491428, 0.13265741290524602, 0.13961843156721443, 0.17791347432648763, 0.2067790855653584, 0.1948445790912956, 0.18759419705020264, 0.12693340599071234, 0.16203549195779487, 0.1545225380687043, 0.11589211135287769, 0.07210895331809297, 0.11830520452349447, 0.1033041364280507, 0.15256645943736658, 0.12818560207961127, 0.12295827749767341, 0.0800744465959724, 0.09581903534126468, 0.20052913343533874, 0.12071844612364657, 0.1167595484002959, 0.07530455957748927, 0.10229603271000087], [0.038534099658136256, 0.08046065282542259, 0.03293452493380755, 0.06875362945720553, 0.007204411094789975, 0.06650666604400612, 0.023168230727605987, 0.08465261460514739, 0.049792338904808275, 0.015405091435241047, 0.015422454907820793, 0.010280257447448093, 0.024470380776620004, 0.04755363188451156, 0.034335065211053006, 0.05719283886719495, 0.07301375007955357, 0.027852299499500077, 0.030511678087350447, 0.010736154126789188, 0.05463819958094973, 0.014626061802118784, 0.04985076819139067, 0.03035468045709422, 0.057731033230083995, 0.011972889424214372, 0.04090493494004477, 0.03539033241395373, 0.11856208409881219, 0.014310765000118408, 0.036031510899192654, 0.07356167770922184, 0.060191468000994064, 0.03919557959306985, 0.014275067696871702, 0.05527944114874117, 0.09070779007743113, 0.032279056395054795, 0.0036898986445521587, 0.03598738279833924, 0.021434057962324005, 0.06131633010227233, 0.09386883451952599, 0.0738320050004404, 0.016209334607992787, 0.006904740212121396, 0.0719256279990077, 0.07058647446683608, 0.05859397286258172, 0.044412655115593225, 0.04866240793489851, 0.08096686433418654, 0.07061731070280075, 0.03163522473187186, 0.05428019125247374, 0.04828679586353246, 0.0411324217566289, 0.04015851991425734, 0.06990424037212506, 0.036883552093058825, 0.02285433751239907, 0.05110683458042331, 0.04342285275924951, 0.07144717281335033, 0.009116794390138239, 0.08842500319587998, 0.08207155857235193, 0.06769629908376373, 0.0742165933479555, 0.017406938313797582, 0.023776420748617966, 0.01944844741956331, 0.05628317732771393, 0.04325452995544765, 0.07473988167475909, 0.057872609031619504, 0.007204771500255447, 0.049085075879702345, 0.02032253411016427, 0.01568905012391042, 0.04513273132033646, 0.010491365064808633, 0.06196295595145784, 0.034407762286718935, 0.019618998521764297, 0.028547554575197864, 0.02418245901935734, 0.0541099388647126, 0.018996297658304684, 0.02220163161837263, 0.03261063313402701, 0.013634020015160786, 0.0326041282096412, 0.05001244135200977, 0.014537747156282421, 0.04018315550638363, 0.1541568076936528, 0.08561048976844177, 0.048035307991085574, 0.02381015136052156, 0.010456740164954681, 0.027289974204904865, 0.025490939588053152, 0.025044452413567342, 0.017591631039977074, 0.040748460523900576, 0.10083043205668218, 0.018739058141363785, 0.01369402543787146, 0.044488302228273824, 0.016045551892602816, 0.04367068555438891, 0.009871199563349364, 0.08314066682942212, 0.018308003927813843, 0.06986652442719787, 0.031793320740689524, 0.02515726999263279, 0.03512955656333361, 0.02932518062152667, 0.05032751643739175, 0.024223447835538536, 0.0575020324322395, 0.029126366680429783, 0.020442817694856785, 0.06459848562371917, 0.0480503290600609, 0.0271268983851769, 0.014494732276943978, 0.020245103987690527, 0.05734069323807489, 0.05591781431576237, 0.08666592024383135, 0.045041410048725083, 0.04137121148232836, 0.020486025532591157, 0.035429621711955406, 0.04843842405534815, 0.025984449239331298, 0.03753535442228895, 0.002758140817604726, 0.0178057295124745, 0.03173727003741078, 0.050850459665525705, 0.06105514235969167, 0.05525800421310123, 0.06414768286049366, 0.011704315456881886, 0.02428532996418653, 0.04937082871038001, 0.02490129212674219, 0.004214017017147853, 0.0627345297834836, 0.012883982381026726, 0.017717777591315098, 0.04146580191445537, 0.017255759121326264, 0.0273227214711369, 0.018332138570258394, 0.08148356238962151, 0.08856215208652429, 0.10794635920319706, 0.044119254453107715, 0.04838033244595863, 0.038777431327616796, 0.04465629106562119, 0.03751840005861595, 0.012700984534603776, 0.014374995098478394, 0.06836270316853188, 0.0454436763538979, 0.0633279065368697, 0.03956325068429578, 0.044506700069177896, 0.030939915850467514, 0.02752500124188373, 0.02576663075160468, 0.026032210153061897, 0.017215286097780336, 0.02740094012551708, 0.0650533330917824, 0.04666230881412048, 0.031929356409818865, 0.07677120665903203, 0.055982325502554886, 0.06202911099535413, 0.02247633758088341, 0.030580803577322513, 0.03659021822386421, 0.04445092024980113, 0.04729252577817533, 0.013155099131836323, 0.054604190663667396, 0.03486546702333726, 0.06509496015496552, 0.023917204307508655, 0.06494155823020265, 0.03932849082048051, 0.057902320913854055, 0.03100274236203404, 0.05493071708770003, 0.030618892451457214, 0.05306768522132188, 0.03033454227988841, 0.09121405353653245, 0.023813854677428026, 0.01895364828669699, 0.06320091022644192, 0.022665438664262183, 0.026538336314843036, 0.03726842987816781, 0.008302216810989194, 0.04882626672042534, 0.054025571516831405, 0.055768575839465484, 0.017146774735010695, 0.033941162910196, 0.011081589545938186, 0.0255833072878886, 0.024723085771256592, 0.08388702990487218, 0.03728720992512535, 0.07150220306357369, 0.017856529520940967, 0.04000117718533147, 0.04259366600308567, 0.01875903304608073, 0.03949587480747141, 0.03592465647670906, 0.017120241100201383, 0.045041309858788736, 0.05351389409042895, 0.08085991343250498, 0.008759064367040992, 0.013296544129843824, 0.06127766420831904, 0.04740668664453551, 0.06965783992200159, 0.046742427366552874, 0.026457108251634054, 0.09573815608746372, 0.06651685573160648, 0.01680893612501677, 0.03596289563574828, 0.06391437389538623, 0.0015696043010393623, 0.008354601304745302, 0.024796944308036473, 0.05675414424331393, 0.017657559728831984, 0.015089435619302094, 0.01947531502082711, 0.02054229331406532, 0.03246637817937881, 0.010290871086908737, 0.04329948926169891, 0.010540676139498828, 0.0834922147623729, 0.05106616488774307, 0.02576203871285543, 0.06378593039698899, 0.03081684550124919, 0.032154772634385154, 0.054554051166633144, 0.07088966405717656, 0.03588801664591301, 0.057273083584732376, 0.06915245961863548, 0.027723202911147382, 0.05490529852977488, 0.07457042709575035, 0.02671445909072645, 0.018615739172673784, 0.06669570590020157, 0.05770635310909711, 0.08610222197603434, 0.08670387367601506, 0.02455217472743243, 0.02285845828737365, 0.008473733632854419, 0.028632198373088613, 0.02203892872785218, 0.04618220977135934, 0.07066373946145177, 0.008079245963017456, 0.0465003202407388, 0.0171041030989727, 0.052201190701453015, 0.017487615332356654, 0.08136983567965217, 0.031919496977934614, 0.029891925405536313, 0.042955462995450944, 0.05521997656614985, 0.019942856924899388, 0.03712509147590026, 0.02363489689741982, 0.050685049791354686, 0.0560524361935677, 0.0411901200277498, 0.026363924189354293, 0.020636746448872145, 0.046037149586481974, 0.07026304650935344, 0.10223818972008303, 0.018454346172802616, 0.013842015250702389, 0.027399635800975375, 0.007497600709029939, 0.04334396988269873, 0.0256654834447545, 0.052209821878932416, 0.05732754238124471, 0.03734949837962631, 0.021776230714749545, 0.032550066462135874, 0.050835026704589836, 0.037611506195389666, 0.02072067221888574, 0.02768562797427876, 0.06594462276552804, 0.004375392391011701, 0.05279280485410709, 0.015144294247875223, 0.04280448047211394, 0.04675355216022581, 0.029191898320277687, 0.03687157382955775, 0.03916467656381428, 0.0329164981667418, 0.026199492094747256, 0.019892826894647442, 0.024088412210403476, 0.029043366739642806, 0.12642832996789366, 0.006718442127748858, 0.08088315749773756, 0.0356324172753375, 0.05615936854155734, 0.02957879474706715, 0.0037731685415565153, 0.10819716058904305, 0.012669145471591037, 0.03902057374943979, 0.03192363445123192, 0.017161448849947192, 0.035293738183099777, 0.049043764229281805, 0.017145360943686683, 0.05241041326371487, 0.019636600409285165, 0.03359610876941588, 0.09877667194814421, 0.16761540347943082, 0.13883583684219047, 0.11979235714534298, 0.22014561051037163, 0.15767393459100276, 0.075118755485164, 0.18081593967508525, 0.09462008834816515, 0.13760667701717466, 0.07729721866780892, 0.11599919584114105, 0.09165511932224035, 0.07630698586581275, 0.12415394419804215, 0.13857834128430113, 0.21621911495458335, 0.11085165955591947, 0.08015580824576318, 0.1402775477617979, 0.20060823153471574, 0.11707223748089746, 0.17679317272268236, 0.08614158548880368, 0.18120017921319231, 0.11242750624660403, 0.11225716851186007, 0.15860199026064947, 0.25314390077255666, 0.14790495566558093, 0.252882664790377, 0.2612943743588403, 0.11611596535658464, 0.1245811689295806, 0.07601840174174868, 0.1291676118853502, 0.16851809254148975, 0.1472312191617675, 0.12163701714598574, 0.18702801258768886, 0.111771299270913, 0.1218279346358031, 0.11127530713565648, 0.1382427421049215, 0.16246679850155488, 0.14033172454219311, 0.1881154815782793, 0.11178792337886989, 0.23803537711501122, 0.12876818800577894, 0.14501743717119098, 0.25075854908209294, 0.10186268526013009, 0.09842179919360206, 0.16216366086155176, 0.20872245862847194, 0.11299635501927696, 0.1452011484070681, 0.09755477774888277, 0.17237455904250965, 0.16615387721685693, 0.10619891312671825, 0.1488664376665838, 0.17134380497736856, 0.1402455908828415, 0.15719136048574, 0.14444718573940918, 0.11880392034072429, 0.09053400135599077, 0.13111053965985775, 0.12244451092556119, 0.0931482165469788, 0.13006938068429008, 0.17471564904553816, 0.15987714839866385, 0.1366685429820791, 0.07089417631505057, 0.15963676676619798, 0.11132181010907516, 0.1744301151484251, 0.11181936075445265, 0.2204376010922715, 0.17007839865982533, 0.1751578800030984, 0.1306584826670587, 0.14078036765567958, 0.1516671248828061, 0.08919715590309352, 0.1464574263081886, 0.1039524692168925, 0.16345775860827416, 0.16328213678207248, 0.11211934426683001, 0.18123161658877507, 0.2662973402766511, 0.10411378243588842, 0.15737962850835174, 0.23013052472379059, 0.10974086486385204, 0.18407211260637268, 0.12814853922463953, 0.13932779169408605, 0.10279839247232303, 0.08782757431617938, 0.12591847451403737, 0.15229082579026, 0.14429624774493277, 0.13470372185111046, 0.08060314517933875, 0.2104200323810801, 0.082283523370279, 0.11646447048406117, 0.14296392939286307, 0.21484036784386262, 0.1417260419111699, 0.14976445119827986, 0.11278339574346319, 0.1415418557007797, 0.14703549997648224, 0.09427686731214635, 0.21213409665506333, 0.1547340353135951, 0.3087650192901492, 0.10021345500717871, 0.15202647278783843, 0.1394944335334003, 0.13593482610303909, 0.16137477272422984, 0.1871831066091545, 0.13017141114687547, 0.13703066651942208, 0.16971341043245047, 0.13547266105888411, 0.12819376570405439, 0.12137863101088442, 0.16172929666936398, 0.08571921440307051, 0.1694645534735173, 0.1315724226878956, 0.13755322754150257, 0.15654634509701282, 0.14866188692394644, 0.17382116813678294, 0.14035192580195144, 0.13417304173344746, 0.17051731963874772, 0.20360218884889036, 0.13972972403280437, 0.13194615341490135, 0.09772366829565726, 0.14416377438465133, 0.10913024801993743, 0.1453314398531802, 0.2178158308379352, 0.1332284658565186, 0.17507722339360043, 0.12356652689049952, 0.15976569266058505, 0.19072086521191522, 0.10865905103855766, 0.18563618883490562, 0.16903220792301, 0.1453495185705833, 0.12185900093754753, 0.16757957258960232, 0.1646596222417429, 0.18708910618443042, 0.14264081313740462, 0.14005422068294138, 0.1546233959379606, 0.10680740000680089, 0.138134136213921, 0.0909825628332328, 0.17640933394432068, 0.08961580882896669, 0.22766505077015609], [0.022472786404250655, 0.052670053628389724, 0.009318639076809632, 0.05611138869426213, 0.024274808165500872, 0.015290361898223637, 0.004327344358898699, 0.0010926905792985053, 0.023134182847570628, 0.025310953933512792, 0.03762185915547889, 0.013614432882604888, 0.01594982411916135, 0.06323726804112084, 0.012670120468101231, 0.019026410300284624, 0.12269617320271209, 0.008963167038018582, 0.04639190359739587, 0.02865613263566047, 0.00397283293750661, 0.07925320824142545, 0.018088500764861237, 0.013178894241718808, 0.0640617792669218, 0.06578448956133798, 0.038791591505287215, 0.05847499174706172, 0.03518819736200385, 0.019739126255444717, 0.028254938733880408, 0.025144410428765696, 0.033393628618796356, 0.0627368972345721, 0.020162074360996485, 0.033237224706681445, 0.05672662169672549, 0.012737357192236232, 0.011040366025554249, 0.026508132759772707, 0.07054130735923536, 0.05448997413623147, 0.05904038582229987, 0.012107977927371394, 0.026298184748156928, 0.08053825920796953, 0.06982414037338458, 0.12263068609172478, 0.029510023632610682, 0.017307978487224318, 0.01822101494326489, 0.013250874217192177, 0.010366562728449935, 0.02738417315413244, 0.027778806470450945, 0.0400590016215574, 0.04806553195521701, 0.03778836369747296, 0.03566514598787762, 0.04172840344836004, 0.09415352978976443, 0.017072075715987012, 0.03725272232259158, 0.03308998631837312, 0.10161371697904542, 0.08160576442605816, 0.07005685562035069, 0.05054982306319289, 0.07483423833036795, 0.01196761368191801, 0.009491097498539602, 0.031036118598422036, 0.01648178258619737, 0.04685628395236563, 0.026505557507334743, 0.0298128068970982, 0.02829658620612463, 0.029119999053364154, 0.04236253895214759, 0.02000474833039334, 0.03530074405716732, 0.02613047050544992, 0.025682805171527434, 0.029430313261400443, 0.032980215255520307, 0.009415611802978674, 0.009978273847082164, 0.05988447861454915, 0.05785430024843663, 0.027481468714540824, 0.05098180496133864, 0.05439675667730626, 0.054440717794932425, 0.02471574036462698, 0.047795616555958986, 0.013488431977748405, 0.07792279720888473, 0.02487315174221294, 0.03221752122044563, 0.06928215734660625, 0.019572701494325884, 0.03384552604984492, 0.06201671341841575, 0.019754420063691214, 0.03817871111095883, 0.008140764439303894, 0.03949440535507165, 0.06631323267356493, 0.04256033986166585, 0.06588718053535558, 0.015267913786374265, 0.03436770486587193, 0.04042049062263686, 0.05218673737545032, 0.0947957843891345, 0.05354749482648913, 0.026378652109997347, 0.0376103039161535, 0.10387326721684076, 0.08291060104966164, 0.04905700414383318, 0.03608405495469924, 0.017543912799737882, 0.02317712907824898, 0.022947252546146046, 0.03512570110615343, 0.02797774472128367, 0.06107098721258808, 0.017692932342470158, 0.0280602678321884, 0.014250351396185579, 0.0268492980467272, 0.022985922150837723, 0.031596811168128625, 0.03987317155406345, 0.029245075056678616, 0.03926769408280961, 0.08267002645879984, 0.06349174305796623, 0.04018245788756758, 0.01601991996722063, 0.021637764511979185, 0.05421707159257494, 0.07282888851477765, 0.05331146589014679, 0.015603513893438503, 0.02566439248766983, 0.05097505883895792, 0.024166385956050362, 0.025299905209976714, 0.0803672980691772, 0.021537672910199035, 0.05340514348063152, 0.03347309037053492, 0.03261072590248659, 0.020537903510557953, 0.010847801895579323, 0.05234956457570661, 0.017217909589817282, 0.03571933390048798, 0.08718564626178704, 0.05741399887483567, 0.01571760240040021, 0.012184366260044044, 0.047031512440298684, 0.03509006688545924, 0.040710325265536085, 0.008161077021213714, 0.04655929129512515, 0.047539464285364375, 0.0032055503424999188, 0.01134643700424931, 0.007167853364080656, 0.026126676275453065, 0.03554185670509469, 0.08065167421591468, 0.03266833140514791, 0.08356304533663206, 0.015753342377138324, 0.0709850003477186, 0.016032100465963595, 0.02970779300085269, 0.05190222022065427, 0.03518554789479822, 0.08231751373386942, 0.049425250399508514, 0.0028874296685899026, 0.03525407410052139, 0.028157129236205947, 0.008501277516188566, 0.02524057050322881, 0.03666152377263643, 0.12722701445454732, 0.0306971760437591, 0.0558888371597277, 0.04066370354848914, 0.022526916800416075, 0.023061446809151676, 0.0240369498351356, 0.025467662126175128, 0.028066162340110168, 0.06536007014801726, 0.0556997416424565, 0.031774833842064254, 0.07117191766155884, 0.047501559092779644, 0.008550271322746994, 0.006436829089579987, 0.07281086916918866, 0.05106381970108487, 0.046752539128647186, 0.0259084477511351, 0.013196743821026757, 0.04118059827305842, 0.019960950485256035, 0.06447628358728252, 0.04356349345471244, 0.03036417438124772, 0.022342982920235954, 0.05894932059163693, 0.017842833185568452, 0.03317984926979989, 0.06338972743833438, 0.03231878356018569, 0.0656545469246339, 0.04131333509576507, 0.011594057359616272, 0.019234627252444625, 0.047349415108328685, 0.03256805241107941, 0.049192075020982884, 0.03968129669374321, 0.024186665141314734, 0.02992132187500829, 0.04589555523125455, 0.06974598480155692, 0.036186757060931996, 0.022623373733949848, 0.03864447557134554, 0.02697020689083729, 0.03718837440828793, 0.019394532246224117, 0.017984262412937824, 0.05252085225947667, 0.015147759149840567, 0.04755540932819713, 0.030623037346231285, 0.07749237382085994, 0.015610204354743473, 0.040953263596748, 0.049167313263751566, 0.0237351369287353, 0.010615738810884068, 0.026111393599421717, 0.06531085091410205, 0.04838846638449468, 0.03513242867484223, 0.006676783523289487, 0.10142085506231524, 0.030495905593852513, 0.05098606488900259, 0.002801488039949618, 0.015614835356245749, 0.045192949182819575, 0.04796695619006641, 0.021364707972679753, 0.03138126550766174, 0.08154504190315492, 0.06356659607263282, 0.024496159276168328, 0.03731724835233763, 0.03587645398511086, 0.029252628264657687, 0.057241753820562735, 0.034088597967638634, 0.03870055967126973, 0.04713448171969503, 0.020285543614591006, 0.03267704421887174, 0.017780559574021026, 0.05384136675274931, 0.0394150066858856, 0.020224752443027683, 0.0053795195890415926, 0.028700002840196248, 0.058240773651050404, 0.021990679852024186, 0.029226426740933675, 0.09307127067586407, 0.034103607904398814, 0.012898759468953358, 0.06663068634225056, 0.039740920838085, 0.0014443005511566298, 0.03524929838022217, 0.03264336184656713, 0.014859316961519653, 0.04907287497189827, 0.06763090845197439, 0.007686568205826916, 0.04301308705180418, 0.0323600581032224, 0.042477386305108666, 0.023944214772200212, 0.018059575559163932, 0.10074964186060242, 0.0513186843454605, 0.027511158332345076, 0.06088458940212149, 0.04528247445705347, 0.0401686428085668, 0.017297989179496653, 0.036463618962443434, 0.06978540026466362, 0.03363896037626546, 0.033072879814426415, 0.02472994692652719, 0.050005338998744264, 0.004203926127956947, 0.003926216786567238, 0.05325786427420098, 0.04716355906566605, 0.04636231416952796, 0.10081051281304099, 0.05469148207339458, 0.036095157483941875, 0.07873165654018521, 0.054227361470111646, 0.030837603371765, 0.06727544940076768, 0.0297216006583767, 0.04963916704582516, 0.03918744194379542, 0.018680231805774383, 0.04949821093759965, 0.020683956317952834, 0.04765230412886012, 0.010734367406257661, 0.015623162253177725, 0.03791875904425979, 0.030889913650753442, 0.09082681572181173, 0.0441291732568061, 0.0337098614545539, 0.01544879465654958, 0.022090977399784606, 0.0015188616930572607, 0.022487931782961823, 0.0035262631990917725, 0.03865584156301338, 0.07605162769323215, 0.0632526601839345, 0.15587903559207916, 0.2108552129357122, 0.11608708839048631, 0.21158256218768656, 0.0730488017143216, 0.06683952669845894, 0.12757273652823642, 0.14636899199103937, 0.11956106682191603, 0.24037907947786152, 0.09807899376028217, 0.12295198408537544, 0.10167794243898243, 0.10502742559765466, 0.11302675338811241, 0.14453545678406954, 0.18583693978143856, 0.21655121119692922, 0.11850767725263722, 0.27164935308974236, 0.07596438081236556, 0.11994779255473986, 0.11186247211298905, 0.1552195186377503, 0.15893240924924612, 0.2344179860665463, 0.16216665913816541, 0.09346913604531437, 0.1053061243146658, 0.12142260326072574, 0.11478029991849326, 0.12113591161323711, 0.17617168341530487, 0.10046672032331116, 0.09212142555043101, 0.10128847818123177, 0.25557710614521056, 0.12490735767642036, 0.10516746886423789, 0.13707892096135765, 0.14301371265901253, 0.10207618630374782, 0.13903709244914353, 0.15275487588951364, 0.0563388012960786, 0.19613361539086327, 0.15172538347542286, 0.24851956375641748, 0.13606018968857825, 0.1330614826292731, 0.052837474722764455, 0.15110757522052154, 0.15431173844262958, 0.07234678938402794, 0.1906241782126017, 0.13958301628008485, 0.08260268397862092, 0.10639112195349298, 0.20048559905262664, 0.11433348248829134, 0.1474621458328329, 0.18711048003751785, 0.17924340296303853, 0.16870031948201358, 0.15985884703695774, 0.09035124006913975, 0.14392983459401876, 0.17982046731049195, 0.12364099398837425, 0.17443584452848881, 0.1526192409801297, 0.16776295728050172, 0.07011281355516985, 0.17383923201123253, 0.07007018459262326, 0.17784337105695158, 0.12456797354388982, 0.0801673337991815, 0.16130403120769188, 0.12673140823608264, 0.12108483701013029, 0.10220677460893057, 0.20372694387333468, 0.12286352750379592, 0.16692735836841166, 0.15129041072214022, 0.11989811318926513, 0.12036343978252262, 0.17607829155167565, 0.17454109591199085, 0.16682017740095034, 0.11952785571338609, 0.14800910867052153, 0.1824822393245995, 0.12823146680602804, 0.10870840385905467, 0.12115699602873065, 0.2211847953731194, 0.273462746408768, 0.16331781924236566, 0.19296473386930302, 0.08884019771357998, 0.10812187712872401, 0.10293350787833333, 0.1508410254609771, 0.15881624829489738, 0.08023732574656606, 0.11175076404470019, 0.16682991437846795, 0.23531154671218246, 0.08859644673066214, 0.19033517106436193, 0.21783076284918934, 0.2147864137077704, 0.15481761598493904, 0.1473725537653081, 0.17516182822873816, 0.13890015135984868, 0.19002575485501438, 0.15172398823779076, 0.0950385260512121, 0.24949107959400862, 0.15329380868934095, 0.10815371526405215, 0.16252355795586482, 0.09560733029502444, 0.12899541878141463, 0.13408569095190614, 0.07518128142692149, 0.14618654240621254, 0.17689756321487948, 0.138927343650721, 0.09311000336310826, 0.1383193614310585, 0.07247142566484399, 0.1893399510299787, 0.17114176269387826, 0.1738532882882282, 0.2736196661135182, 0.11829209819552489, 0.09715937630971894, 0.15264404355548322, 0.10253596905386075, 0.12454513023840263, 0.10540290779317729, 0.10716498902183957, 0.11028960885596462, 0.2181797058437951, 0.1489132671849802, 0.06276102445553988, 0.15320381586207077, 0.11644429148873314, 0.13111189036862925, 0.16142745036631823, 0.17278866260312498, 0.10025356808910146, 0.12858976086135954, 0.11175002931850031, 0.1422044451464899, 0.10417669429443777, 0.15647440130123869, 0.1122485744417645, 0.1094722816196736, 0.11713651489117183, 0.17320107406703755, 0.1269254946964793, 0.12293311869143508, 0.06419612283934839, 0.09939938579918817, 0.12646387884160504, 0.1352962525561452, 0.0924080132972449, 0.05254095704003703, 0.14389433024916798, 0.16893425927264616, 0.20092257560463622], [0.00847880157380132, 0.07119505782611668, 0.03206338456948288, 0.02252300939289853, 0.05487216534675099, 0.013344136204977985, 0.02805443826218834, 0.0638361218443606, 0.039227154265972786, 0.03508063789922744, 0.02407774569292087, 0.03126979121589102, 0.04156885654083453, 0.048502293284400366, 0.03301136319350917, 0.007184631467680447, 0.04776539630256593, 0.024566470347053837, 0.045039335745968856, 0.012054572980559897, 0.059285224051564, 0.03154502410325222, 0.03355747627210803, 0.02713477071665693, 0.06675015727523714, 0.03702166577568278, 0.007087095636961749, 0.03184659952239599, 0.025373212702106684, 0.04777887741511222, 0.024818668825901113, 0.06331537166261114, 0.013459086530929198, 0.06114839321526233, 0.046540247785742395, 0.03037325084733311, 0.013726344113820232, 0.023619963030796498, 0.018209656373073813, 0.03532707916747313, 0.03028781295142835, 0.029146150482119992, 0.010451372581883334, 0.03496411329251714, 0.0549356375267962, 0.06317256760667078, 0.04129075154196471, 0.05401110334787518, 0.02959471010399284, 0.022936415334697813, 0.016360248482669704, 0.0491151848109439, 0.07052436412777752, 0.0498900908860378, 0.03270428474934306, 0.03182440559612587, 0.03239506891986821, 0.05215730008785613, 0.02275465780257946, 0.025416672870051116, 0.047098257491597906, 0.015483222887269221, 0.014807709867454832, 0.015110195345187094, 0.06405960477422923, 0.0717794249067083, 0.012535989335447084, 0.050137816069764085, 0.056641538176336326, 0.024597935553174466, 0.06754572474164888, 0.026239299040753394, 0.08785478887148201, 0.008081587438937277, 0.027984208827547263, 0.021380159487307537, 0.048128722119145095, 0.037025632555014454, 0.030883122999512125, 0.034596390250953846, 0.010853395833692048, 0.01153221697677509, 0.0399363023461774, 0.06845297801191919, 0.01857818650023546, 0.020072621446161065, 0.056081394795910455, 0.037615302280755714, 0.020004145335406065, 0.04539854635368101, 0.05641152063617483, 0.024014852388063446, 0.06423634724342264, 0.012327817839832278, 0.07988684650626965, 0.004006199897048646, 0.048815075133461505, 0.02823931095917942, 0.06750570071744733, 0.026986255834344774, 0.03666687465738505, 0.02470653402269818, 0.014463780080404831, 0.038570936158066615, 0.05670236831065267, 0.006455345674112323, 0.033245143422391266, 0.03810123831499368, 0.05394112995418254, 0.052944870913052, 0.005092339515613276, 0.08728776578209363, 0.020701424618891906, 0.08571962258429267, 0.005527491775865201, 0.045448285090969875, 0.04241677510435693, 0.002249736262456281, 0.07903241188614629, 0.12048654723912477, 0.06200578900461551, 0.048500823832000606, 0.040295568614965305, 0.004764541235999786, 0.022751104770577513, 0.036624498025048524, 0.01975474660866894, 0.06519999631564133, 0.06145406900031958, 0.03315154375741258, 0.017223373652086593, 0.058745511996676214, 0.05030137428548187, 0.011917748779524118, 0.02385240739386063, 0.010684082262741867, 0.0775493484979961, 0.05993695587676484, 0.06939925340702757, 0.03798750418354757, 0.002568173276813468, 0.038659722995362245, 0.014154427881294396, 0.05281719924823847, 0.016229242719418835, 0.039124893737607636, 0.03404259965464007, 0.05462777982756961, 0.10558527574175969, 0.011830818239104701, 0.04351214425696526, 0.010005849271692568, 0.019431910513958428, 0.03277918971434701, 0.048704357832320966, 0.035599324910435826, 0.0466589171992382, 0.04475762390939053, 0.08184981226804666, 0.017664363367657643, 0.012743586594297085, 0.009717809698486235, 0.019052173956879415, 0.02719272317335708, 0.00662435450067278, 0.017184160424221773, 0.029692363750655204, 0.0190902220128919, 0.032298968217219226, 0.03928880818421021, 0.04290876335289795, 0.03443993809923995, 0.06591211669729091, 0.020356713721412234, 0.05541868660657201, 0.06790411527617835, 0.04884893562120851, 0.008698523670318536, 0.021259306304273196, 0.07013012043898925, 0.08959736645920202, 0.021711220433644485, 0.02732680699409684, 0.013937693856860278, 0.083313676295802, 0.06303707370534539, 0.0843921207706444, 0.03488225811452139, 0.09532945536193438, 0.024382744268223178, 0.032529768723179586, 0.03259357858041767, 0.06625255467952229, 0.016567226048209704, 0.044816531881224364, 0.0555479167815065, 0.036491712962742895, 0.0397584281017771, 0.04000236091087572, 0.06824630472692661, 0.048670916658011265, 0.05309690357535146, 0.025652199001342524, 0.024900093558244407, 0.04182279350061435, 0.08619982181699015, 0.04281227302271873, 0.04420292789291125, 0.02657418946910184, 0.040642444728291593, 0.026987721576006152, 0.03704535141878296, 0.034108554318663664, 0.047496441984549165, 0.01753199947415851, 0.096374874265166, 0.0185355074427207, 0.019038588943658397, 0.014061647361813812, 0.0402591625606874, 0.0586227051098831, 0.04656114295357838, 0.013945306436653482, 0.07059144685626961, 0.036808179575018585, 0.010069459676742554, 0.032525245333090425, 0.027764217702497263, 0.04757472743222024, 0.01174406581412768, 0.003918514685210539, 0.05311705288477242, 0.07942034731968306, 0.033202302947756834, 0.028891679176012985, 0.01719027572107734, 0.08922301974962465, 0.051202226532041095, 0.058924499462591484, 0.05985238814901095, 0.03185423993272707, 0.09112200496019796, 0.009038308562594466, 0.03436717051954474, 0.04538065317319706, 0.015580889521515928, 0.03365651959029492, 0.0878207762434613, 0.030351953064382542, 0.020708009324152954, 0.0469074810098391, 0.061751469838782214, 0.05294611401041038, 0.044998435987508856, 0.033482393191661686, 0.008243050942837726, 0.025426690008316655, 0.05916703703405801, 0.03336436944664456, 0.05521640683582518, 0.04810859136341605, 0.024393197418248747, 0.015814612233953085, 0.034260609245393425, 0.02477784513757797, 0.026857569282583427, 0.04373954943730496, 0.037686040086555295, 0.009782955421542283, 0.02821440819388954, 0.1020112335390877, 0.019245162038714625, 0.019346639601280913, 0.023464562873414252, 0.04266437783371657, 0.05275200157484505, 0.05585788589087315, 0.06670999224297702, 0.04495538400078658, 0.0529220313183032, 0.019337783924129326, 0.01621197850909084, 0.05414496081357356, 0.022305478487396613, 0.051690485488506965, 0.042294335580663756, 0.01835942362959031, 0.047368302766699344, 0.03167041366396006, 0.019520591595210135, 0.05670672471751459, 0.006742593932358432, 0.0343408205662854, 0.04326212583691813, 0.07782720858813263, 0.03438885978539474, 0.042523540469119325, 0.020609993880498223, 0.018094120678142644, 0.06458431802457199, 0.018330546663491987, 0.07018042320851237, 0.04103423561900854, 0.07980785230756737, 0.05417258355009835, 0.040058456143015064, 0.02606138397823088, 0.07327007304411381, 0.016222162630583625, 0.03366906188603025, 0.018018909577222075, 0.009864087005553301, 0.012896882763016038, 0.05221398903813679, 0.09899955373839475, 0.054570634456467815, 0.01897391448437702, 0.02858095493138535, 0.013218059229984647, 0.05900015770748723, 0.02654447016539052, 0.06365389490383677, 0.038378990793717094, 0.08444596358458512, 0.04842148824536707, 0.03617245587520301, 0.08825096956570633, 0.017879582483146805, 0.07577750802738592, 0.028269382783037145, 0.0034721497331702267, 0.02270423443405889, 0.04528623343503568, 0.07720314402831718, 0.0655318031203933, 0.03610002597270068, 0.01744396777212387, 0.05916689973673783, 0.030433054962486494, 0.05812538081954699, 0.02125079758116044, 0.025841481910902075, 0.05711737729143351, 0.028590361653186847, 0.047407380552613176, 0.039409065793734044, 0.039703961883788, 0.11880036545335315, 0.053551899472950026, 0.03493485040962696, 0.023197896225610748, 0.017925256106536835, 0.13888245855923742, 0.148747545608785, 0.1655180347734131, 0.14654689963208511, 0.18182506755692884, 0.06550947931827977, 0.2153743282542564, 0.15297150879632682, 0.15387537045171484, 0.11280090300715528, 0.18610924860695377, 0.15145666664466262, 0.182290468364954, 0.10817819129442796, 0.15405538579216227, 0.09243478256394155, 0.11992120882496238, 0.15413274726597592, 0.1653142410214059, 0.15628041874151677, 0.13375693437410519, 0.08224053817684762, 0.1438548628357239, 0.1708118780516088, 0.15544902038527653, 0.15696030022809282, 0.09708464946015738, 0.07720565990894102, 0.09135760716162622, 0.09554383956128731, 0.1498474826803431, 0.2405440143775195, 0.1324062849744223, 0.12094109784811735, 0.1595004045520909, 0.17941727332072333, 0.13542090367991477, 0.12707653659163043, 0.0832765169616323, 0.21218097070232034, 0.10775565693620592, 0.0769843440502882, 0.14179132122080773, 0.08184740770957433, 0.146695344010368, 0.15361653902800754, 0.13325886422535405, 0.17294155986746773, 0.13956900453194976, 0.09262152918381616, 0.1242677154368721, 0.1043961696268525, 0.16968535725027323, 0.1550261297961697, 0.08464541577268392, 0.1378739986103028, 0.13194052793551236, 0.12088268340448849, 0.09637299663154408, 0.07885393279138952, 0.2724480821052566, 0.10116892561200075, 0.1680981260142289, 0.16775332420365885, 0.19162450422300026, 0.32126474543474615, 0.09058769574039616, 0.14734928001416847, 0.15272576885763556, 0.20374239538796246, 0.11558550788322464, 0.17295370140345767, 0.1963200280442834, 0.10671596741303802, 0.10708527493989095, 0.1639508266816847, 0.23046762304147705, 0.1898461699602194, 0.18243480124510825, 0.07916459580883384, 0.09774545775144361, 0.17065381543943658, 0.1222968012734782, 0.14779324759729207, 0.10974122109473683, 0.1766710152151063, 0.07772784985718317, 0.10920589513261802, 0.09358658091514371, 0.1675900220288895, 0.15872049640165642, 0.17925557418493554, 0.14558773313183337, 0.12307556651649065, 0.16484158200910315, 0.1018254146038089, 0.1229546261311043, 0.1421404571738094, 0.15668012463720515, 0.1425209266017191, 0.20778764941496775, 0.10397503050626256, 0.10081194515805691, 0.18795654323184863, 0.10066509639727883, 0.13379552605329081, 0.14233861060347408, 0.08544425611034967, 0.1213608639955055, 0.14455411437666044, 0.1597423298517242, 0.1818209857447073, 0.09483185276621953, 0.09825748027651571, 0.11039419972803444, 0.15827581635676324, 0.08593468955950812, 0.1465451778494753, 0.20002563076559454, 0.16919344692723826, 0.16937353648245335, 0.14581319759599864, 0.11154131512739696, 0.1884071753011085, 0.08815059409243986, 0.18259470438351855, 0.09059258649358526, 0.20344598160590976, 0.14469663641648367, 0.3004008368588984, 0.1502765330951661, 0.11262788611929864, 0.18464959255652502, 0.10846035584108904, 0.07396149492706172, 0.13190342055168003, 0.23050801071804017, 0.12171872760518454, 0.11706358403898776, 0.13171420258004218, 0.08673551885294728, 0.12061954752425663, 0.18111023091478273, 0.15879356826189905, 0.1552527816966176, 0.2294367057038471, 0.09711279912153259, 0.4336434183642268, 0.19735401787329465, 0.1098923446261324, 0.26583519007544965, 0.060053324632463045, 0.11527622526045889, 0.15068757900735363, 0.16250883374596015, 0.11674185559968464, 0.08720118683413602, 0.136681575095281, 0.21139922202564776, 0.08544844182324596, 0.21497408801224083, 0.11170495126862079, 0.1289740894571878, 0.10511542946915142, 0.07716559877735563, 0.06726057676132768, 0.18163316301070154, 0.12945644091814756, 0.08175693990779109, 0.20710943033918738, 0.12593402992933989, 0.21885053312871605, 0.154194078349974, 0.10004339186707512, 0.05760976629971992, 0.26176807237789035], [0.027554663029150106, 0.039733566154609434, 0.04702231351984665, 0.03215311393432785, 0.061285612609935924, 0.046372047436307184, 0.07774853351293132, 0.04791087951161899, 0.04025288399134297, 0.012359447246126365, 0.04179450654191896, 0.05011193366954103, 0.03436574559600558, 0.03540316043654457, 0.03629263926995918, 0.03694320963404607, 0.06910521449754015, 0.05175056976440828, 0.023400404206768144, 0.051933872819063254, 0.03838864613499027, 0.03948506171582267, 0.020011371998407412, 0.018713442914304323, 0.07617656083311886, 0.024329829138878267, 0.02637738303747028, 0.05789042428659741, 0.048789151915116236, 0.016363473114324734, 0.037198055724729784, 0.08470745931845158, 0.03339917246194091, 0.011392924207029864, 0.06136836207588203, 0.04649050533771515, 0.031995730387279764, 0.021668576628144365, 0.08507726408424787, 0.03688378958031535, 0.058948634105036035, 0.07935860063298605, 0.0380180398497032, 0.026326631268602796, 0.025610885495552793, 0.00488341984237195, 0.05095386310131289, 0.01745526140439324, 0.02737254926614696, 0.010039203243650263, 0.051865075729438104, 0.04446757404366508, 0.05907061720790807, 0.011505912480060942, 0.057416459094383754, 0.01905948967760196, 0.06351682022796012, 0.055938327277544886, 0.035855336172971874, 0.02574160182120977, 0.03996912011643872, 0.04055500488902908, 0.011127412526548142, 0.06889696785947308, 0.007093031890690327, 0.07486770919058472, 0.038689824505127035, 0.04883151370449923, 0.013201814545027446, 0.05378422138164751, 0.06303577494691126, 0.04298425090382807, 0.026324979990022257, 0.07488049639505334, 0.01787275843526004, 0.03463874461886007, 0.06764274570741691, 0.02986650313687278, 0.040619378778501414, 0.03910263301804662, 0.05870856417459436, 0.044483036690508015, 0.011728525241778698, 0.02067248642561026, 0.037223407489364035, 0.0844849189161323, 0.10042261448688805, 0.06548737073899247, 0.12752687180181965, 0.013010790371481562, 0.04284444512450136, 0.010232332333544036, 0.0026207739210803993, 0.04647817084332928, 0.023475652415072545, 0.039051150233717635, 0.04335823396104388, 0.08977755991509184, 0.052844543679384515, 0.043724821516661905, 0.067614618310472, 0.03277023570262827, 0.056265005841851234, 0.03741768319741823, 0.049005124310497195, 0.031530526248388924, 0.04362910673080478, 0.0644848108640872, 0.04614680932718329, 0.02293138542881934, 0.05178371036890894, 0.053622770865331404, 0.015376222818304086, 0.010409308579255594, 0.04999199889425654, 0.06433737580664456, 0.03691073325171601, 0.040299023312400095, 0.0448573351604864, 0.0035702873992704554, 0.026918976436718367, 0.054604728720732965, 0.040093882562359795, 0.05633026659779716, 0.04405594554555137, 0.015899615973467007, 0.03695743660500739, 0.03047686393983895, 0.04418221455125604, 0.02652721894264687, 0.047986263161874376, 0.02139316376997158, 0.057406866835663095, 0.07847961576771922, 0.025280911795562133, 0.04419694989337586, 0.08222836695495062, 0.02973836391902296, 0.007582649905089056, 0.05573608461418189, 0.059186332873650827, 0.0358525419869693, 0.024686963588465005, 0.012747636865242384, 0.09115312321227975, 0.011726969514711527, 0.10751637368230149, 0.0590305968944449, 0.02874225887353532, 0.016751803741499316, 0.04031362506793812, 0.04669028407079168, 0.03945131255022716, 0.050854589717346244, 0.09501946769887581, 0.03791166040173266, 0.01439449873942067, 0.020584037265507504, 0.0424117136572022, 0.07464397393050604, 0.01278243153137737, 0.07041039250907488, 0.057793566593318246, 0.05212553987803403, 0.061776914371876046, 0.05160386201168876, 0.08240224473411217, 0.051228654410806485, 0.06797018126235344, 0.03779715814744122, 0.027805748286482412, 0.06356690035318024, 0.038627591711701825, 0.09193424106342718, 0.051135091853211634, 0.058089798549190164, 0.006712266067552264, 0.01650131591304671, 0.06405780135537498, 0.04754435874929186, 0.05744733243773226, 0.05876198767509777, 0.03909004619345069, 0.03680115885799751, 0.037199354483163916, 0.037624445540132, 0.01878427719930187, 0.07263682069606148, 0.06361683204886504, 0.018081719390465878, 0.03584612983104307, 0.03399074950721115, 0.04692950795288198, 0.046515645590261556, 0.01761992542014923, 0.07620422067702748, 0.02877195776818553, 0.09358516341308132, 0.08135307798511349, 0.012601063626789255, 0.06025297348969616, 0.07894960304838605, 0.03585645310522523, 0.03161061882565264, 0.055543972266605124, 0.051374189570196904, 0.01957452346687205, 0.05708779157430399, 0.02332068826945033, 0.038702426172676496, 0.07294855240616016, 0.020386462711030617, 0.023793417785782367, 0.04984739141946193, 0.04720319717307575, 0.0179901328010601, 0.02155613012291724, 0.02264559178001946, 0.011991450537607307, 0.024523765314370394, 0.05875425078556873, 0.02830468860338442, 0.05541212231037207, 0.02301968059327919, 0.03289426342234947, 0.04277212283341214, 0.05636511414195411, 0.07166596536990255, 0.0630864042614121, 0.033493592200102285, 0.08395405326155014, 0.011612602702371078, 0.03511483606416732, 0.032650961438775994, 0.027963050197286066, 0.062095377361401916, 0.07619889947818592, 0.08373762073460966, 0.02964895924378652, 0.03667906072223559, 0.011153051873407094, 0.026721869435277767, 0.0401971041719662, 0.0178977539690095, 0.05711400794098154, 0.06784704411984421, 0.012735479558614315, 0.06126045009295922, 0.05106127784529235, 0.0482766284403624, 0.08987678505945951, 0.034412949898978695, 0.042849510282394476, 0.02761429459496867, 0.051924269428127445, 0.013521065138775157, 0.04862437286647037, 0.06686311957309954, 0.05118067827424966, 0.028851055867562536, 0.04464827215997502, 0.038445539175882004, 0.013533237288356759, 0.05069790749985259, 0.0449218055291567, 0.045016021176707, 0.03211836658010725, 0.01613404743693536, 0.03093956704105949, 0.03250108100473881, 0.04835428677324671, 0.03227660730772186, 0.05282817561237607, 0.059255207888782024, 0.007927163205749821, 0.028093931650801096, 0.034098041796823964, 0.08410729933530092, 0.08562120638089254, 0.019630394199339207, 0.046997329118312337, 0.020025569283461664, 0.052551773842424154, 0.018697881932894234, 0.06393502044375055, 0.03232816801755689, 0.04932546864438336, 0.057464680139673874, 0.033021077906596474, 0.05016916067688726, 0.0011384347067178169, 0.04599116240569856, 0.03225328531698324, 0.09315864372183569, 0.02224317333457293, 0.01767099260177929, 0.020745432120747864, 0.02016641963564325, 0.019019510182261, 0.08973291973234154, 0.0427078157372307, 0.003648163274192484, 0.017267260554945096, 0.048065249939099886, 0.04982377999112941, 0.05544768973777536, 0.0593305507209152, 0.03933843931008596, 0.04745095575344749, 0.07918785471701995, 0.018672617370611988, 0.026468995602044743, 0.05317816132446751, 0.04883044501184486, 0.032398701732745394, 0.06327116934699006, 0.01878234019386582, 0.017221724228875246, 0.03168245872075204, 0.017416797745681833, 0.04188644750684034, 0.02488068083039252, 0.016564528341405094, 0.03565531624190044, 0.013270576382637955, 0.019604964509198908, 0.01796565677068429, 0.020798015139007475, 0.03266146653913893, 0.05308854699251242, 0.031206478597596288, 0.03281346209405456, 0.03346458535816055, 0.035625522723421454, 0.08704633029992692, 0.0725095349480398, 0.02931945495220134, 0.037901337127550505, 0.03450878713920247, 0.01915332682983717, 0.05432241203379817, 0.018695093312999234, 0.04247533426678274, 0.03025386711669853, 0.07084221855620854, 0.03043315144168446, 0.03220913866243791, 0.03240718076995108, 0.02184879976994125, 0.04094176401849836, 0.018923407624242827, 0.04449078842299059, 0.1201980299083516, 0.0947334588272497, 0.16091772849904373, 0.1434277420048602, 0.1747756145778112, 0.20421643479494378, 0.16162187821464613, 0.0989930599462241, 0.11219965206691995, 0.09393976899445988, 0.10174577473662794, 0.23138518474297598, 0.17090118810301647, 0.1063420066202525, 0.1443551148986444, 0.0840151913871523, 0.1856529910583049, 0.14805016427999362, 0.088160345912911, 0.322621242958121, 0.1373544507077895, 0.1253287194413133, 0.16696526727173477, 0.1707486470695585, 0.12444387160940096, 0.17284335888689384, 0.15539935586275533, 0.12705453933449462, 0.13609615416498855, 0.09335883063613437, 0.08400495717069134, 0.23392965289531276, 0.1775578668457456, 0.15261134452885017, 0.12640434375498444, 0.1646695818635635, 0.1928496712935157, 0.1483991221175529, 0.17386876948876306, 0.14316383429104462, 0.1435130593017675, 0.12759259640006348, 0.07229691706015728, 0.16216505609918386, 0.12444914827938192, 0.08417544333497062, 0.11189622498932295, 0.19937564298743382, 0.12479716358939186, 0.13741760747507215, 0.11821639171103016, 0.18545133469160646, 0.1522566721541807, 0.12407705027726479, 0.141609821585007, 0.08755081260460429, 0.13323757942998782, 0.10187584353843704, 0.13482311856932938, 0.22427668649470434, 0.30985006887931377, 0.15020751336123794, 0.10867785706068389, 0.1377192311338149, 0.14607332035666332, 0.17417987779481336, 0.1625552773475647, 0.0950966881646309, 0.1448445167625323, 0.10806490987306461, 0.12572697072755545, 0.180451218620874, 0.174000337428879, 0.15294615703169256, 0.09646943872212432, 0.2267141072661616, 0.1298328285338357, 0.13392298249527812, 0.10712453455198556, 0.07961323150084354, 0.22016061673639342, 0.17380657751346007, 0.08104724634904414, 0.11796341583249159, 0.12607632932486013, 0.17686204402707517, 0.21763977856608108, 0.14233852154575288, 0.2850051020504907, 0.10587555196252652, 0.15201427188003436, 0.23157097399234772, 0.08576951717259362, 0.3000491776037961, 0.15365814382676035, 0.27933809207752347, 0.10019347639172338, 0.17323215521173552, 0.13995780085679144, 0.1621955880546011, 0.17557229526573792, 0.13939639582531527, 0.1680307390051894, 0.10922620771452785, 0.13805797701934353, 0.10660319065209478, 0.16394015459809452, 0.11318602570099756, 0.21913391479756683, 0.13602413615444675, 0.09932695218594745, 0.21823395683895797, 0.11551340823643841, 0.16975955717498437, 0.1747702859574929, 0.13236217171652243, 0.11707774421665817, 0.12290046419366263, 0.12088733667042106, 0.14559620845830068, 0.10931792974588461, 0.15243812726112083, 0.1282962117693387, 0.2129939044243656, 0.2108111442066729, 0.09128333302214742, 0.10646255366737023, 0.18087562319124117, 0.14715819183038548, 0.12249951148987748, 0.1424448416219093, 0.11230666976189241, 0.18908969883341342, 0.16921142174396664, 0.13207274896558374, 0.1192906430514995, 0.11419704605941661, 0.07649172126548365, 0.19201156392227858, 0.1271793685737066, 0.12530792446341366, 0.10372224758611992, 0.10628888368955813, 0.05291263201797847, 0.15729545411886647, 0.09736878069816157, 0.263617088785395, 0.202811979688704, 0.16632829676382244, 0.11836059842607938, 0.0925148899841588, 0.059408684028312564, 0.15720556519227102, 0.07218889004434459, 0.2688431442948058, 0.14735083852428943, 0.1398426343803294, 0.13349881541216746, 0.1306050777202472, 0.2588487899629399, 0.19584529101848602, 0.17602258594706655, 0.1968906950787641, 0.09150401805527508, 0.23369394679320976, 0.07397966270218603, 0.13607555214548483, 0.1572361565195024, 0.18451035080943257, 0.11611583919147961, 0.12957807892234996, 0.12695543293375522, 0.11683958902722225, 0.17647827946348116, 0.07144553266698495, 0.18841625918867067], [0.02718923322390765, 0.09629845531890169, 0.01991539746086346, 0.037693520935135894, 0.021365654210967477, 0.027113341202493757, 0.029510622916859575, 0.026596335155772977, 0.09058238196303137, 0.03320552386867348, 0.04183747689239681, 0.04487234880798496, 0.023765724545228295, 0.041264479514211416, 0.1138923573307693, 0.0577704264287604, 0.02837533178535523, 0.0486641594034154, 0.03759426610486116, 0.05204615605180152, 0.013565708104579244, 0.04485277837375179, 0.07348168903263286, 0.017111799170379527, 0.06972760180360638, 0.01960497749678325, 0.04761443975439761, 0.012983029409951996, 0.0260995786084095, 0.026122369963559322, 0.02592157634353498, 0.020815216266782954, 0.041941663293982856, 0.00870733574629412, 0.03405364652280696, 0.02952667371573625, 0.04808379992027767, 0.05246101660304703, 0.0374931596161332, 0.019886704176315106, 0.05016067792894319, 0.01492413335654419, 0.06373700060066767, 0.05100386530102696, 0.04981078498531133, 0.019813140643236693, 0.024732208621571772, 0.02612747593957465, 0.02951901846245164, 0.10195460024988279, 0.020994981132389512, 0.010933989360637497, 0.012855931054218672, 0.04254530023899861, 0.01662380924244644, 0.02845276005245978, 0.020734817553602625, 0.05776999598310795, 0.04558627631922718, 0.027561939787119627, 0.04865674905886408, 0.027439032710390165, 0.05787347734440118, 0.02757290316367289, 0.017837422929005697, 0.03138438623864204, 0.04731761779112276, 0.04335726916906424, 0.016327944649674464, 0.05451812379760668, 0.028230195530341007, 0.03788759626331739, 0.055560084292665124, 0.07220977407996543, 0.041873634327203035, 0.027282717855996452, 0.002907345201492717, 0.05078349196992349, 0.0852635431510862, 0.025770035354071297, 0.017751832892827224, 0.02214327840192709, 0.0593156112881843, 0.05342564902093727, 0.05521416926058009, 0.04565890289086383, 0.02540078348829411, 0.006621925822400954, 0.016376824351027608, 0.022151866905915085, 0.04441544188011903, 0.04231033999531064, 0.09139442510786466, 0.03715733408171218, 0.06021063025400508, 0.038736334900022484, 0.05752171047788579, 0.041060348085011356, 0.03509021902573295, 0.04441215787664987, 0.020301251170167234, 0.06765767029719427, 0.08361293250345625, 0.04397255412186496, 0.017751727136783302, 0.03723000889294781, 0.05035497961216606, 0.03540435529430397, 0.047745284100528806, 0.034768627883750014, 0.0536792297498323, 0.01379565514071146, 0.0375793637795141, 0.031146494511631317, 0.05839328128786292, 0.029585410993604455, 0.052140679690637626, 0.01741697586112423, 0.0540052774886135, 0.04409782493894454, 0.020583903678925708, 0.03187676782545168, 0.023934626224217936, 0.0598975478351349, 0.032748527883086354, 0.024327953360625543, 0.01922529103467241, 0.025400228732905816, 0.06263580929953605, 0.008975674081739271, 0.013485652634699363, 0.04441313380084466, 0.06357970982207917, 0.042155639312113635, 0.01397402291331673, 0.020008561114082113, 0.028406166165950708, 0.0776054993912112, 0.028079196308681276, 0.011946455979341408, 0.02848165742761921, 0.03058631958992919, 0.017940514662768692, 0.020949945756001398, 0.038287691786536016, 0.013264996359794168, 0.03945886390283704, 0.02870806070859544, 0.01763738258887315, 0.06690344045637175, 0.042067746762768365, 0.060457613290054724, 0.09709622696391307, 0.05837060867634136, 0.03584907615731936, 0.020984932452847715, 0.02895100275054574, 0.008457535332127009, 0.02348001995414961, 0.036967039995943196, 0.05391865772253368, 0.059247678800602444, 0.019049233196710702, 0.029379734041867778, 0.02891479707614053, 0.014143102707748767, 0.03673553073895164, 0.04189618077361956, 0.05404335337516386, 0.03719169551914092, 0.03589324878703337, 0.012390039501042338, 0.009026561292557744, 0.06353987875627354, 0.030133518594084308, 0.06756994844181463, 0.05421441099315416, 0.05771550378995016, 0.08476465663989075, 0.008446157280559419, 0.019997248928120825, 0.030177307162375655, 0.02860060143575538, 0.019201243594579864, 0.035640050264191814, 0.019515622916514985, 0.021896083853789605, 0.012091893731849268, 0.021551894315052778, 0.03207660593034234, 0.06808631995227188, 0.039799691512598656, 0.027661751228151843, 0.0819291478546802, 0.04747460057842545, 0.038081437814980745, 0.03735031103133224, 0.043990681078867055, 0.030809789532213472, 0.010708649206208065, 0.050882442519650795, 0.06354338911478408, 0.03566743922419846, 0.027006395866919775, 0.01855056190834148, 0.07014226939645596, 0.02745520596363349, 0.016054774932854343, 0.04099601130292285, 0.02267052979732398, 0.07410910809994675, 0.041213916993001476, 0.018134610400011297, 0.028961530115338974, 0.06873660458950326, 0.06966037806705572, 0.03866343373374548, 0.027951415177085437, 0.011766910047299461, 0.06978195669944398, 0.04145138940657489, 0.011506119353725808, 0.03144783615425695, 0.03386278840480372, 0.0783144508022815, 0.05091436600196175, 0.037784582455060445, 0.07117975474102423, 0.03477307705907151, 0.03811588088865392, 0.025744234590092674, 0.08373076329007745, 0.03764508095628116, 0.025935435951396357, 0.029639407803188078, 0.03300615331681911, 0.0394348368718056, 0.004955281074217055, 0.04277883926988579, 0.040363805383094586, 0.09675240478827618, 0.008415688407694688, 0.028320201345195528, 0.14413763594347984, 0.01566518265462946, 0.029493961701518856, 0.038242821538005956, 0.05344960925867781, 0.026439124158059712, 0.11670726409647614, 0.014545619487762451, 0.06904492242028937, 0.07477598715922795, 0.026712510953075252, 0.007659468683414161, 0.03462664390099235, 0.019356797747605015, 0.016761742954258807, 0.08057127735810354, 0.09229440533090383, 0.023411605070577934, 0.03433157711697277, 0.028370333420753013, 0.03115570085356012, 0.04359087870398071, 0.05042709410190582, 0.07635801594005898, 0.015014336768217618, 0.061477246272261254, 0.041211608913727105, 0.024736375780776143, 0.02745506866631331, 0.07651588559383526, 0.04718633557786234, 0.03281728415458929, 0.04593424338963814, 0.04827138145628851, 0.03649452941317577, 0.05828466797538567, 0.08370346709853038, 0.08593757651397027, 0.02137644318281673, 0.029514953348552808, 0.028909455468237866, 0.09315447285189293, 0.019159429139108397, 0.004901110323771718, 0.03329366503749043, 0.06427392960176803, 0.03437894469243474, 0.03883691817463841, 0.03290211534476839, 0.04263893330062274, 0.03195970653905533, 0.07309742723009549, 0.03780131788516883, 0.04571363257127814, 0.044375748111633584, 0.0609908204205567, 0.02796404096443439, 0.025548381818225607, 0.045403344338410534, 0.018269859392603394, 0.06213293003384024, 0.04220671391522046, 0.013854429525963496, 0.015977649090928026, 0.04898876366496552, 0.015096973984327633, 0.036640094258473255, 0.025042244524229318, 0.03227224719012156, 0.008565445459680632, 0.09397458314197138, 0.06424885243177414, 0.04884325448074378, 0.035818581309285946, 0.06177306262543425, 0.07218723505502567, 0.03378844376129564, 0.05524587380932644, 0.031857126887189224, 0.030543993052560836, 0.025592190795578063, 0.02018587132624816, 0.03697470267070457, 0.011630097906163428, 0.07788640970829874, 0.07493194207199849, 0.03741198350326158, 0.05528881447389722, 0.0012411579177751264, 0.03489714188617654, 0.04288045041903388, 0.08413017974817194, 0.055142481505754404, 0.03970983969338704, 0.04188946433714591, 0.028741553833242506, 0.03283456506324001, 0.03826546817435883, 0.009037571053340798, 0.011673611879814416, 0.009429002002434572, 0.032776588486740366, 0.05076340945379343, 0.057327787289978005, 0.0373869916802505, 0.04161945245868992, 0.04242196642735507, 0.020897566828352865, 0.007827033568901243, 0.1291940620285459, 0.17537906969664618, 0.24696075677638873, 0.09029825072502717, 0.05020984150178265, 0.17922410712344572, 0.14861772913718596, 0.17149438674096018, 0.1735501061193645, 0.10063201145385392, 0.15551545744528994, 0.179682130983565, 0.05662547438987531, 0.12211159832077101, 0.13453798543196172, 0.12238329858519137, 0.113564120256342, 0.23947349603986368, 0.11583893647184595, 0.12568164034746587, 0.11321994927129708, 0.10757869924418628, 0.12877360568381846, 0.051326220855116844, 0.17386111052474007, 0.1826301048276946, 0.10011267135269009, 0.15272324555553496, 0.0825686936150305, 0.18010557076195255, 0.259102574782446, 0.14502098463708535, 0.11140195463667624, 0.16184177657123655, 0.10560362905380316, 0.1381583302281797, 0.12209833614178933, 0.09577209450071678, 0.26589773828163743, 0.15130764339119196, 0.22299520525848493, 0.09146878830506466, 0.13551432522945106, 0.12335793144302443, 0.1387774001341313, 0.1217363536125049, 0.15738396265078336, 0.10356232218327932, 0.11761629109969363, 0.17192607920151204, 0.20970469107851386, 0.1425552138243802, 0.1487158113741316, 0.1510615917504765, 0.08900510292733088, 0.15020917577203363, 0.09955539266229607, 0.13899008481530473, 0.059327504204702564, 0.061337759616435505, 0.18397172971162945, 0.09393573913257569, 0.15197106404229999, 0.2104040316771716, 0.22380968264769763, 0.08929388000979088, 0.1550851750653237, 0.31337803113274276, 0.11757320200558752, 0.1373994693858549, 0.11928249427000992, 0.11026492502423935, 0.13741996750468388, 0.19674539740663022, 0.0931917286652606, 0.18846032791770995, 0.18395140970824286, 0.15020552440546453, 0.23261052992893383, 0.13945443177362904, 0.21623248845571652, 0.1001518196426332, 0.1747619590605609, 0.16815147158922628, 0.085051296337042, 0.09197007195325568, 0.08975472403108142, 0.12000170216197148, 0.10647548930137418, 0.09850254486082122, 0.2115745618357323, 0.12341584864770994, 0.18351404723944142, 0.1285412095603533, 0.21346185822039843, 0.10299882429535501, 0.17279081483138725, 0.10922685338300653, 0.15256349084666, 0.1569448338705115, 0.1273841568036005, 0.14773957547731698, 0.24003435188205913, 0.2244555440847762, 0.18855550093576312, 0.15906149841612205, 0.09637506722356193, 0.08435317286057398, 0.22610599145991728, 0.1249914726940915, 0.14674575068056583, 0.15315039607230574, 0.12086722446838394, 0.08348270785063505, 0.15589312155498192, 0.08727779873879626, 0.11181150141055696, 0.20586652593920007, 0.11875762516865507, 0.14057605440029874, 0.09703462870675139, 0.1442217658041045, 0.0881091970950365, 0.15397133014630526, 0.07278314995346591, 0.12675903097260743, 0.08897797742974944, 0.13759882509475574, 0.1724063971778378, 0.12352516700048, 0.08687132445629686, 0.12090560092474334, 0.11520011801621877, 0.12470458808820695, 0.17119580588769168, 0.16004692210117355, 0.08427348846453242, 0.18929453159216791, 0.0927774395677261, 0.1417820740607567, 0.10747481341240928, 0.17965363251278177, 0.09433226121473126, 0.12269580955035053, 0.15966640814440325, 0.08435619340161793, 0.10893127822782844, 0.13400381722021848, 0.11372476554242894, 0.1317225888487883, 0.12052597754518501, 0.16345913900295272, 0.17954616952920333, 0.09047312298207544, 0.13911289541283622, 0.16467970475787297, 0.13234008540166542, 0.13727615412790328, 0.18742676853435114, 0.09665392921306193, 0.08931117205065675, 0.13385265658143908, 0.1619737601140514, 0.13465065829223022, 0.20900836359942332, 0.08576136839110404, 0.1632279303157702, 0.125684401136823, 0.137772680609487, 0.13150138431228697, 0.13334223709534854, 0.09654038804001175, 0.1318312541116029, 0.13844833185430616, 0.13557596801547334, 0.16660525143379346], [0.019195154272892978, 0.03550979221472517, 0.05024166479415726, 0.012092318611394148, 0.03866216466121841, 0.023744161444483325, 0.056442961722495966, 0.024259386336780153, 0.024263508967123926, 0.033733112941263244, 0.024935538531281054, 0.10694164710002951, 0.01705577815300785, 0.048736132885096595, 0.029584822841570713, 0.02890874857257586, 0.01983470003324328, 0.02029391318501439, 0.024001400961424224, 0.05766777627286501, 0.022022030025254935, 0.055717452996759675, 0.03213652322301641, 0.04353044190793298, 0.006840365858806763, 0.08539094022125937, 0.02782993487926433, 0.025315631319244858, 0.034529129407019354, 0.03552305068296846, 0.025344051864522044, 0.0364084514148999, 0.009546978435537312, 0.0623228530457709, 0.04727351195469964, 0.03791972383623943, 0.09562531253322959, 0.0539694243343547, 0.011836830562970135, 0.0445643092825776, 0.02656333370396169, 0.07211847507278435, 0.029687788410228677, 0.03270391367550474, 0.03390671241504606, 0.047613745846319944, 0.025455663453612942, 0.06237171604880132, 0.030540811094397213, 0.022674711799481884, 0.00913620804567472, 0.05905898033233825, 0.04458489274838939, 0.03201626932423096, 0.041169644173351116, 0.034709300598478876, 0.03754788929654751, 0.036674270158982836, 0.019451026382739656, 0.04925363617076073, 0.03526279433572199, 0.02174767472752137, 0.04443277473910712, 0.011772853722504806, 0.029676342637685593, 0.05025974351156037, 0.07188469855464064, 0.049100534815806895, 0.03541399579262361, 0.026072187793033663, 0.03619135095505044, 0.02603383360110456, 0.01951812952029286, 0.03907935555616859, 0.03988742450019345, 0.05999968219839502, 0.02259444667288335, 0.021977272954245564, 0.03704206370457541, 0.04378811558126472, 0.030996157656772994, 0.016984487447189167, 0.006827428369433619, 0.022689896140946075, 0.05233985728409607, 0.04946683293383103, 0.030386750513571315, 0.05642743228236213, 0.06281773938098922, 0.029382817665464245, 0.08338848478160799, 0.024850276895449497, 0.09187178933643736, 0.05597141593170818, 0.08770338332396932, 0.06720003977534361, 0.04104046965949237, 0.020675720334111247, 0.05115086991281714, 0.02768093574559316, 0.030638967546110507, 0.02624495235068025, 0.016304745113302488, 0.03214738826500252, 0.07551006026915275, 0.023551854283141438, 0.027693453921529, 0.03971206613641698, 0.04697899435996078, 0.03424316877499223, 0.025700080514070578, 0.04232635925291106, 0.0333919142576633, 0.06676310033071786, 0.008580916455684928, 0.02443698227580171, 0.03648092955700122, 0.058875406393781304, 0.021080962651467416, 0.08790742940618657, 0.014633164155384293, 0.045207992516225204, 0.0330640964966733, 0.06510647086543031, 0.02449929299473297, 0.037806041655130684, 0.026100307768501807, 0.060082884374423884, 0.031627176140318625, 0.02906510795583017, 0.060114581501693465, 0.0569982885645004, 0.06349940202198923, 0.02766933226666879, 0.05023359764891211, 0.05022218341764528, 0.01934811647515744, 0.006147701342342771, 0.03479564948065672, 0.02040308125287993, 0.021435494018078316, 0.015709423933003563, 0.03869201384077314, 0.015250216347340029, 0.0084875923130312, 0.06666853587375954, 0.04393681971123442, 0.06206817393831443, 0.03393869526917115, 0.046309747849591076, 0.03291527733381372, 0.05427419840998482, 0.025830101076280698, 0.06181681965244934, 0.023962820414453745, 0.050687480324995704, 0.00797296763266786, 0.05800563900265843, 0.10263182484777644, 0.04818485445866827, 0.03804515421506949, 0.02755591725872364, 0.04846058087423444, 0.031925972216413356, 0.03529173067363445, 0.028154040046501905, 0.003538752152962843, 0.04904474386421498, 0.008676699890202144, 0.07147256910684519, 0.0728404957044404, 0.07523315754951909, 0.04627015798178036, 0.02048052250756882, 0.07312516871024854, 0.03082596649619518, 0.027139518606418278, 0.05578058749961201, 0.08154523486155085, 0.07574408169602975, 0.02495156521035824, 0.05343599084881134, 0.03700507506437134, 0.02733812103542732, 0.008678625763423042, 0.023852056729083415, 0.026051724926219322, 0.03937915724236518, 0.034125126476283185, 0.03197545862349216, 0.018338953341299202, 0.01472223022574326, 0.09812528151087463, 0.05850189088960178, 0.029150505033612717, 0.038679026256431825, 0.01387222066114191, 0.025767541737877764, 0.05997392967401538, 0.05317206829204224, 0.028322283069428522, 0.05102336152049247, 0.0398270804726053, 0.039326475889538415, 0.04323514876887202, 0.0281250925763743, 0.03151554970827419, 0.012015687225357397, 0.06503452706965618, 0.028546947869472206, 0.02611834010167513, 0.020216447810526006, 0.04205165329040028, 0.09828507332713343, 0.03967751545133069, 0.04944496555253863, 0.04749292420456186, 0.04548947428702377, 0.012214815651532263, 0.015235611808748217, 0.06903221685206518, 0.026085952777066268, 0.020724601890833583, 0.05377952729759272, 0.01697161489573773, 0.012650326461880468, 0.03208960093616042, 0.09186902112560347, 0.020044529301230796, 0.03677067514217924, 0.019081288410234265, 0.04247624339768663, 0.04165299753367435, 0.036031833733431995, 0.018866798454837408, 0.05569076907704584, 0.06253394210943952, 0.05462842920678668, 0.01824934828619007, 0.009309625693276757, 0.018994946949533187, 0.016755954202380963, 0.0389575171720935, 0.02132879544660682, 0.0532628181099426, 0.09311511676060036, 0.03828602937574033, 0.07157581669162028, 0.0673963526787702, 0.034267837763763964, 0.054392678575823084, 0.015991384389053565, 0.04488002632569987, 0.0347704461455578, 0.02409965203696629, 0.05119307585118804, 0.052277424110798165, 0.05277264441247098, 0.012978379854757804, 0.016964839087449946, 0.06207818922121078, 0.1356934499926865, 0.030021940401638858, 0.05804055334010627, 0.060652230386040173, 0.045177308420534246, 0.06018980930093676, 0.022277373354882002, 0.013221408171375515, 0.0512193775648484, 0.024313006506417878, 0.0391620382288238, 0.06140204444818664, 0.021314817095117178, 0.04452047804079484, 0.03578545554773882, 0.03601632284699008, 0.04613631535903551, 0.07838695120881312, 0.026940443058265373, 0.07104611620889045, 0.07199556799605489, 0.07428373544826172, 0.0336379325017333, 0.022359339855029248, 0.03708144948177505, 0.019125564940623008, 0.04879890002484899, 0.08676411380292848, 0.04790034472534899, 0.05283473990857601, 0.0059233449974271934, 0.06452764020650648, 0.04257647044141777, 0.02061564719042508, 0.05638652139168698, 0.010391584237368079, 0.035315245622769, 0.03056450601434335, 0.011532973967405269, 0.037215214179013856, 0.021486238365469035, 0.048255655347020365, 0.09332213143352419, 0.01921382670843741, 0.0032193123115575872, 0.12403885935782455, 0.04042544445837848, 0.03301592369098216, 0.023251909733517095, 0.04421128076501191, 0.05281477242533583, 0.012147766319685616, 0.02478907012118725, 0.04749137682665605, 0.0289255600728211, 0.08964098247815855, 0.03474978846497834, 0.041340586758451536, 0.021978467812004965, 0.004601059554261155, 0.010938345767499413, 0.0809522217605263, 0.07763681060168892, 0.06681181490421295, 0.027913691810681485, 0.05642780335620046, 0.015794550126884133, 0.028611173329409212, 0.048538005430600606, 0.027576489592320286, 0.030044453451409936, 0.016701586318959016, 0.023126349478843622, 0.04960700236551929, 0.05536089185625315, 0.02849391214112984, 0.04958553574397229, 0.04257257416611537, 0.018573876477603335, 0.018550582317402586, 0.02679875964531675, 0.029762403937638737, 0.04738308263767976, 0.03990569988673087, 0.04392058894154616, 0.05920867894019466, 0.02042559801338939, 0.02585910235211486, 0.06287576790782623, 0.023425902545568533, 0.00705812683008844, 0.19056560791796073, 0.21656611352227628, 0.17179731657961383, 0.14919546141754836, 0.15021877916296944, 0.12122657237341627, 0.20178417937131599, 0.1402245881035924, 0.08791910338914022, 0.21643801883328706, 0.15648578584659845, 0.181789088237565, 0.12172059781732969, 0.07340437950915657, 0.13518126419512555, 0.09833347619860433, 0.1992437633452937, 0.14545414655003697, 0.1375062347506173, 0.13932250760262832, 0.10179287142818794, 0.10996483018971048, 0.13259335071779788, 0.19449321669526398, 0.11117687608930282, 0.19790835765888914, 0.18985394766787067, 0.1047309821296949, 0.10598110762657598, 0.17660955054452643, 0.14667643408756703, 0.1330146679538302, 0.11577862955164164, 0.18795047246385366, 0.1585196118685417, 0.11835797122330405, 0.1881448706262745, 0.12942406843649223, 0.1463815342867747, 0.20838237687712535, 0.14296464185463265, 0.1416576307383366, 0.1357232843292877, 0.10429558635223657, 0.10360396408941597, 0.12593913590535522, 0.09587514912709594, 0.22432405035942793, 0.11072765410062857, 0.12241747448570095, 0.15602452622260898, 0.1352821962791495, 0.07353524240897968, 0.08999772544484586, 0.1256770538748242, 0.10093105243868195, 0.08911425800761208, 0.16195677977520972, 0.16209507157327607, 0.1726949738804251, 0.1504271593876183, 0.13851218624040484, 0.1334275840781629, 0.10959023114992306, 0.13241826323792338, 0.15161587216425687, 0.15633984992746264, 0.13775617524515837, 0.14571539737517014, 0.17961648060008883, 0.09528583934297785, 0.154950104188174, 0.13593773532193154, 0.0948763667838648, 0.11698122791131027, 0.0989059689163696, 0.13148118305252865, 0.07397373294224963, 0.12083237321348861, 0.17023070220602676, 0.11345092047122307, 0.14856484369374812, 0.09446984055102803, 0.06411341790226288, 0.16559080977458507, 0.14840906689641997, 0.11390931540518068, 0.11913194961380213, 0.24167921830667183, 0.11264199434663169, 0.14907229458913207, 0.13945006794529036, 0.2413452073233202, 0.10412883319077082, 0.30783846275880933, 0.20575556001858786, 0.161574944795575, 0.11755321596865542, 0.14285214710980654, 0.09545495253405534, 0.1014274824410677, 0.21188200393225998, 0.17102867423091084, 0.13867894682334736, 0.15447797952219844, 0.15374472277471796, 0.2148894386482425, 0.15184231626335531, 0.13444845273625106, 0.09974673317628913, 0.17201617592945695, 0.12890548532595858, 0.21626417816150934, 0.14466102817095816, 0.12100731226382777, 0.1375502737937495, 0.17461200070101768, 0.17149680614238605, 0.09573569957865402, 0.13772271922789514, 0.10075875543407165, 0.1091263369016815, 0.10802406206494197, 0.23679777164943516, 0.16171445371583104, 0.08190787048079073, 0.3079552174312994, 0.12127513109589927, 0.06970177506445907, 0.11617437237873673, 0.34628557157702744, 0.17093280359404162, 0.16813450609333813, 0.10054474230855703, 0.15842247958062217, 0.12861113471444696, 0.13684894423931837, 0.1665290625533089, 0.08490360894938931, 0.16166204324690625, 0.13669601728906855, 0.18848182051442564, 0.11004203581251204, 0.13475632527843118, 0.13305471424246207, 0.15396191971376538, 0.25384154927451164, 0.1318800132139586, 0.13374703412409872, 0.09641733995522372, 0.2702116349246353, 0.21838830871274695, 0.08920246968045831, 0.16874781693331897, 0.09767464944161475, 0.18393600272247568, 0.11196676612598822, 0.1903772508376278, 0.20618452137568966, 0.18423363362671807, 0.08294176383060403, 0.20233137969626114, 0.13504920643754303, 0.17581168242031708, 0.09619019081583247, 0.18100555840646848, 0.18690218887059018, 0.08086969493888319, 0.13099810428684577, 0.13198418106185272, 0.2528840897139162, 0.15931497153360397, 0.13437123969197273, 0.1216745623969473, 0.1087991833628621, 0.09075692025362514], [0.06684661420877092, 0.018980649474542588, 0.04180858508334495, 0.03977931584813632, 0.010800926920637721, 0.08508825529133901, 0.044956708734389395, 0.026868953827943187, 0.0690298642439302, 0.013739674941461999, 0.021041003565187566, 0.023237050081661437, 0.004756593762067496, 0.008124232172121992, 0.01631111830647569, 0.02321807151020039, 0.05560904377489351, 0.04088342378963716, 0.023589306765643414, 0.029255160843604244, 0.039811016686144285, 0.011994594460702501, 0.048533585941186175, 0.026241534760629293, 0.025717509852256626, 0.02112659360136604, 0.06544138726894744, 0.045947880353196524, 0.02622699052153621, 0.0613305014121579, 0.05286285246256739, 0.02870396219805116, 0.0870756377116777, 0.02221232596639311, 0.020773476026079152, 0.03482986619928852, 0.049499639571877196, 0.0606611435796367, 0.00948280956436065, 0.03464142748271115, 0.055274613478104584, 0.013513671492546564, 0.043726016374421306, 0.03179588857165072, 0.039609638624824584, 0.08618031817604788, 0.04237392349750735, 0.03411583849810995, 0.04769453233166132, 0.02281025950651383, 0.035997969534946606, 0.041113433908321895, 0.03119277855148539, 0.010352880308346357, 0.02833911683410406, 0.028344079946691636, 0.010475708531885175, 0.0533477383578429, 0.06091707320592832, 0.06946064386283979, 0.03589719330193475, 0.009711849324958166, 0.08457275209366344, 0.02197948269895278, 0.03667614779260475, 0.028938488285348285, 0.08089619703241624, 0.04546890195342712, 0.03033527700608829, 0.034978462717845105, 0.008275288910226664, 0.11681072690407746, 0.04271509991667699, 0.041957144494517706, 0.06300530978478491, 0.009576941720297327, 0.01997641498746816, 0.01137276747613214, 0.012459457211662084, 0.019168564977007918, 0.012873547784693073, 0.05147398616827559, 0.03344030599691905, 0.034998385672224686, 0.06554963692906313, 0.051563975284807384, 0.07591959220007993, 0.03805020453000907, 0.052552189445123076, 0.05276373864035122, 0.07722806534729898, 0.07099625130649656, 0.009676133468019543, 0.03361930088431109, 0.0709476851625368, 0.09011426489450969, 0.03154690544761252, 0.08881807429133914, 0.03747082097106613, 0.05990521050989628, 0.09771769400686026, 0.09750199620611966, 0.03268746397225186, 0.013489736302290112, 0.024851666566974018, 0.07075405141222291, 0.05040371273935307, 0.03678195207612589, 0.01620986524358159, 0.06053537923435215, 0.01675475748925237, 0.04631674259144347, 0.03506433291477151, 0.08960400868090801, 0.0161415412731003, 0.0550229474902153, 0.028504875517683104, 0.05563734928728081, 0.01819659271859564, 0.03500940656522289, 0.08187226965674199, 0.056309508727281354, 0.0683818876859732, 0.020201176266709808, 0.03620329953264445, 0.020406997937243432, 0.0603284350654576, 0.03972109807364177, 0.04553356899123173, 0.05865986073331442, 0.031203009057207964, 0.06800986389862373, 0.02467667556629749, 0.024173894635168836, 0.054238938973867334, 0.010047796386061236, 0.03130468699964695, 0.05635950721625704, 0.06549819125211798, 0.042170500819338486, 0.04657785982999485, 0.061579150569741614, 0.06633402765146457, 0.028333543305052444, 0.010066751765407389, 0.11305739666568115, 0.03129575896309689, 0.007850408437661827, 0.04372228337160777, 0.03296498267445713, 0.08698478399310261, 0.006994933883106569, 0.02519560748623917, 0.030449705045612063, 0.015612126517225988, 0.13349241809919477, 0.013003917156311218, 0.008048407871683594, 0.032429960992885754, 0.028127109362685587, 0.027337263854860794, 0.04795661065145396, 0.015729552833363414, 0.04201944037049543, 0.04813801009731833, 0.05440883513074368, 0.029382849206740502, 0.06929782408406027, 0.014571005576726748, 0.006398514324246207, 0.020832771770074032, 0.05256227152131032, 0.07773001692839898, 0.043551389026106335, 0.04874901656876318, 0.016047654025896918, 0.03414316437556408, 0.021473395499924663, 0.006760654096069629, 0.011505546972330194, 0.03391326928976923, 0.06796245550503954, 0.054021979522076435, 0.014657729243481299, 0.04958100493240636, 0.05960025831882376, 0.06371166367898695, 0.015246934199240059, 0.0850428878038656, 0.024531509625376202, 0.019838043408526573, 0.05705597570340615, 0.021796151813759934, 0.017721800031722523, 0.01850364889833145, 0.026194671845587436, 0.03172860175254755, 0.04060609433508944, 0.09694809428765438, 0.02911999534262577, 0.09280083206249401, 0.06120628815551754, 0.033422995402361266, 0.0014328819133879733, 0.031046287876961287, 0.1122251819469966, 0.04517698929703329, 0.049370212727808394, 0.09538032216369174, 0.06175067203002982, 0.01171045394585235, 0.03147021932818461, 0.052898308567819186, 0.04275694220268633, 0.06997617674642242, 0.026016856973001268, 0.038424024314736016, 0.008822176605463028, 0.0355940853478387, 0.008542883242625976, 0.005293107160468935, 0.02134925831342116, 0.060507029193104245, 0.0673170987283811, 0.03297646369901486, 0.02902941807406023, 0.01703677360637812, 0.027535311528481543, 0.035058206485700794, 0.022213166448636912, 0.009180851939163404, 0.0241768019986921, 0.017270056596316863, 0.033439942344557494, 0.03653533640317619, 0.03874871392326895, 0.0427257868432207, 0.06844847317552194, 0.05036578528233804, 0.06949895352590829, 0.020461764725041576, 0.02616362224216573, 0.03536311043717433, 0.10663845008821227, 0.050385589493089356, 0.020603693046723492, 0.10327753785531968, 0.03191589014022611, 0.070005395100452, 0.03255398500186857, 0.012719298883894226, 0.05099870737467427, 0.05700157998944633, 0.0372675467224326, 0.016312626721628476, 0.04548439428617712, 0.03273708396591246, 0.06270653597312048, 0.010129943784704665, 0.04944920692651067, 0.07808898633811623, 0.02266250718093943, 0.008431440492131514, 0.08660983614390716, 0.04603692694217898, 0.021016744613007177, 0.07613567591761239, 0.06780327224987559, 0.04077559715369716, 0.052807295287493616, 0.10385493616922759, 0.012084415666322457, 0.027745289226004388, 0.0629697905969806, 0.030505551658279728, 0.07193684185040183, 0.03562705525837373, 0.03178541315719485, 0.04256324908055831, 0.01748413465975318, 0.007596207551614498, 0.04365093700471334, 0.059114526375196874, 0.04200033006782178, 0.045403908370644785, 0.06474458481534384, 0.017297234044235665, 0.05409791978308931, 0.04724175545561593, 0.07303986625629477, 0.07609144391608424, 0.04631758863979485, 0.02850889981345972, 0.029051951532892417, 0.030698111149831675, 0.02708310425077798, 0.02485644228727324, 0.02850699620466912, 0.051702007331186906, 0.03214600044884719, 0.06318864252534695, 0.008876659521774855, 0.023719696546322666, 0.029624579692608677, 0.02098311233567074, 0.07155924453400075, 0.03777246689423919, 0.01897905571240699, 0.03585414131521247, 0.017700736025290098, 0.061913922254461795, 0.044653107252088375, 0.07644780838745646, 0.05914100620429963, 0.028840964514529333, 0.04949570618919097, 0.06392142429831438, 0.017659244404057972, 0.10478276177309453, 0.016012630221666768, 0.06445476130465977, 0.06188462226418778, 0.0953583768568933, 0.09497389241005294, 0.024343903969565872, 0.029304495110409334, 0.07438950633513741, 0.01020071591483429, 0.0158522112906212, 0.05864650207513478, 0.046088253875495866, 0.12039311084663495, 0.08947130525484681, 0.043222320746281184, 0.029705201050092, 0.009078460607270245, 0.06538173343869857, 0.0791041181946639, 0.027308229182381183, 0.07314772257814184, 0.0048791320841701236, 0.07119489455362782, 0.020141303502896335, 0.028463092603487894, 0.055992355628404766, 0.02232144765002886, 0.06344906956655905, 0.029243533244880382, 0.06908769239089452, 0.018765231834549922, 0.0664727424737066, 0.025058158025785815, 0.13407245103735477, 0.14855152956442907, 0.11553294898476452, 0.09275600634282455, 0.09095487330341712, 0.17323515348834917, 0.11508703697472811, 0.09162886955891736, 0.15758281369926408, 0.13632041634991765, 0.1991661940701306, 0.07149497454520315, 0.13238062150776386, 0.054006394420866854, 0.11148303427034989, 0.13206976553192362, 0.1452102026087232, 0.13871785020455718, 0.15794331935467198, 0.07634810826857574, 0.09893683483824134, 0.12969615461770445, 0.19257755542639643, 0.09799795123399235, 0.1523650554008782, 0.16392688499763608, 0.12478448770707473, 0.10885571275139228, 0.12303137904382311, 0.20021133095724508, 0.1492400496499613, 0.19162198092089966, 0.3004185593454167, 0.19871554715791717, 0.09346486127469689, 0.10305186558980495, 0.06675529293715954, 0.12161637801909819, 0.19196368055418134, 0.12045716561260633, 0.09406946672243066, 0.09617189687560312, 0.15385577775305137, 0.12992415722692385, 0.12153152085375041, 0.15105569909792393, 0.14665752416476607, 0.16396268620155752, 0.26285472500603646, 0.11827965980046429, 0.11722587689291686, 0.15272711956640705, 0.14602497685700655, 0.06073606709833257, 0.10106469097081572, 0.09852472023339942, 0.052048323123017326, 0.1264214131515473, 0.13180085574276745, 0.07434367129462771, 0.1376873633125797, 0.12366998227662407, 0.15061190963024274, 0.1752449487685226, 0.16695273981895298, 0.09065874895895831, 0.15561771055217832, 0.2527389850001782, 0.14921349560609087, 0.12969753501238301, 0.1984678627923131, 0.28385895886458457, 0.16533736634301022, 0.08694306045072153, 0.1254276031977497, 0.18746706715319306, 0.1627849423675798, 0.2257992618251592, 0.15426260826643556, 0.14596711902413517, 0.10022548522101715, 0.1934574605547823, 0.10019408495281823, 0.13633934111567214, 0.175534920708742, 0.12808012805180624, 0.13132019637851045, 0.18714040343184024, 0.19246397714596242, 0.09799304563784972, 0.1741226136800833, 0.24951744067948312, 0.10503462443011813, 0.08829458558466285, 0.220662709325552, 0.15281208063242957, 0.10778301249956712, 0.21486039098817855, 0.17303245811490342, 0.13290425122249871, 0.23201406584121287, 0.11088861851021647, 0.10974167380481958, 0.0836172369599808, 0.08440657038590871, 0.13120410963892937, 0.16137195256305858, 0.07344420315348543, 0.1267355345771648, 0.2318919380195439, 0.07581894955364987, 0.158367189578712, 0.2351486452971585, 0.25212665379513055, 0.18127409712178633, 0.12902207672595978, 0.10073345561977476, 0.08960928535088897, 0.08000987974810414, 0.1223288917390164, 0.30180518806446344, 0.10425586660858244, 0.22530898422701284, 0.08397076642722823, 0.20767867245012894, 0.0955095374956727, 0.1366152270929888, 0.09584395666024648, 0.09534142620395869, 0.20877794158877805, 0.12853393651312217, 0.14137853868305683, 0.11913744150660932, 0.2103999795508571, 0.1816842524567619, 0.14111914322711527, 0.19326666923006997, 0.23194678273284808, 0.12343791269813664, 0.1461138713057153, 0.19118170923320577, 0.16678980871802196, 0.2648392575792968, 0.14619898080127314, 0.1714796180021949, 0.2404060639673844, 0.17075667710741982, 0.17366332816891372, 0.14252279681386426, 0.12909548997413367, 0.16118822648422793, 0.11615617491770536, 0.0917609421594534, 0.1207507740764413, 0.0902476510964334, 0.40302896581124514, 0.20256518590031192, 0.11116546927951276, 0.17527536198031157, 0.14316840592073277, 0.16095287661300972, 0.17498178320238367, 0.1318675302900374, 0.11414268374210224, 0.09537558726151474, 0.11653653302346356, 0.15516690036747605, 0.15809961565537378, 0.0944201166566927, 0.12675778416451067, 0.16705989110050723, 0.14481861580861732, 0.1885639614192769, 0.14882015733746812, 0.16814176429761574, 0.10849942249478772], [0.029820202398695983, 0.0531765916821314, 0.015807521012902725, 0.04510612161539029, 0.020641499904741067, 0.021668511690222658, 0.05182666216569487, 0.017503521412436385, 0.06995141869992949, 0.02499474892829312, 0.05204519497056026, 0.04032467935758177, 0.02593236531538423, 0.06377021170919761, 0.022349560204020236, 0.04134541442908812, 0.01853950019722106, 0.03253818838857114, 0.051877469595638104, 0.055597759419470094, 0.04922338623146061, 0.04285502072889358, 0.013225894454080844, 0.02101457939716056, 0.014692626882606419, 0.04581530680297874, 0.015720439259894192, 0.002033818368545326, 0.051777390981442295, 0.04045653673529159, 0.053857278398936614, 0.02850699620466912, 0.011051229212171165, 0.04416696712723933, 0.05886032224225346, 0.02559288841439411, 0.03998355117801111, 0.09005999905639328, 0.015638621189282276, 0.014028452023922, 0.021888775554543827, 0.036022998465341516, 0.02025759433308849, 0.030193818092811853, 0.008171638710336993, 0.024310618646268267, 0.10194238449912518, 0.04991839268768672, 0.017721449366945308, 0.01254900382264168, 0.11557253514183685, 0.01658265529840719, 0.06461073848186061, 0.06722971826093271, 0.01453504295568564, 0.018548205589468125, 0.031207855281536467, 0.03353907843120396, 0.00715969020347984, 0.010709626985772047, 0.01018124659822206, 0.018482230516383424, 0.05602674304100219, 0.05474267542012967, 0.02727426850469783, 0.06470693566370755, 0.017110496701207012, 0.06273352046264336, 0.05645161887514405, 0.045936647948110476, 0.0654105213470757, 0.06252810882870108, 0.05679827605490573, 0.028759844062733464, 0.05099884838273283, 0.022367301244230475, 0.02082910741592059, 0.01990640077565331, 0.07823619875125587, 0.018300489682587795, 0.050115874473704025, 0.020294950336392503, 0.08344871748704463, 0.03257160358771216, 0.033200406760443, 0.04514960033702664, 0.039756895566824824, 0.025478265561105218, 0.027663541659421753, 0.03682911556097679, 0.018595864457893185, 0.03768360213143751, 0.07490604853956029, 0.03447309725743253, 0.07738312226138078, 0.045922565695946105, 0.019560491309675854, 0.02741792231972795, 0.03680133326270152, 0.07314606758882292, 0.04311184093239717, 0.010695768305595266, 0.028539290760818403, 0.02205290707934182, 0.03659861191408709, 0.05276693729683757, 0.05191760494199116, 0.06522234238218516, 0.07180853193858638, 0.01852238998253597, 0.0826142837468069, 0.008987759956653463, 0.03243244718760252, 0.009165195406239945, 0.010596423489914741, 0.03790486603975296, 0.022148916868900415, 0.019461880292510614, 0.0256745135266101, 0.02337771304155467, 0.02180763469368685, 0.03733413221198134, 0.03151755721773952, 0.020817336953768972, 0.026094270397152286, 0.04553982158540748, 0.01866667462309124, 0.07064798366627656, 0.034573250086396, 0.0185726890413207, 0.05636137742840219, 0.05358938164135907, 0.03205929162504617, 0.016718635306460783, 0.027534959008335136, 0.03958713299653027, 0.017237420652236324, 0.02066476437903475, 0.01219664602103876, 0.008501848042214988, 0.03276068797276821, 0.020211755581840407, 0.05059391405666247, 0.04356091820227448, 0.07096732981153764, 0.01929634796397295, 0.0723233820463065, 0.042085695604328066, 0.01602228185220156, 0.05430350953247398, 0.019941162972827442, 0.02342105446587084, 0.054841703895363025, 0.05945280099695083, 0.045392238098429516, 0.015368485928775044, 0.06604859023354948, 0.023220765506266616, 0.01802782091544941, 0.04906180583930109, 0.059967072229483165, 0.07075238157995045, 0.03803696461545769, 0.045473518111975864, 0.04670756126870401, 0.04504376636759844, 0.03248548848205246, 0.022598801224376075, 0.034617311393958516, 0.022018347117409576, 0.06759637632058002, 0.04718118507298641, 0.07188974515884183, 0.08267245328170247, 0.019108144879282918, 0.03508751389745157, 0.01842469922848977, 0.0339263347996166, 0.08588903263444081, 0.02480060124071315, 0.007166932173277019, 0.02013069264648948, 0.04867374424065929, 0.07133465580409393, 0.03994446225988213, 0.0802359230874572, 0.04287036834284663, 0.03250689202104695, 0.08202662895200774, 0.06331827346002683, 0.04139433309319429, 0.1052912516752258, 0.028959179362573195, 0.011387390568415867, 0.06105077853135299, 0.04309876429033466, 0.02648518555361079, 0.11077511444455013, 0.04108438624825794, 0.016394216581829824, 0.09734096500324085, 0.0003242068646613916, 0.010286547149007674, 0.03755307319806889, 0.01603475735464599, 0.04517788358498365, 0.07066114936606027, 0.012799055639334256, 0.016632143560855184, 0.0333156919805333, 0.021635768134729005, 0.026595413037284743, 0.06740200042258948, 0.07446463394444436, 0.012358517706161365, 0.018217209581052884, 0.04166625971265603, 0.06493208842584863, 0.008279348458017921, 0.028266332556086127, 0.029103130036673974, 0.029298402077984065, 0.044478617201093584, 0.05252113798633218, 0.05052203334344085, 0.018215671479993034, 0.03945511605706997, 0.013799133030261146, 0.013176194679545006, 0.061728808359475806, 0.049852987212943844, 0.0323730493983021, 0.019010979194717947, 0.019347903107700404, 0.035799749311991036, 0.013458719167829258, 0.033687611867208034, 0.035505543419276364, 0.04850563665968366, 0.08060140113229863, 0.04857418512983713, 0.014461956252489472, 0.023942474435898475, 0.07811797462636605, 0.06210599378391635, 0.04519097878073808, 0.11910198169061914, 0.03416785562876612, 0.0040151961184164975, 0.01739920327963773, 0.009181147870549466, 0.05156617204193026, 0.060148916963953525, 0.06724387101712637, 0.047631212291889824, 0.03415879029489588, 0.06650492941844277, 0.08415654083364643, 0.04457479211851023, 0.03420324494072702, 0.04061370505951345, 0.06484591765911318, 0.033742501109372824, 0.02061685318039963, 0.10125908171175979, 0.07043989287922159, 0.020654224026657175, 0.04644080370781012, 0.022712826648785267, 0.02016810431086924, 0.03431818506214768, 0.06599397558602504, 0.019611000025179237, 0.05728318792534992, 0.0671656486520078, 0.030747007549507543, 0.008890966273611411, 0.012288658417674014, 0.015356738658738323, 0.03490062998025678, 0.02016292968619382, 0.003129426631858223, 0.035569887622841634, 0.06065925110306125, 0.019081566715613008, 0.05461562715936452, 0.019846639333991334, 0.027462647849461064, 0.03784657776122913, 0.0400391937000677, 0.03374394087586552, 0.03334688073664438, 0.02710672495595645, 0.01031153062285739, 0.025860877940431237, 0.04888183502771426, 0.08247765435953625, 0.0343899321887875, 0.03074609841860365, 0.0012964527900294343, 0.014687512557429727, 0.048291000130120665, 0.1078456052346155, 0.06083242755266838, 0.05711037512810435, 0.0448759927530773, 0.041382232375326566, 0.0274012017325731, 0.031026557880977634, 0.031491912304772995, 0.03623294091084972, 0.030167325276124757, 0.05520290716958698, 0.03854066766507458, 0.019889424147550017, 0.03637704372522421, 0.03282929210399743, 0.006453591886383947, 0.06848560282378457, 0.0291152307545417, 0.07604739745147526, 0.021792227707919665, 0.06376584045938216, 0.039655403161305, 0.04223965785058681, 0.05465583300974686, 0.03130101707938593, 0.07071561558404937, 0.014653041653218679, 0.06521617513499223, 0.034271144031663425, 0.012551059571705991, 0.08450805908069015, 0.06356470359605737, 0.04216322035063058, 0.0873100376338698, 0.010388518239778932, 0.005847735455972725, 0.009025388699228643, 0.027743778955482412, 0.040338349717785604, 0.03226206492399797, 0.05995828891173005, 0.04200425602903124, 0.0565378119063098, 0.019803288632829208, 0.11147481127409264, 0.02031781961704837, 0.01745048753946321, 0.03765461013244931, 0.05504005399416201, 0.016209765053645242, 0.17338339006528258, 0.13110549305565655, 0.16091716446680948, 0.12624818104086444, 0.13306700420798734, 0.16343335679266602, 0.14672810240881518, 0.1504310333984904, 0.13669404317624867, 0.20567092549754307, 0.12996132398257032, 0.18705269641941413, 0.13307914574397728, 0.11888756780535914, 0.10259712202241644, 0.24122336151776835, 0.11186027535586618, 0.14292723761172965, 0.1272934812004678, 0.1474435772979632, 0.13207168027292937, 0.22059698472730815, 0.07622409539180808, 0.0815680855885148, 0.20978414540877566, 0.12448468973161653, 0.1262436984688975, 0.08742970894672908, 0.15714781126007438, 0.1581958870519884, 0.12988338363356888, 0.1450213705538772, 0.15338806144427508, 0.21697693679016083, 0.07687033532420173, 0.09171329627861269, 0.20798176556127146, 0.10708873334806412, 0.1168699206027668, 0.12807230581529438, 0.10734695621067658, 0.11018170058378018, 0.11873257768456824, 0.0824050500523299, 0.08795746500254609, 0.08055071986746043, 0.1971118402434513, 0.1638767306576483, 0.11342231809976511, 0.14752954768482596, 0.2664432761957869, 0.093283621390583, 0.12068970274413005, 0.15045120497234166, 0.09943191413185559, 0.10714928517700173, 0.1257288409397006, 0.07624376230523922, 0.08162413258105516, 0.11733964071027003, 0.0936439711949788, 0.10007313714595512, 0.13689051935216412, 0.1720603634021245, 0.11240970212384127, 0.13575611694250256, 0.12114546305383556, 0.11908281943760812, 0.20095635816687718, 0.24571397836552933, 0.13887324108509347, 0.10143546052859165, 0.16355649393517524, 0.10771486849989742, 0.22086252516601235, 0.2162886838777922, 0.16253897978458554, 0.09382094372995198, 0.25588153512217104, 0.11062744932132773, 0.12801496748579666, 0.24053240718785673, 0.13115030393237248, 0.18739832943538204, 0.10146030021132901, 0.19169904553564265, 0.19520181929692626, 0.13131470448570326, 0.1378831863985397, 0.20610766456229612, 0.08311449128086679, 0.12046881733112969, 0.17028838192345574, 0.10358587052905932, 0.22022876073606312, 0.1773783561657183, 0.13687272265087813, 0.13964219513582066, 0.12157121833297424, 0.12492234905948862, 0.12596034648595378, 0.09482040884904563, 0.11855719334562309, 0.1190574157226365, 0.17513681785203516, 0.15455686982022598, 0.10157871729461476, 0.12294673710130155, 0.17239272681763396, 0.14066659641684964, 0.15135157853364944, 0.10920226603047922, 0.231300238519907, 0.07302088211872615, 0.16367177915526554, 0.18007275299169123, 0.13805339054670185, 0.12736120959743857, 0.10439559075166471, 0.25328238552901894, 0.14098238025326282, 0.14372439327416942, 0.09950256659067236, 0.07110892416676506, 0.16873901506187394, 0.1144314905104693, 0.21219128655502573, 0.20785695116501302, 0.1516449495102279, 0.11308494518743828, 0.12762591883074492, 0.11598306897212751, 0.09080591684323736, 0.0914375513093546, 0.1208552165189758, 0.08224263845477253, 0.18173301155911759, 0.09261725441319868, 0.0738323167024646, 0.10322428875952028, 0.15877103665843606, 0.07217958351247944, 0.11403407042962499, 0.11739229608792812, 0.15571853873552755, 0.10668738730601035, 0.11472496538772248, 0.17877234698971733, 0.11230575692025013, 0.11585620624828152, 0.15437727008247748, 0.14062120666494593, 0.1124583202181384, 0.13208027434302494, 0.2650346205336973, 0.11761789413867518, 0.15612499817507342, 0.21328890812583268, 0.1237964590836782, 0.21404263330623507, 0.15686462254961953, 0.12894228100776672, 0.12181956321001053, 0.1533122139517218, 0.11398759714211337, 0.11762471447582357, 0.09540056795231067, 0.13180545705836266, 0.1294104871340096, 0.08207175895222463, 0.18288062419742346, 0.09848661837168038, 0.10562890660366975, 0.14713784214109182, 0.10752870817668736, 0.16339572990546003], [0.02547124298871495, 0.030128260477795266, 0.013499096639861818, 0.054354580424842425, 0.02474976412486285, 0.027540089104149956, 0.05530491907848045, 0.04320111758715939, 0.03256660893384833, 0.026066853606607765, 0.053588446535286494, 0.07147286596591584, 0.030086568476690445, 0.03307904706161935, 0.04798476031282917, 0.03510306189127732, 0.018654983941814862, 0.004719162616311223, 0.01628349371458171, 0.030602361111959908, 0.04676931908761617, 0.055688349675619975, 0.07430520578054711, 0.02081262988212984, 0.021117339019838255, 0.055731349712004885, 0.061204618323245086, 0.0253689601959195, 0.002254123514831008, 0.04605191832524724, 0.06801030918722972, 0.02067369241558481, 0.0495590856007766, 0.03509188514726702, 0.027824927237816155, 0.0670246480149217, 0.05950664752162993, 0.03151003926177509, 0.047000872873468325, 0.005650496259477222, 0.013224016820458928, 0.02444124962494243, 0.010785581162053859, 0.04611147567629814, 0.060903803605469875, 0.09349802043288946, 0.02727424624026753, 0.032036619013524614, 0.05439225926238578, 0.0666114647174254, 0.0477338661585236, 0.04663560634071473, 0.1039570260036271, 0.009574481500749243, 0.06161946032079868, 0.016716386599000543, 0.07398319532512687, 0.023294505299418233, 0.031251519540091977, 0.03343642827530857, 0.032571354968240485, 0.019793761312030256, 0.07547685658209957, 0.03221605176804587, 0.025673784366517793, 0.05818181001814082, 0.04404256833367981, 0.050059196655638516, 0.04170155996689573, 0.07924158620880917, 0.043499175226315856, 0.05425628667580895, 0.03110566711256979, 0.026025619881693274, 0.06947166475583799, 0.03870713509968482, 0.03230355097912252, 0.044195717928232625, 0.023777042297297157, 0.07212285374407656, 0.07393338979454711, 0.13817300990922377, 0.03040547304408392, 0.009977976988011505, 0.008588473374402383, 0.03700542758451775, 0.024011338318814524, 0.048352268131566234, 0.024280914185510483, 0.06272285580052994, 0.021856339990335982, 0.023328671923081856, 0.037251638786983676, 0.042261284033884294, 0.05614433634036686, 0.023128937718865927, 0.03416645296965726, 0.02992731286212802, 0.03580192009394523, 0.07129317717044614, 0.03189302085957024, 0.04105451109353453, 0.03967247626860626, 0.0377421650046017, 0.017158717746497132, 0.061205846577649936, 0.02901893709349679, 0.043273870323901065, 0.048767978441901505, 0.04027349343232345, 0.10709926442359574, 0.1029050094075501, 0.11728158991900273, 0.06639038634602912, 0.01778873433067929, 0.01131781144067645, 0.02642307892529061, 0.05380747657909524, 0.10594725827104412, 0.03400801186216995, 0.06398746802005917, 0.014823066758253844, 0.05618149938527495, 0.029961726249894127, 0.030279909078672063, 0.04741064600239042, 0.0324865645961836, 0.03474343568086624, 0.04162114084465429, 0.03527261666022241, 0.047999150556279346, 0.02089011381031014, 0.06922769855009392, 0.05560279118071776, 0.04307026210881304, 0.05494265082234051, 0.01437001621525269, 0.06856657113530673, 0.03445997237577103, 0.04066464607603848, 0.01693426074780291, 0.09316441763076, 0.03491804818622768, 0.02643117019033525, 0.011658141811494716, 0.03922536940081045, 0.022463170025730506, 0.04498892536503263, 0.03271512752689887, 0.06282813686993904, 0.050890257334685884, 0.05317010160069913, 0.049557682941667736, 0.061847396136727184, 0.037987129398970865, 0.02888930986955529, 0.018202969622507226, 0.03277324511145707, 0.04059646867972333, 0.021697687370760832, 0.045647870865650475, 0.027057489023718517, 0.05101132388517726, 0.018902367737609893, 0.02334465036256006, 0.04068986054335255, 0.0711201602825895, 0.02781847240839852, 0.01219058824062813, 0.038874949532328174, 0.0446249279048061, 0.00532594533979136, 0.05578597178100608, 0.08514831730281003, 0.0448659663379658, 0.0398054580000462, 0.0681336318666581, 0.035383808935876004, 0.022137910818855744, 0.05150850716745481, 0.01798664656234905, 0.03557090065442026, 0.09342902296339162, 0.041207742324331775, 0.05797370438813232, 0.0421971439209301, 0.025451889632677194, 0.0459345402487088, 0.003132841438855394, 0.008086108973657247, 0.01719760814012261, 0.07045887701679021, 0.02182405471103266, 0.029468346474459395, 0.025616685379645787, 0.031993355514714494, 0.015798617096152157, 0.08436183372396044, 0.12620044610230252, 0.03564442893548403, 0.04828203498618677, 0.0029924034424766432, 0.021797589724883437, 0.05205380388360936, 0.015283219654520508, 0.03573999158106744, 0.11924867460038513, 0.049697444192133844, 0.04977842734660953, 0.08055711718043312, 0.11353807829436846, 0.012205048988107592, 0.07811673523974605, 0.05186924659938086, 0.08963540152763017, 0.005582482135650935, 0.025648319424362853, 0.041572890113457106, 0.01500068310633651, 0.021120652709214482, 0.04045595043862704, 0.004338768330853782, 0.05974462830636185, 0.12433980766218156, 0.06114522795542143, 0.020677657339547295, 0.04370611939521041, 0.04447457249625586, 0.09556663091643713, 0.018461711988493335, 0.025040737964445725, 0.01821317600843031, 0.03891533720889129, 0.010297871394868707, 0.022627041798841674, 0.016719754094083328, 0.022793475836806465, 0.021782761614304036, 0.036506448304862715, 0.0700736726867035, 0.030436543056566734, 0.019899294711649418, 0.03182538152032066, 0.05393116662162356, 0.07013126334641129, 0.040562218564446084, 0.010005055173678556, 0.017745086770446505, 0.06319727370282635, 0.016056133063102607, 0.015613467949151527, 0.08469735126709566, 0.03586428276321385, 0.043873766844626516, 0.07343110424699262, 0.0294613072037464, 0.03053526354051428, 0.009667908616393106, 0.06018804670020472, 0.03563749727618415, 0.03414156875805929, 0.03862299781758338, 0.08138781049638055, 0.028899043136334512, 0.03165536661981605, 0.07651483916561119, 0.05260162019112613, 0.0336225514911348, 0.04123533166421112, 0.0226257077883929, 0.05416324362158775, 0.011886964493896812, 0.04269696553819813, 0.053417403760249726, 0.06856234089354984, 0.04699763339885976, 0.029807951395923737, 0.03750164607481565, 0.02081694547086954, 0.05056627647718415, 0.02310587362444494, 0.06580238274182193, 0.018385213261353783, 0.01699119089607848, 0.06403862425941043, 0.018978408188559115, 0.032540841566515155, 0.0416357240465004, 0.09060713258804753, 0.02044074524746975, 0.0632535656041, 0.046238494251156226, 0.010076704893435817, 0.029592893697554246, 0.03189037881384138, 0.05019129894208163, 0.10855357701075263, 0.017833543352026027, 0.03162194770993665, 0.06340454070596024, 0.04854128943406977, 0.01744073200825369, 0.015562676289846422, 0.012297049324843101, 0.08012848236830905, 0.028485961884143762, 0.06550857389811426, 0.03253283750382252, 0.039025880105327815, 0.02586269249150064, 0.020787838438991457, 0.05509135495231021, 0.02550222950958414, 0.04676626886066515, 0.04480920317291748, 0.030262798863986973, 0.05605270707746968, 0.033265303864027373, 0.05687897719326429, 0.03030210114957299, 0.014462758699664846, 0.039846487634349614, 0.050815586146200076, 0.02065379358100472, 0.021830264631717, 0.02488769227056764, 0.03796353281359188, 0.023160909440775868, 0.03318425762699917, 0.029337685809878167, 0.01417896235579974, 0.02181589850806631, 0.03479688886727672, 0.08417717253905721, 0.01119236992963124, 0.04601521912263706, 0.045149778452469036, 0.013599944304587552, 0.06082091684220359, 0.010474084156157915, 0.04139511234825477, 0.026371649946668185, 0.023501091382058803, 0.0399678176472662, 0.019556201696104836, 0.026012674970843364, 0.061048158750054426, 0.008931682350521442, 0.03265670937253162, 0.07420838519465178, 0.04138908981985878, 0.055446821424993686, 0.1443931573885493, 0.12933637626701966, 0.22354694752721116, 0.24893899593735114, 0.06586551724467427, 0.21040796505985782, 0.16302098985761404, 0.15440579823916778, 0.14457597804721445, 0.09754731916473247, 0.10143408013391308, 0.125632792187389, 0.09253976677428, 0.10489421751117334, 0.13747203658567742, 0.2423896614345722, 0.1344020536635071, 0.14465569955063984, 0.08972249255748466, 0.09612457753974013, 0.11082781435106881, 0.13739169167820364, 0.17817478452343494, 0.07854755938751623, 0.1507988863158971, 0.12150873692007735, 0.17019271908793598, 0.09662218755693175, 0.06897142753587104, 0.07486876304028556, 0.11830241404823028, 0.07781032472848892, 0.13477306813001633, 0.09919395190081559, 0.1859596316353418, 0.15487024909816682, 0.15668646257836372, 0.11349407635862008, 0.19762610405450687, 0.08298424436361529, 0.11812707423814572, 0.08774227928370237, 0.16172303294297308, 0.09741490517626517, 0.09359586518257856, 0.16945944749750197, 0.19479979790048674, 0.20050422695931047, 0.10546142613748088, 0.10666496702469885, 0.12724690401228145, 0.14064356015296653, 0.19781515875365585, 0.09470682314713486, 0.090281159064034, 0.05819114623591304, 0.15929603192489594, 0.11294800409814343, 0.16371893521863967, 0.1602331269532442, 0.13139844842953607, 0.13963759382022545, 0.17293195647653192, 0.09643590106861666, 0.06368707632645965, 0.21474682755069807, 0.14596702996641397, 0.1621681879623793, 0.21418160788016394, 0.08623826506664045, 0.1867897980264388, 0.1648931167437695, 0.0741719531652052, 0.09241095220204443, 0.17323697917163372, 0.17998869734583423, 0.1452002875157632, 0.11705892335157841, 0.15235289902193472, 0.14968394301831722, 0.1126961933914572, 0.18725929548963904, 0.14574445987818763, 0.10519599702092819, 0.15306832938222215, 0.1099023265123833, 0.09377476730151102, 0.10232637912849896, 0.10985283268382773, 0.2789955760817975, 0.12247775914147496, 0.142034137097653, 0.10508913517696783, 0.07964725155034102, 0.1508278152323328, 0.10208178209722973, 0.13381538592511788, 0.1911452697822824, 0.21390296111349016, 0.21050362789537758, 0.09595840325346217, 0.20508413901552558, 0.11676374895614572, 0.08233187429141253, 0.1580119680147618, 0.18602339696371928, 0.08909797528758645, 0.18305398989468813, 0.1792000763816759, 0.1243543611781206, 0.18474239070201293, 0.1613196756807156, 0.2111539273755625, 0.11144309930386953, 0.18615869048517197, 0.13464617572026327, 0.15465720818610862, 0.1324627920985222, 0.326909965951927, 0.1256525333155878, 0.18440061685396358, 0.1284602115629241, 0.1410920251510106, 0.14409873256227002, 0.08690078771905974, 0.12616445193998516, 0.14566545083653182, 0.1123318359896075, 0.14176041819155216, 0.16187138826353475, 0.1580973743693903, 0.09299918587203138, 0.1467929215868935, 0.10139193356735632, 0.13440787210129201, 0.17468712088884786, 0.1636212834273465, 0.19356523524038494, 0.1917342233355157, 0.13747332792263478, 0.10781298042275012, 0.19847285002470016, 0.05760044492490124, 0.06681726226815954, 0.06963992447708733, 0.09068917701370083, 0.21520372334634885, 0.1291648659389466, 0.09453376915189438, 0.15673968940973282, 0.19249275763286278, 0.0871238179388456, 0.13954898138763383, 0.14341696602059528, 0.1047321101941634, 0.204093728098087, 0.11479659005999565, 0.13062793586868793, 0.1628122088732198, 0.13329610519576818, 0.11464517709100619, 0.09168760312604718, 0.17525836679851636, 0.14460230944678187, 0.20506562985247, 0.13674986752448604, 0.1275812860694714, 0.20007250481285155, 0.08749932239879854, 0.13625647290609777, 0.10275476903188974, 0.12050157572957687, 0.10782046869280748, 0.16659750341204926, 0.14446836663410068, 0.14081866247579455], [0.03450186661211774, 0.06162638084788341, 0.02817917844367912, 0.0173727401488577, 0.019811984748230316, 0.01295091296924511, 0.04057078294863459, 0.022706446034135297, 0.039042463395162486, 0.05148249489138834, 0.030337633324961644, 0.020405593422765378, 0.010947222781396704, 0.038670350550091825, 0.03932722545869183, 0.019011535805475432, 0.01649390185775701, 0.03800236569077242, 0.029409920898615383, 0.07893000292824581, 0.061410961352521554, 0.03021427724888781, 0.02982474434247706, 0.034390618675388396, 0.050326763157499954, 0.033830393658718094, 0.03057025580346817, 0.04533979052212089, 0.044425071246223524, 0.040751076594460756, 0.001231830513006571, 0.005303905409164145, 0.026853116396523546, 0.03969320074247662, 0.010985331136907917, 0.03464654459094163, 0.0407246412942186, 0.0015127894175748224, 0.047453545848838985, 0.026748109921754804, 0.025259409922000486, 0.0603500130091561, 0.05847718479344621, 0.03094890696957009, 0.09080917487153783, 0.07787607901263982, 0.08688725836691447, 0.05472564684168901, 0.00586396576181869, 0.061687240668106824, 0.04811379752936773, 0.03918075890396722, 0.02036863075772999, 0.06340591367916204, 0.033568645594641566, 0.06246246586670168, 0.011839957787742605, 0.053400623801280744, 0.01681543177255662, 0.0424352397385519, 0.036132372479187325, 0.06864410330308601, 0.02945807143987622, 0.059838543384103104, 0.034938342214445584, 0.008496536120219389, 0.014949012002034578, 0.03184858476743102, 0.019637724763015285, 0.08478510280838236, 0.04382021346827969, 0.03208949332474731, 0.03831044974504039, 0.022952989347686525, 0.01027654021527269, 0.06346639871480875, 0.02084970572468592, 0.08955028461059555, 0.019452174856269266, 0.08527291647624224, 0.052196967881172895, 0.0953995437885169, 0.07660558156203479, 0.04629726492566988, 0.06934453485882841, 0.015009514663688606, 0.023307221999857575, 0.05410404992289841, 0.02417212090222165, 0.014237527084333124, 0.014232097346393857, 0.03153513127472252, 0.06991690141148865, 0.06576834784937091, 0.0246165189309977, 0.10620178523822688, 0.06437512885895558, 0.05805180800962262, 0.044803176933783107, 0.015211464178719325, 0.05119580324389972, 0.013544124594773166, 0.08472144138067961, 0.013707847010664409, 0.03535192256094888, 0.07979313551913947, 0.05421319016022608, 0.05490895360708237, 0.02385691779636545, 0.005849224389748997, 0.03186112335242797, 0.05751093449362088, 0.019580048756324686, 0.016064096307673026, 0.027739893812395167, 0.047522342938464135, 0.03904318327840883, 0.0700723665067926, 0.00807969217930804, 0.015453406176675344, 0.05640766517899465, 0.04251780737831723, 0.02705873026570771, 0.0703798902395647, 0.041020836142706685, 0.07613984678755514, 0.016222197882598266, 0.04096392454812303, 0.017806263858801685, 0.055864676542114466, 0.027740474542952143, 0.011246869544265792, 0.05572276306338608, 0.03451976350334007, 0.007882249356043758, 0.021458860537677538, 0.05475769277836662, 0.05446391362056602, 0.009850328515312867, 0.04382464408990927, 0.11606561063672416, 0.05635826411889866, 0.03606100755860098, 0.012214859252708266, 0.012682361266342923, 0.04058605263708159, 0.014895635813445551, 0.0835976739472244, 0.023510446153522935, 0.03257916607253719, 0.055420909338863567, 0.021219393602223136, 0.006614212588829105, 0.03125318566162605, 0.12852154264692217, 0.022153887402964756, 0.024328600884473417, 0.01907431593281217, 0.02246418491267832, 0.08929617324611172, 0.037391618971014395, 0.04378643090603873, 0.025112208641075995, 0.03201437313691713, 0.00888680375283002, 0.03406512754736468, 0.09043807876878418, 0.051704152137972414, 0.034562741275294684, 0.018085456104017794, 0.016225775034399703, 0.02109113378537586, 0.013175926578696817, 0.030120822302706074, 0.026365211815573275, 0.033507455518702045, 0.04244240888510831, 0.13436133944196627, 0.03822571503405925, 0.01801665530365426, 0.10221098258625716, 0.012781549303326756, 0.04949229602061678, 0.028974168890272267, 0.10301992355380207, 0.038213465886656195, 0.009834048578341026, 0.022766096153645776, 0.008822171967040049, 0.054834564434713684, 0.044878144981339574, 0.0824732385808602, 0.009595335850463016, 0.0420337230025325, 0.06901826447574422, 0.031178154531517066, 0.019910768314730376, 0.07658574395463802, 0.014725858400197467, 0.05466739195981063, 0.01860576285253046, 0.03681357127788942, 0.024109871410473716, 0.09763484064023942, 0.05118293069244828, 0.01538971135232714, 0.014246125792851672, 0.04134489492571447, 0.041453014709986746, 0.03714125545229763, 0.011891088979609776, 0.06330659947707318, 0.04956667406077031, 0.04406427986396011, 0.025423142542422283, 0.03192866992321797, 0.058317033035564236, 0.023798577567504253, 0.022698640495946165, 0.06591446930542588, 0.031995581957744434, 0.0211860266426811, 0.038380668047466315, 0.05637245027173776, 0.05530029920919333, 0.01327588459389517, 0.04507137797190808, 0.019411091416259296, 0.0543927193939453, 0.06643235479714349, 0.014799407090322347, 0.05426678435469512, 0.018693672100198455, 0.04567820615193341, 0.04310870906920172, 0.06544518706505187, 0.08531328930985183, 0.10083143395604566, 0.03935271452064626, 0.06765115424059331, 0.047635379451094195, 0.019350749244040344, 0.08783921861322597, 0.0788735700189136, 0.026347825150878634, 0.034549486517789774, 0.06425714222132228, 0.027152880975336302, 0.023867432173574343, 0.003956634636779199, 0.04305813541577663, 0.035114357378915884, 0.026571178204903845, 0.02775277378532337, 0.018429393312544562, 0.033653781065368094, 0.04428009640832897, 0.026564749350654893, 0.07092573243426159, 0.05509574475581758, 0.014052690567041282, 0.023462457029381767, 0.10431080037960783, 0.05531607355806045, 0.03580630618671421, 0.031152973460848443, 0.02917815374530619, 0.047855953162070364, 0.045251233750605024, 0.045162365277064964, 0.028381567681208253, 0.030604708153987303, 0.026381917559774593, 0.03230209636967629, 0.032630559799144976, 0.030700118659297004, 0.01749536706483923, 0.03815771946392488, 0.07530597707955167, 0.01858009010902606, 0.02021658881858457, 0.08801602045423351, 0.0760087241360452, 0.014358181742863962, 0.04157158393354621, 0.08033333739149384, 0.04930671086185612, 0.02408985197689617, 0.016577784954279196, 0.041601358898333274, 0.007672535120946122, 0.020689279372163583, 0.04029490068205632, 0.0328931947296951, 0.03948424164263997, 0.021046786750957835, 0.0564670778112486, 0.004436570407051477, 0.03400372224859893, 0.02036248020885978, 0.01748558926919941, 0.04124983694055118, 0.03923821968783159, 0.027133167677675374, 0.01729993546177866, 0.07994675266672857, 0.04926613764837384, 0.023399409728881437, 0.02373956569499569, 0.06838015106040984, 0.02709791009692708, 0.028668817794823553, 0.023497252623201348, 0.013761775171587942, 0.012758062184730079, 0.03115717030595988, 0.012270037932466948, 0.030524669382430147, 0.012043001970596379, 0.044985285130678676, 0.04016047176264692, 0.03293569381639827, 0.019878334605891723, 0.022671921324217692, 0.02728139497776283, 0.03988204764027614, 0.0237971953174565, 0.02469511608069297, 0.014767347238375805, 0.025446854160691146, 0.00982569941697875, 0.02437013703456614, 0.02711997600272298, 0.032485343763255514, 0.046888619326637127, 0.04952986724674702, 0.04715601142379455, 0.0730662644491531, 0.04557384534564335, 0.03904465273080859, 0.0073479540515108965, 0.04406528176332358, 0.02427019200695213, 0.06769316722056828, 0.03803753606916871, 0.008111284478218295, 0.04419306103955023, 0.04922361629724037, 0.005829287520100479, 0.03844112710794434, 0.01695622460829327, 0.03717868195963092, 0.27936994505580515, 0.16230499546509236, 0.09255509954527952, 0.1331002969527617, 0.2776405034819618, 0.06950021517695859, 0.1877092002541758, 0.16085013368865475, 0.175495037692599, 0.12753168091876432, 0.15507524512941018, 0.17581347841769457, 0.06648922557360493, 0.18722198030445725, 0.19308261660626158, 0.09412114988663234, 0.17734283697791398, 0.1300462256767787, 0.1432779320748523, 0.17602147272555158, 0.11599161109188572, 0.1259381859563291, 0.09387520214659162, 0.10120750986970961, 0.12656265869736671, 0.14782893005758524, 0.14515160262817517, 0.19567553215892985, 0.11880528589244932, 0.12127540569053963, 0.18538017757236958, 0.21151701570488513, 0.16088676609797403, 0.08322702313307673, 0.12671677308389917, 0.08116342214634642, 0.13762482994934544, 0.1505138273932971, 0.12202435886138119, 0.17878646263852715, 0.16757596575189382, 0.12662461318541318, 0.11719717804226093, 0.1810795653727837, 0.280030129943043, 0.1250971990521066, 0.23437154246494174, 0.16565899830311537, 0.11569626600248739, 0.0770636425295379, 0.18309681181563064, 0.10958426428260282, 0.20466835820116103, 0.24112066312227398, 0.11595166870392859, 0.15441032533999532, 0.0851916141982656, 0.1957529381616041, 0.22221682593226433, 0.17093649948947132, 0.1374366955133155, 0.18297379341674969, 0.17141824238933623, 0.18007540988037363, 0.1260154732153751, 0.18900227383710444, 0.2085854730103165, 0.19606046931585297, 0.15368555876193568, 0.13989057712024078, 0.11659859883366153, 0.04538634173513856, 0.14772765658563003, 0.1303855504374951, 0.12081258013495244, 0.10962050335365348, 0.08301162961288355, 0.18947612028568983, 0.17767344892490655, 0.16573367320233956, 0.20550593122607097, 0.25684261636342853, 0.13312198250787333, 0.1984422586974688, 0.13145627657650039, 0.13074926217086613, 0.23623894929187372, 0.14081109256949276, 0.12237788090715185, 0.11713548330590129, 0.11956148984609172, 0.13904114457545802, 0.12033211372909136, 0.12808879633666947, 0.15006974106654525, 0.15472373430384323, 0.20204545988235623, 0.11254114389885217, 0.16868371021701023, 0.11836709221825004, 0.12775376118952408, 0.08608983553131111, 0.131084282475058, 0.09798192084417678, 0.10731429429142736, 0.2372238683165051, 0.14386167575139552, 0.11483043199405074, 0.10159805024159141, 0.09067286460776813, 0.09374977918923832, 0.18665079376660287, 0.09364098033984192, 0.08202711876947433, 0.09428286386537366, 0.12379124178551137, 0.1678734036977403, 0.1109486359928269, 0.11654840738628991, 0.0908788328524679, 0.12910819554235786, 0.12127300113206729, 0.07670385675737634, 0.2169195984606631, 0.19491738377837464, 0.12227219907799736, 0.08494061243254691, 0.17671066074399278, 0.08006004150956869, 0.15323725703638047, 0.14293899323092774, 0.15050658403197303, 0.1772494599572383, 0.14665007300209254, 0.09009564440930262, 0.11412078296416439, 0.17343280225759372, 0.19600693078245968, 0.10861070011742413, 0.14389449352165684, 0.17594575881958008, 0.08435191120952368, 0.07784317960613407, 0.11923996920813806, 0.16525400831596926, 0.082529938663356, 0.16351024329196662, 0.3370496624847874, 0.15311037946958095, 0.14466034539509565, 0.16138762672198936, 0.12451900664018467, 0.07392805375275202, 0.09598394055501558, 0.14658415544545278, 0.09342428806121461, 0.1808389462530613, 0.12923578557092696, 0.09134507228736766, 0.1367210573516786, 0.18387434509349987, 0.16255530703347176, 0.16652417922159657, 0.12296287881326862, 0.10189067164901644, 0.18197835073806345, 0.14973142562666908, 0.14522397686960176, 0.08976725148386322, 0.08139205558109097, 0.062216558944783174, 0.19824688090011477, 0.11525284760864452, 0.1167791782063432, 0.11599797871895134, 0.11613665643380955], [0.09798473358387128, 0.053157889560679905, 0.04829704492294695, 0.021148472114873584, 0.017748827194736805, 0.07015672643319704, 0.04796438093762845, 0.03673173465358559, 0.0069172741586953634, 0.04389808702399023, 0.01901518160593696, 0.07277527576661669, 0.06301154382526875, 0.056100891015375964, 0.07706394681008533, 0.07206645052065141, 0.04988467691873666, 0.05198622020543553, 0.05300694414472673, 0.008552860490453895, 0.05254379204416182, 0.011317673215671675, 0.026603726946632378, 0.08288131590234116, 0.07615174341481179, 0.04965453321347013, 0.06266620024689473, 0.08361043888726272, 0.01919338796142256, 0.04338030172220897, 0.026461459092388395, 0.008944536348280963, 0.04097622564586345, 0.07048883751849644, 0.04950710186676588, 0.03984483264503069, 0.08198506868211553, 0.024352262407774106, 0.04871079225267749, 0.06022307978128083, 0.039462188724428415, 0.05153892037924379, 0.06974955453188159, 0.04024079811642878, 0.03883417222823482, 0.028308310284046456, 0.025535420209052972, 0.006961251510801958, 0.059427712694741786, 0.08557999492040835, 0.015060752539284294, 0.017398184681951534, 0.020021884520247113, 0.054830916778882965, 0.1196701625303831, 0.014543633315042825, 0.04017600862425752, 0.03578062045562547, 0.029983114945935085, 0.07977805507835001, 0.006190197182149859, 0.037116144885658287, 0.0452199670689879, 0.03400867979507893, 0.037575608512270264, 0.074561254150467, 0.030500703578582034, 0.03311713779112324, 0.060889276064699516, 0.13020911224884912, 0.017240457891603, 0.034988092083949596, 0.017468317637394648, 0.041295015180367045, 0.027361776992620435, 0.048209753513219766, 0.014515749899146613, 0.017219276996911503, 0.07837338474928401, 0.04429836437338963, 0.04668712994316593, 0.06733816087944433, 0.1528951121144928, 0.05509515103767626, 0.047285631226259284, 0.053029305054224096, 0.038428866828326136, 0.10165241255890578, 0.06245189768378623, 0.03062048435822362, 0.04384753563499544, 0.061292039608815685, 0.08486055696266703, 0.02829871060384903, 0.04054411387187429, 0.04488604514335748, 0.060390422950149514, 0.07015139781287871, 0.1334388498798944, 0.09098006921703927, 0.06754749847459607, 0.04720909353636671, 0.032679604628356174, 0.0341771324747242, 0.06951767049031332, 0.04473891807720065, 0.045715658634435385, 0.008013669794308953, 0.024220152699854225, 0.056017406823229976, 0.0526213242119411, 0.0232541658624541, 0.06635264813667163, 0.01727719234622782, 0.04812756065803114, 0.022628166152571794, 0.03563606122042984, 0.011027190121239983, 0.07392107014311478, 0.0478478229342727, 0.05330832289473619, 0.04490262843319215, 0.041546532738721, 0.037730899202870205, 0.030639184624305926, 0.07986984390299767, 0.024728893076826353, 0.05925300742092077, 0.051870905299438164, 0.016938420485530514, 0.04471324347832706, 0.003546493448993715, 0.05628699938824866, 0.03244880412239581, 0.14866728975903243, 0.04044741945108399, 0.020216379161865916, 0.02056700312095927, 0.025340094362036325, 0.028369188657961786, 0.02092074224492535, 0.04613752134901006, 0.0665508238307666, 0.020462738793867175, 0.07887556639616378, 0.029672108685190324, 0.03408011150895618, 0.057866757197189145, 0.019850209064316005, 0.0391461711114971, 0.0041656146095192526, 0.018408062132948544, 0.075899569055764, 0.037257375588524155, 0.03381910930329468, 0.010323342830815818, 0.018080576483043842, 0.009995879445341416, 0.06417684926418588, 0.007964563737914432, 0.026348571009293664, 0.02864580379537074, 0.03605687008530367, 0.034079866600222886, 0.03477919606666546, 0.022287908141152002, 0.016873341555765364, 0.018101141395163722, 0.027354019694030285, 0.04776743720867671, 0.05135866013006307, 0.019807175631285645, 0.039532878290629014, 0.06662342813797295, 0.037484825297724456, 0.05093798856250942, 0.00578685383516131, 0.029561858937086072, 0.03787385539908428, 0.027059529929829296, 0.05654532986227423, 0.085884609434288, 0.07481872002244927, 0.0332464644452557, 0.04336941070505418, 0.04144098078540992, 0.040504794887965545, 0.09888423883239739, 0.030024439583939966, 0.08331153891049325, 0.05263373663183302, 0.02292367451445898, 0.029141092745703645, 0.0592002815392334, 0.04242369934218004, 0.0444823539146455, 0.004004989732493414, 0.041277548734797165, 0.0625283463159576, 0.021800135291414335, 0.07216212077764794, 0.08515394278219901, 0.04952965202392079, 0.02548559983551968, 0.03688278025947511, 0.036677023526863195, 0.04127190841245465, 0.03072450934269, 0.04602376495313365, 0.07761701752315275, 0.035395193481235765, 0.036638569144997746, 0.0672771266545169, 0.02117659580108011, 0.01570323442138033, 0.041553954215487465, 0.04079999154782854, 0.052557970775524154, 0.0770785151689779, 0.02808276047289837, 0.03873371140798554, 0.028140145186625887, 0.05448341726150829, 0.03448554307396989, 0.05178536164748948, 0.09802466855035163, 0.057476695510558784, 0.030173208651831374, 0.031185293992166407, 0.05354688626539428, 0.05275199415336829, 0.07157972038839944, 0.016806919338705484, 0.02097162760037463, 0.006788603841414442, 0.03090299400355434, 0.005085228349344106, 0.03521988335705828, 0.028521703716251068, 0.06286136282142252, 0.06939756873180158, 0.07030067339655943, 0.07082792479195632, 0.024511328774678987, 0.10816066918778233, 0.18993212550412863, 0.02895667275879532, 0.010314133705833228, 0.030967241727921646, 0.05419333770987578, 0.04899466373899486, 0.06477240051026456, 0.02970819376059808, 0.006050247147868504, 0.11167222997755744, 0.05845657906320412, 0.04256861109752208, 0.0959051690006163, 0.10420133359730244, 0.05805770066217519, 0.15195221349131316, 0.016770119946158957, 0.04858987784245983, 0.04293447134841699, 0.01664787152549252, 0.0467018541530706, 0.04829992074519396, 0.07634421199327335, 0.05570725959842093, 0.053277879997040145, 0.04013009194750339, 0.02323270480701467, 0.054032365878811106, 0.07102248622686602, 0.1028006114938762, 0.08274367719423026, 0.0340712094475748, 0.020538641947496217, 0.036635986471083015, 0.021081556369608734, 0.0317445022665197, 0.041250478898291476, 0.017365379899274558, 0.03826805826975033, 0.06081796680518892, 0.01785840529919369, 0.01575462443724973, 0.06610057025682181, 0.024663808580953628, 0.022961431277508382, 0.022115889441920444, 0.02154427802452119, 0.05860573219251819, 0.07293762057088315, 0.03613671404309571, 0.0373939418932423, 0.042959574493579566, 0.03828947665169835, 0.009897960480884649, 0.0326098167715827, 0.017713894303597044, 0.0747494405368343, 0.03713828315085266, 0.04703491518739611, 0.022808895810157992, 0.03705023103975691, 0.027436782147560734, 0.020483524494920857, 0.04236430526361801, 0.026349814106652047, 0.07570689267595299, 0.05214941476879176, 0.01675947569310665, 0.06357504913466983, 0.03124181595921982, 0.02480761453625746, 0.047691541476524435, 0.01422746448952239, 0.007635462061443832, 0.019316113211971242, 0.03339112015964929, 0.047297865530708805, 0.008648129987705033, 0.015131063610169804, 0.028891048350487836, 0.04448368606972508, 0.010793171477416763, 0.04377366967673879, 0.049848363632918335, 0.024999333545565605, 0.05274160408589523, 0.00649195257210522, 0.027626489936665166, 0.05416813066403847, 0.007827066965546692, 0.020984965849493165, 0.06709188659442589, 0.030992177889856976, 0.0457994693715591, 0.045410450402414426, 0.009254603792214766, 0.026585603700368665, 0.0422821754909819, 0.016984543108264916, 0.03496425058983732, 0.020732028933707625, 0.031585497126798145, 0.05842145692440681, 0.033893086583702825, 0.016209317909670062, 0.030338577707880177, 0.0544485808495665, 0.17393452377291396, 0.21922893938608468, 0.16158278187504038, 0.1942141097970307, 0.1266130802105181, 0.22844038729090244, 0.22506132954731584, 0.115383539814502, 0.12261112307896838, 0.12740149337332696, 0.12324694325798191, 0.17661015910562128, 0.13296956021804363, 0.2965631615370512, 0.18439804902300239, 0.13188278884626925, 0.09670381637988612, 0.10122829000465572, 0.1282941337558441, 0.11313877315842547, 0.1321264507714659, 0.10948007417027839, 0.11301400329102762, 0.16333680337993428, 0.12544102122774348, 0.18309915700228885, 0.17961070669116452, 0.10413290016003884, 0.19644944375613704, 0.1265715347835794, 0.11180418383446522, 0.1659290658426471, 0.14834452973445877, 0.19011699449038133, 0.10012210404966027, 0.24832182592945173, 0.13765393698122352, 0.10714484713389538, 0.1746315191849135, 0.15488512173760682, 0.2901825914159417, 0.20076521061128005, 0.18042653478914872, 0.12574499007314444, 0.07520379076595418, 0.1172550581395626, 0.1458233650191687, 0.11289180867606774, 0.18141372478567064, 0.24080829316517338, 0.0841540694818832, 0.11312326227198355, 0.2202580458833836, 0.21178018127102405, 0.19343620544532314, 0.1441698896815069, 0.13098501280182973, 0.09246728121070191, 0.10774308495456353, 0.2146425558021292, 0.11107299025752582, 0.1041854739014525, 0.13206338306190446, 0.18672006583074108, 0.17495914769824594, 0.17133745219325647, 0.1422140040085651, 0.15481586451642215, 0.15686245547840372, 0.35104196635074914, 0.1342880300944671, 0.17410716216545552, 0.0970380796934478, 0.12294238069443963, 0.2166278602089733, 0.1463628766941838, 0.18707551003899425, 0.16764740488724783, 0.21644539578119293, 0.15410378866363317, 0.1608068961650133, 0.17322163155768067, 0.31878291454631835, 0.14746222004760057, 0.3078265587100759, 0.2155271513038315, 0.18600260198581964, 0.15998413640772924, 0.22433826990891248, 0.20175884244963527, 0.20148454466834664, 0.12334584927884862, 0.16309192433254793, 0.17719909781590104, 0.06985055340919644, 0.16173369018360972, 0.14301403920399025, 0.11330197885399684, 0.23359028360573575, 0.21395100775407627, 0.15828023955691606, 0.15571454598102719, 0.15606979723088443, 0.10045173636171967, 0.23545092204585671, 0.11314382718410343, 0.11679980249027722, 0.14272948494181037, 0.14750357251614332, 0.11000947037246078, 0.14754382660612464, 0.12065785718732513, 0.10865779680898413, 0.08400955106480978, 0.09822351959883235, 0.11298071054625325, 0.12276842127903365, 0.11807574730482884, 0.22630130988545716, 0.11885707295732573, 0.11098425165982917, 0.11244383349549025, 0.11952607455896214, 0.09580863785231486, 0.09865187981631607, 0.24699703295482323, 0.08620840104413219, 0.11519870051415637, 0.10616055893478915, 0.11474758604890667, 0.10144084109924734, 0.10176626543398015, 0.18155255093006417, 0.16448359965579584, 0.30433519918005913, 0.16794548108009622, 0.14864285825751722, 0.13945569342467934, 0.07345240388531238, 0.09436724605620839, 0.09341423196019605, 0.09979634574847296, 0.19383669801754877, 0.09951910164090805, 0.20417629944859073, 0.19484085350995883, 0.1584427698981017, 0.12603432376636192, 0.11912673973711208, 0.19327152287587523, 0.09771030963747762, 0.10274119515088387, 0.11481478752102703, 0.08096543941064738, 0.11474433544208296, 0.10184364175074734, 0.17976964503759518, 0.12004262418486178, 0.12283453179406933, 0.11249165749177337, 0.1505806652130559, 0.09513871598755941, 0.12179239318356849, 0.14227226260118186, 0.12892923405161127, 0.08874332517734729, 0.14208363834768534, 0.1608622752246447, 0.13447426463244483, 0.17395338916685432, 0.14308307378087193, 0.09270768510759808, 0.08830059698084369, 0.14131937467027456, 0.17086651496356353, 0.16639157227473333], [0.008335099519172218, 0.06651376839727163, 0.0026979788481185096, 0.026040666925837286, 0.013752004797424888, 0.024789444905763958, 0.07213476521428674, 0.0360204343451187, 0.04347914466052316, 0.05291028312058188, 0.027990867747575976, 0.05545240237552207, 0.020076742221135646, 0.026020237455668394, 0.04428704662132077, 0.055595970843569376, 0.0710331583104562, 0.03689645804115571, 0.06549501486006193, 0.022700191584590357, 0.03852863374049775, 0.030890880298102275, 0.026104148382728454, 0.06718803924741223, 0.03084279283939395, 0.06729049273417331, 0.08765111386310309, 0.08990271569928154, 0.03834985778667033, 0.04140294200624339, 0.022711633646395057, 0.030322547318064608, 0.0396841094334377, 0.07355152512900531, 0.0650919321924448, 0.049772646016208455, 0.08991407055873424, 0.04354053511633538, 0.07588736072648317, 0.022140818182379007, 0.04130773559154477, 0.03367643141245935, 0.07271723981830291, 0.009149579691438703, 0.016015951332519762, 0.020696695282822475, 0.060331403656164184, 0.06493701628642157, 0.027801135838672053, 0.06939377635717392, 0.06357364647556096, 0.029927032701380085, 0.04876386694377288, 0.042867525917245075, 0.009286121876357356, 0.029551858497143257, 0.06253164887311868, 0.04166417056694627, 0.0053989388106856495, 0.004042586933792336, 0.006994742780079832, 0.01708881671220297, 0.03950246507884003, 0.041592798224883154, 0.03730329597601667, 0.015944870283419732, 0.03493126583634876, 0.031156135009950958, 0.05733938334742561, 0.0077050110394338844, 0.02052153358818032, 0.051775290703517385, 0.04391592454339843, 0.027481884317239746, 0.06672505784081295, 0.07672828825889155, 0.037055503998999484, 0.2030074317008257, 1.0095792263746262, 0.6557987944688648, 1.2640709266997874, 2.280018017627299, 2.782110725529492, 2.2880752477794886, 1.8979694182053208, 1.722586266696453, 1.8654626375064254, 1.14461709279567, 0.600534500554204, 0.22264310071477666, 0.03771765928831883, 0.16371850477298722, 0.07750815930194221, 0.027795111454906873, 0.06057052734831814, 0.11094830944784917, 0.06164542806800455, 0.14154516567941755, 0.4651619552168995, 0.43483661371283233, 0.3998645074898377, 0.09966218771296553, 0.016836881695780903, 0.059888508476433344, 0.04908237446215935, 0.03959719280828722, 0.04636861500330269, 0.09543153035338037, 0.04377410754386801, 0.015364970931841526, 0.0044239738417672925, 0.02823699360305909, 0.08484951380523853, 0.06199862727953587, 0.021730557091359515, 0.024482971311954316, 0.03622143391112331, 0.10097045305883512, 0.05166029863175936, 0.05822129227453843, 0.04212850268231705, 0.056282746882061474, 0.01604560384294018, 0.043536894881981425, 0.03885566482495051, 0.07461885223165154, 0.021688464330509305, 0.030339164004544728, 0.027143223778693937, 0.02716760147450259, 0.013811315384373302, 0.01865434012870537, 0.023351543059106916, 0.04286659823264927, 0.033875505105243064, 0.04041637912450824, 0.02045426346739987, 0.04744089223095216, 0.06925004461663775, 0.03781624618568458, 0.015876973047852516, 0.014283668260759441, 0.03675398795166984, 0.09365834659547545, 0.0014787045461162052, 0.04875728038314264, 0.01811282279959414, 0.057489423343213275, 0.03569587461242918, 0.021054725875728764, 0.046151885617291555, 0.018917565066658426, 0.017865591144072823, 0.06062732762075029, 0.013731294238823466, 0.028299805271672085, 0.08092217962257564, 0.04521537688560784, 0.05674645188264549, 0.012675984362431336, 0.08462502897600643, 0.06188056642713491, 0.04507643199758604, 0.027719887366401963, 0.008772031542321201, 0.04740420787129551, 0.04128990178287495, 0.024940505354607012, 0.029241596239444334, 0.03742444787349086, 0.11215412130695768, 0.026326929983042646, 0.023235866356117185, 0.04942621148074977, 0.024617912313260604, 0.05256787844700739, 0.005849191456945846, 0.03326532612845767, 0.024761311942711473, 0.025363811546412762, 0.018436408463458065, 0.06741891396814026, 0.06783943710615858, 0.050791611065506004, 0.014295787532319082, 0.04124727282032836, 0.012804858306481037, 0.04386787048133556, 0.008984950000012759, 0.0831956673937384, 0.03457777347648516, 0.030725145734322723, 0.017365914245601743, 0.02142537668987643, 0.06718614677083679, 0.028660316493187565, 0.040187812483054586, 0.03877835159073584, 0.010930260996246943, 0.022305122256511822, 0.032331659822375514, 0.030220429653127212, 0.06515361208585091, 0.014120921769062988, 0.02916096374974586, 0.03887234830472153, 0.03902472977642901, 0.08797262707957998, 0.016725696841604076, 0.028726718301186338, 0.04109863919438794, 0.09075733585632406, 0.026120215879927855, 0.0218491430132417, 0.009706763758003945, 0.06297212836216204, 0.01870796400908148, 0.09375033579999581, 0.07734654180239886, 0.04204182725516148, 0.03959456931625027, 0.04709141489001922, 0.029760945617454126, 0.052599571863538586, 0.0072869355972216, 0.06081088671635371, 0.06950011869776063, 0.024132876133080572, 0.03329814018798061, 0.06282726855715737, 0.03842386846372392, 0.06472315159044228, 0.06165224469441455, 0.040480626848875545, 0.006895502792758634, 0.0427803866477916, 0.01784674430382438, 0.005955953574812156, 0.028635356211452745, 0.09422982257092372, 0.02145270256733056, 0.03256234158470761, 0.041747172363102436, 0.0628617635811679, 0.053154011839069426, 0.032193356892094016, 0.030106647282082122, 0.02711184020881774, 0.020427006238605827, 0.04048682007123716, 0.05518720703548752, 0.049937803560169414, 0.012510489141277503, 0.4150007577845827, 1.491686669178307, 1.1931205401197076, 1.6723732673563063, 3.121243240311742, 3.679837016388774, 3.7900384655222297, 3.1910222209990025, 2.7545945020392537, 2.334184586070478, 1.4179993607103825, 0.6879925669636577, 0.35321999166626483, 0.07674342807149515, 0.14590102335205302, 0.030113573375274427, 0.029392331998678856, 0.07074419569107704, 0.1534890677430667, 0.09012947150040418, 0.2082204699399881, 0.5104020901490003, 0.596603195881471, 0.5484671413432807, 0.10914317623246461, 0.08605908093159087, 0.0708895453135483, 0.04547246055153664, 0.08478005620418116, 0.06539883994264528, 0.09247287700418383, 0.08011347614228725, 0.05932118481723592, 0.06107764056650922, 0.01741400541504845, 0.043254648699075915, 0.07045618302072398, 0.06832879444118589, 0.010536312311160145, 0.022409267839975655, 0.05292664376611356, 0.057860089000314474, 0.07138035725802183, 0.027066279762948398, 0.015264901594491675, 0.013204714487073943, 0.04575592014589347, 0.05981040114420466, 0.032306771900039166, 0.02882035136281047, 0.012969198560313089, 0.08250788945588283, 0.04949860798660666, 0.03477472462691367, 0.01776305045495974, 0.05209438080783002, 0.03929481958039105, 0.013490215915226145, 0.0516570814215811, 0.027535608387552202, 0.05377365319873206, 0.08918181571061723, 0.03249969689932186, 0.0389024089963641, 0.04744870704598725, 0.017966009290830698, 0.07662031319341622, 0.05993960163323209, 0.055728859806549735, 0.03247191460104659, 0.029506804567063227, 0.03770168455957901, 0.05878361756913364, 0.05174885540327523, 0.0456482642039191, 0.04116371812415309, 0.10637938117724843, 0.03711726552865002, 0.05755224614404142, 0.03806514396273997, 0.04382879640616011, 0.09039915312314406, 0.0538032129406929, 0.07997846463695168, 0.03835841103864368, 0.04116634161619004, 0.04260414883901831, 0.035659297864185646, 0.046917960135033354, 0.06223240379767958, 0.02846633393346565, 0.07373993415967561, 0.042143657337874174, 0.05519390862900764, 0.025046042464964557, 0.02078593668557005, 0.022062445532355923, 0.07130874742870219, 0.03474344681308139, 0.11497083149151877, 0.12578157795360312, 0.0986319086223375, 0.10807158178067766, 0.18067006312776357, 0.1245687750633806, 0.13200809305999428, 0.15249852323904634, 0.1285924029070884, 0.16325118922395632, 0.11238009785301983, 0.16253578854957595, 0.1289278536569327, 0.16491999733261764, 0.09205285110510886, 0.10565340489847586, 0.19282957393443212, 0.07559157034847885, 0.12749010580591857, 0.11916045550606214, 0.12377930062939413, 0.10861988048418425, 0.1049206082825549, 0.24760811735177413, 0.11815198813565075, 0.14218690077541396, 0.19225749681936577, 0.12898211949504912, 0.11524117362569086, 0.20124002185184509, 0.08355965372174978, 0.15350579575169832, 0.13568890804890543, 0.1674480046494864, 0.18219035264337435, 0.2145321390707977, 0.18346460536122322, 0.18854191963328049, 0.13496578903868794, 0.17457973212003708, 0.15550395415630192, 0.12471457739593461, 0.16357908491045237, 0.09758330590557307, 0.1309179374948144, 0.14071388606680557, 0.16500148514751345, 0.21578522573690861, 0.1065902401751373, 0.19195073749870062, 0.148924206441734, 0.19468479469651356, 0.14411348645808175, 0.10237210284685716, 0.10501633791136555, 0.13277833844767883, 0.19129133928800002, 0.14112156262854114, 0.10381999585661106, 0.1827501694788225, 0.11151840502861887, 0.08088821894489229, 0.1560107816476375, 0.21466146572493017, 0.26195064070634544, 0.11780903427279554, 0.14927941316273063, 0.10918372718151659, 0.17428671737434343, 0.12639892607694492, 0.11774967730161734, 0.10077415499836206, 0.16619386413367465, 0.10522960146772675, 0.1373258780222386, 0.21245783631457016, 0.29948232520837337, 0.595979435602203, 2.1205037645995617, 1.812927012797445, 2.0867397263646126, 3.6185669666156173, 4.523551343008876, 4.957926934584975, 4.349602852016687, 4.1815815679728985, 3.2429830078035593, 1.9373728288337588, 1.2534322100691497, 0.6219074630644172, 0.17266729177208617, 0.3006849013036117, 0.15316241886466742, 0.09796229103812948, 0.18098808825016022, 0.26235914847347885, 0.26317660929635167, 0.4996252153068781, 0.7674897043034434, 0.8809249580372125, 1.0153626347891986, 0.4132454004138708, 0.23757200979162008, 0.20949450001353398, 0.15177038731053472, 0.15265410707797855, 0.12006845834548585, 0.2017534544575028, 0.16186654946068302, 0.15284624911146238, 0.16798762022517622, 0.09288043482229114, 0.19686363637447357, 0.1573614458902739, 0.09749476026627235, 0.06514075066661462, 0.08821652649203315, 0.22177615348482504, 0.12726104934699833, 0.13125479832524434, 0.12919980625156313, 0.2351814927533269, 0.14017538371263072, 0.16758766199927777, 0.1585521179367788, 0.15296913392376155, 0.11286602646578103, 0.16444938664790243, 0.14149293332593516, 0.18779163801809773, 0.1007962338917423, 0.12898335146019235, 0.13819025742122903, 0.11630896828137338, 0.14941669563995674, 0.13717526657273993, 0.08916602280805819, 0.14699493418447673, 0.13697666785446927, 0.10174955968977883, 0.07121427945094183, 0.14540443749865517, 0.21034232951933518, 0.24487232352839783, 0.13630426721647382, 0.2306769383721985, 0.1828260169713758, 0.16281060583423823, 0.15153095562709495, 0.15133651293581352, 0.1519430405460298, 0.12067724950611591, 0.178427426435519, 0.2012727505643852, 0.08591133417212404, 0.08529192287824117, 0.2829893695889041, 0.11186497315065935, 0.1965269833453931, 0.18781437742291018, 0.25115687458310276, 0.17079532815841958, 0.1368012686725706, 0.13608010893221945, 0.10128883441211656, 0.22355598688591272, 0.12169103065389208, 0.08002888615010306, 0.14535429800162092, 0.18173529737396166, 0.24428230128251016, 0.14498825592454523, 0.10795667505590245, 0.13037185039138421, 0.22732580022420734, 0.10549084487138316], [0.033551535379956476, 0.004567046926240437, 0.08995482930913568, 0.039315425310633145, 0.02731528144067852, 0.06996650656219572, 0.06296484047197737, 0.04083227497176267, 0.01215848385982099, 0.05010689819755498, 0.05225402048381511, 0.053504227616940625, 0.07649375475011766, 0.06600661436095834, 0.07447132069501095, 0.09529006958473474, 0.0758078989747446, 0.03349628248543013, 0.03258051678130869, 0.056156722785090096, 0.020309585488575976, 0.05628616076137405, 0.027937986014876515, 0.02727088245592313, 0.053714633904746734, 0.024853431023075245, 0.014101473789196461, 0.065737741679186, 0.008895703958842205, 0.009635850619815756, 0.03341041228850372, 0.03898472430591937, 0.06333011071546935, 0.08452846814179793, 0.06796434056013823, 0.020319060859037563, 0.03207526635378599, 0.0387803516787244, 0.082114966789959, 0.05733320125727914, 0.07816760946298018, 0.006837710361651261, 0.004974720241079922, 0.06376637480570935, 0.030709221100551076, 0.04462673132366035, 0.021553488077188376, 0.05674740554240998, 0.04964621373801492, 0.04583557114528958, 0.033293950764345936, 0.015507735097344266, 0.026540071085037198, 0.04555626386718359, 0.10484187383553945, 0.05551847207243554, 0.024575044008088298, 0.01721835487842327, 0.022470710246125236, 0.03019069550646236, 0.008691085495229345, 0.042749498461489566, 0.07933146771392785, 0.05601539189228788, 0.031191576272249222, 0.06595022598048672, 0.033538484713062644, 0.0588166913803434, 0.02010774358495837, 0.04082444902451243, 0.03762334345083218, 0.1219158865569625, 0.04984996667189989, 0.030023580548004247, 0.675195031799376, 2.2030308237299323, 3.583357580937445, 8.455733768641949, 15.267335660755634, 21.73046015202999, 20.328945256769657, 18.020553924143314, 28.922946006059647, 28.4686366841197, 31.60313978791237, 25.473565198481083, 18.705178387463093, 15.727589763700962, 8.830192275345325, 4.377220720052719, 3.563868901692331, 2.469823295250535, 2.4413492856547236, 3.2982099568471313, 3.4318829840049148, 5.030269827693701, 6.461459705606103, 6.725028762593865, 6.9170671328902245, 8.989371433854103, 12.097932379692793, 8.68344034999609, 4.906379850581288, 0.8907198230735958, 0.1463710403186269, 0.07280643112608232, 0.02214492968050763, 0.01055878175975522, 0.05218710102781188, 0.03186480069416575, 0.025220100214937702, 0.048497792158741504, 0.018841860437532887, 0.10032321122707799, 0.007218786495286622, 0.07122812050511129, 0.05469408701173961, 0.03943671450542752, 0.017939976605703123, 0.03906179263140075, 0.02554007533035474, 0.07069515457260422, 0.04254304039932322, 0.04218370362650603, 0.029626540817844216, 0.028690935650956817, 0.06432951646274887, 0.03070333958021365, 0.026243686988891568, 0.013366215098358225, 0.03793251846218482, 0.03488862203084864, 0.0428250268305419, 0.05636468740704004, 0.06088856731366832, 0.05214919954596553, 0.052601178613258526, 0.021578045743808616, 0.02874517551390454, 0.005368720412661787, 0.04362237545137759, 0.05413592516561039, 0.07498430801206268, 0.008985976946860319, 0.018995985956280492, 0.024026799110288266, 0.003390526012481132, 0.047364436177304015, 0.03341175557579845, 0.046973962598713115, 0.020860429758613463, 0.026175275816058274, 0.04755687135912012, 0.017304564607911743, 0.012550259907584405, 0.01750948271364905, 0.020374640298541635, 0.04616173391696066, 0.05784677487099543, 0.04527713099378161, 0.029494753944163676, 0.014212929527275264, 0.041184950969181955, 0.04977309872629121, 0.09227591101080179, 0.02778706471872283, 0.018381680638412945, 0.08677374687977135, 0.03648736026661936, 0.040487614169251174, 0.019997031849925406, 0.05308892919856589, 0.016410410244134255, 0.05091330844152253, 0.029863694107916672, 0.023634164026589133, 0.007143306829675566, 0.03179572529916186, 0.03358907692017965, 0.038334844139171764, 0.024540762351534795, 0.022083129188104067, 0.060231692405068316, 0.08577972170314752, 0.020614916174963582, 0.02324004835827509, 0.06855007319245487, 0.02438033599901246, 0.02629962080391124, 0.027280715912638698, 0.07542703620856628, 0.049587988542043604, 0.13328212313354015, 0.035395768645685166, 0.05180679858312942, 0.08629118761746213, 0.023295772516576108, 0.019713293950189836, 0.02664393094164552, 0.06530863189254887, 0.08441025143838488, 0.040504598218831234, 0.01819043103751028, 0.061788803577655926, 0.016048993602453265, 0.01485518319896073, 0.016300885945383925, 0.0280172659404343, 0.02551121320720995, 0.055359444668283686, 0.029086663635098375, 0.06739589996868744, 0.03599847790610511, 0.026480541564524174, 0.031870233215158805, 0.033290206629317254, 0.017412426495866384, 0.01337556244834559, 0.020254354858479928, 0.04902799359115306, 0.020727772716782056, 0.05319904536008835, 0.021655789423675742, 0.03590792475733906, 0.011904029252036707, 0.014065044542803662, 0.008810507260932354, 0.05348961472918745, 0.08516127520124428, 0.026600407691148575, 0.047881167629384436, 0.07889297718065791, 0.028718280082102865, 0.046183363810996525, 0.004776732403115602, 0.013444787200569408, 0.007470219170500059, 0.05387474855524488, 0.06300630426267162, 0.03450539181358181, 0.07661789379199035, 0.06494195898994803, 0.038047284178901464, 0.11226885733776726, 0.027892531325051095, 0.01845676000812091, 0.03826970583759248, 0.025133691960945725, 0.10044591792393476, 0.1897214149357751, 1.2050127144902945, 2.8640920389443636, 5.746990693733096, 12.054773345589638, 20.526352263987064, 27.216630466282368, 28.87592162936926, 28.452063873410225, 38.946310356259346, 37.71314352750778, 39.53158535063267, 32.17181347310543, 24.702848754823208, 19.80429980903864, 12.263321354985237, 5.528609286993742, 4.653901923447847, 3.081075120717287, 2.980107651092112, 3.7837500404566526, 3.463996248319745, 5.801559090614319, 7.519988855347037, 8.09515306726098, 9.14753794670105, 11.466570608317852, 17.050384283065796, 11.94621317088604, 7.191665573045611, 2.1717542270198464, 0.17690119973849505, 0.04743066914670635, 0.020956322659912985, 0.021106865460751578, 0.031072298297658563, 0.07805216839187779, 0.036666878368123434, 0.030212069359549787, 0.03471982796327211, 0.023944170243339613, 0.013065590555925155, 0.029825881683791522, 0.07371396641246974, 0.029410650058707688, 0.05913370718189981, 0.030206555202312302, 0.0257850842535845, 0.008384546963497996, 0.01586156420671614, 0.03706766408868134, 0.029933135010651313, 0.018715697187872138, 0.023568224205519073, 0.03804926200245973, 0.00966589832387399, 0.04881573564489372, 0.029250492734718136, 0.027175299401278608, 0.010057304225483676, 0.03165331087075174, 0.03877611401549075, 0.04536524247669149, 0.020660285517806187, 0.02949742010969203, 0.08901914436137304, 0.02864995982235996, 0.17639737052377313, 0.033405124486307614, 0.041975148997153156, 0.03146772942272946, 0.01435872443835251, 0.0632972558378242, 0.03460039784840774, 0.07497554324800149, 0.06807311714510433, 0.04208867161651142, 0.03417202278797049, 0.020394091989146546, 0.04990731613361277, 0.05754943340434693, 0.014215954706742195, 0.021459168528963346, 0.0501278750016354, 0.02952145085146185, 0.026252807983837556, 0.03213948439224623, 0.010655775822669966, 0.04898081155261025, 0.03527980064973235, 0.01899198021419579, 0.021284645081323106, 0.023249041332746856, 0.059575240520644, 0.06866237497888505, 0.06811970175476745, 0.06767399012460373, 0.018792578121065162, 0.044473681919043884, 0.030195562139851972, 0.016718674269213807, 0.05306427505274769, 0.030946732476877514, 0.12104171823011711, 0.0904670225281734, 0.14611651335144415, 0.10801025069667958, 0.16897099558264017, 0.17234004917554557, 0.18043288757326081, 0.1265924930339679, 0.10426404507597908, 0.16428241826361045, 0.1756274071522057, 0.20707873511128128, 0.13415071793133393, 0.1112047882634215, 0.15112295252038166, 0.17518115375423804, 0.17984290985623375, 0.09525544839561917, 0.1580353159806691, 0.2813098893966526, 0.11528399554663338, 0.0939525784633588, 0.112222436000593, 0.1409138206508942, 0.1985941466409713, 0.10774234280688688, 0.07648526458069682, 0.17807116586482152, 0.054673459017067216, 0.13713223685044795, 0.12273218962945975, 0.1433057922986336, 0.1803033976466395, 0.14881966752000153, 0.17030153278028592, 0.1528681127820164, 0.13600669568404555, 0.1308406057069078, 0.2045875828480348, 0.12940006738062948, 0.1416322641307488, 0.22450884513091296, 0.10448578395880759, 0.13945872138720006, 0.11591776739805937, 0.1800054105115123, 0.0876138432067819, 0.1828889807802625, 0.14039620233234018, 0.11723234099918045, 0.10500664546270855, 0.10267964884405956, 0.14698736427817494, 0.07534002681495622, 0.22236394928768277, 0.1620491177891381, 0.07453589496435598, 0.17859893676359206, 0.07714917504927143, 0.08852220969856717, 0.08731586349313147, 0.19140286924084648, 0.17174359993077815, 0.15608869231073186, 0.13682424556463957, 0.14537188690155745, 0.10128947265911847, 0.21238887595245615, 0.13335520983673632, 0.14188983390340582, 0.19814137718640268, 0.14763635757844895, 0.1515723526244983, 0.6063765683211386, 1.6755623649805784, 4.176686480641365, 7.809173762798309, 14.761866834014654, 23.7458948045969, 32.12689608335495, 34.06821571290493, 36.43492251634598, 43.68031293153763, 43.99687774479389, 45.19724853336811, 40.12779615819454, 30.769774205982685, 23.932031616568565, 17.40374442189932, 8.51930245757103, 6.6957617830485106, 4.638583995401859, 4.868457885459065, 5.294627342373133, 5.0181242544204, 8.02861388772726, 9.400445725768805, 9.832208007574081, 12.207079622894526, 15.600668024271727, 21.564454659819603, 14.243554696440697, 9.435175862163305, 2.8135462012141943, 0.30616705713327974, 0.18311664200155064, 0.16198557510506362, 0.09134185136645101, 0.10063080175314099, 0.1639189588604495, 0.11566548913833685, 0.3230344410985708, 0.15236864739563316, 0.2183369075646624, 0.1109000772703439, 0.17161403578938916, 0.2194210814195685, 0.055243205788428895, 0.21490901650395244, 0.1317788881715387, 0.1309311477234587, 0.11328439737553708, 0.12779566284734756, 0.16514939517946914, 0.11226272719795816, 0.16314160369802266, 0.17493079765699804, 0.20654002495575696, 0.1028327910171356, 0.1574114221148193, 0.15191580372629687, 0.09866229956969619, 0.09730419158586301, 0.11507554110721685, 0.1977361793979071, 0.19768350175581872, 0.1505186513531953, 0.15799469081684947, 0.2087892816052772, 0.09276572847738862, 0.3460279869614169, 0.23773117078235373, 0.19105965562630445, 0.11966189500526525, 0.13482062495313585, 0.16905853932257742, 0.09551414623274468, 0.11288198264082894, 0.22983987000770867, 0.1722532624262385, 0.1654829757171683, 0.17208008968736976, 0.1279011814040132, 0.1222915542894043, 0.0871387128427159, 0.10912318277405575, 0.1350868184817955, 0.1300931442528963, 0.1172455883352086, 0.09881543432129547, 0.09599716562661342, 0.11271634270087816, 0.1666730985743925, 0.18226355809019879, 0.15056372940307483, 0.14438106038141996, 0.10786374332383275, 0.1884388946928084, 0.13583110354375094, 0.17609712725970894, 0.13601923797978088, 0.12600255984580144, 0.15085325605468825, 0.1377067036810331, 0.09939717419911176, 0.11248357550357468], [0.03501725848764181, 0.02948620811366709, 0.05989359589875676, 0.046187334301066585, 0.04816798544197809, 0.032747830264270306, 0.05359126669645775, 0.03081914986978518, 0.059885398877668194, 0.023277890468307305, 0.032514940612600185, 0.008089625825959956, 0.011850096452690195, 0.013434492684609722, 0.06879975393530913, 0.046698648075107485, 0.033382600304321386, 0.05822429055115208, 0.06972202827455476, 0.02899948911363026, 0.04356085140898358, 0.022025291764293797, 0.11386181053239852, 0.019637368532130495, 0.056783848704071715, 0.03525047839502804, 0.0317923299735412, 0.05577483956585638, 0.033515006871311925, 0.04288767522666603, 0.04633369324437808, 0.0430270913784625, 0.082012097700499, 0.03748662871657871, 0.04934622280416079, 0.06468254126957618, 0.011964019831793848, 0.05717395120882429, 0.03132173413177952, 0.07126730590243824, 0.11001843551639467, 0.027203940735489596, 0.06375125725753605, 0.0612673149589682, 0.02642390641995007, 0.0383236599736847, 0.07559957812190987, 0.0726929864322301, 0.026896502349700313, 0.058250232323189266, 0.0817108599585481, 0.02968238557514269, 0.021955618940410204, 0.031131814830587246, 0.04979266916052438, 0.029314707062439993, 0.0393419941974571, 0.046799153424217366, 0.027545239609025884, 0.0083611526133609, 0.02530401856347453, 0.03994822865934111, 0.07778512881486677, 0.0601771631045267, 0.04039132792968303, 0.021095877964398824, 0.06199646020832006, 0.07207280330476351, 0.03347853031300474, 0.08559975831303746, 0.4929023963632062, 2.8073981311172247, 3.422704339027405, 10.894961580634117, 17.290375605225563, 23.462796695530415, 36.37466534972191, 46.25410482287407, 51.26263506710529, 61.72101907432079, 69.13909882307053, 66.11465111374855, 68.76389175653458, 69.47517558932304, 77.29495838284492, 71.33941635489464, 60.28703302145004, 55.19415870308876, 45.21020203828812, 32.309423089027405, 22.99710128456354, 29.171897247433662, 17.93968666344881, 18.480758629739285, 26.794670708477497, 25.193527825176716, 34.31775212287903, 35.537011697888374, 40.7968832552433, 41.439956948161125, 46.78195349872112, 45.93979708850384, 31.109721064567566, 25.451488383114338, 13.27254245057702, 2.334176036529243, 0.09515077588730492, 0.08260827235062607, 0.10345068832975812, 0.03947192199120764, 0.08638587081804872, 0.0944585153774824, 0.056784869157127105, 0.04226338802254759, 0.054489465765072964, 0.07100636677932926, 0.0313815401023021, 0.012191740424896125, 0.03489870410703588, 0.029716535500483587, 0.03147338087728713, 0.05782079228083603, 0.026429029094288126, 0.050441187486285344, 0.039012992710922845, 0.03649611389846541, 0.018505318730603904, 0.006933570793989929, 0.06512858686619438, 0.0248638433549786, 0.029679352046514396, 0.017802222864702344, 0.03542644903063774, 0.03438824009208474, 0.04882703855400905, 0.05639500785036944, 0.00901998029803508, 0.059025591108365916, 0.06763282319298014, 0.024918441304180305, 0.03955339496314991, 0.008865279614838073, 0.03900903706380632, 0.05413727958512027, 0.049710309322108515, 0.08199470918043517, 0.02917256537330104, 0.031981893043848686, 0.0844591367058456, 0.012439788442861754, 0.01693018821242731, 0.047289453286794014, 0.0317111501499312, 0.08249144346336834, 0.047683897355454974, 0.04851770769164432, 0.05820589271024801, 0.059957776829833165, 0.034743220458040014, 0.037566027385764755, 0.02233830553450389, 0.11846112232888117, 0.0641993511817418, 0.05501502877450548, 0.02004876696446445, 0.029597932880278677, 0.07358829112490639, 0.025764786514628213, 0.00881288306118222, 0.01343375610304065, 0.047266836336348206, 0.03761270105314907, 0.02845908129529562, 0.06940812949324027, 0.07056552363792434, 0.017426920639991295, 0.07599293865496293, 0.01361794231343083, 0.060240286475163884, 0.03415722807403654, 0.06740329175954685, 0.07106357152224518, 0.026444369286764413, 0.04640154780645389, 0.02368080800806638, 0.03591660788515583, 0.05312037028488703, 0.019035729819734115, 0.008601287481724285, 0.041041746153496206, 0.09892104935715906, 0.016305305434798356, 0.040517600646126084, 0.06449856286053546, 0.06214284512680024, 0.017519228968012612, 0.051621985257952474, 0.029451325317495503, 0.11084272409789264, 0.06293174810707569, 0.008836651268211426, 0.017485965909145307, 0.04214189473714214, 0.05790012415673118, 0.03789852067711763, 0.02531414331315318, 0.07005169027252123, 0.06896626960951835, 0.02435516049445141, 0.006356693838824867, 0.05745602298702579, 0.045117483896319754, 0.06370642411638983, 0.026728704615379684, 0.05252176881185733, 0.08306783987791277, 0.07921262018498965, 0.01949885223439196, 0.05447707560961135, 0.09636321512516588, 0.05093627049063798, 0.05633146887703333, 0.04030719064758159, 0.09784695386770181, 0.028547018373501487, 0.04938327081617899, 0.02464323624735698, 0.03546294043189846, 0.08213064837036654, 0.06745379490894265, 0.08739034543395974, 0.02812667706166394, 0.058673616440501064, 0.013328486165846698, 0.0448251333727967, 0.041062459495151415, 0.0322163115197327, 0.019594680197769776, 0.03534093877533451, 0.007543832334704348, 0.03432373261603061, 0.013704506418434903, 0.10116915567778051, 0.11020302990800701, 0.06818246518378146, 0.22027190920198336, 0.7305375183932483, 3.942114617675543, 5.511927232146263, 12.735087890177965, 22.926417477428913, 31.312136203050613, 48.87989692389965, 59.43429797887802, 63.68231043219566, 74.47779715061188, 82.31720209121704, 80.29181957244873, 83.47418680787086, 82.64059513807297, 89.33714300394058, 83.08150067925453, 71.29665344953537, 65.64054295420647, 52.6925553381443, 38.519068881869316, 27.50423703342676, 35.186320915818214, 21.494851894676685, 23.27009193599224, 32.51467667520046, 31.308131217956543, 42.850642651319504, 47.12906487286091, 53.008588179945946, 56.063438057899475, 58.52794401347637, 57.87613458931446, 41.943106949329376, 32.49259985983372, 17.715473994612694, 4.047602657228708, 0.08370283627300523, 0.1490262517472729, 0.11569501919439062, 0.03753738048544619, 0.08064030451350845, 0.056868976753321476, 0.038579541360377334, 0.025963342559407465, 0.03111822054052027, 0.05531160582904704, 0.06823770323535427, 0.06361583014950156, 0.06695616262732074, 0.03884528217895422, 0.10578094297670759, 0.030602541082771495, 0.07003481383435428, 0.003351905111230735, 0.04327926944824867, 0.07582847130834125, 0.019500946946209297, 0.028713732572214212, 0.05711277226509992, 0.05603500314464327, 0.022413431288441643, 0.008646143814985408, 0.051927928216173314, 0.02010544849326834, 0.07767510542180389, 0.01818664422899019, 0.02963771014037775, 0.028819553554058075, 0.060050007232348435, 0.03336697438498959, 0.04567619864246808, 0.06074454984627664, 0.009002455408335663, 0.032639406199450605, 0.013542247888835846, 0.04200245632091537, 0.040014506157604046, 0.11047945765312761, 0.02106166495650541, 0.048080649503390305, 0.022463465029431973, 0.03172207456373144, 0.0693326085456647, 0.03874594571243506, 0.0119469448691234, 0.04299411033571232, 0.017538381944177672, 0.046229462313931435, 0.06782016353099607, 0.04466899663384538, 0.07008031490840949, 0.04261946305632591, 0.07360350515227765, 0.03696054620377254, 0.04833754392166156, 0.08218230927013792, 0.06016183404426556, 0.024500554645783268, 0.001144706202467205, 0.08488982726703398, 0.06986325897742063, 0.019524059280229267, 0.08109440983389504, 0.014866591864119982, 0.016761694714659825, 0.030421342016779818, 0.12078468280378729, 0.12045142881106585, 0.12204660102725029, 0.1328838273184374, 0.1936419733101502, 0.09249315990018658, 0.1294375309953466, 0.1859261459321715, 0.13987099926453084, 0.14374348131241277, 0.15295657678507268, 0.10549571336014196, 0.06749699532520026, 0.13045986910583451, 0.1761287427507341, 0.08665774919791147, 0.11571847106097266, 0.13697567337658256, 0.12314150633756071, 0.061115371354389936, 0.11601707417867146, 0.09898566815536469, 0.27362109103705734, 0.18868608924094588, 0.11024360312148929, 0.1368788824765943, 0.12941216438775882, 0.18085393763612956, 0.08547316276235506, 0.09781211745576002, 0.20119014952797443, 0.13011727889534086, 0.11500084394356236, 0.088659596076468, 0.12424792235833593, 0.16772696311818436, 0.14752549555851147, 0.11835311757749878, 0.1119325753825251, 0.15245472168317065, 0.2117874097893946, 0.11739113833755255, 0.24877214629668742, 0.2511708269594237, 0.15911471040453762, 0.14869146893033758, 0.19207319186534733, 0.23584718437632546, 0.0883819512091577, 0.1536715470138006, 0.20044086239067838, 0.14299511443823576, 0.11584278821828775, 0.24187747563701123, 0.15230428834911436, 0.15953111462295055, 0.20436933205928653, 0.16520158300409093, 0.12269241051399149, 0.09712996499729343, 0.11709755213814788, 0.10383990025729872, 0.12640808417927474, 0.17121701646829024, 0.18934035178972408, 0.22066132893087342, 0.17506834730738774, 0.23487991362344474, 0.2806107862852514, 0.4429719178006053, 1.4087625313550234, 4.891679864376783, 6.516293613240123, 14.888153057545424, 26.512809433043003, 35.08436858654022, 56.859445944428444, 68.06044310331345, 74.17750686407089, 84.10317465662956, 93.29377949237823, 92.62804001569748, 95.57276800274849, 93.23986038565636, 99.49620947241783, 92.55855694413185, 83.39698255062103, 75.87475419044495, 62.79366351664066, 46.42839387059212, 36.198571398854256, 41.635213270783424, 29.779418148100376, 30.91081503778696, 39.032326340675354, 38.71926113963127, 52.136945351958275, 56.64982259273529, 63.89335110783577, 64.67059940099716, 68.7183777987957, 66.99538305401802, 49.86348934471607, 37.10491396486759, 20.024448595941067, 4.58026472479105, 0.25346370704937726, 0.33226506609935313, 0.2589082805206999, 0.12641854846151546, 0.2542444464052096, 0.22234215983189642, 0.14372590725542977, 0.15843855449929833, 0.30929135042242706, 0.11718022738932632, 0.1179160297033377, 0.10996632932801731, 0.14817439980106428, 0.10150461384910159, 0.1577282152720727, 0.1024993737519253, 0.15258845669450238, 0.16993140889098868, 0.08804151322692633, 0.14350295125041157, 0.07661707000806928, 0.1766952537582256, 0.16032337211072445, 0.11013892319169827, 0.08692783158039674, 0.08303947499371134, 0.1704668832826428, 0.08410560723859817, 0.20240327896317467, 0.2137223817408085, 0.10927590192295611, 0.09238620157702826, 0.15421393822180107, 0.2366851136321202, 0.12033655177219771, 0.08925651287427172, 0.12510101369116455, 0.14673237717943266, 0.14726232999237254, 0.14598037378164008, 0.19761991454288363, 0.14444314845604822, 0.22642547119176015, 0.11171925245434977, 0.13994763343362138, 0.14635711762821302, 0.14214655762771145, 0.13288553425809368, 0.13538384082494304, 0.11949799911235459, 0.1373687296290882, 0.1256629975978285, 0.14735450473381206, 0.1381467972532846, 0.18898569425800815, 0.1360047364141792, 0.14251834392780438, 0.1667028438532725, 0.1307805659598671, 0.14605482603656128, 0.1489213714376092, 0.10094352794112638, 0.059756562041002326, 0.2070753657608293, 0.16741410334361717, 0.09242621075827628, 0.16883878939552233, 0.1318052047281526, 0.1546780180069618, 0.12249606050318107], [0.01733009634335758, 0.0900285023089964, 0.06432766851503402, 0.006170026999825495, 0.014844131692370865, 0.039265322920982726, 0.08020427791052498, 0.02032711501669837, 0.09325892271590419, 0.045291628848644905, 0.12537761213025078, 0.045123680829419754, 0.02619575352582615, 0.02914879994932562, 0.0713495358650107, 0.03948742545617279, 0.017376198557030875, 0.06896149759995751, 0.022223794003366493, 0.08716282522073016, 0.038073151736170985, 0.0405782378220465, 0.027513093482411932, 0.028910077016917057, 0.056007706953096204, 0.02527321943489369, 0.04976770702342037, 0.008760980035731336, 0.028900345605507027, 0.019901680716429837, 0.03880052696331404, 0.00944305178563809, 0.022632978980254848, 0.02891548356274143, 0.017125888844020665, 0.012990622508368688, 0.032359456963604316, 0.0461911155434791, 0.03872243076330051, 0.04554319093585946, 0.016696706697985064, 0.024625801343063358, 0.014581217528757406, 0.02468070357281249, 0.040160212010960095, 0.08067560847848654, 0.023728982669126708, 0.013894707735744305, 0.031012364306661766, 0.038595883452217095, 0.0825278161210008, 0.008768576844886411, 0.03810874142800458, 0.020419202555785887, 0.06700151527184062, 0.1151900619152002, 0.030814696983725298, 0.027590577410592232, 0.03844506049063057, 0.026296644791727886, 0.01675601914030267, 0.0772125693038106, 0.08027679316001013, 0.09159665292827412, 0.03564406157238409, 0.06619022169616073, 0.7143753825221211, 2.1172136161476374, 3.6311267176643014, 5.08214226923883, 11.591982878744602, 26.273564770817757, 37.87916801869869, 50.57973951101303, 56.000342443585396, 63.032252714037895, 68.44787791371346, 71.14647790789604, 62.18143276870251, 65.09832724928856, 65.83749398589134, 70.6266961991787, 64.52876821160316, 67.2086276113987, 55.53041025996208, 69.44274812936783, 69.49339181184769, 70.546003729105, 66.20926603674889, 70.97003057599068, 60.6424355506897, 59.11111772060394, 61.15982338786125, 56.947719007730484, 60.22763080894947, 67.13873416185379, 75.0281672179699, 66.45282536745071, 72.14771658182144, 71.73730820417404, 70.35398483276367, 71.05198457837105, 64.03387516736984, 57.78652019798756, 52.311682775616646, 27.58508339524269, 6.8792947847396135, 0.6755891419015825, 0.10684560576919466, 0.0894432223867625, 0.047026165266288444, 0.02257229727547383, 0.0642951847112272, 0.026226231675536837, 0.021584070127573796, 0.04374295960587915, 0.01805674055503914, 0.03582587662094738, 0.012333435897744494, 0.013498004755092552, 0.03814904375758488, 0.03243426916014869, 0.004463283084987779, 0.08815837922156788, 0.012698809114226606, 0.04637658938008826, 0.04986371124687139, 0.062002746199141257, 0.03336514870170504, 0.007428291073665605, 0.011060062624892453, 0.023432353664247785, 0.02061290495475987, 0.07570367175503634, 0.02401533849479165, 0.02405014707619557, 0.04319229345128406, 0.04275178798707202, 0.025248318524973, 0.042343899913248606, 0.02928670397523092, 0.050204190047224984, 0.04784388584084809, 0.041118035223917104, 0.03985973497037776, 0.028353612833598163, 0.03386766060430091, 0.052456341072684154, 0.04266894204192795, 0.01500565827882383, 0.0305899468366988, 0.036604025881388225, 0.022209602284419816, 0.09604731996660121, 0.04057768121128902, 0.04830911224416923, 0.04058965205331333, 0.04605063069902826, 0.02390329089394072, 0.037909667735220864, 0.0587728044774849, 0.05281665005895775, 0.041838207907858305, 0.031142167790676467, 0.015145962224778486, 0.02892845259339083, 0.021288751013344154, 0.0162745322813862, 0.009438564575248165, 0.05170735821593553, 0.025345777357870247, 0.016108871932374313, 0.06092959323723335, 0.04755175054015126, 0.03413746468140744, 0.02847205218131421, 0.03154270860250108, 0.07426074371323921, 0.026868465865845792, 0.027024858645745553, 0.0580091642041225, 0.030009188449184876, 0.02286026912770467, 0.03341062751132995, 0.030519390857079998, 0.08050853619351983, 0.038800564070697874, 0.012722458577627549, 0.029530384454119485, 0.04963062492606696, 0.04792786727193743, 0.028763141053786967, 0.05177499013370834, 0.02339843566005584, 0.03710545424837619, 0.05452010904264171, 0.057608645656728186, 0.12521238037152216, 0.07360533825703897, 0.013206654275563778, 0.02119234974088613, 0.03249029759899713, 0.037267520747263916, 0.015177759541984415, 0.039705245799268596, 0.09802280575968325, 0.011896386058651842, 0.03666495620564092, 0.016231253939622547, 0.030023634353710804, 0.07047255479847081, 0.028424692027329, 0.030806004579062574, 0.11049908003769815, 0.05348517297534272, 0.010560218743194127, 0.009072639386431547, 0.036499230918707326, 0.02680103247257648, 0.029062888934276998, 0.06411783368093893, 0.06332711243885569, 0.04256489293766208, 0.01792209270206513, 0.0204085100631346, 0.00630833271316078, 0.02943286996014649, 0.02871079366741469, 0.04792694700881839, 0.03176917496602982, 0.06097931713156868, 0.027699277925421484, 0.019701532764884178, 0.11124265263788402, 0.04053003904118668, 0.04499730792304035, 0.023374929987767246, 0.028463471098802984, 0.13525197602575645, 0.08201521472074091, 0.06749496926204301, 0.07756364226224832, 1.1971334810368717, 2.82206391915679, 4.435684382915497, 6.807660553604364, 15.186091270297766, 31.6842445358634, 49.27402317523956, 63.099224120378494, 67.74139702320099, 78.39046239852905, 80.71975260972977, 84.81917023658752, 77.72707119584084, 77.56478950381279, 74.92668986320496, 79.8024134337902, 73.8893911242485, 76.26892223954201, 66.2079057097435, 79.70569342374802, 80.18967345356941, 82.09187418222427, 75.41886985301971, 79.7160592675209, 70.84152907133102, 70.1056757569313, 68.93846198916435, 66.42501085996628, 70.04421025514603, 77.19945430755615, 86.33370816707611, 77.32908815145493, 82.32914105057716, 82.6844371855259, 84.37801390886307, 79.31974813342094, 77.26771384477615, 68.37115243077278, 60.84988921880722, 36.532702669501305, 11.68133033439517, 2.4170856876298785, 0.07642403739737347, 0.10696325844037347, 0.0629586583818309, 0.004814993826585123, 0.04779560913448222, 0.049334033028571866, 0.03775713783397805, 0.030856270241201855, 0.031086720082385, 0.03460662817815319, 0.046415771066676825, 0.006704171555611538, 0.09079308510990813, 0.0353901617199881, 0.07803390413755551, 0.01880099778645672, 0.02566100643889513, 0.011801514538092306, 0.027759150689234957, 0.0598102156072855, 0.07093687207088806, 0.0116832208368578, 0.03067506189836422, 0.06506310717668384, 0.04936404919135384, 0.09037197567522526, 0.021119999619259033, 0.014767214579478605, 0.058856563264271244, 0.011655778071144596, 0.02246348358312389, 0.06655034143477678, 0.028503899593488313, 0.01848960375355091, 0.024682840958121233, 0.055172928114188835, 0.0069495418119913666, 0.03460806794464588, 0.019991462031612173, 0.012759582659782609, 0.03693468606797978, 0.026548192035988905, 0.02504396816220833, 0.0059991275520587806, 0.043495672289282084, 0.037826836633030325, 0.054997658808133565, 0.05120436762808822, 0.032012061346904375, 0.08274997060652822, 0.019972372137999628, 0.017514547871542163, 0.05178957333555445, 0.03170928364852443, 0.046542370328097604, 0.05358122172765434, 0.017020899067574646, 0.09939686249708757, 0.05092963940114714, 0.02438605053612264, 0.03188769223925192, 0.045339953794609755, 0.0290990296707605, 0.05114761930599343, 0.05621984615572728, 0.03873785259202123, 0.06490041356300935, 0.04494069689826574, 0.1857559714699164, 0.18737624312052503, 0.15026623208541423, 0.10822367752552964, 0.10047118805232458, 0.08102092979243025, 0.13810689939418808, 0.15282034815754741, 0.11207234405446798, 0.20475665893172845, 0.1378602540353313, 0.11803225745097734, 0.14717333164298907, 0.09461530149565078, 0.20145245420280844, 0.14552678796462715, 0.1367983891395852, 0.18546740961028263, 0.13127508864272386, 0.11380945943528786, 0.1954008633038029, 0.1732773965341039, 0.1625523087568581, 0.15471864317078143, 0.22363846917869523, 0.11567532259505242, 0.18875141307944432, 0.05488958355272189, 0.13556931837229058, 0.21284465852659196, 0.07769426767481491, 0.11372351873433217, 0.1948388942400925, 0.1216795422078576, 0.11827376714791171, 0.13871410978026688, 0.14793182141147554, 0.12725024367682636, 0.17001816595438868, 0.10509083469514735, 0.10288314573699608, 0.10749051725724712, 0.08776087750447914, 0.17826908180722967, 0.16940405359491706, 0.18524524028180167, 0.13800047541735694, 0.13120752351824194, 0.16768623405369, 0.1800440764054656, 0.1839601225219667, 0.13030087138758972, 0.20612566906493157, 0.15783383772941306, 0.11237784172408283, 0.1648161411867477, 0.14180873200530186, 0.1500236091669649, 0.13805327180307359, 0.21962137223454192, 0.11055572816985659, 0.14684300171211362, 0.18106476694811136, 0.17329882975900546, 0.14161011844407767, 0.2763540646992624, 1.5134482202120125, 3.611731845885515, 6.342450566589832, 9.481209442019463, 18.983978927135468, 37.1060349047184, 54.845367819070816, 69.63550418615341, 79.48626279830933, 88.72718453407288, 93.37472274899483, 98.28281298279762, 93.76576736569405, 90.78485772013664, 88.45663145184517, 93.56547251343727, 86.58729895949364, 91.26465037465096, 78.50945681333542, 94.0609735250473, 93.07918980717659, 91.65352910757065, 87.05745533108711, 91.38423755764961, 82.42274522781372, 81.57158330082893, 80.64327791333199, 77.62135326862335, 80.87397113442421, 88.6297957599163, 96.40746921300888, 89.9015799164772, 91.8451376259327, 93.36993500590324, 95.52839398384094, 91.63023635745049, 90.12927889823914, 78.15869763493538, 70.23348569869995, 43.797806426882744, 14.131401814520359, 2.507678051479161, 0.26116767490748316, 0.23901521984953433, 0.15937211690470576, 0.10032669189968146, 0.1348708535078913, 0.1615404200856574, 0.17810646240832284, 0.09516059450106695, 0.12040808738674968, 0.0857159860606771, 0.147287548170425, 0.08507128979545087, 0.13098406285280362, 0.14173454692354426, 0.1404500228818506, 0.17129918705904856, 0.13007356639718637, 0.12807815393898636, 0.2061662942287512, 0.1389812829438597, 0.14806386432610452, 0.09237796373781748, 0.1076261447451543, 0.15914761723252013, 0.22269070206675678, 0.23845276096835732, 0.1352033653529361, 0.07840010948712006, 0.14020365953911096, 0.06980243255384266, 0.12371196557069197, 0.09334040310932323, 0.11536624777363613, 0.13923941674875095, 0.12098617589799687, 0.15503047878155485, 0.09841460778261535, 0.14220728015061468, 0.09292245522374287, 0.13642437639646232, 0.09349589789053425, 0.08967462403234094, 0.12822873570257798, 0.11904764163773507, 0.10690985349356197, 0.21318371611414477, 0.12883701478131115, 0.2099346974864602, 0.12041599868098274, 0.10842894815141335, 0.0867423095041886, 0.07960204733535647, 0.19648361223516986, 0.17111437744461, 0.25947471731342375, 0.15296800585929304, 0.14989204122684896, 0.11341449586325325, 0.16689991374732926, 0.12639566062716767, 0.11724690193659626, 0.09924171652528457, 0.09835243065026589, 0.09941621028701775, 0.23492528853239492, 0.1648213213775307, 0.11025879488443024, 0.2008071864838712], [0.01841765253630001, 0.0013842663702234859, 0.06548528530402109, 0.04150222652242519, 0.015816794148122426, 0.0080153192175203, 0.03998857180704363, 0.039571610977873206, 0.0369581861741608, 0.025724142797116656, 0.038481184528791346, 0.022375117914634757, 0.04346828704001382, 0.05084438518679235, 0.026447447344253305, 0.034984659650945105, 0.020357539360702503, 0.04473043532925658, 0.06103680017986335, 0.042817204594030045, 0.055880521395010874, 0.039536689218948595, 0.014606902332161553, 0.03865482853143476, 0.017302456908510067, 0.06631937765632756, 0.02476803580066189, 0.027579365414567292, 0.07426044685416855, 0.022614043082285207, 0.049546287264092825, 0.029296672873897478, 0.09153883220278658, 0.0035751658606386627, 0.049397538605262525, 0.03532521266606636, 0.058461911394260824, 0.0636614128598012, 0.033499937562737614, 0.02305992726178374, 0.0490346024162136, 0.03268029111495707, 0.04811131504538935, 0.043552891875151545, 0.018947366006614175, 0.01997989194933325, 0.006858139831820154, 0.04550251011096407, 0.04098310906556435, 0.022498527796415146, 0.04140409975661896, 0.031874615597189404, 0.06279135603108443, 0.059579274093266577, 0.021507022211153526, 0.037681082540075295, 0.0537586618156638, 0.06300678665866144, 0.13584559026639909, 0.4005743865855038, 0.6303799990564585, 1.2136344518512487, 1.899240450002253, 2.573262294754386, 5.843575811013579, 8.665542360395193, 16.869135908782482, 17.846614457666874, 30.310247763991356, 42.671155482530594, 49.75878596305847, 56.58762753009796, 65.4282483458519, 64.92546692490578, 67.61686250567436, 64.52273413538933, 56.466170847415924, 54.44295421242714, 55.55307224392891, 54.68905560672283, 50.88219188153744, 50.64714029431343, 64.50801372528076, 43.985706344246864, 44.8052653670311, 56.336035430431366, 40.92983812093735, 46.36225841939449, 56.311758533120155, 59.39936265349388, 63.87256622314453, 68.87916997075081, 65.26690900325775, 64.31911066174507, 56.62933029234409, 64.37834948301315, 65.29218524694443, 68.63903045654297, 60.7404512912035, 58.91469486057758, 57.98761300742626, 65.63878744840622, 66.40257686376572, 67.46663376688957, 70.22885754704475, 61.116007938981056, 50.23607835173607, 26.172436997294426, 3.3133008470758796, 0.41157865547575057, 0.06316909435554408, 0.08193462490453385, 0.027952495001954958, 0.06429217159166001, 0.023882636924099643, 0.030336774289025925, 0.06291457480983809, 0.06024017515301239, 0.05647431746183429, 0.029412800431600772, 0.052193502051522955, 0.010685377310437616, 0.04407862186781131, 0.03251255089708138, 0.03188085705915, 0.08027428470086306, 0.027828957099700347, 0.01837250398239121, 0.02072339404548984, 0.037169323477428406, 0.07054412009892985, 0.05741755376220681, 0.07299938952201046, 0.04324358327721711, 0.023574849728902336, 0.026684986551117618, 0.0056497350942663616, 0.009375691679451847, 0.040181270451284945, 0.06064974790206179, 0.022844268423796166, 0.05016632938350085, 0.025460615433985367, 0.04560440698696766, 0.0271945340136881, 0.025340166721434798, 0.013616442247439409, 0.032661659497534856, 0.027804143392131664, 0.024408181379840244, 0.017061809958249796, 0.0037404586146294605, 0.02334120679734042, 0.07674457840039395, 0.023430624460161198, 0.05994347564410418, 0.04814881947822869, 0.03916244641004596, 0.05580533070315141, 0.040452718385495245, 0.04451959488505963, 0.07359821363934316, 0.028786340590158943, 0.0402578341163462, 0.009072241409739945, 0.06691331102047116, 0.0601529950654367, 0.04814347230421845, 0.04638774385966826, 0.04151033819653094, 0.04689555469667539, 0.05851817360962741, 0.008792471217020648, 0.021597681115963496, 0.03550226683728397, 0.05523288251424674, 0.02724684058193816, 0.011287242377875373, 0.006885915172460955, 0.030944428108341526, 0.04366106732049957, 0.012886213462479645, 0.022076460991229396, 0.06721250043483451, 0.10307749937055632, 0.03513463285344187, 0.02072776715067448, 0.030288208145066164, 0.029924036280135624, 0.009156821197393583, 0.012285225056984928, 0.07283681465196423, 0.0416752953606192, 0.020713803642138373, 0.0494697384419851, 0.030685748824907932, 0.06452175497543067, 0.07296057519852184, 0.01333591970251291, 0.06440682598622516, 0.018302465650776867, 0.06639280574745499, 0.0529510233172914, 0.028991073158977088, 0.037576792237814516, 0.03505026179482229, 0.06466936072683893, 0.09549775961204432, 0.056600901880301535, 0.008240327260864433, 0.0689975956629496, 0.08097948084468953, 0.09677682886831462, 0.05003061654861085, 0.05652088351780549, 0.06964297470403835, 0.012885729211120633, 0.03983099159086123, 0.04943330270180013, 0.07660869116079994, 0.09669272127212025, 0.0033270951144004357, 0.03642344650870655, 0.031210011220537126, 0.01100306475564139, 0.016495976160513237, 0.03778685713768937, 0.06499174967757426, 0.034970488341059536, 0.048587669953121804, 0.03468861694273073, 0.07252680472447537, 0.01961473117262358, 0.05188274626561906, 0.26286760868970305, 0.8386570948641747, 1.0237231361679733, 1.313766916282475, 2.326641040854156, 3.0103195924311876, 6.298406179994345, 9.589724019169807, 20.37304189056158, 23.69669884443283, 41.35080613195896, 55.90721324086189, 64.13223668932915, 71.21729090809822, 76.44733026623726, 76.37223109602928, 79.26532745361328, 74.52668532729149, 67.72223845124245, 65.42783796787262, 69.25090402364731, 66.32139801979065, 60.85766360163689, 60.53401216864586, 73.88353943824768, 52.06515580415726, 53.40542368590832, 65.71244269609451, 51.512011885643005, 54.769767075777054, 66.92420527338982, 67.43516385555267, 72.55259245634079, 77.78697118163109, 76.10473304986954, 71.74011245369911, 66.98975175619125, 71.65155440568924, 73.42756390571594, 77.38524153828621, 70.38614630699158, 66.82868599891663, 64.34732034802437, 72.92869627475739, 73.85625690221786, 75.48376277089119, 79.24907192587852, 70.30379712581635, 62.07262180745602, 37.330606654286385, 6.919395457953215, 1.0407515661790967, 0.12879673100542277, 0.09665061923442408, 0.039168969888123684, 0.037657144566765055, 0.04523393799900077, 0.046103215572657064, 0.010395012959634187, 0.06146611776784994, 0.03683912713313475, 0.07357043505180627, 0.019462880336504895, 0.03394514453248121, 0.06581384892342612, 0.16027256468078122, 0.09181542322039604, 0.032047350468928926, 0.06248953199246898, 0.04225754732033238, 0.057885507558239624, 0.02292645200213883, 0.03698136715684086, 0.021253059276205022, 0.08256931701907888, 0.031179379075183533, 0.03668002180347685, 0.09250512332073413, 0.0686109738308005, 0.012349401349638356, 0.0371861887833802, 0.036190612518112175, 0.016841603610373568, 0.06226912155398168, 0.03974571511207614, 0.016873764579941053, 0.03842288511805236, 0.03844745391688775, 0.02807917961035855, 0.0014775667409594462, 0.05743148758483585, 0.02700547374843154, 0.03191332230926491, 0.02158479743229691, 0.014169484202284366, 0.02393943905190099, 0.048536602771491744, 0.023601446446264163, 0.060831644586869515, 0.022747837465431076, 0.021364414824347477, 0.0734068731253501, 0.043671850726241246, 0.048653197882231325, 0.07980246431543492, 0.033518828931846656, 0.07729709992418066, 0.025468619496678002, 0.03280692006228492, 0.024057217888184823, 0.06049276140402071, 0.03155403748678509, 0.04412041591422167, 0.019714655791176483, 0.034022543113678694, 0.06417002892703749, 0.035133055789629, 0.06977050536079332, 0.17023623862769455, 0.10758638789411634, 0.12803735065972432, 0.149744012451265, 0.17369394918205217, 0.09086022721021436, 0.16529969492694363, 0.1721607759827748, 0.2901190932607278, 0.10556341949268244, 0.0770440572523512, 0.08833400104776956, 0.18574616027763113, 0.1120640394219663, 0.12165034611825831, 0.12294034720980562, 0.16612383507890627, 0.12195841904031113, 0.13270507362904027, 0.15719551651272923, 0.13663148012710735, 0.18905021657701582, 0.12830275751184672, 0.13928732980275527, 0.12313270446611568, 0.2095864075818099, 0.1510186807718128, 0.15414079214679077, 0.19462258787825704, 0.12099586834665388, 0.14908234326867387, 0.16650577395921573, 0.17704842699458823, 0.0838777530589141, 0.17088009626604617, 0.1639575802255422, 0.12279104194021784, 0.13291964336531237, 0.133153612841852, 0.22534076299052685, 0.1801543150213547, 0.07081049916450866, 0.16293310472974554, 0.13695131608983502, 0.1776101437280886, 0.19267725554527715, 0.15302172250812873, 0.09292612885474227, 0.13327829365152866, 0.1209514656511601, 0.12071027507772669, 0.21599883068120107, 0.20386223739478737, 0.16686917399056256, 0.09379012233694084, 0.22174240060849115, 0.15905419568298385, 0.21421227342216298, 0.5156827974133193, 1.1333913076668978, 1.4141900651156902, 2.2379445377737284, 3.495673961006105, 4.595166575163603, 8.651906792074442, 13.259422704577446, 25.216053016483784, 30.594026036560535, 49.536486491560936, 65.88598698377609, 75.47923341393471, 84.05944660305977, 89.90401178598404, 88.80160734057426, 93.72479796409607, 87.62622401118279, 82.84719005227089, 76.2261289358139, 78.02480041980743, 74.79288384318352, 71.85495749115944, 71.96195214986801, 84.47490870952606, 63.165021389722824, 63.411601558327675, 75.02340987324715, 63.47063519060612, 66.1146131157875, 77.8239431977272, 78.99561032652855, 81.77038103342056, 87.58098363876343, 86.99298039078712, 83.12773659825325, 78.51361379027367, 83.66421461105347, 84.9891047179699, 87.97535687685013, 80.66286966204643, 78.42906832695007, 76.86401590704918, 84.38106134533882, 85.37948817014694, 86.05215847492218, 90.01694172620773, 82.96898111701012, 72.040835916996, 42.41650074720383, 8.465763330459595, 1.0536036640405655, 0.209670047624968, 0.22595837828703225, 0.08781487616943195, 0.1277074808604084, 0.08627935036201961, 0.1568254965241067, 0.14939750370103866, 0.13532381592085585, 0.12651079741772264, 0.12088483563275076, 0.10258933689328842, 0.13460105314152315, 0.11546094581717625, 0.24502943619154394, 0.21434430149383843, 0.19708179810550064, 0.18223943829070777, 0.11901727295480669, 0.11942080833250657, 0.10554936321568675, 0.16563636279897764, 0.14487072941847146, 0.1289304660167545, 0.14587430603569373, 0.1605763257248327, 0.23146869119955227, 0.15954292961396277, 0.18581875716336071, 0.2086991403484717, 0.15934553317492828, 0.13009499962208793, 0.2089739279472269, 0.20484962034970522, 0.14762675418751314, 0.14861556206597015, 0.1609520602505654, 0.12446127497241832, 0.14215123315807432, 0.12141217608586885, 0.08931894975830801, 0.1754735450958833, 0.0680275121703744, 0.13133493543136865, 0.17326485423836857, 0.14986513095209375, 0.08455039860564284, 0.2129400838748552, 0.10470979381352663, 0.2616558299632743, 0.1554920055787079, 0.14103430090472102, 0.12436182718374766, 0.20162948610959575, 0.1304278676980175, 0.167024178954307, 0.18009463150519878, 0.18942455586511642, 0.19043427746510133, 0.11208667492610402, 0.09060655371285975, 0.15322655526688322, 0.16088554897578433, 0.0818991354026366, 0.11604936502408236, 0.09780233594938181, 0.14035764033906162], [0.011961883374169702, 0.010163502774958033, 0.04433994319697376, 0.05078122470877133, 0.019569727337511722, 0.060656178611679934, 0.03931629362341482, 0.0752353914140258, 0.06585840004845522, 0.08441986967227422, 0.0319261614640709, 0.022627119724347722, 0.016737997939344496, 0.05156568222446367, 0.051595408949651755, 0.01805133400921477, 0.046709435191587545, 0.026939502386085223, 0.0028103193653805647, 0.06596613020519726, 0.057410985755268484, 0.05273978953482583, 0.08115600066957995, 0.0501038182846969, 0.018491305127099622, 0.022056020388845354, 0.05194984383706469, 0.07791864118189551, 0.019291227145004086, 0.05410431338532362, 0.04958906094543636, 0.024687757686479017, 0.06390064416336827, 0.02782810177450301, 0.027534270666365046, 0.021430963206512388, 0.058940945455105975, 0.05049213221354876, 0.008818929709377699, 0.006559756575370557, 0.012282442930882098, 0.021970708658045623, 0.044096578130847774, 0.056295222384505905, 0.02931573679234134, 0.07635955218574964, 0.007575830495625269, 0.010673319266061299, 0.05226831795880571, 0.06319178181001917, 0.041851807764032856, 0.034394956528558396, 0.02375520645728102, 0.1695219660177827, 0.2730718126986176, 0.671951015247032, 1.7591302120126784, 3.0661720829084516, 5.32956219278276, 8.102839104831219, 7.9132364038378, 14.878929052501917, 15.065092463046312, 23.904103115200996, 31.57197955995798, 37.0120545476675, 43.512905314564705, 57.382704466581345, 65.11364802718163, 65.08488357067108, 61.28333196043968, 61.46680511534214, 62.272620275616646, 55.04584886133671, 38.31764169037342, 45.12062564492226, 36.13636493682861, 29.597286321222782, 28.619089610874653, 34.960012659430504, 35.850548073649406, 37.187753319740295, 41.344171687960625, 41.61683365702629, 53.05402614176273, 30.48747595399618, 29.58543475717306, 28.825760520994663, 35.89266501367092, 40.69436855614185, 52.68327623605728, 47.34541766345501, 44.860221818089485, 41.09389431774616, 46.22770003974438, 47.49669134616852, 45.29589883983135, 37.9716132581234, 38.50253216922283, 46.78333282470703, 40.50543509423733, 49.58323918282986, 46.5309389680624, 49.97909054160118, 52.20368877053261, 59.83661659061909, 68.05724367499352, 64.98494133353233, 42.84125715494156, 19.91269089281559, 9.790065418928862, 4.015431208536029, 0.29949069663416594, 0.08719230332644656, 0.007641618640263914, 0.08618785097496584, 0.019125364560750313, 0.042569646393531, 0.06492593602160923, 0.03611560365243349, 0.010016249543696176, 0.03897661263181362, 0.0316362117882818, 0.03494234610116109, 0.051396654380369, 0.030227487477532122, 0.014298852602223633, 0.031291246705222875, 0.08621542176115327, 0.0730018608737737, 0.1491199404699728, 0.02346140317968093, 0.009420734477316728, 0.019490523482090794, 0.03168409886711743, 0.011936642931686947, 0.036640543257817626, 0.0680347258457914, 0.03341099858516827, 0.03982788199209608, 0.020325801415310707, 0.043365425372030586, 0.08229995451983996, 0.028368774910632055, 0.013882569910492748, 0.030027306129341014, 0.07915861409856007, 0.09135910629993305, 0.04510657432547305, 0.035360145557206124, 0.033041379356291145, 0.016456877965538297, 0.10985121480189264, 0.04024485024274327, 0.019291570388304535, 0.028136182118032593, 0.03957361477660015, 0.04455804926692508, 0.0486546190950321, 0.03172044183884282, 0.04200539522571489, 0.03482046689896379, 0.07224032829981297, 0.0734601444855798, 0.015738883485028055, 0.022147720155771822, 0.01792165854567429, 0.04893165911198594, 0.010997719437000342, 0.04502324969507754, 0.017154903107439168, 0.04998494106985163, 0.0637694176111836, 0.04406373809615616, 0.08660632578539662, 0.0759318599011749, 0.01712475892418297, 0.01908793990878621, 0.02601890344521962, 0.09499182269792072, 0.014654445240012137, 0.05306700986693613, 0.040728378007770516, 0.02208263751526829, 0.11119338145363145, 0.026007238739111926, 0.035570485051721334, 0.016994352445180994, 0.040699515884625725, 0.04246236523613334, 0.03730617550900206, 0.044771594839403406, 0.009860113732429454, 0.026431287078594323, 0.028051421431882773, 0.044431739443098195, 0.03434368525631726, 0.02720205382502172, 0.032777746237115934, 0.05442057219624985, 0.010867992023122497, 0.017976102499233093, 0.018584299941721838, 0.029555225992226042, 0.07660863921046257, 0.02338241825782461, 0.05520978316781111, 0.01057282875990495, 0.0285503135091858, 0.01643568593863165, 0.049138851900352165, 0.023199020579340868, 0.049152266219607554, 0.020005249280075077, 0.016368313772545662, 0.017466801800765097, 0.017856019294413272, 0.031032183360366616, 0.03964169940445572, 0.0465085098403506, 0.03153845238557551, 0.008577586067985976, 0.07517523292335682, 0.030803297595412005, 0.05710885743610561, 0.012131275798310526, 0.03270257780968677, 0.015599289217789192, 0.02198089649027679, 0.11154163425089791, 0.25680286693386734, 0.7862782711163163, 2.32048109639436, 4.090864285826683, 6.828923737630248, 9.992007482796907, 10.347738694399595, 17.476894296705723, 17.254372537136078, 26.90897237509489, 37.88257263600826, 44.06852290034294, 51.6893445700407, 68.91776829957962, 75.25106325745583, 74.73465576767921, 73.57552036643028, 73.94562050700188, 75.34987315535545, 70.15435874462128, 50.02599522471428, 57.2913383692503, 44.07163493335247, 33.01452085375786, 35.10083690285683, 42.905207723379135, 46.06788441538811, 53.291388005018234, 53.874656707048416, 51.77594192326069, 63.99689555168152, 47.562298625707626, 41.93885877728462, 35.38671836256981, 49.27507571876049, 50.9216033667326, 60.819399654865265, 54.92080517113209, 57.15065851807594, 51.98903448879719, 54.37910243868828, 59.63642433285713, 57.49881863594055, 49.30057615041733, 47.13710904121399, 59.94876757264137, 50.90730093419552, 63.14291037619114, 57.820965349674225, 60.681185871362686, 61.88707396388054, 70.93226060271263, 74.60272684693336, 73.5248538851738, 53.93551044166088, 30.285549089312553, 16.509768292307854, 6.814753348007798, 1.3364253379404545, 0.09773181707714684, 0.0855127043905668, 0.0814951176289469, 0.02702046142076142, 0.04853151163842995, 0.04359799961093813, 0.03298218194686342, 0.022806500528531615, 0.011012931609002408, 0.033688094263197854, 0.06160177865240257, 0.02044726501480909, 0.053985313716111705, 0.05332943328539841, 0.017355624368065037, 0.07185579190263525, 0.13908555469242856, 0.10384568900917657, 0.04055688623338938, 0.021359210513764992, 0.048045030125649646, 0.03091860136919422, 0.04877181905612815, 0.018655800304259174, 0.05470507821883075, 0.10529671388212591, 0.03243093320634216, 0.02284953952766955, 0.02088523604470538, 0.031058728127391078, 0.052047358331037685, 0.07182051762356423, 0.04888555318757426, 0.024147071562765632, 0.028102546129957773, 0.07950518964207731, 0.0328433743561618, 0.042262605056748725, 0.056096382468240336, 0.03994000937382225, 0.0373177641449729, 0.036955885516363196, 0.036088500419282354, 0.04191980333416723, 0.06478115785284899, 0.06565751551534049, 0.08341707231011242, 0.04210849438095465, 0.01470015133236302, 0.03493795629765373, 0.028257966696401127, 0.05963197399978526, 0.03167402792314533, 0.0643980092718266, 0.01599840139533626, 0.08989787689642981, 0.038248328273766674, 0.03768908660276793, 0.05178546554816421, 0.07693198553170078, 0.10460878751473501, 0.0356573608587496, 0.03971870835812297, 0.14046369324205443, 0.1483327741152607, 0.14988392213126644, 0.26006424974184483, 0.07724799201241694, 0.15926973021123558, 0.20060891431057826, 0.18311998166609555, 0.20859298354480416, 0.28359623858705163, 0.13562371779698879, 0.07787304362864234, 0.14652135490905493, 0.19945039210142568, 0.10231391846900806, 0.18552771653048694, 0.12317483618971892, 0.12238251190865412, 0.09601263940567151, 0.11383981327526271, 0.10038229360361584, 0.10824649114510976, 0.14360404660692438, 0.13663320190971717, 0.07290957481018268, 0.09291299284086563, 0.07263285020599142, 0.16170299495570362, 0.11149119047331624, 0.17196861910633743, 0.1619883210514672, 0.12234469206305221, 0.1552169062779285, 0.0940632846322842, 0.18031429237453267, 0.21256693202303723, 0.10881293535931036, 0.10016772386734374, 0.25830586440861225, 0.1646343298489228, 0.09111509556532837, 0.16411637014243752, 0.13049319153651595, 0.13288902235217392, 0.13010973867494613, 0.2797161421040073, 0.09853767813183367, 0.09859818543191068, 0.17367968510370702, 0.14296297944383696, 0.0952243004576303, 0.120548954437254, 0.0867445433686953, 0.30593482428230345, 0.5109697440639138, 1.4736159075982869, 3.940048716031015, 6.744377324357629, 10.038893166929483, 13.590613882988691, 15.143195372074842, 22.177832946181297, 24.057578779757023, 34.89258527755737, 46.83463767170906, 54.472699016332626, 61.245174407958984, 82.45296880602837, 89.16062727570534, 86.41652092337608, 90.76382204890251, 86.66669949889183, 87.59898707270622, 78.44828769564629, 60.24256780743599, 67.1654923260212, 57.871023863554, 45.236321836709976, 43.40518869459629, 52.787329852581024, 52.52786077558994, 57.47031256556511, 61.053964868187904, 62.14497372508049, 68.55471298098564, 48.19034792482853, 47.69923187792301, 43.68315137922764, 56.7376434803009, 59.4894178211689, 72.16940581798553, 65.47912761569023, 64.54720482230186, 60.343357399106026, 64.67582792043686, 67.09982424974442, 63.050081357359886, 55.62519617378712, 55.61839833855629, 65.55687144398689, 62.320923283696175, 71.9328685104847, 66.13965377211571, 70.44597789645195, 70.98656728863716, 81.98886930942535, 85.16168385744095, 84.44134891033173, 62.76410110294819, 38.60087089240551, 20.239819139242172, 7.11227310821414, 1.3787722843699157, 0.2149353182176128, 0.18034656095551327, 0.21575319464318454, 0.09825120912864804, 0.14743729872861877, 0.1562738136271946, 0.1703913920209743, 0.1926929148612544, 0.19181444949936122, 0.13066409330349416, 0.14612233178922907, 0.17324536544037983, 0.15259859443176538, 0.12260089628398418, 0.14101358014158905, 0.1932575408136472, 0.25411733135115355, 0.280610162881203, 0.17558685620315373, 0.11034511408070102, 0.05546998756472021, 0.12990935880225152, 0.120484506333014, 0.12221308701555245, 0.14801448181970045, 0.14955424529034644, 0.10682961248676293, 0.234838338510599, 0.16504855215316638, 0.11554126103874296, 0.17948489781701937, 0.12306105752941221, 0.1597458476317115, 0.18494361662305892, 0.16946894698776305, 0.3126023383811116, 0.09639275260269642, 0.08246346449595876, 0.09805887413676828, 0.3113777650287375, 0.10694219628931023, 0.15831414086278528, 0.10536785615840927, 0.10428534471429884, 0.21302448090864345, 0.15807125077117234, 0.12992461735848337, 0.12188488704850897, 0.09272009381675161, 0.14073937141802162, 0.2176949943532236, 0.11303804145427421, 0.12606142699951306, 0.1619790738914162, 0.13177796790841967, 0.10845735756447539, 0.08662085703690536, 0.08360796753549948, 0.10784216909087263, 0.2162953483639285, 0.17414042522432283, 0.14947011542972177, 0.1650181389413774], [0.019016476653632708, 0.0415500950475689, 0.04331405019911472, 0.0415594795049401, 0.053758138601551764, 0.0358458144182805, 0.05467893606692087, 0.02265411905682413, 0.012992541887797415, 0.041065212863031775, 0.07907359366072342, 0.034317609897698276, 0.03664905198093038, 0.053176398723735474, 0.019434374444244895, 0.08511549953254871, 0.03925409422663506, 0.04071762799867429, 0.11201885747141205, 0.08946960573666729, 0.007364763232544647, 0.020901067910017446, 0.029497952600650024, 0.016311057079292368, 0.027549948536034208, 0.015965808124747127, 0.00556605237761687, 0.026119585054402705, 0.042706164458650164, 0.011913349699170794, 0.05195183650357649, 0.021598677449219394, 0.05575680908805225, 0.04718040581792593, 0.0500250727054663, 0.04699699886259623, 0.057632468597148545, 0.11094664703705348, 0.03632765008660499, 0.04554130217002239, 0.053249570773914456, 0.041704469185788184, 0.018154130739276297, 0.02822137324983487, 0.049791511410148814, 0.05973668732622173, 0.017743170174071565, 0.011973193704761798, 0.04299793981772382, 0.04571463447064161, 0.11000074271578342, 0.08267228258773685, 0.6642071495298296, 2.582250237464905, 6.8231285735964775, 9.581963885575533, 11.087111569941044, 22.54529982805252, 31.982640624046326, 34.981846287846565, 40.13624310493469, 39.61928844451904, 47.191909700632095, 52.66766667366028, 60.18335938453674, 61.81518942117691, 65.21939635276794, 65.87628230452538, 56.487214118242264, 56.39153905212879, 48.126560747623444, 40.72869211435318, 35.37098340690136, 18.76758623868227, 21.45293064415455, 25.47162350267172, 30.52295085042715, 44.92092736065388, 36.770072132349014, 34.37920242547989, 24.869258925318718, 14.401273783296347, 14.146783389151096, 17.636358439922333, 14.774856436997652, 12.609184496104717, 16.435550674796104, 19.608034640550613, 16.235666200518608, 14.970407243818045, 24.383753277361393, 22.149114087224007, 14.02099208906293, 17.84469746053219, 18.288314156234264, 20.45502059161663, 18.70796173810959, 32.67191223800182, 42.54771150648594, 19.150172509253025, 24.031094200909138, 23.80021668970585, 27.608746625483036, 37.31452211737633, 40.06934389472008, 50.722152069211006, 57.42349527776241, 57.42532677948475, 68.8784784078598, 60.812814608216286, 46.14410452544689, 33.91897492110729, 19.76955447345972, 7.412885427474976, 2.582272798754275, 0.4813868767814711, 0.06982378414249979, 0.0641633421764709, 0.03412690763070714, 0.053023701839265414, 0.017432419954275247, 0.03336275527544785, 0.05469719661050476, 0.040706365907681175, 0.08915099431760609, 0.09133901636232622, 0.0063382857933902415, 0.02393635171756614, 0.02622116095153615, 0.041975330823333934, 0.06971604656428099, 0.024472000513924286, 0.06701592035824433, 0.033208729946636595, 0.020801742575713433, 0.021207298450462986, 0.007171886472860933, 0.04184813784377184, 0.0578937231330201, 0.02966936273878673, 0.05585718456131872, 0.019391706518945284, 0.03189003742591012, 0.02083946037600981, 0.02190573919506278, 0.03611050880863331, 0.02699421536817681, 0.0351336086896481, 0.015985547397576738, 0.025299311491835397, 0.00853281879244605, 0.04206156838336028, 0.042709377958090045, 0.012529594805528177, 0.038386805608752184, 0.04307177980081178, 0.05568011925788596, 0.0023961680290085496, 0.01057184170349501, 0.02189868137065787, 0.044874486193293706, 0.033880945047712885, 0.06850681340438314, 0.012707809510175139, 0.051746061217272654, 0.01693873775366228, 0.04942061939800624, 0.021412496716948226, 0.09298254692112096, 0.030986005076556467, 0.04970945585228037, 0.016338698369509075, 0.09119262031163089, 0.035537756339181215, 0.07083132382831536, 0.03617766946263146, 0.04050881732837297, 0.07608060113852844, 0.01211636883454048, 0.028816306657972746, 0.027736817610275466, 0.044594110222533345, 0.02721608783758711, 0.03569351458281744, 0.05348352169676218, 0.026222984779451508, 0.07237115409225225, 0.05651748077070806, 0.012333878403296694, 0.02109451983415056, 0.0483572553639533, 0.03653721032605972, 0.04408940898429137, 0.03485618646664079, 0.017537285420985427, 0.003520789396134205, 0.030937448209442664, 0.03692326070449781, 0.01584467292559566, 0.01117236719437642, 0.019884353423549328, 0.04416454401507508, 0.037380178764578886, 0.02563114612712525, 0.03636761102825403, 0.00895051898623933, 0.015021195140434429, 0.046991636845632456, 0.04938147481880151, 0.07843750630854629, 0.051527851246646605, 0.03421288543904666, 0.061117011500755325, 0.10150390880880877, 0.05245942469628062, 0.055308800510829315, 0.017299597784585785, 0.0287036653389805, 0.01984588976483792, 0.056501750950701535, 0.06148587373900227, 0.022527109758812003, 0.043446568088256754, 0.03162853798130527, 0.06198756556841545, 0.028147518423793372, 0.03335494788188953, 0.13164515316020697, 0.9106562845408916, 3.1905270600691438, 8.330976013094187, 11.499834973365068, 13.105582259595394, 26.50448977947235, 35.789261162281036, 39.80354055762291, 45.06757669150829, 45.468322187662125, 52.9142240434885, 60.59319779276848, 68.41798111796379, 72.95892745256424, 76.11279621720314, 73.44954952597618, 65.84136217832565, 66.28920614719391, 61.650696247816086, 47.44184508919716, 44.604522138834, 31.90188355743885, 30.678235217928886, 32.15262450277805, 43.725184723734856, 59.11638043820858, 45.52949130535126, 45.113352835178375, 37.23981432616711, 26.78649354726076, 30.830274559557438, 34.50259320437908, 29.662682712078094, 19.70474325120449, 26.28606230020523, 32.155918926000595, 29.984597638249397, 25.857540294528008, 34.17093560099602, 34.92673024535179, 23.687691427767277, 26.700152680277824, 27.382559962570667, 29.691922143101692, 30.245151557028294, 42.02780820429325, 50.80162100493908, 31.91431649029255, 37.17835642397404, 35.81306308507919, 39.54263895750046, 47.870017513632774, 49.11374397575855, 58.774508982896805, 65.64268603920937, 65.79087048768997, 75.39494633674622, 69.87129673361778, 58.521035984158516, 44.146190732717514, 27.87242967635393, 11.753231976181269, 4.421000070869923, 1.4474164322018623, 0.22012638888554648, 0.10347293049562722, 0.026760663349705283, 0.048787485793582164, 0.021851888959645294, 0.03514198753691744, 0.04389602014271077, 0.05929804094193969, 0.04309702395403292, 0.08153167582349852, 0.011438034725870239, 0.062180780005292036, 0.023093095696822274, 0.07472051162039861, 0.04779752387548797, 0.09863760831649415, 0.030638622447440866, 0.027472429355839267, 0.027502232151164208, 0.0062366876318264985, 0.02459919163811719, 0.0796926709881518, 0.07176792903919704, 0.009481934757786803, 0.032259170548059046, 0.020235784468241036, 0.07005551233305596, 0.07678651716560125, 0.015064294439071091, 0.011772946490964387, 0.02408248245046707, 0.06634792807744816, 0.0571389144170098, 0.033602691619307734, 0.028337424737401307, 0.05502495499968063, 0.02526831754948944, 0.05561866571952123, 0.007339494959524018, 0.04127948202949483, 0.03642674535512924, 0.06437502495828085, 0.003277550263192097, 0.028136252622061875, 0.0962223406531848, 0.018466771580278873, 0.0812407761986833, 0.009464672402828, 0.047984322445699945, 0.05211582887568511, 0.015748876503494103, 0.09575432006386109, 0.08548378289560787, 0.016666516130499076, 0.024906142061809078, 0.01949368503119331, 0.10799655065056868, 0.026151072524953634, 0.010253402833768632, 0.027852262392116245, 0.1248701463919133, 0.1376595179317519, 0.12628594151465222, 0.12978475220734254, 0.10186874118517153, 0.13256130478112027, 0.12697648024186492, 0.13096190232317895, 0.09968065976863727, 0.11466592754004523, 0.1789631976862438, 0.1289116748375818, 0.09477101149968803, 0.15700984600698575, 0.1365022425306961, 0.228381831839215, 0.11118485417682678, 0.10754741771961562, 0.18248321895953268, 0.12385479189106263, 0.11323455473757349, 0.25475545960944146, 0.10668764705769718, 0.08344421265064739, 0.17301432002568617, 0.1983152178581804, 0.08216763701057062, 0.16394310834584758, 0.12273444575839676, 0.10661490174243227, 0.12109810661058873, 0.10611119127133861, 0.1891854655696079, 0.13004203996388242, 0.2609290892723948, 0.1830341448658146, 0.08655706944409758, 0.22976476466283202, 0.06905465939780697, 0.1594217962701805, 0.06637561760726385, 0.11026629799744114, 0.11181314155692235, 0.16021001647459343, 0.22291065979516134, 0.1975621160818264, 0.15445216762600467, 0.07601655379403383, 0.15658398682717234, 0.1586828992003575, 0.22542259219335392, 0.36418652976863086, 1.2543410737998784, 4.532419117167592, 11.359745040535927, 16.8118691816926, 19.046789556741714, 32.482462003827095, 46.6297222673893, 49.751311764121056, 57.2244543582201, 58.054185435175896, 63.632928282022476, 71.89535692334175, 79.24663245677948, 82.94334009289742, 85.66673755645752, 82.34499379992485, 75.71931213140488, 76.6017159819603, 68.1964910030365, 59.93838272988796, 53.39864864945412, 34.25556845963001, 36.75641566514969, 40.808480232954025, 48.32874409854412, 63.60452480614185, 52.63193719089031, 52.353108152747154, 38.93236890435219, 23.64930398762226, 29.252893701195717, 33.07272993028164, 27.02815108001232, 23.13027273863554, 27.35555861145258, 33.6155916005373, 27.664286345243454, 28.175765499472618, 40.98626509308815, 38.29879850149155, 28.845568858087063, 31.62174168974161, 33.798289597034454, 34.32486154139042, 33.887565806508064, 49.32418808341026, 59.262505397200584, 34.07070837914944, 38.84547896683216, 39.70207080245018, 44.41393196582794, 55.402197539806366, 57.028806656599045, 70.8313836157322, 76.90033435821533, 76.75457417964935, 88.14090639352798, 79.26044091582298, 69.478230625391, 54.88906167447567, 34.18384350836277, 15.346609856933355, 6.29257301799953, 1.6496185446158051, 0.4141521861311048, 0.18194814532762393, 0.1337225580937229, 0.21388865250628442, 0.16436818084912375, 0.12534050474641845, 0.17047103930963203, 0.1315039224573411, 0.2047601915546693, 0.22543176513863727, 0.05080047601950355, 0.19956729520345107, 0.12244871148141101, 0.19520541129168123, 0.2717697591288015, 0.2437170222401619, 0.12251058433321305, 0.09298863253206946, 0.12707735295407474, 0.10178568001720123, 0.15683832083595917, 0.15842568565858528, 0.1989674469223246, 0.07692192943068221, 0.29593420622404665, 0.1586655923165381, 0.2121239886037074, 0.12258917035069317, 0.09408657322637737, 0.19234248757129535, 0.08195288915885612, 0.11549469127203338, 0.14687261340441182, 0.2010372225777246, 0.088317525369348, 0.1252084321458824, 0.1346354591078125, 0.10906686118687503, 0.15342951781349257, 0.19262025860371068, 0.11067300976719707, 0.20677766064181924, 0.09649018917116337, 0.11941681557800621, 0.20929622784024104, 0.199495381093584, 0.2094053680775687, 0.11382189783034846, 0.1554660007241182, 0.1766965154092759, 0.20599450188456103, 0.2546557446476072, 0.2888744225492701, 0.12983275431906804, 0.08905179143766873, 0.11777707739383914, 0.17186632147058845, 0.1787769779912196, 0.14271403342718259, 0.14767573593417183], [0.030851997325953562, 0.03562181198503822, 0.07002476515481248, 0.05340302093827631, 0.08174192626029253, 0.06268082055612467, 0.04714346541732084, 0.06524016876937822, 0.05900352705793921, 0.009734144368849229, 0.04197058478894178, 0.025631049647927284, 0.039617227084818296, 0.06350544310407713, 0.05011715096770786, 0.04451787310244981, 0.030947361447033472, 0.0577290850924328, 0.033075555256800726, 0.021504452524823137, 0.051473488929332234, 0.04987504755263217, 0.030500633074552752, 0.04420873519848101, 0.03284881058789324, 0.03434947029745672, 0.049817976396298036, 0.0319510605186224, 0.032880029029911384, 0.023658686441194732, 0.08311334837344475, 0.012455526612029644, 0.014699131806992227, 0.09254505086573772, 0.02531196325435303, 0.05000622957595624, 0.06886698509333655, 0.07926235150080174, 0.019035006225749385, 0.0192420023449813, 0.06067664333386347, 0.03087637131102383, 0.02295349957421422, 0.024735377592151053, 0.022142272791825235, 0.05130083198309876, 0.010882801580009982, 0.11791849363362417, 0.03363488598552067, 0.31037966546136886, 0.6964670028537512, 4.26659963093698, 9.506745021790266, 21.836480163037777, 26.857642829418182, 32.27128453552723, 43.05840790271759, 39.63559716939926, 52.60986037552357, 56.877738162875175, 59.716185852885246, 56.56644366681576, 60.29720887541771, 59.30104672908783, 55.872604697942734, 51.74112059175968, 44.597572311758995, 44.07935991883278, 35.4619163274765, 32.973494455218315, 31.754130385816097, 18.74832697212696, 13.815410770475864, 19.760545156896114, 42.612733617424965, 37.81022071838379, 15.993527993559837, 12.793628498911858, 13.631759975105524, 16.33621260523796, 17.207697741687298, 24.796865209937096, 17.438693046569824, 15.631324779242277, 26.511139422655106, 36.437012404203415, 43.531668707728386, 18.513985946774483, 21.405834071338177, 20.44527031481266, 13.39283449575305, 13.61417356878519, 13.528915643692017, 14.616212099790573, 17.80977353453636, 22.146385833621025, 15.199814233928919, 24.83514055609703, 26.746802777051926, 15.149354841560125, 16.15697242319584, 21.92489381879568, 21.62562757730484, 18.556701354682446, 21.77757192403078, 40.68291217088699, 32.61928506195545, 48.331027776002884, 49.92879644036293, 55.763710141181946, 62.29177884757519, 55.718294978141785, 56.58348195254803, 43.76296989619732, 28.005470037460327, 18.091632910072803, 9.727420080453157, 4.2610139306634665, 0.6695481785573065, 0.03777790683670901, 0.04598893225193024, 0.10586793010588735, 0.027458345248305704, 0.08765639795456082, 0.025530111997795757, 0.0022780120889365207, 0.0324727532279212, 0.033571087260497734, 0.040410519868601114, 0.005567528323808801, 0.014844147463008994, 0.050811352193704806, 0.02861672459403053, 0.04140173601626884, 0.052604024749598466, 0.02093166665872559, 0.05479582061525434, 0.0336237908777548, 0.06993476490606554, 0.04865503098699264, 0.033137190621346235, 0.008066569153015735, 0.05882521865714807, 0.03756810910999775, 0.017848942916316446, 0.028328472581051756, 0.03572233588784002, 0.05503004613274243, 0.03147087241814006, 0.036076050892006606, 0.05592471999989357, 0.020746697482536547, 0.016574756991758477, 0.012504150272434345, 0.10717249955632724, 0.034134295710828155, 0.13499212043825537, 0.018004101875703782, 0.03920942806871608, 0.06506967518362217, 0.03325368925288785, 0.01927835644892184, 0.04568449956423137, 0.02416461778921075, 0.06395463540684432, 0.0239921333923121, 0.013628038304887014, 0.0595287412579637, 0.03922697243979201, 0.0491382247855654, 0.030811596661806107, 0.022932565443625208, 0.01852714343840489, 0.02646067241585115, 0.036988669889979064, 0.05115194602694828, 0.060004220431437716, 0.025103748157562222, 0.04277581501810346, 0.03440004766162019, 0.035138733219355345, 0.0801305306958966, 0.04839332003029995, 0.05558772558288183, 0.08095391385722905, 0.020934394051437266, 0.031808839048608206, 0.020562279350997414, 0.03714768616191577, 0.05614661473373417, 0.01846898318035528, 0.05366102486732416, 0.029588845281978138, 0.026521754880377557, 0.0782452010025736, 0.0283051580117899, 0.028188570322527084, 0.032592736242804676, 0.004064844406457269, 0.033446506640757434, 0.008182362744264537, 0.04222063289489597, 0.03307698389107827, 0.040342494612559676, 0.08899606356862932, 0.027839386129926424, 0.036067935507162474, 0.062179332817322575, 0.01983457386813825, 0.09367290753289126, 0.028967294747417327, 0.07343466655584052, 0.045361127267824486, 0.06430245775845833, 0.021395970943558495, 0.05051945809100289, 0.046469317021546885, 0.014585539611289278, 0.07001369973295368, 0.07789367533405311, 0.05190966396185104, 0.04633970464055892, 0.018876247850130312, 0.023293084086617455, 0.029257917922222987, 0.294327664305456, 0.9573431324679404, 5.514588514342904, 12.011430971324444, 25.42819943279028, 31.381313391029835, 38.955338671803474, 46.554448306560516, 45.30317544937134, 59.32053968310356, 66.95207297801971, 67.49570980668068, 66.71789154410362, 69.63182598352432, 69.44214776158333, 65.36698803305626, 62.27964989840984, 53.83662074804306, 54.670132622122765, 44.20910395681858, 41.19963124394417, 45.13023912906647, 36.16378806531429, 28.849628940224648, 25.159373357892036, 44.476636201143265, 50.56958645582199, 29.778728485107422, 23.386080712080002, 30.00739261507988, 27.9787764698267, 19.687114097177982, 23.685616739094257, 17.946419902145863, 21.143767833709717, 25.821854509413242, 30.056292191147804, 48.58693264424801, 28.189370669424534, 26.57216414809227, 24.326247163116932, 24.41090852022171, 22.993407882750034, 21.96880616247654, 25.61134770512581, 23.865335695445538, 34.27515260875225, 25.468891449272633, 32.48854547739029, 40.41755720973015, 23.453920371830463, 27.62798309326172, 28.794566094875336, 33.22594910860062, 30.18541496247053, 30.124508030712605, 51.99385263025761, 43.1810387223959, 55.80399177968502, 58.11917334794998, 62.28308491408825, 70.47815456986427, 64.81134384870529, 64.99190255999565, 53.11445809900761, 35.88196098804474, 25.02508096396923, 14.739882163703442, 7.509781653061509, 1.670174729079008, 0.023085143584467005, 0.06199097944772802, 0.043048992156400345, 0.05927143865847029, 0.056160633903346024, 0.031765790772624314, 0.003229552789889567, 0.03889002626237925, 0.035191292117815465, 0.07063309618388303, 0.049206743569811806, 0.01668248158239294, 0.01350502083369065, 0.03047554291697452, 0.03917132620699704, 0.027950309377047233, 0.03226102591725066, 0.03036845286260359, 0.04109216024517082, 0.07456580351572484, 0.040801832074066624, 0.07442390487994999, 0.034793931408785284, 0.0366880666842917, 0.01895809004054172, 0.03527598972141277, 0.06761787633877248, 0.04272992802725639, 0.08783151512034237, 0.04243266819685232, 0.04432419482327532, 0.04362567429780029, 0.032965787904686294, 0.024859971199475694, 0.028164782634121366, 0.030178251545294188, 0.04479610055568628, 0.10373958415584639, 0.03629425344115589, 0.10069651892990805, 0.03927737910998985, 0.0037396839979919605, 0.0250016360587324, 0.03502487663354259, 0.004063112883159192, 0.0510737051081378, 0.09456226762267761, 0.10341364773921669, 0.03647527068096679, 0.07780178260873072, 0.0802181486506015, 0.006502674286821275, 0.024970428748929407, 0.046290763712022454, 0.049731790786609054, 0.0037363856154115638, 0.07096994217135943, 0.08489114086842164, 0.12129726193961687, 0.21663581603206694, 0.1540439567179419, 0.1370738446712494, 0.17668804008280858, 0.17273929493967444, 0.14586666191462427, 0.19830019678920507, 0.07293524569831789, 0.14364165865117684, 0.18016065296251327, 0.15283281623851508, 0.20563626720104367, 0.17865520640043542, 0.1455017033731565, 0.13165284181013703, 0.12389984025503509, 0.20856864110101014, 0.1732201175764203, 0.13780537963612005, 0.16062794951722026, 0.09386450037709437, 0.10886225107242353, 0.11488105388707481, 0.10517468996113166, 0.09586383137502708, 0.17350563663057983, 0.17564190871780738, 0.12059139044140466, 0.14137620833935216, 0.24709277000511065, 0.08593366539571434, 0.15946126368362457, 0.16279626754112542, 0.14845494646579027, 0.30447712750174105, 0.26172484969720244, 0.11320365912979469, 0.1638196743442677, 0.14904001116519794, 0.15592985786497593, 0.20074775529792532, 0.14069941418711096, 0.205906824558042, 0.12047174881445244, 0.122584249911597, 0.21658204001141712, 0.11791945842560381, 0.5517726670950651, 1.6798935388214886, 7.410029880702496, 16.616006791591644, 33.32510858774185, 40.867897644639015, 50.60644447803497, 58.809239119291306, 56.88126437366009, 68.56490403413773, 75.80158531665802, 76.04819968342781, 75.15830263495445, 78.10379818081856, 78.30881997942924, 73.8130684196949, 72.41988077759743, 62.75346167385578, 65.7245184481144, 53.982240334153175, 52.293721139431, 46.84456653892994, 36.2829914689064, 26.666870266199112, 29.795844666659832, 57.71473824977875, 55.35267859697342, 29.46439605206251, 22.60821495205164, 26.970196589827538, 33.56489472091198, 30.94537228345871, 35.95664218068123, 30.42552787810564, 28.016692735254765, 37.805113792419434, 52.41279914975166, 56.37963809072971, 30.571550242602825, 31.107927560806274, 32.49818556010723, 25.54855417460203, 24.59422778338194, 25.21419871598482, 27.8607415035367, 30.534452833235264, 35.69697171449661, 25.967565290629864, 36.44046641886234, 41.287197545170784, 26.271786466240883, 28.896070048213005, 34.957808777689934, 37.91016675531864, 31.459216810762882, 35.01130610704422, 58.52904215455055, 48.96382302045822, 68.37533980607986, 68.00093829631805, 73.56530651450157, 78.94247397780418, 73.96100208163261, 74.12531286478043, 63.32234434783459, 43.03180553019047, 28.255789205431938, 17.286423817276955, 8.571265619248152, 3.187172790057957, 0.34743144758976996, 0.1425433691474609, 0.1791328823310323, 0.19510234182234854, 0.2969296934315935, 0.09723448907607235, 0.10201339318882674, 0.14233157504349947, 0.18324243603274226, 0.1639239164069295, 0.13755765074165538, 0.12153241885243915, 0.15503044909564778, 0.08059290354140103, 0.1675746447290294, 0.1352472708094865, 0.1523184633697383, 0.19900743383914232, 0.21717299736337736, 0.24216326186433434, 0.16627504024654627, 0.21968023938825354, 0.1470321009401232, 0.2586783334845677, 0.14849806524580345, 0.12817509326850995, 0.14511982386466116, 0.13914802868384868, 0.23698948323726654, 0.15035186108434573, 0.26619403332006186, 0.12303564639296383, 0.0849410577211529, 0.13064467872027308, 0.2168432908365503, 0.17878874845337123, 0.14208681473974138, 0.2615525230066851, 0.19016612466657534, 0.1898312973207794, 0.14629894809331745, 0.09870886933640577, 0.08861806549248286, 0.14401960477698594, 0.10649926771293394, 0.12055842424160801, 0.35737910598982126, 0.13070482236798853, 0.1675250247353688, 0.18554282665718347, 0.14216996496543288, 0.19704911392182112, 0.14249515923438594, 0.14923994574928656, 0.17764576681656763, 0.19949802313931286, 0.16293927939841524], [0.11186408999492414, 0.01938388613780262, 0.05985829564451706, 0.04831807367736474, 0.049301404505968094, 0.044850937847513705, 0.029876355147280265, 0.04275682345905807, 0.03645033822976984, 0.03225231310352683, 0.06712178772431798, 0.036347565619507805, 0.07452518577338196, 0.02687243450054666, 0.024783305489108898, 0.015029529458843172, 0.04401151687488891, 0.012806305494450498, 0.04870085489528719, 0.050784382547135465, 0.0438215827307431, 0.061950725357746705, 0.018648825971467886, 0.05146951101778541, 0.08033013131353073, 0.03426257593673654, 0.06522778974613175, 0.0424271614610916, 0.03053640088182874, 0.04247390563250519, 0.026097823429154232, 0.027787148210336454, 0.05274237220874056, 0.020145826892985497, 0.04576220613671467, 0.056504723252146505, 0.04396696203912143, 0.022287626125034876, 0.03252463306125719, 0.08888958764146082, 0.08893698861356825, 0.06070025476219598, 0.024961179733509198, 0.01912700099637732, 0.046464084880426526, 0.03189317671058234, 0.0172872670009383, 0.11870329995872453, 0.6817233189940453, 5.029649510979652, 17.320031113922596, 29.541208930313587, 41.118858978152275, 56.06999270617962, 49.43713702261448, 48.13010595738888, 51.43258094787598, 56.83390751481056, 57.11845524609089, 52.912529334425926, 54.55211475491524, 50.76835758984089, 55.015317499637604, 45.526238679885864, 41.27592355012894, 32.02554032206535, 31.65982134640217, 24.335803650319576, 24.987362287938595, 17.71549679338932, 13.166917618364096, 9.305704459547997, 16.61328613758087, 44.697807133197784, 68.94222378730774, 29.661926552653313, 32.0727413892746, 46.07826545834541, 29.366640597581863, 34.82711859047413, 33.58468405902386, 40.41241608560085, 55.65460279583931, 50.45384846627712, 46.805546432733536, 38.50650675594807, 42.75196194648743, 44.849160611629486, 47.58375607430935, 35.605149641633034, 27.58788764476776, 30.061277523636818, 26.389283761382103, 30.858717933297157, 27.769899778068066, 24.50809020549059, 23.638157285749912, 32.23356395959854, 21.21641043573618, 23.688968159258366, 23.010102286934853, 19.90976694971323, 25.102733597159386, 14.38594825565815, 23.182191252708435, 16.18453424423933, 17.030102871358395, 33.83947938680649, 32.7290877699852, 47.707766219973564, 44.34778891503811, 59.151251167058945, 57.90344752371311, 58.52877236902714, 51.688018441200256, 57.86627031862736, 46.58670857548714, 39.49518710374832, 13.859727792441845, 6.07684101909399, 1.3143019750714302, 0.5312570929527283, 0.2889133110875264, 0.12556029920233414, 0.03502295818179846, 0.026423258896102197, 0.03626146906754002, 0.022148790703795385, 0.07462637760909274, 0.025994542447733693, 0.017069532004825305, 0.08720454134163447, 0.048632402904331684, 0.04875434147834312, 0.03821312449872494, 0.028265685032238252, 0.024499138999090064, 0.07342839540797286, 0.027136887692904565, 0.07675108703551814, 0.05384286960179452, 0.0726185787061695, 0.05791900068288669, 0.028253582459001336, 0.04301576620491687, 0.034770312558976, 0.03710185854288284, 0.02592783079307992, 0.08354380886885338, 0.017923363629961386, 0.033991903546848334, 0.06648355556535535, 0.023949302194523625, 0.03815803116594907, 0.04419022974616382, 0.018057478991977405, 0.056382896000286564, 0.0759355780610349, 0.05523969914065674, 0.0027314680301060434, 0.017207181845151354, 0.03722253175510559, 0.07207229122286662, 0.025150139808829408, 0.020132156532781664, 0.052991718985140324, 0.06442344267270528, 0.08047889481531456, 0.057789618367678486, 0.012018464713037247, 0.07080558614688925, 0.05313464178470895, 0.014390289834409487, 0.009219220974046038, 0.02810286339808954, 0.05416785606939811, 0.024361121795664076, 0.0318102788151009, 0.03042607135284925, 0.02734335503191687, 0.052376126041053794, 0.09848419897025451, 0.043550068003241904, 0.03930423372366931, 0.02777159279503394, 0.01775934342731489, 0.027734318427974358, 0.03136229621304665, 0.03016804144863272, 0.022055322770029306, 0.04471800806641113, 0.034758794427034445, 0.021334016455512028, 0.07147170821554027, 0.09152368496870622, 0.06806468634749763, 0.060935775327379815, 0.03809524547250476, 0.06467223283834755, 0.02107649121171562, 0.0423913305712631, 0.06083552972995676, 0.04073477532074321, 0.025560276590113062, 0.05497694917721674, 0.01605517383723054, 0.07390283557469957, 0.03178511258738581, 0.055036666090018116, 0.046028648284845985, 0.005025834734624368, 0.016038414287322666, 0.035867396072717384, 0.039418246160494164, 0.08319835396832787, 0.06400243713869713, 0.038715539922122844, 0.05146879113453906, 0.023435416878783144, 0.039027579623507336, 0.027796122631116305, 0.08715277654118836, 0.05016805116611067, 0.282955527654849, 1.1143322428688407, 7.594007458537817, 22.24709562957287, 36.43653362989426, 47.1198807656765, 63.719278648495674, 56.09771601855755, 58.015818893909454, 61.582163125276566, 66.69203013181686, 64.0831433236599, 60.78487850725651, 61.23936451971531, 60.18764555454254, 62.32786551117897, 55.695519000291824, 48.70778515934944, 43.54138098657131, 42.31506519019604, 39.01638999581337, 40.0980019569397, 32.60342091321945, 22.62607019394636, 10.861929953098297, 12.524850871413946, 32.560950592160225, 77.11367771029472, 47.27268576622009, 30.64963225275278, 32.62941911816597, 21.176474578678608, 28.869836255908012, 29.78881884366274, 33.81442733108997, 43.15980166196823, 42.01015055179596, 37.269559130072594, 43.990714475512505, 40.488822385668755, 31.805912107229233, 40.80847643315792, 37.21815548837185, 24.448735490441322, 28.23241475969553, 27.885331884026527, 30.40276139974594, 34.731090143322945, 30.634571760892868, 27.093040198087692, 32.77398236095905, 23.57144996523857, 26.17929182946682, 22.866614386439323, 24.74544446915388, 30.2846884354949, 20.0119586661458, 29.25907976925373, 28.742383494973183, 27.38827485591173, 46.77965082228184, 42.723482474684715, 55.82951121032238, 51.79746016860008, 66.8512187898159, 65.66600918769836, 65.60185343027115, 60.862344950437546, 67.23832681775093, 55.29354237020016, 47.354168593883514, 20.66130392253399, 10.564089585095644, 3.0224651657044888, 0.8421891240868717, 0.3159602003870532, 0.1761405132128857, 0.146731635031756, 0.014211887737474171, 0.006744270722265355, 0.023623308261448983, 0.06741623481502756, 0.038348662928910926, 0.06504261647933163, 0.07744331043795682, 0.030005527805769816, 0.042861032125074416, 0.026015708499471657, 0.027649884286802262, 0.052395796665223315, 0.030931447945476975, 0.03390103498531971, 0.026257515055476688, 0.13435497181490064, 0.005795407550976961, 0.10892681049881503, 0.034271730328327976, 0.04546440082776826, 0.03268102584115695, 0.06706050859065726, 0.039703832007944584, 0.007492880185964168, 0.02282115980051458, 0.013624080802401295, 0.06455849870690145, 0.0733671014313586, 0.03443398236413486, 0.028942811295564752, 0.02519755005778279, 0.03846754756523296, 0.04627470363629982, 0.036130205407971516, 0.0261768640120863, 0.03525614840327762, 0.0364797606744105, 0.06424924577004276, 0.07584024919196963, 0.026011975496658124, 0.037836061528651044, 0.03517658275086433, 0.049734674030332826, 0.1455483547761105, 0.029484287806553766, 0.04462226730538532, 0.015643311562598683, 0.004941889019391965, 0.03226893721148372, 0.048780669167172164, 0.06552013655891642, 0.14488037733826786, 0.1804611782426946, 0.11379381496226415, 0.12419485137797892, 0.14167956862365827, 0.2740349719533697, 0.10564871452515945, 0.1192681114480365, 0.10119745376869105, 0.070873411023058, 0.1122711060452275, 0.08352712538908236, 0.12846249737776816, 0.10579476918792352, 0.2246786782052368, 0.13358711614273489, 0.0988923579279799, 0.09627291059587151, 0.23242867406224832, 0.12805452395696193, 0.09567004919517785, 0.18223017628770322, 0.11256625075475313, 0.12667001778027043, 0.14874108892399818, 0.15704729477874935, 0.15939356497256085, 0.13508183124940842, 0.11921478071599267, 0.09559278420056216, 0.09360544630908407, 0.08025124843697995, 0.16830819833558053, 0.13771032536169514, 0.10881621565204114, 0.24177752318792045, 0.12838803027989343, 0.07383898118860088, 0.26296111929696053, 0.13370116939768195, 0.2238628946361132, 0.1454793944139965, 0.10982583335135132, 0.11680859694024548, 0.09194185549858958, 0.23330690193688497, 0.15561978856567293, 0.3263100137701258, 2.160773053765297, 8.820607289671898, 28.710474707186222, 42.31285750865936, 55.94941757619381, 72.84291967749596, 66.78842335939407, 68.63636299967766, 70.30656337738037, 77.05327615141869, 74.43456307053566, 68.60606342554092, 72.63168141245842, 69.66536298394203, 71.69959142804146, 65.14860615134239, 59.783601835370064, 48.576870784163475, 48.413221165537834, 40.59938505291939, 39.808088913559914, 30.917481780052185, 24.266884848475456, 16.761371791362762, 29.677002243697643, 57.12700858712196, 83.47089618444443, 42.17098452150822, 47.874493673443794, 65.09457305073738, 45.42371638119221, 53.63366223871708, 49.557598158717155, 55.550727769732475, 73.23772609233856, 66.01526364684105, 66.0941170156002, 54.35898631811142, 55.447198525071144, 59.111729487776756, 62.36899450421333, 51.857599541544914, 40.17049826681614, 44.733240231871605, 37.761560529470444, 42.85323791205883, 42.14247465133667, 34.51406478881836, 34.13590908050537, 44.667940735816956, 33.948750123381615, 37.32451178133488, 34.30375747382641, 34.791734889149666, 38.77428598701954, 25.477718375623226, 35.78894957900047, 28.68015233427286, 29.729371033608913, 52.30353221297264, 48.65515038371086, 66.4980885386467, 62.37229272723198, 79.00404587388039, 74.9065813422203, 76.61496207118034, 68.86368200182915, 75.88196620345116, 61.71520918607712, 53.613356128335, 25.594761595129967, 12.305143810808659, 3.8779598101973534, 1.179655131418258, 0.5195090733468533, 0.2864496479742229, 0.2062198772910051, 0.1018810979439877, 0.0833199400221929, 0.15583505592076108, 0.24708469543838874, 0.21147533669136465, 0.12675220321398228, 0.21721553726820275, 0.13886443921364844, 0.1945606482331641, 0.10812281223479658, 0.13277853140607476, 0.0894319343206007, 0.17915940668899566, 0.11568255111342296, 0.14632535370765254, 0.2845614164834842, 0.3166449652053416, 0.23854064609622583, 0.1291351651889272, 0.10029252342064865, 0.14264802681282163, 0.1614040875574574, 0.09688592457678169, 0.23268305259989575, 0.15790631587151438, 0.15454034961294383, 0.2011255975230597, 0.09489885385846719, 0.14641699410276487, 0.10021469439379871, 0.12549797364044935, 0.11756239633541554, 0.1634747686330229, 0.21206173725659028, 0.12838994502089918, 0.14616197731811553, 0.21638707781676203, 0.16042054892750457, 0.15432101528858766, 0.08549573889467865, 0.09428088975255378, 0.13205297815147787, 0.15957464900566265, 0.2540068107191473, 0.09260972161428072, 0.14776317577343434, 0.12583477509906515, 0.08230373947299086, 0.21907521091634408, 0.1171314311795868, 0.14228988118702546], [0.00571628394027357, 0.044595820872928016, 0.04811887753021438, 0.04582187480991706, 0.009368501196149737, 0.00818611801150837, 0.008308070500788745, 0.07441335153998807, 0.034120031632483006, 0.04656291668652557, 0.05532442271942273, 0.044866244643344544, 0.021551968529820442, 0.018197242097812705, 0.03490619237709325, 0.019268673277110793, 0.03559411132300738, 0.04697363605373539, 0.054571736545767635, 0.04909679068077821, 0.028663073571806308, 0.019788963327300735, 0.043121243943460286, 0.10151046197279356, 0.019684006947500166, 0.054111616118461825, 0.0447320903185755, 0.04268845310434699, 0.010632502999214921, 0.031211387904477306, 0.04383205443446059, 0.09675305787823163, 0.0691851215378847, 0.04935533637763001, 0.04291065954021178, 0.006419381661544321, 0.03784372420341242, 0.02237834811239736, 0.07388726531644352, 0.021190598272369243, 0.04838754241063725, 0.013409341299848165, 0.04665938104153611, 0.05687063545337878, 0.018454405544616748, 0.03173619021254126, 1.1401925864629447, 6.723384400829673, 13.552561774849892, 32.352976351976395, 49.71806354820728, 62.26697377860546, 62.33855053782463, 62.76697754859924, 64.34658318758011, 59.21345002949238, 63.02281402051449, 49.808525294065475, 43.43410514295101, 45.352899581193924, 32.234871089458466, 33.58929701149464, 36.43602065742016, 33.1876889616251, 24.86946791410446, 16.4195117354393, 22.09574595093727, 13.044683877378702, 8.933139201253653, 12.709691952914, 23.496147505939007, 48.970837444067, 54.9643774330616, 59.68026638031006, 31.658668108284473, 37.49980017542839, 49.897801503539085, 42.57980838418007, 44.25580345094204, 27.563947029411793, 24.866158291697502, 27.379360534250736, 21.706707626581192, 28.831106834113598, 27.79092025011778, 29.995689243078232, 40.051367059350014, 47.93402507901192, 44.68632034957409, 35.82009270787239, 46.61505125463009, 51.460851430892944, 57.057498916983604, 55.25984577834606, 40.19579350948334, 54.314673095941544, 53.44436779618263, 48.20591948926449, 46.97095535695553, 41.04505553841591, 40.60013361275196, 31.193088591098785, 36.61827027797699, 24.64389491826296, 18.295465372502804, 20.0840312987566, 17.4014550447464, 13.532003927975893, 19.408026672899723, 20.533159598708153, 36.68757475912571, 44.66861329972744, 47.73966170847416, 49.20390173792839, 52.04036593437195, 59.39612902700901, 59.78422500193119, 62.48914785683155, 50.1446932554245, 44.72064010798931, 30.152259841561317, 13.728783018887043, 5.6329963356256485, 0.9765141131356359, 0.08401821934967302, 0.01391026315104682, 0.08818712260108441, 0.021579097738140263, 0.05354614411771763, 0.028833171963924542, 0.01623590349481674, 0.03131259829388, 0.047653614019509405, 0.01963173934200313, 0.031693769051344134, 0.03327828031615354, 0.03332673142722342, 0.028902744597871788, 0.08684614338562824, 0.07648027734830976, 0.01520189325674437, 0.03611395608459134, 0.02604789173346944, 0.03208378991985228, 0.03472103024250828, 0.06693301504128613, 0.010556315974099562, 0.07349795690970495, 0.047096869675442576, 0.03641337556473445, 0.053396504881675355, 0.04565326256852131, 0.03323646400531288, 0.02660287904291181, 0.027103971588076092, 0.056931035142042674, 0.01570020460349042, 0.031599096982972696, 0.04167998944467399, 0.049450097503722645, 0.08921075204852968, 0.02763570926617831, 0.035670118377311155, 0.11155022832099348, 0.04396164084027987, 0.04562386980978772, 0.05429009150248021, 0.012089702540833969, 0.049202231311937794, 0.0888691414729692, 0.02215862044977257, 0.012656360122491606, 0.026991363665729295, 0.053264632661012, 0.071262578421738, 0.018308315629838035, 0.014582647090719547, 0.009170876546704676, 0.06768541177734733, 0.013180848873162176, 0.045456478401320055, 0.06286248346441425, 0.03670308033179026, 0.0630926902522333, 0.014784129052713979, 0.05922824937442783, 0.026936184985970613, 0.03873330322676338, 0.03498929436318576, 0.006310743301582988, 0.02419087126327213, 0.02525754342059372, 0.04574112543195952, 0.012918004285893403, 0.02346353870962048, 0.017837847808550578, 0.0495192693779245, 0.01739700837788405, 0.03685697949549649, 0.02030763920629397, 0.06748359955963679, 0.09066369908396155, 0.07341859163716435, 0.013873148345737718, 0.014335420073621208, 0.028359665047901217, 0.048774279275676236, 0.05997159561957233, 0.021837153617525473, 0.00308636745558033, 0.031085599439393263, 0.026014938521257136, 0.04063382097228896, 0.03353002051881049, 0.04321352258557454, 0.027963178217760287, 0.13628976565087214, 0.044734906769008376, 0.09031376161146909, 0.04761318923556246, 0.04527719778707251, 0.03253656308515929, 1.3650098978541791, 9.014072008430958, 17.37687986344099, 38.68833839893341, 59.50021304190159, 70.06415918469429, 73.0035674571991, 72.28813424706459, 73.38203474879265, 67.97350376844406, 70.74768170714378, 60.07474221289158, 53.212454840540886, 52.39093892276287, 43.0003622174263, 45.084033608436584, 47.55655713379383, 43.337894305586815, 36.79019205272198, 24.663758352398872, 27.66462452709675, 15.91051859781146, 13.24957363307476, 17.389289997518063, 17.273234724998474, 34.463930279016495, 55.2258376032114, 66.9157013297081, 47.14026287198067, 30.394618436694145, 43.586678355932236, 42.9049189388752, 31.210231371223927, 21.88534554094076, 18.99484444409609, 17.4264083057642, 16.738297529518604, 19.26058128476143, 21.965173557400703, 18.757919557392597, 24.542535357177258, 30.184655003249645, 27.65894953161478, 25.565936341881752, 30.768052898347378, 35.71940951049328, 37.131972312927246, 43.44400741159916, 36.430073976516724, 41.84604115784168, 42.57864564657211, 48.32433633506298, 49.049071446061134, 37.46774509549141, 37.75731235742569, 34.0004463493824, 36.85830719769001, 21.53435457497835, 22.6861734688282, 31.55268419533968, 21.3053959608078, 22.747608572244644, 30.253435112535954, 33.09171751141548, 47.93381609022617, 54.84354391694069, 54.70356322824955, 56.71099931001663, 58.60078230500221, 67.31927007436752, 67.86781623959541, 69.85515519976616, 60.623584762215614, 56.68395236134529, 39.233707934617996, 20.18881067633629, 8.512012548744678, 2.2915544360876083, 0.2310724585549906, 0.03193936798197683, 0.05251192793366499, 0.04701563790149521, 0.061113259944249876, 0.010091183266922599, 0.026320924152969383, 0.023694712144788355, 0.08756681330851279, 0.01841029414208606, 0.015771966573083773, 0.03424176982662175, 0.06895558268297464, 0.12114876561099663, 0.06130250018031802, 0.024781303545751143, 0.042194026900688186, 0.03939056034141686, 0.034120870259357616, 0.013558495356846834, 0.038293372927000746, 0.09077836832148023, 0.052794945950154215, 0.09672627376858145, 0.04487262340262532, 0.017196545013575815, 0.007369120103248861, 0.05652198931784369, 0.019427062434260733, 0.04917732112517115, 0.052298274749773555, 0.042544023744994774, 0.05181686952710152, 0.0467265750921797, 0.03824623170658015, 0.06688116118311882, 0.02928724203229649, 0.09342441422631964, 0.04233094943629112, 0.04290223245334346, 0.018981322973559145, 0.0541895045171259, 0.008477099272568012, 0.02604801604320528, 0.027571036662266124, 0.03375690619577654, 0.011481499532237649, 0.03763371496461332, 0.020558939686452504, 0.08485450845910236, 0.024386378936469555, 0.026795336489158217, 0.12672272510826588, 0.13750427548075095, 0.15758591587655246, 0.15327103959862143, 0.11192489415407181, 0.11710109218256548, 0.08339633670402691, 0.1839461998315528, 0.14093788107857108, 0.10528941114898771, 0.06962037630728446, 0.12433641604729928, 0.12797642033547163, 0.07047165679978207, 0.14975630241679028, 0.13524194218916818, 0.11226436734432355, 0.12762535479851067, 0.10821426709298976, 0.08091075796983205, 0.14499882410746068, 0.1537422143155709, 0.110360877297353, 0.14635505445767194, 0.18143156601581722, 0.3226846520556137, 0.13680693868082017, 0.10499428128241561, 0.1679228901048191, 0.12481215497246012, 0.16689066658727825, 0.14611306978622451, 0.1601313191349618, 0.15304084023227915, 0.16865397978108376, 0.09485629911068827, 0.1345449616201222, 0.14482995582511649, 0.13195525214541703, 0.08487529601552524, 0.15116120281163603, 0.1571740981307812, 0.19556239916710183, 0.13881692691938952, 0.0778159724723082, 0.14000834111357108, 2.111392328515649, 11.889762450009584, 22.451346069574356, 48.24722707271576, 69.26928743720055, 80.4990604519844, 84.13727402687073, 81.92868813872337, 82.3767676949501, 76.31286308169365, 81.39017343521118, 66.22340127825737, 62.22460985183716, 61.735169515013695, 48.09381790459156, 49.752014726400375, 53.75020958483219, 49.4000244140625, 38.908251598477364, 27.519797198474407, 33.20760749280453, 22.702485993504524, 17.078166492283344, 22.875293120741844, 39.15824398398399, 65.18511459231377, 71.88892766833305, 71.9374130666256, 42.05418638885021, 52.2097722440958, 65.02139657735825, 54.737799391150475, 56.75775580108166, 36.36708475649357, 31.890586763620377, 34.23542574048042, 28.013449609279633, 35.9378407895565, 37.734232395887375, 38.93888175487518, 54.41635563969612, 60.584397464990616, 60.217283964157104, 47.66105532646179, 62.93095014989376, 67.53503009676933, 71.66467890143394, 71.42021521925926, 56.46899029612541, 68.68518278002739, 72.19442367553711, 62.683739215135574, 61.50546424090862, 58.35536867380142, 58.71787302196026, 48.940682262182236, 53.81419435143471, 39.711232110857964, 30.278945043683052, 33.245293870568275, 29.14757665246725, 24.34900414198637, 32.87842735648155, 35.17788916826248, 52.04282060265541, 62.44481943547726, 67.09301501512527, 70.40852710604668, 70.1727345585823, 77.4057224392891, 77.92130157351494, 79.968251734972, 68.79029273986816, 64.55030545592308, 44.157168343663216, 23.610299080610275, 10.122951306402683, 3.079013731330633, 0.4869829671224579, 0.13662404380738735, 0.21758730872534215, 0.16638026194414124, 0.13383439974859357, 0.12651787750655785, 0.12787425628630444, 0.0786972431524191, 0.11514269062899984, 0.13892137678340077, 0.10233666529529728, 0.08296315252664499, 0.13286188943311572, 0.3051808616146445, 0.1144922427192796, 0.1070734005770646, 0.23787062033079565, 0.15458683774340898, 0.10231706517515704, 0.17843563458882272, 0.10878622546442784, 0.2039342702482827, 0.14410398696782067, 0.21193908993154764, 0.15084046142874286, 0.19992006768006831, 0.18545158702181652, 0.10627681636833586, 0.09488034469541162, 0.1788704885984771, 0.08402567793382332, 0.15246224706061184, 0.16345131676644087, 0.1435803869389929, 0.11409493396058679, 0.15294240176444873, 0.12993956421269104, 0.1649847422959283, 0.11742728092940524, 0.22307290812022984, 0.10197057126788422, 0.11465613861219026, 0.12620914407307282, 0.09081687836442143, 0.11010259506292641, 0.16230823122896254, 0.0985289727395866, 0.15490064746700227, 0.13092187087750062, 0.14768821885809302, 0.2209712498006411, 0.10939601852442138], [0.07628588660736568, 0.02450336924084695, 0.05936875277257059, 0.017667369065748062, 0.06896868901094422, 0.04011936791357584, 0.023806190147297457, 0.024744890069996472, 0.03536382289894391, 0.047416857778443955, 0.025699744692246895, 0.03503663967421744, 0.055386102612828836, 0.01420888018401456, 0.019003255292773247, 0.06824084252002649, 0.017273203302465845, 0.07474536614608951, 0.01612715845112689, 0.07939408271340653, 0.019182342948624864, 0.022792269846831914, 0.04455042741028592, 0.10580884772934951, 0.05919679344515316, 0.014020897888258332, 0.046115290315356106, 0.11578970981645398, 0.01667034190177219, 0.02798799006995978, 0.04177773400442675, 0.028554899981827475, 0.028278898971620947, 0.04972441754944157, 0.03434638667386025, 0.036460717165027745, 0.032344135324819945, 0.0962668027204927, 0.02985217226523673, 0.032729180093156174, 0.040881590684875846, 0.05839535559061915, 0.01764318618370453, 0.08118418001686223, 0.3456629393622279, 3.8801038451492786, 16.300986595451832, 37.486006915569305, 56.21836334466934, 65.262151658535, 62.586513832211494, 63.82247731089592, 65.30612289905548, 58.67972306907177, 48.93489137291908, 43.974249958992004, 32.20019795000553, 38.33208471536636, 32.71353520452976, 34.562390595674515, 20.768593065440655, 19.926337860524654, 20.725577473640442, 22.71788276731968, 24.20220661908388, 34.67150554060936, 46.56457096338272, 68.70689481496811, 43.025577664375305, 42.4280559271574, 58.07447634637356, 32.51295156776905, 23.229517713189125, 19.266351275146008, 27.682200483977795, 39.290723875164986, 20.876968950033188, 7.839437238872051, 8.374326936900616, 6.177095789462328, 6.899559097364545, 6.1792773474007845, 3.4896327601745725, 5.412651859223843, 7.317745657637715, 9.50505981221795, 9.30952325463295, 4.829172268509865, 9.3445098772645, 10.424213390797377, 7.749013965949416, 13.59753331169486, 21.65347058326006, 17.522955425083637, 26.46063443273306, 30.559542886912823, 33.5571925342083, 26.384655609726906, 28.096562549471855, 42.31246992945671, 39.25019904971123, 40.9297127276659, 44.620887860655785, 44.50020253658295, 43.89270253479481, 35.10017193853855, 43.291665986180305, 36.417040675878525, 27.86619421094656, 19.430219382047653, 17.19779547303915, 19.148732386529446, 33.302978575229645, 33.507479801774025, 36.46558307111263, 43.89937877655029, 50.84922485053539, 52.90216729044914, 60.63585050404072, 58.21289151906967, 55.79598940908909, 50.785110890865326, 41.561725214123726, 25.942182652652264, 13.691194485872984, 3.163485573604703, 0.3715670696692541, 0.11496568098664284, 0.03132856189040467, 0.043596407704171725, 0.03443377085204702, 0.04560138644592371, 0.029793152971251402, 0.022938862566661555, 0.01516926195108681, 0.10644820053130388, 0.03136452265607659, 0.047574523341609165, 0.01998969015403418, 0.041357236841577105, 0.07393549749394879, 0.04327436756284442, 0.014027220058778767, 0.044707810957334004, 0.05719224514905363, 0.07888528853072785, 0.04372037605207879, 0.04318811887060292, 0.025304946248070337, 0.02073567102343077, 0.02564936028647935, 0.028053076421201695, 0.015077973148436286, 0.053411700355354697, 0.026044956539408304, 0.037983927031746134, 0.01247154865268385, 0.04493742402701173, 0.05362752803193871, 0.047373100751428865, 0.029879318171879277, 0.019682459569594357, 0.03486802372208331, 0.04441655139089562, 0.04756888301926665, 0.0180096754047554, 0.0400471606553765, 0.03451588207099121, 0.02008948675211286, 0.05877163559489418, 0.13421702140476555, 0.02019659907091409, 0.026382114228908904, 0.042633077755453996, 0.04109412693651393, 0.02531449583329959, 0.05126714218931738, 0.04113572431378998, 0.06594821476028301, 0.04680434474721551, 0.015345163010351826, 0.022640278002654668, 0.005785874664070434, 0.018806556472554803, 0.025712628375913482, 0.05980667185212951, 0.04721230703580659, 0.012003811007161858, 0.058961510367225856, 0.0136511914570292, 0.042056581150973216, 0.10769339816761203, 0.05346687903511338, 0.1297654860536568, 0.07596485578687862, 0.047382281118188985, 0.06504191143903881, 0.027124571752210613, 0.045181805835454725, 0.06383871936122887, 0.046927107105148025, 0.013320448706508614, 0.027965632871200796, 0.08374275639653206, 0.05754937774327118, 0.030742938724870328, 0.028999049391131848, 0.042818247311515734, 0.029176218595239334, 0.005211661555222236, 0.04685251013142988, 0.05917517468333244, 0.017250276505365036, 0.11935207061469555, 0.0215919702895917, 0.04290936820325442, 0.0610379171121167, 0.031595824111718684, 0.009234018471033778, 0.0981423286430072, 0.6889432284515351, 6.1777531541883945, 21.118563786149025, 45.71712143719196, 66.19158938527107, 76.35575518012047, 70.68823769688606, 72.8457923233509, 73.03282588720322, 67.42947936058044, 59.255791157484055, 53.427356109023094, 39.883260279893875, 45.48216104507446, 37.848917841911316, 37.04087980091572, 22.538196109235287, 22.302473857998848, 24.66076411306858, 21.027784757316113, 23.117072246968746, 32.4002306163311, 50.504830330610275, 57.38469175994396, 31.575444974005222, 32.0588531345129, 59.43532392382622, 53.016244769096375, 37.79332682490349, 28.273144774138927, 20.795054845511913, 25.9715398773551, 16.647237315773964, 6.231084717437625, 5.689151622354984, 4.321222649887204, 3.50469087716192, 3.3458349388092756, 2.33922952786088, 2.8042932227253914, 2.717341063544154, 4.360340600833297, 4.477707277983427, 3.142393142916262, 4.999824436381459, 6.063595879822969, 6.10037125647068, 9.103953335434198, 13.52293286472559, 14.47627130895853, 21.31673075258732, 22.549882382154465, 22.055316120386124, 20.43842688202858, 22.25383646786213, 32.137353122234344, 33.260352462530136, 38.922694623470306, 43.33617299795151, 37.581499591469765, 38.00863467156887, 31.505694016814232, 41.11051842570305, 43.86959217488766, 34.02467764914036, 25.080430693924427, 28.57937414199114, 30.825399421155453, 41.93382404744625, 43.24930965900421, 46.87991984188557, 49.91425842046738, 61.17573693394661, 58.872600719332695, 68.4660105407238, 65.82201361656189, 64.28983703255653, 60.512938499450684, 53.90510067343712, 34.12417531013489, 18.5105699300766, 5.160643681883812, 0.6060300744138658, 0.05804250147775747, 0.013045487630733987, 0.09276940952986479, 0.018718034953053575, 0.07737463209195994, 0.04272620615665801, 0.008516229936503805, 0.03349277583765797, 0.03041738636966329, 0.04373888521513436, 0.1126056068460457, 0.045360299773165025, 0.0413065333123086, 0.07697368680965155, 0.03171404081513174, 0.032727517682360485, 0.12683084118179977, 0.10422552761156112, 0.10015605730586685, 0.023046813512337394, 0.015777065127622336, 0.017028919828590006, 0.08534653010428883, 0.08339121588505805, 0.023676189994148444, 0.06150742199679371, 0.09757002888363786, 0.025566610820533242, 0.03079437698033871, 0.06013707970851101, 0.03282334750110749, 0.03513079966069199, 0.062475831946358085, 0.09181534900562838, 0.040998757249326445, 0.07108037374564447, 0.04609705203620251, 0.07442675472702831, 0.0538304794463329, 0.05415303909103386, 0.05324447593011428, 0.06219229442649521, 0.04002006484370213, 0.12936610670294613, 0.0713319172791671, 0.049190308709512465, 0.050920117646455765, 0.045134950341889635, 0.03221909086278174, 0.16055000916821882, 0.16170620103366673, 0.18942893453640863, 0.28026622196193784, 0.0811145146144554, 0.19860431406414136, 0.13925433391705155, 0.12463604332879186, 0.15930716414004564, 0.2047082263743505, 0.16466667264467105, 0.10421964238048531, 0.1646863395581022, 0.10250881387037225, 0.1404672407079488, 0.23227000288898125, 0.1098996250948403, 0.22444616333814338, 0.11188881093403324, 0.11911377441720106, 0.1267033550539054, 0.10236537156742997, 0.11697656722390093, 0.15086124156368896, 0.14052340644411743, 0.10090106967254542, 0.16389172204071656, 0.20059300266439095, 0.0818361493293196, 0.05879574797290843, 0.1349393982673064, 0.08351715834578499, 0.10134914875379764, 0.0684026010276284, 0.10183706632233225, 0.10409930313471705, 0.26655358902644366, 0.17746253055520356, 0.09201333916280419, 0.179243165475782, 0.12490064866142347, 0.20569031039485708, 0.10451558860950172, 0.21675298630725592, 1.3594227726571262, 8.937890846282244, 26.6988018527627, 54.567857310175896, 74.53267380595207, 84.46100905537605, 82.44066506624222, 80.7064837217331, 83.27969044446945, 75.7594683766365, 66.34049579501152, 61.642180904746056, 49.261521846055984, 54.820163771510124, 48.38173985481262, 50.5536425113678, 32.90958568453789, 31.012125201523304, 33.566160053014755, 34.830458611249924, 35.55782698094845, 48.23618486523628, 58.17537233233452, 79.1055004298687, 57.84044310450554, 60.46321056783199, 73.90472710132599, 46.535958498716354, 36.50074638426304, 30.998379439115524, 39.334318935871124, 51.21270194649696, 26.043464317917824, 11.211424749344587, 10.760802179574966, 7.789748255163431, 9.846318550407887, 8.436145819723606, 5.552546102553606, 8.465790878981352, 9.82119619846344, 12.767126820981503, 12.394332624971867, 7.921063033863902, 13.398977816104889, 15.407376196235418, 11.229470930993557, 18.87891076505184, 28.460854701697826, 24.27612215280533, 34.965921342372894, 41.04504033923149, 43.25154773890972, 35.490319803357124, 37.44357839226723, 54.83692467212677, 50.77901981770992, 56.69653348624706, 60.00378102064133, 63.33359934389591, 58.256421983242035, 45.830537751317024, 59.64876987040043, 48.63265559077263, 40.993173122406006, 29.409038722515106, 30.44104814529419, 33.091386929154396, 48.01477454602718, 49.95173200964928, 51.87944836914539, 58.63384813070297, 67.90084406733513, 67.80059024691582, 77.10224032402039, 75.316381752491, 73.03594931960106, 71.12187802791595, 61.6099738329649, 40.13557434082031, 21.909339353442192, 6.833389448001981, 1.0756050772033632, 0.2587725268676877, 0.17612218216527253, 0.18497448996640742, 0.08242159252404235, 0.2093327563488856, 0.07498300925362855, 0.12037445325404406, 0.1340797240845859, 0.17362206475809216, 0.10437846198328771, 0.18194639385910705, 0.11736223168554716, 0.14764144871151075, 0.15652446658350527, 0.1168857877200935, 0.1389201745041646, 0.2433202849351801, 0.21973729570163414, 0.16910167294554412, 0.11789959113229997, 0.13711169420275837, 0.12496741226641461, 0.1640497549669817, 0.17350523587083444, 0.15303583815693855, 0.15477385895792395, 0.28032755304593593, 0.15712527965661138, 0.15707617916632444, 0.09195862803608179, 0.14570650644600391, 0.15505149640375748, 0.16827959596412256, 0.1276515080826357, 0.09569479982019402, 0.12066826209775172, 0.1121955257258378, 0.10170537963858806, 0.15125784528208897, 0.13440067326882854, 0.1465720435953699, 0.1332715994794853, 0.12044933595461771, 0.34568152274005115, 0.16324632073519751, 0.1249478492536582, 0.25737975316587836, 0.16258445859421045, 0.11284181760856882], [0.006434990418711095, 0.013509867058019154, 0.08370487717911601, 0.056052933432511054, 0.04094814648851752, 0.0443318129691761, 0.10319538210751489, 0.020160436070000287, 0.06139378063380718, 0.053710904612671584, 0.05983438735711388, 0.03895432222634554, 0.07516885045333765, 0.029400317507679574, 0.03171823023876641, 0.04902697684883606, 0.0569429800088983, 0.05362927207897883, 0.024911979053285904, 0.046691267416463234, 0.05121825321111828, 0.0619243011897197, 0.015272166292561451, 0.07406597447698005, 0.05832721530168783, 0.03437970168306492, 0.06696942480630241, 0.0702025243663229, 0.03413476326386444, 0.06776315174647607, 0.03841515936073847, 0.01622333707928192, 0.05202749103773385, 0.02291688015247928, 0.02705071136006154, 0.022978198248893023, 0.01659515306528192, 0.014833700806775596, 0.0803648860892281, 0.05972443446808029, 0.0829900182725396, 0.051830558440997265, 0.028422409923223313, 1.6565703903324902, 14.151527434587479, 31.611111760139465, 58.62429544329643, 71.60949066281319, 72.02356964349747, 68.02119120955467, 60.07341988384724, 55.839649066329, 44.590155109763145, 39.142227843403816, 37.74925298988819, 37.805964946746826, 31.158383153378963, 22.209878526628017, 30.54868306964636, 34.9128457903862, 22.501509077847004, 28.992945849895477, 41.32807955145836, 44.92850035429001, 48.87830100953579, 40.54601311683655, 26.300891004502773, 39.034632816910744, 42.0889925211668, 33.87496568262577, 26.638352796435356, 16.09327644109726, 19.405809491872787, 15.342309437692165, 16.177865602076054, 3.486192994751036, 2.3291861917823553, 3.2752639381214976, 1.38765454525128, 0.3255037445342168, 0.3814680321374908, 0.16677832027198747, 0.060076446243328974, 0.1381802384275943, 0.11898262207978405, 0.05495351586432662, 0.03986827337939758, 0.2416719452594407, 0.15048567031044513, 0.07526236106059514, 0.2351417878526263, 0.4343215038534254, 0.6179556157439947, 1.2342666322365403, 0.8821177377831191, 2.5374570535495877, 4.598880400881171, 7.406057193875313, 15.977785438299179, 13.702847510576248, 22.176605612039566, 27.38559029996395, 34.88697297871113, 31.56771808862686, 46.62048876285553, 57.812415808439255, 68.77534434199333, 38.73614743351936, 32.09866359829903, 34.84631136059761, 26.27672430127859, 14.90882109850645, 18.763265870511532, 24.092335514724255, 25.63800137490034, 29.621310532093048, 28.900304920971394, 48.50423388183117, 42.559988647699356, 49.952955543994904, 57.19722501933575, 62.33999066054821, 58.613390028476715, 54.319776222109795, 49.82631973922253, 30.414090491831303, 11.378370691090822, 1.2790539977140725, 0.3108174732187763, 0.029884296127420384, 0.046688617949257605, 0.011189394845132483, 0.061448844280675985, 0.038497214918606915, 0.021241400136204902, 0.00557797266083071, 0.016334683350578416, 0.05379643713240512, 0.04408095592225436, 0.03936584311304614, 0.015318173882405972, 0.014204255676304456, 0.06485885329311714, 0.053133090696064755, 0.011979655955656199, 0.05834042181959376, 0.04576072926283814, 0.07528583519160748, 0.029175597046560142, 0.06390097812982276, 0.005004162167097093, 0.030168668563419487, 0.037073133717058226, 0.021826529773534276, 0.08552830433472991, 0.026689311416703276, 0.0159832096323953, 0.011006068598362617, 0.015314282245526556, 0.049911145615624264, 0.03829961067822296, 0.02428334286378231, 0.027499840580276214, 0.016988572970149107, 0.06320465807220899, 0.07577410899102688, 0.035229757631896064, 0.014421587129618274, 0.03350184859300498, 0.037438084837049246, 0.05549038920435123, 0.039523549494333565, 0.036409924578038044, 0.030418043170357123, 0.02139303946023574, 0.027225236663070973, 0.056170582392951474, 0.07340662079514004, 0.027531572959560435, 0.025332372315460816, 0.023624514251423534, 0.04484552388021257, 0.056774267577566206, 0.06315448888926767, 0.030504816932079848, 0.0045053392022964545, 0.022482072527054697, 0.005723773138015531, 0.002710651947381848, 0.037069059326313436, 0.012332647365838056, 0.03737300219654571, 0.032462930903420784, 0.0371832906967029, 0.01357347931843833, 0.07806681096553802, 0.03234977193642408, 0.021007081850257237, 0.055101065954659134, 0.08355971309356391, 0.03376440188731067, 0.042722803409560584, 0.04487365498789586, 0.0320698857831303, 0.031825155165279284, 0.06689855712465942, 0.02120834673405625, 0.02751575222646352, 0.028313470065768342, 0.04458634364709724, 0.0884328996471595, 0.06567983931745403, 0.007088227412168635, 0.02383967956120614, 0.11389209757908247, 0.05255237869278062, 0.043696831417037174, 0.06392154304194264, 0.18021500785835087, 2.079753801226616, 17.987256310880184, 37.528021261096, 68.36820378899574, 80.76449140906334, 82.37749725580215, 75.2256578207016, 69.03202056884766, 64.27727490663528, 56.278495118021965, 46.08949765563011, 46.13621234893799, 49.91832800209522, 36.8825650960207, 27.979194447398186, 38.18510860204697, 46.540864035487175, 32.5376882404089, 39.224504828453064, 47.13849976658821, 49.761309027671814, 58.373360708355904, 48.108614310622215, 35.22349052131176, 58.18265654146671, 53.0316187441349, 46.08391955494881, 34.215936586260796, 18.109923228621483, 14.04483200982213, 10.483776144683361, 9.085563272237778, 2.905828286893666, 1.9640451413579285, 2.2127238661050797, 0.6846326566301286, 0.16157038800884038, 0.21196001849602908, 0.09069457242731005, 0.081373813591199, 0.05052105370850768, 0.13104100042255595, 0.038617561585851945, 0.10811239990289323, 0.12873781932285056, 0.1542955299373716, 0.11442824732512236, 0.07414220046484843, 0.1525524031603709, 0.27067348826676607, 0.48329624463804066, 0.8849449048284441, 1.347799077630043, 3.2189407479017973, 4.446311937645078, 9.118719343096018, 10.708254799246788, 14.974319133907557, 20.23112140595913, 25.32478418201208, 31.035108268260956, 44.92981508374214, 42.256590127944946, 59.25130359828472, 39.66552056372166, 34.7662952542305, 37.77932457625866, 30.633650310337543, 22.707492224872112, 30.806151553988457, 39.75750222802162, 35.389989987015724, 39.92381550371647, 38.3587820827961, 56.24504551291466, 51.2972816079855, 56.72665826976299, 65.20019978284836, 69.53172415494919, 65.53310751914978, 63.119385838508606, 58.95421274006367, 36.99735313653946, 14.381255507469177, 1.9694458390586078, 0.30506283044815063, 0.04176996742899064, 0.046970897528808564, 0.046927875227993354, 0.022334880522976164, 0.06029592899722047, 0.09742166614159942, 0.023954923963174224, 0.011324572406010702, 0.08369773771846667, 0.06589817174244672, 0.010220480235147988, 0.0462195323780179, 0.06644256674917415, 0.009100723182200454, 0.030885019186825957, 0.021013265795772895, 0.023273162987607066, 0.09050338776432909, 0.009585375300957821, 0.025647371330705937, 0.05759539460996166, 0.014121192652964965, 0.023190137071651407, 0.0832318545144517, 0.010737258999142796, 0.03216090648493264, 0.011474111452116631, 0.03779653845413122, 0.02980405326525215, 0.0023651434730709298, 0.0672265567118302, 0.019816088824882172, 0.06466211736551486, 0.06922574670170434, 0.03485166307655163, 0.039408516604453325, 0.06608171228435822, 0.016903144351090305, 0.016695675112714525, 0.025835069754975848, 0.03050479837838793, 0.0637779152020812, 0.027645837726595346, 0.06607239090953954, 0.0447719288058579, 0.0711259564559441, 0.040177003102144226, 0.10493053079699166, 0.2118448817054741, 0.15969336294801906, 0.11062131176004186, 0.15337958611780778, 0.08654182573081926, 0.19055961136473343, 0.08620721360784955, 0.17288221773924306, 0.11020981313777156, 0.1150190710905008, 0.16233907488640398, 0.15355223935330287, 0.08598036874900572, 0.12978923477930948, 0.08263484865892678, 0.21481703472090885, 0.14436871104408056, 0.11594985786359757, 0.14302214345661923, 0.22588076448300853, 0.10631776807713322, 0.15937671822030097, 0.15555409365333617, 0.06627144233789295, 0.17836774291936308, 0.15659354568924755, 0.2650922111934051, 0.11020884092431515, 0.1424598033190705, 0.07145144758396782, 0.11920094708329998, 0.18384703405899927, 0.1508587331045419, 0.11875842668814585, 0.12035493477014825, 0.09247434645658359, 0.12850013910792768, 0.2611042361240834, 0.11075008180341683, 0.20410727971466258, 0.14521995442919433, 0.4226104432018474, 3.7303325068205595, 22.79681023210287, 48.10006856918335, 83.294737637043, 93.3253102004528, 91.06005415320396, 86.88792362809181, 78.33207473158836, 76.73091664910316, 61.80538594722748, 53.43872129917145, 52.141790091991425, 52.30813756585121, 46.12952470779419, 35.020117834210396, 43.692992851138115, 49.604229256510735, 36.63407362997532, 42.61180266737938, 53.921527191996574, 57.29761183261871, 63.08958023786545, 55.4240957647562, 38.984950482845306, 53.314737752079964, 57.4541862308979, 50.75160808861256, 37.24609158933163, 26.49918146431446, 28.32346547394991, 21.652526333928108, 20.63482504338026, 5.308404928073287, 3.400703757070005, 4.563395529985428, 2.542619789019227, 0.6104226387105882, 0.8664537314325571, 0.48849255486857146, 0.20483733038417995, 0.40211330400779843, 0.28080953343305737, 0.1074675032577943, 0.43799611448775977, 0.708366836188361, 0.47466426563914865, 0.34862859116401523, 0.5248628079425544, 0.7074301270768046, 1.538339734543115, 2.0383540727198124, 1.3761915103532374, 3.5555613599717617, 6.636508237570524, 9.540023636072874, 20.82054577767849, 16.83227028697729, 28.921999856829643, 36.197173073887825, 44.794261157512665, 43.361278250813484, 59.11764197051525, 72.22035348415375, 80.684794485569, 49.341967329382896, 48.04125912487507, 51.2203623354435, 39.68244105577469, 24.52865280210972, 30.630454681813717, 37.23699867725372, 38.80413718521595, 43.202800154685974, 43.483517691493034, 64.59771171212196, 59.02222529053688, 69.0032409131527, 75.21941095590591, 77.92108118534088, 74.66944366693497, 73.18594247102737, 67.33460605144501, 43.121792301535606, 18.532245866954327, 2.757501108571887, 0.418102074181661, 0.11644509300822392, 0.16379938402678818, 0.22057399299228564, 0.13082876102998853, 0.09956904817954637, 0.28044775128364563, 0.1529633006430231, 0.09066767699550837, 0.15494525054236874, 0.17884314787806943, 0.10264869386446662, 0.15635834424756467, 0.14544797188136727, 0.14720257226144895, 0.15143800905207172, 0.11168760727741756, 0.13519177300622687, 0.14111421536654234, 0.12406698675476946, 0.09367305596242659, 0.11121920077130198, 0.13466676289681345, 0.10548046222538687, 0.18365219060797244, 0.05419764587713871, 0.16011827217880636, 0.1239105939748697, 0.15931565430946648, 0.11757602216675878, 0.06289651835686527, 0.10621532943332568, 0.1047470718913246, 0.10812598862685263, 0.08889877542969771, 0.08324166570673697, 0.10474052614881657, 0.13598392659332603, 0.12792199122486636, 0.09974343804060481, 0.05833738643559627, 0.07525325490860268, 0.20802163373446092, 0.17431337531888857, 0.1656915934290737, 0.12189025277621113, 0.1070586169953458, 0.1117651246022433], [0.04913586104521528, 0.00696975188475335, 0.12425146240275353, 0.05395649612182751, 0.038405856539611705, 0.05103106130263768, 0.008225914752983954, 0.01230304495038581, 0.04143151098105591, 0.031209588196361437, 0.03550654531863984, 0.017402787852915935, 0.011542692391230958, 0.05833246970723849, 0.027665458255796693, 0.054751425341237336, 0.03687735144922044, 0.04993584057956468, 0.1102751147118397, 0.09031048131873831, 0.02751342559349723, 0.04045975023473147, 0.02089909750793595, 0.0670767690462526, 0.06747246734448709, 0.023583607071486767, 0.08826116667478345, 0.043777758910437115, 0.030481624817184638, 0.02119058342941571, 0.06513678759802133, 0.09821347091929056, 0.025527380894345697, 0.05136655658134259, 0.018624956646817736, 0.08173984082532115, 0.038250302386586554, 0.04470392581424676, 0.04995538874936756, 0.07397025969112292, 0.0939529569586739, 0.3200681955786422, 8.228043336421251, 25.669948160648346, 55.09131722152233, 70.02830430865288, 71.59426867961884, 67.00052797794342, 60.47896072268486, 60.062484070658684, 49.41481702029705, 37.07208372652531, 30.009045526385307, 25.609628297388554, 25.86179606616497, 13.069059569388628, 17.164074182510376, 17.443522587418556, 17.029624097049236, 13.746669609099627, 14.910554755479097, 17.66829762607813, 19.475839734077454, 16.939095854759216, 19.08816933631897, 24.100860357284546, 30.318035446107388, 18.54989591985941, 12.857681661844254, 10.305386167019606, 9.825267679989338, 13.976839408278465, 4.988029394298792, 2.6583817647770047, 0.38246960495598614, 0.4329964437056333, 0.06364894477883354, 0.039475499143009074, 0.08184396414435469, 0.16035166278015822, 0.1394399895798415, 0.07260673402925022, 0.007806689445715165, 0.05569717010075692, 0.03971762111177668, 0.23167071864008904, 0.033558210998307914, 0.10863705378142186, 0.04821180184080731, 0.17273549514357, 0.04379825331852771, 0.048550180363235995, 0.05370624021452386, 0.03776668927457649, 0.02638713485794142, 0.18753844691673294, 0.08341498687514104, 0.0362075371958781, 0.23436612478690222, 0.9135308302938938, 1.4222938427701592, 4.235082222148776, 5.788578512147069, 7.223867420107126, 10.250666253268719, 22.65055228024721, 37.522382363677025, 47.47614964842796, 44.355931878089905, 41.288956850767136, 39.38663072884083, 29.972575083374977, 26.346693746745586, 21.928068548440933, 23.174243979156017, 20.602631270885468, 25.58529820293188, 20.776498541235924, 24.493664279580116, 30.46848837286234, 29.412846118211746, 40.95558933913708, 45.46571172773838, 58.643522411584854, 61.10334321856499, 51.83431439101696, 36.52199864387512, 13.204195518046618, 1.8347316677682102, 0.24250113201560453, 0.009347316590719856, 0.030781261375523172, 0.017637089440540876, 0.03131914032564964, 0.013645201397594064, 0.0185125342613901, 0.0376418637461029, 0.029050526609353255, 0.00590920569266018, 0.027553733489185106, 0.020933900523232296, 0.039147900315583684, 0.026748315867735073, 0.04727290339360479, 0.05919091192481574, 0.053036396275274456, 0.013415934354270576, 0.02732033361098729, 0.07868753586080857, 0.04542654387478251, 0.015950323213473894, 0.05688184930477291, 0.016696096281521022, 0.06476328693679534, 0.06127794993517455, 0.06603252273635007, 0.059187312508584, 0.03035535952221835, 0.027206634731555823, 0.017716239490255248, 0.04135840943490621, 0.07571671128971502, 0.031811028384254314, 0.03511546688969247, 0.051824862457579, 0.025322718829556834, 0.0654118497914169, 0.04604352834576275, 0.028196604071126785, 0.06800532195484266, 0.0322887043148512, 0.045542018342530355, 0.04564725488307886, 0.04841146925173234, 0.050844849029090255, 0.024505402725480963, 0.027053633566538338, 0.01905121658637654, 0.04338268030551262, 0.02198462578235194, 0.03620794537710026, 0.0634617602918297, 0.030371933535207063, 0.02206447345088236, 0.09707255245302804, 0.07851566930185072, 0.047276577024604194, 0.02877136219467502, 0.061515277629951015, 0.022876524017192423, 0.050406473528710194, 0.04303635338146705, 0.05209293361986056, 0.07365735538769513, 0.06573599763214588, 0.04656290555431042, 0.025545268508722074, 0.013070732711639721, 0.042819605441764, 0.051940392586402595, 0.07320126111153513, 0.03577923635020852, 0.08382803658605553, 0.03420163076953031, 0.02876488695619628, 0.06937712256330997, 0.057188289501937106, 0.11366834747605026, 0.011736735250451602, 0.06263611358008347, 0.0335135967907263, 0.027711662514775526, 0.027076751466665883, 0.03245869324018713, 0.0705746743187774, 0.0264194071496604, 0.14313523191958666, 0.8846206159796566, 9.92105484008789, 30.86283691227436, 63.617645502090454, 79.54323694109917, 79.35856685042381, 76.30362957715988, 68.0357900261879, 70.75605645775795, 58.86423356831074, 47.887017801404, 37.40335375070572, 32.23556265234947, 28.983562253415585, 17.29707084596157, 27.513088658452034, 26.357249580323696, 25.852161683142185, 24.292257986962795, 21.93350985646248, 23.626738898456097, 29.701246842741966, 27.425203174352646, 27.68800087273121, 28.156929910182953, 23.725499399006367, 17.544445171952248, 14.179240297526121, 10.538929235190153, 8.168506231158972, 8.133835941553116, 3.7177934171631932, 1.716461826581508, 0.2738291001878679, 0.233950715046376, 0.0792749531683512, 0.09860410777037032, 0.024606281003798358, 0.15196116379229352, 0.14870176994008943, 0.033859853210742585, 0.02312386699486524, 0.09607943269656971, 0.09958080379874445, 0.10615966835757717, 0.3232187608955428, 0.23530798440333456, 0.1892593686352484, 0.23509250924689695, 0.0670812590396963, 0.08275868342025205, 0.03762989661481697, 0.05642340984195471, 0.06517878573504277, 0.018300619558431208, 0.07680507827899419, 0.07175141625339165, 0.14612341532483697, 0.6352681992575526, 1.2308780453167856, 2.6123355980962515, 4.464853517711163, 6.094749458134174, 9.758762698620558, 18.70467111468315, 31.48168120533228, 32.898805662989616, 36.74874007701874, 38.26272703707218, 33.68758633732796, 21.55602291226387, 25.120965018868446, 27.563681043684483, 32.39149488508701, 28.150312565267086, 32.38579899072647, 31.764709018170834, 32.18608930706978, 40.08002512156963, 36.90018095076084, 49.44683410227299, 52.580883130431175, 66.62188589572906, 69.42610502243042, 61.86285026371479, 43.71022492647171, 17.226964607834816, 2.541701188310981, 0.1967948244418949, 0.058535424832371064, 0.0325814222014742, 0.025494394285487942, 0.08801713367574848, 0.10008275537984446, 0.0426459131995216, 0.04591291035467293, 0.02657442139025079, 0.03765817986277398, 0.014037629607628332, 0.049241320230066776, 0.13939779106294736, 0.04152013825660106, 0.007584004324598936, 0.05290994173265062, 0.02287628096382832, 0.04396695461764466, 0.005536271846722229, 0.010873694500332931, 0.010071810429508332, 0.015789516510267276, 0.16573920962400734, 0.025220862771675456, 0.05728486146836076, 0.08526129444362596, 0.02577122279035393, 0.0658742300583981, 0.015016503839433426, 0.016666816700308118, 0.021216488094069064, 0.06191145832417533, 0.0063899341694195755, 0.002802625613185228, 0.0568673774250783, 0.023097778648661915, 0.03521518185152672, 0.06752498171408661, 0.07331082437303849, 0.010034601928055054, 0.05387169832829386, 0.07857159755076282, 0.039437423256458715, 0.025734781484061386, 0.021453591289173346, 0.09730077028507367, 0.03788355155847967, 0.15592534560710192, 0.11942512021050788, 0.2486530167516321, 0.10330709759728052, 0.10956800382700749, 0.07879588200012222, 0.1419871294638142, 0.10153823313885368, 0.19290968135464936, 0.29162286256905645, 0.1435050886357203, 0.11259185484959744, 0.2580976177705452, 0.18406480987323448, 0.10829518345417455, 0.2637398103252053, 0.15697731025284156, 0.20167509850580245, 0.13420326198684052, 0.08106844208668917, 0.12792794324923307, 0.12639641761779785, 0.10672960066585802, 0.1732499519130215, 0.2050884286290966, 0.08961617990280502, 0.2545733959414065, 0.13239331223303452, 0.1033214210474398, 0.1515937561634928, 0.09965743054635823, 0.36838482948951423, 0.18023213662672788, 0.21390061592683196, 0.24084933393169194, 0.15494642313569784, 0.15096963965333998, 0.1399285305524245, 0.15288058086298406, 0.15702808799687773, 0.28537694772239774, 2.1241537062451243, 14.746261071413755, 40.36686412990093, 75.69658935070038, 91.21219038963318, 87.82205030322075, 86.09297588467598, 78.86490494012833, 79.70355033874512, 68.03569123148918, 53.15659783780575, 44.185796007514, 41.0261819511652, 37.6184868067503, 22.315471060574055, 30.107427947223186, 30.344084948301315, 26.62785965949297, 23.698577843606472, 24.198513217270374, 26.44761823117733, 29.662150740623474, 29.5468782261014, 30.720747336745262, 37.81260319054127, 43.87540206313133, 28.318246454000473, 22.494384460151196, 16.185140311717987, 14.215280413627625, 18.32278210669756, 6.4703037310391665, 3.6043146438896656, 0.8231757755856961, 0.7811005739495158, 0.26462632056791335, 0.19041358638787642, 0.177359297813382, 0.38117099495138973, 0.29703044740017503, 0.4241053364239633, 0.3676135599380359, 0.5158670281525701, 0.3708559140795842, 0.6417245278134942, 0.6596954260021448, 0.4372716596117243, 0.4472101747523993, 0.6968289928045124, 0.28249207127373666, 0.24002900841878727, 0.21289182943291962, 0.15102069941349328, 0.18074369902024046, 0.29818686190992594, 0.2122929459437728, 0.16104423499200493, 0.7194224023260176, 1.7595567391254008, 2.167554977349937, 5.286477729678154, 8.02616111934185, 9.841821491718292, 16.03627000004053, 27.436040192842484, 43.01634036004543, 59.55378256738186, 57.06178888678551, 55.94097062945366, 54.76062476634979, 42.81137555837631, 39.98465023934841, 32.679211646318436, 37.44784936308861, 32.1251405775547, 37.63374678790569, 34.094305112957954, 37.51604810357094, 46.44139677286148, 44.40876804292202, 58.19418132305145, 64.01961833238602, 74.83053982257843, 79.92285937070847, 68.4072656929493, 50.43891526758671, 21.347571797668934, 3.9369364455342293, 0.43207965383771807, 0.1565319177461788, 0.13107576261973009, 0.11994086831691675, 0.15027337154606357, 0.15381402452476323, 0.20844246115302667, 0.16510143759660423, 0.1480148677364923, 0.1230838117771782, 0.08144851075485349, 0.14539563562721014, 0.26127041783183813, 0.09222839871654287, 0.08320694061694667, 0.17833510326454416, 0.12298066067160107, 0.12694737320998684, 0.19467617094051093, 0.10046054565464146, 0.0781952470424585, 0.10151225797017105, 0.2143457709462382, 0.15486116521060467, 0.18116899416781962, 0.17112496047047898, 0.15909206005744636, 0.26856932148803025, 0.11341610632371157, 0.08992933653644286, 0.1504585225484334, 0.15666317398427054, 0.14468988287262619, 0.07509136281441897, 0.23566402232972905, 0.24362297728657722, 0.1293444656766951, 0.13366611034143716, 0.11502506764372811, 0.15263056615367532, 0.1778921004734002, 0.1451270078541711, 0.09755188337294385, 0.12086262315278873, 0.20304594916524366, 0.133310443488881, 0.1418479619314894], [0.07232488118461333, 0.06729052984155715, 0.028634378431888763, 0.0768420594977215, 0.011697632417053683, 0.02175843772420194, 0.007993194867594866, 0.02509513924451312, 0.01264652388272225, 0.042727074469439685, 0.024021056742640212, 0.042328463241574354, 0.012558523721963866, 0.0024704400811970118, 0.05417678410594817, 0.0546078197658062, 0.05319425108609721, 0.016424126988567878, 0.05001016295864247, 0.015414632671308937, 0.02228383189503802, 0.008084957717073848, 0.1025134077644907, 0.03618082730099559, 0.04165581769484561, 0.008119038993754657, 0.08627940231235698, 0.03784422886383254, 0.05783213971881196, 0.014122598095127614, 0.04124373277591076, 0.033482048092992045, 0.012308291934459703, 0.12721801962470636, 0.034953582216985524, 0.05080426839413121, 0.025342595399706624, 0.049690375235513784, 0.11122939045890234, 0.03503855812596157, 2.5748895574361086, 21.779042445123196, 45.6524945050478, 61.41765855252743, 66.0675336420536, 65.41143044829369, 59.72850859165192, 63.857253044843674, 54.703190848231316, 40.71395270526409, 30.902713872492313, 25.93854244798422, 33.598256930708885, 23.643760085105896, 41.68469041585922, 59.012376219034195, 26.766362227499485, 19.740448035299778, 21.25728104263544, 32.668963596224785, 39.172394424676895, 49.542136788368225, 36.263278126716614, 27.765262126922607, 29.14147038012743, 23.261852078139782, 15.689693447202444, 14.459029734134674, 7.844346575438976, 3.603211990557611, 1.2963021034374833, 0.43148486700374633, 0.02693559868930606, 0.03339511662488803, 0.12625132774701342, 0.04124165476241615, 0.043365792735130526, 0.1086292760737706, 0.0411442181939492, 0.0168285826293868, 0.0648021161032375, 0.05623665580060333, 0.08225263518397696, 0.05386051045206841, 0.05100812151795253, 0.138157335750293, 0.09107784717343748, 0.17347774672089145, 0.13232338707894087, 0.04375729418825358, 0.012393355973472353, 0.009392095926159527, 0.0987770504434593, 0.016774799187260214, 0.046262855248642154, 0.04806223310879432, 0.14055049483431503, 0.2136995384353213, 0.2681925182696432, 0.07367570127826184, 0.04188648461422417, 0.09618213109206408, 0.021917177546129096, 0.774864989798516, 1.740220170468092, 2.446938310749829, 4.071383206173778, 12.617990523576736, 17.32390120625496, 26.50393880903721, 35.71296125650406, 56.83215580880642, 63.36949981749058, 57.47108772397041, 40.50098933279514, 51.75317734479904, 38.935769721865654, 32.25596755743027, 29.35624435544014, 24.141086898744106, 26.475408039987087, 30.085613317787647, 34.087024703621864, 46.470085233449936, 57.579195722937584, 57.092297449707985, 56.00485660135746, 40.6613103300333, 27.001649402081966, 4.252074435353279, 1.0044946242123842, 0.22245101805310696, 0.0501780924241757, 0.004174344585408107, 0.026297047406842466, 0.0484720322128851, 0.06329991272650659, 0.05000588818802498, 0.03144805508782156, 0.05912597400310915, 0.06397956414730288, 0.051916992670157924, 0.09550269489409402, 0.02294666996021988, 0.055230066063813865, 0.08191089844331145, 0.032292574614984915, 0.038654698655591346, 0.05648801008646842, 0.035046376651735045, 0.03626502395491116, 0.02104540450091008, 0.005105025602460955, 0.03408272757951636, 0.1496699164272286, 0.04176318419922609, 0.004928345288135461, 0.05253009941952769, 0.05612092529190704, 0.028676703113887925, 0.04948996938765049, 0.038196986497496255, 0.011000119357049698, 0.020071059225301724, 0.037941305490676314, 0.04363520347396843, 0.05971988881356083, 0.03162835244438611, 0.009104245600610739, 0.03320922718557995, 0.04621580308594275, 0.06783456861739978, 0.03642301606305409, 0.06067173402698245, 0.094493262731703, 0.020624510289053433, 0.0439463637303561, 0.08549496706109494, 0.023616738399141468, 0.03628247926826589, 0.01988414747756906, 0.03021009895746829, 0.03432853060076013, 0.028856295430159662, 0.018690345423237886, 0.02215187247202266, 0.11108087928732857, 0.0419697387405904, 0.033356792118866, 0.002185438211199653, 0.07283999104402028, 0.08360368534340523, 0.0806981697678566, 0.029060749693599064, 0.0092225272419455, 0.06434601440560073, 0.03889860548952129, 0.011311004091112409, 0.015935990486468654, 0.03153702746203635, 0.040044629931799136, 0.013581863731815247, 0.03792769450228661, 0.026941858704958577, 0.046467457941616885, 0.06263144547119737, 0.05714695558708627, 0.014407105973077705, 0.036120783843216486, 0.034690123502514325, 0.08220277028158307, 0.04233833009493537, 0.019517880900821183, 0.045643039484275505, 0.044946760244783945, 0.1456694139051251, 3.7349309725686908, 24.11881059408188, 51.54233045876026, 71.20134696364403, 74.56124067306519, 74.76477295160294, 69.94101539254189, 70.61199098825455, 66.57678991556168, 50.51590293645859, 40.592891201376915, 32.0358681678772, 34.66190345585346, 24.839732609689236, 36.461787074804306, 53.94602827727795, 25.16856126487255, 21.123860701918602, 20.061893686652184, 28.882316686213017, 33.18315580487251, 34.33517038822174, 24.475459456443787, 19.980771839618683, 18.270707800984383, 16.454304568469524, 12.421157285571098, 8.697215560823679, 4.83902751468122, 1.9285380654036999, 1.063708271831274, 0.15435592591529712, 0.02810568541462999, 0.04792229374288581, 0.05369831036659889, 0.024681237919139676, 0.14915881416527554, 0.5913187481928617, 0.2010433527175337, 0.13062483369139954, 0.0607752784708282, 0.05199002742301673, 0.25714579853229225, 0.09347420491394587, 0.06818654699600302, 0.18808380671544, 1.0133444680832326, 0.5139472405426204, 0.257681094808504, 0.20559825439704582, 0.14722802792675793, 0.27692498406395316, 0.04842058653593995, 0.04099938065337483, 0.037288256353349425, 0.10442502432852052, 0.053111434826860204, 0.25928074959665537, 0.5995917948894203, 0.11069882166339085, 0.09841198800131679, 0.11592153008677997, 0.05081317787698936, 0.37441442313138396, 1.3893303740769625, 1.9912273390218616, 4.272628482431173, 9.546688478440046, 14.084829613566399, 21.873345784842968, 29.563371241092682, 46.83378651738167, 53.58583800494671, 42.2928249835968, 34.298696145415306, 52.027370631694794, 40.19101716578007, 36.03162735700607, 33.02344277501106, 33.991505429148674, 39.775186479091644, 38.98830570280552, 43.47398400306702, 53.02544787526131, 66.14185765385628, 66.37154012918472, 68.09569001197815, 49.76116843521595, 34.97888624668121, 8.1775126978755, 1.4347255881875753, 0.1841522051836364, 0.05693267899914645, 0.02361100345297018, 0.032733402913436294, 0.018073420324071776, 0.05433701750007458, 0.03869560212478973, 0.06374310847604647, 0.06693826202536002, 0.03835595452983398, 0.021851801757293288, 0.0929886028461624, 0.030852227391733322, 0.045988423880771734, 0.04655588112655096, 0.05708435543056112, 0.030026385866221972, 0.0397082552080974, 0.03921173243725207, 0.029160806043364573, 0.03834838462353218, 0.04019782034447417, 0.0764375296421349, 0.032708110520616174, 0.04148410327616148, 0.009698210506030591, 0.07758651525364257, 0.05463949833938386, 0.041884525344357826, 0.02577652172476519, 0.053415771035361104, 0.027024467162846122, 0.03782541542022955, 0.013581375769717852, 0.024805935427139048, 0.007809940052538877, 0.028097050526412204, 0.04458908959350083, 0.03348742495290935, 0.04379649442853406, 0.04193303582724184, 0.07790004296111874, 0.04342725369497202, 0.04858565873291809, 0.04296592356695328, 0.15629297588020563, 0.11383372024283744, 0.1701881326152943, 0.11213568635866977, 0.1350206189090386, 0.1560586056439206, 0.10822732889209874, 0.12249367820913903, 0.10708281100960448, 0.08046601855312474, 0.30364764388650656, 0.12845541728893295, 0.13993017812026665, 0.09773392477654852, 0.16829590837005526, 0.22917978902114555, 0.22045453690225258, 0.09809517257963307, 0.1642360191908665, 0.1538728768355213, 0.13954259891761467, 0.10098560771439224, 0.2186164745944552, 0.12020304682664573, 0.13394404464634135, 0.05643962576868944, 0.1564854444586672, 0.06866766649181955, 0.24514547840226442, 0.06766988604795188, 0.11856193566927686, 0.11824587723822333, 0.1770076682441868, 0.2494441461749375, 0.2405958014423959, 0.23232477338751778, 0.053602105763275176, 0.20899683062452823, 0.1807968071079813, 0.3654621628811583, 6.061202958226204, 32.11173489689827, 62.37300328910351, 81.34267598390579, 84.34201464056969, 83.12028139829636, 79.95423808693886, 81.28904566168785, 73.60493078827858, 59.136819541454315, 45.50309032201767, 40.347948744893074, 45.84323287010193, 37.36530639231205, 55.00127725303173, 72.14397758245468, 37.341728657484055, 31.34010460227728, 32.206779196858406, 44.986663833260536, 53.60935114324093, 64.83692407608032, 47.756954580545425, 40.7394265383482, 41.024677231907845, 31.654638424515724, 20.644227638840675, 18.410528898239136, 10.739823505282402, 5.533412704244256, 2.385116103105247, 0.8844028995372355, 0.21205835306318477, 0.12919802509713918, 0.19346583198057488, 0.2105535744340159, 0.24598484742455184, 0.48906014941167086, 0.3021508804522455, 0.3017093619564548, 0.3504529385827482, 0.24050493288086727, 0.4846069071209058, 0.5236153467558324, 0.21798143367050216, 0.4688636987702921, 0.5720910080708563, 0.6527610355988145, 0.2680602378677577, 0.1769919495563954, 0.25430120585951954, 0.4391840851167217, 0.25560180481988937, 0.2036447435966693, 0.17384298727847636, 0.14434987533604726, 0.3786088339984417, 0.5416956078261137, 1.0249510640278459, 0.24461423425236717, 0.46395652927458286, 0.23515299428254366, 0.12743285653414205, 1.508406128268689, 2.537984037771821, 3.8141586212441325, 5.627885609865189, 15.873644426465034, 22.397537156939507, 34.9472301453352, 44.5316344499588, 69.23303738236427, 78.20085257291794, 72.59312108159065, 53.45624215900898, 64.96515959501266, 52.30270765721798, 44.533720538020134, 43.279609233140945, 39.32117164134979, 40.0670450180769, 46.096018105745316, 49.97090958058834, 64.87327292561531, 74.95771899819374, 75.60033291578293, 78.07577848434448, 57.94301860034466, 42.68803417682648, 11.378201600164175, 1.9701869180426002, 0.3678833751473576, 0.18894377775723115, 0.14406391099328175, 0.1837997295660898, 0.17711260792566463, 0.14393139310413972, 0.16136968159116805, 0.1612403549370356, 0.0967688656237442, 0.20839426608290523, 0.13183876464609057, 0.17900352599099278, 0.18696297076530755, 0.16880977142136544, 0.16671290737576783, 0.17333672381937504, 0.16552740067709237, 0.20108874246943742, 0.109250386885833, 0.08472953821183182, 0.21967799810227007, 0.1016651552345138, 0.12396691556205042, 0.21646874374710023, 0.10489239182788879, 0.1278209255542606, 0.17056984885130078, 0.25391338916961104, 0.08301833120640367, 0.22372320760041475, 0.13914658891735598, 0.07404955074889585, 0.13392213644692674, 0.12067062954884022, 0.11726412718417123, 0.141747044690419, 0.10954239973216318, 0.09945595971657895, 0.1255554603994824, 0.07064796882332303, 0.16925931995501742, 0.13902055739890784, 0.08461463890853338, 0.2257517198449932, 0.1688220613868907], [0.021691106376238167, 0.03803724663157482, 0.037512848793994635, 0.05188055321923457, 0.02839623994077556, 0.0634881659061648, 0.09488413707003929, 0.026140456102439202, 0.02290812466526404, 0.02281239318108419, 0.03522772414726205, 0.04021875261969399, 0.021388315690273885, 0.06833361097960733, 0.03936658897146117, 0.007930987121653743, 0.03466701302386355, 0.03032574040844338, 0.033936773106688634, 0.05296620023727883, 0.03457125370914582, 0.02420504442852689, 0.04233752486470621, 0.05510119954124093, 0.033325232288916595, 0.026743662601802498, 0.04892630080576055, 0.04097363183973357, 0.07653645792743191, 0.049358245596522465, 0.08666096269735135, 0.04718993128335569, 0.014111658838373842, 0.03572255853214301, 0.07385363860521466, 0.04947951252688654, 0.04894306221103761, 0.08664592678542249, 0.3538526577176526, 3.7595310900360346, 26.462458334863186, 49.885212779045105, 63.63862417638302, 63.62489551305771, 59.87446255981922, 60.6706490367651, 48.3754625916481, 47.453058287501335, 32.11185269057751, 29.53893855214119, 27.079127244651318, 29.272759035229683, 51.51733160018921, 38.729030415415764, 33.36140803992748, 29.357842169702053, 33.22439879179001, 48.9242709428072, 54.97171103954315, 44.08080764114857, 37.740604653954506, 25.08448887616396, 23.351166285574436, 12.231079135090113, 7.686883499845862, 2.7997833397239447, 0.9239379968494177, 0.02153894012735691, 0.07940957875689492, 0.03339785514981486, 0.043161601934116334, 0.08171325709554367, 0.03235527496144641, 0.12114459474105388, 0.07269698660820723, 0.00622123472567182, 0.043183109373785555, 0.07126349868485704, 0.01452950096791028, 0.14089946751482785, 0.021006300739827566, 0.18069065030431375, 0.10642160195857286, 0.05794369935756549, 0.030742231829208322, 0.05658277492329944, 0.3244651830755174, 0.4705279797781259, 0.09384810633491725, 0.17297356127528474, 0.03012654240592383, 0.110494731052313, 0.08466673025395721, 0.05346712394384667, 0.09640890173614025, 0.0045769587723043514, 0.046476133647956885, 0.041201315325452015, 0.02994840469909832, 0.15778295608470216, 0.06773919521947391, 0.019636442702903878, 0.06526110475533642, 0.016971060140349437, 0.08594628190621734, 0.1694543712073937, 0.21310074400389567, 0.23580035485792905, 1.6806261870078743, 2.820782200433314, 6.708238888531923, 10.272878911346197, 24.354850128293037, 46.89136482775211, 74.10392761230469, 73.18041756749153, 62.23690219223499, 62.64517888426781, 33.81193846464157, 14.939716290682554, 12.542168442159891, 16.193355470895767, 18.81252832710743, 39.96869869530201, 39.72561053931713, 55.810470432043076, 59.830723106861115, 64.47891488671303, 55.26400275528431, 36.05817653238773, 12.024078592658043, 1.4007197879254818, 0.054437934741145, 0.022701874404447153, 0.0767845801601652, 0.023300151187868323, 0.020328924001660198, 0.030207119234546553, 0.014681354587082751, 0.005588094627455575, 0.04349249960796442, 0.03935978347726632, 0.051819081127177924, 0.016415865029557608, 0.04562477522995323, 0.021922548839938827, 0.065036026207963, 0.04212628737150226, 0.03807543384027667, 0.08273998872027732, 0.022445566282840446, 0.05738551524700597, 0.017122102035500575, 0.006916531547176419, 0.02178712544264272, 0.036463529904722236, 0.010074773454107344, 0.02834597798937466, 0.03854026319459081, 0.02882687113014981, 0.03578642033971846, 0.056736670376267284, 0.06924630419234745, 0.027194300237169955, 0.0322050234535709, 0.013018049503443763, 0.024264757630589884, 0.07261788850883022, 0.052689943186123855, 0.03791060655203182, 0.02351565046410542, 0.06726835446897894, 0.006539217174577061, 0.06777242859243415, 0.005478065668285126, 0.071201625833055, 0.04712933492555749, 0.014413484732358484, 0.027192799243493937, 0.10738928089267574, 0.03207466521416791, 0.032504739792784676, 0.027714710886357352, 0.03997040032118093, 0.04988599423086271, 0.049351521738572046, 0.05820598918944597, 0.05385096272220835, 0.03456098238530103, 0.04515662105404772, 0.016901645212783478, 0.023075388053257484, 0.09770492906682193, 0.020176835678284988, 0.053208737808745354, 0.030167794684530236, 0.060217242789804004, 0.024889809246815275, 0.03705399372847751, 0.04779073322424665, 0.0297089637388126, 0.012635225612029899, 0.026535634897300042, 0.027175540599273518, 0.06794399829232134, 0.029989779432071373, 0.04194144807115663, 0.0027670280360325705, 0.06383354659192264, 0.010485221009730594, 0.08014843129785731, 0.054100632332847454, 0.03125679992081132, 0.09739733111928217, 0.34624329884536564, 4.195474572479725, 29.958485439419746, 57.13370382785797, 71.57935827970505, 73.61196801066399, 69.7828982770443, 71.17779582738876, 61.05075404047966, 57.31041334569454, 42.39168807864189, 43.71011473238468, 36.15304984152317, 38.558548763394356, 60.91884031891823, 43.65068592131138, 39.993184581398964, 41.839079931378365, 41.61823198199272, 41.584816575050354, 44.156662970781326, 32.33647383749485, 27.980566173791885, 18.86488001793623, 14.888211004436016, 7.753889104351401, 4.020287347957492, 1.6309421905316412, 0.2704973617801443, 0.014197948348737555, 0.051732257270487025, 0.0362597918137908, 0.0448485703964252, 0.028861314203822985, 0.12778904289007187, 0.1837000294472091, 0.08112585463095456, 0.11670584659441374, 0.11773475271183997, 0.1654828421305865, 0.8335779549088329, 0.5790808517485857, 0.106901081308024, 0.19884992041625082, 0.10989669361151755, 0.09508364120847546, 0.13395247544394806, 0.4691641201497987, 1.423351017292589, 2.0476887468248606, 2.1513324603438377, 0.9139749908354133, 0.1872415581601672, 0.2849565359065309, 0.4009055328788236, 0.24369974504224956, 0.37586760765407234, 0.21080961538245901, 0.19980687531642616, 0.08822171410429291, 0.2956925629405305, 0.22648202284472063, 0.10455071445903741, 0.07430351368384436, 0.22483613225631416, 0.08851871418301016, 0.02493226380465785, 0.04062128980876878, 0.11508910756674595, 0.3345493966480717, 1.2621660414151847, 2.8001590445637703, 6.649806099012494, 12.004920970648527, 26.345646902918816, 44.081088826060295, 67.64300510287285, 74.53759834170341, 62.2081833332777, 66.7021755874157, 45.33176131546497, 27.79826145619154, 15.958115793764591, 27.11027417331934, 29.12581332027912, 50.297851637005806, 47.614177241921425, 62.686201483011246, 68.9056545495987, 73.11868607997894, 62.596298307180405, 42.47357368469238, 17.79332421720028, 2.3558529233559966, 0.037852370223845355, 0.04811948980204761, 0.051195432170061395, 0.01938016797794262, 0.009970588907890487, 0.08516722722561099, 0.10373585115303285, 0.013539984338422073, 0.02033787615800975, 0.06893310302984901, 0.048400489176856354, 0.025882136760628782, 0.1260549109429121, 0.029323809503694065, 0.0510668662172975, 0.05016638133383822, 0.027836391564051155, 0.04222608396958094, 0.05110110891109798, 0.026317647570976987, 0.03802374696533661, 0.04294837919587735, 0.020316437367000617, 0.031989099297788925, 0.0012710044302366441, 0.01249812681635376, 0.04074021526321303, 0.0465903761505615, 0.027007199241779745, 0.027619844004220795, 0.020401136825967114, 0.06684641382889822, 0.03299437172245234, 0.014554583704011748, 0.012223001540405676, 0.020789858936041128, 0.015964234771672636, 0.06661888619419187, 0.048893523853621446, 0.10653198158252053, 0.021858199070265982, 0.07188483214122243, 0.042536242326605134, 0.035421806896920316, 0.14977341634221375, 0.1557826009229757, 0.21570642449660227, 0.14177831879351288, 0.09065805134014226, 0.18147858849260956, 0.18702525179833174, 0.1627153140725568, 0.13476808089762926, 0.0918404187541455, 0.11451121201389469, 0.23888911411631852, 0.14888416015310213, 0.1751441799569875, 0.16721461404813454, 0.16323460964486003, 0.2963632269529626, 0.13113666325807571, 0.11083202974987216, 0.1467735366895795, 0.20879808347672224, 0.2209868497448042, 0.08784730802290142, 0.0819450595008675, 0.11285041910014115, 0.09937994153006002, 0.10721651633502916, 0.15927323314826936, 0.12992730393307284, 0.0797298748511821, 0.20884357712930068, 0.17277034639846534, 0.19288484909338877, 0.16921867994824424, 0.22376890905434266, 0.23480362084228545, 0.1541431076475419, 0.14804651291342452, 0.9845537098590285, 9.060852248221636, 39.813750609755516, 70.41516914963722, 85.0281286239624, 85.86932748556137, 80.29228314757347, 82.25889801979065, 69.40212070941925, 66.86898663640022, 47.55374148488045, 43.9956846088171, 41.512004882097244, 44.5677325129509, 63.743118569254875, 52.07031972706318, 47.206231132149696, 40.84332436323166, 46.853309869766235, 65.03961279988289, 69.64074030518532, 57.08521082997322, 47.57238328456879, 32.59449899196625, 28.46877347677946, 15.882449503988028, 10.008219312876463, 4.258444318547845, 1.5933484327979386, 0.3182830929290503, 0.3250649571418762, 0.1339334764634259, 0.19396504503674805, 0.22588558844290674, 0.20214003918226808, 0.19733308930881321, 0.1901196365361102, 0.25592953723389655, 0.1635788771091029, 0.1013022598635871, 0.6274871667847037, 0.5950669501908123, 0.40860611654352397, 0.46467659063637257, 0.5618561978917569, 0.42923758446704596, 0.22267710592132062, 0.41430705750826746, 1.2948033213615417, 1.9238536292687058, 1.3262113672681153, 1.0378333227708936, 0.2585976175032556, 0.28353431378491223, 0.329987236764282, 0.17575799545738846, 0.19603832362918183, 0.2832791634136811, 0.32843356544617563, 0.14523834484862164, 0.23128615255700424, 0.488171917386353, 0.10878488217713311, 0.19201818387955427, 0.2985263499431312, 0.11315415787976235, 0.1364603260299191, 0.3923559916438535, 0.4202438530046493, 0.7788045471534133, 2.692948984913528, 4.095049761235714, 8.299567848443985, 14.682474844157696, 31.109318286180496, 57.01245993375778, 84.0485867857933, 81.74105420708656, 71.63998022675514, 75.04803255200386, 49.00149039924145, 26.836886443197727, 21.07523661106825, 27.991600781679153, 30.519316345453262, 58.69961880147457, 57.2456344217062, 73.38088721036911, 77.82116934657097, 83.46869230270386, 70.50137132406235, 50.594467520713806, 21.743445955216885, 3.0271747754886746, 0.20985605951864272, 0.16628277342533693, 0.14871064602630213, 0.16366498108254746, 0.12313740226090886, 0.1939028679043986, 0.1693507970776409, 0.15014308009995148, 0.10690594237530604, 0.1944352698046714, 0.15366580279078335, 0.13607886212412268, 0.20700147753814235, 0.14805598271777853, 0.21094496827572584, 0.14920730609446764, 0.11428423356846906, 0.11640998942311853, 0.15566710790153593, 0.10405820299638435, 0.12064996073604561, 0.1227773270511534, 0.08216446803999133, 0.18558561889221892, 0.1361660793190822, 0.10473037356860004, 0.17942043486982584, 0.1290563787915744, 0.10005820513470098, 0.19419331481913105, 0.1662857865449041, 0.15720967669039965, 0.1900277438107878, 0.07618466508574784, 0.1735642069252208, 0.19192194216884673, 0.09886037136311643, 0.11821987238363363, 0.12396188380080275, 0.23286814423045143, 0.052920788220944814, 0.15487559256143868, 0.14506190665997565, 0.2106822034693323], [0.024230815506598447, 0.05510078764928039, 0.07636065798578784, 0.050771554524544626, 0.011594190946198069, 0.04846361254749354, 0.03330282313982025, 0.05836015181557741, 0.03251606125559192, 0.04002095913165249, 0.05106184929900337, 0.06496648697066121, 0.029893237151554786, 0.04695051444286946, 0.08096425197436474, 0.01803021805244498, 0.04446800820005592, 0.023562606147606857, 0.021587342998827808, 0.037230543239274994, 0.05619463539915159, 0.03164752954035066, 0.041226678222301416, 0.0658679218031466, 0.011712474442902021, 0.03370896716660354, 0.06475566508015618, 0.09280705868150108, 0.0370207306696102, 0.02358606729103485, 0.02596001031633932, 0.033027334211510606, 0.033259637566516176, 0.050541752207209356, 0.08738468284718692, 0.02048943755653454, 0.1122140052029863, 0.9835567977279425, 9.336956832557917, 33.406488820910454, 55.150138065218925, 62.59856678545475, 63.40028956532478, 59.55591805279255, 50.394510850310326, 46.56156152486801, 44.39806021749973, 33.39354291558266, 25.33490303903818, 14.375247079879045, 21.879319064319134, 18.879112154245377, 25.44097814708948, 27.897557727992535, 17.13078036904335, 29.229884035885334, 34.66552086174488, 42.01595664024353, 25.348455011844635, 22.476360127329826, 14.904858861118555, 7.517837220802903, 2.0138824358582497, 0.44919319334439933, 0.2811076393118128, 0.09579722362104803, 0.07658699076273479, 0.11502936467877589, 0.10760888981167227, 0.1050160187878646, 0.0645215249096509, 0.0826120276178699, 0.12673991324845701, 0.06279179389821365, 0.02377538174187066, 0.05360103335988242, 0.10689926304621622, 1.1989470524713397, 0.4255773714976385, 0.06466067759902216, 0.15504891372984275, 0.12216423885547556, 0.09761425346368924, 0.16435020603239536, 0.15077864052727818, 0.22792515868786722, 2.4192016990855336, 0.45991654449608177, 2.489201780408621, 1.0644241771660745, 0.14917658118065447, 0.2162415871862322, 0.07881030935095623, 0.402519615017809, 0.39640339789912105, 0.5047181888949126, 0.16763651015935466, 0.29653145698830485, 0.18144600820960477, 0.027363990448066033, 0.13590791582828388, 0.04799296846613288, 0.09715614796732552, 0.1493132847826928, 0.08679368096636608, 0.03574675625714008, 0.18824856349965557, 0.08202133743907325, 0.016321267175953835, 0.20692944468464702, 0.3017774020554498, 1.6799645475111902, 3.258018088527024, 10.065878368914127, 18.106007538735867, 29.58401933312416, 34.74032364785671, 27.510689087212086, 21.01562350988388, 30.8068735152483, 60.23651473224163, 18.188628405332565, 21.13775845617056, 20.260241143405437, 39.242968037724495, 45.79820528626442, 55.21542236208916, 55.52436098456383, 56.4455683529377, 52.76209160685539, 49.554459527134895, 19.246465042233467, 4.390858663246036, 0.3693844727240503, 0.08661618892801926, 0.03080952421441907, 0.05990046447550412, 0.024497810554748867, 0.012734085248666815, 0.012063620688422816, 0.03819069308519829, 0.03219938313122839, 0.049292639741906896, 0.03070712453336455, 0.03784805834584404, 0.021358880258048885, 0.08257100169430487, 0.0662447621289175, 0.034881159735959955, 0.014256415670388378, 0.0288464823825052, 0.008319937442138325, 0.020440786065591965, 0.03650443337392062, 0.04633255404769443, 0.05168822935956996, 0.03672570099297445, 0.08563190815038979, 0.007538018999184715, 0.031880229944363236, 0.0390835598227568, 0.06062658176233526, 0.03972492384491488, 0.004643195916287368, 0.044402350395102985, 0.03227630673791282, 0.033371386452927254, 0.03131437944830395, 0.02910443250584649, 0.10398585101938806, 0.0724646721209865, 0.026114399297512136, 0.0057065015062107705, 0.04138360534852836, 0.04906382077024318, 0.033723691376508214, 0.05781512227258645, 0.03706668816448655, 0.018510161244194023, 0.02077707729768008, 0.06433339047362097, 0.06753727167961188, 0.009265942881029332, 0.03943617644836195, 0.026227728958474472, 0.01607210964721162, 0.02537147422117414, 0.0276196436243481, 0.0529577731504105, 0.04903324428596534, 0.041871534049278125, 0.052896894776495174, 0.051569897623267025, 0.03297730232588947, 0.04863331574597396, 0.019257817511970643, 0.03355956170707941, 0.02560602628363995, 0.02944862389995251, 0.01762952138960827, 0.01591632913914509, 0.025443998747505248, 0.03299386706203222, 0.10345039147068746, 0.02096539541525999, 0.02978870936203748, 0.030876211749273352, 0.032130767867784016, 0.017780294256226625, 0.007017860216365079, 0.041875701208482496, 0.08667694855830632, 0.059543777169892564, 0.9261995286215097, 10.263145733624697, 37.476195842027664, 64.53172445297241, 71.21871963143349, 73.5525543987751, 69.33438554406166, 59.56037901341915, 56.20764411985874, 52.12577395141125, 47.25181348621845, 32.17697739601135, 20.204051658511162, 29.739210605621338, 25.085305832326412, 36.61027550697327, 37.306683138012886, 26.98060803115368, 24.013119265437126, 33.14497545361519, 40.99296793341637, 24.922687858343124, 16.11871227622032, 8.518733438104391, 3.3593617379665375, 1.2597417715005577, 0.24905419209972024, 0.17686164326732978, 0.06527431498398073, 0.16202934697503224, 0.20245528867235407, 0.3052615775959566, 0.40178254363127053, 0.32014137133955956, 0.18277556577231735, 0.3667905181646347, 0.2087756706168875, 0.22932193998713046, 0.440791814471595, 1.2224300298839808, 2.6398755703121424, 2.57986752782017, 1.7579418257810175, 0.5953983636572957, 0.10867439865251072, 0.12382705783238634, 0.028805222682422027, 0.30112894310150295, 1.200900028925389, 5.03719543106854, 5.312893437221646, 3.97563808131963, 3.303960235789418, 0.8796964958310127, 1.3502907939255238, 1.0265094554051757, 2.0670902682468295, 1.5014883619733155, 2.0616978826001287, 1.7147129704244435, 1.0449696960859, 1.1958801420405507, 1.1023839027620852, 0.8673839690163732, 0.9732661780435592, 0.3642587852664292, 0.4075445485068485, 0.5904282897245139, 0.2141035784734413, 0.1848013320704922, 0.2179821312893182, 0.08224903576774523, 0.3376217989716679, 0.2016552386339754, 1.0037521203048527, 3.5025584790855646, 12.311904598027468, 22.862514406442642, 31.424925550818443, 37.27798327803612, 35.763756930828094, 26.983826458454132, 26.195860840380192, 56.34656086564064, 25.804962515830994, 25.808676816523075, 26.947451010346413, 44.67083618044853, 55.167605727910995, 62.29840189218521, 62.587877959012985, 67.97860309481621, 61.354722529649734, 58.35107110440731, 26.576497815549374, 7.021433282643557, 0.594539965968579, 0.013668461233464768, 0.02359596754104132, 0.02687102256459184, 0.01738722130539827, 0.05585346640145872, 0.03998278305516578, 0.041411139027331956, 0.013415538232948165, 0.034718054230324924, 0.04251412261510268, 0.01821341906179441, 0.047236757091013715, 0.031770176865393296, 0.02824360242811963, 0.06608329305890948, 0.06556904409080744, 0.03937627770937979, 0.04973222123226151, 0.03424060094403103, 0.04026486596558243, 0.02376949465542566, 0.011576882207009476, 0.02251494039228419, 0.10057079169200733, 0.04234825632011052, 0.039490716881118715, 0.03798664329224266, 0.023018582214717753, 0.047097775095608085, 0.04140209224715363, 0.025786512887862045, 0.04645087094104383, 0.010275834247295279, 0.014737518467882182, 0.007702582361162058, 0.044640609485213645, 0.0774864069535397, 0.02792960531223798, 0.022964603958826046, 0.01063261153831263, 0.10668358008842915, 0.04260129157046322, 0.1126319234026596, 0.15238613239489496, 0.237813311687205, 0.12375928490655497, 0.17126642866060138, 0.18463063810486346, 0.2143854758469388, 0.16498634533490986, 0.2075419094762765, 0.13127894781064242, 0.1624575216555968, 0.10632682970026508, 0.12624565773876384, 0.13191118341637775, 0.12117011719965376, 0.16753312898799777, 0.09913550777127966, 0.1114927935122978, 0.1892545446753502, 0.09593771217623726, 0.12406836714944802, 0.11057428186177276, 0.14185229607392102, 0.16043126553995535, 0.05779447572422214, 0.15292591124307364, 0.17815441999118775, 0.312915732502006, 0.09728474731673487, 0.11659799027256668, 0.15186578297289088, 0.08606308852904476, 0.09605168379493989, 0.14885483047692105, 0.1680969534208998, 0.12113346994738095, 0.26871962123550475, 1.862779981456697, 15.113520864397287, 47.63528510928154, 77.5435334444046, 84.178327023983, 84.37672957777977, 80.04253014922142, 72.14820295572281, 62.9814912378788, 60.445625111460686, 49.72661308944225, 40.325457751750946, 25.306406468153, 35.707949325442314, 30.853280425071716, 34.658578634262085, 39.72167395055294, 27.73160733282566, 42.58933447301388, 47.18712955713272, 52.93625146150589, 33.18301901221275, 28.17320253700018, 17.957446910440922, 9.583823885768652, 2.8547744639217854, 0.7106732530519366, 0.7021475792862475, 0.35063924733549356, 0.3333659382769838, 0.3567843488417566, 0.40789668273646384, 0.4813057748833671, 0.22405999421607703, 0.17163521668408066, 0.33976930717471987, 0.09445142044569366, 0.21499644150026143, 0.3170375316403806, 0.6317623530048877, 2.434874908067286, 3.2342088036239147, 1.4268942084163427, 0.5689286277629435, 0.25323488807771355, 0.2876263379584998, 0.45512737648095936, 0.6357024447061121, 0.8250210515689105, 6.904528755694628, 4.9019412137568, 3.4694114327430725, 1.672582731116563, 1.0996474558487535, 1.0800169967114925, 0.7132070045918226, 1.5008115232922137, 0.7563514332287014, 1.5786410844884813, 1.087901454884559, 1.5320375352166593, 1.1516519403085113, 0.6180064380168915, 1.0153317614458501, 0.7038543408270925, 0.2742749231401831, 0.3699550061719492, 0.498100962722674, 0.3643455571727827, 0.7716775545850396, 0.3426891239359975, 0.15356804709881544, 0.6416443758644164, 0.61048474162817, 2.5552481738850474, 4.856750713661313, 14.93849465623498, 24.38256774097681, 40.58179959654808, 47.778727412223816, 37.9363701492548, 31.947249323129654, 40.96501663327217, 72.54598081111908, 26.645768098533154, 31.57694399356842, 33.90531845390797, 55.87802700698376, 63.82569193840027, 72.29239001870155, 71.82661861181259, 75.90342745184898, 70.80055207014084, 65.13560324907303, 31.98377676308155, 8.840883951634169, 0.7386585138738155, 0.24290873436257243, 0.14341252797748893, 0.11299936813884415, 0.1206304422521498, 0.17549429554492235, 0.16338815999915823, 0.08414716750849038, 0.17857800819911063, 0.15914493065793067, 0.1403789548203349, 0.12470607238356024, 0.18458223523339257, 0.16665031464071944, 0.1255756022874266, 0.13408146071014926, 0.13020598038565367, 0.0941003326443024, 0.1357756502693519, 0.1495256132329814, 0.19670443085487932, 0.16103693225886673, 0.13411067164270207, 0.1764657668536529, 0.20524330000625923, 0.14502427977276966, 0.11946455051656812, 0.1290473245899193, 0.10933583034784533, 0.13523051311494783, 0.1375877225655131, 0.08796777343377471, 0.13472142949467525, 0.07108815145329572, 0.08007164127775468, 0.07360559800872579, 0.1016989081108477, 0.19594879093347117, 0.09220921419910155, 0.15321520040743053, 0.10562904019025154, 0.2047076474991627, 0.14576699148165062], [0.055786788143450394, 0.025716129457578063, 0.05907040940655861, 0.03261890808062162, 0.08585481220507063, 0.044232198197278194, 0.014265343706938438, 0.054005351703381166, 0.013937054682173766, 0.04437444564246107, 0.06078798403905239, 0.04073296448041219, 0.047315539777628146, 0.030131561179587152, 0.048468978275195695, 0.04517495210166089, 0.05303612539137248, 0.009887401574815158, 0.024305935694428626, 0.064671646541683, 0.06382699342793785, 0.014965162990847602, 0.042588997894199565, 0.033652508282102644, 0.010015076022682479, 0.021962554310448468, 0.03620185605541337, 0.019493965191941243, 0.04952017108735163, 0.056516026161261834, 0.043776163292932324, 0.042954145683324896, 0.06286144445766695, 0.05002169593353756, 0.007236006176754017, 0.017540448825457133, 1.0860916832461953, 9.430002439767122, 33.269946947693825, 41.759417206048965, 59.06258672475815, 59.5430139452219, 53.6711548268795, 49.708640053868294, 42.6729641854763, 30.876884758472443, 54.59457367658615, 19.648340977728367, 18.966055288910866, 38.074393942952156, 26.384070441126823, 25.711348839104176, 39.8603019118309, 37.17354208230972, 41.54087193310261, 48.97609256207943, 39.41866301000118, 17.814637273550034, 9.033160284161568, 4.233918059617281, 0.8375068847090006, 0.3048399486579001, 0.07953806678415276, 0.02834029870427912, 0.046103193308226764, 0.08615682178060524, 0.08581689588027075, 0.13753290753811598, 0.11409630693378858, 0.05312259672791697, 0.12204196260427125, 0.2711319871013984, 0.45169328106567264, 0.9737249440513551, 0.23858685221057385, 0.8889740542508662, 1.1658156802877784, 1.8684999807737768, 2.308037239126861, 1.393490913324058, 0.3047079948009923, 0.2917279803659767, 0.11288419424090534, 0.1433000183897093, 0.11393588429200463, 0.9737460210453719, 2.5555424205958843, 4.582735542207956, 6.0431919246912, 2.2477470617741346, 0.7052724366076291, 1.7954293079674244, 0.9022153937257826, 1.6305187507532537, 2.9919549403712153, 0.7572623156011105, 1.2726201117038727, 0.6961455044802278, 1.0416182759217918, 0.6630757602397352, 0.8154597552493215, 1.2384652881883085, 0.2694803522899747, 0.47510958393104374, 0.2901228336850181, 0.05923999757214915, 0.08424240731983446, 0.1319364461232908, 0.09074537985725328, 0.09049058571690693, 0.008452031379420077, 0.14488793240161613, 0.17451328021707013, 1.2538170581683517, 4.617839008569717, 14.016248043626547, 25.583010725677013, 45.57646818459034, 62.080217599868774, 80.90849608182907, 41.991178169846535, 22.564338706433773, 26.144985370337963, 18.471430130302906, 30.278289578855038, 30.353972017765045, 42.80146189033985, 48.26413616538048, 47.80149199068546, 54.3514247238636, 59.806841388344765, 48.762300834059715, 30.92801671475172, 10.067481882870197, 1.7681948631070554, 0.17241206718608737, 0.1204906810016837, 0.060869375374750234, 0.04896360114798881, 0.021442026773002, 0.06362148531479761, 0.04908572525891941, 0.01979260541702388, 0.008290705172839807, 0.014718351576448185, 0.038680770303471945, 0.028289788133406546, 0.02292218279762892, 0.024136679639923386, 0.047838512691669166, 0.017207367382070515, 0.05106597935082391, 0.013076450959488284, 0.020919771886838134, 0.04749414132675156, 0.08525963945430703, 0.06313071789918467, 0.022974966195761226, 0.009986163804569514, 0.008566471478843596, 0.011265840694250073, 0.04546270502032712, 0.042170545348199084, 0.03877267416100949, 0.0524689687154023, 0.027445094201539177, 0.07098149741068482, 0.0681699080450926, 0.07915321126347408, 0.06325713533442467, 0.07414931766106747, 0.03008434945513727, 0.04344539178418927, 0.04960024882166181, 0.01669569181103725, 0.014151745945127914, 0.00806114776423783, 0.046564564254367724, 0.08327239062055014, 0.0277432501752628, 0.11326822597766295, 0.04020198008220177, 0.07673036627238616, 0.08556243570637889, 0.012091089429304702, 0.05958086971077137, 0.09257144905859604, 0.04696374322520569, 0.07096033135894686, 0.007192981556727318, 0.02454478479194222, 0.16767815948696807, 0.040428238644381054, 0.05290056469675619, 0.044152510090498254, 0.04819088811927941, 0.01680328838119749, 0.022638784430455416, 0.06304543028818443, 0.10264786265906878, 0.051489385732566006, 0.009383219839946833, 0.0063569345729774795, 0.045012080372544006, 0.06828785015386529, 0.06955200966331176, 0.06339083323837258, 0.057855799386743456, 0.02758818769507343, 0.04201806368655525, 0.020511169495875947, 0.049435900218668394, 1.0425867489539087, 11.729326508939266, 38.63864466547966, 50.5557855963707, 70.95639690756798, 71.69340535998344, 64.16693642735481, 61.09615780413151, 54.0397122502327, 40.273962914943695, 62.25721210241318, 27.2104424983263, 28.962579779326916, 40.69022677838802, 30.889158099889755, 30.473475605249405, 34.72952462732792, 32.584927305579185, 31.083979345858097, 40.78643761575222, 31.366315595805645, 16.232508569955826, 7.157002883031964, 3.0472766468301415, 0.7149587105959654, 0.4482578200986609, 0.13873523130314425, 0.11786436880356632, 0.19574726815335453, 0.435387198231183, 0.32243315305095166, 0.5615994741674513, 0.2734610839979723, 0.7349977665580809, 1.1458585574291646, 1.8356908787973225, 0.8595651760697365, 2.738064439035952, 3.0472604976966977, 3.0071256263181567, 2.9473313223570585, 3.888915809802711, 2.6855985168367624, 3.0462661385536194, 0.8428540290333331, 0.3086003812495619, 0.2704911871114746, 0.13445683900499716, 0.2041129645658657, 1.4670484350062907, 5.876701008528471, 7.247040001675487, 10.289149638265371, 7.14473239146173, 3.434607437811792, 4.1946865897625685, 3.9024903438985348, 3.958830633200705, 5.4018808621913195, 4.306061463430524, 4.2607322707772255, 3.137225420214236, 3.5326637886464596, 2.166199875064194, 2.6635582745075226, 4.449410671368241, 1.5823980141431093, 1.8763490533456206, 0.9932222915813327, 0.4760592360980809, 0.34966940875165164, 0.12248829021700658, 0.34939344855956733, 0.27341792068909854, 0.09447537697269581, 0.10801784286741167, 0.28376503265462816, 1.2023510760627687, 3.144309902563691, 11.022055260837078, 21.241747476160526, 36.03172615170479, 47.5386106967926, 70.17089545726776, 52.1794118732214, 22.45086159557104, 28.87356575578451, 27.920882776379585, 45.31884580850601, 36.46825812757015, 49.518984630703926, 56.97700783610344, 56.85921035706997, 64.28030714392662, 69.37786281108856, 57.20419764518738, 39.89239878952503, 13.931511640548706, 3.0717430589720607, 0.16470649628899992, 0.07756188337225467, 0.04420398545335047, 0.01968272488738876, 0.05808557201817166, 0.03190304727468174, 0.0958370695298072, 0.048448161032865755, 0.015646552892576437, 0.05382661285693757, 0.0231435728710494, 0.06023018584528472, 0.09186537718051113, 0.021841198322363198, 0.05104044576000888, 0.05572956484684255, 0.07375581611995585, 0.05636916255753022, 0.08647175214719027, 0.0234023616212653, 0.04312563374696765, 0.017826439143391326, 0.05199743405682966, 0.05309920052241068, 0.027639178806566633, 0.04265633295290172, 0.034061457627103664, 0.015766023825563025, 0.037926469958620146, 0.05174498139240313, 0.05511273993761279, 0.023952415504027158, 0.046776291565038264, 0.048835755078471266, 0.06018245832819957, 0.10613566730171442, 0.04279518507246394, 0.03804880558163859, 0.05747050599893555, 0.02451011536322767, 0.03202938678441569, 0.07848417255445383, 0.11333044021739624, 0.22832073824247345, 0.2117989130783826, 0.17995755682932213, 0.12441333223250695, 0.1512457334320061, 0.174798502412159, 0.27251781430095434, 0.12391485390253365, 0.29747739841695875, 0.20299779862398282, 0.22201790066901594, 0.12049726385157555, 0.09069932217244059, 0.24367160280235112, 0.09662010954343714, 0.12088483563275076, 0.15110272157471627, 0.18912432744400576, 0.11379529183614068, 0.06695735748508014, 0.13681158452527598, 0.12426925168256275, 0.13224348746007308, 0.11543884465936571, 0.14966537448344752, 0.22699990833643824, 0.13989471830427647, 0.21240000816760585, 0.1661236272775568, 0.28083259938284755, 0.14211031113518402, 0.14460505539318547, 0.12761416321154684, 0.3095095418393612, 1.8048418778926134, 16.92009497433901, 49.07480366528034, 65.04194587469101, 84.92969110608101, 82.67926946282387, 76.41042664647102, 67.89456680417061, 60.989995300769806, 47.64616012573242, 70.77004730701447, 31.476568579673767, 32.617734745144844, 51.42131455242634, 38.188330829143524, 40.116077587008476, 52.71953389048576, 50.463883727788925, 57.03489013016224, 64.17346447706223, 49.91175815463066, 21.52924194931984, 11.832838654518127, 5.5851673521101475, 1.6340392618440092, 0.6601964053697884, 0.36353180708829314, 0.2287499074009247, 0.18499083205824718, 0.21443419042043388, 0.20289014268200845, 0.2335622304235585, 0.29829922306817025, 0.28003651241306216, 0.4044554033316672, 0.9715446922928095, 0.9194766206201166, 2.5845241779461503, 2.452735137194395, 3.147522867657244, 4.078822731971741, 3.8259256398305297, 3.72779899276793, 2.56499488838017, 1.973126179073006, 1.5596993383951485, 0.5239410605281591, 0.43647720536682755, 0.7514434622135013, 5.8377602230757475, 10.031055137515068, 10.637399051338434, 15.24358693510294, 9.585372302681208, 3.0020918464288116, 6.006879173219204, 4.663303568959236, 6.347966445609927, 9.649621155112982, 5.599314467981458, 3.885513092391193, 2.498548566363752, 4.123315019533038, 2.906841882504523, 1.9515429809689522, 4.282784862443805, 2.0607070857658982, 1.4179538819007576, 0.7117808936163783, 0.2581807679962367, 0.21161514247069135, 0.45063575031235814, 0.3696959372609854, 0.4765866952948272, 0.3573914256412536, 0.41193666751496494, 0.5436966754496098, 2.170451609417796, 6.9948551338166, 17.88477960973978, 33.231565207242966, 58.04267965257168, 73.17838087677956, 92.59603813290596, 52.149488478899, 31.40214767307043, 38.66909623146057, 32.848074585199356, 44.92441177368164, 43.8224671036005, 58.99110496044159, 66.22867539525032, 66.31042420864105, 73.61863285303116, 78.74089479446411, 65.17952889204025, 46.79641172289848, 16.42747800797224, 4.290672289207578, 0.5025664356071502, 0.21723677753470838, 0.19262022891780362, 0.10914852711721323, 0.17144476674729958, 0.15114823007024825, 0.11020010584616102, 0.11024190360330977, 0.1620952200028114, 0.1765944404178299, 0.15133611217606813, 0.2159844627021812, 0.15603942854795605, 0.08097060475847684, 0.195229189703241, 0.09560555656207725, 0.15347318578278646, 0.24081905430648476, 0.1621057139709592, 0.15045314939925447, 0.11858782920171507, 0.17819906759541482, 0.11829304072307423, 0.13632338494062424, 0.08078425147687085, 0.14478937519015744, 0.13667122955666855, 0.13364776445087045, 0.1554276910610497, 0.1815005560638383, 0.10570364087470807, 0.11410276361857541, 0.13331673690117896, 0.22103581664850935, 0.1586612284881994, 0.18876358430134133, 0.1031874782347586, 0.110370792390313, 0.30085601087193936, 0.11376718670362607, 0.0990436298889108], [0.1317334093619138, 0.0647399909212254, 0.05909491883357987, 0.016418961640738416, 0.03558294571121223, 0.014231002678570803, 0.04747868610138539, 0.01132097206209437, 0.04775015258928761, 0.015829943149583414, 0.04165177670074627, 0.01411190281942254, 0.013498655061994214, 0.013316275981196668, 0.02051949453743873, 0.02151185915863607, 0.05166178663785104, 0.02589801686553983, 0.044944441033294424, 0.06251421582419425, 0.03098125718679512, 0.03244105238991324, 0.026670130610000342, 0.10506056249141693, 0.05097338529594708, 0.09214703706675209, 0.03214990414562635, 0.06579933993634768, 0.03557332376658451, 0.017977206443902105, 0.03667993645649403, 0.05308034254994709, 0.03324014134705067, 0.05770629744802136, 0.03423215159273241, 0.6027740647550672, 4.917025929316878, 28.993646912276745, 52.08690583705902, 52.48267740011215, 60.64403146505356, 53.322018161416054, 45.667971074581146, 43.705608174204826, 29.582419618964195, 22.303055226802826, 22.01742645353079, 28.88371881097555, 31.74674168229103, 30.69738619029522, 34.796990007162094, 26.401513405144215, 54.427394047379494, 44.727057963609695, 36.678584441542625, 15.58208417147398, 7.368273446336389, 2.7233863016590476, 1.2558343936689198, 0.3047602716833353, 0.07471616263501346, 0.06723058657371439, 0.05172952987777535, 0.06957604782655835, 0.29953365214169025, 0.36952269030734897, 0.279325713054277, 0.626333988038823, 0.6109622097574174, 1.6600918513722718, 2.286332566291094, 1.9314002618193626, 1.8483460997231305, 1.5035971300676465, 1.836301814764738, 1.8183750892058015, 3.5332819679751992, 5.233102468773723, 2.630987372249365, 3.4186399821192026, 0.7297396205831319, 0.0742448543314822, 0.05919687508139759, 0.2118841264746152, 0.07671312618185766, 2.0957732666283846, 4.571278681978583, 6.756587494164705, 7.129298094660044, 7.919937344267964, 1.8398721981793642, 4.0007986687123775, 3.7716517271474004, 5.370087493211031, 3.8305609161034226, 4.160858429968357, 4.734335532411933, 1.8227235996164382, 2.043395689688623, 3.4159732377156615, 1.5991770825348794, 3.5014591505751014, 1.8442772305570543, 2.4159797094762325, 1.891200675163418, 0.36583427572622895, 0.16665855247993022, 0.20086638018256053, 0.013807534141960787, 0.14047096628928557, 0.20851600798778236, 0.07868654880439863, 0.03694794824696146, 0.04542186092294287, 0.22526742395712063, 0.9924559795763344, 5.4427566938102245, 16.44096728414297, 34.51944150030613, 30.144128277897835, 41.31225720047951, 52.993898168206215, 33.56725059449673, 16.77616249769926, 12.270433623343706, 24.13367349654436, 23.63332014530897, 39.006928503513336, 33.929181173443794, 46.164232045412064, 53.44790160655975, 57.621506452560425, 52.88458563387394, 45.18107660114765, 21.92753277719021, 8.639151826500893, 1.9527333858422935, 0.11935516537050717, 0.04557883999950718, 0.021263289781927597, 0.020176254947728012, 0.036349298534332775, 0.03605817997595295, 0.026544991524133366, 0.06210120322066359, 0.02998636740812799, 0.03142461435345467, 0.007966134307935135, 0.0377019517327426, 0.045269227121025324, 0.01900147970445687, 0.030688990154885687, 0.035868119666702114, 0.0076148048447066685, 0.01809438042982947, 0.058350975159555674, 0.06093150426750071, 0.051702100099646486, 0.17296450707362965, 0.0038365706814147416, 0.040279237655340694, 0.008541940715076635, 0.03182856162311509, 0.05529374975594692, 0.029037136409897357, 0.05593410074652638, 0.019329082242620643, 0.0138966122722195, 0.07308086249395274, 0.042041007181978785, 0.031335096500697546, 0.0584882316616131, 0.04019284053356387, 0.010956544156215386, 0.06172331646666862, 0.07215967911179177, 0.028164472787466366, 0.014022681825736072, 0.04285545117454603, 0.0056153031528083375, 0.04132442278205417, 0.029711175338889007, 0.031134649834712036, 0.04761040989251342, 0.08514674394973554, 0.06449980224715546, 0.028522915272333194, 0.009437303851882461, 0.07250396141898818, 0.011857557819894282, 0.04332195778260939, 0.055806711097829975, 0.03254102710343432, 0.03806773776886985, 0.07044626050628722, 0.04571916157146916, 0.04564194110571407, 0.025260717957280576, 0.030751957674510777, 0.10581069567706436, 0.035310570092406124, 0.036569623625837266, 0.0655482936417684, 0.051713699867832474, 0.015508545893681003, 0.009725476083985996, 0.002619788024276204, 0.015679634125262965, 0.09750710218213499, 0.027078877719759475, 0.05405367293860763, 0.6313963851425797, 5.610567564144731, 33.60747903585434, 61.95334240794182, 62.68802158534527, 74.5529343187809, 63.59129771590233, 57.42808923125267, 51.53878904879093, 42.91465401649475, 30.258177258074284, 32.77806714177132, 29.83365073800087, 32.64747954905033, 35.227472707629204, 37.00591027736664, 30.123464986681938, 53.26763167977333, 43.76138538122177, 32.144899517297745, 15.654457937926054, 6.948713259771466, 2.9024790041148663, 1.0218505491502583, 0.1476544511388056, 0.14381891320226714, 0.09746894094860181, 0.30236435180995613, 0.7271336135454476, 1.0550333373248577, 1.2306928052566946, 2.1138187358155847, 2.437740904279053, 2.4819676810875535, 3.9899246022105217, 4.9969223421067, 5.271215848624706, 4.375390168279409, 6.495343912392855, 6.55048655346036, 5.976241417229176, 6.739173978567123, 5.717477677389979, 3.933487180620432, 1.2529738596640527, 0.7199107948690653, 0.17998878640355542, 0.08541117858840153, 0.08601574692875147, 0.48541676835156977, 4.149932116270065, 6.057255445048213, 8.553258385509253, 9.331656116992235, 10.131331756711006, 6.711894292384386, 7.637556446716189, 9.048582706600428, 5.971812754869461, 11.597183849662542, 7.101488336920738, 8.49543308839202, 5.657063294202089, 5.445975121110678, 3.767303335480392, 6.336418390274048, 6.191434795036912, 3.0811691656708717, 5.223125629127026, 4.325647037476301, 3.5768936527892947, 2.299659876152873, 1.892190403304994, 1.2084203003905714, 0.7669130258727819, 0.4131536412751302, 0.16902592935366556, 0.11523078355821781, 0.10204822217929177, 0.3866506868507713, 0.8152620471082628, 4.264660784974694, 14.22437522560358, 32.33144290745258, 34.910843297839165, 35.21972872316837, 38.31283114850521, 32.25443243980408, 26.681182198226452, 18.952127136290073, 34.751251861453056, 35.60325354337692, 45.416219383478165, 40.9171088039875, 55.91557279229164, 64.39840480685234, 66.20993480086327, 63.07396687567234, 57.512782886624336, 30.500685945153236, 12.160951998084784, 3.346118973568082, 0.27155762363690883, 0.042805682751350105, 0.038876478356542066, 0.0217952964885626, 0.02468148282787297, 0.004166968101344537, 0.021290383738232777, 0.0967753074655775, 0.037618493515765294, 0.047857597019174136, 0.012767996759066591, 0.026067896324093454, 0.04336425648943987, 0.07562758677522652, 0.05063845404947642, 0.03483005544694606, 0.030672015382151585, 0.015841179265407845, 0.01687529897026252, 0.04338112921686843, 0.021021067623223644, 0.038541866233572364, 0.02690152483410202, 0.041707753189257346, 0.01340821138001047, 0.04061082181578968, 0.038573277633986436, 0.03882289158354979, 0.018085906958731357, 0.021170608524698764, 0.012939358657604316, 0.07800648920238018, 0.08276378197479062, 0.02399416502157692, 0.04361061241070274, 0.02791274371702457, 0.022398584624170326, 0.01807198055757908, 0.06580068322364241, 0.17718603601679206, 0.09542584550217725, 0.1575203100219369, 0.055551672048750333, 0.12954986246768385, 0.1802787435008213, 0.1577913126675412, 0.08921916058170609, 0.2083518003928475, 0.24850440910086036, 0.10827337915543467, 0.1511705687153153, 0.21338155784178525, 0.15017505182186142, 0.13893289491534233, 0.22260804165853187, 0.15701087017077953, 0.18514246767153963, 0.18804362684022635, 0.17142217577202246, 0.07456527659087442, 0.1783201118814759, 0.06961227205465548, 0.2988032007124275, 0.1598028594162315, 0.1297880770289339, 0.1096259432961233, 0.17408075655112043, 0.13381838420173153, 0.06373267387971282, 0.07526831308496185, 0.08386561152292415, 0.2659756934735924, 0.10913076752331108, 0.12356398132396862, 1.4393935189582407, 10.772935878485441, 45.598108023405075, 74.05930280685425, 76.20559483766556, 86.04921743273735, 74.87616777420044, 64.07227590680122, 59.61134187877178, 46.02973826229572, 35.4848100990057, 35.33659905195236, 42.64408953487873, 45.671143904328346, 43.212577030062675, 48.630303516983986, 40.53694300353527, 69.68165650963783, 58.32433953881264, 46.86184421181679, 21.368934251368046, 10.168136581778526, 3.4680363815277815, 2.3035864904522896, 0.47667765291407704, 0.23142347956309095, 0.13608318142360076, 0.1844882348086685, 0.44105607841629535, 1.0908382222987711, 0.7950318139046431, 1.8960912502370775, 1.7576334485784173, 3.462419332936406, 2.8531160904094577, 6.816778164356947, 7.04794873483479, 5.414646752178669, 7.596103996038437, 9.644097201526165, 8.841211684048176, 10.859727021306753, 14.746282920241356, 8.726112060248852, 7.658010749146342, 3.71025200933218, 0.7859382487367839, 0.44313771359156817, 0.8796906773932278, 1.3084152597002685, 7.738045854493976, 12.766732592135668, 16.163770258426666, 16.909048967063427, 25.027436837553978, 10.926878917962313, 12.664572224020958, 11.904935985803604, 14.040391948074102, 12.405215241014957, 15.870493445545435, 16.01894862949848, 7.817010842263699, 6.680991975590587, 10.765322037041187, 9.56025755032897, 10.92168079689145, 7.4465245474129915, 6.218829900026321, 5.169548504054546, 3.163102506659925, 1.8293955666013062, 1.1425837269052863, 0.7170031196437776, 0.7340677070897073, 0.3762046614428982, 0.24435004452243447, 0.29204704449512064, 0.3261796629521996, 0.620655786478892, 1.4939907705411315, 7.5697319861501455, 20.684000104665756, 44.0513364225626, 42.46652506291866, 57.90313974022865, 68.33670347929001, 47.64813981950283, 26.325931660830975, 20.250179283320904, 36.47240370512009, 37.89275608956814, 51.914615482091904, 50.48851020634174, 66.38046965003014, 72.69221976399422, 78.8413918018341, 72.57393971085548, 67.46784970164299, 35.489711835980415, 15.672661811113358, 3.857145714573562, 0.3837524517439306, 0.21575458988081664, 0.13324917177669704, 0.09879394914605655, 0.08721718753804453, 0.13647879066411406, 0.1877383518149145, 0.18512150942115113, 0.15194345614872873, 0.2457295189378783, 0.09021438061608933, 0.11984781784121878, 0.16103458707220852, 0.15066086169099435, 0.07465336209861562, 0.09118114670854993, 0.1667041500331834, 0.07967891157022677, 0.12013001207378693, 0.1614888705080375, 0.14181955251842737, 0.28968959755729884, 0.13398694078205153, 0.18380366294877604, 0.08494026362313889, 0.08612819714471698, 0.11819575258414261, 0.1873035720200278, 0.11668805731460452, 0.11653556823148392, 0.06647551810601726, 0.13357868534512818, 0.1913388367393054, 0.08895610633771867, 0.11671690459479578, 0.06231736857444048, 0.1166563676088117, 0.15022327657788992, 0.11638860814855434], [0.03059718834265368, 0.024164573260350153, 0.03518537349009421, 0.0505630332918372, 0.048432141775265336, 0.012462303348002024, 0.13157221488654613, 0.06461773693445139, 0.05463206944114063, 0.06150761866592802, 0.06947435875190422, 0.021759545379609335, 0.02708744395931717, 0.025750270106073003, 0.020889249208266847, 0.1077317820454482, 0.03684459676151164, 0.06059777158952784, 0.0612431469198782, 0.021021433130954392, 0.0987721374258399, 0.030042028483876493, 0.04212292544252705, 0.008106649765977636, 0.06138644821476191, 0.0394534276711056, 0.05783266664366238, 0.024110567173920572, 0.09168997799861245, 0.04905880385194905, 0.019490799932100344, 0.035240362922195345, 0.027612051453616004, 0.019572694072849117, 0.22876917355461046, 4.453337285667658, 24.449371956288815, 52.50205636024475, 56.42957501113415, 58.71995151042938, 52.91134759783745, 43.62891688942909, 41.655090004205704, 35.16659617424011, 21.218312233686447, 25.128758400678635, 35.82561381161213, 35.543820932507515, 19.93128139525652, 26.70086894184351, 35.48534967005253, 50.28135672211647, 33.44517074525356, 21.527881622314453, 7.162835095077753, 3.346036090515554, 1.268265782855451, 0.2961262740427628, 0.1115778659004718, 0.10793666675454006, 0.023754900321364403, 0.160035403969232, 0.16804705141112208, 0.4041044565383345, 1.112448493950069, 2.4617710523307323, 2.1889739530161023, 3.0195675836876035, 0.697003664681688, 7.381039336323738, 5.618839245289564, 5.126027539372444, 1.905734301544726, 6.825422225520015, 4.888398740440607, 4.808565024286509, 2.796077113598585, 3.9724514773115516, 2.9365410888567567, 3.7155375257134438, 0.3659684560261667, 0.29453442664816976, 0.10238488262984902, 0.20373012026539072, 0.1548606902360916, 0.44095268240198493, 3.9168998831883073, 6.351269893348217, 9.228259865194559, 7.488431548699737, 4.805174181237817, 3.8651312235742807, 5.835198210552335, 3.9917214307934046, 8.578635323792696, 3.7584813963621855, 8.211133293807507, 4.622339867055416, 4.493230395019054, 1.6492587514221668, 6.54637754894793, 6.456392202526331, 2.352384659461677, 3.495946596376598, 2.5922617502510548, 3.8429254526272416, 2.2326977318152785, 0.7087934820447117, 1.5391081245616078, 0.42219813563860953, 0.03936542751034722, 0.05092826271720696, 0.19625286367954686, 0.05850546804140322, 0.12718281213892624, 0.15380146738607436, 0.39221798186190426, 1.0640941886231303, 4.26107662729919, 23.36421098560095, 54.86088238656521, 44.29188631474972, 40.49850046634674, 24.327109716832638, 28.60422670841217, 12.651205491274595, 26.646028384566307, 77.03652665019035, 35.230071768164635, 25.32079439610243, 44.042509496212006, 51.82855010032654, 56.362687200307846, 61.58565513789654, 57.954060807824135, 45.524695962667465, 24.044974856078625, 5.449057230725884, 0.6652385566849262, 0.08504267258103937, 0.046349760741577484, 0.04430098044394981, 0.04543304137769155, 0.02330307339434512, 0.04323196495533921, 0.02113233040290652, 0.06409113120753318, 0.028750530109391548, 0.05861193283635657, 0.03533766961481888, 0.005379515414460911, 0.032768384044175036, 0.006536660939673311, 0.021639189435518347, 0.05395236978074536, 0.0710404387791641, 0.09213790865032934, 0.05186184367630631, 0.004780372637469554, 0.03840672485239338, 0.016167494177352637, 0.05142330861417577, 0.03612613472796511, 0.033612172555876896, 0.03453144490777049, 0.008562387811252847, 0.05018604453653097, 0.007534985470556421, 0.021940427177469246, 0.031485359140788205, 0.0350640917167766, 0.026437229826115072, 0.05213420445215888, 0.044284163377597, 0.051041978294961154, 0.030753701721550897, 0.03477919606666546, 0.07723402479314245, 0.033597574511077255, 0.08764246042119339, 0.00523944941960508, 0.030912109432392754, 0.10988557623932138, 0.049335765943396837, 0.02684275787032675, 0.035203697116230614, 0.027352793294994626, 0.009261874056392116, 0.013705102919630008, 0.04257867833075579, 0.03847487998427823, 0.011812790544354357, 0.02048231293883873, 0.05912294232985005, 0.008704322626726935, 0.0132241559731483, 0.035992700286442414, 0.03738828672794625, 0.04792515843291767, 0.031385083857458085, 0.05256293574348092, 0.017077276315831114, 0.06018608371959999, 0.04654513482819311, 0.06841578157036565, 0.07767761388095096, 0.026437485867063515, 0.049563007851247676, 0.05551108770305291, 0.05566801111854147, 0.22705101262545213, 5.531515181064606, 29.136561043560505, 61.362793296575546, 67.49208480119705, 69.15979251265526, 61.2801743298769, 53.98249872028828, 51.673028245568275, 41.91553942859173, 27.196586541831493, 30.64189776778221, 41.69274218380451, 40.01824803650379, 25.971919856965542, 34.76045876741409, 38.082445710897446, 42.042167633771896, 30.44214628636837, 20.311190709471703, 8.034797105938196, 2.7651728969067335, 0.7684581179637462, 0.2001536512398161, 0.06493749126093462, 0.21770683903014287, 0.765379392541945, 1.0481439507566392, 0.9740774938836694, 1.8696551187895238, 2.4968448327854276, 4.363349564373493, 4.086230909451842, 4.611139493063092, 4.8529646918177605, 8.729540426284075, 8.463568948209286, 10.479975398629904, 9.202396553009748, 9.814723245799541, 9.029498230665922, 9.266310073435307, 3.728758916258812, 2.443133289925754, 3.236100864596665, 2.8447612887248397, 0.6796406744979322, 0.29045653296634555, 0.3157461353112012, 0.08400080856517889, 0.11904606086318381, 1.1578367021866143, 3.9285132475197315, 5.97572416998446, 7.971297763288021, 6.5186708606779575, 6.2645442970097065, 8.155288640409708, 9.707595594227314, 6.108028795570135, 6.928535392507911, 7.0953830145299435, 10.236872043460608, 8.946331143379211, 5.459063993766904, 7.543584639206529, 6.40355508774519, 6.757697509601712, 5.5674707517027855, 7.190575506538153, 7.446329332888126, 6.447331113740802, 4.839380895718932, 4.1877063643187284, 3.4736446430906653, 2.107023987919092, 1.0577539913356304, 0.8883854420855641, 0.6702170020435005, 0.129759949631989, 0.3559585165930912, 0.02852150148100918, 0.3395448817173019, 0.8822612394578755, 4.346090415492654, 19.251207187771797, 48.637222945690155, 44.10147473216057, 42.25966416299343, 22.114528343081474, 28.147550113499165, 22.308355942368507, 31.27922236919403, 82.14029118418694, 42.93628625571728, 35.17538510262966, 51.419057473540306, 62.75732606649399, 66.32260635495186, 72.25688472390175, 68.70209947228432, 58.031588047742844, 33.486797511577606, 9.868536908179522, 1.1503507476300001, 0.06503534343210049, 0.06684435807983391, 0.0473501424130518, 0.048780201614135876, 0.04991522371710744, 0.04638519458239898, 0.061105374625185505, 0.009449590106669348, 0.023227066340041347, 0.04444600723218173, 0.05673023966664914, 0.05155451290193014, 0.014485417395917466, 0.03134871491056401, 0.03721344786754344, 0.0969452592835296, 0.026892197893175762, 0.07758422201732174, 0.024782626423984766, 0.010130531936738407, 0.05953205494733993, 0.07471529432223178, 0.031464805360883474, 0.07695977154071443, 0.04743916302686557, 0.014564160192094278, 0.026048711806652136, 0.03316418995382264, 0.0400324216025183, 0.0409297820442589, 0.02450670890539186, 0.08129159847158007, 0.050432960779289715, 0.014954618927731644, 0.04316999933507759, 0.049316347649437375, 0.09070641710422933, 0.09056591370608658, 0.1823536993470043, 0.1605349880992435, 0.1553809951292351, 0.11041348814615048, 0.10734423995018005, 0.2528343064477667, 0.1643427845556289, 0.18105480732629076, 0.14093914272962138, 0.16814212052850053, 0.05512924901267979, 0.1253678454668261, 0.17415071139112115, 0.1326546966447495, 0.19167958642356098, 0.10932379271253012, 0.20195186021737754, 0.11370659034582786, 0.06457190931541845, 0.17017508565913886, 0.11693386404658668, 0.18866887141484767, 0.15149931045016274, 0.13190613681217656, 0.14645656541688368, 0.15908204106381163, 0.20051279134349898, 0.21131169312866405, 0.12669210409512743, 0.17123766301665455, 0.1307689884561114, 0.08702305654878728, 0.2243983096559532, 0.4800191579852253, 7.990815415978432, 37.79312163591385, 72.81621471047401, 81.03116869926453, 80.68636760115623, 72.21067160367966, 61.75334393978119, 61.855136677622795, 49.99888747930527, 35.40494218468666, 37.17418424785137, 48.886846750974655, 51.24608315527439, 32.584353536367416, 40.05104027688503, 50.90122886002064, 64.39864799380302, 43.59601825475693, 27.946812584996223, 10.099137034267187, 4.724258948117495, 1.872133060824126, 0.5520367529243231, 0.2241862186929211, 0.20660233567468822, 0.5277215014211833, 0.5902086733840406, 0.5823949864134192, 1.2361231888644397, 3.2155349431559443, 5.952378222718835, 7.337491773068905, 7.963199922814965, 6.87625209800899, 14.648500867187977, 14.086253587156534, 16.082844100892544, 11.639115549623966, 17.798548936843872, 13.848548792302608, 18.02832070738077, 14.104371014982462, 16.295499689877033, 12.985458355396986, 9.295474458485842, 0.8417302987072617, 0.8707482134923339, 0.40187923063058406, 1.1633462877944112, 0.3449392563197762, 1.8941349489614367, 10.635289214551449, 16.089978218078613, 21.653195098042488, 15.273686069995165, 16.657073087990284, 14.224850200116634, 19.60270542651415, 13.469142951071262, 20.430595502257347, 12.586997486650944, 15.753850154578686, 12.28348022326827, 14.45361502468586, 8.80181159824133, 17.547308318316936, 17.68751509487629, 8.32147367298603, 12.264680732041597, 10.903038997203112, 11.714737191796303, 7.436989909037948, 3.405053336173296, 3.808641079813242, 1.9310991279780865, 1.0612176242284477, 0.44901584973558784, 0.7636970921885222, 0.27639060805086046, 0.366204755846411, 0.2833093539811671, 1.1251896852627397, 1.8567621731199324, 6.680887481197715, 28.694338873028755, 66.00296750664711, 58.43939356505871, 57.441916689276695, 35.13419531285763, 42.16920241713524, 19.797798357903957, 37.0104206353426, 86.58245801925659, 46.53081737458706, 41.74677528440952, 62.817925214767456, 74.25284922122955, 78.43403846025467, 84.93468403816223, 79.70861166715622, 66.5411402285099, 38.22627179324627, 12.770205605775118, 1.4970253827050328, 0.19746036763535812, 0.20180479623377323, 0.1750153728062287, 0.08688308007549495, 0.1336142490617931, 0.13050963752903044, 0.15032472816528752, 0.13072705711238086, 0.1347165906918235, 0.1066433111554943, 0.1726440922357142, 0.09577800941769965, 0.15049537760205567, 0.043614471578621306, 0.13023345469264314, 0.21122814214322716, 0.17180458962684497, 0.23913141048979014, 0.11197536019608378, 0.07601675417390652, 0.3122220322256908, 0.13392566906986758, 0.14518491021590307, 0.1686858624452725, 0.08443657541647553, 0.08976540353614837, 0.06308414813247509, 0.14411737531190738, 0.1762940190383233, 0.12048881821101531, 0.1347630936652422, 0.15724932221928611, 0.15943516977131367, 0.1809612225042656, 0.1041618810268119, 0.10974761098623276, 0.1732324669137597], [0.04958123499818612, 0.047472251681028865, 0.03689675490022637, 0.01710842981992755, 0.04674249044910539, 0.04330813528213184, 0.024133095066645183, 0.061669443966820836, 0.021584669411822688, 0.12594021944096312, 0.02877620285289595, 0.034006342029897496, 0.04926500216242857, 0.0777245473000221, 0.04986685424228199, 0.016940938221523538, 0.025209192499460187, 0.03399017434276175, 0.03427108094911091, 0.06330035059363581, 0.1161422448058147, 0.05173519988602493, 0.09073558350792155, 0.03975115505454596, 0.03650295278930571, 0.07534499920438975, 0.11135080581880175, 0.08595434162998572, 0.06726724124746397, 0.04019437306851614, 0.05340050505765248, 0.05815818745759316, 0.05185367634112481, 0.03961801376135554, 1.7752973944880068, 12.787981051951647, 42.63925239443779, 66.0499481856823, 66.25107899308205, 52.936650440096855, 50.70683889091015, 31.00798912346363, 33.52963641285896, 28.943852484226227, 27.877570800483227, 17.369371466338634, 25.919554866850376, 32.76626877486706, 31.21222246438265, 30.50917848944664, 40.54326206445694, 33.53495992720127, 20.389362014830112, 5.353682823479176, 1.5449392679147422, 0.13684950827155262, 0.04050266492413357, 0.07500634979805909, 0.172294050862547, 0.2972762763965875, 0.8264162298291922, 1.279002819210291, 2.4320081993937492, 3.7502306140959263, 1.9424556498415768, 2.6765288785099983, 2.534245513379574, 3.341355691663921, 2.4051146674901247, 8.122544847428799, 4.410779569298029, 6.847213106229901, 6.831756010651588, 5.785817010328174, 6.134747061878443, 4.207137571647763, 5.914509454742074, 3.728104163892567, 2.634048108011484, 1.1837295815348625, 0.2600241737673059, 0.07617764436872676, 0.3279279253911227, 0.8555262302979827, 0.5081781407352537, 2.969545880332589, 2.2871134243905544, 4.38024440780282, 4.187218090519309, 5.672526089474559, 3.954960540868342, 7.068686597049236, 7.223378671333194, 2.3724444955587387, 11.342755202203989, 6.166386064141989, 9.477285202592611, 7.628318192437291, 4.759670197963715, 3.097137571312487, 3.239785716868937, 3.3540667220950127, 1.232166769914329, 4.481545547023416, 5.302753681316972, 5.3525281604379416, 4.547217423096299, 6.336192777380347, 4.297840129584074, 1.996254944242537, 1.2308819638565183, 0.5508006911259145, 0.2713672479148954, 0.15739959228085354, 0.18923838069895282, 0.1428705672151409, 0.09564236708683893, 0.4418181750224903, 0.5975699471309781, 2.9225003672763705, 7.490266850218177, 29.643545038998127, 37.306192964315414, 41.04876793920994, 28.94718300551176, 24.252316430211067, 50.90124025940895, 39.002296552062035, 15.372213833034039, 25.550750456750393, 33.18842992186546, 35.48559285700321, 47.630565762519836, 55.61820074915886, 62.93209008872509, 62.372186332941055, 51.67173631489277, 38.05020064115524, 16.847638562321663, 3.2168261613696814, 0.11907521984539926, 0.07190808362793177, 0.05741994347772561, 0.04249733894539531, 0.047192966667353176, 0.09928237137501128, 0.03596065806050319, 0.011253718639636645, 0.07433288788888603, 0.05073920059658121, 0.035860534917446785, 0.053722830925835297, 0.04417367614223622, 0.07820136976079084, 0.01669392549956683, 0.02878264283936005, 0.02542335776524851, 0.15861009451327845, 0.04722503857919946, 0.027752484347729478, 0.04679745761677623, 0.046482007746817544, 0.025884539463731926, 0.05237156183284242, 0.03377711858775001, 0.04618496684997808, 0.05030982363678049, 0.020102674716326874, 0.055725349448039196, 0.04292191792046651, 0.05241779021162074, 0.049612397779128514, 0.03153092329739593, 0.020384701965667773, 0.02260463636048371, 0.08525428856955841, 0.04461793687369209, 0.02229291949333856, 0.03364776224771049, 0.08765298407524824, 0.017783669172786176, 0.04133769980398938, 0.04770716739585623, 0.039776499397703446, 0.031122910913836677, 0.02027108657784993, 0.027529474537004717, 0.047183292772388086, 0.08263848518254235, 0.07658927657757886, 0.02596969348815037, 0.040156553222914226, 0.041806740846368484, 0.04233332059811801, 0.01759520633640932, 0.062466881645377725, 0.08178313772077672, 0.033118199062300846, 0.08866870222846046, 0.07985002113855444, 0.06657029778580181, 0.041371972183696926, 0.0039642592764721485, 0.026139344736293424, 0.04573016762151383, 0.024928439888753928, 0.022027505219739396, 0.03977970918640494, 0.038418168769567274, 0.02624235668918118, 2.1030684001743793, 15.089270565658808, 49.99980702996254, 76.72859117388725, 76.84306383132935, 61.675185933709145, 59.08659763634205, 38.166140019893646, 42.82593257725239, 38.4905020147562, 28.60657498240471, 23.440546989440918, 33.44266667962074, 39.97388541698456, 29.860914275050163, 29.27875891327858, 39.17570784687996, 32.77215085923672, 18.091773502528667, 5.923510696738958, 1.4403963088989258, 0.23504357202909887, 0.08977357458206825, 0.31879612477496266, 0.48435205360874534, 0.8695871382951736, 2.114181141369045, 3.230760251171887, 3.747582631185651, 4.080863697454333, 6.005275184288621, 7.090467028319836, 7.488174112513661, 7.5519204419106245, 7.978904955089092, 9.344986751675606, 11.057229973375797, 9.219714123755693, 10.60151282697916, 12.620609533041716, 10.259555876255035, 9.169082790613174, 4.059610962867737, 3.0828987853601575, 1.9596371403895319, 2.0982407592236996, 0.8492348366416991, 0.4568698798539117, 0.9674264851491898, 0.7268987980205566, 0.6331901857629418, 0.8143491460941732, 1.1416076542809606, 3.934353534132242, 3.5520368115976453, 4.521194519475102, 3.9757166896015406, 6.235696244984865, 8.772605415433645, 7.096296390518546, 7.625238932669163, 7.7698691468685865, 11.55654788017273, 10.95137145370245, 7.111148843541741, 7.457952909171581, 6.223074747249484, 5.1034249272197485, 6.719299620017409, 7.173159616068006, 10.205701366066933, 8.88259906321764, 6.9991968758404255, 8.919854164123535, 6.496557472273707, 1.755718826316297, 1.200913090724498, 2.160116401501, 0.9319658379536122, 0.8969304116908461, 0.4653765546390787, 0.5532969790510833, 0.07264537023729645, 0.3649223246611655, 0.5661584576591849, 2.481593401171267, 8.480194956064224, 29.240730553865433, 36.84242404997349, 37.58935756981373, 34.62064906954765, 22.25232034921646, 45.24921074509621, 49.43463675677776, 26.032541804015636, 34.85340937972069, 47.28086672723293, 46.0466967523098, 55.11743322014809, 62.97822341322899, 69.91361886262894, 71.24100923538208, 61.97709873318672, 48.00549544394016, 23.249953016638756, 4.818411245942116, 0.13608190492959693, 0.030373165500350296, 0.06439211661927402, 0.043384450327721424, 0.048525897291256115, 0.04053231743455399, 0.0048533614699408645, 0.03934557505999692, 0.029652167177118827, 0.025870729950838722, 0.12172056813142262, 0.022831210335425567, 0.022843485457997303, 0.06440549754188396, 0.07182000554166734, 0.0446459752129158, 0.007872129244788084, 0.03781534447625745, 0.010336905579606537, 0.10084577967063524, 0.028196774765092414, 0.034477579829399474, 0.07561773105408065, 0.012979680468561128, 0.07656977293663658, 0.06017252468154766, 0.03084436248173006, 0.033042596478480846, 0.021223568182904273, 0.019764324024436064, 0.010373570457886672, 0.01604153872904135, 0.03419071748794522, 0.04975637071765959, 0.03478738566627726, 0.02749407594819786, 0.12846623780205846, 0.12398431892506778, 0.10811428495799191, 0.17786821816116571, 0.13378917326917872, 0.19899986393284053, 0.11855279983137734, 0.12501024903031066, 0.11483541922643781, 0.20706404058728367, 0.10644565496477298, 0.10511254251468927, 0.14843294920865446, 0.13091477594571188, 0.1813390795723535, 0.14726912806509063, 0.12411142655764706, 0.1470484133460559, 0.17569513554917648, 0.13025491760345176, 0.36821285902988166, 0.13588848640210927, 0.1328712998656556, 0.15745265583973378, 0.22985264979070053, 0.1901655161054805, 0.2535500633530319, 0.10010291211074218, 0.1516275090398267, 0.0994030742731411, 0.17491067061200738, 0.14733345742570236, 0.22849380708066747, 0.2316791791236028, 3.979793870821595, 22.451997734606266, 62.157239466905594, 88.3364363014698, 85.87047502398491, 72.22458645701408, 70.32489359378815, 47.50006556510925, 48.73173527419567, 42.98654615879059, 41.763403192162514, 27.069120481610298, 38.76084990799427, 47.91342258453369, 46.618254482746124, 44.02565360069275, 54.27137441933155, 43.28571930527687, 25.202958919107914, 7.130764340981841, 2.329090959392488, 0.5119024752639234, 0.23510701081249863, 0.4942312266211957, 0.3604673902736977, 0.9566503821406513, 1.3706717127934098, 3.249625526368618, 6.38953099027276, 7.552758771926165, 8.555451817810535, 10.140408519655466, 11.545127592980862, 14.992882087826729, 15.36807395517826, 19.974496476352215, 16.739059388637543, 15.913964062929153, 19.169158190488815, 18.319436386227608, 17.575073428452015, 15.307642947882414, 18.90462588518858, 11.249033231288195, 10.386830996721983, 4.186888933181763, 1.11212361138314, 0.4926370340399444, 1.320361343678087, 2.2053325502201915, 3.0140346055850387, 11.753704100847244, 10.595862530171871, 13.937344327569008, 16.33820939809084, 14.875130206346512, 10.466298032552004, 16.024673022329807, 17.057166919112206, 12.49013688415289, 27.283128798007965, 15.895930230617523, 23.497893512248993, 18.433234579861164, 15.51166445016861, 12.694692257791758, 12.039407920092344, 10.8144467510283, 9.710697177797556, 15.142542757093906, 18.80555760115385, 15.82682428881526, 14.531754031777382, 16.450831554830074, 12.544240280985832, 7.611719258129597, 2.876923237927258, 3.238900126889348, 0.4863819759339094, 0.6951957929413766, 0.5973391095176339, 0.3607191564515233, 0.2815033821389079, 0.8807406085543334, 1.2404792988672853, 4.816849529743195, 11.205609161406755, 39.22874540090561, 50.722064673900604, 58.16493049263954, 41.526436507701874, 35.300516188144684, 60.74149243533611, 46.392375603318214, 25.596817284822464, 38.893382996320724, 50.195781514048576, 53.358876183629036, 63.741241469979286, 72.6596175134182, 79.42246422171593, 81.65299013257027, 74.83572274446487, 59.48562942445278, 29.626227468252182, 5.56952596642077, 0.2527110802475363, 0.1784986280836165, 0.18136496568331495, 0.11274878939730115, 0.1893496880074963, 0.1619412243599072, 0.11342810685164295, 0.15964586549671367, 0.15352853515651077, 0.1491670816903934, 0.2126331315957941, 0.17226586409378797, 0.16234064823947847, 0.24887496343581006, 0.1509703669580631, 0.14894252264639363, 0.058245044710929506, 0.24835765681928024, 0.07438065993483178, 0.15485812240513042, 0.14166325621772557, 0.182822959322948, 0.1222261562361382, 0.10292754843248986, 0.17107639432651922, 0.22804105246905237, 0.14366502146003768, 0.133456245821435, 0.16702501015970483, 0.16841491917148232, 0.10394642071332783, 0.23853407066781074, 0.16492474707774818, 0.1439662740449421, 0.15600570535752922, 0.09773082259926014], [0.085804049303988, 0.07200701191322878, 0.06920766056282446, 0.014082855159358587, 0.019075416166742798, 0.019146363629261032, 0.0460976309113903, 0.04304606809455436, 0.08707587519893423, 0.0570992095163092, 0.046212051529437304, 0.040344019726035185, 0.05494520009960979, 0.07492122545954771, 0.009197146719088778, 0.06809017169871368, 0.042264200674253516, 0.06037438513885718, 0.011309867677482544, 0.042325561444158666, 0.05233567157119978, 0.016184235173568595, 0.01697222160146339, 0.05098220943182241, 0.03095266038144473, 0.04994213770260103, 0.05083230302261654, 0.04919538871035911, 0.1710011702380143, 0.02459556439134758, 0.019138871648465283, 0.027135162199556362, 0.02155072543246206, 0.6753004167694598, 10.241669286042452, 44.76826675236225, 67.84618780016899, 69.40278187394142, 57.98173472285271, 42.663799077272415, 38.95670659840107, 30.766010507941246, 25.441322028636932, 20.05880255252123, 26.589548215270042, 37.406781166791916, 36.830595284700394, 30.322141125798225, 42.7734649926424, 56.469936445355415, 28.59627563506365, 12.97366188839078, 2.989591467194259, 0.2845003525726497, 0.06329655821900815, 0.08167921478161588, 0.05585693594184704, 0.4586418019607663, 0.3645638673333451, 0.5277069553267211, 2.459097420796752, 5.362691665068269, 4.094510190188885, 2.3783232551068068, 4.348800620064139, 5.7298521883785725, 3.8511332497000694, 4.889007182791829, 4.133369754999876, 5.704827206209302, 9.884687941521406, 10.211129374802113, 6.640780633315444, 8.944661132991314, 9.455186538398266, 5.413633156567812, 0.991620677523315, 1.021839149761945, 1.670732230413705, 1.3049638574011624, 0.9076243441086262, 1.0956580261699855, 0.2449375731521286, 0.1590456164558418, 0.50530472304672, 4.958020029589534, 10.72722053155303, 8.48395960405469, 14.384079705923796, 4.89211636595428, 4.422741802409291, 2.6183544751256704, 4.225769396871328, 4.8878829181194305, 2.7513596881181, 4.782003499567509, 5.99127103574574, 10.417219866067171, 0.9785920078866184, 6.083398992195725, 1.2626366224139929, 3.593375268392265, 5.485655916854739, 4.729097513481975, 5.925511289387941, 4.485301170498133, 3.798807207494974, 6.189931500703096, 3.3805904863402247, 2.1002548886463046, 1.802800081204623, 3.029463440179825, 2.39830092061311, 0.48954584053717554, 0.4185725067509338, 0.498688209336251, 0.15751308150356635, 0.16116799553856254, 0.05380589951528236, 0.27547634148504585, 2.4861234705895185, 8.567395526915789, 25.123925060033798, 39.38164159655571, 36.572011560201645, 54.07812438905239, 53.750760555267334, 17.58872229605913, 15.02889845520258, 16.53421238064766, 13.758389130234718, 26.944745555520058, 41.167291179299355, 44.096120819449425, 43.701002821326256, 51.35922208428383, 57.945005893707275, 62.51598201692104, 53.308080509305, 23.238350339233875, 4.469070816412568, 0.08048209347180091, 0.0714669658918865, 0.015899534337222576, 0.15265229623764753, 0.07053197114146315, 0.07547094908659346, 0.07533736992627382, 0.01787241704732878, 0.03315836038382258, 0.03900227238773368, 0.06543793628225103, 0.0749863192322664, 0.043203811583225615, 0.0234466919573606, 0.02961567948659649, 0.03725107846548781, 0.04203893658996094, 0.022262090678850655, 0.019141573066008277, 0.033377204890712164, 0.027241296738793608, 0.017867850983748212, 0.05522966159333009, 0.0297030989167979, 0.03398984408704564, 0.057710813416633755, 0.02620420287712477, 0.007663981868972769, 0.04444935802894179, 0.0691181056026835, 0.08608006144640967, 0.002992710042235558, 0.02684833696548594, 0.03883788667735644, 0.05387908640841488, 0.0363569723413093, 0.007102532772478298, 0.054960109846433625, 0.011235325437155552, 0.04082087558344938, 0.02913922809966607, 0.0630318489857018, 0.0627282660570927, 0.023581412169733085, 0.06984951440244913, 0.026343513272877317, 0.05373535837861709, 0.03017070390342269, 0.021825401709065773, 0.0560325169499265, 0.060969869591644965, 0.05114466184750199, 0.07780495900078677, 0.026010739820776507, 0.06892666860949248, 0.028232373733771965, 0.035237056654295884, 0.019803988107014447, 0.03701878995343577, 0.030812756267550867, 0.04269826800737064, 0.01984563743462786, 0.07199079598649405, 0.06565232790308073, 0.00960780393143068, 0.05505909379280638, 0.06346130758174695, 0.06797757305321284, 1.1272223386913538, 12.737020086497068, 52.82458305358887, 77.46552363038063, 80.14298155903816, 66.97465896606445, 50.64446143805981, 47.166732251644135, 36.754432171583176, 32.15881057083607, 27.911140099167824, 36.607957631349564, 36.19578994810581, 36.89759708940983, 36.750153601169586, 46.35614834725857, 40.22241108119488, 25.403312668204308, 10.902605820447206, 2.609477201476693, 0.20940014335792512, 0.08081100590061396, 0.16563268174650148, 0.6007847527507693, 0.8963022578973323, 1.2499930383637547, 2.9320098320022225, 4.276494774967432, 4.975605485960841, 5.114027783274651, 9.457138683646917, 8.67970135062933, 9.698652774095535, 7.087629530578852, 7.131401281803846, 8.840334881097078, 6.963065089657903, 10.244045108556747, 12.8883346170187, 7.37509218044579, 4.273056909441948, 11.356309074908495, 8.215104080736637, 4.0136481542140245, 0.9410496661439538, 1.3532256614416838, 1.528803315013647, 1.1795031395740807, 1.4381429110653698, 0.1982234141905792, 0.4300764191430062, 0.377346589230001, 5.711718136444688, 10.08466076105833, 9.807412438094616, 13.20968147367239, 4.924128223210573, 3.3153912099078298, 3.2152668200433254, 2.784908562898636, 4.908339120447636, 3.4212948521599174, 8.687341790646315, 6.4324074145406485, 5.865056533366442, 4.923809040337801, 5.896237185224891, 3.8646173011511564, 6.549623524770141, 10.014910753816366, 9.677619002759457, 7.653302326798439, 9.05160354450345, 9.065908826887608, 7.139823529869318, 5.910763330757618, 5.6288099102675915, 3.6807872029021382, 4.238660680130124, 6.1749413050711155, 4.205991933122277, 2.112000295892358, 1.6582349385134876, 0.309824924916029, 0.1503166535985656, 0.07074873763485812, 0.32725809258408844, 1.7665013414807618, 8.747592307627201, 23.92084501683712, 38.34261775016785, 33.619026616215706, 40.955209359526634, 59.020625576376915, 24.57553468644619, 19.16070744395256, 29.914453402161598, 23.829651810228825, 37.60187789797783, 56.32091224193573, 55.28863303363323, 53.9116857200861, 57.721672877669334, 67.02801570296288, 71.73750579357147, 61.8896122276783, 29.466121159493923, 5.8600137289613485, 0.11242181397392415, 0.015918088029138744, 0.035236563126090914, 0.03496270321193151, 0.058020463402499445, 0.024364197997783776, 0.055276027269428596, 0.046668316499562934, 0.05392572667915374, 0.006842332550149877, 0.011093220855400432, 0.10094973229570314, 0.07262053797603585, 0.0614314223639667, 0.02477331432601204, 0.020715851969725918, 0.02364843552641105, 0.09438359556952491, 0.03216786040866282, 0.016590147279202938, 0.020518201345112175, 0.047421826457139105, 0.035680367436725646, 0.0674756288935896, 0.04789756909303833, 0.08054792197071947, 0.04912112941383384, 0.015957724281179253, 0.04038952822156716, 0.05340027499187272, 0.04922756823361851, 0.07488743547582999, 0.029770159380859695, 0.022918139948160388, 0.06804877470131032, 0.16146049078088254, 0.17270600219490007, 0.19629234593594447, 0.1936381438281387, 0.14864021621178836, 0.11347435007337481, 0.2441118299611844, 0.19623487401986495, 0.13069082546280697, 0.19878953928127885, 0.13158916553948075, 0.1802763983141631, 0.15799003012944013, 0.21282456116750836, 0.20365725620649755, 0.19063284649746493, 0.12969931616680697, 0.16170633462024853, 0.11267840411164798, 0.17511571117211133, 0.16083092690678313, 0.09929849082254805, 0.1220126922999043, 0.10369012743467465, 0.1459213433554396, 0.18290018721017987, 0.09705863718409091, 0.18301982141565531, 0.2540684980340302, 0.12338306056335568, 0.14565641147783026, 0.17204569856403396, 0.08956144651165232, 1.677936881314963, 19.835613928735256, 66.11233323812485, 88.84508460760117, 91.24869123101234, 76.45132005214691, 61.89172111451626, 55.5809323489666, 46.96206383407116, 39.204833284020424, 32.15116158127785, 40.24254620075226, 51.8633334338665, 47.563104182481766, 43.81061173975468, 59.23144966363907, 69.31626811623573, 35.68111516535282, 15.821247138082981, 3.945479574613273, 0.4895279399352148, 0.19915880227927119, 0.3020803170511499, 0.5494106782134622, 0.858376967953518, 0.8485914836637676, 2.7678351290524006, 6.467868536710739, 13.179640285670757, 10.96388703212142, 12.64393363147974, 14.39113212749362, 17.9113781824708, 13.575372900813818, 15.227126218378544, 16.491890251636505, 16.94457706063986, 20.3076284006238, 24.688698314130306, 19.824235439300537, 19.812562465667725, 22.503832653164864, 18.76724235713482, 5.6274709571152925, 3.58235752210021, 4.880610108375549, 3.8890922628343105, 3.9358960138633847, 3.375539844855666, 1.078004410956055, 0.47235918464139104, 0.9908331104088575, 4.925472876057029, 4.390150001272559, 3.5882317693904042, 12.036177143454552, 12.768824379891157, 12.472955156117678, 11.689623389393091, 15.05580386146903, 11.327997744083405, 9.220443684607744, 18.90366643667221, 17.446180544793606, 21.922900825738907, 11.649280954152346, 16.678631231188774, 10.635040327906609, 15.183059982955456, 15.623401254415512, 17.193406708538532, 18.79932213574648, 14.574107509106398, 13.264382388442755, 17.81862895935774, 12.671953327953815, 11.19401028379798, 8.38184293359518, 8.839706014841795, 9.271604139357805, 4.061743123456836, 3.4258752688765526, 1.129625947214663, 0.2806524949846789, 0.3433837741613388, 0.2223268270608969, 0.6109308020677418, 3.6393653880804777, 11.573757156729698, 33.69900472462177, 51.49826042354107, 49.806750789284706, 69.75000724196434, 64.84131664037704, 27.01292149722576, 25.92945333570242, 28.581619821488857, 24.23734523355961, 40.01563377678394, 60.07170997560024, 60.75813174247742, 63.30404832959175, 67.2233784198761, 78.4708508849144, 81.65374249219894, 75.84738805890083, 37.91687719523907, 7.50306123867631, 0.2643684984650463, 0.1538456548587419, 0.07659982991754077, 0.31513172609265894, 0.09269755479181185, 0.10856305423658341, 0.1542714991956018, 0.15118112205527723, 0.10643720190273598, 0.10584179908619262, 0.17966709507163614, 0.3500902955420315, 0.13282757252454758, 0.12703669810434803, 0.15662481979234144, 0.1101640152046457, 0.1823377431719564, 0.17914411844685674, 0.07390132901491597, 0.11736420579836704, 0.0784418849798385, 0.10316332132788375, 0.11588758425205015, 0.1775462448131293, 0.11441716706031002, 0.20217588491505012, 0.07979374408023432, 0.1457768026739359, 0.1799557014601305, 0.1503549632616341, 0.20693475846201181, 0.15435536188306287, 0.11894468349055387, 0.10514355686609633, 0.13149222620995715], [0.10266683195368387, 0.2149815094890073, 0.156692904420197, 0.05043096069130115, 0.10151697060791776, 0.038341764666256495, 0.04619349041604437, 0.02694672904908657, 0.16872023872565478, 0.05757578335760627, 0.032344962819479406, 0.06063291228201706, 0.04957365395966917, 0.0657972990302369, 0.06232688290765509, 0.05523958781850524, 0.054569476706092246, 0.039052734719007276, 0.06344498033286072, 0.047249024792108685, 0.04558528555207886, 0.003451829497862491, 0.14571464038453996, 0.012436833767424105, 0.05417522188508883, 0.03895347617799416, 0.16343552386388183, 0.1816391892498359, 0.20940367598086596, 0.04979275821824558, 0.011127119378215866, 0.08347697104909457, 0.12007381665171124, 2.6811931282281876, 38.009246438741684, 69.15258809924126, 70.26867941021919, 61.03203624486923, 57.55231216549873, 41.975116431713104, 28.26337169855833, 31.513861678540707, 27.284829206764698, 24.363279975950718, 21.850216425955296, 29.999937415122986, 41.093924716115, 48.19049991667271, 29.708320163190365, 17.896342389285564, 7.1485336124897, 1.4841148629784584, 0.2390619009383954, 0.16807146806968376, 0.14474085357505828, 0.11011242851964198, 0.2942109986906871, 1.1621265532448888, 2.3702793242409825, 2.836447097361088, 6.229835534468293, 3.3189302450045943, 3.6551373917609453, 6.14333507604897, 5.337167484685779, 3.6383123695850372, 4.794597448781133, 4.428268130868673, 7.653580661863089, 6.239783875644207, 8.627858832478523, 7.9168799333274364, 5.314324060454965, 6.544118095189333, 5.532730640843511, 4.624386057257652, 0.8186696330085397, 1.031323322094977, 1.2217109184712172, 1.4316895511001348, 0.4665632190881297, 1.8090597703121603, 0.1847764998092316, 0.6361293280497193, 5.5122829880565405, 33.12889851629734, 48.20615507662296, 43.91706682741642, 38.60456049442291, 21.956194639205933, 9.639415852725506, 4.010993996635079, 2.4356006691232324, 4.91856912150979, 5.54445443674922, 6.144918641075492, 4.341849843040109, 3.80309219006449, 4.874457763507962, 4.07422830350697, 2.310722745023668, 1.5788643225096166, 6.499596834182739, 2.3425526870414615, 4.418653696775436, 5.139000043272972, 4.946204563602805, 7.698469078168273, 4.481339883059263, 1.3867744174785912, 3.061622539535165, 2.343242112547159, 3.5609915060922503, 1.778335568960756, 1.1261866567656398, 0.4517848027171567, 0.18051884311717004, 0.08817925583571196, 0.08751635468797758, 0.13001907791476697, 0.0689594195864629, 1.4878451940603554, 5.879794042557478, 18.121062330901623, 35.009140223264694, 42.05037899315357, 27.651752717792988, 26.926896013319492, 29.36637081205845, 13.494774475693703, 23.073678575456142, 19.269039630889893, 18.121936284005642, 15.7814528234303, 31.931392773985863, 37.55285672843456, 47.53984563052654, 58.140125423669815, 63.98291230201721, 47.692133858799934, 13.13873453065753, 2.3267533723264933, 0.2421898307511583, 0.08770232947426848, 0.0645500530663412, 0.21718203672207892, 0.2020949759753421, 0.37860227341298014, 0.08935436504543759, 0.14149521914077923, 0.11605784777202643, 0.1082187496649567, 0.04705737257609144, 0.04198336828267202, 0.018498207100492436, 0.06412834991351701, 0.09110806742683053, 0.06651174975559115, 0.059811128448927775, 0.09485587608651258, 0.009412889976374572, 0.03559021504770499, 0.08396371602430008, 0.07120409718481824, 0.03920546871086117, 0.06475622169091366, 0.05688785699021537, 0.10839518785360269, 0.07370158738922328, 0.05041554999479558, 0.11077356335590594, 0.045435501597239636, 0.05192620272282511, 0.08991497597889975, 0.1006562054681126, 0.04358791011327412, 0.10900783076067455, 0.07237853846163489, 0.08294748578919098, 0.008405802072957158, 0.07312885718420148, 0.05614371293631848, 0.025545095959387254, 0.05460436506837141, 0.09336425573565066, 0.0692620080371853, 0.06327584487735294, 0.005346513034965028, 0.05400257607107051, 0.037086076772538945, 0.06972953880904242, 0.040727517116465606, 0.06300395907601342, 0.04097553915926255, 0.05761304288171232, 0.04252751466992777, 0.027601151159615256, 0.05563584272749722, 0.06987939326791093, 0.019947914661315735, 0.031599575668224134, 0.09080941978027113, 0.06389478119672276, 0.14435320015763864, 0.20003855897812173, 0.07544300722656772, 0.008176878272934118, 0.0947983522200957, 0.11544497479917482, 3.702712976373732, 45.54941363632679, 77.89730206131935, 77.83259153366089, 71.61395162343979, 64.83320787549019, 51.743541061878204, 36.31467416882515, 36.86931900680065, 32.478020042181015, 26.410480923950672, 28.318668231368065, 39.33441013097763, 45.07891908288002, 44.80035983026028, 31.466052643954754, 19.421398155391216, 7.3838796839118, 1.5729341469705105, 0.21607968024909496, 0.14004283613758162, 0.43249495967756957, 0.45628860010765493, 1.024886704981327, 3.0011103115975857, 3.939475421793759, 3.896070350892842, 5.385705605149269, 7.350317509844899, 5.9628357365727425, 5.7411945797502995, 7.5548467598855495, 9.428270682692528, 9.573736377060413, 8.747374769300222, 7.239800915122032, 9.319643061608076, 8.547151163220406, 8.296463415026665, 6.883299769833684, 8.414837513118982, 9.48342852294445, 7.646184833720326, 2.9749579774215817, 2.00570076238364, 2.104456750676036, 3.12007955275476, 1.5866504609584808, 3.6542624887079, 0.5192474811337888, 1.235047490336001, 6.808611452579498, 35.741949900984764, 51.890167593955994, 51.99695326387882, 44.833809435367584, 25.493050552904606, 7.376252068206668, 3.192026079632342, 0.7818300160579383, 5.38219079375267, 4.23743762075901, 6.262175124138594, 2.8194529842585325, 3.5512255551293492, 4.167487174272537, 5.4434107337147, 4.154464323073626, 3.9643277507275343, 9.240423012524843, 7.303570043295622, 6.123084062710404, 8.803686797618866, 8.735771141946316, 9.844905976206064, 6.834120908752084, 6.366734113544226, 5.917956344783306, 5.925874644890428, 7.8775558434426785, 5.2073583751916885, 5.448656352236867, 4.466582899913192, 1.72031968832016, 1.274336432106793, 0.4344469861825928, 0.07000063051236793, 0.12905338051496074, 0.7059080118779093, 6.075334874913096, 19.333083294332027, 33.35642650723457, 41.81394428014755, 37.57611148059368, 23.603147864341736, 27.103514336049557, 17.481210865080357, 27.66723308712244, 27.446759417653084, 26.405298002064228, 28.402138352394104, 41.930415630340576, 47.876629158854485, 55.42420595884323, 63.68515647947788, 71.76817774772644, 55.04020616412163, 15.888374336063862, 2.6398589462041855, 0.17398953175870702, 0.07193125347839668, 0.05370327904529404, 0.10400642335298471, 0.16109525022329763, 0.21434017515275627, 0.06833295788965188, 0.07942129726870917, 0.059751188891823404, 0.05594643524091225, 0.012274883229110856, 0.03951946026063524, 0.0625791611673776, 0.050332629834883846, 0.024966755117930006, 0.03964412993809674, 0.034950828849105164, 0.014566253048542421, 0.014763831313757692, 0.05434103622974362, 0.05558640827075578, 0.0551122946490068, 0.06945348955923691, 0.03529544883349445, 0.05650892751873471, 0.0702100497437641, 0.04528190300334245, 0.039691909405519255, 0.0683457228296902, 0.08457495627226308, 0.051077426978736185, 0.07464718000846915, 0.04602919376338832, 0.055705793856759556, 0.24784784589428455, 0.30359406082425267, 0.22845919331302866, 0.1412709421128966, 0.2024142033769749, 0.0986185202782508, 0.09792290526092984, 0.10163837854634039, 0.2381312774377875, 0.20656485721701756, 0.2213194506475702, 0.2387336638639681, 0.1349541373201646, 0.16730659583117813, 0.18238632415886968, 0.15448127465788275, 0.21579560096142814, 0.11618958640610799, 0.1559758561779745, 0.12377371225738898, 0.14237310562748462, 0.17183589341584593, 0.17154786590253934, 0.08430076981312595, 0.15148718375712633, 0.3849592729238793, 0.27071715623605996, 0.2973346092039719, 0.3451939910883084, 0.29251887230202556, 0.11228603063500486, 0.3113473072880879, 0.4794753121677786, 7.660787925124168, 58.03761072456837, 88.28443989157677, 90.64236536622047, 81.11864000558853, 74.50036033987999, 56.37907192111015, 45.44962719082832, 44.97909463942051, 41.34379170835018, 36.51625715196133, 31.741129383444786, 43.20080146193504, 55.20208887755871, 60.41709244251251, 43.1412548571825, 24.267990589141846, 9.84737204387784, 2.373397769406438, 0.5767947994172573, 0.33702371700201184, 0.4547123675001785, 0.37576661619823426, 0.9386477794032544, 3.4139626706019044, 5.600802563130856, 8.62573854625225, 15.660744700580835, 11.834938991814852, 10.323772430419922, 16.867678686976433, 14.09277118742466, 12.853871416300535, 18.108486905694008, 13.944069966673851, 17.66556177288294, 17.031970471143723, 19.52150758355856, 20.657405331730843, 17.727722637355328, 20.824784450232983, 17.58435633033514, 15.320808291435242, 9.271065518260002, 3.569475025869906, 2.047282406128943, 3.5477955266833305, 2.2888774797320366, 4.117569727823138, 0.6529016874264926, 1.8788909981958568, 6.613847203552723, 26.166862696409225, 33.92585635185242, 34.37480226159096, 29.80861958116293, 21.59801635891199, 16.021857373416424, 10.58639818802476, 10.504210498183966, 15.062145721167326, 12.713484149426222, 12.582122348248959, 12.429619431495667, 14.431333970278502, 14.500657450407743, 14.593157786875963, 11.25359583646059, 11.159382741898298, 14.749850928783417, 10.94319999217987, 13.838785216212273, 15.602023601531982, 15.858613383024931, 18.060721568763256, 14.289407785981894, 7.457350166514516, 10.227014422416687, 11.131391543895006, 12.11109297350049, 8.438308853656054, 5.384154338389635, 5.4228828102350235, 1.6032081912271678, 0.7470975641626865, 0.29349265911150724, 0.250146544422023, 0.34213408653158695, 2.163136526942253, 7.937943153083324, 25.043126195669174, 44.8863910138607, 52.94190555810928, 40.92298708856106, 40.424757823348045, 42.59792201220989, 22.83277340233326, 32.137877494096756, 28.546390011906624, 27.226508036255836, 28.308353684842587, 45.45709379017353, 56.773027181625366, 64.33035805821419, 77.2759898006916, 79.81853976845741, 69.65439677238464, 22.22320631146431, 3.717782492749393, 0.3150932234711945, 0.14390390395419672, 0.19413849979173392, 0.31533741974271834, 0.36937458731699735, 0.5310286302119493, 0.3358802158618346, 0.21568836062215269, 0.15973896050127223, 0.16490711364895105, 0.16645790543407202, 0.08660533872898668, 0.12829653831431642, 0.22449107811553404, 0.13166470133000985, 0.14205070183379576, 0.1488641815376468, 0.1250146425445564, 0.14393581630429253, 0.11323899278067984, 0.1555765065131709, 0.2750361291691661, 0.2656623290386051, 0.2324109961045906, 0.23054116987623274, 0.2227945433696732, 0.21320167608791962, 0.17902139690704644, 0.30189875804353505, 0.12809134932467714, 0.2475042166770436, 0.2281342662172392, 0.22278802731307223, 0.17465430311858654], [0.131086538603995, 0.16294297529384494, 0.11758426000596955, 0.028245825160411187, 0.04085444663360249, 0.04234943262417801, 0.060550407724804245, 0.03435730737692211, 0.13838731247233227, 0.025008929515024647, 0.01119551292504184, 0.10417386671178974, 0.09091821862966754, 0.07956563014886342, 0.13540291402023286, 0.03210855538782198, 0.01921109746035654, 0.050235382514074445, 0.09073447770788334, 0.05057119320554193, 0.02149859141354682, 0.12403266984620132, 0.06376183286192827, 0.05636075773509219, 0.06726946026901715, 0.09609397879103199, 0.1432154729263857, 0.35913366184104234, 0.28888315020594746, 0.19395406125113368, 0.02729995052504819, 0.04810485464986414, 3.3078177412971854, 30.780962705612183, 63.58092047274113, 70.82998529076576, 72.22701832652092, 55.77061057090759, 44.437414705753326, 34.55853760242462, 24.38532829284668, 26.189760267734528, 28.681499361991882, 35.37655010819435, 36.53931051492691, 34.28676478564739, 37.746460139751434, 42.214818969368935, 22.367351576685905, 4.851505095139146, 0.6584400089923292, 0.014019804148119874, 0.02837532250850927, 0.09958993963664398, 0.42972838156856596, 0.5112674937117845, 2.2004652488976717, 2.9124090587720275, 4.5614096615463495, 5.858066808432341, 5.064532114192843, 5.064670806750655, 3.132857079617679, 8.301936071366072, 4.46574741974473, 4.84293133020401, 3.8919212110340595, 6.892211241647601, 5.769091257825494, 5.702643748372793, 7.831491390243173, 7.472409708425403, 4.581489209085703, 3.3485786290839314, 7.371719861403108, 5.552807338535786, 4.740687366575003, 5.238032704219222, 9.014410190284252, 7.118520447984338, 7.780562248080969, 7.055078102275729, 2.488735355436802, 3.6532811913639307, 22.429960817098618, 56.68652482330799, 66.84377878904343, 57.19312123954296, 55.97983114421368, 57.46611759066582, 21.42093636095524, 12.257208433002234, 6.774207623675466, 7.623997824266553, 7.813028180971742, 9.650254771113396, 6.761545753106475, 0.7661549665499479, 2.196787758730352, 1.8801496806554496, 0.6482844008132815, 0.6326015142258257, 7.406041994690895, 5.680820094421506, 3.6750122252851725, 7.071885550394654, 6.751625910401344, 4.134018570184708, 3.9900086726993322, 7.4221740290522575, 3.62993904389441, 3.2548846816644073, 7.87167708389461, 3.663800689391792, 1.9043560442514718, 3.4933185623958707, 0.9605677344370633, 0.14692014054162428, 0.05823803512612358, 0.1801856781821698, 0.053199661342659965, 0.3429292532382533, 1.049519358202815, 4.816499948501587, 10.91442983597517, 23.135003484785557, 29.23722144216299, 49.34573672711849, 41.18292734026909, 39.89853546023369, 31.550400517880917, 31.95001557469368, 31.272373236715794, 23.113272450864315, 27.073412351310253, 26.68136078864336, 44.57001619040966, 52.01253242790699, 59.06994692981243, 62.51600481569767, 30.812668204307556, 8.539692163467407, 0.6154322542715818, 0.0334571601706557, 0.2185065476805903, 0.27349522279109806, 0.41509376373142004, 0.5230929341632873, 0.3533902997151017, 0.16026511351810768, 0.11882628125022165, 0.016388897238357458, 0.007779138604746549, 0.06803425829275511, 0.04687265201937407, 0.013170647125662072, 0.005955941051070113, 0.09976839646697044, 0.043369484919821844, 0.02787102017464349, 0.019693495305546094, 0.03683686358272098, 0.04028000206744764, 0.07862319907872006, 0.02672556904144585, 0.026635303474904504, 0.08167407911969349, 0.06545668293256313, 0.02182228839956224, 0.03319295559776947, 0.13461217051371932, 0.0355258968193084, 0.021222343639237806, 0.07641766977030784, 0.023751824119244702, 0.09987724726670422, 0.11265948676737025, 0.11037321921321563, 0.03264968123403378, 0.0636876626231242, 0.028484978538472205, 0.0159120116950362, 0.05144171758729499, 0.06326184055069461, 0.05077351750514936, 0.05419714121671859, 0.05677251610904932, 0.04031964017485734, 0.027370348798285704, 0.07686219396418892, 0.10248044156469405, 0.07462596200639382, 0.02870365420676535, 0.021848823889740743, 0.11210938464500941, 0.06490266227046959, 0.03334873239509761, 0.0030239349780458724, 0.0506305798626272, 0.13276117999339476, 0.10646476526744664, 0.12412772412062623, 0.006807522577219061, 0.22837478143628687, 0.19559579581255093, 0.12725840730126947, 0.08757205287110992, 0.12174091782071628, 4.182477844879031, 36.03874057531357, 72.01189666986465, 80.7515037059784, 82.34782844781876, 64.73412439227104, 54.88262102007866, 43.4735432267189, 33.03920052945614, 33.362703770399094, 37.843221947550774, 38.46023663878441, 35.62572553753853, 31.011655926704407, 36.42853885889053, 42.39284321665764, 20.587715171277523, 4.9617808777838945, 0.42710922367405146, 0.029863361996831372, 0.08751486297114752, 0.4779712460003793, 1.5626545110717416, 1.488493059296161, 3.7869570683687925, 4.675372671335936, 9.390202425420284, 6.387573145329952, 7.8929787408560514, 7.895368337631226, 8.912940435111523, 8.61096303910017, 8.173462115228176, 7.473617093637586, 8.649506270885468, 8.14593069255352, 10.620334167033434, 7.310991995036602, 5.353865688666701, 7.240571323782206, 4.211909640580416, 4.634220404550433, 5.679056039080024, 3.1603676034137607, 5.33069453202188, 6.438912665471435, 9.064015578478575, 9.400933049619198, 9.736401848495007, 7.680075690150261, 3.5150080360472202, 5.65830915234983, 27.826803624629974, 65.23432955145836, 75.45625224709511, 67.6025752723217, 70.4601663351059, 67.11417227983475, 24.89713802933693, 12.75967637076974, 5.709063028916717, 9.258073065429926, 7.376855285838246, 7.254047775641084, 6.587693206965923, 2.0572283724322915, 1.7861912911757827, 2.826519892551005, 4.0680075623095036, 2.751792627386749, 6.599147692322731, 6.347278682515025, 6.723278006538749, 7.440991094335914, 7.5050433073192835, 9.900971967726946, 7.45763847604394, 10.92814140021801, 8.783971555531025, 9.302970506250858, 8.994118329137564, 8.620782662183046, 5.15653420239687, 6.345270490273833, 5.358073012903333, 1.8967872066423297, 0.3452350466977805, 0.4368008114397526, 0.4212228942196816, 0.13054791750619188, 0.8011828525923193, 3.6443074978888035, 11.729794833809137, 24.46704860776663, 31.482602655887604, 45.7535956799984, 40.978775694966316, 32.43901513516903, 30.143930688500404, 29.356042966246605, 29.905309192836285, 28.936294689774513, 39.96942065656185, 38.25938321650028, 52.95351393520832, 63.27357396483421, 66.34852856397629, 70.61422526836395, 38.734106943011284, 10.11275740340352, 0.597394562792033, 0.06352862779749557, 0.27234560635406524, 0.02956954573164694, 0.1942541857715696, 0.16083278227597475, 0.23038711486151442, 0.06702275553834625, 0.06906447059009224, 0.06589493597857654, 0.041601396005717106, 0.04693529299402144, 0.09234104931238107, 0.06728353138896637, 0.06128664419520646, 0.07117261528037488, 0.028426935168681666, 0.04488685037358664, 0.0841280423628632, 0.056090471261995845, 0.0219833956725779, 0.03716175357112661, 0.016371325036743656, 0.021892801705689635, 0.022914521978236735, 0.049724217169568874, 0.05963621908449568, 0.03480093728285283, 0.06415030264179222, 0.035466172485030256, 0.04718686992418952, 0.060269630994298495, 0.008123613406496588, 0.04616376740159467, 0.30270805524196476, 0.27194656839128584, 0.23858027678215876, 0.1984348223777488, 0.12253494161996059, 0.0860210310202092, 0.14878987771226093, 0.17476702050771564, 0.2543444879120216, 0.14581157971406356, 0.20669848832767457, 0.1869593490846455, 0.2350151477730833, 0.24388370860833675, 0.3283810510765761, 0.15535265993094072, 0.14400335174286738, 0.09648486797232181, 0.19787190336501226, 0.1233046229754109, 0.11806648530182429, 0.26525785855483264, 0.22111644357210025, 0.21926499292021617, 0.1675555418478325, 0.28527536254841834, 0.3196228772867471, 0.7454126514494419, 0.5281644745264202, 0.3416067163925618, 0.18301167263416573, 0.23772925604134798, 7.670919606462121, 46.50519534945488, 82.67530247569084, 88.96876037120819, 93.76254513859749, 73.3892011642456, 61.8453674018383, 50.1568716019392, 38.386357203125954, 41.42564311623573, 41.16957485675812, 49.54447366297245, 50.963902696967125, 46.089767441153526, 51.72334894537926, 53.448433578014374, 28.12908310443163, 6.009467309340835, 1.2663149437867105, 0.11326470819767565, 0.20137402403634042, 0.35371826961636543, 1.085116679314524, 1.6177984583191574, 4.0005070343613625, 7.856559595093131, 14.525038842111826, 13.738252110779285, 13.987844567745924, 16.53855174779892, 12.60631849989295, 19.41550277173519, 13.81002550944686, 13.090378325432539, 14.451824370771646, 17.642671801149845, 17.203979641199112, 15.650073923170567, 19.79007337242365, 18.737223967909813, 11.486006565392017, 8.420918136835098, 14.662632308900356, 13.674224596470594, 9.663829542696476, 11.742129921913147, 14.953412655740976, 16.07052706182003, 11.611524280160666, 10.099781099706888, 3.91887245234102, 6.526849921792746, 30.16950711607933, 59.55713778734207, 71.22699558734894, 59.07417610287666, 63.79657030105591, 56.89769089221954, 29.41801954060793, 19.278594218194485, 11.608416996896267, 16.09826747328043, 13.112337347120047, 15.039443839341402, 12.4809062294662, 4.400838352739811, 7.803193358704448, 6.479785647243261, 5.290378220379353, 6.771658910438418, 14.06222652643919, 14.109419994056225, 13.082621991634369, 18.905600532889366, 15.255672186613083, 15.344333779066801, 14.986962955445051, 20.249168537557125, 10.640357192605734, 9.612816330045462, 16.188394837081432, 12.902851738035679, 10.312208700925112, 8.139447290450335, 4.417520882561803, 2.2650064481422305, 0.16048281511757523, 0.22841714322566986, 0.3288561146473512, 0.4116815171437338, 1.7446466954424977, 6.486274749040604, 15.544393043965101, 29.77726176381111, 39.138591438531876, 61.466132551431656, 55.48974484205246, 55.04004657268524, 45.040753930807114, 47.79117934405804, 44.940982684493065, 33.56049835681915, 41.383849158883095, 41.68094001710415, 63.260472267866135, 72.86378815770149, 80.27435570955276, 83.94574910402298, 50.215692445635796, 13.587118070572615, 1.1480435589328408, 0.16988465358735994, 0.5274717835709453, 0.35647727781906724, 0.5413729220163077, 0.7240456261206418, 0.6527705944608897, 0.4825640714261681, 0.25694331096019596, 0.16044636082369834, 0.12645645736483857, 0.20699298736872151, 0.17020630039041862, 0.3547454613726586, 0.2345143910497427, 0.2602623141137883, 0.25759129493962973, 0.2049841420375742, 0.10215293179498985, 0.14263720629969612, 0.1519373556948267, 0.1710159538197331, 0.12941299559315667, 0.08404426131164655, 0.19369328540051356, 0.231999697862193, 0.19963650789577514, 0.14872900675982237, 0.3827914595603943, 0.14610771147999913, 0.17785269243177027, 0.23408540000673383, 0.27446307241916656, 0.1898896152852103], [0.03247851971536875, 0.1072506551281549, 0.04083236402948387, 0.04179843992460519, 0.03548027700162493, 0.061313372643780895, 0.02625112701934995, 0.039303409939748235, 0.017520794899610337, 0.05452362311189063, 0.06962597210076638, 0.06736754992743954, 0.038554616330657154, 0.05385112228395883, 0.0927900338137988, 0.06020483036991209, 0.01588999217347009, 0.11294275711406954, 0.021128560292709153, 0.049760953479562886, 0.051132535154465586, 0.062135405096341856, 0.08265774391475134, 0.17002165404846892, 0.07658310190890916, 0.040659291480551474, 0.06005519113386981, 0.2179024543147534, 0.27027142234146595, 0.24229432514403015, 0.21469557483214885, 2.1503948606550694, 23.404650315642357, 54.764948934316635, 73.51434364914894, 66.7052686214447, 68.16674619913101, 47.924521788954735, 41.0447933524847, 25.705010779201984, 32.49090135097504, 34.98936228454113, 23.231052830815315, 34.07028280198574, 37.76712343096733, 57.65849366784096, 44.69864308834076, 19.374947547912598, 3.68489193264395, 0.4041822929866612, 0.04692611262726132, 0.034277927261427976, 0.16566052712732926, 0.7674404256977141, 1.5113759064115584, 1.204620860517025, 2.6733629358932376, 3.933845073916018, 5.3703392297029495, 3.17049952223897, 5.700611332431436, 6.211628336459398, 7.580755669623613, 2.44623392354697, 5.368418907746673, 8.865627273917198, 7.1902392245829105, 5.5878115352243185, 7.4393676314502954, 9.632196240127087, 5.162660898640752, 3.679825379513204, 3.545590932480991, 11.205821000039577, 15.13890540227294, 16.338317692279816, 22.9290659353137, 23.875598944723606, 25.97908817231655, 22.691020108759403, 22.01940044760704, 27.661552391946316, 18.64209607243538, 16.67312152683735, 34.685906767845154, 53.44406001269817, 52.85212777554989, 64.81609359383583, 39.89435948431492, 64.48754042387009, 38.889738991856575, 30.30827756971121, 21.21895629912615, 15.75045408681035, 21.41209613531828, 19.948279783129692, 16.764082945883274, 13.616729881614447, 3.1222314247861505, 3.2072428381070495, 4.325101766735315, 1.8441841355524957, 7.825219351798296, 4.302900033071637, 3.217347920872271, 6.416635885834694, 4.2351301945745945, 9.301155153661966, 6.089072562754154, 6.940481001511216, 6.288246950134635, 5.09206211194396, 6.556316865608096, 5.65196349285543, 5.60681764036417, 4.560302495956421, 3.828216679394245, 2.405644739046693, 1.6654489701613784, 0.17351498769130558, 0.33424579887650907, 0.15642161975847557, 0.0763174427265767, 0.5350846750661731, 3.166966186836362, 7.187045495957136, 22.95156452804804, 33.888527154922485, 36.178436279296875, 47.032599449157715, 56.79829582571983, 72.01976984739304, 69.76417288184166, 41.10256925225258, 14.855719897896051, 18.746778555214405, 28.461230881512165, 45.383290350437164, 62.04342797398567, 60.047577470541, 50.48013165593147, 17.957764193415642, 2.6174275623634458, 0.11176818967214786, 0.27228760009165853, 0.27006519434507936, 0.442073117592372, 0.3245326888281852, 0.29201397439464927, 0.02973252507217694, 0.0928645528620109, 0.016172629839275032, 0.031201127712847665, 0.04598986735800281, 0.045856544238631614, 0.04242985545715783, 0.03764140361454338, 0.047647817846154794, 0.0677940621972084, 0.052679315631394275, 0.07151557656470686, 0.055250389777938835, 0.03443396381044295, 0.03813436778727919, 0.026305196188332047, 0.02511877850338351, 0.09289930763770826, 0.026772827150125522, 0.09531176998279989, 0.08806534358882345, 0.03784999906201847, 0.029378880572039634, 0.03203417363693006, 0.11926284219953232, 0.10600457433611155, 0.14788799016969278, 0.025370060429850128, 0.03623717857408337, 0.02930106082203565, 0.04337408252467867, 0.027739468932850286, 0.05410780147940386, 0.016826027786009945, 0.07363758457358927, 0.06925351786776446, 0.0823417077481281, 0.012596286978805438, 0.04929950460791588, 0.07189051699242555, 0.09209242984070443, 0.03706385687110014, 0.019304930901853368, 0.03978783199272584, 0.037829590000910684, 0.020808778135688044, 0.09335605500382371, 0.007095779692463111, 0.022079405462136492, 0.034376343464828096, 0.015318180376198143, 0.028647358594753314, 0.1504877780098468, 0.06887713767355308, 0.2088517852826044, 0.14425634988583624, 0.14760592952370644, 0.13988553051603958, 2.7612073346972466, 27.532518915832043, 66.62256225943565, 82.73322656750679, 75.44336333870888, 75.19905164837837, 52.78240531682968, 44.22630563378334, 30.65688606351614, 35.76012432575226, 36.669871509075165, 24.884752593934536, 39.52105611562729, 37.65679635107517, 51.11558295786381, 38.30897055566311, 17.762912549078465, 4.293345445767045, 0.4845996340736747, 0.022288119653239846, 0.21657081873854622, 0.7530934643000364, 1.6404048702679574, 4.067439017817378, 4.878013897687197, 6.098036281764507, 7.612600335851312, 9.70802117139101, 8.105876091867685, 9.775090422481298, 8.720168229192495, 8.415037952363491, 7.13896525092423, 10.46283071860671, 10.325628630816936, 11.335732229053974, 10.442864689975977, 7.77618583291769, 8.970141615718603, 5.832298016175628, 1.9109536777250469, 3.3458285266533494, 5.010817721486092, 12.088331244885921, 14.899298809468746, 20.740571469068527, 23.4724747762084, 25.900276601314545, 26.75427697598934, 26.08305249363184, 30.296190418303013, 20.57164393365383, 19.32619236409664, 41.5380334854126, 62.628968954086304, 60.8659927546978, 71.75352573394775, 50.56300900876522, 79.01131108403206, 45.65700486302376, 32.478259429335594, 22.43588089942932, 15.604627411812544, 21.276948787271976, 19.686234444379807, 16.56891781836748, 15.331601612269878, 3.752144048921764, 3.0466572800651193, 2.618926106952131, 3.0805357871577144, 3.7699187826365232, 6.281556459143758, 6.3218119740486145, 7.411188818514347, 6.742383856326342, 9.49551472440362, 7.465149248018861, 11.647008676081896, 13.620829861611128, 11.522792391479015, 11.674132570624352, 7.9673269763588905, 7.760005826130509, 6.960449879989028, 5.901102824136615, 4.387942319735885, 5.069606741890311, 1.0113716614432633, 1.192876878194511, 0.34145350742619485, 0.1332070177886635, 0.44319574953988194, 2.4818807607516646, 6.812540916725993, 22.27154541760683, 37.38264486193657, 40.11133164167404, 38.035522028803825, 43.77029210329056, 65.24892076849937, 66.97128474712372, 44.276481941342354, 23.65637730807066, 25.74407648295164, 38.94486263394356, 50.96114404499531, 70.18117010593414, 65.80649524927139, 60.52078887820244, 22.877177819609642, 2.557336874306202, 0.03688541859446559, 0.30633950256742537, 0.16506373649463058, 0.14199162687873468, 0.29362241621129215, 0.11432686995249242, 0.010019609617302194, 0.09371840860694647, 0.048386926428065635, 0.03883402379869949, 0.02873659999750089, 0.06718170130625367, 0.041209831470041536, 0.04400804733450059, 0.06377139914548025, 0.07565001447801478, 0.021584290916507598, 0.05785109045973513, 0.08667979098390788, 0.028145008109277114, 0.02292958386533428, 0.02513921725039836, 0.01025337685859995, 0.026893925241893157, 0.06196937552886084, 0.03629215687396936, 0.0283541360477102, 0.027986871282337233, 0.11130375365610234, 0.07949911145260558, 0.1186014995619189, 0.0655309422290884, 0.0739980382786598, 0.15693209861638024, 0.26249015238136053, 0.2134457981446758, 0.20750940340803936, 0.11408790582208894, 0.1496273319935426, 0.23336490819929168, 0.19441045238636434, 0.10468903594301082, 0.17559694941155612, 0.2104705577949062, 0.16934211394982412, 0.1884714898187667, 0.21948342182440683, 0.216603844310157, 0.1173567546356935, 0.1772577126394026, 0.24689909914741293, 0.13715016713831574, 0.1861473504686728, 0.10138074940186925, 0.18759722501272336, 0.18848965759389102, 0.3700780839426443, 0.2597461058758199, 0.4050107079092413, 0.2676079730736092, 0.5868441320490092, 0.4716100014047697, 0.34947273961734027, 0.42775892943609506, 4.030518773943186, 37.17973954975605, 78.25873106718063, 91.28822430968285, 84.93243455886841, 86.45442768931389, 66.36570364236832, 55.31682372093201, 38.25337953865528, 46.18095874786377, 48.22002433240414, 34.11215275526047, 45.56225314736366, 52.945097386837006, 73.95768105983734, 56.684187948703766, 24.41960245370865, 5.431099394336343, 0.8320394530892372, 0.125974862894509, 0.31272452557459474, 0.6242455844767392, 1.6979276086203754, 3.559449976310134, 6.9917236268520355, 7.659706883132458, 13.687487784773111, 15.100088585168123, 13.073050305247307, 13.990787509828806, 18.955619148910046, 20.29385793954134, 10.608643144369125, 15.099497716873884, 19.95006948709488, 19.119076877832413, 16.28054179251194, 18.743398636579514, 22.390870414674282, 13.236197400838137, 11.35077752172947, 10.645965691655874, 17.613612860441208, 23.167372047901154, 21.019408106803894, 28.22102677077055, 31.356181539595127, 34.0540424734354, 32.879483699798584, 37.47566007077694, 35.083342641592026, 22.599123939871788, 23.423468805849552, 46.040845066308975, 67.1025601029396, 63.952027559280396, 72.36701041460037, 55.38680836558342, 84.85212966799736, 49.857128486037254, 37.14412786066532, 26.96345955133438, 22.456910870969296, 26.60478349775076, 25.313080810010433, 20.93681573867798, 18.874366208910942, 6.6869633551687, 7.669536005705595, 8.825485277920961, 6.473158802837133, 17.91876308619976, 12.924236990511417, 10.568887777626514, 12.266929261386395, 12.15805085375905, 19.803441055119038, 16.769389361143112, 16.30642220377922, 17.786665074527264, 14.414972048252821, 17.553188502788544, 13.073248844593763, 12.905216161161661, 15.50244614481926, 10.810576658695936, 9.644557926803827, 6.6045016050338745, 1.0039538657292724, 0.8688034303486347, 0.6191197782754898, 0.3355797054246068, 1.1585949989967048, 4.338671788573265, 9.365906529128551, 29.78352952748537, 42.21850477159023, 47.64713667333126, 60.16894295811653, 68.53534922003746, 81.20389983057976, 79.61439192295074, 50.89555196464062, 25.47419786453247, 31.88210941851139, 43.07152479887009, 60.57641789317131, 79.73274797201157, 76.86925202608109, 72.84485757350922, 28.455468490719795, 3.6270718602463603, 0.24112848535878584, 0.48255216737743467, 0.5797355447430164, 0.8067807834595442, 0.6432183820288628, 0.5187317181844264, 0.2768161555286497, 0.31536576978396624, 0.2182999040815048, 0.11621353551163338, 0.15396931150462478, 0.2734774409327656, 0.10793107096105814, 0.14855222718324512, 0.13446979690343142, 0.2254520109272562, 0.17843198322225362, 0.229713601002004, 0.20162886270554736, 0.0955901866836939, 0.14039655856322497, 0.11113936052424833, 0.15408498264150694, 0.20773103839019313, 0.23445544968126342, 0.13930058456026018, 0.23103693936718628, 0.19355597323738039, 0.19670964073156938, 0.33120361680630594, 0.36824112001340836, 0.23715940536931157, 0.27956762351095676], [0.05957045366812963, 0.08487280982080847, 0.06955378339625895, 0.049382276338292286, 0.12952975026564673, 0.05984956427710131, 0.07888382649980485, 0.017699218333291356, 0.09788873678189702, 0.0055785997756174766, 0.02498475219908869, 0.03168436232954264, 0.048644418275216594, 0.019444979734544177, 0.08514393121004105, 0.14028161473106593, 0.030326031701406464, 0.030184374263626523, 0.026687942154239863, 0.06078657395846676, 0.026267691755492706, 0.048121526997420006, 0.042913360957754776, 0.07646528596524149, 0.030414796274271794, 0.06061954620236065, 0.011021927366527962, 0.14227100095013157, 0.32593659474514425, 0.09682536532636732, 0.7303640933241695, 11.37155195698142, 46.264212280511856, 71.80008083581924, 69.20133948326111, 60.605182349681854, 57.99654632806778, 59.74397376179695, 49.452586993575096, 41.20604149997234, 37.96320430934429, 39.27919529378414, 28.925115689635277, 25.357593521475792, 46.65547348558903, 37.54646547138691, 16.366382986307144, 5.286016529425979, 0.13496593746822327, 0.03749828043510206, 0.030388264494831674, 0.62508421135135, 0.8161266194656491, 1.2867599842138588, 4.48596328496933, 2.4468561401590705, 6.426936183124781, 4.3647711630910635, 8.74608663842082, 6.990742329508066, 7.813399136066437, 5.150217991322279, 5.710123647004366, 6.5968079678714275, 8.918916564434767, 5.689800437539816, 9.403634704649448, 7.770313248038292, 8.291899859905243, 4.044302059337497, 2.2172175999730825, 10.430560950189829, 14.269974678754807, 22.378243692219257, 28.40385966002941, 31.67290024459362, 41.16257183253765, 42.59466178715229, 41.504108905792236, 42.28123940527439, 38.60059350728989, 39.181175753474236, 37.46347792446613, 33.955620154738426, 29.4478802382946, 40.25575049221516, 54.222490042448044, 58.94776068627834, 37.06837512552738, 31.501041166484356, 40.394401252269745, 48.636227399110794, 29.237776212394238, 26.378469541668892, 35.85575379431248, 43.62166307866573, 35.32163165509701, 37.58799344301224, 23.5333589091897, 11.18224611505866, 8.291523680090904, 7.197539582848549, 5.652039013803005, 9.630618374794722, 9.43161640316248, 5.210005408152938, 5.650269258767366, 5.730185145512223, 6.299407901242375, 10.398003347218037, 12.307075057178736, 14.56350702792406, 6.79181445389986, 9.733166322112083, 4.535405281931162, 4.011362101882696, 8.808692079037428, 0.16185886081075296, 4.427155265584588, 2.5729920342564583, 0.7936235738452524, 0.17447885940782726, 0.027121317434648518, 0.051335022726561874, 0.37953393592033535, 1.4403123571537435, 6.595137482509017, 19.145141579210758, 34.26969230175018, 48.762935400009155, 81.16113692522049, 76.09769582748413, 78.74816000461578, 52.045191675424576, 32.58712738752365, 20.168381072580814, 22.97667358070612, 44.628700241446495, 57.64233313500881, 57.94453851878643, 62.784240022301674, 32.2616558521986, 5.992337828502059, 0.3418167738709599, 0.06661578401690349, 0.28468131786212325, 0.32714439556002617, 0.12819882715120912, 0.040773211148916744, 0.011958127179241274, 0.04407318563607987, 0.04035841739096213, 0.035702880486496724, 0.020773080832441337, 0.00918202360480791, 0.0442926609684946, 0.09577759381500073, 0.028959064329683315, 0.004366358134575421, 0.024937067355494946, 0.0525437957549002, 0.013183292394387536, 0.010199948719673557, 0.02487264522642363, 0.06927723690751009, 0.022935123997740448, 0.04977638272976037, 0.009766816492629005, 0.01875158559414558, 0.028613002723432146, 0.05877363568288274, 0.05201379470236134, 0.007064949486448313, 0.10590382778900675, 0.0971163169015199, 0.006445627250286634, 0.0405530307762092, 0.06051242089597508, 0.050142543550464325, 0.023750668224238325, 0.0875082949642092, 0.061910868316772394, 0.01298419272643514, 0.029172810282034334, 0.07992783532245085, 0.0035833250785799464, 0.049091584514826536, 0.015117023103812244, 0.026648103666957468, 0.00926208556847996, 0.10476129886228591, 0.04888985764409881, 0.029863974268664606, 0.020646709781431127, 0.02316070535016479, 0.09613467074814253, 0.010192697936872719, 0.031029864148877095, 0.11949199513765052, 0.04208768827083986, 0.05268931607133709, 0.04197785041469615, 0.05936717570875771, 0.03670357385999523, 0.25292716396506876, 0.10171020359848626, 0.7152381737250835, 14.089757949113846, 56.93222723901272, 85.44898644089699, 77.11601078510284, 69.69164237380028, 68.44169184565544, 67.64385625720024, 53.92147779464722, 42.845653519034386, 39.200246930122375, 44.45478357374668, 30.405746139585972, 27.239041663706303, 40.33912941813469, 37.1170961111784, 19.116531014442444, 4.986167969182134, 0.2699414041126147, 0.06801084353355691, 0.3041398065397516, 1.2423510546796024, 1.58344212686643, 3.564005456864834, 9.032672960311174, 8.471124842762947, 11.15664878860116, 9.7842450812459, 9.61371498182416, 7.327087931334972, 9.39288318157196, 8.408114723861217, 12.733381781727076, 7.892516115680337, 8.47696702927351, 11.201210897415876, 6.39406937174499, 8.085851166397333, 7.496860921382904, 5.048092296347022, 4.021168425679207, 7.45468033477664, 13.06246692314744, 22.523952573537827, 29.574060067534447, 34.36990052461624, 41.78648695349693, 41.21202237904072, 41.82707257568836, 45.175848081707954, 44.07195791602135, 44.70740161836147, 40.00738821923733, 39.079120829701424, 38.71286988258362, 48.10789994895458, 58.89889530837536, 64.19183269143105, 47.40198142826557, 41.705539897084236, 49.903622791171074, 50.867114290595055, 33.625148087739944, 30.30111115425825, 39.72007803618908, 41.995278149843216, 35.720701441168785, 37.27193020284176, 26.20180182158947, 11.968158893287182, 10.544025711715221, 8.194569032639265, 6.81282352656126, 6.627505570650101, 6.971131581813097, 6.101068519055843, 10.071909595280886, 10.378544591367245, 10.591855645179749, 8.632510732859373, 11.097296923398972, 12.803613413125277, 9.659980349242687, 15.162002462893724, 11.892273165285587, 8.179217856377363, 8.182409685105085, 6.387668615207076, 7.5394590105861425, 5.483877137303352, 3.073754576034844, 1.1704088025726378, 0.2194056150619872, 0.024100861737679224, 0.18967519397847354, 1.1676355451345444, 5.337793501093984, 17.699189968407154, 28.38844958692789, 44.36061702668667, 71.48731201887131, 72.21441060304642, 78.61883014440536, 51.701925694942474, 36.230512484908104, 30.03658264875412, 30.03780998289585, 53.627202585339546, 64.41462233662605, 64.00896370410919, 69.6136325597763, 40.55433847010136, 8.044804818928242, 0.5558569729328156, 0.08649678478832357, 0.04836681793676689, 0.22204395005246624, 0.12729716225294396, 0.0977483595488593, 0.04091689464985393, 0.04551953497866634, 0.035824013830279, 0.0969910275307484, 0.04509055506787263, 0.008743821581447264, 0.048385078480350785, 0.0901422809693031, 0.07616802613483742, 0.031309113910538144, 0.009721088135847822, 0.02917019977758173, 0.04482124080823269, 0.08044705667998642, 0.005648793958243914, 0.05772153002908453, 0.04126583764445968, 0.11839662969578058, 0.042797018177225254, 0.015364338250947185, 0.1011176357860677, 0.06392341325408779, 0.05224482527410146, 0.04523791962128598, 0.03562912213965319, 0.05960071102890652, 0.023842241826059762, 0.19805781135801226, 0.1854859187733382, 0.160645182186272, 0.16625966294668615, 0.2944329008460045, 0.17305870045674965, 0.3168427327182144, 0.23892003198852763, 0.2861600916367024, 0.07834499017917551, 0.14643655711552128, 0.20246238360414281, 0.15647696913219988, 0.14638245454989374, 0.2031718916259706, 0.21113043098011985, 0.17129290848970413, 0.15010475559392944, 0.11991352017503232, 0.26005187071859837, 0.08065761881880462, 0.14157237281324342, 0.19871061929734424, 0.18161596002755687, 0.147679416986648, 0.157256031234283, 0.266759698279202, 0.3378290362888947, 0.5316078022588044, 0.3327291161986068, 1.3975411397404969, 18.832137174904346, 67.16170772910118, 96.58693358302116, 84.97922524809837, 79.50832441449165, 75.93745082616806, 79.197858273983, 62.73699335753918, 54.8015371710062, 50.51520757377148, 53.782310262322426, 42.94819101691246, 38.28513823449612, 60.566397830843925, 49.08648423850536, 21.751189939677715, 7.222324702888727, 0.3556536720134318, 0.11607231223024428, 0.21754395245807245, 1.3568646786734462, 1.5636081411503255, 4.554286943748593, 11.413331665098667, 11.244928501546383, 17.301653400063515, 10.014977250248194, 21.886627972126007, 19.583845138549805, 19.077273420989513, 13.593711666762829, 16.882653683423996, 15.135509334504604, 16.491580568253994, 15.770680401474237, 20.005605407059193, 14.670157805085182, 19.679966680705547, 13.606011606752872, 8.568548765033484, 16.52085229754448, 17.92607769370079, 27.206019535660744, 32.79901161789894, 34.041172564029694, 43.979387283325195, 45.078846886754036, 47.26932294666767, 50.04300691187382, 46.75014540553093, 51.55915975570679, 41.90709628164768, 43.09504173696041, 44.16988246142864, 50.591868460178375, 63.037834614515305, 70.01401707530022, 49.42919924855232, 49.00713309645653, 54.040422812104225, 56.9352974742651, 39.348210990428925, 33.430036157369614, 43.08235801756382, 45.963796600699425, 40.318777710199356, 40.6643083691597, 30.651245266199112, 14.69423046335578, 11.857147850096226, 12.034538481384516, 10.619767047464848, 13.822430893778801, 16.87221184372902, 11.5712283924222, 11.98276150971651, 11.87980318441987, 15.542425699532032, 19.202163219451904, 21.720719374716282, 23.480232059955597, 18.96429978311062, 21.035428047180176, 14.240863490849733, 13.686164505779743, 18.199664913117886, 9.374457970261574, 11.51643343269825, 6.023886110633612, 2.484886161983013, 0.6475579866673797, 0.3059475001646206, 0.09426874079508707, 0.6373169424477965, 2.4074904900044203, 8.690419625490904, 24.757881201803684, 46.048167273402214, 60.1848679035902, 82.84621730446815, 76.0475005209446, 84.00480553507805, 59.792101979255676, 46.924913227558136, 30.44025208801031, 39.18497174978256, 62.0022039860487, 74.55532059073448, 75.48549547791481, 81.39653429389, 51.3811469078064, 11.432210952043533, 0.8019332529511303, 0.40979856974445283, 0.37631378683727235, 0.5406575510278344, 0.31468946544919163, 0.2697220252593979, 0.15815192222362384, 0.13643206504639238, 0.09352518303785473, 0.17101343051763251, 0.1596021233126521, 0.09272861367207952, 0.19509974430548027, 0.16528565349290147, 0.20289789070375264, 0.1661409341613762, 0.09523670916678384, 0.11043803096981719, 0.18481274630175903, 0.18371500598732382, 0.08219344148528762, 0.26456944236997515, 0.13663986639585346, 0.22586072649573907, 0.1635410127346404, 0.14868098980514333, 0.19873114710208029, 0.2842247486114502, 0.19957354408688843, 0.12362100795144215, 0.3658331773476675, 0.2813920599874109, 0.20512892020633444], [0.06256757624214515, 0.041093800391536206, 0.09357130009448156, 0.01868869600002654, 0.008305474839289673, 0.03929304213670548, 0.021735744703619275, 0.04402292368467897, 0.09199882275424898, 0.023990864319785032, 0.05512658470252063, 0.07393707084702328, 0.022597918068640865, 0.0792761480261106, 0.07547628512838855, 0.040387639455730096, 0.07272864662809297, 0.05431863079138566, 0.058408573240740225, 0.022216604447748978, 0.031136757534113713, 0.03432680510741193, 0.10564016498392448, 0.03071158855163958, 0.08450540219200775, 0.0461006625846494, 0.0975427104276605, 0.1392947364365682, 0.11441836933954619, 0.11624051257967949, 3.2342154532670975, 34.0802800655365, 68.51871371269226, 72.44299113750458, 67.84463748335838, 58.00443850457668, 43.41490097343922, 29.4214241579175, 30.55876012891531, 41.157043129205704, 44.21347752213478, 29.314651787281036, 27.040019743144512, 48.49773623049259, 38.910079300403595, 24.267798699438572, 5.65694835036993, 0.4070490610320121, 0.13036741234827787, 0.05404311959864572, 0.08022507288842462, 1.7576879519037902, 2.918835701420903, 2.85708948969841, 7.462365422397852, 6.999448612332344, 5.731612918898463, 8.891530483961105, 6.869516484439373, 3.6778205120936036, 7.254396406933665, 5.295133665204048, 7.724063554778695, 5.816625757142901, 8.478375803679228, 9.459295067936182, 6.665393812581897, 6.794606829062104, 3.25975863263011, 7.58369623683393, 14.044355135411024, 22.64557834714651, 30.363161824643612, 43.6206941306591, 52.82768748700619, 59.916807487607, 56.882009133696556, 63.153325617313385, 59.216809049248695, 62.07181245088577, 56.00708328187466, 55.2750563621521, 51.798611506819725, 37.11883641779423, 47.97650299966335, 44.52558897435665, 49.77104410529137, 61.30925036966801, 34.089255183935165, 32.86807291209698, 43.73884119093418, 49.44312550127506, 36.29441365599632, 39.9392768740654, 62.13291697204113, 57.20609374344349, 56.66072800755501, 45.840656608343124, 49.60458263754845, 42.812485098838806, 34.80337366461754, 25.677887834608555, 19.427255541086197, 21.150273084640503, 17.172200046479702, 13.485965598374605, 13.047272488474846, 8.05974941700697, 6.775256367400289, 15.989866890013218, 14.547807220369577, 13.56063349172473, 6.6939198318868876, 4.788908204063773, 6.958814542740583, 4.0994518250226974, 3.3106371900066733, 4.974229959771037, 5.895871454849839, 1.5725681791082025, 2.836251170374453, 1.6255724849179387, 0.2763472666265443, 0.11820473257103004, 0.09324915605247952, 0.03327772741613444, 0.654847954865545, 7.920754300430417, 21.79955944418907, 37.82587967813015, 52.11260765790939, 62.966694831848145, 53.18478472530842, 51.85408093035221, 26.629896350204945, 17.627225629985332, 20.636681243777275, 29.64574322104454, 47.35832177102566, 57.84050390124321, 58.20506013929844, 55.90071938931942, 13.06068291887641, 0.9446910582482815, 0.20349681872176006, 0.5209934280719608, 0.28574754658620805, 0.04590738877595868, 0.06587281997781247, 0.05648937563819345, 0.09481581495492719, 0.022586453742405865, 0.11729061443475075, 0.051613840187201276, 0.05235661126789637, 0.011686117995850509, 0.02283789151988458, 0.053501266447710805, 0.04043983470182866, 0.02712359211727744, 0.04299024374631699, 0.051492087150109, 0.04864523092692252, 0.05411782789451536, 0.0677817351242993, 0.12682588363531977, 0.038745081110391766, 0.042610022937878966, 0.025950100789486896, 0.02359001366130542, 0.0944623893883545, 0.05702508380636573, 0.04963737846992444, 0.06450623666751198, 0.10665823574527167, 0.05557289005082566, 0.07591996327391826, 0.02539020417316351, 0.04321538537624292, 0.050864126314991154, 0.08316817824379541, 0.06887320429086685, 0.020845468061452266, 0.012534386296465527, 0.031180759469862096, 0.030639661454188172, 0.03710965109348763, 0.0722877960652113, 0.01758492573571857, 0.09180964188999496, 0.05843756895046681, 0.043283210252411664, 0.02444295841996791, 0.013926941992394859, 0.08131352151394822, 0.03915314358891919, 0.07083824806613848, 0.03425858689297456, 0.03831366695521865, 0.10654101351974532, 0.04464151861611754, 0.008860662528604735, 0.05578185657213908, 0.04796013585291803, 0.13021340186242014, 0.050136595236836, 4.450101759284735, 41.513745188713074, 77.48069241642952, 80.24027913808823, 76.00457042455673, 66.34015381336212, 52.35487125813961, 42.4032698571682, 44.37640517950058, 44.112680330872536, 43.18642683327198, 32.921365052461624, 30.600472390651703, 37.06779755651951, 33.67383487522602, 22.193949781358242, 5.417458601295948, 0.3589904570253566, 0.05495256591530051, 0.12409659844706766, 1.1485084402374923, 3.8992925779893994, 6.996088642627001, 7.078067818656564, 11.09095411375165, 9.924689345061779, 13.82013676688075, 11.585975401103497, 12.050550822168589, 13.758788108825684, 12.823173813521862, 13.0638044513762, 9.944100603461266, 8.98437375202775, 11.679736319929361, 15.528667587786913, 8.519668187946081, 6.747666047886014, 4.476844249293208, 6.669773077592254, 14.562820214778185, 26.253971122205257, 34.07784439623356, 43.85045640170574, 51.64388380944729, 60.370590537786484, 56.71970084309578, 66.07679754495621, 59.78250749409199, 64.35475274920464, 61.537219136953354, 61.99883356690407, 53.305401653051376, 41.091067269444466, 53.01628276705742, 52.17301681637764, 56.99325196444988, 61.833531036973, 41.898721531033516, 38.95099550485611, 49.869948998093605, 56.42608679831028, 42.22148001194, 45.58949388563633, 64.65449586510658, 57.85972706973553, 57.61188916862011, 48.51437173783779, 53.61907862126827, 43.412070125341415, 36.89658634364605, 28.60516905784607, 22.52194818109274, 17.86762163043022, 16.77141085267067, 12.940047942101955, 12.039449717849493, 8.87791296467185, 9.768177643418312, 15.643325485289097, 9.57986544817686, 10.440699756145477, 13.026449605822563, 16.952644027769566, 15.005330219864845, 9.064621645957232, 7.272378467023373, 10.269290953874588, 8.32667464390397, 7.342840936034918, 5.729048531502485, 3.3517077611759305, 1.2994971382431686, 0.8519937854725868, 0.22752585355192423, 0.11828991628135554, 0.4555181023897603, 5.74877992272377, 19.182679764926434, 43.02672900259495, 58.55544313788414, 74.09245982766151, 65.31167820096016, 53.454095274209976, 35.65949812531471, 25.5615171790123, 29.326148070394993, 37.8865472227335, 53.60197193920612, 65.10978743433952, 65.68333625793457, 64.74155679345131, 17.79933549463749, 1.3841976807452738, 0.03568417836504523, 0.17741541902069002, 0.14646521885879338, 0.03066352892346913, 0.04957396195095498, 0.04615008961991407, 0.0998640593024902, 0.03844110484351404, 0.026113343592442106, 0.02207543126132805, 0.1103251132008154, 0.0590008293511346, 0.007063230023049982, 0.04908456750854384, 0.015478888744837604, 0.048660771499271505, 0.06103968342358712, 0.04023516521556303, 0.08857085005729459, 0.021045148459961638, 0.026195497484877706, 0.04804402451554779, 0.05629686995234806, 0.017984193764277734, 0.050233430665684864, 0.03066243796638446, 0.005528737656277372, 0.019498727924656123, 0.03107446351350518, 0.10672494739992544, 0.009745015904627508, 0.004975081574229989, 0.18646635522600263, 0.11059309530537575, 0.2819939417531714, 0.1486501461477019, 0.2290121972328052, 0.18298363429494202, 0.08403652813285589, 0.10041508910944685, 0.14000755443703383, 0.07678728899918497, 0.1366717490600422, 0.13504610426025465, 0.12498743541073054, 0.17319720005616546, 0.14098569023190066, 0.14973608631407842, 0.12284735610592179, 0.1746904753963463, 0.2362241508672014, 0.15355367911979556, 0.139220729470253, 0.11681728006806225, 0.21665275184204802, 0.2747080405242741, 0.15018272562883794, 0.11637798059382476, 0.24514151533367112, 0.257628817926161, 0.2923144254600629, 0.2920828456990421, 6.46381082944572, 50.30098266899586, 87.34794974327087, 88.17939072847366, 84.91272881627083, 74.60671663284302, 58.76514248549938, 44.89485315978527, 44.77946475148201, 55.56364707648754, 57.67951413989067, 43.4074267745018, 38.946884125471115, 64.70402240753174, 50.43584123253822, 29.94342114776373, 7.586731323972344, 0.5810266442131251, 0.297599644982256, 0.1516618556343019, 0.5906281352508813, 4.240447534248233, 8.737430702894926, 8.53093458339572, 18.350482620298862, 15.791722722351551, 20.442110784351826, 16.639502830803394, 15.246195495128632, 13.237298391759396, 20.34387655556202, 20.163384340703487, 16.667809411883354, 13.032257594168186, 19.506496489048004, 18.370024971663952, 15.88169714435935, 14.504814427345991, 11.393253542482853, 13.548992816358805, 21.84752807021141, 27.877390310168266, 33.991592824459076, 45.93448117375374, 55.12657172977924, 63.085700646042824, 59.127171859145164, 68.25913444161415, 61.82275481522083, 69.94169935584068, 59.827808663249016, 68.7363812327385, 59.70243439078331, 45.23802034556866, 61.65158919990063, 56.91246449947357, 62.49032199382782, 67.78777733445168, 45.64437814056873, 43.15682642161846, 54.32011440396309, 61.913858726620674, 44.949266240000725, 48.22134666144848, 66.74796313047409, 61.163478791713715, 58.829647824168205, 51.82247422635555, 53.046833127737045, 45.5476201325655, 39.775555059313774, 33.19985210895538, 25.51807790994644, 26.66929643601179, 22.121103890240192, 20.252489559352398, 18.783290795981884, 15.985398329794407, 13.497068602591753, 25.789862126111984, 24.323952086269855, 25.202789828181267, 14.768686518073082, 15.588660668581724, 16.86837214976549, 10.979049168527126, 14.553543962538242, 16.280049718916416, 16.107481978833675, 8.718224633485079, 9.788363110274076, 4.58684834651649, 1.0632812697440386, 0.6517900095786899, 0.2854264638153836, 0.270435051061213, 1.0512357973493636, 10.039017610251904, 25.398887805640697, 46.74398973584175, 59.81498435139656, 70.42556539177895, 61.40363730490208, 62.33505852520466, 36.08965024352074, 25.68801999092102, 33.125866279006004, 45.47093264758587, 63.12789738178253, 74.85490411520004, 73.92632514238358, 77.9589119553566, 24.676563665270805, 2.4109278805553913, 0.23280942550627515, 0.6381510570645332, 0.6149071105755866, 0.2227582671912387, 0.14776584750507027, 0.22794261400122195, 0.35514559771399945, 0.17334981530439109, 0.2046928193885833, 0.11132782892673276, 0.22947633638978004, 0.3504191560205072, 0.06881070061353967, 0.1855641114525497, 0.17639314028201625, 0.1779912514030002, 0.15024435357190669, 0.12853545049438253, 0.18545920145697892, 0.1301431204774417, 0.17205830023158342, 0.25495613634120673, 0.21290811215294525, 0.16629328223643824, 0.13058750366326421, 0.16141674859682098, 0.2131429425207898, 0.12546407233458012, 0.14069274970097467, 0.2147622048505582, 0.15960952994646505, 0.10344523354433477], [0.025175209557346534, 0.01670394263783237, 0.05652737359923776, 0.049666941922623664, 0.09711296981549822, 0.08300421555759385, 0.07876753938035108, 0.06076051344280131, 0.016150614028447308, 0.06436392985051498, 0.024323595098394435, 0.03434558144363109, 0.01000870190182468, 0.04499364171351772, 0.03858810574456584, 0.026219491119263694, 0.04045282599690836, 0.11007259003235959, 0.028749830635206308, 0.14173337433021516, 0.00841703355035861, 0.09546238143229857, 0.1427444169530645, 0.00655671933600388, 0.050146688445238397, 0.028807996459363494, 0.08587495409301482, 0.07143174356315285, 0.08105912813334726, 1.2583833443932235, 17.52394527196884, 61.822800412774086, 69.03923258185387, 62.932462468743324, 51.595421209931374, 52.69025646150112, 38.362475484609604, 16.914074197411537, 31.61595080047846, 64.87765789031982, 54.86323066055775, 39.804410710930824, 50.49940422177315, 43.34665663540363, 23.799722716212273, 4.276674315333366, 0.5992673872970045, 0.0881814377498813, 0.06418636359740049, 0.3678856015903875, 2.189262737520039, 2.0454114815220237, 4.168854625895619, 4.816733635962009, 9.923709947615862, 8.216007482260466, 13.626252170652151, 13.365863543003798, 10.951289758086205, 6.307299602776766, 5.951757431030273, 11.450672261416912, 13.319235295057297, 6.5595989394932985, 6.044910857453942, 11.068420372903347, 3.268003477714956, 8.084104210138321, 14.837806709110737, 26.57327178865671, 42.75809861719608, 46.58954322338104, 54.679282531142235, 62.00372010469437, 63.075479194521904, 66.79853841662407, 63.406525030732155, 63.29813964664936, 65.47346591949463, 63.68921086192131, 66.48302614688873, 67.41535931825638, 57.78131827712059, 42.06774786114693, 38.34135241806507, 36.79884798824787, 45.56658871471882, 59.686007872223854, 37.646430507302284, 45.13822630047798, 47.93576538562775, 50.29395304620266, 47.79079556465149, 50.6222478300333, 63.364275097846985, 60.40960684418678, 64.17123019695282, 58.118523582816124, 65.26317000389099, 62.30693243443966, 62.618766501545906, 49.298463463783264, 45.13612121343613, 32.128598392009735, 28.128408640623093, 21.701570302248, 26.199326254427433, 20.295947827398777, 14.822332989424467, 13.899825140833855, 12.315756641328335, 10.691839680075645, 10.006459057331085, 18.35402213037014, 15.61194771900773, 7.957926280796528, 5.863191308453679, 8.511678166687489, 6.978453313931823, 8.246725033968687, 5.547371730208397, 1.6584682697430253, 0.7896412094123662, 0.5442296562250704, 0.11412211140850559, 0.055014034296618775, 0.11370100939529948, 0.1797933640773408, 2.2113060671836138, 10.307386759668589, 27.581655979156494, 27.637038007378578, 22.436656057834625, 29.314824678003788, 32.17164248228073, 27.786056511104107, 17.604578845202923, 24.56168632954359, 37.98503793776035, 51.61161594092846, 59.505236372351646, 54.578781723976135, 37.51422040164471, 6.890283795073628, 0.12189577435492538, 0.2735930378548801, 0.17843591660493985, 0.14256046822993085, 0.04945124783262145, 0.012620366887858836, 0.1071774867887143, 0.03864398575387895, 0.06179761287057772, 0.02640611899551004, 0.027103700704174116, 0.041017084586201236, 0.016558975221414585, 0.04017198989458848, 0.015729658589407336, 0.010151529149879934, 0.06201325129950419, 0.014206006217136746, 0.04703995065938216, 0.05047739687142894, 0.052408602423383854, 0.040569001794210635, 0.03800626938755158, 0.04099301673704758, 0.05267195723718032, 0.07959858150570653, 0.02786941342492355, 0.0855536486778874, 0.06725751169142313, 0.08066760070505552, 0.1811283838469535, 0.00757161184992583, 0.02256120216770796, 0.04523937423073221, 0.02464754998072749, 0.048562091833446175, 0.01751596908434294, 0.05603991245152429, 0.06056686856027227, 0.012119497914682142, 0.04897910461295396, 0.03564399106835481, 0.045821715248166583, 0.03409465018194169, 0.047702098527224734, 0.027123517902509775, 0.15113844856387004, 0.022495922858070116, 0.005931602781856782, 0.034419618095853366, 0.027782016259152442, 0.041729442455107346, 0.029492490393749904, 0.007063971243042033, 0.1046651833166834, 0.08159064687788486, 0.01339337863100809, 0.016912324717850424, 0.03919946844689548, 0.04568877433484886, 0.03441812266828492, 1.3912048609927297, 22.284795306622982, 73.99112686514854, 80.11167123913765, 74.04363244771957, 60.591358691453934, 62.05736942589283, 52.812267914414406, 26.497940830886364, 32.7450355142355, 59.42382574081421, 53.681558668613434, 41.00806072354317, 41.862756460905075, 40.78762695193291, 22.93336920440197, 5.44398307800293, 0.6163938995450735, 0.15824575937585905, 0.26656786794774234, 1.299871418159455, 3.841575337573886, 5.827947249636054, 6.491691833361983, 9.177505038678646, 13.381022829562426, 12.747913151979446, 12.030611392110586, 14.711287748068571, 10.23568270727992, 13.055754583328962, 13.41776305809617, 11.376307401806116, 13.613142874091864, 7.795820804312825, 12.034524232149124, 13.168121203780174, 4.67981843277812, 5.6753517128527164, 9.636471960693598, 23.835055120289326, 39.53244790434837, 49.26787130534649, 57.6920572668314, 66.66293129324913, 67.00862154364586, 69.59631308913231, 65.65426021814346, 64.85245004296303, 67.99037486314774, 62.41464905440807, 69.08078715205193, 71.03160247206688, 61.799192279577255, 47.52873122692108, 45.17037637531757, 43.406469225883484, 54.23654168844223, 64.40688595175743, 43.111373260617256, 50.83425745368004, 51.00799173116684, 56.85413382947445, 53.938326090574265, 58.68507318198681, 65.74993908405304, 60.014017671346664, 63.69836837053299, 58.91185261309147, 65.2168656885624, 64.21704053878784, 63.92454743385315, 52.05946370959282, 47.28638403117657, 36.317550614476204, 29.085049107670784, 23.716547079384327, 21.244825311005116, 17.783988118171692, 11.815374791622162, 11.595074012875557, 9.25368145108223, 8.99773383513093, 9.801024030894041, 15.7219841144979, 15.134713277220726, 13.922089096158743, 11.924593281000853, 15.733556393533945, 12.872040141373873, 12.466083224862814, 9.308697748929262, 4.954364150762558, 3.426993121393025, 1.9782725279219449, 0.33837415860034525, 0.03438536426983774, 0.0006472012455560616, 0.2994180255336687, 3.0412190593779087, 12.793430909514427, 33.948784321546555, 38.75210277736187, 29.199896045029163, 30.97765725106001, 31.389940828084946, 27.517213337123394, 23.37561797350645, 33.86608175933361, 46.072573363780975, 57.51897655427456, 67.5161375105381, 61.36169135570526, 44.201029390096664, 7.937395507469773, 0.21323734370525926, 0.1783059220178984, 0.18297070608241484, 0.034709964820649475, 0.0730934418970719, 0.03062026356928982, 0.11181762412888929, 0.021687113621737808, 0.021121565550856758, 0.020616482106561307, 0.015544746929663233, 0.04858987784245983, 0.03517458637361415, 0.01466743375203805, 0.003852240665764839, 0.05003583755751606, 0.026778358005685732, 0.0398632453288883, 0.03804279047471937, 0.025386849665665068, 0.02501326922356384, 0.07080646930262446, 0.04008851683465764, 0.02625243319926085, 0.004770904224642436, 0.07445726441801526, 0.01478259280702332, 0.12054743303451687, 0.037778730620630085, 0.04629793285857886, 0.1117319060722366, 0.01762055624567438, 0.2099213982000947, 0.28687362209893763, 0.13860471721272916, 0.1591256051324308, 0.15072728390805423, 0.19085314561380073, 0.1577626954531297, 0.17009954986860976, 0.14123113331152126, 0.16754494397900999, 0.1094509003451094, 0.16000472358427942, 0.13865387707483023, 0.1792879615095444, 0.20379002642584965, 0.14439808524912223, 0.10489457374205813, 0.24919837655033916, 0.13141802628524601, 0.1709398688399233, 0.2121827073278837, 0.21835783612914383, 0.27488936204463243, 0.20688208081992343, 0.15725779754575342, 0.12204499798826873, 0.19673925242386758, 0.18761629820801318, 0.23538154608104378, 2.06104954238981, 30.176871120929718, 84.61784183979034, 86.45217061042786, 84.34170305728912, 68.86536911129951, 69.56038981676102, 54.583018496632576, 29.139733873307705, 42.49454475939274, 74.91176426410675, 65.79762652516365, 54.36300650238991, 65.70837691426277, 56.16510920226574, 30.089751295745373, 6.636620331555605, 0.9587313642259687, 0.292909806012176, 0.28382289048749954, 0.7839443651027977, 4.765620678663254, 6.839070143178105, 11.946420259773731, 12.942754346877337, 21.741817742586136, 20.98946001380682, 24.125323444604874, 24.20627810060978, 23.845510259270668, 17.188244685530663, 13.729330189526081, 20.554352961480618, 25.259323194622993, 20.18405333161354, 14.40100209787488, 19.476525597274303, 10.82930775359273, 15.942266844213009, 21.473842822015285, 33.64751748740673, 48.1205228716135, 50.815250873565674, 59.52038995921612, 66.05615705251694, 68.30099299550056, 69.60001409053802, 65.50944238901138, 66.82263672351837, 67.35998868942261, 64.41144570708275, 69.10250678658485, 69.10619258880615, 67.78409153223038, 51.37062527239323, 50.70829801261425, 48.84950615465641, 60.79187013208866, 69.41849023103714, 44.744088649749756, 54.60534229874611, 57.35033020377159, 63.30485388636589, 57.49477945268154, 56.649621203541756, 65.34592196345329, 61.85806632041931, 65.17192929983139, 59.1217115521431, 66.11925646662712, 64.13641646504402, 64.4151771068573, 52.35893324017525, 49.76294293999672, 39.2376559227705, 35.40084220468998, 28.66150863468647, 34.3648885935545, 28.42697761952877, 21.45358420908451, 22.72854309529066, 20.627666227519512, 19.00473341345787, 18.546016328036785, 29.957041516900063, 25.966546945273876, 17.354020290076733, 16.209156922996044, 15.93381704762578, 15.910680089145899, 20.38080107420683, 13.775334320962429, 9.857324659824371, 4.876377610489726, 1.6127924644388258, 0.21742261131294072, 0.2505992248188704, 0.20279905147617683, 0.2732539357384667, 3.643215768970549, 14.567328672856092, 36.96011133491993, 38.87914516031742, 33.330162316560745, 40.133252665400505, 42.04475149512291, 39.19129841029644, 28.758798614144325, 38.12510222196579, 53.00384983420372, 69.48334515094757, 76.31070479750633, 73.00516337156296, 54.383833184838295, 12.02604403719306, 0.40431157511193305, 0.6501913047395647, 0.43295865354593843, 0.17618550220504403, 0.18356170796323568, 0.19246209209086373, 0.24372422107262537, 0.14916224288754165, 0.2241574678919278, 0.19385225343285128, 0.13124457153026015, 0.11901123187271878, 0.09759227104950696, 0.1465140373329632, 0.12480807316023856, 0.07726877214736305, 0.1956426550168544, 0.09959224029444158, 0.17926351516507566, 0.13868430512957275, 0.1545318149146624, 0.1734566400409676, 0.16957507410552353, 0.1093283569207415, 0.15016725927125663, 0.31500072218477726, 0.14040213951375335, 0.3542333794757724, 0.16775365074863657, 0.13170059159165248, 0.201620357693173, 0.11229547075345181], [0.03324799698020797, 0.015187623612291645, 0.02656818920513615, 0.04750387459353078, 0.03884841033141129, 0.011281973129371181, 0.02121743618772598, 0.007954780376167037, 0.06876841303892434, 0.02395438034000108, 0.046663143730256706, 0.029602081485791132, 0.007422469852826907, 0.07660589326405898, 0.06631083553656936, 0.029248715291032568, 0.038687746491632424, 0.04157367307925597, 0.05998175191052724, 0.04977121738193091, 0.0320333684067009, 0.05770500240032561, 0.04486523903324269, 0.06962748608202673, 0.04768102153320797, 0.023972026756382547, 0.0432558917964343, 0.060677006986225024, 0.22033098415704444, 5.010222103446722, 41.76397316157818, 74.5939265191555, 67.44379699230194, 58.18579897284508, 46.10151641070843, 36.97648465633392, 23.35795272141695, 29.912120327353477, 60.31140871345997, 78.44231441617012, 60.3678584843874, 31.6874173656106, 39.56479176878929, 21.227916218340397, 6.598468478769064, 1.3702372298575938, 0.08480530406814069, 0.07811580755515024, 0.622248969739303, 0.7066970632877201, 3.3565745875239372, 5.308950198814273, 6.862182877957821, 10.250134281814098, 9.05232835561037, 7.703103879466653, 8.409626092761755, 7.776193907484412, 6.985860541462898, 21.521359272301197, 15.181039441376925, 11.165427267551422, 8.826849404722452, 6.278236387297511, 17.79406327754259, 29.69738245010376, 15.388577654957771, 23.13939794898033, 29.684010967612267, 47.525235414505005, 59.319255352020264, 57.816515788435936, 57.79628187417984, 60.30405230820179, 63.95207315683365, 64.4225563108921, 66.04779750108719, 60.60639828443527, 68.10357078909874, 67.38907992839813, 66.65906310081482, 69.74323600530624, 66.48743391036987, 46.39088228344917, 39.78947751224041, 33.31647925078869, 28.398049771785736, 55.968921929597855, 48.98960843682289, 45.91932378709316, 43.71388413012028, 50.88846534490585, 56.93497449159622, 62.38759070634842, 59.68314662575722, 61.32729560136795, 62.922377809882164, 63.71505707502365, 62.32481807470322, 65.1508404314518, 63.854441195726395, 59.17508728802204, 60.43197624385357, 56.61785490810871, 51.12575501203537, 40.82788199186325, 33.68007034063339, 24.41596794873476, 19.932109750807285, 19.255597852170467, 10.767714958637953, 7.052245354279876, 17.38779477775097, 21.66099987924099, 20.908685848116875, 10.335781686007977, 5.42415289208293, 15.404792334884405, 6.464753653854132, 7.635003933683038, 4.76986457593739, 3.5988576617091894, 3.259015060029924, 3.3746238565072417, 0.5970278824679554, 0.04035575679154135, 0.05498070073372219, 0.07574124669190496, 0.518996516475454, 2.084324243478477, 13.414210248738527, 30.97027614712715, 38.1051304936409, 33.59280802309513, 43.64595517516136, 38.18014606833458, 25.754993297159672, 20.825869292020798, 24.654488749802113, 37.76089556515217, 55.36382719874382, 55.04613384604454, 45.504819229245186, 18.435620851814747, 0.7600869296584278, 0.2943712135311216, 0.04829986879485659, 0.022022423363523558, 0.13696295296540484, 0.020332271087681875, 0.00915817654458806, 0.0719230156391859, 0.0679900188697502, 0.014770038451388245, 0.07632331311469898, 0.021649126792908646, 0.07601173725561239, 0.026600357596180402, 0.02287921615788946, 0.01229017332661897, 0.030293302988866344, 0.058302687320974655, 0.030654445035906974, 0.06583390175364912, 0.07668024903978221, 0.07386930534266867, 0.060629075378528796, 0.04778632857778575, 0.03147030838590581, 0.06709227993269451, 0.013402549720922252, 0.06179145675559994, 0.03726976574398577, 0.05328710118192248, 0.08955147946835496, 0.08687922832905315, 0.025938001926988363, 0.060618277129833587, 0.013745703035965562, 0.017556015372974798, 0.02011874777963385, 0.039935415479703806, 0.006614532640014659, 0.023767798847984523, 0.042955589160555974, 0.014932447265891824, 0.0660043656534981, 0.03586634593375493, 0.10371082593337633, 0.07966602046508342, 0.049323795101372525, 0.0157043031140347, 0.02323708904441446, 0.02551968296756968, 0.027658274266286753, 0.03684610332129523, 0.05837135082401801, 0.042975708784069866, 0.03891527041560039, 0.046344758666236885, 0.06225634919246659, 0.07550501366495155, 0.054451801770483144, 0.028821904306823853, 0.13040408928645775, 6.867496892809868, 52.77184188365936, 81.81309074163437, 75.87699607014656, 65.88329672813416, 57.537770345807076, 46.91970370709896, 34.16768677532673, 31.009801626205444, 51.237400621175766, 77.28624925017357, 59.11222346127033, 36.5820924192667, 39.29842606186867, 21.80278357118368, 6.613292908295989, 1.2232184875756502, 0.15847091213800013, 0.11882803271873854, 1.3605015585198998, 5.193728506565094, 8.090248480439186, 11.0727958381176, 9.668385498225689, 12.121656406670809, 16.46695788949728, 16.251482851803303, 16.20772060006857, 14.903121404349804, 20.672836303710938, 18.973987363278866, 16.446406692266464, 10.66351504996419, 5.964197963476181, 5.780698684975505, 6.671492960304022, 10.706070866435766, 9.999273642897606, 19.780150204896927, 30.902181901037693, 49.929769188165665, 62.68400900065899, 61.35879971086979, 61.910241320729256, 61.9143944978714, 65.96998527646065, 65.63247218728065, 68.02094042301178, 64.40779030323029, 68.93321827054024, 66.94454178214073, 67.13084578514099, 70.75151950120926, 69.70149904489517, 50.10989852249622, 44.97373312711716, 38.68421941995621, 37.44560748338699, 63.10384087264538, 55.64571127295494, 50.64614474773407, 48.50524082779884, 58.26005078852177, 61.97629697620869, 65.98756313323975, 60.73629431426525, 62.22831465303898, 61.75501585006714, 67.84709975123405, 65.41089087724686, 66.82316109538078, 66.07248857617378, 63.200610280036926, 61.86795338988304, 57.340446934103966, 51.246755719184875, 38.694345876574516, 32.698351219296455, 22.436057589948177, 18.980616107583046, 17.967926748096943, 12.765020783990622, 9.235886055976152, 11.136068142950535, 14.102870095521212, 24.69255890697241, 10.663396306335926, 9.844210613518953, 11.944903191179037, 12.639181986451149, 9.092831332236528, 10.95740457996726, 6.972012184560299, 6.45222382619977, 6.479026637971401, 2.8384769009426236, 0.6016426754649729, 0.14926796924555674, 0.1805447885999456, 0.4346177395200357, 2.660745712928474, 14.176450297236443, 28.92337918281555, 34.83443699777126, 38.14874455332756, 40.731560960412025, 32.603371515870094, 27.820311672985554, 25.340078361332417, 30.02582922577858, 44.21995237469673, 60.499365627765656, 63.33649478852749, 53.22825439274311, 22.092774510383606, 0.8217737101949751, 0.2629173325840384, 0.049950256798183545, 0.09711064689327031, 0.1160790806170553, 0.011049102031392977, 0.04218522873998154, 0.004908536438961164, 0.02027269518293906, 0.02989350803545676, 0.05299948184983805, 0.02345888173294952, 0.04263871436705813, 0.04253181912645232, 0.012500741031544749, 0.05589987289567944, 0.025736408642842434, 0.04479363662539981, 0.02678545850358205, 0.053234282531775534, 0.054259136522887275, 0.025575045328878332, 0.08555427208193578, 0.04562017020361964, 0.004675817017414374, 0.09778072460903786, 0.015935131450532936, 0.08441973608569242, 0.023368339716398623, 0.032911796661210246, 0.028568486850417685, 0.07861236372264102, 0.08994944131700322, 0.19104356586467475, 0.12119264880311675, 0.10560951428487897, 0.09918736162944697, 0.16883176867850125, 0.17316800396656618, 0.11082412587711588, 0.13472558552166447, 0.15380623197415844, 0.2158488129498437, 0.1273573059006594, 0.16677665786119178, 0.19964885723311454, 0.12788706575520337, 0.0717470672680065, 0.12337221036432311, 0.0853092223405838, 0.11892284208443016, 0.1411824335809797, 0.12185572064481676, 0.21156534436158836, 0.14592744380934164, 0.1882621448021382, 0.126497438759543, 0.17865395959233865, 0.20175562152871862, 0.17679611162748188, 0.2557063288986683, 10.17650468274951, 63.91611948609352, 92.74096995592117, 86.41708329319954, 74.91247102618217, 62.79715172946453, 50.57548373937607, 34.364295825362206, 44.34430070221424, 74.17581975460052, 86.05794176459312, 67.57328644394875, 45.89062012732029, 52.683561220765114, 27.271668612957, 8.926419261842966, 1.9834840670228004, 0.29300204012542963, 0.17448340135160834, 1.1049187229946256, 4.077707016840577, 13.076240234076977, 14.766075108200312, 19.103771299123764, 22.738777846097946, 19.525330178439617, 21.146452389657497, 19.529253467917442, 17.63794105499983, 17.80849490314722, 33.86774227023125, 26.216364540159702, 20.849165841937065, 20.65724764019251, 16.95501510053873, 27.018738985061646, 38.72558780014515, 19.61172804236412, 26.65150199085474, 35.671703070402145, 53.90413172543049, 64.01478499174118, 62.53502279520035, 62.02265068888664, 62.9711139947176, 67.5753915309906, 69.66022565960884, 69.88558396697044, 67.5714473426342, 72.06608176231384, 70.21919086575508, 68.3403816819191, 70.00830218195915, 73.17495346069336, 54.40275236964226, 49.19126361608505, 48.26300382614136, 41.88165284693241, 73.3437480032444, 55.69754049181938, 53.91650766134262, 55.53607955574989, 64.23700466752052, 65.0777779519558, 65.27872636914253, 60.58495603501797, 64.0433518588543, 65.75198337435722, 69.39366236329079, 67.51282408833504, 69.40804079174995, 68.03085789084435, 63.02216425538063, 62.159530743956566, 59.44351248443127, 56.86143323779106, 45.79421550035477, 40.462694987654686, 31.690519899129868, 25.65875206142664, 24.012792482972145, 16.249111779034138, 13.309561964124441, 29.00100901722908, 32.4711462110281, 29.1645560413599, 19.28148966282606, 11.829510983079672, 24.172338321805, 16.295689679682255, 16.585823111236095, 13.520439248532057, 10.67424377426505, 7.632290404289961, 9.2142747156322, 2.9718174459412694, 0.2622390689793974, 0.1489162357756868, 0.27487101615406573, 1.0403551999479532, 3.403013083152473, 18.082091622054577, 42.01882168650627, 49.96532008051872, 45.73612041771412, 59.06492739915848, 51.09901964664459, 37.063670977950096, 31.017974987626076, 38.28305594623089, 52.75437422096729, 69.84088316559792, 72.23977044224739, 65.42846873402596, 27.264908775687218, 2.2633065143600106, 0.48428350884933025, 0.28808706323616207, 0.1591621633269824, 0.23157979070674628, 0.1254699649871327, 0.11196569743333384, 0.1479492470389232, 0.10693707547034137, 0.12346550574875437, 0.15739751426735893, 0.07445408060448244, 0.2766920387512073, 0.1305302989203483, 0.13315989141119644, 0.12154633412137628, 0.21843086346052587, 0.1749676972394809, 0.12043414419167675, 0.1985127478837967, 0.1650615842663683, 0.1859285356476903, 0.19773364125285298, 0.1697704815887846, 0.1253386790631339, 0.17162273376015946, 0.11691919920849614, 0.18804318155162036, 0.1383866000105627, 0.13879953097784892, 0.2178677514893934, 0.1931226480519399], [0.029334459322853945, 0.05443747460958548, 0.029654440004378557, 0.045926948077976704, 0.07494843259337358, 0.09697432920802385, 0.03247611515689641, 0.05527617198822554, 0.045977236004546285, 0.06880453336634673, 0.016069180019258056, 0.056678753171581775, 0.027076339574705344, 0.05859126402356196, 0.0652942861779593, 0.020091375517949928, 0.01740082116157282, 0.03708255157107487, 0.0333549107745057, 0.03308593048132025, 0.05556461510423105, 0.12047789379721507, 0.017447865902795456, 0.01607251411769539, 0.04050670220749453, 0.08102018022327684, 0.019655293253890704, 0.13079321215627715, 0.25346198526676744, 17.077457830309868, 66.2986296415329, 71.77492618560791, 58.79135347902775, 50.8907338231802, 34.64765042066574, 23.140653781592846, 20.05746692419052, 48.38949903845787, 63.50923351943493, 65.25527402758598, 52.668848410248756, 31.485298611223698, 27.23141547292471, 8.579368684440851, 2.3191521177068353, 0.0577003565558698, 0.07618574862135574, 0.24410673882812262, 1.3743362599052489, 6.117728250101209, 4.624757012352347, 8.746122736483812, 3.9215866941958666, 9.480961505323648, 14.128579515963793, 11.622019317001104, 10.64917841926217, 15.200160015374422, 14.570774137973785, 12.0629514567554, 18.955273367464542, 8.463074024766684, 13.738415502011776, 10.787972621619701, 26.76944386214018, 31.83513443917036, 33.326115533709526, 47.124748304486275, 56.90789334475994, 64.32180091738701, 65.72369769215584, 61.656278148293495, 60.03778539597988, 60.41963070631027, 62.36579887568951, 57.670805007219315, 64.06335398554802, 60.79931013286114, 65.87033942341805, 65.42442575097084, 67.01442003250122, 66.15155473351479, 64.3945138156414, 60.75679421424866, 55.847248658537865, 31.478709764778614, 27.543300837278366, 38.829455226659775, 44.46822725236416, 44.582745507359505, 36.96417711675167, 56.738931611180305, 61.14306628704071, 65.19990339875221, 61.10727220773697, 64.20556515455246, 61.59938380122185, 63.06704744696617, 61.34942941367626, 60.52730932831764, 62.47475042939186, 65.30795440077782, 63.24830912053585, 63.06365802884102, 64.34925064444542, 58.658539205789566, 45.33591069281101, 40.05979880690575, 31.068687066435814, 26.099669001996517, 24.274841621518135, 17.81184822320938, 13.34136625751853, 15.030073542147875, 22.064378634095192, 13.197682667523623, 14.004413578659296, 17.987212613224983, 15.773291811347008, 10.425891950726509, 8.815767299383879, 6.818945473060012, 5.911912769079208, 4.583940077573061, 1.8960557458922267, 0.7310732896439731, 0.05965733689663466, 0.05382771123549901, 0.10902015783358365, 0.43031251116190106, 1.7719712667167187, 17.311040796339512, 36.44671708345413, 33.642881736159325, 34.21732731163502, 37.752137035131454, 27.197908870875835, 24.14228193461895, 28.11615999788046, 38.435887545347214, 48.26553829014301, 57.21811629831791, 51.77225612103939, 36.823812648653984, 8.143315482884645, 0.11673594068270177, 0.1236388343386352, 0.12695819372311234, 0.014409365812753094, 0.030577430516132154, 0.06450601402320899, 0.11315158262732439, 0.03980789966590237, 0.0461707769864006, 0.026409486490592826, 0.02030739615292987, 0.06362178959534504, 0.020044536722707562, 0.0915007822914049, 0.01924254040204687, 0.12460037571145222, 0.02995829752762802, 0.06337794955470599, 0.0708101355121471, 0.036768919962923974, 0.047498542262474075, 0.06565407937159762, 0.022224528729566373, 0.021285596885718405, 0.04916999241686426, 0.03492882788123097, 0.0335320317390142, 0.015367921896540793, 0.021766588361060712, 0.03342909214552492, 0.027972267671430018, 0.010581814312899951, 0.019455549772828817, 0.04478489041503053, 0.09328929882030934, 0.04745141959574539, 0.017075638024834916, 0.04007091680250596, 0.014692227050545625, 0.02529808880353812, 0.042609251104295254, 0.04101816812180914, 0.043231582749285735, 0.014569178038073005, 0.05142439214978367, 0.08032870638999157, 0.03233711460779887, 0.009115112497966038, 0.02235097585071344, 0.01159864568762714, 0.10010648926254362, 0.04679836674768012, 0.04188013554085046, 0.025929639778041746, 0.06315272257779725, 0.028880856807518285, 0.08350964781129733, 0.051576669720816426, 0.19588604976888746, 0.2820599335245788, 22.948841974139214, 74.41961467266083, 82.62788102030754, 68.64419057965279, 60.36476545035839, 45.12307271361351, 34.66345377266407, 24.3584618344903, 36.0248751193285, 66.65096953511238, 66.66049182415009, 55.017513781785965, 29.80942513793707, 24.18699413537979, 8.20241466164589, 1.632525755558163, 0.04938969781505875, 0.27392252173740417, 1.5392518043518066, 5.604073237627745, 6.99895653873682, 8.918279148638248, 13.91326216980815, 11.35705953463912, 12.759150099009275, 14.34978749603033, 12.436311822384596, 17.612244933843613, 14.366538897156715, 12.217243127524853, 14.514668248593807, 15.031802449375391, 12.729972414672375, 11.165589708834887, 10.318622756749392, 18.437325060367584, 24.13098704069853, 31.693656630814075, 46.28508076071739, 57.82522112131119, 63.25761862099171, 67.58185878396034, 64.45898115634918, 62.88770467042923, 62.514028921723366, 65.78260973095894, 60.77129043638706, 65.83927229046822, 62.73131266236305, 65.17123773694038, 66.2320876121521, 68.74970331788063, 66.87532469630241, 65.96493914723396, 63.24379876255989, 61.362227126955986, 35.26249922811985, 34.13077935576439, 47.120101153850555, 53.447054252028465, 51.097305938601494, 42.34644390642643, 61.72389172017574, 65.18373146653175, 68.00394013524055, 61.048143580555916, 65.16809150576591, 64.92621168494225, 64.85361278057098, 64.17775064706802, 62.48800031840801, 64.77646172046661, 66.8688802421093, 65.50669893622398, 64.3904784321785, 66.09209552407265, 58.34897741675377, 45.791631639003754, 37.79456935822964, 30.230832025408745, 25.377103574573994, 22.549623996019363, 17.722984291613102, 13.23080264031887, 8.700751271098852, 13.100840114057064, 10.621774289757013, 12.50490004196763, 13.526026848703623, 14.046017546206713, 11.088707484304905, 12.87526236847043, 10.220387578010559, 5.092312898486853, 7.067067883908749, 3.176950626075268, 3.053545360453427, 0.3865201579174027, 0.24341945070773363, 0.01917796427733265, 0.13844968256307766, 2.1214211778715253, 15.326843317598104, 32.201478481292725, 36.000579223036766, 33.91123853623867, 41.623525097966194, 32.20410034060478, 33.04325491189957, 33.67902919650078, 43.81771735846996, 54.067401364445686, 65.34787505865097, 62.62633189558983, 43.81214305758476, 9.916269946843386, 0.09126670149271376, 0.03183372326020617, 0.06763836703612469, 0.013286357225297252, 0.04252375198120717, 0.07864797196816653, 0.044860760172014125, 0.050318777648499236, 0.027844588585139718, 0.03348895377712324, 0.01994554535485804, 0.046214062749641016, 0.040031479074968956, 0.04349525668658316, 0.03588330771890469, 0.05311317145242356, 0.02513814855774399, 0.016640932444715872, 0.09491042394074611, 0.02135015445674071, 0.0747047112963628, 0.1445525261806324, 0.02611811003589537, 0.011451128993940074, 0.015830503471079282, 0.006993554416112602, 0.0822621643601451, 0.06258282737690024, 0.02723188816162292, 0.03303491525002755, 0.02417755898932228, 0.09656985130277462, 0.21880754793528467, 0.11282909719739109, 0.2613832539645955, 0.12873557803686708, 0.1606880486360751, 0.15693189081503078, 0.11772390993428417, 0.1628848206019029, 0.11930636173929088, 0.17646487627644092, 0.13393381785135716, 0.18048391764750704, 0.12934140802826732, 0.2751729218289256, 0.20642720366595313, 0.04885948896117043, 0.10656462865881622, 0.11490016418974847, 0.2393744044820778, 0.16861224139574915, 0.1400875876424834, 0.09638096729759127, 0.11756313848309219, 0.1420037090429105, 0.29970562260132283, 0.1221639197319746, 0.21910967625444755, 0.690398431615904, 32.746175453066826, 86.47968873381615, 90.07675051689148, 74.72622781991959, 68.23449656367302, 50.2037762850523, 35.462870076298714, 31.062785983085632, 63.03862877190113, 74.68303173780441, 73.20281356573105, 60.07368586957455, 44.784742668271065, 33.965875804424286, 11.508422512561083, 3.0920532066375017, 0.18299617659067735, 0.2943165320903063, 1.0928424960002303, 4.64917260222137, 12.53653809428215, 13.440098259598017, 19.70939990133047, 13.844766095280647, 19.985681176185608, 23.525457233190536, 23.449864089488983, 21.825905330479145, 27.98428427428007, 25.411510728299618, 20.227462202310562, 28.48365917801857, 17.86779072135687, 20.4592402651906, 16.73741787672043, 32.083217427134514, 34.56350773572922, 37.0341731607914, 50.964031890034676, 61.12335294485092, 65.58098495006561, 69.65764939785004, 67.68906623125076, 63.93988341093063, 65.50495862960815, 66.57096102833748, 62.31736287474632, 68.27748745679855, 64.35191810131073, 66.94490656256676, 67.86304369568825, 68.86957168579102, 66.52314439415932, 69.17339578270912, 66.54892981052399, 63.48869942128658, 42.46845155954361, 39.592553079128265, 55.695777386426926, 55.280531868338585, 53.11491407454014, 49.99123848974705, 68.87363746762276, 66.16292372345924, 66.35993555188179, 60.925843343138695, 66.6340984404087, 67.17285633087158, 66.95218697190285, 67.02621459960938, 64.56396952271461, 67.85672083497047, 69.812141507864, 67.60460436344147, 67.23436743021011, 68.7294428050518, 60.56058034300804, 50.89240953326225, 45.833436995744705, 35.71664325892925, 30.125855058431625, 29.32380359619856, 21.153685301542282, 18.835917972028255, 20.22033378481865, 32.659376710653305, 23.780900426208973, 20.08528523147106, 30.27287296950817, 25.978459306061268, 20.267002880573273, 18.615455701947212, 15.659249480813742, 16.98972813785076, 13.050077687948942, 6.698428764939308, 1.8095812923274934, 0.5883778841234744, 0.2128442726098001, 0.20680820744019002, 0.9323969960678369, 2.6669329684227705, 21.83781199157238, 45.876587480306625, 45.33509373664856, 48.11133116483688, 52.975051179528236, 37.51175433397293, 36.47575132548809, 40.82148313522339, 54.27929699420929, 64.6573457121849, 74.84019130468369, 74.54351082444191, 54.386344850063324, 14.635988138616085, 0.5982429266441613, 0.3395968320546672, 0.2916557842399925, 0.13105001009535044, 0.1116464774531778, 0.22828579792985693, 0.21658511250279844, 0.1073262354475446, 0.1390801221714355, 0.0756495023961179, 0.16362103109713644, 0.11141150607727468, 0.16952379170106724, 0.22125705087091774, 0.12470668094465509, 0.1920369453728199, 0.1305128139210865, 0.15002191707026213, 0.33087876392528415, 0.1396445551654324, 0.1759100763592869, 0.2199130956432782, 0.18190619914093986, 0.08752777634072118, 0.16802720638224855, 0.12758559052599594, 0.1555142700090073, 0.11968667531618848, 0.23916421341709793, 0.12358111009234563, 0.14475539966952056], [0.001718177279599331, 0.031162372761173174, 0.02107170435920125, 0.022528607041749638, 0.14839054289041087, 0.06359689054079354, 0.044567771401489154, 0.06914301950018853, 0.004105023817828624, 0.039773412063368596, 0.012286429191590287, 0.04976113901648205, 0.01923070685734274, 0.05839955985720735, 0.013584476091637043, 0.012713559299299959, 0.041039003917830996, 0.055953348346520215, 0.048969582858262584, 0.03983004906331189, 0.08551666745916009, 0.06334951045573689, 0.02301162272488, 0.01486163710069377, 0.027509835454111453, 0.019435624963080045, 0.054894927015993744, 0.08680456085130572, 5.260655265301466, 40.059000849723816, 79.18318346142769, 57.07716666162014, 52.627438232302666, 35.12126460671425, 29.05807815492153, 20.28947487473488, 42.995794862508774, 69.82402727007866, 74.17962715029716, 59.004590436816216, 26.251753941178322, 33.95116299390793, 12.314265221357346, 2.7119028428569436, 0.020717957813758403, 0.11850418173708022, 0.18507398228393868, 0.5863746197428554, 4.121772777289152, 6.704788198694587, 7.830018969252706, 13.617370147258043, 9.862780217081308, 9.495928902179003, 15.493787359446287, 16.235766895115376, 19.47966042906046, 15.042305085808039, 23.659861721098423, 24.846842028200626, 23.31012848764658, 24.840049892663956, 22.15768452733755, 33.00373323261738, 38.74119736254215, 49.031295999884605, 57.60275065898895, 63.18382278084755, 64.39927116036415, 58.995714113116264, 62.21259109675884, 61.50765672326088, 58.42812716960907, 58.27999971807003, 57.9065215587616, 59.874029383063316, 63.43266002833843, 66.28376483917236, 65.81391245126724, 66.9840520620346, 66.58389553427696, 66.14098370075226, 59.74642463028431, 63.695833906531334, 61.132746040821075, 43.87881048023701, 25.724178850650787, 44.42858777940273, 38.103830963373184, 39.159239530563354, 43.07489141821861, 57.23165117204189, 62.25248895585537, 65.31970337033272, 60.698531940579414, 65.53273513913155, 60.56121490895748, 62.885196805000305, 55.31173959374428, 58.500292897224426, 57.956127896904945, 59.20072451233864, 59.67873126268387, 65.47555580735207, 65.76607301831245, 64.9739371240139, 61.91176123917103, 48.94649975001812, 46.05983644723892, 42.383081540465355, 33.723232224583626, 31.529902517795563, 24.13113333284855, 25.61293411999941, 48.72070446610451, 16.388275511562824, 14.838725309818983, 8.62005215138197, 8.269252125173807, 3.3831610484048724, 10.630251634866, 6.279538767412305, 4.75000636652112, 5.457689892500639, 3.4754528710618615, 5.550060085952282, 0.5502464552409947, 0.3053937095683068, 0.08046780712902546, 0.07976316759595647, 0.016813711845315993, 2.0087923714891076, 13.129230290651321, 40.42102262377739, 39.29216019809246, 34.58924375474453, 33.733419477939606, 17.16585248708725, 16.15322582423687, 30.379588343203068, 42.18887776136398, 43.93020272254944, 60.28042897582054, 44.86716024577618, 27.232108935713768, 2.304069777019322, 0.05048235441790894, 0.05658559879520908, 0.021582084882538766, 0.014903363426128635, 0.04115371768421028, 0.06774400433641858, 0.04036777958390303, 0.05220223712967709, 0.0805355206830427, 0.044295822517597117, 0.013782626738247927, 0.05144915390701499, 0.162945706397295, 0.03210512666555587, 0.022771534240746405, 0.03160307118378114, 0.014250598160288064, 0.034718191527645104, 0.09690303850220516, 0.04608543371432461, 0.006073282020224724, 0.06393711330019869, 0.03128209231363144, 0.06640882129431702, 0.0428740271308925, 0.02547992240579333, 0.046845329852658324, 0.028972252293897327, 0.02148109157133149, 0.04905767578748055, 0.05122721464431379, 0.027566769313125405, 0.020923143092659302, 0.0312655461311806, 0.05075450739241205, 0.04525788339378778, 0.05657851499563549, 0.06557685148436576, 0.024252376751974225, 0.03840506986307446, 0.060063788914703764, 0.061303390757529996, 0.038732538814656436, 0.05031548622355331, 0.021723028003179934, 0.03816992037172895, 0.01807464301236905, 0.050438549151294865, 0.05023196863476187, 0.026829024427570403, 0.009185262151731877, 0.047984860502765514, 0.022864191378175747, 0.019232358135923278, 0.027496189213707112, 0.03860235869069584, 0.034151302024838515, 0.08048501011217013, 7.408682378008962, 50.68601980805397, 84.86043602228165, 67.09926187992096, 57.31128349900246, 45.222437381744385, 36.41370065510273, 29.966143928468227, 34.4234586507082, 66.83308616280556, 74.4805558025837, 71.11969694495201, 32.25135840475559, 24.507563933730125, 11.229647621512413, 1.7878177226521075, 0.07600129523780197, 0.49601719016209245, 0.7984821475110948, 3.846726198680699, 6.469840630888939, 10.240127518773079, 10.624522492289543, 15.165402330458164, 15.697947554290295, 17.68142592161894, 16.718855872750282, 16.72867264598608, 20.5447755753994, 13.410171065479517, 9.523344431072474, 13.517137225717306, 13.552932254970074, 19.631118401885033, 21.335961520671844, 28.708033338189125, 37.402346804738045, 44.935871958732605, 56.42066068947315, 61.83360703289509, 68.78555059432983, 62.06251434981823, 65.10450571775436, 64.81980979442596, 62.66203857958317, 58.653443679213524, 59.43181291222572, 60.99512882530689, 65.08216291666031, 66.61506906151772, 65.8078707754612, 67.7611255645752, 67.08378911018372, 66.23264238238335, 62.35832467675209, 63.28815758228302, 66.44872158765793, 44.1630732268095, 35.66974617540836, 50.232130363583565, 44.62782248854637, 45.835811868309975, 47.83192835748196, 63.0945959687233, 64.67496156692505, 64.68022048473358, 59.06243093311787, 66.8765178322792, 61.60801313817501, 64.03959766030312, 58.823936730623245, 59.716125056147575, 61.37674614787102, 63.09071637690067, 63.9666111767292, 68.15652474761009, 66.80981621146202, 65.68649768829346, 62.53852620720863, 51.26216009259224, 46.06097638607025, 37.514558583498, 32.36599065363407, 29.547613486647606, 23.646374344825745, 20.66419556736946, 19.62826855480671, 14.016319289803505, 10.131850428879261, 12.096435260027647, 9.234159998595715, 14.335814695805311, 6.37990040704608, 11.420599725097418, 11.065034754574299, 10.514797680079937, 7.302083848044276, 7.953606862574816, 2.914849240332842, 0.7039683347102255, 0.14214168913895264, 0.07700581438257359, 0.060710414763889275, 2.0231651002541184, 12.156738974153996, 36.11185245215893, 37.10490256547928, 30.690668150782585, 31.69454388320446, 24.243506602942944, 27.70242679864168, 42.498804330825806, 49.352488964796066, 51.291543915867805, 69.00837823748589, 55.53613655269146, 31.042103692889214, 2.959474283270538, 0.029835767090844456, 0.03964125040511135, 0.04575676248350646, 0.02065491979010403, 0.037986921597621404, 0.030297225239337422, 0.059270551791996695, 0.042079713894054294, 0.05908833227294963, 0.07895416725659743, 0.019794989566435106, 0.016654628780088387, 0.05674195446772501, 0.03660841568489559, 0.026900495104200672, 0.03771583360503428, 0.006018069943820592, 0.05589412496192381, 0.05478549734107219, 0.022657395638816524, 0.03975924075348303, 0.04886781956884079, 0.06894884398207068, 0.05003710663004313, 0.02397161857516039, 0.03003957939654356, 0.010477606574568199, 0.06994024195591919, 0.06686933877062984, 0.015615442061971407, 0.1602122577605769, 0.18817684234818444, 0.10219711184618063, 0.11798503459431231, 0.2258842228911817, 0.1984472607728094, 0.13705999619560316, 0.22651472187135369, 0.07694912172155455, 0.14801514975260943, 0.11420755487051792, 0.20386949559906498, 0.11332551977830008, 0.30032694863621145, 0.07622749442816712, 0.14080707012908533, 0.15910249465378, 0.15488469129195437, 0.12013131083222106, 0.10922947316430509, 0.16849303763592616, 0.12790900364052504, 0.09497620791080408, 0.16140027291839942, 0.1188421854749322, 0.1128945175150875, 0.17310051305685192, 0.24977947818115354, 11.233449317514896, 63.27769674360752, 93.4651654958725, 76.86953321099281, 68.97162660956383, 50.256604850292206, 43.186901807785034, 31.58932562917471, 56.261069253087044, 80.68553164601326, 80.87854608893394, 69.73434448242188, 37.74911619722843, 42.45131067931652, 16.571936756372452, 3.908502571284771, 0.15233496873406693, 0.5495269875973463, 0.6104560650419444, 4.062545355409384, 9.868360217660666, 21.09216660261154, 15.61310475692153, 24.498816803097725, 19.80007253587246, 19.025881178677082, 22.995226085186005, 27.287641055881977, 31.77995380014181, 31.485957875847816, 41.42775200307369, 36.64661295711994, 31.515130810439587, 29.72439520061016, 25.566065534949303, 36.39521084725857, 40.34589685499668, 52.17607565224171, 60.23266553878784, 63.7411654740572, 66.09451979398727, 63.73466782271862, 66.30047634243965, 65.89892908930779, 63.93140226602554, 60.59480130672455, 60.9792722761631, 64.6718381345272, 67.54801779985428, 70.48320829868317, 67.54766821861267, 70.96981778740883, 69.57894802093506, 67.94434413313866, 65.87144136428833, 67.23824322223663, 67.74934619665146, 51.66667878627777, 42.27575249969959, 56.72258108854294, 48.43500159680843, 51.88814230263233, 54.17552836239338, 66.24284103512764, 64.50001895427704, 67.35811918973923, 61.544731333851814, 69.29295256733894, 64.73207250237465, 68.22584062814713, 60.30130885541439, 65.40464401245117, 62.866152226924896, 64.08093184232712, 65.62609612941742, 70.00913053750992, 69.28466901183128, 68.49639371037483, 65.36467015743256, 54.34827849268913, 50.323336869478226, 44.43899542093277, 37.53519147634506, 34.076202884316444, 28.73488649725914, 34.29579310119152, 57.330472469329834, 24.167978055775166, 22.623910009860992, 19.33883238583803, 19.15397420525551, 16.311316341161728, 22.85765066742897, 16.06158424168825, 16.75080455839634, 16.80075477808714, 11.929656509310007, 13.454064410179853, 2.2557465825229883, 0.7013753894716501, 0.3219498664839193, 0.1641401633969508, 0.5422833294142038, 3.0244664708152413, 16.734697222709656, 51.08670070767403, 52.63948358595371, 45.64322680234909, 46.28360643982887, 26.31534542888403, 28.89334749430418, 42.751034796237946, 56.92926339805126, 59.20751094818115, 78.72359812259674, 65.63341453671455, 38.098849430680275, 4.807493006810546, 0.1054313246277161, 0.1482373190810904, 0.1420378775219433, 0.1296217172057368, 0.1752267513074912, 0.20360836351756006, 0.18148523813579232, 0.12528435385320336, 0.13150594109902158, 0.2643808181164786, 0.22725707734934986, 0.20308510487666354, 0.25775263784453273, 0.12401662461343221, 0.17943336308235303, 0.1412127132061869, 0.07753581172437407, 0.2373586274916306, 0.20141236338531598, 0.11907335705473088, 0.15261507011018693, 0.1405676532885991, 0.1828105209278874, 0.16402507113525644, 0.1732645128504373, 0.07616130969836377, 0.17873084609163925, 0.1936888028285466, 0.2152970409952104, 0.10132159281056374], [0.0578453870548401, 0.03746804904949386, 0.024108709949359763, 0.058446352268219925, 0.0198395648112637, 0.17164007032988593, 0.08132788207149133, 0.04024242713057902, 0.02702424822928151, 0.030771478013775777, 0.03192199801560491, 0.03883751189277973, 0.02290106498548994, 0.03502089501125738, 0.029557066518464126, 0.05796004887088202, 0.03908158570993692, 0.05466959984914865, 0.07166612864239141, 0.09172802048851736, 0.055128517997218296, 0.035661498332046904, 0.053022647989564575, 0.037340551789384335, 0.0632400436734315, 0.05794699820398819, 0.09322669866378419, 0.292741249431856, 20.86529217660427, 58.73357377946377, 64.21539902687073, 61.61361023783684, 47.19136252999306, 36.748960465192795, 22.10751961916685, 37.24101126194, 82.47433125972748, 64.08217817544937, 59.20808091759682, 21.21034026145935, 29.940974079072475, 14.79063319042325, 2.799173234961927, 0.07934475215733983, 0.07487275579478592, 0.2352693778811954, 1.2169753038324416, 3.7135015474632382, 7.418700540438294, 5.500700259581208, 9.072731360793114, 13.30705314874649, 16.52807381004095, 13.371967915445566, 12.528467327356339, 9.771214630454779, 18.753412999212742, 9.77988576516509, 3.8338463148102164, 25.91629084199667, 32.47828222811222, 46.31215810775757, 50.05588822066784, 47.81180463731289, 55.56621193885803, 62.10509866476059, 62.14842773973942, 63.68435092270374, 65.33339783549309, 59.977950006723404, 63.06677766144276, 58.63647758960724, 56.36158145964146, 57.02569082379341, 62.621107175946236, 62.08562470972538, 63.67549739778042, 66.15227669477463, 66.42612040042877, 64.64064940810204, 65.5948694050312, 65.6526567041874, 60.97435154020786, 61.550537422299385, 65.01069635152817, 56.50752782821655, 25.533256195485592, 47.21221201121807, 35.11543571949005, 36.51973016560078, 47.921854332089424, 56.73658333718777, 59.80470210313797, 60.46388693153858, 58.7421765178442, 63.52827429771423, 60.73732025921345, 57.30484664440155, 51.58920094370842, 52.655058950185776, 56.86530143022537, 58.46424803137779, 56.37437917292118, 61.60739377140999, 63.9681538939476, 63.21346499025822, 62.401889339089394, 64.53790292143822, 54.546760842204094, 50.14331392943859, 46.789382100105286, 44.915128871798515, 40.2569018304348, 26.00205224007368, 25.655018761754036, 25.95892835408449, 26.343178935348988, 15.609156768769026, 13.790742494165897, 15.85051791742444, 7.3535720352083445, 8.119567707180977, 4.019247628748417, 5.919760297983885, 3.5738975135609508, 6.972043057903647, 1.267209320794791, 0.6634676735848188, 0.15897290082648396, 0.07784720946801826, 0.06009800192259718, 0.397787443944253, 1.7664717743173242, 18.02002765238285, 39.28217813372612, 54.65452305972576, 43.941674306988716, 35.96233807504177, 21.0201433673501, 18.244580402970314, 27.29583341628313, 43.671383410692215, 56.44422322511673, 57.689446806907654, 33.33157204091549, 10.19618857651949, 0.3470317565370351, 0.0813936883059796, 0.04060075829329435, 0.04780617731739767, 0.04340068109740969, 0.03063131600356428, 0.04618704115273431, 0.02415797185676638, 0.04377193676191382, 0.0643930739897769, 0.06963210966205224, 0.012310157508181874, 0.033970904478337616, 0.04889619929599576, 0.0400632504170062, 0.12188266060547903, 0.03108870718278922, 0.013534859808714828, 0.025018315827765036, 0.011320466473989654, 0.03513940115226433, 0.012842277392337564, 0.01190223603771301, 0.016114029858727008, 0.010813674234668724, 0.01881052510725567, 0.02760784533165861, 0.03967566379287746, 0.05643395576043986, 0.028778748419426847, 0.02414023081655614, 0.012875905958935618, 0.05328715684299823, 0.038306935675791465, 0.07198096252977848, 0.05567841602896806, 0.02454879053402692, 0.02803886429319391, 0.037209982037893496, 0.03911848529241979, 0.019408855696383398, 0.012956214686710155, 0.04814216612430755, 0.037793395458720624, 0.017394984170095995, 0.15044408035464585, 0.026972038140229415, 0.033007147794705816, 0.06958843427128159, 0.01539137561849202, 0.08037209234316833, 0.02594384077383438, 0.017027396570483688, 0.035891668012482114, 0.013802769553876715, 0.02271395285788458, 0.06623438690439798, 0.42896153521724045, 28.744006007909775, 69.47952255606651, 75.1753181219101, 69.11760717630386, 58.371422812342644, 45.78308969736099, 32.314731404185295, 29.41992323845625, 69.37559813261032, 69.2485785484314, 67.08992198109627, 31.424251087009907, 20.010041669011116, 13.636712059378624, 1.9437484117224813, 0.17139107978437096, 0.11440964168286882, 1.2772112153470516, 4.3028321117162704, 8.81220119073987, 9.559603035449982, 12.100931368768215, 11.125429663807154, 11.088016871362925, 12.937528677284718, 16.420045606791973, 19.347503520548344, 15.643312186002731, 12.540752068161964, 14.662149734795094, 8.572586998343468, 17.480838485062122, 27.12878108024597, 40.10139897465706, 43.42387609183788, 47.22958467900753, 54.32567350566387, 63.1493966281414, 63.1955299526453, 66.07803627848625, 65.11854216456413, 62.40837939083576, 63.6962328851223, 61.00729577243328, 57.15161606669426, 59.86497446894646, 63.26772227883339, 65.62518417835236, 65.53785726428032, 66.23138085007668, 67.84681856632233, 64.96945336461067, 67.30264216661453, 66.41123279929161, 63.016988933086395, 62.69470542669296, 65.61650544404984, 56.89719311892986, 33.39598998427391, 50.20604096353054, 42.491257935762405, 43.80123384296894, 52.707640528678894, 61.31048150360584, 59.82686251401901, 61.15801468491554, 58.53347651660442, 65.97073763608932, 61.89528152346611, 58.40656712651253, 53.75988386571407, 56.02640524506569, 60.787397772073746, 60.52891664206982, 59.32756930589676, 63.23125943541527, 63.48327711224556, 64.65068086981773, 64.06921327114105, 65.37154778838158, 55.60855306684971, 52.49956749379635, 45.17619766294956, 41.499305963516235, 36.815795078873634, 30.81094689667225, 27.489858604967594, 24.281426668167114, 17.432100400328636, 12.384284064173698, 11.844241842627525, 12.959707137197256, 11.653826460242271, 11.987547352910042, 8.484460227191448, 12.277051918208599, 6.955702509731054, 10.814037322998047, 5.467631109058857, 1.4922948740422726, 0.15753593965200707, 0.20182775828288868, 0.09814263292355463, 0.27514567016623914, 1.4821432437747717, 17.008615024387836, 35.39170369505882, 47.24272057414055, 34.6615918725729, 29.00150489062071, 22.339303381741047, 26.79498229175806, 36.42543442547321, 51.116962283849716, 62.332535460591316, 65.66017270088196, 41.828121319413185, 12.374765574932098, 0.4391425842186436, 0.07400077680358663, 0.004620742238330422, 0.04573968566546682, 0.05163231224287301, 0.018319392183911987, 0.07166085939388722, 0.008095117718767142, 0.03721210829098709, 0.09506745496764779, 0.08672169264173135, 0.023471774693462066, 0.0603933692764258, 0.10001651127822697, 0.0356201124668587, 0.2004940150072798, 0.02197384794271784, 0.07630844789673574, 0.02609869174193591, 0.027639844884106424, 0.04066673151100986, 0.07633535817149095, 0.03573180569219403, 0.102214515209198, 0.019635707976703998, 0.015539944306510733, 0.04325982888985891, 0.046423047824646346, 0.06901836837641895, 0.03715927479788661, 0.11685190125717781, 0.11380335155990906, 0.12164199695689604, 0.15849887626245618, 0.22521024890011176, 0.24009897810174152, 0.17032353003742173, 0.18275272246683016, 0.10069855241454206, 0.12424330619978718, 0.14881545212119818, 0.13330432819202542, 0.21947616362012923, 0.09042162535479292, 0.09437192900804803, 0.19230659730965272, 0.1615278035751544, 0.09884490500553511, 0.1269072972354479, 0.20348702237242833, 0.11215927923331037, 0.11859407808515243, 0.11255617981078103, 0.17776087392121553, 0.15875273529672995, 0.2064200196764432, 0.2876275253947824, 1.5954980487003922, 39.09549795091152, 83.17746832966805, 84.27207559347153, 78.99929612874985, 64.33127000927925, 52.885877564549446, 32.945976331830025, 48.833774998784065, 94.824078977108, 71.60138189792633, 69.50830981135368, 32.032349556684494, 42.30410277843475, 19.175235964357853, 3.6574683291837573, 0.20955784973921254, 0.28223044937476516, 1.1693009245209396, 3.2018644642084837, 10.339374393224716, 18.55895083397627, 16.489044204354286, 22.13082756847143, 24.3808863312006, 27.310559526085854, 24.883576557040215, 26.039746217429638, 21.121463030576706, 30.01480981707573, 20.77645294368267, 9.860146958380938, 30.861358791589737, 36.71337157487869, 50.89590534567833, 51.34869284927845, 49.50228072702885, 56.684290543198586, 63.820037841796875, 62.49152272939682, 67.39845782518387, 68.4027211368084, 65.44552981853485, 66.25427082180977, 64.21240478754044, 59.83627840876579, 61.96461260318756, 65.25672554969788, 68.27279090881348, 67.02105447649956, 70.9462970495224, 70.58719351887703, 67.62527525424957, 69.96722638607025, 68.10195967555046, 64.25924107432365, 64.18604180216789, 66.35516300797462, 63.26660893857479, 39.25020284950733, 57.14428626000881, 46.79792784154415, 50.131637156009674, 58.0136264115572, 62.73583061993122, 60.61034247279167, 62.30879433453083, 59.89329054951668, 69.02282506227493, 64.24661815166473, 60.81084631383419, 55.756574124097824, 58.49160276353359, 63.40123951435089, 63.71417932212353, 60.53528510034084, 64.83661249279976, 67.52097085118294, 66.69954612851143, 66.47901356220245, 69.19231876730919, 58.201017156243324, 52.21725784242153, 48.9207599312067, 48.26103553175926, 43.415679931640625, 32.29548543691635, 30.650736093521118, 32.03924618661404, 33.60465198755264, 23.473916798830032, 27.432189099490643, 29.497294686734676, 17.81076718121767, 20.64059693366289, 12.049837410449982, 12.465692795813084, 10.334151573479176, 17.009297087788582, 4.842785038053989, 2.4171538464725018, 0.6578556122258306, 0.2597738028271124, 0.23214348155306652, 0.4713656863896176, 2.685934086330235, 21.504155695438385, 49.23388592898846, 72.42463812232018, 59.529562667012215, 50.30381731688976, 31.20445378124714, 29.036729000508785, 40.73928214609623, 59.032955914735794, 71.59771129488945, 77.18325957655907, 52.795932590961456, 18.72201718389988, 1.3931514252908528, 0.12293386083911173, 0.08859114037477411, 0.10237877475447021, 0.15481717069633305, 0.10702185842092149, 0.14283012016676366, 0.07922177828731947, 0.16809346532681957, 0.1986795975244604, 0.20412764424690977, 0.13804181304294616, 0.13605446030851454, 0.25246421224437654, 0.14134304918115959, 0.2851594390813261, 0.13330219080671668, 0.1719087574747391, 0.1210373395588249, 0.10442746599437669, 0.12797021598089486, 0.1138240574800875, 0.23155733331805095, 0.21790580882225186, 0.1751616649562493, 0.14669641270302236, 0.09410452577867545, 0.1782185712363571, 0.13667974941199645, 0.06869646182167344], [0.05541176979022566, 0.049614601957728155, 0.03638469526777044, 0.029205537139205262, 0.025702212333271746, 0.04109396366402507, 0.026407503100926988, 0.048089670308399945, 0.06968924761167727, 0.029004901225562207, 0.006946620069356868, 0.04642742278520018, 0.07800428502378054, 0.029281718598213047, 0.024061509357125033, 0.03482501255348325, 0.05283051708829589, 0.056953986058942974, 0.010755731982499128, 0.0207958406463149, 0.04056158402818255, 0.03904728735506069, 0.03162250060995575, 0.02779159738565795, 0.057055697398027405, 0.006442475441872375, 0.12148372654337436, 4.638737887144089, 38.81650932133198, 62.92564183473587, 57.029665410518646, 50.309881791472435, 37.55047045648098, 26.572817713022232, 23.659449443221092, 54.19611565768719, 72.41701573133469, 77.16058239340782, 42.14818574488163, 30.982937067747116, 22.47695479542017, 3.265188541263342, 0.29348265496082604, 0.024265837455459405, 0.15303718886571005, 1.0280670155771077, 5.791048854589462, 7.099192310124636, 4.537488045170903, 6.956107662990689, 7.559749446809292, 11.044449359178543, 13.012167122215033, 23.416053503751755, 16.572575122117996, 16.029584258794785, 24.047273732721806, 22.46645975857973, 26.273724362254143, 40.00689424574375, 48.52710485458374, 61.505388244986534, 61.65316231548786, 59.64819610118866, 67.72593185305595, 62.43287667632103, 62.85417526960373, 63.31689544022083, 62.282051369547844, 57.70802780985832, 57.202753722667694, 51.026690527796745, 54.504404515028, 59.81531113386154, 63.938804268836975, 61.97764590382576, 61.89255706965923, 63.58412370085716, 65.85096806287766, 62.22631596028805, 62.2758425027132, 64.24483224749565, 61.10150031745434, 63.703733682632446, 60.09025298058987, 60.967029333114624, 32.973391860723495, 39.69080060720444, 38.09512183070183, 38.125998973846436, 54.36931416392326, 58.35855670273304, 59.67249199748039, 59.070490300655365, 61.08159698545933, 62.01453812420368, 60.1782638579607, 53.300230130553246, 50.18255442380905, 49.19580817222595, 52.86715216934681, 54.78933222591877, 54.318096712231636, 57.253553196787834, 58.71105618774891, 57.2988011687994, 59.97122436761856, 57.45580114424229, 62.397671565413475, 56.6156168282032, 57.941867262125015, 54.7355081140995, 50.70970393717289, 51.053505688905716, 42.13243559002876, 41.93140357732773, 24.82753336429596, 25.22682163864374, 15.796906594187021, 20.029120445251465, 7.1227035485208035, 10.80013481900096, 11.318225618451834, 13.845761641860008, 8.5998628847301, 5.396477552130818, 7.124227741733193, 1.1108965147286654, 0.4422487097326666, 0.2748559060273692, 0.10563862131675705, 0.13284026324981824, 0.1164000372227747, 2.3690854758024216, 18.43943204730749, 35.206190049648285, 40.31071454286575, 51.561337038874626, 22.381133437156677, 17.619791328907013, 19.935814552009106, 35.83653062582016, 42.59262889623642, 51.030068546533585, 51.09684996306896, 23.185842856764793, 7.40317314863205, 0.15668377600377426, 0.03394258412299678, 0.02651138522196561, 0.07197843922767788, 0.0589754219254246, 0.034640043377294205, 0.057841739399009384, 0.024840356236381922, 0.055177956164698116, 0.006898538176756119, 0.05078024878457654, 0.02576723745733034, 0.0788137009658385, 0.0592485953529831, 0.09343134588561952, 0.03589605039451271, 0.03732538971235044, 0.028037309493811335, 0.040482151962351054, 0.07694816435105167, 0.03865761900669895, 0.04748100160213653, 0.06404205298167653, 0.00820035333163105, 0.050073527527274564, 0.02035320892900927, 0.008204382265830645, 0.06995448376983404, 0.016314585991494823, 0.07285674873855896, 0.02556406154326396, 0.015160319999267813, 0.05476523299876135, 0.06343378132442012, 0.026917492141365074, 0.02291117860295344, 0.01908794918563217, 0.07639878953341395, 0.04758960007166024, 0.03045042492885841, 0.07119690577383153, 0.06080704239138868, 0.01310180179643794, 0.026769006944959983, 0.04504507625824772, 0.07922485077870078, 0.021631222480209544, 0.027408415407990105, 0.04387614913866855, 0.01592286931554554, 0.027528442951734178, 0.01736803307721857, 0.046277902292786166, 0.054143795641721226, 0.13180035108234733, 0.03983394904935267, 5.775945615023375, 48.158152252435684, 73.17054569721222, 66.30877509713173, 59.89735633134842, 49.165170416235924, 39.30083893239498, 30.646180137991905, 48.163452968001366, 74.4743849337101, 74.83141377568245, 43.637356236577034, 21.038684472441673, 20.626148208975792, 3.3601266844198108, 0.4009762447094545, 0.018329663507756777, 0.3734538168646395, 1.6648603579960763, 7.44223172776401, 12.60931558907032, 13.67502635344863, 13.105916641652584, 14.255296066403389, 14.272229857742786, 14.797564018517733, 21.07428476214409, 19.76177629083395, 14.454818610101938, 13.035515919327736, 18.83804775774479, 24.704172983765602, 32.89369113743305, 45.82252778112888, 55.803463608026505, 60.6995502859354, 58.29559028148651, 64.54186230897903, 61.98020696640015, 62.37015724182129, 63.63137796521187, 65.86097672581673, 61.86117075383663, 59.71230246126652, 54.130736365914345, 56.51160500943661, 59.813753217458725, 64.93300572037697, 63.59887830913067, 63.502507880330086, 63.72904792428017, 67.03840434551239, 63.851560950279236, 64.68540340662003, 65.38835808634758, 63.766057938337326, 63.97718980908394, 62.72983454167843, 61.01416580379009, 38.544493317604065, 44.64624010026455, 45.744221583008766, 43.65723296999931, 60.16957372426987, 58.721995800733566, 59.53641749918461, 59.9247794598341, 62.743312418460846, 63.33850488066673, 62.638419046998024, 55.129539370536804, 52.42427833378315, 52.63472244143486, 56.17204003036022, 58.41738134622574, 57.69811414182186, 59.04278978705406, 61.07329063117504, 60.72122052311897, 62.896079421043396, 59.602811336517334, 64.22714799642563, 58.43445762991905, 58.16814512014389, 54.01094779372215, 50.43460249900818, 47.54928432404995, 41.11519977450371, 35.196295380592346, 25.078257210552692, 22.334240153431892, 14.90490635856986, 14.489313159137964, 9.083542730659246, 10.536813698709011, 6.4680566266179085, 11.521882340312004, 11.693145800381899, 12.82917084172368, 9.370954558253288, 4.686850430443883, 1.249055676162243, 0.3823350981110707, 0.08437525917543098, 0.05663681440637447, 0.22221851802896708, 2.1765666687861085, 18.734818696975708, 41.176330894231796, 42.98734411597252, 39.91660349071026, 30.78418493270874, 25.417020432651043, 26.272519826889038, 44.21874403953552, 51.49034924805164, 58.46748545765877, 61.82646721601486, 28.162644803524017, 8.382085170596838, 0.1136752642923966, 0.05469187170092482, 0.012297557696001604, 0.007815531207597815, 0.06405509251635522, 0.07484879926778376, 0.02642018826009007, 0.036923546431353316, 0.014665687849628739, 0.048639382803230546, 0.018909737264038995, 0.03181371866958216, 0.021667622968379874, 0.02886714748456143, 0.06879432141431607, 0.048362494926550426, 0.025200665222655516, 0.052158639664412476, 0.007009515229583485, 0.041098457368207164, 0.010521286603761837, 0.05688092533091549, 0.023003069472906645, 0.019757448026211932, 0.028356529473967385, 0.02357083656534087, 0.021019165869802237, 0.04932817377266474, 0.04065287561388686, 0.1429636325337924, 0.1009064725076314, 0.07726875730440952, 0.09833401796640828, 0.11519620689796284, 0.1810990838566795, 0.1165002716879826, 0.13756303873378783, 0.17894229880766943, 0.11560360886505805, 0.14968036586651579, 0.10916895102127455, 0.13675581954885274, 0.22286035702563822, 0.11517069186083972, 0.18148235860280693, 0.20286688377382234, 0.1375037559773773, 0.11534964593010955, 0.17793907842133194, 0.11062530451454222, 0.17960396799026057, 0.09452908620005473, 0.14354522398207337, 0.1862755193724297, 0.2629177481867373, 0.15000821702415124, 8.455608375370502, 59.20179985463619, 81.59149423241615, 74.8057347536087, 66.66713386774063, 53.822227120399475, 39.46451134979725, 36.36686056852341, 68.72838646173477, 80.24676159024239, 87.67356187105179, 55.58628626167774, 44.06243942677975, 28.873731046915054, 4.441435849294066, 0.724845661316067, 0.11823552427813411, 0.3574861236847937, 2.187998592853546, 13.227543365210295, 12.491243574768305, 18.172608464956284, 17.73329883813858, 24.250027053058147, 23.312043584883213, 21.530575677752495, 31.17070399224758, 25.516485795378685, 27.454094924032688, 32.47660651803017, 30.501278713345528, 33.54798562824726, 43.29936437308788, 53.23935739696026, 63.02761696279049, 60.9748987108469, 59.77104350924492, 67.70116478204727, 60.94603165984154, 63.15420717000961, 66.6359831392765, 68.42172771692276, 63.884824365377426, 61.4687430113554, 54.05376769602299, 58.4178601205349, 61.289928406476974, 67.38542452454567, 64.29487556219101, 62.8140190243721, 64.29567351937294, 70.43166026473045, 66.18773639202118, 67.44619086384773, 68.34583818912506, 66.77766233682632, 66.9518905878067, 63.74252960085869, 63.93983021378517, 44.71335969865322, 49.61025193333626, 49.762304574251175, 51.06355234980583, 62.466683462262154, 61.190430745482445, 61.970566883683205, 62.23102390766144, 63.81891310214996, 66.7683832347393, 66.49145409464836, 57.997716665267944, 55.52857495844364, 55.08952371776104, 58.88317175209522, 60.16323186457157, 60.106956884264946, 63.052923604846, 63.551179468631744, 62.167814299464226, 64.0776564180851, 60.730997398495674, 67.87120565772057, 58.512117862701416, 60.117185935378075, 56.542748138308525, 55.38414090871811, 53.99696834385395, 45.61037756502628, 45.52487835288048, 30.298652686178684, 30.746964029967785, 19.8236882686615, 25.161311253905296, 13.75516215339303, 18.65378424525261, 21.35566346347332, 26.973548009991646, 18.108182922005653, 16.44744783639908, 19.49116811156273, 2.7506149280816317, 0.9327590453904122, 0.5180250748526305, 0.23042601824272424, 0.30778930289670825, 0.34199681889731437, 3.2870744168758392, 22.995226085186005, 48.98699037730694, 56.09740063548088, 65.21859839558601, 34.68512021005154, 25.70767253637314, 32.67131187021732, 51.16141229867935, 61.215915977954865, 66.31753742694855, 71.90972775220871, 36.72499135136604, 11.022366844117641, 0.45136216445825994, 0.10293941537383944, 0.1639817890827544, 0.1653726035146974, 0.23682738334173337, 0.18617584893945605, 0.08941032298025675, 0.19727768056327477, 0.10761487894342281, 0.14382234192453325, 0.11692104715621099, 0.14844776247628033, 0.18252384412335232, 0.13516579783754423, 0.2135000194539316, 0.13664086087374017, 0.22610446263570338, 0.11857760982820764, 0.16363364760763943, 0.1545672005158849, 0.16372190380934626, 0.18123713816748932, 0.13987433892907575, 0.14476543350610882, 0.14668667572550476, 0.14307311415905133, 0.12014377149171196, 0.1924828128539957, 0.11411237443098798], [0.02215233260358218, 0.01910050446895184, 0.05443092144560069, 0.035768133820965886, 0.04063179119839333, 0.03520649130223319, 0.025055048427020665, 0.07617118026246317, 0.043845097679877654, 0.034160745854023844, 0.06793023887439631, 0.019697217176144477, 0.10684229579055682, 0.027328359938110225, 0.06675816504866816, 0.05815363067085855, 0.06033803103491664, 0.06858719541924074, 0.02108153967128601, 0.039497867473983206, 0.09192806639475748, 0.03385794218047522, 0.042054733203258365, 0.05221494269790128, 0.12704748893156648, 0.05197843878704589, 0.04636531615688, 18.527277633547783, 64.63849112391472, 61.87080703675747, 56.83992639183998, 49.043823927640915, 32.391711473464966, 21.473441943526268, 23.81546527147293, 38.597770258784294, 75.38013473153114, 66.86006471514702, 33.079983741045, 26.510506756603718, 4.741876227781177, 0.36196946748532355, 0.11218846790143289, 0.07990842816070653, 0.14692996657686308, 1.6820537229068577, 6.8687099777162075, 16.259707510471344, 10.202755574136972, 13.686087559908628, 8.661987651139498, 11.59402621909976, 12.78765806928277, 15.312685277312994, 26.027130894362926, 22.78548114001751, 25.128826797008514, 42.47414745390415, 44.545803889632225, 47.89424881339073, 61.01071558892727, 62.7015146613121, 65.57941943407059, 59.979287534952164, 62.47939758002758, 57.91558787226677, 61.90549537539482, 63.20975258946419, 58.19523386657238, 57.36703410744667, 53.601751551032066, 49.80605162680149, 56.99625380337238, 60.801802799105644, 64.1197657585144, 64.13661405444145, 62.19447746872902, 63.49832430481911, 62.78890997171402, 59.19950097799301, 59.825673177838326, 62.31604054570198, 60.19852817058563, 62.37009644508362, 60.09926609694958, 59.2585726082325, 34.81788128614426, 41.46489880979061, 42.90653005242348, 47.99137160181999, 59.49761398136616, 55.788123831152916, 59.440415650606155, 57.28255704045296, 61.191407293081284, 59.81054998934269, 59.70100946724415, 48.9657761156559, 44.63126890361309, 48.385490253567696, 54.36991833150387, 51.750186905264854, 53.50657045841217, 52.32086308300495, 54.5707793533802, 52.286729514598846, 58.46023164689541, 58.16141188144684, 59.63969595730305, 60.27179203927517, 59.27681162953377, 58.27560715377331, 56.55134327709675, 53.870598524808884, 53.463948145508766, 46.93573124706745, 38.17920371890068, 33.905025869607925, 31.81575357913971, 24.551538974046707, 18.708831891417503, 12.767692040652037, 8.381214067339897, 12.278209906071424, 4.744072984904051, 14.309357665479183, 6.809170972555876, 5.218926854431629, 0.2625166915822774, 0.3208258392987773, 0.09809505383600481, 0.08798455339274369, 0.1163233065744862, 0.23660616396227852, 3.11751801520586, 20.36921549588442, 39.10980798304081, 42.952876165509224, 24.211529418826103, 22.2169803455472, 44.356361255049706, 61.22025914490223, 47.3756792396307, 36.300014555454254, 48.528233394026756, 47.89668068289757, 16.443725936114788, 0.8476211701054126, 0.0260308371798601, 0.05547499706153758, 0.038472004162031226, 0.04062658503244165, 0.044013023434672505, 0.036325980254332535, 0.014810359334660461, 0.04466554193641059, 0.030061049728828948, 0.06942918422282673, 0.021495307410077658, 0.042724102167994715, 0.02428893123578746, 0.01552449464725214, 0.06081278290366754, 0.06270917801884934, 0.004953819507136359, 0.017005267582135275, 0.0033425983474444365, 0.016567088750889525, 0.054787998378742486, 0.04199241506285034, 0.008835348799038911, 0.019912772113457322, 0.042150451699853875, 0.005805952077935217, 0.0029450922238538624, 0.010436858028697316, 0.052062609465792775, 0.05396038126491476, 0.03956892069254536, 0.00994586240267381, 0.08606318500824273, 0.02700034179724753, 0.04468729799555149, 0.03603481345635373, 0.04393490125949029, 0.08328815383720212, 0.07892008783528581, 0.011459360339358682, 0.024939130526036024, 0.13102501456160098, 0.09881315592792816, 0.04889496733085252, 0.01303342494793469, 0.01328852893493604, 0.049966461592703126, 0.10761494573671371, 0.05556732023251243, 0.07057211390929297, 0.010377116996096447, 0.031675489954068325, 0.14082721201702952, 0.022107119111751672, 0.07969739846885204, 23.980308026075363, 73.32715809345245, 71.56990438699722, 65.47779768705368, 61.59249097108841, 43.83980177342892, 33.93968380987644, 33.03411640226841, 45.20827554166317, 76.40302464365959, 70.67800104618073, 34.9745012819767, 25.94341568648815, 6.407636543735862, 0.36222167895175517, 0.047423262512893416, 0.4467169434064999, 2.4243138497695327, 6.4546870440244675, 10.673040188848972, 14.239297024905682, 15.330892000347376, 14.428653214126825, 10.404808782041073, 11.972486861050129, 13.358551785349846, 16.142443902790546, 16.008375696837902, 19.708689339458942, 22.67234031111002, 38.60025532543659, 44.90200437605381, 50.14326833188534, 60.54889976978302, 63.0004446208477, 64.32164892554283, 61.36587493121624, 60.619279593229294, 59.46067236363888, 62.98553802073002, 65.48955425620079, 60.78721918165684, 60.1251807063818, 54.49837423861027, 51.72768831253052, 58.441912829875946, 63.28560791909695, 66.03772044181824, 64.13384020328522, 62.67137087881565, 63.452677354216576, 63.57280790805817, 62.39968925714493, 62.04599663615227, 63.03667567670345, 62.30260066688061, 64.5115627348423, 61.03197164833546, 59.224518835544586, 38.66091527044773, 47.38553211092949, 49.263315349817276, 52.18036562204361, 62.033996880054474, 58.17866675555706, 58.816956505179405, 57.477418184280396, 61.24459683895111, 63.09781439602375, 59.99356336891651, 50.85329823195934, 46.433519795536995, 50.509135499596596, 55.941662192344666, 53.356250524520874, 54.996770694851875, 54.790760949254036, 56.41700528562069, 54.69444751739502, 60.2290291339159, 59.390889108181, 62.04555965960026, 62.52370320260525, 59.46528151631355, 58.23640465736389, 56.47447720170021, 56.88109718263149, 52.86608822643757, 49.86950822174549, 39.25285130739212, 31.681556180119514, 24.900909326970577, 17.395966239273548, 17.930240370333195, 12.095894739031792, 6.653938377276063, 10.124625116586685, 11.193083133548498, 14.986848961561918, 11.366622671484947, 7.137188846245408, 3.579193241894245, 1.2676820391789079, 0.22147261508507654, 0.08059855870669708, 0.1246193450060673, 0.3089225327130407, 3.4895570017397404, 21.801233254373074, 39.27063815295696, 46.86839506030083, 22.692847810685635, 12.290742583572865, 41.04406379163265, 59.344637989997864, 54.4743063300848, 40.53829953074455, 56.88266269862652, 55.98181463778019, 18.866154849529266, 1.316692759282887, 0.03560320634278469, 0.009020262314152205, 0.012437411714927293, 0.09577239135978743, 0.0344417860469548, 0.018741557323664892, 0.06979524114285596, 0.052727410511579365, 0.06741732577211224, 0.015534627746092156, 0.04310690193960909, 0.036083817467442714, 0.030143686017254367, 0.02790556343825301, 0.022509700829687063, 0.044006655807606876, 0.034642099126358517, 0.04268349184712861, 0.013606786906166235, 0.01248280053914641, 0.04854531929595396, 0.03703773698362056, 0.042226262085023336, 0.05014748625399079, 0.061332813202170655, 0.03277178308053408, 0.03668015910079703, 0.012010905011266004, 0.08785433616139926, 0.11931114859180525, 0.11708664256730117, 0.19634696800494567, 0.13333255948964506, 0.06815156957600266, 0.2368968928931281, 0.17146950995083898, 0.17357300879666582, 0.1709064276656136, 0.13135182671248913, 0.10753645619843155, 0.2672865043859929, 0.2813983237138018, 0.17125063575804234, 0.10670951814972796, 0.1504336457583122, 0.12344171249424107, 0.10222169919870794, 0.22968335106270388, 0.13374844420468435, 0.18785979686072096, 0.18804727820679545, 0.1867784876958467, 0.2770128840347752, 0.13884731044527143, 0.19628053094493225, 30.155601762235165, 85.36652326583862, 80.21979063749313, 75.22052809596062, 64.45088759064674, 45.51837310194969, 31.575422175228596, 33.57175715267658, 50.94325080513954, 84.52361449599266, 78.83852675557137, 46.006320118904114, 32.5430915504694, 7.218199074268341, 0.6833387666847557, 0.2260444822604768, 0.39660698384977877, 2.7311920328065753, 7.067798869684339, 15.305611956864595, 29.371785521507263, 20.608547553420067, 29.075654111802578, 15.97695518285036, 25.235251486301422, 27.31611292809248, 23.199332132935524, 34.48710523545742, 30.513322167098522, 32.782087326049805, 47.99550957977772, 49.240178391337395, 49.46532391011715, 63.427404910326004, 64.35970768332481, 64.24737811088562, 61.361505165696144, 61.177602633833885, 58.43021705746651, 63.8555583357811, 67.51354604959488, 64.16891992092133, 64.09207284450531, 56.77753373980522, 53.95638272166252, 61.51582628488541, 64.91889327764511, 68.42795178294182, 65.11944651603699, 61.400643065571785, 65.93421399593353, 66.0158260166645, 62.43834838271141, 65.49099817872047, 65.89941546320915, 64.79109093546867, 67.20350548624992, 63.02404895424843, 59.94203433394432, 44.832703694701195, 51.16080813109875, 53.052939400076866, 56.41631372272968, 64.01081040501595, 59.75578352808952, 60.58239497244358, 60.079636350274086, 63.0033590644598, 65.22036150097847, 63.586270585656166, 54.78758051991463, 49.1756122559309, 53.40356558561325, 58.15077245235443, 55.855490416288376, 58.61655905842781, 56.515427604317665, 58.033347353339195, 58.18346209824085, 63.661818131804466, 61.08469381928444, 63.93410012125969, 63.30842949450016, 60.98720625042915, 58.28509524464607, 56.25613711774349, 57.236849293112755, 55.2537053078413, 52.38188400864601, 42.50391885638237, 37.75231562554836, 35.474679842591286, 30.359092243015766, 26.71887617558241, 19.469368681311607, 17.40004152059555, 27.70996179431677, 11.921187713742256, 19.054930619895458, 18.301710337400436, 14.98716814443469, 4.513214472681284, 0.9636566124390811, 0.18615086824866012, 0.2087814742117189, 0.37330758408643305, 0.5137770215515047, 4.46167878806591, 26.1173190549016, 52.326216995716095, 57.38628767430782, 31.752625666558743, 32.36380957067013, 55.0791122764349, 70.3368553519249, 60.56186847388744, 50.38348004221916, 66.46211966872215, 64.91652980446815, 24.19333979487419, 1.8603555927984416, 0.1806109881727025, 0.1570004058885388, 0.08763036341406405, 0.18738792452495545, 0.24064947356237099, 0.061365141154965386, 0.06925801528268494, 0.15440029150340706, 0.13415803550742567, 0.2068326240987517, 0.1257383998017758, 0.2046909194905311, 0.09688607300631702, 0.20047529804287478, 0.15096655231900513, 0.10949736621114425, 0.13831758027663454, 0.08042206856771372, 0.19132515153614804, 0.18160036008339375, 0.08218316273996606, 0.1341789195430465, 0.09876042633550242, 0.11240133811952546, 0.10208711071754806, 0.084893894236302, 0.1399059544201009, 0.12557008070871234], [0.03132276571705006, 0.036096511903451756, 0.042669350223150104, 0.0256838089262601, 0.027007496100850403, 0.0895363544987049, 0.041190390911651775, 0.018579737588879652, 0.0361959856672911, 0.07273961557075381, 0.028900943034386728, 0.13094192370772362, 0.04247197604854591, 0.040732474662945606, 0.04433503017935436, 0.02239228935650317, 0.09395867891726084, 0.034040699756587856, 0.0444823316502152, 0.06411232694517821, 0.036979192664148286, 0.02042887830612017, 0.019706419807334896, 0.019635487187770195, 0.02063879477645969, 0.02847665349690942, 0.5966930848080665, 24.26472656428814, 63.72228428721428, 50.18372096121311, 59.36408534646034, 41.463264897465706, 26.995938308537006, 25.491745322942734, 36.5318401157856, 37.17959515750408, 61.25849649310112, 55.30604749917984, 25.51219392567873, 8.85998647660017, 0.9106334263924509, 0.07803537358995527, 0.0274170261764084, 0.25497724302113056, 1.7297631315886974, 4.890131447464228, 4.447022024542093, 12.5544379837811, 14.70159636810422, 14.573044516146183, 10.416688844561577, 9.96917450800538, 18.501655608415604, 35.75446642935276, 43.36918942630291, 40.183254182338715, 40.471681505441666, 55.61280123889446, 62.55757838487625, 62.38554261624813, 63.18213187158108, 61.8413320183754, 62.45192125439644, 62.15602733194828, 61.968028619885445, 57.56905406713486, 61.973200142383575, 62.11290344595909, 58.04043397307396, 52.91637472808361, 47.75567404925823, 49.636728912591934, 57.658147886395454, 62.63888642191887, 61.48303024470806, 61.942638382315636, 61.86372421681881, 63.648070469498634, 59.88341107964516, 57.7336460351944, 56.58615320920944, 60.24061091244221, 57.72030495107174, 61.49797864258289, 59.84349802136421, 61.57690040767193, 40.18014594912529, 38.46063181757927, 43.267997056245804, 53.11747133731842, 58.868151158094406, 58.479496613144875, 59.21632267534733, 57.214210107922554, 61.200447008013725, 61.60021975636482, 58.23188289999962, 46.09433479607105, 44.00632783770561, 51.03361375629902, 56.1459544301033, 53.269744366407394, 50.597005784511566, 49.44259352982044, 51.76084153354168, 50.51234632730484, 50.91966927051544, 55.10435812175274, 58.08709926903248, 58.64017479121685, 60.78921787440777, 59.28362086415291, 56.37991167604923, 57.07881577312946, 60.41966490447521, 55.833649188280106, 54.8413248360157, 47.86071941256523, 36.03547655045986, 34.8336086422205, 29.476515501737595, 24.539592415094376, 6.715425727888942, 6.702083218842745, 18.92369896173477, 17.99124799668789, 7.276388676837087, 9.103245623409748, 4.348384067416191, 1.1262348666787148, 0.2402297593653202, 0.05696028318197932, 0.08852546030539088, 0.036477597313933074, 0.4098177468404174, 8.200337123125792, 30.779437087476254, 47.09406495094299, 66.00405424833298, 80.31185209751129, 96.63660451769829, 72.62551054358482, 40.19759841263294, 37.86274529993534, 44.9265206605196, 52.91509039700031, 24.705670103430748, 2.999605117365718, 0.09394761349540204, 0.07484764151740819, 0.0522799622558523, 0.03410603843803983, 0.034797812841134146, 0.051982553995912895, 0.03808853274676949, 0.06367730224155821, 0.03431746888963971, 0.05788019749161322, 0.0221467071241932, 0.01837514417275088, 0.03137856037938036, 0.03156076134473551, 0.012641852063097758, 0.12486634659580886, 0.0456016758835176, 0.09846516288234852, 0.03437449180637486, 0.012114085802750196, 0.04583895904943347, 0.03412410973396618, 0.04430847242474556, 0.07702494694967754, 0.04135680639592465, 0.037701280089095235, 0.04838969834963791, 0.06381332306773402, 0.020665218944486696, 0.029390825438895263, 0.08026370909647085, 0.031121027714107186, 0.043209444484091364, 0.12961165368324146, 0.014588765170628903, 0.03528184155584313, 0.0654466194100678, 0.023860884575697128, 0.036734825698658824, 0.08769449239480309, 0.08435828625806607, 0.008937667771533597, 0.01589155253896024, 0.046747203086852096, 0.08720800717128441, 0.013422654501482612, 0.03577766670787241, 0.07615969181642868, 0.0495898698864039, 0.010833935793925775, 0.030997376634331886, 0.05059214403445367, 0.06226562603842467, 0.06005639712384436, 1.0106266639195383, 31.92176029086113, 73.11158046126366, 58.08943994343281, 66.22621312737465, 47.751038298010826, 30.243061669170856, 25.36491572856903, 28.426895923912525, 32.73574881255627, 67.27662116289139, 59.68826115131378, 31.030003242194653, 11.389403399080038, 1.0112505429424345, 0.20508201647317037, 0.09842025552643463, 0.8627334341872483, 4.3702048715204, 11.530073750764132, 11.542466785758734, 17.383784092962742, 14.979198072105646, 15.473494548350573, 14.072189591825008, 9.671108052134514, 11.999813094735146, 21.568522341549397, 31.381571777164936, 33.86610455811024, 39.94178093969822, 51.29910171031952, 60.85001461207867, 63.54169137775898, 62.78508737683296, 61.52286730706692, 63.28511394560337, 61.88795551657677, 60.442691668868065, 58.04214768111706, 61.93414583802223, 63.7542025744915, 60.60880735516548, 56.90668500959873, 49.975621327757835, 51.48347541689873, 59.263242557644844, 63.170595690608025, 63.05003196001053, 61.418847888708115, 60.63602149486542, 65.1173110306263, 61.83890774846077, 59.42840829491615, 57.85923309624195, 62.75452941656113, 59.90064695477486, 62.99125671386719, 62.663501501083374, 62.14126892387867, 42.09071382880211, 43.183953166007996, 48.20921391248703, 58.12711492180824, 61.25694617629051, 60.150054171681404, 59.64656598865986, 56.780752167105675, 61.62597097456455, 61.64504215121269, 58.20363141596317, 49.21941250562668, 46.73803925514221, 52.87668585777283, 58.01265746355057, 55.780277252197266, 53.484562039375305, 51.63837410509586, 53.26370649039745, 53.52539464831352, 53.370305970311165, 57.60200209915638, 61.05264253914356, 60.9417986869812, 61.71805903315544, 58.828473687171936, 56.22811742126942, 56.49722658097744, 60.092859640717506, 56.96002654731274, 54.635455682873726, 49.15732763707638, 39.32093605399132, 32.65675105154514, 23.910629265010357, 14.538431223481894, 8.582941442728043, 10.497719496488571, 10.871543437242508, 12.27761808782816, 12.032701279968023, 11.934354957193136, 7.4298230186104774, 4.016744513064623, 0.7243901013862342, 0.6150214013177902, 0.043186311741010286, 0.08153170550940558, 0.48071205674204975, 8.517221119254827, 29.75927922874689, 43.392364382743835, 37.15998440980911, 60.297505259513855, 91.1007271707058, 82.61376857757568, 47.8435405343771, 43.43412034213543, 51.89888432621956, 60.656977370381355, 31.78030338138342, 3.9040919579565525, 0.027410352413426153, 0.058986502190236934, 0.01875190471764654, 0.06901854649186134, 0.015333993687818293, 0.020741841981362086, 0.04042972665047273, 0.018649031917448156, 0.04685448053351138, 0.0571941339148907, 0.020711363831651397, 0.013128623013471952, 0.0380038759612944, 0.07457675761543214, 0.0481776110973442, 0.06594106045668013, 0.04250717982358765, 0.05384097712521907, 0.04917913938697893, 0.010610833214741433, 0.03768993636185769, 0.014959011514292797, 0.03313824818178546, 0.06687140194117092, 0.039962993687368, 0.010873376304516569, 0.03041625088371802, 0.009580441874277312, 0.12295945009100251, 0.23964172607520595, 0.19104840466752648, 0.11584809457417578, 0.19857830920955166, 0.20201900973916054, 0.2044602599926293, 0.2528082422213629, 0.14501206402201205, 0.10175367860938422, 0.09567804212565534, 0.24078194692265242, 0.15263720095390454, 0.17740823503118008, 0.10317807522369549, 0.10868038036278449, 0.2768575376830995, 0.05520882208656985, 0.11753235419746488, 0.20318919850979, 0.13716860208660364, 0.13416073692496866, 0.13265957997646183, 0.13104520097840577, 0.14785895735258237, 0.16170789313036948, 1.9400267489254475, 41.32094353437424, 82.70062431693077, 67.40759253501892, 73.58678296208382, 53.820589408278465, 38.72448205947876, 35.44610157608986, 50.128122344613075, 47.680745869874954, 72.04236343502998, 67.73407101631165, 33.885354325175285, 12.17205310240388, 1.7450523236766458, 0.32270964758936316, 0.12974285054951906, 0.9299302159342915, 3.221512734889984, 11.946716643869877, 17.45691116899252, 30.076746493577957, 24.95317742228508, 23.491205871105194, 21.2624354660511, 21.587720811367035, 28.303465247154236, 47.27772809565067, 48.69241498410702, 44.81327533721924, 43.48895139992237, 58.89339700341225, 65.05345925688744, 65.35438030958176, 65.07336258888245, 61.84907600283623, 62.0223543047905, 63.27958904206753, 62.50172898173332, 58.228330090641975, 63.5502865165472, 66.79337829351425, 62.979359552264214, 59.47112180292606, 52.340907007455826, 53.789066299796104, 62.55675382912159, 66.26703053712845, 64.6392434835434, 62.41606257855892, 62.59092919528484, 67.03619286417961, 64.68987956643105, 62.13586561381817, 60.820634588599205, 66.91293507814407, 60.898652002215385, 64.5228785276413, 63.95107761025429, 64.8273865878582, 45.45304700732231, 48.15172679722309, 52.00841344892979, 61.032150238752365, 62.6277644187212, 61.51985786855221, 60.48520378768444, 58.289077430963516, 62.469711899757385, 65.80010399222374, 61.872836127877235, 51.79771475493908, 50.20371928811073, 55.77896252274513, 60.90697355568409, 59.27607446908951, 56.229135766625404, 52.00168780982494, 55.64745157957077, 55.089158937335014, 56.45022310316563, 60.19154414534569, 61.8239289522171, 63.125712499022484, 63.26574258506298, 60.50294503569603, 56.84319041669369, 57.717401906847954, 62.18166455626488, 58.19882467389107, 54.88670580089092, 51.141493767499924, 39.867772310972214, 39.925552010536194, 33.34959827363491, 28.765930831432343, 10.476338043808937, 18.290177956223488, 35.64098931849003, 27.564420104026794, 13.60680766403675, 20.19903212785721, 12.447372078895569, 3.883956838399172, 1.07040090020746, 0.5436271510552615, 0.32271790027152747, 0.21534578525461257, 0.8095995197072625, 10.664279758930206, 39.2474327981472, 60.75926408171654, 78.75870063900948, 88.24875220656395, 98.49722787737846, 76.01851567626, 49.84690323472023, 51.757398918271065, 62.68263727426529, 69.60338830947876, 40.21419212222099, 5.444436203688383, 0.20361939183203503, 0.08127246590447612, 0.1920671804691665, 0.23588179814396426, 0.12161038146587089, 0.12524343183031306, 0.1872753704083152, 0.1635033413185738, 0.07986560623976402, 0.09663187258411199, 0.09605546874809079, 0.15149766288232058, 0.15273841505404562, 0.1716761980787851, 0.16789911169325933, 0.2713533549103886, 0.1650358020560816, 0.16411544987931848, 0.174268267583102, 0.17158311791718006, 0.1568099856376648, 0.17392965528415516, 0.12788513617124408, 0.15580778941512108, 0.30147944460622966, 0.1312986740958877, 0.07799034749041311, 0.11778230211348273], [0.040744857396930456, 0.0008192499785764085, 0.07236952136736363, 0.04026637252536602, 0.0601950451527955, 0.014179645131662255, 0.026863845996558666, 0.057252989936387166, 0.022509209156851284, 0.026690376398619264, 0.042030127297039144, 0.008710305264685303, 0.033984790061367676, 0.012493640533648431, 0.029611814752570353, 0.11138567933812737, 0.10607397256535478, 0.048517292088945396, 0.027042603396694176, 0.08189894244424067, 0.009650756655901205, 0.0314650205837097, 0.08427253851550631, 0.023665655207878444, 0.056988447686308064, 0.038034615718061104, 4.286794122308493, 47.905792593955994, 60.61704531311989, 59.85203616321087, 46.38400085270405, 52.80933067202568, 48.10409255325794, 63.38669389486313, 86.04434609413147, 57.42355227470398, 56.21779717504978, 38.793653547763824, 11.87927121296525, 2.4299829080700874, 0.0915382087987382, 0.1268907918711193, 0.28088618244510144, 0.9183682675939053, 5.783922811970115, 12.920986264944077, 10.402488056570292, 9.197686705738306, 14.598912578076124, 11.349661331623793, 14.250828456133604, 13.0358493514359, 24.666296616196632, 43.12625706195831, 51.0005859285593, 59.031386598944664, 59.93560887873173, 64.63820993900299, 63.05665500462055, 61.10424377024174, 60.93288816511631, 61.230750381946564, 61.08557537198067, 58.86420696973801, 59.54698093235493, 58.03330555558205, 60.861888974905014, 59.8092732578516, 53.89579117298126, 51.31809689104557, 48.16111609339714, 52.33337201178074, 59.48351673781872, 63.6557574570179, 56.99800930917263, 58.75774808228016, 59.852264150977135, 61.26238748431206, 58.11921514570713, 56.12059459090233, 54.94301877915859, 56.997002363204956, 58.565402403473854, 63.17351013422012, 58.54546867311001, 63.03865157067776, 44.906313344836235, 37.162746861577034, 44.547133818268776, 54.16467234492302, 59.57186959683895, 57.12881729006767, 58.93570013344288, 57.250045984983444, 58.44504006206989, 61.607477366924286, 56.13543279469013, 43.5420573502779, 45.250726863741875, 53.82400922477245, 55.845303162932396, 54.44196626543999, 51.39650568366051, 49.7048706561327, 49.39262621104717, 48.11643049120903, 50.4132704436779, 51.974051892757416, 56.11601583659649, 55.784932002425194, 58.402714133262634, 58.29095833003521, 57.50936307013035, 55.739072263240814, 54.63049314916134, 56.30502909421921, 56.52760595083237, 54.81751151382923, 54.64088939130306, 42.50415824353695, 43.28427918255329, 24.649879597127438, 10.827678591012955, 9.052263759076595, 10.803045462816954, 13.511363435536623, 11.377149056643248, 3.4887495450675488, 2.9369870899245143, 3.239997080527246, 1.0502668493427336, 0.2425223425962031, 0.06599557120352983, 0.0981723410950508, 0.04293923593650106, 1.5823863772675395, 14.323744643479586, 38.37001048028469, 43.82441259920597, 39.86790910363197, 39.30116571485996, 24.744583815336227, 24.785785004496574, 40.05137465894222, 42.536912485957146, 56.0353347659111, 40.02179704606533, 7.432407354936004, 0.41756704507861286, 0.06181291966640856, 0.07273097697179765, 0.025312358447990846, 0.07705689640715718, 0.07722581663983874, 0.015365555373136885, 0.021536665444727987, 0.023702450889686588, 0.06725092142005451, 0.08880718698492274, 0.09626629806007259, 0.016335097097908147, 0.03753250828594901, 0.03140262822853401, 0.03180768500897102, 0.024722375164856203, 0.038829129334772006, 0.0337966185179539, 0.018938916655315552, 0.04764772507769521, 0.04201678719255142, 0.0022152451811052742, 0.028590851470653433, 0.03308011204353534, 0.02475226701790234, 0.05284789818688296, 0.08144093342707492, 0.06817708461312577, 0.02418328836938599, 0.09242301210178994, 0.02462737655150704, 0.0647524738451466, 0.004826371414310415, 0.048652255354681984, 0.01754595370584866, 0.033769801011658274, 0.12584621901623905, 0.044300434965407476, 0.03364956195582636, 0.04490259874728508, 0.041570927132852376, 0.014783205078856554, 0.07401674782158807, 0.023981774866115302, 0.017435036024835426, 0.007851880673115375, 0.09176057850709185, 0.02697950414585648, 0.01899680788483238, 0.07009045264567249, 0.041387520177522674, 0.043749564720201306, 0.04775821973453276, 7.402839716523886, 55.646752417087555, 68.8095273077488, 64.96215775609016, 56.617197543382645, 57.812305614352226, 51.76152929663658, 47.5195737183094, 59.72359545528889, 57.792402282357216, 62.19872944056988, 49.48330834507942, 16.778556369245052, 3.009478412568569, 0.08893933380022645, 0.148122894752305, 0.39058216963894665, 2.36088955309242, 8.674900308251381, 11.716171614825726, 11.736115794628859, 12.429415192455053, 14.970781523734331, 16.83402009308338, 14.704000689089298, 12.512770369648933, 19.866876751184464, 34.503470957279205, 42.97744184732437, 52.30568669736385, 59.125302359461784, 65.92717677354813, 65.02846419811249, 63.16194735467434, 61.71351447701454, 61.448972672224045, 61.486488059163094, 59.062807112932205, 60.46886086463928, 58.93723905086517, 63.562989234924316, 62.96323701739311, 56.428628861904144, 51.63894787430763, 49.2208868265152, 54.4363159686327, 60.19473597407341, 64.75816190242767, 59.26143765449524, 60.319741666316986, 60.50231046974659, 60.974412336945534, 59.06796343624592, 58.93715925514698, 56.82566575706005, 58.9431781321764, 60.75449913740158, 63.91621068120003, 60.180205553770065, 61.6258379817009, 46.63248851895332, 41.97463005781174, 47.955623120069504, 59.920136108994484, 62.032514959573746, 58.50144803524017, 59.267578125, 58.02202396094799, 59.92990158498287, 62.65420340001583, 59.03637193143368, 45.92691197991371, 47.298326790332794, 56.06107458472252, 57.58424565196037, 56.95552758872509, 54.47170726954937, 51.559577733278275, 51.3528498262167, 50.30434928834438, 52.21753142774105, 54.70127955079079, 58.04406277835369, 59.5325531065464, 61.463430896401405, 60.16386263072491, 56.41689129173756, 55.84009364247322, 55.68207532167435, 58.30773442983627, 56.63039803504944, 56.05036675930023, 52.61590965092182, 44.888116121292114, 40.574078410863876, 26.526530496776104, 14.247375391423702, 14.157773349434137, 12.426868379116058, 19.09069050103426, 13.464027475565672, 9.858492147177458, 9.294717349112034, 6.024912530556321, 3.830778216943145, 0.9139362210407853, 0.2381616015918553, 0.02637460369442124, 0.054237699587247334, 1.526133008301258, 14.427078198641539, 37.22527250647545, 48.95975723862648, 53.95329348742962, 62.26387694478035, 35.045242086052895, 27.611165195703506, 46.18785917758942, 49.69724826514721, 61.88047371804714, 50.3336913138628, 9.759041983634233, 0.49508184660226107, 0.08676301542436704, 0.02019534669670975, 0.05340498762961943, 0.07721172325545922, 0.016173609474208206, 0.05780173392849974, 0.015421568969031796, 0.018277087910973933, 0.06953952673939057, 0.09727896598633379, 0.05012492125388235, 0.05907746352022514, 0.041573799244361, 0.04814597705262713, 0.03760333886020817, 0.021943043248029426, 0.05499967373907566, 0.05759027750173118, 0.012737396154989256, 0.022932021820452064, 0.0967080688860733, 0.06255361644434743, 0.05774703764473088, 0.0248566278241924, 0.032221358123933896, 0.0708657297946047, 0.023552060229121707, 0.15462473180377856, 0.13927953725215048, 0.1946227066218853, 0.21271481236908585, 0.1397779191029258, 0.10964859364321455, 0.1391315381624736, 0.1588985524722375, 0.11020915262633935, 0.19425509119173512, 0.1358526703552343, 0.13970784551929682, 0.12335074003203772, 0.10445651365444064, 0.140792494348716, 0.17737440794007853, 0.15904202446108684, 0.12298830479267053, 0.14708482311107218, 0.23889503645477816, 0.10427617176901549, 0.09587171298335306, 0.16811526962555945, 0.13249133509816602, 0.12408437527483329, 0.28715174936223775, 13.465147465467453, 67.62728914618492, 77.88039296865463, 76.72981470823288, 62.87306785583496, 64.81507524847984, 60.2691625803709, 82.09487602114677, 99.98408049345016, 68.01753580570221, 68.51597025990486, 49.87040497362614, 16.45363960415125, 3.4104428719729185, 0.3725977643625811, 0.3134669701103121, 0.38236965250689536, 2.7599192038178444, 11.290426310151815, 22.159590125083923, 23.40562306344509, 21.57617513090372, 24.616458490490913, 19.23006322234869, 27.081948593258858, 18.864832520484924, 30.732122026383877, 48.170209005475044, 56.74108229577541, 64.20818701386452, 64.96405765414238, 68.34198519587517, 66.40965968370438, 62.582877427339554, 62.96170949935913, 61.690149530768394, 61.45012401044369, 58.76894608139992, 58.745448142290115, 59.21262927353382, 65.57944223284721, 66.163569688797, 59.39943864941597, 54.47552606463432, 52.1667243540287, 58.23234647512436, 64.59292396903038, 65.74825197458267, 59.68955308198929, 59.17264401912689, 62.25040286779404, 63.92856761813164, 61.02564498782158, 60.29280871152878, 59.119044095277786, 61.01875215768814, 64.91513907909393, 65.08638828992844, 62.19167701900005, 63.34004379808903, 47.74448744952679, 47.303403317928314, 54.75761532783508, 60.79622469842434, 63.75416457653046, 60.8286901563406, 60.73435641825199, 59.366498216986656, 62.05698944628239, 65.62053322792053, 61.80295027792454, 48.11851277947426, 50.50677202641964, 58.810181468725204, 60.599805638194084, 60.756972804665565, 56.92040607333183, 53.51730488240719, 53.49674418568611, 52.98587679862976, 55.99739000201225, 57.53871649503708, 60.705941542983055, 60.93998618423939, 64.95339542627335, 61.43411926925182, 58.43820422887802, 55.7128194719553, 55.813137888908386, 56.93510368466377, 57.84871906042099, 56.05185627937317, 56.84910669922829, 47.27222979068756, 47.49763749539852, 29.528181329369545, 19.456151090562344, 18.006568774580956, 18.830881342291832, 26.205546520650387, 23.75182818621397, 12.52904299646616, 12.811648081988096, 10.808549467474222, 2.5815073773264885, 0.4813551128609106, 0.32540901680476964, 0.27781743148807436, 0.26371466636192054, 2.1472424548119307, 18.785853758454323, 49.53378103673458, 55.9947719424963, 48.24522078037262, 48.255362436175346, 31.75480294972658, 37.79472514986992, 54.14992153644562, 58.63319456577301, 69.38815265893936, 60.399704575538635, 14.077222421765327, 0.8273778157308698, 0.17594293865840882, 0.11879666213644668, 0.09071855864021927, 0.15090320259332657, 0.15485191805055365, 0.1552975332015194, 0.07066189151373692, 0.14790844375966117, 0.09962885786080733, 0.15082935889950022, 0.22944240539800376, 0.10354615078540519, 0.08349421113962308, 0.20028563478263095, 0.13393076020292938, 0.11104576828074642, 0.13167308759875596, 0.21624399174470454, 0.07236293851747178, 0.10670012256014161, 0.15399298601550981, 0.11145938944537193, 0.1336104641086422, 0.13247149006929249, 0.12931132136145607, 0.2011636400129646, 0.13553817785577849], [0.04966056687408127, 0.05704115501430351, 0.03249777844757773, 0.051873777410946786, 0.006836255752205034, 0.03668213321361691, 0.05991207537590526, 0.08490121181239374, 0.048161105733015575, 0.026717138243839145, 0.02111070050887065, 0.05121093192428816, 0.013805175040033646, 0.061337069419096224, 0.047929904467309825, 0.03543656821420882, 0.0309519145230297, 0.026797629725479055, 0.04097069664567243, 0.013674583024112508, 0.02390186597040156, 0.0318004527798621, 0.03839505458017811, 0.04937808320391923, 0.07869379958719946, 0.05148413503775373, 14.109260402619839, 59.3299175798893, 59.56066779792309, 51.91509425640106, 42.705912217497826, 34.04251389205456, 26.42617028206587, 66.11540347337723, 66.37194290757179, 64.0587030351162, 43.39579939842224, 16.734129153192043, 4.050615895539522, 0.4417248722165823, 0.0653447670629248, 0.2358704581274651, 0.47716254252009094, 0.7366799481678754, 9.499210976064205, 11.301328875124454, 9.016439281404018, 11.890542358160019, 14.300561137497425, 25.71883823722601, 35.10935604572296, 30.606590062379837, 38.92782434821129, 52.888689413666725, 58.28832507133484, 61.33452661335468, 63.9794696867466, 56.82495519518852, 60.99493123590946, 61.838664561510086, 62.54944682121277, 59.127593636512756, 60.569441467523575, 59.70899663865566, 58.2894080132246, 59.783088862895966, 59.55681100487709, 56.88620410859585, 52.65441298484802, 47.02753812074661, 48.08803841471672, 51.27425864338875, 58.66789050400257, 60.69989986717701, 60.63798598945141, 58.284692466259, 60.730450227856636, 61.77848719060421, 58.97051386535168, 53.7748246639967, 53.34434576332569, 54.716189950704575, 55.15095882117748, 60.52976779639721, 58.791315481066704, 60.44562131166458, 54.74919877946377, 35.59324488043785, 42.742055878043175, 54.99218434095383, 54.50117468833923, 56.00613713264465, 57.5406201928854, 56.19168117642403, 59.51511204242706, 58.95773135125637, 53.74658837914467, 42.243674620985985, 47.176509127020836, 55.47327272593975, 58.41542825102806, 56.27136290073395, 53.77313755452633, 52.14802175760269, 51.23492315411568, 46.622191071510315, 46.48924760520458, 46.23580500483513, 50.70296309888363, 55.55501773953438, 55.094801634550095, 58.61905172467232, 60.13355165719986, 57.43992179632187, 56.531120762228966, 54.51016500592232, 57.8141675144434, 57.46788829565048, 59.85348008573055, 58.069893792271614, 52.524912133812904, 37.27639876306057, 25.28251525014639, 25.98656617105007, 10.401130579411983, 12.195921521633863, 14.153407383710146, 14.754485730081797, 8.296396918594837, 3.315794225782156, 2.9587520845234394, 1.9954643491655588, 0.1323845103615895, 0.07668994890991598, 0.043666136189131066, 0.016981997541734017, 3.7281868094578385, 17.04989030957222, 32.65559211373329, 32.77630403637886, 16.455237418413162, 19.887399449944496, 28.69488414376974, 27.19364359974861, 40.76346404850483, 49.62814897298813, 54.04832638800144, 23.811350092291832, 1.044564542826265, 0.017121255987149198, 0.029790735425194725, 0.05241517414106056, 0.017580858766450547, 0.024385250872001052, 0.02858967516658595, 0.05369150858314242, 0.035078485670965165, 0.05941740426351316, 0.012500539723987458, 0.032428873746539466, 0.012090935433661798, 0.03464144974714145, 0.005530343942155014, 0.04348926384409424, 0.05751874930865597, 0.09849293404840864, 0.02669431720278226, 0.03271696434239857, 0.037749972398160025, 0.024838118661136832, 0.01875522211776115, 0.09233681164914742, 0.04095871096069459, 0.049959218231379054, 0.038869420532137156, 0.02888904640713008, 0.051710831467062235, 0.10474270806298591, 0.022261365229496732, 0.0798438761557918, 0.012776563926308881, 0.07487648879759945, 0.08472570872982033, 0.07359926006756723, 0.08119432517560199, 0.04534912673989311, 0.0037595109370158752, 0.026898699106823187, 0.03764314024010673, 0.04339099607022945, 0.09579205827321857, 0.04462427110411227, 0.030525437505275477, 0.03308858365926426, 0.062195467107812874, 0.0438571278937161, 0.06625161957344972, 0.0642082495323848, 0.03666353128210176, 0.04289405027520843, 0.027560086273297202, 0.33082716981880367, 19.831266961991787, 70.58454886078835, 67.96279594302177, 59.927279725670815, 50.005514323711395, 45.10054752230644, 36.96332976222038, 69.00140941143036, 70.84215983748436, 71.30150198936462, 53.98519657552242, 19.83169823884964, 4.495412427932024, 0.34273377154022455, 0.0872293216525577, 0.7611796085257083, 1.6433734609745443, 4.8535555601119995, 12.327861841768026, 14.657783769071102, 9.490237757563591, 15.443830490112305, 12.918794732540846, 13.602239359170198, 16.97906021028757, 26.67124193161726, 33.08643579483032, 46.16453982889652, 55.991602912545204, 64.22764956951141, 63.65676060318947, 60.23523420095444, 60.52409090101719, 63.10384847223759, 62.17478312551975, 59.248005375266075, 60.202217772603035, 60.48263892531395, 58.69116045534611, 60.962021201848984, 59.762995541095734, 60.13410642743111, 54.18221980333328, 50.596679002046585, 49.75510396063328, 53.043496906757355, 61.7338851839304, 61.13390877842903, 59.96725358068943, 58.65788944065571, 62.19942860305309, 63.59474793076515, 60.68084008991718, 55.92712417244911, 54.746417328715324, 56.17968522012234, 57.898177206516266, 60.447639003396034, 60.54825760424137, 62.2175270318985, 55.50748988986015, 40.3654658049345, 47.40711495280266, 58.73961925506592, 55.487939938902855, 55.6170342117548, 60.08169203996658, 57.160933166742325, 60.379630252718925, 61.32160730659962, 55.86890369653702, 45.190933272242546, 50.00016041100025, 57.512653693556786, 59.37260448932648, 58.60186904668808, 54.538264498114586, 54.542372077703476, 54.07096937298775, 49.105650410056114, 48.92758436501026, 49.884380623698235, 52.732441797852516, 58.01276385784149, 57.69147589802742, 61.39218471944332, 59.60144720971584, 56.47229231894016, 56.236408576369286, 54.39808242022991, 57.456648498773575, 58.15159320831299, 62.12068922817707, 59.01621401309967, 51.61202631890774, 37.559745758771896, 25.05465477705002, 17.749922946095467, 7.909207670018077, 15.194376725703478, 13.936671763658524, 9.666529297828674, 11.157644335180521, 9.99088179320097, 7.109698746353388, 3.4983148192986846, 0.7475852442439646, 0.04978391181793995, 0.06414466231944971, 0.05007627718441654, 4.341401942074299, 19.358498230576515, 37.35326483845711, 40.00430278480053, 23.32876268774271, 24.45334654301405, 36.05783835053444, 34.83350604772568, 46.17593541741371, 57.30185620486736, 61.6844118386507, 30.480488128960133, 1.7813110467977822, 0.029523165212594904, 0.06456047281972133, 0.03379120826139115, 0.05910496380238328, 0.01337218289336306, 0.02851975372323068, 0.07822166749974713, 0.019726841856027022, 0.026095352077391, 0.04409390268847346, 0.03936776156479027, 0.03855480928905308, 0.0518002083117608, 0.018830718945537228, 0.027562296018004417, 0.08331452234415337, 0.11823383218143135, 0.020170312200207263, 0.015135445992200403, 0.03801747952820733, 0.032284748667734675, 0.023909513802209403, 0.014891298887960147, 0.0912430789321661, 0.04301970329834148, 0.032405002566520125, 0.00739057280952693, 0.1642486357013695, 0.18285129452124238, 0.09640267511713319, 0.15551833697827533, 0.20477194717386737, 0.22006841230904683, 0.22566462139366195, 0.17152356798760593, 0.1139567609061487, 0.12464077823096886, 0.14139621664071456, 0.12975537800230086, 0.11551974617759697, 0.18761052429908887, 0.18451713403919712, 0.13842805637978017, 0.11644800964859314, 0.1616965382709168, 0.24960777489468455, 0.136919759970624, 0.10692802126868628, 0.12258335191290826, 0.22068391990615055, 0.12885987292975187, 0.20437656057765707, 0.9466353070456535, 28.45128681510687, 80.56397616863251, 76.33377715945244, 68.2265093922615, 56.07210919260979, 47.1628450602293, 35.78539676964283, 81.58651649951935, 74.33026626706123, 73.12481135129929, 53.19652609527111, 23.72234746813774, 5.475176079198718, 1.0139911458827555, 0.2577327482867986, 0.9221718634944409, 1.9675522344186902, 5.710977176204324, 18.622196540236473, 24.142798706889153, 17.41263784468174, 19.2181508615613, 27.0782969892025, 37.2548159211874, 44.522298350930214, 35.00345192849636, 42.43527173995972, 54.978368282318115, 64.42219153046608, 67.08856165409088, 66.93823412060738, 60.78179307281971, 65.2992832660675, 65.46805500984192, 63.8215197622776, 58.65422643721104, 60.914356559515, 60.81511348485947, 59.74370397627354, 62.04877428710461, 62.77777276933193, 61.60082012414932, 57.03380338847637, 51.75264537334442, 51.975355222821236, 54.74801704287529, 62.98698954284191, 62.54255399107933, 62.06270433962345, 58.48045036196709, 62.4799295514822, 64.87619116902351, 63.859456926584244, 57.63313762843609, 58.1865893304348, 59.28171716630459, 60.019550174474716, 64.02179181575775, 63.38365025818348, 62.61411555111408, 57.25533150136471, 45.77146992087364, 51.714719608426094, 59.29584480822086, 58.24549376964569, 56.37333042919636, 60.18264502286911, 58.54320019483566, 62.457981929183006, 62.88637474179268, 58.147679418325424, 46.9663842022419, 52.74573728442192, 60.35533435642719, 62.52980187535286, 60.45740827918053, 57.98236168920994, 56.52988202869892, 57.49210059642792, 51.962834894657135, 51.42538793385029, 51.26070477068424, 56.014508083462715, 60.090826749801636, 60.5154387652874, 64.60564568638802, 63.182447254657745, 56.29793867468834, 58.04684042930603, 54.01547335088253, 57.92748883366585, 59.58090931177139, 61.26777559518814, 61.21600717306137, 55.06020829081535, 39.84444156289101, 32.4609399586916, 31.17030691355467, 16.086533702909946, 18.683633543550968, 25.588313341140747, 27.02743861824274, 17.464512661099434, 15.740147139877081, 10.972071792930365, 4.912314182147384, 0.45892889436800033, 0.18059249385260046, 0.23750825930619612, 0.17894072545459494, 5.147410416975617, 21.76697239279747, 44.444900304079056, 47.06261783838272, 25.52686493843794, 32.195562198758125, 39.98547859489918, 40.48254132270813, 55.99547490477562, 63.89319911599159, 71.16695880889893, 38.39161232113838, 3.034316967241466, 0.12145645261625759, 0.18936417473014444, 0.1618106954265386, 0.1024711572972592, 0.09022137164720334, 0.12065978677128442, 0.27140349440742284, 0.14039191271876916, 0.1344206221983768, 0.10854589578229934, 0.07663917858735658, 0.15571433817967772, 0.1890456152614206, 0.15035714517580345, 0.09458976419409737, 0.17039897677022964, 0.21702372177969664, 0.11811731499619782, 0.1382294576615095, 0.19139645708492026, 0.09456456828047521, 0.11562683066586033, 0.23962030769325793, 0.20581122109433636, 0.15796936873812228, 0.2203598982305266, 0.10700082595576532], [0.056965519033838063, 0.07787377835484222, 0.07553303716122173, 0.05361525290936697, 0.04335952900873963, 0.050436623278073967, 0.05127863434609026, 0.07687344492296688, 0.06722861988237128, 0.019724678495549597, 0.015173623924056301, 0.03165826099575497, 0.07940966781461611, 0.015582720770908054, 0.0576458235445898, 0.04505959266680293, 0.036723823359352536, 0.05485962676175404, 0.01733298700855812, 0.04681969236116856, 0.04508186080784071, 0.07076729132677428, 0.07980400798260234, 0.10311817648471333, 0.057089951224043034, 0.7800493366084993, 34.32714901864529, 63.296566531062126, 57.4337737262249, 46.0337470471859, 43.02563086152077, 30.11920351535082, 34.77008745074272, 62.4433109164238, 64.69587564468384, 46.80630259215832, 19.67672735452652, 8.898172527551651, 1.0658927983604372, 0.06190093467012048, 0.07081795032718219, 0.5231265979819, 1.127185884397477, 3.1587778637185693, 11.185915768146515, 8.860791083425283, 7.742331549525261, 12.808835282921791, 17.92056418955326, 33.45629274845123, 31.449622325599194, 45.675867050886154, 50.77738970518112, 59.85665671527386, 58.892614245414734, 62.57068008184433, 57.48191714286804, 58.42101015150547, 55.919820964336395, 60.52088387310505, 59.565869718790054, 61.927743181586266, 57.600531578063965, 58.42015899717808, 57.75395214557648, 59.86563563346863, 55.61761558055878, 54.41003277897835, 48.14261108636856, 46.07730031013489, 46.53553292155266, 55.459582060575485, 57.83299930393696, 60.76795041561127, 59.475761353969574, 58.71217332780361, 58.92572946846485, 60.13476379215717, 57.67371945083141, 50.60430519282818, 50.147235319018364, 49.811576530337334, 54.68226157128811, 57.844546884298325, 57.560546323657036, 58.78463923931122, 58.4784060716629, 37.19151511788368, 42.01111190021038, 56.72234170138836, 54.394457414746284, 59.024603962898254, 58.50923761725426, 58.662422597408295, 59.2365375906229, 60.80873742699623, 50.33621057868004, 41.601668670773506, 45.03634996712208, 57.55430705845356, 56.86436668038368, 58.97166520357132, 57.84502945840359, 55.27509056031704, 51.12546622753143, 49.06534977257252, 45.5628003180027, 47.58964575827122, 44.63977284729481, 52.04276740550995, 54.200204238295555, 55.87850198149681, 57.891531363129616, 55.90523734688759, 52.9908013343811, 55.397668182849884, 53.88860955834389, 57.58594796061516, 58.35628442466259, 58.048208355903625, 56.011779829859734, 47.88352578878403, 39.493697583675385, 36.504268795251846, 22.085294611752033, 22.532568611204624, 12.173723112791777, 6.670774798840284, 9.060564413666725, 5.816313698887825, 6.702673612162471, 3.3484845841303468, 1.2356809875927866, 0.12504279962740839, 0.06883493915665895, 0.0727340643061325, 0.44452125497628003, 7.854953706264496, 27.28935096412897, 51.17356024682522, 48.81630353629589, 21.493521966040134, 10.922471154481173, 18.39125633239746, 37.13366322219372, 49.04964901506901, 52.01730877161026, 44.74424824118614, 6.744783902540803, 0.03281396675447468, 0.025982092920457944, 0.02224034018581733, 0.08257206296548247, 0.012519932042778237, 0.06455787530285306, 0.020928633130097296, 0.07088489946909249, 0.019474044092930853, 0.030661766322737094, 0.019198833469999954, 0.07369989529252052, 0.022769166789657902, 0.04986978572560474, 0.020243055660102982, 0.048798354546306655, 0.03425126560614444, 0.0548160144535359, 0.008086770412774058, 0.0636057072551921, 0.030602461301896255, 0.029835052773705684, 0.008170630317181349, 0.018886585967266, 0.012180891153548146, 0.014098076608206611, 0.010945269077637931, 0.05524642299860716, 0.014932771027815761, 0.10758568285382353, 0.06354301804094575, 0.04270220139005687, 0.018234560993732885, 0.08657465092255734, 0.03479453254840337, 0.022691011217830237, 0.01137568875492434, 0.03326979756820947, 0.007171934712459915, 0.03292046865681186, 0.007414001947836368, 0.07750894597847946, 0.09418987276148982, 0.04935184457281139, 0.054861534081283025, 0.0007829893968391843, 0.04199809249257669, 0.025470758737355936, 0.08894263635738753, 0.08609353884821758, 0.004303155910747591, 0.14546437334502116, 1.6999350883997977, 41.81654714047909, 71.15270957350731, 64.18674096465111, 53.80369931459427, 50.08892364799976, 39.898421466350555, 35.48256441950798, 62.78865538537502, 68.54604184627533, 54.292584881186485, 26.24992433935404, 9.646313432604074, 0.9628745075315237, 0.05862804115167819, 0.2723293681629002, 1.3109830906614661, 4.2123219184577465, 9.5200015604496, 11.343932189047337, 16.629142686724663, 10.281085520982742, 12.679375279694796, 21.02170128375292, 24.244125969707966, 29.208952859044075, 42.44270034134388, 51.28043331205845, 57.1495071798563, 60.310169979929924, 64.21036049723625, 60.285946279764175, 59.27293963730335, 59.60101403295994, 63.19768063724041, 61.90131939947605, 61.72567382454872, 57.878186479210854, 56.94393441081047, 59.93039555847645, 63.57851900160313, 59.23245280981064, 56.78417198359966, 49.3324526399374, 47.5327780097723, 49.143177196383476, 55.71430519223213, 60.197646617889404, 62.66149140894413, 58.73884029686451, 58.3393145352602, 58.79232622683048, 62.60713912546635, 59.90759298205376, 52.20061473548412, 51.91720314323902, 52.016670405864716, 57.298565581440926, 59.02813017368317, 58.81161019206047, 61.30743786692619, 58.40413145720959, 41.897296607494354, 46.30795173346996, 59.14894849061966, 56.27456232905388, 58.630120530724525, 58.53827565908432, 59.828621819615364, 61.03486329317093, 61.70072056353092, 53.30511286854744, 43.48786845803261, 47.71477684378624, 57.67033003270626, 61.09797790646553, 60.45713469386101, 58.77762861549854, 57.018721997737885, 52.4250078946352, 52.107686921954155, 48.93117517232895, 49.027051627635956, 47.16107055544853, 54.49165239930153, 56.60439223051071, 58.43267172574997, 60.61219297349453, 56.960007548332214, 53.02737437188625, 55.83692081272602, 54.55539017915726, 57.12341398000717, 57.70705886185169, 60.30732773244381, 56.66299268603325, 49.52671721577644, 39.60917718708515, 32.634457647800446, 19.118685498833656, 12.74249179288745, 9.034190028905869, 7.9063397739082575, 12.663808465003967, 8.483328837901354, 8.66040313616395, 6.057546604424715, 3.6970016453415155, 0.6681439757812768, 0.06477549526607618, 0.0894343463005498, 0.4528791439952329, 7.716617379337549, 27.549103125929832, 49.24693442881107, 40.16734063625336, 27.405250445008278, 18.97279802709818, 26.754580959677696, 44.35188889503479, 56.00030064582825, 57.567363157868385, 53.252911269664764, 8.936792705208063, 0.05336364258255344, 0.048492745554540306, 0.04417203970660921, 0.06782429729355499, 0.021071342562208883, 0.04341323823609855, 0.04474146364373155, 0.08054059697315097, 0.03296866001619492, 0.04172945729806088, 0.08593313847086392, 0.03490255956421606, 0.02028631544817472, 0.026534638564044144, 0.03977811356890015, 0.038356949007720686, 0.04115461568289902, 0.03153574354655575, 0.016904569274629466, 0.015252204375428846, 0.020647168057621457, 0.002258964173051936, 0.03964781099057291, 0.03336332301842049, 0.025927363240043633, 0.0029124996490281774, 0.008928245279093971, 0.1019763080694247, 0.18590972962556407, 0.24414212442934513, 0.1989963313098997, 0.15228848060360178, 0.1949935726588592, 0.13636791380122304, 0.27095538564026356, 0.14454611402470618, 0.13406906684394926, 0.13882699044188485, 0.14212791487807408, 0.2597685484215617, 0.10798150731716305, 0.12130421586334705, 0.115486631548265, 0.1354247034760192, 0.1993251621024683, 0.10045473463833332, 0.13801463559502736, 0.09862383405561559, 0.17323265987215564, 0.14149557537166402, 0.10110462593729608, 0.289532380993478, 3.4015955217182636, 55.114807561039925, 79.61936205625534, 75.11199831962585, 62.496124282479286, 58.30671228468418, 42.16974958777428, 47.957124039530754, 76.7653276026249, 73.88223230838776, 60.135303363204, 29.533371850848198, 12.366142887622118, 1.810960618313402, 0.34309062582906336, 0.484905784833245, 1.2175567913800478, 5.403751786798239, 15.421276800334454, 22.692359536886215, 16.029576659202576, 17.13859274983406, 22.19454064965248, 26.36674527078867, 39.888834580779076, 34.70070317387581, 49.19941037893295, 54.16172370314598, 59.8580626398325, 59.99889448285103, 66.36588603258133, 62.22220458090305, 61.749061569571495, 60.103757455945015, 64.12993401288986, 61.15934461355209, 63.08106489479542, 57.7748092263937, 58.57800252735615, 59.99371536076069, 65.36656245589256, 61.71220734715462, 59.001683592796326, 51.56520903110504, 50.90998359024525, 49.74495470523834, 59.77803893387318, 62.5051411986351, 63.852434903383255, 60.390596464276314, 59.03048984706402, 59.38703991472721, 63.65340918302536, 61.2428755313158, 54.92465056478977, 54.87355850636959, 54.8026467114687, 59.8478639870882, 62.28262513875961, 60.5414217710495, 63.736799508333206, 59.17962044477463, 45.83417035639286, 51.134764328598976, 61.9913175702095, 59.61500108242035, 60.60244269669056, 60.912680849432945, 61.53627298772335, 63.3064915984869, 63.98540496826172, 55.694215670228004, 45.658733770251274, 50.1715312153101, 62.25419506430626, 62.147549986839294, 62.75938555598259, 60.633437633514404, 59.18135695159435, 55.67712798714638, 54.65303733944893, 50.348461121320724, 52.871255949139595, 48.85469287633896, 58.336153104901314, 59.80912886559963, 61.881727650761604, 63.255224749445915, 58.209859281778336, 53.78424055874348, 55.44676534831524, 54.766183868050575, 57.00633846223354, 60.001181960105896, 60.770374685525894, 57.88797475397587, 51.41564145684242, 41.73289842903614, 38.07909809052944, 27.586949095129967, 31.916740760207176, 22.344389408826828, 18.974268548190594, 18.024061135947704, 16.047908775508404, 19.076091684401035, 10.104346554726362, 3.4048688085749745, 0.679047490702942, 0.1857273542555049, 0.2465403004316613, 0.7919156248681247, 10.980604235082865, 35.45870169997215, 66.55429512262344, 62.7906958758831, 31.184746138751507, 19.466496035456657, 30.512894690036774, 51.161716282367706, 64.09580424427986, 65.63450887799263, 63.68486389517784, 13.813479524105787, 0.17449162434786558, 0.15090216358657926, 0.1329137061838992, 0.18962815665872768, 0.1315067574614659, 0.16124307119753212, 0.09233616598066874, 0.19812999264104292, 0.10770300155854784, 0.17661511665210128, 0.1447603720589541, 0.1563700256519951, 0.13889627734897658, 0.14947069430490956, 0.08255013250163756, 0.13994463515700772, 0.1961047458462417, 0.10658676692401059, 0.18637916771695018, 0.16802129888674244, 0.11122025462100282, 0.10330812918255106, 0.09435149768250994, 0.13655968476086855, 0.14791430672630668, 0.08880997746018693, 0.10325865761842579], [0.013360199991439003, 0.04187053214991465, 0.03203599189873785, 0.007708061266384902, 0.04077561941812746, 0.10945564266876318, 0.0512696840451099, 0.05034972149587702, 0.02482137395418249, 0.030066497092775535, 0.053560987071250565, 0.013792719018965727, 0.04775866131240036, 0.006224696380741079, 0.03608673039707355, 0.1277973994729109, 0.07654016124433838, 0.013983861008455278, 0.010557239947956987, 0.048928983669611625, 0.072574072110001, 0.02940218215371715, 0.057695885116118006, 0.07197966377134435, 0.03021617158083245, 7.172050550580025, 50.44906832277775, 59.68725800514221, 52.35498525202274, 31.061915829777718, 23.97968675941229, 22.301314920186996, 38.082213923335075, 67.0857422053814, 72.04711318016052, 37.91958265006542, 14.337327964603901, 2.799870022572577, 0.05035887588746846, 0.06427222266211174, 0.013961941676825518, 2.0096865110099316, 2.1573166642338037, 7.1075537614524364, 7.847788715735078, 17.134773954749107, 6.606467999517918, 22.679704315960407, 29.34587851166725, 24.32611607015133, 42.173769772052765, 57.50698059797287, 59.14702199399471, 61.23883254826069, 61.287158355116844, 61.33982352912426, 55.19478566944599, 56.11918106675148, 56.46843172609806, 61.35840833187103, 60.238388031721115, 58.879022374749184, 58.85574482381344, 58.57802152633667, 59.194435849785805, 56.81300103664398, 55.74756480753422, 48.453954979777336, 45.95308877527714, 46.84670962393284, 50.27593821287155, 54.578489139676094, 57.60097615420818, 60.903188958764076, 59.20495368540287, 58.56665253639221, 60.95432661473751, 61.03782333433628, 58.71134117245674, 48.890722543001175, 45.54211042821407, 48.48991245031357, 53.2827852666378, 54.810706079006195, 59.523790776729584, 57.57976569235325, 61.442334428429604, 32.41544879972935, 37.29868456721306, 56.134517043828964, 53.1398369371891, 59.61040712893009, 58.602294623851776, 60.77909141778946, 56.75262987613678, 56.376225873827934, 45.8979195356369, 41.49588614702225, 44.42433200776577, 55.233463793992996, 58.14382642507553, 57.956857457756996, 56.14856109023094, 57.92681246995926, 55.57533144950867, 51.64236769080162, 47.32559032738209, 45.68285867571831, 47.073888033628464, 43.830735459923744, 48.79286639392376, 53.05980183184147, 56.94230429828167, 56.98578156530857, 55.06276175379753, 53.159299492836, 59.470969811081886, 57.40296497941017, 53.392739966511726, 56.71384155750275, 55.98824009299278, 60.563232600688934, 52.05116115510464, 35.7364059984684, 23.33360742777586, 27.86866407841444, 8.227869495749474, 4.456038465723395, 12.94403962790966, 8.116375878453255, 6.795000582933426, 4.025141587480903, 3.647246165201068, 1.177433675620705, 0.14038014225661755, 0.03320022122352384, 0.045263802021509036, 1.1005843430757523, 10.060689747333527, 36.80006392300129, 44.797905161976814, 34.200801998376846, 21.809860691428185, 21.551183871924877, 30.03759529441595, 52.62913294136524, 50.316991209983826, 46.3749535381794, 16.154789440333843, 0.03833373833913356, 0.026297793265257496, 0.05672146005963441, 0.08089310969808139, 0.08081053092610091, 0.056476722020306624, 0.026159724111494143, 0.04983424056263175, 0.022380255431926344, 0.013402452314039692, 0.07429245568346232, 0.04755050744279288, 0.13085945625789464, 0.06377755154971965, 0.07310185785172507, 0.04744044694234617, 0.03843762417091057, 0.06326743634417653, 0.07596997660584748, 0.03836965457594488, 0.08564431685954332, 0.044069244831916876, 0.0964156181726139, 0.05777915779617615, 0.04643803178623784, 0.05158841420779936, 0.04109683577553369, 0.01957818411028711, 0.018181382401962765, 0.01924970027175732, 0.02636567565787118, 0.035695043407031335, 0.0172215349812177, 0.026673590873542707, 0.012842971300415229, 0.0017405594098818256, 0.025731599525897764, 0.04008294330560602, 0.059567132557276636, 0.012018160432489822, 0.06332222168566659, 0.025118390731222462, 0.07673654836253263, 0.05178065272048116, 0.01866142021754058, 0.04245799769705627, 0.0120781871919462, 0.02762177915428765, 0.019489334190438967, 0.0429620013164822, 0.05577027164690662, 0.049327216402161866, 9.263690114021301, 61.60485930740833, 68.65755826234818, 58.829511031508446, 39.96828071773052, 33.6063314974308, 29.441090002655983, 38.077110797166824, 69.91422683000565, 72.98198461532593, 42.229877561330795, 17.22378797829151, 2.652807463891804, 0.12435479904524982, 0.06253255429328419, 1.0847122385166585, 2.8170854737982154, 8.112294897437096, 9.135068915784359, 12.00720939785242, 16.723326332867146, 11.117088161408901, 19.709284007549286, 25.45655731111765, 27.111374214291573, 41.15561060607433, 57.672982290387154, 58.76641161739826, 62.43512615561485, 62.26215943694115, 64.58369046449661, 59.073970913887024, 57.80224375426769, 57.161191552877426, 63.744197711348534, 59.1952034085989, 59.70925882458687, 58.456979021430016, 58.41551564633846, 61.00083611905575, 58.80114555358887, 56.81480213999748, 52.082536071538925, 48.820620104670525, 48.64555209875107, 52.556127458810806, 58.45268525183201, 59.2068687826395, 61.788765639066696, 58.94902601838112, 58.514637127518654, 59.13762129843235, 62.219077348709106, 59.63671691715717, 52.227027118206024, 47.16909572482109, 51.5030899643898, 56.30807653069496, 56.7226342856884, 61.52344487607479, 59.00701850652695, 62.55705401301384, 35.53518399596214, 40.049463361501694, 58.55230450630188, 54.05687972903252, 61.691984832286835, 59.68313902616501, 62.46251508593559, 58.045970275998116, 57.37656019628048, 47.16096416115761, 44.13921430706978, 47.06667222082615, 57.363333106040955, 57.692304253578186, 58.4847517311573, 56.72064699232578, 58.720939457416534, 56.81049697101116, 53.46039533615112, 49.189834892749786, 48.21648292243481, 47.82916970551014, 46.76879480481148, 51.45876534283161, 55.848646983504295, 58.64447996020317, 58.87700468301773, 53.68300639092922, 52.7057596296072, 58.84189456701279, 57.649290561676025, 55.06450206041336, 57.53302440047264, 58.8439654558897, 58.56135182082653, 53.52318316698074, 37.21079148352146, 23.765174970030785, 17.481511048972607, 11.611327640712261, 13.660592827945948, 12.767105922102928, 11.884781867265701, 7.259432086721063, 8.421642947942019, 6.884895684197545, 2.339145219884813, 0.25927831535227597, 0.04418024414917454, 0.030897695069143083, 1.23942592414096, 10.531809367239475, 37.3643184453249, 42.60623976588249, 29.205394349992275, 22.343599051237106, 27.154234014451504, 37.202150747179985, 58.674669340252876, 58.113500252366066, 54.84958179295063, 21.77020601928234, 0.26698160043451935, 0.04727341547550168, 0.03008539402799215, 0.14076806284720078, 0.02980031284096185, 0.02232246995845344, 0.036552075544022955, 0.047079885625862516, 0.025691425216791686, 0.0707901940040756, 0.02557551288191462, 0.013662982328241924, 0.0889821482996922, 0.025349491806991864, 0.05569869892497081, 0.015605764456267934, 0.04964349005604163, 0.027135325472045224, 0.03392544422240462, 0.0400713286944665, 0.022211930772755295, 0.051340599966351874, 0.030769160657655448, 0.06349700488499366, 0.043438007414806634, 0.03169360577885527, 0.04433995061845053, 0.1733540603891015, 0.12182503283838741, 0.13721917202929035, 0.11892572161741555, 0.16261807788396254, 0.15927498461678624, 0.11845177868963219, 0.09850515722064301, 0.09150295678409748, 0.18868445651605725, 0.21216841356363147, 0.16305208584526554, 0.1065266529622022, 0.16382252419134602, 0.15456780907697976, 0.1731984320213087, 0.19140252785291523, 0.2070632835966535, 0.14278762479079887, 0.17249913595151156, 0.1900511363055557, 0.11865615873830393, 0.09511140495305881, 0.2243869102676399, 0.18777572637191042, 14.167277589440346, 74.36990574002266, 73.91608849167824, 68.71952533721924, 44.602759033441544, 37.09562346339226, 32.765349224209785, 51.201367154717445, 77.78143107891083, 80.2893953025341, 48.65924656391144, 20.11346071958542, 3.7513615284115076, 0.15444044169271365, 0.20909805956762284, 0.8692958601750433, 4.263087194412947, 8.507410045713186, 17.734106294810772, 17.218485362827778, 25.3582014888525, 16.816993206739426, 32.095395773649216, 37.27414168417454, 29.121358059346676, 46.44275330007076, 61.68238274753094, 59.38276894390583, 62.030774652957916, 62.652166709303856, 67.21575602889061, 59.274793937802315, 61.8068640679121, 60.3936742991209, 66.25833660364151, 61.058311834931374, 59.31866638362408, 58.94385829567909, 59.08791996538639, 62.30187110602856, 62.36053615808487, 60.312940031290054, 54.42323327064514, 50.31423255801201, 50.90569742023945, 55.00557482242584, 60.44788219034672, 61.556385308504105, 64.35887932777405, 60.62097430229187, 57.95681186020374, 60.86399406194687, 63.731757178902626, 62.84309506416321, 53.960406705737114, 48.64625886082649, 54.95581269264221, 58.64997826516628, 58.64155791699886, 64.60050836205482, 61.96247711777687, 62.542789578437805, 39.177246764302254, 44.994662404060364, 60.315212309360504, 57.70411781966686, 62.83071532845497, 61.9902840256691, 64.17623832821846, 61.15430988371372, 59.456758573651314, 49.08426895737648, 46.963621750473976, 49.63749647140503, 58.13365437090397, 61.22297219932079, 58.485705479979515, 58.91450487077236, 60.744247287511826, 59.89700675010681, 57.68995977938175, 51.517525389790535, 50.65985061228275, 49.92783509194851, 49.45875026285648, 54.196602031588554, 59.11582566797733, 61.79724678397179, 60.28533071279526, 55.90073078870773, 53.65243323147297, 58.61184351146221, 57.39538058638573, 54.09198984503746, 58.14689666032791, 58.19589503109455, 60.576687678694725, 53.27894367277622, 40.87031431496143, 28.312288373708725, 32.70431309938431, 18.57211332768202, 11.669648811221123, 30.02060640603304, 25.834129750728607, 11.799719631671906, 12.48031821101904, 10.364017020910978, 2.3140031564980745, 0.43941809912212193, 0.17546104732900858, 0.158295305154752, 1.6239479533396661, 13.399730175733566, 49.333159402012825, 58.997044041752815, 45.02005644142628, 32.02354922890663, 30.81952303647995, 43.43693219125271, 65.403473675251, 64.4979290664196, 63.851241767406464, 26.837895289063454, 0.8619313209783286, 0.14522730169119313, 0.16762010869570076, 0.307311003562063, 0.11110289880889468, 0.18686189025174826, 0.107030200160807, 0.12161060411017388, 0.2268018588074483, 0.10594351784675382, 0.09121662878897041, 0.11762624330003746, 0.27713798044715077, 0.2186360227642581, 0.1950144863803871, 0.154206694860477, 0.12273018583073281, 0.10595516956527717, 0.19623497792053968, 0.1389101258246228, 0.15809437609277666, 0.14852034451905638, 0.22716459090588614, 0.20249981753295287, 0.09094853536225855, 0.14977671147789806, 0.06684533029329032], [0.041844119114102796, 0.02017742383031873, 0.03124346723780036, 0.021278175408951938, 0.014281782277976163, 0.03319309660582803, 0.01468114678573329, 0.02248890399641823, 0.047842160347499885, 0.019849713680741843, 0.03224261323339306, 0.0400385517423274, 0.08164252300048247, 0.01326591198449023, 0.02286192411702359, 0.03214354394003749, 0.05693658269592561, 0.0831898489559535, 0.05525619337277021, 0.03822342921921518, 0.03656669214251451, 0.05643129516101908, 0.022592136738239788, 0.05890422027732711, 0.23896218597656116, 19.77908056229353, 58.36458697915077, 59.5400995016098, 49.70019690692425, 42.84581311047077, 23.84323988109827, 34.27718169987202, 47.861304581165314, 46.7021007835865, 61.48817136883736, 25.137959606945515, 9.289456531405449, 0.5432098859455436, 0.09807368740439415, 0.04387045315525029, 1.3039034768007696, 1.4164585433900356, 7.282109744846821, 7.2658556420356035, 10.450774915516376, 25.791233852505684, 13.983221165835857, 18.882942348718643, 49.826266542077065, 48.04861932992935, 55.01491852104664, 60.18018275499344, 61.28757253289223, 62.93174050748348, 62.12687149643898, 58.44048410654068, 55.4410694539547, 53.97894591093063, 57.11670733988285, 60.30864246189594, 57.867896631360054, 58.56862463057041, 58.016050681471825, 57.155256271362305, 58.02437983453274, 52.41200119256973, 50.48459641635418, 45.403733253479004, 46.03374324738979, 50.14888443052769, 54.19641964137554, 54.18082907795906, 59.731928408145905, 59.65506233274937, 56.817530393600464, 54.17821481823921, 59.173555970191956, 56.91885955631733, 57.676208317279816, 47.24749691784382, 45.77294424176216, 46.00391864776611, 51.34176962077618, 54.205387160182, 59.088463336229324, 55.53525499999523, 61.143343672156334, 30.845741629600525, 37.063249200582504, 57.172579541802406, 54.78246219456196, 61.3598408550024, 56.61467827856541, 54.75224241614342, 53.113204166293144, 49.551784470677376, 44.07146394252777, 41.312169805169106, 40.59874668717384, 54.10383380949497, 58.35499629378319, 57.17873141169548, 54.64417241513729, 57.44216367602348, 57.01192036271095, 53.94509732723236, 49.79975916445255, 49.09414082765579, 43.977191001176834, 43.22037801146507, 44.01560693979263, 50.36810986697674, 53.88437278568745, 56.16134360432625, 52.307822182774544, 56.559144258499146, 51.24278873205185, 53.72660905122757, 54.19122911989689, 58.21885719895363, 59.37821298837662, 60.91277964413166, 54.85026195645332, 55.30514694750309, 37.735562324523926, 23.631205558776855, 9.278653711080551, 19.711541086435318, 10.093909464776516, 5.6934107188135386, 6.999482335522771, 3.4234685730189085, 5.180836748331785, 0.8308374113403261, 0.6329760910011828, 0.05485095847689081, 0.06586485673324205, 0.10027015508967452, 3.267579562962055, 16.73749767243862, 46.90590664744377, 49.761396422982216, 33.41391742229462, 14.363060183823109, 32.37556993961334, 46.995084062218666, 48.619162514805794, 51.56207799911499, 26.594926826655865, 2.403030004352331, 0.05437882638943847, 0.06725037223077379, 0.08031683202716522, 0.046088469098322093, 0.016361465604859404, 0.045247827292769216, 0.04714519833214581, 0.017678525400697254, 0.0242759529282921, 0.03875102942402009, 0.011247344518778846, 0.04857391795667354, 0.06118990153481718, 0.018842307581508067, 0.03472389864327852, 0.06636848556809127, 0.04283113099518232, 0.05846975589520298, 0.028864930318377446, 0.015312287723645568, 0.05709009965357836, 0.03991738871263806, 0.05107871089421678, 0.07795086523401551, 0.06330341566354036, 0.028348130217636935, 0.007673454920222866, 0.04981066995242145, 0.10673625030904077, 0.019497315988701303, 0.022767554473830387, 0.00892067444510758, 0.016595269953540992, 0.019439101924945135, 0.05811176240968052, 0.03650304926850367, 0.012820702231692849, 0.0670445449941326, 0.04786214638443198, 0.030418260248552542, 0.060498078892123885, 0.024581682519055903, 0.011872456434502965, 0.06200388539582491, 0.035017573900404386, 0.034933373535750434, 0.05355895729735494, 0.031140902428887784, 0.05205463137826882, 0.05168039599084295, 0.3715459333034232, 26.274917498230934, 67.75414153933525, 64.57941189408302, 59.55166608095169, 46.815262511372566, 33.81986863911152, 31.156800538301468, 38.69434207677841, 53.870932906866074, 67.11264476180077, 29.187867790460587, 8.252470325678587, 0.8475410775281489, 0.005300676139086136, 0.3328814642736688, 1.3132841046899557, 4.704845789819956, 8.85693334043026, 12.136863190680742, 11.62213521078229, 17.499474585056305, 7.352932244539261, 21.635448150336742, 32.50659450888634, 45.24656608700752, 54.615157172083855, 60.34368418157101, 61.73391558229923, 61.38817213475704, 61.41545847058296, 60.855972692370415, 60.11843606829643, 55.71782000362873, 60.51656350493431, 62.06989735364914, 58.80105435848236, 59.256247133016586, 57.70179234445095, 58.645657896995544, 61.38723358511925, 55.1946222782135, 52.93928749859333, 47.16330863535404, 48.04499812424183, 50.64992554485798, 56.2497952580452, 56.30428433418274, 61.747826635837555, 60.541528165340424, 56.60960175096989, 55.74636027216911, 59.6945346146822, 58.45532990992069, 58.59797425568104, 49.73221778869629, 46.97777599096298, 48.290871530771255, 52.92821489274502, 56.76933377981186, 60.48763185739517, 56.921017840504646, 61.781853809952736, 32.15079300105572, 40.1323027163744, 59.32648256421089, 56.33387714624405, 60.709783136844635, 58.614092990756035, 57.69467532634735, 53.79356525838375, 51.6730472445488, 45.13098008930683, 43.29768866300583, 43.21872130036354, 56.11340917646885, 59.28666070103645, 58.72096985578537, 56.53943091630936, 57.99381047487259, 58.06444488465786, 55.58545030653477, 52.472330555319786, 51.244027465581894, 45.877453833818436, 45.2623276412487, 46.575499176979065, 53.39835986495018, 57.18448810279369, 58.32356818020344, 53.82820039987564, 55.81101380288601, 52.2558219730854, 55.02859778702259, 53.32593575119972, 56.86787389218807, 59.81336183845997, 62.73731254041195, 56.82942375540733, 53.228497579693794, 39.61010813713074, 22.773289494216442, 18.685322552919388, 14.875836968421936, 14.862740971148014, 11.243258491158485, 9.303282089531422, 13.809286449104548, 7.945504747331142, 3.4175712894648314, 1.403530805837363, 0.20990753488149494, 0.09446801486774348, 0.17424083780497313, 3.6287912679836154, 18.83245635777712, 44.00592505931854, 43.926117941737175, 34.13709841668606, 20.762220807373524, 37.9903082549572, 54.89108316600323, 53.87835010886192, 58.26743759214878, 31.32847722619772, 3.426679875701666, 0.07674360618693754, 0.05703012298909016, 0.04457271410501562, 0.013295801054482581, 0.044546623903443106, 0.04876593382505234, 0.037897860165685415, 0.010262098021485144, 0.0866605545161292, 0.03402210524654947, 0.0476569351303624, 0.04308804025640711, 0.03380742789886426, 0.019594715449784417, 0.05112742917845026, 0.015367181604233338, 0.05815892218379304, 0.05710022996936459, 0.014395688031072496, 0.05344003555364907, 0.0387084449903341, 0.056184423447120935, 0.05336722344509326, 0.05108490782731678, 0.029911480996815953, 0.027833166932396125, 0.14495572017040104, 0.1618506823433563, 0.2239040393033065, 0.14773659204365686, 0.10871592923649587, 0.10900524066528305, 0.18828979722457007, 0.1189743322902359, 0.09842881248914637, 0.2104406789294444, 0.15328709967434406, 0.1848421650356613, 0.19272724661277607, 0.1775574660860002, 0.08569864206947386, 0.10140794911421835, 0.1602366892620921, 0.16142146865604445, 0.11923585028853267, 0.16045425727497786, 0.18948645098134875, 0.14489498280454427, 0.24148010008502752, 0.11302418555715121, 0.7450251909904182, 33.63547593355179, 78.73653262853622, 74.47277382016182, 65.21899357438087, 53.7252601236105, 36.57987713813782, 47.6384237408638, 62.99205847084522, 57.970696315169334, 72.75722667574883, 32.833376973867416, 12.251070812344551, 1.0938531230203807, 0.25760857213754207, 0.358069897047244, 2.7028346294537187, 5.497911209240556, 17.662531435489655, 20.097334384918213, 19.452695176005363, 35.58258265256882, 24.424185007810593, 25.618683211505413, 54.81891743838787, 51.689587756991386, 59.0877565741539, 61.75487905740738, 61.96273930370808, 62.66373708844185, 63.31102855503559, 63.54192316532135, 61.85709737241268, 58.756174966692924, 63.726954236626625, 62.988064885139465, 58.36986109614372, 59.048546478152275, 60.24617001414299, 60.815497264266014, 62.971558570861816, 57.057054340839386, 56.15648366510868, 49.14580285549164, 50.870241522789, 53.98351326584816, 60.0468061119318, 57.95237369835377, 63.67409907281399, 62.364142164587975, 58.058764189481735, 55.2175198495388, 60.571147575974464, 61.081475391983986, 62.529756277799606, 52.928693667054176, 48.89017157256603, 51.534331887960434, 54.503439366817474, 60.02655699849129, 63.27032133936882, 60.72881631553173, 61.53141684830189, 35.952633395791054, 43.73848780989647, 60.21131068468094, 59.6959937363863, 65.00331714749336, 61.94244459271431, 59.527351185679436, 56.60121940076351, 54.092662408947945, 48.43149058520794, 44.69178065657616, 44.90518860518932, 59.11319620907307, 61.38896629214287, 60.15880890190601, 56.459346413612366, 58.384433314204216, 61.007763147354126, 58.88536423444748, 54.92849975824356, 54.30976375937462, 48.54201905429363, 47.553825080394745, 49.01907205581665, 55.06390929222107, 58.976935520768166, 61.52889758348465, 52.556207254529, 56.23004391789436, 51.768923699855804, 56.792740523815155, 54.06143568456173, 59.30860452353954, 60.56612804532051, 65.65372064709663, 59.37342144548893, 58.56818005442619, 42.13394030928612, 27.633080519735813, 14.202604293823242, 27.7853649482131, 21.633392460644245, 13.739746380597353, 18.73599473387003, 14.267757497727871, 14.053872674703598, 4.1094980109483, 1.7578493244946003, 0.3277390042785555, 0.3330799442483112, 0.3765007189940661, 4.7883634082973, 22.238895669579506, 60.70417083799839, 62.79207140207291, 45.617821365594864, 23.098538741469383, 43.7959673255682, 61.36127717792988, 62.58901409804821, 65.50372749567032, 40.069435089826584, 4.564737807959318, 0.17358179582515731, 0.196810424386058, 0.17246740171685815, 0.10826538622495718, 0.12201853300211951, 0.15303791617043316, 0.15453000407433137, 0.15156068606302142, 0.1491778576746583, 0.1366063955356367, 0.13933653419371694, 0.2021535611129366, 0.17349586996715516, 0.1085623491962906, 0.1179418119136244, 0.11496331353555433, 0.19757719652261585, 0.13720615475904197, 0.0903468242904637, 0.1096952598891221, 0.09848212837823667, 0.10371854426921345, 0.1556410882039927, 0.17460826027672738, 0.21462527860421687, 0.12566433346364647], [0.03167754570313264, 0.019540367975423578, 0.01320935198236839, 0.02397098589426605, 0.010210204272880219, 0.04077085111930501, 0.025751921384653542, 0.02084138624923071, 0.00601791548433539, 0.022770074065192603, 0.04949596223013941, 0.025811988962232135, 0.039315403046202846, 0.0343626656831475, 0.10371748299803585, 0.05230311355262529, 0.015127805581869325, 0.05629612409393303, 0.04909241572022438, 0.013803800211462658, 0.0133897467458155, 0.09028375658090226, 0.026081414544023573, 0.0481242952082539, 0.9416565648280084, 37.783223167061806, 61.6708617657423, 60.24784192442894, 48.341180831193924, 35.81817761063576, 20.221069045364857, 49.06334728002548, 66.95638954639435, 66.84610426425934, 39.95271295309067, 12.060890067368746, 3.7733504734933376, 0.03339216658787336, 0.0809658995422069, 0.23659998929360881, 1.181866256520152, 2.9926476906985044, 8.722143173217773, 5.273005552589893, 10.066906213760376, 10.104964021593332, 10.116158220916986, 41.902441531419754, 43.00251670181751, 54.24781568348408, 57.85153090953827, 59.854965806007385, 59.32239018380642, 56.79358787834644, 59.68000419437885, 58.75161901116371, 54.57595847547054, 53.91908772289753, 60.926177725195885, 59.05390799045563, 57.52564139664173, 57.88206227123737, 58.406213745474815, 58.379185795784, 55.690598264336586, 47.96563558280468, 45.35930223762989, 47.91577845811844, 50.61704970896244, 52.20287561416626, 54.875431805849075, 55.892663821578026, 59.69202294945717, 57.89670288562775, 55.30486576259136, 56.85989812016487, 59.27407197654247, 58.38353656232357, 58.068693056702614, 45.70950664579868, 44.59725312888622, 44.889738634228706, 51.10490173101425, 52.018881887197495, 57.09731698036194, 53.3470968157053, 62.33567789196968, 32.53792002797127, 33.918325155973434, 56.38028785586357, 52.81493537127972, 60.69152511656284, 54.07371282577515, 56.58923864364624, 53.862668350338936, 56.6128733754158, 50.030091404914856, 44.59303915500641, 38.27853798866272, 48.69434528052807, 56.35453663766384, 56.36978901922703, 53.32239054143429, 55.81343047320843, 57.63105534017086, 57.14028887450695, 51.58610790967941, 49.51368771493435, 44.28313158452511, 39.82057124376297, 43.15327361226082, 49.387173503637314, 54.99175116419792, 56.13398127257824, 52.989129424095154, 54.66785654425621, 54.007596373558044, 55.658877566456795, 61.064383909106255, 55.936027094721794, 55.26480831205845, 53.95417883992195, 60.32090060412884, 52.46515654027462, 46.93432152271271, 35.26050053536892, 41.69884465634823, 27.941528968513012, 14.272492993623018, 12.154026869684458, 5.515511864796281, 10.995527934283018, 6.502943029627204, 3.712663692422211, 0.23620921885594726, 0.1924804231384769, 0.03199095466698054, 0.038871491124155, 0.2844968199497089, 7.064582342281938, 30.60138814151287, 47.95804738998413, 34.88761894404888, 19.237659014761448, 27.196922823786736, 42.52334341406822, 46.48658774793148, 53.4618354588747, 36.61548122763634, 4.3953001499176025, 0.09465026407269761, 0.03943953837733716, 0.03198207858076785, 0.053781813112436794, 0.02753795728494879, 0.017614769349165726, 0.038875190730323084, 0.019678752541949507, 0.04600528547598515, 0.026537876183283515, 0.06871349411085248, 0.012490680292103207, 0.05747631330450531, 0.022101497343101073, 0.027298924505885225, 0.03230741014704108, 0.03397956534172408, 0.06772047083359212, 0.05663345618813764, 0.016174535303434823, 0.04375401018478442, 0.025679808750282973, 0.04654857097193599, 0.017246626994165126, 0.0197006421876722, 0.02803050956572406, 0.0381835424923338, 0.02629093582072528, 0.06821736096753739, 0.0644894344441127, 0.033215776638826355, 0.03445825801463798, 0.06699084318825044, 0.020466330788622145, 0.03848434236715548, 0.007174760439738748, 0.029136650991858914, 0.05625795543892309, 0.01609755418030545, 0.03707945310452487, 0.03280144672316965, 0.00811827272627852, 0.039221632687258534, 0.0506931020936463, 0.03164774847391527, 0.04066790410433896, 0.021653566691384185, 0.03822070924798027, 0.08171397697879001, 0.01897106834803708, 1.478828634135425, 47.13439218699932, 71.28315657377243, 67.05498665571213, 55.567070692777634, 45.36025978624821, 25.63592478632927, 39.41686570644379, 66.60764425992966, 70.20890861749649, 48.62657591700554, 13.708168175071478, 3.4700730722397566, 0.03719207401445601, 0.04318529499869328, 0.6924538838211447, 3.7723247660323977, 7.202017167583108, 16.02665651589632, 9.917376637458801, 13.71843522414565, 14.73016133531928, 10.7171187736094, 24.091659151017666, 40.68142645061016, 54.81413349509239, 58.411860242486, 60.41535593569279, 60.42861722409725, 55.91136261820793, 62.763933911919594, 60.93790389597416, 57.6460075378418, 54.325821697711945, 62.02472157776356, 60.137758031487465, 58.661978021264076, 58.024402633309364, 58.857637122273445, 59.8148437589407, 57.91557267308235, 49.86082948744297, 47.096493020653725, 49.77027274668217, 52.12319768965244, 54.49367769062519, 56.61299116909504, 59.174825102090836, 62.80106171965599, 57.77580477297306, 57.655001655220985, 56.452795565128326, 60.20979456603527, 60.16937993466854, 61.38901948928833, 48.57608802616596, 46.013634726405144, 47.0472514629364, 53.80606658756733, 55.78470021486282, 59.090788811445236, 56.386473923921585, 62.06355929374695, 34.51638266444206, 37.31446132063866, 58.357678949832916, 54.639905244112015, 62.74865873157978, 56.435179710388184, 58.456808030605316, 55.76757833361626, 58.75733770430088, 51.293713599443436, 45.93362241983414, 39.45090048015118, 51.58101998269558, 58.112709894776344, 58.53079006075859, 53.859263733029366, 55.862846821546555, 58.037986904382706, 57.763812616467476, 54.49986755847931, 51.11209474503994, 45.7809504121542, 43.36627118289471, 45.449414402246475, 51.60577565431595, 56.42574481666088, 57.55755588412285, 54.84868884086609, 54.33879040181637, 54.28377315402031, 56.043971702456474, 60.99763289093971, 56.05225145816803, 54.864283204078674, 56.105893179774284, 63.40851232409477, 54.25679840147495, 49.29590240120888, 33.827677220106125, 33.22253689169884, 23.081741742789745, 11.255583129823208, 13.778737038373947, 10.591602008789778, 13.88384509831667, 7.165229441598058, 5.9570814203470945, 2.8776594484224916, 0.48807629907969385, 0.07813591975718737, 0.0856044857937377, 0.47130147577263415, 8.064704351127148, 34.73775498569012, 40.9110177308321, 34.24730010330677, 21.60647850483656, 33.37232485413551, 47.11251676082611, 51.37531042098999, 61.29035398364067, 44.787486121058464, 5.594054125249386, 0.06869629112770781, 0.03876711918564979, 0.057451173051958904, 0.042044406218337826, 0.05181340369745158, 0.03644863871159032, 0.0211652223879355, 0.0373325477266917, 0.023592954421474133, 0.007019218810455641, 0.0379708763648523, 0.04259134679159615, 0.032159488982870243, 0.0214524725015508, 0.051647945583681576, 0.03812622271652799, 0.05425694718724117, 0.10109663300681859, 0.06306949813733809, 0.012035732634103624, 0.08295346007798798, 0.01677277497947216, 0.053667618849431165, 0.05392514409322757, 0.017955617367988452, 0.019134053254674654, 0.1368024412658997, 0.10182620128034614, 0.1266692904755473, 0.1501790148904547, 0.11175995183293708, 0.15616407967172563, 0.23075271164998412, 0.10492963279830292, 0.11779435459175147, 0.1203616734710522, 0.07591214845888317, 0.12854155094828457, 0.08296615822473541, 0.14643185189925134, 0.21329943177988753, 0.1147491297160741, 0.11671990287140943, 0.19081161502981558, 0.17386149644153193, 0.14961976208724082, 0.07072832857375033, 0.14355421881191432, 0.15166831231908873, 0.19853159843478352, 2.7629424165934324, 60.7130965590477, 79.1080690920353, 75.56722149252892, 61.92839674651623, 49.60528180003166, 29.864748269319534, 63.314634561538696, 76.6313011944294, 75.75170159339905, 49.82257314026356, 17.533372566103935, 4.313466316089034, 0.2407644025515765, 0.22659588314127177, 0.8434200205374509, 3.6981653328984976, 10.05088247358799, 19.887553341686726, 15.816639885306358, 23.526946753263474, 23.737269267439842, 16.79803602397442, 45.91140881180763, 48.63316096365452, 59.520705342292786, 62.414873242378235, 61.03476829826832, 60.70759825408459, 55.929065868258476, 63.428373858332634, 64.34310257434845, 61.38119950890541, 57.90460266172886, 64.71485942602158, 63.144700080156326, 61.150016114115715, 58.19912865757942, 60.950728207826614, 63.42252977192402, 61.521244794130325, 52.20645882189274, 49.05483953654766, 53.031611144542694, 54.49478343129158, 57.70357824862003, 59.143628776073456, 61.3052149862051, 64.846081584692, 59.25389125943184, 57.141896188259125, 57.89675608277321, 61.406749337911606, 61.79630443453789, 63.31353262066841, 50.83515800535679, 48.1703419983387, 50.1473531126976, 56.511225029826164, 57.13885635137558, 61.243434101343155, 58.6955302208662, 62.3376689851284, 37.49444246292114, 40.206501334905624, 58.4387020021677, 57.9774409532547, 65.12693971395493, 58.62035125494003, 60.832349359989166, 58.09381730854511, 60.88364660739899, 53.632647693157196, 48.72057147324085, 42.403060868382454, 52.63824485242367, 60.95273829996586, 59.35382969677448, 54.72356155514717, 56.90863810479641, 59.349079951643944, 60.44119454920292, 56.811374723911285, 54.88903507590294, 48.15678432583809, 43.91675144433975, 47.49402388930321, 54.51130874454975, 60.02884827554226, 60.46190343797207, 54.99230973422527, 54.82670322060585, 56.641071662306786, 58.27420502901077, 63.59778396785259, 56.95955157279968, 55.98306857049465, 54.866855666041374, 63.92901599407196, 54.70358982682228, 52.08686403930187, 39.06291089951992, 48.744867369532585, 40.62244601547718, 21.464596018195152, 26.603983640670776, 14.639192316681147, 21.517762765288353, 16.78191538900137, 11.590211223810911, 2.585300523787737, 0.6707553856540471, 0.25308277748990804, 0.30176594329532236, 0.6785755441524088, 9.751121308654547, 40.27783490717411, 62.08215169608593, 46.91260188817978, 28.827856108546257, 38.04097853600979, 54.838763773441315, 60.33032789826393, 68.16419273614883, 53.014006689190865, 9.323112275451422, 0.2810083399526775, 0.22193803073605523, 0.20729036594275385, 0.16453219548566267, 0.12157576769823208, 0.12665830668993294, 0.12052069345372729, 0.053217380118439905, 0.10604594164760783, 0.08302765258122236, 0.1452050669468008, 0.17006609385134652, 0.1558142906287685, 0.07913782654213719, 0.12172731425380334, 0.10243688491755165, 0.15318106161430478, 0.3072628827067092, 0.18219473131466657, 0.14980371081037447, 0.2626761345891282, 0.16921608243137598, 0.1745997107354924, 0.18968349118949845, 0.09521523883449845, 0.0979180441936478], [0.03744500165339559, 0.03016739949089242, 0.0959719845559448, 0.05140260640473571, 0.04048042646900285, 0.06149709501187317, 0.09900051110889763, 0.024217653517553117, 0.03209937502106186, 0.035643564333440736, 0.03462742315605283, 0.01192051049656584, 0.0360627293412108, 0.03475392222753726, 0.06731357352691703, 0.059085575194330886, 0.03658081892353948, 0.03623804688686505, 0.01855148217146052, 0.03966458352806512, 0.07534214193583466, 0.0864890961383935, 0.08057874336373061, 0.17351141053950414, 10.110301785171032, 49.83068190515041, 56.57486401498318, 55.27014322578907, 40.304558873176575, 18.99553030729294, 34.571103528141975, 66.68480291962624, 57.05116845667362, 53.92116241157055, 17.2498032823205, 8.615137115120888, 0.20457480306504294, 0.0893230464134831, 0.05950132632278837, 0.9188494167756289, 1.7651267652399838, 7.1639489103108644, 5.977427903562784, 11.775106452405453, 8.857676200568676, 20.246193297207355, 13.17221263423562, 34.50320117175579, 50.83092883229256, 60.738106817007065, 58.80361162126064, 57.88583546876907, 56.95637874305248, 59.53017443418503, 59.19198118150234, 57.83437483012676, 52.31295570731163, 54.86274428665638, 59.454805478453636, 58.549333065748215, 60.98056800663471, 58.0544476211071, 57.951317355036736, 54.950489178299904, 51.49546377360821, 45.39799936115742, 45.8793119341135, 49.71462473273277, 53.41401882469654, 54.631560891866684, 59.31241191923618, 57.850611358881, 59.49923649430275, 55.309550911188126, 55.37239573895931, 59.053391218185425, 58.92366237938404, 56.10012508928776, 53.531698510050774, 41.45085856318474, 44.161275923252106, 43.55461947619915, 49.84568729996681, 51.05784125626087, 59.08710680902004, 54.323420226573944, 62.043868750333786, 34.69318337738514, 35.255093425512314, 57.25312761962414, 53.968416675925255, 59.63642053306103, 54.49122302234173, 57.97354236245155, 55.64857251942158, 58.17154973745346, 55.52328184247017, 53.64575698971748, 41.22121028602123, 42.06443063914776, 53.837688490748405, 58.397063836455345, 55.601002871990204, 53.03503856062889, 53.797342255711555, 55.612425059080124, 53.92662271857262, 50.97090192139149, 48.36293466389179, 42.28617534041405, 44.31123107671738, 48.13984103500843, 52.78277009725571, 56.628722324967384, 52.958867847919464, 53.66520434617996, 57.12647281587124, 55.39944648742676, 55.65678767859936, 58.04859973490238, 60.95098279416561, 55.81817641854286, 54.7692047059536, 57.891143783926964, 58.09436447918415, 43.34151931107044, 48.285373225808144, 29.040817581117153, 20.91634053736925, 8.49866671487689, 7.277317252010107, 17.047656029462814, 5.721785221248865, 2.408814006485045, 2.3466426925733685, 0.6069797859527171, 0.10369193827500567, 0.06544656745973043, 0.11181051435414702, 1.3108929642476141, 15.42206620797515, 49.95667554438114, 38.38465489447117, 19.91695426404476, 14.204692281782627, 29.219301603734493, 41.28516465425491, 48.67950327694416, 39.45301316678524, 16.048210859298706, 0.7154263230040669, 0.030475275743810926, 0.028447351651266217, 0.05247355889878236, 0.014518673033308005, 0.03313346504000947, 0.027340408705640584, 0.007953988133522216, 0.04158936579187866, 0.057422518730163574, 0.012020456451864447, 0.02699012798984768, 0.03933642808988225, 0.06367644877173007, 0.035733508921111934, 0.0014919773934707337, 0.08591540114139207, 0.02827036241797032, 0.10485820108442567, 0.0484434149984736, 0.04927655369101558, 0.02649753118021181, 0.03687496173370164, 0.0203939472703496, 0.06013153957610484, 0.033977409402723424, 0.027400333419791423, 0.0495316855085548, 0.06049978212104179, 0.07856823562178761, 0.009083146342163673, 0.014950622462492902, 0.0653338797565084, 0.02315759575139964, 0.04448709623829927, 0.057572117148083635, 0.06272447368246503, 0.020765997032867745, 0.02050214312475873, 0.031234075358952396, 0.022932513493287843, 0.033568289363756776, 0.013559696708398405, 0.05113104714837391, 0.013539640167437028, 0.011153925752296345, 0.037815945615875535, 0.028606173109437805, 0.10148716595722362, 0.09370669009513222, 15.310202110558748, 57.658474668860435, 64.05181020498276, 63.50984528660774, 47.68886223435402, 25.258637331426144, 23.81334498524666, 62.144616544246674, 65.6051516532898, 60.99622696638107, 21.59252755343914, 8.106736745685339, 0.6452117313165218, 0.06414156756363809, 0.26857410091906786, 2.5280316593125463, 5.557104907929897, 9.766620676964521, 13.469388037919998, 7.405442576855421, 9.526353869587183, 14.329508934170008, 14.090558756142855, 33.438980877399445, 51.87878340482712, 60.95297388732433, 61.80425740778446, 59.457746520638466, 57.115183621644974, 59.089200496673584, 60.401676669716835, 59.33937147259712, 55.293420776724815, 56.973865404725075, 61.27885960042477, 59.406981244683266, 61.201913729310036, 58.671469911932945, 58.264910727739334, 58.43127720057964, 54.25445772707462, 49.17965143918991, 49.44548897445202, 51.52646251022816, 54.60253044962883, 57.250543758273125, 60.79213231801987, 58.605098873376846, 60.65551444888115, 56.561116352677345, 56.03451780974865, 59.09638591110706, 60.438644886016846, 57.55892001092434, 56.29754729568958, 42.3377575725317, 46.84037156403065, 46.80777691304684, 50.68834528326988, 53.881739526987076, 60.06520852446556, 56.471684351563454, 61.39324486255646, 36.84484452009201, 38.01201269030571, 59.41933438181877, 55.349425971508026, 59.909857660532, 57.199470698833466, 60.44740341603756, 57.73525334894657, 59.88023824989796, 58.41268099844456, 55.452328249812126, 42.458252906799316, 44.109119921922684, 55.238281935453415, 60.28149671852589, 56.33411653339863, 53.735549971461296, 55.56547857820988, 57.042725309729576, 56.57929837703705, 53.87546606361866, 50.780231952667236, 45.291331484913826, 45.612513050436974, 51.39371283352375, 54.825472086668015, 57.2449504584074, 54.599824994802475, 54.96439263224602, 59.309892654418945, 58.16496089100838, 58.8294692337513, 59.27328161895275, 60.94005458056927, 56.69711485505104, 54.04858857393265, 58.069946989417076, 57.926869466900826, 45.79828128218651, 43.33166263997555, 21.791235990822315, 14.239757750183344, 15.33700967207551, 10.474103763699532, 11.506161633878946, 8.246806729584932, 7.028497578576207, 4.730149107053876, 1.5325983613729477, 0.25091864517889917, 0.08435240844846703, 0.06702007638523355, 1.8355760537087917, 16.55664447695017, 50.13939633965492, 41.51880271732807, 21.617290824651718, 20.445357710123062, 37.555550783872604, 48.24495479464531, 56.323515102267265, 47.63459354639053, 19.642779976129532, 0.9868183883372694, 0.08350854201125912, 0.019509314661263488, 0.047745970587129705, 0.011504555277497275, 0.05633040018437896, 0.04424623592058197, 0.04291262252081651, 0.059088592024636455, 0.03391309117432684, 0.029715578129980713, 0.02206976496381685, 0.0070168040474527515, 0.009131068673013942, 0.07533739961218089, 0.050269016646780074, 0.03688459109980613, 0.048000467868405394, 0.03240914003981743, 0.01921171529829735, 0.024465434362355154, 0.050419212493579835, 0.01104337357901386, 0.03790323702560272, 0.02787451012409292, 0.04838146051042713, 0.0948144197172951, 0.11003350853570737, 0.1639730020542629, 0.1685854053357616, 0.10786077473312616, 0.12727106834063306, 0.1555738941533491, 0.14300682552857324, 0.12627902469830588, 0.10305722389603034, 0.16965722985332832, 0.09983018768252805, 0.1365306816296652, 0.15108229767065495, 0.132640729425475, 0.19561163324397057, 0.13024730316828936, 0.10678497972548939, 0.12842869997257367, 0.15130224055610597, 0.14809187297942117, 0.1718771122978069, 0.2543715317733586, 0.26934593450278044, 21.927067302167416, 68.13591465353966, 73.8331389427185, 71.51236027479172, 55.12443624436855, 30.598251409828663, 47.810729295015335, 77.14917540550232, 66.11146688461304, 64.77591454982758, 24.80181634426117, 11.58512994647026, 0.8395045681390911, 0.38021024025510997, 0.30328419932629913, 2.6938397996127605, 7.597561217844486, 16.65718138217926, 16.464657112956047, 22.84020770341158, 27.153523452579975, 33.180172964930534, 17.093492969870567, 40.14791987836361, 55.18923036754131, 65.64547508955002, 62.65128135681152, 60.2851939201355, 57.352967262268066, 58.90908256173134, 61.944549679756165, 62.98164702951908, 56.72187812626362, 59.02545131742954, 63.09857815504074, 62.08040378987789, 61.386382430791855, 61.60072132945061, 59.99249182641506, 61.36899076402187, 54.6362080425024, 51.639730632305145, 50.77914521098137, 54.556108340620995, 55.75605735182762, 59.175562262535095, 62.738175094127655, 59.97592851519585, 61.59527242183685, 56.02854073047638, 56.656506434082985, 62.46318005025387, 61.534099504351616, 59.913440868258476, 58.22174124419689, 45.87577812373638, 47.91140869259834, 49.478611797094345, 52.68660105764866, 56.708875223994255, 62.74169370532036, 60.17309993505478, 61.181873604655266, 39.388412833213806, 41.87401905655861, 60.051179677248, 57.688728645443916, 61.16288982331753, 58.65204155445099, 63.14340054988861, 60.24351395666599, 61.755836606025696, 61.81728310883045, 58.526986464858055, 45.92103749513626, 46.52388274669647, 58.33763122558594, 62.47106462717056, 59.0008020401001, 53.960338309407234, 55.44857785105705, 58.97244796156883, 58.05206894874573, 56.16992734372616, 54.17824141681194, 46.75285466015339, 48.76552686095238, 53.47425699234009, 56.23135104775429, 60.254696756601334, 55.32277800142765, 55.57397872209549, 60.50259165465832, 58.56547459959984, 60.520648285746574, 61.35409936308861, 62.754297628998756, 58.445617631077766, 56.441156789660454, 60.18816612660885, 60.0962832570076, 48.072949424386024, 60.486476719379425, 37.28968285024166, 32.39296540617943, 20.497162230312824, 16.691195257008076, 31.3170550391078, 14.997313600033522, 10.560091249644756, 7.981378622353077, 1.0194421908818185, 0.5448354862164706, 0.29546576261054724, 0.20770926377736032, 2.018441716209054, 20.613073110580444, 61.57220385968685, 51.72492206096649, 29.494300447404385, 23.471405133605003, 43.494692891836166, 55.61880871653557, 62.940369844436646, 56.6926234960556, 25.332444570958614, 1.4967831457033753, 0.15805492352228612, 0.13816521735861897, 0.17230683064553887, 0.1514342537848279, 0.19849446136504412, 0.06247586905374192, 0.19779189984546974, 0.14775919786188751, 0.15477702050702646, 0.0933502588304691, 0.21035209618275985, 0.126187146815937, 0.17183310294058174, 0.14308286597952247, 0.08951506970333867, 0.14225094811990857, 0.1346753421239555, 0.2576354081975296, 0.0936650407675188, 0.22145275521324947, 0.0889264426950831, 0.12106755981221795, 0.16529064072528854, 0.12520274729467928, 0.21300380467437208], [0.0306990573881194, 0.038537862346856855, 0.04002637309895363, 0.03440647466049995, 0.02894531047786586, 0.05646252102451399, 0.08747565530939028, 0.02539423032430932, 0.0716491779894568, 0.059433508868096396, 0.04083184452611022, 0.046296504224301316, 0.025582036359992344, 0.013261562999105081, 0.05267389424261637, 0.031067765630723443, 0.05323455712641589, 0.05653728498145938, 0.027310644873068668, 0.057073427306022495, 0.04456033137103077, 0.04968502064002678, 0.06725437982822768, 0.7571037334855646, 24.211096242070198, 52.11376279592514, 51.421029567718506, 45.655758529901505, 34.58882197737694, 24.184818752110004, 60.81697918474674, 69.19938638806343, 74.77667391300201, 37.61153317987919, 13.489453811198473, 3.0341747123748064, 0.11086365266237408, 0.10502430115593597, 0.08112003619316965, 2.3645169334486127, 5.243196152150631, 8.791129421442747, 18.006927855312824, 3.349627610296011, 9.620850048959255, 18.62498939037323, 28.956336714327335, 40.42002707719803, 55.9879969060421, 61.507953107357025, 58.87394964694977, 60.19674226641655, 60.04944697022438, 57.69499450922012, 58.10815393924713, 57.0325418561697, 51.2551798671484, 54.13055017590523, 56.29137262701988, 57.46032290160656, 58.29843632876873, 56.68556347489357, 54.51108455657959, 51.80651508271694, 47.02473387122154, 47.67574153840542, 51.02995455265045, 51.27339228987694, 54.763577207922935, 55.37951275706291, 58.45660664141178, 54.67748522758484, 56.82537317276001, 55.406236723065376, 56.00044123828411, 55.182595923542976, 54.20924015343189, 50.100699216127396, 44.6796441078186, 41.56745910644531, 44.22428794205189, 42.34183095395565, 48.73963885009289, 51.56266696751118, 56.92786127328873, 53.33149865269661, 61.27237714827061, 33.7349583953619, 32.21562132239342, 56.448258608579636, 50.541095584630966, 59.32436227798462, 53.235964179039, 58.8260418176651, 55.39273604750633, 59.6818432956934, 55.100839510560036, 57.938299253582954, 45.48704378306866, 39.960753321647644, 46.650507152080536, 54.83450040221214, 55.84577053785324, 54.73776899278164, 52.54032410681248, 54.470913112163544, 55.04938647150993, 52.546992748975754, 48.8988047093153, 44.30322490632534, 41.984403133392334, 45.70967763662338, 50.60379981994629, 56.63535296916962, 53.91912192106247, 55.313985273242, 56.18736460804939, 53.49461629986763, 52.534423023462296, 54.81845386326313, 54.697445556521416, 58.1323966383934, 58.5530948638916, 53.97554889321327, 54.16807696223259, 51.20325565338135, 43.818834498524666, 30.32078269869089, 17.641282975673676, 18.507378101348877, 13.465356454253197, 7.873786445707083, 3.7725408794358373, 5.556546812877059, 4.483820199966431, 1.5931059583090246, 0.1437700798851438, 0.024915168432926293, 0.05876792114577256, 0.33386270224582404, 6.187204672023654, 24.979629702866077, 48.472338393330574, 34.84479524195194, 20.540278516709805, 17.848482057452202, 29.605759866535664, 43.305155262351036, 47.180453315377235, 23.73400904238224, 3.0454698437824845, 0.011241293232160388, 0.03065476230403874, 0.028125934913987294, 0.004450008382264059, 0.04180335294222459, 0.02882264830986969, 0.03972415943280794, 0.05590756896708626, 0.0062292661550600315, 0.04878464707871899, 0.03199531107384246, 0.02162387336284155, 0.07045622754958458, 0.050069063508999534, 0.038524689225596376, 0.036487293473328464, 0.02723755631450331, 0.02533175818825839, 0.05945139462710358, 0.07849341229302809, 0.017112875284510665, 0.03494273572869133, 0.04098250421520788, 0.029732506518485025, 0.09329162174253725, 0.05391901024268009, 0.04064099754032213, 0.07844765888876282, 0.03774130411329679, 0.06111268106906209, 0.06791429754230194, 0.07773736419039778, 0.025562848131812643, 0.07758943931548856, 0.04766561454744078, 0.014976231195760192, 0.06898114967043512, 0.0471894637303194, 0.03502719584503211, 0.0403024742990965, 0.01193248597701313, 0.020950413309037685, 0.046161581776686944, 0.05468379342346452, 0.02696550352993654, 0.06235349632333964, 0.10377681028330699, 0.0970750386477448, 0.7791031873784959, 30.807154700160027, 59.404579773545265, 61.251280680298805, 51.23853296041489, 43.42188119888306, 28.144153095781803, 56.7615631967783, 70.96889063715935, 71.12098127603531, 42.63492822647095, 14.316899310797453, 3.4629874024540186, 0.06392691619112156, 0.08320694061694667, 0.3770425758557394, 3.371607530862093, 9.590015653520823, 10.489488188177347, 17.872561365365982, 12.25626228377223, 9.09836858510971, 15.704163070768118, 30.575779415667057, 42.990273758769035, 57.137112244963646, 63.95681530237198, 61.00832171738148, 60.813095793128014, 60.04802964627743, 58.784886226058006, 59.37326565384865, 60.379090681672096, 53.88509854674339, 56.16548538208008, 59.22816663980484, 59.62174192070961, 59.789966493844986, 57.921165972948074, 56.57315410673618, 54.02059927582741, 48.96182432770729, 49.257570058107376, 52.21999369561672, 53.02808113396168, 55.90049900114536, 57.73743063211441, 58.8078597933054, 56.28493197262287, 57.023954316973686, 55.14760360121727, 57.17109762132168, 59.09721426665783, 57.058262676000595, 53.558411076664925, 47.10990630090237, 43.86166200041771, 45.21600052714348, 44.62344132363796, 50.16316406428814, 53.2291055470705, 57.90912821888924, 55.681987926363945, 61.14895597100258, 35.828285068273544, 34.91685077548027, 57.244027107954025, 50.278092697262764, 62.82734110951424, 55.471775606274605, 60.0432875007391, 55.95673218369484, 59.7672513127327, 57.4204820394516, 59.177636951208115, 48.06567281484604, 41.61114916205406, 48.951177299022675, 57.50621683895588, 56.97301805019379, 55.077265575528145, 52.38645516335964, 56.64455987513065, 55.88041327893734, 55.538241639733315, 51.51162810623646, 46.50774501264095, 44.77187655866146, 48.63313056528568, 54.955550506711006, 57.54721663892269, 53.93951162695885, 56.57875880599022, 57.803334295749664, 55.52364282310009, 56.30942925810814, 57.49083146452904, 58.10698740184307, 58.97029347717762, 57.10974231362343, 55.19309476017952, 56.30823612213135, 51.32098853588104, 43.06177832186222, 31.36306867003441, 14.543454553931952, 15.767451524734497, 11.049479339271784, 12.78304036706686, 9.508747514337301, 8.337725400924683, 7.883964199572802, 2.7733621699735522, 0.6331655464600772, 0.08985665801446885, 0.09528126029181294, 0.2970139717217535, 7.144973678514361, 29.739715978503227, 44.52240854501724, 29.53074809163809, 24.034745804965496, 22.78469268232584, 35.584167167544365, 49.598578959703445, 55.5626667290926, 29.596904441714287, 4.101052964106202, 0.04737278162792791, 0.0334601695794845, 0.05036257549363654, 0.03581609882530756, 0.08307129086460918, 0.051050976835540496, 0.03404878545552492, 0.0397751152922865, 0.06151726658572443, 0.037561596764135174, 0.024946741250460036, 0.030318825447466224, 0.05416125095507596, 0.04836944513954222, 0.04957823301083408, 0.022794232827436645, 0.025035910293809138, 0.02111143523507053, 0.05845981853781268, 0.07574046001536772, 0.032929905064520426, 0.06815306871430948, 0.036173031039652415, 0.0594871772773331, 0.0439054194430355, 0.08760279262787662, 0.20704894530354068, 0.1780439735739492, 0.12863277574069798, 0.1617056963732466, 0.12544775992864743, 0.2878341096220538, 0.13512348057702184, 0.23597585794050246, 0.20163134147878736, 0.1351083704503253, 0.1688082722830586, 0.09911859422572888, 0.08669458940858021, 0.07909205829491839, 0.16860646748682484, 0.11696711226250045, 0.11290154565358534, 0.11789786934969015, 0.1088227539730724, 0.17113972920924425, 0.13707403762964532, 0.161056881188415, 1.3274642312899232, 36.61821708083153, 69.80233803391457, 69.9780786037445, 59.317249059677124, 47.49016709625721, 35.555577501654625, 73.56741160154343, 75.94822704792023, 80.34089013934135, 50.11920802295208, 18.292429335415363, 3.947630259208381, 0.2527120301965624, 0.2888825861737132, 0.3785996907390654, 5.400598431006074, 14.496990647166967, 18.030596785247326, 28.20936519652605, 14.042221549898386, 19.052474051713943, 20.33492613583803, 34.630855321884155, 45.58733180165291, 59.72897596657276, 64.22524809837341, 61.51575408875942, 60.80499842762947, 60.36257676780224, 58.264397755265236, 61.73615366220474, 63.07095743715763, 57.19504773616791, 60.77353231608868, 62.6552939414978, 61.935304775834084, 62.16617278754711, 60.18051713705063, 58.75907801091671, 56.189785078167915, 51.13343060016632, 52.176854610443115, 54.76628266274929, 55.13292498886585, 58.70578587055206, 59.60219956934452, 61.232201904058456, 57.510449811816216, 57.30857044458389, 56.84982866048813, 58.3704424649477, 60.1585391163826, 59.1074775159359, 55.68707965314388, 49.248420149087906, 45.403528064489365, 47.65367232263088, 46.7824474722147, 53.083147779107094, 56.25560134649277, 60.7218436896801, 57.874166294932365, 61.35180048644543, 37.304623648524284, 38.43169257044792, 57.698630914092064, 51.77211552858353, 61.859305053949356, 55.568066239356995, 59.87103894352913, 58.337251245975494, 61.006494015455246, 60.533898174762726, 63.043906688690186, 49.59226369857788, 44.459966495633125, 51.47325396537781, 59.851192608475685, 59.07416470348835, 56.21953748166561, 53.72972868382931, 57.17376887798309, 58.83344382047653, 58.06064888834953, 54.85559307038784, 49.26274538040161, 47.20487840473652, 51.413277983665466, 57.05832727253437, 60.01145280897617, 56.0392789542675, 58.02498400211334, 60.21340437233448, 58.81410665810108, 58.7945681065321, 60.8382086455822, 61.30963794887066, 62.298515886068344, 59.09433402121067, 56.16806924343109, 57.73710384964943, 55.30792839825153, 49.16347190737724, 41.22446671128273, 23.40522028505802, 24.89744771271944, 21.810462959110737, 14.310226868838072, 15.52241312339902, 16.344800144433975, 11.56546600162983, 4.4738775584846735, 0.6775712699163705, 0.16594675864325836, 0.1754777308087796, 0.8657998102717102, 9.129427168518305, 33.187745958566666, 61.84316731989384, 47.20298990607262, 31.96354664862156, 26.29245925694704, 44.86067399382591, 56.06263630092144, 64.08076465129852, 37.635464295744896, 5.53703248500824, 0.15288877417333424, 0.10517753238673322, 0.1291926222620532, 0.12638307380257174, 0.19993314432213083, 0.1273591909557581, 0.1083429777645506, 0.15834250574698672, 0.10411114039015956, 0.12625138711882755, 0.11951066015171818, 0.12141061757574789, 0.18849074112949893, 0.09590038956957869, 0.1403506493079476, 0.21611410105833784, 0.1108914238284342, 0.1671606450690888, 0.16589424427365884, 0.25649425224401057, 0.09391642845002934, 0.11038346085115336, 0.1587654260220006, 0.1455908501520753, 0.2056818499113433], [0.08178251431672834, 0.028621806450246368, 0.06495338064269163, 0.021931851661065593, 0.010007850287365727, 0.07250445123645477, 0.042549474819679745, 0.08703145023901016, 0.011854726526507875, 0.08655947400256991, 0.03173585995682515, 0.08385460547287948, 0.014803894300712273, 0.00807309448646265, 0.014700768242619233, 0.04273132697562687, 0.0069686562892457005, 0.05110733553010505, 0.07564286017441191, 0.06103281855757814, 0.0754485881770961, 0.08190146574634127, 0.04383215091365855, 3.093399521894753, 35.40910676121712, 55.58443196117878, 52.141824290156364, 49.726297706365585, 30.3902505710721, 35.647152587771416, 53.89545299112797, 63.88586550951004, 58.55666667222977, 22.263546846807003, 6.194547303020954, 0.3785755857825279, 0.05130121789989062, 0.12068677868228406, 1.3467312161810696, 2.689266032539308, 7.179330959916115, 6.561133582144976, 14.127629566937685, 6.750366277992725, 5.1068618427962065, 20.04415813833475, 37.793976590037346, 52.44564838707447, 57.38305024802685, 61.813452914357185, 61.06710836291313, 58.758405447006226, 57.92368523776531, 58.04696582257748, 57.128064930438995, 56.492989808321, 50.7386089861393, 50.801351219415665, 56.29339411854744, 57.50279322266579, 55.26959225535393, 53.19131277501583, 47.91218385100365, 44.425057768821716, 47.03348480165005, 48.00215162336826, 50.391414016485214, 52.60787308216095, 55.459308475255966, 57.32484497129917, 57.525181621313095, 54.74208936095238, 55.91918259859085, 55.31367368996143, 59.50552515685558, 53.075886368751526, 48.59742008149624, 42.5141517072916, 41.799607649445534, 41.19646221399307, 46.9822483509779, 49.31778162717819, 51.53477266430855, 52.23178446292877, 56.5338072180748, 53.369534611701965, 60.41958890855312, 38.94017368555069, 32.0459870249033, 56.10678993165493, 49.21674884855747, 49.892561584711075, 50.690670758485794, 52.907126024365425, 52.38098345696926, 53.04255075752735, 54.58594053983688, 56.93559005856514, 51.44862748682499, 41.0382729023695, 42.17255763709545, 51.59522742033005, 56.18280865252018, 55.74573710560799, 53.297862857580185, 54.055728390812874, 55.881044045090675, 55.8795241266489, 50.18471650779247, 47.64435522258282, 40.879129841923714, 42.98064507544041, 50.209244191646576, 55.50125062465668, 54.47133108973503, 55.1907654851675, 55.31936578452587, 51.07730761170387, 49.02329742908478, 55.25148242712021, 56.786463260650635, 58.10247704386711, 58.80443997681141, 59.41311791539192, 53.59008617699146, 53.33472467958927, 50.781577080488205, 34.915824830532074, 23.046464435756207, 30.333667807281017, 12.398560848087072, 13.792832382023335, 8.373591676354408, 5.5054091569036245, 4.264065166935325, 3.186966651119292, 0.6334046367555857, 0.08328597192303278, 0.03937090456020087, 0.026790686933964025, 1.503224631305784, 17.74711299687624, 49.19129401445389, 49.003736078739166, 27.966024354100227, 18.03717613220215, 25.007018633186817, 43.54097440838814, 48.049504682421684, 36.54535599052906, 8.218838330358267, 0.03239682409912348, 0.04014989986899309, 0.02382187914918177, 0.052432829834287986, 0.02872888908314053, 0.017226299569301773, 0.05817853714688681, 0.06864517941721715, 0.01202152050609584, 0.032588865942670964, 0.034444817720213905, 0.029424248059513047, 0.07246645327541046, 0.007449168151651975, 0.05250845839327667, 0.11083841221989132, 0.06033122554072179, 0.04462477576453239, 0.05391337734181434, 0.011262978787272004, 0.019242250964452978, 0.07890454726293683, 0.055045994886313565, 0.053484924355871044, 0.05135499392054044, 0.050462086364859715, 0.01857486910012085, 0.0325677221553633, 0.030401328149309848, 0.03258859876950737, 0.024479696585331112, 0.010333493555663154, 0.0310373876709491, 0.020287907354941126, 0.05761016705946531, 0.050089984652004205, 0.027712629162124358, 0.03886802529450506, 0.02781282466457924, 0.0008728462603357912, 0.06867701013106853, 0.07323656507651322, 0.02395066032477189, 0.08679973689140752, 0.06276092055486515, 0.04042052401928231, 0.03657374996691942, 0.1645648351404816, 3.651167079806328, 43.420121893286705, 65.3159111738205, 58.801821917295456, 58.23052637279034, 38.24179396033287, 37.80183456838131, 62.77532570064068, 73.73927637934685, 66.43263325095177, 28.451336212456226, 7.408484313637018, 0.6183373171370476, 0.03044264351046877, 0.2494450961239636, 2.372570363804698, 4.275589948520064, 7.181627936661243, 11.714017130434513, 16.82402092963457, 10.67756099626422, 11.752993538975716, 19.99357335269451, 36.35616414248943, 52.39523269236088, 61.57235585153103, 61.10651604831219, 63.14692296087742, 59.956959933042526, 59.42232482135296, 56.52854070067406, 58.5550669580698, 56.91132836043835, 54.38550129532814, 53.71310457587242, 59.52892430126667, 59.69344027340412, 58.70031416416168, 55.315467193722725, 50.51860459148884, 47.35444977879524, 49.27222207188606, 50.0918722897768, 52.93734200298786, 54.87979777157307, 57.55729369819164, 57.663763985037804, 59.59145374596119, 54.998681992292404, 55.89807853102684, 57.36689351499081, 60.337980687618256, 55.12995354831219, 53.16404923796654, 45.611194521188736, 44.62490804493427, 43.547867238521576, 48.24226073920727, 49.84624966979027, 53.862512558698654, 54.27325151860714, 58.88428509235382, 55.172819048166275, 61.04760020971298, 39.00152899324894, 34.12631459534168, 55.8656320720911, 50.091309919953346, 53.3888603746891, 52.18768782913685, 54.04428340494633, 53.20842705667019, 54.61238332092762, 55.50134941935539, 59.70719553530216, 53.38784962892532, 42.2542342543602, 42.81068779528141, 53.522145822644234, 58.90963353216648, 55.274813175201416, 51.94104686379433, 54.43801447749138, 56.76890820264816, 58.204216584563255, 51.971616223454475, 49.606288745999336, 43.29539738595486, 45.838684514164925, 52.89153166115284, 57.90505103766918, 55.91686852276325, 57.28554368019104, 56.213229820132256, 53.77667136490345, 52.6364703476429, 57.78734855353832, 58.12718331813812, 60.854532569646835, 59.52190227806568, 60.33078007400036, 54.67725723981857, 55.11568911373615, 48.76523807644844, 35.27049399912357, 18.093399815261364, 18.32694098353386, 6.940919402986765, 9.950044434517622, 11.239417847245932, 8.340624645352364, 7.2503443993628025, 4.67241358011961, 1.6622298303991556, 0.2566684491466731, 0.17261505941860378, 0.08241394840297289, 1.8626759620383382, 17.40978989750147, 46.90910987555981, 51.214959025382996, 31.69870276004076, 22.052815854549408, 30.46481776982546, 48.483316004276276, 55.192285403609276, 43.00552234053612, 10.02683736383915, 0.06276340674958192, 0.045665496872970834, 0.04932797710353043, 0.05402153423347045, 0.05797865451313555, 0.021714632457587868, 0.07519366787164472, 0.08639854670036584, 0.06450735731050372, 0.026088149534189142, 0.026317929587094113, 0.021037882834207267, 0.0038080896047176793, 0.014585884709958918, 0.04101159269339405, 0.05780508101452142, 0.04705717590695713, 0.018209554327768274, 0.0701707010739483, 0.03602096126996912, 0.05007696367101744, 0.05633383261738345, 0.08867115873727016, 0.06413701077690348, 0.040233495383290574, 0.3416934882989153, 0.13865240762243047, 0.1427755574695766, 0.168271001894027, 0.18889300001319498, 0.17895181314088404, 0.08669371367432177, 0.11640043056104332, 0.07366240199189633, 0.19756143330596387, 0.14238334726542234, 0.10122561085154302, 0.24222109001129866, 0.12945148337166756, 0.10097058664541692, 0.14459859870839864, 0.19529803132172674, 0.11822382803075016, 0.22656999703031033, 0.16249963111476973, 0.19224715128075331, 0.23121741483919322, 0.28367449063807726, 5.324174081906676, 53.31490494310856, 72.41013050079346, 67.27721393108368, 64.98633205890656, 43.98327827453613, 46.245688274502754, 64.48483496904373, 69.00712430477142, 68.66144925355911, 30.583323910832405, 8.701502680778503, 0.9510458610020578, 0.37333471700549126, 0.424783926573582, 3.4472714457660913, 7.094395067542791, 16.723542921245098, 19.358103051781654, 25.237181782722473, 17.68836434930563, 11.550525203347206, 25.748947821557522, 43.00681047141552, 57.259283289313316, 64.75961342453957, 64.1917110979557, 64.61956813931465, 59.270078390836716, 60.5636315792799, 56.07210539281368, 60.769173949956894, 60.00906653702259, 55.959661826491356, 56.07989877462387, 61.86872474849224, 62.709714621305466, 61.932656317949295, 57.45111979544163, 52.74223767220974, 49.50338266789913, 51.65275253355503, 52.300902754068375, 55.21298669278622, 57.020591497421265, 60.80513522028923, 61.07672564685345, 60.85335463285446, 56.18413858115673, 55.72502441704273, 58.35090771317482, 63.16572055220604, 58.84705848991871, 54.03326399624348, 46.123380437493324, 46.73404186964035, 45.690051689743996, 51.875093802809715, 53.59395816922188, 56.464533135294914, 57.327052652835846, 60.678089037537575, 58.41882526874542, 60.8871728181839, 42.216259092092514, 37.24725052714348, 55.8224093914032, 51.54449634253979, 52.6721428334713, 53.312784656882286, 54.92200590670109, 53.19988511502743, 53.80301535129547, 56.17340415716171, 61.008534505963326, 55.47824285924435, 46.63823381066322, 46.31876215338707, 54.66344118118286, 62.03112803399563, 56.717664152383804, 53.70043225586414, 56.42349533736706, 58.84192496538162, 60.01316271722317, 54.74715068936348, 52.12888218462467, 45.27616649866104, 47.97828510403633, 54.84692953526974, 60.94188988208771, 57.64049023389816, 59.78965111076832, 59.00623194873333, 55.41204281151295, 54.964236840605736, 61.42583951354027, 61.73116832971573, 63.05151768028736, 63.1704019010067, 62.07421012222767, 53.46494369208813, 55.67784994840622, 53.55657197535038, 38.247250467538834, 28.230778947472572, 37.91026175022125, 19.892817959189415, 25.14106784015894, 22.640135139226913, 14.626472499221563, 12.649107053875923, 8.522091507911682, 2.4720860738307238, 0.5715753044933081, 0.3086988494032994, 0.2650866302428767, 2.686221208423376, 23.30390252172947, 62.88256734609604, 60.25396719574928, 39.87481713294983, 30.247279442846775, 37.979372441768646, 58.20563770830631, 62.18756563961506, 52.04515367746353, 12.76321493089199, 0.2649599307915196, 0.21063439431600273, 0.2143445092951879, 0.16124149784445763, 0.12284861775697209, 0.043274018753436394, 0.20497673540376127, 0.16182491497602314, 0.10998967729392461, 0.10132802723092027, 0.1945195035659708, 0.0733611716714222, 0.16693289479007944, 0.05337847069313284, 0.17782177455956116, 0.23839235014747828, 0.1681196631398052, 0.1522424674476497, 0.13467866694554687, 0.1119362044846639, 0.13527428498491645, 0.16709275339962915, 0.18904815340647474, 0.14173895528074354, 0.1828981240396388], [0.03466443777142558, 0.0461234353861073, 0.022036778354959097, 0.020603279299393762, 0.034815873004845344, 0.08730909510632046, 0.03130651639366988, 0.012648181655094959, 0.09648939507314935, 0.0221392930689035, 0.05756852144259028, 0.0418612256180495, 0.055471171290264465, 0.045649960011360236, 0.023986721280380152, 0.039186161739053205, 0.024906663420551922, 0.016974295904219616, 0.02883395121898502, 0.0275289030832937, 0.05527079512830824, 0.036384390987223014, 0.1092539714591112, 8.63268457353115, 38.66163343191147, 50.19060239195824, 47.0167201012373, 32.77919568121433, 26.146780773997307, 37.58966535329819, 46.32147520780563, 32.891506254673004, 22.210993766784668, 14.704729299992323, 2.3725710762664676, 0.06871128251077607, 0.06347436938085593, 0.18541085795732215, 1.0666274651885033, 3.0551640735939145, 6.988717038184404, 5.788589436560869, 14.90758141502738, 13.65863973274827, 14.717874694615602, 30.0334782153368, 38.28353852033615, 53.54613393545151, 59.514701664447784, 56.89188480377197, 58.80307585000992, 55.87645389139652, 53.87805372476578, 55.99789537489414, 55.99067196249962, 55.80770418047905, 51.764310747385025, 48.37088383734226, 52.42872029542923, 51.34764030575752, 48.937722221016884, 44.72485028207302, 43.524354100227356, 48.901681154966354, 51.389764845371246, 54.85481031239033, 54.394012838602066, 55.03219239413738, 55.590405240654945, 57.495664805173874, 54.61908616125584, 56.04828827083111, 54.33242194354534, 56.31440319120884, 55.711538940668106, 50.00925712287426, 42.479337975382805, 41.08847200870514, 42.19966918230057, 47.891824543476105, 57.654367089271545, 52.500319853425026, 54.68310512602329, 52.59827859699726, 56.08834572136402, 54.52365808188915, 60.219848826527596, 39.194364845752716, 28.027326464653015, 56.44724026322365, 46.556591391563416, 53.65093231201172, 53.90480048954487, 57.02420890331268, 55.47609597444534, 56.878372728824615, 50.43331436812878, 54.39851559698582, 55.99524311721325, 45.63496224582195, 37.22758658230305, 47.83131279051304, 54.142485335469246, 56.42914943397045, 51.23448237776756, 51.17424041032791, 53.72237607836723, 54.95715782046318, 51.03060431778431, 48.54160487651825, 42.891840040683746, 41.40800066292286, 44.575020521879196, 54.85392116010189, 57.07459419965744, 55.60808189213276, 53.32663491368294, 47.50571966171265, 45.252493768930435, 49.956660345196724, 50.205512791872025, 54.181509241461754, 54.213134944438934, 57.31010936200619, 54.17833261191845, 54.84212279319763, 49.34286408126354, 46.26938380300999, 27.05948229879141, 24.674608670175076, 12.078188639134169, 9.599626287817955, 6.594862947240472, 6.770952623337507, 6.6427237540483475, 2.9048709757626057, 1.7251039878465235, 0.3432197595247999, 0.20304499921621755, 0.021598985440505203, 0.4305058851605281, 5.543468864634633, 30.782870203256607, 33.6796485632658, 28.014994226396084, 17.68951378762722, 25.87681096047163, 42.79560260474682, 45.95952183008194, 40.32838359475136, 10.513360407203436, 0.48597263696137816, 0.02224145155196311, 0.04803912263014354, 0.02235132094938308, 0.017592308249732014, 0.022169329640746582, 0.03434797858062666, 0.01371255408230354, 0.04659665843064431, 0.0950597292103339, 0.021582335357379634, 0.05578678443271201, 0.051628104265546426, 0.07897773786680773, 0.011021728842024459, 0.03544251652783714, 0.06696326498058625, 0.08154625902534463, 0.05082586118078325, 0.047877082106424496, 0.019109644017589744, 0.02970327146613272, 0.018101686873706058, 0.08114123935229145, 0.028673285523836967, 0.07966700752149336, 0.028731898491969332, 0.04480414172576275, 0.012576278677443042, 0.109871319582453, 0.022460080836026464, 0.06298680062172934, 0.010816140020324383, 0.03140742250252515, 0.052211391521268524, 0.053306671616155654, 0.07304962549824268, 0.02720707816479262, 0.034951255584019236, 0.05335124129487667, 0.032832739379955456, 0.04096822900464758, 0.029215441099950112, 0.01565490019856952, 0.017639980105741415, 0.08659853323479183, 0.04549967510683928, 0.030476077263301704, 11.839734334498644, 48.81295591592789, 58.2624788582325, 52.801685482263565, 40.56118570268154, 27.390625029802322, 36.563830599188805, 53.29440884292126, 45.618087351322174, 31.98712818324566, 17.678539976477623, 2.6157086296007037, 0.14321251917863265, 0.013693619112018496, 0.4910208145156503, 2.6188650727272034, 6.711674854159355, 10.731368958950043, 11.770690139383078, 18.491489253938198, 10.851601157337427, 18.91493283212185, 30.216341502964497, 40.21052531898022, 54.91377554833889, 62.09562197327614, 60.07569596171379, 59.232802391052246, 56.47922694683075, 54.13874253630638, 55.930581986904144, 59.12151776254177, 58.81442964076996, 54.10636827349663, 50.497378930449486, 55.215540155768394, 53.76339867711067, 51.9121266156435, 47.69448593258858, 45.397740975022316, 49.78814698755741, 52.459570840001106, 55.55105835199356, 56.875800266861916, 56.497367173433304, 57.35267847776413, 59.99440312385559, 56.94111876189709, 56.39580622315407, 55.193235352635384, 56.51590257883072, 57.307244315743446, 53.520929887890816, 44.57681402564049, 42.66376107931137, 45.43701946735382, 49.14286181330681, 59.51421529054642, 55.82201801240444, 58.119287341833115, 54.12637419998646, 57.839994728565216, 58.047881573438644, 60.8033911138773, 42.05075517296791, 30.659032948315144, 55.19480846822262, 47.81965121626854, 53.507945984601974, 55.33740721642971, 56.742104440927505, 56.44691728055477, 56.87935307621956, 50.82033880054951, 54.72886607050896, 58.58708783984184, 48.482647240161896, 39.13493223488331, 50.28408497571945, 56.56767480075359, 55.52980989217758, 52.94438682496548, 50.86499400436878, 54.70121115446091, 57.385679706931114, 53.23089525103569, 49.96384955942631, 45.674100145697594, 43.8431303948164, 48.196062818169594, 55.80493412911892, 59.193330109119415, 56.317340433597565, 55.05297347903252, 50.04660911858082, 49.46638025343418, 51.8582759052515, 53.51613074541092, 56.178507283329964, 57.281595692038536, 58.08567434549332, 56.26972518861294, 53.70006367564201, 50.82588650286198, 45.59597633779049, 30.88888641446829, 18.50198809057474, 11.124740950763226, 12.438198421150446, 10.832906160503626, 7.316744411364198, 11.883934512734413, 6.543255066499114, 3.404937917366624, 0.6714369740802795, 0.19145688274875283, 0.06557129279826768, 0.7624905381817371, 7.506898557767272, 33.53208728134632, 37.85939387977123, 26.721889413893223, 23.912092186510563, 32.322087809443474, 49.94912914931774, 50.82818537950516, 48.86308282613754, 13.817442711442709, 0.6355904694646597, 0.04094186791917309, 0.005013124991819495, 0.054875853820703924, 0.07153105034376495, 0.022890652653586585, 0.01417289808159694, 0.03490831863018684, 0.05917573129408993, 0.0645774086297024, 0.017661509809840936, 0.06978676581638865, 0.023449740328942426, 0.07351990963798016, 0.08847085307934321, 0.015051120390126016, 0.026112042978638783, 0.041456513936282136, 0.034820648725144565, 0.04423183825565502, 0.059693375587812625, 0.0859388084791135, 0.021794845633849036, 0.019862096414726693, 0.0384047062107129, 0.1932910265168175, 0.11755611776607111, 0.16691860102582723, 0.1023815652297344, 0.17313500808086246, 0.1017510736710392, 0.11526110029080883, 0.14398414496099576, 0.20485597313381732, 0.12113313598092645, 0.15982386219548061, 0.15171258884947747, 0.08413338582613505, 0.19490638514980674, 0.09708010009489954, 0.06486845668405294, 0.1469562534475699, 0.08230776933487505, 0.22477428166894242, 0.12690253264736384, 0.11954064291785471, 0.13097169867251068, 0.30099301133304834, 15.481178686022758, 59.15434040129185, 66.78226009011269, 61.48159772157669, 45.57919263839722, 39.724918976426125, 49.34000663459301, 55.80928489565849, 43.485189601778984, 33.32168497145176, 21.303625255823135, 3.565804660320282, 0.5281277233734727, 0.19770600367337465, 0.8118165226187557, 2.552367690950632, 12.268246840685606, 20.86115039885044, 19.18450176715851, 27.19215787947178, 25.925058871507645, 20.619623959064484, 33.91356021165848, 44.67587850987911, 56.691380962729454, 64.47288081049919, 59.21045199036598, 59.68751259148121, 57.279247418046, 55.01206487417221, 55.79679116606712, 60.480062663555145, 60.4142501950264, 56.76717169582844, 53.865377604961395, 57.79859595000744, 55.42349919676781, 53.76749485731125, 50.313464999198914, 48.217603862285614, 53.41971091926098, 56.141428872942924, 58.4808075428009, 59.14718918502331, 58.74792940914631, 59.819327518343925, 59.55628663301468, 57.605410516262054, 56.85839340090752, 56.57388746738434, 58.829450234770775, 60.10180436074734, 56.03362485766411, 47.420034259557724, 45.680628195405006, 47.43863046169281, 53.522677794098854, 63.2369439303875, 58.59311431646347, 59.51647996902466, 57.00232967734337, 59.256159737706184, 60.03623887896538, 59.66380186378956, 44.23577852547169, 34.01358984410763, 55.705637857317924, 48.74297887086868, 53.583261743187904, 56.062898486852646, 59.896049201488495, 59.88279551267624, 60.644020065665245, 52.02819898724556, 56.78423658013344, 62.93151631951332, 51.89278945326805, 42.08755999803543, 52.88560397922993, 60.09758658707142, 57.11610697209835, 52.78125777840614, 50.829374715685844, 56.02680802345276, 57.588843405246735, 57.16404899954796, 53.94090235233307, 48.41039031744003, 46.09155714511871, 51.058179438114166, 59.31845739483833, 62.64874689280987, 59.4629180431366, 57.81868167221546, 53.024015352129936, 49.65858153998852, 54.33188617229462, 56.14367455244064, 58.371920585632324, 57.71873563528061, 59.932527244091034, 58.46700668334961, 54.72863428294659, 54.04143735766411, 48.60409252345562, 32.436503469944, 31.501428745687008, 17.668151333928108, 17.68245756626129, 17.454281710088253, 15.908296667039394, 14.346715360879898, 7.101169629022479, 4.6209068689495325, 0.8451496402267367, 0.41087964142207056, 0.1769481331575662, 0.9811293217353523, 8.260586690157652, 39.21548791229725, 43.261807188391685, 40.51235072314739, 29.404418170452118, 37.34617441892624, 57.077744230628014, 57.44794316589832, 57.891633957624435, 19.403905794024467, 1.17477607447654, 0.2266323522781022, 0.13578883081208915, 0.1261756880558096, 0.12108096299925819, 0.15939608827466145, 0.09103397882427089, 0.1147438159387093, 0.12981130625121295, 0.3246631287038326, 0.25099665974266827, 0.21559918415732682, 0.1569201351958327, 0.17198646033648401, 0.2513563638785854, 0.13859269442036748, 0.13104735320666805, 0.1327912072883919, 0.16255205642664805, 0.1512858539354056, 0.11073572124587372, 0.24312000896316022, 0.0671200139913708, 0.23563206545077264, 0.14895874599460512], [0.020435448168427683, 0.03081878436205443, 0.03624761688115541, 0.060661755851469934, 0.01884763805719558, 0.03980458597652614, 0.021147845000086818, 0.06358500133501366, 0.04492086300160736, 0.01536128524094238, 0.029192421534389723, 0.026398317168059293, 0.03165909962262958, 0.03077920562645886, 0.054958595865173265, 0.06931110852747224, 0.012336834934103535, 0.020292770277592354, 0.004969213505319203, 0.05012734807678498, 0.03859614320390392, 0.04503205156652257, 0.24735799874179065, 13.760290928184986, 41.17400161921978, 50.68969801068306, 42.34143577516079, 30.468237586319447, 32.80040994286537, 33.618065267801285, 37.07549214363098, 40.805033817887306, 35.213778242468834, 10.519169345498085, 0.4359290550928563, 0.025303096444986295, 0.009290907801187132, 0.29149720212444663, 2.957043838687241, 4.035074254497886, 4.599019093438983, 10.528975669294596, 14.941726382821798, 9.584599044173956, 34.16948787868023, 38.332909271121025, 49.18902933597565, 57.471585497260094, 62.12343268096447, 61.685338988900185, 54.336267337203026, 56.853563860058784, 57.546224892139435, 54.18689735233784, 57.82907031476498, 54.509021267294884, 52.73301176726818, 47.07800701260567, 44.395164772868156, 43.78695420920849, 43.607326447963715, 47.96012967824936, 53.33382032811642, 52.50634253025055, 56.07905142009258, 54.25134189426899, 56.25464379787445, 55.42820334434509, 56.42216540873051, 53.76450061798096, 56.24387137591839, 55.83691321313381, 55.91757528483868, 54.11880500614643, 53.49680118262768, 43.723125234246254, 40.7576959580183, 40.62464229762554, 45.407191067934036, 53.186848014593124, 57.717960476875305, 54.3998759239912, 60.99329732358456, 53.75400558114052, 57.21189223229885, 52.341541573405266, 59.58111450076103, 39.8824243247509, 26.434193551540375, 54.094702899456024, 51.32477693259716, 58.638882860541344, 52.036607936024666, 56.83795429766178, 54.5198392868042, 58.48611205816269, 54.60732199251652, 56.63861319422722, 55.40867619216442, 48.826562985777855, 38.13667640089989, 45.34264013171196, 53.75351160764694, 55.91269254684448, 48.94095964729786, 51.98659881949425, 52.039624974131584, 54.77908417582512, 54.346325397491455, 50.37578545510769, 47.16234348714352, 42.25722849369049, 40.0264859944582, 45.225781202316284, 48.38745854794979, 49.275474697351456, 45.368292555212975, 42.23039053380489, 44.580712616443634, 50.25074936449528, 49.92685094475746, 54.47393395006657, 53.06732922792435, 56.2961907684803, 57.310287952423096, 57.51901835203171, 52.45676279067993, 52.20686919987202, 34.38008397817612, 28.35665289312601, 10.620728395879269, 8.228871691972017, 8.634730763733387, 4.711130652576685, 7.97521535307169, 6.762446304783225, 1.988426058087498, 0.4387820785632357, 0.14146191155305132, 0.03343188262078911, 0.045694934160565026, 2.914891275577247, 19.53557062894106, 46.35975815355778, 49.41790625452995, 35.83354398608208, 35.38282357156277, 41.28065429627895, 50.10456740856171, 46.764246448874474, 20.98880834877491, 1.055013625882566, 0.05851087087648921, 0.050372264231555164, 0.02889044535550056, 0.037043603661004454, 0.061265611730050296, 0.0620433936273912, 0.04323953857237939, 0.004492512107390212, 0.01081562051695073, 0.07469668867997825, 0.006260276331886416, 0.010824810160556808, 0.01424433350621257, 0.03050935145438416, 0.04542071801552083, 0.05133715269039385, 0.017730245672282763, 0.033415384677937254, 0.07107166093192063, 0.024944579745351803, 0.01762220010277815, 0.05270219604426529, 0.05382057177484967, 0.032102410405059345, 0.05814174888655543, 0.05874482179933693, 0.031463142950087786, 0.033067154145101085, 0.030929206659493502, 0.041826593296718784, 0.022487440110126045, 0.026560526530374773, 0.028888480519526638, 0.04113776893063914, 0.008327322739205556, 0.022162542700243648, 0.010050623041024664, 0.05836926538904663, 0.05417003427282907, 0.058410925848875195, 0.03495685137750115, 0.019969453642261215, 0.005935392373430659, 0.05442628673336003, 0.02991433641000185, 0.05762018605310004, 0.2808911103056744, 18.31842754036188, 51.09709694981575, 58.54894928634167, 47.396076545119286, 35.354841873049736, 40.93224339187145, 36.48335851728916, 42.985128834843636, 41.27376526594162, 32.23001874983311, 11.328160185366869, 0.5741206929087639, 0.06728431064402685, 0.13180648122215644, 1.6991124325431883, 5.221754852682352, 9.26124969497323, 7.16504467651248, 9.616235196590424, 16.777566522359848, 8.94692961126566, 25.642209649086, 40.16132935881615, 50.44445537030697, 59.99773554503918, 62.589823454618454, 62.526959627866745, 55.647181794047356, 56.66649229824543, 57.943968549370766, 53.52967321872711, 57.95272707939148, 57.50669941306114, 54.18328374624252, 48.14437039196491, 46.663498654961586, 45.25783248245716, 45.82066588103771, 50.73095999658108, 54.4580963999033, 54.607029408216476, 58.41946363449097, 57.532272040843964, 59.17371556162834, 57.97902166843414, 58.55987749993801, 55.399032309651375, 56.78396679461002, 54.1583950817585, 56.941092163324356, 56.41481660306454, 55.36996006965637, 45.6171640008688, 42.97218292951584, 42.557526379823685, 46.8672551214695, 54.96015585958958, 59.69516538083553, 56.68888069689274, 62.411324232816696, 56.82041443884373, 59.992529824376106, 53.48527640104294, 58.87326568365097, 40.88224187493324, 29.176785685122013, 54.372069016098976, 51.872255355119705, 59.813323840498924, 53.50682504475117, 58.29145610332489, 56.38461962342262, 59.995710253715515, 55.76980501413345, 57.38954409956932, 58.20713862776756, 49.372460693120956, 39.59630727767944, 47.70742803812027, 57.47780196368694, 56.92343831062317, 50.20900100469589, 51.894567757844925, 52.42522068321705, 56.66480138897896, 57.10797160863876, 52.97241412103176, 49.15038920938969, 44.05863203108311, 42.36567847430706, 48.04845593869686, 52.56610572338104, 51.920185983181, 48.744867369532585, 43.59327860176563, 47.069275081157684, 51.48872673511505, 52.121012806892395, 56.85317248106003, 55.88435746729374, 57.76988849043846, 59.062567725777626, 58.53368170559406, 55.774668753147125, 50.450755432248116, 40.09137511253357, 28.069654293358326, 11.466107033193111, 6.861593909561634, 8.941405657678843, 10.797338169068098, 12.590485699474812, 8.177813831716776, 5.297288149595261, 1.7957091866992414, 0.37128751748241484, 0.15121160948183388, 0.06498872913653031, 3.130116001702845, 22.304470650851727, 39.26341854035854, 40.46540804207325, 32.225481793284416, 35.28022147715092, 46.13782726228237, 52.91922837495804, 54.46471184492111, 27.56556574255228, 1.9979705521836877, 0.09801007792702876, 0.038231815487961285, 0.028522126740426756, 0.040124087972799316, 0.048700695333536714, 0.050954211910720915, 0.07720559311565012, 0.009421407048648689, 0.06520618582726456, 0.03481163534161169, 0.0483850747696124, 0.03156077989842743, 0.046302218761411496, 0.02685446339455666, 0.006207228543644305, 0.021975554882374126, 0.05841236561536789, 0.021773668449895922, 0.05376070272177458, 0.04890118652838282, 0.020498462072282564, 0.07030466615105979, 0.027531571104191244, 0.03992666184785776, 0.08619073050795123, 0.11454631559900008, 0.08564047995605506, 0.13124151388183236, 0.10736320924479514, 0.14547008788213134, 0.14238002244383097, 0.10249318424030207, 0.13706039695534855, 0.13887643232010305, 0.15995335212210193, 0.17952783848159015, 0.09944983699824661, 0.1353046833537519, 0.12679870618740097, 0.12263025564607233, 0.12720770377200097, 0.09794704732485116, 0.16129095456562936, 0.149208597431425, 0.11833897966425866, 0.13282202125992626, 0.4633216664660722, 24.242866337299347, 63.393396735191345, 66.64310395717621, 55.26511609554291, 43.76031003892422, 47.74536520242691, 47.718949019908905, 46.13511420786381, 52.16894343495369, 45.48396594822407, 13.848930671811104, 0.817054957151413, 0.22968197066802531, 0.22911669162567705, 1.4722552243620157, 6.359103173017502, 11.364355143159628, 11.149101443588734, 19.41175427287817, 26.085205078125, 18.838207349181175, 42.348917573690414, 52.93120913207531, 54.75844748318195, 62.63161361217499, 65.16358494758606, 64.63850632309914, 56.28241270780563, 57.87436008453369, 58.80132034420967, 53.18843632936478, 59.82116661965847, 60.10053142905235, 56.94575451314449, 50.87497986853123, 49.53020542860031, 46.41940735280514, 48.28511863946915, 53.71124267578125, 58.64862933754921, 58.10621604323387, 60.80860823392868, 58.93926054239273, 59.96789574623108, 61.015290543437004, 59.1627911478281, 55.642337054014206, 58.20330463349819, 56.816158667206764, 58.21424804627895, 58.04082155227661, 58.13932366669178, 48.440465703606606, 44.441271498799324, 45.08534073829651, 50.04310190677643, 58.430122062563896, 61.04512274265289, 60.23493021726608, 64.43546801805496, 59.72424142062664, 61.71095721423626, 55.49055799841881, 59.71968166530132, 42.73645877838135, 32.418044060468674, 53.61203379929066, 53.80122184753418, 61.60392075777054, 57.90344372391701, 60.85514433681965, 58.749700114130974, 61.9025619328022, 58.451328724622726, 58.82994040846825, 61.466748118400574, 52.12179936468601, 41.85178644955158, 50.4065828025341, 58.15138801932335, 58.840606436133385, 49.36845190823078, 52.67772853374481, 53.440469205379486, 59.1783133149147, 58.80609668791294, 55.459779649972916, 51.17293328046799, 47.93309412896633, 44.03736837208271, 48.49254950881004, 55.32669939100742, 53.744517490267754, 48.671231120824814, 46.002033948898315, 49.0021363645792, 55.30413620173931, 54.38574828207493, 59.8046413064003, 56.79439343512058, 62.20002897083759, 61.170595809817314, 60.47283925116062, 55.2907495200634, 54.417225793004036, 38.6841244250536, 32.066049948334694, 16.354848705232143, 15.436690673232079, 17.821429409086704, 15.9395157918334, 20.043517872691154, 18.224694170057774, 7.570957895368338, 1.1943671107292175, 0.8115789166186005, 0.1803947114967741, 0.23018341016722843, 4.260751269757748, 27.022098004817963, 61.48483894765377, 61.23535193502903, 47.26092539727688, 46.26522682607174, 54.98389698565006, 63.51234555244446, 60.042375549674034, 34.60339039564133, 2.6791678369045258, 0.12317234999500215, 0.11934845635551028, 0.14227202511392534, 0.1559953301330097, 0.17508629243820906, 0.12920949870022014, 0.13369670166866854, 0.12328671495197341, 0.10402716638054699, 0.17213907558470964, 0.13605230808025226, 0.15152040228713304, 0.12480743491323665, 0.09252127987565473, 0.20793971547391266, 0.0956039312586654, 0.2257047122111544, 0.13369404477998614, 0.16051995218731463, 0.13034293631790206, 0.06470703956438228, 0.137209999084007, 0.1437216770136729, 0.09060584867256694], [0.004981213105565985, 0.12230684253154323, 0.010778217201732332, 0.04971127040334977, 0.14178093115333468, 0.05287365442200098, 0.06745369100826792, 0.033421088082832284, 0.030517726590915117, 0.01954166487848852, 0.031531320346402936, 0.08348960982402787, 0.07483026041882113, 0.030338407013914548, 0.03135968014248647, 0.044909233547514305, 0.019640149730548728, 0.0711497497104574, 0.030145220407575835, 0.020062819530721754, 0.05350593084585853, 0.04834716957702767, 0.3990158170927316, 21.373666897416115, 48.95650841295719, 48.593806475400925, 41.88703715801239, 21.95265892893076, 17.934615835547447, 33.006362691521645, 27.99340758472681, 33.549832329154015, 26.08819741755724, 3.117071301676333, 0.253890827880241, 0.0833891675574705, 0.3257529577240348, 1.1752580548636615, 3.2733438536524773, 6.74669804982841, 9.962123986333609, 9.557168316096067, 19.299439899623394, 17.292248904705048, 35.16382612287998, 44.990319237113, 52.205740660429, 58.655134588479996, 59.124033227562904, 58.238182961940765, 55.626807287335396, 55.383536741137505, 54.19354699552059, 53.32823842763901, 56.078701838850975, 55.03095746040344, 53.026956394314766, 50.936616361141205, 48.68616431951523, 46.76816023886204, 50.60276247560978, 52.77992784976959, 55.082102715969086, 57.72161968052387, 55.28178580105305, 53.63211952149868, 55.1977951079607, 52.442840337753296, 54.804660603404045, 52.88662612438202, 55.44978238642216, 53.21929067373276, 55.73781453073025, 55.08102357387543, 50.54128557443619, 39.91169795393944, 41.45716242492199, 37.990467846393585, 48.792691603302956, 54.214962646365166, 56.9220931828022, 53.67864802479744, 51.700116991996765, 48.6442943662405, 56.45106665790081, 47.37388573586941, 58.481563702225685, 35.04579305648804, 22.377728819847107, 59.18734163045883, 50.877122953534126, 58.62689450383186, 50.94067454338074, 53.66541713476181, 51.14177115261555, 54.890634790062904, 56.59334622323513, 57.287956550717354, 55.28533101081848, 50.61446204781532, 36.920935437083244, 43.793554455041885, 53.15730839967728, 55.72155900299549, 52.89690837264061, 52.02625349164009, 51.17823779582977, 54.48402240872383, 57.05567121505737, 52.479386776685715, 49.026363864541054, 42.85050205886364, 40.121127516031265, 39.66906197369099, 39.45592001080513, 40.57447358965874, 39.663719460368156, 40.64217835664749, 44.14102301001549, 46.643397733569145, 49.11161608994007, 50.16532614827156, 53.043018132448196, 53.73233914375305, 54.8967220634222, 56.20973780751228, 56.119150668382645, 58.9725049585104, 48.801678121089935, 36.46402135491371, 30.356829464435577, 16.3774061948061, 8.972893618047237, 6.489158319309354, 13.796448837965727, 6.308455690741539, 3.4053862933069468, 2.102558040060103, 0.28697511821519583, 0.11467964985058643, 0.06108670961111784, 0.40322866290807724, 10.22061936557293, 49.97066259384155, 67.20820963382721, 45.216597095131874, 31.689400859177113, 42.031345814466476, 49.03471581637859, 46.37462295591831, 26.149805411696434, 4.653232684358954, 0.09948435428668745, 0.07865629144362174, 0.06704878265736625, 0.044699513746309094, 0.013865492164768511, 0.032243848909274675, 0.02483453408785863, 0.08621745524578728, 0.06715274270391092, 0.03268156018748414, 0.07705052135861479, 0.0295128085417673, 0.03693737635330763, 0.027294356586935464, 0.03978720116720069, 0.08765676902839914, 0.013699767805519514, 0.03660086433228571, 0.08693615105585195, 0.01862542048911564, 0.03524726489558816, 0.03798992729571182, 0.035133189376210794, 0.06642024294706061, 0.03622056930908002, 0.016017893904063385, 0.019569903597584926, 0.007061644610075746, 0.038624619410256855, 0.06821791757829487, 0.05250134490779601, 0.0226616500003729, 0.007187752198660746, 0.06129248118668329, 0.050074625905836, 0.07052839398966171, 0.07797382728313096, 0.03724623966263607, 0.0173086909489939, 0.03306791484646965, 0.01900547245895723, 0.07627424973179586, 0.019835592465824448, 0.023112642011255957, 0.07335963542573154, 0.03834556817309931, 0.6293249025475234, 25.89199684560299, 57.80551537871361, 56.39653578400612, 50.15134669840336, 28.231647200882435, 24.769974052906036, 39.089532271027565, 28.618620336055756, 36.58278778195381, 29.372260496020317, 4.073946168646216, 0.27565421944018453, 0.11526995411259122, 0.4617899627191946, 2.457844438031316, 7.727309055626392, 9.171127080917358, 13.781274352222681, 10.062803383916616, 12.805527560412884, 15.695677176117897, 33.6640390008688, 46.27391695976257, 54.68313932418823, 60.3448773175478, 61.40173360705376, 57.555804178118706, 57.001778706908226, 55.91435685753822, 54.39019024372101, 53.92387926578522, 58.66455428302288, 58.213769271969795, 54.79109153151512, 51.896840035915375, 50.53510710597038, 48.36703464388847, 51.96412682533264, 54.707306027412415, 56.86315454542637, 57.88697920739651, 57.40682177245617, 54.16191749274731, 56.35566137731075, 53.74362453818321, 55.54313577711582, 54.884520918130875, 56.39853447675705, 52.54460647702217, 57.9307908564806, 56.97073057293892, 52.83619523048401, 41.58021122217178, 43.61291214823723, 40.45262552797794, 51.58517315983772, 55.669801980257034, 58.61230328679085, 55.63182681798935, 55.485135689377785, 51.89204089343548, 57.786732986569405, 48.65233853459358, 58.30642729997635, 36.278902888298035, 24.14993852376938, 58.07179369032383, 51.1840932816267, 60.135956928133965, 53.52360114455223, 56.72963351011276, 52.28491321206093, 56.55065931379795, 57.51898035407066, 59.06496539711952, 56.586643382906914, 52.9553834348917, 38.68605092167854, 46.01167023181915, 56.062339916825294, 57.40540824830532, 53.62478591501713, 52.58603185415268, 52.53370866179466, 55.73611602187157, 57.38362781703472, 54.06563065946102, 50.57812839746475, 44.95391719043255, 41.177334040403366, 41.16178907454014, 40.826574862003326, 42.79392309486866, 41.930860206484795, 43.48521240055561, 47.142386958003044, 49.34639409184456, 50.26378646492958, 52.70822949707508, 56.66937634348869, 55.114370584487915, 57.984493374824524, 57.9924463480711, 57.66507491469383, 60.460896492004395, 49.1130980104208, 36.84710919857025, 30.63503723591566, 11.59480707719922, 10.670009851455688, 11.545779258012772, 11.243939604610205, 8.912819791585207, 7.234121644869447, 2.551693939603865, 0.46089727780781686, 0.32818948791828007, 0.04792055711732246, 0.8276777027640492, 11.314285229891539, 49.632955715060234, 66.07726112008095, 47.52001449465752, 41.3510949164629, 48.41266639530659, 54.668795093894005, 54.1387577354908, 31.894891932606697, 5.769546283408999, 0.09897394222207367, 0.013840913161402568, 0.01646775042900117, 0.006532266497742967, 0.031248806990333833, 0.062202491535572335, 0.052883469325024635, 0.05260298574285116, 0.029672476048290264, 0.013384626854531234, 0.01521807393146446, 0.1156870336853899, 0.035963025511591695, 0.015836438797123265, 0.05069153616204858, 0.03268399814260192, 0.02584102920081932, 0.04729998065158725, 0.016729596827644855, 0.02422214536636602, 0.06285766692599282, 0.02698208310903283, 0.05140984976605978, 0.023992851420189254, 0.08882220805389807, 0.19578780425945297, 0.10720933976699598, 0.137214956630487, 0.23945497203385457, 0.11776630883105099, 0.19305218855151907, 0.17861523432657123, 0.07784408502629958, 0.12385751557303593, 0.17776954220607877, 0.18378312030108646, 0.11578070756513625, 0.19934243930038065, 0.12124842120101675, 0.12877207685960457, 0.289864536607638, 0.21398104989202693, 0.085606764187105, 0.1350841615931131, 0.18633607862284407, 0.13448180485283956, 1.0421837330795825, 36.832517981529236, 67.43597701191902, 64.73851695656776, 56.887401044368744, 32.90482074022293, 28.087292946875095, 42.80514769256115, 36.22041642665863, 44.97816748917103, 34.215814992785454, 4.37422220595181, 0.5254203686490655, 0.22418118693167344, 0.6812143244314939, 2.9715042002499104, 10.131668988615274, 17.659172415733337, 22.951718419790268, 19.32709291577339, 28.57996691018343, 23.481140211224556, 43.26303452253342, 55.10555125772953, 58.08640770614147, 64.65038448572159, 61.61644868552685, 59.585643857717514, 57.21677877008915, 56.40472434461117, 53.84657621383667, 53.70836243033409, 59.63859401643276, 60.88224068284035, 57.412836849689484, 56.19410164654255, 53.898519426584244, 51.60604164004326, 53.43525588512421, 57.14525520801544, 58.06041330099106, 60.75564667582512, 58.406358137726784, 56.415861546993256, 55.225298032164574, 53.825475946068764, 54.95062597095966, 55.44137343764305, 56.93686679005623, 54.645718932151794, 58.79282779991627, 60.711044669151306, 54.8425255715847, 44.51672405004501, 46.296282559633255, 41.705239713191986, 52.73308016359806, 59.14535768330097, 61.31152264773846, 58.11523675918579, 56.20806969702244, 53.046703934669495, 57.473508194088936, 48.61917391419411, 58.27444441616535, 37.77736388146877, 27.43070337921381, 56.99304297566414, 55.522514283657074, 62.9849224537611, 55.07737576961517, 58.50756950676441, 53.33648778498173, 57.873136550188065, 60.91904930770397, 61.32532350718975, 59.1704211384058, 54.807472452521324, 41.25591762363911, 49.59310345351696, 59.09712307155132, 60.087566524744034, 53.30399572849274, 53.648356050252914, 52.53606453537941, 56.875002309679985, 60.64664572477341, 55.54592862725258, 53.92427824437618, 46.50220490992069, 43.84512908756733, 42.901673913002014, 43.08441370725632, 44.92957189679146, 44.51716862618923, 45.540252327919006, 48.97352769970894, 51.46470822393894, 53.17869745194912, 55.614853128790855, 57.77002528309822, 58.29975105822086, 60.5156097561121, 61.29590168595314, 58.40957656502724, 61.0299501568079, 54.57749739289284, 43.52323696017265, 35.18229693174362, 23.065191730856895, 22.479401864111423, 17.753177471458912, 22.948294803500175, 13.817943334579468, 10.116422306746244, 5.313006481155753, 0.7236888015177101, 0.4109003028133884, 0.28706322598736733, 0.7645423093345016, 13.870109785348177, 60.71597680449486, 73.55286598205566, 57.45118819177151, 45.868338122963905, 54.72413532435894, 61.55398003757, 60.25699183344841, 39.33970704674721, 9.184259176254272, 0.25108191766776145, 0.2096662626718171, 0.14011970779392868, 0.1622525107813999, 0.08355240293894894, 0.2161685746978037, 0.15369784872746095, 0.15178031724644825, 0.14544274716172367, 0.09356790847959928, 0.1566352098598145, 0.254083281615749, 0.10019417401053943, 0.08715196017874405, 0.20154140802333131, 0.13385630794800818, 0.11090291227446869, 0.1708327472442761, 0.16644242423353717, 0.10894734572502784, 0.1912581207579933, 0.12138126563513651, 0.12927863717777655, 0.13797010673442855], [0.06497965267044492, 0.01948316323250765, 0.03873497676977422, 0.03250283618399408, 0.057126145766233094, 0.03689119992486667, 0.04329982693889178, 0.04390582020278089, 0.045835441269446164, 0.1148780704534147, 0.008673756346979644, 0.06894635036587715, 0.013090207594359526, 0.056948434794321656, 0.03468138100288343, 0.02165173729736125, 0.03400269808480516, 0.022817347016825806, 0.05610489490209147, 0.07125273754354566, 0.03720871296536643, 0.06364264394505881, 2.4947478203102946, 32.917447462677956, 49.67781610786915, 43.25663186609745, 40.2156550437212, 36.03404402732849, 26.989463455975056, 19.44780293852091, 27.04120147973299, 40.73349505662918, 10.474923569709063, 1.2859974126331508, 0.05484300265379716, 0.2113942793221213, 0.1435663306619972, 2.3912335373461246, 9.01031780987978, 8.533358853310347, 5.444136019796133, 5.189699297770858, 17.791589610278606, 19.52396795153618, 36.92791946232319, 51.26330003142357, 57.60629966855049, 58.13569486141205, 57.90041908621788, 57.4209950119257, 54.8311185836792, 54.172059148550034, 57.52985157072544, 52.361194118857384, 55.49206271767616, 54.14960615336895, 55.789100378751755, 52.44312532246113, 51.62326991558075, 49.92086246609688, 50.9957829862833, 54.8709100484848, 57.22416937351227, 52.7849967777729, 51.86571590602398, 52.54295736551285, 52.99300141632557, 53.175228238105774, 51.97539322078228, 53.39306674897671, 54.32137593626976, 54.61629331111908, 56.104377061128616, 53.13501879572868, 46.290639862418175, 39.0870776027441, 42.18784801661968, 40.19601009786129, 48.45324441790581, 50.941419303417206, 57.05695554614067, 52.37245291471481, 57.030273377895355, 53.409949243068695, 57.722212448716164, 46.77992060780525, 57.645122185349464, 34.829919040203094, 21.417940221726894, 57.80303791165352, 52.85273194313049, 54.32800278067589, 50.299170166254044, 48.05942974984646, 43.9102727919817, 48.40758226811886, 52.61133089661598, 55.68823479115963, 54.3016891926527, 49.1667777299881, 39.29109625518322, 44.23941493034363, 50.22823937237263, 56.10827945172787, 52.73631379008293, 51.0224499553442, 50.289533883333206, 54.41460773348808, 52.80067093670368, 53.530448377132416, 50.5203714966774, 47.52448685467243, 41.47170424461365, 40.19304245710373, 39.551777467131615, 41.18714511394501, 40.860890820622444, 42.872544676065445, 46.27672120928764, 49.18131574988365, 51.36161595582962, 53.098764941096306, 51.69201582670212, 53.96455988287926, 54.22846332192421, 57.22895331680775, 60.051430463790894, 55.571128875017166, 54.52782265841961, 38.7168824672699, 26.853235065937042, 11.27874193713069, 7.70076890476048, 9.22062512487173, 7.506397459656, 5.763497008010745, 4.9668659549206495, 2.853346453048289, 0.6076740205753595, 0.14771208632737398, 0.010751861682365416, 0.16426812449935824, 4.3929647002369165, 29.00755226612091, 39.3395284563303, 21.82813961058855, 21.92247334867716, 38.00310216844082, 40.013688281178474, 46.46013356745243, 39.68817114830017, 11.037509981542826, 0.1647099992260337, 0.05037011200329289, 0.09322819780209102, 0.07078576338244602, 0.054734014556743205, 0.024618018069304526, 0.07578286633361131, 0.13391671876888722, 0.10573055114946328, 0.05312170986144338, 0.028493218233052175, 0.024949322069005575, 0.06658941550995223, 0.03381543938303366, 0.043354155859560706, 0.009271266862924676, 0.040587856055935845, 0.08626345355878584, 0.06002075177093502, 0.04963628380210139, 0.06928502945811488, 0.06640808656811714, 0.04693373819463886, 0.017741056908562314, 0.06541704482515343, 0.04990667417587247, 0.032989039391395636, 0.05001539881050121, 0.05973668732622173, 0.05516321340110153, 0.04545013674942311, 0.01218102288476075, 0.04542811351711862, 0.0364420484402217, 0.05000675650080666, 0.015120771877263905, 0.028350284301268402, 0.05634981847833842, 0.01087077785996371, 0.047234337689587846, 0.09872964947135188, 0.04904686640657019, 0.11237131082452834, 0.09399742644745857, 0.05230401526205242, 0.07345080826780759, 3.6030139261856675, 39.423192366957664, 57.752090245485306, 49.82688590884209, 45.7190365344286, 35.30654266476631, 26.706063263118267, 27.3195593431592, 25.415567010641098, 36.78190469741821, 12.989971563220024, 1.1808054009452462, 0.08456632509478368, 0.10854528722120449, 0.2918591327033937, 4.2283879313617945, 7.404143046587706, 15.479805059731007, 11.522616650909185, 9.19586755335331, 15.10765777900815, 22.441688887774944, 34.31391812860966, 50.423776879906654, 56.89830265939236, 61.18372790515423, 59.60729889571667, 58.637967109680176, 56.28335505723953, 54.50336717069149, 56.30709618330002, 51.042965054512024, 55.46792261302471, 56.52868889272213, 57.919288873672485, 54.684127271175385, 54.41460773348808, 52.04007335007191, 52.93756239116192, 57.05824747681618, 58.881560638546944, 55.3043831884861, 52.96216607093811, 53.20891723036766, 53.406544625759125, 52.15975932776928, 51.83079957962036, 53.82781282067299, 55.49131415784359, 54.006722420454025, 59.021396934986115, 55.409082770347595, 47.67527036368847, 41.06767952442169, 44.07426059246063, 42.68594428896904, 50.18424153327942, 52.147930562496185, 58.57766814529896, 55.21678268909454, 58.58622148633003, 55.27904234826565, 57.90183641016483, 47.20976874232292, 58.04598167538643, 35.07358096539974, 22.923985607922077, 57.892800495028496, 53.462386429309845, 56.55381314456463, 52.212595492601395, 48.67560088634491, 46.10083244740963, 51.0600071400404, 55.271587148308754, 57.772901728749275, 57.5256983935833, 51.59939959645271, 40.79264648258686, 45.74026219546795, 52.79546141624451, 56.761038824915886, 53.754560351371765, 51.67539931833744, 50.34237764775753, 54.817161932587624, 54.85433153808117, 56.159052327275276, 51.99397422373295, 49.74565766751766, 43.83288994431496, 41.826981380581856, 41.82956524193287, 43.16511757671833, 42.91130259633064, 45.27775481343269, 48.01191329956055, 51.46625854074955, 52.92829088866711, 54.604240357875824, 53.237115517258644, 55.280824452638626, 57.13480956852436, 58.92011716961861, 60.14238238334656, 56.969955414533615, 56.46154649555683, 41.26581609249115, 29.513519816100597, 13.064757250249386, 7.303358679637313, 13.121382761746645, 8.299633394926786, 7.922139326110482, 8.783288542181253, 6.3007307052612305, 2.3209323221817613, 0.5710932053625584, 0.04374564618046861, 0.04977634562237654, 4.7838967479765415, 31.975686997175217, 46.72484256327152, 29.84533131122589, 28.078196235001087, 45.68503215909004, 45.894362926483154, 51.914847269654274, 45.992416664958, 14.965404812246561, 0.4549453721847385, 0.05881088778551202, 0.026849910318560433, 0.023305685754166916, 0.10163034850847907, 0.04041849424538668, 0.034064752762787975, 0.07302050362341106, 0.04841854934056755, 0.04727817635284737, 0.013898629058530787, 0.019409918822930194, 0.025891493387462106, 0.01197369558212813, 0.03411489597056061, 0.026552884264674503, 0.03510426417051349, 0.009893754358927254, 0.05459368556330446, 0.014877601624903036, 0.10049374934169464, 0.0402505536476383, 0.01564988513564458, 0.02864181104087038, 0.13573177449870855, 0.14220119453966618, 0.10653964796802029, 0.13446648692479357, 0.2624079224187881, 0.14258889248594642, 0.14041337562957779, 0.07595482195029035, 0.1396307215327397, 0.23397112410748377, 0.10913132413406856, 0.14173352275975049, 0.10186114901443943, 0.1495660305954516, 0.1473196831648238, 0.11124421856948175, 0.12196087554912083, 0.15957484196405858, 0.16743993008276448, 0.1813112638774328, 0.15813201782293618, 0.1189410469669383, 4.594897264614701, 47.189432233572006, 65.40848180651665, 58.60384114086628, 53.643032535910606, 49.313685446977615, 37.69115410745144, 31.98682799935341, 39.65056076645851, 52.47519180178642, 15.343380030244589, 1.717245653271675, 0.3350139217218384, 0.4072649369481951, 0.8589760295581073, 7.272479636594653, 14.521804265677929, 18.404622115194798, 16.297927759587765, 13.060866259038448, 24.810027703642845, 25.104756988584995, 41.743784844875336, 55.11103056371212, 59.89799089729786, 61.56722232699394, 62.215687930583954, 60.284471958875656, 56.441741958260536, 54.30956616997719, 58.604471907019615, 51.76269203424454, 55.23826293647289, 57.626522183418274, 62.02144615352154, 57.81241960823536, 55.34922078251839, 54.10477235913277, 54.694048538804054, 58.529824912548065, 60.15582986176014, 57.060842737555504, 53.152315467596054, 52.38836646080017, 53.726666048169136, 53.23513962328434, 52.226407751441, 54.11729648709297, 55.96683584153652, 56.268676444888115, 61.79286561906338, 58.63133646547794, 50.10575674474239, 42.59565733373165, 45.845303758978844, 44.109754487872124, 53.13371166586876, 53.87537106871605, 60.94036616384983, 57.48024143278599, 60.818704292178154, 56.6874747723341, 59.580696523189545, 49.20387513935566, 57.906494960188866, 38.79156745970249, 26.295153312385082, 58.477026745676994, 55.17963208258152, 57.17688471078873, 54.047437235713005, 51.771693751215935, 48.595949560403824, 52.49773219227791, 57.017076686024666, 59.997389763593674, 60.89187316596508, 54.118474423885345, 43.17820407450199, 46.95533439517021, 54.08185958862305, 59.38570238649845, 56.48474045097828, 51.731811091303825, 51.95216506719589, 56.215733885765076, 56.186304464936256, 57.99466162919998, 55.477194115519524, 51.61897614598274, 45.775383710861206, 44.203655049204826, 44.39047582447529, 45.914669036865234, 44.89638827741146, 47.819073647260666, 50.72798855602741, 53.207017332315445, 56.32780507206917, 58.202818259596825, 56.648720651865005, 58.274653404951096, 59.576117768883705, 60.56533768773079, 63.42933900654316, 58.625507578253746, 61.0187179595232, 42.9266157746315, 31.66702575981617, 16.886415481567383, 13.43909416347742, 15.068418234586716, 13.975455332547426, 18.826372884213924, 16.60371635109186, 6.667884103953838, 2.0378339756280184, 0.7721200527157634, 0.19136260030791163, 0.5301208351738751, 6.224490171298385, 34.501704052090645, 51.68870620429516, 36.68655261397362, 32.945204973220825, 50.827163234353065, 53.4265923500061, 60.90665057301521, 55.53990215063095, 19.78693664073944, 0.6673817010596395, 0.11912259113159962, 0.17339418089250103, 0.18464316555764526, 0.16230189328780398, 0.13997151574585587, 0.2012697226018645, 0.22642389783868566, 0.1756685072905384, 0.1852172167855315, 0.08042209825362079, 0.08496781956637278, 0.10511180036701262, 0.10247534301015548, 0.0699410805827938, 0.11058896154281683, 0.1987380045466125, 0.178536715102382, 0.19120933196973056, 0.10998340614605695, 0.24050205334788188, 0.11725778924301267, 0.0978571361338254, 0.11429431193391792], [0.03708490417920984, 0.032230824217549525, 0.012038329223287292, 0.013329955618246458, 0.031963127839844674, 0.0165503848620574, 0.03433063830016181, 0.0600135640706867, 0.045072992143104784, 0.022341021795000415, 0.043530445618671365, 0.03711619312525727, 0.014927787506167078, 0.07113504034350626, 0.06380789054674096, 0.015199679801298771, 0.03792926043388434, 0.012672251359617803, 0.09101906907744706, 0.08232543244957924, 0.03840781209873967, 0.01927409652125789, 6.575714824721217, 35.9671638160944, 51.444208323955536, 41.456660851836205, 44.61627870798111, 56.120780780911446, 20.40717925876379, 21.94436777383089, 42.206235229969025, 30.374348424375057, 7.239400986582041, 0.0731641537277028, 0.01839068288973067, 0.12435068012564443, 0.25377882295288146, 2.7964395191520452, 6.739371567964554, 8.962446078658104, 11.716832779347897, 8.289018664509058, 19.145422764122486, 29.83813639730215, 41.797791346907616, 51.43127761781216, 57.2979462146759, 56.92703291773796, 58.64579848945141, 53.443239256739616, 54.953722804784775, 55.76733514666557, 52.211128771305084, 51.976153180003166, 52.31427803635597, 54.22538548707962, 54.998184219002724, 55.457644164562225, 55.846606492996216, 52.208427116274834, 53.53109434247017, 53.82197253406048, 52.32856526970863, 51.52643971145153, 51.20475277304649, 53.0182396620512, 55.12062884867191, 56.77555024623871, 56.6944245994091, 56.339052468538284, 54.8492132127285, 52.92813889682293, 54.91970703005791, 49.85816203057766, 42.1071707457304, 37.8879227489233, 41.501354053616524, 40.817991122603416, 43.31403158605099, 47.00387679040432, 55.18385365605354, 52.680509984493256, 56.07755430042744, 51.97478525340557, 57.563950940966606, 50.44660985469818, 58.49165976047516, 34.715396985411644, 24.753078259527683, 58.42242747545242, 52.97515757381916, 57.334716841578484, 49.674590080976486, 51.11743725836277, 45.909850895404816, 42.85390667617321, 40.66476434469223, 47.938482239842415, 47.56413012742996, 43.02951045334339, 39.055668488144875, 40.25977447628975, 48.423503413796425, 53.660010024905205, 54.10732202231884, 50.657099559903145, 51.21112123131752, 52.53184676170349, 53.13917577266693, 54.273213520646095, 51.438839212059975, 46.61473207175732, 44.599517807364464, 45.57274058461189, 47.77615115046501, 51.04086376726627, 50.46794570982456, 48.59994314610958, 51.480625569820404, 50.69136992096901, 52.94151797890663, 52.21642568707466, 57.387944385409355, 54.271078035235405, 58.502948954701424, 54.7406530380249, 60.74879564344883, 54.64188493788242, 50.67295990884304, 43.63299027085304, 35.80796755850315, 15.285965111106634, 6.745714852586389, 15.93358051031828, 7.582294587045908, 4.85810961574316, 8.65247106179595, 3.4381253365427256, 1.5104429377242923, 0.6934790569357574, 0.01413618589140242, 0.05496735691849608, 0.5769586656242609, 13.258449956774712, 36.32430285215378, 36.64921961724758, 25.178742818534374, 31.166016943752766, 35.62636390328407, 44.856190234422684, 48.63876186311245, 20.08668165653944, 1.8149259430356324, 0.042326823095208965, 0.06467504557804205, 0.026229549075651448, 0.03989887954958249, 0.015092093435669085, 0.030352138601301704, 0.0743167387554422, 0.004955974518452422, 0.016212967420869973, 0.03046784313482931, 0.01375484165691887, 0.06596903200261295, 0.04063935368321836, 0.01434589456039248, 0.073441642744001, 0.016947610129136592, 0.028512506651168223, 0.07021431709290482, 0.036749438586412, 0.03538704841048457, 0.005785248013125965, 0.070020490384195, 0.03258781951444689, 0.0363495805504499, 0.017582662185304798, 0.010807222188304877, 0.009002216065709945, 0.07198830237030052, 0.015847476388444193, 0.025712724855111446, 0.01874332177976612, 0.02329578550416045, 0.08312856240081601, 0.0383465218328638, 0.03052858606679365, 0.036863250643364154, 0.10633540892740712, 0.07375225381110795, 0.02703239330003271, 0.012359899028524524, 0.021493205276783556, 0.0297684765610029, 0.0170386809259071, 0.042465875594643876, 0.02106570409523556, 8.63284321501851, 42.48727574944496, 59.10791829228401, 47.552563548088074, 50.3813673555851, 63.263466507196426, 23.899231776595116, 25.085987895727158, 41.011617332696915, 33.160132840275764, 7.7172813937067986, 0.33706082438584417, 0.056385500938631594, 0.618764734826982, 1.3429621746763587, 5.344693930819631, 11.622238755226135, 14.378652647137642, 7.7256713435053825, 5.278566554188728, 16.066466979682446, 27.99527708441019, 39.70716632902622, 55.302475690841675, 60.70453941822052, 59.230837896466255, 60.250478982925415, 54.531865641474724, 55.835218504071236, 55.609715804457664, 54.66934606432915, 54.290612787008286, 54.68801446259022, 54.45101737976074, 56.79567016661167, 56.99273519217968, 57.48427301645279, 53.4367948025465, 54.70957450568676, 55.98288998007774, 54.67469997704029, 52.76787489652634, 51.12583480775356, 52.336731031537056, 55.64219646155834, 57.0947977155447, 57.58158199489117, 58.70248764753342, 56.18604227900505, 54.371837228536606, 57.210600301623344, 51.96078680455685, 44.58931155502796, 39.8916882276535, 43.51635932922363, 42.78695046901703, 46.3515467941761, 49.46619026362896, 56.81911110877991, 53.68578404188156, 57.645844146609306, 55.75982674956322, 59.80402193963528, 50.71979999542236, 58.22180204093456, 35.59829480946064, 26.061270162463188, 58.875097185373306, 53.76259692013264, 60.82894094288349, 51.72093227505684, 53.11723954975605, 47.81051650643349, 43.44670906662941, 43.07755887508392, 50.29883198440075, 48.965464532375336, 44.194786325097084, 42.032466754317284, 43.03497076034546, 50.910291373729706, 57.87562541663647, 55.07095791399479, 51.518433541059494, 50.40266901254654, 54.34838488698006, 55.21825321018696, 56.209490820765495, 53.963640332221985, 49.46212828159332, 46.07611857354641, 46.583680137991905, 49.238126501441, 52.28378467261791, 51.25322677195072, 51.581487357616425, 52.805888056755066, 53.38119998574257, 55.20016998052597, 53.76100480556488, 58.05640451610088, 55.73592223227024, 57.866680696606636, 57.02378712594509, 61.50699935853481, 55.71522854268551, 53.399632796645164, 45.39766877889633, 34.50356975197792, 16.64030648767948, 5.4554033651947975, 14.530620742589235, 7.906645657494664, 9.874122608453035, 6.744644260033965, 6.813414394855499, 3.227127408608794, 1.0451700165867805, 0.19596062076743692, 0.07495279642171226, 0.8257690176833421, 15.200330056250095, 38.62426243722439, 38.47797408699989, 32.997847348451614, 39.05299723148346, 42.12134398519993, 49.13497343659401, 54.984953328967094, 24.700489081442356, 2.523977276869118, 0.12841936375480145, 0.050711384901660495, 0.11110649822512642, 0.021487722660822328, 0.04844930394028779, 0.06061015432351269, 0.021073398311273195, 0.0712539695086889, 0.048768587002996355, 0.04155678550887387, 0.008460605040454539, 0.05431943231087644, 0.007454924434568966, 0.0567081830376992, 0.06703224760713056, 0.005130786939844256, 0.02179643382987706, 0.003115018762400723, 0.05467545910505578, 0.08624512251117267, 0.03106460779235931, 0.045893588539911434, 0.0574085923290113, 0.10250253530102782, 0.13456783461151645, 0.0746153864020016, 0.11091687207226641, 0.14381413377122954, 0.12339999637333676, 0.12196029667393304, 0.10091716685565189, 0.10691659219446592, 0.24019499716814607, 0.1879367872606963, 0.13862753083230928, 0.12258666931302287, 0.18650747020728886, 0.1698749017668888, 0.15675059898057953, 0.17846903123427182, 0.0697912706527859, 0.1658920623594895, 0.21984325954690576, 0.09549899899866432, 0.1534700984484516, 11.127891931682825, 49.74204786121845, 66.52076572179794, 56.38939596712589, 55.56724928319454, 66.63489639759064, 30.22268146276474, 29.932397939264774, 54.24378789961338, 38.72754469513893, 9.912190865725279, 0.5042186938226223, 0.2958116924855858, 0.7162743899971247, 1.6053531761281192, 6.3280341401696205, 15.6942437030375, 16.198884174227715, 22.140359356999397, 16.261592209339142, 21.684364825487137, 37.16979168355465, 44.37543623149395, 56.14354535937309, 61.84351310133934, 62.117227613925934, 60.65628960728645, 56.514219269156456, 57.33292333781719, 55.251771211624146, 53.65617223083973, 54.60227966308594, 57.6029634475708, 56.88761383295059, 57.469203025102615, 61.034217327833176, 61.08469381928444, 57.00336702167988, 57.99985595047474, 58.89840513467789, 56.06710106134415, 51.998062804341316, 51.30562976002693, 53.29437844455242, 56.86630077660084, 60.099015310406685, 59.07576061785221, 60.88550090789795, 57.209802344441414, 56.31198272109032, 59.29524444043636, 54.74362447857857, 47.113462910056114, 40.965294018387794, 45.593707859516144, 45.39709880948067, 47.76837296783924, 53.546297326684, 60.05161665380001, 55.18229953944683, 60.70813402533531, 59.7818311303854, 61.84979036450386, 53.29507380723953, 57.560588121414185, 37.80025005340576, 28.939699307084084, 58.870997205376625, 56.00418023765087, 61.78788408637047, 54.561055675148964, 55.80044277012348, 51.0071861743927, 47.53734156489372, 44.639985635876656, 51.824662908911705, 53.413817435503006, 46.579333171248436, 44.47140388190746, 44.29469056427479, 52.59940333664417, 60.01157060265541, 56.70087285339832, 51.442570611834526, 50.56859090924263, 54.454399198293686, 56.961903646588326, 58.51046875119209, 56.98138900101185, 52.01144948601723, 49.571000039577484, 49.5214506983757, 51.9296170771122, 56.41523078083992, 56.02955907583237, 53.54719787836075, 56.05562947690487, 54.76818636059761, 58.49354445934296, 55.50716310739517, 60.87147206068039, 58.342225179076195, 63.10652352869511, 58.32404315471649, 64.06938046216965, 56.37480095028877, 53.570741415023804, 45.562864914536476, 39.33147668838501, 20.20609024912119, 12.256821803748608, 26.525346860289574, 17.556422129273415, 14.034755900502205, 17.14335959404707, 12.848628647625446, 3.207626142539084, 1.316445297561586, 0.2662173961289227, 0.2500246837735176, 1.220222229603678, 18.78639902919531, 49.00271773338318, 50.80567918717861, 36.9371073693037, 40.76245330274105, 48.54980483651161, 56.52461551129818, 61.14297889173031, 32.38802187144756, 3.8284228183329105, 0.258793396060355, 0.17672151094302535, 0.2166965979267843, 0.09095862114918418, 0.09485479997238144, 0.2160917327273637, 0.13575485529145226, 0.23099028796423227, 0.10329477794584818, 0.12448271561879665, 0.09021564226713963, 0.16630160913337022, 0.16472543589770794, 0.0783416950434912, 0.1256957559962757, 0.09129086582106538, 0.12421408042428084, 0.20576406503096223, 0.19865353329805657, 0.1932943068095483, 0.10427681001601741, 0.14948190073482692, 0.18781930528348312], [0.02357970894081518, 0.007887497267802246, 0.006720713563481695, 0.08328409428941086, 0.026496746359043755, 0.029130201728548855, 0.04989723405742552, 0.030673182409373112, 0.039733061494189315, 0.05884844787942711, 0.10673017211956903, 0.01512069766249624, 0.02631300358189037, 0.023466781894967426, 0.05648556842061225, 0.028834120057581458, 0.05923083204834256, 0.036597494981833734, 0.03356908346177079, 0.047296351549448445, 0.05317166753229685, 0.29199494572822005, 10.76661016792059, 41.83179572224617, 51.19144208729267, 48.977023512125015, 33.73104840517044, 30.08978359401226, 20.922226421535015, 31.45960818976164, 41.065247654914856, 20.290246233344078, 2.281598257832229, 0.05806222034152597, 0.05648281134199351, 0.3379435942042619, 0.35403676971327513, 4.5236278139054775, 5.911193182691932, 21.06061689555645, 8.059665821492672, 10.711089447140694, 24.130779951810837, 31.06096588075161, 44.01852898299694, 59.39428612589836, 58.01842175424099, 56.6117562353611, 54.964210242033005, 54.088984206318855, 55.28299033641815, 50.706637501716614, 56.122813671827316, 47.59611301124096, 49.82547618448734, 53.10512959957123, 53.34179610013962, 51.42900913953781, 54.615620747208595, 53.326254934072495, 52.97491058707237, 50.9272650629282, 54.78019751608372, 51.848905608057976, 51.269501298666, 51.009549647569656, 55.208483934402466, 52.20919467508793, 52.84248769283295, 53.436095640063286, 56.34578950703144, 55.108796283602715, 54.33668911457062, 42.44084984064102, 39.36515048146248, 39.79424625635147, 41.545971259474754, 40.10438561439514, 42.56035342812538, 39.99591663479805, 45.13732194900513, 44.20831359922886, 51.326118260622025, 49.95746210217476, 57.35965870320797, 50.77535681426525, 59.30665522813797, 28.93130175769329, 26.305274069309235, 57.222744449973106, 50.584398061037064, 57.809482365846634, 50.690226182341576, 54.01331126689911, 48.563142120838165, 49.007687866687775, 41.96464039385319, 39.95191119611263, 38.229672610759735, 42.642429023981094, 40.997212305665016, 40.050656497478485, 45.324294716119766, 52.3661832511425, 53.35813142359257, 53.090120404958725, 51.229896023869514, 53.7384682148695, 53.843031004071236, 54.49203237891197, 52.01203465461731, 48.948597237467766, 49.30353619158268, 50.735580548644066, 52.338573932647705, 52.980462089180946, 55.12217156589031, 53.82019802927971, 51.990087032318115, 53.35450641810894, 56.082543432712555, 54.94141146540642, 55.783123299479485, 54.701431542634964, 56.366973370313644, 56.449474543333054, 58.05179536342621, 58.32732617855072, 62.099581360816956, 53.103993460536, 35.13568103313446, 22.3703496158123, 8.866442330181599, 12.718279492110014, 4.605967020615935, 5.476141702383757, 3.3462301176041365, 7.324483171105385, 5.041833557188511, 0.668795759556815, 0.11497772604343481, 0.1465598723734729, 0.24444211536319926, 5.751335285604, 33.60031262040138, 38.69743891060352, 19.354229159653187, 23.185498975217342, 31.73379957675934, 51.63350656628609, 45.200425162911415, 26.594406254589558, 4.663540106266737, 0.1769206885364838, 0.0509063656500075, 0.04637271907995455, 0.019208436860935763, 0.02736371214268729, 0.005131324533067527, 0.0797301420243457, 0.01864934547484154, 0.002122037926710618, 0.047994330307119526, 0.05516339893802069, 0.07595822840812616, 0.02116640240274137, 0.04737717143143527, 0.12784179474692792, 0.03811959904851392, 0.024889846354199108, 0.0803436161368154, 0.04763668934174348, 0.02931161787273595, 0.06924200715729967, 0.023128935863496736, 0.05013126661651768, 0.05577875068411231, 0.06244923337362707, 0.051414298941381276, 0.03845848965283949, 0.02305920181242982, 0.02947521319583757, 0.048133586897165515, 0.06160399025247898, 0.019148458341078367, 0.07820925136911683, 0.03327434322272893, 0.05718525411793962, 0.022832206668681465, 0.048639553497196175, 0.04232188410242088, 0.05455121987324674, 0.06745665217749774, 0.043744525537476875, 0.01448651206374052, 0.09203051246004179, 0.08062154302024283, 0.29852718114852905, 13.37000247091055, 48.6302275210619, 58.47253918647766, 54.20344166457653, 39.6237114071846, 36.93186365067959, 24.760814644396305, 29.75792460143566, 44.13017459213734, 23.75402446836233, 2.6223566103726625, 0.08393351061386056, 0.13652214693138376, 0.27785563725046813, 1.9063942786306143, 6.188914105296135, 14.323486257344484, 15.357592217624187, 7.076414907351136, 9.668215457350016, 16.686855889856815, 29.843429513275623, 46.20241239666939, 59.35073286294937, 59.93484891951084, 57.997975051403046, 56.25215873122215, 54.759880006313324, 56.46704860031605, 52.43785880506039, 54.679822102189064, 50.0583390891552, 53.48862402141094, 53.68079110980034, 53.46878528594971, 53.11234541237354, 57.54059359431267, 55.08565552532673, 54.52048145234585, 54.16892811655998, 54.29340183734894, 52.54511184990406, 51.32317341864109, 53.70016627013683, 56.40215568244457, 55.02197474241257, 55.713647827506065, 56.90377436578274, 58.490823805332184, 57.43208661675453, 56.904587522149086, 45.747341215610504, 40.97017675638199, 41.993089467287064, 43.60095798969269, 42.442533150315285, 44.964503422379494, 41.76110811531544, 47.23611272871494, 47.29189373552799, 53.6774966865778, 52.55043916404247, 59.842943251132965, 51.70961648225784, 58.232445269823074, 30.37246372550726, 26.975922882556915, 56.62605866789818, 51.48317903280258, 59.44127820432186, 52.88153059780598, 54.724097326397896, 51.29613406956196, 52.66278013586998, 43.839972764253616, 43.39625537395477, 40.14923460781574, 44.92524012923241, 42.59688846766949, 41.60688579082489, 47.23119579255581, 54.71396327018738, 55.01570127904415, 53.66947151720524, 51.1168596893549, 51.82866029441357, 54.9297308921814, 56.22788943350315, 53.46544146537781, 51.84012807905674, 50.39040707051754, 52.693748474121094, 54.36143718659878, 55.25765709578991, 57.36866042017937, 57.03426696360111, 53.525911420583725, 55.61886191368103, 57.95581631362438, 57.49541401863098, 56.833189353346825, 56.64753131568432, 58.39658886194229, 58.479667603969574, 58.01575429737568, 57.96139441430569, 61.89445696771145, 53.751079738140106, 36.445972323417664, 23.774334378540516, 8.333142846822739, 12.363820262253284, 9.380520544946194, 8.012658543884754, 10.763497184962034, 10.440251380205154, 4.211746249347925, 2.715573920868337, 0.3149080724688247, 0.1099441984842997, 0.23341331107076257, 7.129597803577781, 35.9579873085022, 42.77910768985748, 21.082456223666668, 27.962367050349712, 37.23639830946922, 58.718701377511024, 51.92122332751751, 32.99192726612091, 6.22576167806983, 0.1549779495690018, 0.028774405000149272, 0.08409574409597553, 0.052128846145933494, 0.048753506562206894, 0.013888078501622658, 0.03791373470448889, 0.03442484652623534, 0.020438283172552474, 0.004891716125712264, 0.03771874282392673, 0.031777750482433476, 0.008153651833708864, 0.02400992267212132, 0.07395188411464915, 0.04628950577171054, 0.0530321363476105, 0.026199983767583035, 0.03989152486610692, 0.08965607776190154, 0.03379770947503857, 0.10250782681396231, 0.057566758841858245, 0.13635488168802112, 0.17602178442757577, 0.23093427065759897, 0.1400786521844566, 0.09042801524628885, 0.1300435687880963, 0.145839276665356, 0.14944319031201303, 0.08488918902003206, 0.20319323579315096, 0.20514820120297372, 0.11836585283163004, 0.0820033106720075, 0.16061484318925068, 0.11820400526630692, 0.15931229980196804, 0.23992314847419038, 0.17184934113174677, 0.10851497048861347, 0.16011794563382864, 0.1675182711915113, 0.7346821459941566, 16.710834503173828, 58.88403430581093, 67.27073907852173, 61.92756839096546, 46.319753900170326, 42.353291139006615, 29.286936074495316, 42.08046197891235, 54.69753295183182, 28.093241527676582, 3.3416466135531664, 0.21801337570650503, 0.1781926554394886, 0.8482824533712119, 1.8783357529900968, 11.77775776013732, 14.961814004927874, 29.607992246747017, 18.470848761498928, 16.32288672029972, 27.689839974045753, 35.3487242013216, 46.23152643442154, 62.82443046569824, 60.4301181435585, 58.43961775302887, 57.74030327796936, 57.059892788529396, 55.12983575463295, 52.77314521372318, 55.59866979718208, 50.773388519883156, 53.679552376270294, 54.22380477190018, 54.17336627840996, 52.48095989227295, 58.640102595090866, 57.51641549170017, 56.35611355304718, 54.62048068642616, 56.360851898789406, 52.40051060914993, 53.78070294857025, 53.92037205398083, 58.95674340426922, 57.75647521018982, 57.60587029159069, 58.893241211771965, 62.17423215508461, 60.23372568190098, 58.701792284846306, 46.388773396611214, 43.445675522089005, 44.31831009685993, 47.16750741004944, 43.75032417476177, 46.3646636903286, 44.55549716949463, 48.18819344043732, 48.646817430853844, 55.3580667078495, 54.118200838565826, 61.88067890703678, 55.45438773930073, 59.01310957968235, 33.191063180565834, 30.293773747980595, 56.84468753635883, 52.884376645088196, 62.31690309941769, 54.72371734678745, 57.17626914381981, 52.89190024137497, 54.90450784564018, 45.9116367995739, 44.80788342654705, 41.7228289693594, 48.1097998470068, 45.545712634921074, 42.67304018139839, 50.29568575322628, 56.803262159228325, 56.35663412511349, 54.420543015003204, 51.72802649438381, 53.14594320952892, 56.21315002441406, 57.5208954513073, 57.38101355731487, 54.11055564880371, 55.46714745461941, 54.49249595403671, 56.37993447482586, 57.1090317517519, 59.64837469160557, 58.059809133410454, 56.241663694381714, 60.08857727050781, 61.21212758123875, 59.5340920239687, 59.83615301549435, 56.03878118097782, 60.230412259697914, 59.85110141336918, 61.18620537221432, 61.3899352401495, 65.11781260371208, 56.130968034267426, 41.184519454836845, 29.356343150138855, 14.233436789363623, 22.878397554159164, 13.498475477099419, 12.410739194601774, 11.099334564059973, 17.584968097507954, 12.01794097200036, 3.0628707725554705, 0.3214786620810628, 0.20436514634639025, 0.5885491718072444, 8.172459919005632, 45.140183195471764, 53.216277435421944, 27.599133141338825, 33.88661205768585, 45.03258436918259, 67.83087462186813, 58.360464200377464, 43.69665205478668, 8.960648775100708, 0.3487678477540612, 0.18846579012461007, 0.15779632958583534, 0.08295331164845265, 0.09796741185709834, 0.14899867353960872, 0.1846700016176328, 0.10443505816510879, 0.07648231825442053, 0.15142846503295004, 0.15574185701552778, 0.1738596410723403, 0.09149207689915784, 0.15425141667947173, 0.1693533203797415, 0.14895027066813782, 0.17721085343509912, 0.148000989574939, 0.1687004233826883, 0.23850739788031206, 0.09923896315740421, 0.17549928277730942, 0.17235388280823827], [0.07994223298737779, 0.05381057504564524, 0.025309061456937343, 0.08718636614503339, 0.028368834282446187, 0.060989206249359995, 0.017705509890220128, 0.04079674094100483, 0.03489428090688307, 0.15470360725885257, 0.034057958400808275, 0.0523970174981514, 0.05087307290523313, 0.026495519960008096, 0.02560841599915875, 0.0663771983818151, 0.007054063107716502, 0.03980099027103279, 0.03686528783873655, 0.0035803328319161665, 0.03770209274080116, 0.3951499401591718, 14.829188771545887, 43.39168041944504, 51.991192772984505, 39.59784239530563, 28.72762318700552, 18.52532833814621, 15.028965901583433, 32.21027500927448, 33.853033259510994, 13.723269514739513, 0.8299275382887572, 0.07812536641722545, 0.11478036671178415, 0.260558282607235, 1.4367176312953234, 6.960514951497316, 16.821119785308838, 12.96046044677496, 2.073155455291271, 7.112535294145346, 18.19805569946766, 33.82809139788151, 51.229793429374695, 54.73684564232826, 56.52501069009304, 54.24524322152138, 54.990554228425026, 54.15475107729435, 55.86592085659504, 56.354316249489784, 54.327014833688736, 54.835693538188934, 52.75777883827686, 51.27170518040657, 52.06967756152153, 52.667989656329155, 53.3529295027256, 52.21237510442734, 53.25263008475304, 50.83681471645832, 53.957594856619835, 50.92156916856766, 53.99999678134918, 54.409352615475655, 53.86704571545124, 51.86969429254532, 48.025710359215736, 47.819974198937416, 49.88663010299206, 45.86398735642433, 42.10941642522812, 37.877678498625755, 40.463576540350914, 38.85591320693493, 42.17633083462715, 44.583741053938866, 44.836184307932854, 43.660185411572456, 44.22822453081608, 42.66298592090607, 47.21932142972946, 48.147151842713356, 56.422670781612396, 48.78644473850727, 57.61115960776806, 26.657545566558838, 30.20719539374113, 58.45309183001518, 49.55925486981869, 57.093190401792526, 52.9639557749033, 57.32084758579731, 53.514694422483444, 55.42294442653656, 51.272472739219666, 49.628506153821945, 39.68213327229023, 40.951626151800156, 40.790788382291794, 40.20859122276306, 40.82823157310486, 52.30168171226978, 54.35102194547653, 52.45217263698578, 50.68567402660847, 53.66586931049824, 52.43802599608898, 54.942900985479355, 53.79730425775051, 53.54371726512909, 50.34879170358181, 51.720115318894386, 54.42213512957096, 56.42176643013954, 54.061990454792976, 53.758272752165794, 56.21267884969711, 55.334272384643555, 52.01542027294636, 51.23390480875969, 49.20308858156204, 50.805417001247406, 50.44877953827381, 51.20155334472656, 54.853119403123856, 55.84145396947861, 50.16401141881943, 57.44823195040226, 45.71642607450485, 30.225721299648285, 12.190941888839006, 13.319984804838896, 7.150842938572168, 10.009622387588024, 5.1939184963703156, 4.113578042015433, 3.390504391863942, 2.0365969045087695, 0.3005864628357813, 0.06267771095735952, 0.03345115990669001, 0.9146163845434785, 20.49893483519554, 38.963177651166916, 35.88845483958721, 21.212764531373978, 25.281874984502792, 42.97623731195927, 47.43087887763977, 44.632336646318436, 12.878565341234207, 0.2070589642971754, 0.01705566497548716, 0.05243101899395697, 0.023833118975744583, 0.03494238691928331, 0.042314132369938307, 0.029911061683378648, 0.04021292676043231, 0.022769389433960896, 0.08799921080935746, 0.053456774694495834, 0.039206277651828714, 0.054896593137527816, 0.0674857443664223, 0.027623771820799448, 0.014750650771020446, 0.062424638599622995, 0.02044555250904523, 0.032160019618459046, 0.007566703934571706, 0.03618061949964613, 0.046428372734226286, 0.05561032397963572, 0.058412083599250764, 0.04358261117886286, 0.051110144559061155, 0.05648984690196812, 0.03778624857659452, 0.0679442728869617, 0.04120353434700519, 0.08159336313838139, 0.05651030420267489, 0.0584367080591619, 0.02428251722449204, 0.06052680742868688, 0.025187757419189438, 0.03881034928781446, 0.045435030333464965, 0.06418407778255641, 0.03845209605060518, 0.03063118983845925, 0.047048106862348504, 0.08514263987308368, 0.03631245461292565, 0.5536711995955557, 17.268418483436108, 51.87925457954407, 56.26478165388107, 46.5082997828722, 33.83913740515709, 26.987257674336433, 23.882003501057625, 32.78963752090931, 37.92285047471523, 16.013951897621155, 1.1704356386326253, 0.07675099797779694, 0.060475877544377, 1.09337862348184, 3.654980887658894, 7.707423772662878, 16.656050942838192, 15.6739841401577, 6.287825172767043, 8.805712088942528, 17.571910098195076, 35.63926041126251, 51.45527333021164, 57.361266016960144, 58.56250315904617, 55.85560441017151, 55.39378099143505, 55.11065058410168, 57.40070790052414, 54.8557298630476, 54.951450526714325, 54.06067952513695, 53.64629656076431, 50.10676749050617, 51.77959352731705, 52.39717058837414, 53.399522602558136, 53.23477104306221, 54.04714085161686, 51.864716559648514, 53.29229615628719, 51.78403548896313, 54.206352308392525, 55.88248796761036, 55.87073899805546, 53.68809051811695, 51.74784243106842, 50.714715868234634, 52.957454323768616, 50.75403615832329, 45.96928350627422, 37.573455423116684, 42.1358972042799, 41.841979175806046, 44.76444415748119, 46.47763542830944, 46.623992174863815, 44.34591941535473, 46.45841605961323, 44.70886453986168, 50.52796728909016, 50.0056055188179, 58.04422236979008, 51.091963425278664, 59.21395160257816, 28.59270002692938, 31.350941620767117, 57.81427010893822, 48.56371968984604, 57.53762975335121, 54.80996131896973, 59.39934365451336, 56.68137229979038, 56.186513453722, 53.96396331489086, 49.868508875370026, 41.31892204284668, 42.867768332362175, 41.38492450118065, 42.17550627887249, 44.49675992131233, 54.523369297385216, 55.99704422056675, 52.97806441783905, 51.63293279707432, 52.926489785313606, 53.467120975255966, 56.015218645334244, 55.78431263566017, 54.48518514633179, 52.881013825535774, 53.617999479174614, 56.370978355407715, 58.09714213013649, 55.04628203809261, 57.39452563226223, 58.46581354737282, 58.114845380187035, 54.324518367648125, 52.23004795610905, 51.507630720734596, 52.108355686068535, 50.659508630633354, 52.88239695131779, 57.575680911540985, 58.231632113456726, 52.65632428228855, 57.507850751280785, 45.745593309402466, 29.875655584037304, 13.52783365175128, 7.923169070854783, 10.936280563473701, 11.38454345986247, 8.029049914330244, 8.38042750954628, 4.702185457572341, 2.9513743054121733, 1.2700504995882511, 0.02737767750659259, 0.053771304301335476, 1.8299462995491922, 23.42549219727516, 41.77723824977875, 33.05016674101353, 26.160439141094685, 32.467669397592545, 50.80934979021549, 55.73723316192627, 51.01437918841839, 16.4423219114542, 0.39304886071477085, 0.047991068568080664, 0.10949740331852809, 0.025389207839907613, 0.06313284044153988, 0.017139592600869946, 0.011191689936822513, 0.031603616662323475, 0.11543404296389781, 0.06119871453847736, 0.018653449551493395, 0.038582090637646616, 0.0016196192564166267, 0.030167128606990445, 0.021792721236124635, 0.026791262098413426, 0.05286492305458523, 0.04394527277327143, 0.06914331635925919, 0.04892914694210049, 0.07761952598229982, 0.021097087665111758, 0.013524055066227447, 0.21385941188782454, 0.12684418499702588, 0.10004020063206553, 0.11161717004142702, 0.14920135407010093, 0.22583691839827225, 0.08658498903969303, 0.1507793233031407, 0.13504723232472315, 0.25483843171969056, 0.061262316594365984, 0.16941401321673766, 0.13279717415571213, 0.17430267354939133, 0.06745734979631379, 0.2620416576974094, 0.1674899211502634, 0.1500950928311795, 0.12516936549218372, 0.1862261220230721, 0.1655216861399822, 0.828365347115323, 22.954887449741364, 60.38785681128502, 63.773946315050125, 53.306815177202225, 42.193768098950386, 29.728394486010075, 25.727934949100018, 40.70970833301544, 44.2286729067564, 18.507873974740505, 1.5335738402791321, 0.23978217010153458, 0.39227052591741085, 1.0645764064975083, 7.188567789271474, 13.875326905399561, 26.860124096274376, 22.835830338299274, 9.292088840156794, 10.61227859929204, 20.776489041745663, 37.18396872282028, 53.21067273616791, 56.96085870265961, 58.38468410074711, 56.726384684443474, 56.287679225206375, 55.63385970890522, 57.71539181470871, 56.86799168586731, 55.22562101483345, 54.6590144187212, 52.658763751387596, 52.19897322356701, 50.96050187945366, 52.57992938160896, 54.94639299809933, 55.47970198094845, 54.382605850696564, 53.078097850084305, 55.30368022620678, 53.450930044054985, 55.75579896569252, 58.11951532959938, 59.52094852924347, 55.7047601044178, 53.587437719106674, 53.61542321741581, 54.349566623568535, 51.486541852355, 47.03013338148594, 40.34490130841732, 44.37984399497509, 42.715875282883644, 47.8913077712059, 48.79741474986076, 47.45471879839897, 48.59351769089699, 49.20685417950153, 47.58771926164627, 51.7697748541832, 52.92918764054775, 61.186049580574036, 53.566215857863426, 57.393416091799736, 31.74525786191225, 33.678022250533104, 57.272780165076256, 50.67061923444271, 58.218990191817284, 56.81743919849396, 62.690787836909294, 58.18269453942776, 61.12982399761677, 56.25960633158684, 52.33388118445873, 45.38969300687313, 45.16021192073822, 44.047190845012665, 44.798300340771675, 45.401023998856544, 57.89144016802311, 58.433097302913666, 55.30218690633774, 51.65782146155834, 54.25731897354126, 54.82899069786072, 57.48435281217098, 58.69686394929886, 57.58805684745312, 56.965950429439545, 56.689135283231735, 58.62963415682316, 60.47507353127003, 56.91235810518265, 60.076170936226845, 61.300442442297935, 58.73793214559555, 56.6617501527071, 51.45234368741512, 51.86714082956314, 53.22813279926777, 52.69668571650982, 54.365457370877266, 59.60632614791393, 61.030417531728745, 55.33974789083004, 58.60430471599102, 52.265598848462105, 34.94553543627262, 18.87460559606552, 23.888947628438473, 19.895166233181953, 22.339841052889824, 17.271245531737804, 11.294586136937141, 10.828597191721201, 3.5912393080070615, 1.3790003908798099, 0.20266107138013467, 0.14293739019194618, 2.076324485242367, 28.05475529283285, 51.61840237677097, 48.290415555238724, 31.803968511521816, 36.459925174713135, 56.32884621620178, 63.71667578816414, 59.831650257110596, 22.088368646800518, 0.6978777959011495, 0.12085434078471735, 0.16851623717229813, 0.08563184877857566, 0.1945282460656017, 0.10146522807190195, 0.08833943356876262, 0.12056422783643939, 0.21097475808346644, 0.2167970995651558, 0.1107725317706354, 0.2105717867380008, 0.18628669611644, 0.15286705893231556, 0.19481842580717057, 0.14639741624705493, 0.19656504067825153, 0.1471561286598444, 0.0831214823119808, 0.12820862350054085, 0.1091572770383209, 0.1176272303564474, 0.12557343521621078], [0.05963801879261155, 0.04655697208363563, 0.021003087240387686, 0.014120976502454141, 0.08065892499871552, 0.02335304961889051, 0.006946769426576793, 0.028305820378591307, 0.08435523603111506, 0.04868837568210438, 0.019229701247240882, 0.036700605269288644, 0.03624376142397523, 0.022840709825686645, 0.12018773632007651, 0.028334185262792744, 0.034418319337419234, 0.05523561732843518, 0.033089381468016654, 0.0698777828074526, 0.11503609595820308, 1.3954884186387062, 20.21681137382984, 48.31854164600372, 54.06462371349335, 43.34755718708038, 29.0462588891387, 16.15300353616476, 20.37968583405018, 46.01755991578102, 30.46030931174755, 7.12323646992445, 0.09802365180803463, 0.04139566524827387, 0.01764378546795342, 0.5750869691837579, 3.179419543594122, 3.784055686555803, 19.45636957883835, 9.75005641579628, 3.724082079716027, 11.07110682874918, 16.17716833949089, 35.25917820632458, 49.364450722932816, 53.917753994464874, 54.053285121917725, 55.44800408184528, 54.95887152850628, 53.5682487487793, 55.16243040561676, 57.18636520206928, 53.44462238252163, 53.41748803853989, 52.71760359406471, 52.231761664152145, 52.62099377810955, 51.92294463515282, 51.65942497551441, 51.95719599723816, 50.48441782593727, 49.98626455664635, 51.304406225681305, 51.16695620119572, 52.791224643588066, 52.10642918944359, 51.38995863497257, 48.1897209584713, 43.24991002678871, 40.30238538980484, 41.720142513513565, 38.27724225819111, 38.03033530712128, 39.43165451288223, 39.43021818995476, 42.3191499710083, 49.39618282020092, 49.704885855317116, 51.496542915701866, 49.43496733903885, 51.67003020644188, 48.21863740682602, 51.66714996099472, 49.433721005916595, 54.930734038352966, 50.24342715740204, 56.209961995482445, 20.38711253553629, 33.57380524277687, 59.11388777196407, 46.607516258955, 51.49521678686142, 49.12015043199062, 53.14662717282772, 51.3986411690712, 57.118041068315506, 52.83655621111393, 55.276416689157486, 45.44572860002518, 41.36055260896683, 39.31166835129261, 41.48993946611881, 39.90213766694069, 49.99080151319504, 54.364693611860275, 55.02691827714443, 49.8802350461483, 50.55196300148964, 50.425836369395256, 52.97204554080963, 53.956318125128746, 56.30560286343098, 53.27287159860134, 53.77882204949856, 48.760397136211395, 49.61476229131222, 46.55764013528824, 50.885319113731384, 50.435423254966736, 50.761107578873634, 51.587867215275764, 50.99501922726631, 48.423169031739235, 48.71153935790062, 50.10963253676891, 51.91492706537247, 52.05588050186634, 48.674772530794144, 38.910387083888054, 29.251634068787098, 33.31105314195156, 28.212826810777187, 12.806481309235096, 9.631952103227377, 11.09585490077734, 5.160185806453228, 11.074748933315277, 8.979349471628666, 1.6486866446211934, 3.0914844246581197, 1.206296926829964, 0.017202077724505216, 0.042016668448923156, 0.5303125467617065, 9.38691085204482, 36.19229033589363, 31.945680007338524, 24.29321363568306, 21.378709226846695, 38.45846973359585, 46.38083562254906, 46.38955995440483, 21.720713675022125, 1.5712359943427145, 0.04801550378033426, 0.006686652232019696, 0.07114418360288255, 0.05899258409044705, 0.005496633739312529, 0.03503138526866678, 0.07354294590186328, 0.019300724779895972, 0.07180263928603381, 0.011168309501954354, 0.04094331139640417, 0.1314231174183078, 0.016602283249085303, 0.026728142438514624, 0.04329151488491334, 0.04003468515293207, 0.06254273655940779, 0.07085814504534937, 0.04092655741260387, 0.08023877293453552, 0.028275601980567444, 0.02248730837891344, 0.043958134192507714, 0.011257895075686974, 0.014253614062909037, 0.04067014167958405, 0.023736274270049762, 0.007021779219940072, 0.03213358802895527, 0.05056213900388684, 0.05196430458454415, 0.032028321802499704, 0.039184428824228235, 0.04167193343164399, 0.09002646882436238, 0.05452571596833877, 0.10421692611998878, 0.020124334296269808, 0.0046492309684254, 0.04300961380067747, 0.056442145360051654, 0.015687537998019252, 0.03373158411704935, 2.0006325468420982, 23.742775171995163, 54.474446922540665, 59.24539111554623, 48.35143268108368, 31.926969811320305, 21.64572659879923, 20.008289963006973, 37.7761023491621, 33.6321435123682, 7.920588534325361, 0.12393841709126718, 0.0326235168176936, 0.20377628185087815, 1.5108604403212667, 6.134730912744999, 6.3629072438925505, 14.223673213273287, 10.213457699865103, 9.691474009305239, 12.873527761548758, 22.71555919200182, 36.636239513754845, 51.849513575434685, 55.30301906168461, 56.0235857963562, 54.90180239081383, 56.06554314494133, 54.62287075817585, 54.9910482019186, 57.65205681324005, 53.581589832901955, 53.90145666897297, 53.14625859260559, 52.62653008103371, 54.33365307748318, 51.537531316280365, 51.87459222972393, 51.79689399898052, 51.66974142193794, 50.367653891444206, 52.34358586370945, 52.22934119403362, 53.726768642663956, 55.32090090215206, 54.585427567362785, 50.36324992775917, 44.70324844121933, 42.77796395123005, 43.053095787763596, 39.90656442940235, 40.077008083462715, 41.66121907532215, 41.621845588088036, 43.372058272361755, 51.21748968958855, 52.59640529751778, 54.45761762559414, 51.51810675859451, 53.48904199898243, 51.339246556162834, 52.873957604169846, 52.63473004102707, 57.49905422329903, 52.18148656189442, 57.66673922538757, 22.07260139286518, 34.44390155375004, 58.83768819272518, 47.53051333129406, 52.1409959346056, 50.28142511844635, 54.40764270722866, 52.99983724951744, 58.279832527041435, 54.49971176683903, 55.723192915320396, 46.680244356393814, 42.819001749157906, 40.635502114892006, 42.91227534413338, 42.773989364504814, 50.77537961304188, 56.519303396344185, 55.48092171549797, 49.97863456606865, 50.27024231851101, 51.73469513654709, 53.62241864204407, 55.84714986383915, 57.07413822412491, 55.25264136493206, 54.696913585066795, 50.91592267155647, 51.09150744974613, 47.108473777770996, 50.971578285098076, 51.55743844807148, 52.56400443613529, 51.8524432182312, 51.11793503165245, 48.09526942670345, 49.73776549100876, 50.90596340596676, 54.50198784470558, 55.84265470504761, 53.128289356827736, 41.53343953192234, 33.639332726597786, 32.94456660747528, 28.51658061146736, 14.1118423640728, 10.96688412129879, 7.814864907413721, 9.481114447116852, 13.89485975727439, 10.646186079829931, 5.634994553402066, 6.848465139046311, 1.7799682938493788, 0.10982279796735384, 0.05989625278743915, 0.6043202849105, 12.1156888268888, 40.59285320341587, 35.58388218283653, 24.338279217481613, 26.203031055629253, 43.234091475605965, 52.308346554636955, 54.397751837968826, 27.362886518239975, 2.2405314864590764, 0.06784550045267679, 0.007022650779617834, 0.06396109209163114, 0.08495064626913518, 0.022270848021435086, 0.030144461561576463, 0.037021272437414154, 0.06279960871324874, 0.039981877635000274, 0.005204343051445903, 0.027188196072529536, 0.029431014590954874, 0.05676339140336495, 0.022733638325007632, 0.04997860312869307, 0.04564220827887766, 0.037501430851989426, 0.0670592840469908, 0.07076337278704159, 0.05821046433993615, 0.08776709670200944, 0.0400954522046959, 0.1845644088461995, 0.18080335285048932, 0.07281132187927142, 0.14308041689218953, 0.1869984602672048, 0.0991119520040229, 0.09600270946975797, 0.23687632055953145, 0.22686915675876662, 0.1451442702091299, 0.07990030906512402, 0.10133893680176698, 0.1888466306263581, 0.22924830409465358, 0.22489160037366673, 0.18072806939017028, 0.07549042304162867, 0.15505608287639916, 0.1885884819785133, 0.18553200614405796, 0.18397091334918514, 2.9231912177056074, 30.928750075399876, 62.717295214533806, 68.04070696234703, 55.86316980421543, 40.16984470188618, 25.603105947375298, 28.06943580508232, 57.493453323841095, 40.844350308179855, 10.43782141059637, 0.24396353401243687, 0.18995542894117534, 0.397719819447957, 1.411804505623877, 5.173778152093291, 12.920861821621656, 31.704385355114937, 19.879511073231697, 8.934081550687551, 15.912193357944489, 20.766649469733238, 38.90178054571152, 53.146254792809486, 55.27196332812309, 53.885280936956406, 55.74136734008789, 56.26968339085579, 54.49670232832432, 54.887754544615746, 59.107481315732, 54.77636732161045, 55.7996866106987, 52.58520729839802, 54.11038085818291, 53.74583221971989, 51.52247652411461, 51.30327008664608, 52.29677997529507, 52.07247041165829, 50.4201290756464, 53.61873283982277, 52.22232677042484, 56.141463071107864, 57.55963437259197, 55.70959724485874, 52.89285399019718, 47.033507600426674, 44.615811333060265, 45.278940349817276, 41.018624156713486, 42.135395631194115, 43.66465777158737, 42.75044582784176, 45.320023745298386, 53.13732147216797, 55.26877909898758, 56.35388687252998, 53.914710357785225, 54.859867841005325, 54.04980070888996, 56.07656255364418, 54.07123155891895, 60.041596591472626, 54.26000162959099, 56.71751216053963, 25.198226273059845, 37.8338972479105, 59.71864812076092, 46.673564314842224, 52.634350061416626, 50.365731194615364, 55.48411354422569, 53.5275187343359, 59.89098787307739, 56.218443140387535, 58.84724088013172, 49.23548184335232, 46.75451897084713, 42.332540452480316, 45.42244724929333, 43.94561089575291, 54.15782891213894, 59.499240294098854, 57.203319892287254, 51.52022324502468, 50.15002056956291, 52.284362241625786, 54.638776704669, 56.981582790613174, 59.20411393046379, 56.50932893157005, 56.444546207785606, 50.80567918717861, 51.8058767169714, 47.46550641953945, 51.000756919384, 52.50091642141342, 51.89902491867542, 52.277723997831345, 51.02886401116848, 49.763649702072144, 49.92260657250881, 50.0712925940752, 53.37208807468414, 57.42355987429619, 54.32493254542351, 45.95995880663395, 34.20270189642906, 36.012540981173515, 32.367073595523834, 17.469245307147503, 20.860124453902245, 26.18569828569889, 14.447856433689594, 18.432079441845417, 20.2238941937685, 6.79238679818809, 6.526123210787773, 2.2530019422993064, 0.38766867597587407, 0.0998618699668441, 1.1490006325766444, 12.406113892793655, 48.86202648282051, 44.95544470846653, 35.06272494792938, 33.04500661790371, 50.05938783288002, 59.97354984283447, 61.671815514564514, 33.95303249359131, 3.6048962501809, 0.1731010028743185, 0.0626113629550673, 0.21232046477962285, 0.14498145785182714, 0.12792979861842468, 0.15066256863065064, 0.1388959211180918, 0.15832512464839965, 0.1718613490811549, 0.08766703293076716, 0.14322008908493444, 0.25767575134523213, 0.10175469535170123, 0.12309066180023365, 0.1429474537144415, 0.1943438668968156, 0.15383449295768514, 0.23461229517124593, 0.14366365590831265, 0.1348406184115447, 0.22214978031115606, 0.12259493683814071], [0.03645227894594427, 0.05347507605620194, 0.06786781683331355, 0.0285527254891349, 0.017920849604706746, 0.0709526427090168, 0.07823066975106485, 0.02602716540422989, 0.04209869061014615, 0.04662684157665353, 0.021693501657864545, 0.04683443512476515, 0.07039175718091428, 0.03688158169097733, 0.08149161469191313, 0.0445647731248755, 0.04503038915572688, 0.036505164389382116, 0.016358554530597758, 0.05304395133862272, 0.023743541751173325, 2.5139474775642157, 27.161575220525265, 51.54325760900974, 50.729181692004204, 40.340960919857025, 23.592599630355835, 15.74767168611288, 22.9782846942544, 47.704285606741905, 26.33634690195322, 3.1399957090616226, 0.08931109041441232, 0.07816611032467335, 0.07686708471737802, 5.3325925301760435, 5.595181239768863, 5.780736682936549, 6.682760305702686, 11.955679412931204, 8.774442616850138, 9.937674198299646, 27.276047877967358, 41.4954149723053, 49.8745771497488, 56.32039166986942, 52.89452210068703, 52.98915222287178, 52.88651593029499, 54.89482596516609, 53.30646939575672, 50.93679115176201, 52.657228633761406, 52.53822661936283, 52.71490953862667, 53.202214390039444, 53.535353913903236, 53.49974222481251, 51.494886204600334, 51.6528133302927, 52.54416950047016, 51.13879211246967, 49.597944393754005, 52.93855033814907, 54.06543307006359, 51.3466789573431, 48.406799510121346, 45.724154859781265, 40.413841009140015, 40.763289257884026, 42.60279715061188, 39.9594271928072, 38.955038487911224, 38.834695145487785, 44.67506915330887, 49.649256840348244, 53.832790553569794, 52.30562210083008, 56.315163150429726, 55.67242383956909, 57.30138882994652, 55.29171846807003, 56.515925377607346, 53.06819938123226, 54.25158128142357, 48.97664353251457, 54.13623847067356, 21.119418740272522, 32.65387460589409, 55.33712983131409, 49.56016682088375, 55.30953951179981, 49.49060395359993, 53.01341012120247, 49.50340926647186, 51.92737519741058, 52.180464416742325, 53.24204005300999, 50.00555992126465, 42.65302665531635, 38.742743879556656, 39.90782596170902, 36.842678636312485, 44.20571833848953, 51.56223379075527, 54.76162791252136, 52.551753893494606, 51.259481236338615, 49.45004492998123, 48.69378291070461, 49.40107695758343, 50.728771314024925, 49.29743751883507, 50.447514206171036, 49.32638816535473, 46.033940836787224, 56.99632599949837, 45.95128767192364, 49.297034740448, 49.84393559396267, 48.59655372798443, 50.09284123778343, 51.513246819376945, 49.774498119950294, 47.672230526804924, 52.41963118314743, 52.673795744776726, 47.13539533317089, 41.7283158749342, 36.2753576785326, 22.731121256947517, 19.85912326723337, 14.335147831588984, 5.970456702634692, 6.503753811120987, 10.687329322099686, 4.794467305764556, 7.050908776000142, 3.6299274070188403, 4.706398956477642, 1.495280445087701, 0.06411218593711965, 0.06338006467558444, 0.03681775699078571, 5.0405487511307, 28.037648610770702, 36.62003718316555, 21.76188826560974, 21.125699803233147, 41.65342569351196, 46.21069975197315, 49.541536420583725, 30.669210702180862, 4.859086638316512, 0.09801957741728984, 0.05303358724631835, 0.03426959665375762, 0.05306808969180565, 0.03855080169159919, 0.03793072246480733, 0.03830228612059727, 0.037285606886143796, 0.05831958231283352, 0.04917604092042893, 0.09045418337336741, 0.08004056013305672, 0.10468614898854867, 0.10116666206158698, 0.05643903205054812, 0.022641869909421075, 0.05844689774676226, 0.06098126155848149, 0.06802186442655511, 0.037789517737110145, 0.024624845827929676, 0.02232336795714218, 0.01060589607732254, 0.06524420605273917, 0.05856675830727909, 0.015428319729835493, 0.0437963979493361, 0.0641610637831036, 0.036204991629347205, 0.032560486215515994, 0.044205232261447236, 0.04470250460144598, 0.024674924097780604, 0.010773799567687092, 0.046261626994237304, 0.007456962557625957, 0.060158004562254064, 0.033356524945702404, 0.14787553693167865, 0.004514017227847944, 0.06617658844334073, 0.059955023461952806, 0.05294114904245362, 3.2563435658812523, 31.105372197926044, 57.58388467133045, 57.634095177054405, 47.80699409544468, 31.780058294534683, 18.66729822009802, 22.272117286920547, 45.999393090605736, 28.911048844456673, 4.072859426960349, 0.05890373788133729, 0.10676486752345227, 0.3707124717766419, 5.8004015777260065, 8.161734994500875, 11.207234524190426, 11.421975251287222, 17.164431363344193, 12.769824676215649, 11.713016834110022, 28.316960223019123, 40.88487133383751, 52.13091887533665, 57.00935550034046, 54.14644472301006, 53.08803431689739, 53.658775091171265, 54.13389019668102, 54.402372390031815, 51.578379124403, 51.795172691345215, 53.52033331990242, 55.5104461312294, 53.53503093123436, 53.96134905517101, 53.52101728320122, 52.52040937542915, 50.70698708295822, 52.17285342514515, 51.64681725203991, 51.79381616413593, 54.04819339513779, 55.7413749396801, 54.22547288239002, 51.34185701608658, 46.945663914084435, 42.7479949593544, 42.9701804369688, 45.060581266880035, 41.899356096982956, 39.33222524821758, 39.54546220600605, 45.97667030990124, 51.92460514605045, 55.8008873462677, 54.868717566132545, 59.04509626328945, 57.06563428044319, 59.10935841500759, 55.83367958664894, 57.75034233927727, 53.88732522726059, 56.51017248630524, 50.19949771463871, 55.58691322803497, 22.826389744877815, 34.4718224555254, 53.924358040094376, 50.06200589239597, 56.00238673388958, 50.40896527469158, 53.61818566918373, 50.127529576420784, 53.11710275709629, 54.2020433396101, 55.02265490591526, 51.29938289523125, 45.69402627646923, 40.887200608849525, 40.98760262131691, 38.879156559705734, 46.14289239048958, 53.61631616950035, 56.499856039881706, 53.21780115365982, 51.56532682478428, 49.53553654253483, 50.498047694563866, 49.65370260179043, 50.57787001132965, 51.07722021639347, 49.63677071034908, 49.64516066014767, 47.2286157310009, 56.45165182650089, 48.647212609648705, 49.18481916189194, 49.5801917463541, 49.23939563333988, 51.116909086704254, 50.61867982149124, 49.98218737542629, 49.65438276529312, 53.45170520246029, 52.81302787363529, 51.92500412464142, 48.9367950707674, 38.86235386133194, 25.934609659016132, 20.01670081168413, 14.24047401174903, 9.567175079137087, 8.893107399344444, 11.497472450137138, 12.766115125268698, 11.20848560705781, 9.1981740295887, 5.2486830577254295, 1.668810008559376, 0.1854204316623509, 0.0770512931921985, 0.14854878361802548, 5.947041884064674, 30.69537229835987, 40.67473120987415, 30.959509424865246, 25.759815238416195, 46.68820112943649, 51.32480353116989, 56.25462859869003, 36.612031012773514, 6.264443602412939, 0.1748706985381432, 0.014652425670647062, 0.0512429259106284, 0.06981562051805668, 0.04273985054169316, 0.04976391093805432, 0.032611842834739946, 0.007326251798076555, 0.026942198237520643, 0.013803301117150113, 0.007005201496212976, 0.010766821524157422, 0.06315795471891761, 0.018428972143738065, 0.04548516983049922, 0.06582255431567319, 0.057416036070208065, 0.07368083694018424, 0.04868615294981282, 0.015181640974333277, 0.030999074297142215, 0.03213058975234162, 0.10967073932988569, 0.16217957250773907, 0.1322250673547387, 0.16303425945807248, 0.13493509381078184, 0.19153951347107068, 0.19598361250245944, 0.10572923012659885, 0.14913990424247459, 0.13177021988667548, 0.1174237483064644, 0.1576269418001175, 0.14635315455961972, 0.11118175199953839, 0.3451273759128526, 0.2216511609731242, 0.2609284658683464, 0.0875700861797668, 0.2513768174685538, 0.1368996180826798, 0.1357548256055452, 4.544530492275953, 38.14695484936237, 65.40716707706451, 63.624462336301804, 52.73967660963535, 35.27574151754379, 23.3746300265193, 35.07327318191528, 59.30267684161663, 34.01483237743378, 4.548549726605415, 0.2590418077306822, 0.22046109748771414, 0.5963495001196861, 8.450943175703287, 12.283499222248793, 13.786456324160099, 17.200533226132393, 21.615031845867634, 15.751602575182915, 12.894592881202698, 29.367668442428112, 43.053395971655846, 52.079302445054054, 56.33990742266178, 52.41602137684822, 52.98960439860821, 54.1997292637825, 55.28605677187443, 54.57782797515392, 51.784050688147545, 54.2028982937336, 55.11412739753723, 55.849581733345985, 55.952844992280006, 57.13867396116257, 55.324377715587616, 52.09925137460232, 50.73433041572571, 52.75581054389477, 52.44974456727505, 51.80435299873352, 55.5466315895319, 58.29269863665104, 56.16659112274647, 53.043789491057396, 49.0484406799078, 43.17002311348915, 43.798672780394554, 47.33162060379982, 44.70867075026035, 41.930826008319855, 42.72667430341244, 49.12918634712696, 53.287580609321594, 57.92754203081131, 55.90354263782501, 61.5663255751133, 61.04893773794174, 60.50651304423809, 58.60182724893093, 59.74762536585331, 56.12685665488243, 57.576186284422874, 49.87891651690006, 53.961805030703545, 26.463822461664677, 36.44851818680763, 54.259948432445526, 52.45053492486477, 57.56890967488289, 52.27102875709534, 54.85397815704346, 50.633928403258324, 54.309486374258995, 54.30141940712929, 56.99315696954727, 54.614815190434456, 47.71991416811943, 42.95833267271519, 42.896623983979225, 40.784503519535065, 47.91290581226349, 55.81370405852795, 59.04956862330437, 55.05077339708805, 52.782162129879, 49.762673154473305, 49.55435313284397, 50.14243617653847, 50.59433072805405, 51.03465110063553, 50.31123451888561, 50.567481368780136, 45.712740272283554, 56.074525862932205, 48.3929568529129, 48.62484320998192, 50.160622000694275, 49.052065685391426, 49.50880117714405, 50.66327042877674, 50.89753545820713, 49.79753628373146, 52.16597959399223, 54.09895487129688, 52.57962539792061, 51.83597110211849, 44.7120525687933, 30.64590845257044, 25.109354741871357, 17.841821014881134, 12.158555276691914, 15.938934423029423, 19.028335846960545, 16.095888800919056, 14.48012050241232, 13.74334478750825, 10.431577395647764, 3.210130683146417, 0.40862665919121355, 0.22161173808854073, 0.2535458776401356, 7.3226644936949015, 37.84493945538998, 48.58248308300972, 31.73112452030182, 29.975542724132538, 53.86239856481552, 57.665523290634155, 62.250083684921265, 43.6872323602438, 8.956300858408213, 0.49633046553935856, 0.07271248265169561, 0.12209472930408083, 0.13514409743947908, 0.09933547204127535, 0.12487166037317365, 0.12123131469707005, 0.18439321022015065, 0.179266142367851, 0.1564223025343381, 0.1668872675509192, 0.16262313933111727, 0.18186680594226345, 0.2146619258564897, 0.1340620609698817, 0.1580873256898485, 0.12913296843180433, 0.1481576421065256, 0.2507801307365298, 0.1667091075796634, 0.1879600461688824, 0.13256914186058566], [0.038276225604931824, 0.024466298964398447, 0.022350916478899308, 0.0306580908363685, 0.032995889414451085, 0.10719886064180173, 0.041405194424442016, 0.0288521264155861, 0.06589198965230025, 0.03503632797219325, 0.017081970399885904, 0.07127792603569105, 0.04453388864931185, 0.05931630890700035, 0.04616296217136551, 0.10850351172848605, 0.07333855843171477, 0.04765984805999324, 0.007088139282132033, 0.09359081857837737, 0.020870734479103703, 3.6447682231664658, 27.733659222722054, 45.94647713005543, 43.10338228940964, 25.393347702920437, 14.766779970377684, 18.80626816302538, 37.42054022848606, 41.85416132211685, 16.895749680697918, 1.2391521013341844, 0.02100853274896508, 0.06788506434531882, 0.4988312954083085, 2.049504811875522, 8.443362582474947, 5.737020028755069, 7.928573805838823, 9.832314401865005, 18.23319051414728, 17.523405700922012, 32.53976672887802, 40.94447873532772, 54.490569457411766, 54.39646750688553, 52.74501912295818, 57.81241960823536, 53.369363620877266, 51.947536915540695, 52.258687019348145, 50.50731539726257, 52.39186607301235, 53.49934704601765, 53.63070219755173, 50.834185257554054, 53.23773868381977, 52.82413847744465, 55.77705882489681, 52.76452727615833, 50.40198504924774, 49.776238426566124, 51.33541636168957, 52.94473260641098, 52.72090941667557, 49.61721695959568, 47.95115076005459, 42.30437256395817, 39.513129740953445, 38.14245969057083, 40.08407570421696, 39.38329450786114, 40.320225432515144, 41.85682877898216, 49.62714582681656, 53.87190565466881, 56.44983172416687, 55.59775784611702, 53.60524356365204, 53.28033819794655, 54.02146562933922, 53.05355116724968, 55.26748336851597, 54.53751593828201, 54.35369700193405, 47.573067247867584, 53.85919153690338, 16.61366991698742, 37.823447808623314, 57.000140994787216, 52.31287211179733, 54.100501388311386, 50.3583025932312, 52.7350864559412, 54.73992347717285, 53.84455472230911, 53.27966183423996, 53.10420244932175, 46.59297063946724, 43.829793110489845, 38.11928853392601, 38.95112469792366, 39.504743590950966, 39.037053287029266, 47.199053317308426, 55.05349405109882, 53.927340880036354, 51.31808929145336, 48.86251285672188, 48.731412291526794, 45.42546808719635, 49.11637343466282, 48.176942244172096, 48.90721745789051, 50.41951350867748, 48.56678992509842, 43.82043041288853, 47.02981419861317, 51.09814569354057, 47.48594932258129, 48.65879438817501, 53.877563551068306, 54.55209195613861, 53.21142889559269, 54.535023272037506, 56.450599282979965, 56.791908368468285, 60.614229664206505, 49.45656917989254, 46.561797112226486, 38.752836138010025, 27.188593670725822, 13.441016860306263, 9.98137280344963, 4.405049001798034, 13.089702911674976, 22.19682812690735, 11.850653998553753, 6.452209576964378, 8.741903062909842, 1.3436846109107137, 0.13757633802015334, 0.13532746728742495, 0.09337756244349293, 2.1308175986632705, 22.578909024596214, 40.15282541513443, 24.365071579813957, 23.320492431521416, 38.8741522282362, 43.834406062960625, 44.28984582424164, 37.29832738637924, 10.762861669063568, 0.9052470966707915, 0.10824724813573994, 0.04939936799928546, 0.0088628611410968, 0.07455703875166364, 0.02878527004213538, 0.012872701736341696, 0.012993602231290424, 0.09418504138011485, 0.023122473612602334, 0.015401166401716182, 0.04819483634491917, 0.08239175818744116, 0.04017972307337914, 0.035309252780280076, 0.015844368645048235, 0.05030613887356594, 0.022234169227886014, 0.025754825037438422, 0.022033529603504576, 0.04262161528458819, 0.026243763059028424, 0.02196267305407673, 0.04881380606093444, 0.015215059884212678, 0.009460619348828914, 0.0430363199848216, 0.02005496760830283, 0.05037768933107145, 0.048622120448271744, 0.051290772171341814, 0.04353586700744927, 0.017771596285456326, 0.028878240736958105, 0.02055596367426915, 0.0784595258301124, 0.04485458179260604, 0.07219006263767369, 0.05237104604020715, 0.04301057859265711, 0.046041294481256045, 0.05432467929495033, 0.03485148867184762, 4.553968235850334, 33.751951083540916, 54.6306337416172, 49.64945062994957, 31.675136424601078, 19.074744656682014, 17.97592531889677, 36.98450982570648, 44.592427387833595, 19.94153704494238, 1.634771078824997, 0.05586088045674842, 0.15034942683996633, 0.7077538222074509, 4.194416804239154, 10.341668520122766, 10.142201073467731, 9.877824559807777, 15.702054183930159, 14.364239070564508, 16.47037200629711, 33.274886682629585, 41.682839915156364, 54.282492622733116, 54.148230627179146, 52.855391800403595, 56.47539675235748, 53.389901518821716, 52.541137263178825, 52.89240941405296, 52.52635605633259, 53.739999532699585, 54.44814093410969, 55.56727968156338, 52.844930961728096, 56.563080847263336, 53.79227712750435, 56.681759878993034, 53.259215131402016, 51.53148204088211, 49.857987239956856, 52.03041806817055, 54.47694718837738, 54.65003550052643, 52.100269719958305, 50.11981979012489, 44.74989093840122, 42.09363207221031, 39.81874354183674, 42.071741446852684, 39.94823299348354, 41.741778552532196, 42.889404371380806, 51.96833319962025, 55.7773058116436, 57.12322399020195, 57.609776481986046, 55.998051166534424, 55.43661989271641, 55.522514283657074, 53.85754242539406, 57.02202782034874, 55.74570670723915, 55.23776136338711, 49.115203097462654, 54.624402076005936, 19.24715280532837, 37.39671930670738, 56.853495463728905, 54.14778985083103, 55.90557172894478, 52.92360574007034, 54.501322880387306, 55.91679632663727, 54.846009984612465, 55.00129625201225, 53.865677788853645, 49.221836775541306, 46.00884698331356, 40.08860886096954, 40.96781708300114, 40.9574968367815, 42.515679225325584, 49.08362679183483, 57.20952495932579, 54.768714532256126, 53.695579916238785, 49.11484971642494, 49.773350581526756, 46.10976576805115, 49.71138350665569, 48.12379069626331, 49.64177884161472, 49.71469692885876, 48.352690413594246, 48.66919822990894, 49.28578734397888, 50.171778202056885, 47.40630939602852, 48.78594696521759, 54.438371658325195, 53.163627460598946, 53.3988082408905, 54.949014857411385, 57.19348601996899, 57.72587165236473, 58.39103735983372, 50.77110104262829, 49.62457716464996, 42.64508128166199, 28.928930684924126, 15.112230833619833, 8.470494076609612, 7.219633497297764, 12.731348890811205, 10.666359197348356, 14.836794063448906, 14.359329733997583, 11.332073975354433, 4.818418370559812, 0.5042289651464671, 0.18440371903125197, 0.08842712573823519, 2.662902809679508, 23.540789410471916, 39.986257553100586, 22.761122547090054, 24.972605779767036, 46.32757768034935, 50.38625009357929, 50.51133558154106, 44.00183267891407, 13.042421098798513, 0.9510456828866154, 0.0706537056248635, 0.009038119314936921, 0.029677582024305593, 0.04723108337202575, 0.04487138030526694, 0.056181083782576025, 0.03991370394942351, 0.08805568082607351, 0.03073860272706952, 0.07044892481644638, 0.011705813667504117, 0.08311887737363577, 0.058874315436696634, 0.05990117322653532, 0.03543934384651948, 0.027962437925452832, 0.017371161229675636, 0.030882058017596137, 0.04572577781800646, 0.030825699323031586, 0.05197359627345577, 0.17614514421438798, 0.07740768734947778, 0.1431561159552075, 0.0688877355423756, 0.08685585809871554, 0.1947376801399514, 0.15203555667540058, 0.10790839092805982, 0.18656834115972742, 0.14756211312487721, 0.04103901876078453, 0.16670962708303705, 0.15764129493618384, 0.16067923192167655, 0.12261717900400981, 0.12628868746105582, 0.10454819857841358, 0.08223601107602008, 0.11096661823103204, 0.24352542939595878, 0.1554032595595345, 6.44526687450707, 41.102831438183784, 62.38593399524689, 56.36567384004593, 38.35300639271736, 25.967943370342255, 27.45273269712925, 49.35021668672562, 53.85927893221378, 23.189405165612698, 2.1686148829758167, 0.20113886712351814, 0.2226079229149036, 1.2256900174543262, 5.770793091505766, 15.615612622350454, 13.216509707272053, 13.219027072191238, 21.890699453651905, 26.049844175577164, 22.094144336879253, 36.57220534980297, 42.69953615963459, 54.43458706140518, 55.04703439772129, 52.073462158441544, 57.76491455733776, 54.82419915497303, 54.94064010679722, 53.84833171963692, 52.37352445721626, 55.4916675388813, 57.812613397836685, 59.34592232108116, 55.399925261735916, 59.28430862724781, 56.23288616538048, 58.91663655638695, 54.53019753098488, 51.19477450847626, 49.7910500317812, 53.44143055379391, 56.71246983110905, 56.57893359661102, 52.77494631707668, 51.989931240677834, 46.765044406056404, 44.05103623867035, 41.99614070355892, 44.71850462257862, 42.496429458260536, 44.3026777356863, 45.78282371163368, 53.57175976037979, 58.108799904584885, 59.565330147743225, 58.48879091441631, 57.03826814889908, 57.07381524145603, 55.5602690577507, 55.18322288990021, 58.13601404428482, 56.48963078856468, 55.35640239715576, 50.28311222791672, 56.566553860902786, 22.244393974542618, 40.2900018543005, 58.600630313158035, 57.86222353577614, 57.5665196031332, 55.50983816385269, 56.3233745098114, 58.06798629462719, 57.56588503718376, 56.42414890229702, 55.384745076298714, 50.735717341303825, 49.08292382955551, 41.50434449315071, 42.88465462625027, 43.68583023548126, 44.55566816031933, 49.93028216063976, 60.06910711526871, 58.78438465297222, 55.52143134176731, 51.19256302714348, 49.61426831781864, 47.15762414038181, 49.83035512268543, 47.7402126789093, 49.33672361075878, 51.35251924395561, 47.85013698041439, 50.12197807431221, 51.33668169379234, 51.27073623239994, 48.417826518416405, 48.96256908774376, 55.74572570621967, 56.20246879756451, 55.012444853782654, 57.02000632882118, 58.508276268839836, 58.53055827319622, 62.24004842340946, 51.60883828997612, 52.61593624949455, 46.211843490600586, 34.659220799803734, 16.49805922061205, 13.562527690082788, 8.488912638276815, 20.449459590017796, 30.67494459450245, 22.859884947538376, 15.921707097440958, 15.62901545315981, 5.04118949174881, 0.8588174474425614, 0.6064636667724699, 0.4023917281301692, 3.399854265153408, 29.435749389231205, 51.615111753344536, 34.677410423755646, 34.07434858381748, 49.70946080982685, 57.351344749331474, 57.8729123622179, 52.219473123550415, 17.33290672302246, 1.389157958328724, 0.22392159851733595, 0.20091743994271383, 0.07755377911962569, 0.1421688517439179, 0.11022378777852282, 0.15302911429898813, 0.18828672473318875, 0.1910777046578005, 0.06302765585132875, 0.1500121207209304, 0.14577373018255457, 0.24360510637052357, 0.13903391605708748, 0.1656272789114155, 0.10885487412451766, 0.20808051573112607, 0.10598903376376256, 0.08532375359209254, 0.14005089586135, 0.12264323580893688, 0.14947339572245255], [0.0330373828910524, 0.033308259371551685, 0.02725260335864732, 0.04939763508446049, 0.04460513111553155, 0.06861170113552362, 0.054594872999587096, 0.03680186389829032, 0.018829947111953516, 0.024900353309931234, 0.06833346997154877, 0.08387292167753913, 0.008496007339999778, 0.0736075424356386, 0.0235498486290453, 0.04568635864416137, 0.08251514023868367, 0.011980821127508534, 0.05858592798176687, 0.03191519252141006, 0.07248804235132411, 5.539100049063563, 31.31042629480362, 48.20557750761509, 41.636904180049896, 28.277921117842197, 19.38966605812311, 24.77358005940914, 34.29330423474312, 35.59859499335289, 11.664529535919428, 0.6436773855239153, 0.029049307631794363, 0.2464352865354158, 0.10909769000136293, 4.359416775405407, 8.600583896040916, 14.358359836041927, 11.62557877600193, 19.882340021431446, 15.310707483440638, 16.352021656930447, 36.25957332551479, 47.705862522125244, 53.101413398981094, 54.918753281235695, 59.9048837274313, 52.69589155912399, 51.65482722222805, 51.33113779127598, 50.038006380200386, 49.417024701833725, 50.79725503921509, 54.79034297168255, 50.53124651312828, 47.55192518234253, 47.04272210597992, 51.35004937648773, 51.87991954386234, 55.617550984025, 57.61363327503204, 52.96323761343956, 49.90163929760456, 53.899351581931114, 52.36617565155029, 49.40538972616196, 44.833269864320755, 39.52152729034424, 39.20096129179001, 38.62775444984436, 40.16848437488079, 38.825108259916306, 41.03196524083614, 45.57517245411873, 51.01931892335415, 55.82539603114128, 54.54503953456879, 50.675699561834335, 51.482848450541496, 50.00532053411007, 50.05609340965748, 52.38414868712425, 53.644248470664024, 49.249267503619194, 51.83603189885616, 44.128791466355324, 43.405131697654724, 18.344123661518097, 42.81106777489185, 52.48858228325844, 52.07778252661228, 50.23276872932911, 49.2876910418272, 48.84157598018646, 49.074256494641304, 50.83698570728302, 50.61054065823555, 49.79222796857357, 46.31400480866432, 41.36069320142269, 39.025365114212036, 37.88411535322666, 38.5295183211565, 37.484205812215805, 40.89272931218147, 48.755723387002945, 53.38314548134804, 54.41164009273052, 54.81446027755737, 51.78688533604145, 50.4103560000658, 46.518327444791794, 50.07259592413902, 53.487210497260094, 54.32383820414543, 51.196530014276505, 49.60006467998028, 52.81925193965435, 49.321805611252785, 50.04527539014816, 51.50981940329075, 54.05749149620533, 53.63235130906105, 54.83379743993282, 53.89300972223282, 57.39625833928585, 53.54961834847927, 54.99861739575863, 58.61585609614849, 52.04398714005947, 45.05571752786636, 36.15343742072582, 24.51033018529415, 13.15946051850915, 8.75352568924427, 10.637723933905363, 6.555114705115557, 14.114867001771927, 11.12821776419878, 3.710897737182677, 2.1735826414078474, 0.32649878645315766, 0.0587776284373831, 0.043618508861982264, 0.8178771380335093, 11.478317677974701, 42.169703990221024, 51.34450167417526, 27.50518698245287, 24.40597828477621, 33.96516144275665, 47.56309658288956, 42.00704611837864, 18.440676480531693, 1.258450672030449, 0.025409364570805337, 0.07394708241918124, 0.04046742775244638, 0.10059019885375164, 0.03040013885765802, 0.009565731579641579, 0.041694350002217107, 0.012042962080158759, 0.06307304560323246, 0.004499726710491814, 0.08592813639552332, 0.01318362357778824, 0.021689833592972718, 0.04884054564172402, 0.01135958786107949, 0.025518232068861835, 0.02512706458219327, 0.0638658448588103, 0.12033809543936513, 0.06780881609302014, 0.009886522129818331, 0.021149243948457297, 0.03140896245895419, 0.03642595125711523, 0.03177049969963264, 0.020454176265047863, 0.029832516484020744, 0.06140122437500395, 0.018631624843692407, 0.12031482910970226, 0.03963653034588788, 0.056981794332386926, 0.0399932028085459, 0.03838202617771458, 0.041920089061022736, 0.04189552768366411, 0.027070304058725014, 0.04904347479168791, 0.06419137309421785, 0.03857542615151033, 0.0506639765080763, 0.04546705400571227, 6.678782869130373, 39.16760288178921, 55.38448289036751, 47.07044541835785, 33.029062673449516, 23.073226399719715, 27.68242847174406, 38.6074635386467, 41.46312050521374, 13.218478001654148, 0.7512680778745562, 0.031696247824584134, 0.4613870062166825, 1.0816088737919927, 6.731686955317855, 10.662673395127058, 12.594478335231543, 13.912348318845034, 9.693905878812075, 6.581434942781925, 18.998005874454975, 35.16921803355217, 48.67012158036232, 55.09195938706398, 55.18498219549656, 56.47714465856552, 53.83803807199001, 53.65751355886459, 51.57908208668232, 52.160390093922615, 50.563442185521126, 51.24829463660717, 56.07298694550991, 53.82805220782757, 50.64141020178795, 51.520793214440346, 53.572310730814934, 53.72264586389065, 56.35875441133976, 58.67535710334778, 51.81823365390301, 52.046939581632614, 55.863352194428444, 54.75194223225117, 51.74994371831417, 46.311246156692505, 41.59027688205242, 41.297137811779976, 41.23430818319321, 41.83899253606796, 41.119588539004326, 43.63407701253891, 48.10813553631306, 55.04217445850372, 56.800355315208435, 55.21989852190018, 51.748917773365974, 51.2743916362524, 50.07785104215145, 50.26350907981396, 51.6282020509243, 53.98142337799072, 49.677873104810715, 50.76408661901951, 46.95048205554485, 46.61218620836735, 19.729641415178776, 43.68593282997608, 55.32090850174427, 54.094797894358635, 53.46210904419422, 51.43941678106785, 51.59306913614273, 52.14457534253597, 53.061428144574165, 52.91183017194271, 53.10323350131512, 47.900742664933205, 42.95906223356724, 40.4146883636713, 39.60785485804081, 40.10145217180252, 38.525353744626045, 44.96352307498455, 50.95112398266792, 55.824199095368385, 56.03741705417633, 55.075525268912315, 52.426512613892555, 51.03232562541962, 47.74204798042774, 51.050579845905304, 55.085917711257935, 55.87680347263813, 53.68326857686043, 50.31576007604599, 52.88130261003971, 50.134570598602295, 50.73730565607548, 51.93709887564182, 57.17091143131256, 56.01890064775944, 57.03973487019539, 55.74072517454624, 58.05978633463383, 56.132313162088394, 56.415758952498436, 59.08412016928196, 52.712048292160034, 49.09608252346516, 39.37427759170532, 25.76354093849659, 12.370657045394182, 9.050501603633165, 6.895259153097868, 10.83751056343317, 13.467094860970974, 12.612923495471478, 11.827844772487879, 6.1591042298823595, 0.8285716641694307, 0.06452254907344468, 0.08053592886426486, 0.7564818137325346, 15.28211496770382, 42.61731617152691, 43.374357149004936, 31.370056495070457, 30.952219516038895, 38.58349822461605, 52.621521949768066, 49.36587564647198, 23.179943673312664, 1.7867423803545535, 0.04815177322598174, 0.06047057489922736, 0.05896068658330478, 0.04434327915078029, 0.03218040641513653, 0.04338171551353298, 0.08294348561321385, 0.042958884296240285, 0.08999053403385915, 0.06198311268235557, 0.03809854060818907, 0.029539126953750383, 0.021999869495630264, 0.02181605806981679, 0.026518689810473006, 0.028492233032011427, 0.017337549361400306, 0.08146943931933492, 0.08105649350909516, 0.026488072508072946, 0.022751232791051734, 0.08930406969739124, 0.06566373471287079, 0.1429492942406796, 0.1363073693937622, 0.13404465018538758, 0.0990648775768932, 0.19469086546450853, 0.11332772395689972, 0.22189837036421522, 0.16779417201178148, 0.2218891232041642, 0.16622985829599202, 0.14342928567202762, 0.173147639434319, 0.10619670152664185, 0.20975147606804967, 0.13307346089277416, 0.1320374821079895, 0.16806861822260544, 0.1355563011020422, 0.1637322493479587, 9.40446401014924, 47.868543192744255, 64.06017735600471, 55.88661454617977, 41.61001302301884, 29.824618622660637, 33.51325549185276, 45.19599460065365, 46.8426438421011, 15.006301067769527, 0.9860028570983559, 0.13297338970005512, 0.7012889441102743, 1.3032237882725894, 11.215804014354944, 15.041337087750435, 24.755618423223495, 23.29911857843399, 29.887790232896805, 22.604249864816666, 19.988189041614532, 39.339995831251144, 49.85744006931782, 55.68483017385006, 55.79093188047409, 60.246606990695, 59.22779805958271, 53.17292556166649, 53.57915036380291, 51.896935030817986, 50.4444819688797, 51.06758773326874, 58.51904109120369, 55.54706856608391, 53.57596233487129, 52.37652629613876, 56.86299875378609, 57.26901836693287, 59.86345075070858, 60.39361730217934, 52.78579093515873, 52.09200136363506, 57.84740433096886, 57.33893841505051, 53.66156794130802, 49.09932754933834, 44.09194104373455, 43.71123567223549, 43.15902270376682, 43.98722626268864, 44.18427608907223, 45.57730793952942, 50.526979342103004, 55.50771027803421, 59.23231981694698, 54.505137875676155, 52.50755086541176, 51.87419705092907, 50.212451219558716, 49.77123409509659, 52.2799164801836, 52.94007025659084, 50.06990946829319, 53.23289394378662, 47.765169739723206, 47.98679664731026, 24.21070486307144, 43.85100357234478, 55.62825120985508, 57.356577068567276, 54.60886850953102, 53.477874398231506, 53.628521114587784, 53.38137857615948, 54.77502219378948, 55.84246091544628, 54.675433337688446, 50.02939984202385, 45.20314581692219, 43.602515906095505, 42.400317415595055, 42.77990184724331, 41.064962670207024, 46.5248516947031, 52.585332691669464, 57.68762670457363, 59.531656354665756, 58.7876220792532, 54.33365307748318, 53.056222423911095, 48.841929361224174, 51.027154102921486, 58.49456660449505, 57.94254742562771, 56.122213304042816, 52.33811415731907, 53.692038506269455, 52.24018581211567, 49.760305881500244, 54.352294877171516, 58.853468745946884, 58.92908088862896, 60.55011950433254, 58.301749750971794, 61.562028005719185, 58.8233857601881, 60.339128226041794, 63.493870943784714, 57.27396570146084, 52.19152182340622, 44.15400691330433, 28.51062823086977, 16.651892066001892, 14.948870949447155, 20.747564993798733, 16.068471372127533, 27.285193987190723, 23.902003727853298, 11.109005995094776, 7.148542162030935, 1.7827801429666579, 0.12333753722487018, 0.32029478810727596, 1.037594173103571, 16.56264815479517, 54.59576681256294, 64.03959766030312, 37.883397191762924, 37.77315750718117, 46.18545010685921, 59.44794684648514, 55.923601761460304, 28.433180786669254, 2.8975478187203407, 0.20068348530912772, 0.15220268833218142, 0.14422517968341708, 0.1962263393215835, 0.10520283962250687, 0.06777699280064553, 0.1853040183777921, 0.14218924596207216, 0.12508897605584934, 0.12616630730917677, 0.1341416934155859, 0.09084346209419891, 0.05660167371388525, 0.1544588469550945, 0.16546421422390267, 0.1794388995040208, 0.10893435071920976, 0.1620155430282466, 0.22536783653777093, 0.11566156317712739, 0.16093787038698792], [0.037332540305214934, 0.021704465034417808, 0.011691737909131916, 0.05721977511711884, 0.03438385399931576, 0.05109472644107882, 0.04393239280034322, 0.04115435222047381, 0.005251844677331974, 0.011356264894857304, 0.03605579768191092, 0.027034450904466212, 0.05487818787514698, 0.0716631452087313, 0.06828292971476912, 0.08441346493782476, 0.04974646304617636, 0.03445703347097151, 0.045854848431190476, 0.04531800848781131, 0.10672994205378927, 10.443548653274775, 33.25016900897026, 50.853959396481514, 40.61435244977474, 27.472495436668396, 16.726191379129887, 19.1861242800951, 39.117589965462685, 31.439531967043877, 5.920320767909288, 0.025719864315760788, 0.07881941550294869, 0.29976656776852906, 0.9952168283052742, 4.049519654363394, 8.88313578441739, 6.330708246678114, 8.452284503728151, 7.7529120817780495, 9.3021279014647, 22.164885140955448, 40.01447483897209, 45.526573061943054, 61.668376699090004, 59.132711961865425, 52.64552526175976, 52.00474664568901, 50.98088398575783, 52.88702130317688, 52.44195498526096, 52.40864597260952, 52.95370392501354, 50.993693098425865, 50.104745998978615, 46.71928346157074, 42.80495010316372, 46.300982907414436, 50.39475403726101, 50.99605277180672, 52.661043629050255, 52.54083327949047, 51.73851013183594, 50.738950967788696, 52.86152087152004, 47.27519363164902, 44.38580967485905, 40.21244041621685, 38.189333975315094, 36.83594919741154, 37.95872054994106, 37.53612242639065, 39.84514832496643, 48.45374219119549, 54.079765900969505, 53.74005272984505, 48.45087714493275, 52.069080993533134, 51.34787209331989, 49.92500424385071, 50.924362018704414, 49.677607119083405, 53.009925708174706, 51.42658106982708, 50.47845594584942, 47.34587363898754, 48.30554634332657, 17.414169162511826, 42.83793993294239, 51.347195729613304, 47.69760176539421, 46.371469125151634, 40.578090995550156, 42.65678845345974, 43.736804500222206, 44.04821678996086, 45.098963007330894, 43.552077412605286, 40.89537397027016, 41.14981971681118, 39.24903251230717, 37.737739607691765, 37.80906558036804, 37.88033075630665, 37.82867632806301, 41.65353588759899, 45.30251048505306, 50.28274744749069, 49.91278789937496, 50.02942644059658, 53.37075054645538, 50.855965688824654, 54.53431650996208, 50.70484399795532, 50.19543573260307, 51.5392792224884, 53.19913275539875, 52.57048688828945, 52.211998924613, 53.085670843720436, 52.249632105231285, 51.97947420179844, 50.992990136146545, 51.20919853448868, 50.78014835715294, 53.578777983784676, 52.67841249704361, 52.11368300020695, 51.8605025857687, 50.404105335474014, 46.994852274656296, 44.71267193555832, 30.65650798380375, 20.377299562096596, 11.198802776634693, 7.252100855112076, 7.990757469087839, 11.56828735023737, 16.254811473190784, 16.690862774848938, 8.745843451470137, 0.38689025212079287, 0.39809846319258213, 0.1225930146756582, 0.2311090612784028, 7.311043292284012, 28.97513810545206, 27.98952989280224, 23.025206476449966, 26.967740021646023, 41.48211568593979, 48.086165115237236, 48.721130043268204, 16.95571046322584, 3.0717537458986044, 0.1565618856693618, 0.07871967085520737, 0.04953164840117097, 0.08363796514458954, 0.07783019202179275, 0.06940653387573548, 0.06051093660062179, 0.04448722982488107, 0.03666061835247092, 0.09278489073039964, 0.020678956097981427, 0.041498582577332854, 0.05661184484779369, 0.02991106353874784, 0.03003776670084335, 0.02578114716015989, 0.01394271726894658, 0.07638751631020568, 0.028210949785716366, 0.05769286828581244, 0.050179680620203726, 0.06143558210169431, 0.06666177490842529, 0.013658894022228196, 0.035469578942866065, 0.014183393905113917, 0.08679360675159842, 0.015989720122888684, 0.027726049047487322, 0.016026933262764942, 0.028214439735165797, 0.08136864824336953, 0.04607727751135826, 0.0560575050621992, 0.017411335538781714, 0.09128357050940394, 0.07378922760835849, 0.04228347424941603, 0.02453868990414776, 0.011850452683574986, 0.043923064004047774, 0.09402073730598204, 11.92427409812808, 40.46190842986107, 56.859062165021896, 47.751319482922554, 32.33638644218445, 20.155507363379, 22.992651723325253, 35.88327571749687, 33.2916209846735, 7.457721121609211, 0.07076809284626506, 0.03268297768954653, 0.2713696227874607, 1.7131356988102198, 6.393094249069691, 13.605960309505463, 11.530792862176895, 15.293146725744009, 7.8642921801656485, 9.232146106660366, 21.5529602766037, 39.51074726879597, 47.99250394105911, 58.68286930024624, 56.63900077342987, 57.72075712680817, 54.84968438744545, 52.89538465440273, 55.22291176021099, 52.83534787595272, 54.836046919226646, 53.96205961704254, 53.70270073413849, 50.6429985165596, 48.8801135122776, 45.14483794569969, 49.13792967796326, 52.37679988145828, 53.40101972222328, 55.11977009475231, 53.67625035345554, 54.177891835570335, 52.34909176826477, 54.00594346225262, 50.20713910460472, 45.963298827409744, 41.86555691063404, 40.15447832643986, 39.04698595404625, 39.60169918835163, 40.60184732079506, 41.9165463745594, 50.72178728878498, 56.180232390761375, 54.34234321117401, 49.72004324197769, 51.33224733173847, 51.719161570072174, 50.099772065877914, 51.01649567484856, 50.79257749021053, 51.8989185243845, 50.535194501280785, 50.14987997710705, 46.730428263545036, 49.27197888493538, 19.19395375996828, 44.3879109621048, 53.81251484155655, 48.669790998101234, 48.51154088973999, 44.68296892940998, 45.53292252123356, 46.49680159986019, 46.86962999403477, 48.326141238212585, 45.86294621229172, 45.011753886938095, 42.61535167694092, 41.787250712513924, 40.0307759642601, 39.829219579696655, 38.98415632545948, 38.691644221544266, 43.78412336111069, 48.74829478561878, 52.985417023301125, 52.73687236011028, 52.815972715616226, 55.66780708730221, 50.596147030591965, 56.42508365213871, 53.31307724118233, 54.69035513699055, 53.78484092652798, 55.60900904238224, 54.92175132036209, 52.91334629058838, 54.17823001742363, 54.291547536849976, 53.62031735479832, 54.61479239165783, 53.29165019094944, 53.934279307723045, 54.751718044281006, 55.359415635466576, 52.64288820326328, 55.994502156972885, 52.337270602583885, 52.8542822599411, 45.82157403230667, 34.057568684220314, 20.62879666686058, 10.343993995338678, 3.538811858743429, 8.567695710808039, 13.64404471591115, 11.29875736311078, 16.011191345751286, 9.02853213250637, 2.674835119396448, 0.5829073651693761, 0.04745022473798599, 0.3105873480672017, 8.365852441638708, 33.8737041503191, 35.3586682677269, 25.420742332935333, 29.966579005122185, 45.01739278435707, 53.440218418836594, 53.34690682590008, 21.710055246949196, 3.452185532078147, 0.10741205740487203, 0.04698335818829946, 0.02656931355886627, 0.07823471445590258, 0.005603929739663727, 0.03031686988833826, 0.0017186000718538708, 0.07364079065155238, 0.03990568504377734, 0.06545888711116277, 0.030042709404369816, 0.12168595436378382, 0.005764121851825621, 0.09651320317061618, 0.026030386325146537, 0.037713904021074995, 0.01153079390860512, 0.07977363929967396, 0.009469037158851279, 0.06841961847385392, 0.036840815519099124, 0.1292312436271459, 0.20640391507185996, 0.12249752253410406, 0.24313894857186824, 0.07585471365018748, 0.2519550989381969, 0.12782221689121798, 0.09467900745221414, 0.16423533641500399, 0.128951869555749, 0.19080009689787403, 0.14355310559039935, 0.26165689865592867, 0.18706835573539138, 0.17222935042809695, 0.17212559818290174, 0.16884370241314173, 0.1382121062488295, 0.12032123384415172, 0.1033178142097313, 0.2691905584651977, 15.484891086816788, 50.21450310945511, 64.97250080108643, 54.58988852798939, 38.75625595450401, 26.2566651776433, 28.17868184298277, 49.964499324560165, 40.70239372551441, 8.850776720792055, 0.33938009524717927, 0.3337287297472358, 0.563045177841559, 2.0704136649146676, 9.168697111308575, 22.287295572459698, 17.75195013731718, 17.220474556088448, 17.35596388578415, 14.194899257272482, 29.057069309055805, 42.97481618821621, 48.79919685423374, 61.577591970562935, 58.53692293167114, 56.797756254673004, 57.45597593486309, 54.000779539346695, 53.22708025574684, 52.15519197285175, 53.97329941391945, 55.34788325428963, 56.02040156722069, 54.23402242362499, 50.683021768927574, 47.58138120174408, 51.91407971084118, 53.732985109090805, 56.06965072453022, 57.36848942935467, 55.335302129387856, 54.908832013607025, 53.94533671438694, 57.01838381588459, 51.659470573067665, 49.09285269677639, 44.11037765443325, 42.43947051465511, 40.95511436462402, 41.67380020022392, 41.47919364273548, 43.50107654929161, 52.9558964073658, 57.79440477490425, 53.77753011882305, 50.53519830107689, 50.67812763154507, 51.3478796929121, 50.20024247467518, 50.79729303717613, 51.75336733460426, 52.62177653610706, 52.0404951274395, 51.97813667356968, 48.18511560559273, 50.38350664079189, 21.921392306685448, 47.02680855989456, 55.13970002532005, 52.17236705124378, 50.869945138692856, 47.112949937582016, 46.960885897278786, 47.62519285082817, 48.06541062891483, 48.84339988231659, 48.23717661201954, 46.973558217287064, 44.499275386333466, 44.556549713015556, 42.44517780840397, 42.07605041563511, 41.434777826070786, 40.87676256895065, 46.92444585263729, 50.19569031894207, 55.65932974219322, 54.58922356367111, 54.857508167624474, 57.62720234692097, 52.41817206144333, 58.45792897045612, 54.26732003688812, 56.65701560676098, 56.41620732843876, 57.18014493584633, 57.88095273077488, 53.82150515913963, 57.62902244925499, 57.959239929914474, 57.22103834152222, 56.95975676178932, 56.77465349435806, 54.437737092375755, 58.65472421050072, 57.792675867676735, 55.97287751734257, 57.96145141124725, 55.84312587976456, 54.722604006528854, 52.06678591668606, 34.72248740494251, 22.855708971619606, 14.800796695053577, 15.020017381757498, 16.49065151810646, 21.98284450918436, 26.455992981791496, 27.419068403542042, 17.694176137447357, 2.1181564405560493, 1.180689507164061, 0.27542721130885184, 0.6755282264202833, 9.699783213436604, 40.27815788984299, 39.63823422789574, 34.46934498846531, 38.683497458696365, 53.4638075530529, 60.32427102327347, 63.09926211833954, 28.49682927131653, 5.395905207842588, 0.32153298729099333, 0.1541537352022715, 0.1369381949189119, 0.19921603670809418, 0.1461773249320686, 0.20274569105822593, 0.09282188679208048, 0.1709919676068239, 0.1318694301880896, 0.21143251477042213, 0.2261319220997393, 0.18702201603446156, 0.12182717764517292, 0.20787283312529325, 0.0923460884951055, 0.17271708988118917, 0.11664846373605542, 0.14922890259185806, 0.10521565651288256, 0.13404395256657153, 0.11338561147567816], [0.062413187260972336, 0.023478283328586258, 0.039898953764350154, 0.006233389249246102, 0.05391688770032488, 0.02128272291884059, 0.05682923103449866, 0.015032823666842887, 0.06986020132899284, 0.04783002623298671, 0.03649357575341128, 0.09533083575661294, 0.04545955089270137, 0.03722137029399164, 0.011252199092268711, 0.047482018344453536, 0.03510757414915133, 0.0333883074199548, 0.04352522832050454, 0.06318023399217054, 0.11761183079215698, 8.767397794872522, 37.17942796647549, 47.69900768995285, 41.217053309082985, 30.44640015810728, 22.128798477351665, 25.42279042303562, 41.545397490262985, 26.963602043688297, 2.9893190693110228, 0.0472143850493012, 0.10398685291875154, 0.3809868235839531, 1.5994516178034246, 5.726164961233735, 10.18035577610135, 11.08415437862277, 15.56386224925518, 3.276764857582748, 6.439528232440352, 27.33014367520809, 41.07208348810673, 62.44578458368778, 61.82373896241188, 47.9233780503273, 42.98863984644413, 51.42406180500984, 48.296092450618744, 51.115305572748184, 55.23295842111111, 52.24284566938877, 52.41429626941681, 51.84469923377037, 51.240220069885254, 46.33173085749149, 41.189725175499916, 40.7386589795351, 44.36129339039326, 49.192825332283974, 53.79485718905926, 54.382700845599174, 49.992496222257614, 51.96261830627918, 52.520325779914856, 47.22292743623257, 43.96229960024357, 38.50364550948143, 39.51472565531731, 36.373616605997086, 38.683995231986046, 36.75201550126076, 42.77719259262085, 48.4653277695179, 54.492138773202896, 44.203799441456795, 47.4142699688673, 53.46173286437988, 49.949946105480194, 52.81193733215332, 51.429598107934, 50.621769055724144, 51.743062287569046, 52.118311151862144, 52.885721772909164, 50.594201534986496, 49.76830445230007, 18.181251101195812, 40.12923628091812, 52.8433882445097, 53.62286701798439, 50.3041061013937, 40.988662764430046, 41.2085797637701, 38.68594832718372, 40.90427689254284, 40.04771925508976, 39.67391051352024, 39.73629176616669, 39.155990704894066, 39.52785015106201, 39.916128516197205, 37.73813858628273, 37.95958690345287, 39.18079197406769, 39.69370745122433, 38.024912998080254, 43.420482873916626, 46.693406850099564, 53.06104816496372, 51.61588691174984, 51.5530800819397, 53.97104233503342, 48.939720913767815, 50.34911848604679, 48.29140730202198, 51.032830998301506, 53.15510831773281, 51.44583463668823, 51.258424893021584, 49.410405457019806, 45.14331802725792, 44.93796564638615, 42.0786152780056, 43.84250722825527, 41.57208725810051, 43.08996520936489, 44.76879872381687, 51.03054732084274, 53.26404467225075, 52.09564916789532, 41.48128353059292, 40.58885961771011, 20.291357673704624, 14.508220944553614, 4.234536001458764, 9.634438119828701, 9.247849714010954, 6.319470824673772, 12.613664455711842, 6.401519346982241, 2.0165859907865524, 0.08247504942119122, 0.060870915331179276, 0.07898541909526102, 4.2295516189187765, 25.156001038849354, 43.05208124220371, 44.12267379462719, 26.722584776580334, 30.640417747199535, 43.14164623618126, 53.585955798625946, 26.763704270124435, 6.7969802767038345, 0.266622697818093, 0.050902595539810136, 0.022925858283997513, 0.04111258043849375, 0.04053196491440758, 0.040463093610014766, 0.01904557069792645, 0.05167639581486583, 0.016538126437808387, 0.05976984277367592, 0.058262166057829745, 0.07278249686351046, 0.041843072685878724, 0.05655734523315914, 0.042724091035779566, 0.008504137567797443, 0.01464421287892037, 0.04903122564428486, 0.020917235597153194, 0.003156514094371232, 0.03639082169684116, 0.043726131407311186, 0.0421712503884919, 0.03773929289309308, 0.016199488163692877, 0.04429913991771173, 0.028719016663671937, 0.02126998395397095, 0.060956373636145145, 0.03986365351011045, 0.06621865337365307, 0.05727624142309651, 0.043660900337272324, 0.06242679824936204, 0.02283105448441347, 0.03529060631990433, 0.07397564026177861, 0.05770499868958723, 0.039637183435843326, 0.02222835821157787, 0.023191591681097634, 0.1116564370749984, 11.787403542548418, 43.138135224580765, 55.50027407705784, 45.88129922747612, 35.715564116835594, 25.254316963255405, 24.717717356979847, 46.773354560136795, 29.611748345196247, 3.6931838002055883, 0.07894968468463048, 0.04536463020485826, 0.9849741810467094, 3.5226016910746694, 8.843027036637068, 12.958095073699951, 9.796189740300179, 12.967741806060076, 6.587179284542799, 10.93868488445878, 27.872431576251984, 42.12349846959114, 59.57881182432175, 62.301612719893456, 52.18259610235691, 48.14193092286587, 55.237339586019516, 52.83727057278156, 53.53364400565624, 55.966505259275436, 52.833250388503075, 53.188804909586906, 54.17470760643482, 53.85943092405796, 47.62825548648834, 44.73577469587326, 42.83969163894653, 46.28207512199879, 51.108093559741974, 55.19440568983555, 55.94303011894226, 51.79173767566681, 53.3700779825449, 53.823530450463295, 46.96120128035545, 46.12271547317505, 39.92407388985157, 41.788014471530914, 38.472787365317345, 41.14132717251778, 37.543262243270874, 45.47839164733887, 49.8450793325901, 56.18327982723713, 45.87824039161205, 47.50624783337116, 54.27046626806259, 50.16538314521313, 54.17500399053097, 52.788633182644844, 54.45943012833595, 52.22229637205601, 53.81880730390549, 54.42924074828625, 50.98549693822861, 49.0902004390955, 19.75640717893839, 42.478730008006096, 55.814114436507225, 55.782427936792374, 51.727779507637024, 42.62503355741501, 41.66775852441788, 39.293740913271904, 41.43236495554447, 40.9872492402792, 42.72714927792549, 40.69797836244106, 40.025232061743736, 40.88638745248318, 42.06708289682865, 39.264714270830154, 40.34802094101906, 41.40895061194897, 42.56146676838398, 40.148045271635056, 43.16892497241497, 49.56729903817177, 53.79951573908329, 54.93340149521828, 53.60078640282154, 55.30579291284084, 50.96733011305332, 51.520166248083115, 51.94045029580593, 53.766187727451324, 54.17131818830967, 53.79766903817654, 52.22603917121887, 51.357314586639404, 48.09474505484104, 48.05393524467945, 44.716475531458855, 46.860461086034775, 45.3073438256979, 45.51398813724518, 47.80168578028679, 52.38036789000034, 54.60694961249828, 53.80678094923496, 45.63677474856377, 42.38604158163071, 22.225792072713375, 14.70709752291441, 5.702609550207853, 13.147508259862661, 11.799220908433199, 10.009710732847452, 14.34784960001707, 6.832392476499081, 6.563094276934862, 0.39596078102476895, 0.37970068166032434, 0.054829276632517576, 5.03761388361454, 27.65196930617094, 45.467311441898346, 45.76343335211277, 31.537483111023903, 37.585409581661224, 49.02164451777935, 60.6362646818161, 33.06172952055931, 7.951811458915472, 0.260250914725475, 0.10453264316311106, 0.027712796145351604, 0.06270428726566024, 0.04617499609594233, 0.030389342464332003, 0.03586623461160343, 0.027960372899542563, 0.02103709615767002, 0.05829141409776639, 0.02283984336827416, 0.049730655300663784, 0.0715836686140392, 0.02974631788674742, 0.04668303328799084, 0.008116653916658834, 0.05965025680779945, 0.07980909169418737, 0.05100044400023762, 0.01854225542047061, 0.030070636421442032, 0.12742409919155762, 0.17851514829089865, 0.1391892772517167, 0.12962055945536122, 0.1302442603628151, 0.10355234029702842, 0.24781878339126706, 0.17289970273850486, 0.17525548726553097, 0.12184291117591783, 0.15241068264003843, 0.21131675457581878, 0.15941942139761522, 0.09302954713348299, 0.11295991556835361, 0.1722225226694718, 0.196401872090064, 0.09831187227973714, 0.19217143737478182, 0.12999152939300984, 0.34738015034236014, 15.586358942091465, 50.95149256289005, 63.51969055831432, 52.26935304701328, 41.81598097085953, 31.243648678064346, 34.736793637275696, 54.10733342170715, 33.32700468599796, 4.6617736760526896, 0.320858612540178, 0.27819916256703436, 1.0828590067103505, 4.753153547644615, 15.374479461461306, 20.194863751530647, 20.25738749653101, 27.28445492684841, 9.851122442632914, 11.143194660544395, 33.584201484918594, 44.72350895404816, 63.70171599090099, 61.909245774149895, 54.20753784477711, 51.46902859210968, 54.20094519853592, 53.09276886284351, 52.19117224216461, 55.885417610406876, 53.586495369672775, 54.109461307525635, 56.515469402074814, 56.119006276130676, 50.57316206395626, 46.63520537316799, 44.97586101293564, 47.432356998324394, 52.71583668887615, 57.32041820883751, 58.37031327188015, 52.08234988152981, 56.6715270280838, 55.222022607922554, 50.399423986673355, 47.879623398184776, 42.6633545011282, 43.19490037858486, 40.49517564475536, 44.218702241778374, 40.659794211387634, 47.2047758102417, 54.259458258748055, 57.60097615420818, 50.185731053352356, 47.68277496099472, 54.030862525105476, 51.8181424587965, 57.11473144590855, 54.20024983584881, 54.90222416818142, 55.24704426527023, 56.46970845758915, 58.49373824894428, 53.05216424167156, 49.557427167892456, 22.624858058989048, 44.694600105285645, 60.29241353273392, 58.2171168923378, 54.893002063035965, 44.620846062898636, 44.34077449142933, 41.9920901209116, 45.208750516176224, 44.402296990156174, 44.67357963323593, 44.569541215896606, 42.59069859981537, 43.90211082994938, 44.2387917637825, 42.221369817852974, 41.819039806723595, 43.16761024296284, 45.01778036355972, 42.142968624830246, 46.005248576402664, 51.55595652759075, 57.55388528108597, 57.81650818884373, 57.21360594034195, 56.90356157720089, 53.27795572578907, 55.42951427400112, 54.91898886859417, 55.86280882358551, 57.26261951029301, 56.33419252932072, 55.1647786796093, 52.39734537899494, 49.371978119015694, 49.89295296370983, 46.438527926802635, 48.4499803930521, 45.90217910706997, 48.14128115773201, 49.220670238137245, 56.840545758605, 59.29517224431038, 58.9689027518034, 48.621263802051544, 46.97635866701603, 23.935797214508057, 17.781881131231785, 9.80879271402955, 19.068062715232372, 18.380276821553707, 16.64244767278433, 21.7021706700325, 13.078915290534496, 5.986898420378566, 0.19362269231351092, 0.3241415770025924, 0.2844816801371053, 6.330344891175628, 34.103857800364494, 55.56828662753105, 55.906160697340965, 36.56916931271553, 42.71134592592716, 56.031341180205345, 66.14681258797646, 42.40363843739033, 10.860226694494486, 0.5294501117896289, 0.16851809254148975, 0.17871132760774344, 0.16140920837642625, 0.12976177531527355, 0.2172036629053764, 0.1319195399992168, 0.1420886255800724, 0.06311376724625006, 0.15435273468028754, 0.14666074508568272, 0.12243896708241664, 0.14728690992342308, 0.1266476494492963, 0.1006578010856174, 0.06064848625101149, 0.09362757715280168, 0.15894824668066576, 0.12004260934190825, 0.09305343686719425, 0.11004345331457444], [0.014335152900457615, 0.09106922341743484, 0.0319850323285209, 0.01584596797329141, 0.07894825233961456, 0.05187436370761134, 0.08976527737104334, 0.062360672891372815, 0.05563226557569578, 0.04380632788524963, 0.06382061837939546, 0.012221861416037427, 0.060134767918498255, 0.035419992345850915, 0.04328328446717933, 0.015979539712134283, 0.05495029494340997, 0.07316101444303058, 0.04594335696310736, 0.0817468912282493, 0.026866265397984535, 10.196655001491308, 37.94345676898956, 48.28868664801121, 36.746490597724915, 20.042241141200066, 11.595396045595407, 26.85125157237053, 36.12413339316845, 17.15730294585228, 1.3019163021817803, 0.013775465940852882, 0.023181389005912933, 0.6632593972608447, 1.321952270809561, 5.52566634491086, 9.63894372805953, 6.836033156141639, 11.399697046726942, 5.469908136874437, 20.144575349986553, 29.57124251872301, 54.38281483948231, 50.8271898329258, 37.22948648035526, 40.56642562150955, 43.793022483587265, 51.95499211549759, 49.102143198251724, 50.2062651515007, 48.99717003107071, 51.83793939650059, 51.99869357049465, 49.54488784074783, 50.376442819833755, 46.75148293375969, 46.289944499731064, 39.28170695900917, 37.44204707443714, 39.51641656458378, 45.39887711405754, 50.710995867848396, 55.7375181466341, 54.16889771819115, 48.51563327014446, 44.719906747341156, 39.202029034495354, 38.727947473526, 39.855734556913376, 36.38147458434105, 39.571749195456505, 37.46796928346157, 42.25762367248535, 54.210459887981415, 45.51465690135956, 42.926611974835396, 50.047395676374435, 50.40979743003845, 54.52797845005989, 52.80278742313385, 54.10135254263878, 48.945405408740044, 50.466661378741264, 48.50288115441799, 51.25119008123875, 51.18012249469757, 52.549865394830704, 20.277714505791664, 41.39161594212055, 51.67651265859604, 55.971665382385254, 51.5698903799057, 47.94860489666462, 44.83345225453377, 42.64234162867069, 39.52590845525265, 37.975014075636864, 37.15900406241417, 37.70791120827198, 37.07465618848801, 38.907636031508446, 37.8851754963398, 39.49908569455147, 37.99038045108318, 38.951934054493904, 38.37763287127018, 39.45515625178814, 37.83318668603897, 41.243936866521835, 40.88650144636631, 51.026329547166824, 53.52453209459782, 51.25232242047787, 46.29249416291714, 45.509363785386086, 43.76752585172653, 46.208446472883224, 42.732058614492416, 48.22115287184715, 42.99210526049137, 43.53453755378723, 39.35190439224243, 39.72942553460598, 36.47391602396965, 41.56467005610466, 40.690416768193245, 45.03254257142544, 43.27867828309536, 51.44597142934799, 46.89187780022621, 57.95732103288174, 45.47708831727505, 40.88942728936672, 26.430933326482773, 19.038667492568493, 4.244590736925602, 10.724359285086393, 11.218971144407988, 7.146865976974368, 13.677219785749912, 6.85645611025393, 10.482554510235786, 5.661272518336773, 0.9879338066093624, 0.12139026788645424, 1.7757448204793036, 19.709831178188324, 32.32594460248947, 27.90196169167757, 26.37069895863533, 32.95970879495144, 41.97843745350838, 46.266621351242065, 45.35921864211559, 10.047237519174814, 1.0443784715607762, 0.06695226635201834, 0.028067338644177653, 0.060565681123989634, 0.06040947759174742, 0.005329109671947663, 0.1310073514468968, 0.09319859353126958, 0.06217667592864018, 0.010522231914364966, 0.05768044473370537, 0.08846684548188932, 0.009807024198380532, 0.014296652134362375, 0.127578629180789, 0.08236513735027984, 0.011509672385727754, 0.016896876913961023, 0.043816365432576276, 0.07978813344379887, 0.03374088693817612, 0.05982620146824047, 0.034556785540189594, 0.007485055630240822, 0.02571162647655001, 0.03196289035258815, 0.04909470153506845, 0.06563926610397175, 0.02868671654141508, 0.019825630988634657, 0.06287035022978671, 0.1115770718024578, 0.007499864723286009, 0.04050235693284776, 0.05247418230283074, 0.06321852881228551, 0.014109538151387824, 0.021638237631123047, 0.09163295879261568, 0.012765619103447534, 0.05185848545806948, 0.1715775963384658, 13.161723297089338, 44.83708865940571, 53.3202588558197, 43.64038847386837, 24.62774198502302, 15.280647296458483, 26.481056436896324, 36.07312113046646, 20.18541555851698, 1.5611077565699816, 0.06100056481955107, 0.030854012256895658, 1.5557683305814862, 4.548857510089874, 8.959958162158728, 11.081373877823353, 9.991381466388702, 9.187811985611916, 8.25423438102007, 23.28024499118328, 32.03410506248474, 54.44156348705292, 52.11047597229481, 42.78196133673191, 45.163791328668594, 49.74437713623047, 52.992328852415085, 50.46601161360741, 51.43938638269901, 50.03077156841755, 51.883787736296654, 52.166530564427376, 51.02822944521904, 52.062305957078934, 49.08646523952484, 46.5266527980566, 41.977654695510864, 40.36647655069828, 42.21251629292965, 49.237203150987625, 54.10866715013981, 58.625754565000534, 55.37509739398956, 51.76727078855038, 47.048068419098854, 40.778055265545845, 40.887105613946915, 41.45975008606911, 39.05516691505909, 40.13938173651695, 38.45135271549225, 45.20811215043068, 55.93680985271931, 49.42916505038738, 45.52524693310261, 50.93272536993027, 52.51266919076443, 55.99995866417885, 55.51460310816765, 55.37928856909275, 50.983813628554344, 52.03919179737568, 49.83763173222542, 52.402760088443756, 52.94738106429577, 53.17394010722637, 21.70726239681244, 41.63739815354347, 53.77294756472111, 56.72532834112644, 53.98061402142048, 49.872016087174416, 46.9630441814661, 43.1391079723835, 41.77619710564613, 40.01164399087429, 40.30368871986866, 39.56365562975407, 40.081013068556786, 40.592617616057396, 40.874585285782814, 40.25463715195656, 40.77987536787987, 39.9352452903986, 39.467782974243164, 41.50354653596878, 39.29237678647041, 41.57731957733631, 45.40925055742264, 52.034780234098434, 56.81954808533192, 52.79310554265976, 49.255879148840904, 47.21029311418533, 48.33759002387524, 47.55345270037651, 47.22301863133907, 49.214324578642845, 45.56144379079342, 46.84622325003147, 42.846417278051376, 42.37281449139118, 39.625645503401756, 43.01309533417225, 42.14691661298275, 46.54218636453152, 46.00791983306408, 54.30279493331909, 52.06993594765663, 59.072420597076416, 50.60982249677181, 43.21324959397316, 27.697817645967007, 17.988553941249847, 7.149955686181784, 10.90281955897808, 13.391427621245384, 11.892141122370958, 11.965725123882294, 7.232826864346862, 4.9808435048907995, 3.980351253412664, 0.31744437699671835, 0.047301732120104134, 1.8788913544267416, 24.289280846714973, 39.26405310630798, 35.60312055051327, 30.91464713215828, 36.894036680459976, 48.190583512187004, 51.17994770407677, 52.55506731569767, 13.155559077858925, 0.9203419648110867, 0.04303247565985657, 0.04347956026322208, 0.055396303432644345, 0.06941877189092338, 0.013557363581639947, 0.03880394826410338, 0.042604605259839445, 0.10705197477363981, 0.02494568925612839, 0.060397595807444304, 0.07765170550555922, 0.03552838301402517, 0.0512597912165802, 0.0708086289523635, 0.06719853321556002, 0.013841928976034978, 0.04971627990016714, 0.059009594115195796, 0.053654905859730206, 0.04815752115973737, 0.09711705904919654, 0.1916678308043629, 0.12361540473648347, 0.1157800544751808, 0.11750600795494393, 0.12369526724796742, 0.15825963753741235, 0.1766462274827063, 0.1491740281926468, 0.19076422147918493, 0.15358404780272394, 0.08940136525779963, 0.17974877584492788, 0.18147651047911495, 0.23229198530316353, 0.1103272357431706, 0.19234514445997775, 0.1767551599186845, 0.251446312176995, 0.19129626714857295, 0.4114534700056538, 17.373146563768387, 53.48988555371761, 62.451317086815834, 49.55810733139515, 29.809079356491566, 20.52669994533062, 36.31258808076382, 45.05295507609844, 24.32538840919733, 1.7497771326452494, 0.25385754997842014, 0.20964387949788943, 1.6543656773865223, 5.977891953662038, 15.478794313967228, 19.51671604067087, 14.503019023686647, 18.072831518948078, 10.278859790414572, 24.14476130157709, 32.977712228894234, 54.18983839452267, 53.812606036663055, 46.04614198207855, 48.666986748576164, 51.56642496585846, 54.99154597520828, 51.79571606218815, 51.890418380498886, 51.56567260622978, 54.7181848436594, 53.95440302789211, 52.59176194667816, 54.51599769294262, 51.23398080468178, 50.02791412174702, 44.19209606945515, 41.92009158432484, 44.243176728487015, 49.540206491947174, 55.360848158597946, 60.3842394053936, 57.46203660964966, 54.52735148370266, 49.12182234227657, 43.91304284334183, 42.52993606030941, 43.00355404615402, 41.80816479027271, 43.10084022581577, 40.65760172903538, 47.70827919244766, 58.523718640208244, 50.45371547341347, 47.4574888497591, 50.93714453279972, 54.08920079469681, 57.97608062624931, 56.55485808849335, 56.854000836610794, 54.61663909256458, 55.78371226787567, 52.83417373895645, 55.8116939663887, 54.77399244904518, 53.56286823749542, 24.819667786359787, 44.7372680157423, 57.62614220380783, 59.36371676623821, 56.18058577179909, 52.31858320534229, 49.82136480510235, 46.55472569167614, 43.77256818115711, 43.715263456106186, 41.98091112077236, 40.99209778010845, 40.837499275803566, 43.69603268802166, 42.61892348527908, 42.4802765250206, 41.754606664180756, 42.27786138653755, 41.95777416229248, 42.94160217046738, 40.77701032161713, 43.59371177852154, 45.56923717260361, 53.63603711128235, 59.09970313310623, 56.26134663820267, 52.36581087112427, 50.324776992201805, 49.37348663806915, 49.89587880671024, 49.0293163061142, 52.410253286361694, 47.53650180995464, 48.77140894532204, 43.845828250050545, 44.13920670747757, 40.838468223810196, 46.354525834321976, 45.55252566933632, 49.33526448905468, 49.07101146876812, 58.2778300344944, 53.14053229987621, 62.888001054525375, 51.99484817683697, 48.52469578385353, 27.88517039269209, 22.299411222338676, 8.033723663538694, 16.386086829006672, 21.578101627528667, 17.52165399491787, 21.94717962294817, 13.056673184037209, 17.900826148688793, 9.251615311950445, 1.4172887988388538, 0.11974854074651375, 2.3793363757431507, 26.9663055986166, 43.57700027525425, 37.4250315874815, 37.19849534332752, 44.83731284737587, 54.28536906838417, 57.74254895746708, 60.29317729175091, 18.667731396853924, 1.410937795881182, 0.14216613548342139, 0.1847831642953679, 0.1394895205157809, 0.23870587785495445, 0.10464348291861825, 0.2029127039713785, 0.19940699130529538, 0.18285926518728957, 0.13420400413451716, 0.11113403932540677, 0.21448450803291053, 0.1254033498116769, 0.21284302580170333, 0.31665410846471786, 0.32510058023035526, 0.15974261186784133, 0.11482197151053697, 0.2048056258354336, 0.17512108432129025, 0.15402883174829185], [0.0409137590759201, 0.01626114950340707, 0.07277290089405142, 0.010115661152667599, 0.01664102150243707, 0.035793196148006245, 0.06075073564716149, 0.020895676207146607, 0.09967990277800709, 0.09373096574563533, 0.03230687951145228, 0.07082731623086147, 0.048930646080407314, 0.06114812975283712, 0.014056963482289575, 0.028792988377972506, 0.03916542242222931, 0.05921179967117496, 0.04669916015700437, 0.06823725052527152, 0.20172733085928485, 12.848042529076338, 39.45159584283829, 47.11797706782818, 36.40863932669163, 23.897257782518864, 22.00007278472185, 30.17475463449955, 39.91805121302605, 15.203449688851833, 0.5044391413684934, 0.059682989231077954, 0.08493246365105733, 2.339364420622587, 4.987377729266882, 5.61944056302309, 10.698243286460638, 8.855465669184923, 8.682658541947603, 15.253992676734924, 23.551330044865608, 33.95313508808613, 32.69416384398937, 28.098635338246822, 40.179644376039505, 48.76131668686867, 48.63707855343819, 52.39658161997795, 50.610810443758965, 49.04524505138397, 51.36875577270985, 46.825225576758385, 47.44826294481754, 47.93148301541805, 49.5487180352211, 49.51740011572838, 47.80977174639702, 41.34564220905304, 37.23911516368389, 35.79667456448078, 37.63654723763466, 40.052886977791786, 41.59742429852486, 42.07839868962765, 41.61619909107685, 39.31084379553795, 40.17802186310291, 39.3321568518877, 41.282318606972694, 37.3382518440485, 38.80357101559639, 34.02241297066212, 43.70553217828274, 53.89842063188553, 53.35593894124031, 55.63555061817169, 53.253545835614204, 52.268342301249504, 51.739889457821846, 47.61919677257538, 49.16911460459232, 46.95208176970482, 47.50294201076031, 43.17338973283768, 49.71319600939751, 48.86017598211765, 57.146611735224724, 18.94200447946787, 36.7304440587759, 53.404811918735504, 52.35699534416199, 56.333934143185616, 50.954608395695686, 52.41234317421913, 46.6393281519413, 45.7704021781683, 44.05946798622608, 38.81631173193455, 37.381903901696205, 36.987599059939384, 38.09251517057419, 40.11029049754143, 42.30293244123459, 44.99470800161362, 43.870937302708626, 41.75174921751022, 39.54978637397289, 39.06275890767574, 40.89106120169163, 38.06447647511959, 38.11553053557873, 40.85658185184002, 44.778055027127266, 41.10558249056339, 40.89624032378197, 39.291597828269005, 39.958165660500526, 38.96634668111801, 38.003364354372025, 36.39624439179897, 37.702211514115334, 37.901526018977165, 40.766625478863716, 43.3966201543808, 48.43579575419426, 47.625462636351585, 53.13659571111202, 52.363451197743416, 55.14778219163418, 53.31254526972771, 50.77283754944801, 42.97887437045574, 46.66426621377468, 25.17872951924801, 22.748989798128605, 5.314318835735321, 16.220337823033333, 8.661091849207878, 7.952101668342948, 8.785207439213991, 8.003056459128857, 11.892179120332003, 13.766450397670269, 10.105149261653423, 0.6488863716367632, 0.35782748193014413, 14.172351267188787, 41.20587430894375, 25.719736889004707, 22.781850434839725, 24.058333039283752, 36.632895693182945, 48.986017629504204, 46.382222548127174, 16.19260311126709, 1.685002720914781, 0.05902584714931436, 0.08004595554666594, 0.029717266515945084, 0.08946849993662909, 0.05977034743409604, 0.049711652609403245, 0.08104110136628151, 0.031062670786923263, 0.04820416143047623, 0.13882639672374353, 0.03859338612528518, 0.038827615353511646, 0.040718852542340755, 0.023226023622555658, 0.0336287261598045, 0.032716686037019826, 0.04044090710522141, 0.025129168570856564, 0.04649998627428431, 0.0011753485523513518, 0.06127650645794347, 0.007879701934143668, 0.009001638118206756, 0.03008726238476811, 0.0288171360080014, 0.046207980849430896, 0.02460444604366785, 0.05401156719017308, 0.019607218782766722, 0.052338810855872, 0.035611202984000556, 0.013936844097770518, 0.04551987265585922, 0.04250200705428142, 0.035837595132761635, 0.030825823632767424, 0.06165513535961509, 0.1615279816905968, 0.05177240374905523, 0.026799819061125163, 0.4501635959604755, 15.700986441224813, 45.94806544482708, 54.45075139403343, 42.318519204854965, 25.793532729148865, 21.791767962276936, 31.0979587957263, 38.977685272693634, 16.83830626308918, 0.7286173745524138, 0.024669524973433, 0.04922744948999025, 2.6466016843914986, 7.113922219723463, 9.51267745345831, 11.873244736343622, 8.141158148646355, 7.63084695674479, 11.63902435451746, 25.66835794597864, 35.66190339624882, 36.268012672662735, 32.6949618011713, 44.74848501384258, 52.21635729074478, 49.98102843761444, 52.479987144470215, 51.824233531951904, 49.187311828136444, 52.29424171149731, 49.1859894990921, 50.041718780994415, 47.611528784036636, 51.90590634942055, 51.36884696781635, 49.96857650578022, 41.948027685284615, 38.84760685265064, 38.053126484155655, 40.03431737422943, 43.46659719944, 45.262551829218864, 45.026649087667465, 44.021413028240204, 42.16065667569637, 41.86290085315704, 40.86358867585659, 43.5301373898983, 39.84832115471363, 41.000685319304466, 36.717137172818184, 47.16744661331177, 55.03242418169975, 53.57300229370594, 55.14424078166485, 53.64126943051815, 54.308319836854935, 53.26130121946335, 51.573032811284065, 51.98191747069359, 48.47526043653488, 49.06178176403046, 45.364477559924126, 51.970723271369934, 52.08025239408016, 56.98412865400314, 20.787210166454315, 38.69128704071045, 53.4211852401495, 54.78921823203564, 57.8617637604475, 51.40598997473717, 53.42143602669239, 50.10079801082611, 47.394180446863174, 45.49621269106865, 41.11193574965, 39.628689140081406, 40.55725671350956, 40.8516801148653, 43.39823126792908, 44.03888829052448, 46.5005823969841, 45.01955486834049, 42.171360701322556, 40.73123797774315, 41.41619682312012, 41.96380443871021, 39.28534336388111, 41.4041780680418, 43.67789626121521, 46.70640595257282, 44.68900300562382, 43.8206622004509, 41.38540327548981, 41.81694231927395, 39.66985233128071, 40.97892768681049, 38.04846413433552, 39.31143656373024, 40.10320767760277, 43.131584376096725, 44.515112936496735, 49.56157274544239, 50.16764782369137, 53.32384966313839, 55.85436187684536, 56.60058483481407, 55.71894854307175, 52.52301603555679, 46.98707029223442, 46.7604960501194, 28.29436093568802, 22.3588989302516, 11.579364705830812, 12.834809739142656, 10.267499350011349, 14.918856360018253, 14.035034235566854, 10.24375632405281, 13.535546287894249, 11.285668015480042, 9.075715150684118, 0.5072028993163258, 0.6573030981235206, 16.1220370978117, 40.98338484764099, 29.071491435170174, 29.25921656191349, 32.690162658691406, 41.05050064623356, 54.393256679177284, 52.85781607031822, 21.06110706925392, 2.053279196843505, 0.03972693877585698, 0.07988875382579863, 0.021854859405721072, 0.05833784285641741, 0.06237257694010623, 0.04125061248487327, 0.06503900964162312, 0.027714900134014897, 0.008394415672228206, 0.05425941482826602, 0.02286228034790838, 0.045915919763501734, 0.007186318925960222, 0.03400238638278097, 0.02002970675675897, 0.03326741527416743, 0.023778368886269163, 0.07546357956016436, 0.050915698157041334, 0.004387557119116536, 0.1441498368512839, 0.13085062470054254, 0.11265880399150774, 0.08846439639455639, 0.13110509229591116, 0.17144731973530725, 0.1853595903958194, 0.08898215572116897, 0.18597496440634131, 0.15837619925150648, 0.18352324987063184, 0.3464692976558581, 0.1633818814298138, 0.18913902196800336, 0.15132354019442573, 0.13908911700127646, 0.1060930680250749, 0.21477361908182502, 0.13314350479049608, 0.14284981676610187, 1.10141531098634, 20.164575576782227, 54.78734873235226, 60.57175554335117, 49.19921278953552, 34.829352870583534, 31.575532369315624, 40.06245866417885, 50.39483763277531, 20.20357858389616, 0.9238278621342033, 0.1536923271487467, 0.38789057813119143, 3.6705165915191174, 11.505795903503895, 15.741918794810772, 20.862552523612976, 19.100974649190903, 15.505269393324852, 21.668988950550556, 27.982390075922012, 37.641380578279495, 38.9191722124815, 39.633739069104195, 49.8447335511446, 54.04227331280708, 50.16042061150074, 54.545826092362404, 52.50061623752117, 50.04132740199566, 52.314502224326134, 49.91276130080223, 50.280057191848755, 51.815247014164925, 54.048398584127426, 53.95615853369236, 52.75915056467056, 45.302924662828445, 39.79956217110157, 39.67089347541332, 41.01885974407196, 44.9204295873642, 45.703822150826454, 45.96126973628998, 46.54982775449753, 43.702100962400436, 44.17780503630638, 42.57408209145069, 45.15520378947258, 42.669407576322556, 42.44925118982792, 38.59935097396374, 48.97864602506161, 57.67589673399925, 56.60861000418663, 56.56407259404659, 56.16921678185463, 56.21550589799881, 54.51751381158829, 56.07132263481617, 54.39703747630119, 52.402125522494316, 51.47746033966541, 48.82241740822792, 54.69043493270874, 54.56277698278427, 57.53685839474201, 24.019119143486023, 40.98460838198662, 55.01399137079716, 57.71120823919773, 59.79339011013508, 53.34357060492039, 55.44512003660202, 51.75216659903526, 49.10853825509548, 49.410918429493904, 43.77762570977211, 42.18590632081032, 41.53489865362644, 41.911857426166534, 46.552388817071915, 46.027211397886276, 49.60802145302296, 49.238069504499435, 45.04843331873417, 43.82853917777538, 43.2147429138422, 44.18671935796738, 42.29114167392254, 42.963648587465286, 45.54180644452572, 49.2486747354269, 47.18002773821354, 46.34586989879608, 43.29355448484421, 43.67978855967522, 41.384973898530006, 42.46584489941597, 39.744624719023705, 42.07118667662144, 41.24429024755955, 47.337776273489, 47.6513696461916, 52.36753597855568, 53.70980255305767, 57.2954573482275, 57.72880509495735, 61.075927689671516, 58.636678978800774, 55.74995867908001, 48.307009264826775, 52.29696236550808, 29.22993913292885, 24.757638014853, 11.823603250086308, 23.6994593963027, 16.420670673251152, 16.682432927191257, 17.01722726225853, 21.578578501939774, 21.348869428038597, 17.31062661856413, 11.64462050423026, 0.9624768944922835, 0.8666583267040551, 19.3161666020751, 51.461656987667084, 34.21159341931343, 34.22066733241081, 36.40066735446453, 48.485896065831184, 60.54684787988663, 60.739581137895584, 27.327383123338223, 3.1433765776455402, 0.12751113827107474, 0.1668088967562653, 0.15719783201348037, 0.12466843065340072, 0.0904895541316364, 0.14333813509438187, 0.1334940508240834, 0.17278720799367875, 0.1477564370725304, 0.18032212945399806, 0.23348075745161623, 0.163543536036741, 0.17520965222502127, 0.07952397339977324, 0.06845763869932853, 0.20351889019366354, 0.1378992316313088, 0.11956177928368561, 0.15356065530795604, 0.07786294299876317], [0.03962812552344985, 0.03649896374554373, 0.07516318044508807, 0.0107281175951357, 0.05815741191327106, 0.02292336281243479, 0.029982701198605355, 0.019005561516678426, 0.01196091208839789, 0.018313206383027136, 0.031663162881159224, 0.017713675370032433, 0.051730238628806546, 0.0398042186134262, 0.009896314768411685, 0.02486281362507725, 0.014228649142751237, 0.039929296472109854, 0.03988327589468099, 0.03915812339982949, 0.3936856531072408, 13.420954886823893, 43.90033632516861, 43.003497049212456, 39.177463352680206, 24.014994464814663, 15.980737879872322, 31.43948256969452, 30.918733812868595, 7.416666699573398, 0.1989733098889701, 0.04361896157206502, 0.053937563934596255, 1.9270687317475677, 4.29006147198379, 6.969378925859928, 6.424721851944923, 7.102702371776104, 5.7577460166066885, 11.216008253395557, 27.212372794747353, 24.572513848543167, 24.643889218568802, 37.73848816752434, 49.435932487249374, 56.40467494726181, 48.61054837703705, 46.58173844218254, 49.26346734166145, 46.962960585951805, 52.33945928514004, 49.00603875517845, 48.59599895775318, 46.023719385266304, 50.01344829797745, 50.37642382085323, 49.519189819693565, 45.58290883898735, 43.77639077603817, 36.444368809461594, 37.15918645262718, 36.02647863328457, 38.400549441576004, 36.91410720348358, 38.77968929708004, 38.99544171988964, 39.05262865126133, 38.78847822546959, 40.83227455615997, 36.506282687187195, 39.50328066945076, 35.51760233938694, 39.09872017800808, 47.144427448511124, 53.31619307398796, 51.75774469971657, 52.92661897838116, 49.986477345228195, 48.34011688828468, 43.27318757772446, 42.66913019120693, 41.092336401343346, 40.32103858888149, 39.678553864359856, 48.87133978307247, 45.909782499074936, 58.85818429291248, 22.941088490188122, 37.90405288338661, 53.53168711066246, 46.46159648895264, 50.52333153784275, 49.51300375163555, 52.32091248035431, 50.994825437664986, 49.48262818157673, 46.94988928735256, 41.70031137764454, 36.822174936532974, 38.52284587919712, 38.1751911342144, 42.76589959859848, 46.636409908533096, 48.738951086997986, 49.187448620796204, 46.74345776438713, 42.29293517768383, 39.68364179134369, 38.04213747382164, 37.07483857870102, 39.07049909234047, 37.71527141332626, 38.80758360028267, 38.91693793237209, 38.841675370931625, 39.844380766153336, 38.723174929618835, 37.48805120587349, 37.84671016037464, 38.26168209314346, 40.96013009548187, 46.56317263841629, 50.0298710167408, 51.22228503227234, 50.211755856871605, 49.86408211290836, 52.85568058490753, 50.41904613375664, 50.423503294587135, 47.80140079557896, 52.09785304963589, 46.927930265665054, 47.82756619155407, 35.444023087620735, 19.628515541553497, 12.875324115157127, 9.324815534055233, 11.044743843376637, 16.00556194782257, 11.586504522711039, 8.897271025925875, 3.8406783482059836, 1.009894609451294, 1.5080038248561323, 0.6267967913299799, 0.1798282004892826, 7.986356355249882, 37.498869225382805, 39.647194147109985, 23.92346117645502, 22.814023308455944, 38.7525587528944, 43.55777710676193, 45.530570447444916, 19.075723104178905, 2.8509171959012747, 0.10762171412352473, 0.036492562721832655, 0.04277398933481891, 0.026101881121576298, 0.032260131629300304, 0.020037150497955736, 0.0421953961631516, 0.04468215491215233, 0.030934913775126915, 0.04951436378178187, 0.07216526748379692, 0.015716164489276707, 0.061676030527451076, 0.021977306350891013, 0.07991245060111396, 0.018143362176488154, 0.01973267884750385, 0.040458043295075186, 0.007452833897332312, 0.034037601290037856, 0.04411660869664047, 0.13440134120173752, 0.03786500899877865, 0.048160178048419766, 0.028518015242298134, 0.06542695249663666, 0.04456379348994233, 0.046484130289172754, 0.06110012764111161, 0.01578899329615524, 0.047223261135513894, 0.04806624441698659, 0.02676403455552645, 0.027890165729331784, 0.03683684131829068, 0.05116780201205984, 0.06695491581922397, 0.02432823723211186, 0.04114530544029549, 0.03480456638499163, 0.684409299865365, 16.782785542309284, 50.89601933956146, 48.77361282706261, 43.07322330772877, 27.37248670309782, 16.315627209842205, 30.961548015475273, 35.940842628479004, 9.622141979634762, 0.24530607915949076, 0.03312893422844354, 0.1534915019874461, 3.9215795695781708, 6.616563107818365, 9.608839843422174, 12.83470144495368, 10.158101320266724, 6.7484549805521965, 13.22192631661892, 25.961257629096508, 25.148386247456074, 27.277320809662342, 43.88667605817318, 51.56356751918793, 54.717014506459236, 49.659797474741936, 49.96876269578934, 47.81716234982014, 48.4476663172245, 53.44123676419258, 48.76227803528309, 48.29315520823002, 47.06487491726875, 51.963469460606575, 51.80318646132946, 49.93983864784241, 47.43480026721954, 45.1084852963686, 37.88349598646164, 38.900089636445045, 38.422288075089455, 39.63293731212616, 38.97377908229828, 40.07171496748924, 41.708214953541756, 40.38871295750141, 41.91899724304676, 42.568906769156456, 39.03067722916603, 39.71511170268059, 37.28691279888153, 41.03908605873585, 49.699645936489105, 54.712538346648216, 55.26891589164734, 53.05009715259075, 52.47922718524933, 52.00780548155308, 46.537922993302345, 45.445975586771965, 43.038542568683624, 42.747759371995926, 43.351588770747185, 51.669897213578224, 49.68013398349285, 59.268987849354744, 25.490466691553593, 38.22915963828564, 52.70487807691097, 47.68535502254963, 50.64751647412777, 50.344414338469505, 54.021952003240585, 53.897569477558136, 52.27478675544262, 49.18403260409832, 43.55484366416931, 40.08811868727207, 40.240262523293495, 40.18244482576847, 45.910124480724335, 47.762338891625404, 50.94033256173134, 49.39283899962902, 48.04439775645733, 44.53136846423149, 41.577399373054504, 38.915490210056305, 38.5206837952137, 39.39026713371277, 40.44466495513916, 40.06666123867035, 40.88319182395935, 41.99392922222614, 41.66372314095497, 39.755507335066795, 38.406245335936546, 39.97541293501854, 38.24101120233536, 41.962949484586716, 47.03415736556053, 51.069111451506615, 53.33605460822582, 55.25870583951473, 53.41328166425228, 56.23789429664612, 52.45104409754276, 55.47702692449093, 49.89049829542637, 52.93532431125641, 47.198794931173325, 52.569358348846436, 34.96998332440853, 21.172270104289055, 15.037170611321926, 9.805337749421597, 15.133167710155249, 11.740331668406725, 12.962468639016151, 9.62124427780509, 6.119892708957195, 2.6496258471161127, 2.537098922766745, 0.6615276401862502, 0.2823790570255369, 10.212552398443222, 39.220397248864174, 35.23994743824005, 29.414660520851612, 25.552304573357105, 43.236785531044006, 48.71205233037472, 51.041388139128685, 23.945545591413975, 3.6240645591169596, 0.08847477161907591, 0.013986354624648811, 0.07062291391775943, 0.03553279137122445, 0.07270773290656507, 0.07134103085263632, 0.052760358157684095, 0.06505750396172516, 0.016403584340878297, 0.03299667609098833, 0.02787272896966897, 0.056804435880621895, 0.054493265561177395, 0.03988771764852572, 0.02106223641021643, 0.03983919603342656, 0.03940942573535722, 0.03755724406801164, 0.017254712693102192, 0.052454277902143076, 0.1515597806428559, 0.20389781595440581, 0.14995421835919842, 0.1757216005353257, 0.16005665907869115, 0.2483102781116031, 0.23095211188774556, 0.15245674032485113, 0.21970226633129641, 0.0509188931027893, 0.1383635785896331, 0.31647418218199164, 0.12862686824519187, 0.07139963825466111, 0.10699160848162137, 0.11961356634856202, 0.12146480177761987, 0.1696794349118136, 0.14951698947697878, 0.12878729088697582, 1.2508104695007205, 21.232143491506577, 57.804424837231636, 56.41754485666752, 50.55589199066162, 34.78942081332207, 25.498746447265148, 42.07527905702591, 42.18875236809254, 11.571261640638113, 0.3590302064549178, 0.1361360668670386, 0.5716826487332582, 5.704046823084354, 12.828076500445604, 14.376752749085426, 12.920220606029034, 14.225804898887873, 12.327805794775486, 15.742150582373142, 34.81957599520683, 31.603001095354557, 34.71919298171997, 47.43654057383537, 55.97404785454273, 57.106592282652855, 49.96952265501022, 51.70605607330799, 52.456998378038406, 49.13471885025501, 54.3044326454401, 51.146186515688896, 49.13962058722973, 46.80974140763283, 53.1598162651062, 52.945131585001945, 52.72940196096897, 49.65988107025623, 48.00201863050461, 39.665740951895714, 40.744465067982674, 39.40434917807579, 42.30621166527271, 40.224766954779625, 43.48129481077194, 43.48020426928997, 43.253094255924225, 43.61407108604908, 45.20745098590851, 40.021869242191315, 42.514497488737106, 39.41725708544254, 42.44922459125519, 52.06413745880127, 58.08375544846058, 59.396288618445396, 56.792945712804794, 54.4095654040575, 54.05476704239845, 48.512608632445335, 46.742492616176605, 44.47187505662441, 44.91838149726391, 44.562378600239754, 53.94653744995594, 51.88978001475334, 60.18033854663372, 29.510603472590446, 39.41830202937126, 53.34046997129917, 48.60854968428612, 50.53382657468319, 51.40560619533062, 54.882780611515045, 55.39069555699825, 53.63851837813854, 52.29328416287899, 45.62948293983936, 42.2809924185276, 43.112342208623886, 42.684196382761, 48.88329014182091, 50.94682641327381, 53.05499888956547, 53.315132930874825, 50.952214524149895, 45.54284378886223, 43.854009211063385, 41.36332646012306, 41.54114551842213, 43.718451485037804, 42.58279122412205, 42.416671738028526, 42.99981124699116, 42.475237995386124, 44.41392056643963, 41.82117149233818, 40.985463336110115, 42.1324697881937, 42.402494698762894, 45.87300427258015, 52.175919860601425, 55.88630676269531, 55.99816516041756, 55.6316976249218, 54.78106006979942, 60.45844182372093, 55.64972385764122, 57.70274229347706, 51.17202892899513, 54.83083359897137, 50.46551004052162, 54.05891261994839, 39.87343020737171, 22.54083886742592, 17.55033865571022, 14.609402865171432, 18.130565620958805, 25.684731267392635, 20.343716964125633, 15.364904925227165, 8.668102473020554, 2.091938084922731, 2.342136134393513, 1.0613161814399064, 0.5372128577437252, 12.31007594615221, 49.13127243518829, 51.20534934103489, 34.69922885298729, 31.95849671959877, 49.94395762681961, 55.016149654984474, 60.057563334703445, 30.7787037268281, 4.764426592737436, 0.21161928365472704, 0.1899124585906975, 0.2829047053819522, 0.13678678194992244, 0.17134705558419228, 0.2023868923424743, 0.16960760985966772, 0.26207003742456436, 0.1314276148332283, 0.1027819984301459, 0.18142260087188333, 0.09464658302022144, 0.21521869988646358, 0.1387121801963076, 0.23547544260509312, 0.06886898147058673, 0.1123985624872148, 0.16838738549267873, 0.15422841010149568, 0.1325599243864417], [0.03879751013300847, 0.03468647213594522, 0.03895282308803871, 0.0875964695296716, 0.03391805243154522, 0.050144588167313486, 0.01159157023721491, 0.03980840432632249, 0.04443946520041209, 0.024229147529695183, 0.027675915116560645, 0.005421803452918539, 0.06209535880771, 0.09859156547463499, 0.03643938784080092, 0.04549326666165143, 0.03371762431925163, 0.017534643375256564, 0.029181396930653136, 0.03918300390068907, 0.06423332670237869, 16.176320984959602, 44.60463233292103, 47.8026357293129, 33.125900477170944, 23.210129253566265, 21.469376161694527, 33.46439391374588, 29.820725731551647, 6.613988745957613, 0.12445268832379952, 0.015242504505295074, 0.06040847940312233, 3.2526214281097054, 6.011093622073531, 10.852376315742731, 15.609645042568445, 7.48183130286634, 5.330862672999501, 16.765447072684765, 18.071987964212894, 20.25232806801796, 36.455456614494324, 47.47867651283741, 53.28896753489971, 49.21889953315258, 51.202028319239616, 42.32599340379238, 52.14863732457161, 45.219633132219315, 51.046035289764404, 48.30237731337547, 50.72047255933285, 49.44185636937618, 49.447122886776924, 48.87140437960625, 50.67561596632004, 48.301700949668884, 47.03758858144283, 44.31077890098095, 40.21417312324047, 37.470040172338486, 38.44715774059296, 38.35333697497845, 36.91998928785324, 37.14929178357124, 38.703066408634186, 37.90960818529129, 39.7760072350502, 40.98403461277485, 37.912340238690376, 37.768001183867455, 38.0048880726099, 39.459457620978355, 47.41515152156353, 49.046867564320564, 48.020033463835716, 44.286361411213875, 41.23612828552723, 37.74456024169922, 37.77981474995613, 35.875714123249054, 40.512935891747475, 40.26980593800545, 49.054071977734566, 47.805447578430176, 54.34212662279606, 26.964373402297497, 38.318143263459206, 55.59513598680496, 49.19110782444477, 51.29173770546913, 51.78125783801079, 51.579522863030434, 50.34923627972603, 51.78025849163532, 49.138279259204865, 45.59471480548382, 40.53555227816105, 38.78261514008045, 41.35101892054081, 46.0141135007143, 48.182163164019585, 52.00256556272507, 51.37282535433769, 49.0159410238266, 44.95032258331776, 39.43690583109856, 37.26419001817703, 36.6356885433197, 36.333699747920036, 38.70649002492428, 40.232545137405396, 38.48094552755356, 37.05147743225098, 35.47897361218929, 37.36443243920803, 37.1766959130764, 36.89994916319847, 41.089292764663696, 49.05188329517841, 50.788986682891846, 52.84256748855114, 51.445219069719315, 49.45712395012379, 47.51428060233593, 49.88397404551506, 50.361023247241974, 51.57435514032841, 55.40833421051502, 52.98398070037365, 53.72078396379948, 48.58436398208141, 37.590049132704735, 25.3983748331666, 20.54350644350052, 14.165024310350418, 13.40587254613638, 15.96542090177536, 16.159877367317677, 4.938918454572558, 14.161256812512875, 1.657362647820264, 0.0979950865439605, 0.1489386783214286, 0.23538739420473576, 4.772503059357405, 31.87355797737837, 41.78728111088276, 28.77424668520689, 26.332606002688408, 35.05941152572632, 45.68828098475933, 48.29239144921303, 28.056826181709766, 4.7229537181556225, 0.13918757031206042, 0.0755030543950852, 0.03346394711115863, 0.045449179378920235, 0.03351172657858115, 0.013775814750260906, 0.053442362186615355, 0.038006970717106014, 0.021606306727335323, 0.06086825844249688, 0.02422462228423683, 0.07188168543507345, 0.018226137617602944, 0.051340933932806365, 0.06828009471064433, 0.04357908226666041, 0.05380774746299721, 0.07113415718777105, 0.05053296888945624, 0.018803469138219953, 0.02228241068223724, 0.048949730407912284, 0.038365472573786974, 0.062249599359347485, 0.014464012001553783, 0.04072721283591818, 0.04536586217000149, 0.0393468849506462, 0.039233970892382786, 0.034703779019764625, 0.01161336340373964, 0.07784881992847659, 0.03509593727358151, 0.05322711338521913, 0.037853390676900744, 0.03497559802781325, 0.015600465521856677, 0.010672363750927616, 0.06624236499192193, 0.026664751894713845, 0.3207753732567653, 19.820203855633736, 51.31120026111603, 53.947475999593735, 37.70848497748375, 26.811448708176613, 25.210780799388885, 34.763092026114464, 32.27288044989109, 7.144480179995298, 0.0657120039977599, 0.025712403876241297, 0.4696226486703381, 2.848042412661016, 7.908427286893129, 7.586289122700691, 8.220211006700993, 10.386809147894382, 6.793661154806614, 13.694417662918568, 15.782034192234278, 21.397225633263588, 40.16954451799393, 52.51878686249256, 51.273578479886055, 51.357041001319885, 51.389077082276344, 45.50525240600109, 52.92177803814411, 46.0713080316782, 51.78601138293743, 47.66256384551525, 49.74691540002823, 49.992796406149864, 49.361346289515495, 49.863432347774506, 53.561112731695175, 51.06654278934002, 49.02882233262062, 45.265314280986786, 40.43838009238243, 38.53481903672218, 41.50065489113331, 40.3152970969677, 40.163035467267036, 39.91433881223202, 40.79846017062664, 39.740175157785416, 41.61922752857208, 44.230021834373474, 40.09840093553066, 40.414844155311584, 40.107364654541016, 40.786563009023666, 49.06411483883858, 50.2401327341795, 49.693410471081734, 46.937448754906654, 43.8494760543108, 38.7903743237257, 38.955878242850304, 38.668343871831894, 41.31221540272236, 43.95059622824192, 50.842263624072075, 50.46821169555187, 57.06448294222355, 28.902947679162025, 38.29768516123295, 55.45980624854565, 49.98505242168903, 52.68443517386913, 51.17588572204113, 52.77853712439537, 52.55572848021984, 53.66312965750694, 49.49874311685562, 47.95322924852371, 42.95835167169571, 41.17314286530018, 41.95164889097214, 48.42470794916153, 50.20561158657074, 52.80143089592457, 52.93926849961281, 50.936240181326866, 47.14148260653019, 41.65918618440628, 39.122366309165955, 39.71609964966774, 38.585037142038345, 40.49079827964306, 41.78350031375885, 40.27006432414055, 38.59919898211956, 38.37694130837917, 39.39233422279358, 38.87619651854038, 39.2086710780859, 43.52064169943333, 50.22325024008751, 55.01243345439434, 53.78138691186905, 53.423575311899185, 52.19257436692715, 49.5181904733181, 51.00372456014156, 52.503724470734596, 54.28318038582802, 53.83239917457104, 55.20685002207756, 54.96807463467121, 50.217542946338654, 40.651073679327965, 27.03954476863146, 17.150594405829906, 9.00204660370946, 11.07148015871644, 14.993853885680437, 14.71994273364544, 7.258533909916878, 15.595242865383625, 4.231453891843557, 0.3829937690170482, 0.18246053892653435, 0.3356708708452061, 5.657447073608637, 34.484810158610344, 44.586286917328835, 31.4477851241827, 30.65350614488125, 40.309301018714905, 49.180658385157585, 54.516601860523224, 34.273157715797424, 6.592531772330403, 0.13217645668191835, 0.05952039580733981, 0.020924224772898015, 0.06237769775907509, 0.030341446108650416, 0.03438093735894654, 0.03046728095796425, 0.03791924515098799, 0.087360718898708, 0.029709290283790324, 0.08561416339944117, 0.07284557199454866, 0.0041065735149459215, 0.009687956808193121, 0.04111537833523471, 0.03717536084877793, 0.04469851184694562, 0.010058115021820413, 0.017286712245550007, 0.036991285960539244, 0.12441724335076287, 0.12109988776501268, 0.14659239328466356, 0.197631120972801, 0.10174446855671704, 0.11739032197510824, 0.08426193322520703, 0.1456869879621081, 0.1795472827507183, 0.08177104813512415, 0.09573805218678899, 0.17869370902189985, 0.1114307573880069, 0.15243907721014693, 0.11279000827926211, 0.1283032918581739, 0.09236540659912862, 0.09750695375259966, 0.18080918613122776, 0.1628933849860914, 0.6566706101875752, 25.623239167034626, 58.081935346126556, 60.43167985975742, 45.11108435690403, 33.59543368220329, 32.2001713514328, 44.25091311335564, 41.743397265672684, 9.529077373445034, 0.27550044644158334, 0.16303541720844805, 0.5866237438749522, 7.810667557641864, 10.910503696650267, 23.289615288376808, 24.313388653099537, 16.092176400125027, 12.006176803261042, 20.877594016492367, 21.573175191879272, 27.030700743198395, 46.57996013760567, 54.718830808997154, 53.34403418004513, 53.355615958571434, 54.73217949271202, 45.51873788237572, 52.13352933526039, 48.1813158094883, 52.029566913843155, 48.68096239864826, 51.41132488846779, 51.64395220577717, 50.87486207485199, 49.72803421318531, 54.82592426240444, 54.28996302187443, 50.180825516581535, 48.53217378258705, 44.08291272819042, 41.017355024814606, 43.578710183501244, 43.65670099854469, 40.93114525079727, 41.84935078024864, 42.39534728229046, 41.857740730047226, 43.48382547497749, 47.02355973422527, 42.940751016139984, 42.66724169254303, 41.068952456116676, 42.30200529098511, 51.95319481194019, 53.376856818795204, 52.08161652088165, 47.94973723590374, 45.253702104091644, 42.0487754791975, 41.53710253536701, 41.2999876588583, 43.563370406627655, 44.9566226452589, 52.920949682593346, 53.73651511967182, 58.63941103219986, 33.708481416106224, 40.85424117743969, 58.01008500158787, 53.63986350595951, 54.68294933438301, 53.866673335433006, 54.65168081223965, 54.556305930018425, 56.3490155339241, 53.70746947824955, 50.448258966207504, 44.44813773036003, 43.11768092215061, 45.06975777447224, 50.58224357664585, 51.85650900006294, 56.02393917739391, 56.10587038099766, 53.89243595302105, 50.857029631733894, 42.903011441230774, 41.48425877094269, 41.461566388607025, 40.395902171730995, 43.98391664028168, 45.41090726852417, 41.64722442626953, 40.87346434593201, 40.727179795503616, 41.00021794438362, 40.25748699903488, 40.81533886492252, 45.77414497733116, 53.265895172953606, 56.83269917964935, 55.36935590207577, 55.460543408989906, 52.60865584015846, 50.276052206754684, 52.72481560707092, 53.67652773857117, 55.13235881924629, 57.0375993847847, 57.96386808156967, 59.3571051210165, 53.23820985853672, 44.6131856739521, 32.75206133723259, 26.508641056716442, 17.567787319421768, 20.275757610797882, 30.519398041069508, 23.930555395781994, 12.659580241888762, 23.542151637375355, 5.890755979344249, 0.7526227645576, 0.16922860988415778, 0.3872375772334635, 7.0936911553144455, 41.49084001779556, 52.43851996958256, 38.328794091939926, 36.598370745778084, 46.12596429884434, 58.06369632482529, 61.17686167359352, 42.692320346832275, 8.551698569208384, 0.25757962837815285, 0.09358134877402335, 0.20989497774280608, 0.20305132231442258, 0.11248517112107947, 0.16251483029918745, 0.11693836888298392, 0.23833852959796786, 0.1644976856186986, 0.13483189075486735, 0.2151437578140758, 0.1775008550612256, 0.07641607415280305, 0.12525005178758875, 0.10228331972029991, 0.1652024735813029, 0.149005783314351, 0.08119215810438618, 0.08883263522875495, 0.10025975017924793], [0.07779277293593623, 0.04521955888776574, 0.03378635832632426, 0.04431121466041077, 0.09231108138919808, 0.010284345753461821, 0.05138311389600858, 0.030279742095444817, 0.0755016146285925, 0.012167213371867547, 0.06661998457275331, 0.0556817928008968, 0.02793323998048436, 0.05986988056974951, 0.03389745041204151, 0.0650140289508272, 0.008862577269610483, 0.046064623893471435, 0.10004928451962769, 0.06305577582679689, 0.5256395100150257, 24.405193626880646, 48.573697954416275, 42.64268361032009, 32.60940179228783, 13.619166500866413, 9.975083190947771, 31.620242670178413, 25.89839570224285, 2.4894309556111693, 0.14344408409669995, 0.057861261593643576, 0.7749694841913879, 1.3853896292857826, 7.316506449133158, 4.267780892550945, 10.566936582326889, 7.6532534044235945, 7.484769020229578, 13.868511021137238, 15.783724151551723, 30.432325713336468, 43.40643122792244, 49.73799727857113, 52.44814485311508, 43.57700027525425, 57.02299676835537, 47.171740382909775, 44.287896528840065, 52.898884266614914, 48.470256105065346, 51.86820097267628, 50.026515796780586, 49.951173439621925, 49.25346627831459, 49.69833120703697, 49.26303796470165, 50.639339312911034, 49.065535962581635, 47.79111474752426, 47.46202580630779, 43.710555508732796, 39.366886988282204, 39.08318281173706, 36.73601076006889, 36.00728966295719, 37.827118411660194, 37.973600551486015, 37.25837633013725, 39.25912097096443, 37.04572834074497, 36.74924165010452, 38.24956454336643, 37.71463684737682, 37.599506825208664, 38.25332634150982, 38.30283008515835, 37.0091363042593, 36.75025999546051, 35.2080899477005, 39.02715101838112, 37.13757321238518, 37.91640602052212, 43.002535700798035, 47.74942338466644, 48.98071311414242, 54.307575076818466, 29.901667088270187, 39.49049815535545, 54.28128428757191, 47.38302044570446, 50.29421143233776, 46.9601259380579, 52.02640548348427, 51.2513230741024, 51.96275129914284, 48.44936862587929, 44.856953993439674, 40.53923808038235, 38.70457872748375, 38.904941976070404, 42.86255121231079, 49.50248971581459, 51.6574414819479, 52.61172987520695, 50.131766349077225, 45.852200388908386, 41.22108869254589, 38.635836616158485, 37.647452652454376, 39.83273059129715, 45.791050270199776, 44.51034419238567, 45.33407919108868, 42.646529003977776, 41.00486509501934, 37.58953996002674, 37.79630206525326, 39.67107966542244, 47.58692890405655, 53.89703370630741, 52.43537373840809, 49.66124139726162, 48.87667469680309, 51.083474680781364, 49.0968082845211, 52.73797810077667, 53.614089488983154, 53.02173927426338, 48.45694161951542, 51.20453618466854, 50.68133465945721, 55.50674133002758, 41.001825258135796, 30.86123339831829, 22.230767905712128, 10.855255611240864, 18.14708713442087, 7.225465709343553, 11.91931251436472, 5.043946718797088, 9.446609448641539, 5.811680322512984, 0.8858038962353021, 0.08346216520294547, 0.06581185996765271, 2.6815391471609473, 24.475391060113907, 34.118110835552216, 26.64791878312826, 19.84254475682974, 30.99627435207367, 44.09325197339058, 44.456588476896286, 36.6648405790329, 5.2799781784415245, 0.025474322901573032, 0.05721507732232567, 0.058880664510070346, 0.045458003514795564, 0.027344253030605614, 0.03468463160970714, 0.04495807799685281, 0.019251932280894835, 0.030010246009624097, 0.05590326079982333, 0.04775547749886755, 0.024766917013039347, 0.10113660508068278, 0.038492684107040986, 0.052591834974009544, 0.09768394113052636, 0.049151921120937914, 0.04552738319034688, 0.03561741847079247, 0.052612010258599184, 0.01358280811473378, 0.06914887504535727, 0.022454032332461793, 0.03784498585446272, 0.028347898296487983, 0.027534830987860914, 0.09943013297743164, 0.01813756414776435, 0.034584237582748756, 0.0452552895876579, 0.03734425139555242, 0.07547137211076915, 0.01145600768722943, 0.025718355900608003, 0.01825543018640019, 0.032223239468294196, 0.06088570262363646, 0.09011306261527352, 0.04929898881528061, 0.0558181253290968, 0.7639417634345591, 28.838957212865353, 54.24405388534069, 50.686228796839714, 37.23944954574108, 19.716501720249653, 13.945027515292168, 32.62679345905781, 30.53505890071392, 3.3988941041752696, 0.23372012976324186, 0.1316544448491186, 1.1811002413742244, 5.335136018693447, 12.146434877067804, 10.438886303454638, 14.126734714955091, 11.472912468016148, 10.57334778830409, 14.232445042580366, 16.516216546297073, 33.38545694947243, 46.538831144571304, 50.3512691706419, 50.72615325450897, 47.50073052942753, 55.914683640003204, 46.74528926610947, 46.75786279141903, 50.56192226707935, 49.005715772509575, 50.34513249993324, 50.40018394589424, 50.892086550593376, 51.988415122032166, 49.491664096713066, 50.40749475359917, 52.45995081961155, 51.81470364332199, 50.42657732963562, 48.52679707109928, 45.41257157921791, 41.09268598258495, 41.85843609273434, 39.72542054951191, 38.48953686654568, 39.998553693294525, 39.31778982281685, 39.22804243862629, 41.24538838863373, 38.92701879143715, 38.35236422717571, 40.57394161820412, 38.85527864098549, 40.127233788371086, 40.98366603255272, 39.89336393773556, 39.279541075229645, 37.922440096735954, 36.47800840437412, 40.6451839953661, 38.49940113723278, 40.67232593894005, 44.74459022283554, 50.85510693490505, 49.829294979572296, 56.50132276117802, 32.639036402106285, 40.56204825639725, 56.18709862232208, 51.26299984753132, 53.0424215644598, 49.41600635647774, 55.316436141729355, 53.10411125421524, 54.52616974711418, 50.99798686802387, 46.975549310445786, 42.9143500328064, 39.31471958756447, 40.96448466181755, 45.54625600576401, 50.92080160975456, 53.74779291450977, 54.57250826060772, 51.9078404456377, 48.391782715916634, 43.31413418054581, 38.959146067500114, 38.82626719772816, 40.41040599346161, 47.586693316698074, 46.48708552122116, 47.16414839029312, 44.18637357652187, 43.1785574555397, 38.856946751475334, 39.03144858777523, 40.427425280213356, 48.14781680703163, 54.94177624583244, 54.37534064054489, 50.0081779807806, 49.21030059456825, 51.310349106788635, 50.17858363687992, 53.46571505069733, 54.92743581533432, 54.33763146400452, 54.89820398390293, 53.38678568601608, 54.38555829226971, 57.0483186095953, 43.598298132419586, 35.8106654137373, 20.828527249395847, 9.802490752190351, 13.681199122220278, 17.78342764824629, 12.795234862715006, 10.129813738167286, 15.829354953020811, 5.094908634200692, 1.0871260589919984, 0.08464176440611482, 0.07543660249211825, 3.1011701049283147, 29.802260622382164, 38.65439862012863, 29.445689655840397, 25.536729209125042, 37.61309489607811, 49.79055605828762, 50.1507843285799, 42.963621988892555, 7.242372902110219, 0.11639133183052763, 0.034445404016878456, 0.07443366412189789, 0.029637112711498048, 0.022738480838597752, 0.08664143679197878, 0.023713417976978235, 0.030417137750191614, 0.020462295360630378, 0.045226620422909036, 0.08428510307567194, 0.07391940031084232, 0.05907964914513286, 0.03115390114544425, 0.02381860071182018, 0.03860993230773602, 0.017941870937647764, 0.001083565873614134, 0.10361744149122387, 0.0176511160316295, 0.21323468681657687, 0.11244375185924582, 0.25540831207763404, 0.1380736511782743, 0.12049399098032154, 0.12859786511398852, 0.143226649670396, 0.1355736079858616, 0.24278245051391423, 0.21058348298538476, 0.19947323540691286, 0.17196588800288737, 0.09992334205890074, 0.2112152733025141, 0.17778955050744116, 0.21390530630014837, 0.10441683843964711, 0.20082541363080963, 0.11893551796674728, 0.14721024606842548, 1.4678573166020215, 35.36736220121384, 61.87408246099949, 57.918525114655495, 43.97225886583328, 23.175761997699738, 17.555702067911625, 43.97339880466461, 34.545181319117546, 3.9633963257074356, 0.26137512002605945, 0.17919474776135758, 1.4786257012747228, 4.8316288366913795, 13.186144586652517, 11.046031024307013, 22.442403249442577, 14.648423921316862, 11.218739356845617, 18.42004168778658, 20.01927137374878, 37.61400684714317, 50.2259860932827, 53.32306310534477, 54.887332767248154, 50.76828919351101, 57.94626742601395, 51.76654502749443, 48.89656662940979, 52.42224924266338, 51.08695529401302, 51.482050493359566, 51.02516680955887, 51.28011032938957, 50.42112082242966, 48.66817608475685, 51.03867508471012, 52.96708680689335, 53.02035994827747, 52.02002942562103, 52.28079043328762, 48.55928912758827, 43.58175382018089, 43.76447841525078, 41.51726000010967, 39.86434109508991, 41.66622720658779, 41.810592859983444, 40.46812489628792, 43.23559619486332, 41.14245571196079, 39.93967205286026, 41.69080808758736, 40.55553540587425, 41.88290297985077, 41.321129724383354, 42.32345513999462, 41.50833807885647, 41.27053923904896, 38.34916479885578, 43.690522983670235, 41.098682060837746, 42.65236169099808, 47.39065423607826, 52.16992378234863, 53.01865004003048, 56.362823992967606, 35.67563585937023, 41.45547151565552, 56.620860546827316, 54.121320471167564, 53.93046051263809, 51.52088820934296, 58.1231365352869, 56.3689074665308, 56.83180242776871, 54.36035044491291, 48.991489335894585, 44.16597247123718, 41.48242726922035, 43.00073079764843, 46.686084643006325, 54.38700221478939, 56.223261281847954, 57.44239166378975, 54.07779760658741, 51.66862428188324, 44.740896821022034, 41.809076741337776, 40.756738409399986, 43.207663893699646, 52.27218009531498, 47.641729563474655, 49.30507890880108, 47.44037076830864, 46.06815420091152, 41.46532818675041, 41.34618557989597, 43.15252885222435, 51.20457798242569, 59.11184348165989, 56.818259954452515, 52.42408834397793, 49.76646535098553, 52.101649045944214, 51.072174087166786, 56.263067945837975, 57.191684916615486, 57.463191747665405, 55.044123753905296, 56.93266041576862, 54.99013625085354, 59.48065549135208, 43.580237701535225, 39.9715181440115, 27.433064952492714, 15.801985021680593, 26.880378909409046, 14.93828946724534, 19.093680940568447, 12.248511649668217, 14.575333893299103, 10.318871643394232, 2.0186452427878976, 0.289916813489981, 0.22854675189591944, 3.5904109524562955, 33.73723067343235, 47.39844761788845, 35.0253539532423, 28.94141111522913, 43.45401227474213, 56.59950949251652, 57.410720363259315, 50.63623867928982, 10.21318981423974, 0.2007795637473464, 0.12300441681873053, 0.13488747761584818, 0.18050888349534944, 0.16946127318078652, 0.1081196877930779, 0.11857367644552141, 0.12249915525899269, 0.08658682956593111, 0.10349588512326591, 0.13597303186543286, 0.08667872229125351, 0.18394143524346873, 0.12219589145388454, 0.14806116290856153, 0.1472765050129965, 0.1059877201623749, 0.08642496715765446, 0.18527877051383257, 0.10865413802093826], [0.13266431487863883, 0.019837416293739807, 0.07491796743124723, 0.018240021345263813, 0.009261426912416937, 0.026054663831018843, 0.06341484913718887, 0.017613175587030128, 0.021624513465212658, 0.027887709220522083, 0.038794712236267515, 0.07790608404320665, 0.05458932544570416, 0.02992204546899302, 0.04277912128600292, 0.047212462886818685, 0.05510446870175656, 0.09630356871639378, 0.07606922401464544, 0.13111956417560577, 1.2129589193500578, 22.70065639168024, 43.21297600865364, 44.95890632271767, 34.13968987762928, 17.173136696219444, 25.811298675835133, 30.860175155103207, 19.999271146953106, 2.4245629739016294, 0.016102552544907667, 0.12111286050640047, 6.68635823763907, 8.54897316545248, 10.591926891356707, 7.732125772163272, 5.57437545619905, 13.61470839008689, 10.880382712930441, 9.804468546062708, 20.749968364834785, 39.3549632281065, 49.91292089223862, 54.654561057686806, 52.832942605018616, 53.60645189881325, 48.31917621195316, 54.84890162944794, 48.87492299079895, 52.765044048428535, 54.059664979577065, 51.063168570399284, 52.118181958794594, 50.160895586013794, 49.316223710775375, 49.266161397099495, 48.003337159752846, 49.42769452929497, 51.020386666059494, 51.1313521116972, 48.41981761157513, 48.29683721065521, 49.04838748276234, 47.659273222088814, 46.51048086583614, 41.89472794532776, 37.32869155704975, 36.30647040903568, 36.850498616695404, 37.811588644981384, 35.70113629102707, 37.2062773257494, 36.16980314254761, 36.06515675783157, 37.80854120850563, 36.004796996712685, 34.691671058535576, 37.46562480926514, 36.22877597808838, 36.43737718462944, 38.28646056354046, 36.55652739107609, 38.66167142987251, 41.46235294640064, 47.67902456223965, 47.1757073700428, 54.878768026828766, 31.16304360330105, 40.511856749653816, 53.97367179393768, 47.39887319505215, 47.527234107255936, 42.67086669802666, 42.87699043750763, 40.523278936743736, 41.966559290885925, 42.06443063914776, 40.30161403119564, 39.57524500787258, 39.34569172561169, 37.807807847857475, 38.45546409487724, 47.69901528954506, 53.69151413440704, 52.213503643870354, 50.160519406199455, 46.19639351963997, 41.7628788203001, 39.36269961297512, 42.25368708372116, 47.693361192941666, 49.3176144361496, 51.885049268603325, 51.06218442320824, 50.1614997535944, 47.59424731135368, 44.83849458396435, 40.77644035220146, 42.54997618496418, 49.86835688352585, 51.5878102183342, 51.940598487854004, 49.493643790483475, 51.53039149940014, 48.7550014257431, 50.727372989058495, 54.21789228916168, 52.31203995645046, 50.97601644694805, 50.04260413348675, 50.95586612820625, 53.104320243000984, 55.254841446876526, 46.92184679210186, 32.77293361723423, 29.581984542310238, 7.8565282467752695, 5.157325034961104, 16.959468461573124, 18.556144684553146, 3.201681599020958, 7.812215024605393, 6.449154065921903, 0.13299675250891596, 0.49141789320856333, 0.09451655874727294, 1.0859054932370782, 20.757590755820274, 43.49087029695511, 24.435428604483604, 21.708373837172985, 32.150413021445274, 46.427603513002396, 50.70159137248993, 40.10907456278801, 9.768830258399248, 0.13778532680589706, 0.03811548012890853, 0.033948651180253364, 0.06508052538265474, 0.019446228398010135, 0.001028495037189714, 0.08479959695250727, 0.012430550559656695, 0.03981519868830219, 0.03528170054778457, 0.11042328449548222, 0.031097585124371108, 0.022586743179999758, 0.009641608758101938, 0.0394708458770765, 0.03750301904801745, 0.037769917616969906, 0.08278133376734331, 0.07519452134147286, 0.0638769993383903, 0.051582510423031636, 0.005421918021966121, 0.052045636548427865, 0.02767099838820286, 0.007588359339933959, 0.006468783649324905, 0.08921399523387663, 0.07668611200642772, 0.019877547929354478, 0.045226022994029336, 0.07957208683365025, 0.05485077665071003, 0.028546346729854122, 0.03278985808719881, 0.021870674572710413, 0.04161455428402405, 0.02798461700876942, 0.09049434840562753, 0.0603711271105567, 0.03639806505816523, 1.8494169297628105, 27.740793339908123, 51.44251361489296, 51.105505898594856, 36.757783591747284, 17.52339620143175, 24.100351184606552, 37.96961076557636, 25.275318436324596, 2.7527929237112403, 0.025411602146050427, 0.09210564006934874, 9.049462359398603, 10.014812909066677, 13.595963045954704, 9.221003204584122, 8.297552056610584, 8.297957684844732, 9.734991174191236, 11.739811096340418, 21.55545674264431, 43.36773410439491, 50.745729804039, 55.63952520489693, 54.27211157977581, 55.0469584017992, 51.732856035232544, 57.0648705214262, 50.54380103945732, 54.180156514048576, 54.09234702587128, 52.17320300638676, 51.6492111235857, 50.644579231739044, 51.129129230976105, 49.90355059504509, 48.1835462898016, 50.21647520363331, 53.049542382359505, 52.035107016563416, 50.04795044660568, 50.56870870292187, 51.316428780555725, 49.81819577515125, 48.29105772078037, 43.90713036060333, 38.519068881869316, 37.53437452018261, 39.274825528264046, 39.199790954589844, 39.25681829452515, 39.82209876179695, 38.42418037354946, 37.13493995368481, 39.65057976543903, 38.08574393391609, 37.259276881814, 39.67028550803661, 38.89021396636963, 38.81427124142647, 39.91914935410023, 37.28052154183388, 40.50486512482166, 43.73495399951935, 50.24436190724373, 48.78959096968174, 56.73977516591549, 32.873457223176956, 42.59939253330231, 55.50240956246853, 48.34023468196392, 50.79601250588894, 45.63459746539593, 45.14964088797569, 44.55905377864838, 45.61411276459694, 45.455589070916176, 42.10421070456505, 41.466848105192184, 41.301260590553284, 39.36360016465187, 39.926247373223305, 49.21525552868843, 55.1672675460577, 54.08195458352566, 52.01132029294968, 48.70559647679329, 44.488616958260536, 41.78573079407215, 43.49041052162647, 49.6303528547287, 52.193360924720764, 54.49170559644699, 52.600562274456024, 52.476821914315224, 49.55906867980957, 45.43438620865345, 41.304357424378395, 44.472589418292046, 50.99744729697704, 53.11115227639675, 54.14483740925789, 50.53631164133549, 51.48906871676445, 51.439363583922386, 51.78442306816578, 54.8076206445694, 55.21814301609993, 52.48361974954605, 51.60300560295582, 52.666146755218506, 55.45893229544163, 57.6221714168787, 48.69927741587162, 34.79775756597519, 28.38787581771612, 11.166560556739569, 8.71765086427331, 13.944544941186905, 11.237661391496658, 10.267766285687685, 13.68573322892189, 4.219167251139879, 1.120994829107076, 0.45996570435818285, 0.09086300284252502, 1.678120696451515, 22.484751977026463, 47.917978540062904, 29.2860222235322, 25.253838188946247, 36.577395871281624, 51.29030518233776, 55.414288491010666, 43.69431138038635, 11.877688597887754, 0.3000793978571892, 0.010521572330617346, 0.04055035904457327, 0.05398585919465404, 0.04007006333267782, 0.0648566045856569, 0.03194500088284258, 0.1245092845056206, 0.0031968755638445145, 0.03354231419507414, 0.00977785037321155, 0.06679978469037451, 0.03157017177727539, 0.07316710747545585, 0.010962026772176614, 0.01714045720291324, 0.044492721717688255, 0.0743712717667222, 0.05457627477881033, 0.014592728239222197, 0.2422964625293389, 0.04945755979861133, 0.21399106888566166, 0.11929768603295088, 0.05717425548937172, 0.12713752628769726, 0.19887268950697035, 0.1219286589184776, 0.13387719198362902, 0.13961605669464916, 0.24446115887258202, 0.20075244567124173, 0.15574044693494216, 0.12784094869857654, 0.11816572528914548, 0.10117852900293656, 0.21591410710243508, 0.27785560756456107, 0.3497697471175343, 0.17979233991354704, 2.841231753118336, 33.6798195540905, 59.874363765120506, 59.23054151237011, 45.45214645564556, 25.964616648852825, 37.24473886191845, 40.422246158123016, 29.030503034591675, 3.4226513793691993, 0.22147729061543941, 0.25769947038497776, 11.027929745614529, 15.499548800289631, 18.453685082495213, 16.841177009046078, 11.956483069807291, 20.385091044008732, 16.51046745479107, 15.202814172953367, 24.05911199748516, 47.139970287680626, 52.956648766994476, 60.88053837418556, 57.49351032078266, 58.95135149359703, 52.599053755402565, 57.707902416586876, 55.38895525038242, 57.21823789179325, 56.37834616005421, 53.616354167461395, 53.01742650568485, 52.14061975479126, 50.669163912534714, 51.620401069521904, 48.85209381580353, 52.10780471563339, 54.96528938412666, 54.72135007381439, 51.98277622461319, 53.10479521751404, 54.97859627008438, 52.418099865317345, 50.641904175281525, 46.09888315200806, 40.514873787760735, 40.23968115448952, 41.46059364080429, 40.957242250442505, 40.18193945288658, 40.955904722213745, 40.26433423161507, 39.74140629172325, 41.64600469172001, 39.02629606425762, 37.990296855568886, 41.597063317894936, 41.147783026099205, 41.37156441807747, 43.121165335178375, 40.125295892357826, 42.45267480611801, 46.17640659213066, 52.773696184158325, 52.30854794383049, 57.004632353782654, 36.02269783616066, 43.68606962263584, 56.1637868732214, 50.5117991566658, 52.420242950320244, 47.386265471577644, 46.67679414153099, 45.673628970980644, 46.96496307849884, 47.44225166738033, 43.79575073719025, 43.7928818911314, 43.3320502191782, 41.91304676234722, 42.22174599766731, 50.32786622643471, 58.05888958275318, 54.54052537679672, 53.74777011573315, 50.47671563923359, 45.813138484954834, 42.83548526465893, 47.38332822918892, 52.104856073856354, 53.34948688745499, 55.841442570090294, 55.21718166768551, 54.35458995401859, 53.34290184080601, 50.20576737821102, 44.22213725745678, 47.37245701253414, 53.67707870900631, 55.50365209579468, 56.00817382335663, 49.461254328489304, 52.26838789880276, 51.83509334921837, 53.71672958135605, 56.49907328188419, 57.311051711440086, 55.45314900577068, 54.71825323998928, 54.9939626455307, 57.98806518316269, 60.69540090858936, 50.19741542637348, 38.836838230490685, 34.47429232299328, 13.140585981309414, 11.67568288743496, 21.600558422505856, 28.26308861374855, 6.011263187974691, 14.562805965542793, 11.19963588193059, 1.0400737775489688, 1.074444951955229, 0.19612090982263908, 2.1529169753193855, 27.67376683652401, 55.5868486315012, 35.1603227108717, 31.59467004239559, 43.1263292580843, 58.74107077717781, 62.704003527760506, 52.52043977379799, 16.13665111362934, 0.6185543804895133, 0.09073737208382227, 0.0965482325409539, 0.3122630878351629, 0.13850100949639454, 0.13894804957089946, 0.15917571494355798, 0.24474618810927495, 0.1349647797178477, 0.0942267055506818, 0.20956568681867793, 0.16094147722469643, 0.08273661936982535, 0.2076173562090844, 0.13611669681267813, 0.10449287146911956, 0.15648401953512803, 0.14995077479397878, 0.24231569899711758, 0.25551666563842446], [0.04663586238166317, 0.013397994789556833, 0.038989021340967156, 0.008169967950379942, 0.04028849223686848, 0.00973777810941101, 0.03501273880829103, 0.024920174219005276, 0.06710839938023128, 0.08460028577246703, 0.020586024365911726, 0.028470653232943732, 0.05782952735899016, 0.06022637491696514, 0.06495024877949618, 0.1121742112445645, 0.07171025674324483, 0.04732549568871036, 0.09109217804507352, 0.004945742157360655, 1.459004741627723, 18.77704583108425, 45.50010748207569, 41.77156135439873, 34.062071442604065, 20.165973901748657, 17.72136177867651, 29.54928919672966, 20.803929269313812, 0.7800908375065774, 0.5036888003814965, 0.3182729403488338, 9.011755082756281, 21.69091947376728, 11.646528951823711, 11.57406684011221, 11.721240542829037, 10.232611522078514, 9.538127537816763, 16.008679680526257, 30.443840995430946, 46.092708483338356, 51.62904180586338, 53.10350328683853, 45.96811696887016, 48.930373415350914, 46.93970203399658, 48.96215870976448, 50.341480895876884, 49.28655110299587, 50.693972781300545, 52.10318796336651, 51.437064707279205, 52.769356817007065, 51.26147232949734, 50.380979776382446, 48.13265562057495, 45.67750856280327, 47.350456193089485, 51.13857552409172, 50.18391855061054, 48.80459636449814, 50.86103081703186, 51.095463037490845, 49.35699552297592, 51.30442522466183, 45.60660436749458, 38.009702414274216, 35.32298058271408, 36.64656735956669, 36.17027431726456, 36.55186504125595, 37.64435961842537, 36.01719193160534, 35.700566321611404, 36.76089942455292, 35.40696367621422, 35.808776915073395, 37.47972585260868, 35.16892924904823, 36.49650581181049, 36.797795444726944, 38.80993187427521, 41.590425074100494, 46.322375759482384, 47.93187439441681, 55.03221519291401, 38.03514584898949, 42.407658621668816, 52.5472055375576, 47.808088436722755, 46.00472420454025, 37.242325991392136, 38.12267415225506, 35.16501545906067, 36.60223513841629, 36.411671563982964, 37.90433406829834, 36.98009446263313, 39.21689763665199, 38.11015382409096, 38.37254874408245, 45.91024987399578, 53.44534434378147, 51.57327599823475, 51.86506234109402, 49.30683061480522, 47.81842388212681, 46.29276394844055, 48.71112518012524, 49.653622806072235, 53.54342848062515, 51.24895580112934, 50.45050464570522, 53.51544298231602, 53.50869834423065, 49.70933921635151, 46.988309025764465, 49.833752140402794, 50.78363656997681, 54.03222285211086, 50.76953552663326, 46.45811587572098, 49.92888383567333, 50.83661712706089, 51.75994098186493, 52.22616456449032, 51.89231067895889, 47.95091137290001, 50.90529844164848, 51.53920702636242, 53.05010475218296, 51.571136713027954, 53.85223791003227, 37.924438789486885, 26.306784488260746, 18.138241209089756, 16.429890878498554, 24.56502255052328, 10.61064088717103, 20.088972933590412, 15.064103566110134, 13.614819534122944, 1.444846463855356, 0.09254212680389173, 0.06251742190215737, 0.6044737610500306, 12.685884330421686, 31.471089273691177, 40.908981040120125, 33.75277943909168, 32.552640438079834, 42.776656821370125, 47.66927048563957, 43.07028606534004, 11.501755770295858, 0.41371918749064207, 0.04954232048476115, 0.05853994080098346, 0.035056451306445524, 0.04638422979041934, 0.03672785322123673, 0.03372319413756486, 0.008226667105191154, 0.06361747029586695, 0.01845809216320049, 0.07577550422865897, 0.11158459717989899, 0.03494352240522858, 0.06848143195384182, 0.04068430185725447, 0.03391292419109959, 0.026701397291617468, 0.03268025400757324, 0.02644522461196175, 0.008766128685238073, 0.029911868768977, 0.022102133734733798, 0.07132992090191692, 0.02374555668211542, 0.03422622554353438, 0.044176989831612445, 0.08373627002583817, 0.012718488087557489, 0.06697150281979702, 0.054497454984812066, 0.03548775413946714, 0.05307391555106733, 0.02612693602713989, 0.044760852251783945, 0.02063299860310508, 0.057735326554393396, 0.04802409413969144, 0.004732177567348117, 0.04743099198094569, 0.025596081504772883, 2.3043625988066196, 24.49147369712591, 54.31491248309612, 48.113918825984, 40.4356100410223, 24.399697221815586, 21.202573478221893, 29.863838218152523, 22.832967191934586, 1.1900886590592563, 0.38285421556793153, 0.22815019270638004, 8.229307718575, 21.76042914390564, 7.8184699639678, 14.560353197157383, 9.767843261361122, 10.001574419438839, 11.024489980190992, 16.92990604788065, 33.030981570482254, 48.22440169751644, 53.50832216441631, 54.25205625593662, 49.16482463479042, 51.80635929107666, 48.237636387348175, 51.842506751418114, 52.85557799041271, 52.30894312262535, 52.47709169983864, 54.276093766093254, 54.20044742524624, 54.06792193651199, 50.29625192284584, 51.34156063199043, 48.47252458333969, 46.68883189558983, 48.83984327316284, 51.57592065632343, 52.28562377393246, 51.85075990855694, 52.4554480612278, 53.71515266597271, 52.72009626030922, 54.53726515173912, 46.35140240192413, 37.983487620949745, 36.93703517317772, 38.49699206650257, 37.62710854411125, 39.50106918811798, 39.49556328356266, 39.31660808622837, 37.190633565187454, 38.014847338199615, 37.59771712124348, 38.193107172846794, 39.21326503157616, 36.87858670949936, 39.13238637149334, 38.989973813295364, 41.498242020606995, 41.896783635020256, 48.813244700431824, 50.2137241512537, 56.183971390128136, 39.50586073100567, 43.61555300652981, 54.0288258343935, 49.48427729308605, 48.01848694682121, 40.75565926730633, 40.35168394446373, 37.42213994264603, 39.0302212536335, 38.559730499982834, 39.29095946252346, 39.162146374583244, 41.81545279920101, 39.066182523965836, 40.66107854247093, 48.228041902184486, 55.96288405358791, 53.12340281903744, 53.57308588922024, 52.49368540942669, 49.60114762187004, 48.254727870225906, 50.23547798395157, 53.37257444858551, 54.71309691667557, 53.8542366027832, 52.335659489035606, 56.016438379883766, 54.49653893709183, 51.63505308330059, 48.84980633854866, 51.76541268825531, 53.88843096792698, 56.615662425756454, 51.589926704764366, 47.29038521647453, 50.801807194948196, 49.65838775038719, 52.53098800778389, 54.00820814073086, 52.948346212506294, 50.46427510678768, 53.91866594552994, 54.03669901192188, 56.67304314672947, 54.3145515024662, 53.98479759693146, 40.102219730615616, 27.235578149557114, 19.676301777362823, 11.093148496001959, 11.230941452085972, 8.45146469771862, 11.924262698739767, 14.63245527818799, 12.26822404190898, 1.3647346501238644, 0.03553584530891385, 0.0883385504130274, 0.8034053177107126, 15.516283102333546, 35.68380922079086, 31.972453370690346, 29.81657065451145, 36.82595573365688, 49.57364849746227, 54.84148062765598, 50.67544497549534, 14.72866801545024, 0.618478562682867, 0.040002075184020214, 0.08687926543643698, 0.03831581547274254, 0.043689372832886875, 0.029478619653673377, 0.06314644400845282, 0.021761461975984275, 0.06802498144679703, 0.017181974799314048, 0.06363875509123318, 0.047467464828514494, 0.020970083933207206, 0.042482065546209924, 0.05471570577356033, 0.031704303837614134, 0.025482349228695966, 0.05272395210340619, 0.040773122091195546, 0.04083598942088429, 0.15816468716366217, 0.07911810767836869, 0.1966459644609131, 0.14652928104624152, 0.16914703301154077, 0.13127446523867548, 0.1896032501826994, 0.12435612748959102, 0.13379071693634614, 0.26076587615534663, 0.17892328498419374, 0.16763070656452328, 0.19595262041548267, 0.16723245527828112, 0.154275877866894, 0.1790596917271614, 0.15138208080315962, 0.22154381673317403, 0.24474134930642322, 0.08752946843742393, 3.391115446574986, 32.90293224155903, 62.705580443143845, 54.9370227009058, 47.99417205154896, 29.887805432081223, 26.54109511524439, 38.63701835274696, 29.816914536058903, 1.5170987555757165, 0.8059868635609746, 0.6576065474655479, 12.301344014704227, 27.238940969109535, 25.35440929234028, 22.250743433833122, 20.671428479254246, 16.92431464791298, 15.03322072327137, 20.02478677779436, 35.51881447434425, 52.583782374858856, 57.16265067458153, 57.96833664178848, 50.133977830410004, 54.7410786151886, 51.54565908014774, 54.40829247236252, 55.46578332781792, 54.75311636924744, 53.78987945616245, 56.517460495233536, 55.33852435648441, 55.6401863694191, 51.47689796984196, 51.48638606071472, 47.818720266222954, 45.02395883202553, 47.35630787909031, 51.60826452076435, 53.987024277448654, 53.71414951980114, 55.33630907535553, 55.503530502319336, 53.80027949810028, 57.42375746369362, 50.158520713448524, 42.47775346040726, 38.36706183850765, 40.359036549925804, 38.84289130568504, 40.01464582979679, 39.853994250297546, 40.412195697426796, 38.5746219009161, 40.13499677181244, 38.1803322583437, 40.71491025388241, 42.279913276433945, 39.18109215795994, 41.10856153070927, 42.09699109196663, 44.02954079210758, 47.50044174492359, 50.36149442195892, 52.84466877579689, 56.125059351325035, 42.361266911029816, 46.928618028759956, 56.15291565656662, 52.77137830853462, 50.04378207027912, 41.693429946899414, 42.42254622280598, 38.49674887955189, 40.14510802924633, 40.50420016050339, 41.29933789372444, 39.64074969291687, 45.04801534116268, 42.22689852118492, 43.06415319442749, 50.596610605716705, 59.00805205106735, 54.90279793739319, 55.49176253378391, 55.49317225813866, 52.314357832074165, 50.683690533041954, 51.91792510449886, 56.832281202077866, 57.51877896487713, 55.4588259011507, 53.607572838664055, 58.140828385949135, 56.93316958844662, 53.849745243787766, 52.15524896979332, 55.678685903549194, 57.778381034731865, 59.168791025877, 51.76405996084213, 49.39276300370693, 51.93578414618969, 52.304531559348106, 54.72837209701538, 56.659002900123596, 56.43440455198288, 52.96093113720417, 55.660173296928406, 57.00251206755638, 58.59396547079086, 54.9974774569273, 55.84317907691002, 40.84300898015499, 31.27522688359022, 23.040483556687832, 20.68575371056795, 33.846421614289284, 16.351748071610928, 29.911086782813072, 24.505713433027267, 18.424789533019066, 3.7635859474539757, 0.2286094633745961, 0.14282943739090115, 1.1456669052131474, 17.547982782125473, 44.714777022600174, 53.10656972229481, 47.48504117131233, 45.18792763352394, 54.010837599635124, 59.832018837332726, 58.135288283228874, 19.114655815064907, 1.0196125879883766, 0.11102718490292318, 0.2519856160506606, 0.1147536419739481, 0.08666125955642201, 0.053023289947304875, 0.1956835770397447, 0.1326619103201665, 0.28902371297590435, 0.10334431630326435, 0.26189521711785346, 0.13597306155133992, 0.11202558132936247, 0.11344486454618163, 0.09407312551047653, 0.12466069747461006, 0.19160412484779954, 0.21290481701726094, 0.09346853490569629, 0.1676353078801185], [0.007807155143382261, 0.05044781857577618, 0.04143369660596363, 0.05858712283952627, 0.044817567177233286, 0.0299931153858779, 0.09440358902793378, 0.05898295101360418, 0.07655847002752125, 0.10278559784637764, 0.07354244124144316, 0.04837979438889306, 0.01807937976991525, 0.046598532353527844, 0.013236063732620096, 0.07577977157779969, 0.021585637914540712, 0.03617664900957607, 0.03132634657958988, 0.04154182010097429, 2.226408594287932, 25.43865267187357, 44.13992866873741, 44.18780229985714, 27.05378070473671, 14.999333191663027, 28.626510612666607, 48.501950204372406, 17.00301982462406, 1.1135985259898007, 0.07857512275222689, 0.23413074522977695, 6.954745436087251, 5.621576523408294, 8.266977947205305, 8.477499950677156, 5.138244833797216, 6.011788034811616, 12.614127080887556, 19.337781742215157, 31.247077994048595, 45.14956869184971, 52.78966672718525, 46.93826951086521, 49.661982357501984, 47.07470878958702, 45.341067016124725, 44.895860105752945, 46.8079175055027, 46.932459622621536, 49.807719737291336, 49.10322234034538, 50.49574501812458, 50.19370682537556, 50.52998498082161, 49.59732122719288, 51.0427750647068, 51.23236209154129, 48.97527560591698, 50.5539008975029, 49.9780759960413, 51.389479860663414, 51.984843313694, 51.414759904146194, 51.966041922569275, 51.14323407411575, 52.406746074557304, 42.95770190656185, 37.11499482393265, 36.09405040740967, 36.22788302600384, 38.09965118765831, 39.23361673951149, 36.41121558845043, 37.346060425043106, 35.78981973230839, 37.207785844802856, 33.67084823548794, 35.854773446917534, 35.28326891362667, 37.14491441845894, 36.43578127026558, 39.77513328194618, 41.17485657334328, 46.88754603266716, 46.434378549456596, 56.15437097847462, 35.636775344610214, 40.18805332481861, 54.97567042708397, 47.841256856918335, 45.36184050142765, 41.58747263252735, 40.4487307369709, 40.16048960387707, 42.78085179626942, 39.18629787862301, 36.52570724487305, 36.98744706809521, 38.232142478227615, 38.244465216994286, 36.472506299614906, 45.0452870875597, 52.254674434661865, 51.357367783784866, 53.09832416474819, 51.44842989742756, 51.65727809071541, 51.00883528590202, 50.832403153181076, 51.6060758382082, 49.14168767631054, 49.64550644159317, 49.36961084604263, 49.86586041748524, 53.24400834739208, 53.62839952111244, 50.79602770507336, 50.316124856472015, 53.21531988680363, 50.286197662353516, 48.25284697115421, 49.90836873650551, 50.79925373196602, 50.98367303609848, 50.48482060432434, 48.66753771901131, 48.29677261412144, 45.8664458245039, 51.58001683652401, 53.077436685562134, 55.51698558032513, 46.548273637890816, 49.301035925745964, 44.49831023812294, 33.82147595286369, 18.44169482588768, 15.841699540615082, 6.496382681652904, 1.0795023618265986, 19.547976963222027, 5.029240557923913, 8.507496491074562, 8.05504621937871, 0.1657308975700289, 0.21611959295114502, 0.2403020890778862, 10.67434636875987, 45.46612970530987, 80.13834580779076, 60.525477826595306, 35.02683587372303, 44.92301344871521, 49.788895547389984, 45.0626977533102, 15.60758650302887, 0.6182455876842141, 0.06529601538204588, 0.03383389659575187, 0.02695706902159145, 0.06701028745737858, 0.02821508725901367, 0.043475315178511664, 0.02712991707085166, 0.05700368397810962, 0.023853125421737786, 0.015866686881054193, 0.09451914884266444, 0.05054027904407121, 0.01638141824514605, 0.01814018021832453, 0.034783582159434445, 0.012094204594177427, 0.05204542132560164, 0.039409043529303744, 0.055944501946214586, 0.04530221558525227, 0.007281824518940994, 0.04284438204194885, 0.045748695338261314, 0.05009060063457582, 0.05355521687306464, 0.02795979587972397, 0.06551989907165989, 0.02425473307084758, 0.053018963226350024, 0.07745223847450688, 0.01861619188275654, 0.07335396541748196, 0.02686427458684193, 0.05579981654591393, 0.08519305396475829, 0.05338542090612464, 0.06759056530427188, 0.1026803241984453, 0.05780515894002747, 3.26770709361881, 32.81280867755413, 53.41901935636997, 48.68168815970421, 34.27417226135731, 16.182178370654583, 26.928267739713192, 47.732951268553734, 19.136151261627674, 1.2354102521203458, 0.10847407815163024, 0.3571480605751276, 6.853034868836403, 5.80008334480226, 7.083216067403555, 8.811552375555038, 8.903915919363499, 6.764071192592382, 7.954962914809585, 21.459413096308708, 35.4994773119688, 47.47105032205582, 54.609248489141464, 49.92187321186066, 51.01864255964756, 48.957120180130005, 47.507235780358315, 47.63369299471378, 49.1028917580843, 50.945431888103485, 53.001212775707245, 52.202708423137665, 52.075726836919785, 51.940932869911194, 52.538701593875885, 52.197263315320015, 51.90369486808777, 50.59099070727825, 48.64340141415596, 49.55586165189743, 49.47470560669899, 50.968876630067825, 51.800439208745956, 51.96294128894806, 51.79911307990551, 53.10974635183811, 52.54975140094757, 44.81176681816578, 38.62182296812534, 37.566562592983246, 37.96815924346447, 39.45816949009895, 40.767909809947014, 38.01246486604214, 39.77159567177296, 37.487488836050034, 38.617768585681915, 37.31188885867596, 37.682387977838516, 37.45163016021252, 40.117646902799606, 38.37561517953873, 40.92441961169243, 43.332414999604225, 49.11788955330849, 50.69998025894165, 56.035988330841064, 38.344939425587654, 42.88196437060833, 55.24895936250687, 48.62364247441292, 47.291114777326584, 42.99304760992527, 42.30742000043392, 40.47523431479931, 43.31295624375343, 40.10097339749336, 40.16982190310955, 38.119858503341675, 40.28269484639168, 40.094004571437836, 37.76936151087284, 47.277583703398705, 54.96254973113537, 53.24493929743767, 53.286140486598015, 54.895266741514206, 54.14357207715511, 53.48922438919544, 52.96865992248058, 52.587870955467224, 49.77928586304188, 49.05635945498943, 49.22505520284176, 52.04107269644737, 55.49549013376236, 55.12036666274071, 53.328219428658485, 52.70569883286953, 54.033339992165565, 52.049477845430374, 49.31447580456734, 49.80181485414505, 51.6649878770113, 51.09545923769474, 53.89630414545536, 51.66349455714226, 50.872680991888046, 47.60682463645935, 52.522107884287834, 54.7773552685976, 57.00011059641838, 48.30982871353626, 50.230629444122314, 46.5660984814167, 35.30362442135811, 22.670225724577904, 13.599321115761995, 6.832306981086731, 9.308958034962416, 12.884745709598064, 6.2984484527260065, 14.81636255979538, 8.817095328122377, 0.09372433094540611, 0.1632964750751853, 0.2477354698930867, 11.862163580954075, 42.62173153460026, 71.42108917236328, 62.73897685110569, 42.24409639835358, 48.16289059817791, 55.71651667356491, 53.88961270451546, 19.876077957451344, 0.9096128842793405, 0.010988489902956644, 0.022591183078475296, 0.04491951229283586, 0.055275567137869075, 0.002511751267775253, 0.024251478753285483, 0.01876885537058115, 0.06633115553995594, 0.0547242553147953, 0.05897146627830807, 0.09972460975404829, 0.055695511400699615, 0.019244623981649056, 0.020557726275001187, 0.0752923809341155, 0.07892256660852581, 0.05437234744022135, 0.03209468093700707, 0.04686765365477186, 0.14852148742647842, 0.21931789320660755, 0.10088600407470949, 0.21634671982610598, 0.15800803463207558, 0.13082228950224817, 0.17666228755842894, 0.22786721179727465, 0.10327860654797405, 0.14335281477542594, 0.1423127541784197, 0.12310025776969269, 0.18570231419289485, 0.1509218305000104, 0.18974727136082947, 0.19096384436124936, 0.13575350458268076, 0.17454908142099157, 0.20784722903044894, 0.12881357775768265, 4.693788383156061, 40.96928760409355, 60.71229100227356, 56.66710406541824, 38.577600941061974, 22.797575891017914, 40.80186478793621, 60.09478233754635, 22.444151155650616, 1.9313759193755686, 0.24964595097117126, 0.7086540176533163, 11.940873507410288, 9.993174020200968, 19.853387475013733, 16.292969025671482, 12.45279723778367, 10.876470822840929, 16.885653622448444, 22.1629586443305, 36.21205687522888, 49.035342782735825, 57.57927551865578, 52.13973060250282, 54.35295604169369, 52.39450693130493, 50.18994502723217, 49.721965938806534, 50.56963965296745, 52.58584566414356, 54.44076173007488, 54.468530640006065, 55.403234884142876, 55.049344673752785, 54.12439450621605, 52.58734658360481, 53.45899701118469, 52.94417783617973, 50.02667538821697, 50.56382976472378, 49.80026073753834, 50.7521590590477, 52.604172080755234, 53.508170172572136, 52.927097752690315, 57.121761068701744, 56.12323924899101, 48.04594807326794, 40.396244153380394, 40.235159397125244, 40.370587930083275, 41.03025533258915, 42.646726593375206, 40.14895722270012, 41.14491418004036, 38.90143856406212, 42.38576799631119, 39.758543372154236, 39.75839138031006, 38.79594102501869, 42.15316727757454, 40.956615284085274, 43.42197999358177, 45.294853895902634, 51.30893938243389, 53.117475137114525, 58.64620506763458, 40.85393339395523, 46.249761655926704, 57.71723851561546, 53.044758439064026, 48.942962139844894, 46.30873069167137, 43.852481693029404, 44.322831854224205, 46.61415450274944, 42.94846460223198, 40.10979652404785, 40.837848857045174, 42.46789678931236, 41.896551847457886, 40.17868682742119, 51.051377803087234, 55.86157388985157, 55.25369010865688, 54.85861390829086, 56.7039430886507, 57.44287043809891, 57.067746967077255, 55.96586689352989, 54.061963856220245, 49.34212692081928, 48.91438007354736, 50.17152741551399, 52.432618886232376, 56.48260876536369, 56.95190258324146, 56.11034274101257, 55.397592186927795, 57.509993836283684, 52.153539061546326, 50.762376710772514, 51.709901466965675, 52.197502702474594, 52.6313254237175, 55.75781665742397, 53.605034574866295, 53.103985860943794, 51.345428824424744, 57.131682336330414, 59.190301671624184, 60.78729137778282, 49.426584988832474, 49.764139875769615, 49.652251079678535, 40.2754220366478, 28.213358782231808, 20.35755392163992, 16.222851388156414, 12.839432191103697, 33.49601201713085, 11.70686211436987, 14.825680609792471, 12.409340869635344, 0.5462881363928318, 0.4174676863476634, 0.6083430221769959, 14.62861368432641, 55.94618394970894, 86.48020550608635, 68.7243814766407, 48.505138233304024, 56.92043647170067, 62.70297758281231, 59.91845279932022, 24.87311191856861, 1.2253101565875113, 0.15289564646082, 0.16069026023615152, 0.23481712793000042, 0.1882597550866194, 0.11347655425197445, 0.12381597756757401, 0.11790425181970932, 0.16125561349326745, 0.18934343912405893, 0.10049435790278949, 0.2073869638843462, 0.09875410323729739, 0.13904731924412772, 0.06062350556021556, 0.16216383897699416, 0.14841458847513422, 0.16334110783645883, 0.21585369628155604, 0.07527361944084987], [0.038047057823860087, 0.05239484671619721, 0.08622999012004584, 0.026617347211868037, 0.07993231047294103, 0.06477648974396288, 0.018377012529526837, 0.07935373956570402, 0.07925769823486917, 0.019344793508935254, 0.06310076481895521, 0.016455139484605752, 0.014159233287500683, 0.04888915631454438, 0.02495879372872878, 0.01839272750657983, 0.051426967402221635, 0.07038714102236554, 0.04742709941638168, 0.04797106026671827, 3.4290751721709967, 27.276995927095413, 42.71741420030594, 45.867866948246956, 31.533375531435013, 19.41516648977995, 32.939733266830444, 35.47570958733559, 14.12368917837739, 0.3287531639216468, 0.7131596852559596, 4.165670396760106, 30.16866736114025, 32.454772889614105, 5.546084549278021, 10.769564509391785, 10.332711450755596, 9.373715110123158, 12.026099134236574, 28.674382343888283, 40.362463966012, 49.39740255475044, 51.120450496673584, 47.76385121047497, 44.95420217514038, 42.35660456120968, 40.89972473680973, 41.379331201314926, 41.851402670145035, 40.572448298335075, 43.44928152859211, 45.35771392285824, 47.59358234703541, 47.50169947743416, 46.46295301616192, 50.128164142370224, 50.60431279242039, 49.15292747318745, 50.4757808893919, 51.954319551587105, 51.45896293222904, 48.870940804481506, 49.54507403075695, 48.94737750291824, 50.890559032559395, 49.159349128603935, 50.634194388985634, 45.35664618015289, 36.39842547476292, 32.427991926670074, 35.52339322865009, 36.4984817057848, 38.08741584420204, 38.375854566693306, 37.05290615558624, 37.856832817196846, 34.81176741421223, 34.194661527872086, 35.80245025455952, 34.904866218566895, 36.48952938616276, 36.07057146728039, 39.12998490035534, 40.79022981226444, 46.8506234139204, 44.71841722726822, 56.537766605615616, 39.207766726613045, 38.76614682376385, 55.27166694402695, 46.63606032729149, 48.37956637144089, 45.599342957139015, 49.512783363461494, 49.7989422082901, 50.67972354590893, 46.89187780022621, 40.66213868558407, 37.04125598073006, 39.43104274570942, 38.62832821905613, 35.02875857055187, 40.611669793725014, 50.909903794527054, 50.264698415994644, 50.35355284810066, 48.14257308840752, 49.706857949495316, 50.099574476480484, 47.859625071287155, 47.50320799648762, 48.23457755148411, 50.07551796734333, 51.82418793439865, 51.87909498810768, 49.65006999671459, 52.708275094628334, 53.17320674657822, 52.00626656413078, 50.192357897758484, 48.22215981781483, 52.26986601948738, 52.50492140650749, 51.87644653022289, 51.10339321196079, 49.835716634988785, 47.88589686155319, 44.54253226518631, 43.19773502647877, 49.54526402056217, 51.55935734510422, 55.27653448283672, 48.54552626609802, 43.756149262189865, 43.270485922694206, 36.32264234125614, 23.682747893035412, 11.839198563247919, 7.063023475930095, 5.768634332343936, 5.631159134209156, 7.966673886403441, 3.999824495986104, 18.84658209979534, 1.6229824488982558, 0.09225025496562012, 0.17737752496032044, 6.866378327831626, 37.17498980462551, 52.715487107634544, 21.404116563498974, 21.728577353060246, 41.36812560260296, 47.91404955089092, 46.50830738246441, 17.784480191767216, 1.3191403029486537, 0.034120261698262766, 0.0985316073638387, 0.021478288108482957, 0.04876413782767486, 0.05791128976852633, 0.0399146353447577, 0.0937517533020582, 0.03786955836403649, 0.05969779136648867, 0.039639317110413685, 0.04564231960102916, 0.04170611304289196, 0.020162514083494898, 0.01386644396916381, 0.10002232971601188, 0.013841757354384754, 0.023332019009103533, 0.06280522677116096, 0.07086739220540039, 0.0614241864241194, 0.039423986672773026, 0.05044236379035283, 0.05973556668322999, 0.03489023249130696, 0.018711800912569743, 0.035507654829416424, 0.061234593667904846, 0.044588072851183824, 0.018845109188987408, 0.09315756018622778, 0.019178153524990194, 0.04118187847780064, 0.07542647217633203, 0.09029036911670119, 0.013167713786970126, 0.015916356969682965, 0.009667748126958031, 0.023628944873053115, 0.01555287901283009, 5.2234158385545015, 33.04384388029575, 50.846242010593414, 53.408106341958046, 36.000723615288734, 25.2475381270051, 36.97289004921913, 39.34314966201782, 15.510993786156178, 0.595720277633518, 0.8424466790165752, 5.625171130523086, 31.96763902902603, 23.537360094487667, 5.498427031561732, 9.262552075088024, 15.240858681499958, 7.001157095655799, 9.834974259138107, 27.998400516808033, 38.34143601357937, 51.268099173903465, 54.09908026456833, 50.21013714373112, 47.58999153971672, 44.84758369624615, 42.751437574625015, 43.72688703238964, 44.0285262465477, 44.56445328891277, 46.530710980296135, 47.62186422944069, 49.77264001965523, 49.52872350811958, 49.5590078830719, 52.430422604084015, 52.089010924100876, 50.97053714096546, 52.29432910680771, 52.93744459748268, 52.145392298698425, 49.44246053695679, 51.12983599305153, 48.249803334474564, 49.47313629090786, 50.309007838368416, 53.29130440950394, 45.67751996219158, 36.94719962775707, 34.498823806643486, 36.81287303566933, 37.09683559834957, 39.4393453001976, 40.00538572669029, 39.58076611161232, 38.628932386636734, 38.41084688901901, 36.5118607878685, 37.67904035747051, 37.67004244029522, 39.43252086639404, 37.05116964876652, 41.329610869288445, 43.28654006123543, 49.18937511742115, 47.14426785707474, 56.04006551206112, 40.315620079636574, 40.73294408619404, 56.71456351876259, 49.44656811654568, 49.33510109782219, 48.211182206869125, 50.46025112271309, 51.7960162460804, 52.61928007006645, 48.0902498960495, 42.55441054701805, 39.22862760722637, 41.36579632759094, 38.9460139721632, 36.59698761999607, 42.25173398852348, 53.058665692806244, 52.571664825081825, 50.952788293361664, 51.34980618953705, 50.61680272221565, 50.791859328746796, 49.613705947995186, 46.71291500329971, 48.17592769861221, 50.19300006330013, 51.6961158066988, 51.50697335600853, 51.58698186278343, 54.83064740896225, 53.71954143047333, 51.46022446453571, 51.65823943912983, 48.8717045634985, 51.57483011484146, 52.932250276207924, 53.63537594676018, 54.276462346315384, 51.60542607307434, 49.77780394256115, 46.94662146270275, 47.52527341246605, 51.11237213015556, 54.24884542822838, 56.36218182742596, 50.24509906768799, 45.346185341477394, 46.622559651732445, 39.157138243317604, 27.34346766024828, 16.9504876434803, 13.002167958766222, 12.55916777998209, 12.668935339897871, 7.075675372034311, 7.015429604798555, 19.358996003866196, 1.4265171973966062, 0.03859460695821326, 0.19531944970367476, 9.009377360343933, 42.30691842734814, 66.1545641720295, 34.49133440852165, 27.885149493813515, 48.17316144704819, 54.82104152441025, 53.47689405083656, 21.051263697445393, 1.664505552034825, 0.03847310996206943, 0.05483142515004147, 0.0354026001150487, 0.019745332465390675, 0.03659258196421433, 0.022267222630034667, 0.019733022090804297, 0.013999535167386057, 0.0986555905546993, 0.02820934674673481, 0.03970248129917309, 0.04609479219652712, 0.016053457620728295, 0.023254741026903503, 0.09396011126227677, 0.06478420807980001, 0.04776190820848569, 0.0670717001776211, 0.10553568543400615, 0.12652543256990612, 0.1590480507002212, 0.14520350843667984, 0.09340529650216922, 0.212171352468431, 0.2149192729848437, 0.08982433006167412, 0.4105803184211254, 0.18086783064063638, 0.14766966516617686, 0.23174343426944688, 0.09003568629850633, 0.1723748113727197, 0.1714144425932318, 0.1731767613091506, 0.1330221488024108, 0.08391000679694116, 0.17308933631284162, 0.15488838718738407, 0.14548267470672727, 7.443687524646521, 40.8451596647501, 59.14047874510288, 59.0708626806736, 42.46753200888634, 30.144582353532314, 42.584083154797554, 46.54879420995712, 19.469210989773273, 0.8618338324595243, 1.3018879224546254, 5.997916404157877, 41.54993824660778, 42.489764615893364, 14.62370814755559, 23.598441816866398, 20.64094841480255, 15.80867551267147, 15.369217693805695, 35.554410964250565, 43.18791635334492, 52.59792901575565, 56.95694491267204, 52.718857526779175, 49.952784553170204, 46.762810125947, 45.05404181778431, 46.89828425645828, 46.987511068582535, 46.29610396921635, 48.00054430961609, 48.81530798971653, 51.811903193593025, 51.50400571525097, 52.92979180812836, 54.326456263661385, 56.041296645998955, 52.39405855536461, 54.15035091340542, 56.89187340438366, 54.37600940465927, 50.57194992899895, 52.01540507376194, 50.55445186793804, 50.65366834402084, 51.85597322881222, 55.09502202272415, 50.24998180568218, 40.13400122523308, 35.71681424975395, 38.622613325715065, 39.07065108418465, 41.8980223685503, 42.523157224059105, 41.447066366672516, 42.83656820654869, 40.145643800497055, 39.15401101112366, 39.66640591621399, 39.66695308685303, 40.44948689639568, 39.65950548648834, 43.61338332295418, 46.10240936279297, 51.73714600503445, 49.23467628657818, 58.74556973576546, 43.78802575170994, 44.132420271635056, 56.98330409824848, 51.00723177194595, 51.50575742125511, 48.978551030159, 53.83668914437294, 54.06728737056255, 54.74169038236141, 51.78330212831497, 45.01804634928703, 40.366453751921654, 44.24498923122883, 40.919966250658035, 39.402312487363815, 43.59319880604744, 53.80750671029091, 54.07282367348671, 52.72469021379948, 52.30159051716328, 51.94852866232395, 51.79782114923, 49.22465622425079, 46.52912266552448, 48.410853892564774, 50.36513462662697, 53.811815679073334, 54.05593737959862, 53.78907009959221, 55.612409859895706, 54.10287246108055, 52.33627125620842, 51.48243807256222, 50.34230165183544, 51.499381363391876, 52.977623641490936, 54.01292748749256, 56.560550183057785, 54.164033979177475, 53.394085094332695, 49.81528893113136, 49.21691983938217, 54.01436761021614, 58.33372503519058, 60.43361395597458, 52.82528601586819, 48.8537011295557, 49.52782295644283, 45.104864090681076, 31.19047813117504, 18.215333372354507, 11.28559771925211, 9.939301460981369, 14.722775481641293, 16.835798397660255, 11.006311755627394, 23.043033219873905, 2.2257787780836225, 0.14280243805842474, 0.4609122988767922, 9.656846467405558, 46.58712275326252, 58.470270708203316, 32.68130913376808, 35.663514509797096, 54.68651734292507, 61.761745288968086, 64.04403582215309, 26.481580808758736, 2.252176911570132, 0.1198251749156043, 0.12504420970799401, 0.13073582929791883, 0.20174288627458736, 0.12920568406116217, 0.13381402037339285, 0.3037201665574685, 0.10973546202876605, 0.19806863187113777, 0.12095225232769735, 0.16599066409980878, 0.24896995833842084, 0.08258162924903445, 0.16569242463447154, 0.22185801237355918, 0.1582221145508811, 0.130801257037092, 0.1691898104036227, 0.11466393116279505], [0.018788980560202617, 0.015261840235325508, 0.08278876266558655, 0.033258019684581086, 0.03745244539459236, 0.04222808034683112, 0.035983315829071216, 0.03713489153597038, 0.034699741736403666, 0.021164608260733075, 0.04826028263778426, 0.020117009298701305, 0.05688807592377998, 0.11869391179061495, 0.032695891059120186, 0.020488044174271636, 0.011594437710300554, 0.055245064868358895, 0.056132736572180875, 0.029069199044897687, 3.6186607740819454, 26.47036001086235, 48.13975743949413, 39.28701527416706, 29.868118688464165, 20.131608545780182, 37.6716573536396, 44.332589730620384, 11.792565565556288, 0.396241580019705, 0.30736244923900813, 1.146255279891193, 8.589367847889662, 21.817773766815662, 12.16502157971263, 4.222564268857241, 6.174596948549151, 4.112554471939802, 7.884486196562648, 27.221744991838932, 36.72145374119282, 50.672568529844284, 52.37886697053909, 48.33671607077122, 46.370287388563156, 42.76862405240536, 41.520641818642616, 42.24998228251934, 41.51062175631523, 39.10303674638271, 40.56245103478432, 40.40477469563484, 41.119356751441956, 42.347048074007034, 41.64797678589821, 43.14155884087086, 44.75454568862915, 46.519296392798424, 48.49171355366707, 48.7834656983614, 47.85447634756565, 50.00716723501682, 48.77335824072361, 49.6335256844759, 52.57626257836819, 51.79324619472027, 50.84945283830166, 43.31804037094116, 36.06609530746937, 37.876340970396996, 36.225325763225555, 38.377302289009094, 45.77457055449486, 42.32707254588604, 43.422291576862335, 39.90762077271938, 38.28859984874725, 35.620295628905296, 37.66669861972332, 35.67104950547218, 36.2817869335413, 36.811653301119804, 37.45095759630203, 40.5008677393198, 48.023255690932274, 46.961383670568466, 56.204585283994675, 34.60481531918049, 36.30572944879532, 56.107257306575775, 52.2200582921505, 51.193615570664406, 49.23621900379658, 51.91990099847317, 50.380987375974655, 52.55635924637318, 49.26343314349651, 46.170938685536385, 38.505150228738785, 36.963880732655525, 38.40350188314915, 37.777409479022026, 37.433645725250244, 50.373045802116394, 52.84284867346287, 47.65210680663586, 48.37740048766136, 46.657065600156784, 47.34271980822086, 49.06368546187878, 52.80559927225113, 52.81402722001076, 51.213936880230904, 50.795510932803154, 50.98226711153984, 52.75994852185249, 51.14049442112446, 49.185605719685555, 48.1637417525053, 48.6177983880043, 51.55337646603584, 49.77518208324909, 51.695348247885704, 52.3434566706419, 48.31499643623829, 47.647140473127365, 42.56689667701721, 42.122301533818245, 42.44642414152622, 45.756278336048126, 49.99207824468613, 52.65826977789402, 52.71049037575722, 53.557673916220665, 46.559190452098846, 39.54678073525429, 30.850704163312912, 19.889514036476612, 11.956865899264812, 18.48000817000866, 12.215912248939276, 5.874641519039869, 8.167412839829922, 18.11053689569235, 4.905621316283941, 0.35981266759335995, 0.16599290538579226, 5.331389419734478, 27.547047436237335, 24.92621786892414, 17.905558794736862, 27.236402705311775, 37.79638186097145, 46.21587507426739, 48.05449761450291, 16.292866431176662, 0.7152463076636195, 0.02653565716173034, 0.01165567324278527, 0.02692242371267639, 0.015910839101707097, 0.0717843379243277, 0.023850279285397846, 0.08068652547081001, 0.02340845650905976, 0.01039156846672995, 0.071490402915515, 0.020783992258657236, 0.09556035976856947, 0.04351420000602957, 0.02660862883203663, 0.05175964251975529, 0.03184041001077276, 0.01750317074765917, 0.019729164778254926, 0.0166604026890127, 0.0322236142528709, 0.03268341926741414, 0.029878533350711223, 0.03058723985304823, 0.09064698591828346, 0.02221350969193736, 0.016908825491555035, 0.04217021138174459, 0.07546016568085179, 0.04835390456719324, 0.035840166674461216, 0.05995608473313041, 0.0822215985681396, 0.028744654155161697, 0.04906655187369324, 0.045532722942880355, 0.024430236153420992, 0.01458197359170299, 0.0665384522289969, 0.0859301550372038, 4.785789046436548, 32.069557160139084, 52.7604690939188, 44.78182062506676, 33.99460606276989, 22.693180292844772, 37.39067763090134, 45.75671911239624, 13.013203516602516, 0.393226501182653, 0.4839507001452148, 1.7792339832521975, 13.541796952486038, 27.135590314865112, 9.054650980979204, 6.3783828634768724, 10.600365288555622, 6.192137282341719, 10.182006787508726, 29.661442078649998, 40.57635448873043, 53.18567767739296, 52.55057595670223, 50.61560958623886, 47.63557009398937, 45.76023772358894, 44.024707451462746, 43.89474682509899, 43.210338950157166, 41.78418807685375, 43.22515435516834, 43.62907648086548, 44.71217416226864, 44.56606060266495, 44.00115631520748, 45.324910283088684, 47.09925927221775, 48.2208488881588, 51.28934383392334, 51.664752289652824, 51.42639867961407, 51.196127235889435, 52.03256495296955, 51.56590819358826, 54.57663103938103, 53.08963783085346, 52.86434791982174, 45.39853893220425, 37.545492723584175, 39.836876168847084, 38.62734027206898, 39.18463356792927, 45.38840487599373, 44.696967378258705, 45.72798125445843, 41.04032479226589, 39.50058661401272, 36.48045167326927, 38.122533559799194, 37.3837012052536, 37.97544725239277, 37.86539375782013, 40.304859057068825, 42.364508137106895, 49.66615453362465, 47.769121527671814, 57.84470647573471, 37.3818165063858, 38.444368690252304, 56.498602107167244, 52.4538217484951, 51.8598186224699, 51.01382061839104, 54.12729375064373, 51.589368134737015, 53.2911866158247, 51.29432536661625, 49.59904633462429, 40.67085161805153, 38.641581907868385, 40.444068387150764, 39.38780106604099, 40.05528464913368, 53.00056681036949, 55.605539828538895, 49.619097858667374, 50.092396661639214, 48.455189913511276, 48.41076269745827, 49.46997866034508, 52.70510986447334, 53.84854830801487, 53.13981793820858, 51.56432747840881, 52.50328749418259, 53.99444527924061, 52.88466922938824, 50.09276144206524, 50.031763315200806, 49.798140451312065, 50.56911528110504, 50.304212495684624, 52.86887727677822, 52.62605510652065, 51.24721549451351, 51.2646147608757, 44.507669135928154, 44.71208296716213, 44.644598588347435, 48.506920337677, 52.84500315785408, 55.51449291408062, 55.45534148812294, 55.323792546987534, 48.37890140712261, 43.33836168050766, 31.082339733839035, 16.964809074997902, 13.520369902253151, 15.25826744735241, 10.947844292968512, 9.909523408859968, 9.260713923722506, 19.960401132702827, 4.050171319395304, 0.19005634618224576, 0.10955464516882785, 5.955578600987792, 35.5868536233902, 33.64450804889202, 18.682467006146908, 32.041233479976654, 43.0204289406538, 52.39463232457638, 57.72025555372238, 20.076078325510025, 1.1045301938429475, 0.050764919724315405, 0.03250124798796605, 0.048817665228853, 0.029841203322575893, 0.05108604331326205, 0.03817204662482254, 0.07197207902208902, 0.049384777375962585, 0.0798128024325706, 0.010655119021976134, 0.05182268796488643, 0.1110113994218409, 0.03749864408746362, 0.05940991970419418, 0.08339126041391864, 0.06623400840908289, 0.07040186523227021, 0.042500084891798906, 0.025040821456059348, 0.1104995772766415, 0.17105977021856233, 0.18401793582597747, 0.11875123527715914, 0.15963381301844493, 0.09640348405810073, 0.17703494959278032, 0.15587789268465713, 0.21893653320148587, 0.17364185041515157, 0.15172106417594478, 0.19824521848931909, 0.13916843774495646, 0.1560235465876758, 0.06915007732459344, 0.10479961594683118, 0.13133587053744122, 0.16977634455543011, 0.17528875032439828, 0.13548469869419932, 6.739405291154981, 41.45386040210724, 61.86107195913792, 51.321444511413574, 39.85902518033981, 30.31485691666603, 49.24914211034775, 54.485036954283714, 15.032342970371246, 0.7366449187975377, 0.7780970726162195, 1.6706353356130421, 11.484271008521318, 26.825872734189034, 16.39299675822258, 10.087676849216223, 12.496043667197227, 8.18701408803463, 10.317100938409567, 31.305148378014565, 38.888238072395325, 56.25272110104561, 55.94658672809601, 53.90416592359543, 51.59436106681824, 49.282101541757584, 46.385851353406906, 46.558107510209084, 46.486960127949715, 44.12560723721981, 46.34669065475464, 44.33273412287235, 46.84617005288601, 46.82722806930542, 45.41603319346905, 48.15045766532421, 48.929507061839104, 50.67398585379124, 53.80533702671528, 53.80952060222626, 53.68355356156826, 53.09405319392681, 54.874523654580116, 52.810166627168655, 57.50990644097328, 54.55481261014938, 54.19936828315258, 48.86770337820053, 38.87009024620056, 41.09239719808102, 41.250358521938324, 41.42567351460457, 49.02787998318672, 46.63989432156086, 48.69812227785587, 43.85938212275505, 42.088867127895355, 38.36569771170616, 41.5427528321743, 39.77067992091179, 39.99039173126221, 40.57348944246769, 42.01424293220043, 44.90812584757805, 52.27463856339455, 51.84002548456192, 58.6133748292923, 40.69379098713398, 40.8514179289341, 57.48768903315067, 57.06568367779255, 54.109856486320496, 54.14132259786129, 54.623972699046135, 53.04586797952652, 55.823359340429306, 52.984816655516624, 52.45256021618843, 42.498648539185524, 41.35264903306961, 42.547422721982, 41.82375155389309, 42.3524209856987, 55.46524755656719, 56.97768419981003, 51.74963213503361, 52.306047677993774, 47.67885357141495, 48.347655683755875, 51.25060111284256, 54.110388457775116, 55.99568389356136, 56.34006321430206, 55.47169201076031, 55.589470490813255, 56.32965937256813, 54.073059260845184, 51.394180208444595, 49.806287214159966, 49.424381107091904, 50.23164018988609, 48.28381150960922, 54.71299432218075, 55.64312361180782, 54.19923909008503, 53.421268835663795, 46.837916895747185, 47.15936824679375, 48.111752942204475, 50.14270596206188, 55.87744943797588, 57.175957560539246, 58.944736048579216, 57.923533245921135, 52.29950822889805, 41.882238015532494, 36.299277395009995, 21.86574999243021, 17.905125617980957, 28.155541084706783, 21.731201112270355, 13.983790185302496, 11.834823098033667, 23.96099366247654, 5.730078751221299, 0.3767253819387406, 0.2513592434115708, 7.564319176599383, 36.65473312139511, 38.909110352396965, 29.64525304734707, 38.66585500538349, 49.93518769741058, 58.35633002221584, 65.37410125136375, 26.745860427618027, 1.5195118635892868, 0.12829814135329798, 0.1792574889259413, 0.11596690499573015, 0.13803433219436556, 0.19909668451873586, 0.12574598455103114, 0.16479219950269908, 0.11428768455516547, 0.161205384938512, 0.10029529905295931, 0.12489690823713318, 0.15044310071971267, 0.13423599069938064, 0.14383878791704774, 0.12974117329576984, 0.1194516074610874, 0.13809024560032412, 0.18216578755527735, 0.13737573550315574], [0.01817207030399004, 0.029956113758089487, 0.028178965076222084, 0.028989336533413734, 0.013157191060599871, 0.032000769570004195, 0.08170798042556271, 0.03966870244767051, 0.06705958832753822, 0.05582365432928782, 0.10011673832195811, 0.026616493742039893, 0.09439171466510743, 0.04543396535154898, 0.015187832341325702, 0.03621708492573816, 0.06297533444012515, 0.0136136777473439, 0.044193721550982445, 0.11539686136529781, 3.4746128786355257, 34.072129502892494, 44.28971283137798, 51.55575513839722, 24.917508736252785, 28.714441694319248, 57.90529042482376, 41.76304221153259, 8.030734173953533, 0.24760042870184407, 0.7878797664307058, 3.951396094635129, 7.845041938126087, 3.666610401123762, 1.671201386488974, 4.500194946303964, 15.803691130131483, 4.690793668851256, 13.898643404245377, 33.84645961225033, 41.570213958621025, 53.37343320250511, 51.63005635142326, 51.4448618888855, 45.233798772096634, 46.69821739196777, 45.43646849691868, 45.8729662746191, 43.46669599413872, 39.767795875668526, 36.17520645260811, 38.620648831129074, 38.01043197512627, 36.64146043360233, 35.73789171874523, 35.872438699007034, 36.61655656993389, 38.64525631070137, 39.36636261641979, 40.76333865523338, 40.284218564629555, 41.31576821208, 43.94343741238117, 43.83075825870037, 45.60411550104618, 47.27199800312519, 45.94143480062485, 38.42418037354946, 34.464496448636055, 37.52753488719463, 42.01243042945862, 48.25442388653755, 48.88365492224693, 47.951397746801376, 44.41385976970196, 41.57573886215687, 38.81971634924412, 38.29448573291302, 36.22284449636936, 35.43611191213131, 37.165938690304756, 35.848522782325745, 39.44842681288719, 43.895719572901726, 46.938607692718506, 46.38244293630123, 54.937550872564316, 37.39540457725525, 33.86750288307667, 53.26029047369957, 47.42364026606083, 52.507676258683205, 47.04489938914776, 50.82700364291668, 46.82619832456112, 48.98279160261154, 50.518266409635544, 45.943087711930275, 39.047943502664566, 37.60800316929817, 36.51788726449013, 39.67288836836815, 36.40809215605259, 41.49254232645035, 50.596344619989395, 51.64099596440792, 53.083216175436974, 53.94531011581421, 50.50295703113079, 51.60561986267567, 50.49563102424145, 48.542706817388535, 45.76334975659847, 47.055614814162254, 49.02954809367657, 48.48710060119629, 51.75529383122921, 49.61596302688122, 50.59486269950867, 52.972991690039635, 49.22836482524872, 47.17892199754715, 50.05429990589619, 50.79643428325653, 47.818439081311226, 46.3448553532362, 41.11456520855427, 39.003086909651756, 39.26484726369381, 39.549094811081886, 44.45966251194477, 47.94904567301273, 52.14270204305649, 52.41403788328171, 52.9733906686306, 44.046495482325554, 27.363707274198532, 17.36493520438671, 21.47056169807911, 20.605131536722183, 9.210122488439083, 8.259333707392216, 1.874895750079304, 6.7312870267778635, 6.62199966609478, 0.11809305418864824, 0.09728601638926193, 3.347405679523945, 21.720464788377285, 37.90332332253456, 31.036426797509193, 26.418973468244076, 38.27137917280197, 48.628741800785065, 49.439063519239426, 14.298817031085491, 0.5297139601316303, 0.05643623044306878, 0.03448628893238492, 0.07931462838314474, 0.05001279387215618, 0.082288703561062, 0.018259322750964202, 0.060322787321638316, 0.02036230951489415, 0.06433127535274252, 0.07555773583590053, 0.03343897384183947, 0.05849347493494861, 0.0679503584979102, 0.04975890515197534, 0.044380419931258075, 0.023705065104877576, 0.021556404717557598, 0.038372255803551525, 0.08785325262579136, 0.11221268418012187, 0.02378299061092548, 0.05620899595669471, 0.05810098271467723, 0.01478010753999115, 0.007293312037290889, 0.09214996112859808, 0.038402390709961765, 0.04483478500333149, 0.05045429010351654, 0.031573207161272876, 0.0363743682828499, 0.042392807445139624, 0.02310037802089937, 0.01040453100358718, 0.03882376360706985, 0.03934634318284225, 0.08990909074782394, 0.04376685305032879, 0.1335469659534283, 5.647286418825388, 39.942240715026855, 53.10706749558449, 55.6352162361145, 32.109827399253845, 31.076723635196686, 54.49542559683323, 46.64238698780537, 9.824637863785028, 0.2748102491023019, 0.8123947447165847, 2.5832780823111534, 4.228755561634898, 5.90383012779057, 2.8553950181230903, 8.272351808845997, 8.473668806254864, 5.540450401604176, 13.727095909416676, 33.102980107069016, 42.8454103320837, 54.39793422818184, 53.99587780237198, 52.814847975969315, 48.21614474058151, 48.59812304377556, 46.44583873450756, 47.09562286734581, 45.21952673792839, 42.57408209145069, 38.89218986034393, 40.6250336766243, 39.56812798976898, 38.67295302450657, 37.53259241580963, 38.080864995718, 39.62447516620159, 41.37833945453167, 42.66137860715389, 43.35791923105717, 44.840120896697044, 43.95449101924896, 45.69949798285961, 47.39275932312012, 48.37209217250347, 49.719290882349014, 48.84759105741978, 41.16430073976517, 35.930286794900894, 40.398242846131325, 42.91423223912716, 49.0387511998415, 51.2523490190506, 49.014865681529045, 47.907449305057526, 43.99043329060078, 42.01838470995426, 39.17418032884598, 38.694216683506966, 37.236056327819824, 38.54455031454563, 37.97575883567333, 40.73072500526905, 46.41815721988678, 49.121841341257095, 48.40219795703888, 56.07507683336735, 38.978988602757454, 37.07588732242584, 53.2477131485939, 50.39639174938202, 53.47034700214863, 50.7293488830328, 51.59326672554016, 48.2440048456192, 49.48998838663101, 52.569992914795876, 46.989270374178886, 39.66980293393135, 38.590626642107964, 37.794223576784134, 41.88889905810356, 39.27180469036102, 44.03992183506489, 52.96722739934921, 54.37667056918144, 55.11205270886421, 54.96027745306492, 52.065976560115814, 53.69295805692673, 51.774387806653976, 50.9854057431221, 48.67063835263252, 49.868018701672554, 50.71659676730633, 50.03728821873665, 54.135117530822754, 52.29098528623581, 52.145057916641235, 53.34508292376995, 50.285509899258614, 47.38213129341602, 51.76067814230919, 53.8744705170393, 50.278419479727745, 49.05498392879963, 43.56628865003586, 41.70650504529476, 41.57451152801514, 42.09037944674492, 48.619884476065636, 50.26519238948822, 56.6303638368845, 55.93647927045822, 54.42349545657635, 44.02544841170311, 34.25400674343109, 18.802270777523518, 12.503932993859053, 16.682702712714672, 10.771751292049885, 14.270435404032469, 5.167022114619613, 10.199301559478045, 7.117993226274848, 0.11506867624120787, 0.08007800890482031, 4.047221727669239, 26.033035777509212, 36.88738323748112, 36.758676543831825, 33.68407532572746, 45.368463546037674, 52.89215862751007, 56.49313040077686, 18.886785842478275, 0.6011862249579281, 0.0465308633283712, 0.05930549952608999, 0.04230379425280262, 0.07373002648819238, 0.04092941839189734, 0.05818273399199825, 0.021315321755537298, 0.048590942824375816, 0.03942115537938662, 0.041891082219081, 0.03385686606634408, 0.04878694031503983, 0.004878225272477721, 0.058481181258684956, 0.02178472830564715, 0.08738371063373052, 0.03193271091731731, 0.02316838101251051, 0.09320395925897174, 0.20617479924112558, 0.12196668656542897, 0.22151433862745762, 0.15846295631490648, 0.1330351215437986, 0.09851597773376852, 0.23256172629771754, 0.11850014445371926, 0.20925382152199745, 0.12345772061962634, 0.25421205908060074, 0.13653740548761562, 0.232993908575736, 0.22059735580114648, 0.1739623988396488, 0.10730748879723251, 0.2086170291295275, 0.12974901037523523, 0.20591207896359265, 0.28272308700252324, 7.9186610877513885, 48.731036111712456, 59.157520830631256, 63.287492617964745, 36.184447556734085, 40.23004487156868, 64.30937558412552, 49.621921107172966, 11.142939124256372, 0.533888511126861, 1.6167294094339013, 7.058001095429063, 12.119724210351706, 8.70425183326006, 3.297630725428462, 10.601322837173939, 27.509400956332684, 11.001273225992918, 16.26388728618622, 37.03119792044163, 45.00989578664303, 57.336878925561905, 54.40993018448353, 56.04640357196331, 50.44176511466503, 51.23907633125782, 49.880539029836655, 50.496041402220726, 47.931365221738815, 45.41661836206913, 40.49742892384529, 42.845094949007034, 41.55206233263016, 39.50562134385109, 39.21920031309128, 40.31726539134979, 41.43380507826805, 43.36663976311684, 43.252683877944946, 45.574192106723785, 44.114025458693504, 46.58056050539017, 47.38165631890297, 49.65117193758488, 49.52787235379219, 52.28246994316578, 51.396957859396935, 42.41224877536297, 37.747619077563286, 42.322368398308754, 46.157552003860474, 53.75972807407379, 53.68500128388405, 50.67568436264992, 50.19594110548496, 46.90565586090088, 43.79942514002323, 43.083801940083504, 40.218094512820244, 39.16962057352066, 39.96630862355232, 40.29784083366394, 42.89937503635883, 48.511305302381516, 50.483460277318954, 52.12831601500511, 54.89254988729954, 40.519589334726334, 39.05168630182743, 52.58897289633751, 50.81438072025776, 54.79332201182842, 49.14866030216217, 52.30461895465851, 50.089421421289444, 53.12888592481613, 54.34786431491375, 50.277860909700394, 42.240596786141396, 40.71419969201088, 40.353462249040604, 43.07209096848965, 40.28375878930092, 47.42278531193733, 54.06123049557209, 56.93283140659332, 57.271416038274765, 59.326657354831696, 53.593072816729546, 56.53373882174492, 54.737370014190674, 54.505548253655434, 48.96150514483452, 51.500984877347946, 54.25750136375427, 51.82256542146206, 55.196039602160454, 54.2752730101347, 53.66444058716297, 55.31013987958431, 51.92039117217064, 47.23202794790268, 50.57729624211788, 55.634756460785866, 52.95991279184818, 51.416116431355476, 45.39806395769119, 43.36837626993656, 43.35166856646538, 44.3675896525383, 50.75604245066643, 53.44956211745739, 58.40879000723362, 57.729177474975586, 56.39644078910351, 43.518684804439545, 30.866612009704113, 23.893494084477425, 27.07596391439438, 26.71334747225046, 16.05710808187723, 17.097950130701065, 6.773128006607294, 9.907300528138876, 8.401207644492388, 0.2171792759327218, 0.1979282620595768, 4.507168047130108, 32.49773718416691, 51.08421564102173, 42.06513360142708, 38.03265318274498, 50.774323269724846, 59.34987410902977, 65.76111808419228, 25.020804293453693, 1.5214608027599752, 0.1742934263893403, 0.24607760104117915, 0.1594818805460818, 0.16000332834664732, 0.13509778742445633, 0.14856120717013255, 0.1775436769821681, 0.09590540648787282, 0.14143660431727767, 0.19459750328678638, 0.13116343994624913, 0.1504119750461541, 0.13404202298261225, 0.1905594629351981, 0.08696202232385986, 0.18855754926335067, 0.10845307537238114, 0.1664142671506852, 0.1987317853490822], [0.04734615336928982, 0.08195730493753217, 0.019810595076705795, 0.019185003548045643, 0.008115922901197337, 0.07271833077538759, 0.08370817973627709, 0.01014709945593495, 0.0707430750480853, 0.07195801532361656, 0.016905153715924826, 0.03276091803854797, 0.04440131138835568, 0.05105257616378367, 0.029359059662965592, 0.015685805083194282, 0.0277181525962078, 0.07200985433883034, 0.02477229016221827, 0.07093379215802997, 4.308398813009262, 39.80545185506344, 45.43887756764889, 34.956634640693665, 17.62176152318716, 38.650173246860504, 54.84060287475586, 31.112950891256332, 5.557001363486052, 0.6822136708069593, 1.5141115221194923, 9.579798001796007, 42.41341531276703, 36.874414533376694, 4.377053529024124, 4.277372052893043, 8.767279051244259, 7.027911460027099, 15.400642957538366, 29.40113514661789, 44.990813210606575, 46.22598633170128, 50.93976639211178, 50.37242263555527, 50.72691321372986, 49.461915493011475, 48.67495872080326, 49.77087311446667, 46.94140434265137, 44.584117233753204, 37.34818831086159, 34.725869223475456, 36.57147578895092, 36.346603855490685, 35.4808659106493, 34.009964838624, 34.308583214879036, 33.73393625020981, 33.798323795199394, 34.619030356407166, 35.620276629924774, 34.11778785288334, 34.93928097188473, 37.544516175985336, 36.818093955516815, 37.26080060005188, 35.891631469130516, 34.82902228832245, 35.28885841369629, 38.93178753554821, 47.88720399141312, 48.81788045167923, 48.84135939180851, 44.40621837973595, 46.828269213438034, 40.597804337739944, 41.91086947917938, 36.18032097816467, 34.80641350150108, 36.72401860356331, 36.57181777060032, 38.501669615507126, 44.89237569272518, 45.72153680026531, 48.80262807011604, 46.647041738033295, 54.2624107003212, 35.11846035718918, 34.2879731208086, 50.03563150763512, 46.403353214263916, 49.668544605374336, 49.46404717862606, 50.935613214969635, 50.12855552136898, 48.96071098744869, 47.88681261241436, 44.25895728170872, 38.70630003511906, 37.52821505069733, 35.62097579240799, 37.07416221499443, 37.369379773736, 35.42433254420757, 41.696758568286896, 41.06191523373127, 44.42220792174339, 44.384795129299164, 45.72263494133949, 44.44684199988842, 44.67173293232918, 43.26169319450855, 40.593654960393906, 42.12496139109135, 46.93271420896053, 45.59811942279339, 46.919851899147034, 47.73242309689522, 47.21217401325703, 48.852321803569794, 51.228094920516014, 49.06845040619373, 49.501387774944305, 52.525314912199974, 50.69148011505604, 46.331483870744705, 41.36285148561001, 38.3709642291069, 43.131626173853874, 48.929396867752075, 48.71652469038963, 46.103176921606064, 50.967751890420914, 53.359373956918716, 52.84379102289677, 43.62019635736942, 35.69488562643528, 17.645270861685276, 10.69397421553731, 11.525382902473211, 6.7914544232189655, 12.166031375527382, 12.883784361183643, 2.8909492352977395, 5.817849766463041, 0.3914973564678803, 0.05924341516220011, 2.6031493535265326, 26.777106150984764, 42.483684942126274, 20.986606366932392, 21.429757587611675, 34.773864448070526, 44.66711238026619, 48.916036784648895, 15.456763096153736, 0.44573837716598064, 0.0427836187009234, 0.04490259874728508, 0.010791686254378874, 0.0243443622457562, 0.08213826280552894, 0.032135243018274195, 0.05450867254694458, 0.03202932741260156, 0.041120113237411715, 0.056793923358782195, 0.008713694096513791, 0.07995772160938941, 0.03827738335530739, 0.03681430971482769, 0.009394782500748988, 0.08864458985044621, 0.025372756281285547, 0.023396036667691078, 0.010439613251946867, 0.0906094406673219, 0.0377993326401338, 0.05284986487822607, 0.009662191296229139, 0.07848899651435204, 0.046914702106732875, 0.17126777936937287, 0.025122826918959618, 0.03858069540001452, 0.017628966634219978, 0.04377064913569484, 0.03283413090684917, 0.012044965878885705, 0.05373645675717853, 0.08929399875341915, 0.05488217320817057, 0.10385220506577753, 0.031264072968042456, 0.06960463535506278, 0.09096429115743376, 5.700303073972464, 46.22211813926697, 50.60751222074032, 42.226480543613434, 22.53453690558672, 38.233050629496574, 60.653572753071785, 38.93062099814415, 7.843939997255802, 0.6873727252241224, 2.35695771407336, 13.500896897166967, 46.554961279034615, 41.38843551278114, 7.830185210332274, 7.202765252441168, 9.76716784760356, 4.962196480482817, 14.23909468576312, 29.406356066465378, 48.01742300391197, 49.79130081832409, 53.30313317477703, 52.7944278717041, 54.030626937747, 50.722030475735664, 51.287668123841286, 51.41315259039402, 48.980572521686554, 45.66499203443527, 39.23091508448124, 36.849959045648575, 37.869068160653114, 37.21738412976265, 37.46488764882088, 36.75975948572159, 36.31146714091301, 36.03176034986973, 35.66015928983688, 36.76392786204815, 37.492721155285835, 36.636095121502876, 36.64139203727245, 38.75686392188072, 39.691020995378494, 39.89426448941231, 38.29419694840908, 35.59383764863014, 36.46050274372101, 40.611791387200356, 50.152304247021675, 51.54080294072628, 49.776815995574, 46.99701435863972, 47.90814846754074, 44.129650220274925, 42.99973525106907, 38.61201569437981, 38.464040234684944, 37.21469007432461, 38.761214688420296, 40.89424543082714, 47.027146741747856, 48.43909777700901, 50.58875262737274, 49.7145639359951, 54.514758959412575, 37.36379787325859, 37.282584831118584, 49.45624239742756, 48.02651971578598, 50.217459350824356, 50.153368189930916, 51.62968397140503, 52.37302288413048, 50.533685982227325, 49.304911717772484, 45.59276930987835, 40.24066150188446, 38.54811072349548, 36.07068546116352, 38.48058074712753, 38.54074291884899, 38.99948090314865, 45.49569211900234, 44.609971046447754, 46.21152050793171, 47.51086838543415, 48.942962139844894, 46.69119156897068, 47.19480514526367, 45.02601832151413, 42.773347198963165, 43.60540375113487, 48.62509399652481, 47.582243755459785, 50.11180602014065, 50.573808029294014, 48.772856667637825, 51.97980858385563, 52.3404548317194, 48.46092380583286, 50.509006306529045, 54.09234322607517, 52.5243915617466, 48.606866374611855, 42.66878820955753, 40.0351495295763, 44.06012915074825, 49.1870192438364, 49.84985187649727, 51.502732783555984, 53.01135063171387, 57.062575444579124, 55.80145351588726, 45.11649526655674, 34.528819397091866, 22.760163098573685, 14.14527676999569, 17.163361720740795, 8.603594284504652, 13.285158723592758, 8.911547809839249, 6.61469598300755, 8.472616262733936, 0.32938306918367743, 0.10312730490113609, 2.8277334524318576, 26.818269342184067, 45.53386107087135, 26.305266469717026, 23.68628930300474, 40.19065618515015, 49.89913523197174, 56.08079552650452, 19.04829427599907, 0.6886260048486292, 0.04983675644325558, 0.06606079114135355, 0.01964237802894786, 0.06123185143223964, 0.04057101301441435, 0.06804821066907607, 0.05235055163211655, 0.01426331393304281, 0.030108992468740325, 0.038623873551841825, 0.03052160987863317, 0.03160238098644186, 0.026203737179457676, 0.047756883868714795, 0.023554526014777366, 0.03537760458129924, 0.02606697606097441, 0.05682468166924082, 0.021543947768805083, 0.21011738455854356, 0.18080351612297818, 0.09488412964856252, 0.10970183531753719, 0.1878671144368127, 0.1282131060725078, 0.20797924225917086, 0.05867795058293268, 0.26513400895055383, 0.14617630076827481, 0.1169516533263959, 0.07859801800805144, 0.10423219209769741, 0.16549103544093668, 0.22403363313060254, 0.21038322185631841, 0.15944196784403175, 0.23723172023892403, 0.20955473271897063, 0.2526438713539392, 8.155339937657118, 54.04413901269436, 58.16027194261551, 48.53568099439144, 27.23990611732006, 50.45138239860535, 62.50627353787422, 40.84382973611355, 8.856702502816916, 1.1376734403893352, 2.4802689347416162, 13.847333807498217, 50.374478325247765, 52.93682903051376, 12.161084990948439, 13.5140441916883, 14.02700811624527, 11.61479115486145, 18.547218963503838, 34.30363208055496, 49.30803894996643, 50.211524069309235, 54.16421256959438, 54.0204206854105, 54.985185116529465, 53.36801089346409, 55.199341624975204, 54.02499943971634, 51.98112331330776, 48.07787016034126, 42.889841347932816, 38.6692064255476, 40.171961188316345, 39.66780424118042, 38.9310047775507, 37.73261368274689, 38.095049634575844, 38.88121224939823, 37.42286570370197, 39.149576649069786, 39.55717317759991, 38.09219218790531, 39.01017352938652, 41.0851775854826, 40.45146279036999, 41.47572822868824, 40.2989237755537, 37.497539296746254, 38.741379752755165, 42.362148463726044, 53.52746933698654, 52.54238739609718, 50.93578800559044, 49.13655415177345, 51.44902266561985, 45.74853055179119, 45.3779174387455, 40.26008605957031, 40.01504860818386, 40.434413105249405, 40.39391487836838, 42.76503324508667, 49.16918680071831, 50.07397145032883, 51.7432826757431, 51.39743663370609, 54.53929424285889, 38.281733617186546, 39.93277922272682, 49.606588929891586, 48.268669322133064, 50.628236308693886, 52.960566356778145, 53.99361312389374, 53.69034759700298, 53.166275918483734, 51.40581898391247, 48.085914328694344, 42.27004900574684, 40.71792349219322, 38.31416107714176, 41.445462852716446, 39.47376385331154, 39.37408000230789, 46.32210597395897, 45.345269590616226, 48.77896673977375, 49.129395335912704, 51.15673094987869, 47.71929860115051, 47.96061985194683, 45.41857145726681, 44.69504848122597, 46.50767281651497, 53.10222655534744, 49.41815324127674, 52.360475957393646, 52.21038781106472, 51.31127245724201, 53.54575015604496, 53.42181980609894, 49.055451303720474, 50.69237306714058, 56.94962650537491, 54.79463294148445, 51.50245539844036, 45.57364873588085, 43.00651028752327, 47.70576372742653, 53.85186553001404, 53.38510997593403, 52.11408577859402, 56.73980936408043, 60.13724885880947, 55.4200641810894, 46.36388473212719, 36.00159376859665, 21.960587203502655, 15.383510626852512, 20.505884662270546, 17.965397983789444, 23.03170032799244, 20.613443590700626, 4.505389742553234, 8.270143177360296, 0.5808934732340276, 0.12924304377520457, 3.6353547032922506, 34.69430431723595, 54.89335544407368, 31.13873440772295, 31.141270771622658, 48.69715712964535, 57.026963755488396, 63.216626420617104, 25.856183767318726, 0.8784882794134319, 0.1113861394696869, 0.18554931302787736, 0.1561663209577091, 0.13418785500107333, 0.15930904919514433, 0.15328493260312825, 0.18227687221951783, 0.05672665880410932, 0.09973313703085296, 0.13820391293847933, 0.10673311844584532, 0.15697492053732276, 0.1793344199541025, 0.14371838187798858, 0.14280022645834833, 0.1583618758013472, 0.11736566040781327, 0.19680981582496315, 0.15453617874300107], [0.02223253650299739, 0.00968676844422589, 0.050303125753998756, 0.015024773219920462, 0.028386527083057445, 0.042160426164628007, 0.04176044567429926, 0.04664107967983, 0.01934917218022747, 0.020552431051328313, 0.03195281940861605, 0.056661873022676446, 0.02879892741475487, 0.07252158000483178, 0.025992280752689112, 0.04572413396090269, 0.046957872837083414, 0.02483156178641366, 0.038276273844530806, 0.028735700143442955, 5.501516740769148, 36.463922560214996, 44.40356232225895, 29.74247843027115, 25.183110684156418, 36.39491446316242, 30.56937675923109, 28.729283697903156, 7.60357772000134, 0.15005215216660872, 0.2381955028977245, 1.8396875518374145, 12.152769137173891, 45.275619328022, 8.094300962984562, 6.559150563552976, 6.287109861150384, 3.6775293527171016, 16.796812489628792, 30.766599476337433, 45.50988435745239, 51.33051082491875, 52.11074195802212, 50.55954359471798, 52.786216512322426, 50.460771694779396, 50.76363064348698, 49.95395869016647, 49.54351991415024, 46.05773515999317, 37.744693234562874, 34.87010568380356, 35.5203115940094, 36.6241941601038, 37.50470571219921, 37.24464766681194, 37.11659073829651, 34.99519117176533, 34.31849308311939, 34.50448550283909, 35.314408242702484, 34.54376399517059, 32.858835607767105, 35.45967824757099, 36.759713888168335, 34.48127254843712, 35.35649098455906, 34.93448182940483, 36.373092234134674, 46.34231708943844, 51.420292407274246, 50.80059885978699, 46.53666906058788, 46.73866622149944, 44.90245655179024, 40.339699387550354, 38.2497925311327, 35.518377497792244, 36.012369990348816, 35.260401740670204, 39.62492734193802, 46.03554055094719, 49.86596681177616, 47.622992768883705, 51.84481702744961, 45.36791257560253, 50.22314004600048, 37.265417352318764, 34.11034405231476, 50.20525060594082, 45.493834018707275, 50.13428941369057, 49.034134447574615, 48.380558118224144, 48.11511196196079, 47.52061486244202, 43.96226540207863, 40.72616524994373, 37.175172194838524, 35.49062758684158, 35.99392578005791, 37.61885158717632, 36.932281628251076, 37.1947031468153, 36.179397627711296, 36.1600186675787, 35.85524842143059, 35.00489965081215, 37.38088175654411, 37.118749022483826, 37.12389774620533, 36.41457460820675, 35.20952247083187, 37.83384025096893, 39.93360377848148, 42.15640090405941, 43.40437933802605, 43.21440473198891, 46.84303522109985, 48.446484580636024, 51.732685044407845, 50.90821288526058, 48.717581033706665, 51.97313994169235, 50.29776804149151, 47.48983271420002, 39.710529148578644, 39.576286152005196, 51.9525982439518, 53.406749814748764, 54.1085759550333, 54.262965470552444, 52.68045298755169, 53.1391491740942, 51.88514046370983, 42.608052268624306, 38.85750912129879, 25.2296144887805, 14.618274439126253, 22.654515467584133, 11.178542263805866, 13.296523913741112, 4.578604688867927, 4.47070425376296, 4.328309744596481, 0.2839012909680605, 0.058354314824100584, 1.690186474006623, 19.21955868601799, 37.55051225423813, 36.20965160429478, 37.91906587779522, 41.47873766720295, 47.99259513616562, 44.8457407951355, 17.26206712424755, 0.4741927346913144, 0.09415404929313809, 0.02926258046500152, 0.052502554608508945, 0.03048272690648446, 0.022543167979165446, 0.073449079063721, 0.01443547364033293, 0.03438244391873013, 0.09905416096444242, 0.09441558955586515, 0.04263542665285058, 0.08870900826877914, 0.0785931569407694, 0.05038974923081696, 0.03355765809828881, 0.029493894908227958, 0.0219699832086917, 0.01899457030958729, 0.046016358319320716, 0.013837544738635188, 0.057694278366398066, 0.024356579851882998, 0.008496041664329823, 0.04889407675364055, 0.11268564005149528, 0.03721847591805272, 0.05299674332491122, 0.020071923827345017, 0.05251737900834996, 0.06651973526459187, 0.06951414528884925, 0.026241093182761688, 0.027601204965321813, 0.0649755857011769, 0.04006863840913866, 0.012964735469722655, 0.05783793589216657, 0.01444905587050016, 0.03884538607962895, 7.07803457044065, 44.50557544827461, 50.823192447423935, 36.288018599152565, 25.714263282716274, 45.14542691409588, 40.498599261045456, 32.14843712747097, 7.508938098326325, 0.2624084270792082, 0.2597410592716187, 0.5250576068647206, 18.99391159415245, 49.55026835203171, 7.550024343654513, 6.545701185241342, 6.898255292326212, 6.6794169601053, 16.897738873958588, 31.67756639420986, 47.11371749639511, 51.75567001104355, 52.25978896021843, 51.43271394073963, 54.58150617778301, 51.373984292149544, 52.13607519865036, 52.04220503568649, 52.460342198610306, 48.66400010883808, 40.60156233608723, 36.11718736588955, 37.75658659636974, 37.55334310233593, 38.287288919091225, 37.0587882399559, 37.25170008838177, 35.413700714707375, 35.267701148986816, 36.78234547376633, 37.73626148700714, 35.64323119819164, 35.63089706003666, 36.21526390314102, 37.68065147101879, 37.179237976670265, 37.507794946432114, 35.6768973916769, 37.84807048738003, 48.60257640480995, 52.34473340213299, 50.55396929383278, 48.96967850625515, 49.33203466236591, 46.948502361774445, 43.35975833237171, 40.7718425989151, 36.817432790994644, 37.2344908118248, 36.495837047696114, 42.110005393624306, 47.785080671310425, 51.464324444532394, 49.96618263423443, 53.03896754980087, 47.17889539897442, 49.59985189139843, 38.42622086405754, 35.161660239100456, 51.008185520768166, 46.19245693087578, 50.563020408153534, 50.343376994132996, 50.873991921544075, 49.46817755699158, 50.04478141665459, 46.57417684793472, 42.0870166271925, 39.651499316096306, 36.45229898393154, 36.58072829246521, 39.382580146193504, 37.77110181748867, 38.26181888580322, 38.18716809153557, 37.07935653626919, 37.85303682088852, 38.07858131825924, 39.64869126677513, 40.15738897025585, 38.27248491346836, 38.51084232330322, 37.77231775224209, 40.29518097639084, 43.35655890405178, 44.876427948474884, 46.71409673988819, 46.34727582335472, 48.75025928020477, 51.12994998693466, 52.7840506285429, 51.927641183137894, 49.468766525387764, 53.0908689647913, 52.73073948919773, 50.32003104686737, 41.390555799007416, 41.53684414923191, 53.202199190855026, 55.70303499698639, 55.472417771816254, 55.82302875816822, 54.07176733016968, 56.010039523243904, 53.64362150430679, 43.738244622945786, 37.024601474404335, 23.942716643214226, 13.34954721853137, 11.45395053550601, 11.327685210853815, 8.706683702766895, 7.880337294191122, 4.980795532464981, 4.25726780667901, 0.564640142256394, 0.04890340183919761, 2.1336541464552283, 21.865233220160007, 39.54879842698574, 35.51818370819092, 41.331001594662666, 47.967999055981636, 53.35905857384205, 51.24748907983303, 21.45472414791584, 0.5927173106465489, 0.023613888552063145, 0.04462684264581185, 0.08610194738139398, 0.002648808085723431, 0.008574348448746605, 0.05948219004494604, 0.018609672115417197, 0.02313674511242425, 0.13172603241400793, 0.017230800694960635, 0.055689748623990454, 0.020870688094873913, 0.0439599747187458, 0.055262598107219674, 0.007573331777166459, 0.031444793348782696, 0.03943299634556752, 0.02728689243667759, 0.04183489421848208, 0.15838096383959055, 0.1277461022255011, 0.1901762475608848, 0.24233196687418967, 0.15975662361597642, 0.16550633852602914, 0.16309110797010362, 0.10887803655350581, 0.1259746847790666, 0.15665380808059126, 0.13111954933265224, 0.18610455823363736, 0.09385970610310324, 0.12814999383408576, 0.1859857700765133, 0.1311176791205071, 0.10978275167872198, 0.20043710712343454, 0.13954577530967072, 0.16211950307479128, 9.824650213122368, 51.768992096185684, 57.40808330476284, 41.852637603878975, 34.60131570696831, 45.73848769068718, 39.327631294727325, 39.59917992353439, 10.119778476655483, 0.5259580397978425, 0.6060374958906323, 3.0565495742484927, 14.626167565584183, 49.421029686927795, 15.061975680291653, 17.31488808989525, 15.229500140994787, 7.539895037189126, 18.68600271642208, 35.36271505057812, 49.14324939250946, 53.234337866306305, 53.468371108174324, 52.28508040308952, 56.54403246939182, 52.587031200528145, 53.97497892379761, 54.617361053824425, 55.492305904626846, 51.02544039487839, 41.77387923002243, 37.56848528981209, 39.884521812200546, 39.85571935772896, 41.904937997460365, 39.853906854987144, 40.45094981789589, 37.49265655875206, 37.080785259604454, 39.50415842235088, 39.85117480158806, 37.938194051384926, 37.42856539785862, 38.77395540475845, 39.68520350754261, 38.65058742463589, 38.5940046608448, 39.03086721897125, 39.44132499396801, 50.69041237235069, 54.75432090461254, 52.03584037721157, 52.43244789540768, 51.66366174817085, 49.8864971101284, 45.74505373835564, 41.836336478590965, 38.94719570875168, 39.162739142775536, 39.28089380264282, 43.45831744372845, 50.325882732868195, 54.61465559899807, 51.16618864238262, 54.36338648200035, 48.450584560632706, 49.217223823070526, 39.77424792945385, 39.15483936667442, 50.57690866291523, 47.36530959606171, 51.640406996011734, 53.08983542025089, 52.49788038432598, 51.781349033117294, 52.05012381076813, 48.54261562228203, 45.95457449555397, 42.28625513613224, 38.82295377552509, 40.04071243107319, 41.93108059465885, 40.286361649632454, 41.28519885241985, 40.6284648925066, 40.39224296808243, 39.76725250482559, 39.64070409536362, 41.03503927588463, 41.8480284512043, 39.91887576878071, 39.617867320775986, 37.86312147974968, 42.76123724877834, 44.1450621932745, 46.49210885167122, 46.951314210891724, 48.13088871538639, 53.12503673136234, 53.705030009150505, 55.171207934617996, 54.749795347452164, 50.345922857522964, 54.13786858320236, 54.66697119176388, 52.758903577923775, 43.90887066721916, 43.96025151014328, 57.77269273996353, 58.77054959535599, 57.08984658122063, 58.76349717378616, 57.96707510948181, 58.424821346998215, 53.801415637135506, 45.98567582666874, 41.626158356666565, 27.748185843229294, 19.06754594296217, 31.69255468994379, 24.076060988008976, 19.221563078463078, 13.27421436086297, 10.680809821933508, 6.951237749308348, 0.5927918222732842, 0.09488608891842887, 2.499932167120278, 25.76078798621893, 48.92123110592365, 46.820209845900536, 49.21776719391346, 54.7698924690485, 60.532997623085976, 58.78037966787815, 26.72853335738182, 1.5829455410130322, 0.16400185675593093, 0.15254922676831484, 0.20949412893969566, 0.15361005265731364, 0.09775376980542205, 0.13584967207862064, 0.12322037437115796, 0.13262961205327883, 0.15179520472884178, 0.196699324878864, 0.15269014576915652, 0.12277498928597197, 0.15243371890392154, 0.16850302694365382, 0.11779632128309458, 0.0669995931093581, 0.11540279854671098, 0.13093852467136458, 0.17750296276062727], [0.10624460715916939, 0.0743165606399998, 0.0539087389188353, 0.04951654569595121, 0.056090174402925186, 0.03184953471645713, 0.02440124600980198, 0.05257375254586805, 0.04410473062307574, 0.06497062073322013, 0.047126588979153894, 0.036019862891407683, 0.01580836335051572, 0.002642606050358154, 0.06236584566067904, 0.06375543554895557, 0.06668002431979403, 0.03182361520885024, 0.024093761239782907, 0.2941521315369755, 9.178933762013912, 29.370672181248665, 36.737838461995125, 31.542533040046692, 26.804899759590626, 17.48225010931492, 31.353272795677185, 31.93744584918022, 7.733827130869031, 0.07387612567981705, 0.2421130778384395, 1.3912835880182683, 4.134195260703564, 5.162399662658572, 5.832327464595437, 4.69567640684545, 3.6114767845720053, 3.5648549487814307, 13.351516462862492, 27.972018532454967, 48.92794154584408, 50.42006067931652, 51.43296092748642, 49.648956656455994, 51.35361738502979, 51.28498926758766, 50.416222885251045, 52.09865480661392, 49.76737730205059, 45.58588407933712, 38.35214003920555, 34.22573246061802, 39.0815033018589, 43.638746961951256, 48.00759673118591, 46.39954201877117, 44.62774649262428, 42.615264281630516, 38.45886871218681, 36.973004043102264, 38.94310712814331, 39.00008127093315, 37.67556734383106, 37.57033199071884, 38.32872949540615, 34.757065549492836, 36.61423869431019, 33.945379704236984, 41.94470286369324, 47.98429638147354, 52.27443337440491, 46.320525258779526, 48.49452160298824, 44.81021650135517, 41.29322022199631, 37.013255283236504, 36.33279159665108, 35.33271186053753, 36.200311705470085, 36.44601412117481, 45.15684150159359, 48.029061779379845, 51.471141278743744, 49.12319786846638, 49.74495850503445, 44.92068037390709, 50.798136591911316, 38.74559372663498, 33.09575669467449, 47.22435995936394, 44.9815759062767, 46.94664426147938, 45.790750086307526, 45.66699452698231, 44.87149961292744, 44.53391432762146, 39.27199088037014, 39.99052092432976, 35.74824996292591, 35.31516820192337, 36.77289918065071, 36.97167791426182, 41.3300022482872, 38.55399660766125, 36.93932645022869, 36.75796218216419, 36.11996881663799, 34.73460115492344, 35.04251763224602, 34.389541670680046, 36.79122939705849, 35.76013572514057, 36.12334683537483, 37.90993116796017, 42.76892423629761, 40.65787151455879, 38.865215107798576, 39.06388744711876, 40.91829814016819, 43.601683750748634, 51.28951482474804, 50.56686580181122, 48.32902908325195, 49.51859325170517, 52.17509910464287, 48.68445821106434, 39.27869372069836, 42.439223527908325, 55.04349298775196, 53.585294634103775, 54.75844748318195, 53.78972366452217, 55.18286190927029, 53.244490921497345, 50.93033529818058, 45.75910158455372, 38.58776159584522, 27.203061394393444, 18.76905295997858, 17.054868042469025, 6.620856877416372, 6.140753589570522, 4.621507711708546, 5.999584514647722, 1.6882317163981497, 0.6673402595333755, 0.006854653129266808, 1.1666536540724337, 19.811939299106598, 39.39898006618023, 31.317134834825993, 19.759198129177094, 28.232152573764324, 50.42380727827549, 45.07212124764919, 17.717848867177963, 1.2977466196753085, 0.03748794973944314, 0.01939233363373205, 0.04486867146624718, 0.018948481083498336, 0.028969573140784632, 0.03313373963464983, 0.023786866477166768, 0.05423805952887051, 0.09129229074460454, 0.028793821438739542, 0.01741861786285881, 0.03874846901453566, 0.00616383795204456, 0.003140713538414275, 0.05463686371513177, 0.01045158131091739, 0.05062340329459403, 0.039995763218030334, 0.06782125448808074, 0.05065103716333397, 0.04345648689195514, 0.047596190343028866, 0.010808663810166763, 0.024312121495313477, 0.013144552285666578, 0.021318872932170052, 0.054349990241462365, 0.03819933168415446, 0.07914996065665036, 0.07851409594877623, 0.09791648568352684, 0.013973200984764844, 0.021088488028908614, 0.044066892223781906, 0.051618233701447025, 0.02933312160166679, 0.08386598259676248, 0.06119268087786622, 0.3474321303656325, 11.302363369613886, 37.352645471692085, 44.23083879053593, 37.49789647758007, 33.23602616786957, 23.2914087921381, 36.381531581282616, 36.0545439273119, 9.087875448167324, 0.05896683156606741, 0.6397362251300365, 3.1209542183205485, 2.9203929053619504, 11.011998150497675, 6.795330215245485, 6.655575139448047, 8.76480158418417, 8.693045284599066, 18.836999014019966, 32.04141207039356, 48.3845479041338, 51.07454136013985, 50.35060040652752, 49.245023131370544, 51.446419805288315, 50.86587555706501, 52.24680505692959, 53.187721967697144, 50.37895068526268, 47.94724836945534, 41.05919077992439, 34.75572042167187, 40.82637347280979, 45.92193804681301, 49.411913976073265, 47.0920966565609, 45.00396050512791, 43.07962976396084, 39.56107936799526, 38.468535393476486, 38.66373851895332, 39.13874723017216, 39.02128793299198, 39.07977819442749, 39.41352188587189, 35.799490213394165, 37.12740495800972, 35.60627818107605, 42.80952885746956, 51.14557094871998, 53.50083276629448, 49.38664153218269, 50.04970595240593, 47.57525593042374, 42.41973057389259, 39.122890681028366, 37.91915327310562, 37.94110469520092, 38.71834918856621, 37.69083872437477, 48.18808324635029, 50.0584302842617, 52.573997899889946, 51.076992228627205, 50.91807335615158, 45.68085998296738, 50.04207596182823, 40.37560746073723, 34.50110748410225, 46.92183159291744, 45.982556194067, 49.1507425904274, 48.55117276310921, 48.96608009934425, 47.64368645846844, 45.786520913243294, 42.51275718212128, 42.61898048222065, 37.106460481882095, 37.10787780582905, 36.8278594315052, 40.578691363334656, 42.98360891640186, 39.64959941804409, 38.88413429260254, 37.15693697333336, 37.353272438049316, 36.336887776851654, 36.06590911746025, 35.75695909559727, 36.78450755774975, 37.38488294184208, 38.45804035663605, 40.04512779414654, 43.88054318726063, 43.127655386924744, 41.865560710430145, 41.458693742752075, 43.44186432659626, 46.8959853798151, 52.8670571744442, 53.25459457933903, 49.314730390906334, 49.57745209336281, 53.29410865902901, 50.968644842505455, 41.63371995091438, 44.187627509236336, 56.049982979893684, 56.16754487156868, 56.42758011817932, 55.82772150635719, 57.138749957084656, 53.810094371438026, 53.13921757042408, 47.02468827366829, 39.254451021552086, 28.554633669555187, 16.528909765183926, 13.82536243647337, 11.700972430408001, 12.728454396128654, 9.42299846559763, 4.94887107051909, 2.2951383562758565, 0.2716684708138928, 0.05065810983069241, 1.643342706374824, 20.885111913084984, 42.90010839700699, 33.57388883829117, 24.87227786332369, 34.54178810119629, 56.93902127444744, 52.13165603578091, 22.035038508474827, 1.7180184368044138, 0.02791916143905837, 0.04833346582017839, 0.03609517232689541, 0.08327809031470679, 0.030230482043407392, 0.03014496436662739, 0.02003256588068325, 0.039859089301899076, 0.068547876435332, 0.057253527993452735, 0.005933208140049828, 0.028025295978295617, 0.06315303427982144, 0.06262084760237485, 0.037558936164714396, 0.04673295756219886, 0.050578414302435704, 0.056180189494625665, 0.007883874659455614, 0.14110631891526282, 0.17661520570982248, 0.12965598958544433, 0.14044690586160868, 0.0988616627000738, 0.18408772739348933, 0.1892387814586982, 0.25021945300977677, 0.1041940828145016, 0.12385021283989772, 0.1265270949807018, 0.2078391841496341, 0.10205056736594997, 0.10082940047141165, 0.18275230686413124, 0.2167399096651934, 0.14113444631220773, 0.17135131551185623, 0.13788346841465682, 0.5312423687428236, 14.654353503137827, 46.46906688809395, 50.12392736971378, 44.26997289061546, 38.928257524967194, 26.976143270730972, 43.13354127109051, 39.888963773846626, 11.313266884535551, 0.23168520536273718, 0.8750857994891703, 3.604203974828124, 7.225968707352877, 9.815705493092537, 9.476446397602558, 14.381147213280201, 9.28834319114685, 9.509939700365067, 17.681190334260464, 32.38228037953377, 52.103852927684784, 52.64403574168682, 52.16703973710537, 49.76833865046501, 52.670288532972336, 51.79419234395027, 53.106489926576614, 56.69082999229431, 54.135083332657814, 51.11388444900513, 42.90051117539406, 37.52206318080425, 43.431202098727226, 48.71188893914223, 51.906153336167336, 51.73198588192463, 47.93889261782169, 48.31596538424492, 42.57963739335537, 41.1205080896616, 42.661466002464294, 41.920631155371666, 41.92261464893818, 41.489897668361664, 41.97179161012173, 37.12602563202381, 40.734870582818985, 36.90251022577286, 45.307134836912155, 53.599597066640854, 55.10640621185303, 50.72461813688278, 52.522742450237274, 48.87810342013836, 45.03270976245403, 41.95972725749016, 40.54521895945072, 39.23136346042156, 40.44819496572018, 41.4022021740675, 51.40564799308777, 52.271568328142166, 54.75030452013016, 54.1058287024498, 52.661275416612625, 46.54512740671635, 48.94474044442177, 42.675213664770126, 38.518099933862686, 46.857151463627815, 46.94043919444084, 49.955744594335556, 50.355270355939865, 50.56672900915146, 50.37962704896927, 47.32776001095772, 43.58842246234417, 44.84320253133774, 39.12956312298775, 39.02614787220955, 40.16661487519741, 42.5149230659008, 45.452758222818375, 43.28768379986286, 40.403980538249016, 40.061915293335915, 40.38656987249851, 38.763855546712875, 38.40309150516987, 37.591147273778915, 40.263870656490326, 39.48492385447025, 41.321061328053474, 41.78285054862499, 47.977525144815445, 45.37032924592495, 43.42713251709938, 43.179382011294365, 46.88091158866882, 48.34300093352795, 57.04201474785805, 54.88399654626846, 49.91588853299618, 50.17147421836853, 56.253541857004166, 53.608507588505745, 43.952245339751244, 46.387188881635666, 59.02795158326626, 58.79085570573807, 58.508945032954216, 57.310956716537476, 58.61685164272785, 54.768163561820984, 54.113371297717094, 49.49880391359329, 42.79821686446667, 28.26375737786293, 23.756169453263283, 23.376503325998783, 17.000295370817184, 21.395114846527576, 20.554314963519573, 13.040733989328146, 4.6961708553135395, 1.6970018832944334, 0.166111990401987, 2.013304391875863, 26.27560146152973, 51.29131592810154, 42.22469083964825, 31.29526700824499, 39.92375090718269, 63.12223568558693, 61.34722173213959, 27.280983813107014, 2.3534647515043616, 0.1613041796372272, 0.1652925554662943, 0.12507438543252647, 0.18243211467051879, 0.09776976308785379, 0.08479278403683566, 0.15776006825035438, 0.14918658533133566, 0.15941182180540636, 0.1578419716679491, 0.18451321549946442, 0.11460187277407385, 0.10317651671357453, 0.1275138248456642, 0.13459545734804124, 0.16965396440355107, 0.14696606463985518, 0.209096783073619, 0.11722615148755722], [0.05536137425224297, 0.01897787384223193, 0.06497687703813426, 0.03731981247256044, 0.047672501677880064, 0.038388976390706375, 0.023249570112966467, 0.016245438237092458, 0.040219357470050454, 0.023595984239364043, 0.023544091418443713, 0.04892377750365995, 0.029863916752219666, 0.10722669117967598, 0.06786023950553499, 0.06131614827609155, 0.023079816819517873, 0.041771329269977286, 0.03582849269150756, 0.08148053442710079, 11.143050268292427, 33.244222328066826, 47.90722891688347, 36.480934247374535, 24.75902684032917, 17.325320430099964, 31.38825371861458, 31.500338204205036, 6.743781231343746, 0.20549723325530067, 0.06582924106623977, 1.283486697357148, 4.221014901995659, 1.9313058606348932, 1.3002746715210378, 3.973293607123196, 6.1499647703021765, 10.656201392412186, 21.243578977882862, 33.25213350355625, 49.97829258441925, 48.63147385418415, 54.97554123401642, 49.763607904314995, 50.237602069973946, 49.76225137710571, 51.915147453546524, 48.06196041405201, 46.872510239481926, 42.46566250920296, 36.36672757565975, 34.78767290711403, 42.2716411203146, 49.40151013433933, 51.3907527923584, 48.03075648844242, 50.129383876919746, 48.3878081291914, 47.844129502773285, 47.24332474172115, 47.2933604568243, 46.629574075341225, 48.56095343828201, 47.06974245607853, 45.554896742105484, 43.05158346891403, 38.93891215324402, 37.002159878611565, 43.33449728786945, 48.758345246315, 50.75605005025864, 46.67179360985756, 50.88920630514622, 44.22685280442238, 39.538941755890846, 35.22235058248043, 35.496099293231964, 35.947249084711075, 36.67840585112572, 37.69427753984928, 47.49113604426384, 49.98839624226093, 49.48031410574913, 48.09463486075401, 50.64456783235073, 44.625561609864235, 49.554588720202446, 40.9409449249506, 31.93310648202896, 49.56990569829941, 45.14207549393177, 48.406799510121346, 46.99671797454357, 49.67068009078503, 48.265333101153374, 44.502148032188416, 41.4494564384222, 38.428538739681244, 36.668002009391785, 35.717623606324196, 39.963515773415565, 40.9102463722229, 45.32565124332905, 46.87410995364189, 46.44287109375, 46.06391362845898, 43.65849070250988, 42.80605964362621, 42.52974987030029, 36.36876046657562, 33.992706164717674, 36.0801849514246, 36.755442917346954, 37.72901147603989, 39.362627416849136, 38.65040883421898, 38.39461036026478, 38.203818798065186, 36.50279447436333, 40.37531867623329, 46.93043813109398, 52.81982570886612, 49.74090412259102, 48.742929473519325, 51.800473406910896, 47.59875766932964, 42.06642173230648, 39.20916885137558, 47.79599368572235, 51.39730744063854, 53.02263602614403, 51.54867611825466, 51.388374119997025, 52.250164076685905, 51.115031987428665, 48.376245349645615, 40.46917364001274, 36.37892112135887, 19.085710868239403, 6.218126937747002, 11.14825788885355, 9.108307901769876, 7.955475887283683, 1.2364648142829537, 0.7833399006631225, 0.4798728064633906, 0.01867634851805633, 1.2372804642654955, 14.497385825961828, 33.23122702538967, 32.92041890323162, 25.966484248638153, 41.5997763723135, 52.937645986676216, 36.67304813861847, 17.52721879631281, 2.277629845775664, 0.07484814617782831, 0.05303352416376583, 0.09609901797375642, 0.13344707287615165, 0.039684669754933566, 0.020974833678337745, 0.01822093330702046, 0.01145390091551235, 0.10327784955734387, 0.05422299764177296, 0.01996215090912301, 0.075230522925267, 0.04003069981990848, 0.037460827952600084, 0.03736529128218535, 0.06432168680476025, 0.01789969282981474, 0.0547390166320838, 0.012609191999217728, 0.050557700960780494, 0.03193258846295066, 0.0643384964496363, 0.028434968917281367, 0.06595484956051223, 0.039400642417604104, 0.05479221748828422, 0.0638758712739218, 0.10071614131447859, 0.048996081241057254, 0.00893586342499475, 0.009959523486031685, 0.018187108071288094, 0.02563577156251995, 0.0822957613854669, 0.03453140408964828, 0.06179150499519892, 0.03234679221350234, 0.04815867891011294, 0.08950888019171543, 13.568815402686596, 38.63592401146889, 54.45833578705788, 41.8760671466589, 29.964810200035572, 22.38005619496107, 35.562933906912804, 33.88624347746372, 8.400422986596823, 0.19787558441748843, 0.06335648664389737, 1.228950242511928, 7.2241248562932014, 4.169092588126659, 6.318743638694286, 6.847148034721613, 6.203746134415269, 17.279103510081768, 19.70488004386425, 32.639944553375244, 49.68599706888199, 51.57569266855717, 53.76109600067139, 52.175756469368935, 50.60114376246929, 50.811804458498955, 51.251839846372604, 51.60134129226208, 49.896669164299965, 45.44007830321789, 37.046142518520355, 37.23696827888489, 42.29111887514591, 51.70026898384094, 51.57322660088539, 49.64360274374485, 50.93115225434303, 50.7686235755682, 50.75950786471367, 49.3610917031765, 47.935146018862724, 49.37856316566467, 50.28732240200043, 49.65416617691517, 46.54981255531311, 43.763790652155876, 39.485269635915756, 38.90068620443344, 45.02358265221119, 51.62326231598854, 51.4584993571043, 47.33424626290798, 51.24132581055164, 47.08659455180168, 41.5900868922472, 37.41819195449352, 38.147881999611855, 37.50397615134716, 37.74997875094414, 39.87431176006794, 49.59950990974903, 52.53404304385185, 51.31941922008991, 49.32429827749729, 50.7182040810585, 45.871305763721466, 47.98669785261154, 41.03511527180672, 33.70351128280163, 49.437270015478134, 46.16480201482773, 50.276918560266495, 48.37952457368374, 50.78650541603565, 48.95414873957634, 46.90811812877655, 44.44156028330326, 41.4774951338768, 38.60722415149212, 37.631903886795044, 39.806709587574005, 42.09889478981495, 46.16689570248127, 48.4161052107811, 47.69382856786251, 47.24192261695862, 43.49888786673546, 43.396848142147064, 42.10601940751076, 37.279962971806526, 36.01574420928955, 38.06481085717678, 38.931825533509254, 40.141175240278244, 42.24441558122635, 40.95267489552498, 40.86772285401821, 40.040837824344635, 39.17850449681282, 43.795321360230446, 50.58953158557415, 52.84874975681305, 50.4406213760376, 50.76215252280235, 53.215034902095795, 50.58508962392807, 42.972171530127525, 41.071806102991104, 51.24178558588028, 54.1108026355505, 54.653858095407486, 53.05900767445564, 53.73743087053299, 53.44170793890953, 52.39907808601856, 49.84012059867382, 42.22446285188198, 34.80777382850647, 18.004511184990406, 11.919022779911757, 13.272748589515686, 6.7535315081477165, 10.118824727833271, 5.02953409217298, 1.9286965881474316, 0.692275530891493, 0.05771568190539256, 1.066509315278381, 16.952113956212997, 41.19573265314102, 39.93058294057846, 31.12037379294634, 43.97189408540726, 58.376594334840775, 45.684340596199036, 22.550285160541534, 3.0079124215990305, 0.026509424096730072, 0.04890717194939498, 0.024312737477885094, 0.029925507587904576, 0.032387962855864316, 0.023901940185169224, 0.024312570494657848, 0.03425995986617636, 0.05706916366762016, 0.025870318058878183, 0.009025137296703178, 0.08265625961939804, 0.0329290924128145, 0.01961003894393798, 0.09641027470934205, 0.036662254788097925, 0.05368986472603865, 0.012467747928894823, 0.045156123815104365, 0.13348213193239644, 0.09976890112739056, 0.14628778619226068, 0.09115845183259808, 0.12261288196896203, 0.08788311664829962, 0.16512506757862866, 0.15547815710306168, 0.16896810120670125, 0.1766882775700651, 0.09347225306555629, 0.15634210605639964, 0.08979734557215124, 0.21812961087562144, 0.11168908415129408, 0.12007997647742741, 0.20704317139461637, 0.11773855992942117, 0.14727179979672655, 0.20706095325294882, 16.41727175563574, 49.12299267947674, 61.3167929649353, 48.03714394569397, 35.0863216817379, 28.131746761500835, 41.68537437915802, 41.07071556150913, 10.029748007655144, 0.8211440127342939, 0.2486216090619564, 2.6895149191841483, 9.707282111048698, 6.8336340598762035, 4.8509555496275425, 9.443115536123514, 10.605614706873894, 17.30566218495369, 24.360359832644463, 37.754865288734436, 53.42510662972927, 50.23149959743023, 56.5375804156065, 52.18648709356785, 52.564076632261276, 51.255100071430206, 55.521511137485504, 51.81820325553417, 52.970411628484726, 47.16399259865284, 40.57896114885807, 39.52637203037739, 45.58429196476936, 52.39180527627468, 53.171215653419495, 49.65456135571003, 52.97397963702679, 52.53006085753441, 54.87243376672268, 52.70623840391636, 51.6237448900938, 51.086252331733704, 52.99137130379677, 51.27292111515999, 50.763243064284325, 46.523088589310646, 41.58542834222317, 40.74484124779701, 47.987909987568855, 53.819696456193924, 53.80885563790798, 49.056146666407585, 53.84408354759216, 48.26661743223667, 44.1962606459856, 39.087902158498764, 38.702431842684746, 39.32628236711025, 39.48985978960991, 42.628426775336266, 52.30966128408909, 56.107884272933006, 52.05734722316265, 50.05819849669933, 52.65094757080078, 46.79691329598427, 48.75065825879574, 43.00051800906658, 36.91165253520012, 50.06716601550579, 47.72552266716957, 52.14917689561844, 50.768148601055145, 54.883149191737175, 52.13644377887249, 49.81076717376709, 45.56748166680336, 42.277040630578995, 41.45250767469406, 38.82575422525406, 43.390331491827965, 45.871047377586365, 47.842662781476974, 50.59708558022976, 50.25858834385872, 49.12085339426994, 47.23713867366314, 46.272872015833855, 46.20258338749409, 39.50198493897915, 37.75652959942818, 39.77539926767349, 40.333688110113144, 42.22889341413975, 43.02983723580837, 42.06273972988129, 42.712797448039055, 41.79705798625946, 40.95084339380264, 45.426672622561455, 51.829800233244896, 57.06628404557705, 50.9493874758482, 50.69974847137928, 55.99342301487923, 52.02701725065708, 46.64255417883396, 43.388701379299164, 52.51467928290367, 56.042668372392654, 57.21705995500088, 55.30165493488312, 55.64814314246178, 55.75693890452385, 52.99058094620705, 49.92213159799576, 45.45177027583122, 41.69116146862507, 22.874384969472885, 14.5115970633924, 19.518178962171078, 14.427139945328236, 13.794547040015459, 9.884798135608435, 2.4757063295692205, 0.9725800179876387, 0.1258021206012927, 1.6003235522657633, 20.06298802793026, 47.806826904416084, 46.031695157289505, 37.5848738104105, 54.75647158920765, 63.41268450021744, 54.25024375319481, 28.485766164958477, 3.7623811746016145, 0.1395505398977548, 0.09796961603569798, 0.1401393153355457, 0.3076550335390493, 0.1505202692351304, 0.17396872193785384, 0.10128028487088159, 0.20304572652094066, 0.17760791728505865, 0.1114506321027875, 0.06356100770062767, 0.23505365039454773, 0.14065141207538545, 0.16149140865309164, 0.13112664426444098, 0.15839533181861043, 0.1943553553428501, 0.09183998088701628, 0.1326915220124647], [0.057420785815338604, 0.031927048330544494, 0.01894127668492729, 0.03026760241482407, 0.021572756086243317, 0.008602597372373566, 0.01584218116477132, 0.011888745648320764, 0.03467871298198588, 0.007011223096924368, 0.04438378557097167, 0.02820936901116511, 0.03751580625248607, 0.024368131380470004, 0.03132070996798575, 0.10871679754927754, 0.0873050355585292, 0.06595316488528624, 0.03594234185584355, 0.1294764640624635, 7.148576360195875, 27.71551139652729, 43.756263256073, 36.54747627675533, 23.69409028440714, 17.47149668633938, 34.66340057551861, 31.309385150671005, 8.222614377737045, 0.019813923609035555, 0.10876618005568162, 2.8236785950139165, 2.097249012440443, 2.2852743230760098, 5.253502149134874, 5.166850173845887, 9.754903055727482, 9.99885281547904, 18.821512944996357, 38.23335461318493, 48.62080402672291, 49.769816771149635, 50.755844861269, 48.275007382035255, 52.062925323843956, 48.6352014541626, 50.230295062065125, 48.79921205341816, 45.474067479372025, 37.17945076525211, 37.58093722164631, 35.43231591582298, 39.620283991098404, 48.14416140317917, 50.92213153839111, 47.586419731378555, 46.87083452939987, 47.155412659049034, 47.40238420665264, 49.15989629924297, 50.68053290247917, 49.64579902589321, 46.33861988782883, 48.10233324766159, 48.83572429418564, 47.73472957313061, 45.17119713127613, 43.462330028414726, 44.85299460589886, 50.65160885453224, 50.676136538386345, 48.56208577752113, 48.735143691301346, 43.95068742334843, 38.1749327480793, 33.83143521845341, 34.706942439079285, 35.96607327461243, 36.78191229701042, 37.39074222743511, 46.23394690454006, 47.02131785452366, 50.25761179625988, 48.619052320718765, 49.574875831604004, 47.83630192279816, 51.0744159668684, 39.68988485634327, 30.169176533818245, 47.633240818977356, 45.2482607960701, 47.38999307155609, 47.057024538517, 48.32703419029713, 47.03063115477562, 49.09364305436611, 42.32399471104145, 39.668176621198654, 36.72021880745888, 36.3519349694252, 38.08499917387962, 43.41124936938286, 43.799368143081665, 48.34104783833027, 50.565258488059044, 51.33404843509197, 52.008360251784325, 50.06428577005863, 51.63484789431095, 47.81007573008537, 35.335709899663925, 34.63790014386177, 36.11206144094467, 37.14047245681286, 38.907343447208405, 38.7597631663084, 37.112000584602356, 35.44837765395641, 36.36526085436344, 37.82305262982845, 46.69610470533371, 51.23638607561588, 50.80415926873684, 48.4059027582407, 51.86437837779522, 47.7727997303009, 44.25880528986454, 40.79299606382847, 43.07803764939308, 46.028195545077324, 48.28590899705887, 48.844357430934906, 52.428142726421356, 52.84575551748276, 53.54563996195793, 48.9060091227293, 43.5049257427454, 38.649496883153915, 22.391396686434746, 16.255816519260406, 14.054035115987062, 9.75867435336113, 10.008379854261875, 3.2253350922837853, 2.0021550776436925, 0.3707952657714486, 0.055632072617299855, 0.49121009185910225, 14.024388156831264, 41.82356536388397, 22.494652345776558, 24.015064761042595, 40.087221935391426, 51.273046508431435, 44.35158871114254, 16.3569974899292, 0.6904883799143136, 0.02899332372180652, 0.07364930308540352, 0.05605068101431243, 0.04489450562687125, 0.07339203759329394, 0.06930377610842697, 0.10255995526676998, 0.06801311450544745, 0.023554351610073354, 0.0237605888833059, 0.0566791019809898, 0.03627690202847589, 0.011418766716815298, 0.05058537564764265, 0.04116322088520974, 0.06242050483706407, 0.009966142515622778, 0.07534209740697406, 0.03683508242829703, 0.02329850733076455, 0.031031439357320778, 0.050209641121909954, 0.02588581595773576, 0.03598510811571032, 0.0195265083675622, 0.04350233677541837, 0.03255625968449749, 0.04405902545840945, 0.013625000137835741, 0.01759703387506306, 0.05164039052033331, 0.029136843950254843, 0.01575231450260617, 0.033061784706660546, 0.07873400172684342, 0.04217516521748621, 0.04088925335963722, 0.07950463303131983, 0.07656178742763586, 9.63032579049468, 35.20734518766403, 50.9027373790741, 43.741759434342384, 29.32479914277792, 18.12525350600481, 36.869664788246155, 35.66752329468727, 8.591317143291235, 0.1666648013633676, 0.25469092244748026, 0.6649814173579216, 4.224147833883762, 4.777300776913762, 7.361659901216626, 9.31366028264165, 10.114846341311932, 18.589544892311096, 20.329519025981426, 39.93197366595268, 48.99898253381252, 50.91986685991287, 52.963465601205826, 50.45966595411301, 52.32886165380478, 49.986975118517876, 53.27822931110859, 51.657532677054405, 48.606216609478, 40.33187560737133, 39.618809670209885, 36.673747301101685, 42.00649134814739, 49.33791674673557, 51.627666279673576, 48.171968311071396, 47.53730736672878, 47.8907036036253, 50.03198370337486, 51.06859087944031, 51.56390190124512, 50.389563515782356, 47.937813475728035, 50.77033348381519, 50.373748764395714, 50.56805893778801, 47.33785226941109, 45.810592621564865, 48.815809562802315, 51.17213912308216, 50.70794463157654, 48.18230375647545, 50.160124227404594, 45.52064538002014, 40.992907136678696, 36.48298613727093, 37.464861050248146, 37.48122677206993, 38.82145665585995, 38.87141637504101, 48.65977093577385, 48.1570503115654, 51.71519458293915, 50.96291474997997, 52.529046311974525, 50.09922869503498, 51.574678122997284, 41.4787794649601, 31.813099421560764, 46.77738234400749, 44.341371059417725, 49.77031074464321, 48.50848205387592, 49.80284459888935, 49.43717882037163, 50.10326407849789, 43.28827276825905, 40.86894638836384, 38.675658479332924, 37.44920589029789, 40.2635058760643, 45.00810608267784, 46.33260101079941, 51.68158158659935, 52.69969895482063, 53.749981597065926, 54.19296182692051, 52.79746010899544, 53.365024253726006, 48.738631904125214, 36.234110891819, 35.993101224303246, 37.29757882654667, 38.969838693737984, 40.331940203905106, 41.29154451191425, 38.5617595911026, 38.544090539216995, 38.70184287428856, 40.64942076802254, 48.158254846930504, 53.82648289203644, 53.09659145772457, 50.06544090807438, 53.2475421577692, 50.411549136042595, 46.22396484017372, 43.148478269577026, 46.255172565579414, 47.97728195786476, 50.62725596129894, 51.792265847325325, 53.2228434830904, 55.420531556010246, 54.433724507689476, 49.58884388208389, 42.91034124791622, 34.76464234292507, 23.047807663679123, 16.086104325950146, 11.608417946845293, 5.864060511812568, 8.147124778479338, 7.950036004185677, 2.4830741342157125, 0.46530848485417664, 0.0967046624282375, 0.67124069086276, 16.81557398289442, 46.17293357849121, 32.76320233941078, 29.26250908523798, 46.88272789120674, 55.83764277398586, 50.67663811147213, 21.341684013605118, 1.5274194767698646, 0.02500345803127857, 0.09584022365743294, 0.06077189798816107, 0.025675543256511446, 0.05947743287833873, 0.05418898872449063, 0.04164960220805369, 0.031252090993802994, 0.016367219104722608, 0.0819577428046614, 0.026453230530023575, 0.005974836594759836, 0.03156208978907671, 0.02682494818145642, 0.06123360290075652, 0.06582032787264325, 0.012698047485173447, 0.02551187000790378, 0.04084256484929938, 0.14472069684416056, 0.2901466120965779, 0.12400603416608647, 0.16342461429303512, 0.08959231985500082, 0.13579022604972124, 0.08898240062990226, 0.10509437473956496, 0.1891603512922302, 0.06835516294813715, 0.13229373085778207, 0.1320397382369265, 0.1398566015996039, 0.10687636779039167, 0.11509580916026607, 0.16629945690510795, 0.164864499529358, 0.10424081585370004, 0.36573643097653985, 0.4670133168110624, 12.060653530061245, 44.01478238403797, 57.79554471373558, 51.47923864424229, 35.81647150218487, 26.960347518324852, 47.12913706898689, 40.90665936470032, 10.78097339719534, 0.3331265808083117, 0.4065977461868897, 4.226276194676757, 5.536805447191, 8.855363074690104, 15.334915034472942, 13.137899525463581, 17.138499654829502, 13.47017364576459, 21.168173924088478, 39.75672706961632, 51.643572226166725, 52.18920774757862, 53.77398490905762, 51.29296503961086, 52.888697013258934, 50.53620524704456, 55.733019188046455, 53.851211965084076, 51.03679798543453, 40.84504947066307, 41.7275483161211, 38.74193072319031, 44.77261371910572, 52.07755833864212, 54.2626728862524, 48.42445716261864, 47.64101900160313, 47.89082519710064, 49.307681769132614, 52.28872060775757, 53.74887205660343, 52.670630514621735, 48.71087059378624, 50.74766010046005, 51.63283780217171, 52.63447545468807, 49.83222842216492, 49.77777734398842, 50.80938778817654, 53.498248904943466, 52.17792235314846, 49.0605316311121, 53.76378245651722, 47.1343731880188, 43.67554418742657, 37.26625710725784, 38.445706218481064, 37.82620646059513, 40.38058899343014, 41.578900292515755, 50.26347868144512, 51.28447629511356, 53.0077788233757, 52.826406955718994, 53.57671469449997, 52.68099635839462, 52.25866802036762, 42.69878000020981, 35.096565932035446, 46.198730394244194, 45.15188656747341, 49.84528452157974, 50.24257980287075, 51.552050337195396, 51.746938079595566, 53.01138482987881, 46.54853582382202, 43.51860500872135, 40.90721033513546, 39.60101142525673, 40.91749258339405, 48.16553145647049, 48.86399857699871, 55.011365711688995, 54.14237894117832, 54.924764558672905, 57.13253729045391, 54.56414110958576, 55.084982961416245, 51.38815373182297, 39.413761273026466, 37.62993939220905, 39.90784876048565, 41.182881742715836, 42.426969185471535, 43.17015990614891, 40.343936160206795, 39.49198767542839, 40.1155000180006, 42.071391865611076, 49.80152986943722, 54.836689084768295, 54.48078878223896, 50.14634616672993, 53.7932650744915, 52.27043978869915, 48.665983602404594, 46.21093533933163, 48.84922876954079, 50.38553573191166, 53.88794079422951, 53.486997708678246, 57.309421598911285, 55.5969712883234, 58.73208045959473, 49.712208062410355, 47.14299872517586, 41.012810468673706, 25.931054949760437, 20.474998019635677, 19.43861123174429, 16.34132143110037, 21.397043243050575, 11.543240044265985, 4.695956641808152, 0.9494012023787946, 0.14901460002874956, 1.1022814270108938, 19.09286968410015, 55.4476772993803, 34.63309720158577, 34.10759299993515, 52.57590539753437, 63.54198016226292, 59.14018236100674, 27.946214117109776, 2.598969815298915, 0.08603569585829973, 0.20686717849457636, 0.1016393730242271, 0.10382353590102866, 0.1562524397741072, 0.1763085651327856, 0.17646181862801313, 0.19379179808311164, 0.0686483558092732, 0.2980701962951571, 0.22177256149007007, 0.21287502720952034, 0.28632799512706697, 0.16206851752940565, 0.1413139866781421, 0.14806053950451314, 0.038556211948161945, 0.17904703068779781, 0.18088844750309363], [0.0607404643233167, 0.03780952603847254, 0.02462846565322252, 0.12414239638019353, 0.01789233814633917, 0.010098735547217075, 0.038107246000436135, 0.006065279812901281, 0.052220022698747925, 0.06530653161462396, 0.07883379090344533, 0.09894466449622996, 0.013106266742397565, 0.03832750800938811, 0.0432633281161543, 0.008713138413440902, 0.047619415854569525, 0.07361480063991621, 0.09708349913125858, 0.09003496641525999, 7.213266938924789, 30.563063398003578, 46.25042662024498, 36.83862425386906, 25.55557619780302, 28.264732025563717, 30.415361523628235, 30.12765236198902, 8.71259618550539, 0.1662306152866222, 0.12150164940976538, 0.3302841552067548, 8.411522191017866, 2.621286017820239, 8.689477276057005, 9.381947368383408, 7.408779272809625, 33.07333789765835, 23.797410540282726, 40.89462921023369, 49.117965549230576, 54.98998425900936, 46.99821889400482, 51.72912463545799, 48.298330530524254, 53.02330479025841, 50.084740072488785, 47.14327231049538, 40.89921556413174, 34.18072387576103, 35.26539467275143, 35.423477590084076, 35.66086605191231, 42.110381573438644, 46.867980882525444, 50.91120332479477, 48.17539572715759, 49.45789150893688, 46.111677065491676, 50.413057655096054, 49.53318826854229, 48.874250426888466, 47.42939315736294, 48.96949991583824, 47.34118469059467, 50.32190054655075, 49.80136647820473, 49.23355154693127, 49.12159815430641, 51.08070082962513, 49.312211126089096, 50.178655833005905, 49.221141412854195, 43.20784628391266, 36.70419126749039, 33.82555693387985, 36.52965523302555, 35.85294954478741, 35.78521437942982, 36.25252090394497, 40.8705423027277, 45.512468218803406, 44.12856347858906, 44.15730893611908, 47.53216244280338, 45.87741203606129, 53.55254799127579, 43.6362124979496, 30.0416249781847, 48.29462952911854, 43.783143013715744, 46.021200120449066, 46.004047840833664, 46.44076220691204, 48.669190630316734, 48.676729425787926, 41.49861820042133, 37.574716955423355, 35.464807972311974, 37.16018959879875, 38.181814178824425, 39.819811284542084, 45.36253586411476, 49.51222479343414, 49.76639315485954, 50.489102974534035, 50.70126459002495, 49.39361035823822, 51.79929926991463, 47.021101266145706, 37.54743441939354, 36.97581209242344, 37.02371992170811, 36.138090044260025, 34.766850024461746, 35.36589927971363, 36.12539492547512, 34.9629233032465, 37.250822335481644, 36.5285836905241, 40.29516197741032, 48.63600701093674, 53.065501525998116, 52.12917476892471, 50.72699300944805, 51.171474158763885, 46.31015561521053, 43.78208287060261, 42.29360394179821, 43.21697719395161, 44.25187066197395, 45.9240697324276, 48.56335490942001, 51.50618299841881, 51.987924948334694, 50.35822659730911, 45.49696125090122, 36.60007305443287, 24.864959456026554, 22.53594473004341, 13.632563631981611, 2.463485710322857, 4.830290833488107, 5.9401865769177675, 2.9766674106940627, 2.059260788373649, 0.025116986216744408, 0.5522133246995509, 10.465872455388308, 36.44057281315327, 34.928816333413124, 33.93600560724735, 35.755309984087944, 43.202287182211876, 48.471806421875954, 21.0102391988039, 1.6164954844862223, 0.06658197919023223, 0.060977728935540654, 0.04392165021272376, 0.04836109226744156, 0.10700136772356927, 0.05595932263531722, 0.02856842562323436, 0.02701908288145205, 0.038858919142512605, 0.02578733110567555, 0.022085878845246043, 0.0948104121198412, 0.020891184358333703, 0.07657761001610197, 0.013864506036043167, 0.040675429481780156, 0.03441801876761019, 0.022867629377287813, 0.02167521513911197, 0.05512454379640985, 0.01751505067659309, 0.03410731864278205, 0.09043866506544873, 0.019310333736939356, 0.0268564467842225, 0.0871576153440401, 0.05615511232463177, 0.021163745514058974, 0.027084646062576212, 0.009596870240784483, 0.009172443405986996, 0.03794632983044721, 0.026170101191382855, 0.0389545077632647, 0.025616648272261955, 0.03417138083023019, 0.06360091298120096, 0.009724681058287388, 0.02923880205344176, 8.92467325553298, 37.03150190412998, 50.64803324639797, 42.686651051044464, 30.828935131430626, 34.70174431800842, 36.50562912225723, 33.11965361237526, 9.543622992932796, 0.2657877519959584, 0.056216680895886384, 0.9196278406307101, 4.864515597000718, 6.185163231566548, 12.964364737272263, 9.279384221881628, 6.6398425586521626, 17.58344627916813, 23.94193008542061, 42.27097615599632, 52.23867729306221, 54.919577836990356, 48.83385859429836, 50.589106008410454, 48.73025335371494, 51.80282548069954, 52.721688374876976, 49.47122499346733, 42.57042668759823, 36.914992555975914, 36.97951689362526, 36.5562804043293, 38.552940264344215, 45.22251717746258, 50.04040025174618, 50.94987004995346, 48.3859234303236, 47.900434881448746, 47.15628281235695, 51.09952121973038, 51.73721820116043, 50.65261200070381, 49.08327341079712, 49.458305686712265, 49.40168112516403, 50.859697088599205, 51.990592405200005, 52.50931017100811, 52.25128121674061, 50.3513527661562, 48.87935355305672, 51.264531165361404, 51.31450988352299, 44.564137905836105, 39.10206399857998, 35.09321831166744, 37.29102037847042, 38.3711352199316, 38.73610943555832, 39.56140235066414, 43.73772405087948, 46.84859812259674, 46.53063118457794, 47.13414140045643, 50.87721034884453, 49.454129710793495, 54.527005702257156, 45.533108711242676, 31.712522618472576, 45.905511528253555, 44.45022761821747, 47.25095473229885, 47.94879488646984, 47.73181512951851, 52.23638601601124, 50.07024385035038, 44.456698670983315, 38.55439178645611, 37.6266373693943, 37.636338248848915, 39.38089683651924, 43.65401454269886, 48.87601353228092, 51.06664918363094, 52.168236672878265, 51.06933943927288, 51.78533121943474, 50.462690591812134, 52.44298852980137, 50.296479910612106, 39.66585114598274, 38.502338379621506, 38.75027507543564, 37.936537340283394, 37.02978439629078, 37.405546233057976, 37.04114958643913, 36.85468599200249, 38.13322238624096, 37.66715079545975, 43.10245133936405, 50.15705019235611, 53.827679827809334, 52.4075972288847, 52.29705736041069, 52.1368807554245, 48.628209829330444, 45.094513446092606, 44.84209679067135, 46.49889528751373, 47.24820747971535, 50.15639282763004, 52.078394293785095, 53.21854591369629, 54.758964255452156, 51.5680056810379, 47.115153819322586, 36.7201542109251, 25.92194303870201, 17.96240944415331, 12.81007781624794, 6.653689490631223, 11.288932990282774, 6.527221351861954, 4.130036858841777, 1.5955146728083491, 0.002029853908425139, 0.5846959410700947, 12.599630858749151, 41.43038906157017, 30.5220502987504, 32.42843650281429, 42.67643719911575, 49.76864643394947, 56.750619783997536, 24.62011579424143, 2.245521331205964, 0.04523502524534706, 0.03171339885739144, 0.038728119325242005, 0.04594245896441862, 0.048113756711245514, 0.04278548891306855, 0.05034553578298073, 0.02260302961076377, 0.026087362857651897, 0.03142098896205425, 0.054854120025993325, 0.013300463597261114, 0.007483572262572125, 0.04949438887706492, 0.030565025517717004, 0.040035000565694645, 0.04393203285872005, 0.05478488506923895, 0.03881024167640135, 0.10373778073699214, 0.1108243633643724, 0.06481274365796708, 0.18490276881493628, 0.0787606077210512, 0.1317103730980307, 0.11592185663175769, 0.1366432654322125, 0.17426293896278366, 0.10536223810049705, 0.14487636974081397, 0.21275177132338285, 0.15323206200264394, 0.12551456806249917, 0.11390610932721756, 0.14019626774825156, 0.12581001705257222, 0.16207801701966673, 0.20719140797154978, 0.1691971131367609, 11.413234770298004, 43.36850546300411, 60.72689741849899, 48.205015137791634, 36.61872625350952, 38.961437344551086, 42.54633978009224, 39.74330618977547, 11.802087854593992, 0.48712557822000235, 0.3492168174125254, 1.2545393756590784, 14.529541600495577, 9.8984888009727, 17.095632255077362, 14.825788903981447, 18.691398426890373, 39.2664659768343, 27.17774525284767, 44.028754234313965, 53.138244822621346, 55.906358286738396, 49.75845918059349, 53.22568953037262, 48.55050019919872, 54.405039846897125, 55.01556448638439, 53.024281337857246, 45.38965120911598, 39.21823136508465, 38.754671439528465, 38.11602830886841, 41.13297522068024, 46.56778559088707, 50.93080647289753, 53.1269708275795, 48.14561292529106, 49.07265678048134, 47.548053190112114, 53.29664312303066, 53.68854269385338, 52.11635425686836, 50.03723122179508, 50.910625755786896, 49.46307063102722, 51.276622116565704, 53.8825336843729, 54.40412409603596, 53.76519218087196, 51.90657131373882, 49.88542556762695, 53.08170385658741, 53.73310670256615, 47.18886986374855, 40.86140379309654, 36.546723917126656, 39.32792387902737, 40.298813581466675, 39.92112144827843, 40.5208470672369, 45.11952370405197, 50.68995639681816, 47.9722548276186, 49.436996430158615, 53.01933400332928, 51.83336444199085, 54.2860796302557, 47.141478806734085, 34.93156738579273, 46.34294405579567, 43.96943561732769, 46.982202753424644, 49.130854457616806, 51.00079871714115, 51.068305894732475, 53.39392550289631, 45.33466435968876, 41.381645277142525, 39.21289645135403, 39.682703241705894, 41.488997116684914, 43.73969994485378, 50.636766850948334, 53.29464063048363, 53.683815747499466, 53.71340475976467, 52.77323640882969, 52.92246960103512, 54.28431272506714, 51.368892565369606, 41.7284070700407, 40.24725794792175, 41.18064746260643, 40.73849938809872, 38.28921161592007, 39.1426420211792, 39.85801063477993, 40.01099802553654, 39.50519196689129, 40.67239813506603, 44.10805217921734, 52.70582042634487, 57.604631558060646, 54.59871545433998, 53.457781076431274, 54.257444366812706, 51.91343754529953, 49.18182872235775, 46.73977576196194, 48.02729867398739, 50.20893640816212, 52.09532618522644, 54.90891180932522, 56.16923198103905, 55.94272993505001, 53.2112693041563, 50.352439507842064, 39.081111922860146, 28.04299872368574, 24.73275315016508, 19.26155023276806, 10.762531086802483, 17.117579877376556, 12.733649667352438, 5.8616257924586535, 3.334097843617201, 0.2123509076773189, 1.070491976570338, 14.757255781441927, 48.87817181646824, 47.27770909667015, 47.5215420126915, 50.51191695034504, 56.9942969083786, 64.57496613264084, 30.911187417805195, 3.2560925418511033, 0.21705585677409545, 0.10464038816280663, 0.21424241946078837, 0.16620305192191154, 0.2001806505722925, 0.11564337313757278, 0.1633464512997307, 0.0731749742408283, 0.08339070380316116, 0.19922578852856532, 0.16241204284597188, 0.2931833022739738, 0.17350158450426534, 0.13827840972226113, 0.08741315163206309, 0.15401223732624203, 0.15912440285319462, 0.14441543666180223, 0.10969704104354605], [0.06163144971651491, 0.0028058319230694906, 0.02424934136797674, 0.01923733980220277, 0.023327384296862874, 0.050488547640270554, 0.04794776425114833, 0.026699076224758755, 0.051501308334991336, 0.02767481673799921, 0.005537725528483861, 0.022101256145106163, 0.0668644554389175, 0.04647736561310012, 0.07730962737696245, 0.01651434246014105, 0.03680364876345266, 0.07462703812052496, 0.051288430695421994, 0.04742542216263246, 4.996833996847272, 26.283752024173737, 46.34482875466347, 39.777280166745186, 30.742558166384697, 18.113073259592056, 31.8430133163929, 37.13421419262886, 9.40960893407464, 0.2695937821408734, 0.03134556449367665, 0.7179004058707505, 1.9429590040817857, 4.079920873045921, 6.801988407969475, 7.17084601521492, 6.689394749701023, 18.743324540555477, 26.72138974070549, 43.37160609662533, 50.258953124284744, 50.10282330214977, 48.13821092247963, 50.14550641179085, 51.40426106750965, 51.32794216275215, 46.60767965018749, 45.906685665249825, 35.5582145601511, 34.24985356628895, 34.12026531994343, 34.79777276515961, 35.72536379098892, 40.44279545545578, 45.07943205535412, 49.4169145077467, 47.21460588276386, 48.332665488123894, 48.51378656923771, 47.15455010533333, 45.64918868243694, 45.783408880233765, 45.43129697442055, 48.362216502428055, 49.77010935544968, 50.021344274282455, 47.48297408223152, 47.427367866039276, 48.86543869972229, 48.23515132069588, 49.380744248628616, 47.522423565387726, 46.10110603272915, 39.22577016055584, 34.655200615525246, 34.83004443347454, 35.76441049575806, 34.67623628675938, 36.85986511409283, 35.69831684231758, 36.80275797843933, 38.65333467721939, 41.0342413187027, 41.037463545799255, 44.70272406935692, 45.768513679504395, 50.65238021314144, 46.40061356127262, 31.38911247253418, 48.8291772454977, 48.67411136627197, 49.80470269918442, 45.634019896388054, 51.26005120575428, 47.75497868657112, 48.5526242852211, 41.93999111652374, 35.571073070168495, 34.64836098253727, 37.72777274250984, 34.88287679851055, 37.37653099000454, 39.52952966094017, 46.584185510873795, 48.59333150088787, 52.14383438229561, 48.67965906858444, 47.39275932312012, 49.63649332523346, 46.55971862375736, 37.715822383761406, 36.735961362719536, 37.377237752079964, 37.57277525961399, 40.61908319592476, 41.33032523095608, 42.908456549048424, 40.52720032632351, 37.073964625597, 35.502532348036766, 36.06348864734173, 42.726062536239624, 48.91677014529705, 52.534962594509125, 49.51007030904293, 53.205619007349014, 49.81040619313717, 47.5629635900259, 43.120374977588654, 43.85986849665642, 43.67503881454468, 45.78433223068714, 48.184830620884895, 52.885387390851974, 52.991736084222794, 53.40913988649845, 46.19510538876057, 39.84158031642437, 27.99801103770733, 21.62813164293766, 9.97121974825859, 5.306977154687047, 7.497883541509509, 7.359181009232998, 3.8949966710060835, 1.2152700265869498, 0.06317227816907689, 0.28036979609169066, 14.372735414654016, 37.48457059264183, 38.536604940891266, 30.411527529358864, 36.63599252700806, 46.90672740340233, 43.91586609184742, 26.51868011802435, 1.2476774188689888, 0.023309107054956257, 0.01652704431762686, 0.062172779653337784, 0.030287419613159727, 0.061007006661384366, 0.08876540407072753, 0.03694279774208553, 0.008015170787984971, 0.011044412585761165, 0.047938338975654915, 0.04144344842643477, 0.03097235141467536, 0.043630353538901545, 0.026948293125315104, 0.07197924816864543, 0.013013946354476502, 0.09716558808577247, 0.10364880465203896, 0.0038051298270147527, 0.0100508364084817, 0.05902143137063831, 0.026739150343928486, 0.024887271101761144, 0.04862975714786444, 0.019286260321678128, 0.05791723437141627, 0.01740687708661426, 0.041576548901502974, 0.02025103003688855, 0.05236738725216128, 0.01558078747621039, 0.07231438721646555, 0.016894977015908808, 0.02874820162105607, 0.03238843411963899, 0.013509310447261669, 0.04663284926209599, 0.09085670943022706, 0.1611045715981163, 6.789630521088839, 32.00464144349098, 53.97867612540722, 45.28055526316166, 35.46942472457886, 22.278305254876614, 34.28869508206844, 42.219165936112404, 11.285886503756046, 0.24468470859574154, 0.07205145171610638, 1.9783709663897753, 5.0093011278659105, 10.327172297984362, 11.719681676477194, 9.246878866106272, 10.584085062146187, 20.307746194303036, 30.646068044006824, 44.851345494389534, 52.044697701931, 51.54608465731144, 49.47815582156181, 48.91555041074753, 51.773392260074615, 52.35242418944836, 49.27426636219025, 49.603328704833984, 38.2845226675272, 36.50999128818512, 36.00521117448807, 36.13823443651199, 37.40246839821339, 43.04334931075573, 48.677276596426964, 51.069936007261276, 47.09789514541626, 48.360681384801865, 49.24807816743851, 49.5081552118063, 48.549557849764824, 48.36975149810314, 48.79492588341236, 50.88539130985737, 51.07723921537399, 49.76795867085457, 48.04704621434212, 48.083524256944656, 47.876526564359665, 47.573033049702644, 52.10282318294048, 50.678777396678925, 46.87941446900368, 41.550515815615654, 36.41137138009071, 37.12545946240425, 37.20151238143444, 37.32107676565647, 37.9584925621748, 36.532265692949295, 37.38024719059467, 39.19266253709793, 42.853378504514694, 43.41569133102894, 46.01884424686432, 48.414311707019806, 53.154108971357346, 48.31623136997223, 32.60551080107689, 48.068097084760666, 48.15579637885094, 50.431479066610336, 47.92728804051876, 52.84254848957062, 49.97099317610264, 50.750072970986366, 42.929526418447495, 36.88751243054867, 36.136459931731224, 38.57049912214279, 37.58632533252239, 40.04619173705578, 42.97099359333515, 47.00483813881874, 50.10769844055176, 52.9089081287384, 50.05209602415562, 49.61105369031429, 50.901646837592125, 49.16219897568226, 40.21739535033703, 37.86407522857189, 39.10458706319332, 37.44221806526184, 40.622715801000595, 42.392231449484825, 43.984893187880516, 41.1048149317503, 38.11974450945854, 36.60445421934128, 37.65756390988827, 45.60517944395542, 52.72313229739666, 53.571660965681076, 52.514895871281624, 53.99651616811752, 51.21737189590931, 49.900579154491425, 45.97599774599075, 45.17187349498272, 45.634776055812836, 47.94596403837204, 51.74314588308334, 54.23886716365814, 55.22698134183884, 52.73140445351601, 49.30031396448612, 38.49083259701729, 29.0034256875515, 16.209253817796707, 11.024545077234507, 8.66247782483697, 6.909598633646965, 4.994567893445492, 3.2673670118674636, 2.66512094065547, 0.011014517021976644, 0.6502840435132384, 14.972736518830061, 44.99301329255104, 46.211045533418655, 37.3144119232893, 41.398778557777405, 53.005757331848145, 50.79819358885288, 30.80682221800089, 1.8026706506498158, 0.03688137017888948, 0.02473155182087794, 0.02808935816574376, 0.04094801661267411, 0.050172081027994864, 0.05055876594269648, 0.052722397304023616, 0.03337793590617366, 0.009684905653557507, 0.04889360548986588, 0.08524455901351757, 0.04067121037223842, 0.05629932275041938, 0.02548951466451399, 0.125012653588783, 0.042833591214730404, 0.04987484717275947, 0.06245935626793653, 0.051911968330387026, 0.20126230112509802, 0.13854458840796724, 0.13414427608950064, 0.13530453492421657, 0.15661523124435917, 0.08655427896883339, 0.1059738420008216, 0.17120033298851922, 0.13636331248562783, 0.11185882816789672, 0.1969282329082489, 0.051108849511365406, 0.18073022161843255, 0.15968331426847726, 0.12466915795812383, 0.0838736786681693, 0.14529730106005445, 0.06578414075192995, 0.1740895287366584, 0.37779496517032385, 9.548793565481901, 39.92806747555733, 60.74496924877167, 52.26727455854416, 42.56269030272961, 26.015038043260574, 41.5466970205307, 46.99369713664055, 13.187104035168886, 0.6725477613508701, 0.23888939613243565, 1.524266239721328, 7.356926780194044, 12.435764651745558, 16.333026476204395, 14.778053015470505, 13.391746804118156, 20.974133536219597, 31.47547233849764, 47.190237790346146, 53.68091270327568, 53.065045550465584, 50.10698027908802, 49.16286014020443, 53.936714977025986, 56.50469318032265, 50.941366106271744, 51.89117453992367, 39.23961661756039, 38.79992701113224, 38.232203274965286, 37.99182057380676, 40.68936422467232, 46.100699454545975, 48.73950965702534, 52.34897397458553, 48.2873909175396, 49.69523437321186, 53.66217590868473, 51.53305135667324, 51.348354667425156, 50.44061377644539, 51.15581139922142, 54.14501219987869, 51.18345871567726, 51.80603250861168, 46.96669578552246, 48.28953020274639, 49.76421967148781, 48.180149272084236, 51.511384919285774, 51.45819537341595, 48.71663488447666, 43.18527549505234, 36.77042171359062, 39.50807221233845, 40.2664203196764, 39.64491426944733, 40.18980123102665, 38.560726046562195, 38.61602067947388, 41.26090295612812, 44.9422974139452, 46.278944090008736, 47.07202233374119, 51.84749208390713, 53.87917086482048, 50.397554486989975, 36.06919214129448, 49.107246324419975, 50.444554165005684, 52.39479571580887, 50.909827798604965, 53.44127096235752, 51.91686116158962, 53.506445065140724, 46.13796405494213, 38.866833820939064, 37.96482302248478, 40.66342681646347, 39.34817299246788, 41.55039042234421, 44.053243920207024, 51.0506634414196, 53.409751653671265, 56.567667201161385, 50.906989350914955, 50.50471633672714, 53.14338594675064, 51.5919291973114, 42.17432074248791, 40.147752687335014, 41.60182826220989, 40.13133376836777, 43.725595101714134, 45.97361907362938, 46.76138900220394, 44.54762779176235, 40.76490417122841, 39.37604449689388, 40.39631634950638, 47.269797921180725, 52.79301054775715, 56.68350778520107, 51.86114475131035, 57.21381492912769, 52.74145871400833, 53.19087199866772, 47.44714580476284, 48.97026367485523, 48.38595002889633, 51.81435026228428, 55.016818419098854, 58.13206985592842, 56.63449041545391, 56.06365464627743, 48.50502423942089, 42.43239909410477, 30.28778526932001, 24.14299249649048, 13.714133854955435, 12.219167724251747, 14.386940002441406, 11.246873047202826, 8.714583478868008, 3.2563981879502535, 0.2664274536073208, 0.7899657357484102, 19.02959167957306, 50.92467360198498, 55.24030342698097, 42.04350896179676, 50.62488108873367, 61.68800264596939, 60.458829402923584, 36.0019813477993, 2.8910938650369644, 0.16604720090981573, 0.1738515665056184, 0.1923383167013526, 0.0987509787955787, 0.13477036671247333, 0.1948993347468786, 0.15777845866978168, 0.08772680550464429, 0.0662780251877848, 0.13108646438922733, 0.18029665894573554, 0.11973998378380202, 0.14075696031795815, 0.2872174442745745, 0.1814217696664855, 0.19085737585555762, 0.19105094281258062, 0.17536896164529026, 0.1693206065101549], [0.014154115251585608, 0.04336751822847873, 0.005608302844848367, 0.03113939215836581, 0.02208955989772221, 0.03749297036847565, 0.0703179209085647, 0.014945962702768156, 0.10058515967102721, 0.03533411472744774, 0.0362461362965405, 0.03177342005074024, 0.030528163042617962, 0.011091899832536, 0.04191523541521747, 0.030362447032530326, 0.017054063791874796, 0.017992548491747584, 0.09521501619019546, 0.07730280703981407, 3.448325889185071, 25.720538645982742, 44.00681421160698, 37.1256722509861, 46.062591299414635, 38.097382709383965, 30.6700561568141, 32.34013304114342, 9.470936693251133, 0.6965820654295385, 0.05954821150226053, 3.2600136939436197, 6.924609253183007, 7.9571302235126495, 12.784499488770962, 7.187086818739772, 6.008335445076227, 18.692285679280758, 29.950904846191406, 42.93364159762859, 50.78280061483383, 48.422507867217064, 50.845539048314095, 51.58457279205322, 49.58286300301552, 47.05492325127125, 45.73128327727318, 38.80176231265068, 34.16297882795334, 33.8045896589756, 34.93751026690006, 36.219990849494934, 37.54244528710842, 43.46848949790001, 46.4037711918354, 48.83973307907581, 45.896696001291275, 50.585583597421646, 45.11163532733917, 43.78886550664902, 41.85476928949356, 42.485573440790176, 43.48656892776489, 44.42767582833767, 47.507801949977875, 49.648519679903984, 49.842594265937805, 49.41633313894272, 50.597055181860924, 50.636690855026245, 49.12830099463463, 46.44352085888386, 43.097883984446526, 37.12888687849045, 34.57037016749382, 34.21382009983063, 36.39031670987606, 36.14686377346516, 34.086124151945114, 35.50488442182541, 36.92267194390297, 35.67645661532879, 36.19865879416466, 35.70088170468807, 40.47517351806164, 42.97153316438198, 49.08481612801552, 46.69454678893089, 31.872596628963947, 49.00532819330692, 49.60056625306606, 48.108690306544304, 50.67818462848663, 48.65122899413109, 50.028932467103004, 47.127818539738655, 40.665060728788376, 36.00073501467705, 36.0833577811718, 36.634996980428696, 36.24360278248787, 37.38557830452919, 37.34903186559677, 40.7660973072052, 45.87593011558056, 50.58852843940258, 50.550348088145256, 47.93799586594105, 47.28317320346832, 48.221232667565346, 42.07783252000809, 41.58826678991318, 42.47360408306122, 43.240163549780846, 48.022647723555565, 50.02313017845154, 50.48678129911423, 49.85140219330788, 47.12723337113857, 39.81093876063824, 36.21212147176266, 34.306816309690475, 44.36152897775173, 49.476039335131645, 51.23904973268509, 50.78125789761543, 51.483232229948044, 47.75100030004978, 46.72489956021309, 42.56674088537693, 43.454027473926544, 40.899162366986275, 47.669692263007164, 49.61484208703041, 55.01256264746189, 50.3427804261446, 51.61317765712738, 39.08302702009678, 31.430395357310772, 15.357585567981005, 13.996632546186447, 7.115058833733201, 7.596962274983525, 3.769251205958426, 2.235762979835272, 6.10901246778667, 0.31340638117399067, 0.6166594102978706, 8.296037837862968, 33.55920262634754, 22.534240521490574, 24.66920156031847, 43.35668809711933, 44.86135795712471, 46.87149949371815, 25.19785199314356, 1.2637947290204465, 0.060130671263323165, 0.030216236518754158, 0.11748108663596213, 0.013868291916878661, 0.06607337796594948, 0.04564852766634431, 0.03042188563995296, 0.061273289247765206, 0.03640276656369679, 0.04065102766617201, 0.04112858485314064, 0.025704381259856746, 0.041461861110292375, 0.058585942824720405, 0.031144457316258922, 0.02228795081464341, 0.06453255322412588, 0.03604991616157349, 0.09360923868371174, 0.06577750595170073, 0.023972045310074463, 0.022529237867274787, 0.043602960868156515, 0.050876694585895166, 0.06891560318763368, 0.034362836377113126, 0.029267374738992658, 0.030018760298844427, 0.06622965200222097, 0.05795443823444657, 0.013986029007355683, 0.07901865988969803, 0.022145506700326223, 0.03408379627217073, 0.012759851688315393, 0.034469434758648276, 0.02352735598833533, 0.02342080213566078, 0.12777908326825127, 5.131211411207914, 31.209879890084267, 50.38954831659794, 43.985793739557266, 49.670763686299324, 37.084877640008926, 36.970655769109726, 39.36899207532406, 11.171910669654608, 0.6484515324700624, 0.023351173840637784, 2.0718696992844343, 2.022868716157973, 9.73536355420947, 12.540019657462835, 6.526494640856981, 7.915075505152345, 15.087829492986202, 32.04559184610844, 43.23491983115673, 51.63892887532711, 49.492306262254715, 51.8475528806448, 52.07443870604038, 53.14148984849453, 49.01207663118839, 47.286262437701225, 41.096322387456894, 35.973927453160286, 35.91885320842266, 36.98345348238945, 37.419582679867744, 39.325700998306274, 44.95015159249306, 49.01438690721989, 49.82716329395771, 46.2570458650589, 52.359583005309105, 48.02421323955059, 44.84857924282551, 43.19867357611656, 44.45561572909355, 44.94671657681465, 46.44178055226803, 49.94578532874584, 52.723789662122726, 51.43193878233433, 49.71033476293087, 50.166222900152206, 51.41043193638325, 50.96678674221039, 47.15839549899101, 45.91127201914787, 39.34205912053585, 35.24217791855335, 36.32274493575096, 37.87633337080479, 38.452344462275505, 34.98435415327549, 37.7308239787817, 38.28870244324207, 37.749161794781685, 37.90444806218147, 38.562268763780594, 44.351345524191856, 46.2062805891037, 50.2468241751194, 49.401118755340576, 33.254743963479996, 49.34743143618107, 51.07548750936985, 50.635748505592346, 51.889688819646835, 51.68547637760639, 51.88857927918434, 50.083007365465164, 42.95195281505585, 36.62464253604412, 38.06777089834213, 38.013053834438324, 38.02048243582249, 39.30098332464695, 39.550645127892494, 42.74581767618656, 47.983502224087715, 52.235295474529266, 52.611881867051125, 48.14261108636856, 50.71252718567848, 50.3634437173605, 43.001866936683655, 42.00856223702431, 42.48783811926842, 44.9888601154089, 49.44439843297005, 52.93088234961033, 52.68625907599926, 51.65413185954094, 49.27617006003857, 41.53655916452408, 38.835569098591805, 37.11713030934334, 46.99440009891987, 51.37532562017441, 53.69562171399593, 53.47487635910511, 53.64529341459274, 50.775763392448425, 47.956516072154045, 46.65666662156582, 48.115438744425774, 43.6410154402256, 50.25888092815876, 51.050313860177994, 58.033449947834015, 52.91879899799824, 52.38137863576412, 39.0164165943861, 31.245442181825638, 15.497943386435509, 14.305575918406248, 9.131801091134548, 9.970100708305836, 7.160396100953221, 0.9722544823307544, 6.099353861063719, 0.19077667471719906, 0.8048235916066915, 11.636358797550201, 41.41106329858303, 32.5063931196928, 31.65658961981535, 48.25564742088318, 54.34433810412884, 54.26100097596645, 29.103196933865547, 1.9301624782383442, 0.07656581728952006, 0.07519408347434364, 0.045446173680829816, 0.014351949557749322, 0.09651052401750349, 0.042011124605778605, 0.029352152123465203, 0.072037195059238, 0.012961570209881756, 0.058680492438725196, 0.04357293357315939, 0.020741025618917774, 0.10649818417732604, 0.03659158377558924, 0.03555103707185481, 0.03750818068510853, 0.0552226000581868, 0.04997180505597498, 0.04392101938719861, 0.15762155380798504, 0.09379717273986898, 0.10300174093572423, 0.1223053211288061, 0.13995401590364054, 0.19489308586344123, 0.16304957738611847, 0.11978337715845555, 0.25811548868659884, 0.1912473002448678, 0.12477365235099569, 0.0782325622276403, 0.15387826482765377, 0.0814096667454578, 0.12215384136652574, 0.08908529198379256, 0.06905186892254278, 0.10010962854721583, 0.13871176459360868, 0.19964722450822592, 7.307299543172121, 36.556747779250145, 59.85798664391041, 49.2642766982317, 54.946974366903305, 45.942521542310715, 42.56965532898903, 44.22372177243233, 13.406763598322868, 1.0912290075793862, 0.2744543447624892, 5.358618758618832, 13.136751987040043, 14.420285113155842, 22.464664354920387, 18.311561308801174, 10.693612284958363, 21.761143505573273, 34.399607330560684, 45.92847749590874, 52.146498039364815, 49.34666767716408, 52.543101757764816, 53.00711765885353, 54.65170741081238, 51.485101729631424, 50.561272501945496, 43.64604637026787, 38.18896159529686, 37.28343218564987, 39.776550605893135, 39.65121813118458, 41.46207936108112, 48.03778611123562, 51.453571021556854, 51.49963974952698, 47.23859779536724, 53.13505679368973, 50.32138377428055, 47.8813599050045, 45.982104018330574, 47.480154633522034, 48.97895000874996, 48.96768741309643, 51.68581835925579, 55.33893093466759, 52.263721749186516, 51.88432350754738, 52.300860956311226, 54.6603861451149, 53.375253304839134, 50.25537371635437, 47.64147497713566, 40.80816484987736, 37.274335473775864, 39.0520016849041, 40.572490096092224, 40.46608440577984, 36.66816920042038, 39.4852202385664, 40.02917245030403, 39.457732513546944, 39.86603960394859, 40.312903225421906, 45.005571618676186, 47.67361365258694, 54.14228394627571, 51.47539705038071, 36.209727600216866, 50.59192545711994, 52.11972087621689, 52.451636865735054, 54.11738768219948, 52.71376959979534, 54.470802918076515, 52.2599333524704, 44.31197963654995, 39.234486892819405, 41.196044236421585, 39.515204429626465, 39.053703993558884, 41.57020255923271, 41.471882835030556, 45.92468909919262, 50.63731022179127, 55.78503459692001, 54.57639545202255, 49.07174102962017, 51.66380234062672, 53.27835090458393, 46.25645309686661, 45.67999742925167, 46.210855543613434, 47.06108272075653, 53.08991901576519, 55.612512454390526, 55.44442467391491, 53.21821913123131, 52.2755391150713, 44.951641112565994, 41.966019719839096, 38.31380769610405, 48.99443417787552, 53.175631016492844, 55.85672155022621, 54.738589748740196, 55.56444503366947, 54.137477204203606, 50.97694359719753, 48.83573569357395, 50.69816395640373, 45.5351036041975, 54.285878241062164, 53.47153253853321, 60.6038524210453, 53.9323528110981, 53.38678568601608, 40.512362122535706, 34.90537919104099, 18.93192932009697, 18.510978408157825, 18.742784969508648, 16.801429241895676, 9.614940416067839, 6.482946602627635, 8.693175427615643, 0.3637837810674682, 1.4998596743680537, 12.83579483628273, 46.7528622597456, 33.84569205343723, 39.48613218963146, 57.16678485274315, 61.13153390586376, 64.30663973093033, 34.50074650347233, 3.4329398022964597, 0.1922832493437454, 0.2408944713533856, 0.1752483329619281, 0.11908920932910405, 0.24091225321171805, 0.09181063636788167, 0.12915033468743786, 0.1605993916746229, 0.10718809950049035, 0.16315571934683248, 0.1818737672874704, 0.18407187511911616, 0.1522701940848492, 0.21763626078609377, 0.0943976741109509, 0.11855600590934046, 0.2583340660203248, 0.18351734237512574, 0.15892066847300157], [0.03370859609276522, 0.02741413736657705, 0.11021341997548006, 0.030312552444229368, 0.02934493102657143, 0.02149910720618209, 0.026054576628666837, 0.09840069251367822, 0.010556533979979577, 0.05844718718435615, 0.04635069584765006, 0.019652554728963878, 0.09341095908894204, 0.04431244291481562, 0.09541140330838971, 0.049121890115202405, 0.008512950571457623, 0.027166447434865404, 0.08445687315543182, 0.09408181605977006, 3.8844560366123915, 23.21735266596079, 41.22254401445389, 39.25175316631794, 32.48123086988926, 20.681359246373177, 27.500921711325645, 40.99797606468201, 11.80344058200717, 1.0333926673047245, 0.46922346227802336, 2.331028855405748, 0.6988692458253354, 12.722082138061523, 9.230145514011383, 5.150791760534048, 9.476161412894726, 22.914379723370075, 34.72102828323841, 45.97061723470688, 49.51317474246025, 49.47792403399944, 52.72846721112728, 50.61670772731304, 46.06901675462723, 44.418822303414345, 39.76525381207466, 34.77444961667061, 36.550709903240204, 35.80435015261173, 41.72457307577133, 42.398550510406494, 45.39563588798046, 45.990353375673294, 48.36708404123783, 45.80630265176296, 49.842123091220856, 45.86727797985077, 41.53217040002346, 40.62570624053478, 38.996285274624825, 37.16291405260563, 39.31479938328266, 42.40955471992493, 45.10060451924801, 45.08145734667778, 47.71401688456535, 48.51493030786514, 49.25236813724041, 48.87623392045498, 46.65923908352852, 42.66126461327076, 38.00770752131939, 35.15891298651695, 34.72407191991806, 34.34655077755451, 36.47879496216774, 35.30015520751476, 34.420984983444214, 35.18693268299103, 34.96975913643837, 34.62556220591068, 36.67522922158241, 35.90188331902027, 41.91483646631241, 43.19503337144852, 48.124942034482956, 46.83001331984997, 31.32594656199217, 52.92886085808277, 48.473504930734634, 47.02996239066124, 44.42082479596138, 44.05781127512455, 42.487347945570946, 39.69020023941994, 35.99539630115032, 36.64749450981617, 35.74788138270378, 36.337514743208885, 36.304080337285995, 36.399941593408585, 36.6339710354805, 37.8744562715292, 42.30016618967056, 48.36974389851093, 51.025535389781, 51.35839372873306, 47.359647899866104, 49.11837212741375, 46.98910318315029, 46.62938788533211, 45.74826076626778, 47.03175589442253, 49.476913288235664, 48.838175162673, 48.30999210476875, 48.21731507778168, 50.89413084089756, 47.5191443413496, 42.282941713929176, 35.51642060279846, 33.98265190422535, 41.513061225414276, 48.7374197691679, 49.51216779649258, 48.76938745379448, 48.394647762179375, 48.02603334188461, 44.948589876294136, 43.07015687227249, 40.85821956396103, 49.307434782385826, 49.07624378800392, 54.064912497997284, 50.712048411369324, 52.41568699479103, 38.7992050498724, 32.38188520073891, 13.668711092323065, 11.884664073586464, 7.977148499339819, 5.130575420334935, 3.5315969958901405, 3.981282915920019, 4.405814660713077, 0.06172504938149359, 0.7041284604929388, 10.982867013663054, 36.056599617004395, 34.687160700559616, 31.81051556020975, 35.20456753671169, 45.5170963704586, 46.09313786029816, 20.990962833166122, 1.1100197117775679, 0.07817016987246461, 0.07104175238055177, 0.0423943177156616, 0.08291400008602068, 0.10524184690439142, 0.045279865807970054, 0.024639202674734406, 0.026816886602318846, 0.12010273814667016, 0.10241761134238914, 0.01820264122216031, 0.06810732273152098, 0.008856244894559495, 0.0466372947266791, 0.06533093343023211, 0.03351985309564043, 0.0343395366508048, 0.012052771417074837, 0.015313354560930748, 0.023920851963339373, 0.03741151223948691, 0.047790050448384136, 0.013139174498064676, 0.05376895911467727, 0.008414341409661574, 0.05864006765477825, 0.1044111090595834, 0.06436694297008216, 0.08459342090645805, 0.06523884774651378, 0.03900718911609147, 0.09855088836047798, 0.010154905921808677, 0.11324589475407265, 0.05875777227629442, 0.034156018373323604, 0.0315629989199806, 0.09414774103788659, 0.16563507146202028, 5.302207935601473, 29.162483252584934, 48.36127795279026, 44.765698090195656, 39.17426772415638, 27.34826300293207, 31.645627208054066, 44.76478613913059, 14.160446505993605, 0.871118278009817, 0.38295048696454614, 0.4945102147758007, 3.635319792665541, 11.472651232033968, 10.138737559318542, 8.426131457090378, 8.86532424017787, 20.24942122399807, 32.884491831064224, 45.72772666811943, 50.701048001646996, 50.40483109652996, 52.85315752029419, 52.84872695803642, 48.432611525058746, 47.854411751031876, 43.08146886527538, 37.34806291759014, 37.965727373957634, 37.535373866558075, 43.81348818540573, 44.99288409948349, 45.67328318953514, 46.481241434812546, 51.06406532227993, 47.64698848128319, 47.54548452794552, 48.62927757203579, 44.988867715001106, 43.3889065682888, 41.83244548738003, 40.20066484808922, 42.45487488806248, 45.582551658153534, 46.577779054641724, 48.78939338028431, 50.70725306868553, 50.6835613399744, 51.930696219205856, 51.11654430627823, 49.62873034179211, 45.75066603720188, 39.60820823907852, 37.321019768714905, 36.220693811774254, 37.85437434911728, 38.255028650164604, 37.824967727065086, 35.65289027988911, 37.5034935772419, 36.54456563293934, 37.32342503964901, 37.39119440317154, 37.51674346625805, 42.798695638775826, 46.24216586351395, 50.17397828400135, 48.68624031543732, 33.895241394639015, 53.25614869594574, 49.95940759778023, 50.29496379196644, 45.95394752919674, 47.66464613378048, 45.62268130481243, 43.02582465112209, 37.90254056453705, 38.489149287343025, 37.82002419233322, 36.336906775832176, 39.34310786426067, 38.65331947803497, 36.61050349473953, 38.18546578288078, 44.56899784505367, 49.89433228969574, 52.673092782497406, 52.472965121269226, 48.55857856571674, 51.421740129590034, 49.4924658536911, 49.15960751473904, 49.206538796424866, 50.56660361588001, 52.243259847164154, 51.002318635582924, 50.337741896510124, 49.37638208270073, 52.96093873679638, 49.68700781464577, 42.12438762187958, 36.89142622053623, 35.9566193819046, 43.734137043356895, 50.46364054083824, 53.96242059767246, 51.755540817976, 51.138947904109955, 49.75764602422714, 47.30501443147659, 44.88813132047653, 44.29584950208664, 50.31925208866596, 54.821630492806435, 55.55007800459862, 53.74903164803982, 49.4830309599638, 41.801511347293854, 32.12310008704662, 13.230454009026289, 8.826314583420753, 13.127815816551447, 8.642997220158577, 3.8569020526483655, 4.173831408843398, 4.56005978398025, 0.05390439364418853, 0.8580503042321652, 12.040683701634407, 40.68782910704613, 35.803263410925865, 34.503075778484344, 43.361536636948586, 49.69056822359562, 54.671128168702126, 25.760673992335796, 1.4802336087450385, 0.050478658522479236, 0.0499451990617672, 0.07410484075080603, 0.01971024557860801, 0.04834724008105695, 0.07846019376302138, 0.0886809773510322, 0.03396835891180672, 0.05007369822124019, 0.07765806571114808, 0.04996714065782726, 0.04173754670773633, 0.04725869126559701, 0.05741118613514118, 0.04413533679326065, 0.06694834781228565, 0.04703602098743431, 0.04799861620995216, 0.026262422506988514, 0.14797514799283817, 0.07960915711009875, 0.15796381747350097, 0.11576497403439134, 0.14759432233404368, 0.19407915766350925, 0.1259805032168515, 0.186658066813834, 0.11154817999340594, 0.15721577714430168, 0.140556120313704, 0.1257747205090709, 0.21831517748069018, 0.12443937419448048, 0.19334306591190398, 0.20430437929462641, 0.12982785614440218, 0.21361478517064825, 0.23669636459089816, 0.2832859318004921, 8.08501711115241, 34.832381308078766, 55.18649831414223, 52.63863243162632, 43.68923105299473, 31.56707402318716, 36.87777355313301, 52.21554413437843, 16.23138763010502, 1.5417393646202981, 1.0206405515782535, 4.041371941566467, 4.338876027613878, 24.983537793159485, 19.322327971458435, 11.03745773434639, 20.482747703790665, 25.84589581936598, 34.63515669107437, 47.41813436150551, 51.02302372455597, 53.01191680133343, 52.968386337161064, 56.13273113965988, 50.85872434079647, 50.85383020341396, 45.02148896455765, 39.107265919446945, 40.42142540216446, 40.30300475656986, 47.16925151646137, 48.1552492082119, 49.530707001686096, 49.34444859623909, 53.218165934085846, 47.316831797361374, 50.35803280770779, 51.68092042207718, 47.16572530567646, 46.36130087077618, 43.27139027416706, 41.706858426332474, 43.90360414981842, 48.636896163225174, 47.900415882468224, 50.76162815093994, 52.130101919174194, 53.35932455956936, 53.234227672219276, 54.9218463152647, 51.729873195290565, 46.3949366658926, 40.65352834761143, 38.774339184165, 38.69286775588989, 38.410839289426804, 41.01159833371639, 39.457390531897545, 37.23979912698269, 39.53369803726673, 39.43238027393818, 37.977039366960526, 40.24877406656742, 40.82654446363449, 45.817873030900955, 48.74953351914883, 53.05998042225838, 51.55150316655636, 37.41323322057724, 54.601660296320915, 51.80574372410774, 50.65880946815014, 48.905686140060425, 49.57239456474781, 46.49075232446194, 44.21028949320316, 40.430408120155334, 40.356205701828, 40.25944009423256, 39.11109231412411, 41.10592447221279, 40.45468121767044, 39.20278899371624, 40.85785858333111, 47.415052726864815, 53.16982872784138, 55.44699713587761, 54.955299720168114, 49.35605317354202, 53.33699315786362, 52.09710828959942, 51.97324253618717, 52.817515432834625, 51.7761243134737, 54.01233471930027, 51.306249126791954, 51.01822078227997, 49.99862149357796, 55.81022724509239, 51.59537561237812, 45.499621108174324, 38.86948607861996, 37.26977191865444, 45.933630019426346, 52.94793963432312, 54.83793541789055, 54.42008323967457, 53.39500084519386, 53.20571780204773, 49.242872446775436, 48.11358064413071, 45.06707891821861, 54.15776051580906, 57.075988724827766, 58.14685486257076, 54.1399584710598, 54.19641964137554, 41.410105749964714, 34.829045087099075, 15.603344980627298, 16.017774492502213, 17.81135804951191, 10.75925376266241, 10.913918763399124, 7.405143342912197, 5.55235231295228, 0.20084190415218472, 1.2390763428993523, 15.005562957376242, 49.33162808418274, 45.58122172951698, 44.89494435489178, 47.137595415115356, 59.76402148604393, 61.54657043516636, 32.19698332250118, 2.187012070789933, 0.1525892730569467, 0.23432802292518318, 0.1480049081146717, 0.13188615819672123, 0.2298944178619422, 0.18391336721833795, 0.18093388178385794, 0.21730036474764347, 0.15476367669180036, 0.259473025216721, 0.151038822659757, 0.11947219463763759, 0.08927200149628334, 0.12072571174940094, 0.13401664153207093, 0.19134490750730038, 0.18136357044568285, 0.11191624071216211, 0.109695326682413], [0.010812902401085012, 0.022506834284286015, 0.021623819557134993, 0.02986301689816173, 0.0474380943342112, 0.02220474121713778, 0.04495778113778215, 0.010949365732813021, 0.035978013183921576, 0.06446734070777893, 0.1386605712468736, 0.048775689356261864, 0.037042664844193496, 0.026490593954804353, 0.03139518448733725, 0.00602253210672643, 0.1259383640717715, 0.0213620640715817, 0.06010875935317017, 0.024501011066604406, 2.339551798067987, 21.716594696044922, 40.41183851659298, 46.520318537950516, 37.825936675071716, 30.243893824517727, 31.81978516280651, 38.58792118728161, 13.428611475974321, 1.6378381079994142, 0.08839818197884597, 0.7226782932411879, 2.0535012474283576, 5.973100885748863, 7.744642300531268, 4.525124933570623, 6.108484771102667, 14.613173212856054, 34.175658747553825, 43.96609179675579, 49.09408003091812, 52.80713438987732, 51.25487968325615, 48.033959716558456, 43.92890699207783, 39.88137178122997, 35.93994587659836, 34.243051931262016, 36.09823778271675, 43.9886511862278, 49.79608096182346, 51.770588010549545, 46.48904621601105, 46.400951743125916, 46.034301817417145, 45.43410882353783, 47.58041985332966, 44.267495423555374, 42.65106216073036, 39.2969973385334, 34.962284937500954, 36.10244795680046, 35.60917742550373, 37.10413120687008, 38.85131545364857, 41.28109507262707, 44.02817666530609, 45.207849964499474, 46.617483124136925, 45.35908184945583, 41.199619844555855, 37.09747776389122, 35.38352273404598, 35.479095205664635, 35.17261125147343, 35.20261824131012, 35.33907651901245, 35.32984301447868, 35.55051237344742, 36.58551603555679, 38.072368651628494, 39.18988488614559, 39.941047579050064, 40.81085130572319, 43.76997672021389, 44.53620180487633, 48.74401621520519, 45.11839896440506, 33.96378591656685, 50.373098999261856, 47.5926323980093, 43.38156916201115, 40.20931698381901, 41.054475232958794, 36.181643307209015, 36.66017442941666, 36.617168337106705, 35.73059991002083, 35.40525756776333, 36.78050257265568, 36.6434059292078, 36.82887017726898, 37.43294656276703, 36.19806222617626, 39.24452215433121, 47.98406079411507, 48.85953761637211, 50.831578597426414, 49.503686651587486, 49.06808562576771, 49.510742872953415, 52.47450403869152, 49.097222462296486, 48.53471204638481, 48.479645401239395, 50.697677582502365, 51.54479272663593, 49.39938224852085, 49.477677047252655, 50.81545226275921, 49.51961539685726, 43.55596840381622, 37.1675194054842, 34.91763733327389, 35.99292263388634, 41.765557676553726, 44.14329528808594, 44.25730437040329, 44.07969810068607, 41.888971254229546, 40.0012781471014, 41.403691694140434, 45.18732346594334, 48.92299421131611, 52.84082718193531, 53.54225434362888, 49.736880138516426, 43.854377791285515, 29.878049455583096, 15.25292968377471, 9.874226152896881, 7.820959305390716, 11.272933948785067, 3.418872719630599, 6.293484969064593, 4.639797555282712, 0.012628144595510093, 0.5237169319298118, 10.496233776211739, 36.768195033073425, 36.39684095978737, 35.3818242251873, 39.008699208498, 47.77534179389477, 39.86591801047325, 16.313605718314648, 1.2508948962204158, 0.04034277291793842, 0.007739849306744873, 0.012985348621441517, 0.01447186299628811, 0.029331741206988227, 0.030004162254044786, 0.06025224247423466, 0.1592135793180205, 0.031901010079309344, 0.03228441841201857, 0.026915844573522918, 0.04177833143330645, 0.04329229413997382, 0.031199290897347964, 0.05156515529961325, 0.06426100138924085, 0.05248444249446038, 0.10022308066254482, 0.040126496242010035, 0.06227139994734898, 0.02155882968509104, 0.0457596308842767, 0.021206068340688944, 0.03480675943137612, 0.036485126402112655, 0.027965560511802323, 0.015756784086988773, 0.04858806700212881, 0.06301515066297725, 0.09586803935235366, 0.06360275350743905, 0.043381285067880526, 0.01936313754413277, 0.061494219189626165, 0.04908693124889396, 0.0472658195940312, 0.047430928898393176, 0.052045592019567266, 0.02759958522801753, 3.3839267073199153, 26.24536458402872, 49.033507481217384, 51.4043864607811, 41.09213501214981, 32.664289847016335, 36.87683880329132, 41.47701635956764, 15.968352444469929, 1.8396468227729201, 0.1845638151280582, 0.5465607123915106, 2.1754576032981277, 5.707464264705777, 9.108718279749155, 8.168505281209946, 9.511919394135475, 16.76353007555008, 32.2466466575861, 46.45224139094353, 50.242910385131836, 53.36734972894192, 52.47485361993313, 50.17567299306393, 45.26853270828724, 44.021508023142815, 37.87237398326397, 37.267537638545036, 36.56922250986099, 45.15555337071419, 51.905416175723076, 51.50408171117306, 48.52096438407898, 48.98175805807114, 48.83051857352257, 45.60180902481079, 50.00600829720497, 46.95101782679558, 44.810132905840874, 42.300561368465424, 36.387413665652275, 37.44253344833851, 37.675491347908974, 39.78688605129719, 42.69396185874939, 43.880060613155365, 47.23732486367226, 47.41835854947567, 48.49872037768364, 45.938182175159454, 44.37742732465267, 38.732237443327904, 38.18784825503826, 37.94122628867626, 37.105662524700165, 36.650602743029594, 36.57845601439476, 37.63853073120117, 37.38765299320221, 37.50085651874542, 40.15491910278797, 40.49319215118885, 40.99072225391865, 41.350524947047234, 45.304132997989655, 48.0327969789505, 49.71343919634819, 48.17682445049286, 34.98047836124897, 52.41671673953533, 50.719921588897705, 46.404166370630264, 42.31048263609409, 42.875949293375015, 39.33984003961086, 40.993309915065765, 37.71800346672535, 37.01146177947521, 37.650796473026276, 39.42217782139778, 38.71666967868805, 39.41458582878113, 38.231979086995125, 37.36315570771694, 41.79071232676506, 49.027298614382744, 51.732677444815636, 50.90424209833145, 49.45391312241554, 50.00639587640762, 51.769311279058456, 54.38140131533146, 50.663969591259956, 49.97140735387802, 48.23914870619774, 50.64267173409462, 51.448521092534065, 48.23150351643562, 49.97741863131523, 53.436927795410156, 51.909865736961365, 44.272625148296356, 39.11966845393181, 35.844046622514725, 38.30859437584877, 45.054030418395996, 48.22201922535896, 47.43418090045452, 47.38960549235344, 43.29738087952137, 41.45490914583206, 42.791886404156685, 49.456299394369125, 50.8992263674736, 56.178438887000084, 54.28104110062122, 52.735363841056824, 42.52854533493519, 31.72972809523344, 17.097950130701065, 10.415871888399124, 11.200946811586618, 9.892170690000057, 3.98836906068027, 8.678638357669115, 4.611497148871422, 0.050790534951374866, 0.5487216683104634, 12.31482569128275, 42.19800867140293, 35.63817746937275, 38.641213327646255, 44.28583703935146, 54.51471336185932, 48.70238184928894, 21.145595535635948, 1.4305314444936812, 0.012361211702227592, 0.06082152540329844, 0.035725901907426305, 0.04061145264131483, 0.014805246864852961, 0.0675267331826035, 0.06806485704146326, 0.0771925832668785, 0.03824137806077488, 0.052808382533839904, 0.01416551742295269, 0.08169802080374211, 0.056511896109441295, 0.02292588796990458, 0.019419900709181093, 0.02751636264292756, 0.03211232920875773, 0.03995476698037237, 0.056246069943881594, 0.18570034008007497, 0.11078278083004989, 0.1861541485413909, 0.10100873303599656, 0.16907589073525742, 0.10325675772037357, 0.16737533354898915, 0.1380995224462822, 0.08624773487099446, 0.1595717843156308, 0.1701807853532955, 0.12157037228462286, 0.19139757030643523, 0.18494909367291257, 0.2166237635537982, 0.1237804583797697, 0.13827993854647502, 0.12371670789434575, 0.17047329543856904, 0.13135277666151524, 4.73615943454206, 31.22943364083767, 57.048436403274536, 58.832615464925766, 49.19954717159271, 41.39835298061371, 41.30108579993248, 50.033074244856834, 19.29939240217209, 2.61169770732522, 0.3035674325656146, 1.7838196246884763, 3.8783488143235445, 14.179081656038761, 15.102832987904549, 12.888403963297606, 11.706828866153955, 17.990550734102726, 36.48067966103554, 46.95325210690498, 51.95099093019962, 53.1865668296814, 56.63567595183849, 53.04767668247223, 48.35962504148483, 44.5116513222456, 41.090227514505386, 39.59362842142582, 39.65442515909672, 48.627506867051125, 54.5378503203392, 55.09569838643074, 50.963895097374916, 49.340815991163254, 49.01244521141052, 45.72196997702122, 51.07389539480209, 47.645647153258324, 47.08572439849377, 43.96153204143047, 37.25540108978748, 39.770607724785805, 39.199749156832695, 41.76949426531792, 44.33118000626564, 45.05323626101017, 49.36733476817608, 49.35719311237335, 51.51464134454727, 49.416431933641434, 47.2799813747406, 39.18407119810581, 39.564442187547684, 40.19951730966568, 37.68770009279251, 38.663901910185814, 38.64625185728073, 40.01887120306492, 40.307534113526344, 39.96115989983082, 42.515147253870964, 43.65260101854801, 45.188144221901894, 42.714366763830185, 48.05172376334667, 51.20532654225826, 52.99103692173958, 49.61274079978466, 39.606650322675705, 53.60291808843613, 52.44429565966129, 48.233870789408684, 44.21696573495865, 44.81357932090759, 42.42804832756519, 41.230386793613434, 39.196986705064774, 39.05147351324558, 39.45434309542179, 39.88762624561787, 39.367977529764175, 41.37438386678696, 39.57936018705368, 39.034325033426285, 44.46399047970772, 51.784187480807304, 55.34077003598213, 54.276283755898476, 51.189147010445595, 51.49540677666664, 52.26143427193165, 55.8615966886282, 50.628851875662804, 51.13862872123718, 49.401468336582184, 53.13689589500427, 52.44379788637161, 50.09830914437771, 50.590462535619736, 53.51502500474453, 55.289073809981346, 48.5132659971714, 41.37629896402359, 38.75468283891678, 38.705509677529335, 46.31249628961086, 49.45086948573589, 49.81898233294487, 49.36729297041893, 45.82130424678326, 44.94655318558216, 47.286631017923355, 51.639430448412895, 54.63530369102955, 59.56995449960232, 56.91299647092819, 51.810710057616234, 45.544306710362434, 33.490414917469025, 19.117289073765278, 13.471389580518007, 15.08182866498828, 19.183076843619347, 6.5102543123066425, 10.049431901425123, 5.767606012523174, 0.08058502193307504, 1.0107727185823023, 14.547412041574717, 50.23320570588112, 46.47547334432602, 49.375074952840805, 51.364587396383286, 61.94890804588795, 57.57065378129482, 26.610851772129536, 2.6348201790824533, 0.16452922689495608, 0.21466213365783915, 0.10687938090995885, 0.12927504518302158, 0.07980054957442917, 0.11889393543242477, 0.19831695448374376, 0.2429116435814649, 0.14476521086180583, 0.15359431912656873, 0.07561738966614939, 0.22113563551101834, 0.16447435249574482, 0.18113371246727183, 0.11197679996257648, 0.15681822347687557, 0.15185122203547508, 0.1239625146263279, 0.18591894709970802], [0.01998521685891319, 0.01162303729870473, 0.11125274584628642, 0.09157093008980155, 0.05742291577917058, 0.12326885145739652, 0.024921113035816234, 0.07233296317281201, 0.0320321512845112, 0.06201313255587593, 0.0374454209668329, 0.04457797222130466, 0.039429619573638774, 0.04591643184539862, 0.07307703301194124, 0.03561674682714511, 0.06274310901062563, 0.06098507990827784, 0.01545266773973708, 0.08085934940027073, 1.4511703932657838, 14.079976323992014, 38.937126249074936, 46.91412940621376, 39.712759628891945, 18.07322669774294, 25.938075073063374, 36.816866621375084, 15.869634691625834, 1.6426452063024044, 0.23154505819547921, 0.9511110512539744, 3.326098322868347, 4.661000417545438, 7.037377702072263, 7.468598987907171, 11.239588838070631, 23.444846458733082, 34.64518055319786, 41.53926461935043, 49.0157700330019, 50.253234431147575, 49.504697397351265, 45.810490027070045, 41.949699595570564, 34.89376321434975, 35.90874195098877, 36.55161425471306, 41.498112827539444, 46.23765550553799, 47.27734051644802, 47.75749795138836, 47.243537530303, 50.20284913480282, 45.31459003686905, 47.21588261425495, 47.72773414850235, 45.718485563993454, 40.72904549539089, 38.42017158865929, 33.86432625353336, 34.32817496359348, 34.913408160209656, 34.4258639216423, 34.67190831899643, 34.58350606262684, 38.62441822886467, 38.81517559289932, 37.37001433968544, 36.82936035096645, 35.094962418079376, 34.277531281113625, 33.19367744028568, 34.31782431900501, 34.77055482566357, 34.54669363796711, 34.802693501114845, 33.91989827156067, 40.1938746124506, 44.10096175968647, 44.567481726408005, 44.81849245727062, 46.39813609421253, 44.82158549129963, 45.11176072061062, 45.951945036649704, 54.08432565629482, 46.14637680351734, 30.555923581123352, 50.89858040213585, 47.27115444839001, 42.58220225572586, 35.81971272826195, 36.02628484368324, 35.973539873957634, 35.224600061774254, 34.74560536444187, 36.49172566831112, 36.268020272254944, 35.239187479019165, 34.82067413628101, 36.675856187939644, 37.927235439419746, 38.189436569809914, 37.37127587199211, 45.622023940086365, 48.56407307088375, 49.92451027035713, 50.37751816213131, 48.4381440281868, 47.46620178222656, 48.913730308413506, 49.77738216519356, 49.9814198166132, 51.47542744874954, 51.31524704396725, 49.43968288600445, 50.36262296140194, 48.95072892308235, 48.12122963368893, 50.20385608077049, 51.070141196250916, 48.96908953785896, 43.53389538824558, 35.930184200406075, 34.20636869966984, 36.18366099894047, 38.340026289224625, 38.54087211191654, 38.78789685666561, 38.06685134768486, 38.61043497920036, 46.90708078444004, 49.03766065835953, 51.451291143894196, 54.35979567468166, 49.16718050837517, 42.968964502215385, 32.27348081767559, 11.966731119900942, 4.6906359773129225, 15.089282914996147, 8.253198936581612, 1.8033325276337564, 6.901098964735866, 3.8034733571112156, 0.07561292193713598, 0.5386158730834723, 11.289135329425335, 37.55984455347061, 44.532451406121254, 34.0007009357214, 37.81373932957649, 48.903174474835396, 39.35632735490799, 21.30198374390602, 0.7350820151623338, 0.014544881050824188, 0.08309751836350188, 0.10784114492707886, 0.02870293061278062, 0.08675225428305566, 0.03832537062407937, 0.1000623611616902, 0.0451536598848179, 0.006576993419002974, 0.07070587860653177, 0.010198285381193273, 0.019158271388732828, 0.016843184384924825, 0.006590462471649516, 0.031283914286177605, 0.12376522950944491, 0.04850183686357923, 0.0576162563811522, 0.026448673743288964, 0.052105034337728284, 0.029243457174743526, 0.10432814437081106, 0.052459031358012, 0.07220053434139118, 0.022378637549991254, 0.019043592874368187, 0.00736094905732898, 0.010680754658096703, 0.028699577960651368, 0.08875298794009723, 0.015735478882561438, 0.022990799916442484, 0.025156550109386444, 0.035546146318665706, 0.02729863135755295, 0.035490603986545466, 0.0007827400236237736, 0.07120470574591309, 0.05223318839853164, 2.271210802718997, 19.195405282080173, 44.05837744474411, 54.91760194301605, 47.56880007684231, 26.20837166905403, 31.27705078572035, 45.28936319053173, 18.52974370121956, 2.012211950495839, 0.13871373870642856, 0.60524238855578, 3.1891802698373795, 5.497281868010759, 10.221126638352871, 11.64015194401145, 9.212467912584543, 20.216007716953754, 34.67329524457455, 43.99353392422199, 50.023821741342545, 52.09998853504658, 52.19634756445885, 47.45547875761986, 45.93001641333103, 38.60388793051243, 37.895051166415215, 37.05838546156883, 41.935507357120514, 48.80095615983009, 48.76876808702946, 49.58960384130478, 48.53209398686886, 50.159060284495354, 44.99661549925804, 47.53660440444946, 48.949668779969215, 47.532181441783905, 42.37786442041397, 40.1571723818779, 35.765257850289345, 36.61738112568855, 37.90736250579357, 35.712581276893616, 37.41750419139862, 36.83110065758228, 38.840980008244514, 41.00374035537243, 40.158532708883286, 38.955372869968414, 36.563720405101776, 37.01288290321827, 35.606950744986534, 37.36798904836178, 35.655770525336266, 36.669898107647896, 35.60598939657211, 36.044903844594955, 39.73486304283142, 43.71174484491348, 47.00494073331356, 47.428386211395264, 46.59419037401676, 46.70642875134945, 48.605460450053215, 48.77462737262249, 55.79779051244259, 47.4261861294508, 34.07222829759121, 51.9409366697073, 49.29687514901161, 45.1553899794817, 38.15811485052109, 38.74323025345802, 37.251544296741486, 37.3590063303709, 37.045276165008545, 40.05112387239933, 37.656815350055695, 37.052856758236885, 36.83492325246334, 37.035381495952606, 38.69283735752106, 38.6680056899786, 40.25367960333824, 48.160055950284004, 50.93462146818638, 52.106991559267044, 51.124223694205284, 47.8489438444376, 47.328204587101936, 48.974793031811714, 49.33138869702816, 50.38114316761494, 51.39771021902561, 52.036607936024666, 50.81493929028511, 51.733122020959854, 49.9524387717247, 49.2539868503809, 52.88107082247734, 52.53158837556839, 49.54629756510258, 44.31558944284916, 38.5511277616024, 35.359530821442604, 37.863193675875664, 40.560547336936, 40.99695011973381, 40.45630373060703, 41.584011018276215, 42.83001735806465, 48.85720834136009, 51.005654856562614, 53.25398661196232, 55.448828637599945, 50.19872635602951, 46.84069834649563, 33.55682015419006, 13.682896681129932, 7.232472533360124, 6.318138521164656, 11.581721529364586, 4.632116267457604, 10.523604657500982, 5.753216659650207, 0.09952664928277954, 0.5969350249506533, 12.862271815538406, 42.00685612857342, 46.5173052996397, 40.48506818711758, 43.331548646092415, 56.457313522696495, 46.51081904768944, 25.192311890423298, 0.8789208624511957, 0.09877823045826517, 0.018006513855652884, 0.04173953195277136, 0.041780910396482795, 0.06791217499994673, 0.02487358960934216, 0.08131844195304438, 0.009178228447126457, 0.03890016771038063, 0.04640547005692497, 0.061921232409076765, 0.025599018554203212, 0.010650621607055655, 0.04590295073285233, 0.05795994497020729, 0.07258715617354028, 0.01057992647474748, 0.050103272806154564, 0.024402305425610393, 0.1264422229724005, 0.11205115573829971, 0.16631324600894004, 0.12310424310271628, 0.10044868613476865, 0.2738479507388547, 0.17359778168611228, 0.11629848915617913, 0.15465671836864203, 0.1173298443609383, 0.14521300792694092, 0.24849061999702826, 0.13859113591024652, 0.24668035854119807, 0.19482525356579572, 0.060730875775334425, 0.16102937719551846, 0.13601659593405202, 0.14358573040226474, 0.17011203279253095, 2.7333025820553303, 22.68331792205572, 51.2105018645525, 60.841514468193054, 51.42542593181133, 29.789867587387562, 34.827304780483246, 48.070908933877945, 23.244680799543858, 2.6108857383951545, 0.5655871226917952, 1.4888267288915813, 8.115224540233612, 9.275761116296053, 14.979267418384552, 19.263735115528107, 17.90823955088854, 25.752878710627556, 36.99408531188965, 46.84526950120926, 51.552836894989014, 53.54417324066162, 54.05585378408432, 51.9178681075573, 47.14956097304821, 40.98055399954319, 40.09193368256092, 40.98256029188633, 45.53126960992813, 52.134673073887825, 49.01948243379593, 51.903991252183914, 47.89483778178692, 51.6578708589077, 45.16489326953888, 48.10276262462139, 51.290008798241615, 50.963944494724274, 45.07574625313282, 43.11581142246723, 37.32458397746086, 38.1233087182045, 38.93758222460747, 37.40055710077286, 38.655044585466385, 37.34566904604435, 43.23423586785793, 41.61402180790901, 41.49097681045532, 41.1324318498373, 37.74830684065819, 39.05658043920994, 37.073710039258, 40.32466359436512, 37.56084010004997, 38.02288770675659, 37.8522502630949, 37.60889612138271, 43.002091124653816, 46.4493003487587, 48.58837656676769, 51.077934578061104, 50.80808065831661, 49.01507847011089, 51.10435836017132, 51.94294296205044, 55.134300515055656, 48.60967442393303, 37.950900569558144, 53.807829692959785, 51.47372514009476, 48.32595504820347, 38.90163615345955, 40.565707460045815, 40.229680091142654, 38.91614377498627, 38.15511301159859, 40.7677236199379, 39.394260719418526, 39.20885346829891, 37.95155793428421, 38.51281061768532, 41.84038706123829, 40.93070067465305, 41.219564974308014, 51.21474243700504, 53.78281943500042, 52.70445629954338, 53.26124422252178, 50.09027257561684, 47.94624902307987, 49.35545280575752, 51.34478285908699, 51.937513053417206, 53.99893283843994, 55.18103800714016, 54.2841075360775, 53.85557033121586, 51.95846512913704, 50.628099516034126, 53.097039833664894, 55.56676670908928, 53.52696016430855, 47.4832134693861, 41.35390676558018, 37.65800088644028, 40.40907986462116, 41.77550174295902, 43.076445534825325, 42.99149729311466, 43.5592932254076, 45.63816927373409, 53.128289356827736, 53.27553905546665, 57.73206152021885, 59.35929000377655, 52.22814045846462, 47.45041362941265, 38.74399021267891, 14.121677186340094, 8.572495803236961, 21.32574386894703, 19.996354803442955, 7.200103495270014, 9.887669831514359, 5.595040172338486, 0.1362017766223289, 1.2481335131451488, 15.160435047000647, 51.82213604450226, 57.10613630712032, 45.92537306249142, 50.168099999427795, 65.24511337280273, 54.53200243413448, 31.385489366948605, 1.4896474848501384, 0.2053744820295833, 0.12571724859299138, 0.1634936043410562, 0.1761052166693844, 0.11772557234507985, 0.1326012026402168, 0.2503871783846989, 0.14260793599532917, 0.139187837485224, 0.10633707875967957, 0.20308370963903144, 0.1663279256899841, 0.0720226341218222, 0.11617060969001614, 0.2186685288324952, 0.21299510670360178, 0.13495746214175597, 0.1633215299807489, 0.1365965695003979], [0.07843523533665575, 0.10936768332612701, 0.0472824845201103, 0.036391471076058224, 0.02175029079808155, 0.031180692676571198, 0.03532716822519433, 0.03892717075359542, 0.0365734011575114, 0.04105259635252878, 0.039496891549788415, 0.04847233649343252, 0.04253470979165286, 0.029297392757143825, 0.03374264211743139, 0.06854518986074254, 0.06956529410672374, 0.019437177907093428, 0.06452297209762037, 0.03487493311695289, 0.6718727631960064, 12.140240259468555, 40.166455283761024, 47.43321195244789, 35.13671837747097, 24.242845438420773, 34.16125752031803, 32.74184748530388, 21.476267091929913, 3.0373461171984673, 0.06946128953131847, 0.33598260255530477, 1.2314905249513686, 4.760052552446723, 9.947258234024048, 9.000166654586792, 6.276211095973849, 11.505428273230791, 19.840964041650295, 42.31078281998634, 49.1619747877121, 52.69205376505852, 45.30350223183632, 44.891425743699074, 39.048946648836136, 34.85441252589226, 35.486649200320244, 37.11582697927952, 44.4236708432436, 50.52406869828701, 47.17242434620857, 47.56247341632843, 46.37886732816696, 47.85275124013424, 50.2655153721571, 46.873718574643135, 47.655819207429886, 44.138807728886604, 42.89464429020882, 39.24310863018036, 36.120914965867996, 35.63379630446434, 34.88291099667549, 34.532436802983284, 35.6857281178236, 33.35837960243225, 34.014403000473976, 33.27490568161011, 35.24785101413727, 33.4304541349411, 35.8539754897356, 34.74581815302372, 44.44540947675705, 42.12515898048878, 33.48776265978813, 35.94552777707577, 34.3647176027298, 36.6161347925663, 44.71561677753925, 48.96409660577774, 47.37896606326103, 48.07132311165333, 47.60496273636818, 48.63082028925419, 49.149427860975266, 49.24796797335148, 44.56831008195877, 41.153228133916855, 26.5444503352046, 49.657969772815704, 47.93536260724068, 41.91068708896637, 39.72237691283226, 37.91526608169079, 38.02995152771473, 36.861286237835884, 38.44828628003597, 35.96130833029747, 33.843746557831764, 35.95123127102852, 35.9999218583107, 36.21235325932503, 37.37734034657478, 36.15645445883274, 36.853629648685455, 40.50144150853157, 45.58302283287048, 48.51321280002594, 50.16499176621437, 51.14279329776764, 50.42362868785858, 51.33160136640072, 48.965643122792244, 48.18832263350487, 46.288975551724434, 44.652950540184975, 45.42505010962486, 44.5471566170454, 50.97997583448887, 51.69907204806805, 51.41093730926514, 51.14571534097195, 51.5511953830719, 49.63355228304863, 46.29018008708954, 37.98067197203636, 34.26506794989109, 38.30414101481438, 39.48852986097336, 38.31600397825241, 39.169160798192024, 39.62236627936363, 46.58756732940674, 48.47986958920956, 53.61117884516716, 52.94847160577774, 56.11087091267109, 42.77315340936184, 32.41088904440403, 14.36495153233409, 11.462721414864063, 4.824388800188899, 6.152995582669973, 5.0848467741161585, 4.678793912753463, 3.551155496388674, 0.06906115318997763, 0.574418205069378, 11.012257486581802, 40.8439627289772, 34.49310891330242, 25.64518678933382, 37.22615405917168, 50.72755537927151, 46.466878205537796, 15.805736370384693, 0.4232459591003135, 0.028909295906487387, 0.027366665890440345, 0.027598130618571304, 0.05725877497752663, 0.03274312133726198, 0.0452768675313564, 0.02839175365807023, 0.029343756577873137, 0.02928677076852182, 0.05304832629917655, 0.02883581029891502, 0.04780090064741671, 0.006716686948493589, 0.026096185138158035, 0.03858358977595344, 0.054585336401942186, 0.12642962130485103, 0.06763315715943463, 0.015450336468347814, 0.040476233334629796, 0.05216245430347044, 0.058135162325925194, 0.07781171254464425, 0.04924783999740612, 0.09231468080542982, 0.06366347603034228, 0.022857866424601525, 0.00489988809931674, 0.024334259760507848, 0.0475843642198015, 0.04108618224563543, 0.07327485989662819, 0.05914167042647023, 0.050666815222939476, 0.01619525792193599, 0.07687556004384533, 0.012627883916138671, 0.023515769207733683, 0.0399560212099459, 0.915356632322073, 15.238615851849318, 45.41924402117729, 53.360145315527916, 38.81924517452717, 25.239482559263706, 36.78680643439293, 38.96691285073757, 22.630472257733345, 3.558636107482016, 0.048634102422511205, 0.44733156042639166, 2.086287788115442, 4.332229234278202, 9.301628228276968, 9.574882965534925, 9.803966972976923, 17.375397942960262, 25.649999231100082, 44.26448978483677, 49.844874143600464, 53.30909125506878, 49.77007895708084, 47.1732185035944, 41.57582625746727, 36.953488290309906, 37.79427297413349, 39.49307061731815, 47.53186605870724, 51.40475124120712, 49.513075947761536, 48.81415665149689, 47.068085744977, 48.010514974594116, 49.36377055943012, 47.47507430613041, 49.14745196700096, 46.78763799369335, 44.42417621612549, 42.7810075879097, 36.98865160346031, 36.86105065047741, 35.75301110744476, 37.440025582909584, 37.35389560461044, 34.38639543950558, 36.4093878865242, 35.041039511561394, 36.46287761628628, 34.95767958462238, 36.34827956557274, 36.32855862379074, 42.85644493997097, 42.69768185913563, 35.20780876278877, 38.09893682599068, 36.69135555624962, 37.46708393096924, 46.71066552400589, 51.39251209795475, 50.573268458247185, 49.19686071574688, 50.84862448275089, 50.83273373544216, 51.69475927948952, 50.188466906547546, 48.678462132811546, 44.03275541961193, 29.580677412450314, 52.16885223984718, 50.55883303284645, 43.443293049931526, 40.80520860850811, 38.874748796224594, 40.311941877007484, 39.309099689126015, 40.32482698559761, 37.055763602256775, 35.931514129042625, 37.14318931102753, 37.863615453243256, 37.23926715552807, 38.31956818699837, 37.27532722055912, 37.79931530356407, 43.46512667834759, 47.12298899888992, 50.70048563182354, 52.11256965994835, 51.5138965845108, 51.73155650496483, 51.098825857043266, 49.9704460054636, 49.57262635231018, 49.28234852850437, 48.32544967532158, 47.96275153756142, 48.10977324843407, 52.97841019928455, 51.4051578193903, 52.675938829779625, 53.49007934331894, 53.40372137725353, 51.64228409528732, 48.3732321113348, 39.506381303071976, 36.31325304508209, 39.029506891965866, 41.51999965310097, 41.89981207251549, 41.774509996175766, 42.21578411757946, 49.49135631322861, 51.848012655973434, 55.818522199988365, 56.0315615683794, 56.523669362068176, 44.75366033613682, 34.964447021484375, 13.57396887615323, 9.831228610128164, 8.288764078170061, 9.425945207476616, 6.796289188787341, 7.482082564383745, 5.022046593949199, 0.07159419968957081, 0.8965320268180221, 13.663183338940144, 45.21581053733826, 41.75845205783844, 29.90076843649149, 42.96453773975372, 57.01086401939392, 54.28234443068504, 20.411824509501457, 0.6839723826851696, 0.02211536622780841, 0.05657421424984932, 0.0342226149950875, 0.06448930827900767, 0.05903026292799041, 0.03725671507709194, 0.01809378114558058, 0.01759316543029854, 0.040846071497071534, 0.01868065297458088, 0.01164406048701494, 0.03169797702867072, 0.04721299352240749, 0.019730175954464357, 0.026809025403053965, 0.04832752492802683, 0.027240868148510344, 0.0920239370316267, 0.02004638281505322, 0.14253167290007696, 0.1979678779025562, 0.16184915351914242, 0.10162795879296027, 0.1771111533162184, 0.24533653690014035, 0.17409991880413145, 0.11900875309947878, 0.08401744009461254, 0.10836186542292126, 0.08163923528627492, 0.2571223763516173, 0.17828395444666967, 0.14191735273925588, 0.19754008913878351, 0.17884984205011278, 0.14050983998458833, 0.119898053817451, 0.1537986472249031, 0.20602539007086307, 1.1016209749504924, 17.851624488830566, 54.29389201104641, 59.918627589941025, 46.7463494092226, 34.581017196178436, 44.19075854122639, 44.42489057779312, 28.100770823657513, 4.46621716953814, 0.2322624032967724, 0.7227534579578787, 4.9443132150918245, 10.971821956336498, 17.911142595112324, 16.015830896794796, 13.107377663254738, 15.465878807008266, 24.149967022240162, 47.13085077702999, 51.017411425709724, 56.04294195771217, 50.67445322871208, 49.48069028556347, 43.81039895117283, 39.73982557654381, 39.021523520350456, 41.05812683701515, 50.875055864453316, 54.91000235080719, 50.577482432127, 50.71565441787243, 49.104776456952095, 49.73766289651394, 50.733977034687996, 48.16561505198479, 50.61359569430351, 48.78596976399422, 48.203164637088776, 43.561200723052025, 38.567303493618965, 39.1780599206686, 38.01674723625183, 38.51482070982456, 39.39594402909279, 37.09564246237278, 38.585740104317665, 36.77644059062004, 38.56627754867077, 37.291803136467934, 38.61095555126667, 37.8436703234911, 46.308742091059685, 43.64989176392555, 36.27859890460968, 40.01925878226757, 36.50466397404671, 40.08734732866287, 50.17881542444229, 54.31345336139202, 53.12994986772537, 51.877727061510086, 52.21089318394661, 52.33850933611393, 52.690894827246666, 52.23193645477295, 50.11301435530186, 47.32847057282925, 33.894340842962265, 52.613382786512375, 52.82813586294651, 46.442171931266785, 44.40005511045456, 42.2656374424696, 43.3678936958313, 40.54630950093269, 42.91397765278816, 38.91115464270115, 36.93125568330288, 39.55666020512581, 39.4558972120285, 37.99258053302765, 41.01861655712128, 40.14967158436775, 39.66507978737354, 44.86294627189636, 48.31917621195316, 53.65782514214516, 54.53959062695503, 54.38518211245537, 53.96669156849384, 54.11806024610996, 52.66182258725166, 52.7874780446291, 51.159014627337456, 50.807259902358055, 49.97628629207611, 50.048759803175926, 55.872965678572655, 54.28225703537464, 54.54446956515312, 52.567367255687714, 54.57516811788082, 52.838095128536224, 52.012304440140724, 42.22869582474232, 38.593560084700584, 41.44046612083912, 44.37816068530083, 44.22304920852184, 44.71150919795036, 44.77736346423626, 51.75447687506676, 54.93280492722988, 59.43445757031441, 57.47066594660282, 60.314079970121384, 45.54415091872215, 35.630224496126175, 17.34531305730343, 17.87378679960966, 12.815271187573671, 15.494120791554451, 12.315771840512753, 8.57706980779767, 5.227524368092418, 0.207807598344516, 1.3858515419997275, 16.239842176437378, 51.69182203710079, 47.63232886791229, 40.30079707503319, 52.71049037575722, 62.85047046840191, 63.52866567671299, 22.91658740490675, 1.484218763653189, 0.16163391584996134, 0.11941245917114429, 0.2028309489833191, 0.18194256437709555, 0.12672784592723474, 0.20419558044523, 0.14106017217272893, 0.17008850671118125, 0.14895988890202716, 0.1286312023876235, 0.14013407577294856, 0.12044975155731663, 0.1708157075336203, 0.11619586497545242, 0.20752804615767673, 0.10134111129445955, 0.1543963878066279, 0.2716418425552547, 0.12229030748130754], [0.048260694529744796, 0.010450344707351178, 0.028925322585564572, 0.015287905389413936, 0.07697156426729634, 0.03685776246129535, 0.05441781511763111, 0.03283123282017186, 0.023368400943581946, 0.04917242666124366, 0.036410165776032954, 0.035815078372252174, 0.06715546638588421, 0.03294706722954288, 0.040470930689480156, 0.02686333205929259, 0.03411639881960582, 0.04577643681841437, 0.09656152440584265, 0.019703235993802082, 0.20471636031288654, 12.337106745690107, 40.338532850146294, 46.9189627468586, 41.50200001895428, 25.64426153898239, 30.747532099485397, 41.41886427998543, 23.612434566020966, 4.931014878675342, 0.04122963568079285, 1.0586748481728137, 1.8452428537420928, 4.083657497540116, 8.090651258826256, 11.68368810787797, 6.767809242010117, 15.614432785660028, 24.853590466082096, 36.58611260354519, 50.960866659879684, 50.21711736917496, 46.08994223177433, 43.10732267796993, 38.358831480145454, 35.632728561758995, 35.74900232255459, 43.026478216052055, 46.98385566473007, 50.415063947439194, 48.67050535976887, 47.63007938861847, 50.22647626698017, 47.064069360494614, 49.707629308104515, 48.538933619856834, 48.0270516872406, 45.76700896024704, 44.66830171644688, 42.569522336125374, 38.58379080891609, 34.55857180058956, 33.97859372198582, 33.34717020392418, 34.321472123265266, 34.62025389075279, 34.3269058316946, 35.71674205362797, 36.33707396686077, 34.1915038973093, 34.857171177864075, 35.75958855450153, 44.83115337789059, 40.376162230968475, 34.44659560918808, 36.786289662122726, 34.374627470970154, 41.01537153124809, 48.7512244284153, 50.25725081562996, 50.449949875473976, 49.449163377285004, 48.495577946305275, 48.38856428861618, 45.76383613049984, 46.29647634923458, 42.63208217918873, 37.56197243928909, 31.98291040956974, 42.144347950816154, 50.99895961582661, 46.00106120109558, 42.89616420865059, 42.0432011783123, 42.87434957921505, 41.329884454607964, 42.375930324196815, 41.61301486194134, 35.69828264415264, 33.89708809554577, 36.29641994833946, 35.56075282394886, 38.210335448384285, 36.3884624093771, 34.566422179341316, 35.65909914672375, 40.89873678982258, 44.546370059251785, 48.23000639677048, 48.56028847396374, 50.46340495347977, 49.06089261174202, 45.83072014153004, 46.78429417312145, 43.33444029092789, 42.59728744626045, 42.90091775357723, 42.97285169363022, 44.853207394480705, 49.70757611095905, 49.78615589439869, 50.30473306775093, 52.45281100273132, 48.56399327516556, 52.986351773142815, 45.43071560561657, 35.04436053335667, 38.05150777101517, 38.29564847052097, 39.916352704167366, 38.9306627959013, 40.44141232967377, 43.963796719908714, 48.23612026870251, 50.2682626247406, 54.12434130907059, 52.915785759687424, 43.289538100361824, 27.833612859249115, 12.210970614105463, 3.5114875249564648, 4.2723572719842196, 8.833204563707113, 4.331698687747121, 1.8561967159621418, 1.923510697670281, 0.06381645493092947, 0.8945108321495354, 11.914012748748064, 37.16180071234703, 47.10978090763092, 36.694026812911034, 41.596823930740356, 44.94355894625187, 48.595565780997276, 15.324257556349039, 0.9116084896959364, 0.07302450379938819, 0.03496957549941726, 0.14087092451518402, 0.04210726241581142, 0.03958474699174985, 0.013355281407712027, 0.015947124556987546, 0.08704575142473914, 0.03831486923445482, 0.056117003041435964, 0.0478991016279906, 0.03150925629597623, 0.03637748530309182, 0.010942161334241973, 0.0051995390367665095, 0.07861657169996761, 0.017328333742625546, 0.002471570928719302, 0.0032288431111737737, 0.03387161254067905, 0.056762077801977284, 0.06385071246768348, 0.07473491670680232, 0.07333385321544483, 0.023511594627052546, 0.00673885629112192, 0.09556266042636707, 0.027123451109218877, 0.0971679481153842, 0.03212798481399659, 0.017665068407950457, 0.07305171835469082, 0.048706239176681265, 0.050109057847294025, 0.011197819148947019, 0.019472613603284117, 0.03130907309241593, 0.033645209259702824, 0.08038340267376043, 0.5281096149701625, 15.118898525834084, 46.86832666397095, 51.863964200019836, 46.21478073298931, 30.472092479467392, 33.356418907642365, 45.141041949391365, 30.330443680286407, 5.399004416540265, 0.136161255359184, 0.7554398383945227, 3.1998367980122566, 3.3046363620087504, 7.99534572288394, 8.933872561901808, 7.5287768337875605, 13.607424180954695, 27.595943212509155, 39.49795335531235, 51.92682042717934, 52.23598703742027, 48.24519798159599, 44.990737214684486, 40.461391657590866, 38.14793139696121, 38.212873712182045, 43.91023099422455, 49.56900514662266, 52.5931640714407, 49.062287136912346, 48.72384689748287, 50.81542566418648, 48.83936069905758, 51.309053376317024, 48.18473942577839, 48.55823278427124, 47.483361661434174, 46.04714892804623, 45.24244710803032, 40.85148632526398, 36.72987028956413, 35.302385687828064, 35.66395528614521, 35.18137738108635, 35.82762770354748, 36.83975279331207, 36.6940838098526, 36.50977849960327, 35.93005880713463, 36.31601169705391, 37.69219525158405, 47.17420645058155, 42.54044629633427, 36.25187873840332, 37.91136749088764, 36.411097794771194, 43.54157097637653, 51.63053512573242, 52.02890194952488, 52.52983286976814, 51.305546164512634, 51.13010957837105, 49.80039373040199, 46.50721304118633, 46.177223548293114, 43.47775340080261, 39.860723689198494, 34.274092465639114, 45.676030442118645, 52.03691191971302, 49.08288203179836, 45.726050958037376, 43.569484278559685, 44.86592911183834, 42.089775279164314, 44.3295156955719, 42.763125747442245, 36.27620503306389, 36.13046385347843, 37.147920057177544, 36.82852819561958, 39.76308412849903, 37.15581603348255, 37.30444125831127, 37.736299484968185, 42.84487076103687, 47.04284369945526, 50.403907746076584, 51.46322250366211, 52.67914205789566, 50.58400668203831, 47.58523799479008, 48.09818007051945, 46.18215188384056, 44.832908883690834, 45.94266593456268, 45.0261665135622, 48.29188607633114, 51.68486841022968, 49.42299038171768, 49.50062021613121, 52.21584051847458, 51.866612657904625, 54.499099999666214, 45.9254452586174, 35.706501603126526, 40.59059612452984, 39.94453199207783, 42.060475051403046, 42.23079711198807, 43.29068943858147, 46.733110919594765, 50.38467317819595, 54.84729431569576, 56.38197876513004, 56.85248851776123, 45.21752804517746, 29.7092093154788, 15.861877407878637, 7.91887435130775, 6.88262103125453, 9.156831298023462, 5.414970209822059, 1.9922903319820762, 1.7900026054121554, 0.17993386747548357, 1.1247423780150712, 13.620015755295753, 41.64472036063671, 53.72484594583511, 42.89847828447819, 45.61171889305115, 51.73889771103859, 54.009500071406364, 18.74399520456791, 1.1873290571384132, 0.05655159729940351, 0.01057854793543811, 0.07042819663183764, 0.058019442949444056, 0.03563788690371439, 0.042944861415890045, 0.02412505946267629, 0.05592458270257339, 0.038464107710751705, 0.03019485895492835, 0.060112551727797836, 0.058887685227091424, 0.05916420945140999, 0.054224789928412065, 0.009596480613254244, 0.08427495049545541, 0.021805502874485683, 0.007509069673687918, 0.018074255240208004, 0.2532906975829974, 0.07744882459519431, 0.17633102252148092, 0.14497939468128607, 0.1956180008710362, 0.1348578807665035, 0.1015324518084526, 0.13036376098170877, 0.15360237885033712, 0.18764421780360863, 0.07937413378385827, 0.1421619942993857, 0.1723067564307712, 0.11433200561441481, 0.14160611084662378, 0.06692039110930637, 0.12779561831848696, 0.2512430230854079, 0.18284694553585723, 0.13037345343036577, 0.607166332192719, 17.603682093322277, 51.12790569663048, 59.94487278163433, 53.058950677514076, 35.56484520435333, 39.801169484853745, 50.819050669670105, 33.31679843366146, 7.029927726835012, 0.2139525959501043, 1.7949311784468591, 3.857112228870392, 10.614065453410149, 16.94479174911976, 16.679465286433697, 14.990055989474058, 19.37148593366146, 29.631771370768547, 38.758171051740646, 54.643720239400864, 53.97372119128704, 50.03108695149422, 47.450056448578835, 43.93317796289921, 39.512236788868904, 41.19471810758114, 47.695546075701714, 53.07734169065952, 53.46053592860699, 51.53116665780544, 50.500954538583755, 54.610741809010506, 51.63985222578049, 52.489395439624786, 50.332733765244484, 50.41033320128918, 49.232521802186966, 49.128950759768486, 48.554524183273315, 42.91304670274258, 39.16362449526787, 37.47846432030201, 37.351771518588066, 36.466373428702354, 36.806747764348984, 38.25890064239502, 38.03193502128124, 40.135532543063164, 38.20387199521065, 37.840273305773735, 39.905812069773674, 47.00515352189541, 44.437749087810516, 38.29418934881687, 40.65558023750782, 38.73247683048248, 45.71545712649822, 53.58162023127079, 54.27462324500084, 53.741629645228386, 52.64311619102955, 51.532154604792595, 49.00964476168156, 47.876465767621994, 47.81564623117447, 44.69851769506931, 40.10378524661064, 37.842537984251976, 47.761628329753876, 55.116000697016716, 52.492112293839455, 48.25500525534153, 46.132222563028336, 46.908224523067474, 46.45786888897419, 46.01047329604626, 46.37437216937542, 38.43449681997299, 36.865625604987144, 38.775577917695045, 38.6808717995882, 42.4494069814682, 38.837233409285545, 38.69543641805649, 39.06466260552406, 45.02770163118839, 48.82739134132862, 52.20686540007591, 53.64786207675934, 55.217272862792015, 52.94458821415901, 49.387466087937355, 51.697818115353584, 49.01129387319088, 47.51719884574413, 47.59882986545563, 47.7872009575367, 50.50078734755516, 53.31516332924366, 51.804098412394524, 49.53275889158249, 53.47341723740101, 52.87594489753246, 57.22089394927025, 50.4840112477541, 36.693308651447296, 42.10872866213322, 41.90948635339737, 45.64682140946388, 44.1066500544548, 45.28131902217865, 48.109290674328804, 53.58065888285637, 56.997883915901184, 59.828853607177734, 56.63898177444935, 47.69391976296902, 31.917717307806015, 15.742550510913134, 6.812409348785877, 6.806945716962218, 14.154801908880472, 12.178299017250538, 4.897967576980591, 3.3486394258216023, 0.4471843776991591, 1.4505550637841225, 17.393513470888138, 48.47443588078022, 63.40336740016937, 50.5430942773819, 52.846397683024406, 58.586806654930115, 62.71417558193207, 22.96472132205963, 1.7787438095547259, 0.11974650726187974, 0.08162894169799984, 0.21999680990120396, 0.16257246548775584, 0.09704248805064708, 0.17943122569704428, 0.16686791233951226, 0.18024320947006345, 0.12300462462008, 0.06590057630091906, 0.257283155224286, 0.08333867925102822, 0.22139316075481474, 0.11675574860419147, 0.10965024121105671, 0.21095189993502572, 0.20868533640168607, 0.05493598633620422, 0.11778252475778572], [0.014590674345527077, 0.024832305789459497, 0.07915080670500174, 0.025614178775867913, 0.04337645739724394, 0.06395313626853749, 0.007845503769203788, 0.05288493506668601, 0.052028975333087146, 0.010864776668313425, 0.08909397511160932, 0.025626279493735638, 0.016367400930903386, 0.06318021172774024, 0.017556423554196954, 0.06387863206327893, 0.10635300524882041, 0.020559802433126606, 0.07346595550188795, 0.030359137053892482, 0.11392609536414966, 5.384511519223452, 30.33390149474144, 50.29522977769375, 39.228999987244606, 24.576150253415108, 28.05122148245573, 32.43570551276207, 31.632901690900326, 7.236183034256101, 0.2283759688725695, 0.40376268269028515, 2.6376876002177596, 2.060160390101373, 4.32130909524858, 9.727778211236, 3.3324040845036507, 7.215653210878372, 16.117325350642204, 32.36385136842728, 50.067333206534386, 50.869652554392815, 46.79322749376297, 43.17417249083519, 36.2804152071476, 35.75294651091099, 41.34548641741276, 51.695838421583176, 50.32810181379318, 49.97680306434631, 48.4573519974947, 47.7075382322073, 45.26120290160179, 44.48490835726261, 47.069997042417526, 48.45969267189503, 47.382260486483574, 48.73239643871784, 46.744935885071754, 45.04689820110798, 41.43155179917812, 38.667032942175865, 33.599096685647964, 34.56091247498989, 34.88455630838871, 34.72150705754757, 33.89808364212513, 35.812189131975174, 35.82635477185249, 35.825404822826385, 35.14075756072998, 35.15390105545521, 33.154482543468475, 34.58582013845444, 35.327426344156265, 34.84495863318443, 35.06202958524227, 40.79066298902035, 50.04306010901928, 50.72442054748535, 50.86759306490421, 49.97283987700939, 50.44523052871227, 51.76064774394035, 48.08206133544445, 49.12797801196575, 46.98262073099613, 42.578672245144844, 27.194519452750683, 44.67831797897816, 51.11404024064541, 44.64447699487209, 42.29793190956116, 43.605114966630936, 45.128848403692245, 47.99676351249218, 48.52081999182701, 44.791027531027794, 38.240692019462585, 33.89101982116699, 35.867156982421875, 36.34707123041153, 36.547100096940994, 35.608641654253006, 35.92747114598751, 34.898486360907555, 36.968486085534096, 38.676156252622604, 39.594532772898674, 44.67113256454468, 46.82804122567177, 46.10877402126789, 43.053840547800064, 43.03193852305412, 41.83818697929382, 40.57440519332886, 39.017621129751205, 41.54928468167782, 45.14945849776268, 46.18617586791515, 50.89017525315285, 46.960046142339706, 51.409272998571396, 50.437763929367065, 51.059817150235176, 46.622901633381844, 36.82496398687363, 37.445455491542816, 38.07868771255016, 38.30461598932743, 41.56468905508518, 41.92556329071522, 43.54535557329655, 45.089505314826965, 50.38575232028961, 52.334793135523796, 55.528647154569626, 40.97632862627506, 29.330225251615047, 12.33929542824626, 8.994426112622023, 6.375215733423829, 7.709046760573983, 5.340070528909564, 1.1376892332918942, 0.6854307325556874, 0.056562755489721894, 0.851127253845334, 13.00663746893406, 46.88817299902439, 42.177174389362335, 28.111828230321407, 37.44265504181385, 46.84098333120346, 46.03765703737736, 16.10950157046318, 0.45968754740897566, 0.09387450452777557, 0.025129730747721624, 0.06116616023064125, 0.057488057791488245, 0.042214361747028306, 0.03882026067003608, 0.0227140363494982, 0.04367026253021322, 0.023951231778482907, 0.009276662276533898, 0.07540578852058388, 0.0489471588662127, 0.028604271356016397, 0.04190581385046244, 0.06616567887249403, 0.013471818074322073, 0.05574409238761291, 0.0278715934837237, 0.024881027784431353, 0.0221203256296576, 0.06047474205843173, 0.03617346519604325, 0.06568743148818612, 0.07385763878119178, 0.06964127518585883, 0.0337340294936439, 0.05277439959172625, 0.045651863620150834, 0.0513303917250596, 0.025538728332321625, 0.053776295244460925, 0.08741875484702177, 0.11384953540982679, 0.03276762334280647, 0.015522580833930988, 0.06187761639012024, 0.017173362175526563, 0.10731924441643059, 0.0483951457135845, 0.14431404444621876, 7.997607551515102, 37.36802324652672, 56.371312737464905, 45.859993770718575, 26.33373074233532, 29.90514200180769, 37.80559256672859, 32.39022575318813, 8.260288406163454, 0.2118231070926413, 0.3299988142680377, 0.8110224839765579, 3.5806927364319563, 5.863021267578006, 10.696878209710121, 10.573839861899614, 12.134049441665411, 25.003999695181847, 37.28684060275555, 51.18593618273735, 53.15875992178917, 50.09215347468853, 45.75203396379948, 38.916048780083656, 38.28133083879948, 43.226716071367264, 51.72862306237221, 52.36668482422829, 49.91292089223862, 49.247895777225494, 50.096857622265816, 48.753485307097435, 46.90302260220051, 48.637918308377266, 48.90368364751339, 48.01572069525719, 49.27750378847122, 49.51448567211628, 46.47401042282581, 43.854480385780334, 40.2532996237278, 35.39449654519558, 35.524381175637245, 37.49539241194725, 36.25643849372864, 35.820423290133476, 37.727810740470886, 36.699498519301414, 35.82546181976795, 36.28285467624664, 36.8666173517704, 35.461327359080315, 36.14252060651779, 35.875106155872345, 36.019228622317314, 35.187111273407936, 42.39770695567131, 50.16388602554798, 52.53230273723602, 53.136272728443146, 50.938451662659645, 50.20064525306225, 51.826308220624924, 48.73423554003239, 48.5164388269186, 45.93651406466961, 42.58745737373829, 29.592591673135757, 46.97833836078644, 53.54527898132801, 46.91568732261658, 45.46089358627796, 47.08154462277889, 47.262851893901825, 49.36968304216862, 49.72556434571743, 47.27376110851765, 40.40837310254574, 36.040967255830765, 36.647395715117455, 37.21652537584305, 37.767856791615486, 37.23854139447212, 38.066049590706825, 36.819792464375496, 38.18781025707722, 39.21639606356621, 43.90803851187229, 47.23651930689812, 49.068332612514496, 49.02643986046314, 44.597598910331726, 45.97356207668781, 43.523316755890846, 43.08376394212246, 41.95681281387806, 44.73145812749863, 46.36059410870075, 49.77948725223541, 51.95185348391533, 47.68957659602165, 51.63697578012943, 50.4018634557724, 54.11970555782318, 49.74473811686039, 39.13370490074158, 40.18234223127365, 40.2576769888401, 41.26557670533657, 42.064822018146515, 43.28979268670082, 45.27495816349983, 49.109913781285286, 52.55648083984852, 55.52273467183113, 56.8450903147459, 43.689888417720795, 28.486820608377457, 14.401950147002935, 7.297982918098569, 9.166203495115042, 13.055511396378279, 4.993685390800238, 1.628889231942594, 0.8018391486257315, 0.11183156908373348, 1.0308031062595546, 15.948395915329456, 50.36334492266178, 51.71912357211113, 34.47470650076866, 44.01778422296047, 52.502394542098045, 53.230401277542114, 21.056456118822098, 0.6802401517052203, 0.09236967394826934, 0.044182325873407535, 0.013261814401630545, 0.011111179901490686, 0.03587804960261565, 0.027325181690684985, 0.07869002205552533, 0.02286645492858952, 0.0445703058358049, 0.08047544382861815, 0.02946806445834227, 0.021704303617298137, 0.028790804608433973, 0.04074873882927932, 0.025154206778097432, 0.04875433776760474, 0.10710863032727502, 0.05974199368210975, 0.027548657199076843, 0.14345858566230163, 0.16806744562927634, 0.15686923870816827, 0.16423055698396638, 0.11491951940115541, 0.2074265797273256, 0.21140449127415195, 0.08144409497617744, 0.13834440149366856, 0.17796897212974727, 0.15614364092471078, 0.1712696347385645, 0.0945999390387442, 0.2381261417758651, 0.11673700195387937, 0.17201454320456833, 0.3367285500280559, 0.10882708811550401, 0.1730179417063482, 0.1811029578675516, 0.3735092404531315, 9.487449657171965, 41.82696998119354, 61.44110709428787, 52.75380425155163, 34.78022910654545, 38.535977974534035, 44.27923299372196, 40.64727008342743, 9.577546622604132, 0.44674805423710495, 0.855201407102868, 5.103964023292065, 7.0361498929560184, 15.383648369461298, 19.783980399370193, 12.888389714062214, 9.802093673497438, 18.921128399670124, 36.34530432522297, 54.40831907093525, 56.41043163836002, 52.33832314610481, 47.11295373737812, 40.33900782465935, 40.43136186897755, 45.34579396247864, 57.335746586322784, 54.43464785814285, 50.988008603453636, 50.17858363687992, 51.41667500138283, 49.25874039530754, 48.91735911369324, 49.71418395638466, 51.419570446014404, 50.05235441029072, 52.459905222058296, 52.61783614754677, 50.673488080501556, 46.59409157931805, 43.82093198597431, 37.20658890902996, 37.65652656555176, 39.247751981019974, 37.77836322784424, 37.52806305885315, 39.64049510657787, 39.82793524861336, 39.34036821126938, 37.97225162386894, 38.855430632829666, 36.72656826674938, 37.39286631345749, 38.204297572374344, 39.1711138933897, 37.825507298111916, 43.7268490344286, 53.624063953757286, 53.78882311284542, 55.91388188302517, 53.17302815616131, 51.01630948483944, 53.86873282492161, 50.30817188322544, 49.93119031190872, 47.17496261000633, 44.63699899613857, 33.18466432392597, 50.355038568377495, 54.90852043032646, 49.1980766505003, 46.866833344101906, 49.60924878716469, 50.70565715432167, 52.293177768588066, 52.458753883838654, 48.863299414515495, 42.64023654162884, 37.33615055680275, 39.48766730725765, 40.08317895233631, 40.666842833161354, 39.257597252726555, 38.65869618952274, 38.91777768731117, 40.94740837812424, 41.47426150739193, 44.13883052766323, 48.58249068260193, 51.66724115610123, 51.71280451118946, 46.62099413573742, 46.988077238202095, 46.048528254032135, 45.66831685602665, 43.61441306769848, 46.653482392430305, 50.16196712851524, 51.951712891459465, 55.04216305911541, 47.8214181214571, 52.8754623234272, 51.90967954695225, 55.39164550602436, 52.39203326404095, 41.1139952391386, 40.97966484725475, 43.19216072559357, 43.50899152457714, 45.713074654340744, 46.891049444675446, 48.5707189142704, 50.40953904390335, 56.09839618206024, 57.68180541694164, 61.288495883345604, 45.05369983613491, 34.7993078827858, 15.179451126605272, 13.188352268189192, 14.832688383758068, 19.600055068731308, 12.799541931599379, 5.910707758739591, 1.8563711503520608, 0.17601415514945984, 1.4152293093502522, 19.261223450303078, 59.1711089015007, 51.9568882137537, 40.87769351899624, 50.51876038312912, 61.63722977042198, 61.13058015704155, 26.430272161960602, 1.0300429095514119, 0.20713601406896487, 0.17126178281614557, 0.12994161254027858, 0.13043267681496218, 0.1706060953438282, 0.11814369092462584, 0.10778452648082748, 0.13062372046988457, 0.15511264937231317, 0.11839731247164309, 0.11338279873598367, 0.16748466674471274, 0.13669098552782089, 0.058563047568895854, 0.1811651498428546, 0.11308243672829121, 0.14091261837165803, 0.1620119361905381, 0.06166852741444018], [0.03316940725198947, 0.014810803695581853, 0.04809983402083162, 0.015848743605602067, 0.05406377727922518, 0.01987857209314825, 0.0473159702232806, 0.05175457365112379, 0.03885291516780853, 0.016159686783794314, 0.020065691642230377, 0.03718736508744769, 0.02436373230011668, 0.010826076450030087, 0.03883131495967973, 0.008593346501584165, 0.0840327209152747, 0.10162907201447524, 0.050755141928675584, 0.0150650672003394, 0.1771502644987777, 3.891527457162738, 29.2783048376441, 45.207808166742325, 44.16817255318165, 37.79850594699383, 23.18968065083027, 43.39705713093281, 37.416478246450424, 8.960134852677584, 0.6142679136246443, 0.272352701285854, 0.8522655896376818, 1.3732156762853265, 3.571610748767853, 7.283191736787558, 8.671813923865557, 10.791119802743196, 22.592143714427948, 35.48542946577072, 44.580370634794235, 52.04084470868111, 46.07102304697037, 43.36012311279774, 36.17885425686836, 36.980782225728035, 45.432991683483124, 52.605536207556725, 51.983577981591225, 49.92114745080471, 47.37904965877533, 46.64972059428692, 42.01212264597416, 43.197852820158005, 41.76448993384838, 45.79238399863243, 49.23475608229637, 47.44219847023487, 47.783537954092026, 47.10514135658741, 43.721445724368095, 38.013483211398125, 34.0181116014719, 36.03119418025017, 35.11508233845234, 36.28909774124622, 36.44641689956188, 39.51691813766956, 40.84933564066887, 40.90428069233894, 38.019289299845695, 34.73378799855709, 35.90050399303436, 35.541256070137024, 35.002159997820854, 35.85111044347286, 34.912773594260216, 37.824435755610466, 43.79727065563202, 47.121499478816986, 48.32338638603687, 50.770694464445114, 48.57598163187504, 50.49304336309433, 50.70721127092838, 50.450660437345505, 47.580279260873795, 48.94384369254112, 29.0138029307127, 41.01658746600151, 47.04014964401722, 49.474238231778145, 47.14403606951237, 47.32434019446373, 47.98127934336662, 50.74429728090763, 49.37849476933479, 47.479368075728416, 40.901529639959335, 35.18217533826828, 36.172159016132355, 35.659414529800415, 36.06287308037281, 34.800926595926285, 35.46653687953949, 36.743481159210205, 35.75156718492508, 35.64622163772583, 35.26821792125702, 37.20289170742035, 38.989939615130424, 39.50937174260616, 36.415326967835426, 36.87138229608536, 36.40579707920551, 36.60890758037567, 36.67466305196285, 40.5963072180748, 42.6017864048481, 45.6548997759819, 50.61158560216427, 49.30558428168297, 48.28862965106964, 49.5820726454258, 52.31946475803852, 43.55643957853317, 37.4969807267189, 37.75753274559975, 38.493462055921555, 37.33503721654415, 39.4736460596323, 39.95989836752415, 41.40824005007744, 45.06090424954891, 51.51931129395962, 52.72855840623379, 53.1756804138422, 43.25145274400711, 24.643264152109623, 13.564309794455767, 6.035020938143134, 8.402977399528027, 8.869566712528467, 2.4677345948293805, 0.5617819237522781, 0.29754992108792067, 0.03584480880817864, 1.443216826301068, 13.582691308110952, 38.33979070186615, 43.722251281142235, 32.40776941180229, 43.27485948801041, 46.70571818947792, 45.433576852083206, 14.478063862770796, 0.24786029913229868, 0.09079653609660454, 0.06932414806215093, 0.07736278741504066, 0.04187590900983196, 0.052613182851928286, 0.01140286898589693, 0.0255294830276398, 0.024813709424051922, 0.0781781628029421, 0.0720572924183216, 0.07092684565577656, 0.053341949605965056, 0.03706606847117655, 0.07885552098741755, 0.0457294217630988, 0.02448033668770222, 0.02034301738603972, 0.01239977276782156, 0.09084456047276035, 0.047865055603324436, 0.02573650697740959, 0.02454353241773788, 0.03938323905458674, 0.015023722153273411, 0.025070073206734378, 0.011132820927741705, 0.09152257174719125, 0.038782477931817994, 0.03416995961742941, 0.06270678830333054, 0.044775932692573406, 0.02124140941305086, 0.05861775127414148, 0.028986746438022237, 0.04896864033071324, 0.11585875923628919, 0.034240975728607737, 0.06790750689106062, 0.03755310288397595, 0.1432947491412051, 4.985543377697468, 35.16216941177845, 51.48862414062023, 49.38466563820839, 40.51851399242878, 27.714289762079716, 45.134859681129456, 43.47665525972843, 9.249052349478006, 0.681871926644817, 0.3756891656666994, 0.698846090817824, 2.5380797451362014, 4.63568807579577, 8.00495920702815, 11.513788774609566, 13.705674558877945, 22.39887658506632, 36.9583710283041, 48.44801589846611, 54.42297488451004, 48.14064659178257, 45.15204235911369, 38.599373772740364, 39.84059616923332, 47.17175178229809, 54.11515720188618, 52.03365549445152, 51.21563158929348, 49.43246707320213, 48.43116380274296, 45.39599686861038, 45.90958870947361, 44.28364455699921, 47.791718915104866, 50.75068473815918, 48.600554913282394, 47.270972058176994, 50.2494840323925, 45.82060508430004, 39.59139794111252, 35.99513031542301, 37.64497138559818, 35.93430697917938, 37.86260470747948, 37.440325766801834, 40.23851461708546, 42.168427258729935, 42.522290870547295, 37.97282539308071, 36.01241938769817, 37.427832037210464, 37.70945392549038, 36.74334056675434, 37.70914614200592, 35.89147187769413, 38.76805052161217, 45.56165277957916, 49.88265551626682, 49.62978668510914, 52.03857623040676, 50.593703761696815, 52.171177715063095, 51.93308249115944, 52.14696541428566, 47.49852664768696, 49.179381653666496, 31.90488539636135, 43.28794978559017, 49.9269725382328, 51.55284069478512, 48.97712230682373, 49.960726127028465, 49.833041578531265, 53.291878178715706, 51.3248111307621, 50.444048792123795, 41.87432684004307, 36.04271896183491, 37.91002996265888, 37.52166420221329, 38.350635319948196, 37.865028977394104, 36.58719174563885, 37.892702892422676, 36.98952555656433, 37.68130123615265, 37.33056105673313, 40.50529070198536, 41.34457066655159, 42.15729005634785, 39.79297332465649, 39.877385795116425, 38.75805325806141, 38.31139862537384, 39.48004491627216, 43.11487287282944, 45.48494249582291, 48.5512525588274, 53.04845944046974, 49.26409050822258, 48.86305622756481, 51.01952411234379, 52.27984808385372, 48.002812787890434, 40.07887378334999, 39.67869445681572, 39.596736654639244, 39.57950837910175, 40.27314215898514, 42.59999290108681, 43.79729725420475, 48.579333052039146, 54.097165167331696, 56.66910655796528, 56.302616223692894, 46.36479288339615, 26.531618423759937, 12.829443477094173, 7.4168414901942015, 10.758776888251305, 8.692177031189203, 3.9998282957822084, 2.549996618181467, 0.35315797780640423, 0.06632785298279487, 1.5817093010991812, 16.276187226176262, 49.5884221047163, 42.7136068046093, 33.16004924476147, 50.38108617067337, 52.62539014220238, 53.46725396811962, 17.022047303617, 0.35433184762950987, 0.06592740493942983, 0.06856712032458745, 0.11841464904136956, 0.039347716156044044, 0.03996953942987602, 0.05049893028626684, 0.02501945502444869, 0.03761765859962907, 0.021673487790394574, 0.03368977893842384, 0.011040996851079399, 0.07765399874188006, 0.05197811966354493, 0.03702411486301571, 0.04741490221931599, 0.06653492702753283, 0.03303376121039037, 0.025025792965607252, 0.02464077788317809, 0.1234557168208994, 0.156830127525609, 0.14823720033746213, 0.11493631420307793, 0.21968494460452348, 0.12985443987417966, 0.08273915751487948, 0.15557678852928802, 0.14785690902499482, 0.1078446775500197, 0.23017114988761023, 0.16473723604576662, 0.07608963307575323, 0.16553044348256662, 0.13475202082190663, 0.12310533405980095, 0.22213051415747032, 0.22577732393983752, 0.11909762528375722, 0.07832795788999647, 0.4293640167452395, 6.276350263506174, 41.18340611457825, 58.641972094774246, 55.60181222856045, 48.97120222449303, 32.57734291255474, 52.993392795324326, 47.1968000382185, 12.743147257715464, 1.0412742756307125, 0.6696668034419417, 2.6292575150728226, 5.493358578532934, 12.525927163660526, 14.924454409629107, 12.99844890832901, 14.466431736946106, 27.627428323030472, 40.86395725607872, 49.7952526062727, 56.53357543051243, 51.16483211517334, 48.775470927357674, 39.75721724331379, 41.60225383937359, 50.7931474596262, 56.46902069449425, 52.77872331440449, 52.09294371306896, 51.12390071153641, 51.993620842695236, 46.98435723781586, 48.1323516368866, 46.17334395647049, 50.58808386325836, 52.55610466003418, 50.95563814043999, 50.40925405919552, 53.01777608692646, 47.74273194372654, 41.40686072409153, 37.55379907786846, 40.47195129096508, 37.188824862241745, 41.07251286506653, 39.51402269303799, 43.55309195816517, 45.292197838425636, 46.04176081717014, 41.54207646846771, 38.662864565849304, 39.69716526567936, 38.95432412624359, 37.64763504266739, 40.53025156259537, 38.09319533407688, 40.75636602938175, 46.710068956017494, 50.7636496424675, 52.40100458264351, 53.42784248292446, 53.09080436825752, 53.89982655644417, 54.299675300717354, 55.832988023757935, 49.42062310874462, 48.976062163710594, 35.053715631365776, 45.015888065099716, 49.894507080316544, 53.55113826692104, 50.73213033378124, 51.436198353767395, 52.11247846484184, 54.63921748101711, 53.40231545269489, 51.458100378513336, 44.91731755435467, 38.47661755979061, 40.34502670168877, 38.17765340209007, 39.505849331617355, 38.46935614943504, 39.36673119664192, 40.308263674378395, 39.089524671435356, 39.277508184313774, 39.05193328857422, 42.31206335127354, 43.19546654820442, 42.67294518649578, 39.914714992046356, 40.672314539551735, 41.001722663640976, 40.155899450182915, 40.61297692358494, 46.45340792834759, 48.75934079289436, 51.02469943463802, 55.53318411111832, 50.13815000653267, 49.02995467185974, 54.231126978993416, 56.162266954779625, 49.65043857693672, 42.88748547434807, 41.519646272063255, 42.73001812398434, 40.50441674888134, 43.52150805294514, 45.79267278313637, 45.983570739626884, 51.42332084476948, 57.955569326877594, 60.18877029418945, 60.35084679722786, 48.02941896021366, 28.109422959387302, 16.08086820691824, 10.399583112448454, 16.46743856370449, 14.950348120182753, 7.295288387686014, 3.401235966011882, 0.7984579238109291, 0.21136964001925662, 2.2468239488080144, 18.465565145015717, 53.946997225284576, 53.42489764094353, 45.56248493492603, 55.13352915644646, 59.15124736726284, 59.93409276008606, 21.867535896599293, 0.9083575266413391, 0.15014441596576944, 0.18886476871557534, 0.24346521153347567, 0.1603685985901393, 0.18793997849570587, 0.16063974966527894, 0.18265403166878968, 0.1546815803158097, 0.15334727300796658, 0.1358972882735543, 0.12508916901424527, 0.14922844246029854, 0.1562543396721594, 0.1565990672679618, 0.12693950644461438, 0.2541062288219109, 0.11321717363898642, 0.14259479998145252, 0.10279410285875201], [0.040625449546496384, 0.04188833998341579, 0.029255875160743017, 0.022935166671231855, 0.044295648112893105, 0.049640421275398694, 0.08955059631261975, 0.0265133574794163, 0.038325389177771285, 0.03584581812901888, 0.05085474556835834, 0.03812444527284242, 0.0039830634432291845, 0.03776060737436637, 0.06548226476297714, 0.03733052908501122, 0.026547642846708186, 0.02395001836703159, 0.033089348071371205, 0.030919846321921796, 0.08646008558571339, 1.8384976219385862, 22.571501322090626, 51.57475031912327, 44.104943946003914, 27.54129834473133, 19.67102576047182, 21.90164476633072, 32.56597012281418, 14.801165275275707, 0.7382591790519655, 0.08009389086510055, 0.3678244783077389, 2.1320636942982674, 2.9303229600191116, 7.839293796569109, 18.31630915403366, 17.42374274879694, 21.06735773384571, 34.55331288278103, 45.13004153966904, 51.15423448383808, 45.70737116038799, 44.61766563355923, 36.96253560483456, 40.19906513392925, 48.87209974229336, 50.768387988209724, 48.925384283065796, 49.300796538591385, 47.96109862625599, 42.75336407124996, 40.30470706522465, 38.86249825358391, 40.17325311899185, 43.66695664823055, 47.42444582283497, 48.284628465771675, 47.39397905766964, 45.34437283873558, 44.846903532743454, 37.71377429366112, 32.94541776180267, 34.96454581618309, 37.88794554769993, 37.39016845822334, 39.178732484579086, 43.84704798460007, 46.635748744010925, 49.586495608091354, 47.15025633573532, 41.24456383287907, 37.1088657528162, 34.830124229192734, 34.38188888132572, 35.464800372719765, 35.5636178702116, 36.23139403760433, 37.602064087986946, 41.668434888124466, 44.59700234234333, 44.70242388546467, 44.04920853674412, 44.79971766471863, 47.87054568529129, 49.833539351820946, 49.5391121506691, 53.559748604893684, 29.27704520523548, 41.945394426584244, 44.09914545714855, 46.397752314805984, 48.02518978714943, 47.90527582168579, 50.97007356584072, 49.49048615992069, 48.76832731068134, 48.24886858463287, 43.36443968117237, 35.65705105662346, 35.572410598397255, 35.190386697649956, 35.662784948945045, 36.40124872326851, 36.11259341239929, 35.85693933069706, 34.97609339654446, 34.55773584544659, 35.260933712124825, 35.71297645568848, 33.53866092860699, 37.37260580062866, 37.58392386138439, 36.35334849357605, 35.00681854784489, 36.165034398436546, 35.958842262625694, 40.88721960783005, 45.068557038903236, 46.24672181904316, 49.27813835442066, 51.23444437980652, 51.07874393463135, 51.49095341563225, 49.906856417655945, 45.45420214533806, 40.05723774433136, 41.428808346390724, 41.55549734830856, 39.986325949430466, 37.417644783854485, 38.258570060133934, 41.954536736011505, 46.98786064982414, 48.38924825191498, 52.89908565580845, 52.44599796831608, 41.60598523914814, 20.506238043308258, 10.075328461825848, 4.159088674932718, 6.475157970562577, 10.546545926481485, 3.2884361688047647, 1.5853771730326116, 0.4174411471467465, 0.028175226507300977, 1.051557355094701, 17.611338682472706, 37.344027534127235, 46.970936357975006, 30.621861442923546, 39.18905273079872, 50.938048884272575, 41.38689659535885, 15.637111868709326, 0.5540353863034397, 0.06696994430967607, 0.023248510697158054, 0.017875645389722195, 0.08357488259207457, 0.03381129448825959, 0.021048634698672686, 0.017409272368240636, 0.01708020965452306, 0.03445891852607019, 0.027512765082065016, 0.04754185771162156, 0.04682123602833599, 0.022424932722060475, 0.03421965753659606, 0.07422111302730627, 0.007016718700469937, 0.056255595409311354, 0.03232694718462881, 0.028736308704537805, 0.018327758043596987, 0.01462022202758817, 0.05033807348809205, 0.07984121926710941, 0.016934130871959496, 0.047745454794494435, 0.07027374085737392, 0.09913367466651835, 0.05125810654135421, 0.021190167826716788, 0.049066796782426536, 0.050800539102056064, 0.0662160558567848, 0.06128732697106898, 0.04160193777352106, 0.03842076628643554, 0.022958520203246735, 0.03388411772903055, 0.00788212040788494, 0.04568802847643383, 0.1804472110234201, 3.083410570397973, 28.496888168156147, 56.037721037864685, 49.28930215537548, 35.10468229651451, 26.26371569931507, 29.38327420502901, 37.85528250038624, 16.99663996696472, 0.825928965350613, 0.12566783640068024, 0.3213909105397761, 0.9915119083598256, 5.687180953100324, 6.926890555769205, 10.666010566055775, 13.434162978082895, 18.38384672999382, 33.837324902415276, 49.685024321079254, 52.65393801033497, 48.576278015971184, 46.113090589642525, 39.25156697630882, 43.326008543372154, 50.13155356049538, 54.539070054888725, 49.85060043632984, 51.88289098441601, 51.31033390760422, 44.956314861774445, 42.44475983083248, 42.536559104919434, 41.79553046822548, 47.38603748381138, 51.75611458718777, 49.68839854001999, 50.05746133625507, 48.247113078832626, 47.88622744381428, 39.734361469745636, 34.660353139042854, 36.7235816270113, 40.18891587853432, 39.63749706745148, 39.15985509753227, 45.21400943398476, 49.89010691642761, 49.22292351722717, 46.811831295490265, 41.744453608989716, 37.50181786715984, 36.470507606863976, 37.31437012553215, 38.465928733348846, 37.73815378546715, 37.88348838686943, 40.17416886985302, 44.80599872767925, 48.24474960565567, 47.879372611641884, 47.96100363135338, 46.9975995272398, 50.5531295388937, 52.01884388923645, 51.39025501906872, 53.567655980587006, 31.504970155656338, 44.399355947971344, 47.07018323242664, 48.840591832995415, 48.829872608184814, 49.8268973082304, 51.6851381957531, 51.67215049266815, 51.00717477500439, 51.44915945827961, 44.967129081487656, 38.59100662171841, 37.00872212648392, 37.18019172549248, 36.95929817855358, 37.69260562956333, 37.62541763484478, 39.17944684624672, 37.028640657663345, 35.001012459397316, 37.38488294184208, 37.22057215869427, 36.172398403286934, 40.13714745640755, 39.0253347158432, 37.24849306046963, 36.527215763926506, 39.17418792843819, 38.015291914343834, 43.44243049621582, 46.94299265742302, 47.89530895650387, 50.714810863137245, 51.4616683870554, 52.01766215264797, 52.26517327129841, 51.86323843896389, 47.540533393621445, 41.87089562416077, 41.657559871673584, 43.496748581528664, 42.320954874157906, 40.35429820418358, 41.17949612438679, 44.58116099238396, 49.6287227421999, 51.020842641592026, 55.83548069000244, 55.21393284201622, 43.7933112680912, 25.151543878018856, 12.687641736119986, 9.38303031027317, 9.882035683840513, 6.273846197873354, 3.8460909202694893, 1.0321344598196447, 0.16329353617038578, 0.04050542200275231, 1.5387364570051432, 19.594340175390244, 41.95455573499203, 51.40348970890045, 37.802336141467094, 46.66937313973904, 57.59239241480827, 47.38332062959671, 18.586738742887974, 0.535536672687158, 0.0690188656153623, 0.03460154446656816, 0.027777622744906694, 0.04745252910652198, 0.039599322772119194, 0.04639303166186437, 0.034241881148773246, 0.025372778545715846, 0.04872017671004869, 0.01667278542299755, 0.09192501616780646, 0.09356607537483796, 0.028453880695451517, 0.019164002624165732, 0.036119633514317684, 0.05352960906748194, 0.01585906316904584, 0.055845120950834826, 0.09819882834563032, 0.08192850960767828, 0.12022617214825004, 0.09050038948771544, 0.10328280710382387, 0.08458572483505122, 0.10907828283961862, 0.2132764845737256, 0.15351174777606502, 0.20981353445677087, 0.10436851720442064, 0.1053207520453725, 0.1285453062155284, 0.12302753471885808, 0.11970173349254765, 0.1997994093107991, 0.1425955124432221, 0.14383461704710498, 0.13102238735882565, 0.11346631261403672, 0.1499996823258698, 0.2093386193155311, 4.347909092903137, 34.75887805223465, 63.57788443565369, 55.839272886514664, 40.54988130927086, 31.591955088078976, 31.25665917992592, 43.56408856809139, 18.951431773602962, 1.577726046089083, 0.30932204565033317, 0.6653868674766272, 7.357214139774442, 8.165037967264652, 13.933953009545803, 28.647734373807907, 24.22180786728859, 27.223074920475483, 38.435279577970505, 50.971243903040886, 55.084409192204475, 52.18677967786789, 48.68124358355999, 42.417724281549454, 44.78651337325573, 53.48919779062271, 55.90545013546944, 50.672560930252075, 52.337133809924126, 54.536934569478035, 47.14533559978008, 44.272039979696274, 44.19252544641495, 44.1186536103487, 48.16737815737724, 54.36426043510437, 52.73029491305351, 51.49361327290535, 50.95977611839771, 50.979493260383606, 41.7037957906723, 36.74173325300217, 39.59444917738438, 41.915186047554016, 40.79155974090099, 42.3635695874691, 48.24934735894203, 50.489893332123756, 52.86348536610603, 49.87355500459671, 44.97553803026676, 39.80110488831997, 38.55572551488876, 39.679762199521065, 39.17583703994751, 40.51606312394142, 38.9826326072216, 42.142710238695145, 44.82771456241608, 48.90196993947029, 48.868448138237, 48.516321033239365, 49.77775074541569, 53.438014537096024, 54.01144556701183, 54.00385357439518, 55.345257595181465, 36.60358026623726, 46.4657648652792, 50.3702187538147, 49.30633284151554, 51.03699937462807, 50.479747876524925, 55.261658281087875, 52.429427057504654, 53.20943780243397, 53.74519385397434, 47.71663874387741, 39.94280308485031, 39.875447899103165, 39.62421678006649, 39.15453538298607, 39.207322150468826, 40.001297146081924, 40.59086211025715, 39.53825019299984, 37.718128859996796, 39.17812831699848, 40.17942778766155, 36.76989734172821, 42.06256493926048, 41.52101419866085, 39.20270159840584, 40.024065524339676, 40.99807485938072, 40.310965329408646, 46.194622814655304, 49.998233914375305, 51.75396390259266, 51.99678987264633, 53.26758608222008, 52.52123773097992, 54.52114261686802, 54.56830948591232, 49.60864081978798, 44.746790304780006, 44.81688514351845, 46.620211377739906, 45.45544847846031, 41.92999765276909, 43.810900524258614, 46.99270159006119, 53.867684081196785, 52.17682421207428, 59.91184875369072, 57.71188460290432, 44.226180240511894, 23.106900192797184, 12.846557758748531, 8.263116404414177, 14.043389037251472, 21.818624921143055, 12.261523101478815, 3.265825482085347, 0.7240810710936785, 0.22506912209792063, 1.9357587466947734, 23.50398648530245, 51.79080292582512, 60.88330842554569, 43.204901441931725, 53.82815480232239, 63.87543886899948, 56.32432445883751, 21.591967083513737, 1.159815089777112, 0.20010956766782328, 0.11823719411040656, 0.11572610033908859, 0.16991877753753215, 0.10415607743198052, 0.21336137142498046, 0.0999696966027841, 0.09904385995469056, 0.17012748430715874, 0.07194476798758842, 0.1457557998946868, 0.19017906772205606, 0.12494269874878228, 0.1998586326953955, 0.15942087600706145, 0.11392176122171804, 0.1345112978015095, 0.10262156836688519, 0.1910277729621157], [0.05616543930955231, 0.01600008978130063, 0.05391208971559536, 0.06119086632679682, 0.031947383176884614, 0.09026032697875053, 0.05895914291613735, 0.016978654166450724, 0.057207878489862196, 0.024149127311829943, 0.022617414288106374, 0.03493391901429277, 0.06411812311853282, 0.021158203526283614, 0.026546742992650252, 0.0136812243181339, 0.03890617910656147, 0.04503921700234059, 0.08582797614508308, 0.029122616979293525, 0.05279315366351511, 1.5627510496415198, 18.798478581011295, 49.31751184165478, 41.90061762928963, 30.763753429055214, 22.005759179592133, 34.520965218544006, 43.115693628787994, 18.60446099191904, 2.2521063778549433, 0.06685683358227834, 0.18722674489254132, 2.163208960555494, 5.348382107913494, 4.587397892028093, 5.386842219159007, 8.659068457782269, 12.885433472692966, 25.662282072007656, 45.256361961364746, 51.132062673568726, 46.49506129324436, 43.77409569919109, 39.598932936787605, 42.9381899535656, 49.883651062846184, 51.58303387463093, 47.95320264995098, 50.024646297097206, 44.60253484547138, 42.61090591549873, 38.784332647919655, 36.98698349297047, 38.99177111685276, 42.85773307085037, 45.503196716308594, 46.373004242777824, 46.820954605937004, 43.347370997071266, 39.23588901758194, 34.124198108911514, 33.16986411809921, 34.994632601737976, 35.726036354899406, 35.86467191576958, 39.57119442522526, 47.264497205615044, 48.168297708034515, 52.635300010442734, 49.02755320072174, 48.37409846484661, 43.55961240828037, 37.56662718951702, 33.75681482255459, 36.51005208492279, 35.376493111252785, 39.23186123371124, 33.861172422766685, 35.57441309094429, 36.65739297866821, 40.88003799319267, 40.62400013208389, 46.6407834738493, 44.684044271707535, 48.32034654915333, 43.94841514527798, 54.895274341106415, 31.563889794051647, 41.29423476755619, 46.598480343818665, 45.92786952853203, 48.09178501367569, 47.02306196093559, 51.446146219968796, 49.59958590567112, 49.41015087068081, 50.01708470284939, 46.00359186530113, 39.729353338479996, 34.53294217586517, 35.52918791770935, 34.98531550168991, 35.388052091002464, 36.02875091135502, 38.723319321870804, 36.39125905930996, 37.58604034781456, 35.42005397379398, 36.90208464860916, 36.25646889209747, 36.641943007707596, 35.308431163430214, 36.43593326210976, 35.24428680539131, 35.213744044303894, 35.28336390852928, 40.19852936267853, 44.77424003183842, 45.657327845692635, 47.99390606582165, 52.460554987192154, 51.11238732933998, 51.397182047367096, 48.907624036073685, 49.14361037313938, 45.45221105217934, 47.75626681745052, 45.585048124194145, 45.898504704236984, 40.60672625899315, 38.25974799692631, 42.486686781048775, 47.24118925631046, 51.706059873104095, 54.100448191165924, 49.34187613427639, 37.05156482756138, 21.258234791457653, 7.163462536409497, 7.919053891673684, 10.225504953414202, 3.683595252223313, 1.8292712420225143, 2.14616141282022, 0.09457261316129006, 0.12227791361510754, 2.048180107958615, 18.85845646262169, 43.25600869953632, 34.570400565862656, 24.211246334016323, 30.808226242661476, 50.820714980363846, 37.40236580371857, 10.013767015188932, 0.5659280356485397, 0.057877867147908546, 0.025136731055681594, 0.012517213926912518, 0.028624188744288404, 0.04444185862666927, 0.042413327828398906, 0.027520772855496034, 0.07315452065085992, 0.035662370355566964, 0.02646494162036106, 0.09820630177273415, 0.04128547487198375, 0.007915093101473758, 0.027940290383412503, 0.03772137002670206, 0.012987404370505828, 0.04850005941989366, 0.02995476490468718, 0.034362190708634444, 0.08790616775513627, 0.024840870173648, 0.0214285920446855, 0.04968241570168175, 0.04376685305032879, 0.034382147059659474, 0.033276621616096236, 0.05474947720358614, 0.035061572125414386, 0.09371719890623353, 0.06865489413030446, 0.015724561890237965, 0.048389575895271264, 0.007374797532975208, 0.026962718620779924, 0.010746093339548679, 0.034429911684128456, 0.029914521946921013, 0.033318070563836955, 0.02809245663229376, 0.05134182079927996, 2.363772173412144, 24.596015587449074, 57.61949636042118, 48.93828459084034, 36.271595880389214, 25.7890185713768, 32.225231006741524, 45.310634449124336, 21.058397814631462, 2.076621581800282, 0.18968390679219738, 0.11641198580036871, 0.32386980252340436, 3.947069076821208, 6.395848151296377, 10.901430733501911, 7.893911590799689, 12.63939667493105, 29.607716761529446, 48.8141680508852, 52.17664182186127, 49.36836451292038, 45.28690852224827, 41.70029237866402, 45.324678495526314, 53.384464010596275, 51.46452583372593, 49.44174237549305, 51.2364886701107, 48.57945844531059, 44.36897277832031, 41.72729752957821, 40.23870460689068, 41.0569678992033, 43.98751504719257, 47.17769466340542, 49.35182400047779, 50.5600755661726, 45.512073040008545, 41.66648179292679, 35.696751326322556, 35.62994711101055, 36.108463034033775, 38.21956515312195, 38.051864951848984, 40.24985320866108, 49.077866300940514, 52.26498708128929, 54.27159860730171, 51.38076312839985, 49.97270308434963, 44.8181314766407, 39.10314694046974, 36.25758223235607, 36.72575891017914, 36.93621441721916, 38.53400968015194, 35.33781498670578, 37.02013671398163, 39.54198159277439, 42.943992242217064, 44.01817940175533, 47.584713622927666, 46.8425602465868, 49.46199908852577, 47.10996709764004, 54.990759417414665, 33.625516667962074, 45.28734169900417, 48.36300686001778, 47.83331908285618, 49.33614984154701, 49.036980494856834, 51.970810666680336, 51.5704071521759, 51.92574128508568, 51.648785546422005, 48.222099021077156, 40.935674607753754, 36.22547395527363, 37.51384802162647, 37.06551767885685, 37.850099578499794, 36.76370367407799, 40.5026688426733, 38.54514688253403, 38.20699542760849, 37.62786090373993, 38.17199930548668, 37.99277052283287, 36.587712317705154, 37.78497867286205, 37.922576889395714, 37.71621756255627, 36.64926901459694, 37.52520181238651, 41.24035365879536, 47.590937688946724, 46.87136650085449, 50.326920077204704, 52.43053279817104, 51.31933942437172, 51.60047113895416, 51.64985328912735, 51.00956864655018, 47.06288002431393, 48.779228925704956, 47.99076743423939, 47.54557192325592, 42.44265854358673, 41.47983580827713, 45.474504455924034, 50.345922857522964, 54.41963106393814, 56.50212451815605, 52.20498830080032, 41.38761095702648, 25.081998109817505, 11.574448719620705, 10.798658598214388, 5.91839094646275, 7.822037972509861, 4.962182231247425, 1.8830440565943718, 0.2444323486997746, 0.09709581136121415, 1.9366030138917267, 20.924230813980103, 47.125151082873344, 41.432178765535355, 28.041948080062866, 35.812257528305054, 58.20570230484009, 45.975097194314, 14.068175107240677, 0.7007632660679519, 0.056605859426781535, 0.03160010259307455, 0.013577612153312657, 0.05156747451110277, 0.08520875038811937, 0.02937152032245649, 0.04887388291535899, 0.022362343697750475, 0.08831729530356824, 0.039218912716023624, 0.03945501215639524, 0.020003687059215736, 0.057430162851233035, 0.07743078298517503, 0.03540219564456493, 0.07142375063267536, 0.04993803733668756, 0.023817042201699223, 0.04633658019884024, 0.23770399333443493, 0.21837190724909306, 0.17767322628060356, 0.09863763058092445, 0.09496091966866516, 0.12539837742224336, 0.20239489269442856, 0.11518045110278763, 0.09559184167301282, 0.2438970672665164, 0.21284146729158238, 0.08269942292827182, 0.11774297570809722, 0.08862054426572286, 0.15799090586369857, 0.09162055750493892, 0.1327947695972398, 0.1063533392152749, 0.21025284135248512, 0.12797508446965367, 0.14391546661499888, 3.3873790595680475, 30.01571226865053, 63.26064705848694, 55.758177638053894, 41.6122967004776, 31.887505128979683, 43.920448645949364, 54.22754377126694, 25.479485280811787, 3.3204632252454758, 0.47940863762050867, 0.5087131995242089, 3.936269818805158, 10.897599589079618, 11.522755343466997, 13.404884599149227, 15.064242258667946, 15.578965488821268, 30.3420140594244, 50.4342795163393, 57.060861736536026, 50.99150441586971, 48.35699178278446, 43.15220206975937, 47.91744276881218, 55.35261780023575, 54.556340128183365, 51.44526846706867, 53.72820496559143, 50.30468367040157, 46.50893434882164, 43.13513718545437, 41.069628819823265, 43.50403279066086, 47.13611349463463, 49.73854064941406, 50.59341497719288, 51.8501253426075, 48.38680878281593, 43.23333911597729, 38.20300944149494, 37.2125393897295, 38.99427518248558, 39.87485133111477, 38.86719860136509, 43.34050856530666, 49.99791093170643, 53.508819937705994, 55.9768483042717, 52.743434607982635, 53.77389371395111, 47.18014553189278, 42.48159505426884, 37.56605342030525, 38.333175256848335, 39.39760074019432, 41.822205036878586, 35.87118476629257, 38.358318507671356, 40.89533977210522, 44.07974749803543, 45.55618107318878, 50.9951826184988, 48.77654246985912, 50.771028846502304, 49.58774194121361, 57.73098237812519, 38.29459972679615, 48.360012620687485, 49.384156465530396, 50.42512200772762, 50.58362290263176, 50.99968537688255, 54.46729950606823, 52.83090591430664, 53.063666224479675, 54.03867110610008, 50.721532702445984, 43.847731947898865, 37.74543039500713, 39.845125526189804, 37.448601722717285, 39.33934986591339, 37.16857194900513, 42.99369737505913, 39.95187699794769, 41.39386922121048, 38.10203365981579, 41.071027144789696, 41.25940203666687, 39.159471318125725, 38.32621403038502, 38.55355203151703, 38.647498190402985, 38.073356598615646, 38.98376874625683, 43.21452632546425, 50.324047431349754, 50.23751087486744, 52.531455382704735, 53.67362469434738, 52.02210791409016, 52.45494648814201, 54.05623376369476, 54.65527541935444, 50.41965790092945, 52.254742830991745, 50.523886308074, 50.65618760883808, 45.59064902365208, 43.06032679975033, 49.50003504753113, 51.85492068529129, 57.346636801958084, 59.26698915660381, 56.44038923084736, 42.958306074142456, 24.077381417155266, 9.93098370730877, 13.015692383050919, 17.416756823658943, 9.301425889134407, 7.25094286724925, 5.481779174879193, 0.5047884851228446, 0.2695400803349912, 2.8871026542037725, 24.73647315055132, 55.98875306546688, 47.478216737508774, 35.48168286681175, 44.58989292383194, 64.79965567588806, 53.3548977971077, 17.70044580101967, 0.9223253990057856, 0.18600481358589604, 0.1087814757192973, 0.11934113135794178, 0.10360547064919956, 0.174458910478279, 0.16255800845101476, 0.11301939870463684, 0.14461969054536894, 0.21500787057448179, 0.111278246040456, 0.1518734122510068, 0.1665889093419537, 0.16454930941108614, 0.18467607238562778, 0.15092807938344777, 0.1636444532778114, 0.11155599480844103, 0.11450994294136763, 0.13503572903573513], [0.027115899756608997, 0.04814006584638264, 0.044260199429118074, 0.053589366798405536, 0.04488609338295646, 0.09269171408959664, 0.04160805307037663, 0.0901086394151207, 0.059831370526808314, 0.044049069547327235, 0.05683160219632555, 0.08267924393294379, 0.031627235512132756, 0.0497400137828663, 0.020800629354198463, 0.051702797718462534, 0.05333564135071356, 0.019123750389553607, 0.032739703747211024, 0.06923635941348039, 0.030908057306078263, 1.2287115678191185, 19.399779215455055, 47.62083448469639, 46.28985330462456, 34.07351262867451, 30.416338071227074, 26.489700973033905, 34.75767731666565, 30.018586814403534, 3.0244263354688883, 0.24329980165930465, 0.09393102649482898, 0.3762781637487933, 3.94835720770061, 4.699501376599073, 9.825760703533888, 6.918858736753464, 8.480223454535007, 22.606761530041695, 43.88645187020302, 49.72894996404648, 48.82931783795357, 43.880318999290466, 41.37246496975422, 44.05274994671345, 49.662404134869576, 48.37776146829128, 45.91671712696552, 50.38176633417606, 46.080659329891205, 41.13112471997738, 35.82175321877003, 35.3250552713871, 38.74693505465984, 39.707546308636665, 41.93895757198334, 43.161306381225586, 43.89583356678486, 41.77671767771244, 34.68857802450657, 33.521269261837006, 34.656503945589066, 33.35793882608414, 34.998455196619034, 34.056926518678665, 37.5508314371109, 40.637310817837715, 48.16394314169884, 50.3569308668375, 49.69075061380863, 49.39028553664684, 47.820984944701195, 41.79711498320103, 35.466977655887604, 37.251312509179115, 34.532463401556015, 36.50682605803013, 37.97193244099617, 37.7642659842968, 35.954898074269295, 36.59059636294842, 35.64811773598194, 38.689884915947914, 41.47558383643627, 45.983597338199615, 45.28851963579655, 54.575384706258774, 36.04292035102844, 41.08580835163593, 46.71763435006142, 48.704616129398346, 51.9188142567873, 48.7125501036644, 50.03165312111378, 49.196891114115715, 50.1699922978878, 48.116726875305176, 47.95108616352081, 42.65974089503288, 37.98521652817726, 34.5767842233181, 36.85943193733692, 37.2981183975935, 35.902099907398224, 36.70028507709503, 36.46144509315491, 37.87526562809944, 36.45776309072971, 36.35968275368214, 36.09677106142044, 34.98015537858009, 35.01733258366585, 34.64139975607395, 34.3641172349453, 36.71499788761139, 38.15116122364998, 42.48873487114906, 46.29559859633446, 48.85557822883129, 50.81811971962452, 44.923173040151596, 48.5147251188755, 50.22863455116749, 51.05422385036945, 52.25229576230049, 50.30240759253502, 45.96894912421703, 48.62360827624798, 48.480887934565544, 44.047654420137405, 40.864158645272255, 44.49256494641304, 48.2880824804306, 51.93195775151253, 52.351223453879356, 51.96987211704254, 36.409650072455406, 25.665225014090538, 12.807957530021667, 14.016280341893435, 3.16585854627192, 6.47654109634459, 3.225551680661738, 0.2930074429605156, 0.5935193051118404, 0.03866176390147302, 2.0373563887551427, 21.441419161856174, 37.375550642609596, 40.043281093239784, 32.16950319707394, 41.280217319726944, 53.13651591539383, 34.296841844916344, 10.098743755370378, 1.1606912990100682, 0.06345280999084935, 0.01265297314603231, 0.030584798187192064, 0.017216410451510455, 0.03163036366458982, 0.01232394197359099, 0.050314922191319056, 0.01744632038025884, 0.03966128839238081, 0.05181553366128355, 0.03546049876604229, 0.01572668999870075, 0.059035825324826874, 0.06536400353070349, 0.01943301260325825, 0.009767630999704124, 0.01889862360258121, 0.043719403838622384, 0.036244674265617505, 0.06414059535018168, 0.04421935162099544, 0.04297217987186741, 0.03812874230789021, 0.03360584574693348, 0.02221465631009778, 0.016663796159264166, 0.04772408094140701, 0.10103901266120374, 0.049624461389612406, 0.05336363145033829, 0.056258764379890636, 0.0696636360953562, 0.00692371971126704, 0.020485680433921516, 0.039335611727437936, 0.021790663631691132, 0.024710762409085874, 0.10180206663790159, 0.015577527592540719, 0.02295134177984437, 1.9421400292776525, 22.99450982362032, 53.60889136791229, 50.072219744324684, 37.92766101658344, 33.13218913972378, 36.220481023192406, 44.73800137639046, 32.00383588671684, 4.154804879799485, 0.19263335008872673, 0.0870981247862801, 0.8728274144232273, 4.3778847344219685, 6.413426008075476, 13.562505841255188, 7.268535923212767, 7.024345826357603, 23.841615468263626, 46.49385675787926, 51.927523389458656, 52.36809454858303, 46.167089492082596, 43.2047114521265, 46.93171486258507, 50.55985517799854, 51.39479197561741, 48.304205015301704, 51.70534551143646, 48.66175442934036, 43.53044517338276, 38.8269017636776, 37.06850811839104, 39.21025179326534, 43.01297374069691, 46.03433981537819, 46.97262346744537, 45.83995744585991, 44.475564658641815, 37.0750779658556, 35.28386548161507, 36.56470835208893, 35.12074403464794, 37.446390241384506, 35.94122640788555, 39.193479493260384, 41.38473831117153, 50.854894146323204, 51.903041303157806, 51.04468636214733, 52.57238678634167, 51.83465637266636, 42.09894418716431, 36.361928433179855, 37.48736344277859, 37.222415059804916, 38.84994372725487, 40.23359768092632, 39.27097253501415, 37.60286584496498, 38.32424953579903, 38.21721687912941, 41.514904126524925, 43.570023849606514, 48.87010484933853, 47.445280104875565, 57.83531717956066, 38.09530422091484, 42.41182319819927, 48.15154820680618, 49.05829735100269, 53.38939614593983, 51.87281012535095, 50.59947185218334, 50.63430078327656, 51.32413096725941, 50.09808875620365, 49.38640974462032, 44.290829971432686, 38.326932191848755, 35.38444608449936, 37.69072473049164, 38.040625154972076, 37.85964846611023, 36.29060626029968, 37.715700790286064, 39.638739600777626, 39.307161793112755, 37.37181544303894, 37.734756767749786, 36.075458005070686, 36.57722868025303, 36.40360839664936, 36.739502772688866, 39.83866587281227, 41.690188720822334, 45.508531630039215, 47.25308261811733, 50.74142083525658, 51.024889424443245, 46.39808289706707, 47.7995540946722, 52.46691584587097, 52.11153991520405, 55.26323139667511, 51.93801462650299, 49.985842779278755, 50.38400441408157, 51.38680100440979, 46.414148434996605, 41.87426224350929, 47.590561509132385, 51.92271284759045, 55.31017407774925, 54.727817326784134, 54.180456697940826, 37.95742101967335, 26.765248887240887, 13.064178731292486, 6.442249361425638, 11.552828829735518, 4.533981783315539, 4.331035148352385, 1.6047152853570879, 0.18475245422450826, 0.14841990225249901, 2.7326323930174112, 23.9041069149971, 44.658859223127365, 43.98716166615486, 32.92900264263153, 45.18938675522804, 59.320653676986694, 42.36743777990341, 12.779544554650784, 1.1289901938289404, 0.046011823797016405, 0.031273401764337905, 0.0422543338208925, 0.02545151670346968, 0.04371203431219328, 0.013566089382948121, 0.02987921983731212, 0.015962177167239133, 0.040027760915108956, 0.0831276569806505, 0.034044725907733664, 0.012484718990890542, 0.03327357138914522, 0.05267982400255278, 0.021880329913983587, 0.08133963769068941, 0.04871745673881378, 0.05006664039683528, 0.02896674926887499, 0.18951641890453175, 0.09587064429069869, 0.09432836493942887, 0.24134188250172883, 0.16402098932303488, 0.24007335916394368, 0.13591318507678807, 0.164832052832935, 0.2112029239651747, 0.1336439498118125, 0.14619529974879697, 0.17332185117993504, 0.18196235003415495, 0.17916595243150368, 0.12357886138488539, 0.15567202091915533, 0.19355193595401943, 0.16442957130493596, 0.22145361610455438, 0.2280621591489762, 0.1174699395778589, 2.312256912700832, 28.14337983727455, 60.2811661362648, 57.552570551633835, 43.5797893255949, 40.78914687037468, 35.675442069768906, 44.35285024344921, 38.10373216867447, 4.84225639142096, 0.5964398046489805, 0.2142234650091268, 1.966868864838034, 11.071896236389875, 14.18460750952363, 19.686122350394726, 12.509317304939032, 11.915877498686314, 27.77586355805397, 48.45526970922947, 53.36729273200035, 55.706846192479134, 47.59266659617424, 45.42271323502064, 48.89075294137001, 52.89273239672184, 53.050150349736214, 50.48825562000275, 53.8775559514761, 50.93463286757469, 46.1382794380188, 40.829892084002495, 38.99850815534592, 42.000069692730904, 44.258767291903496, 47.2295580804348, 47.95308865606785, 49.26681116223335, 47.458579391241074, 38.53025168180466, 37.001415118575096, 37.53288120031357, 35.69385588169098, 39.40606668591499, 37.32863835990429, 41.44935004413128, 43.49108308553696, 52.316569313406944, 54.279103204607964, 52.338334545493126, 54.38275024294853, 53.81023496389389, 44.595942199230194, 40.1705514639616, 40.1204701513052, 38.442920967936516, 41.00865349173546, 43.48346069455147, 40.11263497173786, 40.136657282710075, 39.24341641366482, 40.670049861073494, 42.04595223069191, 45.7499972730875, 49.916880279779434, 49.22779105603695, 58.94939459860325, 43.08610461652279, 42.78916954994202, 49.43356901407242, 50.91273084282875, 55.850911661982536, 55.28901681303978, 53.06308105587959, 54.17006805539131, 54.659379199147224, 51.69556863605976, 52.99953706562519, 45.19438348710537, 41.22035913169384, 37.64261171221733, 39.94556173682213, 41.11487299203873, 38.725910782814026, 38.96674565970898, 39.774707704782486, 42.71361440420151, 42.70128406584263, 39.45680156350136, 40.303494930267334, 39.22598294913769, 38.26244965195656, 37.792954444885254, 37.7771282941103, 40.9752456843853, 43.25884334743023, 47.212823778390884, 50.486925691366196, 52.69257813692093, 52.731575444340706, 45.01439854502678, 49.0815445035696, 50.144020691514015, 53.24595384299755, 56.369409039616585, 55.97103841602802, 52.294815480709076, 52.073986530303955, 54.32288445532322, 48.54977823793888, 45.25184780359268, 50.37229724228382, 53.798755779862404, 58.513892367482185, 58.32870930433273, 56.23391591012478, 40.5091816931963, 27.716484144330025, 16.470829881727695, 18.556123785674572, 10.220679212361574, 16.325797364115715, 10.197881385684013, 2.7592991245910525, 1.2569957063533366, 0.26339848176576197, 3.4474279498681426, 28.31047587096691, 50.22719442844391, 53.62348638474941, 45.44578179717064, 54.310223534703255, 67.82725721597672, 52.54174143075943, 16.703122816979885, 1.3067837222479284, 0.12273705811821856, 0.16582325042691082, 0.14014819142175838, 0.13035964948358014, 0.13968172192107886, 0.13018089579418302, 0.07102982606738806, 0.08127012813929468, 0.1455580917536281, 0.14608057856094092, 0.11291690068901516, 0.10672472475562245, 0.1133941684383899, 0.12173292489023879, 0.11893731396412477, 0.18833665642887354, 0.1186063235218171, 0.1960134765249677, 0.12332562575466], [0.01039743143337546, 0.05267290347546805, 0.05818902740429621, 0.06050431293260772, 0.026622981968102977, 0.03159860716550611, 0.0228615456217085, 0.05117137545312289, 0.01532452852188726, 0.062058655894361436, 0.03456066326180007, 0.04269654622476082, 0.01867086404672591, 0.029470908739313018, 0.029887277705711313, 0.07816522716893815, 0.03358513240527827, 0.035345447322470136, 0.03445011294388678, 0.028232741096871905, 0.04806319047929719, 0.24988697085063905, 12.545050587505102, 44.76732440292835, 48.56717370450497, 39.94148075580597, 22.140150368213654, 19.305093996226788, 32.623111456632614, 31.1233414337039, 7.11080021224916, 0.21934876654995605, 0.07211836375063285, 0.29257940186653286, 1.7033061012625694, 4.314158353954554, 9.12786165252328, 2.9318749392405152, 1.5089195757173002, 12.672929875552654, 33.74937102198601, 49.742967411875725, 48.00059370696545, 46.65406376123428, 45.36692462861538, 46.37885972857475, 51.08326569199562, 46.137941256165504, 50.95104418694973, 48.8424651324749, 45.48873469233513, 41.52267850935459, 36.52096129953861, 34.64982010424137, 35.076833590865135, 36.15501433610916, 40.54195873439312, 41.58266209065914, 40.14990717172623, 37.17961795628071, 32.558438926935196, 33.57781022787094, 33.47046218812466, 34.768290147185326, 34.55801323056221, 34.11689110100269, 36.107235699892044, 43.16457040607929, 45.16664497554302, 49.56761062145233, 49.61379714310169, 49.90606985986233, 49.77071352303028, 49.949748516082764, 41.34582839906216, 36.22977912425995, 36.47576652467251, 36.4111889898777, 35.82662455737591, 37.3791528493166, 35.6653156131506, 37.67308987677097, 35.972339138388634, 37.502076253294945, 37.159463837742805, 46.72480836510658, 43.588084280490875, 54.20851819217205, 35.956638380885124, 38.79633620381355, 50.56319899857044, 47.93865703046322, 49.10151243209839, 46.38276591897011, 45.947727262973785, 45.81114739179611, 46.86925381422043, 45.29144927859306, 46.622928231954575, 44.82935227453709, 39.12922494113445, 33.998839035630226, 36.448468789458275, 35.28512701392174, 36.9116335362196, 37.363509088754654, 38.674115762114525, 42.82098524272442, 42.279134318232536, 40.604750365018845, 38.50838765501976, 37.4123440682888, 35.90273827314377, 34.68197397887707, 35.51394693553448, 33.94636385142803, 39.571741595864296, 45.50614915788174, 48.28324913978577, 52.012106850743294, 43.30875366926193, 46.76208816468716, 51.396786868572235, 49.08510111272335, 48.16865108907223, 47.42471560835838, 49.27793316543102, 49.00398686528206, 51.247834861278534, 49.52649302780628, 47.554984018206596, 41.31607599556446, 40.246611982584, 46.82997152209282, 46.192418932914734, 53.51393446326256, 52.617748752236366, 40.3267040848732, 23.486307933926582, 10.08986933156848, 4.99701876193285, 9.576028604060411, 5.973334098234773, 3.311121426522732, 1.7384900758042932, 0.13474617269821465, 0.06777829155907966, 3.1852223072201014, 21.42645176500082, 43.52023132145405, 35.90548172593117, 35.399234890937805, 39.79700490832329, 54.425421953201294, 35.72974115610123, 9.718338567763567, 0.33166241250000894, 0.102127758145798, 0.017708946033963002, 0.07900567230535671, 0.002078790430459776, 0.029892294624005444, 0.04468757259019185, 0.01552417366838199, 0.027614775135589298, 0.024741429806454107, 0.032648059641360305, 0.029322592381504364, 0.009349522624688689, 0.019496505192364566, 0.0399517724144971, 0.028038526616001036, 0.01488941939896904, 0.042316496110288426, 0.02890562598622637, 0.08619839689345099, 0.06749078354914673, 0.03677708729810547, 0.05525612286874093, 0.11080598778789863, 0.04511899045610335, 0.011641699529718608, 0.03608051862102002, 0.03485197477857582, 0.05837902834173292, 0.01117103503929684, 0.03775928635150194, 0.01977507403353229, 0.01031297595545766, 0.0637211705907248, 0.03378553825314157, 0.08710005437023938, 0.07893838177551515, 0.03491692754323594, 0.031120706735237036, 0.04218367765133735, 0.019386266576475464, 0.329194949590601, 16.531138345599174, 49.42270539700985, 54.86745983362198, 44.52017806470394, 29.210658967494965, 20.94574525952339, 36.0000966489315, 36.084588915109634, 7.5472367182374, 0.44173256086651236, 0.05958008303423412, 0.5196656961925328, 1.6291955905035138, 3.291681194677949, 10.506111346185207, 8.627035226672888, 4.44068206474185, 18.208284750580788, 37.03326880931854, 53.54619853198528, 49.45872366428375, 48.527401238679886, 45.66926300525665, 51.08366847038269, 52.15982772409916, 48.68280149996281, 51.11662410199642, 50.828166380524635, 48.21177497506142, 43.521823436021805, 37.51344904303551, 36.948609352111816, 37.5620636343956, 38.27322207391262, 42.694619223475456, 42.7624873816967, 42.411241829395294, 39.63035725057125, 35.2980425208807, 36.6891098767519, 35.518138110637665, 36.38193815946579, 35.325359255075455, 34.83178474009037, 37.70386442542076, 44.36614952981472, 47.82682903110981, 51.44475169479847, 51.731655299663544, 50.51451601088047, 52.13350273668766, 50.44393099844456, 42.645370066165924, 37.66784995794296, 37.27253057062626, 37.213614732027054, 36.97819456458092, 39.13182780146599, 37.468478456139565, 39.67787750065327, 37.66184628009796, 39.184561371803284, 39.187992587685585, 48.51924307644367, 46.99905104935169, 57.42570295929909, 39.66191075742245, 40.808472633361816, 49.921649023890495, 50.300192311406136, 51.38101011514664, 48.59479442238808, 47.7143170684576, 48.350950106978416, 48.20419058203697, 47.851417511701584, 48.01635906100273, 47.00615666806698, 39.948825761675835, 36.45479924976826, 37.987766191363335, 36.69023461639881, 39.08000238239765, 38.47762070596218, 40.16402341425419, 43.939512223005295, 45.06985656917095, 40.3847573697567, 39.06531997025013, 38.25160123407841, 37.36854001879692, 37.103219255805016, 36.318675354123116, 35.765128657221794, 41.977954879403114, 47.68237978219986, 50.02245381474495, 53.13482500612736, 45.19559562206268, 48.423400819301605, 51.41420133411884, 50.40501728653908, 50.387994199991226, 50.58502122759819, 50.49168683588505, 51.254404708743095, 53.423351123929024, 50.207116305828094, 49.57842484116554, 43.306929767131805, 44.4652596116066, 48.91297794878483, 51.15232698619366, 55.3349145501852, 55.33383160829544, 41.14526756107807, 24.416137039661407, 15.723603777587414, 8.384114261716604, 9.87739423289895, 10.98447622731328, 3.86114405002445, 1.935032510664314, 0.14183142688125372, 0.09470241478993557, 3.4998886473476887, 24.529864937067032, 49.33679200708866, 43.78074914216995, 43.22944812476635, 46.779373437166214, 60.964783653616905, 40.89090920984745, 12.10159633308649, 0.6272033101413399, 0.046560757036786526, 0.011499067095428472, 0.030772793470532633, 0.027485166465339717, 0.0911002600332722, 0.05963123185210861, 0.04594718644511886, 0.01610519644600572, 0.03398544686206151, 0.029355272854445502, 0.009026948137034196, 0.05460252083139494, 0.0476537253416609, 0.04366093373391777, 0.020485530149016995, 0.03612575623265002, 0.062032087007537484, 0.01869871499366127, 0.04648891343094874, 0.17253161233384162, 0.10154874937143177, 0.11871245806105435, 0.1526234415359795, 0.12049130440573208, 0.183051674393937, 0.1945892654475756, 0.10200452452409081, 0.1155048661166802, 0.14038481778698042, 0.10535498731769621, 0.10274234547978267, 0.1236191822681576, 0.12849500344600528, 0.13200680172303692, 0.1403786282753572, 0.1379386248299852, 0.13969752966659144, 0.15992785192793235, 0.15964080404955894, 0.13158061599824578, 0.5745478731114417, 20.618535317480564, 58.78560818731785, 60.70585034787655, 52.289241179823875, 33.615656197071075, 27.33822964131832, 42.31155797839165, 40.40880247950554, 9.291705060750246, 0.6967329292092472, 0.15028824418550357, 0.491722856531851, 6.328210830688477, 10.188292600214481, 17.62848526239395, 7.875891532748938, 3.6332446290180087, 16.417245157063007, 36.47427700459957, 54.903782084584236, 51.21587097644806, 51.311394050717354, 50.311948880553246, 52.66600236296654, 55.99712781608105, 50.607493221759796, 51.62381708621979, 53.50680224597454, 50.754617527127266, 46.81746259331703, 40.07880538702011, 38.05042862892151, 39.74751636385918, 40.28939388692379, 46.01517744362354, 45.538390427827835, 44.18644957244396, 41.926152259111404, 37.252984419465065, 37.569366842508316, 37.070487812161446, 37.919198870658875, 37.335417196154594, 37.15089909732342, 41.224333718419075, 47.27352172136307, 49.81706343591213, 54.55406405031681, 53.670824244618416, 51.97968319058418, 53.910105004906654, 53.21477651596069, 46.185826286673546, 39.66463901102543, 39.82861541211605, 39.71438214182854, 39.733502715826035, 40.34820333123207, 38.71013022959232, 43.314213976264, 39.0065561234951, 39.51615437865257, 40.527625903487206, 50.51889717578888, 49.15366843342781, 59.12014603614807, 44.48270447552204, 41.65620714426041, 51.37914061546326, 52.389947175979614, 53.549029380083084, 51.141752153635025, 50.100235641002655, 50.86761586368084, 49.90174189209938, 49.26534824073315, 50.650883093476295, 48.537827879190445, 42.619147673249245, 37.421425580978394, 39.67954561114311, 39.02612887322903, 41.34930141270161, 41.25913605093956, 41.74514517188072, 48.511749878525734, 47.808191031217575, 44.13732200860977, 41.81303232908249, 40.19244968891144, 39.6620437502861, 39.123867228627205, 37.970591112971306, 38.04901510477066, 43.2978330552578, 51.10476113855839, 53.33100087940693, 55.92220723628998, 48.78888040781021, 47.900168895721436, 52.52956688404083, 51.114123836159706, 51.71593174338341, 52.30936110019684, 53.03064979612827, 52.16247618198395, 55.67851111292839, 53.12636286020279, 52.60832905769348, 46.11233443021774, 45.392261669039726, 52.823329120874405, 50.38017801940441, 58.38165566325188, 56.90358057618141, 47.15579643845558, 25.516563691198826, 15.906546860933304, 11.147373486310244, 15.62969846650958, 12.042691893875599, 12.1616730093956, 5.255915019661188, 0.33194977208040655, 0.28987813275307417, 4.597952300682664, 28.527909703552723, 57.21448749303818, 47.69332319498062, 47.65670835971832, 51.20646648108959, 67.43061169981956, 56.76934517920017, 14.894627910107374, 0.7794265856500715, 0.22728045500116423, 0.08482688572257757, 0.13292247836943716, 0.12219891941640526, 0.337384786689654, 0.17393289104802534, 0.15395172260468826, 0.1022207344067283, 0.1484348194207996, 0.13173312734579667, 0.10326178206014447, 0.10630965640302747, 0.06908275710884482, 0.11177403779583983, 0.0825810874812305, 0.11342325320583768, 0.15501514601055533, 0.08151132613420486, 0.19863481633365154], [0.03691345322295092, 0.024607722625660244, 0.06459082665969618, 0.07381144750979729, 0.01159435885710991, 0.07714928637142293, 0.013708609567402164, 0.02118283540767152, 0.03717365761986002, 0.03193715267116204, 0.06527067846036516, 0.08362806489458308, 0.084968257433502, 0.046294229541672394, 0.020132468234805856, 0.030061840116104577, 0.035967856892966665, 0.04915967656415887, 0.010610124463710235, 0.0038214257665458717, 0.008918723524402594, 0.007076815036271, 9.06806806102395, 38.36208790540695, 50.90470187366009, 40.09635664522648, 32.323212549090385, 31.311950013041496, 38.082487508654594, 41.8014657497406, 10.457487255334854, 0.7445436262059957, 0.012007092227577232, 0.49451027414761484, 1.1616587033495307, 2.744170711375773, 10.873035807162523, 10.042013749480247, 3.9997309260070324, 10.012116953730583, 25.85750799626112, 43.80492344498634, 52.152133136987686, 49.94861237704754, 45.6901428848505, 48.840496838092804, 48.73720698058605, 52.0647644251585, 50.53456753492355, 51.17358684539795, 44.434291273355484, 41.55822180211544, 36.69378362596035, 34.445391073822975, 34.636061042547226, 36.14692077040672, 38.06342773139477, 38.138690292835236, 37.62124165892601, 36.97568289935589, 37.10953451693058, 35.91299772262573, 35.17273284494877, 34.78352352976799, 36.29838824272156, 41.92987985908985, 44.297749400138855, 48.054907992482185, 47.18723215162754, 49.33800034224987, 49.348430782556534, 48.95935446023941, 50.160192623734474, 49.03568856418133, 47.23638251423836, 40.640825629234314, 34.297503009438515, 37.00158230960369, 35.325017273426056, 36.15531072020531, 35.34870520234108, 36.31875894963741, 34.7725573182106, 37.083916291594505, 36.900218948721886, 47.200254052877426, 46.05528049170971, 53.81140910089016, 39.224455431103706, 43.54800783097744, 49.185666516423225, 47.08982437849045, 50.820920169353485, 45.31563878059387, 48.89401316642761, 43.65869589149952, 45.28679832816124, 43.25325004756451, 43.37751477956772, 41.212482154369354, 39.375436529517174, 36.57410904765129, 35.775969475507736, 37.06280082464218, 37.76256747543812, 37.67710626125336, 47.219374626874924, 50.36198079586029, 50.40972143411636, 47.60707162320614, 43.12141232192516, 35.58804675936699, 35.70743255317211, 35.46204552054405, 35.51183804869652, 35.68776100873947, 40.65336495637894, 48.78996714949608, 45.71171812713146, 47.948677092790604, 48.206440061330795, 46.880869790911674, 54.769151508808136, 51.995307952165604, 52.10947282612324, 49.85664211213589, 53.68471249938011, 51.15635097026825, 49.96274381875992, 49.43899892270565, 51.22583404183388, 44.48857516050339, 44.057036116719246, 43.00032041966915, 48.34452085196972, 48.093745708465576, 50.10783143341541, 34.77850779891014, 28.312153480947018, 15.4158934392035, 4.853908941149712, 11.713640950620174, 5.751211317256093, 1.6133714583702385, 0.9328773140441626, 0.12874994601588696, 0.12212142435600981, 3.8599297776818275, 24.552950598299503, 39.41712789237499, 28.411586545407772, 26.82101659476757, 36.72529153525829, 53.72357681393623, 40.66925950348377, 8.053529150784016, 0.08475978815113194, 0.030819407766102813, 0.09056924594915472, 0.002385451880400069, 0.024241359569714405, 0.03434092075622175, 0.012933491980220424, 0.058695272309705615, 0.020240914564055856, 0.038214579108171165, 0.013854503740731161, 0.027498178169480525, 0.03580965698347427, 0.026499694540689234, 0.028339693853922654, 0.04134970404265914, 0.05174844722205307, 0.012793820715160109, 0.03491551375191193, 0.07718709137407131, 0.023385232852888294, 0.12342885107500479, 0.030808600240561645, 0.09781988032045774, 0.06422797581763007, 0.02985335413541179, 0.011618402586464072, 0.00368697249541583, 0.04100311365618836, 0.02584357662271941, 0.05860104181920178, 0.015333702394855209, 0.03234684045310132, 0.060369665079633705, 0.02990552155097248, 0.018729497423919383, 0.024299063406942878, 0.01095102164981654, 0.023260377638507634, 0.04526666671154089, 0.03074630250921473, 0.1767539873253554, 11.359898932278156, 42.905713096261024, 57.00553670525551, 46.10077165067196, 35.01185707747936, 30.10359015315771, 38.542179241776466, 45.382621586322784, 11.96094973012805, 0.8259201189503074, 0.10076583552290685, 0.18848394305678084, 2.286811340600252, 2.423527529463172, 8.934732265770435, 9.469521269202232, 5.680672852322459, 12.246393263339996, 29.46536310017109, 47.085731998085976, 52.697848454117775, 51.003143191337585, 47.29813680052757, 51.36461019515991, 50.668411552906036, 51.70628026127815, 51.33369505405426, 52.09031045436859, 45.92002294957638, 44.6810158342123, 38.02569195628166, 36.07725530862808, 35.56060463190079, 39.07247878611088, 40.96637316048145, 41.884289905428886, 40.062207877635956, 37.218949645757675, 37.92161554098129, 37.73473396897316, 36.949388310313225, 36.73903539776802, 37.35293805599213, 43.71451869606972, 45.51869608461857, 50.410150811076164, 48.739730045199394, 51.34323634207249, 51.133666187524796, 51.52415983378887, 50.81666819751263, 51.99742063879967, 48.65133918821812, 42.58254423737526, 35.754504427313805, 38.49387623369694, 36.721810922026634, 38.33754502236843, 36.99012592434883, 37.526163160800934, 37.172763124108315, 38.23853373527527, 39.150545597076416, 48.59091863036156, 47.50537008047104, 55.12305311858654, 41.751228645443916, 44.999199360609055, 50.83990395069122, 48.71206372976303, 52.509211376309395, 47.120598927140236, 50.62988921999931, 46.34383700788021, 47.59407252073288, 44.95776258409023, 45.41189521551132, 44.63371977210045, 40.5910786986351, 37.75348216295242, 37.174735218286514, 38.7744265794754, 39.72028702497482, 39.678329676389694, 49.01597902178764, 51.99090778827667, 50.36373630166054, 50.55193640291691, 45.460433810949326, 38.246342316269875, 37.15407572686672, 37.094335332512856, 37.42984212934971, 36.819834262132645, 43.73689949512482, 50.923393070697784, 49.13156121969223, 49.403071850538254, 48.23601767420769, 48.88437308371067, 55.74888713657856, 53.820965588092804, 52.51406371593475, 53.29328030347824, 53.96877385675907, 51.545241102576256, 51.3922993093729, 53.01464505493641, 52.289864346385, 46.92826084792614, 44.06198725104332, 45.81940434873104, 50.95533415675163, 51.00268341600895, 53.257277235388756, 39.59650106728077, 27.619587443768978, 18.267700262367725, 5.957513647153974, 11.462853457778692, 14.753435086458921, 5.6211343221366405, 1.4306681184098125, 0.20522891718428582, 0.09616225637728348, 4.83833072707057, 26.67918350547552, 44.27625015377998, 31.67538531124592, 31.277955137193203, 41.33860878646374, 60.764260813593864, 47.39252373576164, 9.806914664804935, 0.24581106612458825, 0.03088931251113536, 0.07625260128406808, 0.005922839409322478, 0.019295759811939206, 0.03112829705059994, 0.014895426156726899, 0.016081102621683385, 0.033924379240488634, 0.04005623341072351, 0.015535337424807949, 0.04443633704795502, 0.016704050249245483, 0.012378920273476979, 0.05628538150631357, 0.030926555336918682, 0.01652107745030662, 0.03315508751256857, 0.03204604428901803, 0.05916906309721526, 0.15476508677238598, 0.16502501122886315, 0.16717066406272352, 0.2669980167411268, 0.1749407869647257, 0.11764934635721147, 0.11954681016504765, 0.10905287170317024, 0.11512011449667625, 0.08648479168186896, 0.12761860125465319, 0.13940699369413778, 0.13374532718444243, 0.25220944778993726, 0.10235554553219117, 0.04409783607115969, 0.13316471537109464, 0.1271730157895945, 0.07069609710015357, 0.08400102378800511, 0.11151116908877157, 0.33767775690648705, 14.591548573225737, 49.68700021505356, 63.63127917051315, 51.46611414849758, 43.734007850289345, 39.94186833500862, 49.128616377711296, 51.689956337213516, 14.175686538219452, 1.3083358202129602, 0.4385927418479696, 1.4383927476592362, 5.303979590535164, 10.689506605267525, 19.86630868166685, 19.136390648782253, 9.006747901439667, 12.680590264499187, 29.588841274380684, 48.629102781414986, 55.93223109841347, 54.715528786182404, 50.93985378742218, 53.052054047584534, 52.132708579301834, 52.127385064959526, 53.91500674188137, 55.66146142780781, 47.838118225336075, 47.40771912038326, 40.36151021718979, 37.60427936911583, 37.27778568863869, 39.925605207681656, 43.8917525857687, 42.69783765077591, 41.20125375688076, 40.337161123752594, 41.966122314333916, 39.85854260623455, 38.65485839545727, 37.57584549486637, 39.342739284038544, 47.35447257757187, 48.193877935409546, 52.92214661836624, 52.785745337605476, 53.45146581530571, 52.48178444802761, 53.57633091509342, 54.74300891160965, 53.067507818341255, 50.89696928858757, 46.73420526087284, 37.28408955037594, 39.56850416958332, 39.2240184545517, 39.67791169881821, 38.401047214865685, 37.799892872571945, 37.90940299630165, 40.024263113737106, 40.781186297535896, 51.93892277777195, 50.2391941845417, 56.51298813521862, 45.59526577591896, 47.19945229589939, 53.50852735340595, 50.72321221232414, 54.806222319602966, 49.48370732367039, 53.869314193725586, 49.097393453121185, 49.48808088898659, 47.411150336265564, 48.490938395261765, 45.45199066400528, 41.761731281876564, 39.64650258421898, 38.309825509786606, 41.74594312906265, 41.717098876833916, 40.74274756014347, 51.892166286706924, 54.41490791738033, 53.377388790249825, 52.46952250599861, 48.63787271082401, 40.48596493899822, 37.97111548483372, 38.05990532040596, 39.49818134307861, 39.434238374233246, 45.144549161195755, 53.47797319293022, 53.03226090967655, 51.79633542895317, 52.363280206918716, 51.87483161687851, 57.418730333447456, 55.411818623542786, 54.13179270923138, 54.18649077415466, 56.37395739555359, 53.67930918931961, 54.03853811323643, 53.8091292232275, 55.521435141563416, 49.88332808017731, 48.905575945973396, 48.131888061761856, 54.54476974904537, 53.206941336393356, 55.67900888621807, 40.41959770023823, 30.86820412427187, 21.66312586516142, 10.869878176599741, 19.515834487974644, 15.396137349307537, 7.644425053149462, 3.3983459835872054, 0.6671000411733985, 0.23422866419423372, 5.503625152632594, 34.41675581037998, 50.69738119840622, 41.05254493653774, 39.10701133310795, 48.640156388282776, 68.44186663627625, 57.22747519612312, 12.664918005466461, 0.5574875010643154, 0.10620384098729119, 0.18262829398736358, 0.1129070894967299, 0.13443004747387022, 0.1430403409176506, 0.0991933952900581, 0.11916277842829004, 0.1214560295920819, 0.10717791723436676, 0.09174837017781101, 0.12125189445214346, 0.13110920379403979, 0.0501113436621381, 0.142038649355527, 0.17560943233547732, 0.23519097740063444, 0.20986688003176823, 0.14795166644034907, 0.12360956403426826], [0.030003319916431792, 0.0278420912582078, 0.050892060753540136, 0.05001779594749678, 0.071428433584515, 0.021024542729719542, 0.019913657124561723, 0.06202425363881048, 0.0541838382196147, 0.027729691137210466, 0.05790272909507621, 0.06203462886333, 0.024695928732398897, 0.07028666906990111, 0.06211669184267521, 0.054325970631907694, 0.050294643006054685, 0.02985803523188224, 0.05044620069384109, 0.025097844372794498, 0.01252597776328912, 0.06331692275125533, 4.993985574692488, 30.45677550137043, 49.75099258124828, 51.08482740819454, 33.29819843173027, 22.366654314100742, 27.647249959409237, 33.16991351544857, 17.38667953759432, 2.0336786611005664, 0.06016380444634706, 0.28172329533845186, 1.0988605418242514, 1.0254799481481314, 5.3656151331961155, 7.901940084993839, 4.990855967625976, 5.036309128627181, 14.781692270189524, 37.81164564192295, 47.67692707479, 49.05120313167572, 49.22004707157612, 49.8692574352026, 47.082901149988174, 44.64984230697155, 50.97514249384403, 50.279954597353935, 44.296685457229614, 41.97315573692322, 36.116541400551796, 34.77266751229763, 32.84733362495899, 32.829903960227966, 35.94013586640358, 34.75179523229599, 35.12028805911541, 34.07335303723812, 33.79415161907673, 32.95768350362778, 36.08237363398075, 37.06494390964508, 45.62120698392391, 49.53367084264755, 47.108481377363205, 48.88941541314125, 49.83406372368336, 48.3705722540617, 48.54895368218422, 50.8767581731081, 48.24764505028725, 53.74496206641197, 48.307875618338585, 44.83241870999336, 37.07582652568817, 36.812933832407, 35.28350830078125, 34.77722726762295, 35.40204294025898, 36.91229850053787, 33.59813533723354, 37.943468168377876, 38.58461536467075, 45.11333383619785, 45.39397157728672, 54.22662802040577, 36.85644529759884, 33.899383172392845, 46.800435706973076, 57.12818272411823, 49.593981206417084, 48.573595359921455, 47.35959090292454, 44.86509695649147, 41.778666973114014, 40.32651409506798, 40.40571704506874, 37.90187940001488, 39.042828977108, 39.36692878603935, 36.05187647044659, 36.88319966197014, 36.70637995004654, 41.023195311427116, 50.642694532871246, 50.55570960044861, 52.598426789045334, 48.45420956611633, 48.44640098512173, 39.461471512913704, 36.5817466378212, 35.149937868118286, 36.5566261857748, 34.2487858235836, 37.92662747204304, 47.1026448905468, 51.37264296412468, 46.52909226715565, 52.81550534069538, 50.6746432185173, 48.31223778426647, 48.04779477417469, 48.00459869205952, 48.52134816348553, 49.75845918059349, 50.44463396072388, 53.66723343729973, 50.82691624760628, 50.76785981655121, 47.707021459937096, 45.02708986401558, 43.86368729174137, 45.77852614223957, 50.194417387247086, 54.753268361091614, 35.97281791269779, 24.201532155275345, 23.53003978729248, 6.338135423138738, 7.400355124846101, 18.353218473494053, 2.9052716167643666, 1.0648725531063974, 0.06391883420292288, 0.14968507108278573, 4.688587412238121, 28.834733739495277, 41.31803289055824, 36.789872869849205, 38.81393685936928, 44.98281463980675, 49.9436042457819, 35.88457524776459, 7.021850310266018, 0.07560506259324029, 0.07184481553849764, 0.054708069073967636, 0.03542991486028768, 0.06256432563532144, 0.07268799177836627, 0.048541653086431324, 0.01611397419765126, 0.06661397317657247, 0.020324918259575497, 0.053160056631895714, 0.04550134122837335, 0.037555974995484576, 0.0890862345113419, 0.06772398861357942, 0.10151504102395847, 0.03021993426955305, 0.016477700773975812, 0.09510892617981881, 0.025263783027185127, 0.0789961357077118, 0.028664975325227715, 0.026758516687550582, 0.01796485339582432, 0.04568233620375395, 0.09960106443031691, 0.01598035236384021, 0.08263896757853217, 0.0437231850810349, 0.00862165665239445, 0.04299299340345897, 0.06634309669607319, 0.08275740692624822, 0.10209099214989692, 0.025441885481995996, 0.016961371402430814, 0.003922928144675097, 0.026408256380818784, 0.07484954141546041, 0.08807665391941555, 0.03599155737902038, 0.07978574372828007, 7.335071302950382, 36.78682163357735, 55.541277676820755, 56.3029620051384, 41.07552230358124, 26.320632845163345, 36.65431134402752, 41.141403168439865, 19.155503623187542, 2.432639440521598, 0.039645606811973266, 0.236742259003222, 1.645348642487079, 3.20144553668797, 9.352516997605562, 7.52171871252358, 7.452650768682361, 10.381279494613409, 20.951148569583893, 38.89974765479565, 52.103039771318436, 50.89388385415077, 51.83217890560627, 52.03326031565666, 50.73296628892422, 46.16371147334576, 52.260849103331566, 51.76204986870289, 47.1174792945385, 43.64989176392555, 37.22902290523052, 36.852394714951515, 35.61473652720451, 34.947708919644356, 37.498793229460716, 36.617263332009315, 37.89961852133274, 36.86971798539162, 36.07033967971802, 35.13676777482033, 38.21174517273903, 39.274190962314606, 46.44053801894188, 50.96588999032974, 48.992792665958405, 50.82330264151096, 50.64088962972164, 50.73914855718613, 50.11694714426994, 52.920615300536156, 49.968880489468575, 53.379129096865654, 50.996694937348366, 44.853644371032715, 39.76484723389149, 39.267750307917595, 36.539580300450325, 36.790249049663544, 37.51716524362564, 39.47434522211552, 36.24470092356205, 41.16283021867275, 39.0753286331892, 47.062055468559265, 49.44700129330158, 54.78196822106838, 41.00266121327877, 37.38820396363735, 48.272769302129745, 57.69258923828602, 51.12663276493549, 50.134809985756874, 48.394716158509254, 44.112045764923096, 43.11009652912617, 42.265645042061806, 42.5458762049675, 40.520508885383606, 40.29205374419689, 40.451082810759544, 37.628586664795876, 38.73898208141327, 38.93593691289425, 42.95949921011925, 51.86492554843426, 52.0994907617569, 54.946803376078606, 49.78229530155659, 49.34298947453499, 41.95511810481548, 38.19004453718662, 36.76547057926655, 37.82722860574722, 35.2379335463047, 40.08607819676399, 48.192171826958656, 52.97404423356056, 49.670414105057716, 55.68273648619652, 52.43988789618015, 50.95988631248474, 50.07406644523144, 50.870260521769524, 51.119071170687675, 52.90157452225685, 52.59091459214687, 54.95143912732601, 51.24908499419689, 53.19404482841492, 49.07992959022522, 47.6567767560482, 46.60394065082073, 50.43039992451668, 52.550450563430786, 56.32085524499416, 39.318781569600105, 24.716491922736168, 15.599064510315657, 8.503783140331507, 13.32279285416007, 13.335657063871622, 6.4888823591172695, 1.4755010814405978, 0.08438147837296128, 0.10746827509137802, 5.556414294987917, 31.682593524456024, 47.945257276296616, 39.45058889687061, 40.5500029027462, 48.17639507353306, 57.85056196153164, 41.9526444375515, 9.068999011069536, 0.16640993300825357, 0.0945698597934097, 0.07754147431114689, 0.02562782130553387, 0.04700584526290186, 0.0031307112431022688, 0.06470306907431222, 0.026507266302360222, 0.07378762456937693, 0.05728304691729136, 0.05714669212466106, 0.09598538032150827, 0.011782500714616617, 0.01641530470806174, 0.07913941473816521, 0.03085423490119865, 0.03849155604257248, 0.07781145279295743, 0.035882558149751276, 0.06428338456316851, 0.24280514538986608, 0.11523459819727577, 0.23710288340225816, 0.28878088225610554, 0.23323411209275946, 0.14625213341787457, 0.1129951082111802, 0.1416986863478087, 0.13811904093017802, 0.12348880176432431, 0.13677701528649777, 0.2385777237941511, 0.22718418360454962, 0.17178677808260545, 0.16788186418125406, 0.14346446347190067, 0.12425058666849509, 0.1094549302069936, 0.1401823599007912, 0.21979273413307965, 0.1580827243742533, 0.21050585433840752, 7.973343953490257, 39.918590784072876, 63.98274511098862, 63.17799389362335, 46.19980953633785, 33.14766190946102, 39.65352840721607, 41.9950083643198, 23.64220216870308, 3.0174192739650607, 0.4003880778327584, 0.9367523936089128, 4.167008874937892, 4.033315423876047, 14.80933103710413, 16.554717980325222, 8.310428615659475, 7.22508430480957, 16.823973432183266, 40.08992739021778, 50.68765752017498, 55.51515407860279, 52.97637350857258, 54.54413518309593, 51.00713677704334, 46.5450020134449, 53.17673295736313, 55.60918763279915, 49.32623617351055, 47.50965245068073, 38.909402936697006, 39.477122873067856, 35.939163118600845, 35.675544664263725, 39.50226232409477, 39.4544380903244, 38.55621948838234, 37.86778762936592, 36.169054582715034, 37.033853977918625, 39.249819070100784, 41.70002639293671, 51.71577215194702, 53.82665008306503, 51.64506174623966, 54.11858081817627, 53.14947322010994, 53.258949145674706, 52.816846668720245, 54.55020725727081, 50.592278838157654, 56.119374856352806, 52.62473277747631, 47.69672781229019, 41.68547697365284, 41.574595123529434, 37.98243127763271, 37.38041818141937, 38.32401014864445, 40.64853921532631, 37.407886907458305, 43.48530359566212, 41.99908174574375, 49.87875312566757, 52.1965641528368, 57.13781900703907, 43.08000214397907, 38.647995963692665, 48.41219522058964, 58.17341923713684, 54.238270595669746, 52.02389381825924, 50.131295174360275, 47.655629217624664, 45.456455424427986, 45.236698016524315, 44.478566497564316, 41.657575070858, 42.337795570492744, 42.521314322948456, 40.39255075156689, 39.50455740094185, 40.22968769073486, 43.73126059770584, 55.3940811753273, 52.906989231705666, 56.585773229599, 52.399021089076996, 52.27966949343681, 44.72242221236229, 39.56606090068817, 38.510355949401855, 40.32227352261543, 37.87800148129463, 42.90864273905754, 50.244855880737305, 55.395327508449554, 53.57045643031597, 53.97828474640846, 54.74749647080898, 53.771735429763794, 52.6844921708107, 52.21707925200462, 53.32348108291626, 54.57319222390652, 53.8090456277132, 57.421770170331, 53.485033214092255, 53.774376288056374, 51.876028552651405, 49.844361171126366, 50.276242196559906, 51.59790627658367, 55.85420608520508, 58.77877235412598, 40.67310869693756, 28.124498650431633, 28.766215816140175, 12.083947230130434, 21.174076907336712, 31.32119871675968, 8.175014331936836, 2.1432016091421247, 0.20260719145881012, 0.445003918139264, 7.098682662472129, 37.881159111857414, 55.51771514117718, 47.13090777397156, 51.634122133255005, 58.299982845783234, 66.37304484844208, 48.008086904883385, 11.311040204018354, 0.3489543643081561, 0.2148094351287, 0.1666257347096689, 0.1558718367596157, 0.12962606619112194, 0.19896346901077777, 0.13909732515458018, 0.28574371710419655, 0.12295260748942383, 0.1949325532768853, 0.23669848713325337, 0.1594089571153745, 0.12722508487058803, 0.12885518255643547, 0.162256607436575, 0.13650519627844915, 0.11607404885580763, 0.15775129606481642, 0.21743412944488227, 0.1082125527318567], [0.029143419378669932, 0.034957452517119236, 0.010120404404005967, 0.03211088573152665, 0.04660229504224844, 0.027186843508388847, 0.047170921170618385, 0.061718191936961375, 0.0380608432169538, 0.02014942074310966, 0.0303931719463435, 0.013603985298686894, 0.05564208418945782, 0.0719849404413253, 0.03589403546357062, 0.04299813648685813, 0.10546278426772915, 0.030867949790263083, 0.00028820029456255725, 0.03316585236461833, 0.0076564750452234875, 0.057181079537258483, 2.4895036267116666, 18.694554157555103, 45.6629553437233, 50.014972016215324, 32.08077035844326, 30.300651378929615, 29.737388603389263, 44.38663803040981, 22.361304201185703, 4.132969826459885, 0.14515759918140247, 0.07363897981122136, 1.0808605514466763, 2.0171246118843555, 6.939672119915485, 3.075910247862339, 5.437930477783084, 7.643150221556425, 13.545334562659264, 25.471311919391155, 41.01236589252949, 52.41722971200943, 49.8188341408968, 47.58340269327164, 49.79822784662247, 50.386930257081985, 53.37048076093197, 48.14368262887001, 44.49780486524105, 39.17191945016384, 35.91472662985325, 33.86723689734936, 34.08595696091652, 34.71978195011616, 34.6768556535244, 34.92118254303932, 35.097971856594086, 34.44928966462612, 33.79854418337345, 34.252783209085464, 35.58967687189579, 42.02398180961609, 48.75870622694492, 49.36540827155113, 50.02168245613575, 50.56803613901138, 46.758561953902245, 47.00495593249798, 43.91297064721584, 47.283355593681335, 49.377620816230774, 48.29617224633694, 48.02406884729862, 47.57719002664089, 41.64730042219162, 36.821764558553696, 34.94887165725231, 35.39921969175339, 33.96725133061409, 37.771971970796585, 38.76512087881565, 43.01115743815899, 40.39285093545914, 47.12907627224922, 45.755788162350655, 53.67368929088116, 44.274468049407005, 31.51015877723694, 44.521614387631416, 43.00231151282787, 53.29871401190758, 49.65690203011036, 48.24315749108791, 45.191883221268654, 41.26761719584465, 37.331936582922935, 38.31064246594906, 35.98926343023777, 35.91924078762531, 34.861510545015335, 37.26431541144848, 36.340189799666405, 37.70479917526245, 46.44519656896591, 50.48168957233429, 49.51054148375988, 51.99288368225098, 50.40448151528835, 48.066808953881264, 39.66480240225792, 35.50429165363312, 35.06978116929531, 35.91428965330124, 34.90711949765682, 34.9470629543066, 41.184648647904396, 48.77769760787487, 50.514082834124565, 47.02470347285271, 48.80588449537754, 46.101729199290276, 46.09517455101013, 44.816866144537926, 45.30664086341858, 46.5240765362978, 48.97388108074665, 52.329484820365906, 53.115613237023354, 52.932235077023506, 52.06102542579174, 51.18326112627983, 46.77126847207546, 47.565110474824905, 50.44540911912918, 50.69711521267891, 37.34216943383217, 23.48159808665514, 17.69209574908018, 4.816407328471541, 10.944446325302124, 12.310719061642885, 7.047203974798322, 0.688077409286052, 0.09168170305201784, 0.057211318344343454, 6.576658124104142, 27.221944481134415, 43.42984177172184, 25.33275045454502, 27.237947322428226, 49.53541874885559, 46.20080508291721, 30.34466441720724, 4.460162669420242, 0.06438268392230384, 0.008655831625219434, 0.032399046831415035, 0.01939066936756717, 0.034525986411608756, 0.015381456814793637, 0.014258397204685025, 0.034249157906742766, 0.06845914525911212, 0.020961322879884392, 0.037617035195580684, 0.058180206979159266, 0.04804153089935426, 0.03047982696443796, 0.030032553113414906, 0.01558441472298, 0.01986579787626397, 0.010004668329202104, 0.02944446972833248, 0.024405908552580513, 0.06906995506142266, 0.057939457983593456, 0.02889963870984502, 0.08275373329524882, 0.018865087804442737, 0.018640862726897467, 0.008114806896628579, 0.019146150261803996, 0.028143907875346486, 0.03635722467151936, 0.024022526195039973, 0.04428976659255568, 0.02658961500856094, 0.05146652758412529, 0.08071426695096307, 0.005748892517658533, 0.031396249469253235, 0.033357018473907374, 0.023264682095032185, 0.014450635717366822, 0.022161288470670115, 0.030723555682925507, 2.903262237086892, 24.75630808621645, 53.150875344872475, 56.434510946273804, 36.43094792962074, 32.58042834699154, 29.333814159035683, 43.907149359583855, 25.35041380673647, 3.9863523188978434, 0.2616286970442161, 0.1596129289828241, 1.3101666094735265, 3.262511109933257, 5.605753222480416, 5.113447839394212, 11.730167213827372, 6.923297373577952, 17.03638583421707, 29.753982312977314, 44.65473644435406, 54.749050587415695, 51.48500673472881, 50.802722945809364, 48.57854649424553, 50.74746251106262, 55.85274696350098, 51.21480703353882, 47.19385899603367, 42.069932743906975, 37.739704102277756, 35.219610929489136, 35.552275478839874, 36.87634862959385, 37.0006437599659, 36.64403669536114, 36.25366844236851, 36.49880088865757, 36.135346591472626, 36.43379397690296, 37.25597105920315, 43.50912071764469, 51.98936507105827, 52.34263211488724, 51.32533170282841, 50.23437224328518, 48.240482434630394, 48.865229710936546, 46.94634787738323, 49.06658470630646, 51.751558631658554, 51.21691972017288, 50.716353580355644, 49.213021248579025, 42.96939007937908, 37.7948809415102, 37.89416581392288, 36.330207735300064, 35.2270433306694, 39.74407374858856, 39.38932478427887, 44.43961098790169, 41.732370257377625, 47.69006296992302, 48.43925356864929, 55.40809862315655, 45.28511501848698, 35.34637212753296, 44.67380382120609, 45.16011692583561, 55.23092173039913, 50.44545091688633, 51.182964742183685, 47.229349091649055, 43.70025046169758, 39.71771836280823, 41.68714888393879, 39.018829464912415, 37.52023167908192, 36.436480432748795, 38.082924485206604, 38.88747811317444, 39.69912976026535, 48.177884593605995, 53.46124269068241, 52.09756426513195, 53.54301430284977, 51.30965754389763, 50.75050614774227, 41.217756271362305, 38.33581991493702, 37.9591841250658, 38.222889974713326, 35.79368032515049, 37.50268802046776, 44.27625395357609, 52.10754632949829, 51.3219840824604, 50.5097396671772, 51.11425682902336, 48.83690223097801, 47.96700730919838, 48.78726169466972, 48.437722250819206, 50.307001546025276, 52.1182731539011, 54.8846273124218, 53.54246333241463, 54.19440574944019, 55.25745950639248, 54.58511218428612, 48.00033152103424, 51.44851729273796, 51.998028606176376, 54.58234593272209, 39.29046168923378, 23.61943569034338, 11.749071199446917, 9.455648213624954, 9.687111843377352, 10.941107254475355, 4.369992557913065, 1.9334850437007844, 0.17881027073599398, 0.14847842801827937, 8.079462759196758, 31.923986971378326, 50.15846751630306, 31.667958609759808, 35.635825395584106, 56.988118439912796, 54.743776470422745, 36.56258046627045, 6.104897763580084, 0.07857751988922246, 0.025651453142927494, 0.01439161271264311, 0.008710086331120692, 0.018401750166958664, 0.06641639862209558, 0.03508395158860367, 0.04894691024674103, 0.023927097136038356, 0.029552272244472988, 0.030443599025602452, 0.03980723173299339, 0.012622332651517354, 0.04430024200701155, 0.04525715237832628, 0.020466226887947414, 0.03596407565055415, 0.034737966052489355, 0.012221219458297128, 0.030529690011462662, 0.13831202901201323, 0.16258494841167703, 0.14550027844961733, 0.22824502433650196, 0.13042877311818302, 0.14065164956264198, 0.14927729062037542, 0.21622761996695772, 0.3177286492427811, 0.08208447936340235, 0.3652612486621365, 0.225397166213952, 0.13123308308422565, 0.10671631622244604, 0.15531365264905617, 0.15488553734030575, 0.1822890731273219, 0.1070747958146967, 0.12831993080908433, 0.08767659179284237, 0.11532097676536068, 0.18461549829225987, 3.554921569302678, 28.04327040910721, 60.31172789633274, 61.25804051756859, 44.57904830574989, 41.43906019628048, 39.58929665386677, 53.82217012345791, 28.611942194402218, 5.8556862361729145, 0.35804742481559515, 0.5801702651660889, 2.972563630901277, 8.035451620817184, 19.205584935843945, 9.81407443061471, 14.103163629770279, 12.775990795344114, 17.491191029548645, 29.424034617841244, 48.56752708554268, 56.32334791123867, 56.42606779932976, 52.81221091747284, 50.68816289305687, 52.54272177815437, 57.72707998752594, 54.88500729203224, 49.89605739712715, 43.729858472943306, 39.44143518805504, 37.5907026976347, 39.22781065106392, 38.03848586976528, 39.218124970793724, 37.36527979373932, 38.42953808605671, 39.951622411608696, 38.73536467552185, 38.57334516942501, 40.39294593036175, 46.03959113359451, 52.82856144011021, 54.158193692564964, 54.59207721054554, 53.03251549601555, 50.76214112341404, 50.21611802279949, 49.1840174049139, 52.209019884467125, 54.06155727803707, 52.332125678658485, 51.570304557681084, 50.82613728940487, 45.027051866054535, 39.32046867907047, 39.39267620444298, 38.442130610346794, 37.831716164946556, 41.28707595169544, 41.91609039902687, 45.87072439491749, 44.98862452805042, 50.630216002464294, 50.15098571777344, 56.895050033926964, 49.05442535877228, 36.01272337138653, 46.04253597557545, 48.596808314323425, 55.33528313040733, 53.701256811618805, 52.65598610043526, 49.675927609205246, 45.48812672495842, 42.238803282380104, 41.270949617028236, 40.29375605285168, 39.649595618247986, 38.44044350087643, 40.66966228187084, 41.3718456029892, 40.99388748407364, 51.30509398877621, 56.328230649232864, 53.3377493172884, 52.95794069766998, 53.68190445005894, 52.08017259836197, 43.230474069714546, 39.55816872417927, 38.74925673007965, 40.784872099757195, 37.937035113573074, 38.24682489037514, 46.681479290127754, 53.38642090559006, 56.0959605127573, 52.53675989806652, 52.13711254298687, 49.66735526919365, 50.201792791485786, 50.011054426431656, 50.72292722761631, 51.588323190808296, 55.00047169625759, 57.317078188061714, 54.314099326729774, 54.556974694132805, 57.173221707344055, 56.61648318171501, 50.8163870126009, 54.76102754473686, 56.22524857521057, 56.14049032330513, 40.889807268977165, 26.375845782458782, 21.128057576715946, 9.215597044676542, 20.455907844007015, 22.064640820026398, 11.848029289394617, 2.0619555562734604, 0.34929673187434673, 0.3976977034471929, 10.276387073099613, 37.42513798177242, 57.71373130381107, 36.824044436216354, 39.85636152327061, 65.37172257900238, 63.040072694420815, 42.9694052785635, 7.893847469240427, 0.16170115442946553, 0.11154479580000043, 0.17364450730383396, 0.16017736197682098, 0.15488041652133688, 0.08843754549161531, 0.0863627009675838, 0.12075558319338597, 0.12717555393464863, 0.1376387377968058, 0.20773546159034595, 0.20933894586050883, 0.1274833077332005, 0.1385806270991452, 0.23638647340703756, 0.12681231717579067, 0.10328555305022746, 0.08626441092928872, 0.1260619019740261, 0.0843785765755456], [0.09391191619215533, 0.09704383875941858, 0.035403869187575765, 0.03569120650354307, 0.06383527579600923, 0.001874921536000329, 0.025652764888945967, 0.03848291002213955, 0.030454972438747063, 0.011367468541720882, 0.015207256201392738, 0.009820091563597089, 0.016714130470063537, 0.022437384104705416, 0.02244321924081305, 0.047934138419805095, 0.0015551575847894128, 0.032123331548064016, 0.05351996485842392, 0.043558825345826335, 0.04678785422584042, 0.02157940387405688, 0.694922445109114, 14.53382397070527, 39.305292293429375, 47.52914160490036, 38.33138555288315, 34.9216765165329, 34.6774560213089, 37.51204691827297, 27.598230689764023, 8.063376322388649, 0.3226171463029459, 0.2782467193901539, 0.6379935436416417, 1.757389905396849, 5.94215439632535, 7.770321797579527, 11.940485928207636, 5.867800936102867, 7.037012921646237, 12.682011388242245, 31.946633756160736, 44.248458445072174, 50.23667111992836, 48.781242817640305, 51.31012871861458, 50.966364964842796, 47.94838830828667, 45.37538677453995, 41.25253200531006, 35.82703493535519, 36.94763280451298, 37.20146298408508, 34.22426573932171, 33.917219415307045, 33.589475601911545, 34.73068356513977, 34.84045967459679, 34.67882014811039, 34.45196472108364, 34.32298444211483, 35.1214773952961, 44.63402755558491, 49.237442538142204, 50.90549983084202, 47.314551919698715, 49.01495687663555, 47.721684873104095, 43.71717095375061, 41.6152149438858, 41.88796430826187, 47.68620237708092, 48.720446079969406, 49.28420662879944, 47.32315085828304, 41.915554627776146, 37.998090237379074, 34.31415371596813, 35.68466417491436, 34.699764624238014, 39.67931382358074, 42.845455929636955, 44.34549003839493, 41.658829003572464, 47.26176895201206, 44.1725043207407, 52.2791413217783, 42.2917952388525, 39.830830693244934, 47.11177580058575, 48.96830677986145, 52.189150750637054, 52.75097340345383, 50.618691220879555, 46.04724012315273, 40.58518901467323, 39.09915715456009, 38.200828358531, 35.80906569957733, 36.195276975631714, 34.38452214002609, 37.000719755887985, 35.854731649160385, 41.268213763833046, 46.082589626312256, 49.46240186691284, 50.47005459666252, 49.79515381157398, 52.0834556221962, 46.692285910248756, 42.23797872662544, 37.23908856511116, 35.61544708907604, 35.15660271048546, 35.265067890286446, 35.949753150343895, 37.49428667128086, 39.75459158420563, 45.2855633944273, 45.36553770303726, 44.687619879841805, 42.65395000576973, 40.85135333240032, 40.10536976158619, 40.895628556609154, 43.20021249353886, 45.9622348845005, 51.363721042871475, 51.51419296860695, 54.850049167871475, 52.89056271314621, 52.25340910255909, 53.06712783873081, 50.16872316598892, 52.20216125249863, 49.81143593788147, 35.79901523888111, 21.190074048936367, 7.2376359812915325, 10.044567212462425, 7.555303685367107, 5.527841253206134, 4.988976493477821, 2.902128710411489, 0.22556239797268063, 0.19606746034696698, 7.541154194623232, 29.964785501360893, 42.043873742222786, 34.08856742084026, 41.66050471365452, 47.363755479454994, 44.62173141539097, 30.742265582084656, 3.900504712946713, 0.03127866730210371, 0.10546913705184124, 0.030179015957401134, 0.016346923221135512, 0.04154598354944028, 0.09247059118933976, 0.022589181135117542, 0.029375475969573017, 0.049659861833788455, 0.024345573801838327, 0.03426011942792684, 0.03163538429362234, 0.0036498310191745986, 0.0489627179922536, 0.0276364198725787, 0.09928446423145942, 0.061905936745461076, 0.03025441816134844, 0.041317153445561416, 0.008700038579263492, 0.0327215174183948, 0.04300364693335723, 0.036773510146304034, 0.011342088946548756, 0.011732005914382171, 0.04444975878868718, 0.055094100898713805, 0.014202864149410743, 0.015439768285432365, 0.03748922252270859, 0.04618734172254335, 0.03012647375726374, 0.048666968432371505, 0.04448634295840748, 0.013603077095467597, 0.008108615529636154, 0.01930472681124229, 0.027371740325179417, 0.046061848261160776, 0.018064924588543363, 0.018627285135153215, 0.03122426787740551, 1.1243519489653409, 17.59070958942175, 46.142083033919334, 53.547289073467255, 41.12345293164253, 38.4200955927372, 38.43563675880432, 42.74345800280571, 30.11274766176939, 8.947824463248253, 0.3538242186186835, 0.18411530560115352, 0.5140620062593371, 4.235089821740985, 5.53006935864687, 9.57371262833476, 9.106413703411818, 5.799691015854478, 9.604618269950151, 18.290098160505295, 36.527223363518715, 49.34226751327515, 50.92046342790127, 50.937243327498436, 52.502873316407204, 53.64652834832668, 50.993807092309, 48.238434344530106, 42.24649406969547, 39.001832976937294, 38.86586107313633, 37.84179322421551, 36.517602279782295, 35.89815191924572, 34.41613644361496, 36.52573004364967, 35.72921298444271, 35.83878770470619, 35.103424564003944, 36.231850013136864, 36.68614983558655, 46.89916580915451, 50.93864165246487, 51.59409508109093, 49.73764009773731, 51.95781536400318, 51.216425746679306, 46.30471810698509, 43.54104280471802, 44.34532284736633, 49.869743809103966, 50.62579683959484, 51.958058550953865, 49.93066594004631, 43.02867069840431, 39.5714870095253, 36.50341384112835, 37.40415170788765, 37.237154468894005, 41.164452731609344, 43.33191342651844, 45.58059096336365, 43.21267582476139, 49.872692450881004, 47.152908593416214, 54.558433815836906, 44.83065940439701, 41.059399768710136, 48.31330172717571, 48.455531895160675, 54.16752979159355, 53.6896750330925, 52.841765731573105, 48.587950989603996, 42.19321332871914, 40.419422909617424, 39.68574307858944, 36.58862426877022, 37.99938976764679, 37.82440535724163, 39.53136496245861, 36.828144416213036, 43.23768608272076, 49.780133217573166, 51.91385172307491, 51.55619591474533, 50.58436766266823, 52.585986256599426, 48.79722096025944, 44.69719536602497, 39.33175407350063, 37.11279474198818, 36.79007425904274, 36.91071018576622, 38.44013951718807, 39.98291753232479, 44.255860447883606, 48.41924764215946, 48.09849165380001, 46.89003109931946, 45.345413982868195, 43.84032994508743, 42.5758907943964, 43.36793929338455, 45.2029862254858, 48.759572580456734, 53.44269588589668, 53.96685875952244, 54.89301726222038, 54.24906201660633, 55.47283574938774, 56.61340914666653, 52.028134390711784, 56.50666527450085, 52.6786594837904, 38.49560894072056, 22.1567839756608, 8.153321295976639, 10.040898509323597, 13.2490074634552, 7.814930928871036, 3.0471647903323174, 1.6413086280226707, 0.24543035920942202, 0.2747806522529572, 9.187453854829073, 36.00704647600651, 49.0700501203537, 30.830513946712017, 40.718432664871216, 54.33629393577576, 52.344243228435516, 34.24452245235443, 5.4248482547700405, 0.06074889883166179, 0.05290732195135206, 0.020810867281397805, 0.08203813966247253, 0.03909281440428458, 0.03274538859841414, 0.06888510833960027, 0.018745832094282378, 0.054579666393692605, 0.06466608043410815, 0.0701047464099247, 0.016571276319155004, 0.04267246353265364, 0.07937172180390917, 0.03062360323383473, 0.04621292726369575, 0.04271311467164196, 0.04120249534025788, 0.00706687999809219, 0.01057187510014046, 0.1751161416177638, 0.13795983541058376, 0.14984159002779052, 0.13906910869991407, 0.1721682123024948, 0.1289654805441387, 0.15390115266200155, 0.13436643057502806, 0.12901446229079738, 0.0970898667583242, 0.10965356603264809, 0.12275801636860706, 0.13972452899906784, 0.1296499781892635, 0.1328523750999011, 0.14152944699162617, 0.07427895601722412, 0.10881595590035431, 0.1578031128155999, 0.10908031632425264, 0.17427441256586462, 0.09375593159347773, 1.437282138504088, 21.362993270158768, 51.998575776815414, 62.88064084947109, 48.474595472216606, 46.01627178490162, 45.97624473273754, 46.40862733125687, 36.76721088588238, 10.605420917272568, 0.5751313199289143, 0.532735688611865, 1.9876760733313859, 6.019981820136309, 12.610143944621086, 18.922739513218403, 24.644122906029224, 10.395006258040667, 10.878412518650293, 16.5515261515975, 36.34099915623665, 49.95566099882126, 54.35557410120964, 50.27793690562248, 53.81994344294071, 56.36902906000614, 52.8751203417778, 51.272248551249504, 44.79125551879406, 39.56808619201183, 41.93053342401981, 40.31335920095444, 37.926711067557335, 39.22083802521229, 36.35245554149151, 39.296381771564484, 38.48164848983288, 36.9682314991951, 37.35306344926357, 37.16710142791271, 39.357756078243256, 51.14320747554302, 54.8831719905138, 55.481928661465645, 51.751216650009155, 52.662802934646606, 53.215669468045235, 48.64587128162384, 44.785308837890625, 46.77297078073025, 51.873026713728905, 53.585594817996025, 54.201268181204796, 51.79142229259014, 45.8479256182909, 40.87797850370407, 38.51172387599945, 38.49821180105209, 38.03911283612251, 43.082567006349564, 46.07817806303501, 47.8826480358839, 45.10910086333752, 50.72603926062584, 48.50909002125263, 56.43348500132561, 47.83105820417404, 42.91414484381676, 50.17244316637516, 50.60009881854057, 54.997002482414246, 57.467325925827026, 55.2237781137228, 51.78753510117531, 43.754640743136406, 42.635167613625526, 42.10911624133587, 40.37647381424904, 40.05767472088337, 40.072592720389366, 41.201215758919716, 39.66718107461929, 45.52000321447849, 51.238103583455086, 54.20783042907715, 53.30355875194073, 51.30249872803688, 56.02287903428078, 50.675570368766785, 46.172766387462616, 41.127545312047005, 39.27949547767639, 39.34559293091297, 38.45341980457306, 41.074842140078545, 41.37971878051758, 45.042714625597, 51.81675933301449, 49.93221625685692, 49.230196326971054, 46.86160862445831, 45.339007526636124, 43.49608741700649, 44.59261737763882, 47.18553364276886, 50.810371935367584, 55.73704317212105, 54.36671890318394, 56.160895228385925, 57.06271983683109, 58.786960914731026, 58.9334050565958, 55.400730818510056, 59.342228919267654, 53.75371299684048, 38.64423796534538, 24.653170220553875, 9.42602215334773, 15.662933383136988, 20.80990444868803, 15.661482810974121, 9.383452087640762, 5.1787772588431835, 0.46405196946579963, 0.5403201410081238, 10.628711767494678, 40.671679973602295, 57.16553471982479, 46.26741170883179, 54.316698387265205, 59.56713505089283, 61.98869951069355, 40.48606373369694, 6.362732453271747, 0.2544504666002467, 0.1509264318156056, 0.13663121295394376, 0.2154605955001898, 0.17660874902503565, 0.12950444302987307, 0.19393003050936386, 0.10971777664963156, 0.13515036116586998, 0.1597303367452696, 0.12911107507534325, 0.16492952650878578, 0.1407562626991421, 0.24955588392913342, 0.1357563099008985, 0.17233111371751875, 0.13441729737678543, 0.15743569034384564, 0.15187825105385855, 0.10287377241184004], [0.06686608816380613, 0.05063537784735672, 0.019765953038586304, 0.0410475683020195, 0.018902703559433576, 0.05165685506653972, 0.08049511816352606, 0.036103306265431456, 0.06311646124231629, 0.04013404388388153, 0.08035773178562522, 0.0291148318501655, 0.0579681753879413, 0.015850816052989103, 0.020871318920399062, 0.042077609905391, 0.06708129614708014, 0.04926371453620959, 0.044914306126884185, 0.016648214768792968, 0.02794293799524894, 0.04366306740848813, 0.32418518560007215, 8.646185249090195, 33.81121650338173, 46.73804685473442, 40.246908366680145, 37.96172998845577, 26.94687534123659, 40.21209083497524, 31.866980530321598, 11.336092259734869, 1.0064303828403354, 0.1534572444506921, 0.6023199891205877, 3.7505336478352547, 2.130440231412649, 5.1287006959319115, 8.04541278630495, 2.9394419956952333, 5.283704353496432, 11.787098608911037, 23.422693647444248, 36.12545192241669, 49.14107210934162, 51.38073652982712, 52.58177608251572, 48.83983567357063, 45.70172466337681, 42.40336485207081, 37.44214586913586, 36.07511602342129, 36.624475345015526, 35.41802868247032, 34.889089465141296, 37.837632447481155, 38.67442734539509, 38.66518244147301, 36.49913527071476, 36.12492375075817, 33.166417703032494, 35.71852035820484, 35.51655359566212, 46.04165822267532, 48.71919594705105, 46.57662391662598, 51.34617738425732, 49.7409725189209, 48.03188502788544, 42.070464715361595, 37.11627535521984, 40.692423060536385, 42.14359559118748, 46.40034757554531, 47.192920446395874, 45.4653849452734, 42.094080448150635, 36.73001088202, 35.56143298745155, 35.85939399898052, 36.64246737957001, 44.63389836251736, 45.926247015595436, 46.83456167578697, 45.562161952257156, 47.57510393857956, 46.4096000790596, 52.98989698290825, 43.18383917212486, 38.44344154000282, 55.129060596227646, 49.83179524540901, 52.50354588031769, 47.825434505939484, 48.67747038602829, 45.52878074347973, 41.273563876748085, 39.891612231731415, 38.89225825667381, 36.71066991984844, 37.18820929527283, 35.461422353982925, 37.287011593580246, 36.97001360356808, 44.02846924960613, 47.733551636338234, 50.65034732222557, 50.88092654943466, 50.042790323495865, 51.06033392250538, 47.4236174672842, 41.84043645858765, 36.92991815507412, 37.03409716486931, 35.147080421447754, 34.313796535134315, 35.9528461843729, 36.6593536734581, 38.62223334610462, 37.99721248447895, 38.20778198540211, 39.059734269976616, 37.24498584866524, 37.442332059144974, 37.63876631855965, 38.60058210790157, 41.11893117427826, 43.35070341825485, 48.3802655339241, 52.228759825229645, 51.730112582445145, 52.875827103853226, 53.22837598621845, 54.05723690986633, 54.667894542217255, 52.44797006249428, 47.1221986413002, 30.100153237581253, 17.647765427827835, 8.382804282009602, 13.699048664420843, 7.975313197821379, 5.604368196800351, 1.6148225055076182, 1.5973302628844976, 0.2066016974276863, 0.554100873414427, 9.336919784545898, 31.184240765869617, 38.23845013976097, 37.905325815081596, 35.71807198226452, 49.248564541339874, 48.659029975533485, 18.747660107910633, 2.1427548956125975, 0.10806102844071575, 0.04284536909835879, 0.08667433619848453, 0.010394276378065115, 0.044032256191712804, 0.08154300099704415, 0.038440707794507034, 0.018071203157887794, 0.002921535760833649, 0.010963801432808395, 0.03060185830690898, 0.04631533251085784, 0.027617816085694358, 0.09751660909387283, 0.01105101120629115, 0.024576452233304735, 0.05825103755341843, 0.03620222341851331, 0.015789089775353204, 0.07597646297654137, 0.04591885124682449, 0.044939713552594185, 0.03701258930959739, 0.04109399706067052, 0.03055008979572449, 0.03138806358037982, 0.03305367674329318, 0.0348485275026178, 0.03292396788310725, 0.03297038550954312, 0.07072025400702842, 0.08476147282635793, 0.07861069389036857, 0.04355434648459777, 0.04218443464196753, 0.039602777469553985, 0.08549307458451949, 0.0363564639701508, 0.01404208991516498, 0.0295300931611564, 0.022907681232027244, 0.008394388769374928, 0.4143310140352696, 12.248781435191631, 41.72623358666897, 53.60438860952854, 45.2062426507473, 41.43317811191082, 33.86795125901699, 42.62940712273121, 37.23956733942032, 12.465445809066296, 1.2414030055515468, 0.11699386668624356, 0.6345408351626247, 2.1192657435312867, 6.5390111692249775, 8.484541922807693, 7.892755502834916, 6.404589582234621, 5.832827612757683, 11.139287520200014, 26.98198925703764, 38.577293157577515, 50.021781250834465, 52.56503418087959, 54.449227675795555, 51.52275010943413, 47.25511930882931, 45.82379691302776, 39.448267221450806, 37.744514644145966, 38.16222243010998, 35.66884942352772, 36.138800606131554, 37.536601200699806, 40.32461419701576, 40.310209169983864, 37.48633749783039, 36.886102706193924, 36.04429587721825, 38.42746339738369, 37.76593789458275, 47.192285880446434, 51.91919803619385, 49.2148831486702, 52.041350081562996, 52.45509088039398, 49.85996313393116, 44.969538152217865, 40.38683205842972, 41.74784302711487, 44.071296751499176, 48.111460357904434, 48.48346419632435, 46.53112895786762, 42.752638310194016, 37.73924432694912, 36.69255629181862, 36.65820233523846, 37.67646409571171, 45.34728728234768, 47.60436236858368, 48.76227043569088, 46.924578845500946, 49.032162353396416, 49.211778715252876, 54.2666170746088, 45.652011930942535, 41.84933178126812, 55.85097245872021, 53.009462133049965, 54.29794259369373, 51.07934810221195, 50.45882239937782, 47.967337891459465, 43.69705103337765, 41.2571981549263, 39.428998455405235, 36.97681523859501, 38.745012357831, 35.95329836010933, 39.9241840839386, 38.05681228637695, 46.379984468221664, 52.15809501707554, 53.911640122532845, 53.37443634867668, 50.44292785227299, 52.13960520923138, 47.66909949481487, 44.01184134185314, 39.04014632105827, 39.150477200746536, 38.11779901385307, 35.476530343294144, 38.073937967419624, 37.426418513059616, 39.987663477659225, 38.881428837776184, 40.34885309636593, 41.632135435938835, 39.582039043307304, 38.215487971901894, 40.91828294098377, 40.14606177806854, 42.46285445988178, 46.09217271208763, 49.50218193233013, 54.0926244109869, 54.20485898852348, 54.61006924510002, 55.56871980428696, 57.58468642830849, 56.163209304213524, 54.73399959504604, 50.77713891863823, 33.087381944060326, 17.59099457412958, 7.891884874552488, 9.597348310053349, 7.979810256510973, 8.525277636945248, 3.4716870356351137, 0.5603015469387174, 0.30379221425391734, 0.7285370444878936, 10.564220678061247, 35.59229873120785, 43.364914655685425, 43.28366361558437, 42.11206868290901, 53.904720693826675, 53.67011748254299, 24.85265951603651, 3.4456047601997852, 0.07031147906673141, 0.015583509302814491, 0.026456249215698335, 0.0121901744932984, 0.09505995927611366, 0.019863784800691064, 0.04684304032707587, 0.0723793993529398, 0.05757998020271771, 0.0199024191533681, 0.058462304732529446, 0.012949845204275334, 0.05167282608454116, 0.04226030439895112, 0.009953050102922134, 0.04498423499171622, 0.0364406532025896, 0.06598558189580217, 0.037378067354438826, 0.04070584269356914, 0.12799120391719043, 0.13678440707735717, 0.06993253104155883, 0.16179583763005212, 0.20438839041162282, 0.1611164608038962, 0.13491656980477273, 0.23854037892306224, 0.1283453419455327, 0.12274861335754395, 0.16067424468928948, 0.20336980756837875, 0.17238285625353456, 0.11179603505297564, 0.1278399393777363, 0.13710583123611286, 0.14759923535166308, 0.10211134183919057, 0.15024184511275962, 0.17781464994186535, 0.10857619025046006, 0.12864503602031618, 0.814042134443298, 13.822420444339514, 47.74177819490433, 62.0283617824316, 50.99403128027916, 49.154538586735725, 37.16235928237438, 50.77836625277996, 42.00783647596836, 16.060324609279633, 1.6795306582935154, 0.4482331807957962, 1.1087837093509734, 7.8867399506270885, 9.77482158690691, 9.292280729860067, 14.884128123521805, 8.347774911671877, 8.913771640509367, 13.19552343338728, 28.603751733899117, 38.31308573484421, 50.3845439851284, 53.23627196252346, 56.90821632742882, 53.010602071881294, 50.19269607961178, 47.80805803835392, 41.629589572548866, 40.40877588093281, 42.102037221193314, 37.931137830019, 38.49637649953365, 40.69694861769676, 43.83225157856941, 42.81319186091423, 39.74755056202412, 39.71223525702953, 37.64664709568024, 39.96469371020794, 39.39349316060543, 50.88800556957722, 57.131340354681015, 49.21914651989937, 54.451138973236084, 53.86244036257267, 52.06274673342705, 45.65002083778381, 42.462497279047966, 43.791126385331154, 45.11513493955135, 49.472402930259705, 49.61874447762966, 49.80166666209698, 44.83472518622875, 39.638918191194534, 39.06620152294636, 37.88908548653126, 39.77140948176384, 48.06168682873249, 49.27267424762249, 50.954350009560585, 49.63662251830101, 50.34228265285492, 51.13007918000221, 56.20300456881523, 48.27814981341362, 43.18821653723717, 56.299340799450874, 55.309858694672585, 56.75066918134689, 53.24588544666767, 53.6198765784502, 50.65807990729809, 45.481906458735466, 44.003329798579216, 40.407187566161156, 40.52222639322281, 40.83463042974472, 38.54442112147808, 41.689314767718315, 40.45149698853493, 49.434389770030975, 52.68470115959644, 57.25604586303234, 53.878798484802246, 52.669027000665665, 54.27789866924286, 50.90924263000488, 46.06451019644737, 40.81112489104271, 40.62608242034912, 37.92665787041187, 36.963451355695724, 40.17078325152397, 40.252087488770485, 42.46177151799202, 41.20501175522804, 41.65211856365204, 43.0200831592083, 40.731158182024956, 40.862726122140884, 43.28285425901413, 42.461775317788124, 45.07449992001057, 46.69001363217831, 54.97568942606449, 56.24738998711109, 57.3194682598114, 54.580514430999756, 57.11561679840088, 58.48267704248428, 60.18072232604027, 56.314194202423096, 53.958066031336784, 33.24392594397068, 19.83408071100712, 11.97665048763156, 21.516111753880978, 17.827537581324577, 16.322504840791225, 6.2597679533064365, 2.8856076719239354, 0.6864974659401923, 1.0351258493028581, 13.522197604179382, 41.455015540122986, 52.05028340220451, 48.97802285850048, 49.96306300163269, 61.53980299830437, 62.56912976503372, 28.605978414416313, 4.39547399058938, 0.1293632123270072, 0.10863475312362425, 0.17621426784899086, 0.2009185086353682, 0.13277029356686398, 0.17223116126842797, 0.20287832769099623, 0.2550109662115574, 0.20487179572228342, 0.20386593329021707, 0.15142769319936633, 0.23732448869850487, 0.11090756554040127, 0.2275327852112241, 0.06917477599927224, 0.1220587054558564, 0.16004828765289858, 0.1898797001922503, 0.13374123052926734, 0.14636312902439386], [0.031442693070857786, 0.04044761983095668, 0.03176980208081659, 0.0869775480532553, 0.03978157568781171, 0.02281408156704856, 0.09231899268343113, 0.05534194853680674, 0.040019727166509256, 0.0879444922611583, 0.019479734510241542, 0.04397010874527041, 0.047306919732363895, 0.026635238536982797, 0.034029589805868454, 0.06262302209506743, 0.03177664097165689, 0.02872420798667008, 0.0687955979083199, 0.010888595897995401, 0.034910148024209775, 0.055360914120683447, 0.10270350147038698, 4.221510300412774, 27.011361680924892, 41.70119293034077, 40.083688125014305, 34.31430570781231, 33.06820057332516, 33.18574346601963, 35.33906511962414, 18.02484769374132, 2.2902710549533367, 0.05303059639118146, 0.30713603482581675, 1.8797229160554707, 5.365620832890272, 8.037919588387012, 3.281656145118177, 4.865466495975852, 3.1860646745190024, 3.6580150248482823, 13.448895737528801, 27.1556893363595, 42.150290831923485, 51.78523242473602, 49.65439036488533, 44.779358357191086, 42.15003244578838, 38.394728153944016, 36.11450470983982, 35.728057846426964, 38.9187466353178, 43.47121015191078, 43.1616635620594, 44.38813515007496, 44.30796705186367, 43.07080663740635, 40.547863617539406, 39.07072328031063, 36.59103333950043, 35.7537292689085, 39.0524310618639, 45.39633505046368, 47.25470133125782, 49.987678080797195, 48.785282000899315, 51.2983987480402, 46.68711818754673, 43.4320342540741, 36.61371432244778, 36.22424282133579, 40.545925721526146, 42.362938821315765, 40.851699113845825, 42.50814042985439, 41.41390934586525, 37.478228732943535, 33.57049562036991, 36.30462370812893, 35.877241641283035, 48.84193316102028, 50.05963861942291, 47.75404393672943, 45.15595994889736, 49.59890194237232, 45.18565155565739, 54.90298792719841, 41.61729343235493, 41.697332337498665, 52.34684228897095, 43.97418916225433, 47.4255895614624, 46.89348891377449, 47.42641791701317, 41.664361506700516, 37.294861972332, 35.47365389764309, 35.74036918580532, 35.194228291511536, 36.506172493100166, 36.514661237597466, 39.06567335128784, 38.13647121191025, 46.583790332078934, 49.40801918506622, 50.62171205878258, 50.18862269818783, 51.30306489765644, 49.404975548386574, 45.72589136660099, 43.58952820301056, 36.90887488424778, 37.943167984485626, 37.45881177484989, 35.541172474622726, 36.423257142305374, 35.11448197066784, 35.85301034152508, 36.896943524479866, 37.041366174817085, 37.09784634411335, 34.65875722467899, 36.837628707289696, 36.146366000175476, 38.61937589943409, 37.34172485768795, 41.03555224835873, 44.79841433465481, 50.793858021497726, 53.81265163421631, 52.01352417469025, 55.366943031549454, 57.57814697921276, 53.7113718688488, 52.19800807535648, 42.48009033501148, 26.453241929411888, 13.426219504326582, 4.730671104043722, 4.646071018651128, 7.719819657504559, 5.239535523578525, 2.7351528452709317, 0.45898081501945853, 0.16155680670635775, 1.138226785697043, 11.157023068517447, 40.7796435803175, 46.06941573321819, 34.58673968911171, 39.85537737607956, 53.37950527667999, 39.72740784287453, 14.292926397174597, 1.3191325846128166, 0.026457902349648066, 0.03748344490304589, 0.02804352126986487, 0.09380032686749473, 0.06518591035273857, 0.06710832516546361, 0.03270649634941947, 0.03328807666548528, 0.0394250108365668, 0.07078696566168219, 0.01394672115566209, 0.03210046597814653, 0.0361109095683787, 0.06076788296923041, 0.09069606414414011, 0.04909590381430462, 0.02434328242088668, 0.07629677391378209, 0.02069703481538454, 0.07000412602792494, 0.02118272037478164, 0.05626783342449926, 0.039632166517549194, 0.13209477590862662, 0.016531493492948357, 0.05972578888759017, 0.0026669658882383374, 0.06514213848276995, 0.04527365032117814, 0.0025201871676472365, 0.038648869085591286, 0.11407384212361649, 0.03352586449182127, 0.03282823825429659, 0.008523129126842832, 0.049189458950422704, 0.02416213716060156, 0.02662102269823663, 0.06273979903198779, 0.014250168642320205, 0.034313743308302946, 0.036069475463591516, 0.20043945231009275, 6.35455054230988, 31.901587173342705, 49.041988626122475, 47.96216256916523, 40.87247259914875, 36.982309743762016, 40.81319198012352, 38.58455076813698, 20.416625551879406, 2.5339469918981194, 0.11538031147210859, 0.07138924818718806, 2.527874205261469, 3.841080889105797, 9.88456729799509, 7.7193166594952345, 8.15153919160366, 5.080767218023539, 8.797020055353642, 17.900744453072548, 29.200008139014244, 46.13902419805527, 52.704855278134346, 53.433891758322716, 46.6119734197855, 46.68711818754673, 40.11833846569061, 36.268107667565346, 37.151651456952095, 39.85291890799999, 42.974348813295364, 44.6884710341692, 45.0610638409853, 46.82543456554413, 44.12910684943199, 41.479478627443314, 40.93487665057182, 38.07920068502426, 37.19541370868683, 40.63804417848587, 48.2843928784132, 49.55301560461521, 50.61608836054802, 50.346257239580154, 53.41899275779724, 49.4649363309145, 44.7412122040987, 38.51611644029617, 38.991406336426735, 40.84533825516701, 44.3035326898098, 44.79042336344719, 44.85430173575878, 43.22918213903904, 38.14921572804451, 36.67126603424549, 37.06946186721325, 38.11215251684189, 49.2835758626461, 51.29135772585869, 50.827710404992104, 49.448528811335564, 51.63574084639549, 47.18284718692303, 56.25342406332493, 43.238696828484535, 43.464043736457825, 53.70267033576965, 47.19347521662712, 49.13775868713856, 48.82423371076584, 48.882397189736366, 45.26264302432537, 38.453982174396515, 36.40700541436672, 38.11348244547844, 36.89898021519184, 39.17899087071419, 37.683991491794586, 39.45771351456642, 40.454213842749596, 49.29245598614216, 51.68513059616089, 52.6642544567585, 51.36118657886982, 52.02456258237362, 52.447985261678696, 48.505867794156075, 44.891513139009476, 39.42363694310188, 38.82574662566185, 39.29835766553879, 36.65759816765785, 37.43648037314415, 37.533264979720116, 37.87311494350433, 38.8392549008131, 38.49532775580883, 38.32941725850105, 37.97212243080139, 38.367286026477814, 38.80681224167347, 39.28375504910946, 38.545352071523666, 43.09900872409344, 47.22508192062378, 55.110228806734085, 57.328534573316574, 53.45482103526592, 56.43415376543999, 57.44556449353695, 58.25156584382057, 52.910625636577606, 46.267651095986366, 28.056294210255146, 13.606327939778566, 4.712555101141334, 10.204412285238504, 7.525615403428674, 6.709628663957119, 2.827990176156163, 0.263419677503407, 0.05548328314034734, 0.9482283715624362, 12.477494962513447, 41.769543662667274, 47.26904176175594, 38.209693282842636, 43.590022176504135, 58.74687686562538, 47.8570032119751, 17.121892645955086, 1.4851182466372848, 0.01778064306563465, 0.1348877596319653, 0.0591378038370749, 0.06635451092734002, 0.023802581454219762, 0.04818922570848372, 0.015153078493312933, 0.034170709186582826, 0.024820898979669437, 0.04765519479406066, 0.03661975570139475, 0.029726858774665743, 0.04124152859731112, 0.05168247771507595, 0.02159802992537152, 0.01629436061193701, 0.0014817969827163324, 0.05800860388262663, 0.01987997104151873, 0.0378520065714838, 0.10366479051299393, 0.21167322294786572, 0.11415441709687002, 0.2752981963567436, 0.08710381705895998, 0.1569428449147381, 0.185962199466303, 0.30287818517535925, 0.2119480847613886, 0.18406543327728286, 0.1439404918346554, 0.18183357256930321, 0.14791029912885278, 0.11566712186322547, 0.051781910660793073, 0.17236808751476929, 0.12162041530245915, 0.08404654712649062, 0.19484126911265776, 0.11370915817678906, 0.13514972291886806, 0.1528390948078595, 0.24989652971271425, 7.875047503039241, 37.327099442481995, 55.36765359342098, 52.93269485235214, 45.43707646429539, 44.65265415608883, 44.28850829601288, 47.64160796999931, 24.42858327180147, 3.5213164100423455, 0.24209349998272955, 0.7626752438955009, 5.1827076729387045, 11.190486922860146, 20.589533373713493, 11.447478532791138, 11.616152431815863, 6.447598999366164, 5.613568928092718, 16.354035548865795, 30.05238600075245, 45.99921829998493, 55.349870547652245, 54.786797761917114, 49.3781565874815, 47.89704546332359, 43.33322815597057, 38.95743615925312, 40.360203087329865, 43.38894456624985, 48.30622650682926, 47.42776684463024, 48.527237847447395, 48.78233715891838, 47.85609506070614, 44.366350919008255, 42.238666489720345, 39.82606954872608, 39.371648132801056, 42.24620148539543, 51.34990878403187, 51.626731529831886, 52.77214206755161, 51.360137835145, 55.40866099298, 50.845307260751724, 47.21316196024418, 40.59720776975155, 40.17731510102749, 44.6651516854763, 45.30582770705223, 45.105335265398026, 47.20459342002869, 46.05289041996002, 39.77729916572571, 36.68131649494171, 38.68307948112488, 40.00233069062233, 51.118349209427834, 54.44540128111839, 51.52077801525593, 50.62153346836567, 52.214525789022446, 49.39241722226143, 56.901217103004456, 44.26339164376259, 47.11762748658657, 54.740774631500244, 48.96764561533928, 51.719359159469604, 52.15472459793091, 51.55404902994633, 46.891247034072876, 40.636110082268715, 39.532132521271706, 39.74787354469299, 37.89766922593117, 40.5897031724453, 40.33302314579487, 41.05512119829655, 43.10889199376106, 52.8353288769722, 55.47003909945488, 53.66970710456371, 52.41087265312672, 53.90059791505337, 53.765408769249916, 50.559497997164726, 47.09373816847801, 41.395229548215866, 40.80706290900707, 41.10758118331432, 39.59797538816929, 40.74079446494579, 39.35688212513924, 38.748489171266556, 41.232324689626694, 41.36456899344921, 39.5314409583807, 38.889678195118904, 40.61428025364876, 40.41436158120632, 42.81280428171158, 41.17094658315182, 45.78891098499298, 49.54723611474037, 57.3848095536232, 58.178396970033646, 55.803026631474495, 55.98315976560116, 58.349376395344734, 59.56921733915806, 55.28660774230957, 46.264090687036514, 30.44017419219017, 15.366789624094963, 7.095574904233217, 11.06204716488719, 14.623395614326, 14.20936033129692, 5.944380601868033, 0.6798091123346239, 0.3180101013276726, 2.0574789214879274, 15.232000406831503, 50.11635057628155, 58.54847431182861, 46.848594322800636, 52.661233618855476, 66.8664787709713, 53.2746385037899, 22.194413356482983, 2.5771592231467366, 0.08976577460998669, 0.3150953014846891, 0.18294726905878633, 0.29258611088152975, 0.10332030782592483, 0.1730370000586845, 0.10040757115348242, 0.1445173186948523, 0.1341528701595962, 0.10640148975653574, 0.14212965150363743, 0.1282103601261042, 0.17845218448201194, 0.10982713210978545, 0.1390470817568712, 0.1240830023016315, 0.07749863754725084, 0.21901781321503222, 0.10277272158418782, 0.13833224511472508], [0.09889732289593667, 0.04417144969920628, 0.05832209819345735, 0.029718429832428228, 0.05334502209734637, 0.02550455985328881, 0.054379976718337275, 0.049975044530583546, 0.00856165679579135, 0.045163508184487, 0.04369617090560496, 0.011928864296351094, 0.028012542170472443, 0.057393656607018784, 0.08121392529574223, 0.028142549745098222, 0.012332289279584074, 0.02927377947344212, 0.10115714772837237, 0.03075058470130898, 0.05728999341954477, 0.030426822777371854, 0.04653967262129299, 2.5222350703552365, 21.759826876223087, 42.35978499054909, 44.95482534170151, 31.51017777621746, 23.589664287865162, 35.704202726483345, 40.196450874209404, 24.87585537135601, 4.778966512531042, 0.30846379639115185, 0.17737575864885002, 0.8535122196190059, 3.3961846120655537, 8.332462683320045, 7.71222529001534, 7.564862072467804, 3.7430675234645605, 4.056353587657213, 7.8382764011621475, 17.518665455281734, 33.549790531396866, 46.88420221209526, 51.570194363594055, 44.73598748445511, 41.17591291666031, 37.176460325717926, 38.56154680252075, 43.405561074614525, 45.756688714027405, 45.59606373310089, 48.11634309589863, 46.40045776963234, 47.65038549900055, 46.815064921975136, 46.49313099682331, 43.66300106048584, 43.585204035043716, 39.691055193543434, 42.23166346549988, 46.726560071110725, 46.565878093242645, 49.93556387722492, 49.73804667592049, 47.884775921702385, 47.072919085621834, 43.01437966525555, 37.360670641064644, 36.07706531882286, 38.3737076818943, 39.79724429547787, 40.49003452062607, 40.79193592071533, 38.8546022772789, 37.525057420134544, 35.19743151962757, 35.43712265789509, 39.22809183597565, 50.276584178209305, 48.78786586225033, 50.702522322535515, 48.266355246305466, 50.27775451540947, 49.270998537540436, 54.154420495033264, 41.61048039793968, 42.786217108368874, 50.848240703344345, 45.27211971580982, 44.09174345433712, 41.107729375362396, 39.34037961065769, 36.967729926109314, 35.397794768214226, 38.28551061451435, 34.42751683294773, 36.41992472112179, 35.67726597189903, 36.407529786229134, 36.032657101750374, 38.854005709290504, 47.02673256397247, 47.40679956972599, 51.016013100743294, 49.22263853251934, 50.911241322755814, 50.680810287594795, 45.687760412693024, 42.150351628661156, 36.83335393667221, 38.71316246688366, 40.998352244496346, 41.1191363632679, 42.112087681889534, 40.611498802900314, 38.37332770228386, 37.970161736011505, 37.48139016330242, 36.053426787257195, 37.022826969623566, 35.70357196033001, 36.381094604730606, 36.37175850570202, 38.559662103652954, 36.88493236899376, 41.090569496154785, 46.994251906871796, 50.8617527782917, 54.247504100203514, 54.63867411017418, 53.77254098653793, 55.821763426065445, 44.75320816040039, 32.82805345952511, 19.359562173485756, 6.934174289926887, 3.375770919956267, 8.38337330147624, 2.7458974812179804, 5.626699598506093, 2.6921253791078925, 0.1877949183108285, 0.09059859046828933, 1.5504220174625516, 14.207098502665758, 33.32606613636017, 42.68318563699722, 38.848218619823456, 41.24462082982063, 48.58102776110172, 37.840212509036064, 14.602208901196718, 1.092499801889062, 0.09054679598193616, 0.028885276296932716, 0.030268014306784607, 0.05326334503479302, 0.03363564668688923, 0.0439084511162946, 0.030728670935786795, 0.10774735230370425, 0.019675752409966663, 0.005105878608446801, 0.06159881377243437, 0.050672759825829417, 0.025192722387146205, 0.07884558363002725, 0.07624913545441814, 0.1491601945599541, 0.01512724433268886, 0.014949653959774878, 0.02737785005592741, 0.04903263572487049, 0.03610189989558421, 0.014320677310024621, 0.07112984530976973, 0.03215166674635839, 0.03753110191610176, 0.02499104190064827, 0.07031061075394973, 0.02006803497351939, 0.03939368478313554, 0.01671958525548689, 0.02917454876296688, 0.055888280548970215, 0.0643434762605466, 0.007431235544572701, 0.08801210191450082, 0.027193587775400374, 0.019101910838799085, 0.040633357129991055, 0.02897401118389098, 0.014795179631619249, 0.0555746303871274, 0.031073090540303383, 0.06624666202696972, 3.6667500436306, 26.497032679617405, 48.0059590190649, 48.82982321083546, 35.805467292666435, 28.20016399025917, 38.20372760295868, 44.18397590517998, 27.168639041483402, 4.851906448602676, 0.2552754379576072, 0.10808838400407694, 0.5988621746655554, 2.0430510956794024, 8.640898782759905, 7.2044276632368565, 9.938225168734789, 5.593079002574086, 6.619714563712478, 14.661619663238525, 20.247557424008846, 37.13987208902836, 49.507475048303604, 53.109130784869194, 46.64648316800594, 44.2879269272089, 38.63884225487709, 40.6837747246027, 44.52400825917721, 46.91642068326473, 49.081392511725426, 49.89688955247402, 48.955645859241486, 50.89271731674671, 47.49082826077938, 48.82924944162369, 45.360077396035194, 43.29876020550728, 40.566573813557625, 44.49637234210968, 48.40875260531902, 49.92313094437122, 51.09462708234787, 50.39262615144253, 50.664106383919716, 48.26450854539871, 43.32234174013138, 38.51299300789833, 37.62830168008804, 39.02572609484196, 42.36839532852173, 42.81851537525654, 42.441564202308655, 40.06390638649464, 39.40059117972851, 36.578665003180504, 38.2942995429039, 40.91446414589882, 51.426113694906235, 51.37469485402107, 51.749955117702484, 50.42845822870731, 52.003276124596596, 50.65750993788242, 55.43291889131069, 43.17520223557949, 44.95539911091328, 52.02730983495712, 48.48168969154358, 45.90425759553909, 44.3161366134882, 42.446245551109314, 39.376287683844566, 37.02372372150421, 39.99639540910721, 36.44374184310436, 37.753998935222626, 37.78744474053383, 38.39370220899582, 37.812094017863274, 41.653083711862564, 48.874619007110596, 50.79516515135765, 53.65080311894417, 48.892120867967606, 52.4754273891449, 52.755498960614204, 49.025448113679886, 44.11905258893967, 37.38008759915829, 40.631231144070625, 41.48181550204754, 41.952040269970894, 42.902411073446274, 41.333049684762955, 39.38244715332985, 39.25486899912357, 39.052951633930206, 36.77041791379452, 37.74013347923756, 37.35209450125694, 38.105856254696846, 38.127165511250496, 38.640122786164284, 39.39100809395313, 43.69543232023716, 49.837259352207184, 54.64489437639713, 56.36324197053909, 57.17515580356121, 55.652368515729904, 57.33443185687065, 47.07107238471508, 36.45806327462196, 24.3272503092885, 9.337616097182035, 4.272138308733702, 11.027705557644367, 7.873714249581099, 4.381021941080689, 1.8796460889279842, 0.5379311973229051, 0.0552808957581874, 2.0374577958136797, 15.904098842293024, 38.72381329536438, 49.94939513504505, 44.38687741756439, 49.39785473048687, 55.88370770215988, 44.57803376019001, 16.73557497560978, 1.5605913405306637, 0.05601180731900968, 0.0363408157863887, 0.015910208276181947, 0.08990212940261699, 0.022600315205636434, 0.013546274039981654, 0.031263464406947605, 0.04075044947967399, 0.0347103804233484, 0.020943754389008973, 0.018648354707693215, 0.02617529436975019, 0.047779504529898986, 0.04631402262020856, 0.02187483431043802, 0.04293171426979825, 0.0364089820504887, 0.025933424731192645, 0.03521575330523774, 0.04420148070494179, 0.25075629295315593, 0.09875178031506948, 0.2644371322821826, 0.19942018669098616, 0.11031552465283312, 0.09848702655290253, 0.1268068846547976, 0.243169940658845, 0.1469425088725984, 0.10661957727279514, 0.2058185386704281, 0.12465628911741078, 0.1321024348726496, 0.1272217303630896, 0.13418559887213632, 0.09230420168023556, 0.11044192724511959, 0.14374499529367313, 0.1885094284079969, 0.11452180988271721, 0.16457133635412902, 0.08105309447273612, 0.1513863555737771, 5.089794583618641, 29.513683207333088, 54.401335045695305, 57.22474314272404, 43.109811544418335, 33.12220327556133, 47.34171286225319, 49.39967483282089, 32.58898928761482, 6.655650185421109, 0.6704034889116883, 0.6221298105083406, 3.6652161134406924, 9.044107496738434, 16.34818196296692, 16.24407894909382, 15.817050263285637, 8.637215830385685, 5.529229128733277, 11.770856380462646, 18.699522390961647, 38.58366161584854, 51.292607858777046, 56.92056566476822, 49.41560737788677, 46.338395699858665, 40.85780918598175, 42.51469887793064, 49.27638664841652, 49.9930813908577, 50.119914785027504, 53.91251787543297, 49.91502597928047, 52.935039326548576, 50.43421491980553, 51.46936297416687, 48.41461569070816, 46.8300437182188, 42.92161524295807, 47.976290211081505, 50.6519166380167, 51.48099794983864, 53.41368444263935, 51.906727105379105, 53.31246167421341, 51.12353213131428, 46.322960928082466, 41.74466259777546, 39.61602441966534, 43.08461129665375, 44.01787541806698, 44.95485953986645, 43.183386996388435, 42.44156040251255, 40.8233792334795, 37.34014414250851, 39.46922309696674, 42.75984272360802, 52.98783369362354, 53.11581842601299, 54.30212616920471, 52.683245837688446, 53.67110922932625, 52.904192581772804, 57.275960594415665, 44.783412739634514, 48.36204931139946, 53.7288661301136, 51.16007477045059, 47.768908739089966, 45.42869031429291, 43.567778170108795, 41.84336610138416, 38.03624019026756, 42.481481060385704, 37.636965215206146, 40.054026916623116, 39.931863471865654, 40.927451848983765, 39.40371461212635, 44.19689521193504, 51.82988002896309, 51.71917676925659, 55.048865899443626, 50.31484052538872, 54.03957925736904, 54.20661449432373, 51.49382226169109, 47.39842101931572, 40.52717752754688, 42.92208641767502, 46.331955045461655, 45.1375537365675, 45.716935247182846, 44.46111783385277, 42.989639192819595, 42.03354589641094, 42.012616619467735, 39.48405370116234, 40.87827488780022, 38.526398688554764, 39.93501350283623, 39.99041832983494, 40.73411822319031, 40.64178317785263, 45.35772532224655, 52.52148851752281, 55.92790313065052, 57.088885232806206, 58.04388038814068, 55.23057594895363, 58.85458588600159, 48.79388853907585, 36.690777987241745, 21.871157102286816, 8.64994514733553, 8.188590053468943, 12.975728027522564, 11.226312350481749, 13.645530436187983, 8.413642477244139, 1.2309780274517834, 0.21979736513458192, 2.48637021984905, 19.861167557537556, 42.634867429733276, 55.1834736764431, 53.72442416846752, 54.21469286084175, 64.59684535861015, 52.48615801334381, 19.766083359718323, 1.9251364166848361, 0.16121442429721355, 0.06752853660145774, 0.05271355090371799, 0.1880983676528558, 0.07887152169132605, 0.16209830733714625, 0.07735559600405395, 0.13932859321357682, 0.13222874840721488, 0.07286695326911286, 0.10875250969547778, 0.11971037209150381, 0.12084404719644226, 0.1396650681272149, 0.16697448474587873, 0.3388996288413182, 0.14069301687413827, 0.15064410399645567, 0.11221314431168139, 0.29120948631316423], [0.010166120700887404, 0.06303823887719773, 0.03469328134087846, 0.061722837781417184, 0.08487594910548069, 0.05593161084107123, 0.06988320790696889, 0.04001939691079315, 0.03304992147604935, 0.06168550404254347, 0.0369333093840396, 0.012079752195859328, 0.019174370427208487, 0.051430629901005886, 0.09949010593118146, 0.015671900946472306, 0.038778462912887335, 0.07482348461053334, 0.0557139945885865, 0.08091569325188175, 0.0420415786356898, 0.06498132250271738, 0.12399904313497245, 0.9454058355186135, 15.137156546115875, 43.23244236409664, 45.02214252948761, 36.76751486957073, 32.44355969130993, 33.560224771499634, 32.88036525249481, 32.441173419356346, 7.42790887132287, 0.7525616115890443, 0.058036141272168607, 0.8561688114423305, 1.0670875967480242, 4.350567050278187, 5.555050168186426, 8.31447159871459, 4.486338514834642, 8.664366323500872, 7.872844096273184, 10.733607038855553, 27.25429594516754, 43.571019396185875, 51.22500568628311, 44.83538255095482, 43.39375510811806, 42.98799768090248, 45.69861263036728, 45.2410601824522, 48.69561821222305, 49.79567438364029, 49.624193385243416, 48.815501779317856, 47.893728241324425, 48.49873937666416, 47.72370256483555, 43.923040106892586, 45.489262863993645, 45.35761892795563, 45.53439304232597, 43.41358624398708, 47.368824407458305, 48.99344243109226, 51.17158055305481, 48.12762849032879, 46.08504429459572, 40.20460143685341, 35.68441718816757, 35.41590839624405, 37.86017283797264, 36.98679730296135, 38.926749005913734, 40.04574716091156, 38.42915430665016, 36.80722273886204, 35.54160185158253, 34.0083347260952, 40.66082015633583, 49.24525871872902, 49.60897900164127, 50.7026819139719, 47.78268299996853, 48.373577892780304, 47.404770478606224, 50.01292012631893, 40.84471508860588, 40.98218031227589, 52.800648137927055, 45.471023842692375, 43.05965043604374, 37.0397512614727, 36.690785586833954, 36.21298402547836, 37.334851026535034, 34.78040389716625, 34.7308811545372, 34.36024144291878, 35.99750518798828, 35.779613479971886, 36.05486311018467, 38.90057221055031, 48.61909031867981, 49.56665687263012, 48.75065065920353, 49.60423305630684, 48.18878620862961, 50.92224933207035, 46.90409794449806, 44.46916200220585, 43.01129423081875, 43.90662878751755, 45.46883136034012, 48.914243280887604, 44.97640058398247, 47.65494905412197, 46.776534989476204, 43.08014273643494, 39.72979411482811, 39.90331560373306, 40.60174472630024, 39.47397284209728, 37.59640999138355, 37.21764251589775, 35.503569692373276, 38.55911873281002, 40.481234192848206, 44.16037157177925, 47.54102736711502, 50.59030294418335, 57.64406584203243, 53.640672862529755, 47.39264912903309, 36.95778585970402, 26.938705779612064, 15.10408977046609, 4.732237095013261, 2.2394430823624134, 13.175476659089327, 8.655106220394373, 2.319707600399852, 0.5466323741711676, 0.2245247716200538, 0.14610308047849685, 1.3308637426234782, 17.029046528041363, 39.7911836206913, 40.68391531705856, 31.81585807353258, 38.57326917350292, 53.432527631521225, 30.031346529722214, 11.597846914082766, 0.29848829261027277, 0.015551158157904865, 0.03229614805604797, 0.10353164179832675, 0.03097365017310949, 0.04915157602226827, 0.02361640628805617, 0.03335378642077558, 0.08700156395207159, 0.017780947346182074, 0.03851990608382039, 0.04012424011307303, 0.033342891692882404, 0.0498781163332751, 0.11140671180328354, 0.04630024093785323, 0.02283379486470949, 0.027535565714060795, 0.06435955860069953, 0.03855696151731536, 0.07368910446530208, 0.056371581958956085, 0.02523104503779905, 0.06676741963019595, 0.05081480318040121, 0.022278176729741972, 0.008395164313697023, 0.025377227721037343, 0.05278757642372511, 0.027224364639550913, 0.07945689809275791, 0.04474420959013514, 0.03325393045088276, 0.05770922522060573, 0.06269783800235018, 0.02961712296382757, 0.04273473714420106, 0.041274565301137045, 0.062106817567837425, 0.05204712455451954, 0.03780532548262272, 0.06996923766564578, 0.05274319228192326, 0.08164728758856654, 1.0461747064255178, 18.955860435962677, 49.23896245658398, 51.41830891370773, 41.55673988163471, 35.610606148839, 41.295439302921295, 41.64670765399933, 38.43592554330826, 8.762475159019232, 0.6821553083136678, 0.20093350001843646, 0.9414321393705904, 2.4287605611607432, 6.665244670584798, 7.752410508692265, 10.056404527276754, 5.62116852030158, 8.956981021910906, 10.243002064526081, 16.397767402231693, 30.95578372478485, 47.093878760933876, 53.76751005649567, 46.889951303601265, 45.00643417239189, 44.24842044711113, 47.05666735768318, 48.28597739338875, 50.348084941506386, 53.545077592134476, 50.859670490026474, 50.63415639102459, 49.892569184303284, 50.107816234230995, 49.604932218790054, 46.73870041966438, 47.50978924334049, 47.411537915468216, 47.51523055136204, 46.626530438661575, 49.78133015334606, 49.829997941851616, 53.143180757761, 50.10934755206108, 47.72229664027691, 43.13761845231056, 37.440994530916214, 37.98075556755066, 38.381273075938225, 40.506255850195885, 41.510872542858124, 41.82652920484543, 40.577285438776016, 36.64008870720863, 36.753007248044014, 36.17019832134247, 43.86264614760876, 52.95343413949013, 51.0769048333168, 52.4276639521122, 49.70250338315964, 51.13235525786877, 49.46261465549469, 50.113398134708405, 42.274023592472076, 43.38897876441479, 54.61655929684639, 47.25892670452595, 45.393109023571014, 40.569336265325546, 38.297202587127686, 38.14773000776768, 37.9524052888155, 37.32486896216869, 35.90080417692661, 36.17371693253517, 39.22200836241245, 38.04063655436039, 39.446207731962204, 41.2891810387373, 50.36433286964893, 51.744734197854996, 50.936711356043816, 50.94162829220295, 49.1906176507473, 52.57604978978634, 49.208518490195274, 47.189147248864174, 44.84430067241192, 43.94712321460247, 46.789055317640305, 50.64004987478256, 45.75472801923752, 48.94762448966503, 47.601314932107925, 45.224648863077164, 40.94701699912548, 41.242496743798256, 40.70142097771168, 40.762859880924225, 37.93856643140316, 38.26530709862709, 37.82008498907089, 40.139339938759804, 43.044975623488426, 47.39657051861286, 50.00352703034878, 54.97762732207775, 58.621175810694695, 54.750380516052246, 49.056241661310196, 40.569815039634705, 29.18276846408844, 19.586271308362484, 7.766727190464735, 6.8674669694155455, 12.363286390900612, 5.238022254779935, 6.93463834002614, 2.832083269022405, 0.4976559412898496, 0.0885530533560086, 1.72823466360569, 19.057292193174362, 44.559334963560104, 45.32833389937878, 39.9198979139328, 43.26951317489147, 59.48657177388668, 37.75409013032913, 14.142835400998592, 0.8558132336474955, 0.029822887117916252, 0.01499347685239627, 0.040481751202605665, 0.03718414045579266, 0.08481150100124069, 0.023632445954717696, 0.052802152204094455, 0.08414207637542859, 0.0066181793681607815, 0.09853486539213918, 0.058223207015544176, 0.021739110343332868, 0.02387916738371132, 0.021413507893157657, 0.08222833726904355, 0.023050657837302424, 0.024805013308650814, 0.05571651417994872, 0.035909227226511575, 0.033133554097730666, 0.14832986489636824, 0.16325631004292518, 0.19859971274854615, 0.12992055038921535, 0.09338601550552994, 0.19955114607000723, 0.16228399268584326, 0.10775820992421359, 0.093424466176657, 0.1656388267292641, 0.08170014334609732, 0.14259019866585732, 0.12918980210088193, 0.13087793573504314, 0.24101272516418248, 0.13270554860355332, 0.18544930120697245, 0.16379408509237692, 0.16339029738446698, 0.19513179024215788, 0.3768148849485442, 0.18698242987738922, 0.2018391279852949, 1.7797690420411527, 22.191474214196205, 55.76083369553089, 58.1972249597311, 48.0970249325037, 42.72885158658028, 44.72647659480572, 43.01253296434879, 43.04703511297703, 10.47766512259841, 1.1135676526464522, 0.274342042976059, 3.1153355073183775, 5.453672083094716, 12.700020521879196, 13.840645216405392, 18.800116293132305, 11.445199605077505, 17.693798057734966, 14.409990515559912, 14.406679943203926, 31.461352296173573, 49.10634197294712, 55.78092321753502, 51.46760746836662, 47.74992875754833, 48.18134240806103, 50.440180599689484, 50.85624307394028, 54.0810502320528, 54.330427050590515, 54.71626974642277, 51.981830075383186, 51.3436771184206, 52.73788310587406, 51.78242437541485, 48.39437797665596, 49.208974465727806, 48.75544220209122, 49.97052200138569, 47.81104847788811, 52.31158398091793, 51.67278125882149, 54.4395761936903, 52.3430272936821, 49.813028052449226, 44.14332568645477, 38.89047995209694, 39.15200091898441, 40.49981899559498, 42.17016376554966, 43.27936604619026, 44.06226463615894, 43.378548324108124, 38.11921253800392, 38.65847200155258, 37.80241973698139, 48.05268511176109, 54.37995359301567, 54.15902204811573, 54.86024022102356, 51.68643392622471, 52.27857515215874, 51.91731333732605, 50.856987833976746, 43.51519279181957, 47.274866849184036, 56.6567762196064, 50.23724868893623, 47.04164296388626, 41.96986511349678, 40.60656666755676, 39.97184872627258, 39.215115532279015, 37.986660450696945, 36.91398561000824, 38.090497478842735, 40.5289064347744, 40.35216271877289, 41.4947310090065, 43.71226541697979, 53.44772681593895, 54.868014603853226, 52.48787172138691, 52.23001755774021, 51.246763318777084, 54.109495505690575, 51.366688683629036, 50.78430533409119, 48.818306028842926, 48.033332750201225, 49.02781538665295, 53.617015331983566, 48.208678141236305, 50.92972353100777, 51.022780537605286, 47.774483039975166, 43.92918057739735, 44.708792343735695, 45.175050124526024, 43.729421496391296, 41.43805705010891, 40.905242040753365, 38.49936693906784, 41.59493923187256, 45.8966314047575, 50.596344619989395, 53.27036753296852, 55.80124072730541, 60.563593581318855, 55.14187730848789, 49.897930696606636, 39.700744673609734, 31.53275426477194, 18.149051629006863, 8.116563968360424, 7.254487602040172, 25.699993148446083, 19.162622541189194, 6.764132464304566, 4.349552504718304, 1.313257624860853, 0.5153642676305026, 2.2025446873158216, 22.138111777603626, 50.43960303068161, 55.01646503806114, 45.0278802216053, 53.13788764178753, 68.73971745371819, 43.87069411575794, 15.115828290581703, 0.9960227413102984, 0.10483881618711166, 0.15186765318503603, 0.1835509913507849, 0.1516509905923158, 0.09548800779157318, 0.08332433353643864, 0.17815982282627374, 0.437646028585732, 0.08086003217613325, 0.12021147762425244, 0.09006621825392358, 0.06602801047847606, 0.12689117778791115, 0.26961919327732176, 0.17766921868314967, 0.16771853232057765, 0.11047702340874821, 0.11567250985535793, 0.12115624645957723, 0.18067306140437722], [0.015508445703744655, 0.04560030662105419, 0.030986290803411976, 0.04098386605619453, 0.03716835497471038, 0.04205024320981465, 0.010581960887066089, 0.022589027139474638, 0.052014009925187565, 0.051471217957441695, 0.010884306284424383, 0.047210614939103834, 0.010129579204658512, 0.0408795646217186, 0.055733783956384286, 0.03469340750598349, 0.022472801247204188, 0.015253928941092454, 0.03947623015847057, 0.06618075189180672, 0.03726587689016014, 0.03903571727278177, 0.058296638817409985, 0.27386819652747363, 8.175285067409277, 37.17831462621689, 45.22682994604111, 39.85037684440613, 25.997019410133362, 24.677063338458538, 32.257825657725334, 32.328923642635345, 11.85152130201459, 1.7145391297526658, 0.1701459934702143, 0.10770631153718568, 1.3713426142930984, 5.169405536726117, 4.662127532064915, 7.624905025586486, 4.806232899427414, 3.8877248112112284, 6.598842283710837, 10.085687655955553, 21.961673945188522, 36.41584374010563, 49.5858496427536, 46.71198405325413, 45.815300568938255, 46.28141775727272, 47.00700782239437, 48.35111729800701, 50.37011615931988, 48.27690348029137, 46.565809696912766, 46.63382604718208, 45.48954784870148, 48.077049404382706, 47.691636085510254, 48.74933212995529, 48.69765490293503, 49.16684232652187, 47.82194249331951, 47.89445400238037, 49.223352894186974, 48.65431062877178, 49.05363120138645, 48.46581034362316, 45.1583082228899, 40.56726537644863, 35.43154075741768, 36.53532832860947, 36.434200555086136, 35.34017086029053, 39.28856559097767, 41.7370668053627, 38.71016442775726, 36.77983000874519, 36.806481778621674, 35.27481056749821, 39.96536247432232, 48.9075518399477, 50.21929085254669, 50.393439307808876, 48.87216813862324, 49.207412749528885, 45.92207483947277, 50.021351873874664, 39.41145099699497, 41.74063861370087, 50.82464776933193, 46.991911232471466, 45.257080122828484, 37.33126401901245, 36.4726734906435, 36.83160223066807, 35.72578936815262, 36.86022609472275, 35.11673144996166, 37.487637028098106, 36.36770412325859, 37.66490891575813, 36.069154143333435, 38.31008389592171, 45.0491476804018, 50.565661266446114, 49.98200498521328, 49.53986071050167, 49.94200073182583, 49.144195541739464, 50.41995048522949, 46.50296866893768, 44.20741304755211, 47.64872118830681, 46.59081235527992, 51.15111485123634, 49.64095048606396, 48.99837836623192, 48.61355401575565, 48.38018573820591, 46.16344928741455, 44.3891154974699, 45.90415120124817, 45.67564286291599, 45.89388035237789, 44.83089879155159, 41.1259949952364, 40.00091336667538, 39.88020144402981, 43.28549511730671, 47.23625332117081, 52.40345545113087, 54.53769072890282, 54.681323021650314, 41.29808396100998, 30.36879502236843, 17.13110525161028, 14.989915397018194, 4.485095031559467, 5.339016560465097, 9.193206746131182, 4.125863257795572, 4.4301471300423145, 2.0761192962527275, 0.36700974858831614, 0.04016599334136117, 2.7039370452985168, 17.009401582181454, 35.52217349410057, 34.08827863633633, 28.96922942250967, 46.43797315657139, 51.0675535351038, 30.794588774442673, 7.072004768997431, 0.1778117852518335, 0.06609168674913235, 0.07255988224642351, 0.09385131241288036, 0.029223626988823526, 0.012814509937015828, 0.08738443051697686, 0.05076311630546115, 0.026016535994131118, 0.04537864566373173, 0.019202264047635254, 0.023420468169206288, 0.010932827899523545, 0.037067623270559125, 0.04386605964100454, 0.049369010448572226, 0.03692137193866074, 0.04101593054656405, 0.0400789208651986, 0.02449333911499707, 0.020157829276286066, 0.013175839376344811, 0.025174938673444558, 0.03158335603075102, 0.028406659694155678, 0.031470957765122876, 0.05729044984036591, 0.007898789972387021, 0.0328055730642518, 0.047536146885249764, 0.08508183571393602, 0.015476161352125928, 0.02551380701333983, 0.01364349816867616, 0.062029404143686406, 0.044987763903918676, 0.040949927642941475, 0.012725120104732923, 0.04844593087909743, 0.03344210570503492, 0.04564106166071724, 0.03201260682544671, 0.01754672182869399, 0.01351852606603643, 0.46331065299455076, 10.97463570535183, 43.37668642401695, 51.081597581505775, 46.618425473570824, 30.051019974052906, 28.50633066147566, 37.39399865269661, 38.18988494575024, 12.775543369352818, 1.2782676774077117, 0.04215658926113974, 0.14689018746139482, 2.175100422464311, 7.487615067511797, 7.429228350520134, 8.303235601633787, 6.525540417060256, 9.276041351258755, 5.835604788735509, 15.010514091700315, 26.542577035725117, 41.03661239147186, 51.11549936234951, 48.26807655394077, 48.833148032426834, 47.48049281537533, 50.08352793753147, 52.244297191500664, 51.67250767350197, 49.457929506897926, 47.735215947031975, 47.71565459668636, 46.56076356768608, 51.137617975473404, 49.13757249712944, 50.28528571128845, 50.59346817433834, 52.7582386136055, 50.830765441060066, 50.0425661355257, 50.001114159822464, 50.92891417443752, 51.38565346598625, 52.083797603845596, 47.560060545802116, 42.592153921723366, 37.04925835132599, 38.63796830177307, 38.403448686003685, 37.33977936208248, 40.61833843588829, 43.73777724802494, 39.47147637605667, 38.51291701197624, 38.57691317796707, 37.81033471226692, 41.796529814600945, 52.25546479225159, 51.87684930860996, 51.38455152511597, 50.17655834555626, 49.98290553689003, 46.66666388511658, 50.262460336089134, 41.31689295172691, 44.28009934723377, 53.0918113142252, 47.97717556357384, 46.177740320563316, 39.500214233994484, 38.14592890441418, 37.5164470821619, 37.09479510784149, 37.77387946844101, 37.08958938717842, 39.07220520079136, 38.08977551758289, 38.22742313146591, 37.109298929572105, 39.93284001946449, 47.06443414092064, 52.426976189017296, 51.29926510155201, 51.17199473083019, 51.39243610203266, 50.77503003180027, 51.31397411227226, 47.95172832906246, 47.22965307533741, 48.75332951545715, 48.921592086553574, 52.919748947024345, 51.19240343570709, 52.08250567317009, 50.70761024951935, 51.187585294246674, 49.19649213552475, 46.12443298101425, 46.517255902290344, 46.52035653591156, 46.07197679579258, 45.59047803282738, 43.16968113183975, 40.97382456064224, 41.45698383450508, 45.431722551584244, 49.47941355407238, 54.80048842728138, 58.13148848712444, 55.55869594216347, 43.453727290034294, 32.038961201906204, 21.472923271358013, 13.370684534311295, 7.515623364597559, 8.683625590056181, 5.871058786287904, 4.925327058881521, 8.384585436433554, 2.619244339875877, 0.4523637372767553, 0.053991384484106675, 3.137391423806548, 20.816297605633736, 40.7271645963192, 37.88469672203064, 35.21198853850365, 52.21404321491718, 58.27729806303978, 35.715735107660294, 9.500816389918327, 0.21090694062877446, 0.055809523837524466, 0.03393420898646582, 0.06157278665341437, 0.031670142780058086, 0.02545437397202477, 0.03607291902881116, 0.0739920639898628, 0.0465332085150294, 0.053991165550542064, 0.025064978362934198, 0.042864438582910225, 0.02670479447260732, 0.054063647403381765, 0.04681708371208515, 0.04262408292561304, 0.05883286277821753, 0.06449034728575498, 0.0940691030700691, 0.021135978058737237, 0.041099088193732314, 0.08429038716712967, 0.08842379349516705, 0.07891349756391719, 0.12369108153507113, 0.1379386693588458, 0.09464509130339138, 0.16393423225963488, 0.07524780012317933, 0.11725118412869051, 0.12396420672303066, 0.13239674095530063, 0.11006738015566953, 0.14860705705359578, 0.1099071727367118, 0.19891571922926232, 0.12333748527453281, 0.09368084109155461, 0.12404591718222946, 0.08584500843426213, 0.20801498409127817, 0.09982283299905248, 0.1739987640758045, 0.16372224519727752, 0.6675345834810287, 11.551867481321096, 48.11298407614231, 58.26760858297348, 52.29678377509117, 36.12302005290985, 34.359090104699135, 41.53801828622818, 43.82336005568504, 15.678501147776842, 2.208772315643728, 0.48183074046391994, 0.5322386277839541, 4.231308549642563, 12.041020933538675, 13.800604864954948, 16.4683885127306, 12.111801635473967, 8.98590411990881, 9.953423403203487, 16.596886217594147, 26.915749311447144, 41.076316460967064, 54.153136163949966, 52.504340037703514, 51.102777644991875, 51.46727688610554, 52.046426609158516, 53.627578765153885, 53.39828006923199, 51.49542577564716, 50.89989893138409, 49.64157745242119, 46.20093047618866, 51.78690813481808, 49.78564292192459, 53.631180971860886, 52.510670498013496, 55.212542116642, 52.606695145368576, 51.85370475053787, 51.3447068631649, 50.87769292294979, 53.84040914475918, 53.186411038041115, 49.04460288584232, 45.64119391143322, 38.649094104766846, 40.3080964833498, 41.46045684814453, 38.767028376460075, 43.5730104893446, 44.978551268577576, 42.10878565907478, 40.53301401436329, 40.7493744045496, 38.909281343221664, 43.72104674577713, 54.554968401789665, 54.25333298742771, 52.76253238320351, 53.319814279675484, 51.52951754629612, 46.93726256489754, 49.45485547184944, 42.75043822824955, 47.47479312121868, 53.86125482618809, 50.6417141854763, 47.75381214916706, 42.16716952621937, 39.79733549058437, 39.59852255880833, 39.16223756968975, 40.07003165781498, 37.689033821225166, 41.60566605627537, 39.708051681518555, 40.39579577744007, 39.32575799524784, 41.77019342780113, 49.33349758386612, 54.35723081231117, 54.860578402876854, 51.45901992917061, 52.37531416118145, 50.927671641111374, 53.7286951392889, 51.47408612072468, 49.708066284656525, 52.0297759026289, 51.58325806260109, 55.8987282961607, 53.32603454589844, 54.97066989541054, 52.81283028423786, 54.0728160738945, 51.069274842739105, 47.6045523583889, 49.925627410411835, 49.527705162763596, 48.809900879859924, 48.49118158221245, 46.07707232236862, 45.54961882531643, 44.85819652676582, 48.19094069302082, 50.96056267619133, 57.66777276992798, 61.02028727531433, 57.78511427342892, 44.54498313367367, 33.44817638397217, 20.627584531903267, 17.4836503341794, 7.430329341441393, 10.576468370854855, 16.157954670488834, 10.575736910104752, 13.13337491825223, 4.005841948091984, 1.0080327093601227, 0.15337167482357472, 3.92111599445343, 23.654144927859306, 48.96214351058006, 47.59963542222977, 42.41447925567627, 59.01248261332512, 67.25486353039742, 44.220127165317535, 11.127559449523687, 0.5326083954423666, 0.19087253051111475, 0.0872120147687383, 0.2282075904076919, 0.12484360719099641, 0.10232554050162435, 0.16006241814466193, 0.10629167416482233, 0.17248953256057575, 0.16660784895066172, 0.14161633764160797, 0.15677678195061162, 0.09711689577670768, 0.13512318371795118, 0.12699979852186516, 0.16433433891506866, 0.11790553573518991, 0.17869042872916907, 0.2950377808883786, 0.18685491406358778, 0.15276415273547173], [0.02931357899797149, 0.04828653982258402, 0.02522639919334324, 0.03287275227194186, 0.05995198436721694, 0.07076102760038339, 0.022423350092140026, 0.044612036799662746, 0.07412009930703789, 0.10834765329491347, 0.054289583131321706, 0.008458662468910916, 0.04383936458907556, 0.01813174385461025, 0.047366914950544015, 0.15292018186300993, 0.008391961018787697, 0.07283985745743848, 0.02294799098308431, 0.01847150833782507, 0.01472633337471052, 0.03765014240343589, 0.05859244032762945, 0.08363641405594535, 3.897993522696197, 28.474319279193878, 46.62220247089863, 46.03384204208851, 35.42600825428963, 27.71673873066902, 33.93590301275253, 38.19889426231384, 20.28344839811325, 2.3945585964247584, 0.07311108274734579, 0.3613412840059027, 2.2834941186010838, 5.561033897101879, 5.651204958558083, 6.40132793225348, 4.087257329374552, 9.052332155406475, 3.019435303285718, 8.387136049568653, 19.058038853108883, 36.04049228131771, 48.67515631020069, 48.760233744978905, 47.9960947483778, 48.45044016838074, 49.421835243701935, 50.324716195464134, 48.93785521388054, 46.33712276816368, 48.050363436341286, 49.47245992720127, 48.72110724449158, 48.45444515347481, 48.9499955624342, 48.46736826002598, 46.791886165738106, 48.60764153301716, 48.2684413343668, 49.60592396557331, 47.70137116312981, 48.095854595303535, 50.212998390197754, 48.3722897619009, 45.817306861281395, 42.231925651431084, 38.231644704937935, 36.20451048016548, 35.44908821582794, 36.89869523048401, 36.65312960743904, 38.7460383027792, 36.18046157062054, 36.20187722146511, 35.30410699546337, 35.65846458077431, 37.81961761415005, 46.46931007504463, 47.67183534801006, 51.25535845756531, 48.3015451580286, 49.674236699938774, 45.41135184466839, 49.7612140327692, 41.863733008503914, 38.51295880973339, 53.56307342648506, 46.592339873313904, 46.49558566510677, 41.285259649157524, 37.37387493252754, 38.74138355255127, 36.50530233979225, 35.413905903697014, 37.12457410991192, 35.548528879880905, 34.765440300107, 37.128370106220245, 36.70191138982773, 38.00124406814575, 43.08531045913696, 47.06120431423187, 49.0983510017395, 50.49571081995964, 49.12603251636028, 48.44702035188675, 48.53317692875862, 50.499495416879654, 46.07283174991608, 51.33065901696682, 51.80718384683132, 50.22582270205021, 50.032439678907394, 48.217090889811516, 53.961444050073624, 50.9734021872282, 47.83777244389057, 49.56676706671715, 49.39242862164974, 50.07521778345108, 48.94160181283951, 48.885387629270554, 46.91521994769573, 45.3906087577343, 43.934975266456604, 46.30239263176918, 47.443015426397324, 51.46031565964222, 53.72272565960884, 45.85172161459923, 31.978377252817154, 23.707611858844757, 12.038063742220402, 7.1102250181138515, 5.4373890068382025, 11.868077013641596, 4.015302490442991, 1.3698240020312369, 10.57164452970028, 3.0558492243289948, 0.36638664139900357, 0.18492286617401987, 2.95391280669719, 21.23376790434122, 38.095779195427895, 30.746202170848846, 31.33419591933489, 41.74214333295822, 49.097857028245926, 30.682365596294403, 4.675594484433532, 0.0836546412028838, 0.020395431565702893, 0.03279668955656234, 0.11870635018567555, 0.06951491712243296, 0.07938129550893791, 0.05304041871568188, 0.05780613857496064, 0.009935554899129784, 0.02120403114531655, 0.03161929453199264, 0.04365281463833526, 0.02514732892450411, 0.04298212836147286, 0.0415946907014586, 0.05178608153073583, 0.02349125235923566, 0.06350240029860288, 0.04295770428143442, 0.012289102778595407, 0.05388738361943979, 0.018597884954942856, 0.07299727440113202, 0.024496051664755214, 0.024901101023715455, 0.016374009755963925, 0.02038256272498984, 0.004913929533358896, 0.0209290747079649, 0.06107192602939904, 0.07776393307722174, 0.025931163036148064, 0.014619911253248574, 0.02587353712442564, 0.057309634357807226, 0.044109042501077056, 0.0924700271571055, 0.01912834428367205, 0.024693180930626113, 0.10198519157711416, 0.022736783175787423, 0.06619173567742109, 0.007635609563294565, 0.04222048075462226, 0.14568159996997565, 5.478379782289267, 33.79844158887863, 53.58036249876022, 49.17837470769882, 37.35847055912018, 31.41542226076126, 38.17042239010334, 42.13653177022934, 23.162244223058224, 2.657651728950441, 0.12625396979274228, 0.14873277687001973, 2.5315934931859374, 5.970980124548078, 8.657397497445345, 10.25507876649499, 10.919398069381714, 13.116077296435833, 4.574234448373318, 10.036049969494343, 20.262099243700504, 38.91837425529957, 52.011806666851044, 51.573306396603584, 49.321976602077484, 50.905781015753746, 50.16901195049286, 51.40409007668495, 49.41779986023903, 48.652752712368965, 50.7599638402462, 51.12581580877304, 48.94181840121746, 49.205509051680565, 49.34161774814129, 50.093358010053635, 48.666523173451424, 50.23983635008335, 50.49712434411049, 51.999871507287025, 46.82219333946705, 48.6217387765646, 52.035673186182976, 51.00460611283779, 48.39202970266342, 44.13002260029316, 39.91054281592369, 38.58626447618008, 37.245730608701706, 38.841116800904274, 38.18870320916176, 39.64216701686382, 38.301823139190674, 38.00576962530613, 37.44247265160084, 37.265607342123985, 40.03199189901352, 48.461147993803024, 49.7792212665081, 51.60338178277016, 50.37663280963898, 50.26444382965565, 46.02292902767658, 50.19064038991928, 44.898398369550705, 41.42439678311348, 55.122912526130676, 48.48150350153446, 48.27114678919315, 42.645430862903595, 39.21341322362423, 40.62631040811539, 37.773199304938316, 36.553213968873024, 38.13473090529442, 37.60987266898155, 36.73230595886707, 39.06560495495796, 38.206577450037, 39.83244560658932, 43.94737400114536, 49.787622615695, 51.05095222592354, 51.529745534062386, 49.52825993299484, 49.82193477451801, 50.8685240149498, 52.02820658683777, 47.396171540021896, 53.37345600128174, 54.309083595871925, 53.72845575213432, 52.915546372532845, 49.26781810820103, 55.73518507182598, 53.71520586311817, 51.3593664765358, 50.28171390295029, 50.85930570960045, 52.76755951344967, 52.27658025920391, 50.950816199183464, 49.0054801851511, 48.61366420984268, 47.0866971462965, 48.332452699542046, 49.93643403053284, 53.55998799204826, 56.446552500128746, 48.94197419285774, 36.62813454866409, 23.926810696721077, 15.908866636455059, 9.01691710576415, 7.644683914259076, 9.012772478163242, 7.308783363550901, 6.915512541308999, 6.045710239559412, 2.373021114617586, 0.41654772008769214, 0.10041905217804015, 4.168812828138471, 22.16061607003212, 40.90696334838867, 34.01848778128624, 32.36685700714588, 48.429814875125885, 56.21201008558273, 36.16596154868603, 6.1889449786394835, 0.16165667009772733, 0.03754791156097781, 0.026819459999387618, 0.034180486982222646, 0.12163900610175915, 0.02611760352010606, 0.05099779453303199, 0.018892109401349444, 0.03341491712490097, 0.01063713121766341, 0.03690456229378469, 0.047313061004388146, 0.06800029019359499, 0.09797654769499786, 0.02221404774900293, 0.041150719407596625, 0.01672471349593252, 0.03403439150133636, 0.010364532954554306, 0.037212609240668826, 0.00659024261040031, 0.13123392913257703, 0.1648674681200646, 0.13589964830316603, 0.1858009456191212, 0.25759755866602063, 0.1810262494836934, 0.06661300096311606, 0.1658683136338368, 0.12489439977798611, 0.17961762350751087, 0.11150095713674091, 0.09328906875452958, 0.08273120169178583, 0.19660271209431812, 0.20600272488081828, 0.3559885884169489, 0.08553808584110811, 0.1555427091079764, 0.15436800807947293, 0.09688239195384085, 0.12108767201425508, 0.12750245514325798, 0.13364798709517345, 0.21155836817342788, 6.4334656577557325, 37.480440214276314, 61.939663141965866, 58.02832782268524, 47.15343676507473, 38.305957317352295, 44.61602032184601, 48.53206738829613, 26.53880573809147, 3.5338241513818502, 0.3382278961362317, 1.2533790129236877, 4.50387267395854, 11.506509315222502, 12.752674296498299, 13.352296371012926, 11.297370437532663, 15.769551862031221, 7.136941384524107, 10.466739758849144, 23.545041382312775, 41.22381694614887, 53.18030096590519, 52.84226730465889, 51.52990132570267, 52.90209889411926, 51.985420882701874, 52.612516433000565, 51.30425423383713, 49.38067965209484, 52.48399592936039, 51.822888404130936, 52.05003261566162, 50.209054201841354, 50.40530227124691, 50.88389419019222, 50.56571826338768, 52.692806124687195, 51.8082781881094, 53.16108539700508, 47.385022938251495, 48.49398963153362, 54.70741242170334, 52.88657292723656, 51.24842382967472, 46.98278032243252, 41.659566164016724, 40.16350284218788, 38.74340884387493, 40.85851214826107, 39.71564367413521, 39.924472868442535, 39.413613080978394, 39.68826614320278, 38.75014588236809, 38.65121819078922, 42.77718499302864, 49.67183142900467, 52.644400522112846, 53.79633150994778, 53.12180310487747, 51.177724823355675, 47.7793999761343, 50.25810196995735, 47.01715707778931, 44.87939178943634, 57.19754420220852, 50.42881540954113, 50.655754432082176, 45.142679661512375, 41.19479030370712, 41.82844050228596, 40.5806178599596, 38.28283555805683, 39.64201122522354, 39.46598567068577, 37.91539907455444, 41.652775928378105, 38.3622170984745, 42.023199051618576, 45.55060297250748, 51.89615607261658, 53.08645740151405, 54.35800977051258, 51.90037004649639, 51.99261009693146, 52.94975593686104, 54.59380231797695, 49.82680231332779, 56.880508214235306, 56.70815706253052, 54.76516172289848, 54.40336033701897, 51.17631509900093, 59.16482783854008, 55.16976021230221, 52.211523950099945, 53.41741964221001, 54.38794456422329, 55.42471893131733, 54.43398669362068, 54.412156865000725, 51.3355303555727, 51.55554614961147, 49.872194677591324, 51.62466064095497, 52.628080397844315, 57.03621245920658, 58.37548479437828, 49.60671052336693, 35.55366240441799, 24.61070939898491, 14.41466236487031, 10.452479124069214, 9.816663041710854, 20.545320846140385, 13.629988320171833, 12.930424008518457, 21.191031597554684, 7.51870452426374, 1.034691366367042, 0.3953976393677294, 5.006397133693099, 27.934206761419773, 52.62106217443943, 42.23046272993088, 45.35314276814461, 56.76000528037548, 66.37570470571518, 41.736299246549606, 7.851483542472124, 0.30387055536266416, 0.1167806847661268, 0.09642362594604492, 0.1425645500421524, 0.18311073450604454, 0.2054338390007615, 0.11331718545989133, 0.125835606304463, 0.13202073925640434, 0.08199390766094439, 0.14559142902726308, 0.1547823045984842, 0.08610524993855506, 0.18066041520796716, 0.16971336590358987, 0.10042851456091739, 0.0856859958730638, 0.15925150306429714, 0.1238534931326285, 0.10067214680020697, 0.10314494575140998], [0.05680695176124573, 0.06577481937711127, 0.0523282092763111, 0.059718389675254, 0.037106148156453855, 0.05699449247913435, 0.04070475544722285, 0.03840115503408015, 0.06129230678197928, 0.02506868724594824, 0.04081533545104321, 0.02279297674249392, 0.05070004488516133, 0.0491054478334263, 0.08014847582671791, 0.05103927316667978, 0.08431310430751182, 0.07347126185777597, 0.05116376843943726, 0.024197819620894734, 0.022835468407720327, 0.054398396823671646, 0.05440292021376081, 0.04436700932274107, 0.4877656954340637, 21.747080460190773, 42.56538815796375, 48.383894339203835, 36.507525220513344, 22.599954195320606, 25.015632770955563, 34.246524944901466, 23.974021263420582, 5.040176371112466, 0.5384653655346483, 0.03613777160353493, 2.3246086249127984, 6.094954172149301, 6.826494242995977, 5.6341153755784035, 10.644176937639713, 14.041502438485622, 2.1041252184659243, 10.104733183979988, 15.528968721628189, 29.45042610168457, 47.894989773631096, 54.880249947309494, 50.90830408036709, 51.78142122924328, 49.28557835519314, 52.55034036934376, 48.8992340862751, 49.36198465526104, 49.835013672709465, 48.186168149113655, 49.56808179616928, 51.79578445851803, 51.03306658565998, 49.26716834306717, 46.699452325701714, 48.23252946138382, 50.31281143426895, 49.11422275006771, 48.434127643704414, 46.260214895009995, 49.16270434856415, 50.39579518139362, 46.53592810034752, 45.932702869176865, 45.60604579746723, 41.10153190791607, 37.304882034659386, 36.71802632510662, 35.84066480398178, 39.057906568050385, 37.02559322118759, 34.771565571427345, 34.879783764481544, 34.535670429468155, 36.62940748035908, 41.491767168045044, 44.38008338212967, 48.779802694916725, 49.180589988827705, 50.35849638283253, 46.022716239094734, 50.58821305632591, 44.09707836806774, 39.80596102774143, 52.006251364946365, 48.13726097345352, 48.60574923455715, 43.63025061786175, 37.462698966264725, 37.14733108878136, 37.59237080812454, 36.46635822951794, 38.38856868445873, 40.59164106845856, 37.02816188335419, 37.14780606329441, 37.82766558229923, 35.02385303378105, 38.70058514177799, 44.93148699402809, 47.330921441316605, 50.4196161031723, 48.15871462225914, 50.186415016651154, 49.68427576124668, 46.42157703638077, 53.41865077614784, 48.78933258354664, 50.280064791440964, 48.297688364982605, 47.06824153661728, 48.26586127281189, 48.97952377796173, 51.08578495681286, 52.96760357916355, 52.615894451737404, 54.254339933395386, 52.7320010215044, 51.380246356129646, 51.02235496044159, 50.80274574458599, 47.09286041557789, 48.19064050912857, 49.307674169540405, 48.03475767374039, 51.12705074250698, 51.2255072593689, 41.32088653743267, 29.521227702498436, 15.02403186634183, 8.47974183037877, 2.77469708584249, 6.413550451397896, 6.760637126863003, 1.4571296609938145, 5.677595967426896, 4.570005750283599, 2.0365859800949693, 0.3682663233485073, 0.25852304650470614, 4.533892013132572, 23.589043021202087, 38.97659473121166, 37.04293169081211, 35.07227383553982, 41.19655340909958, 52.79675334692001, 25.008929930627346, 2.8780406154692173, 0.023402181650453713, 0.06879996173665859, 0.03423223322897684, 0.020648379613703582, 0.07848877387004904, 0.025628663643146865, 0.03474542092590127, 0.03970731268054806, 0.09437240398256108, 0.04531951133685652, 0.006935864494153066, 0.016131952725118026, 0.02011836742894957, 0.039956551845534705, 0.00719293470865523, 0.015496819960389985, 0.03473004362604115, 0.020945515134371817, 0.0471593214024324, 0.031038059314596467, 0.05088499550765846, 0.04448117018910125, 0.0806980807101354, 0.012523414570750901, 0.07908044368377887, 0.05624375815386884, 0.05413976949057542, 0.02420846572931623, 0.048861355462577194, 0.03216097698896192, 0.042683547508204356, 0.05804531792819034, 0.026470411248737946, 0.05405082309152931, 0.02936869830591604, 0.06392620372935198, 0.03968372351664584, 0.02769888458715286, 0.009950694711733377, 0.04054200246173423, 0.04881873021076899, 0.038583044297411107, 0.02535014304157812, 0.0619076139992103, 0.061157428863225505, 1.0681619890965521, 25.788874179124832, 47.939382791519165, 53.84858250617981, 42.2995962202549, 26.23183161020279, 30.760724991559982, 43.13917636871338, 27.22672462463379, 4.838419072329998, 0.5098348518367857, 0.08488186402246356, 1.400439077988267, 3.733087358996272, 8.921050149947405, 8.293250687420368, 10.237364117056131, 12.831361424177885, 6.56695581972599, 9.71859410405159, 18.227226734161377, 32.66371987760067, 50.01608535647392, 53.67970436811447, 52.08427257835865, 53.08590643107891, 50.79524114727974, 51.83783680200577, 51.27159498631954, 51.211227625608444, 52.70208142697811, 49.03547577559948, 52.69734688103199, 52.9001571983099, 52.3511778563261, 48.23004439473152, 46.74216963350773, 47.59729094803333, 52.230363339185715, 49.844532161951065, 48.55989709496498, 47.173617482185364, 51.10898271203041, 52.29918144643307, 48.48671302199364, 47.12004795670509, 46.05778455734253, 41.72897703945637, 37.1894746273756, 37.751958444714546, 37.55943417549133, 39.536308497190475, 38.620702028274536, 35.86991183459759, 36.45875483751297, 37.38441936671734, 38.724219873547554, 43.896156549453735, 46.954840421676636, 51.82247802615166, 50.83160899579525, 52.48782232403755, 48.24893318116665, 50.06333962082863, 43.62732097506523, 42.08948269486427, 51.477821320295334, 51.58450819551945, 50.226385071873665, 45.884038880467415, 40.66815376281738, 38.41534584760666, 38.60286958515644, 37.97168545424938, 40.13824179768562, 41.31763771176338, 38.3157379925251, 39.48702894151211, 38.32841411232948, 36.49519108235836, 41.06675997376442, 47.73359343409538, 50.132898688316345, 51.36761583387852, 51.15766189992428, 51.63024254143238, 50.95191814005375, 46.71079471707344, 55.22044949233532, 49.66933496296406, 52.151137590408325, 49.84015479683876, 49.95013989508152, 49.35108684003353, 49.8775751888752, 51.57318100333214, 52.64111749827862, 53.57200674712658, 55.63712753355503, 54.2231360077858, 52.92466588318348, 54.01815600693226, 54.46256875991821, 50.59078551828861, 50.83209916949272, 51.457781195640564, 51.37964978814125, 54.34159845113754, 54.4525220990181, 42.94720306992531, 30.590458028018475, 18.249590434134007, 11.54773235321045, 5.3287936840206385, 7.344576492905617, 8.5891655087471, 4.04786104336381, 5.534532219171524, 4.22317698597908, 1.4149785228073597, 0.049921324171009474, 0.33182227110955864, 4.572050990536809, 27.09664050489664, 44.05328951776028, 40.810459926724434, 39.881690964102745, 47.29352004826069, 58.906730487942696, 29.91193413734436, 4.161577541381121, 0.03651736529718619, 0.011439977297413861, 0.0439765951159643, 0.04747636317915749, 0.05730651733756531, 0.028970801395189483, 0.007022043610049877, 0.06653637421550229, 0.007880815155658638, 0.04785604964126833, 0.019078863442700822, 0.02296885275427485, 0.013060658984613838, 0.06924346918822266, 0.027106990273750853, 0.07335656293435022, 0.03231465721910354, 0.03181719563144725, 0.04972675160388462, 0.05183001667319331, 0.06316774364677258, 0.09151296093477868, 0.19375503208721057, 0.15187195764156058, 0.17719388793921098, 0.2485196676570922, 0.1676761853741482, 0.10938442617771216, 0.0894247206451837, 0.1491501904092729, 0.10491095294128172, 0.13949196960311383, 0.1157628811779432, 0.16964634996838868, 0.09988053498091176, 0.17821114975959063, 0.15667908563045785, 0.24918846145737916, 0.08718074808712117, 0.3082464064937085, 0.1714647008338943, 0.08568162462324835, 0.11363306577550247, 0.15164322772761807, 0.19795649335719645, 1.4139044866897166, 28.37959226220846, 54.54286225140095, 61.24166339635849, 48.62580455839634, 31.26177940517664, 34.812322184443474, 44.49375808238983, 31.446329802274704, 6.804811181500554, 0.8982061338610947, 0.17207008553668857, 4.805614007636905, 14.630021508783102, 17.099622040987015, 15.02816604450345, 19.374901950359344, 23.688806667923927, 6.029643276706338, 12.64835374429822, 20.907268524169922, 36.141570657491684, 50.64188897609711, 56.500369012355804, 54.83179114758968, 55.29456451535225, 49.98628355562687, 53.724040389060974, 52.384707257151604, 52.62271888554096, 55.58158591389656, 52.62739263474941, 52.63256035745144, 55.970662236213684, 53.9031095802784, 49.75916974246502, 48.503124341368675, 48.97240296006203, 51.47372514009476, 50.20316071808338, 49.56122696399689, 46.90560646355152, 50.804052874445915, 55.09013548493385, 50.20560398697853, 49.504723995923996, 49.52173948287964, 44.30254474282265, 41.63305498659611, 40.31836733222008, 38.860507160425186, 41.964765787124634, 39.943639039993286, 36.96246720850468, 38.13796453177929, 38.04949387907982, 40.367673486471176, 46.144423708319664, 49.38373848795891, 52.8445927798748, 54.80216033756733, 53.458316847682, 49.32866804301739, 51.156415566802025, 45.352333411574364, 47.34816491603851, 52.33747199177742, 53.61590579152107, 52.19336472451687, 48.93294207751751, 41.992344707250595, 41.27129539847374, 39.22975234687328, 39.9165540933609, 41.68559096753597, 44.542520865798, 39.37730222940445, 42.42778234183788, 39.461661502718925, 38.37137080729008, 42.59004503488541, 49.082798436284065, 51.35538429021835, 55.254351273179054, 52.31250733137131, 53.12854394316673, 51.21438905596733, 46.85883477330208, 56.85028463602066, 51.77345685660839, 51.720628291368484, 50.625097677111626, 50.84661819040775, 50.14122024178505, 50.00624768435955, 52.80190207064152, 55.44660195708275, 56.09906114637852, 57.67548255622387, 56.88524276018143, 54.66046214103699, 56.08723618090153, 55.86199186742306, 51.94966860115528, 54.576004073023796, 55.82315415143967, 53.49018573760986, 56.92811965942383, 55.419311821460724, 45.31407706439495, 32.28684850037098, 18.28671634197235, 10.433514341711998, 6.966885784640908, 10.856481045484543, 14.893787205219269, 17.14967865496874, 12.786207497119904, 12.482216209173203, 4.777024816721678, 0.8700130716897547, 0.5563760013319552, 5.802073962986469, 30.920344926416874, 49.538929760456085, 51.18929900228977, 47.35521353781223, 55.08989229798317, 66.43039897084236, 36.23683914542198, 5.414453437551856, 0.15066044608829543, 0.22803820262197405, 0.1467090440564789, 0.18644453608430922, 0.11404592252802104, 0.10864497991860844, 0.16122027242090553, 0.13669956475496292, 0.20995103957829997, 0.1309730642242357, 0.1279204327147454, 0.09999418005463667, 0.16067697579273954, 0.15194393112324178, 0.11968398132012226, 0.16081624722573906, 0.07967692261445336, 0.09075093854335137, 0.17782459472073242, 0.10839912865776569, 0.1658675418002531], [0.05517436045920476, 0.03631851424870547, 0.03331762156449258, 0.06707722917781211, 0.054039375463617034, 0.042503046061028726, 0.02292936493176967, 0.024883725491235964, 0.050149645903729834, 0.08157932170433924, 0.049914106784854084, 0.03151492630422581, 0.04385300897411071, 0.014011429011588916, 0.02146542668924667, 0.026448798053024802, 0.030404530516534578, 0.14641914633102715, 0.06922023996594362, 0.024481314467266202, 0.0776734875398688, 0.05201378728088457, 0.10584364703390747, 0.022662368028250057, 0.17397599498508498, 11.699892338365316, 37.63138331472874, 46.0181450843811, 41.96262650191784, 27.484405897557735, 30.17494272440672, 36.04836545884609, 28.183473385870457, 7.89404695853591, 0.8232963597401977, 0.1844442106084898, 1.3234068802557886, 2.1971021918579936, 6.097301971167326, 10.157216917723417, 11.607965771108866, 11.635716632008553, 5.683392556384206, 6.397483013570309, 14.208417981863022, 32.57078066468239, 48.405264392495155, 50.16504116356373, 45.71731522679329, 50.91688022017479, 48.4697013348341, 50.14307454228401, 48.431650176644325, 46.95839703083038, 44.37789849936962, 46.09263248741627, 45.72065144777298, 48.7105780094862, 51.055075004696846, 51.76272243261337, 51.364921778440475, 52.66184538602829, 49.55099791288376, 50.86207576096058, 47.5140830129385, 47.77891740202904, 46.353769674897194, 50.31246565282345, 48.79695117473602, 48.34609396755695, 46.41483999788761, 48.012623861432076, 41.82519927620888, 36.79135859012604, 36.31352283060551, 37.14099682867527, 35.30409179627895, 35.36463774740696, 36.060551404953, 34.97306115925312, 35.69619655609131, 39.849730879068375, 42.457040771842, 47.99602635204792, 47.14416526257992, 50.75619824230671, 46.247686967253685, 51.02979876101017, 42.75342866778374, 36.54988534748554, 51.16605564951897, 50.30558042228222, 51.78360231220722, 44.674164801836014, 39.37832437455654, 38.064316883683205, 38.51157188415527, 37.991041615605354, 42.050956562161446, 40.69107033312321, 36.924134865403175, 38.11802700161934, 38.290685936808586, 38.53138022124767, 36.82758964598179, 39.32768829166889, 44.2321041226387, 46.08799673616886, 48.48442554473877, 49.23749953508377, 48.36231529712677, 47.740053087472916, 49.28732246160507, 52.110901549458504, 49.99063432216644, 51.62127502262592, 50.6447996199131, 50.01586116850376, 49.980895444750786, 51.408106461167336, 52.304478362202644, 51.68332189321518, 52.67348796129227, 52.831741869449615, 50.529775992035866, 50.22642306983471, 53.5611355304718, 53.36210981011391, 53.43971684575081, 53.245262280106544, 51.29790477454662, 52.67238602042198, 50.89017905294895, 35.00586859881878, 24.370429292321205, 13.47897682338953, 7.551828771829605, 2.947296411730349, 4.552835896611214, 6.238204585388303, 2.141037150286138, 4.280970934778452, 2.286162762902677, 0.8790515991859138, 0.15566180896712467, 0.16208928282139823, 5.968080405145884, 23.297336474061012, 38.55144314467907, 37.22767777740955, 29.14540696889162, 40.030726566910744, 45.11978209018707, 19.16081763803959, 1.6436468088068068, 0.03302004261058755, 0.04689798523031641, 0.044679661295958795, 0.050519936776254326, 0.05699592482415028, 0.031770243658684194, 0.027308390599500854, 0.06299134998698719, 0.027436945420049597, 0.08508380240527913, 0.05398575900471769, 0.02962041809951188, 0.04207432590192184, 0.02434251429804135, 0.04753003529913258, 0.03593323941458948, 0.013152347619325155, 0.04482923002797179, 0.04212516301777214, 0.002386114942964923, 0.019385606065043248, 0.04778982780408114, 0.03818576893536374, 0.04787447345734108, 0.02400818975729635, 0.033955779508687556, 0.08988224726635963, 0.02999888929480221, 0.03882155200699344, 0.020815526113437954, 0.06392806652002037, 0.07060372940031812, 0.07769247909891419, 0.011518295214045793, 0.06655517281615175, 0.03924043870938476, 0.03869209176627919, 0.016054568986874074, 0.08745653016376309, 0.036827115472988226, 0.039513497104053386, 0.02658634399267612, 0.05320057047356386, 0.050959822547156364, 0.04558630971587263, 0.35219627316109836, 16.088760383427143, 43.32111440598965, 53.29060524702072, 46.169464364647865, 28.932709582149982, 30.282163470983505, 41.26601368188858, 31.13418035209179, 9.58377068862319, 0.7576200307812542, 0.007191848853835836, 1.3996239029802382, 2.6086260471493006, 5.646940162405372, 5.901299463585019, 9.41865909844637, 8.03092036396265, 11.199487689882517, 10.471810586750507, 15.98115585744381, 35.21114118397236, 49.036585316061974, 54.582984298467636, 48.3367008715868, 52.50331789255142, 50.52822947502136, 52.868425101041794, 50.62520407140255, 49.705467224121094, 47.19118393957615, 48.61055217683315, 49.393674954771996, 51.31667956709862, 52.202263846993446, 53.65798093378544, 52.47308291494846, 53.353997245430946, 52.58173048496246, 53.09110075235367, 50.72721339762211, 48.02346467971802, 47.30705492198467, 52.00604237616062, 51.33183315396309, 50.610905438661575, 49.39991042017937, 49.4850068539381, 42.47481241822243, 38.03117886185646, 37.93331891298294, 38.353952541947365, 35.50660192966461, 37.01767824590206, 35.99409677088261, 36.49446152150631, 36.8125044554472, 41.58813759684563, 44.04029041528702, 48.8532717525959, 48.65464121103287, 51.47757813334465, 48.91903102397919, 53.127662390470505, 44.53389912843704, 39.01096008718014, 52.194466665387154, 52.16998837888241, 52.63066045939922, 46.163753271102905, 43.085458651185036, 39.90935727953911, 39.82439763844013, 39.56552512943745, 43.536118268966675, 42.97315187752247, 39.0473697334528, 40.09950667619705, 39.867137745022774, 40.61983935534954, 39.76471804082394, 41.290955543518066, 45.423670783638954, 48.05820621550083, 51.97690933942795, 50.68847827613354, 51.232761070132256, 48.264155164361, 49.710528552532196, 52.20593824982643, 51.84746168553829, 54.84167821705341, 52.308019772171974, 51.46847382187843, 50.418734550476074, 52.54114106297493, 54.17968533933163, 53.781504705548286, 53.76322768628597, 54.20420542359352, 51.42346903681755, 51.903159096837044, 55.183108896017075, 55.71630768477917, 55.35362094640732, 54.634091556072235, 53.0618005245924, 56.717082783579826, 53.99534963071346, 37.92836397886276, 26.392713077366352, 14.671698622405529, 9.477564487606287, 6.262167049571872, 7.043955624103546, 7.4640981294214725, 5.808059116825461, 7.25513594225049, 4.210477592423558, 0.8387195540126413, 0.1286340522347018, 0.23892386147053912, 6.788949407637119, 28.51372506469488, 45.148390755057335, 41.95565767586231, 35.935165733098984, 44.31096509099007, 52.60588198900223, 23.9090371504426, 2.343351119197905, 0.06325030757579952, 0.04460968790226616, 0.02073656716675032, 0.11201143599464558, 0.06728847409249283, 0.036259179541957565, 0.06660387996817008, 0.03973097605921794, 0.06789840816054493, 0.06780219613574445, 0.05907003091124352, 0.03178412182023749, 0.01734783738356782, 0.013461724865919678, 0.05150799508555792, 0.021682842561858706, 0.049302517727483064, 0.04716600073152222, 0.004820194890271523, 0.03306751408672426, 0.02430021373584168, 0.1329218252794817, 0.14863044954836369, 0.13373455120017752, 0.1460816472535953, 0.11268248592386954, 0.14989867602707818, 0.15452948457095772, 0.12281835297471844, 0.10275184497004375, 0.144840108405333, 0.19270852964837104, 0.12116401674575172, 0.17485400021541864, 0.1283107727067545, 0.20010744512546808, 0.14243510464439169, 0.08589426477556117, 0.2199716362520121, 0.1536052583833225, 0.10454796109115705, 0.1329839727259241, 0.09834938784479164, 0.27653449564240873, 0.13124975172104314, 0.5459861713461578, 17.99111120402813, 49.48111206293106, 60.11022850871086, 52.85103343427181, 37.38968588411808, 38.89938287436962, 46.3828457146883, 36.91162973642349, 11.773128658533096, 1.1750800581648946, 0.22298057010630146, 3.4328144090250134, 6.702480772510171, 14.295328818261623, 22.443450093269348, 21.610933765769005, 21.740632206201553, 12.649152651429176, 10.680185705423355, 19.289151951670647, 37.32399880886078, 55.053452253341675, 54.95450556278229, 49.65637005865574, 53.60170595347881, 53.186110854148865, 53.67805905640125, 53.985017985105515, 51.21335171163082, 49.45100627839565, 49.03342388570309, 50.828827545046806, 53.49558524787426, 54.45797100663185, 55.478223860263824, 54.20742765069008, 56.38652712106705, 54.068309515714645, 55.11706463992596, 52.28228375315666, 47.36714109778404, 46.842332258820534, 51.77165575325489, 53.99374611675739, 53.23785647749901, 51.60983383655548, 52.37822100520134, 45.215662345290184, 39.56114776432514, 41.17087818682194, 41.240000277757645, 37.45158836245537, 38.04117992520332, 39.05916430056095, 38.2456811517477, 39.42096568644047, 43.22809539735317, 45.97733907401562, 50.87860867381096, 51.25513046979904, 53.57701487839222, 51.06911905109882, 53.550085723400116, 46.03641830384731, 42.652753069996834, 52.43472397327423, 54.80567894876003, 56.723436042666435, 49.22931097447872, 43.98784942924976, 42.12417483329773, 41.156837940216064, 41.790708526968956, 44.32054437696934, 44.68294233083725, 41.099658608436584, 42.47207656502724, 42.29341395199299, 42.00506642460823, 41.84912659227848, 43.461976647377014, 46.987708657979965, 50.14086686074734, 54.12367634475231, 53.53568449616432, 52.64492489397526, 50.65532885491848, 52.250129878520966, 52.85687372088432, 53.024820908904076, 55.669630989432335, 55.22540062665939, 53.56156870722771, 53.09614308178425, 55.32111369073391, 55.96444956958294, 55.70674739778042, 55.63863605260849, 55.25926820933819, 51.89115934073925, 52.55433015525341, 56.58145286142826, 57.10035681724548, 58.77490036189556, 58.0481893569231, 56.46193787455559, 58.39340463280678, 55.035676807165146, 38.13631922006607, 28.62098950892687, 15.181078389286995, 11.040413975715637, 6.915291678160429, 10.828179214149714, 14.140272438526154, 11.36347834020853, 13.536410741508007, 9.123921263962984, 2.559167188592255, 0.21611107309581712, 0.5145995586644858, 7.776579586789012, 32.103208154439926, 52.81904675066471, 50.57166114449501, 42.447070106863976, 53.932136222720146, 58.45819115638733, 29.239336028695107, 3.2751019718125463, 0.253087705350481, 0.17841243505245075, 0.06355556775815785, 0.15876619785558432, 0.16998059843899682, 0.11608917382545769, 0.10179631499340758, 0.22054628119803965, 0.19897173653589562, 0.17984917358262464, 0.2689956407994032, 0.09609715518308803, 0.1776043846621178, 0.13186390860937536, 0.10904591777944006, 0.10960229104966857, 0.18006901256740093, 0.11176668311236426, 0.11268043017480522, 0.12043599956086837, 0.15646128013031557], [0.025971142531489022, 0.02723306075495202, 0.006603735782846343, 0.07333107016165741, 0.04705350598669611, 0.033624622083152644, 0.03680382316815667, 0.04323906730860472, 0.0064189103977696504, 0.042057694372488186, 0.032074720875243656, 0.026700109665398486, 0.02343387506698491, 0.05768536517280154, 0.06582875867024995, 0.04427334657520987, 0.0952642725314945, 0.04678135672293138, 0.05635295405227225, 0.03385599404282402, 0.019086360989604145, 0.04908315742795821, 0.016653400525683537, 0.01481474171669106, 0.039795364791643806, 5.427119107916951, 30.317834056913853, 47.241603434085846, 37.603401616215706, 29.355776980519295, 34.28179085254669, 36.67285054922104, 32.630220875144005, 11.495101377367973, 1.5643622819334269, 0.06134087292593904, 0.6224457873031497, 1.0720344563014805, 5.573890032246709, 3.376666009426117, 5.919618755578995, 5.351550662890077, 12.942502610385418, 11.658904887735844, 14.319279883056879, 30.13470858335495, 39.622377678751945, 46.515754982829094, 50.04960335791111, 49.46789637207985, 47.95434258878231, 49.56494316458702, 45.85235618054867, 43.740927278995514, 44.18046109378338, 43.825624734163284, 43.58130544424057, 45.27708984911442, 46.70590437948704, 46.695192754268646, 47.61231914162636, 47.89830319583416, 46.7985700070858, 46.243510991334915, 47.37315997481346, 52.5437743216753, 49.23295497894287, 48.20424757897854, 47.17256113886833, 51.73069015145302, 48.16077411174774, 49.406632259488106, 46.297749280929565, 36.68899588286877, 34.50554944574833, 35.328934863209724, 34.59584400057793, 34.63604964315891, 34.16839353740215, 36.15476354956627, 35.000788271427155, 38.17842476069927, 41.157369911670685, 43.2749392837286, 44.05257895588875, 48.019311502575874, 46.286840066313744, 50.42693831026554, 46.136596128344536, 36.51438005268574, 49.8606812953949, 51.14543795585632, 51.257406547665596, 44.945424646139145, 39.59286846220493, 34.38865251839161, 38.89752097427845, 38.35529766976833, 39.82367567718029, 37.55619294941425, 37.24845886230469, 37.762658670544624, 38.54911766946316, 36.630786806344986, 37.46238738298416, 35.55031858384609, 40.116358771920204, 45.00842146575451, 46.8914370238781, 49.971205964684486, 48.2381721585989, 46.50527894496918, 51.35134130716324, 49.02107074856758, 49.97029401361942, 48.78411926329136, 50.722862631082535, 49.49139431118965, 50.40729336440563, 49.26965340971947, 49.107014536857605, 49.96123909950256, 51.43756628036499, 48.335864916443825, 51.98165528476238, 50.99624656140804, 52.71542251110077, 50.06988666951656, 52.06351429224014, 52.962238267064095, 53.484869822859764, 53.72885853052139, 47.6259908080101, 31.88348114490509, 19.421660341322422, 7.733361655846238, 6.172437714412808, 4.572425270453095, 5.803085183724761, 6.1654589138925076, 2.8357726335525513, 4.296939577907324, 1.7081127245910466, 1.0337762092240155, 0.04489049060794059, 0.36278443469200283, 5.930313281714916, 27.02957410365343, 36.87611684203148, 35.793520733714104, 34.59638737142086, 44.98333901166916, 43.18854331970215, 16.75147332251072, 1.1663408833555877, 0.04612196593370754, 0.03349129154230468, 0.028261189472686965, 0.033460748454672284, 0.0020098300683457637, 0.03456330159679055, 0.04091142873221543, 0.06925808207597584, 0.06324516449240036, 0.01933871717483271, 0.03740095147804823, 0.03663611634692643, 0.006085308523324784, 0.053474252272280864, 0.027311652338539716, 0.05789205701148603, 0.04607603441399988, 0.042115474279853515, 0.1305269295698963, 0.034413695757393725, 0.003557163213372405, 0.007138049177228822, 0.02123641661455622, 0.03021446093043778, 0.012307228807912907, 0.0510980067338096, 0.04326772905187681, 0.045023268248769455, 0.06696675307466649, 0.03202815481927246, 0.029992940981173888, 0.02490983981260797, 0.02332094245502958, 0.06226239769603126, 0.008923096629587235, 0.020571888308040798, 0.04269614917575382, 0.03621523697802331, 0.046647799827042036, 0.06830698272096924, 0.028067785788152833, 0.049196483378182165, 0.039039902985678054, 0.08286795724416152, 0.029377043756539933, 0.22418249311158434, 7.728867447003722, 37.186320796608925, 52.97235332429409, 44.05809625983238, 30.42643792927265, 36.79820202291012, 39.26907263696194, 36.99292257428169, 12.832471914589405, 1.507811222691089, 0.04289464770408813, 0.30625629296991974, 1.5351235633715987, 3.5396530386060476, 6.47749294526875, 8.073454331606627, 9.229579344391823, 8.420033734291792, 9.813991785049438, 14.136152509599924, 33.97958926856518, 45.73483608663082, 48.903508856892586, 50.61209857463837, 52.65639267861843, 51.331768557429314, 51.225978434085846, 48.02016645669937, 46.56512193381786, 46.70954458415508, 46.42202541232109, 45.743260234594345, 48.60846608877182, 48.69519643485546, 48.81290651857853, 49.408604353666306, 48.438098430633545, 48.01722161471844, 48.88202480971813, 48.939720913767815, 53.951454386115074, 49.802890196442604, 48.65360766649246, 47.62485846877098, 54.00633864104748, 51.681319400668144, 50.116871148347855, 46.78736060857773, 39.460236579179764, 35.72249494493008, 36.46633543074131, 34.95326042175293, 36.01100966334343, 36.068758964538574, 36.72232389450073, 37.73944191634655, 40.83364628255367, 42.293429151177406, 46.6434471309185, 46.36945143342018, 49.20885667204857, 48.708472922444344, 52.13255658745766, 45.91742388904095, 40.71655556559563, 51.435624584555626, 53.02739717066288, 52.106546983122826, 46.482613161206245, 41.06038771569729, 36.32119461894035, 40.45337788760662, 40.80471843481064, 40.88785037398338, 40.244609490036964, 38.879114761948586, 39.376603066921234, 39.6089643985033, 38.07205706834793, 38.44486266374588, 38.87128338217735, 41.05798624455929, 47.351683527231216, 49.04780991375446, 51.950135976076126, 49.753979220986366, 48.31811226904392, 51.66555404663086, 52.280896827578545, 52.417602092027664, 51.64021320641041, 52.658402770757675, 51.10861413180828, 52.53923736512661, 51.927025616168976, 51.812347769737244, 51.56200960278511, 53.52680817246437, 49.616544395685196, 52.597845420241356, 53.19825500249863, 54.39235992729664, 52.48959302902222, 54.15939062833786, 55.76867647469044, 55.83912469446659, 56.67702913284302, 49.73483964800835, 32.46109575033188, 21.606738790869713, 11.304826587438583, 6.734334463253617, 6.017200369387865, 6.435432527214289, 8.488344568759203, 6.12323890440166, 6.109127886593342, 1.964891783427447, 0.9725811460521072, 0.12434906966518611, 0.38730748754460365, 7.211227873340249, 28.95455840975046, 41.49827241897583, 42.57755510509014, 40.83028346300125, 51.81412987411022, 50.07490620017052, 19.720742292702198, 1.673765298910439, 0.03915513996616937, 0.019107950065517798, 0.03187785507179797, 0.029274731277837418, 0.03165369307680521, 0.031268099119188264, 0.050854248329414986, 0.03803517603955697, 0.06424118604627438, 0.02423532961984165, 0.014608696474169847, 0.10026734234998003, 0.05582016994594596, 0.08117750068777241, 0.012560573904920602, 0.042802402458619326, 0.037116957537364215, 0.059169827509322204, 0.05239165548118763, 0.035487835775711574, 0.024930959480116144, 0.15988112631021068, 0.131059049454052, 0.07686448720050976, 0.2018047813908197, 0.1170755697239656, 0.22528878296725452, 0.13010433583986014, 0.19515778025379404, 0.07154830527724698, 0.16477058816235512, 0.1119476484018378, 0.10262759460601956, 0.21537643595365807, 0.14051301637664437, 0.18816836702171713, 0.20820611680392176, 0.2088752668350935, 0.13176912150811404, 0.14247623446863145, 0.06224851582373958, 0.17831239354563877, 0.18977271218318492, 0.16087080992292613, 0.16611990169622004, 0.36188317055348307, 8.415398932993412, 43.25464837253094, 60.47801837325096, 50.3974062949419, 38.74393701553345, 44.95810076594353, 44.61739964783192, 44.28087830543518, 15.890259984880686, 2.1510771615430713, 0.29231944237835705, 1.6256292443722486, 4.2404095362871885, 11.59345529973507, 9.59169041365385, 12.589235566556454, 13.674526680260897, 21.432768926024437, 16.941459327936172, 18.651707656681538, 36.82150237262249, 47.440735548734665, 50.052445605397224, 51.68175257742405, 53.255810514092445, 52.290080934762955, 53.98026444017887, 50.76726324856281, 48.489737659692764, 48.54682199656963, 48.791920244693756, 47.73339964449406, 51.08219034969807, 50.99505342543125, 50.90049549937248, 51.59062206745148, 52.10902065038681, 50.523042753338814, 50.74173241853714, 50.91068275272846, 55.65109558403492, 51.280858889222145, 48.21479581296444, 46.83712653815746, 55.19920863211155, 54.09724496304989, 51.39653988182545, 50.10528936982155, 40.43867267668247, 37.302985936403275, 38.02918776869774, 37.32056379318237, 36.58407211303711, 37.950163409113884, 37.9508625715971, 39.71033155918121, 42.62209251523018, 44.28794972598553, 47.97652579843998, 49.37307246029377, 51.65605455636978, 49.629836082458496, 53.60067240893841, 48.68216693401337, 42.98104785382748, 52.09725648164749, 55.91144621372223, 52.944291830062866, 48.996866047382355, 42.234026938676834, 36.87352158129215, 42.41325572133064, 42.922667786478996, 43.54464501142502, 42.57551461458206, 40.51911436021328, 42.12025344371796, 42.1768894046545, 40.47158271074295, 40.35299867391586, 39.93078052997589, 43.0314027518034, 49.250958412885666, 50.35381503403187, 53.50624367594719, 52.227817475795746, 48.03114026784897, 53.10757666826248, 54.39433962106705, 53.31540271639824, 53.17855305969715, 54.85020875930786, 53.93727354705334, 54.713112115859985, 54.84996937215328, 52.841936722397804, 54.22945126891136, 55.92050112783909, 50.62350556254387, 55.50151661038399, 54.25232224166393, 54.99888338148594, 53.28448377549648, 55.632225796580315, 54.349395632743835, 55.83043076097965, 55.52232429385185, 51.347393319010735, 34.9278511852026, 22.16581229120493, 11.535445712506771, 10.58184603229165, 9.403235726058483, 12.565974164754152, 14.631267841905355, 9.878777358680964, 13.125155009329319, 6.408407427370548, 3.4248495614156127, 0.41902248573023826, 0.7847785390913486, 9.076054282486439, 35.742250084877014, 50.75707979500294, 47.588220834732056, 47.507691755890846, 59.608172848820686, 57.55947098135948, 23.713362850248814, 2.4435075698420405, 0.13587796274805441, 0.16004389413865283, 0.0893290207022801, 0.10594952924293466, 0.06000495144689921, 0.07848084031138569, 0.1374386844690889, 0.24421166366664693, 0.15038079000078142, 0.10943757137283683, 0.07154543316573836, 0.19068285240791738, 0.13221625064034015, 0.18271061300765723, 0.1700940282898955, 0.14723351981956512, 0.12032528597046621, 0.16549605235923082, 0.24633916356833652, 0.130957642395515, 0.06414663643226959], [0.025070485098694917, 0.0240149952514912, 0.023926772446429823, 0.049926675055758096, 0.057606118643889204, 0.10556932698818855, 0.01803243150789058, 0.03982417496445123, 0.06005505383654963, 0.09512977310805582, 0.031868834266788326, 0.029497256837203167, 0.05116917127452325, 0.037294371650204994, 0.09619954187655821, 0.014808793403062737, 0.00955053332290845, 0.034816229235730134, 0.03628465005022008, 0.025631830758356955, 0.04147508618189022, 0.06823126139352098, 0.049378328112652525, 0.05116425825690385, 0.03186078567523509, 3.039597258903086, 21.60317648202181, 44.511795714497566, 40.056967958807945, 34.54262025654316, 22.267690524458885, 35.92512667179108, 35.45067273080349, 16.43776025623083, 3.016146579757333, 0.12663953035371378, 0.28178628883324564, 0.9661954699549824, 1.9098931783810258, 3.8407286955043674, 6.427563149482012, 5.854112645611167, 6.540300250053406, 7.914017261937261, 11.40054440125823, 27.747570276260376, 45.055272951722145, 56.311826929450035, 51.12253278493881, 48.26230846345425, 46.42569221556187, 45.25428727269173, 42.44472183287144, 41.402578353881836, 38.09866324067116, 39.72863517701626, 37.91116610169411, 40.06795696914196, 41.36483497917652, 43.66037160158157, 40.983586236834526, 42.620690390467644, 43.65032114088535, 47.982909455895424, 48.35660420358181, 51.08880199491978, 47.76819817721844, 48.24731446802616, 44.17856879532337, 46.41072481870651, 50.9831752628088, 50.172978937625885, 49.25629712641239, 38.83963868021965, 36.12307704985142, 36.94767840206623, 35.39383918046951, 35.35145625472069, 34.15176942944527, 36.22559554874897, 34.28872928023338, 36.428067684173584, 38.991079553961754, 43.67881581187248, 43.055778443813324, 47.29697786271572, 45.27360163629055, 51.79985783994198, 47.41706661880016, 37.0244836807251, 52.01342158019543, 47.8935344517231, 49.30283322930336, 44.460361674427986, 39.075066447257996, 38.572782799601555, 37.01011285185814, 38.81323769688606, 39.05544430017471, 37.47627563774586, 39.7994177788496, 38.3839975297451, 38.083885833621025, 37.1981305629015, 37.132245898246765, 37.54855155944824, 41.28836028277874, 44.52653132379055, 48.49600352346897, 48.20919871330261, 52.358382269740105, 47.21896804869175, 51.58694766461849, 49.199702963232994, 46.93844810128212, 45.34645892679691, 46.80416330695152, 46.23825587332249, 46.300800517201424, 44.78489086031914, 44.87897381186485, 45.11845976114273, 46.99764512479305, 47.055443823337555, 45.85037648677826, 50.33176101744175, 50.98056100308895, 52.97229252755642, 53.265705183148384, 48.16011294722557, 49.265697821974754, 48.5830644518137, 42.053073048591614, 31.758313961327076, 18.409879133105278, 8.604443538933992, 4.092275910079479, 4.746252642944455, 3.693564017303288, 5.913827391341329, 3.5528338188305497, 4.48086348362267, 1.8281916249543428, 0.09400685914442874, 0.3798131021903828, 0.24490374606102705, 9.558712933212519, 29.998231306672096, 39.24405477941036, 31.32570907473564, 35.14053717255592, 42.62480936944485, 40.914699733257294, 12.21272137016058, 0.34279893210623413, 0.003545084528013831, 0.03570533328456804, 0.04064901273522992, 0.011091690175817348, 0.06994798255618662, 0.023253184372151736, 0.032156806119019166, 0.05148666947206948, 0.03530366069753654, 0.008365263183804927, 0.011835739605885465, 0.07977429238962941, 0.050672529760049656, 0.02016487040236825, 0.06929487033630721, 0.04173103807261214, 0.058770678224391304, 0.029775241237075534, 0.05165597933228128, 0.05407213015132584, 0.053769063015352, 0.03549851157004014, 0.05181114756851457, 0.0020542694073810708, 0.05759083040175028, 0.04556787847832311, 0.057586978655308485, 0.04311567041440867, 0.012878394009021576, 0.06219621667696629, 0.05922207470575813, 0.022075577835494187, 0.07795951125444844, 0.03700058878166601, 0.01540588553325506, 0.1227404571545776, 0.026147218923142646, 0.05104031959490385, 0.03952882245357614, 0.032077162541099824, 0.02199263355578296, 0.039237288292497396, 0.015231261895678472, 0.038740249729016796, 0.02939121321105631, 0.09387612983118743, 4.097939031198621, 26.39917653053999, 52.8377303481102, 44.09329757094383, 38.07412415742874, 26.219033896923065, 37.56543405354023, 39.97721403837204, 18.511679470539093, 3.203121484257281, 0.1788426877465099, 0.22851213812828064, 1.0648026131093502, 2.410697042942047, 4.873964739963412, 7.789831850677729, 7.475016368553042, 8.775893189013004, 7.788207437843084, 14.75229324772954, 29.461563304066658, 45.76012372970581, 55.89668780565262, 54.69244882464409, 50.496960952878, 49.61144506931305, 49.0322345495224, 46.46192707121372, 42.87767060101032, 40.09933948516846, 41.606376618146896, 40.189455449581146, 42.260112538933754, 45.120659843087196, 47.05211900174618, 43.677953258156776, 46.028514727950096, 45.64397536218166, 49.48137804865837, 51.19276061654091, 52.23816052079201, 49.89488705992699, 49.17011775076389, 44.736447259783745, 47.5988944619894, 52.40497536957264, 51.74815781414509, 51.3347589969635, 40.44980227947235, 38.50179500877857, 38.55817258358002, 37.614839002490044, 37.39452302455902, 36.8474967777729, 38.68699707090855, 35.45499309897423, 38.04792836308479, 41.02380707859993, 46.13940417766571, 46.95805124938488, 49.54415827989578, 48.54855090379715, 52.34736666083336, 50.061090141534805, 40.05405351519585, 53.413125872612, 49.99675579369068, 51.32791556417942, 48.113451451063156, 40.780791118741035, 39.82931077480316, 39.46267984807491, 41.4028899371624, 40.55002950131893, 39.08577047288418, 40.401552468538284, 39.32665474712849, 39.402688667178154, 38.89451153576374, 39.066661298274994, 40.10785862803459, 43.9586365967989, 46.28159634768963, 50.330446287989616, 49.956884533166885, 53.325912952423096, 47.472764030098915, 54.01185594499111, 51.92414157092571, 48.60222302377224, 48.39315064251423, 50.26404105126858, 49.84436497092247, 48.11871416866779, 48.571425676345825, 47.71146722137928, 47.725720256567, 49.215198531746864, 49.63675171136856, 49.54989977180958, 52.88970775902271, 53.961026072502136, 54.756726175546646, 53.53491313755512, 49.281922951340675, 50.47713361680508, 51.17292948067188, 44.72167365252972, 34.458245784044266, 20.97773004323244, 11.70241255313158, 5.7658804301172495, 6.234912062063813, 10.11238882318139, 6.337461909279227, 9.524137638509274, 7.138758162036538, 2.72939401678741, 0.5185347225051373, 0.16386970994062722, 0.41592401918023825, 11.18176544085145, 32.85076104104519, 47.220997139811516, 37.71791987121105, 39.18764680624008, 49.5063541084528, 48.62118400633335, 15.727538466453552, 0.7238849659916013, 0.03833413167740218, 0.044281910959398374, 0.07198076957138255, 0.03545737432432361, 0.038254261744441465, 0.010722879887907766, 0.07693798208492808, 0.0707841529219877, 0.05758676714322064, 0.02180369945563143, 0.021030763782619033, 0.050275833273190074, 0.03291215660283342, 0.02716150844207732, 0.014098836381890578, 0.014056186082598288, 0.024709476638236083, 0.019654458337754477, 0.054662590264342725, 0.04723697973531671, 0.07107823636033572, 0.08476271221297793, 0.08843706309562549, 0.12576434528455138, 0.17584451503353193, 0.1107613772910554, 0.1730789610883221, 0.1300737148267217, 0.08548607613192871, 0.1512862992240116, 0.16496452619321644, 0.17181863106088713, 0.16991662530926988, 0.21332739590434358, 0.14673237717943266, 0.16388792224461213, 0.1399518785183318, 0.14386554976226762, 0.10658502287697047, 0.12555977969896048, 0.08614890306489542, 0.08864902789355256, 0.10933160010608844, 0.11076433103880845, 0.11343331672833301, 0.20948624733136967, 5.005962057039142, 31.515127010643482, 57.97828830778599, 51.779532730579376, 45.951998233795166, 30.708624087274075, 43.99089686572552, 45.309365317225456, 21.990428902208805, 4.363278318196535, 0.4328887729207054, 0.880317643750459, 4.311925023794174, 7.282689213752747, 11.954273488372564, 16.981096900999546, 12.399392053484917, 11.176367830485106, 11.818029899150133, 16.436116844415665, 34.863490238785744, 49.35579098761082, 58.98994982242584, 56.15054838359356, 52.0272072404623, 51.11431382596493, 50.199064537882805, 46.61269158124924, 43.780167773365974, 43.47050338983536, 43.163388669490814, 41.002038046717644, 43.69062177836895, 46.28968991339207, 48.28551761806011, 44.74739447236061, 47.256240248680115, 47.66025736927986, 51.439466178417206, 54.1400458663702, 54.120841696858406, 50.926695093512535, 49.608131647109985, 45.54010413587093, 47.45658829808235, 54.87352050840855, 54.11570817232132, 53.059798032045364, 42.82309792935848, 40.548840165138245, 39.67904023826122, 40.300348699092865, 38.366351276636124, 38.82202282547951, 40.088635459542274, 38.24787363409996, 39.45790730416775, 42.34135217964649, 48.251623436808586, 48.34361270070076, 52.123551070690155, 50.41368842124939, 54.08840283751488, 51.36381223797798, 43.87252561748028, 55.266829803586006, 51.16335779428482, 52.03284993767738, 49.87767018377781, 42.27233648300171, 42.33957767486572, 41.22197784483433, 44.29462216794491, 42.907806783914566, 40.61026766896248, 42.909091114997864, 40.2532996237278, 41.167446970939636, 41.41118489205837, 39.94281828403473, 42.02192232012749, 46.3403107970953, 48.91765549778938, 53.15443955361843, 51.924734339118004, 54.52614314854145, 47.80662551522255, 54.793580397963524, 54.014029428362846, 52.07493267953396, 50.54736904799938, 52.841758131980896, 50.85503853857517, 50.792022719979286, 49.73417088389397, 49.46004219353199, 48.907863423228264, 51.96777082979679, 51.82471990585327, 51.43202617764473, 54.51334923505783, 55.55862754583359, 55.94214856624603, 55.00593580305576, 48.80333103239536, 51.31632998585701, 51.785483211278915, 45.924917086958885, 37.903437316417694, 22.004972621798515, 11.933421157300472, 8.321463223546743, 10.334917232394218, 13.768696077167988, 15.303320679813623, 13.448235522955656, 10.505280140787363, 5.6806225050240755, 1.6742690093815327, 0.5681147589348257, 0.5186003283597529, 13.059047106653452, 39.07893843948841, 52.510214522480965, 45.29871068894863, 48.323979154229164, 57.91371077299118, 55.08251689374447, 17.711119428277016, 1.1439499910920858, 0.10173881339142099, 0.20459607301745564, 0.14068274555029348, 0.11983805859927088, 0.12763299891958013, 0.07690719037782401, 0.19089164823526517, 0.13518202118575573, 0.13870557508198544, 0.14400296582607552, 0.1622783820494078, 0.13482124835718423, 0.12838727328926325, 0.09072062923223712, 0.13739808899117634, 0.12271661194972694, 0.19605098466854542, 0.09789989868295379, 0.075802896899404, 0.17222200316609815, 0.2836231637047604], [0.015243154812196735, 0.055743216653354466, 0.01788367357221432, 0.005433804908534512, 0.019766943805734627, 0.02867207211238565, 0.11198895634151995, 0.034726652011158876, 0.026150397170567885, 0.02108975895680487, 0.0232186448192806, 0.047079859650693834, 0.028180874251120258, 0.0033698071047183475, 0.011869610298163025, 0.04336669444455765, 0.03824228719167877, 0.03286612860392779, 0.0566716433968395, 0.017733182721713092, 0.06526871176902205, 0.05636027162836399, 0.004720074066426605, 0.05277904543618206, 0.06637904632952996, 1.887638010084629, 15.716816391795874, 35.72281792759895, 44.96916577219963, 34.441557079553604, 30.047100484371185, 32.45631940662861, 33.672337755560875, 23.65367565304041, 6.303361589089036, 0.39859228825662285, 0.024440600245725363, 0.6885964376851916, 1.0762479552067816, 3.8540902035310864, 5.405377624556422, 7.627693600952625, 7.158804936334491, 6.7300444934517145, 17.83903006464243, 33.123996779322624, 47.96391807496548, 54.33008126914501, 50.67929416894913, 48.09525802731514, 45.57630479335785, 42.844897359609604, 40.05952902138233, 41.47472508251667, 40.63504233956337, 39.17980782687664, 39.26390491425991, 35.06765328347683, 35.30737102031708, 37.81702235341072, 38.318082466721535, 39.98965077102184, 41.90889358520508, 45.231211110949516, 46.4905471354723, 50.9971509128809, 51.77119217813015, 50.27899704873562, 47.08841845393181, 47.04246371984482, 51.40460304915905, 49.26776111125946, 48.062796369194984, 37.17323049902916, 35.312557741999626, 35.207588374614716, 34.767818972468376, 35.59733726084232, 37.09009476006031, 38.286886140704155, 36.58724494278431, 36.39423809945583, 38.48387137055397, 41.81646354496479, 41.08074702322483, 46.3717845082283, 45.74337422847748, 51.55477099120617, 46.69408321380615, 37.262829691171646, 50.701614171266556, 49.33711878955364, 50.15367977321148, 43.38164895772934, 40.44289045035839, 36.57003566622734, 37.22452014684677, 37.584201246500015, 36.63907416164875, 36.690177619457245, 37.09307760000229, 36.988370418548584, 38.40854801237583, 35.89174546301365, 38.343772888183594, 43.823857828974724, 46.327847465872765, 49.33953545987606, 48.49162615835667, 48.68146777153015, 48.49475339055061, 49.55554246902466, 49.93495590984821, 48.67772117257118, 45.49851916730404, 39.995388463139534, 39.48852226138115, 38.98096829652786, 38.16382214426994, 37.221822291612625, 37.93785586953163, 39.13165681064129, 39.80221062898636, 42.966133654117584, 45.61960726976395, 49.801879450678825, 50.47369860112667, 52.09584675729275, 53.36175262928009, 55.83024837076664, 53.948349952697754, 52.49947249889374, 45.045119896531105, 32.63317711651325, 19.927557595074177, 10.629315935075283, 3.692612168379128, 5.443386035040021, 6.922477092593908, 5.508319325745106, 8.052994329482317, 6.350363167002797, 0.671448492212221, 0.5047706735786051, 0.0636379535717424, 0.8159860270097852, 8.760986588895321, 29.151129461824894, 33.040636852383614, 31.441152580082417, 38.60275559127331, 48.05485859513283, 39.003189504146576, 5.62599141150713, 0.12651165830902755, 0.06462368895881809, 0.019368399371160194, 0.0037545186023635324, 0.0373128511273535, 0.05390864243963733, 0.021754923654953018, 0.025995809664891567, 0.03453987941611558, 0.01795034811948426, 0.020466781643335707, 0.047455256499233656, 0.022854860726511106, 0.04704847051471006, 0.025417988326807972, 0.0852175522595644, 0.0438624824892031, 0.04440563810931053, 0.02472829379257746, 0.03922846786736045, 0.04311633463657927, 0.04671441871323623, 0.02915065902925562, 0.10514007619349286, 0.009580142232152866, 0.04027282921015285, 0.041610312910052016, 0.040195063265855424, 0.02109754779667128, 0.024476139842590783, 0.04647772555472329, 0.04383530133054592, 0.05239780788542703, 0.05063023847469594, 0.010807551516336389, 0.0564100437622983, 0.03393144077563193, 0.01451202339012525, 0.03554431321390439, 0.07062031640089117, 0.04953573392413091, 0.011232593406020897, 0.03638096968643367, 0.0644275319064036, 0.046476293209707364, 0.026045451922982465, 0.04187623555480968, 2.5791173055768013, 19.203614741563797, 44.29777979850769, 50.719157829880714, 39.1151162981987, 29.14685659110546, 36.320750042796135, 38.069803789258, 26.24509669840336, 6.933848932385445, 0.5071540956851095, 0.04803842872206587, 0.7558139401953667, 1.75831432454288, 3.739915592595935, 7.855464778840542, 10.520199090242386, 6.236679442226887, 5.083571942523122, 16.73987064510584, 34.498865604400635, 49.050059393048286, 57.204984202980995, 52.12009325623512, 50.9955246001482, 47.45528496801853, 45.18119439482689, 41.61827377974987, 43.60367104411125, 41.82454951107502, 40.51708146929741, 39.5551934838295, 38.56448024511337, 37.47887469828129, 41.119425147771835, 40.551633015275, 41.72776110470295, 43.95073302090168, 46.3384260982275, 48.86451914906502, 54.63094912469387, 53.12653385102749, 50.872627794742584, 46.041753217577934, 47.205965146422386, 52.484763488173485, 50.784483924508095, 49.26024131476879, 38.807845786213875, 37.28476591408253, 36.73455163836479, 36.64149463176727, 37.170946821570396, 38.27528536319733, 39.970898777246475, 37.3710972815752, 38.15170079469681, 39.79656033217907, 44.699813425540924, 44.857417568564415, 48.33380542695522, 47.41895891726017, 53.79652909934521, 49.15143795311451, 40.3002043068409, 53.10672551393509, 52.56118878722191, 51.32589027285576, 46.57487981021404, 41.2201539427042, 38.76365415751934, 39.73362810909748, 39.003026112914085, 37.51638248562813, 38.124539852142334, 39.03958015143871, 39.478365406394005, 39.53839838504791, 38.498994559049606, 39.28923815488815, 45.64380057156086, 47.157377153635025, 50.87958142161369, 51.03019393980503, 51.22166186571121, 49.661666974425316, 49.916169717907906, 50.497017949819565, 51.28765292465687, 46.389442160725594, 42.04065531492233, 41.83227829635143, 41.35596625506878, 41.32719039916992, 39.686031863093376, 41.09363213181496, 42.564738392829895, 42.01103590428829, 44.791156724095345, 49.5740170776844, 51.34757950901985, 50.777830481529236, 54.259663447737694, 55.667769089341164, 56.39052450656891, 54.34312976896763, 53.95767465233803, 47.56432391703129, 33.62913407385349, 21.203726716339588, 11.286529619246721, 4.236747482791543, 7.225705571472645, 7.526789540424943, 5.145751805976033, 6.38350261375308, 8.21920121088624, 2.910156729631126, 0.31553536537103355, 0.15875855373451486, 0.7926500542089343, 10.794746708124876, 34.65451665222645, 41.09127625823021, 35.49660846590996, 44.192875027656555, 55.77565290033817, 44.18825447559357, 7.700233608484268, 0.028642796241911128, 0.021272941412462387, 0.05474750309076626, 0.047926713232300244, 0.12454630283173174, 0.05277908996504266, 0.050701425279839896, 0.029777196796203498, 0.037639229121850803, 0.05150506360223517, 0.014621347309002886, 0.03217129655240569, 0.008437487140326994, 0.0256660808736342, 0.09397454603458755, 0.09729807628900744, 0.044886353134643286, 0.012465322033676784, 0.02628236215969082, 0.03705760798766278, 0.044615339356823824, 0.01920306371175684, 0.13013123127166182, 0.1465388695942238, 0.09154775281785987, 0.20188681839499623, 0.05852520545886364, 0.16156112600583583, 0.12416164769092575, 0.10379824350820854, 0.13688286038814113, 0.10994468830176629, 0.14520098513457924, 0.1414528870373033, 0.10079172905534506, 0.14387267437996343, 0.10169480403419584, 0.2713323966600001, 0.1543296390445903, 0.07624581805430353, 0.16671255114488304, 0.11787273280788213, 0.1920135974069126, 0.1722929673269391, 0.093806642544223, 0.15244684007484466, 0.1276229799259454, 2.8951572719961405, 22.076045908033848, 50.056442990899086, 57.48434141278267, 47.19263546168804, 38.84305089712143, 43.43353897333145, 44.96576115489006, 30.41485045105219, 8.755114953964949, 0.9115042327903211, 0.4790219193091616, 2.047535330057144, 6.117204828187823, 9.944473933428526, 13.408634047955275, 15.983050055801868, 15.775332301855087, 10.735114607959986, 21.312982253730297, 37.61939115822315, 52.203601375222206, 60.28199449181557, 54.85180467367172, 54.658744633197784, 49.29338313639164, 45.983194559812546, 45.155310183763504, 45.55882953107357, 45.28668813407421, 42.85619035363197, 43.063796013593674, 40.177071914076805, 38.922033458948135, 42.084390968084335, 41.833129450678825, 44.1250828653574, 47.05176942050457, 48.22760112583637, 50.8667267113924, 55.191297456622124, 54.28861789405346, 50.94333440065384, 46.291206032037735, 47.31290280818939, 52.82114803791046, 53.462291434407234, 52.507839649915695, 41.935370564460754, 39.06836360692978, 38.20446856319904, 39.064320623874664, 39.203693345189095, 40.3119570761919, 42.31259532272816, 40.230744034051895, 41.23700603842735, 42.76868484914303, 45.96718601882458, 45.17986826598644, 51.0679829120636, 50.34529209136963, 54.21262577176094, 52.30860874056816, 43.794059827923775, 53.868660628795624, 54.85499270260334, 54.07049439847469, 48.79855468869209, 44.1484060138464, 39.79022987186909, 41.4752646535635, 40.53943566977978, 38.90203893184662, 39.377693608403206, 41.26779958605766, 41.61536693572998, 41.76598325371742, 40.222692266106606, 41.661367267370224, 48.75701531767845, 50.359153747558594, 53.09169352054596, 52.50651352107525, 53.330723494291306, 49.475799947977066, 50.43969042599201, 53.60544495284557, 53.59971106052399, 49.032306745648384, 42.9411955922842, 43.63884195685387, 43.39515343308449, 42.415452003479004, 41.11651070415974, 42.70432010293007, 42.88080923259258, 44.01399202644825, 46.34784959256649, 50.1257436722517, 55.6651396304369, 53.145259246230125, 56.78484834730625, 56.93333677947521, 57.27488525211811, 54.91709277033806, 55.19727073609829, 48.77751901745796, 36.49283140897751, 22.83521857112646, 14.562273994088173, 7.6842317171394825, 10.725493524223566, 12.112239561975002, 12.772122602909803, 16.416642889380455, 13.26433489099145, 3.365739220753312, 1.4124467899091542, 0.336189572699368, 1.1625256505794823, 12.954606860876083, 39.54307213425636, 45.44132083654404, 43.00495237112045, 52.20110110938549, 63.2745923101902, 51.167871952056885, 9.900141712278128, 0.5597059882711619, 0.21619974490022287, 0.10714025323977694, 0.10849424230400473, 0.22370572260115296, 0.12592990358825773, 0.11960598902078345, 0.1545898657059297, 0.15346151922130957, 0.12865781580330804, 0.07439102031639777, 0.22039394796593115, 0.17482495255535468, 0.1587739904061891, 0.1766915578627959, 0.2130942279472947, 0.1024758699350059, 0.16246817889623344, 0.052271765234763734, 0.12657690793275833, 0.10782382320030592, 0.1734346873126924], [0.02081992890452966, 0.013142350890120724, 0.03340611525345594, 0.044879087508888915, 0.03812376249697991, 0.023491499123338144, 0.036905642118654214, 0.0448542366939364, 0.01892035739729181, 0.05004472106520552, 0.04006473100162111, 0.03991630888776854, 0.017225132542080246, 0.03656141176179517, 0.06320305503322743, 0.03163867942930665, 0.012824753430322744, 0.012984150980628328, 0.04776920352014713, 0.09178523265291005, 0.017984759651881177, 0.024473764970025513, 0.043125785887241364, 0.03808829525951296, 0.06693258459563367, 0.33682304027024657, 10.544686876237392, 29.558938778936863, 50.633381232619286, 38.81948836147785, 33.988556787371635, 32.551473900675774, 41.35774835944176, 30.212612003087997, 10.838754046708345, 0.932011257391423, 0.21266047231620178, 0.45692827203311026, 0.7928460405673832, 2.2020317148417234, 4.54094965942204, 6.756699113175273, 3.3291329350322485, 5.309161087498069, 17.490746453404427, 32.97585792839527, 45.32816290855408, 52.70289458334446, 50.339637994766235, 46.34055018424988, 43.336666971445084, 44.79201167821884, 45.726153552532196, 47.49020889401436, 44.306705519557, 47.477601170539856, 45.00939421355724, 38.3896554261446, 36.23557761311531, 36.782565861940384, 35.41257597506046, 42.11344800889492, 42.07880146801472, 48.093179538846016, 47.639784067869186, 50.19032880663872, 50.958989560604095, 49.796031564474106, 46.65326960384846, 50.66199369728565, 49.4236895442009, 48.5420798510313, 44.924217984080315, 36.231713220477104, 33.77976179122925, 37.634898126125336, 36.41554355621338, 36.8378908932209, 35.9453833848238, 37.647562846541405, 36.37770898640156, 35.380794480443, 35.12917958199978, 42.42665380239487, 42.402384504675865, 48.862809240818024, 45.902004316449165, 51.09227880835533, 48.04709181189537, 33.54558415710926, 51.418137922883034, 49.48126405477524, 49.42483328282833, 45.13992480933666, 42.93845593929291, 38.84159557521343, 35.74348121881485, 34.932308346033096, 37.79786758124828, 34.96711067855358, 37.39087522029877, 37.534800097346306, 36.840535551309586, 36.24250464141369, 39.52968165278435, 46.92543379962444, 48.215065598487854, 49.96620163321495, 50.231837779283524, 49.25548017024994, 49.34909574687481, 50.363580510020256, 50.166401490569115, 49.079352021217346, 45.705710649490356, 40.62457390129566, 36.064617186784744, 36.422580778598785, 35.988689661026, 41.129578202962875, 42.11122512817383, 43.275193870067596, 41.31086267530918, 40.24521745741367, 41.7751407623291, 46.07112564146519, 47.139780297875404, 50.213883742690086, 49.67289537191391, 51.83339864015579, 54.49842743575573, 54.32806737720966, 46.33870728313923, 36.07297673821449, 18.84119588881731, 11.235903985798359, 4.013496162369847, 4.562460305169225, 6.5113111305981874, 2.0775005221366882, 6.24109860509634, 8.613472804427147, 2.983724344521761, 0.13791864621452987, 0.1088446399080567, 1.0414261487312615, 12.243708707392216, 30.16996119171381, 41.2692891061306, 33.31241726875305, 36.77629619836807, 45.84086559712887, 29.446861892938614, 4.658857332542539, 0.09047547559021041, 0.019086440770479385, 0.06677449229755439, 0.027173670387128368, 0.07651673906366341, 0.0536005732283229, 0.041695793479448184, 0.017102952770073898, 0.06008349664625712, 0.04923189124383498, 0.06033180441590957, 0.016946443101915065, 0.022137192790978588, 0.046856050175847486, 0.1121631012938451, 0.024341493844985962, 0.01463415399484802, 0.07981612725416198, 0.028264757347642444, 0.0805988184583839, 0.05334463618055452, 0.05672003884683363, 0.012097163908038056, 0.06350599971483462, 0.03548491542460397, 0.03236699718399905, 0.01646868924581213, 0.024460949935019016, 0.015561441541649401, 0.04591532233462203, 0.030239506559155416, 0.06406141561456025, 0.03672204591566697, 0.016315548928105272, 0.01938260222232202, 0.07016499395831488, 0.010126543820661027, 0.049913030670722947, 0.07302818485186435, 0.07007621083175763, 0.02718841871683253, 0.03080805476201931, 0.02997434276039712, 0.04955245822202414, 0.04479053073737305, 0.05643509124638513, 0.050912544029415585, 0.8105855074245483, 12.956241723150015, 36.08873449265957, 54.37685675919056, 44.29816737771034, 36.92581817507744, 35.34167937934399, 42.46204890310764, 32.558438926935196, 11.522400062531233, 1.0961848916485906, 0.18281584954820573, 0.40489614999387413, 1.7151403287425637, 4.138357937335968, 8.623171783983707, 12.161161936819553, 3.8869617646560073, 5.277194827795029, 19.590680971741676, 36.28635808825493, 48.424567356705666, 54.15422670543194, 51.29567429423332, 48.398310765624046, 45.78202195465565, 46.03187754750252, 47.431680634617805, 47.92376182973385, 47.19529911875725, 49.080757945775986, 45.86378216743469, 40.5722963064909, 38.045314103364944, 40.15080392360687, 38.07838372886181, 42.67695017158985, 42.972505912184715, 49.24329802393913, 50.15845611691475, 51.494449228048325, 53.12245287001133, 49.130759462714195, 46.55643180012703, 50.53917668759823, 52.63202838599682, 50.35277768969536, 46.53920732438564, 38.4436809271574, 35.881125032901764, 38.796028420329094, 37.08379849791527, 37.79234267771244, 37.34508007764816, 39.45009112358093, 38.837077617645264, 38.15581597387791, 37.90080025792122, 43.75545769929886, 44.41381797194481, 50.28979226946831, 48.53757329285145, 51.641375944018364, 50.39739869534969, 36.58284477889538, 53.50459836423397, 51.29064716398716, 51.205318942666054, 47.77265913784504, 44.621222242712975, 39.29565221071243, 37.31783553957939, 36.65272302925587, 39.20833669602871, 36.32735028862953, 37.81741753220558, 39.23811189830303, 38.895491883158684, 37.555543184280396, 41.85476168990135, 47.839619144797325, 49.77466531097889, 52.64045253396034, 52.43267968297005, 50.60561612248421, 50.50660863518715, 51.36496737599373, 52.39881590008736, 49.86273318529129, 48.29832673072815, 41.79027535021305, 39.06227633357048, 37.66349919140339, 37.41386018693447, 40.87230160832405, 43.52165624499321, 43.57242912054062, 43.32309789955616, 42.01855570077896, 44.992948696017265, 47.198050171136856, 50.98750703036785, 52.54652917385101, 52.48892426490784, 52.07597762346268, 56.24544449150562, 55.66062547266483, 49.730002507567406, 33.51287931203842, 20.653831623494625, 9.137630928307772, 4.624648243188858, 9.127479773014784, 6.844384158030152, 6.101779080927372, 6.0449037328362465, 7.166352281346917, 3.7176186265423894, 0.8013581181876361, 0.18029138969723135, 1.6774318646639585, 13.483209796249866, 36.891935393214226, 41.40858583152294, 36.76760986447334, 43.63156534731388, 55.50194978713989, 36.05227544903755, 6.434210892766714, 0.06842859103926457, 0.01581912634719629, 0.04417657051817514, 0.02587025683169486, 0.040465924903401174, 0.019406107894610614, 0.0631583332142327, 0.03474466393527109, 0.06212973879883066, 0.015344856874435209, 0.03961133072152734, 0.024759096631896682, 0.10322854126570746, 0.00966922685620375, 0.056733505116426386, 0.010607937911117915, 0.10607977616018616, 0.034544781301519834, 0.03973712846345734, 0.059134850089321844, 0.039941289578564465, 0.05674986576195806, 0.11181420282809995, 0.1559691471629776, 0.0915701879421249, 0.1849628530908376, 0.16023462609155104, 0.14803799305809662, 0.08849276127875783, 0.1379997777985409, 0.05165471025975421, 0.18867213686462492, 0.07898558236774988, 0.12336213199887425, 0.07774998812237754, 0.10768710475531407, 0.06882298315758817, 0.15060013916809112, 0.14079053507884964, 0.14442800864344463, 0.17804047063691542, 0.14473206654656678, 0.09452662969124503, 0.11638840034720488, 0.16788924112915993, 0.10440696045407094, 0.17976557806832716, 0.9785648749675602, 15.31713293865323, 41.89117893576622, 63.54952275753021, 51.69543944299221, 45.96771419048309, 44.38838593661785, 52.807730957865715, 37.95713223516941, 14.096701126545668, 1.6206080513074994, 0.5846682144328952, 2.0093697030097246, 3.5495044849812984, 9.337508752942085, 12.397689744830132, 14.876805916428566, 10.29121482744813, 7.69459281116724, 20.452767312526703, 37.52877742052078, 48.57278220355511, 56.97362221777439, 53.73127140104771, 50.87551563978195, 47.3033083230257, 48.373638689517975, 49.18411619961262, 51.850987896323204, 48.65001305937767, 51.28637619316578, 49.41165179014206, 43.890624046325684, 39.66808922588825, 40.44672444462776, 39.21924211084843, 45.0099565833807, 46.240501552820206, 52.435936108231544, 52.06482522189617, 53.41651149094105, 54.165398105978966, 49.9405188113451, 46.46078333258629, 50.763809233903885, 56.27820633351803, 52.171949073672295, 49.36161607503891, 39.23918344080448, 37.49999016523361, 40.52131064236164, 39.108637645840645, 40.14815166592598, 38.66608299314976, 41.50731973350048, 40.40274180471897, 40.07879018783569, 40.151396691799164, 45.95973461866379, 47.51616530120373, 52.90896512567997, 50.61141841113567, 53.06970790028572, 54.255274683237076, 40.34631483256817, 54.07050579786301, 54.668092131614685, 52.9426047205925, 51.17043301463127, 47.10515655577183, 42.22308732569218, 39.5065750926733, 38.034287095069885, 41.29326581954956, 38.88788089156151, 39.709191620349884, 41.48746579885483, 39.21917371451855, 39.69316028058529, 42.913757264614105, 49.84793297946453, 51.762741431593895, 55.5771591514349, 54.03857611119747, 50.5728542804718, 50.602648481726646, 53.333056569099426, 52.91656091809273, 51.775208562612534, 49.15673866868019, 44.621093049645424, 41.1584984511137, 40.68075388669968, 39.41840462386608, 45.41677035391331, 45.77134072780609, 47.073306664824486, 45.85852324962616, 44.614310413599014, 46.45280756056309, 50.29462181031704, 52.88316830992699, 54.63631443679333, 54.064106941223145, 54.51458416879177, 59.05094414949417, 59.22670751810074, 50.620792508125305, 39.072896763682365, 24.063401967287064, 16.040293984115124, 7.6851484179496765, 12.640637308359146, 15.405389852821827, 9.458189327269793, 14.850917905569077, 17.054755948483944, 7.244745874777436, 1.3546077185310423, 0.5124130728654563, 1.8301227525807917, 16.724812053143978, 44.54047277569771, 53.45483623445034, 45.85267536342144, 51.78550601005554, 63.201450034976006, 40.58604396879673, 7.8659759648144245, 0.15522882516961545, 0.1432455744361505, 0.14557259331922978, 0.11786747840233147, 0.13295550394104794, 0.15671577741159126, 0.16268188774120063, 0.1535296335350722, 0.1775084249675274, 0.09519131941488013, 0.15436517307534814, 0.19256805593613535, 0.14654658793006092, 0.0980235479073599, 0.15323707892093807, 0.12933011254062876, 0.19629863934824243, 0.14169913163641468, 0.12280756956897676, 0.2350971699343063, 0.18133888661395758, 0.13481796806445345], [0.030838692473480478, 0.023246581113198772, 0.053179129827185534, 0.05356700217816979, 0.03493506934319157, 0.02799872152536409, 0.06401532082236372, 0.016082269648904912, 0.019622080289991572, 0.1399403010145761, 0.03883924109686632, 0.04846056974201929, 0.07160508699598722, 0.013283031476021279, 0.06211241336131934, 0.017031778952514287, 0.05415123567217961, 0.03405922747333534, 0.034669996457523666, 0.020143160727457143, 0.01808720757253468, 0.05879656062461436, 0.04229789788951166, 0.027479969576233998, 0.10512981229112484, 0.05964217853033915, 4.94276337325573, 22.62127675116062, 43.37948687374592, 46.928454637527466, 41.852379217743874, 27.93655313551426, 34.80868957936764, 34.12313796579838, 15.11302214115858, 2.3712145490571856, 0.03301124816061929, 0.2131557816755958, 1.3091365084983408, 1.7852798150852323, 6.612349133938551, 11.755720842629671, 0.9541140182409436, 4.276858130469918, 16.765350177884102, 34.19233985245228, 43.32103081047535, 54.39663469791412, 48.80312204360962, 47.77321770787239, 48.357405960559845, 50.41980989277363, 48.75190079212189, 51.12883284687996, 53.73754866421223, 51.33256271481514, 51.69559523463249, 44.617654234170914, 34.31749753654003, 35.665030628442764, 36.243769973516464, 41.301287189126015, 43.95778924226761, 48.26068215072155, 48.97253215312958, 52.53529317677021, 49.67655837535858, 48.362455889582634, 48.94152581691742, 52.27432698011398, 48.00474688410759, 47.38140173256397, 40.309806391596794, 35.35239480435848, 36.39319695532322, 36.64312854409218, 35.856642946600914, 35.9735968708992, 35.73187664151192, 35.80667182803154, 36.594194769859314, 37.673108875751495, 35.92829950153828, 38.749526515603065, 41.813697293400764, 45.78182056546211, 46.979957073926926, 49.00964856147766, 45.83149529993534, 33.21141488850117, 46.76108501851559, 50.26941016316414, 50.337905287742615, 48.39757360517979, 47.62569062411785, 46.06113977730274, 45.27028441429138, 37.8178621083498, 33.81731517612934, 36.88558213412762, 37.34628841280937, 34.403046146035194, 36.952397748827934, 35.83035595715046, 41.63148187100887, 48.34199018776417, 50.366768538951874, 49.95131403207779, 49.6306948363781, 50.10660029947758, 46.33048452436924, 48.20977248251438, 52.14792676270008, 49.222266152501106, 46.12160973250866, 38.218284621834755, 33.308020904660225, 37.05905802547932, 47.26834639906883, 48.72237257659435, 50.85177831351757, 49.91232052445412, 49.211691319942474, 44.9801129847765, 44.91868928074837, 43.874615505337715, 46.55510947108269, 46.78438536822796, 49.4762559235096, 48.90844099223614, 52.89597362279892, 53.1788494437933, 49.15170393884182, 29.72199372947216, 20.686074793338776, 8.066159673035145, 2.2925884556025267, 8.78541262820363, 4.7877212427556515, 4.684250894933939, 2.2019514441490173, 5.283508189022541, 3.726072935387492, 0.337368103209883, 0.13595097523648292, 1.0237030684947968, 13.633667472749949, 35.64099691808224, 43.108208030462265, 40.970799922943115, 47.7279469370842, 42.523491606116295, 26.245077699422836, 3.7134300637990236, 0.044178470416227356, 0.02813515609886963, 0.05663183088472579, 0.02443951671011746, 0.06055800731701311, 0.005546062629946391, 0.06152263602416497, 0.004802991443284554, 0.04603445187967736, 0.0409695760026807, 0.03984128146839794, 0.052521204779623076, 0.04128814660361968, 0.021594178178929724, 0.01850629094406031, 0.0580846332013607, 0.033907510223798454, 0.04267041520506609, 0.062387123034568503, 0.040679284938960336, 0.012305469917919254, 0.03955487183702644, 0.07304117985768244, 0.02602332107926486, 0.04767410100612324, 0.07315571550861932, 0.048686431255191565, 0.03645911412604619, 0.07149990982725285, 0.09112158193602227, 0.06692481430945918, 0.022150100594444666, 0.028520371561171487, 0.014492201553366613, 0.0509881429024972, 0.08377164078410715, 0.03257142918300815, 0.06461649012635462, 0.04175915804808028, 0.015053423830977408, 0.05502209402038716, 0.018384090762992855, 0.02536113610403845, 0.034210644153063186, 0.05489702358318027, 0.04817519540665671, 0.030156348911987152, 0.06965995504288003, 6.762257739901543, 27.20867559313774, 50.681327059865, 50.41317544877529, 45.2229655534029, 33.83908420801163, 39.60189297795296, 37.3088414222002, 16.52935054153204, 2.1964631136506796, 0.28846662724390626, 0.27306566771585494, 2.4157141987234354, 3.6508319852873683, 9.25630996003747, 10.878878943622112, 3.10039019677788, 4.272007215768099, 17.218253575265408, 34.5637471228838, 47.2249299287796, 55.22922322154045, 50.133909434080124, 50.4361642152071, 50.0674320012331, 51.528920978307724, 49.99821871519089, 53.17667976021767, 52.99125351011753, 54.5179545879364, 53.28659266233444, 45.96760019659996, 36.495023891329765, 37.5911320745945, 39.12444859743118, 42.50474341213703, 46.86652556061745, 50.651757046580315, 51.58899575471878, 53.7380388379097, 52.12085321545601, 48.02583575248718, 49.169304594397545, 53.452826142311096, 49.693908244371414, 49.11589466035366, 42.76565261185169, 37.17357628047466, 37.406093403697014, 37.53660500049591, 37.396335527300835, 37.43117205798626, 38.40593755245209, 36.65982864797115, 38.36206890642643, 38.69957059621811, 38.94891321659088, 39.9282156676054, 46.13971196115017, 47.508934289216995, 47.574723958969116, 51.440913900732994, 48.02482880651951, 35.68933792412281, 48.86077634990215, 50.24412252008915, 52.96582147479057, 49.07444268465042, 48.869679272174835, 48.0262803286314, 45.91259054839611, 39.26308795809746, 36.1642250418663, 38.63424830138683, 38.43016505241394, 35.77819995582104, 39.08086113631725, 37.67149776220322, 43.491390869021416, 50.178595036268234, 52.07190044224262, 51.8047633767128, 51.268733739852905, 51.06942303478718, 47.27112025022507, 50.15483111143112, 54.472972601652145, 51.10001139342785, 48.33665907382965, 39.30317960679531, 35.647999942302704, 37.957333624362946, 48.360920771956444, 50.7242875546217, 51.50639958679676, 51.07334442436695, 50.27334675192833, 47.39476181566715, 46.305063888430595, 45.27935832738876, 49.20499987900257, 49.62644286453724, 50.666849836707115, 52.0525024831295, 55.25192700326443, 54.31837409734726, 50.51573574542999, 32.1386032551527, 21.381196193397045, 9.095453191548586, 3.4252903377637267, 4.511365871876478, 8.59797628596425, 4.6411412581801414, 5.128870736807585, 4.641022989526391, 2.5229173712432384, 0.3212524257833138, 0.06526793251396157, 1.5798297082073987, 14.952963329851627, 40.6863471865654, 50.08105807006359, 46.1037240922451, 52.099266573786736, 50.883878991007805, 31.562489569187164, 5.099200028926134, 0.060960897026234306, 0.10372296746936627, 0.0443751469720155, 0.034927428932860494, 0.05697172338841483, 0.0712119639501907, 0.003018142051587347, 0.07781150474329479, 0.052717061262228526, 0.11976825218880549, 0.059022158675361425, 0.03286857398052234, 0.08042410205234773, 0.037589894855045713, 0.027229977131355554, 0.06627208058489487, 0.020288629093556665, 0.0357962166890502, 0.09396831941558048, 0.047462392249144614, 0.024849712863215245, 0.03283998274127953, 0.09456304687773809, 0.09435145315364935, 0.18043033458525315, 0.20077028690138832, 0.15640909230569378, 0.10463244718266651, 0.1806159011903219, 0.16790141235105693, 0.11486254472401924, 0.15672725101467222, 0.12202051453641616, 0.12140996448579244, 0.19022119202418253, 0.16366376396035776, 0.13255808386020362, 0.19873815297614783, 0.2940830821171403, 0.19382479396881536, 0.21650006237905473, 0.15845508954953402, 0.08226626843679696, 0.14955601160181686, 0.08653888682601973, 0.10130043418030255, 0.22472418670076877, 0.15633085509762168, 7.092895098030567, 31.45316183567047, 57.33614556491375, 60.52360072731972, 53.06234009563923, 39.80662979185581, 46.19291290640831, 44.52815383672714, 20.472081676125526, 3.644686290062964, 0.582372365752235, 1.2212532805278897, 4.015699094161391, 7.636784613132477, 15.915942806750536, 22.314416617155075, 4.594019986689091, 5.963403806090355, 19.61795210838318, 36.22636690735817, 48.91214579343796, 57.4655894190073, 53.874227330088615, 52.45726436376572, 53.745410442352295, 54.981377720832825, 52.88824483752251, 54.54806797206402, 56.08883589506149, 55.747013837099075, 55.54319657385349, 49.20041732490063, 39.77357156574726, 39.60002347826958, 41.19143508374691, 45.06787307560444, 49.376119896769524, 54.650563672184944, 53.979770466685295, 55.05830079317093, 51.56068727374077, 48.229584619402885, 49.54011149704456, 54.20136697590351, 50.98031021654606, 51.18054427206516, 43.99052068591118, 39.53910134732723, 39.82054464519024, 40.27926363050938, 39.35494042932987, 39.0231042355299, 39.61898826062679, 37.56130747497082, 40.31262964010239, 40.86525298655033, 39.69599112868309, 41.49435482919216, 47.839945927262306, 49.47525277733803, 50.89967094361782, 54.043930023908615, 49.630341455340385, 40.26789844036102, 48.50287355482578, 53.16321328282356, 54.52353648841381, 51.51073515415192, 52.17216186225414, 51.08923897147179, 49.302289858460426, 41.86628267168999, 37.207527458667755, 39.96021755039692, 40.959404334425926, 38.84700648486614, 40.88124252855778, 39.450778886675835, 46.14643380045891, 52.09762126207352, 55.5451762676239, 52.77672462165356, 52.54409350454807, 51.077558398246765, 48.76489229500294, 50.51669329404831, 55.65499797463417, 52.13246539235115, 50.69545090198517, 41.83303825557232, 37.187282145023346, 40.5422855168581, 52.37862378358841, 52.32078328728676, 55.4110586643219, 54.381093531847, 53.410059437155724, 49.539993703365326, 48.9090109616518, 48.16395454108715, 52.79445827007294, 51.198289319872856, 53.07044506072998, 53.24123069643974, 56.84264324605465, 56.3567329198122, 52.76588760316372, 33.858968541026115, 23.893562480807304, 10.459580942988396, 6.769876331090927, 15.759800635278225, 13.637820649892092, 11.862010639160872, 9.854214526712894, 10.556977316737175, 7.23829809576273, 1.7542618419975042, 0.39684818184468895, 2.0741733256727457, 18.24022013694048, 48.067067340016365, 55.91513201594353, 53.31764079630375, 59.82068784534931, 60.789335668087006, 36.21397577226162, 6.553441844880581, 0.1657943511963822, 0.13392532768193632, 0.11677672911901027, 0.1189995875756722, 0.1645190891576931, 0.11108074570074677, 0.178708418388851, 0.14811772940447554, 0.24366579920751974, 0.2038792919483967, 0.13848542439518496, 0.18859435978811234, 0.19056544464547187, 0.09870466135907918, 0.12707713030977175, 0.15605666121700779, 0.16872803127625957, 0.1356737533933483, 0.18640143214724958, 0.1355386825161986, 0.08913662633858621, 0.1181264805200044], [0.03599269657570403, 0.04236296197632328, 0.027210239713895135, 0.04936726269079372, 0.04809427904547192, 0.009014868755912175, 0.014384761761903064, 0.0641536051989533, 0.07228541377116926, 0.019770199978665914, 0.0982876263151411, 0.006015733570166049, 0.02966133826703299, 0.04247673321515322, 0.04791595209098887, 0.08150974535965361, 0.06834745203377679, 0.03671542966912966, 0.0073070389862550655, 0.06676423581666313, 0.06034681064193137, 0.0014773522138966655, 0.021434542213683017, 0.015710403567936737, 0.03291196364443749, 0.0634779836400412, 1.861467626877129, 15.322037525475025, 35.964287370443344, 45.523787811398506, 40.20765647292137, 30.36857843399048, 34.69044752418995, 33.60639989376068, 20.257212705910206, 4.574724147096276, 0.3310755518032238, 0.08770709406235255, 1.2927741114981472, 2.5346235930919647, 6.7858226504176855, 9.951783791184425, 2.8950625145807862, 4.012208506464958, 13.899519257247448, 29.47770293802023, 43.99978458881378, 52.44048446416855, 50.696537643671036, 50.006388276815414, 50.10796442627907, 51.137876361608505, 51.28778971731663, 49.27917189896107, 48.49354885518551, 47.86692447960377, 49.04100447893143, 48.46840560436249, 35.776706635951996, 34.50735054910183, 37.2462397813797, 44.170460030436516, 49.38954837620258, 48.40879060328007, 51.93480759859085, 50.7503617554903, 48.94525721669197, 50.705858543515205, 51.601383090019226, 48.32663141191006, 47.3668447136879, 43.41901995241642, 35.138686671853065, 36.779788210988045, 34.8531623929739, 34.28828090429306, 34.749861136078835, 35.658198595047, 36.6759929805994, 38.21495220065117, 35.19230559468269, 34.94640938937664, 35.59106379747391, 38.31216998398304, 41.35771416127682, 45.00597819685936, 47.28190027177334, 50.14284275472164, 51.347598508000374, 37.8655419498682, 49.47215214371681, 48.058012425899506, 49.594034403562546, 49.39800292253494, 49.41064104437828, 46.509872898459435, 47.53674499690533, 45.77899731695652, 39.25112999975681, 35.96121333539486, 36.9193547219038, 37.959203124046326, 37.046606093645096, 35.754075050354004, 41.94393150508404, 48.9427075535059, 49.11940947175026, 51.04562871158123, 50.27683116495609, 46.07126623392105, 49.40849035978317, 51.36721305549145, 50.01077704131603, 47.629346027970314, 45.70930525660515, 39.08495731651783, 38.02334748208523, 42.12221793830395, 49.48170103132725, 50.40444351732731, 50.445481315255165, 52.64346197247505, 51.244190856814384, 47.229615077376366, 47.78176724910736, 46.98040544986725, 47.29068920016289, 47.91282221674919, 48.664467483758926, 49.75711405277252, 51.94014631211758, 50.89601933956146, 48.72348591685295, 32.6477075368166, 16.74493957310915, 7.981931492686272, 2.871394772082567, 3.4757912904024124, 4.812570959329605, 3.940327288582921, 3.48756305873394, 2.8077211137861013, 1.6111805196851492, 0.5096523428801447, 0.22240326827159151, 2.724766577593982, 19.094461798667908, 34.010474011301994, 34.71898779273033, 40.05074769258499, 43.16640950739384, 38.40095981955528, 24.441396184265614, 1.6231730324216187, 0.04697106822277419, 0.08148941793479025, 0.04283155401935801, 0.012155181302659912, 0.055719126539770514, 0.05486568268679548, 0.029901565903855953, 0.03984503673564177, 0.01595849982550135, 0.04911476178676821, 0.02530476442188956, 0.07091099338140339, 0.061930780138936825, 0.055619827180635184, 0.04167631210293621, 0.028190475786686875, 0.006342575406961259, 0.051181086455471814, 0.017838116837083362, 0.023586703682667576, 0.04469776227779221, 0.05424492068414111, 0.02092213006108068, 0.04637487501895521, 0.10217508490313776, 0.051131373693351634, 0.08546803452190943, 0.01676929801760707, 0.01623541182198096, 0.03962751325161662, 0.030627820488007274, 0.026838011835934594, 0.07613254405441694, 0.09825492728850804, 0.016951558354776353, 0.0809026462957263, 0.035686905757756904, 0.04246099968440831, 0.06982250022701919, 0.02928729954874143, 0.07082911222823896, 0.060847641580039635, 0.08004887218703516, 0.06102643608755898, 0.02251898324175272, 0.014092093042563647, 0.035028947313549, 0.030108406172075775, 2.608899869956076, 19.40341182053089, 42.1455904841423, 53.97897630929947, 44.98481713235378, 33.42768408358097, 39.096109718084335, 40.81404693424702, 22.396307922899723, 4.861667649820447, 0.31183510611299425, 0.05982090995530598, 2.154388683848083, 2.793175494298339, 7.653991989791393, 9.870805386453867, 2.678955285809934, 5.094794640317559, 14.697807021439075, 31.852856688201427, 44.166816025972366, 54.899689704179764, 52.27857515215874, 51.99068360030651, 51.38324059545994, 54.2426897585392, 52.39672601222992, 52.34837360680103, 52.026101499795914, 50.16173154115677, 51.376207172870636, 50.97290821373463, 36.66985630989075, 37.328763753175735, 38.739217668771744, 45.48300080001354, 50.75308620929718, 49.028020575642586, 53.13089981675148, 52.201842069625854, 49.163627699017525, 50.97067393362522, 53.61356131732464, 50.875956416130066, 49.38109003007412, 46.565441116690636, 37.14757427573204, 37.292388305068016, 37.35166512429714, 37.181373462080956, 36.08314499258995, 37.18148745596409, 37.723152190446854, 38.37497681379318, 37.7742138504982, 38.276337906718254, 38.69341492652893, 40.236823707818985, 41.88427470624447, 47.44011618196964, 48.425080329179764, 51.23439118266106, 51.51613846421242, 40.124600529670715, 48.93548794090748, 49.287995025515556, 52.28732228279114, 51.92924089729786, 51.094665080308914, 47.33055666089058, 49.84531491994858, 47.22624845802784, 39.27575267851353, 38.78022126853466, 40.70645950734615, 39.648299887776375, 38.74699965119362, 38.25052969157696, 43.29799264669418, 49.96405094861984, 50.605057552456856, 51.20271988213062, 49.679298028349876, 47.74910420179367, 48.593954667449, 52.304299771785736, 52.83338338136673, 49.755487740039825, 49.192585945129395, 41.5509869903326, 39.849430695176125, 44.8171853274107, 52.851842790842056, 50.95967352390289, 53.132309541106224, 53.98987032473087, 53.10254953801632, 49.4225762039423, 48.52821059525013, 48.9106410741806, 49.32427167892456, 49.08836133778095, 49.557107985019684, 49.86532464623451, 54.61220093071461, 52.0691379904747, 51.94691374897957, 34.222050458192825, 18.254290781915188, 8.150474298745394, 4.607128333300352, 5.991825331002474, 7.774418452754617, 7.703525656834245, 4.8206645250320435, 2.912781913764775, 1.7924366123043, 0.58578179217875, 0.22019137133611366, 2.585258726030588, 21.365168653428555, 36.80863246321678, 40.76839238405228, 44.406567960977554, 53.477239832282066, 46.970214396715164, 29.332305639982224, 2.3333559930324554, 0.030052429683564696, 0.14240728894947097, 0.06732889145496301, 0.04233576597471256, 0.06966765853576362, 0.0501026456913678, 0.031232045585056767, 0.0283476070035249, 0.057232825784012675, 0.05702034890418872, 0.027914517449971754, 0.02942180639365688, 0.03976471038185991, 0.032369141990784556, 0.06686608816380613, 0.02723363406403223, 0.008582860882597743, 0.042943173029925674, 0.013294229556777282, 0.08195684480597265, 0.0796494260430336, 0.0186367827700451, 0.20054422871908173, 0.14140133745968342, 0.1639947172952816, 0.12892145634396002, 0.19633622170658782, 0.08704344334546477, 0.1379882893525064, 0.10677433732780628, 0.23082226573023945, 0.09967630336177535, 0.22856373223476112, 0.18363708048127592, 0.12387748676701449, 0.14569461724022403, 0.21612498094327748, 0.16293837397824973, 0.14301904127933085, 0.14420717518078163, 0.10016877029556781, 0.1390418570372276, 0.17162439617095515, 0.17615259537706152, 0.0862722702731844, 0.08362796841538511, 0.08912803226849064, 0.11161631657159887, 2.931157252751291, 22.32161533087492, 49.752280712127686, 60.15670761466026, 52.63575978577137, 40.76638609170914, 45.49560472369194, 46.0337470471859, 28.021187894046307, 6.224658787250519, 0.6554832332767546, 0.9354371891822666, 3.3798039285466075, 10.322721786797047, 16.665915213525295, 21.034371703863144, 8.126699924468994, 5.884912367910147, 16.84639222919941, 33.90433430671692, 47.04466760158539, 56.04813627898693, 56.43245525658131, 52.94796623289585, 53.36797669529915, 55.62261611223221, 55.53982995450497, 54.11770686507225, 52.83576965332031, 53.00247810781002, 54.136705845594406, 53.645905181765556, 39.53441619873047, 38.77767540514469, 40.69309562444687, 48.19430731236935, 53.40721718966961, 50.411780923604965, 55.86952306330204, 51.66012033820152, 49.13716211915016, 52.80038595199585, 56.11820071935654, 53.28326404094696, 52.97524496912956, 46.53686285018921, 37.596326395869255, 39.912294521927834, 38.675685077905655, 38.089631125330925, 37.16269366443157, 39.719302877783775, 40.65946742892265, 40.72046555578709, 39.28226552903652, 39.7429908066988, 40.504454746842384, 42.95077867805958, 43.2229770720005, 49.474504217505455, 51.92411497235298, 53.66322845220566, 54.726248010993004, 43.23921360075474, 49.92270536720753, 50.51089480519295, 53.05173106491566, 53.70624594390392, 53.25943171977997, 49.48584280908108, 51.299458891153336, 50.485500767827034, 42.144040167331696, 39.626964032649994, 42.31055483222008, 42.2812470048666, 39.50950853526592, 40.4482139647007, 46.336131021380424, 52.68390320241451, 54.49823744595051, 53.4395382553339, 49.750745594501495, 47.57871754467487, 48.40801164507866, 54.411351308226585, 52.713541612029076, 51.50519885122776, 51.270208060741425, 43.00426460802555, 42.88240894675255, 46.88743203878403, 53.6103580892086, 52.89076790213585, 53.91956649720669, 55.87811440229416, 55.73173105716705, 52.36698500812054, 50.24517886340618, 50.3319776058197, 51.146752685308456, 53.72296504676342, 51.51035897433758, 53.06337743997574, 56.374656558036804, 54.95431177318096, 54.24502283334732, 35.655367746949196, 19.504955671727657, 9.70262736082077, 6.354459347203374, 10.101794991642237, 12.281900458037853, 10.707834921777248, 10.998406279832125, 8.947689570486546, 4.664210770279169, 1.5296142152510583, 0.4239311395213008, 3.766472367569804, 23.014646843075752, 43.61845225095749, 50.12499891221523, 52.38731391727924, 58.651532381772995, 56.08786314725876, 31.745278760790825, 3.3720684936270118, 0.18544668884715065, 0.1828163245227188, 0.11545306420885026, 0.1470238037290983, 0.23307162628043443, 0.1821456159814261, 0.17746925441315398, 0.11793870231485926, 0.08150048335664906, 0.20450876676477492, 0.1561933648190461, 0.11057696843636222, 0.2312119526322931, 0.23901988053694367, 0.18243814090965316, 0.09708981480798684, 0.11506794151500799, 0.21164442761801183, 0.1317272792221047, 0.16396004415582865, 0.16644637245917693, 0.15144510398386046], [0.034610368602443486, 0.06279686276684515, 0.024402980779996142, 0.008397373130719643, 0.01493066425609868, 0.06780242620152421, 0.055559420070494525, 0.05461464010295458, 0.019436291040619835, 0.016109183634398505, 0.05135889019584283, 0.0414707743038889, 0.03450228592555504, 0.017664491388131864, 0.033823027843027376, 0.015345155588875059, 0.018990113712789025, 0.048300503331120126, 0.04957086348440498, 0.048951878925436176, 0.011399358627386391, 0.022689818215440027, 0.026150282137678005, 0.032699356888770126, 0.031023440860735718, 0.018405392256681807, 0.427665151655674, 10.54913168773055, 27.999150976538658, 43.16596493124962, 43.80019649863243, 30.2479862049222, 30.058722160756588, 35.52187331020832, 26.037967912852764, 5.446058716624975, 0.8482683228794485, 0.12253324210178107, 1.8979446007870138, 1.6044994094409049, 6.202956726774573, 5.506426552310586, 1.5141058224253356, 4.227631771937013, 11.212204657495022, 27.443778477609158, 38.99796098470688, 52.10048630833626, 54.15228120982647, 53.21567326784134, 53.11269499361515, 51.802529096603394, 51.3260118663311, 51.87558397650719, 49.397516548633575, 51.03039152920246, 49.83960382640362, 43.60110618174076, 36.006556302309036, 35.5161090195179, 42.054068595170975, 48.26396517455578, 49.4669996201992, 48.65804962813854, 50.14999017119408, 47.73050419986248, 48.26761677861214, 53.08552645146847, 47.38633006811142, 47.55560338497162, 43.22929993271828, 37.288881093263626, 35.080545991659164, 37.29823239147663, 35.77811636030674, 33.86397287249565, 34.26768980920315, 37.94474110007286, 40.408354103565216, 40.95542214810848, 37.92688585817814, 39.56315025687218, 36.59479893743992, 37.319921627640724, 38.94305393099785, 44.24975037574768, 47.5597907602787, 48.232886642217636, 49.856854900717735, 35.609489008784294, 46.242542043328285, 49.219393506646156, 50.05798950791359, 45.63124604523182, 51.44159406423569, 51.89072996377945, 49.337703958153725, 48.87266971170902, 46.0639326274395, 35.53897239267826, 34.04325105249882, 35.895412266254425, 36.6660413146019, 36.32648393511772, 42.4445166438818, 49.30422395467758, 49.39206384122372, 49.97050680220127, 47.268061414361, 47.805911153554916, 50.4124952852726, 50.97281701862812, 46.70403108000755, 47.24773250520229, 41.8280491232872, 36.98437303304672, 35.17699621617794, 43.387759029865265, 50.28806336224079, 51.92928649485111, 49.01494927704334, 49.28240932524204, 51.51303023099899, 52.837213575839996, 51.38784974813461, 52.113834992051125, 51.40234597027302, 50.120302364230156, 52.66373008489609, 52.63272374868393, 54.93688590824604, 52.952043414115906, 44.788120687007904, 30.6377711892128, 18.334365785121918, 6.8047176115214825, 2.3068652395159006, 1.5239906357601285, 5.626334343105555, 3.6844578059390187, 2.1212031645700336, 1.014628205448389, 1.307039970997721, 0.2285597543232143, 0.4256117477780208, 2.4458781676366925, 18.978222236037254, 47.57988788187504, 36.89843684434891, 33.5479362308979, 46.067291647195816, 42.52674803137779, 15.254698488861322, 0.6689272087533027, 0.03426341456361115, 0.11311877227853984, 0.05314155117957853, 0.030153422994771972, 0.04406727814057376, 0.01602511871169554, 0.060908831655979156, 0.044301789384917356, 0.05299504009599332, 0.026613660593284294, 0.02353481457248563, 0.02668571200047154, 0.053239091648720205, 0.04435426293639466, 0.024309568507305812, 0.05124989467731211, 0.06555357773322612, 0.0665335392113775, 0.024964936856122222, 0.0030515489015670028, 0.041799983591772616, 0.09699272704892792, 0.03748050599824637, 0.03009632771863835, 0.02924086707935203, 0.04188777966191992, 0.06582253205124289, 0.05998424923745915, 0.04832525024539791, 0.06710235829814337, 0.04528347635641694, 0.04793540378159378, 0.03650842983915936, 0.0678969535510987, 0.04873851517913863, 0.0279245549972984, 0.02211137532867724, 0.019596069869294297, 0.08067188289714977, 0.039785115732229315, 0.026030510634882376, 0.044770778476959094, 0.07911667533335276, 0.017679352895356715, 0.06406014654203318, 0.03277204654295929, 0.05277612137433607, 0.012191518708277727, 0.7248935149982572, 12.808840982615948, 35.97723327577114, 51.32962927222252, 49.1985934227705, 35.115849897265434, 36.52296759188175, 38.029579147696495, 30.092641040682793, 6.564647918567061, 0.5580626951996237, 0.04551947189611383, 0.707847629673779, 2.637211438268423, 5.78300753608346, 5.557477762922645, 3.5030194418504834, 4.065092643722892, 13.639081232249737, 30.36258425563574, 42.91542537510395, 54.07036140561104, 56.47025562822819, 54.47693198919296, 54.29281286895275, 52.999172285199165, 53.598438128829, 51.229991018772125, 51.85737155377865, 52.109016850590706, 50.5573321133852, 46.702590957283974, 38.069522604346275, 37.51835457980633, 43.490026742219925, 49.17652040719986, 50.851611122488976, 50.44512793421745, 52.13055409491062, 48.699505403637886, 50.33762030303478, 54.05850224196911, 49.81342703104019, 49.725055173039436, 46.78563930094242, 37.95296385884285, 37.05051988363266, 37.57371760904789, 38.18126320838928, 36.17598921060562, 37.380326986312866, 39.099624529480934, 42.54165083169937, 41.09705574810505, 39.92071866989136, 40.282375663518906, 38.26455473899841, 39.4330870360136, 39.67004992067814, 46.17759592831135, 49.125888124108315, 50.7846587151289, 51.88109748065472, 38.91474924981594, 47.38561570644379, 48.98833550512791, 50.79671926796436, 47.95572191476822, 52.98320934176445, 55.0358971953392, 50.823956206440926, 51.40108063817024, 46.54584176838398, 37.34260641038418, 36.37246526777744, 37.378765270113945, 38.12031447887421, 39.00440163910389, 44.684971421957016, 52.27538712322712, 51.35834813117981, 51.11690528690815, 49.345573335886, 48.56781966984272, 51.38705179095268, 53.22036221623421, 48.84695649147034, 49.59420159459114, 44.561075270175934, 38.87299709022045, 37.48013623058796, 45.737180560827255, 52.243286445736885, 52.857056111097336, 49.69301909208298, 51.88719995319843, 53.51272612810135, 54.91547405719757, 53.45474883913994, 53.648648634552956, 52.677979320287704, 51.466315537691116, 53.96102987229824, 54.04694326221943, 58.19940984249115, 54.49303552508354, 47.27300874888897, 33.692617267370224, 19.04532853513956, 6.9294592179358006, 3.0677656223997474, 6.041760351508856, 10.512784738093615, 5.789889441803098, 4.2221220675855875, 2.779459417797625, 1.5610297420062125, 0.15179830690613016, 0.31582726689521223, 3.259130953811109, 22.4035332351923, 48.14964450895786, 41.79417014122009, 39.526790007948875, 50.8132141828537, 48.45898970961571, 19.606790207326412, 0.8436154131777585, 0.028749364937539212, 0.015656419745937455, 0.06590093995328061, 0.0945703050820157, 0.07181835055234842, 0.0049767940799938515, 0.046024733455851674, 0.09947018668754026, 0.057726854938664474, 0.04057783335156273, 0.0426491452526534, 0.00605348801400396, 0.007953713538881857, 0.022264352373895235, 0.055292655088123865, 0.061105144559405744, 0.08880023306119256, 0.039885539445094764, 0.1046350818069186, 0.08985266525996849, 0.04549306999251712, 0.05235764656390529, 0.12785200669895858, 0.09027774518472143, 0.17980988428462297, 0.16217321972362697, 0.18379919521976262, 0.16953787766397, 0.18788823595969006, 0.21868003212148324, 0.1782167752389796, 0.13045464438619092, 0.14702442713314667, 0.13465194962918758, 0.18877528054872528, 0.1256871470832266, 0.18820128869265318, 0.07240865481435321, 0.1605244050733745, 0.14472366543486714, 0.14342061738716438, 0.17350973328575492, 0.2195929182926193, 0.09431964470422827, 0.16510428744368255, 0.08749750413699076, 0.2053432079264894, 0.11853206422529183, 0.8936364634428173, 15.307576451450586, 42.21841357648373, 58.32360237836838, 56.02801255881786, 40.49021691083908, 40.73484018445015, 46.09072498977184, 35.767495930194855, 7.64361284673214, 1.394827135372907, 0.20970558165572584, 5.3866964019834995, 5.306186322122812, 14.242357760667801, 12.248559147119522, 5.248112613335252, 5.7349548395723104, 14.142251182347536, 32.31350027024746, 43.02472271025181, 54.69209924340248, 57.049720734357834, 55.80429956316948, 55.88707812130451, 53.72231528162956, 52.35024690628052, 53.29294212162495, 52.97021023929119, 54.71362128853798, 54.12012353539467, 47.716376557946205, 40.31312741339207, 39.786874651908875, 45.49958311021328, 51.61363363265991, 53.50062757730484, 51.399659514427185, 55.819301158189774, 50.663240030407906, 50.3956051915884, 56.43314301967621, 51.65869541466236, 50.53140610456467, 46.88859477639198, 40.11006250977516, 39.07603919506073, 41.28131166100502, 40.528028681874275, 37.41378799080849, 38.4405916929245, 41.249750554561615, 45.059011951088905, 43.4418985247612, 41.38716258108616, 42.989012226462364, 41.89983107149601, 41.81181259453297, 43.33860106766224, 48.76302659511566, 51.23558051884174, 53.25719363987446, 53.86415787041187, 42.51124106347561, 47.94428072869778, 48.605331256985664, 50.93767650425434, 46.606490314006805, 54.64233711361885, 56.40462175011635, 53.683386370539665, 54.34985160827637, 50.77253736555576, 38.92259582877159, 37.64682188630104, 39.06799502670765, 40.24696536362171, 40.946789011359215, 48.06080907583237, 53.98220233619213, 54.3334174901247, 51.504138708114624, 48.41126807034016, 49.28781643509865, 52.12991952896118, 54.53795671463013, 50.559042021632195, 52.16534502804279, 46.54449664056301, 40.31729958951473, 38.223402947187424, 46.678340658545494, 53.96026611328125, 55.904051810503006, 52.42202505469322, 50.41792519390583, 52.66316771507263, 54.90303352475166, 53.95845741033554, 56.003454476594925, 54.95214208960533, 53.72136153280735, 57.11784727871418, 57.01716028153896, 58.43414984643459, 55.65608471632004, 49.69213753938675, 35.322923585772514, 20.977209471166134, 8.78443418070674, 5.668370062485337, 7.9931494407355785, 16.17841277271509, 11.671865042299032, 10.49844715744257, 7.8373777493834496, 4.325398625805974, 0.8199927338864654, 0.70968595915474, 3.9846276864409447, 23.769926615059376, 56.13510221242905, 51.16118811070919, 44.76734720170498, 61.2185188382864, 57.64410763978958, 22.06573136150837, 1.4736886974424124, 0.18644512980245054, 0.21144919825019315, 0.1853859069524333, 0.13835750782163814, 0.11869149238918908, 0.068477231397992, 0.10511571890674531, 0.16327109362464398, 0.1948928483761847, 0.08758080279221758, 0.13889923109672964, 0.10551848245086148, 0.10896142426645383, 0.19290264579467475, 0.1731458434369415, 0.1578327245078981, 0.1421398189268075, 0.11045856619603, 0.13144404598278925, 0.1889791782014072, 0.1719088465324603, 0.13622095371829346], [0.044711703521898016, 0.06390859998646192, 0.038055351324146613, 0.04305314818338957, 0.09492329278145917, 0.01719816846161848, 0.027975696393696126, 0.01287144379602978, 0.011424330041336361, 0.027407764173403848, 0.035622802752186544, 0.024593920534243807, 0.008987564215203747, 0.014328048691822914, 0.043317237723385915, 0.0433916714246152, 0.01906060289911693, 0.02326607547729509, 0.025025486829690635, 0.08929726420319639, 0.02254799379443284, 0.011597144693951122, 0.015295010525733232, 0.013277651833050186, 0.0448568045248976, 0.025991546026489232, 0.00935822894462035, 4.645428378134966, 20.363563299179077, 41.47353194653988, 47.69393116235733, 37.3446810990572, 39.61062490940094, 36.628951504826546, 26.538038179278374, 12.763452418148518, 1.2021615612320602, 0.05565056693740189, 0.630254487041384, 1.1670465767383575, 3.5796945774927735, 4.968776302412152, 2.570074265822768, 2.131217052228749, 9.201298411935568, 25.61123751103878, 39.515880793333054, 49.53348845243454, 52.39478811621666, 55.112698674201965, 50.189280062913895, 49.5070456713438, 50.206781923770905, 53.080560117959976, 51.61003142595291, 49.70022350549698, 47.024015709757805, 39.37251828610897, 36.77362494170666, 37.80702508985996, 44.66319099068642, 49.03245493769646, 49.9996018409729, 50.77441446483135, 45.418518260121346, 49.296559765934944, 51.322113275527954, 48.59800525009632, 45.346873104572296, 44.67722363770008, 36.18521511554718, 38.250476494431496, 37.76500694453716, 35.63715912401676, 34.65958558022976, 35.60215160250664, 36.31555952131748, 39.722741693258286, 41.6966787725687, 45.10422192513943, 43.19695606827736, 44.492792934179306, 41.741675958037376, 40.94439513981342, 40.45017085969448, 44.05414827167988, 46.25432901084423, 48.46894137561321, 50.75820453464985, 35.7811675965786, 46.99952982366085, 47.10850037634373, 52.09831282496452, 50.59362016618252, 49.71248924732208, 50.05930423736572, 49.95215378701687, 47.06734098494053, 47.892193123698235, 40.907670110464096, 34.03049513697624, 35.01491591334343, 35.81656649708748, 36.075123623013496, 42.840884774923325, 48.04293863475323, 49.60872061550617, 49.94220592081547, 48.67261044681072, 50.143051743507385, 51.56840465962887, 50.49712814390659, 47.044158428907394, 44.81125384569168, 38.294371739029884, 37.54039339721203, 34.369467347860336, 39.944505393505096, 49.89080987870693, 47.46804088354111, 53.15558709204197, 50.41428878903389, 52.687163427472115, 50.93825027346611, 52.26500608026981, 50.828827545046806, 51.25152826309204, 55.32657779753208, 50.832916125655174, 55.8893807977438, 53.92254553735256, 50.98473697900772, 44.132598862051964, 28.163997530937195, 13.29807898029685, 5.251430785283446, 3.8841166673228145, 6.839320454746485, 6.633912976831198, 6.369368797168136, 2.60977691039443, 1.1932177911512554, 0.8697714877780527, 0.24994046485517174, 0.3455503407167271, 6.250622319057584, 22.05748960375786, 46.558966264128685, 39.7140933573246, 34.75081868469715, 45.52528873085976, 36.12283006310463, 10.233325883746147, 0.6985714368056506, 0.05201005798880942, 0.004004933607575367, 0.0832442261162214, 0.046313428902067244, 0.046764587896177545, 0.032876221812330186, 0.011520266543811886, 0.03973036007664632, 0.050108367649954744, 0.02989597382111242, 0.032556345031480305, 0.08159650242305361, 0.03954988831537776, 0.06471096552559175, 0.07112054619938135, 0.016342600210919045, 0.043884576225536875, 0.010148699711862719, 0.028040450633852743, 0.05061633804871235, 0.0339629189693369, 0.03727191055077128, 0.04750693966343533, 0.05641175441269297, 0.028652754008362535, 0.06530678394483402, 0.022138270760478918, 0.03378641398740001, 0.061995996366022155, 0.017416584378224798, 0.06834342959336936, 0.057601999724283814, 0.030550208539352752, 0.04810204562090803, 0.028763172595063224, 0.027321632369421422, 0.12142242514528334, 0.03539251432812307, 0.006878144422444166, 0.03242098471673671, 0.03495602388284169, 0.12562151154270396, 0.015117060211196076, 0.07408912948449142, 0.007354097642746638, 0.06937690734048374, 0.07448259391821921, 0.029728035078733228, 0.012512319462985033, 7.05707062035799, 24.946945756673813, 49.186027497053146, 52.57832206785679, 38.993834406137466, 40.309369415044785, 46.220959201455116, 31.140590608119965, 12.866252101957798, 1.4679658482782543, 0.03920645947800949, 0.359128555865027, 2.7603357564657927, 3.992649056017399, 7.845649430528283, 4.041613228619099, 4.262660192325711, 11.657920740544796, 26.09655126929283, 41.696234196424484, 51.05434164404869, 53.94469454884529, 54.27182279527187, 50.57758502662182, 49.86011132597923, 50.95246911048889, 54.52235855162144, 52.22830384969711, 53.17650876939297, 49.52121511101723, 41.2345589697361, 38.49937453866005, 38.894857317209244, 46.89913921058178, 51.31360173225403, 52.32276678085327, 51.695006266236305, 46.90463371574879, 50.88629946112633, 52.99751177430153, 51.0270781069994, 48.55795919895172, 47.3838260024786, 41.09139785170555, 39.85599674284458, 39.57811385393143, 37.28113330900669, 35.77860273420811, 36.521702259778976, 36.62211187183857, 41.8412534147501, 43.579800724983215, 45.46226151287556, 44.7999532520771, 45.85096925497055, 42.07511566579342, 42.38480664789677, 42.70349554717541, 47.30865843594074, 47.8636072576046, 49.90265004336834, 52.71873213350773, 37.96624414622784, 46.46297201514244, 47.543003261089325, 51.37775368988514, 49.48040530085564, 48.8455505669117, 52.25587137043476, 51.056925505399704, 49.673928916454315, 50.60898654162884, 41.635110676288605, 35.890062153339386, 36.437852159142494, 37.44258664548397, 37.331799790263176, 45.49798719584942, 50.254769548773766, 50.5238901078701, 51.45804338157177, 48.94875682890415, 49.947692826390266, 51.90964534878731, 51.69332675635815, 49.62567910552025, 46.65981285274029, 40.223060846328735, 39.238491877913475, 35.993279814720154, 42.495878487825394, 50.99119283258915, 49.90353159606457, 53.494346514344215, 52.01559126377106, 52.96768717467785, 52.157388255000114, 53.267745673656464, 53.692380487918854, 53.14828008413315, 55.471114441752434, 52.78033062815666, 57.184241116046906, 53.924160450696945, 54.341256469488144, 46.10678672790527, 31.290851645171642, 15.719469599425793, 6.598030552268028, 2.1519105043262243, 6.303044781088829, 9.534573778510094, 6.973246168345213, 5.113941337913275, 2.0852487813681364, 1.13995699910447, 0.29585916025098413, 0.3692073666024953, 6.361752105876803, 22.260077632963657, 51.80446319282055, 45.16720354557037, 38.73264022171497, 50.663684606552124, 42.60668434202671, 12.371213715523481, 0.8864804974291474, 0.03868829197017476, 0.02120701828971505, 0.07340236828895286, 0.026401291324873455, 0.058346340447315015, 0.054567947881878354, 0.02522849947126815, 0.017178857779072132, 0.016893735773919616, 0.00889347844349686, 0.039115828403737396, 0.08220599120249972, 0.01972472673514858, 0.02850596276402939, 0.0476990965398727, 0.042033697027363814, 0.021446325663418975, 0.008893749327398837, 0.047178999448078685, 0.12035591440508142, 0.023264088376890868, 0.013159773734514602, 0.14625283103669062, 0.1828956452663988, 0.12138962963945232, 0.12764355225954205, 0.11736785716493614, 0.14547462982591242, 0.15019988408312201, 0.10843948664842173, 0.1356149307684973, 0.11142760326038115, 0.13133398548234254, 0.16652634629281238, 0.122537153220037, 0.0810301472665742, 0.1454087716410868, 0.08987141933175735, 0.09834171403781511, 0.14616877539083362, 0.13699324743356556, 0.1918696949724108, 0.13390658103162423, 0.16576570429606363, 0.10603624177747406, 0.1505823276238516, 0.2800105372443795, 0.15859108068980277, 0.21947631204966456, 7.109141126275063, 30.738566480576992, 56.75301365554333, 59.06757965683937, 46.82778663933277, 50.911936685442924, 49.78416860103607, 35.842203721404076, 17.183135859668255, 2.083594207651913, 0.45706928009167314, 2.3370643565431237, 5.2906152326613665, 11.405141204595566, 12.904053423553705, 7.898892173543572, 4.101545987650752, 13.255554512143135, 29.93298500776291, 43.17723132669926, 54.35926750302315, 54.8725363612175, 55.76025232672691, 51.22529447078705, 50.44970668852329, 50.78164927661419, 57.1726593375206, 55.07587864995003, 55.27829758822918, 50.17336651682854, 43.84441092610359, 41.00530207157135, 40.08154883980751, 49.88154977560043, 53.263261914253235, 54.650685265660286, 52.89519086480141, 46.701219230890274, 53.38761784136295, 55.53692691028118, 51.33542776107788, 50.84684617817402, 49.775638058781624, 41.474231109023094, 42.98726812005043, 40.965081229805946, 37.763730213046074, 38.03771071135998, 37.24402830004692, 38.792110830545425, 43.88728402554989, 44.345452040433884, 47.46696934103966, 48.06253798305988, 48.67745518684387, 45.129277780652046, 45.885137021541595, 44.99894097447395, 50.15277922153473, 50.98639369010925, 52.15536676347256, 55.86899109184742, 43.028313517570496, 47.88317620754242, 46.0757689923048, 51.4640698581934, 49.69702027738094, 49.35610257089138, 52.71766819059849, 51.82712897658348, 51.368873566389084, 51.53119705617428, 44.992390125989914, 36.799357160925865, 38.053685054183006, 39.93436373770237, 39.298870638012886, 47.959430515766144, 52.19485804438591, 52.2698812186718, 51.03579483926296, 49.06501919031143, 50.73541335761547, 53.04414287209511, 54.24199439585209, 52.13073268532753, 48.731651678681374, 42.43771880865097, 41.9903764128685, 37.79602847993374, 43.85293386876583, 54.11274053156376, 50.93859605491161, 56.36898726224899, 54.07928332686424, 53.78001518547535, 51.98686860501766, 52.7241126447916, 54.295567721128464, 54.06942665576935, 58.0875476449728, 52.45325177907944, 57.2231662273407, 55.64551368355751, 55.308486968278885, 47.25554868578911, 32.77633063495159, 16.177770607173443, 7.956603476777673, 6.891194321215153, 11.183281559497118, 14.013887420296669, 14.302252046763897, 12.141057215631008, 6.180623425170779, 3.762988904491067, 0.9101953217759728, 0.9235970245208591, 8.610064387321472, 28.28135423362255, 55.8856114000082, 51.866589859128, 49.9389722943306, 57.94174946844578, 51.64925292134285, 15.148517936468124, 1.2372469785623252, 0.21277345687849447, 0.20184681663522497, 0.28687985613942146, 0.2363237619283609, 0.13753707840805873, 0.14240237593185157, 0.09652670283685438, 0.1008917111903429, 0.1691513226251118, 0.09530920215183869, 0.09847923400229774, 0.17980265576625243, 0.11340098877553828, 0.14305635646451265, 0.1794410072034225, 0.113513082760619, 0.14915744861355051, 0.08576896056183614, 0.13032761838985607, 0.2627643017331138, 0.09271538860048167, 0.1031860162038356], [0.03732125594979152, 0.06687133514788002, 0.0056055912227748195, 0.026423184681334533, 0.07879226031946018, 0.028331992216408253, 0.02508158762793755, 0.01909125359816244, 0.05592196663201321, 0.11678791328449734, 0.04338957856816705, 0.013241464712336892, 0.034603195745148696, 0.06559470755746588, 0.04190874533378519, 0.011640680004347814, 0.01404780630764435, 0.013827240945829544, 0.011497369432618143, 0.0915541872382164, 0.027145873245899566, 0.047532833195873536, 0.04015922866528854, 0.06533143066917546, 0.032493422040715814, 0.05793696807813831, 0.07100742805050686, 1.5578727051615715, 16.145012564957142, 38.00653338432312, 48.91146942973137, 43.318249359726906, 35.632135793566704, 29.29260917007923, 43.76577414572239, 16.435955353081226, 2.7513414015993476, 0.03147352559608407, 0.11647999621345662, 1.6445772838778794, 2.115460247732699, 4.943566555157304, 3.768665324896574, 2.056196015328169, 10.440400522202253, 23.045191504061222, 37.068884298205376, 47.24729172885418, 53.923921063542366, 48.50741811096668, 47.86622911691666, 52.05590710043907, 53.39013330638409, 47.85960607230663, 47.50201106071472, 47.882237657904625, 41.05555817484856, 35.96375919878483, 35.852064192295074, 40.089433416724205, 46.1796136200428, 52.191054448485374, 52.14659683406353, 46.76926977932453, 48.65757465362549, 52.473668083548546, 51.71684369444847, 47.14607656002045, 45.01372218132019, 38.38975802063942, 37.306930124759674, 37.5717531144619, 37.31610283255577, 35.82643076777458, 36.12716183066368, 34.734753146767616, 36.70003429055214, 42.37346425652504, 48.540993109345436, 47.83974073827267, 48.49684327840805, 47.27129504084587, 47.63847693800926, 44.264922961592674, 46.3805278390646, 45.56389085948467, 47.95555092394352, 48.602063432335854, 49.81983348727226, 35.53516499698162, 46.865761801600456, 49.03199516236782, 48.199364840984344, 51.39715164899826, 49.642827585339546, 50.89762285351753, 49.87459994852543, 50.56088112294674, 48.67267124354839, 39.809890016913414, 33.64746429026127, 37.40285597741604, 35.70389114320278, 38.05137097835541, 44.246015176177025, 47.83699728548527, 49.737127125263214, 50.36333732306957, 47.38233648240566, 50.38484036922455, 49.14634622633457, 49.72988851368427, 46.63060002028942, 44.814301282167435, 37.05978758633137, 36.324264854192734, 34.32945169508457, 34.543517008423805, 43.016161769628525, 48.51161688566208, 48.87987792491913, 50.27479447424412, 49.95365850627422, 52.641345486044884, 51.39640688896179, 54.23806540668011, 46.4031708240509, 53.793010488152504, 52.17480652034283, 48.88108246028423, 57.72751696407795, 47.68570460379124, 41.073694601655006, 24.05464343726635, 12.610145844519138, 4.519892139360309, 0.7838848745450377, 3.9491613395512104, 9.429227281361818, 2.227606005035341, 2.01438020914793, 1.4319214574061334, 0.8942029892932624, 0.11930196822504513, 0.3636587143409997, 7.0450418908149, 21.50972429662943, 29.536706171929836, 39.65696342289448, 40.39836443960667, 45.2727010846138, 34.149504750967026, 7.792190099135041, 0.07295516494195908, 0.04978075397957582, 0.031261330732377246, 0.04965123807778582, 0.07243975080200471, 0.045114099702914245, 0.01984139049454825, 0.0752874679164961, 0.03428462514420971, 0.05045307298132684, 0.06739535820088349, 0.09530113500659354, 0.013640921060869005, 0.027409517497289926, 0.10483675301657058, 0.058029896099469624, 0.07295291623449884, 0.06579764041816816, 0.019857430161209777, 0.048333562299376354, 0.07116028820746578, 0.0703079835511744, 0.03208997572073713, 0.024913379857025575, 0.031668328228988685, 0.03832381953543518, 0.06578074171557091, 0.07167570234742016, 0.07902152457972988, 0.058711833335109986, 0.028192770878376905, 0.026491901990084443, 0.08526955454726703, 0.027684533306455705, 0.07155506624258123, 0.06445188919315115, 0.04010002012364566, 0.027899958367925137, 0.025283269969804678, 0.02653003353771055, 0.03639506678155158, 0.0063929505358828465, 0.04527175784460269, 0.06042469904059544, 0.02447620478051249, 0.02827493219228927, 0.07797180121997371, 0.05759933170338627, 0.025188451327267103, 0.043970439000986516, 2.5066378572955728, 22.49441295862198, 46.73094883561134, 54.98125992715359, 47.527344301342964, 42.300819754600525, 35.1885399967432, 40.397881865501404, 17.397938333451748, 2.5235369754955173, 0.16339014895493165, 0.18948505574371666, 2.610172089189291, 3.997735558077693, 5.374687146395445, 3.6305358493700624, 3.008518726564944, 9.316770415753126, 25.013259798288345, 39.88835960626602, 49.51985478401184, 54.319749623537064, 52.182333916425705, 49.677778109908104, 54.34487387537956, 54.637040197849274, 51.0077865421772, 50.48561476171017, 49.34192553162575, 43.343495205044746, 40.672356337308884, 37.509664446115494, 42.061075419187546, 48.23910690844059, 54.27864342927933, 53.09316784143448, 48.13364736735821, 47.929966896772385, 52.954178899526596, 53.46754655241966, 50.8456302434206, 48.133369982242584, 40.6253756582737, 38.718535378575325, 40.01560337841511, 38.10821212828159, 38.937597423791885, 36.98159918189049, 35.251844599843025, 38.57176445424557, 43.10413084924221, 49.94442880153656, 50.03121234476566, 49.222383946180344, 49.35823805630207, 48.01038198173046, 47.02221840620041, 48.51705439388752, 48.225382044911385, 49.81809318065643, 49.732145592570305, 51.352728232741356, 37.79201589524746, 46.61299556493759, 50.09493112564087, 49.63329769670963, 52.66446344554424, 51.61609970033169, 51.68243274092674, 50.16393922269344, 51.72113746404648, 50.99433906376362, 42.04271100461483, 34.73844274878502, 38.23704041540623, 37.34422132372856, 38.71941313147545, 46.777564734220505, 49.39026653766632, 51.032770201563835, 51.82858049869537, 46.67625077068806, 51.014994755387306, 52.28259913623333, 52.881743386387825, 48.041718900203705, 46.81078255176544, 38.493454456329346, 39.49477292597294, 36.360856890678406, 37.08183020353317, 45.70655420422554, 50.76034002006054, 51.37704312801361, 52.60994017124176, 52.89709836244583, 53.85901674628258, 52.20806233584881, 52.69946716725826, 48.53761129081249, 55.75931757688522, 53.38147737085819, 51.34870044887066, 57.42978014051914, 49.67248119413853, 42.18332625925541, 26.59420106559992, 12.175937443971634, 5.949222492054105, 4.040604382753372, 4.22739808447659, 8.186232279986143, 6.6457825899124146, 4.977939510717988, 2.5109525257721543, 0.546234583016485, 0.27334893064107746, 0.40632410149555653, 9.027627781033516, 28.62762775272131, 37.448309138417244, 44.8648651689291, 45.10970123112202, 51.66162885725498, 39.84458215534687, 10.261324681341648, 0.14714133023517206, 0.09134208143223077, 0.04127637614146806, 0.025537156834616326, 0.0778149557299912, 0.03566753199265804, 0.03522268125379924, 0.028205955131852534, 0.03839510653051548, 0.008352033473784104, 0.10627931740600616, 0.09746464391355403, 0.01373369230350363, 0.06014697995851748, 0.0385641677712556, 0.034532825302449055, 0.016717273465474136, 0.00446285356701992, 0.060735488223144785, 0.023703953738731798, 0.03120868277619593, 0.03163273482641671, 0.0386979992617853, 0.10078044841066003, 0.12133914875448681, 0.12117655904148705, 0.19317630532896146, 0.20114605111302808, 0.1593276919447817, 0.13018819852732122, 0.10758873308077455, 0.1315435383003205, 0.20941363560268655, 0.14163143292535096, 0.12843721982790157, 0.12476848700316623, 0.17699202377116308, 0.0996933133865241, 0.10332951787859201, 0.08492258566548117, 0.12480318982852623, 0.1350906034349464, 0.31564321427140385, 0.17924249754287302, 0.11431840946897864, 0.13990547944558784, 0.136986686848104, 0.12306133212405257, 0.1955966863897629, 0.1823498698649928, 3.2198880845680833, 25.067268200218678, 53.75787377357483, 61.916260197758675, 53.976289853453636, 45.78682489693165, 38.90323206782341, 53.03286887705326, 21.108017452061176, 3.7146956333890557, 0.315120029845275, 0.7089540828019381, 5.4688256699591875, 5.586402285844088, 11.236028429120779, 7.951470427215099, 5.111328028142452, 12.51496760174632, 26.18507321923971, 42.285897955298424, 51.326521039009094, 55.8555968105793, 51.65352389216423, 50.89894138276577, 55.96042558550835, 56.767365485429764, 51.47889666259289, 52.44806885719299, 52.11958408355713, 45.24863697588444, 40.95390982925892, 38.80665265023708, 44.65672753751278, 51.10261805355549, 57.88734778761864, 55.9312279522419, 46.672663763165474, 48.09964679181576, 55.8410169929266, 56.1522962898016, 52.702864184975624, 49.38738629221916, 42.08992347121239, 40.27185022830963, 41.71023644506931, 40.12549728155136, 40.47028698027134, 39.08196687698364, 39.17943924665451, 38.91329012811184, 45.15047304332256, 52.73346774280071, 51.4983706176281, 51.33200794458389, 50.925194174051285, 50.77981777489185, 48.81428204476833, 50.210752710700035, 49.67284977436066, 51.905887350440025, 51.22272200882435, 52.848369777202606, 40.91025397181511, 46.963389962911606, 50.09843833744526, 51.826137229800224, 55.534795224666595, 53.380151242017746, 52.97111839056015, 51.558658182621, 53.023190796375275, 53.23017328977585, 43.07799965143204, 37.73235909640789, 41.76345258951187, 39.531744942069054, 40.75439393520355, 50.172412768006325, 51.31521664559841, 52.53878898918629, 52.148667722940445, 46.88512176275253, 50.398394241929054, 52.214335799217224, 56.41499139368534, 50.84492348134518, 49.107683300971985, 40.76281048357487, 40.576324090361595, 37.45362885296345, 37.9215357452631, 47.00580708682537, 51.951952278614044, 53.51888559758663, 54.377848505973816, 55.43354585766792, 54.091522470116615, 54.45255249738693, 52.99615524709225, 50.12262783944607, 54.57847014069557, 54.82471972703934, 52.97543875873089, 59.10420209169388, 50.036646053195, 42.90796637535095, 27.243956699967384, 14.454038701951504, 5.72290426120162, 3.5332817304879427, 9.501097574830055, 17.21234679222107, 10.258999206125736, 9.221281539648771, 4.1065731178969145, 1.9696961506269872, 0.6302696862258017, 0.6423969729803503, 10.086515061557293, 29.216060377657413, 39.806948974728584, 50.56862510740757, 50.80417066812515, 61.17398142814636, 46.24666482210159, 12.386102266609669, 0.3084274014690891, 0.1603996945777908, 0.12167215783847496, 0.08861908223479986, 0.17497615772299469, 0.25212795997504145, 0.10385394169134088, 0.16285834077280015, 0.12913843063870445, 0.07568154091131873, 0.19744418881600723, 0.18416700360830873, 0.08950910283601843, 0.10301492889993824, 0.15448633610503748, 0.09258750913431868, 0.12914285383885726, 0.08500658193952404, 0.1550052606035024, 0.07066055564791895, 0.111874391004676, 0.09666089055826887, 0.15386321407277137], [0.01954855386429699, 0.03346872283145785, 0.021669530287908856, 0.05218019905441906, 0.012124443401262397, 0.04298080733860843, 0.03830872425169218, 0.033038681649486534, 0.050513691603555344, 0.04961246086168103, 0.020258950607967563, 0.005137411535542924, 0.07345083795371465, 0.015662663063267246, 0.0044730562422046205, 0.018527557185734622, 0.008396657885896275, 0.040209249418694526, 0.028288457833696157, 0.053682688158005476, 0.04672961789765395, 0.038727247301721945, 0.08653203680296429, 0.024641935633553658, 0.020525949366856366, 0.03837295342236757, 0.05841181642608717, 0.4530897655058652, 8.997994121164083, 32.671365067362785, 51.80043540894985, 40.139393135905266, 37.46450386941433, 59.84385900199413, 59.98765468597412, 24.194502532482147, 4.997611530125141, 0.20722329063573852, 0.21441645309096202, 1.7196731292642653, 3.397106775082648, 4.3164752796292305, 0.6329719349741936, 3.6515712831169367, 6.567552862688899, 22.260032035410404, 34.342883974313736, 50.30285216867924, 43.47869575023651, 49.09177355468273, 52.71512992680073, 52.933451011776924, 47.84616619348526, 48.722733557224274, 45.942213758826256, 41.436920911073685, 37.57598988711834, 38.741740733385086, 36.28509275615215, 42.24758081138134, 49.22322750091553, 50.98834678530693, 51.148508191108704, 48.21139119565487, 48.568230047822, 49.97280187904835, 48.26051115989685, 46.94981329143047, 40.79327344894409, 37.94454351067543, 36.664829179644585, 35.3337188065052, 35.8242192864418, 37.9331973195076, 38.125843182206154, 37.987826988101006, 37.134191393852234, 43.798596784472466, 51.53929062187672, 50.38589671254158, 49.18223910033703, 48.0395682156086, 47.39432103931904, 46.30939565598965, 47.8825568407774, 50.011730790138245, 46.7048404365778, 50.86995653808117, 47.73500315845013, 31.037105061113834, 50.106049329042435, 50.26862360537052, 50.71755051612854, 46.56483694911003, 47.83888578414917, 48.492036536335945, 51.98777675628662, 48.45440335571766, 45.56532718241215, 36.12898573279381, 35.28673432767391, 35.970659628510475, 36.870470345020294, 35.369452089071274, 43.83749529719353, 47.40608140826225, 48.59814964234829, 48.86797696352005, 48.659603744745255, 48.04877512156963, 50.65016113221645, 49.44944456219673, 47.5266033411026, 46.601352989673615, 41.381105706095695, 35.6150709092617, 34.66120809316635, 36.33896246552467, 34.9065837264061, 40.08256338536739, 46.09045900404453, 47.90969878435135, 49.72137697041035, 49.93495970964432, 48.05162496864796, 51.20931252837181, 53.42123843729496, 42.949053570628166, 50.66318683326244, 42.25985795259476, 55.01855492591858, 45.043713971972466, 37.06671841442585, 21.835038140416145, 9.506860915571451, 3.7387224566191435, 3.2336678076535463, 3.8881931360810995, 6.104536782950163, 5.754822548478842, 3.201681599020958, 2.223115833476186, 0.3865399584174156, 0.13554334320360795, 1.0448267287574708, 6.129073491320014, 24.642426297068596, 36.13296031951904, 30.82167562097311, 36.201873421669006, 46.9636445492506, 23.531630001962185, 5.0074943248182535, 0.06317234496236779, 0.07478722327505238, 0.04877546300122049, 0.041536521166563034, 0.03605643221817445, 0.031333270817412995, 0.08276065753307194, 0.05694382605724968, 0.017946507505257614, 0.02494801959983306, 0.03461985324975103, 0.05007565378036816, 0.1297131201135926, 0.04410127592564095, 0.037119896442163736, 0.01649141380767105, 0.05495392775628716, 0.03489018796244636, 0.06387263551005162, 0.062243851425591856, 0.0531779201264726, 0.053646849846700206, 0.02978867596539203, 0.0524737926753005, 0.022841902828076854, 0.04833177743421402, 0.06589832759345882, 0.026209631687379442, 0.03832218309980817, 0.028943471806996968, 0.07440172208589502, 0.05033785826526582, 0.04304017544200178, 0.0448901343770558, 0.05893026966077741, 0.030770936245971825, 0.004610011710610706, 0.05637568603560794, 0.027163135600858368, 0.029907566167821642, 0.037366118776844814, 0.023658126119698863, 0.030467587093880866, 0.14415469049708918, 0.060331737622618675, 0.055093815171858296, 0.043592793444986455, 0.039262625214178115, 0.012481318099162308, 0.08340729822521098, 0.7491410826332867, 12.761191539466381, 41.933869644999504, 59.4066658616066, 45.1283810287714, 38.489244282245636, 50.82967109978199, 61.46461263298988, 27.8942709043622, 5.2886326890438795, 0.08414379073656164, 0.11021677448297851, 2.5559148006141186, 4.241516226902604, 4.864716986194253, 3.4101412631571293, 2.9213632782921195, 9.103606604039669, 25.074434615671635, 38.51263202726841, 50.79669266939163, 50.358777567744255, 50.46612560749054, 52.98884443938732, 55.964415371418, 50.955584943294525, 51.772225722670555, 48.909417539834976, 43.74600760638714, 39.4036690145731, 39.725074768066406, 39.124931171536446, 43.183455392718315, 51.363120675086975, 52.307050824165344, 52.48869247734547, 49.55081932246685, 47.9916337877512, 53.223044872283936, 51.39741003513336, 48.3510223031044, 41.16968885064125, 39.60837543010712, 39.47684548795223, 37.4749381095171, 38.415976613759995, 38.06841306388378, 40.53815893828869, 39.02188450098038, 39.379536509513855, 45.741896107792854, 52.3678969591856, 50.47652184963226, 52.964381352066994, 49.830066338181496, 48.872183337807655, 49.37743842601776, 50.865005403757095, 51.020911037921906, 49.43444296717644, 53.179894387722015, 49.99347656965256, 35.17771437764168, 49.83955442905426, 51.49913817644119, 53.55592221021652, 49.477601051330566, 49.69586133956909, 50.01545839011669, 54.33657132089138, 50.071714371442795, 49.690598621964455, 38.19351755082607, 36.73658072948456, 38.21002386510372, 39.28323067724705, 37.54578150808811, 45.726598128676414, 49.322029799222946, 50.182626619935036, 48.84593054652214, 47.19599448144436, 48.34787607192993, 53.000468015670776, 51.15008510649204, 49.4034556299448, 48.98180365562439, 41.91254518926144, 38.05684268474579, 37.13906653225422, 37.60664664208889, 37.684360072016716, 42.99275502562523, 49.185408130288124, 50.043664276599884, 51.276777908205986, 51.88960522413254, 51.627278700470924, 52.657639011740685, 53.251231759786606, 46.33094049990177, 52.608135268092155, 45.20705960690975, 56.68139889836311, 47.92532354593277, 39.188087582588196, 23.949453681707382, 9.868435263633728, 3.8442007591947913, 5.492565846070647, 4.894741550087929, 10.352340247482061, 7.688410542905331, 5.706430720165372, 3.3485194947570562, 0.817371824523434, 0.22195673285750672, 0.839550937525928, 8.65640290081501, 26.64670094847679, 38.701443895697594, 37.39824302494526, 41.26177690923214, 52.343057692050934, 29.14747215807438, 5.830690702423453, 0.09810887262574397, 0.11307807289995253, 0.04875397411524318, 0.021032938275311608, 0.034340642450843006, 0.051807251293212175, 0.08517344642314129, 0.03257585609389935, 0.024643358701723628, 0.05279710931063164, 0.01692854621069273, 0.025634719568188302, 0.11648643063381314, 0.024334608569915872, 0.01015422778436914, 0.026972557643603068, 0.0870795339869801, 0.054306979072862305, 0.030324269100674428, 0.033088925047195517, 0.04475770183489658, 0.05151485253009014, 0.053114006368559785, 0.11906387240742333, 0.13007325469516218, 0.0944422697648406, 0.1680227238102816, 0.08139397032209672, 0.09979443842894398, 0.23713650269201025, 0.12560879113152623, 0.21933343377895653, 0.17659386154264212, 0.2104013302596286, 0.10866563388844952, 0.2020155216450803, 0.1297168605378829, 0.19572126329876482, 0.12613538943696767, 0.0850142260605935, 0.11711045808624476, 0.14748546411283314, 0.10116571953403763, 0.2639684214955196, 0.24770222167717293, 0.18017046415479854, 0.10186123065068386, 0.16867069294676185, 0.16655644780257717, 0.1538694481132552, 1.075387301389128, 16.2260128185153, 50.968549847602844, 66.94769561290741, 52.03272074460983, 47.16560371220112, 67.13938012719154, 66.9675761461258, 30.607813596725464, 6.350697549059987, 0.41357909969519824, 0.7815380254760385, 5.525473030284047, 8.5189557261765, 8.632178250700235, 7.358753057196736, 7.475842824205756, 12.364273387938738, 34.24855783581734, 47.12779954075813, 55.65139576792717, 50.57915814220905, 51.787018328905106, 54.055944979190826, 57.41654545068741, 51.74412623047829, 53.02100211381912, 50.49872025847435, 45.15138499438763, 41.10029697418213, 42.59174734354019, 41.17359884083271, 46.44205793738365, 54.105156138539314, 53.91736261546612, 54.27949458360672, 49.16697911918163, 49.399933218955994, 54.68132682144642, 54.169334694743156, 50.047464072704315, 43.550986871123314, 42.89616800844669, 41.25177584588528, 38.388853669166565, 40.005241334438324, 39.86346714198589, 41.905245780944824, 40.77854923903942, 41.422462686896324, 47.39288471639156, 55.23478992283344, 52.36310921609402, 55.1408551633358, 52.349327355623245, 50.84251821041107, 50.1850850880146, 53.482152968645096, 54.02927041053772, 50.54312847554684, 54.37919743359089, 51.2993448972702, 38.41904304921627, 50.30027970671654, 52.84556172788143, 54.3148934841156, 51.14193454384804, 51.989745050668716, 52.46072597801685, 56.64422169327736, 52.468032985925674, 50.34360498189926, 39.55117329955101, 38.90001364052296, 39.03806783258915, 41.42380401492119, 38.4072332829237, 47.7244321256876, 50.506270453333855, 53.1469501554966, 50.850839763879776, 49.130767062306404, 48.192118629813194, 53.76323528587818, 52.63831704854965, 51.19477450847626, 50.35671807825565, 45.451310500502586, 40.44064477086067, 37.55208536982536, 39.370242208242416, 38.528423979878426, 44.16250705718994, 51.07547990977764, 51.695469841361046, 54.6979471296072, 54.538538083434105, 52.783514857292175, 54.81647416949272, 55.67087732255459, 48.00024412572384, 53.646315559744835, 48.89775976538658, 58.52777302265167, 50.636854246258736, 41.59023888409138, 27.484162710607052, 12.366215083748102, 7.112891050055623, 7.767607793211937, 9.697333294898272, 14.14495948702097, 14.466407038271427, 9.767759665846825, 6.926476377993822, 1.616279489826411, 0.35300402669236064, 1.6407466144300997, 9.490437246859074, 32.968588918447495, 49.54471305012703, 42.09272012114525, 49.58187125623226, 60.670440047979355, 33.69723781943321, 7.413867199793458, 0.18483141873730347, 0.2840629604179412, 0.1646786805940792, 0.15707153332186863, 0.14176433673128486, 0.1205314917024225, 0.20088111923541874, 0.21065734152216464, 0.16418740851804614, 0.06517179470392875, 0.13164798816433176, 0.08921140513848513, 0.2248469676123932, 0.20212065428495407, 0.08038168831262738, 0.11898821787326597, 0.17017409118125215, 0.08924402995035052, 0.13151756313163787, 0.27902647911105305, 0.10833935608388856, 0.11901365127414465, 0.16633785562589765], [0.05502853215148207, 0.01655729611229617, 0.06109066525823437, 0.024732696583669167, 0.017778839646780398, 0.029042858368484303, 0.044676102697849274, 0.040634629913256504, 0.08907342504244298, 0.05734284917707555, 0.025317432882729918, 0.05446165378089063, 0.06543363182572648, 0.018541641293268185, 0.052272444299887866, 0.03525324660586193, 0.04788154241396114, 0.035074400148005225, 0.06708503657137044, 0.057866827701218426, 0.03288408857770264, 0.10464351260452531, 0.014308739864645759, 0.09985751355998218, 0.009483569338044617, 0.06516824723803438, 0.08032190089579672, 0.03961294118198566, 7.499775364995003, 26.315221935510635, 48.97547699511051, 45.24670667946339, 55.44086046516895, 76.75782680511475, 52.978866174817085, 22.768710739910603, 6.420258991420269, 0.9024696832057089, 0.06336700287647545, 1.4419137337245047, 4.756882572546601, 4.542523724958301, 1.4168448164127767, 0.5829695274587721, 12.922292444854975, 24.700470082461834, 29.65292863547802, 31.6661936044693, 50.214989483356476, 56.54661253094673, 53.05189825594425, 49.48956660926342, 48.67355279624462, 44.73045498132706, 42.72667050361633, 39.6775659173727, 37.904493659734726, 38.682862892746925, 36.947689801454544, 40.90082287788391, 49.28216993808746, 51.22968703508377, 50.2489672601223, 50.70986732840538, 50.496212393045425, 50.74832886457443, 48.6467794328928, 43.360601887106895, 39.034393429756165, 37.32925772666931, 37.954331785440445, 37.23340407013893, 37.63391777873039, 41.09048970043659, 35.364272966980934, 37.87031069397926, 36.52638740837574, 43.18375177681446, 50.16665607690811, 50.320308431982994, 50.76238051056862, 50.039583295583725, 46.35856881737709, 51.5787249058485, 52.27905012667179, 51.924152970314026, 53.634019419550896, 39.4237395375967, 34.27937798202038, 28.884072192013264, 50.92485599219799, 52.1420256793499, 47.52127222716808, 47.21510745584965, 44.1743054240942, 45.788641199469566, 44.49995554983616, 42.76067107915878, 35.837393179535866, 35.24577632546425, 36.22849099338055, 35.635164231061935, 35.43757103383541, 35.465358942747116, 41.138625517487526, 47.075183764100075, 49.39532406628132, 48.78357969224453, 49.013930931687355, 49.048976451158524, 51.28011032938957, 50.46550624072552, 50.559410601854324, 45.97793564200401, 47.23397344350815, 38.04131671786308, 35.444650053977966, 36.00196994841099, 35.61735458672047, 38.2086331397295, 38.268251940608025, 40.86929976940155, 42.88000747561455, 43.48884880542755, 49.601212218403816, 42.47578516602516, 54.35052417218685, 48.07947747409344, 47.53546066582203, 51.16142749786377, 47.81350314617157, 45.055675730109215, 27.68543791025877, 18.259929679334164, 5.879211723804474, 2.2932085348293185, 3.343252739869058, 3.783552451059222, 6.837873682379723, 5.648035928606987, 3.9890330750495195, 2.452729200012982, 0.1344133194652386, 0.2826687617925927, 1.3433306361548603, 15.158250164240599, 26.39118365943432, 35.711258947849274, 32.7380058914423, 41.87344528734684, 42.1637687087059, 17.417778968811035, 1.4354914845898747, 0.059208456295891665, 0.10794693065690808, 0.05275542658637278, 0.06185651713167317, 0.031929367542034015, 0.0476395837176824, 0.07503309680032544, 0.010277708170178812, 0.02139412670658203, 0.03437259190832265, 0.0370529547217302, 0.01814186489355052, 0.050879770788014866, 0.026531172734394204, 0.00990245975117432, 0.019684801045514178, 0.03438215077039786, 0.019664278806885704, 0.025369689356011804, 0.07176877508754842, 0.07663045093067922, 0.09263750762329437, 0.03930820050300099, 0.050716008481686004, 0.04934497599606402, 0.0592319526913343, 0.02768156657111831, 0.0442090023716446, 0.07672079998883419, 0.0404841334966477, 0.030474244158540387, 0.04221918941766489, 0.09811938885832205, 0.01082192598914844, 0.049207808551727794, 0.05108242163260002, 0.06358754690154456, 0.009117363988480065, 0.040973394352477044, 0.060624978723353706, 0.10141886610654183, 0.013040486483077984, 0.04615773374098353, 0.05470007614349015, 0.055931395618245006, 0.0250240340756136, 0.07075361354509369, 0.019316152174724266, 0.05810247814224567, 0.05864517363079358, 0.14552715903846547, 10.450634323060513, 34.072661474347115, 57.036516442894936, 50.083695128560066, 56.87622584402561, 74.69647541642189, 61.67844995856285, 30.040420442819595, 6.8306193966418505, 0.653595922049135, 0.20840918325120583, 1.024422061163932, 3.6839286843314767, 7.855396857485175, 2.6092556258663535, 1.8664642400108278, 13.626772742718458, 29.1299531981349, 34.87615115940571, 40.369713976979256, 51.73467613756657, 56.27761736512184, 55.653656646609306, 53.025919049978256, 51.1254358291626, 47.92692705988884, 45.20038716495037, 40.20764887332916, 39.41291771829128, 41.80182673037052, 39.579432383179665, 43.30493867397308, 49.84259806573391, 53.64887662231922, 51.67305864393711, 51.025413796305656, 51.30890138447285, 53.19503657519817, 50.26752546429634, 46.679009422659874, 41.95034176111221, 38.20883072912693, 40.14174900949001, 38.95616702735424, 39.75740343332291, 42.62864336371422, 38.23466174304485, 38.93566332757473, 38.59954856336117, 44.75065849721432, 51.81468464434147, 52.561819553375244, 52.251828387379646, 51.12746872007847, 48.538223057985306, 52.81506836414337, 54.224359542131424, 53.9713691174984, 53.099414706230164, 43.00108417868614, 36.88617490231991, 33.5190349817276, 53.565581291913986, 53.35181996226311, 49.35760349035263, 49.861236065626144, 47.461170852184296, 47.83440962433815, 46.03353425860405, 45.06862163543701, 38.86323541402817, 37.61256292462349, 37.61491879820824, 36.1991223692894, 38.09073306620121, 37.608793526887894, 43.64259995520115, 49.761008843779564, 52.87289746105671, 49.91721086204052, 50.79205311834812, 47.652946561574936, 51.44440971314907, 52.682250291109085, 52.185164764523506, 49.17394794523716, 47.4491710960865, 40.44715762138367, 37.68793188035488, 38.72935339808464, 37.535305470228195, 38.520638197660446, 40.16932412981987, 43.464651703834534, 45.56155398488045, 45.794135704636574, 50.56775875389576, 46.56044438481331, 55.48402614891529, 48.78511480987072, 51.69495686888695, 53.088414296507835, 49.85049404203892, 47.51620329916477, 30.391006730496883, 19.75907653570175, 6.740753743797541, 3.606438492424786, 5.775267826393247, 6.500670751556754, 8.357306700199842, 7.772887609899044, 5.312171475961804, 2.3916308535262942, 0.3220929525559768, 0.10605325922369957, 1.6101096896454692, 12.197505086660385, 29.56888284534216, 40.967756286263466, 37.01416343450546, 46.87224805355072, 47.687186524271965, 21.666775569319725, 2.29525163769722, 0.030306683911476284, 0.11959966592257842, 0.03589254745747894, 0.05974413106741849, 0.0464565001311712, 0.032263898028759286, 0.038219317721086554, 0.01866401402367046, 0.015736896384623833, 0.054388938151532784, 0.032541954788030125, 0.057457314323983155, 0.03438549414568115, 0.08188425534171984, 0.005624421828542836, 0.07209610674181022, 0.028583201783476397, 0.053332906536525115, 0.02644819691340672, 0.03814990464888979, 0.056795930868247524, 0.032728838705224916, 0.03572087014617864, 0.240048719861079, 0.13605802261736244, 0.19124523707432672, 0.19891484349500388, 0.12162586266640574, 0.1775885175447911, 0.12504458078183234, 0.1943571216543205, 0.2578283369075507, 0.15059911500429735, 0.11719541915226728, 0.11840882318210788, 0.21543445705901831, 0.1892690610839054, 0.11932957611861639, 0.23620988678885624, 0.2420090138912201, 0.1514309734920971, 0.13165420736186206, 0.16948614997090772, 0.11890719761140645, 0.2722845721291378, 0.12438564270269126, 0.17826480703661218, 0.11662740900646895, 0.15972499328199774, 0.2042240195441991, 0.2583184512332082, 12.310849204659462, 40.58866202831268, 65.76415792107582, 57.55953177809715, 64.2340712249279, 81.02283954620361, 59.54295314848423, 31.03908285498619, 8.640647996217012, 1.357385131996125, 0.5197649064939469, 3.3322957903146744, 8.179059214890003, 12.088879365473986, 5.053724069148302, 2.3072252701967955, 17.310905903577805, 32.06952676177025, 36.27431273460388, 41.7121097445488, 53.929312974214554, 57.78590843081474, 57.5531405210495, 54.52614314854145, 53.71600762009621, 49.39626641571522, 48.7981291115284, 42.639780566096306, 41.93388104438782, 42.4960532784462, 42.02037960290909, 45.38843907415867, 52.517726719379425, 56.377495005726814, 52.91458502411842, 52.07027032971382, 51.543234810233116, 55.361353531479836, 53.19479338824749, 47.62666717171669, 43.72537091374397, 39.418689608573914, 41.563233733177185, 40.75097791850567, 41.792783215641975, 44.413342997431755, 39.19790245592594, 40.062979236245155, 39.97114956378937, 47.100832387804985, 54.355577901005745, 53.700485453009605, 53.53879652917385, 52.62024521827698, 49.236207604408264, 54.161256328225136, 56.8448281288147, 55.31101383268833, 56.01915143430233, 45.801708698272705, 37.8958947211504, 38.191461861133575, 52.80452772974968, 56.24254144728184, 50.16619250178337, 52.23264321684837, 47.78221182525158, 49.2825461179018, 48.52368123829365, 47.27992817759514, 40.15419714152813, 39.130786657333374, 40.76523095369339, 39.26753751933575, 38.798635080456734, 40.08816048502922, 46.21826134622097, 51.0690126568079, 53.50773699581623, 52.03403927385807, 51.19274541735649, 49.41062584519386, 52.527218610048294, 54.009199887514114, 55.77683083713055, 51.42539173364639, 51.361011788249016, 42.74247385561466, 39.15320165455341, 39.61235001683235, 38.4172647446394, 42.37612411379814, 40.68885885179043, 44.40542422235012, 46.5213368833065, 47.635323107242584, 51.93164236843586, 47.146247550845146, 56.78168311715126, 52.77741618454456, 53.25209431350231, 52.76488445699215, 53.17352592945099, 48.79855468869209, 32.31013745069504, 20.63971158117056, 7.984572350978851, 4.67583529651165, 8.91991876065731, 12.294170949608088, 16.79470930248499, 14.78382870554924, 11.54874499887228, 6.190470596775413, 1.4656005939468741, 0.3966579248663038, 2.2571558319032192, 18.167997412383556, 34.55672889947891, 49.19216796755791, 44.481214955449104, 56.554641500115395, 52.85283833742142, 25.581253319978714, 2.919081738218665, 0.11112896303529851, 0.2740551286842674, 0.15085810970049351, 0.15289640345145017, 0.1478069624863565, 0.21284376794937998, 0.1731693249894306, 0.1544964441563934, 0.10122602645424195, 0.22237068798858672, 0.08876285108271986, 0.09874591734842397, 0.18992874131072313, 0.19324961467646062, 0.06084492531954311, 0.2983133535599336, 0.11827871727291495, 0.1274712849408388, 0.08609018434071913, 0.1774654843029566, 0.12709275993984193, 0.17507379467133433, 0.08999722078442574], [0.03797026409301907, 0.10319397202692926, 0.029623063855979126, 0.03763134009204805, 0.03823563012701925, 0.08734629896935076, 0.10787509076180868, 0.02142885550711071, 0.064089134830283, 0.03634956570749637, 0.014931636469555087, 0.016086447940324433, 0.06330708929453976, 0.02482670814060839, 0.04223969124723226, 0.014503369020530954, 0.03585170707083307, 0.09302962134825066, 0.018590372565086, 0.06767882892745547, 0.02092330265440978, 0.01891995663754642, 0.00630654228189087, 0.05482991487951949, 0.04319798943470232, 0.03063988966459874, 0.052595579109038226, 0.07272595263202675, 2.253944054245949, 19.80755053460598, 43.0548170953989, 47.29040801525116, 51.696887165308, 52.72987313568592, 29.786003194749355, 26.14824939519167, 13.043403346091509, 1.0883892537094653, 0.19345578330103308, 0.9539283032063395, 1.304283575154841, 4.609762066975236, 3.4793562116101384, 2.785504893399775, 5.292019257321954, 9.575335141271353, 19.97944761067629, 38.72243396937847, 51.77896276116371, 52.42302440106869, 53.76963034272194, 49.026261270046234, 49.05554249882698, 44.5075361430645, 43.815840259194374, 43.68369095027447, 41.813233718276024, 39.17576864361763, 40.5325922369957, 40.75890429317951, 47.74532340466976, 49.594581574201584, 50.69303423166275, 49.72898416221142, 50.05080409348011, 49.992910400033, 48.530786857008934, 43.3714085072279, 42.64357656240463, 40.68479686975479, 40.761522352695465, 37.85893030464649, 36.51056505739689, 35.9789127856493, 34.00931127369404, 35.11286325752735, 33.97486612200737, 43.12790997326374, 50.46190783381462, 48.12921680510044, 48.11736524105072, 49.45163704454899, 50.20602956414223, 50.572873279452324, 51.74892917275429, 47.355825304985046, 48.19029852747917, 46.28925673663616, 43.15880611538887, 37.95080937445164, 47.8191876411438, 51.078964322805405, 45.72330370545387, 44.71294932067394, 38.84519778192043, 38.07953506708145, 34.56210941076279, 34.89011161029339, 35.60242138803005, 36.17023251950741, 37.65466086566448, 42.243503630161285, 36.40513211488724, 35.18929995596409, 36.67055927217007, 45.41223719716072, 50.77662594616413, 50.271009877324104, 49.239114448428154, 49.689219295978546, 49.12628710269928, 49.911488369107246, 50.75384236872196, 46.861232444643974, 49.17272441089153, 45.1411597430706, 36.51325911283493, 35.30101016163826, 36.07198119163513, 36.983088701963425, 35.875372141599655, 37.95030020177364, 38.55776980519295, 41.14836059510708, 42.98536442220211, 45.185754150152206, 47.13848456740379, 56.04575380682945, 51.99082799255848, 45.92349216341972, 49.04651798307896, 41.61321625113487, 23.877688832581043, 11.902791950851679, 2.2672575898468494, 2.1687279269099236, 3.5142288403585553, 3.265402279794216, 7.745769890025258, 6.50316009297967, 4.251731978729367, 1.3275949680246413, 0.7858219393528998, 0.3661508165532723, 2.3244761070236564, 14.99720910564065, 32.913210690021515, 31.571895964443684, 30.199586302042007, 40.84365114569664, 35.393292009830475, 11.139595303684473, 0.5547436920460314, 0.1684496516827494, 0.02208492333011236, 0.07613857771502808, 0.018315783490834292, 0.04229533748002723, 0.01935636915732175, 0.035561063486966304, 0.024511210031050723, 0.054870554886292666, 0.008531594248779584, 0.05922647564148065, 0.012768069118465064, 0.04689319466706365, 0.0383966056688223, 0.012641034772968851, 0.05336351641744841, 0.015574382741760928, 0.04701549689343665, 0.07300023557036184, 0.04070249560754746, 0.04613223354681395, 0.0036965366916774656, 0.01525554311228916, 0.03738250168680679, 0.07311265610042028, 0.026686374367272947, 0.04143306578043848, 0.059333530443836935, 0.043466042043291964, 0.011302488874207484, 0.009252235413441667, 0.018082361348206177, 0.048912608181126416, 0.037212034076219425, 0.009652091594034573, 0.07554275187430903, 0.03013293415278895, 0.022159501750138588, 0.06854290404589847, 0.06140302408311982, 0.024143449882103596, 0.042629623058019206, 0.0157390949971159, 0.03844057420792524, 0.026721490939962678, 0.01950294703419786, 0.05361231400456745, 0.09228264971170574, 0.0623276547412388, 0.06515828019473702, 0.06134786395705305, 3.3864777954295278, 25.91741368174553, 52.80075453221798, 53.47677245736122, 60.29448062181473, 62.1297213435173, 39.120367616415024, 28.522103615105152, 12.819407265633345, 1.3880670606158674, 0.09165929019218311, 0.7851135148666799, 3.878120114095509, 7.75416886433959, 4.459281116724014, 0.742394900880754, 6.803377233445644, 12.434288430958986, 25.55556859821081, 39.53501656651497, 53.08554545044899, 55.50373949110508, 55.128228440880775, 51.538903042674065, 51.652953922748566, 46.41496539115906, 45.91945677995682, 44.3226532638073, 42.84357503056526, 41.57033175230026, 42.27067597210407, 43.08295838534832, 51.429818496108055, 51.58471338450909, 53.123315423727036, 49.481682032346725, 51.073374822735786, 52.98500284552574, 50.06759539246559, 45.28257295489311, 43.96951541304588, 41.515196710824966, 41.63657359778881, 38.58443297445774, 37.78121307492256, 37.79521532356739, 37.08206199109554, 36.53142973780632, 35.66139802336693, 46.61785930395126, 52.44686432182789, 50.569495260715485, 49.614477306604385, 49.99866709113121, 50.99855683743954, 50.636732652783394, 51.347332522273064, 48.29466752707958, 49.093080684542656, 45.39471633732319, 45.28969757258892, 40.73404222726822, 48.471369445323944, 53.20339612662792, 47.70598791539669, 48.623220697045326, 41.9315479695797, 40.39255455136299, 37.017123475670815, 37.70752362906933, 37.23090760409832, 37.525213211774826, 38.42616006731987, 43.3630945533514, 37.73848056793213, 37.15224802494049, 39.168541431427, 47.76294305920601, 51.63788013160229, 52.6038870960474, 50.91563008725643, 51.18961438536644, 51.31905443966389, 51.52196355164051, 52.84511335194111, 49.72911335527897, 50.119280219078064, 47.224211767315865, 39.637485668063164, 37.79593348503113, 39.221658781170845, 38.36573950946331, 36.88623949885368, 39.72895435988903, 40.25480434298515, 43.14661256968975, 45.31411126255989, 47.051929011940956, 50.594338327646255, 57.21165284514427, 52.4012515693903, 48.80514733493328, 52.73400351405144, 44.5114803314209, 27.365141697227955, 13.693746998906136, 3.864154675975442, 2.3342551197856665, 5.075509725138545, 5.647885361686349, 8.26014781370759, 7.053792821243405, 6.060710409656167, 1.8264109455049038, 0.28559098311234266, 0.41924765333533287, 2.6155445259064436, 17.632349655032158, 34.83866237103939, 36.66444920003414, 36.19357846677303, 46.97205729782581, 41.74861818552017, 15.024772826582193, 0.8684125856962055, 0.07960644084960222, 0.06491624357295223, 0.024494849385519046, 0.025803337375691626, 0.034418894501868635, 0.024839948055159766, 0.08266106873634271, 0.03230794820410665, 0.031863702315604314, 0.03136640771117527, 0.03975468025601003, 0.028517167338577565, 0.0462815239734482, 0.018796711883624084, 0.046957872837083414, 0.03193580938386731, 0.053574883786495775, 0.05361118594009895, 0.023962547675182577, 0.032621962018311024, 0.08873637125361711, 0.015955212111293804, 0.042866950752795674, 0.1542415758012794, 0.27070507407188416, 0.13617137825349346, 0.17470049438998103, 0.11751948535675183, 0.24175886559532955, 0.1913133662310429, 0.09320128752733581, 0.11161547794472426, 0.17187113058753312, 0.13317071192432195, 0.10082524444442242, 0.1467016522656195, 0.1000016089528799, 0.1381630651303567, 0.09211982993292622, 0.13904556777561083, 0.13182148744817823, 0.09007730594021268, 0.13192127662478015, 0.09572223701979965, 0.09759375534486026, 0.1127693172020372, 0.13098131690640002, 0.1009351787797641, 0.16260666365269572, 0.17282560671446845, 0.1905930822249502, 4.343871809542179, 30.818267203867435, 60.746922343969345, 60.668201968073845, 62.54442349076271, 59.855600371956825, 40.58294713497162, 35.60814008116722, 17.472332641482353, 2.187259769998491, 0.5020386795513332, 2.5608106004074216, 6.608411595225334, 13.848926872015, 9.682028666138649, 4.45920892059803, 6.975941648706794, 11.831155344843864, 24.950610660016537, 42.506419122219086, 55.644119158387184, 57.01304890215397, 56.21227987110615, 54.08609636127949, 53.90643060207367, 49.50203754007816, 48.04686762392521, 46.8551641702652, 45.54335296154022, 44.7281751036644, 46.209236830472946, 45.34971535205841, 53.68479609489441, 54.77342627942562, 53.53020898997784, 49.83879826962948, 51.77737444639206, 52.80155248939991, 53.083903938531876, 47.28182427585125, 47.026314586400986, 45.38072928786278, 44.03799153864384, 40.609690099954605, 40.29499478638172, 40.53075693547726, 37.703328654170036, 37.394637018442154, 37.019961923360825, 47.08484664559364, 54.89763021469116, 52.06309251487255, 50.48537157475948, 50.94371058046818, 50.55547021329403, 52.369238287210464, 51.14577233791351, 50.17680533230305, 50.20759887993336, 48.88960920274258, 44.80092599987984, 44.090899899601936, 51.948737651109695, 54.639168083667755, 50.42100302875042, 49.79729689657688, 43.10402825474739, 41.81845843791962, 38.38175565004349, 38.898725509643555, 38.45446474850178, 38.87973412871361, 41.982355043292046, 46.527572348713875, 40.30932381749153, 39.00727428495884, 39.762795343995094, 48.86522211134434, 55.10966643691063, 53.501892909407616, 52.65211410820484, 52.09000267088413, 51.184644252061844, 51.45351782441139, 53.55865426361561, 52.84783400595188, 52.20266282558441, 49.296354576945305, 41.13149330019951, 39.42256540060043, 40.02653159201145, 40.3834730386734, 37.84557402133942, 41.57768055796623, 41.2293266505003, 44.90921638906002, 45.69104343652725, 50.5237191170454, 51.49590075016022, 60.490610897541046, 56.27864331007004, 50.51952414214611, 53.04389588534832, 48.82638059556484, 28.33497505635023, 14.278656262904406, 3.310150341130793, 4.5742064248770475, 7.658768333494663, 8.269127681851387, 17.559192180633545, 13.019624222069979, 11.472260802984238, 4.108911417424679, 1.054094193968922, 0.7771962834522128, 3.2123986864462495, 19.716951996088028, 42.613675966858864, 42.871446534991264, 41.9541871547699, 54.7261568158865, 45.99977307021618, 17.639225386083126, 1.4660799619741738, 0.19325958914123476, 0.1443711156025529, 0.14940070977900177, 0.1406572898849845, 0.12700641847914085, 0.15893283969489858, 0.21514077438041568, 0.12103635992389172, 0.2717635250883177, 0.11382482189219445, 0.19244141585659236, 0.11309575085761026, 0.33060642541386187, 0.1264155947137624, 0.1833933443413116, 0.2906704496126622, 0.10095654521137476, 0.2598071697866544, 0.14768097549676895, 0.16199911187868565, 0.17272506054723635, 0.07691830032854341, 0.13215848186518997], [0.01932747363753151, 0.05431916884845123, 0.03816507043666206, 0.012192826743557816, 0.02473534976161318, 0.0709586837911047, 0.03202103020157665, 0.03440322776441462, 0.03148536285152659, 0.0368696813529823, 0.05298419731843751, 0.008833902538754046, 0.03550261193595361, 0.03078653804550413, 0.07961394396261312, 0.014190452657203423, 0.0698149303207174, 0.03607789512898307, 0.07481074193492532, 0.01495331645855913, 0.014633851569669787, 0.019189469421689864, 0.06370168179273605, 0.01373535007587634, 0.02209518166637281, 0.07766398062813096, 0.04026242429972626, 0.027526938247319777, 1.4028348494321108, 13.209006059914827, 36.87533788383007, 43.638119995594025, 47.27505683898926, 39.06182415783405, 24.38897419720888, 32.135905399918556, 14.101553466171026, 2.9644897766411304, 0.046077822989900596, 0.5431367992423475, 2.389699132181704, 5.800805306062102, 2.626182292588055, 1.6009392379783094, 0.6706645467784256, 3.9075504848733544, 17.060562036931515, 30.564442723989487, 44.867768213152885, 54.377958700060844, 53.35913456976414, 50.61851643025875, 47.144685834646225, 46.14157386124134, 42.67433971166611, 43.525862619280815, 40.83601355552673, 39.758379980921745, 39.75539334118366, 41.79203845560551, 45.717668607831, 50.49745112657547, 51.22991502285004, 50.21317698061466, 49.92920681834221, 50.421709790825844, 49.83012713491917, 47.710802257061005, 46.597013622522354, 47.88447953760624, 46.44701287150383, 41.594627648591995, 38.410736694931984, 36.14400252699852, 36.408593729138374, 37.51330845057964, 34.562458992004395, 41.02862901985645, 47.76913292706013, 50.79214431345463, 50.799044743180275, 48.169506043195724, 48.95897068083286, 49.62378680706024, 48.94865043461323, 52.55514331161976, 49.694535210728645, 50.29546916484833, 50.181220695376396, 34.50105428695679, 51.32097713649273, 48.63510265946388, 47.676030322909355, 45.51883667707443, 40.36417007446289, 37.16612488031387, 38.40820223093033, 35.25474764406681, 35.69251075387001, 35.157320871949196, 41.43526799976826, 39.26783390343189, 35.907727405428886, 36.523913741111755, 36.53201870620251, 39.34734083712101, 44.798497930169106, 46.49358697235584, 49.34889055788517, 48.12312573194504, 51.14763803780079, 49.802924394607544, 47.67595432698727, 49.6048866212368, 48.27731005847454, 47.773419097065926, 40.108743980526924, 35.526980236172676, 36.812246069312096, 37.69607104361057, 37.805767357349396, 37.77197577059269, 38.504644855856895, 39.94884856045246, 38.615298718214035, 43.01942199468613, 46.51596017181873, 49.84340362250805, 52.97808341681957, 52.50017546117306, 40.248553678393364, 38.61139252781868, 17.23125647753477, 7.855209242552519, 2.4858558224514127, 1.988971447572112, 5.053841862827539, 4.552963189780712, 5.449450509622693, 4.616697169840336, 2.3208964616060257, 1.238877447322011, 0.3597743430873379, 0.2243857822031714, 4.19873527251184, 15.715908240526915, 33.44721123576164, 37.61391945183277, 37.53463290631771, 38.58752220869064, 22.50665970146656, 5.105155259370804, 0.038625732631771825, 0.03544244231306948, 0.017126133752753958, 0.020544447397696786, 0.05216777921305038, 0.06670885675703175, 0.014493530925392406, 0.05952392843028065, 0.07301297824596986, 0.04910312491119839, 0.015803663700353354, 0.04629973256669473, 0.05944424403423909, 0.04588663090544287, 0.06814540975028649, 0.025973773445002735, 0.10664078043191694, 0.019074173069384415, 0.04327490561990999, 0.037754102449980564, 0.041364981152582914, 0.02455540121445665, 0.03893298919138033, 0.04849481243581977, 0.034464072741684504, 0.012310195543250302, 0.049173280131071806, 0.10062562898383476, 0.03352728941536043, 0.019921713137591723, 0.0425386839924613, 0.08823289084830321, 0.009977916688512778, 0.021948386711301282, 0.02903599350247532, 0.033733320742612705, 0.03605322242947295, 0.045726857642875984, 0.049776649902923964, 0.03310775704449043, 0.025040810323844198, 0.0730709548224695, 0.041685028627398424, 0.01725620069919387, 0.042983994862879626, 0.03858476979075931, 0.016262053068203386, 0.0498285408684751, 0.017037248580891173, 0.0615319240023382, 0.016025166951294523, 0.08493208515574224, 1.749790906906128, 17.079342529177666, 46.10497422516346, 50.37515468895435, 54.67458978295326, 45.14066196978092, 25.09853482246399, 36.27732217311859, 17.805481664836407, 2.8995203878730536, 0.1625946705462411, 0.6384125305339694, 1.979547597002238, 3.3656938606873155, 3.760456102900207, 3.5019305627793074, 1.6937897494062781, 6.048926766961813, 19.844974726438522, 34.10254307091236, 45.52610568702221, 56.852423921227455, 55.51157467067242, 53.48184138536453, 48.78314271569252, 48.92560847103596, 45.5773763358593, 44.91947963833809, 41.849335581064224, 42.012282237410545, 42.517050951719284, 43.55450928211212, 47.54562892019749, 52.552259266376495, 53.35206314921379, 50.860795229673386, 50.54092459380627, 52.160150706768036, 50.674403831362724, 48.88047069311142, 48.552096113562584, 48.434728011488914, 46.755750104784966, 44.07495975494385, 40.77262155711651, 37.44745798408985, 38.17564330995083, 39.457458928227425, 36.368479281663895, 43.02648201584816, 49.74177047610283, 50.32662749290466, 51.412111446261406, 47.772089168429375, 49.01317857205868, 50.77466905117035, 50.98580092191696, 54.34438370168209, 50.94652242958546, 50.49169063568115, 51.15825466811657, 37.173998057842255, 51.917009353637695, 50.983198061585426, 48.330153822898865, 46.33772313594818, 41.37838505208492, 39.34966251254082, 39.47865419089794, 37.66547128558159, 37.50170387327671, 36.97667084634304, 41.44689537584782, 42.10779011249542, 36.24651342630386, 38.70952606201172, 38.11724804341793, 42.94647350907326, 47.45018944144249, 49.81542952358723, 51.07798397541046, 51.08102761209011, 53.414091020822525, 50.32684788107872, 50.80385148525238, 52.225245013833046, 50.749256014823914, 49.66057263314724, 41.36686027050018, 38.51715378463268, 39.202553406357765, 39.828155636787415, 39.45716254413128, 39.966464415192604, 40.05132146179676, 42.192213982343674, 41.68730467557907, 46.269323006272316, 49.59291346371174, 51.686122342944145, 55.65489538013935, 52.003181129693985, 45.397577583789825, 40.454289838671684, 19.104783944785595, 9.6873683296144, 3.252097531221807, 4.314258098602295, 5.8931047283113, 9.044656567275524, 6.878755213692784, 7.576549770310521, 3.0558458995074034, 1.4075386407785118, 0.21195149864070117, 0.3807282296475023, 4.201917601749301, 17.26813729852438, 35.51436111330986, 41.30631431937218, 41.2678299844265, 45.43549954891205, 28.67322340607643, 7.625726731494069, 0.21108271088451147, 0.09796413898584433, 0.01420909076841781, 0.033196061485796236, 0.01289262190766749, 0.04518503417784814, 0.03527423083141912, 0.04388619039673358, 0.028693833737634122, 0.04494052620430011, 0.050596006913110614, 0.028554070631798822, 0.019457073030935135, 0.06765525831724517, 0.06991238915361464, 0.01562178000312997, 0.045167359930928797, 0.02093733666697517, 0.02741181815508753, 0.05941874755080789, 0.0435544503852725, 0.0285697670551599, 0.01815360752516426, 0.05248934066912625, 0.1517022878397256, 0.22228271380299702, 0.1652713745716028, 0.1416304087615572, 0.0667454297945369, 0.17311439121840522, 0.14238671661587432, 0.18422079447191209, 0.17081892845453694, 0.11643560836091638, 0.1518159848637879, 0.1580791620654054, 0.09714821440866217, 0.06504960751044564, 0.28820518346037716, 0.22509612143039703, 0.130530848109629, 0.22577831841772422, 0.19630738184787333, 0.07646164944162592, 0.1025688907247968, 0.09592955597327091, 0.10203749814536422, 0.1454369435668923, 0.08981604027212597, 0.18751184834400192, 0.20762084430316463, 0.13410467508947477, 2.6100231846794486, 21.973597705364227, 56.396695375442505, 55.09846083819866, 59.57604557275772, 49.91847239434719, 33.473813608288765, 43.68913605809212, 19.713868461549282, 4.481684239581227, 0.5403326090890914, 1.5915134875103831, 5.203062705695629, 14.457536414265633, 5.57304885238409, 3.1887967279180884, 1.6462518065236509, 5.881628869101405, 20.792448185384274, 34.3199560046196, 46.17980360984802, 56.52873829007149, 57.41705842316151, 55.6164376437664, 51.644009202718735, 50.47839514911175, 47.705588936805725, 48.306367099285126, 44.34292517602444, 43.46887707710266, 44.897695407271385, 46.65484271943569, 50.33795088529587, 55.41975639760494, 54.785065054893494, 50.655803829431534, 52.22122862935066, 53.9228381216526, 51.9060355424881, 50.99103324115276, 51.193296387791634, 50.35567693412304, 49.810976162552834, 45.514603704214096, 43.133187890052795, 39.99580644071102, 38.90849478542805, 41.09642878174782, 37.12635241448879, 44.09308858215809, 51.36601611971855, 52.92530804872513, 52.37281769514084, 48.62528778612614, 50.17997816205025, 51.89440056681633, 52.65621408820152, 55.532899126410484, 53.92871640622616, 52.970274835824966, 51.59131363034248, 41.67894132435322, 53.769934326410294, 52.80130550265312, 52.38961659371853, 49.50307868421078, 43.639191538095474, 40.62379494309425, 41.4928463101387, 38.68454620242119, 39.795484989881516, 39.12792161107063, 44.40556101500988, 41.97219058871269, 38.62621933221817, 40.53386516869068, 40.8282695710659, 44.75657857954502, 49.32119384407997, 51.36043041944504, 53.785053715109825, 53.03023561835289, 55.21922215819359, 50.894769206643105, 49.62565630674362, 53.47636587917805, 52.76220940053463, 51.54102332890034, 42.90848694741726, 39.54353950917721, 40.305520221590996, 41.24572277069092, 42.11667403578758, 42.12980233132839, 43.03665027022362, 44.24125023186207, 44.74180497229099, 48.565653786063194, 51.32761538028717, 55.3183588385582, 57.332402765750885, 55.933249443769455, 46.51088744401932, 42.4873973429203, 22.26339865475893, 9.125553276389837, 3.967765378765762, 5.7280724588781595, 10.652135610580444, 12.957701794803143, 11.49220023304224, 14.601885918527842, 9.848561380058527, 2.511113304644823, 0.8331139641813934, 0.7318097969982773, 5.611692303791642, 22.126250714063644, 42.14787036180496, 48.75253915786743, 50.803862884640694, 52.058783546090126, 32.55164109170437, 8.800165336579084, 0.5613121739588678, 0.2109541412210092, 0.051185943812015466, 0.08891064237104729, 0.22272957576205954, 0.1859249733388424, 0.09727420881972648, 0.25404130574315786, 0.17438730807043612, 0.13634469942189753, 0.11264281813055277, 0.12632791738724336, 0.12615979125257581, 0.20245536288712174, 0.2164416850428097, 0.11559335238416679, 0.2039197093108669, 0.09518365302938037, 0.08799198971246369, 0.15819247317267582, 0.15805104951141402, 0.20612841501133516, 0.13527406234061345, 0.1704237941885367], [0.06117249446106143, 0.048873923733481206, 0.03307429731648881, 0.047887386826914735, 0.011096521557192318, 0.04561645204375964, 0.031301655326387845, 0.036645730870077386, 0.03703529902850278, 0.05039269555709325, 0.02834900780726457, 0.024257391814899165, 0.041095566703006625, 0.1001007598824799, 0.04956235476129223, 0.01726074635371333, 0.05224666208960116, 0.04250281970598735, 0.04225148768455256, 0.04389409798022825, 0.029662343877134845, 0.01578167200932512, 0.05879461248696316, 0.05120184061524924, 0.0606815711944364, 0.030389164348889608, 0.04007668700069189, 0.03479846964182798, 0.32047091459389776, 8.175200521945953, 30.307912789285183, 47.125812247395515, 35.713652819395065, 35.597827434539795, 26.232726462185383, 26.219636164605618, 18.04621584713459, 4.922550357878208, 0.5959103268105537, 0.622920939931646, 1.7114702006801963, 2.2707044798880816, 4.244518540799618, 2.995757586322725, 1.1491094017401338, 3.272920176386833, 10.995892714709044, 25.108262300491333, 39.971043169498444, 51.073390021920204, 55.38421310484409, 51.245418190956116, 49.544735848903656, 45.95744714140892, 44.97426889836788, 43.03503155708313, 41.601178497076035, 43.936229199171066, 45.87291307747364, 45.7815507799387, 48.01326982676983, 48.6496938765049, 51.56848445534706, 51.0061564296484, 50.70098340511322, 51.23972989618778, 50.77913001179695, 49.83333796262741, 51.059900745749474, 50.243020579218864, 49.597480818629265, 50.17492063343525, 46.711140498518944, 39.62564170360565, 35.172618851065636, 37.08306133747101, 35.256628543138504, 37.0149689912796, 45.34612834453583, 51.182801350951195, 50.533264204859734, 52.566854283213615, 49.90228906273842, 49.02319483458996, 49.50891897082329, 47.17772126197815, 49.64315056800842, 50.54158195853233, 52.65200771391392, 35.45645982027054, 45.89087091386318, 50.29719427227974, 45.262475833296776, 44.32568550109863, 38.18597115576267, 39.08279523253441, 37.62870065867901, 38.48287582397461, 39.32953879237175, 40.35186633467674, 36.92891500890255, 36.37935809791088, 35.26119589805603, 37.70411141216755, 35.178664326667786, 35.07068172097206, 36.76810383796692, 40.832293555140495, 46.22757464647293, 48.94310653209686, 48.42927150428295, 50.88702142238617, 49.072010815143585, 49.59850676357746, 48.98913346230984, 48.08062881231308, 41.6151237487793, 36.89375929534435, 35.916147753596306, 37.80957095324993, 41.26604028046131, 42.48011313378811, 41.54285542666912, 41.48293264210224, 40.29184855520725, 42.99599625170231, 44.779624342918396, 50.57298727333546, 50.17583638429642, 52.069837152957916, 41.35259583592415, 26.9037913531065, 15.212116073817015, 2.901506731286645, 2.752669667825103, 1.787522763479501, 2.9825283586978912, 6.954966774210334, 6.68296311981976, 4.151409761980176, 3.811663342639804, 1.6063338797539473, 0.14020523289218545, 0.6326340499799699, 5.785992750898004, 21.456219367682934, 27.34783362597227, 31.579940132796764, 40.30099846422672, 32.4648005515337, 16.29150230437517, 1.401087655685842, 0.09462409594561905, 0.029466799096553586, 0.03374978528881911, 0.03612102875194978, 0.05933439875661861, 0.015467783432541182, 0.02340431346965488, 0.026074746347148903, 0.024994264676934108, 0.035246170227765106, 0.0649074862303678, 0.06751459164661355, 0.03889532519679051, 0.03460719221038744, 0.02007370683713816, 0.01175149100163253, 0.005097382872918388, 0.03337427340738941, 0.05183108907658607, 0.030997981484688353, 0.046739306635572575, 0.03910056242602877, 0.020587759136105888, 0.04478673836274538, 0.05480807347339578, 0.08378386395634152, 0.05970312740828376, 0.013864208249287913, 0.04288800548238214, 0.03312498600280378, 0.022338875132845715, 0.025948022775992285, 0.04299455562431831, 0.015978465453372337, 0.024607973100501113, 0.0360521054972196, 0.04406050233228598, 0.048840345261851326, 0.0477554441022221, 0.026031829802377615, 0.09513701646937989, 0.03004055717610754, 0.062244181681307964, 0.02613725187984528, 0.09123881158302538, 0.0597904299502261, 0.02394086026470177, 0.02973921553348191, 0.12975000485312194, 0.05582853023952339, 0.03799251739110332, 0.051605231274152175, 0.4057453153654933, 11.948068421334028, 35.99304422736168, 53.58234219253063, 43.33243019878864, 39.27320681512356, 29.634839706122875, 33.330264911055565, 19.519753977656364, 5.362908728420734, 0.3210007189773023, 0.2550465299282223, 1.8459264608100057, 3.942846553400159, 5.718308882787824, 3.416118579916656, 1.9261369504965842, 3.7995355809107423, 13.71090117841959, 27.0577609911561, 43.99930581450462, 53.22253569960594, 56.81219927966595, 52.242678478360176, 50.70860579609871, 48.43135379254818, 46.88353344798088, 43.838342651724815, 43.29731248319149, 45.25337912142277, 46.85178615152836, 47.651977613568306, 49.13314573466778, 51.68459862470627, 52.28133000433445, 50.40394574403763, 49.7463758289814, 51.98459252715111, 52.649963423609734, 50.78694239258766, 51.594573855400085, 53.07096563279629, 52.61928766965866, 51.66731335222721, 48.47709193825722, 40.142334178090096, 36.48334711790085, 37.64220133423805, 36.67436666786671, 39.38801005482674, 46.94761320948601, 52.41652674973011, 51.95869691669941, 52.72193916141987, 51.72568961977959, 50.77996216714382, 50.96167981624603, 49.6699733287096, 51.39878936111927, 52.27133274078369, 53.86029727756977, 37.57003180682659, 49.26194742321968, 51.960323229432106, 47.5094548612833, 46.26727111637592, 41.41536466777325, 39.715700671076775, 39.11439433693886, 38.79516586661339, 39.786977246403694, 42.31824941933155, 39.09372344613075, 38.034328892827034, 37.28473551571369, 39.38468523323536, 37.278169468045235, 37.28910908102989, 38.475188836455345, 43.297677263617516, 48.81388306617737, 51.04943610727787, 50.50721660256386, 51.924700140953064, 50.190385803580284, 53.1935128569603, 51.16837352514267, 50.87330795824528, 43.30971501767635, 38.19034852087498, 38.919821977615356, 39.40405659377575, 43.1358477473259, 44.18975919485092, 42.40175373852253, 43.00386182963848, 40.65714955329895, 45.01886710524559, 47.943087592720985, 52.28571496903896, 51.76363818347454, 53.17083567380905, 43.53042997419834, 31.476274095475674, 16.318429559469223, 5.19013199955225, 4.378476552665234, 5.738068772479892, 7.548082647845149, 11.331271268427372, 7.50206901691854, 3.2606097869575024, 4.263305207714438, 1.3000734010711312, 0.30954270099755377, 0.8541861490812153, 7.218831740319729, 25.323828533291817, 32.87484034895897, 35.74528232216835, 46.08085311949253, 38.0344694852829, 20.966347754001617, 2.6471550296992064, 0.10619439344736747, 0.04966393993527163, 0.04267494230589364, 0.08684048079885542, 0.04372026844066568, 0.054959018889348954, 0.006356144185701851, 0.034489250101614743, 0.03592375847802032, 0.034418445502524264, 0.05403598384873476, 0.038158220413606614, 0.04915163910482079, 0.08620523949502967, 0.03387154945812654, 0.03764135166420601, 0.03888104998623021, 0.03325046091049444, 0.01710738524707267, 0.006909763160365401, 0.019620881721493788, 0.02732455457589822, 0.004178085473540705, 0.06668878166237846, 0.2721146203111857, 0.08899092048523016, 0.18280724063515663, 0.2200325665762648, 0.16012619831599295, 0.1008099339378532, 0.10943023153231479, 0.14137402642518282, 0.09406147379195318, 0.1282839960185811, 0.11201892426470295, 0.10864735479117371, 0.11998011308605783, 0.1850462704896927, 0.12338142783846706, 0.08860314090270549, 0.23905554815428331, 0.09121965675149113, 0.2132958546280861, 0.13056087540462613, 0.19973705406300724, 0.1279573916690424, 0.16906383825698867, 0.15286122565157712, 0.22496401914395392, 0.16567795275477692, 0.20150578493485227, 0.18168652342865244, 0.6897760962601751, 12.905024271458387, 41.71390324831009, 61.14291049540043, 48.3951835334301, 46.9166524708271, 34.180674478411674, 40.173830687999725, 24.860798679292202, 6.405895287171006, 1.1203553946688771, 1.0058180219493806, 4.504150059074163, 6.672184998169541, 9.53484071418643, 7.979844454675913, 2.4197189463302493, 4.158453159034252, 14.194619972258806, 28.825359642505646, 45.75610354542732, 55.78497000038624, 58.67342680692673, 54.41742718219757, 53.878935277462006, 50.85167571902275, 49.450459107756615, 48.069529607892036, 45.17419517040253, 48.618014976382256, 50.45998513698578, 49.366495013237, 51.006787195801735, 54.2727917432785, 53.079762160778046, 52.108279690146446, 52.044564709067345, 52.92012892663479, 53.930069133639336, 52.44266174733639, 55.300427600741386, 54.379425421357155, 56.120951771736145, 54.59825187921524, 49.87056076526642, 42.7397608011961, 38.81182797253132, 40.274768471717834, 38.36284026503563, 41.144317612051964, 48.36898773908615, 54.93141420185566, 53.547555059194565, 55.871669948101044, 53.40465612709522, 53.41184914112091, 52.836157232522964, 51.41664460301399, 53.51244114339352, 55.98001353442669, 54.81159523129463, 40.12854091823101, 50.09295903146267, 53.25832597911358, 51.36490657925606, 48.08702766895294, 42.236865386366844, 41.53890743851662, 40.35175234079361, 41.69175423681736, 42.689626291394234, 43.536657840013504, 40.41616268455982, 40.047954842448235, 39.24583688378334, 40.99465884268284, 38.07067774236202, 37.53912426531315, 39.113003611564636, 44.40550021827221, 50.01652233302593, 53.24015915393829, 52.138822451233864, 52.256578132510185, 50.6881894916296, 52.18743324279785, 53.878840282559395, 52.606470957398415, 46.35381527245045, 39.72366504371166, 40.725249499082565, 40.6993804872036, 45.16321375966072, 46.37515872716904, 46.50353863835335, 44.60402436554432, 43.68177205324173, 46.77717335522175, 52.40866497159004, 54.78259138762951, 54.252033457159996, 54.79463294148445, 46.275968849658966, 32.819697707891464, 18.504133075475693, 5.310307200998068, 4.770094463601708, 4.611440151929855, 12.205898836255074, 15.939130112528801, 16.582452692091465, 11.001327373087406, 6.073697162792087, 4.079790730029345, 0.5021123006008565, 1.3731804094277322, 8.343762326985598, 29.98771347105503, 37.40173503756523, 43.71062010526657, 52.99267843365669, 45.55450156331062, 23.52809999138117, 3.2786968164145947, 0.1909630576847121, 0.16516869101906195, 0.14894673804519698, 0.2026613088673912, 0.20971640216885135, 0.10601386602502316, 0.1738714857492596, 0.1358760183211416, 0.1083319123426918, 0.13126593054039404, 0.08946561298216693, 0.1193884878011886, 0.13805385067826137, 0.15463887713849545, 0.13671630760654807, 0.12817773531423882, 0.1239132063346915, 0.2192080850363709, 0.09998571214964613, 0.10911882636719383, 0.24960620154161006, 0.17059521545888856, 0.13865194749087095, 0.19534818566171452], [0.0647113959712442, 0.009491332202742342, 0.04445106125785969, 0.03288981053628959, 0.0612915943202097, 0.05105459480546415, 0.04013548736111261, 0.017829687894845847, 0.017523294081911445, 0.030649799191451166, 0.023641455627512187, 0.050966446215170436, 0.0010633399142534472, 0.01890087045467226, 0.045565243854071014, 0.06330518939648755, 0.01747299131238833, 0.011612556318141287, 0.07652899192180485, 0.025724432234710548, 0.03745968504517805, 0.030186385483830236, 0.02452429966069758, 0.09188471012748778, 0.0548450509813847, 0.064951970562106, 0.015425868787133368, 0.05799929735076148, 0.13090809661662206, 3.909702356904745, 19.08198706805706, 39.9665480107069, 43.76909896731377, 28.69204569607973, 21.42807997763157, 20.81106338649988, 18.276306800544262, 7.110011279582977, 0.6508701620623469, 0.18927781842648983, 1.11261117272079, 0.8864584704861045, 3.6617200635373592, 3.3713147090747952, 0.9962293552234769, 1.110070296563208, 5.9093407820910215, 18.264430537819862, 32.55030356347561, 47.67504997551441, 53.824062421917915, 54.120180532336235, 50.68070389330387, 46.636527702212334, 44.724314510822296, 45.542969182133675, 47.64703027904034, 48.456261456012726, 49.000141471624374, 49.11177188158035, 47.985379323363304, 50.325084775686264, 51.31275437772274, 48.296856209635735, 49.54583398997784, 51.825168281793594, 52.89652459323406, 53.915029540658, 53.69507074356079, 50.43512687087059, 50.81414133310318, 48.96056279540062, 50.670398846268654, 48.17403919994831, 40.91014377772808, 34.05794866383076, 36.10048346221447, 34.70267906785011, 38.289587795734406, 45.42295642197132, 50.66274605691433, 50.59056892991066, 50.47444336116314, 47.5736828148365, 44.20850358903408, 45.092738941311836, 47.100034430623055, 48.58201190829277, 52.53607213497162, 36.222795099020004, 47.41326302289963, 49.981237426400185, 46.81089274585247, 46.19389325380325, 41.33580833673477, 39.26411010324955, 38.56449544429779, 39.71408195793629, 40.57002402842045, 38.56471583247185, 36.554243713617325, 38.429063111543655, 36.125657111406326, 36.90973363816738, 35.71062058210373, 36.40270784497261, 36.44955933094025, 37.33688771724701, 38.372628539800644, 47.05868124961853, 48.79565164446831, 50.43420352041721, 49.894438683986664, 50.30396170914173, 49.117194190621376, 49.10659655928612, 42.305501103401184, 35.20193047821522, 36.195835545659065, 41.15550421178341, 46.83314435184002, 48.54403294622898, 47.09657281637192, 46.1337348818779, 45.24009123444557, 46.333558559417725, 47.42091201245785, 47.511472553014755, 53.02203945815563, 49.27260585129261, 39.15230110287666, 24.67543702572584, 9.530431050807238, 2.687473716214299, 2.0159951224923134, 7.820901358500123, 5.479523995891213, 9.51999681070447, 3.878523367457092, 3.845623070374131, 3.678911766037345, 0.5277683457825333, 0.24568789929617196, 1.2171294330619276, 8.64852212369442, 21.94655265659094, 30.95442909747362, 34.74988013505936, 34.83630649745464, 34.048137590289116, 7.780331885442138, 1.0867190058343112, 0.024550983580411412, 0.04901075721136294, 0.03524679734255187, 0.019320779465488158, 0.0073057611007243395, 0.06605359230889007, 0.011585246211325284, 0.029429704700305592, 0.05866127452463843, 0.02584278438007459, 0.0029452617582137464, 0.014908709672454279, 0.04223992131301202, 0.045222315966384485, 0.047094528199522756, 0.03788938112847973, 0.03763670953048859, 0.027188778658455703, 0.04813124171050731, 0.04722761383163743, 0.058417456748429686, 0.05661060175043531, 0.033815049755503424, 0.05567727312154602, 0.021426209750643466, 0.026889318360190373, 0.04147116022068076, 0.05520909297047183, 0.013456053002300905, 0.09228890601661988, 0.024270819121738896, 0.023796160021447577, 0.06820875947596505, 0.026224591529171448, 0.022244405299716163, 0.08246158686233684, 0.029738098601228558, 0.04817054585146252, 0.05850074056070298, 0.040021241147769615, 0.05297048614011146, 0.033908556652022526, 0.04345588946307544, 0.06309786302153952, 0.01575960424816003, 0.05635145120322704, 0.03520460995787289, 0.03934167878469452, 0.038747122016502544, 0.031175044932751916, 0.03373312407347839, 0.04036808757518884, 0.011526219495863188, 4.940874399617314, 24.417172484099865, 48.20322163403034, 45.69486603140831, 33.53905990719795, 26.56598947942257, 25.16652077436447, 22.444156855344772, 7.9250409454107285, 1.1597845726646483, 0.12977762758964673, 0.6311949959490448, 3.337210826575756, 8.541757352650166, 5.766122192144394, 2.95778242405504, 1.462033772841096, 7.024734830483794, 22.830161042511463, 33.799980506300926, 50.78210525214672, 56.59044697880745, 55.70611663162708, 51.403330117464066, 49.242184683680534, 45.93450017273426, 47.16966189444065, 48.861996084451675, 51.74562714993954, 51.19745336472988, 50.42239375412464, 49.699345752596855, 51.635699048638344, 52.80664421617985, 49.04105767607689, 49.858895391225815, 50.076722502708435, 52.14293383061886, 56.498560309410095, 55.07505029439926, 52.9859983921051, 53.72845195233822, 52.81866297125816, 53.73398445546627, 49.48387831449509, 41.628833413124084, 36.718896478414536, 38.26569087803364, 37.07184053957462, 39.68768857419491, 48.40994954109192, 52.78486378490925, 52.01231583952904, 52.84262828528881, 49.29033949971199, 48.484721928834915, 46.69018842279911, 49.30606305599213, 50.58688312768936, 54.09585423767567, 37.661359906196594, 49.53327566385269, 51.782336980104446, 48.83437916636467, 47.76334963738918, 45.18099680542946, 42.28680990636349, 39.97249849140644, 41.180719658732414, 42.331886887550354, 41.4673762768507, 38.83828595280647, 39.6924839168787, 38.50040428340435, 37.902331575751305, 37.6076839864254, 38.50929580628872, 37.592826783657074, 38.58706243336201, 41.99587091803551, 49.46106053888798, 51.92350320518017, 52.318826392292976, 50.16497656702995, 49.799804762005806, 50.44287085533142, 52.05733202397823, 43.802654966712, 37.53178685903549, 37.44851052761078, 42.36607365310192, 49.21932511031628, 49.607291892170906, 48.369557708501816, 46.17505766451359, 47.66701340675354, 48.65771524608135, 49.32893022894859, 49.22813303768635, 54.46424067020416, 50.40284760296345, 41.34693033993244, 26.580183617770672, 13.091979939490557, 3.7607771856710315, 4.579213606193662, 9.153388682752848, 5.32603170722723, 11.49093585088849, 7.501644864678383, 4.990814169868827, 3.4636195935308933, 0.550435435725376, 0.2550349524244666, 1.447776344139129, 9.991723448038101, 25.35120226442814, 34.15528044104576, 37.1415363997221, 41.77540674805641, 38.47263537347317, 11.360247563570738, 1.5223327372223139, 0.03732756420504302, 0.05137905434821732, 0.011799414260167396, 0.031217685027513653, 0.048110186980920844, 0.028555408352985978, 0.019811775091511663, 0.043720587564166635, 0.054178357459022664, 0.03861837052681949, 0.010295549400325399, 0.043417694832896814, 0.014559422506863484, 0.030661139207950328, 0.032389406333095394, 0.07222854299470782, 0.030189081335265655, 0.03261886726249941, 0.030932525914977305, 0.06705464562401175, 0.031679300882387906, 0.06786235462641343, 0.12358685431536287, 0.10387070680735633, 0.12591580278240144, 0.08975422679213807, 0.09394828142831102, 0.1487053174059838, 0.20395561441546306, 0.18220356287201867, 0.15837839600862935, 0.10748812754172832, 0.15168220532359555, 0.14636890293331817, 0.10659334235242568, 0.2018801390659064, 0.12368249488645233, 0.1382028145599179, 0.13704867102205753, 0.1609435403952375, 0.21566202922258526, 0.09645174592151307, 0.16998285456793383, 0.1392270377255045, 0.12510230502812192, 0.12987231079023331, 0.16577548580244184, 0.14138276892481372, 0.12708554626442492, 0.13525219867005944, 0.19186975434422493, 0.13994511013152078, 0.17815067956689745, 6.296055056154728, 26.948934830725193, 53.22996810078621, 54.914945885539055, 39.51811507344246, 32.208956480026245, 30.218013413250446, 27.545871399343014, 10.05803368985653, 1.3230229821056128, 0.6144940608646721, 3.3970160549506545, 4.677115827798843, 11.185024715960026, 9.715784154832363, 3.304432360455394, 1.5622421144507825, 7.748187510296702, 21.5091847255826, 35.28830364346504, 50.55452026426792, 58.38929705321789, 57.15626701712608, 54.40198101103306, 50.80297373235226, 50.00377021729946, 50.45187637209892, 51.140954196453094, 52.51076169312, 52.4807471036911, 53.34432676434517, 53.32550637423992, 53.7196060270071, 53.83564040064812, 48.46914656460285, 51.502219811081886, 51.0455185174942, 52.91648872196674, 57.89024703204632, 56.60645171999931, 53.48093323409557, 54.1863501816988, 52.729147374629974, 55.16154125332832, 51.74150437116623, 43.82353484630585, 38.333217054605484, 40.217459946870804, 38.25956180691719, 41.03421851992607, 48.6713907122612, 55.305013954639435, 53.914744555950165, 54.55407924950123, 51.51752158999443, 48.25809828937054, 49.1498838365078, 51.4672426879406, 51.94291636347771, 53.91873054206371, 42.17476911842823, 51.315794214606285, 53.44512015581131, 50.37710018455982, 50.42859122157097, 46.298915818333626, 43.90049211680889, 42.59014382958412, 44.06646341085434, 42.46104955673218, 42.07033172249794, 40.89045323431492, 41.719105169177055, 39.561630338430405, 39.020030200481415, 39.21332202851772, 39.52705979347229, 38.94804306328297, 40.7083024084568, 42.12333507835865, 51.66830889880657, 53.54375146329403, 54.04870256781578, 50.55948659777641, 50.49197942018509, 51.24978415668011, 54.81553941965103, 45.83331160247326, 39.770041555166245, 40.06077155470848, 46.30922846496105, 51.658733412623405, 52.490474581718445, 50.694462954998016, 49.95774328708649, 50.48794783651829, 52.189675122499466, 51.92655064165592, 50.89604593813419, 57.7557722479105, 52.77457773685455, 41.52179315686226, 27.379392832517624, 11.43123060464859, 4.7827240359038115, 4.2643900495022535, 15.314756166189909, 12.128990013152361, 18.66181891411543, 12.387009467929602, 8.301443047821522, 9.806050211191177, 1.1102053080685437, 0.8103560947347432, 2.255690535530448, 12.021394986659288, 32.486877366900444, 41.24405845999718, 46.500191017985344, 47.754553109407425, 44.763741195201874, 13.025185223668814, 1.7523406888358295, 0.1597192045301199, 0.1529977362952195, 0.1158783222490456, 0.11399989452911541, 0.07862233076593839, 0.11539764062035829, 0.1578818101552315, 0.10732931536040269, 0.14519182703224942, 0.10067339360830374, 0.0603569186932873, 0.08259493595687672, 0.1643166461144574, 0.14050001394934952, 0.12067048854078166, 0.22950643789954484, 0.12500126904342324, 0.10318122935132124, 0.12894707528175786, 0.19359909201739356, 0.10500907970708795, 0.13812530465656891, 0.1733934090589173, 0.20477870071772486], [0.01984973223443376, 0.07515538789448328, 0.020557819043460768, 0.008864704450388672, 0.03427875475608744, 0.0439259138511261, 0.03944139003579039, 0.02609833551105112, 0.014920179564796854, 0.05948748155788053, 0.05406399621278979, 0.0797510334814433, 0.033676735693006776, 0.06900224892888218, 0.026056183378386777, 0.02983512884384254, 0.02590705807961058, 0.0592660580878146, 0.051841174863511696, 0.020512535047600977, 0.047868198598735034, 0.06885520720970817, 0.03204424458090216, 0.009275282809539931, 0.04741919554362539, 0.04542546404991299, 0.01926568613271229, 0.013962507564428961, 0.03833328191831242, 0.5753820470999926, 11.299371030181646, 29.506288804113865, 43.887116834521294, 39.28814761340618, 21.184195764362812, 16.780024990439415, 16.871111802756786, 11.404727026820183, 2.7054503140971065, 0.15085514110978693, 0.6382985366508365, 4.219939559698105, 6.456231661140919, 2.7320947218686342, 2.896430678665638, 2.248933785595, 4.415518390014768, 10.405008271336555, 28.61136082559824, 41.17424100637436, 54.063293784856796, 52.83719837665558, 50.673324689269066, 47.63159170746803, 49.32046428322792, 48.88193741440773, 49.096785485744476, 50.6285060942173, 54.015545547008514, 50.79048000276089, 51.480944752693176, 50.54916255176067, 49.323572516441345, 46.40321262180805, 49.34544414281845, 49.808320105075836, 49.76879462599754, 47.85412676632404, 49.988525435328484, 49.255605563521385, 50.823732018470764, 50.35145916044712, 49.372107312083244, 49.573135524988174, 46.72033980488777, 38.70769836008549, 36.63417622447014, 35.92730775475502, 35.29901526868343, 36.29691772162914, 40.720199570059776, 41.663194969296455, 41.71839840710163, 39.827023297548294, 40.21886587142944, 40.241163074970245, 47.91534908115864, 47.40991160273552, 52.87849076092243, 35.4110636562109, 43.976016864180565, 50.43751694262028, 45.49088157713413, 48.12289774417877, 40.622415617108345, 40.485607758164406, 38.56042206287384, 37.463702112436295, 35.48021614551544, 34.664460718631744, 37.69638642668724, 37.50955045223236, 36.85948133468628, 36.962018832564354, 35.74898712337017, 36.05083152651787, 36.336253210902214, 36.536114886403084, 36.97957769036293, 44.54762779176235, 46.51191718876362, 48.422200083732605, 49.14754696190357, 51.1541660875082, 50.83933778107166, 47.70067200064659, 44.51495334506035, 35.85542321205139, 34.840706661343575, 42.51188322901726, 48.604559898376465, 49.90854732692242, 49.61203023791313, 49.39238302409649, 48.22557583451271, 46.328052654862404, 45.84270849823952, 51.93914316594601, 50.608503967523575, 47.78005354106426, 36.499842032790184, 21.889295428991318, 8.633730467408895, 1.5245809103362262, 6.579148415476084, 9.130398016422987, 4.038089867681265, 9.291003048419952, 5.809209030121565, 3.887878702953458, 3.5882457811385393, 0.7520159252453595, 0.7312650606036186, 3.636297765187919, 12.313506212085485, 34.51973408460617, 39.17635381221771, 37.04027183353901, 37.94148467481136, 24.593840204179287, 4.227919606491923, 0.19798243883997202, 0.018431541830068454, 0.037928095262032, 0.09475186408963054, 0.08121250779367983, 0.07085868681315333, 0.039309365674853325, 0.10259888833388686, 0.04704280792793725, 0.006490751220553648, 0.051889269743696786, 0.038268102798610926, 0.013321424630703405, 0.0461241886659991, 0.020453087163332384, 0.022769717834307812, 0.16308975726133212, 0.017165784847748, 0.04948350899212528, 0.05879353266209364, 0.043402399169281125, 0.05620863230433315, 0.008439659777650377, 0.02690181056095753, 0.09425893702427857, 0.01723789748211857, 0.08782414559391327, 0.07597668562084436, 0.07754770093015395, 0.054920004185987636, 0.03489270755380858, 0.08804379162029363, 0.0387065636459738, 0.052532711779349484, 0.03411225763557013, 0.04480818271986209, 0.007194684785645222, 0.031359861968667246, 0.02304428464412922, 0.043154384547960944, 0.04622479420504533, 0.04124012964894064, 0.08010057761566713, 0.03956708387704566, 0.03552463145751972, 0.006830921101936838, 0.009138933583017206, 0.04036726379126776, 0.1029208319960162, 0.08974177355412394, 0.0367449003533693, 0.014136688696453348, 0.018325861856283154, 0.03801474471401889, 1.2711223983205855, 14.351537302136421, 34.00714538991451, 50.23396946489811, 41.3707360625267, 23.400088660418987, 19.88756664097309, 23.019075505435467, 12.503466568887234, 2.4700384587049484, 0.2025050125666894, 0.4086411459138617, 2.3969467682763934, 8.099296744912863, 7.43848797865212, 7.678686864674091, 3.3729842444881797, 6.036873813718557, 14.620922897011042, 31.417970024049282, 43.781634494662285, 53.87597143650055, 56.35242775082588, 53.32387626171112, 49.135740995407104, 50.14327973127365, 51.327577382326126, 50.94858571887016, 52.305078729987144, 55.16888625919819, 53.355368971824646, 54.255179688334465, 52.04090930521488, 49.97401021420956, 47.98892453312874, 49.84067536890507, 49.55237723886967, 50.995372608304024, 49.138108268380165, 51.20390921831131, 49.418054446578026, 52.022715881466866, 51.96848899126053, 51.68823882937431, 51.909858137369156, 46.99921444058418, 40.316520631313324, 37.99621693789959, 36.923500299453735, 37.03436695039272, 38.77626948058605, 44.756316393613815, 45.544975474476814, 45.71324944496155, 43.30754533410072, 43.25676865875721, 43.61790508031845, 48.8502699136734, 50.39116322994232, 55.81621952354908, 38.1022160500288, 46.51192098855972, 51.07432097196579, 48.92702579498291, 49.098035618662834, 43.033192455768585, 43.171767219901085, 40.02599202096462, 37.975701838731766, 38.22759032249451, 37.59009853005409, 38.8620612770319, 39.98143181204796, 37.8986419737339, 38.61015759408474, 37.20998592674732, 38.38723115622997, 38.33218351006508, 38.67777116596699, 39.05743919312954, 46.46867170929909, 49.14397515356541, 51.66305758059025, 50.801343619823456, 52.04001635313034, 53.300477117300034, 50.86124740540981, 46.10442325472832, 36.800557896494865, 36.50446638464928, 44.945314452052116, 50.0113470107317, 52.22589857876301, 50.108116418123245, 50.53839012980461, 50.90163163840771, 48.53829525411129, 49.50260370969772, 53.34185689687729, 52.259880155324936, 49.441799372434616, 38.15285213291645, 24.365035481750965, 10.529674831777811, 3.9384869998320937, 10.44192424044013, 7.672825679183006, 6.906863255426288, 11.14690801128745, 6.065493877977133, 3.325686282478273, 2.598463729955256, 0.3864660701947287, 0.6992134836036712, 4.163880692794919, 14.328672979027033, 36.32069304585457, 44.76595647633076, 43.80742751061916, 41.9602782279253, 31.242753826081753, 5.873341513797641, 0.3408145479625091, 0.0778222361986991, 0.0763608212582767, 0.05744142865296453, 0.028782316294382326, 0.030156469510984607, 0.07928716891910881, 0.04078354926605243, 0.020886365964543074, 0.00806223222753033, 0.0017007441147143254, 0.04590517717588227, 0.016559919604333118, 0.046419088466791436, 0.015653230366297066, 0.007768797240714775, 0.07748262942186557, 0.020939201313012745, 0.06336370774079114, 0.05288355467200745, 0.04486123514652718, 0.02520510883186944, 0.03783052881772164, 0.04697457487054635, 0.06066599351470359, 0.11675084300804883, 0.1672655699076131, 0.11405821249354631, 0.1261752427672036, 0.16550817905226722, 0.08245914519648068, 0.1886756398016587, 0.15139889786951244, 0.09582322105416097, 0.08066278416663408, 0.1424272230360657, 0.11290430644294247, 0.15802977955900133, 0.14147112902719527, 0.16913794912397861, 0.20006413338705897, 0.08346890390384942, 0.10439772071549669, 0.25695462129078805, 0.1388496407889761, 0.1291775715071708, 0.1370085950475186, 0.09119005248066969, 0.202145857620053, 0.2492437366163358, 0.202683306124527, 0.1062033289053943, 0.12800716009223834, 0.11204699228983372, 1.281370329670608, 15.593273621052504, 40.34151189029217, 56.94820158183575, 50.69018438458443, 30.97333498299122, 26.000437326729298, 25.682603381574154, 15.583451148122549, 3.846082133240998, 0.6199550209566951, 1.3695835461840034, 8.550321143120527, 15.081917010247707, 10.867167972028255, 9.943348243832588, 6.436794754117727, 6.81708499789238, 14.203580841422081, 32.909008115530014, 44.781467244029045, 55.99333941936493, 59.157699421048164, 54.97717894613743, 51.817321702837944, 53.403200805187225, 54.28030014038086, 53.99047829210758, 56.65485352277756, 58.12194339931011, 54.04258109629154, 56.617626920342445, 51.828933879733086, 50.91765157878399, 48.87420102953911, 50.347765758633614, 50.34227505326271, 49.600695446133614, 48.427842780947685, 49.681570306420326, 49.80453550815582, 51.6383209079504, 53.267738074064255, 52.03094623982906, 53.54229994118214, 48.538565039634705, 44.05332371592522, 39.95991736650467, 38.35317738354206, 39.26107406616211, 40.30961260199547, 44.74242813885212, 45.9377072006464, 44.886641800403595, 43.62491950392723, 43.91920991241932, 44.7059690952301, 50.845178067684174, 52.95314535498619, 56.48444406688213, 42.37381383776665, 48.271568566560745, 53.419699519872665, 50.98941072821617, 51.51587627828121, 44.46467824280262, 44.24585938453674, 40.986234694719315, 38.94206218421459, 38.82050670683384, 38.5687892138958, 40.70813521742821, 40.98597630858421, 41.19299300014973, 40.93242958188057, 41.15591838955879, 39.37006741762161, 39.35385748744011, 38.94382528960705, 40.76007463037968, 49.13705952465534, 51.10736779868603, 53.120112195611, 50.98275348544121, 50.52856765687466, 55.028027817606926, 52.53085881471634, 49.16225217282772, 38.712858483195305, 38.321213498711586, 45.48487029969692, 52.99872010946274, 54.392390325665474, 52.13623858988285, 54.520865231752396, 53.31709362566471, 51.85050152242184, 51.00296840071678, 56.15717142820358, 54.03927147388458, 52.321680039167404, 41.38616323471069, 26.45941659808159, 14.775826334953308, 4.593285676091909, 10.20448638126254, 15.306920986622572, 12.043471802026033, 19.680738039314747, 13.28500958159566, 8.495679125189781, 5.558574479073286, 1.6178793227300048, 1.0425660875625908, 5.864131757989526, 16.83207269757986, 45.043523982167244, 54.35758039355278, 48.48464973270893, 48.75193879008293, 32.86607041954994, 6.933686016127467, 0.36964089958928525, 0.1498457757406868, 0.1553679778589867, 0.2127802697941661, 0.2716236450942233, 0.13089999236399308, 0.179518309305422, 0.2378020013566129, 0.1319183674058877, 0.18788278859574348, 0.16922733339015394, 0.18860004463931546, 0.19554568600142375, 0.11573027863050811, 0.14014568296261132, 0.155079668329563, 0.26019451150204986, 0.11726733326213434, 0.17883336637169123, 0.1153366435028147, 0.0684710567293223, 0.12130945542594418, 0.10891420883126557, 0.13348781678359956, 0.2450088193290867], [0.08138653400237672, 0.019712431203515735, 0.06306948329438455, 0.034632662718649954, 0.0545282986422535, 0.031106153219297994, 0.017977737079490907, 0.06203489232575521, 0.04479784089198802, 0.06039796688128263, 0.03054481312574353, 0.07615244103362784, 0.03612311418692116, 0.05179372565180529, 0.03953870414989069, 0.09362949189380743, 0.014917052340024384, 0.03724582405993715, 0.07162619367591105, 0.04961134021868929, 0.042601402892614715, 0.09108920945436694, 0.053451498024514876, 0.031418833023053594, 0.05606506012554746, 0.04535762433079071, 0.045137703709769994, 0.01791740232874872, 0.044113090916653164, 0.08076140817138366, 3.3482758328318596, 28.73500619083643, 45.70884168148041, 42.857239097356796, 23.656485602259636, 21.5824181959033, 20.489245355129242, 20.929362438619137, 4.3398744240403175, 0.20491454342845827, 0.20388905861182138, 1.83413403108716, 7.576996246352792, 6.587195908650756, 3.488981807604432, 1.6637144819833338, 2.3443058179691434, 9.880311526358128, 23.858171179890633, 39.193867072463036, 51.44663639366627, 55.30534453690052, 51.62226676940918, 48.95142048597336, 49.88221473991871, 49.6802593767643, 52.8979305177927, 53.44428040087223, 52.926163002848625, 51.40806466341019, 52.58709579706192, 51.87180317938328, 52.46404320001602, 51.69010452926159, 50.977255180478096, 52.17584006488323, 50.47515012323856, 52.190875858068466, 50.07538117468357, 51.15473225712776, 48.64907830953598, 48.37198197841644, 50.13717345893383, 51.4060165733099, 48.86168450117111, 45.94702050089836, 38.950083553791046, 34.36238452792168, 36.75084136426449, 36.578220427036285, 36.11095190048218, 34.35899131000042, 35.56895658373833, 36.11410953104496, 39.126781672239304, 42.65613488852978, 46.99590101838112, 46.74724996089935, 56.69823959469795, 33.90953242778778, 45.282284170389175, 54.7679203748703, 45.83942547440529, 46.00565895438194, 41.733175814151764, 41.18734270334244, 37.435644418001175, 36.847188994288445, 36.72972209751606, 38.34477983415127, 41.19472570717335, 36.56642206013203, 35.942267552018166, 37.255127504467964, 41.13014057278633, 43.83715711534023, 41.76105111837387, 41.82122088968754, 41.095003858208656, 43.88194911181927, 48.151491209864616, 49.84239287674427, 50.802878737449646, 48.29687900841236, 50.39149381220341, 48.5274962335825, 45.61443194746971, 36.994271501898766, 36.94663345813751, 40.42348489165306, 50.29492199420929, 49.596485272049904, 51.54446214437485, 50.53787335753441, 51.75441987812519, 50.40877528488636, 50.185681656003, 48.928564712405205, 50.427086502313614, 38.34294453263283, 26.97840604931116, 15.401495061814785, 5.831911861896515, 2.650590045377612, 9.17353330180049, 6.063694674521685, 3.75297786667943, 9.534133952111006, 5.007656291127205, 2.878588498570025, 1.3627625559456646, 0.34186489472631365, 1.6801887354813516, 6.087023047730327, 19.527575857937336, 22.547927387058735, 25.885706283152103, 33.88771019876003, 36.501198559999466, 16.077607981860638, 2.7585522271692753, 0.008116180797514971, 0.03763551467272919, 0.04078493708220776, 0.07522094922023825, 0.0371521279157605, 0.02357930818106979, 0.02744313307630364, 0.07391479899524711, 0.0267101101053413, 0.06157072348287329, 0.013684689220099244, 0.020041106145072263, 0.03287053325038869, 0.028611844973056577, 0.07356794143561274, 0.0228380863336497, 0.015954297414282337, 0.02056933346466394, 0.047259455677703954, 0.008121912032947876, 0.07519970153225586, 0.038123391423141584, 0.08289284887723625, 0.027857624409080017, 0.008664802335260902, 0.07377471119980328, 0.039379068184643984, 0.029519244817493018, 0.032071874738903716, 0.0563722647348186, 0.014619084686273709, 0.04953219016897492, 0.01669852495979285, 0.03876780938298907, 0.04677345285017509, 0.050375641003483906, 0.08629007439594716, 0.045970155915711075, 0.045363019744399935, 0.040609808784211054, 0.027682998916134238, 0.039975784602575004, 0.016622734983684495, 0.011287513261777349, 0.0686633842997253, 0.0009328137639386114, 0.017282420776609797, 0.04166045611782465, 0.06383744286722504, 0.0362498099275399, 0.02191548359405715, 0.07771782344207168, 0.06471548520494252, 0.03178643361025024, 0.03784688204177655, 5.481400145217776, 34.03634302318096, 49.66081202030182, 48.25083687901497, 24.74617213010788, 21.779450923204422, 22.646034322679043, 20.471640899777412, 5.497497981414199, 0.3034536464838311, 0.07185499038314447, 2.158874818123877, 7.304384624585509, 7.707863124087453, 9.494088850915432, 4.881485011428595, 3.7626488227397203, 11.685444563627243, 25.48584993928671, 40.02078250050545, 54.176520109176636, 56.91831238567829, 53.10506120324135, 51.89904011785984, 52.746083065867424, 52.61958785355091, 54.95798237621784, 55.17828315496445, 54.4778211414814, 52.49281905591488, 52.62809179723263, 50.97504369914532, 52.401137575507164, 53.598251938819885, 53.9128902554512, 52.68300265073776, 52.900780364871025, 51.99340805411339, 51.34486645460129, 50.63933551311493, 48.38471509516239, 50.33272236585617, 52.89125807583332, 53.20601798593998, 52.10783891379833, 46.81632645428181, 40.421018823981285, 36.37743920087814, 39.57768067717552, 38.433083295822144, 38.10416914522648, 36.914692372083664, 37.73706704378128, 38.30645889043808, 40.52079766988754, 45.4460059851408, 48.291384503245354, 50.269805341959, 58.31610158085823, 35.78032024204731, 47.3468653857708, 55.06528101861477, 48.220176324248314, 48.402821123600006, 43.32320809364319, 42.36663982272148, 39.95786927640438, 37.86797381937504, 38.729615584015846, 41.15865044295788, 41.41778513789177, 38.309095948934555, 37.208667397499084, 39.43212568759918, 41.39889635145664, 45.18662050366402, 43.02322179079056, 42.94104740023613, 43.65032874047756, 46.03980012238026, 50.89258052408695, 52.6877523958683, 51.15358091890812, 48.896125853061676, 52.22681812942028, 50.494950860738754, 48.01339901983738, 40.170418471097946, 38.27819220721722, 43.405956253409386, 52.36896090209484, 51.99110917747021, 53.40682581067085, 53.06889474391937, 51.59504123032093, 52.83276401460171, 52.308449149131775, 50.89739866554737, 51.709342896938324, 41.62939578294754, 31.59667443484068, 20.413188636302948, 7.3782317619770765, 2.4714807188138366, 5.928302239626646, 5.683277137577534, 3.781925425864756, 8.210725765675306, 6.599564719945192, 2.5257296953350306, 1.2713524047285318, 0.40889549476560205, 1.3299587974324822, 6.91362926736474, 20.178995802998543, 31.778213493525982, 32.74081014096737, 39.938243329524994, 42.26405292749405, 20.421390496194363, 3.8784416718408465, 0.038328190785250627, 0.06560117908520624, 0.039844123893999495, 0.024498634338669945, 0.05234964992268942, 0.009318037009506952, 0.03890829051670153, 0.10412712625111453, 0.029170999441703316, 0.03713168916874565, 0.05914295063121244, 0.047905335668474436, 0.05802933948871214, 0.04025563735922333, 0.06110941190854646, 0.056888895996962674, 0.03439882682869211, 0.023193769884528592, 0.1091425379854627, 0.03967679185734596, 0.05707579846784938, 0.05217170517425984, 0.0460497141466476, 0.018848146428354084, 0.017594568089407403, 0.11367534592864104, 0.13528031122405082, 0.18003674398642033, 0.1495658524800092, 0.13112762389937416, 0.11702200150466524, 0.12153797011706047, 0.11852656491100788, 0.12515964335761964, 0.20607797865523025, 0.14871083898469806, 0.14091405813815072, 0.16421586245996878, 0.11329395623761229, 0.05027053062804043, 0.17769593599950895, 0.14183062536176294, 0.14920049317879602, 0.20893224893370643, 0.2194825015612878, 0.1818121987162158, 0.15931048896163702, 0.08717138218344189, 0.13920548575697467, 0.08400535050895996, 0.17686202918412164, 0.2690298983361572, 0.14730797207448632, 0.05758765029895585, 0.19284296227851883, 5.988584104925394, 37.59378433227539, 56.387340277433395, 56.063164472579956, 34.27289552986622, 29.649544917047024, 30.01848042011261, 25.26895947754383, 6.802529403939843, 0.5583963054232299, 0.8406382135581225, 4.9707431718707085, 13.311405815184116, 14.440690018236637, 12.26933928206563, 3.5225525312125683, 3.6497454810887575, 12.423509359359741, 25.646322928369045, 41.58976770937443, 55.14643706381321, 60.79744063317776, 54.96512219309807, 53.58312875032425, 56.82712107896805, 54.79452654719353, 58.22815530002117, 56.096386089921, 55.812184140086174, 54.21959839761257, 54.748245030641556, 53.167271465063095, 54.80502538383007, 55.598791390657425, 54.517802596092224, 54.09557685256004, 53.05066332221031, 53.25892634689808, 52.90472075343132, 51.55962713062763, 48.0760994553566, 50.31322941184044, 52.38308094441891, 53.712397813797, 53.82852718234062, 48.54394555091858, 42.66007527709007, 37.14461423456669, 42.09278091788292, 41.080526635050774, 39.67318095266819, 37.04794742166996, 39.50727425515652, 39.53057460486889, 42.03494042158127, 47.26370304822922, 51.677230820059776, 52.68171451985836, 59.4832431524992, 40.694121569395065, 49.02866654098034, 57.858807519078255, 50.01665152609348, 49.97939832508564, 46.34259067475796, 43.13565015792847, 41.16126850247383, 39.867867305874825, 39.632264748215675, 42.05603688955307, 44.137736186385155, 40.595653653144836, 38.58746141195297, 42.01436072587967, 44.39895696938038, 46.93694718182087, 45.4272273927927, 45.8860831707716, 45.60907423496246, 48.01484674215317, 53.0184942483902, 54.37092147767544, 52.366871014237404, 49.23595681786537, 54.613321870565414, 52.51627899706364, 50.06959788501263, 41.664893478155136, 40.50291582942009, 44.55592654645443, 54.221745282411575, 53.28103356063366, 53.457952067255974, 53.73010866343975, 53.99805508553982, 56.115164682269096, 54.462792947888374, 53.44467177987099, 54.06482890248299, 43.44681166112423, 35.178611129522324, 22.050061002373695, 9.597697891294956, 6.622133133932948, 15.349045526236296, 16.95835132151842, 13.614343609660864, 22.331190817058086, 11.2146089784801, 8.70667515322566, 4.743595160543919, 0.8825092355255038, 2.20734644215554, 8.286180216819048, 27.114396952092648, 33.74791570007801, 38.862281665205956, 46.8216385692358, 49.89969380199909, 22.59233370423317, 4.592970293015242, 0.16669885109877214, 0.2011688202037476, 0.18820519238943234, 0.19304754270706326, 0.130809138645418, 0.11519920517457649, 0.11209448231966235, 0.16097083658678457, 0.09748304917593487, 0.18276820366736501, 0.11178203814779408, 0.17246762436116114, 0.11463158094557002, 0.2344668935984373, 0.16066234064055607, 0.15597265010001138, 0.12360695167444646, 0.12184734179754741, 0.14440452709095553, 0.15184657619101927, 0.14485373423667625, 0.2131515959626995, 0.11710287333698943, 0.07963078329339623, 0.1679812525981106], [0.018343424781051, 0.030357255709532183, 0.012984784589207266, 0.05171298369532451, 0.015383984755317215, 0.019065154119743966, 0.05043058961746283, 0.08926309572416358, 0.01735312704113312, 0.04696910153143108, 0.023348294307652395, 0.021754597109975293, 0.029480794146365952, 0.01568195704749087, 0.02778243742795894, 0.026631991640897468, 0.0862191547639668, 0.014886986082274234, 0.0571221159043489, 0.06168506988615263, 0.054966284515103325, 0.03038681545149302, 0.03647885525424499, 0.022108532903075684, 0.04672853436204605, 0.010264409811497899, 0.038350703835021704, 0.050195414150948636, 0.07027216008282267, 0.07032557245111093, 0.7201294018886983, 11.751289330422878, 39.7329593449831, 46.689462661743164, 30.708075016736984, 23.960125409066677, 30.9679164737463, 29.78357322514057, 6.342031639069319, 1.6159988986328244, 0.02420104054181138, 1.5517927939072251, 4.143566032871604, 6.389524815604091, 5.44624918140471, 2.738922955468297, 2.790976599790156, 6.039716061204672, 19.99413952231407, 31.15319073200226, 40.84150046110153, 47.25842513144016, 53.15726280212402, 51.07257306575775, 51.78294874727726, 52.59879156947136, 52.1638061106205, 52.41748049855232, 52.918221428990364, 51.444276720285416, 52.325658425688744, 52.74744339287281, 51.75009571015835, 50.27599900960922, 49.8123174905777, 50.87175004184246, 51.12299256026745, 50.92989832162857, 52.275075539946556, 50.84834709763527, 51.521040201187134, 49.82825003564358, 49.6804341673851, 50.62325857579708, 51.89922250807285, 46.91146954894066, 40.8444757014513, 35.98483666777611, 36.47695206105709, 35.665399208664894, 38.67827273905277, 38.95265981554985, 40.83715729415417, 39.85109880566597, 41.815566793084145, 44.70490135252476, 48.00294578075409, 47.89210572838783, 54.42913815379143, 34.04135875403881, 44.63970825076103, 54.448285326361656, 47.389601692557335, 48.59101742506027, 42.85907059907913, 39.41589675843716, 37.47662141919136, 37.42805242538452, 34.97985519468784, 38.22100907564163, 35.30693784356117, 36.82462200522423, 37.93348230421543, 44.800204038619995, 46.926497742533684, 48.3024001121521, 46.83097466826439, 48.231032341718674, 45.95181964337826, 46.64523683488369, 45.5223248898983, 51.50476187467575, 46.19537517428398, 49.92571860551834, 51.70965448021889, 50.15599004924297, 46.49349957704544, 40.684876665472984, 33.29584635794163, 40.13848878443241, 48.29647623002529, 50.35793401300907, 49.751790538430214, 51.67104475200176, 50.12233525514603, 49.98583137989044, 52.27182671427727, 51.068047508597374, 41.617833003401756, 30.84935523569584, 17.36435003578663, 6.580234682187438, 3.4209357714280486, 2.751712594181299, 6.549832988530397, 2.643917128443718, 4.135660557076335, 6.149571016430855, 5.109192542731762, 1.341169977094978, 1.072118526790291, 0.6623394310008734, 3.373116049915552, 11.210858579725027, 22.257615365087986, 19.535129852592945, 28.59784685075283, 32.517834305763245, 25.774759836494923, 8.896687757223845, 0.37044140975922346, 0.03458958104602061, 0.015816256091056857, 0.08164194412529469, 0.03251014633860905, 0.01108885702706175, 0.05645266530336812, 0.086095082515385, 0.03046087993425317, 0.03245045169023797, 0.00987713396170875, 0.030724743119208142, 0.013371475070016459, 0.06622870205319487, 0.012689263239735737, 0.034637646240298636, 0.09931849170243368, 0.10073792334878817, 0.006425611063605174, 0.02746890972048277, 0.05894391404581256, 0.0422486229945207, 0.0624740582134109, 0.04778261041792575, 0.03875537098792847, 0.02795539123326307, 0.023158280382631347, 0.05098036890558433, 0.012786359347956022, 0.005951632883807179, 0.05216554163780529, 0.04407973880006466, 0.0331334353541024, 0.053192959749139845, 0.019336911900609266, 0.05749063675466459, 0.04086839900992345, 0.03492739182547666, 0.05962297545920592, 0.029038904576736968, 0.02985677172546275, 0.02708276286284672, 0.02298950857948512, 0.005947090940026101, 0.03248475746659096, 0.03431737241044175, 0.05145277929841541, 0.08056861304794438, 0.04808219317055773, 0.02766662528301822, 0.06315878592431545, 0.04206424382573459, 0.027770414635597263, 0.04004961345344782, 0.025858992885332555, 0.01117562058425392, 1.6810660134069622, 16.694442182779312, 48.15452724695206, 50.472509264945984, 36.0241873562336, 25.05996499210596, 29.108647741377354, 28.864117562770844, 6.280534313991666, 0.9474157495424151, 0.13197629945352674, 0.6942934007383883, 3.238343931734562, 6.683506965637207, 9.293091036379337, 5.971528720110655, 3.8177696149796247, 9.025983419269323, 22.095544561743736, 36.94214589893818, 44.23554673790932, 50.772951543331146, 55.12078084051609, 54.59695614874363, 54.50055532157421, 54.9969606846571, 52.55545109510422, 53.37497591972351, 52.9433760792017, 52.546479776501656, 54.52094502747059, 54.187486320734024, 54.1568523645401, 52.53858759999275, 52.03731469810009, 53.530026599764824, 54.209019765257835, 53.1735373288393, 52.29644939303398, 51.66513606905937, 50.644537433981895, 50.24877727031708, 49.88991692662239, 52.06680491566658, 53.79362225532532, 49.38856802880764, 43.214720115065575, 36.9256965816021, 37.93070465326309, 37.309502586722374, 39.69287149608135, 40.567508563399315, 41.99754662811756, 41.31145164370537, 42.16567620635033, 46.01343713700771, 50.01439444720745, 49.35821145772934, 55.98519265651703, 37.51749202609062, 45.990816950798035, 54.93015266954899, 49.729968309402466, 49.2495296895504, 43.93869146704674, 42.478498220443726, 39.334311336278915, 39.22405645251274, 37.28540427982807, 39.81199890375137, 38.75767707824707, 37.27885723114014, 38.95147807896137, 46.48661054670811, 49.21349622309208, 50.000677183270454, 48.96581411361694, 49.57773707807064, 46.82417303323746, 48.65917816758156, 48.43886598944664, 54.30455423891544, 47.57390320301056, 49.784009009599686, 52.15227372944355, 51.6357446461916, 48.93169194459915, 43.05294379591942, 35.25918200612068, 41.84450604021549, 50.870545506477356, 51.877974048256874, 52.33749479055405, 53.005286157131195, 53.7688247859478, 53.00079099833965, 54.395323768258095, 51.362151727080345, 46.04748710989952, 33.39269556105137, 19.72912274301052, 7.44487876072526, 4.424001909792423, 4.430945087224245, 3.2492462592199445, 3.5186924133449793, 2.3483015410602093, 4.618240362033248, 2.157417358830571, 0.6705841573420912, 0.03256479809351731, 0.8468007703777403, 3.8744089007377625, 12.683202624320984, 25.42065303772688, 22.892367504537106, 30.756216533482075, 37.43972159922123, 31.892748847603798, 12.313245926052332, 0.8271836105268449, 0.05476100275700446, 0.010304190782335354, 0.01922209979966283, 0.02313246292033, 0.028232327349542174, 0.057090318587142974, 0.04766515070514288, 0.040944235370261595, 0.05400785645178985, 0.06266099779168144, 0.025564282332197763, 0.0310467275994597, 0.02834425806213403, 0.0419795647758292, 0.06601244764169678, 0.03777784004341811, 0.048214915150310844, 0.06137337528343778, 0.003911791291102418, 0.015733263571746647, 0.07175548322265968, 0.030468243894574698, 0.0028203167903484427, 0.009755894861882553, 0.03464995475951582, 0.16515948838787153, 0.1629629242233932, 0.05551552203542087, 0.131718848424498, 0.11913303314941004, 0.14924404240446165, 0.14750600676052272, 0.12281274233828299, 0.07360456642345525, 0.20374352345243096, 0.05798642479931004, 0.10421797254821286, 0.11052996822400019, 0.10402421263279393, 0.11867737674037926, 0.14300326321972534, 0.09676341825979762, 0.09917410687194206, 0.15493681974476203, 0.0709427276160568, 0.13971106644021347, 0.2801036322489381, 0.08694836680660956, 0.1694127664086409, 0.19346031040186062, 0.16267126018647105, 0.1279214717214927, 0.10420394595712423, 0.21137863484909758, 0.17088791850255802, 1.9926251890137792, 18.51053573191166, 53.00791181623936, 59.328397661447525, 41.583874225616455, 35.672706216573715, 40.31037636101246, 37.87726812064648, 8.594477623701096, 2.209643656387925, 0.3678414586465806, 3.327687825076282, 9.095990862697363, 16.687216870486736, 14.183262381702662, 6.498711006715894, 5.490239895880222, 8.718549516052008, 25.938434153795242, 39.95039127767086, 48.00236441195011, 50.313689187169075, 57.581555396318436, 56.782895252108574, 57.96479903161526, 55.96489794552326, 53.79195794463158, 57.23902277648449, 54.67397041618824, 52.394525930285454, 56.07939340174198, 56.19861960411072, 56.48703172802925, 54.37991179525852, 53.71820010244846, 54.02482084929943, 55.45883350074291, 52.513592541217804, 53.53578329086304, 52.977399453520775, 51.91198602318764, 50.681376457214355, 50.07153958082199, 53.64372789859772, 55.23659482598305, 51.496945694088936, 45.43553754687309, 39.07823547720909, 40.01713089644909, 39.0087828040123, 41.76831252872944, 43.7911681830883, 45.27799800038338, 44.006510227918625, 44.81046348810196, 47.948893681168556, 51.146460101008415, 53.627510368824005, 56.210501566529274, 42.15444780886173, 48.65941375494003, 56.00784324109554, 52.47038505971432, 51.558437794446945, 45.73880307376385, 42.58209206163883, 40.36693632602692, 40.66489353775978, 38.972274363040924, 41.74250051379204, 40.26448242366314, 40.46926103532314, 40.96380449831486, 49.765819385647774, 51.40749469399452, 50.66637486219406, 50.107618644833565, 52.68437437713146, 50.70430442690849, 51.62124842405319, 49.95643995702267, 55.207043811678886, 47.112056985497475, 50.72135031223297, 53.45847263932228, 54.224549531936646, 50.55119924247265, 45.31989835202694, 36.67809046804905, 44.34575602412224, 51.805694326758385, 54.23427700996399, 52.88835123181343, 54.32786978781223, 53.602051734924316, 55.116171687841415, 54.668399915099144, 53.91762860119343, 44.76948268711567, 33.12805496156216, 20.764107406139374, 8.189274966716766, 6.033266857266426, 6.656517488881946, 17.93363358825445, 11.231054496020079, 8.35596727207303, 14.87206757068634, 13.409200217574835, 5.316736456006765, 2.7324706641957164, 1.4995561656542122, 4.523526644334197, 16.18035636842251, 31.66901495307684, 32.767982482910156, 37.02025830745697, 45.7686884701252, 34.46518801152706, 12.740990873426199, 0.9089287428651005, 0.14628894394263625, 0.06622138447710313, 0.26711109036114067, 0.07082488940795884, 0.10809813582454808, 0.10271832215948962, 0.1341198742738925, 0.1566800949512981, 0.18110628268914297, 0.1654472784139216, 0.07417534478008747, 0.07864468425395899, 0.06311319579253905, 0.11487572526675649, 0.21732653287472203, 0.11777813866501674, 0.1785616809502244, 0.08961473271483555, 0.19622481049736962, 0.1561020509689115, 0.16494432493345812, 0.1117341622011736, 0.13783715839963406, 0.11843580767163076, 0.12926400202559307], [0.023095333272067364, 0.04485755038331263, 0.07591018176754005, 0.03545310326444451, 0.024841178164933808, 0.051737593312282115, 0.015392219811474206, 0.026203091510978993, 0.018796984622895252, 0.02863428380805999, 0.04951192582666408, 0.03471954965789337, 0.03989267519500572, 0.030424366268562153, 0.015135724297579145, 0.04248574659868609, 0.049608865156187676, 0.03822454244073015, 0.09573188493959606, 0.15978749695932493, 0.03973181468609255, 0.029718119985773228, 0.013042279697401682, 0.015317022625822574, 0.030814439087407663, 0.035008126360480674, 0.039247270178748295, 0.02547977026551962, 0.012777080646628747, 0.040111935304594226, 0.361921435687691, 5.433547887951136, 26.64960779249668, 44.32501673698425, 34.759242832660675, 22.465895488858223, 25.12158628553152, 21.320973224937916, 11.72014145180583, 1.6636638971976936, 0.3211529483087361, 0.9841331199277192, 3.392282221466303, 4.910265142098069, 6.19160246104002, 7.208586540073156, 1.2303769472055137, 6.488958830013871, 6.7860601376742125, 17.492595054209232, 32.56059721112251, 46.04767709970474, 54.27760608494282, 52.49731041491032, 51.921949088573456, 51.40660174190998, 52.73711554706097, 53.329591155052185, 51.70859053730965, 51.24189957976341, 49.922940954566, 49.56193372607231, 48.27112399041653, 46.89811326563358, 47.955623120069504, 47.313548773527145, 50.07260352373123, 51.45843856036663, 51.0901091247797, 52.03448385000229, 52.645342871546745, 50.45227535068989, 50.694968327879906, 51.52365826070309, 50.44635906815529, 49.97206471860409, 43.55109706521034, 36.23224899172783, 37.73760661482811, 41.13018997013569, 39.538675770163536, 38.925213888287544, 40.927212461829185, 39.641087874770164, 43.410029634833336, 45.7837850600481, 49.84680823981762, 47.40060970187187, 58.2035668194294, 31.343805603682995, 45.02090759575367, 51.459711492061615, 47.53328338265419, 46.919817700982094, 41.902836710214615, 40.31253084540367, 38.7387502938509, 38.35746355354786, 39.02376540005207, 37.60495573282242, 35.67028194665909, 35.83020016551018, 42.16098725795746, 49.08004738390446, 49.373334646224976, 50.207956060767174, 49.692760705947876, 53.2144421339035, 50.506563037633896, 50.27146965265274, 49.521959871053696, 49.04794290661812, 48.16290579736233, 49.81773979961872, 49.22841802239418, 49.97019901871681, 46.99232541024685, 38.79897706210613, 34.980406165122986, 37.63703741133213, 46.621985882520676, 47.785285860300064, 53.14640298485756, 46.91387861967087, 48.668917044997215, 50.62328517436981, 48.32963705062866, 46.224629804492, 37.39043444395065, 23.26191857457161, 10.032401215285063, 3.0463946191594005, 3.1292216246947646, 1.6890098433941603, 1.5666008368134499, 2.092469106428325, 1.2797988764941692, 3.63802975974977, 2.944159680046141, 0.4889560112496838, 0.07583982616779394, 1.0111338179558516, 4.7811642196029425, 11.723622065037489, 24.600966721773148, 29.8875280469656, 38.4847567230463, 34.66198705136776, 18.467417545616627, 3.1513141142204404, 0.07934855195344426, 0.007797607413522201, 0.012942680696141906, 0.05312073393724859, 0.0629562686663121, 0.03373307583387941, 0.012576903936860617, 0.01469366032324615, 0.07712435763096437, 0.042039389300043695, 0.013281765186548, 0.04028586503409315, 0.028968179758521728, 0.016925312302191742, 0.013138559443177655, 0.07558849785709754, 0.010434366267872974, 0.03354076310642995, 0.10886098942137323, 0.07976304143085144, 0.017602429288672283, 0.052971005643485114, 0.045333801390370354, 0.006429980458051432, 0.08240844166721217, 0.019456778027233668, 0.057782983567449264, 0.08692248811712489, 0.0593039484374458, 0.0263112706670654, 0.03417545522097498, 0.014673059231427033, 0.037499928002944216, 0.028435070962586906, 0.0525909592397511, 0.06912812459631823, 0.04536105305305682, 0.008805859561107354, 0.046756235024076886, 0.0314899864315521, 0.032561714469920844, 0.049355640658177435, 0.02112806490913499, 0.06772892389562912, 0.07134225539630279, 0.09520915322354995, 0.013138372050889302, 0.038986531435512006, 0.028476633087848313, 0.011088526771345641, 0.03643345437012613, 0.04429227134096436, 0.06544569172547199, 0.0484842479636427, 0.02048075071797939, 0.05836696844198741, 0.4644128313520923, 7.307461034506559, 33.40071313083172, 50.185096487402916, 38.43689829111099, 23.75234115868807, 26.61295495927334, 27.3271057382226, 12.026225477457047, 2.565986872650683, 0.18231801688671112, 0.22417682310333475, 2.142146215774119, 5.315191838890314, 6.638165898621082, 8.739297352731228, 3.1581974448636174, 8.061920050531626, 14.027670230716467, 22.186707369983196, 37.88805574178696, 49.35984157025814, 56.4881906658411, 54.42208953201771, 53.53297144174576, 50.34342639148235, 52.715658098459244, 54.546726644039154, 53.548755794763565, 53.78210507333279, 53.244327530264854, 51.56306214630604, 51.3431603461504, 49.05653804540634, 50.886519849300385, 50.002178102731705, 52.51935303211212, 51.83765821158886, 54.09535266458988, 53.49873147904873, 52.64871709048748, 50.84744654595852, 51.992290914058685, 52.88588136434555, 52.8243550658226, 52.660614252090454, 46.36800371110439, 39.13083605468273, 39.36974063515663, 42.03869841992855, 41.67651325464249, 40.938110277056694, 42.68390379846096, 40.75239524245262, 44.59579020738602, 47.5663910061121, 50.93556001782417, 50.06285324692726, 57.593612149357796, 35.33825196325779, 46.29476264119148, 52.35168322920799, 49.701952412724495, 50.78102611005306, 45.723672285676, 41.61040440201759, 39.493234008550644, 39.3492217361927, 40.56981883943081, 38.959868028759956, 36.70881561934948, 37.7088687568903, 44.01675447821617, 50.75611084699631, 50.97928427159786, 52.51474387943745, 52.66809985041618, 54.44197006523609, 52.87965729832649, 51.68366767466068, 51.2553508579731, 49.577843472361565, 48.334432393312454, 50.81139788031578, 50.48431523144245, 50.8073852956295, 48.91558080911636, 40.52977278828621, 36.866081580519676, 39.07115265727043, 47.940857112407684, 51.68076083064079, 53.60784262418747, 49.95934680104256, 50.62663659453392, 51.72537423670292, 49.987609684467316, 50.71242079138756, 39.1523315012455, 26.98962114751339, 13.135719392448664, 3.823829577304423, 3.891654987819493, 5.395927056670189, 3.052170784212649, 1.191015571821481, 0.884652795502916, 1.9970911368727684, 0.21314344718120992, 0.12378937157336622, 0.1476731087313965, 1.2164776492863894, 5.703592747449875, 15.706470496952534, 28.299648351967335, 34.30950276553631, 42.71270625293255, 39.73229058086872, 23.10253232717514, 4.07394521869719, 0.10485912134754471, 0.04659495520172641, 0.03617440401285421, 0.03995484490587842, 0.009299257890234003, 0.013072446145088179, 0.03947687211621087, 0.025263020470447373, 0.054190339433262125, 0.037805570391356014, 0.01692085756076267, 0.01564918566145934, 0.008784973670117324, 0.016456827870570123, 0.023488966544391587, 0.08197308299713768, 0.028965007077204064, 0.006643515825999202, 0.050531722081359476, 0.05178345803869888, 0.09071156760910526, 0.03303078148746863, 0.035280390657135285, 0.01831840883824043, 0.0257550068636192, 0.1224847872799728, 0.14194978459272534, 0.2875127596780658, 0.14344776514917612, 0.12490539840655401, 0.1028728966775816, 0.13290517148561776, 0.0877400825265795, 0.09536240671877749, 0.17932741408003494, 0.21585708047496155, 0.08868140779668465, 0.14219726115697995, 0.11947868842980824, 0.2176112652523443, 0.11804312249296345, 0.17702438140986487, 0.10438290002639405, 0.14562904107151553, 0.21132162306457758, 0.26834988326299936, 0.1689435212756507, 0.14329905359772965, 0.16523043770575896, 0.06382327526807785, 0.17340080084977672, 0.11059345895773731, 0.0771505331795197, 0.10744383616838604, 0.21881939261220396, 0.1790528788114898, 0.6259699200745672, 8.226497769355774, 39.7154650837183, 56.36318117380142, 46.575833559036255, 31.164276637136936, 35.19811548292637, 30.850859954953194, 14.717383570969105, 2.5740882754325867, 0.5657242715824395, 2.1088623767718673, 9.495916552841663, 14.46354104205966, 15.863385926932096, 16.690553091466427, 5.267252661287785, 11.157974917441607, 12.251458391547203, 23.324128836393356, 37.05306954681873, 50.587760880589485, 56.082923412323, 54.414394944906235, 53.42486724257469, 52.214088812470436, 54.11219336092472, 56.6524026542902, 56.35766766965389, 55.67443013191223, 54.72885087132454, 53.13167877495289, 52.44086064398289, 49.659360498189926, 52.319605350494385, 51.52612052857876, 54.45797860622406, 54.43594738841057, 55.53075984120369, 54.347594529390335, 53.07802565395832, 52.34738186001778, 53.09986308217049, 52.68301025032997, 53.727703392505646, 55.308410972356796, 48.15766587853432, 40.29047302901745, 39.97892014682293, 44.313776940107346, 43.17337453365326, 44.096428602933884, 43.614074885845184, 42.34960533678532, 47.339326590299606, 50.238312631845474, 53.52119967341423, 51.890064999461174, 58.82979601621628, 39.429393634200096, 48.64845134317875, 52.91278392076492, 51.287109553813934, 52.065026611089706, 46.586849167943, 43.310410380363464, 42.17609144747257, 41.71045683324337, 43.05425092577934, 41.059468165040016, 38.17639946937561, 40.004599168896675, 47.08690993487835, 52.78673328459263, 52.986617758870125, 53.94586868584156, 53.133612871170044, 57.197779789566994, 55.03025829792023, 53.746713772416115, 51.357743963599205, 50.59729836881161, 48.42375420033932, 51.11224293708801, 52.16564901173115, 52.65269547700882, 51.964996978640556, 43.6686285585165, 38.504986837506294, 41.40577398240566, 48.63235540688038, 53.04217457771301, 54.91734355688095, 51.00106470286846, 50.37034794688225, 52.94076941907406, 50.02944923937321, 49.37702424824238, 40.82909792661667, 27.49332781881094, 11.713236272335052, 4.788835057988763, 5.977380881085992, 5.849822200834751, 6.019061794504523, 3.3841782063245773, 2.7666448429226875, 11.098423562943935, 8.359603676944971, 1.2418425944633782, 0.22600615775445476, 2.22173769492656, 8.475794792175293, 19.23389721661806, 35.788736790418625, 42.85288453102112, 47.615248784422874, 45.94934597611427, 25.024066418409348, 4.98259948566556, 0.18534538568928838, 0.15923486411338672, 0.1511362666497007, 0.11176238607731648, 0.14411091862712055, 0.10235384601401165, 0.12522143457317725, 0.06874629703816026, 0.0998903758591041, 0.17208310280693695, 0.06864520168164745, 0.09186603027046658, 0.17872839700430632, 0.10865980060771108, 0.11751294703572057, 0.12965126952622086, 0.2009604696650058, 0.15174610423855484, 0.1847468881169334, 0.1877913560019806, 0.19936476310249418, 0.1757889727014117, 0.09602134479791857, 0.07384026510408148, 0.20458603918086737, 0.2549464884214103], [0.055301134125329554, 0.03648171252280008, 0.05375590473704506, 0.05762277614849154, 0.021780026800115593, 0.08532564606866799, 0.026976374138030224, 0.08084420216619037, 0.018936567757918965, 0.03506560198729858, 0.010558446865616133, 0.01900227194710169, 0.05662607552949339, 0.036167810030747205, 0.024386089498875663, 0.03541729834978469, 0.012259432642167667, 0.06259878355194815, 0.06076340410800185, 0.08169595021172427, 0.026573391660349444, 0.0939153300714679, 0.06912367171025835, 0.07415251631755382, 0.019994746035081334, 0.04668978312110994, 0.029916759522166103, 0.0357365480158478, 0.03749553819943685, 0.052637866683653556, 0.016464071231894195, 2.9289222601801157, 15.513527300208807, 36.5718861669302, 46.244050562381744, 28.951585069298744, 21.185639686882496, 18.035319931805134, 11.138206478208303, 4.5258392952382565, 0.7326867186930031, 0.09314530732808635, 0.5298077082261443, 1.2738792691379786, 2.803900418803096, 7.047833316028118, 1.6686600353568792, 0.8052607462741435, 5.787532143294811, 11.823616549372673, 25.434273406863213, 38.03739532828331, 50.5463545024395, 52.86886967718601, 51.15307554602623, 51.71443462371826, 52.48782232403755, 52.61410094797611, 49.66434583067894, 48.455592691898346, 47.687452509999275, 45.68179853260517, 44.51566010713577, 44.000054374337196, 43.12878392636776, 46.748880073428154, 46.64111785590649, 47.95698344707489, 48.435567766427994, 52.16853305697441, 51.29455715417862, 50.73832020163536, 49.79094743728638, 51.38443373143673, 53.13373066484928, 48.619394302368164, 49.91876497864723, 39.435841888189316, 38.586484864354134, 41.068359687924385, 39.36828151345253, 40.332677364349365, 40.23265153169632, 41.01660266518593, 46.62785656750202, 46.425965800881386, 50.62390834093094, 47.12273821234703, 55.46766422688961, 34.60680641233921, 40.80216497182846, 53.259412720799446, 47.0905577391386, 48.67324121296406, 44.24843564629555, 39.61518086493015, 38.876337110996246, 38.147239834070206, 37.92019061744213, 35.17175629734993, 35.482002049684525, 39.371613934636116, 45.30644707381725, 49.545404613018036, 49.89495165646076, 49.77813832461834, 49.71028156578541, 51.08529098331928, 49.611004292964935, 49.37439478933811, 47.707165852189064, 48.209981471300125, 48.25889244675636, 48.98257501423359, 49.14394095540047, 48.317967876791954, 45.63890263438225, 40.04660591483116, 35.27884215116501, 37.078839763998985, 42.08625666797161, 47.14500121772289, 49.30196687579155, 54.988563135266304, 45.922747403383255, 49.50968272984028, 50.32152816653252, 41.41192205250263, 27.949278652668, 14.586287755519152, 5.5575741827487946, 1.2085908162407577, 2.7233335794880986, 13.709231168031693, 7.378324856981635, 0.9030925529077649, 0.8010638121049851, 1.7824801965616643, 0.1408447267021984, 0.04313907404139172, 0.2946743363281712, 3.124931179918349, 7.375275995582342, 19.75184552371502, 30.271334052085876, 30.86712308228016, 35.852964743971825, 27.933374606072903, 10.864929892122746, 1.219818857498467, 0.04841229303565342, 0.04078687408764381, 0.06570899087819271, 0.019101591715298127, 0.03690876284963451, 0.03730692136741709, 0.018792284972732887, 0.0752950823516585, 0.07848107037716545, 0.017505254327261355, 0.0559434814931592, 0.05878148389456328, 0.04646876783226617, 0.00945215700994595, 0.03175081423250958, 0.04689501663960982, 0.03593405577703379, 0.04925852692394983, 0.02029214687354397, 0.011177181877428666, 0.05441034911200404, 0.0286007294562296, 0.03348807062138803, 0.04692094727943186, 0.044727963977493346, 0.027139722697029356, 0.05208328198932577, 0.0692194903967902, 0.09172001271508634, 0.07303189559024759, 0.07516663885326125, 0.017072834561986383, 0.029215567265055142, 0.022713490870955866, 0.020838226555497386, 0.027104385335405823, 0.04165041485975962, 0.09967507881810889, 0.01888432612759061, 0.02421655699436087, 0.05714484788768459, 0.006669003960269038, 0.005709128245143802, 0.027276730579615105, 0.04409283399581909, 0.09322577840066515, 0.01951362097315723, 0.09152571103186347, 0.025846957105386537, 0.06120207275671419, 0.015534311405644985, 0.06812917155912146, 0.07189553391071968, 0.024194114448619075, 0.0704009375476744, 0.031241812248481438, 0.006892680312375887, 3.7679376639425755, 19.42321825772524, 42.761085256934166, 48.676607832312584, 30.968993715941906, 24.771188087761402, 25.80636654049158, 13.225394580513239, 4.520016107708216, 0.6115973100531846, 0.056899579212768, 1.0960824158973992, 2.4419810017570853, 5.227886773645878, 7.917569596320391, 5.729128802195191, 2.5654128659516573, 8.17665584385395, 16.035791225731373, 26.783360615372658, 40.86210295557976, 53.14820408821106, 53.287504613399506, 52.459407448768616, 53.225282952189445, 53.928636610507965, 56.142698004841805, 52.09462322294712, 50.9360121935606, 51.323352009058, 49.8862349241972, 46.51358909904957, 46.10146701335907, 47.11560599505901, 48.421223536133766, 50.01921258866787, 49.45915684103966, 51.64173312485218, 53.57122398912907, 53.48932698369026, 52.11950808763504, 51.60408474504948, 51.65955036878586, 53.706565126776695, 50.79302966594696, 50.10723106563091, 40.50469413399696, 39.447537660598755, 44.611430168151855, 41.98414094746113, 42.05339603126049, 41.79741516709328, 43.30498047173023, 48.56002248823643, 49.85419504344463, 52.5972830504179, 49.53583672642708, 56.01827748119831, 36.93885527551174, 44.58764344453812, 54.115369990468025, 49.14787374436855, 52.020880579948425, 45.663912892341614, 41.59330911934376, 40.944482535123825, 40.17067305743694, 39.64788191020489, 38.13682459294796, 38.11303786933422, 41.11947454512119, 46.95455923676491, 50.414011403918266, 52.53186576068401, 50.96976198256016, 51.29250146448612, 52.060531452298164, 50.730716809630394, 49.80670899152756, 47.54036620259285, 48.430115059018135, 49.50552195310593, 50.47429896891117, 51.5082348883152, 50.10326787829399, 48.60391013324261, 42.105776220560074, 37.57264606654644, 39.0189054608345, 44.931593388319016, 50.42783506214619, 51.56004510819912, 55.07310099899769, 47.85035736858845, 51.40940599143505, 50.31580947339535, 43.26394647359848, 31.64966069161892, 16.721369437873363, 5.805269116535783, 2.1251093549653888, 2.503620581701398, 6.013534991070628, 4.068937562406063, 1.1232925183139741, 0.513919098302722, 0.32254316902253777, 0.01689499185886234, 0.038200830822461285, 0.047336928473669104, 3.2431119633838534, 10.208084788173437, 23.177243918180466, 34.96092081069946, 34.360496029257774, 41.22005894780159, 33.02315779030323, 14.313711281865835, 1.725250636227429, 0.0158497102529509, 0.012526675382105168, 0.015811890407348983, 0.03963180286518764, 0.08061097483732738, 0.05308803119987715, 0.04894293975667097, 0.08054136880673468, 0.025171354100166354, 0.035458379934425466, 0.13081335404422134, 0.02224036245024763, 0.012592891653184779, 0.09195159989758395, 0.07631418469827622, 0.049932285692193545, 0.06278115150053054, 0.0702992187871132, 0.0470378392492421, 0.02019197363551939, 0.058496076162555255, 0.013850200211891206, 0.028655451715167146, 0.05393182342231739, 0.055354795113089494, 0.056524586834711954, 0.17507541255326942, 0.1478821865748614, 0.20457385311601683, 0.1368506660219282, 0.11781459295889363, 0.14203698694473132, 0.11398415357689373, 0.1303628258756362, 0.08486962600727566, 0.12545831326860934, 0.11081732038292103, 0.21166874037589878, 0.18585960497148335, 0.13776049454463646, 0.18104544142261147, 0.11339814634993672, 0.20413472433574498, 0.2056550732231699, 0.10324902454158291, 0.1824699790449813, 0.1264850894222036, 0.23757993592880666, 0.10113434153026901, 0.19380586920306087, 0.11767650896217674, 0.19134695583488792, 0.1707862739567645, 0.08548016121494584, 0.21970989560941234, 0.130456707556732, 0.1458743802504614, 4.158448884263635, 23.685527443885803, 48.04031677544117, 59.80477049946785, 38.587035834789276, 33.918659538030624, 27.609295696020126, 14.856268018484116, 6.673551024869084, 1.087803253903985, 0.34724635595921427, 2.839305493980646, 9.259654730558395, 12.892780378460884, 17.84566640853882, 7.950230268761516, 3.294258168898523, 9.268096927553415, 15.290685407817364, 27.585497573018074, 40.5295941978693, 52.370097041130066, 52.936616241931915, 52.70468048751354, 55.78033424913883, 56.10777407884598, 57.52373769879341, 55.31522020697594, 52.37941414117813, 52.767411321401596, 50.66756799817085, 49.34549354016781, 47.92276628315449, 48.28221559524536, 51.684294641017914, 51.0731316357851, 52.02285647392273, 52.693930864334106, 55.0992663949728, 53.48436824977398, 52.89786972105503, 50.69342941045761, 53.60516756772995, 54.96965155005455, 52.015264481306076, 52.41494603455067, 43.05905006825924, 41.20495095849037, 44.89851996302605, 42.48672477900982, 44.745494574308395, 43.38979572057724, 46.951770186424255, 51.45199030637741, 52.15985432267189, 54.43944700062275, 52.3621516674757, 56.00287690758705, 41.530639082193375, 46.34559631347656, 56.03326767683029, 51.76553428173065, 53.20007510483265, 48.822782188653946, 43.32262672483921, 42.54088707268238, 41.15364991128445, 39.372848868370056, 40.647224485874176, 39.34465058147907, 42.61030554771423, 49.7478349506855, 53.230633065104485, 54.140118062496185, 52.25853122770786, 50.805356204509735, 52.76048429310322, 51.35635323822498, 50.20381048321724, 47.40047290921211, 48.04654084146023, 49.407206028699875, 52.19513162970543, 53.67485202848911, 50.553631111979485, 50.321946144104004, 43.33469107747078, 39.75686766207218, 40.465309247374535, 46.216927617788315, 51.032872796058655, 53.02145428955555, 57.41092935204506, 46.584709882736206, 50.785513669252396, 51.4397207647562, 44.18683335185051, 29.74081601947546, 17.493807189166546, 6.639575148001313, 2.6621796609833837, 8.464934024959803, 27.59670127183199, 14.74181815981865, 2.8424353385344148, 2.9145592683926225, 3.2655326602980494, 0.25391330011188984, 0.24054670095210895, 0.3638203541049734, 5.2918321173638105, 12.739305663853884, 27.394658513367176, 40.999355390667915, 43.670140877366066, 48.06204400956631, 36.51349849998951, 16.22235171496868, 2.0181963918730617, 0.15097962896106765, 0.19489652942866087, 0.1506714298739098, 0.0952395293279551, 0.16850859305122867, 0.16138667677296326, 0.15141299867536873, 0.193920174788218, 0.32837561855558306, 0.1571827961015515, 0.24269759334856644, 0.17263396934140474, 0.13680057105375454, 0.19959361176006496, 0.14638114836998284, 0.1923703181091696, 0.1906516228336841, 0.14243517885915935, 0.12314741383306682, 0.06549924510181881, 0.10430219146655872, 0.11151156242704019, 0.1403436582768336, 0.19791488855844364, 0.13568439579103142, 0.16891837731236592], [0.027535322660696693, 0.05139932611200493, 0.06907230024808086, 0.020061589420947712, 0.07330338063184172, 0.01632516345125623, 0.019003129127668217, 0.06292802994721569, 0.026284046834916808, 0.028461341134971008, 0.030995654851722065, 0.016009793362172786, 0.02768107489828253, 0.03385263953532558, 0.04485178389586508, 0.0163337575213518, 0.02184281805966748, 0.05354078581149224, 0.058860374192590825, 0.04178904433501884, 0.012199946722830646, 0.10098257975187153, 0.01821185498556588, 0.055624795859330334, 0.02121431360137649, 0.025978423000196926, 0.03155632330162916, 0.012921402394567849, 0.03493467600492295, 0.008871743721101666, 0.041466380789643154, 0.20108886121306568, 7.232702421024442, 24.284238517284393, 42.17114791274071, 38.3783358335495, 18.035743609070778, 20.78277960419655, 31.395737417042255, 7.931944224983454, 1.8744643544778228, 0.3613379888702184, 1.3832125836052, 1.2182275741361082, 6.553537314757705, 2.6670419750735164, 6.051427032798529, 5.295676561072469, 2.146236696280539, 4.628693126142025, 18.319556079804897, 30.448083467781544, 45.41412569582462, 55.186418518424034, 49.84768599271774, 54.054554253816605, 52.617197781801224, 50.48064462840557, 48.19214902818203, 48.81094202399254, 44.791054129600525, 43.88903193175793, 46.849829256534576, 45.998294949531555, 49.273605197668076, 48.12571719288826, 46.664877980947495, 46.90583445131779, 47.6706650108099, 48.93620990216732, 52.60237857699394, 51.87648452818394, 51.246265545487404, 49.20044392347336, 53.21352258324623, 51.54799975454807, 50.004845559597015, 45.59428542852402, 38.63342374563217, 36.393485739827156, 36.865549609065056, 39.81634207069874, 40.06251946091652, 40.33005930483341, 47.079291343688965, 49.396984577178955, 51.06686197221279, 50.27849167585373, 71.07109755277634, 36.15105874836445, 40.1084665954113, 52.81072519719601, 48.3920942991972, 49.808301106095314, 46.62980206310749, 45.60677155852318, 37.9127050191164, 36.08606703579426, 34.7829307615757, 37.93895021080971, 36.25048041343689, 42.43250168859959, 49.447320476174355, 49.28699567914009, 50.230690240859985, 48.690670877695084, 47.41283364593983, 49.809672832489014, 48.51445913314819, 48.89284282922745, 51.018517166376114, 51.24895200133324, 51.1231255531311, 48.76370295882225, 51.09089948236942, 47.157145366072655, 45.574765875935555, 38.27664948999882, 38.73287580907345, 38.87913376092911, 44.38243545591831, 46.96560524404049, 49.40383180975914, 48.22573162615299, 55.98316356539726, 44.78495545685291, 50.66213808953762, 32.55976125597954, 19.609529860317707, 5.9646510891616344, 4.4349937699735165, 3.907659729011357, 1.3925263588316739, 25.123955458402634, 13.866572175174952, 3.392691412009299, 0.05446113056677859, 0.05805906250316184, 0.038703446625731885, 0.07362359508988447, 0.49442878633271903, 3.3365814853459597, 6.651553055271506, 16.946017183363438, 27.323106452822685, 34.66798312962055, 36.34709022939205, 17.90296733379364, 3.514939402230084, 0.06813769141444936, 0.06000264336762484, 0.0018691544687499118, 0.0531526017584838, 0.04159255331614986, 0.060632930835708976, 0.027178902528248727, 0.025097298894252162, 0.03854811511700973, 0.06068668830266688, 0.0387296036205953, 0.10711088645621203, 0.00821391793579096, 0.01756670044414932, 0.0348217025748454, 0.036175454151816666, 0.014505608451145235, 0.03429498181503732, 0.02889430266804993, 0.030799588712397963, 0.03779393351578619, 0.10786853017634712, 0.03946689022995997, 0.052652576050604694, 0.07207851042039692, 0.0203347665592446, 0.044292319580563344, 0.026339778414694592, 0.012915314928250154, 0.07231502546346746, 0.02335463410418015, 0.04480326228076592, 0.08950573348556645, 0.008630036427348386, 0.04035425023175776, 0.04046150170324836, 0.009840842940320726, 0.01498288918810431, 0.029398011283774395, 0.028809543837269302, 0.02824140010488918, 0.05224814267421607, 0.07067424085107632, 0.03133770886051934, 0.04992535032215528, 0.05726753603084944, 0.016526489562238567, 0.062131675804266706, 0.037395830659079365, 0.03507026267470792, 0.059685237938538194, 0.0032361349440179765, 0.03411987949220929, 0.03077398276218446, 0.07142007700167596, 0.05588117448496632, 0.060880793316755444, 0.0852820003638044, 0.5105343111790717, 9.811363276094198, 30.289479978382587, 50.877138152718544, 39.767039716243744, 23.10942515730858, 22.47121900320053, 23.39311223477125, 9.327983614057302, 1.970281081739813, 0.18383020214969292, 0.44720702804625034, 1.4796495088376105, 3.934201067313552, 6.520907990634441, 8.25810732319951, 0.7623239408712834, 2.196306847035885, 6.961515247821808, 19.725986011326313, 32.426551803946495, 48.63437309861183, 55.33338703215122, 50.913798585534096, 55.999920666217804, 54.76416237652302, 53.16146157681942, 51.33954294025898, 50.36698892712593, 47.05502964556217, 46.55523106455803, 48.83593708276749, 48.503116741776466, 50.2673202753067, 49.25934836268425, 48.60439270734787, 48.2477780431509, 49.84014339745045, 51.98180727660656, 53.60841639339924, 53.832790553569794, 51.10172130167484, 49.851744174957275, 54.17416423559189, 52.066044956445694, 53.522867783904076, 46.9890233874321, 40.696728229522705, 38.24135318398476, 39.685944467782974, 40.60542672872543, 41.40217177569866, 41.726917549967766, 49.96268682181835, 50.444820150732994, 52.575916796922684, 51.47638879716396, 63.95654171705246, 39.3993828445673, 42.22886681556702, 54.170619025826454, 49.78368602693081, 52.46498554944992, 46.96944683790207, 46.79317809641361, 39.75190132856369, 38.802408277988434, 36.859880313277245, 39.400906562805176, 37.4593361467123, 44.27468463778496, 51.71040304005146, 50.520865470170975, 52.781447768211365, 50.090580359101295, 47.399557158350945, 50.10947674512863, 48.095649406313896, 48.38898226618767, 50.19607029855251, 51.49749666452408, 50.81147387623787, 51.0323940217495, 53.56183089315891, 49.579952359199524, 46.81274704635143, 40.02808190882206, 40.332403779029846, 40.4922915995121, 46.2327765673399, 48.41127946972847, 52.33051836490631, 50.880310982465744, 54.07920353114605, 45.98593421280384, 52.14296042919159, 33.64539720118046, 22.048489786684513, 8.219236359000206, 5.312192374840379, 3.8369160750880837, 1.7399026500061154, 26.804394386708736, 16.97730280458927, 4.702794849872589, 0.24190287193050608, 0.07182881483458914, 0.01683926398982294, 0.07306676168809645, 0.9625616774428636, 5.864858468994498, 8.175219520926476, 22.56063960492611, 33.87737475335598, 39.16286073625088, 41.33150316774845, 22.907650284469128, 5.298364916816354, 0.11704955002642237, 0.008296468877233565, 0.03548471133399289, 0.06676680364762433, 0.05210954288486391, 0.03372502724232618, 0.0012471547029235808, 0.04228608660923783, 0.016923568255151622, 0.0353351203375496, 0.011035508669010596, 0.05312428140314296, 0.026017988748208154, 0.01791246704669902, 0.039948198973434046, 0.03455298574408516, 0.02359857247938635, 0.005633601731460658, 0.012701628347713267, 0.04483463286305778, 0.034796250620274805, 0.010172628408327, 0.026486534407013096, 0.04355525932624005, 0.03367542209161911, 0.03590746833651792, 0.08978508529253304, 0.0956002130988054, 0.14795988943660632, 0.1395267466432415, 0.17431183165172115, 0.2177468704758212, 0.14262237818911672, 0.08543854899471626, 0.13830839248839766, 0.19468816404696554, 0.14895965141477063, 0.0977393944049254, 0.07458495834725909, 0.1076252393249888, 0.12387670009047724, 0.17930333880940452, 0.09972802363336086, 0.1371642085723579, 0.1387260583578609, 0.13566296256612986, 0.15240621491102502, 0.12884088879218325, 0.158029853773769, 0.11016002245014533, 0.20035040943184868, 0.14388710173079744, 0.14919387322152033, 0.19309184892335907, 0.2022484818007797, 0.15963241778081283, 0.1292157030547969, 0.15250079421093687, 0.7650074281264096, 10.839742943644524, 36.004367619752884, 58.142827078700066, 48.93111437559128, 28.165183067321777, 30.83401545882225, 35.45408874750137, 12.337465826421976, 2.7558432100340724, 0.7734316354617476, 2.35675941221416, 7.462602434679866, 15.420105513185263, 7.823106190189719, 14.476302657276392, 11.236659195274115, 5.240030447021127, 7.976344842463732, 24.18774839490652, 36.599537283182144, 48.92777055501938, 56.34982869029045, 51.500004529953, 54.67762961983681, 57.591921240091324, 54.93987634778023, 52.51426510512829, 51.533381938934326, 49.227042496204376, 49.540901854634285, 51.41996942460537, 51.380930319428444, 52.86145627498627, 53.12957748770714, 51.295514702796936, 50.3414086997509, 50.68236440420151, 53.64108704030514, 55.23786395788193, 55.28339311480522, 51.86796918511391, 50.4606045037508, 54.653736501932144, 55.906468480825424, 53.92302431166172, 49.80930805206299, 42.63989455997944, 40.46797290444374, 40.95983751118183, 43.425327613949776, 42.87284106016159, 44.381314516067505, 50.73342226445675, 52.95180782675743, 57.12845630943775, 52.38941140472889, 63.227064460515976, 44.57843653857708, 44.72640819847584, 55.76185584068298, 52.555508092045784, 55.489885434508324, 50.30298516154289, 49.13549780845642, 42.11421176791191, 40.1096673309803, 38.76133628189564, 40.91804355382919, 40.56486390531063, 45.88021628558636, 53.844676315784454, 52.68902912735939, 55.123718082904816, 51.73874191939831, 47.388940528035164, 50.16882196068764, 49.13176640868187, 49.35090444982052, 53.03400881588459, 53.300040140748024, 52.70628780126572, 50.993400514125824, 54.443189799785614, 52.317257076501846, 48.1549908220768, 42.09803223609924, 41.37601017951965, 42.91791044175625, 49.47921596467495, 51.30141578614712, 54.04901035130024, 51.21707171201706, 55.87162435054779, 47.324343994259834, 51.38798274099827, 36.936457604169846, 22.086369954049587, 7.491132728755474, 6.906045349314809, 7.6882856246083975, 5.785410907119513, 32.9758807271719, 17.319738529622555, 6.823460580781102, 1.0445453063584864, 0.19702723540831357, 0.2699404541635886, 0.34435263311024755, 1.2159783323295414, 11.095835901796818, 13.421404212713242, 27.613977044820786, 41.62180759012699, 45.14002740383148, 47.230074852705, 24.269301518797874, 5.88594876229763, 0.2658176457043737, 0.16510419838596135, 0.1056937183602713, 0.20082599250599742, 0.14140482555376366, 0.1717589920735918, 0.2206327859312296, 0.0813225979800336, 0.21396911615738645, 0.14572468906408176, 0.09790993994101882, 0.20251696114428341, 0.1230342363123782, 0.09344912774395198, 0.11942871962673962, 0.06907084563863464, 0.08235828732722439, 0.1184589923650492, 0.08260631308075972, 0.10093466669786721, 0.12689267692621797, 0.24138335371389985, 0.1420766324736178, 0.181098178436514, 0.162189680559095, 0.07153303929953836, 0.18289313680725172], [0.03914510612958111, 0.059276370229781605, 0.016924418014241382, 0.034690913889789954, 0.0345962455321569, 0.04484169068746269, 0.027352804427209776, 0.0057230398033425445, 0.05257623502984643, 0.04045729372592177, 0.04062905638420489, 0.10814461653353646, 0.009083890345209511, 0.047284633037634194, 0.01950039961229777, 0.06091540337365586, 0.047798139858059585, 0.09267193585401401, 0.013451478589558974, 0.04280885543266777, 0.03294586123956833, 0.047662360229878686, 0.006033769614077755, 0.025260064867325127, 0.09582482409314252, 0.05371412182284985, 0.10731554852100089, 0.04368799985968508, 0.04821206159249414, 0.03269563501817174, 0.049957418523263186, 0.1778648784966208, 2.2881771298125386, 14.056487884372473, 33.681058287620544, 44.181452840566635, 25.513732843101025, 38.873548060655594, 37.62012451887131, 13.039998728781939, 4.298531217500567, 0.5961200874298811, 0.5924621899612248, 1.159244051668793, 2.7761412458494306, 5.813525123521686, 5.736100003123283, 1.7118873470462859, 1.8583883671090007, 1.8212716025300324, 3.664735914207995, 19.016723670065403, 35.95581382513046, 44.45053540170193, 52.38436907529831, 56.43312022089958, 51.50412730872631, 50.22155933082104, 47.85556688904762, 46.940442994236946, 50.42705990374088, 49.60583657026291, 50.78732617199421, 52.03045226633549, 50.91006338596344, 49.783743023872375, 48.57999421656132, 44.71295312047005, 46.86959579586983, 48.817637264728546, 53.09595309197903, 52.59382903575897, 52.25283533334732, 51.34450547397137, 51.25408172607422, 51.92992106080055, 51.962363719940186, 48.71165715157986, 39.75495256483555, 36.05528108775616, 38.91047827899456, 40.29886297881603, 39.03162717819214, 41.78866423666477, 47.66096793115139, 47.92932093143463, 56.13432325422764, 49.90046136081219, 42.123563066124916, 36.51069425046444, 43.05154547095299, 50.77792547643185, 46.3251344114542, 49.87349420785904, 48.3358459174633, 47.98299305140972, 45.23915268480778, 38.244765400886536, 35.53632393479347, 39.8654430359602, 36.72861635684967, 45.950409919023514, 49.3950504809618, 47.6683509349823, 49.64092008769512, 49.2840888351202, 49.674605280160904, 49.0918343514204, 51.37165881693363, 48.039841800928116, 49.234972670674324, 49.85967434942722, 50.022852793335915, 48.4353169798851, 48.46304789185524, 46.40708081424236, 42.587214186787605, 38.106053844094276, 40.30169002711773, 41.981325298547745, 46.43536649644375, 44.95058476924896, 50.70843480527401, 49.674631878733635, 54.652699157595634, 48.87168176472187, 34.88422192633152, 23.164022527635098, 8.936034645885229, 3.7817408982664347, 0.8143540739547461, 1.2216681707650423, 0.3271689161192626, 2.606350681744516, 1.168057678733021, 0.8215247048065066, 0.26234522578306496, 0.08683656225912273, 0.272315297042951, 0.1812204101588577, 0.8999555837363005, 4.508206816390157, 18.626921586692333, 21.44300177693367, 32.57890082895756, 36.22397303581238, 24.651901088654995, 6.357049383223057, 1.2239717971533537, 0.040148864572984166, 0.034506223018979654, 0.017453600848966744, 0.02965299838251667, 0.014627054424636299, 0.03412435093196109, 0.054475294455187395, 0.035101585017400794, 0.03993080303189345, 0.015705017431173474, 0.03502166684484109, 0.05005758619518019, 0.03793480798776727, 0.019697825737239327, 0.05033169101807289, 0.02609033886983525, 0.02556873150751926, 0.03815498836047482, 0.08106898385449313, 0.08605419759987853, 0.08479765252559446, 0.03652114282886032, 0.05223012332862709, 0.017307275302300695, 0.01474120415878133, 0.01819839613744989, 0.09035309543833137, 0.006641662776019075, 0.06140224853879772, 0.05302828460116871, 0.026623494049999863, 0.06158066826174036, 0.08373827382456511, 0.02903904372942634, 0.06752226545359008, 0.015007314195827348, 0.03219563528546132, 0.01752393047354417, 0.09205092894262634, 0.08439943834673613, 0.03151212840748485, 0.044350225653033704, 0.018855744165193755, 0.02112055623001652, 0.04633534452295862, 0.012219892869325122, 0.016076451211120002, 0.03992265796114225, 0.01194863325508777, 0.08036032188101672, 0.02063780586468056, 0.03996762839960866, 0.05570939327299129, 0.036675910305348225, 0.08102357925963588, 0.036724843812407926, 0.027559332993405405, 0.016814999471534975, 0.09832506024395116, 3.053933414630592, 17.924194894731045, 40.11359252035618, 48.408342227339745, 24.3112987652421, 33.402297645807266, 41.58295467495918, 15.213633142411709, 4.5592323783785105, 0.5340380687266588, 0.45748577336780727, 1.1201469996012747, 3.71225212700665, 5.938242031261325, 7.770475689321756, 1.0243966500274837, 1.0079600382596254, 4.090939331799746, 6.814499236643314, 24.153166450560093, 40.451804772019386, 48.16737435758114, 53.77027250826359, 56.45332753658295, 54.10824917256832, 51.464214250445366, 50.59616602957249, 49.615522250533104, 53.29306371510029, 52.00832225382328, 52.96441175043583, 54.514185190200806, 52.97520697116852, 51.76981285214424, 50.738787576556206, 47.13906593620777, 48.37776146829128, 49.879262298345566, 54.85767535865307, 53.84552747011185, 53.19354325532913, 51.00879728794098, 52.85129562020302, 52.65315905213356, 53.859639912843704, 51.431517004966736, 41.51362359523773, 38.216544315218925, 41.000556126236916, 40.51629111170769, 40.43855868279934, 43.44211511313915, 49.84000660479069, 51.51042357087135, 59.423992931842804, 51.709962263703346, 44.34574842453003, 41.518479734659195, 44.6118139475584, 51.94011211395264, 48.974014073610306, 51.761206313967705, 47.908916026353836, 50.38769021630287, 46.42528183758259, 39.73359011113644, 37.08994276821613, 41.79022215306759, 38.31320732831955, 46.61245599389076, 50.42524740099907, 50.43774113059044, 51.7012645304203, 49.908193945884705, 49.732479974627495, 49.89760771393776, 50.91271564364433, 51.203134059906006, 52.280691638588905, 50.95422461628914, 51.926698833703995, 50.63341163098812, 50.583824291825294, 49.247785583138466, 44.41766336560249, 40.38592770695686, 42.985026240348816, 43.8703977316618, 46.78538091480732, 47.89024382829666, 51.90326929092407, 51.44141927361488, 54.02401149272919, 47.88585506379604, 38.57326537370682, 26.721087656915188, 11.066792160272598, 5.088154496625066, 1.7819074960425496, 2.7765881968662143, 0.9738583525177091, 2.5206833286210895, 1.940301877912134, 1.0535554541274905, 0.07183469264418818, 0.14577699563233182, 0.11333618444041349, 0.4912937170593068, 0.7604028470814228, 4.581588478758931, 19.166447035968304, 21.88684456050396, 34.283774346113205, 40.90906463563442, 30.69269724190235, 9.408419597893953, 1.549675001297146, 0.04989146014850121, 0.07909088570158929, 0.06912968310643919, 0.06507435813546181, 0.05584238613664638, 0.045180703746154904, 0.0546220281830756, 0.07772626166115515, 0.05871106521226466, 0.01514232755653211, 0.007249877380672842, 0.06327443479676731, 0.04864542017458007, 0.027625894363154657, 0.021247890217637178, 0.02130707463948056, 0.0034715165884335875, 0.049475345367682166, 0.047159733294392936, 0.0908808886015322, 0.04256126754626166, 0.09063894103746861, 0.024620899457659107, 0.03398699052922893, 0.010726653708843514, 0.07507608941523358, 0.027381033869460225, 0.2037190622650087, 0.1721507718320936, 0.1561752415727824, 0.138506842777133, 0.08882131005520932, 0.12942145607667044, 0.11756818508729339, 0.22334264911478385, 0.12361857370706275, 0.1329058691044338, 0.12467362568713725, 0.25596275576390326, 0.1170173185528256, 0.23473093489883468, 0.11171477730385959, 0.14529296691762283, 0.11748252640245482, 0.17657603515544906, 0.15995470283087343, 0.11846569395856932, 0.11386496466002427, 0.13414310349617153, 0.21849277341971174, 0.2140135708032176, 0.13616383803309873, 0.20009261701488867, 0.24272509734146297, 0.14115896687144414, 0.14337347616674379, 0.10195704191573896, 0.13974545756354928, 0.32432453124783933, 3.533628461882472, 22.43877064436674, 48.34609396755695, 55.61774857342243, 34.800360426306725, 46.779331639409065, 46.47458799183369, 16.839227713644505, 6.036276295781136, 0.846017834264785, 1.8059740983881056, 3.8834087178111076, 10.75395304709673, 13.969689141958952, 14.175398703664541, 6.555842841044068, 5.851265173405409, 3.7254276825115085, 4.974342528730631, 25.614108256995678, 45.681699737906456, 51.5052330493927, 55.5561500787735, 58.26810635626316, 56.594824343919754, 55.566420927643776, 52.78940834105015, 51.54989965260029, 55.15136159956455, 55.07030434906483, 56.260495483875275, 58.148975148797035, 55.851888209581375, 53.533267825841904, 53.03737163543701, 48.91760990023613, 50.432455614209175, 52.680012211203575, 58.030809089541435, 54.78297136723995, 52.56600692868233, 53.65729317069054, 53.45373809337616, 55.50182819366455, 55.75293771922588, 53.638563975691795, 43.8346416503191, 39.89356152713299, 42.924579083919525, 44.0346173197031, 43.885710909962654, 46.287132650613785, 51.197430565953255, 53.859769105911255, 60.65515726804733, 52.43210211396217, 45.612703040242195, 46.179184243083, 47.3026205599308, 51.40586458146572, 50.354894176125526, 54.97597061097622, 51.802350506186485, 51.3552512973547, 48.257608115673065, 42.38490164279938, 39.22786004841328, 44.108185172080994, 39.244176372885704, 48.90416622161865, 52.84783400595188, 52.0692253857851, 52.46123135089874, 50.00974729657173, 49.58185225725174, 51.84113882482052, 54.69594083726406, 51.92403897643089, 54.46561239659786, 52.963944375514984, 53.34296263754368, 52.887652069330215, 53.44063259661198, 49.903022423386574, 45.95164865255356, 42.43610389530659, 43.77518244087696, 46.45957499742508, 49.212584272027016, 49.865814819931984, 54.22678381204605, 54.52663332223892, 54.491580203175545, 49.20186124742031, 38.68235372006893, 26.591795794665813, 12.585962992161512, 5.471650818362832, 2.9948871955275536, 3.834204920567572, 1.5712155704386532, 5.0497176591306925, 2.0016691787168384, 1.7807891685515642, 0.3825064154807478, 0.9484440693631768, 0.32188538869377226, 1.1526569863781333, 4.698289716616273, 12.642031833529472, 28.74705534428358, 32.25971795618534, 44.35817375779152, 45.992910638451576, 34.98971566557884, 10.467810351401567, 1.7945843283087015, 0.127915742341429, 0.15765726595418528, 0.159611311100889, 0.1700498111313209, 0.15612903545843437, 0.14850294857751578, 0.17638172605074942, 0.11342531637637876, 0.14475774485617876, 0.09916830327711068, 0.11653953130007721, 0.19370866270037368, 0.15505642426433042, 0.14159067417494953, 0.17918977537192404, 0.1597725649480708, 0.1602156419539824, 0.14535783062456176, 0.11564182947040536, 0.19417119881836697, 0.18501223559724167, 0.23279897606698796, 0.14522139419568703, 0.12835179863031954, 0.09584394181729294, 0.13325283798621967, 0.2892219554632902], [0.07797334488714114, 0.03245576917834114, 0.028497557941591367, 0.027026522911910433, 0.062616743525723, 0.024762321263551712, 0.06879783919430338, 0.062204751375247724, 0.06030298682162538, 0.02627108151500579, 0.11062879260862246, 0.028646583050431218, 0.024913172055676114, 0.027475032438815106, 0.02117592786817113, 0.038820464760647155, 0.023329440045927186, 0.0053172297430137405, 0.01779332636942854, 0.022350222570821643, 0.0274448901109281, 0.025897933373926207, 0.017084979808714706, 0.06759802388842218, 0.052512299007503316, 0.009951928532245802, 0.04545120544207748, 0.05558315395319369, 0.09348968611448072, 0.04221155642881058, 0.023821676913939882, 0.09582331011188217, 0.25186363665852696, 4.896953031420708, 25.093701481819153, 44.851330295205116, 38.90498377382755, 34.69010554254055, 21.775284446775913, 19.44431282579899, 9.042538180947304, 1.595010249875486, 0.2789795456919819, 1.3328309683129191, 1.3087860960513353, 7.276080418378115, 4.191119531169534, 0.7318811025470495, 0.7878999528475106, 1.9575522397644818, 2.1988363238051534, 5.373959010466933, 20.74751939624548, 36.35159678757191, 46.975610107183456, 52.80763976275921, 53.343012034893036, 50.172937139868736, 50.86808703839779, 50.57194992899895, 51.14195354282856, 51.81944198906422, 53.779684603214264, 52.95205861330032, 53.23001749813557, 51.84847243130207, 48.86891171336174, 47.38127253949642, 47.18856208026409, 48.47924642264843, 51.75241358578205, 51.28474608063698, 50.968739837408066, 50.974021553993225, 50.3980066627264, 53.587240129709244, 52.678484693169594, 48.08893136680126, 41.9621667265892, 35.6162678450346, 36.62391297519207, 35.973642468452454, 43.21887329220772, 45.77903911471367, 47.5208580493927, 47.99762986600399, 53.73149938881397, 45.83039715886116, 45.036194175481796, 33.405683264136314, 38.18921998143196, 53.30574743449688, 48.90553034842014, 50.99619336426258, 48.275212571024895, 49.798569828271866, 48.88552062213421, 41.069457828998566, 34.24812465906143, 35.5352333933115, 37.530304938554764, 49.95420187711716, 48.8187962025404, 52.99357518553734, 51.515253111720085, 48.40048424899578, 49.042615592479706, 49.39086690545082, 48.744506388902664, 48.17079797387123, 45.37482440471649, 46.80857107043266, 45.68228870630264, 45.20408816635609, 43.67806725203991, 41.333650052547455, 38.93336825072765, 40.753204599022865, 42.24061198532581, 44.30684231221676, 44.8479712754488, 48.52877676486969, 49.04599741101265, 53.128604739904404, 49.76044647395611, 42.446401342749596, 27.884095050394535, 12.860859241336584, 5.197811862453818, 1.3292802963405848, 1.0516358446329832, 0.7265515916515142, 0.826838897773996, 0.11696093017235398, 0.29148954316042364, 0.12175625801319256, 0.06398467012331821, 0.06577187305083498, 0.3122970781987533, 0.36372470611240715, 1.4550200616940856, 9.928662031888962, 17.314149029552937, 22.811226658523083, 36.52683198451996, 36.11706577241421, 16.630567610263824, 4.233662048354745, 0.07913409353932366, 0.05240138132649008, 0.030245848211052362, 0.0327277143514948, 0.018806641819537617, 0.041507120986352675, 0.08257555848103948, 0.030238380350056104, 0.05613885557977483, 0.014278005673986627, 0.029100421197654214, 0.03411906312976498, 0.14701270119985566, 0.04919815321045462, 0.10988786205416545, 0.04875742881267797, 0.036323019085102715, 0.013221728222561069, 0.006169659172883257, 0.008628950108686695, 0.05230045295320451, 0.028105523997510318, 0.0373108139319811, 0.02761887364613358, 0.03346104160300456, 0.03903060016455129, 0.04352528398158029, 0.08434745090198703, 0.042289066332159564, 0.05366544806747697, 0.018610321494634263, 0.04072229981829878, 0.02721317119721789, 0.005403888008004287, 0.06200267198437359, 0.04224404023261741, 0.03682874819787685, 0.01264091788470978, 0.07203470144304447, 0.02878085240809014, 0.04218704329105094, 0.05489532035426237, 0.050452813229640014, 0.026884960097959265, 0.08104346881737001, 0.023869886827014852, 0.0688763361540623, 0.02264261947857449, 0.012697766396740917, 0.026453549653524533, 0.0892722538264934, 0.07254321360960603, 0.06836013533757068, 0.06414394985768013, 0.061162282509030774, 0.06856618521851487, 0.07023210637271404, 0.07294317183550447, 0.021881908833165653, 0.10211111919488758, 0.31442564679309726, 7.744406713172793, 30.26592504233122, 50.3373809158802, 39.50467899441719, 38.935420140624046, 30.845040567219257, 24.78755760937929, 9.66849284246564, 1.4376342133618891, 0.30619816796388477, 0.5856229132041335, 1.2233483931049705, 5.257120030000806, 4.965020203962922, 0.43414751475211233, 0.7451187015976757, 3.0182568915188313, 4.061383092775941, 6.971147730946541, 26.97683673352003, 40.69397337734699, 50.60683585703373, 55.97860001027584, 55.788321420550346, 53.54857340455055, 53.1414670497179, 53.38145077228546, 54.047900810837746, 53.62675800919533, 56.42991699278355, 54.21872824430466, 55.162905380129814, 54.29649867117405, 50.75092792510986, 48.2495753467083, 49.5835317671299, 50.73230892419815, 52.38691493868828, 53.33494506776333, 51.60870149731636, 50.82157373428345, 52.281292006373405, 54.628817439079285, 55.249567329883575, 50.855692103505135, 43.48921738564968, 37.11730509996414, 38.513433784246445, 38.201793506741524, 43.49964402616024, 47.1323174983263, 49.97786320745945, 49.664949998259544, 54.529156386852264, 47.83833861351013, 43.18672701716423, 36.441161781549454, 40.149143412709236, 52.19992317259312, 49.98995415866375, 52.91135899722576, 50.5243156850338, 52.781208381056786, 50.18961824476719, 42.636923119425774, 36.299208998680115, 37.32715643942356, 40.1563174277544, 51.90823182463646, 50.09400397539139, 54.28612902760506, 50.91984026134014, 48.93529415130615, 49.41975295543671, 50.10889157652855, 51.75424888730049, 49.354700446128845, 45.790525898337364, 49.33909088373184, 48.156301751732826, 48.917845487594604, 46.683417186141014, 43.65350157022476, 40.988411977887154, 43.44868876039982, 43.669377118349075, 46.2362951785326, 47.09557726979256, 51.14286169409752, 51.8768835067749, 55.59075102210045, 48.82030472159386, 44.680837243795395, 30.359097942709923, 15.19153542816639, 5.868783183395863, 3.306257212534547, 2.9270247370004654, 1.064783139154315, 1.8612519884482026, 0.9571605641394854, 0.16652777121635154, 0.04591310702380724, 0.06690364083624445, 0.18607384816277772, 0.39191349351312965, 0.10997257078997791, 1.1604022770188749, 11.48035816848278, 22.64725025743246, 25.815638042986393, 42.0414874702692, 39.36108469963074, 21.276519410312176, 5.1004249881953, 0.12779150682035834, 0.07732947240583599, 0.04466265869268682, 0.05319169438735116, 0.03215111755707767, 0.01903431231767172, 0.061187689934740774, 0.048432071271236055, 0.06481881442596205, 0.016607315010332968, 0.03454974998021498, 0.045840951715945266, 0.09360147581901401, 0.033839151001302525, 0.027027869909943547, 0.076116684358567, 0.04905054003756959, 0.10678834907594137, 0.021730659136665054, 0.04791900973941665, 0.03396022868400905, 0.05523835956410039, 0.013145827851985814, 0.030319114885060117, 0.07032293040538207, 0.05313147652486805, 0.02563030935561983, 0.05802787374705076, 0.19539786502718925, 0.17368450906360522, 0.08832793027977459, 0.06572709928150289, 0.09340430944575928, 0.0975501244829502, 0.21909078117460012, 0.12821647542295977, 0.18948481825646013, 0.09749612581799738, 0.15640131459804252, 0.10257966670906171, 0.10321355730411597, 0.20968769589671865, 0.12232146284077317, 0.17762880132067949, 0.13749306905083358, 0.12736057135043666, 0.11533611657796428, 0.22250491281738505, 0.11120303679490462, 0.08436507690930739, 0.26144488190766424, 0.22328378196107224, 0.3112132754176855, 0.10133999807294458, 0.207877671928145, 0.1465928682591766, 0.12590940546942875, 0.13144615368219092, 0.16010338469641283, 0.2844428806565702, 0.43789723073132336, 8.74139104038477, 37.581697180867195, 56.70374169945717, 49.006882309913635, 45.16894765198231, 31.196134127676487, 26.65055774152279, 12.313320972025394, 2.444748440757394, 0.9355190035421401, 4.66628878377378, 5.225844383239746, 14.258054718375206, 13.032181598246098, 0.7918924104887992, 2.0629715267568827, 4.197169756516814, 4.788989899680018, 7.192457355558872, 27.217779904603958, 41.24403566122055, 51.7938731610775, 58.444561287760735, 58.314897045493126, 55.31737469136715, 54.80586513876915, 56.13187238574028, 55.699858367443085, 55.59086501598358, 57.35346883535385, 55.482658222317696, 55.187721848487854, 56.71101450920105, 53.57546456158161, 51.84454724192619, 51.48489274084568, 52.05737002193928, 54.35360960662365, 54.52581636607647, 51.65580756962299, 52.81789541244507, 52.92280778288841, 56.439838260412216, 56.948843747377396, 52.942327335476875, 44.5479279756546, 38.892972618341446, 40.58168940246105, 39.87849913537502, 45.8036769926548, 50.25424897670746, 51.98816813528538, 52.73539423942566, 56.694451197981834, 49.3870747089386, 44.634943306446075, 40.82928031682968, 42.807055190205574, 50.39255015552044, 50.81952564418316, 52.559554874897, 52.16693714261055, 54.31522786617279, 52.523874789476395, 44.402091801166534, 38.11115317046642, 38.038755655288696, 41.68451942503452, 55.13045892119408, 52.58209526538849, 55.00607259571552, 50.65634720027447, 48.3594274520874, 49.70115065574646, 51.462147161364555, 53.64812046289444, 52.12940655648708, 47.212945371866226, 51.513349413871765, 50.234858617186546, 49.46272484958172, 47.871176451444626, 44.596842750906944, 42.70363613963127, 44.16851833462715, 45.25285094976425, 47.79763899743557, 50.34556947648525, 51.83484636247158, 52.88330130279064, 55.97389206290245, 51.295024529099464, 44.41424734890461, 30.7169646397233, 14.801028482615948, 7.459839507937431, 2.7738428441807628, 2.8096221992745996, 2.4073437228798866, 2.694496214389801, 2.137098186649382, 0.7637830032035708, 0.6035026162862778, 0.29953050543554127, 0.40654638956766576, 1.5390554023906589, 0.9909342206083238, 3.5996729554608464, 15.642960704863071, 30.27938012033701, 33.37766736745834, 48.54277141392231, 46.552062034606934, 24.202447906136513, 5.885515110567212, 0.14752120594494045, 0.15379962685983628, 0.19778483459958807, 0.14064473274629563, 0.13790481258183718, 0.15107270912267268, 0.17895000230055302, 0.11559433201909997, 0.1532278466038406, 0.22504561085952446, 0.08065152578637935, 0.23620944150025025, 0.229103154852055, 0.1545905930106528, 0.18431240518111736, 0.15627900866093114, 0.1129713594855275, 0.16104132577311248, 0.07803849061019719, 0.143340673239436, 0.11651751177851111, 0.17253496684134007, 0.0803646857093554, 0.042284134760848247, 0.16639045905321836, 0.1195162336807698, 0.14015176857355982, 0.20827350381296128], [0.012501102828537114, 0.013604884225060232, 0.0470153967035003, 0.019795180669461843, 0.08324009977513924, 0.016316170476784464, 0.03769158764043823, 0.054414494006778114, 0.021215172637312207, 0.02538054141041357, 0.012240918840689119, 0.04077975689142477, 0.022135773433547, 0.029667631679330952, 0.012617322227015393, 0.031767764885444194, 0.08395746714086272, 0.013234375346655725, 0.11732911705621518, 0.02294794645422371, 0.08323936504893936, 0.025208248116541654, 0.058951743703801185, 0.04216764726152178, 0.021184297438594513, 0.03617183247115463, 0.05394619140133727, 0.020929920756316278, 0.0417788286722498, 0.05688597935659345, 0.08005781506653875, 0.05117855944263283, 0.07709521349170245, 1.5981703740544617, 16.580636389553547, 39.871032536029816, 44.2085225880146, 28.138715587556362, 20.1566644012928, 23.714934065937996, 19.021690003573895, 5.042287157848477, 0.22497026802739128, 0.4501869884552434, 1.0426863748580217, 3.575702179223299, 3.0174674838781357, 0.24129258905304596, 0.9409843571484089, 1.0168902715668082, 1.455473187379539, 2.187908347696066, 11.943466868251562, 26.34698823094368, 40.51769703626633, 51.30558796226978, 53.37375998497009, 53.99677835404873, 52.82815866172314, 54.30583477020264, 55.43481878936291, 52.6943564414978, 52.957249134778976, 51.62304952740669, 52.28726148605347, 53.589934185147285, 49.28270950913429, 50.557506904006004, 48.760765716433525, 51.38434253633022, 51.03770613670349, 52.08692863583565, 51.9165875762701, 52.981738820672035, 53.03986430168152, 52.901388332247734, 51.965114772319794, 45.77773578464985, 41.081848964095116, 40.07832281291485, 39.879228696227074, 36.98256053030491, 41.43937937915325, 47.60677143931389, 50.433663949370384, 49.509044364094734, 54.34213802218437, 47.17469282448292, 55.411560237407684, 35.43162055313587, 38.54297339916229, 54.70948711037636, 44.953039437532425, 53.082437217235565, 49.06367026269436, 52.13810048997402, 48.831400126218796, 44.7250022739172, 35.46378202736378, 35.866093039512634, 38.76582384109497, 49.06253792345524, 46.108819618821144, 53.095033541321754, 52.79294595122337, 46.62159450352192, 50.48550456762314, 50.6934180110693, 49.6915827691555, 46.88632629811764, 45.37122219800949, 40.27013272047043, 41.7204312980175, 40.607444420456886, 40.368281453847885, 39.23648938536644, 41.62070944905281, 43.7662111222744, 46.52748115360737, 45.791057869791985, 48.36852416396141, 48.37959297001362, 51.19844131171703, 51.37933440506458, 44.35034237802029, 31.090923473238945, 16.75495393574238, 7.207981897518039, 1.5302348881959915, 1.5629259590059519, 1.9606894464232028, 2.1851112227886915, 1.1676534754224122, 0.9612926049157977, 0.10165020838030614, 0.04998502270609606, 0.08212278160499409, 0.024564713312429376, 0.10395943798357621, 0.8004947332665324, 7.0780307706445456, 14.011244662106037, 18.98282378911972, 25.534536726772785, 31.804779767990112, 25.192292891442776, 7.279306445270777, 0.42116521450225264, 0.061024781098240055, 0.052557766684913076, 0.07357519221841358, 0.05077309448097367, 0.07666884222999215, 0.09963939635781571, 0.03217002005840186, 0.017613364834687673, 0.031713565840618685, 0.060278306700638495, 0.010449157271068543, 0.020729433272208553, 0.03742652217624709, 0.07343332326854579, 0.04538995970506221, 0.07701522481511347, 0.027262076873739716, 0.034165005781687796, 0.02388608976616524, 0.058905622936435975, 0.028159903013147414, 0.07131020945962518, 0.021769818558823317, 0.018435386155033484, 0.04065525048645213, 0.05863371115992777, 0.02613481949083507, 0.026589320004859474, 0.045746172036160715, 0.041261815204052255, 0.04233348758134525, 0.004434285519892001, 0.06200136209372431, 0.03651668252132367, 0.021058733473182656, 0.011622980709944386, 0.032323870982509106, 0.0308260499878088, 0.013051666937826667, 0.004554772267510998, 0.006359743601933587, 0.012757618751493283, 0.030489849668811075, 0.008952602565841516, 0.0658133219985757, 0.03391873149666935, 0.02884392197302077, 0.11672295309836045, 0.05809353526274208, 0.007883276302891318, 0.06006406350934412, 0.05941354138485622, 0.03179457868100144, 0.026027632957266178, 0.06408261135220528, 0.013172034014132805, 0.03418388972932007, 0.06638528037001379, 0.07146418283809908, 0.04416413954459131, 0.10859600559342653, 2.4501056782901287, 20.443809293210506, 46.044086292386055, 46.48545540869236, 33.079166784882545, 20.40787272155285, 25.329552926123142, 20.754435025155544, 4.431555904448032, 0.30408174090553075, 0.3775181440869346, 0.6545528769493103, 1.6853633453138173, 4.14967468008399, 2.5779263069853187, 0.4601510928478092, 0.7841019378975034, 1.1964672105386853, 2.74992645252496, 14.148856177926064, 29.11079842597246, 43.70392486453056, 55.607682913541794, 54.676212295889854, 56.503541842103004, 53.88744682073593, 57.46431648731232, 57.56244242191315, 54.73794758319855, 54.898944944143295, 53.04629735648632, 55.179594084620476, 55.50928719341755, 52.247804403305054, 51.048763543367386, 50.66931210458279, 53.081829249858856, 53.367475122213364, 52.78134897351265, 51.07613727450371, 53.55156384408474, 55.08658267557621, 53.688189312815666, 52.75853119790554, 47.87778049707413, 42.61892348527908, 40.88199108839035, 41.48513652384281, 39.01086509227753, 44.144374430179596, 48.139544650912285, 51.70062616467476, 50.95222972333431, 55.321444272994995, 48.04746799170971, 55.972033962607384, 37.05514423549175, 39.733742102980614, 53.50851595401764, 46.72475516796112, 53.68925325572491, 51.622023582458496, 53.907524943351746, 51.63417913019657, 45.21050602197647, 37.518145591020584, 37.787072360515594, 41.57472811639309, 51.57891109585762, 48.973626494407654, 55.25200679898262, 53.72066617012024, 48.26453894376755, 51.75015650689602, 52.168175876140594, 51.920626759529114, 49.11055974662304, 46.28427140414715, 42.31960594654083, 43.85191932320595, 43.195888325572014, 42.804672718048096, 40.49454487860203, 43.64326111972332, 45.269421860575676, 47.73756042122841, 48.5149797052145, 51.01405620574951, 49.92674835026264, 53.10927517712116, 51.76112271845341, 45.97269952297211, 33.228658363223076, 19.403930492699146, 9.916860815137625, 2.679009670391679, 3.6083419527858496, 6.3980273343622684, 1.9063336006365716, 0.9965596999973059, 1.2721837288700044, 0.19108506676275283, 0.15146880818065256, 0.1144140055112075, 0.15523663256317377, 0.08541782081010751, 0.9760285110678524, 6.45837189629674, 15.12552822008729, 23.0471009016037, 29.58612062036991, 37.07384303212166, 30.325604639947414, 10.765588022768497, 1.4363507134839892, 0.060180899818078615, 0.0098447883829067, 0.019459485010884237, 0.010800930631376104, 0.0896352382551413, 0.0651950684550684, 0.05678165194694884, 0.04768240192788653, 0.032777230444480665, 0.08672979689436033, 0.034714922367129475, 0.04000622750027105, 0.041941937888623215, 0.04876904342381749, 0.05060058967501391, 0.07284223233000375, 0.026560758451523725, 0.021501693590835202, 0.04354337383119855, 0.062409996025962755, 0.027013158687623218, 0.061163340069469996, 0.024002929785638116, 0.04084243868419435, 0.060058475137338974, 0.0743689933733549, 0.04975875301170163, 0.01688978012680309, 0.09610609806259163, 0.11804920810391195, 0.1641707101953216, 0.13034957111813128, 0.17201072856551036, 0.1300828135572374, 0.10975265759043396, 0.08521819792804308, 0.18897181609645486, 0.11018431294360198, 0.09236548823537305, 0.16059496847447008, 0.060391651204554364, 0.12512917077401653, 0.18023699027253315, 0.10997850054991432, 0.22521262377267703, 0.22000936703989282, 0.15615564887411892, 0.18706801434746012, 0.16544582380447537, 0.1092934982443694, 0.11813836972578429, 0.13616254669614136, 0.13035362324444577, 0.17334778181975707, 0.17113085312303156, 0.08975814533187076, 0.13756781816482544, 0.17499344976386055, 0.21515319793252274, 0.21387459622928873, 0.263182160560973, 3.5164963686838746, 24.286632388830185, 52.18362584710121, 54.075487330555916, 40.72401836514473, 27.504392825067043, 31.831159852445126, 22.99561556428671, 5.226175440475345, 0.6634567491710186, 1.4037415757775307, 4.624676266685128, 9.201255664229393, 11.148140095174313, 3.9084059139713645, 1.240294415038079, 8.118272926658392, 4.090373637154698, 3.751400951296091, 14.16234165430069, 29.30606234818697, 43.76764364540577, 56.210923343896866, 56.029395684599876, 58.80161672830582, 55.762121826410294, 58.777279034256935, 58.123831897974014, 56.2136135995388, 53.90626721084118, 54.101238548755646, 56.64549462497234, 56.26468665897846, 55.84648869931698, 53.39258797466755, 51.90992273390293, 56.451902613043785, 54.45628769695759, 53.604631796479225, 52.58696660399437, 54.72663179039955, 56.04578420519829, 56.78566910326481, 56.242925226688385, 49.89734172821045, 44.53286558389664, 44.32362601161003, 43.44534493982792, 40.4181157797575, 45.90567111968994, 52.25891500711441, 54.32910092175007, 53.17146264016628, 57.1977835893631, 47.498310059309006, 53.30823250114918, 41.48072496056557, 41.838977336883545, 54.33354288339615, 45.70195645093918, 54.22606185078621, 52.86030113697052, 56.781181544065475, 54.05734710395336, 48.69575120508671, 40.184994488954544, 40.091105327010155, 44.007779359817505, 53.36028590798378, 50.7586795091629, 57.161472737789154, 53.15172269940376, 47.21617139875889, 52.55623385310173, 52.05426178872585, 54.561587646603584, 50.15548847615719, 48.450660556554794, 44.042741283774376, 45.60381531715393, 45.99213927984238, 45.25042288005352, 43.347788974642754, 46.320760846138, 46.30865089595318, 49.487693309783936, 51.095094457268715, 51.839284524321556, 52.578781843185425, 55.360289588570595, 53.261384814977646, 45.30284866690636, 33.62703278660774, 18.184437230229378, 10.645770002156496, 2.9718981916084886, 4.422639207914472, 7.365286331623793, 4.384287865832448, 2.3514788830652833, 1.6489921719767153, 0.700684895273298, 0.3277334530139342, 0.2563606359763071, 0.30782828049268574, 0.3331084724050015, 1.8494052928872406, 9.166024904698133, 21.667590625584126, 32.279066517949104, 36.25099718570709, 43.78105692565441, 34.055125415325165, 11.369850598275661, 1.3359219837002456, 0.16104119218653068, 0.12770399276632816, 0.22454887657659128, 0.1350036237272434, 0.18299492978258058, 0.22349974693497643, 0.16395431477576494, 0.11472774102003314, 0.08816101384581998, 0.25516310648526996, 0.07008853048318997, 0.11635747505351901, 0.1380070360028185, 0.11563728010514751, 0.13654838927323, 0.23271777026820928, 0.13244267989648506, 0.1007888421008829, 0.1692188877495937, 0.15979459189111367, 0.1444738733698614, 0.2834736061049625, 0.13892428600229323, 0.1485000690445304, 0.1511621824465692, 0.15817929262993857, 0.13390298903686926, 0.08759111864492297], [0.03278307485743426, 0.0674423880991526, 0.024281275982502848, 0.04266996620572172, 0.04161104392551351, 0.034648719083634205, 0.011969866100116633, 0.062328678905032575, 0.0826278724707663, 0.042238080786773935, 0.036422559642232955, 0.030228029245336074, 0.02740168598393211, 0.06716696225339547, 0.07724606242845766, 0.06034699246811215, 0.06016726285452023, 0.05020665397751145, 0.05244673397100996, 0.030659469375677872, 0.03896807051205542, 0.09827077214140445, 0.04494663036894053, 0.0165243354786071, 0.040198955830419436, 0.011192897782166256, 0.01759216724167345, 0.03764734821743332, 0.02676361153135076, 0.08382971383980475, 0.07401443232083693, 0.046671129239257425, 0.01751983381836908, 0.052960322427679785, 6.473032934591174, 26.312360689044, 48.443440943956375, 36.26604437828064, 26.51059415191412, 23.801301531493664, 22.885550670325756, 9.467077050358057, 1.1958192265592515, 0.14077972940867767, 0.6028484576381743, 2.064202898181975, 1.182751371525228, 2.0179997524246573, 0.36809067183639854, 0.6251432269345969, 0.987403616309166, 0.11877468714374118, 2.887138989754021, 14.660986047238111, 29.79497641324997, 42.569617331027985, 52.141892686486244, 53.970259577035904, 55.5022157728672, 53.759009912610054, 53.486268147826195, 52.38771669566631, 49.559140875935555, 51.648983135819435, 53.36274437606335, 55.107998326420784, 50.77084265649319, 49.991622269153595, 51.90511219203472, 52.20900848507881, 54.6786517649889, 51.67973108589649, 54.99682769179344, 53.32126200199127, 52.6518215239048, 49.37632128596306, 46.2444419413805, 40.22178411483765, 39.711045920848846, 40.76256349682808, 40.85806377232075, 38.083817437291145, 45.14680244028568, 46.82825781404972, 53.11154745519161, 49.2986686527729, 51.61750942468643, 46.084603518247604, 53.92257213592529, 34.36411343514919, 39.25537817180157, 50.714373886585236, 42.87265487015247, 52.25482262670994, 50.336909741163254, 50.69416657090187, 47.91152648627758, 41.53688594698906, 33.45907419919968, 34.71722088754177, 39.62171271443367, 49.93083693087101, 50.68917743861675, 46.85793422162533, 45.696097165346146, 48.62466461956501, 49.17197585105896, 49.35830645263195, 51.386804804205894, 47.447449788451195, 46.45587019622326, 45.82025550305843, 43.995885998010635, 42.752174735069275, 40.63723482191563, 39.421391263604164, 42.6279404014349, 44.71423365175724, 48.35658900439739, 49.05947908759117, 50.96146322786808, 51.21731489896774, 51.18598937988281, 46.72863855957985, 34.50636640191078, 22.143116109073162, 8.365572206676006, 2.209922466427088, 0.8851831045467407, 3.861498855985701, 8.263557180762291, 0.4888702486641705, 0.7029783690813929, 0.8898585161659867, 0.11060413846280426, 0.043128505858476274, 0.06725500323227607, 0.08442776612355374, 0.2522889169631526, 2.7389160683378577, 7.84901462495327, 16.96349624544382, 26.43084403127432, 31.1019029840827, 30.007977783679962, 18.571246974170208, 3.374871318228543, 0.07912242697784677, 0.03814550000242889, 0.041258453275077045, 0.06749464271706529, 0.06669131980743259, 0.05048636572610121, 0.0439145812561037, 0.004979542345608934, 0.030179787790984847, 0.033539816868142225, 0.12987349822651595, 0.04020461841719225, 0.06614262034418061, 0.03405392111744732, 0.035252159359515645, 0.04483407254156191, 0.030482313159154728, 0.05176696751732379, 0.02070936930977041, 0.019056925557379145, 0.02926309811300598, 0.01147188964750967, 0.051647852815221995, 0.04722254125226755, 0.15146628487855196, 0.015775649480929133, 0.011951376418437576, 0.03440299398789648, 0.04012476703792345, 0.03544949271599762, 0.03300154086900875, 0.031493404021603055, 0.06150109147711191, 0.05090808372187894, 0.016563162789680064, 0.03889001141942572, 0.09555900905979797, 0.049585064480197616, 0.021406271953310352, 0.044152684495202266, 0.022518836667586584, 0.008673844477016246, 0.025082956890400965, 0.04428696869581472, 0.04350828137830831, 0.025092929499805905, 0.033822946206782945, 0.029354382277233526, 0.04190302708593663, 0.017815869105106685, 0.0949545149342157, 0.08446321109659038, 0.0386638716008747, 0.020736082915391307, 0.026659504910639953, 0.04215745015244465, 0.03263072307163384, 0.03437439903791528, 0.09222039094311185, 0.07767166185658425, 0.05379822199756745, 0.028305798114161007, 0.26559425925370306, 8.339387811720371, 32.845946699380875, 54.86304447054863, 38.59226815402508, 25.27332354336977, 25.073347873985767, 26.57657951116562, 11.193943787366152, 1.8476633238606155, 0.19951576046878472, 0.25269522797316313, 0.4665281600318849, 2.0000675646588206, 3.4274661960080266, 0.5558809591457248, 1.3976154732517898, 0.991528294980526, 0.3533646807773039, 4.645793158560991, 18.452030271291733, 34.62068326771259, 47.24011391401291, 53.84716138243675, 57.02490046620369, 59.01594802737236, 57.6105098426342, 56.56593829393387, 54.03630383312702, 51.72137305140495, 54.32822696864605, 54.23108518123627, 56.5279745310545, 52.74868592619896, 51.732118874788284, 53.81948746740818, 54.441251903772354, 53.68076831102371, 53.30315977334976, 57.647447660565376, 55.900525599718094, 54.48152594268322, 53.217512369155884, 49.78283107280731, 43.770273104310036, 41.78775228559971, 42.16279596090317, 43.2425270229578, 40.59411473572254, 46.46617144346237, 48.18832263350487, 54.16709661483765, 50.61052925884724, 51.98620744049549, 47.12240383028984, 52.6730851829052, 37.88028135895729, 41.76729418337345, 51.87266953289509, 43.50744880735874, 53.54574255645275, 52.42930926382542, 52.21358723938465, 48.97207237780094, 43.171657025814056, 35.7733666151762, 36.11643500626087, 41.72320894896984, 51.40175320208073, 52.01256662607193, 50.77155701816082, 45.86923107504845, 48.05914096534252, 50.082501992583275, 49.69100899994373, 52.673237174749374, 49.3103264272213, 47.32486456632614, 45.82454927265644, 45.33562570810318, 43.0766811221838, 42.31466241180897, 41.20989069342613, 44.116993099451065, 45.69380968809128, 51.03392913937569, 50.347921550273895, 53.44840317964554, 52.721585780382156, 53.144685477018356, 47.90450066328049, 37.82121352851391, 25.869000479578972, 12.75358434766531, 2.7030820911750197, 2.8615150647237897, 5.494134211912751, 5.71769236586988, 0.609650983242318, 0.8568747423123568, 0.6808284076396376, 0.07340627198573202, 0.07800717939971946, 0.2567528758663684, 0.0766818891861476, 0.3379172628046945, 2.8356047300621867, 9.61446164175868, 18.456363938748837, 30.21427061408758, 35.23370437324047, 34.32177230715752, 21.647801287472248, 4.270492047071457, 0.04845754177949857, 0.050898658446385525, 0.03860031778458506, 0.042259298788849264, 0.023779482107784133, 0.02082588463963475, 0.01357656479740399, 0.02522581289667869, 0.04065664572408423, 0.04871028017078061, 0.05763755973021034, 0.02254143877507886, 0.028666179459833074, 0.0374287115118932, 0.0373467561439611, 0.06394346608431078, 0.018756756508082617, 0.04043802015075926, 0.03330529449158348, 0.06105470078182407, 0.08216024521971121, 0.04267991469532717, 0.03542995938914828, 0.023106101834855508, 0.022065135817683768, 0.0283088316427893, 0.022888646999490447, 0.037978661493980326, 0.017213501232618, 0.10846774763194844, 0.15895741962594911, 0.11769060976803303, 0.14345751696964726, 0.13442547584418207, 0.14530023996485397, 0.11468716780655086, 0.1613718635053374, 0.13231106742750853, 0.05158901163667906, 0.12155193733633496, 0.12874106992967427, 0.1023073801479768, 0.14524561789585277, 0.17853849625680596, 0.1256834066589363, 0.1549843468819745, 0.19256165862316266, 0.12413310469128191, 0.2152684237807989, 0.1021104512619786, 0.2592990954872221, 0.18369038152741268, 0.18814286682754755, 0.12245320147485472, 0.1087504242605064, 0.15452886116690934, 0.10025515628512949, 0.2306792390299961, 0.20999303029384464, 0.2015547369956039, 0.11075994494603947, 0.11587040353333578, 0.36901746585499495, 10.112272929400206, 39.55629542469978, 62.35501125454903, 46.53774440288544, 35.54980181157589, 34.17617931962013, 30.71137323975563, 12.24511843174696, 2.4529645498842, 0.32331675407476723, 1.5182898729108274, 7.022875305265188, 7.27341391146183, 5.029978668317199, 0.8261716773267835, 3.7769225193187594, 1.7628724174574018, 0.47720487462356687, 4.753625672310591, 18.063869699835777, 34.376386776566505, 46.91406100988388, 54.66693699359894, 56.258986964821815, 59.39107149839401, 57.80871480703354, 55.34659892320633, 53.81703659892082, 52.98125624656677, 53.519824147224426, 56.49209685623646, 59.77796673774719, 54.510514587163925, 54.33820143342018, 55.7575848698616, 55.77523112297058, 56.18252366781235, 54.196738824248314, 59.53063800930977, 58.769774436950684, 55.74305824935436, 56.325247809290886, 49.59559611976147, 44.775531962513924, 43.89751687645912, 45.37471041083336, 45.64144089818001, 42.10304416716099, 48.7312451004982, 50.823903009295464, 55.45143149793148, 52.8510220348835, 51.74659989774227, 47.73317165672779, 51.8791975826025, 41.761294305324554, 43.061044961214066, 50.64970135688782, 44.9773733317852, 55.66143102943897, 54.28977683186531, 54.112641736865044, 50.354833379387856, 44.55170877277851, 37.58514739573002, 37.75050312280655, 44.61625210940838, 53.2891271263361, 54.97489146888256, 51.85566924512386, 48.10442313551903, 49.30311821401119, 50.06360560655594, 52.23709277808666, 54.17325608432293, 51.33208014070988, 49.77474890649319, 49.41104382276535, 49.05546650290489, 45.98363533616066, 43.2404675334692, 42.00394548475742, 46.211277320981026, 48.775736913084984, 53.03971990942955, 53.33094388246536, 55.78419104218483, 55.71492075920105, 53.64401288330555, 49.95602957904339, 38.377199694514275, 27.14290302246809, 11.447710320353508, 3.9123125793412328, 2.8630841430276632, 9.542197119444609, 14.624024480581284, 3.1555827101692557, 1.973461511079222, 2.015195027925074, 0.328152944566682, 0.1496393547859043, 0.5152835219632834, 0.11453354323748499, 0.7425417273771018, 3.5337602673098445, 10.89771643280983, 25.023239962756634, 35.76237000524998, 41.1759927123785, 41.27552077174187, 24.6108290925622, 5.430841958150268, 0.31210471352096647, 0.15429391205543652, 0.11332946058246307, 0.25047038798220456, 0.13468852266669273, 0.130863449012395, 0.1951467667822726, 0.0693758089619223, 0.16954647173406556, 0.1258983919979073, 0.20421493565663695, 0.07826661196304485, 0.170585953455884, 0.11867663459270261, 0.11045723033021204, 0.11934597016079351, 0.1578320120461285, 0.12487991305533797, 0.1969430164899677, 0.11751832760637626, 0.21027777751442045, 0.10400617844425142, 0.1991974384873174, 0.06866587791591883, 0.2375993801979348, 0.08177135241567157, 0.1543361254152842, 0.1491043553687632, 0.18798542761942372], [0.08421786449616775, 0.025363596323586535, 0.025035238650161773, 0.13865770655684173, 0.007979015208547935, 0.027544170916371513, 0.05486875888891518, 0.06495946625364013, 0.03588463616324589, 0.07305005594389513, 0.018573544366518036, 0.03426690265769139, 0.0403639575233683, 0.07024553924566135, 0.04738938718219288, 0.03274771152064204, 0.034181770897703245, 0.031992038202588446, 0.04341009152994957, 0.05793333155452274, 0.05792429961729795, 0.03900127419910859, 0.004921447953165625, 0.07991503327502869, 0.0394664412306156, 0.018736291785899084, 0.03796292054175865, 0.03211262977856677, 0.06713214810588397, 0.06932665652129799, 0.01494247182563413, 0.06224631906661671, 0.04702036167145707, 0.06618123428779654, 1.1853994731791317, 11.466987635940313, 37.312477827072144, 43.44146154820919, 33.056425005197525, 19.897227622568607, 19.91656668484211, 13.369778282940388, 2.3891149135306478, 0.25643826462328434, 0.11822329368442297, 0.033197000302607194, 2.855845056474209, 2.529657972045243, 0.615872674388811, 0.536932444665581, 0.8926631812937558, 0.07091979525284842, 1.2570696836337447, 5.430079624056816, 15.513132121413946, 27.574542760849, 38.21761205792427, 48.8495821505785, 53.63858297467232, 54.44571666419506, 54.21114005148411, 53.67289513349533, 52.63935439288616, 54.384760335087776, 53.904283717274666, 53.09347182512283, 56.12260468304157, 51.72407850623131, 53.358720391988754, 53.2519157230854, 52.71179370582104, 52.94420063495636, 49.949801713228226, 49.111885875463486, 49.00957256555557, 43.6344113945961, 41.133659183979034, 39.04551923274994, 40.17962537705898, 40.75272582471371, 39.54771168529987, 38.42451475560665, 43.7993111461401, 48.37642773985863, 52.6095449924469, 52.46340483427048, 53.24965484440327, 46.27659201622009, 54.023863300681114, 36.831796020269394, 39.81326423585415, 54.093733951449394, 52.49025039374828, 51.1862363666296, 48.85788090527058, 47.95968510210514, 46.28197252750397, 40.3676088899374, 37.57774539291859, 34.928105771541595, 41.44718796014786, 47.860552221536636, 52.218108996748924, 50.921610966324806, 49.80845309793949, 52.27361261844635, 47.81074449419975, 50.800355672836304, 51.76124431192875, 49.17928285896778, 47.60245107114315, 46.30632162094116, 45.95879226922989, 44.56926003098488, 44.64318126440048, 42.78831459581852, 42.5324971228838, 47.0611435174942, 46.287831813097, 50.27102887630463, 51.59314513206482, 48.786741122603416, 47.72752895951271, 35.18749885261059, 20.177352391183376, 7.800807086750865, 2.961245463229716, 2.5763182807713747, 3.4995464282110333, 4.230545740574598, 3.211599779315293, 0.854938686825335, 0.23981302860192955, 0.6078560545574874, 0.1010700938059017, 0.294060877058655, 0.032988545863190666, 0.21475867222761735, 0.33966662362217903, 5.929790334776044, 18.190786689519882, 24.489288814365864, 28.709351867437363, 35.06982296705246, 28.066538460552692, 11.780880242586136, 1.0211269254796207, 0.060992968938080594, 0.121336187585257, 0.017660431840340607, 0.01561516932270024, 0.027286597432976123, 0.06845956828328781, 0.021639679252984934, 0.05691900121746585, 0.025366915579070337, 0.014247787275962764, 0.04855545332247857, 0.046166735992301255, 0.10855261964024976, 0.03054415818041889, 0.0005797608946522814, 0.023752983724989463, 0.02757596637820825, 0.02507650206098333, 0.015849174051254522, 0.009355046058772132, 0.0410872954671504, 0.018034149579762015, 0.011647441897366662, 0.043128494726261124, 0.10081005268148147, 0.031864540942478925, 0.024503693930455483, 0.020186494730296545, 0.0649309455184266, 0.06567397635080852, 0.023315953367273323, 0.03458741768554319, 0.11139157199067995, 0.055340590406558476, 0.007697067276239977, 0.02003658089961391, 0.04091452719876543, 0.019551693148969207, 0.0657091689936351, 0.04228157064062543, 0.028887996268167626, 0.04294797843613196, 0.088000465038931, 0.0451455593429273, 0.02691025805688696, 0.04203345954010729, 0.06108446832513437, 0.10894456267124042, 0.058305106722400524, 0.051331809227121994, 0.05009652297303546, 0.018854415720852558, 0.04277780026313849, 0.03651360631920397, 0.04114075607503764, 0.04292709068977274, 0.07289206754649058, 0.050665390299400315, 0.03671805687190499, 0.029224163190519903, 0.03644540294772014, 0.029217981100373436, 0.05359476592275314, 1.53783816145733, 15.996843315660954, 44.81402389705181, 48.01500253379345, 33.23324091732502, 19.524908401072025, 23.221798427402973, 16.558835059404373, 3.1539516476914287, 0.5497493944130838, 0.026006080988736358, 0.18409909709589556, 0.14368492586072534, 0.9957476716954261, 0.12410694398568012, 0.6369203981012106, 1.2493438669480383, 0.11432467319536954, 1.514974432066083, 6.249364111572504, 17.385896779596806, 30.014388039708138, 43.029419258236885, 51.947194933891296, 54.12206523120403, 54.80009324848652, 55.032401382923126, 53.970183581113815, 54.08500961959362, 54.39695008099079, 55.37090241909027, 54.90697391331196, 56.34006321430206, 51.86555251479149, 54.39929835498333, 53.30318637192249, 54.77317929267883, 53.539640083909035, 53.38553935289383, 52.39242844283581, 50.965730398893356, 46.54077664017677, 43.218888491392136, 41.42636887729168, 41.73829033970833, 42.007779479026794, 41.255769431591034, 41.186252161860466, 46.63373485207558, 50.43758533895016, 54.16869252920151, 54.02047388255596, 55.0599081069231, 46.27251483500004, 54.46104124188423, 39.416041150689125, 41.44304618239403, 51.990482211112976, 53.78045216202736, 53.2366481423378, 51.08579255640507, 49.5317367464304, 47.81031891703606, 41.89312823116779, 39.38229516148567, 37.834862396121025, 43.207910880446434, 49.6273510158062, 54.99307729303837, 51.61146014928818, 50.371510684490204, 52.19072766602039, 50.01116842031479, 50.70119999349117, 51.57061994075775, 51.421010568737984, 49.72731605172157, 48.30736644566059, 47.42415703833103, 45.972053557634354, 44.22658681869507, 43.127989768981934, 44.717444479465485, 49.2809996008873, 49.451667442917824, 52.069639563560486, 52.61238344013691, 49.90666642785072, 48.49608711898327, 38.707276582717896, 23.458483926951885, 10.33425036817789, 4.0140181593596935, 2.0314605301246047, 2.2515675192698836, 4.047632105648518, 3.6436126101762056, 0.2983751893043518, 0.2596733160316944, 0.641329645877704, 0.07776293859933503, 0.2852083317702636, 0.09907018393278122, 0.35070797021035105, 0.399696544627659, 6.665773317217827, 16.589087136089802, 26.70137621462345, 30.908751748502254, 39.73965838551521, 32.337651774287224, 15.235713757574558, 1.6882314789108932, 0.034921039041364565, 0.03817969816736877, 0.03154051926685497, 0.06721752477460541, 0.074526328680804, 0.04248742385243531, 0.03313087123387959, 0.04100549966096878, 0.03882695484207943, 0.028325537386990618, 0.08055223384872079, 0.015240534103213577, 0.08932887969422154, 0.050605439610080793, 0.030944611789891496, 0.09826988156419247, 0.012883447107014945, 0.03256493539083749, 0.059414940333226696, 0.04495187364227604, 0.06172540561237838, 0.036357881472213194, 0.057345194363733754, 0.01940498910698807, 0.011389254286768846, 0.04827332217246294, 0.05070122118922882, 0.00581282993152854, 0.06216150271939114, 0.1557013060664758, 0.12093143508536741, 0.13037431432167068, 0.2868855855194852, 0.15680517652072012, 0.11405091718188487, 0.12070210403180681, 0.14117001002887264, 0.17157424183096737, 0.1619274797849357, 0.12837694259360433, 0.12002509465673938, 0.14464245963608846, 0.1968944355030544, 0.16500437952345237, 0.14714812830789015, 0.12853500520577654, 0.10957017831970006, 0.21952003939077258, 0.16158656682819128, 0.13100885058520362, 0.1200408281874843, 0.17103521997341886, 0.11799004409112968, 0.09303874234319665, 0.07132207640097477, 0.19247191812610254, 0.16791319765616208, 0.0969911611173302, 0.11357046561897732, 0.13694119319552556, 0.1438610375043936, 0.18055688560707495, 0.10645610440406017, 1.9942120788618922, 20.932415574789047, 51.79261922836304, 57.989938482642174, 43.96388031542301, 29.66878328472376, 30.591863952577114, 18.268490619957447, 3.7875289376825094, 0.7483653898816556, 0.4516392824007198, 0.4091616882942617, 5.577564910054207, 5.183481881394982, 1.5925593813881278, 0.8665072254370898, 2.7375151310116053, 0.3506980848032981, 2.1798413805663586, 6.499961139634252, 18.913811892271042, 30.404856987297535, 42.24306285381317, 51.59134402871132, 54.70919452607632, 54.002006873488426, 55.14580249786377, 54.96983394026756, 54.11647953093052, 53.31507973372936, 56.45102486014366, 54.71168339252472, 60.31862832605839, 53.79517637193203, 56.18783578276634, 56.78443416953087, 56.824126839637756, 55.150069668889046, 54.93984594941139, 54.41035196185112, 52.464654967188835, 47.46543802320957, 45.02603732049465, 44.287432953715324, 43.017199113965034, 43.09523932635784, 42.74934768676758, 43.59712019562721, 47.96455264091492, 52.843608632683754, 56.01742632687092, 55.683933421969414, 56.676075384020805, 48.308149203658104, 52.646338418126106, 42.63580597937107, 43.688843473792076, 52.53183536231518, 55.23178048431873, 54.40723612904549, 53.6266478151083, 51.908759996294975, 50.804782435297966, 42.87591129541397, 41.79371036589146, 40.392991527915, 45.200451761484146, 50.928074419498444, 56.245463490486145, 53.3692192286253, 49.7954235970974, 52.2513572126627, 50.409105867147446, 50.99288374185562, 53.976563438773155, 52.109993398189545, 51.41123749315739, 49.42335896193981, 49.058050364255905, 48.97288553416729, 48.4425213932991, 45.201591700315475, 46.78739480674267, 52.15055242180824, 51.411989852786064, 53.67302052676678, 55.36794237792492, 51.17819979786873, 50.172952339053154, 40.303958505392075, 23.302304707467556, 10.597242806106806, 4.581178575754166, 5.978509420529008, 9.06921274960041, 5.766457999125123, 8.181743770837784, 3.1244414811953902, 1.2385026924312115, 2.0698208967223763, 0.37309657665900886, 0.7334990438539535, 0.13969393767183647, 0.5292539473157376, 0.6147487659472972, 8.609577063471079, 23.821704536676407, 34.306580722332, 41.48777358233929, 45.26149168610573, 36.80978760123253, 16.367095448076725, 1.930307107977569, 0.17321486317086965, 0.21873925550607964, 0.13788824784569442, 0.13352486479561776, 0.15570958843454719, 0.1819656600127928, 0.18096571991918609, 0.19811019214102998, 0.12233456916874275, 0.16547282313695177, 0.2421304737799801, 0.14986139052780345, 0.13566768262535334, 0.15007348149083555, 0.14945613336749375, 0.19110016204649583, 0.08485025595291518, 0.12475414871005341, 0.15461165516171604, 0.17975296155782416, 0.13527299364795908, 0.09275003205402754, 0.1419366040499881, 0.18802826438331977, 0.2558925189077854, 0.16374924452975392, 0.13913711911300197, 0.07989322897628881, 0.15626492269802839], [0.025000778878165875, 0.05928086022322532, 0.07871400826843455, 0.035761580656981096, 0.050773858893080615, 0.06979561963817105, 0.051161282244720496, 0.06030495722370688, 0.06316147249890491, 0.02380996767897159, 0.008667424899613252, 0.026396908942842856, 0.01671504145633662, 0.019239215580455493, 0.021338916485547088, 0.045334743917919695, 0.0459561181924073, 0.11285424116067588, 0.04160288401180878, 0.02600458185042953, 0.04446472419658676, 0.03742330125533044, 0.017855540609161835, 0.029146879642212298, 0.03456042948528193, 0.03364015152328648, 0.08786057762335986, 0.04507288082095329, 0.060332390712574124, 0.06151094719825778, 0.01737038382998435, 0.05244439991656691, 0.017808386401156895, 0.017449416991439648, 0.03019943986146245, 5.913640726357698, 26.166176833212376, 46.59889832139015, 35.22260516881943, 21.653449684381485, 21.096526868641376, 16.004716493189335, 9.355085659772158, 1.2882664846256375, 0.15020107151940465, 0.2591765223769471, 0.111995850893436, 0.6079476652666926, 0.47186348936520517, 1.0047724843025208, 3.1651890696957707, 0.34177313558757305, 0.36269318021368235, 0.8965468697715551, 5.427313847467303, 13.692003842443228, 23.63260768353939, 34.90677371621132, 43.0208545178175, 54.45985570549965, 54.593410938978195, 53.44389662146568, 54.093365371227264, 54.16563369333744, 55.527275428175926, 52.85310052335262, 58.247367069125175, 54.569734409451485, 52.38019309937954, 51.43633894622326, 51.22393414378166, 49.247227013111115, 48.66453967988491, 45.82547262310982, 43.08790571987629, 41.19496889412403, 42.21413500607014, 40.486987084150314, 43.758619129657745, 41.37646235525608, 44.30800125002861, 41.259740218520164, 42.43123635649681, 45.317417085170746, 51.23855955898762, 50.213059186935425, 53.44163194298744, 50.765112563967705, 52.51912124454975, 36.679013818502426, 40.548327192664146, 53.910671174526215, 49.31441880762577, 50.96647135913372, 48.57835650444031, 48.76675419509411, 40.858337357640266, 37.85594746470451, 36.041430830955505, 37.0353738963604, 40.328938364982605, 50.681110471487045, 48.52020442485809, 52.95763671398163, 49.978630766272545, 49.04781751334667, 48.425578102469444, 49.6977536380291, 50.45707829296589, 50.20902760326862, 51.32680982351303, 48.69583860039711, 48.67210127413273, 47.58056804537773, 46.36119447648525, 44.87433046102524, 45.03855384886265, 45.71221210062504, 51.611441150307655, 47.377278953790665, 53.39560501277447, 46.44375264644623, 40.707679241895676, 22.560309022665024, 10.121220499277115, 3.1500756181776524, 2.5801729364320636, 1.576157680246979, 3.218132578767836, 3.7565093021839857, 2.992636766284704, 0.2055125660263002, 0.3868238447466865, 0.4515824042027816, 0.11277021520072594, 0.15645788109395653, 0.13687367259990424, 0.428064011503011, 3.396672885864973, 12.391120847314596, 30.37750795483589, 38.622047156095505, 35.22675834596157, 29.078826941549778, 22.723968140780926, 5.33791889436543, 0.15558698563836515, 0.013679126823262777, 0.039056864770827815, 0.03241269492718857, 0.03613705914176535, 0.04335207413532771, 0.0665333610959351, 0.06668716378044337, 0.05634415960230399, 0.04755465604830533, 0.04934798911563121, 0.06192838671267964, 0.01401103196258191, 0.052159578481223434, 0.06319471329334192, 0.052481566672213376, 0.05442876921733841, 0.06625094421906397, 0.04270374876796268, 0.028668717604887206, 0.036418544623302296, 0.03691006531880703, 0.03958451692597009, 0.015113669523998396, 0.010541821829974651, 0.03279437776654959, 0.06597365558263846, 0.03081960072449874, 0.011945573751290794, 0.004262324800947681, 0.027252571817371063, 0.014883748463034863, 0.06629779600189067, 0.04607858740200754, 0.03529974215780385, 0.05955929918854963, 0.0341989998560166, 0.030672907814732753, 0.047711694496683776, 0.02872047869459493, 0.05616572503640782, 0.040272606565849856, 0.02297541890584398, 0.09659155912231654, 0.03462882210442331, 0.03870614062179811, 0.05055089917732403, 0.08376902842428535, 0.07072055086609907, 0.016491866517753806, 0.018525495870562736, 0.023529827340098564, 0.021818316054122988, 0.03499864542391151, 0.055427633196813986, 0.07359196475590579, 0.07383039453998208, 0.05134428101882804, 0.01323347549259779, 0.018283084464201238, 0.01157381157099735, 0.06237602050532587, 0.02334899934794521, 0.06299498651060276, 0.09471071942243725, 7.810693681240082, 31.301948949694633, 52.51904524862766, 36.41762964427471, 22.62975599616766, 25.04522368311882, 18.08577362447977, 9.813913889229298, 1.834902896080166, 0.3560164337977767, 0.12859079986810684, 0.15508649608818814, 1.2078267009928823, 0.10151125607080758, 1.1924209026619792, 2.1790932957082987, 0.11148104531457648, 0.33696378115564585, 1.8131368327885866, 7.592850895598531, 15.027000457048416, 25.029277838766575, 39.495266899466515, 45.15690229833126, 54.61575374007225, 57.33183279633522, 54.63390156626701, 54.835317358374596, 54.830909594893456, 56.010442301630974, 55.005293637514114, 58.02340708673, 55.55821716785431, 53.16205054521561, 53.13093401491642, 51.81154601275921, 51.36617571115494, 51.5027441829443, 48.362877666950226, 44.899428114295006, 42.4662970751524, 43.81540708243847, 42.369694858789444, 45.620059445500374, 44.15929242968559, 46.32521040737629, 43.29163558781147, 44.7816002368927, 46.18330702185631, 53.46889168024063, 52.0573890209198, 54.67690005898476, 51.31121166050434, 51.96738705039024, 39.933288395404816, 42.3739468306303, 53.275250270962715, 51.665557846426964, 53.684355318546295, 49.743267595767975, 49.254970997571945, 42.28171817958355, 39.23013232648373, 38.20304363965988, 39.22019965946674, 42.274563163518906, 51.22231923043728, 50.056477189064026, 54.061431884765625, 50.81343077123165, 50.3073625266552, 48.59491981565952, 51.09100967645645, 51.135835871100426, 51.81626915931702, 51.16902709007263, 50.19858956336975, 50.97273722290993, 49.303661584854126, 46.93110689520836, 47.77824863791466, 45.823242142796516, 47.500924319028854, 50.5566481500864, 50.89393325150013, 54.308509826660156, 48.30521576106548, 40.764125213027, 24.17962823063135, 11.603229325264692, 5.651488518342376, 3.807225418277085, 2.1804507728666067, 3.831968028098345, 3.503099475055933, 2.0105072669684887, 0.23620402382221073, 0.24923153570853174, 0.5736071860883385, 0.1224379132327158, 0.45424537849612534, 0.3976501466240734, 0.438731731264852, 3.8801556173712015, 14.052329957485199, 34.10537771880627, 39.95461285114288, 39.60085943341255, 35.158958584070206, 26.136627718806267, 6.68304244056344, 0.3956460510380566, 0.008503612498316215, 0.052993808130850084, 0.01534234470454976, 0.010029977420344949, 0.03010820579220308, 0.041176045197062194, 0.04950143556925468, 0.02681687918084208, 0.05347252677893266, 0.03753964032512158, 0.09929316220222972, 0.025351961303385906, 0.026020469376817346, 0.024428313990938477, 0.04640724750061054, 0.060814085372840054, 0.031031838261696976, 0.020513587041932624, 0.054390593140851706, 0.02099995908793062, 0.05193403238081373, 0.04303203779272735, 0.02700630866456777, 0.009979853693948826, 0.0012097038438696472, 0.03155677601171192, 0.011948397623200435, 0.011382744723960059, 0.023630917130503803, 0.08030883167521097, 0.17223732109414414, 0.22000924829626456, 0.10730373352998868, 0.12114315497456118, 0.15967221173923463, 0.12726714980090037, 0.09771713739610277, 0.14362788439029828, 0.17427749990019947, 0.1158126792870462, 0.1398521932424046, 0.1305124576902017, 0.2459006878780201, 0.17547136318171397, 0.1488483589491807, 0.1904788360116072, 0.217701718211174, 0.15385978535050526, 0.14351865509524941, 0.10809586485265754, 0.10480597615242004, 0.17436298046959564, 0.16904273157706484, 0.10680095074349083, 0.17888988833874464, 0.14106238377280533, 0.16071659163571894, 0.12197217103675939, 0.15611621114658192, 0.11558623518794775, 0.24585319042671472, 0.19510326208546758, 0.13762190588749945, 0.3893995424732566, 9.570923577994108, 37.960582450032234, 61.108393147587776, 46.370671167969704, 30.179861560463905, 35.68800799548626, 22.79991466552019, 11.963944919407368, 2.0027549704536796, 0.5677698680665344, 0.8752611244563013, 0.49718271824531257, 6.704994337633252, 1.5246298327110708, 2.2082669427618384, 4.957988681271672, 1.2439221516251564, 0.9427549433894455, 1.7462041368708014, 6.59903559833765, 15.549145638942719, 26.300488226115704, 37.773936465382576, 45.44836565852165, 56.95509821176529, 57.788594886660576, 53.99044029414654, 55.85710532963276, 55.32662719488144, 56.379284709692, 55.582319274544716, 59.170390740036964, 56.9150597602129, 54.34246480464935, 55.99943809211254, 53.55534844100475, 52.72434063255787, 51.88943803310394, 50.46473868191242, 46.095425337553024, 46.50088258087635, 45.93023680150509, 43.89864161610603, 48.366153091192245, 45.89141048491001, 48.103682175278664, 46.58535584807396, 47.0854090154171, 50.19496075809002, 55.56966595351696, 55.15344388782978, 57.17234395444393, 53.898109048604965, 51.270439848303795, 42.45908886194229, 45.86038514971733, 53.69485795497894, 53.919418305158615, 54.882043451070786, 52.37620711326599, 51.50698475539684, 43.87148827314377, 41.67533531785011, 40.24744413793087, 41.18724770843983, 44.37364652752876, 53.39403189718723, 51.81412987411022, 55.34320950508118, 52.225484400987625, 50.37617303431034, 49.61289279162884, 51.83135814964771, 51.9253309071064, 51.59925900399685, 52.08926931023598, 52.06925958395004, 53.51923517882824, 50.6546600908041, 50.744738057255745, 49.00850482285023, 49.000905230641365, 50.17376929521561, 54.00733798742294, 52.85114362835884, 56.16680771112442, 50.482783913612366, 42.74280063807964, 23.434524312615395, 11.65669435635209, 4.72613699734211, 5.956115797162056, 4.404598250985146, 8.330362346023321, 10.193181037902832, 8.713763672858477, 0.8544782584067434, 0.8873189461883157, 1.6607487411238253, 0.36359946127049625, 0.41826217027846724, 0.9311149211134762, 1.652336586266756, 4.59212246350944, 15.108844265341759, 36.36809170246124, 45.69110423326492, 46.27903148531914, 40.08520044386387, 29.88987822085619, 7.892524190247059, 0.6093233695719391, 0.15123387391213328, 0.15234921796945855, 0.10649226926034316, 0.12791256594937295, 0.11432761952164583, 0.22859104326926172, 0.2338415154372342, 0.15631010464858264, 0.1322455654735677, 0.13386698003159836, 0.17137905699200928, 0.10809645857079886, 0.13439807575196028, 0.13964866666356102, 0.19100758654531091, 0.2541299775475636, 0.12065681818057783, 0.19409640517551452, 0.10758122254628688, 0.07842776933102868, 0.1873006479581818, 0.14257140748668462, 0.14638313732575625, 0.09888426851830445, 0.2548945677699521, 0.07998941131518222, 0.11708143269061111, 0.09278688710764982, 0.11560228784219362], [0.021376784570747986, 0.03378065121069085, 0.0451926115056267, 0.038182069329195656, 0.06576776897418313, 0.04979031655238941, 0.06949673450435512, 0.03737273502338212, 0.07440607849275693, 0.0501552750938572, 0.022740792628610507, 0.11161997535964474, 0.03206296525604557, 0.033504230887047015, 0.05718959939258639, 0.04160066870099399, 0.07214145196485333, 0.027922061381104868, 0.02180276991566643, 0.024548302571929526, 0.047982923497329466, 0.06394364419975318, 0.10181491321418434, 0.012373478475637967, 0.041894922833307646, 0.03233514791645575, 0.03857361160044093, 0.020468887487368193, 0.02566521998232929, 0.03852782479953021, 0.028784830319636967, 0.04251643440511543, 0.031170536385616288, 0.08849229372572154, 0.07165713381255046, 0.866709683323279, 12.92252043262124, 35.10110668838024, 44.19359318912029, 30.222314782440662, 23.050315529108047, 17.946835979819298, 12.382695749402046, 4.452369762584567, 0.18870275787776336, 0.30084618483670056, 0.06136212432465982, 0.10083121131174266, 0.17002290085656568, 0.15623525163391605, 1.6109426761977375, 2.0352444145828485, 0.15550230658845976, 0.2849340933607891, 0.7571372191887349, 2.697706804610789, 10.196514409035444, 22.996702305972576, 27.351439632475376, 36.34840875864029, 48.60635720193386, 48.88341933488846, 52.45251461863518, 53.36574241518974, 56.94296546280384, 57.102879881858826, 52.849878296256065, 53.20819906890392, 53.30942943692207, 51.00271001458168, 52.69550397992134, 49.226423129439354, 47.191370129585266, 44.79971766471863, 43.82634289562702, 41.192966401576996, 45.43216332793236, 45.195177644491196, 44.4765830039978, 44.65773828327656, 44.18728552758694, 41.808054596185684, 40.9571548551321, 41.493670865893364, 47.980492785573006, 49.87451255321503, 51.283526346087456, 49.090352430939674, 59.48349013924599, 40.47482393682003, 40.17467424273491, 54.63420554995537, 51.55966512858868, 50.48832781612873, 48.97542379796505, 43.94614666700363, 37.160732969641685, 35.488237515091896, 37.456592693924904, 36.77603021264076, 36.8023893982172, 47.51210331916809, 50.086446180939674, 50.76964192092419, 47.21457168459892, 50.4744091629982, 51.45432338118553, 50.147964879870415, 49.41465362906456, 50.801719799637794, 50.61114862561226, 50.90970620512962, 52.41968438029289, 48.10948446393013, 48.488134145736694, 44.586860686540604, 47.66506411135197, 44.963055700063705, 52.96640284359455, 47.280524745583534, 46.53314284980297, 41.37002170085907, 22.74310391396284, 13.29827181994915, 2.3185576871037483, 1.809682936873287, 1.0500120255164802, 1.0118137439712882, 0.9108167665544897, 2.669417797587812, 1.168907170649618, 0.10982201871229336, 0.06369380760588683, 0.2330937422811985, 0.12913978134747595, 1.0076977335847914, 0.4257890023291111, 1.6052118712104857, 4.224737752228975, 9.74991012364626, 16.630814597010612, 33.251947313547134, 33.45399007201195, 31.05871830135584, 15.223453715443611, 3.0968668358400464, 0.025341779037262313, 0.046916527790017426, 0.09264815744245425, 0.006903031417095917, 0.04537941007583868, 0.050290375656913966, 0.04797840381797869, 0.04443643723789137, 0.01724333742458839, 0.034198042485513724, 0.06669636641163379, 0.03393062070244923, 0.010429407793708378, 0.02750038791418774, 0.05590701235632878, 0.06570295721758157, 0.029257504174893256, 0.06448314103181474, 0.06336945938528515, 0.045627387589775026, 0.03254218856454827, 0.057639812148408964, 0.049823048975667916, 0.016459941180073656, 0.00959151286224369, 0.024714987084735185, 0.06937227633898146, 0.0579608281259425, 0.014180271318764426, 0.030414614448091015, 0.05985615083773155, 0.042496055029914714, 0.033935719256987795, 0.05186657486774493, 0.07708924662438221, 0.04318442297517322, 0.052939828019589186, 0.05510706621862482, 0.04020044383651111, 0.04357410616648849, 0.03688659118779469, 0.06957434088690206, 0.04711177942226641, 0.03456421443843283, 0.03136488259769976, 0.02386694606684614, 0.10927150840871036, 0.009726332336867927, 0.03891197899065446, 0.03386959760973696, 0.06326221162453294, 0.0731938767421525, 0.07004422426689416, 0.09838897400186397, 0.0651166086026933, 0.0390066065301653, 0.04070396134920884, 0.047005117958178744, 0.07252129798871465, 0.05713538921554573, 0.030674917179567274, 0.03495121476589702, 0.0401878755656071, 0.058391407364979386, 0.04227066478051711, 1.5572529821656644, 15.433072317391634, 41.99763782322407, 48.421523720026016, 32.31495559215546, 26.04393359273672, 23.605653829872608, 15.802324153482914, 5.906171277165413, 0.8906794502399862, 0.7259484333917499, 0.07942467404063791, 0.06899127256474458, 0.12565570970764384, 0.44010449666529894, 1.8254845077171922, 2.0883548771962523, 0.3584803640842438, 0.44988576555624604, 2.240634555928409, 4.43418251350522, 13.89013946056366, 23.181488290429115, 30.578488670289516, 39.59032639861107, 49.48009371757507, 49.135475009679794, 53.91581989824772, 54.15424570441246, 55.77686883509159, 56.67629957199097, 56.063704043626785, 54.339550361037254, 54.81500744819641, 51.99574112892151, 53.033036068081856, 51.37478604912758, 49.06867839396, 45.77571429312229, 45.80757178366184, 43.963515534996986, 46.52860589325428, 46.144381910562515, 47.963538095355034, 45.0739261507988, 46.01555362343788, 43.96080628037453, 43.097447007894516, 45.523993000388145, 50.58527201414108, 52.464130595326424, 54.96053583920002, 52.43902154266834, 59.251273199915886, 42.203214392066, 42.45587423443794, 55.090359672904015, 52.85169079899788, 50.78569985926151, 50.36398708820343, 46.317059844732285, 39.91971172392368, 36.836203783750534, 39.835873022675514, 38.56267914175987, 39.07239519059658, 49.988210052251816, 51.718595400452614, 53.00210952758789, 50.41917532682419, 52.59089559316635, 52.21265248954296, 52.021085768938065, 50.246854573488235, 51.69484667479992, 51.55510917305946, 51.424646973609924, 52.68165372312069, 49.620264396071434, 49.67189222574234, 46.879429668188095, 48.11995290219784, 46.54231935739517, 54.47032034397125, 49.438523948192596, 48.93519535660744, 42.91599914431572, 24.91238661110401, 14.563350286334753, 5.021869903430343, 4.423771072179079, 1.7403655126690865, 1.081164178904146, 1.4991430565714836, 3.3804560685530305, 2.278230688534677, 0.025446026666031685, 0.19119865988614038, 0.6354855000972748, 0.060750646589440294, 1.1964667355641723, 0.8245134225580841, 1.7231359309516847, 7.0550458040088415, 15.10066045448184, 23.555768206715584, 39.954666048288345, 38.55305425822735, 35.43281368911266, 18.06161642074585, 4.214782761409879, 0.014082050856814021, 0.013601837708847597, 0.08397158278967254, 0.007615458862346713, 0.05655563829350285, 0.04475702276977245, 0.09903540689265355, 0.02844040143827442, 0.03508361762214918, 0.02865172613383038, 0.051439416929497384, 0.06492036249255762, 0.12901075155241415, 0.015242918252624804, 0.038040630824980326, 0.06689264962915331, 0.022961724425840657, 0.004242270115355495, 0.04457653616555035, 0.06343715809634887, 0.02384853894909611, 0.040801512950565666, 0.03725286333065014, 0.02867348590370966, 0.04499289956584107, 0.03096127857133979, 0.07076530237100087, 0.010403892756585265, 0.04197087051579729, 0.019228306009608787, 0.16332642815541476, 0.12983242777409032, 0.14204311708454043, 0.21308668772689998, 0.17204379866598174, 0.11801163316704333, 0.1384271212737076, 0.15598370810039341, 0.14761265338165686, 0.16538109368411824, 0.1412133514531888, 0.17569071234902367, 0.12422024767147377, 0.13453911349643022, 0.16977368766674772, 0.07211340620415285, 0.1811746641760692, 0.17348985857097432, 0.08367049347725697, 0.18247325933771208, 0.2437239687424153, 0.12445573112927377, 0.1575384777970612, 0.13909656816395, 0.14485818712273613, 0.1238091423874721, 0.11266834058915265, 0.2717098529683426, 0.1790260724374093, 0.2605441818013787, 0.11137721143313684, 0.11831244788481854, 0.08665649496833794, 0.1494860864477232, 0.1572073166607879, 2.0738653047010303, 20.38808338344097, 49.26555722951889, 57.48723305761814, 39.77730296552181, 33.3055130392313, 27.87572219967842, 15.916875656694174, 6.3699843641370535, 2.7888586884364486, 1.3856351911090314, 0.16853038250701502, 0.5992858519311994, 0.47555053839460015, 0.7543258450459689, 2.6766777830198407, 4.009677842259407, 0.610676275100559, 0.9051210503093898, 1.4339173003099859, 3.6446062568575144, 11.657466664910316, 25.821871608495712, 30.702593810856342, 38.73434633016586, 50.39454124867916, 50.43725095689297, 54.1081427782774, 53.51481221616268, 57.12681099772453, 56.327029913663864, 56.119982823729515, 55.62028683722019, 57.636606842279434, 55.21007984876633, 55.57480327785015, 54.825198501348495, 52.392021864652634, 47.69568666815758, 47.12072812020779, 44.616472497582436, 49.49150450527668, 48.02577495574951, 48.72465245425701, 47.70416781306267, 48.342202976346016, 46.278883293271065, 44.38127651810646, 46.70369289815426, 51.45363561809063, 54.65934120118618, 56.80062510073185, 53.22211392223835, 60.12692481279373, 44.94473688304424, 45.73365814983845, 55.001056864857674, 54.559410363435745, 53.45573678612709, 52.914338037371635, 46.424396485090256, 42.098119631409645, 38.975405395030975, 41.06120467185974, 39.98392067849636, 40.1731239259243, 51.48038998246193, 54.27202418446541, 55.01513510942459, 49.761233031749725, 53.5334388166666, 52.24170573055744, 55.12875661253929, 52.06798665225506, 53.635835722088814, 52.999772652983665, 53.16874958574772, 54.99918736517429, 51.433591693639755, 53.36380071938038, 48.86464834213257, 50.40364935994148, 49.349050149321556, 56.05510890483856, 52.952951565384865, 49.098020419478416, 44.94832769036293, 26.529800221323967, 15.353196803480387, 3.664852757938206, 4.393091043457389, 4.939286084845662, 4.182068416848779, 3.3198965806514025, 6.391745796427131, 2.602179693058133, 0.32925458857789636, 0.23014018748654053, 0.5600118124857545, 0.8118802879471332, 3.972064610570669, 2.26395889185369, 2.0143533730879426, 6.259227432310581, 14.984224252402782, 27.235002480447292, 45.68723984062672, 46.57301031053066, 41.392835676670074, 21.51909079402685, 4.673932073637843, 0.08184526290278882, 0.09096881825826131, 0.27252579980995506, 0.13460957299685106, 0.23753518442390487, 0.24836685945047066, 0.20035612396895885, 0.15162731608143076, 0.1377860689535737, 0.1276487621362321, 0.2453069103648886, 0.10592383609036915, 0.18879843555623665, 0.07612184970639646, 0.20057823392562568, 0.21136172872502357, 0.10025722687714733, 0.10405210254248232, 0.16318525682436302, 0.17569526913575828, 0.12357490573776886, 0.13168570410925895, 0.11663649289403111, 0.08046502407523803, 0.08086502682999708, 0.10533791049965657, 0.07697396882576868, 0.141573530563619, 0.08867162629030645, 0.0946854344510939], [0.0645947155135218, 0.06151371169835329, 0.02731788823439274, 0.02741407799476292, 0.04267818549124058, 0.04942501662299037, 0.07510444687795825, 0.054032722109695897, 0.04220403476210777, 0.0942760583711788, 0.02354397453018464, 0.023205286161100958, 0.03562223500921391, 0.04629714247130323, 0.041485398323857225, 0.08834241700242274, 0.054681054898537695, 0.05703229377104435, 0.056698353291722015, 0.11120106268208474, 0.018278125062352046, 0.07216845129732974, 0.03154745092615485, 0.010576268614386208, 0.048989320275723, 0.020226863853167742, 0.02705262795643648, 0.022293027104751673, 0.03474697943602223, 0.014403722707356792, 0.05405695323133841, 0.031728920876048505, 0.025015447426994797, 0.014450745184149127, 0.05906083941226825, 0.3189908346394077, 3.4034488722682, 23.421612605452538, 42.72970654070377, 29.03452891856432, 20.27948521077633, 13.760964442044497, 17.554864212870598, 7.974016517400742, 1.8753203772939742, 0.009148038807325065, 0.2111523094936274, 0.028786767325073015, 0.0488469466654351, 0.06939888975466602, 0.3672264260239899, 1.7957283044233918, 0.9880274953320622, 0.2852703753160313, 2.176389265805483, 0.7592491339892149, 2.3115969356149435, 7.119879825040698, 13.361300937831402, 22.43975479155779, 34.643356651067734, 44.25567425787449, 47.628867253661156, 54.987396597862244, 52.93513812124729, 58.4426461905241, 52.63651594519615, 55.175391510128975, 59.387685880064964, 52.00016029179096, 52.05672025680542, 49.92428608238697, 51.759792789816856, 45.00900663435459, 46.14963322877884, 46.02072134613991, 47.34863229095936, 46.425175443291664, 49.62578549981117, 46.1965075135231, 46.2664807587862, 41.05269692838192, 40.415547117590904, 38.98266300559044, 43.12124513089657, 46.223436668515205, 52.28101462125778, 46.49135649204254, 55.58494873344898, 43.06719683110714, 40.39034307003021, 55.84811881184578, 50.06834775209427, 51.42433159053326, 46.98882959783077, 42.503827661275864, 38.0000851303339, 37.12882988154888, 36.29365749657154, 39.34660367667675, 34.67090517282486, 42.48668298125267, 46.48249536752701, 51.41674719750881, 50.976027846336365, 51.2439476698637, 50.29185935854912, 51.2941961735487, 49.574575647711754, 47.761738523840904, 50.04340969026089, 49.4790905714035, 51.43390327692032, 51.552152931690216, 50.92337027192116, 49.32646036148071, 45.94756007194519, 47.13793359696865, 50.152699425816536, 52.97620631754398, 37.0606729388237, 28.403346687555313, 13.848146963864565, 2.7736492920666933, 0.9737545112147927, 5.210681296885014, 1.9143472518771887, 0.9587517287582159, 1.584317742381245, 0.7316321565303952, 1.1591618810780346, 0.08320779408677481, 0.2393439318984747, 0.7331193017307669, 0.03540017700288445, 0.31811783148441464, 0.5432323878630996, 1.0473633301444352, 6.272747106850147, 10.047220420092344, 22.4660911783576, 27.22411796450615, 30.52349992096424, 25.394367948174477, 7.813101802021265, 0.5845519050490111, 0.049373875226592645, 0.0723571349226404, 0.03122741458355449, 0.022958655645197723, 0.06391678587533534, 0.03289610394858755, 0.026113228559552226, 0.019795581429207232, 0.05734877893701196, 0.034828177813324146, 0.018678994274523575, 0.02788687801512424, 0.044300468362052925, 0.05673785781254992, 0.04857657113461755, 0.026879759498115163, 0.031273895292542875, 0.0818162300856784, 0.07824180938769132, 0.027098043683508877, 0.051042367922491394, 0.07423255694448017, 0.029261630515975412, 0.019834831764455885, 0.05942345276707783, 0.024970176418719348, 0.055757502996129915, 0.05512979820196051, 0.02704952763451729, 0.048273797146975994, 0.019673295901156962, 0.026715186395449564, 0.008527513364242623, 0.053118047362659127, 0.06334066405543126, 0.048196944044320844, 0.0179683767419192, 0.06415281110093929, 0.019463015778455883, 0.015464206280739745, 0.05906822749238927, 0.01769882128428435, 0.05044009281846229, 0.08372403943212703, 0.07726322088274173, 0.07889363027061336, 0.0438353050412843, 0.05476235717651434, 0.028276730045035947, 0.09506178495939821, 0.01508505880337907, 0.013810712389386026, 0.1064165479328949, 0.0398971503454959, 0.014594272834074218, 0.01791625385521911, 0.06111064758442808, 0.034812154844985344, 0.0684697060205508, 0.05823669554956723, 0.042114624520763755, 0.033679500193102285, 0.07493047261959873, 0.020011848828289658, 0.07785301306284964, 0.5629488767590374, 4.612464671954513, 29.078431762754917, 50.60113996267319, 32.35790088772774, 23.745098747313023, 22.04149816185236, 21.900185644626617, 10.625579785555601, 1.2267636973410845, 0.19631085509900004, 0.19001722015673295, 0.08413245072006248, 0.13653443689690903, 0.14661689900094643, 0.6424579478334635, 3.2537639793008566, 0.4205427010310814, 0.24563629034673795, 5.032793842256069, 3.0189049942418933, 4.779469985514879, 10.5630436912179, 17.415428794920444, 23.576047718524933, 38.25146824121475, 45.41952520608902, 49.190750643610954, 54.247067123651505, 53.415987119078636, 57.85240486264229, 53.800575882196426, 55.5919973552227, 60.57135656476021, 54.157148748636246, 54.67348024249077, 51.91084988415241, 53.439678847789764, 47.078561782836914, 49.13304314017296, 46.506168097257614, 48.98430772125721, 48.65143798291683, 51.81859843432903, 48.929594457149506, 48.82844768464565, 42.96849712729454, 42.36604705452919, 40.412701070308685, 44.31540325284004, 49.12566773593426, 54.9642900377512, 48.77681985497475, 55.926861986517906, 44.01568293571472, 41.306971684098244, 55.56304670870304, 52.00690872967243, 53.26189398765564, 49.411237612366676, 44.368425607681274, 39.32848624885082, 39.46701541543007, 38.24983052909374, 40.85321523249149, 38.066410571336746, 44.625432416796684, 48.588121980428696, 53.35622012615204, 53.53187330067158, 51.45484775304794, 52.28345409035683, 52.23317138850689, 51.49128399789333, 50.37463031709194, 50.87480507791042, 52.04333737492561, 51.24210476875305, 53.177534714341164, 51.21645234525204, 51.41015075147152, 48.353522568941116, 47.85185448825359, 51.09742373228073, 52.65355423092842, 39.98027287423611, 30.63733611255884, 16.693853214383125, 6.009368039667606, 3.6720512341707945, 5.116197466850281, 2.516478141769767, 0.6045176368206739, 1.0189099819399416, 2.178233116865158, 3.790888669900596, 0.3440643532667309, 0.7642037118785083, 0.7691541337408125, 0.2559402835322544, 0.35021681687794626, 0.5892066552769393, 2.5189798325300217, 8.435033429414034, 13.137638289481401, 25.234835408627987, 33.31955328583717, 36.72592610120773, 29.02775388211012, 10.058051738888025, 0.8452275954186916, 0.037077456727274694, 0.021480499708559364, 0.047290763177443296, 0.038707658313796856, 0.05162169582035858, 0.05166886672668625, 0.012323155297053745, 0.04850250108574983, 0.05303536097926553, 0.02699429700442124, 0.031149819333222695, 0.02888544328015996, 0.02423759131488623, 0.086066799267428, 0.03522506354784127, 0.09056324197445065, 0.02668491975782672, 0.056366175413131714, 0.02072160546958912, 0.08459328731987625, 0.010530205363465939, 0.08914899794035591, 0.024686891229066532, 0.034776156971929595, 0.02399928398517659, 0.02354234180529602, 0.049198583656107076, 0.05063889933808241, 0.013794616133964155, 0.0352197905885987, 0.18165731249609962, 0.1981559381238185, 0.11429463847889565, 0.13173082668799907, 0.1296123958309181, 0.18961904308525845, 0.17860135616501793, 0.17996117850998417, 0.16587585385423154, 0.12793649279046804, 0.149506495508831, 0.14768525026738644, 0.14429439237574115, 0.16174655902432278, 0.2706891030538827, 0.2911058528115973, 0.12481350568123162, 0.1382274687057361, 0.2238453651079908, 0.19446648453595117, 0.14571052888641134, 0.10048690674011596, 0.1584203273523599, 0.10890062752878293, 0.13636510848300532, 0.08425002175499685, 0.23460251366486773, 0.19452827575150877, 0.16793295362731442, 0.12469330744352192, 0.15559204708551988, 0.09751904333825223, 0.1653068492305465, 0.1625232314108871, 0.2240684992284514, 0.70793371880427, 5.9234589245170355, 36.146544590592384, 56.22020624577999, 39.89462926983833, 28.931843228638172, 25.589692667126656, 22.535329163074493, 11.916645057499409, 3.242433462291956, 0.4658547352300957, 0.5000962119083852, 0.22832753631519154, 0.3520345740253106, 0.20696827385108918, 1.3957099942490458, 3.455340312793851, 2.1391859371215105, 1.3083614688366652, 5.365146333351731, 1.864726070780307, 4.291765680536628, 8.58709841966629, 15.729954186826944, 26.18451464921236, 38.54922406375408, 47.54038140177727, 49.83323156833649, 55.47920040786266, 54.62656795978546, 60.43057791888714, 54.84368830919266, 55.735584050416946, 63.72878573834896, 56.559889018535614, 55.94133161008358, 54.79817055165768, 56.332038044929504, 48.40634733438492, 51.302365735173225, 49.59414079785347, 50.97918167710304, 49.90880571305752, 55.18992193043232, 50.33086806535721, 50.88492393493652, 45.32298758625984, 43.99355672299862, 43.7554956972599, 47.26798161864281, 50.751581490039825, 56.255882531404495, 51.709627881646156, 55.94969496130943, 47.512905076146126, 44.668472707271576, 56.24140530824661, 54.42678228020668, 55.24998150765896, 52.24215790629387, 45.92616342008114, 41.40741169452667, 40.62073610723019, 40.21551065146923, 43.052005246281624, 39.57534000277519, 46.886649280786514, 48.389673829078674, 55.47283194959164, 55.951522663235664, 54.24202859401703, 55.061306431889534, 55.357082560658455, 54.40017610788345, 51.9068942964077, 53.22673827409744, 53.08776833117008, 53.23634795844555, 53.01025629043579, 53.43605764210224, 54.12412852048874, 49.376971051096916, 49.2458438873291, 52.76849426329136, 54.246432557702065, 41.793520376086235, 31.74528256058693, 17.084111273288727, 3.4100890159606934, 1.7329380987212062, 8.947752267122269, 6.612125895917416, 3.4766362700611353, 2.2957883588969707, 3.4610765799880028, 4.551634211093187, 0.281923912698403, 0.7366263354197145, 1.5784356580115855, 0.35481394676025957, 1.2504912866279483, 1.094390437938273, 2.154273740015924, 9.575077705085278, 16.329466067254543, 31.909053772687912, 39.27522070705891, 42.12926656007767, 34.098534286022186, 11.213488038629293, 0.9457762562669814, 0.23287356190849096, 0.16794135473901406, 0.12031577905872837, 0.08249087943113409, 0.15376102033769712, 0.14159781363559887, 0.12802283425116912, 0.12959669198608026, 0.1868869154714048, 0.1451881608227268, 0.09578332319506444, 0.16422729153418913, 0.1260752754751593, 0.1720240426948294, 0.22163472982356325, 0.16649142082314938, 0.19853723875712603, 0.28855805983766913, 0.10662941072951071, 0.13935289112851024, 0.13521859422326088, 0.14931978599634022, 0.12682092608883977, 0.12915713276015595, 0.14446060376940295, 0.15807985968422145, 0.17541878944030032, 0.14331938844406977, 0.13287406065501273, 0.12374909521895461], [0.05050022904470097, 0.0466461485484615, 0.02947546923678601, 0.03837852695141919, 0.08644199202535674, 0.06036508973920718, 0.04896823957096785, 0.024511959600204136, 0.051101413191645406, 0.01710561708023306, 0.07800202147336677, 0.04005451162811369, 0.04364891836303286, 0.033488541885162704, 0.08477412644424476, 0.032075500130304135, 0.05200512270675972, 0.04385476786410436, 0.02026871356065385, 0.04374688185635023, 0.0355711121665081, 0.06614555924898013, 0.03469763032626361, 0.03239266065065749, 0.056248652617796324, 0.08941174790379591, 0.0130086130957352, 0.09337820811197162, 0.07779994208249263, 0.033088991840486415, 0.04501878938754089, 0.03161176173307467, 0.050002355565084144, 0.0573886953498004, 0.0730659750115592, 0.038637243342236616, 1.030528808478266, 13.854446075856686, 37.21539683640003, 47.889381274580956, 27.59184703230858, 22.91205044835806, 14.399276040494442, 9.428835902363062, 6.324721667915583, 0.41315551148727536, 0.04204824683256447, 0.019172702450305223, 0.019028824135602918, 0.0620822116616182, 0.015417547456308967, 1.0352450679056346, 0.43702131835743785, 0.6817065761424601, 5.65986611880362, 1.9216410792432725, 1.3299354049377143, 1.7669785721227527, 5.169274918735027, 7.450212249532342, 20.33542960882187, 32.4262972176075, 38.8808436691761, 48.38628061115742, 47.08898842334747, 54.67241249978542, 53.86922299861908, 51.03514887392521, 60.34401096403599, 52.140125781297684, 55.61443135142326, 52.74238966405392, 52.18131937086582, 51.54671922326088, 50.45610934495926, 47.70699106156826, 50.47399878501892, 50.04578456282616, 49.11981225013733, 45.868851095438, 45.366920828819275, 43.097462207078934, 42.80001416802406, 41.3592416793108, 39.467706978321075, 41.12352512776852, 50.56715838611126, 48.74761462211609, 57.3962165415287, 46.04746051132679, 40.560235753655434, 51.94706194102764, 51.28104887902737, 52.23812632262707, 45.45939266681671, 42.17756196856499, 38.18249054253101, 39.75412040948868, 38.734741508960724, 38.49750503897667, 36.84344619512558, 37.56604962050915, 39.87271964550018, 44.99862939119339, 47.90928840637207, 49.36996042728424, 49.03819642961025, 48.92022795975208, 47.391266003251076, 47.83273011445999, 48.102998211979866, 49.236610382795334, 52.30527251958847, 50.971388295292854, 50.84110088646412, 51.58571273088455, 50.60356803238392, 48.72988857328892, 46.653182208538055, 37.731086164712906, 25.834118351340294, 12.140701934695244, 4.6165442280471325, 2.4045917205512524, 5.863923244178295, 2.9980982607230544, 1.6076334100216627, 0.39867597282864153, 0.4189310531364754, 2.3947006138041615, 3.7229069927707314, 0.35702382505405694, 0.3768416616367176, 0.7703422824852169, 0.1494705755612813, 0.5582736432552338, 2.061807601712644, 5.777308791875839, 11.698150131851435, 20.405123569071293, 23.880436085164547, 31.936910077929497, 29.347590319812298, 15.946781001985073, 3.1477717543020844, 0.15400134259834886, 0.1947118979296647, 0.036158974762656726, 0.10204858583165333, 0.04902211578155402, 0.059586721545201726, 0.009622260968171759, 0.02230308691650862, 0.07878505406551994, 0.05229893155046739, 0.03094497358688386, 0.02965970925288275, 0.04907280446786899, 0.017620231556065846, 0.02176339527068194, 0.04621576226782054, 0.04874735415796749, 0.08028034804738127, 0.03478486978565343, 0.04485869700147305, 0.014809483600402018, 0.04061651408846956, 0.040055932840914465, 0.06751586814061739, 0.03174314784700982, 0.034419744260958396, 0.051692032866412774, 0.020499246893450618, 0.004115175934202853, 0.020654374311561696, 0.011338561889715493, 0.035122127665090375, 0.06288628414040431, 0.026881653830059804, 0.035010824067285284, 0.025959661506931297, 0.081277141434839, 0.03153126839606557, 0.06485762874945067, 0.07315326642128639, 0.08151039844960906, 0.0735260768851731, 0.04849510187341366, 0.0420242717518704, 0.016283571640087757, 0.0664418246014975, 0.04948820307618007, 0.028120667520852294, 0.0569746511609992, 0.021891558608331252, 0.019340420403750613, 0.03496108532999642, 0.028358943309285678, 0.032347634551115334, 0.025066136113309767, 0.029480545526894275, 0.022015129907231312, 0.028732265855069272, 0.05484612709551584, 0.04782204814546276, 0.044170162072987296, 0.039852365443948656, 0.0047123640797508415, 0.042852308179135434, 0.019299464984214865, 0.050350118544884026, 0.012463346065487713, 1.485744856763631, 18.139310851693153, 43.99514123797417, 51.571258306503296, 29.463736787438393, 18.55420108884573, 16.966619677841663, 11.917560808360577, 7.03459482640028, 0.5784514511469752, 0.15010944596724585, 0.032880533690331504, 0.06763596247765236, 0.12220303833601065, 0.039126199917518534, 1.9845187989994884, 1.248537478968501, 1.627738131210208, 8.787473067641258, 5.0833401549607515, 3.718295465223491, 2.4493678053840995, 8.43659894540906, 10.807375330477953, 22.30662703514099, 33.80358271300793, 40.49327574670315, 50.41156813502312, 49.2980644851923, 53.18743318319321, 53.12901131808758, 55.08626729249954, 59.56310346722603, 54.53427091240883, 57.776484936475754, 54.42312307655811, 53.675969168543816, 53.870119750499725, 53.09094116091728, 49.88729506731033, 50.805287808179855, 50.90490326285362, 50.61150200664997, 48.21149758994579, 48.132366836071014, 44.4800978153944, 43.97633604705334, 42.49143272638321, 42.245570719242096, 43.15714180469513, 50.83680711686611, 51.59015849232674, 57.967154905200005, 48.256099596619606, 42.09642492234707, 53.89580637216568, 52.89721995592117, 52.26144187152386, 47.51200072467327, 43.51485840976238, 40.486310720443726, 40.85012599825859, 40.15143468976021, 40.22037819027901, 37.684607058763504, 39.59663026034832, 43.27855668962002, 48.15995715558529, 49.81110915541649, 51.67380340397358, 50.78179366886616, 49.12438340485096, 49.878300949931145, 48.525797724723816, 49.8209810256958, 51.04216329753399, 53.676216155290604, 50.92587433755398, 51.92835554480553, 52.835515066981316, 51.54616065323353, 50.75918488204479, 49.44803863763809, 42.56645210087299, 28.491585552692413, 16.07301402837038, 7.849752735346556, 4.8180977627635, 5.458890153095126, 5.71424120105803, 1.0174861270934343, 1.1025201017037034, 0.3994942648569122, 3.136160052381456, 5.193492919206619, 2.4638554779812694, 1.2840653350576758, 0.39577551127877086, 0.4183936194749549, 0.3215897467453033, 1.3678472768515348, 5.097084967419505, 13.266529273241758, 24.115804955363274, 29.040084220468998, 35.30981808900833, 33.80686953663826, 19.279107190668583, 4.070134498178959, 0.24152842874173075, 0.024474445890518837, 0.023688437286182307, 0.009808068771235412, 0.037593969245790504, 0.041519722653902136, 0.061641750726266764, 0.04472450556932017, 0.010061409229820129, 0.033217739619431086, 0.08936647689552046, 0.024316374001500662, 0.07134472674806602, 0.025135771829809528, 0.03757659927941859, 0.02751759089733241, 0.03996866740635596, 0.07804874709108844, 0.0520431726181414, 0.02620165359985549, 0.034116758761228994, 0.05244111220235936, 0.050147226502303965, 0.03722221634234302, 0.028811154297727626, 0.01440797892428236, 0.039148015348473564, 0.04346196023107041, 0.027066584043495823, 0.019102302321698517, 0.052619606140069664, 0.12488907115766779, 0.11970080580795184, 0.15602369501721114, 0.14900118199875578, 0.09569654386723414, 0.15118743031052873, 0.12025192467262968, 0.08052494507865049, 0.20642652089009061, 0.18533392692916095, 0.2862928173271939, 0.1704385332413949, 0.15659691503969952, 0.15472181956283748, 0.15692411310737953, 0.09903431593556888, 0.1296108670067042, 0.182084062253125, 0.10784363112179562, 0.12782399804564193, 0.16670455079292879, 0.1449272216996178, 0.1037959948007483, 0.09810473886318505, 0.1559809918398969, 0.11636039169388823, 0.13388035353273153, 0.1884091048850678, 0.16240708529949188, 0.12201231380458921, 0.22361221199389547, 0.1966823445400223, 0.2398327994160354, 0.10810373903950676, 0.14218540163710713, 0.1651766468421556, 1.9694636506028473, 22.861824743449688, 52.14307062327862, 60.6934630125761, 37.1232745796442, 31.625322997570038, 23.86513240635395, 16.793941743671894, 8.61267389729619, 0.8315626974217594, 0.2596765221096575, 0.21726303471950814, 0.13609873683890328, 0.240346395294182, 0.13949614047305658, 2.972833653911948, 1.024282299913466, 4.259184803813696, 9.134810529649258, 4.18837227858603, 3.906167121604085, 2.9314742982387543, 7.705430304631591, 9.377666898071766, 23.72991096228361, 36.35200336575508, 42.76217199862003, 51.02352149784565, 51.86978928744793, 56.38362027704716, 55.97197316586971, 54.89499695599079, 59.99889448285103, 57.63313762843609, 60.6338632106781, 57.61600814759731, 56.43394857645035, 56.7488718777895, 53.94814856350422, 52.22947798669338, 54.16018098592758, 53.078037053346634, 51.33919335901737, 49.98775787651539, 50.23879900574684, 47.20775865018368, 46.49900548160076, 44.55043584108353, 43.422736153006554, 46.220864206552505, 51.127252131700516, 53.93625520169735, 59.98417407274246, 50.88781177997589, 45.790286511182785, 54.13596868515015, 56.71991363167763, 54.18432109057903, 48.93583372235298, 44.37203921377659, 41.7074815928936, 41.814202666282654, 42.339828461408615, 40.83153739571571, 39.47489619255066, 40.27537263929844, 44.493693485856056, 48.85761871933937, 51.91224820911884, 53.814182952046394, 52.51309476792812, 50.75858451426029, 52.34590373933315, 51.635459661483765, 52.46158853173256, 52.72386945784092, 54.13496933877468, 52.1471706032753, 51.901984959840775, 53.55947881937027, 54.99682389199734, 51.85350716114044, 51.79744116961956, 42.4319963157177, 30.303033851087093, 15.764481984078884, 6.07226986438036, 3.801266150549054, 10.293337013572454, 9.199094530194998, 2.0609970577061176, 1.6308921994641423, 0.583304800093174, 4.953342005610466, 10.493054296821356, 2.4484446924179792, 1.9445889978669584, 2.5418363185599446, 1.4714987087063491, 1.284764853771776, 3.4112505661323667, 8.315476644784212, 17.70135585218668, 29.658774621784687, 34.80391703546047, 44.42114397883415, 40.357923209667206, 21.661776937544346, 4.878883101046085, 0.4007753898622468, 0.2658252452965826, 0.07377072586677969, 0.1554875378496945, 0.0813503320387099, 0.1151305490930099, 0.15824335481738672, 0.13437621208140627, 0.14954853075323626, 0.14310260710772127, 0.10766863269964233, 0.15859044244280085, 0.09001405269373208, 0.13848011061782017, 0.10172584807150997, 0.07643496923265047, 0.19581737142289057, 0.2624013618333265, 0.17765286174835637, 0.15864732064073905, 0.16273928544251248, 0.19945909007219598, 0.10479704069439322, 0.14540256728651002, 0.2465620602015406, 0.1660957225249149, 0.14432093157665804, 0.19967599015217274, 0.10906785566476174, 0.13878597936127335, 0.16115105972858146], [0.04398075856443029, 0.020559247677738313, 0.05132647689606529, 0.02840223278326448, 0.02985226317832712, 0.01893103133625118, 0.14841672586044297, 0.0227273597556632, 0.021314926561899483, 0.04040151019580662, 0.09104289943934418, 0.05124082192196511, 0.03304084872070234, 0.03490120514470618, 0.021665969834430143, 0.017975473529077135, 0.01155835449026199, 0.0603598390443949, 0.046803836376057006, 0.04358497491921298, 0.025037429841177072, 0.02993219248310197, 0.02507340359443333, 0.019610196650319267, 0.05283852115098853, 0.07742365836747922, 0.04507462486799341, 0.030601693179050926, 0.03629404563980643, 0.058655842003645375, 0.021853156176803168, 0.06736601368174888, 0.02621841871587094, 0.12138289836002514, 0.012834498757001711, 0.06975834156037308, 0.1460313147981651, 4.739327039569616, 21.160049960017204, 42.11805336177349, 41.185385808348656, 27.4893494322896, 18.84555045515299, 14.504325203597546, 8.818499352782965, 2.1706712851300836, 0.07634467954630964, 0.04524439114902634, 0.06415589101379737, 0.05325680671376176, 0.15179054404143244, 0.35304959455970675, 0.4946222493890673, 0.4354418796719983, 7.481471747159958, 6.777592767030001, 3.060164130292833, 0.8694726100657135, 1.209441851824522, 2.857788889668882, 5.9750511310994625, 18.182316944003105, 28.00373163074255, 37.8468469530344, 44.41636763513088, 47.70971551537514, 54.71639133989811, 47.12276101112366, 55.85466206073761, 54.14885759353638, 56.53729923069477, 55.84533356130123, 56.850793808698654, 53.0351335555315, 52.398694306612015, 50.85553631186485, 50.92153877019882, 49.275645688176155, 50.134065225720406, 46.83536723256111, 45.56370086967945, 41.94705493748188, 42.61060193181038, 40.87284877896309, 42.93071575462818, 40.838149040937424, 48.609199449419975, 46.57688610255718, 57.49240458011627, 46.276500821113586, 36.444961577653885, 52.84034840762615, 48.15876021981239, 52.90841415524483, 46.60227634012699, 41.321722492575645, 41.56474605202675, 43.26694831252098, 38.067729100584984, 42.04999141395092, 40.77086225152016, 40.27761831879616, 36.31380021572113, 38.41689236462116, 39.054604545235634, 41.62115782499313, 43.68657499551773, 45.53257293999195, 44.18276757001877, 46.89590558409691, 46.52955584228039, 50.934678465127945, 50.11041909456253, 51.549363881349564, 49.74086232483387, 49.82116341590881, 49.2491003125906, 44.376237988471985, 36.36141166090965, 23.704687915742397, 12.454776931554079, 5.050314702093601, 3.06377821136266, 4.158014757558703, 4.953687312081456, 3.149023074656725, 0.872503244318068, 0.5942276702262461, 0.7150395156349987, 2.4858589097857475, 4.85362253151834, 2.8218777291476727, 1.3354996126145124, 0.09989550409954973, 0.3167973132804036, 0.4372676520142704, 4.382872441783547, 10.977641344070435, 16.03277798742056, 18.71884435415268, 30.012843422591686, 30.49162533134222, 21.49339847266674, 7.158842459321022, 1.0364063805900514, 0.022387151839211583, 0.0003092603873255939, 0.05239140686171595, 0.03790959723119158, 0.03902317868778482, 0.027832294908876065, 0.05381176248192787, 0.01975710292754229, 0.05635374443954788, 0.02453450048051309, 0.023047023169056047, 0.06676997261820361, 0.012824128170905169, 0.019424329475441482, 0.023638277380086947, 0.006831252749179839, 0.016261041891993955, 0.05234501149971038, 0.015394661477330374, 0.02477829413692234, 0.032548070084885694, 0.01705530874460237, 0.010411629646114307, 0.027027144460589625, 0.07843208120903, 0.027210690568608698, 0.04333367258368526, 0.03262326819822192, 0.04678834775404539, 0.023563752765767276, 0.02616129189846106, 0.011008920300810132, 0.001973822454601759, 0.02438486866594758, 0.025385777262272313, 0.07235566547024064, 0.03120449706329964, 0.09704488518764265, 0.05071949286502786, 0.016325098513334524, 0.08982168801594526, 0.041959942391258664, 0.03717672640050296, 0.05567133594013285, 0.0635623287234921, 0.014932396243239054, 0.023664426953473594, 0.02775100747385295, 0.031422551182913594, 0.10362097411416471, 0.02480030438164249, 0.03971722777350806, 0.021344007618608885, 0.10997800331097096, 0.010856693752430147, 0.05804318796435837, 0.01678187370998785, 0.08671943651279435, 0.0373859081446426, 0.047149254169198684, 0.03269581313361414, 0.039993399477680214, 0.06345998655888252, 0.09547562134684995, 0.07004079554462805, 0.037157055776333436, 0.01768026573699899, 0.12162549901404418, 6.077831340953708, 26.223897635936737, 48.2787311822176, 45.79808369278908, 26.896497644484043, 19.41677000373602, 23.2043269649148, 10.849787704646587, 2.021602909080684, 0.1823093040729873, 0.1465383352478966, 0.19451453117653728, 0.29400459257885814, 0.14691129414131865, 1.3450734363868833, 1.8326797778718174, 2.1961543802171946, 3.6279087653383613, 10.022593941539526, 7.458054553717375, 4.4300407357513905, 4.809219064190984, 6.05853027664125, 11.257882956415415, 20.37309318780899, 30.27047149837017, 39.430077597498894, 45.79481206834316, 49.21167612075806, 55.540000945329666, 49.565376341342926, 57.95706644654274, 55.721357613801956, 57.07529716193676, 57.24449448287487, 58.54931026697159, 54.97384652495384, 54.44625623524189, 52.92740173637867, 52.695686370134354, 50.005943700671196, 51.23281046748161, 49.64128486812115, 45.779533088207245, 45.26134729385376, 44.99581754207611, 42.341070994734764, 44.4332767277956, 42.761351242661476, 49.92299795150757, 49.72627490758896, 59.113743379712105, 48.83777618408203, 39.61518466472626, 54.1762313246727, 51.4951977878809, 55.12535959482193, 48.52211952209473, 43.19494217634201, 42.232142239809036, 43.36808368563652, 40.38088537752628, 41.77441880106926, 40.96550680696964, 41.68320469558239, 38.47518503665924, 39.91276949644089, 41.74722746014595, 44.88955244421959, 46.58915564417839, 46.4921772480011, 46.66956692934036, 49.16608616709709, 48.62141199409962, 53.14716674387455, 50.861798375844955, 51.2127323448658, 50.611274018883705, 52.22204938530922, 49.636162742972374, 47.42063842713833, 39.27312321960926, 27.22453024238348, 14.945463482290506, 7.10172962397337, 4.179908707737923, 4.953352930024266, 4.92973149754107, 5.18086239695549, 2.336672740057111, 1.2197794346138835, 2.104253936558962, 3.472030679695308, 2.842880627140403, 3.9876413997262716, 1.321914391592145, 0.31074008205905557, 0.07364070159383118, 0.5300931679084897, 4.7289113234728575, 15.208969842642546, 19.765304401516914, 20.84579162299633, 32.32907563447952, 35.90264327824116, 26.07380948960781, 9.897293765097857, 1.5191380586475134, 0.023303655980271287, 0.011616122337727575, 0.016468871071992908, 0.020720854045066517, 0.014489737623080146, 0.022902725540916435, 0.031439156737178564, 0.07983011673786677, 0.03287478946731426, 0.029745943102170713, 0.015582737469230779, 0.01306691528952797, 0.046968648821348324, 0.0981298234546557, 0.034228259028168395, 0.015936487725412007, 0.018632118371897377, 0.031689145471318625, 0.021096681339258794, 0.09857933488092385, 0.05172069460968487, 0.005454641632240964, 0.016692988538125064, 0.021840693661943078, 0.01638059260585578, 0.01929227542859735, 0.017748393038345966, 0.09751068675541319, 0.010923621557594743, 0.012946675306011457, 0.03131608267722186, 0.13214004691690207, 0.09988970050471835, 0.18243993690703064, 0.15709100727690384, 0.2869348938111216, 0.12452733353711665, 0.22081223723944277, 0.13699081318918616, 0.10127390240086243, 0.12620909954421222, 0.19531413592630997, 0.09405386677826755, 0.16252582892775536, 0.17704712081467733, 0.12492466456023976, 0.11743870258214884, 0.13289176829857752, 0.12544329219963402, 0.16540977027034387, 0.1491595563129522, 0.09508916278718971, 0.061182019926491193, 0.29126182256732136, 0.06562794093042612, 0.2624333929270506, 0.14536458416841924, 0.2765199198620394, 0.17277224629651755, 0.10892619451624341, 0.23086845700163394, 0.13838256272720173, 0.16121135180583224, 0.1710986439138651, 0.22376389213604853, 0.14454321964876726, 0.17528924014186487, 0.29914069978985935, 7.432270087301731, 33.04092563688755, 55.73688358068466, 54.39658150076866, 38.18296551704407, 27.525472193956375, 23.82524784654379, 11.824530400335789, 3.210804909467697, 0.27533064305316657, 0.2662534051341936, 0.19661823782371357, 0.5090560123790056, 0.4205351014388725, 1.007080147974193, 2.2906332230195403, 2.2225195029750466, 15.196127481758595, 14.419329464435577, 6.809714343398809, 3.472080552019179, 2.548366980627179, 4.567717323079705, 8.351663053035736, 20.89553475379944, 31.875820755958557, 39.72975231707096, 46.78771398961544, 51.412480026483536, 54.78737533092499, 51.358412727713585, 57.6701932400465, 57.15565524995327, 58.75775568187237, 60.026245415210724, 61.155727207660675, 59.321710020303726, 56.80679976940155, 55.13321377336979, 54.473580569028854, 54.31146986782551, 54.06251102685928, 50.89404724538326, 47.79082216322422, 48.381717056035995, 46.06122337281704, 45.326574593782425, 47.10683226585388, 44.637857750058174, 50.62229722738266, 52.79016450047493, 60.0740734487772, 51.730549558997154, 44.05746549367905, 56.38358227908611, 55.16585022211075, 56.28743223845959, 50.539826452732086, 45.923252776265144, 45.73071330785751, 44.71524819731712, 43.58119525015354, 44.871583208441734, 44.9670834839344, 44.07773740589619, 40.46027071774006, 41.07266865670681, 44.11687910556793, 45.84240831434727, 48.251555040478706, 47.894362807273865, 48.246493712067604, 51.057218089699745, 51.04368321597576, 55.79816289246082, 52.528643533587456, 53.77170883119106, 49.162985533475876, 51.85163006186485, 49.97260808944702, 47.31821872293949, 39.6014142036438, 26.780560165643692, 14.811811354011297, 7.126107215881348, 3.8506573252379894, 7.907886290922761, 9.56222489476204, 10.394694674760103, 2.7956104511395097, 0.6348528934177011, 1.421626741066575, 13.16824659705162, 12.570385728031397, 9.16806349530816, 5.586552852764726, 1.2901908438652754, 0.9173332981299609, 0.827443718444556, 6.087919799610972, 15.89800301939249, 23.85315354913473, 27.499040812253952, 41.47288218140602, 41.60542666912079, 29.743219390511513, 11.05568440631032, 1.9661261234432459, 0.09985438169678673, 0.2449189600883983, 0.15514315164182335, 0.07263275372679345, 0.14931488782167435, 0.12470426154322922, 0.14751093462109566, 0.1223747267795261, 0.18553583562606946, 0.18094729981385171, 0.14401040214579552, 0.19134849950205535, 0.07154175211326219, 0.15265999973053113, 0.08130480127874762, 0.13706194062251598, 0.11108536928077228, 0.09761772671481594, 0.1323796418728307, 0.17028017377015203, 0.1105688938696403, 0.16785351414000615, 0.09633528810809366, 0.13766337709967047, 0.1425459369784221, 0.08680280196131207, 0.12792107096174732, 0.13290579488966614, 0.2048393787117675, 0.15723505814094096, 0.07976549051818438], [0.03076443688769359, 0.043883945400011726, 0.04314645098929759, 0.05735635255405214, 0.030420527509704698, 0.027971391937171575, 0.028225330752320588, 0.05616454131086357, 0.015585880464641377, 0.009492990902799647, 0.014575795212294906, 0.029810786400048528, 0.02570242570072878, 0.05876096722204238, 0.06407003194908611, 0.16088966047391295, 0.031534474474028684, 0.08504450568580069, 0.040102487764670514, 0.018114731974492315, 0.07228165850392543, 0.04592694436723832, 0.11833291631774046, 0.058521116225165315, 0.07066065212711692, 0.035175996454199776, 0.06191354746988509, 0.05772382326540537, 0.04437168114236556, 0.05842118232976645, 0.038040467552491464, 0.08060575753916055, 0.03174259123625234, 0.024864424085535575, 0.02647746165166609, 0.03090921320108464, 0.023563810282212216, 0.7706437725573778, 12.657394409179688, 34.924005791544914, 41.530475690960884, 28.641301319003105, 16.390306502580643, 14.56912787631154, 16.621142216026783, 7.241627667099237, 1.3674085191451013, 0.06476957292761654, 0.11286615263088606, 0.11220051295822486, 0.07852788505260833, 1.6419564932584763, 1.2462305277585983, 0.6822109397035092, 2.7022758219391108, 9.37325058504939, 7.1848891116678715, 4.494619220495224, 5.003354921936989, 1.2242248398251832, 3.0356877436861396, 4.60856513120234, 16.762317940592766, 26.307643242180347, 32.68675424158573, 38.70047874748707, 49.551662877202034, 47.97842189669609, 46.12242668867111, 56.0952727496624, 52.48078890144825, 57.957157641649246, 53.78470413386822, 55.36631986498833, 53.91832776367664, 49.915269166231155, 52.41246476769447, 50.2287295460701, 50.287242606282234, 48.967505022883415, 51.97733871638775, 47.943695560097694, 46.06405422091484, 41.93218253552914, 43.19217972457409, 42.08064056932926, 49.671622440218925, 49.07951541244984, 55.28319172561169, 47.82711781561375, 36.41010984778404, 52.57836766541004, 48.32673780620098, 53.90369474887848, 46.23021550476551, 42.00280174612999, 39.35946598649025, 38.99974688887596, 44.17106419801712, 47.66128331422806, 48.739061281085014, 47.22893871366978, 43.33219461143017, 40.05969621241093, 39.65735860168934, 40.15309900045395, 41.25340215861797, 42.24321864545345, 45.03642976284027, 45.71070358157158, 49.04668137431145, 47.655150443315506, 50.39512261748314, 52.15219013392925, 48.78019407391548, 48.90766963362694, 42.463739812374115, 32.7985480427742, 21.467394568026066, 10.100057534873486, 3.2734466856345534, 1.9713183073326945, 2.6836316473782063, 3.000541292130947, 1.8881216528825462, 2.1747306548058987, 1.3728529145009816, 1.4215227216482162, 0.9244934795424342, 1.1189423454925418, 1.646905846428126, 2.1435435907915235, 0.6544264149852097, 0.18189680355135351, 0.3284493583487347, 2.5293207401409745, 6.580993216484785, 11.681263837963343, 16.447554230690002, 26.717339158058167, 26.318915337324142, 26.783512607216835, 14.668948519974947, 3.2011113921180367, 0.2958823152584955, 0.01803402898076456, 0.028121767754782923, 0.04500636954617221, 0.021150559405214153, 0.04731556575279683, 0.03801044025749434, 0.05320958385709673, 0.0816611954360269, 0.02372659851971548, 0.009494290588918375, 0.034518869215389714, 0.05156620543857571, 0.04081605533428956, 0.022320740754366852, 0.03401361878786702, 0.035905267868656665, 0.009643145931477193, 0.06827858815086074, 0.011500702603370883, 0.08248874204582535, 0.03450855707342271, 0.02041601688688388, 0.061911476877867244, 0.04713603280833922, 0.039206852816278115, 0.04862466230406426, 0.0318376121140318, 0.06735712275258265, 0.02667135515366681, 0.02477388763509225, 0.0415353337302804, 0.026530521499807946, 0.01193243959278334, 0.06011972829583101, 0.019723578261618968, 0.041326411737827584, 0.06949274174985476, 0.049370869528502226, 0.032179849804379046, 0.09155375679256395, 0.03501619350572582, 0.0074779277656489285, 0.023756918963044882, 0.051910762340412475, 0.0477467461314518, 0.056931506405817345, 0.11474068407551385, 0.017565457346790936, 0.03441351393121295, 0.03925345226889476, 0.031969257979653776, 0.050456716926419176, 0.035079198132734746, 0.06716815711115487, 0.030120115407044068, 0.02889418763516005, 0.025631582138885278, 0.0902553768537473, 0.028369533756631427, 0.04615691737853922, 0.04887475493887905, 0.01764909924531821, 0.011342748530296376, 0.03569404892914463, 0.0543733530503232, 0.031234190391842276, 0.038939271471463144, 0.02701344812521711, 1.294332027900964, 15.746124219149351, 39.08163629472256, 46.10918439924717, 31.53944380581379, 18.406187631189823, 14.200238920748234, 18.81215214729309, 8.959298897534609, 1.3317176280543208, 0.15052167931571603, 0.07112997889635153, 0.10231867563561536, 0.6919313524849713, 3.1929620169103146, 2.480739396996796, 3.3838212629780173, 7.7539703249931335, 9.935607109218836, 11.613782308995724, 8.03368091583252, 7.091580843552947, 4.143913239240646, 5.245715891942382, 6.3403454795479774, 19.579178988933563, 28.594406135380268, 35.39690941572189, 41.68310970067978, 50.20235136151314, 48.28097686171532, 49.74576026201248, 56.14590883255005, 53.71400132775307, 58.10468092560768, 56.47018723189831, 56.57267153263092, 56.04874424636364, 52.899306043982506, 54.81434628367424, 52.10361734032631, 52.23826691508293, 50.833353102207184, 53.05695578455925, 49.43530552089214, 47.74857982993126, 42.4664718657732, 44.481541737914085, 44.45498116314411, 52.08785578608513, 51.93946614861488, 58.141915127635, 50.31169809401035, 40.28827674686909, 53.56741279363632, 51.32920749485493, 54.33618754148483, 47.65507824718952, 44.56018231809139, 41.60853110253811, 41.23112395405769, 43.89042645692825, 50.72687141597271, 49.27910730242729, 48.30558814108372, 45.25097385048866, 42.19071306288242, 39.793049320578575, 41.93234592676163, 42.08219848573208, 45.19759811460972, 46.031121388077736, 46.921679601073265, 50.4207294434309, 48.997964188456535, 52.738753259181976, 50.8270226418972, 49.47899557650089, 47.10413061082363, 44.97079208493233, 36.36843368411064, 24.214616753160954, 11.819813903421164, 5.058925990015268, 3.4814876597374678, 4.255538424476981, 7.23678482696414, 6.196994371712208, 5.956384157761931, 4.218092858791351, 4.00499221868813, 6.6516513749957085, 6.331095350906253, 1.9103928515687585, 2.660111146979034, 0.24626572063425556, 0.13700619048904628, 0.17818884080043063, 2.926638345234096, 8.250905759632587, 14.973908755928278, 21.22561164200306, 29.563397839665413, 32.597782015800476, 32.12415263056755, 18.15174948424101, 4.190831696614623, 0.3976600617170334, 0.04365977969428059, 0.09122835472226143, 0.013082870536891278, 0.05583416314038914, 0.04091967399290297, 0.04754140871227719, 0.07767293835058808, 0.018981358225573786, 0.0005245701549938531, 0.04119234647077974, 0.0037850827948204824, 0.018278833813383244, 0.018756068166112527, 0.015175493208516855, 0.01664127383264713, 0.09479501255555078, 0.02213680316344835, 0.06479982286691666, 0.011340970158926211, 0.04699782635725569, 0.015523942674917635, 0.04484800636419095, 0.07247425324749202, 0.03973499478888698, 0.06232410727534443, 0.04277161817299202, 0.059278997432556935, 0.042067917456733994, 0.04761665877595078, 0.08470538130495697, 0.062331491644727066, 0.07909255553386174, 0.08188996245735325, 0.1698194188065827, 0.10727346132625826, 0.13429867249215022, 0.1533973086043261, 0.1283546633203514, 0.1468268525786698, 0.11222648070543073, 0.12364267124212347, 0.06688139867037535, 0.15149657934671268, 0.16230621258728206, 0.1483632021700032, 0.11287197849014774, 0.26189818570856005, 0.1301380293443799, 0.17577037448063493, 0.14609865727834404, 0.168404855648987, 0.09212749631842598, 0.10037714309873991, 0.269741885131225, 0.0963539828080684, 0.22256103402469307, 0.17659559816820547, 0.20243427105015144, 0.19246149837272242, 0.15952781948726624, 0.11853999778395519, 0.1174327579792589, 0.2838328352663666, 0.11768836848204955, 0.09030681510921568, 0.1286479303962551, 0.18655343883438036, 0.1398142843390815, 1.6454144264571369, 18.116082698106766, 48.04272584617138, 54.377289935946465, 39.22698609530926, 24.344792068004608, 20.371320582926273, 24.786083288490772, 9.007018636912107, 1.971375304274261, 0.5684499128255993, 0.3100082650780678, 0.2456047193845734, 0.8285278477706015, 3.9053846010938287, 3.0356642324477434, 4.322936832904816, 12.114460542798042, 21.73564687371254, 17.12231632322073, 9.68997498974204, 10.252036079764366, 3.6153373774141073, 5.219262186437845, 6.97002774104476, 19.42984700202942, 30.70883497595787, 36.93674638867378, 42.27657325565815, 50.98691426217556, 49.48357433080673, 51.91154144704342, 59.760483875870705, 55.69531001150608, 58.865183517336845, 57.65848986804485, 57.81757973134518, 59.10033009946346, 54.863538444042206, 56.4957370609045, 54.002280458807945, 54.079541712999344, 52.036186158657074, 56.18826135993004, 51.91901184618473, 49.86973620951176, 45.046989396214485, 45.82701154053211, 46.77926704287529, 52.715589702129364, 54.03232544660568, 58.35596904158592, 53.720069602131844, 43.73001046478748, 54.679548516869545, 54.945697635412216, 56.66122578084469, 50.71816228330135, 45.66275015473366, 42.62832798063755, 42.2762730717659, 47.16958969831467, 53.37418936192989, 52.40067400038242, 51.146726086735725, 47.10416100919247, 44.32699643075466, 42.041206285357475, 44.157571122050285, 44.287220165133476, 46.99581362307072, 48.88048589229584, 49.54696632921696, 53.57118599116802, 51.195956245064735, 53.517069295048714, 53.513896465301514, 49.327987879514694, 47.911066710948944, 46.215255707502365, 36.09649367630482, 23.73755805194378, 12.131839860230684, 4.939424777403474, 3.310049409046769, 4.805702827870846, 8.760952390730381, 6.873965570703149, 9.012079015374184, 6.221599001437426, 5.630041994154453, 10.138353779911995, 9.083123803138733, 6.676678257063031, 6.508867386728525, 1.3583758100867271, 0.5711449182126671, 0.8106463635340333, 4.136085659265518, 9.016292039304972, 19.34147324413061, 25.24618349969387, 37.24665015935898, 38.36507074534893, 37.67413482069969, 20.39833903312683, 4.970812043175101, 0.4860049649141729, 0.1129292426048778, 0.19581299275159836, 0.13841883890563622, 0.16266401682514697, 0.1424573690746911, 0.1581226519192569, 0.2797611162532121, 0.13950127613497898, 0.12293581268750131, 0.18216912721982226, 0.09986223361920565, 0.11094309214968234, 0.12839473929489031, 0.07600324708619155, 0.13669200969161466, 0.207535155932419, 0.17282167333178222, 0.16090362769318745, 0.07893615533248521, 0.15420139592606574, 0.0944510567933321, 0.13714552129385993, 0.1988271513255313, 0.1971960294758901, 0.14280502073233947, 0.10552378138527274, 0.13511935423593968, 0.17196927219629288, 0.10582291142782196, 0.17049587157089263, 0.17900643520988524], [0.03042969859961886, 0.05780127008620184, 0.026391836363472976, 0.1330822627642192, 0.010069101590488572, 0.05671763057762291, 0.020106494921492413, 0.027523891731107142, 0.04404210078064352, 0.04740972945000976, 0.054256680014077574, 0.044604541108128615, 0.03982045309385285, 0.04136957875743974, 0.10323159149265848, 0.11622267877100967, 0.01128452518969425, 0.040558385371696204, 0.07249803165905178, 0.05236859324213583, 0.08821015886496753, 0.03619315437390469, 0.007529752401751466, 0.02415811100945575, 0.061506876518251374, 0.05568999724346213, 0.035390877892496064, 0.023186459729913622, 0.01149752064520726, 0.007796449663146632, 0.023050414783938322, 0.04569550932501443, 0.001488366033299826, 0.0675090700678993, 0.0646036361285951, 0.006011852137817186, 0.03409616416320205, 0.06713339491398074, 3.162523750215769, 18.735173977911472, 43.040172681212425, 38.51078912615776, 23.874656595289707, 32.603363916277885, 24.475584849715233, 8.816102631390095, 3.4870477113872766, 0.5246696120593697, 0.317757444572635, 0.16681711975252256, 0.5346977489534765, 5.0877198949456215, 0.5736207228619605, 3.254440580494702, 1.4994719764217734, 8.673765119165182, 10.774806328117847, 8.397375550121069, 10.884863622486591, 4.740776186808944, 2.2559669706970453, 0.893671017838642, 2.942648073658347, 15.905747953802347, 16.831217743456364, 26.641865707933903, 34.10274066030979, 48.04190129041672, 43.243780955672264, 47.196530252695084, 55.98947122693062, 48.850984275341034, 60.20219877362251, 55.43562054634094, 57.913209199905396, 53.86468984186649, 54.69775713980198, 51.1966136097908, 53.33421930670738, 51.663654148578644, 53.65196205675602, 51.5380784869194, 53.76523397862911, 45.44922061264515, 41.583779230713844, 42.07659378647804, 52.006448954343796, 49.69626411795616, 58.199235051870346, 45.7108061760664, 35.360191985964775, 50.3409793227911, 47.920604199171066, 52.67055071890354, 48.114420399069786, 43.80602538585663, 39.258824586868286, 45.08890874683857, 48.20315323770046, 51.82605743408203, 51.530516892671585, 52.4310077726841, 49.76211078464985, 46.440629214048386, 45.948859602212906, 46.612714380025864, 43.85430559515953, 46.152665466070175, 45.580632761120796, 48.98859389126301, 48.97410526871681, 51.9778972864151, 47.01454661786556, 50.776774138212204, 43.975306302309036, 37.489016354084015, 26.220871098339558, 18.950951099395752, 11.030773892998695, 3.5740433307364583, 1.2999711628071964, 1.9752054987475276, 3.0766915809363127, 4.658227516338229, 4.340364597737789, 4.512721449136734, 2.7732040034607053, 3.778008548542857, 6.477112015709281, 2.9842335171997547, 0.9721799113322049, 1.653704394120723, 0.1816098002018407, 0.37777053366880864, 1.2835973664186895, 6.222208393737674, 11.816060654819012, 17.125143371522427, 22.045611441135406, 25.28473623096943, 26.25582542270422, 16.80345643311739, 5.886013833805919, 0.7291678106412292, 0.04134994524065405, 0.104160574846901, 0.059265961608616635, 0.08866076124832034, 0.0631059895385988, 0.053949738867231645, 0.034167966950917616, 0.016765483378549106, 0.014305969798442675, 0.04720798402559012, 0.029601313362945803, 0.041311839668196626, 0.08028283424209803, 0.048520205018576235, 0.0038036158457543934, 0.049993761494988576, 0.039996776249608956, 0.03792785035329871, 0.028545925561047625, 0.10368863571784459, 0.07173921534558758, 0.07041300486889668, 0.06458339033997618, 0.03665787982754409, 0.052254506590543315, 0.03457398481259588, 0.012965939604328014, 0.08668258145917207, 0.029949132003821433, 0.04029481904581189, 0.05184353489312343, 0.01664381197770126, 0.07273843555594794, 0.027304856121190824, 0.05292024645314086, 0.11266998073551804, 0.016585826124355663, 0.03253305272664875, 0.03864143647660967, 0.046859686699463055, 0.05433541817183141, 0.06809333324781619, 0.04241969174472615, 0.062233305507106707, 0.05781386804301292, 0.044809418395743705, 0.0682503345888108, 0.1002496198634617, 0.05564989900449291, 0.04533274382993113, 0.05905628262553364, 0.07581556536024436, 0.08850819795043208, 0.07025392551440746, 0.042108104753424414, 0.06273087099543773, 0.07408192323055118, 0.021902041444263887, 0.0861163079389371, 0.02110429577442119, 0.04416662202856969, 0.026827245128515642, 0.046295138672576286, 0.02103890699800104, 0.03023622997716302, 0.1148591234232299, 0.041685637188493274, 0.01241693586052861, 0.12243905614013784, 0.031457313380087726, 4.059214359149337, 23.041196018457413, 49.11718659102917, 40.33586159348488, 23.503880091011524, 22.829750664532185, 30.953268259763718, 14.86709838733077, 4.879417447373271, 0.7278830639552325, 0.06452015935792588, 0.35678140993695706, 1.0237200488336384, 1.4037260203622282, 2.9950719606131315, 6.204084316268563, 5.25616723112762, 5.698444498702884, 10.67870568484068, 11.576265972107649, 7.12605164386332, 5.929981749504805, 3.099012770690024, 1.7174669913947582, 5.633549680933356, 18.46493437886238, 20.114632956683636, 30.99066775292158, 36.864117085933685, 49.36060152947903, 44.470693320035934, 51.581692546606064, 55.236344039440155, 52.70332396030426, 59.791516810655594, 58.3453144133091, 59.51158583164215, 55.62187135219574, 55.43943174183369, 54.94708836078644, 54.10998187959194, 53.16751845180988, 55.03436587750912, 55.004856660962105, 53.651718869805336, 46.830062717199326, 43.13591234385967, 43.72723661363125, 51.85574144124985, 54.02947559952736, 59.21973869204521, 48.2892794162035, 38.512962609529495, 53.0299012362957, 50.76911374926567, 54.80378285050392, 49.90966446697712, 45.25404408574104, 41.004602909088135, 45.75725868344307, 49.91562254726887, 53.80688734352589, 53.87756735086441, 54.75606121122837, 49.9484945833683, 48.96715544164181, 47.60895252227783, 48.28588619828224, 45.18748305737972, 46.971339136362076, 46.686282232403755, 49.637287482619286, 51.408919617533684, 52.438345178961754, 48.939910903573036, 52.74036057293415, 45.249157547950745, 41.01586930453777, 30.048016235232353, 21.96668967604637, 12.594570480287075, 5.665184883400798, 2.088655773550272, 3.1594957876950502, 4.82155367732048, 10.914753768593073, 8.503106776624918, 5.753801828250289, 6.970347398892045, 9.2798743955791, 5.8933802135288715, 3.2131949812173843, 1.8330542952753603, 0.769078197190538, 0.32916389813181013, 0.2580512483837083, 1.4985796180553734, 8.869105037301779, 14.896402414888144, 19.066624492406845, 23.59765525907278, 31.590625159442425, 30.526729747653008, 22.73679055273533, 8.887639492750168, 1.2868625787086785, 0.0639852935273666, 0.05375466535042506, 0.02574215472122887, 0.03521103324601427, 0.05487753849592991, 0.02207620123954257, 0.032611497736070305, 0.009195573366014287, 0.021491574407264125, 0.03739271734957583, 0.008760064411035273, 0.11152797131217085, 0.05938502807111945, 0.07556071184808388, 0.048655813952791505, 0.024836228039930575, 0.051936236559413373, 0.03970048863266129, 0.029046131239738315, 0.06030990363797173, 0.04386359571071807, 0.10371555341407657, 0.025960531675082166, 0.03155476108076982, 0.02921201794379158, 0.041792866395553574, 0.04529826735961251, 0.045739492707070895, 0.012891463229607325, 0.0371826932678232, 0.07323679514229298, 0.02178313454351155, 0.20322032418334857, 0.0844699572189711, 0.13160757080186158, 0.16094941820483655, 0.11361107593984343, 0.24513925920473412, 0.14292665873654187, 0.15431141189765185, 0.23913285025628284, 0.17938101198524237, 0.10808614271809347, 0.10507947983569466, 0.13319667225005105, 0.11629791028099135, 0.18393806589301676, 0.2405387451290153, 0.1576313650002703, 0.16042203322285786, 0.13505244220141321, 0.16260317555861548, 0.2606064628344029, 0.14575581473764032, 0.12277585759875365, 0.14835394016699865, 0.11485215465654619, 0.2718875231221318, 0.16487143118865788, 0.09246368921594694, 0.11936758892261423, 0.19940408208640292, 0.09404018157511018, 0.1620405979338102, 0.08231414438341744, 0.2522339386632666, 0.2232630760408938, 0.10906120602157898, 0.14684458990814164, 0.20812011673115194, 4.856785386800766, 28.161607459187508, 56.271043717861176, 51.91445969045162, 32.50534437596798, 41.9181726872921, 34.76883351802826, 12.813269644975662, 5.159352226182818, 1.363646483514458, 0.7752046559471637, 2.343284860253334, 3.170131416991353, 8.626790139824152, 6.373701989650726, 13.27739953994751, 12.424901984632015, 15.608789138495922, 23.64901140332222, 18.841800056397915, 19.485314525663853, 9.40307043492794, 4.014107454568148, 1.397974316496402, 4.498463664203882, 18.978112041950226, 19.67531193047762, 29.906143248081207, 36.7894396930933, 49.06650111079216, 45.45822612941265, 49.88122299313545, 58.76474350690842, 50.56145489215851, 59.86343555152416, 59.32030029594898, 62.15377025306225, 57.80773065984249, 58.09908762574196, 55.395483300089836, 56.9568233191967, 56.107420697808266, 57.495117634534836, 57.45813421905041, 57.13854856789112, 50.48911437392235, 44.103633016347885, 46.695173755288124, 55.2518168091774, 56.45758330821991, 61.42624229192734, 50.5651368945837, 42.854400649666786, 53.91607068479061, 52.858933210372925, 57.08456106483936, 53.01424227654934, 47.283834367990494, 43.880429193377495, 47.989505901932716, 53.0181522667408, 56.07307434082031, 55.12158639729023, 57.511118575930595, 52.73595280945301, 51.69179543852806, 49.41840402781963, 50.796498879790306, 48.03191162645817, 50.763269662857056, 48.647315204143524, 52.79942840337753, 52.720993012189865, 56.10475704073906, 51.07448436319828, 53.563821986317635, 45.40821321308613, 40.21412752568722, 27.95972429215908, 23.195216953754425, 12.651803959161043, 5.300500402227044, 2.3082236666232347, 3.6281144293025136, 7.24166234023869, 14.94453253224492, 12.976393941789865, 10.752206090837717, 10.674162078648806, 15.44183749705553, 16.943066641688347, 8.711028769612312, 4.796544369310141, 3.757811919786036, 0.8675401762593538, 0.865381060866639, 2.1830291720107198, 9.734854381531477, 18.161163479089737, 24.49885480105877, 34.82398375868797, 35.979414358735085, 38.9703668653965, 25.348610803484917, 9.898899178951979, 1.333429436199367, 0.15112559456611052, 0.231969507294707, 0.1234220975311473, 0.18125665665138513, 0.16856884059961885, 0.15119648451218382, 0.10910093318670988, 0.14457560697337613, 0.09796966056455858, 0.07570359754026867, 0.1447554590413347, 0.17122022254625335, 0.12565297860419378, 0.16819372947793454, 0.07874459959566593, 0.09020864381454885, 0.12411904099280946, 0.16582976648351178, 0.08970198701717891, 0.27122727886307985, 0.2509989158716053, 0.12767254054779187, 0.12634373997570947, 0.15124583733268082, 0.07227705718833022, 0.15456270310096443, 0.1186177006457001, 0.20585051039233804, 0.12192448062705807, 0.12902440706966445, 0.2508867625147104, 0.14735021512024105], [0.031123853441386018, 0.03542966253007762, 0.04946955661580432, 0.05535885095014237, 0.006801353938499233, 0.01880221676401561, 0.06345738162053749, 0.028083118559152354, 0.029351766206673346, 0.020890314190182835, 0.017786544995033182, 0.026569196670607198, 0.01935246546054259, 0.022633340777247213, 0.002020088172685064, 0.10051567238406278, 0.04477507551200688, 0.006880684422867489, 0.08402952968026511, 0.01740207168040797, 0.05933552311034873, 0.01664619612711249, 0.02255788476759335, 0.026178489315498155, 0.03805433458182961, 0.02835534389305394, 0.03952984661736991, 0.04421614183229394, 0.0471635034045903, 0.08004781833733432, 0.049328719251207076, 0.03248489476391114, 0.0370759946963517, 0.010115368004335323, 0.023805679920769762, 0.040572771904408, 0.08875528117641807, 0.06156455623568036, 0.5517885193694383, 7.3143367655575275, 30.409221053123474, 43.9551217854023, 40.44665984809399, 21.056119836866856, 22.14357778429985, 18.583387322723866, 9.63608818128705, 2.2490931395441294, 0.5463605106342584, 0.10747361113317311, 0.6918662809766829, 2.4043753696605563, 1.7776817665435374, 2.2811382450163364, 6.989025296643376, 3.1112725753337145, 7.280923733487725, 7.90637444704771, 3.6303586838766932, 5.004402715712786, 2.7289914758875966, 0.25721187936142087, 0.8101164107210934, 4.106058720499277, 7.799825314432383, 12.59201131761074, 20.988179482519627, 24.1656506806612, 44.66156467795372, 34.62392449378967, 53.8101551681757, 54.41525749862194, 52.62323945760727, 56.86535082757473, 56.17343835532665, 53.41545894742012, 58.00843968987465, 53.557647317647934, 54.16660264134407, 53.843878358602524, 54.613777846097946, 52.072451412677765, 55.14691583812237, 48.86178329586983, 44.876530542969704, 42.3405010253191, 51.855122074484825, 48.88452127575874, 59.313263073563576, 47.89608411490917, 35.50389267504215, 52.17851132154465, 49.52438794076443, 51.67558170855045, 46.98783405125141, 44.46622475981712, 42.52623125910759, 44.89009201526642, 53.163095489144325, 52.865237072110176, 54.80206534266472, 52.62619949877262, 51.69739633798599, 51.296217665076256, 48.973352909088135, 47.31977663934231, 47.27816507220268, 47.28616364300251, 49.120272025465965, 48.11920814216137, 50.595786049962044, 47.106801867485046, 52.86761574447155, 43.11635099351406, 35.88267154991627, 22.99139019101858, 14.475163668394089, 8.578796815127134, 4.786187075078487, 1.7729797563515604, 1.19652159512043, 2.4434443982318044, 4.500150298699737, 11.588064339011908, 8.380081728100777, 4.091787161305547, 5.152855524793267, 6.396355899050832, 3.692460651509464, 2.8000008780509233, 1.4628493040800095, 0.7826584309805185, 0.15042321116197854, 0.5489690112881362, 2.7319063944742084, 10.443719644099474, 13.941493704915047, 14.138250946998596, 20.08895393460989, 29.332085251808167, 17.845810800790787, 15.60594879090786, 4.11690428853035, 0.12824228731915355, 0.013120940857334062, 0.011267175632383442, 0.056232588831335306, 0.055121411933214404, 0.023057546823110897, 0.04541507769317832, 0.0244154284519027, 0.046683441469212994, 0.013083048652333673, 0.015036393397167558, 0.034104505903087556, 0.06344941837596707, 0.07114663269021548, 0.05885690094146412, 0.0396821612957865, 0.018315228735446, 0.005272602084005484, 0.08064788926276378, 0.05749432151787914, 0.060494327335618436, 0.021722250603488646, 0.005121895082993433, 0.07116995839169249, 0.02257407657452859, 0.02642833333084127, 0.06252060571569018, 0.032149956095963717, 0.0025805516042964882, 0.06426140214898624, 0.06699380435748026, 0.049292235271423124, 0.0286590251562302, 0.02865514557925053, 0.015483053120988188, 0.033773786344681866, 0.06242275354452431, 0.05192859985982068, 0.022394155857909936, 0.07305164413992316, 0.00759203529014485, 0.017511633086542133, 0.03476679106825031, 0.0518373676459305, 0.027243380318395793, 0.012825003905163612, 0.04617274367774371, 0.10327447278541513, 0.038359197715180926, 0.04806191769603174, 0.053436499219969846, 0.028924675061716698, 0.008721505200810498, 0.057669442394399084, 0.028635849739657715, 0.04750443491502665, 0.040907662332756445, 0.008369755960302427, 0.0485401984769851, 0.04337307320383843, 0.038415415401686914, 0.02249161283543799, 0.07856844342313707, 0.045243775166454725, 0.02487907408067258, 0.03781100662308745, 0.06750452812411822, 0.03263070451794192, 0.03292293258709833, 0.13414976798230782, 0.10381699015852064, 0.6799808156210929, 9.999869260936975, 36.688615903258324, 50.04414305090904, 42.515010461211205, 27.174557223916054, 23.48219085484743, 18.082287311553955, 10.785160772502422, 3.149181716144085, 0.526015927316621, 0.14087999355979264, 0.3740460507106036, 0.6152695755008608, 0.5570462497416884, 3.1863748328760266, 5.09206828661263, 7.640172131359577, 9.908419568091631, 7.575887180864811, 7.853199625387788, 7.046245951205492, 5.428781043738127, 1.6860686824657023, 1.324787512421608, 6.038683941587806, 9.277603067457676, 15.050776731222868, 21.92181598395109, 31.13295491784811, 44.72801171243191, 39.48266677558422, 55.80599807202816, 54.59241919219494, 53.71952623128891, 57.322808280587196, 56.11646041274071, 56.81630685925484, 59.108556658029556, 55.227167531847954, 55.833151414990425, 55.4800021648407, 55.44319733977318, 55.33977448940277, 56.748225912451744, 51.20649687945843, 45.857755690813065, 43.698867335915565, 52.83769994974136, 50.753443390131, 59.56262469291687, 48.63317236304283, 39.47307609021664, 54.22613404691219, 51.00978143513203, 53.40947426855564, 49.188805148005486, 45.62935754656792, 44.34675917029381, 47.656522169709206, 54.08256635069847, 55.71541093289852, 57.43104167282581, 53.992488384246826, 53.8843347877264, 52.198205664753914, 49.31142456829548, 49.39950004220009, 49.33601304888725, 49.2726818472147, 50.42278133332729, 50.0886120647192, 52.00663514435291, 50.54599732160568, 53.225978314876556, 45.63761830329895, 38.916956931352615, 26.158183962106705, 17.556150443851948, 9.769969247281551, 5.5835016164928675, 5.624010292813182, 3.4391534188762307, 3.773487266153097, 5.577163081616163, 9.71627812832594, 8.43135142698884, 7.846576105803251, 7.936447933316231, 6.99483803473413, 4.31495726108551, 2.775581725873053, 0.9155938820913434, 0.1944691562675871, 0.016468880348838866, 0.7791767490562052, 4.374961266294122, 12.489431072026491, 16.64279915392399, 17.43217259645462, 26.60218633711338, 32.94924795627594, 24.551742263138294, 17.99822822213173, 5.072287023067474, 0.07024973980151117, 0.09556855307891965, 0.032879457576200366, 0.014179817680997076, 0.09445644478546456, 0.06086230270739179, 0.02566084687714465, 0.0518974333681399, 0.007379056996796862, 0.04403072736749891, 0.06686649634502828, 0.028083190918550827, 0.061004628078080714, 0.048263032294926234, 0.020123183967371006, 0.030316999764181674, 0.0294433360977564, 0.011092731965618441, 0.05493863580340985, 0.05577833508141339, 0.02953200975753134, 0.06670332033536397, 0.00702575898685609, 0.03799412414082326, 0.09690455248346552, 0.060353322987793945, 0.020847577616223134, 0.041835751399048604, 0.016001308758859523, 0.09898442876874469, 0.03140900327707641, 0.060630555963143706, 0.04390318186779041, 0.09275657779653557, 0.1479501969879493, 0.17012953263474628, 0.2375202820985578, 0.11441947513958439, 0.089205148833571, 0.21912852680543438, 0.09446954369195737, 0.06706358108203858, 0.124702361645177, 0.08514825050951913, 0.11843346248497255, 0.17006374866468832, 0.10790069485665299, 0.1996439739014022, 0.1910280846641399, 0.207342034264002, 0.15988899307558313, 0.2594908367609605, 0.14865376782836393, 0.1279978090315126, 0.1277726117405109, 0.15813169127795845, 0.10342862427933142, 0.11708831239957362, 0.22613212990108877, 0.14183717110427096, 0.09669456179835834, 0.17812489735661075, 0.19171035586623475, 0.07960986957186833, 0.08837954665068537, 0.07708071192610078, 0.17252747114980593, 0.1760463198297657, 0.1713819068390876, 0.23829962621675804, 0.09183037749608047, 0.835302765481174, 12.086224257946014, 44.557568058371544, 58.119177147746086, 48.688888773322105, 32.23428212106228, 32.218235582113266, 26.102636642754078, 13.690729010850191, 3.6799039877951145, 0.8009216166101396, 0.6295087176840752, 1.5487260022200644, 5.253108395263553, 5.741246351972222, 7.747738184407353, 17.494491152465343, 14.051816035062075, 17.827919460833073, 18.54904856532812, 11.577231120318174, 10.27546752244234, 5.3655538614839315, 1.5646423981525004, 1.7536228825338185, 5.372011614963412, 9.77872397750616, 14.146047178655863, 23.089829608798027, 28.800292387604713, 44.98017378151417, 41.53736092150211, 58.04016038775444, 56.92748889327049, 54.91453170776367, 57.295271158218384, 56.72442018985748, 56.53764121234417, 61.716406121850014, 57.78803251683712, 58.087414652109146, 56.36312037706375, 57.398097440600395, 56.01794309914112, 59.18741762638092, 53.56356360018253, 47.58910998702049, 46.02839693427086, 56.48080386221409, 53.04219737648964, 60.96849985420704, 52.14334040880203, 42.68911711871624, 55.55951289832592, 55.62975972890854, 54.38054256141186, 51.70604847371578, 48.032371401786804, 46.458902433514595, 47.74664953351021, 57.15846709907055, 57.905123233795166, 57.663988173007965, 54.270040690898895, 55.16271159052849, 55.041292905807495, 53.55802729725838, 51.70267425477505, 52.22253955900669, 50.95575973391533, 53.206553757190704, 50.8411730825901, 55.22130064666271, 51.62901520729065, 55.75561657547951, 45.83115331828594, 38.23229067027569, 23.937054947018623, 16.642056293785572, 10.211162623018026, 6.16892147809267, 3.1799272913485765, 3.589118071831763, 6.35252240113914, 10.266237817704678, 19.81538951396942, 18.532717041671276, 12.241886705160141, 13.195114005357027, 14.276102799922228, 10.657568369060755, 9.652240164577961, 2.665518494322896, 1.3972809724509716, 0.3718908241717145, 1.2036387319676578, 5.304265050217509, 16.372671648859978, 21.958552412688732, 23.436857387423515, 30.250701159238815, 41.05675891041756, 29.65463664382696, 21.791159994900227, 6.127399681136012, 0.315860960399732, 0.1904240358271636, 0.08559408830478787, 0.1748651175876148, 0.19098542601568624, 0.1580259797628969, 0.11288876587059349, 0.14545678859576583, 0.11481181893032044, 0.23902108281617984, 0.10260078823193908, 0.08280060734250583, 0.10724169740569778, 0.13117449794663116, 0.11912013462278992, 0.13417799927992746, 0.08714445706573315, 0.15010989125585184, 0.160018275200855, 0.20185567787848413, 0.2550244436133653, 0.15128131199162453, 0.10469493601704016, 0.30548107519280165, 0.2063350289245136, 0.2310497043072246, 0.15152440988458693, 0.12298238245421089, 0.11108404825790785, 0.22833565541077405, 0.12116599828004837, 0.17909252434037626, 0.1409660530043766], [0.0335723563330248, 0.017098644602810964, 0.08501832271576859, 0.07377051806543022, 0.051978205010527745, 0.02883056517021032, 0.047682476142654195, 0.0786839216016233, 0.02092092592647532, 0.04046890462632291, 0.051347349799470976, 0.08753167261602357, 0.04959140242135618, 0.012286515466257697, 0.010067600596812554, 0.06372551957610995, 0.06254388688830659, 0.010089042170875473, 0.030421811425185297, 0.06833568899310194, 0.068574126198655, 0.036061371210962534, 0.07084198849042878, 0.04286762610718142, 0.06713367693009786, 0.004022568427899387, 0.05751255608629435, 0.04057092395669315, 0.031818512943573296, 0.04732905428681988, 0.024043011326284613, 0.09031851135659963, 0.03360804992553312, 0.1038395069190301, 0.04400118617922999, 0.030079484677116852, 0.007706570941081736, 0.09582437138305977, 0.12969738658284768, 2.3559519555419683, 9.123498536646366, 34.01647388935089, 48.15181419253349, 21.541406996548176, 22.92569361627102, 24.76756688207388, 12.42324622347951, 6.779962414875627, 1.49114899802953, 0.355164774809964, 0.3245293046347797, 0.45470132434275, 0.803992742439732, 3.1480116164311767, 1.6472853510640562, 4.615841740742326, 7.475537890568376, 7.900598281994462, 5.535143511369824, 4.107391973957419, 5.631472617387772, 3.039638106711209, 0.7362676702905446, 0.7387972064316273, 1.4908690005540848, 3.1833226466551423, 7.196939690038562, 14.306802302598953, 22.35690973699093, 34.854366928339005, 31.22895486652851, 46.90903387963772, 57.202875316143036, 54.31762933731079, 55.29444672167301, 57.18236401677132, 53.06315705180168, 54.523232504725456, 55.76205722987652, 55.16071289777756, 57.8841407597065, 56.74185365438461, 55.262334644794464, 50.52233599126339, 47.22722500562668, 44.671086966991425, 52.57349632680416, 51.06873907148838, 56.79217055439949, 50.68367153406143, 35.28274454176426, 53.07345449924469, 51.408235654234886, 54.34254840016365, 47.0727214962244, 45.224204286932945, 45.30285246670246, 51.80370323359966, 51.94563701748848, 53.635520339012146, 51.32709480822086, 55.3031862527132, 49.78677146136761, 53.13498839735985, 50.58227397501469, 51.40187479555607, 50.654432103037834, 50.93351952731609, 49.19639714062214, 49.75418820977211, 49.62906092405319, 50.921344980597496, 44.39664289355278, 32.78846338391304, 20.06478913128376, 13.12024187296629, 6.737811751663685, 3.1600218219682574, 1.7670087330043316, 4.981397800147533, 1.9446575129404664, 1.82249098084867, 3.1349961273372173, 7.30934145860374, 4.344322085380554, 5.268804877996445, 6.1022241320461035, 6.68461175635457, 2.4668777408078313, 1.5370770148001611, 0.7537344424054027, 0.21821298374561593, 0.21698711905628443, 4.621412241831422, 9.28632264956832, 15.165065098553896, 19.043084755539894, 20.033758096396923, 23.558471761643887, 26.08313038945198, 16.013195738196373, 8.95856173709035, 1.0929674142971635, 0.10043567628599703, 0.0653223913104739, 0.10276979010086507, 0.03017573937540874, 0.015986562284524553, 0.09662169773946516, 0.024827849192661233, 0.020664480507548433, 0.05466881317261141, 0.04457384588022251, 0.0632785537163727, 0.015048101704451256, 0.012855809527536621, 0.04154390553594567, 0.02023658042162424, 0.01577408726006979, 0.04233197731082328, 0.020534075883915648, 0.0381939882208826, 0.05384081385273021, 0.08474453701637685, 0.03156653154292144, 0.09778089530300349, 0.057554572777007706, 0.021575730243057478, 0.02232421586086275, 0.06807318393839523, 0.038741418611607514, 0.05256939613900613, 0.045261308405315503, 0.03419063585170079, 0.01829711105528986, 0.013119913910486503, 0.0582780220429413, 0.07032829613308422, 0.028736562890117057, 0.06248157616937533, 0.048035619693109766, 0.023168993284343742, 0.04593481484334916, 0.0011123346484964713, 0.05503648797457572, 0.029588611505459994, 0.05170896496565547, 0.02286932518472895, 0.03016128233866766, 0.07915998707176186, 0.05672318555298261, 0.0058318609171692515, 0.026408864941913635, 0.02871728931495454, 0.08948609625804238, 0.11636162365903147, 0.027923838824790437, 0.05060782561486121, 0.018061211994790938, 0.05117061475175433, 0.11322004575049505, 0.01345185801255866, 0.062018568787607364, 0.12827351689338684, 0.0347380439779954, 0.005817963738081744, 0.028492563287727535, 0.0781295595515985, 0.03024562742211856, 0.03193131567968521, 0.04588641939335503, 0.014977073533373186, 0.03474363235000055, 0.03547619890014175, 0.07215950841782615, 3.184580854140222, 13.270781245082617, 40.760880187153816, 51.35128811001778, 24.656781926751137, 26.734151355922222, 29.529418163001537, 19.594801850616932, 10.134551133960485, 2.5307606253772974, 0.12369417629088275, 0.13399676681729034, 0.12441939557902515, 0.6020494911354035, 2.0360798947513103, 3.2277125772088766, 4.33675336651504, 7.047476135194302, 8.54766983538866, 8.697743732482195, 8.741665575653315, 10.881848484277725, 4.2892511654645205, 3.172617433592677, 2.742984937503934, 3.0637060152366757, 5.313049228861928, 10.733967069536448, 14.932975452393293, 27.845728509128094, 35.82471705973148, 36.774916872382164, 51.38932026922703, 57.407110556960106, 54.10710163414478, 55.20229406654835, 54.43355351686478, 55.3608937561512, 56.31617769598961, 57.11035028100014, 56.41988553106785, 59.38139721751213, 57.92078219354153, 57.44856633245945, 51.714788004755974, 48.375815972685814, 46.62813015282154, 54.153451547026634, 52.47178338468075, 58.28579440712929, 52.47472062706947, 39.04903404414654, 56.13797105848789, 53.52973401546478, 56.00608393549919, 50.04554137587547, 46.903216391801834, 46.59882612526417, 52.340785413980484, 54.03196446597576, 55.01239165663719, 51.616354286670685, 55.59828221797943, 53.64529721438885, 53.92811983823776, 52.45226003229618, 51.93474680185318, 52.414626851677895, 51.78425967693329, 50.978531911969185, 52.06473022699356, 52.54853926599026, 51.34730592370033, 47.024813666939735, 34.34127666056156, 25.7802277430892, 16.98386125266552, 8.129318933933973, 4.473947379738092, 3.0113042145967484, 9.241769090294838, 4.409452015534043, 5.5065547954291105, 6.878984151408076, 8.377509266138077, 8.600764386355877, 7.634395966306329, 8.153924513608217, 5.558271445333958, 3.1300732539966702, 1.4711517398245633, 0.1891285873716697, 0.0813911427394487, 0.4348439461318776, 4.767480678856373, 11.300071142613888, 19.631122201681137, 22.063326090574265, 25.938420854508877, 27.969993241131306, 32.70775951445103, 19.096304699778557, 12.338114641606808, 1.6475861286744475, 0.04803527088370174, 0.06110702219302766, 0.02445556194288656, 0.006915212379681179, 0.0395581781049259, 0.0451008078380255, 0.017533201753394678, 0.049398514529457316, 0.08505573438014835, 0.06042991633876227, 0.05691676364222076, 0.07103555544745177, 0.030849438771838322, 0.03243368286348414, 0.03143210262351204, 0.07599780714372173, 0.08564177129301243, 0.030953747627791017, 0.023844369934522547, 0.03785724242334254, 0.042588021970004775, 0.04985388521163259, 0.03937620349461213, 0.028228555383975618, 0.02864369238523068, 0.032220345092355274, 0.03976240972406231, 0.04506916637183167, 0.016205302890739404, 0.033376343999407254, 0.008100165250652935, 0.03459224906691816, 0.022213103366084397, 0.10897297208430246, 0.1226574627798982, 0.14140239130938426, 0.20827829808695242, 0.2304705322603695, 0.11539666098542511, 0.15102052129805088, 0.13623487640870735, 0.14825700083747506, 0.10246171717881225, 0.17509396624518558, 0.19753826345549896, 0.1990548867615871, 0.18881620257161558, 0.13583946012658998, 0.20504027808783576, 0.16811856476124376, 0.06520518392790109, 0.1678692625137046, 0.1626247275271453, 0.18806835520081222, 0.2441883008577861, 0.23194561013951898, 0.20964194991393015, 0.21809662983287126, 0.12629631673917174, 0.12761426711222157, 0.14742909057531506, 0.07266133383382112, 0.20795638411073014, 0.1450892473803833, 0.16479028476169333, 0.18284704943653196, 0.20697465632110834, 0.2047411777311936, 0.09106263314606622, 0.12982266111066565, 0.18471761781256646, 0.20768728136317804, 3.7709121918305755, 18.102830909192562, 49.189842492341995, 60.02765133976936, 29.60495050996542, 36.22634030878544, 35.01692220568657, 21.954454332590103, 10.770499259233475, 2.4068915471434593, 0.6386741227470338, 0.9992195572704077, 0.5945374723523855, 3.492630561813712, 7.3402466252446175, 7.198958806693554, 11.93110328167677, 18.711725436151028, 19.340762682259083, 13.60658822581172, 12.01603252440691, 13.834318555891514, 8.388267438858747, 3.212820226326585, 1.8980052787810564, 2.517937500961125, 5.086912913247943, 9.239284973591566, 17.010226137936115, 26.30101639777422, 35.29154106974602, 38.35520267486572, 51.543774381279945, 61.8857554346323, 55.82523263990879, 54.51384320855141, 57.75134548544884, 54.73651126027107, 56.1223728954792, 56.84873811900616, 58.020063266158104, 59.72414642572403, 59.98235397040844, 58.777305632829666, 54.39080961048603, 50.77716551721096, 48.96954171359539, 55.463655441999435, 55.74048578739166, 57.774805426597595, 55.95416732132435, 43.13059262931347, 57.35721543431282, 56.61195382475853, 58.78834784030914, 52.77762897312641, 49.26293917000294, 49.35705251991749, 55.86798794567585, 57.32500076293945, 56.83241419494152, 52.96589747071266, 55.8994996547699, 56.051149517297745, 56.12115316092968, 54.18786250054836, 54.51232708990574, 55.147170424461365, 55.02744644880295, 54.65023688971996, 54.54452656209469, 53.994639068841934, 54.529388174414635, 47.78511106967926, 34.33897778391838, 22.80016165226698, 14.884319063276052, 8.750473503023386, 4.661900969222188, 3.1560151744633913, 8.957522492855787, 4.126661214977503, 6.751524265855551, 8.44574885442853, 13.24789222329855, 12.539663426578045, 14.017658717930317, 15.794086195528507, 14.616929311305285, 7.171251168474555, 4.3160254787653685, 2.037526904605329, 0.8062668610364199, 0.5906323506496847, 6.0035790503025055, 12.61777963489294, 24.090921990573406, 27.763468623161316, 29.865124449133873, 32.73432768881321, 37.08823665976524, 24.170679710805416, 11.907502748072147, 1.8384373001754284, 0.3002363472478464, 0.19872287957696244, 0.17267860210267827, 0.13991818501381204, 0.14291232044342905, 0.31013903149869293, 0.17624977219384164, 0.11843755171867087, 0.1222742696700152, 0.15768800571095198, 0.1792736677452922, 0.2249228151049465, 0.08386210116441362, 0.08918480656575412, 0.07875678566051647, 0.11190274846740067, 0.17677619238384068, 0.2079060664982535, 0.14988932496635243, 0.16130753414472565, 0.13699266855837777, 0.1571171754039824, 0.17035225115250796, 0.1393228638335131, 0.06075541859900113, 0.11220679894904606, 0.19951035763369873, 0.09476901512243785, 0.11885331026860513, 0.17811435885960236, 0.0955739188066218, 0.13894818315748125, 0.16643853537971154], [0.04444024074473418, 0.05697832108126022, 0.017416176197002642, 0.0049302340539725265, 0.04849412594921887, 0.06737982505001128, 0.031971024291124195, 0.03288539475761354, 0.037298720635590144, 0.10859639151021838, 0.022950660859351046, 0.020278335505281575, 0.022890045947860926, 0.03171003692841623, 0.03982396716310177, 0.04953092851792462, 0.08903149369871244, 0.007760291300655808, 0.04763970246131066, 0.043740302717196755, 0.021001350614824332, 0.09709620469948277, 0.10673674754798412, 0.02389891593338689, 0.03289193678938318, 0.03369747500983067, 0.008266433233075077, 0.059991804300807416, 0.030182307382347062, 0.023231161139847245, 0.023591293866047636, 0.05841244354087394, 0.03685484582092613, 0.060150019053253345, 0.006427859307223116, 0.05344583543774206, 0.11270607879851013, 0.035057416098425165, 0.07271782611496747, 0.1724084306624718, 4.79840436950326, 23.056296408176422, 45.566603913903236, 41.555352956056595, 20.684258490800858, 16.55519675463438, 16.03179384022951, 9.139124248176813, 4.540691748261452, 1.4650648226961493, 0.17649138579145074, 0.21784474491141737, 0.16022575000533834, 1.1440605414099991, 2.4992771772667766, 3.746679942123592, 4.541750941425562, 3.9139339048415422, 8.23793325573206, 5.353610152378678, 9.641053564846516, 2.0876001426950097, 4.017399027943611, 3.2464287104085088, 0.5950617848429829, 0.8399774646386504, 1.796616269275546, 3.855894631706178, 9.633345678448677, 19.911503456532955, 29.456382282078266, 25.930365286767483, 35.88858783245087, 52.742644250392914, 49.153311252593994, 50.7130591571331, 54.22181747853756, 52.65668526291847, 52.99124591052532, 53.60431261360645, 58.08456100523472, 56.05430334806442, 54.81031470000744, 52.560987398028374, 47.365814968943596, 46.202400997281075, 54.89988349378109, 53.24389435350895, 59.80489209294319, 50.64056284725666, 35.4583141207695, 51.16481311619282, 50.473007038235664, 54.63930107653141, 49.76370669901371, 49.4816592335701, 47.64068461954594, 51.957021206617355, 51.746542900800705, 56.44236132502556, 51.59131743013859, 52.544420287013054, 52.26470969617367, 52.9839389026165, 55.29209464788437, 51.45135194063187, 51.266735047101974, 50.78834071755409, 51.95588506758213, 50.56637182831764, 51.425847709178925, 43.15909489989281, 34.576856419444084, 16.922224760055542, 11.16943510249257, 5.912226252257824, 3.0220958730205894, 1.5888721542432904, 0.9624271409120411, 9.762743934988976, 4.570356281474233, 4.484905041754246, 5.258514555171132, 5.324520813301206, 5.5146801844239235, 6.481906408444047, 5.293940529227257, 3.442113697528839, 2.545935823582113, 1.4899642928503454, 0.07938122871564701, 0.21055719611467794, 1.9300224795006216, 4.689488438889384, 12.038299329578876, 18.63021031022072, 17.337284088134766, 21.14231251180172, 21.667197346687317, 20.203736275434494, 14.547662828117609, 3.1824631802737713, 0.3180407965555787, 0.062344642501557246, 0.037409590077004395, 0.010958120292343665, 0.044357057122397237, 0.06627406211919151, 0.029103081797074992, 0.007332247423619265, 0.07023161655524746, 0.05511004594154656, 0.020899665250908583, 0.05655230605043471, 0.0930898540536873, 0.06774603039957583, 0.06989556466578506, 0.038592384225921705, 0.020211339979141485, 0.09452978381887078, 0.023666137603868265, 0.05197407124796882, 0.05386933087720536, 0.06070991381420754, 0.10732334849308245, 0.07905219012172893, 0.022476127924164757, 0.030537554921465926, 0.038422899961005896, 0.038672001828672364, 0.016227281594183296, 0.05885239610506687, 0.029851086874259636, 0.04660278485971503, 0.05127088261360768, 0.04384508283692412, 0.04433965375937987, 0.03647222416475415, 0.017898802252602763, 0.027881788737431634, 0.012503612215368776, 0.05976510416076053, 0.034871014577220194, 0.004681956897911732, 0.027089126779173966, 0.08963891930761747, 0.022440558641392272, 0.12538273294921964, 0.0697615031094756, 0.03738152205187362, 0.09751498379046097, 0.03562871024769265, 0.012004736836388474, 0.11520627042045817, 0.09402011390193366, 0.03149072486849036, 0.07649425941053778, 0.012721193215838866, 0.035351633123354986, 0.02690671244636178, 0.05129907309310511, 0.042262178321834654, 0.04612047421687748, 0.04316894548537675, 0.0523268363031093, 0.05592937697656453, 0.09350679261842743, 0.03178450031555258, 0.021349111739255022, 0.045593749746331014, 0.03507268578687217, 0.03715240251040086, 0.010080556639877614, 0.06771655971533619, 0.06948313093744218, 0.34934523864649236, 7.1568456664681435, 27.525840774178505, 55.33669285476208, 43.27759154140949, 25.98695185035467, 20.51805730909109, 21.660980880260468, 12.094639856368303, 5.7542212307453156, 2.0764983259141445, 0.16201356891542673, 0.05625390702334698, 0.23647557565709576, 0.8943191799335182, 1.2254404183477163, 1.744315994437784, 5.787412924692035, 6.165668377652764, 5.968935834243894, 7.439232263714075, 8.814113438129425, 6.358393086120486, 5.486514195799828, 4.6796550415456295, 2.330165351741016, 2.49449513386935, 3.452727240510285, 6.341415122151375, 13.443499077111483, 23.801284432411194, 32.30620086193085, 29.77749925106764, 43.573694452643394, 55.60495845973492, 52.198756635189056, 52.05124855041504, 54.49423246085644, 52.11112953722477, 54.35038357973099, 53.71593542397022, 57.94876009225845, 58.358716294169426, 56.463917568325996, 54.71740208566189, 50.570961982011795, 48.65512378513813, 55.26252083480358, 54.44224365055561, 59.91023004055023, 51.59457005560398, 39.64263439178467, 54.06354837119579, 52.13238179683685, 56.91084198653698, 50.835412591695786, 50.3859993070364, 49.113189205527306, 54.31308098137379, 53.445800319314, 58.16141568124294, 52.616016045212746, 53.404264748096466, 52.38415248692036, 54.358792528510094, 54.77199375629425, 53.37108112871647, 53.868250250816345, 51.90799243748188, 52.290715500712395, 53.211630284786224, 51.28574162721634, 45.834740325808525, 37.58156418800354, 21.325620375573635, 14.12388676777482, 8.987030759453773, 4.64723945595324, 2.043434400111437, 2.104280535131693, 16.641134843230247, 7.350850431248546, 3.307684985920787, 11.672277320176363, 9.387494120746851, 5.949376383796334, 8.588597439229488, 5.540601443499327, 3.1492467876523733, 1.652627270668745, 0.27167129097506404, 0.1281767853652127, 0.3478980506770313, 3.145828158594668, 7.918074494227767, 10.979083366692066, 18.03115725517273, 21.735348589718342, 23.18664651364088, 29.64636828750372, 26.152619160711765, 17.4173191934824, 4.435235057026148, 0.36207894911058247, 0.048181785678025335, 0.016171175229828805, 0.02223952382337302, 0.07246486507938243, 0.03306007034552749, 0.02757927079073852, 0.05151606223080307, 0.07647228441783227, 0.0783777931064833, 0.06283457871177234, 0.024815683536871802, 0.02767110228887759, 0.05733975442126393, 0.021801899747515563, 0.043732636331696995, 0.040519700924050994, 0.025993189883593004, 0.04333225137088448, 0.027817500194942113, 0.034222073227283545, 0.07465217466233298, 0.1115348881285172, 0.029535104513342958, 0.021308032009983435, 0.08991706141387112, 0.01659101188124623, 0.020342527568573132, 0.03584252299333457, 0.03968016491853632, 0.026737545449577738, 0.12840751907788217, 0.080347156181233, 0.03689941549964715, 0.12371164644719101, 0.16394481528550386, 0.12206197090563364, 0.1248675340320915, 0.23561498121125624, 0.17308728798525408, 0.10376903257565573, 0.09523938831989653, 0.1271461055148393, 0.2546827885089442, 0.09890542714856565, 0.24337187904166058, 0.19088493922026828, 0.1988249397254549, 0.21546537493122742, 0.13232022552983835, 0.15409026673296466, 0.16424577101133764, 0.16948471020441502, 0.1870593905914575, 0.24101324466755614, 0.12500365875894204, 0.2635906683281064, 0.12005832802969962, 0.18984671914950013, 0.09827472036704421, 0.14299371920060366, 0.12937683815835044, 0.18931422819150612, 0.16466578206745908, 0.17380697827320546, 0.08230237392126583, 0.0801068042346742, 0.09992599152610637, 0.06869828750495799, 0.19010630756383762, 0.16252609610091895, 0.11783773312345147, 0.20893416367471218, 0.6182550871744752, 8.715703468769789, 35.52244707942009, 63.46916846930981, 52.97565534710884, 30.640706531703472, 25.445353612303734, 26.400331668555737, 16.011026054620743, 7.258899640291929, 2.5114605110138655, 0.605399664491415, 0.6932197802234441, 0.8706846856512129, 3.606829633936286, 6.984640806913376, 10.626640878617764, 14.894133936613798, 12.010670062154531, 17.287702448666096, 13.312235120683908, 20.095297694206238, 7.463518185541034, 7.349293939769268, 5.772036574780941, 2.1907681692391634, 1.9676339300349355, 2.94900038279593, 5.079617304727435, 11.858779862523079, 23.646176755428314, 31.54990464448929, 29.724218510091305, 43.31836335361004, 59.45155665278435, 55.79489886760712, 50.541635155677795, 54.14826862514019, 53.50015640258789, 53.16825941205025, 53.486275747418404, 58.3198481798172, 59.53431621193886, 59.15286228060722, 56.94124415516853, 52.08784058690071, 51.18041127920151, 58.11084799468517, 56.076463758945465, 62.10546724498272, 54.324742555618286, 44.265154749155045, 54.03429374098778, 55.637997686862946, 57.58497141301632, 54.59434188902378, 52.66477882862091, 51.48600608110428, 57.08655595779419, 56.75955310463905, 58.20346802473068, 54.74675931036472, 53.07779386639595, 53.61720152199268, 54.22357298433781, 57.51390002667904, 54.582855105400085, 54.69680339097977, 54.075065553188324, 54.583618864417076, 54.263223856687546, 53.44847157597542, 45.96469335258007, 35.87071739137173, 20.627417340874672, 14.94353223592043, 8.829147331416607, 4.051918750628829, 2.9955806583166122, 3.4024996357038617, 18.15939847379923, 8.537244144827127, 8.359974157065153, 14.140111897140741, 16.038521379232407, 13.520584590733051, 16.135811358690262, 13.28012589365244, 9.612955022603273, 5.840646168217063, 3.0154704535380006, 0.3534358675824478, 0.6951512640807778, 2.725004539825022, 8.558904882520437, 17.916967682540417, 27.997346073389053, 29.128594771027565, 31.50340273976326, 33.39622177183628, 29.945571832358837, 19.722471199929714, 4.811827149242163, 0.5835171137005091, 0.1343194823130034, 0.14717814075993374, 0.14634257153375074, 0.16369775432394817, 0.112041930842679, 0.08218914445023984, 0.15621475351508707, 0.1367624691920355, 0.17237743857549503, 0.10007246179156937, 0.09237868362106383, 0.16779329627752304, 0.1734764702268876, 0.13033661321969703, 0.1186388815403916, 0.0996893280535005, 0.22930540493689477, 0.12245366160641424, 0.08557833993108943, 0.14628248725784943, 0.10782509969430976, 0.21901125262957066, 0.200923377124127, 0.1902391668409109, 0.19612981559475884, 0.09414157379069366, 0.09587341250153258, 0.21676328731700778, 0.17178803973365575, 0.10291677986970171, 0.1456883386708796, 0.24291410751175135, 0.11710519625921734], [0.029787885578116402, 0.04826842399779707, 0.05333717759640422, 0.020819910350837745, 0.026841488797799684, 0.011684143883030629, 0.035315138011355884, 0.03515906435495708, 0.022734259873686824, 0.055694375914754346, 0.04592815777868964, 0.0004235254442619407, 0.041090527520282194, 0.019123507336189505, 0.009909834843710996, 0.00839518936118111, 0.0368541222269414, 0.021798459893034305, 0.0079749064934731, 0.017187847042805515, 0.04658256875700317, 0.043397820118116215, 0.03392102102225181, 0.07596668147016317, 0.016739042512199376, 0.02247904641990317, 0.05212716889218427, 0.0053289120751287555, 0.04497417146922089, 0.03156002290779725, 0.010307348620699486, 0.018815167240973096, 0.012923340327688493, 0.07761557033518329, 0.06019932363415137, 0.04502381372731179, 0.021253990671539214, 0.08365580637473613, 0.0033479909779998707, 0.058736494902404957, 2.321978216059506, 12.914159931242466, 33.72067116200924, 44.7410374134779, 28.063164241611958, 20.44207278639078, 18.60924683511257, 22.755403853952885, 15.894779842346907, 7.643332611769438, 2.074971995316446, 0.14614885614719242, 0.227028199005872, 0.563718038611114, 0.9409243322443217, 0.5090229422785342, 3.0037696938961744, 4.5225168485194445, 4.312831750139594, 7.353934915736318, 6.20908104814589, 4.7647984977811575, 3.339722016826272, 6.151221077889204, 2.0895164273679256, 2.028022902086377, 1.717293388210237, 0.7014395110309124, 3.3965828781947494, 8.202109728008509, 13.204491902142763, 23.908902257680893, 25.061785094439983, 32.56558634340763, 47.699380069971085, 53.30478608608246, 53.218910694122314, 54.6952910721302, 56.99836649000645, 55.87365344166756, 56.104282066226006, 55.112432688474655, 55.08177973330021, 50.34958206117153, 47.384114786982536, 49.93208706378937, 54.31766353547573, 52.872901260852814, 57.46183902025223, 48.262589648365974, 35.15531077980995, 50.60147434473038, 49.761164635419846, 55.96017099916935, 50.48043943941593, 49.31961312890053, 50.39399027824402, 54.602705240249634, 51.74849979579449, 54.77929316461086, 51.955049112439156, 54.10983748733997, 53.71669538319111, 52.652433291077614, 55.229663997888565, 53.22255849838257, 54.63420554995537, 53.488764613866806, 51.769797652959824, 53.08472849428654, 44.64335225522518, 34.954293966293335, 19.070629477500916, 7.746405405923724, 3.2205219380557537, 4.334317222237587, 1.5093222353607416, 0.44123846862930804, 2.615600097924471, 18.256876543164253, 8.174121379852295, 3.815203565172851, 10.32524960115552, 7.268593395128846, 5.985881024971604, 6.271742535755038, 5.412494642660022, 1.6632069717161357, 1.448699813336134, 0.20454925834201276, 0.27827459445688874, 1.7950341291725636, 3.32218952011317, 17.169448994100094, 46.471019983291626, 41.043353229761124, 30.872435197234154, 34.071350544691086, 22.18599870800972, 17.733996100723743, 6.769702015444636, 1.470257006585598, 0.030560873201466165, 0.014159639613353647, 0.013831012911396101, 0.013658785483130487, 0.04641628314857371, 0.035674144528456964, 0.017007963433570694, 0.06277578577282839, 0.052912298051523976, 0.015032527735456824, 0.05607380633591674, 0.0611320659663761, 0.009986156383092748, 0.03643035961431451, 0.06042301065463107, 0.054452722033602186, 0.10306627809768543, 0.09274136376916431, 0.05211370262259152, 0.025422569233342074, 0.08176935603842139, 0.0369105811114423, 0.0397652892570477, 0.04080249258549884, 0.05512871466635261, 0.06023283160175197, 0.05155063889105804, 0.03402504044061061, 0.08535164350178093, 0.03648301128123421, 0.005111398331791861, 0.009487704955972731, 0.20817099837586284, 0.04721131255791988, 0.017961289231607225, 0.021965239029668737, 0.0193606958782766, 0.05024049220082816, 0.02370915619394509, 0.02262006189994281, 0.019717342365765944, 0.07340469121118076, 0.01861691547674127, 0.035659238492371514, 0.05238916928647086, 0.09052067238371819, 0.025822833595157135, 0.010575303822406568, 0.013499684791895561, 0.07482581495423801, 0.025919014078681357, 0.037228353903628886, 0.0036165125311526936, 0.023068272712407634, 0.08685409178724512, 0.024533467039873358, 0.02676314954442205, 0.012392521985020721, 0.02709838136070175, 0.017923875711858273, 0.01630319773539668, 0.05347259728296194, 0.05471191710967105, 0.0342025621648645, 0.048011381149990484, 0.06497868787846528, 0.04915990662993863, 0.01951385103893699, 0.028432994804461487, 0.01870039224741049, 0.06408981760614552, 0.03621639472839888, 0.02436634837067686, 0.052080317109357566, 2.8376525826752186, 16.105336993932724, 40.10996371507645, 48.83999906480312, 31.475136056542397, 19.38186887651682, 21.830030009150505, 23.56707639992237, 15.597915071994066, 6.875705877318978, 2.013630224391818, 0.28079415613319725, 0.21852897538337857, 0.11288909241557121, 0.6861719896551222, 0.605940007371828, 3.607448050752282, 5.683314660564065, 4.253667499870062, 5.622371630743146, 7.036892278119922, 7.911629565060139, 6.101683611050248, 8.393944334238768, 6.850083377212286, 3.312116735614836, 3.732419307343662, 1.9483623141422868, 5.54790417663753, 9.102094285190105, 16.237233616411686, 25.354656279087067, 29.048390574753284, 38.4936710447073, 51.70113153755665, 52.78410382568836, 53.34867373108864, 55.89917667210102, 56.375678703188896, 56.803398951888084, 58.49628411233425, 56.81431956589222, 57.464966252446175, 52.84850277006626, 49.70599539577961, 49.803011789917946, 55.88205099105835, 54.459190741181374, 58.24887178838253, 50.25619067251682, 39.21238727867603, 52.22570858895779, 52.10437349975109, 56.774843484163284, 52.48325116932392, 52.00058586895466, 52.82030828297138, 55.31237035989761, 54.45135936141014, 56.83078408241272, 51.007797941565514, 54.23738144338131, 52.44932658970356, 53.261487409472466, 54.80413243174553, 53.37892010807991, 54.75516825914383, 54.7031756490469, 54.421880543231964, 53.34763638675213, 47.9108577221632, 36.54535599052906, 22.304537147283554, 11.393396984785795, 6.013329327106476, 7.139007048681378, 4.4589039869606495, 2.591531239449978, 2.1452071890234947, 13.834864776581526, 13.991616815328598, 5.217700470238924, 9.501405358314514, 9.993923529982567, 5.1985276490449905, 4.26004545763135, 3.912733169272542, 1.762191541492939, 0.5258202971890569, 0.09407872872543521, 0.08204314173781313, 2.1419892366975546, 4.976919265463948, 10.98459117114544, 36.213295608758926, 40.63301704823971, 31.798382811248302, 37.75228522717953, 25.517316050827503, 21.836561858654022, 9.339447598904371, 1.9102701894007623, 0.06427801141398959, 0.07988703204318881, 0.01232935779626132, 0.060275208234088495, 0.009693188021628885, 0.039270369525183924, 0.03623979093390517, 0.06722231162711978, 0.014997806356404908, 0.017659235127212014, 0.01808579749194905, 0.061961375176906586, 0.01598767179530114, 0.04722591802419629, 0.05691597696568351, 0.07679188289330341, 0.07440572226187214, 0.047542332686134614, 0.038985922874417156, 0.1032990452949889, 0.061744861013721675, 0.08483659301418811, 0.05077210000308696, 0.0232656301886891, 0.06284820454311557, 0.051936592790298164, 0.07295165458344854, 0.011798009745689342, 0.062458836764562875, 0.08423154969932511, 0.028504578658612445, 0.04580085718771443, 0.08640223517431878, 0.059728308478952385, 0.12044097937177867, 0.0874699407722801, 0.13377832307014614, 0.17402619385393336, 0.12255808178451844, 0.09027939275256358, 0.11461689384304918, 0.11689012928400189, 0.10351040895329788, 0.2770122903166339, 0.16173369018360972, 0.2533176227007061, 0.15985676902346313, 0.09995400017942302, 0.17621429753489792, 0.08826662888168357, 0.1415330686722882, 0.1344110633363016, 0.06882385889184661, 0.10456155723659322, 0.2694445807719603, 0.09571222544764169, 0.2157646682462655, 0.11476496714749373, 0.15302249434171245, 0.05400981201091781, 0.12607028824277222, 0.1542075557517819, 0.10906637879088521, 0.13681333599379286, 0.10790292129968293, 0.12225538943312131, 0.14051954727619886, 0.20633841311791912, 0.15472459519514814, 0.1744993872125633, 0.26960755640175194, 0.18639056710526347, 0.18136952247004956, 0.24171659286366776, 3.329776762984693, 19.97709173709154, 48.272537514567375, 55.78103341162205, 39.13096904754639, 29.633431881666183, 30.198982134461403, 33.65493468940258, 22.951237745583057, 10.02844562754035, 2.6902829529717565, 0.3504414501367137, 0.8783652610145509, 1.4653561008162796, 3.4573615668341517, 4.645646391436458, 11.612569224089384, 14.710351098328829, 12.604589592665434, 15.698095746338367, 15.313036758452654, 11.809363514184952, 10.279339514672756, 14.579418674111366, 7.780490051954985, 4.722515316680074, 2.9542790120467544, 1.7327984562143683, 5.171383805572987, 9.758227877318859, 16.350182555615902, 25.8790148422122, 29.838455580174923, 39.293843507766724, 53.29464063048363, 56.89976558089256, 54.90217097103596, 55.577748119831085, 56.47112958133221, 58.12264256179333, 57.86801442503929, 59.70794789493084, 58.449896201491356, 54.72230762243271, 52.05402620136738, 52.28486381471157, 57.80865781009197, 59.55230064690113, 57.98895813524723, 51.44105449318886, 43.145012855529785, 53.49786512553692, 54.78510305285454, 58.66572842001915, 54.274961426854134, 54.006730020046234, 54.788598865270615, 56.20269298553467, 56.06121137738228, 56.47587172687054, 52.348202615976334, 53.47070038318634, 51.33874498307705, 54.194029569625854, 55.60090407729149, 55.676637813448906, 56.286109909415245, 56.82329848408699, 56.536231487989426, 56.895437613129616, 47.23253712058067, 38.32883968949318, 20.44997066259384, 9.73424831405282, 6.104693049564958, 8.707212824374437, 3.7236149422824383, 2.5723710050806403, 7.137484755367041, 27.78552643954754, 17.52979315817356, 8.440258149057627, 20.989038236439228, 16.80660456418991, 13.735816441476345, 13.646278996020555, 12.145939003676176, 5.6165422685444355, 3.199370135553181, 0.7619216374587268, 0.6160839193034917, 2.2929795971140265, 5.400313446298242, 21.29323661327362, 51.19778394699097, 48.117334842681885, 41.13397836685181, 46.38400085270405, 32.69265152513981, 25.327932313084602, 9.983741976320744, 1.9471480417996645, 0.22035691479686648, 0.1718197888112627, 0.08610659322584979, 0.20281479984987527, 0.08545955177396536, 0.14945506467483938, 0.11250710158492438, 0.2030935208313167, 0.14201320853317156, 0.0828660128172487, 0.12895626306999475, 0.14414146542549133, 0.07994106039404869, 0.12915411964058876, 0.19020807085325941, 0.11410259292460978, 0.16346535820048302, 0.2221121682669036, 0.292812911211513, 0.18944938812637702, 0.2154511702246964, 0.18205100699560717, 0.14631787285907194, 0.09751254954608157, 0.09616087598260492, 0.1439976817346178, 0.23488000268116593, 0.08397710436838679, 0.1579243945889175, 0.13231805845862255, 0.1574279274791479, 0.10149885478313081, 0.2904207614483312, 0.1565073081292212], [0.02863849364075577, 0.03885354599333368, 0.05623870041745249, 0.006737391940987436, 0.026284959676559083, 0.014344337905640714, 0.023829543679312337, 0.054223665574681945, 0.058782281703315675, 0.02790788079437334, 0.03620902520196978, 0.09930442800396122, 0.047564526612404734, 0.038088955770945176, 0.02511814767785836, 0.05413497521658428, 0.050812521076295525, 0.0736834789859131, 0.03933165608032141, 0.018519976147217676, 0.013277813250169856, 0.03672986073070206, 0.03346524215885438, 0.040648010835866444, 0.023346145790128503, 0.06738126481650397, 0.048132462543435395, 0.040763229262665845, 0.09826608176808804, 0.03512012757710181, 0.02410700857581105, 0.0742807742790319, 0.018860365889850073, 0.07532297968282364, 0.08575140876928344, 0.046043713882681914, 0.08202742305002175, 0.021479826209542807, 0.023080918908817694, 0.11777026447816752, 0.3455129364738241, 3.3244223752990365, 23.634251095354557, 45.03819286823273, 41.02896340191364, 27.15378563851118, 22.26320866495371, 17.055029533803463, 18.74607939273119, 14.221058953553438, 7.210420416668057, 2.0137254567816854, 0.37260396871715784, 0.12408170354319736, 0.11252444557612762, 0.23281653528101742, 3.5574249224737287, 3.7857767567038536, 2.5746938679367304, 5.106583032757044, 3.8338819378986955, 6.794863790273666, 5.2934707794338465, 5.169019382447004, 5.112666031345725, 3.844585488550365, 3.1672509340569377, 1.2439027964137495, 2.038631932809949, 2.3524086456745863, 5.805622972548008, 10.053563229739666, 19.657551683485508, 26.75292804837227, 31.22186254709959, 39.13601137697697, 53.14554043114185, 52.70738214254379, 54.787937700748444, 55.99099114537239, 57.1405890583992, 55.548531487584114, 54.50779773294926, 50.99996656179428, 52.63925179839134, 52.119804471731186, 53.85139435529709, 56.14091970026493, 56.86102285981178, 47.95343443751335, 41.76063694059849, 47.759090065956116, 50.67119300365448, 55.51808372139931, 51.43332190811634, 53.20808507502079, 52.425714656710625, 53.275843039155006, 55.621293783187866, 52.30979807674885, 52.2017926722765, 56.226863488554955, 54.95541751384735, 53.54102320969105, 52.18136116862297, 51.521838158369064, 53.95260192453861, 52.12466441094875, 51.00557506084442, 47.62905344367027, 34.83986310660839, 15.593988932669163, 8.700433988124132, 2.5329500203952193, 1.4411263447254896, 2.9109546868130565, 3.4428579825907946, 2.386656445451081, 0.6583440641406924, 11.847681608051062, 10.897564440965652, 1.4208872057497501, 11.579505298286676, 8.178688734769821, 1.927958121523261, 3.254776862449944, 2.50081205740571, 1.3908658479340374, 0.1989316605613567, 0.14651604113169014, 0.8584958896972239, 2.6238812785595655, 21.139831244945526, 38.4170937538147, 24.94608510285616, 22.675807625055313, 33.306683376431465, 24.924874641001225, 24.019787907600403, 10.102104675024748, 3.028743378818035, 0.11745578682166524, 0.05200992069148924, 0.03411433564906474, 0.029891539488744456, 0.021795968132209964, 0.04439708485733718, 0.011533804245118517, 0.00803738048489322, 0.04352578122052364, 0.022073382933740504, 0.07615308670210652, 0.025587912314222194, 0.0045012235295871506, 0.06395649077603593, 0.01635121097933734, 0.023718202974123415, 0.023065990608301945, 0.0626390079560224, 0.017563724431965966, 0.0725057499948889, 0.043539269754546694, 0.022559981334779877, 0.019345058826729655, 0.026305262981622946, 0.02892113130656071, 0.05963545096165035, 0.02784687625535298, 0.04476032903767191, 0.025144796345557552, 0.02465049816237297, 0.07268308618222363, 0.0477907888853224, 0.05177330174774397, 0.0522891908622114, 0.09568101813783869, 0.035520108067430556, 0.023945936554810032, 0.01059244650605251, 0.06112283364927862, 0.0513866279652575, 0.02242046128230868, 0.04685292202339042, 0.049259599327342585, 0.016013192398531828, 0.02882902521378128, 0.010249192073388258, 0.0694376447063405, 0.07489073803299107, 0.11138557543745264, 0.05855351468198933, 0.011331477162457304, 0.09009682442410849, 0.0633750477572903, 0.043751917328336276, 0.015417742270074086, 0.11010276575689204, 0.03570911452698056, 0.010625700288073858, 0.057903593697119504, 0.02703223373828223, 0.09528374648652971, 0.021991024950693827, 0.009514240446151234, 0.05843198799993843, 0.017619186983210966, 0.01808389202778926, 0.019336360855959356, 0.033344683979521506, 0.01085108033294091, 0.04107130218471866, 0.03081628146901494, 0.013363405141717521, 0.07023681158898398, 0.06255278523894958, 0.1177050222759135, 0.3926686733029783, 4.501587096601725, 28.728998713195324, 50.65539725124836, 42.94140078127384, 27.291678339242935, 22.3398220539093, 24.519677683711052, 27.56636369973421, 20.734087117016315, 6.696696057915688, 1.3144946959801018, 0.16972877288935706, 0.1198943801864516, 0.12233899979037233, 0.16953085694694892, 1.327817018609494, 2.58392381016165, 2.6677855476737022, 6.233977787196636, 6.109003918245435, 8.789971433579922, 5.77915501780808, 6.668982720002532, 7.448201682418585, 4.662330346181989, 5.301502123475075, 3.694065590389073, 3.5383247723802924, 4.846202479675412, 6.665095053613186, 12.595321889966726, 22.955584712326527, 28.702740222215652, 36.058358922600746, 46.54070444405079, 54.09675478935242, 52.91980214416981, 56.10494703054428, 58.201583325862885, 58.540939316153526, 56.8093304336071, 56.11468970775604, 52.90503993630409, 53.71910445392132, 54.71950717270374, 56.63219913840294, 57.42726467549801, 56.783624812960625, 49.14715938270092, 44.00575786828995, 52.11273305118084, 53.1633310765028, 57.15677618980408, 52.757832035422325, 54.65829625725746, 53.3587583899498, 55.64545288681984, 55.45843072235584, 53.73232014477253, 52.69103541970253, 55.354073122143745, 52.0804575830698, 53.43136869370937, 52.47784785926342, 51.18675693869591, 53.074693232774734, 53.89075264334679, 51.77059181034565, 52.01973304152489, 36.13941617310047, 20.938046872615814, 10.911297854036093, 5.877390671521425, 3.5890646371990442, 5.460847998037934, 5.948969330638647, 2.9479780001565814, 3.1422131275758147, 14.484984241425991, 15.905962642282248, 6.50862704962492, 6.744837574660778, 7.256313879042864, 4.805479114875197, 3.9402292063459754, 2.5397138949483633, 0.7809513132087886, 0.10134750860743225, 0.05796079844003543, 1.7040822096168995, 4.606745503842831, 14.269490204751492, 38.92832592129707, 37.348667085170746, 29.33866459876299, 37.10891894996166, 32.204172536730766, 27.91675239801407, 14.00768805295229, 4.1184793040156364, 0.2538756880676374, 0.023423284619639162, 0.05842560924065765, 0.06738519077771343, 0.04277755164366681, 0.03854699076327961, 0.0027011313522962155, 0.06900067557580769, 0.004204381621093489, 0.021570678072748706, 0.05201320840569679, 0.023148109248722903, 0.026520086903474294, 0.03269982073106803, 0.014085111288295593, 0.03010492364410311, 0.00982099883913179, 0.012168891553301364, 0.059108273781021126, 0.04650856921216473, 0.02868378876883071, 0.012432263065420557, 0.026826515968423337, 0.027347997165634297, 0.019358154022484086, 0.052323017953312956, 0.07081662188284099, 0.08086077432380989, 0.03162792570947204, 0.01884573259303579, 0.02087290155031951, 0.016156473284354433, 0.0273030026073684, 0.039272310241358355, 0.0801413512090221, 0.14201564277755097, 0.09823724190937355, 0.21857880317838863, 0.18835641240002587, 0.10374706500442699, 0.1792561827460304, 0.12385030931909569, 0.19366074964636937, 0.10193607624387369, 0.1483549494878389, 0.12094946185243316, 0.21569285803707317, 0.15797220374224707, 0.23603327048476785, 0.11619320066529326, 0.10733435454312712, 0.18381580448476598, 0.29286940349265933, 0.1355178133235313, 0.09779446176253259, 0.21815206826431677, 0.13635405048262328, 0.11512339478940703, 0.22278917022049427, 0.22303974896203727, 0.19659763580420986, 0.11800605221651495, 0.10611489458824508, 0.17702746874419972, 0.12663519621128216, 0.12063786372891627, 0.14499303535558283, 0.09901591067318805, 0.16443092201370746, 0.11346678016707301, 0.11962590826442465, 0.1339606984402053, 0.17005644593155012, 0.13944352220278233, 0.368990451679565, 0.49141263880301267, 5.61121447943151, 32.7852563560009, 57.52859003841877, 54.025561809539795, 37.29615390300751, 33.56541529297829, 28.242332227528095, 28.427196107804775, 20.231966860592365, 9.501825235784054, 2.811454413458705, 0.5394222016911954, 0.44690384587738663, 0.7164469244889915, 2.156432024203241, 7.9508106876164675, 10.180224683135748, 9.332815054804087, 15.014748014509678, 15.106329750269651, 14.483719859272242, 13.705114088952541, 12.172371335327625, 12.183319497853518, 9.091452956199646, 7.593380967155099, 4.430726123973727, 4.258481366559863, 4.3231025990098715, 7.938723536208272, 12.573329620063305, 22.50097520649433, 29.840325079858303, 36.22170455753803, 45.89334838092327, 57.08971358835697, 56.39873206615448, 55.53598076105118, 58.82486768066883, 60.053258165717125, 58.3900798112154, 58.088725581765175, 56.08133889734745, 57.06796735525131, 58.23917090892792, 58.54752816259861, 59.653371423482895, 56.67371191084385, 51.02654233574867, 50.443364828825, 54.72038112580776, 55.86833752691746, 57.71166041493416, 55.43259970843792, 56.64332114160061, 55.84304228425026, 56.09710805118084, 57.81572163105011, 53.99487845599651, 53.8862194865942, 54.96015205979347, 54.61505077779293, 52.18791961669922, 53.70367348194122, 51.04587569832802, 56.3803106546402, 54.46814686059952, 53.11065450310707, 50.05777291953564, 37.32387721538544, 18.03385891020298, 11.771379802376032, 5.844654478132725, 3.584083104506135, 5.006349636241794, 7.558606658130884, 4.996964614838362, 6.2271148804575205, 21.323228403925896, 22.219324819743633, 8.189582750201225, 17.942329421639442, 15.326373092830181, 8.746326975524426, 8.898886889219284, 7.539728796109557, 3.033848167397082, 0.7443199132103473, 0.33527349529322237, 1.4466304681263864, 4.95067217387259, 23.809594586491585, 45.79843707382679, 35.134655088186264, 32.626516073942184, 44.260215014219284, 35.65968431532383, 31.361265666782856, 14.478223454207182, 4.5972521882504225, 0.2767665503779426, 0.15789988887263462, 0.17399640404619277, 0.12681519670877606, 0.09903196332743391, 0.10731141475844197, 0.13874321681214496, 0.09509226496447809, 0.09411167266080156, 0.11199758751899935, 0.1339406010811217, 0.06893039419082925, 0.08783663593931124, 0.12478543765610084, 0.0905289918591734, 0.13538173312554136, 0.15814200713066384, 0.08031633478822187, 0.1308743140543811, 0.16487368731759489, 0.16650734731229022, 0.1292823182302527, 0.20211387105518952, 0.096915469475789, 0.11645185397355817, 0.2186790673295036, 0.18508046865463257, 0.13725544820772484, 0.15345038700615987, 0.10221887903753668, 0.13663666031789035, 0.15428960759891197, 0.12076482293196023, 0.23822864721296355, 0.2945802320027724], [0.04117316195333842, 0.057742221106309444, 0.028731089551001787, 0.053970133085385896, 0.03115551902737934, 0.04120168639929034, 0.03341162569995504, 0.033863790304167196, 0.027546976234589238, 0.03173995290126186, 0.0443337165779667, 0.056090333964675665, 0.05576384093728848, 0.05014873306208756, 0.03805119529715739, 0.03161792898026761, 0.02005955408094451, 0.021937660822004545, 0.049066885840147734, 0.06061137144570239, 0.061333570192800835, 0.015414423014590284, 0.08554688771255314, 0.018224189479951747, 0.03687223063025158, 0.08244452488725074, 0.03423721303988714, 0.02186315476137679, 0.06668521935353056, 0.023180463176686317, 0.05831639478856232, 0.01906320969283115, 0.10529200124437921, 0.03757122984097805, 0.03856955576338805, 0.02017365928622894, 0.042331320510129444, 0.0363129741162993, 0.04238808367517777, 0.08329679243615828, 0.019890843504981603, 0.6073161272797734, 7.048936206847429, 29.44322358816862, 41.67943149805069, 40.157058387994766, 29.73988886922598, 14.200436510145664, 11.422099694609642, 22.07263559103012, 18.603545241057873, 7.541576446965337, 1.8902640254236758, 0.6982116436120123, 0.12891934864455834, 0.14056248794076964, 0.6005453655961901, 2.732587745413184, 2.9696928849443793, 2.1736985351890326, 3.535760147497058, 9.799352120608091, 4.351643342524767, 6.369284726679325, 10.140229929238558, 3.4931283351033926, 5.359479887410998, 2.449188739992678, 2.3236551135778427, 1.633741334080696, 0.3899347793776542, 2.8941978234797716, 5.841296883299947, 10.79398674890399, 22.135210633277893, 28.85092467069626, 37.22194008529186, 51.93003885447979, 57.336578741669655, 55.17581328749657, 57.88807354867458, 57.491583824157715, 55.42503051459789, 53.7955791503191, 55.075730457901955, 54.42304328083992, 58.330358415842056, 56.76564417779446, 54.51356962323189, 48.49039502441883, 42.29833088815212, 50.46336315572262, 52.398223131895065, 55.65597452223301, 56.89803287386894, 55.87208792567253, 56.54853142797947, 60.29544956982136, 52.54966780543327, 54.98148791491985, 52.03470803797245, 55.37251353263855, 55.23332700133324, 54.643705040216446, 53.85102577507496, 54.13061857223511, 49.936346635222435, 49.856588914990425, 44.12526145577431, 32.361552491784096, 17.02339243143797, 6.819939119741321, 1.441580776590854, 2.2924761241301894, 1.953745437785983, 4.254586100578308, 4.536435501649976, 2.8101921686902642, 1.3245225953869522, 10.161491688340902, 14.568850491195917, 6.164593985304236, 4.22663907520473, 6.73981424421072, 4.487498877570033, 2.363350158557296, 1.4401227235794067, 0.3496057918528095, 0.20097388769499958, 0.39182241715025157, 3.699170141480863, 18.580738864839077, 27.456701584160328, 7.595406733453274, 17.00704000890255, 28.691131845116615, 30.465241447091103, 24.601798877120018, 14.342582132667303, 4.108921866863966, 0.37255742121487856, 0.09330802320619114, 0.0459054369275691, 0.02786930952424882, 0.038056913545005955, 0.06048634182661772, 0.046026295676711015, 0.08165217092027888, 0.019033809512620792, 0.047938580173649825, 0.009611343975848285, 0.03905153243977111, 0.047938624702510424, 0.013321232599992072, 0.08409371061134152, 0.09583542196196504, 0.011868046221934492, 0.004552382551992196, 0.030333295471791644, 0.019874271347362082, 0.03864662779960781, 0.026812810356204864, 0.06592201694729738, 0.012332142705417937, 0.01693978232651716, 0.015100750588317169, 0.010725459778768709, 0.035842920042341575, 0.05008934640500229, 0.06116689866757952, 0.02966674666822655, 0.07999318884685636, 0.07569039473310113, 0.039254235234693624, 0.04406368614581879, 0.17719397699693218, 0.04277367392205633, 0.05327173501427751, 0.03803414074354805, 0.013732224706473062, 0.026255526099703275, 0.02155282571038697, 0.06401563252438791, 0.008522795160388341, 0.005405691426858539, 0.03995993232820183, 0.0058915843237628, 0.05979752488201484, 0.08097267535049468, 0.049544610010343604, 0.05456481230794452, 0.04089086010935716, 0.022924514996702783, 0.04124955121369567, 0.018492590897949412, 0.03146686482068617, 0.051907686138292775, 0.028000044403597713, 0.03138979278446641, 0.016950836616160814, 0.056147186187445186, 0.04233178806316573, 0.01704677961242851, 0.06959397069294937, 0.042511513966019265, 0.04448503677849658, 0.0308069062884897, 0.01594586661667563, 0.08041662120376714, 0.015375723723991541, 0.05941577524936292, 0.042789077197085135, 0.013917997257522075, 0.04899461549939588, 0.06892671313835308, 0.052348080280353315, 0.06389251022483222, 0.9248537477105856, 9.26660930737853, 34.14155177772045, 46.67861424386501, 42.3411013931036, 31.398121789097786, 13.823811169713736, 16.388877779245377, 27.92446978390217, 20.775727182626724, 9.582959432154894, 2.226323098875582, 0.3568167658522725, 0.10239565861411393, 0.052161645362502895, 0.40044311550445855, 1.787357828579843, 2.080002212896943, 3.9776797592639923, 4.124021781608462, 7.14755991473794, 6.891025705263019, 9.82668500393629, 7.8447807021439075, 5.425599664449692, 7.958824932575226, 5.4552181251347065, 5.318753197789192, 3.7775138625875115, 2.2696493240073323, 6.817864906042814, 10.108855962753296, 13.615984171628952, 25.727416276931763, 31.891073137521744, 41.843187510967255, 54.87535201013088, 57.896847277879715, 56.50189273059368, 58.83297644555569, 60.003161653876305, 57.70248010754585, 54.12819430232048, 57.11883522570133, 54.85991343855858, 59.41749148070812, 58.08473959565163, 56.64276257157326, 50.70322908461094, 46.421003267169, 54.040928184986115, 52.1588359773159, 57.435973808169365, 57.026937156915665, 57.086149379611015, 57.0486605912447, 60.49754172563553, 54.83709566295147, 56.16749547421932, 52.83363796770573, 54.84879523515701, 53.48315231502056, 54.93377387523651, 53.751550912857056, 53.3687062561512, 53.13696429133415, 51.129026636481285, 46.16578996181488, 36.30012094974518, 20.98970890045166, 8.845287915319204, 5.349836479872465, 5.165835153311491, 4.4374018907547, 6.699093729257584, 6.281533185392618, 3.6558422539383173, 3.7679934734478593, 10.46906903386116, 17.24604908376932, 7.861451357603073, 5.300833359360695, 5.440399870276451, 2.943936916999519, 2.5231854943558574, 0.9424678212963045, 0.33887009136378765, 0.13715349195990711, 0.6383954908233136, 3.562817070633173, 11.938505284488201, 30.44319123029709, 16.867460198700428, 17.456669881939888, 30.33600278198719, 35.0846079736948, 27.135856300592422, 17.349424436688423, 5.557551858946681, 0.7947123341728002, 0.12764105864334852, 0.03671226812002715, 0.037983307338436134, 0.044883770460728556, 0.04039109786390327, 0.007004578556006891, 0.039394987252308056, 0.037391975201899186, 0.0166185288617271, 0.04987492138752714, 0.04280370492779184, 0.09282324492232874, 0.052530819302774034, 0.04896325233858079, 0.05189100636926014, 0.09460338260396384, 0.02417934942059219, 0.02103656737745041, 0.018770309980027378, 0.04583104404446203, 0.03834929746517446, 0.1094445698254276, 0.029133704665582627, 0.06001763846143149, 0.006997509135544533, 0.007550781156169251, 0.031199268632917665, 0.046198466516216286, 0.04394476069137454, 0.004598695813911036, 0.06574209066457115, 0.060438851796789095, 0.022096714201325085, 0.06615637976210564, 0.06164860817079898, 0.058690555961220525, 0.16916411725105718, 0.15020144259324297, 0.1023121373145841, 0.1778729827492498, 0.10827890073414892, 0.17617874866118655, 0.12358245337964036, 0.08608058837126009, 0.13389418716542423, 0.18459237297065556, 0.16049385827500373, 0.14083357964409515, 0.15558334911474958, 0.16221706580836326, 0.15602180996211246, 0.12322714275796898, 0.12344321905402467, 0.1679443975444883, 0.1568793912883848, 0.236618320341222, 0.12852549087256193, 0.19901938241673633, 0.1425816342816688, 0.15888019173871726, 0.1591434166766703, 0.1779818261275068, 0.19685085659148172, 0.11094141489593312, 0.15469556237803772, 0.18370581819908693, 0.12470788322389126, 0.2121637825621292, 0.18597818532725796, 0.10700973172788508, 0.12496566079789773, 0.08069969859207049, 0.09358929717564024, 0.2113956745597534, 0.18636341934325173, 0.11243243410717696, 1.2410481995902956, 10.988010037690401, 40.41552051901817, 54.9672918766737, 49.19500261545181, 42.307970970869064, 19.88278079777956, 20.548212490975857, 32.98930540680885, 25.088360868394375, 10.349428653717041, 2.8093832870945334, 0.904560046037659, 0.28334402712062, 0.6162688031326979, 2.925280868075788, 5.814098892733455, 6.6249307338148355, 7.674113335087895, 10.177436582744122, 19.95157040655613, 12.562535349279642, 14.532786626368761, 21.68645851314068, 10.84363678470254, 10.988899189978838, 7.64837209135294, 5.951933646574616, 3.6073611304163933, 1.5272537106648088, 4.525607982650399, 8.436323460191488, 13.879970256239176, 24.882429018616676, 32.150337025523186, 42.9952172935009, 56.987396478652954, 62.1867448836565, 58.23438696563244, 57.78016313910484, 62.72282391786575, 58.608252704143524, 58.553003668785095, 58.7089890986681, 56.780410185456276, 60.945138707756996, 60.864461436867714, 56.93596623837948, 52.62218691408634, 49.41490441560745, 53.02516669034958, 54.536539390683174, 58.58876734972, 58.63314516842365, 59.64337036013603, 60.34210726618767, 63.04423347115517, 54.85403135418892, 56.44377484917641, 52.49957889318466, 54.59348313510418, 54.24202859401703, 53.319533094763756, 53.19811441004276, 53.69680345058441, 52.45495788753033, 51.369937509298325, 47.23097160458565, 36.233001351356506, 20.8483374863863, 8.336168434470892, 4.610076025128365, 7.209223955869675, 6.201702794060111, 8.246340304613113, 10.343885701149702, 6.742022400721908, 6.83602555654943, 20.368250347673893, 24.697031266987324, 13.842325676232576, 13.334546573460102, 15.60477465391159, 13.583578560501337, 6.618042178452015, 3.620657566934824, 2.629240653477609, 0.37855670554563403, 0.7381684589199722, 5.750070903450251, 21.749877110123634, 33.64964157342911, 15.988440066576004, 26.503830514848232, 38.212334141135216, 40.96035048365593, 33.11760172247887, 18.308859653770924, 6.103460490703583, 0.8140014647506177, 0.22328526625642553, 0.12744562147418037, 0.1453812379622832, 0.1500517365639098, 0.1520599881769158, 0.13041036785580218, 0.20739744300954044, 0.16908641438931227, 0.2354939072392881, 0.16426767921075225, 0.11209915785002522, 0.2055478180409409, 0.15704463789006695, 0.17127628438174725, 0.24810452508972958, 0.18360107147600502, 0.11250248542637564, 0.07487828479497693, 0.15616764198057353, 0.10301057249307632, 0.0847103982232511, 0.2181727741844952, 0.12296423694351688, 0.10839543276233599, 0.0857470597838983, 0.09305725150625221, 0.08947523121605627, 0.14341074682306498, 0.12546963844215497, 0.08351478347321972, 0.22156401799293235, 0.19154651934513822, 0.11534204633790068, 0.09631904249545187, 0.301357465214096], [0.04059836115629878, 0.03448692717938684, 0.06545317999552935, 0.042235991641064174, 0.006792968597437721, 0.02763248277915409, 0.008851703878463013, 0.07615707203513011, 0.030216438753996044, 0.03521849925164133, 0.08003679002285935, 0.026885718943958636, 0.03723020556208212, 0.0180771997111151, 0.01816641142795561, 0.029958260420244187, 0.05453417274111416, 0.029250264524307568, 0.019075217642239295, 0.09215253638103604, 0.07551233866252005, 0.03984350048995111, 0.03112114645773545, 0.06339542713249102, 0.012218822321301559, 0.0517157741705887, 0.04738729061500635, 0.06549814672325738, 0.0768109857745003, 0.05726795905502513, 0.0836173482821323, 0.018370305369899143, 0.07045877311611548, 0.049137831447296776, 0.03304286365164444, 0.02212436662375694, 0.09987709883716889, 0.07735449020401575, 0.042855325009441, 0.03591259657696355, 0.044718564677168615, 0.07507620073738508, 0.5239461665041745, 12.03180642798543, 29.104190580546856, 37.772496342659, 37.21301056444645, 29.54342231154442, 20.679941922426224, 22.250762432813644, 16.355399675667286, 17.629845589399338, 8.074275087565184, 2.0234044874086976, 0.6049575819633901, 0.22216036333702505, 0.1844747574068606, 0.7580939959734678, 1.0600370750762522, 4.611158017069101, 3.86351203545928, 3.612793651409447, 2.772180908359587, 5.289931744337082, 3.18122492171824, 3.9817802142351866, 5.219948049634695, 6.149123590439558, 3.9240558492019773, 4.484384469687939, 2.4019684363156557, 3.32805379293859, 3.913194607011974, 3.439055811613798, 6.592125669121742, 17.97566693276167, 26.95634063333273, 33.72997306287289, 46.787391006946564, 55.01740358769894, 56.76203817129135, 59.313168078660965, 56.21469274163246, 57.21445709466934, 55.05303047597408, 58.289085030555725, 56.817112416028976, 55.937896594405174, 50.04610374569893, 50.52247658371925, 43.03775601089001, 52.19385489821434, 57.607014030218124, 52.411556616425514, 56.713111996650696, 59.11896429955959, 59.880880415439606, 53.57144437730312, 54.772468730807304, 52.305549904704094, 53.684028536081314, 56.945344135165215, 55.37660971283913, 56.5995816886425, 53.42764489352703, 52.19230838119984, 49.21731501817703, 41.02569937705994, 31.102172769606113, 17.495334707200527, 6.457975767552853, 2.049919464625418, 1.467196389567107, 1.3241188670508564, 2.8003362100571394, 6.93013415671885, 5.187164358794689, 3.1528960168361664, 1.0839975206181407, 11.288931090384722, 13.803470861166716, 6.176058920100331, 3.7783666793257, 3.072525104507804, 1.9705953961238265, 2.5845327274873853, 0.7777281361632049, 0.1570809437544085, 0.4115881252801046, 4.043485103175044, 17.827889062464237, 17.47057143598795, 8.983088470995426, 18.880586475133896, 29.0109720826149, 30.198041684925556, 25.89962113648653, 14.786194078624249, 4.603162771090865, 1.0821403702721, 0.16069866134785116, 0.016485680716868956, 0.10160113757592626, 0.09140468158875592, 0.02133358229912119, 0.009717827324493555, 0.06394469062797725, 0.008956130550359376, 0.02582897857791977, 0.01649757363338722, 0.04768860999320168, 0.07767420000163838, 0.01424219333785004, 0.046840991999488324, 0.07940204595797695, 0.05194233701331541, 0.03968711513152812, 0.021100334561197087, 0.08164942497387528, 0.019130516920995433, 0.10424573629279621, 0.0425883039861219, 0.03334117733174935, 0.029659278807230294, 0.030769643053645268, 0.020262327379896306, 0.038480023067677394, 0.02836755407770397, 0.014139945797069231, 0.07451779398252256, 0.03674891166156158, 0.020457254322536755, 0.007463978636224056, 0.018437759172229562, 0.026268725196132436, 0.03813633076788392, 0.011210156426386675, 0.020566275816236157, 0.02991634391946718, 0.01624648466531653, 0.08035406557610258, 0.026550028851488605, 0.006909467228979338, 0.016762785671744496, 0.0553143369324971, 0.06410099435015582, 0.06175060152600054, 0.014518390089506283, 0.010728671422839398, 0.025210350249835756, 0.061132459304644726, 0.02487241887138225, 0.035079840090475045, 0.06858484281110577, 0.00954022860241821, 0.019377477692614775, 0.04697414442489389, 0.052160302075208165, 0.03333823842694983, 0.08412723342189565, 0.04720162382000126, 0.02002429278945783, 0.02070171776722418, 0.051100377895636484, 0.022921707823115867, 0.0038074682879596367, 0.08016623542062007, 0.07522837811848149, 0.054803190141683444, 0.013774816561635816, 0.02444631107209716, 0.045246001609484665, 0.09304364793933928, 0.03698289227031637, 0.05595409049419686, 0.06947815854800865, 0.016026675366447307, 0.055041508603608236, 0.9753174148499966, 16.026301234960556, 34.530783891677856, 44.10620167851448, 38.36983188986778, 25.67351046949625, 16.2850084528327, 27.040338926017284, 26.534171886742115, 19.054183959960938, 8.440731223672628, 2.7394527895376086, 0.6014213373418897, 0.1436012561316602, 0.14114014600636438, 0.2784651186084375, 0.49802778696175665, 2.463720585219562, 3.480650754645467, 7.007575426250696, 6.095564039424062, 9.478191453963518, 6.519611785188317, 7.802288057282567, 8.390395324677229, 6.637554131448269, 5.104467496275902, 4.13936915807426, 2.923212116584182, 4.19540380127728, 7.1786536462605, 5.67901661619544, 10.54935872554779, 22.196672335267067, 32.78271049261093, 36.82101219892502, 53.47189351916313, 56.66868478059769, 59.074974060058594, 58.76925386488438, 59.826581329107285, 59.905875474214554, 57.54855416715145, 59.08070795238018, 61.15196920931339, 56.159994676709175, 53.489296585321426, 51.02542519569397, 45.448521450161934, 54.34961602091789, 56.13241955637932, 55.257885083556175, 57.81643219292164, 58.39868254959583, 61.54444634914398, 57.014340832829475, 56.13493502140045, 52.74067975580692, 54.24540661275387, 55.2718835324049, 55.338577553629875, 56.34759820997715, 53.04179459810257, 52.79197320342064, 50.01010827720165, 42.70481027662754, 35.673108994960785, 21.20466146618128, 8.725935369729996, 4.268700918182731, 3.370110411196947, 4.885492846369743, 5.060542328283191, 5.2071028389036655, 6.899852631613612, 4.962078211829066, 4.785392442718148, 9.932785760611296, 12.261406257748604, 9.214336462318897, 3.2855796720832586, 3.685381868854165, 2.288245288655162, 0.5164137238170952, 0.10895976927713491, 0.02552787813328905, 0.3790307301096618, 3.432154431939125, 13.743572775274515, 20.50635203719139, 14.83978545293212, 14.681042321026325, 28.572392016649246, 34.33813042938709, 32.04348675906658, 17.78861626982689, 7.2866457514464855, 1.5541492612101138, 0.15148998907534406, 0.0838713557459414, 0.0231184752919944, 0.06880913468194194, 0.020801790815312415, 0.03970462239522021, 0.042893152276519686, 0.07882865524152294, 0.020858515017607715, 0.029796151247865055, 0.044737901334883645, 0.028752019970852416, 0.03712536607054062, 0.023067020338203292, 0.07019194876193069, 0.0464924423431512, 0.045385603298200294, 0.04677572753280401, 0.019939250087190885, 0.011471467551018577, 0.05743527624872513, 0.08207554390537553, 0.042092912990483455, 0.04649322530895006, 0.07411979502649046, 0.012862801486335229, 0.01179824908831506, 0.05451251687190961, 0.006930596637175768, 0.06196964270202443, 0.022311439788609277, 0.05041821059421636, 0.026901140772679355, 0.03655756743683014, 0.03662336996058002, 0.09033867550897412, 0.0659004352928605, 0.1493139230296947, 0.18571325344964862, 0.12984375294763595, 0.1886267916415818, 0.10587017881334759, 0.08649648050777614, 0.11206398747162893, 0.11722887516953051, 0.11570888251299039, 0.12363568763248622, 0.13711160514503717, 0.1101590131293051, 0.09022621787153184, 0.10174925540923141, 0.09094273176742718, 0.21132515568751842, 0.40602071152534336, 0.10554796797805466, 0.18757729092612863, 0.12421962426742539, 0.134440986730624, 0.11962448334088549, 0.10553981919656508, 0.12275521105038933, 0.12829036364564672, 0.1790560403605923, 0.11508383831824176, 0.15640763769624755, 0.13305936008691788, 0.30716949084308, 0.15717633941676468, 0.15660634031519294, 0.10634680831572041, 0.19097951852018014, 0.17282358807278797, 0.13424698932794854, 0.12434806034434587, 0.15020782506326213, 0.136460964276921, 0.10882123257033527, 0.19069747271714732, 1.6343218716792762, 18.014037273824215, 40.70807062089443, 52.64756575226784, 50.562686026096344, 37.717201709747314, 27.730436995625496, 30.689340122044086, 24.04299706220627, 22.968447022140026, 10.425177589058876, 3.55042546056211, 0.7231334375683218, 0.43215751997195184, 0.8237235399428755, 2.3962238570675254, 4.537350302562118, 11.69583510607481, 9.196583814918995, 11.881962418556213, 12.024036794900894, 14.026545491069555, 10.28564052656293, 10.796801447868347, 13.602529093623161, 13.977830205112696, 10.008026473224163, 9.091497603803873, 5.918741002678871, 6.445163805037737, 6.808469910174608, 4.746989803388715, 8.918394092470407, 20.65551683306694, 29.45521004498005, 39.1298671066761, 52.96282343566418, 59.71667222678661, 59.95026469230652, 59.90815155208111, 59.069392159581184, 62.22508482635021, 58.67466174066067, 61.45848736166954, 60.25663085281849, 57.070285230875015, 54.78648617863655, 55.71717023849487, 52.55084574222565, 52.662742137908936, 58.19342516362667, 55.08339084684849, 57.349767833948135, 58.38093750178814, 61.20146915316582, 55.79852007329464, 55.11128894984722, 53.23124103248119, 52.58794315159321, 56.57581776380539, 54.07901354134083, 56.19705408811569, 52.633327916264534, 53.03379602730274, 51.39867536723614, 42.91648171842098, 35.36234647035599, 20.633506514132023, 7.839671401306987, 4.248082749545574, 4.7946924436837435, 5.755611956119537, 6.870923833921552, 12.886200081557035, 11.533561963588, 7.841953178867698, 7.97770706936717, 21.670820452272892, 24.166676625609398, 13.690919000655413, 11.474099904298782, 9.87234715372324, 6.658626850694418, 5.225152345374227, 2.118006111122668, 0.49514822429046035, 0.6247824837919325, 5.740641709417105, 21.019732989370823, 22.49753639101982, 18.458431027829647, 27.1545322984457, 37.83362366259098, 40.61304531991482, 35.42267583310604, 19.470140039920807, 7.288188943639398, 1.428621334489435, 0.22807096102042124, 0.10225536301732063, 0.16396863822592422, 0.23259999143192545, 0.13733843516092747, 0.10967719601467252, 0.16318445530487224, 0.21435813512653112, 0.11079017262090929, 0.09137670262134634, 0.13438232737826183, 0.28432609629817307, 0.14744025247637182, 0.19659524608869106, 0.22892031935043633, 0.18328133941395208, 0.21252534206723794, 0.13970745960250497, 0.1586187627981417, 0.09325050676125102, 0.2312190772499889, 0.19965797080658376, 0.1551674198708497, 0.11293700546957552, 0.15430312952958047, 0.13033401570282876, 0.16508365573827177, 0.13557308848248795, 0.10866362266824581, 0.2141214197035879, 0.06275171050219797, 0.1563130138674751, 0.06291789963142946, 0.10170641864533536, 0.14124474429991096, 0.17420380463590845], [0.01134602975071175, 0.06141446057881694, 0.03162332439387683, 0.027843900243169628, 0.06610641838051379, 0.05171346609131433, 0.022057927708374336, 0.03066947352635907, 0.017772501705621835, 0.019657970551634207, 0.04686292617407162, 0.025751567009137943, 0.044279031426412985, 0.011109587067039683, 0.11504816327942535, 0.05751992190198507, 0.020500334139796905, 0.0020607286433005356, 0.06564227922353894, 0.023976843294803984, 0.04542206501355395, 0.05732225086831022, 0.10649917123373598, 0.03110869507509051, 0.028423660442058463, 0.06791217499994673, 0.013015982622164302, 0.07272107672179118, 0.018424923728161957, 0.04374249205284286, 0.021627003370667808, 0.02756835750915343, 0.012771072961186292, 0.030204343602235895, 0.05156243532837834, 0.0540909287519753, 0.06335716199828312, 0.06082087602408137, 0.07353018838330172, 0.06726789433741942, 0.03382793343917001, 0.08281762478873134, 0.030775454069953412, 1.3606334826909006, 15.504992008209229, 33.65170866250992, 38.34808565676212, 34.55906957387924, 25.321107879281044, 13.953865841031075, 32.43203490972519, 30.291503369808197, 18.386240601539612, 8.832589946687222, 2.403935780748725, 0.7857399468775839, 0.1648194808512926, 0.7106330583337694, 0.30132332642097026, 1.3990344596095383, 2.2742228535935283, 4.801321662962437, 3.2774397963657975, 9.614692479372025, 4.9126917868852615, 3.195130038075149, 7.564557138830423, 4.72899729385972, 5.465556895360351, 3.512811753898859, 2.3018248099833727, 3.7802608776837587, 3.4292238391935825, 1.6771344118751585, 3.7187421787530184, 6.275213649496436, 15.43959941715002, 28.299844041466713, 34.52868640422821, 42.692346945405006, 49.05699402093887, 52.8981015086174, 57.75992162525654, 57.10436560213566, 56.508523374795914, 58.96142095327377, 53.95073242485523, 53.378281742334366, 50.23298531770706, 51.00037693977356, 46.28567352890968, 46.15564450621605, 62.46861755847931, 46.462033465504646, 68.46446022391319, 56.318704560399055, 54.07333664596081, 55.07633462548256, 58.71741324663162, 56.036983877420425, 58.44835728406906, 54.917544946074486, 56.48858204483986, 55.26525288820267, 53.76630552113056, 46.42761491239071, 38.958648294210434, 28.284901343286037, 16.921538896858692, 5.375928254798055, 2.1790476981550455, 1.2797322613187134, 1.6024544066749513, 5.822040941566229, 3.500100248493254, 4.493111651390791, 6.043374789878726, 3.283230923116207, 3.9523315569385886, 5.558338891714811, 13.806548696011305, 7.399257933720946, 2.0473890379071236, 2.8501997468993068, 1.4030069089494646, 0.7233543007168919, 0.12847394129494205, 0.5058907822240144, 3.807206181809306, 17.53200463950634, 11.907906476408243, 10.41275130584836, 24.001252502202988, 30.5658695474267, 30.60772430151701, 25.426067747175694, 14.259118661284447, 5.784607725217938, 0.6651270564179868, 0.015627271895937156, 0.029427277877402958, 0.004875971926594502, 0.051002893087570556, 0.04752066568471491, 0.04670087080739904, 0.01705858903733315, 0.013859030841558706, 0.00458108001112123, 0.06887075520353392, 0.06293189653661102, 0.050074069295078516, 0.03391293161257636, 0.10083766057505272, 0.03468635339231696, 0.05184115630981978, 0.04932474505039863, 0.019035130535485223, 0.05094270491099451, 0.030562778665625956, 0.04054281140270177, 0.0596769370167749, 0.030880377053108532, 0.052024956603418104, 0.0063635336573497625, 0.05864187849510927, 0.06273634062381461, 0.022747789225832094, 0.06782408949220553, 0.03204412954801228, 0.06863884147605859, 0.011401046085666167, 0.012775039740517968, 0.04970833892002702, 0.02184402404964203, 0.05445600603707135, 0.020145813905401155, 0.02855627295502927, 0.10970672607072629, 0.03380312344233971, 0.032555094512645155, 0.04197578724415507, 0.028646176724578254, 0.01277764189580921, 0.030193098209565505, 0.046669730290886946, 0.01963020124094328, 0.00853364443173632, 0.09891975059872493, 0.012134836251789238, 0.02789537189528346, 0.06509842598461546, 0.010276346329192165, 0.030356810420926195, 0.05719767767004669, 0.05449883909022901, 0.04212016094243154, 0.009316444175055949, 0.055977482988964766, 0.016047435092332307, 0.03042636079044314, 0.021339936938602477, 0.011686000179906841, 0.010093125838466221, 0.08041463966947049, 0.06713206646963954, 0.07095502500305884, 0.012070610791852232, 0.04280257686332334, 0.019439274474279955, 0.04918520644423552, 0.07521041072322987, 0.0808916699315887, 0.013094852511130739, 0.03136244464258198, 0.039189638700918294, 0.07713941580732353, 0.0662755909434054, 0.07654623943381011, 0.052053599792998284, 2.3930773884058, 17.885539568960667, 38.782934322953224, 42.557784765958786, 37.20399744808674, 23.39059866964817, 14.97709583491087, 30.692359060049057, 32.77620144188404, 20.771095231175423, 8.854970745742321, 3.7004456855356693, 0.5834984709508717, 0.0678214177605696, 0.3074564051348716, 0.2923025214113295, 1.5234784944914281, 3.724312442354858, 4.972168570384383, 4.145436957478523, 11.153152976185083, 5.55492477491498, 11.245299931615591, 9.258973617106676, 6.4530303329229355, 5.046882536262274, 4.175906572490931, 4.348725099116564, 3.5210523242130876, 4.044471150264144, 4.34116255491972, 5.383548270910978, 8.549659978598356, 21.346361562609673, 32.16164901852608, 37.01616212725639, 47.51817159354687, 53.26859302818775, 56.321182027459145, 59.8012138903141, 59.67003732919693, 57.997545674443245, 60.40986903011799, 55.54316237568855, 54.317728132009506, 53.54871779680252, 52.62896575033665, 47.772647738456726, 49.45497706532478, 61.67183831334114, 51.80777281522751, 62.939271703362465, 59.14240904152393, 55.601029470562935, 55.40383905172348, 59.17984463274479, 55.85935860872269, 57.38486275076866, 55.84833540022373, 55.95808491110802, 54.29425299167633, 55.01559108495712, 48.306769877672195, 41.65616154670715, 31.30735795944929, 21.095231138169765, 9.78493569418788, 3.3631745958700776, 3.2349469140172005, 3.517448455095291, 4.222736684605479, 5.995880663394928, 5.897690132260323, 4.904458578675985, 6.958335768431425, 5.5948710814118385, 8.05563423782587, 10.018765646964312, 8.36896637454629, 4.10170272924006, 1.991819276008755, 0.9922995942179114, 0.2932067838264629, 0.07389877602690831, 0.4334976605605334, 2.6960883289575577, 12.170109506696463, 17.259601056575775, 14.905950352549553, 18.48443303257227, 30.55248286575079, 32.82273754477501, 30.649018585681915, 19.24712810665369, 7.9106140695512295, 1.106435435358435, 0.02472117659635842, 0.03269314140197821, 0.006714674336762982, 0.07554826603154652, 0.057913508790079504, 0.004757162432724726, 0.023461469972971827, 0.029351064877118915, 0.04374547548650298, 0.05522975065105129, 0.037404966496978886, 0.06622444954700768, 0.007567175662188674, 0.016053431645559613, 0.057624653782113455, 0.022928223879716825, 0.010395116860308917, 0.018777647965180222, 0.08884458380634896, 0.0553533776110271, 0.030119872353679966, 0.046554292930522934, 0.06489951556432061, 0.02420669941784581, 0.0570236291969195, 0.0709799092146568, 0.021882864348299336, 0.05350361534510739, 0.01301609579968499, 0.022228870293474756, 0.02397939628281165, 0.008653168242744869, 0.02680937606783118, 0.1363530708476901, 0.013802711109747179, 0.03620247203798499, 0.020836009389313404, 0.10742183148977347, 0.24959587084595114, 0.14446306769968942, 0.10296976179233752, 0.133223686425481, 0.15771341684740037, 0.09498428989900276, 0.10421419501653872, 0.07774837024044245, 0.1349648687755689, 0.0947909159003757, 0.17885456210933626, 0.16472222981974483, 0.1190563099225983, 0.20478204038226977, 0.12965028989128768, 0.07677410103497095, 0.18246427935082465, 0.15765291696880013, 0.16414145473390818, 0.053534510952886194, 0.24212608026573434, 0.13500616187229753, 0.06889347976539284, 0.11083612640504725, 0.10994750846293755, 0.09493473669863306, 0.1685993280261755, 0.17515737534267828, 0.13185895106289536, 0.15231834462611005, 0.0636416272027418, 0.13657010451424867, 0.10585099429590628, 0.0895782709994819, 0.18718837585765868, 0.14314369240310043, 0.1455213999724947, 0.21365351043641567, 0.17490663332864642, 0.18001632008235902, 0.22118129243608564, 0.15595415577990934, 3.297659461386502, 21.012237891554832, 46.9997426122427, 51.122414991259575, 48.09228278696537, 34.03737656772137, 21.018302366137505, 40.19946791231632, 37.563587352633476, 25.770319774746895, 11.723136641085148, 4.023931352421641, 1.1071242671459913, 0.4708479344844818, 1.3013567822054029, 1.8587879394181073, 4.179909657686949, 7.37066256813705, 13.791488204151392, 11.697379723191261, 21.271630972623825, 16.340278387069702, 9.653383903205395, 14.679558500647545, 12.507401257753372, 12.621456887573004, 9.148378651589155, 6.6155271884053946, 8.149746637791395, 7.824067063629627, 3.3075249195098877, 6.498534316197038, 8.830875288695097, 19.745078086853027, 30.94660721719265, 39.80234742164612, 48.19832369685173, 55.78617453575134, 58.06763671338558, 62.49627247452736, 61.58535495400429, 60.2861362695694, 62.25629635155201, 59.33721698820591, 57.72617943584919, 55.92584364116192, 55.749586299061775, 52.33618006110191, 49.012053832411766, 66.02132812142372, 50.52049309015274, 63.321056216955185, 58.70851792395115, 56.16892799735069, 56.451062858104706, 59.43085536360741, 56.05557627975941, 56.18773318827152, 55.324248522520065, 55.51802672445774, 54.39163416624069, 54.784415289759636, 48.633217960596085, 41.257657930254936, 31.407193802297115, 19.390627406537533, 7.850750656798482, 3.162337322719395, 3.1953848619014025, 5.162759218364954, 11.138083934783936, 8.739054165780544, 9.257492646574974, 11.491749007254839, 9.217533990740776, 10.32275028526783, 15.814068373292685, 20.974300727248192, 14.924357514828444, 9.203241057693958, 8.453647680580616, 3.485069442540407, 1.6825453215278685, 0.22640935174422339, 0.8116765238810331, 5.167719852179289, 19.38018176704645, 19.9147579818964, 18.264867514371872, 34.99389164149761, 39.597261026501656, 39.60102282464504, 38.97649593651295, 21.95177737623453, 7.701869420707226, 0.9844663145486265, 0.13621489779325202, 0.10542652293224819, 0.12353149752016179, 0.2145258753444068, 0.11730457423254848, 0.18502666294807568, 0.18271211214596406, 0.09369615159812383, 0.1674973129411228, 0.17404505924787372, 0.113944611948682, 0.1647995170787908, 0.1294967989088036, 0.13871563860448077, 0.16247350751655176, 0.15201060567051172, 0.14323969662655145, 0.09781213972019032, 0.20778684789547697, 0.1903907282394357, 0.12794722424587235, 0.1778779402957298, 0.1478457619668916, 0.16710574098397046, 0.07141298949136399, 0.24693424726137891, 0.23945964756421745, 0.13252100616227835, 0.15348538669059053, 0.27004328614566475, 0.13842485030181706, 0.06588583724806085, 0.1267452715546824, 0.3354525309987366, 0.16607322060735896, 0.16002298041712493, 0.08043547917623073], [0.003657584143184067, 0.06283058595727198, 0.04734454661956988, 0.04151162211201154, 0.01966250507393852, 0.019086565080215223, 0.06614449055632576, 0.023178010378615, 0.018705238471738994, 0.02426522518362617, 0.10123399712028913, 0.07090841812896542, 0.04395391508296598, 0.03556727897375822, 0.03277234711276833, 0.0067706652043852955, 0.04875968865235336, 0.031405337067553774, 0.07128637167625129, 0.04320692860346753, 0.06832469036453404, 0.0470334123383509, 0.054542495927307755, 0.04503893498622347, 0.05366112134652212, 0.08342122833710164, 0.059951579896733165, 0.04715174036391545, 0.008281749305751873, 0.0400824386451859, 0.04648291316698305, 0.03520236125041265, 0.06327603783574887, 0.04349193557573017, 0.07693486506468616, 0.052609783815569244, 0.06149195192847401, 0.03650801052572206, 0.040761266282061115, 0.004031034477520734, 0.079808245645836, 0.056637452653376386, 0.05882702207600232, 0.11252310228883289, 3.1992827402427793, 15.250900592654943, 31.443687044084072, 38.33308786153793, 36.16328649222851, 25.88061075657606, 34.76199008524418, 21.381477378308773, 18.258808739483356, 20.732420906424522, 8.476377110928297, 4.098270088434219, 1.1053463188000023, 0.09280831291107461, 0.3051887877518311, 1.2592122936621308, 3.0603213468566537, 3.749666581861675, 4.025304028764367, 7.386314878240228, 2.9567113565281034, 15.871425345540047, 7.190021211281419, 4.62399372830987, 4.050824409350753, 1.9364317855797708, 2.5688922917470336, 1.4290789724327624, 1.707218347582966, 3.2755636470392346, 1.4534348342567682, 1.510894875973463, 6.346588544547558, 13.239817656576633, 24.097995311021805, 32.79251016676426, 39.784260392189026, 45.89693158864975, 49.00934457778931, 52.840386405587196, 53.878764286637306, 52.71826475858688, 52.90160112082958, 56.88928194344044, 58.018478751182556, 48.99935111403465, 46.86594799160957, 45.151829570531845, 54.49715830385685, 55.02863958477974, 61.530831679701805, 50.61052925884724, 58.37457284331322, 54.50548745691776, 58.667225539684296, 54.87398028373718, 57.75592423975468, 56.23178422451019, 56.186509653925896, 52.39969365298748, 46.34798638522625, 34.32464875280857, 23.20604257285595, 12.782140765339136, 7.417398635298014, 1.8593501904979348, 1.032926479820162, 3.2461045403033495, 2.1811316488310695, 1.6864796541631222, 5.198309160768986, 2.662030281499028, 5.200218083336949, 6.814400916919112, 4.307314921170473, 5.851961961016059, 6.877537854015827, 6.738067287951708, 1.895182030275464, 0.7385385234374553, 1.0576847638003528, 0.1455116184661165, 0.567340194247663, 3.6862486973404884, 8.991793803870678, 12.255128994584084, 12.266851365566254, 24.514285773038864, 21.933103278279305, 24.142234437167645, 28.999369405210018, 13.184040449559689, 5.892547583207488, 1.0641233995556831, 0.038240309368120506, 0.06758427189197391, 0.04292063029424753, 0.06267633056268096, 0.03797056466282811, 0.019014617573702708, 0.032822237990330905, 0.05245884953183122, 0.041682171358843334, 0.04624726643669419, 0.04505473159952089, 0.05290434222843032, 0.06026491093507502, 0.05034201058151666, 0.010798890652949922, 0.08941211897763424, 0.06987655826378614, 0.04146138613577932, 0.05653961903590243, 0.02141445227607619, 0.09263167434255593, 0.04526156815700233, 0.00427072637648962, 0.045498409745050594, 0.03032733602594817, 0.030033575421839487, 0.018533216061769053, 0.036546668998198584, 0.024223870859714225, 0.07096878442098387, 0.050350600940873846, 0.055549527241964824, 0.014538113591697766, 0.076971861126367, 0.0387674049125053, 0.021860175038455054, 0.02966184663819149, 0.03226926375646144, 0.06664890606771223, 0.0647116631444078, 0.08094753880868666, 0.02358450321480632, 0.014396912574738963, 0.019395253984839655, 0.029378570725384634, 0.03723560839716811, 0.031729496040497907, 0.03371345344930887, 0.02914909680839628, 0.018639471200003754, 0.020768889553437475, 0.06423451413866132, 0.039425856884918176, 0.010627049141476164, 0.058786838490050286, 0.02744192894169828, 0.05549427805817686, 0.029417156838462688, 0.04509313032031059, 0.06090259019401856, 0.013523477118724259, 0.050863933356595226, 0.024174595964723267, 0.0327919398114318, 0.04358399528427981, 0.017748318823578302, 0.03742354987480212, 0.037578053888864815, 0.04698978518717922, 0.08300575922476128, 0.05760451931564603, 0.09523103915853426, 0.0594152928533731, 0.03934700369427446, 0.022133769634820055, 0.0441247240814846, 0.06956505661946721, 0.01784029504051432, 0.02186245528719155, 0.007509428687626496, 0.038438930350821465, 0.058024686222779565, 4.658573297783732, 19.764344953000546, 36.30084291100502, 42.43956170976162, 37.13512234389782, 22.468597143888474, 33.80694933235645, 29.861060567200184, 25.52815116941929, 22.506549507379532, 10.274923201650381, 5.655621746554971, 1.038854280486703, 0.07461409506504424, 0.11967402169830166, 0.46085666748695076, 0.2843385940650478, 2.6070678932592273, 1.4993877871893346, 4.322191597893834, 5.506038023158908, 12.10984569042921, 6.065762713551521, 3.5453199595212936, 6.361310379579663, 6.309211375191808, 5.882031172513962, 4.759474508464336, 4.3763686157763, 6.784307956695557, 4.712841510772705, 5.218123672530055, 9.001315142959356, 18.4723686799407, 28.07701639831066, 36.678660437464714, 43.04122142493725, 51.565554812550545, 53.874322324991226, 55.891094505786896, 55.101276487112045, 54.5258429646492, 56.37644626200199, 57.957157641649246, 59.70325514674187, 50.44168911874294, 46.97790518403053, 46.18788957595825, 58.52412901818752, 55.09391248226166, 63.64125743508339, 53.85326765477657, 56.51882462203503, 56.664858385920525, 59.44307930767536, 57.42237813770771, 57.49909222126007, 57.24028430879116, 57.27687254548073, 52.36342079937458, 46.815277710556984, 37.5010085105896, 27.30581548064947, 16.296348944306374, 9.164141155779362, 3.8221465051174164, 2.3401483660563827, 4.473696118220687, 3.7804427929222584, 4.288283167406917, 6.512334700673819, 5.436906907707453, 8.172478917986155, 9.715727157890797, 7.8550126031041145, 6.855737948790193, 5.298757720738649, 6.642973590642214, 1.6551435668952763, 0.8999127766583115, 0.3501075430540368, 0.3254705260042101, 0.49712966952938586, 3.0452665546908975, 10.854160320013762, 17.72293109446764, 15.638256557285786, 22.873670607805252, 24.92826785892248, 28.29285241663456, 35.00049188733101, 19.148369506001472, 8.838774114847183, 1.3278662972152233, 0.0331230564188445, 0.03357941415742971, 0.012976982761756517, 0.02302273453096859, 0.09488902040175162, 0.01576604052388575, 0.03269634005846456, 0.04918925114907324, 0.06535880107549019, 0.09762574190972373, 0.045539368875324726, 0.015283247485058382, 0.03833766430034302, 0.013795554950775113, 0.025859024426608812, 0.05355683475499973, 0.015989516032277606, 0.034149947605328634, 0.033211416521226056, 0.013195343017287087, 0.03755080222617835, 0.07419490779284388, 0.030102311284281313, 0.024537248282285873, 0.10117850673850626, 0.0324926279427018, 0.005935032895649783, 0.06087454814405646, 0.03598688555939589, 0.02534399063733872, 0.030339117620314937, 0.08341516499058343, 0.06918701401446015, 0.0534270145726623, 0.02708982068725163, 0.03960695205023512, 0.01095962870749645, 0.020562416648317594, 0.23186113889096305, 0.19111025525489822, 0.23164178972365335, 0.09236984464223497, 0.12827087484765798, 0.06808090227423236, 0.1752772618783638, 0.13169324432965368, 0.09968536498490721, 0.08739675758988596, 0.13124483870342374, 0.18726276874076575, 0.09342509700218216, 0.11335681614582427, 0.09603928992873989, 0.177411797340028, 0.170338298776187, 0.08937631035223603, 0.16667554766172543, 0.1685938361333683, 0.11494288963149302, 0.1418219125480391, 0.12492003355873749, 0.144847767369356, 0.2694505773251876, 0.1183673000195995, 0.11311011883663014, 0.08446925217867829, 0.10798162606079131, 0.08965284941950813, 0.2727392711676657, 0.16552395711187273, 0.09361188815091737, 0.29909756616689265, 0.18383183487458155, 0.16931134450715035, 0.12029072415316477, 0.21689628018066287, 0.2244470687583089, 0.10020949193858542, 0.13555208570323884, 0.08495017129462212, 0.10074757869006135, 0.22446716611739248, 5.769059434533119, 23.291423991322517, 44.13160711526871, 51.347324922680855, 48.00293818116188, 34.1439950466156, 41.64169952273369, 30.461185164749622, 25.09513970464468, 27.676344998180866, 11.390941366553307, 6.08499395661056, 1.844354176428169, 0.27114953147247434, 0.6847345980349928, 3.3687752578407526, 6.246682405471802, 8.939476311206818, 9.823933951556683, 14.829521253705025, 7.856690688058734, 26.074197068810463, 14.795225244015455, 10.7196693867445, 10.60632336884737, 6.724504865705967, 9.72577191889286, 6.534013012424111, 5.04534836858511, 8.81625272333622, 3.223960278555751, 4.500443357974291, 10.509660355746746, 18.256426267325878, 26.440670304000378, 37.79060237109661, 42.952028810977936, 51.82017154991627, 55.74710503220558, 58.88254098594189, 58.11168015003204, 59.21421378850937, 57.73814879357815, 60.54851979017258, 62.11991786956787, 55.409185364842415, 50.918453335762024, 46.79434463381767, 62.30502873659134, 57.04777903854847, 60.38067899644375, 54.16235826909542, 56.321303620934486, 54.58473600447178, 60.14088146388531, 56.6390273720026, 56.81093394756317, 56.35124981403351, 55.73440611362457, 52.24553972482681, 46.88191473484039, 39.0550073236227, 25.98262008279562, 15.040317792445421, 10.304804798215628, 3.3301009330898523, 3.260305803269148, 6.25995984300971, 7.077295035123825, 5.893695121631026, 11.299986597150564, 10.255218409001827, 13.023496214300394, 14.974149093031883, 10.497611202299595, 16.57052133232355, 16.02950256317854, 13.999659083783627, 4.650517255067825, 3.3055796613916755, 2.4368360778316855, 0.9150704008061439, 0.862997816875577, 5.0072117149829865, 12.487842757254839, 18.099637180566788, 21.28710374236107, 36.50923132896423, 30.839164182543755, 34.31041471660137, 42.26614661514759, 23.01645554602146, 10.224091429263353, 1.3294314569793642, 0.12455284857423976, 0.1515184430172667, 0.2679836779134348, 0.13245578622445464, 0.21089488815050572, 0.1802032522391528, 0.10723863975727, 0.14315838692709804, 0.14540286414558068, 0.22662791423499584, 0.14871079445583746, 0.11455796731752343, 0.14282461343100294, 0.10201542667346075, 0.12011608196189627, 0.3002700407523662, 0.1577600385644473, 0.16592159983702004, 0.13698459399165586, 0.11957389113376848, 0.14672724151751027, 0.2052938551059924, 0.10621612353133969, 0.07115916756447405, 0.14114266930846497, 0.10269080332363956, 0.14744120242539793, 0.16273829096462578, 0.08920583903091028, 0.12984608329134062, 0.14489587338175625, 0.1838642221991904, 0.19370720809092745, 0.22608929313719273, 0.129482104384806, 0.14875026186928153, 0.09015059302328154, 0.13098565104883164], [0.05171558492293116, 0.08759966818615794, 0.03760433704883326, 0.08101275874651037, 0.012765569936163956, 0.046529620231012814, 0.02784073498332873, 0.0418538560916204, 0.015942051977617666, 0.04555828250886407, 0.04824578107218258, 0.04759440176712815, 0.06819367161369883, 0.030092602137301583, 0.012260454022907652, 0.06468874562415294, 0.02330296949367039, 0.05673986903275363, 0.09200695669278502, 0.038483696698676795, 0.07932349704788066, 0.032068601867649704, 0.01812683454772923, 0.025717702810652554, 0.027909721320611425, 0.019976042058260646, 0.032561784973950125, 0.02260830813611392, 0.06363436157698743, 0.0571854582085507, 0.010619581280479906, 0.01668275803240249, 0.0036243665408619563, 0.05119640067277942, 0.06248735749977641, 0.014737271703779697, 0.02483887194102863, 0.03600131662096828, 0.01915839013236109, 0.08725509644136764, 0.0546392905380344, 0.0865276507101953, 0.08688817863003351, 0.05300930417433847, 0.1579707788187079, 4.271145612001419, 16.42057567834854, 31.872476935386658, 37.46548041701317, 32.00403347611427, 28.91699742525816, 16.237140521407127, 13.466540090739727, 14.651677496731281, 14.450011868029833, 8.495273496955633, 6.195617895573378, 1.8661521817557514, 0.5498090630862862, 0.3239782154560089, 0.7390318438410759, 2.052516625262797, 0.9972168272361159, 5.57613143697381, 3.8613953115418553, 10.54329140111804, 6.5073194447904825, 2.3163084452971816, 3.495580153539777, 5.614056251943111, 1.9870498194359243, 3.3823402924463153, 4.014048082754016, 6.203360930085182, 4.399904077872634, 0.9071090561337769, 2.7535393461585045, 4.5038949977606535, 10.66073739901185, 21.30823440849781, 30.987352430820465, 40.65078869462013, 51.19744196534157, 49.415694773197174, 59.770036563277245, 56.41758285462856, 59.54981938004494, 58.59353609383106, 52.74304702877998, 47.83277951180935, 49.1721810400486, 41.03170305490494, 42.61194325983524, 58.0923505872488, 53.00937473773956, 59.15740303695202, 55.652805492281914, 57.02811509370804, 53.83573919534683, 58.32822673022747, 58.24955575168133, 55.806841626763344, 53.093456625938416, 44.88675579428673, 30.829790085554123, 20.423793867230415, 12.644172068685293, 4.159620646387339, 2.3165278835222125, 2.361029195599258, 1.4786428003571928, 4.94065448641777, 2.514213938266039, 2.969003221951425, 5.2983710914850235, 5.1139204390347, 4.745923010632396, 7.819234672933817, 5.698563242331147, 3.3380299201235175, 5.695458333939314, 5.25636482052505, 2.462640730664134, 0.6069262919481844, 0.2458132480387576, 0.44402401603292674, 4.404693245887756, 4.838623311370611, 6.517848204821348, 11.332762688398361, 18.166743479669094, 17.064521424472332, 21.48045066744089, 28.921120204031467, 18.12772337347269, 8.583822045475245, 1.6302006365731359, 0.14265393430832773, 0.05065743447630666, 0.04404005616379436, 0.1232113127480261, 0.07905862454208545, 0.04104055500647519, 0.04665767410187982, 0.08793943823548034, 0.06360607832903042, 0.017506161602796055, 0.07023752405075356, 0.05263499086140655, 0.051088065665680915, 0.03090478443482425, 0.02817763848725008, 0.01717116727377288, 0.015654735070711467, 0.006231134047993692, 0.0378612574422732, 0.011337685227772454, 0.007353992814387311, 0.03629347418609541, 0.0663945720589254, 0.01200593076646328, 0.017285541507590096, 0.08651516036479734, 0.008852962746459525, 0.0636390371073503, 0.007435411516780732, 0.044044638925697654, 0.08273177314549685, 0.03104712835920509, 0.0589758857677225, 0.053312720119720325, 0.036089684144826606, 0.05328573563019745, 0.059504977689357474, 0.036725957033922896, 0.04826556672924198, 0.07030602428130805, 0.020168922528682742, 0.08788911320152692, 0.06299862303421833, 0.01585966059792554, 0.036826195209869184, 0.06153914509923197, 0.04164520498306956, 0.020571532077156007, 0.02039658746070927, 0.04652643641748, 0.023345852641796228, 0.07128772980649956, 0.1034169651393313, 0.008125517015287187, 0.06836985005065799, 0.03290530286903959, 0.011311575544823427, 0.027224618825130165, 0.06287733383942395, 0.03637165944383014, 0.015740458693471737, 0.01343393329079845, 0.057809734280453995, 0.045709829064435326, 0.011406344092392828, 0.0452349065017188, 0.004569587854348356, 0.01021395304633188, 0.07721333371591754, 0.12852418469265103, 0.047654085283284076, 0.020470217787078582, 0.08550295999157242, 0.040563476504758, 0.05618249015242327, 0.03408565906283911, 0.06689030444249511, 0.029318781453184783, 0.06178934534545988, 0.04176571121206507, 0.12001514987787232, 0.053779827867401764, 0.038591018674196675, 0.2446448552655056, 6.149546792730689, 21.620784737169743, 37.65279896557331, 43.80793668329716, 30.944049954414368, 26.198205314576626, 14.635642357170582, 15.788732282817364, 25.27254268527031, 20.470485761761665, 11.332762688398361, 7.568791536614299, 2.486035362817347, 0.5456402711570263, 0.16680263302987441, 0.32853601151145995, 0.8334697200916708, 1.0394368367269635, 1.9353734236210585, 4.619784504175186, 9.86316779628396, 3.7644575256854296, 5.183460032567382, 6.662064241245389, 5.758799035102129, 7.206103848293424, 6.509468229487538, 6.438590157777071, 5.657255658879876, 6.112795164808631, 2.338774739764631, 3.5133050149306655, 6.61043593659997, 13.895653914660215, 25.459314063191414, 33.22175793349743, 43.642820343375206, 51.58807620406151, 52.91765905916691, 60.312734842300415, 56.05370298027992, 59.31299328804016, 57.7477090805769, 55.57015232741833, 47.94413633644581, 47.62039750814438, 43.707983046770096, 49.344839975237846, 61.92884512245655, 55.43060101568699, 56.46266743540764, 57.5082041323185, 57.32248529791832, 56.239186227321625, 57.03616306185722, 58.11964452266693, 55.39041057229042, 54.01663228869438, 45.034605860710144, 36.20088927447796, 21.503669321537018, 16.15266915410757, 6.760803367942572, 4.513057731091976, 4.174889177083969, 3.1946479389443994, 5.954685173928738, 3.9254176011309028, 4.073358625173569, 8.526297882199287, 10.586679372936487, 5.702556353062391, 9.197547063231468, 6.775907082483172, 5.928011555224657, 4.067281801253557, 4.30967079475522, 1.0625564586371183, 0.4205652920063585, 0.14200267003616318, 0.6737895822152495, 2.888124561868608, 9.526538159698248, 11.886548772454262, 16.49758044630289, 18.537001311779022, 17.633060216903687, 22.255935855209827, 32.99374736845493, 23.416266292333603, 10.870283804833889, 2.2591808857396245, 0.023913764453027397, 0.0654477697389666, 0.026723613482317887, 0.059993993636453524, 0.05550457535719033, 0.03942971605283674, 0.01912405095936265, 0.0689159519970417, 0.03497606929158792, 0.05511669187399093, 0.0490024451573845, 0.05300165263179224, 0.051343216036912054, 0.03193516742612701, 0.023968423629412428, 0.06599937099963427, 0.08234484703280032, 0.04785995704878587, 0.052089898235863075, 0.03596086215111427, 0.05755383062933106, 0.010007597957155667, 0.04228428690112196, 0.01728951756376773, 0.026315072318539023, 0.07098539368598722, 0.06369702852680348, 0.07287364744115621, 0.02479720591509249, 0.05472486387589015, 0.03246383632358629, 0.030773402031627484, 0.0630469442694448, 0.015469522841158323, 0.035482384701026604, 0.04553672311885748, 0.024933082022471353, 0.035786999214906245, 0.04366432905953843, 0.21380437421612442, 0.15585608838591725, 0.14947725489037111, 0.2089869006886147, 0.1030563258973416, 0.09385293771629222, 0.1456036596209742, 0.06727229527314194, 0.16297384863719344, 0.09835783348535188, 0.13008569309022278, 0.15787839627591893, 0.28871842310763896, 0.22517928649904206, 0.08298335378640331, 0.15851999778533354, 0.1325320641626604, 0.16164297005161643, 0.18518196477089077, 0.08088643036899157, 0.22874916525324807, 0.08500089708832093, 0.10498357951291837, 0.14173848030623049, 0.14120061619905755, 0.12290338083403185, 0.20561864861520007, 0.13102896278724074, 0.06818996829679236, 0.1508181227836758, 0.28078118339180946, 0.13530723634175956, 0.1854115110472776, 0.13264941255329177, 0.17106060142396018, 0.12684514978900552, 0.07810176612110808, 0.1318832192919217, 0.08481511526042596, 0.18269903550390154, 0.1315859000897035, 0.2642115787602961, 0.24023505829973146, 0.08363107801415026, 0.43266117107123137, 7.121400693431497, 25.884936824440956, 44.91786852478981, 54.41658742725849, 41.342636570334435, 39.60386887192726, 24.442581720650196, 20.406863875687122, 24.84470084309578, 22.01603952795267, 12.714251708239317, 7.335498305037618, 2.8753828955814242, 0.8529810199979693, 0.6321398389991373, 1.7312783002853394, 3.809356391429901, 5.067774765193462, 11.93517666310072, 10.762474089860916, 19.899908378720284, 14.178984761238098, 8.45637783408165, 9.24037741497159, 13.901528399437666, 9.008479658514261, 7.407417045906186, 11.448293589055538, 12.773405984044075, 8.539378680288792, 2.79276582878083, 3.9418286830186844, 5.625048112124205, 13.138027768582106, 24.342339299619198, 32.60325372219086, 44.60902489721775, 52.0188856869936, 53.420307487249374, 61.32401257753372, 58.395160138607025, 62.080346792936325, 62.606424763798714, 57.14521341025829, 51.76825873553753, 47.42022044956684, 45.510169342160225, 51.11962214112282, 62.207164987921715, 62.138624265789986, 59.5588780939579, 60.76983891427517, 61.04629307985306, 54.68976616859436, 56.339242458343506, 58.64787697792053, 54.38960887491703, 53.42817306518555, 44.94429610669613, 32.484502494335175, 21.414509005844593, 15.788434948772192, 5.3101628087460995, 6.09547664411366, 6.705231824889779, 4.052856350317597, 9.431626852601767, 7.528767334297299, 8.92736541107297, 11.451290678232908, 9.446129724383354, 12.34299547970295, 18.06874293833971, 13.315209411084652, 9.170470666140318, 12.0915506221354, 10.934309419244528, 5.336945196613669, 2.693778765387833, 0.5701978190336376, 0.9043344925157726, 5.052513359114528, 7.939198035746813, 13.17704787477851, 21.86056327074766, 27.849364914000034, 25.874200500547886, 31.881056874990463, 41.44142746925354, 28.380403518676758, 13.231879882514477, 2.0290407724678516, 0.1941886986605823, 0.14670680277049541, 0.12222061981447041, 0.2621344558428973, 0.19327397196320817, 0.13539253879571334, 0.1149944392091129, 0.2360138707445003, 0.1691200485220179, 0.10729934001574293, 0.16914716659812257, 0.1923569297650829, 0.24342369579244405, 0.10571912949671969, 0.11128546713734977, 0.1460207169293426, 0.22329161904053763, 0.1858232545782812, 0.12601910973899066, 0.22840623365482315, 0.13026835047639906, 0.11554483076906763, 0.14172945579048246, 0.10010538346250542, 0.06982420716667548, 0.13077829498797655, 0.2349168577347882, 0.15883152169408277, 0.080903863417916, 0.16703688452253118, 0.12996632605791092, 0.14295043714810163, 0.13026107742916793, 0.19106266874587163, 0.09618875847081654, 0.18516799755161628, 0.15925990417599678, 0.15039671648992226, 0.21452476212289184], [0.047748323195264675, 0.02334562628675485, 0.06009572352922987, 0.07215785342850722, 0.017583931257831864, 0.03786579196457751, 0.05175316357053816, 0.02967738349980209, 0.04926513574901037, 0.07443030961439945, 0.10155795942409895, 0.008288773733511334, 0.036126702470937744, 0.042220718241878785, 0.023931926662044134, 0.03765757501241751, 0.09135226369835436, 0.019003425986738876, 0.004770593914145138, 0.05141806905157864, 0.05061778523668181, 0.02427636667562183, 0.061895491016912274, 0.027221798663958907, 0.06714257528074086, 0.05712854290322866, 0.02118500618962571, 0.04049110968480818, 0.021646792738465592, 0.07102949952241033, 0.05844634855748154, 0.008903299840312684, 0.03894654451869428, 0.12530602456536144, 0.04469782536034472, 0.0370027818280505, 0.02567720195656875, 0.01404083475790685, 0.03419087333895732, 0.030851080773572903, 0.06644777662586421, 0.04046903821290471, 0.058392405553604476, 0.0988342848722823, 0.12147494693635963, 0.3679914912208915, 5.434597106650472, 18.501767702400684, 35.685842111706734, 43.88478755950928, 36.229140758514404, 34.74894538521767, 22.905805483460426, 15.679000820964575, 15.804872866719961, 16.75260566174984, 6.522291591390967, 4.6292260475456715, 3.266682573594153, 0.45375300804153085, 0.037363847804954275, 0.6798700278159231, 0.20361691305879503, 0.9371680556796491, 5.160814672708511, 7.804191755130887, 1.8252990301698446, 2.9444164037704468, 7.552145104855299, 5.078326798975468, 6.760780569165945, 6.212371671572328, 6.440346138551831, 4.082307619974017, 5.181041462346911, 4.528794111683965, 1.6524669667705894, 2.0820075552910566, 5.274159265682101, 9.362813495099545, 16.963104866445065, 25.267262868583202, 36.947252824902534, 48.16283740103245, 58.90565514564514, 61.9735649228096, 63.67063745856285, 61.03691138327122, 55.491986721754074, 47.72952005267143, 48.06276597082615, 32.47386686503887, 39.11847151815891, 42.30963908135891, 57.39353388547897, 52.531386986374855, 49.371909722685814, 52.75679849088192, 54.48646567761898, 51.454593166708946, 58.98150287568569, 55.948615819215775, 43.445899710059166, 27.817534022033215, 16.66961431503296, 7.94980944134295, 3.2306840177625418, 1.0997974290512502, 0.957743595354259, 3.997631538659334, 3.4251022478565574, 3.719030488282442, 2.5875186547636986, 5.629077320918441, 7.604502970352769, 8.35573073476553, 5.606163600459695, 7.792654624208808, 7.441916819661856, 5.696816286072135, 1.7730970750562847, 3.7146118003875017, 0.17429976433049887, 0.33658840286079794, 0.2265861164778471, 4.01141719892621, 7.190785920247436, 5.315145766362548, 14.8365537263453, 17.287024185061455, 19.50560923665762, 30.24366393685341, 31.97599858045578, 24.59825936704874, 12.79077960178256, 1.7194612906314433, 0.11835572251584381, 0.03305276019091252, 0.04280709654267412, 0.04307261842768639, 0.0021904115283177816, 0.02636427485413151, 0.08508766899467446, 0.020352364736027084, 0.09903948870487511, 0.05229198875895236, 0.11278059784672223, 0.021995867464283947, 0.027126011518703308, 0.04014760663267225, 0.04930878887535073, 0.04281776491552591, 0.03783313004532829, 0.020659637993958313, 0.036504544696072116, 0.005073955126135843, 0.0660515514027793, 0.07173970516305417, 0.06794640285079367, 0.01992480789340334, 0.028351184155326337, 0.026733029480965342, 0.04296186401916202, 0.02028335613431409, 0.025283956456405576, 0.044172937705297954, 0.10813228946062736, 0.04562282709230203, 0.013245049285615096, 0.04839538691157941, 0.021579917811322957, 0.039791587259969674, 0.023399419005727395, 0.015170813967415597, 0.047399116738233715, 0.03363233670825139, 0.003432947637520556, 0.07583484635688365, 0.01716971080895746, 0.0303763956981129, 0.029523603079724126, 0.04735650261864066, 0.0436655090743443, 0.0433127477299422, 0.026520341089053545, 0.03379226953256875, 0.030248558905441314, 0.03449048206675798, 0.057144933234667405, 0.028502136992756277, 0.07200429565273225, 0.060656961577478796, 0.0405220683751395, 0.021804332136525773, 0.029064447444397956, 0.02145724451111164, 0.0205714671392343, 0.016649125755066052, 0.0426639956276631, 0.02793109702906804, 0.05258656201476697, 0.13777032057987526, 0.07097437279298902, 0.007729918906989042, 0.06250172547879629, 0.03003362366143847, 0.04310128388169687, 0.02162447079172125, 0.01751961674017366, 0.06694686351693235, 0.011313550585327903, 0.05584363294474315, 0.0922161978087388, 0.06236681045265868, 0.02328053622477455, 0.037057641384308226, 0.01278518675462692, 0.05775266312411986, 0.013859683931514155, 0.019439656680333428, 0.07230514005641453, 0.5507943383418024, 7.229246506467462, 22.4600438028574, 42.245141342282295, 45.46318866312504, 41.030088141560555, 32.36037455499172, 16.758510544896126, 16.932776793837547, 20.10346345603466, 20.440011397004128, 12.528094947338104, 6.009110128507018, 2.9538472602143884, 0.3530852176481858, 0.10648455092450604, 0.2953841560520232, 0.7246661803219467, 1.1142979259602726, 3.0606602411717176, 5.895420229062438, 3.047453099861741, 2.212571636773646, 7.085815602913499, 6.069112233817577, 5.595747884362936, 7.2805732022970915, 7.3625267297029495, 6.987771838903427, 6.412804741412401, 6.8337832018733025, 4.461236586794257, 3.933788314461708, 7.382942559197545, 13.236198350787163, 20.71807287633419, 28.359641432762146, 40.4109113663435, 50.56596525013447, 59.097715839743614, 62.71487094461918, 66.98390007019043, 62.58813634514809, 58.84519279003143, 47.76198171079159, 45.7310438901186, 37.53769174218178, 47.07685947418213, 49.039742946624756, 58.95825572311878, 55.190674290061, 52.8144071996212, 56.323583498597145, 56.95607855916023, 55.42740538716316, 61.47216282784939, 58.41632880270481, 46.861000657081604, 31.49757195264101, 17.968582212924957, 11.036943811923265, 5.0434432458132505, 2.175696990452707, 2.461707405745983, 6.737071266397834, 4.2758112866431475, 5.327285164967179, 6.327758654952049, 4.0525485668331385, 9.150521736592054, 15.672867000102997, 8.061409927904606, 6.502611972391605, 6.317495405673981, 3.8925792882218957, 2.9814684530720115, 1.419566182885319, 0.16026423778384924, 0.13700670999241993, 0.664402482798323, 2.8693473944440484, 9.705730844289064, 10.8915807120502, 16.36758752167225, 20.02063550055027, 17.642346918582916, 29.508545882999897, 33.97504851222038, 29.799714758992195, 16.184811629354954, 3.470372543670237, 0.26700718968641013, 0.01967539246834349, 0.027224826626479626, 0.04018250241642818, 0.1345272094476968, 0.04923988046357408, 0.07175134203862399, 0.03274809001595713, 0.04038191749714315, 0.08450241133687086, 0.1289828764856793, 0.024822861960274167, 0.1461410932824947, 0.016596286695857998, 0.018690620017878246, 0.037667241485905834, 0.03462088483502157, 0.03691555350087583, 0.029837006477464456, 0.007364368038906832, 0.0783750248956494, 0.04241554684995208, 0.07787145543261431, 0.012922733621962834, 0.0707008023164235, 0.03501409322780091, 0.058981811816920526, 0.030860010665492155, 0.022056445268390235, 0.0512306433665799, 0.06470397449447773, 0.019385062441870105, 0.048676274964236654, 0.05064853612566367, 0.06152806854515802, 0.02230012945801718, 0.06057439764845185, 0.025795593064685818, 0.043410384678281844, 0.09176498686429113, 0.07751707249553874, 0.251628850819543, 0.1687773544108495, 0.17762688657967374, 0.12009799582301639, 0.20048429287271574, 0.13248603616375476, 0.17531297402456403, 0.11293464543996379, 0.3638826054520905, 0.17268017545575276, 0.19207356293918565, 0.12459875782951713, 0.12213472364237532, 0.1804175548022613, 0.19257854990428314, 0.10112580683198757, 0.11031076748622581, 0.0697909589507617, 0.18170979717979208, 0.34037555276881903, 0.14008075988385826, 0.12298419329454191, 0.14807774248765782, 0.23351011681370437, 0.18903512129327282, 0.1202240570273716, 0.22119300352642313, 0.10257073125103489, 0.1818914304021746, 0.1635099167469889, 0.17734625085722655, 0.11611056252149865, 0.16728447983041406, 0.07211641190224327, 0.15844514477066696, 0.1531622704351321, 0.23923966014990583, 0.09044842430739664, 0.14056662912480533, 0.16611901111900806, 0.23022780544124544, 0.17056604905519634, 0.2140578324906528, 0.19054510979913175, 0.7380661612842232, 8.267105240374804, 27.099634744226933, 50.07202595472336, 53.30215662717819, 49.47125919163227, 45.9196961671114, 31.309867724776268, 25.169686004519463, 25.141744203865528, 24.885594248771667, 11.311359386891127, 6.93195378407836, 4.055907586589456, 0.7988864101935178, 0.34830379765480757, 1.9314789888449013, 1.9389631622470915, 4.010538971051574, 10.955499932169914, 15.474545191973448, 6.810837658122182, 9.494634121656418, 17.505312971770763, 9.559390246868134, 13.968955781310797, 14.558062870055437, 15.294602997601032, 11.197639089077711, 12.665019650012255, 11.044519655406475, 4.892260283231735, 4.172437358647585, 6.198703804984689, 12.82409431412816, 19.566987343132496, 28.855568021535873, 41.076970025897026, 55.53791485726833, 64.65661615133286, 67.5073067843914, 68.82379174232483, 64.81000632047653, 60.987567231059074, 51.941483840346336, 47.36563257873058, 40.7544319331646, 48.942627757787704, 54.69208024442196, 59.93123151361942, 57.13351383805275, 55.52426978945732, 60.148108676075935, 61.82989843189716, 57.66700521111488, 59.566059708595276, 58.62721748650074, 46.28797620534897, 31.406669430434704, 19.587817825376987, 10.21128136664629, 4.852061290293932, 2.0228739408776164, 3.9118036441504955, 9.275739267468452, 7.547088526189327, 10.606305319815874, 6.53779998421669, 12.506043780595064, 16.039952002465725, 22.195648290216923, 12.291852124035358, 16.99324294924736, 16.135970950126648, 16.250825487077236, 6.1526175029575825, 6.906824307516217, 1.1740196775645018, 0.7553974469192326, 0.6865795771591365, 4.239053009077907, 10.928516630083323, 11.083054337650537, 25.96093464642763, 28.91814686357975, 27.92398151010275, 41.16264782845974, 42.52463914453983, 34.962809309363365, 18.19387972354889, 3.3357146568596363, 0.33781683538109064, 0.17458823713241145, 0.15726443234598264, 0.144773626816459, 0.2118118858197704, 0.15877805737545714, 0.15149625280173495, 0.1221974722284358, 0.10962580228806473, 0.19124894781270996, 0.1648388509056531, 0.08902891102479771, 0.32729505153838545, 0.20434031408512965, 0.1576984254643321, 0.08966450113803148, 0.19631913746707141, 0.17802564252633601, 0.16716866026399657, 0.05845309467986226, 0.1323832932393998, 0.12691327894572169, 0.1737215422326699, 0.1088857177819591, 0.163478419999592, 0.1315274485386908, 0.2731320750899613, 0.17267137358430773, 0.11238469916861504, 0.15345610154327005, 0.15596203738823533, 0.13648622698383406, 0.14141472580377012, 0.1430223067291081, 0.14493706257781014, 0.06077810234273784, 0.13253724435344338, 0.10632185731083155, 0.23351719690253958, 0.1346735015977174], [0.05282048325170763, 0.049886061024153605, 0.02258789536426775, 0.028359900679788552, 0.040474006891599856, 0.046747878441237845, 0.03980820023571141, 0.05896144728467334, 0.06744190570316277, 0.0491544036049163, 0.03571944522263948, 0.0542273280734662, 0.04745469988847617, 0.01591686905157985, 0.04139231074077543, 0.011905119281436782, 0.03630929677456152, 0.025025002578331623, 0.017202843991981354, 0.03048192353162449, 0.07506784415454604, 0.07946776313474402, 0.012447131994122174, 0.03999108768766746, 0.04044202032673638, 0.05462435481604189, 0.006556594562425744, 0.02281130222399952, 0.08454672497464344, 0.024927321101131383, 0.04627140850061551, 0.010010829082602868, 0.027782303841377143, 0.013068801272311248, 0.04136381969146896, 0.022717164501955267, 0.08984790809336118, 0.030557292338926345, 0.06117916636867449, 0.014290704748418648, 0.010256064360874007, 0.018452004696882796, 0.031043224662425928, 0.062033441427047364, 0.07597972100484185, 0.037751304553239606, 0.34996380389202386, 4.911126745864749, 17.060826122760773, 31.367799416184425, 37.684994637966156, 31.502298898994923, 33.899056389927864, 32.85988435149193, 29.36566784977913, 21.56590238213539, 22.46543951332569, 17.01483529061079, 8.352195974439383, 3.2927973847836256, 1.2515032198280096, 0.10387374219135381, 0.5404952878598124, 0.11088099665357731, 1.5223479364067316, 4.8971800692379475, 2.6344610983505845, 2.896787147037685, 3.2720951456576586, 3.3221693336963654, 5.075281262397766, 5.290891667827964, 4.156520487740636, 3.5692413384094834, 3.92159809358418, 3.1228966265916824, 2.653690204024315, 2.0451915683224797, 1.8012486957013607, 4.056772040203214, 6.911390237510204, 14.04723348096013, 21.395217441022396, 27.281111106276512, 60.50719700753689, 57.42862120270729, 66.94055959582329, 61.03976882994175, 53.44191312789917, 57.45316028594971, 42.84389041364193, 28.241338580846786, 45.050394013524055, 41.246843710541725, 58.14257629215717, 56.926899924874306, 48.89123551547527, 47.84074008464813, 46.28747843205929, 46.50765001773834, 49.97291587293148, 42.74018257856369, 33.37898589670658, 12.083385810256004, 6.687401756644249, 1.5073432540521026, 1.7833641241304576, 1.532561075873673, 2.0506908232346177, 4.978108126670122, 3.948395918123424, 4.237240981310606, 6.356185879558325, 1.5996017097495496, 8.768633678555489, 17.513917610049248, 3.292725901119411, 4.302898608148098, 3.317191363312304, 2.799597387202084, 2.7516145119443536, 1.2675874005071819, 0.45636242895852774, 0.5758052493911237, 2.0137423183768988, 11.837665345519781, 5.634652571752667, 18.81147388368845, 17.30645254254341, 15.334146525710821, 24.341336153447628, 32.161759212613106, 29.93342388421297, 16.09465766698122, 3.499076678417623, 0.12887698685517535, 0.017180952490889467, 0.13906413631048054, 0.03501867227896582, 0.0035256233286418137, 0.03863481651933398, 0.10663108798325993, 0.024852991300576832, 0.1667782015283592, 0.02713649249926675, 0.06793731896323152, 0.022958831905270927, 0.044220116033102386, 0.05680563444911968, 0.003184256038366584, 0.0974918065185193, 0.03757218350074254, 0.0496886015025666, 0.04912849151878618, 0.04485638521146029, 0.029701364146603737, 0.03996270053903572, 0.09608331412891857, 0.04801679511729162, 0.031238342708093114, 0.012299651480134344, 0.04043159686261788, 0.04291613287932705, 0.032789750475785695, 0.01248144611963653, 0.08090353687293828, 0.044129570305813104, 0.04074464588484261, 0.025281110320065636, 0.06613427118281834, 0.02200849510700209, 0.08145064814016223, 0.005462058470584452, 0.012361201497697039, 0.05675719818100333, 0.06427921369322576, 0.029941285647510085, 0.013063688802503748, 0.05919804396398831, 0.05412905658886302, 0.08698050922248513, 0.06736820301739499, 0.042731846479000524, 0.038071912349550985, 0.06946851062821224, 0.09571463742759079, 0.055885894544189796, 0.02125670693203574, 0.028107789403293282, 0.027028613912989385, 0.04096895259863231, 0.030098121860646643, 0.015159675258473726, 0.02336100544198416, 0.021765579040220473, 0.061713646282441914, 0.08707367844181135, 0.04643792417482473, 0.029236467998998705, 0.06392986993887462, 0.05930940322286915, 0.03041758118342841, 0.025283462928200606, 0.018381634254183155, 0.053760287119075656, 0.08744392849621363, 0.013786290164716775, 0.048096961909323, 0.0712143314012792, 0.009168969227175694, 0.0099639466861845, 0.04400942401844077, 0.039621516698389314, 0.057396387710468844, 0.014342292361106956, 0.027382332627894357, 0.023283940827241167, 0.043972068015136756, 0.0899127718003001, 0.06150500259536784, 0.058849401539191604, 0.03703580739966128, 0.7140106020960957, 7.690001707524061, 22.710210978984833, 38.00967201590538, 41.46373987197876, 37.29540914297104, 34.68167379498482, 27.902256175875664, 22.585530169308186, 22.058901228010654, 15.008456502109766, 18.121594302356243, 12.715676631778479, 3.930286089889705, 0.7911931886337698, 0.2590749372029677, 0.012399569604895078, 0.3798014356289059, 0.7683236408047378, 3.8429430266842246, 2.0793438982218504, 1.9592385180294514, 4.2988052777945995, 3.746794410981238, 5.4437170922756195, 6.902449792250991, 7.292484613135457, 6.895492365583777, 5.752908876165748, 5.126440767198801, 6.359033826738596, 3.933271304704249, 4.152385359629989, 4.555886657908559, 9.33072991669178, 16.83398399502039, 24.516326263546944, 35.07531367242336, 60.83499401807785, 58.01867634057999, 65.81472560763359, 63.26782867312431, 55.703255385160446, 56.41729027032852, 42.35493645071983, 33.4968251734972, 48.77670966088772, 45.513049587607384, 60.87011933326721, 59.190301671624184, 54.7192107886076, 54.49503041803837, 52.78974272310734, 47.51497596502304, 50.794861167669296, 48.7760066986084, 33.11201222240925, 16.91977199167013, 10.617629662156105, 2.7019939245656133, 2.917811181396246, 2.264498700387776, 3.721280205063522, 6.573270605877042, 5.516868866980076, 5.225752238184214, 7.508979421108961, 4.896632898598909, 8.277802616357803, 12.958627045154572, 8.466254454106092, 5.627321340143681, 3.1338595133274794, 1.4106537611223757, 1.22183654922992, 0.2865160256624222, 0.33666659554000944, 0.860046740854159, 2.178323124535382, 11.661351006478071, 11.091210599988699, 13.672262001782656, 15.3264538384974, 14.413453079760075, 25.738418586552143, 37.31325678527355, 36.395389437675476, 18.760585114359856, 5.157655142247677, 0.20312420121626928, 0.07870502828154713, 0.059022273708251305, 0.006659982227574801, 0.02564646776590962, 0.032536481448914856, 0.037619640133925714, 0.014693999855808215, 0.09534898126730695, 0.03672870298032649, 0.0642530455661472, 0.02123180231137667, 0.060785282621509396, 0.024863001017365605, 0.014261350024753483, 0.07722568305325694, 0.02252330625196919, 0.06776873269700445, 0.016890850674826652, 0.03819982892309781, 0.012356855295365676, 0.05492289114044979, 0.03837282725726254, 0.024823865715006832, 0.0155955469381297, 0.013876135490136221, 0.030238779254432302, 0.01368498886222369, 0.026216233090963215, 0.04608492163242772, 0.050521484154160134, 0.06463427198468708, 0.027222702228755224, 0.035389627373660915, 0.055757525260560215, 0.03529131136019714, 0.023515390712418593, 0.018740160230663605, 0.022470533986052033, 0.03532602531777229, 0.022639539565716404, 0.1942859051632695, 0.08841245347866789, 0.08339385050931014, 0.07726571449893527, 0.2379444194957614, 0.22720646287780255, 0.17633598006796092, 0.15191283513559029, 0.12119335384340957, 0.1827665264136158, 0.10736495329183526, 0.20236298034433275, 0.09975633656722493, 0.1036498362373095, 0.18001569667831063, 0.14782171638216823, 0.10776819181046449, 0.10133485498954542, 0.13308732421137393, 0.18257184623507783, 0.2528918377356604, 0.21381048951297998, 0.08960708117228933, 0.1830801580217667, 0.11195198254426941, 0.1174513265141286, 0.11241849657380953, 0.07686813856707886, 0.21349449787521735, 0.16166746092494577, 0.16770811256719753, 0.10254926834022626, 0.1963753774180077, 0.1858364648069255, 0.18389773758826777, 0.12324337352765724, 0.2555141720222309, 0.1748488051816821, 0.1798800766118802, 0.14357323263539, 0.1561813271837309, 0.112997497926699, 0.14293626212747768, 0.15434200322488323, 0.21126983599970117, 0.12928965064929798, 0.7652740075718611, 9.017526973038912, 27.160864658653736, 45.054835975170135, 50.52368491888046, 43.71132306754589, 45.5244679749012, 43.777785301208496, 42.507920041680336, 32.59234830737114, 28.866767920553684, 22.81431019306183, 10.808963645249605, 4.206875860691071, 1.5734852361492813, 0.281324049574323, 0.8977650012820959, 1.5277555212378502, 3.5312155913561583, 9.34071958065033, 8.066664095968008, 7.464300943538547, 10.72208795696497, 7.989855017513037, 12.746884357184172, 12.230372373014688, 12.029964476823807, 10.64878324046731, 10.753895100206137, 8.885262720286846, 7.272726148366928, 5.969969853758812, 4.670969182625413, 5.067061353474855, 9.001797717064619, 17.342206723988056, 24.263237044215202, 36.83360852301121, 67.62105748057365, 61.58300668001175, 70.10265871882439, 69.15658548474312, 62.03599937260151, 59.1541314125061, 47.91235864162445, 39.860115721821785, 53.8755838572979, 52.1100389957428, 63.40837173163891, 60.29900997877121, 59.38221037387848, 59.84563730657101, 59.418874606490135, 56.202381402254105, 57.996105551719666, 50.126028656959534, 40.115743204951286, 15.37887867540121, 10.051474291831255, 3.2302954886108637, 4.469062266871333, 4.1391554195433855, 5.666046487167478, 9.512546360492706, 11.05901112779975, 11.519412472844124, 16.605728343129158, 6.65652746334672, 19.267783798277378, 31.009039767086506, 11.30727555602789, 10.691083520650864, 9.369504936039448, 7.333065485581756, 5.278819240629673, 2.3802371649071574, 0.7756032783072442, 0.9841787768527865, 2.9054274084046483, 14.870461206883192, 12.233785539865494, 28.207719884812832, 27.325226739048958, 23.58736351132393, 33.93063269555569, 43.18895749747753, 40.602873265743256, 24.048388972878456, 6.15885391831398, 0.25447558087762445, 0.13075714377919212, 0.20618550101062283, 0.12778340256772935, 0.11285511689493433, 0.08786793230683543, 0.15014892822364345, 0.0939229445066303, 0.23210912011563778, 0.19307664973894134, 0.29632899910211563, 0.06986496591707692, 0.1480483534396626, 0.18897849542554468, 0.15943092468660325, 0.2029996391502209, 0.16645508527290076, 0.16771485126810148, 0.13299065205501392, 0.23659063823288307, 0.0974274029431399, 0.1594777245190926, 0.23150716413510963, 0.13313733012182638, 0.11085361140430905, 0.09205065434798598, 0.09844450149103068, 0.18519517499953508, 0.1522988112992607, 0.13860222359653562, 0.18525867315474898, 0.14208595384843647, 0.14281456475146115, 0.15423804317833856, 0.24458254454657435, 0.12467999331420287, 0.1679266305291094, 0.05281792655296158, 0.14597421395592391, 0.13003938307520002, 0.10308331038686447], [0.06820795053499751, 0.02508623532776255, 0.06059398663637694, 0.09560921535012312, 0.03730930737219751, 0.016357600870833267, 0.032016777695389464, 0.047376510920003057, 0.0587621138402028, 0.055575613732798956, 0.01437452012396534, 0.023799865193723235, 0.026552726558293216, 0.005571015954046743, 0.00837694180518156, 0.03147633462504018, 0.02618499238451477, 0.0707297089684289, 0.09469090407947078, 0.08775413138209842, 0.0828823920164723, 0.0623327904031612, 0.04805038101039827, 0.09097475543967448, 0.01702797173493309, 0.06281683396082371, 0.013886351152905263, 0.051707217207876965, 0.01807333126635058, 0.016185554341063835, 0.026863521306950133, 0.0235083737061359, 0.02801162005198421, 0.044018645203323103, 0.10915585211478174, 0.016844253077579197, 0.056341146482736804, 0.01497313551226398, 0.024890050444810186, 0.025909150936058722, 0.033943007147172466, 0.06928587550646625, 0.08537933303159662, 0.02342515112104593, 0.009336771599919302, 0.040419403376290575, 0.03501723251247313, 0.6960193393751979, 5.760691808536649, 20.404870882630348, 40.246205404400826, 37.82886631786823, 31.178381480276585, 29.498031847178936, 36.09625808894634, 39.34211231768131, 27.656992636621, 10.063922423869371, 10.574862007051706, 9.933101143687963, 4.062687372788787, 1.5237823594361544, 0.3534919739468023, 0.16656134597724304, 0.6318914273288101, 3.5871934751048684, 1.2337559158913791, 0.40934105054475367, 3.919739043340087, 5.058066761121154, 3.451511305756867, 4.260020283982158, 5.25571315549314, 6.751009868457913, 3.7120540626347065, 5.572979981079698, 6.188914105296135, 3.038653484545648, 3.1895502749830484, 1.4907105965539813, 2.679419810883701, 3.473296486772597, 7.2338637337088585, 11.758899372071028, 37.384776547551155, 60.38619630038738, 65.85951000452042, 61.700070798397064, 63.18207487463951, 41.24618634581566, 36.93767733871937, 38.98775853216648, 53.78886491060257, 46.23476006090641, 55.761035084724426, 52.01985463500023, 40.00067017972469, 36.91010221838951, 35.98169043660164, 49.5209339261055, 49.74515609443188, 37.09607943892479, 16.535804495215416, 8.660002257674932, 1.752353038173169, 0.9782737155910581, 1.680175436194986, 1.2860116618685424, 3.314757118932903, 8.146395217627287, 5.144314533099532, 3.0718145426362753, 7.458522878587246, 3.6979948170483112, 3.9133344870060682, 7.28118259459734, 9.972884058952332, 4.891484649851918, 2.879386693239212, 1.2263507070019841, 1.6738427197560668, 0.2765087579609826, 1.3587582833133638, 1.6317622340284288, 14.460244718939066, 11.53559010475874, 8.093533404171467, 23.259752690792084, 26.28974810242653, 29.01846718043089, 30.478707924485207, 31.843317300081253, 20.338862724602222, 5.585257122293115, 0.4044992494164035, 0.033780313533497974, 0.05917948285059538, 0.08090374467428774, 0.018473623458703514, 0.043226328343735076, 0.09433868821361102, 0.06354092518449761, 0.01904043874674244, 0.0723472866229713, 0.01739837578497827, 0.026772508026624564, 0.04111293295864016, 0.0704950641375035, 0.03242292543291114, 0.02302045984833967, 0.05779407496447675, 0.04906847403617576, 0.02862528526748065, 0.018626116252562497, 0.06009217235259712, 0.07103299503796734, 0.008608297994214809, 0.0742922627250664, 0.06471503991633654, 0.027614240789262112, 0.04480182622501161, 0.019395539711695164, 0.07451730416505598, 0.05413443715951871, 0.07719583387370221, 0.029654887148353737, 0.03747055379790254, 0.017169682978419587, 0.0914800021564588, 0.027998222431051545, 0.0315004766889615, 0.057211459352402017, 0.025648582886788063, 0.03591837790736463, 0.013639285552926594, 0.031501011035288684, 0.04127693646296393, 0.022186738569871522, 0.06479237912571989, 0.013941984398115892, 0.05608890533039812, 0.04754381698148791, 0.014713830041728215, 0.028115090281062294, 0.03431011049542576, 0.038923274478293024, 0.05326964215782937, 0.031072517231223173, 0.04281074048776645, 0.009300363690272206, 0.03122355541563593, 0.03937566543754656, 0.05459016407257877, 0.03595008245611098, 0.0471975865366403, 0.035266664635855705, 0.03659578433143906, 0.04912130752927624, 0.03131341094558593, 0.03273637150414288, 0.026942220501950942, 0.05621438023808878, 0.0467569623288, 0.059382590116001666, 0.023656437733734492, 0.022917828246136196, 0.013606455722765531, 0.032448199272039346, 0.038137852170621045, 0.013759660050709499, 0.05094646017823834, 0.06187113373016473, 0.054588650091318414, 0.04063166132254992, 0.036927457549609244, 0.008428738146903925, 0.020757187739945948, 0.019966581530752592, 0.004353685035312083, 0.030642108686151914, 0.023871521407272667, 0.06824728436185978, 0.037021765965619124, 0.8573527447879314, 7.797217229381204, 24.08741857856512, 44.30080443620682, 40.07899917662144, 35.13041451573372, 33.232465758919716, 37.8902368247509, 39.25356566905975, 34.479186460375786, 20.22475104779005, 15.839891787618399, 12.187610417604446, 4.572288952767849, 1.408533831126988, 0.39230932539794594, 0.22909901366801932, 0.2127300263964571, 1.6120623098686337, 1.1331406398676336, 0.49151677696499974, 2.4943191558122635, 2.8242820501327515, 3.8904974749311805, 5.7172762881964445, 4.441851451992989, 9.236543420702219, 6.8347355257719755, 7.663962179794908, 8.74500559642911, 5.029867524281144, 5.746657261624932, 2.0814798586070538, 3.7251184741035104, 5.131277907639742, 10.716804340481758, 14.550124146044254, 44.43131983280182, 65.17053097486496, 68.24965015053749, 62.01092071831226, 64.17836621403694, 47.076126113533974, 37.921034172177315, 42.83185265958309, 56.67098365724087, 51.86220109462738, 58.467295467853546, 57.590705305337906, 49.42329056560993, 47.543345242738724, 42.61773034930229, 59.40605789422989, 52.994840517640114, 42.50022545456886, 21.446849070489407, 10.791581477969885, 3.165540788322687, 2.1900440705940127, 3.106783591210842, 2.4437034968286753, 3.8539828592911363, 9.377866387367249, 6.497834678739309, 6.1536396481096745, 6.906557371839881, 4.95661030523479, 5.369064873084426, 8.18400464951992, 5.20627305842936, 2.2571154590696096, 2.4286449048668146, 0.32924170489422977, 0.3952632809523493, 0.3565066965529695, 1.4804904512129724, 1.8878693226724863, 12.142004314810038, 16.681361384689808, 11.649568788707256, 17.782337106764317, 20.75408924371004, 24.811777509748936, 33.003326654434204, 36.22786782681942, 22.97263629734516, 6.7129207123070955, 0.5880890402477235, 0.05503260654222686, 0.07595480710733682, 0.04914622142678127, 0.020438409337657504, 0.15559508989099413, 0.008936497033573687, 0.015265086203726241, 0.022288034306257032, 0.01580846539582126, 0.021674845920642838, 0.01845194161433028, 0.053061744329170324, 0.021179983705224004, 0.10386381967691705, 0.040221505987574346, 0.026776825470733456, 0.044654829034698196, 0.051910992406192236, 0.029883915776736103, 0.02597142640297534, 0.04108954417461064, 0.04416588730236981, 0.04377299432235304, 0.00411148050261545, 0.039922023424878716, 0.023114426876418293, 0.011286520639259834, 0.02300647222000407, 0.007016154668235686, 0.09720036512590013, 0.0194639861365431, 0.06856953972601332, 0.031894642452243716, 0.04221889626933262, 0.024073409695120063, 0.0888409472827334, 0.006387863577401731, 0.06419072742573917, 0.08815546258119866, 0.03662153314508032, 0.07884409933467396, 0.16781187965534627, 0.15377728821476921, 0.14552502165315673, 0.13376652292208746, 0.18178233469370753, 0.06704024795908481, 0.12197776683024131, 0.19072893977863714, 0.24131161771947518, 0.22016943345079198, 0.15352184098446742, 0.1548896636813879, 0.09145280986558646, 0.21759523486252874, 0.14474281284492463, 0.10611758116283454, 0.17120439995778725, 0.1723486729315482, 0.2372269704937935, 0.1672192450496368, 0.11812954558990896, 0.13170008693123236, 0.11165649644681253, 0.18252127629239112, 0.13830549811245874, 0.19891945965355262, 0.1544680941151455, 0.12100226565962657, 0.16525912913493812, 0.20204686996294186, 0.1138463219103869, 0.16382811998482794, 0.19741166790481657, 0.07960183953400701, 0.16037140390835702, 0.09260041508241557, 0.16903813026146963, 0.14871863153530285, 0.12918716005515307, 0.0959844229510054, 0.11056484174332581, 0.24014941445784643, 0.19353011681232601, 0.10525187331950292, 0.11833336160634644, 0.1214498771878425, 0.11844359280075878, 0.990324531449005, 8.787053190171719, 28.271261975169182, 49.872411265969276, 48.756091967225075, 41.055333986878395, 40.72170428931713, 46.01824767887592, 50.517529249191284, 35.52029639482498, 19.066915176808834, 15.810441467911005, 14.00690434500575, 5.917903622612357, 2.5970352441072464, 0.5433201987762004, 0.5872159777209163, 1.6051988094113767, 6.530296336859465, 5.052417414262891, 3.1177908880636096, 7.643742989748716, 10.955831464380026, 7.950640646740794, 11.799610387533903, 14.889506734907627, 17.409014739096165, 14.085926804691553, 11.921971421688795, 13.20640604943037, 7.791186003014445, 6.9121140986680984, 2.9045593924820423, 3.922681985422969, 4.311657138168812, 10.099317524582148, 16.52187254279852, 47.45906576514244, 70.99347531795502, 72.46645867824554, 62.76417709887028, 67.47845873236656, 47.32510395348072, 45.93411259353161, 47.264079228043556, 58.671830892562866, 59.201587066054344, 63.700800240039825, 60.59215284883976, 57.732247710227966, 53.076289147138596, 47.005886882543564, 54.17600333690643, 56.06108978390694, 47.31562726199627, 26.338700875639915, 10.543771125376225, 3.1909459875896573, 2.388811642304063, 5.100390315055847, 5.364620061591268, 7.591400323435664, 16.862296275794506, 12.262118719518185, 7.554170871153474, 14.53363113105297, 9.76957406848669, 12.401696629822254, 16.35033454746008, 16.59218207001686, 10.729203075170517, 5.461608907207847, 2.8756533935666084, 2.83920266199857, 0.5797362572047859, 1.8939896067604423, 2.748549501411617, 17.251306101679802, 18.786421827971935, 17.180538699030876, 32.74476572871208, 37.877180725336075, 37.356281876564026, 40.67388765513897, 43.069636300206184, 26.799665540456772, 7.0324925892055035, 0.7519126182887703, 0.13668194616911933, 0.10669657509424724, 0.13330063229659572, 0.06008734468196053, 0.1783090241951868, 0.1911406239378266, 0.13719579437747598, 0.11286198918242007, 0.13586973975179717, 0.13385188474785537, 0.20449129660846666, 0.10707776440540329, 0.13685614307178184, 0.2241804447839968, 0.10826132667716593, 0.20331021310994402, 0.20656317996326834, 0.0932969874702394, 0.128805176645983, 0.10977378653478809, 0.2316871052607894, 0.15767289558425546, 0.17442423733882606, 0.158282465999946, 0.10860635113203898, 0.16057840373832732, 0.08723845749045722, 0.2065246773418039, 0.14335646614199504, 0.15846329770283774, 0.08937163482187316, 0.1410361859598197, 0.10052942438051105, 0.14747338194865733, 0.10890473902691156, 0.14596521912608296, 0.13753516366705298, 0.154137066565454, 0.14165255444822833, 0.09026124724186957, 0.09798805098398589], [0.07360605814028531, 0.046833051019348204, 0.04429233813425526, 0.011342463731125463, 0.06801085837651044, 0.05754403427999932, 0.010400052142358618, 0.01984816073672846, 0.08361348169273697, 0.05682144961610902, 0.04991208443243522, 0.05935756860708352, 0.013483981874742312, 0.015641073987353593, 0.08522177507984452, 0.09184703871142119, 0.06526662633405067, 0.02488015205017291, 0.024537793760828208, 0.03805903237662278, 0.038788953170296736, 0.047852728530415334, 0.020979856162739452, 0.007441919224220328, 0.04498330359638203, 0.03027816132089356, 0.04457029470358975, 0.059499745548237115, 0.02688775428396184, 0.09638250354328193, 0.044958578946534544, 0.05889567815756891, 0.07988304671016522, 0.07212090189568698, 0.02756679899903247, 0.03918559399608057, 0.049076882569352165, 0.06785166769986972, 0.02942653572972631, 0.026776595404953696, 0.07465279806638137, 0.08854308631271124, 0.005457780453070882, 0.04492208012379706, 0.03835483759758063, 0.023548232602479402, 0.04636595069314353, 0.050017343237414025, 0.3698917751898989, 5.151925049722195, 18.803040236234665, 32.52022437751293, 41.65751427412033, 30.549169443547726, 23.392608761787415, 23.75409286469221, 11.018979325890541, 21.62738688290119, 22.190290577709675, 21.724990345537663, 12.114382646977901, 7.577338228002191, 1.7791951540857553, 0.6022135948296636, 0.26786831847857684, 1.5098500507883728, 0.5554014130029827, 0.5426978040486574, 1.8230769806541502, 1.4671796467155218, 3.1302703684195876, 3.5538509767502546, 3.2378746569156647, 5.712179336696863, 4.367324626073241, 5.626397039741278, 7.222423497587442, 4.688734654337168, 3.843179326504469, 1.0727105825208127, 1.0374996531754732, 1.0596708697266877, 2.266920357942581, 3.8195096841081977, 6.606334056705236, 17.74481602013111, 42.37339586019516, 41.15765109658241, 36.9726924598217, 28.8290948420763, 33.845042288303375, 46.75361841917038, 50.27440309524536, 44.23294387757778, 39.768601432442665, 41.741151586174965, 39.37692604959011, 46.68002016842365, 36.53603509068489, 35.28254695236683, 25.555963777005672, 45.206394642591476, 4.28705345839262, 8.642754033207893, 5.382085824385285, 0.869399820221588, 2.6100984681397676, 2.3480369802564383, 3.8156220177188516, 7.648030584678054, 3.8431819388642907, 4.684248995035887, 2.534004463814199, 4.607965238392353, 3.1652729026973248, 7.208725707605481, 5.660367691889405, 1.784955644980073, 1.1251525185070932, 0.6016102584544569, 0.25682815932668746, 1.2194480211474001, 3.4655905002728105, 16.125757098197937, 19.50097158551216, 6.2707042414695024, 14.879868552088737, 18.102139346301556, 26.905022487044334, 31.016527265310287, 35.056888461112976, 20.907545909285545, 7.886358071118593, 0.7043994928244501, 0.06372346382704563, 0.010631313707563095, 0.08075971607468091, 0.02149817766621709, 0.03365782577020582, 0.06999444842222147, 0.03451987482549157, 0.06387163361068815, 0.03458643433987163, 0.06397016855771653, 0.03560663135431241, 0.02543967388191959, 0.03270966903073713, 0.024911993896239437, 0.013179795951145934, 0.08084548608167097, 0.012642070996662369, 0.05698705244867597, 0.02943942312413128, 0.016381516579713207, 0.033368035656167194, 0.050117295686504804, 0.007133025301300222, 0.02731460794166196, 0.03427959338296205, 0.018271160006406717, 0.03499770289636217, 0.013794312781101326, 0.04549926692561712, 0.11568563844775781, 0.023699910889263265, 0.03496885190543253, 0.034278305756743066, 0.03598944596888032, 0.022834527735540178, 0.06536657136166468, 0.019906313573301304, 0.11315929354168475, 0.03112659938778961, 0.04604068220942281, 0.04214615095406771, 0.04184820092632435, 0.042123381863348186, 0.03186203619407024, 0.0408069714467274, 0.07592403024318628, 0.06559515284607187, 0.09512483040452935, 0.02363115461776033, 0.04533560851996299, 0.047834735159995034, 0.032357482850784436, 0.06847881959402002, 0.017293881392106414, 0.032808582473080605, 0.02215576132584829, 0.038368997775251046, 0.05607279330433812, 0.11107317579444498, 0.06474039168097079, 0.04623929205990862, 0.011244220077060163, 0.03786399967793841, 0.0431063898577122, 0.008883348127710633, 0.028482282687036786, 0.05923085431277286, 0.02562802725151414, 0.09002165970741771, 0.012161950617155526, 0.04447309562237933, 0.04905055488052312, 0.014729099730175221, 0.023326321170316078, 0.04070304479682818, 0.07489058960345574, 0.01570188185723964, 0.013487602627719752, 0.08641436186735518, 0.020714325000881217, 0.05538051795156207, 0.06888112300657667, 0.058384783696965314, 0.040066857254714705, 0.02701297871681163, 0.04351463787315879, 0.011432121664256556, 0.05510210867214482, 0.011846546203742037, 0.05144750633917283, 0.7831662381067872, 7.648574430495501, 23.980154134333134, 38.432441130280495, 45.1589921861887, 32.61590324342251, 28.05690597742796, 28.072775825858116, 15.348650347441435, 19.074349477887154, 20.622084327042103, 25.619431771337986, 16.633571349084377, 8.090371023863554, 2.081208173185587, 0.5571965198032558, 0.11045305203879252, 0.5307447141967714, 0.3146228799596429, 0.2590930159203708, 0.8180813177023083, 1.4030001405626535, 2.193611841648817, 3.6535056168213487, 2.8984756814315915, 10.660750698298216, 5.865047983825207, 8.319567125290632, 6.37626732699573, 8.020153641700745, 7.753642117604613, 3.5145836463198066, 2.96083627268672, 1.6986010037362576, 2.472492177039385, 5.776137979701161, 13.483861461281776, 30.396334044635296, 48.98074731230736, 51.544116362929344, 47.25373238325119, 34.59707133471966, 36.22038222849369, 50.120002180337906, 53.89471583068371, 49.665877148509026, 48.29218626022339, 45.901609137654305, 46.323173716664314, 50.29684469103813, 42.755647748708725, 39.69825200736523, 33.70593175292015, 54.27481323480606, 9.604931753128767, 10.811246372759342, 4.469892997294664, 2.134824958629906, 4.598268633708358, 3.9744627568870783, 5.791587000712752, 8.336186483502388, 5.45001620426774, 7.017080141231418, 5.9960787277668715, 4.692476028576493, 5.135289067402482, 2.696850188076496, 3.3100337348878384, 1.4320955355651677, 0.3036891744704917, 0.40357367251999676, 0.3677862725453451, 1.1866327445022762, 4.930992554873228, 14.210396725684404, 22.823268212378025, 13.828306328505278, 13.565345238894224, 22.192025184631348, 28.539052605628967, 34.774746000766754, 38.87999631464481, 24.96971793472767, 8.949941899627447, 1.065090922638774, 0.060544451989699155, 0.021853705366083886, 0.05189596020500176, 0.0313019967143191, 0.03270248504122719, 0.06954094424145296, 0.034344048908678815, 0.11141883107484318, 0.052421500950003974, 0.05695472449588124, 0.027037324871344026, 0.04105744628759567, 0.04152152978349477, 0.022367702003975864, 0.02805126743623987, 0.06813627391238697, 0.008482087432639673, 0.011737160129996482, 0.041729772710823454, 0.02015793688769918, 0.04408599139424041, 0.046655878104502335, 0.01426020433427766, 0.029400215462374035, 0.028293882933212444, 0.10111031820997596, 0.027760675802710466, 0.0315957758721197, 0.01723077286442276, 0.036957707488909364, 0.03895563953847159, 0.05938655689533334, 0.02995652936078841, 0.03898056827893015, 0.03294269597972743, 0.061637045509996824, 0.018673276026675012, 0.07711771540925838, 0.060344992380123585, 0.015565013127343263, 0.02190548686485272, 0.054519841869478114, 0.10828871192643419, 0.2125357766635716, 0.1702169724740088, 0.13917982229031622, 0.1923753201845102, 0.13971724110888317, 0.09776426377356984, 0.10800276242662221, 0.18580294941784814, 0.18423036817694083, 0.2024792303564027, 0.11111385290860198, 0.10997380275512114, 0.14993334916653112, 0.18355787848122418, 0.14802659366978332, 0.22268794127739966, 0.22889315674547106, 0.1600091319414787, 0.13014552503591403, 0.18153698067180812, 0.17078894568840042, 0.17931447102455422, 0.13371972308959812, 0.1177733443910256, 0.12057783140335232, 0.12682482978561893, 0.13657685805810615, 0.17885533394291997, 0.2177360499626957, 0.13191428559366614, 0.1262523073819466, 0.14760377729544416, 0.21250052464893088, 0.18244516162667423, 0.23934863711474463, 0.12819029245292768, 0.12435350770829245, 0.19379699311684817, 0.1788960926933214, 0.2224020511494018, 0.1729393779532984, 0.06073096483305562, 0.16657828178722411, 0.09763398717041127, 0.13887738226912916, 0.19560137676307932, 0.16096443927381188, 0.722677877638489, 7.896867832168937, 25.804671831429005, 45.08054919540882, 53.34937669336796, 40.17833724617958, 31.78291194140911, 31.432867124676704, 19.508392587304115, 31.46715458482504, 29.649771004915237, 30.193120948970318, 16.61036979407072, 9.00571720674634, 2.9864566354081035, 1.1014938005246222, 0.4880954761756584, 2.6151203736662865, 1.904655396938324, 2.274750550277531, 5.622466150671244, 5.491135697811842, 8.29209079965949, 11.196335759013891, 9.447448253631592, 15.772649645805359, 12.299609407782555, 12.888231072574854, 15.282156765460968, 14.086659215390682, 11.505915597081184, 4.720150418579578, 2.6427536783739924, 1.5553457220084965, 2.5565876020118594, 5.823544235900044, 11.148224640637636, 26.749812215566635, 52.81671367585659, 60.00818118453026, 51.62110783159733, 39.333205595612526, 42.545777410268784, 57.557373493909836, 58.63634079694748, 53.89741748571396, 52.05974109470844, 51.60468891263008, 49.62445177137852, 55.39969727396965, 46.090272814035416, 44.4079814851284, 37.31443092226982, 66.41966074705124, 15.175281800329685, 12.89663527160883, 7.324936296790838, 2.6004581479355693, 7.431623646989465, 7.903586346656084, 9.848488233983517, 13.918476440012455, 10.882937125861645, 12.798090409487486, 10.30321553349495, 12.351866103708744, 10.781126338988543, 13.536013662815094, 12.129754722118378, 5.584104834124446, 3.3398868329823017, 1.181709871161729, 0.48142959480173886, 1.521307029761374, 6.0991396475583315, 19.191373698413372, 25.71695163846016, 13.537141252309084, 22.85196617245674, 29.858881384134293, 38.4552551060915, 42.20110550522804, 45.10408133268356, 28.944620043039322, 10.002147238701582, 1.28003541380167, 0.21955336182145402, 0.18429649353493005, 0.2217160098371096, 0.07056887072394602, 0.10025199473602697, 0.21325631299987435, 0.14160997001454234, 0.2623524097725749, 0.13167461642296985, 0.13399811752606183, 0.13727484794799238, 0.11003658844856545, 0.2188089580158703, 0.13357390591409057, 0.11120247276267037, 0.1804912945954129, 0.09953502070857212, 0.13449762744130567, 0.15566838439553976, 0.14141338993795216, 0.130707063653972, 0.15787291922606528, 0.1362191280350089, 0.1795231332653202, 0.1487573716440238, 0.18411667115287855, 0.15410445659654215, 0.14591730607207865, 0.13824997062329203, 0.2656424988526851, 0.2303446491714567, 0.12811198103008792, 0.13515107362763956, 0.13788195443339646, 0.21099712641444057, 0.12069814838469028, 0.15683127043303102, 0.2266417775535956, 0.10703336170990951, 0.10630011980538256, 0.19993963069282472, 0.11259732447797433], [0.09836154422373511, 0.030113308057480026, 0.030242740467656404, 0.014884489683026914, 0.02913237622124143, 0.0357509790774202, 0.05411716367234476, 0.06955856282729656, 0.04440295153472107, 0.05100773931189906, 0.011973723412666004, 0.014959498548705596, 0.03125905233900994, 0.07607928753714077, 0.040644303808221593, 0.052940651803510264, 0.02115476552717155, 0.07234310833155178, 0.0325614139001118, 0.015215122966765193, 0.015701620250183623, 0.03627299091021996, 0.024349679733859375, 0.014630242876592092, 0.08054754347540438, 0.012193689490231918, 0.026895565388258547, 0.03551934736606199, 0.025975877433666028, 0.058861958677880466, 0.007717182725173188, 0.010722031984187197, 0.057541889473213814, 0.04216641900711693, 0.06280730478465557, 0.06546495787915774, 0.017756241250026505, 0.01720142648991896, 0.09156393163721077, 0.10134023556020111, 0.020632714731618762, 0.045627754952874966, 0.021810924263263587, 0.048073936777655035, 0.03442955174250528, 0.04588127259921748, 0.08723346283659339, 0.05691448524885345, 0.09812472490011714, 0.34171886974945664, 3.8620348647236824, 18.325428664684296, 30.82523413002491, 42.74123132228851, 36.46361857652664, 27.06530548632145, 28.63252379000187, 22.066447623074055, 15.771067030727863, 18.942865133285522, 18.198942951858044, 11.771886125206947, 7.653090013191104, 3.073412119410932, 0.9357590437866747, 0.6805228209123015, 0.11542026870301925, 0.37007066246587783, 0.1675720768980682, 0.5765600432641804, 0.44695763674099, 2.577779064886272, 1.0299743944779038, 9.524822551757097, 4.902364416047931, 7.574109826236963, 5.263448115438223, 5.53291255608201, 7.101778071373701, 1.048805471509695, 1.6775075043551624, 0.4249184631044045, 0.34605500113684684, 0.7319489645306021, 1.5106879058293998, 6.188708916306496, 8.867683913558722, 12.06632187590003, 16.9085530936718, 18.688835464417934, 19.938540905714035, 25.890689715743065, 31.507736407220364, 33.354386016726494, 29.86540373414755, 31.478914953768253, 34.58445221185684, 34.42247070372105, 17.12578173726797, 19.479082860052586, 3.654682128690183, 7.679977370426059, 5.356812905520201, 3.091374230571091, 2.306930311024189, 2.0969215175136924, 2.7884048502892256, 2.2991198301315308, 5.596893522888422, 6.053633764386177, 4.454083945602179, 6.987200444564223, 6.7476437240839005, 2.926756851375103, 3.300139303319156, 2.389532891102135, 1.9080074108205736, 0.519466147525236, 0.8888591104187071, 0.34426550497300923, 1.869885481428355, 3.4710681438446045, 14.142972193658352, 31.730368360877037, 11.259223334491253, 17.13727232068777, 17.963351793587208, 15.505831763148308, 24.10889882594347, 30.066901221871376, 19.654618240892887, 8.860182166099548, 1.1875172657892108, 0.047003121580928564, 0.07299518896616064, 0.06932356918696314, 0.03575879389245529, 0.06868823140393943, 0.10880811882088892, 0.03140546694339719, 0.021295487858878914, 0.03436834682361223, 0.010907874111580895, 0.039600139134563506, 0.023729507738607936, 0.05010197404772043, 0.019446861078904476, 0.012703201700787758, 0.019782434283115435, 0.0335462624207139, 0.03905382938683033, 0.05427092553873081, 0.026126457341888454, 0.032790440673124976, 0.04329286559368484, 0.025282668830186594, 0.027004718613170553, 0.011762402427848428, 0.04911711439490318, 0.033063643786590546, 0.04341912717791274, 0.02520660425943788, 0.017152819527836982, 0.047096903072088026, 0.004304453741497127, 0.04399193530844059, 0.01540635030323756, 0.05206509194977116, 0.030230428237700835, 0.07789088485878892, 0.017660934645391535, 0.014008436301082838, 0.06423074402846396, 0.05669356272846926, 0.026703100520535372, 0.032017534686019644, 0.047614758877898566, 0.03323756238387432, 0.0361853840877302, 0.028192897043481935, 0.05025556522014085, 0.056193570417235605, 0.020722180634038523, 0.08532078500138596, 0.06314893762464635, 0.06508162376121618, 0.04139394346566405, 0.054363590097636916, 0.06584298564121127, 0.03432841556787025, 0.0011630055928435468, 0.030255872770794667, 0.018804174178512767, 0.07035690592601895, 0.020298855888540857, 0.05953641506494023, 0.02742655349720735, 0.04717873227491509, 0.005844405995958368, 0.002888275253098982, 0.040702670012251474, 0.03240148478653282, 0.015757322144054342, 0.05029400846979115, 0.022359174727171194, 0.032094892449094914, 0.009052004897966981, 0.021323847176972777, 0.07268459274200723, 0.034563168010208756, 0.10887725729844533, 0.05129631972522475, 0.02073357445624424, 0.021279791435517836, 0.030718653797521256, 0.06087875612138305, 0.05743444504332729, 0.013073523186903913, 0.0357887358404696, 0.026254169824824203, 0.023027487986837514, 0.031017655819596257, 0.05081101080577355, 0.02212628136476269, 0.06869091055705212, 0.4577879165299237, 5.942078875377774, 22.448576018214226, 37.29301907122135, 46.666181311011314, 34.82771895825863, 24.320771656930447, 25.101667754352093, 19.457944594323635, 16.985050588846207, 23.945093415677547, 23.686059415340424, 17.007041908800602, 8.887727838009596, 4.32658321224153, 1.065775598399341, 0.26067497790791094, 0.08091473588137887, 0.053281071232049726, 0.4121393628884107, 0.5965584295336157, 0.31961545580998063, 1.863968011457473, 2.7379608945921063, 6.034199707210064, 5.412618611007929, 7.42854343727231, 5.965276155620813, 5.836246479302645, 7.3592684045434, 3.318823375739157, 4.443819271400571, 3.3986737160012126, 1.2767960876226425, 1.252644939813763, 2.058673007413745, 10.096685215830803, 19.628884121775627, 21.30626041442156, 25.121821872889996, 25.547277443110943, 23.99613607674837, 31.186932921409607, 37.76398479938507, 40.697191804647446, 33.802096992731094, 36.948480159044266, 37.87168622016907, 41.619976088404655, 24.240250177681446, 31.207332126796246, 8.466112911701202, 14.44070901721716, 5.693584559485316, 6.410152008756995, 3.6007969826459885, 3.4262424241751432, 2.987469518557191, 3.920122110284865, 7.7204005513340235, 6.450432222336531, 6.014599408954382, 7.26890972815454, 4.535451829433441, 2.480148528702557, 2.288995273411274, 1.4339373679831624, 0.5404382315464318, 0.2305343421176076, 0.15114437090232968, 0.414900389732793, 2.42526451125741, 4.99924591742456, 15.32260274514556, 34.74226914346218, 15.998121947050095, 14.225231129676104, 14.255772940814495, 18.11987679451704, 28.196529485285282, 35.6011750549078, 24.354798831045628, 10.366822220385075, 1.71977263642475, 0.044550490492838435, 0.0631484626501333, 0.02143350135156652, 0.014631594513048185, 0.049975274596363306, 0.024985893251141533, 0.06191843451233581, 0.013998906197230099, 0.022910666521056555, 0.05686618998879567, 0.06142159261798952, 0.027112613897770643, 0.04244671705237124, 0.04171368665993214, 0.005075917179055978, 0.02962506394396769, 0.027402255582273938, 0.01037068257573992, 0.03556882635166403, 0.040210110309999436, 0.04111069909413345, 0.05222654617682565, 0.01483103742430103, 0.012549764524010243, 0.024853054383129347, 0.03140314402116928, 0.04217528767185286, 0.06888428455567919, 0.04695215458923485, 0.05224907035881188, 0.026482324574317317, 0.03985679606557824, 0.040921466279542074, 0.04533521147095598, 0.03143134563288186, 0.06574572718818672, 0.03657516746898182, 0.04607983421010431, 0.021703817510569934, 0.03977923792263027, 0.06108437926741317, 0.036910588532919064, 0.02139679101674119, 0.22002817306201905, 0.11748639299185015, 0.12043850059853867, 0.14529906737152487, 0.1145134013495408, 0.11661813216051087, 0.24959604896139354, 0.19664035382447764, 0.20970811980077997, 0.13904400926548988, 0.11884772189659998, 0.09423946306924336, 0.20691111363703385, 0.16347518423572183, 0.09073913839529268, 0.1645186438690871, 0.06557466214871965, 0.21997319476213306, 0.0858349449117668, 0.16144922497915104, 0.1404356400598772, 0.11734223080566153, 0.16660591936670244, 0.0877748076163698, 0.12388278570142575, 0.10071427110233344, 0.10402892527054064, 0.09245824927347712, 0.14705259905895218, 0.17956920579308644, 0.1943509469856508, 0.10270406550262123, 0.12406997018842958, 0.17341274942737073, 0.17041030194377527, 0.17952383088413626, 0.12343861773842946, 0.10867105156648904, 0.10662567772669718, 0.21642210718709975, 0.1624118647305295, 0.1492373927612789, 0.09563630374032073, 0.1419683828135021, 0.1416143635287881, 0.16924404655583203, 0.13003963540541008, 0.19974639028077945, 0.14066993608139455, 0.7308797969017178, 6.5009034890681505, 26.72061648219824, 43.32090921700001, 54.46364790201187, 45.940952226519585, 37.01455481350422, 39.81872834265232, 31.169474758207798, 24.708077274262905, 30.779644176363945, 25.813992731273174, 16.759675182402134, 10.297360047698021, 4.930455833673477, 1.6893710615113378, 0.9546901029534638, 0.3424473915947601, 0.8937397110275924, 0.838928067823872, 2.8901581652462482, 2.1765084844082594, 7.622295990586281, 6.019422300159931, 18.057668432593346, 11.279722284525633, 15.598580036312342, 12.582106199115515, 13.856997638940811, 17.97583982348442, 6.758496416732669, 6.786957839503884, 3.0273148929700255, 0.896868605632335, 1.866080341860652, 2.055021640844643, 10.669239442795515, 16.78572278469801, 17.263176664710045, 25.66539790481329, 25.630293488502502, 29.933699369430542, 33.948020562529564, 40.1727781444788, 41.9629380851984, 36.43312141299248, 36.43308341503143, 38.58567550778389, 39.8540398478508, 29.213761501014233, 38.49611431360245, 11.298346985131502, 12.605189010500908, 8.996719289571047, 5.259748063981533, 4.661278277635574, 6.0884674452245235, 10.580459106713533, 7.092300429940224, 11.316651552915573, 12.18067578971386, 11.499478742480278, 16.391518637537956, 13.066216371953487, 8.189084026962519, 8.556611705571413, 7.705404656007886, 4.68440193682909, 1.3780028256587684, 1.6972510074265301, 0.6310774991288781, 3.408680479042232, 4.882812090218067, 18.83143611252308, 40.0765635073185, 19.42806489765644, 25.094858519732952, 25.53827002644539, 25.029773712158203, 34.77489419281483, 42.221601605415344, 27.20271561294794, 11.41175664961338, 1.854410336818546, 0.16613287443760782, 0.15724964876426384, 0.1077057103975676, 0.08526882724254392, 0.21204548422247171, 0.20019838790176436, 0.18355810112552717, 0.07632436696439981, 0.10459258643095382, 0.15224090893752873, 0.1478316166321747, 0.0702164470567368, 0.1655446778750047, 0.1413891217089258, 0.10994851036230102, 0.13260252366308123, 0.08722570739337243, 0.23325573827605695, 0.12320151639869437, 0.16830721870064735, 0.1099108463677112, 0.10631666969857179, 0.18211362941656262, 0.1281372140510939, 0.11529460825840943, 0.16584155178861693, 0.1129517296794802, 0.2434563948190771, 0.0793272077862639, 0.10407740977825597, 0.14549049694323912, 0.11492936770082451, 0.1860299427062273, 0.12723704829113558, 0.07685029733693227, 0.18454184755682945, 0.14722903724759817, 0.1125154655892402, 0.11056579911382869, 0.2242472826037556, 0.22631968546193093, 0.14848546357825398, 0.1661116341711022], [0.03067557954636868, 0.07495416939491406, 0.040146786559489556, 0.009405179062014213, 0.03025953712494811, 0.05317957511579152, 0.08515472203725949, 0.007055275591483223, 0.03668902034405619, 0.03985121140431147, 0.06708994216751307, 0.05015685215767007, 0.025395853772351984, 0.07371234853053465, 0.028600594014278613, 0.03452522199950181, 0.06527712030219845, 0.006671149694739142, 0.05135098261234816, 0.03712705074576661, 0.03611813808674924, 0.06714519506203942, 0.07621467753779143, 0.017635701624385547, 0.014336456297314726, 0.03711449731781613, 0.06465146012487821, 0.0391231534013059, 0.08484494959702715, 0.0432614913006546, 0.05625462690659333, 0.011881586706294911, 0.053642534257960506, 0.08289016972412355, 0.08622993816970848, 0.046380136845982634, 0.01862958579295082, 0.03973333979956806, 0.024103342366288416, 0.039279653792618774, 0.014856038524158066, 0.03908837265043985, 0.042752504159579985, 0.07406191492918879, 0.054819350407342426, 0.023589592492498923, 0.024527631903765723, 0.048897423839662224, 0.06706861284328625, 0.012461714268283686, 0.012185174273326993, 3.6575044272467494, 13.106562606990337, 27.755414955317974, 39.908787310123444, 43.37747298181057, 30.621088184416294, 26.09923392534256, 21.00770853459835, 20.508527420461178, 29.307901449501514, 21.756302565336227, 17.0854165032506, 10.091420598328114, 6.180915534496307, 1.6497078398242593, 1.0138136241585016, 0.285358126857318, 0.2743158006342128, 0.16785388521384448, 0.4799582128180191, 1.1242644349113107, 2.098102066665888, 5.704582594335079, 4.573824070394039, 4.847405115142465, 4.020045585930347, 4.962612083181739, 4.3416893016546965, 4.0743346977978945, 5.586026581004262, 3.5548346489667892, 0.5366493598558009, 0.18001624586759135, 0.24287930078571662, 0.8948194468393922, 0.175604326359462, 2.1522413240745664, 6.435134243220091, 7.069149222224951, 9.695268105715513, 13.474291674792767, 17.899646311998367, 15.933771450072527, 13.918572384864092, 18.60569592565298, 12.850788831710815, 10.637396201491356, 17.897231541574, 21.902938596904278, 7.973137814551592, 3.4291471308097243, 1.629820775706321, 1.3303207280114293, 1.759551395662129, 2.455248227342963, 1.9846390862949193, 3.378693200647831, 6.594455419108272, 5.387957934290171, 3.530423096381128, 3.9997475501149893, 2.9940191796049476, 2.4821408092975616, 1.8068493576720357, 0.25059162522666156, 0.8641727257054299, 0.3107574483146891, 0.6150293571408838, 1.546473791822791, 7.168266428634524, 8.547471296042204, 30.38754891604185, 40.85108734667301, 12.453393805772066, 24.500196129083633, 21.352838315069675, 32.178523913025856, 29.31635219603777, 20.561680868268013, 7.320085382089019, 1.0520919389091432, 0.020417085579538252, 0.03993036145402584, 0.036173491171211936, 0.05166673305211589, 0.03968520410126075, 0.08892939644283615, 0.040706503205001354, 0.0633741200726945, 0.061885256800451316, 0.021338168771762867, 0.0025504354834993137, 0.055039167127688415, 0.033779764344217256, 0.03226998363970779, 0.02328574424609542, 0.01711916869680863, 0.04852397883951198, 0.019635841563285794, 0.07170073498855345, 0.032740943133831024, 0.054925718723097816, 0.017286148213315755, 0.06695419593597762, 0.04420805613335688, 0.05866910418262705, 0.11898152370122261, 0.05798184574814513, 0.06246560515137389, 0.05029717372963205, 0.1289043721044436, 0.05889221232791897, 0.06059610917873215, 0.03315973335702438, 0.03669649006042164, 0.027623766254691873, 0.02335007731744554, 0.02302319095178973, 0.04213618020003196, 0.09588796601747163, 0.04076112527400255, 0.05625462690659333, 0.02674105951882666, 0.05276062904158607, 0.03695234176120721, 0.025157266281894408, 0.04289555312425364, 0.05630315594316926, 0.039154074984253384, 0.030062975602049846, 0.04767354439536575, 0.08016639127163216, 0.07724414768745191, 0.04681324680859689, 0.05583882753853686, 0.04062543470354285, 0.11754160877899267, 0.037592329099425115, 0.04081630024302285, 0.03842795398668386, 0.027157465592608787, 0.08790657593635842, 0.06673016381682828, 0.021708775057049934, 0.07018486867309548, 0.018674713937798515, 0.08274772189906798, 0.03243071798351593, 0.03378695204446558, 0.06996875526965596, 0.05719008549931459, 0.020550931913021486, 0.0736536891781725, 0.022297090363281313, 0.026433867897139862, 0.06881039633299224, 0.006474474530477892, 0.0626523295068182, 0.016244664548139554, 0.0439971340529155, 0.07802818960044533, 0.04438257958099712, 0.019035169498238247, 0.016922148897720035, 0.025864215749606956, 0.04570286771922838, 0.045915990267531015, 0.030701738396601286, 0.07778808256261982, 0.03723284760781098, 0.011907991392945405, 0.04223657422699034, 0.05432762191048823, 0.03738957064342685, 0.020161879547231365, 0.05271546193398535, 4.903732817620039, 17.173085398972034, 34.70425218343735, 46.383252292871475, 46.57688990235329, 33.1604178249836, 24.279462173581123, 19.623661302030087, 24.045911505818367, 30.083006657660007, 22.738812044262886, 22.294845767319202, 13.906242996454239, 7.061996581032872, 2.374218525364995, 0.9614039270672947, 0.28848776360973716, 0.3225831262534484, 0.15787812910275534, 0.16632730228593573, 0.9766769700217992, 1.1711324262432754, 1.4077622350305319, 2.224564030766487, 3.3405762584879994, 1.8300002091564238, 3.311973768286407, 4.127422124147415, 4.755362179130316, 4.967243559658527, 3.4971622936427593, 3.6907583428546786, 1.2319627683609724, 0.8741103205829859, 1.172842097003013, 1.8750108126550913, 1.3144057570025325, 8.903464693576097, 10.109075400978327, 13.203148674219847, 16.99345003813505, 19.725150056183338, 19.38527539372444, 18.897221982479095, 23.077888749539852, 17.662240751087666, 15.885014366358519, 24.29195400327444, 28.297710455954075, 9.364591799676418, 3.4361549047753215, 3.1529214279726148, 4.497184082865715, 4.196146186441183, 5.028516221791506, 3.3469539787620306, 6.083372393622994, 7.543187560513616, 6.051905807107687, 6.046832604333758, 4.583144495263696, 2.653527525253594, 1.0355954803526402, 1.6148723778314888, 0.31263528973795474, 0.3739176888484508, 0.18323738942854106, 1.048489494714886, 2.352075451053679, 8.720641303807497, 9.177929665893316, 29.215708896517754, 44.28037293255329, 13.967486210167408, 21.596192456781864, 21.44668187946081, 32.25452743470669, 33.58001030981541, 25.019119083881378, 9.37133738771081, 1.3678101100958884, 0.0928768354060594, 0.06025835777109023, 0.07349953768425621, 0.03507363573589828, 0.0462755274202209, 0.015315828695747769, 0.05710020399419591, 0.03365865326486528, 0.02266918651002925, 0.012085207908967277, 0.03928794358216692, 0.012734540741803357, 0.02672446695214603, 0.0401296466588974, 0.02943635619885754, 0.016298509217449464, 0.05056412424892187, 0.016493232069478836, 0.03270816618169192, 0.013195663996157236, 0.04870828379353043, 0.02487083253072342, 0.03445645830652211, 0.04724885780888144, 0.070979775628075, 0.09261939179850742, 0.05472529803228099, 0.05286743522447068, 0.03978926433774177, 0.07161771092796698, 0.042140777804888785, 0.052693063917104155, 0.08118608733639121, 0.009023707734741038, 0.0769867115013767, 0.06972010611207224, 0.037626939156325534, 0.11161826841998845, 0.0407532585086301, 0.022693202408845536, 0.04832334292586893, 0.05207317393796984, 0.039707231044303626, 0.029271547464304604, 0.11520287880557589, 0.17387089203111827, 0.17863832996226847, 0.15061017300467938, 0.09386798104969785, 0.12413806223776191, 0.13417425885563716, 0.12393216078635305, 0.10066613540402614, 0.08535564367775805, 0.13397334463661537, 0.25725035229697824, 0.1354345740401186, 0.149204085173551, 0.1381051924545318, 0.12088464267435484, 0.2330330346012488, 0.23096888442523777, 0.1087344903498888, 0.17850726668257266, 0.1068577473051846, 0.26577151380479336, 0.2534227108117193, 0.14581350929802284, 0.13760991278104484, 0.1312153012258932, 0.15771913138451055, 0.1483137157629244, 0.1691337040392682, 0.08307086041895673, 0.12416658297297545, 0.13092503242660314, 0.14199085504515097, 0.14161583298118785, 0.19189225626178086, 0.21119833749253303, 0.1398827400407754, 0.1239648375485558, 0.07820988961611874, 0.2463065239135176, 0.17375153984175995, 0.13048774417256936, 0.08992233066237532, 0.2359457712736912, 0.14961860433686525, 0.15981192846084014, 0.19441284210188314, 0.1544782318524085, 0.1266442652558908, 0.12466776272049174, 0.17826759751187637, 5.6364422757178545, 20.593361668288708, 41.35745197534561, 54.35428597033024, 54.065512865781784, 40.98474897444248, 36.996790766716, 29.85441282391548, 31.987432166934013, 38.21401745080948, 30.87125726044178, 24.283125177025795, 14.481388684362173, 8.576197754591703, 2.2696336498484015, 1.8361274991184473, 0.6156185630243272, 1.0225067264400423, 0.6467282061930746, 1.4153465093113482, 2.6156490202993155, 5.496080657467246, 13.649215288460255, 11.893955525010824, 14.04451472684741, 10.498863235116005, 12.276950273662806, 13.407718297094107, 9.799898341298103, 10.039212349802256, 10.021566096693277, 4.1648548655211926, 1.9455833570100367, 1.7279895767569542, 2.9213105561211705, 4.126787083223462, 2.9224576195701957, 7.405736586079001, 10.222441367805004, 14.040025267750025, 19.109377898275852, 21.186884120106697, 17.87669364362955, 17.369508258998394, 23.57132077217102, 19.648190885782242, 21.343447118997574, 31.774757578969, 38.09393249452114, 12.96798499301076, 4.671527752652764, 2.504325918853283, 3.6954373167827725, 7.357873879373074, 7.786529827862978, 9.72596475854516, 11.452006939798594, 14.264427926391363, 15.498252119868994, 12.01703567057848, 9.042936209589243, 8.48241213709116, 6.4593232702463865, 5.570875369012356, 1.8012298154644668, 1.9570870022289455, 0.7252280157990754, 1.5114440652541816, 2.749708676710725, 9.420342408120632, 12.364283837378025, 35.87208151817322, 50.59405714273453, 17.580220252275467, 36.00689448416233, 30.60087326914072, 43.32662031054497, 40.53310140967369, 27.83790472894907, 10.291929189115763, 1.4391487883403897, 0.1651875118841417, 0.14731662551639602, 0.1795438985573128, 0.15395834256196395, 0.10599399873171933, 0.14625378098571673, 0.24164534668670967, 0.11445839336374775, 0.15672640496632084, 0.06278006796492264, 0.1336633792379871, 0.17569014831678942, 0.17763090902008116, 0.2419876103522256, 0.15823740279302, 0.17774015315808356, 0.1523638828075491, 0.09295795956859365, 0.1135343972418923, 0.12336206520558335, 0.13862273655831814, 0.11066542501794174, 0.17808036849601194, 0.11491413140902296, 0.1096034116926603, 0.1874800695804879, 0.17341870145173743, 0.08789936968241818, 0.16281878430163488, 0.2736761880805716, 0.13160483969841152, 0.17554225312778726, 0.19208018289646134, 0.1351510884705931, 0.12880412279628217, 0.0860156059206929, 0.12104562934837304, 0.25591006327886134, 0.24874496884876862, 0.18450720410328358, 0.1881346883601509, 0.09770940421731211, 0.10858479916350916, 0.221661432296969], [0.037597950868075714, 0.009222880689776503, 0.03783350854064338, 0.06870922676171176, 0.0750937673728913, 0.04750706582854036, 0.010724557141656987, 0.047327035645139404, 0.10810449603013694, 0.08574718594900332, 0.04794970867806114, 0.0076326140697347, 0.04643367909011431, 0.03231887261790689, 0.024812028459564317, 0.04616265789081808, 0.03153622223180719, 0.10092693351907656, 0.0398643066000659, 0.006246205675779493, 0.058780582185136154, 0.023617725455551408, 0.037912250409135595, 0.031484694918617606, 0.024038376614043955, 0.022993605234660208, 0.08169801338226534, 0.02086085092741996, 0.05486566784384195, 0.06201451295055449, 0.06829314166679978, 0.041133000631816685, 0.05073363077826798, 0.08081887266598642, 0.0406701528117992, 0.05600045245955698, 0.04920953775581438, 0.030131689200061373, 0.0164976218729862, 0.03859836964693386, 0.057824365721899085, 0.0657566219160799, 0.029028243625361938, 0.08044824411626905, 0.030448077886831015, 0.12475478695705533, 0.04579124637530185, 0.046043635957175866, 0.08826135221170262, 0.05253484545391984, 0.03902047727024183, 0.06267886128625832, 2.854127073660493, 11.548101883381605, 25.405704639852047, 41.14204153418541, 40.018525421619415, 34.72286358475685, 24.257776737213135, 21.11855238676071, 16.004450507462025, 25.007902085781097, 20.668350644409657, 18.160365521907806, 11.47254578769207, 9.482520371675491, 4.525926215574145, 1.8920319993048906, 0.6293685408309102, 0.2679024572717026, 0.08907502065994777, 0.0628880133444909, 1.060861274600029, 1.1649702256545424, 1.8982603400945663, 2.294079875573516, 1.4587342436425388, 1.8168593267910182, 2.880134303122759, 2.4325461080297828, 2.848202954046428, 3.0745655950158834, 3.5099695064127445, 0.3918824123684317, 0.546981836669147, 2.431791848503053, 12.015970777720213, 0.8165072521660477, 0.596386844990775, 1.5494043845683336, 1.8792523350566626, 3.8426874903962016, 5.107657900080085, 4.728405950590968, 4.732967130839825, 4.4130318984389305, 3.8834514655172825, 8.412731476128101, 2.7364547504112124, 3.810149598866701, 13.250129353255033, 1.572917285375297, 1.3095954526215792, 6.990090189501643, 2.824876243248582, 3.803066541440785, 0.8638322283513844, 2.471564789302647, 5.675063403323293, 4.557939022779465, 4.813929861411452, 4.134967569261789, 1.3889331766404212, 0.3282552125165239, 0.9908293699845672, 0.40406179788988084, 0.6032226781826466, 0.7321912015322596, 3.4400722570717335, 5.012154774740338, 11.57265616580844, 14.504627287387848, 44.38382238149643, 38.88893723487854, 12.64489023014903, 21.518496125936508, 27.35110905021429, 27.68566969782114, 22.042617201805115, 7.576865628361702, 0.6783036212436855, 0.0684647262096405, 0.03020896347152302, 0.017169827697216533, 0.0430513039464131, 0.032668969652149826, 0.06785793142626062, 0.046326947121997364, 0.0034629336505531683, 0.02156783750251634, 0.004452634657354793, 0.03214646800188348, 0.0845830976322759, 0.03837536169157829, 0.04068473972438369, 0.0179748612572439, 0.052832116416539066, 0.026818420992640313, 0.04602478911692742, 0.02944886509794742, 0.05470973890624009, 0.07726815616479144, 0.05200806903303601, 0.034524747024988756, 0.03885864083713386, 0.037678559237974696, 0.025637730832386296, 0.03605928206525277, 0.05923648350290023, 0.013756151547568152, 0.044890093558933586, 0.019176092209818307, 0.03229090849345084, 0.07765217305859551, 0.02034830704360502, 0.04031500546261668, 0.08722729558940046, 0.07377226953394711, 0.017012219650496263, 0.03088370187469991, 0.0455961431725882, 0.04240878588461783, 0.03543951825122349, 0.027377326841815375, 0.08475442242342979, 0.02504432439309312, 0.04271437261195388, 0.019536909567250405, 0.03166943402902689, 0.030760468252992723, 0.05657553527271375, 0.06276167012401856, 0.03863823782012332, 0.08354596109711565, 0.03181299878633581, 0.08489118539728224, 0.050887333272839896, 0.060584468592423946, 0.10489311171113513, 0.046582891591242515, 0.027931907825404778, 0.04860337750869803, 0.0334899371227948, 0.02422660938464105, 0.040684309278731234, 0.07480358020984568, 0.03591775821405463, 0.035889649370801635, 0.03204570290108677, 0.015299176757253008, 0.023838455017539673, 0.034200981390313245, 0.051073400827590376, 0.01400892055244185, 0.04477536123886239, 0.060687864606734365, 0.007729359049335471, 0.034998292903765105, 0.026235233926854562, 0.03151187236653641, 0.03269122295023408, 0.058106485739699565, 0.012341439032752533, 0.04108894303499255, 0.051953257716377266, 0.0236561705605709, 0.02777435915049864, 0.02665118357981555, 0.02030259074672358, 0.047499725988018326, 0.059890389820793644, 0.06642531923716888, 0.07786774469423108, 0.06761579832527786, 0.06678220321191475, 0.06350948038743809, 0.04036364953208249, 0.11607554057263769, 4.070658395066857, 15.730969682335854, 29.77921675890684, 45.88615916669369, 42.38945759832859, 38.03497485816479, 25.707222260534763, 22.65263456851244, 19.946624971926212, 31.18908930569887, 27.57962118834257, 22.055238224565983, 15.160086415708065, 9.507165849208832, 4.327314672991633, 1.6381927952170372, 0.7085077848751098, 0.03732446573849302, 0.1519369549350813, 0.05413726103142835, 0.31553595908917487, 1.0106277326121926, 1.1860650312155485, 1.9836142100393772, 1.4472433039918542, 2.1458726283162832, 3.649285468272865, 4.188388427719474, 3.921298859640956, 4.953334406018257, 6.706990655511618, 4.223453421145678, 1.6582210455089808, 4.234727416187525, 8.369336854666471, 0.29828515194822103, 1.6133882012218237, 1.457739647012204, 2.278903964906931, 5.361968753859401, 9.195675663650036, 9.589772466570139, 6.9183011166751385, 6.288175703957677, 10.432321205735207, 12.317399103194475, 5.342228338122368, 5.800673738121986, 16.81780256330967, 2.8514980897307396, 3.041518530808389, 6.71553592197597, 6.377715999260545, 5.5193776823580265, 3.8899075565859675, 5.4264517687261105, 4.8829294089227915, 3.970954120159149, 2.807022426277399, 2.2748084971681237, 1.1282030423171818, 0.5351370410062373, 0.247275234432891, 0.1865668865502812, 0.6592879572417587, 1.0594236454926431, 4.340377897024155, 7.30481400154531, 17.727179266512394, 16.470596194267273, 45.20678602159023, 43.57010744512081, 13.952174931764603, 24.74456861615181, 29.44054663181305, 33.96394930779934, 25.604726560413837, 9.489068370312452, 1.1438598646782339, 0.06159351112728473, 0.04606532151228748, 0.05397721688495949, 0.09083964745514095, 0.07307598658371717, 0.08537951856851578, 0.030465540621662512, 0.025705893385747913, 0.027904555972781964, 0.027304397845000494, 0.02053503139904933, 0.041389564794371836, 0.0606072302616667, 0.07329290892812423, 0.03427846160775516, 0.06573362275958061, 0.06839327965280972, 0.06500495248474181, 0.014058510860195383, 0.06861105546704493, 0.04530283527856227, 0.045880990583100356, 0.045863568666391075, 0.05842259983182885, 0.07361982497968711, 0.0784704799298197, 0.05420277411758434, 0.03813469062151853, 0.05444025024189614, 0.042590753073454835, 0.015578327256662305, 0.015837945356906857, 0.09731584330438636, 0.0549038773169741, 0.014924436709407018, 0.03406651165278163, 0.06590824268641882, 0.011417696168791736, 0.010799423143907916, 0.097187911887886, 0.017464985394326504, 0.03125105198705569, 0.03825295185379218, 0.04191858250123914, 0.02420821339910617, 0.10617085252306424, 0.10406630724901333, 0.1602385743171908, 0.13499433203833178, 0.1303762587485835, 0.2259121573297307, 0.11884193314472213, 0.23440087214112282, 0.23868212912930176, 0.1471761814900674, 0.1786288304720074, 0.235757518094033, 0.2487630772520788, 0.11924325692234561, 0.07519505568780005, 0.1513628294924274, 0.1427130537922494, 0.18378798878984526, 0.12250627245521173, 0.19221534283133224, 0.15504585608141497, 0.1270592593937181, 0.07902923549409024, 0.13707811944186687, 0.15333287534303963, 0.29878087691031396, 0.1365519961109385, 0.1009761898603756, 0.11424652504501864, 0.17209481389727443, 0.21774336753878742, 0.19263999973190948, 0.08751778703299351, 0.1628368184901774, 0.10553435698966496, 0.18575625348603353, 0.09189596108626574, 0.18891538318712264, 0.1558531346381642, 0.11820490326499566, 0.11690348052070476, 0.16429737996077165, 0.0986405843286775, 0.11927804138395004, 0.17740007140673697, 0.21427706291433424, 0.17642711580265313, 0.15263381676049903, 0.1964162549120374, 0.14839895884506404, 0.1909235308994539, 0.24185507762013003, 4.3324363231658936, 18.1305181235075, 35.69051206111908, 54.879934564232826, 52.88158759474754, 48.3996444940567, 33.37006017565727, 32.0108313113451, 23.748847246170044, 35.533033311367035, 27.912717014551163, 27.271972596645355, 17.444259747862816, 13.031319044530392, 5.542208282276988, 2.679856074973941, 1.0194157110527158, 0.47355994989629835, 0.20618489244952798, 0.800247093429789, 2.644938323646784, 4.099705461412668, 5.209730872884393, 7.612321525812149, 6.887232083827257, 6.938655199483037, 10.890772305428982, 9.46417210623622, 8.52346608415246, 8.033086247742176, 10.023286454379559, 4.719473579898477, 1.7312153661623597, 4.619592614471912, 16.524131521582603, 1.2756399996578693, 1.052889064885676, 2.2731251874938607, 3.255781433545053, 5.567586645483971, 8.534924369305372, 9.834810867905617, 4.959256388247013, 6.325777061283588, 16.36643808335066, 19.656263552606106, 4.840505160391331, 7.38040667027235, 20.082716569304466, 2.9940384160727262, 3.6141770146787167, 12.191243022680283, 9.905297085642815, 11.473194602876902, 8.064050786197186, 8.96636651828885, 13.625490311533213, 8.017965909093618, 9.708371702581644, 10.056935548782349, 5.2913642674684525, 2.2720921179279685, 1.940531290601939, 0.7652709796093404, 1.1288670566864312, 1.1893406929448247, 4.55165178515017, 7.8232672065496445, 16.390808075666428, 21.03663258254528, 52.05702804028988, 48.78479562699795, 18.668548353016376, 31.5208438038826, 38.34496982395649, 38.847755044698715, 29.71928257495165, 10.348881483078003, 1.3652882329188287, 0.16646562376990914, 0.21597512648440897, 0.13192838639952242, 0.16227079730015248, 0.12654680642299354, 0.15343213017331436, 0.13699833856662735, 0.2604160871123895, 0.11280868813628331, 0.06425164290703833, 0.07221355161163956, 0.1339159469353035, 0.11097525682998821, 0.16241581295616925, 0.12161414415459149, 0.17889827460749075, 0.1337139046518132, 0.10860720460186712, 0.14098000538069755, 0.21654436859535053, 0.07574952905997634, 0.14465854939771816, 0.19745186262298375, 0.1805670975591056, 0.16207279230002314, 0.1359303286881186, 0.22357041423674673, 0.17936897434992716, 0.20222863677190617, 0.21822358161443844, 0.08225339959608391, 0.10045304996310733, 0.14444104075664654, 0.17147372534964234, 0.21258297725580633, 0.1417508296435699, 0.1582225746824406, 0.12964819703483954, 0.10154071933357045, 0.1883155942778103, 0.11614312796154991, 0.13306452543474734, 0.16572601423831657, 0.24116063519613817, 0.07329356943955645], [0.040812251827446744, 0.09371181091410108, 0.06138611053756904, 0.1444202457787469, 0.014344750725285849, 0.026275645723217167, 0.04339938976045232, 0.09308331573265605, 0.04810351507330779, 0.047761978712514974, 0.09336908711702563, 0.027159519486303907, 0.03477459104033187, 0.04447331084520556, 0.014959043055569055, 0.022837691140011884, 0.08519293522113003, 0.04537771797913592, 0.02958118260721676, 0.016316777182510123, 0.03238490520743653, 0.02449849333061138, 0.060282266058493406, 0.043702698094421066, 0.042806866476894356, 0.028366763690428343, 0.026618985502864234, 0.06559504152392037, 0.05373693915316835, 0.03987864118244033, 0.033331681552226655, 0.04801012320967857, 0.02789993795886403, 0.05594278387434315, 0.06430705907405354, 0.06105061525886413, 0.14755996089661494, 0.04110392699658405, 0.03932874315069057, 0.031938158281263895, 0.02033309116086457, 0.08736181727726944, 0.028483696478360798, 0.035386013114475645, 0.07681164628593251, 0.07381051982520148, 0.08762679368373938, 0.0629125784325879, 0.053205353615339845, 0.06881397348479368, 0.16304044896969572, 0.04003515270596836, 0.023457117276848294, 2.283955318853259, 9.157302472740412, 27.380388379096985, 38.986854180693626, 41.932919695973396, 38.66371192038059, 27.483178563416004, 16.965988911688328, 16.122660264372826, 17.230173535645008, 19.75662186741829, 18.49098388105631, 16.443275660276413, 11.038032453507185, 6.6586928721517324, 3.4585143299773335, 2.2337505128234625, 0.9021248517092317, 0.4187054996145889, 0.05109252226247918, 0.4079971101600677, 0.4529228119645268, 0.6259404716547579, 0.37623307085596025, 1.147599695250392, 1.193287493661046, 3.8058465672656894, 3.116727420128882, 3.962030061520636, 5.926813194528222, 4.069221122190356, 0.48452078830450773, 3.8655439764261246, 8.801103886216879, 0.44733236194588244, 1.2569606769829988, 0.17427798971766606, 0.19154555455315858, 0.5338728963397443, 0.7024165929760784, 1.8307723989710212, 1.8330556014552712, 0.5660948110744357, 7.110291039571166, 10.007860232144594, 0.20593437307979912, 0.3904524422250688, 2.2396518336609006, 0.3444025944918394, 3.0681019043549895, 7.128747599199414, 5.827566795051098, 4.79814313352108, 3.378466162830591, 4.468687986955047, 3.8789729308336973, 2.7922445442527533, 2.9439447540789843, 1.1884919134899974, 0.35315812623593956, 0.4925353894941509, 0.9066391875967383, 0.8083045610692352, 1.775060382205993, 3.9926029834896326, 7.25124447606504, 13.012130074203014, 15.118604991585016, 21.206681057810783, 46.5293088555336, 38.14861536026001, 20.72798654437065, 27.148224636912346, 26.324227452278137, 18.551913611590862, 9.586864672601223, 1.4400103921070695, 0.03417492458538618, 0.024586103863839526, 0.022475447003671434, 0.011427823701524176, 0.013027193690504646, 0.04999768374545965, 0.03915684690582566, 0.05098842862935271, 0.0662224976986181, 0.004523691586655332, 0.06399199512088671, 0.03628680598922074, 0.01919043977977708, 0.059086595647386275, 0.05403085931902751, 0.10632277015247382, 0.027704215062840376, 0.04280560482584406, 0.037634360633092, 0.05396308268245775, 0.036122320088907145, 0.054166171394172125, 0.07860473444452509, 0.09719741879962385, 0.016463097163068596, 0.036104293321841396, 0.07701727314270101, 0.028612256865017116, 0.04612545402778778, 0.05015085560444277, 0.07101392926415429, 0.0269887067770469, 0.020471980387810618, 0.04321230917412322, 0.07636423513758928, 0.025958869264286477, 0.030765062147111166, 0.012365136735752458, 0.06340053310850635, 0.025286466770921834, 0.052606514655053616, 0.022503279396914877, 0.0615772284072591, 0.040484630735591054, 0.039800700833438896, 0.08483950965455733, 0.046760376208112575, 0.11734353698557243, 0.04504824893956538, 0.05160261891433038, 0.03733233250386547, 0.02576892584329471, 0.016389409320254344, 0.03688081727887038, 0.06498010538052768, 0.04320910680689849, 0.033878662943607196, 0.04101498059753794, 0.03162028158840258, 0.02721058852330316, 0.07312053770874627, 0.06516699300846085, 0.047116710993577726, 0.03518469813570846, 0.09356044247397222, 0.021380640027928166, 0.033989951698458754, 0.029106447436788585, 0.06496342932223342, 0.08906535047572106, 0.06549000536324456, 0.01978550491912756, 0.01114910643082112, 0.02782704606943298, 0.017872216667456087, 0.03441935092268977, 0.03249290995881893, 0.0574158950621495, 0.04394465679069981, 0.028960530071344692, 0.08781911383266561, 0.06864757655421272, 0.04331770156568382, 0.030749972429475747, 0.007546539782197215, 0.0200641813717084, 0.04848155767831486, 0.03838294644083362, 0.03655605345556978, 0.035163532083970495, 0.031740053091198206, 0.04590378564898856, 0.06527620003907941, 0.03269368316978216, 0.008270249727502232, 0.031108027142181527, 0.14798576070461422, 0.019166186393704265, 0.019035915356653277, 3.130885222926736, 12.853234000504017, 34.05694171786308, 45.457439571619034, 43.982738703489304, 39.90316741168499, 28.09709072113037, 19.196416027843952, 18.991631716489792, 17.940057143568993, 24.368394501507282, 21.40664342790842, 17.919718734920025, 13.784203045070171, 7.638921048492193, 4.694744031876326, 1.9580875360406935, 0.5580470804125071, 0.26145322364754975, 0.051999389615957625, 0.2646288141841069, 0.26119341258890927, 0.08149477624101564, 0.7392550818622112, 1.2085967534221709, 0.6721306743565947, 2.878360510803759, 2.0577308954671025, 3.155463491566479, 3.7776774913072586, 8.37592190131545, 2.9208985157310963, 5.867695491760969, 9.66155156493187, 0.8459296671207994, 2.1933840913698077, 0.923150785965845, 0.46689584967680275, 0.18035236455034465, 1.507088786456734, 2.5758881913498044, 4.547197474166751, 0.46022670285310596, 11.695215739309788, 12.800984904170036, 0.5070079222787172, 1.8223727121949196, 5.9271869994699955, 3.526661298237741, 4.217778900638223, 4.979059025645256, 5.758987599983811, 4.064222490414977, 2.048042365349829, 2.8772281715646386, 2.030089753679931, 1.321288850158453, 0.8918854699004441, 0.6709361728280783, 0.22584246966289356, 0.18200968421297148, 0.6988547591026872, 0.9224925306625664, 2.7131489384919405, 5.9005979262292385, 9.854053035378456, 13.412736877799034, 14.699781965464354, 18.538205847144127, 49.56460498273373, 39.448909386992455, 18.99044618010521, 29.663807451725006, 31.984285935759544, 22.108902744948864, 13.29317819327116, 2.041814737021923, 0.09280921090976335, 0.012765394603775349, 0.06495272013125941, 0.047398211318068206, 0.004207534821034642, 0.018373474340478424, 0.04456019036297221, 0.0665471279353369, 0.017875534067570698, 0.05608010716969147, 0.02965669056720799, 0.0566505515598692, 0.03542301288689487, 0.04909833805868402, 0.05576814910455141, 0.04793890671862755, 0.022413069491449278, 0.05824791682243813, 0.03591680455429014, 0.029223549063317478, 0.04557898842904251, 0.015921244012133684, 0.11201686851563863, 0.06053093005903065, 0.02205546563345706, 0.015227795138343936, 0.036620609171222895, 0.038921645464142784, 0.03671799007861409, 0.05930123588768765, 0.04866825605859049, 0.02007511877309298, 0.029249937979329843, 0.018126504292013124, 0.013598881178040756, 0.02835527153365547, 0.05379443333367817, 0.032990312174661085, 0.013851538860762957, 0.036390450623002835, 0.05715959065128118, 0.03608826293202583, 0.05072889216535259, 0.05732586141675711, 0.0315493879315909, 0.07103368523530662, 0.11218228581128642, 0.2743022044887766, 0.1955353404628113, 0.24212909338530153, 0.15000713348854333, 0.10107436857651919, 0.11738428089302033, 0.20279961550841108, 0.196584410732612, 0.15885800152318552, 0.2199619438033551, 0.15641747857443988, 0.166176215861924, 0.22754890465876088, 0.2149303606711328, 0.23423529899446294, 0.18180124461650848, 0.2761042577913031, 0.17595260142115876, 0.13885916996514425, 0.09579512334312312, 0.17116046481532976, 0.13581299514044076, 0.16415338846854866, 0.1921610176214017, 0.10196067843935452, 0.1646594886551611, 0.14407162932911888, 0.13333192124264315, 0.10629694341332652, 0.10079952160594985, 0.11338015669025481, 0.10893792044953443, 0.15194054692983627, 0.19093187263933942, 0.31229440646711737, 0.2157279764651321, 0.1571123514440842, 0.10645191126968712, 0.09877183314529248, 0.0986754875339102, 0.15913369454210624, 0.152228188526351, 0.13975854904856533, 0.10231124673737213, 0.2181997141451575, 0.17284916248172522, 0.21956679469440132, 0.1495854600216262, 0.0881690438836813, 0.2577314421068877, 0.08765358521486633, 0.1407430079416372, 3.019693926908076, 13.61224327236414, 38.14923092722893, 49.90958087146282, 54.3877849727869, 49.58945944905281, 38.9522760361433, 25.542337708175182, 27.268936559557915, 26.076503545045853, 30.16776490956545, 29.699018262326717, 23.264067359268665, 16.38898227363825, 9.738473687320948, 5.047547975555062, 2.8420102363452315, 1.4838512521237135, 0.7725614227820188, 0.5462542944587767, 1.3963310234248638, 1.5341024869121611, 2.692278795875609, 2.021665843203664, 4.066005544736981, 3.017619475722313, 8.4345119073987, 8.818123172968626, 9.506960660219193, 11.610732022672892, 9.96135737746954, 3.0102941812947392, 9.305287431925535, 16.42146673053503, 2.1791260689496994, 2.976868087425828, 0.48001903924159706, 0.8444017334841192, 1.4279200346209109, 1.8626043596304953, 3.2521162927150726, 5.066002160310745, 0.43211097246967256, 14.844427853822708, 21.220461018383503, 0.4759557213401422, 1.0579186887480319, 4.2490369733422995, 3.7294982140883803, 8.043910916894674, 14.185256324708462, 13.482970409095287, 12.850223612040281, 7.83458442427218, 9.689572211354971, 9.40349506214261, 7.799221146851778, 7.017284380272031, 3.295453442260623, 1.4648698456585407, 0.9841504564974457, 1.3923820853233337, 1.459746533073485, 3.084031124599278, 5.881983675062656, 10.767194386571646, 19.974806159734726, 20.419179014861584, 31.238245368003845, 59.69226993620396, 44.538831263780594, 28.17663185298443, 37.83237732946873, 37.05264776945114, 26.73888210207224, 12.649028208106756, 2.3367874464020133, 0.17496780114015564, 0.132045823847875, 0.13012850016821176, 0.10000792462960817, 0.07883276673965156, 0.11097254799096845, 0.10410085422336124, 0.13457175315124914, 0.23935684526804835, 0.11587734261411242, 0.12935114500578493, 0.12801277072867379, 0.10397423640824854, 0.1941718815942295, 0.16155220539076254, 0.1834628390497528, 0.1637373404810205, 0.16073962789960206, 0.09520757244899869, 0.13774945138720796, 0.23009326891042292, 0.08637853097752668, 0.20218554767780006, 0.21207426470937207, 0.0759566253691446, 0.09568007561028935, 0.19178958755219355, 0.10399993698229082, 0.1270929677411914, 0.09426806544070132, 0.17693815869279206, 0.12628839060198516, 0.11503147237817757, 0.126165505789686, 0.12251029489561915, 0.160674704820849, 0.13963125587906688, 0.15147330559557304, 0.13487673131749034, 0.11961027863435447, 0.1860836148262024, 0.14977972459746525, 0.14194919087458402, 0.14322325063403696, 0.23647830676054582, 0.24981026246678084], [0.04708177439169958, 0.06182728393469006, 0.02749688683252316, 0.027171074725629296, 0.01300143560001743, 0.010074628735310398, 0.01742776483297348, 0.006955883927730611, 0.018722077802522108, 0.07098846617736854, 0.0027676196668835473, 0.044476450129877776, 0.09089321567444131, 0.04397281758429017, 0.08721142105059698, 0.06885773051180877, 0.07211414093035273, 0.06256549080717377, 0.02023188633756945, 0.04859651264268905, 0.014691517371829832, 0.048492263158550486, 0.031056382940732874, 0.05931574116402771, 0.01890505987830693, 0.06817549641709775, 0.032826334645505995, 0.01292001457841252, 0.09388570353621617, 0.055930968883330934, 0.05225009823334403, 0.047423125215573236, 0.06175993774377275, 0.03852747970086057, 0.10676201025489718, 0.02126817125827074, 0.009099293620238313, 0.026846527980524115, 0.03691343837999739, 0.05901755364902783, 0.03357377012434881, 0.032968552404781803, 0.06700260622892529, 0.034983776495209895, 0.08134455812978558, 0.09845776367001235, 0.09756320112501271, 0.015440885217685718, 0.05674723113770597, 0.03961688569688704, 0.08845975797157735, 0.11566977875190787, 0.10458861594088376, 0.02853360776498448, 0.5448558507487178, 6.3798196613788605, 21.303279474377632, 36.376360058784485, 46.80005572736263, 41.88228361308575, 33.46647620201111, 24.90686170756817, 29.598975330591202, 22.268820963799953, 18.000145219266415, 12.740239463746548, 10.762260351330042, 10.538411512970924, 13.077568262815475, 8.005950003862381, 4.648819221183658, 2.1132283424958587, 1.105091969948262, 0.4309268610086292, 0.4481018503429368, 0.3236819204175845, 0.623103033285588, 0.9164742473512888, 1.189053333364427, 1.7832174757495522, 0.8367082150653005, 2.4672311218455434, 2.5911849830299616, 4.5520061161369085, 5.773787805810571, 5.687388041988015, 3.7937596533447504, 1.0558093269355595, 2.0663371961563826, 0.9110474854242057, 0.5489861103706062, 0.6582949636504054, 2.253618696704507, 2.477512420155108, 2.7248252369463444, 0.5263566027861089, 5.448478236794472, 41.948483660817146, 3.1909960974007845, 1.5375085291452706, 2.9310615453869104, 4.244547039270401, 3.9410995971411467, 2.081416449509561, 5.484302239492536, 2.4699731497094035, 0.9899595135357231, 3.2776979450136423, 0.7542403496336192, 1.7166932579129934, 0.26129535399377346, 0.6182082428131253, 0.39573810703586787, 0.7279176777228713, 1.2672756984829903, 3.967607212252915, 6.213607080280781, 9.47551829740405, 17.397068180143833, 18.527577817440033, 24.699225649237633, 29.815364219248295, 43.19843038916588, 31.371458619832993, 28.04357249289751, 28.436304219067097, 19.927753284573555, 11.94937840104103, 1.4038062910549343, 0.14561007177690044, 0.024823338790156413, 0.08649656214402057, 0.042186349382973276, 0.018186636807513423, 0.01768546262610471, 0.034813130769180134, 0.03361322269483935, 0.019733754961634986, 0.013923292481194949, 0.02752942258666735, 0.047197063322528265, 0.048895728032221086, 0.02659664871316636, 0.028576015938597266, 0.053729933279100806, 0.014034636897122255, 0.0447685854305746, 0.03387759054021444, 0.1392695034155622, 0.057055571232922375, 0.04936757068207953, 0.08182504680007696, 0.11024005565559492, 0.037027090875199065, 0.06014108359522652, 0.0362428819789784, 0.03237234806874767, 0.04245050571626052, 0.0388826901325956, 0.05925814308284316, 0.014550833075190894, 0.03338630362122785, 0.02330988074390916, 0.04936183016980067, 0.015896190961939283, 0.02042839962086873, 0.014239598604035564, 0.06684215390123427, 0.011561163519218098, 0.023842167611292098, 0.04110750785912387, 0.051971778011647984, 0.018496630036679562, 0.027811969339381903, 0.1227390619169455, 0.020193572963762563, 0.06294933700701222, 0.04185857986158226, 0.044334128469927236, 0.03852379122690763, 0.03665108546556439, 0.01897189584269654, 0.027984971384285018, 0.044824840224464424, 0.06589429773157462, 0.04693060262070503, 0.07107721219654195, 0.07249161208164878, 0.06555404528626241, 0.020796603203052655, 0.17019363935105503, 0.04680970676417928, 0.037008166109444574, 0.02917199206422083, 0.014320276550279232, 0.015882377738307696, 0.023874272919783834, 0.04649539238016587, 0.059298152264091186, 0.07030689259408973, 0.015420686740981182, 0.024535205520805903, 0.02368082099565072, 0.023317582381423563, 0.0396289344644174, 0.06962635059608147, 0.06075532211980317, 0.06021130560839083, 0.042348671922809444, 0.03366808596183546, 0.019227292978030164, 0.0683088529331144, 0.007094650236467714, 0.026215155121462885, 0.04738622563309036, 0.11224369853152893, 0.022690116929879878, 0.04570260425680317, 0.1000524460687302, 0.03722239074704703, 0.02921909803262679, 0.08049462834605947, 0.030257852449722122, 0.04397253927891143, 0.03892617627570871, 0.04666991582780611, 0.087744928750908, 0.02172884087485727, 0.05074945336673409, 0.09996027132729068, 0.8321056526619941, 9.71059363335371, 26.55682437121868, 43.57906736433506, 51.57449573278427, 42.8380311280489, 32.85367168486118, 24.669554941356182, 23.643938675522804, 24.069002866744995, 23.460283130407333, 21.24609064310789, 17.885279282927513, 13.302766978740692, 13.73456820845604, 8.913089577108622, 5.993853472173214, 1.9472924340516329, 0.7610275573097169, 0.2296189178014174, 0.17807843891205266, 0.2328434752416797, 0.2979646628955379, 0.18992329394677654, 0.6257320765871555, 0.6128291564527899, 1.4294900628738105, 2.0361326169222593, 4.0289651323109865, 3.76245123334229, 4.655247051268816, 3.0346304504200816, 3.1778765888884664, 1.9412126415409148, 1.8031659303233027, 2.2674012696370482, 0.6389170128386468, 1.306728150229901, 3.558500027284026, 2.5630833534523845, 3.4658334497362375, 1.0501804039813578, 5.658264979720116, 44.98213827610016, 3.061830340884626, 1.1628556391224265, 4.39531059935689, 5.807939423248172, 4.235885879024863, 3.7411196529865265, 3.6455098958685994, 2.7131508383899927, 1.567446410190314, 1.357398193795234, 0.8618758677039295, 0.4442296799970791, 0.4768970614532009, 0.18773703079205006, 0.3904715005774051, 0.6554777116980404, 1.6792499483563006, 5.343597214668989, 9.286069013178349, 12.766933981329203, 20.88136911392212, 22.13026899844408, 16.72619517892599, 27.452892288565636, 47.99715109169483, 34.60725098848343, 31.068721264600754, 32.35788568854332, 25.503006018698215, 13.709067776799202, 1.9947549747303128, 0.11467390562756918, 0.042022590787382796, 0.06680088306893595, 0.04894734811387025, 0.038309562878566794, 0.05997908388962969, 0.03044004042749293, 0.02861131990357535, 0.001949320217136119, 0.042025563088827766, 0.053789857993251644, 0.04290410266548861, 0.027566849094000645, 0.08171039240551181, 0.029027679593127687, 0.08728231841814704, 0.05279553595755715, 0.05878264164493885, 0.01832063528127037, 0.031210092856781557, 0.06729313477990218, 0.001476347763400554, 0.01846055794885615, 0.08763192192418501, 0.026959078386425972, 0.01572400527948048, 0.025931287345883902, 0.08138048549881205, 0.010951006806863006, 0.0093319253755908, 0.030911304202163592, 0.046267950092442334, 0.006690590716971201, 0.059314353347872384, 0.02791618728224421, 0.054072278580861166, 0.10299784466042183, 0.04900547311990522, 0.0274892204470234, 0.04635436576791108, 0.029671856354980264, 0.037497044759220444, 0.027857980639964808, 0.03841184938210063, 0.025791975094762165, 0.09197293664328754, 0.02252919519378338, 0.19427281367825344, 0.1546481391415, 0.15287416870705783, 0.09686180477729067, 0.07065170924761333, 0.20747934642713517, 0.13595318683655933, 0.1232413252000697, 0.17856349179055542, 0.1137139079219196, 0.1891732498188503, 0.12475248629925773, 0.20854591653915122, 0.1389961555832997, 0.3149017196847126, 0.18348832440096885, 0.16938986373133957, 0.16819361073430628, 0.08766650600591674, 0.12162132814410143, 0.20506845001364127, 0.16165959415957332, 0.21934254735242575, 0.15130992920603603, 0.17829778807936236, 0.09807085240026936, 0.12300914429943077, 0.06894336693221703, 0.12329636287176982, 0.22773824137402698, 0.1383642465225421, 0.15051209076773375, 0.09986549164750613, 0.09247075446182862, 0.21594892867142335, 0.13614819356007501, 0.08601127919973806, 0.14325976429972798, 0.12246149868587963, 0.19612301752204075, 0.11587363929720595, 0.14318878529593349, 0.2106167608872056, 0.19666436972329393, 0.18340363050810993, 0.2135354495840147, 0.20675205654697493, 0.10320675180992112, 0.24221341620432213, 0.16639167617540807, 0.24985131807625294, 0.24374121625442058, 0.3042570361867547, 0.2181243267841637, 1.3191315159201622, 10.12826532125473, 29.495130702853203, 47.83001326024532, 60.51948554813862, 54.738973528146744, 44.38022777438164, 34.49115961790085, 38.95277380943298, 31.932464316487312, 29.94824878871441, 26.13457962870598, 20.38098156452179, 17.555922456085682, 18.02283950150013, 10.76595850288868, 6.318337060511112, 2.9508981434628367, 1.4462964423000813, 0.8510461519472301, 0.8832666417583823, 0.5963022401556373, 1.5745237679220736, 2.3716548504307866, 3.6237750621512532, 5.885230600833893, 4.708822276443243, 7.416727971285582, 7.489521615207195, 9.811735656112432, 13.933565430343151, 11.150438971817493, 10.41031088680029, 3.9863071963191032, 7.007263842970133, 3.7093063350766897, 1.6124548763036728, 1.7464160942472517, 5.195249374955893, 4.26236760802567, 6.980015505105257, 1.7037243163213134, 10.760420300066471, 52.94197395443916, 6.057775067165494, 3.5985916759818792, 4.825727278366685, 9.018874950706959, 10.651972219347954, 8.303845468908548, 11.47357838228345, 8.47756264731288, 5.535860247910023, 7.840595226734877, 4.221890280023217, 4.206708669662476, 1.3302550627849996, 1.618869169615209, 1.0311194392852485, 0.9985912847332656, 2.3484516330063343, 5.667428188025951, 9.830377455800772, 13.308692760765553, 24.538594968616962, 29.36428852379322, 32.61417433619499, 37.77869001030922, 54.57482993602753, 41.18026368319988, 37.73250348865986, 40.81139847636223, 29.025878682732582, 14.900490995496511, 1.9775572163052857, 0.24440439941827208, 0.10901667716098018, 0.17599969811271876, 0.12638096610317007, 0.11856568351504393, 0.13834477256750688, 0.16944595525274053, 0.1256662333616987, 0.08677770252688788, 0.08661500149173662, 0.24161987617844716, 0.11681816322379746, 0.07463391782948747, 0.2016697550425306, 0.10105695779202506, 0.19632934941910207, 0.16975513397483155, 0.12918907479615882, 0.13843210850609466, 0.19679504708619788, 0.14861532457871363, 0.11840019942610525, 0.10751517140306532, 0.2166557204327546, 0.14205902873072773, 0.1863657496869564, 0.1443792346981354, 0.18224843312054873, 0.17770987353287637, 0.15127776452573016, 0.1771989048575051, 0.07705217634793371, 0.13736099645029753, 0.10424777719890699, 0.14274756365921348, 0.14324397139716893, 0.12250233165104873, 0.24562891339883208, 0.18949464429169893, 0.09034167378558777, 0.10763928075903095, 0.1507480937289074, 0.13128999096807092, 0.11278257195954211, 0.09784441572264768, 0.269354751217179, 0.09296305812313221], [0.005485749215949909, 0.018944326911878306, 0.0307988057465991, 0.022931554267415777, 0.024783142216620035, 0.056982491951202974, 0.03427041301620193, 0.026636485345079564, 0.034004193512373604, 0.01655337015108671, 0.03613779386796523, 0.04428340638696682, 0.024279346398543566, 0.03696574865898583, 0.03174929654051084, 0.0325801605504239, 0.032714081098674797, 0.034018275764537975, 0.03312409171485342, 0.03859839191136416, 0.01292206383368466, 0.06759406081982888, 0.06547706230776384, 0.010883836876018904, 0.01532550444608205, 0.07897797535406426, 0.041569698878447525, 0.011468639040685957, 0.04648834568797611, 0.0051983242337882984, 0.015060556797834579, 0.036586355345207267, 0.0048016017717600334, 0.05861910569365136, 0.013407583337539108, 0.04826017131563276, 0.0708410533843562, 0.09684920310974121, 0.08619881991762668, 0.023890498123364523, 0.042582582027534954, 0.022214687851374038, 0.019218880734115373, 0.08720204772544093, 0.03541219237376936, 0.07380433031357825, 0.10172748821787536, 0.01720528380246833, 0.049223152454942465, 0.03238558056182228, 0.02382077891525114, 0.1041443737631198, 0.10337251791497692, 0.058853464797721244, 0.13425209530396387, 0.3338231606176123, 4.909772118553519, 14.624734092503786, 30.87039850652218, 38.11646148562431, 38.41478727757931, 35.737302750349045, 30.722540840506554, 24.651346318423748, 18.240146040916443, 23.05109068751335, 28.968967236578465, 32.44466543197632, 26.466442421078682, 19.18302744626999, 10.330089591443539, 10.247304383665323, 5.302555616945028, 2.8085000719875097, 1.10975562594831, 0.5136769206728786, 0.3700200479943305, 0.31525982078164816, 0.06921642532688566, 0.6715205102227628, 1.68766756542027, 0.5606567091308534, 3.0842707492411137, 5.09709351696074, 1.7584528983570635, 1.0554826632142067, 0.9790827753022313, 1.6329912305809557, 0.9625914820935577, 4.939283709973097, 0.4643756942823529, 0.9281019796617329, 1.3133420515805483, 2.6473367074504495, 1.7371993325650692, 1.2670111376792192, 0.4479135823203251, 14.196894150227308, 9.584106970578432, 1.2353162071667612, 4.960057195276022, 5.602253135293722, 2.2610112000256777, 2.317303279414773, 1.1334453360177577, 1.8963383557274938, 0.46942022047005594, 0.9760479256510735, 0.279189157881774, 0.1715361251262948, 0.5302641587331891, 0.8264460344798863, 1.5779340849258006, 3.8469192758202553, 6.936189131811261, 9.327893368899822, 15.893845092505217, 19.954593144357204, 11.903144381940365, 8.6708221770823, 14.93316924199462, 22.53627721220255, 30.492985658347607, 33.130771815776825, 27.240757271647453, 22.06279791891575, 9.87552473321557, 2.3958645388484, 0.1490946629201062, 0.03550584027834702, 0.03866160805046093, 0.10536483561736532, 0.03902463700796943, 0.03426246461458504, 0.03853308291581925, 0.03820934325631242, 0.03418623862671666, 0.02293417590408353, 0.0510631035285769, 0.05247712120763026, 0.034033445263048634, 0.0874450862465892, 0.016726533613109495, 0.047048748820088804, 0.03059057951759314, 0.07105459895683452, 0.04260958878148813, 0.00683290356391808, 0.021399273500719573, 0.055785044096410275, 0.04748489045596216, 0.06255576125113294, 0.045827374124201015, 0.06696302007185295, 0.048964157758746296, 0.015113015506358352, 0.03579997566703241, 0.09058190698851831, 0.04572219324472826, 0.049539563406142406, 0.02087704458972439, 0.0007456220293988736, 0.07326055128942244, 0.03239716177631635, 0.042878635867964476, 0.006164086107673938, 0.03344226897752378, 0.030393819470191374, 0.03128961026959587, 0.0345583551825257, 0.03074662348808488, 0.06819351576268673, 0.02838918397173984, 0.048691848933231086, 0.03533130569849163, 0.03892439512128476, 0.02653665535035543, 0.03563232450687792, 0.01680034947639797, 0.07830567861674353, 0.03608270795666613, 0.01069893449312076, 0.010055050879600458, 0.03614256958826445, 0.024090822334983386, 0.02877504510252038, 0.035395456943660975, 0.06414570132619701, 0.05349396000383422, 0.07762597524560988, 0.0046675323301315075, 0.0687995387124829, 0.05577686562901363, 0.09856812102952972, 0.0025753057798283407, 0.06220635441422928, 0.056141104287235066, 0.02452131808240665, 0.03432299788983073, 0.0320744017517427, 0.023985452207853086, 0.039504602464148775, 0.03192103322362527, 0.04167618593783118, 0.09515749974525534, 0.01260969387658406, 0.020515666910796426, 0.020944607858837117, 0.043648358041536994, 0.07817887526471168, 0.02368894565734081, 0.04869711076025851, 0.017604768909222912, 0.07392792016617022, 0.03162796652759425, 0.045029086686554365, 0.0065347995405318215, 0.02142915422155056, 0.05148874748556409, 0.03612193417211529, 0.019099148194072768, 0.07585187122458592, 0.09008411143440753, 0.027261915456620045, 0.08094898599665612, 0.042780735457199626, 0.027127577450301033, 0.017391566580045037, 0.03399584806174971, 0.10671993048163131, 0.14480829995591193, 0.5977084022015333, 7.202532039955258, 19.620693661272526, 37.56164185702801, 44.63195666670799, 41.53621718287468, 37.457922622561455, 33.654493913054466, 24.070819169282913, 21.134562827646732, 24.424393996596336, 26.56715601682663, 34.95601527392864, 29.5783082395792, 21.128958128392696, 13.209649175405502, 11.709099244326353, 5.661843437701464, 2.757831928320229, 0.9451410372275859, 0.31971442862413824, 0.26910316315479577, 0.07089986116625369, 0.04576251783873886, 0.3283585491590202, 0.5662317224778235, 0.6783672678284347, 1.0638139536604285, 1.817838130518794, 1.0854450054466724, 1.492681265808642, 1.5752789773978293, 1.5819226833991706, 2.364007760770619, 2.7437501214444637, 1.4223589142784476, 1.8384036957286298, 2.7564188791438937, 1.9221414648927748, 3.4106601728126407, 0.7626845652703196, 3.760570571757853, 23.19078639149666, 10.09439678862691, 0.44190007844008505, 4.3201591819524765, 6.658654399216175, 2.4080953700467944, 1.078274433966726, 1.0583659959957004, 0.9817740402650088, 0.47061160497833043, 0.2165979813435115, 0.0573626014374895, 0.24630055704619735, 0.24739329528529197, 0.5625593976583332, 1.345456859562546, 4.104566350579262, 8.855372574180365, 13.063552714884281, 17.87675254046917, 17.44204256683588, 15.659512616693974, 12.852461691945791, 18.518488705158234, 24.95595697313547, 35.6853823363781, 35.50129361450672, 31.386726200580597, 26.007554344832897, 12.14047584682703, 3.0460521625354886, 0.2531242783879861, 0.01464735587433097, 0.012605477550096111, 0.06484934638137929, 0.04280559369362891, 0.028508959185273852, 0.03671902166388463, 0.12088513991329819, 0.01686386804067297, 0.026699606860347558, 0.08707039814908057, 0.039657299348618835, 0.029826779682480264, 0.03876489645335823, 0.05155066857696511, 0.02882701955968514, 0.03138892447168473, 0.09116532412008382, 0.050946478731930256, 0.05037659837398678, 0.028528883995022625, 0.058277899588574655, 0.027952869786531664, 0.014349925349961268, 0.020078977941011544, 0.04386067535961047, 0.061947214999236166, 0.07456193692632951, 0.04716664268926252, 0.035319672533660196, 0.05974697349302005, 0.09419198788236827, 0.00997159080725396, 0.03124115915852599, 0.03162230394082144, 0.05141895962879062, 0.018498570752853993, 0.01388798944390146, 0.07287660861038603, 0.024979386471386533, 0.06639004495809786, 0.05201918269449379, 0.040446521452395245, 0.041523682011757046, 0.047760383095010184, 0.0426570899435319, 0.03241198617615737, 0.04312983430281747, 0.1125835205311887, 0.1561153947841376, 0.042997513082809746, 0.11871979048009962, 0.16385979484766722, 0.19030052761081606, 0.17571950767887756, 0.1533823469071649, 0.1299331965856254, 0.13603399187559262, 0.14818185096373782, 0.2353731746552512, 0.10447548294905573, 0.13908334309235215, 0.15026692970423028, 0.20622170297428966, 0.1898520180839114, 0.14426837267819792, 0.17188543919473886, 0.1558184763416648, 0.2218364307191223, 0.128701958747115, 0.24093689251458272, 0.11234687190153636, 0.19462402764474973, 0.1895230685477145, 0.11978584851021878, 0.1026869664201513, 0.17890508752316236, 0.13350614783121273, 0.10748804590548389, 0.19632652925793082, 0.11721841088728979, 0.13178387540392578, 0.14972511737141758, 0.20391058089444414, 0.1995968772098422, 0.170896468043793, 0.13967300910735503, 0.18615877954289317, 0.13304236490512267, 0.06358896440360695, 0.1213087206997443, 0.13762319722445682, 0.3277246659854427, 0.1577472290955484, 0.22498886624816805, 0.09858597710262984, 0.19218757166527212, 0.09247782712918706, 0.12686364410910755, 0.22874771064380184, 0.1990418546483852, 0.26740952278487384, 0.21838498389115557, 0.5825578432995826, 7.830982217565179, 21.270112954080105, 40.8110336959362, 49.72131237387657, 51.98285222053528, 46.00206434726715, 40.907506719231606, 35.73428191244602, 27.635768875479698, 35.77948808670044, 39.71861131489277, 43.18585306406021, 36.36866167187691, 24.183336831629276, 14.16813064366579, 13.042266257107258, 7.778213499113917, 4.1701242327690125, 1.97381311096251, 1.3678583200089633, 0.8026047481689602, 0.8730198384728283, 0.3789263841463253, 2.192501351237297, 3.0447941925376654, 2.3260879330337048, 5.984836081042886, 13.345841467380524, 5.889097843319178, 4.718630500137806, 3.808552259579301, 6.934936624020338, 5.498784687370062, 12.663431335240602, 4.494026452302933, 2.8163779992610216, 6.763962898403406, 6.1787928733974695, 9.258810225874186, 3.593310909345746, 4.3626556266099215, 25.29734395444393, 14.526348821818829, 3.087106109596789, 13.52783840149641, 17.388402745127678, 7.3543476685881615, 6.558132218196988, 4.6865027491003275, 4.767560474574566, 2.9502868512645364, 2.3473140690475702, 1.5576668037101626, 0.7296521065291017, 1.171734337694943, 1.0654872888699174, 2.589090820401907, 5.0303111504763365, 9.529435504227877, 13.005738817155361, 23.416137099266052, 26.571210399270058, 19.280763901770115, 17.516005598008633, 23.279899209737778, 31.68594304472208, 41.476305797696114, 44.16514031589031, 37.356684654951096, 29.816519357264042, 12.556701712310314, 3.985722027719021, 0.41544833220541477, 0.1544157281750813, 0.13682005985174328, 0.28211503056809306, 0.21105862077092752, 0.10391476069344208, 0.05381611146731302, 0.19998218544060364, 0.09741725778440014, 0.10833891079528257, 0.14887722849380225, 0.1582763358601369, 0.10825374934938736, 0.15679477161029354, 0.09392056221258827, 0.14237350638723, 0.09982358256820589, 0.3095384855987504, 0.11827522175735794, 0.09101173665840179, 0.13351742847589776, 0.1970178249757737, 0.10825326695339754, 0.15420491370605305, 0.12603208248037845, 0.13057380361715332, 0.18020531540969387, 0.19785109354415908, 0.07235925746499561, 0.14449207083089277, 0.1702661026502028, 0.16923917806707323, 0.12763702135998756, 0.1287537458119914, 0.14408675429876894, 0.09903412297717296, 0.10719359139329754, 0.10887045180425048, 0.08834665466565639, 0.1635409682057798, 0.17500091576948762, 0.17545251263072714, 0.17800676228944212, 0.140599150035996, 0.20293673471314833, 0.1462689059553668, 0.1353402915992774, 0.1228865711891558], [0.04329408271587454, 0.014069718217797345, 0.02164792822441086, 0.0428077199467225, 0.019795095322479028, 0.018887932965299115, 0.05193469660298433, 0.053952161979395896, 0.08883626433089375, 0.0570250244345516, 0.04469200692255981, 0.01760708440997405, 0.05087176672532223, 0.019890993789886124, 0.028096464229747653, 0.042593814432621, 0.0404959967272589, 0.05679329624399543, 0.005536075177587918, 0.07457508036168292, 0.019806294330919627, 0.010977782567351824, 0.08548111858544871, 0.06707053500576876, 0.013147254630894167, 0.030534317302226555, 0.013862742507626535, 0.005775974877906265, 0.023412859300151467, 0.01876058227935573, 0.050556417045299895, 0.1484903320670128, 0.010959888459183276, 0.012596526321431156, 0.01737890182994306, 0.0584937198436819, 0.04140785131312441, 0.0771444253041409, 0.03753733966732398, 0.01218253686602111, 0.06624553396250121, 0.01858297149738064, 0.0639230792876333, 0.017399759890395217, 0.02197759022237733, 0.035494641269906424, 0.047843459105934016, 0.11658956689643674, 0.04629595874575898, 0.10171593297854997, 0.04654762102290988, 0.032837626422406174, 0.037954986983095296, 0.023716496034467127, 0.019101934958598576, 0.04151676890614908, 0.17549687821883708, 2.634552293457091, 9.890429433435202, 26.270211450755596, 35.261439085006714, 47.33209937810898, 33.88053238391876, 39.1195772588253, 24.79885060340166, 32.17628203332424, 21.028694808483124, 23.211478181183338, 38.968888744711876, 25.773811787366867, 24.35706350952387, 13.338357768952847, 14.686113148927689, 10.477921608835459, 8.001984916627407, 4.01137207634747, 2.097939387895167, 0.6941538769751787, 0.838214656105265, 0.309144850471057, 0.41341933014336973, 0.6973026611376554, 1.3952920166775584, 0.8079270157031715, 0.9413268731441349, 1.6450146166607738, 0.792491293977946, 1.3550274772569537, 1.1465766001492739, 0.6293149874545634, 0.27869901387020946, 2.3995332419872284, 1.8688891036435962, 1.6517635295167565, 1.218032834585756, 0.8004090597387403, 0.562106806319207, 2.8737040981650352, 3.36808820720762, 0.3718210622901097, 5.589710483327508, 3.5331157268956304, 2.3848463175818324, 1.5793524775654078, 1.0556825087405741, 0.7491805055178702, 0.6971547065768391, 0.49330680747516453, 0.41397899854928255, 1.0303964093327522, 2.529924432747066, 4.453866882249713, 7.2569546196609735, 13.251580875366926, 11.586432326585054, 12.863422203809023, 16.740742698311806, 22.038142941892147, 20.418495051562786, 16.491510272026062, 20.27782279998064, 25.26393234729767, 31.82119108736515, 29.565318636596203, 20.374717600643635, 9.148961920291185, 3.0169257754459977, 0.08421684033237398, 0.002879724320337118, 0.059235641165287234, 0.05055060602899175, 0.06999240751611069, 0.08577653046813793, 0.017274939928029198, 0.0929092598380521, 0.04894840567430947, 0.02930633749201661, 0.03155292055453174, 0.020755087462021038, 0.030756028354517184, 0.0463188836874906, 0.05903797013161238, 0.0556265510385856, 0.043230068768025376, 0.022694081853842363, 0.060029442320228554, 0.02244916384370299, 0.04504458644078113, 0.07535026845289394, 0.024589335916971322, 0.0284737368565402, 0.054260030810837634, 0.049279084414592944, 0.029720214697590563, 0.059288556294632144, 0.04823814808332827, 0.010591244226816343, 0.05109768761030864, 0.11062318939366378, 0.016785048246674705, 0.09350328225991689, 0.0292227252793964, 0.03488549387839157, 0.018831470370059833, 0.010289038909832016, 0.044466234467108734, 0.04241342059685849, 0.04946857698087115, 0.01120699487728416, 0.0377243942784844, 0.055410281784133986, 0.01383040898872423, 0.04053244359965902, 0.025614733531256206, 0.022404403061955236, 0.03375919572135899, 0.017177011686726473, 0.021156221991986968, 0.03853211070236284, 0.04449627289432101, 0.04225078264425974, 0.03872301705996506, 0.017273171761189587, 0.11129626538604498, 0.04304102520109154, 0.0462525097100297, 0.023982004931895062, 0.0671882247843314, 0.018202199644292705, 0.06847968048532493, 0.014681696902698604, 0.026563786414044444, 0.06395495453034528, 0.04257628861523699, 0.018747492649708875, 0.052889436192344874, 0.012131581006542547, 0.015550185944448458, 0.11356728180544451, 0.06349194343783893, 0.027840131988341454, 0.04612022188666742, 0.039421437395503744, 0.0517052171198884, 0.0346661595540354, 0.04078062149346806, 0.022714774786436465, 0.05470312637044117, 0.04543262577499263, 0.08954895616625436, 0.040299527972820215, 0.04705501996795647, 0.05080597162304912, 0.05479765372001566, 0.019577978164306842, 0.054961052373982966, 0.03477413090877235, 0.015028428297227947, 0.06496139583759941, 0.058327760780230165, 0.018506981141399592, 0.030665623635286465, 0.07788289192831144, 0.0583542443200713, 0.029596155436593108, 0.010331335761293303, 0.04505838667682838, 0.02753454897174379, 0.06477376606198959, 0.028964949560759123, 0.03316902875667438, 0.003306381772745226, 0.4574373853392899, 4.26935400813818, 14.009099677205086, 31.392017416656017, 42.19272315502167, 51.688523814082146, 38.482932820916176, 38.55355203151703, 27.66326989978552, 30.531865172088146, 27.700431905686855, 33.44704404473305, 43.08361575007439, 25.216087214648724, 24.357804469764233, 17.836292311549187, 16.48933108896017, 13.928288463503122, 8.91308767721057, 4.439808586612344, 2.447627023793757, 0.8341002487577498, 0.4543729091528803, 0.10713114708778448, 0.13183600385673344, 0.26958273898344487, 0.1459720914135687, 0.22447467665188015, 0.3844391758320853, 0.4963558469898999, 0.2941952651599422, 0.9509860735852271, 1.4195469464175403, 1.0032624215818942, 0.6018696539103985, 0.9901243890635669, 0.49704862700309604, 1.3582785590551794, 0.871971866581589, 1.9704772462137043, 0.4013615974690765, 3.233211594633758, 4.691697545349598, 0.19318478065542877, 1.1851626983843744, 1.2966154678724706, 1.1762616760097444, 0.6272211216855794, 0.5805704311933368, 0.2832936798222363, 0.4403180570807308, 0.38788793608546257, 0.5811923509463668, 1.0228083352558315, 2.8583804704248905, 4.652540171518922, 9.51895946636796, 15.984463579952717, 15.963838286697865, 14.421904776245356, 19.491377100348473, 20.779610574245453, 17.233942933380604, 15.995205603539944, 21.25787191092968, 27.72644340991974, 36.70375049114227, 35.098218843340874, 24.5781147480011, 11.529287192970514, 3.7786960741505027, 0.13878057652618736, 0.02462405915139243, 0.05713107733754441, 0.03831177076790482, 0.026674698528950103, 0.06324776943074539, 0.05020494332711678, 0.03467908776656259, 0.014909144756529713, 0.028270538678043522, 0.035296684509376064, 0.01708732499537291, 0.025406102831766475, 0.04653487092582509, 0.05944078562606592, 0.014949272681406, 0.0646021295688115, 0.048838783040991984, 0.08859597175614908, 0.05529118934646249, 0.013430916460492881, 0.02393419392319629, 0.01288440633288701, 0.047531983436783776, 0.024393698367930483, 0.07509194168960676, 0.044752933536074124, 0.09738072185427882, 0.013329341491044033, 0.10633815487381071, 0.025323978625237942, 0.03869488224154338, 0.03822390048298985, 0.012180844769318355, 0.053187174708000384, 0.04001301815151237, 0.05418993125203997, 0.005195367702981457, 0.006152728001325158, 0.018118791522283573, 0.01481608500398579, 0.03883532997861039, 0.0663664669264108, 0.013923573569627479, 0.017180535032821354, 0.06922829226823524, 0.023356869824056048, 0.01691226163529791, 0.059206378282397054, 0.10754854578408413, 0.12492607464082539, 0.12316561871557496, 0.12065672170137987, 0.155411378655117, 0.09927434133714996, 0.1372899580746889, 0.1910072600003332, 0.1383559641544707, 0.14992003503721207, 0.06936815741937608, 0.1280261145438999, 0.1359357760520652, 0.15565940440865234, 0.1006614969810471, 0.10836816625669599, 0.1913505033007823, 0.1317046140320599, 0.14040181296877563, 0.1276235142722726, 0.09987069410271943, 0.11784197820816189, 0.15136933070607483, 0.19227248820243403, 0.07382110285107046, 0.12083265522960573, 0.11660840260447003, 0.1475252432283014, 0.13544825924327597, 0.13942096091341227, 0.10702663043048233, 0.2788627316476777, 0.10912355384789407, 0.19141913711791858, 0.10715376774896868, 0.18412694247672334, 0.11951887572649866, 0.12849923368776217, 0.18370740639511496, 0.18665266397874802, 0.14332623104564846, 0.12029856865410693, 0.1719239863450639, 0.19314807403134182, 0.18811659479979426, 0.11717979694367386, 0.20114061859203503, 0.2010345656890422, 0.08637048609671183, 0.19600676750997081, 0.18162351509090513, 0.11797873376053758, 0.15693499299231917, 0.10978867401718162, 0.30536452832166106, 0.168741968809627, 0.4712605685926974, 4.655682602897286, 15.452578570693731, 36.35934457182884, 45.954604893922806, 60.389619916677475, 45.72270333766937, 51.4297728985548, 36.17323435842991, 42.38365910947323, 31.761313900351524, 34.45849657058716, 50.60585930943489, 32.64853969216347, 33.312736451625824, 18.67098782211542, 19.663276076316833, 14.292443823069334, 10.433377549052238, 4.589789863675833, 3.006495335139334, 1.23106031678617, 1.0237724147737026, 0.6491151906084269, 0.8938106009736657, 1.2023622379638255, 2.859245161525905, 1.6923419083468616, 3.074871953576803, 2.5716616306453943, 2.9065996455028653, 3.2440281892195344, 2.8248220961540937, 2.853311304934323, 2.315414068289101, 7.0901744440197945, 5.468540685251355, 6.553325476124883, 3.2319647865369916, 2.4374692188575864, 1.8096546758897603, 5.065168105065823, 5.453202808275819, 2.048286027275026, 11.730777081102133, 9.235545974224806, 5.665908744558692, 2.563325115479529, 2.9035184858366847, 1.823696584906429, 1.6886012465693057, 1.1991455918177962, 0.9614667424466461, 1.6139109106734395, 3.5321156680583954, 5.792308486998081, 10.113826096057892, 17.467212416231632, 16.668309085071087, 19.951420314610004, 26.063542440533638, 31.657820753753185, 28.813707567751408, 24.73867703229189, 29.193791672587395, 36.66333965957165, 42.94378325343132, 38.78377787768841, 29.321641512215137, 13.335924949496984, 4.062697347253561, 0.30506306793540716, 0.11580087171751074, 0.15997656650142744, 0.11760274690459482, 0.1154480324476026, 0.16792802576674148, 0.1464223227230832, 0.14643839764175937, 0.10427784160128795, 0.1237359740480315, 0.08832407111185603, 0.1338283289805986, 0.0948453598539345, 0.12261684503755532, 0.1621573229203932, 0.12557252979604527, 0.17230257071787491, 0.12109709728974849, 0.16386101196985692, 0.18347267992794514, 0.12714298849459738, 0.19081421254668385, 0.11292135357507505, 0.18134742131223902, 0.15874005941441283, 0.158718507445883, 0.2438546609482728, 0.17734746797941625, 0.1286534668179229, 0.27503624791279435, 0.10649652176653035, 0.18497085344279185, 0.1394387279287912, 0.15816805651411414, 0.11696064073476009, 0.11616093208431266, 0.12901973153930157, 0.17629922891501337, 0.1446423408924602, 0.16631585836876184, 0.14347906893817708, 0.1479843506240286, 0.14360296307131648, 0.12661824555834755, 0.07117801811546087, 0.13896427291911095, 0.16638676315778866, 0.12973701726878062, 0.08129531663144007], [0.004888830562777002, 0.014504703030979726, 0.036281087741372176, 0.028977399088034872, 0.023681045495322905, 0.045654757996089756, 0.012253236636752263, 0.04128985725401435, 0.029319714703888167, 0.015817862840776797, 0.009999744179367553, 0.008410975769947981, 0.032252261153189465, 0.027118562211398967, 0.07638819166459143, 0.053087600754224695, 0.0323452967859339, 0.044877677428303286, 0.019124720747640822, 0.03648602811153978, 0.033538314019097015, 0.016782133461674675, 0.041015878596226685, 0.018010198618867435, 0.03895482688676566, 0.09788985742488876, 0.04647959205613006, 0.02308533468749374, 0.012423689404386096, 0.028070784064766485, 0.02597986091132043, 0.01102111564250663, 0.05155165934411343, 0.05104059418954421, 0.024864485312718898, 0.00494645601065713, 0.09084081262699328, 0.08713089802768081, 0.03172582983097527, 0.04448622050404083, 0.05974896244879346, 0.01793734383682022, 0.04701315912825521, 0.014878200909151928, 0.035371979101910256, 0.03910779094439931, 0.05227355381066445, 0.019197686851839535, 0.02690897228603717, 0.08266486111097038, 0.022515914461109787, 0.04057683516293764, 0.044075452897232026, 0.04901589287328534, 0.03932971536414698, 0.039604384219273925, 0.05592999295913614, 0.16082213987829164, 0.9441462031099945, 8.164805229753256, 19.240598157048225, 31.818434335291386, 41.796522215008736, 42.798608243465424, 34.96972493827343, 30.161075368523598, 25.281645096838474, 16.453721299767494, 37.263540253043175, 43.980895802378654, 31.708021759986877, 28.48966285586357, 21.849270276725292, 18.817893639206886, 12.685906179249287, 9.424313195049763, 8.661686517298222, 7.478335490450263, 3.8717732671648264, 2.864118875004351, 1.9277692004106939, 0.8354480483103544, 0.6029192288406193, 0.35133321478497237, 0.4111861187266186, 0.5947059101890773, 0.36756125336978585, 0.18915245484095067, 1.1036864016205072, 1.2569840694777668, 0.20769201626535505, 0.19629904010798782, 0.20506420492893085, 0.48243333469145, 1.0696467594243586, 0.9540072083473206, 0.359896975569427, 0.18537688243668526, 0.544694596901536, 0.5529969732742757, 0.43763326364569366, 1.6677001118659973, 0.8324409846682101, 0.237012222642079, 0.1808996094041504, 0.863836562493816, 1.0684922151267529, 2.2778186481446028, 3.2387286610901356, 5.6213722843676805, 7.45438015088439, 14.966293014585972, 16.01608358323574, 18.617104813456535, 16.87168177217245, 15.084194988012314, 15.804627779871225, 19.563350938260555, 25.93469325453043, 31.128459759056568, 32.08278425037861, 27.348471991717815, 27.220926135778427, 16.416044421494007, 7.465612823143601, 2.1024948684498668, 0.15576704550767317, 0.056124962575268, 0.06275291278143413, 0.06150545901618898, 0.0747433549258858, 0.033914007726707496, 0.03885687452566344, 0.018294821529707406, 0.05277413241856266, 0.016544345635338686, 0.030556026977137662, 0.017617669291212223, 0.0453104422922479, 0.040916957732406445, 0.05105546682898421, 0.010485093916940968, 0.013724245691264514, 0.010682402225938858, 0.014432056977966568, 0.042609562806319445, 0.029966201400384307, 0.0276091533669387, 0.07706379095907323, 0.05975438383757137, 0.03627219681220595, 0.10900639099418186, 0.05132984253577888, 0.016919015179155394, 0.014413436492759502, 0.0033579802857275354, 0.06198108290845994, 0.044405504522728734, 0.05115908177685924, 0.044444534069043584, 0.059295139144524, 0.027119981568830553, 0.020566160783346277, 0.053856098384130746, 0.04626767178706359, 0.01713181674858788, 0.013861683091818122, 0.04983081926184241, 0.024554473529860843, 0.040240749876829796, 0.03290187414677348, 0.03567106832633726, 0.01809352881537052, 0.01637457935430575, 0.060990479032625444, 0.040298978783539496, 0.04971675116394181, 0.060901977922185324, 0.047573547417414375, 0.0072507526510889875, 0.04128900749492459, 0.045351783628575504, 0.0286828833486652, 0.031714827491668984, 0.036869458708679304, 0.027845881777466275, 0.043498659433680587, 0.04991055560822133, 0.043276935393805616, 0.03310489235445857, 0.04559629160212353, 0.04245974174409639, 0.07883996557211503, 0.06369470560457557, 0.013346458199521294, 0.01076816295608296, 0.0363997757085599, 0.06323833673377521, 0.03647091056336649, 0.05184814734093379, 0.021489845203177538, 0.09051354034454562, 0.026939552481053397, 0.04890249270829372, 0.06134198985819239, 0.030623475213360507, 0.00876131121913204, 0.004918737722618971, 0.07891960543929599, 0.04965978390828241, 0.03702279755088966, 0.023574191072839312, 0.03970131241658237, 0.024113691615639254, 0.026016292940767016, 0.0750195822911337, 0.02995549777551787, 0.04554373270366341, 0.03257764095906168, 0.017009675939334556, 0.06024334412359167, 0.074572185985744, 0.010463549369887915, 0.03309478430310264, 0.045601141537190415, 0.07907123363111168, 0.04106329441128764, 0.025869447890727315, 0.00943535200349288, 0.04023863104521297, 0.042278234686818905, 0.03114246836048551, 0.039512417279183865, 0.15808558906428516, 1.8103778245858848, 11.730247009545565, 24.000051766633987, 39.430575370788574, 46.07882782816887, 47.96830303966999, 38.92219305038452, 31.66777241975069, 25.13366773724556, 20.2806194499135, 45.04161648452282, 45.99323742091656, 31.92796915769577, 28.843262381851673, 31.34649395942688, 27.804483622312546, 18.411881625652313, 15.123769864439964, 9.638824984431267, 8.447367567569017, 4.803357403725386, 2.2144107380881906, 1.3280106894671917, 0.5968990456312895, 0.15757390792714432, 0.2823091170284897, 0.037550984052359127, 0.3729941899655387, 0.069788725086255, 0.10158600518479943, 0.3673574002459645, 0.09657250819145702, 0.0630890388856642, 0.5402944330126047, 0.3052732738433406, 0.4686289426172152, 0.5299626686610281, 0.4078640876105055, 0.32696298498194665, 0.13756250438746065, 0.33649420947767794, 0.3943322418490425, 0.036626438741222955, 0.2103809657273814, 0.07640783631359227, 0.12663907022215426, 0.2591067011235282, 0.7197146897669882, 0.9175238816533238, 2.1713697351515293, 3.7508977157995105, 6.74106010235846, 9.82915772125125, 17.322371788322926, 20.338872224092484, 21.934336312115192, 16.312188394367695, 15.899671129882336, 18.975416086614132, 23.20292294025421, 26.042787954211235, 32.33842693269253, 35.4490502178669, 30.90413499623537, 32.665258795022964, 19.67862155288458, 9.982112813740969, 2.5476452568545938, 0.14302236610092223, 0.05114574909384828, 0.0245188281769515, 0.047640852790209465, 0.016660144792695064, 0.024779965824563988, 0.029290715283423197, 0.07306739993509836, 0.06318635671050288, 0.06997599120950326, 0.04615090598235838, 0.042454743379494175, 0.01900652816402726, 0.038473792737931944, 0.019732582368305884, 0.024182421911973506, 0.02542091053328477, 0.012027092179778265, 0.038905236579012126, 0.06590853212401271, 0.030029270965314936, 0.031419452716363594, 0.1141663508315105, 0.0440366385737434, 0.009545797493046848, 0.07075762114254758, 0.05292751578963362, 0.01765458186127944, 0.018184825967182405, 0.05089319995022379, 0.12066602081176825, 0.031143165979301557, 0.04815978471015114, 0.03239174038753845, 0.03254829643992707, 0.02846247847628547, 0.05768092341895681, 0.052989770847489126, 0.07542100254795514, 0.01615684806893114, 0.018398653555777855, 0.046968203532742336, 0.029414969358185772, 0.03248408953368198, 0.05304113117745146, 0.039988352873479016, 0.035406934257480316, 0.04074225988006219, 0.052552200577338226, 0.007606491399201332, 0.11402867501601577, 0.1226859909365885, 0.1719358903937973, 0.11558192330994643, 0.08577065265853889, 0.23244884563609958, 0.12206903615151532, 0.197531524754595, 0.14195307972840965, 0.19489416939904913, 0.11807688279077411, 0.14295671571744606, 0.14029495854629204, 0.18421724700601771, 0.11793139958172105, 0.14010415237862617, 0.1632208947557956, 0.18249065527925268, 0.12179309080238454, 0.15573755255900323, 0.14220115001080558, 0.07912730288808234, 0.22845557163236663, 0.09117763635003939, 0.11665166981401853, 0.301469677942805, 0.09217973609338515, 0.13648928463226184, 0.14613972773076966, 0.1681613569962792, 0.08050889242440462, 0.09500094369286671, 0.2670744579518214, 0.23563399503473192, 0.13445617107208818, 0.08483149445964955, 0.25996245676651597, 0.11719155256287195, 0.09394497887114994, 0.12681725987931713, 0.1296326713054441, 0.1611041559954174, 0.09160316156339832, 0.11020722304238006, 0.19015022786334157, 0.15364687802502885, 0.21492331026820466, 0.09956524838344194, 0.1444969986914657, 0.14625170297222212, 0.23631870048120618, 0.1102628321677912, 0.11975409943261184, 0.12220226650242694, 0.10386508874944411, 0.13473125552991405, 0.1555593777447939, 0.23520850692875683, 2.013514805585146, 11.62728963419795, 27.709433622658253, 43.7715308368206, 55.041251108050346, 56.410982608795166, 49.489999786019325, 42.02447958290577, 35.83563767373562, 26.56083695590496, 49.71758857369423, 54.4381208717823, 43.975484892725945, 39.87819515168667, 32.16520182788372, 28.973194509744644, 18.099405393004417, 15.818783920258284, 12.34342010691762, 10.322724636644125, 6.1804847326129675, 3.6813061125576496, 2.6436411682516336, 1.6324719646945596, 1.301476713269949, 0.7075488707050681, 0.8087683143094182, 1.7913518892601132, 1.2326367571949959, 0.8601119904778898, 2.802054430358112, 1.8748958688229322, 1.497071930207312, 1.6103288903832436, 1.3624280551448464, 2.4426899012178183, 3.0486110877245665, 2.2816177317872643, 1.8030423182062805, 0.25162261677905917, 1.610025737900287, 1.409049415960908, 2.310476708225906, 3.0202660337090492, 2.0194339379668236, 0.9438661462627351, 0.7152057567145675, 1.500940122641623, 1.6930853622034192, 3.6541905300691724, 4.1074370965361595, 7.722082436084747, 9.962560962885618, 19.8507447168231, 22.49281134456396, 27.627825401723385, 24.90055214613676, 22.29923453181982, 26.187563985586166, 28.70370727032423, 34.95376959443092, 40.56718938052654, 44.69652280211449, 38.400617837905884, 38.09720031917095, 23.441582433879375, 11.192033439874649, 2.771657961420715, 0.2626652695471421, 0.13913444738136604, 0.08455980161670595, 0.15283522079698741, 0.16687490337062627, 0.12665465532336384, 0.1667317727697082, 0.1397984617506154, 0.14920000336132944, 0.15580228267936036, 0.08863563954946585, 0.09168417440378107, 0.13658159296028316, 0.13223009911598638, 0.13214929407695308, 0.1126169394410681, 0.06778314520488493, 0.16208319721044973, 0.12131919982493855, 0.16992919729091227, 0.12686205591307953, 0.11564522108528763, 0.2282839425606653, 0.16108769515994936, 0.11004149404470809, 0.22473071760032326, 0.2231616689823568, 0.1489631543518044, 0.10274018583004363, 0.16163730004336685, 0.20524635765468702, 0.12379743871861137, 0.12967642833245918, 0.11635075861704536, 0.15079756529303268, 0.12087993003660813, 0.10768187261419371, 0.14750679343705997, 0.19415880495216697, 0.12192355294246227, 0.1210398851253558, 0.11729693011147901, 0.08756268696743064, 0.17078061879146844, 0.19868645496899262, 0.15137375390622765, 0.175931301782839, 0.07397312438115478, 0.1308940551825799, 0.1331386511446908], [0.050159308666479774, 0.011672839118546108, 0.03342538882861845, 0.056285318423761055, 0.1035493123345077, 0.0448752840020461, 0.033523775346111506, 0.04683369668782689, 0.013488508047885261, 0.08331639997777529, 0.04214698958094232, 0.04032300952530932, 0.027199983233003877, 0.020116354353376664, 0.02317135516932467, 0.038377821911126375, 0.044516418493003584, 0.032222571535385214, 0.04410735782585107, 0.009833541134867119, 0.023164245394582395, 0.027662497086566873, 0.0237602790366509, 0.01798514000256546, 0.041252107912441716, 0.021648863330483437, 0.03773496617213823, 0.04090288661245722, 0.05914616041991394, 0.04430725530255586, 0.028453337072278373, 0.03592558416130487, 0.03958968598453794, 0.044653578515863046, 0.06113119765359443, 0.02089828485623002, 0.04139972850680351, 0.03808369394391775, 0.04569030315906275, 0.07323301018914208, 0.016020500697777607, 0.04146472208958585, 0.027888640615856275, 0.014799968339502811, 0.039318590570474043, 0.018200258928118274, 0.015090483902895357, 0.12249649094883353, 0.07910332409664989, 0.0329061414959142, 0.029894680628785864, 0.031325789968832396, 0.04054511577123776, 0.022911653577466495, 0.01599452181835659, 0.03980675304774195, 0.021579628373729065, 0.07454523860360496, 0.027437474200269207, 0.7837717118673027, 5.339811192825437, 13.02049532532692, 26.274429224431515, 38.33023801445961, 42.43203051388264, 37.140065878629684, 45.85613317787647, 27.346370704472065, 27.0388513058424, 38.8202179223299, 36.46743357181549, 24.652535654604435, 17.76563510298729, 28.49382933229208, 19.886265210807323, 26.469945833086967, 17.822611145675182, 14.030929505825043, 15.890341680496931, 11.475360486656427, 9.188940525054932, 6.402033744379878, 4.052838301286101, 2.7952801063656807, 2.088148738257587, 1.231844024732709, 0.9651698218658566, 0.7248457206878811, 0.5149963404983282, 0.6497795612085611, 0.4865517496364191, 0.48840376432053745, 0.5766664375551045, 0.4773217480396852, 0.27401558705605567, 0.6005121173802763, 0.45135964115615934, 0.7263471744954586, 0.656944967340678, 0.2768143150024116, 0.7538268843200058, 0.5939062312245369, 0.9430098859593272, 2.6951675908640027, 3.657920742407441, 4.024191638454795, 7.495408449321985, 8.437454849481583, 9.640149213373661, 14.51947309076786, 15.08146008476615, 18.48974894732237, 23.56127981096506, 21.140346117317677, 22.950910963118076, 18.69668584316969, 23.174300976097584, 26.55039321631193, 33.67567777633667, 32.705605030059814, 22.841480635106564, 20.46503685414791, 11.1229607462883, 5.65374749712646, 0.8795290079433471, 0.04519589550909586, 0.06392681229044683, 0.02501713952369755, 0.030862042294756975, 0.028928886749781668, 0.007087349358698702, 0.026098001544596627, 0.04159529926255345, 0.027384341992728878, 0.04564305803796742, 0.033520650904392824, 0.018961977038998157, 0.04397928911203053, 0.03729516203748062, 0.06196698952408042, 0.04059053520904854, 0.0548456706746947, 0.046112410782370716, 0.05526553330128081, 0.06589519573026337, 0.039605612473678775, 0.012259345439815661, 0.0248838943298324, 0.04569344986521173, 0.06761648110114038, 0.04672512790421024, 0.044578053857549094, 0.05257925557089038, 0.08590855853981338, 0.06789497201680206, 0.029634941929543857, 0.020928471712977625, 0.01872209079010645, 0.019368594184925314, 0.02511473750928417, 0.043448289870866574, 0.02773268941382412, 0.06383333136909641, 0.047079596188268624, 0.027623949936241843, 0.017890321360027883, 0.07557182179880328, 0.05540923164517153, 0.011076614373450866, 0.035701284868991934, 0.05467232353112195, 0.010513775141589576, 0.022282119389274158, 0.04473415348911658, 0.055475716944783926, 0.04613493125361856, 0.05453877034597099, 0.043140981360920705, 0.014976358288549818, 0.041965716300182976, 0.07762025328702293, 0.014745571697858395, 0.007691350419918308, 0.06198570648848545, 0.019098524790024385, 0.05657271140080411, 0.09174075574264862, 0.014565369892807212, 0.02267104744532844, 0.018812293274095282, 0.05242265127890278, 0.04275536884961184, 0.02572084209532477, 0.052036994238733314, 0.0050005706361844204, 0.06184073536132928, 0.06257371380343102, 0.0808666150260251, 0.023778890245012008, 0.0017528874104755232, 0.05933225023909472, 0.01739004332193872, 0.051321953505976126, 0.06767659506294876, 0.04829513760341797, 0.05496391706401482, 0.030019940313650295, 0.05340151437849272, 0.026221279695164412, 0.0323327248042915, 0.028833487376687117, 0.03554325194272678, 0.0012118328800170275, 0.021240991954982746, 0.021040602805442177, 0.0328237668145448, 0.009542725929350127, 0.06163842590467539, 0.031745251835673116, 0.014923275248293066, 0.018817584787029773, 0.05825368330988567, 0.0314453239843715, 0.057814027604763396, 0.09978760324884206, 0.015418256207340164, 0.031536964379483834, 0.0368385185720399, 0.029706971072300803, 0.07269991067005321, 0.04500605784414802, 0.07492393429856747, 0.05576052724791225, 0.005421607247626525, 0.024179484862543177, 1.3687868951819837, 7.1626275312155485, 18.39327212423086, 33.43789793550968, 44.46327991783619, 46.41851060092449, 39.79402966797352, 44.39800702035427, 28.070115968585014, 30.655466839671135, 44.46487583220005, 39.26759831607342, 31.166087239980698, 24.556355215609074, 31.626060158014297, 22.018815279006958, 27.29236040264368, 23.770551681518555, 19.79600105434656, 15.700058341026306, 14.257005024701357, 9.97071247547865, 6.482239840552211, 4.5680721290409565, 2.949371812865138, 2.022357643581927, 0.9463911701459438, 0.6298757542390376, 0.5030690773855895, 0.24246556829893962, 0.2692669106181711, 0.1346722399466671, 0.44097004865761846, 0.1929026161087677, 0.3547578997677192, 0.061095492928870954, 0.405453591956757, 0.36933555034920573, 0.3611645638011396, 0.39232784940395504, 0.5088929180055857, 0.42015541868750006, 0.6051856884732842, 0.9493006858974695, 1.8604976101778448, 2.790518724359572, 4.19145486317575, 6.956450594589114, 11.303186025470495, 12.14256003499031, 19.077404513955116, 19.035547859966755, 23.408488109707832, 28.853139951825142, 22.900690957903862, 22.588169127702713, 19.07719362527132, 22.38287754356861, 28.1687605753541, 36.66430100798607, 38.500366285443306, 28.352058939635754, 24.265733510255814, 15.184110626578331, 7.848586197942495, 1.3431237847544253, 0.050673758014454506, 0.03773527787416242, 0.012137687954236753, 0.047687893820693716, 0.0290197757203714, 0.06748776300810277, 0.01535182378574973, 0.03816232820099685, 0.0588955260172952, 0.033252383072976954, 0.029667909984709695, 0.015535588827333413, 0.04001720757514704, 0.01498228712080163, 0.016322927731380332, 0.07865877021686174, 0.03455689686234109, 0.04039195133373141, 0.06089585520385299, 0.011449798694229685, 0.05348126927856356, 0.0330181501340121, 0.016930592682911083, 0.019137739873258397, 0.049658474017633125, 0.016603871445113327, 0.0661345903063193, 0.03108263455942506, 0.12026076365145855, 0.025917993625625968, 0.06707507694954984, 0.056788542788126506, 0.014560526451532496, 0.025859093075268902, 0.03184164197591599, 0.059150424058316275, 0.08439925280981697, 0.042344267276348546, 0.017376795985910576, 0.04059260951180477, 0.007465995422535343, 0.01847559200541582, 0.03168869276123587, 0.040578423358965665, 0.09365338904899545, 0.02565779665019363, 0.01820020697778091, 0.048856457287911326, 0.06761510812793858, 0.03876017639413476, 0.10217547824140638, 0.1541530672693625, 0.08913575060432777, 0.09857767247012816, 0.1844255975447595, 0.23636230907868594, 0.17066758970031515, 0.08903103356715292, 0.09404003314557485, 0.09364292476675473, 0.15695946902269498, 0.16129582305438817, 0.10342727357055992, 0.08777022114372812, 0.09323483260232024, 0.10590545309241861, 0.11259284932748415, 0.113574035349302, 0.142859791230876, 0.13952549983514473, 0.125563163892366, 0.13446926255710423, 0.10839196693268605, 0.16320857510436326, 0.0703143140708562, 0.29516361944843084, 0.16278767347102985, 0.12438409903552383, 0.17366479762131348, 0.1271582767367363, 0.1107451539428439, 0.1828082647989504, 0.1712087489431724, 0.08909759679227136, 0.1767552044475451, 0.23750913504045457, 0.137266342935618, 0.15021284198155627, 0.15448482212377712, 0.0870543900236953, 0.12698829523287714, 0.12981847539776936, 0.2651145349955186, 0.2177158190170303, 0.12918557185912505, 0.10947021844913252, 0.11471398902358487, 0.08887352756573819, 0.1822245804942213, 0.14189363369951025, 0.10326937423087656, 0.15999158757040277, 0.10160670368350111, 0.12301463619223796, 0.16121271735755727, 0.14011602674145252, 0.15440967225003988, 0.1276110313483514, 0.12103103872505017, 0.1206469995668158, 1.4872213150374591, 7.943970104679465, 19.35737159103155, 38.401852771639824, 50.72036616504192, 57.21322976052761, 48.000798895955086, 58.31006370484829, 36.84433154761791, 37.63566568493843, 49.75962191820145, 47.67721965909004, 36.6216254979372, 27.200798615813255, 42.720575630664825, 27.937765270471573, 37.220416367053986, 26.280451901257038, 21.17330364882946, 21.802865266799927, 16.08812391757965, 11.946872435510159, 8.300531096756458, 5.577383944764733, 3.6114375991746783, 3.2292754808440804, 1.7102284985594451, 1.408661361783743, 1.7324565933085978, 1.6299439128488302, 1.1041282466612756, 0.6850845948792994, 1.2682555709034204, 0.8544628217350692, 0.8802508504595608, 0.7571092550642788, 1.3384674908593297, 1.194649483077228, 1.5400494053028524, 1.7408028454519808, 0.9714819956570864, 1.3770312652923167, 1.2054449412971735, 1.4768614084459841, 3.3737810142338276, 4.231482390314341, 5.574896028265357, 9.235894605517387, 12.024127040058374, 12.954286728054285, 21.904557310044765, 21.991827227175236, 26.162358038127422, 35.88280454277992, 28.986058719456196, 34.503068178892136, 25.934655256569386, 32.472574934363365, 36.899797171354294, 45.08461877703667, 45.29613442718983, 33.18192467093468, 27.296074703335762, 16.877354867756367, 8.094082474708557, 1.81724144378677, 0.1442384789697826, 0.1261790722492151, 0.0949169548403006, 0.17230096767889336, 0.11296811630018055, 0.17828024370828643, 0.12340094632236287, 0.14463735366007313, 0.12952191318618134, 0.17223043396370485, 0.11720913404133171, 0.1004320323409047, 0.08555377484299242, 0.1261867312132381, 0.18658026005141437, 0.1615066226804629, 0.166649661550764, 0.11804106674389914, 0.09610067296307534, 0.14019843481946737, 0.1713287245365791, 0.12871838989667594, 0.07360083342064172, 0.09149853358394466, 0.12357707280898467, 0.12634682731004432, 0.1830642018467188, 0.18663540162378922, 0.27881763875484467, 0.10345321905333549, 0.1311801085830666, 0.1667118980549276, 0.16649906494421884, 0.10306968455552123, 0.10498878938960843, 0.22597578907152638, 0.2013090712716803, 0.11330612003803253, 0.1332468562759459, 0.09072680390090682, 0.1272150213480927, 0.12663996079936624, 0.13633991999085993, 0.14644917362602428, 0.17585831898031756, 0.0947620315128006, 0.12877106753876433, 0.15217399690300226, 0.15592516749165952, 0.16459492180729285, 0.15351504291174933], [0.01660854326473782, 0.03040281058929395, 0.011803282704931917, 0.040790095008560456, 0.04304533707909286, 0.035021759613300674, 0.013384349476837087, 0.07332711451454088, 0.10624090384226292, 0.07090271101333201, 0.07118906127288938, 0.036706676037283614, 0.03421583547606133, 0.07624935809872113, 0.1180733204819262, 0.01768772432114929, 0.02324926212168066, 0.040826070617185906, 0.02803969178785337, 0.026217240556434263, 0.07747219482553191, 0.033521111035952345, 0.010929762829618994, 0.053972622990841046, 0.067113906115992, 0.04635763121768832, 0.04282932757632807, 0.051626185813802294, 0.07107926794560626, 0.04558418717351742, 0.016893735773919616, 0.04589334363117814, 0.06376897232257761, 0.05568114713241812, 0.03172145487042144, 0.009506064761808375, 0.03283788246335462, 0.027424525578680914, 0.043876909840037115, 0.04823844865313731, 0.023238380381371826, 0.054461052641272545, 0.02474279721354833, 0.04467953884159215, 0.04382720078865532, 0.014413064491236582, 0.04297902618418448, 0.009689188773336355, 0.007103778652890469, 0.023167657418525778, 0.04259137647750322, 0.011272315932728816, 0.022745022870367393, 0.07550746275228448, 0.029132326126273256, 0.0436709972564131, 0.01013146982586477, 0.04960720274539199, 0.07698012123000808, 0.02406708288617665, 0.24728813295951113, 1.2183524924330413, 8.754092808812857, 21.93809051066637, 35.453944355249405, 43.67233335971832, 42.43876375257969, 38.81100721657276, 28.982600905001163, 39.674575477838516, 48.20908471941948, 20.428279526531696, 24.850271344184875, 25.72550307959318, 26.865905486047268, 23.133627958595753, 15.661315619945526, 21.385037787258625, 22.184495888650417, 21.51543729007244, 21.1299042776227, 13.974369540810585, 12.0463159494102, 10.295193213969469, 8.11074648052454, 8.832311611622572, 6.5323482267558575, 4.96299016289413, 4.699962101876736, 4.0449784230440855, 3.4054687013849616, 3.268692190758884, 3.051339816302061, 2.664273348636925, 2.979349591769278, 2.249452220275998, 2.5871370127424598, 1.9295988022349775, 2.643389906734228, 3.2660684315487742, 3.5809777211397886, 5.179063193500042, 5.789642930030823, 9.07840445637703, 12.994382176548243, 12.657008729875088, 17.510305903851986, 15.320995431393385, 17.96113271266222, 18.607183545827866, 16.356442719697952, 17.595630325376987, 18.687429539859295, 20.40333006531, 24.56976469606161, 33.84045973420143, 35.507479682564735, 37.0857135951519, 29.034861400723457, 21.23945239931345, 11.21407700702548, 6.407526824623346, 1.5378829278051853, 0.5319072143174708, 0.032187961478484794, 0.046045929193496704, 0.027134267911606003, 0.07090742365107872, 0.0868412823183462, 0.004801599452548544, 0.03935332308174111, 0.01703518912108848, 0.05495459568919614, 0.03418861721002031, 0.08508645187248476, 0.007921394862933084, 0.036400261815288104, 0.011464357776276302, 0.03886751692334656, 0.04857157648075372, 0.010872389248106629, 0.05558630437008105, 0.05407483156886883, 0.031018856243463233, 0.027717430857592262, 0.012593307255883701, 0.02369965113757644, 0.05419287015683949, 0.047727242490509525, 0.06912539349286817, 0.023980596706678625, 0.08288513796287589, 0.035813004069495946, 0.04615967074641958, 0.01731749282043893, 0.06839358393335715, 0.03657693006971385, 0.024138696426234674, 0.049294153723167256, 0.015076913732627872, 0.06482156037236564, 0.0068543882753147045, 0.02509722653485369, 0.0681560521479696, 0.03170158757711761, 0.010262222331220983, 0.0399436941370368, 0.0450048221682664, 0.06561058209626935, 0.052930610545445234, 0.04584053240250796, 0.01826829346100567, 0.025910219628713094, 0.02001626831770409, 0.03443532194069121, 0.022635199857177213, 0.01579702704475494, 0.06799925118684769, 0.07213938879431225, 0.09901312761940062, 0.05158748652320355, 0.05494766402989626, 0.05522357598238159, 0.008754314621910453, 0.06975637486902997, 0.025734248993103392, 0.03629250939411577, 0.07809557660948485, 0.035719808875001036, 0.03109206725639524, 0.04694152703450527, 0.05726755458454136, 0.0032358589578507235, 0.035205270469305106, 0.07880558929173276, 0.06241019640583545, 0.033198722085217014, 0.06170284061226994, 0.0024288396889460273, 0.08996210977784358, 0.1007705184747465, 0.03807344488450326, 0.029253971551952418, 0.03854267517453991, 0.05830930356751196, 0.0038983101785561303, 0.014121356853138423, 0.030602598599216435, 0.05666073382599279, 0.03937907189538237, 0.02166506070352625, 0.037527524764300324, 0.05585037906712387, 0.0362281206616899, 0.0440033755148761, 0.06925940309884027, 0.014967095357860671, 0.057671613176353276, 0.053608555026585236, 0.0508351009193575, 0.02350288923480548, 0.049661917582852766, 0.03770012604945805, 0.03687977456138469, 0.007582316402476863, 0.02586791721114423, 0.06765855345292948, 0.015427372563863173, 0.03419229826249648, 0.040109052060870454, 0.03300328862678725, 0.04152658751991112, 0.028007128203171305, 0.02875582162232604, 0.05048714127042331, 0.05052887223428115, 0.5291521840263158, 2.700194721110165, 12.207338009029627, 27.579564191401005, 40.69681562483311, 48.33218291401863, 50.33568620681763, 39.09842759370804, 31.809413619339466, 42.728927582502365, 51.152376383543015, 21.419997811317444, 21.823374666273594, 28.701102510094643, 24.430046193301678, 31.23702373355627, 22.802673317492008, 24.934822507202625, 30.40590763092041, 30.2707526832819, 21.362641789019108, 17.728537693619728, 14.448913726955652, 12.381728701293468, 11.044586151838303, 9.793567880988121, 7.669291868805885, 6.08753839507699, 5.134195201098919, 4.323601797223091, 3.9285690570250154, 3.0980606842786074, 3.017214322462678, 2.8315377607941628, 2.7576725743710995, 2.647497011348605, 2.950054588727653, 2.059592795558274, 2.6853330060839653, 3.336647031828761, 3.6412460496649146, 5.372555935755372, 6.78021652624011, 10.92086574062705, 14.873748980462551, 15.163833014667034, 19.949182234704494, 21.274133138358593, 24.369443245232105, 24.766816422343254, 19.930720925331116, 20.918223336338997, 20.791593231260777, 22.569187246263027, 27.915019690990448, 35.26085391640663, 37.839501947164536, 41.18775688111782, 35.08881434798241, 27.656612657010555, 15.510221477597952, 9.258948918431997, 2.940438254736364, 0.7529924728441983, 0.01741408519592369, 0.013901276670367224, 0.06008616466715466, 0.058010240318253636, 0.029219252028269693, 0.05716731269785669, 0.06688909474178217, 0.02575886232079938, 0.033636373991612345, 0.03529493675159756, 0.04219304726575501, 0.0025924793089870946, 0.062230492767412215, 0.003204436657142651, 0.0026041576984425774, 0.015117065777303651, 0.02034442932199454, 0.03162842294841539, 0.04620110114046838, 0.0426310850889422, 0.018746531568467617, 0.05040668504079804, 0.04413042377564125, 0.035174664299120195, 0.05150158664037008, 0.02430678730888758, 0.02822175174514996, 0.025796448389883153, 0.01879172650660621, 0.09663715667556971, 0.055233060629689135, 0.013745799515163526, 0.012089699757780181, 0.04865705705014989, 0.09433961589820683, 0.10267207893775776, 0.04969134373823181, 0.027081673761131242, 0.07807308211340569, 0.047051873261807486, 0.02466174541041255, 0.05211654133745469, 0.03491663439490367, 0.012755574134644121, 0.026155952145927586, 0.05734213671530597, 0.05491023381182458, 0.029363506982917897, 0.0954675542016048, 0.0455483154655667, 0.022068675862101372, 0.028258540005481336, 0.08909801981644705, 0.1101502038363833, 0.13402755110291764, 0.19761140953050926, 0.10858850248041563, 0.10344373440602794, 0.09889738968922757, 0.13506255025276914, 0.1833911772700958, 0.15415646630572155, 0.25225721241440624, 0.20098595501622185, 0.17331987706711516, 0.1769078493816778, 0.17832045326940715, 0.19866812392137945, 0.07661800511414185, 0.09469350159633905, 0.15694872272433713, 0.13047503860434517, 0.19615384633652866, 0.11730060374247842, 0.09972628700779751, 0.1831340676289983, 0.27214249537792057, 0.21562624286161736, 0.15841072396142408, 0.12436442470061593, 0.12696456135017797, 0.1304405287373811, 0.09370539875817485, 0.18942324968520552, 0.2227103541372344, 0.15063214057590812, 0.17840863525634632, 0.1717059433576651, 0.1431985222734511, 0.10506990613066591, 0.14774435490835458, 0.15294550394173712, 0.13297258818056434, 0.19707701867446303, 0.1320987389772199, 0.13399986899457872, 0.09281195685616694, 0.18081976915709674, 0.10444960425957106, 0.08006439049495384, 0.0762665388174355, 0.17436525144148618, 0.19030186347663403, 0.1680649965419434, 0.2242497613769956, 0.196507568762172, 0.08756356270168908, 0.13771252211881801, 0.10625712719047442, 0.1264155501849018, 0.17356432566884905, 0.11151889484608546, 0.7090776355471462, 3.134513315744698, 13.119374569505453, 29.788353368639946, 48.59075523912907, 53.87240722775459, 57.660610154271126, 50.84464989602566, 40.247379541397095, 50.26557236909866, 60.12925408780575, 29.57202337682247, 37.700471207499504, 40.779316797852516, 36.88043721020222, 37.52192258834839, 26.342817954719067, 30.56125659495592, 33.69306564331055, 32.57599398493767, 26.243947260081768, 21.123518720269203, 17.74115301668644, 15.146541092544794, 11.44150810316205, 13.233593590557575, 9.025206360965967, 6.723368251696229, 5.757689969614148, 5.99456213414669, 5.4376179445534945, 5.154440514743328, 4.285446619614959, 4.31950799189508, 3.7346573872491717, 3.9355642441660166, 3.910999749787152, 3.452076050452888, 3.803096702322364, 4.872827650979161, 5.211058901622891, 7.1475214418023825, 8.352810591459274, 12.912847101688385, 17.017668038606644, 18.762498311698437, 22.833746150135994, 22.098398208618164, 25.611028522253036, 27.559128887951374, 27.076450288295746, 25.71905292570591, 30.50463393330574, 31.316971443593502, 35.90657226741314, 44.04266528785229, 44.92365561425686, 50.55635556578636, 39.34131816029549, 31.65346048772335, 17.871636115014553, 9.86766105517745, 3.223149972036481, 0.7875669363420457, 0.2218013716628775, 0.08188376552425325, 0.18765018467092887, 0.20338813861599192, 0.136512795870658, 0.13410186977125704, 0.13376110524404794, 0.13949863408925012, 0.11896836542291567, 0.15277819416951388, 0.13360589247895405, 0.0897480892308522, 0.08425203297520056, 0.13219152227975428, 0.09900180986733176, 0.14676054910523817, 0.09850714617641643, 0.09806757952901535, 0.20141923567280173, 0.10087116854265332, 0.1003933664469514, 0.1231554735568352, 0.062165091003407724, 0.19649377965833992, 0.1721145847113803, 0.16955030121607706, 0.20100201509194449, 0.19129749911371619, 0.17508992896182463, 0.17599162354599684, 0.1111416463390924, 0.13706913945497945, 0.10610080862534232, 0.21846647170605138, 0.1832955886493437, 0.17785756092052907, 0.18848339386750013, 0.11492685182020068, 0.15184372634394094, 0.1375188957899809, 0.13716609362745658, 0.12422519037500024, 0.0934025802416727, 0.09282397222705185, 0.14765592059120536, 0.11382484415662475, 0.18382150417892262, 0.05967855489870999, 0.2067254134453833, 0.16455201082862914, 0.0921035472129006, 0.10428039458929561], [0.044125510758021846, 0.028158134846307803, 0.031574272143188864, 0.04377307224785909, 0.05932786785706412, 0.10583023642539047, 0.0222417855184176, 0.01796879976609489, 0.05752865326940082, 0.12611833488335833, 0.02101679285260616, 0.055962792175705545, 0.01613878604985075, 0.10187394364038482, 0.0025523432668705937, 0.07902090859715827, 0.11721533097443171, 0.026256594792357646, 0.05101038877910469, 0.08589809425757267, 0.03079834561503958, 0.0455192789377179, 0.04133003341848962, 0.018165121946367435, 0.012354115842754254, 0.04855251812841743, 0.04640633465896826, 0.012290412669244688, 0.046784956139163114, 0.037353899315348826, 0.023075232202245388, 0.05205871690122876, 0.026896272283920553, 0.05545575317228213, 0.09838461017352529, 0.05602655379334465, 0.03619676121161319, 0.04684662118961569, 0.02505053431377746, 0.034694817586569116, 0.011991252013103804, 0.02317733502422925, 0.062414909043582156, 0.02876339709473541, 0.025000389250635635, 0.038983559134067036, 0.06216032641532365, 0.05654326298099477, 0.034465716598788276, 0.06648125490755774, 0.009653718752815621, 0.06015272418153472, 0.02784903219435364, 0.03686305397422984, 0.07815667020622641, 0.029963012020743918, 0.020165529058431275, 0.06320526663330384, 0.006139705628811498, 0.050635426086955704, 0.01946023458003765, 0.059233715292066336, 1.6152544948272407, 4.566668579354882, 15.300306491553783, 29.393077678978443, 38.4285881370306, 45.13697236776352, 38.01644325256348, 41.80406101047993, 44.5984348654747, 30.31283162534237, 29.296855442225933, 23.811978958547115, 25.993899777531624, 20.49557201564312, 24.576505534350872, 24.166178852319717, 19.736621640622616, 21.017599403858185, 29.353537000715733, 27.053972594439983, 22.830693013966084, 18.792826384305954, 18.84292669594288, 15.738968253135681, 17.46828965842724, 14.510343130677938, 11.209792736917734, 11.228786017745733, 11.255578380078077, 12.890939377248287, 11.23429762199521, 10.0174262188375, 9.367831125855446, 10.59656834229827, 9.609765093773603, 11.801769621670246, 12.215857151895761, 12.175614461302757, 13.20234501734376, 15.218820814043283, 18.158803805708885, 20.59456430375576, 23.418779857456684, 26.721412539482117, 26.33565913885832, 23.57557274401188, 18.72968327254057, 26.29884671419859, 23.144092597067356, 22.50756025314331, 32.77004957199097, 31.353033408522606, 32.633864879608154, 35.11572830379009, 29.279961548745632, 19.282342717051506, 11.326710563153028, 5.702253794297576, 1.9315133057534695, 0.5416356422938406, 0.06669891197816469, 0.08147692016791552, 0.025943649670807645, 0.021054499520687386, 0.03158740444632713, 0.05785253022622783, 0.014820918240729952, 0.034568066184874624, 0.012092487449990585, 0.08014981169253588, 0.04169373401964549, 0.032367776439059526, 0.031864897173363715, 0.03399834909942001, 0.01989332784432918, 0.026131695049116388, 0.04669435846153647, 0.008598213134973776, 0.09102374460780993, 0.10264372147503309, 0.05545474756218027, 0.03728719508217182, 0.02770517057797406, 0.02070619291771436, 0.022677114502585027, 0.016192580624192487, 0.032729399026720785, 0.025595920087653212, 0.0415396493190201, 0.025178259784297552, 0.08741411642404273, 0.01694329082965851, 0.05882236138859298, 0.039158379440777935, 0.026390897546662018, 0.023356927340500988, 0.017835471080616117, 0.04758895440318156, 0.028758298540196847, 0.03966795658925548, 0.04093067633220926, 0.020022481949126814, 0.02438864619762171, 0.012895577510789735, 0.05644770775688812, 0.04437786694325041, 0.03210683360521216, 0.02192495154304197, 0.06589567812625319, 0.031986976755433716, 0.020484199849306606, 0.04989278859284241, 0.00794311845311313, 0.0127264309230668, 0.08046139497309923, 0.062469108088407665, 0.03435539634665474, 0.027037113359256182, 0.057841602101689205, 0.017179913484142162, 0.03825950130703859, 0.03675826272228733, 0.041704573086462915, 0.06344184104818851, 0.07262136175995693, 0.11990125247393735, 0.02705926090129651, 0.0632004723593127, 0.056382150141871534, 0.11581918792217039, 0.04508527468715329, 0.033434057113481686, 0.04845605377340689, 0.0565266128978692, 0.03846172912744805, 0.022532020921062212, 0.014304960477602435, 0.02204161159170326, 0.030729919599252753, 0.03570909597328864, 0.02520257625292288, 0.049393293520552106, 0.05044111327151768, 0.04046163157909177, 0.0061960582934261765, 0.024731972989684436, 0.013102509619784541, 0.01611212624993641, 0.06480760057456791, 0.08691519280546345, 0.03469568589935079, 0.017737535417836625, 0.012524734665930737, 0.022709405347995926, 0.06585281167645007, 0.051875610515708104, 0.030358977492142003, 0.021263193302729633, 0.06747466410160996, 0.018093695798597764, 0.02523717332223896, 0.021543422699323855, 0.016843772536958568, 0.02168192972021643, 0.020720577595056966, 0.01975512881472241, 0.006907956030772766, 0.07715197294601239, 0.04956435484928079, 0.028644883532251697, 0.020253891016182024, 0.08915900951251388, 0.0029986803883730317, 0.03429653290368151, 0.004764377499668626, 0.13707233068998903, 2.1545625245198607, 7.046362794935703, 20.458599999547005, 35.873126462101936, 44.87967297434807, 51.53220020234585, 44.06097270548344, 46.45721152424812, 51.000578328967094, 30.716658756136894, 30.72449393570423, 26.6930128633976, 28.178026378154755, 24.502194821834564, 24.20885246247053, 25.58847863227129, 24.129151739180088, 24.99025773257017, 30.760253816843033, 34.542787447571754, 27.43358362466097, 23.218182921409607, 21.869792975485325, 22.929045036435127, 20.251824595034122, 19.18098695576191, 13.66712847724557, 12.695815097540617, 12.16545095667243, 14.720124173909426, 14.321048688143492, 13.18394735455513, 12.754470650106668, 14.804647788405418, 11.454391311854124, 12.471156902611256, 12.683869488537312, 11.32486766204238, 13.085024412721395, 18.56206476688385, 22.072859779000282, 24.662002846598625, 28.60861547291279, 31.699331626296043, 31.53782319277525, 22.59243819862604, 17.66364097595215, 27.076575681567192, 22.455485947430134, 20.617070496082306, 31.708926111459732, 33.42943958938122, 39.01191383600235, 39.85201075673103, 35.40794022381306, 25.702567510306835, 15.396792814135551, 8.392863292247057, 3.5203127888962626, 0.793657653266564, 0.059708177723223343, 0.05647564961691387, 0.022056936941226013, 0.08697102457517758, 0.04245462092512753, 0.0360638574056793, 0.008549524536647368, 0.03195733908796683, 0.02855687780538574, 0.04091630835318938, 0.026187226249021478, 0.03850719309411943, 0.04572341036691796, 0.09105592413106933, 0.04324675966927316, 0.05143099355336744, 0.057598648927523755, 0.025196581555064768, 0.06007497679092921, 0.015620349513483234, 0.03072737959882943, 0.040369404887314886, 0.022843190454295836, 0.028386938975017983, 0.018181315608671866, 0.017951613481272943, 0.025970700953621417, 0.0478384607413318, 0.01065899303284823, 0.03445101094257552, 0.14051709818886593, 0.02439946671074722, 0.05109000267111696, 0.048608828583383, 0.003935963504773099, 0.040586709437775426, 0.02695641222089762, 0.009182385401800275, 0.038158910610945895, 0.08581586429500021, 0.01797728251403896, 0.010395270855951821, 0.0753330580482725, 0.021228609220997896, 0.03935257722332608, 0.021814456886204425, 0.021132289584784303, 0.014345049439725699, 0.09339146286947653, 0.037048724479973316, 0.02100211873766966, 0.05593891357420944, 0.03961248105042614, 0.03726366157934535, 0.1637652303907089, 0.2168409456498921, 0.14164963038638234, 0.12871392216766253, 0.1177732330688741, 0.1968856930034235, 0.14039646950550377, 0.08766419792664237, 0.16728824994061142, 0.2625711355358362, 0.10928641815553419, 0.23215133347548544, 0.09898669231915846, 0.26651383959688246, 0.09577190154232085, 0.30151886749081314, 0.15830397343961522, 0.1474803581368178, 0.18047541263513267, 0.18428098264848813, 0.17960913333809003, 0.09974864049581811, 0.10867618722841144, 0.11436130560468882, 0.19134940492222086, 0.10740215715486556, 0.09270722497603856, 0.1082425206550397, 0.11379981893696822, 0.14656877814559266, 0.1109722066030372, 0.07288066815817729, 0.11575079159229062, 0.10717189841670915, 0.20005061145639047, 0.1225456730753649, 0.12256361078470945, 0.19545587128959596, 0.10479488104465418, 0.17854661535238847, 0.19225344469305128, 0.16564716846914962, 0.09616959621780552, 0.08744645179831423, 0.2493399486411363, 0.10776557202916592, 0.13809196738293394, 0.13188759796321392, 0.18738250684691593, 0.0986199377803132, 0.09360425145132467, 0.19785210286499932, 0.14469706686213613, 0.14770233450690284, 0.2393735435907729, 0.08568023680709302, 0.0965447815542575, 0.1827749572112225, 0.08760777243878692, 0.09815052937483415, 0.06893988625961356, 0.28600186575204134, 2.194865536876023, 7.197851641103625, 22.452408112585545, 39.686913415789604, 50.99626936018467, 60.05141906440258, 51.77762143313885, 51.71003445982933, 59.863781332969666, 41.58422380685806, 44.36319328844547, 39.78205271065235, 36.358763203024864, 34.34989079833031, 36.237116530537605, 34.58003304898739, 33.70538458228111, 35.13926804065704, 40.35554453730583, 41.33247971534729, 33.111305460333824, 28.71030181646347, 27.242053002119064, 24.162025675177574, 22.647115364670753, 21.11604832112789, 17.45517086237669, 16.733074709773064, 15.327841714024544, 17.168753631412983, 15.52594218403101, 14.509146194905043, 13.688093852251768, 15.088357664644718, 14.407066572457552, 17.98699602484703, 15.944841206073761, 16.09565321356058, 18.265133500099182, 21.69750452041626, 24.83668327331543, 26.92535899579525, 30.806981809437275, 39.62181530892849, 39.227472469210625, 31.859183348715305, 25.285539887845516, 38.751491010189056, 30.289324186742306, 31.822199933230877, 43.15547749400139, 39.90891270339489, 44.63679000735283, 45.87570212781429, 40.249344035983086, 29.164474345743656, 17.12424661964178, 9.142726454883814, 3.7617059983313084, 0.9888961643446237, 0.2819126914255321, 0.12896663829451427, 0.0868302836897783, 0.1377326194779016, 0.1284634621697478, 0.1068963241414167, 0.09940854390151799, 0.1206618054129649, 0.10507245911867358, 0.13320173369720578, 0.14930651639588177, 0.09455489809624851, 0.21080737409647554, 0.1672901795245707, 0.09554427742841654, 0.1490588320302777, 0.13984687946503982, 0.15287808724679053, 0.10371098920586519, 0.1649601326789707, 0.12621079164091498, 0.1222609035903588, 0.1051560917403549, 0.07503012820961885, 0.1464615823351778, 0.10759300042991526, 0.07678954512812197, 0.10854549502255395, 0.23177095310529694, 0.16595680732280016, 0.1681155664846301, 0.1749257807387039, 0.1549494214123115, 0.1384830049937591, 0.13788204349111766, 0.14332149614347145, 0.0723382324213162, 0.15220584988128394, 0.10428276946186088, 0.13708098413189873, 0.13522524386644363, 0.13975526875583455, 0.1808891154360026, 0.10524548342800699, 0.2008157063391991, 0.11120421680971049, 0.13987793092383072, 0.12972595926839858, 0.2184970333473757, 0.11509678879519925, 0.1253770777839236, 0.12601070862729102, 0.12046382267726585, 0.12368483265163377], [0.02600549840281019, 0.05745637921791058, 0.07867209176765755, 0.035856004105880857, 0.11462542854133062, 0.05019903212087229, 0.016086366304080002, 0.06866962576168589, 0.07803493572282605, 0.0620017851179, 0.021739082512794994, 0.0339566775073763, 0.04682508035330102, 0.0461304969212506, 0.0027381283416616498, 0.03780838684178889, 0.03687716591230128, 0.018909798491222318, 0.0362901345215505, 0.014820260512351524, 0.02382277529250132, 0.02684709572349675, 0.031195576448226348, 0.03037412101548398, 0.05051285297668073, 0.0330251671402948, 0.03666785800305661, 0.078789247199893, 0.0928680483775679, 0.02578557778178947, 0.02417769999738084, 0.14428881142521277, 0.07069672792567872, 0.018211841997981537, 0.05127257842104882, 0.03859580552671105, 0.0388045865111053, 0.02910143979534041, 0.09532832729746588, 0.055016167971189134, 0.05290646477078553, 0.04273626967915334, 0.023702684666204732, 0.06463768586399965, 0.04508163074206095, 0.04300592532672454, 0.021678330303984694, 0.011776377068599686, 0.014355216862895759, 0.05674746120348573, 0.0268266569764819, 0.021992225374560803, 0.039482248976128176, 0.0845728040440008, 0.029088966148265172, 0.053892359719611704, 0.03689470286190044, 0.004621912048605736, 0.06281189867877401, 0.02979233660880709, 0.020427462659426965, 0.03662581162643619, 0.06883033784106374, 0.5209578643552959, 2.138101807795465, 10.767603814601898, 21.91272497177124, 28.0553974583745, 38.55779640376568, 44.301902577281, 41.39111056923866, 42.36111871898174, 33.90310317277908, 26.229604929685593, 29.52858030796051, 23.937978297472, 20.297401249408722, 34.336880296468735, 22.987164817750454, 22.669788748025894, 25.077763237059116, 16.052343137562275, 19.74382795393467, 25.76767321676016, 21.100683845579624, 15.872616581618786, 16.116947270929813, 19.20235700905323, 20.014004856348038, 18.473958894610405, 20.239583551883698, 17.617994025349617, 21.292761638760567, 19.847788475453854, 21.54439553618431, 16.840831227600574, 16.644488163292408, 21.3143140822649, 30.135158859193325, 26.425351426005363, 17.041439563035965, 20.64564686268568, 24.88408572971821, 20.46754851937294, 23.550032414495945, 26.387638449668884, 33.130232244729996, 39.179142862558365, 27.492516562342644, 27.23296768963337, 24.78539552539587, 30.72428684681654, 29.639857336878777, 39.662218540906906, 30.593423768877983, 24.645158350467682, 11.961157768964767, 5.003496464341879, 2.416261131875217, 0.20765250432305038, 0.04053682598168962, 0.05436367173388135, 0.09101073475903831, 0.055214848325704224, 0.030867708592268173, 0.01843305210059043, 0.01260736353287939, 0.027498341441969387, 0.0731725399964489, 0.037423820758704096, 0.025202707984135486, 0.017096637093345635, 0.10279379857820459, 0.03326223508338444, 0.043199529391131364, 0.013645750586874783, 0.02108529493852984, 0.031851905878284015, 0.00659362865917501, 0.03812696857494302, 0.06467097860877402, 0.035734429184230976, 0.034892291951109655, 0.056099974462995306, 0.0357590128260199, 0.00981263483481598, 0.04737491901323665, 0.024345260244444944, 0.06877233157865703, 0.05042418859375175, 0.07601312507176772, 0.07538077814388089, 0.042366138368379325, 0.055574452271685004, 0.029442434388329275, 0.02730039952439256, 0.06341904969303869, 0.02949058121885173, 0.04689912071626168, 0.058288605068810284, 0.009062823555723298, 0.03474820769042708, 0.06874164377222769, 0.07229303562780842, 0.035157494712620974, 0.05154189268068876, 0.015682708472013474, 0.02946596603578655, 0.047538224898744375, 0.02179972896556137, 0.029076954488118645, 0.028681950097961817, 0.014318301509774756, 0.0894952988892328, 0.05621884796710219, 0.08903522670152597, 0.03053550473850919, 0.05172236073121894, 0.036157319773337804, 0.0027274634476270876, 0.030755148909520358, 0.009940003146766685, 0.08827401325106621, 0.026745853792817798, 0.06744124519173056, 0.06308307201834396, 0.05181793821975589, 0.06341296408209018, 0.08000667367014103, 0.018380649053142406, 0.028172757010906935, 0.013982370219309814, 0.05960894144664053, 0.02956979991722619, 0.048419792437925935, 0.015247645733325044, 0.023453558678738773, 0.0501776731107384, 0.032572709387750365, 0.006512039726658259, 0.051064940344076604, 0.028975692148378585, 0.05490216666657943, 0.03073500145546859, 0.05872682100743987, 0.015547091188636841, 0.028403290343703702, 0.11890175766893663, 0.0442896070308052, 0.019957677614002023, 0.051585022592917085, 0.01868887040473055, 0.028059121214027982, 0.03691949801577721, 0.013913427483203122, 0.060209795337868854, 0.02374177915044129, 0.02491515358997276, 0.04906435511657037, 0.02224861142167356, 0.03812768845818937, 0.02459066436131252, 0.01298201266763499, 0.05343286269635428, 0.029432599076244514, 0.0032691294381947955, 0.04257924607372843, 0.025311389945272822, 0.05048389437433798, 0.0749216707481537, 0.031217273135553114, 0.05224814638495445, 0.0493025103060063, 0.02928878013335634, 0.02042314335994888, 0.021555182029260322, 0.015642704856873024, 0.05927344616793562, 0.07182446584920399, 1.0451343934983015, 3.506979066878557, 14.50810220092535, 26.25976961106062, 36.19561515748501, 43.72797757387161, 48.96215870976448, 45.96627026796341, 46.56062677502632, 37.9978546500206, 31.314085498452187, 33.12374599277973, 25.75049053877592, 21.41946204006672, 31.68609693646431, 25.29262650758028, 25.64407154917717, 27.684189677238464, 22.01214473694563, 24.957701079547405, 30.107342451810837, 27.58113730698824, 25.261998251080513, 24.974082000553608, 24.58399873226881, 25.851741805672646, 22.94037412852049, 29.34474427253008, 25.00869244337082, 26.78578108549118, 25.013162903487682, 23.623974546790123, 22.822437956929207, 22.913007996976376, 26.86626836657524, 34.687331691384315, 26.958730705082417, 25.08616268634796, 26.930431723594666, 34.96615692973137, 27.31421872973442, 27.981423027813435, 31.93925455212593, 40.493264347314835, 35.07284380495548, 22.24635846912861, 27.789744213223457, 26.41774233430624, 32.51127205789089, 35.569743141531944, 43.537626788020134, 36.712311431765556, 29.953131526708603, 16.106167249381542, 8.439528588205576, 3.8475115690380335, 0.646093402756378, 0.17760481510777026, 0.05298414907883853, 0.10905125382123515, 0.02354649783228524, 0.015604436011926737, 0.0294613294681767, 0.038212434301385656, 0.03057304071262479, 0.08746065650484525, 0.01865811394964112, 0.05079463531728834, 0.06745147198671475, 0.03070015762205003, 0.05724609538447112, 0.0269788362129475, 0.0550706193462247, 0.023018663850962184, 0.033119494109996594, 0.037002336539444514, 0.01725403177260887, 0.03814852054347284, 0.037955595544190146, 0.030313550632854458, 0.04985187028069049, 0.007543248821093584, 0.04957801036653109, 0.07496458914829418, 0.0179286941056489, 0.0554581503092777, 0.017008186077873688, 0.023260882298927754, 0.05279462682665326, 0.052067748838453554, 0.03394700361241121, 0.04343413711467292, 0.06023551817634143, 0.029165698651922867, 0.004581719185807742, 0.04335285339038819, 0.0668012689857278, 0.02048881786322454, 0.052263653560657986, 0.012233561374159763, 0.019995749789814, 0.048137861667783, 0.027803603479696903, 0.03309494015411474, 0.09984291551518254, 0.037007731953053735, 0.04771375024574809, 0.020083811177755706, 0.07775987352943048, 0.10763180733192712, 0.05129014505655505, 0.04872121942753438, 0.07179474283475429, 0.13948819949291646, 0.20425720838829875, 0.1531608306686394, 0.1257758040446788, 0.23326684080529958, 0.10060581364086829, 0.13249890500446782, 0.16508512519067153, 0.12018438181257807, 0.2142994906171225, 0.15253580873832107, 0.17210613907082006, 0.15060505218571052, 0.19845396978780627, 0.07942845899378881, 0.21769156563095748, 0.09798958722967654, 0.06649122937233187, 0.16633435268886387, 0.07705256968620233, 0.10414665957796387, 0.1570383890066296, 0.13923864491516724, 0.16748358320910484, 0.23433485068380833, 0.07300531928194687, 0.11113901171484031, 0.27282829920295626, 0.1861477066995576, 0.11307271459372714, 0.16103089117677882, 0.28942153381649405, 0.1387420145329088, 0.08430626170593314, 0.12759339791955426, 0.11381704418454319, 0.12491372530348599, 0.1612310780910775, 0.14103810070082545, 0.16757661884184927, 0.11004053667420521, 0.17018854821799323, 0.11864058105857112, 0.11229548559640534, 0.14365857961820439, 0.07841063314117491, 0.1630558559554629, 0.09731061858474277, 0.07141753885662183, 0.11237471728236414, 0.1331016476615332, 0.08576582869864069, 0.15856955840718, 0.13664442318258807, 0.11630663051619194, 0.15322847000788897, 0.2431840414647013, 0.13565006403950974, 0.18961181456688792, 0.17570984491612762, 0.0549884227802977, 0.1206331659341231, 0.2051270945230499, 1.0053626401349902, 3.6781168961897492, 14.373035598546267, 28.190556205809116, 40.38884215056896, 51.8111964315176, 58.65232273936272, 55.10075591504574, 56.37221708893776, 48.61234188079834, 39.21928010880947, 42.46022880077362, 36.70020908117294, 31.3581308349967, 48.67453694343567, 35.36759398877621, 38.81697289645672, 34.98337760567665, 26.330423019826412, 31.71857189387083, 39.30926688015461, 33.26959356665611, 29.502483308315277, 28.031688630580902, 28.506894931197166, 30.16626589000225, 27.08915490657091, 30.735655836760998, 25.874869264662266, 30.706857182085514, 29.64349754154682, 28.771978206932545, 26.834638863801956, 25.520686469972134, 31.337689831852913, 39.25801523029804, 35.092766135931015, 25.887053310871124, 30.001242645084858, 37.322478890419006, 30.71821667253971, 33.59193406999111, 38.37149620056152, 49.546339362859726, 52.049162462353706, 34.67502035200596, 39.34157654643059, 37.69298940896988, 39.62124913930893, 43.784507140517235, 50.771587416529655, 42.43453077971935, 32.532653510570526, 18.070188760757446, 8.506168462336063, 3.9313799561932683, 0.7307809428311884, 0.19073317002039403, 0.1789764524437487, 0.19239011860918254, 0.11553784715943038, 0.2164402898051776, 0.09219615982146934, 0.10283944066031836, 0.1536992736510001, 0.13933271955465898, 0.07414597799652256, 0.16295245994115248, 0.1583352030138485, 0.15479232359211892, 0.14247090584831312, 0.12370084077701904, 0.11391736028599553, 0.2064430114114657, 0.08349126481334679, 0.15019197278888896, 0.19621749292127788, 0.1518752527772449, 0.13558405742514879, 0.13939881522674114, 0.12453977193217725, 0.11668426493997686, 0.08624047666671686, 0.1684793524327688, 0.12809234380256385, 0.12176033982541412, 0.11332808760926127, 0.1959927854477428, 0.11190279299626127, 0.08429959721979685, 0.16693878744263202, 0.1677090031444095, 0.1295008510351181, 0.10906417461228557, 0.11907621432328597, 0.16395223676227033, 0.10748329616035335, 0.09921967473928817, 0.15696923568611965, 0.2393718366511166, 0.1611739327199757, 0.15951892855810001, 0.15599963458953425, 0.1143225358100608, 0.1776322745718062, 0.1438732087262906, 0.0687873229617253, 0.1231083768652752, 0.1359876521746628, 0.19412471068790182, 0.23857643245719373, 0.1437799949781038, 0.18221797537989914], [0.01803383416699944, 0.027717724005924538, 0.09157425491139293, 0.09799091567401774, 0.04292920581065118, 0.038410112756537274, 0.059267787291901186, 0.060564304440049455, 0.046077808146947064, 0.01675765928666806, 0.029752783848380204, 0.0958469846227672, 0.07776857892167754, 0.04303626803448424, 0.019646778964670375, 0.02729767955315765, 0.12054980048560537, 0.09356799753732048, 0.03604938923672307, 0.08926591588533483, 0.03325054254673887, 0.027085638685093727, 0.009491994569543749, 0.0737266126088798, 0.06952104726224206, 0.01401587447617203, 0.10691305215004832, 0.016442125925095752, 0.028029554050590377, 0.09622219964512624, 0.021520299233088735, 0.05045305071689654, 0.08543514995835721, 0.04579964377626311, 0.01918250993185211, 0.026242468011332676, 0.027239558257861063, 0.04113776521990076, 0.020517314478638582, 0.0562743531918386, 0.04428377375006676, 0.03476244579360355, 0.02271952082082862, 0.0369494214100996, 0.06756650487659499, 0.038264796530711465, 0.026231027804897167, 0.04891264528851025, 0.01781275208486477, 0.02337153837288497, 0.030596449905715417, 0.06940413673873991, 0.1068305030639749, 0.049431380539317615, 0.011348082716722274, 0.05896312082768418, 0.005298966880218359, 0.02224726998974802, 0.03124413145997096, 0.07380789262242615, 0.04972617643943522, 0.08094762786640786, 0.041086616402026266, 0.07125083764549345, 0.058748736628331244, 0.48237900948151946, 4.450100809335709, 9.831973370164633, 23.331946916878223, 36.57584935426712, 42.104028314352036, 44.746900498867035, 42.02584370970726, 40.76778821647167, 39.386550933122635, 42.66777366399765, 34.20380383729935, 40.439181849360466, 24.113352186977863, 27.913533970713615, 29.536071605980396, 30.118548050522804, 31.30052212625742, 21.359886936843395, 19.434163570404053, 28.38195003569126, 21.538131572306156, 21.60162426531315, 19.210636764764786, 14.18489534407854, 16.5359203889966, 25.417358614504337, 25.222503170371056, 29.5078182220459, 20.10039322078228, 25.141932293772697, 21.835241429507732, 25.41708692908287, 56.520211547613144, 40.70191875100136, 16.651105508208275, 23.827681615948677, 21.838294565677643, 27.02089536935091, 30.755931548774242, 22.836010828614235, 31.852784492075443, 41.85054011642933, 34.57656003534794, 34.77416843175888, 39.04776111245155, 30.34748576581478, 30.295894034206867, 22.950204201042652, 12.421516366302967, 4.584703836590052, 1.097494752611965, 0.3850289457477629, 0.11246108100749552, 0.046600313507951796, 0.12146810433478095, 0.04548752243863419, 0.07450888078892604, 0.00494028551656811, 0.035623800940811634, 0.03402866583201103, 0.019385717387194745, 0.01396714227666962, 0.028862119434052147, 0.06743074380210601, 0.062313598464243114, 0.03821965539827943, 0.043587331238086335, 0.0493674667814048, 0.04611237738572527, 0.018264708887727465, 0.02887960072257556, 0.04087395398528315, 0.027041807443310972, 0.0644013712008018, 0.0419116211560322, 0.039401069152518176, 0.04603597328241449, 0.0668076217698399, 0.029847331607015803, 0.05130783414642792, 0.02983129565109266, 0.03224377469450701, 0.011473174490674865, 0.01890409508632729, 0.0814457425440196, 0.06155914226837922, 0.016601951138000004, 0.05993551982101053, 0.09351460743346252, 0.041672612496768124, 0.06056935104425065, 0.019784718242590316, 0.028465424802561756, 0.03695348095789086, 0.044085976551286876, 0.031070611767063383, 0.021688920751330443, 0.04670888229156844, 0.05621138567221351, 0.05884640326257795, 0.09704679250717163, 0.014051901107450249, 0.030997742142062634, 0.03433189252973534, 0.027862140377692413, 0.016264964142465033, 0.026179801061516628, 0.023244497533596586, 0.08491811051499099, 0.05705183451937046, 0.034480448230169713, 0.009002087117551127, 0.03795217795413919, 0.05227179120993242, 0.014005708908371162, 0.015305708584492095, 0.06348720111418515, 0.017918062840180937, 0.054221862155827694, 0.022192941069079097, 0.014583138763555326, 0.05495563840668183, 0.01922397372254636, 0.019649786518129986, 0.00921032355108764, 0.043806724934256636, 0.06361614927300252, 0.04191568812530022, 0.03317340371722821, 0.07385513032204472, 0.06098509104049299, 0.02494527736416785, 0.08014650171389803, 0.05181364489544649, 0.07503263666876592, 0.062469612748827785, 0.017898644546221476, 0.021843098220415413, 0.058860960489255376, 0.03185649977240246, 0.035559961397666484, 0.0720982144412119, 0.054632878382108174, 0.04123632985283621, 0.04553703482088167, 0.0562624676967971, 0.021719526921515353, 0.03502953361021355, 0.036474509979598224, 0.029644472961081192, 0.026390331659058575, 0.022453136189142242, 0.02564649003033992, 0.06269186371355318, 0.043933346460107714, 0.06798481641453691, 0.023315669495787006, 0.03999347369244788, 0.019188517617294565, 0.051705161458812654, 0.026897023708443157, 0.03909285893314518, 0.024059756033238955, 0.02290110023750458, 0.015264433113770792, 0.021221777751634363, 0.09342118588392623, 0.05477997947309632, 0.03257822354498785, 0.04169053536315914, 0.07852710579754785, 0.10045256756711751, 0.019902925669157412, 0.08684238069690764, 0.17640629113884643, 1.1014721891842782, 6.442650239914656, 13.917818125337362, 28.40459682047367, 41.46739907562733, 47.16077037155628, 49.2961797863245, 47.81268998980522, 43.19928914308548, 44.07128155231476, 42.403395250439644, 37.07412801682949, 42.87168592214584, 29.771915450692177, 33.20294514298439, 32.2914082556963, 23.606408089399338, 29.49553918093443, 23.702200949192047, 20.190693475306034, 24.554436318576336, 20.18759474158287, 23.29848401248455, 21.815091110765934, 19.743088893592358, 22.142871022224426, 26.722622774541378, 30.518563985824585, 33.32693248987198, 26.706849820911884, 28.347130604088306, 25.945298485457897, 26.54298171401024, 59.30643104016781, 48.14454898238182, 20.98804648965597, 24.814372770488262, 21.29721499979496, 23.86266253888607, 30.90501844882965, 25.416661351919174, 34.806398302316666, 46.19623012840748, 35.13332135975361, 38.40865820646286, 40.375569462776184, 36.965818628668785, 32.84867115318775, 28.367831893265247, 16.875004693865776, 7.590713035315275, 2.0714298728853464, 0.8320323284715414, 0.1208427558594849, 0.01946915148437256, 0.07669751139474101, 0.01665893323661294, 0.05738724074035417, 0.057357877667527646, 0.039711695062578656, 0.007965062832226977, 0.013198865435697371, 0.01276741510082502, 0.024212566095229704, 0.03422830726776738, 0.07214865821879357, 0.029061749737593345, 0.08028438533074223, 0.037784742016810924, 0.05092866347695235, 0.023675765114603564, 0.03664000891149044, 0.020847290033998434, 0.03758033970370889, 0.0667569405050017, 0.026589423905534204, 0.020112393140152562, 0.0314389712002594, 0.04467052174732089, 0.021467154037964065, 0.025538164300087374, 0.039838706215959974, 0.028872182956547476, 0.04322740074712783, 0.03991566693002824, 0.034352999209659174, 0.06209933300851844, 0.03164314715832006, 0.003734098640961747, 0.047555817509419285, 0.044302820970187895, 0.011815440011559986, 0.11025640516891144, 0.08055004451307468, 0.017616262921364978, 0.02620905466756085, 0.05247048269666266, 0.06386275010299869, 0.06545721727889031, 0.03534127645252738, 0.061009322162135504, 0.030944554273446556, 0.021347080109990202, 0.04692519978561904, 0.06870887795230374, 0.009438503348064842, 0.033573061373317614, 0.03647907047707122, 0.05259938261588104, 0.047289776121033356, 0.00869173487444641, 0.1479461300186813, 0.18163400905905291, 0.18573533976450562, 0.19208036101190373, 0.15259568521287292, 0.11503613306558691, 0.10848864651052281, 0.14796311035752296, 0.17096171766752377, 0.14930739213014022, 0.11595474861678667, 0.0845396077784244, 0.19690783869009465, 0.0846189507865347, 0.08987907087430358, 0.1499379801680334, 0.27427216235082597, 0.17880737636005506, 0.11804611334810033, 0.20865685277385637, 0.19328216527355835, 0.12287463003303856, 0.1632304536178708, 0.1392575993668288, 0.1746286396519281, 0.12813759996788576, 0.16806622850708663, 0.13132864201907068, 0.09631029999582097, 0.09868477922282182, 0.08292562954011373, 0.20999988773837686, 0.14380993321537971, 0.11186541843926534, 0.16014365362934768, 0.1753339619608596, 0.1840469686430879, 0.1626006225706078, 0.12622331909369677, 0.2298428534413688, 0.10037232656031847, 0.20082268252735958, 0.045782207016600296, 0.12952268501976505, 0.12593600404215977, 0.1489568906254135, 0.13241321663372219, 0.12710936920484528, 0.11488752541481517, 0.18732666765572503, 0.05138810112839565, 0.18634160020155832, 0.15872315329033881, 0.1213146281952504, 0.1177946588722989, 0.2314688841579482, 0.15233623038511723, 0.11519240710185841, 0.11467550124507397, 0.1299806495080702, 0.09305216779466718, 0.2835735585540533, 0.09054407972143963, 0.1883948259637691, 0.1773071990464814, 1.2834383687004447, 6.574995713308454, 14.941961020231247, 30.4940951988101, 45.50241015851498, 53.12155231833458, 59.65769559144974, 56.786797642707825, 55.54520666599274, 55.73103189468384, 58.34251016378403, 45.16063369810581, 56.19027145206928, 35.349772945046425, 41.095741018652916, 40.78619062900543, 41.58815659582615, 45.15812963247299, 34.71932217478752, 30.350685194134712, 41.66782692074776, 31.635989025235176, 34.50311757624149, 32.1075589209795, 24.45181332528591, 27.076936662197113, 35.47593757510185, 36.04000210762024, 45.28577618300915, 29.738813526928425, 34.417941346764565, 34.546192064881325, 36.76550857722759, 66.92919820547104, 50.86043044924736, 27.611877657473087, 33.212733417749405, 34.81881983578205, 36.05270482599735, 42.12629891932011, 31.8331528455019, 44.47665520012379, 54.95429277420044, 46.54017627239227, 45.98070949316025, 52.135813012719154, 43.91631066799164, 41.24912738800049, 30.248100198805332, 19.39309347420931, 8.21234542876482, 2.3394135804846883, 0.9671870979946107, 0.20492702635237947, 0.10642123088473454, 0.25041811109986156, 0.11411455634515733, 0.244987549376674, 0.141526211227756, 0.11417906382121146, 0.12121436404413544, 0.20183161745080724, 0.13107669772580266, 0.13601192040368915, 0.19872428965754807, 0.20372416824102402, 0.07889807573519647, 0.1717241111327894, 0.15087742038303986, 0.1755345199489966, 0.11564314307179302, 0.09114453656366095, 0.10446628031786531, 0.16994325356790796, 0.16628642479190603, 0.0924340404162649, 0.0902513915207237, 0.14413817028980702, 0.20669226913014427, 0.14405536145204678, 0.0858721487747971, 0.15843733737710863, 0.09943831144482829, 0.05574169896135572, 0.14968710456741974, 0.10547603902523406, 0.20895691792247817, 0.11380220123101026, 0.1866139387129806, 0.18397768173599616, 0.1912261638790369, 0.08967135116108693, 0.16149970586411655, 0.14213042333722115, 0.15578735066810623, 0.08368228620383888, 0.13764929113676772, 0.17622164479689673, 0.12341357025434263, 0.08999416313599795, 0.2087535843020305, 0.16582201846176758, 0.0870310643222183, 0.14637890708399937, 0.167901442036964, 0.14417609403608367, 0.18534032424213365, 0.14588678895961493, 0.1738490877323784, 0.212042010971345, 0.08820201750495471], [0.008239702001446858, 0.03533876057190355, 0.029972535630804487, 0.034388963686069474, 0.09317030286183581, 0.11895245377672836, 0.06466665930929594, 0.041484559696982615, 0.01768087244272465, 0.044475255272118375, 0.04363168198324274, 0.058277877324144356, 0.03712688747327775, 0.045990535290911794, 0.04787746431247797, 0.014732324361830251, 0.02397893986199051, 0.022918182621651795, 0.05492312120622955, 0.07715272993664257, 0.018665739517018665, 0.02555114075221354, 0.019873356650350615, 0.06321719294646755, 0.023216642875922844, 0.008244272703450406, 0.059877309467992745, 0.04453616333194077, 0.020590967069438193, 0.0411089402041398, 0.044988083027419634, 0.02313690467417473, 0.036199585083522834, 0.06625822468777187, 0.041655995810288005, 0.0572926428867504, 0.09052442765096202, 0.02922357318311697, 0.040909543677116744, 0.04363331099739298, 0.04202525509754196, 0.06013220379827544, 0.046591786231147125, 0.026705033815233037, 0.02467816542775836, 0.06010773890011478, 0.030820717656752095, 0.018930855076177977, 0.0323748862138018, 0.028503040557552595, 0.0281024737705593, 0.05344962410163134, 0.008143822087731678, 0.05934826949669514, 0.03184525623510126, 0.027985657870885916, 0.05009664913814049, 0.05630087383906357, 0.05419751971203368, 0.0582935589045519, 0.030959656978666317, 0.02596815538709052, 0.012740063248202205, 0.04622354739694856, 0.027027029427699745, 0.07145330295315944, 0.21289531752699986, 1.2263870425522327, 4.254636922851205, 12.127354200929403, 18.770276494324207, 31.328270137310028, 35.37119619548321, 40.6813770532608, 47.438033893704414, 51.65755547583103, 52.15182155370712, 51.91141225397587, 42.49289944767952, 45.2553816139698, 41.64307504892349, 43.996227979660034, 35.002178996801376, 31.718019023537636, 28.843433372676373, 29.446149431169033, 30.075739547610283, 24.19831942766905, 28.659745529294014, 22.01010424643755, 26.970511972904205, 34.147471860051155, 18.61439935863018, 19.992152228951454, 18.60265038907528, 22.172678522765636, 26.956680715084076, 25.463064461946487, 84.45879757404327, 45.74239768087864, 19.397997111082077, 29.136080369353294, 40.68147584795952, 35.31709849834442, 33.022751212120056, 35.89352376759052, 42.2131622582674, 38.678884506225586, 40.057431533932686, 34.34504985809326, 33.16162995994091, 19.368349201977253, 12.783445045351982, 4.588910210877657, 1.7003842955455184, 0.17083240585634485, 0.03294298912805971, 0.009560899270582013, 0.031785324099473655, 0.06494543224107474, 0.041871522917062975, 0.05202470798394643, 0.05374577442125883, 0.0031103631772566587, 0.05705246905563399, 0.0451925669767661, 0.009202356595778838, 0.03185316381859593, 0.040901947795646265, 0.01711543012788752, 0.035144622161169536, 0.07420774694764987, 0.05549089386477135, 0.11174239261890762, 0.05227819965512026, 0.03342543335747905, 0.03948190758819692, 0.028304477091296576, 0.04749511354020797, 0.044268036508583464, 0.009618559506634483, 0.03292554865765851, 0.02682385536900256, 0.008055492598941782, 0.06444688711781055, 0.022381979069905356, 0.01582984481501626, 0.02552201331127435, 0.034414497276884504, 0.0015474240581170307, 0.03758344930247404, 0.09140152746113017, 0.058248751738574356, 0.05333745590178296, 0.016205601605179254, 0.049414604291087016, 0.06185670637933072, 0.023335546065936796, 0.03483156942820642, 0.10148182991542853, 0.03847950356430374, 0.07495829573599622, 0.025747158651938662, 0.05447779178211931, 0.055293686673394404, 0.01391748053720221, 0.037698137093684636, 0.03133913749479689, 0.05724918642954435, 0.03972559919930063, 0.015368558288173517, 0.024663584081281442, 0.04810662838281132, 0.027733570714190137, 0.02680551875528181, 0.030648240681330208, 0.029304023846634664, 0.047051940055098385, 0.009728994791657897, 0.02298637857165886, 0.020533612041617744, 0.029838199479854666, 0.07708258213824593, 0.03949269470467698, 0.010262869855068857, 0.029263929318403825, 0.09415180800715461, 0.022372878484020475, 0.04482338190427981, 0.03983762639109045, 0.047006093882373534, 0.02140251668606652, 0.022204663291631732, 0.041313661640742794, 0.006728906409989577, 0.03630164523201529, 0.046987343521323055, 0.01733703727950342, 0.025591790035832673, 0.055499057489214465, 0.022631004867434967, 0.017554236073920038, 0.03966521435359027, 0.030531920165230986, 0.02390160436334554, 0.025423545157536864, 0.06223035175935365, 0.05589396540017333, 0.04837570886593312, 0.019397740179556422, 0.07873424663557671, 0.03208631693269126, 0.07592115813167766, 0.03300749660411384, 0.03294294830993749, 0.05195453792111948, 0.03806255015661009, 0.03894395813404117, 0.00374660035049601, 0.06788642247556709, 0.05811722090584226, 0.04705875297077, 0.034953916183440015, 0.02365664182434557, 0.06713930983096361, 0.045368300125119276, 0.007556250320703839, 0.053052701259730384, 0.029102649496053346, 0.027950862277066335, 0.019912432580895256, 0.013356394629226997, 0.046175997995305806, 0.03635701315943152, 0.038116585928946733, 0.0507186208415078, 0.08860139685566537, 0.023489792183681857, 0.059852362173842266, 0.05561930767726153, 0.08267723271274008, 0.050490558860474266, 0.3526830329792574, 1.6194326081313193, 6.0799620766192675, 15.969456285238266, 25.261135697364807, 38.37662972509861, 41.52838200330734, 48.785574585199356, 54.01732385158539, 57.75678679347038, 58.199440240859985, 54.72395293414593, 45.983665734529495, 45.06185419857502, 44.574701339006424, 43.88657346367836, 37.75145307183266, 32.53909416496754, 27.19418317079544, 29.369385950267315, 27.506427615880966, 25.287852063775063, 31.32369328290224, 23.614672645926476, 24.50791161507368, 35.91846562922001, 22.03075233846903, 24.49527159333229, 18.334088400006294, 18.85711133480072, 26.26900501549244, 27.292141914367676, 88.9919239282608, 50.67637212574482, 17.261987328529358, 26.719258055090904, 34.947974905371666, 30.1332950592041, 32.54921682178974, 37.913943752646446, 43.28809417784214, 46.00958414375782, 45.91090723872185, 39.83628340065479, 38.663920909166336, 23.882039599120617, 17.722617611289024, 7.549330880865455, 2.568005039356649, 0.44961995794437826, 0.11887938191648573, 0.015023938303784234, 0.0627379139768891, 0.022211147806956433, 0.03567355452105403, 0.021619722901959904, 0.03683616225316655, 0.0359671407204587, 0.05232242794591002, 0.08397624347708188, 0.038605271620326675, 0.01771378483681474, 0.03431040735449642, 0.08000173096661456, 0.05861795165401418, 0.02670885773113696, 0.06452545087086037, 0.17050934897270054, 0.031232364708557725, 0.023801974748494104, 0.048636247229296714, 0.09514451216091402, 0.030072736699366942, 0.0427202763967216, 0.11831844443804584, 0.08600641813245602, 0.03637417532445397, 0.048049664837890305, 0.055886376940179616, 0.04948961686750408, 0.025961325773096178, 0.08333274206961505, 0.01914515763928648, 0.01623814107006183, 0.06198608498380054, 0.034881319297710434, 0.08851336329826154, 0.0336889922618866, 0.06983398867305368, 0.014096855775278527, 0.02223391318693757, 0.02123478945577517, 0.028109385020798072, 0.04766774822201114, 0.045214567944640294, 0.034212250902783126, 0.016513349837623537, 0.03757360471354332, 0.020451072232390288, 0.018329067934246268, 0.05370586542994715, 0.07546411390649155, 0.0742547916888725, 0.06775355577701703, 0.03626913545303978, 0.012212014044052921, 0.04794408319867216, 0.012011117451038444, 0.07139381239539944, 0.016069168887042906, 0.1735440650372766, 0.1489401180879213, 0.12308853925787844, 0.14711991185322404, 0.18952251935843378, 0.2216369562665932, 0.18030108214588836, 0.09676013054559007, 0.10203902696957812, 0.11983749456703663, 0.20989469572668895, 0.15075360046466812, 0.12690354196820408, 0.13574173412052915, 0.14347577380249277, 0.10959538907627575, 0.0817552329681348, 0.17423579120077193, 0.13287204201333225, 0.22473417600849643, 0.09611833607777953, 0.06744667771272361, 0.1496137655340135, 0.10631805009325035, 0.12674304511165246, 0.1008594871382229, 0.17122546210885048, 0.08338968706084415, 0.09926416649250314, 0.09436999200261198, 0.13013850431889296, 0.1546853207401, 0.09298662131186575, 0.20937857654644176, 0.18062011658912525, 0.11765864546759985, 0.2170138363726437, 0.13464292511343956, 0.14117475977400318, 0.14897762623149902, 0.10274927713908255, 0.12015183863695711, 0.15272603603079915, 0.11401207317248918, 0.1227773270511534, 0.13242344342870638, 0.14604317431803793, 0.11315382391330786, 0.1778367956285365, 0.12794581416528672, 0.1611691087600775, 0.12353295212960802, 0.10330200646421872, 0.11372883251169696, 0.16745232394896448, 0.10121168073965237, 0.10008552359067835, 0.09646342732594348, 0.14468741894233972, 0.19897250836947933, 0.12364932088530622, 0.14789983484661207, 0.20938641362590715, 0.1987798765185289, 0.19005955226020887, 0.11371203028829768, 0.37146278307773173, 2.017720704898238, 6.479227552190423, 16.85556683689356, 25.89673139154911, 40.75359597802162, 46.13696850836277, 55.62052622437477, 63.069863095879555, 66.33984223008156, 68.0176194012165, 67.60345682501793, 55.47336392104626, 60.478888526558876, 53.74418690800667, 56.40092074871063, 49.5054117590189, 43.58463406562805, 41.44762493669987, 43.20433147251606, 42.759865522384644, 36.66113957762718, 43.81298281252384, 33.71818229556084, 40.49879305064678, 49.12856698036194, 29.51737090945244, 35.84941953420639, 29.260303303599358, 32.630882039666176, 41.10771417617798, 32.9801706969738, 95.67397937178612, 53.52636359632015, 27.050911858677864, 39.66808542609215, 53.790867403149605, 44.45990949869156, 45.96278205513954, 47.57201850414276, 54.097609743475914, 54.44654501974583, 54.80759024620056, 47.85142511129379, 44.76951688528061, 27.551293708384037, 18.751938678324223, 7.947757551446557, 2.809422709979117, 0.4462411080021411, 0.20594664820237085, 0.16693338460754603, 0.14013699983479455, 0.13763962837401778, 0.10545313634793274, 0.10577324690530077, 0.10896697553107515, 0.15766897704452276, 0.12026554308249615, 0.16055100364610553, 0.12295835913391784, 0.08611804456450045, 0.13409011415205896, 0.18311420775717124, 0.11523804176249541, 0.12952583172591403, 0.18313749635126442, 0.22452903154771775, 0.15861007967032492, 0.08813676788122393, 0.21175634348765016, 0.14514480455545709, 0.1580538845155388, 0.14414847129955888, 0.1767362648388371, 0.1614962622988969, 0.13973215827718377, 0.14145296125207096, 0.18500840611523017, 0.12997530604479834, 0.12758921220665798, 0.13560473365942016, 0.11329449800541624, 0.08070104930084199, 0.16923430957831442, 0.1687185317859985, 0.15778442553710192, 0.19663351122289896, 0.13420214876532555, 0.14815600938163698, 0.14927216980140656, 0.07933766464702785, 0.1376520370831713, 0.17783304036129266, 0.23293187987292185, 0.18815570598235354, 0.1617344026453793, 0.200023137149401, 0.12792406923836097, 0.12598390225321054, 0.13264509325381368, 0.12744912441121414, 0.2732836513314396, 0.2401619715965353, 0.09899316384689882, 0.08313352736877277, 0.1071168681664858, 0.08659426588565111, 0.08752879308303818, 0.1281040400499478], [0.037054149579489604, 0.06566495183506049, 0.006066574396754731, 0.05292422807542607, 0.059024670845246874, 0.07449061653460376, 0.04860907720285468, 0.0791575454059057, 0.023981457597983535, 0.011835817531391513, 0.04479850140342023, 0.028049441752955317, 0.0053121219116292195, 0.045974196909810416, 0.03110332749201916, 0.022169687727000564, 0.03722544468473643, 0.034680816970649175, 0.027319567343511153, 0.018514480543672107, 0.06339454397675581, 0.07131721533369273, 0.06442795493057929, 0.03992725927673746, 0.02181301711971173, 0.02798746500047855, 0.09614798487746157, 0.06251700629945844, 0.05065619508968666, 0.06543991781654768, 0.04020246989966836, 0.004689754086939502, 0.015053349616209744, 0.04231336424709298, 0.024325144331669435, 0.05701968839275651, 0.028348256382741965, 0.08024636510526761, 0.04863855901930947, 0.03521172344335355, 0.0398742662218865, 0.03356387729581911, 0.03621984942583367, 0.04498729635088239, 0.05226439570833463, 0.051409649386187084, 0.058094277410418727, 0.01783880146831507, 0.04594286343490239, 0.02061844879790442, 0.05001756588171702, 0.02780600803816924, 0.017412003471690696, 0.09357368981000036, 0.010851916176761733, 0.021173532586544752, 0.006928417506060214, 0.017899523991218302, 0.032329975147149526, 0.0468319229548797, 0.0404433450603392, 0.01675169427471701, 0.049174278319696896, 0.06336410107905976, 0.041016360992216505, 0.025620377564337105, 0.06350193274556659, 0.02210732505773194, 0.1684004918206483, 1.0672811488620937, 2.453334555029869, 7.552222525700927, 17.2839330509305, 22.8236747905612, 27.104428187012672, 26.738817505538464, 42.8327190130949, 42.86903366446495, 47.16163292527199, 52.472243160009384, 51.605198085308075, 47.81889885663986, 55.09891681373119, 42.82152481377125, 45.10885387659073, 42.93166570365429, 40.928420796990395, 39.106528759002686, 30.892116241157055, 34.08751107752323, 34.30451363325119, 35.19642077386379, 32.54142343997955, 30.26598583906889, 37.53047212958336, 36.36077709496021, 28.767939023673534, 32.16901682317257, 72.27911353111267, 56.96202524006367, 29.420090429484844, 41.009645238518715, 39.128711968660355, 41.89783617854118, 44.47690598666668, 44.926988035440445, 42.56646350026131, 35.30293665826321, 27.577726989984512, 18.661737218499184, 9.507223796099424, 5.738543272018433, 1.3722388911992311, 0.18986016686540097, 0.0842369747988414, 0.04135965995374136, 0.05074057728052139, 0.06323218432953581, 0.040950970360427164, 0.042748730338644236, 0.046986723828013055, 0.03642877141828649, 0.05525209300685674, 0.05697295906429645, 0.05347113896277733, 0.06480254654888995, 0.031564186356263235, 0.042210517422063276, 0.027292323102301452, 0.05050432198913768, 0.036255001250538044, 0.04332562028139364, 0.08094714547041804, 0.01927104629430687, 0.05181819426070433, 0.05860874160134699, 0.05100340516946744, 0.022369011894625146, 0.02556227111199405, 0.04052484771818854, 0.033983491302933544, 0.04835888437810354, 0.032452878513140604, 0.030443764153460506, 0.03542800011928193, 0.05103212628455367, 0.025375622826686595, 0.00458516785329266, 0.008864882565831067, 0.014147013826004695, 0.045245519213494845, 0.05258143748505972, 0.036246577874408104, 0.03035652840480907, 0.022349372811731882, 0.05230795235547703, 0.058507976500550285, 0.03382456037797965, 0.03255379575421102, 0.04709367472969461, 0.02304711779288482, 0.20267156534828246, 0.04488307655265089, 0.047615686562494375, 0.03048228161787847, 0.07618617164553143, 0.08401693543419242, 0.017675380549917463, 0.0318740849616006, 0.04211422005027998, 0.06845550873549655, 0.033779419245547615, 0.09901435958454385, 0.010588039076537825, 0.012296006607357413, 0.09450349694816396, 0.005582536869042087, 0.04485458921408281, 0.047011303759063594, 0.05251498558209278, 0.052426584661589004, 0.07746265080641024, 0.030317142627609428, 0.006002769641781924, 0.05634611516143195, 0.007557219751106459, 0.022177342980285175, 0.03057017416722374, 0.052986063819844276, 0.03151323791826144, 0.08121890510665253, 0.029141617815184873, 0.029985419314471073, 0.028357436749502085, 0.012961504344275454, 0.028738366308971308, 0.026216349979222286, 0.027111621275253128, 0.06273661521845497, 0.018633986728673335, 0.009902543242787942, 0.08272314938949421, 0.018634457992448006, 0.0341213600768242, 0.05084374322905205, 0.017040833154169377, 0.0660479000362102, 0.0638945733953733, 0.02031144827924436, 0.07829967464203946, 0.03233313669625204, 0.02766504079772858, 0.028686538425972685, 0.05576444949838333, 0.04337639802542981, 0.04150471642788034, 0.008326570386998355, 0.020948372402926907, 0.04953254268912133, 0.04295690276194364, 0.030756130399822723, 0.0391108263283968, 0.022016829425410833, 0.021721217162848916, 0.007482044829885126, 0.03021154614543775, 0.03352619845827576, 0.03499083803035319, 0.03742136053915601, 0.018067110213451087, 0.0038423186151703703, 0.0607843957550358, 0.03693100130476523, 0.08703158382559195, 0.030074809146753978, 0.038246973854256794, 0.016214160423260182, 0.03643930620455649, 0.05932755986577831, 0.03517568846291397, 0.01976974726858316, 0.031946548260748386, 0.024119164954754524, 0.01193400181364268, 0.2989068935858086, 1.8019312340766191, 4.279147507622838, 11.243353486061096, 22.036737017333508, 28.40077232569456, 35.00413589179516, 38.73118110001087, 51.003511771559715, 49.77410674095154, 52.912776321172714, 58.074928522109985, 57.8780572861433, 53.22306767106056, 58.567727878689766, 46.85175955295563, 45.86415834724903, 44.59562301635742, 42.32264958322048, 42.18337185680866, 36.88800260424614, 36.99579522013664, 38.437852039933205, 38.61488074064255, 34.75953921675682, 34.278089851140976, 35.62958613038063, 35.11347122490406, 31.802503690123558, 34.13429796695709, 74.12180185317993, 57.30879843235016, 26.35702159255743, 39.15881775319576, 43.82311686873436, 44.662263840436935, 47.92904734611511, 52.44697071611881, 48.27622711658478, 40.816026628017426, 33.537011817097664, 23.057027868926525, 13.037492763251066, 7.417028630152345, 2.0876585645601153, 0.2723426674492657, 0.0852810058859177, 0.03041527310415404, 0.09254611213691533, 0.04377629687951412, 0.02876352140447125, 0.03660293121356517, 0.08480818360112607, 0.03965663141570985, 0.08490350504871458, 0.05451372286188416, 0.05790357514342759, 0.06493320906884037, 0.08975028598797508, 0.023954693897394463, 0.07146454649046063, 0.05613556786556728, 0.03446195762080606, 0.04130736822844483, 0.1386787835508585, 0.01656730211834656, 0.059473213768796995, 0.07013464011834003, 0.05295343158650212, 0.10568706871708855, 0.008948958620749181, 0.013083561661915155, 0.06382360181305557, 0.05473500903462991, 0.016115541984618176, 0.12805309903342277, 0.004037856670038309, 0.04251882783137262, 0.0882592296693474, 0.06201843520102557, 0.02542855465435423, 0.013448702957248315, 0.04986592655768618, 0.04515405322308652, 0.025561679249221925, 0.006906199459990603, 0.05526282446226105, 0.033082657610066235, 0.01772014318703441, 0.01722144035738893, 0.01038118210999528, 0.06025004571711179, 0.020405248324095737, 0.07519757898990065, 0.030253783625084907, 0.053089259454282, 0.022039932482584845, 0.12096666483557783, 0.03928622551029548, 0.009147808741545305, 0.014366266514116433, 0.04754161280288827, 0.019816272506432142, 0.12777556548826396, 0.08449157598079182, 0.013514963757188525, 0.07549341389676556, 0.02425930284516653, 0.1020111222169362, 0.1410487579414621, 0.10017988766776398, 0.1501040579751134, 0.20041463489178568, 0.1723134209169075, 0.1513895022799261, 0.17625581327592954, 0.15824405243620276, 0.11673194050672464, 0.12312840000959113, 0.07205973408417776, 0.14538379095029086, 0.11371433094609529, 0.20184356602840126, 0.058119213572354056, 0.12335234307101928, 0.10634550213580951, 0.1319294550921768, 0.16908726043766364, 0.14945110160624608, 0.19079914694884792, 0.14384212758159265, 0.18849727202905342, 0.14051493111765012, 0.09277258592192084, 0.17487221251940355, 0.12412051044520922, 0.09257240642909892, 0.17863021086668596, 0.15235373022733256, 0.135980082268361, 0.10052698271465488, 0.16010105435270816, 0.08144044360960834, 0.10969146009301767, 0.1523497820016928, 0.1914739966741763, 0.17114823422161862, 0.16115462203742936, 0.11284327963949181, 0.16757218079874292, 0.15856354701099917, 0.14834240719210356, 0.1618563523516059, 0.11678755705361255, 0.10193726368015632, 0.0923760118894279, 0.19575133512262255, 0.19344386440934613, 0.09628354557207786, 0.14304707961855456, 0.13333290087757632, 0.134105907054618, 0.13222206907812506, 0.1101052742160391, 0.1787815644638613, 0.15126701822737232, 0.06195713751367293, 0.1795668902923353, 0.09359076662804, 0.19679258315591142, 0.11955935988225974, 0.14212009264156222, 0.07629695945070125, 0.0958370250009466, 0.17355164978653193, 0.15249329851940274, 0.3297160560032353, 1.5960314450785518, 4.470006516203284, 11.32731568068266, 21.981757767498493, 30.20827453583479, 38.11723284423351, 42.06178978085518, 56.09846077859402, 57.48624511063099, 62.89495088160038, 68.5951580107212, 67.22716301679611, 61.615563333034515, 72.36702561378479, 55.45773535966873, 59.776853397488594, 55.72879001498222, 54.36773344874382, 53.64804446697235, 46.70654654502869, 46.76676191389561, 47.22319342195988, 49.72959592938423, 45.18391504883766, 44.87536020576954, 51.72960340976715, 46.694573387503624, 42.96758137643337, 41.814255863428116, 78.63890826702118, 65.73882088065147, 37.095106691122055, 53.06332424283028, 54.979132041335106, 53.55627179145813, 56.78398959338665, 60.16045041382313, 53.74828688800335, 47.83924676477909, 37.77565777301788, 26.36491946876049, 14.550294186919928, 7.632109913975, 2.1437784656882286, 0.44827011006418616, 0.1797864175750874, 0.09225287474691868, 0.19181645329808816, 0.12925803515827283, 0.12084236994269304, 0.15162114141276106, 0.1503486995352432, 0.10886054413276725, 0.19712129520485178, 0.1458065034239553, 0.19083643244812265, 0.24351100204512477, 0.2014800620963797, 0.11624286518781446, 0.18938488065032288, 0.13703600998269394, 0.10927494455245323, 0.09967092279111966, 0.17870610288809985, 0.18292783963261172, 0.1161768140445929, 0.1599393700598739, 0.15550355339655653, 0.17749508115230128, 0.11428844896727242, 0.07835104610421695, 0.16691897209966555, 0.17346458102110773, 0.1063829509075731, 0.18890371662564576, 0.15988430270226672, 0.1395546068670228, 0.21109192835865542, 0.1385158227640204, 0.08759447315242141, 0.16539593663765118, 0.2391231429646723, 0.1377022359520197, 0.12455270014470443, 0.11913486625417136, 0.15264368732459843, 0.11489981538034044, 0.1439471117919311, 0.10530764571740292, 0.13806153932819143, 0.17420557094737887, 0.10706309956731275, 0.2707338100299239, 0.2716721221804619, 0.11851160321384668, 0.13183615228626877, 0.2158163217245601, 0.17934359289938584, 0.09525819434202276, 0.06058547049178742, 0.14412159071071073, 0.19726463360711932, 0.25768311345018446, 0.16053547791671008, 0.10764649443444796, 0.14785080857109278, 0.23753496177960187], [0.038605590743827634, 0.05601223776466213, 0.06857822285383008, 0.00981900246188161, 0.004211634259263519, 0.10791315551614389, 0.07190636926679872, 0.033248653780901805, 0.023952959127200302, 0.09010633133584633, 0.039078850895748474, 0.07249584974488243, 0.03409776349144522, 0.024099620495690033, 0.07074461871525273, 0.05456695340399165, 0.07765984686557204, 0.0218625332126976, 0.050382709960103966, 0.05127614444063511, 0.0693906370725017, 0.03906687634298578, 0.040979235054692253, 0.002198892420892662, 0.03818957986368332, 0.023774515284458175, 0.02845686783985002, 0.04703009864897467, 0.0127878250896174, 0.0010182748519582674, 0.03417151441681199, 0.07851864531403407, 0.018756274112092797, 0.06199551768077072, 0.05306097991706338, 0.04137496303883381, 0.012759104902215768, 0.07022617661277764, 0.026531182011240162, 0.018761617575364653, 0.027276992186671123, 0.031023273877508473, 0.02911611762101529, 0.013647381456394214, 0.009570669644745067, 0.020545137595036067, 0.013356114468479063, 0.03964818206441123, 0.030259553823270835, 0.038805373187642545, 0.00892512269274448, 0.049971693733823486, 0.03940604525269009, 0.04269464632670861, 0.05720434957765974, 0.04225914664857555, 0.03524266357999295, 0.014056492218514904, 0.028465484174375888, 0.0025146141024379176, 0.09975225475500338, 0.019741248797799926, 0.04859306165599264, 0.04845718925935216, 0.02844352216925472, 0.0765540765132755, 0.020200905382807832, 0.059505059325601906, 0.046342521090991795, 0.030882250975992065, 0.13047019980149344, 0.5521927226800472, 2.09729983471334, 5.262603610754013, 6.104046134278178, 7.048529153689742, 16.497816033661366, 23.86155679821968, 26.494758501648903, 35.92097729444504, 39.40030239522457, 45.180058255791664, 42.123004496097565, 55.74505314230919, 54.960471242666245, 51.686080545187, 51.236712858080864, 51.927059814333916, 52.31939256191254, 53.99891383945942, 46.313039660453796, 52.70137086510658, 43.49439650774002, 48.22703875601292, 44.85332518815994, 42.236584201455116, 46.14712156355381, 42.65430338680744, 57.74789147078991, 51.199976429343224, 44.980994537472725, 49.30719539523125, 43.38887237012386, 40.12978345155716, 35.68477436900139, 25.556113868951797, 18.002943769097328, 11.94036053493619, 5.73294379748404, 2.7052636491134763, 1.5172879141755402, 0.21439637057483196, 0.03930576625862159, 0.01822058820835082, 0.0276363530792878, 0.03552301357558463, 0.01422965104211471, 0.05998468339384999, 0.07209384319139645, 0.005541116215681541, 0.07875793598941527, 0.03346694909851067, 0.022116063846624456, 0.03483056752884295, 0.011859854766953504, 0.06669194321148098, 0.03417990810703486, 0.03488873706373852, 0.02165561501897173, 0.037445439520524815, 0.02961465532280272, 0.0725927964958828, 0.04484132703510113, 0.021462920085468795, 0.0236617478003609, 0.06961086197406985, 0.05464719441079069, 0.024658298134454526, 0.07592835696414113, 0.032009641945478506, 0.031108368530112784, 0.011157424050907139, 0.02598906354251085, 0.02961652553494787, 0.07258233963511884, 0.07119116897229105, 0.04981166814104654, 0.07651515086763538, 0.032022941231844015, 0.015559608436888084, 0.04814798456209246, 0.045004243293078616, 0.060187326816958375, 0.10054590748040937, 0.030991339262982365, 0.026641320437192917, 0.004159845802860218, 0.03191827985574491, 0.03504142281599343, 0.08345723734237254, 0.05945658223936334, 0.010392840322310803, 0.0601481043122476, 0.06031243807228748, 0.019976290677732322, 0.05736725841416046, 0.006301048997556791, 0.035342853516340256, 0.09064284473424777, 0.0570743995194789, 0.05778179984190501, 0.06649285467574373, 0.06667667723377235, 0.05764400528278202, 0.08624904847238213, 0.03312280408863444, 0.019211609542253427, 0.03527388573274948, 0.04507969002588652, 0.0672722581657581, 0.057977671167463996, 0.0689646220416762, 0.0906022047274746, 0.04211821280478034, 0.038497971909237094, 0.03963525014114566, 0.024112708269967698, 0.06793430584366433, 0.0701347811263986, 0.03085291387833422, 0.06349500850774348, 0.03675506406580098, 0.02954823681648122, 0.025138360069831833, 0.026786345370055642, 0.026570257941784803, 0.06099132137023844, 0.012831498625018867, 0.045014162096777, 0.08898672735085711, 0.04104467763681896, 0.00728530008927919, 0.024870784291124437, 0.058799436446861364, 0.05226482986472547, 0.03510390051815193, 0.007656077068531886, 0.05975265463348478, 0.007903426539996872, 0.06074583747249562, 0.010821571613632841, 0.043555801094044, 0.03588171581213828, 0.013886843753425637, 0.020470590716286097, 0.010504094752832316, 0.05922929209191352, 0.05778900238510687, 0.03287303799879737, 0.05351498504751362, 0.024669884915056173, 0.10552320993156172, 0.0064050104356283555, 0.023461696328013204, 0.0718736850831192, 0.008017623586056288, 0.05797241676191334, 0.017826227631303482, 0.06151442044938449, 0.022538425655511674, 0.020645110453187954, 0.05701113143004477, 0.006557247652381193, 0.016086878385976888, 0.060192629462108016, 0.02020005376834888, 0.07480047061108053, 0.014433126598305535, 0.07524248634581454, 0.04429225649801083, 0.043347684331820346, 0.043657894639181904, 0.035143850327585824, 0.06173735047923401, 0.003261017532167898, 0.036508593111648224, 0.18820554862031713, 1.0682243295013905, 3.4691554214805365, 7.9498588386923075, 9.921693205833435, 10.346382167190313, 23.43416903167963, 30.157676450908184, 33.462562412023544, 42.213413044810295, 46.21444255113602, 53.54514978826046, 51.581814140081406, 59.937732964754105, 61.53569161891937, 57.530634328722954, 56.755240336060524, 56.849517077207565, 55.555906891822815, 58.26422676444054, 50.863778069615364, 56.36143706738949, 50.29599353671074, 53.30386273562908, 49.1906176507473, 47.28278562426567, 49.9392306804657, 46.77129507064819, 61.03395514190197, 55.30021861195564, 48.66649277508259, 52.02512115240097, 49.07440468668938, 47.02600300312042, 40.91978006064892, 31.737717166543007, 23.177965879440308, 16.33694026619196, 8.579148296266794, 4.089813642203808, 1.8885245500132442, 0.3432118333876133, 0.053187130179139785, 0.0478892978571821, 0.06162186116853263, 0.023661751511099283, 0.025534874730510637, 0.023932420190249104, 0.040154085581889376, 0.02895816447562538, 0.07262870902195573, 0.045877086886321194, 0.00800263313067262, 0.056236407181131653, 0.01028013870381983, 0.019145207734254654, 0.030810266362095717, 0.024411749254795723, 0.07253991847392172, 0.06344690991682, 0.05541133934457321, 0.02101157369907014, 0.042474020665395074, 0.02477579309925204, 0.02022823682636954, 0.01990161577850813, 0.04346320332842879, 0.07268397675943561, 0.029384114568529185, 0.01699286629445851, 0.05481146137753967, 0.01580533353262581, 0.08632764191133901, 0.04937787540256977, 0.06404076906619594, 0.03575687172997277, 0.018672394726308994, 0.0632214306097012, 0.029723661973548587, 0.019186678946425673, 0.03493754440569319, 0.06742324068909511, 0.1189548138063401, 0.009373830744152656, 0.032381213022745214, 0.03446922324656043, 0.030848451715428382, 0.08044090427574702, 0.020557644638756756, 0.08260770831839181, 0.12766517844283953, 0.05495646590134129, 0.03484800428850576, 0.010818682803801494, 0.05497257792740129, 0.0490228059788933, 0.03283835372712929, 0.029465928928402718, 0.01840680790337501, 0.12471193535020575, 0.03824912608251907, 0.021167472950764932, 0.03061289960896829, 0.05917219867114909, 0.040885627968236804, 0.010752184516604757, 0.08505361925926991, 0.1204569726542104, 0.2471173499361612, 0.1280341891106218, 0.1902013915241696, 0.145963660615962, 0.17407738720066845, 0.11448974910308607, 0.1309797732392326, 0.159274197940249, 0.14188517321599647, 0.18275540904141963, 0.18390486220596358, 0.1386190703487955, 0.15855949488468468, 0.26742472196929157, 0.15805118309799582, 0.09737015367136337, 0.16208000597544014, 0.1623651836416684, 0.18141237407689914, 0.05123783848830499, 0.15666309976950288, 0.33952285477425903, 0.14267673308495432, 0.11501610249979421, 0.1039077622408513, 0.13717575639020652, 0.1012165195425041, 0.0934596365550533, 0.06774574096198194, 0.15574035787722096, 0.10269569407682866, 0.20299681898904964, 0.174739011854399, 0.10181814155657776, 0.07496356498450041, 0.11292210314422846, 0.1603402040200308, 0.11137891095131636, 0.17082005651900545, 0.16976316401269287, 0.11229406067286618, 0.145849637046922, 0.09527027650619857, 0.14723703759955242, 0.11026036081602797, 0.1492437010165304, 0.13547681708587334, 0.10669248586054891, 0.22806443012086675, 0.09312153633800335, 0.16302726842695847, 0.1688001977163367, 0.12425497276126407, 0.1466313115088269, 0.12145315005909652, 0.062048143372521736, 0.12241191579960287, 0.08299951776280068, 0.18023940967395902, 0.15719290415290743, 0.19612834614235908, 0.22126763389678672, 0.11684604571200907, 0.1528570250957273, 0.17493349907454103, 0.14129771880107, 0.28112806321587414, 0.19159352697897702, 0.24381786526646465, 0.9631604421883821, 2.874866835772991, 8.213663958013058, 11.186801120638847, 13.951860498636961, 24.96889527887106, 31.90821021795273, 36.793216690421104, 46.231762021780014, 52.195523008704185, 58.86016398668289, 59.854639023542404, 69.5603746175766, 68.84009286761284, 67.21504166722298, 66.93515628576279, 63.44117917120457, 68.07263284921646, 66.60194456577301, 63.382704108953476, 65.59686809778214, 59.92569901049137, 63.12580369412899, 61.18548721075058, 57.92848438024521, 60.303626731038094, 55.45940726995468, 67.76394501328468, 64.40134584903717, 57.548455372452736, 61.53733313083649, 57.67715826630592, 55.17220348119736, 48.44987019896507, 38.53600077331066, 26.35778345167637, 17.717978060245514, 9.279409870505333, 4.712621597573161, 1.92380411317572, 0.36901660496369004, 0.16381765570258722, 0.1475461124209687, 0.14418747858144343, 0.11942394761717878, 0.08260741888079792, 0.11907364649232477, 0.09521215892164037, 0.14052521728444844, 0.3848619922064245, 0.10157784898183309, 0.08687282359460369, 0.16663550137309358, 0.10560273847659118, 0.12308227553148754, 0.14823573088506237, 0.12266629433725029, 0.19143691897625104, 0.13462646427797154, 0.14068731717998162, 0.15801878093043342, 0.1173943147296086, 0.07777437509503216, 0.11156212494825013, 0.21471611747983843, 0.1105804268445354, 0.19125519669614732, 0.11819937426480465, 0.11652562345261686, 0.11481505469419062, 0.12884540105005726, 0.15722503914730623, 0.11918438234715723, 0.12580264010466635, 0.10995247343089432, 0.08172362489858642, 0.13489017903339118, 0.0867631564324256, 0.10391571806394495, 0.10059589112643152, 0.17107213439885527, 0.12366272407234646, 0.15371212764875963, 0.12605272902874276, 0.15031816757982597, 0.1476205201470293, 0.23501838353695348, 0.19360620179213583, 0.16317725647240877, 0.26562741841189563, 0.10166103631490842, 0.1342820335412398, 0.1651313461479731, 0.1967981641064398, 0.17439122661016881, 0.1011546837980859, 0.12908318516565487, 0.17673388996627182, 0.21530051424633712, 0.19781027542194352, 0.15355084411567077, 0.14467360015260056, 0.12283669886528514, 0.2399234304903075, 0.10911618432146497], [0.023865862531238236, 0.03838205957436003, 0.0035337201597940293, 0.01331268120338791, 0.024006551466300152, 0.05158582040166948, 0.045979462447576225, 0.0798194223898463, 0.0908999469538685, 0.05019229713070672, 0.0375804695795523, 0.05072130741609726, 0.02350455164560117, 0.04267690899723675, 0.030682689321110956, 0.06302372246864252, 0.03011597422300838, 0.0476884726958815, 0.024849744404491503, 0.06680791862891056, 0.03705608658492565, 0.04204000528261531, 0.04694766830652952, 0.03105860381765524, 0.02375773347012, 0.030598937955801375, 0.0553365345695056, 0.049251268719672225, 0.06490531915915199, 0.03510816786729265, 0.012407928043103311, 0.08195079630240798, 0.0750902273284737, 0.04593675184878521, 0.07665193610591814, 0.06753019159077667, 0.040292299454449676, 0.01404042101057712, 0.03315064946946222, 0.05995626655931119, 0.0196830477216281, 0.04454161440662574, 0.06543078940012492, 0.023003639071248472, 0.011907880998478504, 0.07296005569514818, 0.03733226942131296, 0.012991705116291996, 0.04487499827519059, 0.08550346465199254, 0.04517794666753616, 0.014887315410305746, 0.01713028050289722, 0.04379827558295801, 0.016087965632323176, 0.029423060623230413, 0.026749442076834384, 0.028867132641607895, 0.02648847883392591, 0.024072559936030302, 0.05828701316204388, 0.08563691764720716, 0.010044075443147449, 0.05739757885748986, 0.02231140639196383, 0.01701929602859309, 0.07136007436201908, 0.062399806338362396, 0.05812352173961699, 0.05962985145743005, 0.025707407367008273, 0.03852921632642392, 0.04467171660508029, 0.1331304875202477, 0.24417841545073316, 1.1331992992199957, 1.1040043970569968, 3.9220436196774244, 6.999057233333588, 7.705278787761927, 13.524078503251076, 18.973713777959347, 19.304869808256626, 26.00857838988304, 29.0802613645792, 33.968148082494736, 36.237690299749374, 39.182057306170464, 38.14489156007767, 45.1902911067009, 38.129316195845604, 43.3742431551218, 41.64077237248421, 37.12919846177101, 40.811421275138855, 43.23064126074314, 40.59479869902134, 45.31242415308952, 39.820506647229195, 43.26089143753052, 41.09386771917343, 38.15377928316593, 27.590281516313553, 24.68319620937109, 15.027396585792303, 7.917387206107378, 2.3531410563737154, 1.0607777978293598, 0.19175029825419188, 0.008635724989289884, 0.03994408005382866, 0.03506924222165253, 0.011860731428896543, 0.020107780692342203, 0.05737709187087603, 0.03090046884608455, 0.03637862449977547, 0.025781299300433602, 0.01765612181770848, 0.036422526245587505, 0.0130358573369449, 0.036821527100983076, 0.0028457947200877243, 0.06099111727962736, 0.028725150514219422, 0.013074814523861278, 0.013759134053543676, 0.018466556357452646, 0.023520210961578414, 0.05538266646908596, 0.0240110340382671, 0.010389971921540564, 0.013943462199677015, 0.05119680514326319, 0.045860414538765326, 0.04430401211720891, 0.032474029721925035, 0.022139235552458558, 0.023866053634264972, 0.03377031309355516, 0.0030415533319683163, 0.04380636499263346, 0.016285692327073775, 0.09458041313337162, 0.01811052399716573, 0.02218192574218847, 0.08156602241797373, 0.04577139763568994, 0.038010941207176074, 0.10390022202045657, 0.03979125329351518, 0.06852498860098422, 0.061808793325326405, 0.015169052294368157, 0.028593909119081218, 0.05183017252420541, 0.005316897168086143, 0.020890106388833374, 0.06853938626591116, 0.031252606786438264, 0.05151036624738481, 0.016679180880601052, 0.024925693942350335, 0.028084600999136455, 0.04496066438150592, 0.04692668779171072, 0.0304065621457994, 0.03955442654842045, 0.02152829030819703, 0.013425248307612492, 0.01639300688111689, 0.06091214905609377, 0.05468194547574967, 0.04624895482265856, 0.04364658430858981, 0.03984391980338842, 0.029568770187324844, 0.049722116891643964, 0.035551515757106245, 0.08297038104501553, 0.03688807919388637, 0.0014156560860101308, 0.006559044113600976, 0.020534552713797893, 0.031197361313388683, 0.046243451797636226, 0.03656295171822421, 0.029214064416009933, 0.029634951206389815, 0.04836870670260396, 0.04577937572321389, 0.08390543516725302, 0.008289824800158385, 0.022143193054944277, 0.02412401488982141, 0.055083358311094344, 0.033941782603506, 0.0022272809610512923, 0.006883583901071688, 0.010350540687795728, 0.012056890336680226, 0.01729573490592884, 0.030664169025840238, 0.03327090336824767, 0.06051209806173574, 0.07194091624114662, 0.023263490948011167, 0.04597874627506826, 0.073986972856801, 0.04807392935617827, 0.020918174413964152, 0.04063246655277908, 0.07388690908555873, 0.028902993217343464, 0.00417334361372923, 0.038606373709626496, 0.01983161455427762, 0.055576793747604825, 0.04833812650758773, 0.0363528126035817, 0.033935593091882765, 0.06708119224640541, 0.026258110628987197, 0.016456529156130273, 0.00482936922708177, 0.05128472366777714, 0.026484424852242228, 0.04297733037674334, 0.018877949223679025, 0.0026031312154373154, 0.014920833582436899, 0.037756503297714517, 0.009916996568790637, 0.028018304947181605, 0.08563334049540572, 0.05020501383114606, 0.055340096878353506, 0.0415736211289186, 0.02807224795105867, 0.04100203383131884, 0.07537716388469562, 0.02335648390726419, 0.05286451487336308, 0.01673099020990776, 0.05815360098495148, 0.008528334365109913, 0.01876672169601079, 0.028178885295346845, 0.13404950383119285, 0.16201830381760374, 0.5628078687004745, 1.2796766893006861, 2.1962971100583673, 6.091650724411011, 9.880526214838028, 12.686883676797152, 18.743598125874996, 24.73173290491104, 25.431096777319908, 34.48097236454487, 36.37547090649605, 40.87749592959881, 43.58376391232014, 47.6883302628994, 47.72033214569092, 52.139088436961174, 45.282960534095764, 52.14604966342449, 49.36320818960667, 45.02589292824268, 48.97286273539066, 48.62166278064251, 48.33725184202194, 51.7321340739727, 45.612771436572075, 49.40711863338947, 45.38911543786526, 44.9053405970335, 33.36817927658558, 29.51433677226305, 17.97307927161455, 10.587052702903748, 3.4686870966106653, 1.762420954182744, 0.2918754005804658, 0.0714486867946107, 0.0809075147844851, 0.05179313935514074, 0.0456115687120473, 0.0028947504915777245, 0.050795433126040734, 0.072923801781144, 0.03241769700252917, 0.09212035685777664, 0.03395436200662516, 0.043823708983836696, 0.05119891655340325, 0.023973846873559523, 0.05882999437744729, 0.037157204205868766, 0.06217387803189922, 0.03725902315636631, 0.03870758409902919, 0.015297634945454774, 0.04114290830329992, 0.04045634748763405, 0.04115583280508872, 0.02793513616779819, 0.025574707651685458, 0.02562124587711878, 0.025298367108916864, 0.03567254520021379, 0.059160739911021665, 0.03628910664701834, 0.012912110705656232, 0.008738715605431935, 0.017060889695130754, 0.03564356804417912, 0.023862133239163086, 0.03687167030875571, 0.01302780596233788, 0.055180687268148176, 0.05771069467300549, 0.04027436916658189, 0.04819757858058438, 0.06990442590904422, 0.036761164519703016, 0.07641016665729694, 0.02717537176067708, 0.011434782263677334, 0.03117627689789515, 0.028007480723317713, 0.07322839403059334, 0.018107069299730938, 0.02401575224212138, 0.0206672542844899, 0.036407204606803134, 0.02731025710090762, 0.049130187326227315, 0.059212575215497054, 0.04221559371217154, 0.003490778103696357, 0.06777769784093834, 0.02341214127227431, 0.0035516669140633894, 0.02647699038789142, 0.04547208205622155, 0.07262054539751261, 0.07531921699410304, 0.026205603680864442, 0.05896611910429783, 0.041235316821257584, 0.14082718233112246, 0.103248386294581, 0.07089346385328099, 0.2239481228752993, 0.07475220132619143, 0.15151369327213615, 0.1304484548745677, 0.1678787768469192, 0.18075392581522465, 0.22757761093089357, 0.09157863358268514, 0.2084150313748978, 0.14992537850048393, 0.1684218508307822, 0.1714922790415585, 0.2588825725251809, 0.11690463827108033, 0.12533925793832168, 0.12137552883359604, 0.18471251183655113, 0.15561294596409425, 0.09111467254115269, 0.09354396679555066, 0.09122292962274514, 0.12273296888452023, 0.13872739422367886, 0.18131138262106106, 0.12857312191044912, 0.15810271783266217, 0.1501831560744904, 0.11822652202681638, 0.18601701449370012, 0.15206022566417232, 0.16592507308814675, 0.115199887950439, 0.13049099477939308, 0.21368049492593855, 0.07802307620295323, 0.15397239883895963, 0.12977598002180457, 0.10317455002223141, 0.17588000453542918, 0.1948833340429701, 0.13725359283853322, 0.206707245670259, 0.21845186623977497, 0.11212838362553157, 0.09451686302782036, 0.10952261407510377, 0.1521293492987752, 0.13910076871979982, 0.06678528312477283, 0.16070532583398744, 0.10087359536555596, 0.10322936504962854, 0.17901210521813482, 0.058991404075641185, 0.1290542265633121, 0.17283100954955444, 0.1748809847049415, 0.13074219692498446, 0.11800122825661674, 0.08624701498774812, 0.09899470751406625, 0.1278545003151521, 0.12470133748138323, 0.12131342591601424, 0.20035863242810592, 0.12584819312905893, 0.20076914399396628, 0.135372337535955, 0.12052608886733651, 0.13023130246438086, 0.20990412100218236, 0.7842801127117127, 1.4384357328526676, 2.1577059058472514, 5.297270100563765, 9.240811541676521, 12.978512328118086, 18.93211741000414, 25.64840331673622, 28.54001585394144, 36.498667895793915, 41.01920932531357, 44.17382664978504, 46.99615940451622, 52.93893791735172, 51.97391130030155, 57.69850552082062, 51.8708760291338, 57.10517875850201, 57.474074363708496, 51.07360281050205, 54.0853364020586, 55.788731798529625, 57.298839166760445, 61.25131867825985, 54.16949428617954, 57.185263261199, 54.433021545410156, 50.64245134592056, 39.51654955744743, 33.40333119034767, 21.17046520113945, 12.56196727976203, 4.413643665611744, 1.878033431712538, 0.4557462385855615, 0.1293463062029332, 0.15671050816308707, 0.17766798671800643, 0.10772842011647299, 0.12944449234055355, 0.10894219522015192, 0.15433005464728922, 0.11252928437897936, 0.1865150994854048, 0.20918483147397637, 0.11512975499499589, 0.15626697102561593, 0.1597690026392229, 0.13923753169365227, 0.14236792543670163, 0.23037559672957286, 0.13252358883619308, 0.1012871200509835, 0.09418282235856168, 0.1592545458697714, 0.120936882449314, 0.16822822450194508, 0.1567128236638382, 0.10448248140164651, 0.17896762088639662, 0.11137139299535193, 0.149560360587202, 0.09019809047458693, 0.14698446990223601, 0.08539159331121482, 0.1038867817260325, 0.10031098063336685, 0.14584243821445853, 0.1601437575300224, 0.14933589060092345, 0.27686611691024154, 0.18866994010750204, 0.16629099642159417, 0.17059457721188664, 0.2023524121614173, 0.139820815238636, 0.10593706858344376, 0.14922740345355123, 0.16423342167399824, 0.08366658235900104, 0.16141425498062745, 0.1129267638316378, 0.13399995805229992, 0.1293877774151042, 0.09442828028113581, 0.11878583420184441, 0.11290944210486487, 0.11462502778158523, 0.15132333239307627, 0.18172336363932118, 0.14408328104764223, 0.11611261827056296, 0.1885466990643181, 0.13790466415230185, 0.11961439755395986, 0.14730861032148823, 0.07286314605153166, 0.20899895316688344, 0.19965103914728388, 0.11343361358740367, 0.09838325204327703, 0.14630758669227362], [0.07227394758956507, 0.036328655696706846, 0.02675077794265235, 0.01731539254251402, 0.039136849736678414, 0.02530272351577878, 0.02754344546701759, 0.006677480678263237, 0.03973760343797039, 0.04137623211136088, 0.006930412955625798, 0.02958197484986158, 0.011359899563103681, 0.028218536390340887, 0.03375796375621576, 0.04193123982986435, 0.04502497518842574, 0.04668453613703605, 0.07683644143980928, 0.07287456770427525, 0.012110833340557292, 0.01257438898392138, 0.0422078345582122, 0.012077665833203355, 0.04663658226490952, 0.0298524450045079, 0.00858219758811174, 0.03782864005188458, 0.017142186406999826, 0.02385828149272129, 0.0407264113164274, 0.062191533725126646, 0.03751203985302709, 0.04306840302888304, 0.08987297784187831, 0.011880630263476633, 0.04776377470989246, 0.031268043458112516, 0.027853008250531275, 0.028129721722507384, 0.003108797709501232, 0.12519262440036982, 0.015113959889276884, 0.03248093169531785, 0.05879509488295298, 0.05494771226949524, 0.025016536528710276, 0.032209710116148926, 0.04277457934222184, 0.020628456659324, 0.010907174637395656, 0.07988480560015887, 0.015473578678211197, 0.04897605067526456, 0.0791512594150845, 0.012056288269377546, 0.03921446354070213, 0.011369703333912184, 0.012629704033315647, 0.026880206642090343, 0.02910335453634616, 0.012420565890352009, 0.02312739034096012, 0.059483655786607414, 0.02838909120328026, 0.051423698241706006, 0.09069360763533041, 0.053398397358250804, 0.045261965206009336, 0.014932852664060192, 0.019519086890795734, 0.07564262268715538, 0.03208921501936857, 0.0038707219982825336, 0.022509569098474458, 0.035240696888649836, 0.02866809049010044, 0.07140025423723273, 0.20116041909204796, 0.17941958882147446, 1.1812785943038762, 2.2563761612400413, 3.330886303447187, 3.1915819784626365, 6.271485574543476, 8.750290162861347, 9.669768624007702, 12.102793268859386, 11.873870752751827, 15.283429697155952, 14.472350869327784, 11.795748844742775, 12.86976121366024, 16.703440099954605, 13.664966393262148, 17.68030308187008, 16.090363897383213, 17.348347194492817, 17.332933321595192, 16.70931078493595, 15.950584597885609, 11.620232462882996, 6.748348586261272, 3.5840320447459817, 1.4778308314271271, 0.29364631336648017, 0.08451712812529877, 0.04985155115718953, 0.027755363880714867, 0.08153313785442151, 0.020916855246468913, 0.021723751597164664, 0.09285405889386311, 0.02324291861441452, 0.02570267803093884, 0.039961038128240034, 0.037168232520343736, 0.06311312157777138, 0.04275961393432226, 0.05370305269025266, 0.023704148552496918, 0.028633994370466098, 0.0359504090010887, 0.09445941337617114, 0.037172592637944035, 0.02672599021025235, 0.016691049677319825, 0.03939824899134692, 0.015892678748059552, 0.06237801688257605, 0.03865288781526033, 0.007384055361399078, 0.062235368677647784, 0.01453825645512552, 0.07924606878077611, 0.05163097637705505, 0.08409497968386859, 0.02056734821962891, 0.020065882745257113, 0.028593322822416667, 0.0063920209959178464, 0.03754116172785871, 0.03713657621119637, 0.04648712485504802, 0.03595329966628924, 0.019274760743428487, 0.02893553453759523, 0.023835428910388146, 0.03661767397716176, 0.05173921490495559, 0.026629553685779683, 0.03754828263481613, 0.02455398742313264, 0.0038372919561879826, 0.07060821197228506, 0.023682437022216618, 0.008944690343923867, 0.049538160747033544, 0.10066665490739979, 0.046480712699121796, 0.024816377444949467, 0.04623876142431982, 0.07361521624261513, 0.03783367923460901, 0.060514777214848436, 0.022943142903386615, 0.06603288638871163, 0.006260601485337247, 0.03643816329713445, 0.06343231187202036, 0.023769192230247427, 0.02012587610806804, 0.036975036637159064, 0.02890717521950137, 0.0481552576093236, 0.0527508846425917, 0.019660139478219207, 0.012202700090711005, 0.05020506207074504, 0.01979555545403855, 0.009119765763898613, 0.034367511907476, 0.09598051925422624, 0.02409346809145063, 0.0266716445912607, 0.041045909601962194, 0.12431545037543401, 0.003128628823105828, 0.06493170250905678, 0.07305543651455082, 0.03763428270758595, 0.14358556712977588, 0.03132299578282982, 0.01714824975351803, 0.02988044623634778, 0.0463994215533603, 0.020397247972141486, 0.029012022132519633, 0.0327276698226342, 0.03247732856834773, 0.050303882744628936, 0.045814004333806224, 0.018348835037613753, 0.03483342479739804, 0.030772706268180627, 0.015044926240079803, 0.06640215680818073, 0.03579186770366505, 0.0268294901252375, 0.026148146607738454, 0.05384245770983398, 0.036634676580433734, 0.057308380128233694, 0.01726108959701378, 0.14268712315242738, 0.05874759743164759, 0.05987096039461903, 0.06684069929178804, 0.0525154679780826, 0.09773270023288205, 0.042179670053883456, 0.02482170606526779, 0.020982025089324452, 0.061773827037541196, 0.06670038885204121, 0.07333026864216663, 0.03143041052680928, 0.02331271203729557, 0.02511201939341845, 0.03266199346398935, 0.04670659647672437, 0.032887235283851624, 0.03963554328947794, 0.04327619695686735, 0.09374504428706132, 0.008231261926994193, 0.026643943929229863, 0.005819469370180741, 0.05002709505788516, 0.04117960008443333, 0.03309554871520959, 0.03317010487080552, 0.0460163397656288, 0.045316587275010534, 0.019460846851870883, 0.033620595932006836, 0.0189607283755322, 0.029975713878229726, 0.05161340603081044, 0.10215218222583644, 0.014142541458568303, 0.037454712655744515, 0.11461414047516882, 0.06937895566807128, 0.45793581171892583, 0.541646151104942, 1.8701954022981226, 3.5267071332782507, 5.199147965759039, 5.827684588730335, 9.172293618321419, 12.544791251420975, 13.395554199814796, 16.198299005627632, 15.512154623866081, 20.455322675406933, 19.655260406434536, 16.984909996390343, 19.048807248473167, 21.29982925951481, 18.482749722898006, 23.22279777377844, 21.63409162312746, 22.173115499317646, 21.81134831160307, 20.54060149937868, 19.01250209659338, 14.61918069049716, 8.978012893348932, 5.061990525573492, 2.1530152950435877, 0.38938042474910617, 0.12253365028300323, 0.018920320289907977, 0.022650100327155087, 0.06865398871013895, 0.055606746827834286, 0.07730737124802545, 0.06260996029595844, 0.0260292656821548, 0.05822640196129214, 0.022300936543615535, 0.03460354455455672, 0.08388267349801026, 0.09562972831190564, 0.11884312800248154, 0.06811849205405451, 0.02923972046119161, 0.03013547229784308, 0.11783570706029423, 0.006947144674995798, 0.06707737018587068, 0.0356937446485972, 0.03560413031664211, 0.02833975879184436, 0.048119771818164736, 0.014420385778066702, 0.022533518203999847, 0.044777468938264064, 0.02481134382833261, 0.022132712074380834, 0.05208141177718062, 0.04003008012659848, 0.020186784167890437, 0.014304106080089696, 0.0320773666317109, 0.01670116515015252, 0.05745294678490609, 0.014936138522898545, 0.045299870398594067, 0.02303119130374398, 0.060383836389519274, 0.02238894969195826, 0.04779604329087306, 0.04633593081962317, 0.042578533611958846, 0.04909482770017348, 0.0889326173637528, 0.01662442893575644, 0.008953224114520708, 0.06723451253492385, 0.05972926584945526, 0.02112534493790008, 0.022252769304031972, 0.05392121442127973, 0.030815704449196346, 0.03280294215073809, 0.01942570615938166, 0.008168211843440076, 0.04410231864312664, 0.03839933306153398, 0.03576442308258265, 0.044442114667617716, 0.03645814933406655, 0.06922470769495703, 0.024202741915360093, 0.009258514910470694, 0.021502799390873406, 0.038261378940660506, 0.03897937342117075, 0.05223731102887541, 0.03328888560645282, 0.16558371484279633, 0.1233715721173212, 0.09746948271640576, 0.17543327616294846, 0.10148376692086458, 0.14060694258660078, 0.10477457588422112, 0.0719678339373786, 0.2299953202600591, 0.1432255661347881, 0.23021735600195825, 0.12238887211424299, 0.10930453398032114, 0.19021789688849822, 0.23048020986607298, 0.18716054531978443, 0.1743579635513015, 0.10838357324246317, 0.20752381591591984, 0.15529526222962886, 0.11576379401958548, 0.09298186414525844, 0.12181393030914478, 0.11891273403307423, 0.21757956070359796, 0.09154346320428886, 0.11238666585995816, 0.11717727364157327, 0.076143950864207, 0.09029246197314933, 0.13253380078822374, 0.261145529220812, 0.09095223125768825, 0.11210404860321432, 0.11786989780375734, 0.11753915969165973, 0.16163724067155272, 0.14994385797763243, 0.2409820002503693, 0.1249467211891897, 0.12568741425639018, 0.15646418934920803, 0.13844485860317945, 0.16002352960640565, 0.09948867358616553, 0.11415086220949888, 0.1034082449041307, 0.1770083064911887, 0.17920380196301267, 0.1541807345347479, 0.09840695624006912, 0.1900122477672994, 0.07780608706525527, 0.14574254513718188, 0.22854292241390795, 0.1644235450658016, 0.14583621901692823, 0.12161443359218538, 0.1736215007258579, 0.12529737112345174, 0.12482054124120623, 0.07090972430887632, 0.09751617122674361, 0.11707548808772117, 0.09722063317894936, 0.10804853067384101, 0.17233890626812354, 0.1484709620126523, 0.1089105055143591, 0.08061270404141396, 0.16298650967655703, 0.11635253977146931, 0.14389167336048558, 0.18439236417179927, 0.08964053718955256, 0.11871645823703147, 0.18837398645700887, 0.26902829529717565, 0.4201921104686335, 0.6840365042444319, 1.8706918694078922, 3.1431671138852835, 4.4819853734225035, 5.820788908749819, 8.97716173902154, 12.1067707054317, 14.168008100241423, 16.25367533415556, 16.949913874268532, 20.68448267877102, 20.9517128393054, 17.99158237874508, 19.55203514546156, 22.651088051497936, 21.333149671554565, 24.472450017929077, 24.12995159626007, 25.10351825505495, 24.728271290659904, 24.11666750907898, 21.319911181926727, 16.026343032717705, 10.580305214971304, 5.9009498823434114, 2.3485157545655966, 0.5364786658901721, 0.18026244593784213, 0.11159255300299264, 0.10780570737551898, 0.18630827777087688, 0.08098155143670738, 0.1410176619538106, 0.2035654228529893, 0.1240839745150879, 0.19639022037154064, 0.19331018876982853, 0.16132047720020637, 0.2439213651814498, 0.1505702009308152, 0.18731816264335066, 0.15191954415058717, 0.12149755275459029, 0.149184032343328, 0.1452778122620657, 0.11372343709808774, 0.1398151452303864, 0.20528622582787648, 0.07399639071081765, 0.11075570728280582, 0.1521402143407613, 0.07459911110345274, 0.07665271536097862, 0.13141928793629631, 0.13630370318423957, 0.19677429663715884, 0.24348918290343136, 0.22511987015604973, 0.0869481812696904, 0.09795963414944708, 0.1491196287679486, 0.08150550027494319, 0.18613246298627928, 0.1401226912275888, 0.1337737069115974, 0.18841002514818683, 0.17604835331439972, 0.11251076037297025, 0.12075131584424525, 0.12791787972673774, 0.10846493489225395, 0.13415203895419836, 0.21122382284374908, 0.10489812862942927, 0.09466702176723629, 0.1592631102539599, 0.21691753529012203, 0.04740000731544569, 0.21686589665478095, 0.2146801826893352, 0.15615247248206288, 0.15243533678585663, 0.19121387391351163, 0.07922536286059767, 0.09195582271786407, 0.09764951289980672, 0.0898735789814964, 0.16486745327711105, 0.14226120460079983, 0.19929850415792316, 0.12786444509401917, 0.09524128821794875, 0.12344071801635437, 0.08932120588724501, 0.08734186834772117, 0.14236577320843935, 0.12639491847949103], [0.14640593610238284, 0.03770347684621811, 0.032516398932784796, 0.07889489934314042, 0.017460144736105576, 0.04183667908364441, 0.06922497486812063, 0.03825060666713398, 0.035838834519381635, 0.01888932634756202, 0.026670121333154384, 0.028033589478582144, 0.00833947447972605, 0.027599314344115555, 0.017037070465448778, 0.057409516302868724, 0.022035904476069845, 0.07315874347114004, 0.06278578992350958, 0.011062574794777902, 0.03758080354600679, 0.032869794813450426, 0.022863291524117813, 0.08208584491512738, 0.059672190982382745, 0.015351147503679385, 0.06480614596512169, 0.07510309616918676, 0.04128286622290034, 0.025585741532268003, 0.01056968854754814, 0.0348212832614081, 0.02242485665192362, 0.028852272989752237, 0.05787827161839232, 0.017681430908851326, 0.026726235118985642, 0.07584464270621538, 0.009674377361079678, 0.043412243758211844, 0.06089811504352838, 0.02913413325586589, 0.03329553524963558, 0.06269783800235018, 0.07525844994233921, 0.07877533193095587, 0.009574751456966624, 0.07238026024424471, 0.07685910662985407, 0.05267492582788691, 0.020219869111315347, 0.0830646486429032, 0.05243503401288763, 0.030375883616216015, 0.02380365571298171, 0.011191901448910357, 0.016871020488906652, 0.050612990962690674, 0.049176538159372285, 0.05959425434411969, 0.04371525523310993, 0.02621528870804468, 0.034252868645126, 0.04021480810479261, 0.01697687115665758, 0.032449357022414915, 0.043550034606596455, 0.055370840345858596, 0.041079591974266805, 0.04171665153990034, 0.0373740671784617, 0.07272283561178483, 0.0314247850474203, 0.07875063325627707, 0.08864945091772825, 0.04031714655866381, 0.0011026341985598265, 0.04756733193062246, 0.08999451936688274, 0.051172815219615586, 0.022240490470721852, 0.04778429509315174, 0.05173827979888301, 0.09804469169466756, 0.27677729667630047, 0.1979103614576161, 0.3634607983985916, 0.6215156684629619, 0.879241885850206, 1.2301493156701326, 0.8199104445520788, 1.1479328898712993, 0.7449456921312958, 0.9678512311074883, 1.2317105568945408, 1.5798439574427903, 2.4245879100635648, 2.247934676706791, 2.4302795296534896, 1.303112762980163, 0.7939499407075346, 0.35232083522714674, 0.07467260598787107, 0.07122460272512399, 0.038199086775421165, 0.0605253862158861, 0.07132897837436758, 0.0274579036704381, 0.07556604788987897, 0.005479701176227536, 0.003349824546603486, 0.02088095756334951, 0.033947768024518155, 0.026263170220772736, 0.08162979516782798, 0.04493405838729814, 0.03182291387929581, 0.014544799414579757, 0.055563023197464645, 0.051045054497080855, 0.013680105530511355, 0.06167379666294437, 0.031039435998536646, 0.09040264863870107, 0.03322653778013773, 0.012587171549967024, 0.03776691562961787, 0.03688948185299523, 0.024037059301917907, 0.03439976935624145, 0.06375488635967486, 0.0206028284446802, 0.049583687796257436, 0.04009330368717201, 0.09544220985844731, 0.09697732006316073, 0.01723917026538402, 0.026361875861766748, 0.018617186360643245, 0.06261511822231114, 0.03761028536246158, 0.0035828215777655714, 0.04152551882725675, 0.025372643103764858, 0.0155182401977072, 0.016597774701949675, 0.048034999999799766, 0.03939080525015015, 0.005718937118217582, 0.04500469600316137, 0.04506899567786604, 0.04588339143083431, 0.04124201470403932, 0.09666830461355858, 0.03283754478616174, 0.04652297429856844, 0.06968298388528638, 0.0320599929546006, 0.03785060020163655, 0.044526634155772626, 0.011877868546434911, 0.05275375675410032, 0.021033257398812566, 0.07094411543221213, 0.08021849746000953, 0.03960687783546746, 0.009716953445604304, 0.05970463025732897, 0.012368934676487697, 0.048621560126775876, 0.020813919363718014, 0.013113115837768419, 0.01588789004017599, 0.00846558670673403, 0.06020675995387137, 0.03563025762559846, 0.08562404138501734, 0.053417288727359846, 0.03079516736761434, 0.0618282041978091, 0.07169233387685381, 0.03784208034630865, 0.04848631113418378, 0.03829378852969967, 0.12087335460819304, 0.025687272900540847, 0.04840589201194234, 0.02960140427603619, 0.026902966455963906, 0.010465616251167376, 0.018871336687880103, 0.06186620958033018, 0.020473472104640678, 0.00870581990966457, 0.06134019386081491, 0.007127708740881644, 0.085333876486402, 0.05924963807046879, 0.06266438198508695, 0.15477350272703916, 0.04103129300347064, 0.012117723254050361, 0.030216828381526284, 0.044790022366214544, 0.036257275933166966, 0.01506406901171431, 0.019771407824009657, 0.03662735158286523, 0.05399940338975284, 0.03881737000483554, 0.009495143131061923, 0.040803427691571414, 0.024107735880534165, 0.03593901332351379, 0.05243735322437715, 0.022886889964865986, 0.03806242028076667, 0.06911431322805583, 0.02840847610059427, 0.04651786090107635, 0.05429576522146817, 0.016404304224124644, 0.05874745642358903, 0.016894019645405933, 0.0849992866278626, 0.015008356913313037, 0.03147338087728713, 0.06675001626717858, 0.01942258357303217, 0.020799358426302206, 0.06746788829332218, 0.046486393839586526, 0.02490191182005219, 0.021801601033075713, 0.02561537919973489, 0.024378532580158208, 0.025026086113939527, 0.013451208633341594, 0.029333129023143556, 0.06334628211334348, 0.08653722441522405, 0.07055341920931824, 0.045544359818450175, 0.0500282157008769, 0.015728910875623114, 0.09063475532457232, 0.022277031966950744, 0.02129779964889167, 0.04841530986595899, 0.03126953146420419, 0.054752742653363384, 0.04623124346835539, 0.08572884005843662, 0.029315250685613137, 0.05269477827823721, 0.030725891592737753, 0.032346762527595274, 0.02478881779097719, 0.030046058345760684, 0.2527766564162448, 0.48419228405691683, 0.4787304037017748, 0.7799005508422852, 1.3783950358629227, 1.6471876250579953, 2.0433657662943006, 1.7621408379636705, 2.3153254855424166, 1.6944658756256104, 1.9668111554346979, 2.300109202042222, 2.6876865047961473, 3.594018858857453, 3.360049738548696, 3.323948113247752, 1.7593923979438841, 0.9044819127302617, 0.6341702956706285, 0.2540110854897648, 0.06853045080788434, 0.06091565570386592, 0.02303390014276374, 0.03786662688071374, 0.041728455398697406, 0.029593006875074934, 0.060243247644393705, 0.0518101679335814, 0.05173816105525475, 0.009982392766687553, 0.026303463273507077, 0.0370320410002023, 0.023446218838216737, 0.13377317256527022, 0.013546248064812971, 0.060606525221373886, 0.014964577621867647, 0.014703698798257392, 0.05759064486483112, 0.047290785441873595, 0.05761307256761938, 0.06965548731386662, 0.05258557495835703, 0.028765593851858284, 0.04242758448526729, 0.04136332245252561, 0.02167882939829724, 0.038353275376721285, 0.019516793654474895, 0.01887124206405133, 0.03854306480207015, 0.09135377767961472, 0.03215676901163533, 0.041664363525342196, 0.004348348529674695, 0.012119841157982592, 0.07273035356774926, 0.04610579453583341, 0.009875254472717643, 0.09816655234317295, 0.03275981223850977, 0.05158475170901511, 0.02066856231976999, 0.018226640422653873, 0.044448690096032806, 0.026846553955692798, 0.04972465132595971, 0.008779986437730258, 0.03773195305257104, 0.020345446064311545, 0.047720808070153, 0.020030072264489718, 0.026798787475854624, 0.05884169433556963, 0.01997440562263364, 0.017241632340301294, 0.04982224003470037, 0.05504475178895518, 0.05168832954950631, 0.011474503862700658, 0.0325496174627915, 0.059791825187858194, 0.11080045878770761, 0.026958395610563457, 0.018251372493978124, 0.02415969178400701, 0.00048105389112151897, 0.049002118612406775, 0.03140567474474665, 0.03308681363705546, 0.06715160721796565, 0.04105285981495399, 0.019239863104303367, 0.28040058037731797, 0.11827862079371698, 0.10379577215644531, 0.284914203803055, 0.11633008980425075, 0.13942027813754976, 0.08503249031491578, 0.15311162627767771, 0.19235994288465008, 0.06683862127829343, 0.13063820719253272, 0.11400921590393409, 0.08146369509631768, 0.12030280631734058, 0.10349689444410615, 0.15819768304936588, 0.16815090755699202, 0.13971059146570042, 0.2397699246648699, 0.09726117670652457, 0.1921781909186393, 0.1598905070568435, 0.19666361273266375, 0.2615644864272326, 0.18849866726668552, 0.0685776885075029, 0.15016690304037184, 0.11239051760639995, 0.12632411759113893, 0.15617503377143294, 0.07752666104352102, 0.09192006604280323, 0.1321465036016889, 0.24127050273818895, 0.1740220229839906, 0.2035180144594051, 0.09489201867836528, 0.20486605149926618, 0.1391285250429064, 0.19654385978356004, 0.19351761904545128, 0.1001889344479423, 0.12191300702397712, 0.09715455234982073, 0.20111495512537658, 0.08942339962231927, 0.17369011970004067, 0.1701787963975221, 0.14988093869760633, 0.1641493066563271, 0.12924473587190732, 0.12782983132638037, 0.08954537159297615, 0.11124890152132139, 0.10828662649146281, 0.10814374822075479, 0.11229170806473121, 0.12054839782649651, 0.07225688561447896, 0.13301224855240434, 0.09103645759751089, 0.15354100323747844, 0.1004417025251314, 0.10468764812685549, 0.13070173503365368, 0.191371773253195, 0.21566740237176418, 0.13518347579520196, 0.1424383552512154, 0.1445817667990923, 0.09593655442586169, 0.1885690080234781, 0.1322453873581253, 0.14855157409328967, 0.21355471573770046, 0.09453241844312288, 0.111507532565156, 0.10632401696057059, 0.26356608839705586, 0.09524686916847713, 0.2358798388740979, 0.20346518838778138, 0.1602094672853127, 0.2580570668214932, 0.5525888514239341, 0.3680921858176589, 0.6049572257325053, 1.232264139689505, 1.4556688768789172, 1.8809199705719948, 1.3688697782345116, 2.1719380421563983, 1.5680315787903965, 1.6919754655100405, 2.0981519389897585, 2.5012704078108072, 3.6652080388739705, 3.5282629122957587, 3.5643355641514063, 2.1411969792097807, 1.416248248424381, 0.7966686354484409, 0.6030608306173235, 0.2700548339635134, 0.09381118448800407, 0.19798438326688483, 0.12031667705741711, 0.19930209615267813, 0.0945726280042436, 0.22380476963007823, 0.13950710941571742, 0.1339916163124144, 0.14612206461606547, 0.10591956874122843, 0.1131672493647784, 0.08847523175063543, 0.19082912971498445, 0.0800425119814463, 0.15286355599528179, 0.12334242055658251, 0.0805032743664924, 0.14153867930872366, 0.0929424561036285, 0.1410984669928439, 0.10314598475815728, 0.08880558394594118, 0.08363915258087218, 0.1448569996864535, 0.16302729811286554, 0.07473369958461262, 0.12048175296513364, 0.07369914572336711, 0.18041320581687614, 0.09890141212963499, 0.203365414054133, 0.14821892866166309, 0.08663532149512321, 0.16498702811077237, 0.11423169693443924, 0.1734778654645197, 0.09348616091301665, 0.07686398254008964, 0.17473484098445624, 0.1404908558470197, 0.18396570347249508, 0.1399816683260724, 0.1004193267726805, 0.1207174442242831, 0.10954714947729371, 0.18647683435119689, 0.1408496842486784, 0.08966588895418681, 0.1460071504698135, 0.30075157585088164, 0.11469803284853697, 0.1624498181627132, 0.19013449433259666, 0.08966355118900537, 0.09545274093397893, 0.1363309400039725, 0.14664187969174236, 0.14471272617811337, 0.059287591502652504, 0.11745455485652201, 0.198645384516567, 0.15231031458824873, 0.11971939660725184, 0.2181112946709618, 0.17114148067776114, 0.35294652509037405, 0.11608378583332524, 0.11471863486804068, 0.0825474904559087, 0.15634324896382168, 0.15003336098743603, 0.11898136042873375], [0.009027118830999825, 0.01939030200446723, 0.045971120707690716, 0.0488171123288339, 0.018512920178181957, 0.025785844954953063, 0.06699433128233068, 0.04098864177649375, 0.03387367200048175, 0.01999885938857915, 0.0680805608863011, 0.03441647881118115, 0.02596035355963977, 0.033070861172745936, 0.04214282242173795, 0.04410396621096879, 0.025468534149695188, 0.039252298229257576, 0.01213802934216801, 0.01949761284777196, 0.050750058217090555, 0.0019817274869637913, 0.006775681658837129, 0.03967547083448153, 0.013164057781978045, 0.04111353038751986, 0.05729081720346585, 0.0037762503097837907, 0.023828087214496918, 0.06659400198259391, 0.07027280575130135, 0.004182436778137344, 0.006703003136863117, 0.08703179162694141, 0.061439422715920955, 0.03254161711083725, 0.09097427304368466, 0.026511676514928695, 0.027164235834788997, 0.01971114172192756, 0.002446251633045904, 0.017467326870246325, 0.10697432386223227, 0.013431533370749094, 0.027109463480883278, 0.012012759452773025, 0.09602077334420756, 0.03252710070228204, 0.036036665114806965, 0.06265940959565341, 0.031448121881112456, 0.03193248085153755, 0.031680907632107846, 0.07951148305437528, 0.10742952013970353, 0.04820707064936869, 0.01707393294054782, 0.03427253926929552, 0.04842972237383947, 0.03170668984239455, 0.022973207305767573, 0.019434489477134775, 0.03179313149303198, 0.05179659405257553, 0.01416705552401254, 0.03530601330567151, 0.024410062724200543, 0.03175946025294252, 0.09504383240710013, 0.06898651539813727, 0.040810923383105546, 0.04295240534702316, 0.019779612266574986, 0.10001024755183607, 0.026472845493117347, 0.040875597842386924, 0.05388664147176314, 0.033138786238851026, 0.023128041575546376, 0.04010436539829243, 0.07229945520521142, 0.021225291820883285, 0.027912977493542712, 0.08323644098709337, 0.02443636258249171, 0.05730186778237112, 0.09973798325518146, 0.05257502903987188, 0.022182406282809097, 0.044661471256404184, 0.02546634666941827, 0.041946654237108305, 0.019684170219989028, 0.051801054360112175, 0.015504352759307949, 0.037998925836291164, 0.046533408894902095, 0.027014318293367978, 0.027041892790293787, 0.03486385285214055, 0.004306267828724231, 0.053063915111124516, 0.046582605864387006, 0.0628655707987491, 0.00598713444560417, 0.05407134347478859, 0.03290207081590779, 0.04693686634709593, 0.009014873394335154, 0.019794310501310974, 0.03512759729346726, 0.026830863098439295, 0.0357786871609278, 0.026728066368377768, 0.06941351006389596, 0.09032968067913316, 0.04097329045180231, 0.020763726060977206, 0.016285039237118326, 0.015345221454481361, 0.04194554472633172, 0.01897640624520136, 0.04063056294398848, 0.035509209628799, 0.02948930658021709, 0.034449500672053546, 0.07983748626429588, 0.06177999428473413, 0.040924920976976864, 0.08754618902457878, 0.022609543811995536, 0.04413804563228041, 0.0554840883705765, 0.029071586905047297, 0.03333769665914588, 0.032856606849236414, 0.04428143598488532, 0.042475527225178666, 0.039923993826960213, 0.021660967759089544, 0.019638849116745405, 0.03907709200575482, 0.02123141453921562, 0.0027084169232693966, 0.027221303280384745, 0.037159671846893616, 0.05291002707963344, 0.021966083222650923, 0.049764419309212826, 0.0237435250528506, 0.04541810565569904, 0.08148434164468199, 0.020449599069252145, 0.002121162888215622, 0.02196470097260317, 0.025289168188464828, 0.05078234535176307, 0.018803357816068456, 0.0243812785265618, 0.004644420923796133, 0.025454195856582373, 0.041747628783923574, 0.024288307831739075, 0.027146379761688877, 0.029729064808634575, 0.0963415221485775, 0.07376317080343142, 0.017984835722018033, 0.03775018391024787, 0.02787567715131445, 0.03866558967274614, 0.017562240136612672, 0.02347851339436602, 0.02103042796079535, 0.03577207833586726, 0.018306285855942406, 0.03977572385338135, 0.02599831626866944, 0.039713368605589494, 0.10377471742685884, 0.055026498666848056, 0.023415506911987904, 0.031585623291903175, 0.01830325974879088, 0.017393676134815905, 0.030739150060981046, 0.02126604871591553, 0.04138484473514836, 0.02180312429118203, 0.018383621354587376, 0.08819632523227483, 0.05524818931007758, 0.06625003879889846, 0.03932501385861542, 0.026784605033753905, 0.021471547552209813, 0.029969698771310505, 0.04094623916898854, 0.057314131772727706, 0.006800584887969308, 0.025617546270950697, 0.050534705515019596, 0.030300880316644907, 0.028975714412808884, 0.0457373887184076, 0.022943862786632963, 0.09334799528005533, 0.037498250749194995, 0.02676266714843223, 0.036256897437851876, 0.016665299008309375, 0.014500935703836149, 0.06498030576040037, 0.05862480538780801, 0.018509495166654233, 0.01510200760094449, 0.047762921240064315, 0.054061454356997274, 0.012735580676235259, 0.029768242784484755, 0.020683104703493882, 0.011259930415690178, 0.06391709015588276, 0.041783641499932855, 0.04809130303328857, 0.025517220892652404, 0.03273603753768839, 0.03053355660085799, 0.012238517992955167, 0.05670265403750818, 0.03928291924239602, 0.05428700787888374, 0.056358086003456265, 0.04239839210640639, 0.09531720992526971, 0.03431560980970971, 0.02803973631671397, 0.020164616216789, 0.07518241691286676, 0.023147161155065987, 0.06013419646478724, 0.09726569638587534, 0.03577457566279918, 0.03620500647230074, 0.03760871943086386, 0.04526976517809089, 0.02741239146416774, 0.0416214488359401, 0.03256952557421755, 0.056035107045318, 0.025995907999458723, 0.04826997137570288, 0.01912774685479235, 0.03797777091676835, 0.04528847843175754, 0.017999444899032824, 0.08588417898863554, 0.0955618143780157, 0.10817596485139802, 0.05551126952923369, 0.06643336411798373, 0.07050687170703895, 0.03916293993825093, 0.0794248966849409, 0.03672808328701649, 0.043824350941576995, 0.04405648731335532, 0.0403409620776074, 0.020107578457100317, 0.09540275728795677, 0.010205910948570818, 0.06516392051707953, 0.08037095685722306, 0.03154776633891743, 0.042622416804078966, 0.03665556061605457, 0.0237701496007503, 0.10828636673977599, 0.014436213004955789, 0.030978553913882934, 0.04816672750166617, 0.03861699384287931, 0.023798245456418954, 0.04357151236035861, 0.02765929286397295, 0.01346965656921384, 0.02999377033120254, 0.06634213932557032, 0.015210004003165523, 0.04065423745487351, 0.03056995708902832, 0.07092230371199548, 0.02820114230416948, 0.02028486083872849, 0.0464036035555182, 0.02567543193435995, 0.016762520353950094, 0.04308066701923963, 0.02834844377503032, 0.061565012656501494, 0.04400360929139424, 0.03311336397018749, 0.046369798728846945, 0.020539189281407744, 0.020849267857556697, 0.02866199560230598, 0.059513801825232804, 0.05112348837428726, 0.03205562170478515, 0.052530258981278166, 0.06857699088868685, 0.023038803883537184, 0.057555708262952976, 0.03251289599575102, 0.0132337612194533, 0.030585224922106136, 0.021220198832452297, 0.061184728765510954, 0.008463657122774748, 0.003859816833937657, 0.030149498888931703, 0.05137249747349415, 0.021220837079454213, 0.07342973869526759, 0.04267345058906358, 0.013309599435160635, 0.04331442869442981, 0.04956863704137504, 0.06426651554647833, 0.04742248696857132, 0.06261501432163641, 0.0704285602841992, 0.05138916982105002, 0.02781911436613882, 0.042494162553339265, 0.027933720521104988, 0.034802759255398996, 0.01985345224966295, 0.02555034665419953, 0.08130460089887492, 0.02732854918576777, 0.023737135161354672, 0.011278265174041735, 0.07744124726741575, 0.1828641930478625, 0.07654702611034736, 0.06247293757041916, 0.040376128745265305, 0.03202562409569509, 0.026412492188683245, 0.03520831327477936, 0.012577603411045857, 0.07634009307366796, 0.0938289292389527, 0.1770034825312905, 0.15504054230405018, 0.18578277784399688, 0.10994344149366952, 0.14055006438866258, 0.09955732966773212, 0.13568047725129873, 0.14916335610905662, 0.1252914933138527, 0.14645696617662907, 0.14444482570979744, 0.1045086421072483, 0.2541028743144125, 0.12020798210869543, 0.14370174292707816, 0.09657617440097965, 0.1505884132348001, 0.11430134007241577, 0.12736440083244815, 0.10752664500614628, 0.24415756110101938, 0.1580687571549788, 0.13710698898648843, 0.12361970919300802, 0.22463462431915104, 0.12075665188604034, 0.1160987549519632, 0.08443232291028835, 0.14462683000601828, 0.1170009616180323, 0.11205080692889169, 0.11930897409911267, 0.1611889834748581, 0.1603218136006035, 0.21578114392468706, 0.18001912540057674, 0.07283223560079932, 0.11649014137219638, 0.12879190704552457, 0.10543079770286568, 0.16811020817840472, 0.11607269814703614, 0.0956039980519563, 0.16868642647750676, 0.2636917488416657, 0.12184788356535137, 0.12936616607476026, 0.20466403890168294, 0.07246231209137477, 0.07655895242351107, 0.11576687393244356, 0.1426689702202566, 0.20517089607892558, 0.11690950675983913, 0.12763721431838349, 0.15803672606125474, 0.3141457977471873, 0.16179304715478793, 0.09990190883399919, 0.16346944001270458, 0.1605678503983654, 0.13451996608637273, 0.21415021503344178, 0.14286008808994666, 0.09510726376902312, 0.12021902526612394, 0.2669916342711076, 0.2592807199107483, 0.10856516193598509, 0.23353947617579252, 0.06023035282851197, 0.1588092275778763, 0.2493850712198764, 0.10255077490000986, 0.1641347902477719, 0.09681734270998277, 0.09542396786855534, 0.12747860251693055, 0.19818287808448076, 0.21575503516942263, 0.30586366716306657, 0.2157314051873982, 0.15670828172005713, 0.1559940684819594, 0.23823648429242894, 0.16386056668125093, 0.11431539634941146, 0.10339740954805166, 0.14106536720646545, 0.17471407569246367, 0.0848838900856208, 0.23288586671696976, 0.08842725932481699, 0.14394674071809277, 0.14161722821881995, 0.09682782925665379, 0.17917191929882392, 0.1756246612058021, 0.10588991252006963, 0.15672523237299174, 0.10976719626341946, 0.19456780253676698, 0.11064628502936102, 0.10796581089380197, 0.08311086217872798, 0.10523563512833789, 0.13974533881992102, 0.11942382145207375, 0.09803283959627151, 0.12488377222325653, 0.1533183440915309, 0.17587580397957936, 0.1417388513800688, 0.3069696156308055, 0.11416548251872882, 0.08771291992161423, 0.08480705553665757, 0.27255554508883506, 0.14081403147429228, 0.07987546938238665, 0.09406741097336635, 0.13223913847468793, 0.1392508903518319, 0.16821609780890867, 0.14479235862381756, 0.1380242983577773, 0.12622406124137342, 0.203700493730139, 0.1120753274881281, 0.13018520025070757, 0.1500657483120449, 0.09706855227705091, 0.07809446338796988, 0.08947020687628537, 0.0926749044447206, 0.18923481839010492, 0.10671538111637346, 0.10702565079554915, 0.06937033933354542, 0.23914847988635302, 0.08659010985866189, 0.06882457877509296, 0.0883377340505831, 0.11859205944347195, 0.17149738501757383, 0.1840020390227437, 0.09385088938870467, 0.11521905762492679, 0.2406840873300098, 0.1844106803764589, 0.14559994888259098, 0.10268593483488075, 0.09723016977659427, 0.19250001583714038, 0.08888114200090058, 0.1627731422195211, 0.14829585968982428, 0.14406092755962163, 0.16700189968105406, 0.09058186988113448, 0.09666455676779151, 0.11343831138219684, 0.11687019519740716, 0.17088526161387563, 0.1682623929809779, 0.28934847679920495, 0.24156884610420093, 0.18351778766373172, 0.1517213016632013, 0.10721954429754987, 0.12473298265831545, 0.1707719505066052, 0.13817548868246377, 0.06757468334399164], [0.03594577057810966, 0.02516643737180857, 0.07627059094375, 0.016188999761652667, 0.050949566066265106, 0.04977305048669223, 0.009962048643501475, 0.06572598605998792, 0.08305093375383876, 0.06078096332203131, 0.0111794537770038, 0.030256030477175955, 0.04746486731164623, 0.059133599570486695, 0.04943703199387528, 0.029553728709288407, 0.06268537734285928, 0.06407714172382839, 0.05767789174569771, 0.04420210039825179, 0.060433883118093945, 0.004627040752893663, 0.018105494091287255, 0.03796464232436847, 0.037556973184109665, 0.023428568711096887, 0.015249003863573307, 0.01934552266902756, 0.10432744675199501, 0.06466091508627869, 0.05710658275347669, 0.022253917777561583, 0.030751477133890148, 0.02122637721186038, 0.0037256042969602277, 0.02333162567083491, 0.10187242965912446, 0.05107348246383481, 0.07296748459339142, 0.06449862965382636, 0.031528414838248864, 0.03987958742072806, 0.01040938928781543, 0.06280596149736084, 0.026126987977477256, 0.031933497593854554, 0.028569058304128703, 0.039361842937069014, 0.029716431599808857, 0.08071943972026929, 0.05910709747695364, 0.017117038732976653, 0.04580617096507922, 0.012437152890925063, 0.02087426710204454, 0.026200636857538484, 0.034892373587354086, 0.03577174436941277, 0.08083383436314762, 0.018660310706763994, 0.03895973619364668, 0.020463141408981755, 0.014348289842018858, 0.03893262553901877, 0.046824215751257725, 0.03265137333073653, 0.058344069475424476, 0.026171316458203364, 0.056417520900140516, 0.05344969831639901, 0.008769511950958986, 0.07065211742883548, 0.023711998619546648, 0.06814877910073847, 0.0354774716834072, 0.06491730484412983, 0.027281099974061362, 0.0561304284929065, 0.033298711641691625, 0.03801077422394883, 0.04433776128280442, 0.072930792812258, 0.03537490687449463, 0.03583561730920337, 0.03160225482133683, 0.03942744879168458, 0.011458317621872993, 0.039491073112003505, 0.018501270315027796, 0.05535207885259297, 0.08069488205364905, 0.04972415408701636, 0.07763503686874174, 0.06741557430359535, 0.03354431057232432, 0.07696672546444461, 0.07519437291193753, 0.018887404185079504, 0.022706373674736824, 0.01985709062864771, 0.038477937632706016, 0.07071723346598446, 0.08275184824015014, 0.022037283015379217, 0.03311913045763504, 0.01874538680567639, 0.04371401955722831, 0.05276838448480703, 0.03266705862188246, 0.027109836410090793, 0.09447554766666144, 0.027128106230520643, 0.05824684812978376, 0.042891118791885674, 0.07053211957099847, 0.010772721598186763, 0.05666334989655297, 0.02182957443437772, 0.03901609488821123, 0.03988756550825201, 0.005195348221604945, 0.06738050040439703, 0.04719244345324114, 0.009138519835687475, 0.036652900016633794, 0.009939628362189978, 0.05845037099788897, 0.03824763807642739, 0.020129356780671515, 0.0997960711538326, 0.03181190782925114, 0.04750104701088276, 0.03450498734309804, 0.00953186738115619, 0.03348678299516905, 0.010553161846473813, 0.015845355701458175, 0.021664962368959095, 0.08229451457737014, 0.026557025448710192, 0.06785294419387355, 0.03790656555793248, 0.006983467237660079, 0.04262686969013885, 0.04714290138508659, 0.04262039816239849, 0.01666448821197264, 0.030646079176221974, 0.026980140537489206, 0.031720174665679224, 0.02499504578736378, 0.033947359843296, 0.0064668498907849425, 0.032259571307804435, 0.01574723450175952, 0.015131635991565417, 0.05510055387276225, 0.033778168726712465, 0.007025391159913852, 0.041355548455612734, 0.04491240993957035, 0.031151140356087126, 0.033345270276186056, 0.026102248484676238, 0.04919239414448384, 0.02718729436310241, 0.026653089043975342, 0.06610194323002361, 0.02356845241592964, 0.02572894449258456, 0.026325046783313155, 0.024387731500610244, 0.015496912728849566, 0.017580021994945128, 0.037904331693425775, 0.012774729893862968, 0.03420985747652594, 0.034667836807784624, 0.036859406318399124, 0.011245401019550627, 0.02360705522733042, 0.05210477458604146, 0.05000281940738205, 0.06327234194031917, 0.05996523912472185, 0.05495274774148129, 0.05823627252539154, 0.023915308120194823, 0.05833764989802148, 0.0555553085723659, 0.006877279820400872, 0.03907751874066889, 0.06413418319425546, 0.014884905285725836, 0.12460476922569796, 0.032888337373151444, 0.028584613719431218, 0.0485487851256039, 0.020985849005228374, 0.021112850881763734, 0.06521275383420289, 0.024186364571505692, 0.06888780233566649, 0.009057077477336861, 0.05632843720377423, 0.07053562250803225, 0.021117374271852896, 0.05156615348823834, 0.042291719510103576, 0.03546596097294241, 0.028554770105984062, 0.031004699776531197, 0.05230617491179146, 0.052268347644712776, 0.07637836562935263, 0.016822088837216143, 0.049529807874932885, 0.05005312959838193, 0.021963712060824037, 0.05615147209027782, 0.02651470076671103, 0.02119760600180598, 0.05597920848231297, 0.02514913234335836, 0.022280345656326972, 0.1258228562073782, 0.016915653250180185, 0.022674038300465327, 0.04492845888307784, 0.023406324689858593, 0.024926901787694078, 0.02939503341622185, 0.0034505613530200208, 0.027672365795297083, 0.05093030362331774, 0.038567551964661106, 0.07243442960316315, 0.008921980625018477, 0.025871499929053243, 0.05079639420728199, 0.023295551727642305, 0.07910883825388737, 0.026420605718158185, 0.055210844438988715, 0.04242497954692226, 0.03408579636015929, 0.04360179569630418, 0.02712067733227741, 0.09171784564387053, 0.053556868151645176, 0.01931290898937732, 0.07683965493924916, 0.05480963198351674, 0.008756533643463627, 0.03435282480495516, 0.03569116197468247, 0.01750308168993797, 0.033404608693672344, 0.039642541742068715, 0.06949858245206997, 0.024591723777120933, 0.003065088922085124, 0.02700173332414124, 0.044003189977956936, 0.03784532724239398, 0.023712627589702606, 0.05634078654111363, 0.05442882116767578, 0.06819505200837739, 0.03293609828688204, 0.04161621298408136, 0.06708395303576253, 0.061412453069351614, 0.030646012382931076, 0.021157446535653435, 0.020560088159982115, 0.021408845350379124, 0.10625003968016244, 0.07339820484048687, 0.02533679366024444, 0.038989997265161946, 0.03189552189724054, 0.058022782613988966, 0.02694908165722154, 0.08708917448529974, 0.016852839726198, 0.059419656681711785, 0.04100932914298028, 0.008430510952166514, 0.09740831490489654, 0.025899042884702794, 0.03211032541003078, 0.020145977177890018, 0.03564886697859038, 0.022481428713945206, 0.018650603415153455, 0.018196520359197166, 0.02500268990843324, 0.03548540895280894, 0.050103321045753546, 0.024527338755433448, 0.023351893723884132, 0.03704706577991601, 0.028163804854557384, 0.03204974018444773, 0.07886158433393575, 0.04942916893924121, 0.02647010511282133, 0.050698831473710015, 0.0333603766921442, 0.04228802732541226, 0.00902426712855231, 0.026476231541892048, 0.0485877144819824, 0.04201711002679076, 0.030655721529910807, 0.054461052641272545, 0.04265302297426388, 0.04141362151131034, 0.02529466750274878, 0.020313966015237384, 0.03875249887641985, 0.04892758843197953, 0.03236542754166294, 0.04566390496620443, 0.07459567495970987, 0.035290903178974986, 0.025995184405473992, 0.010841414787137182, 0.04564017479424365, 0.0301028456306085, 0.009383321885252371, 0.03564407270459924, 0.018920049406006, 0.043946578953182325, 0.047385253419633955, 0.036355862830532715, 0.02922785537521122, 0.057228992591262795, 0.01856022652646061, 0.05599491974862758, 0.03176926031301264, 0.046227614366216585, 0.04212137806462124, 0.0556100642279489, 0.016130446165334433, 0.04161110700806603, 0.017059240271919407, 0.009985384549509035, 0.026986142656824086, 0.024582151927461382, 0.05645210127113387, 0.12544649827759713, 0.08691371593158692, 0.1587560007465072, 0.13686736434465274, 0.1579180418048054, 0.21840390865691006, 0.07391024962998927, 0.20501719729509205, 0.12703727697953582, 0.15868126647546887, 0.19090346322627738, 0.14785070467041805, 0.13784788985503837, 0.20800524711376056, 0.132171795994509, 0.12474935443606228, 0.2081962165539153, 0.10511430882615969, 0.18550473963841796, 0.13793571561109275, 0.18652289203600958, 0.1764263291261159, 0.11305384919978678, 0.10578728091786616, 0.16388400370487943, 0.04736466253234539, 0.1346721954178065, 0.09383686279761605, 0.16649507218971848, 0.15887003915850073, 0.09526883673970588, 0.1903900009347126, 0.20653888204833493, 0.14811565139098093, 0.17552828590851277, 0.11455761108663864, 0.25107782101258636, 0.13265836285427213, 0.2441281423671171, 0.12083174238796346, 0.10319114444428124, 0.1059095942764543, 0.10669970695744269, 0.12515896058175713, 0.1695998915238306, 0.15430321858730167, 0.14153492404147983, 0.11390814281185158, 0.07910173590062186, 0.16774481919128448, 0.1493360984022729, 0.08458346870611422, 0.2813038631575182, 0.14655178296379745, 0.1250972435809672, 0.12244998055393808, 0.14834699366474524, 0.09790908647119068, 0.24667945312103257, 0.12024378331261687, 0.1731418803683482, 0.09550096569000743, 0.1298335855244659, 0.11483815032988787, 0.06945423912839033, 0.3111164696747437, 0.13670959859155118, 0.132824603933841, 0.17756513989297673, 0.11096505972091109, 0.09094525506952778, 0.14288748818216845, 0.13299535727128386, 0.12348420787020586, 0.16481165861478075, 0.20196539699099958, 0.18590931402286515, 0.10889518016483635, 0.08193861023755744, 0.16262278310023248, 0.11728968675015494, 0.22031213360605761, 0.11761252098949626, 0.16545934573514387, 0.11975883433478884, 0.07409403508063406, 0.17792604630813003, 0.13746323471423239, 0.08883740723831579, 0.09341242111986503, 0.17675716371741146, 0.1390631715185009, 0.18640438589500263, 0.21325490291928872, 0.1562746151466854, 0.12187084561446682, 0.1503166981274262, 0.17629272770136595, 0.1399495778605342, 0.11295108401100151, 0.10216110284090973, 0.19849214586429298, 0.3463054314488545, 0.20144439447904006, 0.12038952627335675, 0.13959064555820078, 0.19475014822091907, 0.15746950259199366, 0.27600035711657256, 0.09161658701486886, 0.1443096064031124, 0.09694591979496181, 0.18052512168651447, 0.21611350734019652, 0.11871570866787806, 0.15961646160576493, 0.12491647124988958, 0.1826278932276182, 0.11089395455201156, 0.1453015164588578, 0.12232059452799149, 0.09453858569031581, 0.13996937836054713, 0.15276741818524897, 0.16229206725256518, 0.1499252300709486, 0.14069858298171312, 0.1278025796636939, 0.1865087021724321, 0.24086478544631973, 0.12224537043948658, 0.11244750712648965, 0.1747758372221142, 0.06834414205513895, 0.1486195993493311, 0.1094165092217736, 0.13990561303216964, 0.10552608204307035, 0.18470963230356574, 0.17088230786612257, 0.26860289624892175, 0.15358706092229113, 0.21084553533000872, 0.15325253043556586, 0.25532177765853703, 0.16076591477030888, 0.14316522952867672, 0.09259285259759054, 0.2092051663203165, 0.2132736792555079, 0.10880514280870557, 0.07020000848569907, 0.13708907354157418, 0.10336028732126579, 0.1068617771670688, 0.09120093236560933, 0.09794731449801475, 0.09127842000452802, 0.0921018848021049, 0.16236236348049715, 0.14076197723625228, 0.05520372353203129, 0.20266782492399216, 0.1277925309841521, 0.2159646325162612, 0.14524690923281014, 0.11496984443510883, 0.14186394779244438, 0.14525574079016224, 0.08126004977384582, 0.11559001271962188, 0.10190536617301404, 0.1163650672242511, 0.0914054385793861, 0.12839634233387187, 0.10091133357491344], [0.035562028278945945, 0.03445563081186265, 0.024945767181634437, 0.030268795417214278, 0.05025018093874678, 0.025893007368722465, 0.031030910577101167, 0.036540806031553075, 0.025272052407672163, 0.036109833454247564, 0.021485538891283795, 0.05828539528010879, 0.025002088768815156, 0.058635885652620345, 0.03404714530915953, 0.07582989623188041, 0.024707322554604616, 0.012178824272268685, 0.030617415577580687, 0.04483131917368155, 0.02787601111776894, 0.10277917084749788, 0.08466935003525577, 0.010994907624990446, 0.06925176639924757, 0.02939289974165149, 0.02921806459198706, 0.03762518768780865, 0.014876805671519833, 0.0421316568099428, 0.026386003082734533, 0.02754933255346259, 0.08150442416081205, 0.027785268721345346, 0.05095072752737906, 0.07976356835570186, 0.050938374479301274, 0.0835850574367214, 0.03909236169420183, 0.09016256386530586, 0.008373398050025571, 0.05765573492681142, 0.0472720833204221, 0.012088904732081573, 0.04452562483493239, 0.027943297936872113, 0.011048505530197872, 0.051786730909952894, 0.047926037877914496, 0.010861244973057183, 0.048751899812486954, 0.012690403364103986, 0.025355670186399948, 0.10437745266244747, 0.008612842721049674, 0.05085375109047163, 0.015240607390296645, 0.022048253813409247, 0.052706181377288885, 0.05929775892582256, 0.03714752288942691, 0.012481566718633985, 0.01805410964152543, 0.028465191026043613, 0.026903461839538068, 0.036765535769518465, 0.09182405439787544, 0.012690657549683237, 0.13222419162048027, 0.07890533393947408, 0.0926896880264394, 0.053052140938234515, 0.07766971000819467, 0.04447185252502095, 0.06412209360860288, 0.009673089734860696, 0.038083215258666314, 0.031360641223727725, 0.042026513037853874, 0.02726142749452265, 0.0771406180865597, 0.06001227273372933, 0.020815058560401667, 0.051057069867965765, 0.06585769500816241, 0.006078807309677359, 0.04103219100215938, 0.03188323935319204, 0.05399387810030021, 0.04451260014320724, 0.03261816964368336, 0.04451004344446119, 0.06330365315079689, 0.07874211340094917, 0.06820160517236218, 0.011302849743515253, 0.03437638057221193, 0.021064069514977746, 0.03512312956445385, 0.05578861753747333, 0.02637195422721561, 0.04442070741788484, 0.07369756494881585, 0.07003559308941476, 0.05021702549129259, 0.04305139671487268, 0.021890757088840473, 0.015224940652842633, 0.04412044560012873, 0.08176730771083385, 0.02823897884809412, 0.007031129352981225, 0.02982704871101305, 0.04350758375949226, 0.030814930760243442, 0.012256156987859868, 0.054998805426293984, 0.01727099541312782, 0.04269774479325861, 0.040792399377096444, 0.010898191867454443, 0.0419783253892092, 0.034184409232693724, 0.007533901471106219, 0.012979068196727894, 0.04730671564175282, 0.0376543021411635, 0.03873364832543302, 0.024057152950263117, 0.056136432467610575, 0.05474066419992596, 0.04161972705333028, 0.031024433483253233, 0.0021114973424118944, 0.04813521220057737, 0.049257476784987375, 0.053949727735016495, 0.015836804304854013, 0.03924429045582656, 0.05164478403457906, 0.028353731577226426, 0.021998782249283977, 0.01668544275162276, 0.06334776640869677, 0.026828397312783636, 0.015469715799554251, 0.07168963245931081, 0.03757572725589853, 0.044037191473762505, 0.046072345940046944, 0.03918925649486482, 0.035321520481375046, 0.04391659989778418, 0.01559564898343524, 0.0331235202611424, 0.016587134159635752, 0.05886113489395939, 0.11220950036658905, 0.02799718342430424, 0.051365788458497263, 0.009006252421386307, 0.10120983279193752, 0.06389011308783665, 0.023787790451024193, 0.023185535756056197, 0.02365254516917048, 0.0624208313820418, 0.07661601615836844, 0.021779906201118138, 0.03347030360600911, 0.044469470230978914, 0.017821058572735637, 0.018412520585116, 0.010866553184314398, 0.01181772304335027, 0.016821021999930963, 0.04577261475787964, 0.016953330232354347, 0.021610162184515502, 0.030722256924491376, 0.03778344325837679, 0.051826669587171637, 0.08986528919194825, 0.052537016235874034, 0.06499028764665127, 0.04764777702803258, 0.04525073280092329, 0.08073405260802247, 0.015700863259553444, 0.05145281269506086, 0.03850491099001374, 0.06807221914641559, 0.007142107797335484, 0.00805100260549807, 0.03425162554776762, 0.048656641447450966, 0.04760901465488132, 0.04024474634206854, 0.060336524475133047, 0.04439086565980688, 0.02155763668270083, 0.01380068133585155, 0.012021850761811947, 0.04081994418811519, 0.02049275310127996, 0.10460270932526328, 0.013537063987314468, 0.03056178418773925, 0.030125536795821972, 0.06553420767886564, 0.06714949951856397, 0.01669861958362162, 0.050575950372149237, 0.025680478538561147, 0.05699780616851058, 0.06742410900187679, 0.03154829697450623, 0.019712353278009687, 0.06798022994189523, 0.033212470370926894, 0.04082710591319483, 0.03605700367188547, 0.014512894485960715, 0.015160815382841974, 0.05637069138174411, 0.00857572606037138, 0.03059546470467467, 0.030473435217572842, 0.022670867474516854, 0.06490376064903103, 0.028831502131652087, 0.048766635154606774, 0.02445596270263195, 0.059174087436986156, 0.04579474189085886, 0.03877855197060853, 0.054681730252923444, 0.03321151300042402, 0.07418216511723585, 0.007436176392729976, 0.027483969752211124, 0.08079532432020642, 0.027949711948167533, 0.04239108937326819, 0.01349380883766571, 0.0773251531063579, 0.11536325691849925, 0.036745798352058046, 0.02047554084128933, 0.039937319088494405, 0.005918699152971385, 0.04113369825063273, 0.02197609850554727, 0.04279765642422717, 0.03304930178273935, 0.005761018746852642, 0.008138628909364343, 0.06070316769182682, 0.06081396291847341, 0.017416063019481953, 0.031781375873833895, 0.016070591955212876, 0.018365088071732316, 0.031234576308634132, 0.08521824987838045, 0.034593061718624085, 0.06495427864138037, 0.03270646295277402, 0.011677360653266078, 0.06303720729192719, 0.023406256041198503, 0.019436931142990943, 0.004169762287347112, 0.07385229531791992, 0.04494517947023269, 0.08304274786496535, 0.0102668440558773, 0.026282527287548874, 0.019663685088744387, 0.017873387405415997, 0.0464296974678291, 0.011971743733738549, 0.039957416447578, 0.011610613746597664, 0.02498096724593779, 0.034356613468844444, 0.09647645201766863, 0.04980136713129468, 0.062132043167366646, 0.042749234999064356, 0.03832789763691835, 0.05725329050619621, 0.03466356574790552, 0.018405874652671628, 0.0498428160790354, 0.06226092082215473, 0.06555368163390085, 0.10433558811200783, 0.043100252296426333, 0.019330588802404236, 0.027475757888169028, 0.029579581423604395, 0.01413463665812742, 0.05123218703374732, 0.016180181191884913, 0.06069325259886682, 0.040010969823924825, 0.06317824503639713, 0.02971172823890811, 0.005504904511326458, 0.08406694876612164, 0.04034869896713644, 0.008924333233153448, 0.051814008547808044, 0.04074494274391327, 0.044735559858963825, 0.044138739540358074, 0.05021944118198007, 0.035651423677336425, 0.04169847634329926, 0.043348715917090885, 0.02220244427007856, 0.01378836725052679, 0.01900081548228627, 0.10393888791440986, 0.040705401115701534, 0.01264793581867707, 0.02703164929698687, 0.07993256280315109, 0.042514371234574355, 0.04733592657430563, 0.027893733604287263, 0.023301253277168144, 0.08905208087526262, 0.028409546648617834, 0.02629600840009516, 0.06278927059611306, 0.04810109196114354, 0.030580274797102902, 0.01964083065104205, 0.03273903210356366, 0.039436792430933565, 0.04582643159665167, 0.01365080832329113, 0.04932040348649025, 0.036973452151869424, 0.014784096583753126, 0.011818470757134492, 0.0377633458992932, 0.024940484945545904, 0.026193130033789203, 0.061314942286117, 0.1124344824347645, 0.06785137084079906, 0.14656494866358116, 0.05301909681293182, 0.10305830001016147, 0.10598399458103813, 0.2873011288465932, 0.12053772574290633, 0.12379495252389461, 0.20423409790964797, 0.1532272231997922, 0.1493614204810001, 0.07687695528147742, 0.20668864744948223, 0.09964053926523775, 0.1793310951325111, 0.17916354787303135, 0.07053983048535883, 0.230554127774667, 0.12665223592193797, 0.22409214405342937, 0.12523249257355928, 0.19811807374935597, 0.21631105220876634, 0.16741953586461022, 0.13362189318286255, 0.14258957526180893, 0.17036436300259084, 0.10838871632586233, 0.2369873013230972, 0.06841440117568709, 0.11687547186738811, 0.1119401675532572, 0.09400079579791054, 0.15395883237943053, 0.21513462939765304, 0.12536259106127545, 0.18530480505432934, 0.13297871832037345, 0.2286398023716174, 0.10071531753055751, 0.11364482139470056, 0.08271796177723445, 0.12496447336161509, 0.14592677587643266, 0.10821194417076185, 0.12687437556451187, 0.09042919526109472, 0.11558668047655374, 0.09153887673164718, 0.14540163218043745, 0.08612308374722488, 0.10811660788021982, 0.19937450008001179, 0.15925064217299223, 0.1253287639701739, 0.10698003839934245, 0.19284915179014206, 0.11162689217599109, 0.1721893486683257, 0.253555525559932, 0.1305909175425768, 0.13034614239586517, 0.1541783002903685, 0.11998760135611519, 0.15391048887977377, 0.23148017964558676, 0.12534182576928288, 0.13350647437619045, 0.16587585385423154, 0.23112377064535394, 0.1414216129342094, 0.12810496031306684, 0.11966292659053579, 0.06443075282732025, 0.13943849044153467, 0.19068142748437822, 0.19421694480115548, 0.13621172140119597, 0.07723855931544676, 0.15485546551644802, 0.13197322696214542, 0.13164639996830374, 0.13396887690760195, 0.15409598127007484, 0.09455455670831725, 0.1322406969848089, 0.06826811644714326, 0.2115982660325244, 0.13563664600951597, 0.16274504450848326, 0.16486978362081572, 0.12623467395314947, 0.1962623037979938, 0.1898302137851715, 0.08365235538803972, 0.14277791749918833, 0.24371758627239615, 0.16441357060102746, 0.1425556294270791, 0.07858281882363372, 0.18367259966908023, 0.27341513021383435, 0.19947547669289634, 0.16360295237973332, 0.0917214153741952, 0.1602672805893235, 0.14572149782907218, 0.11859389996971004, 0.26899967808276415, 0.138233287143521, 0.15958082367433235, 0.14170849754009396, 0.13604392181150615, 0.10211785789579153, 0.13233797770226374, 0.22154544945806265, 0.13583840627688915, 0.10183458754909225, 0.2140973147470504, 0.1903102794312872, 0.23643441614694893, 0.11707004072377458, 0.09285105319577269, 0.16641166963381693, 0.1914775144541636, 0.09433078434085473, 0.14498380303848535, 0.10316234169295058, 0.2145054514403455, 0.0974567474622745, 0.11060887336498126, 0.10346905648475513, 0.07096948946127668, 0.21492523985216394, 0.133620067499578, 0.09262456456781365, 0.12338560612988658, 0.14837483904557303, 0.12295837397687137, 0.07183096706285141, 0.17904766893479973, 0.14286396210081875, 0.2359769563190639, 0.17577588121639565, 0.07097503330442123, 0.09152621569228359, 0.1939682659576647, 0.15430370840476826, 0.0887861693627201, 0.06539072084706277, 0.10812330205226317, 0.14673503406811506, 0.11250871204538271, 0.11476585772470571, 0.08470175962429494, 0.21600279374979436, 0.11907421052455902, 0.12173063165391795, 0.14789287350140512, 0.10997268953360617, 0.22844461753265932, 0.19908676942577586, 0.060348031474859454, 0.09177513944450766, 0.1979791437042877, 0.12696163728833199, 0.10508669351111166, 0.14169087895425037, 0.1717031974112615, 0.09479503481998108, 0.15487652766751125, 0.11178713670233265, 0.07750818156637251, 0.17438577924622223, 0.13870993891032413], [0.04937509605952073, 0.026327941159252077, 0.020109033066546544, 0.018954149236378726, 0.038178384565981105, 0.04516600180068053, 0.06348647380946204, 0.037604745230055414, 0.02747848157014232, 0.014192260714480653, 0.05418848777480889, 0.06790528044803068, 0.0838428275892511, 0.04958133147738408, 0.04651447670767084, 0.051077426978736185, 0.06042207183782011, 0.05636694353597704, 0.04625081390258856, 0.047056530238478445, 0.022693295177305117, 0.05122655784361996, 0.028625877130252775, 0.040153384252334945, 0.020242137252353132, 0.032289041992044076, 0.03195083045284264, 0.0354843551031081, 0.05818909048684873, 0.044020519126206636, 0.042533143860055134, 0.020693904807558283, 0.02319608538527973, 0.018818634925992228, 0.06072547665098682, 0.04847661868552677, 0.05018737298087217, 0.05765048794273753, 0.055823476213845424, 0.024379632814088836, 0.07064260309562087, 0.03655967513623182, 0.018288259088876657, 0.016628124831186142, 0.005292556579661323, 0.052644661045633256, 0.05540644116990734, 0.05124691866512876, 0.012061987963534193, 0.05257338889350649, 0.04608504779753275, 0.015263669629348442, 0.04287591960746795, 0.030875890770403203, 0.053270592106855474, 0.03273852002166677, 0.009896471547108376, 0.005440094610094093, 0.03943523763155099, 0.05908500374061987, 0.016395389175158925, 0.0067587940884550335, 0.02853006029909011, 0.025705537154863123, 0.03997230021923315, 0.04749284256831743, 0.020386332835187204, 0.06001064000884071, 0.04254904437402729, 0.05111518745252397, 0.04573693229758646, 0.12353730853646994, 0.039215929282363504, 0.019253932368883397, 0.02900229999795556, 0.02947981636680197, 0.04140215532970615, 0.11777424238971435, 0.05616301619738806, 0.03140731860185042, 0.010477972082298947, 0.0324902827560436, 0.05640712712192908, 0.10909766031545587, 0.0485033916629618, 0.060199494328117, 0.04264972412784118, 0.05426212366728578, 0.06431157875340432, 0.03147699884721078, 0.034915209471364506, 0.03933779735234566, 0.024073708409559913, 0.043265732674626634, 0.01757404399540974, 0.05815251744934358, 0.01683836042502662, 0.03646607176051475, 0.0393592788168462, 0.03130591896479018, 0.004400470952532487, 0.04340049184975214, 0.05345685262000188, 0.10167927830480039, 0.02066620971163502, 0.01799644662241917, 0.10572395345661789, 0.02602477754408028, 0.1009725830226671, 0.0459672726719873, 0.06379487327649258, 0.03145437818602659, 0.020543642167467624, 0.027239929331699386, 0.035895308246836066, 0.058752569821081124, 0.0639008371217642, 0.020525274012470618, 0.04881283013673965, 0.009574154028086923, 0.05702526934328489, 0.04567278105241712, 0.07212405602331273, 0.07916530827060342, 0.08433312003035098, 0.07451633937307633, 0.03532587688823696, 0.023905775233288296, 0.02718821277085226, 0.02872453824238619, 0.08310577846714295, 0.05281231591652613, 0.020010409061796963, 0.05687985663826112, 0.03932055726181716, 0.018573386660136748, 0.050298958594794385, 0.029862514093110804, 0.02055511391517939, 0.041974930063588545, 0.02860271470126463, 0.04134718074055854, 0.002936714072347968, 0.04683214930992108, 0.025142909435089678, 0.05049589861300774, 0.09514074205071665, 0.07487800277885981, 0.03834235467365943, 0.08125669526634738, 0.019112030022370163, 0.033310990475001745, 0.03157747079967521, 0.07108798818080686, 0.039709123520879075, 0.019537473599484656, 0.06464346719440073, 0.0689927049097605, 0.051983474259031937, 0.019916160017601214, 0.07078883587382734, 0.039272748108487576, 0.045595230330945924, 0.07851914255297743, 0.04891226679319516, 0.0586449472757522, 0.05297301315295044, 0.00861630298459204, 0.06634574616327882, 0.06571425270522013, 0.0308682559261797, 0.022571399276785087, 0.018214016490674112, 0.03235348638554569, 0.14568096172297373, 0.03058917685848428, 0.024464629132125992, 0.055638707417529076, 0.023292638798011467, 0.007972845178301213, 0.0225870437498088, 0.04218392998154741, 0.02163156201277161, 0.0683531368849799, 0.015351953661593143, 0.043149208067916334, 0.026789388175529893, 0.06505208628368564, 0.04455708447494544, 0.041350820974912494, 0.057342500367667526, 0.018112127036147285, 0.023516366636613384, 0.022566701481991913, 0.04713178401289042, 0.04577230676659383, 0.08721018908545375, 0.053800429886905476, 0.0012598399780472391, 0.034117345057893544, 0.013881076338293497, 0.05884988022444304, 0.03778857149882242, 0.01927877019625157, 0.0133628346156911, 0.05387727927882224, 0.04592027617036365, 0.04010793141787872, 0.03693781422043685, 0.029634628372150473, 0.02994403530465206, 0.0505464128946187, 0.08012944716028869, 0.07127945485990494, 0.055410166751244105, 0.03124474002106581, 0.019743556877074298, 0.02348868267290527, 0.0356795139668975, 0.033205928339157254, 0.0475811544311, 0.020293863090046216, 0.06177563045639545, 0.02140086540748598, 0.04711329711426515, 0.01735544439725345, 0.04402910948556382, 0.036390509994816966, 0.03873169276630506, 0.023432184825651348, 0.17686342442175373, 0.0293766745380708, 0.0094276902564161, 0.031215762865031138, 0.010162109392695129, 0.025534392334520817, 0.03374786683707498, 0.004573081050693872, 0.02531779282435309, 0.09303066777647473, 0.014601577422581613, 0.027679427330440376, 0.03465725007117726, 0.07003612743574195, 0.046819350973237306, 0.020110675068281125, 0.026820819985005073, 0.02342832009162521, 0.02421934375888668, 0.024418064931523986, 0.07513946140534244, 0.026245217668474652, 0.034613901225384325, 0.028641475219046697, 0.05431735800812021, 0.007641993888682919, 0.005840079738845816, 0.04921492945868522, 0.0068378012747416506, 0.038433605441241525, 0.0038000753374944907, 0.031167300621746108, 0.027251727624388877, 0.02671061476576142, 0.03271500507253222, 0.040686973588890396, 0.05654849512211513, 0.062221805928857066, 0.07944909812067635, 0.04229235775710549, 0.04582187109917868, 0.05127977354277391, 0.043983107461826876, 0.08027340896660462, 0.017320941951766144, 0.042037589591927826, 0.062055305097601376, 0.036511257421807386, 0.037464282650034875, 0.10593426326522604, 0.016050676422310062, 0.050504155005910434, 0.10295742729795165, 0.03948635305278003, 0.03707058072905056, 0.04594708625518251, 0.0407339812227292, 0.0772149367548991, 0.018784540661727078, 0.006129035864432808, 0.014992537107900716, 0.011818817711173324, 0.031173653405858204, 0.02526057323848363, 0.014554107801814098, 0.018624372205522377, 0.04893279830866959, 0.02157280618121149, 0.06756447139196098, 0.07500565960071981, 0.07802476829965599, 0.045635822098120116, 0.07417348941089585, 0.022070985796744935, 0.05251632886938751, 0.017493136911070906, 0.0350437754241284, 0.14233130787033588, 0.07458102496457286, 0.04557278778520413, 0.02824538358254358, 0.033790733286878094, 0.0482996684149839, 0.032744089839980006, 0.019236671869293787, 0.08116899567539804, 0.011178890672454145, 0.012969461095053703, 0.03468404902378097, 0.03115287698165048, 0.05133129714522511, 0.030806934119027574, 0.07371133920969442, 0.04883752510068007, 0.0441110017709434, 0.055255725819733925, 0.01312010686888243, 0.04139502329053357, 0.01674261595326243, 0.07408951540128328, 0.0750133853580337, 0.019337759804329835, 0.004311031025281409, 0.04099342491826974, 0.08624921174487099, 0.05014307418605313, 0.01887554466520669, 0.0640795091749169, 0.020840302713622805, 0.03628718819527421, 0.049443407042417675, 0.059982438397128135, 0.010318448366888333, 0.04436558439920191, 0.0039596741953573655, 0.06893670986755751, 0.03430676712014247, 0.011433845302235568, 0.021406192172435112, 0.024903247685870156, 0.0733984200633131, 0.02171793872548733, 0.10909541160799563, 0.10468576307175681, 0.09232551616150886, 0.12557016976643354, 0.17819918633904308, 0.1984991814242676, 0.13088360574329272, 0.11109911385574378, 0.19612329953815788, 0.11291526054264978, 0.09610042063286528, 0.15546280948910862, 0.15765072021167725, 0.07638591327122413, 0.18132650759071112, 0.11582957056816667, 0.14273796026827767, 0.07625648271641694, 0.14126130903605372, 0.2065408116322942, 0.1295247333473526, 0.11420473470934667, 0.07978785884915851, 0.121125269215554, 0.11845804241602309, 0.1914374830084853, 0.27495155401993543, 0.10826229146914557, 0.13394794834312052, 0.107926276687067, 0.10723573053837754, 0.14603164134314284, 0.062479483312927186, 0.09998597190133296, 0.09736750420415774, 0.18410924967611209, 0.18492700735805556, 0.14747891837032512, 0.1436836938955821, 0.10277430235873908, 0.21021905879024416, 0.07199161977041513, 0.12192709298687987, 0.21669453475624323, 0.11765117204049602, 0.14887897996231914, 0.14188993780408055, 0.07506021487643011, 0.14295570639660582, 0.19881630112649873, 0.21213897998677567, 0.13013638177653775, 0.16602907766355202, 0.1248688402120024, 0.2940546430181712, 0.1063321805850137, 0.06052630647900514, 0.12917295534862205, 0.18178275029640645, 0.18002075812546536, 0.09787990522454493, 0.11935463844565675, 0.10384280205471441, 0.2905693097272888, 0.13259253435535356, 0.09654783178120852, 0.10991268689394929, 0.18028053949819878, 0.08643661145470105, 0.2088656189152971, 0.16149578732438385, 0.1729732792591676, 0.15836744190892205, 0.11732609651517123, 0.12890544079709798, 0.08367934729903936, 0.11090482701547444, 0.24370839848415926, 0.17016566038364545, 0.12572061794344336, 0.16985559108434245, 0.1649809128139168, 0.14235386915970594, 0.1310481844120659, 0.1626344199758023, 0.17883743334095925, 0.09642613440519199, 0.1791431091260165, 0.11800480540841818, 0.18218227807665244, 0.15486147691262886, 0.10665042835171334, 0.1583319969358854, 0.19638106226921082, 0.18825530220055953, 0.14825447753537446, 0.20944528077961877, 0.12743155035423115, 0.06125640538812149, 0.14659739536000416, 0.10048708485555835, 0.11205513364984654, 0.11757764004869387, 0.20550683664623648, 0.08291501682833768, 0.09060635333298706, 0.2194138677441515, 0.09178431238979101, 0.185865527309943, 0.13155545719200745, 0.1649229065515101, 0.1581608279957436, 0.13114406989188865, 0.07678531488636509, 0.12647173076402396, 0.10990864961058833, 0.14780681405682117, 0.15908961097011343, 0.13121420284733176, 0.09365442805574276, 0.19014967867406085, 0.18292923487024382, 0.1508756392286159, 0.141838314011693, 0.16882884461665526, 0.1372019838890992, 0.25912777811754495, 0.257716717896983, 0.13975658977869898, 0.049466576892882586, 0.1659343350911513, 0.24499676685081795, 0.1247374207014218, 0.10416701668873429, 0.1284620669321157, 0.10235520414425991, 0.17634479678235948, 0.10231815613224171, 0.09241265914170071, 0.21064292901428416, 0.11720379799953662, 0.11688599552144296, 0.16132335673319176, 0.2175141774932854, 0.17734448454575613, 0.20371232356410474, 0.210225515475031, 0.18558891402790323, 0.1313482940895483, 0.11833932105218992, 0.1408935006475076, 0.08883662798325531, 0.07488024406484328, 0.13179095549276099, 0.2809010253986344, 0.09314060953329317, 0.17682063218671829, 0.12463454419048503, 0.11655199195956811, 0.11928605657885782, 0.1303008120157756, 0.21234638057649136, 0.18573759589344263, 0.1556431662174873, 0.1752296753693372, 0.14396731305168942, 0.16403817746322602, 0.13827619812218472, 0.16582483862293884, 0.18654128245543689, 0.1297386796795763, 0.07571164242108352, 0.08330773911438882, 0.20414389728102833, 0.28259662503842264, 0.08234220498707145], [0.07965733733726665, 0.06841263486421667, 0.058014678361359984, 0.03229442998417653, 0.04160665412200615, 0.03428263989917468, 0.024926658734329976, 0.04545510542811826, 0.0919584499206394, 0.021168638122617267, 0.08316388863022439, 0.09108757672947831, 0.02867718922061613, 0.018047873745672405, 0.0816105587000493, 0.02960038196761161, 0.0486795404140139, 0.062211705298977904, 0.028672717780864332, 0.040809164493111894, 0.03268845845013857, 0.01081865497326362, 0.023749580977892037, 0.05573574693698902, 0.02844207683665445, 0.01831757206673501, 0.06148869390017353, 0.01970561086636735, 0.04521210030361544, 0.02164973906474188, 0.03635313914855942, 0.041267047345172614, 0.07862630125600845, 0.03684945411805529, 0.03703773327288218, 0.023658816317038145, 0.011235395013500238, 0.03873675421345979, 0.04320142186770681, 0.012002584608126199, 0.056695726088946685, 0.00807274938779301, 0.06192496912262868, 0.017598987578821834, 0.02323331336810952, 0.024932716514740605, 0.04246668082487304, 0.032865709290490486, 0.014507831183436792, 0.013548871556849917, 0.03346194702317007, 0.02950116053398233, 0.04057715799717698, 0.0767485934193246, 0.03402538553928025, 0.05662637981004082, 0.011169577646796824, 0.021809117133670952, 0.019688287284225225, 0.04193539956759196, 0.05968855904939119, 0.014896586690156255, 0.016778424578660633, 0.04054808436194435, 0.05534665746381506, 0.058040156291099265, 0.07200856300187297, 0.032782852213131264, 0.050197295495308936, 0.055641538710915484, 0.04971675487468019, 0.016446870104118716, 0.026406399156257976, 0.023956638324307278, 0.02831654255714966, 0.010134400381502928, 0.034605741311679594, 0.04854247315961402, 0.054250976609182544, 0.02213130755990278, 0.06464680685894564, 0.06205413621501066, 0.05000612567528151, 0.02921212184446631, 0.027238135189691093, 0.031568212507409044, 0.03486273220914882, 0.05763536297308747, 0.0832578148401808, 0.05952973573585041, 0.005239442925812909, 0.06428934400901198, 0.05562704085605219, 0.05143848553416319, 0.04419661592692137, 0.032713105174480006, 0.047904793900670484, 0.048485902952961624, 0.026391758437966928, 0.04785564146004617, 0.05235766882833559, 0.04484982091526035, 0.046655165642732754, 0.0789587982580997, 0.0063964896526158554, 0.04649826449167449, 0.02550559329392854, 0.05997539912641514, 0.05398304645495955, 0.03709550204803236, 0.01569728054164443, 0.052530808170558885, 0.0442406512593152, 0.04872025834629312, 0.06966510554775596, 0.03417846834054217, 0.050806954968720675, 0.05475922531331889, 0.03895973619364668, 0.015483874121855479, 0.06692324095638469, 0.006796066136303125, 0.04097209188330453, 0.03897390379279386, 0.021969070367049426, 0.019645977445179597, 0.013868912537873257, 0.0349105636269087, 0.07142958391341381, 0.10424828928080387, 0.014866695764794713, 0.0818523504131008, 0.016966789080470335, 0.018266536426381208, 0.031041486181493383, 0.03440130931267049, 0.03531445894623175, 0.010188140222453512, 0.05385016120271757, 0.06287058771704324, 0.02950794561911607, 0.006562034041053266, 0.07280425663338974, 0.016458354839414824, 0.04049327675602399, 0.01939738209330244, 0.05450518074212596, 0.056564325132058, 0.02043590273387963, 0.023652459822187666, 0.06034204976458568, 0.02109075529006077, 0.05630925268633291, 0.027010863595933188, 0.03859362732328009, 0.05994126033328939, 0.018128868032363243, 0.05978066699753981, 0.021899924468016252, 0.02095466581522487, 0.01519156441645464, 0.0436889906268334, 0.015548399223916931, 0.004624722469088738, 0.021641887142322958, 0.018562226614449173, 0.007755619481031317, 0.015264851499523502, 0.038268447897280566, 0.06017912979586981, 0.02025094840064412, 0.01524001088910154, 0.048541389624006115, 0.05835777323227376, 0.030990545164968353, 0.019771187035075855, 0.10561502102063969, 0.02923215983173577, 0.0544111543422332, 0.047628392130718566, 0.06159740369184874, 0.05958974208624568, 0.030193588027032092, 0.029484903789125383, 0.03487104797386564, 0.05714175684261136, 0.03524352818203624, 0.04251500577083789, 0.02021344582317397, 0.046093612181721255, 0.06918657614733092, 0.024050497740972787, 0.0255753180681495, 0.053215955194900744, 0.023819821544748265, 0.045421935137710534, 0.04803263997018803, 0.03429950891586486, 0.009410820312041324, 0.02243576993350871, 0.056802253966452554, 0.04088407687959261, 0.03769795897824224, 0.05724521222873591, 0.013399249019130366, 0.04160761149250902, 0.026901693672698457, 0.054091889833216555, 0.06491481864941306, 0.023732236986688804, 0.06074961871490814, 0.02873733472370077, 0.010276822231389815, 0.050184523133793846, 0.07592656096676365, 0.021082656603539363, 0.05200663668802008, 0.0899354147259146, 0.027912695477425586, 0.009974230997613631, 0.06176325514388736, 0.025360763174830936, 0.015273360222636256, 0.06749055348336697, 0.05104879863210954, 0.04511781044129748, 0.09306322579504922, 0.019722769320651423, 0.05622843651508447, 0.041815071454038844, 0.023545553449366707, 0.04594928672304377, 0.019474123873806093, 0.02577097046014387, 0.041210358394891955, 0.023500712886743713, 0.04241508671839256, 0.021408188549685292, 0.02964533014164772, 0.02662028797203675, 0.06558344917721115, 0.02545485636801459, 0.11993220003205352, 0.011500432647153502, 0.011289135782135418, 0.02866209950298071, 0.10209428728558123, 0.020512496084847953, 0.04312470606237184, 0.03264037470216863, 0.048908567187027074, 0.011632041405391647, 0.008716877910046605, 0.054566997932852246, 0.047357964649563655, 0.03424843060201965, 0.017389338281645905, 0.017710200263536535, 0.05945489014266059, 0.03891422398737632, 0.005243585501375492, 0.012482191050366964, 0.054859982992638834, 0.07921555908978917, 0.08290742465760559, 0.08086518268100917, 0.036064354644622654, 0.024176635015464853, 0.023663614301767666, 0.039183590197353624, 0.04449219850357622, 0.04420620447490364, 0.03946574361179955, 0.09862143691862002, 0.032158160538529046, 0.008889256550901337, 0.0760213406465482, 0.12121714709792286, 0.022998388376436196, 0.020637560955947265, 0.03483602973574307, 0.026050854758068454, 0.10468772234162316, 0.03544058694387786, 0.019736573267437052, 0.019614577176980674, 0.041334961279062554, 0.006028611687725061, 0.061589536926476285, 0.051268222014186904, 0.010716342494561104, 0.11131488587125205, 0.029907339812780265, 0.06692178634693846, 0.055082293329178356, 0.038225147291086614, 0.03808553818089422, 0.01673650993325282, 0.052878166679874994, 0.03766546775295865, 0.02963531300338218, 0.0719020128599368, 0.014649134245701134, 0.0560443579161074, 0.021032672957517207, 0.05391126593167428, 0.1070192015322391, 0.019118197269563098, 0.07533840893302113, 0.012290949798625661, 0.07760581109323539, 0.07998287299415097, 0.03509086098347325, 0.020742825327033643, 0.009390611630806234, 0.04403733619255945, 0.056126242780010216, 0.05411914891737979, 0.03558218500984367, 0.02182886568334652, 0.013523728521249723, 0.025610030170355458, 0.03824756757239811, 0.05895917260204442, 0.014016135155543452, 0.011353455865901196, 0.060944632859900594, 0.08056887279963121, 0.04718105890788138, 0.02340326704143081, 0.048608234865241684, 0.04823038892936893, 0.05329452265868895, 0.07375448025413789, 0.03388375407666899, 0.0316412361280527, 0.015777109656482935, 0.02019813717197394, 0.044948504291824065, 0.050231653221999295, 0.05355363609851338, 0.028703246025543194, 0.036484220981947146, 0.021209545302554034, 0.08559879352105781, 0.04554071587335784, 0.03216858771338593, 0.048228986270260066, 0.06540579386637546, 0.048480006589670666, 0.029703839209105354, 0.06760638047126122, 0.13297773868544027, 0.10212787688942626, 0.08393579642870463, 0.13056299794698134, 0.1590807645698078, 0.1296014417312108, 0.17145340534625575, 0.2256888005649671, 0.14035023370524868, 0.14773541945032775, 0.12768885295372456, 0.1756726484745741, 0.09188871772494167, 0.12643923953874037, 0.17902049148688093, 0.16319917951477692, 0.12985804671188816, 0.10307291289791465, 0.23586435767356306, 0.13350709778023884, 0.1294964723638259, 0.11564554763026536, 0.16264497331576422, 0.1271671082940884, 0.12226350110722706, 0.14193934999639168, 0.11405218625441194, 0.12036866450216621, 0.3362295596161857, 0.13328810484381393, 0.1688686979468912, 0.1330002406029962, 0.13313456933246925, 0.08377149977604859, 0.11937101764488034, 0.10591755752102472, 0.12669603747781366, 0.15468741359654814, 0.1934920297935605, 0.10519003757508472, 0.25371152500156313, 0.2051619309349917, 0.17330093745840713, 0.11244593377341516, 0.1285940653178841, 0.1098201707645785, 0.16823586862301454, 0.10377219412475824, 0.22687678603688255, 0.12934655853314325, 0.15045767650008202, 0.11599648700212128, 0.14122525550192222, 0.1045360644639004, 0.10941593776806258, 0.13502432964742184, 0.17100716679124162, 0.11919461656361818, 0.13008438691031188, 0.19228881545132026, 0.09836108409217559, 0.11479621898615733, 0.09644108868087642, 0.13522260182071477, 0.2636039676144719, 0.15037688630400226, 0.2383766759885475, 0.15435427834745497, 0.1652839020243846, 0.1428827829658985, 0.18439519917592406, 0.12284273994737305, 0.17026009125402197, 0.06747781080775894, 0.15919401630526409, 0.1895495186909102, 0.0809409782232251, 0.17207056051120162, 0.1112794408982154, 0.0751323664735537, 0.1657222886569798, 0.2075392971164547, 0.13348153821425512, 0.043799047416541725, 0.07672239560633898, 0.07213795644929633, 0.09757668594829738, 0.10300003399606794, 0.19231205951655284, 0.1820093725109473, 0.11672995155095123, 0.12038359651342034, 0.1763599959667772, 0.2638954238500446, 0.11410990307922475, 0.11854478463646956, 0.09447286851354875, 0.14732288924278691, 0.15625227650161833, 0.13277439022203907, 0.14655979815870523, 0.13537383667426184, 0.1242242923763115, 0.18580386968096718, 0.12220280084875412, 0.09334331974969245, 0.2611818944569677, 0.13549848779803142, 0.1345769184990786, 0.08610164310084656, 0.10566509372438304, 0.11193817117600702, 0.22089897945988923, 0.16102397436043248, 0.13622528786072508, 0.20090506091946736, 0.28497710824012756, 0.1795074442634359, 0.10539630267885514, 0.0780467432923615, 0.1551194622879848, 0.11460924972197972, 0.18133541336283088, 0.13286677276482806, 0.11894876530277543, 0.12674178346060216, 0.07843620012863539, 0.11696231056703255, 0.15055690164444968, 0.3736296168062836, 0.15064446022734046, 0.26943306264001876, 0.1206171874946449, 0.14032945357030258, 0.11210404860321432, 0.2133342533488758, 0.18568920786492527, 0.11249094503000379, 0.17433520930353552, 0.1857280221884139, 0.11889326007803902, 0.1713736096280627, 0.1622542177210562, 0.1443895505508408, 0.17426241945941, 0.15265039633959532, 0.11478798856842332, 0.11041985577321611, 0.08231151718064211, 0.10515365007449873, 0.264906941447407, 0.15211165649816394, 0.12241800883202814, 0.11862490689964034, 0.12511726672528312, 0.14943337911972776, 0.12546904472401366, 0.13678949821041897, 0.1286700612399727, 0.09899747572490014, 0.12047163749230094, 0.07728216049144976, 0.10052083773189224, 0.09204965987009928, 0.136860046768561, 0.09594054718036205, 0.09656242982600816, 0.11099716502940282, 0.1904379585175775, 0.13180539768654853, 0.23759028146741912, 0.18438283499563113, 0.12254104207386263, 0.18370391830103472, 0.05016944640374277, 0.12249705498106778], [0.056468402544851415, 0.04091653099749237, 0.057662362305563875, 0.012587617766257608, 0.006589892409465392, 0.03135441460472066, 0.01228900908245123, 0.03090030928433407, 0.008071464544627815, 0.014920692574378336, 0.0978237840172369, 0.022715305422025267, 0.042308358461013995, 0.027007728021999355, 0.051457837034831755, 0.024848848261171952, 0.020415903709363192, 0.06450990287703462, 0.0578307147952728, 0.05339754017768428, 0.01945602289197268, 0.017852204655355308, 0.039182629116112366, 0.0434032897464931, 0.018164526372856926, 0.05663757139700465, 0.0197915385797387, 0.07602515528560616, 0.016930870988289826, 0.043960650073131546, 0.06319108419120312, 0.033342858296236955, 0.08525888246367685, 0.02956285341497278, 0.06766987862647511, 0.07485253969207406, 0.032887892084545456, 0.06720190998748876, 0.026130071601073723, 0.07267177585163154, 0.022478089049400296, 0.010115819786733482, 0.08544956988771446, 0.01427214456271031, 0.013674375222763047, 0.012567029662022833, 0.019848216397804208, 0.03200000515789725, 0.021375762262323406, 0.03375008214788977, 0.0215661862239358, 0.04365809872979298, 0.07864927072660066, 0.019642177649075165, 0.016256208655249793, 0.03538201293849852, 0.010632448265823768, 0.04745761652884539, 0.027565578166104387, 0.025273349310737103, 0.03681118898384739, 0.03313009568955749, 0.011730639434972545, 0.038017230908735655, 0.006073989379729028, 0.07439712819177657, 0.020215839249431156, 0.035097766667604446, 0.009887220676318975, 0.03539017285220325, 0.035659008426591754, 0.038958574732532725, 0.035237164265709, 0.021086643791932147, 0.06342496461002156, 0.019986161241831724, 0.030934075148252305, 0.04300990323827136, 0.04652009105484467, 0.062421736802207306, 0.04440695913217496, 0.05100954644149169, 0.020621437797672115, 0.033809635788202286, 0.014489809054794023, 0.023409757122863084, 0.02285539136209991, 0.024963727155409288, 0.04069378279382363, 0.0674271592288278, 0.07754906648187898, 0.03978062202804722, 0.051547165639931336, 0.03941388233215548, 0.07449823096976615, 0.09908188018016517, 0.024043746052484494, 0.07506370297051035, 0.0737691079848446, 0.029955058053019457, 0.026942771546600852, 0.025915819132933393, 0.047811016120249406, 0.00912041699848487, 0.03709758006152697, 0.04611824406310916, 0.031055486797413323, 0.007021251367405057, 0.021696741132473107, 0.07406578151858412, 0.029164483385102358, 0.04287613854103256, 0.028864024898211937, 0.047239120831363834, 0.04504338045080658, 0.007400097811114392, 0.05529490008484572, 0.014454754636972211, 0.01792051007214468, 0.010883678241953021, 0.028441828217182774, 0.01722229011647869, 0.07833085968741216, 0.08832889507175423, 0.039448462703148834, 0.037232495087664574, 0.0431566518091131, 0.030500364046019968, 0.07007027365034446, 0.06609633259358816, 0.015799290595168713, 0.006581981579074636, 0.006760911528544966, 0.013879942707717419, 0.029854285530745983, 0.03013313267729245, 0.07702906586928293, 0.0448134037287673, 0.03145425202092156, 0.06247789511689916, 0.03913621520041488, 0.03948148827475961, 0.041425759336561896, 0.02968735425383784, 0.05649373204505537, 0.011912156696780585, 0.026664145188988186, 0.03697846164868679, 0.04686324900831096, 0.06957533536478877, 0.06558608380146325, 0.07979456044267863, 0.021091326743771788, 0.03577314331778325, 0.025248737838410307, 0.028961201714992058, 0.019505021336954087, 0.03507055953377858, 0.0515926333173411, 0.06329001247650012, 0.026053242618218064, 0.05248829424090218, 0.033096750994445756, 0.06688540626782924, 0.06345084329950623, 0.045358039933489636, 0.030743029637960717, 0.023669755573791917, 0.09349232816020958, 0.04858866072027013, 0.02985176779475296, 0.02564940667070914, 0.009008793349494226, 0.05370634411519859, 0.02566835370089393, 0.028741839560098015, 0.010767336389108095, 0.02808036148053361, 0.017735184665070847, 0.018501303711673245, 0.06722856051055714, 0.031925879447953776, 0.04434713831869885, 0.054641301758238114, 0.02472151056281291, 0.06649988281424157, 0.014278782145993318, 0.024639833500259556, 0.05100159061839804, 0.03551116147718858, 0.04501483002968598, 0.039284763479372486, 0.051926095111411996, 0.041448146221227944, 0.022966206997807603, 0.029266157616802957, 0.04026959344628267, 0.025094538104895037, 0.07486947550205514, 0.06440669239964336, 0.013902044793212553, 0.06653109754552133, 0.01833116821217118, 0.02166245576518122, 0.024188032548408955, 0.008300672216137173, 0.03178973245667294, 0.04934441196382977, 0.037805262400070205, 0.05425130686489865, 0.049309805617667735, 0.15159503265749663, 0.053819224776816554, 0.04846354204346426, 0.034019630184047855, 0.013682977642019978, 0.02485763528966345, 0.03425683913519606, 0.038602069253101945, 0.04058263133629225, 0.0029507715089494013, 0.005853464836036437, 0.023424425671692006, 0.07824203945347108, 0.020903142212773673, 0.026834076597879175, 0.07177916515502147, 0.026136251835851, 0.039538411001558416, 0.02268484211526811, 0.026741467700048815, 0.06240881601115689, 0.04148453372181393, 0.027484708189149387, 0.018738336402748246, 0.03958096946007572, 0.009433657123736339, 0.032882786108530127, 0.005228199388511712, 0.05086981116619427, 0.07374850596534088, 0.0858446596248541, 0.016922835384320933, 0.07799928294843994, 0.047280536382459104, 0.02688487475097645, 0.033522064695716836, 0.03159464038617443, 0.0422089403582504, 0.04046559835842345, 0.0406315982399974, 0.03936687840905506, 0.022387532189895865, 0.04662293416913599, 0.045369617437245324, 0.05920122406678274, 0.04683643150201533, 0.026371328967798036, 0.04287765252229292, 0.003878195425386366, 0.021713530368288048, 0.0480912510829512, 0.05211021452851128, 0.029431508119159844, 0.01404034586812486, 0.054058541427366436, 0.043189614298171364, 0.023625447502126917, 0.012535446639958536, 0.04939826962072402, 0.07849990608519875, 0.10192263594944961, 0.04451996966963634, 0.0874063980882056, 0.03665538250061218, 0.034383445818093605, 0.0759952912630979, 0.03675716805446427, 0.03532401780830696, 0.020487563633651007, 0.037085638905409724, 0.05601145850960165, 0.016708490147721022, 0.025385905282746535, 0.07619750424055383, 0.04091095004696399, 0.03156874685373623, 0.0319007317739306, 0.06033664321876131, 0.05776253739895765, 0.036689955450128764, 0.033272487853537314, 0.023466961865779012, 0.026253474061377347, 0.013862926189176505, 0.03138250860502012, 0.04374210613605101, 0.03101412505202461, 0.06758505856851116, 0.05163575209735427, 0.042271280763088726, 0.01571119766595075, 0.060013352558598854, 0.0769495299027767, 0.05390724720200524, 0.07002868369454518, 0.026158531109103933, 0.049502151741762646, 0.05639229158987291, 0.01713355894025881, 0.03720806729688775, 0.01953413764567813, 0.011274934786342783, 0.07749915705062449, 0.038557417938136496, 0.049600026177358814, 0.05298848693200853, 0.023475548514397815, 0.05461106666189153, 0.03440765467530582, 0.028677599257207476, 0.07252244089613669, 0.005447746616482618, 0.04131166155275423, 0.05392968232627027, 0.05822985294798855, 0.08440984325716272, 0.03317820170195773, 0.06496088375570253, 0.06846922362456098, 0.0210509112366708, 0.07795028635882773, 0.0903903141443152, 0.03391516176634468, 0.025002910697367042, 0.038941661186981946, 0.02371410260820994, 0.0181016998612904, 0.08420282116276212, 0.05170604832528625, 0.0194735023251269, 0.038619984698016196, 0.020098049280932173, 0.03715688508236781, 0.0340904867334757, 0.06623463923460804, 0.030503297384711914, 0.011268736925558187, 0.05245672327873763, 0.019709505286300555, 0.11058433796279132, 0.020903017903037835, 0.11919841635972261, 0.18385265953838825, 0.13714192929910496, 0.10788324696477503, 0.1688674362958409, 0.14303354284493253, 0.1324657310033217, 0.21691331989131868, 0.14585799362976104, 0.15685531601775438, 0.13157703884644434, 0.10156941818422638, 0.10753191425465047, 0.18879784183809534, 0.16150723124155775, 0.114663233543979, 0.08618300475063734, 0.1896082967869006, 0.12069425210938789, 0.12822391174267977, 0.10116117016877979, 0.1275428873486817, 0.1402766423416324, 0.21130666136741638, 0.11394269720767625, 0.11708792648278177, 0.10583213632344268, 0.15349936875281855, 0.10144351283088326, 0.10869075558730401, 0.27310992940329015, 0.09596268544555642, 0.16117797000333667, 0.09547332811052911, 0.1378992761601694, 0.22764020366594195, 0.19202161260182038, 0.1996475807391107, 0.10006060969317332, 0.12835206580348313, 0.13220875494880602, 0.28297713899519295, 0.16524865000974387, 0.12608099001226947, 0.09515436788205989, 0.0790952421084512, 0.1184600981650874, 0.16505300503922626, 0.08023260568734258, 0.21035712794400752, 0.12318956039962359, 0.10008514509536326, 0.18082000664435327, 0.09121693306951784, 0.12617144297109917, 0.0865474363672547, 0.13534992467612028, 0.22055863053537905, 0.07784822621033527, 0.20199018472339958, 0.12552997504826635, 0.1709354159538634, 0.15417319431435317, 0.14386412483872846, 0.09529004732030444, 0.14773148606764153, 0.11046042156522162, 0.1843364952947013, 0.20046455174451694, 0.10291571859852411, 0.08756724375416525, 0.12311543468968011, 0.10158534467336722, 0.17903564614243805, 0.22671012935461476, 0.13129042141372338, 0.14044545125216246, 0.13477798114763573, 0.1533419592306018, 0.18457074678735808, 0.25033288286067545, 0.240722946182359, 0.09010309557197616, 0.0919358737883158, 0.12025729040033184, 0.09869798945146613, 0.11949003586778417, 0.13966784375952557, 0.08902141533326358, 0.12840840965509415, 0.17177677393192425, 0.18683411908568814, 0.1489152858266607, 0.26121588482055813, 0.20426761329872534, 0.19498907524393871, 0.0946568840299733, 0.23704612394794822, 0.16972147015621886, 0.1906350877834484, 0.3082954476121813, 0.14255549584049731, 0.18574287998490036, 0.10780048265587538, 0.11648244530078955, 0.10208711071754806, 0.08001572787179612, 0.13732198916841298, 0.17757066147169098, 0.13470706151565537, 0.14112988952547312, 0.16723039210774004, 0.07024413658655249, 0.1464732934255153, 0.17542987712658942, 0.14530329761328176, 0.12973961478564888, 0.07586782739963382, 0.07395208449452184, 0.16932635073317215, 0.09923953461111523, 0.06720576915540732, 0.16580414754571393, 0.1939271212904714, 0.0928086468775291, 0.15141715470235795, 0.12087760711438023, 0.12938878673594445, 0.16204801941057667, 0.09836521043325774, 0.08364644047105685, 0.10692044394090772, 0.2272764770896174, 0.12290295780985616, 0.11186561881913804, 0.11842678315588273, 0.11385668971342966, 0.1599891681689769, 0.0948028867424, 0.1768040971364826, 0.21542581846006215, 0.10007246921304613, 0.17225442017661408, 0.0730387530347798, 0.10484176993486471, 0.16598947666352615, 0.16147045040270314, 0.10807563390699215, 0.16761648701503873, 0.17890860530314967, 0.21592612989479676, 0.16926614771364257, 0.14633118698839098, 0.13793432037346065, 0.11107975122286007, 0.13347077707294375, 0.15869432827457786, 0.19827671523671597, 0.2125637259450741, 0.14716025500092655, 0.1183831003436353, 0.14867211371893063, 0.15864740969846025, 0.15473335253773257, 0.1772463132510893, 0.15267073118593544, 0.15636046678991988, 0.2128591452492401, 0.1817816073889844, 0.1821077219210565, 0.14194049290381372, 0.09027041276567616, 0.12540107883978635, 0.14874049520585686, 0.20052410167409107, 0.09835789285716601], [0.06981153128435835, 0.028797290979127865, 0.08311245037475601, 0.05075444430985954, 0.06454105081502348, 0.06454859845689498, 0.034528717515058815, 0.09011286223540083, 0.04605513182468712, 0.022278011601883918, 0.018506918058847077, 0.07142510134144686, 0.028710968072118703, 0.03378278859599959, 0.03470466588623822, 0.01474970267736353, 0.06821464470704086, 0.044553392290254124, 0.04312852070142981, 0.012219863183418056, 0.03330113846459426, 0.015446474517375464, 0.06305273302132264, 0.03496475896099582, 0.05792659656435717, 0.017508202508906834, 0.10126182765816338, 0.029076906248519663, 0.033635924992267974, 0.03267042055085767, 0.024429204568150453, 0.03775740129640326, 0.10178139040363021, 0.07651791907846928, 0.020096631778869778, 0.05615672649582848, 0.030838944803690538, 0.0815817411057651, 0.010849035716091748, 0.02711605189688271, 0.05062058684416115, 0.026305893807148095, 0.018454509445291478, 0.010195582108281087, 0.08434454910457134, 0.03138577776553575, 0.023548017379653174, 0.02069641512207454, 0.04710004235676024, 0.01323858796240529, 0.04541371585219167, 0.09834024458541535, 0.06861094414489344, 0.025924518959072884, 0.011208761188754579, 0.0231510091907694, 0.04110555601073429, 0.05194465251406655, 0.021556208048423287, 0.024219278820964973, 0.06430170076782815, 0.0255886860031751, 0.05531854862056207, 0.05273068709357176, 0.04659706661186647, 0.09461139037739486, 0.01946162425156217, 0.03598746443458367, 0.06912637312780134, 0.03558301250450313, 0.05020992684876546, 0.022387359640561044, 0.046976511875982396, 0.03315678332000971, 0.051455358261591755, 0.044063530294806696, 0.04483189062739257, 0.02411405341263162, 0.0032119376828632085, 0.01949406723724678, 0.005386542161431862, 0.07042903525871225, 0.05789454691694118, 0.03143654437735677, 0.021372481969592627, 0.07989437188371085, 0.014417396778299008, 0.040449022490065545, 0.07987171411514282, 0.03244533087126911, 0.05980620800983161, 0.05300567878293805, 0.02092677961627487, 0.005352991984182154, 0.02520812937291339, 0.06445461287512444, 0.022425066308642272, 0.022965475982346106, 0.03304807723907288, 0.016809533553896472, 0.04802705530892126, 0.020315639558248222, 0.02707811330765253, 0.027472677975310944, 0.09643847632105462, 0.005707720947611961, 0.037684845228795893, 0.05227475608990062, 0.04404782644996885, 0.03834228788036853, 0.018890628816734534, 0.03789446484006476, 0.0339368473214563, 0.05697217980923597, 0.051162647796445526, 0.036916637036483735, 0.06704012921545655, 0.053055796015542, 0.023342030581261497, 0.0624269837862812, 0.03974204148107674, 0.04348460686742328, 0.048323936644010246, 0.05760268621088471, 0.055497621433460154, 0.08284100244054571, 0.039543977109133266, 0.0733697360556107, 0.047512887977063656, 0.017938432938535698, 0.036790794765693136, 0.04154375710641034, 0.027642883978842292, 0.027955554505751934, 0.05063769705884624, 0.03397881948330905, 0.048459786776220426, 0.021016744613007177, 0.03325136633065995, 0.01720971256872872, 0.0682143701124005, 0.04586645562085323, 0.06096067067119293, 0.03977493346610572, 0.02304734785866458, 0.019192547479178756, 0.009272695497202221, 0.05658894588123076, 0.013400114548858255, 0.034162708834628575, 0.03436486986174714, 0.014367438179760939, 0.007544861600763397, 0.02656176406162558, 0.014050469690118916, 0.05502019041159656, 0.030159718262439128, 0.13945771206635982, 0.0366129724716302, 0.03326272861158941, 0.05156203456863295, 0.03827455948339775, 0.034221590831293724, 0.07853994495235384, 0.02417030820652144, 0.0492973969085142, 0.02149410698621068, 0.02684071510884678, 0.03947988894651644, 0.040536306478315964, 0.0175488443710492, 0.04823913885047659, 0.011515216228872305, 0.03239243058487773, 0.043896027564187534, 0.036098448908887804, 0.043047934595961124, 0.039115642866818234, 0.06262973853154108, 0.071449503157055, 0.023737654664728325, 0.036652065100497566, 0.010707697401812766, 0.09341867742477916, 0.05425178926088847, 0.03083859042817494, 0.018879108829423785, 0.033031935527105816, 0.03810914218774997, 0.021360258797358256, 0.03242201259126887, 0.02161472639272688, 0.0038604476594628068, 0.06799257927923463, 0.013655000529979588, 0.0216707158688223, 0.02503105850337306, 0.004973548575435416, 0.02032089396379888, 0.10288635923643596, 0.051586662739282474, 0.07968708261614665, 0.046940213433117606, 0.03439552056079265, 0.03917277710570488, 0.03646568955446128, 0.024410476471530274, 0.04118353346711956, 0.020747348717122804, 0.0492906025465345, 0.021927610287093557, 0.020099819303140976, 0.018891239233198576, 0.03706081406562589, 0.04427339481480885, 0.055148507744888775, 0.025419689700356685, 0.04596781072905287, 0.032220667926594615, 0.05185688984056469, 0.03668890531116631, 0.004915047857139143, 0.053356247080955654, 0.05155624581675511, 0.0685727977543138, 0.04371081719000358, 0.08949833427323028, 0.01850276759796543, 0.007542287276010029, 0.05125976153067313, 0.05221872765105218, 0.016108606614579912, 0.09135118758422323, 0.016315038701577578, 0.08509772509569302, 0.09679797265562229, 0.09086721081985161, 0.03390569196199067, 0.017928688539541326, 0.04532778257271275, 0.10325641633244231, 0.025129526657110546, 0.0268400249115075, 0.052660001238109544, 0.1292762326193042, 0.008185804454114987, 0.03107618715148419, 0.050533236062619835, 0.07274672534549609, 0.046446985797956586, 0.013431794050120516, 0.05913580745982472, 0.05779257211543154, 0.06244334072107449, 0.06264338662731461, 0.07509616450988688, 0.01331371278865845, 0.05042752454755828, 0.04966299740772229, 0.031281112678698264, 0.058525903077679686, 0.043607506522675976, 0.03462511878751684, 0.038178751929081045, 0.030425370023294818, 0.046996776218293235, 0.0482170710893115, 0.04514416039455682, 0.007388743879346293, 0.04710281056759413, 0.05275089577480685, 0.011569262205739506, 0.03753923956537619, 0.03398667511646636, 0.0237388996174559, 0.003986341880590771, 0.024044354613579344, 0.049195874817087315, 0.022392181745090056, 0.04885907706920989, 0.0791796317207627, 0.017980317898036446, 0.0323357564775506, 0.0383248325670138, 0.028681042822427116, 0.03128194759483449, 0.029669872965314426, 0.037650201775250025, 0.037299985997378826, 0.04589198550092988, 0.023589822558278684, 0.01821731904783519, 0.05817631812533364, 0.07130747093469836, 0.04184483899734914, 0.059870893601328135, 0.016279050105367787, 0.08209725172491744, 0.026079397757712286, 0.0667480866832193, 0.05547871522139758, 0.02173198758100625, 0.015226943523884984, 0.14993738644989207, 0.01854523699876154, 0.019858265077346005, 0.03280751749116462, 0.048136444165720604, 0.05374274645873811, 0.04552951686491724, 0.04798751739144791, 0.03608805884141475, 0.04442356468643993, 0.03009431835380383, 0.013008267069380963, 0.03414602164411917, 0.003888066917170363, 0.05598751311481465, 0.09322096928372048, 0.051142977172276005, 0.03400784116820432, 0.04162802055361681, 0.04384399187983945, 0.03885223239194602, 0.005983563323752605, 0.0323940521775512, 0.02557282816269435, 0.06810770122683607, 0.009469308042753255, 0.009682640247774543, 0.008242814383265795, 0.02973885744722793, 0.03727283081389032, 0.11752903679735027, 0.07114904467016459, 0.053096484261914156, 0.014022904470039066, 0.019887789567292202, 0.03237637793063186, 0.04573425314447377, 0.03318883667816408, 0.03202334570232779, 0.06545326163177378, 0.037586614562314935, 0.0076972013266640715, 0.040996575335157104, 0.042553126186248846, 0.03682231006678194, 0.04948841087752953, 0.00954635039306595, 0.01929186168126762, 0.017652353562880307, 0.12366500988719054, 0.13689751038327813, 0.15165199991315603, 0.10134111871593632, 0.13605091284262016, 0.13417468930128962, 0.08383639316889457, 0.14665969123598188, 0.12725149048492312, 0.10420445061754435, 0.0939279020531103, 0.23202371376100928, 0.1100781190325506, 0.07682119772653095, 0.06559743123943917, 0.12304673407925293, 0.115580602287082, 0.18048825178993866, 0.1126897960784845, 0.13232782512204722, 0.08443543993053026, 0.09036067276610993, 0.13926934014307335, 0.16512600268470123, 0.12093848548829556, 0.17976422735955566, 0.15459418500540778, 0.1726487826090306, 0.18153266137233004, 0.1324386871419847, 0.14836885733529925, 0.1582338850130327, 0.2755095897009596, 0.23984975006897002, 0.09894243063172325, 0.1820460197632201, 0.07715762068983167, 0.184958296304103, 0.11260667553870007, 0.08711453367141075, 0.16311479732394218, 0.07993044026079588, 0.06335611557005905, 0.1162910825223662, 0.15702296717790887, 0.08974163254606538, 0.13232843368314207, 0.13040855701547116, 0.18012977961916476, 0.17397844407241791, 0.27857264096383005, 0.25368768721818924, 0.10960375308059156, 0.10004560346715152, 0.12680041312705725, 0.10063002991955727, 0.11712153092958033, 0.14934473700122908, 0.20225945074344054, 0.1017373290960677, 0.15020671184174716, 0.13481097703333944, 0.14293782063759863, 0.1899746505660005, 0.26208345545455813, 0.18576094385934994, 0.14422970678424463, 0.1677547936560586, 0.1751095216604881, 0.1262890436919406, 0.15057311014970765, 0.1698558434145525, 0.1460401908843778, 0.34264515910763294, 0.0988488235452678, 0.07495694502722472, 0.1073338944115676, 0.09056911236257292, 0.12511057255323976, 0.14273236447479576, 0.08579095781897195, 0.16570600593695417, 0.20263781247194856, 0.15767424629302695, 0.1413403477636166, 0.2119915300863795, 0.09410748694790527, 0.14334494801005349, 0.14907015720382333, 0.15774595260154456, 0.15144310018513352, 0.23976078140549362, 0.06490658823167905, 0.11080922355176881, 0.11993524283752777, 0.18134019279386848, 0.17973090492887422, 0.1480993241420947, 0.17798644228605554, 0.10410932954982854, 0.14584442717023194, 0.14670801989268512, 0.10380715670180507, 0.11372919616405852, 0.21324914385331795, 0.12238254159456119, 0.11307461449177936, 0.1347901820554398, 0.10519653136725537, 0.16824214719235897, 0.1171138348581735, 0.12246307203895412, 0.12019130605040118, 0.1879698276752606, 0.12932641664519906, 0.17130809283116832, 0.12867739365901798, 0.268162238644436, 0.15677084476919845, 0.14486059168120846, 0.11105782818049192, 0.18267926468979567, 0.17849861324066296, 0.1690591181977652, 0.16529081884073094, 0.16758895333623514, 0.09248059534002095, 0.27133711671922356, 0.1826790568884462, 0.08735565745155327, 0.12579403119161725, 0.15725763427326456, 0.1396380242658779, 0.15348991379141808, 0.07112269100616686, 0.10234002722427249, 0.17028694215696305, 0.10612412690534256, 0.1560056905145757, 0.15586980327498168, 0.15281500469427556, 0.1305742043768987, 0.19380638870643452, 0.10558796973782592, 0.11895238698343746, 0.15943052392685786, 0.13501585432095453, 0.18008182203629985, 0.13309893140103668, 0.15041694743558764, 0.24692866631085053, 0.2607312920736149, 0.12973213393706828, 0.10209581610979512, 0.09680223258328624, 0.17489570891484618, 0.2010692239855416, 0.2863262436585501, 0.2726108499336988, 0.12424306871253066, 0.16628531157039106, 0.13329928158782423, 0.09726017480716109, 0.10193350099143572, 0.11690585539327003, 0.11602752361795865, 0.0984921028430108, 0.15085330058354884, 0.1680349840898998, 0.14675962884211913, 0.13886357832234353, 0.09201266380841844, 0.21826251468155533, 0.11263034262810834, 0.12933714810060337, 0.10094008437590674], [0.07773435849230736, 0.03578023453883361, 0.06754220696166158, 0.02606258996820543, 0.031040157737152185, 0.10214902809821069, 0.04462372562556993, 0.040889104930101894, 0.015065580209920881, 0.007259163039634586, 0.08370819457923062, 0.018445748391968664, 0.07030753826256841, 0.052029650687472895, 0.03323525430459995, 0.04422109937877394, 0.0678302047890611, 0.042805374760064296, 0.0053284037039702525, 0.006170546503199148, 0.046419993886956945, 0.04745311540318653, 0.017730204854160547, 0.0441514599515358, 0.01372608807287179, 0.05573403257585596, 0.018248183114337735, 0.06931624418939464, 0.02917502002674155, 0.013990143288538093, 0.022215624812815804, 0.03664522620965727, 0.01907464989926666, 0.025078042017412372, 0.03591323482396547, 0.011488266991364071, 0.022926340679987334, 0.10725165702751838, 0.024018214317038655, 0.06567493372131139, 0.08849640522385016, 0.13102878467179835, 0.029158008146623615, 0.10216597132966854, 0.05716094878152944, 0.05574257840635255, 0.04180324904154986, 0.03376732594915666, 0.01563426663778955, 0.010926875875156838, 0.0412693517137086, 0.0042004347869806224, 0.11145012002089061, 0.01123806581745157, 0.017720308314892463, 0.025412199574930128, 0.03581855904485565, 0.03221361381292809, 0.057323712899233215, 0.011518054016050883, 0.03731254313606769, 0.08368487629923038, 0.04204745273455046, 0.013156206787243718, 0.02745754743955331, 0.025099722006416414, 0.03612573396821972, 0.02102213074977044, 0.029965449975861702, 0.0028119330727349734, 0.02271105291583808, 0.02533017370296875, 0.04023794084787369, 0.04175526548351627, 0.018177890597144142, 0.035937848151661456, 0.05592729525233153, 0.03505588727421127, 0.010771215966087766, 0.03452119213761762, 0.04048354348924477, 0.018807339438353665, 0.03634698674432002, 0.03560786703019403, 0.06189625171828084, 0.018302554708498064, 0.062351284723263234, 0.013157148387108464, 0.02855805039871484, 0.0555976258328883, 0.06042199020157568, 0.02216119013610296, 0.020467176836973522, 0.02031295112828957, 0.03569076863641385, 0.04460038508113939, 0.04675262076489162, 0.048446346481796354, 0.0338922739319969, 0.026113983694813214, 0.039423329872079194, 0.04398227625642903, 0.029894919971411582, 0.04634072509361431, 0.02896757490816526, 0.07597173549584113, 0.02192281786847161, 0.05744569600210525, 0.03348706872202456, 0.04326399975980166, 0.0854866772715468, 0.047065424878383055, 0.04992276393750217, 0.02788023393804906, 0.061205731544760056, 0.03164321024087258, 0.05977760563837364, 0.037216178970993496, 0.09323080274043605, 0.07834080446627922, 0.013583377713075606, 0.05376273620640859, 0.008069570212683175, 0.012164268900960451, 0.015196518252196256, 0.030791903773206286, 0.033514112583361566, 0.07471383971278556, 0.04544957271718886, 0.06216957357537467, 0.06955759061384015, 0.0139074569051445, 0.007760843736832612, 0.04212400897813495, 0.05433990074379835, 0.04511130551691167, 0.03246820386266336, 0.05840592748427298, 0.04274621816875879, 0.04233203668263741, 0.06036880047759041, 0.027160688368894625, 0.035939454901381396, 0.034729817270999774, 0.02204918706411263, 0.04665690597903449, 0.07061227894155309, 0.05947918434685562, 0.03788453861488961, 0.01942913488164777, 0.04287867668608669, 0.02867671981221065, 0.057352137155248784, 0.06356452548061498, 0.03238191064156126, 0.07768484982079826, 0.04003819551144261, 0.06611193995922804, 0.09354697249364108, 0.010052407906187, 0.05196752921619918, 0.003695711284308345, 0.05313913177815266, 0.022773508353566285, 0.029853712221665774, 0.04706981468189042, 0.036925323875038885, 0.023938247904879972, 0.018921520713774953, 0.05514287855476141, 0.0215045490040211, 0.033240827833651565, 0.024611693115730304, 0.040326256421394646, 0.03355952831043396, 0.06452095345593989, 0.01834458438679576, 0.03164928471960593, 0.04861069879552815, 0.062123538154992275, 0.05203928376431577, 0.03143023241136689, 0.09784057881915942, 0.05607966559182387, 0.021720319164160173, 0.04092744427907746, 0.01090015577574377, 0.06089209251513239, 0.005455001573864138, 0.0914983480470255, 0.01087058304619859, 0.03469719616987277, 0.02998083840793697, 0.011635695555014536, 0.024431534911855124, 0.06071676383726299, 0.007038608346192632, 0.01254432736459421, 0.012127458376198774, 0.04841492394916713, 0.01762238192895893, 0.04034384532133117, 0.07837098761228845, 0.012997719295526622, 0.004948367968609091, 0.06600360866286792, 0.016710844611225184, 0.0382208354130853, 0.045020273682894185, 0.03078216679568868, 0.07049713472952135, 0.013577224381151609, 0.046260639937827364, 0.042926281748805195, 0.027832868217956275, 0.05093797743029427, 0.056797548750182614, 0.0787455569661688, 0.02689761371584609, 0.06192439395817928, 0.03326761936477851, 0.030821277978247963, 0.018467311492713634, 0.06491501902928576, 0.05305233760736883, 0.04946327804645989, 0.071453221316915, 0.037545117374975234, 0.012095181446056813, 0.016071096615632996, 0.01899713257444091, 0.02747627553617349, 0.03653725114418194, 0.030761488706048112, 0.010864721007237677, 0.06211281041032635, 0.02916424404247664, 0.019869864845531993, 0.09596387288183905, 0.024451650824630633, 0.03043139626242919, 0.05011522509448696, 0.017870851115731057, 0.03505251050228253, 0.02688793611014262, 0.02313871736987494, 0.007947246649564477, 0.015143463970161974, 0.017955687872017734, 0.05322648255969398, 0.02348910755245015, 0.054199352816795, 0.02083326158754062, 0.0302193034440279, 0.05775232544692699, 0.03860390235786326, 0.028947312421223614, 0.03191666197380982, 0.027003321520169266, 0.010657384427759098, 0.029931635872344486, 0.029948117116873618, 0.05344726407201961, 0.04769187173224054, 0.016133052959048655, 0.0288384708983358, 0.021687876178475562, 0.07204385954537429, 0.028099785340600647, 0.018645864802238066, 0.040166961844079196, 0.023196343281597365, 0.011057095889555058, 0.03980006629717536, 0.010271214378008153, 0.018204734078608453, 0.030280380342446733, 0.04048051552672405, 0.018918726527772378, 0.06655004457570612, 0.05069694270787295, 0.08551101971534081, 0.04472973771044053, 0.049481828027637675, 0.005852822878296138, 0.03874338530295063, 0.07840814694645815, 0.04439080999873113, 0.03780068705964368, 0.016941877038334496, 0.06157745105156209, 0.029244613069749903, 0.03228909023164306, 0.06649799775914289, 0.04843465765588917, 0.0020647779865612392, 0.037689769378630444, 0.006273529697864433, 0.036058710611541755, 0.034105340819223784, 0.04054256649396848, 0.02578021947556408, 0.04634308512322605, 0.044322398825897835, 0.02429373107588617, 0.06542019895277917, 0.05501234219991602, 0.019827198775601573, 0.03042465014004847, 0.019958119191869628, 0.03802546503720805, 0.01200012995468569, 0.02909739880124107, 0.03817849217739422, 0.06106233748141676, 0.04583505906339269, 0.06748857937054709, 0.06579616354429163, 0.05041608434112277, 0.017138846742454916, 0.03875545633491129, 0.050558472794364206, 0.045633766349055804, 0.024765380767348688, 0.07245437853271142, 0.04719404278148431, 0.062981123192003, 0.04067318077431992, 0.018815070761775132, 0.03987078926002141, 0.031893848354229704, 0.010571287875791313, 0.03474460085271858, 0.03598565730499104, 0.040676516728126444, 0.03367358156538103, 0.039151596211013384, 0.045979644273757, 0.012393069318932248, 0.03123198992398102, 0.024124753326759674, 0.02890865580411628, 0.04191913911199663, 0.011746404506993713, 0.00836709072245867, 0.04442518998985179, 0.06873063772218302, 0.040296600200235844, 0.012091226726624882, 0.004061635545440367, 0.0715946449781768, 0.05992650272673927, 0.15292830095859244, 0.09894876857288182, 0.21609027811791748, 0.07915044305264018, 0.08190439722966403, 0.19877594313584268, 0.21811331331264228, 0.14834326808340847, 0.14266468060668558, 0.13272794662043452, 0.1472445036051795, 0.11700703238602728, 0.20285288686864078, 0.10263054093229584, 0.11452876380644739, 0.13933985901530832, 0.1451123578590341, 0.10778434836538509, 0.10620272776577622, 0.16189668065635487, 0.10969920069328509, 0.1458904700120911, 0.09972733343602158, 0.16065534960944206, 0.13239795807749033, 0.13712791755096987, 0.1310679255402647, 0.16149807313922793, 0.16857255133800209, 0.12386605769279413, 0.08980839615105651, 0.14208536013029516, 0.08093230993836187, 0.13513541431166232, 0.14504888938972726, 0.05073311127489433, 0.179270431981422, 0.20275326096452773, 0.09431649799807929, 0.23255482432432473, 0.2001571690198034, 0.18785500258672982, 0.1417731386027299, 0.1624445934430696, 0.09753332225955091, 0.16651242360239848, 0.11447515105828643, 0.1374392633442767, 0.12895316089270636, 0.22049446444725618, 0.15750957856653258, 0.10941679865936749, 0.2148396850680001, 0.1592700567562133, 0.08452089081401937, 0.15571136958897114, 0.1216840989945922, 0.14230778178898618, 0.19999490585178137, 0.17114594840677455, 0.12186719424789771, 0.17158679896965623, 0.1649405251373537, 0.1024312742811162, 0.08340698652318679, 0.10552962950896472, 0.17837623308878392, 0.18413774814689532, 0.1548248593462631, 0.1697647967375815, 0.10182346275541931, 0.12091621363651939, 0.0934046137263067, 0.17290561023401096, 0.0951239991991315, 0.15159807546297088, 0.11442461822298355, 0.1548888473189436, 0.14933660306269303, 0.2019538640161045, 0.16277277114568278, 0.10202868885244243, 0.12451633490854874, 0.13506633520592004, 0.19707924511749297, 0.1517960210912861, 0.13385105354245752, 0.10898559601628222, 0.18780655518639833, 0.15264805115293711, 0.12654459482291713, 0.13063321996014565, 0.10206938823102973, 0.08690898102940992, 0.13587255991296843, 0.18094593426212668, 0.13479709887178615, 0.09994599982746877, 0.1202986651333049, 0.10333610072848387, 0.14572137908544391, 0.07135720225051045, 0.10875026098801754, 0.11344418919179589, 0.1575597032206133, 0.14689287403598428, 0.0910210951406043, 0.09043796002515592, 0.08621571862022392, 0.14595521497540176, 0.10982895037159324, 0.11565473541850224, 0.13026271015405655, 0.09049241882166825, 0.1732713109231554, 0.10794938716571778, 0.21477556350873783, 0.1261664557387121, 0.25865393166895956, 0.10792692977702245, 0.08565548618207686, 0.29672854172531515, 0.09555200318573043, 0.17351059417705983, 0.08091478041023947, 0.05888175546715502, 0.15831840079044923, 0.11636784285656177, 0.16700204811058939, 0.236343176511582, 0.189982992305886, 0.17289317183895037, 0.10757607946288772, 0.18673746177228168, 0.11147062556119636, 0.11474279177491553, 0.1388172386214137, 0.17252102930797264, 0.21149494423298165, 0.12185187631985173, 0.1990449716686271, 0.09879054268822074, 0.15046760643599555, 0.08007170064956881, 0.10116088815266266, 0.09968748752726242, 0.1203580221044831, 0.15910869900835678, 0.24074941116850823, 0.09606951760360971, 0.12526600796263665, 0.11025912885088474, 0.09096094407141209, 0.10300543683115393, 0.10213181769358926, 0.15489021287066862, 0.10409962967969477, 0.13074472022708505, 0.16723885259125382, 0.16278322058496997, 0.1856380293611437, 0.15458529407624155, 0.17515241779619828, 0.0992941418371629, 0.07071748579619452, 0.19223864626837894, 0.1250108130625449, 0.20353178872028366, 0.08391452647629194, 0.10944269219180569, 0.11445479394751601, 0.1722819686983712, 0.11978190770605579, 0.10840604547411203, 0.1744964037789032, 0.1216742061660625], [0.041006171304616146, 0.037483563646674156, 0.046146033782861196, 0.036869770410703495, 0.03843085578409955, 0.04520928756392095, 0.04586788054439239, 0.017431421765650157, 0.08499701565597206, 0.01580896077939542, 0.009688659065432148, 0.04550485529762227, 0.04532507744443137, 0.015892166666162666, 0.0188419457845157, 0.03359027177793905, 0.055537493317388, 0.027972286225121934, 0.04338203834777232, 0.015999384741007816, 0.09061396776814945, 0.06595634127734229, 0.029492110043065622, 0.04024662026495207, 0.0354795088787796, 0.09854615345830098, 0.054461924664792605, 0.032565881629125215, 0.04165127204032615, 0.017469759259256534, 0.0375487761630211, 0.0016431126368843252, 0.0539148690586444, 0.09534782351693138, 0.017190370344906114, 0.055006816910463385, 0.024009150838537607, 0.031140123173827305, 0.022651061408396345, 0.05252633673080709, 0.05996185493131634, 0.05346950623788871, 0.04015143611468375, 0.08689270573086105, 0.03466638590907678, 0.018105124872818124, 0.020619511924451217, 0.010379831401223782, 0.05515318327525165, 0.05491252333740704, 0.07299639124539681, 0.055947730288608, 0.026891912166320253, 0.016577178248553537, 0.016308715603372548, 0.038362225677701645, 0.04869868040259462, 0.04231284103298094, 0.030732771301700268, 0.05234119686065242, 0.01919900230859639, 0.028960531926713884, 0.029751030524494126, 0.026827738656720612, 0.04909755509288516, 0.029559029499068856, 0.004570604596665362, 0.024653867512824945, 0.022291798850346822, 0.036257034735172056, 0.07084033350110985, 0.029148289722797927, 0.0413220256450586, 0.09052157038240694, 0.021870160635444336, 0.02040638752077939, 0.04557313288387377, 0.007731043724561459, 0.04413102491525933, 0.043100163238705136, 0.0637099270534236, 0.031626270720153116, 0.0859178279642947, 0.02075265878374921, 0.012592992770805722, 0.0326886068796739, 0.04030177296954207, 0.034965827653650194, 0.10533646331168711, 0.06295439103269018, 0.03401257978111971, 0.02314923174708383, 0.06424160907045007, 0.09649091647588648, 0.08555212727515027, 0.02681817793927621, 0.011926197203138145, 0.003392303920008999, 0.07917002090835012, 0.038376627053366974, 0.0628655040054582, 0.060711034457199275, 0.021964958868920803, 0.04420074597874191, 0.0349427208857378, 0.004664078096539015, 0.054646040371153504, 0.020539372962957714, 0.0635387803777121, 0.04454773341421969, 0.03120113513432443, 0.026142239112232346, 0.05194753575779032, 0.06373382420861162, 0.07590484572574496, 0.01090257239411585, 0.03326730766275432, 0.05048686667578295, 0.03371764287294354, 0.052816542447544634, 0.02358965743042063, 0.02812239486956969, 0.015852758624532726, 0.012149473259341903, 0.09728640972753055, 0.03794324249611236, 0.012360812797851395, 0.055327424706774764, 0.05851787303981837, 0.047628425527364016, 0.04972162707417738, 0.07616620787302963, 0.0588153852004325, 0.01030894794894266, 0.009842645431490382, 0.05489190276421141, 0.05144727256265469, 0.034678278825595044, 0.03840610515908338, 0.07721919668256305, 0.02040270275756484, 0.028598690405488014, 0.006308373067440698, 0.04779302646056749, 0.10231885375105776, 0.026285154490324203, 0.011098054092144594, 0.02335238539671991, 0.010888672895816853, 0.06573098071385175, 0.0047553219064866425, 0.021212346910033375, 0.05195133184315637, 0.050206279192934744, 0.018424335576128215, 0.017795248531911056, 0.0327611777902348, 0.022993161801423412, 0.020483006846916396, 0.023258132641785778, 0.03255890173022635, 0.022109655401436612, 0.02309597151906928, 0.01447695784008829, 0.022357833295245655, 0.07284361272468232, 0.015418126331496751, 0.041530888265697286, 0.0393803483893862, 0.06192535875015892, 0.026668098980735522, 0.019739423114515375, 0.03799190883000847, 0.03318997587484773, 0.042302369329263456, 0.032974623172776774, 0.03413978760363534, 0.033936027248273604, 0.0715969679004047, 0.07098546047927812, 0.03335505549330264, 0.010763144182419637, 0.041765050700632855, 0.03660199981823098, 0.016458712925668806, 0.029228465791675262, 0.03449527263001073, 0.02510760175937321, 0.04733314723125659, 0.008361410509678535, 0.005015526767238043, 0.01296311202167999, 0.040098023746395484, 0.040805527969496325, 0.05331958869646769, 0.01829976052249549, 0.06028535710356664, 0.014152390685922, 0.0640485022449866, 0.007802758846082725, 0.05549053392314818, 0.05825939784699585, 0.08475258931866847, 0.008924092035158537, 0.03917001260560937, 0.02685446153918747, 0.023282907386601437, 0.04371879898826592, 0.07866266649216413, 0.03109823079284979, 0.02711505556362681, 0.03634720567788463, 0.03478042432107031, 0.035845075981342234, 0.053120960292289965, 0.08873370694345795, 0.022503496475110296, 0.07600876124342903, 0.03424630805966444, 0.05646463614539243, 0.041322155520902015, 0.05181651700695511, 0.0121666038830881, 0.004411824884300586, 0.10690295894164592, 0.013147511599527206, 0.03431526471104007, 0.024724006034375634, 0.0712764120544307, 0.02660502570506651, 0.0607585690158885, 0.046192199079087004, 0.031158187048276886, 0.06281111200223677, 0.05156216073373798, 0.09312831214629114, 0.03707949392264709, 0.008497588114551036, 0.009348344465252012, 0.024341241514775902, 0.007475756519852439, 0.02011216121900361, 0.026394211236038245, 0.022029143510735594, 0.03022255034011323, 0.08070482683251612, 0.05693545834219549, 0.020813256996916607, 0.0842955376720056, 0.052055102642043494, 0.07219047081889585, 0.06854852952528745, 0.009823808795772493, 0.06755952126695774, 0.014781786649109563, 0.08672477255458944, 0.04882440021901857, 0.053042901199660264, 0.031801402728888206, 0.020354581902211066, 0.04235552936734166, 0.015909547764749732, 0.021894221063121222, 0.023178980736702215, 0.004490847841225332, 0.05048965344030876, 0.020302527664171066, 0.033633104831096716, 0.026562055354588665, 0.06749931824742816, 0.011106366146123037, 0.057501817209413275, 0.007968415484356228, 0.04303186338802334, 0.07393900043098256, 0.09338539952295832, 0.009393727723363554, 0.07107163124601357, 0.05315210823027883, 0.01807419401302468, 0.03273204849392641, 0.0029548913562393864, 0.08331576173077337, 0.037946908705634996, 0.06076691817725077, 0.028820646366511937, 0.06605639020563103, 0.04868745541898534, 0.0640183562063612, 0.04125740684685297, 0.022620971030846704, 0.01203368616188527, 0.006371050685629598, 0.05056416877778247, 0.047108721773838624, 0.028243249907973222, 0.013062157195236068, 0.0262192684749607, 0.0328186311526224, 0.0308722839326947, 0.003190806651218736, 0.033401395194232464, 0.012956323225807864, 0.057170741420122795, 0.04003537163953297, 0.05889783780730795, 0.026024137441709172, 0.019556713778001722, 0.04625276575097814, 0.027178071322850883, 0.03415166567720007, 0.03863138408632949, 0.04966013271769043, 0.034359069977654144, 0.05000658580684103, 0.056243387080030516, 0.020797315664822236, 0.008666532467032084, 0.02339709608349949, 0.062259147089207545, 0.07815764984115958, 0.02282516739796847, 0.04687575048592407, 0.051827092611347325, 0.0196885804325575, 0.017510497600596864, 0.0421111401374219, 0.0513571053306805, 0.07377259607892483, 0.054020762399886735, 0.00459061660876614, 0.04511535764322616, 0.07431584075675346, 0.02412589623418171, 0.035376005253056064, 0.03053792785067344, 0.04048305367177818, 0.04078641395608429, 0.04404217499541119, 0.012304237025091425, 0.024388733399973717, 0.05021945973567199, 0.015415332145494176, 0.053603734777425416, 0.020934943240717985, 0.053646779342670925, 0.07918077462818474, 0.018822473684849683, 0.023775686022418085, 0.024922068550949916, 0.02876876653317595, 0.033497332624392584, 0.09516934442217462, 0.106481151888147, 0.16941773879807442, 0.15203671442577615, 0.16260655975202098, 0.09446572163142264, 0.13140389579348266, 0.11379299859981984, 0.21053534728707746, 0.1426528359297663, 0.1622473751194775, 0.09779258412891068, 0.19489362020976841, 0.07061979689751752, 0.1435947252321057, 0.13242126151453704, 0.130454228783492, 0.10703667168854736, 0.13971204607514665, 0.12726119777653366, 0.12767313426593319, 0.1783437715494074, 0.22033738147001714, 0.10327035386580974, 0.14971658267313614, 0.1729042298393324, 0.257584645296447, 0.10209010157268494, 0.1731092407135293, 0.11259970677201636, 0.14907107746694237, 0.11259892009547912, 0.15909490990452468, 0.19183549680747092, 0.1847299374639988, 0.15536713181063533, 0.11732384038623422, 0.18447572219884023, 0.1758182281628251, 0.19233297323808074, 0.2118537577916868, 0.14223574893549085, 0.16573542467085645, 0.21173544460907578, 0.08407656700001098, 0.11247777190874331, 0.12652942532440647, 0.11784577800426632, 0.21165223501157016, 0.14154583361232653, 0.20223497471306473, 0.18478987331036478, 0.18114156438969076, 0.13759109191596508, 0.22651399456663057, 0.1414367082179524, 0.1251468635746278, 0.1533280810690485, 0.12510001921327785, 0.13670241460204124, 0.1551712048240006, 0.04160182274063118, 0.14429131988435984, 0.13663391437148675, 0.13143571908585727, 0.08372023221454583, 0.13190109020797536, 0.09531879069982097, 0.12528799037681893, 0.18196721852291375, 0.24582890735473484, 0.13784263544948772, 0.15027611749246716, 0.1162713413941674, 0.14395674486877397, 0.11276410732534714, 0.15021175844594836, 0.16206958622206002, 0.15486210031667724, 0.09721699665533379, 0.11930778666283004, 0.12301727823796682, 0.13858574791811407, 0.17285281384829432, 0.1780520481406711, 0.14068458607653156, 0.16228007414611056, 0.10677793674403802, 0.1380962273105979, 0.09199488195008598, 0.18829380482202396, 0.12169116424047388, 0.15573296608636156, 0.1697635350865312, 0.19813702820101753, 0.17366893880534917, 0.07990062818862498, 0.07152938051149249, 0.17114630463765934, 0.15239537955494598, 0.12364579568384215, 0.23411220638081431, 0.12960411346284673, 0.11608659115154296, 0.13784621260128915, 0.13084850215818733, 0.20432695542695, 0.13213494094088674, 0.17215914325788617, 0.14521118224365637, 0.15277386002708226, 0.09201462307828479, 0.10522927492274903, 0.2145266768638976, 0.1483650426962413, 0.07110246748197824, 0.1330845188931562, 0.14470389462076128, 0.1770844656857662, 0.14364428585395217, 0.09105655495659448, 0.18403415917418897, 0.09711274717119522, 0.07787253896822222, 0.18054315587505698, 0.06665414563030936, 0.08951644267654046, 0.20333316031610593, 0.1610843258094974, 0.15431114472448826, 0.09217828890541568, 0.23136155476095155, 0.12218045478221029, 0.0897457885730546, 0.1300428860122338, 0.15324018109822646, 0.15172811457887292, 0.1258132528164424, 0.1104564436536748, 0.25019068736582994, 0.09276870448957197, 0.11414445747504942, 0.10531195759540424, 0.1902620546752587, 0.16920273861614987, 0.13201195222791284, 0.1169836324697826, 0.17552441189764068, 0.09507026028586552, 0.10817500748089515, 0.12480667792260647, 0.1238784589804709, 0.14316471002530307, 0.10265541030094028, 0.06500303032225929, 0.11081910895882174, 0.13788631826173514, 0.16246449784375727, 0.12331998543231748, 0.19717220653546974, 0.08545268690795638, 0.10992810130119324, 0.17145402875030413, 0.0704168937227223, 0.0872279486793559, 0.1092302895267494, 0.10575751337455586, 0.27213866589590907, 0.0862587706069462, 0.16015748726204038, 0.1827068132115528, 0.1074142986908555, 0.12511156703112647, 0.08352985649253242, 0.14571627310942858, 0.18869343650294468], [0.006754006308256066, 0.014375907940120669, 0.01558540177938994, 0.03693735408887733, 0.03467975569947157, 0.013069832857581787, 0.004034397798022837, 0.07722799113253132, 0.037313359498512, 0.057790341961663216, 0.04810561164049432, 0.024927447266236413, 0.06460540244006552, 0.034117541727027856, 0.025603105932532344, 0.04388032743008807, 0.018601694027893245, 0.06702785409288481, 0.04103043953364249, 0.019614656957855914, 0.03546714840922505, 0.02059659997030394, 0.02835545521520544, 0.012756225369230378, 0.0597142299375264, 0.03174744859279599, 0.027650140327750705, 0.05722915586375166, 0.02814125098666409, 0.02582197641459061, 0.03621396790549625, 0.06795050692744553, 0.05368745645682793, 0.04987748550774995, 0.029539481329265982, 0.014012129413458752, 0.023640809959033504, 0.06735301125445403, 0.0418178693507798, 0.027693426090991125, 0.050097695566364564, 0.04146985033003148, 0.061933592878631316, 0.045232587290229276, 0.057160102733178064, 0.014868129037495237, 0.025244581811421085, 0.03191084353602491, 0.043329056425136514, 0.03232245348044671, 0.05598521987849381, 0.03479834347672295, 0.020687731994257774, 0.04308379517169669, 0.05138695822097361, 0.06099830869061407, 0.027064416972280014, 0.02826439555065008, 0.06750647255103104, 0.03461209038505331, 0.026015958974312525, 0.013087642546452116, 0.013072702186036622, 0.059843489798367955, 0.026104909084097017, 0.00747641795896925, 0.027190513428649865, 0.027099405524495523, 0.09885948078590445, 0.0835364541853778, 0.0431667004886549, 0.01926826695125783, 0.024681636823515873, 0.05237579578533769, 0.04532076927716844, 0.02806511034577852, 0.005955836686553084, 0.04285804126993753, 0.03675201012811158, 0.022080442613514606, 0.050405074580339715, 0.00575549716813839, 0.0270813509268919, 0.06759694777429104, 0.01717965744319372, 0.057635463163023815, 0.05105177093355451, 0.040846795091056265, 0.03630249128036667, 0.05317620947607793, 0.03312690445454791, 0.09096806126763113, 0.03282325473264791, 0.015145310990192229, 0.04077379002410453, 0.05522988794837147, 0.053643257851945236, 0.014520763106702361, 0.014730860475538066, 0.028588786444743164, 0.03004831447469769, 0.04661121194658335, 0.016975487051240634, 0.02472591892001219, 0.0203269535995787, 0.019333052732690703, 0.019565964648791123, 0.029820686650054995, 0.008370128889509942, 0.049333940260112286, 0.024730562909098808, 0.017248276417376474, 0.025014159800775815, 0.025194935842591804, 0.014636415689892601, 0.030762062015128322, 0.013684773639397463, 0.03711539902724326, 0.0642129176412709, 0.04714775874163024, 0.06651606905506924, 0.026149512159463484, 0.030788462063355837, 0.020276617433410138, 0.04136989045946393, 0.02873153855034616, 0.01034815004459233, 0.04229766040225513, 0.04420465338625945, 0.05236709039309062, 0.01997398074308876, 0.013086571070743958, 0.01630784729059087, 0.10416424105642363, 0.03153158751956653, 0.01866947437520139, 0.06534576896228828, 0.015741121060273144, 0.0420368214690825, 0.054124240050441585, 0.02392621769104153, 0.046416012264671735, 0.014505980452668155, 0.05237157296505757, 0.02731798100285232, 0.04906100431981031, 0.043504366549314, 0.04298609514080454, 0.11836427947855555, 0.0545772989426041, 0.04279083979781717, 0.04561677858873736, 0.017928627312358003, 0.04314563462685328, 0.09751260149641894, 0.04181692311249208, 0.011061003297072602, 0.10533612934523262, 0.02824961753503885, 0.035525110142771155, 0.038138965392136015, 0.08616613573394716, 0.03234874406189192, 0.06503587035695091, 0.09313657967140898, 0.0848578184377402, 0.0762591247621458, 0.062334920366993174, 0.07898236886831, 0.047413978245458566, 0.06739492033375427, 0.01814488543459447, 0.0642665452323854, 0.01850467306212522, 0.031075480255822185, 0.05377595385652967, 0.05022885903599672, 0.04029118252219632, 0.0304873208006029, 0.050448074616724625, 0.02545048511819914, 0.013727401674259454, 0.017201344853674527, 0.03751914591703098, 0.015246587245201226, 0.03140793458442204, 0.06548688092152588, 0.029985500950715505, 0.04691981550422497, 0.012511944678408327, 0.02887324422772508, 0.028042114900017623, 0.09972002328140661, 0.04722550242149737, 0.05256445343547966, 0.04219813839881681, 0.11231654032599181, 0.02599869476398453, 0.04139330892940052, 0.02360788272198988, 0.028053788882971276, 0.06268854631343856, 0.02840850764187053, 0.06762684148270637, 0.013267932481539901, 0.015543091012659715, 0.04242297574819531, 0.025830427621258423, 0.028993242085562088, 0.03667916462291032, 0.06399462974513881, 0.05057782429503277, 0.02542722435464384, 0.02292254830535967, 0.012309008106967667, 0.015801125555299222, 0.031484761711908504, 0.006004162096360233, 0.019655458381748758, 0.06826517754234374, 0.075832864822587, 0.014081077715673018, 0.06232009225641377, 0.016859843744896352, 0.03131699180812575, 0.02581135071523022, 0.05195115372771397, 0.09774517573532648, 0.03919442926417105, 0.010410955219413154, 0.003434147133702936, 0.053552493191091344, 0.037880393720115535, 0.01846921324613504, 0.053805892093805596, 0.03166215727105737, 0.038517516368301585, 0.0471802351239603, 0.010681940239010146, 0.012690845869656187, 0.008851210350258043, 0.020376948377816007, 0.019628477602964267, 0.03990464974776842, 0.071158247301355, 0.025376563498866744, 0.0018727839187704376, 0.034800061548594385, 0.015424008779518772, 0.05599095668003429, 0.06875557388411835, 0.0052196554133843165, 0.050645779047044925, 0.007615399026690284, 0.03705518858623691, 0.04198734990495723, 0.05018873111112043, 0.018813981660059653, 0.01962356829608325, 0.10309677294571884, 0.033056964457500726, 0.02595013975223992, 0.0396735078538768, 0.06673948519164696, 0.024098267931549344, 0.044562483599293046, 0.03871244887704961, 0.0747768406290561, 0.01927811339555774, 0.1392826097435318, 0.040844739341991954, 0.054109148477436975, 0.04672981827752665, 0.04999566881451756, 0.025205906640621834, 0.04753749759402126, 0.02574885631474899, 0.040106666056090035, 0.031045668183651287, 0.037758752005174756, 0.02842745652742451, 0.008158372820616933, 0.028265638648008462, 0.023905151829239912, 0.021064125176053494, 0.004101784807062359, 0.012893564435216831, 0.024915407775552012, 0.07746539675281383, 0.019987318992207292, 0.05615972106170375, 0.030806568611296825, 0.03379850728379097, 0.03985054347140249, 0.003725180577021092, 0.027709495443559717, 0.05399338457209524, 0.004683744546127855, 0.03175009806000162, 0.047159881723928265, 0.05982865797705017, 0.02567839495895896, 0.07464211113983765, 0.0309100406957441, 0.04485338693484664, 0.06697866454487666, 0.031532351931673475, 0.055600653795409016, 0.03736212231160607, 0.03030175419553416, 0.06772493856260553, 0.021278813655953854, 0.03858031690469943, 0.01281934317375999, 0.03497429184790235, 0.01980441484192852, 0.023450805310858414, 0.027393405471229926, 0.024234086522483267, 0.06328424598905258, 0.035842370853060856, 0.0166033018467715, 0.027394299759180285, 0.052498435688903555, 0.04319013009080663, 0.07330378881306387, 0.0663873138546478, 0.046324527720571496, 0.030479270353680477, 0.022363609059539158, 0.012433306710590841, 0.04790500912349671, 0.03062274419789901, 0.06839490495622158, 0.09748722004587762, 0.013920560450060293, 0.03813525465375278, 0.00788234397987253, 0.030826593610981945, 0.03044390701688826, 0.06332395088975318, 0.05011755172745325, 0.013510496028175112, 0.046700726088602096, 0.03433754027355462, 0.018381782683718484, 0.05586508472333662, 0.05011989691411145, 0.08741920755710453, 0.018842044119082857, 0.036300595093052834, 0.0718540552770719, 0.16448368871351704, 0.1036756852408871, 0.191127962898463, 0.10702109400881454, 0.07130061349016614, 0.08678479745867662, 0.09384697827044874, 0.17112957662902772, 0.1073450934200082, 0.15011049981694669, 0.11150332458782941, 0.12337689331616275, 0.13707302830880508, 0.11128151891171001, 0.06755315363989212, 0.1320071579539217, 0.22711234370945022, 0.10606755298795179, 0.1794710344984196, 0.06141917692730203, 0.2283188235014677, 0.1288977373042144, 0.10022286543971859, 0.11151929560583085, 0.09412414074176922, 0.15241225599311292, 0.14504698949167505, 0.14489330555079505, 0.10832214567926712, 0.1089142236742191, 0.15347051405115053, 0.14698528626468033, 0.13494857121258974, 0.17840185202658176, 0.13759469875367358, 0.1741745788604021, 0.17211543075973168, 0.10679887272999622, 0.11056202158215456, 0.09032016634591855, 0.08857249762513675, 0.07386339784716256, 0.18563709425507113, 0.0996756502718199, 0.125532750680577, 0.1577273989096284, 0.19373407383682206, 0.12927471863804385, 0.13495162886101753, 0.08249879072536714, 0.15509439253946766, 0.12145648230216466, 0.13904448424000293, 0.11759186701965518, 0.1553834739024751, 0.1159489895508159, 0.13969671330414712, 0.10092932323459536, 0.18679018394323066, 0.09969421138521284, 0.11264591288636439, 0.13990908628329635, 0.06787149046431296, 0.13023493898799643, 0.110334850178333, 0.0722058406972792, 0.11493498575873673, 0.14002526208059862, 0.1556941369199194, 0.12889312114566565, 0.07781843640259467, 0.132722083653789, 0.08375869772862643, 0.12706104054814205, 0.14039649919141084, 0.11870407179230824, 0.11322995342197828, 0.15114503883523867, 0.14466398191871122, 0.1454405504046008, 0.20013515691971406, 0.08038971092901193, 0.20007057522889227, 0.16570891515584663, 0.11749570694519207, 0.09012904105475172, 0.18898523412644863, 0.149659734161105, 0.10808773833559826, 0.0908143402193673, 0.14206416439265013, 0.16148605034686625, 0.06993204122409225, 0.1645993598503992, 0.1324075911543332, 0.11395334702683613, 0.12988215166842565, 0.10404935659607872, 0.14286842982983217, 0.23610518459463492, 0.11330155582982115, 0.17168554913951084, 0.12492205220041797, 0.09664123848779127, 0.12294793938053772, 0.1077962078852579, 0.11292496041278355, 0.11842506879474968, 0.06772143562557176, 0.11934953246964142, 0.14455187309067696, 0.09863189377938397, 0.2232068806188181, 0.09427007666090503, 0.14658026659162715, 0.08738421529415064, 0.09970054190489464, 0.16559457988478243, 0.19419506628764793, 0.24562775564845651, 0.23692295711953193, 0.10702866391511634, 0.10115377095644362, 0.07638619528734125, 0.17378881049808115, 0.0848976791894529, 0.19033095566555858, 0.13413787877652794, 0.12122431624447927, 0.18667926255147904, 0.11970467981882393, 0.10865508796996437, 0.22644877462880686, 0.17946824402315542, 0.17539067688630894, 0.18264206824824214, 0.18919630092568696, 0.10618798871291801, 0.16470866336021572, 0.09258103018510155, 0.07610764499986544, 0.10221399570582435, 0.08821038893074729, 0.3040528268320486, 0.10622453948599286, 0.16116214741487056, 0.08342928806087002, 0.15540297754341736, 0.2820792293641716, 0.1401186391012743, 0.08171733890776522, 0.1360102283069864, 0.15015348501037806, 0.1410290168132633, 0.12672627257416025, 0.11209710210096091, 0.08551246690331027, 0.2452749534859322, 0.1782533631194383, 0.13048989640083164, 0.18967154261190444, 0.12917147105326876, 0.09498357743723318, 0.19874177465680987, 0.17793836595956236, 0.20283899386413395, 0.09677757843746804, 0.1562394225038588, 0.15376563649624586, 0.1331147539895028, 0.13682797114597633, 0.14178226701915264, 0.20707168470835313, 0.17943297716556117, 0.22450541640864685, 0.17236103711184114], [0.03757166770810727, 0.02745806508755777, 0.05484279856318608, 0.054665655334247276, 0.019547470328689087, 0.04306479619117454, 0.014049122692085803, 0.03184049164701719, 0.014262788863561582, 0.050564621487865224, 0.04979552642907947, 0.07061702126520686, 0.018734171098913066, 0.030389850835490506, 0.021842736423423048, 0.023291065444936976, 0.029254229448270053, 0.01584019963047467, 0.038330242823576555, 0.040334189980058, 0.030906031242921017, 0.028955854540981818, 0.01143027928264928, 0.05521857019630261, 0.02162077304092236, 0.04081608873093501, 0.05306852384819649, 0.03132160796667449, 0.03384755582374055, 0.019446742335276213, 0.011860754621011438, 0.02595191905129468, 0.055046417910489254, 0.028300204176048283, 0.04464951896807179, 0.04668354165914934, 0.03751607713638805, 0.026199861313216388, 0.02533898856199812, 0.027066307593486272, 0.09475633924012072, 0.014257963975978782, 0.011662566867016722, 0.007943932960188249, 0.02991758145071799, 0.053074438765179366, 0.017725707439240068, 0.04658042766095605, 0.04543173148704227, 0.01687087948084809, 0.059021138222306035, 0.048255759247695096, 0.023645622786716558, 0.049722703188308515, 0.047891127251205035, 0.021340519524528645, 0.04620613661245443, 0.020862040219071787, 0.06260584879782982, 0.06933511700481176, 0.026749698117782827, 0.06375701632350683, 0.02007451948884409, 0.014636220876127481, 0.058962081820936874, 0.05899601281271316, 0.014394772406376433, 0.018999347885255702, 0.007500665315092192, 0.04925958077365067, 0.0894889461051207, 0.03333707696583588, 0.052457617566687986, 0.04336738464189693, 0.05131320358486846, 0.02807595497870352, 0.0045023905568086775, 0.01988770793104777, 0.018927378114312887, 0.09118194822804071, 0.036833356934948824, 0.10533560984185897, 0.10612449797918089, 0.06617912658839487, 0.0553788740944583, 0.05955945875030011, 0.023960100443218835, 0.020810444257222116, 0.05569458371610381, 0.022046016238164157, 0.0994254054967314, 0.05283790516841691, 0.06068998343835119, 0.042330333453719504, 0.019738432347367052, 0.03663456896902062, 0.0422326668194728, 0.025088129659707192, 0.017488962330389768, 0.07059431896777824, 0.09184630398522131, 0.007147844598875963, 0.008700739908817923, 0.028814653524023015, 0.050308702993788756, 0.041058681963477284, 0.0440051010082243, 0.07791183568770066, 0.018966808420373127, 0.055830270575825125, 0.035059642541455105, 0.05228652655205224, 0.033645554358372465, 0.03479997620161157, 0.038361112456186675, 0.057428073705523275, 0.029372258759394754, 0.09504774352535605, 0.0391863175900653, 0.0307219192472985, 0.01936857748660259, 0.036548346251947805, 0.09391155253979377, 0.05314249741786625, 0.030210345721570775, 0.021106344102008734, 0.05487880014698021, 0.04545077128568664, 0.04575048391416203, 0.09558111763908528, 0.04691696936788503, 0.024459992564516142, 0.05486336718604434, 0.022713394391757902, 0.06923160224687308, 0.03126525669358671, 0.007111040104064159, 0.03309372303192504, 0.05197255726670846, 0.05357059788366314, 0.020694331542472355, 0.06515375309390947, 0.006880510945848073, 0.020566344464896247, 0.019287336435809266, 0.026836175020434894, 0.06300076784100384, 0.022794819124101195, 0.025107362416747492, 0.019550889774109237, 0.03965971132856794, 0.06286064293817617, 0.011333272232150193, 0.04800708782568108, 0.06727346044499427, 0.04257643704477232, 0.016753813106333837, 0.031884085401543416, 0.051340533173060976, 0.0212380363518605, 0.02921068764408119, 0.03174325916916132, 0.041015544629772194, 0.024037168768700212, 0.027117539902974386, 0.04776580448378809, 0.02011133557971334, 0.03687933669425547, 0.030347346182679757, 0.07539858226664364, 0.024336506612598896, 0.04678445890021976, 0.005426843563327566, 0.0450160434411373, 0.029744982020929456, 0.01815834613807965, 0.02501476279576309, 0.015020721093605971, 0.059859419998247176, 0.08670291630551219, 0.02393018818111159, 0.028033810267515946, 0.034126584796467796, 0.046735139476368204, 0.06426967709558085, 0.02543521171901375, 0.07148949007387273, 0.04902932203549426, 0.02999716751219239, 0.01621600466023665, 0.01974810438696295, 0.02225277672550874, 0.03391849029867444, 0.043346177772036754, 0.01939259709615726, 0.01900819243019214, 0.04825944401090965, 0.01763662374287378, 0.03863999299937859, 0.03910339371941518, 0.03407239317311905, 0.05781692198070232, 0.06355790552333929, 0.017976334420382045, 0.013013597545068478, 0.0302791261128732, 0.04289787233574316, 0.008082493786787381, 0.02660178808582714, 0.02330207706108922, 0.04003880778327584, 0.019989237443951424, 0.04402908722113352, 0.03359093971084803, 0.02605508499982534, 0.007161368848755956, 0.05256330310658086, 0.019910323026124388, 0.07618785632075742, 0.028229642630321905, 0.027449005319795106, 0.03774849923502188, 0.03693081947858445, 0.033292284642811865, 0.01017892738673254, 0.08067753806244582, 0.06302144407527521, 0.013173274328437401, 0.018905204597103875, 0.054797119373688474, 0.009190190939989407, 0.05927534235524945, 0.03451210453931708, 0.02511387661797926, 0.01792686842236435, 0.08765662059886381, 0.01584543177159503, 0.031229429514496587, 0.014281822168413782, 0.06729144268319942, 0.02179634291678667, 0.01756580801156815, 0.027365337446099147, 0.01185411889309762, 0.028318731892795768, 0.028400839401001576, 0.03589874439057894, 0.020169805684417952, 0.0316660015960224, 0.04693072878581006, 0.03695747000165284, 0.01477816867918591, 0.01960214434802765, 0.036378572549438104, 0.03374456056917552, 0.057934051437769085, 0.015311660608858801, 0.058862979130935855, 0.04524256175500341, 0.01656388267292641, 0.059426692241686396, 0.020685715207946487, 0.020678147157013882, 0.04660191654693335, 0.061624206355190836, 0.05613468099909369, 0.0650757756375242, 0.05109860787342768, 0.08674924858496524, 0.03844095641397871, 0.025838431683951057, 0.046282329203677364, 0.052028077334398404, 0.051788270866381936, 0.03812992974417284, 0.050750058217090555, 0.040730819673626684, 0.03502274295897223, 0.06573327395017259, 0.03997415929916315, 0.03622172705945559, 0.07141337540815584, 0.04753982422698755, 0.033325451222481206, 0.035000185380340554, 0.04553572493023239, 0.032088365260278806, 0.026883640930464026, 0.05171084631001577, 0.033454083968536, 0.04514970052696299, 0.07522699772380292, 0.04698247132182587, 0.019281666427559685, 0.034262627887073904, 0.01676678399235243, 0.03182029780873563, 0.06982221821090207, 0.03357778143254109, 0.06255131578654982, 0.012807909461116651, 0.06039205938577652, 0.03182186002959497, 0.03067335124796955, 0.05019490577979013, 0.04571202953229658, 0.045035317016299814, 0.04236513646901585, 0.034792050064424984, 0.06224407406989485, 0.05704732597223483, 0.04955177544616163, 0.02894073328207014, 0.017936362346517853, 0.0822585352580063, 0.0386204040114535, 0.08995975716970861, 0.04506537028646562, 0.029020527144894004, 0.04476100810279604, 0.014084503654885339, 0.017703062658256385, 0.04593744204612449, 0.03789825350395404, 0.028160698966530617, 0.04670070753491018, 0.02956623018690152, 0.0693907261302229, 0.02462841926899273, 0.025758428164408542, 0.0834856838628184, 0.03720625274581835, 0.016579102266405243, 0.0261476493687951, 0.058175442391075194, 0.024813458949211054, 0.02017711212829454, 0.029685777190024965, 0.013719286289415322, 0.01580990330694476, 0.03322807402582839, 0.008716170086700004, 0.04276811894669663, 0.02371207097894512, 0.03356977365911007, 0.0353894307045266, 0.09171389741823077, 0.028214324702275917, 0.041001395584316924, 0.04775790803250857, 0.055773993517505005, 0.044916154074599035, 0.13739421498030424, 0.10407427791506052, 0.11549874339834787, 0.20485634420765564, 0.20508400542894378, 0.08638719184091315, 0.06787318998249248, 0.16248468426056206, 0.10201867728028446, 0.07106228018528782, 0.11917588475625962, 0.1537903500138782, 0.09336947303381748, 0.15316648583393544, 0.14590880105970427, 0.1482348403078504, 0.16798150492832065, 0.13663850084412843, 0.10794625530252233, 0.09242210668162443, 0.13648144755279645, 0.22386400785762817, 0.09851404072833247, 0.17820306034991518, 0.11721371309249662, 0.18134271609596908, 0.17036232951795682, 0.1351450473885052, 0.13493357982952148, 0.1316781490459107, 0.14996883866842836, 0.07808425885741599, 0.15149698010645807, 0.10877509324927814, 0.10065961934742518, 0.12887556193163618, 0.23115851799957454, 0.1115498052968178, 0.10989296803018078, 0.10526972939260304, 0.20367015473311767, 0.10965961453621276, 0.09011166737764142, 0.11297088451101445, 0.11821770531241782, 0.11218719882890582, 0.14859190239803866, 0.18308091501239687, 0.07455955463228747, 0.16734404460294172, 0.10459136930876411, 0.1479533436940983, 0.07338876472203992, 0.14112580771325156, 0.10247132799122483, 0.0742880547477398, 0.19602215965278447, 0.2448525230283849, 0.11989377162535675, 0.17166530335089192, 0.09602014994015917, 0.14515712420688942, 0.12931875768117607, 0.20406123687280342, 0.09173050668323413, 0.09139947913354263, 0.1211142705869861, 0.09265505941584706, 0.16423260531155393, 0.1690202296595089, 0.11184264192706905, 0.05746801238274202, 0.14242854405893013, 0.17474315303843468, 0.103592713130638, 0.19008635863428935, 0.1444806417566724, 0.08220897463615984, 0.1413140312070027, 0.20207955414662138, 0.14510115142911673, 0.2520364383235574, 0.2099473585258238, 0.09357990158605389, 0.1965200071572326, 0.08477452720399015, 0.1099330440047197, 0.1978966168826446, 0.172212919278536, 0.22121492656879127, 0.2944257465424016, 0.142850321426522, 0.18802370759658515, 0.12926735653309152, 0.12885116011602804, 0.1499374012928456, 0.14348386321216822, 0.11030408073565923, 0.15574181248666719, 0.1487591676414013, 0.21669049747288227, 0.10656350059434772, 0.19758460315642878, 0.10670263844076544, 0.16637563094263896, 0.1896838771062903, 0.1722078281454742, 0.13632455753395334, 0.0871612889750395, 0.22098214452853426, 0.14132833981420845, 0.21699669276131317, 0.09124848918872885, 0.20304789359215647, 0.1966446582810022, 0.1376717782113701, 0.12328246986726299, 0.2023007586831227, 0.16206114058149979, 0.11729189835023135, 0.08279934569145553, 0.17824234964791685, 0.17757582681952044, 0.15013035968877375, 0.08661652289447375, 0.13063764316029847, 0.11063321580877528, 0.12116175319533795, 0.10939048952423036, 0.14588365709641948, 0.29199651908129454, 0.11420901690144092, 0.11883767321705818, 0.1431023993063718, 0.1611002374556847, 0.1830286084441468, 0.12434966338332742, 0.09860012243734673, 0.1271281752269715, 0.1164335897192359, 0.14272515079937875, 0.24348913837457076, 0.1439097966067493, 0.14836731366813183, 0.10760833320091479, 0.15141705080168322, 0.13888162735383958, 0.18169415270676836, 0.08267842757049948, 0.13998298934893683, 0.1897638212540187, 0.1426924963016063, 0.0737691747781355, 0.10243696655379608, 0.08652373217046261, 0.16594784217886627, 0.16136377409566194, 0.0952267792308703, 0.1286857353989035, 0.10994583120918833, 0.08360147374332882, 0.1374888833379373, 0.10705643508117646, 0.10655996054993011, 0.1487968539004214, 0.045111401996109635, 0.09306753025157377, 0.12954006611835212, 0.09746118550538085, 0.14892738283379003, 0.12788258318323642, 0.10124141117557883, 0.08221247015171684, 0.12539827352156863, 0.15278332983143628, 0.1022637789719738], [0.023120291698432993, 0.03740136708074715, 0.031976464233594015, 0.0350715725653572, 0.03065587552555371, 0.040764249715721235, 0.04209128026559483, 0.12448385852621868, 0.046006740085431375, 0.03987226984463632, 0.004799713005922968, 0.1402521663112566, 0.026029365872091148, 0.050091016237274744, 0.05258812423562631, 0.015419339742948068, 0.0571512860187795, 0.02298317434906494, 0.014048845314391656, 0.04794697757461108, 0.05629189756291453, 0.05037823852035217, 0.01458316195567022, 0.0321263891964918, 0.028265553301025648, 0.03844176164420787, 0.039406612995662726, 0.0284495242885896, 0.04586996597936377, 0.049286784196738154, 0.011649779662548099, 0.019296123464300763, 0.01756386729539372, 0.039634485729038715, 0.056922890071291476, 0.07233937532873824, 0.030566884597647004, 0.053766079581691884, 0.09962525844457559, 0.042659231039579026, 0.026080841234943364, 0.019957132135459688, 0.05134688595717307, 0.09120108821662143, 0.06775247966288589, 0.03775828445213847, 0.06857365122414194, 0.015067596996232169, 0.050642691712710075, 0.026379420232842676, 0.04173344263108447, 0.01732891076244414, 0.03302855133370031, 0.03738149236596655, 0.049922897524083965, 0.03637256486399565, 0.05259924160782248, 0.06699840567307547, 0.03969458855863195, 0.012440918362699449, 0.06500211748061702, 0.057598533894633874, 0.04492017280426808, 0.03499145772366319, 0.03441172906605061, 0.01236613214132376, 0.03324610079289414, 0.02218367349996697, 0.04511240389547311, 0.07863059086957946, 0.034495150175644085, 0.027148580229550134, 0.010560035061644157, 0.03132678073598072, 0.05980991503747646, 0.020823203631152865, 0.026304817693016957, 0.021860739070689306, 0.06073207805457059, 0.02487173052941216, 0.025146163752651773, 0.07650666069821455, 0.020428264178917743, 0.05027268285630271, 0.052992086348240264, 0.07567618260509335, 0.01268669077035156, 0.006824007532486576, 0.016104263195302337, 0.027708367379091214, 0.04950674563588109, 0.037220743179204874, 0.0038546285259144497, 0.04577789513859898, 0.06813788437284529, 0.01657708919083234, 0.0283758253135602, 0.034109956977772526, 0.05692046324838884, 0.047893079099594615, 0.03395324507437181, 0.03016442533407826, 0.03403442860872019, 0.05195097561227158, 0.04702628772065509, 0.03090817976044491, 0.03690065488626715, 0.029467138629115652, 0.07913885070593096, 0.020678217661043163, 0.04717767842521425, 0.023286269315576646, 0.07545199463493191, 0.02142094606824685, 0.02394726499915123, 0.030687782309541944, 0.023883455141913146, 0.03150806514895521, 0.037634260443155654, 0.01238915820067632, 0.028889944405818824, 0.050074080427293666, 0.05014036905777175, 0.02164143257687101, 0.01405924187565688, 0.025681211409391835, 0.057614946490502916, 0.03998393709480297, 0.03531444410327822, 0.060827718625660054, 0.07401489987387322, 0.05493375989317428, 0.05899803145439364, 0.0472526947123697, 0.02883904420741601, 0.047338512958958745, 0.05662517753080465, 0.025226354664482642, 0.062021437188377604, 0.038345000430126674, 0.029412781877908856, 0.05296126124449074, 0.01032733280226239, 0.05129264609422535, 0.11322008285787888, 0.030486946016026195, 0.06893505487823859, 0.04015474609332159, 0.01453583983675344, 0.026308084998163395, 0.042870405450230464, 0.03534670526278205, 0.025967223991756327, 0.015546031772828428, 0.08114178854157217, 0.025189200896420516, 0.029658840940101072, 0.07650305386050604, 0.03953437371819746, 0.03382536189747043, 0.008348702158400556, 0.07387722405837849, 0.018799545032379683, 0.03299250893178396, 0.036234172875992954, 0.05419780543888919, 0.11842100924695842, 0.02610456769616576, 0.017571904754731804, 0.017756768174876925, 0.017578810438863002, 0.05820499100082088, 0.06090795221098233, 0.0629536117776297, 0.019978921591246035, 0.031914209175738506, 0.010562142761045834, 0.03670081678137649, 0.032608421533950604, 0.01640436730667716, 0.037596885886159725, 0.054687559822923504, 0.013002180530747864, 0.07503743094275706, 0.03533582537784241, 0.055884276662254706, 0.023141351994127035, 0.055492756655439734, 0.034514612998464145, 0.01733017612423282, 0.08066083973972127, 0.06460922450060025, 0.03863600024487823, 0.021176621776248794, 0.05475864643813111, 0.04400047371746041, 0.013990165552968392, 0.04128498134377878, 0.07829421243513934, 0.0869269781105686, 0.08614860620582476, 0.024576775067544077, 0.008677816822455497, 0.10266654993756674, 0.009359383911942132, 0.02437046729028225, 0.033804782142397016, 0.03835346833511721, 0.01658625842537731, 0.014639639393863035, 0.02895161131164059, 0.01175067649455741, 0.011151210419484414, 0.00970300663539092, 0.04588941766996868, 0.08072929544141516, 0.01677867319813231, 0.053054734744364396, 0.04962086197338067, 0.0389180126512656, 0.060229373193578795, 0.05683748000592459, 0.011276800360064954, 0.012810630360036157, 0.07452402060152963, 0.02888866791181499, 0.019293063960503787, 0.050553021719679236, 0.018442295549903065, 0.0319862271862803, 0.03105112296907464, 0.024987182732729707, 0.016853125453053508, 0.03551867572241463, 0.06022451212629676, 0.02207787849329179, 0.07271214126376435, 0.038022143926355056, 0.058073790423804894, 0.038562568443012424, 0.06411089460016228, 0.001444575609639287, 0.03544388950103894, 0.042864483111770824, 0.12065241724485531, 0.049178430635947734, 0.03778171776502859, 0.0432885574264219, 0.0070981262706482084, 0.08105316126602702, 0.08482557212118991, 0.012325032002991065, 0.011768362801376497, 0.062498667830368504, 0.021711602639697958, 0.07386831086478196, 0.03256427116866689, 0.05440612258098554, 0.021431742461572867, 0.04416523050167598, 0.003421544538468879, 0.023076779580151197, 0.0274220059873187, 0.03655272121250164, 0.0458340386103373, 0.03990234908997081, 0.017471805731474888, 0.05132331534696277, 0.05341101757949218, 0.04838274071516935, 0.04642194944608491, 0.03386572359886486, 0.03486832429189235, 0.03130304685328156, 0.03929873440938536, 0.042662923224270344, 0.020363470976008102, 0.03796285374846775, 0.04400562793307472, 0.07340927768382244, 0.04625934860087, 0.03353239539137576, 0.01695802617177833, 0.03318440976727288, 0.05853819675394334, 0.02326927598915063, 0.019291637181595434, 0.05344970202713739, 0.09206502974848263, 0.028414502339728642, 0.04866008872340899, 0.03483355096250307, 0.033242664649151266, 0.04451984721526969, 0.09498522500507534, 0.0785360783629585, 0.053705683603766374, 0.045206270733615384, 0.015895411706878804, 0.01955136474862229, 0.06488720333436504, 0.02952743070636643, 0.04669151232519653, 0.016415048667113297, 0.0651290469977539, 0.030830332179903053, 0.02978043441544287, 0.0486578511481639, 0.12996188801480457, 0.0310755878672353, 0.012956659975316143, 0.030617404445365537, 0.015104186732060043, 0.06521435687318444, 0.03268047294113785, 0.05899403869989328, 0.030836230398563202, 0.00807197940957849, 0.01721274424198782, 0.032472571401740424, 0.03125344912405126, 0.029753334893030114, 0.10331866025808267, 0.03092532337177545, 0.04747451523144264, 0.023725752471364103, 0.04752290325996, 0.015238567411870463, 0.032912323586060666, 0.0107575530273607, 0.045164339389884844, 0.031801573422853835, 0.05498263031768147, 0.033363330439897254, 0.02063476676994469, 0.019968331143900286, 0.02441204425849719, 0.024879205811885186, 0.029036251398792956, 0.03814786745351739, 0.07142507907701656, 0.033091311051975936, 0.053930802969262004, 0.02792881306959316, 0.00893953520062496, 0.003854066117128241, 0.018028397935268003, 0.06447687730542384, 0.0015433947760357114, 0.026166006391576957, 0.06188049963384401, 0.06476821479736827, 0.14775759482290596, 0.16279767762171105, 0.11115872315713204, 0.10450772184412926, 0.23947131412569433, 0.12175092197139747, 0.06841184818767942, 0.3525050065945834, 0.13727573852520436, 0.16916007996769622, 0.13634551578434184, 0.2681815641699359, 0.09807826645555906, 0.10982800042256713, 0.21030784933827817, 0.0922022528538946, 0.22855334216728806, 0.11071709333918989, 0.09833393633016385, 0.1768273560446687, 0.16555714595597237, 0.10963519045617431, 0.18335358006879687, 0.17544715432450175, 0.12150982787716202, 0.09762512592715211, 0.18728301452938467, 0.17417183291399851, 0.0940604496281594, 0.0905512785539031, 0.1910383114591241, 0.13017004559515044, 0.09019230914418586, 0.11664376594126225, 0.13437349582090974, 0.1801578773302026, 0.12790625769412145, 0.15763791074277833, 0.3430329164257273, 0.15091356297489256, 0.1330010569654405, 0.11930639142519794, 0.21522153489058837, 0.10918487008893862, 0.1822569826617837, 0.18824048893293366, 0.09959762086509727, 0.05242389437626116, 0.17298068589298055, 0.1570321698090993, 0.08967875779489987, 0.13282119005452842, 0.13127743382938206, 0.09149806603090838, 0.11826004483737051, 0.10847945130080916, 0.12519149633590132, 0.1861453615128994, 0.17174224922200665, 0.16085528419353068, 0.19004842004505917, 0.08611528377514333, 0.11552397641935386, 0.12473960261559114, 0.19642673403723165, 0.1837323425570503, 0.14533826761180535, 0.14962666406063363, 0.21428451407700777, 0.13332864094991237, 0.09850862305029295, 0.18261385179357603, 0.15785150084411725, 0.18346699507674202, 0.12465352832805365, 0.11872243994730525, 0.11969693179707974, 0.13393659348366782, 0.09459530803724192, 0.15951744426274672, 0.10602956244838424, 0.16774343879660591, 0.1567651896039024, 0.21764604229247198, 0.10698575293645263, 0.1965547990403138, 0.15160459151957184, 0.14429546106839553, 0.10826390192960389, 0.1540192135144025, 0.11163869974552654, 0.11809883551904932, 0.12107634684070945, 0.20214803953422233, 0.11323085142066702, 0.25450482149608433, 0.1265801436966285, 0.18926751741673797, 0.08767449151491746, 0.2143258962314576, 0.10041869594715536, 0.15282784384908155, 0.10742862956249155, 0.28119346126914024, 0.146964862360619, 0.1376884468481876, 0.11904110331670381, 0.16627067641820759, 0.13758910296019167, 0.11455203755758703, 0.11188082542503253, 0.16396559542044997, 0.151360172603745, 0.14352577971294522, 0.13107836013659835, 0.189358564093709, 0.15053499344503507, 0.13112413580529392, 0.13938916730694473, 0.1316876188502647, 0.09926140570314601, 0.14073361235205084, 0.2274572939495556, 0.10347321993322112, 0.14221444929717109, 0.09908549443935044, 0.3117314726114273, 0.13562085310695693, 0.17156374786281958, 0.12975991994608194, 0.11095773472334258, 0.1522059686249122, 0.20334978442406282, 0.18469507136614993, 0.14100002852501348, 0.11418143869377673, 0.18791922804666683, 0.14007250720169395, 0.18443278153426945, 0.15403524390421808, 0.14611088787205517, 0.14217377960449085, 0.11884470877703279, 0.09826614856137894, 0.23338188853813335, 0.1288667303742841, 0.195471664192155, 0.11409966886276379, 0.13724710646783933, 0.08597656153142452, 0.1660509264911525, 0.12901134527055547, 0.09572277136612684, 0.1477991699357517, 0.13956603594124317, 0.10412835821625777, 0.1178873456956353, 0.1726653176592663, 0.1538851816440001, 0.07461605433491059, 0.09049367305124179, 0.19464538665488362, 0.10263553558615968, 0.13037144963163882, 0.163957045879215, 0.111056173191173, 0.23419811739586294, 0.10507126426091418, 0.077686987206107, 0.07439868670189753, 0.16112725163111463, 0.14610662794439122, 0.07965335200424306, 0.13894095463911071, 0.12790927081368864, 0.16817223688121885], [0.06789209990529343, 0.01028845817927504, 0.043595364986686036, 0.011056341681978665, 0.03926746030629147, 0.06178999101393856, 0.01984183763852343, 0.07264242391102016, 0.02501331560779363, 0.0505741432425566, 0.013828203882439993, 0.04261129201040603, 0.024414587969658896, 0.07380938433925621, 0.010426792650832795, 0.022219274324015714, 0.047918783384375274, 0.040402753293165006, 0.04002375702839345, 0.024897818875615485, 0.047993766274885274, 0.008361596974282293, 0.05249777517747134, 0.03658034765976481, 0.04324824025388807, 0.04569183940475341, 0.05709720200684387, 0.040185552643379197, 0.028173757054901216, 0.024281660043925513, 0.019453501445241272, 0.08951820156653412, 0.0854717378388159, 0.004767615118907997, 0.046609686833107844, 0.05095453103422187, 0.030382696531887632, 0.055643676096224226, 0.036110419750912115, 0.02375602281972533, 0.07437206586473621, 0.03819427394773811, 0.05432005571492482, 0.031160732614807785, 0.017631109585636295, 0.04023682020488195, 0.07108219200745225, 0.019151118940499146, 0.08178217292879708, 0.09126345088589005, 0.014167896006256342, 0.022639700982836075, 0.023655864424654283, 0.08818336733384058, 0.1267861490487121, 0.00939231207667035, 0.059174948328291066, 0.0780700022005476, 0.0182749264058657, 0.03292813133157324, 0.019975498435087502, 0.04363118845503777, 0.08118179030134343, 0.03749489253095817, 0.008033359899854986, 0.03793618096096907, 0.025909386567946058, 0.062216596052167006, 0.03334622764668893, 0.03175967918650713, 0.01630410686630057, 0.09388933263835497, 0.05603036472166423, 0.03356071203597821, 0.004627787075150991, 0.07406453471048735, 0.02408763666608138, 0.008933850349421846, 0.04495243767451029, 0.013685624326171819, 0.04949370239046402, 0.06584951654076576, 0.033737417397787794, 0.039635598950553685, 0.026815105447894894, 0.04309740616008639, 0.02648732108355034, 0.02685631134227151, 0.09653692221036181, 0.046988582907943055, 0.03731786804564763, 0.04290301170840394, 0.014548199378623394, 0.04873869700531941, 0.01810221750929486, 0.00909984095414984, 0.04183808916423004, 0.01600977480848087, 0.052582335483748466, 0.027566450189624447, 0.033373705664416775, 0.03115312931186054, 0.04323478140577208, 0.04059139981109183, 0.016125930196722038, 0.04777411282702815, 0.07484217931050807, 0.033582037649466656, 0.0936525801080279, 0.0802420532272663, 0.07919913536170498, 0.050476246542530134, 0.054771426221122965, 0.02366600772802485, 0.04757284979859833, 0.009101269588427385, 0.05931306201091502, 0.05852735026564915, 0.04545322408375796, 0.028344478851067834, 0.046306326548801735, 0.054274892318062484, 0.049461333619547077, 0.051393322137300856, 0.028743960247084033, 0.039511704817414284, 0.06494313158327714, 0.04993091642973013, 0.0703415583120659, 0.08054136880673468, 0.03258266529883258, 0.01778082674718462, 0.02205366221460281, 0.03575536888092756, 0.06435330971726216, 0.09504247427685186, 0.04302204106352292, 0.02777237390546361, 0.05050512721936684, 0.025720367120811716, 0.022569020693481434, 0.030849943432258442, 0.014525924743793439, 0.035949841258116066, 0.07482929562684149, 0.02560978155088378, 0.010849833524844144, 0.0740897528885398, 0.06050293624866754, 0.03154779231408611, 0.05502088803041261, 0.027263305128144566, 0.026135318585147616, 0.054902652773307636, 0.02049189220997505, 0.04817651271878276, 0.0189343914098572, 0.02901270861912053, 0.05857522992300801, 0.03360691072884947, 0.03868582803988829, 0.016773914176155813, 0.041137004518532194, 0.040837477426975965, 0.050768363289535046, 0.02531741061829962, 0.09244524684618227, 0.07560814250609837, 0.017143618752015755, 0.05685516538505908, 0.08472279951092787, 0.02410094708466204, 0.03659490488644224, 0.008058654148044297, 0.02664128889591666, 0.04518918278336059, 0.041606134618632495, 0.04459664094611071, 0.0566233518475201, 0.05079693226434756, 0.05080130722490139, 0.027875155792571604, 0.07420127541990951, 0.0039529786317871185, 0.014268067388911732, 0.020283628873585258, 0.04418746153532993, 0.12340166620560922, 0.03222459017706569, 0.028598922326636966, 0.024050681422522757, 0.048236916118185036, 0.044361105537973344, 0.020761416126333643, 0.027140045531268697, 0.015344917173933936, 0.039280815253732726, 0.01730181866150815, 0.04360818558780011, 0.04188757186057046, 0.08411451301071793, 0.03523538682202343, 0.024791105461190455, 0.06369987095240504, 0.05823527433676645, 0.06969828697037883, 0.02347291574551491, 0.03320388372230809, 0.01700018943665782, 0.06044733454473317, 0.06962592015042901, 0.07123005008907057, 0.034663016558624804, 0.01572705736180069, 0.024794972050585784, 0.0486944130534539, 0.01617290443391539, 0.04943082021782175, 0.06054820725694299, 0.0270320630443166, 0.03671568199933972, 0.041590137625462376, 0.03192920055880677, 0.030503095149470028, 0.07739983542705886, 0.05875762755749747, 0.013489748362189857, 0.06720784716890194, 0.029574759319075383, 0.041154174105031416, 0.018763079606287647, 0.0277764260317781, 0.09324172715423629, 0.07047944935038686, 0.03770843810343649, 0.03839067961962428, 0.050596604341990314, 0.04504051205003634, 0.04174074907496106, 0.04024119887617417, 0.058588477259036154, 0.0853488827124238, 0.05015998031012714, 0.012103770877729403, 0.006860301800770685, 0.04144250960962381, 0.013559429535234813, 0.0409055917407386, 0.039291372304433025, 0.026416520195198245, 0.042404433188494295, 0.05794383665488567, 0.034909814057755284, 0.03868901556415949, 0.06255280008190311, 0.05617766248178668, 0.02559734130045399, 0.05295313472743146, 0.011045508181268815, 0.027513117602211423, 0.010743360380729428, 0.023047264367050957, 0.04556339590635616, 0.07579629178508185, 0.018766897956083994, 0.03181965585099533, 0.057838778229779564, 0.048666820002836175, 0.03533773640810978, 0.05376256180170458, 0.01861471315351082, 0.036010682524647564, 0.022069401311455294, 0.021673812480003107, 0.03860919758153614, 0.030088878411334008, 0.03359196758538019, 0.0345546815515263, 0.042148592619923875, 0.05770891351858154, 0.019588405339163728, 0.016207746411964763, 0.04797042201971635, 0.01777499903255375, 0.052304564451333135, 0.015212195194180822, 0.014242633060348453, 0.02677774944459088, 0.060832917370134965, 0.03204620756150689, 0.08197038157959469, 0.039604246921953745, 0.031071207340573892, 0.06415327123249881, 0.022871315995871555, 0.03280576602264773, 0.0318691719439812, 0.024608435087429825, 0.03288111627625767, 0.023060457897372544, 0.009859710189630277, 0.002310056866008381, 0.08170167217031121, 0.05980310212180484, 0.01641380000364734, 0.021931326591584366, 0.022239911595534068, 0.016429440765932668, 0.051729377737501636, 0.13115768088027835, 0.05602812714641914, 0.026220240688417107, 0.015742581235826947, 0.013216463612479856, 0.043359284100006334, 0.057351680734427646, 0.04130079651076812, 0.037247174768708646, 0.03384020114026498, 0.008334772974194493, 0.0911821708723437, 0.013480452034855261, 0.03107697568339063, 0.06996410942520015, 0.1359012958710082, 0.08454701441223733, 0.074955156451324, 0.04836455067561474, 0.02487082139850827, 0.07647649981663562, 0.07208022478152998, 0.07469505595508963, 0.03229772140912246, 0.02163448978535598, 0.025702267994347494, 0.03292242792667821, 0.060515534205478616, 0.03871624867315404, 0.04264344555849675, 0.014555541074514622, 0.009864757721516071, 0.05910575790039729, 0.016756469995016232, 0.06770859647076577, 0.03370403930603061, 0.03192574957211036, 0.06548033517901786, 0.06714256785926409, 0.017646646447246894, 0.03326152633235324, 0.03134380189294461, 0.03521882950735744, 0.18860332493204623, 0.07300482946448028, 0.1552320906193927, 0.09459944922127761, 0.1953342481283471, 0.11441769398516044, 0.1782773938612081, 0.1823116492596455, 0.2013887037173845, 0.11794429810834117, 0.16754993121139705, 0.30678909562993795, 0.17074449104256928, 0.2031299751251936, 0.1590210068388842, 0.13686889316886663, 0.1265375889488496, 0.13996638008393347, 0.10471901128767058, 0.08373268545255996, 0.17108055035350844, 0.10456057760166004, 0.1355261550634168, 0.14890755264787003, 0.12623140850337222, 0.10721187049057335, 0.1621831496595405, 0.1726472092559561, 0.07564375817310065, 0.1798591183614917, 0.1404670180636458, 0.1315053176949732, 0.16113835416035727, 0.19158356735715643, 0.12431095296051353, 0.12499594042310491, 0.06945458793779835, 0.15620722813764587, 0.0808095364482142, 0.20291763183195144, 0.11550533366971649, 0.14736130280653015, 0.08294904429931194, 0.09609548535081558, 0.12364163223537616, 0.13579965132521465, 0.24611433735117316, 0.08814749933662824, 0.20525737112620845, 0.1779317608452402, 0.12325481744483113, 0.3168220119550824, 0.12870427424786612, 0.16130545613123104, 0.25560103298630565, 0.15433953929459676, 0.18692669458687305, 0.2222211452317424, 0.09111602324992418, 0.10295941625372507, 0.12179437471786514, 0.14976986887631938, 0.14801344281295314, 0.2437604675651528, 0.15709992789197713, 0.1560458555468358, 0.1329197917948477, 0.14928511285688728, 0.11925451530260034, 0.16428405098849908, 0.1359483925625682, 0.1253158357576467, 0.20939601701684296, 0.09322053141659126, 0.11648871644865721, 0.19526239339029416, 0.1264564722077921, 0.14238073490560055, 0.13049301342107356, 0.11212597164558247, 0.11475672930828296, 0.1437207864364609, 0.07258804675075226, 0.13840666768373922, 0.10680647232220508, 0.21475882065715268, 0.1482489559566602, 0.11985875709797256, 0.23104660212993622, 0.1339819238637574, 0.18705698603298515, 0.15628202178049833, 0.07128807861590758, 0.13985099096316844, 0.07780598316458054, 0.13845541194314137, 0.12984213506570086, 0.06685966116492637, 0.14903343573678285, 0.13163370924303308, 0.11849839298520237, 0.16313357366016135, 0.16991295909974724, 0.12865391210652888, 0.09883628124953248, 0.13660609867656603, 0.10565091870375909, 0.1412643666844815, 0.23581751331221312, 0.1294642037828453, 0.1504870952339843, 0.13382239179918543, 0.21559594839345664, 0.16057754284702241, 0.19094377668807283, 0.0814742261718493, 0.12199338903883472, 0.13254583842353895, 0.15460205177078024, 0.1663742505479604, 0.21137240080861375, 0.1380045127007179, 0.11149293452035636, 0.1387628837255761, 0.10603967049974017, 0.1376327857724391, 0.21346478228224441, 0.1711104589048773, 0.15541134896920994, 0.09927190709277056, 0.1597757264971733, 0.08590112964157015, 0.15298007318051532, 0.2299208234762773, 0.1633147319080308, 0.1291076760389842, 0.17276427563047037, 0.09770278426003642, 0.1396081899292767, 0.0792541285045445, 0.14253864908823743, 0.09905038343276829, 0.0924962101271376, 0.11227880211663432, 0.3415724291699007, 0.10026875243056566, 0.09835262360866182, 0.2640075475210324, 0.2596288168570027, 0.31757074990309775, 0.2006743717356585, 0.21075058495625854, 0.10256793335429393, 0.14306328812381253, 0.2233622269704938, 0.16738674778025597, 0.11894921801285818, 0.07409951213048771, 0.11584786450839601, 0.14259656629292294, 0.13980456220451742, 0.10714257616200484, 0.1635778381023556, 0.13063719787169248, 0.16090304881799966, 0.18794849835103378, 0.17088383669033647, 0.1850298244971782, 0.1304094772785902, 0.08710363894351758, 0.18621313443873078, 0.10780941069242544, 0.07299235396203585, 0.14400922955246642, 0.12638112937565893, 0.11017208977136761], [0.02017129369050963, 0.023803041585779283, 0.013943557751190383, 0.042122877202928066, 0.019919167571060825, 0.06738245967426337, 0.03729728457983583, 0.022110332611191552, 0.04399468125484418, 0.015190484591585118, 0.09114852931816131, 0.05248771165497601, 0.04515898479439784, 0.033089210774051026, 0.03550924673618283, 0.04917857906548306, 0.03912600324838422, 0.024299196993524674, 0.0266391552213463, 0.04736273294838611, 0.05145223381987307, 0.03505689659505151, 0.0564713266066974, 0.03134407648758497, 0.02642336650751531, 0.038575444705202244, 0.0382888012973126, 0.03506676715915091, 0.02333814543817425, 0.022946749741095118, 0.035125697395415045, 0.039167352006188594, 0.09077880618860945, 0.034041790713672526, 0.023389524321828503, 0.0489201150048757, 0.040242423419840634, 0.060032243927707896, 0.06293182232184336, 0.012956749960721936, 0.05070427512691822, 0.033940665671252646, 0.0667061256535817, 0.06627051465329714, 0.03341475756315049, 0.037636935885529965, 0.027168707274540793, 0.017576368773006834, 0.04726045757706743, 0.041809368049143814, 0.029223257770354394, 0.031795239192433655, 0.04178114417300094, 0.06543228853843175, 0.06331108204904012, 0.0354967267048778, 0.03787089794059284, 0.02962016576930182, 0.02380793790507596, 0.01729369214444887, 0.08435362557065673, 0.04506668388785329, 0.05029789732361678, 0.0662472409021575, 0.0718377873999998, 0.046453639151877724, 0.03226974244171288, 0.01566203780384967, 0.06224989250767976, 0.04418181750224903, 0.027941312691837084, 0.014154029904602794, 0.03104334340605419, 0.05738558575103525, 0.037957625318085775, 0.033522936719236895, 0.07742172136204317, 0.0793728869757615, 0.047154649582807906, 0.02464085766405333, 0.00244561292220169, 0.015843312939978205, 0.046093968412606046, 0.0355513265094487, 0.023680572376179043, 0.04779201713972725, 0.026941467222059146, 0.06650136710959487, 0.008265280121122487, 0.04425386890943628, 0.0350907385291066, 0.056474759039701894, 0.02357048218982527, 0.03650972488685511, 0.060399054127628915, 0.06907293107360601, 0.027046414325013757, 0.0408925781812286, 0.023134728326112963, 0.025686822045827284, 0.03360314432939049, 0.03860556105792057, 0.02034139950410463, 0.052796734526054934, 0.09030518238432705, 0.006331782260531327, 0.04558408327284269, 0.03885741258272901, 0.08600112661952153, 0.03726270791958086, 0.0400080977124162, 0.015595153599861078, 0.048947437171591446, 0.05763735192886088, 0.06133197086455766, 0.04600175285304431, 0.011351708108122693, 0.07894077149103396, 0.011199916643818142, 0.07930719206342474, 0.024135850289894734, 0.011110447958344594, 0.006439804174078745, 0.037391103178379126, 0.01874490626505576, 0.0331476883002324, 0.03789825350395404, 0.08850857644574717, 0.045574483592645265, 0.10329407290555537, 0.05136752508406062, 0.038678625496686436, 0.021127471190993674, 0.04565613839076832, 0.05908731553063262, 0.016512386901013087, 0.019236462212575134, 0.025852669787127525, 0.021212359897617716, 0.032477989079779945, 0.031023479823488742, 0.07315555223613046, 0.02926128541730577, 0.1000131641922053, 0.009997760789701715, 0.03685000701807439, 0.028049792417732533, 0.026239252656523604, 0.025076097590499558, 0.03856791561702266, 0.06131474190624431, 0.03230649730539881, 0.04510972103162203, 0.019258084685134236, 0.05055123314377852, 0.03727125746081583, 0.01764753702445887, 0.03492211144475732, 0.09067551407497376, 0.04210139944916591, 0.02796873690385837, 0.029115696452208795, 0.04859127679083031, 0.03263337253883947, 0.04708282453066204, 0.04535748332273215, 0.02279723295941949, 0.00539458750608901, 0.0639493513153866, 0.10326708099455573, 0.01698834661510773, 0.028529409064503852, 0.05106778276967816, 0.007555452511951444, 0.015746982171549462, 0.07263045306899585, 0.01598347123945132, 0.022801542982051615, 0.029243831959320232, 0.051785413597826846, 0.009565161981299752, 0.03991606768977363, 0.07956440560519695, 0.040514491047360934, 0.03760548737773206, 0.04481904034037143, 0.0488505757675739, 0.029478263422788586, 0.10982710984535515, 0.013784388411295367, 0.04321306987549178, 0.006156762501632329, 0.09215361991664395, 0.03474416669632774, 0.015824527326913085, 0.03014056714164326, 0.05829118032124825, 0.03649761674751062, 0.058344399731140584, 0.0175748492256389, 0.025508348517178092, 0.06757230847142637, 0.05522510480659548, 0.049320329271722585, 0.011454094801592873, 0.019058003526879475, 0.033854298235382885, 0.005605913593171863, 0.03852183566777967, 0.03704956681758631, 0.03935231005016249, 0.01863418896391522, 0.06983510189456865, 0.06713991839205846, 0.033522190860821865, 0.046774228394497186, 0.05132208338181954, 0.05906980826694053, 0.038169972322066315, 0.07086367404554039, 0.0332191756751854, 0.04156136456003878, 0.030348915825015865, 0.04490784944209736, 0.01782042960257968, 0.037721499902545474, 0.037898216396570206, 0.02566899565863423, 0.02852487454219954, 0.03393136656086426, 0.041847536704153754, 0.014702282223879592, 0.04789913502463605, 0.07827418186934665, 0.0830444844905287, 0.036556906925397925, 0.04413586371811107, 0.048867107107071206, 0.07743411522824317, 0.044704081665258855, 0.034446172139723785, 0.05637992740957998, 0.053280945066944696, 0.05480956519022584, 0.07750150965875946, 0.036408629530342296, 0.045225551730254665, 0.02795765107293846, 0.041400259142392315, 0.047952833119779825, 0.02285867536556907, 0.0474721329374006, 0.06109895133704413, 0.025601454653951805, 0.05658244095684495, 0.03675573199870996, 0.03921188457752578, 0.0752552438643761, 0.04758001152367797, 0.039857334122643806, 0.06649046496022493, 0.033116087652160786, 0.028330769528110977, 0.09605685656424612, 0.0020008642286484246, 0.0312691529688891, 0.0065811517652036855, 0.03907254635123536, 0.045910483531770296, 0.02290153624926461, 0.03024015593837248, 0.029693892574869096, 0.012942921894136816, 0.045702426141360775, 0.05643596698064357, 0.03546577543602325, 0.0741532955726143, 0.04630552131857257, 0.025578065869922284, 0.03162630040606018, 0.016793226714071352, 0.03178175807988737, 0.023718982229183894, 0.0038117718167995918, 0.01844404701841995, 0.009937626418832224, 0.014505580620607361, 0.03141438755847048, 0.0063156326632451965, 0.08739971133763902, 0.026839536949410103, 0.04079757214640267, 0.008111856859613908, 0.07324432051973417, 0.0796108046779409, 0.057581045184633695, 0.010666237321856897, 0.02013021210586885, 0.025405481283087283, 0.060658520087599754, 0.10394899596576579, 0.020612415137293283, 0.03264690560172312, 0.06009938973875251, 0.02115233499353053, 0.0545917522686068, 0.036225408111931756, 0.02173069995478727, 0.016292299296765123, 0.04706864208856132, 0.01051759441907052, 0.08409387388383038, 0.008930338135542115, 0.04056071200466249, 0.060197768834768794, 0.07227437803521752, 0.04483839926251676, 0.05375720720621757, 0.02397631080384599, 0.047103593533392996, 0.02636316348798573, 0.05634660868963692, 0.05014019836380612, 0.05553041322855279, 0.08437756725470535, 0.009691945851955097, 0.012522429369710153, 0.045071077402099036, 0.02793958719848888, 0.02486733515979722, 0.03395564592210576, 0.04584842885378748, 0.029215765789558645, 0.021845042647328228, 0.058354567154310644, 0.045666632358916104, 0.030429592843574937, 0.011841898503917037, 0.012406533733155811, 0.045108073463779874, 0.031270418330677785, 0.08829217360471375, 0.034921358164865524, 0.03348523561726324, 0.06817637215135619, 0.08879510482074693, 0.039825982094043866, 0.017487351869931445, 0.048243491546600126, 0.016086670584627427, 0.07876960997236893, 0.03936143475584686, 0.12590907892445102, 0.11548683192813769, 0.10159514844417572, 0.10031691039330326, 0.10571118851657957, 0.0711943453643471, 0.14811531000304967, 0.11978875030763447, 0.20564221922541037, 0.2507954486645758, 0.16787482862127945, 0.1254711375804618, 0.16460569779155776, 0.14008206606376916, 0.19381171732675284, 0.09149732388323173, 0.2144616944133304, 0.1908373972401023, 0.1270225824555382, 0.1946117970510386, 0.1712230427074246, 0.12732733797747642, 0.13569266331614926, 0.12020788562949747, 0.2358919952530414, 0.14641653397120535, 0.16789884452009574, 0.10849875456187874, 0.09095107350731269, 0.08807375212199986, 0.11784893213189207, 0.09925860038492829, 0.14982312539359555, 0.09254352204152383, 0.13759895868133754, 0.1113228416943457, 0.1760460971854627, 0.09545361666823737, 0.09913176734698936, 0.10368942239438184, 0.12080771164619364, 0.10385737783508375, 0.14651216712081805, 0.26261887047439814, 0.11394521308830008, 0.08771120556048118, 0.17394158901879564, 0.18272079527378082, 0.12069578835507855, 0.11100997449830174, 0.22565497347386554, 0.12265816782019101, 0.10387847709353082, 0.19894967990694568, 0.1909979831543751, 0.15620513528119773, 0.17165445315185934, 0.10593903527478687, 0.14086031180340797, 0.14187052322085947, 0.16925691539654508, 0.19442744756815955, 0.22006850136676803, 0.1250289659947157, 0.18561903038062155, 0.08528016725904308, 0.1644504553405568, 0.127538746164646, 0.24198902043281123, 0.08972016221377999, 0.18995830847416073, 0.08383488660911098, 0.17882774089230224, 0.15855749108595774, 0.14468036853941157, 0.18854965281207114, 0.18027515150606632, 0.12224960810272023, 0.16813821683172137, 0.08227982005337253, 0.09890638451906852, 0.1799848530208692, 0.13629310531541705, 0.11486699018860236, 0.12226431746967137, 0.0982515059877187, 0.11000788959790953, 0.12579276954056695, 0.08906119444873184, 0.10134370138985105, 0.08856397034833208, 0.14104987116297707, 0.11292595489067025, 0.18453644472174346, 0.11424595359130763, 0.12721191917080432, 0.16571687097894028, 0.12181355923530646, 0.10113172174897045, 0.1913881895598024, 0.12537516304291785, 0.11087954946560785, 0.05009607026295271, 0.15157290181377903, 0.17456969828344882, 0.11325058512738906, 0.12265366298379377, 0.10588096221908927, 0.12213018912007101, 0.19491591432597488, 0.08950324729084969, 0.09652617591200396, 0.0658938821288757, 0.21470403531566262, 0.12015998741844669, 0.1521194787346758, 0.08374452270800248, 0.22475075558759272, 0.20549427950754762, 0.17189130216138437, 0.16496476368047297, 0.14225068094674498, 0.17991277563851327, 0.18578196148155257, 0.16008812614018098, 0.1331676245899871, 0.0996707149897702, 0.16489480884047225, 0.208016037940979, 0.14127705740975216, 0.11782136876718141, 0.12110735377063975, 0.1904002871015109, 0.1352554641198367, 0.16043114679632708, 0.1831643027253449, 0.11001131089869887, 0.08579433459090069, 0.10488825806532986, 0.15436014131410047, 0.1330759099801071, 0.17468594829551876, 0.11850091628730297, 0.16759926918894053, 0.10983130297972821, 0.16331988241290674, 0.10153919050935656, 0.11051615685573779, 0.20273579080821946, 0.10193363457801752, 0.065980661456706, 0.0766622148512397, 0.09585741179762408, 0.13453034131089225, 0.1497861961252056, 0.13086131162708625, 0.10802469289046712, 0.17648633918724954, 0.21236331638647243, 0.2075948246056214, 0.14139494014671072, 0.15815840859431773, 0.09750932862516493, 0.08165761828422546, 0.09432478036615066, 0.12709191389149055, 0.08431646623648703, 0.20469170616706833, 0.2033344071242027, 0.23940291779581457, 0.12138813792262226, 0.09670165673014708, 0.1316449453588575, 0.03564011705748271, 0.11303418228635564, 0.16887019708519801], [0.04968207060301211, 0.06110569374868646, 0.051610500522656366, 0.031284775177482516, 0.14135063393041492, 0.054628310463158414, 0.011426587097957963, 0.045083701334078796, 0.06661131628789008, 0.022845262901682872, 0.03430169825151097, 0.07839853613404557, 0.00696258552125073, 0.04322792396123987, 0.030917207986931317, 0.05602952609478962, 0.03477557809674181, 0.021505491531570442, 0.026233035314362496, 0.02677467324247118, 0.024909958556236234, 0.036932025468559004, 0.012445252505131066, 0.030759978435526136, 0.03398038541490678, 0.06363925233017653, 0.03662447204987984, 0.028633588044613134, 0.04555710620479658, 0.04668528199545108, 0.05734493461204693, 0.023431002955476288, 0.02824954703100957, 0.08885063230991364, 0.03782955289352685, 0.023182125587482005, 0.04308516072342172, 0.022187363829289097, 0.04762361269968096, 0.014549057486874517, 0.042626628492143936, 0.019434190762694925, 0.04523802352196071, 0.007195466359917191, 0.029649491734744515, 0.013153385698387865, 0.04846947922487743, 0.024253888877865393, 0.026717848850239534, 0.04833881299418863, 0.03218184989236761, 0.037533970316872, 0.026706583048508037, 0.03862413330352865, 0.030092570596025325, 0.0058590893877408234, 0.0763262074906379, 0.04801617542398162, 0.04978398232196923, 0.01562854838994099, 0.019596025340433698, 0.055508813020423986, 0.01910999653773615, 0.07656110465177335, 0.05081899631477427, 0.05451760800497141, 0.08945499284891412, 0.027037039144488517, 0.042594137266860344, 0.02625147953949636, 0.0784085105988197, 0.0035847428125634906, 0.07075890505802818, 0.028363717174215708, 0.009049532618519152, 0.018387762538623065, 0.02468895254423842, 0.014242696142900968, 0.036292895310907625, 0.019578312130761333, 0.06219101051101461, 0.070500133006135, 0.025973315168812405, 0.02428321855404647, 0.03775448465603404, 0.028693184358417057, 0.019673518545459956, 0.05884004676772747, 0.020432744895515498, 0.04316250364354346, 0.02743342764006229, 0.08618353167548776, 0.05810505710542202, 0.06772677908884361, 0.015534286358160898, 0.044313459657132626, 0.039694892839179374, 0.011510692838783143, 0.05487122652994003, 0.05055558212916367, 0.09156028769211844, 0.0356230996112572, 0.010597739874356193, 0.038530129168066196, 0.011089463732787408, 0.026911662571365014, 0.07020237593678758, 0.07136928441468626, 0.0324666453525424, 0.032010168870328926, 0.06666224988293834, 0.05895438946026843, 0.04949893453158438, 0.028588458044396248, 0.014109262629062869, 0.01922018691402627, 0.020943689451087266, 0.017516199150122702, 0.005819885900564259, 0.01880750456621172, 0.035720543601200916, 0.01834349528508028, 0.14052541024284437, 0.04691355919931084, 0.062355923146242276, 0.01949630481249187, 0.07103230484062806, 0.04665658685553353, 0.0372723484179005, 0.013902272075938527, 0.019988213280157652, 0.03294426933280192, 0.012313986062508775, 0.01945146610523807, 0.02503944848285755, 0.016492139257024974, 0.007786305432091467, 0.044058479979867116, 0.009343709753011353, 0.06503680546302348, 0.02578182622528402, 0.028040433935530018, 0.05369485937990248, 0.06459745403844863, 0.023178036353783682, 0.03793258154473733, 0.04906808440864552, 0.017125107733590994, 0.052164799490128644, 0.06330544914817438, 0.006942848567632609, 0.0253072561827139, 0.03297027789813001, 0.037278159434208646, 0.06376100165653042, 0.060675081113004126, 0.0016439568298665108, 0.07237009282107465, 0.03754830118850805, 0.02253691909572808, 0.056637474917806685, 0.026814912489498965, 0.04461456752324011, 0.0038629171558568487, 0.04019867010356393, 0.06497562280856073, 0.08164908358594403, 0.009147664950432954, 0.01037079111483763, 0.03768881571886595, 0.05341204916476272, 0.025246793411497492, 0.0902239691640716, 0.030608919842052273, 0.03134640683128964, 0.04532417202426586, 0.06504975593998097, 0.017242276153410785, 0.038569834068766795, 0.06905817717779428, 0.0672909602872096, 0.08726592437596992, 0.012898333661723882, 0.018827492458513007, 0.06786863319575787, 0.03470590527285822, 0.020348394245957024, 0.06991970672970638, 0.022632118088949937, 0.04571958088490646, 0.0819015473825857, 0.07869552136980928, 0.05239302474365104, 0.015961303288349882, 0.04586231072607916, 0.05076744673715439, 0.013759160028712358, 0.018299951625522226, 0.03670836813398637, 0.04967418157320935, 0.10209528176346794, 0.07706834774580784, 0.050378427768009715, 0.006070928948247456, 0.06101907398260664, 0.08902567526092753, 0.04801379684067797, 0.016081983922049403, 0.005247768431217992, 0.027390165996621363, 0.05323936995409895, 0.03345042518049013, 0.04494625187362544, 0.020880436204606667, 0.03605275116569828, 0.01776184817572357, 0.06620323154493235, 0.037961870402796194, 0.013415450102911564, 0.03358641261002049, 0.022053562024666462, 0.016159564329427667, 0.08381743871723302, 0.021203326105023734, 0.05885650389245711, 0.031002966861706227, 0.03747762646526098, 0.05368298130633775, 0.039589166481164284, 0.034492689956096, 0.009121976436290424, 0.02158805731596658, 0.08683489242685027, 0.01293951265324722, 0.020291462242312264, 0.06837708599050529, 0.03326291414850857, 0.03262098238337785, 0.01727554848912405, 0.058046995181939565, 0.06695656338706613, 0.017831533987191506, 0.049613729934208095, 0.038877521074027754, 0.0810564192943275, 0.013108015427860664, 0.045049662730889395, 0.03886015481839422, 0.0838824656966608, 0.031071806624822784, 0.009607615611457732, 0.023998005635803565, 0.02146492202882655, 0.012756218875438208, 0.1402702004997991, 0.020719085878226906, 0.007441237839884707, 0.00947357168115559, 0.02271350756927859, 0.03614442495745607, 0.029549181199399754, 0.05121664275065996, 0.01125375945775886, 0.01974093152966816, 0.02123489150108071, 0.02491049475793261, 0.031806816696189344, 0.01777843888703501, 0.09102173338760622, 0.031788982887519524, 0.024592048466729466, 0.046943541965447366, 0.15035880758659914, 0.0722964272426907, 0.037224049447104335, 0.031531791610177606, 0.055214377061929554, 0.02278704512718832, 0.014426982543227496, 0.10697551871999167, 0.017712491644488182, 0.03232147755625192, 0.056319609357160516, 0.027245263518125284, 0.023102105369616766, 0.017167245023301803, 0.017404366772098, 0.03323778131743893, 0.05259714132989757, 0.06696322045172565, 0.03407047101063654, 0.04247765347827226, 0.003927445504814386, 0.01249705348527641, 0.026877547898038756, 0.008508481914759614, 0.029470760309777688, 0.027005412521248218, 0.040628607384860516, 0.01798978955775965, 0.07402248462312855, 0.015027028421172872, 0.029174123883422, 0.03508686080749612, 0.028445067691791337, 0.0708223512629047, 0.029518114897655323, 0.0116396873818303, 0.026375564775662497, 0.02925365242845146, 0.014746908491360955, 0.026020602963399142, 0.019444289537204895, 0.04574521095491946, 0.02693741138500627, 0.04776788620802108, 0.011840005099656992, 0.03922505769878626, 0.09210785909090191, 0.07387213292531669, 0.05526897686650045, 0.056424942376906984, 0.08770174317760393, 0.0161716854563565, 0.04490927065489814, 0.030778812288190238, 0.03776780991756823, 0.019376527743588667, 0.046450162190012634, 0.04738848547276575, 0.06017326311848592, 0.030960673720983323, 0.04914989505778067, 0.01962071102752816, 0.02372675993683515, 0.01571861172124045, 0.09680939430836588, 0.032697876304155216, 0.028299998230068013, 0.023974869181984104, 0.020764421824424062, 0.031137106343521737, 0.08659039187477902, 0.0029845603330613812, 0.033606101787881926, 0.006099983565945877, 0.029274599546624813, 0.03590488566260319, 0.08711939473869279, 0.003289562619102071, 0.0220750212247367, 0.06642225416726433, 0.1598888891749084, 0.15376528026536107, 0.11831851865281351, 0.07950123399496078, 0.2281675292761065, 0.16542480618227273, 0.11703497424605303, 0.120876152504934, 0.17853300436399877, 0.10287969475029968, 0.13380664342548698, 0.21271322417305782, 0.09589215173036791, 0.11037723423214629, 0.17694550595479086, 0.15603000327246264, 0.0913075715652667, 0.1288147206651047, 0.13266888650832698, 0.12767022504704073, 0.10938776584225707, 0.11022766178939492, 0.07736226049019024, 0.10220940923318267, 0.18704166810493916, 0.12633948004804552, 0.11714798849425279, 0.14816522685578093, 0.206216448568739, 0.2145138822379522, 0.10531458479817957, 0.06093883668654598, 0.08623337431345135, 0.17375195544445887, 0.11725707678124309, 0.08963288564700633, 0.13200533227063715, 0.06301719156908803, 0.09445536124985665, 0.18765279703075066, 0.22975838219281286, 0.07551998278358951, 0.07251018061651848, 0.12830113962991163, 0.1376150336000137, 0.1939926974591799, 0.16742473089834675, 0.09259108628612012, 0.30165895528625697, 0.11992250758339651, 0.1186387924826704, 0.15075903298566118, 0.12242143755429424, 0.09825789587921463, 0.09305013431003317, 0.08765052014496177, 0.14714392775204033, 0.1347692238050513, 0.09985746160964482, 0.1268182840431109, 0.15933667193166912, 0.07062577860779129, 0.1243878691457212, 0.15498891851166263, 0.18084672396071255, 0.07615912036271766, 0.12460534810088575, 0.09874262963421643, 0.24328451341716573, 0.08968040536274202, 0.24584594706539065, 0.12290962971746922, 0.22334962530294433, 0.09942144984961487, 0.27126441593281925, 0.14169930975185707, 0.10519723640754819, 0.1285670808283612, 0.2890117495553568, 0.12475051218643785, 0.10571773425908759, 0.11773815916967578, 0.10371787633630447, 0.1322611208888702, 0.10766252482426353, 0.18811285437550396, 0.12550950661534443, 0.09673387336079031, 0.14094629703322425, 0.20847475941991434, 0.08142223130562343, 0.18318716087378561, 0.13625063962535933, 0.09113298132433556, 0.08140168123645708, 0.1063845019962173, 0.22918249043868855, 0.3175038378685713, 0.1313496002694592, 0.14116423611994833, 0.1709045426105149, 0.11280340404482558, 0.09858207340585068, 0.19304402492707595, 0.10815284695127048, 0.1041753584286198, 0.11439861336839385, 0.09489440097240731, 0.17369763023452833, 0.23327776521909982, 0.13142841635271907, 0.2049908065237105, 0.13072750240098685, 0.22275599621934816, 0.08918792358599603, 0.18970317294588313, 0.1052032552252058, 0.14756471064174548, 0.11164095587446354, 0.12574412918183953, 0.12876277032773942, 0.08221724216127768, 0.1834931632038206, 0.10620180008118041, 0.18469152390025556, 0.18142200715374202, 0.16027961508370936, 0.13772591046290472, 0.1858257778803818, 0.1232681909459643, 0.08869933066307567, 0.15191571466857567, 0.0625382836733479, 0.07890400549513288, 0.09659008224844001, 0.165020884887781, 0.06605149203096516, 0.19251289952080697, 0.1877520518610254, 0.1260560390073806, 0.1494322213693522, 0.1495473730028607, 0.23470613232348114, 0.13104806566843763, 0.24480575288180262, 0.10162831502384506, 0.21124056569533423, 0.11985496472334489, 0.3668249538168311, 0.1896496640983969, 0.09972178217140026, 0.10823919583344832, 0.12440159887773916, 0.17047169239958748, 0.15615863230777904, 0.18173421383835375, 0.1262847986072302, 0.16213829425396398, 0.14818654133705422, 0.10236281115794554, 0.2215165799134411, 0.12932767829624936, 0.11368592895451002, 0.05135670457093511, 0.19201105926185846, 0.13251794851385057, 0.12187041516881436, 0.07306391926249489, 0.0930240997695364, 0.1768085203366354, 0.08372985786991194, 0.09520147941657342, 0.16799314180389047, 0.06104794723796658, 0.09671547551988624, 0.17736823327140883], [0.04564545888570137, 0.0179377464519348, 0.017677219220786355, 0.03889559979143087, 0.02408805969025707, 0.025884632232191507, 0.015168809241004055, 0.041667688346933573, 0.0028322918069534353, 0.07159275250160135, 0.04030799216707237, 0.033763696847017854, 0.015895433971309103, 0.031786426188773476, 0.030356717652466614, 0.007361445832430036, 0.005584943282883614, 0.04189586536085699, 0.04633231284969952, 0.06265041476581246, 0.035518111690180376, 0.06266554715693928, 0.05048939368862193, 0.06819825066486374, 0.017211347148986533, 0.048580979491816834, 0.032620195706840605, 0.012114532946725376, 0.04476997324672993, 0.03430218806897756, 0.013937153016740922, 0.04336950718425214, 0.0366203419980593, 0.07603535239468329, 0.027131779861520045, 0.01865941085270606, 0.03199554113962222, 0.03680839108710643, 0.024100416449073236, 0.016699871957825962, 0.027091533193015493, 0.05506465247890446, 0.030983607939560898, 0.028653648296312895, 0.07402983930660412, 0.0594916709815152, 0.02212587874964811, 0.068499763001455, 0.03814636460447218, 0.019409245323913638, 0.07121839837054722, 0.02498010449926369, 0.025262378512707073, 0.020127442039665766, 0.03726785471371841, 0.013684969380847178, 0.048298826077370904, 0.02067731966235442, 0.042065164088853635, 0.015198755827441346, 0.04224433709168807, 0.014687824259453919, 0.020084762982151005, 0.042762775483424775, 0.03942556002584752, 0.030859841826895718, 0.04540756344795227, 0.02591124750324525, 0.014484185430774232, 0.06557265834999271, 0.04046002111863345, 0.013889380970795173, 0.06756338043487631, 0.061296421990846284, 0.053583032567985356, 0.054283501231111586, 0.007240065724545275, 0.0754657392099034, 0.014389733223652001, 0.03351423503772821, 0.05665946475346573, 0.010653506706148619, 0.036973099631723017, 0.01689965069090249, 0.010675219164113514, 0.03357501693244558, 0.026969583486788906, 0.015471592505491572, 0.04285859045921825, 0.02885578891437035, 0.038461421136162244, 0.017003319444484077, 0.036968186614103615, 0.02576638955360977, 0.03615241788793355, 0.005584692344200448, 0.028936432536283974, 0.04204437653243076, 0.010502824752620654, 0.046237562855822034, 0.0165062975793262, 0.011478779561002739, 0.03453212026215624, 0.06941174375242554, 0.066904004488606, 0.03544891755154822, 0.03533165821863804, 0.06640162246185355, 0.04382153449114412, 0.06802151561714709, 0.017092312227759976, 0.03323841585370246, 0.03985144147009123, 0.10367898779804818, 0.015516150124312844, 0.01265889084606897, 0.038000911081326194, 0.021837571075593587, 0.0289518525096355, 0.053617653757100925, 0.034959114927914925, 0.09037072886712849, 0.03206991917977575, 0.12027818185742944, 0.027344894988345914, 0.035291901367600076, 0.04096323064004537, 0.036319586652098224, 0.03611472049669828, 0.08781010415987112, 0.015562591870548204, 0.055483383330283687, 0.050426856614649296, 0.07133228093152866, 0.012010585887765046, 0.005931515579504776, 0.032800084882183, 0.023687266548222397, 0.03268244334321935, 0.05436633975477889, 0.034211746242363006, 0.03417939973587636, 0.008979475733212894, 0.01856964809121564, 0.05187202223169152, 0.06684220585157163, 0.01580419804668054, 0.046026032214285806, 0.04391936810861807, 0.03266319203248713, 0.05795394841697998, 0.05113365579745732, 0.06246659220778383, 0.03234681447793264, 0.061036636907374486, 0.07751418554107659, 0.08727912718313746, 0.028947748432983644, 0.08171103065251373, 0.021354208438424394, 0.021422454483399633, 0.021555792445724364, 0.04426103063451592, 0.052359453693497926, 0.04661118226067629, 0.05156104751222301, 0.026154195111303125, 0.0051682394223462325, 0.04055790668644477, 0.05370376144128386, 0.04200902803859208, 0.014543114739353769, 0.04689022978709545, 0.04009209769719746, 0.004800716760655632, 0.03097283381066518, 0.019973092021245975, 0.03428715957852546, 0.06649882896454073, 0.011810047381004551, 0.019631436916824896, 0.061043624227750115, 0.0035788035438599763, 0.06394234544131905, 0.013319099853106309, 0.042121177684748545, 0.0366842149378499, 0.04430814959050622, 0.033674130754661746, 0.03755414560146164, 0.06235544817172922, 0.02738022307312349, 0.054344769232557155, 0.02450516894896282, 0.038051863230066374, 0.042308644187869504, 0.06145695595478173, 0.00630264925348456, 0.0475304286374012, 0.05523158746655099, 0.02960311121569248, 0.035622231298475526, 0.08500338328303769, 0.04352579235273879, 0.05979936911899131, 0.04218146605126094, 0.017812475634855218, 0.017326096167380456, 0.06540203117765486, 0.04887702591076959, 0.07715253697824664, 0.017486503966210876, 0.06303971575107425, 0.018000285381276626, 0.016831601315061562, 0.05067292680905666, 0.03215394513972569, 0.00989259104244411, 0.022133335478429217, 0.023991281777853146, 0.028165320691186935, 0.09176252293400466, 0.04012614743260201, 0.05396339067374356, 0.01156619806351955, 0.028767042895196937, 0.0673010312311817, 0.06067020520276856, 0.035844103767885827, 0.05589786909695249, 0.01825110346544534, 0.026655896217562258, 0.07950843282742426, 0.024826988301356323, 0.056250801135320216, 0.06520826384075917, 0.04128605003643315, 0.03250052439398132, 0.07563798426417634, 0.0038820942518213997, 0.0711870648956392, 0.07808799186022952, 0.08104464141069911, 0.04373478484922089, 0.05099052890727762, 0.018562367622507736, 0.07695773805608042, 0.015099288557394175, 0.009474644084548345, 0.03127819232759066, 0.02121097579220077, 0.08765750375459902, 0.047505325492238626, 0.009071490912901936, 0.017259612723137252, 0.029497032337530982, 0.01005952324703685, 0.026563239080132917, 0.04991229965526145, 0.058941913957824, 0.03069493661314482, 0.025153312490147073, 0.041763054323382676, 0.031006822318886407, 0.03001147797476733, 0.052939471788704395, 0.04018305531644728, 0.062194951315177605, 0.04672897593991365, 0.03387723059859127, 0.09567905144649558, 0.030553203105228022, 0.03878811825416051, 0.0378600180556532, 0.032275178673444316, 0.026773233475978486, 0.03392670587345492, 0.07477787221432664, 0.021978707154630683, 0.0749688119685743, 0.020730468568217475, 0.06653630000073463, 0.03313238892587833, 0.030189838325895835, 0.008897963798517594, 0.050602137052919716, 0.048547367623541504, 0.006942032205188298, 0.0012522046699814382, 0.0451294027880067, 0.005401298376455088, 0.029286856115504634, 0.08573641738621518, 0.06343295011902228, 0.07524836415541358, 0.051152639935025945, 0.030830016767140478, 0.042022004490718246, 0.036809084995184094, 0.04642576408514287, 0.02395706691459054, 0.030063927406445146, 0.02640336377226049, 0.031548924089292996, 0.005637367667077342, 0.06632790493313223, 0.020017446477140766, 0.14005217235535383, 0.08168944899807684, 0.09585069536115043, 0.02756802725343732, 0.015320509792218218, 0.03639561226009391, 0.030783005422563292, 0.024799263519525994, 0.037176618789089844, 0.029499169722839724, 0.03442240114964079, 0.006601725954169524, 0.019790768601524178, 0.032483232353115454, 0.035883281743736006, 0.06452315763453953, 0.03482517582597211, 0.04133616355829872, 0.028256565892661456, 0.07999811670742929, 0.05745279835537076, 0.0560073321685195, 0.048560622381046414, 0.051084944934700616, 0.04206845551379956, 0.04715146205853671, 0.022449353091360535, 0.04130823283048812, 0.050983348628506064, 0.08430791669525206, 0.032065974664874375, 0.02541423491493333, 0.031326684256782755, 0.03783187952649314, 0.02912422743975185, 0.053087600754224695, 0.024484507557644974, 0.026827213587239385, 0.013038820361543912, 0.040875839040381834, 0.020807128712476697, 0.04474353052501101, 0.052902071256539784, 0.02611066258396022, 0.054976233004708774, 0.14129556657280773, 0.10618446351145394, 0.12062900248565711, 0.09031601031892933, 0.10169490793487057, 0.16460550483316183, 0.07950568688102067, 0.09278103898395784, 0.07896912153228186, 0.18536876334110275, 0.10834575339686126, 0.20622051553800702, 0.13757304288446903, 0.21638127422193065, 0.14533371082507074, 0.1283870654879138, 0.0780638275318779, 0.1043611996283289, 0.12482382153393701, 0.17094228824134916, 0.14896146225510165, 0.16547217004699633, 0.16043717303546146, 0.1451852812897414, 0.16652947815600783, 0.11758518769056536, 0.18498008575988933, 0.09309601387940347, 0.08275529180536978, 0.12727899447781965, 0.1297564318520017, 0.13494779937900603, 0.1573924082913436, 0.1559410642948933, 0.16652520338539034, 0.14309024292742833, 0.13063897902611643, 0.05764305162301753, 0.08480505915940739, 0.14022904098965228, 0.14679348561912775, 0.1055674790404737, 0.07847430199035443, 0.15393107605632395, 0.1490500450017862, 0.23794836772140115, 0.0740492538898252, 0.14295563218183815, 0.15774464642163366, 0.13454776693833992, 0.20130682998569682, 0.09751259407494217, 0.11976411842624657, 0.08568605524487793, 0.08572992359404452, 0.170174477098044, 0.17622017534449697, 0.1293093472486362, 0.14782605052459985, 0.11992444458883256, 0.12254277127794921, 0.12046342191752046, 0.12896329862996936, 0.08671084244269878, 0.19042614352656528, 0.13993730273796245, 0.14717279729666188, 0.0820354456664063, 0.13709894410567358, 0.09201005887007341, 0.1819939209963195, 0.08260564514785074, 0.14572117128409445, 0.13727852900046855, 0.1609858131268993, 0.1851786399492994, 0.1394809561315924, 0.1678098164848052, 0.15483835159102455, 0.14386228431249037, 0.0921663774352055, 0.07443076974595897, 0.14339591871248558, 0.14229397784220055, 0.11414649095968343, 0.11525573456310667, 0.08275290208985098, 0.047003340514493175, 0.1526271374314092, 0.13236683240393177, 0.08505100689944811, 0.14074389851884916, 0.19293380115414038, 0.14427894086111337, 0.20580265671014786, 0.06798946968046948, 0.1385636764462106, 0.16741107538109645, 0.11714110878529027, 0.13636044779559597, 0.1408568979240954, 0.17154768778709695, 0.09944224482751451, 0.1415137728326954, 0.12773364898748696, 0.1397169442498125, 0.154725203756243, 0.13529461983125657, 0.1269377104472369, 0.19457690126728266, 0.17501869762782007, 0.09320723955170251, 0.1453192241024226, 0.159834400692489, 0.10880545451072976, 0.10967105103190988, 0.16681376524502411, 0.07883747937739827, 0.20855241775279865, 0.18382427981123328, 0.18649932142579928, 0.18807684537023306, 0.11075602640630677, 0.2640824153786525, 0.1467940941802226, 0.11438651636126451, 0.10965347697492689, 0.09351340515422635, 0.1184079993981868, 0.17292489123065025, 0.09241406180080958, 0.1642188013647683, 0.21999491000315174, 0.15818594227312133, 0.0756888288015034, 0.17700425436487421, 0.08621205241070129, 0.11771871490054764, 0.1676134145236574, 0.16664013237459585, 0.15636211435776204, 0.09924649595632218, 0.08289172081276774, 0.09380269431858324, 0.11134239728562534, 0.10219828443950973, 0.16216774267377332, 0.12082484041457064, 0.15532577934209257, 0.1316635584225878, 0.15467101213289425, 0.1238706441654358, 0.16877095709787682, 0.1084107877977658, 0.20306425052694976, 0.12782573467120528, 0.1917373700416647, 0.09015400690259412, 0.09278567740693688, 0.0952023922582157, 0.17135361616965383, 0.11555212608072907, 0.1190578832756728, 0.12252304499270394, 0.10735865245806053, 0.08623528163298033, 0.21470237290486693, 0.11307284075883217, 0.10091836171341129, 0.15250978904077783, 0.10313514198060147, 0.1937897497555241, 0.19963255967013538, 0.11011019465513527, 0.12957852421095595, 0.1196388661628589], [0.036707180697703734, 0.0638091670407448, 0.10785508246044628, 0.02122168312780559, 0.032555265206610784, 0.056703136433498, 0.0767180985712912, 0.014092124583839905, 0.01267229403310921, 0.03672443192044739, 0.04726665451016743, 0.013545432630053256, 0.036629214373533614, 0.019298182924103457, 0.05023391677241307, 0.020104745308344718, 0.03518593010085169, 0.01994618545722915, 0.05171787073777523, 0.08834050968289375, 0.07659762573894113, 0.05425575604022015, 0.05762076863902621, 0.02157339062250685, 0.02177583552111173, 0.06671425959211774, 0.02325404897419503, 0.04381819111586083, 0.0072658335557207465, 0.02281001830851892, 0.016888332938833628, 0.03645167780632619, 0.02288413845235482, 0.05083303032733966, 0.04872724566666875, 0.036225979565642774, 0.10879170993575826, 0.007505693829443771, 0.02361699444008991, 0.04972530441591516, 0.03737474253284745, 0.03720554770552553, 0.011082397559221135, 0.0497853181877872, 0.05485461726493668, 0.017087640408135485, 0.025251305669371504, 0.019049671063839924, 0.013811194785375847, 0.011709270220308099, 0.06362058731610887, 0.06562946233316325, 0.011109708593721734, 0.020758009668497834, 0.0208423621734255, 0.04931480769300833, 0.027314383441989776, 0.04768081373185851, 0.05512394636753015, 0.020058483532920945, 0.03746760376088787, 0.016452562376798596, 0.07517190068028867, 0.02565879298344953, 0.03875568640069105, 0.038132115369080566, 0.027024847513530403, 0.02317433860298479, 0.00927589600905776, 0.0372563922428526, 0.016055752712418325, 0.01896000663691666, 0.005228617310422123, 0.04413414193550125, 0.022207720940059517, 0.087235763494391, 0.014313472911453573, 0.02326896614249563, 0.05336580223229248, 0.052502235485007986, 0.009244560678780545, 0.06125844629423227, 0.014817847604717826, 0.010764641465357272, 0.0219601126445923, 0.01832260753872106, 0.011003410781995626, 0.013102546727168374, 0.052378983309608884, 0.02589449166407576, 0.08311445417348295, 0.08853521212586202, 0.031026294418552425, 0.0257005183811998, 0.013355500341276638, 0.024025958628044464, 0.02284995513036847, 0.04488936625421047, 0.021526562959479634, 0.024335449052159674, 0.02686346007976681, 0.050098352367058396, 0.08076851052464917, 0.013512124114640756, 0.034831573138944805, 0.02251644695206778, 0.015133427350519923, 0.029258520917210262, 0.01632702067581704, 0.001925570911680552, 0.048796977862366475, 0.02992833331518341, 0.013801545937894844, 0.03042037908016937, 0.01841194727603579, 0.02769130911474349, 0.028990677965339273, 0.028903577658638824, 0.05763696230133064, 0.028003786683257204, 0.03823449835181236, 0.06573378603206947, 0.03443158151640091, 0.02601878841232974, 0.0499320741801057, 0.019498579495120794, 0.06357298596412875, 0.02526233027310809, 0.0012895263489554054, 0.017314858196186833, 0.05159815489605535, 0.0736002397025004, 0.010384680408606073, 0.09304243823862635, 0.044705354448524304, 0.04536327578534838, 0.027325088922225405, 0.006150055805846932, 0.0607969232078176, 0.045097379115759395, 0.053046816028654575, 0.10908656520769, 0.03022542059625266, 0.030106350423011463, 0.023428667045664042, 0.06676977223833092, 0.10027425174484961, 0.030906363354006317, 0.03935796150472015, 0.024065910292847548, 0.041169184041791596, 0.06952907730010338, 0.013659216856467538, 0.019805823067144956, 0.031641440218663774, 0.020533730785246007, 0.04454455331142526, 0.014112239568930818, 0.074680235265987, 0.04638733196770772, 0.10172401496674865, 0.008566308206354734, 0.05831727794429753, 0.056523302919231355, 0.05353787659259979, 0.045919044205220416, 0.0363348192331614, 0.05190639480133541, 0.07041526099783368, 0.045583916289615445, 0.07835923941456713, 0.052045707052457146, 0.02802425697154831, 0.04966078951838426, 0.006331621307253954, 0.028686959594779182, 0.08562722519855015, 0.00969235032243887, 0.025226555044355337, 0.03434238278714474, 0.011334723130858038, 0.03741582411748823, 0.06478621930000372, 0.024509525355824735, 0.08836670749587938, 0.04100536978512537, 0.02512672133889282, 0.049966231526923366, 0.033527675332152285, 0.024095963563013356, 0.06181739481689874, 0.05305011858581565, 0.02043547970970394, 0.00473727380267519, 0.08421145976171829, 0.04740913202113006, 0.10907478732406162, 0.012303494877414778, 0.02058877216768451, 0.014967752158554504, 0.022072831889090594, 0.0430710896034725, 0.02877663886465598, 0.03844183956971392, 0.06306365001364611, 0.018616162196849473, 0.04638583654013928, 0.07033501999103464, 0.035415917955106124, 0.006465200467573595, 0.0482214312069118, 0.0801180477719754, 0.07064315228490159, 0.018581129115773365, 0.023520277754869312, 0.04081707578734495, 0.09867538363323547, 0.036968153217458166, 0.01222770582899102, 0.03631012797995936, 0.04550847697828431, 0.07312513160286471, 0.029676852864213288, 0.006329940342766349, 0.08223159529734403, 0.019961110047006514, 0.03567423358617816, 0.10381416257587261, 0.07166571303969249, 0.028592634480446577, 0.030875159754941706, 0.07881190496846102, 0.06088157257181592, 0.04150570719502866, 0.042705281302914955, 0.0466323817090597, 0.038523449838976376, 0.01212112971188617, 0.051206334319431335, 0.06513984524644911, 0.018739195438683964, 0.017289335737586953, 0.026221559855912346, 0.0344721732835751, 0.016656246662023477, 0.01069886584446067, 0.07865898543968797, 0.01654484287428204, 0.020924096752423793, 0.03730297314177733, 0.027409816211729776, 0.029379685802268796, 0.006188077886690735, 0.039797049466869794, 0.010939867170236539, 0.045302004073164426, 0.039375201595248654, 0.020227901004545856, 0.015419909341289895, 0.05083311196358409, 0.008785527497821022, 0.06326380724203773, 0.058727277428261004, 0.025990607209678274, 0.007687143834118615, 0.037301807969924994, 0.03479050639725756, 0.07651239007827826, 0.017045590320776682, 0.021032348267908674, 0.022994275022938382, 0.012009475449303864, 0.020520394391496666, 0.026687955141824204, 0.025357596059620846, 0.01869130093837157, 0.023610754833498504, 0.07223781241918914, 0.028683271120826248, 0.03617885689891409, 0.05229202586633619, 0.04853024998737965, 0.016637537119095214, 0.05206120309594553, 0.07341958611505106, 0.03873593785101548, 0.019375952579139266, 0.04392755770822987, 0.011203654285054654, 0.03971432597609237, 0.07729776043561287, 0.040670824455446564, 0.027733778515539598, 0.010866124594031135, 0.04280740082322154, 0.029747126827714965, 0.03964412993809674, 0.027727750421036035, 0.027124848202220164, 0.04128338572627399, 0.03555982781108469, 0.06113865994848311, 0.0753742695087567, 0.056794439151417464, 0.034811446093954146, 0.041583595593692735, 0.028353685192996636, 0.0037886156496824697, 0.04494007349421736, 0.056959025241667405, 0.008385006167372921, 0.09067026709089987, 0.029825378878740594, 0.015180521259026136, 0.013055598465143703, 0.02182037365855649, 0.020630651561077684, 0.04831919803109486, 0.0032323683126378455, 0.04140707205806393, 0.08493163986713625, 0.08799840186838992, 0.05641169133014046, 0.034053553754347377, 0.016770656147855334, 0.02678024862689199, 0.07694526255363598, 0.06102034305513371, 0.0425119703868404, 0.0476320806046715, 0.047766706193215214, 0.004754720766868559, 0.0386465869814856, 0.024779179148026742, 0.036466591263888404, 0.0942553450295236, 0.07224736385978758, 0.053856417507631704, 0.0429557598545216, 0.011863470881507965, 0.017093531205318868, 0.026001255173468962, 0.024525822918803897, 0.03181108404533006, 0.04940919032378588, 0.06850487639894709, 0.020120658809901215, 0.10459807090228423, 0.02544452938309405, 0.02246288986498257, 0.04943199652188923, 0.04470122068596538, 0.2554599952418357, 0.17377128096995875, 0.20566803112160414, 0.13933436712250113, 0.09385635901708156, 0.15919570840196684, 0.1111565412429627, 0.163404056802392, 0.11166771771968342, 0.10793082605232485, 0.15181307564489543, 0.09963076518033631, 0.14053116930881515, 0.07651323612662964, 0.16745710338000208, 0.13777846936136484, 0.20750077965203673, 0.14707205817103386, 0.1392192451748997, 0.15679625590564683, 0.22136310377391055, 0.13726068777032197, 0.16960707551334053, 0.13840546540450305, 0.06541890019434504, 0.24524942360585555, 0.1204943768971134, 0.1465025488869287, 0.0823889157618396, 0.12495362316258252, 0.10373445591540076, 0.18505210377043113, 0.08416358381509781, 0.10282902090693824, 0.09921796779963188, 0.1324101144564338, 0.21802585863042623, 0.13792272802675143, 0.12219644806464203, 0.1255583844613284, 0.1587232868769206, 0.12410951923811808, 0.08931521675549448, 0.12834176479373127, 0.14267309656133875, 0.1905326417181641, 0.10575322376098484, 0.08300450499518774, 0.14142897503916174, 0.09446078634937294, 0.14879427122650668, 0.21151657041627914, 0.11475761988549493, 0.06214158347574994, 0.06785583856981248, 0.14648610289441422, 0.21380410704296082, 0.1642475966946222, 0.13065597420791164, 0.1747454536962323, 0.1435093634063378, 0.09433206083485857, 0.13527948001865298, 0.09959166884073056, 0.17785150499548763, 0.1806034182664007, 0.09455382198211737, 0.07609553314978257, 0.1108554593520239, 0.10821090516401455, 0.1679509284440428, 0.21599373954813927, 0.10976062825648114, 0.13288390153320506, 0.10482611061888747, 0.2234885998768732, 0.08627730945590883, 0.12729138834401965, 0.14863769290968776, 0.10561536983004771, 0.1582540714298375, 0.20069466205313802, 0.07260293423314579, 0.1961623810348101, 0.10203893791185692, 0.1527431796421297, 0.13099800038617104, 0.07692858649534173, 0.12390454547130503, 0.11207056290004402, 0.07835261203581467, 0.1990923800622113, 0.10145644846488722, 0.13702581287361681, 0.10532369837164879, 0.10084238805575296, 0.12125852925237268, 0.08437013835646212, 0.08721343969227746, 0.18919175898190588, 0.11279323662165552, 0.24718890781514347, 0.27601994981523603, 0.06581122172065079, 0.09902814868837595, 0.1272061007330194, 0.1363022782607004, 0.18820921482983977, 0.10054529149783775, 0.19893825083272532, 0.16861615993548185, 0.09963585631339811, 0.1424685458187014, 0.16495219169883057, 0.1667288041790016, 0.09867398839560337, 0.07385475924820639, 0.2043085204786621, 0.13851043477188796, 0.0846884900238365, 0.08890785931725986, 0.22049697290640324, 0.18717691709753126, 0.10982107618474402, 0.1669325534021482, 0.13306033972185105, 0.21892363467486575, 0.08802347161690705, 0.2056742354761809, 0.12330529090831988, 0.10875205698539503, 0.1826204569078982, 0.1297749113291502, 0.2578091894974932, 0.1616218633716926, 0.16150564304552972, 0.15050680667627603, 0.12654089892748743, 0.18357658060267568, 0.09814238059334457, 0.1439604556071572, 0.24643344600917771, 0.1585168213932775, 0.09902110570692457, 0.10546410529059358, 0.2310148678952828, 0.17310039431322366, 0.12317049462581053, 0.172594427713193, 0.16461809165775776, 0.1653709856327623, 0.11010223883204162, 0.10413203926873393, 0.11090285290265456, 0.1773048093309626, 0.062357689457712695, 0.11861771548865363, 0.12969195406185463, 0.14007175021106377, 0.18361727998126298, 0.2231575277983211, 0.1853168723755516, 0.16970809665508568, 0.1161185628734529, 0.15335960750235245, 0.11273482959950343, 0.0637782491685357, 0.14074308215640485, 0.15891286107944325, 0.13661972450790927, 0.13175073108868673, 0.20827507716603577, 0.12711172923445702, 0.14261620352044702, 0.26459423010237515, 0.09830972747295164], [0.024869279586710036, 0.06985381143749692, 0.06557214626809582, 0.07619115145644173, 0.08337600927916355, 0.019701850033015944, 0.045721350907115266, 0.024016845054575242, 0.03851182780636009, 0.04989982415281702, 0.03041542338905856, 0.021922250125498977, 0.0533849644853035, 0.0176960437966045, 0.025542461335135158, 0.03820910205831751, 0.04086289227416273, 0.037622430609189905, 0.07307672130991705, 0.007520781691709999, 0.008280556303361664, 0.047253900702344254, 0.038045803594286554, 0.03662172981421463, 0.02841383440681966, 0.020571199966070708, 0.02267305495479377, 0.011060042215831345, 0.029986647568875924, 0.019903936845366843, 0.038219421621761285, 0.014544302175636403, 0.01618187514395686, 0.026588991604512557, 0.03318797578685917, 0.014825983398623066, 0.06287389769568108, 0.03607141989050433, 0.07859591030864976, 0.14411307085538283, 0.025510465493425727, 0.02561268334829947, 0.10213417030172423, 0.0266998851657263, 0.03426898438192438, 0.06685053274850361, 0.016492304384883028, 0.08266149918199517, 0.029690369228774216, 0.043425535623100586, 0.03581761280656792, 0.02649305602972163, 0.15596466459101066, 0.029510257409128826, 0.0316331801150227, 0.021443203077069484, 0.017921270773513243, 0.027860524351126514, 0.020744155626744032, 0.02969825640320778, 0.0720174316666089, 0.055878480488900095, 0.0679838887299411, 0.02410256682196632, 0.0209724977685255, 0.022741215652786195, 0.03737752187589649, 0.0352735257911263, 0.05311830340360757, 0.02392402650002623, 0.025353809251100756, 0.06170359018142335, 0.03882440556481015, 0.024918324415921234, 0.0291350164116011, 0.015490097957808757, 0.046870381047483534, 0.019099812416243367, 0.061394229633151554, 0.03328668142785318, 0.01862901248387061, 0.031446466891793534, 0.03640314505901188, 0.005593112009592005, 0.05982306589430664, 0.014526197483064607, 0.01638491561607225, 0.019068169094680343, 0.018569078492873814, 0.021422168756544124, 0.016141403975780122, 0.037012529937783256, 0.023188008963188622, 0.020156610298727173, 0.06258428198634647, 0.027722401391656604, 0.02124464517692104, 0.03633979533333331, 0.024093861429719254, 0.02290767566591967, 0.031152973460848443, 0.02268360272864811, 0.038278956708381884, 0.05032328248489648, 0.02657443066709675, 0.05836673837620765, 0.02771342511550756, 0.028693492349702865, 0.07921012656879611, 0.042646800065995194, 0.018314258377358783, 0.0317767263186397, 0.04144358201301657, 0.060161333094583824, 0.036922878498444334, 0.020550072877085768, 0.06142532191006467, 0.06833822713815607, 0.06378231613780372, 0.05152371748408768, 0.061953538097441196, 0.07466784882126376, 0.007458463551301975, 0.030266086578194518, 0.022011701184965204, 0.026428962300997227, 0.05065090357675217, 0.030205885414034128, 0.03558974007319193, 0.034855488847824745, 0.020614634158846457, 0.031946329327183776, 0.03438212850596756, 0.044005126983392984, 0.07219359526061453, 0.03321491945825983, 0.042841487666009925, 0.009578569806762971, 0.04510478946031071, 0.017962348647415638, 0.05329249288479332, 0.04578298998239916, 0.07811205228790641, 0.03928878220904153, 0.04174025925749447, 0.027864038420375437, 0.024800519604468718, 0.07506506852223538, 0.015309383143176092, 0.05849522269272711, 0.04048525785037782, 0.040517990273656324, 0.07194619291112758, 0.010167722812184365, 0.0698888704937417, 0.05529916743398644, 0.010576233362371568, 0.03330743929836899, 0.05739506297686603, 0.09477372776018456, 0.04285907285520807, 0.04492591331654694, 0.02536895091907354, 0.013640347751788795, 0.016746859182603657, 0.015424049597640987, 0.011814185781986453, 0.02789604724966921, 0.029466628402587958, 0.11557239413377829, 0.024833589704940096, 0.06911486241733655, 0.0744843231223058, 0.06669690075796098, 0.0823194433178287, 0.015050222391437273, 0.04251684258633759, 0.025759598902368452, 0.04394316136313137, 0.011416900215408532, 0.05768352093582507, 0.057577980114729144, 0.044607227682718076, 0.027855566804646514, 0.030569535920221824, 0.04720398013887461, 0.00665148602820409, 0.015714748842583504, 0.01357808063403354, 0.058188686016364954, 0.013462259212246863, 0.10211325658019632, 0.052917737993993796, 0.01722559823974734, 0.07277903845533729, 0.007569367317046272, 0.027502311932039447, 0.08033632824663073, 0.03446722686931025, 0.053969446598785, 0.018422912507958245, 0.04904436536889989, 0.04598352199536748, 0.03921797760995105, 0.03350870974827558, 0.03558586606231984, 0.03297230025054887, 0.04020064421638381, 0.004042413920615218, 0.07040401746053249, 0.025933077777153812, 0.09610175649868324, 0.037472086332854815, 0.041484971588943154, 0.07040464828605764, 0.11041731020668522, 0.03967954151448794, 0.01316759782639565, 0.018686734874791, 0.046253697146312334, 0.039696648018434644, 0.023578638392791618, 0.04748864201246761, 0.017035460004990455, 0.03544629034877289, 0.027556037857721094, 0.04967515749740414, 0.046021887319511734, 0.05801340186735615, 0.03170783646055497, 0.03250447261962108, 0.04486319812713191, 0.042546732584014535, 0.021305974405549932, 0.018999110397999175, 0.044649159026448615, 0.10674560879124328, 0.02785232733003795, 0.048626228235661983, 0.03334620538225863, 0.0371137291949708, 0.06080448940338101, 0.05677725843270309, 0.02627779424074106, 0.02707664385525277, 0.014154366654111072, 0.0031293090478357044, 0.03149669544654898, 0.03924431272025686, 0.03167770155414473, 0.019673961978696752, 0.00964248913078336, 0.016509294000570662, 0.03265437531808857, 0.09500561922322959, 0.039470163101213984, 0.0386687178252032, 0.003584551245694456, 0.02500888498616405, 0.01659902151004644, 0.024505797919118777, 0.06200006704602856, 0.051173319880035706, 0.02139348660421092, 0.010295168121956522, 0.028560261998791248, 0.014450727558141807, 0.05737602317822166, 0.02876133206882514, 0.034346642714808695, 0.05087444216769654, 0.05469724856084213, 0.03856525872834027, 0.03848332191410009, 0.03920189155905973, 0.038278752617770806, 0.059519987626117654, 0.06140153236628976, 0.10408261965494603, 0.035928986908402294, 0.05834167604916729, 0.03944360534660518, 0.02214747524703853, 0.0330615509301424, 0.01611228766705608, 0.021205457924224902, 0.034135661262553185, 0.0653066800441593, 0.022687413656967692, 0.018555573260528035, 0.04401740210596472, 0.006624316465604352, 0.08151966045261361, 0.08742017977056094, 0.00576344696128217, 0.016208239940169733, 0.061759826421621256, 0.07147245036321692, 0.018684170754568186, 0.019204811469535343, 0.022379003057722002, 0.022695636653224938, 0.02635655466292519, 0.04206435885862447, 0.03684069677547086, 0.04344155116996262, 0.013178304234315874, 0.05585820872511249, 0.010349227086408064, 0.014018931196915219, 0.016096123690658715, 0.09562990642734803, 0.08641280335723422, 0.06283972921664827, 0.03041923246200895, 0.009098197097046068, 0.07006341620581225, 0.026431094120198395, 0.06344924026052468, 0.005316903198036016, 0.04636914934962988, 0.02396994132141117, 0.13022621133131906, 0.03715736747835763, 0.01592869703017641, 0.022263699283939786, 0.01596555764990626, 0.03813790783169679, 0.04410393281432334, 0.04563719136058353, 0.044121581086074, 0.048105507739819586, 0.055764868811820634, 0.03556290401320439, 0.05116465159517247, 0.008014879495021887, 0.029557626839959994, 0.0186522973672254, 0.03587462088034954, 0.04297594256058801, 0.056826722575351596, 0.0023535457921752823, 0.08114941039821133, 0.021026219983468764, 0.041871252033161, 0.03134322301775683, 0.029194004164310172, 0.05287895706715062, 0.017682304787740577, 0.059472753637237474, 0.0610082163620973, 0.04668783127272036, 0.10329626224120148, 0.16729611670598388, 0.20803546736715361, 0.15786714531714097, 0.1909563338267617, 0.07963228243170306, 0.22791426395997405, 0.10061969922389835, 0.1454202749300748, 0.09926557657308877, 0.1576790850958787, 0.09157912340015173, 0.18455661629559472, 0.14672174962470308, 0.09094000808545388, 0.15081680176081136, 0.11528096016263589, 0.12983441672986373, 0.16789311514003202, 0.12133403535699472, 0.11816436715889722, 0.18151854572352022, 0.14711557771079242, 0.19695327297085896, 0.12431742448825389, 0.10393093209131621, 0.1490796566940844, 0.08390070026507601, 0.11552916403161362, 0.13226829003542662, 0.14367989409947768, 0.13176595995901152, 0.2325694149476476, 0.1525682702776976, 0.10157698066905141, 0.2245407277951017, 0.08429208668530919, 0.09852381481323391, 0.19787806319072843, 0.25487930921372026, 0.11082026670919731, 0.08927042814320885, 0.14880819391692057, 0.1461571830441244, 0.14350198645843193, 0.15373336791526526, 0.1542256641550921, 0.13720406190259382, 0.08689925889484584, 0.18549774860730395, 0.10578376313787885, 0.21820514666615054, 0.22487334354082122, 0.16385810275096446, 0.15027601359179243, 0.11222107787034474, 0.09913378598866984, 0.10821017785929143, 0.07798458842444234, 0.12253867462277412, 0.2875163219869137, 0.1907183715957217, 0.18807423301041126, 0.190949713869486, 0.1480278850067407, 0.17058154509868473, 0.1373126677935943, 0.11395517271012068, 0.10787449704366736, 0.1156043287483044, 0.09111394523642957, 0.1909167625126429, 0.14102444518357515, 0.09518544902675785, 0.10339776577893645, 0.1264229419757612, 0.10499840762349777, 0.12883110728580505, 0.17446677724365145, 0.167951240146067, 0.13223942049080506, 0.11350774671882391, 0.07769132134853862, 0.13969095423817635, 0.1529465281055309, 0.09453748731175438, 0.18507888045860454, 0.1136964451870881, 0.13144606462446973, 0.11544594701263122, 0.13988308142870665, 0.14849946048343554, 0.11192161386134103, 0.10575658568996005, 0.1306731771910563, 0.11488838630612008, 0.11013188021024689, 0.1582919803331606, 0.12723522260785103, 0.09982998730265535, 0.13324633677257225, 0.11741851616534404, 0.17963831458473578, 0.1668928485014476, 0.10074410543893464, 0.33550667809322476, 0.1305877708364278, 0.10348981435527094, 0.14765120053198189, 0.12598989880643785, 0.07041359116556123, 0.20969719538697973, 0.11352903151419014, 0.09972475818358362, 0.1265918993158266, 0.10155484240385704, 0.144101879268419, 0.1567761882324703, 0.1424740970833227, 0.18968850810779259, 0.1481946901185438, 0.22527030349010602, 0.05888344385311939, 0.1291077205678448, 0.1285925810225308, 0.1012056322360877, 0.1340721987071447, 0.10258572263410315, 0.11692255371599458, 0.1386475094477646, 0.12299490990699269, 0.10448358720168471, 0.07212187410914339, 0.13344518782105297, 0.12164390427642502, 0.13534737168811262, 0.16013465879950672, 0.13243920664535835, 0.10457469325046986, 0.09320120589109138, 0.21069562149932608, 0.12908278440590948, 0.17707624268950894, 0.2858071558875963, 0.09499911800958216, 0.12366886163363233, 0.25015850784257054, 0.2626476954901591, 0.12905964424135163, 0.1122884574579075, 0.0742820581945125, 0.17125520738773048, 0.14225243241526186, 0.08532557185390033, 0.2107982456800528, 0.19104987411992624, 0.11351679349900223, 0.16252394387265667, 0.2040419855620712, 0.14071445009903982, 0.1914206362562254, 0.17992886540014297, 0.09839961639954709, 0.1406265055993572, 0.1409140878240578, 0.08393453477765433, 0.20225183630827814, 0.12111978474422358, 0.13421969313640147, 0.16982317407382652, 0.16748846654081717, 0.13566250243457034, 0.11575106618693098, 0.15989913081284612, 0.15463553747395054, 0.15521188935963437], [0.07781188323860988, 0.09394949855050072, 0.02770749164483277, 0.08354071411304176, 0.0329357531882124, 0.05077747686300427, 0.02436494942230638, 0.030264249762694817, 0.05076612942502834, 0.033342079041176476, 0.015240863431245089, 0.07644584911759011, 0.08263038092991337, 0.0254088858855539, 0.02161250180506613, 0.042921647036564536, 0.02425611161015695, 0.01307739255935303, 0.04429913249623496, 0.028744125374942087, 0.057569215350667946, 0.018724929504969623, 0.05677711371390615, 0.02346815301280003, 0.025549203746777494, 0.08512669111951254, 0.07394409898552112, 0.03562685858923942, 0.021813735147588886, 0.01893280877993675, 0.03989198499766644, 0.08991473849164322, 0.014695549089083215, 0.00521188188031374, 0.03964315401390195, 0.010440603091410594, 0.07904041965957731, 0.0752834825834725, 0.016126705741044134, 0.0711744483851362, 0.04087752371560782, 0.01594804853084497, 0.012884699481219286, 0.07578993157949299, 0.02759563700237777, 0.025030648466781713, 0.029972428019391373, 0.052627617624239065, 0.015292752541427035, 0.008046323364396812, 0.06162638826936018, 0.031253274719347246, 0.05726777351810597, 0.027084692446806002, 0.017904565029311925, 0.02261582609207835, 0.07038603522232734, 0.023917976141092367, 0.0487737115327036, 0.05170995573280379, 0.03859732692944817, 0.07014118586084805, 0.036262059074942954, 0.014074456830712734, 0.05231210096098948, 0.034390114014968276, 0.0265459359070519, 0.014660144006484188, 0.025662720800028183, 0.06045447400538251, 0.018910446015070193, 0.012239882616995601, 0.016066484167822637, 0.02678105200175196, 0.030649932778032962, 0.032437538320664316, 0.044429171612137, 0.0326029333518818, 0.011376174861652544, 0.02985176779475296, 0.05219822211074643, 0.043025065315305255, 0.044175887742312625, 0.03088228993874509, 0.03934046166250482, 0.04434977294295095, 0.052892478997819126, 0.05096056098409463, 0.06619019201025367, 0.08294950443087146, 0.05136090512678493, 0.03433805606618989, 0.0245839182389318, 0.07721182715613395, 0.09937410824932158, 0.0121495845814934, 0.04351309791672975, 0.07021201643510722, 0.02141912409570068, 0.023819613743398804, 0.0907992894644849, 0.039978103814064525, 0.06868889933684841, 0.03283570797066204, 0.026133574538107496, 0.029774745853501372, 0.10245183919323608, 0.01852128974860534, 0.044620411936193705, 0.07581084530102089, 0.026536395598668605, 0.03383824187039863, 0.012656245089601725, 0.06166432685859036, 0.03966927390138153, 0.015197760421870044, 0.031033422746986616, 0.01664609408180695, 0.08166888408595696, 0.09852267190581188, 0.0638140132650733, 0.0112709030690894, 0.08959250539191999, 0.02814050512824906, 0.06353971548378468, 0.034785556272254325, 0.03885849240759853, 0.03345681878272444, 0.08957490164902993, 0.10213860834483057, 0.016829573396535125, 0.007906840419309447, 0.05273652779578697, 0.051464330827002414, 0.041287716157967225, 0.030277706755441613, 0.085098615672905, 0.04288884410925675, 0.08668987677083351, 0.01590078856679611, 0.048547965052421205, 0.04576251783873886, 0.03969542718550656, 0.017027504181896802, 0.0719667949306313, 0.01034716762660537, 0.015813452628208324, 0.054344424133887514, 0.1580584264593199, 0.020925323151459452, 0.03009264666616218, 0.050052446822519414, 0.04338320351962466, 0.026613834997988306, 0.025045302172657102, 0.027265692988294177, 0.02575640581198968, 0.05557798489462584, 0.020245745945430826, 0.012397287500789389, 0.01983980600925861, 0.0371001404710114, 0.04006220398878213, 0.07580034391139634, 0.09767113166162744, 0.07092104206094518, 0.07825462627806701, 0.021304677502484992, 0.016132917517097667, 0.024061624390014913, 0.07801703512086533, 0.09019161152536981, 0.029122136438672896, 0.01517378348580678, 0.03616479691118002, 0.01487512192397844, 0.047276094628614374, 0.06035491489456035, 0.02527271477447357, 0.05469898518640548, 0.020722169501823373, 0.06788731305277906, 0.08896052211639471, 0.022485812951344997, 0.026378512957307976, 0.0244426726931124, 0.02953509709186619, 0.06427229687687941, 0.059504484161152504, 0.053029178889119066, 0.03605203499319032, 0.05155739614565391, 0.051109283667756245, 0.04753803936182521, 0.019119540556857828, 0.044547084035002626, 0.048984229142661206, 0.03277323026850354, 0.020448294744710438, 0.07023215090157464, 0.03817208002146799, 0.01842361940362025, 0.04232273015077226, 0.03590851847548038, 0.02756011781457346, 0.01401872061251197, 0.054109701377456076, 0.026652287524484564, 0.0341914522141451, 0.023278649314306676, 0.019528933335095644, 0.014174082734825788, 0.04580882043228485, 0.03712305428052787, 0.031277338857762516, 0.02077024768368574, 0.011703753280016826, 0.07220028943265788, 0.06666890694759786, 0.01976096951693762, 0.03352494793944061, 0.05931704363320023, 0.05605531572655309, 0.026588440559862647, 0.030612788286816794, 0.030417013440455776, 0.02369868820096599, 0.02236703221569769, 0.035856909526046365, 0.058373985448270105, 0.02302097564097494, 0.05063869153673295, 0.034252772165928036, 0.03805005610047374, 0.03855813411064446, 0.0415712314133998, 0.018716654558375012, 0.019244865179643966, 0.04486290868953802, 0.0275242108546081, 0.022857486073917244, 0.046470775341731496, 0.043668511061696336, 0.05112032682518475, 0.027000471673090942, 0.04330673262302298, 0.07110194055712782, 0.04134434202569537, 0.06519643400679342, 0.008459989057882922, 0.10553463158430532, 0.043440623485366814, 0.061958354635862634, 0.0051881813942600274, 0.012875032080046367, 0.010565289467194816, 0.0805593362019863, 0.028677526897809003, 0.03830229725281242, 0.06343994115013629, 0.07063220560667105, 0.02807066346576903, 0.05510422750376165, 0.015078882279340178, 0.046445126718026586, 0.04418363205331843, 0.04394318733830005, 0.012333410850260407, 0.02544259979913477, 0.03990375917055644, 0.057108107866952196, 0.012527449998742668, 0.05125908617628738, 0.03197990037733689, 0.0667194472043775, 0.018369260797044262, 0.016418052509834524, 0.028017479307891335, 0.027852087987412233, 0.027213486609980464, 0.048702532149036415, 0.01098947139325901, 0.07240742284920998, 0.047856895689619705, 0.038893781529623084, 0.044673557131318375, 0.02134804304660065, 0.13221004628576338, 0.01838098487496609, 0.046261675233836286, 0.031335014864453115, 0.06683308485662565, 0.013040612648183014, 0.017574268495081924, 0.08935391233535483, 0.07008649699855596, 0.01659134399233153, 0.030150016536936164, 0.03717794352269266, 0.018961863861477468, 0.03874487701978069, 0.023100374310160987, 0.01129557576859952, 0.017435473891964648, 0.049803252186393365, 0.025286763629992492, 0.06953015341423452, 0.0178813098318642, 0.05119531342643313, 0.06072049684007652, 0.09205899608787149, 0.030544930014002603, 0.009136109711107565, 0.028434460546122864, 0.10048449476016685, 0.1132034142210614, 0.09302596998168156, 0.013836730231560068, 0.07103620853740722, 0.02296214188390877, 0.008368023045477457, 0.04817970395379234, 0.013242872009868734, 0.04786261393746827, 0.06661532388534397, 0.028011187750962563, 0.003218184710931382, 0.09413802632479928, 0.009179542048514122, 0.017771251186786685, 0.02623198517540004, 0.04046532376378309, 0.017721976291795727, 0.027185568869754206, 0.06767892540665343, 0.034566277608973905, 0.028258627207833342, 0.01583708817634033, 0.08988411747850478, 0.022510552444146015, 0.048120265346369706, 0.034378822238068096, 0.020176347716187593, 0.030133950895105954, 0.06360759973176755, 0.11913480688235722, 0.0834659204701893, 0.04084078740561381, 0.03652206309197936, 0.01353266583464574, 0.04473734843486454, 0.041135364372166805, 0.23218158341478556, 0.18127086135791615, 0.10853148327441886, 0.1118682386004366, 0.09478816253249533, 0.19691833265824243, 0.1243827112193685, 0.0772532464179676, 0.14949312200769782, 0.12653666868573055, 0.13024289481109008, 0.17495125124696642, 0.16229120636126027, 0.12029758159769699, 0.12293084029806778, 0.1301490279729478, 0.17548590927617624, 0.13007539208047092, 0.13110391970258206, 0.13413581560598686, 0.15761238086270168, 0.1271007751347497, 0.12251679610926658, 0.2302302248426713, 0.16814042843179777, 0.14224940445274115, 0.10423669693409465, 0.15067448752233759, 0.12896393687697127, 0.08793935659923591, 0.30619077617302537, 0.3069167450303212, 0.1039148868585471, 0.06558497800142504, 0.195278542523738, 0.1646374913980253, 0.30079601565375924, 0.155108745675534, 0.05706803931389004, 0.14062816801015288, 0.12373387377010658, 0.11756265608710237, 0.13272039155708626, 0.1487909464049153, 0.11324872233672068, 0.1306963321985677, 0.1522854674840346, 0.12062213019817136, 0.09861423808615655, 0.08462956349831074, 0.11334621827700175, 0.06968127694563009, 0.07401947892503813, 0.14615267078625038, 0.14060437475563958, 0.11939141928451136, 0.18046128214336932, 0.11950596235692501, 0.11974275941611268, 0.11596769167226739, 0.10587622731691226, 0.18757411453407258, 0.1690713784773834, 0.12126234389143065, 0.1103732488991227, 0.1587123773060739, 0.0998604524647817, 0.16942091519013047, 0.14802506484556943, 0.26523209118749946, 0.1569537099567242, 0.17789742909371853, 0.12528943014331162, 0.11219424923183396, 0.30004341853782535, 0.17067035048967227, 0.1451001421082765, 0.09515733647276647, 0.1103782509744633, 0.11382139316992834, 0.1338645606301725, 0.10999159203493036, 0.08664762630360201, 0.07442046131473035, 0.24915907240938395, 0.1339781389106065, 0.15835115918889642, 0.11609941546339542, 0.245520262978971, 0.20780712337000296, 0.1937771777738817, 0.11850679409690201, 0.11943962177610956, 0.13914562412537634, 0.20535612129606307, 0.13120238785631955, 0.10100396844791248, 0.1392180725815706, 0.15952373767504469, 0.08793393892119639, 0.12182298451079987, 0.07981172631843947, 0.14250338223064318, 0.10747213425929658, 0.1516713254386559, 0.1337455349857919, 0.18210895388619974, 0.09025392224430107, 0.16902543953619897, 0.19515142746968195, 0.11996365967206657, 0.18735080229816958, 0.12312379869399592, 0.10216786380624399, 0.1282364540384151, 0.1688261580420658, 0.1596149624674581, 0.13791115052299574, 0.18839731957996264, 0.2058231399860233, 0.11318144664983265, 0.06939144601346925, 0.13789077114779502, 0.06575639185030013, 0.12091614684322849, 0.14796732575632632, 0.19594895420596004, 0.14185596228344366, 0.17321665916824713, 0.12046663541696034, 0.10934296980849467, 0.10459228957188316, 0.09783755827811547, 0.18260441167512909, 0.18154091405449435, 0.08017436935915612, 0.21690880763344467, 0.14720239414600655, 0.22636504552792758, 0.2536832640180364, 0.2017944655381143, 0.09601600133464672, 0.10853802159545012, 0.14609466452384368, 0.1269063918152824, 0.10915228980593383, 0.13568072958150879, 0.22095784661360085, 0.3307791380211711, 0.13966539467219263, 0.09550713293720037, 0.13667888852069154, 0.19654461677419022, 0.1258165479521267, 0.08490543463267386, 0.12568324338644743, 0.06955655160709284, 0.103220897144638, 0.10475591087015346, 0.13356094801565632, 0.20231039175996557, 0.13615358155220747, 0.15295132237952203, 0.30097701062913984, 0.1994664521771483, 0.19268157484475523, 0.1074393535964191, 0.07375583096290939, 0.20053866261150688, 0.16496768774231896, 0.18093100225087255, 0.15112798428162932, 0.10639213127433322, 0.09266079621738754, 0.19375440868316218, 0.10198896168731153], [0.04249382487614639, 0.015141629937716061, 0.07188444622443058, 0.025034897262230515, 0.018453360971761867, 0.04599966370733455, 0.04619439583620988, 0.032357894742744975, 0.004926032106595812, 0.04397649121528957, 0.018738447724899743, 0.07085028570145369, 0.007971150298544671, 0.040195890760514885, 0.04835616440686863, 0.06903665489517152, 0.043461210661916994, 0.05934494096436538, 0.040969138135551475, 0.03145157657854725, 0.041600338445277885, 0.021323570726963226, 0.038426718310802244, 0.04154210211709142, 0.09389285783981904, 0.04193190405203495, 0.06572991944267415, 0.03037974463950377, 0.10065783819300123, 0.08881527639459819, 0.029465418701875024, 0.05349204897356685, 0.030081291806709487, 0.04421219360665418, 0.04741753684356809, 0.05878240415768232, 0.032432959269499406, 0.04623916589480359, 0.02850824672350427, 0.02032055072049843, 0.027395346187404357, 0.041422130234423093, 0.044843442155979574, 0.002926061702055449, 0.04122156111407094, 0.03463972425379325, 0.035991817130707204, 0.0265250871234457, 0.041728603828232735, 0.027620311557257082, 0.041676720284158364, 0.042199856470688246, 0.0468380753591191, 0.041814143769443035, 0.05493178206961602, 0.0086061086585687, 0.015597194505971856, 0.009491775635979138, 0.01866165028332034, 0.04144321836065501, 0.040719116004765965, 0.09745412025949918, 0.02489130467438372, 0.06403506195056252, 0.04389623907627538, 0.05832793147419579, 0.021542105387197807, 0.03506854460283648, 0.0229857941303635, 0.05696191961760633, 0.10865090967854485, 0.009161771322396817, 0.04905867397610564, 0.05632006206724327, 0.047013036673888564, 0.03069454698561458, 0.042609102674759924, 0.019302789805806242, 0.04781335017469246, 0.03253428469179198, 0.037815979012520984, 0.13196604297263548, 0.012497175939643057, 0.05967391647573095, 0.018404414477117825, 0.06216241556103341, 0.033617026201682165, 0.03318088456580881, 0.024759892585279886, 0.024221974672400393, 0.02805829371936852, 0.02673552866326645, 0.03244830688345246, 0.036121551966061816, 0.021114606061019003, 0.03902421398379374, 0.00706906237610383, 0.0863246807421092, 0.01337745028649806, 0.0662162339722272, 0.041822452112683095, 0.0331247596477624, 0.04853643949900288, 0.02496765311661875, 0.06606364840990864, 0.07640339084900916, 0.057487701560603455, 0.037362515649874695, 0.028402216084941756, 0.013050463730905904, 0.01876071957667591, 0.04045168308948632, 0.026733621343737468, 0.030820290921838023, 0.06638867198489606, 0.03439814034209121, 0.04146838829910848, 0.023344854453171138, 0.08578227469115518, 0.022126034600660205, 0.09671957217506133, 0.01188206260849256, 0.08608191681560129, 0.016742209627409466, 0.01363988390949089, 0.03336580550239887, 0.0411387300118804, 0.05721658017137088, 0.06075924808101263, 0.021827392520208377, 0.046866206466802396, 0.024526104934921023, 0.056522200829931535, 0.0721586104191374, 0.009770599590410711, 0.04200387011223938, 0.013786241925117793, 0.03594020447053481, 0.037549295666394755, 0.019326364126754925, 0.0505513036478078, 0.012853486605308717, 0.03447612150921486, 0.07623029974638484, 0.0455905214039376, 0.05951862949586939, 0.01503966162999859, 0.07388504629489034, 0.015889639653323684, 0.04213066604279447, 0.023573721664433833, 0.04398003868118394, 0.03853950991469901, 0.027438138422439806, 0.022619399533141404, 0.021535906598728616, 0.0355469663918484, 0.0362994076567702, 0.05291588633554056, 0.09249943846953101, 0.05261764315946493, 0.03626046716817655, 0.006270780040722457, 0.04434719026903622, 0.03962520517234225, 0.027323645444994327, 0.048865511489566416, 0.0724799232557416, 0.05630564584862441, 0.06347151211230084, 0.0026947945707433973, 0.02065987548121484, 0.07248893292853609, 0.055574029247509316, 0.019627165856945794, 0.0674111807893496, 0.0527484503982123, 0.014605795604438754, 0.06607900344533846, 0.05454167956486344, 0.10210787600954063, 0.03123459486232605, 0.02573464789747959, 0.016417397564509884, 0.013831832984578796, 0.019477600835671183, 0.08798997849225998, 0.0112453407200519, 0.06436251976992935, 0.04253947066899855, 0.02122943857102655, 0.038587723538512364, 0.005245081856628531, 0.07971466824528761, 0.007738026870356407, 0.018801810438162647, 0.010111741685250308, 0.04284211107005831, 0.02924959102529101, 0.09147091084741987, 0.023654710385017097, 0.05770630858023651, 0.12779095763107762, 0.013966985497972928, 0.023508885788032785, 0.12579976057168096, 0.01849726828368148, 0.07008554704952985, 0.05769129122199956, 0.039220222606672905, 0.04115840063604992, 0.04326065267377999, 0.03326476209622342, 0.019417091680224985, 0.045156810301705264, 0.04748135412228294, 0.01734177589241881, 0.03657323046354577, 0.032659099088050425, 0.033823910998762585, 0.008000545840332052, 0.006133427987151663, 0.018166348345403094, 0.004283061798560084, 0.04533717074082233, 0.023775044064677786, 0.0237776081849006, 0.08687916153576225, 0.061728233195026405, 0.03891955260769464, 0.06679902027826756, 0.0182686404150445, 0.05117366868944373, 0.0590572437067749, 0.010439520483487286, 0.021506536104425322, 0.05738501058658585, 0.06582506277482025, 0.011591457987378817, 0.02682935282791732, 0.01882960757939145, 0.020842263838858344, 0.04502973606577143, 0.04982915685104672, 0.039429367243428715, 0.019628418231150135, 0.020167018919892143, 0.06004090479109436, 0.028658871160587296, 0.03418354463065043, 0.017415515685570426, 0.017314676370006055, 0.05003213052987121, 0.06636712743784301, 0.05303774698404595, 0.03308874693175312, 0.04046171692607459, 0.05809369853523094, 0.03924855780496728, 0.03423258945986163, 0.02471033196343342, 0.042302688452764414, 0.053038025289424695, 0.05021817582019139, 0.03861264114675578, 0.10539650305872783, 0.02874400477594463, 0.04721227734989952, 0.03857564879581332, 0.0994305411586538, 0.0034491489532229025, 0.07139321125578135, 0.05464049281727057, 0.04344097600551322, 0.04716205621662084, 0.057092214774456806, 0.01828803458920447, 0.01519686706160428, 0.018917600318673067, 0.0625755098008085, 0.05628152975987177, 0.03179344319505617, 0.03431037395785097, 0.020211456867400557, 0.0464707530773012, 0.0624739691556897, 0.039818623699829914, 0.04823268587642815, 0.025671993935247883, 0.003908114877049229, 0.05700902001990471, 0.02940059766842751, 0.04224925010930747, 0.03243436563934665, 0.0734005871345289, 0.026666150843084324, 0.059899217667407356, 0.04597105391439982, 0.05180203770578373, 0.07186322822235525, 0.031032515471451916, 0.019960122990596574, 0.02621589541377034, 0.07252701252582483, 0.009001856124086771, 0.033935993851628155, 0.03810660033195745, 0.023726143954263534, 0.06146432177047245, 0.11961630487348884, 0.02566201947047375, 0.0474839516391512, 0.024857792996044736, 0.05859517143107951, 0.02072227896860568, 0.017580099920451175, 0.05905157369852532, 0.04593049925460946, 0.12396844438626431, 0.057115978343063034, 0.06289260723860934, 0.06045805857866071, 0.012922974819957744, 0.040142196376109496, 0.049335420844727196, 0.0405393975233892, 0.019773174135480076, 0.030511770855810028, 0.013031872931605903, 0.023071078030625358, 0.04951027825882193, 0.009487506431469228, 0.06943590808077715, 0.10162988837691955, 0.05678292101947591, 0.017721972581057344, 0.04640121012926102, 0.03162716871884186, 0.06355271048960276, 0.019915482807846274, 0.030595815369451884, 0.020086141521460377, 0.06278115892200731, 0.05118855617183726, 0.04612146869476419, 0.014360929544636747, 0.05079318070784211, 0.009964290857169544, 0.04629413306247443, 0.02332898733584443, 0.01914140237204265, 0.03482912405161187, 0.12592000333825126, 0.13217896514106542, 0.22312429442536086, 0.19804365118034184, 0.1595046347938478, 0.10989557296852581, 0.17982667166506872, 0.0986219490005169, 0.09557753306580707, 0.12795694638043642, 0.14409730763873085, 0.20248564251232892, 0.10523844044655561, 0.15809075441211462, 0.09594652146915905, 0.10511167420190759, 0.1229658696684055, 0.1907622770522721, 0.11093660577898845, 0.13607117347419262, 0.10994203883456066, 0.17460147704696283, 0.13382298551732674, 0.13636953168315813, 0.2339425217360258, 0.11813518591225147, 0.24762163928244263, 0.10953309320029803, 0.2165580092696473, 0.26592442591208965, 0.1084682226064615, 0.25878674641717225, 0.23045365582220256, 0.2174951191409491, 0.11699347334797494, 0.16341121110599488, 0.08840898764901794, 0.1349019940244034, 0.11398493283195421, 0.08730055298656225, 0.1069531132816337, 0.14473764749709517, 0.226768818392884, 0.14017020352184772, 0.12256943664397113, 0.07872966016293503, 0.11117545116576366, 0.1948478742269799, 0.1785327965626493, 0.10607703763525933, 0.2978588920086622, 0.17211802827659994, 0.15017330035334453, 0.14020886941580102, 0.1207820704439655, 0.11575964541407302, 0.20267873449483886, 0.21955083851935342, 0.08723986014956608, 0.16554993228055537, 0.1305272412719205, 0.2571671426994726, 0.10363655179389752, 0.16175668191863224, 0.1406182232312858, 0.08938888233387843, 0.1245131139876321, 0.09393614731379785, 0.18191593611845747, 0.1365505118155852, 0.16517387120984495, 0.13793531485134736, 0.1602896340773441, 0.14320674526970834, 0.18695369391934946, 0.09817454527365044, 0.15091834240593016, 0.1976807854953222, 0.09225545742083341, 0.07509652816224843, 0.14608028170187026, 0.1228257744514849, 0.09926720187650062, 0.1288015698082745, 0.16278397757560015, 0.13663628924405202, 0.1340422307839617, 0.16558913252083585, 0.12389456358505413, 0.1996253163088113, 0.11614925067988224, 0.1128474876168184, 0.14064168994082138, 0.1262999532627873, 0.15533293364569545, 0.2050969930132851, 0.1738949673017487, 0.11792663499363698, 0.15269623138010502, 0.1528099284041673, 0.135796207759995, 0.11103724842541851, 0.1037354429718107, 0.16392789431847632, 0.11306322252494283, 0.11745655865524895, 0.1509073586203158, 0.08878435852238908, 0.16944286791840568, 0.13008790469029918, 0.16219218901824206, 0.09322548154159449, 0.11034783034119755, 0.20113175734877586, 0.16516688017873093, 0.07432695812894963, 0.17208354809554294, 0.21442377066705376, 0.25069053866900504, 0.10373991070082411, 0.16966705588856712, 0.12642392161069438, 0.16689228446921334, 0.09311266025179066, 0.10556220237049274, 0.07992368671693839, 0.11160879861563444, 0.15863105276366696, 0.09577236909535713, 0.10003793708165176, 0.12163010775111616, 0.10285073614795692, 0.11330672117765062, 0.17948872729903087, 0.08596013780334033, 0.10197087554843165, 0.16124819201650098, 0.14370650751516223, 0.16909754660446197, 0.11106381731224246, 0.15867044596234336, 0.0834015391592402, 0.19861985463649035, 0.18073788058245555, 0.1919183650170453, 0.20213422074448317, 0.10434721014462411, 0.15131920605199412, 0.13303947052918375, 0.16563538316404447, 0.09969631908461452, 0.15217019710689783, 0.12838403752539307, 0.07207878501503728, 0.1427088532363996, 0.12502804573159665, 0.16992079617921263, 0.20332072192104533, 0.1208787426003255, 0.19918741949368268, 0.11276671226369217, 0.15986295853508636, 0.15267865732312202, 0.10870504193007946, 0.13078248070087284, 0.10673326687538065, 0.19634925381978974, 0.18568715953733772, 0.11794679914601147, 0.1491731227724813, 0.2201689436333254, 0.15360031567979604, 0.13515376020222902, 0.1041507933405228, 0.2044371940428391, 0.13984313904074952], [0.03822585233137943, 0.012894163719465723, 0.06485704987426288, 0.031454456111532636, 0.04029231800814159, 0.01320266337643261, 0.0385534548695432, 0.06028438489011023, 0.07516250509070233, 0.01406083563779248, 0.039846086874604225, 0.061147387605160475, 0.03712810830620583, 0.09853108786046505, 0.03985805771662854, 0.02339386031962931, 0.016843998891999945, 0.006142852798802778, 0.06096819975937251, 0.023467240171157755, 0.059320802611182444, 0.018478579149814323, 0.07677139961742796, 0.021951501876174007, 0.050906139294966124, 0.019843668887915555, 0.020493148294917773, 0.016901034796319436, 0.029652989105670713, 0.014882623181620147, 0.01208448338729795, 0.008577600910939509, 0.07805091416230425, 0.023651849405723624, 0.018871076936193276, 0.07950022467412055, 0.02693411439395277, 0.03403559749131091, 0.03596627982915379, 0.029058718064334244, 0.008593028305767803, 0.03764785658859182, 0.035709893782041036, 0.010772590794658754, 0.04131395478907507, 0.04774081637151539, 0.0103278838469123, 0.07111654602340423, 0.02004210247832816, 0.021908835806243587, 0.004165133605056326, 0.021074509677418973, 0.03075355700275395, 0.053773092877236195, 0.02949800455098739, 0.015830471929803025, 0.01616688747162698, 0.04814932784938719, 0.024730295735935215, 0.017724243552947883, 0.0234215053205844, 0.033813995905802585, 0.061230092542245984, 0.0506666111323284, 0.019893190547009, 0.08662384789204225, 0.003496753320177959, 0.01845456881710561, 0.05223856154771056, 0.005686376780431601, 0.06349430346745066, 0.0403999442642089, 0.05715926410630345, 0.02462874024786288, 0.08640192347229458, 0.04702555299445521, 0.02514757012249902, 0.07255249045556411, 0.021981863137625623, 0.04513216728810221, 0.05379916081437841, 0.04017294726509135, 0.031522459103143774, 0.09299151948653162, 0.03438568710407708, 0.04117441247217357, 0.02152153119823197, 0.017889115370053332, 0.03390979974938091, 0.04024804147775285, 0.0069633063321816735, 0.05491938820341602, 0.029331281075428706, 0.04354105461970903, 0.04690604495408479, 0.021218413967289962, 0.015206247808237094, 0.03440270826104097, 0.028294506337260827, 0.018246555955556687, 0.028193307080073282, 0.0412130264157895, 0.07062257995130494, 0.03880109841702506, 0.03767491529288236, 0.04252820115652867, 0.09611041736206971, 0.053765701086376794, 0.04810038321011234, 0.0940071114746388, 0.055116124131018296, 0.06619918684009463, 0.040865259725251235, 0.02440996624500258, 0.010035948926088167, 0.07028796782833524, 0.022523315528815147, 0.02569707667134935, 0.014716158530063694, 0.009809720049815951, 0.02927136934886221, 0.03483415952359792, 0.02913671592978062, 0.0549889534158865, 0.04198578026262112, 0.07053539986372925, 0.012025395444652531, 0.043812784570036456, 0.03337297835969366, 0.06959972975892015, 0.016309734201058745, 0.016953602971625514, 0.06543135343235917, 0.033214526119991206, 0.07415747386403382, 0.035359963731025346, 0.03882167817209847, 0.029211383407528047, 0.018484161955711897, 0.038244187089730985, 0.044597965679713525, 0.018887843907577917, 0.04108100576559082, 0.04868309901212342, 0.059941850340692326, 0.028001100108667742, 0.021700574325222988, 0.028782923000107985, 0.006756048142051441, 0.06851285448647104, 0.09982404269976541, 0.020332720087026246, 0.03158724859531503, 0.055826541283749975, 0.031328955228673294, 0.02317516424227506, 0.07593709946377203, 0.03504190521198325, 0.029948436240374576, 0.012872024526586756, 0.09070966028957628, 0.07068776278174482, 0.0614692681847373, 0.022018577183189336, 0.03182860244123731, 0.0775967791560106, 0.006405602762242779, 0.08572864710004069, 0.08148100940161385, 0.018424908885208424, 0.07812195995938964, 0.027713484487321693, 0.0501578429248184, 0.056022742865025066, 0.01755565172061324, 0.011865015476359986, 0.031383581008412875, 0.04192886866803747, 0.028147039738541935, 0.027750784829549957, 0.02322463580640033, 0.01361582904792158, 0.07840287027647719, 0.0374473245756235, 0.047131557657849044, 0.04849286800890695, 0.01777845372998854, 0.04595651524141431, 0.05246738423011266, 0.05838111006596591, 0.08374184355488978, 0.008638840154162608, 0.09876668264041655, 0.034064385399688035, 0.014784207905904623, 0.028843365362263285, 0.032357712916564196, 0.004565075132632046, 0.05902621822315268, 0.07722189067862928, 0.03799252852331847, 0.02109539185767062, 0.026308936612622347, 0.008440561487077503, 0.008935063760873163, 0.014699677285534563, 0.030382997101696674, 0.027672456708387472, 0.11059161843149923, 0.04624393790436443, 0.05436834726424422, 0.0032231109480562736, 0.0486949882179033, 0.06021537999913562, 0.08427239750744775, 0.012252408214408206, 0.04873753925494384, 0.01218816512846388, 0.07428531622281298, 0.06545099808136001, 0.03417858337343205, 0.02712585381232202, 0.08057331084273756, 0.04466585363843478, 0.040638155114720576, 0.03909113343979698, 0.05657580244587734, 0.03491918738291133, 0.031235956703312695, 0.031537253817077726, 0.03533817798597738, 0.041954995976993814, 0.028819885665143374, 0.020090787365916185, 0.012463447183108656, 0.03955845641030464, 0.04123971033550333, 0.05242228020506445, 0.08127846987918019, 0.04033742574392818, 0.04626654743333347, 0.08815263499855064, 0.022622633441642392, 0.013475644773279782, 0.0344338636205066, 0.025805048026086297, 0.023906508104118984, 0.07431735473801382, 0.024599217613285873, 0.027260965507593937, 0.017231075289600994, 0.01103611630242085, 0.06364700777339749, 0.04537943976174574, 0.01810295223549474, 0.05022300349082798, 0.033750798320397735, 0.13063835562206805, 0.028704028991342057, 0.0647090953134466, 0.04365346772829071, 0.09455788152990863, 0.05272969261568505, 0.03283982689026743, 0.02546726136642974, 0.0635648965544533, 0.023966460648807697, 0.02873914741940098, 0.014885604759911075, 0.015308499059756286, 0.04919964492728468, 0.03372453742485959, 0.017964986982406117, 0.019392201902519446, 0.03983288777817506, 0.005293923986755544, 0.03742841465282254, 0.028819932049373165, 0.012247457161720376, 0.026357371025369503, 0.11102576740086079, 0.043661924501066096, 0.03546658808772918, 0.06770114530809224, 0.031021175454952754, 0.007188085237430641, 0.025415991949557792, 0.06480867668869905, 0.051197153952671215, 0.051534634476411156, 0.08035429564188235, 0.039185278583317995, 0.035805968509521335, 0.048999239079421386, 0.058439294443815015, 0.036087973494431935, 0.059109524299856275, 0.058553306880639866, 0.03867799838189967, 0.03712781144713517, 0.023498705377278384, 0.03985976094554644, 0.05841908947331831, 0.03071038256166503, 0.03502683590340894, 0.047582223123754375, 0.052268611107137986, 0.02206993565778248, 0.07632777342223562, 0.044237960973987356, 0.02467856989824213, 0.023253963627212215, 0.049003380263457075, 0.023708749868092127, 0.10437761593493633, 0.03118546839687042, 0.01740594754664926, 0.030935370195948053, 0.03940264250559267, 0.07570166053483263, 0.05740139720728621, 0.024770544259808958, 0.016391667304560542, 0.04300537613744382, 0.030511104778270237, 0.034802688751369715, 0.09335335358628072, 0.009145906988123897, 0.06996661788434722, 0.0438917861902155, 0.1103234285255894, 0.019314406272314955, 0.05220259707130026, 0.05481815926032141, 0.025474899921391625, 0.03146944007312413, 0.04041649415739812, 0.04574021259031724, 0.059846681033377536, 0.0071259113519772654, 0.0037056344945085584, 0.04906287824269384, 0.06494133558589965, 0.03952857012336608, 0.014250013718992705, 0.03906460166035686, 0.017622697341721505, 0.02881070158764487, 0.03573413232516032, 0.08465161270578392, 0.046080197862465866, 0.024648796788824257, 0.07486936417990364, 0.13667237246409059, 0.19974066090071574, 0.17188214405905455, 0.11246142239542678, 0.1089156634407118, 0.10340082342736423, 0.15515936014708132, 0.2675149077549577, 0.14019994880072773, 0.12588715588208288, 0.205475518014282, 0.1515394457965158, 0.21584378118859604, 0.18284532765392214, 0.13037032156717032, 0.15743557160021737, 0.16082368354545906, 0.2110794305917807, 0.17487265780800954, 0.08545461649191566, 0.07544078078353778, 0.14296988141722977, 0.13028528628638014, 0.1153736024571117, 0.07185791444499046, 0.10271606603055261, 0.09804855086258613, 0.09079440613277256, 0.1835029892390594, 0.11437347682658583, 0.07199155297712423, 0.29703834385145456, 0.22405779745895416, 0.11445724303484894, 0.12872180377598852, 0.12719082733383402, 0.2336095052305609, 0.1831851273891516, 0.1741526706609875, 0.23078011174220592, 0.1658835870330222, 0.17011336865834892, 0.12201082208775915, 0.09026777814142406, 0.10330165023333393, 0.1262147250236012, 0.09141266709775664, 0.12880149559350684, 0.14882463990943506, 0.12151670016464777, 0.13881830731406808, 0.12456743919756263, 0.12333424951066263, 0.11864840329508297, 0.07848835826735012, 0.1366801353287883, 0.09944460485712625, 0.10481132703716867, 0.11139867434394546, 0.1037665166950319, 0.06879661465063691, 0.19347356515936553, 0.14281487645348534, 0.15537571103777736, 0.13121487078024074, 0.07831163064111024, 0.1447607431327924, 0.1517453175620176, 0.1727138986461796, 0.17899543658131734, 0.17038054182194173, 0.19703839730937034, 0.16024733165977523, 0.0917821007897146, 0.09240864412277006, 0.21935957222012803, 0.1635170858935453, 0.112775425077416, 0.10263999589369632, 0.13083061639918014, 0.1891883896314539, 0.23687353008426726, 0.1532183916424401, 0.1545564690604806, 0.23915092897368595, 0.11500234308186918, 0.1819705285015516, 0.17007065063808113, 0.08443990765954368, 0.11068638326833025, 0.19868540111929178, 0.146625270426739, 0.14260725321946666, 0.13389567146077752, 0.2143035872722976, 0.08425825959420763, 0.09514456411125138, 0.11596317199291661, 0.10667614376870915, 0.1257524115499109, 0.1261669900850393, 0.16671817662427202, 0.09495970254647546, 0.15315364667912945, 0.10616498213494197, 0.1511565866530873, 0.13186724827392027, 0.17099563381634653, 0.20452073018532246, 0.13451916456688195, 0.22890008840477094, 0.1154592314560432, 0.1334790445980616, 0.33440280763898045, 0.1871873071650043, 0.20631972583942115, 0.12018599969451316, 0.15895163087407127, 0.13138048845576122, 0.09734204853884876, 0.11962505479459651, 0.09846418324741535, 0.10852315637748688, 0.0945539036183618, 0.16500607162015513, 0.16412158001912758, 0.07729070261120796, 0.15676247334340587, 0.16934086714172736, 0.10860212831175886, 0.06700933750835247, 0.2987554360879585, 0.1360627872054465, 0.07999694411410019, 0.1618540516938083, 0.0947867524519097, 0.09120917020482011, 0.20072893443284556, 0.1811807943158783, 0.17904354259371758, 0.06536666784086265, 0.10196442628512159, 0.17978618008783087, 0.2147170971147716, 0.11389264676836319, 0.06578799991984852, 0.1186339017294813, 0.1694325075368397, 0.159680939395912, 0.19716454757144675, 0.16127032286021858, 0.126247082662303, 0.13262288819532841, 0.2687329502077773, 0.09440372261451557, 0.24720432964386418, 0.10880230038310401, 0.17382652644300833, 0.08613077981863171, 0.14891942701069638, 0.10962827363982797, 0.14123514090897515, 0.08614014572231099, 0.10560658280155621, 0.15820581698790193, 0.12072646131855436, 0.19414814771153033, 0.18654407293070108, 0.08842394192470238, 0.12437267738278024, 0.09709255333291367, 0.14779774501221254, 0.13396176713285968, 0.1847181373159401, 0.0868241535499692], [0.059921641659457237, 0.053362718608696014, 0.05626052698062267, 0.02116585321346065, 0.048410315212095156, 0.04048766983032692, 0.030315478361444548, 0.025385411754541565, 0.08212307846406475, 0.05088381549285259, 0.02389425710134674, 0.020517064003797714, 0.013760104411630891, 0.05217041754804086, 0.00860772654050379, 0.02847463299985975, 0.06519091984955594, 0.04504487958911341, 0.011960110568907112, 0.014381728233274771, 0.04266628515324555, 0.10286112621542998, 0.027064142377639655, 0.018649406702024862, 0.09962554788216949, 0.009554724601912312, 0.017183247582579497, 0.018266300794493873, 0.05112439379445277, 0.04429990804055706, 0.05747369352320675, 0.020814559466089122, 0.049553092758287676, 0.030150428428896703, 0.018554779162514023, 0.04176309514150489, 0.07228312795632519, 0.05022014993301127, 0.07685382253839634, 0.026889759938057978, 0.07005976483924314, 0.03310406485979911, 0.047321001984528266, 0.03393951163161546, 0.07029069151030853, 0.004504501039264142, 0.03375342923391145, 0.020294835303502623, 0.027117309837194625, 0.03808841029240284, 0.04590293960063718, 0.024577207368565723, 0.030848397909721825, 0.05783001717645675, 0.00905383336430532, 0.043933439228567295, 0.02920052022091113, 0.05287620369927026, 0.03121995228866581, 0.08727008040295914, 0.06101785686041694, 0.031990672650863416, 0.12482876423746347, 0.03243303348426707, 0.011164797288074624, 0.047532521493849345, 0.06021965848049149, 0.07281848360435106, 0.08976270211860538, 0.04017596409539692, 0.055936134231160395, 0.04555748470011167, 0.10597633561701514, 0.02700038818147732, 0.017575635902176145, 0.05306899140123278, 0.022061154195398558, 0.02890335501433583, 0.04487814127060119, 0.04638161000912078, 0.01767797064530896, 0.030160549467836972, 0.04813639592612162, 0.013497108611773001, 0.01929770238348283, 0.023819790003472008, 0.027161961152160075, 0.039745362591929734, 0.018082207352563273, 0.023624057830602396, 0.013322181621333584, 0.11515797887113877, 0.11118810478365049, 0.016465414519188926, 0.029300476380740292, 0.06737182469805703, 0.008102781321213115, 0.05742468580137938, 0.03958744840929285, 0.04506075783865526, 0.02018915347434813, 0.05467728849907871, 0.006272571863519261, 0.010942428507405566, 0.03533204042469151, 0.007049366240607924, 0.03212929470464587, 0.014076456918701297, 0.031076099949132185, 0.010582747563603334, 0.02500136888556881, 0.05839330355229322, 0.05109206584165804, 0.024682579351065215, 0.07681666320422664, 0.06221833638846874, 0.038487392594106495, 0.03548264445271343, 0.06297691521467641, 0.05737808263802435, 0.0377997964824317, 0.030011210801603738, 0.014584575746994233, 0.05266325555567164, 0.050488733177189715, 0.035017585032619536, 0.045027869564364664, 0.06354262470267713, 0.020257533105905168, 0.0665387416665908, 0.08934099154430442, 0.08793689266894944, 0.026050697051687166, 0.06873180289403535, 0.06673473544651642, 0.02666988755663624, 0.03712115438247565, 0.009979092992580263, 0.04994376300601289, 0.03908311453415081, 0.042298992557334714, 0.010337102248740848, 0.01979367596504744, 0.022487386304419488, 0.06490761981694959, 0.01691694644250674, 0.033183838313561864, 0.04104896725038998, 0.06095807686506305, 0.018518066972319502, 0.020961762602382805, 0.09876110168988816, 0.03266181534854695, 0.030099029136181343, 0.030092143861111253, 0.010287767054251162, 0.00942321510592592, 0.08800879193586297, 0.03480071092781145, 0.03726491951965727, 0.05734718703024555, 0.03570235727238469, 0.027037107793148607, 0.020420575528987683, 0.042861800247919746, 0.023316712213272694, 0.02542511108913459, 0.04230363469105214, 0.026556281445664354, 0.024539385667594615, 0.05702414498955477, 0.023125124935177155, 0.036440612384467386, 0.019811122001556214, 0.03751888987608254, 0.02062193689198466, 0.04230161976011004, 0.049085580540122464, 0.10614628743496723, 0.02837663054378936, 0.03472348675131798, 0.029838991722499486, 0.02450917469104752, 0.015974058951542247, 0.07072464752127416, 0.0029519772670028033, 0.009500273226876743, 0.048140507424250245, 0.007297287165783928, 0.0818333588540554, 0.04796213223016821, 0.023943207306729164, 0.048109975468833, 0.05258386801870074, 0.028036461590090767, 0.01741195152135333, 0.039255096125998534, 0.07131816528271884, 0.047024168889038265, 0.0580364752386231, 0.07612481087562628, 0.03991607511125039, 0.0024650757450217498, 0.050662533030845225, 0.07130042053177021, 0.04051474708830938, 0.033573120745131746, 0.03380400288733654, 0.049882962557603605, 0.028561313993122894, 0.016918807377805933, 0.040846383199095726, 0.04380774167657364, 0.09389156650286168, 0.024947370220615994, 0.03262316058680881, 0.0452849458088167, 0.07858537923311815, 0.022484124565380625, 0.037627503188559785, 0.027866630371136125, 0.033345414994983, 0.033459464539191686, 0.008834589025354944, 0.03660188849607948, 0.01315139488724526, 0.020240588019078132, 0.09156304848147556, 0.016003112177713774, 0.08521273572114296, 0.057501301416778006, 0.07827951791114174, 0.01704513946606312, 0.040462358883814886, 0.018067718774545938, 0.07333466215641238, 0.12160117883468047, 0.02737369588430738, 0.05765878515376244, 0.021367014196584933, 0.01643258932745084, 0.03238772536860779, 0.05464192887302488, 0.02854125930753071, 0.038970968598732725, 0.020748127972183283, 0.0706577354867477, 0.004454154668565025, 0.015360748111561406, 0.0788312527583912, 0.036051341085112654, 0.025703130741021596, 0.03204042252036743, 0.04533556770184077, 0.04326837100961711, 0.06218843896931503, 0.03237137585529126, 0.041927822239813395, 0.04465184189029969, 0.019835145321849268, 0.05864502520125825, 0.03146338043734431, 0.0851544548640959, 0.02401940360869048, 0.05758957617217675, 0.023044369991112035, 0.106752354913624, 0.031507289604633115, 0.006348665192490444, 0.02727214410697343, 0.0031242547902365914, 0.09484404625254683, 0.011426370019762544, 0.02267731302708853, 0.044781509932363406, 0.050572929831105284, 0.041936486813938245, 0.009581732283550082, 0.0575757982005598, 0.07619279902428389, 0.023535857289971318, 0.040162334553315304, 0.05707822158001363, 0.05419901142886374, 0.024690898826520424, 0.05789855451439507, 0.041069457947742194, 0.06243159994482994, 0.05278291202557739, 0.017344338157272432, 0.04117660551855806, 0.034169514328823425, 0.05586401603068225, 0.021271054501994513, 0.04428519125212915, 0.030899392731953412, 0.04641377840016503, 0.047321161546278745, 0.0370455406664405, 0.10175457660807297, 0.023175422138592694, 0.03433540288824588, 0.05733802892791573, 0.04682481689087581, 0.019809871482721064, 0.020740908730658703, 0.05264082414214499, 0.07176634826464579, 0.030449697624135297, 0.017712693879730068, 0.024440589113510214, 0.03648966092441697, 0.03245818486902863, 0.024912967965065036, 0.028326932624622714, 0.07266956425155513, 0.08061919041210786, 0.025965364911826327, 0.01764906213793438, 0.01171600242741988, 0.030817661863693502, 0.020587640392477624, 0.023988298344193026, 0.035761213293881156, 0.07219065635581501, 0.02329006169020431, 0.022508177571580745, 0.03321097123262007, 0.03801944250881206, 0.033371182362316176, 0.10671945550711825, 0.008769767064222833, 0.03025426787644392, 0.04424175334861502, 0.07557355842436664, 0.015013740267022513, 0.03137412233627401, 0.03569895452528726, 0.023829035308153834, 0.059292675214237534, 0.026695044507505372, 0.019777844099735375, 0.05236568773398176, 0.05174976453417912, 0.03716593186254613, 0.05325020531017799, 0.008737319440115243, 0.023767847087583505, 0.05637402362481225, 0.003313867723591102, 0.056900384442997165, 0.0102170914033195, 0.095880359003786, 0.21252706384984776, 0.23652316216612235, 0.11449982746853493, 0.14022470684722066, 0.13633858412504196, 0.09025688341353089, 0.08306294912472367, 0.18300380586879328, 0.1597626053262502, 0.15282109030522406, 0.16437842248706147, 0.09422069415450096, 0.1077343721408397, 0.1165982945531141, 0.0824533416016493, 0.19693970651132986, 0.16545297810807824, 0.0677432028169278, 0.15246698196278885, 0.32390702865086496, 0.21226272569037974, 0.11728193130693398, 0.12945039983605966, 0.2841654955409467, 0.10118862963281572, 0.07349351144512184, 0.10724128922447562, 0.21920134633546695, 0.08407448898651637, 0.16333187551936135, 0.1192449193331413, 0.11017309909220785, 0.13110000116284937, 0.10404257336631417, 0.1393705839291215, 0.15176814602455124, 0.15659142314689234, 0.1587683946127072, 0.1407957894844003, 0.09728534845635295, 0.15004798129666597, 0.11056877512601204, 0.1086514959752094, 0.10599882269161753, 0.1287471258547157, 0.20953536266461015, 0.10783666235511191, 0.08304381655761972, 0.11056961375288665, 0.1284894670243375, 0.15869895927608013, 0.1532339322147891, 0.23581657820614055, 0.08579282060964033, 0.1940577689674683, 0.0899501092499122, 0.10735571355326101, 0.13998576498124748, 0.1252321808715351, 0.2126016200054437, 0.0724713588715531, 0.17657738586422056, 0.11452917198766954, 0.09636061018682085, 0.1425463822670281, 0.11320997480652295, 0.11766185896703973, 0.2889646083349362, 0.0677916056883987, 0.1814808594645001, 0.3007590863853693, 0.12445473665138707, 0.12066400217008777, 0.11934031499549747, 0.12733633280731738, 0.11402962496504188, 0.15007852809503675, 0.17438178649172187, 0.1005522083141841, 0.09308181659434922, 0.10177815463976003, 0.13203684386098757, 0.1308474928373471, 0.30651791486889124, 0.12892484053736553, 0.10011998150730506, 0.13895132986363024, 0.1209071594348643, 0.09120234986767173, 0.205997871235013, 0.23149937158450484, 0.24019873759243637, 0.15749887679703534, 0.06484956902568229, 0.1284307483001612, 0.10294996871380135, 0.13272862939629704, 0.16831189423101023, 0.13114773610141128, 0.22190702380612493, 0.15419634932186455, 0.14905195974279195, 0.06736126393661834, 0.08158427925081924, 0.08755292772548273, 0.1675216553849168, 0.1158099333406426, 0.07032761335722171, 0.11529607771080919, 0.12445183485397138, 0.13591113674920052, 0.11588826702791266, 0.12625396979274228, 0.12933177495142445, 0.19442919903667644, 0.165228656551335, 0.1277225761441514, 0.12385285488562658, 0.05647788719215896, 0.12189457949716598, 0.14044065697817132, 0.13811847689794376, 0.20265180937713012, 0.08043385387281887, 0.1289402029942721, 0.11001565246260725, 0.16620545648038387, 0.08730302433832549, 0.116770636086585, 0.11559649166883901, 0.1525323058012873, 0.1444899631314911, 0.16907473298488185, 0.278557738638483, 0.10887738346355036, 0.07181198292528279, 0.12870869744801894, 0.22355779772624373, 0.17238290078239515, 0.17634896765230224, 0.11875191063154489, 0.17177628411445767, 0.18913853215053678, 0.1837998631526716, 0.0861694234481547, 0.16028236103011295, 0.16795978968730196, 0.13750541838817298, 0.16063688497524709, 0.08157343647326343, 0.18113913014531136, 0.1312969671562314, 0.06871123798191547, 0.1777837023837492, 0.12695518060354516, 0.11979918490396813, 0.21120552148204297, 0.19606897432822734, 0.12930107972351834, 0.16613510088063776, 0.09208609932102263, 0.10678520979126915, 0.09835485747316852, 0.09539851962472312, 0.09341420969576575, 0.17470203805714846, 0.14502427977276966, 0.12685552501352504, 0.16800382873043418, 0.20921836170600727, 0.0956608317210339, 0.1692427255329676, 0.10263751712045632, 0.15971712651662529, 0.05999330343911424], [0.04050678384373896, 0.08590357130742632, 0.03571053945051972, 0.012786697952833492, 0.017707322585920338, 0.04585473710903898, 0.03732748999027535, 0.020347566751297563, 0.05285655162879266, 0.02049240985797951, 0.05815211668959819, 0.011656833776214626, 0.03123422007774934, 0.05189678027818445, 0.053987978026270866, 0.048402648826595396, 0.01029129318339983, 0.055094824492698535, 0.026397083347546868, 0.029901419329689816, 0.007567044858660665, 0.04440037257154472, 0.05246087930572685, 0.025513973996567074, 0.026449994766153395, 0.03439226253249217, 0.03909010556526482, 0.03157845414534677, 0.0402393101103371, 0.010816603862622287, 0.0669090065639466, 0.039774246979504824, 0.1291980844689533, 0.027635612786980346, 0.014841424708720297, 0.02918557707744185, 0.05460212007164955, 0.01242241383806686, 0.048366647242801264, 0.043931557884206995, 0.14570953440852463, 0.01156188896857202, 0.060945037330384366, 0.01884917430288624, 0.019258724787505344, 0.038200611888896674, 0.022601899690926075, 0.03550329842255451, 0.049446527773397975, 0.04054615106724668, 0.030060888311709277, 0.016519392775080632, 0.02070957896648906, 0.029162514838390052, 0.02133489033440128, 0.10063316178275272, 0.035869670755346306, 0.0687572437163908, 0.02034417699178448, 0.05822532213642262, 0.024656552232045215, 0.03834211347566452, 0.04242260467435699, 0.044769687519874424, 0.011130690963909728, 0.04430738517839927, 0.05417109925474506, 0.021451559659908526, 0.0235037037418806, 0.027029211341869086, 0.047008572655613534, 0.041869010747177526, 0.025459387179580517, 0.009575687490723794, 0.07800485647749156, 0.00982314550128649, 0.013927647032687673, 0.024162749432434794, 0.01122344550822163, 0.03672650251246523, 0.030123128526611254, 0.061837206449126825, 0.05130279125296511, 0.08545490592950955, 0.04179964220384136, 0.051582499290816486, 0.023997486132429913, 0.0356920636841096, 0.019705050544871483, 0.03991902885900345, 0.07251435148646124, 0.03881119904690422, 0.07494587218388915, 0.07924988341983408, 0.022254058785620145, 0.04815810374566354, 0.09158491957350634, 0.02594303739897441, 0.01209450701935566, 0.04336139179940801, 0.015873095326242037, 0.012765118153765798, 0.00746075075767294, 0.041674081949167885, 0.03405555384233594, 0.13148315716534853, 0.029890250007156283, 0.05158693733392283, 0.05190407558984589, 0.018455023382557556, 0.04787863319506869, 0.013874387732357718, 0.04282421417883597, 0.06382180581567809, 0.02344404249015497, 0.03399041554075666, 0.09649743253248744, 0.010094670433318242, 0.03754917321202811, 0.03832991627859883, 0.036902784850099124, 0.02029870931437472, 0.016367662537959404, 0.05321901284332853, 0.0220319525396917, 0.043231285890215077, 0.017876252095447853, 0.056369092053500935, 0.013372726516536204, 0.05600623378995806, 0.020001933735329658, 0.058688385179266334, 0.003812957861555333, 0.009535280332784168, 0.018703405366977677, 0.07301259975065477, 0.051126876278431155, 0.008445972671324853, 0.007812499534338713, 0.033101363442256115, 0.051308513211552054, 0.0033466901322753984, 0.011111245767096989, 0.024271641050290782, 0.017267440525756683, 0.05125112664245535, 0.025612963509047404, 0.06865882751299068, 0.03896467518643476, 0.021220388080109842, 0.04514597123488784, 0.054794930038042367, 0.018435673737258185, 0.014260561492847046, 0.02482331281498773, 0.054845214253873564, 0.018980462082254235, 0.03858146352285985, 0.03918468486517668, 0.02251235957373865, 0.02335072113055503, 0.052317166118882596, 0.02796743814542424, 0.07287364744115621, 0.03716291132150218, 0.012565450742840767, 0.04353017844550777, 0.05042470438638702, 0.026949308012262918, 0.0428183437907137, 0.04064117936650291, 0.06417549855541438, 0.057170719155692495, 0.059818160298164, 0.024752745703153778, 0.07555127172963694, 0.05649372091284022, 0.08505956386215985, 0.020732555858558044, 0.06670726113952696, 0.008017674608709058, 0.08290582161862403, 0.04785760072991252, 0.08141260565025732, 0.05212233380007092, 0.019327039481140673, 0.017838610365288332, 0.09357895163702779, 0.04765483485243749, 0.05269343870168086, 0.048530520871281624, 0.06434020338929258, 0.026101979456143454, 0.019512958606355824, 0.020588883489836007, 0.02119153523381101, 0.027780561649706215, 0.03197088328306563, 0.048005700009525754, 0.0451610071468167, 0.016027048295654822, 0.020888204635411967, 0.007391255121547147, 0.031452459734282456, 0.04917050449876115, 0.04745622500195168, 0.011203526264580432, 0.05395504522311967, 0.04994035654817708, 0.007380441566056106, 0.01657190343394177, 0.06158057920401916, 0.05636638692521956, 0.016729355629649945, 0.06752962013706565, 0.0220800455645076, 0.10645671296515502, 0.005851397954756976, 0.03557105279469397, 0.03593148052459583, 0.042413635819684714, 0.08133953379001468, 0.03018304953002371, 0.02233905139291892, 0.03200790160917677, 0.017872992211778183, 0.04809498037502635, 0.05841465885168873, 0.026421611328260042, 0.03805245323746931, 0.018388278331258334, 0.015360664619947784, 0.017575795463926625, 0.051332224829820916, 0.0350566553970566, 0.03388145341887139, 0.0146755008972832, 0.04862829140620306, 0.030126436649879906, 0.049133274660562165, 0.04968277564330492, 0.05249022382486146, 0.034858231083489954, 0.019545525901776273, 0.03527815679262858, 0.08024873255635612, 0.01448429675292573, 0.08839106478262693, 0.016990868061839137, 0.07651281310245395, 0.055564537178725004, 0.005537504275707761, 0.02114432350936113, 0.029439705140248407, 0.007076133188093081, 0.08710991009138525, 0.04481122923607472, 0.022723619331372902, 0.03465533161943313, 0.04789311991771683, 0.07564022555015981, 0.04280036155250855, 0.0210561563653755, 0.018813191272784024, 0.0037067479479446774, 0.022651501130894758, 0.017082738522731233, 0.05083159056084696, 0.023995688279683236, 0.06235822380403988, 0.042928382026730105, 0.09761429057107307, 0.05006077371945139, 0.02097698405123083, 0.027155189054610673, 0.029520081588998437, 0.04714978851552587, 0.051985170066473074, 0.01160981593784527, 0.07916127840871923, 0.026113384410564322, 0.05403679650044069, 0.03447309725743253, 0.030702072363055777, 0.09698446694528684, 0.02217499593825778, 0.0476173415518133, 0.027910420794796664, 0.03409921067941468, 0.00477207635412924, 0.015553686098428443, 0.017122205936175305, 0.0849609992292244, 0.0922052214446012, 0.02948710240161745, 0.06484844838269055, 0.056452476055710576, 0.017961795747396536, 0.009803990669752238, 0.028186089693917893, 0.06279934154008515, 0.04002786481578369, 0.06141599311376922, 0.08423813997069374, 0.018081713824358303, 0.09887143678497523, 0.04115497191378381, 0.08293734063045122, 0.023565652663819492, 0.01650406928092707, 0.032288192232954316, 0.058377807508804835, 0.02723058012634283, 0.01424824647983769, 0.03581896351533942, 0.04065677188918926, 0.008661396805109689, 0.04322964574384969, 0.05982989365293179, 0.02789459264022298, 0.03525582556903828, 0.06540159331052564, 0.005791970015707193, 0.0033370783921782277, 0.05062477997853421, 0.02338829421205446, 0.03645874676294625, 0.02105569808918517, 0.010475548970134696, 0.03617245216446463, 0.027099693106720224, 0.02184235978347715, 0.032087203799164854, 0.08947871188865975, 0.0918390903098043, 0.042296780957258306, 0.03224664309527725, 0.010920362601609668, 0.08918877705582418, 0.04289336378860753, 0.03719343956618104, 0.020084256466361694, 0.009030573528434616, 0.016371905767300632, 0.007649439485248877, 0.050392510020174086, 0.02118703596352134, 0.03315872774692252, 0.03138272382784635, 0.030166713004291523, 0.011038926259061554, 0.00829396691187867, 0.1547110584215261, 0.17359782621497288, 0.12242856959346682, 0.14939695451175794, 0.09774078222108074, 0.14477324089966714, 0.17082433128962293, 0.0962162773066666, 0.1568927351036109, 0.15243717731209472, 0.21562524838373065, 0.16307231679093093, 0.16266740101855248, 0.1398795933346264, 0.23169903899542987, 0.14769175148103386, 0.14119114639470354, 0.14506502368021756, 0.070007079775678, 0.2691917755873874, 0.11874299743794836, 0.1348511123796925, 0.12237868242664263, 0.14899405738105997, 0.1840388198615983, 0.08317136947880499, 0.10969660317641683, 0.17176248016767204, 0.1354102315963246, 0.06406013169907965, 0.14593277242965996, 0.10073226818349212, 0.16233607660979033, 0.18304594501387328, 0.1229277381207794, 0.24548968649469316, 0.2308258874109015, 0.0708719044632744, 0.13848582515493035, 0.099674789380515, 0.33144478511530906, 0.08251088031101972, 0.2004364095046185, 0.08695797019754536, 0.14154523989418522, 0.18902198527939618, 0.09267805857234634, 0.08895629187463783, 0.1688517621369101, 0.12235888934810646, 0.15313130803406239, 0.11759435321437195, 0.18999636580701917, 0.0817394103796687, 0.0702449752134271, 0.1488353416789323, 0.04762918622873258, 0.16326603217748925, 0.08393224896281026, 0.13033211580477655, 0.05755638732807711, 0.10550619248533621, 0.10605892181047238, 0.14117570972302929, 0.16142287873663008, 0.20789811067515984, 0.13571108342148364, 0.11217644510907121, 0.21313457109499723, 0.11362911012838595, 0.15748014498967677, 0.1912830420769751, 0.10932808232610114, 0.17851361946668476, 0.14995040372014046, 0.07781740481732413, 0.15355835465015844, 0.11571009221370332, 0.08310289893415757, 0.20586925704265013, 0.11471847159555182, 0.12723945284960791, 0.33233384834602475, 0.21454563131555915, 0.2205101979780011, 0.14930687262676656, 0.1464190275873989, 0.11673027067445219, 0.10370048781624064, 0.10471999092260376, 0.2057138958480209, 0.23334855126449838, 0.17497790919151157, 0.14296893146820366, 0.15016136661870405, 0.1661954226437956, 0.12142845138441771, 0.13504024129360914, 0.16797953081550077, 0.14004627970280126, 0.1323685541865416, 0.15444550313986838, 0.054228578592301346, 0.14958151179598644, 0.09965461038518697, 0.15984772966476157, 0.12045880575897172, 0.11498228283016942, 0.23753643123200163, 0.1695286008180119, 0.15381083328975365, 0.11639944350463338, 0.15183344017714262, 0.1406027123448439, 0.1485117504489608, 0.07346957718254998, 0.1968503964599222, 0.20718876592582092, 0.08275241227238439, 0.20419103850144893, 0.1539404271170497, 0.10836702334927395, 0.09605301223928109, 0.09339919604826719, 0.07268702698638663, 0.1224739667668473, 0.10493502079043537, 0.16155073593836278, 0.11839409155072644, 0.18271180044393986, 0.13338415359612554, 0.15272639226168394, 0.1177127702976577, 0.11052901827497408, 0.12220425545820035, 0.11366399106918834, 0.17492910556029528, 0.07805492175975814, 0.23160110518801957, 0.09661121119279414, 0.2102671202737838, 0.10755399314803071, 0.1509425661060959, 0.10764512888272293, 0.13440055452520028, 0.1706941140582785, 0.15022758103441447, 0.1436632254626602, 0.12268311882507987, 0.1681452227057889, 0.12678086495725438, 0.20329890277935192, 0.10382630411186256, 0.10336870327591896, 0.1057062680774834, 0.10283008217811584, 0.15683996840380132, 0.1413408969528973, 0.1666743156965822, 0.17352077644318342, 0.1544310906319879, 0.15263316367054358, 0.21797864319523796, 0.20253294700523838, 0.11387612656108104, 0.10510558116948232, 0.14904654206475243, 0.10501515789655969, 0.08669405506225303, 0.14374590071383864, 0.12362554247374646, 0.15206632611807436, 0.15746739489259198, 0.11383589473553002, 0.11111615356639959, 0.11140665985294618], [0.05145262344740331, 0.02766358433291316, 0.02713707508519292, 0.0193964173013228, 0.023627013433724642, 0.028761712419509422, 0.034024335400317796, 0.01691367542662192, 0.027804304809251335, 0.010654169072950026, 0.045057202951284125, 0.021142095210961998, 0.07176214770879596, 0.026380277413409203, 0.06569972887518816, 0.017311819101450965, 0.02545360584917944, 0.012974119927093852, 0.027188576423213817, 0.042851265461649746, 0.05266376021609176, 0.04022514993266668, 0.007378148793577566, 0.06738110154401511, 0.06936953039257787, 0.056561504970886745, 0.06805966200772673, 0.042187047001789324, 0.028646909595408943, 0.03669414116302505, 0.048148396454053, 0.006656878194917226, 0.007054706456983695, 0.0579427234333707, 0.020979928522137925, 0.03419901469897013, 0.01440430065485998, 0.01370889807731146, 0.06718066972098313, 0.0443875408382155, 0.07637420218088664, 0.025137090997304767, 0.0821965881914366, 0.06797488647862338, 0.09248081798432395, 0.03149896641843952, 0.06737001385772601, 0.01756416415446438, 0.025719871737237554, 0.10668622955563478, 0.036258088584872894, 0.031998301928979345, 0.06592438439838588, 0.03988839300291147, 0.026151363817916717, 0.04420318393385969, 0.04825450501812156, 0.036630064132623374, 0.063005910924403, 0.10916425322648138, 0.004571620411297772, 0.05308340390911326, 0.015144563276408007, 0.07593491754960269, 0.1043227563786786, 0.02183900898671709, 0.009989348545786925, 0.022720314918842632, 0.06068929324101191, 0.06444165497669019, 0.041242994338972494, 0.05781532636319753, 0.036659672114183195, 0.09868397028185427, 0.04874306825513486, 0.030157258042891044, 0.03840254656097386, 0.05588557913142722, 0.015863736844039522, 0.02394473984168144, 0.07266289234394208, 0.07148312986828387, 0.04840438545215875, 0.037073233906994574, 0.036061649516341276, 0.02921749128290685, 0.05323617500835098, 0.03547226922819391, 0.025615520207793452, 0.03140943743346725, 0.04998203927243594, 0.012126295987400226, 0.047735242842463776, 0.005931503983447328, 0.011546942114364356, 0.041793326527113095, 0.05122863956785295, 0.036467533791437745, 0.03229761750844773, 0.07042597761028446, 0.06861397952889092, 0.024067190497589763, 0.05487646980327554, 0.06724558537825942, 0.015454931290150853, 0.03321209558635019, 0.02030702878982993, 0.012862532457802445, 0.0518316568195587, 0.006860645507913432, 0.02156806571292691, 0.030204972572391853, 0.05815168253320735, 0.02540492838306818, 0.022947952020331286, 0.021925612054474186, 0.015329854359151796, 0.03636788562289439, 0.018222922262793873, 0.06808093938161619, 0.044260726353968494, 0.06511365485494025, 0.020366766111692414, 0.03889302824973129, 0.013397719267231878, 0.017613600466575008, 0.06471003041951917, 0.04655736171116587, 0.04642399035219569, 0.05147915151610505, 0.014229029493435519, 0.07373224550974555, 0.05970064863504376, 0.014159121965349186, 0.04774073102453258, 0.0444700045773061, 0.04790356193552725, 0.0976741299382411, 0.08322337918798439, 0.031043655108078383, 0.022875846807437483, 0.07344378012930974, 0.010845163560588844, 0.009563888270349707, 0.05597995062998962, 0.024867439060471952, 0.02599458697659429, 0.01719657284411369, 0.018284283032699022, 0.04452601817320101, 0.06844336719950661, 0.02358216544962488, 0.06618076673476025, 0.024413693681708537, 0.047742712558829226, 0.05048410217568744, 0.0303807335512829, 0.04983920181985013, 0.05471508608025033, 0.03347246325574815, 0.029032690945314243, 0.06815669781644829, 0.04929497750708833, 0.0920946265978273, 0.03198612328560557, 0.064601224148646, 0.0464663929597009, 0.03559423377737403, 0.027641121378110256, 0.006613581763303955, 0.025383036881976295, 0.022644092641712632, 0.07805984219885431, 0.022598940377065446, 0.05348844584659673, 0.032806664021336474, 0.02436562663206132, 0.042427116932231, 0.05860614408447873, 0.023521185030404013, 0.005443951458801166, 0.060618804054684006, 0.1019231257669162, 0.08959464277722873, 0.02770929320831783, 0.046712589319213293, 0.01788729896361474, 0.0272559059158084, 0.03308483210275881, 0.0016615139566056314, 0.055089362285798416, 0.06242283518076874, 0.005323533823684556, 0.058624616140150465, 0.046145803717081435, 0.04114189156098291, 0.02203371699579293, 0.1127619031467475, 0.04544130148133263, 0.028400080555002205, 0.03720534732565284, 0.01948248602275271, 0.057988046391983517, 0.03303684854472522, 0.027315381630614866, 0.05766582071373705, 0.014299485283117974, 0.021819124995090533, 0.017606644687475637, 0.0650226601283066, 0.04980089215678163, 0.019456123081909027, 0.05279812234221026, 0.010486739629413933, 0.04882790686679073, 0.06473509274655953, 0.044915374819538556, 0.03411675133975223, 0.08137389522744343, 0.0923898900509812, 0.024479386738676112, 0.03116176048933994, 0.0180002686829539, 0.05396768028731458, 0.025878505803120788, 0.03840154466161039, 0.024553649745939765, 0.13019312638789415, 0.08002064088941552, 0.06696035576169379, 0.006244906917345361, 0.053215417137835175, 0.04581093555316329, 0.06655831952230074, 0.044357227816362865, 0.043904154081246816, 0.06492851869552396, 0.012004134769085795, 0.011127667639811989, 0.06120623249444179, 0.017686935789242852, 0.0362776515976293, 0.036287915499997325, 0.01006041753498721, 0.05104604897496756, 0.026844138265005313, 0.038316275604302064, 0.058902086602756754, 0.007501087875425583, 0.026230580660921987, 0.03394792387553025, 0.010748576751211658, 0.02662154962308705, 0.04892728044069372, 0.018015362111327704, 0.00691415435539966, 0.11668027960695326, 0.020534092582238372, 0.07192125674919225, 0.045536018078564666, 0.06887959418236278, 0.008724327217350947, 0.03854102760669775, 0.06654228913248517, 0.03516681979817804, 0.056606467987876385, 0.02769682883808855, 0.09824888620642014, 0.03386699638213031, 0.04383923100249376, 0.05317040588124655, 0.012332149199210107, 0.038454203750006855, 0.03314305729873013, 0.024591786859673448, 0.033830601460067555, 0.05956379660347011, 0.005814127298435778, 0.05013479552872013, 0.06719276672811247, 0.03558136122592259, 0.074862425099127, 0.06493027758551762, 0.03176062171405647, 0.07128772980649956, 0.02932651092123706, 0.0386960288597038, 0.026616551258484833, 0.0554016914247768, 0.025147289961751085, 0.0556315976427868, 0.035677484193001874, 0.11824022949440405, 0.02230471593065886, 0.026477073879505042, 0.03939748086850159, 0.030004297695995774, 0.053583822955260985, 0.027165721985511482, 0.02112918740749592, 0.03203472282621078, 0.05595712587819435, 0.03991020472312812, 0.05373450490878895, 0.02928416768554598, 0.019825189410767052, 0.03512444316584151, 0.10131454982911237, 0.033793442125897855, 0.01698908134130761, 0.05305911341565661, 0.009337395003967686, 0.025561163456586655, 0.054530343259102665, 0.021185414370847866, 0.049250303927692585, 0.03257087999372743, 0.05026023332902696, 0.04432330053532496, 0.008841209910315229, 0.0072827160238375654, 0.025918279352481477, 0.04246921896992717, 0.03332940315885935, 0.018944304647448007, 0.02482474516000366, 0.06637107566348277, 0.057443291443632916, 0.0343823177536251, 0.041447585899732076, 0.016394183185184374, 0.03830520647170488, 0.0878664999618195, 0.017730572217260487, 0.05469328549224883, 0.024565702224208508, 0.08738493517739698, 0.01572967528773006, 0.04256685591826681, 0.05657108980813064, 0.06630658303038217, 0.03542331716744229, 0.019100610224995762, 0.032167203607968986, 0.028818093378504273, 0.0072249523509526625, 0.007615867507411167, 0.06522122173919342, 0.011796906728704926, 0.02111007896019146, 0.011827522175735794, 0.017587486145203002, 0.16021164919948205, 0.20489901769906282, 0.0858446373604238, 0.09875701245618984, 0.07924099249066785, 0.23055522615322843, 0.13761721551418304, 0.17490068130427971, 0.10766506296931766, 0.07983672185218893, 0.17711087130010128, 0.11209712436539121, 0.2159384495462291, 0.19062086823396385, 0.09230742260115221, 0.14150482253171504, 0.11950831496505998, 0.09992050705477595, 0.1287623547250405, 0.14376304432516918, 0.19253669277532026, 0.22390004654880613, 0.1191743633535225, 0.23053061653627083, 0.19491129816742614, 0.19985686638392508, 0.14647600968601182, 0.1425821240991354, 0.12158870333223604, 0.11353261608746834, 0.14167864836053923, 0.08040223838179372, 0.10094571727677248, 0.12266273944987915, 0.09508488801657222, 0.07450164484907873, 0.17155252658994868, 0.07636498470674269, 0.16209475987125188, 0.20694017614005134, 0.2557681646430865, 0.12784960214048624, 0.22630445659160614, 0.25346649752464145, 0.12066898198099807, 0.09963287287973799, 0.1717021138756536, 0.10168229884584434, 0.10887622571317479, 0.18106910109054297, 0.1520846868515946, 0.1895973426871933, 0.21832138183526695, 0.1307172459200956, 0.1607892182073556, 0.16258261806797236, 0.21049262926680967, 0.1680072129238397, 0.1681617577560246, 0.1306474840384908, 0.1194879504328128, 0.16611856583040208, 0.07621035823831335, 0.18964201997732744, 0.1484516661730595, 0.08407726461882703, 0.1566940324846655, 0.09870098030660301, 0.17553310986841097, 0.1524612822686322, 0.07861482765292749, 0.13975595153169706, 0.10725819534854963, 0.2297434353386052, 0.18934970285044983, 0.14886032236972824, 0.1515687903156504, 0.1352081447839737, 0.10476751063833944, 0.07793317985488102, 0.33381217683199793, 0.1427518532727845, 0.1434018262079917, 0.1058076974004507, 0.09618304393370636, 0.08185521510313265, 0.1471238600788638, 0.1380419169436209, 0.0937679543858394, 0.06608996496652253, 0.19740570103749633, 0.2619539952138439, 0.07646637692232616, 0.13029312336584553, 0.23113527393434197, 0.07373021202511154, 0.11272418720182031, 0.10611286110361107, 0.1487575497594662, 0.1690366756520234, 0.18239411670947447, 0.07967936428030953, 0.16350733407307416, 0.1645189110422507, 0.18211978924227878, 0.11862178245792165, 0.1396161605953239, 0.11026112522813492, 0.19591993623180315, 0.12010568447294645, 0.0932509297854267, 0.1590886016492732, 0.12695469078607857, 0.04432916350197047, 0.1225905136379879, 0.07123085160856135, 0.21003840520279482, 0.1444281273870729, 0.12006574950646609, 0.14890071004629135, 0.13536337239202112, 0.13284018903505057, 0.13302545878104866, 0.0951350868854206, 0.10564639902440831, 0.18570304149761796, 0.14184828847646713, 0.12984948232769966, 0.11030967652914114, 0.146860976528842, 0.13175395200960338, 0.2837836754042655, 0.10248626000247896, 0.08802366457530297, 0.10328384611057118, 0.13286459085065871, 0.13172540900995955, 0.2032538247294724, 0.10726290798629634, 0.10812113498104736, 0.10218095529126003, 0.1778948909486644, 0.14937204803572968, 0.10990145077812485, 0.15083231264725327, 0.11305349296890199, 0.148765119665768, 0.06742471014149487, 0.09288620873121545, 0.12317612010519952, 0.12624087830772623, 0.14131824660580605, 0.15147998492466286, 0.08250804530689493, 0.15427926206029952, 0.2234311428037472, 0.14215718518244103, 0.10266873185173608, 0.11680697905831039, 0.08212832544813864, 0.14182102197082713, 0.0708856713026762, 0.12600653775734827, 0.2007064622011967, 0.1273078640224412, 0.13041505822911859, 0.08744602877413854, 0.09535387944197282, 0.124536283838097, 0.07620568270795047, 0.1347397011704743, 0.14635505445767194, 0.0871213391656056, 0.14629684039391577, 0.19300440908409655, 0.0974482498713769], [0.0162695302060456, 0.03872237510222476, 0.03860584678477608, 0.1038009746116586, 0.05267380518489517, 0.08598629850894213, 0.08011953948880546, 0.04324603978602681, 0.05081229472125415, 0.029800440861436073, 0.05211000672716182, 0.04632280964870006, 0.12363081172225066, 0.10817880727699958, 0.03074315951380413, 0.014633858991146553, 0.037216327400528826, 0.0739212408370804, 0.057899485909729265, 0.04131935762416106, 0.031643852198612876, 0.015721415184088983, 0.04379895835882053, 0.01850031108915573, 0.02566005648986902, 0.06565289935679175, 0.03985052491771057, 0.05522376151930075, 0.07709240817348473, 0.022820844387752004, 0.0701234040025156, 0.02580081592896022, 0.09375878886203282, 0.017803517912398092, 0.02492042098310776, 0.048191504101851024, 0.037947424498270266, 0.022411954414565116, 0.028226818758412264, 0.018232310430903453, 0.0164192306692712, 0.05030915570387151, 0.028397844835126307, 0.04108067922061309, 0.0089736981135502, 0.027374666242394596, 0.011574253148864955, 0.09361543561681174, 0.04169725551037118, 0.026587689135340042, 0.018819091346813366, 0.01869685776910046, 0.03330094550619833, 0.05401610913395416, 0.039545468825963326, 0.04353459422418382, 0.014838948718534084, 0.03281091652752366, 0.03718339830811601, 0.013284011110954452, 0.058333408524049446, 0.025613778016122524, 0.03982763708336279, 0.06694820680422708, 0.05054784895037301, 0.057542991562513635, 0.04201020063192118, 0.026788022623804864, 0.03060053913941374, 0.05180919572012499, 0.017723492128425278, 0.013247299848444527, 0.05937355075730011, 0.026804941735463217, 0.0947495485888794, 0.021909008355578408, 0.004434145903360331, 0.016828790430736262, 0.05066901198006235, 0.0621864982531406, 0.010780718239402631, 0.03044820776267443, 0.03011015578522347, 0.09332807603641413, 0.035417535837041214, 0.03936356100894045, 0.049902885511983186, 0.03573438836610876, 0.035844998055836186, 0.027142236722283997, 0.0112981473102991, 0.0069528777657978935, 0.06074958531826269, 0.08768220985075459, 0.05034847097704187, 0.006489541519840714, 0.031109468764043413, 0.04760504045407288, 0.06483337536337785, 0.034294106080778874, 0.08123840132611804, 0.02109490018483484, 0.06124464234744664, 0.043685150012606755, 0.08589293633121997, 0.029643535999639425, 0.0589548161951825, 0.03738891384273302, 0.045245667643030174, 0.040506104778614827, 0.04822864859306719, 0.05369828439143021, 0.027820691429951694, 0.05142072965099942, 0.007243826557896682, 0.060549376139533706, 0.08941399661125615, 0.0457126232504379, 0.047433211002498865, 0.04205802833894268, 0.05557913151278626, 0.02387395936239045, 0.05972237129753921, 0.043949584651272744, 0.015430681614816422, 0.003977053902417538, 0.0017760034552338766, 0.03252769813116174, 0.015295863995561376, 0.0751768508052919, 0.04025287285912782, 0.07974525957251899, 0.04107024462427944, 0.05191272161027882, 0.06392839306499809, 0.028310451380093582, 0.0938274004147388, 0.027086920745205134, 0.006510023868031567, 0.03709177646669559, 0.07401058057439514, 0.010357043756812345, 0.0679738845792599, 0.026442890557518695, 0.036374602059368044, 0.1373144192621112, 0.02630196413520025, 0.03385001604328863, 0.06312140394584276, 0.05761174783401657, 0.011711668284988264, 0.03529142639308702, 0.04703637350758072, 0.036923821025993675, 0.06469258994911797, 0.04943276093399618, 0.022774762583139818, 0.03895272660884075, 0.007441719772032229, 0.043682430041371845, 0.04213432112010196, 0.018649948469828814, 0.05094672735140193, 0.06511015933938324, 0.07192921999376267, 0.042668916066759266, 0.03203968037269078, 0.026521719628362916, 0.06136143041658215, 0.0264367362979101, 0.0487854857055936, 0.05767088587163016, 0.08219655850552954, 0.0280714891050593, 0.005257119028101442, 0.021333886579668615, 0.043382765652495436, 0.03392841281311121, 0.0787084866897203, 0.0529702560743317, 0.0791732121433597, 0.05174713733140379, 0.006766544429410715, 0.032535319987800904, 0.012208053758513415, 0.04078228390426375, 0.10255755070829764, 0.036979352225898765, 0.044106804925831966, 0.03418644642806612, 0.06553664934472181, 0.017081764453905635, 0.11380435345927253, 0.007368326469077147, 0.09372911037644371, 0.07148340446292423, 0.029621195499203168, 0.0344196997320978, 0.07443442111252807, 0.08670927651110105, 0.026549544600129593, 0.0597642247157637, 0.02630710350786103, 0.04340166815381963, 0.03499995902529918, 0.08775770111242309, 0.04071912342624273, 0.03453163415542804, 0.07956527391797863, 0.020161933352937922, 0.014893449260853231, 0.017488255434727762, 0.07171625329647213, 0.01019222389004426, 0.058388078832649626, 0.029351764351304155, 0.029843914016964845, 0.054834152542753145, 0.019705215672729537, 0.007130048361432273, 0.02632684092532145, 0.0376343161042314, 0.019107634652755223, 0.03939358830393758, 0.015817139246792067, 0.07311402907362208, 0.02506909913790878, 0.0766856964037288, 0.05150648110429756, 0.0317074542545015, 0.022414997220039368, 0.045334250389714725, 0.04883512054220773, 0.031474468123633415, 0.00400307174459158, 0.04866818926529959, 0.059827574441442266, 0.054944825315033086, 0.01699513912171824, 0.022188137518242, 0.005723475815102574, 0.0677620162605308, 0.037421019151224755, 0.013324341271072626, 0.09579890829627402, 0.019077303077210672, 0.05741062581364531, 0.025242989904654678, 0.02699039145227289, 0.014896120064804563, 0.04529962177912239, 0.010613954873406328, 0.04772908301674761, 0.10453992363181897, 0.019630642818810884, 0.024709636199986562, 0.029526092985179275, 0.04551215432002209, 0.01317608985118568, 0.05015327871660702, 0.04650288065022323, 0.035359514731680974, 0.04542797993053682, 0.031836825437494554, 0.02724556779867271, 0.036305118483141996, 0.03577769639377948, 0.01749488466884941, 0.030432769235630985, 0.021847899915883318, 0.05816420256451238, 0.05763125518569723, 0.01540835317427991, 0.024856646377884317, 0.047717902561998926, 0.0077747372051817365, 0.017083189377444796, 0.03464359455392696, 0.06794859960791655, 0.023198707021947484, 0.06810008679167368, 0.054873582848813385, 0.009627639683458256, 0.08583069240557961, 0.09652593842474744, 0.00455208940365992, 0.022392894206859637, 0.005994438570269267, 0.004074805883647059, 0.06054234429029748, 0.0379553840321023, 0.06839611465693451, 0.03497269623039756, 0.021454149755300023, 0.038276674604276195, 0.01758521331794327, 0.05254664189124014, 0.07640296782483347, 0.032828457187861204, 0.050074640748789534, 0.006122825943748467, 0.047647209285059944, 0.028408856451278552, 0.01556687962875003, 0.06448295549489558, 0.026440639994689263, 0.06055307945644017, 0.015682138873671647, 0.02624298751470633, 0.020545367660815828, 0.008495243855577428, 0.04775463887199294, 0.027533409775060136, 0.00917364197448478, 0.015166095763561316, 0.023947572990437038, 0.0898237363435328, 0.02771763494820334, 0.10121124287252314, 0.060534748408827, 0.03164596731949132, 0.056951177029986866, 0.020585128222592175, 0.027339789012330584, 0.015948831496643834, 0.00963525875704363, 0.039681890411884524, 0.028327619111223612, 0.04969622706994414, 0.057174930843757465, 0.05392791601479985, 0.08701050683157519, 0.047328894725069404, 0.06219118491571862, 0.02250064291729359, 0.03615228801209014, 0.10409363312646747, 0.02816368611092912, 0.0069415345024026465, 0.02643774376338115, 0.059900238120462745, 0.03287308994913474, 0.017722915108606685, 0.03628976715845056, 0.09579667443176731, 0.01605247613042593, 0.003830880496025202, 0.029057673491479363, 0.006008978170939372, 0.045459324537659995, 0.025155268049275037, 0.0743194847018458, 0.14575321722077206, 0.13106129074003547, 0.15338215394876897, 0.16355514322640374, 0.1287645217962563, 0.2517060044920072, 0.10964762142975815, 0.12562376767164096, 0.12952088902238756, 0.1173606954398565, 0.20089842611923814, 0.08628561408841051, 0.2937596244737506, 0.21750438114395365, 0.18080642534187064, 0.12237701259437017, 0.22621523559791967, 0.1421480716089718, 0.16863891418324783, 0.14794378483202308, 0.17212804727023467, 0.08280060734250583, 0.14556640380760655, 0.1282735465792939, 0.11772356112487614, 0.15114808164071292, 0.10698688100092113, 0.1473052112851292, 0.12506237748311833, 0.1811794881359674, 0.09438346198294312, 0.15240251901559532, 0.23441909928806126, 0.18361168418778107, 0.0964010127063375, 0.19251601654104888, 0.1917566213523969, 0.11426582830608822, 0.10466461186297238, 0.109182220621733, 0.14382379653397948, 0.10180286815739237, 0.12477920361561701, 0.09074892732314765, 0.07454400663846172, 0.13122640375513583, 0.1062418389483355, 0.20687081501819193, 0.11258711252594367, 0.10488108891877346, 0.15540156746283174, 0.14341004920424893, 0.1327536694589071, 0.16108407347928733, 0.22688932833261788, 0.11040466401027516, 0.09474200836848468, 0.09004536390420981, 0.09748157230205834, 0.14335900428704917, 0.181065954384394, 0.11429248625063337, 0.22201309155207127, 0.2254950109636411, 0.08410333626670763, 0.20984414062695578, 0.06742768615367822, 0.11109331768238917, 0.13775838684523478, 0.1659896844648756, 0.1363194070290774, 0.15233280166285113, 0.1585511234588921, 0.22674538136925548, 0.10775805407320149, 0.13096752780256793, 0.13030729838646948, 0.1809901514207013, 0.13398603536188602, 0.1516100240405649, 0.11862237617606297, 0.09649968123994768, 0.07486721937311813, 0.14885419222991914, 0.13183883886085823, 0.09707960285595618, 0.1014757294615265, 0.10430142705445178, 0.12547164224088192, 0.11320765930577181, 0.10078303108457476, 0.14174765325151384, 0.10839924740139395, 0.16015187662560493, 0.21771749627077952, 0.1253203777014278, 0.11276263045147061, 0.11018069868441671, 0.24156939529348165, 0.07272745919181034, 0.1871047803433612, 0.10221851538517512, 0.2562791184755042, 0.07647143094800413, 0.18035404180409387, 0.11891793648828752, 0.1407472975552082, 0.17074925563065335, 0.14548301609465852, 0.15778368338942528, 0.19928461115341634, 0.08222997741540894, 0.10816112931934185, 0.13219386746641248, 0.10060788423288614, 0.1807431795168668, 0.31224658247083426, 0.14135183620965108, 0.12032605780404992, 0.1472437466145493, 0.13746951328357682, 0.19149583065882325, 0.1058725907932967, 0.11152032719110139, 0.10810793217387982, 0.1331349997781217, 0.12725493405014277, 0.1659570002811961, 0.17322844447335228, 0.24325803358806297, 0.25819053465966135, 0.11268763642874546, 0.11640060867648572, 0.13663824851391837, 0.1475543502601795, 0.14423614862607792, 0.20749380346387625, 0.14483192993793637, 0.1244175921601709, 0.1627403689781204, 0.148651318741031, 0.11114080771221779, 0.1630087147350423, 0.18682650465052575, 0.09924840327585116, 0.18232919363072142, 0.08323621834279038, 0.07972318810061552, 0.1514527332619764, 0.2569290914107114, 0.0948614718799945, 0.07543753017671406, 0.17895911587402225, 0.0832766282837838, 0.17791831312933937, 0.1422374410321936, 0.15174954780377448, 0.19286041759187356, 0.08991896131192334, 0.08653332071844488, 0.3538732894230634, 0.11876302800374106, 0.13359493837924674, 0.11069466563640162, 0.17120914970291778, 0.24777320068096742, 0.13224706461187452, 0.11609228342422284, 0.17027284135110676, 0.15223572874674574, 0.177679282205645, 0.15061382437124848, 0.1672608795342967, 0.2020537422504276, 0.08374779557925649, 0.16868660459294915], [0.050152425246778876, 0.012560044197016396, 0.08599387583672069, 0.020858871248492505, 0.05468816467327997, 0.031400646694237366, 0.04858120584685821, 0.03449876072409097, 0.03621654315793421, 0.04948645531840157, 0.0382077105314238, 0.03862183635646943, 0.05347197387891356, 0.03993649530457333, 0.03544778948707972, 0.053866265807300806, 0.038439011987065896, 0.031456645447178744, 0.03871003689710051, 0.04335518373409286, 0.04054582452226896, 0.014807879633735865, 0.052818182593910024, 0.04942912441038061, 0.0396498927148059, 0.035022279116674326, 0.060210875162738375, 0.06171707500470802, 0.01792173647118034, 0.037117862957529724, 0.02031618689215975, 0.02574171870946884, 0.021246177711873315, 0.06376217424985953, 0.06239291178644635, 0.05118477864016313, 0.02761268970061792, 0.040711828114581294, 0.029108486487530172, 0.005024591173423687, 0.028971962856303435, 0.019086232969129924, 0.07926044418127276, 0.02464136417984264, 0.013745781889156206, 0.017050388305506203, 0.06660392449703068, 0.04222259216476232, 0.03482864165562205, 0.02265931965666823, 0.033757603814592585, 0.04362701016361825, 0.02863669207727071, 0.0024578205557190813, 0.020400630310177803, 0.04144099562836345, 0.007118788125808351, 0.010765311253635446, 0.07358066926826723, 0.016453779498988297, 0.034116254100808874, 0.04387803048302885, 0.04873566904279869, 0.022253483621170744, 0.0816438885522075, 0.01830060842621606, 0.008817522411845857, 0.011872993563883938, 0.03695985229569487, 0.008754820210015168, 0.04213380532746669, 0.03204191794793587, 0.09381762632983737, 0.05460281026898883, 0.01297201130000758, 0.04518077796092257, 0.02355256860028021, 0.024627012899145484, 0.07044689875328913, 0.046468181535601616, 0.05199335966608487, 0.05345326804672368, 0.021187650090723764, 0.06108683577622287, 0.025829822770901956, 0.047444651208934374, 0.03835145340417512, 0.04667489934945479, 0.043758240426541306, 0.02566585266322363, 0.03920051487511955, 0.074209045706084, 0.035765732973231934, 0.0608154249493964, 0.024213842589233536, 0.007051640923236846, 0.07814468452124856, 0.08001864451216534, 0.043315998336765915, 0.03789175971178338, 0.03314387366117444, 0.016377145329897758, 0.0414379528228892, 0.018251372493978124, 0.03762748834560625, 0.009421417253179243, 0.06248958394280635, 0.02314623532583937, 0.017144546436611563, 0.009691859577287687, 0.0386367164173862, 0.01862461711425567, 0.02127053499862086, 0.03523238112393301, 0.04587390307278838, 0.02806127715302864, 0.05959242123935837, 0.036775725457118824, 0.023498146911151707, 0.09587814740370959, 0.024738130960031413, 0.06722358812112361, 0.05378726789786015, 0.019420533390075434, 0.0504309940879466, 0.01660270256252261, 0.04838740140257869, 0.10840982300578617, 0.03847378902719356, 0.031270900726667605, 0.049130165061797015, 0.018601417577883694, 0.07037404953734949, 0.04776761903485749, 0.030757727872696705, 0.03535850912157912, 0.03707167168613523, 0.026233413809677586, 0.11135577820823528, 0.04467625854886137, 0.04216400702716783, 0.04131030713324435, 0.06603103101952001, 0.04177686569164507, 0.006355676632665563, 0.08682123690959997, 0.027779298143286724, 0.07173867357778363, 0.11724354742909782, 0.05257164484646637, 0.024518360623915214, 0.06638513194047846, 0.036064573578187265, 0.04585585404129233, 0.03689749333716463, 0.08144026549416594, 0.0746564420114737, 0.04997080315661151, 0.010680708273866912, 0.09065510501386598, 0.02238039087387733, 0.02858668060071068, 0.028233646517037414, 0.013250019819679437, 0.01244696686626412, 0.04015143982542213, 0.042261558628524654, 0.047728860372444615, 0.0647116408799775, 0.05928212187427562, 0.004459448500711005, 0.041358268426847644, 0.025346293150505517, 0.0276152612423175, 0.07674476393731311, 0.0235454662470147, 0.004409210669109598, 0.05448818556033075, 0.043327486782800406, 0.036965663312003016, 0.027088451424788218, 0.050753030518535525, 0.028347555053187534, 0.021639196856995113, 0.10521302931010723, 0.01977364910999313, 0.027123118998133577, 0.03253025111916941, 0.027950736111961305, 0.02604779896500986, 0.028355692702461965, 0.0431962676520925, 0.07878597432863899, 0.05034652283939067, 0.04396626442030538, 0.08731383742997423, 0.06346498863422312, 0.03129476448521018, 0.028117838082835078, 0.023519248024967965, 0.023706775755272247, 0.03268653999839444, 0.10028346179751679, 0.0885282433591783, 0.04327867201936897, 0.03880581476551015, 0.022461249718617182, 0.036917646357323974, 0.04405808293086011, 0.06894471021951176, 0.042389846275909804, 0.03277653282566462, 0.026561450504232198, 0.029963180859340355, 0.028921838202222716, 0.03635555854998529, 0.05512482952326536, 0.05157974592293613, 0.037607350168400444, 0.014957955809222767, 0.030563125619664788, 0.019595387093431782, 0.03135017694148701, 0.04498854686971754, 0.0346395127417054, 0.04767126971273683, 0.03584964018955361, 0.009449653189221863, 0.04995967094146181, 0.03263232239987701, 0.017185757897095755, 0.05539504549233243, 0.08759108153753914, 0.02726892318605678, 0.06145135273982305, 0.049397698167013004, 0.04347143003542442, 0.026130134683626238, 0.027634501420834567, 0.016919035588216502, 0.04240224385284819, 0.09856735661742277, 0.014760054709768156, 0.030198809035937302, 0.0327059582923539, 0.026220674844807945, 0.030385269928956404, 0.016219600365730003, 0.02925503096776083, 0.008620057324151276, 0.030685956626257394, 0.022486248963105027, 0.05000819997803774, 0.01802590431907447, 0.06218444250407629, 0.04607722185028251, 0.037461759347934276, 0.04680092715716455, 0.034036098440992646, 0.05279860473820008, 0.028076142370991874, 0.038573596757487394, 0.04002433219284285, 0.07314615664654411, 0.01479350608860841, 0.09987217839807272, 0.014777023916394683, 0.05210775801970158, 0.039932658401085064, 0.0418260812148219, 0.0762333202874288, 0.05045050515036564, 0.05837014483404346, 0.03507697540044319, 0.03477129961538594, 0.024887308209144976, 0.0014619844228036527, 0.0718985618732404, 0.043471426324686036, 0.0306042443116894, 0.014004124423081521, 0.042997431446565315, 0.045976731344126165, 0.04565478768199682, 0.06251846833038144, 0.054140407737577334, 0.043436641863081604, 0.02584491805464495, 0.051944489241577685, 0.019492325045575853, 0.02484450669726357, 0.05572125279286411, 0.008164861974364612, 0.04915987323329318, 0.03427507741434965, 0.041311769164167345, 0.021128369189682417, 0.06146975800220389, 0.028130090940976515, 0.04181740921922028, 0.06252206032513641, 0.0684709231427405, 0.10891406040173024, 0.06095108954468742, 0.019007886294275522, 0.05152964353328571, 0.09481329907430336, 0.022775538127461914, 0.040551568745286204, 0.023908703005872667, 0.01793050494597992, 0.018917219967988785, 0.011660807977023069, 0.055269166114158, 0.04922717118461151, 0.007142473305066233, 0.029678659993805923, 0.07216802085167728, 0.004985719333490124, 0.03572473673557397, 0.01781545164703857, 0.06910872485605069, 0.014759191963094054, 0.04732605229946785, 0.05175209487788379, 0.03498269295960199, 0.04334620745794382, 0.03297106086392887, 0.040176531838369556, 0.12180487610748969, 0.039409800519933924, 0.006172313742354163, 0.12396805104799569, 0.019261277775513008, 0.02636387594975531, 0.037201625455054455, 0.009092584605241427, 0.05293795409670565, 0.037644695039489307, 0.05305067519657314, 0.012937700885231607, 0.033392400364391506, 0.06700219804770313, 0.03182402710081078, 0.043341761993360706, 0.008321866098413011, 0.10559792935964651, 0.0433090295700822, 0.03736602229764685, 0.07948509228299372, 0.032866614710655995, 0.020428343959792983, 0.14112806384218857, 0.14187487220624462, 0.16678758227499202, 0.1393854120397009, 0.17158697708509862, 0.1282634533708915, 0.17760193557478487, 0.18214053969131783, 0.0911649085173849, 0.1290004950715229, 0.1926963881123811, 0.12244834040757269, 0.23758826282573864, 0.10853631465579383, 0.11632490961346775, 0.1376241323305294, 0.14977599901612848, 0.09471419267356396, 0.20962842798326164, 0.18061664333799854, 0.21028833085438237, 0.16818520962260664, 0.13092206383589655, 0.13199053384596482, 0.16059627465438098, 0.09151280508376658, 0.21125157916685566, 0.2743239642586559, 0.0838480300444644, 0.12987535359570757, 0.12422418847563677, 0.0756148440996185, 0.09654231762397103, 0.1777782550198026, 0.22749340685550123, 0.13414797198493034, 0.10891895115491934, 0.15191262733424082, 0.18321083538467064, 0.21461818367242813, 0.16297818277962506, 0.11725594129529782, 0.15998710499843583, 0.1414379698690027, 0.12516939517809078, 0.12707180168945342, 0.1418814921635203, 0.16114077356178313, 0.15790331759490073, 0.1102119950519409, 0.13116994115989655, 0.08743554222746752, 0.12477767479140311, 0.14209609158569947, 0.086981689237291, 0.13355621311347932, 0.21083361643832177, 0.0856414224836044, 0.15798173291841522, 0.11679111936246045, 0.11384945377358235, 0.13025252788793296, 0.11135623091831803, 0.06984238978475332, 0.23853172548115253, 0.181358004338108, 0.1106111443368718, 0.08060417676460929, 0.18894097243901342, 0.2043413234059699, 0.0969835466821678, 0.10978607650031336, 0.254368117894046, 0.1214325703040231, 0.07779150386340916, 0.1753122912487015, 0.1110465252713766, 0.09901337994961068, 0.16704727459000424, 0.17903582425788045, 0.12282057941774838, 0.11121980933239684, 0.17033025389537215, 0.15617009106790647, 0.11026354462956078, 0.10613211241434328, 0.11720769427483901, 0.10240423784125596, 0.10329996555810794, 0.19526142859831452, 0.11422488401876763, 0.12642876041354612, 0.14595181593904272, 0.17359874647809193, 0.1792791744810529, 0.12508361774962395, 0.1274775041383691, 0.16121375636430457, 0.0889472896233201, 0.09349198677227832, 0.07639393588760868, 0.13638864940730855, 0.1699368710978888, 0.08943542983615771, 0.1430270416312851, 0.10775915245176293, 0.10086155773024075, 0.15184008982032537, 0.1453323452733457, 0.14994382829172537, 0.09500360800302587, 0.15843634289922193, 0.20671753183705732, 0.16024455602746457, 0.17900122533319518, 0.17576299753272906, 0.10922041896265, 0.128180971078109, 0.18718966719461605, 0.19857072446029633, 0.09290010915719904, 0.14077910600462928, 0.12102923530619591, 0.10683687069104053, 0.13634155271574855, 0.12139564845710993, 0.2133898253669031, 0.16318081878125668, 0.07385809149127454, 0.10635854909196496, 0.16982030938379467, 0.2264798409305513, 0.14863557036733255, 0.12444544496247545, 0.12047998665366322, 0.11431718492531218, 0.1017184711236041, 0.1876508822897449, 0.20207676367135718, 0.13692934851860628, 0.11523306937306188, 0.16416984930401668, 0.12358823471004143, 0.15118694049306214, 0.0999126180249732, 0.21496534551260993, 0.07767540970235132, 0.21925069915596396, 0.1678303294465877, 0.0897120356967207, 0.16565064172027633, 0.17046826367732137, 0.13057727686828002, 0.13811494427500293, 0.10516068563447334, 0.15439632843481377, 0.2306292182765901, 0.13907163200201467, 0.10732061738963239, 0.2174979096162133, 0.15383061894681305, 0.3445239504799247, 0.13712110463529825, 0.10660678264684975, 0.09819565195357427, 0.12170464164228179, 0.2404659998137504, 0.13961767457658425, 0.07995474559720606, 0.13336171105038375, 0.2240760691347532, 0.16476770862936974, 0.1453044850495644, 0.1833454758161679, 0.09096211666474119, 0.20582095807185397], [0.05036895425291732, 0.019391433779674117, 0.005860872397533967, 0.08054997029830702, 0.044810186518589035, 0.06217518421181012, 0.047675347814220004, 0.03118356478807982, 0.028665424324572086, 0.03834434362943284, 0.04924758766719606, 0.013894887706555892, 0.008838232042762684, 0.02720512817177223, 0.05371454855776392, 0.06033341858710628, 0.07595128932734951, 0.0250906288420083, 0.057673839619383216, 0.03881234195432626, 0.030373978152056225, 0.01696415445621824, 0.07843645245884545, 0.03773728167288937, 0.03921246716345195, 0.02927138233644655, 0.05417679152742494, 0.03896606300259009, 0.029218279814813286, 0.03673474406241439, 0.01784207248419989, 0.050377796942484565, 0.05942561983829364, 0.0009789160935724794, 0.12867080338764936, 0.06762982491636649, 0.04331292955612298, 0.040889175434131175, 0.03654168176581152, 0.040242044924525544, 0.01487991341491579, 0.06135220181022305, 0.03153976227622479, 0.03145223708997946, 0.013905213763791835, 0.030907725194992963, 0.012517299273895333, 0.040471034590154886, 0.04287477298930753, 0.02444538153213216, 0.027083054155809805, 0.024704576608201023, 0.006455372113123303, 0.06908242314239033, 0.09212986376951449, 0.04659242447814904, 0.05259955330984667, 0.031635644045309164, 0.023287093099497724, 0.08195936068659648, 0.051188674915465526, 0.024023539226618595, 0.04139785829465836, 0.033380555687472224, 0.04469704239454586, 0.011760683428292396, 0.008622644636488985, 0.015963132682372816, 0.005370915778257768, 0.05666742057655938, 0.059099987702211365, 0.022115967367426492, 0.06445401173550636, 0.014847000093141105, 0.02107863787387032, 0.020770084411196876, 0.009525018285785336, 0.011972368993156124, 0.03172143260599114, 0.09421510578249581, 0.025671481853350997, 0.06137482247140724, 0.05163338835700415, 0.023090431386663113, 0.0778956939757336, 0.04964618034136947, 0.024033834670262877, 0.023308097734116018, 0.11323842132696882, 0.0634111680847127, 0.0279249539016746, 0.03929097525542602, 0.020559616896207444, 0.036871317788609304, 0.024138707558449823, 0.025140786892734468, 0.027911500619666185, 0.02226522810815368, 0.03783139713050332, 0.053281735454220325, 0.03386990189028438, 0.02591816617496079, 0.04928276546706911, 0.037819686040165834, 0.008013746792130405, 0.03342869138577953, 0.05132435806444846, 0.018912767081928905, 0.03582411402021535, 0.018770100323308725, 0.02472008749464294, 0.058934874687111005, 0.03189895061950665, 0.007564665347672417, 0.03928162419470027, 0.0020368173409224255, 0.013921905592724215, 0.043722654445446096, 0.032668888015905395, 0.05471983582538087, 0.020048809637955856, 0.06777983522624709, 0.026576454874884803, 0.039226315639098175, 0.020592336331901606, 0.020752135569637176, 0.01919646601891145, 0.06536743225296959, 0.08328336698468775, 0.02618787191750016, 0.09932596512953751, 0.006106959754106356, 0.07262194805662148, 0.03929840415366925, 0.011035063380404608, 0.0009665794539159833, 0.0610843941103667, 0.04768416081788018, 0.024358041882805992, 0.046503548583132215, 0.042100738937733695, 0.06408326444216073, 0.017219360488525126, 0.040998757249326445, 0.048361222143284976, 0.04411223744682502, 0.014631147369073005, 0.04819979389139917, 0.033636993684922345, 0.043824762833537534, 0.06411568145267665, 0.011927986706723459, 0.036402581026777625, 0.024617637718620244, 0.0298341640518629, 0.038246458061621524, 0.037494417556445114, 0.05781996849691495, 0.0541913190681953, 0.0508424481813563, 0.05468398267112207, 0.020925369535689242, 0.03551851987140253, 0.03473581753496546, 0.04060279177792836, 0.03565090417396277, 0.028559581078297924, 0.03398886074137408, 0.08507257371093147, 0.02152243847376667, 0.038905177207197994, 0.038209862759686075, 0.056637671586940996, 0.07941003888845444, 0.02166587521060137, 0.01727873972413363, 0.01794505846191896, 0.05544749306864105, 0.012299977097427472, 0.0346339577663457, 0.010067591319966596, 0.027045605384046212, 0.03795634882408194, 0.02016994298173813, 0.03179955849191174, 0.023853780367062427, 0.0628188303380739, 0.01078957113350043, 0.014954399994167034, 0.031828784267418087, 0.031029392885102425, 0.01840202290622983, 0.015882685729593504, 0.024493231503583957, 0.02960415578854736, 0.07004426879575476, 0.03365484604728408, 0.06043566798325628, 0.037282449047779664, 0.060522681087604724, 0.10162765451241285, 0.026772541423270013, 0.02591287651739549, 0.030343258804350626, 0.05374849810323212, 0.028181790803500917, 0.08928707451559603, 0.038261089503066614, 0.038007256443961523, 0.03189368508174084, 0.03351067272888031, 0.05748935654992238, 0.07302604746655561, 0.03662958915811032, 0.02174296765588224, 0.03121984096651431, 0.056590070234960876, 0.09216812890372239, 0.022959522102610208, 0.00751963275433809, 0.025055451042135246, 0.06176544076879509, 0.03254834839026444, 0.018851731001632288, 0.05655692220898345, 0.029030169498582836, 0.0053344749358075205, 0.02650054986588657, 0.022603484176215716, 0.07689683741773479, 0.07912781496997923, 0.07921375567093492, 0.028566386572492775, 0.027484118181746453, 0.03298512827313971, 0.05744535461417399, 0.040090082766255364, 0.06837718989118002, 0.026072245309478603, 0.04736977592983749, 0.06971151204197668, 0.08261366034275852, 0.022946163444430567, 0.07586586070829071, 0.02725768707023235, 0.014017152825545054, 0.05044811172410846, 0.06429142944398336, 0.008202642857213505, 0.026965551769535523, 0.015219592551147798, 0.005546086749745882, 0.016936264546529856, 0.005065055847808253, 0.04958730947691947, 0.05466082024213392, 0.1076980514335446, 0.08145924963173456, 0.031279999457183294, 0.04239373512973543, 0.025761138858797494, 0.03086958808125928, 0.03731557109858841, 0.04780122348165605, 0.03737338811333757, 0.041976503416663036, 0.05896877599298023, 0.030059660057304427, 0.04025928872579243, 0.0160761636288953, 0.023427785745298024, 0.033454321455792524, 0.04021138680400327, 0.05061473872046918, 0.027776164424722083, 0.043600044227787293, 0.013137650312273763, 0.026747193369374145, 0.03236680422560312, 0.016052921419031918, 0.040346004971070215, 0.04959415578923654, 0.029986239387653768, 0.0071846639366413, 0.025708108696562704, 0.029176940333854873, 0.07182105196989141, 0.02712303179578157, 0.0022642438580078306, 0.020040905765199568, 0.025532023028063122, 0.077486206573667, 0.02144621805200586, 0.041164742287946865, 0.012267785514268326, 0.020142921384831425, 0.07014278147835284, 0.09346375547465868, 0.011012328614015132, 0.05836941381858196, 0.017842629094957374, 0.056386866490356624, 0.045388438302325085, 0.03000296183017781, 0.039434450955013745, 0.033731279836501926, 0.04529851968982257, 0.025659438651928212, 0.05996817802952137, 0.0709662536974065, 0.0577499988139607, 0.015742427240184043, 0.054619979855488054, 0.006365445151459426, 0.011928214917134028, 0.07809220725903288, 0.07292770547792315, 0.05142078902281355, 0.10487121835467406, 0.09431757411221042, 0.026394459855509922, 0.03961732727475464, 0.01397466487105703, 0.05678146641002968, 0.11692570784362033, 0.05357779300538823, 0.044369874012772925, 0.055592401113244705, 0.05535459844395518, 0.0358761348616099, 0.01715723345114384, 0.0481061237223912, 0.052877710259053856, 0.008011666923266603, 0.096437066240469, 0.0469663518742891, 0.07129970064852387, 0.034980633499799296, 0.03640298920799978, 0.01023091946990462, 0.050616571825230494, 0.0756879679101985, 0.023205957804748323, 0.028178209940961096, 0.07606025144923478, 0.025021764959092252, 0.057918317907024175, 0.07224685919936746, 0.042397353099659085, 0.034069457979057916, 0.040278057640534826, 0.02808688866934972, 0.09535474033327773, 0.13186085096094757, 0.09867041124380194, 0.22099778900155798, 0.10251162661006674, 0.09009323242935352, 0.1065787962579634, 0.0739919081388507, 0.1333514100406319, 0.07932774955406785, 0.17830832657637075, 0.12815836525987834, 0.060299053438939154, 0.10170464491238818, 0.11370828986400738, 0.17223132454091683, 0.1604005554690957, 0.091168782528257, 0.20386237098136917, 0.13726938574109226, 0.1221567728498485, 0.14716249628691003, 0.18143069028155878, 0.11494116042740643, 0.22356340836267918, 0.2097155709634535, 0.14414174744160846, 0.07484658024623059, 0.14437172416364774, 0.15052720089443028, 0.11680381008773111, 0.17918553028721362, 0.14763279526960105, 0.11954057612456381, 0.13411644555162638, 0.15397124108858407, 0.149481707776431, 0.21453053603181615, 0.11041981866583228, 0.11803017201600596, 0.07259406556840986, 0.23462556477170438, 0.115164391027065, 0.07146876188926399, 0.1656309302779846, 0.13628455577418208, 0.11735380830941722, 0.16962681664153934, 0.15125153702683747, 0.1297385906218551, 0.09957733796909451, 0.11587162807700224, 0.12977560894796625, 0.1955556753091514, 0.2543277450604364, 0.16648494929540902, 0.20686793548520654, 0.11181058114743792, 0.1666112183011137, 0.20763280772371218, 0.25299466971773654, 0.15712873806478456, 0.09598192933481187, 0.11460804002126679, 0.18793337338138372, 0.18051525112241507, 0.06631962998653762, 0.20255438023013994, 0.13857382902642712, 0.07282412392669357, 0.19898890983313322, 0.09087024620384909, 0.11804643989307806, 0.12174176386906765, 0.0981908873654902, 0.14580561284674332, 0.11760975277866237, 0.13622972590383142, 0.1516875487868674, 0.262122611165978, 0.15571245312457904, 0.21867480740183964, 0.13072440022369847, 0.0801911715825554, 0.18477743491530418, 0.1438530519953929, 0.12047603100654669, 0.12919719389174134, 0.16524639388080686, 0.1824528502766043, 0.14778386685065925, 0.15972193563356996, 0.16447266039904207, 0.09476415405515581, 0.08569947327487171, 0.11686279598507099, 0.15003477106802166, 0.192291175480932, 0.10765289174742065, 0.11382864395272918, 0.10795331312692724, 0.08417176970397122, 0.1334042361122556, 0.09837019766564481, 0.09953510234481655, 0.14823757141130045, 0.13119508512318134, 0.1319551927736029, 0.17589949333341792, 0.17932199640199542, 0.16260984004475176, 0.19120962882880121, 0.08150848370860331, 0.12070073105860502, 0.09567719607730396, 0.166334857349284, 0.13916652300395072, 0.10052896424895152, 0.15999693103367463, 0.13081448210868984, 0.180188246013131, 0.1834488273016177, 0.16195461270399392, 0.14975832105847076, 0.057284649956272915, 0.12598961679032072, 0.17126613180153072, 0.15418581082485616, 0.16265291429590434, 0.12836128327762708, 0.1354433610686101, 0.1968089400907047, 0.194512156303972, 0.12870555074186996, 0.130679797148332, 0.08955182085628621, 0.17332574003376067, 0.07940203853650019, 0.08776915245107375, 0.22322740842355415, 0.13098300900310278, 0.1966773869935423, 0.20176961843390018, 0.13365903025260195, 0.14893054438289255, 0.14055000501684844, 0.14324998279334977, 0.14152011077385396, 0.21108697081217542, 0.0898780689749401, 0.3176440147217363, 0.12631233228603378, 0.10884137445827946, 0.16303923184750602, 0.07346625978243537, 0.11570175789529458, 0.16786172229330987, 0.1127927987545263, 0.18191427370766178, 0.19902865926269442, 0.18373125902144238, 0.12692760239588097, 0.12952678167494014, 0.09134536172496155, 0.13390770909609273, 0.305922890547663, 0.07152612990466878, 0.09704354932182468, 0.17382631864165887, 0.08384350294363685, 0.09137117362115532, 0.15341981052188203, 0.13803366426145658, 0.12306538425036706, 0.13736114487983286, 0.1053531096840743], [0.04836973086639773, 0.07534053147537634, 0.08371721167350188, 0.006577450767508708, 0.06271938254940324, 0.022230926042539068, 0.03363705676747486, 0.00997483306491631, 0.08758063209825195, 0.02168300583434757, 0.03815444288193248, 0.039205717330332845, 0.08460798184387386, 0.06109280264354311, 0.017401147706550546, 0.03189354407368228, 0.010628243999235565, 0.005966434555375599, 0.005003580045013223, 0.02980416644277284, 0.054828608699608594, 0.03951893333578482, 0.07096873989212327, 0.02406781761237653, 0.04364628373878077, 0.052057985885767266, 0.060145462266518734, 0.02810892488923855, 0.03763775966945104, 0.01150387899542693, 0.038583823552471586, 0.018602890741021838, 0.032367063977289945, 0.07286412568646483, 0.02988189156894805, 0.01422452744009206, 0.08295782390632667, 0.12421885243384168, 0.039692287900834344, 0.07886479041189887, 0.03531420290528331, 0.06834859494119883, 0.0575604394543916, 0.02168685201468179, 0.07196810111054219, 0.037727570670540445, 0.03696755949931685, 0.04293781843443867, 0.0398320602835156, 0.032785264193080366, 0.10365916503360495, 0.030688424267282244, 0.024538734433008358, 0.04507191231823526, 0.07992517101229168, 0.05270809982903302, 0.10462093647220172, 0.03380312344233971, 0.04365344917459879, 0.014264921610447345, 0.02202241594204679, 0.03927729747374542, 0.020031606654811185, 0.020020281481265556, 0.029088587652950082, 0.026191204160568304, 0.05278921285935212, 0.018836680246749893, 0.05025269310863223, 0.02307216898771003, 0.02056358367553912, 0.02374394807702629, 0.10342036417569034, 0.06850862424471416, 0.03445177906542085, 0.034045289939967915, 0.02417918058199575, 0.049041181555367075, 0.023732390982331708, 0.02239662535430398, 0.10918984989984892, 0.045801462038070895, 0.07834199190256186, 0.057597168342908844, 0.03538589437084738, 0.10150301081012003, 0.03793744632275775, 0.024690440550330095, 0.018687885203689802, 0.040597036422695965, 0.0229068054977688, 0.025082684151129797, 0.0030933503694541287, 0.045523520311689936, 0.05346446705516428, 0.03335976442031097, 0.024367847508983687, 0.028233889570401516, 0.025154601971735246, 0.0389533129055053, 0.0680856074905023, 0.07771232412778772, 0.0387778283766238, 0.00364940358849708, 0.02779330432531424, 0.01853427918831585, 0.022622223405051045, 0.009471502016822342, 0.0464811320125591, 0.04886386392172426, 0.06321779408608563, 0.011448665991338203, 0.04237300323438831, 0.03679205270600505, 0.03280208497017156, 0.05002225996577181, 0.05452777542814147, 0.02118511009030044, 0.01357985807771911, 0.018085042356688064, 0.07260022539412603, 0.0158025690325303, 0.013193271497584647, 0.03646877688879613, 0.053911147188046016, 0.07852568829548545, 0.018985456736118067, 0.04517488159763161, 0.028293335599300917, 0.07049982130411081, 0.10331010329537094, 0.03729847943759523, 0.0310907258244697, 0.07032838519080542, 0.04426666724612005, 0.04497782283578999, 0.036314573444542475, 0.029520951757149305, 0.02921023864473682, 0.05055691799498163, 0.03321279691590462, 0.04961274658853654, 0.023378501573461108, 0.059340703301131725, 0.01705641083390219, 0.031978241677279584, 0.02579885294835549, 0.051679572206921875, 0.047872662617010064, 0.034099889744538814, 0.02911288000177592, 0.06445536986575462, 0.021791619146824814, 0.04405913678056095, 0.016787766362540424, 0.01634198608371662, 0.06467670056736097, 0.05800778752018232, 0.07768752897391096, 0.012213667178002652, 0.022217277946765535, 0.03281091652752366, 0.055492816027253866, 0.015211410373012768, 0.025744863560248632, 0.053727317208540626, 0.025824785443546716, 0.010751022127806209, 0.020754130091518164, 0.010386468984506791, 0.01708760144538246, 0.016566632330068387, 0.044948700960958377, 0.034547467876109295, 0.03317266899102833, 0.020881293385173194, 0.026764175563585013, 0.02871717428206466, 0.06976767035666853, 0.03101126778346952, 0.026053519068227615, 0.01668185261223698, 0.016928562909015454, 0.020800070888071787, 0.07152722828323022, 0.019000730135303456, 0.02902134907344589, 0.05968817313259933, 0.05352208740077913, 0.07032293782685883, 0.042799600851139985, 0.03808888897765428, 0.046117193924146704, 0.01226151251103147, 0.026272302347933874, 0.023070222705428023, 0.026728945813374594, 0.010171491994697135, 0.03641624396550469, 0.050661304776440375, 0.03652892424724996, 0.025260658585466444, 0.01381195548674441, 0.04654505319194868, 0.05875667389773298, 0.044428848777897656, 0.038106822976260446, 0.029406109970295802, 0.04663854153477587, 0.04918595601338893, 0.015423239728988847, 0.028841977546107955, 0.015421645966853248, 0.0700119705288671, 0.028504472902568523, 0.061879367858637124, 0.05971923943434376, 0.02130397431756137, 0.035902284434996545, 0.09179620159557089, 0.030605285173805896, 0.06549286263179965, 0.032417188631370664, 0.05825473344884813, 0.025389666116097942, 0.026954471504723188, 0.05752019649662543, 0.009233943328581518, 0.05522613268112764, 0.018553278168838006, 0.0470996749936603, 0.021581899345619604, 0.06488298793556169, 0.08974215204943903, 0.05440624874609057, 0.053426135127665475, 0.04217126523144543, 0.036936110991518945, 0.039050370978657156, 0.014245732454583049, 0.04747776583826635, 0.0532268536335323, 0.07059048948576674, 0.07031783927232027, 0.04470573665457778, 0.03285478858742863, 0.07086630124831572, 0.041941730087273754, 0.02165547772165155, 0.05823305531521328, 0.015609013207722455, 0.03876925286022015, 0.014496867806883529, 0.06860289184260182, 0.028050825858372264, 0.12060493463650346, 0.09157671142020263, 0.01910245631734142, 0.08132221206324175, 0.04076275057741441, 0.06291784025961533, 0.009675384826550726, 0.04817165536223911, 0.019991475019196514, 0.010801477037603036, 0.017045204403984826, 0.01552685189381009, 0.0286242778020096, 0.08239934293669648, 0.01840696932049468, 0.07339594871154986, 0.019568228199204896, 0.041568251690478064, 0.02456799917126773, 0.019738150331249926, 0.028500507978606038, 0.03652615974715445, 0.03912699030479416, 0.012371931097732158, 0.026903827347268816, 0.026507526054047048, 0.03410065415664576, 0.0355742551619187, 0.01631124261621153, 0.016624551390123088, 0.026811637762875762, 0.0390550094016362, 0.02123313632182544, 0.09848252913798206, 0.054299691182677634, 0.0957375178404618, 0.029195306633482687, 0.045338517738855444, 0.04399449571792502, 0.017754178079485428, 0.032680420990800485, 0.011609124812821392, 0.04153256923018489, 0.03252148635510821, 0.07735345861874521, 0.04658459482016042, 0.03476784491795115, 0.05928319056692999, 0.01501642776929657, 0.08010011006263085, 0.04498291025811341, 0.038838413602206856, 0.03779334350838326, 0.01998784406168852, 0.034893920965259895, 0.06557496642926708, 0.05423867180070374, 0.04961069455021061, 0.012512249886640348, 0.03131243502139114, 0.01615623950783629, 0.027480127282615285, 0.0386098469607532, 0.04209918413835112, 0.025944809276552405, 0.02580461572506465, 0.04332105236244388, 0.058643125303206034, 0.05943097443378065, 0.04093268384167459, 0.01852966674050549, 0.0634222335065715, 0.0476959090156015, 0.033646311349002644, 0.06957909805350937, 0.03233472860301845, 0.035397765022935346, 0.02194976153987227, 0.10039281725767069, 0.036310317227616906, 0.022480374864244368, 0.02069989022857044, 0.01247966218215879, 0.029927431605756283, 0.0648787131649442, 0.039454693032894284, 0.037477400110219605, 0.014907672521076165, 0.018254840178997256, 0.05913648281421047, 0.08585573988966644, 0.031605190015397966, 0.021276711522659753, 0.013248606956040021, 0.034504456707509235, 0.02728388673858717, 0.04522073519183323, 0.1568010650225915, 0.14251965010771528, 0.13435638189548627, 0.10351057222578675, 0.22730769182089716, 0.08915845290175639, 0.11552916403161362, 0.06851388607174158, 0.1395746596972458, 0.08376965182833374, 0.11380487296264619, 0.19389240362215787, 0.3031901840586215, 0.15981406584614888, 0.05914663168368861, 0.22236785298446193, 0.15508616954321042, 0.08635922029498033, 0.060890088716405444, 0.18571448541479185, 0.13586586574092507, 0.10244933073408902, 0.1592787547269836, 0.13073826354229823, 0.18862875091144815, 0.11371356653398834, 0.13279110338771716, 0.07774770972901024, 0.14468580106040463, 0.12517398165073246, 0.11353916925145313, 0.1470862331916578, 0.1559274978353642, 0.11916867108084261, 0.06885905895614997, 0.15180929069174454, 0.10793170178658329, 0.2245469915214926, 0.08465400242130272, 0.12827672297134995, 0.14900613954523578, 0.13264850713312626, 0.20316933863796294, 0.1497260673204437, 0.22720101551385596, 0.09855396827333607, 0.06158922151371371, 0.16730661067413166, 0.12054632723447867, 0.13378305797232315, 0.17491224396508187, 0.2182871985132806, 0.18214779789559543, 0.128165875794366, 0.18340842478210106, 0.09397681700647809, 0.17622885847231373, 0.12985981302335858, 0.1839769841171801, 0.131859915854875, 0.1279312977567315, 0.1076299964915961, 0.16836336959386244, 0.15045353531604633, 0.23289162578294054, 0.10320125991711393, 0.192466723092366, 0.11456218271632679, 0.17787183984182775, 0.13959469768451527, 0.16473676107125357, 0.1562572637340054, 0.15866704692598432, 0.19947255263105035, 0.06408222543541342, 0.16936825239099562, 0.15024978609289974, 0.26701220660470426, 0.0769494853739161, 0.2030914428178221, 0.147002711892128, 0.1473796190111898, 0.12487741943914443, 0.13288556394400075, 0.14076592546189204, 0.14466044929577038, 0.1492149056866765, 0.1034614717354998, 0.12998879828955978, 0.10550779552431777, 0.10034102277131751, 0.177463183645159, 0.14230997854610905, 0.10064293586765416, 0.1351917878491804, 0.14320441492600366, 0.0918531243223697, 0.1592975904350169, 0.1244819957355503, 0.15617350494721904, 0.17325109482044354, 0.11019238008884713, 0.11977361791650765, 0.05210777286265511, 0.11586234380956739, 0.1069085844210349, 0.09333030247944407, 0.06022597415721975, 0.07477353807189502, 0.11167133940034546, 0.13608134089736268, 0.1254291320219636, 0.14359775319462642, 0.18317533103981987, 0.2616431243950501, 0.128344792756252, 0.20861664321273565, 0.10581930459011346, 0.08215477559133433, 0.08186593171558343, 0.1271969426306896, 0.1597685128217563, 0.11475610590423457, 0.2190292571322061, 0.1947880125953816, 0.14698611747007817, 0.10423545754747465, 0.18444611050654203, 0.2072807922377251, 0.16883921984117478, 0.27190681896172464, 0.22713946178555489, 0.07608582585817203, 0.16150519775692374, 0.17949729168321937, 0.24118515575537458, 0.09884957311442122, 0.10661110194632784, 0.10674887424102053, 0.1700926330522634, 0.14105065783951432, 0.17144320823717862, 0.11262617917964235, 0.18449543364113197, 0.20000511780381203, 0.08037322040763684, 0.08660717925522476, 0.18432781216688454, 0.07288086853804998, 0.15134210872929543, 0.1351680836523883, 0.28215347381774336, 0.07792053365847096, 0.20752990152686834, 0.11337050134898163, 0.12040853267535567, 0.1513536713900976, 0.23354682343779132, 0.15099594136700034, 0.10841410519788042, 0.08713015588000417, 0.1325177852413617, 0.1501085702329874, 0.11811024975031614, 0.15737660054583102, 0.12300779359065928, 0.09310160225140862, 0.06541686670971103, 0.16266349732177332, 0.14875725290039554, 0.24992826394736767, 0.17934743722435087, 0.12676317215664312, 0.11912184898392297, 0.20751670614117756, 0.11337394491420127], [0.07513910517445765, 0.091111770743737, 0.02538765489589423, 0.04253579332726076, 0.026895205446635373, 0.0400522072595777, 0.06809599755797535, 0.072032460157061, 0.027963072461716365, 0.0483516781241633, 0.017958686148631386, 0.03424811889999546, 0.03555904113454744, 0.004213920537949889, 0.032207402036874555, 0.0447062190505676, 0.050669772681430914, 0.07532948831794783, 0.17567791772307828, 0.019406991050345823, 0.09237081685569137, 0.05535607902857009, 0.04629933180694934, 0.051418785224086605, 0.033977995699387975, 0.07423183706123382, 0.07060387782985345, 0.031143036103458144, 0.006669892218269524, 0.03131998637400102, 0.022066226774768438, 0.039071243882062845, 0.030042750222492032, 0.011992955242021708, 0.02944245294202119, 0.05257622389763128, 0.0785129753057845, 0.02778717975161271, 0.012116688885726035, 0.020597336551873013, 0.02090758025588002, 0.02499166159395827, 0.04188570906990208, 0.03726386195921805, 0.034250360185978934, 0.06341143525787629, 0.04374020252726041, 0.04058686157804914, 0.0324467483733315, 0.05164371905266307, 0.010913614623859758, 0.03572589819668792, 0.052172855503158644, 0.06824718788266182, 0.03529615387378726, 0.018258537929796148, 0.02731218482949771, 0.036113321548327804, 0.01050780085279257, 0.04462693541427143, 0.050847465099650435, 0.024293562237289734, 0.04163761652307585, 0.022378468711394817, 0.0616794110101182, 0.03409086151805241, 0.08119489662931301, 0.06670113099971786, 0.030297943267214578, 0.018043534037133213, 0.05909820654778741, 0.027278498746454716, 0.043320785189280286, 0.04171258085989393, 0.04674556665122509, 0.10547243960900232, 0.0430389546090737, 0.05872211208043154, 0.04168012674199417, 0.01877093152870657, 0.05305594815581571, 0.029488132131518796, 0.014955034530430567, 0.06026974231644999, 0.028737548091157805, 0.05793319425720256, 0.03252819908084348, 0.018237095428048633, 0.04806992918020114, 0.020784303960681427, 0.049968157400144264, 0.06805794764659368, 0.03964827112213243, 0.020386600008350797, 0.034402196179144084, 0.03438588748394977, 0.03119913504633587, 0.04444707963557448, 0.026149810873903334, 0.023944893837324344, 0.016199267374759074, 0.03293128545919899, 0.05171545875782613, 0.08534446693374775, 0.03369892590853851, 0.07205690650152974, 0.022472398632089607, 0.016184110863832757, 0.010936928265437018, 0.040564593437011354, 0.027000280570064206, 0.02410386372503126, 0.022020720134605654, 0.014427865698962705, 0.026945044373860583, 0.02032539323408855, 0.05704995317501016, 0.015404429996124236, 0.09414161831955425, 0.04908432631054893, 0.045632471301360056, 0.034084961444023065, 0.05342751923308242, 0.12684120156336576, 0.012587167839228641, 0.05916704816627316, 0.0752810706035234, 0.05305671256792266, 0.03994605787738692, 0.051229333475930616, 0.06874668295495212, 0.03978694512625225, 0.03029846277058823, 0.012942779958393658, 0.015542932378593832, 0.014914776729710866, 0.053819157983525656, 0.03199688442691695, 0.04081869366928004, 0.035798714015982114, 0.022287145584414247, 0.022797251513111405, 0.004233908894093474, 0.05789980132249184, 0.03520014593959786, 0.04715638991910964, 0.02708954423724208, 0.05286916813929565, 0.05716682659112848, 0.02456898808304686, 0.023283137452381197, 0.05863217491423711, 0.01346177959931083, 0.012584757714648731, 0.0192662371773622, 0.017435870940971654, 0.06162478523037862, 0.060852220631204545, 0.012346040348347742, 0.018602128184284084, 0.010532081141718663, 0.07858764278353192, 0.029763032907794695, 0.01540860086606699, 0.03287487481429707, 0.01402783882440417, 0.05798779035103507, 0.07652968211914413, 0.030018003308214247, 0.02805053456540918, 0.06246519697015174, 0.03242348575440701, 0.030206757437554188, 0.12329247401794419, 0.01853801033576019, 0.05087712132080924, 0.08221252210205421, 0.029735697753494605, 0.04743725570733659, 0.03862020363158081, 0.058264689359930344, 0.030930733628338203, 0.05211048170167487, 0.013625695901282597, 0.04387959270388819, 0.031076894047146197, 0.04927195237542037, 0.03127547235635575, 0.024651327512401622, 0.06202107724675443, 0.039611968968529254, 0.01934569521836238, 0.03501682062051259, 0.02117689266015077, 0.027412384042690974, 0.07176799583248794, 0.06466124163125642, 0.02501771097740857, 0.019542856025509536, 0.017416664159100037, 0.03486943380266894, 0.08480566029902548, 0.06616733386181295, 0.06310063865385018, 0.02267071533424314, 0.0356146242847899, 0.029784620128339157, 0.040116547752404585, 0.01456108770071296, 0.0280334002309246, 0.04463417506485712, 0.007903926561994012, 0.02208724068623269, 0.03608314953453373, 0.038685004255967215, 0.03650618113169912, 0.02530622274207417, 0.03284164144133683, 0.019989328357041813, 0.035823813450406305, 0.05013281770516187, 0.04218940703140106, 0.02850979595677927, 0.0063854849940980785, 0.03274806404078845, 0.022922759817447513, 0.017512390077172313, 0.10275634238496423, 0.0587471521430416, 0.09959681192412972, 0.026516463367443066, 0.043737066953326575, 0.02944207259133691, 0.04582854300679173, 0.016850323845574167, 0.00859694406244671, 0.04924994398606941, 0.03300174867035821, 0.030807268085482065, 0.053022993088234216, 0.04514833497523796, 0.04730614789878018, 0.06361423453199677, 0.03072461509873392, 0.03171684984408785, 0.018601122574182227, 0.03425377777602989, 0.04480403411434963, 0.029083552180964034, 0.03483285334368702, 0.035454787939670496, 0.1192705902212765, 0.05559358854952734, 0.040504761491320096, 0.06942838270333596, 0.018571933906059712, 0.024589395288785454, 0.015774987114127725, 0.01814123592339456, 0.05591508321231231, 0.03871348417305853, 0.05351938227249775, 0.03255814473959617, 0.07343502278672531, 0.03671687314636074, 0.01454153210943332, 0.020265412858861964, 0.04607905495504383, 0.05620895142783411, 0.010521500898903469, 0.05791296702227555, 0.04460657830350101, 0.04407631007779855, 0.02550644119764911, 0.01667424374318216, 0.03593830086174421, 0.08047590396017767, 0.03969444012909662, 0.006176003143991693, 0.03813203002209775, 0.12838939583161846, 0.06214248147443868, 0.02270207663968904, 0.057954594085458666, 0.010593991100904532, 0.012768493998009944, 0.055486285127699375, 0.03941092858440243, 0.04937060235533863, 0.06844471790827811, 0.013037844437349122, 0.012428237841959344, 0.11154560474096797, 0.030694183333253022, 0.06477824863395654, 0.05631831802020315, 0.00892812375241192, 0.05190410156501457, 0.03214028962247539, 0.005293251415423583, 0.021056447658338584, 0.0243862583374721, 0.05797626108687837, 0.028312774302321486, 0.024398865571129136, 0.006030272243151558, 0.11163544913870282, 0.022751581600459758, 0.021312427379598375, 0.03191901829268318, 0.04628081893315539, 0.04642678453819826, 0.04512219282332808, 0.023058519036567304, 0.052259556905482896, 0.0177964118483942, 0.05186137612327002, 0.055227253324119374, 0.025595602819521446, 0.03283461330283899, 0.06341415151837282, 0.09436539810849354, 0.0516103817790281, 0.036205370124662295, 0.05661192648403812, 0.035203318620915525, 0.022662343908450566, 0.03168062190525234, 0.023606121976627037, 0.016274433946819045, 0.033842809789348394, 0.024882031539164018, 0.17746906145475805, 0.05359843955375254, 0.0326725393824745, 0.062152444806997664, 0.017781876886147074, 0.05435653598397039, 0.02826267747877864, 0.051866374487872235, 0.030985667399363592, 0.021918797283433378, 0.026405022472317796, 0.01808941175113432, 0.016200395439227577, 0.07667722849873826, 0.06552267470397055, 0.06090454204240814, 0.06966846747673117, 0.02895728131989017, 0.020027048012707382, 0.012136375280533684, 0.23287044488824904, 0.24765323993051425, 0.17845444061094895, 0.09170614939648658, 0.15937462536385283, 0.14463005092693493, 0.12436196077032946, 0.10998109806678258, 0.21042500477051362, 0.16127378126839176, 0.151596323994454, 0.111967345001176, 0.08893751553841867, 0.12513142690295354, 0.08743333062739111, 0.10793868539622054, 0.15974814828950912, 0.1362439602962695, 0.22808479465311393, 0.07279380719410256, 0.17038354009855539, 0.12276300360099413, 0.11328144362778403, 0.09530962517601438, 0.12061855304636993, 0.18883873417507857, 0.2126176652382128, 0.20572293520672247, 0.17594532837392762, 0.17457995476434007, 0.11157043700222857, 0.139671420911327, 0.11003493345924653, 0.03786338369536679, 0.14272461645305157, 0.11619453653111123, 0.12245188045199029, 0.13473143364535645, 0.08044756134040654, 0.09178433465422131, 0.18701125489315018, 0.13099372561555356, 0.14572896383469924, 0.09364075027406216, 0.16238670592429116, 0.09261194063583389, 0.07989545541931875, 0.10756234230939299, 0.0778494581754785, 0.15618027333403006, 0.10047454255982302, 0.1823674884508364, 0.10491500506759621, 0.23094474978279322, 0.15180434798821807, 0.1587114718859084, 0.15627900866093114, 0.11865503809531219, 0.09860926569672301, 0.0985066637804266, 0.15777353080920875, 0.1273469752050005, 0.15553893899777904, 0.08599920445703901, 0.18967160198371857, 0.1374060893431306, 0.12126373912906274, 0.2034888628986664, 0.14986746129579842, 0.10368308445322327, 0.25376777979545295, 0.09180777909932658, 0.19960401667049155, 0.14149848459055647, 0.15338544908445328, 0.280933293979615, 0.12168989516794682, 0.10552398176514544, 0.09903931801090948, 0.08309714728966355, 0.18836862815078348, 0.14055628358619288, 0.11296413096715696, 0.16539795527933165, 0.15790539560839534, 0.2496232115663588, 0.1717901325901039, 0.16206167492782697, 0.12642516841879115, 0.09553455529385246, 0.19543494272511452, 0.15574153047055006, 0.18939294037409127, 0.12343771973974071, 0.1312008738750592, 0.14144804823445156, 0.09389695449499413, 0.153903839236591, 0.10831767052877694, 0.1014779633260332, 0.09798871891689487, 0.11400937917642295, 0.15837947954423726, 0.13243730674730614, 0.1853037512046285, 0.1267244468908757, 0.2075851321569644, 0.0763422081945464, 0.06849985948065296, 0.19408154737902805, 0.19188480509910733, 0.2055473133805208, 0.1324336405377835, 0.19910009839804843, 0.08188649662770331, 0.1957804273115471, 0.15228328556986526, 0.0756267926772125, 0.23825713084079325, 0.16079475462902337, 0.12974927754839882, 0.16270919877570122, 0.12851328996475786, 0.13789164688205346, 0.11007543987943791, 0.1753222063416615, 0.21678534394595772, 0.11312338101561181, 0.09792553246370517, 0.09622239260352217, 0.24583897087723017, 0.07951252948259935, 0.09724106450448744, 0.12521527474746108, 0.12848642421886325, 0.12434384494554251, 0.11639079006272368, 0.14207422791514546, 0.18299099639989436, 0.09663725315476768, 0.1666047764592804, 0.12114560406189412, 0.16994243720546365, 0.15159390459302813, 0.13696458569029346, 0.12642879009945318, 0.1524022815283388, 0.0755883939564228, 0.16339212306775153, 0.07774688594508916, 0.11051130320993252, 0.13762162387138233, 0.12304280811804347, 0.11350765766110271, 0.088301635987591, 0.08470642773318104, 0.20736621343530715, 0.10884635426918976, 0.16557813389226794, 0.1518697608844377, 0.09012025402626023, 0.22971692582359537, 0.11389141480321996, 0.1532657555071637, 0.11967647820711136, 0.10489768334082328, 0.12541544681880623, 0.18574250891106203, 0.1235908322269097, 0.21174997586058453, 0.13888472953112796, 0.16005486308131367, 0.11939691117731854, 0.12003000025288202, 0.08883800095645711, 0.14597647008486092], [0.08108429436106235, 0.048156801276491024, 0.014104312504059635, 0.022804077416367363, 0.04513892825343646, 0.006100860227888916, 0.0409112357738195, 0.02153042583813658, 0.0021438619387481594, 0.007420947058562888, 0.052835029346169904, 0.03914156979590189, 0.026992938874172978, 0.03961596914450638, 0.08719924982869998, 0.02660422233020654, 0.007763667608742253, 0.02921302912000101, 0.07688536381465383, 0.02239510024082847, 0.011225201615161495, 0.0562495877238689, 0.018019275084952824, 0.01735949652356794, 0.012710994251392549, 0.03620059440436307, 0.05938951806456316, 0.04712183181254659, 0.008434390529146185, 0.027085490255558398, 0.030737587840121705, 0.02979206201416673, 0.011228617349843262, 0.033547746716067195, 0.09033267153427005, 0.03079803576838458, 0.08233906570239924, 0.05060052288172301, 0.08465777253150009, 0.054001952667022124, 0.0456537746504182, 0.03656679233245086, 0.03820192549028434, 0.06379175625625066, 0.03579634656489361, 0.046829184429952875, 0.03280104967416264, 0.025959231061278842, 0.04588881281961221, 0.04208208876661956, 0.011046671497751959, 0.01567047045682557, 0.01932913419295801, 0.05740658481954597, 0.004000464950877358, 0.003721859234246949, 0.03454935293120798, 0.022392636310542002, 0.03733120072865859, 0.05829256813740358, 0.022732538091077004, 0.022503962172777392, 0.06925782232428901, 0.03417527710553259, 0.08526322402758524, 0.060063607088522986, 0.029020013207627926, 0.05407091673987452, 0.02599438845209079, 0.04136276213102974, 0.10892856196733192, 0.026699721893237438, 0.07829111025785096, 0.019204121272196062, 0.05577599731623195, 0.022159475774969906, 0.028543960725073703, 0.04064014778123237, 0.050466940010664985, 0.055785938384360634, 0.0516804961807793, 0.030084605496085715, 0.01515811860372196, 0.027155578682140913, 0.01744221444823779, 0.03867253617499955, 0.03168717877997551, 0.024189572504837997, 0.04265962437784765, 0.01926115161040798, 0.04435044087585993, 0.03417145875573624, 0.03307059399958234, 0.03439854481257498, 0.03806162618275266, 0.04256749045453034, 0.0051285925019328715, 0.03785342778428458, 0.05492637552379165, 0.045360711665125564, 0.029449787216435652, 0.09712746395962313, 0.02532411592255812, 0.051809303331538104, 0.0590031300089322, 0.07558188532129861, 0.015160071379796136, 0.08185089580365457, 0.07930464649689384, 0.07959832917549647, 0.04817149951122701, 0.0596638343995437, 0.023215798682940658, 0.014403217119252076, 0.05158426189154852, 0.11604775456362404, 0.06534032901981845, 0.03332669803057797, 0.03868241416057572, 0.043340889969840646, 0.020465262095967773, 0.026710104539233726, 0.04312458731874358, 0.016748542002460454, 0.06900967040564865, 0.01885082558146678, 0.027973560863756575, 0.02910687602707185, 0.0572295009624213, 0.02791267506836448, 0.0652307880227454, 0.06207962898770347, 0.06032966331986245, 0.05073933789390139, 0.030304433348646853, 0.025551400503900368, 0.015431020219693892, 0.07544628009782173, 0.12108220238587819, 0.08021969231776893, 0.03466515765467193, 0.054856839997228235, 0.012089403826394118, 0.049212331941816956, 0.03316710288345348, 0.004113137811145862, 0.00911225708478014, 0.04781120536790695, 0.052606317985919304, 0.017889896480483003, 0.06563790797372349, 0.0817233651468996, 0.06506414618343115, 0.020693342630693223, 0.04579057844239287, 0.06878065847558901, 0.012483113168855198, 0.03608491213526577, 0.025957344150810968, 0.027818657945317682, 0.02854232800018508, 0.10212342400336638, 0.04793181178683881, 0.027548857578949537, 0.01375579995510634, 0.009166490453935694, 0.04663622603402473, 0.029738044795522, 0.02404016147920629, 0.0015589440454277792, 0.031736082601128146, 0.05631475200061686, 0.10477591175003909, 0.03457877908658702, 0.05507669011421967, 0.09582457176293246, 0.08210453961510211, 0.010131500439456431, 0.04394344337924849, 0.014795251991017722, 0.02130368859070586, 0.07729628356173635, 0.026556676639302168, 0.0485139932425227, 0.07769153657136485, 0.016753349264035933, 0.03496702993288636, 0.004321415526646888, 0.028566468208737206, 0.006438489645006484, 0.010555171211308334, 0.005599138248726376, 0.04093137395102531, 0.010950063351629069, 0.09294540985138156, 0.01895547211461235, 0.029471062734955922, 0.023860363216954283, 0.042423814375069924, 0.015301187049772125, 0.0725420039088931, 0.029515960814023856, 0.07671114464756101, 0.04240339418174699, 0.023584384471178055, 0.017061015860235784, 0.04593267374730203, 0.032149406906683, 0.03767887093999889, 0.04633732605725527, 0.012665310423471965, 0.01887990478280699, 0.08128349421895109, 0.03541171368851792, 0.05864561891939957, 0.0062554727810493205, 0.031903763447189704, 0.03602265707741026, 0.0673877660301514, 0.04460524614842143, 0.05528070279979147, 0.014995223682490177, 0.0297969601888326, 0.07840091100661084, 0.06921557185705751, 0.012945013822900364, 0.017151730426121503, 0.03324310622701887, 0.02245406201836886, 0.02298737676028395, 0.05129588556883391, 0.00855521866469644, 0.04812147133634426, 0.036411060063983314, 0.018887999758590013, 0.006146151181383175, 0.0649727952259127, 0.03936106739274692, 0.005744607542510494, 0.04929182709020097, 0.05524606676772237, 0.05877254472579807, 0.027677785328705795, 0.010382102373114321, 0.008104533717414597, 0.017679803750070278, 0.06342308697639965, 0.038107075306470506, 0.029743072846031282, 0.016433186756330542, 0.049063835613196716, 0.10212610315647908, 0.03353114858327899, 0.06304229100351222, 0.015354854531324236, 0.011640930479188683, 0.053355571726569906, 0.0261742739166948, 0.022761570908187423, 0.05092471525131259, 0.009294430219597416, 0.013539328465412837, 0.038358314559445716, 0.031099097250262275, 0.02649578898854088, 0.04103343409951776, 0.028371394691930618, 0.03514556839945726, 0.050254270172445104, 0.054380652072723024, 0.07812270952854306, 0.035287366845295765, 0.024061871154117398, 0.039328472266788594, 0.014170595568430144, 0.029564246797235683, 0.029339201646507718, 0.037755583034595475, 0.0810774666024372, 0.014108621599007165, 0.05570624285610393, 0.032953739137155935, 0.010882137357839383, 0.03456572099821642, 0.04760950818308629, 0.011257011919951765, 0.02360602178669069, 0.010879467481572647, 0.024513017160643358, 0.030231992313929368, 0.09057521281647496, 0.053662857972085476, 0.0173151977287489, 0.039505392851424403, 0.02360120153753087, 0.024424768380413298, 0.011710196977219312, 0.04770446968905162, 0.010368767834734172, 0.036578102663042955, 0.05417098422185518, 0.04879444342805073, 0.0352481183654163, 0.03503950065351091, 0.0356778552668402, 0.024299232245539315, 0.024942720665421803, 0.03126552015601192, 0.01157148122729268, 0.021592252305708826, 0.022569540196855087, 0.04127094733121339, 0.01782538714905968, 0.0736286565370392, 0.04085056520125363, 0.03907088394043967, 0.042887504532700405, 0.10022940376074985, 0.0611222621955676, 0.015792518497619312, 0.057357439800398424, 0.03814235329627991, 0.009651896780269453, 0.07863603081204928, 0.037126104507478885, 0.046778692412772216, 0.051158777496311814, 0.0604554054007167, 0.07869802982895635, 0.036143033430562355, 0.03792153096583206, 0.05509532173164189, 0.11487461946671829, 0.00845665867018397, 0.06096468940086197, 0.009831275729084155, 0.10068526054965332, 0.10019556924817152, 0.04947780558723025, 0.06882143949042074, 0.05037322160205804, 0.048602486931486055, 0.050427383539499715, 0.06902196037117392, 0.03335071764013264, 0.02516715911042411, 0.006141143076092703, 0.09351477070595138, 0.07311963971005753, 0.03998458276328165, 0.05703546274162363, 0.01581786655151518, 0.2056978060863912, 0.11352805187925696, 0.10684614753699861, 0.15969912201398984, 0.10525523524847813, 0.11884299441589974, 0.059155255439691246, 0.11845163768157363, 0.1712659388431348, 0.1090643453062512, 0.24656885827425867, 0.1477563480148092, 0.1033253395871725, 0.09866545369732194, 0.13972115964861587, 0.2136970151332207, 0.10374737670645118, 0.08690033500897698, 0.2018054641666822, 0.101598317414755, 0.1403141801711172, 0.12908854347188026, 0.1349843872594647, 0.12867660698248073, 0.10224880985333584, 0.14806312217842788, 0.12574248161399737, 0.06905533475219272, 0.10645454589393921, 0.10862694573006593, 0.16841147560626268, 0.24603690166259184, 0.08591200210503303, 0.15770606958540156, 0.17342253093374893, 0.1787488060654141, 0.24220998748205602, 0.11981094052316621, 0.1222692675946746, 0.09573855684720911, 0.07578259173897095, 0.12228607723955065, 0.20244267216185108, 0.18955953768454492, 0.10684211025363766, 0.12022479917504825, 0.13155118242138997, 0.16977499384665862, 0.15827143768547103, 0.2378984953975305, 0.18881615804275498, 0.11342608820996247, 0.07896496550529264, 0.13084841310046613, 0.07977694185683504, 0.05384444295486901, 0.13274930563056841, 0.10921980298007838, 0.12908640608657151, 0.1961745077278465, 0.22160047228680924, 0.11697831869241782, 0.1702368026599288, 0.1616586442105472, 0.14407743292395025, 0.15290201408788562, 0.08502490556566045, 0.16223005339270458, 0.0800249824533239, 0.13268298731418326, 0.33551276370417327, 0.13571500196121633, 0.15715554443886504, 0.08345290319994092, 0.1352595756179653, 0.14159855578327551, 0.16753869509557262, 0.18388654600130394, 0.16268555395072326, 0.15465554577531293, 0.15688997431425378, 0.08431363123236224, 0.1317780272802338, 0.12804374797269702, 0.1023568665550556, 0.16212539572734386, 0.12298489091335796, 0.08874247170751914, 0.20621457835659385, 0.09656418129452504, 0.09568529290845618, 0.20670009136665612, 0.1495773854549043, 0.07970456019393168, 0.20990841061575338, 0.0982478768855799, 0.09424977150047198, 0.12149678092100658, 0.10931496857665479, 0.13165888289222494, 0.13377856055740267, 0.07467465431545861, 0.1595624629408121, 0.19993909634649754, 0.17061555030522868, 0.1644148916238919, 0.09831601346377283, 0.22802778286859393, 0.11597448232350871, 0.1651237762416713, 0.21876849612453952, 0.14559867238858715, 0.11847613597637974, 0.11208396608708426, 0.20641662064008415, 0.24086223245831206, 0.1695893975556828, 0.2847188705345616, 0.1857473625568673, 0.11318051154376008, 0.14749710098840296, 0.18181412830017507, 0.09308267748565413, 0.1849843456875533, 0.2135176380397752, 0.1557042746571824, 0.14855467627057806, 0.08000475150765851, 0.16369106015190482, 0.11950326836085878, 0.15933771093841642, 0.09392158637638204, 0.1417401130311191, 0.09574924377375282, 0.07397777764708735, 0.08724279163288884, 0.11692320680595003, 0.19720831944141537, 0.19873236422427, 0.08258709145593457, 0.11206162002054043, 0.19059747573919594, 0.10317709558876231, 0.062213037454057485, 0.10863126502954401, 0.11812132259365171, 0.1237405085703358, 0.19538582739187405, 0.11172007623827085, 0.11853190837427974, 0.17881585168652236, 0.14530105632729828, 0.15276965947123244, 0.21052952884929255, 0.2042322573834099, 0.12762732891133055, 0.12953501951415092, 0.15367135405540466, 0.16311280836816877, 0.10887980286497623, 0.26664493256248534, 0.19579852087190375, 0.08055397047428414, 0.16556542832404375, 0.14203240047208965, 0.18095917417667806, 0.18672855600016192, 0.18882841832237318, 0.13377847149968147, 0.09904299906338565, 0.10382166568888351, 0.14460774196777493, 0.12630841374630108, 0.13710470317164436, 0.2067219401942566, 0.13295528129674494], [0.047608996101189405, 0.005838613069499843, 0.02514829371648375, 0.01609823139006039, 0.003165916409670899, 0.04444252284883987, 0.036736168985953555, 0.024332304201379884, 0.017844170906755608, 0.03364493837580085, 0.03421975772653241, 0.008422183127549943, 0.034051947004627436, 0.03230489797715563, 0.01732054490275914, 0.052736854340764694, 0.027811683612526394, 0.01869706185971154, 0.04024816022138111, 0.018309096740267705, 0.011725500062311767, 0.04760669915413018, 0.05113341459946241, 0.006053282068023691, 0.047548852453473955, 0.029261005256557837, 0.01860627678979654, 0.046358874315046705, 0.048218529409496114, 0.024105028896883596, 0.02745927107753232, 0.04186827973171603, 0.010679386323317885, 0.0952292802685406, 0.0166114246530924, 0.03491945084533654, 0.030372336150321644, 0.026835015414690133, 0.04879051375610288, 0.01788345463864971, 0.017462150390201714, 0.03279317548731342, 0.05375301407184452, 0.07732261496130377, 0.03181354055413976, 0.04962828345014714, 0.031141796716838144, 0.004667041584980325, 0.07159402899560519, 0.03492976298730355, 0.00789416453699232, 0.019235009458498098, 0.04010456948890351, 0.057862189278239384, 0.010778917603602167, 0.027658738108584657, 0.034367218759143725, 0.06467704937676899, 0.07180539265391417, 0.047836182347964495, 0.018966676689160522, 0.05052389984484762, 0.06403169260011055, 0.018462309417373035, 0.025830433187365998, 0.04053940123412758, 0.03260803561715875, 0.043442920432426035, 0.07969376936671324, 0.034031497125397436, 0.07951339037390426, 0.05218824022449553, 0.0053978492451278726, 0.021964559964544605, 0.022890322397870477, 0.025935296798706986, 0.013159309892216697, 0.007493839875678532, 0.029819514056725893, 0.02176115769543685, 0.027979848709946964, 0.06625687397900037, 0.025640313506301027, 0.016227546911977697, 0.011035693278245162, 0.08568204764742404, 0.013443566367641324, 0.010918630614469294, 0.019306730609969236, 0.02323867167433491, 0.03863638616167009, 0.060163021480548196, 0.022305574966594577, 0.06085361586883664, 0.027071408003394026, 0.03961281501688063, 0.046549142425647005, 0.019178789916622918, 0.03755016026843805, 0.06451984023442492, 0.03688798642542679, 0.02788917310681427, 0.0017071493130060844, 0.04986915490007959, 0.025452095578657463, 0.005221559949859511, 0.02474837445333833, 0.029736495562247, 0.04370103939436376, 0.032091842222143896, 0.058318569281254895, 0.012829394636355573, 0.042977278426405974, 0.03963249306252692, 0.025339257590530906, 0.05232256153249182, 0.05301105193211697, 0.05990549623675179, 0.021139341843081638, 0.02122680209140526, 0.04780167248100042, 0.023397879049298353, 0.0235124017126509, 0.028544563720060978, 0.061751172979711555, 0.022006610051903408, 0.027658669459924567, 0.0067409292023512535, 0.02144831647456158, 0.019792460698226932, 0.05845618943567388, 0.034934189898194745, 0.060796804464189336, 0.025664192107797135, 0.06958373647648841, 0.012096553491574014, 0.023414369570673443, 0.08394689895794727, 0.026302103287889622, 0.028236123434908222, 0.06187318947922904, 0.025108857844315935, 0.05638985734549351, 0.025809705002757255, 0.03318547474918887, 0.032866993205971085, 0.04570900899125263, 0.08590218349127099, 0.01599491515662521, 0.045760688444715925, 0.03477093967376277, 0.09469079275731929, 0.010518078670429531, 0.016800974735815544, 0.006660209046458476, 0.13798014057101682, 0.06338311490253545, 0.042652470074244775, 0.02726472263020696, 0.05510128117748536, 0.06897366882185452, 0.013912069352954859, 0.06249281970667653, 0.06377374433213845, 0.07383768243016675, 0.03223486892238725, 0.03446520080615301, 0.022806090491940267, 0.04970153713657055, 0.02603765195090091, 0.0806064551579766, 0.04411770336446352, 0.04426136460097041, 0.06201122152560856, 0.019289930241939146, 0.04502145740843844, 0.007121924163584481, 0.09789080737391487, 0.04621869004040491, 0.01886833841126645, 0.03562316269380972, 0.028221287902852055, 0.014278172657213872, 0.0011316230666125193, 0.03256625641370192, 0.10275569671648555, 0.0833443047304172, 0.015022997631604085, 0.07234883771161549, 0.04119729659578297, 0.06548037970787846, 0.03286474820924923, 0.056090827492880635, 0.027837137422466185, 0.0242239209546824, 0.03328188344312366, 0.01948484048625687, 0.04442389865289442, 0.03950818703742698, 0.03447913462878205, 0.022612586617469788, 0.04233295694575645, 0.0622538889729185, 0.07589694185298868, 0.01654966312344186, 0.025658030426711775, 0.05564743136346806, 0.05600263066298794, 0.03649326776212547, 0.046295264837681316, 0.04178521856374573, 0.06891817844007164, 0.0149503794091288, 0.011341442350385478, 0.068460896727629, 0.049346987216267735, 0.06919489562278613, 0.03249340719776228, 0.03087999670242425, 0.05758838131441735, 0.05111862359626684, 0.08068749026278965, 0.03488792441203259, 0.023503445845562965, 0.06158221935038455, 0.05436008344986476, 0.029843923293810803, 0.03591027365473565, 0.09029306311276741, 0.0522264905157499, 0.06778597278753296, 0.05655217246385291, 0.029200134304119274, 0.025215328205376863, 0.04998784286726732, 0.05257439821434673, 0.032257459897664376, 0.0703502785472665, 0.0657996664813254, 0.0160696791135706, 0.08313304497278295, 0.012674475019593956, 0.007002513993938919, 0.03384233110409696, 0.039966318508959375, 0.07665505312616006, 0.10947853792458773, 0.06639146988163702, 0.017298028142249677, 0.029309589954209514, 0.04170640248048585, 0.08107522531645373, 0.03971222940890584, 0.02021154221438337, 0.04787810998095665, 0.03749265866645146, 0.024732548154133838, 0.04693284761742689, 0.018723576940828934, 0.036388569278642535, 0.03013488785654772, 0.04534387233434245, 0.0070244245125650195, 0.026689209371397737, 0.0478378633124521, 0.031196964264381677, 0.10486649087397382, 0.011639188287517754, 0.044831783015979454, 0.1516689357231371, 0.018221200480184052, 0.04569305652694311, 0.0685515500663314, 0.03423526861297432, 0.042183113619103096, 0.07133167237043381, 0.020966328665963374, 0.0272632754422375, 0.04607994924299419, 0.09334343107184395, 0.04173199544311501, 0.04383992119983304, 0.016875341643753927, 0.03716594299476128, 0.027463646038086154, 0.012191319256089628, 0.02542365647968836, 0.018239505552628543, 0.0272617039445322, 0.08478301737341098, 0.06052090735465754, 0.031802549347048625, 0.0351545446756063, 0.05741601751651615, 0.0377663998369826, 0.04164586920524016, 0.005680873291566968, 0.023016196209937334, 0.03153698293317575, 0.04546131349343341, 0.02720199445320759, 0.10386565278167836, 0.00877947250046418, 0.013771897138212807, 0.04817656837985851, 0.019753206652239896, 0.023059090490278322, 0.05563827326113824, 0.06761702286894433, 0.06011442936141975, 0.05783086693554651, 0.058138364693149924, 0.018132838522433303, 0.025033453784999438, 0.022185924062796403, 0.03473256321740337, 0.018385319017397705, 0.03190208619344048, 0.025514883127470966, 0.02784098731353879, 0.045545391403720714, 0.010013271676143631, 0.029091938449710142, 0.0476394278666703, 0.006351122165142442, 0.011467114854895044, 0.05870112785487436, 0.01711367494863225, 0.023439615579263773, 0.027187917767150793, 0.034083607024513185, 0.05935420296736993, 0.04258087879861705, 0.050910247082356364, 0.06145237690361682, 0.03170835225319024, 0.06007029383908957, 0.045771486693411134, 0.029280466224008705, 0.07977146480698138, 0.013820582953485427, 0.04261768190190196, 0.07325213533476926, 0.042671587798395194, 0.06624026471399702, 0.02025014502578415, 0.08866384858265519, 0.04831597339943983, 0.005073111860838253, 0.01726502669043839, 0.05947557379840873, 0.018122281471733004, 0.08896887127775699, 0.21187174745136872, 0.13407797261606902, 0.07482784101739526, 0.11425928998505697, 0.13795060309348628, 0.10484795202501118, 0.07527677356847562, 0.0963787260116078, 0.177624749194365, 0.10370575706474483, 0.07147629468818195, 0.1344816415803507, 0.1114667886577081, 0.09748477095854469, 0.2008353138808161, 0.1366785026038997, 0.0927302983473055, 0.08564928924897686, 0.08236032823333517, 0.12380473403027281, 0.15903733408777043, 0.23789702594513074, 0.07341611286392435, 0.161158510891255, 0.11173025850439444, 0.2096136295585893, 0.23675000702496618, 0.1644306696834974, 0.21680490695871413, 0.10348429277655669, 0.14628974546212703, 0.11468040684121661, 0.20084276504348963, 0.09865406915196218, 0.2155799773754552, 0.07918309012893587, 0.07492748918593861, 0.10602316513541155, 0.132526260567829, 0.22985711751971394, 0.10255116823827848, 0.1929935737280175, 0.11516619444591925, 0.12513574620243162, 0.15367769199656323, 0.1606992253800854, 0.062206944421632215, 0.09838614641921595, 0.15640152239939198, 0.11772157216910273, 0.14153628959320486, 0.20659112924477085, 0.14179362187860534, 0.16553327848669142, 0.09753603852004744, 0.14762515114853159, 0.12180258287116885, 0.1229855662677437, 0.36276478262152523, 0.17442866053897887, 0.2833706553792581, 0.20708222320536152, 0.056847743908292614, 0.14498745440505445, 0.06551103040692396, 0.12193220638437197, 0.13139641494490206, 0.17819385771872476, 0.23514898668508977, 0.25303563626948744, 0.11096395392087288, 0.1906326980679296, 0.13759501045569777, 0.12546094047138467, 0.1523573519079946, 0.12510165193816647, 0.06183192977914587, 0.12866600911365822, 0.12544936296762899, 0.17735227709636092, 0.16448306530946866, 0.12804241210687906, 0.06890168791869655, 0.16118260100483894, 0.23091018054401502, 0.06100200458604377, 0.0942191579088103, 0.14931482844986022, 0.10546665085712448, 0.21512174571398646, 0.18160797451855615, 0.25104522588662803, 0.251321037649177, 0.19272323901532218, 0.1697846714523621, 0.18848646635888144, 0.1395552747999318, 0.10544440869125538, 0.22199168801307678, 0.12181562240584753, 0.10916173734585755, 0.10015261374064721, 0.19673442846396938, 0.14287513884482905, 0.10376598234870471, 0.13913554575992748, 0.10478057243744843, 0.10896539475652389, 0.10187021805904806, 0.11278674282948487, 0.14758584700757638, 0.10187708292505704, 0.2048976521473378, 0.12727633758913726, 0.18878004513680935, 0.1618340879213065, 0.1285878906492144, 0.06338902239804156, 0.1384397377842106, 0.1451140351127833, 0.06591468452825211, 0.10494877278688364, 0.15416399168316275, 0.12451603804947808, 0.24559216224588454, 0.1104251695505809, 0.07556544675026089, 0.16262961085885763, 0.09562172795995139, 0.13082524325000122, 0.12701965839369223, 0.12599093781318516, 0.15795706392964348, 0.18923385359812528, 0.1380489525035955, 0.15316630771849304, 0.1826601172797382, 0.21905140281887725, 0.1152635864855256, 0.14162665349431336, 0.10401737745269202, 0.15096511255251244, 0.08535217042663135, 0.1190304609190207, 0.12187722066300921, 0.08926077280193567, 0.18353515391936526, 0.07911283100838773, 0.13965932390419766, 0.12221354714711197, 0.14265957463067025, 0.15168575278948992, 0.12131554103689268, 0.09486821058089845, 0.22612990345805883, 0.15346891101216897, 0.10272836341755465, 0.19960995385190472, 0.09383868105942383, 0.21921730251051486, 0.1793858062592335, 0.08583397269831039, 0.16115244012326002, 0.19845926872221753, 0.1762520134798251, 0.1758548160432838, 0.09051696906681173, 0.1486219890648499, 0.06636297141085379, 0.20526489650364965, 0.11492565696244128, 0.09283156439778395, 0.08616327846539207, 0.14141104475129396, 0.10933648343780078], [0.09003412778838538, 0.11883434097399004, 0.026783065077324864, 0.022905343466845807, 0.033371468089171685, 0.019674433242471423, 0.01479598950027139, 0.039755518882884644, 0.023940611645230092, 0.021726243357989006, 0.062250426854006946, 0.03182731852575671, 0.04785586781508755, 0.08383130203583278, 0.05361558316508308, 0.03596773443860002, 0.010386093272245489, 0.09679535287432373, 0.05772101052571088, 0.02242770278826356, 0.038719718213542365, 0.01606145982805174, 0.08031197095988318, 0.011498534604470478, 0.019937830729759298, 0.002441292926960159, 0.0420157073676819, 0.024015295821300242, 0.06256252963794395, 0.013316679523995845, 0.027258922746113967, 0.04018457300844602, 0.05551355905481614, 0.060100970513303764, 0.02348565471038455, 0.025639871928433422, 0.04366571687569376, 0.011002145420206944, 0.028308089495112654, 0.012676868445851142, 0.061899335341877304, 0.03687649055791553, 0.020493639967753552, 0.05364729884604458, 0.01886606558400672, 0.03765036875847727, 0.016944639683060814, 0.03818871526164003, 0.05048728969995864, 0.014351236168295145, 0.01820040364691522, 0.052275049238232896, 0.03323353252199013, 0.03679970795928966, 0.07438208485837094, 0.05071477651654277, 0.06304255817667581, 0.06958997051697224, 0.018544706363172736, 0.01149501960753696, 0.05008122359868139, 0.0203278608751134, 0.05861694233317394, 0.004439987069417839, 0.030957014932937454, 0.017323199936072342, 0.0193433667300269, 0.0750070771027822, 0.10694322787458077, 0.01512983164502657, 0.013146102446626173, 0.04717564122984186, 0.02501663300790824, 0.01641850521991728, 0.054286232334561646, 0.07482049375539646, 0.03189120630850084, 0.007190030128185754, 0.019632251423900016, 0.03586355916922912, 0.025311825957032852, 0.010767700041469652, 0.020299735333537683, 0.0677643169183284, 0.015990076353773475, 0.06245620214031078, 0.04123252634599339, 0.027355993806850165, 0.04261506583134178, 0.04804337884706911, 0.04204926357488148, 0.016625030075374525, 0.01355981081360369, 0.03844087848847266, 0.0032427242877020035, 0.04603719040460419, 0.010867102373595117, 0.0798365066293627, 0.04004512717074249, 0.009172537102131173, 0.020432512974366546, 0.03330685300170444, 0.014109238509263378, 0.04791735475009773, 0.01628174966754159, 0.04485771736653987, 0.024498235434293747, 0.01768343285220908, 0.02159995765396161, 0.022379259098670445, 0.07376216890406795, 0.034538458203314804, 0.003656408998722327, 0.03448474897595588, 0.07934261477203108, 0.03884859586833045, 0.021475924368132837, 0.04121868529182393, 0.06086154200602323, 0.03738016392162535, 0.04673108735005371, 0.04591805343807209, 0.04487408172280993, 0.032723283729865216, 0.041899557545548305, 0.012720849972538417, 0.030858877034916077, 0.04605138397892006, 0.01907029905851232, 0.03469181559921708, 0.06568790646269917, 0.023473791479773354, 0.010303093331458513, 0.021716881165048108, 0.02780990987957921, 0.01019054849166423, 0.007472537454304984, 0.09021748279337771, 0.01239743129190174, 0.02049315571639454, 0.023630314135516528, 0.01782999959687004, 0.02753711123659741, 0.1763697774731554, 0.03814860217971727, 0.06168358930153772, 0.025139003882941324, 0.02059828650089912, 0.022784028296882752, 0.050430767732905224, 0.02679267588973744, 0.03392477628949564, 0.01374665298499167, 0.07537523430073634, 0.06226043842616491, 0.023677783756284043, 0.06338024279102683, 0.07391482125967741, 0.02668909804924624, 0.01515374086011434, 0.023059127597662155, 0.006882778207000229, 0.06417595126549713, 0.017496944128652103, 0.055056908167898655, 0.024687687182449736, 0.03490193616016768, 0.057751438580453396, 0.024904403580876533, 0.015294805507437559, 0.010485180191608379, 0.03190303985320497, 0.04520145790593233, 0.03967930773796979, 0.03275450217188336, 0.051649240631377324, 0.04828374563658144, 0.025181003875331953, 0.05598072617431171, 0.013844383629475487, 0.03341921044921037, 0.03054542168683838, 0.007918320516182575, 0.0608205606113188, 0.027920864667976275, 0.03659639289253391, 0.04558667336823419, 0.019752358748519327, 0.04134624934522435, 0.05490976254804991, 0.018729037292359862, 0.05174537101993337, 0.019049387192353606, 0.006331974755084957, 0.06699755220324732, 0.04096992481208872, 0.04725352591776755, 0.05505942775926087, 0.0765975886315573, 0.039131710364017636, 0.03585468679375481, 0.020307555714680348, 0.1571874864748679, 0.03515051481372211, 0.005708798453269992, 0.07154733306379057, 0.04165255595580675, 0.01838195152231492, 0.06512081658001989, 0.060515749428304844, 0.015902668055787217, 0.026596646857797168, 0.0693273170327302, 0.016945916177064646, 0.028854339871031698, 0.024379721871810034, 0.0375662388978526, 0.02187321828387212, 0.0017454066778554989, 0.026128509380214382, 0.026834911514015403, 0.04692703660111874, 0.018489952562958933, 0.02321771899005398, 0.02697098800126696, 0.01018941764414194, 0.05747377515945118, 0.035269165673526004, 0.09267597313737497, 0.04583448760968167, 0.005927830816290225, 0.04213813575915992, 0.08531173822120763, 0.04077775309269782, 0.0427320728340419, 0.10509491650736891, 0.026626423677953426, 0.029499963820853736, 0.044731786038028076, 0.02684154260350624, 0.03068923320824979, 0.02565418981248513, 0.019089503985014744, 0.06017102183250245, 0.21423159894766286, 0.03508969210088253, 0.03403913011425175, 0.03595314752601553, 0.06811590938013978, 0.03376924440090079, 0.008238645368692232, 0.06242681309231557, 0.026468583710084204, 0.07262533225002699, 0.036292539080022834, 0.008432683589489898, 0.0361283945676405, 0.04283035174012184, 0.018883917946368456, 0.05330189589585643, 0.04351335024693981, 0.070090912777232, 0.04132404428673908, 0.07506021487643011, 0.052457491401582956, 0.13706608180655167, 0.04558517051918898, 0.05954204054432921, 0.0018244712646264816, 0.07347002247115597, 0.03772531454160344, 0.06069572023989167, 0.05750722004449926, 0.0645974614599254, 0.025913891404343303, 0.030557685677194968, 0.04903743370960001, 0.08096670848317444, 0.023524995958723594, 0.05456461934954859, 0.038894449462532066, 0.013009295871597715, 0.010445518892083783, 0.04124847509956453, 0.019352068411535583, 0.04351611474703532, 0.01867488092102576, 0.07182045083027333, 0.054637182838632725, 0.02489898219209863, 0.0925877466215752, 0.0282258372681099, 0.03758141952857841, 0.012549740404210752, 0.04594654077664018, 0.04940828490362037, 0.10192785324761644, 0.019173952969140373, 0.011257416390435537, 0.04917101286991965, 0.04892708006082103, 0.017866353700810578, 0.03051490828511305, 0.021400132536655292, 0.012365599650365766, 0.04838766857574228, 0.05539996222069021, 0.05828436369483825, 0.02789675971143879, 0.030470778328890447, 0.03804860891250428, 0.03004677637363784, 0.03527972643496469, 0.03265438645030372, 0.10648799448972568, 0.0034387885716569144, 0.04378738085506484, 0.009088413735298673, 0.04406381231092382, 0.0486287255625939, 0.049510241151438095, 0.07575565919978544, 0.049286821304121986, 0.0250056640652474, 0.04626496294804383, 0.01564126694574952, 0.03130254590359982, 0.018984957641805522, 0.023461436576326378, 0.039245411098818295, 0.016182442886929493, 0.043501138206920587, 0.02134734171704622, 0.028864844971394632, 0.017476837492722552, 0.031593152380082756, 0.00826421050078352, 0.05738729640142992, 0.07111984115908854, 0.0350877068558475, 0.04362205261713825, 0.038784325879532844, 0.021499021859199274, 0.017680432720226236, 0.009923017241817433, 0.029044556031294633, 0.042458071911823936, 0.06637406651861966, 0.10055408594780602, 0.03609009974752553, 0.06861274014227092, 0.03734216596058104, 0.2355229400563985, 0.18964302929816768, 0.0922362061101012, 0.11224610309000127, 0.12500690936576575, 0.09338936259155162, 0.11390392741304822, 0.14027260505827144, 0.13541909283958375, 0.09365019781398587, 0.13534878176869825, 0.1417138855322264, 0.17954689683392644, 0.06837489665485919, 0.1552400315995328, 0.12915333296405151, 0.07815402816049755, 0.17042274033883587, 0.1367581053636968, 0.1299683446995914, 0.13460360612953082, 0.09631849330617115, 0.19873469456797466, 0.1395708302152343, 0.10965281646349467, 0.08139752520946786, 0.18341433227760717, 0.2547309984220192, 0.15890352486167103, 0.12887510180007666, 0.09035979703185149, 0.15403925150167197, 0.13245223875856027, 0.13732421561144292, 0.18325149023439735, 0.11346900661010295, 0.20132388453930616, 0.09235026678652503, 0.11989841746981256, 0.15648949658498168, 0.1488259164034389, 0.15450024395249784, 0.28032927482854575, 0.106795733445324, 0.13067994557786733, 0.15555341087747365, 0.13820887048495933, 0.16718676866730675, 0.14693523582536727, 0.14069441211177036, 0.1546786562539637, 0.1477237232029438, 0.14213593007298186, 0.15113314962945879, 0.1292604100308381, 0.16976910119410604, 0.24829176894854754, 0.23977764300070703, 0.17022095038555562, 0.19078752491623163, 0.12070898374076933, 0.1242499410000164, 0.1480784549494274, 0.16128139570355415, 0.14599515736335889, 0.12122066487791017, 0.11996583416475914, 0.2159114056848921, 0.2474608158809133, 0.1195693269255571, 0.12214062371640466, 0.1828753697918728, 0.1848851057002321, 0.12663157453062013, 0.12130279093980789, 0.23741583223454654, 0.1360990188550204, 0.09617122894269414, 0.1053952710935846, 0.10720832302467898, 0.1327539366320707, 0.13258469727588817, 0.0889823486795649, 0.07895060494774953, 0.08291610778542235, 0.22506233886815608, 0.16771853232057765, 0.18941337912110612, 0.17546866176417097, 0.2458645452861674, 0.15687435952713713, 0.2543880371376872, 0.09231877003912814, 0.13772942824289203, 0.16318239213433117, 0.11664973280858248, 0.18177914345869794, 0.1554787062923424, 0.0971706050040666, 0.0734600776922889, 0.10980909792124294, 0.1438207834144123, 0.08778253337368369, 0.1645340063259937, 0.11169334407895803, 0.16002281714463606, 0.04899154671875294, 0.06907003669766709, 0.13484428462106735, 0.18636977212736383, 0.1639042643364519, 0.10420522245112807, 0.16555920912651345, 0.13394419307587668, 0.17049514426616952, 0.18180853250669315, 0.10500021846382879, 0.11661691503832117, 0.19764091732213274, 0.15092482877662405, 0.13955563103081658, 0.06879774271510541, 0.08980632555903867, 0.13955177186289802, 0.14852944324957207, 0.11501099652377889, 0.13250766234705225, 0.11595819218200631, 0.07051166598103009, 0.18099694949341938, 0.15018912294181064, 0.16157761652721092, 0.07306301384232938, 0.10950522555503994, 0.10112675678101368, 0.0918171598459594, 0.15953310357872397, 0.31028686731588095, 0.1215256133582443, 0.17224616749444976, 0.12572579813422635, 0.12338317188550718, 0.12703223037533462, 0.19545325892977417, 0.16299451002851129, 0.11968568083830178, 0.09796675134566613, 0.10494827554794028, 0.1529167382977903, 0.1096446008887142, 0.1270959066459909, 0.1197703524667304, 0.08201007163734175, 0.1495248859282583, 0.19531269615981728, 0.09730476303957403, 0.16910692735109478, 0.16827400017064065, 0.15900046419119462, 0.09109407794312574, 0.10564553071162663, 0.18633738480275497, 0.1663667696993798, 0.13944150356110185, 0.18518380529712886, 0.10093092627357692, 0.1254188606981188, 0.1301706096273847, 0.15296770900022238, 0.12122851680032909, 0.1606267472379841, 0.12677412625635043, 0.21000462264055386, 0.06008357828250155, 0.18100756220519543, 0.20014556183014065], [0.03715949002071284, 0.06332282282528467, 0.059694937808671966, 0.06417966942535713, 0.047233098302967846, 0.010397295063739875, 0.05184321205888409, 0.04400530509883538, 0.040321606866200455, 0.03814721436356194, 0.04530959253315814, 0.06471147760748863, 0.05659336537064519, 0.04668274013965856, 0.03514617324981373, 0.06601117114769295, 0.033528844214743, 0.009214570491167251, 0.024498380153090693, 0.05309519292495679, 0.0793457985855639, 0.0073992397028632695, 0.04465395330043975, 0.03998310217866674, 0.019709128646354657, 0.009025837698573014, 0.023243131981871556, 0.04900574771454558, 0.04703945713117719, 0.03195682700606994, 0.057398168864892796, 0.0192804901234922, 0.03352836924022995, 0.019753935812332202, 0.025964103260776028, 0.0755984871648252, 0.02224547028163215, 0.034483847266528755, 0.07119086469174363, 0.1494532241486013, 0.05738720363297034, 0.04093602721695788, 0.05469150433782488, 0.002051251649390906, 0.035153791395714507, 0.07768421157379635, 0.05612849519820884, 0.08327141840709373, 0.016902352108445484, 0.03783347143325955, 0.028199337029946037, 0.017166638317576144, 0.08348808842129074, 0.02378836004936602, 0.028970847779419273, 0.046726222572033294, 0.01801122649339959, 0.08385215638554655, 0.05313122419465799, 0.05230748480244074, 0.03990532881289255, 0.015887884474068414, 0.02343504394957563, 0.008331647604791215, 0.026441684567544144, 0.03776360936171841, 0.011633511785476003, 0.042900518092210405, 0.026099402348336298, 0.018163468812417705, 0.049289678572677076, 0.040664664629730396, 0.037865543345105834, 0.04638223341316916, 0.052129146715742536, 0.01508291214122437, 0.006816690420237137, 0.0351119416882284, 0.053836965817026794, 0.04226184435538016, 0.02770548227999825, 0.017975072769331746, 0.03781494000577368, 0.03296440751000773, 0.01185167351650307, 0.05725682683987543, 0.05775211022410076, 0.008482221946906066, 0.045397310677799396, 0.024389627687924076, 0.06003317903378047, 0.03969041026721243, 0.04845954186748713, 0.05261137201159727, 0.027697888253896963, 0.04672488670621533, 0.033733688105712645, 0.02827432363119442, 0.04823395123821683, 0.021833734172105324, 0.04464883248147089, 0.04388288041809574, 0.09838880330789834, 0.03727278999576811, 0.03669287580123637, 0.04699026387243066, 0.02445016838464653, 0.09100038179894909, 0.07518155602156185, 0.04174303488980513, 0.06840175497927703, 0.010183081558352569, 0.018616024899529293, 0.057644918124424294, 0.03567202569684014, 0.017042979816324078, 0.018798168348439503, 0.03725871145434212, 0.03775560900976416, 0.031328142576967366, 0.044725084444507957, 0.07190408345195465, 0.051245742361061275, 0.06416882664780132, 0.024609297834103927, 0.019067779467150103, 0.038326558060362004, 0.025026184448506683, 0.04907763213850558, 0.039551699155708775, 0.038237426124396734, 0.025109442285611294, 0.04153036505158525, 0.01364772748274845, 0.03122136607998982, 0.011666984501061961, 0.048848846563487314, 0.02364248164667515, 0.08516411020536907, 0.01706978804577375, 0.01566643131809542, 0.030222177410905715, 0.027215369809709955, 0.05511390139872674, 0.08765734048211016, 0.03335168614285067, 0.011805394115071977, 0.04247271819622256, 0.04319780018704478, 0.02292155011673458, 0.06823914300184697, 0.04570251519908197, 0.02437022609228734, 0.04219000446028076, 0.07694351850659586, 0.01987976695090765, 0.06198578070325311, 0.09358066599816084, 0.0179321914765751, 0.05110880498250481, 0.05550420799409039, 0.05938302056165412, 0.051698586030397564, 0.03075045668083476, 0.09709645702969283, 0.06125208608864341, 0.03692809208587278, 0.01764750362781342, 0.029383780602074694, 0.05829855355841573, 0.010829538568941643, 0.04099389989278279, 0.0909530624630861, 0.04042924425448291, 0.0280798104358837, 0.028609499786398374, 0.05477412021718919, 0.026875275070779026, 0.04391152360767592, 0.039272069043363445, 0.03807302186032757, 0.0030432514586209436, 0.04723719124740455, 0.024656481728015933, 0.027370936950319447, 0.03147100600472186, 0.017798107655835338, 0.0223800661842688, 0.019796971100731753, 0.05699156470654998, 0.04779288916324731, 0.1333130113198422, 0.030959772011556197, 0.04260040099325124, 0.05876220660866238, 0.10136833327123895, 0.04184782243100926, 0.02530636003939435, 0.03878144263580907, 0.043346649035811424, 0.0455979354592273, 0.05377260677050799, 0.040731153640081175, 0.053325629778555594, 0.011301660451863427, 0.030441710259765387, 0.0334371741337236, 0.0687861058395356, 0.015864501256146468, 0.023899003135738894, 0.04419598510139622, 0.047955037298379466, 0.04245003445248585, 0.04433890790096484, 0.06938754973816685, 0.07717502405284904, 0.04558779030048754, 0.058343976706964895, 0.033629568497417495, 0.053762558090966195, 0.07826575849321671, 0.05105748547066469, 0.10452764108777046, 0.06585598806850612, 0.02207324192568194, 0.05692591061233543, 0.04099899473658297, 0.07650516155990772, 0.023865619477874134, 0.0645802213693969, 0.05004232392820995, 0.051583349049906246, 0.059549833094934, 0.05718715772673022, 0.02407039843092207, 0.09094587847357616, 0.048389965522801504, 0.04918109865684528, 0.0361891690408811, 0.0160489416521159, 0.03863433041260578, 0.00759857082812232, 0.016733626689529046, 0.050405245274305344, 0.027305572293698788, 0.07709380341111682, 0.04105575419089291, 0.03167838804074563, 0.016025536169763654, 0.0858804905146826, 0.022007263141858857, 0.007297788115465664, 0.024979206500574946, 0.05734711652621627, 0.0731292059936095, 0.01633039744774578, 0.02271512545121368, 0.04106935404706746, 0.0890589234768413, 0.012479796696425183, 0.035736859717871994, 0.024080829316517338, 0.03803867155511398, 0.03962749840866309, 0.06983372892136686, 0.030960013209551107, 0.04572890597046353, 0.03138121355732437, 0.06890713528264314, 0.023000208493613172, 0.0239675441844156, 0.009575085423421115, 0.04964999869116582, 0.044501052325358614, 0.04816595195734408, 0.021081584200146608, 0.03535726231348235, 0.027732056732929777, 0.03441072716668714, 0.016323159652529284, 0.05821100981847849, 0.007402753772112192, 0.017298712773481384, 0.008738664582779165, 0.029840802562830504, 0.019270933116786182, 0.05603114397672471, 0.08186623599613085, 0.11188325966941193, 0.022215008830244187, 0.03077962865063455, 0.03610754392866511, 0.06299857850535773, 0.028188184405735228, 0.05364940283470787, 0.03133604273898527, 0.02496357872587396, 0.04490512204938568, 0.045591638336190954, 0.03853147987683769, 0.03836852280073799, 0.027283419185550883, 0.019102022160950582, 0.050599751048139296, 0.0430507955752546, 0.041148021700792015, 0.022323724188026972, 0.006170049264255795, 0.0752849668788258, 0.042951585273840465, 0.06986307344050147, 0.01956715394044295, 0.061346995644271374, 0.02620438655867474, 0.024779309023870155, 0.04897788749076426, 0.015368925651273457, 0.021030799034633674, 0.013454398012981983, 0.08436544798314571, 0.018469100068614352, 0.05443077672680374, 0.03625002886110451, 0.036790553567698225, 0.02426663340884261, 0.03002212779392721, 0.09285054853535257, 0.05424503942776937, 0.02242706083052326, 0.02028255461482331, 0.01943118877534289, 0.07085237855790183, 0.035177866666344926, 0.07067065627779812, 0.005610254693237948, 0.06740204495145008, 0.03240371122956276, 0.030712315856362693, 0.04876752573181875, 0.07268616609508172, 0.04538864239293616, 0.06622988206800073, 0.030934143796912394, 0.024259403035102878, 0.04225768832839094, 0.021075288932479452, 0.02033049921010388, 0.06442940211854875, 0.03474940996966325, 0.03427788273256738, 0.022037166127120145, 0.07909481908427551, 0.12590716418344527, 0.15197615517536178, 0.21682252554455772, 0.14597176486859098, 0.09785895439563319, 0.10110455172252841, 0.13051667308900505, 0.12262215881492011, 0.09677257636212744, 0.13605273852590472, 0.1309251066413708, 0.13803780544549227, 0.07839671045076102, 0.11708678357535973, 0.09387494981638156, 0.1942237131879665, 0.09315924486145377, 0.1307440671371296, 0.2061032413621433, 0.16931003832723945, 0.12813497276511043, 0.13114798843162134, 0.16993571334751323, 0.12040200919727795, 0.133662651933264, 0.08996163480333053, 0.07350223168032244, 0.18185071618063375, 0.13552109361626208, 0.17474950582254678, 0.1419846952194348, 0.15585637040203437, 0.12991914030862972, 0.1439181828754954, 0.11513199628097937, 0.1697583103668876, 0.06700886253383942, 0.23238951835082844, 0.14402436936507002, 0.28067847015336156, 0.1299551344709471, 0.17389885615557432, 0.11475540828541853, 0.09222158580087125, 0.1317211490822956, 0.11712021732819267, 0.1872097051818855, 0.12751306785503402, 0.09263211963116191, 0.14278323127655312, 0.13253942626761273, 0.15570713934721425, 0.14388650801265612, 0.22003280406352133, 0.11982414333033375, 0.28151899692602456, 0.10454399060108699, 0.12537979404442012, 0.09297528129536659, 0.2363164591952227, 0.14725337969139218, 0.10096257145050913, 0.14797066542087123, 0.11763457019696943, 0.0811270643316675, 0.11516205326188356, 0.1131324574816972, 0.11829118535388261, 0.10957589285681024, 0.1680244307499379, 0.1448335181339644, 0.13610841444460675, 0.08041932262131013, 0.1335777502390556, 0.144454087712802, 0.14484735176665708, 0.13281310064485297, 0.18315165652893484, 0.14725940593052655, 0.1401835324941203, 0.0911127429571934, 0.13771750935120508, 0.20299088180763647, 0.17214376595802605, 0.10470938563230447, 0.14784311992116272, 0.11991248858976178, 0.09555710916174576, 0.15622167033143342, 0.08035458507947624, 0.1199734782858286, 0.11258260026806965, 0.13837045087711886, 0.18866082653403282, 0.16104871756397188, 0.16306505858665332, 0.11637829229584895, 0.11017521421308629, 0.1058413834834937, 0.14035707630682737, 0.14650734316091985, 0.14195506868418306, 0.18805192405125126, 0.0931072277307976, 0.17793021717807278, 0.15693101508077234, 0.1006156619405374, 0.14642869035014883, 0.1756376784760505, 0.06977899553021416, 0.19752906082430854, 0.1699297019513324, 0.13044406136032194, 0.14161286439048126, 0.0871799243032001, 0.0890009172144346, 0.2170193727943115, 0.1024947056430392, 0.09606196996173821, 0.12421905281371437, 0.12189751098048873, 0.12023687391774729, 0.1442923885770142, 0.1690741689526476, 0.09884115715976804, 0.12033381324727088, 0.11904458398930728, 0.12094806661480106, 0.08463809819659218, 0.13940426259068772, 0.10429278103401884, 0.10354117839597166, 0.1418044720776379, 0.1442336550098844, 0.12083330089808442, 0.21163667959626764, 0.19946360233007, 0.111968584387796, 0.1825497450772673, 0.15044627711176872, 0.1332788576837629, 0.17550303804455325, 0.11241853368119337, 0.1968325997586362, 0.17261451022932306, 0.2100825184606947, 0.10244610981317237, 0.10597497006529011, 0.11987133650109172, 0.13195327803259715, 0.1258279028115794, 0.09888692540698685, 0.1343847467796877, 0.19105358485830948, 0.11124214055598713, 0.1430644013453275, 0.16603820607997477, 0.1604470584425144, 0.09334908623714, 0.14624591422034428, 0.13966717582661659, 0.139976087375544, 0.10054946978925727, 0.20444943947950378, 0.17622038314584643, 0.19397910131374374, 0.12976086989510804, 0.07864867700845934, 0.11197731946595013, 0.1375341395032592, 0.10076386883156374, 0.1420631996006705, 0.20882494922261685, 0.12170847112429328, 0.10806931080878712, 0.18761251325486228], [0.001026313934744394, 0.02957405427878257, 0.030612200134783052, 0.1422325280145742, 0.06396080265403725, 0.06703597318846732, 0.04565058341540862, 0.07235360972117633, 0.060280154648353346, 0.04519494184933137, 0.035736492354772054, 0.031055544313858263, 0.03697479914990254, 0.053367011933005415, 0.045914635848021135, 0.07250523049151525, 0.02099962697684532, 0.054635772758047096, 0.0571196593955392, 0.04246786826115567, 0.0842493686650414, 0.02960128924314631, 0.06457383889937773, 0.024045029967965093, 0.036597483849618584, 0.060687693912768736, 0.029516014619730413, 0.009979804526665248, 0.010591352765914053, 0.025212699147232343, 0.07195839381893165, 0.05944168362475466, 0.04092704723007046, 0.0437999379937537, 0.038611260752077214, 0.041987565127783455, 0.043406002296251245, 0.020643253228627145, 0.013851405274181161, 0.0709863510564901, 0.11442401708336547, 0.03585732512874529, 0.052004885219503194, 0.06074321398045868, 0.04893771132628899, 0.021701442638004664, 0.0675807986408472, 0.02966054973512655, 0.02785005264740903, 0.04200228191621136, 0.014955964070395567, 0.015066894738993142, 0.05154204853170086, 0.04292866033210885, 0.030577319193980657, 0.04942413346725516, 0.03421550150960684, 0.03128083066258114, 0.032612759387120605, 0.023041624044708442, 0.013299587863002671, 0.03964401861594524, 0.02592776028905064, 0.0976279386668466, 0.0456072531233076, 0.047384945428348146, 0.03260405770561192, 0.04247161610692274, 0.03732652519829571, 0.04768106977280695, 0.005386407183323172, 0.04658213088987395, 0.022104388008301612, 0.01794362240616465, 0.0637594802537933, 0.06276244195760228, 0.06906683061970398, 0.07595722650876269, 0.0575741172360722, 0.016701243075658567, 0.04504382573941257, 0.019720874988706782, 0.04000413464382291, 0.03503065796394367, 0.023847342235967517, 0.04486090118007269, 0.02797097262373427, 0.03467139911663253, 0.05361083341995254, 0.015786614712851588, 0.015031699313112767, 0.08302405316499062, 0.0446174247917952, 0.031535313100903295, 0.029927880605100654, 0.004667664989028708, 0.018791843394865282, 0.016546217702853028, 0.04391602473333478, 0.06346571593894623, 0.05600842312560417, 0.014817629598837811, 0.023225424338306766, 0.057633707983768545, 0.031232780311256647, 0.03314471228804905, 0.02579208456154447, 0.017595822318980936, 0.012027386255795136, 0.024100841328618117, 0.047337043506558985, 0.010690880335459951, 0.02465511246555252, 0.030807221701252274, 0.017851627635536715, 0.04169581945461687, 0.07060513205942698, 0.03555987976142205, 0.01500386135376175, 0.03409062403079588, 0.003632448065218341, 0.023824374620744493, 0.03449265284871217, 0.08329209464136511, 0.029157585122447927, 0.06521429750137031, 0.03288297164544929, 0.03666247743240092, 0.022461492771981284, 0.06673236799542792, 0.03904874196450692, 0.03145627437334042, 0.03540093399351463, 0.05166050272237044, 0.011850877563119866, 0.027530389234016184, 0.023848852506489493, 0.01801190370315453, 0.018645554955583066, 0.10986861816491, 0.05555581323278602, 0.03015780537680257, 0.042398258519824594, 0.04160794545896351, 0.06935110286576673, 0.01760344788635848, 0.07461042143404484, 0.09122742703766562, 0.06023130648827646, 0.01662758306338219, 0.03710931712703314, 0.045466118899639696, 0.008673468764754944, 0.03665964242827613, 0.018469871902198065, 0.11154652500408702, 0.055058800644474104, 0.024753773577685934, 0.07034555106656626, 0.0640022441803012, 0.03638019414211158, 0.03429737153055612, 0.0359503867366584, 0.03872047149343416, 0.005466571192300762, 0.030467998985841405, 0.005855058598172036, 0.020870506268693134, 0.035481364247971214, 0.006569645229319576, 0.010913788100879174, 0.08116747427266091, 0.08989055932033807, 0.03587883627915289, 0.03935043241654057, 0.06647369242273271, 0.03594582623918541, 0.04493651489610784, 0.05873752277693711, 0.034230014207423665, 0.010934338170045521, 0.04501876712311059, 0.060736267478205264, 0.05312734647304751, 0.03755775614990853, 0.05970254111161921, 0.07059278272208758, 0.030935186514398083, 0.024648952639836352, 0.010550135739322286, 0.044165364088257775, 0.055589291514479555, 0.05514370604942087, 0.02844718095730059, 0.03745193331269547, 0.04808453093573917, 0.03910613224434201, 0.016863265045685694, 0.08549577600206248, 0.02555345810833387, 0.09962691343389452, 0.08247286750702187, 0.010361583845224231, 0.050705933826975524, 0.032597578756394796, 0.03799928577791434, 0.025070895135286264, 0.06786308935261331, 0.01272101973881945, 0.040638385180500336, 0.1132777106249705, 0.06228016471141018, 0.06301481669652276, 0.04624331078957766, 0.08571573373046704, 0.03046539033675799, 0.11056616276619025, 0.055141461052699015, 0.05299638338328805, 0.05218296355451457, 0.04852334801398683, 0.0280897032644134, 0.06441982099204324, 0.04436995193827897, 0.01919663671287708, 0.04367846326204017, 0.11110305465990677, 0.021846996351087, 0.04298087784263771, 0.04972384238499217, 0.02905719851696631, 0.04961125487170648, 0.03451958538789768, 0.023493953776778653, 0.05845715422765352, 0.07517163350712508, 0.03059394144656835, 0.06395318079739809, 0.020416916740941815, 0.08241187038947828, 0.03474053017271217, 0.02328427664906485, 0.039409065793734044, 0.011108612998214085, 0.020242178070475347, 0.025547404038661625, 0.030544725923391525, 0.01053985699400073, 0.10266170371323824, 0.0782313451054506, 0.011320380199322244, 0.07565665669972077, 0.03436608698393684, 0.04703310434706509, 0.11983621065155603, 0.0162510062000365, 0.03931041581381578, 0.0158800752251409, 0.040554622682975605, 0.035136896403855644, 0.038858013722347096, 0.04369834910903592, 0.06856194013380446, 0.011333415095577948, 0.017495556312496774, 0.053450763298314996, 0.02087053409923101, 0.007182663848652737, 0.005867810550626018, 0.022630472376476973, 0.056327468701056205, 0.03532065587933175, 0.05272002985293511, 0.028349762942525558, 0.04265079653123394, 0.03271121640864294, 0.04184975572570693, 0.05877329800568987, 0.05681192415067926, 0.10334419755963609, 0.03187693109794054, 0.0391795009636553, 0.049069090018747374, 0.06553995190188289, 0.0312060778378509, 0.015562416538159596, 0.0334602141083451, 0.02160013948014239, 0.057025607020477764, 0.05408437558799051, 0.03880918040522374, 0.019825009439955465, 0.05255282769212499, 0.06421340745873749, 0.033641743430052884, 0.02545684161304962, 0.0033992926319115213, 0.043031202876591124, 0.026416154687467497, 0.10157553348108195, 0.04815430766029749, 0.016188185254577547, 0.03129436372546479, 0.029030212172074243, 0.019334971184434835, 0.004700263361883117, 0.03232534414564725, 0.010740113484644098, 0.0197378905795631, 0.019124381215078756, 0.00899512391697499, 0.03014631507539889, 0.02623166419652989, 0.02889672392484499, 0.06700755635392852, 0.022019781317794695, 0.005038714707552572, 0.02952131169877248, 0.0028375200054142624, 0.060205309055163525, 0.03657412475149613, 0.023349817565758713, 0.04835455765714869, 0.004282193485778407, 0.013836550260748481, 0.024273546514450572, 0.029128435417078435, 0.07613497087731957, 0.060984040901530534, 0.049019069265341386, 0.004818439711016254, 0.014852487347525312, 0.02897680165915517, 0.01734045672492357, 0.0585513290570816, 0.03378264016646426, 0.03536378208082169, 0.04445180711627472, 0.044610956974793226, 0.01809300374588929, 0.02624764820211567, 0.016795466144685633, 0.01243674192664912, 0.03803783663897775, 0.04018583094875794, 0.07100740578607656, 0.010305142586730653, 0.06803655895055272, 0.004164827469139709, 0.07385711927781813, 0.053399202588479966, 0.02714062440645648, 0.15690429776441306, 0.17160312621854246, 0.15371514076832682, 0.2683801035163924, 0.18373296596109867, 0.14772670663660392, 0.20276691648177803, 0.17120935750426725, 0.13339908560737967, 0.14921741414582357, 0.18116124614607543, 0.1632665516808629, 0.08963985441369005, 0.16690973978256807, 0.1036931479757186, 0.15916461241431534, 0.21217671077465639, 0.3309190773870796, 0.15301492443541065, 0.12931132136145607, 0.158979001280386, 0.10102762069436722, 0.2356067136861384, 0.07517389705753885, 0.1265940218581818, 0.1685915354755707, 0.20151060889475048, 0.1931342255556956, 0.09613692687707953, 0.16627155215246603, 0.1516833482310176, 0.20407030591741204, 0.10965880559524521, 0.11056225906941108, 0.18130728596588597, 0.10727980668889359, 0.15472118131583557, 0.10708239540690556, 0.10124092135811225, 0.1274908331106417, 0.23145936982473359, 0.08685239969054237, 0.14245871978346258, 0.17961648060008883, 0.1285804543294944, 0.18559792370069772, 0.15118089941097423, 0.14196106523741037, 0.0771218714362476, 0.10288062985637225, 0.2285335713531822, 0.08546149620087817, 0.1396942196879536, 0.1030736995744519, 0.08091383788269013, 0.21685360668925568, 0.14750510134035721, 0.11146868855576031, 0.1861817267490551, 0.2093222178518772, 0.12815254682209343, 0.16454141295980662, 0.18343631469178945, 0.16375074366806075, 0.17773869854863733, 0.05654614622471854, 0.15477587759960443, 0.07516252735513262, 0.23015173530438915, 0.10112510921317153, 0.08013818223844282, 0.09580981786712073, 0.2103416170575656, 0.17483102332334965, 0.13425730518065393, 0.1958866583299823, 0.16729402384953573, 0.21204198128543794, 0.19135706388624385, 0.14663695183116943, 0.18801162543240935, 0.1365822905790992, 0.21170090505620465, 0.11831805852125399, 0.09795898105949163, 0.12643702793866396, 0.10079853454953991, 0.164770751434844, 0.14940575638320297, 0.15591829520417377, 0.13469296070979908, 0.13666064653079957, 0.11188119649887085, 0.10115870623849332, 0.12800301890820265, 0.11859609672683291, 0.16167397698154673, 0.14414081233553588, 0.16186297230888158, 0.1288057109923102, 0.18558000825578347, 0.1386252895463258, 0.1412376345251687, 0.22004083410138264, 0.11408613951061852, 0.1495746840373613, 0.12237027389346622, 0.10685412562452257, 0.09787237242562696, 0.08640649510198273, 0.09199647756759077, 0.09963702148525044, 0.18568871804745868, 0.13720726798055694, 0.11394298664527014, 0.08823566648061387, 0.18683309492189437, 0.12693444499745965, 0.14647394651547074, 0.14439556194702163, 0.11813415432698093, 0.10081270957016386, 0.09647290455177426, 0.17244702234165743, 0.16962464957032353, 0.16739817685447633, 0.17134236521087587, 0.04929225011437666, 0.10809504849021323, 0.14361645531607792, 0.08836448105284944, 0.11852971161715686, 0.13123753597028553, 0.1873475220054388, 0.10777193965623155, 0.1559918123530224, 0.15787953918334097, 0.08106217836029828, 0.1872618484776467, 0.1870182904531248, 0.14245747297536582, 0.09892013651551679, 0.07477928229491226, 0.12397950980812311, 0.2747523912694305, 0.1257942389929667, 0.11463648654171266, 0.14570926723536104, 0.17594029661267996, 0.10155811527511105, 0.1377417627372779, 0.19181909534381703, 0.15204833645839244, 0.138610505964607, 0.1082052945275791, 0.22911525185918435, 0.14162050851155072, 0.12372545781545341, 0.17883088759845123, 0.12251764957909472, 0.12055791958118789, 0.09225212517776527, 0.23320923530263826, 0.12046601201291196, 0.08041655441047624, 0.11029600616893731, 0.041753206023713574, 0.10526195910642855, 0.13364221318624914, 0.18122263660188764, 0.10999683901900426, 0.18493534909794107, 0.15400710166431963, 0.2133942930959165, 0.15069899323862046, 0.09346926963189617], [0.03430637007113546, 0.0607157433842076, 0.08224669058108702, 0.022944658740016166, 0.013320454272616189, 0.01552658843138488, 0.06717128155287355, 0.017374053750245366, 0.06234183718333952, 0.0076770659325120505, 0.044153129783808254, 0.03806614957284182, 0.0363445116818184, 0.06161515586427413, 0.03496001292660367, 0.08152960523148067, 0.03290533626568504, 0.04581670575134922, 0.05575412251346279, 0.02207049783464754, 0.02142789999197703, 0.01807350567105459, 0.08164479397237301, 0.043801696883747354, 0.04656489079934545, 0.06454880625824444, 0.035685299008036964, 0.013769945289823227, 0.011088402461609803, 0.0708718376699835, 0.004776913301611785, 0.044772949258913286, 0.05989666467939969, 0.04467105238290969, 0.08505562305799685, 0.05855416035046801, 0.05472057426231913, 0.021831416815984994, 0.013526518996513914, 0.013135191948094871, 0.07548668261733837, 0.05814608673972543, 0.08032875091885217, 0.042006556686828844, 0.02888348029955523, 0.047299483412643895, 0.028361065851640888, 0.03684473405883182, 0.032186261960305274, 0.01711725395580288, 0.05184286696021445, 0.04874189937254414, 0.017668356122158002, 0.04937106619763654, 0.06411558497347869, 0.02247337826702278, 0.005747575669374783, 0.04619798040948808, 0.0246021991915768, 0.14478333410806954, 0.03898782277246937, 0.0497888359677745, 0.021623947577609215, 0.07226460395031609, 0.011601540991250658, 0.04430977118317969, 0.027352620745659806, 0.04894508085271809, 0.014515231323457556, 0.056096827756846324, 0.03701224421092775, 0.04320085412473418, 0.06313310761470348, 0.00625006159680197, 0.04869985299592372, 0.06608184587094001, 0.03427518873650115, 0.06177034636493772, 0.021726792547269724, 0.05409824261732865, 0.05141895220731385, 0.0819687636976596, 0.009768283161974978, 0.03794158750679344, 0.05083019161247648, 0.024891367756936233, 0.06116997486969922, 0.027880013149115257, 0.05678605659340974, 0.13401226286077872, 0.01694091595709324, 0.05374072781705763, 0.025380879087606445, 0.02289069161633961, 0.08091336290817708, 0.094840513629606, 0.03325516612676438, 0.07429336110362783, 0.07984670373843983, 0.01960238554602256, 0.030732982813788112, 0.02895634064771002, 0.08317188156070188, 0.02602831202239031, 0.06455208655097522, 0.020905758283333853, 0.07789826180669479, 0.04640405997633934, 0.02751302297838265, 0.04594113052007742, 0.06876344807096757, 0.04102928549400531, 0.012317511263972847, 0.025296253843407612, 0.029959030398458708, 0.023472769171348773, 0.03403467722819187, 0.03842741221887991, 0.05569355584157165, 0.03019305739144329, 0.04603064837283455, 0.047810912219574675, 0.030185949472070206, 0.09239258404704742, 0.03098741886788048, 0.04985890212992672, 0.04060781982843764, 0.05814484364236705, 0.03767436239286326, 0.01637632340134587, 0.02520646510674851, 0.03971772130171303, 0.05750901604187675, 0.025663559426902793, 0.09888094369671308, 0.06127578657469712, 0.03356679022544995, 0.018451739379088394, 0.007486898475690396, 0.036397820149431936, 0.027243257864029147, 0.07593722562887706, 0.03784262953558937, 0.07345700520090759, 0.029387890244834125, 0.022172316785145085, 0.037646264681825414, 0.044101502280682325, 0.019124301434203517, 0.09360774696688168, 0.04316802151151933, 0.0680854071106296, 0.03975391584390309, 0.023264845367521048, 0.04004906797490548, 0.06086550136387814, 0.10827647391124628, 0.07154277627705596, 0.0012689799905274413, 0.024311256893270183, 0.02531623245886294, 0.059345441914047115, 0.045534274031524546, 0.07256957469508052, 0.09767910232767463, 0.04455570779100526, 0.03948404126276728, 0.00903114127140725, 0.07545038417447358, 0.04851476136536803, 0.01708046384010231, 0.05718405926018022, 0.02759529190370813, 0.0338859211478848, 0.025294524639321025, 0.03837367330561392, 0.027425499647506513, 0.04610880394466221, 0.07216598736704327, 0.05717741332773585, 0.027952444906986784, 0.04609195348166395, 0.024947310848801862, 0.026787642273120582, 0.06528141733724624, 0.05208590177062433, 0.01293321831326466, 0.03286798768385779, 0.015599641737935599, 0.08096407385892235, 0.024236209064838476, 0.024603995188954286, 0.055865993854240514, 0.05047487728006672, 0.013119614268362056, 0.039523812956758775, 0.04935951466904953, 0.01984168735361891, 0.0195303155851434, 0.04761111493280623, 0.006005594441376161, 0.04810644284589216, 0.026216554069833364, 0.010609051132632885, 0.10505348982405849, 0.04893289107712917, 0.02410283213976072, 0.02186945373978233, 0.023276832907868084, 0.008257085883087711, 0.04767679871292785, 0.021380467478593346, 0.03764070599572733, 0.016223680322582368, 0.03028765153430868, 0.030688893675687723, 0.06847272656159475, 0.037382126902230084, 0.08233117667259648, 0.0426793989026919, 0.04882188804913312, 0.045082435972290114, 0.0366583659342723, 0.1119214431673754, 0.09749703865963966, 0.015668641062802635, 0.02392306170804659, 0.052491158930934034, 0.06578533560968935, 0.052972211633459665, 0.05821129183459561, 0.017132753710029647, 0.0900033583457116, 0.10283656112733297, 0.0790653855074197, 0.027248970545770135, 0.03131497687718365, 0.005938965350651415, 0.05366525139834266, 0.05120863497722894, 0.05202812928473577, 0.08075236139120534, 0.02213835239672335, 0.038673860908602364, 0.01828355572797591, 0.08088054513791576, 0.03512410919938702, 0.05257079879811499, 0.054194254262256436, 0.0371502465714002, 0.038435716851381585, 0.08058558596530929, 0.02877890241506975, 0.04664873493311461, 0.0532994022796629, 0.020027339305670466, 0.01973473645193735, 0.06629676441662014, 0.016889052822079975, 0.07689399499213323, 0.04076387493114453, 0.03537503303959966, 0.055492285391665064, 0.027570064448809717, 0.03568915446521714, 0.033764453837648034, 0.024501389561919495, 0.01887397316750139, 0.0500497713801451, 0.004115671781619312, 0.09844277228694409, 0.06675722994259559, 0.01810495046811411, 0.040674453557585366, 0.050518753050710075, 0.03249234221584629, 0.029738853736489546, 0.06508258113171905, 0.09150865647825412, 0.054486723529407755, 0.037500740654650144, 0.02637795634655049, 0.0360230021760799, 0.029229777537693735, 0.01623355088668177, 0.060576676041819155, 0.04599499559844844, 0.04627024332876317, 0.02831440702721011, 0.057726602608454414, 0.04695828472904395, 0.04305787195335142, 0.014186032240104396, 0.04478988135815598, 0.044991630493314005, 0.0381693340750644, 0.048542491713305935, 0.032753607883933, 0.0022003321873853565, 0.08025046918191947, 0.01730116371618351, 0.07385042510577478, 0.044498677452793345, 0.03148720337776467, 0.04700987883552443, 0.043460936067276634, 0.060308693937258795, 0.029132520940038376, 0.0477982252050424, 0.034065394720528275, 0.03540275967679918, 0.05910667074203957, 0.021082120401842985, 0.020601585347321816, 0.03078206103964476, 0.09649609666666947, 0.018654620289453305, 0.0268660297660972, 0.012164242925791768, 0.023632880111108534, 0.06169217966089491, 0.044329549418762326, 0.0708770623896271, 0.03890223830239847, 0.05175671474717092, 0.044432117938413285, 0.02085952990455553, 0.13778635096969083, 0.10724965322879143, 0.03106421630945988, 0.05630289619148243, 0.06511268264148384, 0.049153127110912465, 0.05332249049388338, 0.016741163199185394, 0.03201467370672617, 0.07600198543514125, 0.030145791861286853, 0.01907943489641184, 0.033423314525862224, 0.08417782562901266, 0.05608819286862854, 0.03178076360200066, 0.027852470193465706, 0.08511110601830296, 0.0357441624510102, 0.04055793637235183, 0.03867758277920075, 0.040244501433335245, 0.07302405108930543, 0.021945440385024995, 0.029130559814802837, 0.1765377403353341, 0.1057680147641804, 0.2651625667931512, 0.1770591881358996, 0.12053066049702466, 0.12675591395236552, 0.09053501067683101, 0.07985187650774606, 0.1601962570566684, 0.14043464558199048, 0.10454277347889729, 0.18166779162129387, 0.07412505685351789, 0.1613948107114993, 0.09402119001606479, 0.14375676575582474, 0.1365618221461773, 0.21251821744954214, 0.1332694769371301, 0.08867740019923076, 0.1507351061445661, 0.07310331988264807, 0.2039859237265773, 0.09382808319060132, 0.08507193546392955, 0.13518010644474998, 0.11156153865158558, 0.07450453922501765, 0.1692886051023379, 0.19903064821846783, 0.07437622189172544, 0.1278583743260242, 0.16455152101116255, 0.1213172628195025, 0.19657218013890088, 0.1593422528821975, 0.22451139811892062, 0.07289619388757274, 0.08953202777775005, 0.06113840761827305, 0.10555306653259322, 0.12948127317940816, 0.24087885656626895, 0.10140564845642075, 0.14846063131699339, 0.09105928606004454, 0.14506735402392223, 0.27340791653841734, 0.18556409660959616, 0.11430185957578942, 0.17344132211292163, 0.17269914475036785, 0.07347731778281741, 0.10726229200372472, 0.1632576310657896, 0.10790941509185359, 0.21139493241207674, 0.1955997885670513, 0.14094810787355527, 0.20828151900786906, 0.17424840771127492, 0.14667460840428248, 0.1586606347700581, 0.22554743627551943, 0.20313476939918473, 0.1336105531663634, 0.10142444705707021, 0.1890648517291993, 0.07575836061732844, 0.15608814312145114, 0.12341440145974047, 0.11940603217226453, 0.19168797269230708, 0.12742167979013175, 0.1630220585502684, 0.22413023107219487, 0.11044560087611899, 0.08828557591186836, 0.1455959412851371, 0.13151607883628458, 0.07104276170139201, 0.16051797807449475, 0.14177689386997372, 0.18393030302831903, 0.10676759862690233, 0.0987272968632169, 0.11725182237569243, 0.10646133654518053, 0.17210432823048905, 0.4540085740154609, 0.14343786489916965, 0.13154107437003404, 0.08854467450873926, 0.12116561978473328, 0.15157503919908777, 0.18314252811251208, 0.14378845546161756, 0.15575468132738024, 0.1811236044159159, 0.10233157416223548, 0.10625734983477741, 0.14376203500432894, 0.2720969868823886, 0.09443216913496144, 0.13474828039761633, 0.1720381435006857, 0.15429748920723796, 0.17217762273503467, 0.14459212718065828, 0.17028631875291467, 0.21922062733210623, 0.14150780596537516, 0.09373689550557174, 0.20347779005533084, 0.14408298418857157, 0.12121212275815196, 0.1891212401096709, 0.08863564697094262, 0.10813384797074832, 0.1507635007146746, 0.11005668580764905, 0.13032304676016793, 0.17968189349630848, 0.22457519313320518, 0.1284043278428726, 0.25818480527959764, 0.0971186620881781, 0.14228821877622977, 0.14088431285927072, 0.12326337440754287, 0.12296546148718335, 0.17210607969900593, 0.15681252378271893, 0.118222403107211, 0.1495338956010528, 0.09238275801180862, 0.08741163022932597, 0.10269268095726147, 0.08508542028721422, 0.20575002359692007, 0.18000870564719662, 0.07462262976332568, 0.10628266449202783, 0.17065904015908018, 0.1875425287289545, 0.1153213923680596, 0.14081789064221084, 0.13724893215112388, 0.14434856915613636, 0.25757850031368434, 0.1194221516198013, 0.17330021015368402, 0.1569052625563927, 0.23438417381839827, 0.10525000310735777, 0.1788575603859499, 0.1566731632919982, 0.11516022015712224, 0.10427403438370675, 0.06734639129717834, 0.17471916682552546, 0.1436543939053081, 0.10898851265665144, 0.14273730717832223, 0.23520408372860402, 0.14261292322771624, 0.1346574563649483, 0.13109710678691044, 0.1299036294221878, 0.15892007475486025, 0.1163601319422014, 0.3362220787676051, 0.10126737150130793, 0.1338621263857931, 0.10954620694974437, 0.11734261672245339], [0.05234988369920757, 0.056294290989171714, 0.03944695614336524, 0.030578178229916375, 0.036088407650822774, 0.028673248416453134, 0.0119175094368984, 0.035561096883611754, 0.038010815042071044, 0.030908825428923592, 0.030947201885282993, 0.039315918838838115, 0.032730523380450904, 0.05458469815494027, 0.05875575363461394, 0.03168297822412569, 0.04869347052590456, 0.03535766307322774, 0.07579025812447071, 0.0016997687703224074, 0.026521033141762018, 0.04329166702518705, 0.11289869580650702, 0.04712136054877192, 0.020992817771912087, 0.11122598400106654, 0.027290022444503848, 0.005657167703247978, 0.10398794387583621, 0.08103985455818474, 0.05362263727874961, 0.06660617320449091, 0.042371140443719923, 0.0351626452174969, 0.06771564687369391, 0.039490486815338954, 0.1080391053983476, 0.08624684429378249, 0.05259865902189631, 0.10451961847138591, 0.07052446802845225, 0.022188083712535445, 0.014841124138911255, 0.04063848908117507, 0.06412208618712611, 0.07940727067762055, 0.05586674713413231, 0.02616695262986468, 0.11245331072132103, 0.030763900685997214, 0.05109417354105972, 0.007862987840780988, 0.019269354197604116, 0.050412247437634505, 0.033339540896122344, 0.026020632649306208, 0.055009811476338655, 0.04294709528039675, 0.05987355420074891, 0.042759814314194955, 0.05603697725746315, 0.05547693406697363, 0.04309856391046196, 0.010338439969928004, 0.04297025399864651, 0.07970065649715252, 0.01807234792067902, 0.03294803202152252, 0.014944407903385581, 0.05267972010187805, 0.07329389598453417, 0.04805975062481593, 0.03819108271272853, 0.051080135817755945, 0.01981204597541364, 0.02186507135775173, 0.05343989825632889, 0.06318312836810946, 0.028469716271501966, 0.03631715240771882, 0.012789733336830977, 0.021527674325625412, 0.02425594091619132, 0.03560746627044864, 0.04388685461890418, 0.0034809082353604026, 0.02360758400755003, 0.04789566548424773, 0.015538620500592515, 0.0764325943600852, 0.019367783388588578, 0.10735924617620185, 0.051988658160553314, 0.026135203552257735, 0.03099942310655024, 0.03284666578110773, 0.04310423020797316, 0.05965989359538071, 0.022248490822676104, 0.008378153361263685, 0.05350038700271398, 0.03297799623396713, 0.03288216270448174, 0.00955934168814565, 0.032941148601821624, 0.05221229694143403, 0.09152142141829245, 0.020790450798813254, 0.017757102141331416, 0.04369352514913771, 0.03292804227385204, 0.03755613826797344, 0.028168294848001096, 0.029742768565483857, 0.07074067791108973, 0.0633117499819491, 0.034935028525069356, 0.030796330684097484, 0.05201992484217044, 0.011635770697466796, 0.032141588380909525, 0.05700342793716118, 0.06802046176744625, 0.026354341207479592, 0.010209058582404396, 0.009073355558939511, 0.01659683031903114, 0.026141725174966268, 0.02412436926533701, 0.0507619103154866, 0.08799704373814166, 0.01646380034799222, 0.09985504220821895, 0.011306545638944954, 0.027348319999873638, 0.005534087149499101, 0.03302464392618276, 0.015943209727993235, 0.03000027525558835, 0.037411022422020324, 0.059943249289062805, 0.03703919159306679, 0.05466925103974063, 0.06949833754333667, 0.04318056751799304, 0.015342569204221945, 0.026824679152923636, 0.040659406513441354, 0.05638028364046477, 0.020367272627481725, 0.012319258094066754, 0.014229988719307585, 0.01610986455489183, 0.050555107154650614, 0.025462027369940188, 0.03509965172270313, 0.0484564508224139, 0.038061722661950625, 0.047312140741269104, 0.024338120783795603, 0.050567055732244626, 0.03532585091306828, 0.03366089084011037, 0.05141582776559517, 0.07666457488085143, 0.04460544281755574, 0.04011124881799333, 0.014725201599503634, 0.061276936903595924, 0.03039989580429392, 0.05105878422909882, 0.018939176407002378, 0.047941656375769526, 0.04252404141880106, 0.05321249307598919, 0.07756022096145898, 0.03441933979047462, 0.024492871561960783, 0.04218063113512471, 0.06315511229331605, 0.07222031999845058, 0.04125702835153788, 0.03844349084829446, 0.055355496442643926, 0.02109270713845035, 0.02564664217061363, 0.017470250932092313, 0.027613875281531364, 0.021361351609812118, 0.041876858958858065, 0.03330945794004947, 0.05568966698774602, 0.05441889865323901, 0.04836664353206288, 0.030261963947850745, 0.029953529228805564, 0.026965946963173337, 0.02599977087811567, 0.032317395744030364, 0.06180088203109335, 0.016984493013296742, 0.05983026101603173, 0.05790148599771783, 0.03433935853536241, 0.04119489203731064, 0.03947490913560614, 0.0005583319023116928, 0.010335445404052734, 0.01829409051424591, 0.028882450569653884, 0.044007353426422924, 0.026119100803043693, 0.0675213748763781, 0.04069878486916423, 0.012317828532104613, 0.13774729915894568, 0.012046579122397816, 0.08955798068200238, 0.01312718046392547, 0.05521745697478764, 0.04952556650096085, 0.004247492515787599, 0.04925857145281043, 0.02294097768754, 0.013494348750100471, 0.02662851838977076, 0.012012571132800076, 0.030030968628125265, 0.032446867116959766, 0.025234531276510097, 0.10917919265921228, 0.02528313638322288, 0.056314982066396624, 0.027667695831041783, 0.06758621631888673, 0.09655884525272995, 0.024588757041783538, 0.055130662804003805, 0.06055945450498257, 0.014583980173483724, 0.04804376105312258, 0.057862775574903935, 0.03781720355618745, 0.018688781347009353, 0.007150947703848942, 0.03960458459914662, 0.11602223210502416, 0.014347091273521073, 0.0550385956739774, 0.046644241228932515, 0.005795572214992717, 0.025009545497596264, 0.01581089964020066, 0.05349253879103344, 0.04018006075057201, 0.08116619777865708, 0.08062512017204426, 0.03953083367377985, 0.035361154878046364, 0.014919657278369414, 0.018085873562085908, 0.005493856251632678, 0.07500916253775358, 0.04135086179303471, 0.012782117973983986, 0.03969423232774716, 0.026964104581566062, 0.07541121362010017, 0.011507643539516721, 0.0748401606688276, 0.011525689787958981, 0.03149330754240509, 0.04909991883323528, 0.03134405422315467, 0.02786988283332903, 0.0070094405509735225, 0.02207321780588245, 0.05084943179099355, 0.04228348538163118, 0.04072993280715309, 0.038318813749356195, 0.04547281307168305, 0.055234047686099075, 0.025155475850624498, 0.0058056927900906885, 0.01186438372315024, 0.03649869657238014, 0.04945066524669528, 0.01957135449629277, 0.02456300822814228, 0.03845568062388338, 0.026204640744253993, 0.06553749539307319, 0.029834264241799247, 0.010888090309890686, 0.023153128022386227, 0.04943905434629414, 0.06091316579841077, 0.056862226920202374, 0.05178731349587906, 0.01881830281490693, 0.04567390540614724, 0.043989348923787475, 0.03377890716365073, 0.04238454363076016, 0.046565002121496946, 0.05580515258770902, 0.041184698638971895, 0.0564405423210701, 0.021203669348324183, 0.031440373859368265, 0.017412736342521384, 0.03207053516234737, 0.05189224204514176, 0.0774740130873397, 0.03271874549682252, 0.0793482773588039, 0.04591230921505485, 0.07076057489030063, 0.013465816882671788, 0.00849621050292626, 0.045229429451865144, 0.00565028428354708, 0.03598250688810367, 0.06858525099232793, 0.027726394146156963, 0.06025940048857592, 0.024739967775531113, 0.010011521135311341, 0.026446230222063605, 0.008451450648863101, 0.029298470726644155, 0.03205912093108054, 0.0028235370155016426, 0.04500012437347323, 0.05226731977018062, 0.055555816943524405, 0.049970925610978156, 0.01878486535133561, 0.0327789707807824, 0.015250872220349265, 0.011718438527168473, 0.007127763474272797, 0.019922644532925915, 0.0274319210802787, 0.030694667584612034, 0.01925175602082163, 0.018638784713402856, 0.01952042461198289, 0.07568386383354664, 0.0540256605745526, 0.024397477754973806, 0.13215434068115428, 0.19713073532329872, 0.162960133748129, 0.14650471595814452, 0.09827132133068517, 0.10876986852963455, 0.1151764063979499, 0.14423187385546044, 0.21167246595723554, 0.16869033017428592, 0.11738917164620943, 0.14175563876051456, 0.10280786969815381, 0.15883817133726552, 0.13618813594803214, 0.1360324927372858, 0.12405370973283425, 0.2499136287951842, 0.1080019460641779, 0.08901014953153208, 0.18628062534844503, 0.12427133711753413, 0.15242129535181448, 0.17617612145841122, 0.08712143564480357, 0.21450988948345184, 0.16593589360127226, 0.15775266161654145, 0.1795392675558105, 0.09292381335399114, 0.10247391066513956, 0.21909431379754096, 0.08442404054221697, 0.11834980017738417, 0.15095791372004896, 0.13142587820766494, 0.23877213679952547, 0.2036718319868669, 0.10252833977574483, 0.24661567294970155, 0.16911921731662005, 0.19870376185281202, 0.07206783091532998, 0.11723946561687626, 0.15544073801720515, 0.11417550151236355, 0.1157454852364026, 0.18759559228783473, 0.15353696595411748, 0.11718935580574907, 0.08549798760213889, 0.05258866229269188, 0.1678898200043477, 0.17351204878650606, 0.13758466491708532, 0.10091860662214458, 0.1677558771916665, 0.10349423013394699, 0.24327459832420573, 0.17407140549039468, 0.17932597431354225, 0.1673370090429671, 0.1485253169084899, 0.151819190941751, 0.11241774700465612, 0.20708047173684463, 0.056771432573441416, 0.1299715507775545, 0.11185231211129576, 0.18050226353807375, 0.2027285029180348, 0.1597466936800629, 0.0850425761018414, 0.10608187643811107, 0.07527279565692879, 0.07823708932846785, 0.09468542702961713, 0.09804318513488397, 0.10162663777009584, 0.16868994425749406, 0.20382700022310019, 0.1866242100368254, 0.12445800952264108, 0.09938806062564254, 0.09735863553942181, 0.08220226562116295, 0.1314800401451066, 0.16048407676862553, 0.0922753766644746, 0.1651645201491192, 0.29338599764741957, 0.25607983698137105, 0.15689073130488396, 0.14256426802603528, 0.08436193762463517, 0.23058097867760807, 0.13670355750946328, 0.1802422001492232, 0.0684572898899205, 0.13325491599971429, 0.14062824222492054, 0.09331393812317401, 0.0682650291128084, 0.11179262117366306, 0.15074372990056872, 0.11703494456014596, 0.14604651398258284, 0.10520613475819118, 0.09324673665105365, 0.21039769373601303, 0.09398811249411665, 0.17719397699693218, 0.11273672207607888, 0.14718300924869254, 0.24151230929419398, 0.11966127160121687, 0.1857524091610685, 0.10147749577299692, 0.12385636524413712, 0.06424487452022731, 0.1611306209815666, 0.1837092320783995, 0.11179972352692857, 0.10521599790081382, 0.08594211103627458, 0.14375122933415696, 0.09577077347785234, 0.12131578594562598, 0.10197959578363225, 0.11235957004828379, 0.18625364085892215, 0.11924074104172178, 0.26447046955581754, 0.11996126995654777, 0.10978705613524653, 0.1690571292419918, 0.10417492798296735, 0.1746790314791724, 0.29083226749207824, 0.17945202067494392, 0.17608829570235685, 0.1667022649780847, 0.19252124126069248, 0.1965518156066537, 0.08283217088319361, 0.08470237560686655, 0.14523827063385397, 0.10645542904967442, 0.14952135330531746, 0.1350123216980137, 0.09411296399775892, 0.12791044340701774, 0.09757777690538205, 0.16286257101455703, 0.1942395803052932, 0.27551469567697495, 0.141984116344247, 0.08714483556104824, 0.1502436411101371, 0.11298887417069636, 0.22340439580148086, 0.15728835918707773, 0.12443536659702659, 0.16586089215707034, 0.19192798325093463, 0.13463232724461704, 0.10842409450560808, 0.14186716871336102, 0.12874574546003714, 0.08389609152800404, 0.10817574220709503, 0.08300022280309349, 0.09544599481159821, 0.25487583596259356, 0.13386769249336794, 0.16131992801092565], [0.0405436240544077, 0.05525584456336219, 0.08807165926555172, 0.01606749719940126, 0.03967167474911548, 0.060395039108698256, 0.03431681951042265, 0.0703215277462732, 0.06328584902803414, 0.023614853344042785, 0.0032845584564711316, 0.028782932276953943, 0.03416024861508049, 0.03652450475783553, 0.017839849751908332, 0.0354157027322799, 0.08604069793364033, 0.02073964336887002, 0.04383242550829891, 0.023743647507217247, 0.03856738127069548, 0.02470194569468731, 0.07063225755700842, 0.027046816940128338, 0.04303742207412142, 0.02617330912471516, 0.059032786230091006, 0.06120876692875754, 0.04713890120910946, 0.044946689740754664, 0.01989941159990849, 0.028881305806862656, 0.06518084148410708, 0.030308533714560326, 0.0424774679413531, 0.058313348272349685, 0.059804289558087476, 0.07915146721643396, 0.034625894331838936, 0.052495760246529244, 0.04242100163537543, 0.051709614344872534, 0.04688873807026539, 0.018770144852169324, 0.045345749967964366, 0.003743960855899786, 0.03444233523623552, 0.04916621859592851, 0.028310649904597085, 0.04753219865961, 0.0065873394214577274, 0.11951793319894932, 0.03829430432233494, 0.06359879043884575, 0.026748746313387528, 0.022620501622441225, 0.010439254238008289, 0.030004370055394247, 0.02242936890979763, 0.021930554758000653, 0.02150026681192685, 0.022814588082837872, 0.04555966290354263, 0.02109728618961526, 0.013132375497661997, 0.06146632927993778, 0.049837736078188755, 0.018884192541008815, 0.006582025180250639, 0.014659949192719068, 0.014841023948974907, 0.029750570392934605, 0.012215688602736918, 0.06295258019235916, 0.059719413839047775, 0.05304404781782068, 0.03210329727153294, 0.048193389156949706, 0.052560393887688406, 0.03944704891182482, 0.08713247880223207, 0.0403080515388865, 0.030636368173873052, 0.08623010144219734, 0.04665689484681934, 0.024191990050894674, 0.014762257032998605, 0.060288600288913585, 0.012371400462143356, 0.01216282820678316, 0.06884046815684997, 0.0782710054772906, 0.03828992565104272, 0.04045771303935908, 0.017059258825611323, 0.048539333874941804, 0.049677409915602766, 0.03017679693584796, 0.01872844914032612, 0.058974601852241904, 0.047842887652223, 0.006438196960516507, 0.02780862596409861, 0.03413624013774097, 0.01367351804219652, 0.00463387361378409, 0.05155615675903391, 0.059516636829357594, 0.08009247336303815, 0.12315007814322598, 0.004334545046731364, 0.012073055240762187, 0.031419189253938384, 0.05227077446761541, 0.043464724731165916, 0.03703915819642134, 0.04794386797584593, 0.036408295563887805, 0.03136693834676407, 0.03749338226043619, 0.04028291870781686, 0.014884883021295536, 0.013151933871995425, 0.02886200811190065, 0.01708846233668737, 0.06409926514606923, 0.06739809672581032, 0.04369247872091364, 0.018347497316426598, 0.02942799033917254, 0.031561856012558565, 0.037130316195543855, 0.03349822320160456, 0.031919062821543775, 0.07711358164669946, 0.028643974401347805, 0.050274987224838696, 0.004248123341312748, 0.031876244611339644, 0.05343104072380811, 0.03828340588370338, 0.04244052754074801, 0.005734558399126399, 0.007006479845586, 0.06406956439604983, 0.07039391683065332, 0.04111323723918758, 0.009670614672359079, 0.011858765665238025, 0.023644186730962247, 0.047557698853779584, 0.05894537236599717, 0.01924431970110163, 0.05125049952766858, 0.030486361574730836, 0.026440250367159024, 0.020254468036000617, 0.019522714137565345, 0.03635847147961613, 0.023813257248548325, 0.08718048833543435, 0.03147024159261491, 0.01518801416750648, 0.03195534271071665, 0.07228303889860399, 0.024278609816974495, 0.011070446198573336, 0.0545190700358944, 0.04779546070494689, 0.04853121849009767, 0.034350075147813186, 0.015839162479096558, 0.02658688204974169, 0.0021458520541273174, 0.1025712581758853, 0.017351536989735905, 0.05709606281016022, 0.02678930282854708, 0.016771665468695574, 0.042433421476744115, 0.03537913340551313, 0.03614245084463619, 0.038622908759862185, 0.02358156802074518, 0.0449446673883358, 0.021396419942902867, 0.05561970472626854, 0.032690807347535156, 0.022394346960936673, 0.0678551929013338, 0.06485582533059642, 0.013567664591391804, 0.041917918279068545, 0.049234444231842645, 0.0731381711375434, 0.046858228379278444, 0.03295587652246468, 0.037118723848834634, 0.019807025346381124, 0.025989035711972974, 0.030739146350242663, 0.027569385383685585, 0.10835092616616748, 0.055432189983548597, 0.021536747080972418, 0.022333392516884487, 0.0737156139803119, 0.021398817079898436, 0.03704683571413625, 0.04001036497356836, 0.011970983960054582, 0.026194501151621807, 0.027155558273079805, 0.045753092563245445, 0.03309547078970354, 0.04581257941026706, 0.0428833225305425, 0.06498078815639019, 0.014918877095624339, 0.03988439653767273, 0.0786443502875045, 0.022217602636374068, 0.02278519717947347, 0.07170286495238543, 0.06122110513388179, 0.05000202530936804, 0.05208826551097445, 0.0410072659724392, 0.015232347286655568, 0.0384320617740741, 0.011023650076822378, 0.04375932396214921, 0.025565796313458122, 0.039558515782118775, 0.020251345449651126, 0.024356416579394136, 0.019170822961314116, 0.016113406454678625, 0.018320459021197166, 0.03821300946583506, 0.0371026415086817, 0.035417869803495705, 0.10699666250729933, 0.05205014880630188, 0.03582624769478571, 0.028658425871981308, 0.036120390504947864, 0.029489929984265473, 0.020053344160260167, 0.05771698437456507, 0.08993442766950466, 0.03894169829436578, 0.013865730579709634, 0.05343667733541224, 0.03506053311866708, 0.026690281774790492, 0.018909956197603606, 0.05707467040338088, 0.018253669441037346, 0.029654655227204785, 0.04856201390794013, 0.013763947808911325, 0.021209350488788914, 0.046925351925892755, 0.037402795715024695, 0.024331740169145633, 0.029493605470634066, 0.03547881497070193, 0.023497055954067037, 0.016545700054848567, 0.045258362079039216, 0.006345984647850855, 0.04588280513416976, 0.03079905807680916, 0.03955752501497045, 0.07881302561145276, 0.017644412582740188, 0.02127472442225553, 0.016345984404324554, 0.031637952124583535, 0.02482676565705333, 0.01969461594853783, 0.0377991545246914, 0.05761613021604717, 0.0353746693872381, 0.055263611138798296, 0.02590460342617007, 0.07768746960209683, 0.07046171944239177, 0.01801451977371471, 0.04766445679706521, 0.006618824108954868, 0.025105126696871594, 0.06499671464553103, 0.031806519837118685, 0.05423273833002895, 0.020259438570064958, 0.02428814270388102, 0.025547255609126296, 0.03329429586301558, 0.019637045697891153, 0.0657030833826866, 0.046353708967217244, 0.027523197823029477, 0.021308202703949064, 0.05158957195817493, 0.030736728804185987, 0.03551849389623385, 0.016934299710555933, 0.03193477779859677, 0.03010911306773778, 0.0572412751353113, 0.007411798696921323, 0.0961714590084739, 0.056709003110881895, 0.051670276807271875, 0.02696831255889265, 0.11744557486963458, 0.07538713834946975, 0.03604740399168804, 0.050326247364864685, 0.035336315195309, 0.03281643439549953, 0.08897841529687867, 0.021160153519304004, 0.02478016434906749, 0.015612525421602186, 0.045621064491569996, 0.055531567268189974, 0.03208684385754168, 0.029690230076084845, 0.017166567813546862, 0.0181599732968607, 0.031630319135729223, 0.01834107402828522, 0.054097181346151046, 0.048418701480841264, 0.061623735091416165, 0.014426207926589996, 0.02926431523519568, 0.14541343232849613, 0.04277306536096148, 0.02278564432344865, 0.04748245621158276, 0.05942338226304855, 0.007124562034732662, 0.08733653230592608, 0.009684649612609064, 0.03095704461884452, 0.010638908661348978, 0.019979953176516574, 0.004524641071839142, 0.12116779427742586, 0.12107890725019388, 0.11630553955910727, 0.07865846593631431, 0.08363936038222164, 0.10535630834056064, 0.06773194443667307, 0.14770571870030835, 0.20036875532241538, 0.10831741819856688, 0.11163373477756977, 0.12414057811838575, 0.09850035552517511, 0.1315191067988053, 0.12626611132873222, 0.0904958178580273, 0.09659751114668325, 0.16876564332051203, 0.1646553771570325, 0.11834464225103147, 0.10059000589535572, 0.1026075120898895, 0.2097343621426262, 0.21484191151103005, 0.07888103602454066, 0.13553338358178735, 0.2682842774083838, 0.15662440418964252, 0.0993249706516508, 0.08306218471261673, 0.1080467643623706, 0.09151719117653556, 0.17011379910400137, 0.1140061805199366, 0.2438632253324613, 0.1435847656102851, 0.09012471433379687, 0.1549934159265831, 0.16213358903769404, 0.1280906962347217, 0.12314175866777077, 0.19525342824636027, 0.11861105100251734, 0.10520117721171118, 0.20570337219396606, 0.18296715861652046, 0.253986386815086, 0.17702108627418056, 0.2057252952363342, 0.12834036955609918, 0.09535682576824911, 0.18417392042465508, 0.11256381651037373, 0.15260579326422885, 0.1269751146901399, 0.1413425148348324, 0.09415061314939521, 0.06813897532992996, 0.09469494136283174, 0.1411786040989682, 0.06255682252231054, 0.12338344648014754, 0.15174907282926142, 0.13012674869969487, 0.07946357742184773, 0.11853020885610022, 0.1462074858136475, 0.15920216508675367, 0.09206929709762335, 0.08487493978464045, 0.09351453321869485, 0.11590677619096823, 0.12584292388055474, 0.21685507614165545, 0.16362180293072015, 0.10856761102331802, 0.15967547718901187, 0.20568011328577995, 0.09931199048878625, 0.068477231397992, 0.21451864682603627, 0.1581118314061314, 0.08078288592514582, 0.1367260148981586, 0.13905745698139071, 0.1248663614387624, 0.16360066656488925, 0.15621123573509976, 0.07442506263032556, 0.08261616138042882, 0.13621923193568364, 0.19176574976881966, 0.13694258843315765, 0.14685526199173182, 0.09991119310143404, 0.1283247844548896, 0.09671451814938337, 0.146099547855556, 0.06968692468944937, 0.14759950252482668, 0.123217576474417, 0.10315069739590399, 0.11778003114159219, 0.07382063529803418, 0.07816961326170713, 0.07874378323322162, 0.15050640591653064, 0.15143808326683939, 0.22000429074978456, 0.23591041535837576, 0.1619775450672023, 0.07815006509190425, 0.18950776546262205, 0.09078616829356179, 0.1920255905133672, 0.07458654654328711, 0.11681212214170955, 0.1362785740639083, 0.2358761875075288, 0.10413911193609238, 0.09369327948661521, 0.071349558129441, 0.11454776278696954, 0.08292659433209337, 0.1071727964153979, 0.14221336576156318, 0.187228852591943, 0.11302592218271457, 0.11667521073832177, 0.13332064059795812, 0.19526896881870925, 0.15185512573225424, 0.23220898350700736, 0.10403311098343693, 0.24081639741780236, 0.11787609473685734, 0.08552980347303674, 0.16295489418553188, 0.11244194844039157, 0.21273851656587794, 0.19740561197977513, 0.17229474848136306, 0.09640991105698049, 0.17117777169914916, 0.1727567205671221, 0.18147131544537842, 0.20628537924494594, 0.14349633129313588, 0.10052077836007811, 0.1456398912705481, 0.17733645450789481, 0.11463923990959302, 0.0989554553234484, 0.13780863024294376, 0.18703622074099258, 0.15579618222545832, 0.19404574617510661, 0.07424872092087753, 0.20906191697577015, 0.17952721507754177, 0.14977387647377327, 0.18833999609341845, 0.16386108618462458, 0.10654603785951622, 0.25561053247656673, 0.14799085183767602, 0.0675254270026926, 0.15347524895332754, 0.13511925033526495, 0.2667103009298444, 0.1607272488763556, 0.14348641620017588, 0.10967677299049683, 0.13109697320032865, 0.21262277121422812, 0.11621574711170979], [0.06467964689363725, 0.05174072146473918, 0.053627706147381105, 0.06941485335119069, 0.05552306967729237, 0.018540620840212796, 0.10646349619491957, 0.03592920955270529, 0.023496362045989372, 0.02215269811131293, 0.06586860457900912, 0.05525524713448249, 0.11957671129493974, 0.02640913582581561, 0.026290666792192496, 0.08096000688965432, 0.01784462176146917, 0.021286442934069782, 0.035128324598190375, 0.030750690457352903, 0.0406142245628871, 0.05601154385658447, 0.037558657859335653, 0.04075339951668866, 0.02530211495468393, 0.016544562713534106, 0.06484300101874396, 0.00883086066096439, 0.007586416768390336, 0.020753784992848523, 0.05697567903553136, 0.03842406513285823, 0.02333893582544988, 0.022895380134286825, 0.024809076567180455, 0.0549039218458347, 0.030272840122052003, 0.02296139602549374, 0.11544962806510739, 0.022356258086801972, 0.04168402301729657, 0.008242015646828804, 0.1043229122296907, 0.0625486217904836, 0.05025577302149031, 0.06721412573824637, 0.08499703792040236, 0.0456439040863188, 0.0486279722827021, 0.0557710286375368, 0.05202240732614882, 0.032698035865905695, 0.03963560266129207, 0.023391281356452964, 0.024984234551084228, 0.05075172062788624, 0.084813556750305, 0.032051825619419105, 0.07500643143430352, 0.034176813351223245, 0.028980146889807656, 0.031836435809964314, 0.011143945721414639, 0.06606118447962217, 0.04185990088444669, 0.028961198004253674, 0.021943525644019246, 0.05484473556862213, 0.05733990285079926, 0.04310338415962178, 0.03858929318084847, 0.0396815638669068, 0.011307203367323382, 0.04185678386420477, 0.013793070611427538, 0.04542460686934646, 0.01841506800701609, 0.004441080809556297, 0.019386713720450643, 0.025060278712771833, 0.03748611663468182, 0.04916028512525372, 0.045337486153584905, 0.020573535875882953, 0.02285962716996437, 0.06764777746866457, 0.010525652287469711, 0.055836523170000874, 0.04096566859516315, 0.04380788639537059, 0.020749636387336068, 0.04054266297316644, 0.03789312526350841, 0.006422187443604344, 0.07674187698285095, 0.05383811243518721, 0.0566685004014289, 0.049899809309863485, 0.025814252512645908, 0.05769114650320262, 0.03572845860617235, 0.029000136637478136, 0.03810704933130182, 0.02422027144348249, 0.034491008991608396, 0.02579981959570432, 0.0003194128515815464, 0.030931193759897724, 0.11132632978842594, 0.02183892920584185, 0.04284467147954274, 0.030130082450341433, 0.007535008662671316, 0.022529052330355626, 0.06835672145825811, 0.02615869994770037, 0.020108541393710766, 0.03926916353520937, 0.029140430378902238, 0.052473440155154094, 0.04972300375811756, 0.07258230252773501, 0.03145173242955934, 0.008337378840224119, 0.013052345075266203, 0.05263439714326523, 0.04601059925334994, 0.06466295599238947, 0.0162051266306662, 0.057901070395018905, 0.08009404671611264, 0.03221856393793132, 0.027581196663959417, 0.06071136471291538, 0.07260573955136351, 0.016094025268102996, 0.010903392467298545, 0.03103054692473961, 0.009721786682348466, 0.02512011065846309, 0.015307713310903637, 0.040682457620278, 0.0016464890609313443, 0.09568099587340839, 0.015433197495440254, 0.05985300784232095, 0.05422631875262596, 0.024783060580375604, 0.037007205028203316, 0.06074889512092341, 0.03470040966931265, 0.05418835789896548, 0.048068634132505395, 0.05064015356765594, 0.03370192789589055, 0.10406615139800124, 0.034220158486277796, 0.02744661003816873, 0.07585686587844975, 0.00970654111370095, 0.04176981899945531, 0.0424037021730328, 0.025975107455451507, 0.01692178524535848, 0.03433268291701097, 0.04244203038979322, 0.055827506075729616, 0.018893730994022917, 0.005121674757901928, 0.013826127724314574, 0.03694473474752158, 0.041296161798527464, 0.02621416249894537, 0.05502714433532674, 0.015340587669925299, 0.0385107850888744, 0.1072927497443743, 0.0416889286134392, 0.0556068321748171, 0.028218638435646426, 0.029279096961545292, 0.04401055950438604, 0.06385466069332324, 0.014599653404729906, 0.020927519908582326, 0.06016724059008993, 0.023470479645766318, 0.021393397546489723, 0.022892348461027723, 0.03638259870058391, 0.12194160197395831, 0.0600543525069952, 0.016883800271898508, 0.04213298154354561, 0.0040092120889312355, 0.02044481036136858, 0.01730092437355779, 0.017090801957238, 0.020015552145196125, 0.03894567991665099, 0.01959820910997223, 0.024668684491189197, 0.062289315392263234, 0.06312487719696946, 0.0369575219519902, 0.012613871240318986, 0.03631555679021403, 0.01381176716677146, 0.017006551497615874, 0.06719010983943008, 0.023789100341673475, 0.029819276569469366, 0.017645546213316265, 0.07751990749966353, 0.05891813925700262, 0.04472521803108975, 0.05310824730258901, 0.026250327355228364, 0.04352106116130017, 0.02197452700784197, 0.07011568566667847, 0.028935916743648704, 0.06513967455248348, 0.0178350981514086, 0.07201169486506842, 0.04501231414906215, 0.04543075927358586, 0.03966594536905177, 0.024357379516004585, 0.037583586599794216, 0.017562531429575756, 0.050907964978250675, 0.03153198085783515, 0.018396805608063005, 0.018508693647163454, 0.04772246305947192, 0.012617374177352758, 0.02683450704353163, 0.029896934902353678, 0.0653957377653569, 0.03843904167297296, 0.034159873830503784, 0.0072932554485305445, 0.019398996264499146, 0.043586551983025856, 0.05102051538415253, 0.02703690370253753, 0.04445460872375406, 0.022197004327608738, 0.03528145192831289, 0.04697527620010078, 0.08029017408262007, 0.04314072531997226, 0.054494148716912605, 0.046068961746641435, 0.01826343053835444, 0.09077180773601867, 0.07610535918502137, 0.06143086575320922, 0.04230651793477591, 0.02227257537015248, 0.07007632215390913, 0.0422721045470098, 0.055384506995324045, 0.05577457610343117, 0.03876711547491141, 0.015655512470402755, 0.044846496093668975, 0.03703651615069248, 0.011934773647226393, 0.012684107168752234, 0.07596748298965394, 0.00695723185344832, 0.04454519526916556, 0.012723599629680393, 0.035083947877865285, 0.0004000124664571558, 0.04928065034619067, 0.017900791208376177, 0.015729309779999312, 0.04108072374947369, 0.010324645299988333, 0.0242489294760162, 0.02249329936603317, 0.018574690984678455, 0.07857625823817216, 0.013921627287345473, 0.0017792613675737812, 0.058311823158874176, 0.03778273821808398, 0.03309118859760929, 0.033753815150703304, 0.01482462155763642, 0.02493872234481387, 0.03912438165571075, 0.031074643484316766, 0.04838899702008348, 0.05011789682612289, 0.015722188873041887, 0.08182146222679876, 0.028545630557346158, 0.029734627205471043, 0.03595535541535355, 0.01232646527569159, 0.05228569534665439, 0.029279601621965412, 0.05455384336528368, 0.028753381811839063, 0.029796069611620624, 0.04605640460795257, 0.007403923118545208, 0.020997029459977057, 0.066558438265929, 0.030578317382605746, 0.02143517860531574, 0.016906437631405424, 0.00464432861917885, 0.026426080912642647, 0.05003811224014498, 0.025888179698085878, 0.0789901614189148, 0.04680222591559868, 0.06230745348148048, 0.09018521421239711, 0.020280500721128192, 0.030234671467042062, 0.0757631697342731, 0.050878390393336304, 0.02310202929947991, 0.07300442128325813, 0.060184217218193226, 0.10884019444347359, 0.03436416853219271, 0.046200292199500836, 0.02923269603343215, 0.04519318295933772, 0.09858901990810409, 0.005559192613873165, 0.005189240810068441, 0.09846304776147008, 0.07467364499461837, 0.02018915161897894, 0.06860140012577176, 0.04081605533428956, 0.047573706979164854, 0.0878567184554413, 0.02641423994646175, 0.05015592818381265, 0.05101717200886924, 0.07276177610037848, 0.06665033841272816, 0.052483678082353435, 0.2185116388136521, 0.15309528418583795, 0.1610208276542835, 0.08453030124655925, 0.14105433889199048, 0.1454898141673766, 0.27212625718675554, 0.20142699853749946, 0.12430569113348611, 0.18821056553861126, 0.11955927824601531, 0.17664582672296092, 0.27270385588053614, 0.12986552756046876, 0.15150996769079939, 0.2069418237078935, 0.0914387906959746, 0.1631920548970811, 0.12969438830623403, 0.14015711203683168, 0.11120029084850103, 0.07930170017061755, 0.11002322236890905, 0.12747349654091522, 0.18987471295986325, 0.1345843548187986, 0.1307098096003756, 0.16780557140009478, 0.11852787851239555, 0.09324399070465006, 0.13200212619267404, 0.09273560470319353, 0.1197879933170043, 0.15790995239512995, 0.14727328409207985, 0.15389309293823317, 0.12106966009014286, 0.13583692198153585, 0.2108347148168832, 0.10235525609459728, 0.25815871136728674, 0.15098823787411675, 0.22933828207897022, 0.1809306608629413, 0.13086154911434278, 0.18607187404995784, 0.20114900486078113, 0.14038869179785252, 0.1837806118419394, 0.17306594381807372, 0.09509773459285498, 0.08108202338917181, 0.12430252216290683, 0.1396616839338094, 0.11000728845829144, 0.1136654605215881, 0.16682883084286004, 0.08053975834627636, 0.14204412640538067, 0.15264266316080466, 0.08565389056457207, 0.11708755540894344, 0.10426811204524711, 0.2155356266302988, 0.10706622400903143, 0.1419092930154875, 0.1529696534271352, 0.186066307942383, 0.1397848952910863, 0.08406814362388104, 0.12327717093285173, 0.16234112321399152, 0.13481094734743237, 0.12612100661499426, 0.13583039108198136, 0.1661917267483659, 0.05537780169106554, 0.13850598188582808, 0.14525582984788343, 0.10094273384311236, 0.16764062165748328, 0.10869310819543898, 0.1088324241572991, 0.11264448054134846, 0.11083041186793707, 0.1688853814266622, 0.09444916431675665, 0.21244851493975148, 0.14646517432993278, 0.1710338841076009, 0.20842690573772416, 0.14529692998621613, 0.13463637937093154, 0.10464555351063609, 0.14521483361022547, 0.10283710289513692, 0.15386924031190574, 0.0939702638424933, 0.1586589723592624, 0.1578555826563388, 0.09805184599827044, 0.08549649588530883, 0.12942510744323954, 0.09297525903093629, 0.10967285445076413, 0.1347168133361265, 0.056229156398330815, 0.15220694825984538, 0.21670703252311796, 0.29895795334596187, 0.08731033449294046, 0.1154072885401547, 0.11946628714213148, 0.11615362192969769, 0.2141157942241989, 0.16508617904037237, 0.06967999303014949, 0.128068980993703, 0.10941350352368318, 0.096682242146926, 0.11386904647224583, 0.15467438148334622, 0.15510979952523485, 0.17535450460854918, 0.09190978729748167, 0.15639142919098958, 0.12034124214551412, 0.12886074866401032, 0.17598513717530295, 0.18372642021859065, 0.2533113886602223, 0.12084297850378789, 0.0789888329745736, 0.15803717134986073, 0.11326444844598882, 0.20738240709761158, 0.1077417639316991, 0.12081217937520705, 0.06392137234797701, 0.19230630045058206, 0.07443125214194879, 0.14693829347379506, 0.13719533424591646, 0.1765422971220687, 0.17689469852484763, 0.21808818419231102, 0.17044427746441215, 0.2669813926331699, 0.16708015173207968, 0.217043032462243, 0.15929764980683103, 0.1921468277578242, 0.19733613211428747, 0.19061074533965439, 0.0903677602764219, 0.2625941124279052, 0.1293160711065866, 0.1232646063726861, 0.11827620139229111, 0.083994322194485, 0.15434860833920538, 0.15034047653898597, 0.07303940612473525, 0.14558519498677924, 0.19253948325058445, 0.09696313762106001, 0.21380471560405567, 0.10955748017295264, 0.08180931326933205, 0.1207461727608461, 0.08951489158789627, 0.14123883680440485, 0.21943530096905306, 0.18570816231658682, 0.1516728987917304, 0.13479629735229537], [0.014762162409169832, 0.026228660353808664, 0.04567423937260173, 0.019175995730620343, 0.02244118761154823, 0.09643473589676432, 0.08858796398271807, 0.08578166613006033, 0.06712293063174002, 0.03079447902564425, 0.03209337475709617, 0.021534444567805622, 0.01202592236950295, 0.007456711155100493, 0.02066873301373562, 0.04478967355680652, 0.12447487853933126, 0.02164590772736119, 0.03586776714655571, 0.04472813838219736, 0.024438158579869196, 0.02615705980133498, 0.05184660367376637, 0.03706937102833763, 0.02658832738234196, 0.05883380159502849, 0.04833424878597725, 0.01629010439501144, 0.036702946745208465, 0.0664271523419302, 0.0007449340353105072, 0.012136586792621529, 0.034893011834356, 0.04007906929473393, 0.01998475672735367, 0.04370017479232047, 0.03374467931280378, 0.019604081353463698, 0.05395305255660787, 0.03431340192037169, 0.005250316780802677, 0.017850078402261715, 0.020528647073660977, 0.02885388530557975, 0.04654393625969533, 0.015475555574084865, 0.10062789253424853, 0.03667950601084158, 0.06971505950787105, 0.06113824805652257, 0.03658561319753062, 0.06177678449603263, 0.01715172671538312, 0.05379493428335991, 0.030391824948310386, 0.058998599197366275, 0.030907958971511107, 0.05952852974587586, 0.08099899190710858, 0.008888527390809031, 0.11824399218312465, 0.03434811587794684, 0.02444029967591632, 0.09176241161185317, 0.02833181781170424, 0.031936343730194494, 0.021306137678038795, 0.021406056730484124, 0.02993454138049856, 0.06275498337345198, 0.03727402938238811, 0.04661397644667886, 0.04131249646889046, 0.05471560558362398, 0.023078176673152484, 0.008946923280745978, 0.055659212957834825, 0.04430554465216119, 0.04338813138019759, 0.0193515118007781, 0.05791944968223106, 0.02862496614397969, 0.029875195541535504, 0.053017645914223976, 0.06590293633053079, 0.011561122701095883, 0.04896067708614282, 0.009599173681635875, 0.06830282669398002, 0.010574115458439337, 0.05006694467738271, 0.03053907632420305, 0.024571494686824735, 0.014967209463065956, 0.03507533896481618, 0.04431754146935418, 0.037837048585060984, 0.07843899060389958, 0.01070302650987287, 0.0074196269633830525, 0.061721026941086166, 0.05873251328011975, 0.01863509438408073, 0.010792216889967676, 0.01814097246096935, 0.06357461868901737, 0.010583140901871957, 0.008608485386503162, 0.013600398870039498, 0.04824315386940725, 0.0356671201006975, 0.024805499415379018, 0.029708705842494965, 0.05750511976657435, 0.021594009340333287, 0.030363148362084758, 0.051385332917561755, 0.006221056146387127, 0.07021919300314039, 0.016620439891994465, 0.01680055542237824, 0.05162306879356038, 0.04109639790840447, 0.04731048575195018, 0.044108203874202445, 0.017586517642484978, 0.04577970968966838, 0.040321951964870095, 0.06513495449326001, 0.017571997523191385, 0.0628980397596024, 0.0433439327753149, 0.08150632405886427, 0.04061684805492405, 0.08015659492230043, 0.03855210045003332, 0.041156604638672434, 0.017265598144149408, 0.021451292486744933, 0.05654434280586429, 0.02526095358916791, 0.08220216914196499, 0.03356895729666576, 0.06444794838898815, 0.024268336637760513, 0.0502717997005675, 0.015403411398438038, 0.05790705581603106, 0.05181316621019505, 0.03660890550236218, 0.013166136723157251, 0.017964617763936985, 0.0722814655455295, 0.06754626650945283, 0.08674631710164249, 0.04107680892047938, 0.012973620832781307, 0.04407682215969544, 0.02521782553230878, 0.0497053332219366, 0.040504498028894886, 0.018774953969113994, 0.0763521900807973, 0.029194994931458496, 0.013321833739610156, 0.020940518625138793, 0.05725689734390471, 0.07502521519199945, 0.0013325060922397824, 0.04930316339596175, 0.01980119206564268, 0.03639259171904996, 0.0690684410801623, 0.08039998225285672, 0.038170120751601644, 0.054334086016751826, 0.0551060086581856, 0.059769482832052745, 0.044960300729144365, 0.016942762049438898, 0.01750003702909453, 0.043114690779475495, 0.08871710509993136, 0.01497530443884898, 0.028850575326941907, 0.02760306033451343, 0.017854941324912943, 0.05065266988822259, 0.03531605085299816, 0.03306536927993875, 0.00967545904131839, 0.019671498048410285, 0.02063589112367481, 0.042402492472319864, 0.018482319574104622, 0.033420286563341506, 0.01773452415363863, 0.08306576186441816, 0.019851094075420406, 0.028023997219861485, 0.026268240944773424, 0.01901601837744238, 0.02012733071751427, 0.027353917648724746, 0.03208417212590575, 0.06804109347285703, 0.002356988661631476, 0.0007600058370371698, 0.017372391339449678, 0.021084417348902207, 0.02719473068282241, 0.04822360941034276, 0.01405142056682962, 0.061963211992406286, 0.017290404430241324, 0.006668402820650954, 0.04686380932980683, 0.02243177717900835, 0.015283058237400837, 0.05661349241563585, 0.0256977074968745, 0.011260137289355043, 0.03525492014887277, 0.03754523982934188, 0.01603684464498656, 0.061211123247630894, 0.03687614174850751, 0.07725627438048832, 0.021111680143803824, 0.06735196482622996, 0.031132260119193234, 0.027909036689379718, 0.029275395500008017, 0.04207565805700142, 0.06784150769817643, 0.04137803553021513, 0.05398187757236883, 0.057739868498174474, 0.06061096326448023, 0.05156822779099457, 0.011809871120931348, 0.026088286831509322, 0.028894998431496788, 0.10718593242927454, 0.0163777557463618, 0.0864273939805571, 0.02256224488519365, 0.008486660917697009, 0.053345426567830145, 0.025092025935009588, 0.06655034143477678, 0.04270077646651771, 0.040676449934835546, 0.06050571930245496, 0.07558990793768317, 0.020923146803397685, 0.008960865452536382, 0.0310392912797397, 0.09584633153281175, 0.026068757215398364, 0.020041280549776275, 0.05305234873958398, 0.024825338878144976, 0.025274751969845966, 0.0813475860923063, 0.032752524348325096, 0.08258211164502427, 0.004326223252064665, 0.06613873891183175, 0.007167549083533231, 0.02292756336828461, 0.03158407962473575, 0.044613502541324124, 0.02298860315931961, 0.048351845107390545, 0.03291457971499767, 0.043745627626776695, 0.058095190252061, 0.002777177369353012, 0.0460906139051076, 0.07147291791625321, 0.029909707263868768, 0.04067136251251213, 0.010955450416076928, 0.04492894127906766, 0.059904998997808434, 0.039067399557097815, 0.03361772010975983, 0.04169015315710567, 0.06339383151498623, 0.03277282579801977, 0.03403934162633959, 0.03737253093277104, 0.01915444190672133, 0.03908248741936404, 0.037102211063029245, 0.0800684277783148, 0.0835790831479244, 0.07739594657323323, 0.06031186661857646, 0.045933297151350416, 0.027660250234475825, 0.041561346006346866, 0.02345828430406982, 0.05165781614778098, 0.03374303916643839, 0.03753977391170338, 0.09139377201790921, 0.05017850431613624, 0.015495715088036377, 0.05622450313239824, 0.008202011104003759, 0.0684288507909514, 0.008407355944655137, 0.004000881945103174, 0.0011504200438139378, 0.016563715689699166, 0.009130668840953149, 0.07633005181560293, 0.07345686419284903, 0.011488261425256496, 0.05251600232440978, 0.040705757346586324, 0.04878720377746504, 0.02497708581358893, 0.06031559591065161, 0.056408154996461235, 0.011816170099336887, 0.02004142526857322, 0.07022906356723979, 0.07257107383338735, 0.05442267247417476, 0.030674826266476884, 0.005627279097097926, 0.01413343252352206, 0.0206964243989205, 0.027511171319929417, 0.06294065387919545, 0.01588580089446623, 0.008808776201476576, 0.06423794286092743, 0.06502483462099917, 0.02792218012473313, 0.010829155435203575, 0.05798288475489244, 0.03562103272997774, 0.02384650731983129, 0.04352870528236963, 0.020429364412848372, 0.0213964347858564, 0.005263174025458284, 0.018049708705802914, 0.1114964226144366, 0.18657714303117245, 0.19912855233997107, 0.06916043770615943, 0.14797265437664464, 0.14130919240415096, 0.22701901121763512, 0.12050105622620322, 0.09516320686088875, 0.1530822372296825, 0.11391124498913996, 0.09701503600808792, 0.08374986617127433, 0.07478745334083214, 0.10427609755424783, 0.12431369148544036, 0.16476595716085285, 0.07712225735303946, 0.13669934211065993, 0.16846351500134915, 0.1405068565509282, 0.14150443661492318, 0.08560641537769698, 0.11235823418246582, 0.12311521946685389, 0.11022904218407348, 0.13104849611409009, 0.16795386734884232, 0.12836736888857558, 0.16197399760130793, 0.14716007688548416, 0.06749099877197295, 0.1631690631620586, 0.10286117074429058, 0.12167773136752658, 0.1572288092575036, 0.1527846953831613, 0.18140426982427016, 0.1052288593200501, 0.09983749783714302, 0.08545765929738991, 0.12206708430312574, 0.08181608907761984, 0.24254561634734273, 0.12162087543401867, 0.08248495709267445, 0.15864461922319606, 0.09137264307355508, 0.11330946712405421, 0.09797867023735307, 0.18279411946423352, 0.21471895248396322, 0.09858168006758206, 0.2095764924888499, 0.10122821578988805, 0.12042095622746274, 0.11425986143876798, 0.12802756915334612, 0.18025383702479303, 0.08715976757230237, 0.20975619612727314, 0.1509749237447977, 0.12292100684135221, 0.2228868071688339, 0.11266947607509792, 0.12994658492971212, 0.11365461032255553, 0.15172907937085256, 0.16689351643435657, 0.2113048208411783, 0.11707165860570967, 0.11389770079404116, 0.22547663538716733, 0.11053390902816318, 0.1385612867306918, 0.26203221757896245, 0.15509103803196922, 0.12581098184455186, 0.24346222809981555, 0.14154310250887647, 0.11254071345319971, 0.12249539257027209, 0.2346841202233918, 0.12727773282676935, 0.11998760135611519, 0.1200541942671407, 0.13249014766188338, 0.12009111611405388, 0.2089832938509062, 0.09656393638579175, 0.17746257508406416, 0.14422994427150115, 0.15391229972010478, 0.1318388685467653, 0.08837029206915759, 0.10456973570398986, 0.11468169817817397, 0.1471725301234983, 0.1801090588560328, 0.08577588479965925, 0.25801138021051884, 0.18652590515557677, 0.15843386412598193, 0.09898879259708337, 0.1569154002936557, 0.13748981844400987, 0.12437972778570838, 0.12744783307425678, 0.12707462185062468, 0.13166964403353631, 0.11067404877394438, 0.07311143155675381, 0.0756764126708731, 0.20941746508469805, 0.14035723957931623, 0.07769414150970988, 0.10138324301806279, 0.07636265436303802, 0.14244985854020342, 0.1907169763580896, 0.17833893274655566, 0.13590634247520939, 0.218845100607723, 0.15505020506680012, 0.10430363123305142, 0.0825473568693269, 0.15579735481878743, 0.10794258167152293, 0.12191095869638957, 0.12679305102210492, 0.20815539843169972, 0.16880396782653406, 0.20190467446809635, 0.08592887854319997, 0.14001638599438593, 0.13514157413737848, 0.13681176264071837, 0.09478781372308731, 0.052753151903743856, 0.1515008244314231, 0.09943935787305236, 0.14117755024926737, 0.15029789210529998, 0.16068211145466194, 0.08252934494521469, 0.1883329456904903, 0.10958896207739599, 0.18320420058444142, 0.136582424165681, 0.12407279034960084, 0.2079991763457656, 0.10566943528829142, 0.21882699220441282, 0.14884806209011003, 0.17354455485474318, 0.11131947234389372, 0.14786197047214955, 0.20625048346119002, 0.10103610344231129, 0.1434063829947263, 0.10003010000218637, 0.08899805252440274, 0.18483271007426083, 0.07680805429117754, 0.13136877736542374, 0.12823047232814133, 0.22828014276456088, 0.1414977721287869, 0.10265086093568243, 0.13510050368495286, 0.15809519245522097, 0.1427308059646748, 0.1296679233200848, 0.24357279326068237, 0.19426861312240362, 0.15087249252246693], [0.045384215482044965, 0.03100820271356497, 0.0671312352642417, 0.06959835678571835, 0.005401945900302962, 0.0381488174025435, 0.04422397520102095, 0.01811892510886537, 0.05711508776585106, 0.02187310325098224, 0.025961989995266777, 0.04034240555483848, 0.02787221503240289, 0.09744144437718205, 0.028579236859513912, 0.037542660866165534, 0.04314253616030328, 0.037095947336638346, 0.013412475946097402, 0.05107635457534343, 0.07583344369777478, 0.022072273422963917, 0.05705345611204393, 0.04667925946705509, 0.04827238335565198, 0.03611820488004014, 0.05122245005622972, 0.1716506978846155, 0.04320193766034208, 0.031967009272193536, 0.06171468528918922, 0.03908459511876572, 0.0870927664800547, 0.01944985935551813, 0.0407915013784077, 0.02327843409148045, 0.011633314188657096, 0.007411462875097641, 0.05827413318911567, 0.012021286729577696, 0.12641810317290947, 0.022132977392175235, 0.06480196767370217, 0.07474385216482915, 0.03813900621025823, 0.055683874525129795, 0.012044769209751394, 0.016570064763072878, 0.051979882264276966, 0.020602366457751486, 0.05026094579079654, 0.018527366082707886, 0.08993767827632837, 0.04394660863908939, 0.015296778692572843, 0.008523031719960272, 0.015365588769782335, 0.07588389489683323, 0.037062298360979185, 0.04089613306859974, 0.026387620964669622, 0.03461432053882163, 0.0950770583585836, 0.016448280184704345, 0.04234343236021232, 0.07119510977645405, 0.015618614743289072, 0.04998957578209229, 0.04673592986364383, 0.06592781312065199, 0.040633987955516204, 0.008443509668722982, 0.04445054175448604, 0.047285390028264374, 0.037789139241795056, 0.07310537563171238, 0.06900465348735452, 0.010100548242917284, 0.015337087515945313, 0.009411589362571249, 0.022925513185327873, 0.05447349845780991, 0.016645329669700004, 0.05518737030797638, 0.03752605902263895, 0.013240472089819377, 0.052836684335488826, 0.03248557011829689, 0.03295504902780522, 0.023121174854168203, 0.013584464031737298, 0.029000288777751848, 0.027758072719734628, 0.009970666833396535, 0.05482714295794722, 0.008511280739185167, 0.02317480801139027, 0.0373251559358323, 0.04710812063422054, 0.04266278963768855, 0.03271322391810827, 0.07508011185564101, 0.04219751870550681, 0.047280343424063176, 0.02679983761481708, 0.04233837091305759, 0.0333510590280639, 0.03020933083462296, 0.023628362287126947, 0.01205173704875051, 0.04367294910480268, 0.03470554904197343, 0.016099290805868804, 0.0425431554322131, 0.026981329829141032, 0.03221264159947168, 0.09098209528019652, 0.01666721003857674, 0.0674333561619278, 0.060789850540459156, 0.01643497347686207, 0.06314395039225928, 0.021331821553758346, 0.061431678404915147, 0.023120360347093083, 0.038430243512266316, 0.01752746680722339, 0.10186927553149872, 0.020889314146188553, 0.05550073474296369, 0.0721846375381574, 0.009426557553524617, 0.018723864523053635, 0.03988634096458554, 0.04481275434955023, 0.026202807639492676, 0.01542799504022696, 0.032773063285276294, 0.05015616938180756, 0.029551580191764515, 0.013279595332278404, 0.04815472326299641, 0.03960008347348776, 0.036600537787307985, 0.04132935806410387, 0.04383910483738873, 0.05892494475119747, 0.03729816402483266, 0.0728754211741034, 0.04791941049916204, 0.06343461252981797, 0.03974824954639189, 0.05542611179407686, 0.057908825838239864, 0.035530457316781394, 0.08148649387294427, 0.03992692902102135, 0.03726313836523332, 0.04411913570947945, 0.10150489586521871, 0.02473098036716692, 0.04221184957714286, 0.04575078819470946, 0.06256073364056647, 0.003487113517621765, 0.03188861992384773, 0.031326695388997905, 0.06209378916537389, 0.03365781463799067, 0.01726450904243393, 0.01833290483773453, 0.0011781663943111198, 0.052214549359632656, 0.04075793403899297, 0.032229091302724555, 0.06198834853421431, 0.03057019643165404, 0.03251132264267653, 0.027709501009667292, 0.03047645204787841, 0.015359818571596406, 0.012331705765973311, 0.0609129171789391, 0.049463111063232645, 0.054420279047917575, 0.018415014201309532, 0.01852397261245642, 0.055489706428488716, 0.03947577373764943, 0.04404164807056077, 0.023746753395244014, 0.015272262771759415, 0.05352216903702356, 0.07484586036298424, 0.020471566640480887, 0.039736987455398776, 0.07133701583370566, 0.020764080436492804, 0.05722447291191202, 0.025492136301181745, 0.0297429800775717, 0.028265790788282175, 0.06377060504746623, 0.016136759986693505, 0.11898835888132453, 0.04607256116287317, 0.03215199329133611, 0.06190356558363419, 0.03595469119318295, 0.07244527980219573, 0.04322515946114436, 0.02910317271016538, 0.03731830962351523, 0.03935869623092003, 0.03571200890291948, 0.012933425186929526, 0.03635217435657978, 0.1249753384036012, 0.05848446526215412, 0.05401167851232458, 0.011031176381948171, 0.01439251534975483, 0.032571310439379886, 0.06521473536849953, 0.04487168829655275, 0.019640654390968848, 0.011024422838090686, 0.07648625905858353, 0.05676005544955842, 0.0025437308750042575, 0.015026607252366375, 0.00737525302611175, 0.08828248857753351, 0.08146822961862199, 0.02546478444855893, 0.05330858264642302, 0.03179700921464246, 0.04713605507276952, 0.031547180042252876, 0.02180108338507125, 0.03195396231603809, 0.023389628222503234, 0.030385067693714518, 0.0442902044596849, 0.040235940759885125, 0.07592679845402017, 0.01018629505779245, 0.01067545015757787, 0.017918957128131296, 0.08238096736022271, 0.04104721578187309, 0.042409850866533816, 0.059499827184481546, 0.06031737706507556, 0.008843182167765917, 0.031993448283174075, 0.05212332085648086, 0.023823289229767397, 0.04580087203066796, 0.07221859079436399, 0.03781577121117152, 0.023291464349313173, 0.0567683378176298, 0.04899116822343785, 0.13466072181472555, 0.020480917701206636, 0.024361234973184764, 0.019435014546616003, 0.040731932895141654, 0.05286770981911104, 0.04891315365966875, 0.04531506958301179, 0.05724677444959525, 0.09736833540955558, 0.023550039732072037, 0.02429600204777671, 0.051017732330365106, 0.021936317534709815, 0.033315558393951505, 0.05033040710259229, 0.04225096075970214, 0.025977742079703603, 0.02648500001669163, 0.09937899158103392, 0.011726636475941632, 0.0409174104424892, 0.02880948261008598, 0.05179746978683397, 0.032312920593540184, 0.030187658267095685, 0.03319744559121318, 0.024072743617580272, 0.13260709529276937, 0.028103822623961605, 0.0014911051380295248, 0.06370773029630072, 0.03491936920909211, 0.03345787263242528, 0.03303633646282833, 0.009937584673025412, 0.04925756213197019, 0.016087104741018265, 0.018492824674467556, 0.025510048035357613, 0.011964348232140765, 0.05448198120575398, 0.054115920574986376, 0.03454936406342313, 0.027207649618503638, 0.0926523951056879, 0.07870803397963755, 0.030883184226695448, 0.050659549597185105, 0.028624307487916667, 0.08241256800829433, 0.010088868693856057, 0.024739565160416532, 0.018450134484737646, 0.020542170859698672, 0.013036308191658463, 0.03242997954657767, 0.03329101928102318, 0.08190680178813636, 0.04951195922330953, 0.04525877768173814, 0.07301199861103669, 0.06641417217906564, 0.03477925914921798, 0.03481467443634756, 0.06290796969551593, 0.03909597224264871, 0.04555236388114281, 0.03641386538220104, 0.044159074386698194, 0.0567268406302901, 0.054735187150072306, 0.03761548410693649, 0.04645701963454485, 0.05037060553149786, 0.09338265357655473, 0.0658021229901351, 0.043029243606724776, 0.03732103701622691, 0.11404584831325337, 0.02641630682774121, 0.06070045143133029, 0.005487210319188307, 0.012186501789983595, 0.012643496847886126, 0.016243530917563476, 0.010877150125452317, 0.03678040469822008, 0.07067990343784913, 0.07775919817504473, 0.12473801441956311, 0.09793124700081535, 0.218637106299866, 0.1056159041763749, 0.15170123399002478, 0.1711874344618991, 0.1453591961762868, 0.10201215380220674, 0.13721102324780077, 0.11109840881545097, 0.07229052716866136, 0.13737808068981394, 0.11105787270935252, 0.09490298019954935, 0.13877024583052844, 0.1128275906376075, 0.0840323201555293, 0.12924532959004864, 0.2512868691701442, 0.10134040625416674, 0.17101685923989862, 0.16004968289053068, 0.1261358940973878, 0.11585713393287733, 0.18950380239402875, 0.2768025890691206, 0.201614954858087, 0.15874593722401187, 0.1954990197555162, 0.12421055522281677, 0.23406656429870054, 0.11798110863310285, 0.1706060508149676, 0.1364040415501222, 0.1583506099996157, 0.08339085965417325, 0.12273808228201233, 0.1221319183241576, 0.16601132549112663, 0.13019937527133152, 0.12449975532945246, 0.2221534910495393, 0.10563169707893394, 0.09737649161252193, 0.11899572098627687, 0.1748836861224845, 0.2099607468699105, 0.26235870318487287, 0.14077425235882401, 0.19323466782225296, 0.1319960702676326, 0.12412989119184203, 0.10230564352241345, 0.10759242897620425, 0.1696075504878536, 0.19348714646184817, 0.1308212653384544, 0.1490906998515129, 0.10935973492451012, 0.21140570839634165, 0.21014824305893853, 0.08106183697236702, 0.11747117154300213, 0.12215093956911005, 0.12141478844569065, 0.1943624354316853, 0.15333260816987604, 0.2729487052420154, 0.16651895450195298, 0.07613353853230365, 0.09901165816700086, 0.18279964104294777, 0.11979150367551483, 0.1360369159374386, 0.15659743454307318, 0.13902187842177227, 0.24292283516842872, 0.10697934820200317, 0.22089372505433857, 0.12004397489363328, 0.15946215426083654, 0.24703819246497005, 0.1279517513466999, 0.09639658950618468, 0.11347253181156702, 0.22644656302873045, 0.17737914284225553, 0.09790242940653116, 0.08800137788057327, 0.16632060811389238, 0.15525230672210455, 0.11512219993164763, 0.22135795326903462, 0.19335526681970805, 0.13563360320404172, 0.17556883685756475, 0.2292403334286064, 0.12924800132168457, 0.14883376832585782, 0.18019701819866896, 0.22466199472546577, 0.2183744899230078, 0.12677440827246755, 0.12032406884827651, 0.10229794745100662, 0.22147482668515295, 0.20636136032408103, 0.07469902644515969, 0.13971633568871766, 0.11616770789260045, 0.2063040665234439, 0.12436800185241736, 0.12952972057973966, 0.10814383727847598, 0.29251346946693957, 0.13765107229119167, 0.15210791607387364, 0.13357733463635668, 0.06974092335440218, 0.10021961483289488, 0.11114513443317264, 0.20103887014556676, 0.1384750343277119, 0.09012565686134622, 0.07915151174529456, 0.2106518199434504, 0.1164857330149971, 0.14016561704920605, 0.21125917875906453, 0.13087153842207044, 0.05003127706004307, 0.20149060059338808, 0.13378130650380626, 0.04643892236344982, 0.11422126233810559, 0.10390083800302818, 0.2782771474448964, 0.09430019301362336, 0.08531227256753482, 0.13974584348034114, 0.11540510662598535, 0.1726008250261657, 0.15334743628045544, 0.07829925161786377, 0.1570963062113151, 0.10350313590606675, 0.15992333967005834, 0.15499117464059964, 0.15921712678391486, 0.1395700583816506, 0.22980191657552496, 0.17257799656363204, 0.15205586183583364, 0.20191595511278138, 0.16465748485643417, 0.17763390729669482, 0.15442052244907245, 0.1857140104402788, 0.10620464992825873, 0.09483467292739078, 0.12779403012245893, 0.194530175649561, 0.20726174872834235, 0.13079198019113392, 0.12290968908928335, 0.18976732419105247, 0.11850381066324189, 0.16412417753599584, 0.08460982979158871, 0.130970036261715, 0.17894235817948356, 0.16371846024412662, 0.07428631812217645, 0.09925160193233751], [0.017148040096799377, 0.02123413451045053, 0.08545430478989147, 0.02488063444616273, 0.005498610635186196, 0.011181940899405163, 0.047995109562180005, 0.02310020732693374, 0.011177257019880926, 0.034577524857013486, 0.025054874022316653, 0.03281117998994887, 0.0666303449543193, 0.0666140993416775, 0.03870710912451614, 0.04877960047451779, 0.02687583168153651, 0.023850665202189703, 0.031671070464653894, 0.03372923150891438, 0.027014028855774086, 0.02300527921761386, 0.008224254197557457, 0.058678343921201304, 0.06234353670151904, 0.043560350459301844, 0.07601345903822221, 0.009642167224228615, 0.04489478393224999, 0.012962435739609646, 0.035388261821935885, 0.05061126918008085, 0.01464814811697579, 0.04404895080369897, 0.05865586797881406, 0.03563245809345972, 0.089610428258311, 0.04897832535789348, 0.025496624439256266, 0.025154648355965037, 0.033522224257467315, 0.047857686076895334, 0.04979145945981145, 0.037473659685929306, 0.025797264752327465, 0.047081937664188445, 0.04191912797978148, 0.023608279770996887, 0.045771327131660655, 0.01387710492053884, 0.054426464848802425, 0.010401247927802615, 0.0165432138601318, 0.047869471382000484, 0.014617351771448739, 0.03156395257974509, 0.07200451087555848, 0.006799354778195266, 0.09033993716002442, 0.056638818205101416, 0.04293195917853154, 0.05917488524573855, 0.026416264154249802, 0.07047007602523081, 0.0019200561746401945, 0.021925346736679785, 0.02918107966252137, 0.009613758738851175, 0.08119514895952307, 0.04536677501164377, 0.01182331141535542, 0.04042885091621429, 0.031203869948512875, 0.03621673611633014, 0.02233797342341859, 0.010934748206636868, 0.013683808847417822, 0.10023754512076266, 0.025000812274811324, 0.028354807691357564, 0.00767129851737991, 0.04969893961970229, 0.05207698115555104, 0.025734204464242794, 0.033254680020036176, 0.01607403737580171, 0.039608666411368176, 0.03230370311939623, 0.044079308354412206, 0.06507317069917917, 0.0989731852314435, 0.0708817527629435, 0.07261599603225477, 0.0702224881388247, 0.016253488684014883, 0.049288023583358154, 0.022337179325404577, 0.049543359491508454, 0.05219161699642427, 0.034289159666514024, 0.0436327098577749, 0.029287290271895472, 0.08106315057375468, 0.07268362795002759, 0.01339323947831872, 0.10342708803364076, 0.018487529450794682, 0.0242854913813062, 0.07063900367938913, 0.010677786995074712, 0.066684855701169, 0.04729998065158725, 0.006435452405639808, 0.01525716099422425, 0.07809081202140078, 0.05756320395448711, 0.020916287503496278, 0.09245159963029437, 0.04247865166689735, 0.023596388709847815, 0.04131195841182489, 0.012333641843724763, 0.02885398735088529, 0.03799731166509446, 0.020018504037579987, 0.03128875308902934, 0.010433674215164501, 0.05306115061102901, 0.04582092857162934, 0.06282689748331904, 0.0476395169243915, 0.024767755639913958, 0.008824792676023208, 0.0027919512103835586, 0.03376276174094528, 0.07839216108550318, 0.049207418924197555, 0.0324052511859918, 0.04112561255169567, 0.05027190360124223, 0.030695905115862843, 0.013520983502530726, 0.05890227956115268, 0.015989248859114014, 0.08277833549072966, 0.062014060240471736, 0.016519797245564405, 0.050263016382814385, 0.02983433845656691, 0.057701941041159444, 0.015110695367184235, 0.032975543435895815, 0.018508697357901838, 0.0349153875868069, 0.06937276615644805, 0.051615406118799, 0.014019505433680024, 0.0240834268333856, 0.03200173807272222, 0.041856316311168484, 0.00574199239963491, 0.049953952693613246, 0.057492451305733994, 0.02003209461690858, 0.042192119581159204, 0.04830318248423282, 0.08446952677331865, 0.019130108739773277, 0.05714681828976609, 0.006035008536855457, 0.0367773693142226, 0.023319304164033383, 0.04834806015423965, 0.03314513902296312, 0.03499873448163271, 0.06940368402865715, 0.011003229883499444, 0.008135631560435286, 0.03954621839511674, 0.06820008376962505, 0.024227952671935782, 0.0052840900661976775, 0.08460508746793494, 0.053528083954006433, 0.028334142589301337, 0.06167318810184952, 0.01739092647767393, 0.008437279338977532, 0.028595814583241008, 0.04198395829007495, 0.02592180640931474, 0.018577143782749772, 0.021783835873065982, 0.042687217428465374, 0.025697573910292704, 0.01813614107959438, 0.04206867073662579, 0.09168300181045197, 0.09110994506045245, 0.039978081549634226, 0.03289143212896306, 0.06404366344213486, 0.034374528913758695, 0.029999638863955624, 0.05016589151637163, 0.11478796630399302, 0.056545244515291415, 0.027897256950382143, 0.026532126394158695, 0.07465964808943681, 0.0841653352836147, 0.07173174933996052, 0.016260379525192548, 0.05009438558772672, 0.020186578221910167, 0.03251915601140354, 0.026201865111943334, 0.023087716981535777, 0.011735732423403533, 0.03551466070348397, 0.02960953821457224, 0.01240291112480918, 0.01716958278848324, 0.04351588097051717, 0.06803788739489391, 0.0362560959183611, 0.05655647692037746, 0.03560151053534355, 0.048924219081527553, 0.0020590145140886307, 0.033379832093487494, 0.008385983019252308, 0.017555894773977343, 0.008383976437471574, 0.04388312161609065, 0.06575222098035738, 0.03438618434302043, 0.03650671918876469, 0.013551089650718495, 0.07151105688535608, 0.05906115111429244, 0.02048868056590436, 0.010804607973113889, 0.03280809265561402, 0.06648040885920636, 0.007530408274760703, 0.03200344872311689, 0.003018272159351909, 0.0828018764150329, 0.02189606715546688, 0.012109433464502217, 0.0052640850117313676, 0.03332926586153917, 0.04332163865910843, 0.03556575386028271, 0.011351360226399265, 0.017636929878790397, 0.049422062875237316, 0.015320056154450867, 0.017916790056915488, 0.025748359075805638, 0.08042247674893588, 0.023909239207569044, 0.052598996699089184, 0.021651262322848197, 0.017923365485330578, 0.02664688840013696, 0.049294817945337854, 0.10313280421542004, 0.018574314344732556, 0.01499016594607383, 0.023104534047888592, 0.02390406087215524, 0.022416724568756763, 0.03344740835018456, 0.036061029823031276, 0.01839701897552004, 0.021904438581259456, 0.03272655660111923, 0.04683631646912545, 0.04316758735512849, 0.05793621479824651, 0.028393722204782534, 0.05672944927937351, 0.023966388289409224, 0.024479134408466052, 0.028383107637637295, 0.03675434047181625, 0.03704292459588032, 0.023409367495332845, 0.08322909372509457, 0.012256106892891694, 0.029002073642914183, 0.026461088018550072, 0.0478967564413324, 0.030598073353758082, 0.013931959838373587, 0.03310538588266354, 0.02320310981303919, 0.024239019949163776, 0.01838457872509025, 0.006000920766382478, 0.04840722045628354, 0.007099865215423051, 0.03406664895010181, 0.037839850192540325, 0.01501283113611862, 0.029316267427930143, 0.08032112164073624, 0.03644554024504032, 0.02712744757445762, 0.05980474597890861, 0.04504088683461305, 0.03985207229561638, 0.04430467262864113, 0.04706420404545497, 0.03417853884457145, 0.01188792093671509, 0.015270608710125089, 0.07010186687693931, 0.06701027261442505, 0.013889983038097853, 0.005605340747933951, 0.08187837011064403, 0.022977947774052154, 0.025825726115726866, 0.04638499791326467, 0.06613121353439055, 0.023742499033687636, 0.0487135344883427, 0.03733170167834032, 0.01114293176215142, 0.04886036098469049, 0.014703064261993859, 0.06310042343102396, 0.03437310399021953, 0.08938506769482046, 0.011799816875281977, 0.045803402754245326, 0.02838922850060044, 0.033752575764083304, 0.05600399250397459, 0.03119891982350964, 0.16798879281850532, 0.056554781112936325, 0.01026602305501001, 0.013513436788343824, 0.07994874904397875, 0.058913838511216454, 0.039892793938633986, 0.09548693909891881, 0.01998083076614421, 0.09804309607716277, 0.08478556293994188, 0.18579710129415616, 0.16179503611056134, 0.1448940476984717, 0.12940245709614828, 0.15622440143488348, 0.14747635053936392, 0.09910343957017176, 0.15649043169105425, 0.12382284243358299, 0.14410297764698043, 0.09553039926686324, 0.12598042900208384, 0.14653671736596152, 0.11936406372115016, 0.16556759539525956, 0.1029766711872071, 0.09043921425472945, 0.09847045439528301, 0.1033722136344295, 0.2607350918697193, 0.1613205365720205, 0.16596004308667034, 0.16977527586277574, 0.21047023124992847, 0.0960590087925084, 0.1174935101880692, 0.1360743201803416, 0.21989909873809665, 0.1675467102904804, 0.17609917558729649, 0.07597491188789718, 0.17505722993519157, 0.26658012822736055, 0.13612331676995382, 0.15105231490451843, 0.13093120709527284, 0.0924642532481812, 0.08845275951898657, 0.10877095948671922, 0.09519040657323785, 0.17689704371150583, 0.13457383116474375, 0.11689314240356907, 0.1121395752124954, 0.10308286509825848, 0.22002826211974025, 0.2118629455799237, 0.14059738372452557, 0.12635699473321438, 0.12742176884785295, 0.09613397312932648, 0.14509594155242667, 0.12768307904480025, 0.1470719839562662, 0.24339809169759974, 0.04548045719275251, 0.15983195160515606, 0.13291572482557967, 0.22250955866184086, 0.10495390102732927, 0.12417611957062036, 0.19750590581679717, 0.19251528923632577, 0.12024623982142657, 0.14681451808428392, 0.07422113529173657, 0.10868953104363754, 0.12546603160444647, 0.10947546543320641, 0.11124518336146139, 0.18486621062038466, 0.11465796429547481, 0.11204578258912079, 0.1398487199912779, 0.10808736726175994, 0.2592209621798247, 0.1424558847793378, 0.13196586485719308, 0.1712324976688251, 0.08542924988432787, 0.18390953773632646, 0.1172243406472262, 0.12242583106853999, 0.19094784365734085, 0.16801209625555202, 0.1495123139466159, 0.12735533178783953, 0.13815760292345658, 0.21977921220241114, 0.1601247288635932, 0.17664774146396667, 0.1403292902978137, 0.07671047671465203, 0.15673919959226623, 0.13383534969761968, 0.14583050447981805, 0.12439227750292048, 0.1549104883451946, 0.15776569372974336, 0.11152741470141336, 0.22803634725278243, 0.23357848345767707, 0.1170088877552189, 0.25230242405086756, 0.08460014476440847, 0.10559910937445238, 0.14964947768021375, 0.13619959470815957, 0.20034070214023814, 0.08009499666513875, 0.1130184784415178, 0.12607475597178563, 0.23506153200287372, 0.08700649923412129, 0.09400394250405952, 0.1321649385499768, 0.14882780145853758, 0.14804369275225326, 0.14320152055006474, 0.08499245144776069, 0.21520912618143484, 0.1209293793363031, 0.10112713527632877, 0.13254695164505392, 0.10861858172575012, 0.1943644243874587, 0.12485999381169677, 0.18862406053813174, 0.191807814699132, 0.15991591819329187, 0.11373003479093313, 0.1318019541213289, 0.12111302377888933, 0.1763218644191511, 0.18885540281189606, 0.12551646796055138, 0.10138904661289416, 0.1421551962266676, 0.08225931451306678, 0.0898807481280528, 0.1556186011293903, 0.179919870570302, 0.20604716468369588, 0.16018230468034744, 0.15451106446562335, 0.17222936527105048, 0.13315732358023524, 0.164898979710415, 0.265397293260321, 0.15623044251697138, 0.12471079244278371, 0.10134973505046219, 0.17117070645326748, 0.14080821303650737, 0.14037364104297012, 0.10045759190688841, 0.14756146003492177, 0.11545394736458547, 0.1939075137488544, 0.1371791257406585, 0.12516393297119066, 0.09459568653255701, 0.1112125808140263, 0.17699641728540882, 0.13814937992719933, 0.2284729972598143, 0.18079133005812764, 0.08563065392081626, 0.1289311339496635, 0.2130691581987776, 0.16885651188204065, 0.1218057369987946, 0.15989549428923056, 0.12574877502629533], [0.05741166110965423, 0.0486498173995642, 0.1111803122330457, 0.03632978747191373, 0.03968943434301764, 0.05809935741126537, 0.04430859116837382, 0.07912489832961, 0.024121693822962698, 0.042068904513143934, 0.05982160015264526, 0.08686684930580668, 0.04125565537833609, 0.04161397911957465, 0.043006693449569866, 0.010230992756987689, 0.039333040185738355, 0.018316007990506478, 0.0748336742981337, 0.01983913993171882, 0.04458368304767646, 0.028598998396773823, 0.030471464815491345, 0.05417420885351021, 0.04899023682810366, 0.03822836450126488, 0.04434439237229526, 0.0348113904328784, 0.02708372394408798, 0.016449901777377818, 0.010313465772924246, 0.10633347192197107, 0.03984001239587087, 0.03254488627135288, 0.021221427086857148, 0.02081568196445005, 0.0346867207554169, 0.011830408202513354, 0.03951737853640225, 0.007461153836629819, 0.025628789808251895, 0.061573309867526405, 0.02318711281986907, 0.13441483344649896, 0.00864867732161656, 0.022551832553290296, 0.03557202871888876, 0.03419547465455253, 0.01893595363071654, 0.013470164940372342, 0.0844454143953044, 0.0019455985784588847, 0.03992932615801692, 0.06395734424586408, 0.04560938679787796, 0.09765339433215559, 0.07460282926331274, 0.0687836493307259, 0.05078022652014624, 0.02067011340841418, 0.05758897132182028, 0.025416836142539978, 0.025222454678441864, 0.002200454873673152, 0.01312475456870743, 0.0066672761477093445, 0.0602949716267176, 0.051099620905006304, 0.013618236389447702, 0.0464655951509485, 0.008451360663457308, 0.04053700038639363, 0.04016194863652345, 0.08828927180729806, 0.05819538389914669, 0.04884653477347456, 0.05767061869846657, 0.014213549220585264, 0.050291440638829954, 0.06717398297041655, 0.03831693982647266, 0.012956351984030334, 0.011026587126252707, 0.04394699826661963, 0.05614116736978758, 0.05538665551284794, 0.02825067138473969, 0.03516547651088331, 0.08707274333573878, 0.02900990886701038, 0.058216906181769446, 0.10629320298903622, 0.08486486141919158, 0.032950607273960486, 0.02723675665038172, 0.051119232157361694, 0.023875016922829673, 0.03287749830633402, 0.027916929429920856, 0.04421162957441993, 0.059606904251268134, 0.008331013996212278, 0.031039001842145808, 0.04151901761360932, 0.06087143483455293, 0.06040072767063975, 0.031551562424283475, 0.05169549127458595, 0.059080213177367114, 0.010627628016663948, 0.03674169427540619, 0.04370893584564328, 0.07632196240592748, 0.026158581204072107, 0.020323252138041425, 0.04316124199249316, 0.04539977460808586, 0.08408757305005565, 0.05978522007353604, 0.09644564546761103, 0.027480691314849537, 0.04162343408097513, 0.06123276056314353, 0.015361934620159445, 0.054972206853562966, 0.07896178911323659, 0.000879907157695925, 0.011776878018281423, 0.03517869787174277, 0.018264098471263424, 0.06095862976508215, 0.057791544240899384, 0.09970162544050254, 0.016698012877895962, 0.027400659964769147, 0.011881209138664417, 0.01623581443709554, 0.057733489738893695, 0.03521340440784115, 0.007283198883669684, 0.03180760337272659, 0.02812683847878361, 0.010187271909671836, 0.022700512563460506, 0.012605913561856141, 0.0032973897259580554, 0.05185369118407834, 0.046138170728227124, 0.037983318470651284, 0.00995507616607938, 0.01786190267011989, 0.02965323958051158, 0.07818467885954306, 0.019646539622044656, 0.0035205904077884043, 0.03780014900257811, 0.004086802236997755, 0.043598211123025976, 0.05699118250049651, 0.006358204109346843, 0.04845782750635408, 0.04447902909305412, 0.025021720430231653, 0.1046961457177531, 0.030167319710017182, 0.05555523806833662, 0.06522799754748121, 0.0735691659792792, 0.028894183924421668, 0.035228874476160854, 0.03361826929904055, 0.03656764209154062, 0.014258072515076492, 0.06850866877357475, 0.008400501283176709, 0.06605898030102253, 0.06508337522973306, 0.02982970003358787, 0.0360862331581302, 0.006889453825351666, 0.08148421547957696, 0.06157746960525401, 0.03642960262368433, 0.050068410419044085, 0.013926473511673976, 0.005478359744301997, 0.014747555087524233, 0.03184412074915599, 0.025728317377797794, 0.050414934012223966, 0.022784352986491285, 0.07194091624114662, 0.02567213865404483, 0.06122306811448652, 0.07458811247488484, 0.02994029302499257, 0.030233615761972032, 0.027891599929716904, 0.01272380186492228, 0.041872268775478005, 0.0240087983183912, 0.014557939139194787, 0.05145265684404876, 0.057582696463214234, 0.01748975642840378, 0.0765480354311876, 0.0350579393125372, 0.05603298450296279, 0.05824034320539795, 0.042403149273013696, 0.03819110868789721, 0.012989189235668164, 0.012593512274179375, 0.008533931086276425, 0.07447207026416436, 0.025838902947725728, 0.005405338906712132, 0.039436781298718415, 0.10022112139267847, 0.068712714855792, 0.014616001990361838, 0.06972619914449751, 0.03302139331935905, 0.03784270375035703, 0.013285852564877132, 0.04507468795054592, 0.02142318549886113, 0.03430034383200109, 0.016966751973086502, 0.053228349061100744, 0.01814432140236022, 0.043191347212996334, 0.061457393821910955, 0.09466843926929869, 0.02361224283959018, 0.050734818214550614, 0.062472425488522276, 0.045296575262909755, 0.03280431512393989, 0.022990824036241975, 0.016108931304188445, 0.08944492190494202, 0.016539710923098028, 0.01074928457455826, 0.011125488508696435, 0.030072604968154337, 0.04505813434661832, 0.024596236034994945, 0.05635298373817932, 0.01423486091880477, 0.04225744341965765, 0.021424740298243705, 0.03914937718946021, 0.028706646917271428, 0.056767829446471296, 0.016083165792224463, 0.015583835847792216, 0.05429287084552925, 0.015235455957736121, 0.06120610261859838, 0.051213714978075586, 0.10410209360998124, 0.04979667304723989, 0.028232130680407863, 0.05419917099061422, 0.02135021197318565, 0.027304652030579746, 0.02937278382887598, 0.027238804977969266, 0.061968317968421616, 0.019554769351088908, 0.027368962837499566, 0.039217847734107636, 0.05514813667105045, 0.03349694670760073, 0.019988823696621694, 0.019283718465885613, 0.056409476019325666, 0.02323239496035967, 0.07316305534914136, 0.044039017157047056, 0.05248692868917715, 0.030257709586294368, 0.01090228481189115, 0.0295514948447817, 0.03869152031256817, 0.03729798590939026, 0.029341583940549754, 0.02913267493568128, 0.03208350419299677, 0.022859027885715477, 0.023767192142258864, 0.026804791450558696, 0.048881081747822464, 0.019798832036030944, 0.044980750608374365, 0.0485035475139739, 0.021196821180637926, 0.06106550274125766, 0.01151970343926223, 0.05442311776278075, 0.027322324422129896, 0.0058054024248122005, 0.03762087209906895, 0.01574415829963982, 0.02388903794781072, 0.04286807139578741, 0.032220437860814855, 0.04985384068277199, 0.04332020260335412, 0.021433989313663915, 0.019385325904295314, 0.03988792916061357, 0.007987407971086213, 0.016490764428453986, 0.011630030185187934, 0.011101358504674863, 0.036154017216176726, 0.03224878790206276, 0.047302489110734314, 0.008259215846919687, 0.023156944516813383, 0.053302942324080504, 0.044142309270682745, 0.026175745224463753, 0.010327261370548513, 0.027391707808419596, 0.06903819856233895, 0.024331697495654225, 0.04185695084743202, 0.050974891855730675, 0.0842978605942335, 0.03074458072660491, 0.07142290458432399, 0.05801585466542747, 0.04204892218695022, 0.08791549655143172, 0.037182003070483916, 0.05035034118918702, 0.16579519724473357, 0.014077581272431416, 0.041612424320192076, 0.04278987129509915, 0.031541313364868984, 0.017384302809659857, 0.05220373255724553, 0.05271362140774727, 0.17896759120048955, 0.03641673378297128, 0.03426401199249085, 0.03627127283834852, 0.025702713282953482, 0.2241991914343089, 0.20998851803597063, 0.1345274766208604, 0.06315104532404803, 0.19609759154263884, 0.21982993057463318, 0.13161867333110422, 0.16231179353781044, 0.1527044246904552, 0.12853203661506996, 0.16203844570554793, 0.1538214460015297, 0.17981613316806033, 0.13603693078039214, 0.09619534874218516, 0.1268648760742508, 0.11095977562945336, 0.10611261619487777, 0.15685592457884923, 0.1631628884933889, 0.11833488300908357, 0.12086996299331076, 0.11335028524626978, 0.1312496478203684, 0.10598464024951681, 0.09190281853079796, 0.17449012520955876, 0.14628757839091122, 0.09223643617588095, 0.15274911682354286, 0.10011136517277919, 0.1775995607022196, 0.17638519930187613, 0.17441156145650893, 0.12670203403104097, 0.09463128735660575, 0.13685320416698232, 0.11490351869724691, 0.17782126989914104, 0.10434913230710663, 0.12311579834204167, 0.14159830345306545, 0.23531041864771396, 0.2109411239507608, 0.15875427896389738, 0.15838746505323797, 0.07051353619317524, 0.12088502859114669, 0.12545685865916312, 0.09463516878895462, 0.29492815083358437, 0.09429445621208288, 0.10643203655490652, 0.1355675669037737, 0.09869772227830254, 0.1649926684331149, 0.17454596440074965, 0.16121788270538673, 0.13219938904512674, 0.1481922558741644, 0.2228784654289484, 0.11967481579631567, 0.09252141346223652, 0.11063966507208534, 0.12914362567244098, 0.11653475186903961, 0.09993785846745595, 0.19581429893150926, 0.15850594150833786, 0.15695856360252947, 0.15881375467870384, 0.13612212933367118, 0.07376965717412531, 0.14530442567775026, 0.11058648276957683, 0.16000821167835966, 0.10888651187997311, 0.13340318226255476, 0.13733896950725466, 0.10586519158096053, 0.15029896079795435, 0.16897184163099155, 0.15045700856717303, 0.132744615257252, 0.18231730442494154, 0.18214911891845986, 0.09142279741354287, 0.14109347976045683, 0.17946963926078752, 0.06948310867301188, 0.11882743157912046, 0.2577593765454367, 0.22377517278073356, 0.16339429013896734, 0.07874942355556414, 0.14724132721312344, 0.0813935324549675, 0.11771927893278189, 0.1830899840570055, 0.14906163734849542, 0.09705409524030983, 0.09491938908468, 0.18879978626500815, 0.19569013762520626, 0.10021822701673955, 0.11942971410462633, 0.078745868668193, 0.14601614529965445, 0.1284261024557054, 0.13340462202904746, 0.08983394829556346, 0.22590360778849572, 0.12125959052355029, 0.20477273385040462, 0.10003460483858362, 0.16917851491598412, 0.07440122484695166, 0.15885558212175965, 0.10128938360139728, 0.22749840893084183, 0.12055128478095867, 0.18338399328058586, 0.15394992660731077, 0.08678087891894393, 0.15686156490119174, 0.13710882951272652, 0.10127023619133979, 0.10304803610779345, 0.13274590659420937, 0.10702273415517993, 0.14544535952154547, 0.22977622342295945, 0.23069241957273334, 0.10100629137014039, 0.07615456357598305, 0.12099708546884358, 0.062491988501278684, 0.10191308450885117, 0.1267987655592151, 0.10014853192842565, 0.11072528664954007, 0.24668314901646227, 0.20483823580434546, 0.2231781298178248, 0.0954141492547933, 0.11186659845407121, 0.14178952522343025, 0.125642484636046, 0.1437559345504269, 0.12570231658173725, 0.09734661274706014, 0.18017542170127854, 0.11789594718720764, 0.10677405531168915, 0.10885931216762401, 0.15750131104141474, 0.11818854633020237, 0.1370178273646161, 0.2057216438697651, 0.08456746058072895, 0.2608804340707138, 0.15100716263987124, 0.09559374157106504, 0.4728431539842859, 0.11772799916798249, 0.19826901174383238, 0.15019706392195076, 0.13705589954042807, 0.1715999052976258, 0.10556636581895873, 0.12031397563987412, 0.25609286909457296, 0.14270551357185468, 0.13187364558689296, 0.05162583700439427, 0.13761570153292269], [0.03192976088030264, 0.03938347283110488, 0.020317687885835767, 0.017792561957321595, 0.06226837940630503, 0.025659199309302494, 0.008095068551483564, 0.028308128457865678, 0.04479328781599179, 0.06301032670307904, 0.08116138124023564, 0.02484533604729222, 0.020694253616966307, 0.047521300220978446, 0.04865120892645791, 0.05776439647888765, 0.03203005100658629, 0.06962675877730362, 0.027468742737255525, 0.05185541667742655, 0.05558181437663734, 0.05310795044351835, 0.029346443152462598, 0.02656899072462693, 0.04026708869787399, 0.02293649326020386, 0.01184975692012813, 0.03486000481643714, 0.03752783275558613, 0.044327883297228254, 0.03379088171641342, 0.028627253814192954, 0.026014027534984052, 0.0333058436808642, 0.00898553629667731, 0.0342151118820766, 0.0326450502325315, 0.034928887253045104, 0.0587118518888019, 0.06366307527059689, 0.04672058224969078, 0.037124805749044754, 0.021450056810863316, 0.05268283341138158, 0.043877299467567354, 0.021653214171237778, 0.06713695722282864, 0.04613119825080503, 0.053251485514920205, 0.03157813873258419, 0.08229365368606523, 0.06193699191499036, 0.05681714515958447, 0.043034579648519866, 0.011513162335177185, 0.049836956823128276, 0.0350733871164266, 0.04647394802304916, 0.04797839268576354, 0.022266372870944906, 0.049608564586378634, 0.04388837973237969, 0.05398132838308811, 0.043301871555740945, 0.0668906606733799, 0.048016694927355275, 0.09436061867745593, 0.06067647635063622, 0.04824857154744677, 0.03159232859616168, 0.01707439121673815, 0.049930300447158515, 0.03571698129235301, 0.008725649167899974, 0.009507355171081144, 0.03352414641994983, 0.03939416717912536, 0.024812462615955155, 0.027467156396596693, 0.04554020008072257, 0.022699818655382842, 0.0192035813597613, 0.012787513387593208, 0.028699128961306997, 0.01661546564719174, 0.02379519894020632, 0.027213462490180973, 0.03118468914180994, 0.05303759113303386, 0.009831123588810442, 0.018693198981054593, 0.09138928944594227, 0.054349095953512006, 0.038555158098461106, 0.03725197646417655, 0.06092370058468077, 0.06279874782194383, 0.04504652344621718, 0.026044234800792765, 0.06861296278657392, 0.015061243284435477, 0.06318214131169952, 0.06755358408554457, 0.01360753833068884, 0.03813220071606338, 0.02521026490285294, 0.04417582465976011, 0.04117406737350393, 0.06728297477820888, 0.0175984198358492, 0.06109437228587922, 0.059880556364078075, 0.038491615414386615, 0.03358074631250929, 0.041718447537277825, 0.004829417466680752, 0.048264238284900784, 0.04873382480582222, 0.04975316835043486, 0.02205578475695802, 0.03205648259609006, 0.02498801393812755, 0.03946892742533237, 0.06642942331382073, 0.027509054343681782, 0.009593138165655546, 0.1848251253250055, 0.014275774592533708, 0.022488380782306194, 0.017681154458841775, 0.049038461584132165, 0.04933525015076157, 0.03627447520557325, 0.0453227471007267, 0.05444203510705847, 0.0606885214074282, 0.01914990923978621, 0.031488528111367486, 0.035108516676700674, 0.023476548558392096, 0.0592921297356952, 0.06565068775671534, 0.046079819367150776, 0.053969476284692064, 0.028301649508648552, 0.028770885364792775, 0.02314173791091889, 0.06442166893975809, 0.030360586097231135, 0.03619855720899068, 0.05352482963644434, 0.0557952634699177, 0.018516291384003125, 0.00535710719304916, 0.055902028834680095, 0.04058998230902944, 0.03604302903113421, 0.051960601267637685, 0.03320055518997833, 0.011588743582251482, 0.012222226923768176, 0.04392487113364041, 0.015589305476169102, 0.03168109687976539, 0.021430842607514933, 0.028311271453276277, 0.03541071178915445, 0.04315429549023975, 0.011928246458410285, 0.05366060555388685, 0.02514127299946267, 0.08132170740282163, 0.024841625308908988, 0.05776778438303154, 0.021803348790854216, 0.04350159091700334, 0.07614101938088425, 0.10836757996003143, 0.0008491683286138141, 0.02184024837333709, 0.07864463230362162, 0.02774377524474403, 0.043971184859401546, 0.06031765908119269, 0.029282167597557418, 0.020929609054292087, 0.012068600499333115, 0.0423416883131722, 0.020270273926144, 0.04618008722900413, 0.025224621749657672, 0.05150006523763295, 0.028478262101998553, 0.06595916143851355, 0.05413438149844296, 0.05428695221780799, 0.022636073736066464, 0.0577097632776713, 0.023081310391717125, 0.08148730281391181, 0.012349834578344598, 0.05060685711214319, 0.06502440417534672, 0.057027673901757225, 0.053371464819065295, 0.04580554385029245, 0.08287021337309852, 0.04402664926601574, 0.015600367187289521, 0.021619093931803945, 0.052839070340269245, 0.05120244175486732, 0.07949196457047947, 0.003290768840997771, 0.01813009072066052, 0.011107168593298411, 0.019429643252806272, 0.04559597990009934, 0.013900588328397134, 0.07521570965764113, 0.02448368933983147, 0.006564080049429322, 0.11239624698646367, 0.07231386029161513, 0.02150062489818083, 0.043733508355217054, 0.0671743243583478, 0.03358141053467989, 0.02682362715859199, 0.0399846384243574, 0.033086880430346355, 0.046654983816551976, 0.0687290049972944, 0.015624876614310779, 0.03409030490729492, 0.025040737964445725, 0.05557198091992177, 0.04690680194471497, 0.061247421690495685, 0.05011985980672762, 0.045429315796354786, 0.05615844456769992, 0.08843543779221363, 0.0307027310191188, 0.04348647707956843, 0.09569606889272109, 0.04795923043275252, 0.0075445652055350365, 0.008233448479586514, 0.017235286977665965, 0.008636488473712234, 0.058561084588291124, 0.009844908981904155, 0.029715971468249336, 0.08471896260743961, 0.010301069123670459, 0.04433799134858418, 0.07333098852541298, 0.03459391518845223, 0.06970725953578949, 0.06700016456306912, 0.01354170704871649, 0.03976283645897638, 0.04240802147251088, 0.052990435069659725, 0.06401428181561641, 0.09346471284516156, 0.00660604247059382, 0.03389173587493133, 0.06483371675130911, 0.02535979096137453, 0.017598035774426535, 0.0636080524418503, 0.013315352935023839, 0.010560942337178858, 0.01609044811630156, 0.02977118540002266, 0.054507332970388234, 0.026920032141788397, 0.04537191067356616, 0.03285018356109504, 0.012014072126476094, 0.0622572100837715, 0.012701680298050633, 0.0854443600110244, 0.023646511508559342, 0.023285002098418772, 0.03409447206649929, 0.0764227683248464, 0.02392674832663033, 0.10702654137276113, 0.06566615411429666, 0.028586639782588463, 0.054563977391808294, 0.043582566650002263, 0.028222657165315468, 0.0204195977494237, 0.046993529322207905, 0.03205230430467054, 0.039008632593322545, 0.03624714932811912, 0.01410430044415989, 0.049301163307973184, 0.02695933999348199, 0.028773386402463075, 0.00556267514184583, 0.03050527891900856, 0.016750931717979256, 0.04613761411746964, 0.029270673585415352, 0.020071493381692562, 0.023450990847777575, 0.02711566412472166, 0.033764030813472345, 0.02182862262998242, 0.019790234255196992, 0.10140802332898602, 0.02796960707200924, 0.11873098948854022, 0.010551405739533948, 0.026307008884032257, 0.02765802935755346, 0.027773479705501813, 0.03158492938382551, 0.010399220009276178, 0.005334420202416368, 0.016354008876078296, 0.08667794303619303, 0.04620332758349832, 0.007001422109169653, 0.01874229947134154, 0.011912757836398669, 0.04702722653746605, 0.055134358699433506, 0.057513877109158784, 0.03866136685246602, 0.04767624210217036, 0.032954841226455756, 0.06167994535644539, 0.03344957913213875, 0.009192716097459197, 0.06346710375510156, 0.015297763893613592, 0.05747080656874459, 0.07033650428638794, 0.030357547002495266, 0.03492392599582672, 0.07232451011077501, 0.07171421981183812, 0.01462299302147585, 0.01688687647401821, 0.045060598276904784, 0.15928752691252157, 0.2677342272363603, 0.08816826462862082, 0.11451766869868152, 0.12565471522975713, 0.17656021256698295, 0.12022561553749256, 0.15648583037545905, 0.18416157108731568, 0.19647372682811692, 0.18999540101503953, 0.14059134264243767, 0.15527403680607677, 0.20014133158838376, 0.11517249527969398, 0.10003689065342769, 0.14663756039226428, 0.18368490447755903, 0.09985455981222913, 0.13672337285242975, 0.10445600157254376, 0.1421530291554518, 0.11482449481263757, 0.15507536387303844, 0.07624583289725706, 0.13537210004869848, 0.12040059911669232, 0.11233277851715684, 0.11647706473013386, 0.18232431029900908, 0.1970509099191986, 0.19491680490318686, 0.07877151729189791, 0.10799643190694042, 0.20628407306503505, 0.24823227839078754, 0.22765056404750794, 0.07700980713707395, 0.2555677847703919, 0.21447567647555843, 0.18890745704993606, 0.09421702794497833, 0.059347909555071965, 0.16726033034501597, 0.1464370172470808, 0.1413156490889378, 0.20839526056079194, 0.12887315737316385, 0.11530501316883601, 0.11336509851389565, 0.15318031946662813, 0.18374769017100334, 0.13305276981554925, 0.1295358655625023, 0.10572710016276687, 0.1168634342320729, 0.10780093536595814, 0.10887053344049491, 0.16267820668872446, 0.09249782058759592, 0.13231791002908722, 0.2073803439270705, 0.1183224817214068, 0.15973946516169235, 0.21130404900759459, 0.15481522626942024, 0.19080674654105678, 0.11653490029857494, 0.1805290995980613, 0.25431545509491116, 0.10419017911772244, 0.1287817841512151, 0.10473026966792531, 0.10358373314375058, 0.21878400701098144, 0.15861877764109522, 0.1397184730740264, 0.08631358563434333, 0.18330810125917196, 0.1090681079949718, 0.10992592680850066, 0.1681097925757058, 0.0615914813533891, 0.20302984456066042, 0.16515340277692303, 0.09241790612577461, 0.11274546457570978, 0.1605277298949659, 0.11898541997652501, 0.1120567589532584, 0.10528397862799466, 0.13404525874648243, 0.18400882225250825, 0.1675604103365913, 0.09028390501043759, 0.07288753302418627, 0.20248398010153323, 0.12132685878896154, 0.09484190144576132, 0.10965647525154054, 0.081099909148179, 0.18918070098152384, 0.16930092475377023, 0.11635736373136751, 0.08380164581467398, 0.07844368097721599, 0.1849544222932309, 0.15579987812088802, 0.21364763262681663, 0.18610009050462395, 0.18676941865123808, 0.1386456986074336, 0.19349200010765344, 0.1100100640906021, 0.26059619151055813, 0.10191333683906123, 0.1663586060749367, 0.1829596035531722, 0.12163153267465532, 0.12157498102169484, 0.12830054591177031, 0.11027740794816054, 0.16058353940024972, 0.15622701379470527, 0.1453020062763244, 0.10016632120823488, 0.24920686671976, 0.11684335171594284, 0.12999798607779667, 0.0636914253118448, 0.14014936401508749, 0.0901139086636249, 0.11907002481166273, 0.14790833985898644, 0.24250462010968477, 0.13092368171783164, 0.1514092879369855, 0.11233455967158079, 0.10293214974808507, 0.10946047405013815, 0.20844041282543913, 0.15330357535276562, 0.21213477943092585, 0.08995600190246478, 0.11544739420060068, 0.13160452799638733, 0.11537191778188571, 0.16307524085277691, 0.07962437855894677, 0.14275715220719576, 0.26298207754734904, 0.21179254545131698, 0.1569626305717975, 0.10438810248160735, 0.10262429947033525, 0.08110346403555013, 0.16553831024793908, 0.20218431571265683, 0.10216984534054063, 0.11860716957016848, 0.11795324098784477, 0.23679965670453385, 0.10314678627764806, 0.16913656872930005, 0.08543255986296572, 0.1478510460583493, 0.08880422581569292, 0.17637366632698104, 0.17478459456469864, 0.13321734848432243, 0.10478652446181513, 0.16605640354100615, 0.15971038781572133, 0.07350362691795453, 0.12659175088629127, 0.1262830026098527], [0.023638858110643923, 0.07116959473933093, 0.03600065239879768, 0.07466844996088184, 0.01875609228591202, 0.01905877907120157, 0.014002257921674754, 0.03862781435600482, 0.00034761078154588176, 0.03861798832076602, 0.03127058160316665, 0.02960188481665682, 0.034050143585773185, 0.014765628238819772, 0.019414683411014266, 0.025226748002751265, 0.07536899283877574, 0.02695355680771172, 0.008653734130348312, 0.04734527763503138, 0.060072512860642746, 0.019565268885344267, 0.03997828192950692, 0.01835456998378504, 0.03482765459921211, 0.01862854122009594, 0.041579521202947944, 0.04120329685974866, 0.05320262622262817, 0.08161652556736954, 0.06491475927759893, 0.052769538524444215, 0.08606225732364692, 0.04538705790764652, 0.03537821314239409, 0.009692189833003795, 0.04350855597294867, 0.04780520510394126, 0.028501986707851756, 0.054642852846882306, 0.03824308128969278, 0.02755120276560774, 0.007778298586345045, 0.040153718218789436, 0.0406323069910286, 0.03386082542419899, 0.0511488438496599, 0.057300624685012735, 0.022230621761991642, 0.039396901993313804, 0.07474840895156376, 0.019287549803266302, 0.055829892080510035, 0.022319158124446403, 0.00817194020783063, 0.05977396169328131, 0.02374991865508491, 0.03296686030807905, 0.04397485849040095, 0.02227069217042299, 0.05406591095379554, 0.055342757477774285, 0.04834638661122881, 0.05024775782658253, 0.013406235411821399, 0.03590393942431547, 0.06703036997350864, 0.022110842837719247, 0.07245919507113285, 0.03879922820487991, 0.025234917193301953, 0.023198720009531826, 0.059277275649947114, 0.03733470737643074, 0.05966110329609364, 0.00686881052388344, 0.049202494774363004, 0.05884756101295352, 0.010162105681956746, 0.016348546669178177, 0.0657673979003448, 0.01936125619977247, 0.04050693227327429, 0.018730313786363695, 0.05876832190551795, 0.024240392922365572, 0.08632411670987494, 0.06944867302081548, 0.02235144711448811, 0.035221152429585345, 0.0747147822403349, 0.012444223702914314, 0.05755409780249465, 0.053249856500769965, 0.016311018116539344, 0.03267474727181252, 0.031171234004432335, 0.06921875567059033, 0.05188813425775152, 0.04460281190404203, 0.028938248942722566, 0.019499843001540285, 0.05413956911070272, 0.06796156492782757, 0.03924309559806716, 0.015248764520947589, 0.02969181827211287, 0.03260691497416701, 0.04979643184924498, 0.020947014272678643, 0.027682446016115136, 0.10360803848016076, 0.01258060168765951, 0.030668777762912214, 0.04528342069534119, 0.03957059052481782, 0.051112853398080915, 0.016225903054873925, 0.04313982732128352, 0.08991084221634082, 0.03873879511957057, 0.01483769912738353, 0.04272216887329705, 0.004552874688670272, 0.09215223952196538, 0.05519828358956147, 0.021285938273649663, 0.012677538234129315, 0.08937822509324178, 0.015251785989676137, 0.028637834984692745, 0.05906683967623394, 0.016940593122853898, 0.03567797029973008, 0.08627949137007818, 0.026415119391458575, 0.01210287751746364, 0.07136104657547548, 0.059382957479101606, 0.09235215926310048, 0.04359844489954412, 0.017184637254104018, 0.019133008681819774, 0.040262071779579856, 0.0675366482755635, 0.03676424814329948, 0.01515362582722446, 0.02949213045212673, 0.01974979091755813, 0.04994157738110516, 0.048583851603325456, 0.04022417400847189, 0.019033917124033906, 0.07179333275416866, 0.0828997434291523, 0.03308139224827755, 0.018427871909807436, 0.06471096552559175, 0.02135796741640661, 0.06700999801978469, 0.0361083862662781, 0.01711476405034773, 0.05101626658870373, 0.03135564285912551, 0.06256371707422659, 0.07069431594572961, 0.006814802582084667, 0.041101062306552194, 0.03371885628439486, 0.11698021859047003, 0.05494830598763656, 0.03325479876366444, 0.019293794975965284, 0.07462392110028304, 0.055919357982929796, 0.026165637173107825, 0.011935960155824432, 0.02027900714892894, 0.04952198934915941, 0.07591779620270245, 0.030601483522332273, 0.031149570713751018, 0.04328326220274903, 0.05834306386532262, 0.02316406727914, 0.05267288492177613, 0.09000828620628454, 0.019147936982335523, 0.0724896379688289, 0.03762910622754134, 0.023655617660551798, 0.016422715052613057, 0.05321241515048314, 0.018340573078603484, 0.02660454330907669, 0.01766291432431899, 0.06374194330419414, 0.002516360468689527, 0.09358866635011509, 0.005138842489031958, 0.037874322952120565, 0.02442141943902243, 0.05928972517722286, 0.03861383971525356, 0.045660390896955505, 0.04979849501978606, 0.0453178563475376, 0.0019456885638646781, 0.026922347642539535, 0.04253359657013789, 0.019547149349818937, 0.03388719393115025, 0.011559488120838068, 0.020503454870777205, 0.05071712912467774, 0.006592165236725123, 0.021025616988481488, 0.042795641493285075, 0.03986272211477626, 0.008157688189385226, 0.03951743790821638, 0.07417078799335286, 0.031694641074864194, 0.04426337582117412, 0.014003867454448482, 0.0133535169516108, 0.06124373321654275, 0.02841174711647909, 0.02864697638869984, 0.021506593620870262, 0.06848060074844398, 0.06257012923015282, 0.07953915031976067, 0.037438188737723976, 0.023416929980157875, 0.008077042712102411, 0.07104087664629333, 0.10323664551833645, 0.08212011729483493, 0.021935413969913498, 0.08085986890364438, 0.026982821545971092, 0.0650710629997775, 0.020474648408708163, 0.08204196914448403, 0.0262862398813013, 0.07191113385488279, 0.03558526863344014, 0.02500451559171779, 0.016147515561897308, 0.013823457848047838, 0.04547657947114203, 0.06451730951084755, 0.07391370803816244, 0.044572272527148016, 0.0364896757673705, 0.0866580534784589, 0.021359130732889753, 0.04709685854322743, 0.04664913198212162, 0.0145468922710279, 0.038156558002810925, 0.025291572746937163, 0.07386609184322879, 0.04241710907081142, 0.04905363108264282, 0.05910798063268885, 0.023069560338626616, 0.007221889600259601, 0.04523390089161694, 0.044788530649384484, 0.027092750315205194, 0.10319274748326279, 0.050409939358360134, 0.02774317967123352, 0.02709359450818738, 0.04732629349746276, 0.07081456613377668, 0.07875375027651899, 0.052516258365358226, 0.0029652118473677547, 0.014313173269329127, 0.024530123664590064, 0.028262380619707983, 0.03814661322394386, 0.049977534436038695, 0.018841437413357198, 0.01884083256300073, 0.043951722036581486, 0.011915389677596977, 0.05518974889128003, 0.07054196044919081, 0.030772231293667573, 0.027159794080944266, 0.044803907949244604, 0.007943499731482007, 0.038651036156807095, 0.03666290416731499, 0.10500618533114903, 0.06196436603204347, 0.03216111057554372, 0.024911724867706653, 0.026672694730223157, 0.0692123880435247, 0.051822020031977445, 0.0814321092911996, 0.03153439283778425, 0.053643714272766374, 0.017163150223495904, 0.0595878125022864, 0.06163120851852, 0.00785578344220994, 0.08108334441203624, 0.019979945755039807, 0.0051079000331810676, 0.03707835843670182, 0.02381535196036566, 0.01804468993213959, 0.029144888831069693, 0.028901456971652806, 0.05458667968923692, 0.019604361514211632, 0.043813185329781845, 0.01747326590702869, 0.04846159019507468, 0.050691944343270734, 0.01719044455967378, 0.02765198085398879, 0.039297903203987516, 0.012906719002785394, 0.05453282574308105, 0.021841654743184336, 0.005524209163922933, 0.05511555638804566, 0.06173590700200293, 0.07143718350562267, 0.04497100249864161, 0.01903012474940624, 0.011145477328682318, 0.0353522936347872, 0.030318884819280356, 0.020662075949076097, 0.052088818410993554, 0.03421304500079714, 0.01800174741219962, 0.03626014804467559, 0.05854910261405166, 0.027646028829622082, 0.02724793339439202, 0.015158505448198412, 0.08408999987295829, 0.018748802540358156, 0.1283793619950302, 0.15394289104733616, 0.10301687332685106, 0.1570175346569158, 0.0648055893543642, 0.12820556585211307, 0.08631671749753878, 0.19428882922511548, 0.12933257647091523, 0.11337995631038211, 0.17026374262059107, 0.13997524132719263, 0.1880901594995521, 0.11968004051595926, 0.16874542721780017, 0.10611594843794592, 0.2117870535585098, 0.10336618739529513, 0.13329920737305656, 0.06872252604807727, 0.15267524344380945, 0.06483097822638229, 0.17118917108746246, 0.1268565491773188, 0.18287452374352142, 0.15776401647599414, 0.16238912532571703, 0.07706388001679443, 0.1535499980673194, 0.2047509592375718, 0.15439340437296778, 0.12720144004561007, 0.14242882607504725, 0.11152703620609827, 0.13307242188602686, 0.12922650872496888, 0.12883409071946517, 0.15159693255554885, 0.2931265428196639, 0.08230157982325181, 0.06764932855730876, 0.1768009949591942, 0.12308371529798023, 0.15269440569682047, 0.13774017454124987, 0.17437665082979947, 0.14425134781049564, 0.14586240198696032, 0.09211105774738826, 0.08271838480141014, 0.20501047343714163, 0.09669203107478097, 0.09297433876781724, 0.14550205960404128, 0.1197925946325995, 0.13222603214671835, 0.13958513882244006, 0.10274568514432758, 0.12912514619529247, 0.08620634529506788, 0.14655711158411577, 0.12000406961305998, 0.18185536202508956, 0.11900401819730178, 0.20368357276311144, 0.12776507152011618, 0.10394317010650411, 0.0951130673638545, 0.18583238299470395, 0.10572203871561214, 0.11155845131725073, 0.14879192603984848, 0.15459528338396922, 0.10150635047466494, 0.10807111422764137, 0.13676569011295214, 0.17864674591692165, 0.19123701407806948, 0.1482294374727644, 0.09204990477883257, 0.17074849864002317, 0.11722355397068895, 0.12654527759877965, 0.14201883401256055, 0.1255322460201569, 0.09883163540507667, 0.16866735328221694, 0.15154925698880106, 0.0879346216970589, 0.1524675459950231, 0.2084383793408051, 0.09636648799641989, 0.12906659074360505, 0.28398892376571894, 0.10773510686703958, 0.07691749138757586, 0.18580918345833197, 0.0906094629317522, 0.14286460034782067, 0.14215616101864725, 0.13648238265886903, 0.13910308422055095, 0.17805491283070296, 0.12543585587991402, 0.18088736396748573, 0.089805234601954, 0.1530675427056849, 0.15145208017202094, 0.15517414372880012, 0.11547794842044823, 0.12484676874009892, 0.1303051461582072, 0.11178444270626642, 0.07418474036967382, 0.0905055103066843, 0.0934743533434812, 0.1764634216669947, 0.14592659776099026, 0.09216090038535185, 0.16736421617679298, 0.19028451206395403, 0.12001844501355663, 0.1710312272189185, 0.19987061095889658, 0.2134629714419134, 0.178993254667148, 0.09551862138323486, 0.18664865638129413, 0.24302286183228716, 0.11661101496429183, 0.10984112901496701, 0.1339546573581174, 0.08486269434797578, 0.14843962853774428, 0.20157231105258688, 0.1286291392170824, 0.14411937911063433, 0.17633136390941218, 0.16571053303778172, 0.18573833804111928, 0.09581133184838109, 0.11459613597253338, 0.14783155726036057, 0.1337355753639713, 0.19892627256922424, 0.06952666532015428, 0.1601687679067254, 0.14546092977980152, 0.16742116858949885, 0.10242817952530459, 0.1285513472976163, 0.12161798105807975, 0.1561172353103757, 0.21612981974612921, 0.18013487075222656, 0.13093463581753895, 0.12490066350437701, 0.2088009036378935, 0.2659664611564949, 0.18966636242112145, 0.15846665221033618, 0.08768344181589782, 0.16563376528210938, 0.12344854025286622, 0.19616398407379165, 0.13049572968157008, 0.19323742861161008, 0.10318764150724746, 0.15465642150957137, 0.1816738920751959, 0.14913625287590548, 0.18605133140226826, 0.08324310547322966, 0.3369136416586116, 0.1151630403182935, 0.1349986661807634], [0.039213335476233624, 0.007781524145684671, 0.014753532159375027, 0.0048577285451756325, 0.022614926238020416, 0.0256113048089901, 0.007869877754274057, 0.041624692021287046, 0.0244364312311518, 0.04826633114134893, 0.01944559015100822, 0.04711717483587563, 0.04497921807342209, 0.047540796440443955, 0.08032658384763636, 0.03341046794957947, 0.029015964792051818, 0.06218286172952503, 0.03708019525220152, 0.029093387493048795, 0.025345615940750577, 0.0548723620158853, 0.04620310864993371, 0.07381840143352747, 0.030469765297311824, 0.04082123181433417, 0.007236226038003224, 0.08481361612211913, 0.06651321178651415, 0.03456817379628774, 0.04182476761343423, 0.030860424412821885, 0.0184822583469213, 0.019733513763640076, 0.083809430943802, 0.058833886942011304, 0.0461043139512185, 0.01715703863737872, 0.011488053623907035, 0.04459374657017179, 0.04119846176763531, 0.11964800942223519, 0.05278016978991218, 0.051082109930575825, 0.045075355883454904, 0.05104286516143475, 0.013363134257815545, 0.011228610856051091, 0.026305058891011868, 0.02274831429531332, 0.03173110650095623, 0.03863503545289859, 0.09644338191719726, 0.03292663961474318, 0.08978857338661328, 0.05482241547724698, 0.09270217837183736, 0.031550323037663475, 0.04093071343959309, 0.06042021275789011, 0.008375098495889688, 0.03567004045180511, 0.047264665554394014, 0.046799773117527366, 0.037449410010594875, 0.03976029089244548, 0.03950649865146261, 0.035814874281641096, 0.04487902071559802, 0.02701509012695169, 0.12578991969348863, 0.029967713526275475, 0.080530585400993, 0.0948438978230115, 0.06911628734087572, 0.06737621821230277, 0.030149973863444757, 0.0904933836136479, 0.05282545193040278, 0.020761555279023014, 0.024450802920910064, 0.008267076118499972, 0.006925952184246853, 0.06456431714468636, 0.042095298995263875, 0.02767448462691391, 0.007948369147925405, 0.02122467769368086, 0.07254172189277597, 0.064572718256386, 0.033259682095376775, 0.035039226058870554, 0.08971547926194035, 0.09041575496667065, 0.01472908674259088, 0.019198800073354505, 0.02182424952479778, 0.04070444374519866, 0.06812632171204314, 0.07175448874477297, 0.017289922034251504, 0.07152121688704938, 0.032418004993814975, 0.03573164241970517, 0.03069662314374, 0.004799805774382548, 0.02896923731896095, 0.010039608641818631, 0.022596220405830536, 0.021106232779857237, 0.007035495500531397, 0.04012956873339135, 0.008274573665403295, 0.009019833723868942, 0.010535821566008963, 0.013749000027019065, 0.02962001733976649, 0.005728511287088622, 0.0038479869999719085, 0.043872215755982324, 0.05059143899416085, 0.05082049174234271, 0.02501293896784773, 0.04117339944059495, 0.029955687023175415, 0.04348153066530358, 0.04084378197148908, 0.04402550264785532, 0.0626784011546988, 0.03157453189487569, 0.03299627162050456, 0.055513770566903986, 0.08591186109697446, 0.025219059352821205, 0.04970034598954953, 0.006593338293896522, 0.016037633176892996, 0.042806313576875255, 0.017942271697393153, 0.003681462744680175, 0.029712065916100983, 0.0535913223575335, 0.00885423645740957, 0.0050696432481345255, 0.05179021900403313, 0.04511677885602694, 0.0360403090598993, 0.009649539533711504, 0.039277831820072606, 0.050114980185753666, 0.05259987614408601, 0.03796550321567338, 0.0670865728170611, 0.07050234460621141, 0.022080244089011103, 0.06469106854638085, 0.016462442217743956, 0.013481340756698046, 0.025596001723897643, 0.04926232300931588, 0.0502897485421272, 0.01101849493352347, 0.01869541243650019, 0.07808545371517539, 0.01767398902302375, 0.05822668026667088, 0.09120406422880478, 0.024106693163048476, 0.043625143662211485, 0.0468263011862291, 0.030791328608756885, 0.031717432430014014, 0.05500141778611578, 0.1506458703079261, 0.05114918152685277, 0.060071651969337836, 0.07127390359528363, 0.0783764869265724, 0.07234911230625585, 0.060571673966478556, 0.005615227546513779, 0.04807123164937366, 0.038736679998692125, 0.025863757473416626, 0.039503455845988356, 0.04064868247951381, 0.05133766106155235, 0.02735708847467322, 0.060262320839683525, 0.06320084343315102, 0.028375302099448163, 0.03010194021044299, 0.0314408302801894, 0.05417525528173428, 0.02469045724865282, 0.052479763253359124, 0.022589899162994698, 0.026651313455658965, 0.02960268819151679, 0.0561727012245683, 0.0335507783893263, 0.02712451052502729, 0.031191657908493653, 0.03226985747460276, 0.036946842446923256, 0.013744536008744035, 0.0799866950546857, 0.025383315187355038, 0.035099347442155704, 0.03363311225257348, 0.012206436804262921, 0.03304429599666037, 0.035776531221927144, 0.03544428283930756, 0.026326918850827496, 0.08124125117319636, 0.023760390358802397, 0.05850680390722118, 0.01593578082975, 0.005134936009199009, 0.0864162395009771, 0.02434740319586126, 0.013136909092281712, 0.010755984312709188, 0.030431689410761464, 0.022560669676749967, 0.0453208657563664, 0.0722791648877319, 0.07177489038440399, 0.03954087493184488, 0.04736490001960192, 0.009559138525219169, 0.04296792365494184, 0.06532850660732947, 0.03205147681001108, 0.06674747070064768, 0.0047355881997646065, 0.03998563661298249, 0.04539902503893245, 0.04793591586349066, 0.023801824463589583, 0.019003550296474714, 0.034535326340119354, 0.0886710177292116, 0.023278923908947036, 0.04817549226572737, 0.029276423374540173, 0.052364225703058764, 0.03279123477113899, 0.06392948402208276, 0.008521564122929703, 0.016446927620563656, 0.04162280325544998, 0.0648589720367454, 0.02556644754804438, 0.06358151324093342, 0.028625841878238134, 0.054868202278157696, 0.03882224962580949, 0.03541162092005834, 0.027112111092719715, 0.038418536132667214, 0.004686304955612286, 0.08246678931755014, 0.024216918791353237, 0.032942952020675875, 0.050827223021769896, 0.09892000292893499, 0.023213809727167245, 0.05095352171338163, 0.04784462056704797, 0.04745010599435773, 0.017001055894070305, 0.040207308702520095, 0.06607121089473367, 0.018891276340582408, 0.038712259629392065, 0.01587579488841584, 0.05442094327008817, 0.0032913024915615097, 0.04911169300612528, 0.06130707552074455, 0.07858562414185144, 0.02449873081786791, 0.04589652002323419, 0.026875800140260253, 0.024585461906099226, 0.02736766036832705, 0.016877430789463688, 0.052541101758833975, 0.026623427256708965, 0.032053328468464315, 0.020902043834212236, 0.07538715319242328, 0.023364402622974012, 0.03100850142800482, 0.01783563435310498, 0.032075466733658686, 0.0564237215439789, 0.006730430131938192, 0.040221873350674286, 0.014707031969010131, 0.032050274530774914, 0.0065408684531576, 0.022764921704947483, 0.03387332319107372, 0.0789738267485518, 0.02762705582426861, 0.08400175109272823, 0.045453483835444786, 0.06333232231554575, 0.03959391251555644, 0.02671682283107657, 0.041223520383937284, 0.04341110085078981, 0.012230032461957308, 0.04711304107331671, 0.024767295508354437, 0.016830011263664346, 0.05468043149448931, 0.04834780782402959, 0.06055869009287562, 0.013836372145306086, 0.022728237345290836, 0.051235630598966964, 0.014384730220626807, 0.038995800859993324, 0.05767965434642974, 0.11246694397414103, 0.036321126608527265, 0.01990882388781756, 0.03251010180974845, 0.019348361383890733, 0.010292878596374067, 0.06901932574692182, 0.07686673590797, 0.09432272461708635, 0.0579788437607931, 0.04277946267393418, 0.023573597354697995, 0.0766685008420609, 0.058843664737651125, 0.10346186507376842, 0.03668717610707972, 0.04379109159344807, 0.04838467400986701, 0.018422075736452825, 0.020354652406240348, 0.05320057418430224, 0.051749137419392355, 0.07182941597420722, 0.0649643421638757, 0.13060506287729368, 0.15177164896158502, 0.1686403836356476, 0.11623859783867374, 0.12637673586141318, 0.14149222086416557, 0.1718992431415245, 0.09849686743109487, 0.12606205040356144, 0.18635279178852215, 0.1265674232854508, 0.18048526835627854, 0.1647715232684277, 0.16852110566105694, 0.1900312615907751, 0.0907855448895134, 0.09030786153743975, 0.1885215105721727, 0.13888798013795167, 0.12394970515742898, 0.12850628409069031, 0.11950418120250106, 0.12155477234045975, 0.15470515092602, 0.1086676970589906, 0.13144278433173895, 0.15553074568742886, 0.1964745283476077, 0.16534536669496447, 0.08275765183498152, 0.08377493591979146, 0.1641229455708526, 0.13570434472057968, 0.16683794441632926, 0.11758575914427638, 0.15988801344064996, 0.14962014800403267, 0.09377994749229401, 0.08557908207876608, 0.16198081051697955, 0.0986409850884229, 0.1317806841689162, 0.11530346950166859, 0.14682572451420128, 0.19023196800844744, 0.16410954238381237, 0.11147897472255863, 0.12423477150150575, 0.09982786476030014, 0.10477629766683094, 0.12993410200579092, 0.15610599919455126, 0.23659963306272402, 0.16968973592156544, 0.17528987838886678, 0.14019171096151695, 0.20818374847294763, 0.13217762927524745, 0.1639299129601568, 0.2496627828804776, 0.07053468740195967, 0.11258402519160882, 0.21307555551175028, 0.19686693151015788, 0.0694009083963465, 0.0821383815491572, 0.11927618601475842, 0.17808347067330033, 0.07987556586158462, 0.106001509266207, 0.12110991418012418, 0.10790418295073323, 0.26342798955738544, 0.1550977915758267, 0.11519004707224667, 0.16852959583047777, 0.10432406998006627, 0.22246422828175128, 0.14598334237234667, 0.1747931441059336, 0.08311927813338116, 0.09217857834300958, 0.08214035566197708, 0.17367870546877384, 0.1049280223378446, 0.09189734890242107, 0.07971166996867396, 0.1791998537373729, 0.14809678599704057, 0.16151524643646553, 0.14287697937106714, 0.1433238561730832, 0.16402863344410434, 0.11536394711583853, 0.09693935920950025, 0.16295750654535368, 0.09323590871645138, 0.19062080886214972, 0.1588245900347829, 0.1250993215944618, 0.12479502620408311, 0.1903235787176527, 0.14852962136501446, 0.09253372569219209, 0.08846345386700705, 0.1448545654420741, 0.13794469559798017, 0.1435163989663124, 0.06248111603781581, 0.08200294701964594, 0.11966573933023028, 0.1303077139891684, 0.11202348847291432, 0.12326351541560143, 0.11536244055605493, 0.14581395458662882, 0.12072243887814693, 0.15622011182131246, 0.12861229246482253, 0.08062262655585073, 0.17018459999235347, 0.10520441297558136, 0.16475071344757453, 0.1913936814526096, 0.14246078295400366, 0.12674047728069127, 0.10035578408860601, 0.1617150622769259, 0.19216420885641128, 0.12506441096775234, 0.12406255613313988, 0.18150143179809675, 0.25116768025327474, 0.09058316121809185, 0.17194714135257527, 0.10323700174922124, 0.07648169485037215, 0.09157099688309245, 0.13587742840172723, 0.13578103826148435, 0.12666332360822707, 0.15140110946958885, 0.13673943292815238, 0.09323947844677605, 0.20786682172911242, 0.18145196023397148, 0.12991045718081295, 0.12464956525946036, 0.11999686335911974, 0.06321051361737773, 0.13187653996283188, 0.2887747372733429, 0.14123629865935072, 0.16327222168911248, 0.10783552686916664, 0.2358613593969494, 0.13680882373591885, 0.08909665426472202, 0.266875087399967, 0.21089129615575075, 0.18887915153754875, 0.16354509454686195, 0.11835701385280117, 0.18070136691676453, 0.18642666516825557, 0.19633785443147644, 0.24276339216157794, 0.07746530769509263, 0.21292283636284992, 0.1334751260583289, 0.12184248073026538, 0.1632479831459932, 0.1505398322478868, 0.23949173802975565, 0.2888980525312945, 0.16390318080084398]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.015135113881115103, 0.021735987756983377, 0.02257262010971317, 0.03696347397635691, 0.042689031979534775, 0.03094118492299458, 0.02123151843989035, 0.023763314420648385, 0.02798900124616921, 0.066753021965269, 0.04429492822964676, 0.007175558712333441, 0.020822849255637266, 0.047504783724434674, 0.038065874978201464, 0.04542624330497347, 0.024500422914570663, 0.0601375027326867, 0.03709016971697565, 0.028171862722956575, 0.026715885869634803, 0.0367679848568514, 0.03586178914702032, 0.05202142769121565, 0.025635261335992254, 0.019306487556605134, 0.03413992119021714, 0.037379306741058826, 0.03183286236890126, 0.04297385712561663, 0.04339669947512448, 0.04041709158627782, 0.04191399231785908, 0.018409841432003304, 0.07591798916109838, 0.09946104342816398, 0.04016757411591243, 0.03493962612992618, 0.015892717710812576, 0.037657166831195354, 0.04487940292165149, 0.06764592209947295, 0.03429485936067067, 0.04000833891041111, 0.013036796153755859, 0.02678351964277681, 0.05456155427964404, 0.048958947882056236, 0.016636731888866052, 0.07138040178688243, 0.015723736250947695, 0.04324619563703891, 0.023553182727482636, 0.053715027243015356, 0.03375712884007953, 0.010723869727371493, 0.006040312109689694, 0.019384364823054057, 0.01993035173654789, 0.03988092328654602, 0.12145589600550011, 0.027468837361084297, 0.01784568674338516, 0.03172328797518276, 0.073013831715798, 0.08148095002979971, 0.04928738904709462, 0.01907503024995094, 0.04976295727828983, 0.040246716744150035, 0.10970799514325336, 0.036472146239248104, 0.05944848540821113, 0.03264995953941252, 0.015588884307362605, 0.008032204932533205, 0.04549474353552796, 0.0804798373428639, 0.037126186143723316, 0.01300600815739017, 0.018037381632893812, 0.0514647761156084, 0.036622995176003315, 0.013890729824197479, 0.02720858101383783, 0.016978975145320874, 0.025949653645511717, 0.03588054321880918, 0.01512490749519202, 0.04073348769452423, 0.021950935988570563, 0.0255824222767842, 0.0352384259167593, 0.01866807357146172, 0.0768592105305288, 0.04859346241573803, 0.008779743384366157, 0.08092826523352414, 0.011366071448719595, 0.011188956978003262, 0.018516270974942017, 0.0828799355076626, 0.039594836489413865, 0.041054666944546625, 0.005461541286422289, 0.030577534416806884, 0.0392512963298941, 0.027477590992930345, 0.05135045568749774, 0.07906365630333312, 0.020411554723978043, 0.07260576923727058, 0.04044971639814321, 0.04857651918428019, 0.06083298045268748, 0.02988711257785326, 0.009696879278635606, 0.06883998576086015, 0.023222210838866886, 0.027989763802906964, 0.07271353650139645, 0.02501122831745306, 0.01812340211472474, 0.020336449379101396, 0.010547061392571777, 0.03303018405858893, 0.0497698258550372, 0.03599552044761367, 0.03488305963401217, 0.02052488809567876, 0.04368080844869837, 0.03182863954862114, 0.06546696167788468, 0.054522632344742306, 0.06913064789841883, 0.02667245909833582, 0.061412913200911134, 0.011423361538618337, 0.03315940310130827, 0.07757234765449539, 0.07061308788252063, 0.036138053619652055, 0.08115798962535337, 0.076303609093884, 0.01247417585545918, 0.07973721469170414, 0.035699589061550796, 0.03995378363470081, 0.050497579577495344, 0.04890965072263498, 0.052846094768028706, 0.029282356845214963, 0.04968905421264935, 0.061708150678896345, 0.04427262298122514, 0.05094451946206391, 0.06097618897911161, 0.01875572677818127, 0.05253556162642781, 0.020713991034426726, 0.014675382153654937, 0.016313346604874823, 0.013801344630337553, 0.022548379711224698, 0.0318976555718109, 0.041094705811701715, 0.0151011420712166, 0.0496384286088869, 0.0801836907339748, 0.06155619223136455, 0.0165419967379421, 0.054279619798762724, 0.05162808571185451, 0.024251157774415333, 0.06719697470543906, 0.01340777351288125, 0.0297702465832117, 0.02584378071333049, 0.04734346679470036, 0.04168338105955627, 0.06180688971653581, 0.04242870141752064, 0.005650274542858824, 0.027086597910965793, 0.049025633561541326, 0.020496669785643462, 0.00527309653989505, 0.007235661078084377, 0.010839417482202407, 0.0371807006013114, 0.05212077157921158, 0.045479236359824426, 0.00033583394156266877, 0.04592392382619437, 0.06699649835354649, 0.014427047481149202, 0.05566096442635171, 0.049297307850793004, 0.016702855391486082, 0.034805635077646, 0.030961571719672065, 0.058361914416309446, 0.0581993209925713, 0.016333928215317428, 0.012497956122388132, 0.08219993527745828, 0.07937570713693276, 0.049153264408232644, 0.04909573312033899, 0.04212747109704651, 0.07313609312404878, 0.04461050055397209, 0.04396012314828113, 0.02239724504761398, 0.055753120614099316, 0.018993787343788426, 0.03939066795282997, 0.035851525244652294, 0.014385117992787855, 0.040509258906240575, 0.017637959608691745, 0.03018635765329236, 0.02945536260085646, 0.004042543796458631, 0.020977620442863554, 0.07946255325805396, 0.02963748007459799, 0.0431039110844722, 0.0391999953717459, 0.02935508731752634, 0.008196932958526304, 0.056488726258976385, 0.04208154699881561, 0.04216521301714238, 0.052890779479639605, 0.1067994070763234, 0.09058677547727711, 0.061394574731821194, 0.031386553309857845, 0.02600428313598968, 0.04520753238466568, 0.061076950369169936, 0.017139616720669437, 0.05474633049743716, 0.07075931323925033, 0.012587074143084465, 0.03721691740793176, 0.023435190523741767, 0.046462544923997484, 0.09194949961965904, 0.050244666781509295, 0.022948226614971645, 0.021618116152239963, 0.054741050116717815, 0.025282314454670995, 0.019757553782255854, 0.015941771816869732, 0.0416883534489898, 0.046255248234956525, 0.005471023614518344, 0.026397966503282078, 0.013156135355529841, 0.04315467769629322, 0.022489887342089787, 0.041339874296681955, 0.008519022267137188, 0.127754622080829, 0.04749387415358797, 0.030000110127730295, 0.012440606660675257, 0.023703603073954582, 0.01739286719384836, 0.025224566088581923, 0.018708143979893066, 0.032039465149864554, 0.03824900362815242, 0.056498637641198, 0.05967221695755143, 0.009794550551305292, 0.02126562198100146, 0.01797614331735531, 0.04400894162245095, 0.028553040901897475, 0.020184464956400916, 0.05829329544212669, 0.04797878231329378, 0.04649820511986036, 0.03926410208805464, 0.05519062833627686, 0.06433163158362731, 0.014314010040834546, 0.009927078644977883, 0.017259820524486713, 0.07435819512465969, 0.018215537893411238, 0.06415583906346001, 0.08195323796826415, 0.07493429468013346, 0.010167939890379785, 0.057252989936387166, 0.029591160782729276, 0.02443249413772719, 0.07082270007231273, 0.026843453633773606, 0.04206969490041956, 0.05675017004250549, 0.035386172676226124, 0.035010159845114686, 0.02687726402655244, 0.046892920072423294, 0.042730540299089625, 0.01884695899207145, 0.03700162407767493, 0.01860395015683025, 0.022725817943864968, 0.020835951872868463, 0.059901373606408015, 0.015841314707358833, 0.0319267811573809, 0.037545243540080264, 0.07382604555459693, 0.044395222066668794, 0.08527696860255674, 0.03249232737289276, 0.03166186041198671, 0.07343811754253693, 0.025061978230951354, 0.033273957305937074, 0.021081819832033943, 0.041028009000001475, 0.03244824009016156, 0.02851226174243493, 0.02672499387699645, 0.02316336780495476, 0.013453687406581594, 0.03120695357210934, 0.02629802518640645, 0.06041745939000975, 0.032947712898021564, 0.014888094665366225, 0.03931198545615189, 0.027178529599041212, 0.017826782386691775, 0.06019449596351478, 0.06888510833960027, 0.025011911093315575, 0.009570506372256204, 0.04084478387085255, 0.043468350122566335, 0.06212780921487138, 0.030399571114685386, 0.009355842012155335, 0.13008924055611715, 0.14552551147062331, 0.12895639665657654, 0.18795777519699186, 0.148774812114425, 0.09048567269928753, 0.12960959051270038, 0.11237974904361181, 0.08247317920904607, 0.17464993929024786, 0.13680156553164124, 0.12129390743211843, 0.09703602394438349, 0.1155023873434402, 0.138137505564373, 0.15907700930256397, 0.11630605164100416, 0.16605365759460256, 0.13695008412469178, 0.08669043338159099, 0.09566239023115486, 0.10280223679728806, 0.19600645580794662, 0.09888374159345403, 0.09429422614630312, 0.14489714987576008, 0.1591933929012157, 0.08566639575292356, 0.10422036226373166, 0.15692835819208995, 0.15447064710315317, 0.14370714576216415, 0.12513503374066204, 0.0677395069214981, 0.149776013859082, 0.2517306141089648, 0.0669117302459199, 0.216924051346723, 0.09384407647303306, 0.1080714853014797, 0.21821699134306982, 0.10384023422375321, 0.13169539655791596, 0.07985693795490079, 0.12436583478120156, 0.09357938208268024, 0.12794168782420456, 0.14529332314850762, 0.15789479773957282, 0.1673895085696131, 0.12584743613842875, 0.1962790169636719, 0.06827956036431715, 0.17920766113093123, 0.11377296061255038, 0.13557167840190232, 0.12088874675100669, 0.15111009852262214, 0.13691049796761945, 0.1434058931772597, 0.2242210551048629, 0.12278339781914838, 0.1058960500813555, 0.07850471520214342, 0.18947530392324552, 0.23591314646182582, 0.13472476915922016, 0.12892188678961247, 0.14721864718012512, 0.10923961832304485, 0.1525597058935091, 0.10558502341154963, 0.1833458914188668, 0.1843712426489219, 0.15662756573874503, 0.11483994632726535, 0.0792613867088221, 0.175167839624919, 0.09260387349058874, 0.10305996984243393, 0.13010650291107595, 0.10813363274792209, 0.1652900321641937, 0.11607660926529206, 0.12455550546292216, 0.15864884946495295, 0.10939806685200892, 0.11295748874545097, 0.12269395418115892, 0.07350819112616591, 0.27478777687065303, 0.10964578090352006, 0.1474960322957486, 0.10235325229587033, 0.13719384995056316, 0.12092213597497903, 0.09347595638246275, 0.15318020072299987, 0.160241364792455, 0.19303163106087595, 0.1480118843028322, 0.17784276249585673, 0.11699411159497686, 0.12095516896806657, 0.10552709136391059, 0.14968628820497543, 0.13754844811046496, 0.0714396771218162, 0.13381384225795045, 0.12681121879722923, 0.12074133395799436, 0.17621921055251732, 0.1236316651920788, 0.19513422448653728, 0.1258774782763794, 0.17130890919361264, 0.09657785907620564, 0.18975078914081678, 0.1447046219254844, 0.15304196829674765, 0.12123877328122035, 0.09584129977156408, 0.06758541479939595, 0.18100542481988668, 0.09849511596257798, 0.1195895801356528, 0.15395230147987604, 0.1455193813308142, 0.15706604142906144, 0.14547495637089014, 0.1729940000222996, 0.17390201770467684, 0.17732952284859493, 0.2414261904777959, 0.13412869098829105, 0.1482191661489196, 0.10006073585827835, 0.16914664709474891, 0.11285070853773504, 0.09212601944454946, 0.14391122153028846, 0.07198837658506818, 0.16731223615352064, 0.23494134860811755, 0.12000283764791675, 0.11233812940190546, 0.208784235001076, 0.11200641165487468, 0.11493257377878763, 0.20287730352720246, 0.2469648831174709, 0.12848476180806756, 0.11651422406430356, 0.14466453110799193, 0.25928894290700555, 0.09929368170560338, 0.17109882202930748, 0.1263165328418836, 0.11029783927369863, 0.10338171312469058, 0.12669202988035977, 0.13279867329401895, 0.13222223235061392, 0.159946390776895, 0.16278960305498913, 0.12347172494628467, 0.11309212175547145, 0.16632270097034052, 0.31456724856980145, 0.12912305333884433, 0.08866014526574872, 0.10012677215854637, 0.18448930350132287, 0.1553705456899479, 0.15717074362328276, 0.15568615141091868], [0.020661875569203403, 0.0116326935676625, 0.010102456490130862, 0.05655051747453399, 0.0515992718283087, 0.007467403183909482, 0.04361745130154304, 0.03458370323642157, 0.029919755943410564, 0.03110823865426937, 0.06725549304974265, 0.021695844989153557, 0.01404674410878215, 0.029992297168064397, 0.011388062212063232, 0.048424163687741384, 0.04125172199564986, 0.04759052404551767, 0.0188872724538669, 0.06631652780924924, 0.08055887607042678, 0.03584509824577253, 0.0433159129897831, 0.025729684784892015, 0.07840779071557336, 0.034367908956483006, 0.017644993313297164, 0.038790626713307574, 0.051141106960130855, 0.11417651825468056, 0.026493594086787198, 0.06433021408156492, 0.05755833917646669, 0.029794978654535953, 0.05488649992912542, 0.09019121818710119, 0.04498577123740688, 0.028047107698512264, 0.01508798008217127, 0.05958041700068861, 0.05036643837229349, 0.07108423291356303, 0.02777536847133888, 0.015886012406554073, 0.04163894125667866, 0.060767493341700174, 0.03804855325142853, 0.0553844513342483, 0.030792740544711705, 0.030389676430786494, 0.06001916728564538, 0.05999174863973167, 0.016586703713983297, 0.03860608056129422, 0.034283845889149234, 0.0901772287033964, 0.05157550454896409, 0.17763648997060955, 0.08279281479190104, 0.06608217241591774, 0.02882637760194484, 0.0408851418615086, 0.02694758994039148, 0.0302732612908585, 0.06911391988978721, 0.041510494047543034, 0.032667017803760245, 0.01755997844156809, 0.05367210884287488, 0.0441812497592764, 0.033868940809043124, 0.10357243023463525, 0.036993434478063136, 0.0562942056421889, 0.03819353551079985, 0.023647589478059672, 0.06422318154363893, 0.017699791642371565, 0.06705713181872852, 0.06083808642870281, 0.07403104158584028, 0.045926502789370716, 0.031614162580808625, 0.02946744476503227, 0.023541558839497156, 0.07508765207603574, 0.008710839611012489, 0.03531527159793768, 0.023118649696698412, 0.04883768466243055, 0.029402467880572658, 0.03411481433431618, 0.006830474421803956, 0.03849316650303081, 0.032214311431744136, 0.04080523482116405, 0.035926419077441096, 0.05471265554660931, 0.027831901570607442, 0.03266166691901162, 0.03786186971410643, 0.02848757605534047, 0.04723624500911683, 0.019399404445721302, 0.028855176642537117, 0.04942425963236019, 0.012338178221398266, 0.029131383598723914, 0.037796427131979726, 0.03176541598804761, 0.020351997372927144, 0.005940180617471924, 0.029191484572947957, 0.0587267245282419, 0.019298624501971062, 0.03033482986211311, 0.060429040604503825, 0.041754745980142616, 0.02710557462705765, 0.05427152667834889, 0.0368491201516008, 0.02363691368373111, 0.02164102996175643, 0.02303884655702859, 0.05456863436847925, 0.05064064338512253, 0.05060578841948882, 0.01392335185300908, 0.05944498989265412, 0.09066312763025053, 0.04664361411414575, 0.009661424101068405, 0.057136290924972855, 0.019532363912730943, 0.03762129141250625, 0.018137350780307315, 0.043959221438854, 0.016777012642705813, 0.017817919288063422, 0.06543985102325678, 0.05944357610133011, 0.033574794288142584, 0.08037083069211803, 0.06977565586566925, 0.05799157530418597, 0.06986524051171727, 0.015350294033851242, 0.04097995122720022, 0.03777628153329715, 0.023720444260106888, 0.07891838089562953, 0.034558485058369115, 0.08056117672822438, 0.05625437457638327, 0.050976502316189, 0.015094433056219714, 0.0536432430089917, 0.027738791723095346, 0.02056110490229912, 0.025105527456616983, 0.05795810815470759, 0.06307070783805102, 0.026452469828655012, 0.048255736983264796, 0.013477082684403285, 0.10895434417761862, 0.05101536116853822, 0.0451784476172179, 0.03847229359962512, 0.028589474786713254, 0.021436052484204993, 0.06505888435640372, 0.022559396893484518, 0.04020734580990393, 0.04645838518626988, 0.04934495002089534, 0.01574563888425473, 0.07621816563187167, 0.03933223124477081, 0.04740182186651509, 0.05140198671142571, 0.015974964371707756, 0.04806195851415396, 0.03486165980575606, 0.04886687333055306, 0.03957089109462686, 0.029481838719220832, 0.043734001883422025, 0.025080476261791773, 0.008408958055952098, 0.02042418607743457, 0.04332979857281316, 0.05436298524728045, 0.033255607704631984, 0.05180345891858451, 0.060277835436863825, 0.07574276809464209, 0.05771289885160513, 0.014000679002492689, 0.06339995423331857, 0.05581078919931315, 0.04636693403881509, 0.03880341762851458, 0.04345576700870879, 0.014905096340953605, 0.024809733367874287, 0.047403799690073356, 0.06813968779169954, 0.048179236400756054, 0.07926472637336701, 0.04593147888954263, 0.025607351017242763, 0.0042365806257294025, 0.028256178120500408, 0.023559609726362396, 0.06523765288875438, 0.029243308745208196, 0.019811402162304148, 0.014802402583882213, 0.02741057876846753, 0.04080477840034291, 0.06856735781184398, 0.09708113910164684, 0.11183872338733636, 0.050801526158466004, 0.042994563045795076, 0.002708929237087432, 0.04162919314694591, 0.015672299850848503, 0.050023551302729174, 0.0567950514232507, 0.03139408981951419, 0.0578900049731601, 0.09492283264989965, 0.004807518080269801, 0.07166581694036722, 0.015915126859908924, 0.052698630024679005, 0.08536543260561302, 0.028412348256097175, 0.012531803622550797, 0.024299280485138297, 0.05377027642680332, 0.026664204560802318, 0.004913785742246546, 0.07618174844537862, 0.005083829864815925, 0.026694820007833187, 0.03586960767279379, 0.1146969418914523, 0.014023038984305458, 0.045549525166279636, 0.0009735997650750505, 0.06523023883346468, 0.03461683270870708, 0.06383126077707857, 0.03360530026839115, 0.04301653061702382, 0.03231208196666557, 0.03227812128898222, 0.04343457127106376, 0.07831905211787671, 0.023286920550162904, 0.07175746475695632, 0.015062609763845103, 0.08621222310466692, 0.036865180227323435, 0.026295023199054413, 0.05035386639065109, 0.06887193521833979, 0.05275931172946002, 0.029152525530662388, 0.03936106739274692, 0.07177005158155225, 0.014369503205671208, 0.023265106974577066, 0.013821701741107972, 0.01688258686044719, 0.0364395474025514, 0.057444345293333754, 0.026768643292598426, 0.057758151306188665, 0.03858015734294895, 0.018871397915063426, 0.01935729869728675, 0.02198668895289302, 0.013153469190001488, 0.03966446849517524, 0.026769075593620073, 0.023942810257722158, 0.052696106722578406, 0.0333647590741748, 0.04551950529275928, 0.027048169504269026, 0.02516208653105423, 0.03338214388350025, 0.047416720481123775, 0.04493950946198311, 0.04138641437748447, 0.01962771319085732, 0.04361529536254238, 0.02126793006027583, 0.046170706482371315, 0.03528437970089726, 0.055145179212559015, 0.03943377188988961, 0.04788026591995731, 0.032641346915625036, 0.10292892140569165, 0.04158277923124842, 0.02378946028329665, 0.06926628280780278, 0.054727565293433145, 0.03019310192030389, 0.03997252286353614, 0.025499552211840637, 0.07095970795489848, 0.0996606885746587, 0.033918976405402645, 0.034876235586125404, 0.039266573439817876, 0.012534785200841725, 0.0357026652636705, 0.03893548280757386, 0.01454754072256037, 0.015741430906928144, 0.028611156631086487, 0.03612132561102044, 0.06505935933091678, 0.055525945499539375, 0.025617095416237134, 0.030922121004550718, 0.049008749701897614, 0.05229750291618984, 0.02765082124824403, 0.037228227738523856, 0.022013480484019965, 0.03580567165045068, 0.01842356188717531, 0.08912123419577256, 0.020830534194828942, 0.10299742163624614, 0.09235709454515018, 0.047196042869472876, 0.021053558848507237, 0.02498257399565773, 0.028283912179176696, 0.07376402427325957, 0.051803303067572415, 0.04142696903727483, 0.019915291704819538, 0.014166888540785294, 0.10813285349286161, 0.14519400894641876, 0.10524065204663202, 0.10387634712969884, 0.18246387859107926, 0.14683611458167434, 0.21306081645889208, 0.14363287162268534, 0.1684439371456392, 0.1226958392362576, 0.17347985442029312, 0.14897560758981854, 0.06098143967392389, 0.08671213377965614, 0.10008132303482853, 0.2785575605230406, 0.1363175516598858, 0.14345958014018834, 0.20475342316785827, 0.17048528854502365, 0.10713506562751718, 0.1687018186203204, 0.14443062100326642, 0.18631846003700048, 0.25702776736579835, 0.12335238759987988, 0.17672836838755757, 0.114862774789799, 0.1474154499010183, 0.14014479238539934, 0.12452892173314467, 0.17617490433622152, 0.2129200755734928, 0.17354461422655731, 0.152880328532774, 0.1569755290984176, 0.11822557949926704, 0.09616751078283414, 0.11886782667716034, 0.11376432943507098, 0.12109976902138442, 0.13191977748647332, 0.08036309751332738, 0.12300726666580886, 0.09588046290446073, 0.17638641642406583, 0.15918111777864397, 0.17930112720932811, 0.12195309784146957, 0.13014079013373703, 0.11806272261310369, 0.0984463568602223, 0.12209280714159831, 0.11346385610522702, 0.12909979443065822, 0.1881077335565351, 0.24162939051166177, 0.23885184345999733, 0.12798378244042397, 0.14156829100102186, 0.09348378604045138, 0.1903793288511224, 0.16314289503498003, 0.2551349939312786, 0.10444373387144879, 0.09456212661461905, 0.09359376490465365, 0.09640381802455522, 0.11001764883985743, 0.14733805874129757, 0.11618756034295075, 0.251656785258092, 0.08633905614260584, 0.2415139865479432, 0.15786874835612252, 0.12124972738092765, 0.10730435693403706, 0.15967001498211175, 0.15786379080964252, 0.08059948639129288, 0.27246535930316895, 0.1315608897130005, 0.13885030872188509, 0.18555268237832934, 0.13031151378527284, 0.17123531782999635, 0.09392833992023952, 0.15182448987616226, 0.08237814719905145, 0.1466351409908384, 0.09515907309832983, 0.12720477971015498, 0.12226228398503736, 0.16674078244250268, 0.13033257593633607, 0.11942138720769435, 0.1290847733616829, 0.21746540354797617, 0.09634731090045534, 0.13610931986477226, 0.08676969475345686, 0.0695557426661253, 0.0655396401998587, 0.22284955135546625, 0.1388762245187536, 0.21511212748009712, 0.12550389597890899, 0.07799858532962389, 0.1484980949317105, 0.1301323444931768, 0.09886280560749583, 0.13611919042887166, 0.17469013400841504, 0.1637490070424974, 0.11407498503103852, 0.10003303148550913, 0.15231454483000562, 0.10324888353352435, 0.053707175320596434, 0.1918820888386108, 0.16033284191507846, 0.17920028418302536, 0.16064659226685762, 0.12881908449344337, 0.12364985523163341, 0.2419380794162862, 0.08279110043076798, 0.11538074191776104, 0.1511236501391977, 0.1673638599459082, 0.1678070705384016, 0.15231019584462047, 0.13250697957118973, 0.12533355824416503, 0.11984183613094501, 0.11836303267045878, 0.13633904425660148, 0.12660865701036528, 0.09111576349823736, 0.1613451461889781, 0.17454664717661217, 0.16290558589389548, 0.18311195162823424, 0.15010291506769136, 0.08755660135648213, 0.12797976000001654, 0.1258240733295679, 0.13297359750140458, 0.14051322417799383, 0.10459262353833765, 0.11175478648510762, 0.11587808476178907, 0.20513427851255983, 0.10678091275622137, 0.30065031722187996, 0.134230068360921, 0.12617147265700623, 0.1158285909332335, 0.23978991812327877, 0.1737144769867882, 0.11501742352265865, 0.1971063928795047, 0.127657727280166, 0.12691074080066755, 0.16186945867957547, 0.15906446700682864, 0.1995348633499816, 0.08034164202399552, 0.1266857364680618, 0.20557695475872606, 0.16123241395689547, 0.145980789384339, 0.07812915879185311, 0.18562159821158275, 0.1804704699316062, 0.1877030701143667], [0.03961910471844021, 0.0366911651508417, 0.020379686902742833, 0.09805465873796493, 0.07274536721524782, 0.043298131131450646, 0.002305873936165881, 0.04188848099147435, 0.13326955115189776, 0.05701027424947824, 0.029143137362552807, 0.01113305006583687, 0.06105495311203413, 0.059262369613861665, 0.0664197605510708, 0.029241644479043316, 0.04195682537101675, 0.009490888769505545, 0.05863506186869927, 0.08423428080277517, 0.009829016817093361, 0.026115798245882615, 0.026112516097782645, 0.1103819691343233, 0.034741799245239235, 0.01633837182453135, 0.07797086611390114, 0.03011001848790329, 0.03013180052221287, 0.0020432851579244016, 0.056173807024606504, 0.019146057493344415, 0.09505428926786408, 0.019690294793690555, 0.021747090286226012, 0.02261848854686832, 0.01585015925229527, 0.02468640697770752, 0.017665650993876625, 0.07411535698338412, 0.0370933015801711, 0.028808386086893734, 0.07153204482165165, 0.04375422911834903, 0.010751611207524547, 0.05463417342980392, 0.03039594757865416, 0.03590490421629511, 0.020473331096582115, 0.05378548303269781, 0.037049859965918586, 0.053900920393061824, 0.04847167969273869, 0.03030144620424835, 0.02293961399118416, 0.029669151226698887, 0.02018455958022969, 0.07416604566969909, 0.011400290950405179, 0.03282310630311258, 0.014764501102035865, 0.04519240370427724, 0.03236804361222312, 0.05139451699506026, 0.061359723476925865, 0.07404945426969789, 0.009351215649076039, 0.07000023717409931, 0.06019798405759502, 0.003188380756000697, 0.06367158028297126, 0.049162630311911926, 0.061348695162450895, 0.07391516264760867, 0.03443887682806235, 0.07139144494431093, 0.029887624659750145, 0.02647050772793591, 0.07659368493477814, 0.023941901126818266, 0.09023491584230214, 0.09204097674228251, 0.08539658054360189, 0.04220681781589519, 0.03654527376056649, 0.046197961855796166, 0.052597712783608586, 0.03279591030150186, 0.019618258229456842, 0.10313984719687141, 0.012105444420740241, 0.05381777016737033, 0.07644239813089371, 0.03337265552545432, 0.049392981818527915, 0.0022908326900505926, 0.03525254156556912, 0.04341374289651867, 0.036289577910793014, 0.06301647910731845, 0.03228434048651252, 0.08223485332564451, 0.0026832186904357513, 0.05267356398690026, 0.059283335285726935, 0.048063769354484975, 0.04450687818462029, 0.021742702338087838, 0.018343755036767107, 0.025706757987791207, 0.03836478237644769, 0.035382580681471154, 0.057305181471747346, 0.04388639077660628, 0.05987279721011873, 0.038224390300456434, 0.07040415104711428, 0.025898230232996866, 0.002527491060391185, 0.0773663200379815, 0.04103451763512567, 0.024411027516180184, 0.02061343373497948, 0.06987152650253847, 0.026404128184367437, 0.022461012231360655, 0.014028048481122823, 0.04992281217710115, 0.01775223179720342, 0.0606432837957982, 0.021709949505748227, 0.07272252390976064, 0.02401607507636072, 0.03688971191877499, 0.02672578611964127, 0.014669955198769458, 0.035627199977170676, 0.0832828029524535, 0.04926846428134013, 0.10838585905730724, 0.010323943970433902, 0.0380652478634147, 0.05673612489772495, 0.029373041725193616, 0.03596857306547463, 0.0255155176637345, 0.03033780030818889, 0.03416453822865151, 0.04867269781243522, 0.06566910044057295, 0.03122250156593509, 0.018349007586948574, 0.03096576670941431, 0.020614838249457534, 0.019457958042039536, 0.044294490362517536, 0.02056787514447933, 0.004529672833086806, 0.03292284352937713, 0.07954106506076641, 0.021358707708714064, 0.06635370198637247, 0.05813311399833765, 0.03246741347538773, 0.022180693777045235, 0.03034015477169305, 0.039242256971192546, 0.06962748608202673, 0.04582823130476754, 0.018055920481856447, 0.012548346094263252, 0.012915361312479945, 0.01830778313888004, 0.035027993653784506, 0.03275809416663833, 0.015323252955568023, 0.020554254879243672, 0.022037902708689217, 0.045329188942559995, 0.073863034194801, 0.07952260784804821, 0.024363507800444495, 0.047841173291089945, 0.036508915945887566, 0.06783488774090074, 0.03672486236609984, 0.013860181170457508, 0.04416866293468047, 0.014721338720846688, 0.10197734707617201, 0.034667907311813906, 0.03485505469143391, 0.05797498830361292, 0.04278024935047142, 0.016213075032283086, 0.07195315425633453, 0.041735695049283095, 0.03468064998742193, 0.016659790417179465, 0.06925002235220745, 0.04984188839443959, 0.032278689031954855, 0.015587720990879461, 0.03846577754302416, 0.023051964017213322, 0.06776423528208397, 0.02836669133102987, 0.020459896368265618, 0.1080179245036561, 0.010077796778205084, 0.03911817730113398, 0.031303711075452156, 0.030054103226575535, 0.05274306982755661, 0.017696472386887763, 0.048315661697415635, 0.08982599989394657, 0.02245955020043766, 0.026305878964194562, 0.09095579356653616, 0.02572701676399447, 0.002501917115296237, 0.029336040097405203, 0.04459845178644173, 0.030527971939591225, 0.02192941370594781, 0.017066923355741892, 0.01795179345208453, 0.03199217921064701, 0.031078534193511587, 0.026511869473324623, 0.02530643054342363, 0.029731161375821102, 0.021787433433928527, 0.0511536455451278, 0.02893067718105158, 0.043694868436432444, 0.0762580857553985, 0.047323421385954134, 0.08700392398168333, 0.054722756176488474, 0.039859282260295004, 0.03727346163941547, 0.04454355141206179, 0.026744783244794235, 0.019196985522285104, 0.020707402618427295, 0.04146485938690603, 0.03398615190235432, 0.049126907033496536, 0.04011446602817159, 0.06226650919415988, 0.06277926644543186, 0.0628742019762285, 0.02784962962323334, 0.047706688710604794, 0.048624736518831924, 0.026736270810943097, 0.045600659141200595, 0.028418051660992205, 0.06183047516969964, 0.021866748611500952, 0.08364133449504152, 0.03253738315834198, 0.04677140081184916, 0.08369591945665888, 0.06116581513197161, 0.05013384186895564, 0.10360435742768459, 0.010396022280474426, 0.050034041560138576, 0.043154937447980046, 0.03648234334832523, 0.04797378394869156, 0.0326128039159812, 0.14306245691841468, 0.03166398295434192, 0.04571611134451814, 0.015154503416852094, 0.07054505520500243, 0.10323499795049429, 0.07708869001362473, 0.03849006803648081, 0.013750862817687448, 0.005764366760558914, 0.05393219078541733, 0.032457709894515574, 0.0743789084663149, 0.0586721692525316, 0.04524024254351389, 0.009728651548357448, 0.04755144997034222, 0.09593054302968085, 0.03498091180517804, 0.025541227514622733, 0.038788574674981646, 0.0694864928664174, 0.026940391107928008, 0.0403081405966077, 0.03569975604477804, 0.005135684186825529, 0.05063832417363301, 0.022906957638042513, 0.007873711874708533, 0.0880995491752401, 0.03608585837355349, 0.02227103541372344, 0.026507106740609743, 0.015014141954452498, 0.027917775478272233, 0.06348080380121246, 0.05804299500596244, 0.013975497931824066, 0.03873001922329422, 0.024484644854965154, 0.06458604722865857, 0.06692082155495882, 0.029261613817652687, 0.024629955514683388, 0.060879049269715324, 0.04660545659135096, 0.011963320357608609, 0.0929857901064679, 0.01189155282190768, 0.028184601687826216, 0.02629399717989145, 0.02761848587397253, 0.05723678885260597, 0.03033067383512389, 0.03890584885084536, 0.05346470825315919, 0.005098148676552228, 0.006679648213321343, 0.028874190466012806, 0.030284040985861793, 0.08713569972314872, 0.020776225683221128, 0.08582710783230141, 0.04665323605877347, 0.05258711120404769, 0.01734600984491408, 0.08626540540717542, 0.02046450139459921, 0.03835937583062332, 0.02302277905982919, 0.022790295734012034, 0.04045704139571171, 0.03565572442312259, 0.019609118680818938, 0.019276959355920553, 0.01209828733408358, 0.055715571652399376, 0.14962792571168393, 0.15175411943346262, 0.08316462335642427, 0.2717196790035814, 0.19111607369268313, 0.08785308193182573, 0.1708102156408131, 0.0492610131186666, 0.2606310724513605, 0.1631651446223259, 0.07434807223035023, 0.1394529771641828, 0.1736919305403717, 0.2854138769907877, 0.15312669187551364, 0.17096771422075108, 0.15034464740892872, 0.16763276973506436, 0.14260363153880462, 0.1044656198064331, 0.15068088483531028, 0.11330352252116427, 0.1317914601531811, 0.20226780732627958, 0.12896536180051044, 0.13993666449096054, 0.2200238240766339, 0.14157121506286785, 0.24663866468472406, 0.16507617488969117, 0.1427543320460245, 0.11608511427766643, 0.2522003639023751, 0.0789217502460815, 0.16533463523956016, 0.0933728794916533, 0.10563348565483466, 0.1327416763524525, 0.11971038693445735, 0.2396738313836977, 0.10741856603999622, 0.17308699112618342, 0.14982757827965543, 0.1502702248399146, 0.13460221089189872, 0.1100794920057524, 0.09149420686298981, 0.2527157706208527, 0.1425235834904015, 0.19564366433769464, 0.10696886165533215, 0.08367271249881014, 0.18056283763144165, 0.16498162527568638, 0.1426784400246106, 0.0938683001731988, 0.15560925006866455, 0.08265490891062655, 0.14351101097417995, 0.09159543580608442, 0.10193217254709452, 0.1626778207719326, 0.08804783632513136, 0.1802875305293128, 0.1536375714931637, 0.1679798573604785, 0.05537168268347159, 0.12617675674846396, 0.14731551229488105, 0.15384121681563556, 0.16458686208352447, 0.1373745035380125, 0.13618062541354448, 0.1316301617771387, 0.16414823796367273, 0.32800415880046785, 0.10458724296768196, 0.14988567359978333, 0.17333494266495109, 0.14166699664201587, 0.21308930008672178, 0.14146781904855743, 0.11847598012536764, 0.15186309639830142, 0.14168065215926617, 0.1249143635504879, 0.12075985796400346, 0.14234702655812725, 0.1855836299364455, 0.26096747315023094, 0.12426826462615281, 0.17325538443401456, 0.22259039338678122, 0.14888227509800345, 0.19273521727882326, 0.09595311174052767, 0.16299115552101284, 0.18251174711622298, 0.19574015837861225, 0.20452130906051025, 0.06471749642514624, 0.2040789445163682, 0.08259388210717589, 0.1661745979799889, 0.17947146494407207, 0.13561941334046423, 0.14946729526855052, 0.07874310787883587, 0.10746156607638113, 0.15369740343885496, 0.1765783506562002, 0.19295536796562374, 0.17612886149436235, 0.15797633008332923, 0.09983239928260446, 0.1840343521325849, 0.16741536499466747, 0.10495534821529873, 0.1144985509745311, 0.13931815861724317, 0.14180116209900007, 0.12118963568354957, 0.08974887590738945, 0.138410170620773, 0.12424702435964718, 0.10377028680522926, 0.11187760450411588, 0.12251561609446071, 0.10441027785418555, 0.13636580610182136, 0.09146173048065975, 0.13243948866147548, 0.165243974479381, 0.07881292171077803, 0.09978828602470458, 0.12108722672564909, 0.08933845339925028, 0.18414470949210227, 0.1395289137144573, 0.16083012538729236, 0.20185906207188964, 0.08310595658258535, 0.15472244296688586, 0.1768686788273044, 0.16641759197227657, 0.11624326594755985, 0.16087992349639535, 0.11783778507378884, 0.16515405586687848, 0.11730063342838548, 0.15152127802139148, 0.12472783215343952, 0.2443904321989976, 0.06710437693982385, 0.15609215071890503, 0.08096769553958438, 0.0998829172749538, 0.19369200890650973, 0.08538740017684177, 0.1435972040053457, 0.1329145225463435, 0.24026879633311182, 0.15326306893257424, 0.15411131404107437, 0.08741427227505483, 0.20234387746313587, 0.177387009607628, 0.1865930695203133, 0.14150226954370737, 0.12967329646926373, 0.11615243449341506, 0.2852704643737525, 0.15192080580163747, 0.19168904138496146, 0.13075647584628314, 0.17073865776183084], [0.019052426287089474, 0.05153464931936469, 0.05528035770112183, 0.01469220385843073, 0.016286566205963027, 0.05136773288541008, 0.01976042960450286, 0.018029765342362225, 0.031051727819431107, 0.09049518703250214, 0.0319943054637406, 0.008452509136986919, 0.020628400998248253, 0.04659584577893838, 0.04929748967697378, 0.035395456943660975, 0.08371553441975266, 0.011816529113275465, 0.0534350928501226, 0.01564130961924093, 0.05985809526464436, 0.04208644517348148, 0.08241150673711672, 0.03607778009609319, 0.03546658066625241, 0.03144163179968018, 0.07466747032594867, 0.046261615862022154, 0.04185004516330082, 0.1389270616346039, 0.026459739165147766, 0.030913129885448143, 0.0038780950035288697, 0.03816058786469512, 0.07205843532574363, 0.029517747534555383, 0.08959729224443436, 0.04919410479487851, 0.04977244192559738, 0.027141143909830134, 0.0647265357838478, 0.051843983892467804, 0.08138349119690247, 0.015378299904114101, 0.03290902473963797, 0.015689951833337545, 0.104435718676541, 0.02327168611373054, 0.04880583168414887, 0.01228302458912367, 0.02283544799865922, 0.014491669062408619, 0.029369045259954873, 0.06869688484584913, 0.040598884370410815, 0.018324357151868753, 0.05305814862367697, 0.0658654430299066, 0.03581532699172385, 0.026875078401644714, 0.033760999140213244, 0.07054269517539069, 0.02319516883289907, 0.02654919764609076, 0.05701772170141339, 0.02501167546142824, 0.045917574752820656, 0.027755523442465346, 0.010931050455837976, 0.053475513923331164, 0.08478452393319458, 0.028549437774927355, 0.05230979288171511, 0.03373084568011109, 0.052613524239859544, 0.0629636381927412, 0.04297108520404436, 0.01679730852629291, 0.024665530363563448, 0.026230417388433125, 0.032851730939000845, 0.05213827142142691, 0.017836777260527015, 0.0172752275102539, 0.033455423545092344, 0.02409012657153653, 0.053147618236835115, 0.07503095199353993, 0.009663979872129858, 0.08228764228988439, 0.029032310594629962, 0.011661987064144341, 0.02841257275576936, 0.04487614118261263, 0.053042604340589605, 0.06254155654460192, 0.018711376033024862, 0.05585581900959369, 0.020462512438825797, 0.04913175696856342, 0.040280811008415185, 0.024089824146358296, 0.02273277372296434, 0.0292521607116214, 0.07485048394300975, 0.055752556581865065, 0.028336072173260618, 0.02769269693089882, 0.05152141682629008, 0.06016416438797023, 0.02627243407914648, 0.009359274445159826, 0.031898086017463356, 0.06028246272762772, 0.024522043531760573, 0.09584509214619175, 0.00743172489819699, 0.0606408272869885, 0.012400939795043087, 0.12403786487993784, 0.0811986815824639, 0.036826551440753974, 0.033593659682082944, 0.0055207642071763985, 0.02828203454555478, 0.0206942332079052, 0.03296790302556474, 0.03335468070872594, 0.009442264181416249, 0.041280565565102734, 0.02754213557636831, 0.05422468231699895, 0.016386103052354883, 0.08278982393676415, 0.04449411695532035, 0.012437279056030093, 0.058369061298435554, 0.06536178450915031, 0.049881185113918036, 0.05055938563600648, 0.022748125047655776, 0.05862285725015681, 0.04111895177629776, 0.003067978891522216, 0.03902008764271159, 0.03497071469610091, 0.08279526387923397, 0.05920909454289358, 0.037812353621120565, 0.016751427101553418, 0.05815765311126597, 0.025603013164072763, 0.052310486789792776, 0.02160074804123724, 0.009700594655441819, 0.060482263725134544, 0.035817891111946665, 0.045051224951748736, 0.03255610012274701, 0.03207782305253204, 0.029945361893624067, 0.045211436081444845, 0.04726378610939719, 0.06213909357029479, 0.004140192804698017, 0.02414462433080189, 0.04080554281244986, 0.04232742423482705, 0.04932726835249923, 0.0030446163145825267, 0.014414764009416103, 0.051703176213777624, 0.02815651510900352, 0.04473281391256023, 0.05120621557580307, 0.02008033978199819, 0.02208432775660185, 0.05721944115066435, 0.05142193564097397, 0.010150653415621491, 0.05027064195019193, 0.0254631758434698, 0.04132125752221327, 0.023982617203728296, 0.040623512541060336, 0.0074296487400715705, 0.028812085693061817, 0.09382956006447785, 0.018216369098809082, 0.051926139640272595, 0.029770972032565624, 0.04231925689964555, 0.06177799419674557, 0.01743233275192324, 0.029355048354773317, 0.017199595240526833, 0.04105522355530411, 0.051027818117290735, 0.037307329548639245, 0.0033939807099159225, 0.04535655563813634, 0.02218032084783772, 0.028475410399551038, 0.060750579796149395, 0.019633401752798818, 0.0054028262729843846, 0.0173483513208339, 0.04072917581652291, 0.06178952717164066, 0.00495424206746975, 0.04456701070012059, 0.05133294471306726, 0.04890333133516833, 0.05660387047100812, 0.02275453349284362, 0.04012330129626207, 0.03503590494801756, 0.12811214430257678, 0.05724572802137118, 0.02465765988745261, 0.032549057141295634, 0.025230269493476953, 0.04387158864119556, 0.08112059280392714, 0.011427259669289924, 0.03809272217040416, 0.025697542369016446, 0.03133195350528695, 0.03191654323018156, 0.041737439096323214, 0.04218450514599681, 0.035347306402400136, 0.06492667074780911, 0.08618431093054824, 0.03338351314596366, 0.09449196397326887, 0.00896186178579228, 0.016052003011282068, 0.019243753813498188, 0.005400114187068539, 0.019510674646880943, 0.038576201695832424, 0.04896924889180809, 0.05671038350556046, 0.02579424050054513, 0.019811188794847112, 0.08070852272794582, 0.03547231375705451, 0.025457650554017164, 0.05389653430029284, 0.057065096698352136, 0.058472976816119626, 0.03932595638616476, 0.05600487937044818, 0.013133721568010515, 0.035680252403835766, 0.007993460185389267, 0.07983324860106222, 0.048013503692345694, 0.044742617683368735, 0.026953640299325343, 0.011200673634448322, 0.019381897182029206, 0.022126932599348947, 0.019924885818909388, 0.05476561520481482, 0.02294811714818934, 0.015385200022137724, 0.039408264274243265, 0.048285927550750785, 0.07440728819346987, 0.05418367865786422, 0.015161682767939055, 0.027632937344606034, 0.027951136871706694, 0.0742362676828634, 0.04059121427417267, 0.04273676691809669, 0.027957096317550167, 0.02242064681922784, 0.05906044607399963, 0.030471902682620566, 0.007800282855896512, 0.007352570210059639, 0.036880212428513914, 0.019517413347784895, 0.03101838126895018, 0.02597053211502498, 0.04752249878947623, 0.0372332854749402, 0.024723306560190395, 0.05077223730040714, 0.07931758955237456, 0.06768397201085463, 0.048296785171260126, 0.04682675760705024, 0.04098838944628369, 0.04038251863676123, 0.026582356804283336, 0.006516510238725459, 0.027357311118976213, 0.027396719160606153, 0.006255254311327008, 0.07535239841672592, 0.012493961512518581, 0.12345827723038383, 0.016170590788533445, 0.03811893111560494, 0.09832632931647822, 0.06130040732386988, 0.00968374326475896, 0.023039664774842095, 0.0134898717442411, 0.03313810346298851, 0.025110117639997043, 0.06677731988020241, 0.06447299587307498, 0.02425465514534153, 0.047861556377029046, 0.06723109865561128, 0.016841165743244346, 0.03413510836253408, 0.02868410974770086, 0.02277776085975347, 0.02735037760430714, 0.013345864481379976, 0.041217624020646326, 0.044538085494423285, 0.027142305370944086, 0.005858596323378151, 0.027736641350202262, 0.05937586254731286, 0.05006233222957235, 0.013603291390609229, 0.02251052275823895, 0.06895436556078494, 0.008007251144590555, 0.04624365959898569, 0.048264995275530964, 0.08983983352663927, 0.05285514154820703, 0.016747122645028867, 0.030317623168230057, 0.04366660745290574, 0.059907396134804, 0.02209131322160829, 0.018264521495439112, 0.06487062375526875, 0.010778299765661359, 0.03745640846318565, 0.10856999331736006, 0.06959510617889464, 0.06892793026054278, 0.15190398873528466, 0.06668695597909391, 0.09602938967873342, 0.10079100175062194, 0.13809692492941394, 0.11381577511201613, 0.10428770474391058, 0.20183590706437826, 0.15953219815855846, 0.13469509809510782, 0.1696959402761422, 0.18194489472080022, 0.2683824487030506, 0.10149744470254518, 0.15531424636719748, 0.1336612566956319, 0.1662416139151901, 0.15133418259210885, 0.11835752593469806, 0.09983668147469871, 0.14496508607408032, 0.172068927786313, 0.11512033714097925, 0.12067731629940681, 0.11385364690795541, 0.2038673878996633, 0.16926110110944137, 0.20962988259270787, 0.18836819770513102, 0.14928830409189686, 0.09867907952866517, 0.21126193954842165, 0.09104961587581784, 0.22016649454599246, 0.14138944825390354, 0.17778183217160404, 0.1410260927514173, 0.09557975208736025, 0.1293866493506357, 0.09607880187104456, 0.23512482235673815, 0.16558061266550794, 0.10941213055048138, 0.12909128941828385, 0.07157995787565596, 0.20606476842658594, 0.14596823224565014, 0.07196591919637285, 0.11902696540346369, 0.10154466755921021, 0.11442099654232152, 0.07767164701363072, 0.10392141033662483, 0.16639722744002938, 0.08617806204711087, 0.13988466962473467, 0.24767808703472838, 0.24188037001295015, 0.15046293090563267, 0.16412873432273045, 0.09443124145036563, 0.12093101948266849, 0.15623658749973401, 0.11035915551474318, 0.10819031798746437, 0.16401074768509716, 0.22904458455741405, 0.15057643497129902, 0.1333723682910204, 0.17388439911883324, 0.12553263193694875, 0.16135495738126338, 0.13100910291541368, 0.1342087984085083, 0.17039934784406796, 0.09918160256347619, 0.10589429119136184, 0.09182069246890023, 0.11168979661306366, 0.10529022751143202, 0.2079456378123723, 0.15996567177353427, 0.09736630934639834, 0.15900975588010624, 0.1452352575142868, 0.2396511216647923, 0.1329250610433519, 0.1768160902429372, 0.17703717603581026, 0.10896693842369132, 0.059643547792802565, 0.1676409927313216, 0.15981522359652445, 0.23110848240321502, 0.08900218628696166, 0.11881754617206752, 0.140847027359996, 0.12348322823527269, 0.1989875442814082, 0.14210162800736725, 0.1599231021828018, 0.14873173786327243, 0.14366450195666403, 0.19011209631571546, 0.21828716882737353, 0.07854185227188282, 0.18331147060962394, 0.08032984187593684, 0.1281534373993054, 0.14252021413994953, 0.08950767791247927, 0.11408104837755673, 0.17444835713831708, 0.10539088500081562, 0.16769598587416112, 0.15463179704966024, 0.14077601867029443, 0.1252693179412745, 0.20542439888231456, 0.14762672450160608, 0.18986512441188097, 0.14332767081214115, 0.21668453060556203, 0.09385459270561114, 0.0983209784317296, 0.09723887516884133, 0.08801184958429076, 0.0551939828437753, 0.21372135757701471, 0.10555040964391083, 0.12637118459679186, 0.21674194314982742, 0.14654307015007362, 0.15105534286703914, 0.11244307650486007, 0.09075540627236478, 0.2246833685785532, 0.10892452468397096, 0.17135259200586006, 0.14539198426064104, 0.08274199994048104, 0.09226821493939497, 0.14336851862026379, 0.11660482545266859, 0.1194356958149001, 0.22246538603212684, 0.25421918369829655, 0.12624751310795546, 0.08336659142514691, 0.19527581142028794, 0.14178406301653013, 0.1795169585966505, 0.12471629917854443, 0.05329473046003841, 0.2059648308204487, 0.13488243101164699, 0.17418243078282103, 0.16514673829078674, 0.11954661720665172, 0.08276912543806247, 0.17246602132217959, 0.11787455849116668, 0.13859465369023383, 0.11601581252762116, 0.10754504284705035, 0.07472209981642663, 0.2127343011670746, 0.17046058987034485, 0.11181552385096438, 0.08282808164949529, 0.20815758034586906, 0.11416451030527242, 0.18539469398092479, 0.20829878136282787, 0.13842905085766688], [0.06268030105275102, 0.04707556632638443, 0.05394224317569751, 0.018584511453809682, 0.05792654090328142, 0.021000020315113943, 0.021522019160329364, 0.02747564656601753, 0.08098019330645911, 0.018048244819510728, 0.008240108327299822, 0.01649596873903647, 0.10936995429801755, 0.008878162370820064, 0.03039583254576428, 0.029419956590572838, 0.14369745331350714, 0.06162465906527359, 0.03420470326091163, 0.031943126959959045, 0.041352865591761656, 0.018375023573753424, 0.06376535064191557, 0.013038186752964975, 0.037595472094835714, 0.015995835419744253, 0.021843111207999755, 0.07806868859915994, 0.03066179415327497, 0.06975222626351751, 0.014882183459121734, 0.0215371719605173, 0.03830704328720458, 0.03891549305990338, 0.07602581579703838, 0.008834247637423687, 0.0662806152831763, 0.016229680586548056, 0.020315710062277503, 0.014045732932572719, 0.04267393669579178, 0.023469720799766947, 0.03000814758706838, 0.047768817603355274, 0.05513642558071297, 0.03247992608521599, 0.03609696832427289, 0.06484824800281785, 0.023798117435944732, 0.043768003379227594, 0.03998086460342165, 0.02728957901126705, 0.05215899589529727, 0.021348044901969843, 0.06278398650465533, 0.01960411846084753, 0.07225971319712698, 0.012329276160016889, 0.01837510892073624, 0.0178689604945248, 0.1391597100882791, 0.029750939611403737, 0.04742327735584695, 0.04459983218112029, 0.08556245797080919, 0.03907750018697698, 0.018343935007578693, 0.05865826882654801, 0.054939270339673385, 0.12132272502640262, 0.041951875246013515, 0.05404958741564769, 0.030561825005861465, 0.01654291514569195, 0.05053040847997181, 0.04790524661075324, 0.05222516949288547, 0.1045112767315004, 0.041877545445458964, 0.0996710489562247, 0.04082552142790519, 0.032671285152900964, 0.0034893471502073226, 0.009449737608520081, 0.0585285117267631, 0.032530766911804676, 0.025617293940740637, 0.021512163439183496, 0.07472051904187538, 0.012888185719930334, 0.018263146666868124, 0.03592851193388924, 0.030902244434400927, 0.04567038020468317, 0.04895295132882893, 0.031383981768158264, 0.09197439125273377, 0.03933866566512734, 0.04603907174896449, 0.05150301898538601, 0.03233994219044689, 0.07802625259500928, 0.020495684584602714, 0.058176533348159865, 0.05013527792470995, 0.017472249164711684, 0.023173624285846017, 0.03472543859970756, 0.027688514928740915, 0.06261603848543018, 0.016195794123632368, 0.03495579010632355, 0.02523602670407854, 0.03482423329842277, 0.020315669244155288, 0.0732171801791992, 0.06066604175430257, 0.05277475582261104, 0.04331285163061693, 0.05133396516612265, 0.06986788255744614, 0.01760265378834447, 0.0489200036827242, 0.04131429988774471, 0.04199599592539016, 0.01751123974827351, 0.022175756639626343, 0.0459525336191291, 0.07120273905456997, 0.039573640751768835, 0.021246958822302986, 0.047245169334928505, 0.04893185949185863, 0.025404993320989888, 0.006636356883973349, 0.1209441183891613, 0.011948154569836333, 0.08472907065879554, 0.035707975330296904, 0.044390531693352386, 0.013859906575817149, 0.035640269197756425, 0.027406487679400016, 0.03185055516951252, 0.05485771944222506, 0.046283282863441855, 0.06843795694294386, 0.05214636825257912, 0.05902521632378921, 0.05040066251240205, 0.03099942310655024, 0.025001695430546533, 0.028946844868187327, 0.032384485893999226, 0.04335045625339262, 0.03046919755433919, 0.01643828902160749, 0.034181091832579114, 0.08552030398277566, 0.07560898855444975, 0.048298425317625515, 0.02312995260581374, 0.0806933012790978, 0.08941668318584561, 0.04149208507442381, 0.060223176260478795, 0.00927869576116791, 0.06927624985110015, 0.0389707311114762, 0.0393355968844844, 0.01171421199614997, 0.025006526811921503, 0.04273533457308076, 0.04479745126445778, 0.07545758300693706, 0.03972946578869596, 0.07074591005221009, 0.060414869294618256, 0.012061919314874103, 0.025504871555313002, 0.019679071665450465, 0.042620910244295374, 0.01276529905226198, 0.03470447663858067, 0.048637649888405576, 0.029609673656523228, 0.060079166214563884, 0.031138598060351796, 0.05450444601592608, 0.036869666510028765, 0.04315478901844472, 0.04237126289808657, 0.046161032587406226, 0.030104691722954158, 0.009712873488751939, 0.022888698949827813, 0.035357162123546004, 0.043934218483627774, 0.04639071245037485, 0.06352580021484755, 0.0353759310382884, 0.009298240220232401, 0.04188150109257549, 0.0349519494920969, 0.03451090226008091, 0.05283858423354104, 0.03894707886502147, 0.03519931102346163, 0.04370441987703089, 0.045724449373665266, 0.014677114140795311, 0.03981196663517039, 0.02302574022905901, 0.025759185155038722, 0.038090584785095416, 0.01827063679229468, 0.11136463203001767, 0.020138488907832652, 0.03065240784053458, 0.040680409292690456, 0.052413400408113375, 0.031866915815044194, 0.01449383984436281, 0.11669739353237674, 0.023791109706507996, 0.05943399868556298, 0.03676903870655224, 0.03341076851938851, 0.030080866927164607, 0.02370380716456566, 0.0416227104869904, 0.044426896929508075, 0.0332055646867957, 0.027381365980545525, 0.04996226474759169, 0.034315680313738994, 0.10050997268990614, 0.024264392122859135, 0.022254782379604876, 0.03575550246750936, 0.020878911091131158, 0.032169381811399944, 0.08299095337861218, 0.01281421493331436, 0.024115376290865242, 0.10196478251600638, 0.07437695661792532, 0.07128562952857465, 0.05375988635933027, 0.045742546644760296, 0.014185291020112345, 0.02228473731520353, 0.06126953769125976, 0.038213499283301644, 0.04148473410168663, 0.04043436507345177, 0.07367230966337956, 0.0478019211004721, 0.006371210247380077, 0.02936595421488164, 0.01858606996393064, 0.06906665250426158, 0.05204822293308098, 0.008177882955351379, 0.1561718128505163, 0.014810275843046838, 0.05275073250231799, 0.005443715363071533, 0.04229959740769118, 0.007442984669978614, 0.041100086382357404, 0.06550601348862983, 0.03969526762375608, 0.030596538963436615, 0.028594478717423044, 0.052454207398113795, 0.003973477678300696, 0.048465820436831564, 0.008279837347799912, 0.12072344819898717, 0.030516693150275387, 0.054567639890592545, 0.06778105234843679, 0.06302404901362024, 0.025703919272928033, 0.005291841798680252, 0.01686876807070803, 0.017822516892920248, 0.07904738842626102, 0.03318282157124486, 0.016762407176429406, 0.09990469930926338, 0.031730824484839104, 0.013802181401842972, 0.03456175050814636, 0.040911989053711295, 0.08378183047170751, 0.0545079378207447, 0.07764273294014856, 0.08873292768839747, 0.050821679178625345, 0.04854157887166366, 0.034099247786798514, 0.04165344282228034, 0.04610088522895239, 0.06228831349289976, 0.02272764548251871, 0.05761853106378112, 0.023369981718133204, 0.08210282525396906, 0.02741550106293289, 0.0260949754374451, 0.0707271411374677, 0.09657407412305474, 0.05997972213663161, 0.02521602396882372, 0.028180608933325857, 0.029936040518805385, 0.024853525646904018, 0.05741291162848938, 0.03281584067735821, 0.02300492298672907, 0.057275996514363214, 0.027574305822781753, 0.008550827933504479, 0.09011995716718957, 0.06195757167006377, 0.030864702894177753, 0.023298453525057994, 0.04316792132158298, 0.02469537954311818, 0.028824099208577536, 0.022897259623277932, 0.026636535440047737, 0.08382874162634835, 0.020998346772103105, 0.05576162562647369, 0.03554230570443906, 0.05045703976065852, 0.06472307737567462, 0.020143667243246455, 0.057192853710148484, 0.04529668658506125, 0.06206291953276377, 0.06252532577491365, 0.05991965641442221, 0.010075576828967314, 0.021826611409778707, 0.06276964821154252, 0.06445737366448157, 0.04710645451268647, 0.04156761715421453, 0.1639098156010732, 0.1323022655560635, 0.13186328520532697, 0.1288809796096757, 0.14627221593400463, 0.1077030312444549, 0.06030529490089975, 0.1676423434400931, 0.14008855243446305, 0.09645990212447941, 0.20763763168361038, 0.15881771774729714, 0.18371586687862873, 0.09057014394784346, 0.08341512046172284, 0.12652399280341342, 0.21067586552817374, 0.14606494893087074, 0.15035695221740752, 0.09375017252750695, 0.11564660890144296, 0.14694249402964488, 0.18984780268510804, 0.11591778966248967, 0.18088755692588165, 0.10251225001411512, 0.14988485723733902, 0.173087703587953, 0.07987857155967504, 0.2342163593857549, 0.09666923229815438, 0.1625542383408174, 0.11098590664914809, 0.13065503910183907, 0.2285889207269065, 0.21480597672052681, 0.1622232998488471, 0.10469906235812232, 0.1619108408340253, 0.1002077701559756, 0.20950419246219099, 0.15143487718887627, 0.054953100261627696, 0.0966337724821642, 0.24978850269690156, 0.15639135497622192, 0.09096818001125939, 0.22415411338442937, 0.20773531316081062, 0.10520709955017082, 0.15082977450219914, 0.15282346517778933, 0.18759533995762467, 0.10611962206894532, 0.128258035692852, 0.17209499201271683, 0.12078158804797567, 0.09204109548591077, 0.14942392415832728, 0.1832684557302855, 0.21994444396113977, 0.23269397701369599, 0.1907799846958369, 0.09919195552356541, 0.12687309907050803, 0.15355557901784778, 0.12228733889060095, 0.13854184246156365, 0.13035320764174685, 0.2860522427363321, 0.1431870783562772, 0.13518544990802184, 0.14650291996076703, 0.085894524527248, 0.1037465306580998, 0.13503442285582423, 0.16078865417512134, 0.16694732214091346, 0.16206192725803703, 0.20196529309032485, 0.09253135081962682, 0.191209985059686, 0.07703910712734796, 0.1245523735997267, 0.10381883068475872, 0.16006038466002792, 0.13385283469688147, 0.12767822539899498, 0.2956629957770929, 0.19795567699475214, 0.15227246505673975, 0.07352706394158304, 0.15152405365370214, 0.10321379479137249, 0.13693484041141346, 0.1664958440233022, 0.1376127329422161, 0.14137519901851192, 0.17076684453058988, 0.1884000061545521, 0.1439987652702257, 0.12649346084799618, 0.060139862762298435, 0.20805841457331553, 0.10805602636537515, 0.13936923322035, 0.17894652904942632, 0.1730566966580227, 0.140790015575476, 0.14707737194839865, 0.072671983652981, 0.15498574211960658, 0.1512979212566279, 0.10921650784439407, 0.12013853192911483, 0.1571287083788775, 0.1377369833062403, 0.206278640544042, 0.10241746291285381, 0.19156829395797104, 0.20622891664970666, 0.15472410537768155, 0.11402804419049062, 0.1283539508585818, 0.13856753561412916, 0.09585485880961642, 0.14108013594523072, 0.1205391061375849, 0.17612875759368762, 0.18587444792501628, 0.08703222207259387, 0.14098077721428126, 0.12869539816165343, 0.2099637154606171, 0.12475400028051808, 0.15353327005868778, 0.2525700128171593, 0.14046513300854713, 0.1651704276446253, 0.17792191996704787, 0.10063002991955727, 0.13077234296360984, 0.11099304610979743, 0.08072222277405672, 0.11043467646231875, 0.11379865376511589, 0.20953519939212129, 0.21590156480669975, 0.22885435726493597, 0.11140149450511672, 0.111881604680093, 0.11734532556147315, 0.07223984590382315, 0.12085264126653783, 0.12683722365181893, 0.11174229613970965, 0.13334637827938423, 0.11381626492948271, 0.13453837134875357, 0.1484239543788135, 0.15060604666359723, 0.17237001709872857, 0.10953717501251958, 0.20510787289822474, 0.1091685205756221, 0.1033711968921125, 0.12359780841507018, 0.2439915426657535, 0.11010003465344198, 0.10116856195963919, 0.11010309972334653, 0.10429827292682603, 0.18767929170280695, 0.1762943307403475, 0.15433866356033832, 0.07856152660679072], [0.0693413287808653, 0.0640679762000218, 0.035889419305021875, 0.037136338723939843, 0.061743369296891615, 0.03249315486755222, 0.020573541441990528, 0.015028538691694848, 0.03595975264033768, 0.007964562810229836, 0.054421726235887036, 0.08637724706204608, 0.010671319178072736, 0.023053793411236256, 0.03869830725307111, 0.07052258297335356, 0.06394186304532923, 0.054962072827038355, 0.09321981153334491, 0.027080415820819326, 0.015505634819419356, 0.03661194830783643, 0.06373660726239905, 0.056317152848350815, 0.07906816856120713, 0.02842560857970966, 0.05401214977609925, 0.04771521969814785, 0.04700373756350018, 0.00950098661633092, 0.07244091597385705, 0.034263499910593964, 0.031063589194673114, 0.023179644958872814, 0.027078864732175134, 0.08305372422910295, 0.04408102271554526, 0.009060363336175214, 0.04830478923395276, 0.03864051992422901, 0.015327971159422304, 0.04390640649944544, 0.04600429841957521, 0.05191934156755451, 0.06765637153876014, 0.07196217877208255, 0.05699529770936351, 0.03573609530576505, 0.08992457194835879, 0.012959622999915155, 0.01450346271667513, 0.046810259664198384, 0.014544991445291089, 0.03134938655421138, 0.019805336960416753, 0.028137928020441905, 0.08533226602594368, 0.008312473291880451, 0.06374249249347486, 0.04368745438114274, 0.016730261049815454, 0.09702429801109247, 0.021637016798194963, 0.024197969905799255, 0.02325006735190982, 0.03267245403549168, 0.07361904572462663, 0.032023490421124734, 0.06738262294675224, 0.03339955837873276, 0.05044763303885702, 0.07245995206176303, 0.07463491972885095, 0.023185866011772305, 0.03319456234748941, 0.01067067629264784, 0.015642233593098354, 0.08864700925187208, 0.020439114377950318, 0.10203970974544063, 0.047699218994239345, 0.009765527011040831, 0.043016378476750106, 0.024543777326471172, 0.07210772135294974, 0.03250355235650204, 0.015067240765347378, 0.1056182493630331, 0.006994142104304046, 0.03133846585114952, 0.04108037865080405, 0.04673027840908617, 0.018171441333834082, 0.05808203568449244, 0.03261926060076803, 0.03330276005726773, 0.014023963885847479, 0.01784744563337881, 0.025507320642645936, 0.021319427687558345, 0.04145035411056597, 0.043139812478329986, 0.0840053653519135, 0.0684734241804108, 0.036885366644128226, 0.032204106901190244, 0.044956549172638915, 0.04822759474336635, 0.033560760275577195, 0.019181289098924026, 0.11108433769550174, 0.02089240890200017, 0.039628437225474045, 0.015424665580212604, 0.07818032245268114, 0.015904720094113145, 0.06000808331009466, 0.0525990597816417, 0.010955104389722692, 0.023232331877807155, 0.028515477097244002, 0.0247112652141368, 0.031830376174184494, 0.041987531731138006, 0.029525222817028407, 0.04968845307303127, 0.06800817180192098, 0.026332047091273125, 0.03778079008043278, 0.0377397530246526, 0.019479335605865344, 0.04242569571943022, 0.0636802485678345, 0.023201287840493023, 0.03537954900821205, 0.05294782095006667, 0.01920212303957669, 0.07107974292011932, 0.025574199280526955, 0.018133066732843872, 0.11810601208708249, 0.03709867472935002, 0.006850632544228574, 0.04186758211289998, 0.030127740974421613, 0.04099780730030034, 0.04442405450390652, 0.05486777925398201, 0.003517764912430721, 0.05467946299177129, 0.0654177350224927, 0.005419996787168202, 0.03871505010465626, 0.025155475850624498, 0.011040210174542153, 0.04062889682245441, 0.015029497917566914, 0.11943358811549842, 0.027578419176279567, 0.06935681740287691, 0.051498221000656486, 0.05795333614514675, 0.0359621609095484, 0.037160336069064215, 0.036128758220002055, 0.027875649320776574, 0.04068426846060902, 0.04222725285217166, 0.01867189563199645, 0.00703349634022743, 0.04535690073680598, 0.014475049592874711, 0.01829288823500974, 0.02219441237684805, 0.07000278274063021, 0.02937146280601155, 0.0333113763917936, 0.027694852869899478, 0.034419662624713965, 0.026687029312597588, 0.040519185131415725, 0.008375452871405287, 0.06198198090714868, 0.022041140327928588, 0.03690464021929074, 0.04259177723724861, 0.05112265716888942, 0.10512637614738196, 0.006394012734745047, 0.12302321541938, 0.035903557218261994, 0.10061028879135847, 0.025933485958375968, 0.03101382633758476, 0.05336091518984176, 0.01962211183126783, 0.017383644153596833, 0.04395794865558855, 0.044148654633318074, 0.01529439361547702, 0.0634903997706715, 0.012856414377893088, 0.023735610047879163, 0.06397250632289797, 0.07344717174419202, 0.07559358156868257, 0.047347819490823895, 0.018907495978055522, 0.02218665693362709, 0.018874808083637618, 0.0696796145348344, 0.06078445883758832, 0.032799676700960845, 0.08334667960298248, 0.05720384120650124, 0.01517646356660407, 0.03227200228138827, 0.0631433715170715, 0.07157691507018171, 0.0653472235717345, 0.060702173213940114, 0.03997866413556039, 0.014702426942676539, 0.018331888095417526, 0.06765165147953667, 0.016510694804310333, 0.049045942432712764, 0.041189381590811536, 0.026113376989087556, 0.022051945998100564, 0.02426311191811692, 0.034988158877240494, 0.03604833909776062, 0.031247411752701737, 0.04251846046827268, 0.05092182458611205, 0.013243462944956264, 0.04587327966874, 0.024340670061064884, 0.033954825848923065, 0.050659950356930494, 0.03473011041933205, 0.013642452668136684, 0.05480933883518446, 0.03383046045200899, 0.04985619700164534, 0.014051517046027584, 0.039687560420134105, 0.02803304771077819, 0.025551086946506985, 0.018779100719257258, 0.03757556769414805, 0.0271117826923728, 0.037951933045405895, 0.014097825205681147, 0.0650029635289684, 0.02281009994476335, 0.029361866836552508, 0.06093733383750077, 0.07494259931263514, 0.04169483981968369, 0.021678090961358976, 0.05220530219958164, 0.08882968890247867, 0.03361768671311438, 0.04444293103006203, 0.11262407890171744, 0.028599597681022715, 0.06974190298933536, 0.18571990309283137, 0.017552304634591565, 0.002959341923087777, 0.02993942100147251, 0.024246628818218596, 0.02909077698859619, 0.026894107068073936, 0.06032116572896484, 0.05037581540818792, 0.07343595047132112, 0.04729670406959485, 0.03440560263697989, 0.025725103878357913, 0.033296852561761625, 0.0304033746215282, 0.015426533936988562, 0.05772054297267459, 0.01921059094456723, 0.00837280062114587, 0.02766483485174831, 0.01481759249145398, 0.05000446326448582, 0.01604943518032087, 0.027685885870596394, 0.04196033944026567, 0.03879596646584105, 0.07910697546321899, 0.031736208766233176, 0.03353073669131845, 0.050590143946465105, 0.009015030173031846, 0.057827671989798546, 0.03639125956397038, 0.029760164507024456, 0.06989266286836937, 0.04715318384114653, 0.008651698790345108, 0.007527980524173472, 0.03455419915553648, 0.04274473758414388, 0.02263719252368901, 0.021231830141914543, 0.040937188678071834, 0.0370226565428311, 0.01304071098275017, 0.021409641303762328, 0.011412969615776092, 0.08943882145103998, 0.05099538255308289, 0.0519513021572493, 0.04733992675028276, 0.0198655696658534, 0.028161134978290647, 0.049185499592567794, 0.062432831909973174, 0.029374930491030682, 0.12517074588686228, 0.004375795933810878, 0.03772279495024122, 0.036957674092263915, 0.04059062797750812, 0.06251107653952204, 0.019711223358171992, 0.018989692543982528, 0.003828996136689966, 0.023638817292521708, 0.03750152362044901, 0.033258672774536535, 0.047665547754149884, 0.02834255854395451, 0.011991970968665555, 0.03510896938678343, 0.04780553535965737, 0.020851158478762954, 0.005035996127844555, 0.041317736031487584, 0.02600309013359947, 0.01670694833592279, 0.01835133421991486, 0.026053081201098394, 0.05533553638088051, 0.03235096679418348, 0.0070701955428376095, 0.19549061864381656, 0.11987794161541387, 0.17064725485397503, 0.12173457245808095, 0.24327008606633171, 0.07309000575332902, 0.16751742514315993, 0.08429112189332955, 0.13313263974850997, 0.10174374125199392, 0.2950652106665075, 0.15074181515956298, 0.08152300011715852, 0.31380301457829773, 0.15083612728631124, 0.15096420713234693, 0.11986533252638765, 0.24174650141503662, 0.17800667323172092, 0.17832748882938176, 0.19345771288499236, 0.17078033677535132, 0.2169363561552018, 0.1374353893334046, 0.17723164841299877, 0.16852738423040137, 0.12179061202914454, 0.20027522987220436, 0.14818578434642404, 0.1265730190789327, 0.2222534583415836, 0.1789003229350783, 0.1311846059979871, 0.16316282912157476, 0.12728162168059498, 0.15222663001623005, 0.08356445541721769, 0.09550529983243905, 0.13952520297607407, 0.0944115522725042, 0.12373115008813329, 0.16711388976546004, 0.13927514373790473, 0.1967390743084252, 0.17397966119460762, 0.16317363479174674, 0.16084481991128996, 0.13419336173683405, 0.2749268850311637, 0.11537674916326068, 0.11007580353179947, 0.1694124992354773, 0.15492255566641688, 0.14124866283964366, 0.11993091611657292, 0.16618814959656447, 0.19917650992283598, 0.14332952618133277, 0.10216197857516818, 0.19459711736999452, 0.12887771415989846, 0.18615345092257485, 0.13500282220775262, 0.11552321942872368, 0.10586182965198532, 0.11580220758332871, 0.1622207765467465, 0.09889216496958397, 0.14500137709546834, 0.11387586680939421, 0.1906217884970829, 0.091580258886097, 0.14709301642142236, 0.09115093387663364, 0.15320150036131963, 0.12131291383411735, 0.13354077644180506, 0.12930927303386852, 0.08213538327254355, 0.20477059646509588, 0.12406706839101389, 0.13114708301145583, 0.1904259208822623, 0.2720339043298736, 0.14232357469154522, 0.08542075229343027, 0.10986820256221108, 0.18482849467545748, 0.10659303065040149, 0.08838376947096549, 0.2193039853591472, 0.21531681180931628, 0.13219886954175308, 0.3159040049649775, 0.14937889063730836, 0.12258920003660023, 0.12519075418822467, 0.11209793330635875, 0.12437744939234108, 0.12889312114566565, 0.12817478156648576, 0.1568322055391036, 0.18985356175107881, 0.17549520096508786, 0.17661970312474295, 0.13547316571930423, 0.21116075513418764, 0.12772937421686947, 0.16993333847494796, 0.118480989622185, 0.1646461003110744, 0.14453959796810523, 0.1014917079010047, 0.1779280649498105, 0.1808325489400886, 0.09960817420505919, 0.11033764807507396, 0.1652985965483822, 0.10688534035580233, 0.13646482344483957, 0.13885361870052293, 0.15161447692662477, 0.09489746604231186, 0.07640127572813071, 0.23760512442095205, 0.07952369880513288, 0.07843484199838713, 0.10647408664226532, 0.12123739288654178, 0.05242915991402697, 0.13103090721415356, 0.15748663136037067, 0.13254974212031811, 0.15693981695221737, 0.13163842930225655, 0.14663295907666907, 0.0913374281662982, 0.19944948668126017, 0.10089372983202338, 0.1397661041119136, 0.15702943870564923, 0.17289502720814198, 0.12446116365026683, 0.15366059291409329, 0.13250084943138063, 0.14692126860609278, 0.13159679481759667, 0.10701215112931095, 0.0714854231046047, 0.24345917045138776, 0.11895128118339926, 0.14668023388367146, 0.14172535913530737, 0.09352693450637162, 0.11433627296355553, 0.11665136553347111, 0.12282913638046011, 0.16117304214276373, 0.06604479785892181, 0.21469668805366382, 0.15362428704975173, 0.1314294702024199, 0.10667290800483897, 0.0927318939648103, 0.13664424506714568, 0.1181925687706098, 0.11911590438103303, 0.3363692614948377, 0.1846278624725528, 0.10785026592202485, 0.0948984753631521, 0.11075965550844558, 0.12375345162581652, 0.12810927961254492, 0.08348533505341038, 0.17906818189658225], [0.07526324421633035, 0.0313150325382594, 0.029495429298549425, 0.020611682266462594, 0.07348022700170986, 0.035267284329165705, 0.02879757299524499, 0.02897433216276113, 0.008166498409991618, 0.02915180564741604, 0.029520799616875593, 0.030829591887595598, 0.05591041139268782, 0.04493892687605694, 0.01141618125984678, 0.05127592179633211, 0.029807450446242, 0.05068304970336612, 0.03059155358641874, 0.039066252938937396, 0.02876913389627589, 0.047012327922857367, 0.04435693837876897, 0.023961549486557487, 0.031147073386819102, 0.05335006870154757, 0.05223898828262463, 0.029175623021728825, 0.023062723303155508, 0.027093761491414625, 0.08351503580342978, 0.028173408245493192, 0.012419551003404194, 0.06094676282373257, 0.034786647229338996, 0.06331729382509366, 0.062060388809186406, 0.029450236215780023, 0.0037115841996637755, 0.0029191274916229304, 0.032203798909904435, 0.010374328376201447, 0.008455889619654045, 0.02987480034789769, 0.07747434705379419, 0.03891769352776464, 0.023806763456377666, 0.12091927128494717, 0.022441838846134488, 0.04918387428915594, 0.08806800789898261, 0.010253911204927135, 0.0443646121857455, 0.029553264866990503, 0.006581254274351522, 0.026038099094876088, 0.047128255100687966, 0.056078548659570515, 0.02965922871226212, 0.06457166440668516, 0.06211493666341994, 0.039305784812313505, 0.06559628833201714, 0.04985183317330666, 0.05835575459059328, 0.0465071368671488, 0.0779113384487573, 0.021449526175274514, 0.03145639682770707, 0.032897621640586294, 0.03349846439959947, 0.06770377251086757, 0.06461179233156145, 0.05198871382162906, 0.10745133185992017, 0.033195727519341744, 0.03014170448295772, 0.0215377916538273, 0.01874008416052675, 0.030178490887919907, 0.07070262057823129, 0.021779926610179245, 0.04754795445478521, 0.026817387552000582, 0.008530846534995362, 0.1171898159373086, 0.04834809726162348, 0.019014565623365343, 0.028159767571196426, 0.06514212363981642, 0.032240086220554076, 0.03888230421580374, 0.04128297012357507, 0.054319038972607814, 0.03099395162280416, 0.03661911003291607, 0.029215005088190082, 0.06902827604790218, 0.10491251887287945, 0.0915705441730097, 0.1545336257549934, 0.010242865264444845, 0.0472559267655015, 0.015072588867042214, 0.020113207647227682, 0.009840443108259933, 0.03464782108494546, 0.016990662115858868, 0.032497177307959646, 0.037917207955615595, 0.07036698429146782, 0.029533588676713407, 0.06368539907271042, 0.02779838989226846, 0.050655222876230255, 0.06819271424319595, 0.02990740475070197, 0.03987511227023788, 0.027850666774611454, 0.01680129014857812, 0.03816697033471428, 0.04110540387046058, 0.056844771606847644, 0.01582037872140063, 0.023061994143063203, 0.020751872107211966, 0.02987863354064757, 0.06714157338137738, 0.002059404373540019, 0.0367133627878502, 0.0198485058353981, 0.03200085491698701, 0.09814989112783223, 0.030657690076623112, 0.015622279097442515, 0.030062331788940355, 0.07285354266059585, 0.0604746158933267, 0.04302250119508244, 0.011707087378454162, 0.06170197972096503, 0.009019175067805918, 0.0137700176492217, 0.051561578147811815, 0.02229134985100245, 0.09964442069758661, 0.035642818475025706, 0.049528913586982526, 0.013559274611907313, 0.04509831051109359, 0.029139417347323615, 0.04014660473330878, 0.05394615429395344, 0.028013141454721335, 0.04266130905307364, 0.010701288956624921, 0.007970725418999791, 0.029663136119779665, 0.08321164583321661, 0.019452314008958638, 0.06730953624355607, 0.09178912150673568, 0.033364284099661745, 0.05235690070549026, 0.028084087061870378, 0.05157892213901505, 0.06657770441961475, 0.011886252959811827, 0.025862577458610758, 0.02483601467247354, 0.010796873866638634, 0.08974757714895532, 0.05647382393362932, 0.044515008412417956, 0.017803007685870398, 0.03997850086307153, 0.043613907546387054, 0.04330499970819801, 0.04481384159589652, 0.04865663773671258, 0.03246019608923234, 0.04262222384568304, 0.07569446912384592, 0.0038870967910042964, 0.011298491481284145, 0.04043385670229327, 0.023675802221987396, 0.04604264147928916, 0.0450860687851673, 0.04833824154047761, 0.013461764756357297, 0.02266646653879434, 0.024316262679349165, 0.047542403190163895, 0.04173705317953136, 0.024519885737390723, 0.039464552464778535, 0.041067394777201116, 0.018873461085604504, 0.0584237167640822, 0.007217455267891637, 0.12404654800775461, 0.06693723044008948, 0.039052011125022545, 0.021917428020969965, 0.02830859972164035, 0.08352995297173038, 0.04953422365360893, 0.038333411794155836, 0.018559751551947556, 0.08216264977818355, 0.015567054033454042, 0.05863048281753436, 0.022586993654840626, 0.05344986901036464, 0.01995079048356274, 0.08236374953412451, 0.00791620817835792, 0.017236322273674887, 0.02215570566477254, 0.010474528517079307, 0.024793652883090544, 0.038629977716482244, 0.05881112898350693, 0.02022268556174822, 0.040728203603066504, 0.09413119856617413, 0.035206613756599836, 0.008636689781269524, 0.019602185166149866, 0.07310314918868244, 0.05903395140194334, 0.04014161379018333, 0.038579036699957214, 0.04318298691941891, 0.05060444884293247, 0.021545817980950233, 0.021742971366620623, 0.05038642440922558, 0.06665260196314193, 0.010501128945179516, 0.051308665351825766, 0.05071948544355109, 0.018230776040581986, 0.023909983210614882, 0.04710505556431599, 0.010509302774153184, 0.06921790962223895, 0.05477921135025099, 0.03177850376232527, 0.09206713002640754, 0.021006449169362895, 0.030474674604192842, 0.061770531901856884, 0.07585899584228173, 0.009975193006539484, 0.04499048758589197, 0.016078128464869224, 0.033011726845870726, 0.02535243627789896, 0.025797353810048662, 0.013313729486981174, 0.06321978304185905, 0.012033226958010346, 0.0567713917553192, 0.0998791100573726, 0.015220935838442529, 0.03231818613130599, 0.063784468366066, 0.03721620494616218, 0.025652783442637883, 0.07640949130291119, 0.011012080922228051, 0.05443519992695656, 0.06766345904907212, 0.039865468061179854, 0.019871716503985226, 0.010683750151656568, 0.034699819661909714, 0.0077583055917784804, 0.030661642013001256, 0.01123197742344928, 0.037817370539414696, 0.06582274727406912, 0.04364628744951915, 0.020990348275518045, 0.040625486653880216, 0.06591537472559139, 0.05262976614176296, 0.044294902254478075, 0.03877383191138506, 0.06194662499183323, 0.046946822258178145, 0.08485502796247602, 0.029747427397524007, 0.040531946360715665, 0.019476559973554686, 0.03151989869365934, 0.05389376980019733, 0.09674730623373762, 0.037860185038880445, 0.011475310948299011, 0.06313153426162899, 0.05700754314602818, 0.056907579564722255, 0.02446834358124761, 0.01204060483360081, 0.011825457149825525, 0.046748453605687246, 0.0280182177448296, 0.08217064270866103, 0.009662764605309349, 0.058392669016029686, 0.06196363872732036, 0.031889135716483, 0.013998706745042, 0.04328815295593813, 0.042677832971094176, 0.03017457976966398, 0.03590169442759361, 0.04817064604139887, 0.036888877002638765, 0.047296351549448445, 0.05376631706894841, 0.035288699000375345, 0.07488569885026664, 0.023284324888663832, 0.06242597446544096, 0.02550099197833333, 0.0449284885689849, 0.05686749987944495, 0.008172969937731978, 0.026071926185977645, 0.04134850176342297, 0.058301640892750584, 0.0027517873377291835, 0.032118648596224375, 0.027058735831815284, 0.03158498875563964, 0.03196451194526162, 0.04199871218588669, 0.035070555823040195, 0.07615811846335419, 0.00889797121999436, 0.018482759296603035, 0.049765380390454084, 0.10615675171720795, 0.04244538118655328, 0.010650052936398424, 0.020991539422539063, 0.0619409438513685, 0.006467824887295137, 0.1791197611601092, 0.16167406603926793, 0.09797896709642373, 0.19300089130410925, 0.16526031657122076, 0.0957341336470563, 0.09824623673921451, 0.1309376340941526, 0.09524046443402767, 0.1144653101800941, 0.0983827919117175, 0.1910828848485835, 0.11932462599361315, 0.1361739609274082, 0.10295551997842267, 0.15878230246016756, 0.12006660297629423, 0.147158206673339, 0.08298595872474834, 0.09216216203640215, 0.09438566616154276, 0.14476476557319984, 0.09700276088551618, 0.1161162176867947, 0.14237019640859216, 0.28322308673523366, 0.17700654017971829, 0.15704242628999054, 0.06331457014312036, 0.12979916471522301, 0.24196920508984476, 0.1186384362517856, 0.13974634814076126, 0.14546851452905685, 0.17265724309254438, 0.116316797939362, 0.19912123476387933, 0.1363731236779131, 0.13148213300155476, 0.12628224561922252, 0.1601676843711175, 0.07175129008828662, 0.12199629083625041, 0.1180262015259359, 0.22599358577281237, 0.1367398930597119, 0.11722855604602955, 0.2415888395626098, 0.07824603220797144, 0.2103837562026456, 0.2052317967172712, 0.16940418718149886, 0.11970000428846106, 0.10608284865156747, 0.14640428853454068, 0.17444896569941193, 0.1149114448344335, 0.15660841832868755, 0.09322096928372048, 0.1248315695556812, 0.09589455628884025, 0.11694757893565111, 0.15981210657628253, 0.13953446497907862, 0.09430210033315234, 0.11274742384557612, 0.1886397643829696, 0.08648171176901087, 0.0870336544176098, 0.11472335492726415, 0.14262193290051073, 0.22842575213871896, 0.1517064735526219, 0.10507481914828531, 0.27318916108924896, 0.11367611776222475, 0.11936212671571411, 0.10015519641456194, 0.13463183742715046, 0.14791533089010045, 0.17722010059515014, 0.11052998306695372, 0.14658604050055146, 0.14814014226431027, 0.13993019296322018, 0.1405477340449579, 0.1145568912033923, 0.10727425542427227, 0.08765547769144177, 0.20965480391168967, 0.12930954020703211, 0.0777268924866803, 0.10690209805034101, 0.1603086627437733, 0.05892835120903328, 0.11404949225834571, 0.13710229861317202, 0.1653258630540222, 0.2368026104522869, 0.23388035944662988, 0.2396731634507887, 0.19212033308576792, 0.12080440908903256, 0.13665747013874352, 0.08567841112380847, 0.14317722263513133, 0.19099020544672385, 0.1949669889290817, 0.1424796780338511, 0.1113214464567136, 0.14626757008954883, 0.1327391530503519, 0.15836862934520468, 0.13064300146652386, 0.15706829755799845, 0.20100462745176628, 0.12886652257293463, 0.15324107167543843, 0.13551818439736962, 0.11520319792907685, 0.15404863224830478, 0.07809631133568473, 0.12146628607297316, 0.17538460611831397, 0.11092789296526462, 0.12991240160772577, 0.08436033458565362, 0.12756270269164816, 0.21123292157426476, 0.10866337033803575, 0.06714515795465559, 0.09870961148408242, 0.13430631661321968, 0.13556137739215046, 0.1843115739757195, 0.11138505593407899, 0.3372602246236056, 0.1908086909679696, 0.1252996124094352, 0.10641996923368424, 0.20570693450281397, 0.10155314288567752, 0.08985438704257831, 0.13087713421555236, 0.23016340186586604, 0.2120077089057304, 0.129363345913589, 0.10704919914132915, 0.061309528318815865, 0.2635628229472786, 0.16964244627160951, 0.14126478228718042, 0.19047937035793439, 0.13825293921399862, 0.10307046381058171, 0.17703529098071158, 0.11794959704275243, 0.1443993765860796, 0.2722830878337845, 0.12479965720558539, 0.12718209967715666, 0.19443785247858614, 0.10336127437767573, 0.1972690419643186, 0.19200901093427092, 0.15479459456400946, 0.12670941097894683, 0.17288255912717432, 0.11367086335667409, 0.1150573139602784, 0.2523764013312757, 0.12623917136806995, 0.12507401435868815, 0.09603941609384492, 0.12181192651041783, 0.10210440275841393], [0.03643928394012619, 0.03357143978064414, 0.023845113937568385, 0.02480113187630195, 0.026637520641088486, 0.06418083459720947, 0.031166929547907785, 0.05403384275268763, 0.031231652246788144, 0.06737202507792972, 0.04084372259967495, 0.0070624104137095856, 0.07747075505903922, 0.04046233661938459, 0.0337837830738863, 0.007747947065581684, 0.0967778307676781, 0.014885606615280267, 0.03140436114335898, 0.06983239305554889, 0.004067931740792119, 0.020289293315727264, 0.033282989243161865, 0.033222878992091864, 0.017762310162652284, 0.02679833662114106, 0.04728984662506264, 0.04189520484942477, 0.02498354806448333, 0.08328560827067122, 0.08245443998021074, 0.053718708295491524, 0.02774875876639271, 0.07187998591689393, 0.023207982012536377, 0.022368186255334876, 0.08420469879638404, 0.02253318794828374, 0.03793569114350248, 0.0061457318679458695, 0.04112576840270776, 0.028979710878047626, 0.03161717570037581, 0.04727347113657743, 0.02007100727496436, 0.13134332170011476, 0.08690567847224884, 0.021954067851766013, 0.04458363851881586, 0.031050289908307604, 0.031825774858589284, 0.14696894417284057, 0.07918994015199132, 0.05036194095737301, 0.02145255042705685, 0.03721609362401068, 0.043810042334371246, 0.02955568426841637, 0.012648942356463522, 0.0806796680262778, 0.03948843848775141, 0.049463741888757795, 0.03351800514792558, 0.043334622532711364, 0.04080520513525698, 0.07519609469454736, 0.055772650230210274, 0.03169224022713024, 0.05124304836499505, 0.07512440322898328, 0.10366931019234471, 0.06933944372576661, 0.08964790671598166, 0.015948145010042936, 0.03413922357140109, 0.03368291036167648, 0.04617854727257509, 0.02788872596283909, 0.005773824968855479, 0.035168192771379836, 0.04000000830274075, 0.014249094383558258, 0.036856745718978345, 0.023940064311318565, 0.03464280045591295, 0.030713694395672064, 0.03743788445717655, 0.02586659804364899, 0.021012334400438704, 0.01660883270233171, 0.054403231915785, 0.06990174675593153, 0.07945674966322258, 0.06585684895981103, 0.03739239451533649, 0.009561891893099528, 0.10035454470198601, 0.03680730013002176, 0.026696092791098636, 0.023412892696796916, 0.021870093842153437, 0.0250094044895377, 0.0572152925451519, 0.025765914579096716, 0.047935125476215035, 0.03315815258247312, 0.06167014529637527, 0.026396623215987347, 0.05510836868779734, 0.035609191763796844, 0.1028601020516362, 0.03150232463667635, 0.05597290022706147, 0.019366996712051332, 0.04908200709905941, 0.004153580221100128, 0.040039486848399974, 0.06831684586359188, 0.07158586537116207, 0.02769748378341319, 0.06834586383774877, 0.015430367129738443, 0.040513871354050934, 0.029357387975323945, 0.02108895372657571, 0.023948300295160152, 0.008540462913515512, 0.022985463874647394, 0.03901362724718638, 0.04864960217673797, 0.02378550278081093, 0.08801931558991782, 0.04173935012659058, 0.07592128429678269, 0.05889698804821819, 0.018982163455802947, 0.017712951776047703, 0.03217212775780354, 0.0831636437214911, 0.06762946126400493, 0.11270071307080798, 0.02556563118560007, 0.07376099631073885, 0.02011795553698903, 0.05140148947248235, 0.02498280406143749, 0.02990580727782799, 0.042947625915985554, 0.09009771500132047, 0.01747766313201282, 0.013229380692791892, 0.011363524026819505, 0.03192270676663611, 0.0285366802563658, 0.039146634953795, 0.02017237351537915, 0.026215984471491538, 0.06570304627530277, 0.03305373611510731, 0.05773733777459711, 0.06973167619435117, 0.024080666044028476, 0.04736373484774958, 0.023768685714458115, 0.041909817737177946, 0.026726730502559803, 0.02521534861443797, 0.022335377761919517, 0.04912203112326097, 0.04321808308304753, 0.018965702620334923, 0.021970573216094635, 0.019143176104989834, 0.017949837892956566, 0.01589124083693605, 0.030341889541887213, 0.0315028886689106, 0.07536721168435179, 0.01623966989427572, 0.0809003233734984, 0.016425136309408117, 0.06760784992366098, 0.04498416819842532, 0.025375517070642672, 0.03996827406808734, 0.034646756103029475, 0.05336350528523326, 0.03234582000004593, 0.03765943038160913, 0.04156138682446908, 0.017264848574995995, 0.0534703931043623, 0.02922525043686619, 0.042293645383324474, 0.05458045307022985, 0.05416540698206518, 0.033692695578793064, 0.04398946024593897, 0.056965578405652195, 0.018031533509201836, 0.03011537864949787, 0.02748223312664777, 0.023055032797856256, 0.0700553490605671, 0.024113394756568596, 0.0701954442774877, 0.003227161682843871, 0.029367104543780442, 0.01190689486975316, 0.04172037712123711, 0.04372141876956448, 0.0219657566776732, 0.04971800539351534, 0.028707940109597985, 0.031777932308614254, 0.028019533201586455, 0.028245917928870767, 0.030229932854126673, 0.017581560096004978, 0.07976892666192725, 0.005248468369245529, 0.046350473203347065, 0.06874389247968793, 0.03960949390602764, 0.03008732175658224, 0.0692383706336841, 0.022599166732106823, 0.07638200957444496, 0.00987719611657667, 0.016144962573889643, 0.009031611607497325, 0.05419555302069057, 0.005506642528416705, 0.06678049627225846, 0.017225462797796354, 0.030343509279191494, 0.04671655238780659, 0.04686597269028425, 0.00978888981990167, 0.04323623601521831, 0.05734689759265166, 0.026129227408091538, 0.04654908676457126, 0.053701586948591284, 0.01923666259244783, 0.040405621693935245, 0.04211999766994268, 0.03672840241051745, 0.010752567650342826, 0.058413107763044536, 0.025715899391798303, 0.01510819989562151, 0.016976874867395964, 0.004577996851367061, 0.016812311041576322, 0.10102305648615584, 0.02255379924463341, 0.006339257543004351, 0.04854712271480821, 0.05655205372022465, 0.01043218064296525, 0.03383793016837444, 0.023611951546627097, 0.0405107803089777, 0.08266379983979277, 0.029704581356782, 0.032503775000805035, 0.008438662516709883, 0.06625570138567127, 0.02094384159136098, 0.053022362262709066, 0.023602550390933175, 0.06911547839990817, 0.011933494370168773, 0.03863273850583937, 0.013443727784760995, 0.012713254091067938, 0.039952340157469735, 0.04311748125473969, 0.07548629670054652, 0.00974991964540095, 0.00823513779323548, 0.055609592964174226, 0.0706625594466459, 0.045500866253860295, 0.022098354347690474, 0.0909120513824746, 0.02807650416798424, 0.018547196268627886, 0.04383552397484891, 0.04446266473678406, 0.027783927289419807, 0.013421730527625186, 0.03328898579638917, 0.008249942711699987, 0.008440724759566365, 0.05082055853563361, 0.03192161209881306, 0.08860826914315112, 0.05471164251503069, 0.004796137245648424, 0.04270650584658142, 0.021005081762268674, 0.052241159064578824, 0.038683545935782604, 0.02590580756077543, 0.05208426162425894, 0.09476773120695725, 0.0556979048269568, 0.043235482735326514, 0.013575742868852103, 0.02242627044324763, 0.013814783069392433, 0.007342005737882573, 0.06591452125576325, 0.06701033198623918, 0.030167781696945895, 0.019871109798259567, 0.0556031140149571, 0.04432707435626071, 0.06420971156330779, 0.011917550255020615, 0.018324808006582316, 0.040374993259320036, 0.024096711276797578, 0.025054245052160695, 0.04944403415720444, 0.08009689656319097, 0.03929856000468135, 0.03976988315116614, 0.057243004339397885, 0.018186226770922076, 0.04142265715927351, 0.038753125991206616, 0.043081765397801064, 0.05675122760294471, 0.03744476787687745, 0.01568720403156476, 0.011714888278220315, 0.022421947433031164, 0.011890347759617725, 0.00606019842052774, 0.10627130963257514, 0.04209067912597675, 0.03256614138081204, 0.009141000464296667, 0.02736529477260774, 0.031307106401072815, 0.0834200854296796, 0.02177772985305637, 0.05591294953774195, 0.011363948906364385, 0.08887222138582729, 0.14835060050245374, 0.11053287744289264, 0.1522185406065546, 0.11905467719770968, 0.10701117149437778, 0.10649003539583646, 0.16534175985725597, 0.1208205136936158, 0.1567611374775879, 0.20336982241133228, 0.13997384608956054, 0.16022975760279223, 0.15610654838383198, 0.10944562367512845, 0.19214834173908457, 0.13888711924664676, 0.13069786102278158, 0.16498254553880543, 0.12919615488499403, 0.16903808573260903, 0.11407465106458403, 0.09029631371959113, 0.18272689572768286, 0.15144621720537543, 0.08560117581509985, 0.13669177220435813, 0.201932237832807, 0.11488741409266368, 0.20912983833113685, 0.15556626487523317, 0.1553704121033661, 0.08132218979881145, 0.17942793056135997, 0.1224193224334158, 0.0739623632398434, 0.28072154440451413, 0.16036411601817235, 0.14431692397920415, 0.09876698692096397, 0.18349815043620765, 0.07633574408828281, 0.10940640859189443, 0.15873885713517666, 0.1051051878312137, 0.17681085068034008, 0.17370655084960163, 0.1472510493476875, 0.13767467258730903, 0.12680189742241055, 0.10572286992100999, 0.2977029519388452, 0.13774808583548293, 0.2057183487340808, 0.09151154343271628, 0.1512095017824322, 0.11380787123925984, 0.1669046189635992, 0.13748499448411167, 0.1687911435146816, 0.1344879053067416, 0.16929670935496688, 0.12069359901943244, 0.1629150556982495, 0.1973475018166937, 0.15332331648096442, 0.11268186251982115, 0.11126712124678306, 0.18523783364798874, 0.15467034419998527, 0.21226173121249303, 0.0874563297838904, 0.18329500977415591, 0.10370961623266339, 0.11977067159023136, 0.08274755120510235, 0.08749035725486465, 0.1277942379238084, 0.07363548429566436, 0.10936752747511491, 0.06077026526327245, 0.1376729508046992, 0.07792433345457539, 0.1018018662580289, 0.10791614637128077, 0.1586546827456914, 0.14259698189562187, 0.14666954695712775, 0.15988151222700253, 0.12545961944852024, 0.21318218728993088, 0.20072915707714856, 0.16334363113855943, 0.12585975578986108, 0.1742844018735923, 0.08258890971774235, 0.30435986816883087, 0.16689520853105932, 0.1890330878086388, 0.12344443617621437, 0.08007820186321624, 0.0899301454774104, 0.12661621207371354, 0.11000308048096485, 0.14488298969808966, 0.11000605649314821, 0.13236125145340338, 0.14365743671078235, 0.1305108843371272, 0.09947455793735571, 0.1482642293558456, 0.1140376327384729, 0.14497862284770235, 0.11118731810711324, 0.16448692447738722, 0.1422973768785596, 0.12740339327137917, 0.07705570897087455, 0.1310549527988769, 0.09855423544649966, 0.20335451932623982, 0.17420303280232474, 0.21821519534569234, 0.1573660917347297, 0.14069999306229874, 0.12199431672343053, 0.10703959575039335, 0.09007058950373903, 0.1278055927832611, 0.12063581540132873, 0.1092676047119312, 0.23116927914088592, 0.10615416904329322, 0.11332630645483732, 0.12244970595929772, 0.1492603844963014, 0.18798603618051857, 0.10433060087962076, 0.20166516856988892, 0.15097856026841328, 0.270475602010265, 0.12149016096373089, 0.18172388314269483, 0.1199279549473431, 0.20780853345058858, 0.14387669682037085, 0.1181070065649692, 0.17674724862445146, 0.17758118512574583, 0.11672208478557877, 0.1163055544020608, 0.14696095866383985, 0.1066559721948579, 0.1263609726447612, 0.13629841909278184, 0.09412155064637773, 0.11738469649571925, 0.13003555359318852, 0.21101640741107985, 0.14173488831147552, 0.14068396267248318, 0.12432548421202227, 0.1414506754372269, 0.1034143305150792, 0.08037379186134785, 0.1575793107622303, 0.17093609872972593, 0.15605266846250743, 0.16882787982467562, 0.0980880628048908, 0.08300826026243158, 0.09302325372118503, 0.19648905959911644, 0.1465056955930777, 0.17912218056153506, 0.11037493357434869], [0.02715431146498304, 0.022969374113017693, 0.026493725817999803, 0.041748526782612316, 0.028521978310891427, 0.02617732599901501, 0.008605879520473536, 0.07497324259020388, 0.058963621777365915, 0.019016515616385732, 0.07305059771169908, 0.04806076736713294, 0.043726346630137414, 0.0065126311255880864, 0.022063709038775414, 0.04966575819707941, 0.03470440613455139, 0.005226448847679421, 0.03434560741879977, 0.011710876970028039, 0.056112308957381174, 0.014140071962174261, 0.04654751712223515, 0.016099277818284463, 0.02948576096969191, 0.04855529004998971, 0.06660436978563666, 0.09854332587565295, 0.06313314472208731, 0.020983845206501428, 0.06502754346001893, 0.024975529158837162, 0.022264261460804846, 0.01649571455345722, 0.0784221438516397, 0.024760026171861682, 0.062119396970956586, 0.019581920823839027, 0.026829581038327888, 0.024459949891024735, 0.026245345688948873, 0.031989466660888866, 0.12985046196263283, 0.011450880374468397, 0.015020293431007303, 0.04843406393774785, 0.08580991969211027, 0.036753910026163794, 0.03639567534264643, 0.015850702875468414, 0.029625919269165024, 0.05801893457828555, 0.023912398901302367, 0.022951208193262573, 0.05940152230323292, 0.04910362586088013, 0.026348708306613844, 0.034167952107964084, 0.03752851553144865, 0.05622408010822255, 0.006384655180227128, 0.007072507332850364, 0.028039422759320587, 0.0032382885638071457, 0.059354013719712384, 0.014566354166163364, 0.03445749360253103, 0.06368468661094084, 0.04415533767314628, 0.020396652398630977, 0.0497548418934457, 0.08267252007499337, 0.018547932850196958, 0.05503807245986536, 0.015601896011503413, 0.03385319985682145, 0.025753541121957824, 0.03499461185128894, 0.010446861251693917, 0.014920097928552423, 0.019080299498455133, 0.011152168717671884, 0.01721761087537743, 0.01950514008058235, 0.08234889173763804, 0.03960505215218291, 0.01945405063452199, 0.02853932230209466, 0.03238699064240791, 0.04379185600555502, 0.04813163875951432, 0.017020004779624287, 0.03292694018455222, 0.08089459399343468, 0.024632497370475903, 0.09490855372860096, 0.040878191648516804, 0.02330372648430057, 0.04761687399877701, 0.03706346353283152, 0.032493826511199586, 0.03392605278349947, 0.03460347776126582, 0.036431179687497206, 0.03409665026993025, 0.01100447019780404, 0.04139947617659345, 0.047291371738538146, 0.04018308871309273, 0.041819709877017885, 0.03858857700834051, 0.005172946493985364, 0.016612278122920543, 0.03550528737832792, 0.07711318830843084, 0.013633048729388975, 0.032791999183245935, 0.05182058768696152, 0.026116865083167795, 0.008984690248325933, 0.046142534556565806, 0.06244292511837557, 0.014790444729442243, 0.06190320193127263, 0.07293094124179333, 0.04331794647441711, 0.04891833013971336, 0.021196221896389034, 0.01798898803826887, 0.012542411695903866, 0.03713827201863751, 0.007241736948344624, 0.07695841341046616, 0.06994026422034949, 0.007175304526754189, 0.016680535300110932, 0.037244603227009065, 0.057901218824554235, 0.04310477197577711, 0.03456274869677145, 0.036810855017392896, 0.05239715479547158, 0.021211805142229423, 0.08866640157066286, 0.0439481114881346, 0.03361702991242055, 0.038788997699157335, 0.032952176916296594, 0.01413478694303194, 0.02899269475165056, 0.027533398642844986, 0.05895772541407496, 0.004043260432808893, 0.04484313787543215, 0.04040597421408165, 0.04069366033945698, 0.017393191883456893, 0.015914130526653025, 0.021551671670749784, 0.09041185126989149, 0.04129268854740076, 0.0365963298099814, 0.00846263852508855, 0.06262237642658874, 0.09100164344999939, 0.03710200697241817, 0.009140112670138478, 0.02816950454871403, 0.08044370217248797, 0.037737567399744876, 0.02280048171087401, 0.07899577205535024, 0.03387450320587959, 0.00947813310631318, 0.007204489484138321, 0.04676846932852641, 0.012621405894606141, 0.04472555941902101, 0.02753139669948723, 0.00836025183161837, 0.044624074434977956, 0.020666983400587924, 0.04452238907106221, 0.017308570349996444, 0.05965049429505598, 0.042550198413664475, 0.06918124010553584, 0.010549041999183828, 0.02697083957173163, 0.0662881629250478, 0.016385372036893386, 0.09262991545256227, 0.014794175876886584, 0.013776383420918137, 0.05185329784580972, 0.010037778320111101, 0.047547739231958985, 0.015180670616246061, 0.06391128656105138, 0.024390575781580992, 0.06166748840769287, 0.01925243323057657, 0.020642021263483912, 0.02884970701416023, 0.030678336624987423, 0.02627658825076651, 0.015200036032183561, 0.027984270054730587, 0.014132971464277944, 0.02094814790325472, 0.031531056883977726, 0.037026252248324454, 0.025375248042109888, 0.04530418598733377, 0.04094879586773459, 0.12219919401104562, 0.03215470955183264, 0.0314260466984706, 0.06543691211845726, 0.016580182091274764, 0.07746765288175084, 0.026876763076870702, 0.047149610400083475, 0.02592696990177501, 0.02725681504671229, 0.03726634073245805, 0.029719424310314935, 0.015612226707162336, 0.05702295384253375, 0.0374378955893917, 0.04924175067571923, 0.0394794325256953, 0.03163583700370509, 0.030721956354682334, 0.07732834434136748, 0.058344217904959805, 0.028688479142147116, 0.021067177258373704, 0.01880064155557193, 0.06741934441379271, 0.05473513519973494, 0.016845464633661322, 0.08198851224733517, 0.07433993829181418, 0.040896107093431056, 0.04985497987945564, 0.06988734909100458, 0.05515658231161069, 0.025853278348222375, 0.11119801245513372, 0.017280561696679797, 0.08042117799050175, 0.040384860112681054, 0.02154855836124625, 0.10501657539862208, 0.048838552975212224, 0.023713922637398355, 0.05387548328144476, 0.033357478605466895, 0.03071528630243847, 0.07792560994857922, 0.006714797254971927, 0.008223217973863939, 0.05066449972218834, 0.02087974044115981, 0.07317440278711729, 0.06050609779777005, 0.024766677670413628, 0.050618501409189776, 0.0910349955665879, 0.063960461266106, 0.028195789564051665, 0.017424811085220426, 0.015527605173701886, 0.04836448388232384, 0.05726427800254896, 0.06340569103485905, 0.006421090920412098, 0.07565909836557694, 0.008997575787361711, 0.027168271262780763, 0.0905241456348449, 0.008096770852716872, 0.02544285584008321, 0.020174637065792922, 0.031480483230552636, 0.033305895631201565, 0.07551680639153346, 0.018949406912724953, 0.014640682111348724, 0.031424870394403115, 0.03660556954855565, 0.04656561439333018, 0.017864707988337614, 0.028222701694176067, 0.0383942604821641, 0.05833343820995651, 0.048887349184951745, 0.02186174097005278, 0.005460428992591915, 0.08775824288022704, 0.03609315739595331, 0.037538909309660085, 0.0927625891927164, 0.04221965697070118, 0.030614582428825088, 0.02495731499948306, 0.009975512130040443, 0.05473434481245931, 0.07675117609323934, 0.03842698919470422, 0.04789089347468689, 0.032959431409835815, 0.040322927889064886, 0.014525355145451613, 0.02405931260000216, 0.044023788286722265, 0.04593426194333006, 0.04754098197736312, 0.02351713290408952, 0.04812931583728641, 0.03380120870133396, 0.032525761125725694, 0.03710594777658116, 0.03245844090997707, 0.05498737264133524, 0.03706134099047631, 0.043186920302105136, 0.03357824156410061, 0.04874687176197767, 0.023916044701763894, 0.04263161201379262, 0.023181632059277035, 0.01849829244747525, 0.030414983666560147, 0.0381172798370244, 0.03501436782244127, 0.07367520403931849, 0.011070591845054878, 0.05582719066296704, 0.0073618247915874235, 0.03657262190245092, 0.06384938402334228, 0.039633806663914584, 0.04948491165123414, 0.033681299901218154, 0.028911316403537057, 0.05301787969074212, 0.032109928361023776, 0.04593541598296724, 0.028187444113427773, 0.051367098349146545, 0.12576194072607905, 0.12178343546111137, 0.10352473240345716, 0.11254878801992163, 0.16836296883411705, 0.12943429523147643, 0.14609343255870044, 0.13428173668216914, 0.14055542269488797, 0.11661644748528488, 0.24862911959644407, 0.07226103421999142, 0.08646839021821506, 0.16454971017083153, 0.16084522067103535, 0.151293691014871, 0.1137759217817802, 0.1299960564938374, 0.16050968086346984, 0.10975876546581276, 0.12414658209308982, 0.07595528950332664, 0.1392313718679361, 0.07691738006542437, 0.28897422656882554, 0.1580106618348509, 0.14766375767067075, 0.21909968694671988, 0.14954853075323626, 0.09255089156795293, 0.14240224234526977, 0.20785134052857757, 0.130962599941995, 0.09442347858566791, 0.2568047371460125, 0.15673848713049665, 0.08790718449745327, 0.08180903867469169, 0.11791395911131985, 0.23023203568300232, 0.07349455045186915, 0.20828904438531026, 0.22130080789793283, 0.05310800981533248, 0.16758405516156927, 0.19481585797620937, 0.20653531973948702, 0.08487966726534069, 0.11597783683100715, 0.12361437315121293, 0.12065023533068597, 0.08268676931038499, 0.243804506608285, 0.11223669265746139, 0.10248655686154962, 0.1319266646169126, 0.10229957275441848, 0.190545673831366, 0.15022342500742525, 0.12664092559134588, 0.128361476236023, 0.08378163751331158, 0.10863729869015515, 0.21709903492592275, 0.17882827523862943, 0.0732865635654889, 0.16797577554825693, 0.1610937065561302, 0.09418156070751138, 0.1416090942802839, 0.1927339259418659, 0.19617253361502662, 0.11504059337312356, 0.2003342454554513, 0.07075103087117895, 0.17465109704062343, 0.15211846941383556, 0.23274163773749024, 0.19133696652716026, 0.19210186845157295, 0.1515089880558662, 0.10351506221923046, 0.1024349924409762, 0.09739803615957499, 0.1330633825273253, 0.14595629851100966, 0.17947763961274177, 0.13810548931360245, 0.11066584062064067, 0.16513906448381022, 0.2298424081527628, 0.14313978870632127, 0.12740017235046253, 0.22224474552785978, 0.12172468705102801, 0.18513615941628814, 0.1105765750980936, 0.18487688270397484, 0.1654804524150677, 0.12153638192103244, 0.13046825537458062, 0.12462991318898275, 0.16608861275017262, 0.11335873088683002, 0.11878821649588645, 0.13602015824289992, 0.18553160538431257, 0.18065539828967303, 0.18255868053529412, 0.13326603337191045, 0.14874331536702812, 0.15000521874753758, 0.07222980464575812, 0.11770421333494596, 0.19086071552010253, 0.09428839286556467, 0.13041062018601224, 0.1279059608350508, 0.09611596120521426, 0.10047446092357859, 0.13733134022913873, 0.2838581573450938, 0.09900681194267236, 0.10975433484418318, 0.1985984659404494, 0.12759844452375546, 0.1228334111510776, 0.12079807856935076, 0.15493389568291605, 0.15848317241761833, 0.10133733376278542, 0.1171137903293129, 0.270349852507934, 0.1271887047914788, 0.11363161116605625, 0.18418192077660933, 0.23727283522021025, 0.167502136901021, 0.10686598514439538, 0.09927728766342625, 0.12830501364078373, 0.16614526830380782, 0.1947516473592259, 0.13443344651022926, 0.14970395131967962, 0.08819915281492285, 0.10436897733598016, 0.20607107668183744, 0.13358232186874375, 0.09043821977684274, 0.09203813431668095, 0.15225257549900562, 0.14706628426210955, 0.1023729563166853, 0.10525300138397142, 0.2505520835984498, 0.10928890435025096, 0.06518573223729618, 0.19647345965495333, 0.19323020009323955, 0.1470837098895572, 0.18863884411985055, 0.10367511378717609, 0.11871610942762345, 0.12627023766981438, 0.140160407172516, 0.07776007390930317, 0.11485432914923877, 0.1424345702980645, 0.14572154235793278, 0.07555936113931239, 0.15603122039465234, 0.09324684055172838, 0.0949320501240436, 0.16645324474666268, 0.09516411970253102], [0.04161056895100046, 0.07870259403716773, 0.03749123745365068, 0.017835873695730697, 0.03978479289798997, 0.011730996593541931, 0.0698914383247029, 0.022382871502486523, 0.02113806905981619, 0.08335132544743828, 0.06963594656554051, 0.031048234159243293, 0.03175597215886228, 0.03268496293458156, 0.04038683793623932, 0.004987549655197654, 0.07588558699353598, 0.029482360077963676, 0.009100895731535275, 0.038614875011262484, 0.03302724886452779, 0.04617591264832299, 0.01634907730476698, 0.010071380911540473, 0.0459884090378182, 0.08805152479908429, 0.039286129031097516, 0.03166381226037629, 0.019671531445055734, 0.020873907160421368, 0.055777563247829676, 0.018502864077163395, 0.049842511798487976, 0.055634963282500394, 0.013051780115347356, 0.057295114238513634, 0.026677559508243576, 0.006466739960160339, 0.01763837706675986, 0.05312114211847074, 0.034500233887229115, 0.05146160343429074, 0.03738372994121164, 0.012346751882432727, 0.01180252942504012, 0.06453672409406863, 0.048291285856976174, 0.010019929668487748, 0.016432704360340722, 0.07135043386369944, 0.030712273182871286, 0.02952944934804691, 0.036142907265457325, 0.019196048560843337, 0.02399881457677111, 0.046951664771768264, 0.05752037832280621, 0.051055759977316484, 0.03523277446220163, 0.048201408062595874, 0.0073980972592835315, 0.032927010688581504, 0.05832564565935172, 0.09923540827003308, 0.012944896934641292, 0.029845420576748438, 0.041580174292903394, 0.0387524877442047, 0.09783419634914026, 0.04061554929648992, 0.0191732386520016, 0.02112161193508655, 0.017543124267831445, 0.05469458053994458, 0.013876832181267673, 0.05987710537738167, 0.01637687444599578, 0.03632074069173541, 0.0438228666462237, 0.020149244483036455, 0.06176162241899874, 0.03978545340942219, 0.0594122166512534, 0.034384696336928755, 0.0341604230197845, 0.03111583268037066, 0.02732817254582187, 0.03562478428648319, 0.03988076372479554, 0.022447171177191194, 0.03524845975334756, 0.09999261412303895, 0.03707184238010086, 0.04875742881267797, 0.0176148194441339, 0.05531261514988728, 0.03147145500406623, 0.04219775248202495, 0.16999921150272712, 0.052502877442748286, 0.05090075130283367, 0.041898110357578844, 0.03752000680833589, 0.02754041564912768, 0.03169501214870252, 0.03320494870422408, 0.049024323670892045, 0.006841644208179787, 0.04061384606757201, 0.007896219358372036, 0.11664216290228069, 0.03296292692539282, 0.004784896491401014, 0.08033551188418642, 0.044178136449772865, 0.01910329494421603, 0.028404741242411546, 0.029349202086450532, 0.03442787077801768, 0.08153420654707588, 0.03162010347296018, 0.04274560960766394, 0.04698626740719192, 0.034925870422739536, 0.04332912321842741, 0.06360268671414815, 0.02882629411033122, 0.03345546807395294, 0.06619421445066109, 0.0847787871316541, 0.027303696515446063, 0.021834743492945563, 0.03210128234059084, 0.06830170605098829, 0.02514156985853333, 0.07282649879925884, 0.0730353243125137, 0.07103018971974961, 0.05734517952078022, 0.05782585001725238, 0.05973991195787676, 0.049131437845062464, 0.00937226945097791, 0.03778502403292805, 0.034477442532079294, 0.017929653331520967, 0.0729072222020477, 0.02821715042955475, 0.02707435989577789, 0.006360312736433116, 0.0359883884084411, 0.09379251205245964, 0.013243418416095665, 0.047909098357195035, 0.021395636977104004, 0.049441351293353364, 0.03096356438618386, 0.06908252704306506, 0.061506843121605925, 0.036054016527486965, 0.06998639611992985, 0.09628767933463678, 0.054300036281347275, 0.018880390889535192, 0.06272518614423461, 0.008626675426057773, 0.05923595657804981, 0.04601048793119844, 0.008452841248072218, 0.07197172279120423, 0.03741685941349715, 0.03483357693767175, 0.04778720060130581, 0.0347417621378554, 0.044422982100513764, 0.038421957433456555, 0.015001777774159564, 0.06302439782302827, 0.031120936801016796, 0.04162574958172627, 0.013596536919067148, 0.014510906457871897, 0.021574030724877957, 0.020146732313151006, 0.055128907624748535, 0.0607707625022158, 0.006279338394961087, 0.03238774763303809, 0.061062341192155145, 0.04182679738732986, 0.028129103884566575, 0.0640232914884109, 0.07970624486915767, 0.05725996241380926, 0.018975113052874804, 0.05219149083131924, 0.06226250159670599, 0.0705683215346653, 0.0225411641804385, 0.033770468944567256, 0.018792481641867198, 0.04452775479876436, 0.10621129957144149, 0.033591240280657075, 0.008163949132722337, 0.029496279057639185, 0.02022108994424343, 0.02817255663103424, 0.03546267696947325, 0.05405710166087374, 0.025032748744706623, 0.02270305441925302, 0.026273964758729562, 0.003677468366731773, 0.010990724695147946, 0.0312555197160691, 0.037206757406238467, 0.0327361674135318, 0.02011095708439825, 0.0432286475552246, 0.021613681819872, 0.011565000422706362, 0.044555080676218495, 0.044897481639054604, 0.05271138754324056, 0.017668304171820637, 0.06716533694998361, 0.031770221394253895, 0.051717681490117684, 0.04236883978592232, 0.020004228827019688, 0.022290605847956613, 0.05840674013597891, 0.011971614785579732, 0.011332354752084939, 0.05267139320494607, 0.01614362670807168, 0.017506226540717762, 0.022188087423273828, 0.0679812095768284, 0.0179866799589945, 0.06251005979720503, 0.0017150247754216252, 0.04396214550069999, 0.04340177205449436, 0.10724267704063095, 0.009586345659045037, 0.024509330542059615, 0.027617699197435286, 0.029005279720877297, 0.045761181972920895, 0.07190488497144543, 0.007646627209396684, 0.014353954284160864, 0.023894002915767487, 0.05720529952668585, 0.03967156713770237, 0.01330482000412303, 0.03966544070863165, 0.06814172127633356, 0.059049276751466095, 0.06439604258048348, 0.0417440590535989, 0.024483910128765274, 0.03548325672454666, 0.009110213395615574, 0.04067109905008692, 0.1496212909114547, 0.02849782511475496, 0.022584620637644548, 0.037942912240396254, 0.07685709540965036, 0.04420225624926388, 0.033029571786755696, 0.023478810253436677, 0.05191455842577852, 0.05817344230308663, 0.018992870791407768, 0.00786762626376003, 0.08792293287115172, 0.018496952870918903, 0.027382436528569087, 0.04207556899928022, 0.04546336553175934, 0.009891491736198077, 0.012927790430694586, 0.09304080551373772, 0.03327704092953354, 0.034223668844788335, 0.04647559188015293, 0.06683177125523798, 0.030421638875850476, 0.008442615380772622, 0.019932845352741424, 0.07827700945199467, 0.06591361583559774, 0.10825804638443515, 0.08657015350763686, 0.03755540354177356, 0.007021197097856202, 0.02073731488053454, 0.04777898131578695, 0.02762911157333292, 0.07397776280413382, 0.06933194061275572, 0.004225744805808063, 0.01735336638375884, 0.015345548927143682, 0.06313770150882192, 0.0038224007630560664, 0.026901816127065104, 0.08558753514080308, 0.03475688710750546, 0.03841160818410572, 0.041242422885261476, 0.013397592174442252, 0.007485241167159984, 0.07048652943922207, 0.06014105019858107, 0.06649365619523451, 0.026432589547766838, 0.032747622462920845, 0.08721366233658046, 0.07055523004964925, 0.06132295005954802, 0.04237779008690268, 0.030662593817396555, 0.03701883448229637, 0.042073416771017946, 0.05944209922745358, 0.11519277817569673, 0.044346451832097955, 0.01677737815043656, 0.05169823351025116, 0.025266955708502792, 0.07841071477741934, 0.06158746262372006, 0.024302597885252908, 0.07901138684246689, 0.010729643636295805, 0.029082420405757148, 0.016180192324100062, 0.04170950094703585, 0.026169386874244083, 0.05083347932668403, 0.02641182240040507, 0.044740929297404364, 0.020797627366846427, 0.07811712857801467, 0.023809264494047966, 0.04037214341224171, 0.0576477271533804, 0.140423157135956, 0.2380199107574299, 0.07824527521734126, 0.06586667499504983, 0.0932833542174194, 0.1506044139387086, 0.21924897737335414, 0.08120490820147097, 0.11825151756056584, 0.1839046840905212, 0.09852521747234277, 0.1209875859785825, 0.1067290514765773, 0.12777559517417103, 0.09445474526728503, 0.14706307818414643, 0.21405671926913783, 0.10877514519961551, 0.07188051284174435, 0.07509202332585119, 0.14304124633781612, 0.12620152963791043, 0.09603197977412492, 0.10044919821666554, 0.09562465944327414, 0.22299603646388277, 0.17614466923987493, 0.13737604720517993, 0.06904525638674386, 0.06310043827397749, 0.1843990435008891, 0.09321388919488527, 0.08531380881322548, 0.13244971545645967, 0.13208006654167548, 0.15413912973599508, 0.15385545120807365, 0.08768633619183674, 0.1672290710848756, 0.14016267814440653, 0.14795459050219506, 0.17047733272193, 0.16325631004292518, 0.12515486392658204, 0.07778869854519144, 0.1355279955896549, 0.12419525213772431, 0.1495066290954128, 0.1417110356851481, 0.12171175141702406, 0.0856452519656159, 0.22799451980972663, 0.16273063200060278, 0.06799344759201631, 0.1231297581398394, 0.12027089396724477, 0.15020386199466884, 0.1383550142054446, 0.09993572850362398, 0.16462520143250003, 0.17834743775893003, 0.0871361895406153, 0.10222385884844698, 0.24221528641646728, 0.1833164133131504, 0.11404618970118463, 0.18778809055220336, 0.12586903263581917, 0.21085761749418452, 0.13782507623545825, 0.1287265683640726, 0.11997669920674525, 0.10178976182942279, 0.15835486992727965, 0.09191098215524107, 0.2798781677847728, 0.11937186369323172, 0.19715504808118567, 0.14318266999907792, 0.10150393107323907, 0.1686387212248519, 0.14346400334034115, 0.12335059160250239, 0.20950984762748703, 0.18831881519872695, 0.12664582376601174, 0.1458416663808748, 0.08957706129876897, 0.07670221661101095, 0.12301141527132131, 0.1303676498355344, 0.16308796126395464, 0.11276127232122235, 0.14140230225166306, 0.0912741526553873, 0.21205413766438141, 0.18545598053606227, 0.07296810057596304, 0.3207835665671155, 0.16002124379156157, 0.13672166591277346, 0.16195517673622817, 0.11992462270427495, 0.18348651356063783, 0.1406597686582245, 0.1528539229184389, 0.08147133921738714, 0.10567195859039202, 0.0843498480389826, 0.1385983792715706, 0.2636518806684762, 0.17386419785907492, 0.20829407614655793, 0.15997054026229307, 0.2680614253040403, 0.08460729164653458, 0.14355317980516702, 0.09004318941151723, 0.15084696264239028, 0.19433834531810135, 0.12699893763056025, 0.14174559008097276, 0.12127093054004945, 0.10640321153914556, 0.18796558259055018, 0.14933344151359051, 0.11743711438612081, 0.1981110530323349, 0.20924945769365877, 0.15463130723219365, 0.12269275190192275, 0.12136653400375508, 0.1423141494160518, 0.12028185548842885, 0.20324831799371168, 0.1809859211789444, 0.09398733323905617, 0.18193140247603878, 0.14591383282095194, 0.13693200540728867, 0.14559608971467242, 0.1090221616323106, 0.20960450114216655, 0.1558115001535043, 0.12268009086255915, 0.08225768920965493, 0.2632788772461936, 0.15517780993832275, 0.09545827735564671, 0.09573006667778827, 0.15337980876211077, 0.17722894699545577, 0.11400354589568451, 0.13168068719096482, 0.1927215320756659, 0.2504237514222041, 0.13382130826357752, 0.16893568419618532, 0.10354847370763309, 0.17039732920238748, 0.16306875448208302, 0.13507007563021034, 0.30911522393580526, 0.055261176894418895, 0.18461940198903903, 0.16583404125412926, 0.19492897612508386, 0.059575830528046936, 0.09479822605499066, 0.1539863512152806, 0.07438150598318316, 0.1290853225509636, 0.11242807770031504, 0.0940310383157339, 0.17721015581628308, 0.13982845935970545], [0.04077940437127836, 0.02133219448296586, 0.04726335566374473, 0.10031771191279404, 0.06336669859592803, 0.07407802695524879, 0.02779926006041933, 0.07350527448579669, 0.07862457947339863, 0.012431490304152248, 0.035857046823366545, 0.06633680328377523, 0.07342851415160112, 0.07229991533677094, 0.034664062986848876, 0.020989040240237955, 0.03255141346016899, 0.05561650606978219, 0.054201861275942065, 0.06310771874268539, 0.022665186334052123, 0.04372473616967909, 0.056378777080681175, 0.03088958896114491, 0.0635410810355097, 0.06943201922695152, 0.0478799356642412, 0.04292138357413933, 0.04433704511029646, 0.01519298748462461, 0.05457096100144554, 0.03941569688322488, 0.030863845713611227, 0.01996052003960358, 0.02110226600052556, 0.027325907140038908, 0.02698938213143265, 0.09549069436616264, 0.025794880602916237, 0.0522518534125993, 0.040928182716015726, 0.0691912516776938, 0.030737736269657034, 0.008943709781306097, 0.006767693830624921, 0.05158416912308894, 0.0203542201052187, 0.0073232145587098785, 0.013602129001810681, 0.015559809744445374, 0.02968853797938209, 0.04336932906880975, 0.04566653216897976, 0.04413274669786915, 0.039563061436638236, 0.07970099046360701, 0.007498422173739527, 0.026442951784702018, 0.035716157508431934, 0.035802628844976425, 0.04517493725870736, 0.02301315154909389, 0.027300130495859776, 0.05539856698305812, 0.07103307667421177, 0.06420339588657953, 0.09530577342957258, 0.0341313419630751, 0.008189184009097517, 0.018900705326814204, 0.038044464017730206, 0.012730230719171232, 0.04362754450994544, 0.01743147186061833, 0.025716307573020458, 0.021588511881418526, 0.05816465898533352, 0.024014162190724164, 0.008760030086705228, 0.04549392717308365, 0.060638886570814066, 0.04730228873086162, 0.017430559018976055, 0.057675524294609204, 0.007730971365162986, 0.02224521424068371, 0.08632123717688955, 0.07336713853874244, 0.0541974714724347, 0.032375865848734975, 0.02358327867113985, 0.034801312067429535, 0.025017280531756114, 0.0863044275320135, 0.044958649450563826, 0.04082384788489435, 0.08810791317955591, 0.08197448565624654, 0.07974669933901168, 0.02202822139224736, 0.056574715199531056, 0.05140246168593876, 0.049699555602273904, 0.03861516073811799, 0.022654076383332722, 0.03690575344080571, 0.02932264433184173, 0.016378794753109105, 0.04002192021289375, 0.03948835685150698, 0.06106792585342191, 0.04340116720413789, 0.06476336857303977, 0.026021846060757525, 0.05930368868575897, 0.043858055578311905, 0.045695553853875026, 0.022316603281069547, 0.012967360817128792, 0.010884241346502677, 0.05908122991968412, 0.017044423293555155, 0.008271786900877487, 0.04325285270169843, 0.0077379424510581885, 0.06322095563518815, 0.04903410888800863, 0.029399089253274724, 0.03410039069422055, 0.08558965026168153, 0.07049135339912027, 0.045078420953359455, 0.03680555979372002, 0.00890033496034448, 0.021363769155868795, 0.0774007111613173, 0.08612309116870165, 0.025858692315523513, 0.061590765180881135, 0.008210690521082142, 0.06254502979572862, 0.08021523943170905, 0.05412820682977326, 0.03611967804317828, 0.0156261994925444, 0.006838494718977017, 0.006880966902826913, 0.04206685989629477, 0.040432324167340994, 0.0148954038922966, 0.01266062190552475, 0.03140782697300892, 0.08070759504335001, 0.05377868495997973, 0.023428637359756976, 0.049835027239168994, 0.05970081932900939, 0.05090675527753774, 0.015936680683807936, 0.017295625439146534, 0.06088081187044736, 0.004021733975605457, 0.038822598435217515, 0.0419826632423792, 0.025522408504912164, 0.07266234315466136, 0.044214835652383044, 0.07389404854620807, 0.06705362146021798, 0.013485834460880142, 0.026037050811282825, 0.011843752945424058, 0.02602226537419483, 0.02979341457830742, 0.04010229851701297, 0.04320428655773867, 0.04496145105804317, 0.01262213227164466, 0.035514553092070855, 0.06970359332626686, 0.083520653861342, 0.053922220031381585, 0.06561222966411151, 0.016988424540613778, 0.04685166037234012, 0.07016935778665356, 0.03796309123572428, 0.06168893276480958, 0.02079654012050014, 0.05978808105282951, 0.05156384169822559, 0.03386446194781456, 0.029881071495765354, 0.08660034407512285, 0.07755275495583192, 0.03570242777641397, 0.010485621769475983, 0.03054580945899943, 0.05484043482283596, 0.04004114554845728, 0.06134400478913449, 0.01502881050328142, 0.0632824499916751, 0.06698513607261702, 0.06966926157474518, 0.06025323695212137, 0.13429548125714064, 0.03154865320539102, 0.012515889193309704, 0.041365797515027225, 0.015154328084463486, 0.0056039645278360695, 0.018363390408921987, 0.05497852624102961, 0.012389357652864419, 0.03705838353198487, 0.04866668641625438, 0.07740274464595132, 0.004639798735297518, 0.014708724065712886, 0.010682997799449367, 0.05306205232045613, 0.03930785540433135, 0.00914815940632252, 0.02967393993458245, 0.04176575574092567, 0.022558600940101314, 0.003187591760251962, 0.026137658205698244, 0.08941398176830262, 0.03882822762534488, 0.015025455068098381, 0.030969097097113263, 0.03992471371020656, 0.016934036248130724, 0.025201342432410456, 0.04609245814208407, 0.040533794308430515, 0.03920083770935889, 0.028879110905108973, 0.0026278804489265895, 0.009858477296802448, 0.0922358276147861, 0.015785889263497666, 0.05039018709794618, 0.030462718605122063, 0.06836164189735427, 0.014963136927690357, 0.04182169141131453, 0.03431771750911139, 0.05070094659458846, 0.05400549642217811, 0.021152027002244722, 0.03390860860235989, 0.031866823046584614, 0.03727897950739134, 0.06827184944995679, 0.009145688982243882, 0.02203097476012772, 0.05535947064345237, 0.023184378005680628, 0.010876030410145177, 0.08359905434190296, 0.09656481212005019, 0.02449572511977749, 0.07469990217941813, 0.032002684311009943, 0.07830200498574413, 0.015536625978711527, 0.04183961798844393, 0.04268444921763148, 0.05040774631197564, 0.07462888606823981, 0.0972375541459769, 0.07703999770455994, 0.0054759612157795345, 0.03112779239017982, 0.03351938554260414, 0.06825307311373763, 0.03318193099403288, 0.03506382454361301, 0.04864540904236492, 0.07075339832226746, 0.013068382886558538, 0.03611208587244619, 0.007152400921768276, 0.0587771200662246, 0.013046361509623239, 0.08323542424477637, 0.08685366134159267, 0.052741926920134574, 0.012969026938662864, 0.017018611397361383, 0.05778148813988082, 0.02882646665966604, 0.06731325440341607, 0.05857281794305891, 0.040495132125215605, 0.0026151653719352908, 0.06445186692872085, 0.025241405419365037, 0.03508108689857181, 0.0576347803871613, 0.028197490937600378, 0.03336869245686103, 0.07808697511791252, 0.09065938720596023, 0.015581895131617785, 0.015026033943286166, 0.018474573407729622, 0.043063783159595914, 0.02698831714951666, 0.05775893427198753, 0.04803264368092641, 0.04715045644843485, 0.049106650112662464, 0.029469943947333377, 0.04617022779711988, 0.04594279293087311, 0.03917014619219117, 0.02053162308584433, 0.018073292303597555, 0.04939751263009384, 0.07210413677967153, 0.010468130276422016, 0.0372233703819802, 0.003599952665354067, 0.05660003356751986, 0.018766899811453186, 0.013505677634384483, 0.03322738011775073, 0.06815034503233619, 0.07373435320914723, 0.025720491430547554, 0.025878643100440968, 0.0022527129704030813, 0.06956395081942901, 0.0686856042011641, 0.053297880876925774, 0.03448857103649061, 0.017382799960614648, 0.024064286844804883, 0.061081770618329756, 0.09293575451010838, 0.0468417935189791, 0.020555529517878313, 0.03162229651934467, 0.034233090409543365, 0.010489562573638977, 0.023165982020145748, 0.02410495468211593, 0.02114716964570107, 0.20397228305228055, 0.07251352770254016, 0.16630671510938555, 0.20581310614943504, 0.2170959030627273, 0.12795528396964073, 0.09652028325945139, 0.13515506638213992, 0.1497173693496734, 0.10312552374671213, 0.06742017561919056, 0.19551859761122614, 0.13822464854456484, 0.16852391097927466, 0.1865677919704467, 0.10259787901304662, 0.05585520302702207, 0.17290007381234318, 0.1709159865276888, 0.1565412391209975, 0.09216327525791712, 0.20192589989164844, 0.15241981105646119, 0.12889531790278852, 0.1459851977415383, 0.06900083884829655, 0.16789718210930005, 0.17663456092122942, 0.13752404629485682, 0.17250716598937288, 0.31250158441253006, 0.09391403131303377, 0.13117909926222637, 0.12416578145348467, 0.13553240394685417, 0.08473672220134176, 0.07281638332642615, 0.2073538047261536, 0.12053141006617807, 0.22797658952185884, 0.11938680312596262, 0.15253901481628418, 0.09186111725284718, 0.0705509701219853, 0.07664797303732485, 0.213611519720871, 0.07510520386858843, 0.16048927180236205, 0.12207760795718059, 0.11043717749998905, 0.08494703943142667, 0.10002938011894003, 0.12639190535992384, 0.17963132355362177, 0.1798710966249928, 0.18864838813897222, 0.17740584531566128, 0.11933871195651591, 0.122869086189894, 0.16499363322509453, 0.22567453648662195, 0.1353442991967313, 0.13014031515922397, 0.12181539976154454, 0.13363173406105489, 0.19976396433776245, 0.1540679280878976, 0.12475169962272048, 0.1558215933619067, 0.15429032006068155, 0.16783858212875202, 0.141941977199167, 0.10537179696257226, 0.11999491893220693, 0.12478512595407665, 0.14682052948046476, 0.09222146705724299, 0.16252933186478913, 0.08114415599266067, 0.17542960995342582, 0.13633969734655693, 0.10717075550928712, 0.13762754620984197, 0.18512073758756742, 0.08761402874370106, 0.08704689433216117, 0.19826497446047142, 0.146685428917408, 0.1175440801307559, 0.22381149348802865, 0.1564532649354078, 0.11444909425335936, 0.10924867252469994, 0.2819899935275316, 0.12909007229609415, 0.1546295260777697, 0.2180136725655757, 0.1837842186796479, 0.3287441987777129, 0.11390852872864343, 0.18917397712357342, 0.17085619911085814, 0.15436112094903365, 0.08061375046963803, 0.13890024041756988, 0.11402204763726331, 0.1975224557099864, 0.07577037598821335, 0.13555380748584867, 0.15174156229477376, 0.22540304402355105, 0.2740203368011862, 0.17360104713588953, 0.14560913667082787, 0.22527851164340973, 0.12414037031703629, 0.18181570165324956, 0.1085931334819179, 0.11811447999207303, 0.12552626430988312, 0.23616730235517025, 0.14485401625279337, 0.1321965391980484, 0.16395281563745812, 0.16437367274193093, 0.14380797394551337, 0.13327888736966997, 0.08163180638803169, 0.10900990877416916, 0.1564192003570497, 0.128146490897052, 0.10758313728729263, 0.19227153825340793, 0.08795712361461483, 0.07566781117930077, 0.16591821564361453, 0.16059780347859487, 0.12863817857578397, 0.1606090395944193, 0.10157797514693812, 0.14245699800085276, 0.16900387272471562, 0.11963022014242597, 0.09843566993367858, 0.20251580339390785, 0.1580161091987975, 0.10850225749891251, 0.17538658023113385, 0.16934640356339514, 0.08872738384525292, 0.09840607308433391, 0.2626280434196815, 0.17517782893264666, 0.14304354699561372, 0.12272100546397269, 0.23765912308590487, 0.11331790534313768, 0.07213206379674375, 0.10464690421940759, 0.1153563178377226, 0.1484924100805074, 0.1909943763166666, 0.13708113256143406, 0.08373496384592727, 0.10661213353159837, 0.14745549618965015, 0.10544587072217837, 0.1554377842694521, 0.22131631878437474, 0.06840828587883152, 0.12834139371989295, 0.14779584511416033, 0.21085176937049255, 0.0828178548545111, 0.15183247538516298, 0.12276212044525892], [0.04935620840115007, 0.04086961242137477, 0.03504250264086295, 0.018019026465481147, 0.02158425937523134, 0.0204682436742587, 0.03847845713607967, 0.016638134547974914, 0.00933712412006571, 0.011215369086130522, 0.03675737956655212, 0.053503596791415475, 0.037816543044755235, 0.03282857593148947, 0.060461320317699574, 0.04811125196283683, 0.013462415990943555, 0.10574551284662448, 0.02029078132181894, 0.03744122412172146, 0.01758882757712854, 0.03172387798258569, 0.008553740863135317, 0.018855219095712528, 0.0025670853347037337, 0.022083941839809995, 0.019647856934170704, 0.05957232388027478, 0.05875656999705825, 0.10586513963062316, 0.025744418271642644, 0.023510514802183025, 0.06246576100238599, 0.029890507903473917, 0.03563949365343433, 0.06227400488569401, 0.0455211380176479, 0.03993813174020033, 0.05614899331703782, 0.0562935636844486, 0.012529876821645303, 0.025876732070173603, 0.05415300569438841, 0.035474640390020795, 0.01867099021183094, 0.033170041788253, 0.03327871447254438, 0.018211344759038184, 0.05031742693972774, 0.010407739864604082, 0.00709134025782987, 0.015383077479782514, 0.06027337884006556, 0.011874552074004896, 0.07693151797866449, 0.01889886480057612, 0.07617813418619335, 0.032275831763399765, 0.03821118749328889, 0.04019923413579818, 0.01292280969209969, 0.032017419653129764, 0.0305146763639641, 0.05426594572782051, 0.03796225260884967, 0.04425723454914987, 0.055286502683884464, 0.051787628908641636, 0.038808334356872365, 0.04482716314669233, 0.021660873135260772, 0.029207756160758436, 0.014908434150129324, 0.04344501699961256, 0.05451971941511147, 0.004521929913607892, 0.057153883535647765, 0.04171367923845537, 0.0397787443944253, 0.03257627540733665, 0.06750239816028625, 0.09877267919364385, 0.057627659480203874, 0.03584539139410481, 0.06134004543127958, 0.04951723589329049, 0.029175565505283885, 0.023954859025252517, 0.04093357812962495, 0.0450964922492858, 0.0533304760028841, 0.0880400808819104, 0.06844878487754613, 0.043984309741063043, 0.0731119436386507, 0.055092950569815, 0.04057106125401333, 0.08098671678453684, 0.04807445999176707, 0.0430098958167946, 0.0684413782437332, 0.020494526834227145, 0.014247941271605669, 0.018867783655878156, 0.04842333619308192, 0.008197993302019313, 0.06623669498367235, 0.036341954983072355, 0.048973256489261985, 0.06443464910262264, 0.010348314244765788, 0.055010123178362846, 0.03377071385330055, 0.01932962772116298, 0.03737248640391044, 0.0120973976845562, 0.04098390316357836, 0.03331326515763067, 0.06474097055615857, 0.023732878944429103, 0.004533680430540699, 0.04557298816507682, 0.033590093662496656, 0.1111220165330451, 0.055723616533214226, 0.03677772925584577, 0.011318213128106436, 0.04450756838195957, 0.06234475382370874, 0.016141209162015002, 0.028551790383062325, 0.0339298971084645, 0.05810721304442268, 0.0430092093301937, 0.04728923806396779, 0.010786510702018859, 0.05783683751360513, 0.048457111333846115, 0.007795512701704865, 0.0326803727512015, 0.0261848754962557, 0.07088689584634267, 0.026541475599515252, 0.02079387766571017, 0.03878360228554811, 0.05253500130493194, 0.04312964134442154, 0.048290287668351084, 0.03823496590484865, 0.015939090808387846, 0.04772801803483162, 0.025015248902491294, 0.03273970003647264, 0.06721532801748253, 0.044122846447862685, 0.025934697514458094, 0.11298930461634882, 0.04649498048820533, 0.07589317916426808, 0.021403661448857747, 0.08447924890788272, 0.10841534458450042, 0.030643316531495657, 0.03830503577773925, 0.08382429616176523, 0.0377987129468238, 0.030366944447450805, 0.0404278527275892, 0.0404557389265392, 0.04429601176525466, 0.07486629910999909, 0.052084090930293314, 0.032841392821865156, 0.03713509562658146, 0.055938431178219616, 0.03397570246306714, 0.053613464333466254, 0.04353373704361729, 0.013163099483790575, 0.026489872216188814, 0.0783861125819385, 0.1556469066417776, 0.07919332434539683, 0.047870436173980124, 0.016389340671594255, 0.011035264687961899, 0.04793983811396174, 0.037975848754285835, 0.05576073133852333, 0.037305930600268766, 0.023921109859657008, 0.024329689986188896, 0.013305424854479497, 0.08852813945850357, 0.040273478589369915, 0.03371416591107845, 0.02757439488050295, 0.04310680917114951, 0.09209822601405904, 0.04744355654111132, 0.05047890714195091, 0.014285315828601597, 0.06746672312146984, 0.0386576078744838, 0.04880481865257025, 0.032176428503589705, 0.048702992280595936, 0.02185819721489679, 0.04813313047634438, 0.018321718816878274, 0.02968068791233236, 0.07488438524887897, 0.023731094079266768, 0.033341310918331146, 0.008276125681732083, 0.049382380238967016, 0.032883346430025995, 0.04593566460243892, 0.04399246223329101, 0.015070068347995402, 0.06161900018923916, 0.031142913649091497, 0.02842910966137424, 0.012407264748617308, 0.025620331180107314, 0.041642833821242675, 0.01815881554648513, 0.03021675416675862, 0.06318264597211964, 0.0349749894667184, 0.07717794069321826, 0.04374929754703771, 0.04662951330828946, 0.03346629600855522, 0.04090003305464052, 0.0867026268679183, 0.012097391190764029, 0.0564056613802677, 0.06441685982281342, 0.07414775915094651, 0.03383339935680851, 0.004240067792125046, 0.03814977848378476, 0.014923239996278426, 0.0077854269147792365, 0.032843789958860725, 0.010695874061639188, 0.042670485709095374, 0.006967768031245214, 0.053557636274490505, 0.0839211093261838, 0.03708427706442308, 0.025608408577681985, 0.03361335628142115, 0.029490102533600293, 0.07552909635705873, 0.10249640516121872, 0.025655857789388392, 0.06553612241987139, 0.02748125720245298, 0.012983297510800185, 0.022970973441260867, 0.014854737910354743, 0.018992061850440223, 0.01770084178133402, 0.04645178749342449, 0.06766646474716254, 0.05768122027802747, 0.027315505940350704, 0.04223167234158609, 0.036124464895692654, 0.05659644528350327, 0.0516630779748084, 0.13657307310495526, 0.027093902499473188, 0.059184978454140946, 0.03603203411330469, 0.016202391816477757, 0.033531300723552704, 0.022774680946895387, 0.02478754129697336, 0.04648896538128611, 0.03838241580524482, 0.024647969294164795, 0.07082550539053045, 0.03822144768491853, 0.024408012541243806, 0.03593062705476768, 0.006006793473716243, 0.023106088847271167, 0.010002348190027988, 0.03500129489111714, 0.02201870705903275, 0.0349544950586278, 0.06660250699496828, 0.037547603569692, 0.0650959175254684, 0.1259227641276084, 0.03368145946296863, 0.11452397695393302, 0.028134725653217174, 0.06864604030852206, 0.013510153712559259, 0.01827635132940486, 0.03156040511385072, 0.05696949323464651, 0.04509060330747161, 0.027139971316501033, 0.0662152394943405, 0.017288318995269947, 0.02174657263822155, 0.019888021488441154, 0.02410588236671174, 0.022396285821741913, 0.03582101555366535, 0.01702556346572237, 0.041366346704307944, 0.08814957735012285, 0.01236157071616617, 0.009423896954103839, 0.03637306952441577, 0.045788771312800236, 0.020984106813557446, 0.0228550611063838, 0.026241308405587915, 0.028329839988145977, 0.045378890572465025, 0.017359131015837193, 0.06367589958244935, 0.030173576014931314, 0.04854753460676875, 0.0690521954675205, 0.10152190588996746, 0.054229472880251706, 0.027626844312180765, 0.03987959855294321, 0.02327495712961536, 0.034268379531567916, 0.04968237117282115, 0.034977408868144266, 0.054598071656073444, 0.011998158624919597, 0.04398366407258436, 0.012244925510458415, 0.03576298331608996, 0.04058047539729159, 0.03160556108923629, 0.024127896322170272, 0.009929742955137044, 0.07179331048973836, 0.04980294419510756, 0.021025487112638075, 0.11842777763376944, 0.14822011609794572, 0.10287570199579932, 0.1483497247681953, 0.13335954397916794, 0.3684200072893873, 0.10284804957336746, 0.09436961350729689, 0.11838380538392812, 0.12635896884603426, 0.1598749219556339, 0.14890960097545758, 0.17580046114744619, 0.1692566927522421, 0.08681489154696465, 0.23560034605907276, 0.17066760454326868, 0.16468448418891057, 0.1805931024136953, 0.16769402660429478, 0.15140878327656537, 0.07406728065689094, 0.20894384128041565, 0.10528161117690615, 0.1752431082422845, 0.09064891550224274, 0.11358687450410798, 0.13974422559840605, 0.1345160327036865, 0.14362052228534594, 0.1824019686318934, 0.12630425771931186, 0.22989435849012807, 0.125751328014303, 0.1883423115941696, 0.1370502295321785, 0.10591336438665166, 0.13912659545894712, 0.1747483926010318, 0.13458015426294878, 0.13169849873520434, 0.1186497020535171, 0.15303327032597736, 0.07725188828771934, 0.08762519064475782, 0.09906118910294026, 0.08225321405916475, 0.07012007918092422, 0.09923361969413236, 0.10721206344896927, 0.0718811659316998, 0.1274879090487957, 0.12881222704891115, 0.12744020379614085, 0.16740516788559034, 0.22797029610956088, 0.21011984848883003, 0.10714456511777826, 0.15968451654771343, 0.12863610056228936, 0.11293503877823241, 0.12304225150728598, 0.16971562203252688, 0.12319688539719209, 0.13142562587745488, 0.07753103971481323, 0.15024071704829112, 0.19525765848811716, 0.07219567327410914, 0.15186220582108945, 0.05801506056741346, 0.13850010407622904, 0.11124651180580258, 0.2212527018855326, 0.21204765129368752, 0.17511922895209864, 0.11506615293910727, 0.09551462120725773, 0.09361445598187856, 0.16506254905834794, 0.19621228304458782, 0.1445898858946748, 0.11842618943774141, 0.13421662064502016, 0.10941729589831084, 0.11030707901227288, 0.08990756934508681, 0.06944127380847931, 0.15043947903905064, 0.17399251519236714, 0.1731969031970948, 0.21674452582374215, 0.15784553397679701, 0.10859305926715024, 0.12079485764843412, 0.2104784394032322, 0.16108984738821164, 0.32968206563964486, 0.12350975259323604, 0.17434423381928355, 0.11311854963423684, 0.19724517449503765, 0.07543930390966125, 0.05446870418381877, 0.1688995712902397, 0.11987148493062705, 0.17988254054216668, 0.10588411634671502, 0.200804841297213, 0.08398886740906164, 0.19324387045344338, 0.19784886710112914, 0.20264076621970162, 0.21417169278720394, 0.09712480707094073, 0.16728829446947202, 0.12732104456517845, 0.178534904262051, 0.15211233927402645, 0.1053232308186125, 0.19906814151909202, 0.25753456517122686, 0.17275859077926725, 0.24691149301361293, 0.12697465455858037, 0.20047982514370233, 0.09785946647753008, 0.18809012981364504, 0.11177007472724654, 0.10531640305998735, 0.16433010867331177, 0.17123264609836042, 0.1257886431994848, 0.057641352104838006, 0.12758777244016528, 0.18777189688989893, 0.17568772891536355, 0.1485881768167019, 0.2392845303984359, 0.18918041896540672, 0.12162070474005304, 0.16714829573174939, 0.20186718116747215, 0.12117864447645843, 0.08286128533654846, 0.201208213402424, 0.09368625134811737, 0.15325855667470023, 0.12482107558753341, 0.1917198850424029, 0.14135910925688222, 0.09724161369376816, 0.15208531025564298, 0.16423812689026818, 0.17571878037415445, 0.13525761634809896, 0.16664258146192878, 0.2258386550238356, 0.19900299579603598, 0.1355520263314247, 0.23222183750476688, 0.28061393299140036, 0.10915189646766521, 0.13737883768044412, 0.13892771472455934, 0.11546130946953781, 0.11837691083201207, 0.11715096450643614, 0.13441613962640986, 0.11898671873495914, 0.16382408270146698, 0.1703981900936924, 0.09989664700697176, 0.12435839846148156, 0.18256482551805675, 0.1803761429619044], [0.028539980958157685, 0.02706467672396684, 0.03223905834602192, 0.028897245283587836, 0.05412295613496099, 0.015997154587239493, 0.02848190790246008, 0.027291799888189416, 0.03486086199700367, 0.04329896233684849, 0.03682241767819505, 0.03292071727628354, 0.01000296973870718, 0.05439002539787907, 0.06962819854379632, 0.07442664340487681, 0.023392242437694222, 0.015119997260626405, 0.019281289787613787, 0.05820483514980879, 0.07708322780672461, 0.060954596192459576, 0.029866948425478768, 0.009660639279900352, 0.054648957011522725, 0.034782320508384146, 0.00899976048458484, 0.046429678914137185, 0.05704504015739076, 0.09225049245287664, 0.040259785964735784, 0.05104789692268241, 0.015236913350236136, 0.03286379826022312, 0.007392763536699931, 0.018585363068268634, 0.029198011761764064, 0.011957599326706259, 0.053532663005171344, 0.004713326088676695, 0.04270134049875196, 0.05951407270913478, 0.08826668083202094, 0.033371687022736296, 0.015452398711204296, 0.02725464612012729, 0.042023540736408904, 0.06533164589200169, 0.01978238233277807, 0.021752381799160503, 0.006474843748947023, 0.022620056333835237, 0.037443717737914994, 0.05733162790420465, 0.033031545899575576, 0.02561223620432429, 0.06034471036400646, 0.040322066997759975, 0.005121115827932954, 0.04048017042805441, 0.024875979324860964, 0.036028494068887085, 0.024759326697676443, 0.01595688379893545, 0.012608980487129884, 0.009667048652772792, 0.04603664121532347, 0.013462667393469019, 0.05095730295579415, 0.0760582996008452, 0.020222780185576994, 0.03988518692494836, 0.06033394922269508, 0.02182464100769721, 0.04039709070639219, 0.051592644449556246, 0.11186623480170965, 0.046205535472836345, 0.05621381991659291, 0.02477777834428707, 0.023250876292877365, 0.07177513529313728, 0.057795436805463396, 0.059706767642637715, 0.04640513980120886, 0.05401204587542452, 0.027127477260364685, 0.023782044372637756, 0.04195520748908166, 0.030323901737574488, 0.02006864538998343, 0.047654255977249704, 0.01597209040482994, 0.07255972639541142, 0.044988943918724544, 0.0693769370263908, 0.03693128332088236, 0.04626098874723539, 0.01650194488320267, 0.04932767653372139, 0.026265639717166778, 0.012970546486030798, 0.06184085410495754, 0.012313743936829269, 0.02810215279168915, 0.05948906604317017, 0.042333376259193756, 0.05217671467107721, 0.036663275241153315, 0.023338421888183802, 0.038873583980603144, 0.031174239702522755, 0.019197586661903188, 0.011158323904965073, 0.031012145373097155, 0.010322201778762974, 0.1011878800636623, 0.02332245458092075, 0.060463672925834544, 0.07625557729625143, 0.022048322462069336, 0.06655310222413391, 0.09157130858511664, 0.05307729974447284, 0.06286600124440156, 0.044405493390513584, 0.010878611228690716, 0.04665747001126874, 0.012675463931373088, 0.07477586099412292, 0.018232527509098873, 0.012544775436253985, 0.01744144447002327, 0.027885944764420856, 0.07407208977383561, 0.032344432183890603, 0.04265315285010729, 0.048926768358796835, 0.07981395276146941, 0.013752208888035966, 0.05546765351027716, 0.04883349894953426, 0.06321618362562731, 0.023905431989987846, 0.029129431750334334, 0.02977769217977766, 0.057609402647358365, 0.01128882315242663, 0.06417723518097773, 0.03194090422766749, 0.03470079187536612, 0.03209386457456276, 0.03204225191439036, 0.015374837785202544, 0.019053287178394385, 0.0974432477960363, 0.058952341132680885, 0.01337142404736369, 0.04870487733569462, 0.05528515568585135, 0.06596035629627295, 0.031288882964872755, 0.008916487804526696, 0.04584222078847233, 0.015186251566774445, 0.051650309324031696, 0.05407819349784404, 0.0194053583254572, 0.037214605617919005, 0.006979159998081741, 0.048230385218630545, 0.04333568751462735, 0.029549483624577988, 0.008948552294896217, 0.06871600999147631, 0.012642806650546845, 0.02507717741536908, 0.01463308066377067, 0.011590224166866392, 0.0517995218251599, 0.0941153388703242, 0.042077376128872856, 0.024835599069774617, 0.056561931705800816, 0.020997138926759362, 0.022285627892415505, 0.03436954168137163, 0.05155271690455265, 0.0873074030096177, 0.035987457013106905, 0.026926158570859116, 0.007997837001312291, 0.020044393859279808, 0.05189154442632571, 0.012558833568618866, 0.03488785761874169, 0.02064982123556547, 0.1110055587196257, 0.07589070039102808, 0.03222822670068126, 0.02559208318416495, 0.022718010550306644, 0.020432282908586785, 0.060898204101249576, 0.047306941996794194, 0.03887854894855991, 0.04057470148836728, 0.031868626465438865, 0.04076397141034249, 0.022483363864012063, 0.024347121179744136, 0.06871511199278757, 0.03300198615761474, 0.08288334938697517, 0.08153788759955205, 0.024497393096680753, 0.06685178697807714, 0.04974073737685103, 0.10646102484315634, 0.005396153437686735, 0.021643844556820113, 0.027977564750472084, 0.01528924589365488, 0.07760348074953072, 0.024065003017312847, 0.0392457190901041, 0.01209132227813825, 0.05633534659864381, 0.022245574182306882, 0.11170184166985564, 0.026949534367304295, 0.03443888053880073, 0.07332563021918759, 0.01695280701824231, 0.013650772143591894, 0.03473325341474265, 0.028749745288223494, 0.06460702032200061, 0.03894967267115135, 0.04686278145527467, 0.05035427457187325, 0.022982504560786765, 0.08128405825118534, 0.04213546773826238, 0.04490948958846275, 0.040373178708250634, 0.005692811664630426, 0.015793232814758085, 0.03926442492229398, 0.042720933197415434, 0.02647163022629684, 0.026623392004694324, 0.030570033159165177, 0.020274123817216605, 0.057600990403443575, 0.025860861242108513, 0.02750852370809298, 0.04839378016185947, 0.022068095131544396, 0.047747165444889106, 0.055267626157728955, 0.014079263164603617, 0.04489604558330029, 0.0556502997642383, 0.021499357681022957, 0.017263458903471474, 0.0062290091864269925, 0.025601476918382104, 0.07976178720127791, 0.03136424806143623, 0.058530389360385016, 0.046355375088751316, 0.007245796032293583, 0.05773853634309489, 0.04277213025488891, 0.02819035518768942, 0.022887645100126974, 0.02484984644979704, 0.04022128334327135, 0.04447198240086436, 0.0841897890495602, 0.030248868752096314, 0.05959961265034508, 0.026198367741017137, 0.07898089941591024, 0.004358196365501499, 0.08066589376539923, 0.04760370087751653, 0.07695181571762078, 0.0351026685530087, 0.027237782669544686, 0.038697123527526855, 0.02054264026810415, 0.08950634946813807, 0.007255098389578052, 0.06795375753426924, 0.04418882337631658, 0.0549579687503865, 0.02258352040371392, 0.08046389601076953, 0.040042678083409555, 0.02183018485084176, 0.01324081904385821, 0.03191112926288042, 0.04039595522044692, 0.005706783986170194, 0.004530241039901739, 0.06983784041949548, 0.037005653939559124, 0.0497125914262142, 0.05249336682027206, 0.05254470117506571, 0.04374672229459975, 0.025119587444351055, 0.02262475227325922, 0.05745264992583543, 0.052833986628684215, 0.031087675597518682, 0.03234911142499186, 0.027465826096886303, 0.03991143297753297, 0.0025349097541038645, 0.0308387759650941, 0.012741689479298657, 0.03520658035995439, 0.05782009466201998, 0.038822668939246796, 0.00698475068929838, 0.04773754350026138, 0.01882017488242127, 0.025127263106696773, 0.11775987441069447, 0.01510947267888696, 0.05381565875723027, 0.019437563823885284, 0.041714028047863394, 0.04422202706336975, 0.019878601779055316, 0.0521267644217005, 0.07172512196120806, 0.008816603076411411, 0.07194952515419573, 0.03894990644766949, 0.02155633977963589, 0.038691913650836796, 0.03359557442308869, 0.06440021345042624, 0.02531299483962357, 0.023946422661538236, 0.012794142621714855, 0.017205246695084497, 0.09319715376477689, 0.09338384843431413, 0.1565043840673752, 0.07017551019089296, 0.0925347646989394, 0.15020108636235818, 0.11770812445320189, 0.09153526989393868, 0.16429504961706698, 0.1547733839834109, 0.09889425782603212, 0.09262031948310323, 0.15794002421898767, 0.1590670645236969, 0.12843413249356672, 0.21902259264606982, 0.1300188701134175, 0.10047941104858182, 0.1718827526201494, 0.08966943642008118, 0.13555493555031717, 0.2837255800841376, 0.2893457160098478, 0.11785729613620788, 0.11806627750047483, 0.11627298896200955, 0.13552052958402783, 0.16869133949512616, 0.18467328191036358, 0.11359034033375792, 0.22651221341220662, 0.1290436286944896, 0.11918148054974154, 0.10431888236780651, 0.10949607487418689, 0.12630948243895546, 0.14409463590709493, 0.0893761173938401, 0.18461215862771496, 0.12911693804198876, 0.15995210531400517, 0.15329679212300107, 0.220756902708672, 0.17592411779332906, 0.09072610628209077, 0.11112313717603683, 0.15930036606732756, 0.08234784530941397, 0.1646090077701956, 0.12807543767848983, 0.10417681303806603, 0.10502141420147382, 0.2915064641274512, 0.12035438558086753, 0.2886211423901841, 0.12810932414140552, 0.13655806687893346, 0.16455828939797357, 0.13802278437651694, 0.11938822804950178, 0.09319860095274635, 0.0928344513522461, 0.15983644902007654, 0.12147915491368622, 0.09380880219396204, 0.14982205670094118, 0.08780376621871255, 0.13883926556445658, 0.09164648072328418, 0.12942604254931211, 0.14835309411864728, 0.08016164152650163, 0.16163179330760613, 0.17480705195339397, 0.12448963985661976, 0.10604255003272556, 0.09737077707541175, 0.17933513241587207, 0.14989980409154668, 0.13136031688190997, 0.12689758994383737, 0.1028368431434501, 0.10589535246253945, 0.16218878998188302, 0.2777506678830832, 0.1645606048987247, 0.15208275726763532, 0.10440521640703082, 0.09398917376529425, 0.11289501475403085, 0.08885109986294992, 0.11884643798111938, 0.08753352798521519, 0.12214305796078406, 0.1505698446999304, 0.14502395322779194, 0.12392839809763245, 0.12854637490818277, 0.1512268086662516, 0.12998039717786014, 0.1513794090715237, 0.186982786108274, 0.11310542104183696, 0.07319303811527789, 0.15102820994798094, 0.1626458638929762, 0.14506704232189804, 0.11715328742866404, 0.22192103555426002, 0.17574983183294535, 0.10366418937337585, 0.14800275588640943, 0.11471547331893817, 0.16591370338574052, 0.0990648553124629, 0.14494651753921062, 0.08028252254007384, 0.27480428223498166, 0.2103453574818559, 0.12558266753330827, 0.1483524261857383, 0.11472857222543098, 0.12133842887124047, 0.16349375277059153, 0.16531134664546698, 0.11896374926436692, 0.10008527126046829, 0.08156153984600678, 0.13966723519843072, 0.14830112893832847, 0.15470170736080036, 0.06803664058679715, 0.14953301986679435, 0.1504249032586813, 0.14987960283178836, 0.20825011131819338, 0.13379226060351357, 0.14926982461474836, 0.22036718612071127, 0.14386605442268774, 0.10938499020994641, 0.1262236901675351, 0.12764052429702133, 0.12604809802724048, 0.11795827274909243, 0.12228883060743101, 0.18883037759223953, 0.10652646742528304, 0.14962436340283602, 0.1445405330741778, 0.11502087450935505, 0.1388546428643167, 0.12559023743961006, 0.10938884937786497, 0.08680755912791938, 0.1369385511497967, 0.20435301965335384, 0.13840092346072197, 0.13618254015455022, 0.10635466023813933, 0.1231629321409855, 0.15999296796508133, 0.1284296202356927, 0.07575500610982999, 0.117292417853605, 0.12788782274583355, 0.17598197562620044, 0.11484364222269505, 0.11195078768651001, 0.14316641696495935, 0.148050787684042, 0.1679257399518974, 0.1497249392559752, 0.20073858235264197, 0.11106092293630354, 0.16624737298116088, 0.22563943290151656], [0.09685645389254205, 0.060702013652189635, 0.03578216412279289, 0.018861646094592288, 0.013579117785411654, 0.042737056355690584, 0.03686558469780721, 0.038680046709487215, 0.012239687803230481, 0.015725823541288264, 0.009655712347012013, 0.029123409221938346, 0.033946539770113304, 0.045233904602355324, 0.041197942264261656, 0.03169730167428497, 0.030234560144890565, 0.03533690149197355, 0.0537673152575735, 0.07245244894875214, 0.07976649983902462, 0.008241404302680166, 0.04208730977552477, 0.020895653942716308, 0.051192827231716365, 0.016742807056289166, 0.0405114890600089, 0.038038608472561464, 0.01794370218703989, 0.012951400003657909, 0.05698946442862507, 0.04787313759152312, 0.049460814116173424, 0.04163542718742974, 0.047054923488758504, 0.04950821508828085, 0.04480917348701041, 0.03257921431213617, 0.04223176511004567, 0.07852249706047587, 0.01969377917703241, 0.014047572531126207, 0.02203092837589793, 0.018849051848519593, 0.051091509230900556, 0.05307614570483565, 0.039897636452224106, 0.02950046291516628, 0.05172242010303307, 0.011018417935702018, 0.0808196964499075, 0.02725783549976768, 0.08251649094745517, 0.029590977101179305, 0.022928032776690088, 0.02146086990251206, 0.04164683028648142, 0.05549575864279177, 0.03193279626430012, 0.1148577504500281, 0.10472200956428424, 0.027842929885082413, 0.048625081617501564, 0.008282425587822217, 0.022943909170862753, 0.0269878217659425, 0.03351909981574863, 0.08667464047903195, 0.05352797634259332, 0.12412658863468096, 0.02180883882829221, 0.039283776422962546, 0.07714964260230772, 0.032949872547760606, 0.027518579809111543, 0.033514376045786776, 0.03921355069905985, 0.03285192018665839, 0.06565912597579882, 0.05948920334049035, 0.03811071925156284, 0.07913861321867444, 0.14108491537626833, 0.027808789236587472, 0.10684979890356772, 0.01795948210201459, 0.05540571757592261, 0.016747271074564196, 0.02878008242987562, 0.03297895360447001, 0.04163851452176459, 0.060619342111749575, 0.04691654263297096, 0.009073285982594825, 0.08904367976356298, 0.027981765306321904, 0.02885197984141996, 0.09599968150723726, 0.0109472237090813, 0.06334871635772288, 0.008661599968036171, 0.04179228009888902, 0.03776218443817925, 0.041679763089632615, 0.04270938166882843, 0.06909718445967883, 0.04290471122658346, 0.028736087915604003, 0.009128896035690559, 0.06990206587943248, 0.025253682397305965, 0.0336546864855336, 0.023872475067037158, 0.015356754429376451, 0.05326505197444931, 0.029544717181124724, 0.04537203312793281, 0.04154636575549375, 0.02464708057232201, 0.05609769235888962, 0.046292533734231256, 0.07496921272831969, 0.03726467090018559, 0.07779256513458677, 0.027053551930293906, 0.025978189223678783, 0.010680970808607526, 0.021100024714542087, 0.03663511815830134, 0.024617847375338897, 0.03757779784791637, 0.01343959680525586, 0.058062899406650104, 0.022726825409336016, 0.03632029540312942, 0.014519041324092541, 0.08026610623346642, 0.05349557046429254, 0.016918373221415095, 0.07928728766273707, 0.042603699839673936, 0.03246898311772384, 0.022606799720961135, 0.018883042212110013, 0.026771786288009025, 0.074783898453461, 0.049295749340672046, 0.03848571905109566, 0.14196722506312653, 0.038701312951161526, 0.03934173444577027, 0.11269000387983397, 0.012777558404195588, 0.039512061048299074, 0.060657154535874724, 0.06804857432143763, 0.04886103262833785, 0.03952389088226482, 0.016768156965554226, 0.02932636249170173, 0.03146691306028515, 0.05123635790369008, 0.023272689868463203, 0.03256489828345366, 0.031521657583652996, 0.053916505494271405, 0.054523482103832066, 0.06191191845573485, 0.048875081483856775, 0.08605579321738333, 0.07814673284883611, 0.0676110114727635, 0.06377945886924863, 0.013753888924838975, 0.00569723718399473, 0.06942398176761344, 0.021992236506775953, 0.02443703979224665, 0.039204155109473504, 0.016706690439605154, 0.04859477230638731, 0.05120949957927223, 0.059451134875416756, 0.04372470277303364, 0.046277557194116525, 0.059333244716981426, 0.040405588297289796, 0.01727011040202342, 0.04819079164008144, 0.06624895526329055, 0.020000039403385017, 0.012489104155974928, 0.10425673492136411, 0.05603130724921357, 0.09628934174543247, 0.016734144337533507, 0.051564160821726546, 0.03590644417272415, 0.09785822709091008, 0.023239881375047844, 0.022649731108685955, 0.0185919440627913, 0.049206168405362405, 0.06532678482471965, 0.022012055560480803, 0.042442212215973996, 0.1147152209887281, 0.08150130714057013, 0.038749233426642604, 0.009435129359189887, 0.03822348116955254, 0.05229653441347182, 0.027820466930279508, 0.020869391191808973, 0.029200958088040352, 0.10061358392704278, 0.0492602153099142, 0.02132501977030188, 0.023117720156733412, 0.044760087839677, 0.05432814512460027, 0.015824002257431857, 0.05312986977514811, 0.06573452817974612, 0.026285800158802886, 0.035594723594840616, 0.033611486069276, 0.03604209763580002, 0.07763067304040305, 0.005721153820559266, 0.08232684995164163, 0.044470850625657476, 0.07153120619477704, 0.05359840244636871, 0.01126777120589395, 0.039873743007774465, 0.038569522366742603, 0.05857047646713909, 0.029712010255025234, 0.0310504902881803, 0.021773811313323677, 0.09070908141438849, 0.09783976245671511, 0.028721077978843823, 0.015783054259372875, 0.14330721722217277, 0.03869816995575093, 0.043331798660801724, 0.053203379502519965, 0.045977558838785626, 0.0259363784789457, 0.04854492966842372, 0.06371549316099845, 0.07034037829726003, 0.011702363608492306, 0.02582458506367402, 0.010140704926016042, 0.08411353337578475, 0.07501794956624508, 0.0569102253211895, 0.01596434423845494, 0.03375560372660402, 0.09981495881220326, 0.04641309191356413, 0.02967970271129161, 0.06294645005255006, 0.02728955489146756, 0.05151175406354014, 0.03204707216355018, 0.011938320185436169, 0.030886186214047484, 0.039593070177943446, 0.012446614346117713, 0.026614009402692318, 0.0066108107694162754, 0.014276872971095145, 0.025406203021702822, 0.029881659647799097, 0.035377819804125465, 0.025383105530636385, 0.05845389619935304, 0.05471259617479518, 0.05794180317025166, 0.06375953962560743, 0.032353798087569885, 0.07282116275746375, 0.03330074512632564, 0.04210027509543579, 0.0017972783939512738, 0.06423215410904959, 0.01934411258844193, 0.07838793084374629, 0.006168867857923033, 0.03396713065740187, 0.04468402512429748, 0.022813257783127483, 0.04027579409012105, 0.0551115191046847, 0.004035008214486879, 0.07112197112292051, 0.011776767623814521, 0.020500577193161007, 0.009567217730364064, 0.04842925482080318, 0.06818532987381332, 0.046994160147733055, 0.05492009695444722, 0.03674719358969014, 0.035234934111940674, 0.06667302586720325, 0.08828723832266405, 0.01813577371649444, 0.04121917510929052, 0.03890483210852835, 0.053731013103970326, 0.01700828070170246, 0.08266509117675014, 0.07945813005790114, 0.029994441974849906, 0.045814612894901074, 0.004383786545076873, 0.09920909171341918, 0.01788679615856381, 0.012161046124674613, 0.02928089481429197, 0.03827912369160913, 0.06356650701491162, 0.08740400095121004, 0.05201406187552493, 0.04807472345419228, 0.03173994176904671, 0.08892404555808753, 0.048812021195772104, 0.02419875472696731, 0.04638175101717934, 0.03246958425734192, 0.027344542468199506, 0.08357514976523817, 0.027098405480501242, 0.025152099078695755, 0.03881855001964141, 0.0354422382224584, 0.011985749915766064, 0.03867246938170865, 0.035002081567654386, 0.009561925289744977, 0.058352882479084656, 0.026421995389682706, 0.04826156284252647, 0.03821046761004254, 0.032498438959009945, 0.03565179846191313, 0.1502613932825625, 0.21351838018745184, 0.08545250137103721, 0.09032268222654238, 0.1623704528901726, 0.11475675157271326, 0.09138646928477101, 0.11800264575867914, 0.17774135543731973, 0.11801089844084345, 0.08410656460910104, 0.06994683964876458, 0.20282854442484677, 0.2031913210521452, 0.0947583578818012, 0.14022999093867838, 0.2330595738021657, 0.12456430733436719, 0.13908144319429994, 0.213125234877225, 0.21526637545321137, 0.09198901898344047, 0.34275075187906623, 0.11294942160020582, 0.10975069832056761, 0.11466266951174475, 0.10642745750374161, 0.18161919579142705, 0.11473084319732152, 0.15409544692374766, 0.24802321539027616, 0.166539927595295, 0.11871124836034141, 0.1503499166574329, 0.14262267504818738, 0.08553272011340596, 0.19196178065612912, 0.10966711764922366, 0.09674448607256636, 0.16631446313112974, 0.13065855688182637, 0.08058048741077073, 0.09125709810177796, 0.11268368078162894, 0.15233925834763795, 0.10886166477575898, 0.18460381688782945, 0.18002589378738776, 0.11771323785069399, 0.14641712768934667, 0.16391805344028398, 0.06667168257990852, 0.2272055871435441, 0.17424589925212786, 0.15205231436993927, 0.09332728935987689, 0.11243782209930941, 0.16209942055866122, 0.16461446997709572, 0.2212995759327896, 0.24583540856838226, 0.08913414014386944, 0.13440856972010806, 0.0980283496028278, 0.07251379487570375, 0.1036943873623386, 0.1424663045327179, 0.23072767158737406, 0.10690341165172867, 0.1664347355836071, 0.1688582930364646, 0.1683112559840083, 0.15062060760101303, 0.12457540986360982, 0.11181862602825277, 0.10144309722818434, 0.17148077575257048, 0.10525685313041322, 0.09342541612568311, 0.13407705235294998, 0.1584644109243527, 0.15617613214999437, 0.20192313910229132, 0.1179769377631601, 0.15684691490605474, 0.1022765290690586, 0.13721954310312867, 0.22136806132039055, 0.10139283898752183, 0.19146857899613678, 0.09559362282743677, 0.11638635201961733, 0.16393087775213644, 0.1305338167003356, 0.14951929013477638, 0.13577891571912915, 0.14703352586366236, 0.18057738372590393, 0.09413772946572863, 0.12445199812646024, 0.15557505190372467, 0.08929430303396657, 0.1716288342140615, 0.1330599538050592, 0.1275005255592987, 0.14893397310515866, 0.08432190617895685, 0.15385757375042886, 0.15993791545042768, 0.18657415959751233, 0.1171055821760092, 0.12162831175373867, 0.09466828341828659, 0.1675217889714986, 0.10070915770484135, 0.2438106367480941, 0.14435542660066858, 0.17927761597093195, 0.0978461375052575, 0.17934522562427446, 0.13158300571376458, 0.13828875526087359, 0.11593260293011554, 0.21708920889068395, 0.10943281420622952, 0.2237337757833302, 0.12549956183647737, 0.1847114579868503, 0.18153950397390872, 0.11106823309091851, 0.18621789902681485, 0.2054295493871905, 0.23744485020870343, 0.11750898396712728, 0.16236758820014074, 0.07320420743781142, 0.10588493270915933, 0.15476474538445473, 0.16203002975089476, 0.18288527004187927, 0.197648695029784, 0.17615345626836643, 0.06161521152534988, 0.12174207557109185, 0.07564282306702808, 0.21448856015922502, 0.14131875126622617, 0.11240398016525432, 0.19588585681049153, 0.1655762636801228, 0.1649797847494483, 0.19297043356345966, 0.14568884333129972, 0.15724446857348084, 0.2023146813735366, 0.2901104249758646, 0.21236393979052082, 0.11559013146325015, 0.07728552242042497, 0.09878472425043583, 0.11443071125540882, 0.1626589850638993, 0.12041423979098909, 0.22213431395357475, 0.1356277402373962, 0.12341650173766539, 0.23168219224317, 0.1255987276090309, 0.12573274463647977, 0.15062575810588896, 0.17334325471892953, 0.17377248324919492, 0.13843874330632389, 0.17667058476945385, 0.058419360357220285, 0.1159019596525468], [0.057825731273624115, 0.018107538708136417, 0.061941118256072514, 0.01379277375235688, 0.02974136219563661, 0.022346257646859158, 0.11372691777069122, 0.024245018357760273, 0.01236806636370602, 0.10278489280608483, 0.06657069112407044, 0.04632099880836904, 0.02275587492476916, 0.04982158694474492, 0.009020664929266786, 0.023010162549326196, 0.08955274111940525, 0.05786352514405735, 0.05860293429577723, 0.02406501786026638, 0.022952417893975507, 0.007548213789050351, 0.022534156451001763, 0.042490373889449984, 0.0564911790570477, 0.04908277522190474, 0.05725806622649543, 0.040358124242629856, 0.05760445252235513, 0.002633314129525388, 0.04675932606915012, 0.0454132891172776, 0.020464263907342684, 0.08449360204394907, 0.042735508977784775, 0.03023163793841377, 0.06582807589438744, 0.013522692297556205, 0.05096152577607427, 0.009259008438675664, 0.06262365292059258, 0.01663858725805767, 0.058900780422845855, 0.03847340682114009, 0.08628669020254165, 0.03205220782547258, 0.0657689044601284, 0.0124757427147415, 0.01484821628764621, 0.03376722575922031, 0.012082940647815121, 0.040741792327025905, 0.03288318315753713, 0.019466693120193668, 0.01500109685366624, 0.01061379531165585, 0.00538945741027419, 0.014314184445538558, 0.031386553309857845, 0.006560166611961904, 0.04044374953082297, 0.06797357287723571, 0.06267409669817425, 0.03386500000488013, 0.029613109800266102, 0.04562227048154455, 0.028548061090987176, 0.024917209339037072, 0.040350068229599856, 0.024124194860632997, 0.0828078061749693, 0.059159545053262264, 0.05893985820875969, 0.008359950334124733, 0.04775426037667785, 0.03275899958680384, 0.019575777696445584, 0.08904163143597543, 0.03495531142107211, 0.01974680748389801, 0.02652263989148196, 0.03575863804144319, 0.0693350873189047, 0.06433309361455031, 0.07984518975717947, 0.13557936705183238, 0.02096542881190544, 0.02790091573842801, 0.011740970130631467, 0.02490174854756333, 0.04389572328364011, 0.015451429280801676, 0.05905979298404418, 0.04629094553820323, 0.008087808491836768, 0.03744871610251721, 0.020673584804171696, 0.041967827710323036, 0.008892019195627654, 0.041558911761967465, 0.05723665526602417, 0.038906921254238114, 0.05633629654766992, 0.02631865874718642, 0.03585754777304828, 0.016174834017874673, 0.05048941966379061, 0.03617324255174026, 0.020873918292636517, 0.0007830968343114364, 0.013127866022841772, 0.02175930789235281, 0.05182615750527475, 0.025995305004471447, 0.048200881137745455, 0.052204734456609, 0.02220727750682272, 0.0975176332576666, 0.0317601281858515, 0.021439453375933226, 0.0068019745594938286, 0.07037721108645201, 0.10048548923805356, 0.0171821844560327, 0.0831275233940687, 0.022494323529826943, 0.049373129368177615, 0.01193312979012262, 0.07616168819367886, 0.03489452581561636, 0.034319261176278815, 0.03228747606044635, 0.0319057115848409, 0.014319094680104172, 0.003939979915230651, 0.06620421860134229, 0.021922504311078228, 0.05040384261519648, 0.01863745812443085, 0.029339476241148077, 0.05867508960363921, 0.05273042734188493, 0.043914091438637115, 0.01633895626582671, 0.010915018210653216, 0.0444935974519467, 0.0077393316587404115, 0.06491032865596935, 0.060014113259967417, 0.03980470843089279, 0.09807969880057499, 0.026257628232997376, 0.02409411004919093, 0.042109232817892917, 0.055199827256728895, 0.028034494898747653, 0.053970890076016076, 0.043826989276567474, 0.07394101165118627, 0.015477429496968398, 0.03108830456767464, 0.013755568033957388, 0.01860000193119049, 0.06315673759672791, 0.04030801072076429, 0.04546186268271413, 0.025159847100439947, 0.04393250041175634, 0.026370970881544054, 0.03735717589734122, 0.04778708185767755, 0.018941339767479803, 0.04153343754296657, 0.06381016894010827, 0.0434963328007143, 0.10576042259344831, 0.031268340317183174, 0.015867013426031917, 0.016265277699858416, 0.033176346332766116, 0.031226475766743533, 0.029188564221840352, 0.10275064269080758, 0.03100202990026446, 0.005825456646562088, 0.014914462244632887, 0.044723143728333525, 0.058411326608620584, 0.031802768280613236, 0.06789041523006745, 0.019438393173913937, 0.03456497513980139, 0.06897497500176542, 0.01951780854142271, 0.004239590034558205, 0.024693507475603838, 0.03236134572944138, 0.034650092056836, 0.025189280677295756, 0.012673320052272175, 0.028499229629233014, 0.02959014589578146, 0.009637346975068795, 0.02373891074967105, 0.02328336937353015, 0.03006220933457371, 0.012679798073804704, 0.054813554233987816, 0.028512293283711188, 0.04671452632464934, 0.02566913295595441, 0.04889894524239935, 0.01962858335900819, 0.017628541754675098, 0.03311287786345929, 0.01982459012651816, 0.06299147615209222, 0.0032115415615407983, 0.02516609227313893, 0.07869200358982198, 0.03356589222676121, 0.0318332742608618, 0.06739034128258936, 0.007791758362145629, 0.01492626239269157, 0.05263503539026715, 0.040977561511681415, 0.03677866065117996, 0.07505112356739119, 0.03757047285034787, 0.038139585085446015, 0.032563981731073, 0.03573236972442828, 0.04611563170328736, 0.038165233709150925, 0.01617617173906183, 0.03545967127138283, 0.03405412891879678, 0.042340790314483456, 0.020616111032722984, 0.04601738248311449, 0.05485243535076734, 0.03612855412939098, 0.03992301048128866, 0.05973375213216059, 0.008711650407349225, 0.06330254735075869, 0.022762454063922632, 0.0332526391139254, 0.012435915359674254, 0.04787610989296809, 0.039384600895573385, 0.04635484074242413, 0.03408892822335474, 0.020568372383422684, 0.0301188685989473, 0.01684069819020806, 0.022784688808314968, 0.029639034873980563, 0.02618674756377004, 0.03549709035723936, 0.05946913195657544, 0.02582919751148438, 0.0377918072626926, 0.03424581082072109, 0.030848945243633352, 0.02014753939874936, 0.02007043396588415, 0.03456224032561295, 0.09608355903765187, 0.03956006316002458, 0.0434007441799622, 0.030574413685826585, 0.05600180687906686, 0.018416303682897706, 0.041284402468591, 0.04054142729728483, 0.025506708370812703, 0.034843039320548996, 0.016529480417375453, 0.07994795494596474, 0.03127326817775611, 0.016156981655512936, 0.03485728113446385, 0.038402988138841465, 0.008929140494728927, 0.04003267764346674, 0.03306814862298779, 0.046847983030602336, 0.021214575208432507, 0.05806389017379843, 0.021743752477050293, 0.03474086413916666, 0.09294496456277557, 0.049687209975672886, 0.06426369538530707, 0.03590325664845295, 0.06279376058955677, 0.09997173008741811, 0.011426149230828742, 0.07443845097441226, 0.09366924874484539, 0.02956902808364248, 0.0158304552314803, 0.01497439901868347, 0.018733139513642527, 0.023704790510237217, 0.045914405782241374, 0.05211821488046553, 0.05097008644952439, 0.035267673956695944, 0.020497536243055947, 0.07840321166440845, 0.049889582514879294, 0.006109064206611947, 0.06743778678355739, 0.06711173904477619, 0.03217343022697605, 0.051102663710480556, 0.042900243497570045, 0.04603290079103317, 0.03294279616966378, 0.023907929316919763, 0.04804402822628617, 0.07014165341388434, 0.05412206555774901, 0.030986713827587664, 0.030798866973782424, 0.030555501907656435, 0.02703257698158268, 0.05285996550810523, 0.029040832305327058, 0.04511204024311155, 0.0332996467477642, 0.02390979767369572, 0.023131485140766017, 0.032405484962509945, 0.03876292234053835, 0.03411544515984133, 0.028285917833272833, 0.06891952172736637, 0.03706556752149481, 0.02883989396650577, 0.08713166986126453, 0.06391611794242635, 0.019611938841990195, 0.016999207946355455, 0.01069647334588808, 0.02315786106919404, 0.09854239819105715, 0.07644871380762197, 0.09391990912263282, 0.10189887980232015, 0.1683698856504634, 0.15121808100957423, 0.10144777275854722, 0.1038409021566622, 0.10701677470933646, 0.17539639142341912, 0.11609784211032093, 0.13868503243429586, 0.18694998318096623, 0.20555261231493205, 0.09752204903634265, 0.11543773143785074, 0.19667058892082423, 0.1274646946694702, 0.07859387682401575, 0.15746129443868995, 0.1802487310487777, 0.1674663060111925, 0.1317064100294374, 0.0707024424627889, 0.10748293992946856, 0.12465127219911665, 0.1733732523280196, 0.1529390027280897, 0.10949827163130976, 0.118029852892505, 0.13183971459511667, 0.14509634231217206, 0.12631740857614204, 0.12225875136209652, 0.16162683576112613, 0.07873999828007072, 0.18654799147043377, 0.07160479755839333, 0.08395055032451637, 0.09274989846744575, 0.13499327818863094, 0.1311793367494829, 0.08503276490955614, 0.1532209149445407, 0.09982002025935799, 0.18815906048985198, 0.16768886125646532, 0.22473166754934937, 0.09927227074513212, 0.18329368875129148, 0.21534594852710143, 0.07395099353743717, 0.08206404803786427, 0.12733798037515953, 0.16458384896395728, 0.19075887801591307, 0.10021521389717236, 0.08342574059497565, 0.1012886711396277, 0.14896834938554093, 0.13493341655703261, 0.1142343835090287, 0.06878519299789332, 0.12851122679421678, 0.13799020409351215, 0.1488914925721474, 0.1761553413234651, 0.17272390279686078, 0.11101706200861372, 0.11258488608291373, 0.10379077750258148, 0.10929510870482773, 0.09821814644965343, 0.2254243881907314, 0.18895459827035666, 0.24918065406382084, 0.08392866438953206, 0.13907170621678233, 0.13161876238882542, 0.17536538449348882, 0.14275091816671193, 0.10061558030429296, 0.11597656775848009, 0.13008343696128577, 0.0913209599093534, 0.09293720169807784, 0.14099447726039216, 0.13661534583661705, 0.2601577009772882, 0.12260983916348778, 0.12692950229393318, 0.1501100099994801, 0.10121786282979883, 0.1273408005363308, 0.14411158656002954, 0.12557891226606444, 0.1778764560003765, 0.08027456671698019, 0.17957610776647925, 0.11725116928573698, 0.14479978010058403, 0.12390461226459593, 0.10367276860051788, 0.15498122986173257, 0.09717144363094121, 0.14664637710666284, 0.1875814766390249, 0.22785514447605237, 0.064014771633083, 0.08918102161260322, 0.10194693386438303, 0.1841541941394098, 0.05876300441741478, 0.16806202795123681, 0.09833925010752864, 0.09351807326311246, 0.11103506651124917, 0.14897737390128896, 0.1337815885199234, 0.0966253862134181, 0.2007179506472312, 0.15899906895356253, 0.11817615988547914, 0.10232741813524626, 0.24961053568404168, 0.17372885980876163, 0.0921911429031752, 0.11722092676791362, 0.13100666867103428, 0.17699818359687924, 0.0779115833574906, 0.12537204602267593, 0.09471446726820432, 0.10593335784506053, 0.08861440670443699, 0.10292139602825046, 0.1355972231249325, 0.16599194059381261, 0.1106110775435809, 0.1304261013865471, 0.16818016301840544, 0.1386314642149955, 0.11471789272036403, 0.1879368763184175, 0.1664463576162234, 0.11701953015290201, 0.08933739212807268, 0.09509653231361881, 0.1509405326214619, 0.11130096318083815, 0.18030531238764524, 0.1669274622690864, 0.16794003371614963, 0.13649578584590927, 0.12696169666014612, 0.08727229200303555, 0.07486016154871322, 0.10916187093243934, 0.11705070035532117, 0.08780962918535806, 0.1562504211324267, 0.24319474323419854, 0.03800913407758344, 0.15102524135727435, 0.11403348413296044, 0.14262371405493468, 0.1830083181266673, 0.1448959030676633, 0.19552910642232746, 0.07489687559427693, 0.19813919527223334, 0.15053601760882884, 0.14634712832048535, 0.09519747181911953, 0.079999111185316, 0.26097251975443214, 0.16113388643134385, 0.1627172584994696, 0.21770384075352922], [0.023396242613671347, 0.07428795826854184, 0.02868333234800957, 0.01773795287590474, 0.06782026001019403, 0.060575265961233526, 0.033886945311678573, 0.012773071193805663, 0.05775487843493465, 0.08276605294668116, 0.016361994385079015, 0.012739534467982594, 0.023662478815822396, 0.05597737166681327, 0.027045473652833607, 0.06233754014829174, 0.06709642853820696, 0.10933575613307767, 0.02177492824557703, 0.016967683368420694, 0.030357393006852362, 0.03149902950099204, 0.062078207774902694, 0.015202139093162259, 0.005102215181977954, 0.0226722293155035, 0.031437954457942396, 0.024473007979395334, 0.026283777806384023, 0.04094212767085992, 0.030849911890982185, 0.005685011692548869, 0.042909917392535135, 0.011166080275870627, 0.021861920940864366, 0.03399608925974462, 0.030260403582360595, 0.02481899908161722, 0.05681699301931076, 0.03743604764167685, 0.03584325029805768, 0.015893522941041738, 0.004185628476989223, 0.039411477773683146, 0.015477897050004685, 0.08953209457104094, 0.021296727245498914, 0.04173780274868477, 0.03257290234614629, 0.03735890510142781, 0.08912847755709663, 0.059104922984261066, 0.07167276344262064, 0.025100605162151624, 0.06367038542521186, 0.03928401019948069, 0.013904813004046446, 0.027733795213862322, 0.024747602619754616, 0.040874647893360816, 0.044968642469029874, 0.013915319959778572, 0.03112479596893536, 0.07979508736752905, 0.06974561372771859, 0.024775294004939497, 0.05723270332964603, 0.02427326635370264, 0.07106855133315548, 0.021065793152956758, 0.017985904414672405, 0.039293505979003385, 0.006853390550531913, 0.03503157080558594, 0.07600202254252508, 0.02769009384792298, 0.01699100721452851, 0.03751461139472667, 0.051169980215490796, 0.021473991073435172, 0.06344457957311533, 0.027785266865976155, 0.05431681624031626, 0.02776134559098864, 0.026831274990399834, 0.03669870537123643, 0.042443002603249624, 0.016252560999419075, 0.035952375692431815, 0.026761631852423307, 0.04156940573011525, 0.03255079376685899, 0.011925876224267995, 0.05284918581310194, 0.011652118355414132, 0.03995701568783261, 0.09614648573915474, 0.044144617349957116, 0.05159599895705469, 0.026887231069849804, 0.060225621637073345, 0.03789489528571721, 0.06470862776041031, 0.008709879457455827, 0.00920332788155065, 0.02324627868802054, 0.013546118188969558, 0.03481628489680588, 0.06446820159908384, 0.009353135028504767, 0.012723852887575049, 0.010429866069898708, 0.02929199177742703, 0.016540555116080213, 0.05197690254135523, 0.06871082237921655, 0.14508357737213373, 0.04719606142316479, 0.046935118589317426, 0.021011185926909093, 0.011346059436618816, 0.026723003065853845, 0.013885955031582853, 0.06331678916467354, 0.010775044520414667, 0.06151184148620814, 0.03462834712991025, 0.01776036759110866, 0.021628689901262987, 0.032988660896080546, 0.07788885137415491, 0.037524919825955294, 0.07114371604984626, 0.0978807735373266, 0.03111409048869973, 0.05551646085223183, 0.04634756398445461, 0.049563534776098095, 0.018237832009617705, 0.02303753481101012, 0.05742936875321902, 0.058353387139504775, 0.03639389047748409, 0.06447622421546839, 0.06243082811124623, 0.08660768391564488, 0.04873351310379803, 0.021071019727969542, 0.08623181580333039, 0.014073323200136656, 0.029605126146634575, 0.03532993643602822, 0.05120900234032888, 0.033287007972830907, 0.05858670723682735, 0.009525450586806983, 0.02848336622264469, 0.03869911619403865, 0.060773909208364785, 0.04571933597617317, 0.039836631913203746, 0.025136022304650396, 0.03502299157844391, 0.06359643783071078, 0.00748051693335583, 0.024858700271579437, 0.045038359821774065, 0.005762195514762425, 0.034515292063588277, 0.011745797801268054, 0.12393504774081521, 0.09036331481183879, 0.03397417734959163, 0.09418717134394683, 0.01067893175786594, 0.03053426720725838, 0.013418008657026803, 0.13175748463254422, 0.05014745285734534, 0.04089362089871429, 0.07293423637747765, 0.06884308051667176, 0.009217681945301592, 0.040365824024775065, 0.04015382583020255, 0.06879556080093607, 0.028702027047984302, 0.08153303395374678, 0.018917594752565492, 0.02309132196387509, 0.025038216517714318, 0.05907872888201382, 0.10775568662211299, 0.08438423174084164, 0.057688459928613156, 0.027915116734220646, 0.0448888949904358, 0.05820678699819837, 0.018662756083358545, 0.009081072039407445, 0.011887968248629477, 0.07573224444058724, 0.059353601827751845, 0.027516414593264926, 0.01292313716476201, 0.04947674802679103, 0.09412238185177557, 0.020010115913464688, 0.028314586998021696, 0.022346860641846433, 0.01893948810902657, 0.0391385344119044, 0.017957825257326476, 0.03147635688947048, 0.039218456295202486, 0.03175002755597234, 0.04244773379468825, 0.031130371353356168, 0.059761196753242984, 0.06941247105714865, 0.0255641190597089, 0.08122174011077732, 0.02174516070226673, 0.04179214651230723, 0.026978661808243487, 0.020531903246592265, 0.050139560116804205, 0.0783243436308112, 0.05342143362213392, 0.04745799502416048, 0.050688708579400554, 0.01553591258925735, 0.02266124738525832, 0.042435510622453876, 0.042505443198024295, 0.035374765866436064, 0.034360483768978156, 0.06153749010991305, 0.04201138064672705, 0.06374027347192168, 0.041450498829362914, 0.040923418127931654, 0.07770260199322365, 0.03795736927713733, 0.038462686497950926, 0.023462004319299012, 0.04005563969258219, 0.019509702433424536, 0.022118371925898828, 0.01547533756820485, 0.03855070892313961, 0.05073620974144433, 0.08643013992696069, 0.018294450455869082, 0.05551727721467614, 0.028887320913781878, 0.04287647992896382, 0.03391866841411684, 0.010541243882471463, 0.01115989354730118, 0.04008575233456213, 0.02548271102568833, 0.06237530804355629, 0.048258468086714856, 0.04261783033143729, 0.037230049711070023, 0.06216171423147898, 0.030582289728044998, 0.03767392823647242, 0.006963520163481007, 0.012097792878194014, 0.009838443947955966, 0.028715547123283613, 0.04808466452232096, 0.06717096985084936, 0.029338420536078047, 0.07082878568326123, 0.030507002556987572, 0.05010545100958552, 0.0751039719034452, 0.014617483502661344, 0.022043134849809576, 0.07726004449068569, 0.026455677761987317, 0.03543195576639846, 0.05026919476222247, 0.06510209961561486, 0.0594208700931631, 0.043960946932202205, 0.01681427216681186, 0.013895282900193706, 0.03473259290331043, 0.03313621098641306, 0.04053353826748207, 0.03846868305117823, 0.03054506545595359, 0.03923437907360494, 0.005300639495544601, 0.036661898557213135, 0.029686901543755084, 0.041938861686503515, 0.04093218289199285, 0.03570403452613391, 0.01083117036614567, 0.04865550225076731, 0.02623472741106525, 0.06563765564351343, 0.08032582685700618, 0.022282727950369008, 0.018134810779883992, 0.019791043196164537, 0.05554904113523662, 0.01977114621695364, 0.08929013958550058, 0.030014396470505744, 0.019233907369198278, 0.03448625924647786, 0.028270614748180378, 0.04101576727407519, 0.07547923887614161, 0.09192918703774922, 0.01729397972667357, 0.05572419540840201, 0.07134293075068854, 0.07302789541427046, 0.003772342670345097, 0.02564210764830932, 0.024593803645984735, 0.039770577059243806, 0.006888174548294046, 0.020346512901596725, 0.03682651433337014, 0.022001463257765863, 0.02108474389387993, 0.0279883834082284, 0.07224927117931657, 0.043569404660956934, 0.016196298784052487, 0.009070539108506637, 0.06538358138641343, 0.03494023469102103, 0.033477008910267614, 0.026963267810060643, 0.019624790984380525, 0.06044093352102209, 0.007426263618981466, 0.05410722631495446, 0.07169426346081309, 0.026669124999898486, 0.02624957778607495, 0.05622476659482345, 0.0629746590857394, 0.16468199057271704, 0.18958934233523905, 0.13578028127085418, 0.10473011381691322, 0.15697644936153665, 0.13507720024790615, 0.1064374393899925, 0.16519233584403992, 0.17366689047776163, 0.15917498763883486, 0.09600396369933151, 0.13648288731928915, 0.07512867799960077, 0.10386672147433273, 0.09107760226470418, 0.17802249582018703, 0.1724396602367051, 0.207296748412773, 0.1132984907599166, 0.10477383373654447, 0.1201610041607637, 0.1708762816269882, 0.19668167660711333, 0.08852664774167351, 0.12409932955051772, 0.1839459326583892, 0.1685695382184349, 0.10777440358651802, 0.09439020068384707, 0.09941962416633032, 0.20950803678715602, 0.12163539926405065, 0.19685937644680962, 0.08244876255048439, 0.1280420707189478, 0.10327124444302171, 0.09586023195879534, 0.12799264368368313, 0.21286781353410333, 0.11085390084190294, 0.10943530040094629, 0.1710992376320064, 0.13147941674105823, 0.15273400669684634, 0.29090906493365765, 0.17499871901236475, 0.14282906631706282, 0.14750668953638524, 0.11919636803213507, 0.11524293251568452, 0.2549159713089466, 0.13722935429541394, 0.0984608955332078, 0.19013608252862468, 0.10651876393239945, 0.12184586492367089, 0.12222742530866526, 0.11398724833270535, 0.12623039918253198, 0.09433375293156132, 0.12264222648809664, 0.1377296360442415, 0.11257252932409756, 0.09767779614776373, 0.13856772857252508, 0.1202188991010189, 0.14131707401247695, 0.1014162166393362, 0.13471066835336387, 0.10396887068054639, 0.13497926644049585, 0.10967643902404234, 0.08893034639186226, 0.17757162626367062, 0.19872617471264675, 0.2080437052063644, 0.21767574304249138, 0.20027843595016748, 0.20538021140964702, 0.12260244737262838, 0.14406260481337085, 0.08976498793344945, 0.1046553350170143, 0.12910846271552145, 0.09987668323446997, 0.1622798663447611, 0.13740632683038712, 0.1614470430649817, 0.10019399589509703, 0.1016007739235647, 0.0941574334865436, 0.11988478421699256, 0.12897852750029415, 0.1370273862266913, 0.11928409730899148, 0.20009530358947814, 0.23373806005110964, 0.13345134764676914, 0.13669203937752172, 0.1522157501312904, 0.1436563828610815, 0.11659776020678692, 0.15889122005319223, 0.22431576799135655, 0.1657491544028744, 0.11427257442846894, 0.19747715501580387, 0.12071034187101759, 0.16006926074624062, 0.201840300578624, 0.15125604928471148, 0.12117796912207268, 0.1817954410216771, 0.08352911434485577, 0.13708315120311454, 0.1671104462002404, 0.2877695130882785, 0.11698666043230332, 0.10400757368188351, 0.08628230410977267, 0.10263232950819656, 0.11563607782591134, 0.16243406978901476, 0.13619937206385657, 0.13350588065804914, 0.14754548901692033, 0.0936725438805297, 0.09373961918754503, 0.1742703901254572, 0.1509580176207237, 0.12073319259798154, 0.19143966492265463, 0.15354226488852873, 0.2572202211013064, 0.07380948081845418, 0.20595798821887001, 0.20085791969904676, 0.18874402128858492, 0.16699572501238436, 0.11350380591466092, 0.10816776411957107, 0.09023754304507747, 0.2962328167632222, 0.14952334226109087, 0.28305827057920396, 0.17372376867569983, 0.18708830466493964, 0.1766912906896323, 0.20015611517010257, 0.0880313383822795, 0.08687243767781183, 0.19868327857693657, 0.12373667908832431, 0.21657353499904275, 0.14384031674126163, 0.12531325308373198, 0.14504035469144583, 0.13070036948192865, 0.171275052416604, 0.2848110452760011, 0.10861957620363683, 0.08843791656545363, 0.13384853024035692, 0.21497793233720586, 0.11657497627311386, 0.1443820251733996, 0.15723762597190216, 0.110440420685336, 0.21979257086059079, 0.10169962057261728, 0.25724337610881776, 0.19199522183043882, 0.1517334283562377, 0.17602616309886798, 0.18054612446576357, 0.200358216825407], [0.03216781587980222, 0.013956053662695922, 0.010683806740416912, 0.022490627634397242, 0.011187678628630238, 0.008111303959594807, 0.026240594088449143, 0.05047478080086876, 0.03627084239269607, 0.034528316755313426, 0.03812302777078003, 0.059850662655662745, 0.043039537194999866, 0.020462844549911097, 0.031695424040663056, 0.02748599767073756, 0.033533779496792704, 0.04273131213267334, 0.02661854392499663, 0.02793431980535388, 0.0019060484851252113, 0.031181494196061976, 0.026768283350975253, 0.03263013677496929, 0.04878834297414869, 0.04153924484853633, 0.027810735518869478, 0.012243202800164, 0.036508374178083614, 0.0813339528394863, 0.0421985614229925, 0.026619718373694923, 0.054356406108126976, 0.0506057476013666, 0.010987111363647273, 0.11219307663850486, 0.013075487095193239, 0.03110451863904018, 0.07449416400049813, 0.028542404070321936, 0.039036118032527156, 0.01303323477259255, 0.027513084205565974, 0.09174448132398538, 0.029460052974172868, 0.018002547076321207, 0.023134602161007933, 0.10653929915861227, 0.02165468547900673, 0.0218218765076017, 0.04182798853435088, 0.049915301642613485, 0.044311864039627835, 0.03934432454116177, 0.043839464779011905, 0.037197896162979305, 0.027604123461060226, 0.04311840151785873, 0.022924654149392154, 0.09937036040355451, 0.03161830376484431, 0.013359073782339692, 0.010877149197767721, 0.04011294833617285, 0.09570853697368875, 0.059694340379792266, 0.040697289441595785, 0.06379779733833857, 0.01696213581453776, 0.021390838992374483, 0.01125549237258383, 0.035315895001986064, 0.01957029693585355, 0.05986464842862915, 0.007479816995328292, 0.028440683454391547, 0.11071218032157049, 0.03911706407961901, 0.04075770397321321, 0.02816233169141924, 0.028586708431248553, 0.02226331522251712, 0.05357948881282937, 0.04479500217712484, 0.04273147169442382, 0.04290450713597238, 0.041394088184461, 0.05585941471508704, 0.026656549307517707, 0.045122374649508856, 0.04787962396221701, 0.03758310791454278, 0.06649829461821355, 0.05953085266810376, 0.04094249874469824, 0.04434308248164598, 0.014993410059105372, 0.09021467747515999, 0.029452880116878077, 0.041374758948222734, 0.05037361494032666, 0.02673449707799591, 0.030867938658047933, 0.016724971392250154, 0.0208661758369999, 0.041281311423517764, 0.044020519126206636, 0.05932147796556819, 0.03780733670282643, 0.0431565627513919, 0.03956301690777764, 0.017713365523377433, 0.03412517471588217, 0.04401769896503538, 0.0024574462349846726, 0.02715793871175265, 0.015549365871265763, 0.03533667142619379, 0.0072801352052920265, 0.06586044837604277, 0.07956629066029564, 0.028286071828915738, 0.017154220331576653, 0.020831601032114122, 0.033948113123187795, 0.05143544272868894, 0.015228671800286975, 0.014736079629074084, 0.027376419566280674, 0.085019294929225, 0.0044281326518103015, 0.01018801220197929, 0.045084562225383706, 0.071320606948575, 0.013085882728773868, 0.04357314879598562, 0.07157852553064004, 0.026256986275257077, 0.03426074283197522, 0.021320967643987387, 0.033563769684406, 0.032935011040535755, 0.028095790730731096, 0.05816675184178166, 0.041001532881637104, 0.06293312108027749, 0.061810789702576585, 0.041940297742257826, 0.022553383641934488, 0.011137110541312722, 0.06088334630476311, 0.046919017695472576, 0.06258175868424587, 0.11346882107318379, 0.006843513492640341, 0.015803645146661438, 0.04893331410130486, 0.05389196638134308, 0.012095577567379223, 0.02252863301691832, 0.017649691108090337, 0.04481343712541275, 0.04695109702879563, 0.0432025981717743, 0.028987915320612956, 0.0024145749148374307, 0.0160409301679465, 0.048736259050201625, 0.02107295858877478, 0.022908625614945777, 0.06513094689580612, 0.06623518842388876, 0.010682813190214802, 0.014884049032843905, 0.004282972276996588, 0.014683353747386718, 0.04068496607942507, 0.01422850906237727, 0.03360580863954965, 0.035816744493786246, 0.038123506456031464, 0.016901776943996083, 0.04651455834391527, 0.01094730534532573, 0.033349170262226835, 0.023485578640247695, 0.023409794230246916, 0.04841224850679282, 0.02248619515739847, 0.05874672169738915, 0.030010700575076044, 0.029863423224014696, 0.03786901659623254, 0.04782772928592749, 0.03685950650833547, 0.06771404383471236, 0.0380979134934023, 0.00957228474362637, 0.006212962098288699, 0.04129060311242938, 0.014266232428781223, 0.03537858050549403, 0.02363138468354009, 0.03849000124318991, 0.06576519372174516, 0.046025779884075746, 0.038055581389926374, 0.008186282211681828, 0.025556803338986356, 0.06591169367311522, 0.02973263824969763, 0.08575399144319817, 0.003282338507233362, 0.04018222782178782, 0.03992998295871075, 0.03266934072598815, 0.0334305133583257, 0.05259690384264104, 0.09349826534162275, 0.06944545209989883, 0.02260740086057922, 0.013849845836375607, 0.03254762850701809, 0.12894980638520792, 0.010572633018455235, 0.016545340113225393, 0.05352905245672446, 0.03374372194230091, 0.040025337802944705, 0.04405950785439927, 0.03322805918287486, 0.04968925459252205, 0.1448592558153905, 0.026379817281849682, 0.038063719039200805, 0.08560567323002033, 0.020749528775922954, 0.13008538138819858, 0.027237103604420554, 0.03208095491572749, 0.01240454199432861, 0.07794873527018353, 0.03457411097770091, 0.021224503288976848, 0.020291783221182413, 0.009381754098285455, 0.048555675966781564, 0.04373850300908089, 0.004295459839340765, 0.030658209579996765, 0.0448504072119249, 0.030740246584173292, 0.07410056598018855, 0.039832913753343746, 0.010197648061875952, 0.05930848667048849, 0.05804038264614064, 0.06717603871948086, 0.06278707383899018, 0.031161304068518803, 0.0330305440002121, 0.07962865332956426, 0.04620642605004832, 0.01418102274328703, 0.05627526232274249, 0.033333058236166835, 0.03977269218012225, 0.03857250208966434, 0.0710032126517035, 0.013182622606109362, 0.034354045637883246, 0.044215099114808254, 0.07274921896168962, 0.05219773229327984, 0.07524069034843706, 0.1029022189322859, 0.09183496396872215, 0.016502182370459195, 0.01812463036912959, 0.004948763162246905, 0.08541830320609733, 0.03088256824412383, 0.020175601857772563, 0.022226597466215026, 0.03959697758546099, 0.057482436022837646, 0.018396267550997436, 0.028197832325531635, 0.040096580269164406, 0.01998287538299337, 0.045803606844856404, 0.011155678148497827, 0.10355029939091764, 0.017912159055413213, 0.04741290213132743, 0.031397548227687366, 0.03678207453049254, 0.045843244952266105, 0.015085952163644833, 0.005099061982036801, 0.010333103000448318, 0.02674439732800238, 0.02292443150508916, 0.0328421794984024, 0.021397050768428016, 0.1026146589720156, 0.025775979956961237, 0.034750382183119655, 0.026673418324207887, 0.03070703362027416, 0.06978871024330147, 0.038353089839802124, 0.02271320699946955, 0.05407868331531063, 0.041547642249497585, 0.05712048317946028, 0.034189311118097976, 0.011429333044361556, 0.06321898894384503, 0.02098700304486556, 0.09165472598397173, 0.09367040649522096, 0.07151558398618363, 0.004813990071852459, 0.045498432009480894, 0.03497677804261912, 0.019144929428875912, 0.02888234481360996, 0.020293310190027114, 0.07288821580004878, 0.02084766667394433, 0.00819198283352307, 0.04656373675970826, 0.002661645849002525, 0.028379402465361636, 0.055233257298823446, 0.02797161458147457, 0.07717860862612724, 0.05626560698146932, 0.06609326010220684, 0.02477815498423297, 0.02608018257888034, 0.09648952123825438, 0.0733957409102004, 0.06217171838216018, 0.0656066338706296, 0.0270033140986925, 0.015354827628470957, 0.03891889951773919, 0.03172009302943479, 0.032788867320050485, 0.05474336561746895, 0.1618792995577678, 0.09623425212339498, 0.14779140707105398, 0.09325170904048719, 0.1094684521376621, 0.11753411308745854, 0.23376712255412713, 0.16998441307805479, 0.09029560125782155, 0.11235305399168283, 0.13564975233748555, 0.16016320179915056, 0.14820218581007794, 0.12700714578386396, 0.11523562978254631, 0.09850155038293451, 0.1563065274967812, 0.16584511409746483, 0.11219367777812295, 0.2796329028205946, 0.13149727281415835, 0.12143302301410586, 0.09846241693594493, 0.1617007388267666, 0.11033948860131204, 0.17281172855291516, 0.09639047420932911, 0.07204123976407573, 0.12904005154268816, 0.21708015468902886, 0.14002168492879719, 0.09982928226236254, 0.16472251183586195, 0.17266574810491875, 0.15891159942839295, 0.20216975477524102, 0.08756554423598573, 0.1259672484593466, 0.13692727050511166, 0.2028857491677627, 0.10814191511599347, 0.06913844787050039, 0.21526411932427436, 0.2147916829562746, 0.10192570844083093, 0.14318007248220965, 0.20417981722857803, 0.3538825217401609, 0.10755152179626748, 0.08676653320435435, 0.1638614127296023, 0.09211655706167221, 0.16815469251014292, 0.1338467194000259, 0.12492129520978779, 0.08465906386845745, 0.22686804353725165, 0.19308310642372817, 0.20876207447145134, 0.23400348174618557, 0.09154703293461353, 0.1844958937726915, 0.11965572775807232, 0.14245487545849755, 0.23779702896717936, 0.21016333834268153, 0.10900195295107551, 0.15733302163425833, 0.08967254601884633, 0.15049712907057256, 0.2005291631212458, 0.12044811883242801, 0.14996877929661423, 0.16429867129772902, 0.14424336230149493, 0.09961916541215032, 0.37181441264692694, 0.09644137069699354, 0.12276329303858802, 0.1326423027785495, 0.13395298010436818, 0.12984605360543355, 0.1633804416633211, 0.08099666898488067, 0.10104437096742913, 0.12880536960437894, 0.07733239646768197, 0.09333857742603868, 0.16159136110218242, 0.12860433664172888, 0.08986551183625124, 0.13415098510449752, 0.1630294503411278, 0.16212612303206697, 0.11423300311435014, 0.14769788162084296, 0.11405256474972703, 0.11256084049819037, 0.15330684080254287, 0.17454976419685408, 0.18794009723933414, 0.07422928407322615, 0.0853512724279426, 0.10103887165314518, 0.2677577978465706, 0.12594948144396767, 0.08158897704561241, 0.11962205651798286, 0.2524939278373495, 0.11460554640507326, 0.10059667780296877, 0.06961788269109093, 0.1345311279874295, 0.1779826870188117, 0.12981166248209774, 0.11229121824726462, 0.20741093525430188, 0.13336608972167596, 0.10164303181227297, 0.1119576080236584, 0.17343091720249504, 0.1894056162564084, 0.09876176220132038, 0.09817447848035954, 0.09860082747763954, 0.1662147036404349, 0.1053715446323622, 0.13286712899571285, 0.09921553355525248, 0.26109690370503813, 0.07737305131740868, 0.106917415978387, 0.11565180393517949, 0.17537377076223493, 0.12280083828954957, 0.1974487307597883, 0.18265833612531424, 0.14505810686387122, 0.10644686466548592, 0.1279754110146314, 0.1316109995241277, 0.09320451586972922, 0.12269276674487628, 0.15554354031337425, 0.10238388073048554, 0.16418516723206267, 0.17647805681917816, 0.14321094582555816, 0.11411196624976583, 0.14268494123825803, 0.14516539173200727, 0.19995537906652316, 0.12484650156693533, 0.1324860064778477, 0.12548670783871785, 0.05167473711480852, 0.24345802754396573, 0.1102368273132015, 0.16602171555859968, 0.12986251444090158, 0.12608336488483474, 0.12669424148043618, 0.17699862888548523, 0.10292843900970183, 0.06326045273453929, 0.08382000654819421, 0.16564037039643154, 0.2709943038644269, 0.10511575601412915, 0.14266190497437492, 0.1189983481890522, 0.1477470711688511, 0.09955592700862326, 0.1192561851348728, 0.09290751579101197, 0.16934664105065167], [0.027697699006239418, 0.03975786778028123, 0.03749307797988877, 0.051045236323261634, 0.05417811997176614, 0.036195777865941636, 0.07194236342911609, 0.05378346439101733, 0.046717365039512515, 0.06564854294992983, 0.02068726815195987, 0.062385104392888024, 0.04761046184285078, 0.029037752392468974, 0.010161029567825608, 0.02348073056055, 0.04589059026329778, 0.020259804077795707, 0.043594812086666934, 0.037236235511954874, 0.15830575459403917, 0.02581295932031935, 0.05932404950726777, 0.03621147057856433, 0.0035190945163776632, 0.056725115136941895, 0.05251676673651673, 0.0437498986866558, 0.030432310959440656, 0.007937092213978758, 0.03538607619702816, 0.030794219273957424, 0.014576804533135146, 0.07197048340458423, 0.03206473898899276, 0.020207011402817443, 0.025910991462296806, 0.04944808257278055, 0.025576483240001835, 0.038629862683592364, 0.008020754521567142, 0.029380491032497957, 0.029901311718276702, 0.0957948858558666, 0.07062201591907069, 0.018899478927778546, 0.02718290084885666, 0.05524828207853716, 0.023058964325173292, 0.055135093425633386, 0.039038103277562186, 0.07924599456600845, 0.01628341578907566, 0.012450147896743147, 0.03305330566945486, 0.06292279038461857, 0.028351816836220678, 0.05984765324683394, 0.034418263676343486, 0.021524340227188077, 0.06354661003570072, 0.014330116500786971, 0.0602435148175573, 0.0222415202006232, 0.06755566952051595, 0.030714405002072453, 0.027699109086825047, 0.012608603847183986, 0.05377990208216943, 0.12016984313959256, 0.07812719210051, 0.0328001962043345, 0.03519950398185756, 0.06758548901416361, 0.034431024905643426, 0.02587862454674905, 0.07446899777278304, 0.004704807624875684, 0.03296108639915474, 0.010385981950093992, 0.009772637713467702, 0.051072090936941095, 0.06795740147936158, 0.03293875888630282, 0.04229570855386555, 0.09440462061320432, 0.022676162698189728, 0.05820153259264771, 0.0225551072799135, 0.055340842736768536, 0.015145785964705283, 0.07873399430536665, 0.05137503561854828, 0.06696968455798924, 0.033380384993506595, 0.05139524058904499, 0.008376181103812996, 0.045004814746789634, 0.031351368088508025, 0.02192887564888224, 0.005840418807565584, 0.06522730735014193, 0.014409070809051627, 0.06604706140933558, 0.038757311704102904, 0.04690583715273533, 0.046046148127061315, 0.031502424826612696, 0.035746648645726964, 0.02140602704457706, 0.030375080241356045, 0.054733751094317995, 0.07505776578909718, 0.026087372134497855, 0.016305578174069524, 0.05988595548842568, 0.0400999681733083, 0.05984943069051951, 0.005981110989523586, 0.024158960768545512, 0.04760890704346821, 0.035158793471055105, 0.030663946381537244, 0.03247770706366282, 0.006708164310111897, 0.0713829102460295, 0.05060402581875678, 0.08878947191988118, 0.007963824373291573, 0.07889088432420976, 0.028054117283318192, 0.03504656218865421, 0.03677087923279032, 0.07957340785651468, 0.056735672187642194, 0.010788966283143964, 0.0775183860969264, 0.020243469407432713, 0.04404451647133101, 0.07089239516062662, 0.04405026069434825, 0.0383142309874529, 0.0101057237952773, 0.06569833363755606, 0.019918202779081184, 0.07598956188303418, 0.03658281159005128, 0.009752458718139678, 0.02443750734528294, 0.0401685760152759, 0.089471616956871, 0.019642350198409986, 0.0011976880091424391, 0.02023795896093361, 0.05034695328504313, 0.03318422423035372, 0.038392338319681585, 0.019873031960742082, 0.01921068371302681, 0.034624298714334145, 0.03800892998697236, 0.04399890036438592, 0.03994028767920099, 0.027388156631786842, 0.053913054507575, 0.04208113510685507, 0.04293891310226172, 0.06872635553008877, 0.029126125482434873, 0.019372316055523697, 0.05020909564336762, 0.05080855800770223, 0.014556133864971343, 0.04797588051587809, 0.03350111757754348, 0.041103463154286146, 0.029427320550894365, 0.038189642946235836, 0.04042033106088638, 0.017431484848202672, 0.07214809418655932, 0.02113457168888999, 0.026669295693864115, 0.046102940978016704, 0.1076100327190943, 0.04594660385919269, 0.011671609008772066, 0.009794683210202493, 0.03393731858523097, 0.007573277043775306, 0.013805341095576296, 0.011076359260187019, 0.08301644615130499, 0.03624893419328146, 0.028703897260129452, 0.051153166859876364, 0.02333076477953, 0.017805172901717015, 0.02568827294453513, 0.07639577641384676, 0.07174507089075632, 0.01637212284549605, 0.04552437749225646, 0.01731680633383803, 0.01755689110723324, 0.041948064317693934, 0.04734863956400659, 0.048968989140121266, 0.03288529456767719, 0.039374307307298295, 0.011104536752100103, 0.029810129599354696, 0.012942625035066158, 0.024939074864960276, 0.04264626571966801, 0.037519836114370264, 0.01966561467270367, 0.02085621435981011, 0.010060247768706176, 0.008186391678464133, 0.03117735672276467, 0.029035412771918345, 0.08705260144779459, 0.09436381733394228, 0.02499820362572791, 0.02244589097244898, 0.054269500615191646, 0.08561617461964488, 0.04572944773826748, 0.06968821602640674, 0.0460620857484173, 0.04887325951131061, 0.017265570313611533, 0.03745060115761589, 0.017037649340636563, 0.06328276169369929, 0.07356478730798699, 0.023606222166563384, 0.018117932486347854, 0.019119946882710792, 0.019639891834231094, 0.029987564121256582, 0.014454342745011672, 0.026132158891414292, 0.061778933013556525, 0.04657118421164341, 0.03957508422899991, 0.050809801105060615, 0.04089073394425213, 0.03900585696101189, 0.0211317366847652, 0.06269023841014132, 0.020528149834717624, 0.024708563796593808, 0.021478002381627448, 0.059315158578101546, 0.04326674199546687, 0.052689690855913796, 0.036880063998978585, 0.06013057107338682, 0.003468619197519729, 0.05371635939809494, 0.026366820420662407, 0.1492585291271098, 0.009806319158087717, 0.029637533880304545, 0.03505013191897888, 0.06808346268371679, 0.026797488717420492, 0.054625731499982066, 0.03809001704212278, 0.02511796585167758, 0.04924620356177911, 0.05292534129694104, 0.014471567064902047, 0.01846367867983645, 0.044966015266254544, 0.037366705073509365, 0.031097444116312545, 0.02778395326458849, 0.08129763955366798, 0.07484997186111286, 0.03488189817289822, 0.0721215401426889, 0.013059309203526936, 0.026777237362693995, 0.03946052260289434, 0.02160290583560709, 0.029297786095412448, 0.045998947534826584, 0.027484190541144926, 0.06305259943474084, 0.05246318367426284, 0.08653453784063458, 0.021012521792727057, 0.07173776815761812, 0.060087270467192866, 0.03711581462994218, 0.05363863427191973, 0.02826457923220005, 0.04712357585958671, 0.07417776418151334, 0.04495664565183688, 0.0707657179736998, 0.04403603001264855, 0.051559422208811156, 0.06617833991185762, 0.06660141603788361, 0.038443208832177334, 0.03127933152427431, 0.04611513446434401, 0.023822315160941798, 0.008634671139589045, 0.09508200848358683, 0.11088805447798222, 0.029743399391009007, 0.03877945368003566, 0.04828691089642234, 0.041633289802121, 0.015905514192127157, 0.04869395663263276, 0.030237131686590146, 0.010250399918732, 0.021300117005011998, 0.04330199029936921, 0.04405755229527131, 0.04431607943843119, 0.029926357346994337, 0.05548120512685273, 0.07577743381261826, 0.014405741349037271, 0.02266030671307817, 0.05241583094175439, 0.03265183717303444, 0.03195265613612719, 0.029032453458057716, 0.04055878613144159, 0.016036898450693116, 0.06432841066271067, 0.035927380158682354, 0.018007619655691087, 0.010680306586436927, 0.02211426784924697, 0.019623481093731243, 0.04071967261552345, 0.05295657458191272, 0.028826149391534273, 0.007884699371061288, 0.04518995832768269, 0.06878993532154709, 0.056307798076886684, 0.013247341594251338, 0.13517559418687597, 0.21083625848405063, 0.0916856735420879, 0.189715507440269, 0.17282997054280713, 0.13443781033856794, 0.3137303434778005, 0.21645464294124395, 0.22869954525958747, 0.1280349906301126, 0.12438357211067341, 0.14993333432357758, 0.120914573490154, 0.16171933704754338, 0.07544233187218197, 0.07673393600271083, 0.17043553496478125, 0.17637884651776403, 0.11065137616242282, 0.12418023849022575, 0.38820245827082545, 0.13879577571060508, 0.13913759408751503, 0.2047202640096657, 0.13107220031088218, 0.12828320934204385, 0.13947561266832054, 0.16040736838476732, 0.14244881953345612, 0.09182380948914215, 0.09543673280859366, 0.12044104616506957, 0.12711358460364863, 0.18223259568912908, 0.10390958050265908, 0.09203034918755293, 0.1092747961229179, 0.16695069149136543, 0.1295757485786453, 0.16598315356532112, 0.12463559804018587, 0.11979815331869759, 0.07937690941616893, 0.14794457150856033, 0.10950614581815898, 0.07985635165823624, 0.22460511652752757, 0.12820028176065534, 0.14704060595249757, 0.13764400704531, 0.09799415885936469, 0.18356106971623376, 0.10258795649860986, 0.16260713862720877, 0.13186187512474135, 0.21678564080502838, 0.12692583608441055, 0.1550761505495757, 0.10821415577083826, 0.29396718833595514, 0.12202337180497125, 0.14617463835747913, 0.1459908825927414, 0.15081126533914357, 0.1412070877267979, 0.10820766940014437, 0.15969553001923487, 0.1756399791338481, 0.1267454051412642, 0.21927386900642887, 0.15223964728647843, 0.14089036878431216, 0.10195131253567524, 0.1103474221599754, 0.1646461893687956, 0.09002594932098873, 0.15739368478534743, 0.11181117486557923, 0.09587567605194636, 0.154161631653551, 0.13014405558351427, 0.19477677647955716, 0.21779809350846335, 0.10364912377553992, 0.1822617175639607, 0.1552953661303036, 0.11778910018620081, 0.17709461826598272, 0.17146229627542198, 0.08431187976384535, 0.13603716826764867, 0.14927776559488848, 0.143529505294282, 0.20737393177114427, 0.1841111050453037, 0.1437302413978614, 0.16887644596863538, 0.18096931191394106, 0.1930846946197562, 0.18125851202057675, 0.09991909697419032, 0.14453757932642475, 0.13603102328488603, 0.12111376592656597, 0.10604885828797705, 0.23478086659451947, 0.12966112524736673, 0.13758784130914137, 0.15973490837495774, 0.104322711849818, 0.13265306391986087, 0.20183914282824844, 0.17638920689933002, 0.15028423658804968, 0.09038075528223999, 0.20835925155552104, 0.12801193952327594, 0.22589162952499464, 0.08520208590198308, 0.18632908759173006, 0.18494134565116838, 0.14106472895946354, 0.11779345659306273, 0.09170888049993664, 0.0983743833785411, 0.15901783044682816, 0.11536455567693338, 0.13676190515980124, 0.10629773751134053, 0.15553150267805904, 0.1402267997036688, 0.11638152805971913, 0.15650554181775078, 0.12563742318889126, 0.15832178498385474, 0.08914275647839531, 0.14105674345046282, 0.08733800175832585, 0.26020113145932555, 0.16868467500898987, 0.12639269203646109, 0.1541989468387328, 0.13608398294309154, 0.18091145408106968, 0.11017040509614162, 0.1417439870419912, 0.12616583233466372, 0.12008063698885962, 0.1490311647648923, 0.13458637346047908, 0.19827594340313226, 0.18667768919840455, 0.06990095265791751, 0.12966882874025032, 0.09633421941543929, 0.12079015985364094, 0.16325346019584686, 0.10531243256991729, 0.0786736725422088, 0.19036482728552073, 0.16406560724135488, 0.10284406424034387, 0.15761926799314097, 0.10542459334828891, 0.18919558846391737, 0.10102910498972051, 0.15613788185874, 0.21609496849123389, 0.08538196023437195, 0.11297273988020606, 0.0986037144321017, 0.12242428740137257, 0.16259413619991392, 0.16084433009382337, 0.1190539202070795, 0.10269815800711513], [0.036091999645577744, 0.040232623359770514, 0.01155090518295765, 0.018319438568141777, 0.02246237036160892, 0.0575317999755498, 0.030338492360897362, 0.049192212318303064, 0.013669581876456505, 0.0413865628070198, 0.025317375366284978, 0.07513992895837873, 0.02483417971234303, 0.025466775259701535, 0.040277241278090514, 0.040365029926761054, 0.06504764081910253, 0.022842572616355028, 0.04080883794813417, 0.05033478206314612, 0.08911886674468406, 0.03162446359056048, 0.031072578458406497, 0.027772876710514538, 0.061756668583257124, 0.028551361792779062, 0.03037319147551898, 0.02524022540455917, 0.05021727040002588, 0.02261431211081799, 0.0601784692844376, 0.059206756777712144, 0.030669280567963142, 0.04362377439974807, 0.008828078534861561, 0.011149150031997124, 0.07017727650236338, 0.020933739106112625, 0.056942556984722614, 0.028324451996013522, 0.012623700058611576, 0.08481546406983398, 0.04265083363861777, 0.04569148317386862, 0.06587598152691498, 0.01041054889356019, 0.013262719821796054, 0.041349845050717704, 0.012730506241496187, 0.03753857905394398, 0.052611219871323556, 0.018201030761701986, 0.04057620062667411, 0.126963670772966, 0.027991452188871335, 0.02605692181532504, 0.008659264058223926, 0.03805414162343368, 0.054218592995312065, 0.052095408682362176, 0.04474954563193023, 0.04472762258956209, 0.016772400194895454, 0.054906816221773624, 0.10301275440724567, 0.03065321121539455, 0.03318386428873055, 0.031988906339393, 0.03558374351996463, 0.0410879374248907, 0.026130396290682256, 0.03822422331722919, 0.044739782679243945, 0.023420048855768982, 0.008085674817266408, 0.03366086857568007, 0.04441917859367095, 0.040895635829656385, 0.017960775294341147, 0.0717213073221501, 0.03758607279451098, 0.016270999658445362, 0.060764509908040054, 0.015509883614868158, 0.034128740735468455, 0.03333359258249402, 0.07736101368209347, 0.07210332783870399, 0.045493474463000894, 0.028976094763493165, 0.03592099397792481, 0.03104561252257554, 0.00800690697360551, 0.07988991899765097, 0.04222362746077124, 0.024551191381760873, 0.04066149194841273, 0.06768299237592146, 0.12247830833075568, 0.03330032210214995, 0.0037352359822762082, 0.07473453079001047, 0.048228043742710724, 0.05450398588436656, 0.05553586430323776, 0.012996025343454676, 0.04429339569469448, 0.07041197328362614, 0.035585023724706843, 0.020395125429786276, 0.042204698984278366, 0.020545120896713343, 0.06350863433908671, 0.01637144378037192, 0.09953930290066637, 0.05859679302375298, 0.07339369258261286, 0.04730200300400611, 0.051239144668215886, 0.016145563713507727, 0.05908409832045436, 0.06179875577799976, 0.050588756130309775, 0.047347889994853176, 0.053857931488892063, 0.09361124990391545, 0.059659396356437355, 0.007425418034472386, 0.017741081028361805, 0.022496874662465416, 0.01146842381785973, 0.03184523397067096, 0.07813231291947886, 0.056061646246234886, 0.04752155626192689, 0.03136799219646491, 0.026978017995133996, 0.02832698457496008, 0.029767517335130833, 0.044734710099874064, 0.026193441735813394, 0.06504285396658815, 0.04040215215354692, 0.0022773014825361315, 0.04341057392593939, 0.04313251716666855, 0.0406935230421368, 0.03555432478606235, 0.009276702166971518, 0.026184502567048185, 0.026513763805269264, 0.055267615025513805, 0.05451799021102488, 0.02108877190039493, 0.053928005072521046, 0.01617343135876581, 0.015019208967714803, 0.05764184192230459, 0.018993792909896, 0.033348940196447074, 0.05861116471351124, 0.027543712640181184, 0.0572882827691501, 0.038183182550710626, 0.024640438350616023, 0.014465181811829098, 0.0053540732005785685, 0.06646955123869702, 0.04431273977388628, 0.04765841942571569, 0.05512174961040728, 0.0006436743626636598, 0.01685536488366779, 0.05578143354796339, 0.05119660105265211, 0.0033786370386224007, 0.033640184919931926, 0.010906672760029323, 0.02840729237505002, 0.014318827506940579, 0.028586112857738044, 0.054252149202511646, 0.06321893699350767, 0.11559977196156979, 0.047870506678009406, 0.01240908579347888, 0.04738991039630491, 0.06837946828454733, 0.03243750492401887, 0.012393871766107623, 0.043015884948545136, 0.033205208455910906, 0.017385850187565666, 0.05283465827233158, 0.04092707320523914, 0.039248027169378474, 0.03559386641427409, 0.05537266602914315, 0.05055463218013756, 0.0987785570032429, 0.07692041544942185, 0.02278258110891329, 0.050251461143488996, 0.012316450920479838, 0.030232047975005116, 0.01057364326698007, 0.0625063713232521, 0.043758433384937234, 0.03778542479267344, 0.047748898359714076, 0.0491871582926251, 0.08229743863921613, 0.028731681413773913, 0.05092106388474349, 0.0336373796017142, 0.022463411223725416, 0.031305373486247845, 0.0512614276522072, 0.002144455424968328, 0.060994560844847, 0.07102302057319321, 0.03738266124855727, 0.030297822668217123, 0.03549421453499235, 0.02920047569205053, 0.01802520298952004, 0.043253776675555855, 0.006042506083758781, 0.022614727713516913, 0.03180948842782527, 0.021955817464913707, 0.03399909124709666, 0.028164493196527474, 0.040403361854259856, 0.013562005715357373, 0.11909804088645615, 0.057802873125183396, 0.01873908782727085, 0.060889654560014606, 0.03984239840065129, 0.08831958853988908, 0.027736897391150706, 0.032193345759878866, 0.025391436138306744, 0.08177248048014008, 0.0700974436767865, 0.027387813388486393, 0.02606907262816094, 0.1014001268777065, 0.047257804399123415, 0.047418316098628566, 0.009418647186976159, 0.015974986636138055, 0.016908964644244406, 0.003324328527014586, 0.05403896728239488, 0.046255329871200956, 0.0451504278316861, 0.05006793544453103, 0.02423535188427195, 0.02977802614623215, 0.013139723687345395, 0.020399761997396126, 0.02930892016593134, 0.028087194805266336, 0.03688808290462475, 0.03337353125971276, 0.026071308348036837, 0.04368055611848831, 0.07820067956345156, 0.04674069816246629, 0.027868079414474778, 0.06002757581882179, 0.027497339542605914, 0.08567875251173973, 0.07030748631223105, 0.07228365488117561, 0.08654873512568884, 0.032736720313550904, 0.06225932520464994, 0.036077405311516486, 0.014922703794582048, 0.08196627750294283, 0.023474364788853563, 0.050214335205964744, 0.01934220712428214, 0.008993146093416726, 0.059017787425545976, 0.03053600012208335, 0.052845107711618766, 0.06965096021303907, 0.022288579784799367, 0.020365541568025947, 0.03239784455217887, 0.022104480776761193, 0.03938302383176051, 0.016748074449424166, 0.012499958065745886, 0.03366853496117983, 0.008732750593480887, 0.02479982198565267, 0.028449153214751277, 0.032878218189580366, 0.027630714612314478, 0.021401234625955112, 0.02850939334166469, 0.037364077870734036, 0.019417824551055674, 0.04075954821018968, 0.026661113515729085, 0.055210417704074644, 0.06942337320651859, 0.030321280100906733, 0.04946327433572151, 0.0531860429327935, 0.020275363203836605, 0.032254762190859765, 0.02931372742750682, 0.02067834011540981, 0.030095693182374816, 0.028508929499366786, 0.035440924621070735, 0.022546207073901314, 0.05215726669121068, 0.03923211552319117, 0.019198601548851002, 0.010105036380991805, 0.010271651317452779, 0.055864364840090275, 0.03525632280798163, 0.023250763115356676, 0.029420503924484365, 0.10748014945420437, 0.04365335640613921, 0.033315098262391984, 0.010829995917447377, 0.03707373114593793, 0.022450193573604338, 0.03790695518546272, 0.008715083768038312, 0.026381956522527616, 0.046202860030462034, 0.029716201534029096, 0.04871627672400791, 0.0419708890694892, 0.05425791197922081, 0.018179731123382226, 0.012571890729304869, 0.000835785956496693, 0.028348349151201546, 0.02380829413596075, 0.05095555890875403, 0.1055042703228537, 0.13440580893075094, 0.08620424501714297, 0.09772564240847714, 0.16637720429571345, 0.1442024254356511, 0.12706297013210133, 0.13672769215190783, 0.13383759098360315, 0.11590247915592045, 0.11292119772406295, 0.1305627604597248, 0.2705070987576619, 0.10142428378458135, 0.12386037284159102, 0.18393116391962394, 0.1412573756533675, 0.13605468295281753, 0.211564275668934, 0.09175228129606694, 0.19441040785750374, 0.19878101942595094, 0.10197723575402051, 0.14289762591943145, 0.16190389433177188, 0.08023904010769911, 0.09343775062006898, 0.20613835979020223, 0.18285032972926274, 0.08413988703978248, 0.25767634506337345, 0.08987382389022969, 0.17403293255483732, 0.13813982106512412, 0.09312739930464886, 0.13106164697092026, 0.14649840770289302, 0.12109671137295663, 0.12223224926856346, 0.07194708348833956, 0.11231993194087408, 0.15911058406345546, 0.12931653123814613, 0.10507089318707585, 0.17018102284055203, 0.11477063715574332, 0.13299722748342901, 0.13150371465599164, 0.09920391152263619, 0.1399032975314185, 0.19220863381633535, 0.18725263100350276, 0.10140752609004267, 0.25774123845621943, 0.11490968594443984, 0.0800500373588875, 0.11425874079577625, 0.12787293526344, 0.09897517418721691, 0.19123241276247427, 0.13673109118826687, 0.12413823293172754, 0.18384773167781532, 0.10793495981488377, 0.1965411880519241, 0.13063749473076314, 0.12985095178009942, 0.15768174198456109, 0.21879130974411964, 0.1833409338723868, 0.16261239303275943, 0.07659675742615946, 0.17779196990886703, 0.15403733676066622, 0.09203256078762934, 0.08424245184869505, 0.11656638220301829, 0.09849418085650541, 0.10834519678610377, 0.11693516280502081, 0.10643804052961059, 0.08326855371706188, 0.1455844973679632, 0.10035458923084661, 0.08935840232879855, 0.11184702801983804, 0.12302067727432586, 0.1673886476783082, 0.16560832445975393, 0.0745002125040628, 0.140075460949447, 0.09631536886445247, 0.10243689233902842, 0.15745761338621378, 0.10689717761124484, 0.17779689776943997, 0.1566234542406164, 0.21474311681231484, 0.1730790056171827, 0.18412063422147185, 0.14157220954075456, 0.16494574985699728, 0.08554640531656332, 0.1989921010681428, 0.13091090193483979, 0.11636604685918428, 0.1713001073221676, 0.14762788225198165, 0.22920187533600256, 0.07179960390203632, 0.16793794085970148, 0.09978479050914757, 0.1357115138671361, 0.09347880622954108, 0.26544651249423623, 0.12202677826280706, 0.11818972634500824, 0.12347613330348395, 0.1277774802292697, 0.08244779033702798, 0.12058647000230849, 0.1071789933484979, 0.1702345465309918, 0.251666700351052, 0.22598834621021524, 0.13440916343824938, 0.12758326018229127, 0.07588318985654041, 0.10312080368748866, 0.09292905291658826, 0.1563172589521855, 0.10335191589547321, 0.15054624440381303, 0.15643113409169018, 0.1281190462759696, 0.21456035552546382, 0.15662620018702, 0.1213597581954673, 0.21542789647355676, 0.08837687491904944, 0.11143518800963648, 0.2628899324918166, 0.08231071566115133, 0.11493951285956427, 0.11787657713284716, 0.13401974370935932, 0.10586695047095418, 0.12432367337169126, 0.0733514346939046, 0.08561107606510632, 0.08103883781586774, 0.1322115454240702, 0.13842664629919454, 0.13815369922667742, 0.10275170396198519, 0.12432668649125844, 0.1523520826594904, 0.07226206580526195, 0.1172417143243365, 0.1337032622541301, 0.09133421466685832, 0.23262860864633694, 0.08475795504637063, 0.1415267158881761, 0.14161464554490522, 0.12775745708495378, 0.17408023704774678, 0.10545296565396711, 0.17378119606291875, 0.11040482728276402, 0.16404390684328973, 0.10016931948484853, 0.11142619317979552, 0.17411507345968857, 0.13435615925118327, 0.10633005804265849], [0.050130450254073367, 0.008586687581555452, 0.037126505267224275, 0.03446707101829816, 0.03388866338355001, 0.06050799769582227, 0.012845039109379286, 0.028973280168429483, 0.08843957155477256, 0.046339170294231735, 0.03690185345476493, 0.03559808923455421, 0.022861549332446884, 0.024821932420309167, 0.01732986442220863, 0.027241790266998578, 0.018458118138369173, 0.029635847349709366, 0.0249267422259436, 0.039262187347048894, 0.06663744730758481, 0.045913544890936464, 0.02468303391651716, 0.031505452789133415, 0.02633377443999052, 0.06586397357750684, 0.026196989201707765, 0.022259391116676852, 0.04885238660790492, 0.03283879159425851, 0.029400883395283017, 0.02270743680128362, 0.053565736816381104, 0.04653115276596509, 0.020327230049588252, 0.046757782401982695, 0.03967232783907093, 0.0363129073230084, 0.02585800211818423, 0.05945895711192861, 0.07274243573192507, 0.02746698199189268, 0.08217879149015062, 0.009325553110102192, 0.09351022134069353, 0.024170681135728955, 0.01571842803969048, 0.03719563261256553, 0.028917452109453734, 0.03139186337648425, 0.06611530188820325, 0.08991712078568526, 0.01877231006801594, 0.025672537558421027, 0.0285684831396793, 0.021067681918793824, 0.011244069792155642, 0.014773039511055686, 0.031428885413333774, 0.034021719329757616, 0.02119176529959077, 0.011859481837745989, 0.007987866247276543, 0.00041319158867736405, 0.07717389598838054, 0.02756066885922337, 0.05223320324148517, 0.016025525037548505, 0.08253632113337517, 0.05098164911032654, 0.13169382320484146, 0.007869802611821797, 0.05406981836131308, 0.03557235897460487, 0.019415546157688368, 0.036902680949424393, 0.029544806238845922, 0.02722904388065217, 0.05423081987828482, 0.027424861400504597, 0.057456902432022616, 0.025822421703196596, 0.05577852432907093, 0.03149275835312437, 0.005481847374539939, 0.08009015044081025, 0.05004991609894205, 0.031071092307684012, 0.03480262195807882, 0.03281417826656252, 0.05660457180056255, 0.08696619319380261, 0.05149762728251517, 0.07896823837654665, 0.013016016946494346, 0.05764948975411244, 0.013176454431231832, 0.06747859006281942, 0.015414905410580104, 0.0589209111785749, 0.015175568350969115, 0.0383297901134938, 0.03201566076313611, 0.11580951031646691, 0.05122036091051996, 0.0222058878352982, 0.04164927937381435, 0.07368120059254579, 0.03554026479832828, 0.015766968208481558, 0.03355943554197438, 0.049822715009213425, 0.04998515629267786, 0.07318191332160495, 0.010686583300412167, 0.01681957110122312, 0.014535692334902706, 0.020810325513593853, 0.05121305075590499, 0.010399581806268543, 0.02812478458508849, 0.04122444435779471, 0.05768673072452657, 0.03163664594467264, 0.043753683639806695, 0.023778333634254523, 0.05437913438072428, 0.01005098483801703, 0.09305065381340683, 0.02063247167825466, 0.02184735258197179, 0.02683050315681612, 0.057181621305062436, 0.015316557855840074, 0.024002777645364404, 0.013325430372788105, 0.043737527084886096, 0.02446353631967213, 0.0206229016839643, 0.014685738824482542, 0.02716178489208687, 0.040077529338304885, 0.03217320758267306, 0.08852612823829986, 0.08392025585635565, 0.053962937963660806, 0.019538987580745015, 0.07434349317918532, 0.028941544078406878, 0.07258947909576818, 0.03173784520186018, 0.022034273606550414, 0.014910167064954294, 0.04234067899233196, 0.004639712460630108, 0.010464261831657495, 0.03435216800426133, 0.0380367419711547, 0.017746496851032134, 0.05298780415614601, 0.06655831952230074, 0.07585244267829694, 0.06539681387948804, 0.044852681894553825, 0.010751959089247975, 0.03958669141866267, 0.03656407607195433, 0.05736330276704393, 0.07713534141657874, 0.033451501294621266, 0.036855265134363435, 0.028722235729219392, 0.0030153260649967706, 0.02991287808981724, 0.06866995230666362, 0.00882967879078933, 0.014728247188031673, 0.023223988282552455, 0.03250106987252366, 0.031070739787537605, 0.026306789950467646, 0.07757409170153551, 0.028220979911566246, 0.017399129064870067, 0.0712300649320241, 0.033666508898022585, 0.022651868493994698, 0.011670544954540674, 0.03699995795614086, 0.021273577804095112, 0.02527022486901842, 0.04115950272534974, 0.06920331157743931, 0.03797922923695296, 0.05699247383745387, 0.009155249699688284, 0.04737626601126976, 0.04537651198916137, 0.016509329252585303, 0.03415748411498498, 0.03670036778203212, 0.05467675415275153, 0.0395105507777771, 0.012713216983684106, 0.0698434584774077, 0.03304445926914923, 0.02133797952410532, 0.023993337526917458, 0.15359788143541664, 0.03264137289079372, 0.02645823817147175, 0.02674768133147154, 0.0358507051714696, 0.07450470249750651, 0.06283328737481497, 0.024625897822261322, 0.04304794201743789, 0.050862486168625765, 0.04014774021925405, 0.008463060621579643, 0.07073894128552638, 0.026261116327077616, 0.01244892984686885, 0.00978490355919348, 0.04374345313408412, 0.021363886044127867, 0.03740225394722074, 0.06942794483620673, 0.040525716030970216, 0.09472775913309306, 0.048970722054946236, 0.02915184089943068, 0.05947982630459592, 0.03295454807812348, 0.06749993422999978, 0.0205718660436105, 0.00429659625297063, 0.0447724149125861, 0.06155498624139, 0.04256710453773849, 0.059502844014787115, 0.00782786848503747, 0.019431140535743907, 0.040764869409031235, 0.08991041919216514, 0.008700613743712893, 0.07341057644225657, 0.011709940008586273, 0.03059041810047347, 0.04392404363898095, 0.041448995980317704, 0.035466354311211035, 0.01462756094042561, 0.09406918470631354, 0.035691358643816784, 0.04342385465861298, 0.039239767065737396, 0.05646589779644273, 0.033376908031641506, 0.025793778513616417, 0.010291756098013138, 0.0364401225670008, 0.023737266892567277, 0.013967734139441745, 0.0756418434320949, 0.04817915476451162, 0.022435435967054218, 0.030264926972449757, 0.011405925706640119, 0.05114337051054463, 0.04221304443490226, 0.03415128718188498, 0.03185852954629809, 0.010566953733359696, 0.016988226016110275, 0.02911584117100574, 0.03213582560420036, 0.05045511388743762, 0.06465343423769809, 0.04734117355837952, 0.05371636310883332, 0.05131702193466481, 0.021498227761185262, 0.03192856231180485, 0.05318572752003092, 0.03763725500903092, 0.025031017685250845, 0.03357753281306941, 0.020865420701738913, 0.024516262201359496, 0.02968263976072194, 0.047451215505134314, 0.03137621148198377, 0.028610305016627535, 0.0203772155509796, 0.020346180790511426, 0.029829933810106013, 0.018297734459338244, 0.04785849501786288, 0.06443562873755582, 0.04741347729577683, 0.04983232211088762, 0.044974587071919814, 0.07142668211599812, 0.05101032569655217, 0.0472161328070797, 0.029106161709933076, 0.031568754275212996, 0.03219042540877126, 0.021969736444589216, 0.04008510666608345, 0.07259972815518267, 0.03194843702658545, 0.09030403947690502, 0.03616608082666062, 0.07819275342626497, 0.08962301508290693, 0.007358004586421885, 0.06513225307571702, 0.03972939899540506, 0.03197430458385497, 0.05588307809375692, 0.007144985474951682, 0.0778273050673306, 0.035955518687842414, 0.013087337338220095, 0.016096409417514224, 0.06723885409883223, 0.021457170296343975, 0.0767587311565876, 0.028265169239602983, 0.028810694166168105, 0.07366637248196639, 0.028588279928953853, 0.061678372003370896, 0.051883325140806846, 0.04554375867883209, 0.039981992667890154, 0.03585263475542888, 0.0325249855814036, 0.03870319800626021, 0.06569016259163618, 0.03156425314955413, 0.0407693705346901, 0.07175657417974435, 0.006551416690854239, 0.038057522106100805, 0.054326764729921706, 0.038974159833742306, 0.03706735609739553, 0.028565688953676727, 0.016522353944310453, 0.16004794626496732, 0.06693418021313846, 0.29895605344790965, 0.187942293996457, 0.09494232886936516, 0.23722119658486918, 0.11328677224810235, 0.1482419203966856, 0.19680218654684722, 0.14264599332818761, 0.205115427961573, 0.1269172568572685, 0.11815673788078129, 0.11831547584733926, 0.10935491838608868, 0.11885964078828692, 0.12547904887469485, 0.10983580781612545, 0.11257568345172331, 0.10597324828268029, 0.15948645217576995, 0.21261729416437447, 0.08394813834456727, 0.08611621145973913, 0.1647037354996428, 0.12028384444420226, 0.12588075856911018, 0.09959987699403428, 0.23500452021835372, 0.2138646662933752, 0.11796656996011734, 0.0718834888539277, 0.2798833034466952, 0.16563358716666698, 0.14490425965050235, 0.16748285590438172, 0.11868341782246716, 0.17387432075338438, 0.2119665642385371, 0.2594769437564537, 0.16818955860799178, 0.12930789263918996, 0.15856727259233594, 0.158854839974083, 0.17897136131068692, 0.10513032437302172, 0.09859507583314553, 0.1306119203218259, 0.1166840571386274, 0.19318535953061655, 0.09833118296228349, 0.16520766861503944, 0.12462623213650659, 0.2014246681937948, 0.11278361838776618, 0.18371916201431304, 0.06994033843511716, 0.08734134142287076, 0.13755248539382592, 0.15077990217832848, 0.16693917335942388, 0.14676936581963673, 0.17752945743268356, 0.14822206052485853, 0.14872357423882931, 0.12861563212936744, 0.15500236622756347, 0.08702731647645123, 0.16487521614180878, 0.11893890216015279, 0.18828262807801366, 0.08304920454975218, 0.15310469461837783, 0.10179961755056866, 0.0648823200026527, 0.12443691768567078, 0.11967357640969567, 0.2203555344021879, 0.3642206091899425, 0.1149434685066808, 0.15347272565122694, 0.17294927820330486, 0.17101521167205647, 0.12424689819454215, 0.09881016507279128, 0.15567071473924443, 0.0847911364689935, 0.08308435266371816, 0.2513807063223794, 0.11938773081055842, 0.1358058853656985, 0.1527686056215316, 0.15862695610849187, 0.13752968661719933, 0.13260420091683045, 0.11972522988799028, 0.1887650092248805, 0.1727765062241815, 0.11256423211307265, 0.15769309684401378, 0.15690650936448947, 0.10369391980930232, 0.1696672785328701, 0.16575507674133405, 0.10050573502667248, 0.11977108719293028, 0.1275722318678163, 0.1453773639514111, 0.13718301459448412, 0.1024873806454707, 0.14235744631150737, 0.16386007686378434, 0.14282658754382282, 0.14936793653760105, 0.14079685817705467, 0.1740461724693887, 0.09393708984134719, 0.11585701518924907, 0.11507426461321302, 0.08122331346385181, 0.09800427433219738, 0.10632782417815179, 0.11406329620513134, 0.12126923102186993, 0.10939428932033479, 0.11430510276113637, 0.1800686414935626, 0.1701414366834797, 0.22426113107940182, 0.12721922190394253, 0.15299185848562047, 0.12843463715398684, 0.1965963889961131, 0.1597472873982042, 0.12971855263458565, 0.13177372282370925, 0.1289045056910254, 0.20451180957024917, 0.12402269538142718, 0.12920868233777583, 0.10844632182852365, 0.12213039692142047, 0.1392159055103548, 0.16345464158803225, 0.15803403948666528, 0.10285657685017213, 0.13390827312832698, 0.1891385915223509, 0.1376670433091931, 0.20190914219710976, 0.10565595788648352, 0.1206527512113098, 0.16931507008848712, 0.12442050880054012, 0.0481185398530215, 0.08791944477707148, 0.17699723364785314, 0.09058258976438083, 0.11268325033597648, 0.15682809404097497, 0.13671038526808843, 0.16265119251329452, 0.11295305812382139, 0.12119758408516645, 0.17774218664271757, 0.14308767509646714, 0.17164667544420809, 0.14719472033903003, 0.15144535631407052, 0.17510863108327612, 0.21411512629128993, 0.16651812329655513, 0.21359523700084537, 0.11846091452753171, 0.12836163950851187, 0.09004791689221747], [0.039808170549804345, 0.000505722850903112, 0.09082440374186262, 0.03793836658587679, 0.041229027119698, 0.017286903348576743, 0.02956410764454631, 0.010838101097760955, 0.06931420328328386, 0.0418303077458404, 0.0035007919950658106, 0.040854379840311594, 0.025466040533501655, 0.04937081386742648, 0.019539262175385375, 0.10577546592685394, 0.10355495265685022, 0.019938261175411753, 0.05693006292858627, 0.030214431244530715, 0.032739473681431264, 0.011940081858483609, 0.028996728324273136, 0.020184060485917144, 0.03909532657417003, 0.012167599288659403, 0.06604007779969834, 0.02193488704506308, 0.008003721304703504, 0.08662908003316261, 0.03167936025420204, 0.04365766086266376, 0.00808948110716301, 0.04066622685058974, 0.07156121864682063, 0.05164176720427349, 0.030983559699961916, 0.05304887177771889, 0.03531268892402295, 0.005522575975192012, 0.00695604998327326, 0.032662312587490305, 0.04406128529808484, 0.042335728867328726, 0.033362758986186236, 0.04433087044162676, 0.08352762262802571, 0.023978451899893116, 0.07290794950677082, 0.0479760771850124, 0.023755466208967846, 0.024085326731437817, 0.027915025821130257, 0.005251345583019429, 0.02626567496918142, 0.07278296441654675, 0.0838875345652923, 0.0586698240658734, 0.02979717912239721, 0.0035738701171794673, 0.032482749957125634, 0.03570541121007409, 0.03680876958242152, 0.0243317253261921, 0.03595107693399768, 0.054038217713241465, 0.01715340211376315, 0.024734093676670454, 0.016367948264814913, 0.0256955385702895, 0.024896473732951563, 0.03727462681126781, 0.040406987245660275, 0.02617006222862983, 0.0167226373378071, 0.054305431694956496, 0.08204191719414666, 0.08024231297895312, 0.020259828197595198, 0.09880405719741248, 0.05165223890799098, 0.047886444299365394, 0.028239179227966815, 0.03337647387525067, 0.06912586104590446, 0.03992411999206524, 0.023604325979249552, 0.03556605814083014, 0.0375756456196541, 0.03216622026229743, 0.019080310630670283, 0.05216108504100703, 0.06613907287828624, 0.059311254881322384, 0.019546778275980614, 0.035110286698909476, 0.08273097904748283, 0.012155991171312053, 0.04366218425275292, 0.06152807967737317, 0.09585276595316827, 0.01308998773311032, 0.04446522143553011, 0.026979799149557948, 0.03313366541988216, 0.10102871907292865, 0.037201647719484754, 0.09614050402888097, 0.06523970121634193, 0.05503303327714093, 0.06262122609768994, 0.03521959763020277, 0.06482435084762983, 0.021056805744592566, 0.04507539670157712, 0.02398506814643042, 0.06907160262926482, 0.0658096483675763, 0.02642695850227028, 0.007899823413026752, 0.024179445899790153, 0.06095756107242778, 0.13724446442211047, 0.01779198122676462, 0.006430283347071963, 0.1504594279685989, 0.07736154802842066, 0.009438636006962042, 0.01329706734395586, 0.033621523616602644, 0.06259807851165533, 0.003252995379625645, 0.04327024864323903, 0.05000132769055199, 0.01481901741499314, 0.016588809558015782, 0.014933557704353007, 0.0481737370864721, 0.05984655115753412, 0.08307480122311972, 0.014026551198185189, 0.01217768322021584, 0.05387304903706536, 0.029057643805572297, 0.0628569173568394, 0.01968004202353768, 0.1283998749568127, 0.05641975105390884, 0.019950391579186544, 0.015141185576794669, 0.02911913259595167, 0.005236632505329908, 0.09416014974704012, 0.0515577523765387, 0.07247222718433477, 0.04068075810209848, 0.04159710639214609, 0.014156696997815743, 0.06802549352869391, 0.06748510611942038, 0.07374452805379406, 0.008138392349792412, 0.02388994522334542, 0.006875904527987586, 0.02077496588754002, 0.028285498519835528, 0.028088309882150497, 0.04574507736833766, 0.05281640143948607, 0.038207992547540925, 0.022319150702969637, 0.010385442965343827, 0.04335956240538508, 0.048255814908770844, 0.042469133622944355, 0.02766110370430397, 0.06340959473163821, 0.03536470605467912, 0.023121479134715628, 0.020785491396964062, 0.031782604128238745, 0.04230788348650094, 0.09274858486605808, 0.03101591548329452, 0.008472183471894823, 0.13363508856855333, 0.022409048906411044, 0.04047253001772333, 0.020953569292032626, 0.03368779369338881, 0.01597585309355054, 0.10248551043332554, 0.16286099766148254, 0.02547689073253423, 0.05631413972878363, 0.00279310177120351, 0.06976085744099692, 0.08286004594992846, 0.06838718662038445, 0.06923543915036134, 0.023564006951346528, 0.05996594045427628, 0.047313335599028505, 0.013709966769965831, 0.026708803925430402, 0.036742618249263614, 0.05066022124083247, 0.03082918185100425, 0.012652714322030079, 0.046604213493992575, 0.04618035069142934, 0.026941754804283846, 0.06183606725244317, 0.03412827689317055, 0.025545235112076625, 0.04172537177510094, 0.026665178629627917, 0.018938862849608995, 0.048132050651474856, 0.06283198861638084, 0.050442783103790134, 0.03681400172354188, 0.05130623481818475, 0.03180443811288569, 0.01740827789035393, 0.014907106633472722, 0.024996656247822102, 0.04009541138657369, 0.02639881997311022, 0.019633681913546752, 0.07826015527825803, 0.13157006265828386, 0.03221032238798216, 0.06308595897280611, 0.03353595770022366, 0.05298417505400721, 0.0218067385503673, 0.04679104546085, 0.03723132991581224, 0.007125056490622228, 0.025264155956392642, 0.032785549919935875, 0.045061255077598616, 0.04797092668013647, 0.04693068054621108, 0.05467132905323524, 0.022968045668676496, 0.06267885386478156, 0.012104627130611334, 0.042375938428449444, 0.06712586953653954, 0.008597066516813356, 0.03839960765617434, 0.04346219400758855, 0.07537995435995981, 0.02938805722806137, 0.04806461540283635, 0.06664159591309726, 0.03190912175341509, 0.058488239083089866, 0.01842199038947001, 0.009227789068972925, 0.03569203399820253, 0.01953514696651837, 0.056353232357650995, 0.016946255709626712, 0.024725041330384556, 0.013470177927956684, 0.02398333337623626, 0.06210947445651982, 0.04770510051457677, 0.047907261541695334, 0.029308478588063736, 0.06974555435590446, 0.012115391982661095, 0.021460062816913705, 0.04087813969817944, 0.023044058289087843, 0.05807884444948286, 0.07306168539798819, 0.04054231416375842, 0.04066332505317405, 0.05729055745177902, 0.05782177562650759, 0.051938741307822056, 0.012931952023791382, 0.026484285699552856, 0.05203845998039469, 0.030552986027032603, 0.014992630804044893, 0.022022879784344696, 0.06463134792284109, 0.06913136778166518, 0.03358240130182821, 0.044458512420533225, 0.05267790926154703, 0.0546579926594859, 0.018159954743168782, 0.033621111724642105, 0.003913257960448391, 0.04076386379892938, 0.13069438777165487, 0.09974851433071308, 0.02691428791877115, 0.037438634026329964, 0.0003461779726876557, 0.018204257248726208, 0.07633402230567299, 0.08291929902043194, 0.019630676215456333, 0.05528626519662794, 0.049848189228214324, 0.021461253963934723, 0.0361480689025484, 0.04140489756537136, 0.027606310941337142, 0.037679223460145295, 0.03999244581791572, 0.08012086051166989, 0.03398049302631989, 0.032088799416669644, 0.02989052274642745, 0.025065846675715875, 0.07780793501297012, 0.07708702018135227, 0.0437484589201631, 0.030424382966884878, 0.046635966282337904, 0.03517925819323864, 0.033957924315473065, 0.039918453694554046, 0.03834901544905733, 0.03707259565999266, 0.04448151899850927, 0.04620986590452958, 0.08828518999507651, 0.007677431440242799, 0.028092883367207833, 0.0729434761160519, 0.03164894333167467, 0.024333777364518028, 0.039445627699024044, 0.08463429840048775, 0.021578502164629754, 0.004405589916132158, 0.049117815724457614, 0.03995978018792812, 0.10450222995132208, 0.06546829754370265, 0.013130674124113284, 0.02584020356152905, 0.07114292195183225, 0.1795542737818323, 0.14520292956149206, 0.17211413942277431, 0.24121242226101458, 0.14217346790246665, 0.06283225578954443, 0.14915075444150716, 0.13085420185234398, 0.1205822397605516, 0.24370397528400645, 0.07516265352023765, 0.11500495544169098, 0.06521076487842947, 0.1546604884788394, 0.0963895019958727, 0.19043224398046732, 0.27354420453775674, 0.17324149142950773, 0.1406974549172446, 0.13159732916392386, 0.12090920776245184, 0.14389197021955624, 0.22870886663440615, 0.1427194065763615, 0.13549548952141777, 0.2018456588848494, 0.17097843083320186, 0.14222912897821516, 0.12380543907056563, 0.12791776098310947, 0.10712501694797538, 0.0887245117337443, 0.14676555118057877, 0.09054747875779867, 0.155692147964146, 0.12517092400230467, 0.1671897669439204, 0.1363642030628398, 0.12097704006009735, 0.1416750712087378, 0.1346389768877998, 0.12518006726168096, 0.11188158983713947, 0.10016628410085104, 0.13453075691359118, 0.12212975867441855, 0.15812416590051726, 0.06565313684404828, 0.19948374421801418, 0.1391855368274264, 0.08480212767608464, 0.10707804642152041, 0.17560521693667397, 0.16897571564186364, 0.0990223822009284, 0.23222718096803874, 0.1119871306582354, 0.15746558405226097, 0.09550008253427222, 0.20720032858662307, 0.1010639414016623, 0.21126098959939554, 0.1895561534911394, 0.08291920254123397, 0.14425692876102403, 0.10089313611388206, 0.1193478774803225, 0.10641235479852185, 0.1316761749330908, 0.14071544457692653, 0.08249807826359756, 0.1235695845389273, 0.1428656541975215, 0.13449451042106375, 0.14015841821674258, 0.09485650691203773, 0.17502237868029624, 0.1068280242907349, 0.138219305081293, 0.1610563468420878, 0.10835062930709682, 0.12628715863684192, 0.12039777895552106, 0.1742989182821475, 0.13590199348982424, 0.08868020551744848, 0.17489213176304474, 0.09493453631876037, 0.10516689741052687, 0.08690383794601075, 0.0715205266897101, 0.11474166371044703, 0.1050913096696604, 0.21860157226910815, 0.09467366398894228, 0.1054035905690398, 0.2194038635934703, 0.11985377728706226, 0.1096045174926985, 0.1384972542291507, 0.24767955648712814, 0.12647226511035115, 0.10288142395438626, 0.16346556600183249, 0.17312798736384138, 0.1525866161682643, 0.11130835497169755, 0.14165908534778282, 0.1722923736087978, 0.1563836811692454, 0.14733084506588057, 0.15113576198928058, 0.17520536261145025, 0.11759934786823578, 0.13616443175124004, 0.16895030450541526, 0.22948202124098316, 0.1759447346557863, 0.17331785842543468, 0.10799903684528545, 0.09825276021729223, 0.1782862699474208, 0.14870582206640393, 0.12697843951173127, 0.09758292741025798, 0.40064456406980753, 0.23022879991913214, 0.1397436615661718, 0.08201258009648882, 0.11895278774318285, 0.15374026988865808, 0.10590745689114556, 0.18391069548670202, 0.11021908998372965, 0.08524829943780787, 0.14918906410457566, 0.08726457366719842, 0.20155025442363694, 0.13148259313311428, 0.16840156051330268, 0.07685450531425886, 0.13123240030836314, 0.27118058293126523, 0.14733124582562596, 0.10875262101762928, 0.10683986154617742, 0.1719729384058155, 0.16110699099954218, 0.13393061177339405, 0.1398065363173373, 0.086597034096485, 0.10158403849345632, 0.1476097441627644, 0.08279458110337146, 0.20904167118715122, 0.2839568629860878, 0.10633115642121993, 0.24615249858470634, 0.15349755791248754, 0.11851980394567363, 0.16093387763248757, 0.09862127364613116, 0.11341238074237481, 0.11338098047417589, 0.10312127866200171, 0.14819129108218476, 0.13950240419944748, 0.067783174890792, 0.11102409014711156, 0.15140093135414645, 0.10425332104205154, 0.19467986683594063, 0.17009906005114317, 0.11770979428547435, 0.14004840224515647, 0.13863576867152005], [0.04670652597269509, 0.011348972366249654, 0.054565172249567695, 0.033199768513441086, 0.09092062318813987, 0.022869045023981016, 0.02563805737736402, 0.023559342553198803, 0.03028803002962377, 0.009096794437937206, 0.009164473667624407, 0.040772984793875366, 0.06706172571284696, 0.028247828959138133, 0.04408211367262993, 0.0630552860093303, 0.0002359117581818282, 0.046765471051912755, 0.023954064927238505, 0.06405256921425462, 0.11231999131268822, 0.048625541749061085, 0.021441726203192957, 0.01916931269079214, 0.006977954471949488, 0.026610137247189414, 0.04242637107381597, 0.0551228071708465, 0.057986391402664594, 0.032323997147614136, 0.01876448226539651, 0.014431300915020984, 0.04833010389120318, 0.050986884962185286, 0.05770093543105759, 0.04646096786018461, 0.031237875155056827, 0.04722350604424719, 0.03131795288936701, 0.028204639675095677, 0.049715404165908694, 0.03265791165176779, 0.013468851338984678, 0.03165151858411264, 0.010745425406639697, 0.02859617266949499, 0.035692175006261095, 0.026452132151462138, 0.031854581320658326, 0.08020778084755875, 0.01851208340667654, 0.0784150192339439, 0.05085475670057349, 0.05854172937688418, 0.05576564435614273, 0.03553538517735433, 0.01579336640133988, 0.037891318133915775, 0.012827455775550334, 0.049427410049247555, 0.019254409198765643, 0.03301241704321001, 0.0071401884179067565, 0.020977171443519183, 0.011057306473958306, 0.03249447589041665, 0.041146607909468, 0.0703824803349562, 0.05581431440077722, 0.024553991133871023, 0.021150102984393016, 0.020198576894472353, 0.03359217167599127, 0.05923866541706957, 0.10094965065945871, 0.03329799175844528, 0.07741559122223407, 0.024301009689224884, 0.034550384516478516, 0.0788783494499512, 0.026108566016773693, 0.06215570654603653, 0.023959801728778984, 0.03254891242249869, 0.036701224962598644, 0.019912744282919448, 0.021276407242112327, 0.0075872377692576265, 0.021837417079950683, 0.04061042105604429, 0.04168929226580076, 0.03765528919757344, 0.03954009938752279, 0.016119900246849284, 0.02378212786425138, 0.11001176360878162, 0.039623468546778895, 0.03998976666480303, 0.009415923505002866, 0.03524601808749139, 0.009510411891824333, 0.02589193310996052, 0.04891150980256498, 0.020014876790810376, 0.02023473432927858, 0.025677810517663602, 0.014400800500879996, 0.03480989871604834, 0.030581347200495657, 0.02850980708899442, 0.07774321973556653, 0.057711845001904294, 0.06238975023734383, 0.04550811703666113, 0.027910847529710736, 0.06971477749175392, 0.053741432857350446, 0.032249689611489885, 0.009036641513375798, 0.01877746242826106, 0.04915503443044145, 0.035660489011206664, 0.02020207426539855, 0.0210667579449364, 0.040725494764046744, 0.040786870376905426, 0.03258802360505797, 0.01952652877662331, 0.035234614988439716, 0.006849105111541576, 0.04768633531057276, 0.033230293047381565, 0.06245842858334072, 0.011935348811675794, 0.04069067690579686, 0.0306872609507991, 0.02459934192302171, 0.032094721755129285, 0.043287722510285676, 0.03083696326939389, 0.03513828793074936, 0.03209810223779641, 0.045340113356360234, 0.04669027293857653, 0.040475532005075365, 0.02938635770988185, 0.03106089890934527, 0.054878128503332846, 0.021742995486420114, 0.011480570919957245, 0.05442384506750386, 0.06356537152896635, 0.04224821852403693, 0.027741096091631334, 0.1169492636108771, 0.04740058990137186, 0.014600315771531314, 0.024638078321004286, 0.04932674142764881, 0.024409884608758148, 0.032840357525856234, 0.06328066141577438, 0.07253614094224758, 0.03702515386976302, 0.07163287300500087, 0.016930537021835335, 0.016826352475618478, 0.05120929177792277, 0.01353625133560854, 0.03459350329649169, 0.05220036691753194, 0.04720927536254749, 0.05363064876291901, 0.0528189618489705, 0.037821867954335175, 0.04248205070325639, 0.020593575718521606, 0.027389182650949806, 0.06288824341027066, 0.015198828186839819, 0.015624299594492186, 0.034933477436425164, 0.02090479163598502, 0.03528617198753636, 0.005027243887525401, 0.027717074626707472, 0.01001978309432161, 0.039070694692782126, 0.03007623592566233, 0.058856140240095556, 0.03547439177054912, 0.03771322866668925, 0.05104159608890768, 0.03651213315606583, 0.016516110626980662, 0.056415992075926624, 0.028289175861573312, 0.010382895543443738, 0.013107950489938958, 0.03996973238827195, 0.0480201867321739, 0.012099152863811469, 0.025964363012462854, 0.02570469667261932, 0.065353531826986, 0.038513928084285, 0.06810822073020972, 0.029182291218603496, 0.03086192169575952, 0.05542038612475153, 0.05382942930737045, 0.045536852994700894, 0.02789061843941454, 0.03954289357352536, 0.019390982924960554, 0.01664316816459177, 0.03331473832076881, 0.03811627422692254, 0.04952709532517474, 0.0379697483003838, 0.019234328538004775, 0.029671030715689994, 0.031065817493072245, 0.011264527092862409, 0.027322855057718698, 0.015742544128443114, 0.026952796106343158, 0.043010226072510704, 0.1050504989689216, 0.011799622989201453, 0.025391875860805158, 0.033119438448920846, 0.028789656134904362, 0.05069074577477295, 0.040420883960905485, 0.02521586255170405, 0.05295763956382871, 0.045369309445959516, 0.03657398745417595, 0.04672010356443934, 0.04572193349304143, 0.05255606345599517, 0.08471248365822248, 0.05220470848144032, 0.05269659654004499, 0.05937220747000538, 0.0410240644851001, 0.01742730470141396, 0.08068765353527851, 0.044747504725819454, 0.009989564696297748, 0.046885290794307366, 0.03263705730205402, 0.010227818220300833, 0.014240950240491657, 0.06696320560877211, 0.060837162454845384, 0.04514123633271083, 0.033983906905632466, 0.04546604097413365, 0.04820743059099186, 0.08014164806809276, 0.06248401041375473, 0.047512142118648626, 0.07367970887571573, 0.062235324148787186, 0.025255400469177403, 0.05272496142424643, 0.030294867065094877, 0.04155753878876567, 0.05777021491667256, 0.028288535759202205, 0.08786506761680357, 0.03127336094621569, 0.04466063262952957, 0.023109276371542364, 0.065251679479843, 0.06100347774918191, 0.05562965692661237, 0.02584816680609947, 0.05376868080929853, 0.018325264427403454, 0.024544155821786262, 0.05020648328354582, 0.06023664624080993, 0.042019514585263096, 0.038927282075746916, 0.04498741138377227, 0.022677641427435447, 0.02881166266888613, 0.03267801643232815, 0.10915400416706689, 0.06525589487864636, 0.014019815280335024, 0.01781356659193989, 0.026805398156284355, 0.05141710797033738, 0.014237909290386597, 0.08117938574287109, 0.024024196027312428, 0.01342346251476556, 0.008047867031564238, 0.040026209826464765, 0.014896998582116794, 0.07511465140851215, 0.015011364466772648, 0.008758787917031441, 0.02092388709570514, 0.023132984279072843, 0.050463956577004865, 0.0094028357307252, 0.02648379588208627, 0.015380023542093113, 0.049368620821041986, 0.03475105382676702, 0.008862790637067519, 0.01770220547768986, 0.010607607655401807, 0.014807515981374308, 0.05741718639910687, 0.021329608098312747, 0.026477732535568066, 0.05540646714507602, 0.03206885790859815, 0.060893131521879695, 0.04619661485776305, 0.022855934985273052, 0.049285077257081866, 0.030906157408026047, 0.023950150098244194, 0.02853253907233011, 0.10427114000776783, 0.08487517727189697, 0.014633311657235026, 0.014001243962411536, 0.0650399002188351, 0.023405074171023443, 0.05195417797949631, 0.05999296576192137, 0.04560832923743874, 0.048988233029376715, 0.016494827686983626, 0.07671826926525682, 0.05081072136817966, 0.06017226492986083, 0.03210298928024713, 0.02216652617789805, 0.003606008590395504, 0.06260843889322132, 0.04904621702735312, 0.024785357527434826, 0.025189471780322492, 0.10647344097378664, 0.1356021806714125, 0.19449749146588147, 0.10273533218423836, 0.11609707027673721, 0.21919858554610983, 0.07141762791434303, 0.16483043495099992, 0.09683652722742409, 0.08777249211561866, 0.1910209155175835, 0.1640127069549635, 0.16316250257659703, 0.1099408810841851, 0.14172310300637037, 0.18164456239901483, 0.1494159089634195, 0.12826477439375594, 0.11899365781573579, 0.15839087893255055, 0.20687802869360894, 0.13715595589019358, 0.08758595329709351, 0.08487727754982188, 0.050127132853958756, 0.09585543026332743, 0.07466922921594232, 0.13226604874944314, 0.11819317733170465, 0.07913723282399587, 0.312773329205811, 0.11085148886195384, 0.12373462333926, 0.12010109800030477, 0.14151832961943, 0.14257266913773492, 0.11532462071045302, 0.09727280616061762, 0.09715997002786025, 0.10658313040039502, 0.12142718973336741, 0.17150939296698198, 0.08278393870568834, 0.10980767299770378, 0.10154557297937572, 0.11183938389876857, 0.10933386365650222, 0.11261111358180642, 0.11451642189058475, 0.22128053242340684, 0.15433953929459676, 0.11421500603319146, 0.18572407396277413, 0.15570276067592204, 0.1149771323252935, 0.10023326292866841, 0.11731097154552117, 0.15584727167151868, 0.12432414092472754, 0.10896451902226545, 0.09309452216257341, 0.1619257134734653, 0.06873826700029895, 0.09741250061779283, 0.08369659481104463, 0.10870148704270832, 0.11149962127092294, 0.1344971969956532, 0.18350334546994418, 0.25702595652546734, 0.21476183377671987, 0.09655181711423211, 0.16104861366329715, 0.1371030110749416, 0.1684866106370464, 0.17048969690222293, 0.17693600646452978, 0.18455299461493269, 0.18719308107392862, 0.1622612532810308, 0.22919656155863777, 0.16459389764349908, 0.09541288018226624, 0.12284977550734766, 0.1012735313270241, 0.10538822811213322, 0.12633572478080168, 0.07515437115216628, 0.1388625690015033, 0.20466561225475743, 0.10673718541511334, 0.09981992378016002, 0.11184915798367001, 0.13897795812226832, 0.11840388047858141, 0.1406256595510058, 0.20754018769366667, 0.121751159458654, 0.14264090219512582, 0.11543595028342679, 0.22076343360822648, 0.2154920477187261, 0.22394519881345332, 0.12007222845568322, 0.16508828673977405, 0.11605925785261206, 0.11553150179679506, 0.08705324711627327, 0.11703452895744704, 0.11069145213696174, 0.19277173094451427, 0.08904236616217531, 0.13179125235183164, 0.13024495798163116, 0.1497070089681074, 0.24835842865286395, 0.18564914673333988, 0.13857639685738832, 0.07726785930572078, 0.14356888365000486, 0.11614439703407697, 0.0999895713175647, 0.17512675432953984, 0.09000491685583256, 0.10188025189563632, 0.15722949203336611, 0.0665050110546872, 0.1084174745483324, 0.20214291871525347, 0.1407120900694281, 0.09622686033253558, 0.16048781719291583, 0.14266750076785684, 0.08975113945780322, 0.11573005598620512, 0.0952183929621242, 0.0925597305467818, 0.15637464181054384, 0.15040238649817184, 0.14314499858301133, 0.1263762905728072, 0.1593504165066406, 0.08094337536022067, 0.08689540714840405, 0.06936035744729452, 0.11986986704869196, 0.07925635494757444, 0.15593824413372204, 0.15244581591105089, 0.16269883839413524, 0.10471858084201813, 0.12929906108183786, 0.18375935673248023, 0.1364891807315871, 0.18717731785727665, 0.185629598563537, 0.1769144248100929, 0.13563363288994879, 0.09636466973461211, 0.23547961347503588, 0.07298623124370351, 0.1455953178810887, 0.15702948323450983, 0.16543247998924926, 0.16739069600589573, 0.06283536538830958, 0.10255752102239057, 0.12317964530666359, 0.16060774825746194, 0.09240715982741676, 0.12961313797859475, 0.13603550585685298, 0.1367925707018003, 0.12951064738444984, 0.10448989545693621, 0.10429079207824543], [0.05926765741605777, 0.08329875170602463, 0.12013885847409256, 0.023326028021983802, 0.027671324933180586, 0.030803034132986795, 0.03814466508629266, 0.084252908709459, 0.017613342570257373, 0.0631223910022527, 0.018777894729282707, 0.03610737694543786, 0.06079546488763299, 0.0335319649457233, 0.06913772798725404, 0.02787915596854873, 0.06611412929487415, 0.03916715533705428, 0.016077174805104733, 0.01376706946757622, 0.0334043971815845, 0.04586202870996203, 0.055831257632235065, 0.04004970993264578, 0.00910179094717023, 0.049651575754978694, 0.032038236895459704, 0.039933875523274764, 0.06085900757170748, 0.057965793093899265, 0.024943791213445365, 0.04278600470570382, 0.009451837886444991, 0.055189578197314404, 0.02731817581661744, 0.08436832009465434, 0.04694214301707689, 0.019170945415680762, 0.007591873873025179, 0.14310723810922354, 0.028917982745042536, 0.05938498354225885, 0.05033249624830205, 0.07413963263388723, 0.02917414985859068, 0.030984695185907185, 0.046251908570411615, 0.007774026134939049, 0.036696542010759, 0.039256105446838774, 0.06166367747937329, 0.0637099715822842, 0.06249276775633916, 0.07935955800348893, 0.014951961111364653, 0.046186106046661735, 0.03935233602533117, 0.02087071963615017, 0.016908697471080814, 0.038680458601447754, 0.0290343607775867, 0.038099776284070686, 0.039610284293303266, 0.057455432979622856, 0.03711674602527637, 0.0365820768638514, 0.037529510009335354, 0.06495879832073115, 0.014169790338200983, 0.042891337725450285, 0.044569151796167716, 0.026956395522574894, 0.04923886743199546, 0.04298419524275232, 0.012089515148545615, 0.0646508441423066, 0.01641167931666132, 0.04191998144960962, 0.08676352008478716, 0.02491789582563797, 0.060209943767404184, 0.011257519363425672, 0.013878422232664889, 0.047701111470814794, 0.009246453155355994, 0.08257931374828331, 0.022739479027222842, 0.028857369688921608, 0.011238171573495492, 0.019855866084981244, 0.03246002168452833, 0.055341095066978596, 0.02931004266429227, 0.005082019488327205, 0.03569319917005487, 0.009191125118377386, 0.0127299941595993, 0.041681473740027286, 0.08014147737412713, 0.027232535685470793, 0.0259679605733254, 0.055681247322354466, 0.02134611531801056, 0.07519447681261227, 0.01680147383012809, 0.03890582287567668, 0.024296317460539285, 0.025566601543687284, 0.052121651024208404, 0.041587358282413334, 0.03716385384905152, 0.04906749811198097, 0.029298045847099274, 0.0075571432171273045, 0.0247002220567083, 0.03056799410842359, 0.011652010744001018, 0.06931195457582362, 0.017997262984863482, 0.05119737659697421, 0.05369753853301518, 0.01743601380439941, 0.013947397437732434, 0.016400370841438416, 0.03207519956049509, 0.02368280624068575, 0.04300884196709376, 0.053875583471381105, 0.02085980635456508, 0.058366252269479446, 0.05394445477577392, 0.05066940160759259, 0.08668330134241842, 0.02046298741333885, 0.019072301001870073, 0.06840237096184865, 0.05684424097125884, 0.07628308871062472, 0.06130788075097371, 0.07627538521774113, 0.07423758870572783, 0.04450708598596975, 0.04436871255165897, 0.004364269916550256, 0.016850770989549346, 0.07929910265374929, 0.04461671975150239, 0.06070082250516862, 0.03128100506728515, 0.05664448450261261, 0.024893985682865605, 0.11986045661615208, 0.07151922793127596, 0.05742726847529411, 0.055945841522770934, 0.039785575863788836, 0.02622047260956606, 0.023601817520102486, 0.010109118193213362, 0.020792944415006787, 0.03892171967891045, 0.027877460161107592, 0.06855323474155739, 0.034134273446397856, 0.10335329629015177, 0.044364619607222266, 0.062304418097482994, 0.08138334276736714, 0.05949404956481885, 0.07231541880173609, 0.01609869894309668, 0.017704817837511655, 0.057758184702834114, 0.041498044520267285, 0.05601552918960806, 0.02793654439301463, 0.009840995080594439, 0.06616581988055259, 0.01254678387340391, 0.09684923279564828, 0.024471377109875903, 0.058781316911336035, 0.05384863237850368, 0.014525874648825265, 0.020936392284056637, 0.019042949061258696, 0.01590115592989605, 0.04627134541806299, 0.059909407355007716, 0.009205229634972056, 0.06629859009990469, 0.017210797959705815, 0.060495221623568796, 0.012605468273250153, 0.05397290500695817, 0.061846204989706166, 0.03624744618718978, 0.03706704439537134, 0.030092750566836912, 0.02865919585019583, 0.02987331976328278, 0.03350930717715528, 0.028691618426819332, 0.0073196754419768695, 0.012547269980132114, 0.05721561909012962, 0.04657009325455874, 0.021235585409158375, 0.015287164169421885, 0.04875538419582881, 0.0380428053176729, 0.010494450543774292, 0.0336337504995754, 0.045209346935735084, 0.03836473042611033, 0.04408390595926903, 0.05095317661471199, 0.05141409856150858, 0.022418515000026673, 0.036915479286108166, 0.008323446872964269, 0.03647622805146966, 0.051556550097302534, 0.06091322145948652, 0.03161104556056671, 0.022981908987276256, 0.046095998186501674, 0.0690374564146623, 0.07099505644873716, 0.02013475776038831, 0.06506375284516253, 0.03136819628707599, 0.027263626107014716, 0.02657296121469699, 0.06899708358105272, 0.03757254344236571, 0.044334343692753464, 0.032318085941369645, 0.07253484218381345, 0.04269953707989771, 0.0980222862563096, 0.016462052590213716, 0.02633181145938579, 0.12472977658035234, 0.03678031935123727, 0.06179232135764323, 0.0453350741736358, 0.034309783950448036, 0.025485390178801026, 0.02592676395579474, 0.05901048098166939, 0.043277358417981304, 0.03191538547980599, 0.03670504331239499, 0.06081933977839071, 0.07560817961348221, 0.025448585220146924, 0.05483795604959596, 0.045049755499348976, 0.048286064848070964, 0.03193720833223779, 0.02233244442322757, 0.02989550441270694, 0.023246261989697814, 0.07776865313644521, 0.05617364004137926, 0.019953102273575496, 0.025484898505965248, 0.005945675757175195, 0.030122909593046643, 0.03322333170217462, 0.04062006155436393, 0.030668560684716795, 0.09658249007770792, 0.024832554408931173, 0.024020615164772607, 0.03595620146370493, 0.09507607872365043, 0.0015786186122568324, 0.04831105667108204, 0.0153687614511, 0.06833915482275188, 0.04549917415715754, 0.009923234320012853, 0.04123603299376555, 0.04862118905293755, 0.02668395496584708, 0.06528808182338253, 0.027943038185185287, 0.054356714099412784, 0.017543523172207642, 0.030818309387541376, 0.024359873132198118, 0.009761642795638181, 0.03285150458395947, 0.06389771268004552, 0.0454777372215176, 0.043027280626120046, 0.06981593964155763, 0.03976804633566644, 0.04566690695355646, 0.042139571814914234, 0.03550506473402493, 0.03781319595873356, 0.053410746695590205, 0.05397255619755015, 0.026187153889623005, 0.061251818915479816, 0.07375896282610483, 0.021813942948938347, 0.012733500807371456, 0.013400221232586773, 0.06785162317100912, 0.03432108314882498, 0.03478598671790678, 0.05282678408548236, 0.056579086449346505, 0.012211944467708236, 0.04611931275576353, 0.02478127571521327, 0.024179262218240183, 0.02918073456385173, 0.06159750388178509, 0.03784922351769637, 0.03645188560767565, 0.04907690854452085, 0.03495419819955714, 0.028761810754076578, 0.02990112618135754, 0.03775132310693152, 0.04507094381551724, 0.03707831019710284, 0.03352790910867043, 0.015111362372408621, 0.07981131813721731, 0.06037265222403221, 0.034543348956503905, 0.018805170511768665, 0.0745869250386022, 0.018674224120331928, 0.05200234336371068, 0.05270794397802092, 0.10279362046276219, 0.038131885303300805, 0.0143366613156104, 0.1890485393232666, 0.06197533126396593, 0.030774455881328322, 0.019737115035241004, 0.06972701550694183, 0.018901876064774115, 0.023689763875154313, 0.15074292838107795, 0.1822522032307461, 0.22574631700990722, 0.19181235664291307, 0.13243649038486183, 0.09833574717049487, 0.13849306851625443, 0.1629392200266011, 0.20237200486008078, 0.13896566815674305, 0.18051933293463662, 0.10533022927120328, 0.2099408721551299, 0.1416414964478463, 0.20594724192051217, 0.09975082983146422, 0.2277240515104495, 0.17975783004658297, 0.1619624497834593, 0.1255063302232884, 0.098557879391592, 0.2224929493968375, 0.10611619334667921, 0.1130705549439881, 0.183172688994091, 0.17343777464702725, 0.14285526413004845, 0.08038145082537085, 0.21286759088980034, 0.13597231940366328, 0.14812813431490213, 0.12707376095931977, 0.12180740683106706, 0.11961689859163016, 0.13465683296089992, 0.1250908017391339, 0.11316904536215588, 0.14605856646085158, 0.2018249232787639, 0.31615695857908577, 0.10008402445237152, 0.18774969183141366, 0.1007456416846253, 0.21133372007170692, 0.1311337688821368, 0.1661842013709247, 0.18510742345824838, 0.08994927062303759, 0.13017518125707284, 0.13484532362781465, 0.18734266835963354, 0.16103059431770816, 0.17100600904086605, 0.13540862855734304, 0.1356842473614961, 0.06955897100851871, 0.16373699909308925, 0.0953147756808903, 0.10931860510027036, 0.1060941515606828, 0.1896741401287727, 0.11193454207386822, 0.22192268312210217, 0.14481407386483625, 0.15685156075051054, 0.11087926744949073, 0.10482665238669142, 0.23246352531714365, 0.15317654935643077, 0.14676571445306763, 0.169502506905701, 0.13120931951561943, 0.13613465678645298, 0.08514123721397482, 0.12331488687777892, 0.23214164102682844, 0.08963453321484849, 0.07702956310822628, 0.2044424187624827, 0.12118792132241651, 0.12635013728868216, 0.12975822784937918, 0.16811532899737358, 0.08841234957799315, 0.10395648423582315, 0.17071513168048114, 0.12211179127916694, 0.11693131848005578, 0.1331846643006429, 0.15158869471633807, 0.10271189516060986, 0.1312743910239078, 0.10547624682658352, 0.08491382090141997, 0.1312313019298017, 0.1675155252451077, 0.06325346170342527, 0.2039916382636875, 0.13199897948652506, 0.1352665072772652, 0.14557091606548056, 0.14519256917992607, 0.19448581006145105, 0.1293736617662944, 0.18015743204159662, 0.16800313111161813, 0.07562585757113993, 0.11468350901850499, 0.10535771099966951, 0.10589136712951586, 0.08490067004458979, 0.19389235909329727, 0.0797856472490821, 0.10296524953446351, 0.1817907506483607, 0.11267952475463971, 0.11420805953093804, 0.20952409686287865, 0.10376625694334507, 0.21471485582878813, 0.13609845482278615, 0.15491259604459628, 0.1652293690131046, 0.10280047790729441, 0.0957206117163878, 0.20622588868718594, 0.1250346953747794, 0.11627528219833039, 0.11938258772715926, 0.12082802422810346, 0.1632320269709453, 0.10092636206536554, 0.2930295292753726, 0.14129109884379432, 0.08634258134406991, 0.12762582977302372, 0.19729651627130806, 0.17621499515371397, 0.20331902982434258, 0.11307862951071002, 0.24299292359501123, 0.15156804816797376, 0.11483899637823924, 0.12047407173668034, 0.10541294905124232, 0.13862606137990952, 0.21547949058003724, 0.10176675525144674, 0.12828919105231762, 0.14111256779870018, 0.07241462910315022, 0.25086681358516216, 0.12185471132397652, 0.15454901789780706, 0.15977885836036876, 0.14522975077852607, 0.1858963115955703, 0.0838454399490729, 0.1432351695257239, 0.11841916872072034, 0.08897711653844453, 0.14792258909437805, 0.16351862956071272, 0.1236155309015885, 0.16817342431750149, 0.19468731799861416, 0.2674799971282482, 0.16443495929706842, 0.17785488918889314, 0.2538015623576939, 0.14950959768611938, 0.09711426857393235, 0.12639365682844073, 0.17213196580996737, 0.10813681656145491, 0.1189001694729086], [0.030403205782931764, 0.017827467017923482, 0.042262913048034534, 0.057899222447304055, 0.016734368837205693, 0.08692688163137063, 0.04039337254653219, 0.06055369172827341, 0.048853128755581565, 0.016637479602650274, 0.047823640052229166, 0.037489886744879186, 0.020897576105198823, 0.03755461686523631, 0.05985427320410963, 0.025246587465517223, 0.041963189287343994, 0.045076320675434545, 0.03935004278901033, 0.030343741200340446, 0.032849504495970905, 0.09718471323139966, 0.028259066930331755, 0.04415541930939071, 0.05412858532508835, 0.04034061697893776, 0.04822350922040641, 0.029166761778469663, 0.03156934428261593, 0.04292988116503693, 0.02822481681505451, 0.03834550137980841, 0.008593300117354374, 0.05389575133449398, 0.09519178696791641, 0.025630702693888452, 0.05754697689553723, 0.08229259241488762, 0.08393991534831002, 0.023480415147787426, 0.08988875590148382, 0.035740889579756185, 0.08044472633628175, 0.03994255494035315, 0.05402446200605482, 0.021026730209996458, 0.036134988549747504, 0.020740222244057804, 0.039277327159652486, 0.05096876171592157, 0.018964385308208875, 0.11977862741332501, 0.049550647381693125, 0.0567081385088386, 0.0004926600081489596, 0.0634857093973551, 0.0911935257317964, 0.05802476414828561, 0.06341058920952491, 0.015016375818959204, 0.08314325692481361, 0.04829774996323977, 0.06635038458625786, 0.043170819408260286, 0.018501830636523664, 0.05305729515384883, 0.06578812608495355, 0.1347917554085143, 0.02026379126618849, 0.07696979795582592, 0.04814807733055204, 0.07011334790149704, 0.041167276722262613, 0.018641330279933754, 0.03229883463063743, 0.023190676984086167, 0.09810473886318505, 0.008956694582593627, 0.056971649173647165, 0.04246187170792837, 0.05540116449992638, 0.05059114584582858, 0.04046579502755776, 0.08685162785695866, 0.03936499335395638, 0.03504714848531876, 0.07853674629586749, 0.02064600103039993, 0.08724823157535866, 0.05283564532874152, 0.09495858932496049, 0.02779693157208385, 0.04132951762585435, 0.041023292651516385, 0.06346320747979917, 0.03296313472674228, 0.05113839069963433, 0.011191099929419579, 0.037276689981808886, 0.03009861353348242, 0.022054250366636552, 0.028825683693867177, 0.03436395330936648, 0.0190545673831366, 0.010915357743215282, 0.0314341472403612, 0.004086629687662935, 0.0665907068469096, 0.08017693719011731, 0.10901836925768293, 0.049910974921658635, 0.06607166360481642, 0.06177074712468311, 0.06254606880247593, 0.013661362590937642, 0.1432588291936554, 0.07604419879498892, 0.07125503820134327, 0.007442383066518232, 0.04706029663793743, 0.02745240806689253, 0.04653461859561503, 0.06114100513514131, 0.014943087808205746, 0.08406175373238511, 0.006373060050464119, 0.01774214229953941, 0.01585424291988602, 0.05255922500509769, 0.021514697873499244, 0.02893637130910065, 0.06348397277179174, 0.038749441227992065, 0.06609026924706995, 0.03468161106866319, 0.013821951288264245, 0.008611237826698925, 0.042846708674915135, 0.0583089621795807, 0.034720922631095164, 0.02793646461213939, 0.0265347591630416, 0.048566292389295995, 0.002047320817837317, 0.012611488018592354, 0.0030967206475907005, 0.027847581295645796, 0.038970129971858114, 0.09191551667754538, 0.03423975118494127, 0.03605809462897014, 0.045855950520490296, 0.07662806121516041, 0.025862664660962764, 0.09104252094402909, 0.12044758448610082, 0.025554152016411535, 0.008633894667582354, 0.016494985393364914, 0.04260348832758609, 0.01726013779261848, 0.03296228496765252, 0.03080408427194925, 0.02267774903884856, 0.028000114907626994, 0.02237669312307844, 0.013855565011908766, 0.01073908839316573, 0.01926925586303696, 0.024482292246830184, 0.043374594606575556, 0.02419962675048737, 0.007229247994473553, 0.08283559218398295, 0.06719724187860265, 0.03569175198208541, 0.03849136679491494, 0.03818144221440889, 0.02759190771030262, 0.02348063964745961, 0.05849962733918801, 0.013387913641054183, 0.05609319494396914, 0.031837422866374254, 0.01165951292932732, 0.0767143804114312, 0.035886721598217264, 0.028705884360533673, 0.07818284575478174, 0.048573498643236235, 0.037007846985943615, 0.0222464109538123, 0.03481521620415151, 0.026471932651475072, 0.06483008764917031, 0.012977815822523553, 0.05987376942357514, 0.04571102392219473, 0.022419470515160356, 0.03106650026893476, 0.03346968020196073, 0.05776387326477561, 0.06278785309405066, 0.03279345008195378, 0.040052615440799855, 0.08300923989736475, 0.03651458966487553, 0.025939553015632555, 0.06310331038548611, 0.010150342641281895, 0.0934174974099733, 0.06557447661180049, 0.045928740364615805, 0.04697255993960425, 0.02287407492985949, 0.025513263390166685, 0.033757763376343064, 0.015418723760376452, 0.035213222581660375, 0.04728948297270108, 0.06994963754550554, 0.028268588685023133, 0.0392879027640447, 0.06417972879717126, 0.1430390792666003, 0.05701324655092321, 0.01565015787491575, 0.050562476681079715, 0.03822034559561871, 0.020437381463125348, 0.01634436281165108, 0.034442684045643546, 0.04758016737469006, 0.04585885602864437, 0.019164577788615134, 0.03294337875558995, 0.010470618326507974, 0.03368338162545115, 0.04645620698283892, 0.026531057701504324, 0.005534028705369565, 0.030949576757848263, 0.03421432149480097, 0.02258441469166428, 0.009116810160776367, 0.016828343286761083, 0.045703368668910116, 0.03600587340770289, 0.046353593934327364, 0.0607206786662573, 0.03812000351899769, 0.009465341263421578, 0.03537018310453277, 0.020566281382343732, 0.06540633563417941, 0.061364439825410955, 0.06955670745810494, 0.09753837628522888, 0.03910419894964434, 0.03978355722210836, 0.014157949372020084, 0.038179601688170806, 0.05349717721401248, 0.039124251779867336, 0.06663306121481583, 0.05081770126707852, 0.01463208247514558, 0.07113402360118926, 0.020131425517320167, 0.03586212682421319, 0.06302644615061581, 0.05816491131554358, 0.049608772387728095, 0.012821555701520992, 0.017050816895789467, 0.10764711041701958, 0.027940256986767054, 0.0161196534827468, 0.07799794708262198, 0.07474610087228939, 0.02692312318686163, 0.01094128559998353, 0.04978611599653959, 0.02997073592268862, 0.04289623218937777, 0.05332351465767715, 0.005892167373531265, 0.014060547127883183, 0.04722291974758264, 0.03308056104287971, 0.024486266447638627, 0.03965274627262261, 0.025273785322497133, 0.04636299694539048, 0.00709813044522889, 0.07709224490099587, 0.08870877078152262, 0.03420744920731522, 0.07631917935214005, 0.0522290138178505, 0.010050790951936506, 0.07860989237087779, 0.05885263730306178, 0.027389477654651273, 0.027698947669705376, 0.0121360839875706, 0.039599953597644344, 0.06521060902741738, 0.03584985541237984, 0.05545311483729165, 0.024206048183259554, 0.038494379914482124, 0.024089271246339194, 0.014126409023447195, 0.013774295202892972, 0.01692754802206764, 0.018087227981595788, 0.014004778440721566, 0.014592476836696733, 0.05241277329332661, 0.028675222529273015, 0.026626030339684803, 0.02332285719603533, 0.016064257724792697, 0.036709900668938644, 0.07308245811145753, 0.03350975988723803, 0.052733919146703556, 0.023970850452315062, 0.022997035812295508, 0.03067056448344374, 0.0434813711035531, 0.01365025727864122, 0.058003156518680044, 0.028875543030153494, 0.02288734267494874, 0.008206322982005076, 0.048649171731085517, 0.0950908919912763, 0.02135429749614559, 0.05011783003283199, 0.018051051993097644, 0.03653909167042002, 0.03042644057131838, 0.017199530302605126, 0.026559138714219444, 0.09430374047951773, 0.034927466040244326, 0.0576755910879001, 0.06424402847187594, 0.03885084828652907, 0.08323653004481457, 0.1540397116332315, 0.10171011454076506, 0.21358495083404705, 0.20903825730783865, 0.1042944731307216, 0.1737654922180809, 0.1551648520398885, 0.14307762641692534, 0.15959344018483534, 0.11068511419580318, 0.13434576918371022, 0.13397739676292986, 0.3696684481110424, 0.13955690752482042, 0.09217057056957856, 0.13687278202269226, 0.13617866614367813, 0.11009025314706378, 0.11760571549530141, 0.05849887034855783, 0.09668822385719977, 0.15815809689229354, 0.13357461837586015, 0.22111387574113905, 0.18676692503504455, 0.14650835248176008, 0.13430702907498926, 0.13055786228505895, 0.10987635134370066, 0.20852264278801158, 0.23052583710523322, 0.11968987397267483, 0.12802452634787187, 0.22677766479318962, 0.14621566428104416, 0.22045803983928636, 0.18198759789811447, 0.12374811558402143, 0.18070264341076836, 0.1302126151858829, 0.15332566166762263, 0.1243544279714115, 0.24656235706061125, 0.09905052444082685, 0.16964741866104305, 0.06846468910225667, 0.11262165950029157, 0.1466761966003105, 0.2418173913611099, 0.10177666292292997, 0.07533211552072316, 0.19350285030668601, 0.08786065925960429, 0.16002988239051774, 0.08143581260810606, 0.19104144332231954, 0.18776867596898228, 0.18718439794611186, 0.15314242540625855, 0.15152604260947555, 0.2086699294159189, 0.22512696508783847, 0.2316451442311518, 0.18264631333295256, 0.120903419010574, 0.12400096529745497, 0.16217644064454362, 0.14357813081005588, 0.1404870708938688, 0.13326224841875955, 0.2022906209458597, 0.22163306741276756, 0.08436126227024943, 0.13071641471469775, 0.08412574912654236, 0.1710405040648766, 0.3413033561082557, 0.15083531092386693, 0.14153161406284198, 0.18514365510782227, 0.16743184067308903, 0.14699359831865877, 0.13042026810580865, 0.11538964026840404, 0.1464686030521989, 0.12652923236601055, 0.15107088343938813, 0.04679806988860946, 0.2003243303624913, 0.10569569989456795, 0.21301839529769495, 0.15996040252503008, 0.11984635581029579, 0.18453702359693125, 0.14484797517070547, 0.07856364914914593, 0.12817476672353223, 0.1393997503328137, 0.17066577885998413, 0.27337953681126237, 0.11331626519677229, 0.12145052285632119, 0.11129821723443456, 0.1742893148912117, 0.08945651425165124, 0.07846744454582222, 0.10089342555147596, 0.13014864205615595, 0.16025040415115654, 0.15672164037823677, 0.08057947066845372, 0.10054113547084853, 0.15745069656986743, 0.20666265743784606, 0.07547796238213778, 0.22262389393290505, 0.1134942247881554, 0.11011856608092785, 0.0402580122317886, 0.20166699425317347, 0.1286739352508448, 0.14365797105710953, 0.17732465435983613, 0.1628301985329017, 0.17565123009262607, 0.20090988487936556, 0.12658219202421606, 0.10314625193132088, 0.13083728088531643, 0.15365542756626382, 0.08230762090533972, 0.14135474542854354, 0.12796012277249247, 0.14785163977649063, 0.11251992589677684, 0.15628095308784395, 0.1643471186980605, 0.14600569586036727, 0.19460563722532243, 0.12735444121062756, 0.10999307633028366, 0.08120375787257217, 0.09857448123511858, 0.09718862434965558, 0.09498248648014851, 0.08018971697310917, 0.13487395568517968, 0.18979698041221127, 0.19742829201277345, 0.22090307611506432, 0.1600539279752411, 0.16353163198800758, 0.22288615407887846, 0.14269337203586474, 0.13937356736278161, 0.17373852257151157, 0.1526395758264698, 0.19262177258497104, 0.13617255084682256, 0.12052796650095843, 0.16412224795203656, 0.14793124253628775, 0.1704215825884603, 0.09988256846554577, 0.12259532275493257, 0.09151018530246802, 0.08578567372751422, 0.16380278306314722, 0.16565347672440112, 0.0990459973399993, 0.1771675268537365, 0.1642429656931199, 0.19423591409577057, 0.1862511769286357, 0.14788568951189518, 0.14344297087518498], [0.014631987851316808, 0.05950490347458981, 0.009335762279079063, 0.08425558044109493, 0.03150565687974449, 0.02864590769604547, 0.06794200191507116, 0.04065132081450429, 0.03864028614771087, 0.013752393497270532, 0.07127176620997488, 0.07531028895755298, 0.03691691905260086, 0.04983585844456684, 0.06869140779599547, 0.010052435736724874, 0.02514781132049393, 0.07416768581606448, 0.07233918237034231, 0.09768241230631247, 0.02588106806797441, 0.023816003194951918, 0.0412217243865598, 0.06957218123716302, 0.055007540504448116, 0.050761234961100854, 0.039517111363238655, 0.009440126796107506, 0.013457393506541848, 0.028941312157257926, 0.0174038361365092, 0.02174194905819604, 0.03665738258860074, 0.04541929309198167, 0.015680162905482575, 0.018887153710238636, 0.05148165255377535, 0.03301787182863336, 0.01822550122597022, 0.040527092714910395, 0.04015343249193393, 0.04601491855282802, 0.02120894416293595, 0.04096529752132483, 0.02950722202513134, 0.06581739638932049, 0.06664217478828505, 0.019533213671820704, 0.0543320339784259, 0.012737305241898866, 0.07039769436232746, 0.05619341456622351, 0.00585425429562747, 0.06883614143589512, 0.08240078270318918, 0.06521315459394827, 0.026088476079166867, 0.03461200503807049, 0.046148776018526405, 0.04257075961504597, 0.019014949684788007, 0.02499241858458845, 0.052891157974954695, 0.03170997013512533, 0.014569445211236598, 0.03701564324728679, 0.05155709557584487, 0.05345570600184146, 0.05903633369598538, 0.03261144207499456, 0.0017803449031816854, 0.031144038002821617, 0.03184950503055006, 0.05345515310182236, 0.017890334347612225, 0.0408033423445886, 0.04341274470789358, 0.03783374231716152, 0.03952102990297135, 0.034782639631885104, 0.024321663659065962, 0.010959538722090656, 0.03173085417074617, 0.02518813962524291, 0.0640244863461703, 0.036139742005616426, 0.05509011556569021, 0.03406748757697642, 0.06238690039026551, 0.0675337464781478, 0.02590577601949917, 0.025753470617928542, 0.07577570460853167, 0.021540567286137957, 0.06616310362005606, 0.021383727362263016, 0.048693099452066235, 0.019898754799214657, 0.06596976672881283, 0.06187373866850976, 0.08827641038806178, 0.009930745782185113, 0.027528476348379627, 0.016986019982141443, 0.037430073352879845, 0.005780021438113181, 0.0184536633969401, 0.032696258422220126, 0.03080890452110907, 0.022539080600836314, 0.029398343394859694, 0.01327491330812336, 0.011442217655712739, 0.037985808376106434, 0.03831788977549877, 0.044736042254953645, 0.04527419208898209, 0.05268170905765146, 0.03720306522154715, 0.061959412196301855, 0.033210911860805936, 0.03941571914765518, 0.04326804446463939, 0.13889955764170736, 0.060517037054523826, 0.03109546443738509, 0.033297954651061445, 0.028543034895847086, 0.056804825508152135, 0.02839536977262469, 0.05435549697722308, 0.03670270925795194, 0.03243101484258659, 0.03365520227816887, 0.07989803809323348, 0.025035157013917342, 0.017797862747102045, 0.07228355098050088, 0.06484198427642696, 0.04397136297484394, 0.017131384447566234, 0.03580869219149463, 0.05702855334675405, 0.036661839185399, 0.02614007389638573, 0.037889173327130266, 0.02920592305599712, 0.02356046505155973, 0.11146498523885384, 0.04356840276159346, 0.029698013349843677, 0.06139943208836485, 0.054224893829086795, 0.01157766238975455, 0.015281186169886496, 0.031391625889227726, 0.03688221622724086, 0.011362855166225927, 0.09698545400169678, 0.015036205077194609, 0.05126818490680307, 0.03596790513256565, 0.05087369259854313, 0.06754675632691942, 0.05483207081852015, 0.02190789884480182, 0.021513376850634813, 0.0703020983200986, 0.03772364470933098, 0.023890566772024613, 0.04991778783733025, 0.025722927530296147, 0.03978033259045333, 0.05245533917332068, 0.04184807476121932, 0.04036205762531608, 0.029512424480344635, 0.029527755395974964, 0.0386006406188244, 0.050891107093775645, 0.04204184951959178, 0.026411195285618305, 0.03461815002083313, 0.06361352949170396, 0.04189703795418609, 0.035035144246649, 0.0679353300074581, 0.03122817157418467, 0.021277691157592926, 0.026833655429072678, 0.056709210912231356, 0.012732446029986022, 0.04671524620789569, 0.030997053800092544, 0.04605054906278383, 0.09945573707227595, 0.04799069749424234, 0.05587762330833357, 0.06271977588767186, 0.06797953974455595, 0.08438693315838464, 0.03957158129196614, 0.044552613035193644, 0.03893843284458853, 0.007133182543839212, 0.06583498528925702, 0.05414960294729099, 0.057735118753043935, 0.028482418128987774, 0.029416798752208706, 0.028584635983861517, 0.07294285271200351, 0.021383601197157986, 0.02661110760527663, 0.018244398161186837, 0.03003098532644799, 0.010746445859695086, 0.025296224157500546, 0.017387573825544678, 0.04319050116464496, 0.015077030620886944, 0.03715677004947793, 0.02516686039598426, 0.042959285055985674, 0.030061422658036463, 0.016133416611410212, 0.06712281188811176, 0.03533710558258463, 0.061978151425137185, 0.05947827150521334, 0.018597964735818096, 0.02280914442962967, 0.01065320335328579, 0.03686997079057619, 0.03797077246417757, 0.05594206028035842, 0.03694753264426254, 0.05752962919359561, 0.03161867112794425, 0.08026612107641995, 0.04204760116408579, 0.040282165427925065, 0.04262890688551124, 0.0365125153621193, 0.005313471228873823, 0.031849783335928805, 0.04585905269777868, 0.01712386463623261, 0.04994228613213636, 0.04381003862363286, 0.023645793480682187, 0.022917792994121555, 0.03437967941863462, 0.00953768118051812, 0.034982136348844506, 0.04067034948093351, 0.04429051616170909, 0.07940334471641108, 0.048936223320197314, 0.040885089911171235, 0.04185446465271525, 0.045641948527190834, 0.04122999562241603, 0.016103020097943954, 0.03684127193992026, 0.04455395261174999, 0.01546739658806473, 0.02019422234297963, 0.022431413526646793, 0.0171787761428277, 0.07399412716040388, 0.04892850869509857, 0.011387072372599505, 0.010150165453524096, 0.022565877698070835, 0.045003794293734245, 0.045086202371749096, 0.06667807989288121, 0.08257591471192427, 0.05638804650516249, 0.06432525653508492, 0.013238856063253479, 0.022984176248428412, 0.04969601926859468, 0.07159208456869237, 0.03589276639104355, 0.03146548071526922, 0.04633304015442263, 0.008236139692598954, 0.01102419184462633, 0.0559105264255777, 0.04609452131262515, 0.04484437726205215, 0.02809500405419385, 0.036840206958004273, 0.0321245078521315, 0.012373883873806335, 0.042761087097460404, 0.06588703210582025, 0.05939226772170514, 0.018778991252474952, 0.013255856811156264, 0.03768306036363356, 0.008883259069989435, 0.0582049872900825, 0.04499916700297035, 0.025717315038491506, 0.026946437756123487, 0.048077057508635335, 0.006688682933599921, 0.021924265056441072, 0.02758884078502888, 0.04196340451017022, 0.11701254654326476, 0.020526611733657774, 0.03884297781041823, 0.018526241728977766, 0.05417097680037841, 0.0398129611130571, 0.0048586339653411414, 0.04127066531509627, 0.03652616716863122, 0.020082057853869628, 0.02940865739219589, 0.11421803399571218, 0.05747019429691136, 0.027315129300404806, 0.024712369158805814, 0.018644794254214503, 0.04083846077264752, 0.015431090723723173, 0.0336144286848139, 0.014566945101250894, 0.07410394275211729, 0.061969256785232574, 0.007665786215511616, 0.0822316472476814, 0.06871209887322038, 0.03140471366350539, 0.010043560578196775, 0.03761631902307272, 0.02377035554673057, 0.02690662153327139, 0.012007257355435286, 0.06896917140693404, 0.06835153384599835, 0.06600731940125115, 0.006021832168698893, 0.05269997702271212, 0.043522860869416036, 0.04263712246029172, 0.04020615837362129, 0.13671335385879502, 0.24248180649010465, 0.12327127085882239, 0.14044564421055838, 0.11104176810476929, 0.17379900760715827, 0.14890836901031435, 0.14737109915586188, 0.1343825797084719, 0.1281919697066769, 0.2874212380265817, 0.1213199642370455, 0.1126914807537105, 0.11088228056905791, 0.15694551664637402, 0.1340584096033126, 0.11346433850121684, 0.24668359430506825, 0.16161497624125332, 0.24010666675167158, 0.10069005482364446, 0.18084247887600213, 0.15705213358160108, 0.1129999989643693, 0.14710410410771146, 0.11701633891789243, 0.13476123829605058, 0.11005608466803096, 0.10601209229207598, 0.177522451558616, 0.10908807918895036, 0.12138045669416897, 0.1181030212319456, 0.14124682231340557, 0.2382210476207547, 0.11657202994683757, 0.10991802293574437, 0.14459928148426116, 0.08034612459596246, 0.12307178156333975, 0.12235732341650873, 0.15251637931214646, 0.12545647274237126, 0.08193176763597876, 0.093514147301903, 0.16226693813223392, 0.06769215789972804, 0.17774726293282583, 0.12220594013342634, 0.09927722829161212, 0.22281452198512852, 0.15088475280208513, 0.11560705985175446, 0.19764686934649944, 0.11301022575935349, 0.15867338486714289, 0.10443399689393118, 0.11391684820409864, 0.11263758598943241, 0.18951618141727522, 0.15207974414806813, 0.14425345550989732, 0.19741815427551046, 0.14000517956446856, 0.1333788101328537, 0.09506399655947462, 0.21574960264842957, 0.15498911147005856, 0.1958117904723622, 0.08109158967272379, 0.19345443259226158, 0.1155313162598759, 0.09244977394700982, 0.12999644241062924, 0.10125550455995835, 0.09756143481354229, 0.15411604894325137, 0.11480345492600463, 0.15765014133648947, 0.15610463364282623, 0.10874735176912509, 0.1357647406985052, 0.12269284838112071, 0.18176913930801675, 0.22305141552351415, 0.12974714016309008, 0.13634110742714256, 0.08343731067725457, 0.19681753416080028, 0.1655372415552847, 0.15611874929163605, 0.12016752021736465, 0.16982773086056113, 0.17579124367330223, 0.15510510915191844, 0.13724902120884508, 0.07360392075497657, 0.113403794093756, 0.3390742710325867, 0.13251334719825536, 0.19261280744103715, 0.0963412549754139, 0.1371182399452664, 0.0819352779944893, 0.12349375931080431, 0.134475244267378, 0.12708352762274444, 0.13363875477807596, 0.15548594965366647, 0.07062109565595165, 0.0885197235038504, 0.1365507789887488, 0.08266922493930906, 0.11914519694983028, 0.11194787104614079, 0.10986799476086162, 0.11587024768232368, 0.19313884171424434, 0.12703025626251474, 0.12901989481179044, 0.1478603229043074, 0.09135932152275927, 0.1826201006770134, 0.209585769334808, 0.10926954171736725, 0.086826320621185, 0.12607171316631138, 0.07151348370825872, 0.17079188459319994, 0.09194636775646359, 0.11839711951324716, 0.18723802553722635, 0.16350084770238027, 0.10274120257236063, 0.21787958132335916, 0.10074512218125165, 0.11343012549332343, 0.18611856998177245, 0.11845293644000776, 0.13946836930699646, 0.10031576748588122, 0.09601675090380013, 0.09769071693881415, 0.16560106625547633, 0.13182962138671428, 0.14208638429408893, 0.0642404290556442, 0.14004216820467263, 0.1924010578659363, 0.1618749208864756, 0.1276823814259842, 0.0803707490558736, 0.11986562196398154, 0.10847495388588868, 0.06726062871166505, 0.10344521127990447, 0.17310072085820138, 0.10636034508934245, 0.2211567125050351, 0.1202363841002807, 0.2150131991948001, 0.11434541622293182, 0.09864345644018613, 0.17120049626100808, 0.22939950926229358, 0.07492973789339885, 0.06279819121118635, 0.1443508401280269, 0.16155906283529475, 0.12132283634855412, 0.14708305679960176, 0.1366548429359682, 0.14939699904061854, 0.12205869061290286, 0.09457017891691066, 0.1495022207382135], [0.03912398089596536, 0.048194305709330365, 0.016656508269079495, 0.05475984871736728, 0.0611692698294064, 0.03432058962062001, 0.02592999971966492, 0.03424166592594702, 0.053332758106989786, 0.025431623434997164, 0.04739766583952587, 0.03444898116867989, 0.014995860074122902, 0.024746702765696682, 0.05311678942234721, 0.01901417414046591, 0.08102194653474726, 0.060881413010065444, 0.046136508317431435, 0.04934506134304684, 0.030880037520546466, 0.04729102292913012, 0.029985269029566552, 0.04552401755063329, 0.05905669822823256, 0.048391401578555815, 0.05897608985833358, 0.091207203513477, 0.025917334969562944, 0.020061787945451215, 0.009190135278913658, 0.021248884695523884, 0.03943998737668153, 0.05326115569914691, 0.04001975314167794, 0.04340170155046508, 0.05408118064224254, 0.009571582486387342, 0.0429577747854637, 0.056289574640686624, 0.030957632770878263, 0.019786796256084926, 0.057064922293648124, 0.041795953729888424, 0.035727590293390676, 0.04719884447695222, 0.010195332561124815, 0.005277185773593374, 0.05677951827237848, 0.03946006989281159, 0.022572083908016793, 0.08822518735541962, 0.02257043819554383, 0.014404917565116193, 0.01641497074160725, 0.044360578613122925, 0.03069627062359359, 0.017966560335480608, 0.0408461457118392, 0.017712521330395248, 0.019527744043443818, 0.02325123623450054, 0.05605974634818267, 0.0270801338047022, 0.03501354774925858, 0.03959597568609752, 0.06651196497841738, 0.049579888000153005, 0.03920953196939081, 0.007926024009066168, 0.030192968333722092, 0.044026255927747115, 0.006554212732226006, 0.034047445878968574, 0.04982999547792133, 0.03327038015413564, 0.03281306504504755, 0.039625442659598775, 0.021061173283669632, 0.020611932741303463, 0.0374627501150826, 0.04891580312687438, 0.04647118352295365, 0.014340988964249846, 0.024798194826871622, 0.07619666561367922, 0.01974086288100807, 0.02109505974658532, 0.013383799359871773, 0.04862742680415977, 0.025689987305668183, 0.026394519227324054, 0.011646224775176961, 0.006508391606985242, 0.06097629287978634, 0.05030769367294852, 0.015181474918790627, 0.025942239590222016, 0.05894207723031286, 0.03740699256013613, 0.029762721205770504, 0.03499881611787714, 0.04506534060055856, 0.06172144625452347, 0.021805812721140683, 0.03924290635040961, 0.02644898915605154, 0.02027379727223888, 0.0418414399609901, 0.046613085869466886, 0.1018599393137265, 0.046894801416783594, 0.04220894777972717, 0.03703977417899296, 0.0247972263241536, 0.006748725927536725, 0.08858599729137495, 0.03231641981983557, 0.03456413651292678, 0.03001412929734215, 0.012284656386327697, 0.00038097397236924735, 0.01942431648785714, 0.03010420005011838, 0.04633197888324503, 0.046167459586285986, 0.025564916868461296, 0.039547394699184224, 0.05741576518630609, 0.011232797496631974, 0.06432389840483665, 0.026639468778739683, 0.06992260852712207, 0.02891040170652559, 0.05913984845392406, 0.01002243441689643, 0.05125233634316828, 0.07854672818211839, 0.031649117736378685, 0.04600501459208317, 0.048669090974726714, 0.04689037821663078, 0.026381355382909533, 0.03778647864237428, 0.024876979368855245, 0.045309106426429935, 0.048807074781507254, 0.035452194133540615, 0.012765481806127355, 0.01609615337656578, 0.0529801711672917, 0.08510576997650787, 0.030692801083205268, 0.03375808249984402, 0.06216281261004042, 0.03595424961531535, 0.02580649892479414, 0.007715863093835651, 0.011616884894465329, 0.031700722975074314, 0.06725777144310996, 0.033077607295126654, 0.057580139764468186, 0.07202834865893237, 0.004402512786327861, 0.020672929858847056, 0.02054992444755044, 0.08018815846298821, 0.050289707724004984, 0.01914193300763145, 0.028584676801983733, 0.013056286807113793, 0.08676573910634033, 0.05054902154370211, 0.040323109715245664, 0.02664673997060163, 0.03828041131782811, 0.06973503812332638, 0.0667429955501575, 0.020642290292016696, 0.09004897074191831, 0.02037551788816927, 0.035225019018980674, 0.019051116396440193, 0.009924548849085113, 0.04007474628451746, 0.07425007162964903, 0.03700756868056487, 0.011353468853485538, 0.026496059872442856, 0.03211861891031731, 0.03297325019957498, 0.046321726113092154, 0.09646923092077486, 0.020154728954366874, 0.015062124584801495, 0.021276865518302657, 0.014324696039693663, 0.036792204846278764, 0.03219341626390815, 0.10399994440376759, 0.01726667982438812, 0.07728688055067323, 0.018981345237989444, 0.026045656013593543, 0.06360388157190755, 0.09314489914686419, 0.07039580188575201, 0.06369771872414276, 0.03741461812751368, 0.01847313735197531, 0.02664413688762579, 0.024354915585718118, 0.05254949915979523, 0.058941116149071604, 0.02090507921820972, 0.07067562866723165, 0.03533540977514349, 0.029031353224127088, 0.07194214820628986, 0.05873170062841382, 0.030062316945986822, 0.012992475094506517, 0.06050505136954598, 0.014434524618991418, 0.017120973971032072, 0.0325645791599527, 0.06249443016713485, 0.04196828042040579, 0.05281811208988074, 0.08502806711476296, 0.00712008966729627, 0.07691315724514425, 0.045549235728685744, 0.09590856061549857, 0.013183042847231263, 0.061600346307386644, 0.04858826367126312, 0.03917952693882398, 0.02518788543966366, 0.07420918671414256, 0.035981868641101755, 0.045835248311050236, 0.03441712447965983, 0.03325718476844486, 0.03797178920649458, 0.00751216999560711, 0.057909538300009444, 0.00471093683700019, 0.0956953564309515, 0.06041040156560484, 0.015417473241541302, 0.029895385669078678, 0.0785930678830482, 0.04537875698588323, 0.041513811447657645, 0.05030215354054235, 0.06863766146125272, 0.0304637724548229, 0.0607211870374158, 0.03473182849120349, 0.026752933881653007, 0.03218810248654336, 0.031302965217037126, 0.0282896211501793, 0.03954222564061638, 0.028137920598965138, 0.03166269161738455, 0.035606219462351874, 0.008348987885256065, 0.01688036041741725, 0.023338961800618563, 0.022585065926250536, 0.05366394150769338, 0.013380148920987267, 0.039674097861279733, 0.06273871549637988, 0.03479294806311373, 0.0008813037868549145, 0.06755588474334218, 0.07931257263408042, 0.04841977388423402, 0.015670199572923593, 0.029965817338961642, 0.04568448101053946, 0.062037779280217364, 0.06868056501843967, 0.03476777441392187, 0.06657859499682672, 0.06990227368078195, 0.025796819463721476, 0.05459305102704093, 0.023186717626231257, 0.06623159642913379, 0.06324488989776, 0.026761260778584983, 0.013921528952778317, 0.022068417965783738, 0.03939378497307189, 0.09143128016148694, 0.07186275324784219, 0.0093179377472552, 0.09138464360148646, 0.07646078112884425, 0.05553729664825369, 0.05340850540960673, 0.033476597018307075, 0.037972279023961164, 0.11702120740665123, 0.04009147058241069, 0.02309729254193371, 0.04234116509906016, 0.019881627886206843, 0.019770624858210795, 0.04968647153873462, 0.04657135490560904, 0.07034414098598063, 0.043891726818401366, 0.04246302203682717, 0.048373051977250725, 0.04523144438280724, 0.03623406526457984, 0.017118294817919377, 0.022088058904046193, 0.016453718271804973, 0.08362291438970715, 0.01808907778467983, 0.04476382084249053, 0.021343914850149304, 0.06221348274266347, 0.03172500975779258, 0.019145795886288397, 0.04396560390887316, 0.022627843318332452, 0.012947636387252714, 0.09601798286894336, 0.019183847653039265, 0.04140104210819118, 0.034943841528729536, 0.017717271075525787, 0.011318204778945073, 0.02524724983231863, 0.06995531497523189, 0.015764875352033414, 0.05780203820904717, 0.057161779986927286, 0.07782315646181814, 0.014559604333044263, 0.07800050749210641, 0.05054098408436403, 0.05973783023364376, 0.13179733796278015, 0.13276621175464243, 0.11309843001072295, 0.13802377885440364, 0.1713348992052488, 0.17135064757894725, 0.11875956217409112, 0.11770805765991099, 0.21622622472932562, 0.16988115065032616, 0.13662655226653442, 0.1990233751712367, 0.14190616115229204, 0.10818709706654772, 0.10528326616622508, 0.1728385646129027, 0.13850293908035383, 0.15276084275683388, 0.1297617456293665, 0.17102566111134365, 0.21725015103584155, 0.16488404769916087, 0.10102474116138183, 0.17517909058369696, 0.21701730962377042, 0.14770859823329374, 0.1496553109609522, 0.17558284860569984, 0.24239798833150417, 0.13424969074549153, 0.10120854145498015, 0.27163483668118715, 0.14939944812795147, 0.1553813216742128, 0.2430627596913837, 0.17367023014230654, 0.08671607458381914, 0.1925366630894132, 0.15593772463034838, 0.09984260381315835, 0.12857810914283618, 0.17497822089353576, 0.14581797702703625, 0.10518208175199106, 0.14269481180235744, 0.1329062253353186, 0.09913360045175068, 0.09127997109317221, 0.1302661982481368, 0.08118434328935109, 0.07147129261284135, 0.11113918240880594, 0.12904613715363666, 0.15044980973470956, 0.0903281221690122, 0.13163600990083069, 0.10909412027103826, 0.16316291817929596, 0.10147671651793644, 0.18749362119706348, 0.12949366704560816, 0.1032444900192786, 0.13973864464787766, 0.09063836216228083, 0.2034950375673361, 0.16186607448616996, 0.15760942711494863, 0.15698804170824587, 0.11109214508906007, 0.09602500358596444, 0.11571680865017697, 0.16328823723597452, 0.17503140319604427, 0.1360594475409016, 0.11957107097259723, 0.1530659693526104, 0.09621197285014205, 0.16445989545900375, 0.25612766097765416, 0.09485882241278887, 0.10894252918660641, 0.14871177409077063, 0.254155388684012, 0.10797643102705479, 0.1489548126119189, 0.10261325631290674, 0.1919841638300568, 0.14030552672920749, 0.12083951267413795, 0.11593068818910979, 0.10225020509096794, 0.1572007263894193, 0.20139554631896317, 0.11514958518091589, 0.08874019331415184, 0.18147131544537842, 0.16882283322047442, 0.1209911260230001, 0.19811519421637058, 0.10757292533526197, 0.15894366020802408, 0.17664763756329194, 0.17606892564799637, 0.19885895977495238, 0.14527557097608224, 0.1920687686651945, 0.067708589049289, 0.13491336372680962, 0.17913929448695853, 0.066698711598292, 0.2102655469207093, 0.2159962331643328, 0.17075654352083802, 0.1703559618908912, 0.14319706766400486, 0.18110993405571207, 0.1471248100278899, 0.219403047231026, 0.13543726061470807, 0.11692023821524344, 0.10909320000791922, 0.07100222559529357, 0.08419666875852272, 0.08087419235380366, 0.23679833568166941, 0.1792073345859535, 0.08106908775516786, 0.15433389897225425, 0.10789165549795143, 0.16038782021496445, 0.08828007659758441, 0.19504411291563883, 0.07528319314587861, 0.19532200269168243, 0.09826506502577104, 0.10027535012341104, 0.08019287852221169, 0.13804159039864317, 0.08859516281518154, 0.1944664993789047, 0.13238361978437752, 0.13006467546802014, 0.21462784643517807, 0.1322762161726132, 0.0705511259729974, 0.20652533043175936, 0.10245897865388542, 0.13193156279157847, 0.1361230347538367, 0.1038827073352877, 0.14235342387109995, 0.13483356800861657, 0.13013850431889296, 0.1820214992039837, 0.12764417566359043, 0.11745264753699303, 0.12320116016780958, 0.11941537581151351, 0.18996651662746444, 0.13284070853842422, 0.1950666296761483, 0.16724468587199226, 0.10639248750521801, 0.13281308580189943, 0.17232056037755683, 0.10877916021854617, 0.17345736734569073, 0.09941307100234553, 0.13275246717967093, 0.11852528841700405, 0.1259183112415485, 0.16879129194421694, 0.1091895233548712, 0.2111247758148238, 0.1890672414447181, 0.15781142486957833, 0.23641397739993408], [0.015671821165597066, 0.04204179014777765, 0.018646337921381928, 0.00875465600984171, 0.013827203838445712, 0.036930500355083495, 0.012940169453941053, 0.05452759360196069, 0.010283276133122854, 0.06434945797082037, 0.025821477320278063, 0.018895584507845342, 0.024367539517697878, 0.047027452892507426, 0.033489402776467614, 0.033101467342930846, 0.030616539843322244, 0.013981692081870278, 0.02087900385959074, 0.020119567852816544, 0.039952789156814106, 0.09290439134929329, 0.06296357882092707, 0.028362878547341097, 0.05078684276668355, 0.04031998527352698, 0.0351416647026781, 0.018573143606772646, 0.01689479704509722, 0.030331280540849548, 0.026235996483592317, 0.0325323996366933, 0.01613451498997165, 0.01879567473224597, 0.048369278156314977, 0.027979870974377263, 0.1800401578657329, 0.045610930465045385, 0.055011073127388954, 0.05740696702559944, 0.004528716854110826, 0.09637771669076756, 0.014042019411135698, 0.024076009067357518, 0.10508712395676412, 0.046452173410216346, 0.03084180392761482, 0.04200958464934956, 0.04216988483676687, 0.0297269348448026, 0.027964033542957623, 0.013503754544217372, 0.05220320192165673, 0.024577613694418687, 0.07730043958872557, 0.027023003276553936, 0.03465332782070618, 0.02138875912351068, 0.06353716249577701, 0.029916739113104995, 0.051688088351511396, 0.05673515268426854, 0.03154804464429617, 0.04685649917519186, 0.06106162501964718, 0.01722828295896761, 0.0466776638495503, 0.02993398291437188, 0.018838071773643605, 0.044725715270033106, 0.030322970342240296, 0.06377615631208755, 0.04465769001399167, 0.05165681053767912, 0.02772827363514807, 0.04024216737889219, 0.045771568329655565, 0.04251206686603837, 0.041319791780551895, 0.04712706766440533, 0.054802833910798654, 0.06501313095213845, 0.03222466439183336, 0.0789306485967245, 0.04933820018777624, 0.04486653037020005, 0.019516147985996213, 0.0464141606062185, 0.09045622427947819, 0.07751172161079012, 0.03803538013016805, 0.01933292471221648, 0.10297112734406255, 0.03460209736658726, 0.04806559132703114, 0.06267000004299916, 0.01820296405639965, 0.018684565948206, 0.0600785205460852, 0.014035747335583437, 0.02421199835225707, 0.036985389597248286, 0.04794471773493569, 0.057494666616548784, 0.02041453444689978, 0.031021633731143083, 0.010698858422983903, 0.042272701975889504, 0.04252961494785268, 0.030102162854745984, 0.024769371666479856, 0.06038834122591652, 0.026976602348440792, 0.01162525260951952, 0.05358283960958943, 0.09023291946505196, 0.050363072732579894, 0.07313751062611118, 0.024271026923088357, 0.032736122884671204, 0.03258590106270276, 0.044295258485362865, 0.02650877842825139, 0.010373437798989471, 0.03806977496424224, 0.0718437394243665, 0.0844996134401299, 0.012457547109079314, 0.05083785428723786, 0.06841669441200793, 0.07413054874632508, 0.035771425245911814, 0.07875716415583156, 0.040248690856969915, 0.017477642722951714, 0.027133985895488877, 0.004669284262490692, 0.04621068968845066, 0.04074184427736327, 0.017132824214058928, 0.04130774672375992, 0.032761693582870066, 0.038420361815951765, 0.07349832798354328, 0.03684988827444613, 0.024741659872233868, 0.019884167886630166, 0.031855854103923775, 0.08677995865582488, 0.017534665639686864, 0.04292219251510687, 0.06575459585292265, 0.04407737505971454, 0.043262611943646334, 0.03342533687828109, 0.0030978934728409513, 0.0687586389540229, 0.014594604017474921, 0.04396369658934418, 0.0538837953354232, 0.05696754880773369, 0.009007193093566457, 0.03364124619110953, 0.020735346333822235, 0.03365222626598552, 0.03611276493757032, 0.04754237721499521, 0.04279460248653777, 0.028924214930157177, 0.005514848826351226, 0.02821941026923014, 0.05286858926410787, 0.01761932799126953, 0.023734392925689463, 0.03520514059346169, 0.02739736853982322, 0.02316831236385042, 0.10188900181674398, 0.0262672501776251, 0.02634206979564624, 0.017208376702910755, 0.06538511763210408, 0.03176452541083563, 0.029816864589520264, 0.005235120843281038, 0.05382164417824242, 0.012605689062183956, 0.05534426774829626, 0.007272302300407318, 0.03565330131095834, 0.02698539123230148, 0.005054605016994174, 0.06606632014154457, 0.011602819340623682, 0.015228793326969026, 0.06485364341642708, 0.07579468874610029, 0.029645552785950713, 0.06315368736977689, 0.04017016792204231, 0.03689003104227595, 0.0555856735445559, 0.045100236384314485, 0.027092830096080434, 0.0731244488270022, 0.027731995505746454, 0.01888932634756202, 0.03206383727956563, 0.016943160953815095, 0.015324490486818831, 0.027918775522266515, 0.07222144806291908, 0.08490049935062416, 0.08127535285893828, 0.06492411775980145, 0.05745175563788507, 0.03712554418598302, 0.03754594115889631, 0.0386236360645853, 0.027129863265145104, 0.04260708032234106, 0.014062601949262898, 0.02978719538077712, 0.025021241744980216, 0.018875576206482947, 0.01128591949964175, 0.1557532712467946, 0.02313167067768518, 0.013672622826561565, 0.02691375728318235, 0.02403872542345198, 0.023592830111738294, 0.01793218034435995, 0.02202819727244787, 0.04512821164098568, 0.04232953564496711, 0.027019980880140793, 0.03488661823212169, 0.03905020399542991, 0.06109734829806257, 0.011426264263718622, 0.04349364993686322, 0.01797943845303962, 0.027769531479862053, 0.025485674050287344, 0.09548645670292899, 0.06324456335278228, 0.07998961169505492, 0.05719767024856992, 0.008829187117953552, 0.009264325926778838, 0.1044829934835434, 0.02041980369540397, 0.050621392074390315, 0.03348182173795067, 0.04995904011593666, 0.04038837789266836, 0.05291639841743745, 0.03153296420350671, 0.010084783170896117, 0.06182927289046347, 0.019108026135654654, 0.007158268062994466, 0.0243949117793818, 0.01666955151449656, 0.004794269352714764, 0.05998676882882137, 0.0337812375073554, 0.032434369350085035, 0.053459494665730745, 0.027963597531197593, 0.00340618927111791, 0.05808540132420603, 0.06910662457812577, 0.03046003945200937, 0.026225014553347137, 0.019235760883020703, 0.04451527929631993, 0.023298451669688802, 0.025467819832556415, 0.03577483912522439, 0.07500272811739706, 0.03579450974939391, 0.03938280860893428, 0.039417340740328655, 0.08130503134452738, 0.030550887604476884, 0.0458588931360282, 0.02154393107048236, 0.020702799447462894, 0.031428013389813714, 0.0730622345872689, 0.008428564669884508, 0.0403237219870789, 0.04140262659348082, 0.044678169579128735, 0.0375532476027729, 0.00536612150426663, 0.055105748906498775, 0.05302715282596182, 0.04277931424439885, 0.03288630017777905, 0.020630764738598373, 0.018553537920524832, 0.02298548057297012, 0.032169856785913, 0.04817703222215641, 0.054151654985616915, 0.03517661985824816, 0.0383073698321823, 0.03924821641703602, 0.010265818964398932, 0.024527437090000603, 0.0611116383515764, 0.06764554360415787, 0.03626127239840571, 0.004601658838510048, 0.017959363358386327, 0.07040805474389344, 0.042823045296245255, 0.03171187374391593, 0.03340680545079522, 0.007169733316914062, 0.03609005892940331, 0.013029730907874182, 0.0425809344596928, 0.017344683255942073, 0.026669835606298875, 0.08025345261557959, 0.050423309148754925, 0.051982082732138224, 0.0026035180599137675, 0.1107104956463445, 0.03219865953724366, 0.050864115182776004, 0.08535844157449901, 0.040376347678829916, 0.031777290350873955, 0.0551656105380971, 0.01282017066841945, 0.030662638346257154, 0.03470392373856157, 0.043362508731661364, 0.0370672299322905, 0.03365317992575001, 0.012517832692537922, 0.055569769319845363, 0.03540046272973996, 0.022001008692313917, 0.03052207928703865, 0.032832349752425216, 0.005818563950015232, 0.0829540537961293, 0.2203257891233079, 0.12920658948132768, 0.16495087067596614, 0.15055228548590094, 0.15284483903087676, 0.09071249529370107, 0.10431742775836028, 0.07468956406228244, 0.13805579510517418, 0.1154986914480105, 0.1518364978255704, 0.10527763326535933, 0.16913928498979658, 0.1009315051487647, 0.16507535852724686, 0.10828371727257036, 0.09133523883065209, 0.10837264882866293, 0.14682201377581805, 0.11810013427748345, 0.25922954140696675, 0.15769553108839318, 0.17610113485716283, 0.16142197331646457, 0.2080263092648238, 0.10363862980739214, 0.18049396632704884, 0.20177381898975, 0.17973329464439303, 0.13855233642971143, 0.1149411010555923, 0.13527909410186112, 0.05663443582307082, 0.13842505810316652, 0.1626321638468653, 0.2755130035802722, 0.17832408979302272, 0.17709426203509793, 0.1770856828079559, 0.09715404768940061, 0.22600041353143752, 0.13271271775010973, 0.12379072228213772, 0.21135126444278285, 0.13404782657744363, 0.13673747365828604, 0.1393739235936664, 0.11304125495371409, 0.11582677267142572, 0.17199201160110533, 0.07308619853574783, 0.11953156645176932, 0.10145724256290123, 0.11636530471150763, 0.1284807690535672, 0.10562760042375885, 0.15111707471078262, 0.10587684329948388, 0.07465420072549023, 0.153872060473077, 0.1251181127736345, 0.12160932019469328, 0.15027660730993375, 0.09203519541188143, 0.2517288626404479, 0.1712311469600536, 0.15353804948972538, 0.11431683611590415, 0.17763577750883996, 0.1651937756105326, 0.21946284949081019, 0.13576328608905897, 0.13403531396761537, 0.14635076484410092, 0.16467091772938147, 0.20354211941594258, 0.12344385730102658, 0.213021571689751, 0.07163949296227656, 0.18267700856085867, 0.27444665611255914, 0.12996705336263403, 0.10677640049834736, 0.12213884256198071, 0.11434989879489876, 0.08810783154331148, 0.2050175832118839, 0.11465809046057984, 0.1335056876996532, 0.15022219304228202, 0.13202467263909057, 0.23482349555706605, 0.1768316308152862, 0.12925904447911307, 0.13630830449983478, 0.15174742526141927, 0.20207860419759527, 0.12874993117293343, 0.09927515027811751, 0.14239580050343648, 0.1252360548824072, 0.10050137861981057, 0.21366139204474166, 0.12793284142389894, 0.11554026656085625, 0.13447270612232387, 0.2493894350482151, 0.1427986827911809, 0.14193329407135025, 0.13086684804875404, 0.13985523604787886, 0.05816048440465238, 0.12493962625740096, 0.11719743779394776, 0.17911238421220332, 0.15809109580004588, 0.1763833884615451, 0.14562432101229206, 0.16070271347416565, 0.16616782959317788, 0.08213156863348559, 0.10367523253080435, 0.1240764491376467, 0.14260216208640486, 0.16659808228723705, 0.10471745277754962, 0.10343724803533405, 0.12628315103938803, 0.20266589534003288, 0.17750688130035996, 0.16835578484460711, 0.2230320157832466, 0.11311905429465696, 0.11112610576674342, 0.09055177579284646, 0.15640548546798527, 0.18311146181076765, 0.18790667090797797, 0.058413475126144476, 0.13743981253355742, 0.127261123561766, 0.14255847927415743, 0.1152062407345511, 0.22650443570455536, 0.14294730528490618, 0.07196067221229896, 0.1450528673012741, 0.20218617108184844, 0.16653491067700088, 0.12954554316820577, 0.17046774417394772, 0.11127999750897288, 0.14156550052575767, 0.1552372262813151, 0.07582941383589059, 0.22347685910062864, 0.10731925925938413, 0.07270461588632315, 0.21972643065964803, 0.16107089293655008, 0.165330731542781, 0.17606352281291038, 0.0639665691414848, 0.13006690191105008, 0.11941314936848357, 0.1484206592431292, 0.11478332045953721, 0.17258522508200258, 0.0775444132159464, 0.12120157683966681, 0.0952517450787127, 0.15569612587569281, 0.09858137578703463, 0.15033137780847028, 0.0914315770205576], [0.03428705567785073, 0.059911826756433584, 0.03921336516214069, 0.009932634548022179, 0.02005494163313415, 0.054388296193792485, 0.05893837762414478, 0.06916967002325691, 0.027484140446176752, 0.028850920425611548, 0.07770698066451587, 0.07695519991102628, 0.022866373292345088, 0.02413305795926135, 0.030060762146604247, 0.04500451417698059, 0.06534792119055055, 0.06565502932062373, 0.04091829730896279, 0.03219905658625066, 0.06295956380199641, 0.03736724684131332, 0.019272621502750553, 0.028312267786532175, 0.012671165968640707, 0.029799182921124157, 0.035441095315036364, 0.0016849200187607494, 0.04006558818218764, 0.06654988872469403, 0.05711198187782429, 0.00546602061149315, 0.032445364267914556, 0.08790932188276201, 0.045234079007059336, 0.044322732792352326, 0.01962918264325708, 0.017507328630017582, 0.031718649552203715, 0.013234624893811997, 0.00729415947716916, 0.02385564130236162, 0.03332538813992869, 0.011397038488212274, 0.03690462537633721, 0.029060955639579333, 0.019125512990285642, 0.024290467481478117, 0.06973318275413476, 0.06136858100944664, 0.009868536180874798, 0.04130710105528124, 0.05825823267514352, 0.01761400493705878, 0.04649406022508629, 0.02499742437066743, 0.040898470833781175, 0.01753920572809875, 0.027755766495829448, 0.09743534392328002, 0.04067242378368974, 0.050811040491680615, 0.08379666600376368, 0.03471569791145157, 0.023132236565288622, 0.024782095788395964, 0.059555013285716996, 0.019569500982470345, 0.006763318406228791, 0.07011275418335572, 0.02253275193652371, 0.027525457662704866, 0.007944262288219761, 0.024390188009419944, 0.0511655978334602, 0.01869997850008076, 0.06471467626397498, 0.06141182966530323, 0.06384536900441162, 0.04938143028994091, 0.019408519874559715, 0.005821024633405614, 0.05414578459749464, 0.004427473068062682, 0.03565316030289978, 0.03280902034020983, 0.014256110462156357, 0.02521495713153854, 0.010353885918448213, 0.04683252780523617, 0.028788741437892895, 0.09203228619298898, 0.048538933115196414, 0.001921288139783428, 0.05385551579820458, 0.0464364695653785, 0.04295237566111609, 0.015545277565252036, 0.011012586510332767, 0.041416864696657285, 0.021798792004119605, 0.02321004147233907, 0.05029252417443786, 0.0033789039798648446, 0.05799150851089507, 0.012583913521666545, 0.04715164388471749, 0.06384838212397881, 0.005674905496562133, 0.025062516288016923, 0.04732264955237042, 0.019198558875359595, 0.05845201114425436, 0.04276406682038214, 0.08229602113715373, 0.08066425361903384, 0.011498283201945014, 0.03843286700430326, 0.03604800884204451, 0.11433516716351733, 0.02415417206066195, 0.04702665508375503, 0.052417511906242, 0.06791148480260745, 0.005962392633591662, 0.005478632947415463, 0.034710940744844265, 0.04470251573366113, 0.041086122873821296, 0.009859103483904619, 0.01776249941030983, 0.009489506519457791, 0.06816697656176984, 0.023267433607543353, 0.017536528430355247, 0.06596626379177906, 0.04436044873727951, 0.04543472605291754, 0.014123187174845953, 0.009268641515518539, 0.05439480111817829, 0.03647807599918451, 0.007677394332858967, 0.1004245292278938, 0.00605840798925783, 0.04785658027685713, 0.025984219173551537, 0.04468224025913514, 0.0070608611804345855, 0.04210170001897495, 0.04796862602233887, 0.054102758585941046, 0.032689486324670725, 0.0917564521660097, 0.11698107206029817, 0.03291642395197414, 0.03250615729484707, 0.052645221367129125, 0.021640779486915562, 0.028717328277707566, 0.030849531540297903, 0.03983072812843602, 0.06693646602798253, 0.0347746281477157, 0.010270092807331821, 0.0639442601823248, 0.019584752117225435, 0.058279068471165374, 0.019669227076519746, 0.019477704736345913, 0.03779066064453218, 0.016478793586429674, 0.09624113925383426, 0.046430127913481556, 0.026488521507417317, 0.04705657105660066, 0.03653682069852948, 0.0027290855041428586, 0.04978566699719522, 0.021265137729642447, 0.04187110731436405, 0.05842090402438771, 0.016757778030296322, 0.01832578949688468, 0.03395289626496378, 0.05670670616382267, 0.015525368526141392, 0.10375053825555369, 0.02415246326563647, 0.014546705806424143, 0.04914623255899642, 0.035749817616306245, 0.09502032116870396, 0.035688891002791934, 0.01746059744618833, 0.11485102659207769, 0.055291783064603806, 0.05069666440249421, 0.031247727165464312, 0.05288422260491643, 0.025618286563258152, 0.010481462031748379, 0.03344251017551869, 0.07616653441800736, 0.04523040166532155, 0.002902246646954154, 0.09786712544155307, 0.06712606991641223, 0.020969325087207835, 0.07389925842289813, 0.03754693563678302, 0.010077119568450144, 0.021283934474922717, 0.0235480563424062, 0.10346795810619369, 0.0038971941739873728, 0.027142093858856242, 0.0833533589320723, 0.028526041569421068, 0.03415278632019181, 0.03883521494572051, 0.022061118943383917, 0.012306804856052622, 0.050002541102003306, 0.023330907642957754, 0.015212096859613666, 0.025235527609765995, 0.04892347693385091, 0.034218826331198215, 0.0747271538421046, 0.054967041505733505, 0.037505746440729126, 0.01672308448178228, 0.020782405917998403, 0.0328824818279827, 0.03891099935572129, 0.015052072194521315, 0.0360341566556599, 0.04751384163682815, 0.007118580788301188, 0.11395883149816655, 0.015793533384567127, 0.054633141844533384, 0.030661677265015896, 0.011076931641582632, 0.02975976931338664, 0.05669490601576399, 0.05749473340983968, 0.05032422501244582, 0.026751453297038097, 0.03512263603624888, 0.02913107931817649, 0.03256817486544605, 0.06181029988511, 0.05770787822257262, 0.023195916546683293, 0.00725713280189666, 0.04289479984436184, 0.061741005556541495, 0.08084017972578295, 0.014998535516497213, 0.031118871775106527, 0.011464962626632769, 0.02532792499550851, 0.028997607769269962, 0.01741962903906824, 0.025016616309585515, 0.028076038470317144, 0.05123486618686002, 0.009873373128357343, 0.015788238160894252, 0.0376679799228441, 0.04170569001871627, 0.07209640360088088, 0.013404594337771414, 0.0094284648730536, 0.04693632829003036, 0.02477049973094836, 0.02515349246095866, 0.06880867455038242, 0.032944970662356354, 0.04165560989349615, 0.02224941665190272, 0.05430827040981967, 0.031197261123452336, 0.04253130704455543, 0.03620289506216068, 0.034272750781383365, 0.060059324896428734, 0.011279824611847289, 0.04440895550942514, 0.05218725316808559, 0.03288428524683695, 0.015689591891714372, 0.023494400920753833, 0.1026222511427477, 0.06694250711007044, 0.022551348301931284, 0.04868486903433222, 0.008816649460641202, 0.04008487660030369, 0.04180603580607567, 0.07196380407549441, 0.009298205895902356, 0.02729688916588202, 0.027898980588361155, 0.03936386900022626, 0.06012283047311939, 0.04685286265157629, 0.06393709103576839, 0.10793742374517024, 0.042569212237140164, 0.053154297565924935, 0.08218381582992151, 0.040775185261736624, 0.016901409580896143, 0.05705371957446914, 0.0385617112624459, 0.038610492629231885, 0.05083541262138169, 0.009121536713792011, 0.06499445851659402, 0.009086784721148433, 0.06623424589633942, 0.03735211445018649, 0.03841894802462775, 0.03278770214819815, 0.0411825278570177, 0.03835055169474799, 0.04165384358202573, 0.04874065256444737, 0.028459086861403193, 0.028573802483151667, 0.06694491909001954, 0.028969027662242297, 0.031427015201188624, 0.03289223364845384, 0.01628022269869689, 0.02210765716881724, 0.1343626604648307, 0.02377959342993563, 0.05119806679431349, 0.03493226773571223, 0.009763119669514708, 0.03631275518273469, 0.021030409407103434, 0.039208986490848474, 0.01927713932673214, 0.04855830688029528, 0.059833114573848434, 0.04850316159718204, 0.06447526684496552, 0.14572419924661517, 0.10794414018164389, 0.10455930852913298, 0.08678664540639147, 0.1458689774153754, 0.12280941009521484, 0.1065280481998343, 0.12199205317301676, 0.1309354224940762, 0.15346476982813329, 0.08471773806377314, 0.1681118260603398, 0.18209241883596405, 0.14987320551881567, 0.12451974878786132, 0.23536734137451276, 0.17778346489649266, 0.08907139155780897, 0.16429349110694602, 0.1355723018059507, 0.11617443917202763, 0.1343502665986307, 0.1163752940192353, 0.10603104674373753, 0.15403793047880754, 0.11523527355166152, 0.0999314092041459, 0.1832983791246079, 0.1766687590861693, 0.16886390367290005, 0.2121051974245347, 0.141092425910756, 0.13789721298962831, 0.18055308581097052, 0.11262215673923492, 0.12567215570015833, 0.07370517196250148, 0.10923469046247192, 0.17291634168941528, 0.09002390099340118, 0.11550403491128236, 0.13499759748810902, 0.10365611480665393, 0.16411818098276854, 0.09304491701186635, 0.18133205885533243, 0.09589654524461366, 0.09420372865861282, 0.1467075597611256, 0.17890185175929219, 0.13462291681207716, 0.08574706720537506, 0.11723369912942871, 0.11033957023755647, 0.17200749280164018, 0.17415909765986726, 0.14848476595943794, 0.06830218102550134, 0.15764034498715773, 0.1581666464335285, 0.15099830139661208, 0.15093867725227028, 0.17823629372287542, 0.13519806641852483, 0.1643005118239671, 0.15779218840179965, 0.15602362080244347, 0.13125053839758039, 0.17250940727535635, 0.1842198593658395, 0.13099005940603092, 0.15815223392564803, 0.11082661949330941, 0.1636907336069271, 0.18961972586112097, 0.16645765310386196, 0.14693853096105158, 0.17347881541354582, 0.15305851818993688, 0.1169654646946583, 0.15099220094271004, 0.10471519664861262, 0.15111199842067435, 0.17468354373704642, 0.08931194388424046, 0.1431060061440803, 0.14528088475344703, 0.08905499009415507, 0.13646197359776124, 0.12655381229706109, 0.15501766931265593, 0.18112455436494201, 0.1896119481534697, 0.09326045896159485, 0.17947429994819686, 0.15846343128941953, 0.10685841523809358, 0.15466506010852754, 0.067584873031592, 0.16166766872629523, 0.17970012064324692, 0.10057653591502458, 0.0844277067517396, 0.2076626569032669, 0.11998930087429471, 0.17567534989211708, 0.17645469401031733, 0.12760843383148313, 0.0948092617909424, 0.1479974272660911, 0.12251569773070514, 0.11232764285523444, 0.11122259238618426, 0.2037808534805663, 0.1691572746494785, 0.1612958378973417, 0.08107803063467145, 0.07710754798608832, 0.1678520446876064, 0.19948040455346927, 0.15708941908087581, 0.1024559506913647, 0.11992871193797328, 0.1416681395494379, 0.1889013417530805, 0.16619922243990004, 0.11579449666896835, 0.13250181422336027, 0.280370389809832, 0.18949495599372312, 0.09884883096674457, 0.12151923088822514, 0.1769932112074457, 0.21032000571722165, 0.2640572714153677, 0.12631984282052144, 0.2184637257596478, 0.13143246847903356, 0.16101201093988493, 0.1550794011563994, 0.18962147732963786, 0.12255647874553688, 0.07392342275124975, 0.16081096313428134, 0.10921091205091216, 0.17319215345196426, 0.11813452540081926, 0.15705961443018168, 0.08421776801696979, 0.1704860752215609, 0.16387591429520398, 0.175767702748999, 0.09302257836679928, 0.20099766610655934, 0.16177395911654457, 0.1422358676791191, 0.13016869488637894, 0.129529646364972, 0.23130908492021263, 0.08813717606244609, 0.10398152429843321, 0.11006450062268414, 0.12328857774264179, 0.2616431540809572, 0.10119694168679416, 0.135893770493567, 0.14029216807102785, 0.096921443764586, 0.22421832400141284, 0.09724061921588145, 0.1442652111290954, 0.09581443402566947, 0.16788324457593262, 0.16038985369959846, 0.12137129117036238, 0.18492065457394347], [0.018812408306985162, 0.028353249181236606, 0.019606634341471363, 0.0930343043000903, 0.013660292970598675, 0.0023823181618354283, 0.03848670981824398, 0.02235826374089811, 0.03766638430533931, 0.05489500494149979, 0.05669286510965321, 0.002941999787253735, 0.038274080798146315, 0.04626677378837485, 0.03141965309623629, 0.015447978294105269, 0.03377354885742534, 0.06797700159950182, 0.05364585907955188, 0.04305632086470723, 0.03987180600233842, 0.02184276239859173, 0.0822164629062172, 0.03546623556758277, 0.03700066670717206, 0.0406949850730598, 0.042552699451334774, 0.03297322793514468, 0.09951052241376601, 0.027395242286729626, 0.035914596664952114, 0.04479084615013562, 0.05838776341988705, 0.03855154755001422, 0.06298760214122012, 0.022082485374994576, 0.026321350887883455, 0.035827208776026964, 0.01070540138243814, 0.04757841961691156, 0.03896329850249458, 0.022616069145442452, 0.027609450226009358, 0.13618169410619885, 0.03544545543263666, 0.014088759871810907, 0.019777762463490944, 0.05538595047255512, 0.014618978002545191, 0.027694019809132442, 0.014119302031758707, 0.052302727635833435, 0.08716698124771938, 0.031123632652452216, 0.05239226775302086, 0.051321723440196365, 0.038561778055736795, 0.03900464726029895, 0.0019247523459853255, 0.04914826604363043, 0.028130883183621336, 0.02463670720317168, 0.04497711037402041, 0.04146991341258399, 0.028203927213326097, 0.04422930011060089, 0.02645346430654172, 0.00599444228100765, 0.05936130532063544, 0.020116736559430137, 0.01535370049168705, 0.05626861639029812, 0.03469538161880337, 0.07733455611742102, 0.04473967135709245, 0.006190322419570293, 0.02151210963347694, 0.013999645561852958, 0.03507122375594918, 0.026353255816502497, 0.03372842627868522, 0.036977815980208106, 0.0328318228275748, 0.03085417367401533, 0.021574741331278346, 0.005467399150802521, 0.00940634608923574, 0.030124889271974098, 0.05157426516234409, 0.07908882995252497, 0.07696330416365527, 0.030615222531196196, 0.05596306305960752, 0.028965205601707567, 0.04262032394763082, 0.06456849543610588, 0.09618233147193678, 0.04508494814217556, 0.034299753824598156, 0.05519849139091093, 0.017744630349625368, 0.05705911127733998, 0.044564710042322986, 0.01662611546635162, 0.006667006191491964, 0.004929309616272803, 0.030400919968087692, 0.03033489665540401, 0.06588282412849367, 0.05861122779606376, 0.04362446459708735, 0.02086494758259505, 0.0361723037349293, 0.041098746805801056, 0.0022450614278568537, 0.044890843128087, 0.028419897753337864, 0.03763400440220721, 0.0482450240815524, 0.03778502403292805, 0.016507165892107878, 0.04460799209482502, 0.05722658803279046, 0.03273424525104929, 0.03636920664575882, 0.04103679231775459, 0.02392077774857171, 0.06906835944391787, 0.06700965663185343, 0.05019883916247636, 0.06768578285118565, 0.04191854168311693, 0.05391202663304284, 0.018258658528793603, 0.09257389814592898, 0.0485170694446424, 0.0070305249664670555, 0.04379506208351813, 0.0017687545278022299, 0.0773228079196997, 0.028991945182497147, 0.038427111649070866, 0.03780012673814781, 0.010272706094838213, 0.08440838864771649, 0.04840546156628989, 0.023135123519750778, 0.07977840388775803, 0.00987686864391435, 0.01174243679997744, 0.009145033109234646, 0.12612442049430683, 0.03007495015481254, 0.022073661239119247, 0.03457525759586133, 0.014212833975761896, 0.020746211375808343, 0.03622024647484068, 0.06850989331724122, 0.048319494890165515, 0.05015706366975792, 0.04990728273696732, 0.043786720343632624, 0.040829881545505486, 0.034625571497599594, 0.03122077978332527, 0.02904364504502155, 0.008295679417642532, 0.010613426093186717, 0.042286966054234654, 0.04569771350361407, 0.035043979514739476, 0.06225963690667413, 0.046102989217615686, 0.0246774919287418, 0.08162693047779612, 0.028304725710768253, 0.0836382842680905, 0.01393326045217691, 0.02312100972631015, 0.030808173505647574, 0.04139122349442914, 0.07015829978627153, 0.017918608318723273, 0.018842888312065043, 0.07551386748673394, 0.062257128447527066, 0.028755997882399242, 0.009253824537154287, 0.03915479486749973, 0.044820019975304604, 0.03765390138141811, 0.006780941630495363, 0.05921272735577077, 0.02059798593109008, 0.007250443268276285, 0.014353951501107076, 0.06563417497090995, 0.08397075900575146, 0.02692947040486615, 0.03103235962043982, 0.03237904966226779, 0.02875056536140619, 0.0056293042325705756, 0.045285799278644845, 0.05414651190221775, 0.10482057419721968, 0.01946118638443295, 0.02560423585237004, 0.03314811132440809, 0.027545363918761723, 0.018310074519831687, 0.00233279093663441, 0.03174121826305054, 0.028015206480631605, 0.036960690922569484, 0.056634168649907224, 0.04385895357700065, 0.023847865450079553, 0.022185135530889966, 0.0423813932138728, 0.04228465797496028, 0.059844443458132446, 0.052487785869743675, 0.04039145780552644, 0.059924406159552746, 0.04436466042534448, 0.03613859538745601, 0.053079659774084575, 0.02401085221208632, 0.049961422409978695, 0.04380718135507777, 0.020127364114159718, 0.043529135728022084, 0.010038444397650892, 0.03919261471310165, 0.04936566336255055, 0.026963108248310164, 0.09032018861034885, 0.032602202336420305, 0.04543966875644401, 0.05666381744958926, 0.03344619122799486, 0.023026499075058382, 0.037950522964820266, 0.01608569651580183, 0.04734712929348461, 0.038692830203217454, 0.046559102047467604, 0.027804664750874508, 0.025128059060079977, 0.008053044439293444, 0.05341236828826368, 0.037425817135954276, 0.05366551115002949, 0.016139390900207218, 0.0268827169566066, 0.03268813561589923, 0.02374515406700084, 0.012031078440486453, 0.03209207599866204, 0.01459999572034576, 0.061611456258106045, 0.029268797807162628, 0.036367729771882296, 0.03965943673392758, 0.02174463377741631, 0.03217951954866294, 0.05629127786960453, 0.041560266181477346, 0.04526589487795718, 0.042379151927889325, 0.09850054106209427, 0.04306635099055711, 0.020624306198442355, 0.031791680594324134, 0.012448275829228805, 0.05397940993134398, 0.12196788884466514, 0.055610383351449855, 0.04957268916768953, 0.08384520988329314, 0.02236482618172886, 0.06553112776600756, 0.05241905186267104, 0.038639722115476616, 0.032603178260615095, 0.018901232251664624, 0.027032558427890763, 0.05773750846856274, 0.035158700702595524, 0.034624332110979594, 0.03161378037475515, 0.008467125735478476, 0.03915529581718147, 0.02102715694491053, 0.06268453871598467, 0.048761736979940906, 0.032764973875600845, 0.015705188125139102, 0.0422263140353607, 0.03962808470532764, 0.06679408499621786, 0.05578804608376231, 0.03382932125532534, 0.013257660230010515, 0.029376138336374424, 0.03481435160210822, 0.040321425040019676, 0.02907117501308676, 0.0446931164333364, 0.013636598978337133, 0.024493470846209675, 0.009534368418826489, 0.06288350850809366, 0.033551086380612105, 0.04660039514419623, 0.052525186401908286, 0.03847914733341895, 0.051887306763092056, 0.07324295496800914, 0.008536048990208656, 0.009820554478210397, 0.017666740095592104, 0.05833423972944729, 0.061409517875290476, 0.003404169237910537, 0.048887634911807254, 0.046376730388146825, 0.030325875850394368, 0.043620920841931365, 0.02768578939139843, 0.04319935127568897, 0.004917981659673387, 0.07812574491254054, 0.06598046849831007, 0.02511357048206264, 0.06414077346562408, 0.0323928127909312, 0.026600463352224324, 0.04854206126765348, 0.03230023357900791, 0.03975568586611189, 0.039319740899372846, 0.032318371668225154, 0.02044441702309996, 0.027158907214470673, 0.046145770320435986, 0.06449983935453929, 0.0656387911294587, 0.024440661472908687, 0.0477313873852836, 0.06861889996798709, 0.1959271202213131, 0.0975116589688696, 0.32696141162887216, 0.07967144556459971, 0.11415219807531685, 0.15862711938098073, 0.16544491838430986, 0.09823514163144864, 0.13156546134268865, 0.23316516657359898, 0.14127880887826905, 0.12608942080987617, 0.13676123722689226, 0.12015557163977064, 0.11004196901922114, 0.1836319745052606, 0.14588005025871098, 0.10094675628351979, 0.10356765080359764, 0.11176675732713193, 0.09944413730408996, 0.18768876150716096, 0.1560710885678418, 0.13965926453238353, 0.16670637647621334, 0.1667079795151949, 0.1571986632188782, 0.16702214546967298, 0.148311058874242, 0.1226327863696497, 0.06998909753747284, 0.13971350068459287, 0.13861734856618568, 0.21169807005207986, 0.08059317813604139, 0.11040260826121084, 0.09537481542793103, 0.09683735843282193, 0.0710342641104944, 0.17040550766978413, 0.13952524750493467, 0.1983161678072065, 0.2442732619238086, 0.1377182366559282, 0.10667008784366772, 0.11078040595748462, 0.1328613847726956, 0.10521841730223969, 0.11023624843801372, 0.09367009479319677, 0.09891031790175475, 0.1719921303447336, 0.1857179289800115, 0.11485605835332535, 0.1453575782943517, 0.25045717775356025, 0.20020658121211454, 0.09653109635110013, 0.11106292673503049, 0.1465646072756499, 0.11991398030659184, 0.16286325379041955, 0.14281784504419193, 0.1347261347109452, 0.1079598959768191, 0.15167157776886597, 0.18154830584535375, 0.13396644266322255, 0.11725421209121123, 0.18938229797640815, 0.174356835486833, 0.08808486949419603, 0.1967060487368144, 0.1253134460421279, 0.142425783269573, 0.17159527429612353, 0.14312686049379408, 0.11636140101472847, 0.09264560445444658, 0.12625913514057174, 0.11397993817809038, 0.14852939872071147, 0.06336047939839773, 0.10296518274117261, 0.12110057796235196, 0.1690849449369125, 0.07702430870267563, 0.18939706671517342, 0.1673106331145391, 0.2019923517946154, 0.12481261510401964, 0.29589525831397623, 0.14371529454365373, 0.17726139369187877, 0.13425883400486782, 0.18789332709275186, 0.10959325169096701, 0.10334218633943237, 0.12880694295745343, 0.08487838334986009, 0.14132716722087935, 0.20495133911026642, 0.10876209082198329, 0.12575925415148959, 0.09327395862783305, 0.09345628946903162, 0.13737531990045682, 0.11813721939688548, 0.14058081898838282, 0.16109945077914745, 0.15609451074851677, 0.10242278411169536, 0.08642824002890848, 0.15492340171476826, 0.11602643266087398, 0.12351055411272682, 0.2777458290802315, 0.14820310607319698, 0.16171757073607296, 0.13801462075207382, 0.15016887715319172, 0.07850834430428222, 0.23238586698425934, 0.09416992383194156, 0.1434879598673433, 0.13571443792898208, 0.19861553533701226, 0.16409659932833165, 0.1532795446109958, 0.11967247803113423, 0.19466941739665344, 0.11444680101703852, 0.10712381466873921, 0.2531972760334611, 0.1492722737020813, 0.13609281450044364, 0.1088227539730724, 0.12081078413757496, 0.12744177714921534, 0.09894851624267176, 0.13285958877531812, 0.15889105678070337, 0.09225124202203006, 0.1627027420909144, 0.16539863805519417, 0.07691186590818688, 0.10694993688957766, 0.1731289818417281, 0.17774931126041338, 0.0666028780688066, 0.19679445336805657, 0.1097631367156282, 0.12523275974672288, 0.14061526948353276, 0.12208240223117173, 0.17615828022826463, 0.09199911219184287, 0.22742008266504854, 0.1442993202363141, 0.06825465388828889, 0.1619098463561386, 0.09802656102692708, 0.09777888408279978, 0.21708790271077305, 0.1013554199016653, 0.056348987272940576, 0.10304828843800351, 0.12061699453624897, 0.11221344117075205, 0.20482691063079983, 0.15783634618856013, 0.13915681571234018, 0.11762705966248177, 0.13382141216425225, 0.16025959193939343], [0.06720003977534361, 0.03231118025723845, 0.07511119300033897, 0.03754517303605098, 0.0398959554877365, 0.027860012269229628, 0.023012962301436346, 0.07183171663200483, 0.11147987272124738, 0.03448707931966055, 0.0148078054189682, 0.048150745351449586, 0.08386440182221122, 0.02016803566220915, 0.05556686010095291, 0.031217959622154012, 0.021798252091684844, 0.017631914815865457, 0.05338497932825703, 0.06118531877291389, 0.042009002063423395, 0.020942366572853643, 0.03970473742811009, 0.0614228579797782, 0.05598470779659692, 0.059828309167642146, 0.03394739695067983, 0.03340502800710965, 0.026188070442003664, 0.08259364461991936, 0.01924534015415702, 0.024434117585769854, 0.03625189536251128, 0.03342569681990426, 0.02566727387602441, 0.032332442788174376, 0.06006917690683622, 0.01692294485110324, 0.051576884943642654, 0.05999862834869418, 0.04080833328771405, 0.08440053672529757, 0.04533381994406227, 0.006231943916645832, 0.05342457661754452, 0.02978554224682739, 0.008286740248877322, 0.02758696129603777, 0.03814969313680194, 0.0397249869274674, 0.027201877564948518, 0.05292120011290535, 0.006050648835298489, 0.048191481837420724, 0.030287532790680416, 0.05287087507895194, 0.0021310900410753675, 0.04968467925209552, 0.02044753775408026, 0.03175184210704174, 0.04901817868812941, 0.05785287903563585, 0.042727887121145613, 0.042800884766620584, 0.06426472697057761, 0.026643851160770282, 0.01593382898136042, 0.011551549923751736, 0.019024393513973337, 0.03725034373928793, 0.023261479727807455, 0.06094177188060712, 0.023366493624052964, 0.025743566657183692, 0.03453145232924726, 0.02323612239706563, 0.02135514725523535, 0.04706724314019084, 0.04123096041439567, 0.06903143017552793, 0.04006885734270327, 0.029703356813115533, 0.029749557361355983, 0.056531392328906804, 0.03410658391658217, 0.07254213007399812, 0.041718228603713214, 0.052692960016429424, 0.021796511755383108, 0.03321146847156342, 0.009363938843307551, 0.033898504261742346, 0.07724432580289431, 0.055233954917639494, 0.0580159363016719, 0.017261978318856563, 0.04221970149956178, 0.03936966888431925, 0.04650128503271844, 0.02681256544747157, 0.03248929941037204, 0.07125048883608542, 0.05221081635681912, 0.010974250872095581, 0.007914175621408504, 0.0366433819726808, 0.020098913882975467, 0.037707877781940624, 0.014005205175635638, 0.03146386283333413, 0.041138462838716805, 0.018305267258256208, 0.030356261231645476, 0.07195990037871525, 0.02981012217787793, 0.015080768262123456, 0.017667111169430427, 0.01601872696483042, 0.06319213804090396, 0.022733155929017812, 0.056013803696259856, 0.043698196968762204, 0.07519840277382173, 0.03547181280737277, 0.05226300418144092, 0.026528384114499204, 0.044906068287673406, 0.02786056516924873, 0.028219098567205947, 0.0328428882494336, 0.12080128464731388, 0.05298328818753362, 0.06880780623760074, 0.06739453441696241, 0.056275540628121234, 0.10002575101680122, 0.061375846635201015, 0.07480317202862352, 0.017243754882656503, 0.044577493536053225, 0.08939644481870346, 0.04566613511997275, 0.06460710195824504, 0.03857722957036458, 0.06601291519473307, 0.03414355400309432, 0.08798336595646106, 0.049779243709053844, 0.050945513939950615, 0.0067065923485643, 0.057617792626842856, 0.025288014148827642, 0.03237562094000168, 0.04412687259900849, 0.048778053096611984, 0.03273416732554324, 0.037589449566439725, 0.07763108122162521, 0.003995002743977238, 0.04047418500704225, 0.04035401274450123, 0.03794078598730266, 0.047204993170453236, 0.04149401836912148, 0.0034144992378060124, 0.03265185572672635, 0.01576352649863111, 0.03522419152432121, 0.05647747530019842, 0.04907353919406887, 0.04946164903230965, 0.058121588444919325, 0.011392421401978936, 0.06632733347942121, 0.05083185031253379, 0.044176485171192326, 0.12093873781850561, 0.060154713137308136, 0.046890730736777186, 0.08993185983854346, 0.09805356035940349, 0.028460893990995828, 0.028569358873937745, 0.01361408500088146, 0.054779619531473145, 0.017701285214570817, 0.05343736382201314, 0.023725719074718654, 0.03187427791999653, 0.01733177174173761, 0.03331189218442887, 0.1077142079884652, 0.045000547397648916, 0.023920644161989912, 0.003274786922702333, 0.015222738329612184, 0.01981332061404828, 0.047680409261374734, 0.034034799682558514, 0.009586020969436504, 0.018971927383972798, 0.0697785205557011, 0.05336342735972721, 0.04183056007605046, 0.05303922385792248, 0.023656914563616738, 0.04808693178347312, 0.008609645919932518, 0.0680002011358738, 0.027289317404211033, 0.0340106353542069, 0.03306162514491007, 0.03253093389503192, 0.00967459815001348, 0.044838807443738915, 0.03037717495317338, 0.02355744636588497, 0.05058953167463187, 0.016808242216939107, 0.037946493102936074, 0.022383530158549547, 0.05284156766720116, 0.017582051768840756, 0.061602825080626644, 0.02308559629454976, 0.07211426709545776, 0.005709008573830943, 0.03213424854038749, 0.022886214610480238, 0.03793287469306961, 0.020812373841181397, 0.023842510854592547, 0.019474812215776183, 0.04858411135501228, 0.10287089287885465, 0.008467737079627113, 0.02309940024133539, 0.06641319254413247, 0.06961832055822015, 0.09400944181834348, 0.07704013129114173, 0.12661904707783833, 0.027112613897770643, 0.04850716177315917, 0.012698284044745378, 0.0152018644985219, 0.05245244850812014, 0.05868863750947639, 0.03838400400127284, 0.009769954849616624, 0.014387440915015759, 0.059270184428896755, 0.038999797325232066, 0.03123923328530509, 0.004086510016350076, 0.028088469443900976, 0.0649852558854036, 0.05084864882519469, 0.04095090727787465, 0.06226821613381617, 0.03810594353126362, 0.04382071812869981, 0.06330939737381414, 0.021141946781426668, 0.055646841356065124, 0.03106733889580937, 0.01568571045936551, 0.02113212445692625, 0.043584726299741305, 0.032485436531715095, 0.054099645276437514, 0.048398837898275815, 0.019339828540978488, 0.08287010947242379, 0.08083363398327492, 0.04047938004077878, 0.03619207454903517, 0.009049456548382295, 0.05321733930031769, 0.05239004130999092, 0.02148895462596556, 0.02409107837593183, 0.028743834081979003, 0.011802236276707845, 0.020778541183972266, 0.012414265056577278, 0.033119115614681505, 0.013111640819261083, 0.03587553001125343, 0.05975174550258089, 0.058038479037350044, 0.027135167765663937, 0.10034495615400374, 0.028970447019673884, 0.0544665296911262, 0.02591979889984941, 0.03822335129370913, 0.028378422830428462, 0.026740560424514115, 0.07642117270734161, 0.011327620777592529, 0.022688951758027542, 0.008095327375485795, 0.08403071711654775, 0.019754585191549268, 0.04861769724811893, 0.014584020063921344, 0.0400242542673368, 0.033737350604496896, 0.02058008532912936, 0.06124272018496413, 0.03331188105221372, 0.0350034508301178, 0.07085632678354159, 0.06711088557494804, 0.03936135311960243, 0.05288266409479547, 0.04005098271591123, 0.05176161663257517, 0.048747825421742164, 0.023173928566393442, 0.0579439405555604, 0.03364461183082312, 0.03608460414397996, 0.011451534392108442, 0.036006530208396725, 0.018764606575132348, 0.05545835811062716, 0.054593381282757036, 0.02847503561497433, 0.020374616178742144, 0.04194010849460028, 0.03266355568484869, 0.0057906118854589295, 0.026859142635657918, 0.11313816459733061, 0.06015364815539215, 0.015818527062947396, 0.025365561159560457, 0.013154494281479856, 0.04398915967612993, 0.02358854420890566, 0.04356624311185442, 0.029274632943270262, 0.045914301881566644, 0.026944944183924235, 0.05664916003297549, 0.051814698745147325, 0.02866917031496996, 0.08951805313699879, 0.040100528494804166, 0.05350183419068344, 0.38190070423297584, 0.10913286037975922, 0.12288541343878023, 0.2355049949255772, 0.15443187730852515, 0.07763595713186078, 0.11321557060000487, 0.1445206583593972, 0.29740912083070725, 0.15420458716107532, 0.07977411427418701, 0.12654848367674276, 0.1467411345220171, 0.06195589812705293, 0.1667090630508028, 0.16988383722491562, 0.17037098295986652, 0.08150064662913792, 0.17148868704680353, 0.1772493708995171, 0.13980411691591144, 0.09215672209393233, 0.17519485380034894, 0.11506514361826703, 0.1349554880289361, 0.15115575544768944, 0.14640914218034595, 0.10982344363583252, 0.08664025677717291, 0.16184326086658984, 0.12561952258693054, 0.13799143605865538, 0.1256803935393691, 0.07908955725724809, 0.1234816103533376, 0.1306938534253277, 0.17358923214487731, 0.13956435868749395, 0.2343494858359918, 0.16391006793128327, 0.09764998045284301, 0.2231748346821405, 0.1256538394954987, 0.09345121317892335, 0.1544600195484236, 0.16296727320877835, 0.07570618763566017, 0.13031184033025056, 0.16158245533006266, 0.10364668210968375, 0.08173532114597037, 0.18921670998679474, 0.08964049266069196, 0.1633234744076617, 0.15891381102846935, 0.10887373951845802, 0.13508892618119717, 0.1436569172074087, 0.19804549170657992, 0.0651280302554369, 0.14526855025906116, 0.17137375805759802, 0.12323791132075712, 0.19987356470664963, 0.17341874598059803, 0.21841232461156324, 0.0824444432510063, 0.13034893287112936, 0.11651984954369254, 0.17483492702012882, 0.1471948390826583, 0.17678414820693433, 0.18407677329378203, 0.10427375978906639, 0.1460613717790693, 0.09559790501953103, 0.12540023279143497, 0.11925582148251124, 0.13372387911658734, 0.14708909788168967, 0.13682046061148867, 0.0862254630192183, 0.1448930977494456, 0.12678923638304695, 0.15224712813505903, 0.1473272975999862, 0.20669326360803097, 0.1452772185439244, 0.1846451693563722, 0.12244059980730526, 0.06293606740655378, 0.172212919278536, 0.19377980497665703, 0.16818865318782628, 0.11158752866322175, 0.18050849757855758, 0.1027782580058556, 0.11741643073037267, 0.11193604863365181, 0.1520198379876092, 0.1228591488325037, 0.14331677608424798, 0.1795079340809025, 0.16574980749282986, 0.19256484985817224, 0.17091028683353215, 0.13225086440797895, 0.09284770610975102, 0.13882929109968245, 0.08848046389175579, 0.13694623979972675, 0.11744296993128955, 0.09518480335827917, 0.14979327621404082, 0.1544219473726116, 0.17720859730616212, 0.24068168277153745, 0.13515134080080315, 0.16409322997787967, 0.17891593772219494, 0.17360925528919324, 0.12064524809829891, 0.10559781803749502, 0.13115046720486134, 0.1208626083098352, 0.11358538278727792, 0.13997584988828748, 0.20120050990954041, 0.11537167287315242, 0.1408476656069979, 0.2116371100419201, 0.20549200853565708, 0.10437378645292483, 0.15535911661572754, 0.12285114105907269, 0.18208510125987232, 0.10884770497796126, 0.2434971832553856, 0.11828637623693794, 0.13815751386573538, 0.10148583009140566, 0.12305149124586023, 0.20108887605601922, 0.13799796695820987, 0.2126207377295941, 0.10915885781287216, 0.1430440813419409, 0.19772501749685034, 0.09363023404148407, 0.07001678706728853, 0.11969753293669783, 0.12119880862883292, 0.13460132031468675, 0.12072649100446142, 0.11827073176391423, 0.10392860174761154, 0.1539969936129637, 0.1453453625435941, 0.09754878119565547, 0.1695356660638936, 0.2947450481588021, 0.09180008302791975, 0.14015543478308246, 0.07935704954434186, 0.09867872329778038, 0.17209334444487467, 0.10436568962177262, 0.13179356785258278, 0.1473173825070262, 0.1381527047487907, 0.20102655049413443, 0.13032926595769823, 0.09502745320787653, 0.16963970032520592, 0.17261667730053887, 0.18202319130068645], [0.04303486908611376, 0.016732502335798927, 0.07821741499355994, 0.0034283358854736434, 0.02687492255063262, 0.041431967401877046, 0.05577597134106327, 0.07133093022275716, 0.03603077988373116, 0.006129423636593856, 0.010615808387228753, 0.005733523566959775, 0.011297924665996106, 0.05773455472080968, 0.04042066873807926, 0.004331694735810743, 0.04992672329535708, 0.019298528022773098, 0.028265377040952444, 0.026529129972914234, 0.018773692318063695, 0.03559422635589726, 0.03290696899057366, 0.029130327893653885, 0.019877108206856064, 0.016847106635395903, 0.019636991892184597, 0.0638611099566333, 0.009530695715511683, 0.013282759664434707, 0.05331587053660769, 0.004981070705980528, 0.043741089393734, 0.025021202782227192, 0.03717898624017835, 0.019961685211455915, 0.07657222944544628, 0.074173103494104, 0.018050653088721447, 0.009024827450048178, 0.06808514735894278, 0.03138060499622952, 0.029592081045848317, 0.047472400110564195, 0.04096174263395369, 0.05946536184637807, 0.019902020248991903, 0.0455701383179985, 0.02417129526293138, 0.020926393699483015, 0.029128494788892567, 0.035027418489335105, 0.06773807457648218, 0.0188686816545669, 0.06442736863391474, 0.02944813222711673, 0.025841583956207614, 0.08514578657923266, 0.0393120708031347, 0.06491881140391342, 0.014996833215263905, 0.06443462683819234, 0.008083131106104702, 0.061926535054226406, 0.05949309219431598, 0.027616804909484927, 0.02273623955261428, 0.03775130826397799, 0.014567707657988649, 0.0679914141073823, 0.05768179915321525, 0.029347773452172987, 0.026002483427873813, 0.04657955563743599, 0.06388755267835222, 0.01655617175856605, 0.023786779274814762, 0.009342726407339796, 0.030822569315205328, 0.007737727692074259, 0.050798487063730136, 0.055394581650034525, 0.02045464196271496, 0.019409412307140883, 0.02785278560622828, 0.012712977641058387, 0.03942417592043057, 0.07091089690220542, 0.061002691072644666, 0.05030299587815534, 0.018556272734713275, 0.0382957515103044, 0.05585676524788141, 0.05636647969367914, 0.0826369934657123, 0.029491525601770263, 0.06983127983403392, 0.04105350177269429, 0.03651319071650505, 0.06699964505969547, 0.12415999270160682, 0.058225559623679146, 0.03258621276472695, 0.01812193451769417, 0.046144553198246285, 0.012974780438526068, 0.08659900820930488, 0.08960048347944394, 0.04526474454905838, 0.08530493272701278, 0.06568018070538528, 0.051638086151797324, 0.04064055967319291, 0.013485406798281474, 0.025209190644090995, 0.05682017683284357, 0.02393845014012186, 0.030959734904172365, 0.017726954247336835, 0.028820536899729632, 0.03078268073295476, 0.019815151863440406, 0.04125995983486064, 0.044765052807633765, 0.0642553684883751, 0.03247809669119306, 0.03495900731650181, 0.009691174018371385, 0.024387215707974974, 0.01980658376851352, 0.052457064666668884, 0.01584274519700557, 0.04226811550324783, 0.008354113342647906, 0.07041077100438997, 0.0489057507365942, 0.07411661863443442, 0.057910065224859864, 0.04788839243701659, 0.08546822748030536, 0.04113960574613884, 0.056888231774792075, 0.0840414411504753, 0.042153182803303935, 0.02197902627813164, 0.011033065147785237, 0.024176776023523416, 0.03275497343565803, 0.04672894625400659, 0.013425210272544064, 0.0629837132873945, 0.05432919897430111, 0.05959494083072059, 0.040762780263321474, 0.033367475334671326, 0.026756971165013965, 0.07726043782895431, 0.07609666121425107, 0.03987870797573123, 0.01524143395727151, 0.03323478304082528, 0.07695085092564113, 0.03779843835218344, 0.02369255063968012, 0.06797925030696206, 0.026887130879913457, 0.026002232953032944, 0.03029692652489757, 0.03288689760665875, 0.029751692891295534, 0.06615109567064792, 0.020505211905401666, 0.016951662255451083, 0.010968513142870506, 0.026202225053566508, 0.017188492711284198, 0.07328613311983645, 0.06653039250522852, 0.050086233095498756, 0.04217985559080262, 0.030781138921156526, 0.0038972484435362276, 0.04353224903752562, 0.10210754204308614, 0.07402403571177274, 0.065438032761449, 0.015800511428096797, 0.02553557791543426, 0.035518660879461095, 0.06533937907079235, 0.018239700366393663, 0.04337663180194795, 0.03943023184547201, 0.062471356795867905, 0.05022543031373061, 0.023196079819172155, 0.054834404872963205, 0.01816061896533938, 0.041577179727028124, 0.07391128863673657, 0.020179242092126515, 0.022100647584011313, 0.026437317028467078, 0.05936304194619879, 0.08052363889873959, 0.04784639801073354, 0.05197164442506619, 0.01934204756253166, 0.006688567900710041, 0.05339513190847356, 0.06793884778744541, 0.02633268533827504, 0.01788175512047019, 0.05183910056075547, 0.12030879544909112, 0.05532545430469327, 0.021230490565358195, 0.008725820789550198, 0.030474425984721165, 0.0022690805735692265, 0.027960283841821365, 0.008632199787825812, 0.03250862493587192, 0.07645658799447119, 0.05292404253850691, 0.019965802275692113, 0.03047420148504898, 0.014807148618274368, 0.06665384134976193, 0.01257112910025171, 0.059799562077387236, 0.03842059559246991, 0.020848449639743194, 0.0838827328698244, 0.04137291842198465, 0.028703477946692146, 0.047580775935784914, 0.019241091358708218, 0.007088933380146045, 0.06434946539229713, 0.026590776469674893, 0.05936848931014538, 0.01630029593798099, 0.029463179271260742, 0.07209716059151106, 0.032117442606249824, 0.0297916927956976, 0.05339384428225458, 0.02918694448453607, 0.007525171495217364, 0.08925881353206933, 0.04718136689916719, 0.02236809719761368, 0.07568056869786233, 0.050756808050209656, 0.015077481475600507, 0.04175076064711902, 0.04253109553246759, 0.018891927575168665, 0.052336076041683555, 0.026511849064263515, 0.021247632321319543, 0.015391121432912769, 0.11432214989326894, 0.039242542698048055, 0.04048478287586477, 0.03292340014013462, 0.03983406408224255, 0.026691573111747857, 0.04184120618447196, 0.07420447407639585, 0.049726491852197796, 0.05993073296849616, 0.07901049626525491, 0.0048776120729598915, 0.15755078260554, 0.016977900886558928, 0.10207343293586746, 0.029344159192987718, 0.01759261253027944, 0.06202564516570419, 0.010873364244616823, 0.05868542029929813, 0.030215600127121434, 0.03154078272928018, 0.014372029290825594, 0.03163434157613665, 0.05740503373090178, 0.02132615711161634, 0.06571456440724432, 0.016841611031850334, 0.06949172500753775, 0.04230349739373196, 0.04810867671039887, 0.03948872421460692, 0.029246947124192957, 0.05572459987888578, 0.05261353166133631, 0.029668448041775264, 0.05841170881467406, 0.027455489835119806, 0.02984668593853712, 0.02947258784843143, 0.029038537213637028, 0.03194593598891515, 0.04226565157296136, 0.034227053038193844, 0.06596115039428696, 0.06694444411550649, 0.04631456067727413, 0.009508096391073195, 0.01097981048587826, 0.042599554944899864, 0.03204129825462587, 0.011121761071990477, 0.060377754489309154, 0.03796961100306362, 0.022614146982959937, 0.016976841470750514, 0.023177145776571706, 0.035251276203780435, 0.02761041872872738, 0.008038678315642755, 0.05938265319855418, 0.031160769722191617, 0.005547902228499879, 0.02772176500002388, 0.030958634670241736, 0.079520485305693, 0.06655731762293726, 0.01670236928475788, 0.0657863226660993, 0.026307405933039263, 0.05815543780045118, 0.0042908000796160195, 0.025877667176246177, 0.018687185729504563, 0.06235261316760443, 0.049354549701092765, 0.018524360384617466, 0.008637108167022234, 0.02830382585671032, 0.06700386787997559, 0.05358490649086889, 0.02299282783496892, 0.071365670155501, 0.03899727402313147, 0.027992326067760587, 0.060927890008315444, 0.053316026387619786, 0.03844759121420793, 0.023073473312251735, 0.188902469817549, 0.12241754127899185, 0.16143435233971104, 0.2463258197531104, 0.10016110391006805, 0.06975247859372757, 0.22494362492579967, 0.18937968561658636, 0.18205391621449962, 0.11952129512792453, 0.08881493500666693, 0.0941191015590448, 0.07557547316537239, 0.204257327131927, 0.1312906589009799, 0.08737292722798884, 0.14714049902977422, 0.18470042967237532, 0.1268912074738182, 0.11586240318138152, 0.10897194792050868, 0.06702515267534181, 0.10987825124175288, 0.17522891837870702, 0.07605557591887191, 0.12355418497463688, 0.12764419050654396, 0.14465657528489828, 0.16875443689059466, 0.11471678692032583, 0.20275103452149779, 0.11340895944158547, 0.09334299320471473, 0.2320707807666622, 0.16854685818543658, 0.10072570759803057, 0.1584638172062114, 0.13634688133606687, 0.15208182216156274, 0.12425941080437042, 0.16217676718952134, 0.1157765366951935, 0.13020284852245823, 0.18999584630364552, 0.25055048055946827, 0.1457617964479141, 0.058096411084989086, 0.16146252426551655, 0.15824151429114863, 0.12449346933863126, 0.11574993812246248, 0.04517389454122167, 0.14230462023988366, 0.08682093262905255, 0.19058230624068528, 0.13415885186986998, 0.1137784228194505, 0.2041825038031675, 0.16779169323854148, 0.17694531299639493, 0.14932876598322764, 0.1622904048417695, 0.10878137181862257, 0.17143596487585455, 0.18693389341933653, 0.106038468220504, 0.11619391312706284, 0.09781699336599559, 0.18602866621222347, 0.25202195160090923, 0.1871237941668369, 0.12631357909413055, 0.10954983605188318, 0.11205959395738319, 0.18696631042985246, 0.2623368543572724, 0.12307008204516023, 0.14602674316847697, 0.17659932374954224, 0.06562823778949678, 0.1190724664775189, 0.1499660185072571, 0.1516344110132195, 0.13715144363231957, 0.12310088117374107, 0.09540516926790588, 0.08605753726442344, 0.1953114938805811, 0.14863306190818548, 0.09659737013862468, 0.10836414381628856, 0.19731561915250495, 0.16249241743935272, 0.10400018931250088, 0.20996159291826189, 0.13105596211971715, 0.23788773425621912, 0.15233713580528274, 0.09617381161660887, 0.22280165314441547, 0.16815595416119322, 0.1932416736963205, 0.14563811011612415, 0.13070226937998086, 0.14099925669142976, 0.16739872604375705, 0.14715051802340895, 0.13562068983446807, 0.16332671017153189, 0.20318974769907072, 0.2213833198766224, 0.1565238877083175, 0.11211475037271157, 0.1700344486744143, 0.1336314668878913, 0.1378105449839495, 0.14711287629324943, 0.1325257113785483, 0.13117227150360122, 0.13710087368963286, 0.19164405239280313, 0.14667288662167266, 0.26161254791077226, 0.09187095070956275, 0.12485689163440838, 0.06497931870399043, 0.09476411694777198, 0.1713931281119585, 0.09336105707916431, 0.13960726966615766, 0.20963684393791482, 0.15971972403349355, 0.1481581319239922, 0.13090858643408865, 0.17232057522051036, 0.09476311504840851, 0.20401118643349037, 0.11431080987676978, 0.08849308782373555, 0.13420580013189465, 0.11276653414824978, 0.1161791814956814, 0.14498110162094235, 0.12170880509074777, 0.1150115902419202, 0.1294003493967466, 0.12864408607129008, 0.1140063141065184, 0.11988036101683974, 0.16153431963175535, 0.14633476414019242, 0.11762558278860524, 0.17936919699423015, 0.13074860908091068, 0.08817929294309579, 0.1466441951924935, 0.14899977191817015, 0.123057472956134, 0.1375803753035143, 0.08290337995276786, 0.09668838712968864, 0.16282736352877691, 0.1450848241802305, 0.1346620576805435, 0.17121198470704257, 0.0756591948447749, 0.0710084373713471, 0.12478370103053749, 0.2536007668823004, 0.12519379699369892, 0.11750472403946333, 0.17255978425964713, 0.12965909176273271, 0.17056446085916832, 0.08834774562274106, 0.14108905656030402], [0.04260880210495088, 0.065498317417223, 0.08892811252735555, 0.03365241180290468, 0.03969890785811003, 0.02027332600846421, 0.06636714970227331, 0.045901759585831314, 0.02924794716818724, 0.071313393273158, 0.028071795240975916, 0.036041693165316246, 0.021637430545524694, 0.018018475420831237, 0.07785597423207946, 0.040190588115365244, 0.016148797622008715, 0.01894956276373705, 0.020924582859151997, 0.05045954079832882, 0.04289796139346436, 0.020127866919210646, 0.009157170006801607, 0.05505709370481782, 0.027821739713544957, 0.07490054922527634, 0.01442402694010525, 0.01996730141399894, 0.021273913625918794, 0.05738333704357501, 0.0938149397552479, 0.027928148847422563, 0.046763085047132336, 0.02895515877753496, 0.014689491308672586, 0.009252056370314676, 0.023002323614491615, 0.021956413038424216, 0.0723718962399289, 0.00596193945966661, 0.07058101225993596, 0.06257367669604719, 0.014290384697233094, 0.03529579393216409, 0.011416585730330553, 0.060203357206773944, 0.0657577277161181, 0.0531450541166123, 0.07334341207752004, 0.027306249503453728, 0.05865566759894136, 0.016945673123700544, 0.045686726007261313, 0.03592456370824948, 0.04641525898477994, 0.03707762371050194, 0.058537710647215135, 0.0506331254291581, 0.06933416705578566, 0.023619944477104582, 0.02049519662250532, 0.007410299558614497, 0.004928531752739218, 0.07486799120670184, 0.01098355091016856, 0.033026907476596534, 0.05712351485271938, 0.04834650535485707, 0.07287748434464447, 0.012763490067300154, 0.017831693548941985, 0.013905177584092598, 0.08154528681188822, 0.009247967136616353, 0.0289468726987252, 0.07624585516168736, 0.030143886397127062, 0.04695624753367156, 0.043831616567331366, 0.01953192233486334, 0.010638634994393215, 0.03943942334444728, 0.00918217388971243, 0.03279789554653689, 0.04628906048310455, 0.045478512765839696, 0.01575112335558515, 0.0240834268333856, 0.01367290484267869, 0.09033001464558765, 0.08633107063360512, 0.02976853593281703, 0.04401793274155352, 0.0846272925264202, 0.08099793063593097, 0.0673254627326969, 0.0064364167337771505, 0.018999615058419295, 0.06356036203214899, 0.06395234959200025, 0.021978352779115085, 0.08583336413721554, 0.03580517070076894, 0.022362275049090385, 0.010003609841078287, 0.04796758330485318, 0.05429513068520464, 0.043642183372867294, 0.047617167147109285, 0.056593053668620996, 0.046010628939257, 0.05078651993244421, 0.06886115923407488, 0.020810308815271128, 0.04453659748833161, 0.03446426198934205, 0.05218031037657056, 0.02231197227956727, 0.06110850277764257, 0.09361913151224144, 0.03170087140460964, 0.03110271893092431, 0.0526970158534823, 0.05307116960466374, 0.009143962561211083, 0.08958738457295112, 0.03628677259257529, 0.012224057245475706, 0.013095198537484976, 0.01984022161195753, 0.0632301731093321, 0.027545723860384896, 0.029418635567708407, 0.047048693159013055, 0.03404771305213217, 0.09411302336957306, 0.03217157114704605, 0.05626971476885956, 0.04880005035374779, 0.016221518817474134, 0.0166947734032874, 0.08120582104311325, 0.034577684418763965, 0.03357389628945384, 0.04216602195810992, 0.0863379577640444, 0.04438423828105442, 0.021991021239955444, 0.03022518867510371, 0.015101449134817813, 0.05614819921902381, 0.034251094912178814, 0.0033361349369442905, 0.013252637745608808, 0.03144799942674581, 0.013115843230480095, 0.02459641415043734, 0.020079011337656993, 0.045168688375269994, 0.10955761375953443, 0.05222823085205164, 0.10938625928247347, 0.041857039905153215, 0.030975908157415688, 0.025987709123000968, 0.021156826842343435, 0.06508953505544923, 0.04981975755072199, 0.009829963983065682, 0.1086998320533894, 0.013108425464452012, 0.07376038032816723, 0.035790164474747144, 0.03138988926366437, 0.024598887357569765, 0.018344474920013454, 0.004433202448126394, 0.017018715298036113, 0.06905295245815068, 0.0608086973807076, 0.03613927445258014, 0.02418457414023578, 0.03369754922459833, 0.024848230423231144, 0.02847677966201445, 0.038216794418985955, 0.03850588320347015, 0.056672222272027284, 0.013681159380212193, 0.05192510063352529, 0.017081612313631922, 0.008503787830704823, 0.022083377807575744, 0.0737749041581992, 0.04952698029228486, 0.029820265481248498, 0.03255342096963432, 0.05789669172372669, 0.055108698943513446, 0.007329944910452468, 0.026297581753169652, 0.0661355625197757, 0.03425903960305732, 0.014487480566458544, 0.02221531125542242, 0.0681772775715217, 0.030244131994550116, 0.00834872349514626, 0.04436381066625472, 0.03631878142186906, 0.024401639348070603, 0.05685743264621124, 0.022751060241716914, 0.052681267479783855, 0.022797745041316375, 0.010559580496192211, 0.03954998479457572, 0.04368810376035981, 0.00977739209702122, 0.044138932498754, 0.05325083613570314, 0.07803359985700808, 0.0948786897060927, 0.05101835944515187, 0.10288200282957405, 0.03711663470312487, 0.0260906153198448, 0.05261789548967499, 0.008536235454812413, 0.03241373393393587, 0.02776631426968379, 0.04347515932749957, 0.03898323258908931, 0.06683978645014577, 0.04164551668509375, 0.07030220964225009, 0.01586507642059587, 0.03636886154708918, 0.027522585551196244, 0.045224713103380054, 0.006697250100842211, 0.04638423721189611, 0.0304499184130691, 0.07785799287375994, 0.05190576397581026, 0.0523814361076802, 0.02379632329393644, 0.049927498839679174, 0.05915536305110436, 0.030705146709806286, 0.015422640444739955, 0.030674423651362304, 0.04354792690719478, 0.06434896073187701, 0.022545355459442362, 0.01949289649928687, 0.016584035693085752, 0.03602926961320918, 0.021808618039358407, 0.05473773642734159, 0.05490435600222554, 0.04238530062139034, 0.023353851138381287, 0.0142550167220179, 0.07642224139999598, 0.029406332614598796, 0.018474951903044712, 0.06207482729223557, 0.050578577574924566, 0.08954738281317987, 0.04387974113342352, 0.03952020240831189, 0.01110451727072359, 0.018139048443117645, 0.012349455155344913, 0.036164859993732534, 0.041199823608621955, 0.0014852289518785255, 0.030338102733367123, 0.035533351692720316, 0.04786653989867773, 0.02900808318372583, 0.06108090230554808, 0.04063074848090764, 0.0489634044788545, 0.019321525323903188, 0.015044073697936255, 0.0679517759999726, 0.023874849939602427, 0.045241582120070234, 0.07943700111354701, 0.04839351669943426, 0.09120144444750622, 0.013989214676257689, 0.09076365153305233, 0.05594635360466782, 0.03856701390759554, 0.013970095096738078, 0.05124725263158325, 0.026850186768569984, 0.04857069703575689, 0.021388903842307627, 0.02440874912281288, 0.010495168571651448, 0.014765951073059114, 0.005361985886338516, 0.06675711862044409, 0.028327346371952444, 0.04127504398638848, 0.029841880532330833, 0.06028128271282185, 0.03472423260973301, 0.0389551274565747, 0.017838961030065548, 0.02360513677558629, 0.056259866469190456, 0.019111512374365702, 0.03800504113314673, 0.03264017803303432, 0.08886143798008561, 0.02266644427436404, 0.03945754659071099, 0.04628234775736928, 0.03164609348459635, 0.0640745293640066, 0.025910034091793932, 0.05188477232877631, 0.012326427240623161, 0.05297238603816368, 0.009906087925628526, 0.02733846427872777, 0.03147521027131006, 0.030000514598214068, 0.00773494324675994, 0.035315943241585046, 0.06462361474405043, 0.05009219254134223, 0.06338793144095689, 0.013240855223557446, 0.018535340459493455, 0.057772964573814534, 0.05005683662602678, 0.04798146888788324, 0.032170795602723956, 0.08498707829858176, 0.02281611134094419, 0.010502477798581822, 0.01620760725927539, 0.02500881633750396, 0.02463495944539318, 0.13396500289672986, 0.009642734039516654, 0.1275609215372242, 0.11564703934709541, 0.20057713554706424, 0.11515952995978296, 0.13494766579242423, 0.08913663376006298, 0.12551249004900455, 0.12589431018568575, 0.10604571158182807, 0.1538184774108231, 0.18583837954793125, 0.10759547920315526, 0.12186562089482322, 0.12148509951657616, 0.20611235493561253, 0.14635964093031362, 0.0892733596265316, 0.1860812696395442, 0.1109857953269966, 0.14253677887609228, 0.17824356677010655, 0.1282415006426163, 0.16405906149884686, 0.08420649479376152, 0.16758723155362532, 0.18617516616359353, 0.13511407014448196, 0.11444587333244272, 0.12985182751435786, 0.17265970702283084, 0.15891502815065905, 0.11341373887262307, 0.2614499581977725, 0.1699407451087609, 0.11081507909693755, 0.0793643671204336, 0.1006648589100223, 0.22547844622749835, 0.1471081710769795, 0.12815349677111953, 0.146095258241985, 0.11403159165638499, 0.10316568877897225, 0.15761695249238983, 0.1707945266389288, 0.116793167690048, 0.16994427773170173, 0.07523655658587813, 0.11448019024101086, 0.157293435477186, 0.12712850177194923, 0.2623658278025687, 0.12654037942411378, 0.09723497147206217, 0.1918880408629775, 0.11684564495226368, 0.16278794064419344, 0.18550239445175976, 0.12361781671643257, 0.16859877883689478, 0.20922695577610284, 0.13373838068218902, 0.09666715428465977, 0.17093715257942677, 0.08904627728043124, 0.11968038932536729, 0.12810586573323235, 0.11775967403082177, 0.13674695830559358, 0.13666600483702496, 0.08753207337576896, 0.1101252379885409, 0.1707540944335051, 0.12209720807732083, 0.13916269352193922, 0.22360575530910864, 0.1519296076730825, 0.20173308992525563, 0.13860756705980748, 0.11430773738538846, 0.06294839447946288, 0.11539162922417745, 0.08432263348367997, 0.07996460131835192, 0.11211174467462115, 0.1299154740991071, 0.08852435450535268, 0.11431310311309062, 0.10903834787313826, 0.2804554399335757, 0.10559849339188077, 0.08984807136585005, 0.07977006214787252, 0.2483575974474661, 0.13846296700648963, 0.1236302699544467, 0.08829968413920142, 0.10042265901574865, 0.15120503405341879, 0.14329878642456606, 0.09174008780973963, 0.13737312314333394, 0.11755664469092153, 0.10222587006865069, 0.09335797716630623, 0.1787319889990613, 0.10394087687018327, 0.13765632669674233, 0.11563241903786547, 0.1717913497122936, 0.14649693825049326, 0.18215710442746058, 0.17195518623339012, 0.19997385854367167, 0.19353405019501224, 0.09094523280509748, 0.20716662023914978, 0.2412366311182268, 0.1911208382807672, 0.19658536068163812, 0.10092283686390147, 0.07826844506780617, 0.11148668563691899, 0.11660510004730895, 0.13412968546617776, 0.16952745791058987, 0.13246141170384362, 0.0731837835337501, 0.10637489118380472, 0.0631433937815018, 0.213170075439848, 0.10545177079620771, 0.09912510286085308, 0.20148454466834664, 0.15433354274136946, 0.14999812381574884, 0.20573770394548774, 0.12669519142946228, 0.21638078440446407, 0.1587715561618097, 0.13099057890940458, 0.21530783182242885, 0.18813255097484216, 0.160210951580666, 0.1890110014937818, 0.1911758165806532, 0.25433763046748936, 0.12348339150776155, 0.14206404564902186, 0.08805571793345734, 0.18664871575310826, 0.10451431211549789, 0.11177666499861516, 0.08270616905065253, 0.1705552136991173, 0.07644201221410185, 0.19471416890155524, 0.07011138121015392, 0.1255185905029066, 0.20129896322032437, 0.12241599019034766, 0.2125489423633553, 0.1426598269608803, 0.18117985920980573, 0.11472840153146535, 0.11880162710440345, 0.0913434024550952, 0.15530355944065377, 0.14148282527457923, 0.19876935286447406, 0.08492710534483194, 0.17975422320887446, 0.10216175593086518, 0.09573316885507666, 0.19449229643214494, 0.10595360363367945], [0.053120730226510204, 0.020730296018882655, 0.038442084478447214, 0.009992836639867164, 0.012364863068796694, 0.03289380700152833, 0.02946712564153131, 0.11423959338571876, 0.029668206843780354, 0.06490264742751606, 0.0545601033809362, 0.07298004915355705, 0.026891773013630882, 0.032586446541245095, 0.054935014122747816, 0.016027786732593086, 0.030042247417441104, 0.05776047793915495, 0.07819353268132545, 0.02791307953884825, 0.05884992846404202, 0.015398182040371466, 0.03303986908576917, 0.044637429382419214, 0.036205277356202714, 0.040133409347618, 0.07669664308195934, 0.036353888717712834, 0.0617805991350906, 0.01970650515431771, 0.03250425368605647, 0.03189267205016222, 0.012144594566052547, 0.033033620202331804, 0.015215708335745148, 0.04684721490775701, 0.03902113407093566, 0.10606172712869011, 0.03521447681123391, 0.03227857028832659, 0.023143248181440867, 0.0355531410605181, 0.024287070300488267, 0.03224529238650575, 0.028648508923652116, 0.07656188390683383, 0.018582388911454473, 0.034811776349670254, 0.03467637150606606, 0.061834234147681855, 0.02463540844473755, 0.016709237861505244, 0.04300635577237699, 0.04433019879797939, 0.055628228292334825, 0.030784591763222124, 0.0331088480015751, 0.01907393743749708, 0.05652574087434914, 0.05711522506317124, 0.018559256168373395, 0.06241301656700671, 0.01760884144459851, 0.008070020139712142, 0.04796638844709378, 0.05863101716386154, 0.005887371244170936, 0.036030835544806905, 0.08517608846887015, 0.07223779015475884, 0.01111478210077621, 0.04804867407074198, 0.032581856357865036, 0.0068842360633425415, 0.004365057520772098, 0.06852256919955835, 0.061570040707010776, 0.024925667967181653, 0.0582924531045137, 0.06607282135519199, 0.00387620043966308, 0.019006967886525672, 0.04379754085675813, 0.055514434789074585, 0.0612815901695285, 0.021308241666702088, 0.0310852153779706, 0.031131684954743832, 0.02621932784677483, 0.015556739108433248, 0.02125325037923176, 0.012564864446176216, 0.04265177616616711, 0.012470613546611276, 0.0065827153775899205, 0.03558697186235804, 0.031971413918654434, 0.042200591196888126, 0.0737973021750804, 0.07976681154104881, 0.07542682840721682, 0.06625640642596409, 0.045834465345251374, 0.022408956137951463, 0.04556574480375275, 0.034924148640129715, 0.04394810777739622, 0.050746076594805345, 0.050641107227420434, 0.036902569627272896, 0.022772018492105417, 0.048425944842165336, 0.08342671280843206, 0.06809573038481176, 0.027809603743662592, 0.03912192514690105, 0.05087874291348271, 0.027623955502349418, 0.08068484079558402, 0.03933496605895925, 0.01921413655509241, 0.0414522948267404, 0.03803131687163841, 0.02154185676772613, 0.06783576347515918, 0.01750806150084827, 0.08953664393629879, 0.017100230943469796, 0.02397835356532596, 0.004592505374603206, 0.02954895669972757, 0.01682499991147779, 0.02942986240668688, 0.06273130144109018, 0.06357775055221282, 0.028966029385628644, 0.029122719024599064, 0.012011934741167352, 0.03029389670700766, 0.02716931212489726, 0.06276584841543809, 0.003437256268625788, 0.03744445617485326, 0.07252397714182734, 0.026375128763902467, 0.0068816311249975115, 0.059563881950452924, 0.05863791171577759, 0.015520996348641347, 0.0313386254129, 0.0595554771280149, 0.05203089378483128, 0.0876213017909322, 0.08623822053777985, 0.028575270080182236, 0.05080629816802684, 0.055373352515744045, 0.03663732233690098, 0.010542117761360714, 0.07415847576339729, 0.027221590862609446, 0.010662178701750236, 0.03288897562015336, 0.04018335588625632, 0.021938931749900803, 0.036623959967982955, 0.015074537004693411, 0.017304918983427342, 0.05939486152783502, 0.005073886941318051, 0.04737216564535629, 0.06487638282123953, 0.05154031932761427, 0.04181089316261932, 0.017010939445754047, 0.03840741504973266, 0.08634888959932141, 0.023970529473444913, 0.05018317613576073, 0.09200222179060802, 0.027601188266999088, 0.04848861550271977, 0.03334250948682893, 0.027971544077445287, 0.04122932397876866, 0.01278297144381213, 0.060717472588294186, 0.11148339792271145, 0.05080805334728211, 0.08898281623260118, 0.07870824920246378, 0.02736177142651286, 0.04174515743216034, 0.052556237860699184, 0.080960875202436, 0.06290627759881318, 0.05727268653572537, 0.02561565564974444, 0.026660436305974144, 0.040708098822506145, 0.03250090288929641, 0.08263156094471924, 0.07876525356550701, 0.03220044440240599, 0.033012713902280666, 0.02767975202004891, 0.023435450275428593, 0.057677361110108905, 0.014496459625661373, 0.04425301172886975, 0.07179529944551177, 0.03572499277652241, 0.030532333912560716, 0.06788651895476505, 0.009001257767522475, 0.027844197102240287, 0.05401558220910374, 0.022147209929244127, 0.06611007716855966, 0.05356994108296931, 0.030049934212001972, 0.05170325042854529, 0.03658764297142625, 0.023257850625668652, 0.02868402996682562, 0.046463301914627664, 0.04244009338435717, 0.04611962074704934, 0.020878755240119062, 0.057969017725554295, 0.009343789533886593, 0.032452444356749766, 0.06486725440481678, 0.0335661816643551, 0.02918781465268694, 0.06759389754734002, 0.07008443382801488, 0.042022980414913036, 0.06545366981299594, 0.03950368220102973, 0.026525127941567916, 0.0035658999149745796, 0.04921122614177875, 0.03157970466418192, 0.04821400230866857, 0.034839194995583966, 0.03688242031785194, 0.02844952243322041, 0.00369954563666397, 0.04399156052386388, 0.0375996132788714, 0.02311546959390398, 0.020712402838398702, 0.03062509680603398, 0.018467866248101927, 0.025272263919760007, 0.028011180329485796, 0.03977753840445075, 0.06278616841882467, 0.05729443146265112, 0.018256539697176777, 0.021299714389897417, 0.005870967461305554, 0.07954119864734821, 0.06761856653611176, 0.009171670644718688, 0.032702603784855455, 0.0030326693604365573, 0.049839572893688455, 0.07213520308141597, 0.03575745431589894, 0.04193624190520495, 0.06812437728513032, 0.020675028281402774, 0.020125985574850347, 0.08976227909442969, 0.02911304141889559, 0.032449768914375454, 0.04136957504670136, 0.04909674244117923, 0.05836209253175184, 0.003184425572726468, 0.021428987238323316, 0.0606865955342073, 0.035187792891520076, 0.09048593245097436, 0.033477765900897793, 0.007656048774151714, 0.06156330571684521, 0.029479628974513616, 0.011194389498996316, 0.12191629473818466, 0.06185843187267892, 0.0901025092753116, 0.06347181639284827, 0.033096613697125576, 0.048186583662754856, 0.0708297207893338, 0.005619112225758727, 0.051548482952057384, 0.06243912532227114, 0.04702825812273659, 0.019593748802435584, 0.009884060982585652, 0.027896763422177173, 0.08195334929041564, 0.057755639136303216, 0.017532541241962463, 0.04291546865715645, 0.011332417834637454, 0.05158798005140852, 0.09106606928980909, 0.029615818639285862, 0.06303265792666934, 0.03289608168415725, 0.022420251625590026, 0.05651575527735986, 0.05477158949361183, 0.03216069868358318, 0.05154403377673589, 0.048654574566171505, 0.01030370931403013, 0.04062870757479686, 0.07032612164039165, 0.026832213807210792, 0.007222968961286824, 0.05149254728166852, 0.05071388222859241, 0.03476464997220319, 0.09310849680332467, 0.00860529229612439, 0.0158149406343, 0.0190892479440663, 0.02304393954545958, 0.05870261957170442, 0.10525294943363406, 0.03398568063857965, 0.04486666395678185, 0.07082619558786973, 0.007476593755200156, 0.03178868231771048, 0.04245942262059543, 0.04957764671416953, 0.03586087259463966, 0.05162000372365583, 0.011720312450052006, 0.015090840133780148, 0.06279166773310862, 0.04061231353261974, 0.004381176504466566, 0.07319607349927537, 0.048572340892860666, 0.12354478196357377, 0.1287492929259315, 0.19064541847910732, 0.18483619816834107, 0.0947090941190254, 0.11706837089150213, 0.18302967713680118, 0.16752397088566795, 0.2000621592742391, 0.18601751915412024, 0.13444499432807788, 0.24243386375019327, 0.14052214479306713, 0.16552860295632854, 0.14709353592479602, 0.08750605367822573, 0.12332506914390251, 0.17004020774038509, 0.19575008831452578, 0.18623091629706323, 0.1405620574951172, 0.08412136303377338, 0.09523312459350564, 0.09170703255222179, 0.2099124330561608, 0.15033743373351172, 0.25244672724511474, 0.09602380130672827, 0.09376387999509461, 0.08131346956361085, 0.1196527665888425, 0.11747661890694872, 0.09869904330116697, 0.11607842010562308, 0.16494610608788207, 0.15009961993200704, 0.12824602774344385, 0.24734550097491592, 0.12061015193467028, 0.09406623838003725, 0.14264467230532318, 0.1609137505874969, 0.2785816654795781, 0.15688345825765282, 0.1403357766685076, 0.19313195458380505, 0.0780803403176833, 0.16461956111015752, 0.15915198106085882, 0.11331538946251385, 0.12212741348776035, 0.14098040614044294, 0.12002794450381771, 0.12646248360397294, 0.12615477433428168, 0.0769842772569973, 0.104930456582224, 0.10985667700879276, 0.2367757447063923, 0.18109050462953746, 0.14990105089964345, 0.1357653789455071, 0.18663688591914251, 0.12365179223706946, 0.10319288106984459, 0.09749864912009798, 0.07059126874082722, 0.15081752906553447, 0.16110338416183367, 0.12681913009146228, 0.09956004592822865, 0.13428666454274207, 0.09917188042891212, 0.13478706503519788, 0.1305658626370132, 0.11432684026658535, 0.10352736702770926, 0.10759499680716544, 0.09838210171437822, 0.24888030689908192, 0.10170694557018578, 0.19980999233666807, 0.12107969392673112, 0.19099783472483978, 0.08879996588802896, 0.12349081298452802, 0.12711020041024312, 0.17801569774746895, 0.11738730885554105, 0.12141726721893065, 0.17830376978963614, 0.1204173790756613, 0.15176635002717376, 0.18362198519753292, 0.16162910673301667, 0.19598428043536842, 0.10515186892007478, 0.1738849186222069, 0.16658840468153358, 0.2046628069365397, 0.09495373567915522, 0.0922038707358297, 0.18447947746608406, 0.16306140722008422, 0.14947893214412034, 0.16991401294944808, 0.14272635307861492, 0.13232660799985752, 0.24027517880313098, 0.19294499274110422, 0.21193049586145207, 0.21906306938035414, 0.2124790765810758, 0.16860547300893813, 0.10117620608070865, 0.1779305437230505, 0.22499431361211464, 0.1230404555099085, 0.17049395682988688, 0.14812264242209494, 0.13198361702961847, 0.14936251885956153, 0.11126042707473971, 0.20514906209427863, 0.16970496479189023, 0.11264986111200415, 0.1989673578646034, 0.11027273983927444, 0.13315834774402902, 0.12315818981733173, 0.15839506464544684, 0.09344473422970623, 0.151625623984728, 0.1538581377826631, 0.11913362686755136, 0.23257763794390485, 0.1457513024797663, 0.14682553155580536, 0.10400146580650471, 0.09254608987248503, 0.1407013289281167, 0.10461753743584268, 0.11544036606210284, 0.22362910327501595, 0.12006999459117651, 0.08768137864535674, 0.10446126339957118, 0.19720723590580747, 0.10532512329518795, 0.15795691550010815, 0.12806944112526253, 0.13796452578390017, 0.17263184679904953, 0.18243352475110441, 0.13509973185136914, 0.12765806866809726, 0.11597892036661506, 0.12640492263017222, 0.09384560529724695, 0.11866261542309076, 0.10168207620154135, 0.12872432707808912, 0.248148207901977, 0.13413309934549034, 0.12044752511428669, 0.1545578642981127, 0.20339861774118617, 0.10660625572199933, 0.19714195659616962, 0.10651841512299143, 0.15557508158963174, 0.18462658597854897, 0.09628350104321726, 0.13136340421624482, 0.14895335800247267, 0.10383688713773154], [0.020117847925575916, 0.0375810002151411, 0.0281185857966193, 0.08177218362106942, 0.029685665867873468, 0.009645556056057103, 0.0540424813516438, 0.026732699225249235, 0.02343241860216949, 0.012780600281985244, 0.021577255356532987, 0.051662873884197325, 0.03866996834403835, 0.0201919272512896, 0.015263602836057544, 0.047952131790225394, 0.037266199724399485, 0.03401846130145714, 0.01790025686204899, 0.04394475698063616, 0.03471308926236816, 0.05510257622518111, 0.026177058825851418, 0.0336294349108357, 0.04528014782408718, 0.030103183307801373, 0.034086360392393544, 0.09559265803545713, 0.03173916622472461, 0.012124049135309178, 0.01457301679693046, 0.028556369434227236, 0.05637050584482495, 0.018631244493008126, 0.032802649002405815, 0.03156926635710988, 0.036942204023944214, 0.019299071645946242, 0.05497723490407225, 0.008218390303227352, 0.03909944178303704, 0.04571803721773904, 0.059699238554458134, 0.02181492072850233, 0.04071850002219435, 0.015139846000238322, 0.03956044907681644, 0.02008738461881876, 0.09056791750481352, 0.008408092526224209, 0.08033353034988977, 0.02345039898500545, 0.08425281223026104, 0.037752911302959546, 0.015093292931851465, 0.04422914425958879, 0.050822770135710016, 0.05486386813572608, 0.029411050818453077, 0.018847983155865222, 0.006619189616685617, 0.02605619822134031, 0.03839623459498398, 0.011784933103626827, 0.026675984299799893, 0.06849784826044925, 0.03476460915408097, 0.01830381264880998, 0.018372431622992735, 0.08152246577083133, 0.04655198114051018, 0.05340723633707967, 0.022698390021105297, 0.040459431111230515, 0.03335897774377372, 0.023233148240251467, 0.017612058654776774, 0.012299434401938925, 0.09650691717979498, 0.03348519479914103, 0.034156901529058814, 0.04643008709535934, 0.027686117791745346, 0.06466602106229402, 0.03584503516322002, 0.041531244496582076, 0.04937885874824133, 0.03925553770386614, 0.051010834067710675, 0.07856482174247503, 0.008185012211470166, 0.06785075485822745, 0.04541351547231898, 0.061419065605150536, 0.08628607421997003, 0.059792114625452086, 0.06222392476047389, 0.03507853391056415, 0.01715362104732776, 0.040809097699820995, 0.022132116500870325, 0.05188680581341032, 0.006437349984480534, 0.0397124594746856, 0.08627244096715003, 0.05883610967430286, 0.0261380663869204, 0.027752604946726933, 0.024567754262534436, 0.05041835531301331, 0.05476069847645704, 0.05991012352751568, 0.060978753099334426, 0.034789389465004206, 0.05450945180200506, 0.0030439249576375005, 0.08495521789882332, 0.022039609648345504, 0.1088177741621621, 0.03004198952112347, 0.01904206033941591, 0.008343249228346394, 0.03202922722266521, 0.05013932634028606, 0.019000392458110582, 0.015589904760417994, 0.029528137602028437, 0.04150712469709106, 0.06289620665484108, 0.016404003654315602, 0.042684853688115254, 0.04591170436469838, 0.050674077137955464, 0.025764079618966207, 0.039242887796717696, 0.088470415212214, 0.06451209221268073, 0.04638602207705844, 0.08397258468903601, 0.03029149585927371, 0.013737872450292343, 0.04605289053870365, 0.03984887734986842, 0.06673869109363295, 0.03210618793673348, 0.029702315950999036, 0.07548653418780304, 0.021535598607442807, 0.04026999420602806, 0.036328162168501876, 0.04985002233297564, 0.02794065403577406, 0.007580699912068667, 0.035493791510816664, 0.0304988296556985, 0.024872997746570036, 0.007958536571095465, 0.023666471570322756, 0.049096597722382285, 0.057352448857272975, 0.0738274036848452, 0.050495906034484506, 0.029703495965804905, 0.021328031034499872, 0.15893137024249882, 0.027120347076561302, 0.03228803638194222, 0.02423551144602243, 0.017186351615237072, 0.05534183721465524, 0.04861607194470707, 0.021849035401828587, 0.0669945687695872, 0.031796489711268805, 0.022609061416005716, 0.0022358887144946493, 0.01749866220052354, 0.03123713300738018, 0.052445153196458705, 0.08078685641521588, 0.04582275425491389, 0.04706789623014629, 0.08926762282499112, 0.07504108973080292, 0.025426875545235816, 0.006137603495517396, 0.03884547884808853, 0.02485134744347306, 0.038324331617332064, 0.02196180103055667, 0.02341808401979506, 0.07158308231737465, 0.020120643966947682, 0.03180544743372593, 0.029565565964730922, 0.05619204159302171, 0.04935619355819654, 0.028857260222139303, 0.01748537404637318, 0.04665055690566078, 0.07693922147154808, 0.06633453973336145, 0.02877503397030523, 0.06658897764282301, 0.007836189815861871, 0.026875896619458217, 0.04779580209287815, 0.01992555189644918, 0.04186329621006735, 0.03025764279300347, 0.027253057924099267, 0.07107672980055213, 0.022320343705359846, 0.025751565153768752, 0.07023358324659057, 0.0548016279208241, 0.004865984474236029, 0.043517387530300766, 0.05822611252369825, 0.034271110635017976, 0.051130412612110376, 0.048103418594109826, 0.07347236023633741, 0.0044178195821587, 0.041398054963792674, 0.01650597660045605, 0.03307376668090001, 0.0696213410992641, 0.04530797465122305, 0.02204538912337739, 0.02786643926810939, 0.03240103578718845, 0.03346664481796324, 0.019575916849134956, 0.056797481956891716, 0.014374712154676672, 0.03552854628651403, 0.05133943850523792, 0.03468925518973265, 0.019795197367784567, 0.04205208744679112, 0.06475852234871127, 0.05341327741916757, 0.04447897714271676, 0.01835646246036049, 0.026096905021404382, 0.05955031178018544, 0.02652523369761184, 0.08687563633429818, 0.05466508759127464, 0.012972999284102116, 0.029391949792625383, 0.09542136293021031, 0.047857997778919525, 0.0723545670916792, 0.039732512304908596, 0.032109182502608746, 0.029311311736819334, 0.040738222596701235, 0.023199074385047425, 0.03975008265115321, 0.03485300265310798, 0.04465027595870197, 0.05733052210416645, 0.04357878911832813, 0.18614690518006682, 0.04434137554198969, 0.03617023685364984, 0.02162806278647622, 0.08349545052624308, 0.033517912379466, 0.033736281911842525, 0.00881227450008737, 0.06507756421342492, 0.05168963944015559, 0.01275890081160469, 0.024086024350253865, 0.0940852373605594, 0.02660147823917214, 0.008728275442990707, 0.0843982954393141, 0.020644500036723912, 0.061148868189775385, 0.026986665870936122, 0.03818821060121991, 0.027503458550199866, 0.0782276714744512, 0.052541469121933915, 0.0024090384931696462, 0.06910186741151847, 0.010169734960072674, 0.0339485101721948, 0.0805519444111269, 0.053170283426879905, 0.05240282480372116, 0.061056018093950115, 0.046753811911912635, 0.05575712079007644, 0.023248280631378293, 0.075325733050704, 0.03224174492061138, 0.02747375223407289, 0.03173083190631587, 0.04657921053876635, 0.02060386374068912, 0.053743291937280446, 0.08552546190912835, 0.02544867242249893, 0.011653777983156033, 0.01985442631848855, 0.02365361200645566, 0.036617844671127386, 0.011552854248293443, 0.08186800972907804, 0.05828271241625771, 0.02929206228145631, 0.01602135231223656, 0.02682908008864615, 0.013770030636806041, 0.06755333917681128, 0.024413001629000064, 0.05152221092430409, 0.013358311225601938, 0.04794261003553402, 0.037556279276032, 0.027474329253891483, 0.012418819060258102, 0.04834541068703402, 0.033464329317212105, 0.06653144635492936, 0.0633989523339551, 0.04366079272585921, 0.019411366010899656, 0.017907446417666506, 0.010478641870577121, 0.037060840040794574, 0.012639873311854899, 0.10517350252484903, 0.024615158945380244, 0.04080348335264716, 0.04596813356329221, 0.05057553105871193, 0.06625158988754265, 0.08454024602542631, 0.01980989931325894, 0.05485950801812578, 0.04666014916438144, 0.03543551436450798, 0.032216801337199286, 0.00766220674449869, 0.020170360439806245, 0.01908977301354753, 0.15299689024686813, 0.11492938996525481, 0.126182189269457, 0.2643842319957912, 0.13056463067186996, 0.18695945298532024, 0.18312876869458705, 0.15637204429367557, 0.10731815345934592, 0.10863147283089347, 0.10020333211286925, 0.07454678227077238, 0.2524009218905121, 0.08553306892281398, 0.13752035039942712, 0.1337069136206992, 0.11588267123443075, 0.13513027864973992, 0.13147220306564122, 0.12744615582050756, 0.17128504172433168, 0.1682715956121683, 0.19543264206731692, 0.1547707716235891, 0.1371359475888312, 0.17129642626969144, 0.08577143933507614, 0.24537104676710442, 0.09430819336557761, 0.08944197557866573, 0.12265700264833868, 0.12661928456509486, 0.1472899824148044, 0.13885038293665275, 0.1235818448185455, 0.14797789393924177, 0.1155730769096408, 0.06418879042030312, 0.2025931203388609, 0.14408451301278546, 0.15817363746464252, 0.14454225485678762, 0.12067204705090262, 0.14916445448761806, 0.1203454946517013, 0.2350180718349293, 0.14798233198234811, 0.0973292910202872, 0.14084163936786354, 0.09605432584066875, 0.13440992042887956, 0.11618721153354272, 0.15999026654753834, 0.17339012876618654, 0.10043966904049739, 0.10980166160152294, 0.14873509237077087, 0.13643249549204484, 0.14515430404571816, 0.09715047053759918, 0.13466518954373896, 0.14220115001080558, 0.10407202178612351, 0.10444598257890902, 0.13125375931849703, 0.1980859981267713, 0.17283868335653096, 0.1081917058036197, 0.15606167813530192, 0.137083581648767, 0.09999267349485308, 0.15498517808737233, 0.14587344514438882, 0.195109985943418, 0.10543122814851813, 0.07231056515593082, 0.22328152583213523, 0.18266725674038753, 0.1776590512599796, 0.07225634384667501, 0.15177237626630813, 0.1339854416437447, 0.09341746030258946, 0.1155013038078323, 0.11145113676320761, 0.1827275933464989, 0.12080384505679831, 0.11621637793723494, 0.14883041381835938, 0.23371671588392928, 0.12427157460479066, 0.2095623323111795, 0.10913723162957467, 0.19028532842639834, 0.166726058232598, 0.17516804742626846, 0.1259270092123188, 0.13890175439883024, 0.10657569408067502, 0.12489481538068503, 0.18459400569554418, 0.23098288133041933, 0.16522215533768758, 0.07669360769796185, 0.18636306311236694, 0.14897701767040417, 0.12236174661666155, 0.12156974145909771, 0.09302316466346383, 0.12312833321630023, 0.17159240960609168, 0.11398747097700834, 0.12818911985959858, 0.15120874479180202, 0.12548286351375282, 0.07099166483385488, 0.2167038116022013, 0.11306950851576403, 0.20243756618583575, 0.12404513050569221, 0.17678420757874846, 0.11021313795936294, 0.0970948465692345, 0.22549214627360925, 0.17108902567997575, 0.1552128096227534, 0.076057193800807, 0.06976426389883272, 0.16918773239012808, 0.12811447464628145, 0.1396133255911991, 0.11660995369311422, 0.12683907902101055, 0.1289352454477921, 0.0921019515953958, 0.23670322203543037, 0.22762484120903537, 0.15310623828554526, 0.12733416573610157, 0.08880839668563567, 0.12984194210730493, 0.14416260179132223, 0.15070294146426022, 0.12950741162057966, 0.08054542835452594, 0.18294726905878633, 0.12036074578645639, 0.13391244399826974, 0.0839370432368014, 0.15584972075885162, 0.12841269926866516, 0.14246808568714187, 0.11920256496523507, 0.12462694459827617, 0.12960685940925032, 0.15661575074773282, 0.13379874697420746, 0.09781831438886002, 0.09324343409389257, 0.11257001344347373, 0.0832563750736881, 0.1691879698773846, 0.09347184488433413, 0.11628167951130308, 0.2456964339944534, 0.14323445706395432, 0.17283176654018462, 0.16507426014868543, 0.10979033642797731, 0.19122442725347355, 0.11781875640735961, 0.11602984654018655, 0.13550987234339118, 0.05860116798430681, 0.06619317544391379, 0.09494142344919965], [0.07197158178314567, 0.029384570989350323, 0.03672374543384649, 0.08825008640997112, 0.015592615454806946, 0.03986249947047327, 0.0370560309238499, 0.012014561943942681, 0.025653883676568512, 0.14182128914399073, 0.0328453002293827, 0.14055729290703312, 0.04555916566459928, 0.09647246668464504, 0.04582502522680443, 0.009265005919587566, 0.023983589417184703, 0.02128163010638673, 0.02221752471086802, 0.013956904349470278, 0.02182139411161188, 0.02310105337528512, 0.0533384652226232, 0.028112513173255138, 0.052970077958889306, 0.03401005276828073, 0.0065411782998126, 0.04123749131395016, 0.03586431987059768, 0.027997292891086545, 0.07771590127958916, 0.023498859372921288, 0.059795153720187955, 0.021213823783909902, 0.06597393759875558, 0.0368553616135614, 0.058464241737965494, 0.0308682113973191, 0.021790209066239186, 0.08467873078188859, 0.05712021971703507, 0.04355037228378933, 0.031624285475118086, 0.032942573525360785, 0.0490130244725151, 0.011194490616617259, 0.036076188189326786, 0.021714433933084365, 0.10203417332377285, 0.03992971578554716, 0.06279966808506288, 0.015233607082336675, 0.08189779211534187, 0.06481770120444708, 0.009916233084368287, 0.031116919926716946, 0.03389539837371558, 0.0552782611339353, 0.06020016597176436, 0.006375308757924358, 0.010707835626817541, 0.048141208753804676, 0.09637534923967905, 0.010279356665705564, 0.04236744454829022, 0.010746107254817616, 0.03242542647058144, 0.044520266528707, 0.037091872945893556, 0.06714779257890768, 0.024115172200254165, 0.016067666037997697, 0.038197995818336494, 0.10796209273394197, 0.03326943020510953, 0.06736954630468972, 0.08673461343278177, 0.030159690431901254, 0.041721798334037885, 0.037002395911258645, 0.01949607474671211, 0.07613560912432149, 0.03826952772215009, 0.03802498264121823, 0.0487582191999536, 0.041643130680313334, 0.04980745645298157, 0.04436035596881993, 0.025221013056579977, 0.04681677572079934, 0.02323609085578937, 0.027297983833705075, 0.06517721980344504, 0.05002893187338486, 0.06203986471518874, 0.07907722276286222, 0.05607586950645782, 0.03684318297018763, 0.04204326331091579, 0.02239011857454898, 0.025026314324350096, 0.01861558517703088, 0.005423307229648344, 0.022277970783761702, 0.07669018639717251, 0.014135499404801521, 0.009137545766861876, 0.03501786333799828, 0.02252262904221425, 0.03365536183991935, 0.07721194589976221, 0.019429897438385524, 0.01797350498236483, 0.06863072238047607, 0.02477751117112348, 0.04404255349072628, 0.051497716340236366, 0.05999823872116394, 0.04364566404547077, 0.022622659416811075, 0.02968888307805173, 0.016504453342349734, 0.0626737107813824, 0.033435248260502703, 0.02975910138047766, 0.05093159124953672, 0.050849071849370375, 0.04578838910674676, 0.01467417523599579, 0.01860299464169657, 0.019231588157708757, 0.05769831193902064, 0.036913768635713495, 0.015607716304657515, 0.050546616985229775, 0.04462946242711041, 0.05028661667893175, 0.1344142248854041, 0.03599034025683068, 0.044676481193164364, 0.04154671456490178, 0.042692679635365494, 0.05225420602073427, 0.04365124128526077, 0.02548316744650947, 0.0356524478411302, 0.0439965811528964, 0.022888264793436974, 0.039301780925597996, 0.08391399212996475, 0.05468741510412656, 0.025316937499155756, 0.045943509103381075, 0.01739406019623857, 0.04046713831485249, 0.03778182166570332, 0.07002457219641656, 0.018520918674767017, 0.026511904725339264, 0.06914552053785883, 0.04140616292716004, 0.03555631003109738, 0.015206101234070957, 0.1086291647516191, 0.09665645251516253, 0.07369398037553765, 0.046236564667196944, 0.009985699034587014, 0.135261015384458, 0.1257446189993061, 0.013372934317885665, 0.01599082777829608, 0.014882207578921225, 0.047304259132943116, 0.058375614462420344, 0.02005448335694382, 0.05218988037086092, 0.03288106803665869, 0.04588152492942754, 0.1242054789327085, 0.02579391024482902, 0.03971401798480656, 0.08483019570121542, 0.06288108168519102, 0.013820772201142972, 0.153197611507494, 0.01054678401487763, 0.05087876888865139, 0.01696004852419719, 0.03016584840224823, 0.05025961734645534, 0.0034126498985642684, 0.020382386464916635, 0.04847423639148474, 0.03157472856401, 0.005539491376111982, 0.04107054519408848, 0.03060367285797838, 0.0494661093398463, 0.08637507999083027, 0.026915299094980583, 0.0706328586966265, 0.020845260260102805, 0.06904979833052494, 0.02080665002722526, 0.06130139066954143, 0.019776923836616334, 0.05696265434380621, 0.05784989560197573, 0.027023446709790733, 0.07582302394439466, 0.0042308094998588786, 0.03508854548272211, 0.033944751194212586, 0.03670224912639242, 0.03324407101899851, 0.06538687652209774, 0.028018967313983012, 0.022498425751109608, 0.05924938202952035, 0.009111080780712655, 0.029940170570625924, 0.03366734381415881, 0.029976654550409876, 0.05301372737449128, 0.060051406180718914, 0.01922734492836753, 0.06930359057150781, 0.01818541782995453, 0.04267497941327747, 0.04688573237217497, 0.01271880442800466, 0.02662609527760651, 0.06919599400134757, 0.11215606573387049, 0.05047493665188085, 0.016088913725980092, 0.007894757327449042, 0.05710679426556453, 0.08107245710561983, 0.04994469811208546, 0.01827303392929025, 0.06820529364631511, 0.019786599586950615, 0.014774132323509548, 0.07295142451766878, 0.01302417407714529, 0.051744328302447684, 0.04898558356217109, 0.03961518617870752, 0.013031897051405394, 0.08375556586543098, 0.1036548160482198, 0.004003251715403167, 0.09438118358957581, 0.005042185175625491, 0.028861058162874542, 0.017038710611814167, 0.032244858230114914, 0.09067626364412718, 0.04208836362522561, 0.08181113153113984, 0.03795546195760835, 0.0634521569008939, 0.020353891704871785, 0.03835593968688045, 0.025597061139706057, 0.06864667113404721, 0.02072812152619008, 0.06065039357054047, 0.026273523180861957, 0.053004999717813917, 0.022317968832794577, 0.05203175838687457, 0.03452208642556798, 0.05002626385248732, 0.04667539287765976, 0.08115276490570977, 0.03937905334169045, 0.025914023135555908, 0.04844231290917378, 0.025964223859773483, 0.011341959998389939, 0.06367169160512276, 0.057293199497507885, 0.018049207756121177, 0.10665728579624556, 0.0020151329454165534, 0.04087280365638435, 0.0556856445473386, 0.036699469783343375, 0.046535037909052335, 0.027105155313620344, 0.03180008541676216, 0.02897107413446065, 0.021193809916439932, 0.0507161420682678, 0.0428318657213822, 0.09351962435175665, 0.04817913250008132, 0.04192463842628058, 0.041329120576847345, 0.03311500411655288, 0.04599275802320335, 0.0679717175080441, 0.01635232420085231, 0.018450422066962346, 0.0030939283169573173, 0.06393628209480084, 0.07523439693613909, 0.01727284336084267, 0.025588567259546835, 0.005190919455344556, 0.0604344248858979, 0.019466496451059356, 0.04764058561704587, 0.06104604733991437, 0.04742403805721551, 0.04877398612734396, 0.03531470014422666, 0.025234221429855097, 0.02479318904079264, 0.03101686543232063, 0.015362681406259071, 0.04439766373252496, 0.03144244816212449, 0.004934568660246441, 0.046080242391326465, 0.02325975423445925, 0.015883273881627247, 0.030500243447022513, 0.047966225174604915, 0.05871234170626849, 0.07842559483833611, 0.054307839964167215, 0.06059184182959143, 0.06232589585124515, 0.05941572700976394, 0.03111868994892575, 0.04881802145973779, 0.031497912568738684, 0.07802391482982785, 0.09033313908730634, 0.030550839364877902, 0.06284434537519701, 0.06844184579676948, 0.024258607081719674, 0.02279948166687973, 0.058435472383280285, 0.05918822906096466, 0.08879469663952477, 0.013831056512572104, 0.20170597184915096, 0.140522308065556, 0.16923125192988664, 0.20103015733184293, 0.07450846518622711, 0.1281371695222333, 0.11362024146365002, 0.11691931053064764, 0.07866553118219599, 0.308813140145503, 0.09824884167755954, 0.2618191618239507, 0.18746111512882635, 0.16520642180694267, 0.14685771107906476, 0.06702466285787523, 0.08515811365214176, 0.10140075770323165, 0.12251540829311125, 0.08826448407489806, 0.12719305377686396, 0.14642882393673062, 0.11302766622975469, 0.09468376461882144, 0.14199901866959408, 0.198783750529401, 0.09100076771574095, 0.1622295190463774, 0.13158362911781296, 0.13029641850152984, 0.1456045056693256, 0.08673143704072572, 0.1309223606949672, 0.11422448325902224, 0.12834387249313295, 0.11288514418993145, 0.15254662925144657, 0.14719792641699314, 0.11294712094240822, 0.12361193890683353, 0.17892387870233506, 0.1937914566951804, 0.16917513072257861, 0.13940568751422688, 0.09429200712474994, 0.15924727282254025, 0.0698033305525314, 0.17044313455699012, 0.2586025750497356, 0.1497123227454722, 0.12888944009318948, 0.17208056466188282, 0.18084439361700788, 0.2391094429185614, 0.1114034463535063, 0.208272019517608, 0.08059657717240043, 0.12639422086067498, 0.2419420870137401, 0.10822805619682185, 0.14160214777803048, 0.08604667222243734, 0.1906465317006223, 0.16888400103198364, 0.14589732745662332, 0.09077131791855209, 0.12611220474354923, 0.13849240058334544, 0.14538595802150667, 0.13902526261517778, 0.12614474049769342, 0.1030401248135604, 0.12299231239012443, 0.19686311687109992, 0.07858496363041922, 0.2189840454957448, 0.16948147444054484, 0.10474334630998783, 0.22131667501525953, 0.07412899023620412, 0.10097723628859967, 0.09113731546676718, 0.07912388900876977, 0.2791312406770885, 0.12836704234359786, 0.1600167018477805, 0.15660328266676515, 0.13206455565523356, 0.05887732113478705, 0.13360417069634423, 0.10044937633210793, 0.11155333791975863, 0.10458412594744004, 0.16245939186774194, 0.12032996892230585, 0.21708128275349736, 0.1828964170999825, 0.1037091932084877, 0.07536560864537023, 0.183854128990788, 0.09943643381120637, 0.1484945326228626, 0.1156068743148353, 0.08221120107918978, 0.2333543251734227, 0.11167684613610618, 0.10943164903437719, 0.20029842940857634, 0.14911979204043746, 0.05026292732509319, 0.1375019599799998, 0.0953658131766133, 0.11633526257355697, 0.1444538205396384, 0.2038739187992178, 0.15905933134490624, 0.22378842753823847, 0.1341526920441538, 0.17305346089415252, 0.10746692438260652, 0.10509928775718436, 0.17899557016789913, 0.21011971490224823, 0.14610313985031098, 0.14490029658190906, 0.1721060648560524, 0.18914276239229366, 0.13025197869865224, 0.13764244853518903, 0.09351742759463377, 0.1262855259119533, 0.14652240875875577, 0.2528039674507454, 0.19749042461626232, 0.20798221084987745, 0.17010814393870533, 0.07211441552499309, 0.2547641872661188, 0.15153757558437064, 0.26287704880815, 0.13620697165606543, 0.17277484381338581, 0.16258086659945548, 0.1116822638141457, 0.18458431324688718, 0.10362410597736016, 0.11221102919080295, 0.1004840643145144, 0.13938389805844054, 0.19238250417402014, 0.13420666102319956, 0.10433342846226878, 0.21918580576311797, 0.09613741669454612, 0.13732301333220676, 0.1004279802145902, 0.16016004025004804, 0.13564112858148292, 0.14652444224338979, 0.1649522955995053, 0.16911685728700832, 0.059229470207355917, 0.15037522389320657, 0.24212391319451854, 0.15550569078186527, 0.1387922727735713, 0.19586068316129968, 0.12159242149209604, 0.28431297512724996, 0.16405408910941333, 0.13015441596508026, 0.10587216034764424, 0.08351181488251314, 0.11895019764779136, 0.2987990446854383, 0.1420096610672772], [0.014187708566169022, 0.05864067992661148, 0.026878774297074415, 0.020865697151748464, 0.03542120575730223, 0.018862135912058875, 0.025381020095665008, 0.02013641089433804, 0.06827812059782445, 0.08727246269700117, 0.016963128437055275, 0.04575119266519323, 0.090884740347974, 0.024546847962483298, 0.020207091183692683, 0.03327780534164049, 0.027265782046015374, 0.011766514853661647, 0.036579583247657865, 0.06891765893669799, 0.03690330435347278, 0.04510351667704526, 0.01853968573414022, 0.07736813087831251, 0.04871255856414791, 0.023087355184543412, 0.04518151268712245, 0.012510270207712892, 0.03271427776780911, 0.0319496652809903, 0.032169886471820064, 0.06359528008033521, 0.03713729609444272, 0.03478928185359109, 0.06351880176225677, 0.061297501815715805, 0.038389113688026555, 0.045305377134354785, 0.051792608719551936, 0.0678981929377187, 0.014397064715012675, 0.053277145270840265, 0.04289035809051711, 0.05002939571568277, 0.036427747254492715, 0.012143815310992068, 0.0742843365878798, 0.05860766919795424, 0.02003792233153945, 0.06868711076094769, 0.053699969066656195, 0.03882655408233404, 0.040191660518758, 0.06990346853854135, 0.022697627464367542, 0.037189290960668586, 0.03806170410825871, 0.014184688952809665, 0.03525512795022223, 0.018145748181268573, 0.05175101505301427, 0.06061505620891694, 0.01846652667154558, 0.05411228405137081, 0.04839371707930695, 0.02601958065497456, 0.021614295947074424, 0.05385966069297865, 0.006026263254170772, 0.03934085129003506, 0.062354052934097126, 0.026074063571286388, 0.051060398400295526, 0.019397287469473667, 0.028553085430758074, 0.09095658766455017, 0.0857532567169983, 0.027703677005774807, 0.012154807445767801, 0.02134045644197613, 0.0053946635762258666, 0.016315335560648236, 0.014428099475480849, 0.014945925595384324, 0.04378548466775101, 0.07813527408870868, 0.080558074550936, 0.048838760776561685, 0.03250137415307108, 0.0278811764655984, 0.05394671461544931, 0.023051763637340628, 0.05563610618992243, 0.045161047964938916, 0.13423021679045632, 0.06470625288784504, 0.059078402337036096, 0.04976152864401229, 0.04894371159025468, 0.037793696028529666, 0.03874207541230135, 0.010626364510244457, 0.02773958767647855, 0.0337068075168645, 0.05948654645180795, 0.09829761562286876, 0.04384077838039957, 0.023963276835274883, 0.015590168222843204, 0.030429644793912303, 0.07569863257231191, 0.023285593961190898, 0.03472741642326582, 0.06980019868933596, 0.04898198414593935, 0.1160465893917717, 0.026862935010285582, 0.05059716466348618, 0.07243764310260303, 0.02631420586112654, 0.023347459391516168, 0.04046719397592824, 0.02509914313122863, 0.039519519632449374, 0.015305171455111122, 0.08315721672261134, 0.03480651823338121, 0.03575600712792948, 0.029501743119908497, 0.11199838161701337, 0.044793339766329154, 0.030694864253746346, 0.06091396731790155, 0.05371871571696829, 0.03472609540040139, 0.012168463890702697, 0.10564470692770556, 0.022131587720650714, 0.016455957702419255, 0.05853243768797256, 0.05663959003868513, 0.029731829308730084, 0.05952826999418903, 0.04807338758837432, 0.015759231318952516, 0.04513545129157137, 0.013567752721428405, 0.045225759531604126, 0.016517045733053237, 0.04457888877368532, 0.0968891529191751, 0.031532455832348205, 0.012145701293775346, 0.007977900131663773, 0.030568504334951285, 0.04677735654695425, 0.014002775569679216, 0.03722809786268044, 0.04186405691143591, 0.04770564228238072, 0.020738958737638313, 0.003681424941532896, 0.010778769174066838, 0.05157582367246505, 0.0765531488286797, 0.03682791328174062, 0.026552737690508366, 0.04229640246194322, 0.02000992295506876, 0.047919106218614615, 0.021427766405395232, 0.08297348322230391, 0.007642854316145531, 0.013268458478705725, 0.09672367625171319, 0.03537083248374984, 0.07009493521763943, 0.06386413049767725, 0.06777293325285427, 0.031267698359442875, 0.04372447270725388, 0.011883250972459791, 0.010885282208619174, 0.015147699778026436, 0.03757474391022697, 0.0716256519081071, 0.0400817966874456, 0.06077416524931323, 0.0010294789626641432, 0.05852234076883178, 0.04961607883160468, 0.03154395169985946, 0.03648549005447421, 0.03716995059221517, 0.03771480201976374, 0.004935241231578402, 0.047204592410707846, 0.06757498762453906, 0.03237109754991252, 0.0544423616520362, 0.038863579829921946, 0.014540507017954951, 0.07626375576364808, 0.08160298137227073, 0.07347456441493705, 0.03201629158866126, 0.024462616056553088, 0.07730880359304138, 0.04133001857553609, 0.050543473989819176, 0.07274427625816315, 0.017787279721233062, 0.08068404669757001, 0.03555245086317882, 0.023429049251717515, 0.050998588631046005, 0.0054529453609575285, 0.04319641608162783, 0.07339787087403238, 0.06852250240626745, 0.010821721898537362, 0.03939948095649015, 0.01763114854838932, 0.10598981301882304, 0.04040571075165644, 0.05518631645827554, 0.023881481029093266, 0.07457554049324244, 0.0123317966790637, 0.029252578169689514, 0.01480063720009639, 0.08299174747662619, 0.03824959363555536, 0.025426049905945547, 0.06504897668492049, 0.06380835809977725, 0.07980898037203588, 0.036291989890742116, 0.06494237459264696, 0.047512231176369824, 0.022355504806910176, 0.06917478342074901, 0.041748994335648604, 0.0486547972104745, 0.03957139575504698, 0.04529777754214592, 0.025973842093662824, 0.06398140467354096, 0.038244116585701704, 0.018592259475553874, 0.03399139517568983, 0.06134695482614916, 0.025055898186110426, 0.026456768719071988, 0.06183611178130377, 0.020215401382301934, 0.06537289445986971, 0.03397851891350001, 0.05240778606093954, 0.022419746965169907, 0.018785486900014803, 0.05170110933249816, 0.03979403634730261, 0.03376821652636863, 0.023074170931067783, 0.029745393912889995, 0.016719197483325843, 0.014764044681214727, 0.08020841909456067, 0.044327367504592985, 0.05001946949050762, 0.04200477182166651, 0.013625634674099274, 0.009277690151066054, 0.04767250538861845, 0.020699164779216517, 0.0506912652781466, 0.04948865949700121, 0.036969771099393256, 0.012113290777051589, 0.06358969912980683, 0.028208650983287953, 0.016302507538057398, 0.02126496703567682, 0.02068949459498981, 0.058649622806115076, 0.05073143773188349, 0.02562061319622444, 0.02030398969509406, 0.11025454979971983, 0.011850711507577216, 0.07470665572327562, 0.04050916984851938, 0.014216305371519411, 0.01717621573334327, 0.026248824506183155, 0.01606373451068066, 0.10492233006516472, 0.0608172840293264, 0.03627137302828487, 0.03152716060867533, 0.08095769138890319, 0.04052093288919423, 0.02099272871419089, 0.06896593564306386, 0.02022410862991819, 0.0334670529991854, 0.06405355627066456, 0.023590076743857935, 0.04334662306064274, 0.02944331197795691, 0.040946406152215786, 0.08234543332946487, 0.015308913734770613, 0.03371194688952528, 0.06745527178281918, 0.03158080675348174, 0.049603024453972466, 0.0342721904598875, 0.044759623997379094, 0.07116653709090315, 0.08335855396580882, 0.038537769578397274, 0.02891818126954604, 0.019398825570533518, 0.037344396114349365, 0.13577953912317753, 0.029307435870578047, 0.04085087690327782, 0.0370054164523026, 0.020496567740337923, 0.0798141531413421, 0.06361384119372815, 0.03846623767458368, 0.024920996147557162, 0.06224371783901006, 0.06348731243633665, 0.03670561476610601, 0.07995122039574198, 0.01497501685662428, 0.05586591221799608, 0.03351263570948504, 0.06990464113187045, 0.04157272313022986, 0.06332886390737258, 0.03340084971569013, 0.02903524764406029, 0.03600071919208858, 0.040233001855085604, 0.03943714495107997, 0.06537429711897857, 0.04183686090982519, 0.1815101594547741, 0.13803544541588053, 0.1629830215824768, 0.11139429567265324, 0.15091544802999124, 0.08102435851469636, 0.10507262239116244, 0.12616629246622324, 0.1465338229900226, 0.16854540357599035, 0.07101381794200279, 0.24645382538437843, 0.13542462926125154, 0.1936607644893229, 0.17465362034272403, 0.08346413931576535, 0.10150446541956626, 0.18336064531467855, 0.08393896539928392, 0.15967595216352493, 0.16921482078032568, 0.15890250069787726, 0.11414515509386547, 0.17113692389102653, 0.16812916263006628, 0.17672623100224882, 0.1811825012555346, 0.16841061471495777, 0.09282454368076287, 0.15254775731591508, 0.08910426127840765, 0.2721910021500662, 0.1266718583065085, 0.14319850743049756, 0.11065621496527456, 0.1302077466971241, 0.18262489495100453, 0.13672179949935526, 0.0951825175434351, 0.1590113589190878, 0.11718140740413219, 0.16037465451518074, 0.19937625154852867, 0.14909399498719722, 0.12908544129459187, 0.10213266374194063, 0.17885603156173602, 0.15665015671402216, 0.2001771773211658, 0.18794352596160024, 0.12994308199267834, 0.10085789894219488, 0.07276576143340208, 0.19763456453802064, 0.15172366169281304, 0.13233129837317392, 0.14588621008442715, 0.16406183713115752, 0.16557157330680639, 0.10884032060857862, 0.13323309685802087, 0.1294886798132211, 0.2075933848391287, 0.11717865403625183, 0.12127864145440981, 0.2089694602182135, 0.11824695335235447, 0.11946211627218872, 0.09239185674232431, 0.1558772544376552, 0.14298139954917133, 0.1448528585024178, 0.14282713673310354, 0.20554536895360798, 0.16091711993794888, 0.17741749703418463, 0.18410539050819352, 0.11258147962507792, 0.17996009497437626, 0.10444730360177346, 0.16904797113966197, 0.05527187495317776, 0.13334389950614423, 0.13944234960945323, 0.12671663949731737, 0.1445043459534645, 0.1471509484690614, 0.14129475021036342, 0.05455176535178907, 0.13870340801076964, 0.09536513782222755, 0.19728014449356124, 0.21938495367066935, 0.17500477493740618, 0.14954382553696632, 0.11402491974877194, 0.15397284412756562, 0.15569858980597928, 0.08875044237356633, 0.11523499895702116, 0.18572760658571497, 0.12619594868738204, 0.13739421498030424, 0.1041008171159774, 0.19324845692608505, 0.2677940740250051, 0.11626893683569506, 0.06921272943145595, 0.13115874957293272, 0.17688117659417912, 0.16933248087298125, 0.07910476386314258, 0.15673853165935725, 0.20541426114505157, 0.18001349992118776, 0.20180625084321946, 0.08673941512824968, 0.11283629602985457, 0.13650878827320412, 0.08244019074481912, 0.1679154983139597, 0.17061436286894605, 0.14204277569660917, 0.10871582533582114, 0.14444356405874714, 0.21730509964982048, 0.10658356826752424, 0.12328401353443041, 0.06579613385838456, 0.14796026051044464, 0.1100546374800615, 0.2091965574072674, 0.14773801696719602, 0.1898897043429315, 0.09929581909091212, 0.08837141271214932, 0.1978842230164446, 0.1259200627100654, 0.06706104293698445, 0.14778797834878787, 0.17459693510318175, 0.127504488627892, 0.23652541829505935, 0.13726420555030927, 0.1508030720287934, 0.19309861731017008, 0.1019353415176738, 0.1105271332198754, 0.12645602691918612, 0.10728313893196173, 0.25533427542541176, 0.061714885669061914, 0.1695911044953391, 0.1380797367892228, 0.1641884772107005, 0.1514438571757637, 0.13091682427329943, 0.11853993099066429, 0.17378769727656618, 0.15520394837949425, 0.12908272503409535, 0.09514707257039845, 0.2323534054448828, 0.10893678496358916, 0.20333595079137012, 0.12953319383086637, 0.13346714054932818, 0.14680200547445565, 0.06863490809337236, 0.15239153522998095, 0.15298258163966238, 0.13492375379428267, 0.07733373233349994, 0.10045541741419584, 0.1471128169214353, 0.16072916361736134], [0.0491709349444136, 0.03851653673336841, 0.051980787684442475, 0.03050280014576856, 0.02025507845246466, 0.06668763133347966, 0.037175943434704095, 0.036490692509687506, 0.03758680380997248, 0.06427559943404049, 0.06647775197052397, 0.024238476325990632, 0.06302674300968647, 0.020607837941497564, 0.03250865833251737, 0.03586157763493247, 0.05270939116599038, 0.037275955255609006, 0.04347730413428508, 0.009630239983380307, 0.03152993995172437, 0.07073986897012219, 0.009039920878421981, 0.046167422478902154, 0.023854559622122906, 0.0510203669546172, 0.015450814225914655, 0.1084730020374991, 0.033129835937870666, 0.004307357394282008, 0.05131669910042547, 0.02116188272339059, 0.023608107221662067, 0.03535099858709145, 0.055113459820859134, 0.014708848375448724, 0.02442728240566794, 0.026850784197449684, 0.029306905234989244, 0.03552192261849996, 0.06429905130062252, 0.007292375075849122, 0.028085528683732264, 0.022952599720156286, 0.015617455137544312, 0.0645405164686963, 0.011550016461114865, 0.07765979491523467, 0.013626650488731684, 0.03727888302819338, 0.04233025181747507, 0.024791266878310125, 0.02080377049423987, 0.023186405924207065, 0.03748563052795362, 0.031575637694913894, 0.06700749698211439, 0.03949021593143698, 0.029338116255530622, 0.037256570358294994, 0.0340019373834366, 0.05800085957162082, 0.013707902671740158, 0.03821469043032266, 0.0758823067008052, 0.02867533385142451, 0.022679969915770926, 0.04608465817000251, 0.07201011409051716, 0.03638415349996649, 0.016548969215364195, 0.06378720689099282, 0.05512215408089105, 0.008500899020873476, 0.017784795381885488, 0.022096072243584786, 0.05067920537840109, 0.022126331459730864, 0.028774579404853284, 0.008390256862185197, 0.04867306517553516, 0.0013746088256993971, 0.030561242419935297, 0.04637815531168599, 0.05248363726423122, 0.04920108098303899, 0.06476925380411558, 0.03768093039980158, 0.07513096381444484, 0.0394285508809844, 0.04069153408636339, 0.016585171179031022, 0.013677997831109678, 0.0338997102517169, 0.026672588974179234, 0.044092503740102984, 0.08400739141507074, 0.0018234389835924958, 0.03796735487412661, 0.059135666451766156, 0.04916165067697875, 0.039703327347524464, 0.028495305523392744, 0.009783512032299768, 0.04858224114286713, 0.0369942842371529, 0.06282925751293078, 0.0016490443681504985, 0.019710598098754417, 0.019847054936690256, 0.023884256661403924, 0.027768160362029448, 0.031883476840448566, 0.010335779370507225, 0.0527427395718405, 0.03813118768448476, 0.016350700752809644, 0.029608979748445563, 0.0539829907938838, 0.027661684434860945, 0.01667805467150174, 0.09290004236390814, 0.025134654897556175, 0.04215479326376226, 0.019695758855959866, 0.0053290331379685085, 0.05689303718099836, 0.059981737067573704, 0.04741538461530581, 0.025457798983552493, 0.015410667747346452, 0.08231447834987193, 0.0645765477383975, 0.026680459450290073, 0.03463241409917828, 0.01356695491267601, 0.0445189603487961, 0.04111848051252309, 0.025129860623565037, 0.05831261725688819, 0.059065722743980587, 0.09496619633864611, 0.027657200007524807, 0.042690776026574895, 0.04885394140728749, 0.04220999049721286, 0.05938850503298454, 0.031310319900512695, 0.08854102314217016, 0.040192380402004346, 0.06766748891095631, 0.04521473863860592, 0.02217869183368748, 0.02158883657102706, 0.07469393531209789, 0.020274194321245886, 0.024448144176858477, 0.022422684014600236, 0.01773171326931333, 0.05684147647116333, 0.12080665037501603, 0.0029976583118696, 0.026608313419274054, 0.03859981312416494, 0.02253267215564847, 0.03346523102663923, 0.03795012962655164, 0.03470814655884169, 0.07140976857044734, 0.020875901682302356, 0.02538583106797887, 0.018845728882297408, 0.041183162393281236, 0.0502387778396951, 0.0291285096318461, 0.010034440510935383, 0.06828923054854386, 0.08384590008063242, 0.09651549640693702, 0.024709135250304826, 0.015735809138277546, 0.04719475895399228, 0.011437440080044325, 0.027261919167358428, 0.008569454912503716, 0.025392755305801984, 0.035399728003540076, 0.06337069135042839, 0.034673276750254445, 0.017657537464401685, 0.02908009191742167, 0.05684673829819076, 0.02343983080209, 0.03450548458204139, 0.01743770219036378, 0.02975405292090727, 0.045715532469330356, 0.03499987367831636, 0.044857502143713646, 0.08782043485553004, 0.024066414953267667, 0.0370896056847414, 0.037574966554529965, 0.05876252573216334, 0.020699587803392205, 0.029750479479844216, 0.02535383708163863, 0.03490279705147259, 0.03916748559277039, 0.015798318381712306, 0.07374593813437968, 0.018939540059363935, 0.024108804573188536, 0.04723033380287234, 0.04230921193084214, 0.022575080329261255, 0.08181676443200558, 0.033064159579225816, 0.010442970542499097, 0.06339156796457246, 0.03440923544985708, 0.05319655916537158, 0.014015800261404365, 0.04655410368286539, 0.04049102804856375, 0.008183675417967606, 0.00850982612973894, 0.03793134215811733, 0.03824556748440955, 0.027246363752055913, 0.021867464784008916, 0.03659470079583116, 0.052866210680804215, 0.012959344694536412, 0.0403014130279189, 0.0386639606585959, 0.03157119594106916, 0.028082296630600467, 0.019779263457166962, 0.088018833193928, 0.010590830479486613, 0.009931806125678122, 0.015755579952383414, 0.028154156934760977, 0.06235215303604491, 0.05287777334160637, 0.027570314923650585, 0.0686930627853144, 0.1303981669479981, 0.015604469408572186, 0.07432892482029274, 0.06473492947407067, 0.053607452937285416, 0.06049217139661778, 0.007899174961494282, 0.03017492486833362, 0.016696200182195753, 0.00899226015462773, 0.028484934009611607, 0.06217451998963952, 0.010158221466554096, 0.0322310951014515, 0.033509106797282584, 0.02287647392222425, 0.029469984765455592, 0.030231253876991104, 0.006367968917402322, 0.019302517066535074, 0.030904057130101137, 0.049320548205287196, 0.07153505794121884, 0.04133024864131585, 0.031427913199877366, 0.045684581200475805, 0.03055684890568955, 0.050198787212138996, 0.03889939216605853, 0.04284621143597178, 0.02855806153092999, 0.04140764351177495, 0.05274083225231152, 0.036299986531957984, 0.08706276144948788, 0.017803579139581416, 0.019432895714999177, 0.021966680651530623, 0.03352308885951061, 0.027289640238450374, 0.01770357474015327, 0.04134994524065405, 0.02874388974305475, 0.059915500387432985, 0.04510652979661245, 0.10375736601417884, 0.050344192495686, 0.04666058703151066, 0.04179709663731046, 0.02077008812193526, 0.024215655284933746, 0.05853987400769256, 0.013778012435068376, 0.006150593399070203, 0.027836367444251664, 0.07295992210856639, 0.038398353426600806, 0.022392832979676314, 0.03731623161002062, 0.09133546147495508, 0.030806603863311466, 0.039031275518937036, 0.050768489454640076, 0.01121864288506913, 0.03211338305845857, 0.0758589142060373, 0.04314920435717795, 0.018758324295049533, 0.037514603973249905, 0.03781574523600284, 0.009043636255228193, 0.02095492927765008, 0.03732265118742362, 0.05076365065178834, 0.043540308761294, 0.05695726264093537, 0.04579595901304856, 0.0689632268040441, 0.04430561144545209, 0.04936325138260145, 0.02577039529569447, 0.02663688239408657, 0.024489147835993208, 0.008198503528547008, 0.024564540763094556, 0.038292638200800866, 0.03097362790867919, 0.023135130941227544, 0.07424311770591885, 0.04354198601504322, 0.0034113947413061396, 0.021573613266809843, 0.018912505474872887, 0.02203205272962805, 0.0447729900770355, 0.023339976687566377, 0.02689953031222103, 0.0325775927194627, 0.04441229517397005, 0.07100998103851452, 0.0958879289100878, 0.032647785046719946, 0.06328771181870252, 0.033942305817618035, 0.10366991875343956, 0.1373672453337349, 0.20927005971316248, 0.1672811253229156, 0.06987197921262123, 0.1677960719098337, 0.1513544877525419, 0.1681255261064507, 0.1689349568914622, 0.10339231841498986, 0.17527675721794367, 0.1809079956728965, 0.1885823963675648, 0.11555001095985062, 0.14525501348543912, 0.17488303303252906, 0.102694157831138, 0.11193797079613432, 0.06220924507942982, 0.12700776918791234, 0.1152064188499935, 0.13326140237040818, 0.1362713603884913, 0.22317860479233786, 0.17679771466646343, 0.13182858237996697, 0.08234920343966223, 0.16744108783314005, 0.10247940997942351, 0.1347373114549555, 0.14259310788474977, 0.13977355527458712, 0.11356726696249098, 0.08146852647769265, 0.28982754796743393, 0.0977000234706793, 0.09808689763303846, 0.10629751486703753, 0.09956904817954637, 0.14011832739925012, 0.25456238246988505, 0.075495751661947, 0.1088223309488967, 0.22461466054664925, 0.11843433079775423, 0.16533714369870722, 0.09635845053708181, 0.2088383969385177, 0.21219143498456106, 0.07997188178705983, 0.08491569853504188, 0.08654746605316177, 0.08908978939871304, 0.1822192221879959, 0.0844515000062529, 0.12762486498104408, 0.1208886799577158, 0.12502678408054635, 0.17474008054705337, 0.12553125154227018, 0.11357391660567373, 0.14850680774543434, 0.08025142655242234, 0.23984584637219086, 0.11822998043498956, 0.08133799012284726, 0.10865593401831575, 0.06778350143576972, 0.13256917154649273, 0.1397438842104748, 0.11508695533848368, 0.2487882657442242, 0.3489100729348138, 0.1809502238756977, 0.14882236893754452, 0.14112922159256414, 0.21405437408247963, 0.10294306674040854, 0.15461958129890263, 0.1040714725968428, 0.15948939108056948, 0.10467869782587513, 0.12203945414512418, 0.1600152175524272, 0.1571876200614497, 0.1989521735231392, 0.24463163019390777, 0.1515154744265601, 0.12160316779045388, 0.053568044895655476, 0.11470018507679924, 0.1414821870275773, 0.08085681867669336, 0.13554789999034256, 0.20147133443970233, 0.12410964540322311, 0.2601160219637677, 0.13839411054505035, 0.09771010183612816, 0.11952905057114549, 0.12227117491420358, 0.1532394834794104, 0.19551221514120698, 0.1331361278425902, 0.15817812003660947, 0.1012313699175138, 0.11498666150146164, 0.10895769868511707, 0.08618817751994357, 0.09874986557406373, 0.11153797546285205, 0.15457591332960874, 0.11217654158826917, 0.12294819913222454, 0.19007898168638349, 0.11523893976118416, 0.12955753627466038, 0.3284096979768947, 0.153291804890614, 0.1145272572466638, 0.1334683725144714, 0.2243179944343865, 0.13223265210399404, 0.11840838531497866, 0.09243257838534191, 0.07676399298361503, 0.11760567838791758, 0.17987559403991327, 0.06886386065161787, 0.15327803062973544, 0.08274655672721565, 0.19627417816082016, 0.12420006125466898, 0.12778764765243977, 0.21721955970861018, 0.0654859458154533, 0.09845842418144457, 0.16287015576381236, 0.13920219062129036, 0.12247963677509688, 0.1126525699510239, 0.16336680098902434, 0.11029345318092965, 0.09575688789482228, 0.15320298465667292, 0.14182747865561396, 0.14478060300461948, 0.3531352977734059, 0.1343029917916283, 0.147260281664785, 0.22372484032530338, 0.15465207252418622, 0.12167482957011089, 0.10886700823903084, 0.13816845312248915, 0.08348877861863002, 0.20749947347212583, 0.08873384795151651, 0.07567235312308185, 0.15729196602478623, 0.14135484932921827, 0.15279707440640777, 0.10704933272791095, 0.12399482031469233, 0.1465896621812135, 0.12320196168730035, 0.1648686852422543, 0.10831917708856054, 0.17992286884691566, 0.14106202754192054, 0.1403355985530652, 0.21847948897629976, 0.2363236283417791, 0.15790692443260923, 0.14932750433217734, 0.07970480510266498], [0.06342080116155557, 0.012296630939090392, 0.03882351127685979, 0.058917122514685616, 0.05114958970807493, 0.062281248247018084, 0.021990976711094845, 0.05301326353219338, 0.05217330079176463, 0.037448159491759725, 0.021883118533878587, 0.04187110731436405, 0.026664154465834145, 0.027307305208523758, 0.03494521079119295, 0.013759473586105742, 0.02229646695923293, 0.03610708379710559, 0.006870328215882182, 0.09289323686971329, 0.03709856711793691, 0.02345037486520596, 0.08750566776143387, 0.04340910818427801, 0.07015288952970877, 0.0483137877745321, 0.040354862503590994, 0.10327469542971812, 0.0157130456136656, 0.022384539479389787, 0.04483962751692161, 0.13886875851312652, 0.04223164636641741, 0.02330323481146479, 0.02531984486267902, 0.030379932031792123, 0.015784636889293324, 0.024133590450219344, 0.03184362722095102, 0.03125819144770503, 0.03778529120609164, 0.04963335602951702, 0.01528466869785916, 0.04029267423902638, 0.04301738037611358, 0.08387132606003433, 0.024123001858242787, 0.02868265328288544, 0.023942207262734883, 0.03250016816309653, 0.050714242170215584, 0.06913832912687212, 0.03923121010302566, 0.018115424027200788, 0.040799857961246744, 0.03914982618880458, 0.05718859378248453, 0.06821111208410002, 0.030029886947886553, 0.025860740643111058, 0.05076139081211295, 0.05614778361632489, 0.01557609524752479, 0.006815036358602811, 0.02425218750431668, 0.0392061923048459, 0.05159012485819403, 0.09990789796574973, 0.04584456226439215, 0.008287457349069882, 0.05370169827074278, 0.049785956434789114, 0.022899113137100358, 0.022335810062941164, 0.09588691958924755, 0.022232508672459517, 0.037974023071001284, 0.04642973086447455, 0.012067778570781229, 0.02911589868745068, 0.050432144416845404, 0.024930432555265725, 0.027009549994545523, 0.053906935499981046, 0.03174554498400539, 0.022583401660085656, 0.047298451827373356, 0.1458202925277874, 0.012401314579619793, 0.09825509798247367, 0.06148487555037718, 0.006240780576263205, 0.04279606080672238, 0.05263274215394631, 0.00614657930782414, 0.04552743514068425, 0.03184802444593515, 0.03314599991426803, 0.05474192585097626, 0.058075193082913756, 0.016586583114985842, 0.02127715495589655, 0.05235677082964685, 0.013590786202257732, 0.05142623638676014, 0.03832757480267901, 0.02087379583826987, 0.03745897258340847, 0.06835635780589655, 0.013883319479646161, 0.017322882667940576, 0.054654007326462306, 0.0375885923858732, 0.0030280993541964563, 0.07162627531215549, 0.06760009448044002, 0.06607230185181834, 0.026024131875601597, 0.014811270320933545, 0.04620168372639455, 0.04101362246728968, 0.011102666539954953, 0.05153879050340038, 0.047783805275685154, 0.09103642049012706, 0.009369651525048539, 0.04678691169829108, 0.026416978471388575, 0.06630993011640385, 0.06282634087256156, 0.0416445110749919, 0.029583767136500683, 0.025598814463592134, 0.029684810542676132, 0.029571182167273946, 0.06202446144015994, 0.03807382337981835, 0.027003471805073787, 0.04399066623591352, 0.03056342433410464, 0.03343922988278791, 0.03378526736923959, 0.022380107002391014, 0.059746312981587835, 0.06424119346775115, 0.02119266144291032, 0.018566989347164053, 0.03210659611795563, 0.017583767985343002, 0.025722946083988063, 0.030970648185757454, 0.011411031682655448, 0.02280526856338838, 0.04622866079444066, 0.009565750133333495, 0.037382765149232, 0.033307673074887134, 0.0096899531854433, 0.03209630252968054, 0.037254540584399365, 0.028957069807802327, 0.03496554563753307, 0.018853768197004683, 0.020858745083387475, 0.021095477204653434, 0.0039300444132095436, 0.04623230102879461, 0.024973773979581892, 0.05112505430588499, 0.10106972273206338, 0.06829903431935236, 0.03179363986419048, 0.029392879332590383, 0.022663138006464578, 0.015319740741688292, 0.032667533596395515, 0.019404079976084176, 0.033299320202786475, 0.03236368349462282, 0.06191034881339874, 0.022467930903076194, 0.023952710507728625, 0.06879262189613655, 0.08210544503526762, 0.06499324139440432, 0.029789035907015204, 0.04178599781880621, 0.020800312086066697, 0.04004919414001051, 0.034552633223938756, 0.06582555259228684, 0.04845456205657683, 0.0397267124208156, 0.030549269722541794, 0.06416632561013103, 0.02434954614727758, 0.007409054142044624, 0.0096121816750383, 0.04084728490852285, 0.07562621380202472, 0.07394399508484639, 0.007009034688962856, 0.046251826934167184, 0.052846655089524575, 0.04897461833024863, 0.02912613475928083, 0.03910617306246422, 0.10416204429930076, 0.02085427549900487, 0.01762925421644468, 0.06736864830600098, 0.016818886469991412, 0.018336741741222795, 0.024859674340405036, 0.02617461715999525, 0.10900027569732629, 0.0638724870805163, 0.04440173441253137, 0.043692619728972204, 0.02552743098931387, 0.04284316863049753, 0.07740897868643515, 0.03811715367191937, 0.07687488468945958, 0.024913194320106413, 0.05306845334416721, 0.04085295120603405, 0.06752908579073846, 0.04939885591738857, 0.016398580410168506, 0.07659203736693598, 0.05512698546226602, 0.019440229989413638, 0.028820744701079093, 0.02901007028413005, 0.022584743092011195, 0.015587691304972395, 0.06222344236448407, 0.004054581895616138, 0.01826292216719594, 0.04117597469303291, 0.008593555230618222, 0.0707280242932029, 0.05391215279814787, 0.02222773666289868, 0.027955771583947353, 0.06054972123820335, 0.038244361494435, 0.0396010482654674, 0.062196250073611736, 0.03216118479031138, 0.07433699196553789, 0.060646838683169335, 0.030655849550385028, 0.048572923478786834, 0.04096490047231782, 0.030671553395222872, 0.012231870205141604, 0.008593125712650362, 0.050667913601500914, 0.0091518376757449, 0.08787943559582345, 0.05141679626831319, 0.040511348051950336, 0.02579716641776031, 0.011793734047387261, 0.0709079802618362, 0.04688234446803108, 0.02257484469737392, 0.07105499229510315, 0.04912411284749396, 0.03037929749552859, 0.013134606579114916, 0.05055039451690391, 0.05696930027625058, 0.06801341878599487, 0.03406773248570971, 0.03300384894828312, 0.030117382448224816, 0.006986436292208964, 0.010051945919258287, 0.07010825676843524, 0.014277988975663902, 0.011981300740444567, 0.037258570446283557, 0.03562495498044882, 0.019455603578535374, 0.01591580035892548, 0.06869605364045128, 0.048764753810246475, 0.0602446651464561, 0.02722221612202702, 0.08914817415643483, 0.014564297489414457, 0.059096566401422024, 0.02472436968673719, 0.04756599977554288, 0.0063344414684252115, 0.016960766552074347, 0.00587845341215143, 0.008191390043066349, 0.009507083359494573, 0.06605610076803714, 0.014660996548627736, 0.10254566150251776, 0.06114176212577149, 0.10872142112930305, 0.030100452204351313, 0.009892518683045637, 0.031792151858098805, 0.027962862804997712, 0.022073466425354127, 0.0779574629268609, 0.019604558183345944, 0.020309630017436575, 0.017967064995900728, 0.015665637220081408, 0.030099433606665116, 0.09037825424456969, 0.030015144184289966, 0.06435921721276827, 0.04363665808341466, 0.015310768176277634, 0.09150988844339736, 0.06939204715308733, 0.0027212182749281055, 0.04070337876328267, 0.019285200905869715, 0.005419690187409287, 0.04112475537112914, 0.013183643986849347, 0.010927160674327752, 0.03876381662848871, 0.11711530431057326, 0.037477340738405474, 0.0014895143908688624, 0.04651357499824371, 0.01773712723661447, 0.04599892898113467, 0.06132239715952892, 0.08575689324061386, 0.06887272189487703, 0.036853547062492, 0.06172261513711419, 0.027565368509385735, 0.0970667414367199, 0.055283693654928356, 0.013402597032836638, 0.08245599106885493, 0.025921923297573812, 0.02408107236988144, 0.008318295440403745, 0.10839568509254605, 0.2865827298955992, 0.12170441157650203, 0.14295965462224558, 0.13977144757518545, 0.11422959665651433, 0.09433380488189869, 0.19103540224023163, 0.1852698202128522, 0.08227953061577864, 0.11047653359128162, 0.1660948764765635, 0.09511385404039174, 0.09261001105187461, 0.12209772015921772, 0.11182509755599312, 0.17433433356927708, 0.10652397380908951, 0.1882297871634364, 0.18120268767233938, 0.14401157473912463, 0.11669671817799099, 0.11792354765930213, 0.17046067892806605, 0.1268533430993557, 0.17864787398139015, 0.20723534311400726, 0.11472725120256655, 0.09066307567991316, 0.08641318185254931, 0.17665899242274463, 0.21523109375266358, 0.1771563501097262, 0.12752215174259618, 0.11399729701224715, 0.13212842488428578, 0.12341300622210838, 0.1674732970423065, 0.11099401832325384, 0.1762310997582972, 0.14518198615405709, 0.1805961600621231, 0.12281402625376359, 0.0960155412030872, 0.20394798513734713, 0.14863174088532105, 0.19557394698495045, 0.10892040576436557, 0.07761064989608712, 0.08262817675131373, 0.13169642072170973, 0.18718377454206347, 0.13143272080924362, 0.0957659792038612, 0.17953808011952788, 0.17765951139153913, 0.10859518923098221, 0.17361148173222318, 0.04573462421831209, 0.11796727500041015, 0.09983890791772865, 0.1078281870286446, 0.11947250633966178, 0.07722290742094629, 0.14495757553959265, 0.12638630956644192, 0.19404642895096913, 0.17939965473487973, 0.1192620481015183, 0.058836217285715975, 0.13997611706145108, 0.13686237711226568, 0.09996260167099535, 0.1605461648432538, 0.1550431695068255, 0.16947124764556065, 0.10711720955441706, 0.19898329919669777, 0.12235882997629233, 0.12577713991049677, 0.12113823453546502, 0.08396092554903589, 0.06746903862222098, 0.16848157887579873, 0.130201616557315, 0.18240985024021938, 0.21632583579048514, 0.2464750804938376, 0.1056321052601561, 0.20297896291594952, 0.24664590804604813, 0.25377986195962876, 0.15733866195660084, 0.17254047357710078, 0.10712259754654951, 0.11896996846189722, 0.12491151370340958, 0.17351673915982246, 0.19930458976887167, 0.1601035479689017, 0.16313591884681955, 0.20071505627129227, 0.127052906609606, 0.10738766301074065, 0.204659778974019, 0.16747872956329957, 0.1427779471850954, 0.1876282467856072, 0.1634510199073702, 0.09861650905804709, 0.08952583084465005, 0.18406155926641077, 0.13441269606119022, 0.14036776323337108, 0.147595361340791, 0.1206170984369237, 0.21614007622702047, 0.07417586428346112, 0.08471910361549817, 0.0934530165977776, 0.1099369848088827, 0.07555180607596412, 0.07268238114193082, 0.10431625516503118, 0.16660802706610411, 0.14208494452759624, 0.12208876243676059, 0.09424372299690731, 0.20823875645874068, 0.15493160986807197, 0.1893879976705648, 0.05935834415140562, 0.13265827379655093, 0.07013753449427895, 0.163176232308615, 0.11618097749305889, 0.11163832125021145, 0.12441280530765653, 0.1385936443693936, 0.10808235776494257, 0.0939566305896733, 0.08013863494852558, 0.1391021194285713, 0.07492894379538484, 0.14146922912914306, 0.11656260467134416, 0.11163245086208917, 0.17817168234614655, 0.1173039062996395, 0.0821645199903287, 0.14796612347709015, 0.12312649269006215, 0.12644300964893773, 0.14044338808162138, 0.11417282235925086, 0.08546296565327793, 0.10788740299176425, 0.20261820493033156, 0.0858496394357644, 0.10346789873437956, 0.11715820786776021, 0.1251004051300697, 0.14503760874504223, 0.32149433623999357, 0.18825779581675306, 0.14892720471834764, 0.1705486382707022, 0.1238795870449394, 0.10557812885963358, 0.26091484003700316, 0.13518518273485824, 0.10552046398515813, 0.13865887915017083, 0.10976986057357863, 0.08681748906383291, 0.15968782652635127], [0.015693334171373863, 0.06639542552875355, 0.015073650138219818, 0.07088311831466854, 0.06074175194953568, 0.0587019813247025, 0.04050240146170836, 0.02941773385828128, 0.01910604831209639, 0.03173968201735988, 0.02166551712434739, 0.03038954469957389, 0.055564722715644166, 0.0353969338175375, 0.11274061835138127, 0.015934521034068894, 0.014376154704223154, 0.0281691130658146, 0.0032110853726408095, 0.059352477474021725, 0.04695740899478551, 0.044126750144641846, 0.012268529517314164, 0.029802073586324695, 0.008676403031131485, 0.016416082107753027, 0.03828188819170464, 0.04164566511462908, 0.030598054800066166, 0.03861600307573099, 0.020810991591133643, 0.10588442062726244, 0.016699482330295723, 0.070854820223758, 0.03535095034749247, 0.008035781156650046, 0.0489558345725527, 0.016924594274314586, 0.04995396753656678, 0.02912580079282634, 0.03425896167755127, 0.06286191201070324, 0.027497178125486244, 0.03592643392039463, 0.034072786511387676, 0.0320272382668918, 0.01955400493898196, 0.02752743734163232, 0.015942231948429253, 0.03106878237304045, 0.004894299727311591, 0.07293875605682842, 0.015117664133867947, 0.08840015609166585, 0.033679763655527495, 0.009146653774223523, 0.06758972667739727, 0.03490526840323582, 0.048890184189076535, 0.014958062492951285, 0.05296333554724697, 0.03910292245564051, 0.032932176036410965, 0.12088516959920526, 0.054624833501293324, 0.07308492946322076, 0.040022398898145184, 0.0803933474526275, 0.07548886453150772, 0.053415440779644996, 0.02349053989746608, 0.020366845892567653, 0.018938541870738845, 0.07561938604339957, 0.09859061552560888, 0.08809971986920573, 0.013501505836757133, 0.005106484386487864, 0.06205536446941551, 0.0946198582823854, 0.03809513415035326, 0.047192539932439104, 0.04383623643661849, 0.016744426793593448, 0.030111634514469188, 0.009736019219417358, 0.05780987899925094, 0.05462430286570452, 0.013087633269606158, 0.06096257427998353, 0.0626783120969776, 0.01722106186207384, 0.1201037252030801, 0.018484319662093185, 0.022434550955949817, 0.003114568371529458, 0.0033622344153627637, 0.06520575538161211, 0.04366006913187448, 0.023918467813928146, 0.06736242168699391, 0.05102041890495457, 0.021582138688245323, 0.034843484609154984, 0.09398400841746479, 0.04485644829401281, 0.03663991985376924, 0.06699600111460313, 0.031343553273472935, 0.033794373521232046, 0.024752918252488598, 0.08256855260697193, 0.021485833894985262, 0.018969307602674235, 0.05382744035159703, 0.02112845268129604, 0.007280241425178247, 0.02133372145181056, 0.030141572751745116, 0.03936533103114925, 0.03979639266617596, 0.053144256307859905, 0.08765087637584656, 0.03530305213644169, 0.0337607430992648, 0.04578841137117706, 0.0070039505135355284, 0.042394369665998966, 0.03331682746647857, 0.05702874630514998, 0.036066250831936486, 0.047916868643369526, 0.07928735445602797, 0.066470219171606, 0.08676190220285207, 0.021688612760044634, 0.00731693320631166, 0.04522032329987269, 0.07075886052916758, 0.016438973652839195, 0.0024830489383020904, 0.02777954490738921, 0.09608223059331067, 0.05808757581689861, 0.04847005067858845, 0.03378274406713899, 0.07458060194039717, 0.059652601994457655, 0.007762080804241123, 0.05589754997345153, 0.05591420747805387, 0.021124936756677926, 0.035995846992591396, 0.08285361152957194, 0.07926971360575408, 0.015210481760732364, 0.04009778254840057, 0.011955950831179507, 0.05671147446264513, 0.02085064825223526, 0.07882930833147839, 0.019854832644341514, 0.09173939019092359, 0.005336576605259324, 0.04980911886377726, 0.08282785158371553, 0.0323614088119939, 0.04886187496595085, 0.05304071928549092, 0.03189796727383509, 0.029222124139778316, 0.045592306269099936, 0.024922482298279647, 0.016469177207909524, 0.05701994814444333, 0.04178336319455411, 0.030897433462087065, 0.0421316122810822, 0.036986328414059244, 0.08341006643604487, 0.01855094040365657, 0.0031430714807356708, 0.03936335691832937, 0.039614162014913745, 0.06418879042030312, 0.08927688482799567, 0.01836336072301492, 0.026677568785089534, 0.014042951734154485, 0.0684278563130647, 0.011818843686342007, 0.03705477669427637, 0.049142833522637375, 0.0038814379149698652, 0.03929645230527967, 0.019747078367799986, 0.06487656835815869, 0.03359861351782456, 0.091923346335534, 0.08346126720425673, 0.057952011411543936, 0.013628329597850097, 0.041199626939487644, 0.04940116770740133, 0.05455750957480632, 0.042986358603229746, 0.027076269070676062, 0.049371132990927435, 0.02794068743241951, 0.028745479794451967, 0.07015329771093093, 0.054230311507126316, 0.015381829744001152, 0.03294105212262366, 0.06315903825452551, 0.015664592647226527, 0.028370724903652444, 0.08175846873200499, 0.025548964404151775, 0.04720162382000126, 0.03415664548811037, 0.0581577570119407, 0.035922021852456965, 0.04651176044717431, 0.012383037337713176, 0.02289096621097997, 0.024315860064234585, 0.02276839681144338, 0.04274264101695735, 0.05021839104301762, 0.02509497968276264, 0.02690866429475136, 0.1074686981155537, 0.062395798740908504, 0.0070999176296027144, 0.039333247987087816, 0.033538484713062644, 0.02372268369072117, 0.004849237911912496, 0.11223318972042762, 0.02597176036942983, 0.04346929636085406, 0.033771730595617555, 0.0801376107847318, 0.02283147936395835, 0.04137159739912022, 0.021021687316533644, 0.041180624248227105, 0.02214592972450191, 0.0671211643202696, 0.014245928196032764, 0.03580146367312409, 0.01806029544241028, 0.04580960710882209, 0.02617581016238546, 0.020300503456383012, 0.04493283384363167, 0.05272783353575505, 0.07226144240121357, 0.004333876649980084, 0.0394157377013471, 0.030212548044801224, 0.012656305389100453, 0.01365831329167122, 0.010587193028186448, 0.02513771440135315, 0.03826755732006859, 0.05647839185257908, 0.06528548430651426, 0.023427294072462246, 0.03609066377975978, 0.027280897738819476, 0.028636103925236966, 0.13742493989411741, 0.04347130758105777, 0.010271200462739216, 0.01761999406880932, 0.015582093656121287, 0.010380118983448483, 0.012579584945342503, 0.06012772864778526, 0.018408453615847975, 0.0837721380230505, 0.024980995076475665, 0.017460278322687373, 0.02961163849249715, 0.054824938779347576, 0.017769312325981446, 0.003343196472087584, 0.02887548180297017, 0.07171790086431429, 0.027878552973561455, 0.006660708604613319, 0.006789138187741628, 0.019299615269119386, 0.016325905598932877, 0.07139163790270686, 0.0756367522990331, 0.07433260587276891, 0.04320566324167885, 0.04093229792488273, 0.029687636269954965, 0.05809935370052699, 0.05274874725728296, 0.04057624515553471, 0.03135787301289383, 0.05671348568284884, 0.02681129080883693, 0.05001531717425678, 0.15647793392417952, 0.07331330314627849, 0.07764555310131982, 0.03304506783024408, 0.0815484112536069, 0.018892200314439833, 0.018322889554838184, 0.059733622256317176, 0.05673619169101585, 0.06551638871314935, 0.020123966933169868, 0.04939612481393851, 0.01909658963995753, 0.06913653312949464, 0.059004094800911844, 0.035543014455470257, 0.06391153889126144, 0.0514876602392178, 0.02676807183888741, 0.05215489924012218, 0.030778374421061017, 0.08674732642248273, 0.03840216806565877, 0.048168234061449766, 0.0384678926639026, 0.053301417210604995, 0.04693246170063503, 0.07379576592938974, 0.0023020987237032386, 0.06818142617703415, 0.031229355299728923, 0.042549760546535254, 0.04503199590544682, 0.027373367483960465, 0.0665967034001369, 0.09434950872673653, 0.07520966115407646, 0.061340572356129996, 0.08164737664628774, 0.018447254951752257, 0.03178968050633557, 0.050612935301614925, 0.012980552492081188, 0.16840510797919706, 0.16041496797697619, 0.11836428690003231, 0.23111073853215203, 0.17752386163920164, 0.20146597613347694, 0.1467617810703814, 0.13218583742855117, 0.15355258074123412, 0.10207164435996674, 0.10533988461247645, 0.14647648466052487, 0.11111961197457276, 0.12962729815626517, 0.19251306279329583, 0.09365372301544994, 0.11993715015705675, 0.13952928478829563, 0.22507971996674314, 0.26913658948615193, 0.16358601656975225, 0.18615036358824, 0.1293984494986944, 0.11733726583770476, 0.15922494902042672, 0.13520875334506854, 0.17217459477251396, 0.17058138182619587, 0.13103123375913128, 0.14877010689815506, 0.12117646998376586, 0.206521115032956, 0.1358975554467179, 0.19595269463025033, 0.206811576790642, 0.16769288369687274, 0.10609092321828939, 0.08516406567650847, 0.13109241641359404, 0.06332720891805366, 0.12181214915472083, 0.1681631975225173, 0.10164684645133093, 0.11619083321420476, 0.09430559584870934, 0.15169072517892346, 0.1941607493790798, 0.14309444348327816, 0.06345439818687737, 0.12894293409772217, 0.12853798863943666, 0.13612956565339118, 0.16741388069931418, 0.16871444997377694, 0.12292154860915616, 0.1329466130118817, 0.11732382554328069, 0.1585901455837302, 0.12556300061987713, 0.1021824470080901, 0.11576697783311829, 0.1041939714923501, 0.04903566739812959, 0.27925868227612227, 0.13325778068974614, 0.26611872017383575, 0.20802881772397086, 0.12524979945737869, 0.1376162507222034, 0.09112253930652514, 0.07252759140101261, 0.11530106494319625, 0.13663053017808124, 0.20471119496505708, 0.18903978198068216, 0.13234988175099716, 0.17779694229830056, 0.17956000316189602, 0.24379925220273435, 0.15800803463207558, 0.15155939472606406, 0.12895878637209535, 0.20273537520552054, 0.16181320388568565, 0.08277612389065325, 0.13624482118757442, 0.16912389284698293, 0.08126518543576822, 0.13965000252937898, 0.2007140766363591, 0.20119028311455622, 0.17494639760116115, 0.23011640907498077, 0.12313541330513544, 0.14126442605629563, 0.1338380214292556, 0.17702525714412332, 0.16558475384954363, 0.09094258333789185, 0.11074167327024043, 0.11920328484848142, 0.09567364118993282, 0.17861985048511997, 0.09030824003275484, 0.14931334415450692, 0.18437162856571376, 0.1473460442502983, 0.10665179390343837, 0.14823985722614452, 0.1305120124015957, 0.13636102667078376, 0.1527437288314104, 0.0932201677642297, 0.10437066201120615, 0.1618981797946617, 0.16049580270191655, 0.08403540006838739, 0.06298107124166563, 0.22122113092336804, 0.12699273327598348, 0.25582908012438565, 0.1464082664460875, 0.12886561715276912, 0.07460358625394292, 0.08706542575964704, 0.1380328182131052, 0.1199601789994631, 0.12659482337767258, 0.1888437065645121, 0.117694201762788, 0.1717783769709058, 0.1481758098816499, 0.1829259842634201, 0.30169021454639733, 0.1862436070223339, 0.1387258802424185, 0.08694632590049878, 0.2210721670417115, 0.2295998446061276, 0.14451776398345828, 0.23136332107242197, 0.20981280715204775, 0.18080225447192788, 0.148400962643791, 0.1368508441373706, 0.09455358449486084, 0.1490314319380559, 0.11837359343189746, 0.12351220168056898, 0.19966347754234448, 0.2132859840639867, 0.06966196626308374, 0.17844920104835182, 0.17230772122275084, 0.20712946832645684, 0.12098722974769771, 0.1140967893297784, 0.10000596535974182, 0.11871345996041782, 0.19678548822412267, 0.11794037214713171, 0.09514950681477785, 0.2215906314086169, 0.09914659545756876, 0.1698075741296634, 0.13952221954241395, 0.11556123965419829, 0.20299431052990258, 0.13816416350891814, 0.10601574365864508, 0.11290023205219768, 0.2010473603149876, 0.13357975403778255, 0.12943677400471643, 0.11294020412606187, 0.0809582405781839], [0.0268399803826469, 0.03531306370859966, 0.014090053064137464, 0.038186807942111045, 0.03482177678961307, 0.02660122590896208, 0.06289406926953234, 0.02151386481273221, 0.012337740354269044, 0.0841339721227996, 0.023857383494032547, 0.03847799700452015, 0.037358730696723796, 0.025006398791447282, 0.059261267524561845, 0.08598674379754812, 0.045955190507811494, 0.06183695782965515, 0.03354081134602893, 0.042041281776619144, 0.016389750708185602, 0.024113372492138296, 0.02806670410791412, 0.044515327535918914, 0.020058479822182562, 0.0879978081502486, 0.04151149965764489, 0.03649172780569643, 0.03822496917564422, 0.019165299527230673, 0.015825482842046767, 0.08935225734603591, 0.039744869063724764, 0.032062163736554794, 0.04145233193412423, 0.08829325714032166, 0.1056194442207925, 0.03666813630843535, 0.02881812677514972, 0.03492740295769181, 0.018578934214019682, 0.014818898671364877, 0.06040254593244754, 0.044633332727244124, 0.06522059091366827, 0.020622192932933103, 0.05595412018010393, 0.021900252868363168, 0.037657478533219546, 0.07489258598070592, 0.019127062223560642, 0.018158444472646806, 0.04120221703487914, 0.014130446306808153, 0.0734416204795707, 0.06453406720538624, 0.01574496167449979, 0.06623402325203642, 0.03285578677605372, 0.03979090819484554, 0.04044328939926345, 0.024070313083939254, 0.04937914818583522, 0.022588713582081255, 0.053700785429100506, 0.03295777270977851, 0.01628692429221701, 0.02161414195143152, 0.059768714709207416, 0.04969474648532923, 0.06257116081542335, 0.03470014620688744, 0.01540115341413184, 0.014643304675701074, 0.05061932890384924, 0.03223461288143881, 0.01588877505128039, 0.044102556130383164, 0.011277369030722184, 0.0381196918169735, 0.007452285635736189, 0.034967263709404506, 0.08136333446600474, 0.0627938199613709, 0.005526066852326039, 0.013839884359185817, 0.04593095196469221, 0.026313652961107437, 0.046213591485866345, 0.05077373643871397, 0.021479573879332747, 0.05164865062397439, 0.09785997855942696, 0.007066098423820222, 0.015400543925352395, 0.06748975196387619, 0.03299414165667258, 0.039261834826902486, 0.047309710207628086, 0.062278413242893293, 0.030420672228501644, 0.028463448834372684, 0.02402547066594707, 0.015930049594317097, 0.04909366623905953, 0.0786838770727627, 0.008821230367175303, 0.04579896471113898, 0.021804888747283258, 0.13874842668883502, 0.017352871000184678, 0.02245430507173296, 0.03677497217722703, 0.03702243760926649, 0.011328785021760268, 0.015452229872607859, 0.017431304877391085, 0.021143974699953105, 0.053248732147039846, 0.02888630046072649, 0.0007103832342636451, 0.05233174189925194, 0.04430222725204658, 0.04319939951528795, 0.041044659083127044, 0.06784189361496828, 0.02998256761202356, 0.039132018355303444, 0.039240201222128235, 0.05628350016195327, 0.03652396299003158, 0.024856251184246503, 0.01225826561494614, 0.07595571252750233, 0.012662104345508851, 0.056859035685192794, 0.0753455187077634, 0.013903141316404799, 0.050774790288414806, 0.0400670131057268, 0.054479632308357395, 0.06990318652242422, 0.04104679646843579, 0.03932491366867907, 0.042208357772324234, 0.013609640463982942, 0.0675473352021072, 0.027713981726265047, 0.0546548719285056, 0.03241121434257366, 0.05978007699013688, 0.006945492932572961, 0.025045890324690845, 0.023161323188105598, 0.04511629646003712, 0.04097129778529052, 0.09610465087462217, 0.03805554057180416, 0.0539526926149847, 0.013260737359814811, 0.010363976343796821, 0.06786996164009906, 0.024206912785302848, 0.03647974583145697, 0.005395630223574699, 0.02366817294387147, 0.027845781587529927, 0.06309867196250707, 0.03833581264188979, 0.06093262491049245, 0.04182245582342148, 0.06508848862722516, 0.02027996080869343, 0.005569269123952836, 0.01596325328137027, 0.026840705832000822, 0.04488949984079227, 0.0213242182508111, 0.05332260923751164, 0.04130443303438369, 0.042272119389963336, 0.030042269681871403, 0.09644528923672624, 0.04142495039559435, 0.032946187784546055, 0.03266312152845785, 0.0177675515806186, 0.010671991749404697, 0.024091087652777787, 0.07375762696028687, 0.014913820286892587, 0.03162811495712958, 0.051713276843656786, 0.029855480388505384, 0.04035248020954896, 0.08094362769043073, 0.013437208017421653, 0.02812796283251373, 0.03991603800386656, 0.07985990654560737, 0.012013750219921349, 0.05779027516837232, 0.0796344643458724, 0.013944307320343796, 0.06006841991620604, 0.0240125387426815, 0.017368005246680696, 0.018781011749524623, 0.02927481476945104, 0.017753107531461865, 0.015450238133780658, 0.04369633046735544, 0.043177636034670286, 0.09297412354499102, 0.06918308063177392, 0.03133058795356192, 0.049178441768162884, 0.02684864310140256, 0.07601462421007454, 0.05891633583814837, 0.04683514387579635, 0.02666871496330714, 0.0161190337894368, 0.00554736417143431, 0.027980321829090826, 0.03733904522960074, 0.01898893740872154, 0.04246152289852034, 0.03739581581612583, 0.07207405011286028, 0.02215344396972796, 0.05121771144331433, 0.04759265772008803, 0.0375749813974835, 0.09975111926905811, 0.01461218827898847, 0.03970237368775997, 0.012440991649782518, 0.06359463441185653, 0.04939086669764947, 0.07017623749561608, 0.05322285716829356, 0.02216380620666314, 0.050271198560949415, 0.06192614913743455, 0.04576116341922898, 0.057273209749837406, 0.04741711753013078, 0.004039171199110569, 0.018078904795402195, 0.03017174662090838, 0.017882805259432644, 0.023874207981862128, 0.020556117669912055, 0.022573833521164488, 0.02211482817074284, 0.05596129303739872, 0.008822525414871052, 0.06107273497036658, 0.08871427751728334, 0.03529544883349445, 0.06067216818337329, 0.018715669357334264, 0.04337008977017831, 0.06844194969744422, 0.040579009655630216, 0.03303303019492887, 0.04384823696454987, 0.02810777641570894, 0.07929942177725025, 0.01162556060080533, 0.04002703361038584, 0.0432253932376625, 0.012021452785120346, 0.011986189638264477, 0.035101117464364506, 0.03536211595928762, 0.04715948467492126, 0.09404358061146922, 0.023002382986305747, 0.03774870332563296, 0.0181775677629048, 0.05219179882260505, 0.06853423576103523, 0.013787095394945936, 0.08251568200648762, 0.022455882135545835, 0.04939389466017019, 0.07533946278272197, 0.02910450115450658, 0.02045183293375885, 0.029825299097865354, 0.04534248451818712, 0.01917559126013657, 0.045930220949230716, 0.016311409599438775, 0.019446443620836362, 0.04248298952006735, 0.03036587018868886, 0.01165934687378467, 0.06833186693256721, 0.0333151613449445, 0.06832387400208972, 0.03328803213662468, 0.021316319944162387, 0.050143311673309654, 0.00904188849744969, 0.019716687420441303, 0.06472583816503175, 0.018409121548756957, 0.029786199047521222, 0.020147060713497922, 0.014165121301630279, 0.037999248670530505, 0.01736576024995884, 0.06399332356522791, 0.01471741647037561, 0.07071447267662734, 0.01712668665277306, 0.01397713251208188, 0.0380516146105947, 0.06588367759832181, 0.06954029115149751, 0.04204562705126591, 0.04252853883372154, 0.034406214908813126, 0.033433047792641446, 0.015441378745890688, 0.05368202764657326, 0.022434526836150326, 0.005811786750200554, 0.006970496351641486, 0.0658656879386399, 0.027733993738365825, 0.04180022107902914, 0.0191177761007566, 0.033794636983657256, 0.05556814772717189, 0.03492012619972229, 0.08072156968410127, 0.02668809986062115, 0.048385961636085995, 0.03794382879277691, 0.04731513159640599, 0.022180048108566552, 0.04203763783152681, 0.03665988733700942, 0.011901312063855585, 0.029080787680868525, 0.0389402548171347, 0.058227979025105014, 0.1075831447087694, 0.16954601160250604, 0.12522282981080934, 0.16436371312011033, 0.15323381347116083, 0.12802995886886492, 0.13823907589539886, 0.21781813149573281, 0.21956851647701114, 0.148133032489568, 0.14707578375237063, 0.10139110978343524, 0.12088652030797675, 0.10981657134834677, 0.3150053828721866, 0.11038116019335575, 0.09975094115361571, 0.14847053156699985, 0.11011551585397683, 0.1422483506030403, 0.1974241211428307, 0.12258655799087137, 0.193996571470052, 0.09847653258475475, 0.2031293517211452, 0.12525682017439976, 0.18695315957302228, 0.1731320098042488, 0.07383927804767154, 0.18363610084634274, 0.13090993714286014, 0.06222496747795958, 0.18228806380648166, 0.11475351580884308, 0.09576125914463773, 0.12574169493746012, 0.22399346809834242, 0.31914211402181536, 0.1489475544076413, 0.1566828557406552, 0.0965112513222266, 0.09107467078138143, 0.12465817417250946, 0.11615106152021326, 0.12088993418728933, 0.131904311128892, 0.07399289519526064, 0.12175320778624155, 0.1389252211083658, 0.14712448348291218, 0.0959507368679624, 0.16413732839282602, 0.1261371112195775, 0.10048827971331775, 0.18699933600146323, 0.14930390403605998, 0.22692933009238914, 0.17163373238872737, 0.168744002294261, 0.15803870017407462, 0.08874972249031998, 0.1795379613758996, 0.10365487542003393, 0.0955469194741454, 0.15789705386850983, 0.16451779782073572, 0.15695547626819462, 0.11017126598744653, 0.13516144885215908, 0.17834573081927374, 0.08682580853928812, 0.12957131053553894, 0.16989361873129383, 0.05918356095207855, 0.09780261054402217, 0.1476155180716887, 0.150931567477528, 0.10655500300345011, 0.1408243176410906, 0.07658330971025862, 0.1265522389439866, 0.22582197154406458, 0.1537507341708988, 0.15579935861751437, 0.18007250066148117, 0.1434755660011433, 0.22179304476594552, 0.23829110636143014, 0.1257175751379691, 0.15274849341949448, 0.14969265583204105, 0.11065239290473983, 0.12495136703364551, 0.18909201433416456, 0.189998087589629, 0.18407638737699017, 0.1356192649109289, 0.115190418146085, 0.1029059816210065, 0.10673798693460412, 0.293015280039981, 0.20358698966447264, 0.1419905581860803, 0.15984585945261642, 0.09597625932656229, 0.10819749455549754, 0.12471517111407593, 0.10143340477952734, 0.10294328938471153, 0.09996484295697883, 0.172758472035639, 0.09523659784463234, 0.11789370590122417, 0.21730558946728706, 0.10944969064439647, 0.10994079944794066, 0.14281836454756558, 0.1381713623413816, 0.10961363106616773, 0.1363602399942465, 0.08706413442268968, 0.0787469967326615, 0.16958438063738868, 0.12531129381386563, 0.1464269240386784, 0.21001719462219626, 0.10445109597640112, 0.16304392222082242, 0.16250481130555272, 0.16073186503490433, 0.15367518353741616, 0.10453535942360759, 0.11599178920732811, 0.14329715369967744, 0.1540475635556504, 0.12248213781276718, 0.11108283855719492, 0.12675904581556097, 0.09039214724907652, 0.13444546930259094, 0.21072459494462237, 0.08908218238502741, 0.11685566394589841, 0.1760051751625724, 0.14915805717464536, 0.1236181877902709, 0.13457990193273872, 0.17305902700172737, 0.16290959349134937, 0.1830698421690613, 0.13263700384413823, 0.09963827571482398, 0.13980643241666257, 0.17050201655365527, 0.07598484924528748, 0.09781619926798157, 0.0740079533716198, 0.12506996223237365, 0.12496260314946994, 0.11131985083920881, 0.08139034121995792, 0.07609027132275514, 0.1446806060266681, 0.09170874691335484, 0.14021786424564198, 0.11737749024177901, 0.11059998243581504, 0.12133548254496418, 0.16027096164179966, 0.17723437951644883, 0.1047220392501913, 0.11512917611980811, 0.18013159045949578, 0.16102489462355152, 0.1484925881959498, 0.1130979105073493, 0.18858769530197605], [0.016490404486830812, 0.04731012581032701, 0.022203796834219247, 0.02932443661848083, 0.04041727712319698, 0.06780535768484697, 0.041093314284808, 0.05755214224336669, 0.03264071980083827, 0.01901567698951112, 0.014048003904463258, 0.05438781008706428, 0.04213905231154058, 0.03830947011010721, 0.015484677496715449, 0.04029649258882273, 0.04449216881766915, 0.048183551989495754, 0.035944857736467384, 0.04826027521630749, 0.041863088408717886, 0.024094685213640332, 0.044447795808082446, 0.07263334744493477, 0.06976817501708865, 0.023227274141390808, 0.035003228185814805, 0.03501878360111732, 0.06495600042399019, 0.022917722490092274, 0.016292982072627638, 0.05706330070097465, 0.069955819635652, 0.041252623705076985, 0.03980840432632249, 0.07277920914930291, 0.042248890167684294, 0.0472219104267424, 0.0360081740655005, 0.02408947162621189, 0.09706832221127115, 0.02708924366743304, 0.006003842045174679, 0.04407071057357825, 0.04324959096265957, 0.019226387557864655, 0.06404050931450911, 0.006203829507285263, 0.0793405738659203, 0.03482331303530373, 0.05581140889262315, 0.007197655231721001, 0.059304037495166995, 0.10896108287852257, 0.01681941153947264, 0.025947514404833782, 0.045372660242719576, 0.028572867377079092, 0.03638266178313643, 0.023459516269213054, 0.020096641055715736, 0.04103292572835926, 0.01796872184058884, 0.027240677045483608, 0.019428166378929745, 0.027120799786644056, 0.0727687003382016, 0.029349985052249394, 0.05484299152158201, 0.06954907075851224, 0.020470371782721486, 0.04099422643776052, 0.03601155083742924, 0.01680165751167806, 0.02351147402805509, 0.011524629444465972, 0.014073445654503303, 0.025775356552912854, 0.033440688202972524, 0.013567324131145142, 0.02009183564950945, 0.021726193263020832, 0.014132709857221926, 0.015686975821154192, 0.02178084872866748, 0.039692688660579734, 0.033091782315750606, 0.04611836280673742, 0.017861327505670488, 0.06158815282105934, 0.04256287058524322, 0.060445909621194005, 0.002066159772766696, 0.056354631306021474, 0.005127617041580379, 0.02909800550696673, 0.02538940079830354, 0.02941793794889236, 0.022223122359719127, 0.02480656996340258, 0.05802654901344795, 0.03146717281197198, 0.015352459249697858, 0.03146013725199737, 0.04500645489315502, 0.008251533690781798, 0.05616425187326968, 0.0431237857992528, 0.0355871573992772, 0.0128031402346096, 0.023056496684148442, 0.02954447041702224, 0.006477013603216619, 0.05568678003328387, 0.08646046408102848, 0.018986356590176, 0.07519274018704891, 0.02016651054873364, 0.028678345115622506, 0.032030295915319584, 0.051716134112211876, 0.011858356556331273, 0.13618452911032364, 0.0389904054463841, 0.017604236418264918, 0.06876338127767667, 0.05603646888630465, 0.02558997362939408, 0.03434223064687103, 0.06942973341210745, 0.0589723011944443, 0.04476434776734095, 0.022214411401364487, 0.017456398745707702, 0.03653246800240595, 0.05534244577575009, 0.004628499536920572, 0.03144384711049497, 0.02992888435983332, 0.05788889175164513, 0.029238119277579244, 0.02484012617060216, 0.050769821609719656, 0.032747726363595575, 0.055776186563889496, 0.07159497152315453, 0.043517706653801724, 0.054588857892667875, 0.040361222709179856, 0.02988468204421224, 0.03977415050030686, 0.012152536473877262, 0.029906560557719786, 0.02601936172140995, 0.040111634734785184, 0.016057711982284673, 0.011810887863248354, 0.03547343068930786, 0.03758596889383625, 0.03248486507800408, 0.040793787193251774, 0.032666464903741144, 0.03614351953729056, 0.030236421080189757, 0.09617890274967067, 0.0834635530191008, 0.07289839064469561, 0.03397321997908875, 0.010597326127026463, 0.051430949024506845, 0.03715546758030541, 0.015298676735255867, 0.015334975178120658, 0.015291337822418427, 0.07896317692939192, 0.04095466996659525, 0.020241179881850258, 0.07196698046755046, 0.10023097711382434, 0.025084003318625037, 0.030634742870461196, 0.04300206986954436, 0.04595824815623928, 0.08197017377824523, 0.059478215844137594, 0.03780759645451326, 0.03901298528944608, 0.03866677710902877, 0.05110340214741882, 0.0018568400355434278, 0.032145811201189645, 0.09143185161519796, 0.027554787338885944, 0.02996927018102724, 0.05210549818002619, 0.06599663247470744, 0.07089779799571261, 0.07099484122591093, 0.04255579420714639, 0.020263544502086006, 0.09167061536572874, 0.03327980542962905, 0.05001917634217534, 0.059872559722862206, 0.06285706578637473, 0.03364129443070851, 0.03934660664526746, 0.024053054439718835, 0.0342182771419175, 0.04457660295884125, 0.007970663264131872, 0.02034608431131346, 0.014150167953630444, 0.08104505701339804, 0.025276911619585007, 0.02262166864966275, 0.053484879827010445, 0.01810897476389073, 0.06294222723226994, 0.0574637672980316, 0.04355747834779322, 0.027022474496334326, 0.03523212508298457, 0.03636906934843864, 0.04663001796870958, 0.08645405192510225, 0.06039353625965305, 0.019415371752984356, 0.032747013901825994, 0.06991276022745296, 0.020226284977979958, 0.0038571956611122005, 0.04214031396259088, 0.02906411718868185, 0.054477658195537515, 0.029974027347634546, 0.016705111520423088, 0.032014699681894854, 0.040809494748828, 0.024872925387171563, 0.031004135744296946, 0.022030557302059606, 0.082932961959159, 0.027307991695124656, 0.058966753640561365, 0.02489664071617881, 0.06450162793044001, 0.028531164243759122, 0.0653994113963563, 0.07261681239469908, 0.06391820337739773, 0.07854884330299683, 0.05140825785929337, 0.015349028672062559, 0.030996721689007245, 0.05193105636863038, 0.05068680868134834, 0.018840467055269983, 0.025993510862463154, 0.04679824429331347, 0.007201833523140522, 0.04909020412014797, 0.06956473749596626, 0.030466657553915866, 0.03713564481586218, 0.04682504695665557, 0.029305163043318316, 0.07700069356360473, 0.04407536755024921, 0.005189006569707999, 0.026041702221846208, 0.01934271364007145, 0.007019384402155993, 0.030604081039200537, 0.02935125226940727, 0.023540764741483144, 0.07676774082938209, 0.020082948431081604, 0.015917592645564582, 0.06495585941593163, 0.05117726439493708, 0.0621208552911412, 0.016629965357424226, 0.056025199373834766, 0.03229312009352725, 0.04739949894428719, 0.09084781107958406, 0.044845201045973226, 0.026301938160031568, 0.011989813174295705, 0.02093606388370972, 0.0016730962147448736, 0.04052800184581429, 0.017021910243784077, 0.02207798981544329, 0.025832772807916626, 0.04303232723032124, 0.017489418751210906, 0.08932505763368681, 0.05056026879174169, 0.013977394119137898, 0.015043611711007543, 0.08492548746289685, 0.016673722384439316, 0.06836935281171463, 0.02997544484969694, 0.008310977864312008, 0.016726661633583717, 0.020597024849848822, 0.22616331494646147, 0.014829134743195027, 0.03389752462680917, 0.04191542466287501, 0.08518233735230751, 0.03600830394134391, 0.043795351521112025, 0.020246055792085826, 0.04432030596944969, 0.0884168544143904, 0.024256981778307818, 0.048999112914316356, 0.04311716584197711, 0.12962945038452744, 0.019304159068269655, 0.03236244410800282, 0.006083883135943324, 0.061413087605615146, 0.015954297414282337, 0.030730094003956765, 0.06655984092503786, 0.06644152032095008, 0.026266441236657556, 0.04886491034994833, 0.015792874728504103, 0.007422066310027731, 0.02172340093238745, 0.026051509703393094, 0.03107955835730536, 0.04940169463225175, 0.013821397460560547, 0.041825353910098784, 0.05302874473272823, 0.016043228970374912, 0.04767817539686803, 0.016066714233602397, 0.07055117792333476, 0.060705835712724365, 0.06598614592803642, 0.03987383948697243, 0.07585092127555981, 0.013611020858661504, 0.004279967506590765, 0.12183006459963508, 0.08582822847529314, 0.1707227758015506, 0.12751550209941342, 0.10493395951925777, 0.19173609354766086, 0.10522963857511058, 0.1372387053561397, 0.13893758528865874, 0.08168094398570247, 0.08789041938143782, 0.15180321992374957, 0.197670336056035, 0.09665916135418229, 0.118131927883951, 0.19826408388325945, 0.12043430004268885, 0.15127984253922477, 0.0955444629653357, 0.15899690188234672, 0.1082883556955494, 0.14335947926156223, 0.14708283415529877, 0.09973589782021008, 0.2216476877219975, 0.1393723502405919, 0.18813448055880144, 0.10383853470557369, 0.1018214737996459, 0.16087812749901786, 0.08288563520181924, 0.09559849873767234, 0.13666134414961562, 0.1507337999646552, 0.12364711670670658, 0.15776385320350528, 0.06897795843542553, 0.12626030773390085, 0.11026606051018462, 0.1383291429374367, 0.16539568430744112, 0.131698795594275, 0.15500128269195557, 0.2379382448270917, 0.12435072465450503, 0.13281485211336985, 0.14583756972569972, 0.0633344597008545, 0.14320296031655744, 0.12355096405372024, 0.20947541197529063, 0.20509883353952318, 0.16974205733276904, 0.18147673312341794, 0.07351971667958423, 0.08466146842692979, 0.13484965777024627, 0.1668041618540883, 0.17851982382126153, 0.06628494200413115, 0.11827307695057243, 0.1377167078317143, 0.1125165045959875, 0.14967007969971746, 0.14246772945625708, 0.0756243806972634, 0.1426690592779778, 0.11588623354327865, 0.14169513888191432, 0.13888904883060604, 0.18092985934345052, 0.14753107650903985, 0.23525064607383683, 0.15148114267503843, 0.14271308347815648, 0.20705655973870307, 0.116614250728162, 0.08264626289019361, 0.08762386220041662, 0.1683157088700682, 0.20017468370497227, 0.09246286543202586, 0.16017406684113666, 0.11267411449807696, 0.08631909979158081, 0.12440405538654886, 0.1545064928359352, 0.10617339808959514, 0.0566078149859095, 0.17109723383327946, 0.14414590346859768, 0.23850244033383206, 0.0954822487256024, 0.20324244018411264, 0.07546933862613514, 0.1624524750513956, 0.10835209875949658, 0.18211964081274346, 0.11043962658732198, 0.08473584646708332, 0.1589432594482787, 0.15000912244431674, 0.0799989553343039, 0.22651187202427536, 0.12798304029274732, 0.11367869301466271, 0.13112235465086997, 0.11370221909601241, 0.16416794940596446, 0.10352007171604782, 0.1658829636289738, 0.15216142492135987, 0.1412126241484657, 0.1305037597194314, 0.1898380953934975, 0.08597768959589303, 0.17730280553223565, 0.11002190134604461, 0.10075273661641404, 0.19149917032336816, 0.056596745853312314, 0.09533027914585546, 0.1871594914700836, 0.17583464446943253, 0.09430750316823833, 0.12817902665119618, 0.11450288511696272, 0.13316179130924866, 0.14434030163101852, 0.17057065037079155, 0.10567419245489873, 0.16855799040058628, 0.09046734907315113, 0.24877198302419856, 0.15777117077959701, 0.164961394330021, 0.16638288914691657, 0.1968517471686937, 0.12781861005350947, 0.1463520561810583, 0.1353850431041792, 0.1475898249191232, 0.13661815115483478, 0.1040835324965883, 0.18456184101523831, 0.11054205780965276, 0.22520215949043632, 0.16542367811780423, 0.11276392178842798, 0.08872765843989328, 0.15595664939610288, 0.08575113417464308, 0.10221458942396566, 0.1181229404755868, 0.19335602381033823, 0.20935923617798835, 0.16621364979073405, 0.09817978483624756, 0.1175567411701195, 0.08320232445839792, 0.09865795058431104, 0.10314893108443357, 0.17426644189981744, 0.1748406860860996, 0.17775794985936955, 0.1449183901422657, 0.12586023076437414, 0.1418051400105469, 0.17336246150080115, 0.16295213339617476, 0.14366144430823624, 0.20674297265941277, 0.22199847124284133, 0.11276848599663936, 0.213393832964357, 0.08509860825142823], [0.03989761789853219, 0.03605241348850541, 0.02399488861556165, 0.0193464429321466, 0.05523520914721303, 0.07211057862150483, 0.08928147130063735, 0.0618450472393306, 0.05541366968827788, 0.02304557041497901, 0.04174991830950603, 0.033790848319767974, 0.04724685401015449, 0.02273068643262377, 0.027910099815926515, 0.026024252474599052, 0.038498168578371406, 0.04722640413092449, 0.022500318227685057, 0.05949979749857448, 0.011154875701322453, 0.028250840223336127, 0.024634096698719077, 0.03944577241782099, 0.02808240238664439, 0.020185683933959808, 0.03880320982716512, 0.06408598070265725, 0.018101833447872195, 0.024173150632122997, 0.02649756643222645, 0.01069689173164079, 0.03893935681844596, 0.011704565931722755, 0.06362351879943162, 0.012454286297725048, 0.03464136068942025, 0.05228707203059457, 0.052612652216339484, 0.03233331852243282, 0.04272726000635885, 0.007180550583143486, 0.04134863535000477, 0.018139475178031716, 0.0134680275550636, 0.010756117899290984, 0.012317001037445152, 0.036046936438651755, 0.06668665169854648, 0.03225145963369869, 0.052718289516633376, 0.011732275870599551, 0.06511893894639798, 0.013692796255782014, 0.036115054463152774, 0.011308986377116526, 0.038547881340491585, 0.025802277959883213, 0.02740571213507792, 0.03860376506054308, 0.0609171659743879, 0.026269183472322766, 0.0630255407304503, 0.04200410759949591, 0.03255327625083737, 0.03208385671314318, 0.020675981941167265, 0.03071570747124497, 0.018525939303799532, 0.03942272131098434, 0.05428027288871817, 0.04608492163242772, 0.0031725050575914793, 0.0090443431508902, 0.06227772304555401, 0.006266587834033999, 0.03543933642504271, 0.04641434985387605, 0.030663313700642902, 0.05066707126388792, 0.04117921787837986, 0.06718406875734217, 0.015740742564958055, 0.048069472759380005, 0.02253426591778407, 0.027424768632045016, 0.05928376573137939, 0.012477377294999314, 0.11747627751901746, 0.02965015224617673, 0.016551755979890004, 0.04374587624624837, 0.04707565909484401, 0.013438136629702058, 0.04417389507580083, 0.04087133791472297, 0.02729798939981265, 0.06095817334426101, 0.015212331563816406, 0.020467733447731007, 0.03571501831174828, 0.03496716351946816, 0.011485215836728457, 0.00877762919117231, 0.026663660937629174, 0.03292529261671007, 0.05181176355108619, 0.08269773825304583, 0.05851904563314747, 0.06578179556527175, 0.09312793365097605, 0.06092352246923838, 0.04830193196539767, 0.04392736103909556, 0.04190200663288124, 0.06656922167167068, 0.06586200688616373, 0.03706705552758649, 0.08795880086836405, 0.02043616805167403, 0.05094360290968325, 0.057514129439368844, 0.04995108429284301, 0.06922429209225811, 0.017321984669251833, 0.03742405824596062, 0.016870276485860813, 0.016782994352979586, 0.040617245103931054, 0.07016324991127476, 0.07775850797770545, 0.043447922507766634, 0.038065704284235835, 0.07472014054656029, 0.037803666782565415, 0.02157165956305107, 0.10412286632345058, 0.025035598591784947, 0.07685366668738425, 0.04089552821824327, 0.03504842869006097, 0.010218582192464964, 0.06064810404495802, 0.023697018368693534, 0.059546909033088014, 0.07523825610405765, 0.016837328839756083, 0.06106464556069113, 0.045060861739329994, 0.04017484716314357, 0.04410609617480077, 0.06259760353714228, 0.01145610973253497, 0.012547921214718372, 0.01968580294487765, 0.05441205976239871, 0.007933456618047785, 0.014174794268910773, 0.01140042546467157, 0.05378653688239865, 0.039353293395834044, 0.05587557869148441, 0.041142915724776685, 0.023231623126775958, 0.019872757366101723, 0.04900659747363534, 0.04866180679528043, 0.04333746495831292, 0.03570401226170361, 0.014375608297996223, 0.026836247379833367, 0.03375224921910558, 0.016485142659803387, 0.07964131436892785, 0.05629156359646004, 0.019224105453758966, 0.03406533163797576, 0.023551045342173893, 0.024206107555073686, 0.019550049291865434, 0.01961036177817732, 0.019320293358759955, 0.020185476132610347, 0.06303312547970563, 0.035161891937605105, 0.02550398468883941, 0.019237740561948158, 0.02793432166072307, 0.020155600977886934, 0.03429599113587756, 0.01234307082995656, 0.040560704583185725, 0.01409571750627947, 0.038561169494641945, 0.007187775390775641, 0.019803568793577142, 0.07146139236283489, 0.008191274082491873, 0.030562786087102722, 0.021503048010345083, 0.04963812061760109, 0.03219850368623156, 0.023548592544102576, 0.06413256531232037, 0.10363945359131321, 0.03268144886533264, 0.11256940488237888, 0.016248258398263715, 0.047184164795908146, 0.010954507888527587, 0.0049536905589775415, 0.06234328437130898, 0.024755805206950754, 0.09964091776055284, 0.043788568291347474, 0.04114733150345273, 0.034616840130183846, 0.03935951259336434, 0.08243663585744798, 0.023554039908049162, 0.02130663862772053, 0.0315641715133097, 0.0046604879571532365, 0.05520001650438644, 0.07029137428617105, 0.0669102682149969, 0.04798955087608192, 0.006752395847797743, 0.010927978892141255, 0.0032366917866966105, 0.05265008243441116, 0.05685100193659309, 0.03195208468241617, 0.08153541624778882, 0.0549170912563568, 0.0207059405875043, 0.03207146284694318, 0.04192689826595597, 0.08474437374388799, 0.06619099352974445, 0.03065212025830988, 0.04203968986985274, 0.13344595965463668, 0.05461903732793871, 0.04312169665354304, 0.05945445969700813, 0.024442785870633088, 0.03621108837251086, 0.04899835592368618, 0.023150259621615987, 0.016332685117959045, 0.0507024420221569, 0.024735104852879886, 0.07506549154641107, 0.015298676735255867, 0.030860300103086047, 0.10765447252197191, 0.1138540699321311, 0.020269062370061874, 0.05343487020581961, 0.030394017994694877, 0.01650621779845096, 0.02900205694459146, 0.01967508262168849, 0.0789665240154136, 0.03625315330282319, 0.035040695511270314, 0.047758182627148926, 0.08446226114756428, 0.03392784135940019, 0.008880479726940393, 0.030471373902400956, 0.032226820330834016, 0.04874609621765558, 0.01584349291078979, 0.02962046262837248, 0.05909404681005981, 0.020855362745351158, 0.04687824781285599, 0.03487361209408846, 0.06788922779378481, 0.05146558876731433, 0.05364157688745763, 0.10424774751299992, 0.00849723095598165, 0.05372565850848332, 0.023403445156873204, 0.0629882923385594, 0.03566481202142313, 0.041876825562212616, 0.01996451279410394, 0.06654192548012361, 0.06880371700390242, 0.024833906973071862, 0.13257938349852338, 0.05140903711435385, 0.03514054405968636, 0.0765494751976803, 0.02888175851694541, 0.05092138671898283, 0.01888308488560142, 0.09026958156027831, 0.06355279954732396, 0.028076418821001425, 0.0397088526369771, 0.08480743403197266, 0.033303865857305937, 0.04546250835119281, 0.00952019247051794, 0.033505217943456955, 0.022123294220364187, 0.0477529653289821, 0.01794072988559492, 0.00836229923152132, 0.06339492989354767, 0.036287466500652954, 0.01754403525410453, 0.051832911049132235, 0.08056626043980941, 0.015363239872385748, 0.0654251713422127, 0.0589760416187346, 0.002518200299164164, 0.05598758361884393, 0.009335345748695545, 0.08133693627314642, 0.03300812742963899, 0.006651330177191994, 0.012930419488839107, 0.01469702410759055, 0.018709103205765132, 0.04741277967696078, 0.005221317824180005, 0.026062881261168513, 0.019899099897884298, 0.018118027110176627, 0.031026327815197874, 0.06012549107254017, 0.06867705465992913, 0.019812283462670166, 0.04691561494837515, 0.050622976559679955, 0.03606730839237571, 0.04964896710589528, 0.057937168458011, 0.026474164660612587, 0.024418740285909735, 0.0722876624786295, 0.02337338446523063, 0.0608699356962461, 0.0219198771083029, 0.03999931439466309, 0.16774464107584208, 0.09640521326218732, 0.049822073051473126, 0.12172583737992682, 0.10614345985231921, 0.12980133178643882, 0.08817546346108429, 0.1877550352946855, 0.14356431202031672, 0.15486395568586886, 0.1689142658142373, 0.104446873156121, 0.13360089040361345, 0.10634576188749634, 0.1241573209699709, 0.22197481157490984, 0.16538947995286435, 0.0989256877801381, 0.09207047711242922, 0.11926163249881938, 0.17408135026926175, 0.12077881241566502, 0.0965980751789175, 0.08091453550150618, 0.09624236379750073, 0.09053435016539879, 0.08064971494604833, 0.18527602456742898, 0.23061176296323538, 0.1273406224208884, 0.21929485694272444, 0.13654326845426112, 0.12461735605029389, 0.1488287068787031, 0.12829266430344433, 0.14478796510957181, 0.10551941755693406, 0.14994186902185902, 0.10465347222634591, 0.10083106288220733, 0.11229115145397373, 0.08131991140544415, 0.16634073515888304, 0.09898766453261487, 0.17444083176087588, 0.0890860341314692, 0.24098346970276907, 0.23406283871736377, 0.1851510172127746, 0.09817182159167714, 0.14530672633554786, 0.16782287828391418, 0.1250538873136975, 0.17798236047383398, 0.17122786666732281, 0.15166601166129112, 0.13683172641322017, 0.12863951444160193, 0.16058110515587032, 0.1070250422344543, 0.145576526701916, 0.09596334595698863, 0.18943760282127187, 0.13776200852589682, 0.12130722898291424, 0.08960142600699328, 0.21875141188502312, 0.19974400056526065, 0.07262303901370615, 0.11795151178375818, 0.08356827747775242, 0.09344409598270431, 0.1663196730078198, 0.10094999946886674, 0.18988476163940504, 0.08470200453302823, 0.09493688892689534, 0.17713439738145098, 0.15533612488070503, 0.1758927249466069, 0.17338514153379947, 0.1937880873447284, 0.12679919600486755, 0.16754158947151154, 0.12556678557302803, 0.17845237744040787, 0.16202723927563056, 0.10047687290352769, 0.20595651876647025, 0.23584587819641456, 0.051911233604187146, 0.16351192054571584, 0.16152664582477883, 0.11745700394385494, 0.07205716625321656, 0.12816424306947738, 0.10440547615871765, 0.14209144574124366, 0.11742787464754656, 0.14684460475109518, 0.16128899529576302, 0.08922680470277555, 0.10021035282989033, 0.10391041170805693, 0.17650415073148906, 0.12218271833262406, 0.17659454431850463, 0.21452787914313376, 0.1269410501117818, 0.23247740347869694, 0.2290587150491774, 0.11468070370028727, 0.11251476797042415, 0.13262777152704075, 0.13296286604600027, 0.15498508902965114, 0.1933566472143866, 0.08824575968901627, 0.19449191051535308, 0.18655955413123593, 0.11680851530400105, 0.23083704931195825, 0.1362775795860216, 0.19670585577841848, 0.08919495914597064, 0.24477412254782394, 0.14911415171809494, 0.07090471481205896, 0.14577760419342667, 0.11736918560927734, 0.15176683984464034, 0.11111127023468725, 0.12005299198790453, 0.11501950895763002, 0.11715835629729554, 0.07615411086590029, 0.1747991406591609, 0.06167111379909329, 0.19908666552510113, 0.17851209064247087, 0.1086861320072785, 0.07689649602980353, 0.2326627029106021, 0.11410778053686954, 0.10808953433297575, 0.16709091287339106, 0.08947016234742478, 0.13597459037555382, 0.1385184351238422, 0.16416312544606626, 0.19516828906489536, 0.14028479112312198, 0.09270357360946946, 0.09540438259136863, 0.07289843517355621, 0.14101273409323767, 0.1949285456794314, 0.0579483897308819, 0.10371150128776208, 0.329854748561047, 0.14081941946642473, 0.09165798401227221, 0.18500065809348598, 0.08914766949601471, 0.09470996985328384, 0.1582461007637903, 0.11295514355879277, 0.18785831256536767, 0.10148403409402817, 0.134613832924515, 0.11070713371736929, 0.2337362343678251, 0.08936076977988705, 0.14632554666604847, 0.19689399021444842, 0.1696606437326409], [0.034848683353629895, 0.02782344108709367, 0.029323238049983047, 0.09631039647501893, 0.01502195862485678, 0.04470802246942185, 0.04532929655397311, 0.05709207005565986, 0.046156635362422094, 0.03406964722671546, 0.031185568586806767, 0.019739937051781453, 0.019945042549807113, 0.0372209361376008, 0.010898238251684234, 0.009917612551362254, 0.04179361967544537, 0.03819535006186925, 0.008749338521738537, 0.03710971417604014, 0.021927025845798198, 0.003966356307500973, 0.035795203657471575, 0.031112641445361078, 0.032741748364060186, 0.021968573128106073, 0.02085589338093996, 0.03300355951068923, 0.008456092782580527, 0.044740769735653885, 0.058334725836175494, 0.010804489229485625, 0.0389174374868162, 0.00035038551516208827, 0.08803531629382633, 0.03583306803193409, 0.05701840447727591, 0.009298160439357162, 0.029645430331584066, 0.014926195599400671, 0.0038938586840231437, 0.01744973982567899, 0.039395848143612966, 0.025853447186818812, 0.0326390536793042, 0.0361487553891493, 0.010371603766543558, 0.019388849250390194, 0.028775863320333883, 0.04687212138378527, 0.03907564481778536, 0.036215570944477804, 0.01806392454454908, 0.042775477340910584, 0.04009705895441584, 0.07266475513461046, 0.029428294619719964, 0.040179823263315484, 0.033903884832398035, 0.02607173508295091, 0.10180289784329943, 0.0574966110434616, 0.08699106998392381, 0.028693356907751877, 0.03520931517414283, 0.03413364633161109, 0.04703967977548018, 0.02686285337404115, 0.05477706654346548, 0.03143019901472144, 0.06316205879556946, 0.020705808856291696, 0.014999827781139174, 0.06426302745239809, 0.052100399625487626, 0.046213097957661375, 0.05178018145670649, 0.02699501874303678, 0.03622259166149888, 0.04935925120662432, 0.019122280937153846, 0.014033876195753692, 0.0472663057007594, 0.02063606181764044, 0.04242025206622202, 0.04036254373204429, 0.011298946974420687, 0.030174423918651883, 0.02331379186216509, 0.014571937899745535, 0.013673784287675517, 0.060947605161345564, 0.035031055012950674, 0.05387602504924871, 0.05861440047738142, 0.03674106716061942, 0.04167828992649447, 0.04313209414249286, 0.03380211412149947, 0.04756089751026593, 0.02675101914064726, 0.08812087849946693, 0.029046622912574094, 0.024832350318320096, 0.014702097614645027, 0.03275262824899983, 0.024356132707907818, 0.004421530784384231, 0.03542224476404954, 0.05444312235340476, 0.016645728574076202, 0.025727133652253542, 0.059898471808992326, 0.0649344410339836, 0.015623874714947306, 0.07014663322479464, 0.03151675940898713, 0.02946443721157266, 0.06179940144647844, 0.06605798582313582, 0.005845058158229222, 0.034998281771549955, 0.01932679642777657, 0.03621334821218625, 0.06782844589906745, 0.02826626576279523, 0.03946481221646536, 0.04111001631827094, 0.08502529890392907, 0.015374762642750284, 0.052135595979052596, 0.04151365559664555, 0.015458026973647065, 0.015460658814845374, 0.022179786501510534, 0.07082941650878638, 0.010863779407372931, 0.05693558450730052, 0.043163279187865555, 0.03996001396444626, 0.04203598655294627, 0.031216735078487545, 0.023328727584157605, 0.1307752076536417, 0.0290253084313008, 0.020868754800176248, 0.07640529074706137, 0.035506968342815526, 0.06379443540936336, 0.019347420711710583, 0.04792062391061336, 0.033163744665216655, 0.045485834052669816, 0.008382316809729673, 0.0058501808325672755, 0.04505216005782131, 0.06467427374445833, 0.014753091509192018, 0.0343781802803278, 0.02807101969665382, 0.06966011089389212, 0.018396356608718634, 0.07121327755157836, 0.023203868659038562, 0.02186484129197197, 0.02844721806468442, 0.1028565620072186, 0.046309710742207244, 0.05878962896531448, 0.0009924444020725787, 0.022909852013981435, 0.02755357763817301, 0.0012004515815533523, 0.04303905108827166, 0.05387851866544224, 0.02096050466207089, 0.028950160412932746, 0.0024957535788416862, 0.03306829705252312, 0.028262152409297414, 0.01027020598485251, 0.06775168556487188, 0.021149229105503764, 0.03774630618863739, 0.05867461833986454, 0.0048463991970493225, 0.019989526881545316, 0.0573882092430722, 0.009470773784414632, 0.020505820466496516, 0.017518716886115726, 0.03991322897491045, 0.018451967589498963, 0.0628658157074824, 0.03181449050316587, 0.01213482048115111, 0.008500948188157054, 0.05206609013839625, 0.0476470423018327, 0.025099987324210815, 0.03780748142162338, 0.026810313029272947, 0.007689562307859887, 0.09493618388660252, 0.06710295201628469, 0.03832229813269805, 0.07832605799194425, 0.031298452959163114, 0.08221880067139864, 0.02713897127250675, 0.0341139237571042, 0.019932546638301574, 0.04989827677491121, 0.06181645600008778, 0.03560873905371409, 0.02142511137208203, 0.038654353556921706, 0.04151798602833878, 0.050836332884500735, 0.029395430465228856, 0.007429850975313457, 0.02696980427572271, 0.005187347869650694, 0.04541026857623365, 0.035510215238900855, 0.07849492627428845, 0.08566915654228069, 0.024452478319290094, 0.013405902373051504, 0.061389917755150236, 0.09461544992518611, 0.017096902411140036, 0.03333039021526929, 0.03838405966234859, 0.0510142145503778, 0.07085001110681333, 0.10997566554578952, 0.058792679192265496, 0.019772060913965106, 0.006672841327599599, 0.060975769665674306, 0.06155203991511371, 0.041981965623563156, 0.03805144391662907, 0.013931168523413362, 0.050038494446198456, 0.009089106715691742, 0.050685380047070794, 0.030568752954422962, 0.007956760055094492, 0.06770962063455954, 0.019820851557597052, 0.045413864281727, 0.024170061442418955, 0.024946731973614078, 0.009237745907739736, 0.02596837432065513, 0.06168798281578347, 0.06564028284628876, 0.05754496196459513, 0.020684258743131068, 0.007983791856531752, 0.041838092874968424, 0.009584748186171055, 0.02104489798512077, 0.05214562239416409, 0.017130395535787102, 0.0736744915775489, 0.008634494879515842, 0.02883381206629565, 0.018128754854842555, 0.0389322878618259, 0.05862844562216196, 0.014307223100331612, 0.043341839918866754, 0.018457192309142556, 0.06005719493259676, 0.03915895831596572, 0.08528090940671973, 0.05000690493034199, 0.02916239609476179, 0.01905674558656756, 0.05087194855150301, 0.05807891866425052, 0.037548286345554516, 0.04098956946108956, 0.03749967196199577, 0.008095907178358175, 0.027127915127493907, 0.053352358227130026, 0.04901976317341905, 0.10460439400048926, 0.09912246081512421, 0.03571010529412888, 0.02668626490049064, 0.034791615908034146, 0.008556138000130886, 0.04593766469042748, 0.021106715175847057, 0.024535576594644226, 0.09589739129296504, 0.019146127997373696, 0.038328465379890986, 0.05043274555646349, 0.024716708867345005, 0.0487556513689924, 0.0365881179459393, 0.04760548945341725, 0.009243237800546922, 0.009947190847015008, 0.05705694049538579, 0.03954982523282524, 0.03301825774542522, 0.04695340139733162, 0.04242811512085609, 0.03937189532734919, 0.04384510139061604, 0.012090459531464148, 0.06957750985748135, 0.02342820505873533, 0.06158008938655257, 0.023001579611445777, 0.057518445028108545, 0.04735149683256168, 0.018774349118757527, 0.014625240801251493, 0.05006484811019618, 0.026775465485116, 0.03249337009037845, 0.0224563107258291, 0.025630500458646566, 0.023309930838877335, 0.03588482170016505, 0.0040449567040923284, 0.025777688751986716, 0.024587456427980214, 0.025471241133345757, 0.057025781425181776, 0.05160595857887529, 0.03105568903265521, 0.06641299958573654, 0.05436185347207356, 0.045063262587063946, 0.02721196891798172, 0.04454981884919107, 0.005289966948112124, 0.05713752660085447, 0.0720593259029556, 0.025851302380033303, 0.06746909057255834, 0.038616459496552125, 0.023516999317507725, 0.1354817152605392, 0.1340577713563107, 0.15583269589114934, 0.1324375145486556, 0.188984046690166, 0.26706656150054187, 0.12905621551908553, 0.1869780957349576, 0.10193878508289345, 0.07317118186620064, 0.07174631769885309, 0.16257107025012374, 0.07571108581032604, 0.15914954681647941, 0.08780904288869351, 0.16819561453303322, 0.11547070505912416, 0.21649272996000946, 0.14359362685354427, 0.12769064895110205, 0.12252572414581664, 0.20503499399637803, 0.08232508364017121, 0.17441972508095205, 0.1475072535686195, 0.12950416101375595, 0.15375733928522095, 0.11542008316610008, 0.1249816021299921, 0.15788525372045115, 0.21547906013438478, 0.0641154291224666, 0.16879978211363778, 0.0976220979646314, 0.17890539922518656, 0.12241124786669388, 0.1400618054321967, 0.11812342287157662, 0.15028249996248633, 0.1616970429313369, 0.16972840181551874, 0.1826984269428067, 0.13427584402961656, 0.07968310470459983, 0.09527754955342971, 0.08013350670807995, 0.10315230785636231, 0.11885175917996094, 0.15488147037103772, 0.16044717718614265, 0.16759833408286795, 0.08745558021473698, 0.11510514537803829, 0.12642444111406803, 0.1696075504878536, 0.1732127257855609, 0.1308479529689066, 0.14418808714253828, 0.10276200497173704, 0.1645954858395271, 0.2467475229059346, 0.11867759938468225, 0.23446557257557288, 0.127694908878766, 0.13894836127292365, 0.2421948328264989, 0.11416386463679373, 0.10347334609832615, 0.1782038321834989, 0.1260602692491375, 0.1617814548080787, 0.1113898131006863, 0.08486070539220236, 0.13437864632578567, 0.12953277822816744, 0.08853529376210645, 0.13196504849474877, 0.11052514426410198, 0.16407537390477955, 0.17503070557722822, 0.09897324460325763, 0.11878611621796153, 0.11627548999967985, 0.15754615160403773, 0.11099456009105779, 0.13561117550125346, 0.1583111277432181, 0.09718131419504061, 0.10105013003339991, 0.12582137191202492, 0.1169540875707753, 0.18594974622828886, 0.17109861422795802, 0.15997854061424732, 0.14884181320667267, 0.10505633224966004, 0.15249947318807244, 0.14795401162700728, 0.11607468710280955, 0.13446089113131166, 0.08607591284089722, 0.21253323851851746, 0.14198471006238833, 0.07918862655060366, 0.17945734929526225, 0.16910271195229143, 0.23338987404713407, 0.09626813858631067, 0.1058996346546337, 0.11327420768793672, 0.1873306604102254, 0.17719106777803972, 0.13355729664908722, 0.1588570515741594, 0.10319961234927177, 0.2197561610955745, 0.19465616263914853, 0.23786590027157217, 0.0742946079117246, 0.21150862943613902, 0.12038805682095699, 0.18654325656825677, 0.13958233350422233, 0.08330478536663577, 0.22450229938840494, 0.07880149263655767, 0.1114703954954166, 0.14372451201779768, 0.23793352476786822, 0.19336172350449488, 0.07552862880402245, 0.13563468673964962, 0.10930264150374569, 0.10231944746919908, 0.1816148022771813, 0.1901864298270084, 0.10611501333187334, 0.09072271466720849, 0.23882444336777553, 0.24715089501114562, 0.08358067134395242, 0.12063540722010657, 0.19269002048531547, 0.17901825020089746, 0.134470732009504, 0.11453946557594463, 0.1482002265402116, 0.11826853500679135, 0.16304663848131895, 0.08136458869557828, 0.12548823666293174, 0.15925362560665235, 0.1266872652922757, 0.12018675668514334, 0.07921946278656833, 0.167516786896158, 0.1757510786410421, 0.13648177409777418, 0.14064287737710401, 0.11216111975954846, 0.0925828336039558, 0.1576972083421424, 0.22288898908300325, 0.06244301417609677, 0.1795969918021001, 0.11476691157440655, 0.16582028183620423, 0.09835131000727415, 0.14850848499918357, 0.07669896600418724, 0.12345260722213425, 0.190895626146812, 0.10386740425019525, 0.11852049414301291, 0.0798886053962633, 0.12271771774976514], [0.0397738981700968, 0.08437755983322859, 0.024199346589739434, 0.054737743848818354, 0.052393993246369064, 0.08280713082058355, 0.04831648177059833, 0.029345834591367748, 0.027702129627869, 0.04130905290367082, 0.060825826149084605, 0.04735709633678198, 0.016396352111769374, 0.05346243728126865, 0.049838827035273425, 0.05302654426486697, 0.08439786499366164, 0.04652999501558952, 0.0038303057954180986, 0.02373619263380533, 0.03791128190641757, 0.04387970031530131, 0.06262069175136276, 0.004944794063703739, 0.09961413365090266, 0.042244927099091, 0.029000053145864513, 0.02269198899739422, 0.03723566034750547, 0.0417361143627204, 0.013285846998769557, 0.014687109942315146, 0.04869634263741318, 0.046450726222246885, 0.04472607521165628, 0.04537956221611239, 0.013946861236036057, 0.017923842315212823, 0.07531707218731754, 0.04728703017462976, 0.04495835259149317, 0.050098615829483606, 0.029771235494990833, 0.0013025467501392995, 0.03487727459287271, 0.08575151266995817, 0.027613379897957202, 0.016991476622933988, 0.05080568960693199, 0.037189264985499904, 0.018025440476776566, 0.03588020183087792, 0.028488269963418134, 0.022067840945965145, 0.021211087114352267, 0.03296093796961941, 0.061936312849866226, 0.02437199611449614, 0.011063859637943096, 0.05362210293242242, 0.058113818158744834, 0.031398876672028564, 0.0705498197930865, 0.023981125486898236, 0.020950183243257925, 0.06947282992769033, 0.023185374338936526, 0.021026900903962087, 0.04854113358305767, 0.013816657919960562, 0.027969978145847563, 0.025434998351556715, 0.050545711565064266, 0.05449743643112015, 0.020709373020508792, 0.06043360110197682, 0.03891249107255135, 0.042119411373278126, 0.0633836789347697, 0.13512984820408747, 0.051588006026577204, 0.03254700139223132, 0.044752269313903525, 0.03739554122148547, 0.0765368141583167, 0.03384702518815175, 0.015504639413848054, 0.02032107764534885, 0.04264384631824214, 0.03210057730029803, 0.048612988321110606, 0.009669919836596819, 0.060419207147788256, 0.09032875299453735, 0.03377580869710073, 0.014383639263542136, 0.039957390472409315, 0.08138363220496103, 0.014521044195134891, 0.04385268242913298, 0.010457038879394531, 0.032500023444299586, 0.02655151500221109, 0.03783333784667775, 0.046873698447598144, 0.10561956296442077, 0.07891739383921959, 0.10021102076279931, 0.08562078335671686, 0.029871777951484546, 0.0728790280118119, 0.0070757829871581635, 0.04020949432742782, 0.025207333419530187, 0.010194739770668093, 0.021837674976268318, 0.07668428632314317, 0.04752871427626815, 0.017167233891086653, 0.035958413063781336, 0.036592953038052656, 0.01942873226653319, 0.05655260662024375, 0.045298983532120474, 0.028347026272967923, 0.029951577380415983, 0.05274356706649996, 0.04747703482280485, 0.05761582222476136, 0.027350049203960225, 0.05661234950821381, 0.002839143221535778, 0.02569499865785474, 0.025095578967011534, 0.033700822095852345, 0.02677024076547241, 0.057639663718873635, 0.01809587029129034, 0.014602597875637002, 0.03471200572676025, 0.03475102785159834, 0.017871066338557284, 0.007904294852778548, 0.04664687585318461, 0.05395249594585039, 0.018123786176147405, 0.07068581093335524, 0.047918749987729825, 0.027771023196692113, 0.02962352584290784, 0.017402683952241205, 0.026632104818418156, 0.0363718004518887, 0.01901254141557729, 0.05963170311588328, 0.043575842792051844, 0.020342119387350976, 0.013939200416643871, 0.03704296912474092, 0.04412696165672969, 0.030269767630670685, 0.019228337550885044, 0.024610893451608717, 0.0480479838734027, 0.042801482195500284, 0.023381928440358024, 0.02555614282755414, 0.03759341263503302, 0.042900577464024536, 0.045205387577880174, 0.12437019860954024, 0.05347960686776787, 0.07470235126675107, 0.03863515048578847, 0.04007008559710812, 0.05018654919695109, 0.06937442856724374, 0.05920720206631813, 0.03746056820091326, 0.04570021454128437, 0.07132005775929429, 0.07852371418266557, 0.018302886819583364, 0.020265804341761395, 0.0453693799499888, 0.02001084136281861, 0.06536179935210384, 0.044905953254783526, 0.002153246628040506, 0.03527898799802642, 0.05125800264067948, 0.019680105106090195, 0.015745149066788144, 0.09705975782708265, 0.05531729068025015, 0.03681244321342092, 0.0602757611341076, 0.01285653590457514, 0.10855941771296784, 0.02588730952993501, 0.033612161423661746, 0.06089857888582628, 0.029952902114018798, 0.05573150556301698, 0.05134015838848427, 0.05511305535037536, 0.05579178279731423, 0.04975666757673025, 0.05164451686141547, 0.047882933940854855, 0.01031158813930233, 0.032878756246645935, 0.05049322317063343, 0.020270494715077803, 0.021715957191190682, 0.07436093364958651, 0.04413554088387173, 0.022224920212465804, 0.009908077809086535, 0.005829986530443421, 0.017985006415983662, 0.06974785501370206, 0.08420320707955398, 0.038583259520237334, 0.04164612153545022, 0.03762834923691116, 0.035052495659329, 0.08558477435144596, 0.04262099930201657, 0.021497439229278825, 0.04934215212415438, 0.016092442638182547, 0.0637668052513618, 0.0043211460342718055, 0.00982215844487655, 0.061857207329012454, 0.01676058891462162, 0.0858721265103668, 0.018834079019143246, 0.02346696928725578, 0.01866453909315169, 0.03532631846610457, 0.029094856945448555, 0.02370666257775156, 0.010015897951234365, 0.04832147642446216, 0.03760601430258248, 0.016306635734508745, 0.04203573422273621, 0.09510677395155653, 0.025202893521054648, 0.04223865966196172, 0.018380374458502047, 0.019240044930484146, 0.058787491580005735, 0.011327487191010732, 0.01016822190649691, 0.043821322979056276, 0.013856355399184395, 0.006268503038882045, 0.052379443441168405, 0.04672458984714467, 0.0647982643567957, 0.04097107514098752, 0.026905445229203906, 0.041024647071026266, 0.028922322453581728, 0.05278758384520188, 0.05977171298582107, 0.07024002508842386, 0.046518283925252035, 0.03827176900813356, 0.055960257741389796, 0.05670369304425549, 0.030604626517742872, 0.040939381724456325, 0.026225129586237017, 0.024793723387119826, 0.06934449032996781, 0.021169402534724213, 0.048380762891611084, 0.08482460732921027, 0.028575639298651367, 0.06774337351089343, 0.04676243566791527, 0.052219518038327806, 0.04885903254034929, 0.02070502032438526, 0.03564170896424912, 0.028683016935246997, 0.04990906389139127, 0.04260462381353136, 0.05195900936087128, 0.02025240672082873, 0.054544273370993324, 0.029685445078939665, 0.005969093299427186, 0.031353446102002636, 0.00871881769853644, 0.051959833144792356, 0.08490765365422703, 0.03859774624288548, 0.02761741532594897, 0.014309309462987585, 0.022187794274941552, 0.02056843732134439, 0.019697538155014627, 0.008923678287828807, 0.02568972013250459, 0.034959159456775524, 0.01976039620785741, 0.022699842775182333, 0.05007072591979522, 0.037671787140425295, 0.018478857455193065, 0.07862841637688689, 0.005791247349407058, 0.022703991380694788, 0.006516628518511425, 0.040326256421394646, 0.052229718858143315, 0.042692163842730224, 0.05219823695369996, 0.0170861319929827, 0.0073940785296144895, 0.031632456521037966, 0.03767786161915865, 0.039079711787053384, 0.019009287098015193, 0.019973737689724658, 0.06702341604977846, 0.008313430662383325, 0.038637425168417394, 0.04035233549075201, 0.032919459335971624, 0.0587113657820737, 0.011617246691457694, 0.046712555922567844, 0.04842087597353384, 0.05610559994238429, 0.02771928808215307, 0.024137575783242937, 0.009141045920841862, 0.013619479486806085, 0.01837108091422124, 0.040764156947261654, 0.04815748405235354, 0.007224669870993239, 0.015152417054196121, 0.0631001933652442, 0.032976129732560366, 0.025291415040555876, 0.18658411921933293, 0.13704898272408172, 0.1285646020551212, 0.15978941170033067, 0.1280270199640654, 0.17764983378583565, 0.08237750895204954, 0.1909981167409569, 0.16648992168484256, 0.06982764331041835, 0.16123014298500493, 0.1174538498162292, 0.08548294426873326, 0.12796312104910612, 0.22606250160606578, 0.1308393440558575, 0.15409936546348035, 0.17409929540008307, 0.09798416213016026, 0.126202910032589, 0.12942691828357056, 0.09415483596967533, 0.12796565919416025, 0.0686521630268544, 0.19775586115429178, 0.16471808863570914, 0.10041706322226673, 0.12592473824042827, 0.10123142928932793, 0.1116586486750748, 0.14455105672823265, 0.23966025008121505, 0.1631868747062981, 0.09895023060380481, 0.08584597322624177, 0.13982701959321275, 0.08866053860401735, 0.17002365784719586, 0.12372494573355652, 0.10658736806362867, 0.10864780750125647, 0.13011870381888002, 0.14412886375794187, 0.09450215366086923, 0.14098865882260725, 0.2804196090437472, 0.12910332705359906, 0.1006242931180168, 0.1353985205059871, 0.1366521415184252, 0.12277924921363592, 0.11578468547668308, 0.12445137472241186, 0.19416163995629176, 0.12178011063951999, 0.11162134833284654, 0.17214467137819156, 0.08848191107972525, 0.1099986647022888, 0.21925452863797545, 0.1203566936601419, 0.20399140077643096, 0.1335894168005325, 0.07501380096073262, 0.07886222258093767, 0.23770518077071756, 0.078717362775933, 0.09560589052853175, 0.1888651101035066, 0.09730436227982864, 0.13734314037719741, 0.13612450420623645, 0.145814711577259, 0.1589054544456303, 0.10963237029500306, 0.16349615732906386, 0.09440133289899677, 0.08422501137829386, 0.18130078475223854, 0.14456778473686427, 0.1306660525733605, 0.08016850639251061, 0.13710051745874807, 0.08999960307846777, 0.10064695830806158, 0.13595722411992028, 0.17825870658271015, 0.18979720305651426, 0.13644889695569873, 0.10627626717905514, 0.20311998581746593, 0.1103360227716621, 0.13818188599543646, 0.18949590594274923, 0.19668970664497465, 0.14264879864640534, 0.06797065623686649, 0.1648718467913568, 0.08909836862585507, 0.18485674081603065, 0.11153122191899456, 0.09232443262590095, 0.26799659128300846, 0.16027446457883343, 0.1097225263947621, 0.3060614940477535, 0.17859840241726488, 0.15400791802676395, 0.13593720097560436, 0.15680437500122935, 0.15994521818356588, 0.10333278332836926, 0.1577791414456442, 0.11194902137503959, 0.20055681554367766, 0.09455707258894108, 0.1652912492863834, 0.19769959151744843, 0.1532414575922303, 0.12286035111173987, 0.11220261323614977, 0.1317090669181198, 0.12260916380910203, 0.1388177284388803, 0.12313170998822898, 0.10355270394938998, 0.12907396769151092, 0.10454676623339765, 0.1922999625094235, 0.10017319349572062, 0.1597857306478545, 0.11098566916189156, 0.06557242086273618, 0.12364554335363209, 0.09120699571212754, 0.22123830422060564, 0.21048554917797446, 0.10376742953667417, 0.09832802883465774, 0.18402130517642945, 0.114961925719399, 0.15420728857861832, 0.12162257495219819, 0.1480932385311462, 0.09701734408736229, 0.1106519773020409, 0.19002706103492528, 0.1220856602594722, 0.14930863893823698, 0.12597561988513917, 0.1370701933046803, 0.13036812481004745, 0.1813137426506728, 0.11218175146495923, 0.12296549117309041, 0.07828132875147276, 0.11939310395973735, 0.11099358045612462, 0.21385472151450813, 0.18903498770669103, 0.09300369070842862, 0.11645126767689362, 0.0906925018352922, 0.1306809252128005, 0.13224802940385416, 0.08661632251460105, 0.17923984065419063, 0.08960375635069795, 0.1292931239004247, 0.1530902969534509, 0.1875402726000175, 0.15812410652870312, 0.2276121059549041, 0.15539282496320084, 0.12837333575589582, 0.15473851788556203], [0.025117164332186803, 0.043128806428285316, 0.008594146165705752, 0.06636632591835223, 0.03733640689461026, 0.09456928091822192, 0.07168659707531333, 0.00872275293659186, 0.0288883116809302, 0.05230941067566164, 0.06947559071704745, 0.07414235631586052, 0.056305252510355785, 0.00479586821711564, 0.0432931179238949, 0.012511141303548357, 0.039086198157747276, 0.055266616836888716, 0.04412870570376981, 0.028813195203838404, 0.011023599054169608, 0.010010495116148377, 0.02457124606735306, 0.07054786794469692, 0.03346471152326558, 0.02445911868562689, 0.07141645532101393, 0.04815697939193342, 0.03721311761182733, 0.035970576864201576, 0.013503633017535321, 0.017002247041091323, 0.02385032938036602, 0.033790918823797256, 0.017325598928437103, 0.014753115628991509, 0.01861285221821163, 0.011861815892189043, 0.027301034060656093, 0.02964781077025691, 0.05459541476739105, 0.06976919918088242, 0.09714811050798744, 0.04769779778143857, 0.044209570114617236, 0.053739262075396255, 0.02019531515543349, 0.05820194819534663, 0.015494701128773158, 0.040539716646890156, 0.061283675604499876, 0.03655645421531517, 0.025811829400481656, 0.06893748912261799, 0.025875758001348004, 0.03163835659506731, 0.043115069274790585, 0.011543894670467125, 0.012242346547282068, 0.058208757400279865, 0.05492770025739446, 0.02235166604805272, 0.05832974231452681, 0.0054539862230740255, 0.114235645160079, 0.03913819673471153, 0.0646975846029818, 0.023449725485988893, 0.04319928077165969, 0.029278766705829185, 0.026758936000987887, 0.004556802041406627, 0.05331269414455164, 0.048057056628749706, 0.049503446789458394, 0.06147615902591497, 0.04171333413978573, 0.012915451297885738, 0.044961814710404724, 0.024154945749614853, 0.030185027353581972, 0.07229339185869321, 0.0622192084119888, 0.03482253749098163, 0.028954769150004722, 0.006977127441132325, 0.02528826276829932, 0.013136145607859362, 0.03475356970739085, 0.04149331332882866, 0.03271110508649144, 0.025505884586891625, 0.047220233172993176, 0.04727892592200078, 0.03797842771746218, 0.026565062908048276, 0.0420300048426725, 0.05268064407573547, 0.01542317479106714, 0.04462102420802694, 0.01948839537362801, 0.009813402029976714, 0.08239817034336738, 0.0963996842619963, 0.052688462601508945, 0.04158179588557687, 0.05099452166177798, 0.02369243560679024, 0.056789711670717224, 0.036143838660791516, 0.06502093834569678, 0.026292924776498694, 0.039077385154087096, 0.040890091986511834, 0.02328415048395982, 0.022961088034207933, 0.027259175076324027, 0.1241460106393788, 0.047206265953718685, 0.03661679082142655, 0.02735678048338741, 0.023500482820963953, 0.03608698272728361, 0.13726631324971095, 0.00917435907467734, 0.03436995357333217, 0.10275548891513608, 0.013011971313972026, 0.1364315752289258, 0.030866382003296167, 0.016129015675687697, 0.03693832259159535, 0.029613796286867, 0.11693750799167901, 0.02276974009873811, 0.032063967155409046, 0.04935012650093995, 0.03779192971705925, 0.04061783882207237, 0.05189093957596924, 0.05190171556023415, 0.07828781512216665, 0.046970990297268145, 0.022586568775295746, 0.017832007106335368, 0.035870965803042054, 0.0663017071201466, 0.02071992636047071, 0.0491301687725354, 0.03307941813545767, 0.016051325801527128, 0.0009779480546967534, 0.04316113067034166, 0.04288727817765903, 0.01611383690033108, 0.029431543371174484, 0.06844289222499356, 0.041900900832843035, 0.051611439339467324, 0.03939505033486057, 0.032451216102344915, 0.04685874046117533, 0.060643202159553766, 0.015145293364184909, 0.03146634160657413, 0.0580966077541234, 0.028519655388663523, 0.024220189807238057, 0.02101518610288622, 0.06734955284628086, 0.02596375074062962, 0.04973091505235061, 0.019266257586423308, 0.10580591624602675, 0.031211591995088384, 0.025469870015513152, 0.033688483890728094, 0.07856174925109372, 0.02864352169126505, 0.030993406144261826, 0.015065747193148127, 0.06628222574363463, 0.1315508410334587, 0.03959144858526997, 0.05457093502627686, 0.05253013652691152, 0.011972773463639896, 0.04558621694741305, 0.03208515918231569, 0.02101112469972577, 0.04641567458747886, 0.057620809457148425, 0.03912784748536069, 0.043266834763926454, 0.04325912013882771, 0.03028110950253904, 0.022637888287135866, 0.03381851187441498, 0.06040179265255574, 0.0024115643464028835, 0.030902689723006915, 0.036349814326968044, 0.0114761764780269, 0.034508623866713606, 0.025632990364101715, 0.022040451985958498, 0.010041323930636281, 0.02043317348579876, 0.08817272493615746, 0.03040081421204377, 0.0021606038626487134, 0.04546629701508209, 0.021942089588264935, 0.013983734843350248, 0.007741465333310771, 0.06817574132583104, 0.0484105044597527, 0.009597936150385067, 0.06222904929018114, 0.06205084479006473, 0.07873540438595228, 0.07842125327442773, 0.048745302119641565, 0.051599724538391456, 0.011729719171853503, 0.04510327547905035, 0.02809695590258343, 0.0184419114884804, 0.01735866717353929, 0.0042311680499551585, 0.033806537321652286, 0.017710612155497074, 0.035342337723704986, 0.05607618862995878, 0.03375952968781348, 0.025187833489326295, 0.043267706787446514, 0.04983578051906079, 0.09268477500882, 0.041296184062957764, 0.04163204299402423, 0.037801599901285954, 0.028229917224962264, 0.06414188668713905, 0.034188795325462706, 0.03276268435001839, 0.036656228548963554, 0.027982203173451126, 0.08316399995237589, 0.0067198786473454675, 0.005133598288011854, 0.020477416619542055, 0.05263888342597056, 0.06040205240424257, 0.029433049930958077, 0.01918609264976112, 0.030047915570321493, 0.05238787423877511, 0.02924303600593703, 0.0203356738347793, 0.11421341783716343, 0.04933322408760432, 0.10594926949124783, 0.07474365178495646, 0.050199944962514564, 0.05234468124399427, 0.031119133382162545, 0.024174469799618237, 0.07219847859232686, 0.009012361224449705, 0.02505867938452866, 0.04776636109454557, 0.039970003272173926, 0.029404894703475293, 0.05268839951895643, 0.07812096548150294, 0.06891855693538673, 0.026248158428643364, 0.02675819199794205, 0.08068025432294235, 0.07202118693385273, 0.05834464835061226, 0.05616719448880758, 0.0366581432899693, 0.03336477391712833, 0.044174084323458374, 0.07830227958038449, 0.04384106410725508, 0.023274480299733113, 0.07604537880979478, 0.028170623336336575, 0.030116655143501703, 0.09832060735789128, 0.04054345336044207, 0.03757358244911302, 0.031540960844722576, 0.028316813441051636, 0.03650824059150182, 0.018677652842598036, 0.05929443781496957, 0.014562180513166822, 0.015249819298333023, 0.03266668012656737, 0.024009959779505152, 0.04653081137803383, 0.02234573072200874, 0.06389878137269989, 0.044279892317717895, 0.03430969860346522, 0.048228674568235874, 0.06997011339990422, 0.04540268382697832, 0.09347493221866898, 0.0260426336171804, 0.016090730132418685, 0.008903820271370932, 0.034813980528269894, 0.05354702727345284, 0.04607708084222395, 0.02181118215958122, 0.02294668294780422, 0.03953585430281237, 0.022910319567017723, 0.02184535434935242, 0.06439327436964959, 0.028006399043079, 0.012975518875464331, 0.040130615161615424, 0.05545646563405171, 0.013727192945225397, 0.030376067297765985, 0.034976273382199, 0.027117319114040583, 0.027271509570709895, 0.013760282527073286, 0.05175994308956433, 0.07264555577421561, 0.037660851594409905, 0.016602457653789315, 0.05518487669178285, 0.03569030108337756, 0.03528012348397169, 0.047712714949739166, 0.04031520584248938, 0.031202986792777665, 0.14994270022725686, 0.05847675434779376, 0.03068438141781371, 0.013000083035876742, 0.0379547198099317, 0.01633049949305132, 0.05627366299449932, 0.17966610059374943, 0.20065284945303574, 0.17485021526226774, 0.11286405235296115, 0.10032241712906398, 0.1947468233993277, 0.10044001042842865, 0.08207607825170271, 0.1425836974522099, 0.10016004263889045, 0.10407913156086579, 0.14189790847012773, 0.18476192402886227, 0.13026490691117942, 0.08816157045657746, 0.20544932020129636, 0.07608679065015167, 0.16752961120801046, 0.18285822618054226, 0.12454682233510539, 0.08692245843121782, 0.13174028164939955, 0.2064022229751572, 0.18050098704406992, 0.08798666851362213, 0.11548006354132667, 0.2027454090421088, 0.1447962474776432, 0.07250701906741597, 0.13542471831897274, 0.17764472780982032, 0.12164517334895208, 0.10446118918480352, 0.19432568427873775, 0.08176128147169948, 0.1463403450907208, 0.10589541925583035, 0.11093526991317049, 0.10774810929433443, 0.19008524541277438, 0.1670317488606088, 0.170419875648804, 0.17100036871852353, 0.10042685957159847, 0.21550459001446143, 0.17282066401094198, 0.13254165271064267, 0.15634639566997066, 0.10311380523489788, 0.1624384187743999, 0.09898718955810182, 0.09309470769949257, 0.07880247969296761, 0.10616579849738628, 0.13658040552400053, 0.0687162549002096, 0.18585538957268, 0.13572905823821202, 0.23001394816674292, 0.17396561976056546, 0.21103640086948872, 0.19422807701630518, 0.1652832340914756, 0.14610318437917158, 0.17011896445183083, 0.1400991651462391, 0.1461190069676377, 0.20632048283005133, 0.11209250820684247, 0.12700267805485055, 0.11950498272199184, 0.10932978184428066, 0.1218020856322255, 0.1433259341865778, 0.11311436392134055, 0.20857273775618523, 0.24663164396770298, 0.12789272092049941, 0.1511498776380904, 0.1043428314733319, 0.13629279361339286, 0.13213360507506877, 0.1487385359359905, 0.12237917966558598, 0.24426511314231902, 0.1519347433350049, 0.16256204573437572, 0.1693818930652924, 0.1730017628869973, 0.16360480774892494, 0.13909456436522305, 0.20277274976251647, 0.10124478052603081, 0.14494622068013996, 0.16850149811943993, 0.09230876588844694, 0.10953496341244318, 0.09822934545809403, 0.11881041413289495, 0.23985331237781793, 0.13619480043416843, 0.07389148071524687, 0.12303197276196443, 0.23681821039645, 0.25244586635380983, 0.12962765438714996, 0.17236776096979156, 0.105352864775341, 0.12800600234186277, 0.15892840165179223, 0.19845247064949945, 0.14954596292227507, 0.14150464441627264, 0.1262759670498781, 0.19495979009661824, 0.17992533277720213, 0.21552204532781616, 0.21087113942485303, 0.16496326454216614, 0.2617602946702391, 0.1832300570094958, 0.14446750574279577, 0.07537373516242951, 0.1447251794161275, 0.1079088139522355, 0.12483786296797916, 0.19787613360676914, 0.11907335705473088, 0.1490003359504044, 0.10819514936883934, 0.10594443810987286, 0.12104079796699807, 0.09635500697186217, 0.2915656578261405, 0.1832460577134043, 0.130647350451909, 0.22000987170031294, 0.13591005321359262, 0.09392503736307845, 0.15166976692853495, 0.13856337958713993, 0.17601667845156044, 0.14833302644547075, 0.170242071908433, 0.14300557872047648, 0.09034260147018358, 0.17978724878048524, 0.13116722489940003, 0.2554203348699957, 0.08375152858207002, 0.09966457000700757, 0.06032821613189299, 0.15171563165495172, 0.19353244715603068, 0.13594721996923909, 0.17172482359455898, 0.19121771823847666, 0.12238429306307808, 0.08124941479763947, 0.16263631987385452, 0.10839874274097383, 0.14364498347276822, 0.2261571105918847, 0.07696252490859479, 0.13090673106489703, 0.1522578892763704, 0.08178076284821145, 0.07399523296044208, 0.12446542357793078, 0.27765558392275125, 0.1340351952239871, 0.11541644664248452, 0.08560185859096237, 0.33941316534765065, 0.12286714918445796, 0.1123802165966481], [0.0285915231143008, 0.04157425195444375, 0.01133933279561461, 0.10496813541976735, 0.04409121240314562, 0.06017042811436113, 0.024196613630920183, 0.044644086447078735, 0.048804139587446116, 0.03248839399020653, 0.0517364244296914, 0.017610650429560337, 0.02966204145195661, 0.04156924245762639, 0.05167825489479583, 0.016445857072540093, 0.026748560776468366, 0.03697325177199673, 0.023172787514340598, 0.05277702679450158, 0.01781493214366492, 0.12466353247873485, 0.12897202628664672, 0.04219562993966974, 0.07947754464112222, 0.03634805172623601, 0.04345582638052292, 0.016301438845403027, 0.017718176495691296, 0.03247296845074743, 0.06634363104240038, 0.03490920920739882, 0.00955416520810104, 0.08278649169369601, 0.03995379476691596, 0.05145450479176361, 0.05308612388034817, 0.049764486102503724, 0.0733982864767313, 0.0476158795208903, 0.05986500465951394, 0.03130351069557946, 0.03177926075295545, 0.03174004938045982, 0.022477202182926703, 0.07526961926487274, 0.05416174448328093, 0.026911419518000912, 0.0394211145612644, 0.04680655634729192, 0.03563331156328786, 0.03227770939702168, 0.024032077635638416, 0.05255765536276158, 0.040110855479724705, 0.05277770585962571, 0.06195740097609814, 0.010420644885016372, 0.06282214031671174, 0.023808646656107157, 0.04999087454052642, 0.04016959646833129, 0.02454569206747692, 0.06746818515239283, 0.03945977303374093, 0.03837461583316326, 0.03275975657743402, 0.02196835233917227, 0.03538285156537313, 0.028057427261956036, 0.028020854224450886, 0.04832544691453222, 0.042257714303559624, 0.04095173848327249, 0.02520319594623288, 0.0780195658444427, 0.02998359177581733, 0.01887711801828118, 0.024547174507461023, 0.028325266503088642, 0.0747495963878464, 0.08048763731494546, 0.08481183496769518, 0.04262168578861747, 0.0015077552211550937, 0.06834232379333116, 0.023589193588122725, 0.04967714274243917, 0.04352589254267514, 0.020994214864913374, 0.014293075910245534, 0.039222218983923085, 0.05872001180250663, 0.03912633350410033, 0.03837715026747901, 0.03609653045714367, 0.028642631114053074, 0.03675335341540631, 0.008755901890253881, 0.04496607834880706, 0.028110362800362054, 0.03058312835491961, 0.036135240879957564, 0.08360485793673433, 0.057172518863808364, 0.015980469252099283, 0.011707872199622216, 0.06674761170870624, 0.023860535766289104, 0.016449311769974884, 0.015791637197253294, 0.06236570465262048, 0.04068485846801195, 0.03990842727944255, 0.07153823433327489, 0.09109684615395963, 0.021854768492630683, 0.04148452258959878, 0.02741013162449235, 0.04250853795383591, 0.02145385846233694, 0.027388640883145854, 0.005060719850007445, 0.07759683110634796, 0.0682600938307587, 0.03695229723234661, 0.03135392478725407, 0.0743020664958749, 0.08721913938643411, 0.031231444445438683, 0.01897286063467618, 0.01619883692910662, 0.07997476874152198, 0.010297883454768453, 0.01982947902433807, 0.08121968436171301, 0.014208775355655234, 0.07093831925885752, 0.07474829762941226, 0.03530977599439211, 0.06883442707476206, 0.07540975158917718, 0.03775736418901943, 0.07471700868336484, 0.038748981096432544, 0.019830312085105106, 0.03476393751043361, 0.13818096573231742, 0.02795978289213963, 0.0897458331019152, 0.06197152404638473, 0.054931889681029133, 0.0864362478023395, 0.035797463497146964, 0.056279006457771175, 0.019328490379848517, 0.08461170742521062, 0.0399585222476162, 0.052527249572449364, 0.04417880809342023, 0.0610529901314294, 0.08488595325616188, 0.017179410679091234, 0.048881449110922404, 0.020895052803098224, 0.026587854263198096, 0.02472531035891734, 0.03349371465446893, 0.055914341064635664, 0.10102836284204386, 0.05565265608311165, 0.03187460817571264, 0.0195953388538328, 0.06068500362744089, 0.011123698077426525, 0.03747427566850092, 0.023733875277685, 0.016859997740539256, 0.041827112800092436, 0.0490619802440051, 0.0439854044088861, 0.02827356664056424, 0.043250607704976574, 0.04439492891833652, 0.0085530144860968, 0.06274040017160587, 0.0628683835384436, 0.03684916839119978, 0.04341736086644232, 0.009833396416070173, 0.02931924715085188, 0.059118452336406335, 0.04296797560527921, 0.010145323867618572, 0.04151391163759399, 0.08533325308235362, 0.030373803747352213, 0.012602036767930258, 0.0791733679943718, 0.04616102887666784, 0.10766861043521203, 0.07257430217578076, 0.026517107180552557, 0.03978209148044698, 0.012080773576599313, 0.07307716659852304, 0.021759393239335623, 0.05578328520641662, 0.015459308106073877, 0.020976625964976847, 0.021475510620803107, 0.027048536867368966, 0.01750702620483935, 0.03385260242794175, 0.05447110132081434, 0.04096289296285249, 0.015649430570192635, 0.01895786183013115, 0.05066218051069882, 0.04954806841851678, 0.031349475611932576, 0.04647149522497784, 0.01573613568325527, 0.047525671470793895, 0.10691265139030293, 0.023368219117401168, 0.02770195893390337, 0.047238512270268984, 0.06689583344268613, 0.026225433866784442, 0.08002806236618198, 0.03640281851403415, 0.04942468636727426, 0.046170728746801615, 0.02020141932007391, 0.022137866289995145, 0.0386032084497856, 0.06392491981387138, 0.03079865731706377, 0.046459594886982813, 0.03134600607154425, 0.029625989773194306, 0.013094569567329017, 0.04826336255064234, 0.030976895213825628, 0.06571755526238121, 0.01628313933906611, 0.03586508428270463, 0.023750751715851948, 0.03316780421300791, 0.04777546724653803, 0.05282181911752559, 0.0374819606076926, 0.014376830986293498, 0.08053531288169324, 0.02038027876551496, 0.04810940401512198, 0.04814172083570156, 0.07803636806784198, 0.019491902021400165, 0.023351140443992335, 0.06930048839421943, 0.010747604537755251, 0.04644770568120293, 0.004091534356120974, 0.05450024546007626, 0.02180469578888733, 0.022982042573858052, 0.03341837182233576, 0.021881656502955593, 0.05511292918527033, 0.07445461495080963, 0.018957717111334205, 0.023098917845345568, 0.029255509653012268, 0.02885861278627999, 0.028760740206053015, 0.026505754176469054, 0.033364569826517254, 0.016784816325525753, 0.08636143189505674, 0.048280053451890126, 0.0507404214295093, 0.03784850734518841, 0.029729120469710324, 0.10434824915137142, 0.07333193847443908, 0.06990613284870051, 0.09870152207440697, 0.021533832295972388, 0.018250168359372765, 0.059466052043717355, 0.06378020843840204, 0.023862290945544373, 0.02327319081814494, 0.0073311304913659114, 0.0560847047745483, 0.04638449696358293, 0.03459219340584241, 0.11063334939535707, 0.027561286697164178, 0.0389817520044744, 0.0792665668996051, 0.037051006584079005, 0.02845797178451903, 0.013345729967113584, 0.009128487854468403, 0.04080740189237986, 0.026676012130337767, 0.030745334006496705, 0.036643593484768644, 0.04755899390147533, 0.030597242148360237, 0.047756664935150184, 0.07703667288296856, 0.06375185839715414, 0.0995815459464211, 0.03036040983715793, 0.054749918781453744, 0.06658845813944936, 0.0689966457139235, 0.021680248755728826, 0.014933889815438306, 0.015388516494567739, 0.00907104284124216, 0.033279456620221026, 0.04130937944864854, 0.0562415762396995, 0.021959535624773707, 0.024902156728785485, 0.04097158722288441, 0.02536184671043884, 0.03928913843992632, 0.04618697435944341, 0.050901181748486124, 0.05218563157541212, 0.06376814111717977, 0.12174318879260682, 0.03763326596526895, 0.001074188373877405, 0.01877850514574675, 0.024178956082323566, 0.008688474063092144, 0.07068889826769009, 0.01207933566547581, 0.05786004076071549, 0.047915213654050604, 0.03535390780598391, 0.05786929534224328, 0.04339761973824352, 0.07094237880664878, 0.026000802463386208, 0.1241647127608303, 0.14744287967914715, 0.1349022166687064, 0.18679686327232048, 0.1989230516483076, 0.15307190653402358, 0.13454527332214639, 0.16128770395880565, 0.1225359806267079, 0.1258161323494278, 0.21038234612205997, 0.08466351675451733, 0.12091028387658298, 0.12489221786381677, 0.1274875528179109, 0.13950075663160533, 0.10150170463020913, 0.12925105897011235, 0.10455680749146268, 0.1545462422654964, 0.08018151624128222, 0.16423860186478123, 0.27081265579909086, 0.10951580115943216, 0.2086273895110935, 0.10044890877907164, 0.050998050573980436, 0.09495473015704192, 0.11543422850081697, 0.16197658027522266, 0.11800360312918201, 0.1095450491993688, 0.13800335495034233, 0.14403345325263217, 0.21920378057984635, 0.10349981108447537, 0.16113915567984805, 0.18801631580572575, 0.23947217501699924, 0.17246640723897144, 0.11532246106071398, 0.1374854546156712, 0.2003453331417404, 0.11496419669128954, 0.14052074955543503, 0.1818937755888328, 0.1349369194940664, 0.1413856039289385, 0.19099908153293654, 0.14354583254316822, 0.17222963244421408, 0.17736256326315925, 0.10236045112833381, 0.11208666750462726, 0.13541777181671932, 0.18864335637772456, 0.13800733286188915, 0.07298203810933046, 0.13842404878232628, 0.1544844065210782, 0.13759202702203766, 0.1527642269502394, 0.13094554538838565, 0.16869047860382125, 0.1141416298924014, 0.17546949296956882, 0.09709466845379211, 0.0927191438677255, 0.13974542787764221, 0.13078818039502949, 0.1288213999941945, 0.1284656292409636, 0.11439896959927864, 0.10817166039487347, 0.11035549672669731, 0.1361869039828889, 0.12539080751594156, 0.1067015623266343, 0.14355974039062858, 0.15692222805228084, 0.13114420347847044, 0.2596423833165318, 0.1769017192418687, 0.06097203295212239, 0.05595038346655201, 0.14875986526021734, 0.1683015635353513, 0.14580050687072799, 0.12896211119368672, 0.2407877505174838, 0.0936723880295176, 0.07499759245547466, 0.17163814074592665, 0.17346372012980282, 0.2995490888133645, 0.1304459315724671, 0.19386095140362158, 0.12119877152144909, 0.11796126360422932, 0.10444149258546531, 0.08951716255978681, 0.08684419895871542, 0.17069470777641982, 0.15096088231075555, 0.1684976983233355, 0.09919782591168769, 0.08461729579721577, 0.07870250497944653, 0.13201169989770278, 0.1666519622085616, 0.22367179160937667, 0.09177358835586347, 0.20999254047637805, 0.1561359819606878, 0.14106974587775767, 0.12700600287644193, 0.10972450792905875, 0.07035787813947536, 0.20679852983448654, 0.22531772672664374, 0.12058283347869292, 0.19268240605015308, 0.1540586957708001, 0.30194928345736116, 0.25909227377269417, 0.13761779438937083, 0.21183507051318884, 0.1478537474758923, 0.10998918005498126, 0.1791876379866153, 0.1176084837061353, 0.23603769368492067, 0.1812812068965286, 0.13362821628106758, 0.07904421945568174, 0.18741912441328168, 0.305926066939719, 0.17352086550090462, 0.18165848508942872, 0.18552741967141628, 0.2664184884633869, 0.22234523232327774, 0.12044361399603076, 0.12161798105807975, 0.14242355682654306, 0.05336170186637901, 0.1431210568989627, 0.12471013935282826, 0.10604125127429143, 0.11932260735193267, 0.13844362663803622, 0.12909461423987523, 0.14974243909819052, 0.10117774974787608, 0.09352085631689988, 0.1009019602497574, 0.11997168970992789, 0.1641894123167731, 0.17302548192674294, 0.11832844116725028, 0.22617462527705356, 0.2743464958621189, 0.1300838970928453, 0.1328478628420271, 0.0983893896045629, 0.10518034512642771, 0.08359961095266044, 0.1845584122929722, 0.1432909196591936, 0.12240103591466323, 0.212461368937511, 0.055028116548783146, 0.18732184369582683, 0.12984125933144242, 0.3549347980879247, 0.11409981729229912], [0.01255825933185406, 0.031993481679819524, 0.026892594942182768, 0.023090457361831795, 0.033581863244762644, 0.02283038840687368, 0.015281060932466062, 0.013022821513004601, 0.007144108813008643, 0.05271325775538571, 0.03109211364062503, 0.02356966582738096, 0.026813751028385013, 0.04787665166077204, 0.07965616474393755, 0.05956128072284628, 0.003394685750208737, 0.035887664125766605, 0.03762858672416769, 0.07053899185848422, 0.008271254409919493, 0.030025701234990265, 0.06365624009049498, 0.013198944288888015, 0.0035920195705330116, 0.02631420957186492, 0.03666090779006481, 0.04591797180182766, 0.042039285399368964, 0.024916879083320964, 0.022717739666404668, 0.02718389903748175, 0.02223856088676257, 0.023230114711623173, 0.015900608595984522, 0.05836626711243298, 0.038003230292815715, 0.023687722969043534, 0.04696789554145653, 0.0881516034132801, 0.027401344596000854, 0.03773318501771428, 0.02818178152665496, 0.00263443361291138, 0.03007359573530266, 0.04230842154356651, 0.04736310031148605, 0.01017571574266185, 0.034565498353913426, 0.03802030340011697, 0.03408285374462139, 0.027831317129312083, 0.047531523305224255, 0.03189247909176629, 0.008920914715417894, 0.03199511811544653, 0.02624354969157139, 0.043895341077586636, 0.022041446463845205, 0.017961862540687434, 0.013953828147350578, 0.03515666721796151, 0.008948426129791187, 0.06594517937628552, 0.012974853725609137, 0.026358165123383515, 0.07844097213819623, 0.006057692744434462, 0.012828855651605409, 0.03408866105019115, 0.10150570480618626, 0.040414238028461114, 0.0111969823774416, 0.009917352799675427, 0.031171671871561557, 0.010369028514105594, 0.019324846434756182, 0.05012244619138073, 0.03558301250450313, 0.040774624940240756, 0.03867719686240889, 0.05586582687101327, 0.03571761211787816, 0.019876696314895526, 0.03712165533215739, 0.01540229353850009, 0.017705222307995427, 0.07092257088515908, 0.11423862117226236, 0.02678519689652603, 0.03288348743808456, 0.008754725586186396, 0.07948087688419037, 0.07252870462252758, 0.08213038119720295, 0.013264898952911608, 0.0506065008812584, 0.0242005933978362, 0.07827309833373874, 0.019296479695185553, 0.11907589519978501, 0.053908093250356615, 0.018984252601512708, 0.034019329614238814, 0.02760906245384831, 0.04512892781349365, 0.037105665760464035, 0.01372061009533354, 0.027923000197915826, 0.030640982477052603, 0.030835523502901196, 0.04069635062478483, 0.014629856959800236, 0.06932561751455069, 0.02897721355111571, 0.01224097821250325, 0.013409625171334483, 0.035571301414165646, 0.0277566403747187, 0.014614369265473215, 0.03653304316685535, 0.026199727726634592, 0.03898608614690602, 0.02338918664463563, 0.04492657011724077, 0.06749436812242493, 0.019609426672104746, 0.03066356232011458, 0.019695562186825555, 0.04361100945970975, 0.031131684954743832, 0.05548569140955806, 0.03720578890352044, 0.03173378936480731, 0.05094120577268768, 0.024030650856730063, 0.04216900168103166, 0.015464702591998503, 0.01798699908249546, 0.03158265841193497, 0.07592915106215514, 0.05421629233751446, 0.0277433614974143, 0.06998973578447476, 0.011310385325487005, 0.048655275895725936, 0.023492714390158653, 0.005168141087779077, 0.02156810096494155, 0.09366510013933294, 0.0965754545177333, 0.01914205917273648, 0.054465791254187934, 0.04071868184837513, 0.005724203119825688, 0.023711458707111888, 0.05169632247998379, 0.041564503844711, 0.0465041051938897, 0.050937814157805406, 0.039372815590468235, 0.06088700880354736, 0.03174608304107096, 0.002736185306275729, 0.04251481281244196, 0.05162739922525361, 0.05146981158759445, 0.014098400370130548, 0.024851720372680575, 0.0609048611659091, 0.08472919682390057, 0.027183103084098548, 0.04259057866875082, 0.01283578916627448, 0.08519085720763542, 0.04308570991270244, 0.03928068537788931, 0.036274649610277265, 0.052268577710492536, 0.026967227167915553, 0.04328953706135508, 0.10149822395760566, 0.018909601822088007, 0.054054708234616555, 0.016584464283369016, 0.028360008291201666, 0.06289415832725354, 0.018400432854832616, 0.03490655974019319, 0.06655218196101487, 0.046416928817052394, 0.003643928394012619, 0.04641869512852281, 0.07603780890349299, 0.010938992363662692, 0.05647491489071399, 0.018828741121978965, 0.024488030903739855, 0.03941552247852087, 0.0273184281468275, 0.00531971964846889, 0.004555485656965175, 0.010685651905077975, 0.027197719682590105, 0.027558956353459507, 0.013269153314467985, 0.05094135049148463, 0.0310017998344847, 0.004403767479743692, 0.02137938394298544, 0.10274296146235429, 0.022881347977090627, 0.036647448941948824, 0.018617952628119383, 0.04375791388156358, 0.04178777897323016, 0.08437988275545649, 0.018470248542143963, 0.023220602233777754, 0.0034853383931476856, 0.0392557455052156, 0.02737245649768738, 0.025141974329017103, 0.041429455231991597, 0.048409695518785156, 0.019715451744559687, 0.05688865108822938, 0.038782570700277574, 0.018484126703697257, 0.04102423517906573, 0.01599803588760551, 0.033522098092362285, 0.01892360429337714, 0.04147557971009519, 0.061070579031365924, 0.05295946524711326, 0.03680942267237697, 0.08559023655834608, 0.030474951054202393, 0.0352685682446463, 0.03916203080734704, 0.04691647583968006, 0.03890117703122087, 0.024722621928958688, 0.02609072849736549, 0.048342297377530485, 0.034895253120339476, 0.018900961367762648, 0.09876176220132038, 0.023515739521826617, 0.03402230933716055, 0.048609359218971804, 0.0294914513870026, 0.04296087696275208, 0.04428836393344682, 0.09360891213873401, 0.07995338746695779, 0.028385471377987415, 0.028697177112917416, 0.014141834562906297, 0.045110930732334964, 0.015010481311037438, 0.02789464830129873, 0.05948196368990466, 0.0648700374586042, 0.06390713795553893, 0.02051523646514397, 0.029320583016669843, 0.04154893358645495, 0.02662452192453202, 0.03801558705163188, 0.06794297412852757, 0.03339882365253288, 0.023270994061022066, 0.020246675485395826, 0.02551674777350854, 0.06098401492636185, 0.03441886852669995, 0.010741043024609098, 0.0345895179634681, 0.038330265088006854, 0.04197275928163435, 0.04811695536773186, 0.0040147406252799556, 0.05642119453113992, 0.050258552364539355, 0.03401943722565193, 0.051693090426851995, 0.020699220440292265, 0.02183042419346748, 0.018806194675562438, 0.032917418429860845, 0.08914119796827435, 0.017411007138434798, 0.029231111548142508, 0.07422220398439094, 0.009596761701686773, 0.031544679004582576, 0.01410146729540429, 0.021686338077415712, 0.044247093101148494, 0.06710346409818158, 0.045608232758240774, 0.025275679654441774, 0.03816999087575823, 0.025310820346930996, 0.045487277529900894, 0.09646501552197151, 0.04809086145542096, 0.10154206262086518, 0.04835947809624486, 0.028417715839168523, 0.08732830188819207, 0.04008198964584153, 0.05383351483033039, 0.013320517355168704, 0.0288477885624161, 0.07198829494882375, 0.04130979134060908, 0.0349923408793984, 0.04815779575437773, 0.05713125174224842, 0.02289060070324922, 0.03939065682061482, 0.032113290289998986, 0.03005515336553799, 0.07330818232730962, 0.05987752098008059, 0.06314382422715425, 0.018713387253228575, 0.03305646350781899, 0.022411985955841374, 0.008023722184589133, 0.015610234040650539, 0.030960753501858562, 0.02224597494205227, 0.004725495455204509, 0.010209810006927, 0.03853874921333045, 0.029866577351640444, 0.03009150932484772, 0.020776615310751367, 0.030611890288128052, 0.03870726497552823, 0.03704169634147547, 0.09383624681504443, 0.07299366756342351, 0.02057286608760478, 0.031744813968543895, 0.030651270499220118, 0.09155069914413616, 0.025536590947012883, 0.11616943709668703, 0.21052740630693734, 0.15526970266364515, 0.15389413194498047, 0.11543700413312763, 0.22133948863483965, 0.17698304378427565, 0.19470192346489057, 0.2839996700640768, 0.09111233477597125, 0.10207162209553644, 0.11868247529491782, 0.13968270155601203, 0.14369249576702714, 0.17992876149946824, 0.11373503686627373, 0.15236413513775915, 0.20725354057503864, 0.08805591089185327, 0.2092759672086686, 0.07504166860599071, 0.15007708832854405, 0.18139606167096645, 0.07731975027127191, 0.24638755159685388, 0.14899615023750812, 0.08749780841753818, 0.11107196609373204, 0.21100695244967937, 0.07982795708812773, 0.13795455131912604, 0.10411008654045872, 0.1036845613270998, 0.11777650594012812, 0.1645263028331101, 0.13745133066549897, 0.09618481024517678, 0.09625032704207115, 0.15761794697027653, 0.16559940384468064, 0.27984901622403413, 0.08530954888556153, 0.12167526743724011, 0.11399213908589445, 0.19066389795625582, 0.09663553137215786, 0.14210608089342713, 0.12479271070333198, 0.11024053063010797, 0.1348579698242247, 0.15134577493881807, 0.18766905006486923, 0.21849157114047557, 0.16241970180999488, 0.1694628910627216, 0.14923638344043866, 0.18807558371918276, 0.24956909415777773, 0.1118930040684063, 0.11929603846510872, 0.24152897793101147, 0.18055563879897818, 0.0666799872124102, 0.1511925956583582, 0.08207166247302666, 0.09561200582538731, 0.1934702106518671, 0.06628506074775942, 0.07557908742455766, 0.16354181425413117, 0.16589978069532663, 0.1976944855414331, 0.15776732645463198, 0.16479634068673477, 0.13814699021168053, 0.1463748698006384, 0.13643445476191118, 0.09961433403077535, 0.11730606594937854, 0.18718340346822515, 0.16091096011223271, 0.09803448716411367, 0.10749969020253047, 0.0697677668358665, 0.11948829924222082, 0.12456919066607952, 0.180111404042691, 0.16636060987366363, 0.1322279468877241, 0.15425195102579892, 0.15236619830830023, 0.10411600887891836, 0.1536436125752516, 0.13931940542533994, 0.11329894346999936, 0.1577974873362109, 0.12203301972476766, 0.10129767339094542, 0.10799803494592197, 0.0665151487919502, 0.21628991584293544, 0.15654892777092755, 0.08659138635266572, 0.12453874776838347, 0.10885208364925347, 0.1340255473041907, 0.19711497210664675, 0.13175982981920242, 0.12436572345905006, 0.16251450375420973, 0.06465987607953139, 0.14599771035136655, 0.12093258541426621, 0.1385645818663761, 0.12770813395036384, 0.1517386085470207, 0.2253114036284387, 0.10001841859775595, 0.1682497764704749, 0.12648011703277007, 0.09274379801354371, 0.17385159619152546, 0.11217303122975864, 0.08834044288960285, 0.15060469595482573, 0.24166823452105746, 0.07742266388959251, 0.12735182885080576, 0.1201113396382425, 0.1444584663840942, 0.1009749727381859, 0.2639954653568566, 0.1361256471136585, 0.11853012721985579, 0.13339034310774878, 0.18369680852629244, 0.2552502049366012, 0.06557767526828684, 0.14070116565562785, 0.17647940752794966, 0.2124053961597383, 0.24670723913004622, 0.14530758722685277, 0.10327769370633177, 0.12231644592247903, 0.1776553108356893, 0.09038914897246286, 0.09608723266865127, 0.18289330007974058, 0.20714034821139649, 0.1782557973638177, 0.10756974152172916, 0.15085592778632417, 0.16204166662646458, 0.11012593560735695, 0.13257064099889249, 0.10511272805160843, 0.0834114987810608, 0.1440427004126832, 0.06112088551162742, 0.14369435113621876, 0.15919768251478672, 0.19335145218065009, 0.1373284458531998, 0.18173615826526657, 0.10628020056174137, 0.11640363663900644, 0.13215704209869727, 0.08379164166399278, 0.1497092650970444, 0.13448949350276962, 0.11199535365449265, 0.15860233164858073, 0.04735867340059485, 0.16465656459331512, 0.12759321980411187], [0.03473982884315774, 0.02441720775095746, 0.039170235249912366, 0.05948189689661376, 0.005835471465616138, 0.04291646684578154, 0.03727850824361667, 0.05632983986288309, 0.03770377370528877, 0.021677606709999964, 0.025645846217230428, 0.09927706501912326, 0.03996660794655327, 0.06283097187406383, 0.0368230485037202, 0.0065299537800456164, 0.05131952668307349, 0.0654587238386739, 0.08979579448350705, 0.041134481216431595, 0.028759821798303165, 0.037977284810040146, 0.03876272196066566, 0.014488307133433409, 0.03629171158536337, 0.05750349817390088, 0.042584923503454775, 0.02010862488532439, 0.051126382750226185, 0.022540065801877063, 0.08522887743311003, 0.004622978422048618, 0.09937740338500589, 0.02708124702621717, 0.04903209024632815, 0.0030386777416424593, 0.017985997183131985, 0.008665338536957279, 0.04964677405951079, 0.0630280195036903, 0.06443827820476145, 0.01894084067316726, 0.04001442081062123, 0.013273424374347087, 0.01737071779643884, 0.023051229291013442, 0.0610398652497679, 0.019752275256905705, 0.060359174822224304, 0.05744358459196519, 0.017458617767260876, 0.055028713977662846, 0.010329256820114097, 0.04587809249642305, 0.033935363026103005, 0.03486963418254163, 0.04710157489171252, 0.01573364577780012, 0.08531762345228344, 0.025239932256226894, 0.039895272711873986, 0.018567438346508425, 0.011928607327718055, 0.05637288071739022, 0.023475103225791827, 0.009668765796959633, 0.060003645266988315, 0.04623334745701868, 0.033397884835721925, 0.0964470035978593, 0.04186156329524238, 0.034527133029769175, 0.037146368849789724, 0.02883807013859041, 0.09970879458705895, 0.04092631621460896, 0.008760099663049914, 0.05374255350034218, 0.03534286093781702, 0.018018197115452494, 0.07748104864731431, 0.06887787239975296, 0.055417302501155064, 0.01480406963310088, 0.06393597039277665, 0.063887337455526, 0.040405517793260515, 0.03789681744819973, 0.07529241804149933, 0.012310167712712428, 0.03901998374203686, 0.06366992529365234, 0.045405685814330354, 0.016698369108780753, 0.03426699542615097, 0.0622024321637582, 0.013477310894813854, 0.1301961246645078, 0.02612795648019528, 0.0640062295133248, 0.06573394930455834, 0.04702446574810892, 0.0559496561618289, 0.06261396789341234, 0.05073508909845259, 0.055192012441693805, 0.01812575472285971, 0.049239654108532704, 0.008110403177852277, 0.023185107165772934, 0.0512348253687378, 0.04224606258503627, 0.02323838409211021, 0.0516682359011611, 0.037594522145809606, 0.05396045547968242, 0.00940297302804538, 0.051315823366167024, 0.05460658408992458, 0.015269636496668682, 0.03127603638859, 0.04318921724916436, 0.020055283021065407, 0.0261262476851698, 0.048268542741425335, 0.0824286874558311, 0.043981419075862505, 0.016543722231290303, 0.0814555017859675, 0.03185022120305803, 0.037702875706600025, 0.07296906536794268, 0.03783314117754344, 0.05569421635300387, 0.013324394149094587, 0.0058276538675272604, 0.05214969678490888, 0.04130023247853387, 0.023793312029738445, 0.027127588582516182, 0.012828051349060843, 0.010837737445399398, 0.09110230093938299, 0.02469039045536192, 0.07439766253810376, 0.0985306351503823, 0.024662483847350813, 0.09564759922795929, 0.04416564239363652, 0.08573963088565506, 0.02178718295908766, 0.047744790572323836, 0.007795616602379596, 0.01636015385884093, 0.01671475201874273, 0.021987188047205564, 0.06260909940465353, 0.07653286593267694, 0.01917859881359618, 0.0012198552644804295, 0.020902802680211607, 0.09636222806875594, 0.02735630736424355, 0.07357213456998579, 0.04365207249065861, 0.058170336415059865, 0.06109547808591742, 0.027234454137214925, 0.004960708492944832, 0.04232222549035214, 0.04081117200257722, 0.02437880903016776, 0.03876822127494961, 0.04215937231492717, 0.02862964909581933, 0.011559780341485748, 0.03437806153669953, 0.01472313100748579, 0.014754308631381718, 0.054426431452156976, 0.04459831819985993, 0.04950347276462708, 0.06578551372513175, 0.02225002335762838, 0.0627787692064885, 0.03951259539462626, 0.011876562366524013, 0.059788808357552625, 0.07285953179234639, 0.03929524260456674, 0.02709392847464187, 0.03367789715412073, 0.019768246274907142, 0.03706436895299703, 0.016615595523035154, 0.03254150207794737, 0.037133607620489784, 0.0348880988167366, 0.05201199499424547, 0.02064126241748454, 0.0378607268066844, 0.06729831497068517, 0.031221770550473593, 0.04576651059323922, 0.028096200767322443, 0.03012148466950748, 0.07257954173837788, 0.05382764444220811, 0.04976860131137073, 0.04934674230753444, 0.028528869152069092, 0.01709869840851752, 0.038693219830747694, 0.01843379610363627, 0.025294326114817522, 0.03101947037066566, 0.017711523141770158, 0.005887128654649132, 0.036438923998503014, 0.02815721272781957, 0.012039396060572471, 0.05485270252393093, 0.051765216048806906, 0.03233305877074599, 0.028018750235787593, 0.040075154465739615, 0.06438890311983414, 0.09509711861028336, 0.03102419042988913, 0.023513956512033474, 0.06710789471981116, 0.041500831284793094, 0.039870919135864824, 0.03378400571818929, 0.044365053763613105, 0.014999823142716195, 0.045071927161188796, 0.038392935748561285, 0.015486097781831631, 0.05595802758762147, 0.044609086762648076, 0.025206197933584917, 0.02722312154219253, 0.04786118530319072, 0.010994463264069054, 0.028395570152497385, 0.01759894861606881, 0.04502416995819658, 0.017294447279709857, 0.04805830343684647, 0.06594284903258085, 0.0325485561916139, 0.021697448028135113, 0.041021582001121715, 0.0400930624891771, 0.03551712092303205, 0.06820559792686254, 0.028626932835322805, 0.05467211944051087, 0.058247924243914895, 0.05566303130763117, 0.05167025083210319, 0.05384754513215739, 0.07563583203591406, 0.05817813267640304, 0.013786533218080876, 0.04451834436622448, 0.015162389663601061, 0.01598739720066078, 0.0841973366914317, 0.07333671790547669, 0.07371493120444939, 0.03035232970432844, 0.0580724397150334, 0.00981757475528866, 0.08117980134557001, 0.052091631150688045, 0.04650613867852371, 0.09635431677452289, 0.03158340427035, 0.03877431430737488, 0.09587704160367139, 0.01657993532717228, 0.03744589594134595, 0.034978807816514745, 0.04373924144601915, 0.03617191410739906, 0.007713729419265292, 0.049923413316719234, 0.04287472846044693, 0.017661016281635966, 0.025406219720025547, 0.030947858685976826, 0.0244999275309965, 0.08496496229781769, 0.026741551191662438, 0.016058908695413265, 0.03749441013496835, 0.015415521393151721, 0.0484223454259336, 0.024099332913465332, 0.005238335270405514, 0.030296061922854278, 0.0258234829743742, 0.04520647482422646, 0.07009319859207608, 0.023111064947443083, 0.10019565088441595, 0.022848376211186405, 0.04992411093553528, 0.015215357670967933, 0.06862400594400242, 0.0738434043887537, 0.019800171612587292, 0.03421736058953684, 0.041159016618621536, 0.011834342512884177, 0.049974376597674564, 0.06887048060889356, 0.04791469415067695, 0.013172769668017281, 0.06064071967557538, 0.02861973214749014, 0.09529098242637701, 0.011988119222223759, 0.026916093192994595, 0.04787861464137677, 0.010291978742316132, 0.01506081562183681, 0.046041969835641794, 0.04668267705710605, 0.0367270628339611, 0.03406569529033732, 0.0627157608687412, 0.014585987682949053, 0.019640619138954207, 0.09003924118587747, 0.013956986913399305, 0.03899940027622506, 0.03150630625896156, 0.035015989415114745, 0.031743897416163236, 0.007836576660338324, 0.06832414117525332, 0.026590297784423456, 0.012670700270973612, 0.010351731834816746, 0.01992299519770313, 0.04102606457308866, 0.015113791978365043, 0.042306087489123456, 0.009833396416070173, 0.1293696096399799, 0.11156984328408726, 0.2255816344404593, 0.16849294857820496, 0.10246240737615153, 0.1299012842355296, 0.2037681924412027, 0.13923877850174904, 0.1707759581040591, 0.14132568292552605, 0.05262554703222122, 0.157348191132769, 0.08396239500143565, 0.1211985934060067, 0.13145050266757607, 0.10349083109758794, 0.1686913098092191, 0.17718020273605362, 0.23117272270610556, 0.21073247655294836, 0.15144875535042956, 0.13957491202745587, 0.13950265652965754, 0.10947499045869336, 0.11911138470168225, 0.19385255029192194, 0.10288832592777908, 0.14076037419727072, 0.09065073376405053, 0.08242466501542367, 0.18198568315710872, 0.17790447949664667, 0.23435235052602366, 0.09501609092694707, 0.15036844066344202, 0.16440073144622147, 0.17795371357351542, 0.09283705629059114, 0.19119751697871834, 0.18168627109844238, 0.2226803862140514, 0.10981709085172042, 0.1445986283943057, 0.09361817414173856, 0.20185720670269802, 0.09997056491556577, 0.09925960228429176, 0.13770753488643095, 0.12351774552371353, 0.11768473195843399, 0.15539895510300994, 0.16091891593532637, 0.07638722687261179, 0.1260570780141279, 0.1330358933773823, 0.08171982510248199, 0.14444828411797062, 0.2305900031933561, 0.1537317203474231, 0.08708067689440213, 0.11437765511800535, 0.10582667411654256, 0.07462480425601825, 0.11860118043841794, 0.17188560246722773, 0.09917717194184661, 0.08420615340583026, 0.09869891713606194, 0.06869733013445511, 0.19866491784341633, 0.10903123067691922, 0.14846263511572033, 0.09938194532878697, 0.18905483273556456, 0.2179960539797321, 0.08747175161261111, 0.06651597999734804, 0.1674486874253489, 0.12967880320502445, 0.13319846824742854, 0.17889947688672692, 0.17399868986103684, 0.2109837083844468, 0.1261383728706278, 0.16597585083218291, 0.21545180847169831, 0.14833825116511434, 0.18401762412395328, 0.21339485712815076, 0.22357606940204278, 0.14962501649279147, 0.1563698475365527, 0.08354088480700739, 0.17293305485509336, 0.08878161257598549, 0.14473798888502643, 0.04791307626874186, 0.14134668570477515, 0.13058662792900577, 0.1380194743978791, 0.1932390613364987, 0.22970935591729358, 0.2528693061321974, 0.10111270792549476, 0.21088489884277806, 0.13807976647512987, 0.0893636344699189, 0.15180791029706597, 0.07865961626521312, 0.1546257411246188, 0.11346797502483241, 0.11938052455661818, 0.10939373270957731, 0.21928747999481857, 0.10644008885719813, 0.10722409366280772, 0.08666972746141255, 0.1131661213003099, 0.18509703339077532, 0.09753110323799774, 0.11918698728550225, 0.09729642129968852, 0.10151611713808961, 0.1739520236151293, 0.11573086492717266, 0.12461416481528431, 0.1272982606315054, 0.12335917082964443, 0.10679762592189945, 0.1338603749172762, 0.13225577742559835, 0.16243218473391607, 0.10391454547061585, 0.2600164257455617, 0.06924254150362685, 0.1465588333667256, 0.12714748590951785, 0.09954403780284338, 0.08232017804402858, 0.1627347434987314, 0.09805521534872241, 0.12512299610534683, 0.17723981203744188, 0.08184318488929421, 0.15538993058726192, 0.20705799950519577, 0.19119914970360696, 0.23010729550151154, 0.1244618983764667, 0.11065823360695504, 0.17054045980330557, 0.16551609034650028, 0.0922918671858497, 0.10622245405102149, 0.21343937114579603, 0.14389621530426666, 0.11842664214782417, 0.1308781880652532, 0.10093678924022242, 0.14384272129973397, 0.1634821158950217, 0.13837343431077898, 0.08752526046009734, 0.16968546115094796, 0.14684334310004488, 0.16884790296899155, 0.12795480899512768, 0.24276953714434057, 0.0842938307323493, 0.1292454483336769, 0.11172839571372606, 0.12116677011363208, 0.11697288617142476, 0.2212376956595108, 0.11897772390511818, 0.09599653480108827], [0.026398194713692646, 0.025979051970352884, 0.04715589639090467, 0.03601447861001361, 0.06711276320856996, 0.025532958134135697, 0.043074202912976034, 0.06404860614566132, 0.03828237429843284, 0.015956915340211708, 0.02494520686013857, 0.04641522187739611, 0.0253747804890736, 0.003997071016783593, 0.06175221198645886, 0.04020324173325207, 0.020097409178561065, 0.049120710100396536, 0.06647319518378936, 0.012705161898338702, 0.051013702468480915, 0.04597216713591479, 0.04434118258359376, 0.03405747229408007, 0.02721749791817274, 0.03445681824814528, 0.046414587341132574, 0.04278516978956759, 0.028541446699819062, 0.04441433608008083, 0.019043724605580792, 0.053355144991655834, 0.03815167467109859, 0.02426042534352746, 0.02313618293555919, 0.021118105287314393, 0.024629766267025843, 0.011832636500912486, 0.035286428028484806, 0.010242017360724276, 0.04270695484592579, 0.04695716408605222, 0.07215251738671213, 0.03560073128028307, 0.05531830000109039, 0.02270537177537335, 0.047267340996768326, 0.011509886680869386, 0.04945860993757378, 0.009716890363051789, 0.04707082771346904, 0.04715591865533497, 0.04236126987962052, 0.04993487207684666, 0.04973585775587708, 0.04734682501293719, 0.04290205062716268, 0.02155986312573077, 0.06631593409110792, 0.03600078598537948, 0.04531248690909706, 0.05152588455530349, 0.07287778120371513, 0.04106347252673004, 0.04213049163809046, 0.03796529541432392, 0.035490177251631394, 0.03274883587437216, 0.05360755312722176, 0.06418790726456791, 0.03387011711311061, 0.021350859497033525, 0.03223292078473605, 0.025021295550686773, 0.021967005341139156, 0.028616720883292146, 0.041838898105197586, 0.1017163040523883, 0.08412888841121458, 0.05376048378820997, 0.05024959464208223, 0.03915126966603566, 0.08594480503234081, 0.11886263164342381, 0.06100824233726598, 0.04128137450607028, 0.09891283378237858, 0.02142612440366065, 0.04847350537602324, 0.010498806022951612, 0.027939108513237443, 0.03585146216209978, 0.028267022753425408, 0.05449787429824937, 0.03556038071110379, 0.026151649544772226, 0.06451481589465402, 0.013362865229282761, 0.008610649674665183, 0.03449690164416097, 0.03242070641135797, 0.059105164182255976, 0.032582772910245694, 0.029037498206889722, 0.03962137569033075, 0.05627110629575327, 0.05530601745704189, 0.03228360947105102, 0.05488593960762955, 0.03716566840012092, 0.06380456572514959, 0.06953103656996973, 0.025731029927555937, 0.02160547737730667, 0.011808264371211408, 0.074153050663881, 0.09384471472003497, 0.011958963023062097, 0.00903707288671285, 0.022212069925444666, 0.008729866422072519, 0.034799556888174266, 0.023051509451761376, 0.027465859493531752, 0.0498886065906845, 0.07782654807670042, 0.06457556810346432, 0.01057892179233022, 0.028646657265198883, 0.028556356446642894, 0.022364970900525805, 0.012329144428804284, 0.033751970913726836, 0.03825050647719763, 0.025513137225061655, 0.031661352040828206, 0.08714904353837483, 0.03569238651834894, 0.01063876672560582, 0.075095429783687, 0.021151229193492327, 0.03485808636469301, 0.06483653691248037, 0.06107327302743215, 0.07155773797421716, 0.03615918627474457, 0.06466181308496743, 0.020822942024096847, 0.021148969353816938, 0.043051942193415016, 0.06731339541147463, 0.070449540799018, 0.0223233197175432, 0.02328386475710431, 0.01881500953459181, 0.04657041979953647, 0.013058928852842655, 0.05485600508109201, 0.009340746728412341, 0.039299313284573145, 0.05235234020801727, 0.11740414818632416, 0.022152314049890265, 0.015115363476070343, 0.01697805302683264, 0.010681545045372332, 0.011359586933394894, 0.0429645023541525, 0.031151073562796228, 0.03660976639366709, 0.08030178869375959, 0.07472313882317394, 0.044638464678428136, 0.06501379888504744, 0.040416178744635545, 0.018484501488273963, 0.05627328820992261, 0.08796122769126669, 0.017507929769635666, 0.060129372504889034, 0.05210379866184667, 0.04431885878148023, 0.03128569915133994, 0.07656324945855886, 0.04990897112293169, 0.019557689702196512, 0.019280530941614415, 0.04787618410773575, 0.0563809627055889, 0.019472602471068967, 0.01672028287430294, 0.062369623192353174, 0.03441982589720283, 0.04394722833239939, 0.06392877156031318, 0.0565407990507083, 0.05067687503469642, 0.037784318992635235, 0.020075695792911574, 0.037634984037140384, 0.09785070913494565, 0.021695865398214664, 0.039129999713622965, 0.03269036576966755, 0.027317765780026093, 0.051317144389031455, 0.03332733998831827, 0.05798078447696753, 0.046140259873936884, 0.005362136635085335, 0.026476745479158126, 0.008728509219508851, 0.05163328445632942, 0.045033595233689994, 0.036625785651267506, 0.027768331055995077, 0.016822942307044286, 0.0193923225015169, 0.03363826275744941, 0.001847524458753469, 0.048622877438901924, 0.09571783608407713, 0.016753659110690933, 0.04546079770079814, 0.025166878949676175, 0.0048545618938078405, 0.042371344534331, 0.010912532943621045, 0.03388857061509043, 0.05264362203888595, 0.06217312104126904, 0.024604718782939017, 0.03937514964491129, 0.03137073072139174, 0.07136521002394147, 0.036705633319797926, 0.008437886972387787, 0.02547880547353998, 0.008563576175220078, 0.02170029973058263, 0.04385651933262125, 0.029084572634019423, 0.01983855734579265, 0.03378354187589139, 0.059401971302577294, 0.06598115127417259, 0.04391818438307382, 0.02139212105248589, 0.028298964789428283, 0.027862763781740796, 0.015538077805103967, 0.10396089259302244, 0.045209358067950234, 0.08610807009972632, 0.02506018408894306, 0.05142315276316367, 0.025103143307205755, 0.04063498243340291, 0.03749704104848206, 0.07227690875879489, 0.12036205196636729, 0.01206051480039605, 0.17868312599603087, 0.052281761963968165, 0.02603168693894986, 0.023340626066783443, 0.011481577457743697, 0.04368987378256861, 0.04694953480793629, 0.05043217781349085, 0.060543142099049874, 0.06684961248538457, 0.07220486848382279, 0.04456359311006963, 0.018416624661767855, 0.05950911887339316, 0.007123192308426951, 0.043071508916909806, 0.041213905860786326, 0.019964828206866514, 0.06311164470389485, 0.009532569638395216, 0.008197484003176214, 0.03632926796854008, 0.009864061958069215, 0.11113235465018079, 0.04960024140018504, 0.04563132097246125, 0.08860202025971375, 0.02202348092396278, 0.05789814633317292, 0.07815137869329192, 0.055536194558953866, 0.01752150921674911, 0.03331983316456899, 0.021310271440597717, 0.04471027117688209, 0.031929297038004734, 0.08191518805688247, 0.02531609330617357, 0.020236433847458102, 0.03421925306611229, 0.005888968717044918, 0.03145614449749701, 0.01066186328898766, 0.04943653846567031, 0.04436173265276011, 0.02005178565013921, 0.009919366802932927, 0.022894873618497513, 0.043676084678736515, 0.03306881284515839, 0.026231081610603724, 0.04061610219650902, 0.07462549445335753, 0.016755735268816352, 0.03198178172169719, 0.020476088175200857, 0.019498510846460704, 0.03594953697756864, 0.07261230013682507, 0.03864281687128823, 0.035724284025491215, 0.024899575910239946, 0.08368336231797002, 0.01463678769141552, 0.046277212095446885, 0.054346583783626556, 0.07139077701140195, 0.05203937653277535, 0.02197908379457658, 0.031158817873802036, 0.021013332589063793, 0.025371006668137852, 0.03284327045548707, 0.02855413556972053, 0.04861621666350402, 0.026160829911532346, 0.09507503229542635, 0.01904531836771639, 0.04155586524575483, 0.018643521470949054, 0.04125119136006106, 0.016767216293374076, 0.05143393987964373, 0.04478723189095035, 0.01842445803049486, 0.039446351293008775, 0.03968603159592021, 0.04274595470633358, 0.045880140824010596, 0.007368868236881099, 0.19778324640356004, 0.15258948085829616, 0.1162711187498644, 0.1265431402134709, 0.194068901182618, 0.08837328292429447, 0.09137190092587844, 0.1865455720690079, 0.0984164112014696, 0.0768740163766779, 0.07241457715281285, 0.21883430978050455, 0.12044189963489771, 0.09567821281962097, 0.14132310025161132, 0.10259882154059596, 0.11638165422482416, 0.12244265555636957, 0.11297112199827097, 0.14964324363972992, 0.1450317309354432, 0.12530255131423473, 0.15215728373732418, 0.16188654291909188, 0.2207691184594296, 0.1453359966399148, 0.09841433318797499, 0.13743423158302903, 0.0884751723788213, 0.13479123590514064, 0.18342924944590777, 0.09423442388651893, 0.17805768846301362, 0.15097002557013184, 0.12227265178808011, 0.10231698353891261, 0.1984227995853871, 0.09308254389907233, 0.11745296666049398, 0.14839459501672536, 0.10835802109795623, 0.15538038656814024, 0.14596809865906835, 0.12487017607782036, 0.268511523026973, 0.18603013566462323, 0.13626557163661346, 0.18584902194561437, 0.12681023916229606, 0.09394567648996599, 0.21150689281057566, 0.15319928876124322, 0.13560716790379956, 0.1266119521460496, 0.1383701985469088, 0.13839670806191862, 0.10816604975843802, 0.10439356468850747, 0.183993162936531, 0.1466902974061668, 0.17606899986276403, 0.1111900714749936, 0.14810204040259123, 0.0997078965883702, 0.11648852349026129, 0.11000142549164593, 0.08330160155310296, 0.17931199225131422, 0.12090435411664657, 0.16610364866210148, 0.11021391721442342, 0.09231805757735856, 0.14065669616684318, 0.09767028561327606, 0.07961053750477731, 0.20507398643530905, 0.1646389756933786, 0.2848426310811192, 0.19319036160595715, 0.22229671070817858, 0.20003076642751694, 0.1522942545125261, 0.19726950209587812, 0.12115281773731112, 0.21357418969273567, 0.17019602906657383, 0.25053519231732935, 0.12529665866168216, 0.08085010224021971, 0.2600749960402027, 0.14120450505288318, 0.09591460911906324, 0.1123357322649099, 0.09454593295231462, 0.15892210823949426, 0.15074644616106525, 0.18449187133228406, 0.10384756664279848, 0.11715798522345722, 0.1354538105078973, 0.1500281214248389, 0.11226449350942858, 0.1722892714315094, 0.1378628663951531, 0.08715077274246141, 0.1504773582564667, 0.21628224203595892, 0.13735057669691741, 0.0945524638518691, 0.17400906508555636, 0.11439337380579673, 0.1813887886237353, 0.1851822913158685, 0.10245416953694075, 0.20471595955314115, 0.17002621083520353, 0.2119527306058444, 0.07279845303855836, 0.08186477396520786, 0.142339026206173, 0.22119851026218385, 0.1635285743395798, 0.13456045766361058, 0.11463077200460248, 0.13416771311312914, 0.16321794100804254, 0.11764901239075698, 0.12715524877421558, 0.1298335855244659, 0.12544299534056336, 0.11002962710335851, 0.15772650833241642, 0.10426154403830878, 0.11439275782322511, 0.11253806398599409, 0.07690827391343191, 0.18431641277857125, 0.14029794197995216, 0.225533944030758, 0.09875473406282254, 0.13552220683777705, 0.08771307577262633, 0.15361429774202406, 0.14260133088100702, 0.13140604802174494, 0.10430392809212208, 0.15386207116534933, 0.09684073520475067, 0.20877081697108224, 0.11609777531703003, 0.23344602494034916, 0.19326554116560146, 0.10931746961432509, 0.12863222655141726, 0.13327756634680554, 0.0731467577861622, 0.13751154852798209, 0.2228942434885539, 0.10104609275003895, 0.08557141569326632, 0.16957409447059035, 0.12472000991692767, 0.18887508456828073, 0.12484408216550946, 0.15569717972539365, 0.12779204116668552, 0.10869205434573814, 0.12259944167453796, 0.14157980913296342, 0.20551557914586738, 0.20105283736484125, 0.0998641483602114, 0.12937027757288888, 0.18084314680891111, 0.09335638154880144, 0.07303137608687393], [0.03490282302664127, 0.0266260971329757, 0.028773061712854542, 0.036343502360978164, 0.02832759499142412, 0.05207324444199912, 0.06103998399339616, 0.031073391110112425, 0.038142705816426314, 0.022848032967885956, 0.08710924215847626, 0.04268635282642208, 0.02131458888470661, 0.02357442856009584, 0.057011550743482076, 0.031676922299084254, 0.08210212021367624, 0.022557313313882332, 0.05062833857664373, 0.004674701012845617, 0.03831783040368464, 0.037837486452190205, 0.04986864281818271, 0.05129113211296499, 0.04227514364174567, 0.04752748231112491, 0.007707825170655269, 0.036009216782986186, 0.01995723789150361, 0.14949471020372584, 0.018649018929863814, 0.05206834997807164, 0.012969120634807041, 0.014515111652144697, 0.034058923192787915, 0.01685828152403701, 0.010338411211705534, 0.03412174970435444, 0.026434400388097856, 0.06397060642484576, 0.010177011718042195, 0.026552977033134084, 0.04917388127068989, 0.07950706727569923, 0.030619551107520238, 0.05967955679807346, 0.053968615393387154, 0.05143960617715493, 0.02937827757705236, 0.03840899582428392, 0.07678325913730077, 0.05043995923188049, 0.0053028752154204994, 0.014246176815504441, 0.057949877736973576, 0.04468064093089197, 0.024501506450178567, 0.013411534346232656, 0.03184423207130749, 0.021579973472398706, 0.01694576960289851, 0.022259867946559098, 0.01302487540669972, 0.03191604228049982, 0.011100765714218142, 0.01649520061619114, 0.0242290992900962, 0.016612215040368028, 0.03372060033143498, 0.05724942762753926, 0.08113736534141935, 0.014552431475749472, 0.014272282787715085, 0.0486132777587045, 0.01742311713314848, 0.03054434371733805, 0.15745381359010935, 0.07651123232790269, 0.1452171491109766, 0.2704391477163881, 1.27035828307271, 1.312139534857124, 1.389301281888038, 2.0435270201414824, 1.5085100289434195, 1.4403514238074422, 1.0389952291734517, 0.3040905873058364, 0.1092438559862785, 0.07626112856087275, 0.0390333424002165, 0.011839667422464117, 0.06619573585339822, 0.03370414691744372, 0.04856004350585863, 0.007213877188405604, 0.022733228288416285, 0.025518771981296595, 0.182428611733485, 0.10301931499270722, 0.1367779355496168, 0.15008029440650716, 0.030255204837885685, 0.029794715192110743, 0.03083368112129392, 0.0032133911327036913, 0.029791664965159725, 0.025910577714967076, 0.01331490115262568, 0.02030108604230918, 0.055973211929085664, 0.03446616930887103, 0.13245602371171117, 0.02012956829275936, 0.020372020517243072, 0.03952523416955955, 0.1191182347247377, 0.06280591696850024, 0.020108927310502622, 0.039544619066873565, 0.07685580407269299, 0.017211605045304168, 0.05345292294805404, 0.044217407194082625, 0.009670642502896953, 0.030050097484490834, 0.018504632244003005, 0.01356713859422598, 0.014986766909714788, 0.017846141308837105, 0.08776746777584776, 0.03836251511529554, 0.10880225585424341, 0.07601270204759203, 0.04556177431368269, 0.07100263377651572, 0.027937781924265437, 0.0203356960992096, 0.02742328248132253, 0.01692766119958833, 0.036148840736132115, 0.00892448537342716, 0.08840355512802489, 0.08196396942366846, 0.05710373661713675, 0.0351074925129069, 0.030564155349566136, 0.04025970432849135, 0.039660523980273865, 0.05677407832990866, 0.017946290427062195, 0.05373611536924727, 0.05709701275918633, 0.04622643435141072, 0.08936949743656442, 0.03641168717877008, 0.07613514899276197, 0.010264581433148123, 0.023955487995408475, 0.007298806249309564, 0.024712901649763808, 0.04211108447634615, 0.006491137137345504, 0.055118877498898655, 0.054684082861058414, 0.09039654818479903, 0.01724113324598875, 0.08013371450942941, 0.028347317565931007, 0.04908839699055534, 0.07845056810765527, 0.02079923782730475, 0.09004454012028873, 0.058058309223270044, 0.04655938035284635, 0.09270649024983868, 0.043532627532840706, 0.022927500285732094, 0.005643541871904745, 0.018375762010691687, 0.047192243073368445, 0.054059688045526855, 0.03861635188513901, 0.015196031217783457, 0.03527811597450636, 0.02730597676418256, 0.014125474845059216, 0.04252331411407795, 0.03317792339657899, 0.07677071684156545, 0.022003441081324127, 0.024669704944244586, 0.05671111081028357, 0.02711220942728687, 0.03803254141530488, 0.004875107788393507, 0.024111340862873476, 0.019843338632199448, 0.13180901936721057, 0.05486267327796668, 0.036471081257332116, 0.04345148852735292, 0.03710176206368487, 0.05942945303104352, 0.04368867521407083, 0.03521698155964259, 0.018503860410419293, 0.038080747617641464, 0.019159687035426032, 0.03659229623735882, 0.04265365008905064, 0.0013548702486332331, 0.04547858326986898, 0.0358611063711578, 0.02805115425871918, 0.08281205868115649, 0.02038770395301981, 0.04093963776540477, 0.03575022208679002, 0.09142454146058299, 0.06431189045542851, 0.11500735257868655, 0.007670173699807492, 0.03345648852700833, 0.052633205996244214, 0.02787915782391792, 0.0394534054066753, 0.01534640146928723, 0.04960517668223474, 0.04272678503184579, 0.036855309663224034, 0.008719637771719135, 0.07298049444216304, 0.0538751418935135, 0.06169204607431311, 0.013581153125414858, 0.023790308187017217, 0.0897977314889431, 0.024747546958678868, 0.06912719691172242, 0.03137548788799904, 0.030929343956813682, 0.05522160186956171, 0.03392302482097875, 0.06588859061594121, 0.0185200596388313, 0.10155588883208111, 0.030477361178782303, 0.022792755953560118, 0.05444518552394584, 0.004958620274919667, 0.09130306672886945, 0.19215295789763331, 0.17380988749209791, 0.787204293301329, 0.8345884631853551, 2.147240317426622, 2.1007735608145595, 2.592373131774366, 3.964196420274675, 3.077468639239669, 2.311635883525014, 1.9784502871334553, 0.2135246290708892, 0.1730537725961767, 0.022204451779543888, 0.0541578778938856, 0.06285987110459246, 0.03898187445884105, 0.039002161065582186, 0.012390279771352652, 0.04571350269543473, 0.0802954359096475, 0.11415040207793936, 0.23250703001394868, 0.18613841501064599, 0.3516513289650902, 0.29941520537249744, 0.05847646119946148, 0.0468574862316018, 0.005445090191642521, 0.050443577201804146, 0.07535163400461897, 0.044286527117947116, 0.05234031370491721, 0.027397342564654537, 0.03027528178790817, 0.0367015663505299, 0.14185098989401013, 0.0936812641157303, 0.03176376470946707, 0.03480641433270648, 0.06013883488776628, 0.018661503709154204, 0.025926376183633693, 0.04237342254782561, 0.08725062129087746, 0.012972916720173089, 0.09957090354873799, 0.03429204662097618, 0.0348570473579457, 0.010010663954744814, 0.0715538788062986, 0.03660209629742894, 0.02499907379387878, 0.04707734377007, 0.013241705910331802, 0.027032089019485284, 0.02446503916871734, 0.0600680080242455, 0.040370310307480395, 0.08584918672568165, 0.01823713624617085, 0.032943456681095995, 0.03948243822378572, 0.05344890050764661, 0.06160300690680742, 0.020509789101197384, 0.06398625831934623, 0.008149587647494627, 0.00866010175741394, 0.0614527145808097, 0.01644977932301117, 0.0384233638033038, 0.011825904293800704, 0.039899484399938956, 0.03134394661174156, 0.05369916383642703, 0.03753243036044296, 0.05213485383137595, 0.07211290154373273, 0.081823488289956, 0.039675545049249195, 0.022806183260399848, 0.018971532190334983, 0.043439918445074, 0.026056650931423064, 0.007681657971261302, 0.030984739714767784, 0.029028701901552267, 0.05203903143410571, 0.0552808734937571, 0.04905340101686306, 0.026174990089202765, 0.06507246565888636, 0.02267070420202799, 0.04991589165001642, 0.07653127773664892, 0.031483303391723894, 0.09380329545820132, 0.0747037168184761, 0.0608911165909376, 0.07460446198820136, 0.08372697833692655, 0.08044913469348103, 0.08864429299137555, 0.10892284000874497, 0.21899341139942408, 0.14385101851075888, 0.10248313556076027, 0.13000784179894254, 0.10606070296489634, 0.16204395244130865, 0.14499612268991768, 0.15969858766766265, 0.1809146601590328, 0.1879951052251272, 0.18388687254628167, 0.16228467546170577, 0.10932320641586557, 0.07863610502681695, 0.06309263088041916, 0.13229594245785847, 0.10082242428325117, 0.15261544118402526, 0.11182318281498738, 0.17490295227617025, 0.17674006463494152, 0.18673401820706204, 0.15279593149898574, 0.2181321638636291, 0.35017386137042195, 0.07445553521392867, 0.1049750299716834, 0.1179868751205504, 0.20681068621343002, 0.16384312621084973, 0.11021668542525731, 0.17299066035775468, 0.168573412229307, 0.09728081393404864, 0.17742137104505673, 0.13625003106426448, 0.17899919184856117, 0.1285565274883993, 0.17236648447578773, 0.15963658865075558, 0.22462720284238458, 0.1811213482869789, 0.17022317682858557, 0.15281895291991532, 0.11853741511004046, 0.1358899410115555, 0.08715937423403375, 0.1336649525910616, 0.10562553725321777, 0.10193873313255608, 0.11618054704740644, 0.129195011977572, 0.18352834100369364, 0.11912372661754489, 0.1780707502621226, 0.1691409622435458, 0.2486147516174242, 0.1835818201652728, 0.14515984046738595, 0.13771623285720125, 0.13315583928488195, 0.11420958093367517, 0.113531673559919, 0.19905401102732867, 0.08922519424231723, 0.24659927148604766, 0.14885107520967722, 0.08751184985158034, 0.12941587512614205, 0.10272999614244327, 0.17069504916435108, 0.2684923162451014, 0.23290002689464018, 1.0235078539699316, 1.0058070975355804, 2.2075756173580885, 2.41428405046463, 2.925494844093919, 3.9933239948004484, 3.282929789274931, 3.318899371661246, 2.584611098282039, 0.6948955496773124, 0.353444060892798, 0.1328071634634398, 0.16587892634561285, 0.23689609137363732, 0.13729200640227646, 0.22687917575240135, 0.14497094904072583, 0.09224922338034958, 0.2098500035936013, 0.37097136257216334, 0.3454983310075477, 0.36970386339817196, 0.4152201069518924, 0.4328729206463322, 0.12910936813568696, 0.0979305048531387, 0.14339107990963385, 0.10987529749399982, 0.21694999682949856, 0.15296297409804538, 0.12717099714791402, 0.08185488113667816, 0.22554761439096183, 0.13188685581553727, 0.5100852227769792, 0.1340959474327974, 0.16822019446408376, 0.16371423000236973, 0.1641803135862574, 0.1349868215038441, 0.12633949489099905, 0.11658226416329853, 0.2175915241241455, 0.12071683566318825, 0.17553633078932762, 0.07449535143678077, 0.14173753035720438, 0.13114586588926613, 0.12025554635329172, 0.07725221483269706, 0.12569235695991665, 0.13485037023201585, 0.0992714766471181, 0.06824374431744218, 0.14381039334693924, 0.1273923649569042, 0.09736989391967654, 0.22770270734326914, 0.17645132465986535, 0.20264210208551958, 0.1901116213412024, 0.1178170791536104, 0.09984721255023032, 0.13609763846034184, 0.161822599475272, 0.17718967254040763, 0.11829338953248225, 0.09325885592261329, 0.0718859230983071, 0.14171983755659312, 0.09663000237196684, 0.19934577896492556, 0.09864666993962601, 0.10674424323951825, 0.15479852794669569, 0.229145293997135, 0.20344224118161947, 0.16288262384478003, 0.20882496406557038, 0.09727889177156612, 0.12137874233303592, 0.08503467222908512, 0.12174572693766095, 0.20953837578417733, 0.11578181336517446, 0.12380136467982084, 0.13193678751122206, 0.17386915540555492, 0.13808849413180724, 0.14289465732872486, 0.13099161791615188, 0.0879766272555571, 0.1625455403700471, 0.17866014910396188, 0.14120967040071264, 0.10590113379294053, 0.15051485155709088, 0.1690008447621949], [0.06354686978738755, 0.09948076229193248, 0.033486638276372105, 0.019427737788646482, 0.10047788222436793, 0.020862381607003044, 0.04219581176585052, 0.02358737347094575, 0.016221314726863056, 0.03669464211270679, 0.032565388100920245, 0.03759170198463835, 0.01730397460050881, 0.03923976335499901, 0.038154917856445536, 0.05796849822218064, 0.038060093647800386, 0.07215158228063956, 0.049621500220382586, 0.042159747099503875, 0.03595113259507343, 0.020324682627688162, 0.019959186029154807, 0.06295221653999761, 0.03506692672090139, 0.058736802893690765, 0.02678332668438088, 0.023293787271541078, 0.0354032643372193, 0.09090278195799328, 0.03875110734952614, 0.04041546257212758, 0.007224298333312618, 0.05226767229032703, 0.04690356247010641, 0.16592038271483034, 0.026171481586061418, 0.062110387298162095, 0.04253197126672603, 0.02631735071190633, 0.01758889622578863, 0.02243027432996314, 0.03697282503708266, 0.051491975827957503, 0.02441503882437246, 0.03936947963666171, 0.055671617956249975, 0.03819641504378524, 0.0478706625290215, 0.0697439513169229, 0.06184876910992898, 0.032075796989374794, 0.04062271102156956, 0.030583699808630627, 0.03939044901926536, 0.06807759971707128, 0.03371510101715103, 0.034863337059505284, 0.038782400006311946, 0.023807071447663475, 0.07468711497494951, 0.07416450200253166, 0.06136188312666491, 0.019303082954138517, 0.05358957088901661, 0.07027008206932805, 0.07418737499392591, 0.03323356591863558, 0.022415180901589338, 0.01970421933947364, 0.12894820334622636, 0.038843564107082784, 0.018071464764943812, 0.2710520726395771, 0.5356252554338425, 2.3286558827385306, 4.056360237300396, 15.50730798393488, 14.059757608920336, 17.58129369467497, 22.812385596334934, 26.42224509268999, 27.587511464953423, 34.91220362484455, 27.46162422001362, 18.905420042574406, 18.293820060789585, 12.155420444905758, 4.612902598455548, 3.6596933472901583, 1.571550783701241, 1.434675834607333, 1.3043095800094306, 0.990367338526994, 0.9017606056295335, 1.6655453899875283, 2.375602601096034, 2.6939081959426403, 7.179227415472269, 6.125143077224493, 6.675522644072771, 5.91760391369462, 2.564471228979528, 1.568802937399596, 0.32828602648805827, 0.2552729443414137, 0.05649045546306297, 0.017837818122643512, 0.012100403382646618, 0.044683242158498615, 0.05238937708782032, 0.07829044232494198, 0.015450010851054685, 0.02333263499167515, 0.01674482940870803, 0.04056424462760333, 0.07193871206254698, 0.07161428962717764, 0.03479908191366121, 0.06066401198040694, 0.03678714710986242, 0.0875578036357183, 0.0142039801539795, 0.034742452335194685, 0.05859555363713298, 0.019625572094810195, 0.07595598712214269, 0.02784467207675334, 0.048348557393183, 0.06834768209955655, 0.011440838188718772, 0.05535433869226836, 0.023613599114469253, 0.04057631565956399, 0.050586941579240374, 0.03792936433455907, 0.026748994932859205, 0.0745818561699707, 0.059685961532522924, 0.03097033462836407, 0.03250868430768605, 0.01371062449834426, 0.043684552583727054, 0.03675647414638661, 0.03488321919576265, 0.042530390492174774, 0.08330569078680128, 0.020979173386876937, 0.05830850946949795, 0.007632211454620119, 0.03661726208520122, 0.023866031369834673, 0.028597924138011876, 0.04743402365420479, 0.02959486224426655, 0.026045852682727855, 0.05133901177032385, 0.062371678941417485, 0.019621334431576543, 0.026209073221252766, 0.04513371466600802, 0.062035152077442035, 0.08215747700887732, 0.045201717657619156, 0.07642739190487191, 0.032069039734778926, 0.011783016507251887, 0.045722783252131194, 0.02765763787465403, 0.029324956121854484, 0.057361514191143215, 0.02264289592858404, 0.12962520529981703, 0.009318594547949033, 0.01627184756216593, 0.022752051008865237, 0.042971255898009986, 0.0904509772954043, 0.03548474844137672, 0.0667393664480187, 0.03905197401763871, 0.05856166717421729, 0.019836965439026244, 0.09477177591179498, 0.03515395466820337, 0.028003397055726964, 0.038083961117081344, 0.00722772380868264, 0.016627497716399375, 0.019143877434544265, 0.06597269079065882, 0.05868319014552981, 0.012446571672626305, 0.0481124097132124, 0.019204184354748577, 0.017582649197720457, 0.04333312710514292, 0.02872647895856062, 0.0529107432521414, 0.0447520763555076, 0.026956991096085403, 0.042990214060409926, 0.04633399752492551, 0.049227341878577136, 0.01907264053443214, 0.03491686446068343, 0.03287178376922384, 0.019030796393053606, 0.027377913138479926, 0.04670875612646341, 0.036926678294548765, 0.04298340114473831, 0.03336304842378013, 0.040401076039415784, 0.06457345298258588, 0.023830849859223235, 0.03355580643983558, 0.05557651544222608, 0.02511463546397863, 0.10501710974494927, 0.05461548615130596, 0.02571049099060474, 0.06710730100166984, 0.024647809732414316, 0.03458674604189582, 0.018266391707584262, 0.039651009647059254, 0.015915562871668953, 0.024078951682895422, 0.006779865052521927, 0.05946363635302987, 0.0736523607338313, 0.024608342318970244, 0.038108210792415775, 0.06868621276225895, 0.031225236380123533, 0.02676175245142076, 0.051037365847150795, 0.02522128022974357, 0.021815664731548168, 0.06794462911784649, 0.029237466187623795, 0.04708787484560162, 0.053419663599925116, 0.04871285542321857, 0.04441835109901149, 0.07228583679534495, 0.051924855724791996, 0.05393656203523278, 0.5358078237622976, 1.1633838107809424, 4.854866489768028, 7.290848800912499, 22.27544780820608, 23.658056817948818, 24.513238929212093, 31.51568368077278, 38.224964663386345, 39.23751913011074, 44.258242920041084, 35.54896965622902, 25.260523930191994, 23.814553320407867, 16.0753471031785, 6.232730504125357, 4.105225615203381, 2.1543371491134167, 1.640446549281478, 1.3734284648671746, 0.9665353142190725, 0.9742458129767329, 2.0902293641120195, 3.286851178854704, 4.005218781530857, 9.576288890093565, 8.859659694135189, 11.039938051253557, 8.89389680698514, 4.734602468088269, 2.289687073789537, 0.5082812695764005, 0.36351230344735086, 0.008345394035131903, 0.07262027080287226, 0.036008077586302534, 0.03510334019665606, 0.033277137408731505, 0.05219705693889409, 0.10824339638929814, 0.00638842157968611, 0.020051885840075556, 0.02207554814958712, 0.03612716631323565, 0.004225055999995675, 0.012331385714787757, 0.033501637080917135, 0.01831238630984444, 0.018333941989112645, 0.04504373297095299, 0.022934166627237573, 0.027317678577674087, 0.020851650151598733, 0.015977105467754882, 0.02473497312166728, 0.030791182034590747, 0.07651675390661694, 0.05083675219793804, 0.012212437995913206, 0.059135332485311665, 0.0413189049140783, 0.04113372051506303, 0.03161622204061132, 0.037737292805104516, 0.06847136843134649, 0.022776471378165297, 0.03788930320297368, 0.04269216755346861, 0.03419882545131259, 0.08896757251932286, 0.02692583202588139, 0.015217939417198068, 0.03960459573136177, 0.05632655957015231, 0.031565058379783295, 0.018145108078897465, 0.04005524635431357, 0.020029875595355406, 0.07371978485025465, 0.0077355313987936825, 0.006325262957034283, 0.007880597149778623, 0.045141963637433946, 0.03640041024482343, 0.03587824998248834, 0.0714372651418671, 0.07603361576911993, 0.020802939288842026, 0.061642934451811016, 0.01124622387578711, 0.030454721963906195, 0.03486063193122391, 0.032225866671069525, 0.05307498053298332, 0.07089286271366291, 0.022230955728446133, 0.013736002238147194, 0.05654056527419016, 0.02646448334417073, 0.02904120337916538, 0.03515496398904361, 0.025266512275265995, 0.06109914058470167, 0.19288219220470637, 0.18624322110554203, 0.09385418452438898, 0.10321646652300842, 0.14335164218209684, 0.10756985284388065, 0.18010515515925363, 0.15820448112208396, 0.15966881270287558, 0.13269659830257297, 0.12428596484824084, 0.1204250380396843, 0.18597364338347688, 0.12877504545031115, 0.14275269932113588, 0.1832834619563073, 0.09244496483006515, 0.11731430378858931, 0.09590548812411726, 0.1687704079085961, 0.15334262716351077, 0.09728357472340576, 0.09320130979176611, 0.14682190987514332, 0.17190587794175372, 0.18732240772806108, 0.14936333522200584, 0.0908935496408958, 0.19446455495199189, 0.14205565938027576, 0.11843833839520812, 0.07256963406689465, 0.1339192717568949, 0.11003362727933563, 0.11539188897586428, 0.22507973480969667, 0.0667878361127805, 0.08783609417150728, 0.19159239891450852, 0.11782507208408788, 0.08146236665197648, 0.1403773220954463, 0.13835617195582017, 0.23801660077879205, 0.10741089965449646, 0.12973105040146038, 0.18104710383340716, 0.06254915613681078, 0.11714265987393446, 0.1825602538883686, 0.10812759166583419, 0.13207119045546278, 0.13895895914174616, 0.12055037193931639, 0.1777567178942263, 0.2015117072733119, 0.10337159765185788, 0.11044462124118581, 0.17439809889765456, 0.16724110872019082, 0.13987502170493826, 0.19719078991329297, 0.12080126980436035, 0.11139847396407276, 0.15927922970149666, 0.09904996783006936, 0.1753367969649844, 0.13369897264055908, 0.13439046131679788, 0.1900313951773569, 0.3367229690775275, 0.11312065733363852, 0.14017925772350281, 0.5007877154275775, 1.188206453807652, 4.505128031596541, 7.8430441953241825, 24.14133008569479, 27.477611862123013, 28.982686400413513, 35.57900324463844, 42.60022468864918, 44.125576838850975, 50.60085117816925, 42.65319384634495, 31.44244071096182, 27.168848030269146, 19.00104571133852, 8.94348794594407, 5.270589357241988, 3.374819071032107, 2.480027172714472, 1.8594912579283118, 1.2635640101507306, 1.7410208587534726, 3.0736944917589426, 4.186625322327018, 5.471488377079368, 11.432684976607561, 11.459975112229586, 14.820361845195293, 10.912926066666842, 6.186049059033394, 2.9354201490059495, 0.6752758962102234, 0.5437883455306292, 0.17032832431141287, 0.13818200473906472, 0.1572952908463776, 0.15808836469659582, 0.13321559701580554, 0.21143178746569902, 0.21954218507744372, 0.1682198976050131, 0.06241233379114419, 0.10873454230022617, 0.14587596844648942, 0.22299017349723727, 0.07877618540078402, 0.06971956434426829, 0.10774831709568389, 0.2778895682422444, 0.1625777644221671, 0.10993606454576366, 0.13579346181359142, 0.2423541125608608, 0.15135726338485256, 0.14173283998388797, 0.11318656746880151, 0.20747750590089709, 0.14384954905835912, 0.09874598414171487, 0.13069590175291523, 0.079728702257853, 0.12862277159001678, 0.14679097715998068, 0.12707551242783666, 0.14113787503447384, 0.11724833428161219, 0.09178990076179616, 0.0660515736672096, 0.06823532094131224, 0.15613106894306839, 0.10809855884872377, 0.12142199469963089, 0.09942278571543284, 0.20987958559999242, 0.11676086200168356, 0.20484350505284965, 0.09499867272097617, 0.13197083724662662, 0.20081022928934544, 0.15986951912054792, 0.1572028489317745, 0.1023878734849859, 0.13821936445310712, 0.12077875304385088, 0.31672075332608074, 0.15900637168670073, 0.11554757671547122, 0.10679322498617694, 0.1400450774235651, 0.20801384118385613, 0.24000600184081122, 0.251158329192549, 0.10238848946755752, 0.19866931135766208, 0.14273659471655264, 0.1726191709167324, 0.14134529046714306, 0.156861461000517, 0.15459514979738742, 0.17410279833711684, 0.09193407036946155, 0.1429511050810106, 0.1019370039284695], [0.08453607515548356, 0.04069200535013806, 0.02034300625382457, 0.04173075234575663, 0.02152082244720077, 0.03401697700610384, 0.02975808092742227, 0.016744367421779316, 0.039856896255514584, 0.017013440483424347, 0.019083815423073247, 0.006200056614034111, 0.04612006974639371, 0.025135146570391953, 0.035786212538369, 0.03846697240078356, 0.02992423666000832, 0.023095620854292065, 0.01475465373005136, 0.0934603861242067, 0.029840737624908797, 0.02559636352089001, 0.02168367376725655, 0.020324055512901396, 0.05862462356162723, 0.02746506354014855, 0.08410965936491266, 0.0323822557402309, 0.08633283694507554, 0.025431185567867942, 0.021777150977868587, 0.028302376813371666, 0.009736573047121055, 0.010858243913389742, 0.011242602195125073, 0.06614849815377966, 0.01753902390191797, 0.09038310046889819, 0.046469684384646825, 0.020983155009162147, 0.007939056122268084, 0.023600750682817306, 0.037259037999319844, 0.058872434092336334, 0.012218916017445736, 0.05833128969243262, 0.03281479795987252, 0.02682361788174603, 0.0324350187293021, 0.01146408596468973, 0.050858838512795046, 0.03407744719879702, 0.04146076644246932, 0.016209972854994703, 0.07573827810119838, 0.019833579390251543, 0.0203269535995787, 0.05362998454074841, 0.05927965423325077, 0.025068004470085725, 0.03528139626723714, 0.0032728728774600313, 0.010553005067777121, 0.018663034388737287, 0.03020851632754784, 0.03811710914305877, 0.03976246909587644, 0.0859503637184389, 0.0300054869876476, 0.16155897377757356, 0.7311371143441647, 2.2108999639749527, 5.511741042137146, 7.867446010932326, 19.38737478107214, 36.63726545870304, 44.93889279663563, 59.44563277065754, 68.73905628919601, 64.68326032161713, 60.928339809179306, 64.66228544712067, 75.33519834280014, 71.22532367706299, 72.70656779408455, 62.29698456823826, 56.437102407217026, 48.83228927850723, 31.903300881385803, 23.63968100398779, 17.66070943325758, 13.594107795506716, 13.212721310555935, 16.509768292307854, 16.94476705044508, 22.97669257968664, 35.12253373861313, 31.77402801811695, 39.935138896107674, 44.24305893480778, 37.935936972498894, 41.759493201971054, 36.08242303133011, 18.92059452831745, 6.3331011682748795, 1.1726599442772567, 0.05734861937526148, 0.03252041024097707, 0.1010726839012932, 0.041368940510437824, 0.10993376388796605, 0.061491373053286225, 0.05643628981488291, 0.04206897130643483, 0.05543076877074782, 0.028958034599781968, 0.03027196624316275, 0.052883228127029724, 0.032818096806295216, 0.025819082038651686, 0.028983579322812147, 0.06496524758404121, 0.041181956403306685, 0.09492114055319689, 0.035083086986560374, 0.03656332650280092, 0.031097251157916617, 0.03996861916675698, 0.0018391662524663843, 0.011826901554741198, 0.04287344454496633, 0.04420208184455987, 0.054565940372413024, 0.023159345364547335, 0.026516201760387048, 0.04462163276912179, 0.00859686891999445, 0.02222154158516787, 0.05447300492960494, 0.04637425532564521, 0.02643251162226079, 0.02735780279181199, 0.053446551610250026, 0.046128003305057064, 0.009565513573761564, 0.07415711021167226, 0.05041958727815654, 0.044262381343287416, 0.07026718769338913, 0.015528417825407814, 0.07122952316422015, 0.020772845200554002, 0.07466772265615873, 0.018408019459457137, 0.027863016111950856, 0.04633339267456904, 0.025060989319172222, 0.05048155660915654, 0.023694437550147995, 0.03424354727030732, 0.04870180113357492, 0.014609830104745924, 0.04648125817766413, 0.03512624287395738, 0.023076607030816376, 0.043211555894231424, 0.06145444749563467, 0.05782100750366226, 0.04936735916999169, 0.068523311347235, 0.010033171438408317, 0.02655527954630088, 0.034807842966984026, 0.06210319588717539, 0.06289268145337701, 0.06433627000660636, 0.026351615670137107, 0.039446158334612846, 0.06204563862411305, 0.017573825061845127, 0.06373573894961737, 0.09074372486793436, 0.05944960976194125, 0.048321973663405515, 0.0401278098433977, 0.03400427885935642, 0.027767540668719448, 0.02212202329246793, 0.01890348838060163, 0.13927257590694353, 0.01967610678548226, 0.018391031699138694, 0.01407114685207489, 0.0117314019917103, 0.03870604785333853, 0.05180122876481619, 0.015774345156387426, 0.013115970323269721, 0.04225153592415154, 0.02439071307890117, 0.033572133688721806, 0.1009054557653144, 0.044401133272913285, 0.10098508078954183, 0.03580171600333415, 0.058507564608589746, 0.03780319922952913, 0.049576926830923185, 0.01071566621249076, 0.049280854436801746, 0.017897091602208093, 0.06936921126907691, 0.015708702194388025, 0.05006481100281235, 0.041080282171606086, 0.056120413210010156, 0.046683693799423054, 0.022361343653756194, 0.01965061586815864, 0.062067995822872035, 0.023502631338487845, 0.06072861964639742, 0.05102535418700427, 0.043876954368897714, 0.01381945581670152, 0.00390631099435268, 0.08450008841464296, 0.04714425580459647, 0.039822642429498956, 0.019902330095646903, 0.05241473627393134, 0.03793908275838476, 0.022499470323964488, 0.007233700416691136, 0.012109875042369822, 0.01659730900428258, 0.009437756561965216, 0.059379179947427474, 0.027431334783614147, 0.020226670894771814, 0.07066958758514374, 0.024733930404181592, 0.07712893668212928, 0.08009582044905983, 0.09369295294163749, 0.3390111884800717, 1.5548658790066838, 3.9853828959167004, 8.895269483327866, 12.757910415530205, 27.407137043774128, 47.201667577028275, 57.06179268658161, 70.18829852342606, 81.66157767176628, 76.04443028569221, 77.44669944047928, 78.50869685411453, 85.77265307307243, 81.48570790886879, 83.6375780403614, 74.50818032026291, 66.95818305015564, 56.67886823415756, 37.691845670342445, 28.60081449151039, 20.624622590839863, 17.38569349050522, 17.030568346381187, 19.659563675522804, 21.082439124584198, 29.21676144003868, 40.75362257659435, 39.28706847131252, 46.31901673972607, 55.39609506726265, 47.66772396862507, 51.379095017910004, 45.255776792764664, 24.996238611638546, 9.81201209127903, 2.2453258791938424, 0.327340827207081, 0.02339187507459428, 0.08013628976186737, 0.07073629923979752, 0.010486221053724876, 0.09581847130903043, 0.06349355389829725, 0.01248512902748189, 0.011267499394307379, 0.018723658577073365, 0.030748389799555298, 0.01595815843757009, 0.07695033142226748, 0.037959922265144996, 0.054810040164738894, 0.015557432088826317, 0.0714409833017271, 0.026946330144710373, 0.03449000338150654, 0.0297814455916523, 0.023685546620981768, 0.018666335090529174, 0.12627163290744647, 0.04168612700595986, 0.020508835441432893, 0.020639041540562175, 0.04410616667883005, 0.01053505622621742, 0.011308915873087244, 0.021510857259272598, 0.017021813764586113, 0.04389092529891059, 0.03279106778791174, 0.0243488114210777, 0.03281811535998713, 0.06902209395775571, 0.03643314266810194, 0.028085161320632324, 0.050014118605758995, 0.07022976118605584, 0.03420973502215929, 0.05240179321845062, 0.014751209237147123, 0.0057530902904545655, 0.017644156541791745, 0.07121744100004435, 0.0179603429933195, 0.024073354034044314, 0.09324905957328156, 0.009704105013952358, 0.0088814742048271, 0.06687431858154014, 0.0375564128626138, 0.023840670328354463, 0.025371437113790307, 0.012913716527691577, 0.027861767448484898, 0.08235605346271768, 0.008671222840348491, 0.05346498284779955, 0.024623137032904197, 0.03717790270457044, 0.03170607757056132, 0.023203454911708832, 0.030983010510681197, 0.011575650241866242, 0.02147209488612134, 0.03424484973947983, 0.06230358689208515, 0.0571910131839104, 0.16739621758460999, 0.13654251146363094, 0.13304853957379237, 0.1340006259852089, 0.0887093051278498, 0.14296740264398977, 0.155582191364374, 0.06205768368090503, 0.13187278469558805, 0.08503096149070188, 0.1174783926398959, 0.08776534523349255, 0.1127495092805475, 0.17880503117339686, 0.10377848011557944, 0.13618801720440388, 0.12425745895598084, 0.08559852634789422, 0.07742304980638437, 0.21438063704408705, 0.12179972560261376, 0.08762047800701112, 0.12919011380290613, 0.1004643009218853, 0.1572018989827484, 0.2485620294464752, 0.2596659539267421, 0.18033330619800836, 0.16214571573073044, 0.13810921489493921, 0.2545017935335636, 0.2023175757494755, 0.059643147033057176, 0.11978069058386609, 0.08425470470683649, 0.16806415049359202, 0.10149027555598877, 0.16450141120003536, 0.1280067890184, 0.12602635310031474, 0.10624008747981861, 0.07831894821720198, 0.09672492305980995, 0.23028195253573358, 0.13170243211789057, 0.1651784873683937, 0.12037946275086142, 0.08315913146361709, 0.08612006320618093, 0.05036951457441319, 0.1682725307182409, 0.16948828735621646, 0.16931544116232544, 0.06434572496800683, 0.1824475364992395, 0.12090879215975292, 0.07045293983537704, 0.16427777241915464, 0.20936530694598332, 0.11026876192772761, 0.11925531682209112, 0.17020014056470245, 0.13950292370282114, 0.14205830142600462, 0.15412727021612227, 0.12295646665734239, 0.153674203902483, 0.2430006122449413, 0.10277249893988483, 0.4889106808695942, 1.5560055803507566, 4.024996720254421, 9.243376404047012, 14.558321256190538, 31.466607414186, 53.52192163467407, 64.1055317223072, 80.0835831463337, 91.18531063199043, 87.78651461005211, 90.73120459914207, 92.76956722140312, 98.93135458230972, 92.99689382314682, 92.97297790646553, 85.48547968268394, 76.23510405421257, 67.68036469817162, 43.70834022760391, 34.12398152053356, 24.691768549382687, 24.336565509438515, 22.38562099635601, 24.794942513108253, 28.52174073457718, 35.81858038902283, 48.55378322303295, 50.65668158233166, 54.242830350995064, 64.46153461933136, 56.326231956481934, 60.38181133568287, 54.70936171710491, 30.205570980906487, 12.59267533197999, 3.0251791700720787, 0.7221823604777455, 0.14389559190021828, 0.19768528291024268, 0.1833466929383576, 0.2136625349521637, 0.2972272352781147, 0.18586735299322754, 0.10186171304667369, 0.17652680107858032, 0.13803189794998616, 0.11190644436283037, 0.09685748547781259, 0.16225717146880925, 0.1704142798553221, 0.10056439437903464, 0.1639078266452998, 0.1099740996141918, 0.13411525811534375, 0.07239143698825501, 0.17434638604754582, 0.08263780240667984, 0.1393170453957282, 0.19634929834865034, 0.08378672864637338, 0.1622202867292799, 0.12786965497070923, 0.10715899989008904, 0.09970867584343068, 0.14409626863198355, 0.1404781502787955, 0.10625459646689706, 0.11619163473369554, 0.09801453823456541, 0.1432773086708039, 0.12356755105429329, 0.16375267325202003, 0.12128598129493184, 0.16054770851042122, 0.15883008192759007, 0.2543283684644848, 0.15728688973467797, 0.10925128488452174, 0.14564818848157302, 0.22207722795428708, 0.16473218944156542, 0.16572776570683345, 0.1314590818947181, 0.09147290722467005, 0.16888492129510269, 0.13903235754696652, 0.09208666335325688, 0.10045857154182158, 0.11122178344521672, 0.13930809509474784, 0.165575684804935, 0.12942948611453176, 0.1416981965303421, 0.1316859119106084, 0.10235692592686974, 0.20873691566521302, 0.11198691543540917, 0.11328585940646008, 0.12211142762680538, 0.16427692637080327, 0.13133986329194158, 0.07472526136552915, 0.10732305163401179, 0.2308126474963501, 0.18266234372276813, 0.11445570678915828], [0.03996012528659776, 0.04012539044197183, 0.014063098260521656, 0.03320812880701851, 0.08472980538499542, 0.020959307948942296, 0.05027080151194241, 0.015992935477697756, 0.04829332676308695, 0.023011090233922005, 0.016246390041487757, 0.050991553071071394, 0.017642978382355068, 0.03792005780269392, 0.021128697590029333, 0.04494563960179221, 0.006446771085393266, 0.012585774456965737, 0.028568223387992475, 0.09307760861702263, 0.05300861768773757, 0.02243258240923751, 0.030867977620800957, 0.04332302647526376, 0.02435544622130692, 0.003745468111446826, 0.07114792402717285, 0.03985671071859542, 0.04140574732446112, 0.025037923369382042, 0.09798814746318385, 0.03038956696400419, 0.07222690284834243, 0.04394109077111352, 0.09379562907270156, 0.04603876375767868, 0.05345406214473769, 0.1004766279947944, 0.015974194393493235, 0.028486594565038104, 0.033584698248887435, 0.053486427204916254, 0.011774952145060524, 0.02671702877705684, 0.03580065844289493, 0.0169352366719977, 0.021393195311247837, 0.0600457658583764, 0.09511051437584683, 0.04225985539960675, 0.05375103253754787, 0.053731929656350985, 0.038894378958502784, 0.007673824138691998, 0.1057668866997119, 0.05380761387641542, 0.06734832088113762, 0.04609358249581419, 0.058929594306391664, 0.08856712447595783, 0.02875997579394607, 0.02458933406160213, 0.017791380087146536, 0.022082448267610744, 0.09076993010239676, 0.14303603646112606, 0.26286306674592197, 2.0404097624123096, 5.039193173870444, 9.956223852932453, 17.317498549818993, 37.182840183377266, 45.387063547968864, 53.17637197673321, 62.184012830257416, 68.99849116802216, 71.49499520659447, 73.30613762140274, 80.56994184851646, 78.10696721076965, 80.65578684210777, 77.44060456752777, 70.97492471337318, 69.15887296199799, 72.6411885023117, 68.51532429456711, 66.37468636035919, 68.32339659333229, 68.77546593546867, 53.652155846357346, 58.621031418442726, 56.347070038318634, 56.63468040525913, 60.72969786822796, 54.619504138827324, 65.27515456080437, 65.93859896063805, 60.023528560996056, 69.1509085893631, 71.2181344628334, 64.59784090518951, 71.80195033550262, 66.91334545612335, 56.54643014073372, 43.92561636865139, 26.433292999863625, 7.061395738273859, 2.294859546236694, 0.41760020423680544, 0.15602586208842695, 0.02663277275132714, 0.027689322014339268, 0.02998277541337302, 0.044128457084298134, 0.05298346630297601, 0.07624978854437359, 0.046242212411016226, 0.03467638263828121, 0.06635234385612421, 0.022110555255494546, 0.0045360724652709905, 0.04373412433778867, 0.03930201841285452, 0.013830173356836895, 0.052399503692868166, 0.02626430941745639, 0.06618278537644073, 0.03904541714291554, 0.061164694488979876, 0.026665911500458606, 0.02777570058242418, 0.03718604777532164, 0.026206021138932556, 0.03470193849352654, 0.045028329695924185, 0.09721862938022241, 0.04953433126502205, 0.06348714916384779, 0.029170964189688675, 0.025346807087771595, 0.003547223536770616, 0.05019614145567175, 0.04689217792474665, 0.05651565137668513, 0.06940251885680482, 0.04811166385479737, 0.010684812350518769, 0.038515119231306016, 0.0833818202954717, 0.04991616995539516, 0.035992195626022294, 0.05390780381276272, 0.029350257791520562, 0.03926277735445183, 0.04897192804492079, 0.04473314787901472, 0.0584138239355525, 0.022764771420042962, 0.026009212851931807, 0.053151291867834516, 0.06276414889725856, 0.056510794020141475, 0.07621426193509251, 0.021717328309023287, 0.0797732533828821, 0.04703809157945216, 0.017139950687123928, 0.011251949545112438, 0.039079518828657456, 0.023898290673969314, 0.06471347398473881, 0.023677984136156738, 0.022718687760061584, 0.0406943876441801, 0.10575521271675825, 0.048139590871869586, 0.030483391128655057, 0.04861645044002216, 0.008759097763686441, 0.042632261393009685, 0.06303973801550455, 0.026754800383059774, 0.049048321016016416, 0.0741100060986355, 0.038462077936856076, 0.07593487302074209, 0.08127515247906558, 0.0829194845573511, 0.0354508471355075, 0.06912220967933536, 0.017727917183947284, 0.02415296978142578, 0.0367592868860811, 0.0373107694031205, 0.047197475214488804, 0.06036268146999646, 0.06232744693988934, 0.05111756232508924, 0.02605424822831992, 0.027845970835187472, 0.027149036650371272, 0.04016322513052728, 0.05430008823168464, 0.07229095019283704, 0.025260879374400247, 0.034729806138784625, 0.046132823554216884, 0.02069248916086508, 0.024204064793593716, 0.06487533639301546, 0.0883448364038486, 0.07343169054365717, 0.023984255494724493, 0.03256306146795396, 0.02774842479993822, 0.05661132905515842, 0.03364470831002109, 0.034326526802033186, 0.05701228918042034, 0.062388592486968264, 0.013134655746398494, 0.05251024696917739, 0.05609581101452932, 0.0429056982829934, 0.01934304575115675, 0.040588360716355965, 0.07711838334216736, 0.038342291591106914, 0.10624274436850101, 0.0541806284309132, 0.07872689937357791, 0.072575088852318, 0.03537348566169385, 0.036295236786827445, 0.039069258637027815, 0.04906079651846085, 0.0167910689197015, 0.06672633433481678, 0.05709027034754399, 0.0955676996090915, 0.05555363131861668, 0.18837009760318324, 0.40455571201164275, 2.5881793443113565, 7.051838776096702, 15.055311787873507, 25.41940290480852, 50.508063957095146, 57.53137908875942, 65.96224889159203, 73.61886084079742, 75.8468408882618, 81.3519474864006, 81.90635293722153, 91.34271338582039, 87.40267440676689, 88.49184036254883, 85.39947509765625, 79.41459104418755, 77.48396784067154, 80.4832760989666, 76.93384855985641, 77.598235309124, 78.20880934596062, 79.18370023369789, 64.34450089931488, 68.88620719313622, 64.97010692954063, 65.48875629901886, 71.53291717171669, 66.8964059650898, 75.10058373212814, 75.75142800807953, 71.8562114238739, 78.62247794866562, 81.27788186073303, 76.31003603339195, 82.16961041092873, 75.97271293401718, 67.46736332774162, 55.20486652851105, 37.27747030556202, 11.927966549992561, 4.486393611878157, 0.6278008874505758, 0.09542700325255282, 0.15877724101301283, 0.03858336713165045, 0.0595257986424258, 0.06605996735743247, 0.045468549433280714, 0.015627169850631617, 0.11105176483397372, 0.08307584765134379, 0.045456214938894846, 0.05777844904514495, 0.03290510991064366, 0.11054312650230713, 0.03199786035111174, 0.0357986731978599, 0.0156767267617397, 0.017653867544140667, 0.03655212378362194, 0.051040705511695705, 0.10672683245502412, 0.03215123258996755, 0.0251532401307486, 0.026075046916957945, 0.034556670507299714, 0.047821276311879046, 0.035253584283054806, 0.0837338951532729, 0.06077473299228586, 0.07128479090170003, 0.04795014283445198, 0.07507540663937107, 0.010990868486260297, 0.03272266032581683, 0.04608800896676257, 0.04743337798572611, 0.07972317325766198, 0.050194104260299355, 0.02927294455730589, 0.03114921819360461, 0.06750860993633978, 0.03530091475113295, 0.024004603328648955, 0.0553688922082074, 0.01867464899987681, 0.03231244561902713, 0.02233064100437332, 0.019212390652683098, 0.061393899377435446, 0.046007463679416105, 0.056392870465060696, 0.0451722284196876, 0.02880772743083071, 0.03944206910091452, 0.030932344088796526, 0.09277116841985844, 0.04432511137565598, 0.04041077219881117, 0.0238011342662503, 0.05024089667131193, 0.03515209558827337, 0.03649967249657493, 0.05105792333779391, 0.06701736754621379, 0.032504943883395754, 0.03971311256464105, 0.05970565813186113, 0.051023754858761095, 0.09218531704391353, 0.17002861539367586, 0.13366542756557465, 0.17819731612689793, 0.18686337454710156, 0.19807583070360124, 0.18899985443567857, 0.10951759715680964, 0.1020088215591386, 0.12519035342847928, 0.1705775671871379, 0.11856041426653974, 0.1847781622200273, 0.16117197345010936, 0.13400519761489704, 0.21980119461659342, 0.11970341816777363, 0.06208059377968311, 0.11246416834183037, 0.17888828529976308, 0.1029642550565768, 0.1600089983548969, 0.11603475213632919, 0.07193716097390279, 0.13117549242451787, 0.09529730552458204, 0.1714293152326718, 0.18418779858620837, 0.13431301078526303, 0.14633504615630955, 0.13124967750627548, 0.12443026804248802, 0.2523777075111866, 0.12248601182363927, 0.20248913060640916, 0.167140458652284, 0.1604322748607956, 0.1957656437298283, 0.17444734781747684, 0.18433971621561795, 0.1826083895866759, 0.17509887926280499, 0.1468677300726995, 0.1895653858082369, 0.2879962540464476, 0.16299468814395368, 0.14837014867225662, 0.15501385467359796, 0.26253919349983335, 0.20363631279906258, 0.13570550247095525, 0.25253830826841295, 0.1805881893960759, 0.10127356101293117, 0.20777236117282882, 0.19611124705988914, 0.13312481751199812, 0.1554036306333728, 0.19256856059655547, 0.1608777861110866, 0.164457980717998, 0.12978720129467547, 0.0928707497951109, 0.16861954412888736, 0.2318518768879585, 0.23491705069318414, 0.5465182615444064, 3.1772023625671864, 8.497411832213402, 17.187224440276623, 30.364256165921688, 56.82392165064812, 65.24368464946747, 73.73128920793533, 86.2786415219307, 88.6561207473278, 92.79251039028168, 93.65682721138, 99.54804629087448, 99.21204552054405, 98.2601509988308, 94.9877741932869, 90.3007560968399, 89.76811587810516, 93.94216150045395, 87.27921903133392, 88.79648521542549, 88.30732986330986, 91.85720577836037, 75.71201652288437, 76.30495950579643, 75.89002177119255, 76.45104646682739, 81.07878014445305, 78.18955197930336, 90.23149341344833, 89.36973765492439, 83.17115306854248, 92.27593570947647, 93.93871128559113, 90.06667345762253, 93.05387556552887, 86.52751296758652, 79.31530237197876, 65.38026452064514, 42.57150202989578, 16.205657310783863, 6.209519924595952, 0.933032986940816, 0.22804357577115297, 0.1969820386148058, 0.15790986333740875, 0.2234669736935757, 0.1902502990560606, 0.0952443755522836, 0.07796821664669551, 0.18675833096494898, 0.22028127510566264, 0.1950120521360077, 0.08345442460267805, 0.08582403534092009, 0.14792073372518644, 0.1175452972529456, 0.07711198602919467, 0.2035924667143263, 0.09629026943002827, 0.15445777826244012, 0.1179285126272589, 0.2454185442184098, 0.1108196061977651, 0.07323636469664052, 0.16762929648393765, 0.11218640473089181, 0.10982198160490952, 0.12552503234473988, 0.19420812808675691, 0.11748545046430081, 0.21847757423529401, 0.16639522364130244, 0.2744142687879503, 0.26545832748524845, 0.30947184073738754, 0.24344594537978992, 0.23850781348301098, 0.11667642786051147, 0.10383305765572004, 0.10473609552718699, 0.10440361336804926, 0.2335779639543034, 0.18241903802845627, 0.10076269623823464, 0.16043073119362816, 0.16952937265159562, 0.19206149561796337, 0.1879614859353751, 0.09745500341523439, 0.13494897197233513, 0.11169832388986833, 0.12957622355315834, 0.21063138119643554, 0.1389487471897155, 0.11922955687623471, 0.16549234162084758, 0.14279185503255576, 0.15313878888264298, 0.1715101202717051, 0.17093678150558844, 0.15559468913124874, 0.15603858249960467, 0.25221755204256624, 0.189462672569789, 0.08757603820413351, 0.07599204807775095, 0.13461515394737944, 0.28238561761099845, 0.12064893657225184], [0.057424047554377466, 0.005766218419012148, 0.029389255796559155, 0.008665529639984015, 0.030721858020115178, 0.05901548305700999, 0.055835135353845544, 0.03202413608960342, 0.026798650178534444, 0.028404839576978702, 0.02831250156305032, 0.04545957315713167, 0.010607014864945086, 0.07653921129531227, 0.06286278032348491, 0.022818011238996405, 0.031042076188896317, 0.05585274651821237, 0.044068487841286696, 0.02789236619719304, 0.017276795297220815, 0.03193140473740641, 0.031537138784187846, 0.016250206535914913, 0.05493896605912596, 0.061312292818911374, 0.04168554442003369, 0.014980275900597917, 0.03226516710128635, 0.01930756181536708, 0.014995397159509594, 0.008089741786534432, 0.035699678119271994, 0.05244329782726709, 0.012556086694530677, 0.05281837184156757, 0.005769303434135509, 0.049090218963101506, 0.04919571154459845, 0.011155081647302723, 0.016115423240989912, 0.06021261178830173, 0.10442364393384196, 0.04758698400110006, 0.04941253369906917, 0.06127521883172449, 0.00948128259551595, 0.062036461968091317, 0.021319865554687567, 0.047085518526728265, 0.045822943502571434, 0.09985805532778613, 0.05805588240036741, 0.0682938244426623, 0.025814857363002375, 0.04752455453854054, 0.01666610609390773, 0.031243448684108444, 0.03719772175827529, 0.1445905092987232, 0.05842366110300645, 0.13483036193065345, 0.24627594742923975, 0.9275987441651523, 2.2756375651806593, 3.5450931591913104, 8.483592923730612, 14.536448679864407, 34.12576362490654, 54.673639833927155, 66.81344121694565, 72.63665914535522, 71.00292921066284, 71.67339563369751, 72.55945488810539, 62.63013929128647, 69.38963457942009, 59.28709767758846, 55.18559776246548, 54.98117633163929, 53.9896347373724, 53.55279877781868, 56.97454176843166, 50.949307680130005, 48.56466583907604, 43.900435119867325, 57.09963485598564, 56.11696198582649, 61.12897664308548, 73.27803432941437, 68.6262859404087, 70.66379740834236, 64.65423747897148, 67.34699338674545, 68.83712902665138, 74.03228625655174, 66.20698615908623, 61.725643426179886, 60.74987858533859, 61.64373122155666, 58.210991621017456, 59.309668466448784, 58.53482164442539, 67.74047747254372, 75.32237023115158, 64.01211753487587, 52.85649374127388, 34.914916679263115, 9.985310342162848, 4.468874651938677, 0.8019058231730014, 0.4422226455062628, 0.03275844668678474, 0.009327279531134991, 0.019112250811303966, 0.08854596584569663, 0.047887913751765154, 0.07704718169406988, 0.03525110922055319, 0.023289273158297874, 0.0289388834789861, 0.07056659975205548, 0.03350570405018516, 0.02261545687360922, 0.036258526452002116, 0.029171745300118346, 0.04665976324758958, 0.04680425197875593, 0.0856044190004468, 0.028120105343987234, 0.02956425421871245, 0.11662645163596608, 0.044932496166438796, 0.024384913194808178, 0.03357123569003306, 0.06444617465604097, 0.03973109109210782, 0.023533135463367216, 0.02172309294110164, 0.021220195121713914, 0.04011818047729321, 0.042667101515689865, 0.013763513652520487, 0.033667759416857734, 0.031710330076748505, 0.046759296383243054, 0.04029043666378129, 0.038278429783531465, 0.02550037228502333, 0.04813795443624258, 0.03930194790882524, 0.0561044236383168, 0.09071905587916262, 0.08642919739941135, 0.08937623613746837, 0.07192720877355896, 0.049692623942974024, 0.03232369286706671, 0.031129425115068443, 0.032381465352955274, 0.009564345618855441, 0.011160789690620732, 0.047461004432989284, 0.03183312583132647, 0.013353259055293165, 0.03350950384628959, 0.06504881341243163, 0.05504132677742746, 0.03329166866024025, 0.022369271646311972, 0.03663859883090481, 0.028367515114950947, 0.07756370905553922, 0.019675034382089507, 0.01983236968953861, 0.007902642646513414, 0.049388829502277076, 0.06589101743884385, 0.03648134515970014, 0.007333873654715717, 0.10514675552258268, 0.0598529299168149, 0.0413828001182992, 0.07592065347125754, 0.08488315535942093, 0.13726905919611454, 0.04267144307959825, 0.05201481886615511, 0.06237611698452383, 0.03546659179846756, 0.00788544244642253, 0.07023071855655871, 0.07702268339926377, 0.08671931034768932, 0.039030629850458354, 0.018778937446768396, 0.023536311855423264, 0.024915363246691413, 0.03392524755327031, 0.03390567340829875, 0.03898302107700147, 0.06701653634081595, 0.035022060183109716, 0.02612421605590498, 0.0006580885519724688, 0.004076480354342493, 0.07707807730184868, 0.026587672437017318, 0.023678592697251588, 0.023311615514103323, 0.022462516935775056, 0.07334648456890136, 0.04561613663099706, 0.11741733615053818, 0.02930267870397074, 0.042932742144330405, 0.04368803696706891, 0.015736556852061767, 0.05250092188362032, 0.038155055153765716, 0.0698211272538174, 0.027300727924739476, 0.02643112195073627, 0.05888065708859358, 0.022665811593469698, 0.024464124471705873, 0.02986945317388745, 0.04155353861278854, 0.07553824703791179, 0.035931766251451336, 0.09004387960885651, 0.028358598210616037, 0.043533599746297114, 0.02724251386098331, 0.1132218491693493, 0.10282263843691908, 0.1359624191536568, 0.0546603601105744, 0.27651350770611316, 1.1781301070004702, 2.8273468231782317, 4.76784735918045, 12.833815142512321, 20.891782455146313, 44.37772370874882, 65.86476132273674, 79.3468026816845, 81.41941666603088, 81.63044214248657, 79.74052235484123, 80.4358546435833, 70.74517384171486, 79.00735169649124, 66.96401953697205, 63.54386106133461, 63.958449214696884, 61.27584256231785, 63.82463559508324, 66.98903739452362, 61.20990090072155, 59.62803438305855, 53.975423499941826, 66.07898622751236, 69.4163167476654, 70.60717284679413, 84.71869602799416, 77.9860956966877, 80.18874630331993, 75.34277513623238, 75.8066314458847, 77.75641322135925, 82.98172563314438, 73.27684119343758, 68.75500023365021, 69.09057542681694, 69.78093758225441, 67.57185772061348, 68.94606918096542, 66.90620183944702, 76.19535058736801, 82.26901307702065, 73.46299320459366, 64.49951738119125, 44.952146485447884, 15.167308878153563, 6.52258132584393, 1.1592542636208236, 0.401665135868825, 0.01061653940269025, 0.02788977239106316, 0.02255368606711272, 0.007263574179887655, 0.011819890114566078, 0.12521227647084743, 0.04218272399157286, 0.002642431877575291, 0.03540566889569163, 0.01850768061558483, 0.07998670989763923, 0.03746492089703679, 0.017935573814611416, 0.04481065407162532, 0.04364153770438861, 0.0608655978430761, 0.07219681618153118, 0.018259211428812705, 0.0460627944994485, 0.03733084078703541, 0.017082157792174257, 0.054332924555637874, 0.005231038567217183, 0.020668211654992774, 0.024413715946138836, 0.02674707277037669, 0.06439113698434085, 0.07760507636703551, 0.07181958993896842, 0.05882940808078274, 0.026775305923365522, 0.014858818794891704, 0.03596213493437972, 0.036824428898398764, 0.02996175036969362, 0.059928443442913704, 0.05990092089632526, 0.030254054508986883, 0.0553397888870677, 0.042724343365989625, 0.04935692828439642, 0.007630866311956197, 0.04106993292225525, 0.07281220503500663, 0.04541865113424137, 0.042420040554134175, 0.020959628927812446, 0.02743074106547283, 0.025118383309745695, 0.02728723567997804, 0.004253979814166087, 0.048681072948966175, 0.013829571289534215, 0.03740052103239577, 0.0540667607128853, 0.020152333672740497, 0.032910201043705456, 0.03697638363519218, 0.023695014569966588, 0.018520098601584323, 0.06633739700191654, 0.015283446009561885, 0.015135949724935926, 0.01409173588399426, 0.1880589299253188, 0.1379877550061792, 0.11825060471892357, 0.10531323408940807, 0.2875544683774933, 0.14503581274766475, 0.11942592172999866, 0.09948083650670014, 0.14570805011317134, 0.28996606240980327, 0.12820604082662612, 0.22385119838872924, 0.1728564503719099, 0.20014306821394712, 0.07648176164366305, 0.10524804383749142, 0.18579152034362778, 0.22960929956752807, 0.10456529023940675, 0.10908950411248952, 0.057528475153958425, 0.17744066688464954, 0.08653030017740093, 0.15264652232872322, 0.1918500874307938, 0.13218659441918135, 0.12500624143285677, 0.11072889348724857, 0.10836459652637132, 0.09466456525842659, 0.13964682613732293, 0.08304748276714236, 0.13222043635323644, 0.13279159320518374, 0.10922623740043491, 0.14289649785496294, 0.12777002906659618, 0.19899429782526568, 0.11021678932593204, 0.08056425664108247, 0.11557340345461853, 0.2163025175104849, 0.24261499231215566, 0.11687939782859758, 0.16404386231442913, 0.13818665058352053, 0.11523645356646739, 0.12345773546257988, 0.11586379841901362, 0.2678631234448403, 0.179221524449531, 0.18348698853515089, 0.17460419330745935, 0.16561760130571201, 0.18272468412760645, 0.19240239373175427, 0.12666154245380312, 0.16638760920614004, 0.25053082848899066, 0.20389367477037013, 0.4528702679090202, 0.4634347994579002, 0.709821623750031, 1.9617012608796358, 4.0559246856719255, 6.950403219088912, 16.36087328195572, 25.26190135627985, 50.5227729678154, 72.48978942632675, 90.91197609901428, 94.7488734126091, 97.56859570741653, 96.03923857212067, 91.71785965561867, 83.1476703286171, 90.16045242547989, 78.9225934445858, 75.38117587566376, 77.67907217144966, 76.6888377070427, 74.2807625234127, 78.17566752433777, 71.96297809481621, 70.83329871296883, 64.9375730752945, 77.35398441553116, 78.55990290641785, 82.38330334424973, 94.90861684083939, 89.34014484286308, 90.5648723244667, 84.85026016831398, 88.64932671189308, 89.0197080373764, 92.50810325145721, 85.34432485699654, 83.47356364130974, 81.80299088358879, 80.74761271476746, 77.68156483769417, 80.67944437265396, 78.65377306938171, 87.91930228471756, 93.82173836231232, 84.07600611448288, 72.04073712229729, 52.01618783175945, 19.144117534160614, 7.76011174544692, 1.7267142701894045, 0.6078367587178946, 0.23117684904718772, 0.11432193467044272, 0.09954651657608338, 0.18200125341536477, 0.10651681208400987, 0.24392991472268477, 0.10723081752075814, 0.06928006449015811, 0.060825469918199815, 0.12476747768232599, 0.17219123372342438, 0.24482648848788813, 0.11082243378041312, 0.18317071488127112, 0.1461199569166638, 0.11332752357702702, 0.1723926526028663, 0.1051074216957204, 0.20375415100716054, 0.1841245824471116, 0.09682702773716301, 0.1234210362599697, 0.08967152927652933, 0.1218072435585782, 0.10993654694175348, 0.13692709238966927, 0.13395449408562854, 0.10673059514374472, 0.2755207219161093, 0.2491433685645461, 0.14814717782428488, 0.13352676469366997, 0.11186272444319911, 0.05478743805724662, 0.10412694071419537, 0.14889082463923842, 0.14916570129571483, 0.1437261892715469, 0.1395922782830894, 0.19322265987284482, 0.2813755249371752, 0.18611122271977365, 0.15851377858780324, 0.15785200550453737, 0.12291582665056922, 0.12556678557302803, 0.08577957327361219, 0.13581719569629058, 0.14992347860243171, 0.13636665215017274, 0.0944237234944012, 0.13803973502945155, 0.07116230684914626, 0.13853868091246113, 0.13490094017470255, 0.15189929836196825, 0.11336633047903888, 0.09071219101315364, 0.16965065442491323, 0.14332302496768534, 0.20951548794982955, 0.13254619465442374, 0.0896872034354601, 0.10545465775066987], [0.059381695828051306, 0.024147065996658057, 0.042392313916934654, 0.08417873104917817, 0.0245622735019424, 0.009187729792756727, 0.044165928120492026, 0.018281592747371178, 0.016953215199464466, 0.02777128480374813, 0.0738781740074046, 0.015150200815696735, 0.030172088008839637, 0.0475298312085215, 0.03563537473382894, 0.0032661805607858696, 0.06544392541400157, 0.022961139984545298, 0.017374135386489797, 0.04628854469046928, 0.07773730481858365, 0.028658950941462535, 0.025844532137853093, 0.04839585075387731, 0.0410759851365583, 0.07243805128382519, 0.04602805456670467, 0.03644517659267876, 0.07087029400281608, 0.0496401541022351, 0.04657234196201898, 0.06209513987414539, 0.0446328503312543, 0.03023663073690841, 0.012649051823245827, 0.03496113728033379, 0.01803269682568498, 0.05707611759135034, 0.03014809437445365, 0.0553013233729871, 0.023724652237433475, 0.042150774534093216, 0.012713770811387803, 0.021203248179517686, 0.06907253773533739, 0.010743069087766344, 0.08329459567903541, 0.059234654108877294, 0.01691981484327698, 0.021161827062314842, 0.04751735941681545, 0.008284860759886215, 0.09795034988201223, 0.0462264157977188, 0.003399962188268546, 0.2700863603968173, 0.3987640212289989, 0.3007250663358718, 0.4583081026794389, 3.1918235030025244, 5.148532306775451, 8.005907256156206, 11.012581419199705, 15.555275660008192, 20.63946459442377, 29.636950492858887, 47.286562621593475, 56.21923729777336, 68.69604259729385, 70.02829670906067, 71.11933216452599, 61.652941927313805, 64.4697117805481, 55.49319125711918, 55.826798155903816, 45.799109637737274, 45.820274502038956, 38.24685908854008, 32.05193370580673, 22.985204122960567, 35.89991122484207, 37.67844378948212, 29.110621735453606, 22.80541867017746, 27.81229790300131, 32.43448197841644, 27.39682249724865, 34.93278332054615, 49.45354454219341, 49.63802844285965, 51.10349580645561, 53.2173565775156, 51.48754499852657, 51.10539190471172, 56.57606475055218, 53.387655839324, 42.35557481646538, 38.79633620381355, 42.36507810652256, 52.708411887288094, 39.9710051715374, 47.41414077579975, 46.15655265748501, 51.42995908856392, 57.34909147024155, 69.21203970909119, 71.0698664188385, 65.52436038851738, 52.03636094927788, 31.407442688941956, 11.82676088064909, 5.630937796086073, 1.2263437011279166, 0.0997217302210629, 0.03387925295101013, 0.05209784663747996, 0.002206197705163504, 0.04704473009041976, 0.02368073935940629, 0.05918190596275963, 0.0268812345166225, 0.0724130631715525, 0.03942316659959033, 0.048924508519121446, 0.025313325095339678, 0.041707222553668544, 0.07467697723768651, 0.037396060724859126, 0.07042137629468925, 0.023970887559698895, 0.015697855706093833, 0.05345895289792679, 0.06040477237547748, 0.04712356843810994, 0.10115590834175237, 0.07203810047940351, 0.05142758338479325, 0.020772587304236367, 0.013404282635747222, 0.03281305020209402, 0.034930275069200434, 0.03733534562343266, 0.05139586399309337, 0.04194622008071747, 0.021681408361473586, 0.03695218591019511, 0.022831388450867962, 0.03289073451014701, 0.03099406480032485, 0.05473635232192464, 0.0264482896818663, 0.03745554757188074, 0.028304523475526366, 0.12002372168353759, 0.059539324283832684, 0.03509666828904301, 0.12042998816468753, 0.017733015738485847, 0.022239495992835145, 0.04804506723303348, 0.060459910237113945, 0.008161497262335615, 0.04188248814898543, 0.017617821431485936, 0.03539893019478768, 0.04319039355323184, 0.052120044274488464, 0.0064474496866751, 0.009352416072943015, 0.032665251492289826, 0.018795181204041, 0.036905883316649124, 0.035676051847985946, 0.03437384984863456, 0.06841496520792134, 0.08209496591007337, 0.02490332004526863, 0.05819687561597675, 0.05073847700259648, 0.06042533728759736, 0.04476739799429197, 0.019925859887734987, 0.026207340306427795, 0.019126242150377948, 0.006634610053879442, 0.02487913159711752, 0.05607865627098363, 0.05878140596905723, 0.0644413655390963, 0.0367407851445023, 0.04311466480430681, 0.04381203500088304, 0.01706899951386731, 0.01036866207869025, 0.10172520982450806, 0.030296598124550655, 0.06691298447549343, 0.060234468037378974, 0.020332768326625228, 0.04409386187035125, 0.057535417945473455, 0.012264634169696365, 0.011053158796130447, 0.045183620386524126, 0.033222901256522164, 0.054656486099702306, 0.0712387406383641, 0.04010046541225165, 0.012812743625545409, 0.027715985524991993, 0.01577941216964973, 0.04648201145755593, 0.11206386872800067, 0.059380293168942444, 0.010738293367467122, 0.02539716922910884, 0.052703060646308586, 0.0018292421145815752, 0.010000366655731341, 0.11556217476027086, 0.06324990681605414, 0.040340910127270035, 0.06651595031144097, 0.10744221086497419, 0.021367910339904483, 0.054356291075237095, 0.03411901860090438, 0.0273115892559872, 0.08884817580110393, 0.10708578702178784, 0.029566554876510054, 0.20588332816259935, 0.2696812665089965, 0.2236818106030114, 0.5661519861314446, 3.043584432452917, 5.79758545383811, 9.121877923607826, 12.571341376751661, 19.414727613329887, 24.06244821846485, 37.58610114455223, 59.90567408502102, 67.8683178126812, 79.09587934613228, 79.36982184648514, 78.0522121489048, 67.56640121340752, 71.6910570859909, 63.17458547651768, 63.958639204502106, 52.6981258392334, 55.56591935455799, 47.75635041296482, 44.60063874721527, 36.56126193702221, 43.2116536796093, 46.79856240749359, 39.219994470477104, 33.80332812666893, 37.75617241859436, 43.679761961102486, 38.06621678173542, 44.819712191820145, 60.27650758624077, 60.52354373037815, 61.59513182938099, 64.1194997727871, 62.10646279156208, 61.839006543159485, 67.3677858710289, 64.09181445837021, 50.8494908362627, 49.12977151572704, 53.07752788066864, 61.26406319439411, 50.673590674996376, 55.90962611138821, 55.759515166282654, 60.92339627444744, 65.75346529483795, 78.1732964515686, 79.54915702342987, 75.35294339060783, 64.37185183167458, 42.032964527606964, 19.88676108419895, 9.571595191955566, 2.3152889125049114, 0.07626909922691993, 0.12712419731542468, 0.07541248269262724, 0.025740542405401357, 0.06172546127345413, 0.04149129839788657, 0.039736185935908, 0.014541274213115685, 0.028327149702818133, 0.0504594999802066, 0.05406941389082931, 0.022517049947055057, 0.010766708346636733, 0.04451727567357011, 0.029205036189523526, 0.026807633876160253, 0.02116127601766493, 0.040587878320366144, 0.053196332810330205, 0.031114212943066377, 0.09529668212053366, 0.026930899039143696, 0.04645764303859323, 0.04688232220360078, 0.07143779948819429, 0.02060247221379541, 0.045016269796178676, 0.030945765829528682, 0.03408852746360935, 0.006045478849046049, 0.051218798689660616, 0.04898311221040785, 0.0275914030498825, 0.032593066498520784, 0.05261688987957314, 0.0405511939607095, 0.02976692918309709, 0.04994774091755971, 0.031097247447178233, 0.05551273156015668, 0.04961603430274408, 0.040354554512305185, 0.01156614054707461, 0.055677688724244945, 0.04308334617235232, 0.007890019642218249, 0.08936980171711184, 0.05104226402181666, 0.05417400105216075, 0.061151369227445684, 0.037092229176778346, 0.019021094667550642, 0.015115991518541705, 0.02449433730362216, 0.02211651470133802, 0.004795973973159562, 0.015069313212734414, 0.09738455133629031, 0.06804737946367823, 0.013062894704489736, 0.030247048634919338, 0.035000589850824326, 0.02092364404234104, 0.13470801146468148, 0.12854955130023882, 0.11364494755980559, 0.1495223180972971, 0.1922325012856163, 0.11278335121460259, 0.1656176903634332, 0.1200976841209922, 0.12495535978814587, 0.10762836376670748, 0.1620039061526768, 0.1550392954959534, 0.16842318669660017, 0.16161968145752326, 0.1462040570913814, 0.10442781480378471, 0.22679476387565956, 0.07656375411897898, 0.18312786327442154, 0.12024943847791292, 0.1950306206708774, 0.09441668051294982, 0.12280841561732814, 0.12189695436973125, 0.18280586024047807, 0.11810538868303411, 0.11839228071039543, 0.180963656748645, 0.1826510630780831, 0.1924536019214429, 0.1729047641856596, 0.16757998819230124, 0.10050239536212757, 0.12657600251259282, 0.12823633529478684, 0.12435957105481066, 0.2041527585242875, 0.1510893480735831, 0.1560824434272945, 0.20323752716649324, 0.12722406070679426, 0.11151777420309372, 0.0993622635724023, 0.3007234929827973, 0.21609769959468395, 0.1677737184218131, 0.20400541252456605, 0.2538284281035885, 0.08338612475199625, 0.09789197996724397, 0.16906824661418796, 0.14099738647928461, 0.2326848782831803, 0.16690216987626627, 0.24572894006269053, 0.6736099231056869, 0.5208432767540216, 0.7296404102817178, 1.3512250687927008, 4.33863521553576, 7.618391700088978, 12.085442449897528, 17.128321900963783, 25.431024581193924, 29.679593704640865, 45.60239799320698, 68.67171630263329, 79.27540451288223, 90.8885009586811, 90.67736148834229, 88.81337910890579, 79.60593357682228, 81.98971286416054, 74.67652648687363, 74.87508863210678, 64.09165486693382, 64.83106479048729, 56.475845128297806, 49.653398618102074, 40.711889415979385, 55.16150325536728, 53.32245893776417, 44.05846484005451, 40.000886768102646, 44.900362864136696, 49.57061626017094, 44.9344128370285, 52.384631261229515, 68.34210678935051, 70.36550581455231, 71.21229037642479, 71.32673263549805, 73.49641621112823, 72.72077143192291, 75.99437937140465, 73.79571095108986, 63.75740960240364, 56.65644183754921, 61.40458345413208, 71.43819585442543, 60.26889659464359, 66.34269207715988, 66.33214384317398, 70.9225407242775, 76.51171401143074, 88.70763078331947, 88.99070799350739, 87.45099261403084, 73.97164911031723, 48.595512583851814, 23.31921759992838, 10.584539137780666, 3.0761966574937105, 0.414296044036746, 0.19143731973599643, 0.1570882910164073, 0.14375903672771528, 0.21706397586967796, 0.19526387768564746, 0.146712250134442, 0.07543397528934292, 0.14365721406647936, 0.2088284818455577, 0.14581925352104008, 0.12874768988694996, 0.10583077819319442, 0.1968698704149574, 0.11760207155020908, 0.16816922376165166, 0.27381850231904536, 0.09653767177951522, 0.18824250757461414, 0.10237832946586423, 0.17389250337146223, 0.08418472018092871, 0.18489368492737412, 0.13115397014189512, 0.2034066923079081, 0.055659739882685244, 0.15827321883989498, 0.10122598934685811, 0.1500724276411347, 0.20538916171062738, 0.08909432392101735, 0.09380751085700467, 0.062111960651236586, 0.07297352567547932, 0.1369013250223361, 0.08751112254685722, 0.08354233199497685, 0.15323511965107173, 0.0979254359845072, 0.16003593831555918, 0.25262858311180025, 0.1454067975282669, 0.1600260825944133, 0.18957822496304289, 0.18545323458965868, 0.19779457157710567, 0.21743743942352012, 0.17043986910721287, 0.17121455253800377, 0.21669296140316874, 0.21558027423452586, 0.1420068260631524, 0.13133422296959907, 0.2045674854889512, 0.240517430647742, 0.09318604381405748, 0.12731411290587857, 0.21389142813859507, 0.1343712248490192, 0.20409978402312845, 0.11892572161741555, 0.2139102341607213, 0.129261270922143], [0.05144915761775337, 0.060473164994618855, 0.04192101303488016, 0.01893395725346636, 0.044777973598684184, 0.1058463855588343, 0.016351929007214494, 0.037977537140250206, 0.07174152342486195, 0.05992012025672011, 0.01584619989444036, 0.05824267354910262, 0.017779561385395937, 0.0507427443517372, 0.02486111225152854, 0.08539756760001183, 0.023257993489096407, 0.03907068356056698, 0.03708281503350008, 0.009351482822239632, 0.08078232189291157, 0.07763099216390401, 0.05642243391775992, 0.08563849100028165, 0.05399796362326015, 0.04623346991138533, 0.019478007161524147, 0.013577830159192672, 0.006648849084740505, 0.02935624506790191, 0.040703657068661414, 0.008885370480129495, 0.016577861024416052, 0.0247717521051527, 0.028543604494188912, 0.020779149745067116, 0.07253341726027429, 0.016158681173692457, 0.09852762203081511, 0.04014652680780273, 0.03032970904314425, 0.03763337357668206, 0.02712254754442256, 0.008569044875912368, 0.04021860419015866, 0.010438288518344052, 0.04883607049123384, 0.023701584432274103, 0.01539927021440235, 0.02480346036463743, 0.015185694028332364, 0.08647000810015015, 0.14282493997598067, 0.5215306836180389, 1.054857715498656, 1.359648979268968, 2.7103150030598044, 6.144147757440805, 13.119071535766125, 15.513068474829197, 19.344699271023273, 24.20630469918251, 34.18843366205692, 46.672629565000534, 50.038675144314766, 58.7069334089756, 63.94132733345032, 64.18808609247208, 55.99103294312954, 49.58789773285389, 46.279172077775, 36.06289587914944, 41.06126546859741, 37.22014658153057, 32.404839769005775, 26.73782005906105, 19.948669262230396, 21.864427663385868, 15.410848259925842, 17.070228718221188, 20.35039510577917, 24.746487513184547, 22.646505497395992, 14.365367610007524, 14.93254417553544, 18.93656887114048, 19.41598914563656, 27.331768088042736, 17.351537123322487, 21.64270006120205, 29.27827823907137, 29.126964658498764, 25.70021353662014, 29.521527886390686, 38.07849772274494, 36.44757203757763, 39.40578930079937, 37.865192368626595, 30.695275403559208, 30.967593491077423, 22.999626249074936, 31.429762691259384, 26.57267902046442, 41.60223104059696, 52.186046317219734, 50.47649525105953, 58.45772758126259, 64.55936416983604, 71.50871247053146, 65.5162288248539, 49.36300680041313, 37.39361487329006, 20.0600203871727, 7.071328405290842, 2.4718227004632354, 1.255240438040346, 0.4639533825684339, 0.2503618266200647, 0.07645600169780664, 0.030195838589861523, 0.01794287840311881, 0.02811967489833478, 0.1039869716623798, 0.05479428808030207, 0.03776414741878398, 0.044628857576753944, 0.015496725336561212, 0.006745452592440415, 0.05663291070959531, 0.10276443179463968, 0.06270784957450815, 0.036933702722308226, 0.010298567158315564, 0.017420497351849917, 0.12389040755806491, 0.11171272155479528, 0.07281953003257513, 0.056912652144092135, 0.012932996596646262, 0.09684490607469343, 0.10895320869167335, 0.06040924010449089, 0.010697545749280835, 0.03812301663856488, 0.015344444054790074, 0.009840866132435622, 0.04330952309828717, 0.018367637349001598, 0.015305511915357783, 0.05609436011582147, 0.047955241388990544, 0.06891581098898314, 0.063406232802663, 0.023678371908317786, 0.04324437366449274, 0.030872005627315957, 0.06331786527880467, 0.02038515653111972, 0.03899973053194117, 0.023343041757470928, 0.05020957803935744, 0.05607015496934764, 0.08373317527002655, 0.03341575946251396, 0.0743215404509101, 0.041338267546962015, 0.028758973894582596, 0.09119317692238837, 0.021138135853107087, 0.012394087916618446, 0.004378601252028602, 0.015903892599453684, 0.004626031895895721, 0.04477022186620161, 0.03171400741848629, 0.034060837933793664, 0.10656856946297921, 0.021490255239768885, 0.010343950416427106, 0.013111546195432311, 0.025696599841467105, 0.04575556391500868, 0.037261104880599305, 0.046594814193667844, 0.028353039524517953, 0.03793763185967691, 0.022799520629632752, 0.011208919822820462, 0.023940615355968475, 0.04268627490091603, 0.05111132457386702, 0.11479901688289829, 0.04529973681201227, 0.05250277725281194, 0.015710169791418593, 0.03832221649645362, 0.054829172731842846, 0.09802262022276409, 0.03343167481943965, 0.08145501196850091, 0.04717283962236252, 0.026791085838340223, 0.04127643180254381, 0.027994450465484988, 0.009277548215322895, 0.048382451277575456, 0.052152004864183255, 0.014086007431615144, 0.03964031158830039, 0.01865792099124519, 0.05546071442950051, 0.02482773230440216, 0.07605233273352496, 0.013293146948853973, 0.008132559996738564, 0.056664318399270996, 0.06367996655171737, 0.047081629672902636, 0.07707412907620892, 0.047002145656733774, 0.028246812216821127, 0.04727748986624647, 0.036400514145498164, 0.049719753151293844, 0.010818251430464443, 0.0898460675671231, 0.032229146963800304, 0.14285103388829157, 0.206694629159756, 0.7597464916761965, 1.2256923923268914, 1.804879994597286, 4.294228898361325, 8.704005796462297, 14.31851802393794, 18.841165490448475, 24.03026394546032, 30.405202768743038, 42.62781500816345, 56.98653392493725, 61.725221648812294, 70.73204174637794, 74.28293600678444, 74.5543098449707, 64.11370128393173, 59.996937587857246, 56.29741050302982, 44.00791995227337, 47.95430839061737, 47.37024553120136, 44.19684961438179, 40.298103019595146, 32.14331120252609, 34.13551390171051, 23.699618987739086, 26.736374236643314, 36.80731013417244, 39.19641673564911, 36.473756432533264, 29.741380289196968, 27.260284423828125, 32.50956594944, 32.657180428504944, 38.05538356304169, 33.84166046977043, 35.95509946346283, 40.268749594688416, 40.47141931951046, 41.48424357175827, 39.48852226138115, 47.75869868695736, 49.562442898750305, 48.91710452735424, 46.47988110780716, 38.9728519320488, 42.7726936340332, 33.88782799243927, 40.679655745625496, 36.34099155664444, 51.78128823637962, 61.55896916985512, 57.953023463487625, 64.2475301027298, 71.7912045121193, 76.9529615342617, 74.49510142207146, 59.60960917174816, 48.22900705039501, 25.672144442796707, 12.385377455502748, 4.0933712013065815, 2.184549802914262, 0.7682226493488997, 0.2961981436237693, 0.03934777181711979, 0.03522617305861786, 0.016670805744070094, 0.14603889954742044, 0.03969160512497183, 0.030993313375802245, 0.008556926532037323, 0.028895890864077955, 0.06793966414988972, 0.02632854229887016, 0.06980518592172302, 0.05626242687867489, 0.04373767922515981, 0.014990743893577019, 0.031062550187925808, 0.1285501301754266, 0.09161033070995472, 0.013538013936340576, 0.028930319094797596, 0.025413800758542493, 0.07260186554049142, 0.05366093580960296, 0.047152835031738505, 0.025442184196435846, 0.049362156714778394, 0.05938965165114496, 0.021292333731253166, 0.020680963607446756, 0.025558950001141056, 0.03955336898798123, 0.04630543968232814, 0.006745295349901426, 0.03706020550453104, 0.031539558185613714, 0.02545531464420492, 0.019728877196030226, 0.0285356616586796, 0.029711815441260114, 0.042597261708579026, 0.012726176737487549, 0.01620536782866111, 0.04925184759486001, 0.027967354653810617, 0.09923914869432338, 0.12313789207837544, 0.031177134078461677, 0.06839420733740553, 0.028364279351080768, 0.03180239349603653, 0.05153319470991846, 0.048245614088955335, 0.017296909354627132, 0.05662133320583962, 0.0226223440040485, 0.007244984308272251, 0.06526469675009139, 0.0879035034449771, 0.016559940013394225, 0.2004512821440585, 0.13525246584322304, 0.09438211127417162, 0.142760862945579, 0.09617521427571774, 0.19929237401811406, 0.1345066964859143, 0.10930681979516521, 0.1402625860646367, 0.2302944057737477, 0.09918547657434829, 0.16232020949246362, 0.09472212623222731, 0.11869027526699938, 0.1210820020060055, 0.19276637263828889, 0.16601166687905788, 0.10854830776224844, 0.10604430150124244, 0.12706193112535402, 0.16023367614252493, 0.22746563568944111, 0.13699136237846687, 0.18590119492728263, 0.1338260728516616, 0.09893722817650996, 0.12565489334519953, 0.10642457797075622, 0.12271486048121005, 0.15725885139545426, 0.13865671207895502, 0.10678752529202029, 0.14079724409384653, 0.12052708334522322, 0.09029521534102969, 0.11209166957996786, 0.11504343579872511, 0.05627087622997351, 0.13318188866833225, 0.17325885768514127, 0.12919358705403283, 0.10352446523029357, 0.13805996597511694, 0.10778396987007, 0.10182498415815644, 0.15821249631699175, 0.17879780265502632, 0.13931075198343024, 0.14324965624837205, 0.12394815406878479, 0.1256386996828951, 0.27349252137355506, 0.2953886683098972, 1.0877735679969192, 2.3128641676157713, 3.741471846587956, 7.10047616623342, 12.024244833737612, 18.544517308473587, 23.279526829719543, 30.190613083541393, 36.5596242249012, 50.40359616279602, 67.38477095961571, 73.13189417123795, 83.96287858486176, 86.02568909525871, 86.50624930858612, 77.16651767492294, 70.20655274391174, 63.9912186563015, 55.062472969293594, 59.25710588693619, 55.07226884365082, 48.75143341720104, 41.73211947083473, 33.126493245363235, 37.22593367099762, 27.43555761873722, 30.963943786919117, 39.63889539241791, 39.64177563786507, 35.865785256028175, 27.020186707377434, 28.569082394242287, 31.29366349428892, 32.19080485403538, 42.57030509412289, 31.637178361415863, 37.845710813999176, 49.25079122185707, 45.990113988518715, 42.49445356428623, 45.25403268635273, 59.17588524520397, 52.50888079404831, 55.348901599645615, 54.780984073877335, 45.896756798028946, 48.39879713952541, 37.72135108709335, 47.8948187828064, 43.45246575772762, 60.22269107401371, 70.60987070202827, 70.92242673039436, 74.5649416744709, 84.37009513378143, 89.87389460206032, 87.17939078807831, 70.28914511203766, 54.54833775758743, 30.754139944911003, 15.520573072135448, 4.943662500008941, 2.6119677303358912, 1.1870763706974685, 0.47173711645882577, 0.14882566407322884, 0.20592212764313444, 0.11578384684980847, 0.2063864003866911, 0.1061659914557822, 0.16686071350704879, 0.08732372283702716, 0.22068086225772277, 0.19474081200314686, 0.12063056841725484, 0.1356229608063586, 0.2001792553346604, 0.18681419984204695, 0.06832103157648817, 0.15738387359306216, 0.15670360618969426, 0.2749583520926535, 0.17663579288637266, 0.13139834452886134, 0.11937206407310441, 0.10798026793054305, 0.13575414282968268, 0.1690628586220555, 0.1600978779606521, 0.15958582574967295, 0.10292668011970818, 0.13990593957714736, 0.201409216679167, 0.1685914018889889, 0.1989371672971174, 0.08226109566749074, 0.12307516575674526, 0.08128638859489001, 0.19181440497050062, 0.19017661863472313, 0.10244688164675608, 0.14313585532363504, 0.1358005270594731, 0.157997407077346, 0.174535752448719, 0.1312368383514695, 0.13314050651388243, 0.14119430794380605, 0.23039789084577933, 0.3081363014644012, 0.09526311478111893, 0.15570555115118623, 0.14732078154338524, 0.13080728327622637, 0.19478456903016195, 0.08980369835626334, 0.07002970043686219, 0.1435389305697754, 0.10568757337750867, 0.10296052947524004, 0.15059009048854932, 0.13544868968892843, 0.11734503612387925], [0.04363141109934077, 0.019492783321766183, 0.030341926649271045, 0.04449308165931143, 0.02398531862127129, 0.008000694269867381, 0.05069975173682906, 0.009272458009945694, 0.05327165708877146, 0.05041557225922588, 0.020033228247484658, 0.041848445835057646, 0.07023618076345883, 0.07490441581467167, 0.0379881832486717, 0.019242143353039864, 0.03448821480560582, 0.03875415015500039, 0.04461008124053478, 0.013031810776737984, 0.03034509933058871, 0.033867805323097855, 0.022716006751579698, 0.040281853725900874, 0.056715463506407104, 0.08202840268495493, 0.029630717253894545, 0.06996586089371704, 0.04969498026184738, 0.04110052796022501, 0.04267170654202346, 0.012165585285401903, 0.04469396248168778, 0.03299651281849947, 0.08313110054587014, 0.03644970369350631, 0.035978254381916486, 0.00877030790434219, 0.026164709488512017, 0.033101304070441984, 0.02814083909470355, 0.022315109708870295, 0.04301700559153687, 0.04942961793858558, 0.02019001065491466, 0.042721805220935494, 0.027899179112864658, 0.08556044675060548, 0.017040517741406802, 0.06450666711316444, 0.5203439004253596, 1.361208320595324, 2.95552724506706, 3.4667938482016325, 11.249618399888277, 20.853224024176598, 25.31229045242071, 27.6282661780715, 30.451590679585934, 36.78989566862583, 41.40364609658718, 51.90513119101524, 58.11115577816963, 59.45300817489624, 58.96688126027584, 50.42950697243214, 54.209198355674744, 45.923381969332695, 39.86017271876335, 21.87657941132784, 19.110147356987, 31.2966026365757, 27.14920498430729, 18.576893471181393, 9.922491163015366, 12.461479771882296, 15.249975342303514, 20.839649252593517, 21.096500270068645, 23.9350638538599, 11.573644112795591, 17.751824744045734, 27.85081833600998, 22.056245170533657, 23.65871038287878, 18.57310127466917, 13.855674359947443, 16.576880291104317, 14.71957890316844, 15.756926089525223, 13.66180021315813, 16.997304931282997, 15.653767324984074, 22.47189536690712, 14.461370408535004, 19.646042101085186, 16.469002179801464, 33.477860391139984, 21.215471886098385, 17.185649424791336, 23.3584675937891, 18.8043150678277, 24.712287448346615, 33.71418111026287, 40.176764130592346, 35.40185295045376, 41.24612174928188, 44.043090865015984, 50.285262912511826, 58.715015575289726, 64.58516478538513, 56.98560297489166, 54.416332840919495, 47.44332320988178, 30.238310024142265, 19.964153431355953, 9.708713684231043, 3.258954738266766, 0.6640534359030426, 0.28222748078405857, 0.07430218523950316, 0.09881366800982505, 0.07133861145121045, 0.042765688413055614, 0.059859772518393584, 0.01654549781960668, 0.03890851316100452, 0.04023624875117093, 0.026049446532852016, 0.026307131338398904, 0.010652799810486613, 0.01753977903717896, 0.07764647336443886, 0.04148564323259052, 0.04129689281398896, 0.024934438297350425, 0.04893198194622528, 0.056929120401036926, 0.029916058192611672, 0.033082186346291564, 0.05134315295435954, 0.027940401705564, 0.03356415931193624, 0.014675509246444562, 0.03531150890921708, 0.0536432430089917, 0.03490464499918744, 0.05815140793856699, 0.013785082319373032, 0.06347875547362491, 0.014384108671947615, 0.0324716251634527, 0.007386542947642738, 0.07213009710540064, 0.037173486925894395, 0.08572110687964596, 0.011879282337758923, 0.03879677169607021, 0.016709954034013208, 0.01274747173738433, 0.028300950034463312, 0.0443738407921046, 0.021161454133107327, 0.054350977297872305, 0.02509818019461818, 0.03378787230758462, 0.03734379497473128, 0.020862520759692416, 0.06957722784136422, 0.03815979005594272, 0.04504034877754748, 0.04214795437292196, 0.03172192242345773, 0.009691322447906714, 0.03225338921765797, 0.0536347454180941, 0.010674057702999562, 0.026691292950999923, 0.01365998869005125, 0.0364364044071408, 0.013258450617286144, 0.008886740670277504, 0.010701136816351209, 0.060565855528693646, 0.0904957510647364, 0.016839351192174945, 0.023293406920856796, 0.049143178621307015, 0.06001897432724945, 0.04711494839284569, 0.02426586714136647, 0.00733414964088297, 0.03942802766687237, 0.07593490270664915, 0.06482020224211738, 0.03925387529307045, 0.03547773143509403, 0.017741841729730368, 0.024733717036724556, 0.03510130300128367, 0.033663985595921986, 0.05624172837997321, 0.010270664261042839, 0.04781398100021761, 0.01990980908885831, 0.02887930200813571, 0.06440840676077642, 0.020408745695021935, 0.06972644405323081, 0.018286466802237555, 0.060305491570034064, 0.011876744192704791, 0.01438288134522736, 0.013210163706389721, 0.03608959508710541, 0.0554581948381383, 0.019203182455385104, 0.036138673312962055, 0.02869549614842981, 0.031002963150967844, 0.004146178689552471, 0.051169909711461514, 0.05528764188056812, 0.16651416022796184, 0.030545692570740357, 0.0869790991418995, 0.7140920008532703, 2.1951745077967644, 4.54889883287251, 5.695599401369691, 13.245827984064817, 23.974384143948555, 29.166018962860107, 32.448495626449585, 37.56399393081665, 45.48260182142258, 51.93534716963768, 65.40881618857384, 71.12443909049034, 70.3250303864479, 70.65470829606056, 64.39148157835007, 64.73856255412102, 54.44011576473713, 46.97714902460575, 29.87798485904932, 27.2660069167614, 42.6088198274374, 40.95633789896965, 32.506909891963005, 22.055975385010242, 22.62106016278267, 24.18220829218626, 33.756529837846756, 29.740650728344917, 40.14272555708885, 23.782009966671467, 28.05079970508814, 34.53334875404835, 29.032125547528267, 25.292140133678913, 18.186141438782215, 23.308922052383423, 27.4752426892519, 20.445671193301678, 26.068153493106365, 27.43505034595728, 25.47843273729086, 22.20136508345604, 34.94936563074589, 29.11507699638605, 27.443740479648113, 28.96747011691332, 50.59168227016926, 32.84351482987404, 27.630219273269176, 35.16722694039345, 32.780586406588554, 34.7985403239727, 45.207766368985176, 52.398701906204224, 46.03370904922485, 48.81197176873684, 55.539932548999786, 60.21070271730423, 68.05759325623512, 71.84504762291908, 68.56070905923843, 64.59449708461761, 58.61788518726826, 42.23072871565819, 27.412582151591778, 13.895638715475798, 4.803874650970101, 1.474160347133875, 0.7018215686548501, 0.03628885802754667, 0.03518703219015151, 0.01661252674239222, 0.07944716853671707, 0.0325417395652039, 0.02633651667565573, 0.038559989479836076, 0.04241704227752052, 0.05194418867176864, 0.06405293286661617, 0.028754372578987386, 0.0423194238828728, 0.0193741306065931, 0.07867642591008916, 0.030742879353056196, 0.04714755465101916, 0.05324096557160374, 0.06934662029379979, 0.09503400637186132, 0.029891548765590414, 0.019125880353385583, 0.010383736953372136, 0.04987813488696702, 0.07202141699963249, 0.06801443552831188, 0.032177393295569345, 0.03980406647315249, 0.03446317103225738, 0.05777612983365543, 0.02816531698044855, 0.0258055118683842, 0.060602417433983646, 0.02024297216848936, 0.07592538837343454, 0.0850191613426432, 0.13226428243797272, 0.0301635310461279, 0.045785750771756284, 0.016132928649312817, 0.002957788979074394, 0.07020589371677488, 0.029850153623556253, 0.03465645597316325, 0.007523157028117566, 0.01978136187972268, 0.03530897447490133, 0.056272742731380276, 0.03733390956767835, 0.09015301984618418, 0.02831424932082882, 0.041029077692655846, 0.022303517362161074, 0.0486620776791824, 0.01928052352013765, 0.034652251706575043, 0.04256147163687274, 0.1063023685128428, 0.16882465890375897, 0.10818642913363874, 0.14702084998134524, 0.15887725283391774, 0.11898625118192285, 0.13540218671550974, 0.15381812117993832, 0.20797271135961637, 0.1421467209002003, 0.06814902400947176, 0.13229481439338997, 0.13802527799271047, 0.15382012497866526, 0.11945788603043184, 0.17513776780106127, 0.10417940313345753, 0.119768140866654, 0.1471522546489723, 0.08618634441518225, 0.14962271583499387, 0.12994115240871906, 0.09513349868939258, 0.15331953152781352, 0.1206158590503037, 0.19113591872155666, 0.0984299108677078, 0.13180375011870638, 0.1750237590749748, 0.11158766967128031, 0.1515710019157268, 0.10639325933880173, 0.15498062130063772, 0.07790008006850258, 0.15852839889703318, 0.12472378002712503, 0.11966946491156705, 0.12423314619809389, 0.23796589724952355, 0.1455698028439656, 0.06828673693235032, 0.17790407873690128, 0.14222702127881348, 0.17272745026275516, 0.08837660774588585, 0.13407176826149225, 0.15496166684897617, 0.26214475685264915, 0.10556914145126939, 0.3048364457208663, 1.0829126788303256, 3.126066131517291, 8.045797515660524, 11.05711692944169, 19.269085228443146, 31.35572176426649, 38.29022616147995, 40.30227139592171, 47.03020937740803, 53.4833575040102, 62.77527630329132, 78.75044748187065, 83.02724719047546, 81.246297955513, 83.79346087574959, 74.43960919976234, 77.10238471627235, 65.73496788740158, 60.128779113292694, 36.07990376651287, 32.07979001104832, 48.50116364657879, 42.55941487848759, 32.784568592906, 20.20866461098194, 21.74228511750698, 25.820140801370144, 33.90207722783089, 33.19561153650284, 39.30732898414135, 22.767736092209816, 27.20776554197073, 40.63556291162968, 31.712820902466774, 33.81061613559723, 27.758148908615112, 22.815275341272354, 27.96609465032816, 25.313671678304672, 28.56978915631771, 29.68289192765951, 30.74347011744976, 26.78521491587162, 38.77679005265236, 28.539651073515415, 30.76321005821228, 27.155829928815365, 46.894659250974655, 33.3666517585516, 29.92619477212429, 37.300740256905556, 32.68112674355507, 39.4730456918478, 50.40313258767128, 55.47910541296005, 54.513790011405945, 59.95438367128372, 65.71245789527893, 68.70633244514465, 77.49590680003166, 80.36786869168282, 78.94932121038437, 74.77793544530869, 66.27343699336052, 49.28338207304478, 32.01060712337494, 17.309737466275692, 6.410149158909917, 2.37003399990499, 1.027748545166105, 0.1203168551728595, 0.10430880400235765, 0.2081514205201529, 0.14119959203526378, 0.10413422860438004, 0.15480783447856084, 0.10332303892937489, 0.1066979109600652, 0.136988720332738, 0.1323089745710604, 0.1056581101147458, 0.06284629722358659, 0.15379680669866502, 0.17171804036479443, 0.11470549143268727, 0.10590182399027981, 0.27162438724189997, 0.13738597714109346, 0.19034848519368097, 0.08596159983426332, 0.11555271979887038, 0.10492701301700436, 0.18830438784789294, 0.17889315378852189, 0.12707086658338085, 0.12787219311576337, 0.10418830890557729, 0.20440317399334162, 0.12406470093992539, 0.12961702683242038, 0.14613428036682308, 0.1367432327242568, 0.1351203041849658, 0.1675842481199652, 0.13179432484321296, 0.24153978360118344, 0.12156171884271316, 0.20903257245663553, 0.12017506785923615, 0.13306967593962327, 0.10275712906150147, 0.12445006112102419, 0.13258573628263548, 0.11333253307384439, 0.13053636968834326, 0.13841493520885706, 0.12972609285498038, 0.0925916651613079, 0.1574960714788176, 0.17184347816510126, 0.09824304550420493, 0.09632936576963402, 0.12821243813959882, 0.06644447406870313, 0.11053403519326821, 0.16009609680622816], [0.015950347333273385, 0.03736810031114146, 0.05175455880817026, 0.02328574424609542, 0.035354178689885885, 0.07267740133102052, 0.02979796023282688, 0.00833024309031316, 0.028883780869364273, 0.07067182144965045, 0.006976680297157145, 0.024813150957925245, 0.020450324518606067, 0.10669431896531023, 0.03818386532657314, 0.05610167027043644, 0.038592291457462125, 0.06297693005762994, 0.0514450572518399, 0.033788577347877435, 0.07389703197986819, 0.05460587904963177, 0.08375621153390966, 0.03578106945496984, 0.03855218950775452, 0.013490504425135441, 0.045578086719615385, 0.04838865563215222, 0.017432490458304528, 0.04497683577938005, 0.02996717917994829, 0.06341896805679426, 0.04147521605773363, 0.02088411169097526, 0.034555902384454384, 0.06207831538631581, 0.0392203116643941, 0.05377121895435266, 0.01529283324998687, 0.028339897944533732, 0.045109394486644305, 0.044118979858467355, 0.06156409239338245, 0.011241760785196675, 0.027088299284514505, 0.042348363931523636, 0.06335583355394192, 0.05503640633833129, 0.6644749164115638, 3.4594899276271462, 7.405936550348997, 13.51808812469244, 22.306537739932537, 24.569151028990746, 34.1242703050375, 41.65737748146057, 52.848916947841644, 52.951872423291206, 54.4043292850256, 53.27948324382305, 50.67367427051067, 52.12681509554386, 45.761997029185295, 43.48335050046444, 43.31059277057648, 34.95314262807369, 33.81283901631832, 44.189367815852165, 23.287143521010876, 25.460524298250675, 47.51366503536701, 13.456220794469118, 10.778626073151827, 14.002844262868166, 19.48778249323368, 30.516859777271748, 40.91788776218891, 26.76126290112734, 36.87676280736923, 31.290598958730698, 35.1710457354784, 44.877955466508865, 50.198737755417824, 50.230758637189865, 47.687152326107025, 52.4530503898859, 49.16323632001877, 38.34971196949482, 51.12550042569637, 39.0033832937479, 32.0259203016758, 39.156005904078484, 37.84714713692665, 18.55359122157097, 24.452204704284668, 20.5474354326725, 18.02842330187559, 16.545896753668785, 17.563888728618622, 16.84467662125826, 20.070099346339703, 16.45783267915249, 15.572575181722641, 30.921709053218365, 33.32059442996979, 21.699412018060684, 19.844070374965668, 30.74795577675104, 29.900937527418137, 45.823249742388725, 39.32825826108456, 52.7450343221426, 57.8645908087492, 62.60636776685715, 63.43148969113827, 53.47482316195965, 43.580735474824905, 23.055595345795155, 16.824571900069714, 7.107442142441869, 3.699544658884406, 1.2121951603330672, 0.1210448204074055, 0.047159711029962637, 0.037139644991839305, 0.004660310769395437, 0.06955655160709284, 0.010255469715048093, 0.037586477264994755, 0.04187801299849525, 0.029737968725385144, 0.02343944117455976, 0.05248025307082571, 0.023934488926897757, 0.021167808772588614, 0.11818909551948309, 0.05502435757080093, 0.02855102782632457, 0.041725872724782676, 0.01716632290481357, 0.06668638452538289, 0.03257466865761671, 0.012920566550747026, 0.006705458254145924, 0.022734903686796315, 0.02372901977651054, 0.07312696470762603, 0.07691021834034473, 0.011083594272349728, 0.08226848003687337, 0.05088759302452672, 0.049068173466366716, 0.037277376468409784, 0.04526835880824365, 0.04026107730169315, 0.05379490459745284, 0.025540290553180967, 0.06982140926993452, 0.06500433650217019, 0.0639081621193327, 0.038128348969621584, 0.02583748359029414, 0.03882732220517937, 0.05584352162259165, 0.03029088915354805, 0.04632227159163449, 0.037198734789853916, 0.0390839568717638, 0.004797972205778933, 0.042895352744380943, 0.05346356534573715, 0.04621618900273461, 0.021450672793434933, 0.04865888273343444, 0.1743990636896342, 0.004408507948028273, 0.01841217734181555, 0.05217335645284038, 0.026629507301549893, 0.07496246660593897, 0.0020220653004798805, 0.045473829814000055, 0.04044915236590896, 0.06481499236542732, 0.030572615833079908, 0.020543642167467624, 0.028526323585538194, 0.028145247451902833, 0.023206842815852724, 0.03442060144152492, 0.07814239128492773, 0.02590570551546989, 0.04872258868999779, 0.035505921914591454, 0.12074062149622478, 0.042071372154168785, 0.05712022342777345, 0.04650397902878467, 0.030293857744254638, 0.020650470614782535, 0.047884206724120304, 0.017880682717077434, 0.05815829135826789, 0.03954419975343626, 0.0895983460941352, 0.0365808597416617, 0.08021428948268294, 0.053168183148954995, 0.04797191373654641, 0.040825621617841534, 0.01628913032618584, 0.05926814723352436, 0.06666870656772517, 0.03469396040600259, 0.08212803601054475, 0.1365188814816065, 0.01816345025872579, 0.07980903232237324, 0.0412180507555604, 0.07444348273565993, 0.01982747151487274, 0.03423094931349624, 0.0881130043126177, 0.06611674165469594, 0.9352881065569818, 5.260197389870882, 9.176960717886686, 16.76936276257038, 25.10545615106821, 29.185088239610195, 39.38576057553291, 49.076794758439064, 61.93423703312874, 63.591328114271164, 68.7638233602047, 66.357541680336, 63.51862281560898, 65.16013473272324, 59.053752198815346, 55.20265504717827, 53.577577248215675, 42.86079950630665, 43.34014758467674, 51.20781160891056, 34.285548850893974, 35.98350673913956, 52.18690887093544, 30.742529667913914, 20.62114007771015, 26.684989593923092, 22.606031969189644, 38.00177603960037, 39.89699274301529, 30.362907238304615, 34.96266111731529, 33.01043227314949, 34.342754781246185, 35.255693793296814, 42.07241401076317, 35.300140008330345, 42.24251188337803, 40.082058012485504, 37.039899453520775, 36.25166215002537, 43.50363381206989, 35.59308148920536, 28.244784995913506, 32.825101017951965, 35.34281171858311, 26.193693056702614, 25.854958333075047, 26.175995506346226, 21.3582606241107, 26.040715165436268, 25.483231879770756, 24.28090799599886, 25.951136872172356, 23.493324257433414, 22.96609114855528, 38.59511040151119, 42.35771790146828, 30.813336968421936, 33.63564312458038, 44.46092024445534, 37.53397934138775, 53.11226561665535, 49.482016414403915, 59.13341872394085, 66.83902144432068, 69.97797220945358, 73.48692432045937, 61.89800217747688, 53.885949701070786, 31.378030367195606, 23.416748866438866, 10.5291941575706, 5.7465185690671206, 2.129514506086707, 0.4440735618118197, 0.0817330798599869, 0.09815012861508876, 0.03172385200741701, 0.06662540225079283, 0.03743228124221787, 0.024764607078395784, 0.06225640856428072, 0.01929882673721295, 0.04138430296734441, 0.027182134581380524, 0.07078467984683812, 0.02380960402661003, 0.1575164360110648, 0.13105910882586613, 0.040932943593361415, 0.043903441619477235, 0.016073623628471978, 0.04461152471776586, 0.028108793158025946, 0.037636130655300803, 0.01107003801735118, 0.02416006100247614, 0.02577146398834884, 0.0489981073042145, 0.029570117185357958, 0.026927212420559954, 0.05750647418608423, 0.056844025748432614, 0.047604899446014315, 0.043831831790157594, 0.0830287064309232, 0.0362856408173684, 0.014661206205346389, 0.012525576075859135, 0.08288414348498918, 0.04232338695146609, 0.06569556542672217, 0.024194355646613985, 0.018297324422746897, 0.010980535007547587, 0.06924482731847093, 0.030241228341765236, 0.007027887095318874, 0.03564571285096463, 0.061880425419076346, 0.01885751604277175, 0.04577552026603371, 0.030795226739428472, 0.0437430152669549, 0.0735358583915513, 0.03378792796866037, 0.06476850423496217, 0.018438746228639502, 0.10814961860887706, 0.19209590158425272, 0.17979308206122369, 0.15261480293702334, 0.12165295847808011, 0.1745257037691772, 0.18848529376555234, 0.13848744303686544, 0.12757468095514923, 0.24442537251161411, 0.17030427872668952, 0.07398542918963358, 0.12647570867557079, 0.18245978193590418, 0.10669117968063802, 0.11944410434807651, 0.10733760514995083, 0.23615959886228666, 0.20793456496903673, 0.14854657201794907, 0.12171233029221185, 0.19209471414797008, 0.2149970649043098, 0.17811385419918224, 0.18067758850520477, 0.13258808146929368, 0.1461496576666832, 0.155840651714243, 0.21773933025542647, 0.2222988777793944, 0.11055945375119336, 0.17644302744884044, 0.12537823553429917, 0.06710109664709307, 0.10295822139596567, 0.2433343412121758, 0.1506978354882449, 0.11230442847590894, 0.10815278015797958, 0.38325696426909417, 0.08869387587765232, 0.1452282813261263, 0.17598383099539205, 0.1688288149307482, 0.11761579386075027, 0.16883727541426197, 0.14060796675039455, 0.2673510415479541, 1.3168307393789291, 7.527220817282796, 13.515500463545322, 22.29500725865364, 33.06939370930195, 37.7163315564394, 49.481587037444115, 58.461299389600754, 70.78676640987396, 76.20167344808578, 80.8816847205162, 77.11619317531586, 75.48564746975899, 74.9976396560669, 70.47921851277351, 67.40932524204254, 63.13397705554962, 53.06468836963177, 50.77116183936596, 61.69013433158398, 40.58835804462433, 41.74150116741657, 62.402147725224495, 26.833576820790768, 20.42808573693037, 23.490160927176476, 27.87149302661419, 44.765226915478706, 54.45241570472717, 37.92840577661991, 51.281827837228775, 43.055934235453606, 50.00484935939312, 59.02273826301098, 66.66544675827026, 66.59995347261429, 68.19116368889809, 71.11132219433784, 66.60760626196861, 53.59437994658947, 68.57576385140419, 56.500600799918175, 48.34173560142517, 55.65794661641121, 53.921356201171875, 28.929120674729347, 37.74097703397274, 34.5033797621727, 28.185728564858437, 26.989060677587986, 26.77395422011614, 28.539041206240654, 30.91334570199251, 26.208975836634636, 27.46383000165224, 44.861935526132584, 46.799535155296326, 36.842849627137184, 35.10633520781994, 47.38006040453911, 45.78311629593372, 63.718309700489044, 58.051928356289864, 70.62000095844269, 77.1781374514103, 80.92802703380585, 81.00646242499352, 71.14317208528519, 60.93583680689335, 38.09795267879963, 29.217407405376434, 14.703125786036253, 6.7502442095428705, 2.780757285654545, 0.6896181078627706, 0.20449981646379456, 0.2217297098832205, 0.1287509998655878, 0.1680946082342416, 0.18322216055821627, 0.1291634261724539, 0.26205709436908364, 0.09336521310615353, 0.10401125473435968, 0.15589444257784635, 0.1272552160662599, 0.14888481324305758, 0.3015108226099983, 0.23963221174199134, 0.13219518848927692, 0.12948456831509247, 0.10029935860075057, 0.1876241056015715, 0.09664031080319546, 0.10399030390544794, 0.11673107219394296, 0.11210674259928055, 0.1026546533103101, 0.19881129905115813, 0.20418919797521085, 0.07072107036947273, 0.14825112302787602, 0.11159339162986726, 0.10352667683036998, 0.13414846180239692, 0.15995801280951127, 0.06864468959975056, 0.15285174100426957, 0.08436714007984847, 0.17649184592301026, 0.22283111640717834, 0.10873305058339611, 0.138174241874367, 0.10437006087158807, 0.18348376761423424, 0.1753652805928141, 0.10989796268404461, 0.09041079742019065, 0.09263273561373353, 0.12954729463672265, 0.11939449177589267, 0.09855295895249583, 0.16064187220763415, 0.10012479804572649, 0.07354786634095944, 0.13131727231666446, 0.2490195634891279, 0.09115325679886155], [0.005763319404650247, 0.01299027462664526, 0.03444330744969193, 0.02770293300272897, 0.027191485642106272, 0.07088635407853872, 0.021891551186854485, 0.015692731176386587, 0.0528580025275005, 0.021633779178955592, 0.0829441832320299, 0.045764855603920296, 0.018310918712813873, 0.02769572674878873, 0.021374487623688765, 0.008348182655026903, 0.04939166079566348, 0.09756542014656588, 0.02260370682051871, 0.05918794704484753, 0.01908302503579762, 0.028402999050740618, 0.06179552372486796, 0.04542441762168892, 0.0593677100550849, 0.015001597803347977, 0.07130044279620051, 0.03719096079294104, 0.005074688924651127, 0.033128169816336595, 0.07078930342686363, 0.030728509518667124, 0.04312032739107963, 0.030622554950241465, 0.020287606785132084, 0.01911521569127217, 0.03997196996351704, 0.04255376443325076, 0.030285005777841434, 0.10112170275533572, 0.08167050196789205, 0.028999607857258525, 0.07393722669803537, 0.04075470569659956, 0.041830749323708005, 0.03501126564515289, 0.922399970004335, 5.439258506521583, 19.183494821190834, 24.901806078851223, 37.35517993569374, 41.070958748459816, 46.920437067747116, 55.564395636320114, 62.63185679912567, 64.32649746537209, 67.31429234147072, 66.38605535030365, 51.17304727435112, 55.67255303263664, 50.0296126306057, 41.57083332538605, 39.30604465305805, 35.10620601475239, 26.993071362376213, 21.834584064781666, 19.51187890022993, 17.948272302746773, 12.343936879187822, 16.790588423609734, 46.65474772453308, 15.173089317977428, 28.528948947787285, 31.339680925011635, 41.99207492172718, 39.267681911587715, 62.349634543061256, 51.83877535164356, 47.32492916285992, 59.71251145005226, 40.50378978252411, 48.91022689640522, 39.45384532213211, 35.40955513715744, 25.985203944146633, 21.409158892929554, 35.217775627970695, 34.770228043198586, 30.22717472165823, 35.62819920480251, 29.379778392612934, 29.949812404811382, 34.60225045681, 43.44457358121872, 46.954137459397316, 34.58842679858208, 48.84077042341232, 46.556967571377754, 45.61514250934124, 40.08484706282616, 52.27506034076214, 35.15683829784393, 40.14890402555466, 42.8560421615839, 38.517370373010635, 18.02610542625189, 17.445753067731857, 16.055882647633553, 24.02684412896633, 25.989606007933617, 30.67834161221981, 41.16134449839592, 37.40588441491127, 47.33823224902153, 49.97060939669609, 60.23463383316994, 60.21660000085831, 53.75661604106426, 47.93575778603554, 39.97013121843338, 33.02881948649883, 20.143803991377354, 8.761076834052801, 3.7141335010528564, 0.5525556625798345, 0.08052414355915971, 0.028782488843717147, 0.04921497398754582, 0.03178277111146599, 0.09346819351776503, 0.058297006180509925, 0.07030143780866638, 0.04981890779163223, 0.06697913209791295, 0.05112037877552211, 0.10160179808735847, 0.018842606295947917, 0.012483142854762264, 0.05272879461699631, 0.06436624535126612, 0.0630915399233345, 0.026377937792858575, 0.03882089520629961, 0.06879950160509907, 0.031941612978698686, 0.0462139328737976, 0.05204743254580535, 0.008149187815433834, 0.088861838739831, 0.03717910498380661, 0.045209933232399635, 0.013692633910977747, 0.11520481581101194, 0.04709678061772138, 0.033158594160340726, 0.03554622053343337, 0.03341832729347516, 0.015887795416347217, 0.06750196029315703, 0.06100161495851353, 0.08332442259415984, 0.03952744576963596, 0.05920930976571981, 0.022212203512026463, 0.015425852088810643, 0.0625312035845127, 0.029422544830595143, 0.04275461928045843, 0.0565500276570674, 0.008772326546022668, 0.06540050977491774, 0.024050210158748087, 0.013927043110015802, 0.013249320345494198, 0.015637893884559162, 0.14279972179792821, 0.008386560966755496, 0.04039676787215285, 0.03587860250263475, 0.09047997300513089, 0.05098389781778678, 0.04707132866315078, 0.013286657795106294, 0.09608698775991797, 0.01769514950865414, 0.019083789447904564, 0.011605864001467125, 0.027068821618740913, 0.055008330891723745, 0.010306137992301956, 0.007457316469299258, 0.03526092041283846, 0.020521481637842953, 0.023235317166836467, 0.05235513439401984, 0.028826316374761518, 0.06087287460104562, 0.04922615073155612, 0.06096340177464299, 0.03725332717294805, 0.05745470196416136, 0.03340153991302941, 0.031788686028448865, 0.03181750362273306, 0.03978713808464818, 0.025544832496962044, 0.05216522251430433, 0.07113172294339165, 0.0349395778903272, 0.05370984334149398, 0.027426924571045674, 0.04284294227545615, 0.018168747337767854, 0.0811183886253275, 0.029884763680456672, 0.048794948088470846, 0.017012347670970485, 0.005214770690145087, 0.03852936846669763, 0.05295506431139074, 0.056380521127721295, 0.04019268097181339, 1.2145636207424104, 7.577261757105589, 22.445971257984638, 30.25133952498436, 43.56220006942749, 48.59317570924759, 54.478109925985336, 63.41997630894184, 72.47455224394798, 72.71855235099792, 77.16087117791176, 75.54424792528152, 59.94698166847229, 64.94633540511131, 61.0836336761713, 49.81251887977123, 48.344543650746346, 42.017522156238556, 37.15730555355549, 33.55466566979885, 30.238864794373512, 36.58245339989662, 25.49979519098997, 29.83359184116125, 50.21674118936062, 15.55192044004798, 31.868116669356823, 30.87346874177456, 38.84623892605305, 39.2446855455637, 56.886287704110146, 41.95037215948105, 39.71792355179787, 31.854053623974323, 28.869484774768353, 30.891969949007034, 27.367372177541256, 22.187271639704704, 22.047986313700676, 19.822692722082138, 25.74265915900469, 24.387372583150864, 24.548869617283344, 25.94652581959963, 24.957359097898006, 28.220935575664043, 28.543692156672478, 27.94729705899954, 38.889070227742195, 31.422930657863617, 40.17644114792347, 37.29728624224663, 31.35272942483425, 33.98514077067375, 44.624497666954994, 24.954397156834602, 40.14103464782238, 50.10443441569805, 45.15716828405857, 28.716900162398815, 26.16171207278967, 27.952985353767872, 35.027398243546486, 38.86298082768917, 44.361502379179, 52.5716458261013, 46.92594677209854, 54.851025715470314, 57.80930757522583, 67.93364390730858, 69.31700527667999, 63.25111337006092, 56.09164394438267, 47.80124120414257, 41.59391708672047, 25.177481286227703, 12.26554898545146, 5.179662611335516, 0.8214152825530618, 0.0784529949305579, 0.07669583414099179, 0.05515517223102506, 0.06107158835220616, 0.09130063248449005, 0.05017539100663271, 0.013022038547205739, 0.06024118447385263, 0.01603847551450599, 0.0178333058647695, 0.04797335350303911, 0.04072648553119507, 0.060530325208674185, 0.0598622921097558, 0.038425311940955, 0.008937435850384645, 0.14407951093744487, 0.08289327190141194, 0.058558962045935914, 0.026806305431819055, 0.042212617699988186, 0.010783265661302721, 0.029941569518996403, 0.035585105360951275, 0.018704346039157826, 0.044268288838793524, 0.04819821682758629, 0.03915971901733428, 0.07759245985653251, 0.052549042738974094, 0.03889579646056518, 0.060064089484512806, 0.013872063882445218, 0.10798785267979838, 0.04618447332177311, 0.051578539932961576, 0.046466734347632155, 0.05893058507353999, 0.022011038818163797, 0.024776154896244407, 0.04052107018651441, 0.05152708683453966, 0.04216853412799537, 0.027793773733719718, 0.03795702417846769, 0.014707291720696958, 0.04141234872804489, 0.03765482906601392, 0.07697295208345167, 0.027286831209494267, 0.043968301615677774, 0.1335332659073174, 0.1215998652332928, 0.15013776632258669, 0.18654569081263617, 0.15383971767732874, 0.15037178032798693, 0.14377518586115912, 0.16204611951252446, 0.23468725208658725, 0.10139211910427548, 0.20967476768419147, 0.12570587889058515, 0.13469434110447764, 0.10323484952095896, 0.12774742324836552, 0.10982633059029467, 0.14482517639407888, 0.1371354577713646, 0.1433022745186463, 0.15366255218395963, 0.14480913116130978, 0.11297043922240846, 0.16590070095844567, 0.1753090406418778, 0.11998426169157028, 0.11185968905920163, 0.1607768243411556, 0.11762809866922908, 0.191762528847903, 0.13586807734100148, 0.1608870629570447, 0.2772568428190425, 0.1268992671975866, 0.14510689565213397, 0.11379448289517313, 0.10268039841321297, 0.06139512021036353, 0.16699147992767394, 0.10637657585903071, 0.15074591181473807, 0.2586517942836508, 0.11969633065746166, 0.16203191480599344, 0.22175581863848493, 0.23812329192878678, 0.17020781437167898, 1.8013928504660726, 10.074671097099781, 28.22207171469927, 37.54550412297249, 52.397732958197594, 59.60555478930473, 65.21240472793579, 75.90968191623688, 82.55842834711075, 83.56617227196693, 85.68350985646248, 83.58686596155167, 69.64482128620148, 73.65907788276672, 69.65834856033325, 61.867869794368744, 60.12956567108631, 52.50909358263016, 43.323762863874435, 36.70081704854965, 33.903000578284264, 32.0206043869257, 25.7271920889616, 28.678166940808296, 60.12935288250446, 21.988694295287132, 40.73312647640705, 43.98810401558876, 58.53878103196621, 53.76035884022713, 75.54592743515968, 65.36235988140106, 63.245337679982185, 72.96955168247223, 53.191848546266556, 60.28379939496517, 49.57465924322605, 47.24951080977917, 33.166805282235146, 29.49677601456642, 45.21109879016876, 45.9250158816576, 39.93714138865471, 44.59791049361229, 40.405815839767456, 43.13164137303829, 46.95937737822533, 57.57888413965702, 65.75121581554413, 49.25982713699341, 66.41168877482414, 62.65899494290352, 60.32253071665764, 57.040392234921455, 68.29878151416779, 47.213655933737755, 54.9931912869215, 56.507280841469765, 53.26054885983467, 33.61969158053398, 30.102324821054935, 29.091282673180103, 37.395605966448784, 40.29842220246792, 46.708020865917206, 60.04832603037357, 52.27767460048199, 63.55469048023224, 67.72506549954414, 78.62853482365608, 77.47231006622314, 74.13553431630135, 64.33101162314415, 57.098977491259575, 50.59753775596619, 30.890558324754238, 15.464596375823021, 6.43336733803153, 1.2947591487318277, 0.20108243421418592, 0.14853077911539003, 0.17426440841518342, 0.15297615464078262, 0.3353885578690097, 0.15683146339142695, 0.15971142682246864, 0.1202255190582946, 0.0924007105641067, 0.10269816542859189, 0.2247127130976878, 0.16170796734513715, 0.1698796811979264, 0.14660275366622955, 0.11777131090639159, 0.16559639072511345, 0.23745359270833433, 0.17857247177744284, 0.11245060188230127, 0.11435194712248631, 0.17032562289386988, 0.1087629071844276, 0.13760117028141394, 0.2061064325971529, 0.09280797894462012, 0.18054182000923902, 0.08535993329132907, 0.21753624896518886, 0.17736688256263733, 0.13085599784972146, 0.10901171961450018, 0.11132543921121396, 0.18304214521776885, 0.22870341927045956, 0.21310516720404848, 0.18086992349708453, 0.11017617900506593, 0.19695595954544842, 0.1394667662680149, 0.1028751528065186, 0.14547722734278068, 0.1673406604095362, 0.09269371788832359, 0.18329449027078226, 0.12421100051142275, 0.17694176553050056, 0.18969938799273223, 0.06812963911215775, 0.12625358387595043, 0.08380486673559062, 0.1903434089035727], [0.038798281966592185, 0.07377675210591406, 0.06958556215977296, 0.058387169701745734, 0.011869498976011528, 0.055228437049663626, 0.012430095994204748, 0.03529396824887954, 0.06702682992909104, 0.04472985274333041, 0.05065073288278654, 0.05661328832502477, 0.007095604823916801, 0.01387744816383929, 0.03606327110901475, 0.02077647986880038, 0.04342234067735262, 0.012241200856806245, 0.0691306330554653, 0.07377597285085358, 0.035625993987196125, 0.09542881409288384, 0.06847568773082457, 0.04929779766825959, 0.010255112556478707, 0.08024337425013073, 0.028057377166987862, 0.016293946864607278, 0.03294426191132516, 0.11699021531967446, 0.06338373088510707, 0.072181186551461, 0.08442590333288535, 0.0302474772252026, 0.04373649549961556, 0.09307975342380814, 0.0540419729804853, 0.033641387199168094, 0.039796247947379015, 0.07117599205230363, 0.08872939506545663, 0.04969756293576211, 0.009932585380738601, 0.03748363786144182, 0.4547349881613627, 3.5901418793946505, 17.609604075551033, 31.060105226933956, 41.44451670348644, 62.46824897825718, 58.318917229771614, 57.36073784530163, 62.660321071743965, 60.18287681043148, 57.577577009797096, 58.53947639465332, 51.93560555577278, 45.30184172093868, 40.91944947838783, 35.464671179652214, 25.19847135990858, 26.31882604211569, 25.515433251857758, 14.586391299962997, 13.946613930165768, 9.311159066855907, 15.663778837770224, 11.659531854093075, 14.343057107180357, 19.109892770648003, 18.448371067643166, 43.191567957401276, 38.561634197831154, 58.77848356962204, 44.69527646899223, 40.18489949405193, 34.087024703621864, 32.3259712010622, 18.746212385594845, 21.75645835697651, 18.03797598928213, 11.440900135785341, 9.06576918438077, 8.556153830140829, 7.60423413477838, 4.114285279065371, 4.19115942902863, 4.233478233218193, 5.506356256082654, 5.063186036422849, 3.4600014751777053, 4.024701761081815, 11.0201021656394, 17.019176557660103, 16.559188440442085, 29.822105057537556, 32.15195573866367, 37.0581840723753, 57.337137311697006, 57.36115962266922, 63.27454671263695, 66.54117062687874, 50.41370742022991, 34.90664452314377, 33.589380607008934, 39.01699796319008, 51.14297568798065, 33.525240048766136, 17.509954422712326, 17.841986306011677, 22.729749530553818, 21.10334750264883, 25.53178757429123, 30.90301975607872, 33.869995549321175, 45.69945618510246, 51.117646247148514, 52.31096841394901, 55.969693288207054, 56.87130890786648, 53.26060205698013, 49.91361625492573, 33.47987428307533, 19.903341494500637, 6.044860985130072, 0.7417491730302572, 0.13931630324805155, 0.16971392993582413, 0.09001975238788873, 0.03769163216929883, 0.02995084079884691, 0.050716709811240435, 0.011948061801376753, 0.04152098801569082, 0.09531715055345558, 0.047153525229077786, 0.0021643853369823773, 0.02695165319892112, 0.04573764847009443, 0.03224358173611108, 0.0685440024244599, 0.08493554356391542, 0.08528712118277326, 0.04240796210069675, 0.033193204217241146, 0.03664655836473685, 0.01378964652758441, 0.08747356245294213, 0.044778834489989094, 0.05079354807094205, 0.037986958705005236, 0.06889561715070158, 0.016806362727948, 0.04609609466569964, 0.03840358927845955, 0.011397139605833218, 0.018096015010087285, 0.04676036878663581, 0.05287532425427344, 0.03269067747169174, 0.09081344222067855, 0.06732041612849571, 0.008189412219508085, 0.02476206707797246, 0.03832434274954721, 0.034029144517262466, 0.11228759656660259, 0.05098607231047936, 0.020611415093299, 0.011118932561657857, 0.07096804969478399, 0.08934635727200657, 0.08485748447128572, 0.053290355499484576, 0.0625114624563139, 0.022943957410461735, 0.06004980314173736, 0.026695883134379983, 0.062013039787416346, 0.03701914247358218, 0.015015433291409863, 0.0628745136782527, 0.02582459619588917, 0.08124620871967636, 0.032293068143189885, 0.04599220883392263, 0.06048807474144269, 0.019335856195539236, 0.04743587902339641, 0.03002670684509212, 0.04115838950383477, 0.05535552612855099, 0.038992372137727216, 0.027643425746646244, 0.02438916013488779, 0.08951817930210382, 0.026097880945599172, 0.03010133350471733, 0.07264830914209597, 0.05371381383156404, 0.040033289915299974, 0.023852758058637846, 0.020080310096091125, 0.012621642454178073, 0.018384229915682226, 0.008062543001869926, 0.05110961392347235, 0.09202197776176035, 0.05373634543502703, 0.028992937805014662, 0.014854287983325776, 0.07762435736367479, 0.026400731003377587, 0.12903135357191786, 0.04912249496555887, 0.026148879478569143, 0.043597795520327054, 0.08508939077728428, 0.04903245760942809, 0.014699790463055251, 0.9360262169502676, 4.8293541837483644, 20.549265034496784, 37.53778673708439, 50.583052933216095, 70.45607775449753, 66.38004407286644, 66.21017038822174, 72.22926020622253, 69.21940371394157, 68.57469990849495, 67.71732911467552, 60.0097580999136, 51.69078089296818, 51.62556119263172, 42.4505203217268, 35.496502071619034, 37.50017635524273, 37.41702921688557, 29.25528757274151, 22.50615242868662, 21.337245851755142, 27.646108120679855, 20.681123659014702, 22.93853122740984, 22.928562462329865, 30.441069044172764, 37.1288450807333, 36.42129644751549, 44.63020496070385, 35.98099887371063, 30.214145220816135, 25.94612494111061, 22.698492407798767, 15.17567602917552, 16.8000366166234, 10.287477727979422, 7.951052924618125, 5.812271665781736, 4.654478067532182, 3.5388218332082033, 2.548764059320092, 1.7075433488935232, 2.1551695419475436, 2.799304802902043, 3.223195569589734, 2.9527543438598514, 3.7975741736590862, 7.696957234293222, 13.210665620863438, 14.216976072639227, 19.744749404489994, 24.155991598963737, 25.12105241417885, 37.28042274713516, 50.22649146616459, 51.156122982501984, 46.17859147489071, 44.78405490517616, 29.850898012518883, 31.70149751007557, 34.70014460384846, 45.40706567466259, 34.28555265069008, 21.94314993917942, 21.13672111183405, 26.654260642826557, 26.780588664114475, 33.24261501431465, 41.589551120996475, 42.32959941029549, 55.95744654536247, 57.91346378624439, 61.234086602926254, 62.15764604508877, 66.22441962361336, 61.41743816435337, 59.548455253243446, 42.45093069970608, 26.985412873327732, 8.588103465735912, 1.0238530416972935, 0.1373090164270252, 0.10601666392176412, 0.07271291309734806, 0.0946182849293109, 0.029247038037283346, 0.029724437517870683, 0.042632409822545014, 0.02430570933938725, 0.009821594412642298, 0.046013337778276764, 0.022176673192007, 0.05371425169869326, 0.09353184010251425, 0.03440703498199582, 0.013372359153436264, 0.04841269750613719, 0.07078253504005261, 0.03241798644012306, 0.02086080639855936, 0.02808225395710906, 0.031242706536431797, 0.027106019915663637, 0.06874945116578601, 0.06967148059629835, 0.04907317183096893, 0.027209367690375075, 0.06754006957635283, 0.020791322822333314, 0.028843654799857177, 0.034291708943783306, 0.01235356572578894, 0.07546662236563861, 0.06562900962308049, 0.02486938905349234, 0.03571827262931038, 0.02421108179987641, 0.04077796089404728, 0.02932885239715688, 0.011223556830373127, 0.02908052978455089, 0.03767505630094092, 0.07007911262917332, 0.02508976795070339, 0.05483233428094536, 0.029501134558813646, 0.027520958392415196, 0.0584213047841331, 0.01480538880059612, 0.023039952357066795, 0.012884961088275304, 0.19478952657664195, 0.14790736022405326, 0.1646933751180768, 0.1428558281622827, 0.09459927852731198, 0.18538730219006538, 0.13433284097118303, 0.14827430772129446, 0.1270932942861691, 0.14841779455309734, 0.0770052577718161, 0.1956361686461605, 0.1583178516011685, 0.11601336344028823, 0.20571337634464726, 0.16916625463636592, 0.1309608039446175, 0.18842987017706037, 0.13390960899414495, 0.16596293746260926, 0.10647530376445502, 0.20983115304261446, 0.20804504107218236, 0.14227803651010618, 0.092218542995397, 0.2005579139222391, 0.12452730385120958, 0.07265627980814315, 0.11683018601615913, 0.18224965024273843, 0.15770284866448492, 0.15333609626395628, 0.13175721745938063, 0.18747917900327593, 0.13175592612242326, 0.2515891013899818, 0.11952152519370429, 0.1824057090561837, 0.17460806731833145, 0.15759364905534312, 0.19774968648562208, 0.1782606658525765, 0.13079159427434206, 0.10892020538449287, 1.7510310653597116, 7.4914181884378195, 27.107903100550175, 48.20286825299263, 64.81809988617897, 81.1686909198761, 78.6906386911869, 73.82154196500778, 83.53110775351524, 76.60465702414513, 76.40238627791405, 76.54732570052147, 68.96312266588211, 60.12868031859398, 59.51417349278927, 51.97013430297375, 42.036825120449066, 41.85142546892166, 40.27697615325451, 28.43844350427389, 24.729405529797077, 18.502919040620327, 24.92457825690508, 18.310729153454304, 23.164159320294857, 29.23276998102665, 30.38049839437008, 53.811876475811005, 52.73374892771244, 74.14704009890556, 57.50496670603752, 52.06959016621113, 41.77523575723171, 39.61889326572418, 25.06670393049717, 29.15947001427412, 22.867362946271896, 14.524775706231594, 11.98941495269537, 10.724364034831524, 10.160864721983671, 5.819355435669422, 6.422683736309409, 5.7030698005110025, 7.712824707850814, 7.219811137765646, 5.683526024222374, 5.443222168833017, 13.985995016992092, 22.427306659519672, 21.899704970419407, 38.695930391550064, 42.806086242198944, 49.882511124014854, 72.16696634888649, 72.2181648015976, 79.11040976643562, 83.58796790242195, 66.11677139997482, 49.58771914243698, 48.56309652328491, 54.186011999845505, 65.4658967256546, 43.79877157509327, 30.158373713493347, 30.66743239760399, 34.9751852452755, 35.09786546230316, 40.70560075342655, 48.603351563215256, 49.61068511009216, 65.18705248832703, 67.17629134654999, 70.48411265015602, 72.87054419517517, 74.38427656888962, 70.24334236979485, 68.61569210886955, 51.61860756576061, 32.77485251426697, 11.714565251022577, 1.6891758469864726, 0.20877703616861254, 0.31933287566062063, 0.20298917486798018, 0.20413842023117468, 0.15961316647008061, 0.14698731974931434, 0.10190636065090075, 0.08561092021409422, 0.18389469478279352, 0.1652560566435568, 0.1549131897627376, 0.12656755687203258, 0.10563514064415358, 0.1255499685066752, 0.23766742029692978, 0.19081136269960552, 0.14675823360448703, 0.09471940255025402, 0.0767933003953658, 0.101609694538638, 0.12243531571584754, 0.23586109222378582, 0.13414914457825944, 0.22725986782461405, 0.08960036473581567, 0.10431839997181669, 0.17373640002915636, 0.11894436436705291, 0.19329448492499068, 0.06729717206326313, 0.15893413103185594, 0.13992530963150784, 0.13058935903245583, 0.11411878658691421, 0.1899010592023842, 0.09000273494166322, 0.21382692066254094, 0.1789200640632771, 0.2747131168143824, 0.16311825573211536, 0.20826885796850547, 0.2925846562720835, 0.1704189702286385, 0.16344888252206147, 0.1471759588457644, 0.259072829503566, 0.14908712269971147, 0.11217116843909025, 0.15720949857495725, 0.07627082843100652], [0.051187639619456604, 0.04674765579693485, 0.04252479469869286, 0.037499030004255474, 0.043218146165600047, 0.03864437167067081, 0.06616979037062265, 0.037940596739645116, 0.044709109715768136, 0.01268219150006189, 0.029793800495099276, 0.06451677516452037, 0.05204238594160415, 0.01006562741167727, 0.017145503807114437, 0.03495490695058834, 0.08989144989755005, 0.1014184727682732, 0.03342676180182025, 0.007876072832004866, 0.028096018941141665, 0.03706757132022176, 0.028596820193342865, 0.0076100509249954484, 0.019256038212915882, 0.09046570892678574, 0.08220166448154487, 0.04475854788324796, 0.049005628970917314, 0.01626531851798063, 0.035083283655694686, 0.034090468179783784, 0.028562918887473643, 0.03610852356359828, 0.05367299942008685, 0.023545265867142007, 0.10473740912857465, 0.019700256270880345, 0.009249810445908224, 0.11081815158831887, 0.020700380046037026, 0.04527716067968868, 0.052771546033909544, 0.8575872040819377, 5.882856203243136, 20.22202279418707, 45.79527944326401, 55.917358696460724, 60.95202013850212, 61.73328101634979, 61.776982471346855, 63.06160993874073, 55.47932580113411, 55.22424928843975, 51.71565055847168, 37.15847589075565, 43.53092774748802, 41.40192098915577, 22.65764269977808, 19.933764562010765, 17.29163333773613, 13.68528675287962, 15.934458263218403, 11.21154634281993, 14.136225655674934, 23.11508685350418, 20.575582422316074, 32.71122492849827, 28.237384893000126, 37.8573077917099, 30.11860314756632, 30.360908545553684, 32.97956272959709, 25.20839262753725, 19.003680869936943, 19.845749884843826, 10.109597872942686, 6.332307485863566, 4.6811616607010365, 1.0170201770961285, 1.468484045471996, 0.5742830748204142, 0.47808618983253837, 0.23468711850000545, 0.3726039984030649, 0.10020949936006218, 0.45284767693374306, 0.13361304678255692, 0.11854744152515195, 0.23338012222666293, 0.6149984837975353, 0.6048219173680991, 0.4419522068928927, 1.0943998186849058, 3.34347621537745, 5.311122732236981, 8.511887155473232, 13.037126082926989, 13.67443548515439, 18.79408221691847, 26.778721064329147, 25.812313221395016, 33.243922144174576, 49.126978665590286, 55.04635043442249, 56.10373109579086, 52.12825521826744, 81.34460628032684, 67.5265945494175, 56.16097502410412, 72.89665639400482, 52.40956172347069, 33.26328590512276, 21.977066919207573, 25.26691898703575, 26.939735524356365, 26.045345216989517, 29.97948881238699, 45.5000276863575, 43.35403963923454, 55.20978346467018, 64.31886747479439, 62.09127500653267, 47.809425964951515, 29.84788667410612, 12.914992086589336, 3.4895957121625543, 0.11494812177261338, 0.039812679096939974, 0.005407367289080867, 0.02485844979673857, 0.01870252406661166, 0.1007592304085847, 0.09791242613573559, 0.04165282312897034, 0.03735893107659649, 0.013001912429899676, 0.02641526411025552, 0.009844883934420068, 0.06668136760708876, 0.02381471000262536, 0.04001033528766129, 0.057660952224978246, 0.04026525559311267, 0.13284722459502518, 0.018552797628217377, 0.03456303442362696, 0.03200393482984509, 0.05782007981906645, 0.03303183533716947, 0.046845481992932037, 0.031178703720797785, 0.04831435551750474, 0.012700298048002878, 0.049797719475463964, 0.009515118035778869, 0.03853954702208284, 0.031056462721608113, 0.1156090859149117, 0.06796167624997906, 0.020777025347342715, 0.05565669336647261, 0.026521124054852407, 0.018846554521587677, 0.014353443129948573, 0.04700442405010108, 0.02877355338569032, 0.010821415762620745, 0.017854965444712434, 0.044200204210937954, 0.030539792496711016, 0.037062149931443855, 0.021856801977264695, 0.0184347627509851, 0.04256636239006184, 0.08336616840097122, 0.025628754556237254, 0.03609402941947337, 0.06497991984360851, 0.08444747756584547, 0.054525478481082246, 0.04521883158304263, 0.017713749584800098, 0.03476837184280157, 0.050116449638153426, 0.06539338515722193, 0.04557126267172862, 0.04507134457526263, 0.04086961613211315, 0.019722463184734806, 0.05196641228394583, 0.02973346574435709, 0.04670685993914958, 0.0714908036752604, 0.03204914275556803, 0.08983029692899436, 0.054686220246367157, 0.0472157357580727, 0.08380606159335002, 0.06331983939162455, 0.05995916835672688, 0.04643475520424545, 0.004708940459750011, 0.035186405075364746, 0.004076917293787119, 0.017190485377795994, 0.11720595764927566, 0.025373767457494978, 0.06481105156126432, 0.0253144049202092, 0.02297733364684973, 0.017975236041820608, 0.027430345871835016, 0.032461910450365394, 0.056304347090190277, 0.10987791727529839, 0.030230443080654368, 0.13500685949111357, 0.0549202119873371, 1.024530592840165, 7.610729411244392, 24.90163128823042, 51.41347177326679, 64.0589614212513, 71.09814450144768, 71.32253766059875, 70.9204812347889, 72.2057318687439, 65.83700761198997, 63.31916391849518, 60.784730315208435, 44.039815440773964, 52.896813377738, 48.94306853413582, 29.579064399003983, 30.07102210074663, 29.157562516629696, 23.327311165630817, 25.778550133109093, 17.51967430114746, 21.35957345366478, 25.866652205586433, 24.605896957218647, 33.48820723593235, 28.49510796368122, 31.31916392594576, 30.468495972454548, 25.30188661068678, 21.456941328942776, 16.772873774170876, 13.773922696709633, 11.481705196201801, 6.830757139250636, 3.4952609706670046, 1.9306037295609713, 0.9423710452392697, 0.8304560068063438, 0.2979129203595221, 0.4053912515519187, 0.20653879299061373, 0.34673540212679654, 0.05382602284953464, 0.5938744673039764, 0.2568950713612139, 0.10832417916390114, 0.0708408975333441, 0.23206376004964113, 0.28340764401946217, 0.21272202604450285, 0.35727098991628736, 1.6363675869069993, 3.1714535085484385, 5.340000707656145, 7.689535757526755, 12.467690538614988, 14.757937844842672, 20.112676061689854, 28.885573111474514, 28.121029436588287, 37.56361395120621, 47.192244082689285, 56.2263011187315, 50.987450033426285, 64.49366569519043, 56.377229019999504, 61.148944571614265, 77.62946963310242, 62.08574630320072, 43.37849132716656, 30.56152258068323, 30.77591847628355, 37.164110988378525, 34.99766103923321, 40.27924843132496, 50.42749688029289, 51.92401997745037, 63.798333406448364, 70.82939252257347, 70.06746500730515, 60.2245719730854, 38.76428872346878, 19.673687517642975, 5.829453868791461, 0.5464018927887082, 0.11270545539446175, 0.007832802839402575, 0.03922824893379584, 0.04559807275654748, 0.006478506247731275, 0.036315742327133194, 0.05428773147286847, 0.009722205068101175, 0.039903614451759495, 0.09817476049647667, 0.044008800614392385, 0.0361673461884493, 0.0841827534895856, 0.056503598898416385, 0.026030770386569202, 0.032311477116309106, 0.014843558383290656, 0.012009188794763759, 0.030448113138845656, 0.012014321673632367, 0.019191651335859206, 0.022004355778335594, 0.0065709797036106465, 0.023491675383411348, 0.037437086648424156, 0.016433372293249704, 0.02863429494027514, 0.019698727446666453, 0.04467386883334257, 0.07431549194734544, 0.1038257400796283, 0.03980963629146572, 0.02860139553376939, 0.03720634922501631, 0.024077506350295153, 0.02648373836564133, 0.05797405319754034, 0.05275484028970823, 0.04202913281915244, 0.06641619082074612, 0.009121531147684436, 0.04708012682385743, 0.04920194929582067, 0.025560694048181176, 0.037940492838970385, 0.048881623515626416, 0.029451687114487868, 0.02409881526546087, 0.10283271680236794, 0.10032061371020973, 0.12753298709867522, 0.14964538102503866, 0.1287548293475993, 0.10153638519113883, 0.17879985098261386, 0.23870207805885002, 0.12572179053677246, 0.15564980101771653, 0.1322219058056362, 0.14505123457638547, 0.13384495308855549, 0.21813916973769665, 0.11930637658224441, 0.16236122057307512, 0.1502910940325819, 0.1599813756183721, 0.17545027134474367, 0.1381378321093507, 0.24877183459466323, 0.14635177416494116, 0.21281455701682717, 0.15206740965368226, 0.1153452078870032, 0.12879635993158445, 0.17666350468061864, 0.16101981833344325, 0.09008397784782574, 0.12224933350807987, 0.17743354226695374, 0.22894923342391849, 0.13574119977420196, 0.10787941006128676, 0.13073277164949104, 0.15347836597356945, 0.12869756523286924, 0.08072744007222354, 0.16097779793199152, 0.27214392030145973, 0.12971735035534948, 0.18273225403390825, 0.22325105324853212, 2.023691372014582, 11.322066262364388, 34.60486091673374, 62.35916443169117, 75.73573485016823, 82.5674718618393, 81.53758272528648, 80.30815109610558, 80.80532401800156, 72.24485456943512, 75.4553858935833, 68.88738512992859, 54.3515083193779, 61.10099494457245, 55.6547661870718, 34.32400278747082, 33.444862961769104, 29.87572018057108, 24.940978176891804, 27.174739614129066, 19.522201046347618, 23.637338429689407, 32.33434595167637, 31.640755869448185, 46.61476626992226, 41.18000529706478, 51.76092512905598, 41.939443945884705, 41.160884723067284, 43.12061436474323, 32.7354334294796, 25.14389678835869, 25.501983873546124, 12.82846787944436, 8.326002079993486, 6.048345398157835, 1.8410547659732401, 2.582305334508419, 1.0794699448160827, 1.1295012664049864, 0.9756923478562385, 0.8517641946673393, 0.39210119750350714, 0.9188646753318608, 0.37160747218877077, 0.6905506609473377, 0.7047692011110485, 0.9624926873948425, 1.2091157818213105, 0.8395898260641843, 1.7688371473923326, 4.537646686658263, 7.2867426462471485, 10.524975433945656, 16.661412455141544, 19.01812009513378, 24.521294496953487, 34.1625190526247, 33.842830806970596, 44.18678775429726, 63.42840425670147, 68.37244436144829, 73.77848267555237, 70.23005068302155, 95.13516068458557, 82.67127469182014, 70.41808739304543, 84.38514232635498, 65.43778583407402, 47.03734539449215, 34.57816734910011, 40.66729120910168, 42.49629646539688, 41.11129358410835, 45.54725915193558, 62.08720542490482, 62.49088816344738, 72.39898949861526, 79.86014753580093, 78.97298634052277, 68.90276670455933, 45.372666120529175, 23.90987880527973, 7.45212497189641, 0.8427323761861771, 0.18540622695581988, 0.08628129478893243, 0.10883945229579695, 0.09580137222656049, 0.2712328894995153, 0.262060419190675, 0.16454656346468255, 0.11674541048705578, 0.13387530692853034, 0.1835161549388431, 0.07073653672705404, 0.10639528540195897, 0.2143141406122595, 0.13776698091533035, 0.16216343821724877, 0.13020706392126158, 0.2547532628523186, 0.21537912252824754, 0.11855343807837926, 0.08359305778867565, 0.13042947073699906, 0.12185663348645903, 0.13860727020073682, 0.17944850289495662, 0.1301186889759265, 0.193589830014389, 0.1859856364899315, 0.13521074230084196, 0.1696986416936852, 0.1975934495567344, 0.20434564270544797, 0.15246539376676083, 0.08648704781080596, 0.13266257825307548, 0.20101813453948125, 0.08885448405635543, 0.08130359157803468, 0.1012527289276477, 0.17826180875999853, 0.11423877702327445, 0.17517972883069888, 0.13033762254053727, 0.1297530476585962, 0.1410861176555045, 0.1472382844076492, 0.15865296096308157, 0.09796422062208876, 0.19458941387711093], [0.03647059515060391, 0.04474600558751263, 0.0458905420236988, 0.036997289935243316, 0.02694655649975175, 0.023490532475989312, 0.1964158986811526, 0.020618261405616067, 0.02556378509325441, 0.03563239130016882, 0.04515336302574724, 0.07467309580533765, 0.014027462184458273, 0.0713916304812301, 0.07875540526583791, 0.03871666427585296, 0.12562458403408527, 0.01898680373415118, 0.008859822046360932, 0.056130109369405545, 0.036361384409246966, 0.006072434580346453, 0.03886481550580356, 0.013816051214234903, 0.023433043861587066, 0.10289668251061812, 0.02754470711806789, 0.041607500170357525, 0.03172300595906563, 0.050045767493429594, 0.04139651500736363, 0.021293500758474693, 0.010680541290639667, 0.09258770951419137, 0.030333237955346704, 0.014863140877423575, 0.030244048502936494, 0.052119161118753254, 0.034997190814465284, 0.04010012031358201, 0.03045880006538937, 0.3054841031553224, 2.7971747796982527, 11.944299973547459, 29.98276423662901, 50.99091164767742, 65.39035677909851, 65.05053341388702, 61.72278217971325, 58.20417478680611, 51.874569430947304, 48.262426257133484, 61.97578780353069, 45.423704981803894, 35.19758351147175, 32.941560968756676, 26.07808046042919, 22.206411212682724, 25.73495127260685, 14.055864717811346, 15.18912160769105, 20.662896037101746, 24.777894727885723, 40.585181415081024, 34.92355741560459, 45.48431172966957, 40.52312694489956, 38.35497088730335, 33.555167242884636, 28.77922061830759, 19.910437613725662, 12.03154994174838, 8.891239799559116, 5.923058046028018, 2.533988314680755, 0.8403748401906341, 0.802022370044142, 0.3962158126523718, 0.3314810909796506, 0.1980739159625955, 0.031954533769749105, 0.08586803727666847, 0.06634376462898217, 0.10316055311704986, 0.009837190646067029, 0.06644376160693355, 0.03573693393263966, 0.013341996964300051, 0.03102830749412533, 0.043192093071411364, 0.04071507129992824, 0.08459478645818308, 0.0493277396162739, 0.17592739808605984, 0.05091531224024948, 0.19620449049398303, 0.2664469869341701, 0.46202091907616705, 0.8491710119415075, 5.129895256832242, 4.445546753704548, 5.513198263943195, 8.50291583687067, 9.918050151318312, 15.783189330250025, 24.145367369055748, 28.662179298698902, 47.72852070629597, 58.58247488737106, 38.40728648006916, 33.214431926608086, 32.94103279709816, 51.75866425037384, 61.10788397490978, 41.00309818983078, 27.139733992516994, 22.679168544709682, 28.815696761012077, 35.13139866292477, 28.85484416037798, 37.76028759777546, 45.31370848417282, 50.97055234014988, 57.66987405717373, 57.701290771365166, 47.6649235188961, 24.3652805685997, 5.325428489595652, 1.1213524849154055, 0.27956613921560347, 0.0240180491891806, 0.0269686112733325, 0.0618728221161291, 0.042209140738123097, 0.07595316696097143, 0.0322578309715027, 0.02025888938078424, 0.043968487152596936, 0.061859756606281735, 0.07232168994960375, 0.02330931671167491, 0.04167512095591519, 0.022466281479864847, 0.03951771250285674, 0.014424402652366553, 0.028484086105891038, 0.02600002320832573, 0.03565467799489852, 0.025470871914876625, 0.039193071133922786, 0.04160913289524615, 0.03054927714401856, 0.0785376739804633, 0.013027258628426353, 0.021916611658525653, 0.0373252227291232, 0.037385021278169006, 0.04177829061518423, 0.07716641513979994, 0.05580829187238123, 0.03842122641799506, 0.057406351043027826, 0.06013321311911568, 0.15664470935007557, 0.03760014762519859, 0.04661813989514485, 0.049972220658673905, 0.03287525330961216, 0.02400545865384629, 0.022965971365920268, 0.038665804895572364, 0.04747111248434521, 0.021846833078598138, 0.08238087088102475, 0.1083119040413294, 0.02114797302056104, 0.0117794282232353, 0.06974310526857153, 0.05947805257164873, 0.015974433736118954, 0.04558721513603814, 0.06797349124099128, 0.06473446192103438, 0.011255098106630612, 0.02907871708885068, 0.03844843726255931, 0.0400293454003986, 0.0645491921750363, 0.04122743150219321, 0.08303525217343122, 0.04190076724626124, 0.034890273309429176, 0.04515686225204263, 0.023746361912344582, 0.030976218004070688, 0.03721915498317685, 0.03575362112314906, 0.009846595512499334, 0.05995547617203556, 0.06164666745462455, 0.008998535940918373, 0.09403529082192108, 0.05990167417621706, 0.01518872013548389, 0.03586880615330301, 0.013525559770641848, 0.04389368237752933, 0.022491811359941494, 0.027140201382280793, 0.03812352500972338, 0.05797461351903621, 0.03943716721551027, 0.014337189168145414, 0.09632314657210372, 0.06248864141525701, 0.013823189747199649, 0.06255072948988527, 0.18767440837109461, 3.050039098598063, 13.777193371206522, 33.734122440218925, 58.322846218943596, 73.82153436541557, 75.9976775944233, 71.34214460849762, 68.41665878891945, 60.18573805689812, 57.99034126102924, 69.65900212526321, 56.23663276433945, 43.97086054086685, 40.5353394895792, 36.10280133783817, 29.607350081205368, 32.15675488114357, 18.739247359335423, 19.203658439218998, 25.671036802232265, 28.714730478823185, 35.73988281190395, 30.154784806072712, 35.18132798373699, 28.0604150891304, 26.146161407232285, 20.982323996722698, 17.203459069132805, 11.976976320147514, 8.779028970748186, 4.4423648994416, 2.4082991341128945, 1.3699464267119765, 0.8472106733825058, 0.41587966843508184, 0.3598311322275549, 0.3484025626676157, 0.206639873504173, 0.04359537982963957, 0.0980109981901478, 0.02799253757984843, 0.024537754798075184, 0.050043325827573426, 0.1999916700879112, 0.16423306544311345, 0.31553996668662876, 0.01890604879008606, 0.033358087166561745, 0.1313259851303883, 0.011243698718317319, 0.12023558258078992, 0.1972547482000664, 0.018743158507277258, 0.047836653611739166, 0.17925112129887566, 0.5113971023820341, 0.828656981466338, 3.0096237547695637, 3.871396374888718, 4.469650285318494, 8.44359626993537, 10.615141745656729, 16.2516937404871, 24.10381279885769, 29.369397349655628, 46.58549264073372, 66.05315521359444, 43.93653318285942, 40.13083979487419, 39.69243071973324, 45.84800161421299, 63.42699833214283, 49.67671796679497, 35.1263677328825, 30.394873023033142, 37.3833592236042, 47.168274968862534, 38.74420300126076, 46.17922984063625, 52.703798934817314, 57.934355065226555, 66.68213546276093, 65.81338047981262, 57.68068827688694, 30.57915173470974, 6.969830151647329, 1.107913318555802, 0.12717126432107762, 0.053674721202696674, 0.09324733036919497, 0.12730415328405797, 0.055124235805124044, 0.05868966909474693, 0.05664100383000914, 0.04780234783538617, 0.015413628916576272, 0.05143292684806511, 0.07306871353648603, 0.051122182194376364, 0.012999711034353822, 0.033915176609298214, 0.043530308321351185, 0.08930411422625184, 0.022646929501206614, 0.03699769811646547, 0.08447374959359877, 0.0370461603597505, 0.03504881460685283, 0.0068963293597335, 0.046139157784637064, 0.06535987718962133, 0.02197125413658796, 0.046298808592837304, 0.02657498356711585, 0.03312692300823983, 0.01849156858952483, 0.013486186981026549, 0.028432889048417564, 0.032093014815473, 0.05591494591499213, 0.08021523943170905, 0.10397396923508495, 0.03341017109050881, 0.024331808817805722, 0.027864539370057173, 0.028783288507838733, 0.015321732480515493, 0.056340597293456085, 0.013785276205453556, 0.016950434001046233, 0.054415380873251706, 0.04698701326560695, 0.016411859287472907, 0.03799898149736691, 0.1470755462651141, 0.12806881772121415, 0.14435177523409948, 0.08379766790312715, 0.11777700317907147, 0.11481857247417793, 0.204277602606453, 0.1363670380669646, 0.1264936538063921, 0.10203568730503321, 0.14388742827577516, 0.139114142220933, 0.16597285255556926, 0.15260475425748155, 0.13299224025104195, 0.17338013945845887, 0.1797016494674608, 0.09390143706696108, 0.09576278796885163, 0.10647091025020927, 0.19929868227336556, 0.0804898637579754, 0.16168638569070026, 0.152565746975597, 0.0594388411991531, 0.27754651790019125, 0.1934361906023696, 0.13017325167311355, 0.11681995922117494, 0.12537418340798467, 0.17374463786836714, 0.12076891216565855, 0.14465409651165828, 0.1265360155957751, 0.11971529253059998, 0.17012825614074245, 0.1386736478889361, 0.11682967393426225, 0.2099446125794202, 0.15142657997785136, 0.20156900107394904, 0.8800750505179167, 5.4703588876873255, 20.885328501462936, 43.56381118297577, 70.19374743103981, 85.96907213330269, 85.4289311170578, 82.14021518826485, 77.63251706957817, 70.2948448061943, 66.10662594437599, 77.45008125901222, 62.40776762366295, 51.08480080962181, 47.084538862109184, 38.929450660943985, 34.15697135031223, 39.10810947418213, 23.454651832580566, 24.767012111842632, 30.420658439397812, 35.36588408052921, 54.807335659861565, 49.21992927789688, 57.88106292486191, 53.785783275961876, 50.35077139735222, 44.90783326327801, 36.741809248924255, 26.667368039488792, 16.394495777785778, 11.158621832728386, 8.576342146843672, 3.764465362764895, 1.6237282776273787, 1.314221229404211, 0.8151533966884017, 0.8842337492387742, 0.7759501878172159, 0.3500013565644622, 0.39404482289683074, 0.20563703903462738, 0.35290781466756016, 0.33708813542034477, 0.3766758064739406, 0.31007152574602515, 0.7621237391140312, 0.17653910588705912, 0.41254947369452566, 0.17339152400381863, 0.17024364526150748, 0.17945072933798656, 0.40003362810239196, 0.12982509535504505, 0.7291455462109298, 0.6561119807884097, 1.0326369828544557, 1.7327941814437509, 7.007606299594045, 5.527685461565852, 7.162308348342776, 11.848278176039457, 12.401749826967716, 20.486813485622406, 29.076220281422138, 35.63344292342663, 57.84672796726227, 68.65109100937843, 48.63045930862427, 44.008877500891685, 45.88275834918022, 63.66986609995365, 73.62705320119858, 55.371848568320274, 41.72727093100548, 36.63635730743408, 44.185055047273636, 51.681748777627945, 45.15583075582981, 54.566751569509506, 62.796881943941116, 68.46679329872131, 75.67193627357483, 76.17473289370537, 66.16336449980736, 35.790435299277306, 9.594403468072414, 1.836965235415846, 0.4943222436122596, 0.14632643724326044, 0.1424634546856396, 0.2909923635888845, 0.14117266691755503, 0.1907146311714314, 0.14329917234135792, 0.09709943304187618, 0.1270523722632788, 0.13261899934150279, 0.2037362355622463, 0.10661738793714903, 0.13117583381244913, 0.3063790441956371, 0.15078595810336992, 0.16009186656447127, 0.12772242771461606, 0.11296808661427349, 0.1912656461354345, 0.15968309162417427, 0.15082983387401327, 0.14764685154659674, 0.14117845566943288, 0.13028993213083595, 0.08276702516013756, 0.13298962789122015, 0.2320441821939312, 0.06209012666658964, 0.19069594389293343, 0.17562489869305864, 0.1751583252917044, 0.13400389143498614, 0.17855259706266224, 0.13373155292356387, 0.255369542283006, 0.13465531897963956, 0.16168789967196062, 0.12285786491702311, 0.16378143889596686, 0.12141877377871424, 0.08813459338853136, 0.1607252302346751, 0.16287728038150817, 0.1223290698544588, 0.19980831508291885, 0.1832049575750716, 0.13677489274414256], [0.027476351606310345, 0.031106307214940898, 0.058907526545226574, 0.0799829101015348, 0.01693229962256737, 0.00795395844761515, 0.018577088121674024, 0.025595777224225458, 0.010035879349743482, 0.04526994700427167, 0.08123005216475576, 0.025820059818215668, 0.033399491585441865, 0.0027587595832301304, 0.10170101581024937, 0.014727907655469608, 0.01717453105811728, 0.039397109794663265, 0.021736080525442958, 0.062013210481381975, 0.036763101525139064, 0.03982512491347734, 0.021624567270919215, 0.08902073255740106, 0.042493301662034355, 0.02818328808643855, 0.030989539554866496, 0.0777737665339373, 0.02250188415928278, 0.02472429918270791, 0.03673096653074026, 0.041779073580983095, 0.03431823701248504, 0.04233950639900286, 0.035333728810655884, 0.04628642214811407, 0.10412058050860651, 0.05165867703908589, 0.005929186627326999, 0.08042914123507217, 0.6136989535298198, 6.956018842756748, 18.490440510213375, 35.28645694255829, 57.01391905546188, 68.221106082201, 65.43334767222404, 66.2008760869503, 62.94735386967659, 51.363926231861115, 42.819248735904694, 34.78103846311569, 28.552194200456142, 27.811517044901848, 26.215399391949177, 18.56371957808733, 17.0280072838068, 23.61689742654562, 13.931536339223385, 27.03381847590208, 39.27837833762169, 41.63245841860771, 37.48228691518307, 41.65565997362137, 32.530362233519554, 30.39127841591835, 20.61125110834837, 18.189158476889133, 8.88778768479824, 5.48355795443058, 2.7924186224117875, 0.8114929462317377, 0.19766052486374974, 0.0835501542314887, 0.010806660011439817, 0.0887131346098613, 0.054921254704822786, 0.09874711962766014, 0.20182502717943862, 0.08736497140489519, 0.08455201648757793, 0.07157804313465022, 0.026824814594874624, 0.08398073347052559, 0.06994626819505356, 0.05772495504061226, 0.26785107096657157, 0.07318814736208878, 0.07979749192600138, 0.021771343672298826, 0.09722773553221487, 0.04675858763221186, 0.0917155524075497, 0.008366002548427787, 0.03417675026867073, 0.02425706341455225, 0.12676734302658588, 0.06053315279132221, 0.029533813176385593, 0.057355855315108784, 0.11801709537394345, 0.7091970916371793, 0.5517213104758412, 0.7285986130591482, 1.6536650899797678, 3.7181586725637317, 7.229194259271026, 9.091814886778593, 12.471525482833385, 30.58589067310095, 45.53086683154106, 58.05543556809425, 80.18404975533485, 59.87381659448147, 23.54833770543337, 23.78414925187826, 21.79195035248995, 17.93575767427683, 14.80130871757865, 28.119631111621857, 46.48835465312004, 35.408453196287155, 43.202819153666496, 52.108226493000984, 60.56477151811123, 60.9919635951519, 46.10618636012077, 26.756518855690956, 9.755004700273275, 2.4708722764626145, 0.5409250210504979, 0.10294740088284016, 0.0813760919845663, 0.061561398397316225, 0.06336359641863964, 0.007585195007777656, 0.037930611142655835, 0.029064091213513166, 0.051428240185487084, 0.015568389899272006, 0.07244556181831285, 0.059825277494383045, 0.028016950527671725, 0.03850641012832057, 0.04658334801206365, 0.030548453360097483, 0.09357681425171904, 0.03891009764629416, 0.03728925083123613, 0.04188214676105417, 0.044490391373983584, 0.005503827005668427, 0.023569359691464342, 0.03219438476662617, 0.0632833554118406, 0.04794384942215402, 0.0988428715209011, 0.01674018356425222, 0.027315563456795644, 0.03690682213346008, 0.04259826731868088, 0.023031829550745897, 0.04017299921542872, 0.03476023419352714, 0.03218739373551216, 0.1039508735993877, 0.016563580247748177, 0.03269016167905647, 0.03948820842197165, 0.0610621742089279, 0.061622966968570836, 0.047020565762068145, 0.049123211138066836, 0.021282223824528046, 0.06871879304526374, 0.029732233779213857, 0.01257960999282659, 0.06887371637276374, 0.07177643405157141, 0.06324230722384527, 0.034989502164535224, 0.008366863439732697, 0.015069848486746196, 0.034655580238904804, 0.007962067338667111, 0.03373193663719576, 0.03029058858373901, 0.0368230485037202, 0.05733478574256878, 0.027376050347811542, 0.05833113755215891, 0.03636336594354361, 0.020090627804165706, 0.017344490297546145, 0.05151765413756948, 0.042165773338638246, 0.030518561507051345, 0.04076088407600764, 0.01002492432235158, 0.07828927715308964, 0.02873636065487517, 0.0384053926973138, 0.040943203784991056, 0.019703872385434806, 0.02195063541876152, 0.04209109101793729, 0.04121271842450369, 0.08379173814319074, 0.021540229608945083, 0.05114284358569421, 0.026958449416270014, 0.053330939845182, 0.011788002811954357, 0.02901151561673032, 0.05385020202083979, 0.051174191903555766, 0.6352911761496216, 7.166686663404107, 20.178180746734142, 39.95324492454529, 64.66589525341988, 78.36998909711838, 76.35610476136208, 77.06204608082771, 71.84225097298622, 61.0563625395298, 54.464225471019745, 42.67780512571335, 38.83724480867386, 36.96704216301441, 32.596562281250954, 27.143343798816204, 28.32769274711609, 30.626535192131996, 21.008717380464077, 30.36627385765314, 39.22920897603035, 39.49717439711094, 35.716088488698006, 36.351972967386246, 27.58887179195881, 20.217301547527313, 14.467860460281372, 10.28517410159111, 5.172238284721971, 3.4982274239882827, 1.6270142700523138, 0.4972940403968096, 0.16007547994377092, 0.11166239652084187, 0.030262850814324338, 0.19070481997914612, 0.1810011055204086, 0.11023532075341791, 0.16213188209803775, 0.07660650182515383, 0.04966886408510618, 0.042625422502169386, 0.08633004646981135, 0.13012709008762613, 0.31779009907040745, 0.15447456564288586, 0.6691015243995935, 0.45822106359992176, 0.1657792559126392, 0.287765683606267, 0.2818820852553472, 0.21288854914018884, 0.06420037534553558, 0.09492887373198755, 0.13398839539149776, 0.1296457479475066, 0.1375880342675373, 0.08251223101979122, 0.029003576491959393, 0.11094822039012797, 0.10223392979241908, 0.3393053758190945, 0.3978028806159273, 0.2839972951915115, 1.3229999458417296, 2.70227178465575, 5.793826030567288, 10.185438953340054, 15.235538017004728, 24.106037579476833, 34.11246053874493, 48.96171413362026, 79.13678795099258, 66.10423967242241, 30.782321132719517, 36.531357541680336, 31.698383577167988, 26.36249329894781, 23.757286593317986, 35.87785340845585, 52.75153197348118, 42.182224318385124, 49.898865446448326, 59.04111787676811, 68.33642989397049, 68.62111061811447, 57.161506935954094, 38.99639926850796, 17.091465778648853, 4.910544427111745, 0.7381154992617667, 0.17326074274023995, 0.0662226090207696, 0.03919121947546955, 0.04017918501631357, 0.007627458926435793, 0.024421560447080992, 0.02519421039323788, 0.012854064552811906, 0.04068164125783369, 0.03625866003858391, 0.02818746452248888, 0.017651717171247583, 0.011272139672655612, 0.03202114152372815, 0.026059626943606418, 0.03990982622781303, 0.018409694857837167, 0.06689700603601523, 0.056400087851216085, 0.045042066849418916, 0.03320394680486061, 0.025470506407145876, 0.00480926027194073, 0.022979472887527663, 0.04583074347465299, 0.07565875697764568, 0.037981964051141404, 0.09745428353198804, 0.05289909524435643, 0.051379547876422293, 0.024932208143582102, 0.009078575640160125, 0.031054820719873533, 0.06156390685646329, 0.11017598604667, 0.004424234057296417, 0.01804863815777935, 0.059614893471007235, 0.04307935341785196, 0.019968583474110346, 0.04404990446346346, 0.03628174825280439, 0.04354964126832783, 0.03663033130578697, 0.060953790962230414, 0.0994860686478205, 0.10734122683061287, 0.17793808394344524, 0.16105343762319535, 0.12896334315882996, 0.13271446921862662, 0.12255431167432107, 0.15213338658213615, 0.07318210628000088, 0.13230156793724746, 0.2304154055309482, 0.11427511257352307, 0.14975557511206716, 0.08921558342990465, 0.184737017552834, 0.10618013679049909, 0.11265065521001816, 0.16665329807437956, 0.15066469117300585, 0.1613201803411357, 0.19883383065462112, 0.10558813301031478, 0.1652821060270071, 0.10887131269555539, 0.09711291786516085, 0.15690137370256707, 0.09397810092195868, 0.15662118326872587, 0.06911791264428757, 0.09792731361812912, 0.11711643237504177, 0.16507304302649572, 0.19418325129663572, 0.11400648480048403, 0.21817618806380779, 0.12699681508820504, 0.3013011807342991, 0.09955005662050098, 0.10197711701039225, 0.24564630934037268, 1.7401072452776134, 11.814553085714579, 28.935891911387444, 51.34450927376747, 76.09709545969963, 86.39525726437569, 84.16534692049026, 86.71754837036133, 81.34386911988258, 70.19607290625572, 61.26296125352383, 50.01026026904583, 43.446834459900856, 42.01401114463806, 38.18613074719906, 30.283100120723248, 28.9983681589365, 35.451843068003654, 25.736252702772617, 39.40738141536713, 52.29188583791256, 54.036512821912766, 50.09849153459072, 52.314023450016975, 44.331210404634476, 38.6903864890337, 26.131473295390606, 22.996806800365448, 12.25440988317132, 7.385822329670191, 4.119136668741703, 1.3084575324319303, 0.592633537016809, 0.3398966894019395, 0.14345098607009277, 0.38497019733767956, 0.22749380761524662, 0.3761046496219933, 1.06879465514794, 0.23910764692118391, 0.2668793621705845, 0.25910723546985537, 0.45607913634739816, 0.251302098040469, 0.4015477281063795, 0.20708137715701014, 0.908115942729637, 0.43392786872573197, 0.3284515254199505, 0.24887073319405317, 0.29244424193166196, 0.3524643072159961, 0.20518481876933947, 0.10602038208162412, 0.2167794364504516, 0.26712058985140175, 0.30577149242162704, 0.17709292616927996, 0.12919746106490493, 0.1963669911492616, 0.3108594787772745, 0.9654444165062159, 1.0238393861800432, 1.467368092853576, 2.8000609623268247, 5.926176253706217, 9.7736132517457, 12.908955160528421, 18.60425390303135, 39.93772275745869, 57.467728704214096, 72.04810872673988, 91.71902239322662, 66.23272597789764, 35.05565732717514, 37.23522797226906, 34.13823835551739, 28.239999152719975, 27.677175253629684, 43.37231285870075, 61.78998537361622, 51.667780727148056, 61.530736684799194, 70.97487911581993, 78.94782409071922, 78.72361332178116, 65.72615996003151, 45.70346496999264, 20.301847010850906, 6.177076790481806, 0.8459199301432818, 0.42425272695254534, 0.21285967959556729, 0.11611168316449039, 0.130883501842618, 0.0782807869836688, 0.10494896574527957, 0.14526904007652774, 0.10110815113876015, 0.15730946586700156, 0.11744979026843794, 0.1700033081579022, 0.12121194464270957, 0.2148639236111194, 0.13516138948034495, 0.15066337015014142, 0.22652949061011896, 0.10172816357226111, 0.24375969573156908, 0.2085555941448547, 0.14141589839709923, 0.11718140740413219, 0.09656621477915905, 0.11414554843213409, 0.19032580516068265, 0.17744103795848787, 0.22252584138186648, 0.15229179058223963, 0.2019605433451943, 0.14865738950902596, 0.1260647815070115, 0.15134540386497974, 0.12453034665668383, 0.14505435159662738, 0.20130408403929323, 0.13328670960618183, 0.07020390476100147, 0.07980618247529492, 0.15504895825870335, 0.18700858316151425, 0.095370748458663, 0.21171157713979483, 0.1562053430825472, 0.12126557965530083, 0.14388114970643073, 0.08534995140507817], [0.03541102720191702, 0.010867074543057242, 0.05172283941647038, 0.09918037059833296, 0.014027182951394934, 0.031432844771188684, 0.04923550550302025, 0.05529978712729644, 0.025951089701266028, 0.023273931110452395, 0.046153470102581196, 0.026499074847379234, 0.0570452961983392, 0.011821225980384042, 0.06126574160589371, 0.03299194489954971, 0.011418851136113517, 0.025492733730061445, 0.041482689484837465, 0.04139265583944507, 0.03328181293909438, 0.03613973087340128, 0.029558617607108317, 0.07101622250047512, 0.032810003685881384, 0.061574708815896884, 0.042488091785344295, 0.021769462327938527, 0.05111312428198289, 0.06298659282037988, 0.039222115083248354, 0.008559147408959689, 0.04207042962661944, 0.05546398359001614, 0.057838447974063456, 0.027376777652534656, 0.08697996745468117, 0.13316137570654973, 0.02644386091560591, 0.4257916146889329, 6.892237365245819, 16.347834281623363, 38.83360840380192, 54.626142382621765, 66.18373140692711, 65.44382750988007, 70.79131856560707, 59.68036897480488, 47.69678480923176, 39.12087298929691, 33.560654148459435, 33.957960829138756, 26.981136202812195, 21.44596941769123, 18.56852252036333, 18.182924911379814, 26.56394138932228, 35.63835985958576, 24.56845186650753, 35.34122720360756, 42.6823078840971, 40.31848132610321, 23.034867458045483, 19.320063292980194, 9.929611030966043, 7.704430483281612, 2.890220624394715, 1.071237449068576, 0.26178042171522975, 0.1781055866740644, 0.05182837281608954, 0.07069899889756925, 0.010977748243021779, 0.01759640119416872, 0.03745755137060769, 0.08697925499291159, 0.021664010564563796, 0.10344348949729465, 0.015255759262799984, 0.14634954772191122, 0.12137505385908298, 0.06890530217788182, 0.10997258563293144, 0.018474872122169472, 0.04642585314286407, 0.3398115502204746, 0.32596331206150353, 0.6000670662615448, 0.04713889749837108, 0.07537280005635694, 0.09128848352702335, 0.09900728691718541, 0.09203788940794766, 0.11427568402723409, 0.026823530679394025, 0.11043319958844222, 0.04949509020661935, 0.06243111754884012, 0.05714972750865854, 0.05782909691333771, 0.055988659732975066, 0.04062896732648369, 0.15318690973799676, 0.0882200145861134, 0.08680745522724465, 0.07666550998692401, 0.40875321021303535, 0.7387864007614553, 4.286168580874801, 6.962655186653137, 12.651675716042519, 24.204420000314713, 27.017296962440014, 30.669222101569176, 31.33375894278288, 33.504238575696945, 28.742394894361496, 28.662251494824886, 23.934657275676727, 26.14259909838438, 28.821120969951153, 22.12062131613493, 34.21917021274567, 34.76172789931297, 45.693927481770515, 55.534502640366554, 66.60737067461014, 56.1040198802948, 46.490691527724266, 27.677705325186253, 6.259834449738264, 0.6179718242492527, 0.21636629768181592, 0.027977631543762982, 0.06522701049107127, 0.019294269950478338, 0.14625256386352703, 0.03094450046774, 0.0711844525358174, 0.12585223041241989, 0.03342165582580492, 0.005490347748491331, 0.04110849491553381, 0.0528952509193914, 0.02662324914126657, 0.028995809916523285, 0.07730268087470904, 0.04898016217339318, 0.013535978596337372, 0.03982479465776123, 0.02855420607374981, 0.0292524928227067, 0.02033752178249415, 0.005026050421292894, 0.01916186523885699, 0.037355216627474874, 0.04577400999551173, 0.02277220588439377, 0.015134383793338202, 0.034723071148619056, 0.02225673608336365, 0.01885674977529561, 0.029369403346208856, 0.07386719764326699, 0.023132030619308352, 0.018293441135028843, 0.019395905219425913, 0.022055608496884815, 0.026799967490660492, 0.015493887549382634, 0.05712279125873465, 0.031451149843633175, 0.041764200941543095, 0.023478030998376198, 0.07146717369323596, 0.024100908121909015, 0.04493306390941143, 0.04746416969283018, 0.07131227263016626, 0.04003174624813255, 0.01785547567124013, 0.0469359869020991, 0.019458963652141392, 0.08107807516353205, 0.012967807961103972, 0.030597501900047064, 0.03322803691844456, 0.04699028613686096, 0.030134579865261912, 0.023789948245394044, 0.03250118490541354, 0.01150041316577699, 0.03773970478505362, 0.01566482456837548, 0.005611585920632933, 0.04617214624886401, 0.04728061059722677, 0.09042949212016538, 0.01900045739603229, 0.05654767133819405, 0.045216163562145084, 0.0035888730963051785, 0.08779416282777674, 0.010461399924679426, 0.04255366053257603, 0.04436061943124514, 0.06248182849958539, 0.051574799508671276, 0.03099113888310967, 0.04760262476338539, 0.020597408911271486, 0.051846533169737086, 0.06022011490131263, 0.06908148061484098, 0.025398881734872703, 0.4708252544514835, 7.052134210243821, 21.220897994935513, 45.10054752230644, 61.620537266135216, 75.04332840442657, 74.41309422254562, 80.41447699069977, 69.11009877920151, 57.81800530850887, 50.44142313301563, 42.95304335653782, 44.028355255723, 33.606206104159355, 28.404988199472427, 24.658985808491707, 25.781107395887375, 31.66308917105198, 38.772275894880295, 26.256000213325024, 33.94141651690006, 34.58497658371925, 32.3950856924057, 18.674354441463947, 15.626970212906599, 6.807727525010705, 4.7184851579368114, 1.6968045313842595, 0.628912802785635, 0.30125766119454056, 0.06410450470866635, 0.05278039243421517, 0.18189046561019495, 0.01633046424103668, 0.13802140398183838, 0.10149880283279344, 0.1366841874551028, 0.0706451635051053, 0.15780055982759222, 0.09104580123675987, 0.21753204840933904, 0.02223409686848754, 0.07888558538979851, 0.07961780313053168, 0.046616251129307784, 0.08238478199928068, 0.24369974504224956, 0.7979048753622919, 0.9126898285467178, 0.7452275895047933, 0.7892680575605482, 0.47762653324753046, 0.19160976517014205, 0.4110707592917606, 0.5246545316185802, 0.2765774808358401, 0.6379757320974022, 0.15493610728299245, 0.2320302149746567, 0.1852549030445516, 0.16233873349847272, 0.05169340583961457, 0.11816324651590548, 0.05204222266911529, 0.11351123481290415, 0.07595075498102233, 0.05129488738020882, 0.28595261683221906, 0.95347695867531, 3.209593486972153, 6.792902145534754, 13.253952898085117, 26.33186124265194, 31.367079354822636, 30.681415647268295, 31.25238060951233, 32.17282421886921, 30.933157838881016, 27.082547061145306, 31.160693429410458, 34.75007772445679, 40.47482393682003, 29.392864890396595, 43.05387854576111, 44.3845671415329, 51.23242288827896, 64.06251803040504, 74.37832608819008, 66.90725058317184, 58.52977931499481, 37.41846174001694, 11.249854937195778, 0.7995684142224491, 0.23249395337188616, 0.08238507143687457, 0.0482295094843721, 0.07484273592126556, 0.0046367939648916945, 0.031291268969653174, 0.07090478902682662, 0.044571066537173465, 0.035139928077114746, 0.054542495927307755, 0.038319834202411585, 0.012444913900253596, 0.03602164033509325, 0.04868422336585354, 0.05400337016908452, 0.060296919764368795, 0.0338853237190051, 0.12248503961018287, 0.030767001007916406, 0.01480855127738323, 0.03087552155193407, 0.05701221867639106, 0.03892246924806386, 0.05962142065982334, 0.028698056557914242, 0.01171685033114045, 0.04878796076809522, 0.027668721850204747, 0.009438041361136129, 0.04580910244840197, 0.025451843248447403, 0.03928560581698548, 0.011647647843346931, 0.026709115627454594, 0.029330542638490442, 0.08393329539103433, 0.033947081537917256, 0.034786932956194505, 0.05361017661925871, 0.0719962730363477, 0.02008387426030822, 0.056738451530691236, 0.04074393342307303, 0.017112875284510665, 0.14843349839793518, 0.17562886176165193, 0.18242503458168358, 0.2517120901029557, 0.08223678290960379, 0.25378805526997894, 0.15848461218411103, 0.2473768196068704, 0.1125697536917869, 0.09882409518468194, 0.16799688222818077, 0.16620747512206435, 0.1250661475933157, 0.1505251377238892, 0.09538749873172492, 0.13975329464301467, 0.060708496312145144, 0.08042194982408546, 0.12111113130231388, 0.22152407560497522, 0.16740153136197478, 0.11287052388070151, 0.06796278205001727, 0.15852189768338576, 0.13691208616364747, 0.1703078261925839, 0.26179538341239095, 0.15843009401578456, 0.14273338863858953, 0.11101735144620761, 0.1496264265733771, 0.16161022649612278, 0.14442886953474954, 0.1622391224373132, 0.141660064982716, 0.20826087245950475, 0.16434239863883704, 0.21222028968622908, 0.10356917962781154, 1.1275272723287344, 12.104370184242725, 30.075674951076508, 59.84149552881718, 75.64554288983345, 86.45313575863838, 84.36023086309433, 88.66746693849564, 78.42401459813118, 64.44189727306366, 55.6738905608654, 49.418586418032646, 49.14617523550987, 40.10367125272751, 34.77585554122925, 30.202223360538483, 30.409213453531265, 39.00354288518429, 48.84826362133026, 37.1449676156044, 46.856585294008255, 54.45158734917641, 51.74621231853962, 30.356768667697906, 25.181545168161392, 13.077278528362513, 9.652868080884218, 4.06060840934515, 1.9029636564664543, 0.5851308989804238, 0.4706107737729326, 0.18108814459992573, 0.31456220196560025, 0.19302943430375308, 0.18991802469827235, 0.23394425836158916, 0.27964171953499317, 0.20010023145005107, 0.3338660567533225, 0.12468790460843593, 0.8981189166661352, 0.22265599924139678, 0.44373796263244003, 0.30013324809260666, 0.19575516460463405, 0.216232473612763, 1.20472582988441, 0.8255947614088655, 1.2051318143494427, 0.6399462232366204, 0.3902270965045318, 0.2780651900684461, 0.1547051954548806, 0.2911121165379882, 0.5543107527773827, 0.2932148287072778, 0.5005181673914194, 0.31292054161895066, 0.243792112742085, 0.23352047719527036, 0.3169059340143576, 0.18180951214162633, 0.17627353576244786, 0.2946718130260706, 0.2033643750473857, 0.34900144615676254, 0.37622012780047953, 0.5297461396548897, 1.492025088518858, 6.148161767050624, 8.659039959311485, 15.195889044553041, 28.6009493842721, 34.29592989385128, 43.42080965638161, 44.94884826242924, 46.54749847948551, 43.25979709625244, 38.67815114557743, 33.786764815449715, 37.383781000971794, 42.41898961365223, 35.440876856446266, 51.86948910355568, 51.47683337330818, 64.20339927077293, 73.31642746925354, 85.62330588698387, 79.10455048084259, 67.07669869065285, 42.59302407503128, 13.019290789961815, 1.1254831007681787, 0.4444759542820975, 0.3823105478659272, 0.17313695250777528, 0.16777630109572783, 0.21019864972913638, 0.1303404723876156, 0.26695176609791815, 0.24273909424664453, 0.1522294947062619, 0.1440024611656554, 0.09698989204480313, 0.07566887245047837, 0.18098060740157962, 0.14831635780865327, 0.16493947128765285, 0.07579016164527275, 0.13715282402699813, 0.18961200752528384, 0.08678121288539842, 0.11025871324818581, 0.10446026150020771, 0.15398880030261353, 0.18978556618094444, 0.16548686457099393, 0.13052451016847044, 0.1115977628796827, 0.12480563891585916, 0.10017824752139859, 0.08796579189947806, 0.10262444047839381, 0.16690919059328735, 0.16647697862936184, 0.09122963863774203, 0.06502182150143199, 0.09199872627505101, 0.2027481549885124, 0.11907932392205112, 0.15059866971569136, 0.16446687164716423, 0.14445527514908463, 0.1619678526185453, 0.11679773189825937, 0.1621881962637417, 0.13757461623754352], [0.06793074353481643, 0.02323409262317, 0.1001703881775029, 0.08365436660824344, 0.13381353055592626, 0.033767518907552585, 0.035088768127025105, 0.03102196213149, 0.047472789738094434, 0.03965114323364105, 0.019643344676296692, 0.014190757865435444, 0.049293407864752226, 0.06260924783418886, 0.04074396681971848, 0.0710196809086483, 0.056331131199840456, 0.01641832153836731, 0.04835465413634665, 0.07911622262327, 0.07678789013880305, 0.040056541402009316, 0.05465847505547572, 0.06170585744257551, 0.04816964785277378, 0.060398961359169334, 0.016936425963649526, 0.09042748832143843, 0.016828888765303418, 0.06469664207543246, 0.036770229853573255, 0.025952236319426447, 0.05482936197950039, 0.010914894828601973, 0.04757575901749078, 0.02542565100156935, 0.04816955879505258, 0.06605722141102888, 0.6045133026782423, 3.5040128510445356, 18.40657141059637, 34.574052169919014, 60.39194159209728, 64.77523058652878, 66.72188892960548, 67.63972967863083, 57.690134570002556, 44.18892323970795, 34.53171104192734, 28.72805256396532, 27.68440816551447, 20.570676885545254, 22.054449766874313, 24.854415021836758, 29.98068004846573, 23.228220082819462, 41.35978125035763, 49.59821417927742, 34.28645700216293, 32.45154686272144, 26.30008164793253, 13.325249422341585, 8.810906410217285, 3.500506589189172, 1.2232002010568976, 0.2263331034919247, 0.03644216347311158, 0.10215981892542914, 0.058081237875740044, 0.05126677482621744, 0.09518250270048156, 0.03660998903797008, 0.08530110324500129, 0.18668237957172096, 0.05131936341058463, 0.07853167742723599, 0.0647536241740454, 0.2615358988987282, 0.10740632060333155, 0.04181873024208471, 0.18762030580546707, 0.0855943925853353, 0.025267708988394588, 0.22876529954373837, 0.3183790377806872, 0.7293483009561896, 1.5566711383871734, 0.6644016515929252, 0.8320886723231524, 1.624274617061019, 0.5882882326841354, 0.558292226633057, 0.22970488818828017, 0.20605661964509636, 0.1222063260502182, 0.47932786226738244, 0.41683923569507897, 0.09397266840096563, 0.02779416521661915, 0.12332345126196742, 0.11073463771026582, 0.05864721453690436, 0.1840030335006304, 0.048020713657024316, 0.05830836103996262, 0.07652032363694161, 0.026463709655217826, 0.062481041823048145, 0.10111408832017332, 0.2266339850029908, 0.6568351294845343, 2.2758287424221635, 10.015915799885988, 21.56745459884405, 28.906935565173626, 63.23075406253338, 52.36141450703144, 48.12553860247135, 40.10552555322647, 19.743189588189125, 14.653170816600323, 22.6988210901618, 18.184733614325523, 26.363420449197292, 35.70505388081074, 41.08236953616142, 44.819807186722755, 50.55701293051243, 57.63420917093754, 55.04500910639763, 38.34368549287319, 18.361232243478298, 3.6352433217689395, 0.37664445815607905, 0.03528932611516211, 0.08735973926377483, 0.02825585714163026, 0.18415526283206418, 0.028630740052904002, 0.004281269048078684, 0.02071320435788948, 0.010766400355350925, 0.024964172444015276, 0.035335955253685825, 0.033224140643142164, 0.02469057413691189, 0.024914828900364228, 0.03063468906475464, 0.09305457235313952, 0.03204668995749671, 0.05814959338749759, 0.009687201672932133, 0.05124256967974361, 0.05834822921315208, 0.02071499478915939, 0.05084299737063702, 0.018416281418467406, 0.03511041657475289, 0.025002244619827252, 0.07053384877508506, 0.0306544617342297, 0.036587524227797985, 0.03858960859361105, 0.039965249816305004, 0.04973559800419025, 0.0497667051240569, 0.024704708339413628, 0.049970027612289414, 0.0404365284339292, 0.03505684464471415, 0.02837113122950541, 0.033256743190577254, 0.042801426534424536, 0.02315917838132009, 0.023003919231996406, 0.03687344775244128, 0.029256634006742388, 0.04384905332699418, 0.015949024455039762, 0.02903884891566122, 0.03607788028602954, 0.06441783203626983, 0.03607156089856289, 0.023255523992702365, 0.03994712657004129, 0.012603051654878072, 0.06978697361773811, 0.04541397931461688, 0.026220776890113484, 0.05115987587487325, 0.01525204203062458, 0.027145455787831452, 0.009027493615576532, 0.05454090773127973, 0.0305410578584997, 0.044909819844178855, 0.07254880198161118, 0.030218574283935595, 0.04809530692000408, 0.008828406935208477, 0.0786578944826033, 0.08427653869148344, 0.022152978272060864, 0.037718019229942, 0.03642505696916487, 0.027634156322164927, 0.08013951810426079, 0.02430935885058716, 0.019495711094350554, 0.0032199642419072916, 0.12796424911357462, 0.07102511342964135, 0.09328839340014383, 0.054989959025988355, 0.6562588666565716, 3.614568868651986, 20.001140646636486, 37.80713528394699, 68.86451795697212, 76.0142371058464, 77.42695569992065, 75.366630256176, 67.29203313589096, 54.09309558570385, 42.933865785598755, 39.45003792643547, 36.30689598619938, 29.213881194591522, 30.58750558644533, 30.606913045048714, 29.649337828159332, 26.642414778470993, 41.37415207922459, 42.93458014726639, 33.94424356520176, 27.87946879863739, 19.438210353255272, 8.677195385098457, 4.181174039840698, 2.3777511483058333, 1.0755505738779902, 0.3877460374496877, 0.1491382863605395, 0.17584113084012643, 0.23442594188963994, 0.3517483128234744, 0.19000754255102947, 0.1483180350624025, 0.3002894256496802, 0.7644622167572379, 0.4725506290560588, 0.5802853277418762, 0.6398628058377653, 1.1450462322682142, 0.38666327367536724, 0.15728993254015222, 0.12164019353804179, 0.1595538985566236, 0.10139705438632518, 0.12429148642695509, 0.6477292743511498, 0.8990651846397668, 1.7943739145994186, 1.9898805487900972, 1.686508865095675, 2.378804166801274, 2.4795966083183885, 2.0824549812823534, 1.7082644789479673, 1.8660802231170237, 1.9099511252716184, 1.5559725696220994, 1.9092589686624706, 0.6385807308834046, 0.5878788640256971, 0.662365376483649, 0.7486876007169485, 0.529874739004299, 0.42550262238364667, 0.29713322001043707, 0.10015712599852122, 0.12851382431108505, 0.12856434972491115, 0.19117804302368313, 0.10798473565955646, 0.15091512148501351, 0.5928756552748382, 2.698087734170258, 7.482999740168452, 18.721259124577045, 25.314591228961945, 51.40648014843464, 51.49582475423813, 48.68179455399513, 38.85115586221218, 27.50680759549141, 21.942262686789036, 30.88766857981682, 30.972576923668385, 34.13324922323227, 46.149131655693054, 49.20148506760597, 55.10330177843571, 61.14045962691307, 66.3382539153099, 65.17439916729927, 52.41527661681175, 27.067541666328907, 6.898151747882366, 1.1757534532807767, 0.04664454179874156, 0.05953097512247041, 0.046037208958296105, 0.06829403966548853, 0.03446130453085061, 0.027064511596108787, 0.03773190110223368, 0.041928167338483036, 0.007537426672570291, 0.014194447267072974, 0.024376749570365064, 0.007822814459359506, 0.042849807141465135, 0.07570568297524005, 0.09011494024889544, 0.021211484163359273, 0.0638624161365442, 0.04768029793922324, 0.05105893265863415, 0.05288549538818188, 0.08012779217096977, 0.04869092124863528, 0.007255073342093965, 0.043801284991786815, 0.02158845807571197, 0.011094594756286824, 0.028980900169699453, 0.021970376546960324, 0.004191191337667988, 0.04697870492236689, 0.03325104720715899, 0.03809645517321769, 0.021321151325537357, 0.03464545363385696, 0.059148553846171126, 0.03310015374154318, 0.03450394833635073, 0.06846261108876206, 0.06464461752329953, 0.0513409042468993, 0.03700553519593086, 0.013186084725020919, 0.15959759621182457, 0.12537133356090635, 0.27679703780449927, 0.20609699247870594, 0.245704137487337, 0.1337261649314314, 0.11417191693908535, 0.13651465123984963, 0.1427211135160178, 0.15069410990690812, 0.15583391301333904, 0.18441903695929796, 0.06995925577939488, 0.0848295351897832, 0.11214417652809061, 0.18132350931409746, 0.17032195668434724, 0.16585685487370938, 0.14914861705619842, 0.16448992275400087, 0.14327546814456582, 0.13764443749096245, 0.21557473781285807, 0.16619588277535513, 0.12416996716638096, 0.20720867032650858, 0.1327584043610841, 0.13705281220609322, 0.13182032969780266, 0.1882441106135957, 0.18638691573869437, 0.15918490273179486, 0.07960545379319228, 0.07885039274697192, 0.26132762257475406, 0.09557259778375737, 0.19210602447856218, 0.36662644415628165, 1.876959870569408, 7.024073665961623, 28.194895572960377, 51.132431253790855, 80.98315447568893, 82.47088104486465, 85.21382465958595, 84.83033403754234, 74.41932588815689, 60.01964136958122, 50.673469081521034, 44.29022200405598, 40.806147158145905, 32.494511157274246, 33.51863980293274, 37.73234009742737, 48.16770873963833, 36.80582441389561, 54.56039071083069, 61.419079676270485, 48.18104602396488, 42.226180359721184, 32.24263407289982, 16.68327648192644, 10.825919285416603, 4.871609341353178, 1.8286633933894336, 0.5893738463055342, 0.35075335996225476, 0.24228435067925602, 0.18986451585078612, 0.31929285905789584, 0.26017966854851693, 0.20748915761942044, 0.30350607179570943, 0.47222818073350936, 0.23857477004639804, 0.40334173652809113, 0.6037504936102778, 1.2785403127782047, 0.3094992705155164, 0.2962999662850052, 0.3692133037839085, 0.5971306550782174, 0.5424881621729583, 1.1466724262572825, 1.8270899215713143, 3.473180830478668, 6.505592437461019, 3.026710725389421, 1.8842081003822386, 3.9362144842743874, 2.274313336238265, 1.3874626555480063, 0.8364776149392128, 1.0438418691046536, 1.9906674628145993, 1.287019201554358, 1.2950132600963116, 0.3297721326816827, 0.37724996160250157, 0.43784611159935594, 0.8095175866037607, 0.5145832314155996, 0.4127579875057563, 0.4129361920058727, 0.18976411811308935, 0.28846882400102913, 0.21345492656109855, 0.32139423536136746, 0.22313529305392876, 0.5016643996350467, 1.3447324046865106, 4.149668030440807, 13.476860336959362, 25.926535092294216, 37.75559104979038, 74.03154909610748, 63.59560668468475, 60.63575930893421, 49.82417665421963, 29.04732473194599, 24.7815615311265, 36.060741394758224, 31.459440998733044, 41.48580148816109, 53.42082045972347, 57.781185284256935, 65.97055524587631, 71.97664976119995, 76.46675482392311, 75.12665793299675, 60.3850107640028, 29.926582351326942, 6.894914321601391, 1.4087884174659848, 0.20846934174187481, 0.2258526667719707, 0.11223130466532893, 0.2650314738275483, 0.14274417946580797, 0.11623769241850823, 0.09302402555476874, 0.17207611177582294, 0.04848746888455935, 0.09943606273736805, 0.08759348609601147, 0.12551965919556096, 0.12225334110553376, 0.12576352892210707, 0.15607606095727533, 0.12498844473157078, 0.10904309019679204, 0.19818182423477992, 0.1556950423400849, 0.17125600890722126, 0.2020330066443421, 0.19127602135995403, 0.08896046274458058, 0.18838115560356528, 0.15297606558306143, 0.11272913732682355, 0.1291550399037078, 0.13590132555691525, 0.15686129772802815, 0.09552138217259198, 0.10579119945759885, 0.19685118313645944, 0.17310737050138414, 0.27669797593262047, 0.13517035462427884, 0.1134362185257487, 0.1530948982690461, 0.16994527220958844, 0.22981088171945885, 0.11330521461786702, 0.1255355411558412, 0.12367168179480359], [0.05064280303486157, 0.07830414237105288, 0.024903564954001922, 0.024092505154840183, 0.062233268399722874, 0.015344340154115343, 0.055497795838164166, 0.07037799776298925, 0.03373857514816336, 0.003963249955631909, 0.0522842110513011, 0.010135217671631835, 0.03903087846993003, 0.06938242149772123, 0.011318054494040553, 0.0861395445826929, 0.032104818674270064, 0.056476376921636984, 0.05716368730645627, 0.036201696493662894, 0.00713880431248981, 0.03984785689681303, 0.05177912760700565, 0.05373627493099775, 0.05204895765928086, 0.034715334259090014, 0.029830625862814486, 0.04129270339035429, 0.04499032431340311, 0.0549274701916147, 0.02434978920064168, 0.018528111941122916, 0.03706525210873224, 0.07922102871816605, 0.03426874318392947, 0.06851119949715212, 0.15051212045364082, 0.5944789317436516, 6.99481476098299, 24.25105679780245, 38.07835713028908, 62.88257874548435, 65.08280128240585, 59.10634897649288, 56.37121394276619, 59.1336315125227, 47.54942111670971, 32.19514422118664, 20.841763839125633, 19.077104330062866, 19.768891409039497, 20.30772529542446, 29.531413055956364, 29.84010849148035, 39.864899665117264, 52.6001100987196, 44.22321259975433, 36.87773555517197, 20.152917802333832, 11.836141627281904, 3.717979369685054, 2.480020048096776, 0.7235548587050289, 0.1331567150191404, 0.008703820749360602, 0.05116222477226984, 0.06939564656931907, 0.08954776130849496, 0.026436372645548545, 0.33993320306763053, 0.03515512355079409, 0.15911292925011367, 0.08876642081304453, 0.6204441259615123, 1.1857996392063797, 0.262684149784036, 0.3419879131251946, 1.0579915973357856, 0.4512704350054264, 0.08361535932635888, 0.17822621535742655, 0.14457721001235768, 0.03588522245991044, 0.10652131692040712, 0.24093101470498368, 0.22401059686671942, 1.2615137826651335, 0.7954570348374546, 1.9555353792384267, 2.338362936861813, 1.7120033595710993, 2.6087611773982644, 2.6824377989396453, 0.9442875080276281, 1.7677667923271656, 2.777502522803843, 2.1368701988831162, 0.5582144495565444, 0.8232412626966834, 0.39564619946759194, 0.6933503982145339, 0.7455369760282338, 0.3669708303641528, 0.21330130199203268, 0.14222440891899168, 0.018518003889766987, 0.06605326576391235, 0.11280604609055445, 0.18991379445651546, 0.039890671396278776, 0.13836066937074065, 0.45816192927304655, 0.9707833081483841, 2.6106411265209317, 8.372086957097054, 15.686218533664942, 30.57098787277937, 33.86327750980854, 41.702272072434425, 29.599241316318512, 29.24296673387289, 17.620064914226532, 19.363515861332417, 24.156572967767715, 21.167554557323456, 32.500256448984146, 40.816763788461685, 43.40923547744751, 47.488301396369934, 58.27083840966225, 63.61945420503616, 53.931216672062874, 39.84078235924244, 16.276249922811985, 2.4374160217121243, 0.1882128810393624, 0.052436559126363136, 0.07637145623448305, 0.03690647332405206, 0.04214482250972651, 0.04748923201987054, 0.041445886381552555, 0.04732923240226228, 0.0640830937481951, 0.06319543317658827, 0.02978082404297311, 0.024397863671765663, 0.05635895431623794, 0.040402122467639856, 0.03333194130391348, 0.0532560460123932, 0.029438797864713706, 0.035535622664610855, 0.026231435986119322, 0.059950949071208015, 0.01620960363652557, 0.03156951868731994, 0.057730873668333516, 0.054159365899977274, 0.0017894914094540582, 0.032797094027046114, 0.05400533314968925, 0.025519506707496475, 0.07312882007681765, 0.06220525974640623, 0.03739843188668601, 0.05451009747048374, 0.015278732444130583, 0.03983091366535518, 0.08569915415137075, 0.03237585842725821, 0.0802556419512257, 0.03327413542137947, 0.05384390489780344, 0.03705110677401535, 0.0335567526781233, 0.033220411351067014, 0.04142897654674016, 0.025631854878156446, 0.017917385630425997, 0.04778951239131857, 0.018639239278854802, 0.04570895333017688, 0.05903713892621454, 0.029501054777938407, 0.06388803507434204, 0.033868343380163424, 0.04693527444032952, 0.028051976187271066, 0.05559598939726129, 0.02518359211535426, 0.02876992613892071, 0.05317941184330266, 0.03432423356571235, 0.07672297448152676, 0.04445655686140526, 0.0367983053001808, 0.040169392377720214, 0.013031177168159047, 0.06439124088501558, 0.06320443542790599, 0.03826828091405332, 0.027231862186454237, 0.05114880303153768, 0.03442812681896612, 0.02219561651145341, 0.03893759050697554, 0.0352557105361484, 0.09315669929492287, 0.03828906475973781, 0.07046211278066039, 0.013397999427979812, 0.21358248690376058, 0.6920097232796252, 6.96753934957087, 24.958801120519638, 43.20454806089401, 70.50280004739761, 76.18286445736885, 68.28308835625648, 65.09931519627571, 67.93362110853195, 55.39421036839485, 40.24205602705479, 30.312204658985138, 27.619465850293636, 31.312652975320816, 28.90872146934271, 33.272109031677246, 34.25026014447212, 51.084907203912735, 46.55558064579964, 37.32614569365978, 34.58602532744408, 17.849747389554977, 10.297557637095451, 3.3415706176310778, 1.6350393206812441, 0.3350236883852631, 0.12994438817258924, 0.10889136552577838, 0.2856098930351436, 0.31653768033720553, 0.19983760023023933, 0.6750132353045046, 0.6844431417994201, 1.005385082680732, 1.6274340287782252, 1.550830970518291, 1.8839796376414597, 3.1542831799015403, 2.2474183794111013, 1.3947935309261084, 0.9380559611599892, 0.6494378764182329, 0.691704552154988, 0.056111036174115725, 0.19867548602633178, 0.09176268620649353, 0.03578469484637026, 0.3043724549934268, 0.7606836757622659, 1.6828995337709785, 1.9632615521550179, 2.568163680844009, 5.30557313002646, 4.882610226050019, 3.306059860624373, 6.073125768452883, 3.7025757087394595, 4.663758119568229, 5.462279571220279, 4.391574924811721, 4.113822653889656, 2.183891963213682, 2.005439051426947, 2.0657572522759438, 1.877280834596604, 1.4722193637862802, 1.3870561961084604, 0.7575980038382113, 0.348030420136638, 0.419405463617295, 0.43074773624539375, 0.4760492913192138, 0.1991325302515179, 0.21691027708584443, 0.25501550815533847, 0.7342511066235602, 1.453212546184659, 6.254543233662844, 16.397757902741432, 26.284299194812775, 30.838719606399536, 38.09559680521488, 30.34330788999796, 36.2455178797245, 28.818267323076725, 22.652267888188362, 32.55592346191406, 36.321753188967705, 42.358223274350166, 51.44414372742176, 53.88248048722744, 56.38799384236336, 65.96519753336906, 71.80093199014664, 66.31589591503143, 50.03951109945774, 23.213094994425774, 5.259618395939469, 0.7771936117205769, 0.06100866536144167, 0.051834736732416786, 0.02105571849824628, 0.05388679732277524, 0.06468466381193139, 0.04027567534649279, 0.06592700417968445, 0.05294748698361218, 0.0498348268592963, 0.018307159734831657, 0.026636535440047737, 0.07336001392104663, 0.04127180451177992, 0.08140172576531768, 0.02421438435703749, 0.032663752353983, 0.044993155606789514, 0.057216105196857825, 0.03618312424805481, 0.03542011480021756, 0.051331341674085706, 0.043479422965901904, 0.06127637287136167, 0.05729604934458621, 0.031740843478473835, 0.03412944577576127, 0.06642667736741714, 0.014132890755718108, 0.0060833399766124785, 0.035338756861165166, 0.04731586632260587, 0.02819380988512421, 0.06333433353574947, 0.014327900262287585, 0.01795249292626977, 0.024133429033099674, 0.011961966865783324, 0.04683916631620377, 0.03490677125228103, 0.04586674134770874, 0.20900043746223673, 0.21279404405504465, 0.09146949334535748, 0.09661585703724995, 0.23478978720959276, 0.07266177170095034, 0.23825721989851445, 0.23437151277903467, 0.10081040149088949, 0.16134566569235176, 0.132154667226132, 0.1266000629402697, 0.22526306012878194, 0.1388459003646858, 0.1261017404613085, 0.2084487842512317, 0.13264080364024267, 0.11233254102990031, 0.22729532764060423, 0.06848267876193859, 0.09340033153421246, 0.11114146822365001, 0.21112533984705806, 0.1988075437839143, 0.15396641712868586, 0.1586143099120818, 0.13372910383623093, 0.11593638046178967, 0.14960327156586573, 0.2441543253371492, 0.1389510923763737, 0.09593042428605258, 0.21263903909130022, 0.16668884694809094, 0.23783372074831277, 0.1746876849210821, 0.28561220853589475, 0.8623167627956718, 11.505381725728512, 34.644576385617256, 54.618098214268684, 83.17575842142105, 84.76832896471024, 77.98633128404617, 74.82149630784988, 75.00103667378426, 62.57231779396534, 47.57467836141586, 35.852827951312065, 30.965535901486874, 31.126761250197887, 31.049370802938938, 42.96721279621124, 45.17387978732586, 56.61590941250324, 66.78011700510979, 56.91148415207863, 46.34340763092041, 25.721199810504913, 14.700785111635923, 5.129215093329549, 3.6070371977984905, 0.9918981220107526, 0.43341344164218754, 0.18641278700670227, 0.2684283728012815, 0.38329169678036124, 0.35872372915036976, 0.31438693637028337, 0.3987816843437031, 0.7301530858967453, 1.2232681224122643, 0.81460100132972, 1.2154445797204971, 2.5776999816298485, 1.3859363249503076, 2.923417305573821, 3.709712913259864, 4.561784416437149, 1.7187165305949748, 0.4371551127405837, 0.5484056321438402, 0.4041591379791498, 0.9622980665881187, 0.825261507416144, 1.9206735561601818, 4.730257401242852, 6.958852540701628, 3.3459408581256866, 7.647334272041917, 3.9758812682703137, 4.985358137637377, 5.9400640334934, 6.2163457833230495, 5.97666984423995, 9.41651601344347, 6.681038998067379, 3.0464568408206105, 1.9388941721990705, 2.106825211085379, 2.6050445018336177, 2.0519354939460754, 1.2659578816965222, 0.8123486721888185, 0.8436558453831822, 0.2173056488391012, 0.3845762356650084, 0.34645187202841043, 0.5159110820386559, 0.43103171163238585, 0.5236956174485385, 0.6770508759655058, 1.5704765100963414, 3.321014433167875, 10.88941102847457, 19.658809415996075, 39.566870257258415, 46.83494545519352, 56.47677227854729, 40.14459505677223, 40.51224432885647, 27.47883729636669, 29.44053903222084, 38.543782755732536, 34.21912081539631, 46.80898144841194, 59.333679378032684, 63.72526332736015, 68.78370389342308, 77.9277916252613, 81.15899384021759, 76.74679979681969, 59.76167321205139, 28.31004459410906, 7.014127699658275, 1.0843539889901876, 0.12668196635786444, 0.28375565190799534, 0.17195754626300186, 0.16949959768680856, 0.10759518976556137, 0.07595741204568185, 0.16383577894885093, 0.13465392374200746, 0.23219943948788568, 0.13065949198789895, 0.06766570033505559, 0.17975723632844165, 0.1224032326717861, 0.11061011275160126, 0.26734890416264534, 0.09983980591641739, 0.11404357734136283, 0.16673373203957453, 0.21532286773435771, 0.1023708337743301, 0.08094546821666881, 0.12582374678459018, 0.1836287387413904, 0.18235366966109723, 0.10775812086649239, 0.27527723810635507, 0.15235837607178837, 0.1662761831539683, 0.11800573309301399, 0.08061461878241971, 0.09877185540972278, 0.16010138089768589, 0.11340752709656954, 0.15288403927115723, 0.19505484437104315, 0.18922328541520983, 0.14467757806414738, 0.19925957109080628, 0.13658745592692867, 0.1449612862779759], [0.0317452332819812, 0.08119347912725061, 0.07095602690242231, 0.0609455828089267, 0.03971351332438644, 0.07830301430658437, 0.04134591537876986, 0.037244937193463556, 0.02693896989512723, 0.0629002958885394, 0.021373543240770232, 0.054018973823986016, 0.03230288675695192, 0.044341828252072446, 0.08036927960347384, 0.07677927380427718, 0.07149544209823944, 0.043255223863525316, 0.01257941517906147, 0.03443801964749582, 0.02688379492610693, 0.00553522495465586, 0.026133346327696927, 0.02457938557199668, 0.04519720911048353, 0.040768082908471115, 0.021389289759099483, 0.028728538418363314, 0.1401870948029682, 0.07861028570914641, 0.04298450323403813, 0.035845294914906844, 0.042584637776599266, 0.08016118881641887, 0.10625475231790915, 0.09209493087837473, 0.5939408449921757, 5.534109966829419, 24.56600859761238, 39.286015927791595, 61.32281944155693, 65.50058126449585, 62.819570526480675, 63.58063168823719, 52.928606271743774, 48.46904776990414, 33.29175777733326, 25.94633013010025, 30.411081053316593, 22.445739470422268, 25.3557563200593, 23.121309019625187, 30.530455447733402, 46.22607372701168, 33.05716596543789, 33.71724754571915, 24.680730141699314, 10.115575902163982, 5.457839509472251, 0.9827039809897542, 0.4956549033522606, 0.06236736706341617, 0.08829122365568765, 0.02182488035032293, 0.15844983514398336, 0.15823355846805498, 0.4656573536340147, 0.7703717309050262, 0.5471813259646297, 1.8825494893826544, 1.2196242366917431, 0.5672115355264395, 0.911446048412472, 2.7398857288062572, 3.9003662578761578, 2.751931082457304, 1.01346226176247, 1.315731885842979, 1.210951202083379, 0.7808072178158909, 0.14906810887623578, 0.06077839178033173, 0.07025078622973524, 0.07581877885968424, 0.21974594914354384, 0.5071409745141864, 0.681539325742051, 1.5676625235937536, 2.5965768937021494, 2.4553149612620473, 6.732802195474505, 4.7826542146503925, 7.3734725173562765, 4.383972957730293, 3.0491734575480223, 3.043935913592577, 4.299717228859663, 4.709411719813943, 2.5379054294899106, 2.522425060160458, 0.9175613452680409, 1.2279760697856545, 1.7940211272798479, 1.217311229556799, 0.6995462032500654, 0.27763836609665304, 0.23868717573350295, 0.5918150371871889, 0.10246993275359273, 0.02958082823170116, 0.023829389683669433, 0.028473200654843822, 0.040622881715535186, 0.4239678313024342, 0.5659463221672922, 3.2785920845344663, 11.620829980820417, 22.372213415801525, 33.97552348673344, 50.26930756866932, 34.250879511237144, 23.91628336161375, 28.240365833044052, 19.51871283352375, 15.837970040738583, 24.112086854875088, 20.93445986509323, 29.412380643188953, 37.91063413023949, 49.23456609249115, 50.580738857388496, 55.04605405032635, 59.21392120420933, 58.969430923461914, 33.138428404927254, 12.565993163734674, 1.6045187646523118, 0.32928400731179863, 0.05061522482719738, 0.03860363518469967, 0.011807925766333938, 0.006309810050879605, 0.03558704236638732, 0.028315622294030618, 0.024490697069268208, 0.07306155923288316, 0.04448767511348706, 0.054266814040602185, 0.07037471747025847, 0.013508934735000366, 0.03135007675155066, 0.10177051051869057, 0.050908744233311154, 0.03818606950517278, 0.06000104403938167, 0.03194726443325635, 0.02716487222642172, 0.057092637798632495, 0.08406914552324452, 0.008693726613273611, 0.028169933138997294, 0.040331878190045245, 0.028881266844109632, 0.03407853073440492, 0.025001305803016294, 0.04575730054057203, 0.04731837478175294, 0.06576924584805965, 0.028116643225075677, 0.04323315981309861, 0.10094574696267955, 0.07122692564735189, 0.041678178604342975, 0.04491092564421706, 0.026783733010233846, 0.04769766419485677, 0.023299833919736557, 0.06500060349935666, 0.043464917689561844, 0.01375598363665631, 0.03926474033505656, 0.02273912094096886, 0.004769133274749038, 0.03124465096334461, 0.03338701237225905, 0.022043342651159037, 0.034889204616774805, 0.05950328188191634, 0.08584974333643913, 0.026938711998809595, 0.0874078378546983, 0.052907555727870204, 0.03437812461925205, 0.06714201866998337, 0.031713176213088445, 0.09051660541445017, 0.011419327038311167, 0.024417914646619465, 0.05372718733269721, 0.0909144633624237, 0.044998491648584604, 0.04105580614123028, 0.03144891968986485, 0.023795894703653175, 0.09475701459450647, 0.07850645924918354, 0.08109173068078235, 0.039467880997108296, 0.041534951524226926, 0.10370938616688363, 0.06236612767679617, 0.059968404384562746, 0.6598364340607077, 6.981265638023615, 27.4962954595685, 45.515914633870125, 69.21919852495193, 74.10670146346092, 72.15579494833946, 72.94257313013077, 61.81577078998089, 57.25473873317242, 41.93177975714207, 35.84221512079239, 37.80072882771492, 26.13071333616972, 26.540785431861877, 23.783945962786674, 32.11710400879383, 42.526588439941406, 36.431259512901306, 33.43421593308449, 19.399461932480335, 10.934875588864088, 4.602359114214778, 1.0249505890533328, 0.24316067865584046, 0.12312940933043137, 0.14150194299872965, 0.40197012887801975, 0.669914324535057, 1.0908933193422854, 1.1851098574697971, 2.4638528656214476, 2.1402277937158942, 5.193165661767125, 4.790192535147071, 4.4844357669353485, 4.431430986151099, 4.25906416028738, 8.707414213567972, 5.594413680955768, 4.2761727422475815, 3.0739692645147443, 2.0419315807521343, 1.451375582255423, 0.1646598448860459, 0.07806368652381934, 0.09717476103105582, 0.035888261554646306, 0.360862331581302, 0.09737323358422145, 1.245493486057967, 3.068092642351985, 4.358370406553149, 6.017184220254421, 6.733503257855773, 4.0174545999616385, 7.149649802595377, 7.763441791757941, 7.053925339132547, 8.806107267737389, 6.69605104252696, 8.934447281062603, 6.336513385176659, 5.579736018553376, 2.395669799298048, 2.756976499222219, 2.207588916644454, 3.798181666061282, 3.2908851373940706, 2.5708373123779893, 1.609074838925153, 2.0171200996264815, 0.46773593116085976, 0.26734792452771217, 0.2988907741382718, 0.12866241711890325, 0.1765966520179063, 0.23544069525087252, 0.5224749923218042, 2.8439025348052382, 10.125393625348806, 21.191090494394302, 33.48688870668411, 39.881588369607925, 27.336983308196068, 24.39837869256735, 33.243732154369354, 27.55991544574499, 23.92914567142725, 34.96162377297878, 36.126865446567535, 40.73405362665653, 49.1714096814394, 59.15620230138302, 60.25356821715832, 62.19496764242649, 67.185388058424, 66.86744391918182, 40.41264407336712, 17.90349170565605, 3.2029364816844463, 0.5411028396338224, 0.028016666656185407, 0.16271077212877572, 0.04952902119839564, 0.020542553065752145, 0.021497235138667747, 0.022800823098805267, 0.00990716032902128, 0.009748636657604948, 0.03441566615947522, 0.02424811496894108, 0.04767816426465288, 0.0239433761453256, 0.023955890610523056, 0.08054835241637193, 0.01622603664145572, 0.07129611607524566, 0.053425296500790864, 0.01597260434209602, 0.06536691274959594, 0.03559939541446511, 0.07288262742804363, 0.051055863877991214, 0.017239016269741114, 0.021837752901774365, 0.04079075180925429, 0.06058601225959137, 0.03319574236229528, 0.0239359620900359, 0.062246293091448024, 0.06882587011205032, 0.04917366604786366, 0.024201014566642698, 0.035779882018687204, 0.11832091578980908, 0.02083292947645532, 0.050255902897333726, 0.031245296631823294, 0.06099475380324293, 0.09167716852971353, 0.2377181831980124, 0.2575459348736331, 0.15756832697661594, 0.20234450086718425, 0.09376407295349054, 0.13153733394574374, 0.13282620697282255, 0.11841627434478141, 0.18392859608866274, 0.15144688513828442, 0.1661513836006634, 0.17819462955230847, 0.08685654829605483, 0.16109119809698313, 0.1423317680018954, 0.1668511249590665, 0.13410418527200818, 0.19478072470519692, 0.15110781270777807, 0.09142853421508335, 0.06586869363673031, 0.10806433099787682, 0.14086960349231958, 0.134425891446881, 0.11486212169984356, 0.1602367783198133, 0.06373328986228444, 0.21838572603883222, 0.13515276572434232, 0.23648047383176163, 0.18555073795141652, 0.2893306058831513, 0.2143086784053594, 0.23026175127597526, 0.2965949848294258, 1.3488905690610409, 11.401621643453836, 35.07374815642834, 55.123330503702164, 81.70127034187317, 83.54306191205978, 82.87229910492897, 83.44405442476273, 69.76776748895645, 64.18249279260635, 47.37211883068085, 39.70364011824131, 43.603640645742416, 33.41085098683834, 35.56333288550377, 34.512191489338875, 45.3533935546875, 59.29033510386944, 45.808430537581444, 43.88916872441769, 30.830316357314587, 13.735408913344145, 7.165453154593706, 1.4646330708637834, 0.7736031606327742, 0.28117155306972563, 0.42382106417790055, 0.3211628634016961, 0.6010959798004478, 0.5780381639488041, 0.9529971156734973, 2.428302923217416, 1.8024686677381396, 4.294926160946488, 6.653265338391066, 4.429124034941196, 6.472299098968506, 8.833189364522696, 12.040874641388655, 10.597766228020191, 7.382362140342593, 7.453958848491311, 3.418079987168312, 3.8183923065662384, 0.40352513606194407, 0.2613368252059445, 0.21306638256646693, 0.3642945270985365, 0.7183676026761532, 2.3440754553303123, 2.560964967124164, 7.0280245039612055, 10.02421360462904, 11.187585778534412, 18.38410321623087, 13.431334979832172, 17.062629126012325, 11.335052065551281, 12.127973567694426, 10.680344346910715, 13.465107567608356, 12.70332159474492, 9.055455587804317, 5.965019669383764, 4.093755455687642, 6.439189100638032, 5.504388911649585, 3.996650716289878, 3.4804887883365154, 2.82934432849288, 1.6609990526922047, 1.2914307648316026, 0.24236782744992524, 0.31859167793300003, 0.41533249779604375, 0.24211189040215686, 0.3544196585426107, 0.6954985891934484, 0.9544317761901766, 4.8354528564959764, 15.020861886441708, 28.188169933855534, 45.42714759707451, 64.24959719181061, 46.45134083926678, 34.86478216946125, 40.4418683052063, 29.937354773283005, 26.216298043727875, 35.5709894746542, 34.211357831954956, 44.285951033234596, 56.258565187454224, 69.30711820721626, 73.14117327332497, 73.0515056848526, 76.51486784219742, 76.52673080563545, 49.580187946558, 23.5282975807786, 5.280141094699502, 0.6459332769736648, 0.10285007563652471, 0.27428658970166, 0.17050945287337527, 0.09729186451295391, 0.1409654741291888, 0.13291394367115572, 0.10678774793632329, 0.11396480578696355, 0.16500363737577572, 0.1907655128161423, 0.1221823324158322, 0.16741255967644975, 0.1282642103615217, 0.26581613172311336, 0.11261898776865564, 0.1718498012633063, 0.1227913833281491, 0.08762451529037207, 0.11544191715074703, 0.09841854858677834, 0.21570024982793257, 0.08907318013370968, 0.12170916132163256, 0.1739880326204002, 0.11025865387637168, 0.13647018175106496, 0.17986167134949937, 0.11169539982802235, 0.14357824955368415, 0.16548978863283992, 0.15243164089042693, 0.12548972095828503, 0.18795330746797845, 0.2413737354800105, 0.19034801021916792, 0.14666332775959745, 0.10597061365842819, 0.17427528830012307], [0.023655812474316917, 0.024863945400284138, 0.022196414320205804, 0.04334112374635879, 0.011016136759280926, 0.05627015263598878, 0.013324352403287776, 0.06343011511489749, 0.05980192210699897, 0.02929718124505598, 0.04342255961091723, 0.08225863915868104, 0.0148254666783032, 0.051771342477877624, 0.02687704694835702, 0.016208117485803086, 0.011304565032332903, 0.07586830237414688, 0.0708413205575198, 0.04051506992254872, 0.04272548256267328, 0.1022616564296186, 0.06706795233185403, 0.05378633279178757, 0.11255891091423109, 0.07836331380531192, 0.05621491087367758, 0.030199053944670595, 0.04040112798975315, 0.05517151061212644, 0.05261745391180739, 0.04704654464148916, 0.07627587503520772, 0.04743414981930982, 0.053229083787300624, 0.20615502842701972, 3.127505541779101, 23.56181178241968, 40.72102792561054, 58.51325020194054, 74.09316658973694, 62.5921793282032, 60.89614413678646, 48.80727902054787, 45.450349152088165, 36.227803230285645, 38.19780372083187, 23.319310694932938, 24.01114907115698, 34.67838317155838, 39.4407170265913, 53.82421061396599, 49.734820649027824, 40.30885264277458, 29.80301298201084, 12.566647678613663, 4.109078133478761, 1.6402716399170458, 0.23229329148307443, 0.23267454758752137, 0.11753855113056488, 0.08704694628249854, 0.20946211268892512, 0.19730926636839285, 0.42695738025940955, 2.1127585927024484, 1.1572759947739542, 0.7972562976647168, 4.234655220061541, 2.035507312975824, 3.6396361235529184, 6.682260157540441, 5.356704136356711, 5.2334710489958525, 6.691035311669111, 4.893793975934386, 1.508705005981028, 0.7015754724852741, 0.40999476390425116, 0.14091879304032773, 0.03115139639703557, 0.389296532375738, 0.027477954645291902, 0.026252507414028514, 0.03962538699852303, 0.3269466874189675, 1.050895240623504, 1.1225175973959267, 2.2286469116806984, 4.447987172752619, 5.148754119873047, 2.315902579575777, 8.622923847287893, 4.842039803043008, 3.7970835249871016, 7.0995428413152695, 3.4282513288781047, 7.1400011703372, 4.883462805300951, 3.5541276494041085, 2.61320480145514, 2.4965427489951253, 1.1884806328453124, 4.446164220571518, 2.1569252852350473, 2.1940960781648755, 1.4306907984428108, 0.9662118565756828, 1.1436477885581553, 0.07600154014653526, 0.11350260363542475, 0.10039951142971404, 0.10485107646672986, 0.09720697766169906, 0.13109121413435787, 0.1527894748141989, 1.0263444017618895, 3.895562603138387, 15.683077052235603, 39.823337495326996, 54.168601334095, 38.02082821726799, 26.784527152776718, 25.918291434645653, 19.82297770678997, 22.668194733560085, 48.93418461084366, 30.775726586580276, 28.102172948420048, 31.54672611504793, 36.22780703008175, 54.70544792711735, 60.923878848552704, 64.91268441081047, 60.91802716255188, 50.05024932324886, 28.694323673844337, 11.764306481927633, 1.3739061704836786, 0.0317308690136997, 0.020206981716910377, 0.004401507176226005, 0.05823822066304274, 0.06797931710025296, 0.05114444291393738, 0.060604859099839814, 0.04104684470803477, 0.05588881118455902, 0.08101586092379875, 0.014688156370539218, 0.020406498842930887, 0.02498380039469339, 0.08665106986882165, 0.05672603911079932, 0.048965018650051206, 0.025423303959541954, 0.05588868873019237, 0.05577423100476153, 0.015853821751079522, 0.043619889256660827, 0.07170068303821608, 0.04034850229800213, 0.04135547795158345, 0.05072444670076948, 0.010379297982581193, 0.046087689843261614, 0.02287591360072838, 0.05631170548440423, 0.023836588516132906, 0.05188529183214996, 0.044185884471517056, 0.003789887041421025, 0.036791529491893016, 0.019892261007044, 0.031882293114904314, 0.036143987090326846, 0.06133372233307455, 0.03357898000103887, 0.05012968213122804, 0.03078906320297392, 0.022437714360421523, 0.06305934555712156, 0.06707707332680002, 0.046688009388162754, 0.019178340917278547, 0.032373490976169705, 0.04135311421123333, 0.07183127134339884, 0.008712849903531605, 0.014802598325331928, 0.0372773059643805, 0.06470431588240899, 0.04104140476556495, 0.058356233275844716, 0.13966229249490425, 0.0068034662763238885, 0.04821813236048911, 0.06913242163136601, 0.03808424313319847, 0.015073190934344893, 0.060839952930109575, 0.05823512590723112, 0.020035783090861514, 0.027253675762040075, 0.051550330899772234, 0.052102373738307506, 0.06245865864912048, 0.039138263528002426, 0.023753592286084313, 0.07731808786047623, 0.012748542285407893, 0.18972899968503043, 4.362713573500514, 27.049610428512096, 44.99189995229244, 66.69665068387985, 83.35842221975327, 72.3241639137268, 67.7994579076767, 57.639642879366875, 52.2520449757576, 44.012111127376556, 46.161720380187035, 26.72332003712654, 33.7093211710453, 40.37085771560669, 36.19208514690399, 42.123141288757324, 42.12950974702835, 39.45444568991661, 26.01722102612257, 10.993476994335651, 4.335240097716451, 1.5343904402107, 0.3246006101835519, 0.19407756946748123, 0.297145361546427, 0.2912189858034253, 0.6716486345976591, 1.289936020039022, 1.944718665909022, 3.6389642721042037, 3.4476523753255606, 3.981082239188254, 5.939893517643213, 7.719725612550974, 7.151624746620655, 4.814429059624672, 7.938299858942628, 7.999319359660149, 10.182977635413408, 7.472650520503521, 3.987917834892869, 3.336174669675529, 1.0786096472293139, 0.7801180297974497, 0.1662318769376725, 0.17278575338423252, 0.18390530749456957, 0.12467187421862036, 0.17539164167828858, 0.5393645516596735, 0.28952929365914315, 2.5691081676632166, 3.348313355818391, 5.594062674790621, 6.070195650681853, 5.890641985461116, 7.751997280865908, 8.053531050682068, 8.984494395554066, 7.838297775015235, 7.1409653685987, 11.866227462887764, 7.215935345739126, 6.409836625680327, 3.7184358201920986, 4.720258237794042, 4.789323806762695, 6.598450429737568, 5.746168037876487, 5.196204073727131, 6.000951016321778, 3.393217446282506, 3.1157872080802917, 1.7479626112617552, 0.6382475956343114, 0.1775523304240778, 0.2711602777708322, 0.051768577977782115, 0.11441903727245517, 0.19034364639082924, 0.6897375045809895, 3.1373496260493994, 14.031037800014019, 34.70633827149868, 43.65760155022144, 35.3685287386179, 29.424361400306225, 29.050355069339275, 21.196873784065247, 33.57072740793228, 50.217064172029495, 34.933455884456635, 44.01244930922985, 43.48229795694351, 45.69439485669136, 65.40755465626717, 71.32674783468246, 74.28664460778236, 69.26364853978157, 58.34690272808075, 35.53284712135792, 15.107513386756182, 1.5078533766791224, 0.01006141757898149, 0.0132710977413808, 0.02160297448426718, 0.15691994223743677, 0.026518940285313874, 0.07752890232950449, 0.024607216109870933, 0.010392202075308887, 0.03938661582651548, 0.01948644538060762, 0.08566211356082931, 0.02206822500738781, 0.008024508861126378, 0.08092051721177995, 0.08578763299738057, 0.08351880591362715, 0.015660700082662515, 0.04603848916303832, 0.07205974150565453, 0.03413261103560217, 0.03215764103515539, 0.03992977515736129, 0.03478478072793223, 0.02421881497866707, 0.045101097275619395, 0.037679739252780564, 0.021150412831048016, 0.06412752612959594, 0.030979245966591407, 0.009566443113726564, 0.02863842499209568, 0.01985475842957385, 0.031183249375317246, 0.04787367935932707, 0.030553997203242034, 0.015250744199875044, 0.06836175321950577, 0.146020227111876, 0.169249672035221, 0.10716017248341814, 0.21791232487885281, 0.09973073989385739, 0.16712205338990316, 0.15208066441118717, 0.22528073808643967, 0.1331764561473392, 0.09650968539062887, 0.16930093959672377, 0.265050710295327, 0.12724663683911785, 0.17844042886281386, 0.18712400196818635, 0.1486571371788159, 0.12745553656714037, 0.15550076292129233, 0.27683871681801975, 0.156866418546997, 0.12379761683405377, 0.1948393989005126, 0.14962632267270237, 0.15250297612510622, 0.14812431967584416, 0.14915491046849638, 0.10802763179526664, 0.09604487087926827, 0.11842689447803423, 0.11177788212080486, 0.14541353622917086, 0.19129374384647235, 0.14799436961766332, 0.16741189174354076, 0.16654901148285717, 0.7764666632283479, 8.014512844383717, 38.290324956178665, 59.80493389070034, 80.52799969911575, 91.12417191267014, 79.99221324920654, 77.20090582966805, 66.35377988219261, 60.39565019309521, 50.15322759747505, 52.27134793996811, 35.54092548787594, 35.04030615091324, 46.39558643102646, 53.23032148182392, 70.17373010516167, 65.09902641177177, 51.469298377633095, 36.50370642542839, 16.389552243053913, 5.834999671205878, 2.780566345900297, 0.475018210709095, 0.38290100055746734, 0.3688486717874184, 0.21847448690095916, 0.39074559055734426, 0.6285548501182348, 1.250619173515588, 4.113256959244609, 4.578904397785664, 4.640636835247278, 10.785989128053188, 10.482268575578928, 11.124314423650503, 13.675692267715931, 12.67979420721531, 12.760975901037455, 16.078635826706886, 15.088156275451183, 7.5014392007142305, 3.396604252047837, 0.9483466402161866, 1.4931314229033887, 0.8079292124602944, 0.7906126510351896, 0.4301673173904419, 0.33398705651052296, 0.45287115848623216, 1.712681504432112, 3.653535065241158, 4.761526873335242, 10.814227312803268, 14.574876017868519, 16.17246799170971, 11.80871469900012, 19.876222349703312, 13.841238934546709, 15.83956215530634, 20.90478155761957, 14.52337833121419, 18.780820928514004, 11.91820677369833, 10.262646060436964, 8.79180483520031, 6.740865837782621, 6.837509851902723, 11.20074162259698, 8.138908669352531, 7.839630078524351, 6.251005148515105, 4.658374283462763, 4.7158324252814054, 1.1631032195873559, 0.3913631761679426, 0.24101869203150272, 0.34355194482486695, 0.21562397188972682, 0.19822234549792483, 0.4160604259232059, 2.081324541941285, 6.095707956701517, 21.1801565811038, 50.111984610557556, 68.85226741433144, 51.15218639373779, 38.11339125037193, 36.55268579721451, 30.981489345431328, 34.82551507651806, 59.66936096549034, 43.16812701523304, 43.99340473115444, 46.67888022959232, 56.99530005455017, 74.75370034575462, 83.55855748057365, 84.48796480894089, 81.48126974701881, 72.06494942307472, 45.54131627082825, 19.745015390217304, 2.40017659496516, 0.14683891989989206, 0.2091809277771972, 0.06653118660324253, 0.34271863172762096, 0.2216898713959381, 0.17626072629354894, 0.135072851262521, 0.15883650892646983, 0.10920927190454677, 0.23737856157822534, 0.15662158402847126, 0.15057961136335507, 0.054470644899993204, 0.15881528350291774, 0.23244329437147826, 0.17668572458205745, 0.11578306759474799, 0.18082377675455064, 0.19514609884936363, 0.15358229633420706, 0.11528325339895673, 0.15182386647211388, 0.12559884635265917, 0.06859076514956541, 0.13854573131538928, 0.13406023528659716, 0.12142492618295364, 0.13238130428362638, 0.1562479423591867, 0.0983545309281908, 0.14771351125091314, 0.1340827817330137, 0.0506298933760263, 0.18711530399741605, 0.1108750891580712, 0.09283500054152682, 0.14765020605409518], [0.01431676248103031, 0.019536195250111632, 0.02825291081535397, 0.05619234958430752, 0.035472688541631214, 0.021624715700454544, 0.09257464771508239, 0.04335031895607244, 0.031082449022505898, 0.07698213987168856, 0.03563095524441451, 0.06346766036585905, 0.025975573153118603, 0.03960955327784177, 0.041547067085048184, 0.018296862435818184, 0.046906542193028145, 0.046261319002951495, 0.01909686794533627, 0.02613196222227998, 0.020058357367815915, 0.08973260060884058, 0.014282379706855863, 0.0882668218400795, 0.018581637486931868, 0.04723124664451461, 0.05835286392539274, 0.021281626395648345, 0.07323370780795813, 0.027096885933133308, 0.06361113235470839, 0.02315790745342383, 0.07292316353414208, 0.018901081966760103, 0.037278330128174275, 2.8744578827172518, 16.462299339473248, 47.663981169462204, 71.41665861010551, 72.17990085482597, 67.69275203347206, 61.533662527799606, 57.65996418893337, 37.43282876908779, 32.67612621188164, 29.592016004025936, 17.73855395615101, 28.26152879744768, 27.422714307904243, 31.999952495098114, 39.06004585325718, 45.68798080086708, 27.606901824474335, 12.793392911553383, 5.459890449419618, 2.4813141161575913, 0.5766940454486758, 0.18419481930322945, 0.13021751336054876, 0.05530537549930159, 0.16298665810609236, 0.3176074119983241, 0.24689820857020095, 3.2120657293125987, 3.4722760040313005, 4.143078709021211, 2.3595935851335526, 4.972994551062584, 2.313987957313657, 9.483786653727293, 4.915062859654427, 3.3729633456096053, 3.7392214173451066, 2.84445493016392, 8.909650761634111, 3.5875117080286145, 1.8938170722685754, 1.4362331572920084, 1.4174958877265453, 1.0098916408605874, 0.01339028480288107, 0.08963255910202861, 0.5989854305516928, 0.2076591836521402, 0.33513913687784225, 0.054157517952262424, 0.6711118540260941, 1.0225436557084322, 2.2757824324071407, 6.193770719692111, 3.720548269338906, 2.5377237517386675, 2.7232582960277796, 7.91980910114944, 6.305941650643945, 6.0595866199582815, 5.928334062919021, 9.005261231213808, 5.479590967297554, 8.622446022927761, 1.5373286325484514, 2.3395365988835692, 2.0509107364341617, 4.885950721800327, 5.873103076592088, 4.08572506159544, 2.8990017157047987, 5.0973794516175985, 2.6918297074735165, 1.3068017712794244, 1.1146507132798433, 0.3427447553258389, 0.15200254594674334, 0.059960014405078255, 0.05200921565119643, 0.08500878611812368, 0.17824429407482967, 1.2566151330247521, 3.505584541708231, 10.366114508360624, 21.983767859637737, 36.19820661842823, 43.60313527286053, 27.17427033931017, 36.670506075024605, 28.972706235945225, 79.48099628090858, 59.45028752088547, 23.580586574971676, 25.093412697315216, 33.18016156554222, 35.39787836372852, 40.712250396609306, 55.181360989809036, 58.12520742416382, 58.18337470293045, 51.712413132190704, 37.59091168642044, 8.315466195344925, 0.7961294800043106, 0.09978632675483823, 0.04959674959536642, 0.06044132685929071, 0.02369522237131605, 0.0021470334604600794, 0.04890199918008875, 0.09914738955558278, 0.06307491581537761, 0.028505964619398583, 0.07487414361094125, 0.024352718828595243, 0.042799244620255195, 0.041730874800123274, 0.02721973549341783, 0.012079007265128894, 0.028248713970242534, 0.01604004701221129, 0.01770709437550977, 0.004128837017560727, 0.09006726468214765, 0.01818627686589025, 0.00737132242647931, 0.055115960858529434, 0.02795946376863867, 0.03679037545225583, 0.05603553006949369, 0.017779960289772134, 0.05583674581430387, 0.025827241952356417, 0.012974579130968777, 0.043419646681286395, 0.014217207080946537, 0.04665680207835976, 0.07743997077341191, 0.07056379443383776, 0.007626452388649341, 0.032290633898810484, 0.02646616801939672, 0.02161797328881221, 0.02516577314963797, 0.00528522926288133, 0.03353336389409378, 0.06366841873386875, 0.058680377405835316, 0.043273836927255616, 0.02894715657021152, 0.03855706541799009, 0.0410412377823377, 0.06541634720633738, 0.032088832813315094, 0.059950444410787895, 0.018180970510002226, 0.05544522209675051, 0.03791963477851823, 0.058936251371051185, 0.08334145488333888, 0.07622226970852353, 0.07197218292276375, 0.02612240150483558, 0.06414305185899138, 0.04600070642482024, 0.04934390730340965, 0.02302835629961919, 0.04339961982623208, 0.01851085700764088, 0.04778514114150312, 0.05345891207980458, 0.010218810402875533, 0.05528630230401177, 0.026748362251964863, 0.08992107643280178, 3.3594054356217384, 17.3088863119483, 55.89229144155979, 78.7630096077919, 82.08336263895035, 76.40794157981873, 70.0498415529728, 64.50760334730148, 47.64832600951195, 40.86485780775547, 35.80883011221886, 28.43301359564066, 38.18626753985882, 27.325319834053516, 32.75368385016918, 37.44207367300987, 48.7010595202446, 31.049006022512913, 13.381784688681364, 5.702476557344198, 1.882269373163581, 0.4376662743743509, 0.05920525763940532, 0.20509001682512462, 0.5977228889241815, 0.9147623204626143, 1.2372345104813576, 1.755877467803657, 4.299525814130902, 5.966870170086622, 6.026338404044509, 6.772298701107502, 8.565124198794365, 6.526634758338332, 8.28864723443985, 6.710199108347297, 10.185062773525715, 10.631224382668734, 10.450420584529638, 10.71505643427372, 8.758818805217743, 6.332130320370197, 4.314200626686215, 3.426193739287555, 0.824243399547413, 0.11398545975680463, 0.5113084602635354, 1.0844043362885714, 0.12220594013342634, 0.10824242417584173, 0.07977679342729971, 0.5349953204859048, 0.36255594226531684, 0.17780605587176979, 2.5494736712425947, 1.9584326050244272, 6.551654515787959, 4.730081660673022, 5.418488346040249, 11.236935630440712, 10.91327279806137, 9.04609004035592, 9.767740666866302, 7.316491724923253, 7.457093205302954, 4.228810183703899, 3.9866434782743454, 5.459654862061143, 5.222341446205974, 8.866755813360214, 7.649512030184269, 7.526135500520468, 8.270835690200329, 3.319745776243508, 2.8017594711855054, 3.478825665079057, 1.6951429517939687, 1.489594525191933, 0.9393193339928985, 0.5599852732848376, 0.12703067186521366, 0.2937092474894598, 0.7704916025977582, 3.0293024238198996, 9.943819418549538, 24.896896742284298, 29.891299344599247, 41.00050292909145, 25.74845004826784, 29.186646156013012, 30.97742546349764, 71.21716171503067, 62.04076051712036, 35.637976080179214, 37.320145815610886, 46.6263784468174, 49.044500291347504, 49.045727625489235, 64.25543367862701, 65.35065650939941, 67.4489951133728, 61.49138979613781, 43.113748133182526, 9.984448738396168, 1.0099180019460618, 0.08110831025987864, 0.09577306671417318, 0.03435768958297558, 0.01900741503050085, 0.057150350912706926, 0.01730819742078893, 0.057144807069562376, 0.06328534436761402, 0.09042513571330346, 0.029365258451434784, 0.03477773774648085, 0.025537668916513212, 0.04122757993172854, 0.04959033743944019, 0.04927905843942426, 0.05329186205926817, 0.04720910837932024, 0.007300908846445964, 0.025526286226522643, 0.07672491890843958, 0.029277184075908735, 0.01981596080440795, 0.044064550747862086, 0.07018879463430494, 0.06219533723196946, 0.03380933150765486, 0.025378378049936146, 0.015019763723103097, 0.03576752154913265, 0.028463613962230738, 0.029310500940482598, 0.05148389012902044, 0.00335195938077959, 0.03703875743667595, 0.055772754130885005, 0.033037249304470606, 0.07119302434148267, 0.19160574272973463, 0.154950772121083, 0.18653395003639162, 0.1978656099527143, 0.08786486723693088, 0.21052984055131674, 0.26796467893291265, 0.20480114326346666, 0.1701412585680373, 0.10569616744760424, 0.12418238329701126, 0.1637836653389968, 0.16272638691589236, 0.15906730201095343, 0.12244169076438993, 0.12137307232478634, 0.12214898772072047, 0.09732133519719355, 0.11015579220838845, 0.20888967934297398, 0.24545186664909124, 0.14764618361368775, 0.13953032379504293, 0.10661286083632149, 0.18474725919077173, 0.22835177485831082, 0.2371522065368481, 0.1876976079074666, 0.1720690613728948, 0.15327397850342095, 0.10858868059585802, 0.16584907716605812, 0.1517770072678104, 0.31219056516420096, 5.884701004251838, 28.570495918393135, 68.89128372073174, 90.24109929800034, 89.65204730629921, 83.69886115193367, 79.50707048177719, 73.9501878619194, 52.22476243972778, 46.09481357038021, 42.72431842982769, 28.149885088205338, 39.59401600062847, 38.65980193018913, 43.762555718421936, 52.02966570854187, 61.09886325895786, 36.471981927752495, 16.982432529330254, 7.1208354737609625, 3.413658211939037, 0.8468758757226169, 0.30620829085819423, 0.4139219125499949, 0.45589745859615505, 0.4434736690018326, 1.2575884745456278, 2.1959038311615586, 6.344046480953693, 8.268532063812017, 11.19842279702425, 12.33167303726077, 16.439624056220055, 13.245698790997267, 23.521628938615322, 15.793983601033688, 13.632999658584595, 16.851894333958626, 14.382915068417788, 22.645870931446552, 14.212224427610636, 9.414052795618773, 4.847744721919298, 3.3547787088900805, 1.4048569346778095, 0.2665355696808547, 0.7791247987188399, 2.425622879527509, 0.44557730143424124, 0.5241398373618722, 0.387618625536561, 1.7885749507695436, 6.102727605029941, 9.276170544326305, 12.597926650196314, 13.364292327314615, 12.21112260594964, 12.837887573987246, 20.21421041339636, 18.05464379489422, 17.676199302077293, 15.66045781597495, 20.059638507664204, 14.856406711041927, 18.94994605332613, 8.738024421036243, 11.378013510257006, 7.32634412124753, 12.621930912137032, 14.905244540423155, 15.542653687298298, 11.21172683313489, 14.8079545609653, 8.114205244928598, 2.8958084620535374, 3.833812354132533, 2.4311712943017483, 1.060786466114223, 0.3586223517777398, 0.5787611939013004, 0.2612767112441361, 0.5309285887051374, 2.0484031084924936, 4.013379793614149, 13.817635551095009, 29.877464286983013, 46.822155341506004, 57.81732514500618, 42.31071822345257, 51.61785140633583, 40.466707572340965, 83.77402871847153, 68.05961474776268, 35.23880369961262, 39.19225215911865, 48.426683843135834, 52.165732607245445, 55.619295090436935, 74.73364502191544, 73.81318241357803, 78.09483826160431, 70.63765481114388, 53.19354705512524, 14.718551058322191, 1.549618598073721, 0.18371568876318634, 0.1932814231258817, 0.18058177724014968, 0.10269409845932387, 0.06279633584199473, 0.15596818237099797, 0.1782368280692026, 0.19502532173646614, 0.15970679582096636, 0.1741639809915796, 0.14067630370846018, 0.1856857494567521, 0.11580662336200476, 0.1675650116521865, 0.1379699879908003, 0.09177982981782407, 0.16917502682190388, 0.15558575367322192, 0.09385384313645773, 0.19970392459072173, 0.17798292450606823, 0.1472834515152499, 0.11621602170635015, 0.2231058743200265, 0.1480189643916674, 0.14711229741806164, 0.1511533508892171, 0.1425760830170475, 0.14954640821088105, 0.15726795012596995, 0.14643758127931505, 0.16448235284769908, 0.10910204640822485, 0.13624654297018424, 0.15157803747570142, 0.17400658631231636], [0.06305085538770072, 0.06917980033904314, 0.005666519691658323, 0.02482381747540785, 0.032658008130965754, 0.008645873858768027, 0.03713620513735805, 0.022222595434868708, 0.027747649255616125, 0.0444037864508573, 0.0029007781222389895, 0.02631216495501576, 0.013277649977680994, 0.07765121568809263, 0.02346783203392988, 0.021331765892682597, 0.014371952293004142, 0.038493348329211585, 0.06007377822243143, 0.03238538760342635, 0.018211934766441118, 0.013361787259782432, 0.03344949749589432, 0.06431354544474743, 0.048471846675965935, 0.03295995091320947, 0.05938975555181969, 0.051977563052787445, 0.03194750563125126, 0.08455623930785805, 0.06340445164823905, 0.005906689812036348, 0.03875550457451027, 0.010786108086904278, 2.9158094013109803, 14.910221323370934, 51.260450184345245, 69.43064957857132, 68.6270534992218, 66.14074051380157, 52.43801839649677, 47.473201006650925, 50.68028211593628, 42.565673142671585, 21.974610351026058, 26.492712311446667, 33.98447200655937, 26.911894418299198, 44.59512144327164, 49.73619997501373, 38.2515974342823, 17.342987582087517, 8.979207929223776, 4.580870792269707, 1.2575171096250415, 0.07767039278405719, 0.06541844748426229, 0.03309283245471306, 0.1671773730777204, 0.25860575144179165, 0.712765040807426, 0.7969054102431983, 2.7663783822208643, 2.707557063549757, 5.373217575252056, 3.696192051284015, 3.600169066339731, 3.58579705003649, 5.237216223031282, 4.313230728730559, 6.811833204701543, 3.328602625988424, 7.139866752550006, 9.370705671608448, 8.147794492542744, 4.67332505621016, 1.8023572862148285, 3.762362888082862, 2.3145078169181943, 0.7744240947067738, 0.38681945123244077, 0.2514391578733921, 1.1564506078138947, 0.26173120248131454, 0.07196512509835884, 0.7220821408554912, 6.460324516519904, 5.102098798379302, 5.391033394262195, 3.1192894326522946, 2.61329575907439, 3.3645814703777432, 3.828022414818406, 2.7596952533349395, 9.107912722975016, 6.3701786287128925, 4.802750386297703, 10.122788865119219, 4.10427519120276, 3.886791723780334, 1.0020939842797816, 3.148169070482254, 5.111389299854636, 6.46072207018733, 5.658567063510418, 3.6366737075150013, 8.950196485966444, 2.5616866908967495, 1.40311935916543, 4.988205609843135, 3.571333126164973, 2.2107579465955496, 0.7775404024869204, 0.5565523949917406, 0.20364723721286282, 0.004810213931705221, 0.09896614967146888, 0.0623315510165412, 0.123787694319617, 1.459946259856224, 7.7504355646669865, 20.942616127431393, 26.127221323549747, 30.63640896230936, 47.88168668746948, 62.38413669168949, 44.57172989845276, 26.17136925458908, 18.203601501882076, 18.361450731754303, 11.309051010757685, 27.12474189698696, 35.56035004556179, 38.67864891886711, 46.68378956615925, 52.49804377555847, 55.582695454359055, 51.451857313513756, 18.132057040929794, 3.6957783484831452, 0.1569326626486145, 0.05482345448399428, 0.062141772723407485, 0.039519222773378715, 0.030479069973807782, 0.02683860369870672, 0.010819801591424039, 0.07420770241878927, 0.05022256933443714, 0.04423008307639975, 0.10077943908981979, 0.012476208412408596, 0.0476141540275421, 0.013673924368049484, 0.028268993155506905, 0.05588620624621399, 0.04538605971902143, 0.06674054646282457, 0.052786225714953616, 0.0984585948754102, 0.04352252319222316, 0.03656649176264182, 0.08265315002063289, 0.06262005350436084, 0.025461246259510517, 0.024591016881458927, 0.0562519774393877, 0.06476920927525498, 0.02772009145701304, 0.043894858681596816, 0.042890547338174656, 0.005996369081913144, 0.051461417897371575, 0.05062160358647816, 0.004403086559250369, 0.03449133182584774, 0.03521505568642169, 0.06123222621681634, 0.0361786565190414, 0.035937536449637264, 0.018298942304681987, 0.040147027757484466, 0.01868349911092082, 0.1007294851297047, 0.10135301534319296, 0.04120323377719615, 0.04122606595046818, 0.052066925054532476, 0.0339912912750151, 0.04285764051019214, 0.09266169421607628, 0.09348742998554371, 0.0952010638138745, 0.0426688641164219, 0.027872103710251395, 0.044600615146919154, 0.06988947163335979, 0.028113349944760557, 0.0027057168972532963, 0.0670044170692563, 0.020301306831242982, 0.021226575736363884, 0.03142338609904982, 0.06272740516578779, 0.05224972344876733, 0.055269726435653865, 0.03724896705534775, 0.033586661229492165, 0.08186466264305636, 0.029402432628558017, 3.672135779634118, 18.182263746857643, 62.454634308815, 78.28891664743423, 80.43908447027206, 76.22117400169373, 61.933093294501305, 55.19528344273567, 60.88121093809605, 45.20186148583889, 30.745077431201935, 35.528918132185936, 27.94270310550928, 24.068584889173508, 42.987127527594566, 41.91519744694233, 35.67403234541416, 19.789245016872883, 8.328636288642883, 3.493632283061743, 0.6052935076877475, 0.049019310463336296, 0.1970431173685938, 0.28914233786053956, 0.2581704076146707, 1.8971182638779283, 3.7681134045124054, 3.6586289294064045, 5.655507277697325, 7.389943208545446, 7.166306208819151, 7.865301026031375, 6.757243908941746, 8.9186230301857, 7.586049260571599, 6.764646386727691, 8.645945861935616, 5.967732723802328, 11.675561293959618, 11.968221589922905, 9.686109647154808, 12.045181710273027, 9.438505433499813, 7.791598280891776, 8.00400735810399, 2.026801505126059, 1.395929551217705, 0.6207635463215411, 1.6326548298820853, 0.42128645174670964, 0.06649231290793978, 0.7776621147058904, 6.350831966847181, 5.3413529600948095, 5.52849386818707, 3.184928772971034, 2.7290418231859803, 4.026608308777213, 4.662630055099726, 6.479138256981969, 8.102278634905815, 5.164933176711202, 8.155126199126244, 8.710862528532743, 8.786990493535995, 5.604102211073041, 6.57577752135694, 6.410939991474152, 9.15406409651041, 8.087637070566416, 9.185215774923563, 6.592318033799529, 7.4745679926127195, 9.316233694553375, 6.796259740367532, 6.38824000954628, 5.7248996291309595, 7.489484092220664, 4.020969411358237, 3.061325680464506, 0.8020177390426397, 0.30074599490035325, 0.3287774766795337, 0.13820453634252772, 0.358673352166079, 1.799064762890339, 6.608419669792056, 19.693824537098408, 27.596862763166428, 30.997642278671265, 42.33435295522213, 49.24479514360428, 47.16314144432545, 39.68997225165367, 27.952308990061283, 31.456004083156586, 23.8100790604949, 38.08654189109802, 46.251425966620445, 49.820418655872345, 55.285008028149605, 61.50079809129238, 63.415975123643875, 60.514439418911934, 25.118947327136993, 4.600237878039479, 0.12219963187817484, 0.07173173449700698, 0.026581599813653156, 0.06403880979632959, 0.02656829125044169, 0.04391982081870083, 0.04890885291388258, 0.04083028601598926, 0.022740271269867662, 0.06410158806829713, 0.07186079397797585, 0.032411325664725155, 0.024348184306290932, 0.15018247329862788, 0.046298007073346525, 0.06361848703818396, 0.021252363512758166, 0.07457373707438819, 0.05156280269147828, 0.10802472999785095, 0.008644249483040767, 0.06088979927881155, 0.06007788600982167, 0.029139827383914962, 0.03756248363060877, 0.10185778708546422, 0.026386812023702078, 0.03456871185335331, 0.014932938938727602, 0.03177068894729018, 0.024045699756243266, 0.04093224968528375, 0.03579404219635762, 0.06353529228363186, 0.04946259155985899, 0.06969765614485368, 0.2854826592374593, 0.14057875581784174, 0.12956757011124864, 0.16711052041500807, 0.0813264051976148, 0.14660864631878212, 0.11218254556297325, 0.2556518552592024, 0.22140056738862768, 0.11385699399397708, 0.17474092659540474, 0.17820647422922775, 0.15272535325493664, 0.15983383666025475, 0.16724241490010172, 0.22852024238090962, 0.15673133282689378, 0.30153118714224547, 0.10805195197463036, 0.1282191471545957, 0.13108787446981296, 0.11190265940967947, 0.16645550087559968, 0.26417283865157515, 0.11857566540129483, 0.18051948136417195, 0.1832520542666316, 0.22091462393291295, 0.1328190675121732, 0.22334322798997164, 0.15341016260208562, 0.16736375604523346, 0.19459115050267428, 0.13794987578876317, 5.693395519629121, 27.231328077614307, 74.5265257358551, 89.55321460962296, 87.58656173944473, 84.9944320321083, 68.60762134194374, 62.950135320425034, 66.5802401304245, 55.52091836929321, 32.69176997244358, 38.08052681386471, 46.51820205152035, 35.285708382725716, 58.06291736662388, 62.31945276260376, 51.35478392243385, 24.30077712982893, 12.117591574788094, 5.992240458726883, 1.8551853764802217, 0.2718697115778923, 0.2871614566538483, 0.36733338434714824, 0.21916167112067342, 1.641582807060331, 4.312038542702794, 4.151140451431274, 7.639547064900398, 9.407547544687986, 14.798505418002605, 12.086184360086918, 14.365215618163347, 14.39157860353589, 16.04164481163025, 16.052455231547356, 20.999979749321938, 12.36566886305809, 18.1799553707242, 20.920735001564026, 18.375850059092045, 18.295455873012543, 12.25462457165122, 16.57290570437908, 12.813266795128584, 2.8394080884754658, 1.7930408986285329, 0.841632632073015, 3.099085441790521, 0.46436548233032227, 0.5348902917467058, 0.7074146310333163, 4.0928952768445015, 2.461609560996294, 3.0855600675567985, 8.241492714732885, 9.883783590048552, 14.257986322045326, 14.472187478095293, 14.299230258911848, 20.20656332373619, 14.018958248198032, 14.64447308331728, 24.042995162308216, 13.859796188771725, 12.696989234536886, 8.916500844061375, 12.77310200035572, 14.45643162354827, 17.680238485336304, 17.873762100934982, 15.036575943231583, 17.89000052958727, 12.834708094596863, 9.680575244128704, 13.812124896794558, 6.755278464406729, 6.570868184790015, 3.3769137086346745, 2.5205512857064605, 0.6020078714936972, 0.21613437653286383, 0.4335522826295346, 0.23393211682559922, 0.6471621547825634, 2.57372017018497, 10.400174930691719, 28.155164904892445, 35.66140182316303, 44.136957228183746, 63.24463091790676, 79.92882505059242, 58.08140717446804, 38.26352879405022, 27.150033339858055, 30.308017283678055, 21.957011595368385, 42.070806697010994, 53.27693358063698, 55.75929097831249, 66.86851546168327, 72.06400707364082, 74.58917677402496, 73.10620754957199, 34.75064009428024, 6.028496213257313, 0.4389428871218115, 0.26726008392870426, 0.16523034864803776, 0.17105081991758198, 0.15311152237700298, 0.15356481133494526, 0.13020160171436146, 0.15545158821623772, 0.20971190475393087, 0.14433494332479313, 0.1622808608226478, 0.17994646914303303, 0.09736452077049762, 0.27192584762815386, 0.14810367312747985, 0.164944265561644, 0.08020420369575731, 0.41347282414790243, 0.13066603773040697, 0.165831666381564, 0.27131746464874595, 0.14128851616987959, 0.22465417248895392, 0.1815343979978934, 0.1082884670177009, 0.1706182665657252, 0.14749515656149015, 0.11194472433999181, 0.11645134931313805, 0.1463814897579141, 0.11159855697769672, 0.09176139486953616, 0.09427294877241366, 0.16726433794246987, 0.10590295947622508, 0.1952030067332089], [0.04543250332062598, 0.06816679844632745, 0.05455729064124171, 0.052413823432289064, 0.036770689985132776, 0.045615717317559756, 0.030878189572831616, 0.06089759182941634, 0.030554776458302513, 0.06047079383279197, 0.04251572936482262, 0.046673218384967186, 0.050086737755918875, 0.062017893433221616, 0.08130092726787552, 0.06753167588612996, 0.08179913842468522, 0.014270998872234486, 0.08827924539218657, 0.0631409818015527, 0.030856637604301795, 0.04793365973455366, 0.037510436814045534, 0.06020229593559634, 0.04519919806625694, 0.06521333270939067, 0.07029369720839895, 0.015969704400049523, 0.14969863754231483, 0.03435813858231995, 0.07795454628649168, 0.08895207647583447, 0.1000491286686156, 0.5162290774751455, 11.007839273661375, 36.54124081134796, 62.12559096515179, 68.13520789146423, 65.69585278630257, 62.73671217262745, 48.8541305065155, 41.32825814187527, 31.53592709451914, 36.05374217033386, 26.106491535902023, 21.388759687542915, 41.853735744953156, 50.03356821835041, 43.73751886188984, 37.94483609497547, 19.447516053915024, 8.102593068033457, 2.3244003485888243, 0.4636203363770619, 0.16102816007332876, 0.07567579668830149, 0.025488214050710667, 0.13801711436826736, 0.7979683438315988, 1.7890921980142593, 3.5606991592794657, 2.311204606667161, 3.7484311731532216, 9.178699124604464, 5.631190482527018, 5.792192118242383, 5.462763570249081, 5.1159751787781715, 3.5159883834421635, 3.534235479310155, 2.6102898828685284, 6.054305853322148, 8.096856325864792, 8.072149101644754, 6.5625509060919285, 9.902443438768387, 6.8284962605685, 3.6240695463493466, 5.762370368465781, 1.023309314623475, 1.052844892255962, 0.8120305580087006, 1.0421513160690665, 0.3542865172494203, 1.4919429179280996, 14.079238213598728, 39.47231613099575, 38.63341994583607, 45.583015233278275, 23.723130226135254, 7.373065464198589, 2.929322188720107, 1.7259475425817072, 2.4649519566446543, 8.507951516658068, 7.470015836879611, 6.492320699617267, 5.153160933405161, 6.004956001415849, 0.6505679001566023, 4.11932285875082, 1.0793400392867625, 6.305039199069142, 1.25689631793648, 5.783795518800616, 3.616975089535117, 4.327417267486453, 7.2203972563147545, 2.566331229172647, 2.7931572077795863, 6.000537313520908, 4.554514456540346, 5.362403830513358, 6.396209131926298, 0.6308511737734079, 0.03187280104612, 0.19482316070934758, 0.146342690277379, 0.019809307450486813, 0.029217678675195202, 1.2996085197664797, 4.314886489883065, 16.14039771258831, 33.539481684565544, 33.977408185601234, 47.31654301285744, 41.197423562407494, 28.853457234799862, 29.095680937170982, 23.331637233495712, 23.715747222304344, 23.13248421996832, 19.435402303934097, 27.31689378619194, 36.45395949482918, 50.43812870979309, 51.60237483680248, 59.70072068274021, 39.66072142124176, 11.93109568208456, 1.323131751269102, 0.05924826880800538, 0.018861020835174713, 0.049683799807098694, 0.06708163011353463, 0.040593811791040935, 0.033208763343282044, 0.09366020938614383, 0.04683102866692934, 0.05408078359323554, 0.042071509451488964, 0.024026719329413027, 0.08818549729767255, 0.09293082664953545, 0.05665227334247902, 0.0957673744414933, 0.0178249622695148, 0.027677247271640226, 0.2229054202325642, 0.0904437190911267, 0.016277855247608386, 0.022461516891780775, 0.043835872784256935, 0.07464327631168999, 0.08450529829133302, 0.07063311844831333, 0.01470435003284365, 0.014139585855446057, 0.05265162981231697, 0.04875260856351815, 0.0259902695324854, 0.07919777723145671, 0.049379623160348274, 0.1444871726562269, 0.09148179073235951, 0.03703069771290757, 0.10308001525118016, 0.0393220749538159, 0.07902340963482857, 0.03988784381363075, 0.029920999040768947, 0.02907930153014604, 0.007574513647341519, 0.0646658058394678, 0.023685925116296858, 0.041361596959177405, 0.06542520102811977, 0.029107000336807687, 0.049222729430766776, 0.033201419792021625, 0.02533392711484339, 0.0778184512455482, 0.015809517390152905, 0.03782392741413787, 0.009794273173611145, 0.06673807511106133, 0.05842832921189256, 0.10113736949278973, 0.026882421952905133, 0.057351784635102376, 0.03214291311451234, 0.06154326030809898, 0.0267770815116819, 0.02235559943073895, 0.11659977142699063, 0.09208018440403976, 0.06629184397752397, 0.026038108371722046, 0.04997822834411636, 0.7474212592933327, 14.199036285281181, 43.89770686626434, 72.34476640820503, 79.41335991024971, 76.41365647315979, 68.8416051864624, 57.24025771021843, 46.093255653977394, 40.063184425234795, 47.047855630517006, 28.016016371548176, 29.388405829668045, 54.13245387375355, 54.836886674165726, 43.200588673353195, 39.72324326634407, 20.69105252623558, 7.6449779234826565, 1.8287232401780784, 0.3056570532498881, 0.025890803190122824, 0.16866721969563514, 0.42408574372529984, 1.1542185838334262, 2.131619118154049, 5.032315542921424, 5.148629201576114, 5.2091029565781355, 7.225998630747199, 8.902359902858734, 8.577600829303265, 7.431702967733145, 9.076856039464474, 10.01234969124198, 7.8580704890191555, 6.965107005089521, 5.81178386695683, 6.4282395131886005, 9.358115997165442, 8.211357481777668, 6.583654498681426, 6.6326158214360476, 9.582824539393187, 4.621473038569093, 6.844974551349878, 4.046357274055481, 2.1415942953899503, 1.4567451691254973, 1.5733744483441114, 0.2826746692880988, 1.6678459290415049, 14.33793118223548, 39.53516475856304, 41.236500665545464, 44.06404294073582, 23.617915771901608, 6.047581639140844, 2.6258894708007574, 3.258395455777645, 3.7076522363349795, 8.737458251416683, 5.260890377685428, 6.1480962205678225, 8.366911634802818, 6.127820033580065, 4.383907886222005, 3.5150400968268514, 5.48501992598176, 4.213069528341293, 6.987751414999366, 9.369535334408283, 11.188690569251776, 11.365408636629581, 9.67251492664218, 5.2836179081350565, 8.506591189652681, 6.890270495787263, 9.43864032626152, 5.1376026682555676, 6.65551339276135, 3.672422426752746, 1.4353163377381861, 0.48783459642436355, 0.4903683776501566, 0.32843258581124246, 0.11432897023041733, 0.744628943502903, 3.1880652671679854, 11.620847079902887, 33.292627930641174, 42.305820286273956, 49.94485057890415, 43.39117504656315, 27.504168637096882, 23.211803063750267, 22.046012319624424, 20.33578298985958, 29.51392449438572, 30.221254639327526, 36.92620575428009, 45.718287974596024, 59.119378477334976, 61.34915582835674, 66.53134435415268, 47.368702813982964, 15.07219048216939, 1.4215058600530028, 0.10229428124148399, 0.029820298877893947, 0.050072150843334384, 0.0403807783004595, 0.05731755678425543, 0.08102473701001145, 0.05587829124124255, 0.017297098602284677, 0.025871522193483543, 0.028182744463265408, 0.07733893478871323, 0.03320889321912546, 0.030942173834773712, 0.025856228385237046, 0.04233862695400603, 0.06847233322332613, 0.08340289728948846, 0.13994712877320126, 0.07243457061122172, 0.08244994256529026, 0.010446338037581882, 0.03777840407565236, 0.05655512250086758, 0.0980867566249799, 0.03654674692370463, 0.04651258423109539, 0.014231122349883663, 0.029988597561896313, 0.035990637115901336, 0.032839095874805935, 0.07173555655754171, 0.017774347797967494, 0.03287687119154725, 0.06377144367434084, 0.027397468729759566, 0.3061096149031073, 0.12094911304302514, 0.15949657507007942, 0.17183767457026988, 0.1701980031793937, 0.12698262522462755, 0.20217589975800365, 0.2513136458583176, 0.15387882885988802, 0.16506182175362483, 0.195797051419504, 0.14468684006715193, 0.1509785751113668, 0.1539783360203728, 0.12391956654028036, 0.2696004614699632, 0.19338615500601009, 0.1768469190574251, 0.09163661758066155, 0.26921362441498786, 0.21524770301766694, 0.16473627125378698, 0.15678874537115917, 0.1571528727072291, 0.15711079293396324, 0.227581856015604, 0.19484033400658518, 0.16358885157387704, 0.2179462558706291, 0.16383704059990123, 0.21413010283140466, 0.12706590903690085, 0.13379761890973896, 1.9347178400494158, 19.88037932664156, 55.38642838597298, 83.05209785699844, 87.44111314415932, 84.5666053891182, 78.41846689581871, 67.59792432188988, 55.555967688560486, 44.88500028848648, 49.205699041485786, 36.28968670964241, 30.19406709820032, 55.88555060327053, 67.07739785313606, 58.45710441470146, 51.08689069747925, 25.78821301460266, 11.237567346543074, 3.5172052681446075, 0.5982657254207879, 0.23455464513972402, 0.22201261657755822, 0.4519502422772348, 0.6270185450557619, 1.6833084868267179, 5.78548357822001, 9.643692523241043, 10.744526702910662, 11.664699576795101, 18.118373975157738, 16.910327598452568, 16.05916567146778, 16.117661632597446, 21.727798394858837, 15.50196262076497, 16.156594343483448, 12.877291459590197, 15.267010778188705, 20.26058502495289, 18.95964503288269, 20.422131456434727, 19.916492588818073, 15.42547082528472, 15.085824150592089, 17.87068996578455, 4.82524897903204, 3.1762528885155916, 1.8365248152986169, 2.2042279969900846, 0.6652840354945511, 2.475209506228566, 12.405430879443884, 31.775582134723663, 29.374582171440125, 35.30105195939541, 19.34142954647541, 15.151830408722162, 13.066494707018137, 12.579068262130022, 11.200313195586205, 21.07404537498951, 18.397280909121037, 17.33742468059063, 15.104457400739193, 14.08496355637908, 9.244466945528984, 10.441852044314146, 7.47004528529942, 15.479502025991678, 9.730973839759827, 16.0803210362792, 14.66851344332099, 14.171477314084768, 19.576188549399376, 12.32179831713438, 11.389873623847961, 13.574484698474407, 10.83169687539339, 10.812775790691376, 14.971172902733088, 3.9359800843521953, 1.31244957447052, 0.6385065161157399, 0.3691413451451808, 0.29587044089566916, 0.4157181771006435, 2.2755867429077625, 6.85479654930532, 20.43149795383215, 40.30100606381893, 43.046278953552246, 58.40343229472637, 55.42993225157261, 44.70526613295078, 41.123498529195786, 34.60483431816101, 35.75133919715881, 36.3994400203228, 30.652189515531063, 42.379874512553215, 52.50027425587177, 70.24863928556442, 72.27978989481926, 78.36631089448929, 60.88426977396011, 22.085672691464424, 2.3936050850898027, 0.1968832587590441, 0.1637983598629944, 0.11711436178302392, 0.14561133342795074, 0.1478981872787699, 0.1958423075848259, 0.18584165984066203, 0.12414370256010443, 0.10643550980603322, 0.14840758260106668, 0.11425222473917529, 0.17440341267501935, 0.182577783416491, 0.1770501784631051, 0.14798573101870716, 0.12011468672426417, 0.20140699023613706, 0.26068774284794927, 0.19069328700425103, 0.11735869164112955, 0.1412361502298154, 0.1356090826448053, 0.16648549848468974, 0.16138078412041068, 0.1475672933156602, 0.09955381188774481, 0.16448085370939225, 0.10327201627660543, 0.19050681497901678, 0.11331556757795624, 0.20306454738602042, 0.1561582463909872, 0.14664196874946356, 0.1796646459843032, 0.11851005954667926], [0.07644562647328712, 0.047793297344469465, 0.05435404607851524, 0.019235248801123817, 0.09000299469335005, 0.05348505794245284, 0.025546339056745637, 0.022909360341145657, 0.03994783532107249, 0.04494701999647077, 0.03472877826425247, 0.045074702793499455, 0.010284830004820833, 0.0993918530002702, 0.1363582065096125, 0.07668877631658688, 0.09906179766403511, 0.021469050225277897, 0.04300421838706825, 0.12808771280106157, 0.06297813975834288, 0.03751733136596158, 0.0939599925186485, 0.08417820412432775, 0.08983018560684286, 0.0893603170698043, 0.13030473055550829, 0.052129892574157566, 0.22736330836778507, 0.09027559295645915, 0.11663500117720105, 0.08223671611631289, 0.17428358551114798, 7.763694003224373, 33.33531104028225, 63.25003042817116, 70.09950488805771, 67.02359274029732, 57.46564641594887, 48.14916953444481, 36.58600240945816, 37.316311821341515, 36.516477540135384, 21.25430580228567, 33.86137381196022, 30.80020297318697, 27.687413804233074, 28.703027106821537, 32.64303758740425, 18.999860174953938, 5.804808866232634, 1.0160365048795938, 0.028145718715677503, 0.11718794572516344, 0.036424478093977086, 0.12982754444237798, 0.39562871446833014, 0.8427799923811108, 1.6930376272648573, 5.234985267743468, 4.497976340353489, 4.00466401129961, 7.037992794066668, 8.218505848199129, 5.682656820863485, 5.293992776423693, 3.9910797402262688, 7.67749990336597, 5.83743866533041, 2.781758769415319, 3.6666464991867542, 4.197743525728583, 7.011188082396984, 8.218136318027973, 3.175357561558485, 5.169979305937886, 8.257291316986084, 4.123819917440414, 8.144999742507935, 8.537847362458706, 5.729381488636136, 1.7355012986809015, 0.7928591617383063, 0.9868493804242462, 5.941074304282665, 37.1673484146595, 77.67320528626442, 76.05394497513771, 62.35572561621666, 69.81414780020714, 25.460946075618267, 5.038132555782795, 2.4128672014921904, 5.797524657100439, 5.618545236065984, 4.114092914387584, 4.6102256420999765, 6.2201527040451765, 6.635621935129166, 3.4031926235184073, 3.7372775841504335, 3.5561945009976625, 4.292416395619512, 4.342864863574505, 4.580022012814879, 4.532013013958931, 7.038817349821329, 8.346210345625877, 6.699958182871342, 6.958703873679042, 5.105063589289784, 14.174392707645893, 7.256410773843527, 2.5502694910392165, 1.5576555230654776, 1.5347156790085137, 0.7231417496223003, 0.431262519559823, 0.0811416252690833, 0.14744417101610452, 0.26546144450549036, 0.9969273302704096, 2.8878837497904897, 8.557945434004068, 16.813693083822727, 35.40095239877701, 45.20040616393089, 49.45433109998703, 73.57970014214516, 98.1172102689743, 73.57512518763542, 35.11412478983402, 25.474433451890945, 18.514415323734283, 31.90593034029007, 41.4177243411541, 50.64493641257286, 50.941453501582146, 59.2773550003767, 34.26702484488487, 4.1247014701366425, 0.22636103793047369, 0.03761437088542152, 0.14517033443553373, 0.010342885434511118, 0.039177211438072845, 0.12595135165611282, 0.1417066273279488, 0.23779088398441672, 0.13231611403170973, 0.09709912133985199, 0.10079697603941895, 0.05865495513717178, 0.04680609992647078, 0.047306415071943775, 0.07902901284978725, 0.00819528724605334, 0.05487083319167141, 0.23305657552555203, 0.3616544109536335, 0.15416909765917808, 0.03236000986362342, 0.07641746196895838, 0.04516238383075688, 0.10239175491733477, 0.03622422067564912, 0.05936281188041903, 0.045031598856439814, 0.09090101564652286, 0.014599819460272556, 0.031637124629924074, 0.07136837157304399, 0.13882676779758185, 0.04300355045415927, 0.04821428803552408, 0.07893841146142222, 0.0697453242901247, 0.030645704391645268, 0.0832852817256935, 0.05954882377409376, 0.08925058311433531, 0.05202055566769559, 0.034374402748653665, 0.021264679453452118, 0.02817061591485981, 0.025296138810517732, 0.015191815818980103, 0.0191084584366763, 0.03795580334553961, 0.044998135417699814, 0.1816741592483595, 0.021084001746203285, 0.03459158484474756, 0.04118043871130794, 0.08211042484617792, 0.11251495350734331, 0.04669158653996419, 0.02361098118853988, 0.1279259691364132, 0.03139303968055174, 0.052532047557178885, 0.035910696678911336, 0.07899262534920126, 0.052948147495044395, 0.06839033332653344, 0.017289651150349528, 0.06986647989833727, 0.029677478123630863, 0.4753758368315175, 10.94569930806756, 42.47413985431194, 75.19740253686905, 82.13858127593994, 77.14318692684174, 67.45497599244118, 59.31524656713009, 42.495373114943504, 46.50595910847187, 41.869060322642326, 29.58722446113825, 35.19414849579334, 33.009398728609085, 31.144897677004337, 31.149653121829033, 33.01559239625931, 18.555578514933586, 5.544033134356141, 0.9452362102456391, 0.018833116082532797, 0.12716411001747474, 0.3993654577061534, 0.6361343746539205, 2.1548418095335364, 3.8033484388142824, 4.616836337372661, 7.598696406930685, 7.657876806333661, 9.360251482576132, 10.177687369287014, 11.11808180809021, 8.537948057055473, 10.452911350876093, 7.268197266384959, 9.332942347973585, 7.8487728629261255, 7.935237223282456, 3.0943967308849096, 5.59532230719924, 7.7802858129143715, 7.186675490811467, 3.564090714789927, 4.912563068792224, 4.579223580658436, 4.759357664734125, 5.2480389922857285, 5.450571924448013, 4.775422252714634, 2.508740806952119, 1.1084323469549417, 1.5711186756379902, 7.197419414296746, 40.99272474646568, 77.70871058106422, 77.83288031816483, 67.74091824889183, 68.97372409701347, 24.572511948645115, 4.126521572470665, 1.847999724559486, 4.200701666995883, 4.030215265229344, 4.48832580819726, 2.552023334428668, 2.3908651946112514, 3.281687730923295, 3.575204643420875, 4.396876115351915, 5.528676258400083, 7.690126150846481, 7.06058400683105, 6.819350151345134, 8.553528171032667, 8.16517286002636, 13.704188838601112, 8.40626422315836, 9.041194003075361, 10.689840987324715, 7.451965380460024, 9.1296162083745, 7.441286528483033, 6.581195555627346, 2.7259962866082788, 1.7771674878895283, 0.5364054604433477, 0.6995983910746872, 0.306103173061274, 0.12493064627051353, 0.692374681821093, 2.627435037866235, 10.616240836679935, 24.216539449989796, 40.80512501299381, 49.46941249072552, 44.432550966739655, 51.96543015539646, 70.84729716181755, 66.40228807926178, 40.63475355505943, 32.95959860086441, 27.929962389171124, 42.02641747891903, 52.64944665133953, 56.895171627402306, 61.07945390045643, 67.23870679736137, 39.470108449459076, 5.262900469824672, 0.36618382728192955, 0.04101754842849914, 0.05540301244764123, 0.06847786222351715, 0.04647608911909629, 0.06771590662538074, 0.13490319630363956, 0.06354774552164599, 0.06212386469997, 0.025215985006070696, 0.11753092185244896, 0.03753436365514062, 0.0034356854666839354, 0.04496122841374017, 0.03140273583994713, 0.03839472061372362, 0.06963955340324901, 0.05584647165960632, 0.20103094400838017, 0.04661661107093096, 0.05721748559153639, 0.051162725721951574, 0.0024929014125518734, 0.06056437865481712, 0.01874095618404681, 0.018668296215764713, 0.03985311501310207, 0.04484744604269508, 0.043413449748186395, 0.08530268401955254, 0.03085230346187018, 0.13647133950144053, 0.001973803205146396, 0.01805461430194555, 0.04159873540629633, 0.21878798492252827, 0.16892281535547227, 0.15908226370811462, 0.09962874653865583, 0.16013535641832277, 0.12963120185304433, 0.19254709768574685, 0.18531464593252167, 0.1112395356176421, 0.12967599788680673, 0.2147014971706085, 0.14644727372797206, 0.09218748411512934, 0.20120050990954041, 0.28785658185370266, 0.14859861141303554, 0.17159720388008282, 0.16521577286766842, 0.1740734389750287, 0.2530970860971138, 0.21422825928311795, 0.1573429664131254, 0.3271206468343735, 0.13259648258099332, 0.1728583502699621, 0.21889092080527917, 0.2766327856807038, 0.17913798830704764, 0.31693671829998493, 0.1492702995892614, 0.25621698587201536, 0.22905669640749693, 0.8045391412451863, 15.995859168469906, 55.210927203297615, 86.49812534451485, 88.60347837209702, 86.24285504221916, 77.29724586009979, 66.76494061946869, 51.08035884797573, 50.66259786486626, 48.05542856454849, 32.10600100457668, 46.01510524749756, 43.12739700078964, 38.47109645605087, 38.30590412020683, 42.83056452870369, 23.411594443023205, 7.97306751832366, 1.4437895268201828, 0.13522537745302543, 0.23150799534050748, 0.4368690890260041, 0.2483722919714637, 1.5026719984598458, 3.258905578404665, 5.72219654917717, 13.173762001097202, 13.826039750128984, 14.529617596417665, 18.619874864816666, 19.710009768605232, 13.034877553582191, 16.103581488132477, 13.01917964592576, 17.780594900250435, 19.353488199412823, 11.754542905837297, 12.659241110086441, 12.480529099702835, 21.51897680014372, 17.328153178095818, 14.159603901207447, 12.570166289806366, 18.367959782481194, 13.390722759068012, 18.032998256385326, 16.013653613626957, 13.655810784548521, 4.877257263287902, 1.5962593141011894, 2.4229625472798944, 8.967608101665974, 40.17606496810913, 68.31810727715492, 71.30037724971771, 58.273049890995026, 61.06119208037853, 26.636783480644226, 13.379902839660645, 7.503738077357411, 15.552574954926968, 14.061826597899199, 10.557203404605389, 12.056587748229504, 13.105620257556438, 15.506991650909185, 8.37135074660182, 9.990459065884352, 9.460488203912973, 12.109785843640566, 14.750231858342886, 14.354259856045246, 14.059527721256018, 14.636154379695654, 16.685620956122875, 14.6148631721735, 15.30041003599763, 14.359913002699614, 23.826763965189457, 16.86224687844515, 12.643922232091427, 9.062268622219563, 4.386114617809653, 1.5750980121083558, 0.6681791832670569, 0.7253509748261422, 0.2850406657671556, 0.4283008456695825, 1.6300399764440954, 3.935526483692229, 11.667131446301937, 25.881300419569016, 46.29369869828224, 54.279988557100296, 61.06941483914852, 83.95258873701096, 106.07782110571861, 83.98300230503082, 50.14324553310871, 39.0972800552845, 30.39876401424408, 47.0594298094511, 60.09793996810913, 68.00887987017632, 74.28456991910934, 80.8801344037056, 53.33220161497593, 7.754769707098603, 0.533699708757922, 0.14725333516253158, 0.17721824522595853, 0.19218078843550757, 0.1704573689494282, 0.24867584521416575, 0.36572227079886943, 0.3281959000742063, 0.21785209217341617, 0.19458763272268698, 0.1898443145910278, 0.19534581078914925, 0.23563438095152378, 0.14257618691772223, 0.10802101925946772, 0.13150372949894518, 0.16349787911167368, 0.3370960021857172, 0.4830123286228627, 0.20449580886634067, 0.1340975653147325, 0.20267426676582545, 0.19906204106519, 0.193300258833915, 0.250137519906275, 0.07751359182293527, 0.12929638935020193, 0.20697177678812295, 0.11995478358585387, 0.14402984641492367, 0.27209024818148464, 0.2229940623510629, 0.11226150265429169, 0.1694102431065403, 0.15836889651836827], [0.016659797838656232, 0.0746191268262919, 0.0968792600906454, 0.04609688505297527, 0.1208711059007328, 0.041720822409843095, 0.029277436406118795, 0.03397457810933702, 0.049802369030658156, 0.048217267758445814, 0.06191240456246305, 0.08274067149613984, 0.025871251309581567, 0.06385897999280132, 0.13692403474124148, 0.011531688196555478, 0.06004129070788622, 0.044721180747728795, 0.07305502833332866, 0.09382380841998383, 0.04327595204813406, 0.07436163126840256, 0.03757487749680877, 0.19836581748677418, 0.182491026353091, 0.08822653064271435, 0.06765573329175822, 0.05363969183235895, 0.20073586609214544, 0.08836586886900477, 0.13753158651525155, 0.03885579470079392, 3.7741052079945803, 39.33600604534149, 66.3322426378727, 63.45770828425884, 67.52224758267403, 51.465414986014366, 49.319594129920006, 41.142782494425774, 37.26772002875805, 20.40735214948654, 24.868508465588093, 29.772010445594788, 28.267087899148464, 50.889829471707344, 62.82501943409443, 57.406388595700264, 18.447443917393684, 5.3375892620533705, 0.5059497384354472, 0.1339871040545404, 0.12335848063230515, 0.09971234947443008, 0.17994044290389866, 0.7889527338556945, 2.321227043867111, 5.67251231521368, 5.242327898740768, 4.457540335133672, 3.3833593502640724, 4.036048427224159, 5.978557867929339, 6.783254463225603, 6.051797037944198, 2.970453556627035, 6.5318818017840385, 5.746890474110842, 5.544924661517143, 5.883488869294524, 3.62289113458246, 3.884616340510547, 4.476043917238712, 5.628807060420513, 3.6990832211449742, 4.943682923913002, 9.098683018237352, 9.261875711381435, 13.683801982551813, 14.963239878416061, 10.306499507278204, 8.588987868279219, 4.03183682821691, 2.556623462587595, 16.187914162874222, 52.80309900641441, 80.72417557239532, 71.90366327762604, 65.2879598736763, 69.26428690552711, 44.945793226361275, 14.368183258920908, 5.418310705572367, 7.703117653727531, 13.482592329382896, 12.231593057513237, 7.558615207672119, 8.406876940280199, 4.176771501079202, 5.3009972255676985, 0.7314948888961226, 4.565944718196988, 2.5977591052651405, 5.360966557636857, 5.895578870549798, 10.915079601109028, 9.213380813598633, 10.594150722026825, 2.856291295029223, 8.782802168279886, 6.037785289809108, 6.595756374299526, 4.948257403448224, 6.022062208503485, 3.323213327676058, 1.5559661574661732, 0.370061727007851, 1.210931846871972, 0.8578321128152311, 0.3535932919476181, 0.11036426891223527, 0.09087895901757292, 0.10414666699944064, 1.191478909458965, 6.354096941649914, 18.26502900570631, 41.068317890167236, 60.32133378088474, 84.30584818124771, 84.05170261859894, 55.029931515455246, 38.58558051288128, 25.21213162690401, 17.250855825841427, 25.984493382275105, 30.96451185643673, 39.81441557407379, 46.53475396335125, 58.03709015250206, 51.03345796465874, 12.499293442815542, 1.255257180891931, 0.04004397684184369, 0.05148622418346349, 0.01926568613271229, 0.0650127895642072, 0.1051127800019458, 0.18774851923808455, 0.21870217780815437, 0.09458169704885222, 0.18167104222811759, 0.11239750863751397, 0.15999951370758936, 0.06783840552088805, 0.0402610216406174, 0.09633443463826552, 0.09580192883731797, 0.054818211210658774, 0.18149691954022273, 0.21150862943613902, 0.05242507439106703, 0.07274246541783214, 0.04079497462953441, 0.055979334647418, 0.061668041307711974, 0.04550295911030844, 0.03842266618448775, 0.1010085697635077, 0.06239060370717198, 0.061883831876912154, 0.05577551492024213, 0.04360195896879304, 0.31596483138855547, 0.08180164688383229, 0.06975839351071045, 0.011090672505815746, 0.013576464607467642, 0.05992924496240448, 0.0527222451637499, 0.015377006711787544, 0.08322297100676224, 0.0688738573808223, 0.013685755129699828, 0.022242386658035684, 0.06698267956380732, 0.04294165162718855, 0.0603104416950373, 0.029523040902859066, 0.007816135130269686, 0.03412944948649965, 0.07287677930435166, 0.03313181747216731, 0.050498395939939655, 0.11076834605773911, 0.08121011065668426, 0.054913187559577636, 0.05790859206172172, 0.04575801300234161, 0.04293085708923172, 0.1210260514926631, 0.05283531507302541, 0.12083187597454526, 0.0360471479507396, 0.014327416938613169, 0.12809621781343594, 0.021444134472403675, 0.035781225305981934, 0.031693806158727966, 5.307258339598775, 47.395776361227036, 77.68704414367676, 75.40696129202843, 77.84000873565674, 62.94900678098202, 60.49831308424473, 51.386033445596695, 47.935282811522484, 32.91040264070034, 34.79212626814842, 35.92123568058014, 35.441690012812614, 42.3814058303833, 46.76757127046585, 39.30000677704811, 15.407250802963972, 4.810931347310543, 0.6007854652125388, 0.25717729527968913, 0.17776871100068092, 0.9525558643508703, 1.0500862402841449, 2.6715029357001185, 4.223841950297356, 5.0683490093797445, 7.4946617893874645, 7.604179037734866, 8.697809278964996, 8.324174378067255, 8.955926578491926, 10.046645700931549, 8.437750283628702, 8.183722514659166, 8.189932331442833, 8.65953203290701, 9.61308041587472, 8.200511913746595, 5.372856119647622, 5.1031513419002295, 4.0219758823513985, 5.0830755941569805, 4.086000546813011, 6.688118018209934, 7.129473835229874, 8.830627351999283, 11.640321984887123, 14.443386923521757, 10.827376507222652, 9.347012042999268, 6.120274113491178, 4.960359279066324, 19.744979292154312, 59.79543060064316, 86.19250014424324, 78.80255028605461, 72.36158430576324, 77.50916808843613, 51.14030063152313, 17.04579222947359, 6.616536509245634, 6.687421705573797, 11.227514985948801, 8.97000577300787, 6.544189816340804, 6.086006127297878, 5.049281157553196, 2.926839734427631, 2.4550779489800334, 5.797730321064591, 4.598718909546733, 8.862677682191133, 11.556028258055449, 10.573602374643087, 9.324999824166298, 10.859723221510649, 10.904648210853338, 18.65458220243454, 12.963853664696217, 11.787247750908136, 9.119350109249353, 6.248987456783652, 6.9899168238043785, 5.326746068894863, 3.911094507202506, 3.120253630913794, 1.873594676144421, 1.3340340787544847, 0.5076079338323325, 0.0761302953469567, 0.07246260152896866, 1.0882298997603357, 5.488301524892449, 20.591885447502136, 49.051035940647125, 70.57800561189651, 84.0790231525898, 88.54435354471207, 67.63827815651894, 46.77330516278744, 32.438015788793564, 22.629205025732517, 38.721408024430275, 43.1138963252306, 50.238381028175354, 53.61416548490524, 67.45455041527748, 58.62592555582523, 15.575139094144106, 1.63744862889871, 0.049858679485623725, 0.05172546661924571, 0.07405421885778196, 0.017985286576731596, 0.07555976189905778, 0.11647228529909626, 0.149922706768848, 0.07628626510268077, 0.10306891272193752, 0.0851568445796147, 0.13241093081887811, 0.03313836692541372, 0.032639970231684856, 0.03210262562788557, 0.08072715063462965, 0.04347284382674843, 0.07971851999172941, 0.11060462828027084, 0.024776691097940784, 0.11296761163976043, 0.037064799398649484, 0.03920730552636087, 0.07477825070964172, 0.059285884562996216, 0.03965256444644183, 0.042854857456404716, 0.01950501206010813, 0.06865734321763739, 0.013312121809576638, 0.05644407865474932, 0.046156694734236225, 0.02128607371560065, 0.036243987779016607, 0.015039990958030103, 0.11127964869956486, 0.12058036212692969, 0.20377356559038162, 0.09721244729007594, 0.2627817273605615, 0.20712540135718882, 0.12087720635463484, 0.12631782417884097, 0.1286568510113284, 0.10703935084166005, 0.20191212563076988, 0.2163228375138715, 0.09526297377306037, 0.10341850880649872, 0.24034930451307446, 0.20755198784172535, 0.4192038072505966, 0.18824891973054036, 0.23649073031265289, 0.1910550839966163, 0.17734362365445122, 0.20994738821173087, 0.23811591498088092, 0.33216659794561565, 0.30846447916701436, 0.2333892061142251, 0.13307927933055907, 0.12950566015206277, 0.34064498206134886, 0.21614573139231652, 0.2879732771543786, 0.1931821831385605, 7.3869736678898335, 56.956652328372, 87.74885103106499, 82.68800899386406, 86.77864149212837, 71.14647030830383, 66.72657787799835, 57.5459361076355, 52.130968272686005, 33.32839161157608, 35.16386792063713, 41.40624515712261, 40.26857480406761, 65.07826432585716, 77.37663879990578, 70.00056579709053, 23.484622724354267, 7.305516488850117, 0.8345579460728914, 0.4912344936747104, 0.2345563966082409, 0.6915516697335988, 0.6416253175120801, 2.6108090300112963, 6.958676800131798, 11.152459513396025, 13.55823677033186, 13.840981498360634, 15.33278999850154, 15.906012989580631, 18.045896664261818, 15.252637099474669, 16.396277882158756, 13.418683558702469, 18.303726129233837, 16.125662103295326, 14.844918977469206, 14.791523292660713, 8.736721090972424, 9.69764867797494, 13.009670656174421, 11.908465046435595, 9.149425495415926, 9.381107613444328, 14.510337430983782, 17.121976241469383, 19.29781548678875, 21.946659050881863, 16.281197257339954, 14.943813420832157, 6.957293674349785, 6.222369885072112, 22.914377823472023, 61.79760776460171, 82.96174630522728, 75.85843026638031, 69.89805489778519, 75.14045879244804, 50.01261234283447, 25.547646023333073, 10.749914813786745, 12.348847165703773, 18.089600019156933, 18.603759929537773, 12.83846989274025, 14.259638283401728, 7.823643386363983, 12.053485214710236, 4.6976071782410145, 12.169152908027172, 7.460227087140083, 13.75173568725586, 16.958440616726875, 21.579961627721786, 18.136780187487602, 20.417497605085373, 12.695674505084753, 20.712150894105434, 17.349228747189045, 17.52297632396221, 13.400554731488228, 15.116755440831184, 12.997023984789848, 8.288919869810343, 6.5803007036447525, 3.7344400864094496, 2.680493490770459, 0.6726988626178354, 0.6724556756671518, 0.1575323921861127, 0.31096893071662635, 1.8897885759361088, 8.121759239584208, 25.67550726234913, 50.76342165470123, 70.2201484143734, 86.5001468360424, 86.98487162590027, 62.73607760667801, 50.67311190068722, 36.04212999343872, 29.056942015886307, 40.5584916472435, 45.215928331017494, 58.47486466169357, 65.78476041555405, 81.00460052490234, 71.88135847449303, 24.48517743498087, 2.967597059905529, 0.12105906964279711, 0.16088899254100397, 0.2167563556577079, 0.17942634236533195, 0.2379960284451954, 0.4503770376322791, 0.47590774891432375, 0.22033672838006169, 0.3050526778679341, 0.2044966400717385, 0.4613576171686873, 0.15019890444818884, 0.16154332930454984, 0.25541264622006565, 0.22346743382513523, 0.19258255750173703, 0.3473834157921374, 0.45703656622208655, 0.2942350442754105, 0.21591606637230143, 0.2505238226149231, 0.14370714576216415, 0.2730738610262051, 0.14176432188833132, 0.22854838462080806, 0.2080547483637929, 0.3499906696379185, 0.09557474259054288, 0.1473977422574535, 0.23549979989184067, 0.4977960587712005, 0.17716191621730104, 0.09149019184405915, 0.13475328247295693], [0.055450057188863866, 0.049231631492148153, 0.014363667141878977, 0.02119912183843553, 0.06620519823627546, 0.05189708084799349, 0.039229918766068295, 0.02103065802657511, 0.09182862602756359, 0.039903833385324106, 0.02745190340647241, 0.06565041316207498, 0.02977749922138173, 0.11289627640508115, 0.045673196655116044, 0.07909562060376629, 0.05281053476210218, 0.022668782039545476, 0.04329967479861807, 0.028780160355381668, 0.03544556675478816, 0.055896418198244646, 0.0527255217457423, 0.06792839092668146, 0.07439243781846017, 0.09750485347467475, 0.13926362560596317, 0.08748931082664058, 0.19880859763361514, 0.16279264586046338, 0.02357907625992084, 0.8081505505833775, 21.238969825208187, 50.99254176020622, 60.90538144111633, 63.58302175998688, 56.90122090280056, 39.23627279698849, 28.02308589220047, 23.73203694820404, 19.30963095277548, 25.832687728106976, 26.576216630637646, 29.63115580379963, 46.375835090875626, 57.519462928175926, 40.074838399887085, 18.282884247601032, 5.077951094135642, 0.5130028130952269, 0.06437943331548013, 0.038599557083216496, 0.16362076392397285, 0.8377013867720962, 2.096662656404078, 4.111687168478966, 3.720408151857555, 3.959492747671902, 4.010191764682531, 6.95497389882803, 6.559380926191807, 7.748945569619536, 7.422260474413633, 11.01691223680973, 7.091634040698409, 9.541914984583855, 4.652090845629573, 7.05897431820631, 6.070263097062707, 5.422862861305475, 2.4861913919448853, 5.574505599215627, 10.363404303789139, 16.86416957527399, 13.411321453750134, 22.219421714544296, 17.453453354537487, 24.903314597904682, 24.633333384990692, 26.322105266153812, 25.414791852235794, 16.467058584094048, 18.68010923266411, 17.4877218157053, 30.949094183743, 45.28755448758602, 74.41235706210136, 55.23574747145176, 53.25022101402283, 45.5293583124876, 49.418491423130035, 32.30559289455414, 19.79650642722845, 22.05792088061571, 27.892783284187317, 28.470424488186836, 18.95591363310814, 20.792687572538853, 20.13558503240347, 13.58343131840229, 14.962013494223356, 9.371691718697548, 8.677470870316029, 5.20124782808125, 3.471493008546531, 5.05475333891809, 4.422396020963788, 14.826358873397112, 9.818187709897757, 14.313054867088795, 15.735923666507006, 6.897022258490324, 8.518670741468668, 3.4578562527894974, 5.5152791272848845, 1.4710588823072612, 2.6944026444107294, 1.3499243510887027, 1.411689561791718, 1.211205788422376, 0.4070166143355891, 0.1380862231599167, 0.1706554481643252, 0.2473406176432036, 1.2980279233306646, 3.697916683740914, 9.987643416970968, 22.485576532781124, 38.619508892297745, 40.021637454628944, 36.13252714276314, 32.22275733947754, 31.23278696089983, 25.801354609429836, 19.892567172646523, 19.374852553009987, 33.7013453990221, 48.148360177874565, 52.568484395742416, 53.7616203725338, 35.55218428373337, 4.84489724971354, 0.1673836901318282, 0.04653677453461569, 0.00714483750925865, 0.07851561735151336, 0.065283109433949, 0.09671244013588876, 0.16264711070107296, 0.05042060402047355, 0.05192402080865577, 0.23605534195667133, 0.02296137376106344, 0.027250562452536542, 0.07705242867814377, 0.07989193021785468, 0.022498551916214637, 0.13679404015420005, 0.08395969358389266, 0.17026069981511682, 0.07599630058393814, 0.10095724283019081, 0.0759132691018749, 0.0786973767390009, 0.07012667687376961, 0.028057330782758072, 0.03584520585718565, 0.031976968894014135, 0.04439042408193927, 0.009766581788426265, 0.008101378662104253, 0.05301158998918254, 0.1284213230246678, 0.015118483279366046, 0.06011889337969478, 0.03346795099787414, 0.013014031701459317, 0.03886367259838153, 0.050863473225035705, 0.027169004133611452, 0.02658070738107199, 0.10595064246444963, 0.04574197890178766, 0.024705736213945784, 0.014657090068794787, 0.052669471042463556, 0.09529296396067366, 0.055679959696135484, 0.02096498166793026, 0.14833698951406404, 0.046102736887405626, 0.07174363112426363, 0.006145993938844185, 0.038003081863280386, 0.04236671724356711, 0.03193682241544593, 0.0581573599629337, 0.012779699500242714, 0.08072298718616366, 0.05304652659106068, 0.08196888986276463, 0.044996703072683886, 0.04492108193517197, 0.08892815705621615, 0.11483124093501829, 0.07629742700373754, 0.0756429492321331, 1.4474342437461019, 27.64030773192644, 63.87296140193939, 71.11489400267601, 74.45979371666908, 70.47291085124016, 48.698141276836395, 35.90464197099209, 36.3050302863121, 30.567716248333454, 29.301935769617558, 29.46237076073885, 25.402640104293823, 43.31101834774017, 51.68199576437473, 38.7342893332243, 20.90828686952591, 5.2641938254237175, 0.4799387091770768, 0.06532033556140959, 0.12105477260774933, 0.20602138247340918, 1.8301991047337651, 4.450094634667039, 4.839405594393611, 7.825129581615329, 6.8903113435953856, 9.888780321925879, 4.577548820525408, 11.577958781272173, 8.418049290776253, 8.431610763072968, 7.615433558821678, 13.344241753220558, 10.388047881424427, 10.172724835574627, 12.217479664832354, 7.8086992632597685, 7.570368451997638, 3.694529877975583, 6.002800092101097, 8.134163673967123, 14.864707365632057, 14.745019488036633, 21.154903136193752, 17.373917922377586, 24.53597690910101, 22.36814383417368, 27.24079716950655, 24.32614266872406, 18.18399265408516, 21.161757968366146, 22.680274285376072, 35.466799065470695, 55.22680655121803, 80.6962850689888, 64.68224957585335, 62.77449734508991, 56.77123747766018, 59.22061264514923, 36.57991513609886, 22.32520993798971, 24.12928283214569, 27.455500848591328, 28.965657614171505, 19.961248487234116, 21.958624608814716, 19.439071007072926, 12.947831824421883, 11.069241128861904, 8.66475485265255, 6.320857275277376, 4.514273190870881, 9.83748972415924, 10.047464556992054, 10.437375884503126, 20.32562993466854, 11.41483448445797, 10.326080806553364, 15.12348772957921, 16.25583551824093, 12.145690117031336, 10.146571788936853, 7.395914113149047, 5.902687339112163, 6.291567971929908, 5.31928326934576, 3.6038874043151736, 4.452190222218633, 1.2806332879699767, 1.2157755182124674, 0.48718863108661026, 0.4510190844302997, 1.042679250240326, 3.3067599730566144, 14.288391340523958, 31.522017940878868, 52.66198217868805, 50.98752222955227, 43.037144243717194, 33.659182861447334, 33.233263716101646, 31.34036298841238, 25.35165064036846, 25.907927490770817, 40.07695488631725, 55.085343942046165, 61.179301142692566, 60.56678541004658, 41.83689504861832, 6.524999421089888, 0.1583732751896605, 0.06927481008460745, 0.058227337067364715, 0.033863916469272226, 0.04953310672135558, 0.07085902820108458, 0.062232797135948204, 0.023683503859501798, 0.0692358918604441, 0.11282629187917337, 0.07828316185623407, 0.02409565928246593, 0.012713570431515109, 0.016071220925368834, 0.045080910858814605, 0.05005177517887205, 0.05111116130137816, 0.10695366989239119, 0.17227757518412545, 0.04760118870763108, 0.04987653184798546, 0.0378890991123626, 0.04589129901432898, 0.030324911058414727, 0.03376391949132085, 0.11003178675309755, 0.022590127373405267, 0.07561480699223466, 0.05476934078615159, 0.0753804664418567, 0.07286237421794794, 0.04688879373134114, 0.027600922949204687, 0.12231981527293101, 0.09947532977093942, 0.11521510197781026, 0.1575253120972775, 0.1743137909215875, 0.13722340227104723, 0.2405329266912304, 0.14516800409182906, 0.1010356581537053, 0.19264458620455116, 0.15117206785362214, 0.18860905431210995, 0.2284917439101264, 0.1376693884958513, 0.3444488748209551, 0.18457205296726897, 0.19296871178084984, 0.1678235610597767, 0.17934396397322416, 0.15878400939982384, 0.16044438671087846, 0.10419643542263657, 0.24265868996735662, 0.1489160131313838, 0.17314760974841192, 0.35221975471358746, 0.21739727439126, 0.19069334637606516, 0.2587891509756446, 0.4264914896339178, 0.2766583749325946, 0.12798489566193894, 2.6308318180963397, 38.670547753572464, 80.24991542100906, 83.12947690486908, 84.14155259728432, 74.49621096253395, 55.82310475409031, 41.854704692959785, 37.75978222489357, 30.50603225827217, 36.380475237965584, 36.33325517177582, 41.0219793766737, 62.74058036506176, 73.09023320674896, 50.44835776090622, 22.826895117759705, 6.609772397205234, 0.6363367731682956, 0.16119634557981044, 0.2675383596215397, 0.3953716345131397, 1.6936966544017196, 5.814636563882232, 8.936674911528826, 13.69333852082491, 14.569917283952236, 16.152159981429577, 17.931036427617073, 19.602310247719288, 21.38695478439331, 18.098941817879677, 22.37901695072651, 18.937019146978855, 21.428993828594685, 15.074824690818787, 15.828752685338259, 13.574604392051697, 11.784547995775938, 11.128670889884233, 12.323428429663181, 16.160221248865128, 21.639658324420452, 17.875092029571533, 26.28799829632044, 22.29678936302662, 29.337144680321217, 29.266175888478756, 33.4546360373497, 30.563291385769844, 22.43670355528593, 25.35410150885582, 25.45093171298504, 42.33400717377663, 56.78260646760464, 86.42962262034416, 67.54421040415764, 65.76239481568336, 58.58946271240711, 61.68205216526985, 43.177485913038254, 25.905453823506832, 28.354990482330322, 31.282045617699623, 34.99849319458008, 21.768965385854244, 23.571442365646362, 24.713659174740314, 17.651519626379013, 21.751091144979, 17.715322002768517, 16.14091258496046, 11.832717061042786, 10.113910641521215, 13.15487701445818, 11.835178378969431, 25.959310233592987, 22.790116891264915, 24.65600296854973, 33.14674615859985, 17.623309940099716, 20.16504105180502, 13.252911753952503, 17.656067982316017, 7.89028943516314, 11.59922244027257, 6.3551608845591545, 4.1336689889431, 5.533251212909818, 1.2945151305757463, 0.9747139597311616, 0.4940994508797303, 0.7691901724319905, 2.28063334710896, 4.5931807067245245, 14.7516586817801, 30.67119039595127, 50.68196542561054, 49.276219457387924, 49.61239121854305, 44.30226355791092, 44.65343311429024, 39.80879567563534, 30.474841631948948, 34.32079955935478, 50.262452736496925, 65.94572737812996, 74.1208367049694, 75.39328202605247, 51.37491524219513, 11.01580174639821, 0.6566152756568044, 0.24162717891158536, 0.191232961951755, 0.259374764864333, 0.1324159328942187, 0.23624356545042247, 0.36651494388934225, 0.2242077558184974, 0.22792593052145094, 0.38869257259648293, 0.2515812049387023, 0.12270247403648682, 0.19584545429097489, 0.17879501217976213, 0.2158404266810976, 0.2949289226671681, 0.30763318471144885, 0.4374416411155835, 0.2433306007878855, 0.22580527322134003, 0.28807055787183344, 0.1169551265775226, 0.18318062997423112, 0.15972471126588061, 0.24121123482473195, 0.17980682663619518, 0.13067737774690613, 0.11943277917453088, 0.12820651580113918, 0.26711868995334953, 0.2543541061459109, 0.24138857843354344, 0.2765716623980552, 0.22638689435552806], [0.036159902447252534, 0.05270653018669691, 0.04514070198638365, 0.11410138322389685, 0.027166664513060823, 0.03369241727341432, 0.035152744967490435, 0.02160342348361155, 0.025510035047773272, 0.04012805475213099, 0.022338867711368948, 0.04293087564292364, 0.032129676910699345, 0.08094642558717169, 0.05329868981789332, 0.06354366370942444, 0.08618148334790021, 0.030946103506721556, 0.03922929165128153, 0.026528706948738545, 0.043604831080301665, 0.026886646628554445, 0.020323335629655048, 0.04986747393559199, 0.07507476097089238, 0.07757592480629683, 0.14890750811900944, 0.07548173249233514, 0.14208417269401252, 0.05196759972022846, 0.03681123722344637, 10.36713095381856, 43.77400070428848, 52.10091568529606, 61.3468911498785, 53.227863013744354, 46.24573387205601, 28.42903520911932, 29.104120284318924, 22.85330180078745, 25.394734628498554, 30.280132479965687, 38.26736658811569, 62.917867451906204, 59.60759907960892, 37.92502775788307, 27.86070540547371, 6.805966794490814, 0.6064377806615084, 0.057504581709508784, 0.11981710777035914, 0.24700403882889077, 0.13929242093581706, 1.325930894818157, 4.006819920614362, 3.550265869125724, 3.7710216734558344, 2.9419284872710705, 8.030680976808071, 3.243340188637376, 5.983341811224818, 4.638777310028672, 8.912743795663118, 7.337145991623402, 10.907804891467094, 11.122123841196299, 7.841701917350292, 7.768086092546582, 6.354580940678716, 10.145785231143236, 10.998125094920397, 17.53529716283083, 24.86119005829096, 29.37836106866598, 34.41465072333813, 36.70752748847008, 37.25125551223755, 42.29202702641487, 46.05265483260155, 45.156305730342865, 41.65207676589489, 34.83305387198925, 38.28134983778, 38.71658608317375, 44.383020624518394, 33.37384097278118, 56.80057190358639, 48.73758316040039, 50.6934218108654, 39.98173579573631, 43.491520062088966, 38.95699918270111, 32.28057123720646, 41.70509152114391, 48.502162992954254, 50.41233569383621, 47.22972147166729, 49.02029179036617, 48.10662321746349, 38.69800888001919, 28.228405974805355, 27.626575268805027, 18.170360885560513, 16.438833698630333, 20.99058285355568, 7.7205677423626184, 8.674310389906168, 11.039300635457039, 11.169963274151087, 16.558985151350498, 10.868704039603472, 15.425796657800674, 7.097591171041131, 6.461650645360351, 3.94603980705142, 4.292234480381012, 2.4178850697353482, 4.715100014582276, 3.8701946893706918, 4.965071026235819, 0.1304554459056817, 0.7211262546479702, 0.03738429397344589, 0.006708103082928574, 0.07720769339357503, 0.2658534765942022, 5.455802343785763, 16.18374578654766, 25.449333898723125, 33.7660863250494, 36.777713522315025, 30.930499881505966, 27.17108990997076, 21.318429261446, 22.48033471405506, 26.868620440363884, 42.847032845020294, 44.466509744524956, 54.12068970501423, 61.72725073993206, 47.20582075417042, 19.762629345059395, 0.7749124278780073, 0.048582081581116654, 0.016099624772323295, 0.056295129616046324, 0.14553045417414978, 0.06809484722907655, 0.04241159120283555, 0.10072167031466961, 0.06574539322173223, 0.09295890951761976, 0.07909567997558042, 0.010152469822060084, 0.027428900539234746, 0.007138692990338313, 0.0466373392555397, 0.0225405890159891, 0.16160691651748493, 0.04225590717396699, 0.11098137954832055, 0.03682014299556613, 0.06916484606335871, 0.029825150668330025, 0.04711315610620659, 0.034126492028008215, 0.030475273888441734, 0.027683032312779687, 0.07150814024498686, 0.0517671864508884, 0.014872187657601899, 0.069913680490572, 0.1355250269989483, 0.035170155751984566, 0.05347090889699757, 0.0578547047189204, 0.035439410639810376, 0.03942450988688506, 0.01322920628808788, 0.0444351681653643, 0.060182896195328794, 0.01435307854990242, 0.03152936478727497, 0.021876390965189785, 0.02480553837813204, 0.002526478724576009, 0.05733534606406465, 0.08300685760332271, 0.0016461405994050438, 0.06249189202208072, 0.004336251986387651, 0.047734151885379106, 0.06232727624592371, 0.030222587447497062, 0.08307219628477469, 0.07259453312144615, 0.028964626726519782, 0.04557766740617808, 0.049951518449233845, 0.039921036368468776, 0.01531606061689672, 0.027291879669064656, 0.09881714868242852, 0.08766329250647686, 0.1776082586729899, 0.1427407210576348, 0.07129598248866387, 14.210313130170107, 55.945948362350464, 64.27137762308121, 72.51407012343407, 63.3443907648325, 55.10622002184391, 38.777952790260315, 40.10942414402962, 29.670067615807056, 30.082714073359966, 34.85261142253876, 30.940848626196384, 46.434059366583824, 51.31036810576916, 39.63641032576561, 27.009794265031815, 5.935604497790337, 0.4162501485552639, 0.02839834207406966, 0.32711283944081515, 0.9780251258052886, 3.3115743147209287, 4.707043971866369, 8.496131300926208, 7.743361769244075, 9.129282776266336, 9.13110002875328, 10.961951036006212, 10.421089008450508, 13.847248312085867, 8.467908315360546, 10.503958761692047, 10.301007851958275, 11.996548119932413, 14.21730000525713, 10.032966434955597, 8.815904092043638, 6.417251452803612, 8.750759437680244, 9.324534349143505, 16.66452258825302, 24.459253326058388, 28.650099746882915, 33.9311608672142, 37.01023444533348, 36.92384608089924, 42.8572428971529, 47.05549702048302, 46.01125605404377, 44.88772474229336, 38.344741836190224, 41.70224167406559, 45.19711174070835, 50.049401968717575, 42.602170184254646, 65.03218799829483, 55.520644783973694, 59.050947949290276, 50.26193976402283, 53.16866599023342, 45.32271400094032, 37.29518875479698, 44.14929136633873, 49.50490638613701, 48.82484167814255, 46.38886459171772, 49.339334070682526, 48.39743681252003, 40.42585216462612, 29.271526001393795, 25.267386361956596, 16.958355121314526, 10.422490183264017, 8.988823313266039, 8.75309631228447, 8.204440902918577, 15.178618021309376, 12.954305727034807, 12.868527229875326, 13.765483349561691, 19.988903403282166, 16.124552562832832, 8.881951197981834, 7.806220846250653, 10.502702929079533, 7.729089260101318, 6.187965581193566, 6.364677948877215, 5.0817005429416895, 4.536137217655778, 0.851372400065884, 0.5988718522712588, 0.06941906874999404, 0.03859556061797775, 0.22167804156197235, 4.355220850557089, 12.267680671066046, 24.726257398724556, 33.396225571632385, 37.671942338347435, 33.35024043917656, 33.58807347714901, 28.224419988691807, 25.65292127430439, 30.55947259068489, 47.150963097810745, 49.5843069255352, 61.165872663259506, 70.40909707546234, 53.98825541138649, 22.96778965741396, 1.0978541895747185, 0.059602729670586996, 0.05208481823501643, 0.04532589751761407, 0.06902252440340817, 0.061563212948385626, 0.04754803238029126, 0.05880072036234196, 0.009336206640000455, 0.08685058885021135, 0.028815904042858165, 0.03511524795612786, 0.05980482390441466, 0.015982332042767666, 0.1192684008856304, 0.0742236734367907, 0.0614601286360994, 0.02652693507116055, 0.02253549602755811, 0.05416373714979272, 0.05303362806444056, 0.0549851907271659, 0.028251810581423342, 0.034611789815244265, 0.004060448109157733, 0.07695517022511922, 0.02437980721879285, 0.0386130122205941, 0.051868381997337565, 0.014259895415307255, 0.027190583932679147, 0.03453885896306019, 0.04018021660158411, 0.01458253576856805, 0.1906642541871406, 0.18980138876941055, 0.1438605328439735, 0.30520137457642704, 0.16341174545232207, 0.17354146752040833, 0.07576883232104592, 0.15308360278140754, 0.11994305023108609, 0.13863478903658688, 0.16182807652512565, 0.14531589928083122, 0.12085716094588861, 0.21215524786384776, 0.24892301007639617, 0.2773217955837026, 0.14705826906720176, 0.19988661166280508, 0.09387455647811294, 0.11782700908952393, 0.1630361593561247, 0.099993089097552, 0.13126207137247548, 0.2537860069423914, 0.24270053225336596, 0.23241288115968928, 0.2406414138386026, 0.24167031253455207, 0.5280773167032748, 0.2573841466801241, 0.32946690218523145, 20.18146377056837, 69.10319074988365, 76.48546501994133, 82.32240781188011, 72.12063923478127, 63.15064676105976, 45.41841946542263, 44.79314021766186, 36.98887959122658, 38.35236802697182, 43.72142672538757, 54.05317112803459, 79.52376678586006, 70.50674423575401, 47.436764761805534, 34.23870116472244, 8.71203476563096, 1.1301643308252096, 0.17329396127024665, 0.3723261383129284, 1.3870071549899876, 2.1902841702103615, 5.751098273321986, 12.508517447859049, 14.03885493054986, 15.283611137419939, 13.386995159089565, 16.81552078574896, 11.564441956579685, 20.297329053282738, 17.439690493047237, 24.090277925133705, 18.65610972046852, 22.623835913836956, 20.133384950459003, 16.78989876061678, 15.585820320993662, 15.238223522901535, 18.51761095225811, 17.18434799462557, 22.958326265215874, 30.886095464229584, 32.06295311450958, 37.476032450795174, 40.267575457692146, 39.88241672515869, 46.23885624110699, 51.80094078183174, 51.51524931192398, 49.5700690895319, 42.34345726668835, 47.51583471894264, 49.78254608809948, 58.51093612611294, 46.92558579146862, 72.42314860224724, 60.593589171767235, 63.142230212688446, 53.23666334152222, 56.66330426931381, 51.523605063557625, 41.05946436524391, 45.590166449546814, 53.40576946735382, 55.087977200746536, 51.19816392660141, 54.39240172505379, 52.87942171096802, 44.26145754754543, 30.859873071312904, 32.922934368252754, 23.660756573081017, 23.642540350556374, 30.97955334931612, 18.86209286749363, 20.768148489296436, 22.438115179538727, 21.366316191852093, 24.353233315050602, 20.24122316390276, 26.022299453616142, 22.40926142781973, 16.125791296362877, 12.8530696593225, 15.042669866234064, 8.768757171928883, 13.724768534302711, 9.160342309623957, 11.654633916914463, 3.5339607065543532, 1.006489754654467, 0.3567182086408138, 0.17293341108597815, 0.3918508265633136, 0.5204291583504528, 7.317810254171491, 21.862415671348572, 34.36550036072731, 45.800971537828445, 50.16428880393505, 43.06657366454601, 38.835466504096985, 32.91526257991791, 33.83580878376961, 38.55526953935623, 58.425516709685326, 63.4123919159174, 73.3699893951416, 80.43485149741173, 66.11180886626244, 31.605159379541874, 2.321422495879233, 0.1593920955201611, 0.16841483011376113, 0.22946843993850052, 0.39199984981678426, 0.20566429069731385, 0.24921111180447042, 0.25666414469014853, 0.17672970425337553, 0.1804531185189262, 0.1960220854380168, 0.10359450912801549, 0.17594601114979014, 0.09777306564501487, 0.2337383123813197, 0.19973178481450304, 0.25097590929362923, 0.18872236541938037, 0.21278166503179818, 0.17752647399902344, 0.22707167401676998, 0.14793321664910764, 0.27098382473923266, 0.15454851323738694, 0.15725822799140587, 0.1104080853110645, 0.21972352144075558, 0.10817948263138533, 0.13557546335505322, 0.14101935405051336, 0.20231426577083766, 0.12275262095499784, 0.22506121080368757, 0.19164479454047978], [0.03662675786472391, 0.029282729774422478, 0.09622043333365582, 0.023007340532785747, 0.029954468045616522, 0.044677457117359154, 0.041818169920588844, 0.0494791228993563, 0.04010395350633189, 0.051279205799801275, 0.0375501268717926, 0.05781226500403136, 0.06527282326715067, 0.0385665129579138, 0.03797993056650739, 0.04492755717365071, 0.04254743020283058, 0.07425185278407298, 0.04136564166401513, 0.048384447654825635, 0.09674750661361031, 0.05418424269009847, 0.02765176563116256, 0.059593938931357116, 0.1827608564053662, 0.0571911022416316, 0.20341546449344605, 0.005902275424887193, 0.09406933313584886, 0.06563214890775271, 2.7345258789137006, 28.171125948429108, 52.01064392924309, 66.99332356452942, 53.36520664393902, 41.879357770085335, 29.873858280479908, 24.093243665993214, 18.576654084026814, 27.176573015749454, 26.287542320787907, 31.125921495258808, 48.7773822247982, 31.102054975926876, 43.663479834795, 30.743850097060204, 9.485943038016558, 1.4859078917652369, 0.12836410343879834, 0.1875500541063957, 0.30743773269932717, 0.8929231110960245, 0.6919325399212539, 4.580975761637092, 5.968986181542277, 3.507996699772775, 7.203940814360976, 4.738356191664934, 9.105724040418863, 5.2451924700289965, 10.689904633909464, 8.874748684465885, 7.707622312009335, 5.20383121445775, 13.625564407557249, 11.18476253002882, 8.267533667385578, 12.021844312548637, 12.275598496198654, 17.63166569173336, 28.616878129541874, 31.2624728679657, 40.59457451105118, 46.87616564333439, 49.51909862458706, 55.65932974219322, 48.813366293907166, 57.41899251937866, 61.069734022021294, 58.69221679866314, 60.79734183847904, 54.32682104408741, 52.15029023587704, 49.41305011510849, 44.43488024175167, 22.929601706564426, 49.75072279572487, 47.32065439224243, 50.994422659277916, 41.89764618873596, 36.65789075195789, 41.917655915021896, 45.184963792562485, 53.183545991778374, 61.63974903523922, 60.394430458545685, 62.62978971004486, 64.16173830628395, 61.128706857562065, 62.00333632528782, 53.77104766666889, 46.75185911357403, 38.24700728058815, 25.039406195282936, 29.92857914417982, 16.13502100110054, 11.574113387614489, 21.5085406601429, 8.63863980397582, 8.746921643614769, 12.953861150890589, 17.353646010160446, 12.585495617240667, 8.843554258346558, 4.707873752340674, 6.893217237666249, 6.5406503062695265, 5.038995109498501, 3.8442306825891137, 4.199605900794268, 2.4640169693157077, 2.0891780080273747, 0.80639130435884, 0.11252203359617852, 0.1644554128870368, 0.07821715524187312, 0.3840335179120302, 4.669911889359355, 17.46513392776251, 29.63993713259697, 39.137398302555084, 32.56284289062023, 29.455251842737198, 28.099281303584576, 22.136838845908642, 16.84529598802328, 24.700369387865067, 36.55370034277439, 47.468116879463196, 60.07327549159527, 59.71959426999092, 38.30269709229469, 8.828613460063934, 0.1815877138869837, 0.12493806774728, 0.05792506774014328, 0.08362667707842775, 0.02972356363898143, 0.011458872377261287, 0.027917849693039898, 0.017557180544827133, 0.08860199799528345, 0.05425645736977458, 0.05930719162279274, 0.03192347860021982, 0.11362755903974175, 0.09978023372241296, 0.07784656379953958, 0.06973977302550338, 0.10938562845694833, 0.12260718227480538, 0.06819663278292865, 0.02328101676539518, 0.09530852679745294, 0.03255628565966617, 0.05436840292531997, 0.043428678618511185, 0.040396107360720634, 0.09385064447997138, 0.04955328200594522, 0.056976662381202914, 0.05296923191053793, 0.06842165195848793, 0.05524005908227991, 0.0925619866757188, 0.08524374265107326, 0.03626173624070361, 0.0258052020217292, 0.027439398218120914, 0.03336549751111306, 0.025951763200282585, 0.02643204035848612, 0.05424909897556063, 0.06882354718982242, 0.11955756388488226, 0.03785567278100643, 0.043883062244276516, 0.021160238866286818, 0.055954012568690814, 0.08736507530556992, 0.0529269888647832, 0.04591643184539862, 0.12755277275573462, 0.09169972981908359, 0.04779172028065659, 0.05524230778974015, 0.055036551057128236, 0.06062753171136137, 0.06934582619578578, 0.018347747791267466, 0.12216919640195556, 0.0481633358867839, 0.0995007854362484, 0.08344952642801218, 0.07505094545194879, 0.04254303297784645, 3.7355410773307085, 36.812622249126434, 62.20789074897766, 77.54227951169014, 64.78203982114792, 53.07970516383648, 43.60967852175236, 31.203144751489162, 29.064127430319786, 37.359298914670944, 29.142899103462696, 27.039487771689892, 34.06597763299942, 31.349501498043537, 40.44498793780804, 25.10530035942793, 9.521435983479023, 1.3984014373272657, 0.2437042721430771, 0.36653207265771925, 0.7786959561053663, 2.030161712318659, 4.77676073089242, 7.936124475672841, 8.918992560356855, 8.194402791559696, 14.102146234363317, 12.273161876946688, 10.048943627625704, 11.719202902168036, 13.65540325641632, 14.626052621752024, 13.17215183749795, 12.581086903810501, 11.219638958573341, 12.654851395636797, 8.378769848495722, 6.022901488468051, 9.283057674765587, 15.622364860028028, 25.810341127216816, 32.088749930262566, 44.210684671998024, 49.1996193677187, 51.71899437904358, 55.24267069995403, 51.85092329978943, 59.65127393603325, 60.31466133892536, 60.868656411767006, 63.57196815311909, 60.482703521847725, 57.28976145386696, 55.68862237036228, 48.92708279192448, 31.605932638049126, 56.524011343717575, 53.512209355831146, 57.99091123044491, 50.87844908237457, 47.203126698732376, 48.71586352586746, 51.27178117632866, 57.57267527282238, 62.72859200835228, 60.552479177713394, 64.19241026043892, 66.1042320728302, 64.53047811985016, 63.14379572868347, 54.794883728027344, 47.45908476412296, 36.50552272796631, 25.677424259483814, 19.158155880868435, 11.126644648611546, 10.840752739459276, 14.26325473934412, 13.416921403259039, 11.060523446649313, 14.738635830581188, 23.511622175574303, 14.354046117514372, 7.5590061116963625, 11.121183391660452, 8.913771640509367, 8.427746370434761, 9.405193571001291, 7.629483304917812, 7.078554192557931, 7.400330901145935, 5.564794270321727, 2.736680838279426, 0.5787961045280099, 0.2696799306431785, 0.04046133100928273, 0.2866661176085472, 4.658040376380086, 17.22137700766325, 29.833534844219685, 42.504713013768196, 32.83054232597351, 22.678277492523193, 25.309875681996346, 25.75362917035818, 26.730193868279457, 33.51990893483162, 46.2845753878355, 56.10433526337147, 65.81360846757889, 67.14264035224915, 46.10573038458824, 11.809021532535553, 0.17592083750059828, 0.07423105038469657, 0.05814502546854783, 0.11095896668848582, 0.03849171189358458, 0.02637710473209154, 0.05041445532697253, 0.027141772879986092, 0.06613459772779606, 0.03668803328764625, 0.05017755065637175, 0.04858460117247887, 0.0521626621048199, 0.031205636259983294, 0.03867656232614536, 0.07122536713723093, 0.10065358568681404, 0.04446394865226466, 0.12927603966090828, 0.04140902390645351, 0.026619391828717198, 0.06101014594605658, 0.06530444617965259, 0.0455377806792967, 0.040645153567311354, 0.03469127754215151, 0.003962038399549783, 0.045287313259905204, 0.09615620787371881, 0.027647787719615735, 0.044224053126526996, 0.05851428475580178, 0.05089579375635367, 0.10130735841812566, 0.09814395394641906, 0.24251020106021315, 0.1773146353662014, 0.14669170748675242, 0.14153024851111695, 0.2109172713244334, 0.15839073050301522, 0.27054224687162787, 0.2021642925683409, 0.23669982299907133, 0.2166086237411946, 0.14822876953985542, 0.17239326116396114, 0.15444507269421592, 0.2517426072154194, 0.25565503165125847, 0.21542749571381137, 0.1084261279902421, 0.2125155011890456, 0.194358472363092, 0.18251983652589843, 0.3494848811533302, 0.1568692535511218, 0.3582726517925039, 0.08426429325481877, 0.41377885616384447, 0.13315417687408626, 0.26145141280721873, 0.30070728447753936, 5.228839097544551, 46.580233722925186, 75.64111232757568, 88.68043944239616, 71.96773543953896, 59.99085411429405, 47.16406099498272, 39.108398258686066, 31.86441756784916, 42.3026018589735, 38.81328709423542, 42.99583286046982, 65.30958071351051, 44.376245588064194, 54.89926412701607, 38.769996017217636, 11.882371846586466, 2.0000067679211497, 0.24923337623476982, 0.3144916979363188, 0.6922289833892137, 2.183660175651312, 4.9807727336883545, 10.594780538231134, 15.616523623466492, 11.845886204391718, 20.401943139731884, 15.761267356574535, 22.98339731991291, 17.085217013955116, 19.236028902232647, 16.002290323376656, 17.20000695437193, 15.58076849207282, 22.840133607387543, 19.86036390066147, 13.863838221877813, 23.476413264870644, 19.60958495736122, 23.422581553459167, 34.29453156888485, 36.045116633176804, 45.46515695750713, 52.93536610901356, 53.08953143656254, 56.715589463710785, 51.6159401088953, 60.82113616168499, 61.32912330329418, 59.98260475695133, 67.50308141112328, 59.52394276857376, 65.23277923464775, 61.75011031329632, 56.07525162398815, 34.339616149663925, 63.552171215415, 58.490447625517845, 63.432276248931885, 53.01976338028908, 51.34456247091293, 53.51008526980877, 54.87573578953743, 57.81276158988476, 63.5263592004776, 62.827219516038895, 67.47392937541008, 68.41418892145157, 67.80831143260002, 66.11943125724792, 58.89273203909397, 51.476905569434166, 41.2608877569437, 29.561410546302795, 34.24104183912277, 21.945743300020695, 23.70048724114895, 31.300932504236698, 17.031647488474846, 19.217806980013847, 26.61265477538109, 27.47863780707121, 21.200738176703453, 17.840570881962776, 11.759463641792536, 15.41440486907959, 12.156100608408451, 17.89209421724081, 14.86359877511859, 16.06983169913292, 13.861457649618387, 6.917988108471036, 3.5856445832177997, 0.3096235357224941, 0.46398490900173783, 0.11899693810846657, 0.5566118855495006, 6.21652009896934, 24.300541542470455, 38.88870544731617, 54.48294706642628, 47.47610405087471, 41.714465618133545, 41.32578447461128, 30.49189131706953, 27.939773462712765, 38.69689553976059, 55.12054905295372, 66.33049473166466, 76.61139026284218, 78.53586539626122, 56.61237560212612, 16.975961476564407, 0.43585629493463784, 0.2348303233156912, 0.1869432147941552, 0.23103590036043897, 0.15151157072978094, 0.21423565107397735, 0.18833245587302372, 0.08912267396226525, 0.18449721479555592, 0.12632782832952216, 0.1697364466963336, 0.12119906095904298, 0.21182082127779722, 0.23083045904058963, 0.20895369700156152, 0.17890458286274225, 0.22866389248520136, 0.19739143695915118, 0.13928060594480485, 0.10353462523198687, 0.23170181462774053, 0.12593711726367474, 0.12093306781025603, 0.2810086071258411, 0.12129487222409807, 0.14363207010319456, 0.17445013829274103, 0.17183564108563587, 0.16788536711828783, 0.17406444414518774, 0.10708007248467766, 0.29642865469213575, 0.16195495409192517], [0.0823552964720875, 0.03390083089470863, 0.0026925825068246922, 0.02425542512355605, 0.07788244663970545, 0.03434123987972271, 0.03072579511353979, 0.030519871397700626, 0.04272099999070633, 0.02278674641274847, 0.03381923546839971, 0.08563243507524021, 0.06544316842337139, 0.006870177003293065, 0.059921675056102686, 0.049791418641689233, 0.07623700876138173, 0.033429659888497554, 0.09588359476765618, 0.07685743679758161, 0.015722198149887845, 0.03232574861613102, 0.05279933575366158, 0.05189853174670134, 0.02101664442307083, 0.009460718611080665, 0.05692822982382495, 0.03868886342388578, 0.044586503208847716, 0.8355406683403999, 15.756118632853031, 46.07068106532097, 66.52468711137772, 62.285782769322395, 48.70061494410038, 41.05615094304085, 20.26652030646801, 24.318508878350258, 31.27840731292963, 29.312738589942455, 44.47645381093025, 45.002698972821236, 34.80665288865566, 44.76426176726818, 31.53871614485979, 10.277444366365671, 0.9032557660248131, 0.0413809187739389, 0.06266329102800228, 0.149213332333602, 1.1719329957850277, 1.4681540569290519, 7.898689359426498, 6.240286873653531, 6.93319346755743, 7.697006156668067, 7.534715915098786, 10.557983312755823, 7.632827600464225, 12.65294674783945, 17.18525804579258, 9.723339099436998, 8.395452853292227, 9.939900878816843, 7.212419584393501, 13.031456787139177, 15.776033364236355, 17.102074809372425, 24.840004295110703, 35.58044336736202, 47.15465649962425, 55.47154001891613, 51.429278925061226, 61.874139457941055, 60.07104881107807, 61.47293418645859, 64.41387757658958, 64.83714446425438, 69.45414751768112, 67.21747353672981, 68.9508493244648, 68.50073307752609, 63.57479900121689, 51.12429589033127, 41.192700415849686, 21.036531887948513, 48.109370470047, 46.48579739034176, 52.788127809762955, 45.44417828321457, 35.424351543188095, 39.11399535834789, 50.61121702194214, 59.171412885189056, 64.84593719244003, 65.99765539169312, 68.09782549738884, 65.00362113118172, 64.45240750908852, 63.49538706243038, 62.51125127077103, 60.71510665118694, 59.94920074939728, 51.19975984096527, 37.43758611381054, 27.797792181372643, 19.150833673775196, 17.833702750504017, 12.477550059556961, 9.39672952517867, 10.17066914588213, 21.614347882568836, 11.430691983550787, 7.223199130967259, 9.293587859719992, 11.88485786318779, 9.046887997537851, 3.1219521397724748, 6.685436787083745, 2.50198548194021, 7.10006388835609, 1.9573599938303232, 1.8153464142233133, 0.6748648651409894, 0.09258222504286095, 0.1564269929076545, 0.14031591679668054, 0.0559992093621986, 3.3592648431658745, 12.73495964705944, 32.08979867398739, 40.92819660902023, 42.47330769896507, 34.83313746750355, 30.211880542337894, 22.17942886054516, 18.32223303616047, 20.36542519927025, 37.57762759923935, 50.36860004067421, 60.29959514737129, 57.03940808773041, 29.617706425487995, 2.1396514121443033, 0.08633118937723339, 0.09356813112390228, 0.0774899692623876, 0.08908120275009423, 0.12587839853949845, 0.02640849386807531, 0.04553421094897203, 0.036511120124487206, 0.045177720312494785, 0.10187045554630458, 0.052656913903774694, 0.06514702923595905, 0.05754348880145699, 0.03549041473888792, 0.050514096074039117, 0.08252826140960678, 0.09419256675755605, 0.0587837808416225, 0.09079296636627987, 0.04141318364418112, 0.10698235390009359, 0.026010253714048304, 0.05708807359042112, 0.05228704234468751, 0.04509167200012598, 0.039615779896848835, 0.020006496088171843, 0.1211722991138231, 0.07376513007329777, 0.08381719380849972, 0.0401872336078668, 0.08098294667433947, 0.03413537924643606, 0.07104734817403369, 0.03007688901561778, 0.03994928993051872, 0.08343453504494391, 0.057115358649753034, 0.04728301144496072, 0.07414779625833035, 0.032473376631969586, 0.033891628263518214, 0.03588235776987858, 0.06844298128271475, 0.028869056659459602, 0.01510020139903645, 0.052877227863064036, 0.03279742428276222, 0.03237157994590234, 0.06652697120443918, 0.1295630875392817, 0.007439192295350949, 0.010297448370693019, 0.014982730554038426, 0.0648628460476175, 0.05929799270234071, 0.0076439452732302016, 0.06308330208412372, 0.01732199394609779, 0.06298584325122647, 0.01675669635005761, 1.13724026363343, 19.786813147366047, 55.515997633337975, 77.83227235078812, 72.31445923447609, 58.304812386631966, 48.36576551198959, 28.52336324751377, 35.54197423160076, 41.302556321024895, 31.615690514445305, 29.632934108376503, 26.669651716947556, 32.61380955576897, 46.20365113019943, 33.9984742552042, 10.350878275930882, 1.0082859895192087, 0.1327535804011859, 0.14766006177524105, 1.835358515381813, 3.2804886577650905, 5.443661045283079, 11.003150325268507, 8.91254335641861, 12.522027622908354, 10.188299249857664, 14.686187244951725, 15.10875592008233, 14.853658508509398, 21.09218180179596, 19.236747063696384, 18.862174563109875, 11.202831510454416, 7.068128976970911, 8.074390031397343, 6.842873264104128, 8.87777617201209, 15.418157167732716, 21.918044686317444, 34.94488187134266, 47.62184143066406, 54.96221914887428, 53.22862297296524, 62.110771760344505, 61.52667470276356, 63.539491295814514, 65.04432454705238, 64.7235457599163, 69.69735726714134, 67.29792281985283, 69.47500079870224, 73.04853424429893, 67.59873747825623, 56.61100387573242, 46.58937983214855, 28.797809220850468, 53.952020555734634, 51.881070882081985, 58.27013544738293, 53.17370072007179, 43.41372303664684, 45.833429396152496, 54.54372100532055, 62.02896974980831, 65.25104105472565, 65.64080893993378, 68.12098145484924, 66.03732526302338, 67.60927811264992, 65.27757123112679, 65.49424320459366, 62.70976401865482, 61.58582612872124, 50.65712235867977, 39.06877778470516, 25.315090902149677, 19.639671742916107, 17.26554773747921, 14.957776721566916, 8.509626276791096, 11.480406615883112, 19.47089619934559, 15.919770151376724, 8.899108227342367, 12.113844975829124, 14.081941768527031, 11.575498413294554, 12.667580712586641, 7.894899537786841, 8.519806880503893, 11.225129663944244, 6.530954176560044, 5.719945169985294, 2.360480362549424, 0.6073942012153566, 0.1866173229063861, 0.35499592137057334, 0.10845014388905838, 4.434219561517239, 13.778629694133997, 31.970678865909576, 40.686514377593994, 34.813910499215126, 33.99654395878315, 30.780535228550434, 23.869597166776657, 23.48381146788597, 28.72964657843113, 44.169506281614304, 57.969153597950935, 66.75959810614586, 64.92452457547188, 34.667591750621796, 3.4370910795405507, 0.06634279983700253, 0.030608474553446285, 0.07332063556532376, 0.07955291715916246, 0.009006103991850978, 0.03133403151878156, 0.04435138340340927, 0.0014437935715250205, 0.03056745234061964, 0.03888708364684135, 0.022347181620716583, 0.0183294371527154, 0.011509090727486182, 0.002861098964785924, 0.01754590546624968, 0.0911003045621328, 0.035473241441650316, 0.02829820594342891, 0.018946508826047648, 0.024795779136184137, 0.020532305861706845, 0.034021259198198095, 0.017395626127836294, 0.04146308565395884, 0.035062466413364746, 0.026558793615549803, 0.04674066476582084, 0.039238664976437576, 0.060517196616274305, 0.012742925155180274, 0.014662771209259517, 0.0439672329230234, 0.19784640317084268, 0.19083984632743523, 0.17193312960444018, 0.15267122100340202, 0.20961824571713805, 0.08260168950073421, 0.12299675043323077, 0.1269596186466515, 0.07385291872196831, 0.21066418412374333, 0.12522404693299904, 0.21922485757386312, 0.15270138188498095, 0.11977372181718238, 0.19781768205575645, 0.1491873274790123, 0.23090595030225813, 0.21787218953249976, 0.2607711305608973, 0.15364871855126694, 0.08462473953841254, 0.16189138172194362, 0.1684051228221506, 0.15237315965350717, 0.08832344770780765, 0.2620293974177912, 0.1546594940009527, 0.23453612113371491, 0.17110087035689503, 1.8774167960509658, 27.88215145468712, 71.35855972766876, 86.91916555166245, 79.5402655005455, 66.78114295005798, 56.07063487172127, 35.70214703679085, 38.19463849067688, 45.35331755876541, 42.21293427050114, 62.3683675378561, 63.77713054418564, 49.799417182803154, 56.936030834913254, 38.082624301314354, 12.3034861497581, 1.23845697613433, 0.3838298429036513, 0.3208070184336975, 1.123926609288901, 3.2874788576737046, 5.909018749371171, 19.59114644676447, 17.589092776179314, 17.033986262977123, 15.862842556089163, 18.956519700586796, 22.703111059963703, 23.151156418025494, 25.70474099367857, 27.94080700725317, 19.578869305551052, 17.97663778066635, 20.067243799567223, 13.07847736403346, 21.2671947106719, 24.14798352867365, 24.224374629557133, 29.213104136288166, 43.334352895617485, 54.20972652733326, 58.98006655275822, 56.35688491165638, 64.21505704522133, 64.57517892122269, 63.7832710146904, 65.66530242562294, 64.70681145787239, 71.24186798930168, 68.49342226982117, 72.74620726704597, 71.48983508348465, 73.09014961123466, 63.5675223916769, 52.247557416558266, 34.44334298372269, 59.24323283135891, 56.43077574670315, 62.228003069758415, 58.64924110472202, 47.451994344592094, 53.405807465314865, 56.56085416674614, 61.647018045187, 65.37110701203346, 68.40009167790413, 72.45854750275612, 69.25905078649521, 68.82596522569656, 66.86166062951088, 66.45053029060364, 66.17196723818779, 63.66641968488693, 55.14147453010082, 40.992416962981224, 30.956908464431763, 24.248904213309288, 24.153265245258808, 19.404014088213444, 16.84779055416584, 15.570840574800968, 30.599695332348347, 21.22807200998068, 17.068471312522888, 20.043580569326878, 18.721147030591965, 16.426039785146713, 12.837628237903118, 15.489318799227476, 11.428369358181953, 18.927698247134686, 7.026167353615165, 7.008947627618909, 2.7300152834504843, 0.31532714841887355, 0.4351383709581569, 0.5659210297744721, 0.24714244937058538, 5.200108364224434, 16.758782230317593, 41.704304963350296, 56.75147093832493, 58.28422129154205, 46.99995920062065, 43.5493453592062, 33.88363301753998, 28.25770240277052, 33.25379401445389, 54.3545937538147, 68.54436233639717, 78.15900921821594, 76.21013179421425, 43.523358553647995, 5.074426308274269, 0.182149178290274, 0.17779241519747302, 0.2771042275708169, 0.24566092964960262, 0.22617759386776015, 0.10346096707507968, 0.223019800032489, 0.12461345235351473, 0.16508331435034052, 0.2198133955243975, 0.09948092556442134, 0.26949611550662667, 0.1398834673454985, 0.10796738424687646, 0.20260401506675407, 0.24693037325050682, 0.2583006693748757, 0.12252193919266574, 0.17076862568501383, 0.12200186436530203, 0.1535777692333795, 0.09121029084781185, 0.15383763966383412, 0.22291368775768206, 0.09393821790581569, 0.20085238327737898, 0.2722705010091886, 0.18545381346484646, 0.14477361197350547, 0.1516841645934619, 0.19058000558288768, 0.19282589288195595], [0.020708321026177146, 0.037345553864724934, 0.04649077993235551, 0.04627401343896054, 0.021911848925810773, 0.038706879058736376, 0.036469096012297086, 0.04351787363702897, 0.04129928995098453, 0.02907637561293086, 0.04983787708624732, 0.04650525181205012, 0.06329051713692024, 0.026634732021193486, 0.030211008088372182, 0.026554158903309144, 0.0503003278572578, 0.05118122375279199, 0.04278759290173184, 0.016981168191705365, 0.04484209515794646, 0.055413357986253686, 0.01615954577573575, 0.037936819207970984, 0.08653573269839399, 0.008822570871416247, 0.0490086643549148, 0.05045893965871073, 0.034557909893919714, 3.3763646380975842, 31.051966063678265, 62.78855659067631, 62.95245699584484, 62.44896501302719, 49.17360596358776, 35.8088681101799, 25.630014203488827, 15.577668808400631, 29.06535856425762, 48.821710646152496, 57.4691916257143, 36.714659705758095, 49.539799913764, 32.26558864116669, 7.400100063532591, 1.2028513429686427, 0.2835584484273568, 0.055998767784330994, 0.08768727129790932, 2.363525661639869, 2.744791740551591, 4.570038048550487, 6.382695632055402, 6.424027439206839, 8.332689721137285, 9.07244162634015, 15.310800578445196, 11.508659049868584, 8.034412376582623, 11.167814489454031, 13.860931377857924, 22.14850801974535, 12.776779253035784, 9.732450060546398, 13.25682744383812, 16.697966493666172, 27.517042346298695, 34.52496640384197, 45.72301112115383, 53.60738664865494, 60.74271596968174, 61.291919499635696, 64.43321093916893, 59.28152337670326, 67.11908921599388, 62.55077674984932, 64.06874969601631, 65.86684361100197, 65.25189220905304, 67.71143943071365, 67.14613616466522, 70.30234560370445, 67.33907461166382, 50.63169412314892, 40.85840195417404, 22.460760064423084, 45.059046149253845, 53.119686618447304, 51.74745865166187, 42.05178111791611, 30.031973496079445, 47.034734934568405, 55.69531001150608, 60.320186242461205, 60.764158219099045, 66.09191313385963, 65.59943675994873, 61.641356348991394, 59.26587201654911, 57.31667920947075, 62.80027896165848, 60.689005851745605, 66.32644414901733, 62.78690367937088, 58.06925542652607, 49.834652692079544, 43.44219110906124, 43.49388353526592, 31.592614352703094, 10.043554566800594, 14.164441041648388, 26.946493461728096, 11.976177413016558, 4.086136389523745, 12.503735404461622, 7.809049794450402, 8.299551699310541, 9.339549243450165, 3.1102022202685475, 5.055176066234708, 6.516465554013848, 8.745870050042868, 3.047489672899246, 3.2881452469155192, 0.31226457213051617, 0.2288582461187616, 0.036363139588502236, 0.12010970691335388, 0.2982784726191312, 4.411071203649044, 13.553496524691582, 26.10422495752573, 30.36543980240822, 32.01320618391037, 33.87392833828926, 31.124848052859306, 23.97753607481718, 23.39149732142687, 33.27411912381649, 41.3512697070837, 50.11290416121483, 55.37240333855152, 40.17328351736069, 11.09022930264473, 0.5245768732856959, 0.05468348172144033, 0.09049592918017879, 0.11347549298079684, 0.03749422830878757, 0.05674240717780776, 0.053661251222365536, 0.03397267450054642, 0.07848984998418018, 0.011105430112365866, 0.05963233023067005, 0.03010327051015338, 0.025875073370116297, 0.027133998883073218, 0.04895137426501606, 0.07040021766442806, 0.028586641637957655, 0.03436765662627295, 0.037261449979268946, 0.05698570173990447, 0.022805101580161136, 0.03558151707693469, 0.007955606943141902, 0.047067202322068624, 0.10026550924521871, 0.06942625273950398, 0.08156905780197121, 0.065401867905166, 0.10758001284557395, 0.02938895337138092, 0.20470231887884438, 0.026748052405309863, 0.024574526360083837, 0.03163710978697054, 0.05809690832393244, 0.07007214386248961, 0.03519640180456918, 0.04719715980172623, 0.059291576835676096, 0.007402827986879856, 0.039656416192883626, 0.023243911236932036, 0.038805432559456676, 0.03257444601331372, 0.03640530470875092, 0.031190273803076707, 0.041389000762137584, 0.03344253243994899, 0.017056067590601742, 0.0773637967358809, 0.0348925925209187, 0.02749674767983379, 0.013322818012966309, 0.0337408906489145, 0.01163645161796012, 0.0423726061853813, 0.01645638814807171, 0.03363497875398025, 0.048432624171255156, 0.06084385662688874, 0.06513692118460312, 4.9805086478590965, 36.059293672442436, 72.63801947236061, 75.3802715241909, 70.46895146369934, 60.44237248599529, 46.76644653081894, 36.63941994309425, 26.762239448726177, 30.84823999553919, 31.96991130709648, 48.80476735532284, 41.2055779248476, 55.55470235645771, 43.18150229752064, 10.195165481418371, 1.590455244295299, 0.24592636618763208, 0.3423284104792401, 1.2977969669736922, 4.358741361647844, 7.350230114534497, 7.784874066710472, 9.93228418752551, 9.261372238397598, 13.727248851209879, 12.59577976539731, 11.23570354655385, 13.923568166792393, 14.374017845839262, 11.057711597532034, 15.784273222088814, 18.329439349472523, 14.354287404567003, 10.054842811077833, 10.573729667812586, 14.79022566229105, 20.02148475497961, 33.74881625175476, 44.13498133420944, 54.59192521870136, 62.030584663152695, 64.66905668377876, 66.05970606207848, 63.537587597966194, 70.19212111830711, 63.8420994579792, 65.75886100530624, 66.37962609529495, 63.61817367374897, 66.60430803894997, 65.00089287757874, 70.9386670589447, 71.16432175040245, 55.61486452817917, 45.78794203698635, 29.522160552442074, 51.49120420217514, 57.689241617918015, 57.53621622920036, 49.23406831920147, 37.464568465948105, 52.8043719381094, 60.59776894748211, 63.58305215835571, 62.84847937524319, 66.84091374278069, 66.25886097550392, 64.74992394447327, 61.098418682813644, 61.57560087740421, 63.64039868116379, 63.96536484360695, 66.42874225974083, 64.34545084834099, 59.4391655176878, 49.94629070162773, 39.139336198568344, 30.328840166330338, 19.83562532812357, 10.115431509912014, 10.298923663794994, 18.390935249626637, 13.025056030601263, 8.121306113898754, 19.758719354867935, 17.07685176283121, 12.756532989442348, 10.465746112167835, 12.822663690894842, 11.492737904191017, 12.389254197478294, 10.868675541132689, 8.723226115107536, 7.171192746609449, 2.5005835946649313, 0.9636364260222763, 0.1319215734838508, 0.1404913901933469, 0.38308843737468123, 4.829255389049649, 14.753994606435299, 27.601069137454033, 33.67500901222229, 33.05191844701767, 35.95381133258343, 34.05820704996586, 29.2957990989089, 28.161710053682327, 38.169483840465546, 51.06922924518585, 57.699550464749336, 63.80416229367256, 48.179488107562065, 14.041795022785664, 0.7119109772611409, 0.04241137226927094, 0.04460986972844694, 0.09314740760601126, 0.06563116927281953, 0.05164029775187373, 0.06747437466401607, 0.06813474508817308, 0.028137427070760168, 0.03796015233092476, 0.06039515785232652, 0.046413726449827664, 0.02563017205829965, 0.07643303222721443, 0.04996851734176744, 0.006123549073890899, 0.03630050603533164, 0.03286363498773426, 0.02325050521903904, 0.03573045127268415, 0.011641486162261572, 0.09512219578027725, 0.006182260840432718, 0.027081547596026212, 0.11160999347339384, 0.04117424919968471, 0.07520428800489753, 0.01884379373223055, 0.051086607345496304, 0.012356708721199539, 0.136302768078167, 0.10146974775125273, 0.11142833798658103, 0.12769578461302444, 0.12319311528699473, 0.16565696481848136, 0.12795046000974253, 0.15254707454005256, 0.15800050925463438, 0.22624437231570482, 0.13493579142959788, 0.1243743249506224, 0.14664421003544703, 0.1699515656218864, 0.14183386112563312, 0.09985338721890002, 0.12577019340824336, 0.13539372623199597, 0.19626481225714087, 0.13614338444313034, 0.10592034057481214, 0.1437703619012609, 0.15648069471353665, 0.13146956101991236, 0.11163247312651947, 0.15669616986997426, 0.16215013893088326, 0.20583545963745564, 0.19917925586923957, 0.15423835488036275, 0.1680852720164694, 7.206645319238305, 47.902627363801, 84.07777681946754, 84.565070271492, 82.79944941401482, 67.93257996439934, 49.81065697968006, 39.60014887154102, 26.877992637455463, 41.06342755258083, 64.85769376158714, 70.20665913820267, 47.141178622841835, 65.51085591316223, 42.2700984030962, 9.762607142329216, 2.1951578836888075, 0.44673528929706663, 0.27490527369081974, 1.2355304206721485, 5.832334589213133, 10.962377563118935, 12.483333349227905, 16.138161532580853, 16.66417870670557, 23.178330659866333, 19.708563946187496, 26.576239429414272, 23.749124631285667, 21.211054623126984, 22.293930016458035, 23.486171141266823, 35.48330157995224, 20.37141937762499, 15.65183037891984, 20.22304493933916, 23.92261002212763, 31.894321963191032, 41.681297197937965, 52.041684463620186, 57.90733851492405, 64.28055793046951, 64.11146700382233, 67.35827878117561, 63.37832674384117, 70.00593110918999, 64.15975481271744, 63.861592411994934, 66.02583467960358, 65.35207003355026, 67.39023506641388, 68.2595220208168, 68.75245437026024, 74.60431516170502, 60.1392475515604, 51.364689990878105, 36.98792964220047, 57.18806371092796, 63.33931803703308, 61.2084835767746, 54.805268570780754, 42.8815083950758, 57.81342275440693, 62.37829640507698, 61.862709671258926, 62.09469482302666, 69.19525980949402, 70.46335056424141, 67.58355349302292, 64.30958077311516, 62.50417225062847, 66.49883329868317, 66.9785575568676, 70.38844898343086, 66.11266002058983, 62.51017972826958, 54.92818057537079, 49.696712493896484, 46.89196899533272, 35.37604473531246, 20.122454836964607, 21.71823240816593, 38.31856124103069, 20.480389930307865, 13.386045210063457, 20.313037410378456, 17.175450772047043, 17.687023021280766, 19.900537244975567, 16.028598211705685, 15.891556665301323, 17.71981906145811, 23.500538170337677, 10.851284824311733, 8.447917588055134, 2.4256005557253957, 0.9650821296963841, 0.20818606397369877, 0.5027224647346884, 0.5785666918382049, 5.8038475178182125, 17.787539027631283, 35.96974767744541, 43.369295820593834, 44.164224565029144, 48.199254646897316, 46.52354836463928, 37.74118222296238, 34.371678829193115, 45.62872298061848, 57.41832375526428, 66.70383989810944, 74.42446321249008, 58.14137555658817, 19.294006191194057, 1.1291814898140728, 0.20183526881737635, 0.23605868162121624, 0.37294891895726323, 0.1665717360447161, 0.2285863974248059, 0.15820277418242767, 0.1504123312770389, 0.13204267714172602, 0.09630583968828432, 0.14725556160556152, 0.12537462869659066, 0.15243417903548107, 0.09161890993709676, 0.20053404645295814, 0.2201289270306006, 0.1631986303254962, 0.1446667278651148, 0.20523601211607456, 0.1262384737492539, 0.12602942559169605, 0.20389670273289084, 0.10690870316466317, 0.0913955457508564, 0.21824687020853162, 0.19463242875644937, 0.37775818433146924, 0.17019720165990293, 0.17408770305337384, 0.13182519818656147, 0.29035156359896064, 0.19242117006797343], [0.05224015716521535, 0.029393146505753975, 0.013748912824667059, 0.04238383116899058, 0.04097330900549423, 0.03932587103918195, 0.027266321958450135, 0.007953410186019028, 0.017448598773626145, 0.06687877888907678, 0.04434084490640089, 0.027667948161251843, 0.01146576785686193, 0.0334751312766457, 0.06968517322093248, 0.04226439734338783, 0.04628161674190778, 0.03075355700275395, 0.01609169863513671, 0.06138354270660784, 0.020271620924177114, 0.03663110313937068, 0.016088414631667547, 0.068296503595775, 0.05674426625773776, 0.06084576394641772, 0.030056294417590834, 0.08035903796553612, 0.34801575529854745, 13.566587772220373, 47.77461603283882, 59.35929760336876, 54.261054173111916, 46.33507467806339, 35.309092327952385, 30.807103402912617, 33.88650946319103, 32.21136935055256, 74.47277382016182, 75.10039374232292, 52.325985208153725, 64.82586666941643, 36.17934063076973, 10.611604135483503, 2.440558928065002, 0.43961378862150013, 0.07332262452109717, 0.33401166612748057, 0.5107462091837078, 3.2119116000831127, 5.028306283056736, 6.294907042756677, 6.936517339199781, 5.217024581506848, 11.59154400229454, 6.564261764287949, 12.685285862535238, 12.630399707704782, 13.46236601471901, 20.829925574362278, 20.558190755546093, 26.51046495884657, 21.64470825344324, 20.323190465569496, 30.06791766732931, 32.7653644233942, 41.753603518009186, 53.99637557566166, 61.16781435906887, 60.830160677433014, 66.1856997013092, 60.44146053493023, 63.27955864369869, 64.90318492054939, 63.026773408055305, 61.178769171237946, 62.22842484712601, 64.19978946447372, 63.744482696056366, 66.68824553489685, 67.58635774254799, 68.16823571920395, 66.9381657242775, 56.991872638463974, 42.96516090631485, 31.995157152414322, 40.765458941459656, 52.11028978228569, 50.10890677571297, 38.25684495270252, 32.327852100133896, 51.332669109106064, 56.57323770225048, 56.81827135384083, 65.32458990812302, 65.47863364219666, 62.61915408074856, 59.67582441866398, 56.164394840598106, 56.22043423354626, 60.53376518189907, 62.25945398211479, 65.71331664919853, 64.3777871131897, 66.69227331876755, 59.52010877430439, 53.72707262635231, 47.62497626245022, 47.11128182709217, 26.9778398796916, 26.098673455417156, 27.189940698444843, 25.36464024335146, 9.211301375180483, 16.976122967898846, 19.956650733947754, 12.042184621095657, 16.18880331516266, 6.8109312281012535, 10.091673284769058, 8.689533323049545, 3.136838315986097, 9.923153277486563, 3.602149710059166, 2.9257057327777147, 0.49331785063259304, 0.07779091756674461, 0.04956588367349468, 0.008529865972377593, 0.36947920045349747, 2.6113706873729825, 14.343108404427767, 27.17329379171133, 47.97056771814823, 39.13182020187378, 25.946943797171116, 19.990429021418095, 22.853220105171204, 26.967297345399857, 31.91376931965351, 46.66101738810539, 59.299268424510956, 47.37778812646866, 26.81257914751768, 4.808637220412493, 0.08044821443036199, 0.08467856008792296, 0.09683931770268828, 0.06483437726274133, 0.031868051300989464, 0.07595272167236544, 0.03330242238007486, 0.046240052761277184, 0.026822484251169953, 0.04891345422947779, 0.01189649738080334, 0.07042769939289428, 0.0030227051001929794, 0.028386285885062534, 0.022548264678334817, 0.009650774281908525, 0.08562720293411985, 0.0754756097740028, 0.03994633618276566, 0.03713401580171194, 0.08646298738312908, 0.020217134297126904, 0.03228190624213312, 0.05437230662209913, 0.09192738361889496, 0.07591275701997802, 0.010415755987196462, 0.028817748279834632, 0.05283012375002727, 0.050803422345779836, 0.0899305462371558, 0.014044594663573662, 0.04134529568545986, 0.04314008336223196, 0.045286522872629575, 0.06715896190144122, 0.006028242005413631, 0.05365125078242272, 0.03129060845822096, 0.06272108206758276, 0.01788412257155869, 0.025475172660662793, 0.02400772034889087, 0.09852431205217727, 0.07074245164403692, 0.013047681604803074, 0.02390983107034117, 0.011081558004661929, 0.01615273842617171, 0.040325017034774646, 0.06078661848732736, 0.12626566604012623, 0.0721152541518677, 0.018438864972267766, 0.03521723017911427, 0.022650783103017602, 0.07133464838261716, 0.06865606672363356, 0.041954561820602976, 0.6237165222410113, 15.378677286207676, 56.92317992448807, 71.15155443549156, 64.98871073126793, 61.37585699558258, 46.87534488737583, 42.02068738639355, 37.14184418320656, 25.99810805171728, 48.85840147733688, 67.1931092441082, 58.1305917352438, 67.36156940460205, 48.08832719922066, 13.28302038833499, 2.3815279081463814, 0.3617960127303377, 0.30140490329358727, 0.6569059600587934, 3.0242370581254363, 6.351799489930272, 9.992910884320736, 11.117262002080679, 14.750388599932194, 14.94423234835267, 16.94038398563862, 12.22440954297781, 16.580094918608665, 15.019897688180208, 15.233080498874187, 12.611455824226141, 12.03168673440814, 16.219746954739094, 13.460577260702848, 19.288215301930904, 22.547131329774857, 28.456752821803093, 40.86921997368336, 53.594471141695976, 62.83351197838783, 63.7490576505661, 68.92083093523979, 64.49314132332802, 64.05797347426414, 65.3041622042656, 63.49912226200104, 63.31681564450264, 62.77249485254288, 65.42141631245613, 61.96909636259079, 65.2802462875843, 65.13580843806267, 68.62110301852226, 68.63664418458939, 60.87469048798084, 49.199205189943314, 39.73302014172077, 49.16211538016796, 55.252318382263184, 55.55154852569103, 44.95219208300114, 40.03124713897705, 58.58886994421482, 59.55059453845024, 58.86066935956478, 65.58185130357742, 66.10576719045639, 64.08099263906479, 61.99315667152405, 59.16455805301666, 59.0938438475132, 62.89251521229744, 65.72671473026276, 68.51245164871216, 66.35504141449928, 65.27359664440155, 59.345591738820076, 56.52473330497742, 47.75888867676258, 38.74109476804733, 25.699635967612267, 16.146893464028835, 17.542511075735092, 13.629455398768187, 9.778133109211922, 16.833528019487858, 13.14696203917265, 16.498066820204258, 12.804884444922209, 12.12156806141138, 12.609788663685322, 13.421737644821405, 14.565493371337652, 12.197035811841488, 9.04061833396554, 5.4122011084109545, 3.149853805080056, 0.7482062140479684, 0.05018908734200522, 0.04602688939485233, 0.45068758190609515, 3.0391702568158507, 14.226786196231842, 28.934163004159927, 42.903269827365875, 35.49759641289711, 30.095815770328045, 27.953374832868576, 26.85310587286949, 36.06550633907318, 38.81508819758892, 52.3933631926775, 65.01442775130272, 57.10732564330101, 32.175883054733276, 5.971618015319109, 0.04107870510779321, 0.058241786682629026, 0.01624115975573659, 0.035600389892351814, 0.06343608198221773, 0.048002660914789885, 0.00836294768305379, 0.024860442463250365, 0.05277832555293571, 0.04434510483406484, 0.03195037774275988, 0.053025642555439845, 0.012681592215812998, 0.042417276054038666, 0.04744735262647737, 0.03902115633536596, 0.04764020712173078, 0.04945295106153935, 0.05275780145893805, 0.015045830732560717, 0.060872637113789096, 0.016225665567617398, 0.01960557492566295, 0.018910577746282797, 0.03071256447583437, 0.03891550419211853, 0.044412759016267955, 0.07925227313535288, 0.04940239967254456, 0.017754463806340937, 0.03423882350034546, 0.1869044004706666, 0.17434702429454774, 0.21406394778750837, 0.1514151063747704, 0.18488405185053125, 0.1448405091650784, 0.1720822270726785, 0.10607728254399262, 0.13122370233759284, 0.10072603414300829, 0.12787231185939163, 0.15616594988387078, 0.17697311384836212, 0.1501020393334329, 0.17986324470257387, 0.20044917444465682, 0.25582578498870134, 0.1463367382530123, 0.15299746912205592, 0.11450279605924152, 0.13348032109206542, 0.13429997867206112, 0.19516388070769608, 0.21297132829204202, 0.1720907469280064, 0.20958994020475075, 0.15586658235406503, 0.20172503020148724, 1.086496717762202, 20.40552444756031, 69.47272852063179, 81.6714495420456, 73.19814741611481, 65.53031086921692, 52.386603355407715, 43.87960083782673, 49.157289639115334, 47.49219238758087, 88.33306208252907, 83.16245153546333, 62.61468932032585, 77.50169768929482, 46.811401918530464, 14.073506221175194, 3.5867289500311017, 0.4874724877299741, 0.41508420486934483, 0.9114991861861199, 2.2192338667809963, 11.632210370153189, 13.294197488576174, 16.132486537098885, 20.56635081768036, 18.973016515374184, 27.970259226858616, 17.45674017816782, 24.563046656548977, 23.250638879835606, 22.619658038020134, 29.381478801369667, 30.761372856795788, 36.53790459036827, 31.524495407938957, 32.58976064622402, 33.91609847545624, 37.415345907211304, 45.50607696175575, 59.87670063972473, 65.15806764364243, 66.96889847517014, 69.64894786477089, 65.26333719491959, 66.17398113012314, 66.94672286510468, 63.83799567818642, 61.92623846232891, 61.970061510801315, 63.059607446193695, 63.420227095484734, 65.91152161359787, 68.90928715467453, 68.08027043938637, 70.28593808412552, 65.3850294649601, 53.40458773076534, 46.88330166041851, 55.25354951620102, 62.22209818661213, 60.94084873795509, 50.15141889452934, 48.00343215465546, 60.35571813583374, 60.83307132124901, 59.99618522822857, 66.0731953382492, 71.36412262916565, 69.03442963957787, 65.9097509086132, 59.7454708814621, 60.51297649741173, 64.84253257513046, 67.71694913506508, 70.54348826408386, 69.2868272960186, 70.31880632042885, 61.24898940324783, 61.50894485414028, 53.977198004722595, 51.5734887868166, 32.230641916394234, 31.589553616940975, 33.035279139876366, 35.36222107708454, 17.49090414494276, 27.955500818789005, 37.0063928514719, 25.141366124153137, 26.430566646158695, 17.05357801169157, 24.121987223625183, 19.731662906706333, 16.71945434063673, 20.508360229432583, 11.742165070027113, 7.7810348477214575, 2.9121549474075437, 0.572945368476212, 0.10525310528464615, 0.12245229605468921, 0.7121478114277124, 3.630157532170415, 17.44628693908453, 36.30094550549984, 62.59855918586254, 53.35506498813629, 39.665406569838524, 33.21668140590191, 35.88786967098713, 43.981051594018936, 46.33695937693119, 64.37771111726761, 74.35194790363312, 66.44087880849838, 41.40661373734474, 7.8837338369339705, 0.2480574877699837, 0.20044500357471406, 0.18880082527175546, 0.130556081130635, 0.14442771178437397, 0.16994853765936568, 0.10705709559260868, 0.13029465219005942, 0.1311618962790817, 0.18424791254801676, 0.1504199011833407, 0.1797270606039092, 0.1513617014279589, 0.22343552147503942, 0.18657537671970204, 0.10154339106520638, 0.2355075627565384, 0.16403586196247488, 0.11320365170831792, 0.10773422371130437, 0.2887947455747053, 0.12580301117850468, 0.08897104577044956, 0.1411805336829275, 0.25067139125894755, 0.21509063488338143, 0.1532728801248595, 0.22968318779021502, 0.143995292019099, 0.19965958868851885, 0.2084999775979668], [0.08810287399683148, 0.09143456787569448, 0.026236890771542676, 0.02215183907537721, 0.12177239230368286, 0.05128356220666319, 0.02384452207479626, 0.01102700272895163, 0.0656955357408151, 0.06612155819311738, 0.03585808583011385, 0.011719805934262695, 0.016458725913253147, 0.03812700197158847, 0.05260314901534002, 0.035077465217909776, 0.053746215999126434, 0.06083706597564742, 0.04333785087510478, 0.0083788584015565, 0.013866456956748152, 0.09297266893554479, 0.057503286661813036, 0.030721759685548022, 0.0749637876288034, 0.04677887794969138, 0.03329603248857893, 0.024098555513774045, 1.37999736238271, 29.967648647725582, 58.64901691675186, 57.793105244636536, 44.74991373717785, 29.09782212227583, 30.224693454802036, 28.758310340344906, 52.81004883348942, 70.34381657838821, 78.63320857286453, 67.15172946453094, 67.54854217171669, 35.08800119161606, 12.959854379296303, 5.667563080787659, 0.7206072856206447, 0.21998171461746097, 0.4216319660190493, 1.0618802136741579, 4.5348818600177765, 3.7762950779870152, 8.168726619333029, 7.929575052112341, 9.601520486176014, 11.063917614519596, 12.635261546820402, 13.546328209340572, 9.453185945749283, 11.262664049863815, 16.90007384866476, 6.854630783200264, 17.447447776794434, 31.150827258825302, 34.022154584527016, 43.33888225257397, 46.59866653382778, 52.48008593916893, 62.092806324362755, 63.62988084554672, 65.4769541323185, 61.684404239058495, 60.6757977604866, 60.554436072707176, 62.706051617860794, 65.75484842061996, 61.94291576743126, 59.034715220332146, 63.370183780789375, 63.84886309504509, 61.815535202622414, 63.91718342900276, 64.79281604290009, 65.41730493307114, 63.15132312476635, 60.002166107296944, 53.44012342393398, 36.275464072823524, 35.71493335068226, 50.0627126544714, 48.13320279121399, 35.26419013738632, 37.899151146411896, 54.7897882014513, 56.38912998139858, 56.804489493370056, 64.26294967532158, 64.88603264093399, 62.45035193860531, 56.13730989396572, 52.8692040592432, 56.91897355020046, 61.45148813724518, 61.11086681485176, 65.52176132798195, 67.23997592926025, 64.23591032624245, 67.95480117201805, 63.95067483186722, 61.49845361709595, 50.71712113916874, 44.825415685772896, 35.491110160946846, 38.02907757461071, 26.963180266320705, 17.391883358359337, 38.73761795461178, 18.98687057197094, 14.55470385029912, 6.386004779487848, 15.056799408048391, 9.1654815338552, 12.666531018912792, 11.081856451928616, 9.216640088707209, 9.975131638348103, 4.060122035443783, 3.052779701538384, 0.24040198215516284, 0.19147316546877846, 0.0669835256121587, 0.05279958808387164, 0.39021373784635216, 1.7210949654690921, 12.463695053011179, 33.22390101850033, 39.62896652519703, 33.326183930039406, 20.72887759655714, 13.845925983041525, 19.76153690367937, 32.30976887047291, 35.67391075193882, 43.90477068722248, 57.920626401901245, 41.805706322193146, 13.88012794777751, 1.010533687658608, 0.06897205093991943, 0.06838420318672433, 0.02205198681622278, 0.04224260788760148, 0.017810841054597404, 0.023509095444751438, 0.01677168587775668, 0.02062703359115403, 0.034848349387175404, 0.05552993454330135, 0.06597821236937307, 0.06370966730173677, 0.04600170461344533, 0.05310458109306637, 0.0316342636506306, 0.01799709971237462, 0.02852833851648029, 0.023410081812471617, 0.03133640639134683, 0.03813478338997811, 0.054145239118952304, 0.014501808655040804, 0.02659938167198561, 0.07763099958538078, 0.06034722624463029, 0.07640351701411419, 0.06536663815495558, 0.03927062556613237, 0.03470252479019109, 0.07254201133036986, 0.03846676831017248, 0.043997289903927594, 0.010268544501741417, 0.07282969745574519, 0.09001082435133867, 0.029467914173437748, 0.03678281667816918, 0.07253162868437357, 0.05256470576568972, 0.01796240987459896, 0.025724586230353452, 0.020321997908467893, 0.07415834959829226, 0.019542037807696033, 0.06288817661697976, 0.06961377861443907, 0.03353751249960624, 0.04881498607574031, 0.02320088151464006, 0.0569963626912795, 0.010424070824228693, 0.06377396697644144, 0.04618652164936066, 0.09119870592257939, 0.011257639962423127, 0.0494746291951742, 0.07679259535507299, 0.04594087447912898, 2.600204274058342, 36.59300543367863, 69.58870589733124, 67.54119336605072, 57.014245837926865, 39.04524564743042, 40.073630064725876, 36.05368137359619, 54.754803478717804, 58.622273951768875, 75.38971781730652, 76.44850820302963, 79.89010512828827, 52.86612242460251, 17.74048425257206, 5.248344400897622, 0.669354151468724, 0.26309069828130305, 0.6209090072661638, 3.7432608380913734, 6.2051435094326735, 11.002633552998304, 8.151455596089363, 11.618961431086063, 15.13632819056511, 15.458359960466623, 15.49587344750762, 17.81983159482479, 11.825128868222237, 16.652213148772717, 15.148605331778526, 11.404559835791588, 13.276634830981493, 25.990284271538258, 32.990369349718094, 32.42229603230953, 43.299778550863266, 50.88978007435799, 61.73832714557648, 64.5842832326889, 68.54195326566696, 62.632742151618004, 62.45971843600273, 63.974271565675735, 66.18385300040245, 67.6435598731041, 64.15872126817703, 60.206583738327026, 62.324859872460365, 64.13868874311447, 61.32177069783211, 62.30369880795479, 64.66416254639626, 64.34508606791496, 65.03120765089989, 63.20957399904728, 58.78693051636219, 42.009588181972504, 43.50455716252327, 56.07968978583813, 53.328595608472824, 42.95941561460495, 44.00143750011921, 61.37504003942013, 59.26324635744095, 58.04554469883442, 65.9339252114296, 64.85218405723572, 63.535075932741165, 57.53726117312908, 55.643408596515656, 59.022289887070656, 64.40303295850754, 64.92409899830818, 67.28235885500908, 68.48415076732635, 65.2494603395462, 68.09626758098602, 64.36582535505295, 61.097210347652435, 49.87982086837292, 43.10719348490238, 33.66223029792309, 29.29204300045967, 23.635372035205364, 18.59616033732891, 20.16682505607605, 13.421988431364298, 11.013969294726849, 6.440362287685275, 12.97404756769538, 11.836460810154676, 11.145631279796362, 14.801045581698418, 11.412544157356024, 6.943360297009349, 8.525958750396967, 6.545393401756883, 2.7000895142555237, 0.565192240756005, 0.07662707415875047, 0.06338093298836611, 0.41717281623277813, 1.8894144147634506, 14.277141094207764, 36.08599103987217, 39.75164674222469, 34.37268577516079, 20.960237681865692, 20.113569013774395, 23.25168952345848, 37.2783974558115, 45.02300888299942, 53.661552742123604, 67.80267253518105, 50.12640483677387, 18.684615790843964, 1.5442880778573453, 0.03909062877937686, 0.007331188935495447, 0.05104611576825846, 0.036672514979727566, 0.05894442983844783, 0.03696444247907493, 0.03124988310446497, 0.03454074772889726, 0.053621141851181164, 0.009640744156058645, 0.017146364698419347, 0.04580905420880299, 0.013809280044370098, 0.07939735558466054, 0.03209378293831833, 0.05143734633747954, 0.022838117874925956, 0.02242572867544368, 0.02204389555117814, 0.08630376702058129, 0.01796076601749519, 0.06965824810322374, 0.019931192218791693, 0.042996822885470465, 0.024370311439270154, 0.12572196865221485, 0.03842770907795057, 0.051618278230307624, 0.01987722880585352, 0.0157328535351553, 0.14200685574905947, 0.1651368974125944, 0.20270408625947312, 0.15946031373459846, 0.2718486642697826, 0.21015009842813015, 0.1146435592090711, 0.16411332733696327, 0.2304340185946785, 0.1871619702433236, 0.1943087633117102, 0.08972793249995448, 0.14127953618299216, 0.18253291316796094, 0.2671593299601227, 0.14524480153340846, 0.2768303453922272, 0.08419468722422607, 0.1456422364572063, 0.10997929464792833, 0.12965756293851882, 0.18095984210958704, 0.1801891514332965, 0.13117161841364577, 0.12180881691165268, 0.22546673513716087, 0.23875947576016188, 0.24267740693176165, 4.360259855166078, 47.288644909858704, 81.7863629758358, 79.92252498865128, 65.44418469071388, 45.53147479891777, 44.71768006682396, 42.45900146663189, 66.84973686933517, 82.53122180700302, 87.1833273768425, 76.88014224171638, 78.07042837142944, 46.05395816266537, 18.38945332914591, 7.831759750843048, 0.9807247621938586, 0.45648767380043864, 0.7586807676125318, 3.180473749525845, 13.410364855080843, 14.014892466366291, 21.530471183359623, 20.73914084583521, 21.508510261774063, 22.969225980341434, 20.893792547285557, 19.88432541489601, 22.235776036977768, 21.184226162731647, 30.70245511829853, 18.267054297029972, 25.199459306895733, 44.45123456418514, 42.886847108602524, 46.40979386866093, 49.575244411826134, 54.83904115855694, 67.17483222484589, 65.12372508645058, 70.32021224498749, 63.48879061639309, 64.0671081840992, 63.95227074623108, 67.90848925709724, 68.5776561498642, 65.48024475574493, 60.40586784482002, 62.63503722846508, 64.75071430206299, 62.92639039456844, 63.75092715024948, 66.41874119639397, 65.85784569382668, 66.62492573261261, 66.63045063614845, 62.23895028233528, 50.544883981347084, 50.35629630088806, 60.756646022200584, 59.586947187781334, 48.295210897922516, 51.95172809064388, 61.959239691495895, 61.039704233407974, 59.78588551282883, 66.10822945833206, 70.09920090436935, 66.77173465490341, 60.39317272603512, 58.2014275342226, 61.329271495342255, 65.29346957802773, 65.32710537314415, 68.38426172733307, 70.6040646135807, 67.63659864664078, 72.13544324040413, 65.48934906721115, 66.96324437856674, 52.74986766278744, 49.55251403152943, 42.69665591418743, 41.5510667860508, 30.357975102961063, 23.476738147437572, 49.88747365772724, 26.9747943431139, 30.86717437952757, 15.721292551606894, 25.06204728037119, 20.142405666410923, 18.502343371510506, 19.013887122273445, 18.722357265651226, 21.480986438691616, 11.572341732680798, 8.817639648914337, 2.334595201537013, 0.5527295032516122, 0.27288648358080536, 0.16722999134799466, 0.7576476980466396, 2.4051583651453257, 17.058616541326046, 41.547806560993195, 54.13710102438927, 46.88385643064976, 32.365504279732704, 24.65571988373995, 31.110802106559277, 44.59544822573662, 51.39747843146324, 60.20189858973026, 76.25680088996887, 61.548892110586166, 24.093158170580864, 2.665748381987214, 0.14045054238522425, 0.20324132696259767, 0.17204295261763036, 0.15970675129210576, 0.09436882683075964, 0.10095606281538494, 0.11119073198642582, 0.23882787209004164, 0.17442797776311636, 0.11026822758140042, 0.19130898755975068, 0.20958287495886907, 0.1613592024659738, 0.20440712221898139, 0.11284918713499792, 0.12282630137633532, 0.13001058774534613, 0.08793550485279411, 0.08997028824524023, 0.17456552741350606, 0.12418268757755868, 0.1548004278447479, 0.10854867141461, 0.12003134354017675, 0.17475318687502295, 0.17423408426111564, 0.12356376610114239, 0.1837406842969358, 0.2413417786010541, 0.10982651612721384], [0.1767663366626948, 0.08150802357704379, 0.11131214734632522, 0.05788831658719573, 0.0657685259648133, 0.04610037685779389, 0.013165035561542027, 0.027137206816405524, 0.05109285993967205, 0.02510264421289321, 0.051946014355053194, 0.034423621982568875, 0.061111527029424906, 0.04344160312029999, 0.07679272152017802, 0.00850053073008894, 0.0032155004555534106, 0.06063347631425131, 0.05183380162634421, 0.043821126309921965, 0.013414532622846309, 0.009636116865294753, 0.055597232494619675, 0.048699548715376295, 0.007076482925185701, 0.09292892675148323, 0.08963921616668813, 0.13692817592527717, 7.464389763772488, 39.51205059885979, 52.27941870689392, 55.84583893418312, 40.5364528298378, 31.395606324076653, 18.007526323199272, 31.82676538825035, 49.95351031422615, 64.46810826659203, 72.2386609017849, 56.24419815838337, 28.35454400628805, 16.74415111541748, 9.610123224556446, 0.5579022725578398, 0.02535974457714474, 0.05561574907915201, 0.5801601719576865, 1.858553420752287, 3.9468674501404166, 4.329993054270744, 6.5947693772614, 11.464398074895144, 16.790143847465515, 21.351962462067604, 17.25540418177843, 16.93943403661251, 15.402637850493193, 20.676729194819927, 22.097577452659607, 27.16780498623848, 30.90910892933607, 39.985459595918655, 43.769836127758026, 48.743058666586876, 55.89731477200985, 60.7515998929739, 67.60397359728813, 64.45820599794388, 63.25440399348736, 59.41375248134136, 60.04512280225754, 59.89252299070358, 61.57836712896824, 66.62764638662338, 60.886002480983734, 62.53319889307022, 59.65857334434986, 62.14185789227486, 63.27961944043636, 65.10569885373116, 63.61996337771416, 62.96984486281872, 61.886169612407684, 60.676888301968575, 62.0485083013773, 42.79072366654873, 32.2703991830349, 50.76379403471947, 40.27123846113682, 37.56185844540596, 45.432178527116776, 57.07592032849789, 55.932880863547325, 54.00727339088917, 63.974210768938065, 63.10037165880203, 60.66828936338425, 51.009154468774796, 53.733448684215546, 59.90457594394684, 62.230704724788666, 61.10437296330929, 61.349003836512566, 63.19346286356449, 64.18152004480362, 61.40603117644787, 59.05291624367237, 61.6482225805521, 64.30154800415039, 59.1252301633358, 45.772191882133484, 44.098651483654976, 40.70665329694748, 41.07908271253109, 34.178102016448975, 21.42859674990177, 20.198602750897408, 10.763197001069784, 8.627150170505047, 7.861235244199634, 13.659275248646736, 15.97198884934187, 11.213422492146492, 5.973415318876505, 6.313208760693669, 6.114506497979164, 3.3137076627463102, 0.6945811759214848, 0.046915173370507546, 0.05084927222924307, 0.07115323038306087, 0.79587139072828, 3.6503710225224495, 14.725026860833168, 36.845551282167435, 47.25864551961422, 37.435576021671295, 41.057138890028, 68.16413193941116, 54.16175790131092, 34.03416953980923, 40.32665468752384, 46.66348345577717, 54.65377449989319, 31.248056441545486, 6.877688895910978, 0.28429741971194744, 0.04212848041788675, 0.01923418381920783, 0.028239617095096037, 0.03637984162196517, 0.02891211235692026, 0.03783898187975865, 0.03162104600050952, 0.06101964914705604, 0.07692992978263646, 0.06283018519752659, 0.03194589517079294, 0.010544486140133813, 0.04311488002713304, 0.018419587686366867, 0.049194349703611806, 0.03911577274266165, 0.029222717857919633, 0.07422476439387538, 0.03846478306513745, 0.07025503873592243, 0.02343465432204539, 0.03112973310635425, 0.03814845003944356, 0.03846792606054805, 0.06845815078122541, 0.04409834073157981, 0.04561910893244203, 0.029166168060328346, 0.09339364478364587, 0.03907442769559566, 0.02874922392948065, 0.05486922644195147, 0.011203813846805133, 0.023439725046046078, 0.039330836007138714, 0.02139446252840571, 0.03941548908187542, 0.057512593193678185, 0.04459310832316987, 0.10570931830443442, 0.05354927598091308, 0.08651079653645866, 0.048011440521804616, 0.013794887017866131, 0.01768181497027399, 0.028959752671653405, 0.055830868004704826, 0.015514702008658787, 0.07127011864213273, 0.03347242614836432, 0.016913449071580544, 0.04597502440446988, 0.01271171784537728, 0.022023558849468827, 0.057637036516098306, 0.050125800698879175, 0.07953713909955695, 9.560815170407295, 47.58993834257126, 64.49289053678513, 65.39179310202599, 50.85736781358719, 37.448499128222466, 24.838349483907223, 32.17373996973038, 52.06455923616886, 72.51764953136444, 80.20584538578987, 70.89897438883781, 42.148060351610184, 17.63916078954935, 7.450596503913403, 0.9520423575304449, 0.02468626782501815, 0.2155727191711776, 1.8486547144129872, 7.078308630734682, 8.372830767184496, 9.576837960630655, 10.747909471392632, 12.990969009697437, 17.979626320302486, 16.267117112874985, 18.940288871526718, 20.227602794766426, 12.174332030117512, 12.11287222802639, 20.17919149249792, 19.491867274045944, 26.101603098213673, 35.856840535998344, 42.09268972277641, 48.22567082941532, 55.07749356329441, 58.496664091944695, 69.51176762580872, 66.21401578187943, 66.33487969636917, 62.07980342209339, 64.74388226866722, 62.70935744047165, 64.7650395333767, 66.12165793776512, 61.603548377752304, 62.639680579304695, 60.506277456879616, 61.95749178528786, 63.05278301239014, 63.88689145445824, 64.72164586186409, 62.58500151336193, 63.25887255370617, 62.48427651822567, 67.60161012411118, 48.690131306648254, 40.933831706643105, 55.38188382983208, 46.551393270492554, 44.41821813583374, 51.143731847405434, 61.04836396872997, 59.59844537079334, 56.410116255283356, 66.09935313463211, 65.68592011928558, 63.832189589738846, 53.235246017575264, 55.9729041159153, 62.06526920199394, 64.7746454179287, 62.02149175107479, 62.16725952923298, 64.59845647215843, 64.76189330220222, 63.40207166969776, 62.64276221394539, 63.17514404654503, 65.05978211760521, 57.22381219267845, 48.22537064552307, 41.97573579847813, 32.96999864280224, 31.177209243178368, 25.20863961428404, 16.218274533748627, 13.4742128290236, 9.148254208266735, 10.140921492129564, 13.137547094374895, 10.595873929560184, 15.473601892590523, 13.453965615481138, 11.946226470172405, 7.433283207938075, 8.876443393528461, 8.262014463543892, 2.523869457654655, 0.018798580240400042, 0.06767439830582589, 0.03762053442187607, 0.4826082440558821, 3.7106659496203065, 16.20772060006857, 35.95615200698376, 42.54020690917969, 33.1331504881382, 24.91403192281723, 56.373250633478165, 59.32723492383957, 42.483969926834106, 45.76635159552097, 53.436369225382805, 64.05421167612076, 40.427493676543236, 8.703812006860971, 0.1620682651991956, 0.07139925975934602, 0.03985659197496716, 0.025243114214390516, 0.029700855775445234, 0.030814132951491047, 0.042621452012099326, 0.08708118897629902, 0.02495658027328318, 0.058868790147244, 0.029037212480034214, 0.029373158613452688, 0.05776830388640519, 0.003014816302311374, 0.019599049592216033, 0.0565285387710901, 0.047234990779543296, 0.022312363762466703, 0.028286767592362594, 0.033426012232666835, 0.07068333958159201, 0.04028000206744764, 0.07616066402988508, 0.014886566768836929, 0.06455370443291031, 0.07508911410695873, 0.06841028967755847, 0.06563607486896217, 0.010494440339243738, 0.033148849761346355, 0.26976895867846906, 0.1620059841661714, 0.21315373334800825, 0.12973709148354828, 0.14025148353539407, 0.20624324009986594, 0.10170615889364854, 0.13646752486238256, 0.1484921429073438, 0.19616637378931046, 0.1860892996774055, 0.10353878125897609, 0.14540068223141134, 0.14170379232382402, 0.14064752322155982, 0.11743436101824045, 0.13862193503882736, 0.16496755415573716, 0.21351211646106094, 0.1528645059443079, 0.0910832203226164, 0.09747598393005319, 0.14144028536975384, 0.06984247142099775, 0.09595176103175618, 0.14208216889528558, 0.19115704024443403, 0.27423965628258884, 14.117988534271717, 58.97965617477894, 76.20463728904724, 75.79875066876411, 61.06164425611496, 44.80583533644676, 31.538961231708527, 44.3508667498827, 62.18163415789604, 74.2055569589138, 81.12055510282516, 67.38209590315819, 39.62299704551697, 24.060738310217857, 12.285473216325045, 0.8535161975305527, 0.19765837263548747, 0.2686734596500173, 2.7230379078537226, 8.146012388169765, 14.752252399921417, 12.862425707280636, 17.30599656701088, 23.478430956602097, 27.994672916829586, 28.35677068680525, 25.119200013577938, 29.690571315586567, 29.726713076233864, 35.32845228910446, 32.98756889998913, 37.322950065135956, 35.96607707440853, 49.648607075214386, 52.015211284160614, 51.57523289322853, 58.11528615653515, 62.461223155260086, 69.95860084891319, 67.83814743161201, 66.21207788586617, 64.45715725421906, 66.30190506577492, 64.23093259334564, 65.79809010028839, 66.22571915388107, 62.022593691945076, 63.29475402832031, 60.35325966775417, 63.6175961047411, 64.32905092835426, 65.2068418264389, 65.645292699337, 63.78134071826935, 64.85297441482544, 65.6499132514, 70.06049618124962, 56.156624257564545, 46.66225992143154, 61.532005816698074, 49.954878240823746, 51.609564051032066, 57.127456963062286, 63.163151890039444, 61.336441710591316, 56.24374598264694, 67.36243575811386, 70.11122345924377, 65.81280291080475, 56.57418765127659, 59.31979492306709, 64.5486031472683, 65.95027193427086, 63.035657331347466, 62.66955457627773, 65.49738183617592, 66.40829935669899, 64.40211340785027, 63.42090725898743, 67.0820564031601, 69.69504699110985, 62.805043905973434, 50.29800362884998, 49.81941930949688, 43.9048732817173, 49.003238305449486, 44.7133406996727, 29.90611094981432, 29.24845363944769, 21.63671538233757, 23.188443817198277, 20.100902393460274, 23.375494480133057, 29.48068767786026, 22.538560889661312, 20.283007621765137, 17.022204995155334, 13.95496778190136, 8.562413044273853, 2.493551359511912, 0.08575405823648907, 0.08304208735353313, 0.17633359035244212, 1.097549730911851, 4.71709918230772, 19.72602590918541, 47.305770590901375, 62.1512433886528, 49.26022231578827, 52.893492355942726, 78.67349401116371, 63.184160962700844, 47.258136346936226, 55.05925454199314, 61.60890229046345, 74.70699325203896, 48.93866457045078, 11.742753088474274, 0.5886623344849795, 0.2245137284626253, 0.166630054009147, 0.11047392123145983, 0.15545192960416898, 0.08818568283459172, 0.22912466229172423, 0.2190145626082085, 0.11942231489229016, 0.17367306514643133, 0.13479785586241633, 0.3481960081262514, 0.0924207188654691, 0.09245813795132563, 0.142854833684396, 0.11883513507200405, 0.17180855269543827, 0.11175995925441384, 0.14797384181292728, 0.14348733646329492, 0.22504911379655823, 0.09637801354983822, 0.15216353262076154, 0.1344355393666774, 0.08309219716466032, 0.2819321060087532, 0.17626443703193218, 0.11986573328613304, 0.09191274104523472, 0.14097467676037923], [0.06487762220785953, 0.059714122326113284, 0.0872108421754092, 0.02794192681903951, 0.04363593448942993, 0.04280596105672885, 0.09339481737697497, 0.06623141089221463, 0.05508402995474171, 0.035455095930956304, 0.06399883030098863, 0.018120791610272136, 0.0353343447932275, 0.051114345114910975, 0.016502720427524764, 0.02207180586992763, 0.037258269876474515, 0.010243171400361462, 0.015658722259104252, 0.07863505859859288, 0.024852160095178988, 0.022358900132530835, 0.027107530186185613, 0.04572221921989694, 0.013114731864334317, 0.07862494312576018, 0.03623029886512086, 1.0804676287807524, 23.956361711025238, 45.77898971736431, 55.21793782711029, 50.206884518265724, 41.129912585020065, 32.2012884914875, 32.17303320765495, 43.94744239747524, 40.17394468188286, 36.47760182619095, 28.751542903482914, 25.42652752250433, 27.769223414361477, 17.262222915887833, 1.223238199017942, 0.12015123007586226, 0.03945892327465117, 0.31725414970424026, 0.928749191807583, 6.805963944643736, 3.8320359494537115, 15.535022746771574, 4.526724172756076, 9.918224941939116, 14.90424994379282, 13.790884986519814, 22.81678956001997, 23.169629126787186, 9.12293616682291, 28.046441338956356, 36.89127042889595, 32.67688997089863, 41.69807709753513, 54.32653985917568, 62.56855219602585, 57.54334084689617, 64.6772338449955, 66.34839177131653, 66.52562946081161, 61.02116882801056, 62.61316180229187, 54.97031271457672, 56.81534171104431, 57.93185479938984, 63.141732439398766, 63.65248203277588, 61.32309302687645, 59.73988138139248, 61.11300989985466, 59.81490455567837, 62.58513830602169, 64.3637278676033, 66.19054064154625, 63.74233581125736, 62.129987329244614, 59.91727106273174, 63.387583047151566, 48.75821605324745, 28.584025092422962, 51.24523960053921, 37.59230621159077, 38.91330912709236, 50.299831330776215, 59.86307457089424, 56.13846503198147, 57.99406886100769, 61.53386011719704, 62.57008731365204, 59.27097514271736, 47.520793452858925, 54.00118611752987, 61.27500280737877, 63.615263029932976, 57.29282408952713, 58.98489609360695, 63.024303540587425, 64.27915960550308, 62.17466153204441, 62.44784787297249, 60.945248901844025, 58.27438361942768, 59.508211612701416, 61.392986476421356, 56.455151438713074, 48.2407446205616, 49.705596417188644, 35.08069418370724, 28.551732525229454, 21.628564819693565, 10.953234303742647, 17.45519746094942, 13.441379740834236, 6.733530331403017, 15.386558063328266, 8.147622551769018, 4.209577515721321, 9.284224212169647, 7.127382047474384, 5.147624630481005, 1.753603289835155, 0.32680627307854593, 0.23217183159431443, 0.09600097284419462, 0.03377598310180474, 0.5253253737464547, 4.98683150857687, 23.602232113480568, 42.98058807849884, 50.16729064285755, 91.09910845756531, 87.36019268631935, 57.095477879047394, 38.17871354520321, 37.789766415953636, 44.73348721861839, 54.2979121953249, 46.19874559342861, 14.538129139691591, 1.3537797192111611, 0.05241948972980026, 0.02940066817245679, 0.02904746710555628, 0.04706366227765102, 0.07404259682516567, 0.07712537437328137, 0.033367957730661146, 0.035569683532230556, 0.0717656580673065, 0.12128284201025963, 0.031090627489902545, 0.03633431457274128, 0.04092609728104435, 0.047015285381348804, 0.07778243481880054, 0.03193623611878138, 0.016855082867550664, 0.04293664213037118, 0.029935569255030714, 0.055917888530530035, 0.03093950952461455, 0.03400323985260911, 0.03324503581097815, 0.08243955991929397, 0.04582033485348802, 0.020283281919546425, 0.03946112374251243, 0.048984088134602644, 0.09215866652084514, 0.042544862371869385, 0.036140795855317265, 0.05254821153357625, 0.006972943119762931, 0.016782547209004406, 0.02030145155003993, 0.05249872883723583, 0.08692490009707399, 0.041183114153682254, 0.02563586618634872, 0.01581265667482512, 0.02712301880819723, 0.01977674757654313, 0.02776028060907265, 0.06260601207031868, 0.017299525425187312, 0.029013972125540022, 0.06360746614518575, 0.036112208326812834, 0.04061121144331992, 0.03002513349201763, 0.05035964772105217, 0.03402094007469714, 0.03130804150714539, 0.01617982310563093, 0.05266540036245715, 0.032075270064524375, 1.464892525691539, 28.232703544199467, 55.35199083387852, 65.34276813268661, 61.91793970763683, 50.866601318120956, 39.92892622947693, 34.480470791459084, 47.62615039944649, 48.375010415911674, 51.87598675489426, 46.236804351210594, 32.88296431303024, 23.216759897768497, 14.823636319488287, 1.6290046507492661, 0.0425221081241034, 0.6594270654022694, 0.9110069938469678, 5.580412382259965, 8.000528644770384, 13.562449794262648, 19.970603585243225, 11.766398269683123, 13.016248103231192, 18.544498309493065, 15.996151752769947, 19.839447923004627, 14.919743612408638, 13.152551539242268, 21.05249673128128, 24.351360015571117, 30.788315311074257, 39.291058257222176, 51.233190447092056, 57.798660546541214, 59.12155196070671, 63.73538218438625, 69.53300088644028, 67.58315071463585, 63.58809448778629, 64.96885299682617, 58.986530005931854, 59.32391010224819, 62.51198083162308, 65.05605831742287, 63.728147372603416, 61.155598014593124, 60.970023572444916, 61.78600698709488, 60.01917019486427, 61.17481738328934, 64.28806632757187, 64.8179478943348, 64.18379992246628, 62.96701401472092, 61.141234785318375, 67.1347063779831, 53.72469775378704, 34.582362323999405, 56.06734424829483, 46.35802164673805, 45.10828770697117, 57.40249380469322, 62.957598119974136, 58.317477107048035, 58.53322573006153, 63.550666496157646, 65.32578304409981, 60.526325181126595, 49.87017318606377, 55.79231880605221, 64.125936627388, 64.2814926803112, 59.33267243206501, 60.27303837239742, 62.76251658797264, 65.26174128055573, 65.29429033398628, 63.04376609623432, 62.202852219343185, 60.344504937529564, 63.66378642618656, 61.28432370722294, 56.38320989906788, 47.04942114651203, 42.342435121536255, 34.04384382069111, 27.42735765874386, 19.39022272825241, 10.450679920613766, 9.223851151764393, 10.589418075978756, 15.700619760900736, 15.883357655256987, 16.545366682112217, 13.092695251107216, 11.01444236934185, 7.59861946105957, 7.596323434263468, 3.119315793737769, 2.147149359807372, 0.4547101410571486, 0.08116638331557624, 0.03270363908086438, 0.37188485730439425, 5.425205435603857, 23.541631065309048, 45.788975581526756, 42.16813467442989, 77.88549989461899, 97.8268526494503, 64.42668288946152, 43.65349017083645, 45.18588714301586, 51.105323508381844, 63.10247294604778, 56.583763137459755, 18.376306034624577, 1.9472357933409512, 0.13910492474678904, 0.1051260347594507, 0.024758193067100365, 0.060870663000969216, 0.030593960000260267, 0.07695535576203838, 0.01962578360689804, 0.05542388164030854, 0.11130384271382354, 0.05004418300813995, 0.01853816989751067, 0.020728286654048134, 0.043037436917074956, 0.08975495409686118, 0.062000998441362754, 0.07027009691228159, 0.025426302236155607, 0.09520483392407186, 0.03587213097489439, 0.02347983441723045, 0.04192099077044986, 0.029763489328615833, 0.028310800189501606, 0.07168598851421848, 0.02638426831254037, 0.02399999459157698, 0.022970424251980148, 0.02288644653162919, 0.06505779339931905, 0.31131690891925246, 0.12838538823416457, 0.19085473380982876, 0.1184132241178304, 0.08508702332619578, 0.12207533698529005, 0.20733335113618523, 0.1472358056344092, 0.16555315320147201, 0.08161287420080043, 0.11329814195050858, 0.1552434454788454, 0.15908484638202935, 0.28623641410376877, 0.14143840031465515, 0.10783478472149, 0.1366022098227404, 0.1561018283246085, 0.11410563573008403, 0.12786281236913055, 0.17109232081566006, 0.14126028487225994, 0.1556148607051, 0.19853780278936028, 0.12113231961848214, 0.17297807353315875, 0.18814219889463857, 2.5819621654227376, 37.105088755488396, 69.2378631234169, 76.70092105865479, 71.27859681844711, 60.43379634618759, 50.092484056949615, 46.08959645032883, 57.9956191778183, 54.751246869564056, 47.79657505452633, 42.00592517852783, 35.75815223157406, 38.71263049542904, 20.677035078406334, 1.6480844956822693, 0.26358838251326233, 0.5300446017645299, 0.5638476472813636, 4.846463240683079, 18.7144460901618, 16.352766416966915, 32.39296540617943, 18.569873347878456, 18.092974238097668, 26.877164281904697, 22.913600765168667, 34.773279279470444, 38.65341067314148, 20.59037882834673, 39.100981056690216, 40.32742224633694, 36.469143480062485, 43.45497742295265, 58.5345708578825, 63.13281051814556, 57.705466747283936, 65.46133697032928, 70.50565749406815, 69.88969534635544, 64.68563139438629, 67.70723685622215, 60.61024367809296, 60.17955958843231, 62.675786241889, 65.96090376377106, 64.43875104188919, 60.45108921825886, 59.088060557842255, 61.146372109651566, 60.6981785595417, 63.49869668483734, 65.38407191634178, 68.19142207503319, 64.850192964077, 65.84511637687683, 63.76231133937836, 67.91197746992111, 58.41703936457634, 40.31159609556198, 61.67328983545303, 49.442004561424255, 52.069673761725426, 61.41951285302639, 65.27062520384789, 62.42691099643707, 59.34641249477863, 64.49096024036407, 69.92852926254272, 62.97947354614735, 52.63290233910084, 58.884262293577194, 68.32174748182297, 64.73445117473602, 58.511053919792175, 60.01339070498943, 64.73831936717033, 66.91734284162521, 67.21510246396065, 65.94479262828827, 66.71413734555244, 62.011977061629295, 66.86011791229248, 64.20759424567223, 58.92936207354069, 50.05440630018711, 52.70882986485958, 39.23805110156536, 33.31460975110531, 28.342247866094112, 17.823240011930466, 26.573395282030106, 24.125256948173046, 17.25288301706314, 22.718925811350346, 21.395207941532135, 12.523561790585518, 16.4652593806386, 17.378215491771698, 15.0423364341259, 4.038046645000577, 2.248009010218084, 0.7419386878609657, 0.16848591301823035, 0.18757162091787905, 1.2744150403887033, 6.458815997466445, 29.803864136338234, 55.317697674036026, 65.54766073822975, 97.61828184127808, 90.4112845659256, 62.07944244146347, 50.468052104115486, 53.23515482246876, 60.34305341541767, 70.87236061692238, 66.15433618426323, 24.810704067349434, 2.860671509988606, 0.16353026643628255, 0.2119049066095613, 0.04887825416517444, 0.19194683380192146, 0.135690288443584, 0.2770488930400461, 0.15185883647063747, 0.13022919476497918, 0.33237003546673805, 0.1925517583731562, 0.11684099910780787, 0.11547693167813122, 0.13796798419207335, 0.1183736305392813, 0.18855692585930228, 0.11289022048003972, 0.11769981239922345, 0.10770073800813407, 0.16101876448374242, 0.1746272889431566, 0.1247151562711224, 0.06987813161686063, 0.1735474047018215, 0.27099359140265733, 0.12919058877741918, 0.12387687078444287, 0.11714388441760093, 0.19626110151875764, 0.2083632443100214], [0.004815947022507316, 0.03577673531253822, 0.03629984181316104, 0.043864998369826935, 0.03718103456776589, 0.07792890508426353, 0.04917868667689618, 0.04435227769135963, 0.045215580976218916, 0.017817303305491805, 0.04277573338185903, 0.04666596760216635, 0.017146255231637042, 0.0077972307735763025, 0.053352851755334996, 0.07780724481563084, 0.03241087666538078, 0.007652595932086115, 0.019411742650845554, 0.06809761543991044, 0.023186394791991916, 0.05927566147875041, 0.08326735143782571, 0.07109146885341033, 0.04628673385013826, 0.109183014719747, 0.039703453512629494, 6.533192731440067, 41.07501693069935, 52.943828254938126, 52.27083116769791, 49.20789912343025, 32.47287891805172, 26.83971729129553, 29.99440111219883, 30.693426802754402, 32.756902277469635, 32.737831100821495, 30.178936310112476, 36.15733601152897, 23.454083763062954, 2.8384263161569834, 0.23029455420328304, 0.11338247219100595, 0.5796631111297756, 2.057252121157944, 2.6682438980787992, 6.2120624631643295, 11.547847297042608, 8.791197817772627, 5.268434872850776, 9.362220726907253, 18.7146170809865, 14.549126699566841, 22.191766798496246, 25.632347278296947, 28.322517424821854, 26.829406544566154, 44.16481353342533, 49.60671052336693, 57.59973742067814, 56.702556163072586, 58.591643795371056, 62.73003973066807, 63.3026348054409, 64.2481380701065, 62.51255080103874, 59.354122281074524, 57.817982509732246, 55.40235713124275, 56.744486913084984, 61.172526106238365, 62.85465404391289, 61.99916794896126, 61.0885202139616, 58.84856320917606, 59.352286979556084, 59.371057972311974, 61.677982583642006, 65.25766789913177, 64.47955325245857, 64.0635971724987, 60.220749378204346, 58.754571452736855, 60.04279352724552, 56.962804198265076, 32.70937442779541, 43.5326224565506, 35.72846062481403, 41.970161497592926, 55.06089225411415, 57.385432720184326, 58.58459137380123, 57.70487777888775, 59.55005116760731, 60.73381684720516, 60.144704058766365, 47.40558743476868, 56.6984523832798, 61.14522077143192, 62.94189356267452, 56.99124187231064, 58.78761067986488, 58.044571951031685, 60.33665455877781, 60.14712072908878, 60.29707968235016, 55.10778173804283, 61.07821136713028, 57.523285523056984, 60.31370759010315, 59.2722936719656, 57.2992305457592, 51.14428661763668, 46.99609860777855, 37.731652334332466, 35.58888651430607, 25.795831605792046, 18.878475688397884, 18.016096763312817, 16.60043902695179, 17.439903281629086, 14.755239989608526, 14.909668453037739, 6.086145769804716, 5.338757699355483, 8.321581967175007, 3.285293262451887, 1.709108033683151, 0.3507166384952143, 0.030483914342767093, 0.13903344108257443, 0.16141551663167775, 0.714020635932684, 7.392965946346521, 30.302931256592274, 43.72374080121517, 32.19446785748005, 28.35710696876049, 18.878870867192745, 25.6260472163558, 36.28948912024498, 43.54202315211296, 49.23324376344681, 50.38460858166218, 24.966731294989586, 4.432898182421923, 0.45042204146739095, 0.01730111733195372, 0.009531313553452492, 0.048170378868235275, 0.08416541691985913, 0.005652590043609962, 0.07999742651009001, 0.05387526434788015, 0.02944513766124146, 0.06347627670038491, 0.04652199837437365, 0.08043226567679085, 0.05663725227350369, 0.01107232197682606, 0.06619351683184505, 0.06670887902146205, 0.03066638619202422, 0.04938114827382378, 0.039067180623533204, 0.05144586990354583, 0.06060436928237323, 0.018117637482646387, 0.045107776604709215, 0.02283160367369419, 0.018189024667663034, 0.017344768602924887, 0.05308322208293248, 0.018837207171600312, 0.026363677425251808, 0.04373268828203436, 0.026783246903505642, 0.03462291831965558, 0.0657280269660987, 0.032483852046425454, 0.02715121485380223, 0.0499830448825378, 0.05630321160424501, 0.024568557637394406, 0.03249664296163246, 0.01808972159778932, 0.06954394251806661, 0.04635642522771377, 0.021707995801989455, 0.013794153219350846, 0.033061324575101025, 0.013114381199557101, 0.026120562833966687, 0.08862354996381328, 0.06823554358561523, 0.0090618494868977, 0.07637078830157407, 0.03232194510928821, 0.02542940626881318, 0.046783212092122994, 0.06491159772849642, 0.06438090276787989, 7.477753646671772, 47.76866935193539, 63.6163991689682, 66.07485204935074, 56.40382759273052, 42.95432008802891, 37.69612044095993, 40.69198988378048, 38.513304591178894, 32.07621060311794, 34.40841145813465, 27.34994251281023, 27.764771953225136, 21.525292061269283, 3.313624542206526, 0.1317198429023847, 0.2021653761039488, 0.8706197922583669, 4.537001196295023, 8.008996490389109, 12.54968348890543, 14.32242326438427, 17.72035863250494, 18.622025549411774, 9.799136482179165, 13.017306346446276, 15.288158543407917, 19.853955544531345, 16.637865118682384, 21.124341376125813, 30.14299213886261, 39.06773664057255, 45.92423692345619, 55.006665363907814, 58.48588787019253, 59.816515669226646, 62.84415900707245, 63.250653594732285, 66.64894804358482, 64.49882581830025, 62.073795944452286, 59.85460862517357, 59.07642558217049, 59.984896034002304, 64.0088041126728, 65.2091597020626, 61.75882324576378, 60.52621878683567, 57.517901211977005, 58.565121218562126, 60.843049585819244, 63.66008162498474, 65.86932107806206, 66.1197580397129, 66.22041463851929, 61.13698661327362, 59.58041153848171, 64.17043223977089, 60.68262979388237, 36.78367540240288, 50.151935666799545, 44.9565352499485, 47.77762167155743, 60.34741938114166, 60.78085832297802, 61.74919456243515, 58.97441625595093, 62.159059569239616, 64.14038345217705, 59.325635209679604, 49.16107423603535, 57.75175966322422, 63.912220895290375, 64.26380082964897, 56.789035722613335, 59.350314885377884, 60.3638307005167, 62.44419626891613, 61.35904289782047, 61.83101937174797, 58.63126426935196, 61.83733083307743, 59.81525033712387, 64.1825307905674, 61.47060111165047, 55.62668189406395, 51.53731092810631, 43.9944002777338, 35.43492637574673, 31.047111824154854, 24.755445532500744, 16.31882283836603, 11.658409014344215, 13.853705115616322, 14.793995060026646, 14.422344602644444, 13.427976910024881, 11.387619394809008, 10.64599609002471, 11.402082368731499, 6.221544379368424, 3.701095450669527, 1.3252730551175773, 0.12059737215167843, 0.1750016727601178, 0.18786610511597246, 0.6626432365737855, 8.56210621073842, 29.871608801186085, 49.52939227223396, 47.56609082221985, 40.20075984299183, 25.832602232694626, 29.94278848171234, 43.37785676121712, 50.76423101127148, 56.287808418273926, 57.598791271448135, 35.007931888103485, 5.579862836748362, 0.3122925362549722, 0.029949927957204636, 0.007350782561843516, 0.019063419349549804, 0.025394005824637134, 0.03366178883879911, 0.015038264536997303, 0.02104677005263511, 0.010188153210037854, 0.04247944205417298, 0.07130430938559584, 0.00645463135697355, 0.009787510352907702, 0.020546043015201576, 0.04815633001271635, 0.05219657454290427, 0.022193247204995714, 0.02648808920639567, 0.07166526032960974, 0.05727575160562992, 0.07713142287684605, 0.05861089754034765, 0.0256958706813748, 0.08570975944167003, 0.016228001477429643, 0.06131582173111383, 0.013896213367843302, 0.06974272677325644, 0.02664702569745714, 0.08868181597790681, 0.12529921164968982, 0.0990720912523102, 0.14575311332009733, 0.09211168115143664, 0.1114502536074724, 0.15196938678855076, 0.17452407104428858, 0.13118160772137344, 0.1665077926008962, 0.11869809750351124, 0.15251064993208274, 0.20487302768742666, 0.0825849392276723, 0.09602996855392121, 0.13409453735221177, 0.16842489363625646, 0.12133292955695651, 0.14589517522836104, 0.1572852866956964, 0.10366315036662854, 0.16734410397475585, 0.19278114137705415, 0.16912890976527706, 0.11071236585848965, 0.20351262646727264, 0.23675707227084786, 10.992995370179415, 60.341666489839554, 74.45883616805077, 72.32590422034264, 67.34941005706787, 49.11117151379585, 43.489597365260124, 44.273806884884834, 44.02195259928703, 44.22489210963249, 45.83013117313385, 44.161256924271584, 46.11052192747593, 28.89699149876833, 3.8171782717108727, 0.3932635788805783, 0.2932821266585961, 1.1484047770500183, 5.573264490813017, 9.30459301918745, 20.15039473772049, 25.893765650689602, 17.775843255221844, 20.527860783040524, 21.579401157796383, 29.915173463523388, 28.67590606212616, 35.9942639619112, 36.955460384488106, 33.06903652846813, 31.5742689371109, 49.68418836593628, 50.06465435028076, 60.96046708524227, 59.19178359210491, 60.291125401854515, 60.60739763081074, 64.97326835989952, 67.97151267528534, 67.84076169133186, 63.58529403805733, 62.3367228358984, 61.06126047670841, 61.07852295041084, 64.14392486214638, 67.62386173009872, 62.46489755809307, 60.60482136905193, 58.51428374648094, 58.70405696332455, 60.881621316075325, 64.925656914711, 69.51201841235161, 68.7087719142437, 66.67004451155663, 62.52647325396538, 60.748164877295494, 64.38674703240395, 64.18331354856491, 42.91344568133354, 55.416841953992844, 47.64527477324009, 55.842567309737206, 64.85543668270111, 61.362835094332695, 65.56710049510002, 59.86393712460995, 64.42517817020416, 67.47375458478928, 63.74343015253544, 53.509739488363266, 62.02683426439762, 66.77714556455612, 65.83409696817398, 57.087616100907326, 59.413034319877625, 60.437512546777725, 61.684997007250786, 64.15559023618698, 63.91619548201561, 59.91451621055603, 65.24793282151222, 61.26416578888893, 66.30742236971855, 64.80819001793861, 58.67178149521351, 53.990516290068626, 47.81492426991463, 43.57731565833092, 37.834793999791145, 31.875201389193535, 25.05972560495138, 25.500855334103107, 24.39592782407999, 30.004303380846977, 26.431362703442574, 26.41533136367798, 17.704034708440304, 15.802846625447273, 17.393956147134304, 7.921993033960462, 3.922194424085319, 1.0438962536863983, 0.40260739624500275, 0.26199410087428987, 0.3849524154793471, 1.0045018675737083, 10.079517737030983, 36.655918657779694, 57.459213361144066, 42.01026074588299, 37.82312862575054, 27.692112252116203, 36.815719082951546, 50.59276521205902, 59.778141528367996, 66.6220910847187, 67.41674244403839, 46.948631554841995, 8.264292441308498, 0.5483973200898618, 0.17530213866848499, 0.15649846172891557, 0.18040922790532932, 0.14387815142981708, 0.04336270169005729, 0.14711323252413422, 0.1515432307496667, 0.08841373739414848, 0.18710760050453246, 0.2588653250131756, 0.14374662801856175, 0.2064764080569148, 0.2084825816564262, 0.13205446244683117, 0.1992225379217416, 0.07680950890062377, 0.14735385164385661, 0.113110059464816, 0.14860569150187075, 0.11389157065423205, 0.2009663771605119, 0.18087155622197315, 0.12521889642812312, 0.13019861828070134, 0.14640412526205182, 0.15587559202685952, 0.17259926651604474, 0.1114703064376954], [0.018051224542432465, 0.044924621979589574, 0.059392171242507175, 0.02683925864403136, 0.01890999516035663, 0.07896383744082414, 0.009555115157127148, 0.053141996468184516, 0.02062409468635451, 0.04698454933532048, 0.0729233119636774, 0.050127336944569834, 0.030458302826446015, 0.03029727904504398, 0.020406667681527324, 0.048950903001241386, 0.011976935984421289, 0.0016432561960755265, 0.01137438071964425, 0.03756046869966667, 0.09173437327262945, 0.033730244540493004, 0.06182204437209293, 0.034169722130172886, 0.013883555111533497, 0.09873174232780002, 0.40190021856687963, 20.782777704298496, 43.905006274580956, 44.00111831724644, 43.953275084495544, 40.34286841750145, 32.90219508111477, 32.478115037083626, 28.87915525585413, 44.08947877585888, 60.61361029744148, 33.640609458088875, 50.14081746339798, 32.87292905151844, 8.728849813342094, 0.8370771515183151, 0.10958359634969383, 0.05143559115822427, 1.4255404123105109, 2.9950123513117433, 11.770677790045738, 7.531663253903389, 14.056264646351337, 25.326646082103252, 14.31840118020773, 8.442026004195213, 16.36792380362749, 22.856318838894367, 32.62557752430439, 26.854988671839237, 38.57552245259285, 52.506236135959625, 47.1131095290184, 59.845420718193054, 59.86134946346283, 63.36081728339195, 60.79011082649231, 66.41563296318054, 64.78418290615082, 63.00913095474243, 59.7346680611372, 57.40102708339691, 54.76262725889683, 58.64548310637474, 55.27933493256569, 64.14568796753883, 62.64882668852806, 62.42003716528416, 57.84764751791954, 62.688378766179085, 59.830852299928665, 62.71040238440037, 62.222599759697914, 60.75558967888355, 60.31686522066593, 64.14013266563416, 60.53460493683815, 59.36385735869408, 58.40339429676533, 60.908812656998634, 38.745050355792046, 31.960886791348457, 31.224070228636265, 44.88468490540981, 53.26312132179737, 59.21937011182308, 58.48514311015606, 57.58492201566696, 59.78207811713219, 59.28446441888809, 55.11007681488991, 43.65943685173988, 49.6705736964941, 59.673745930194855, 62.873147651553154, 57.639319896698, 55.99695302546024, 59.618443697690964, 62.01804153621197, 60.01601256430149, 61.746549904346466, 54.54339802265167, 54.00238685309887, 53.85464318096638, 59.167586490511894, 59.15627829730511, 60.940328165888786, 56.87536709010601, 55.920292139053345, 49.197920858860016, 40.285050719976425, 31.472029723227024, 25.960767455399036, 17.638590820133686, 26.828950569033623, 15.241621490567923, 12.69074046984315, 15.726598016917706, 13.064203429967165, 7.318878471851349, 5.730761764571071, 3.08803943451494, 3.897895677946508, 0.46237177681177855, 0.24460657528834417, 0.008055657726799836, 0.009401014685863629, 0.10787181789055467, 1.8855591653846204, 14.697273150086403, 27.7148350328207, 32.563925832509995, 32.61030234396458, 33.710016533732414, 20.98873995244503, 16.110618710517883, 32.752057537436485, 45.90640068054199, 44.38861012458801, 43.38661149144173, 7.327434662729502, 0.3985555371036753, 0.010159657522308407, 0.024910576394177042, 0.03829016684903763, 0.08510001833201386, 0.02752327018242795, 0.05243019149929751, 0.08204986559576355, 0.04979394194378983, 0.033263355726376176, 0.0690328105702065, 0.032606688619125634, 0.060967802710365504, 0.050150543902418576, 0.018804435785568785, 0.011472443475213367, 0.055262542446143925, 0.05592820067249704, 0.07727770018391311, 0.03910212093614973, 0.08620962558779866, 0.017611231160117313, 0.00963207401582622, 0.02710022745304741, 0.04408474087540526, 0.03960125606681686, 0.04401677870191634, 0.0294299904271611, 0.030506145376421046, 0.05934567940130364, 0.03420783512410708, 0.021421311575977597, 0.05689952726243064, 0.03618520968302619, 0.03155675745802, 0.014263295379350893, 0.01760637380357366, 0.06128142689703964, 0.036632268311223015, 0.03010906668350799, 0.015472242812393233, 0.0577226877794601, 0.04500766459386796, 0.055834630693425424, 0.015706761478213593, 0.02756568392214831, 0.025585017938283272, 0.03343326672620606, 0.042266185919288546, 0.08734914881642908, 0.010191105102421716, 0.009165158298856113, 0.04501560557400808, 0.008810075887595303, 0.11713826635968871, 0.3964589996030554, 25.21730124950409, 56.3140270113945, 59.056932628154755, 55.14790378510952, 50.6840743124485, 39.298680648207664, 34.94555823504925, 29.728806763887405, 44.76005159318447, 59.28092680871487, 32.76045888662338, 47.188239097595215, 29.825912453234196, 7.742121135815978, 1.1012051347643137, 0.051656127761816606, 0.6701092422008514, 3.5483920946717262, 8.574485946446657, 13.696344159543514, 13.053465206176043, 16.274494417011738, 16.788454838097095, 11.193869691342115, 13.46307372674346, 18.063248433172703, 16.081835255026817, 24.576817117631435, 27.80899778008461, 34.10179831087589, 44.88598443567753, 48.477148935198784, 57.554945424199104, 60.61461344361305, 61.56751871109009, 61.53004512190819, 63.2618173956871, 65.88857844471931, 64.97259199619293, 63.17413330078125, 58.15901041030884, 57.470069378614426, 59.90562088787556, 59.24594968557358, 65.5141693353653, 64.05563279986382, 61.3036722689867, 59.27022658288479, 62.33992986381054, 59.58171866834164, 62.3623638600111, 64.63388577103615, 62.47182458639145, 62.54537343978882, 64.79928329586983, 63.13469521701336, 62.17922888696194, 59.802502021193504, 63.081748858094215, 41.53986878693104, 40.483514070510864, 42.065885961055756, 48.58333423733711, 58.60255300998688, 60.06243087351322, 60.00921472907066, 57.86657430231571, 63.05239163339138, 60.24228662252426, 58.37110362946987, 44.944953471422195, 54.30540159344673, 61.87789745628834, 64.69028234481812, 57.959129735827446, 57.24138244986534, 57.82368220388889, 63.07592757046223, 62.10588902235031, 64.65106084942818, 56.537139639258385, 57.0914538949728, 56.87251724302769, 61.205462738871574, 62.68391780555248, 64.0154005587101, 58.17911513149738, 57.70579732954502, 50.1454684138298, 39.684572741389275, 30.65107237547636, 25.880099684000015, 18.88914741575718, 18.814694210886955, 15.367001462727785, 15.785709545016289, 16.45714871585369, 15.207952447235584, 10.620358865708113, 11.138866692781448, 8.475364465266466, 7.033613529056311, 3.463792959228158, 0.9820573031902313, 0.17491435166448355, 0.07530395843787119, 0.1690552887157537, 2.0166648365557194, 15.933708753436804, 31.501269154250622, 38.054464012384415, 34.480121210217476, 27.979848012328148, 26.261635310947895, 28.7751567363739, 43.33430349826813, 55.423085018992424, 52.15499438345432, 51.279547959566116, 12.421410921961069, 0.49864825210534036, 0.061972930416231975, 0.05630946048768237, 0.019729097984964028, 0.018540550336183514, 0.011647299033938907, 0.08484491991112009, 0.07277970638824627, 0.07010418979916722, 0.05294778755342122, 0.07201064101536758, 0.04337524398579262, 0.08855313499225304, 0.0404077998973662, 0.06448360858485103, 0.03966567077441141, 0.057724654470803216, 0.057187692073057406, 0.007178274045145372, 0.037195614058873616, 0.07536092569353059, 0.02742103377386229, 0.03625519049819559, 0.045203012705314904, 0.03902680036844686, 0.017909615344251506, 0.010677811114874203, 0.010750147321232362, 0.05210747600358445, 0.21885405090870336, 0.18941970221931115, 0.1555574926896952, 0.17924162180861458, 0.12877166125690565, 0.1347464250284247, 0.11104458826594055, 0.11764417358790524, 0.13144088443368673, 0.0926982301461976, 0.1554808288346976, 0.13363639474846423, 0.12264470526133664, 0.15193490660749376, 0.11931023575016297, 0.11848815876874141, 0.19519980065524578, 0.2615475654602051, 0.1073709201591555, 0.07560507001471706, 0.2500166092067957, 0.0923473056172952, 0.11858970683533698, 0.15815576654858887, 0.17023997905198485, 0.16106394643429667, 0.6467358651570976, 30.839946940541267, 67.52519622445107, 69.6047106385231, 65.97660452127457, 57.779718562960625, 47.46076047420502, 46.71172946691513, 40.483384877443314, 57.1321003139019, 72.1250469982624, 46.66912995278835, 61.12583041191101, 39.97146114706993, 10.177440382540226, 1.1166922724805772, 0.3376378590473905, 0.8082865120377392, 3.491612928919494, 9.907709956169128, 22.88783434778452, 16.54974214732647, 22.645017877221107, 38.58341842889786, 19.808842465281487, 17.520905435085297, 26.320743039250374, 31.16218864917755, 41.19874209165573, 31.485674791038036, 45.017404183745384, 57.59663678705692, 52.43588671088219, 60.07113240659237, 61.55624471604824, 61.8752945959568, 61.57033056020737, 65.85765570402145, 68.85293617844582, 66.98397606611252, 65.51807552576065, 59.48252119123936, 60.21148927509785, 62.054131999611855, 59.88562636077404, 67.69660502672195, 64.48718324303627, 61.94415830075741, 59.530121237039566, 61.624842435121536, 61.18642956018448, 63.27458471059799, 65.78767865896225, 64.69116389751434, 65.0350834429264, 68.5599946975708, 64.60607126355171, 64.5607016980648, 61.202780082821846, 65.2094104886055, 47.52359390258789, 45.024213418364525, 44.41192947328091, 54.26244869828224, 62.487255558371544, 62.75690048933029, 63.12521852552891, 60.17535701394081, 63.62727798521519, 62.839131876826286, 63.026807606220245, 48.506870940327644, 54.78791110217571, 64.21891763806343, 67.49657616019249, 59.91201214492321, 57.981320545077324, 59.184343591332436, 65.09234637022018, 63.6589302867651, 67.09785595536232, 58.74435380101204, 58.4018249809742, 58.708206340670586, 65.93577951192856, 65.5938358604908, 65.45489251613617, 59.83614541590214, 59.639308378100395, 52.16681934893131, 45.08338764309883, 33.61005149781704, 30.68758461624384, 23.414184004068375, 37.98674024641514, 26.68728467077017, 23.185698464512825, 24.4386413320899, 24.213486313819885, 16.75983477383852, 20.268788784742355, 15.214663837105036, 12.082468159496784, 2.7301406767219305, 0.6531909469049424, 0.31352120626252145, 0.1540639650193043, 0.4681567882653326, 2.678568181581795, 18.938388973474503, 35.63828386366367, 46.281573548913, 48.38924065232277, 46.32037326693535, 29.73254956305027, 27.862202525138855, 46.49304360151291, 64.21226039528847, 60.77162101864815, 63.022605031728745, 20.28740968555212, 0.9474377171136439, 0.19951956026488915, 0.1087195509171579, 0.1346131056197919, 0.19493811938446015, 0.15644893079297617, 0.12473479349864647, 0.22078930487623438, 0.12674907135078683, 0.14230635686544701, 0.21033982106018811, 0.13794969767332077, 0.1537521739373915, 0.13970748928841203, 0.18743231979897246, 0.09401894873008132, 0.18540121003752574, 0.11956342685152777, 0.3361738391686231, 0.19160290772560984, 0.16076640458777547, 0.12745394837111235, 0.12164293948444538, 0.2153367013670504, 0.19885027664713562, 0.11910667948541231, 0.13473771221470088, 0.09645256228395738, 0.20283894933527336], [0.027325695627951063, 0.04899607753031887, 0.07102003713953309, 0.0535702527849935, 0.055580960906809196, 0.029091760334267747, 0.08048822361161001, 0.04426320883794688, 0.04905715257336851, 0.046073047269601375, 0.05737596751714591, 0.05648355720040854, 0.05640892683004495, 0.04265372430381831, 0.017413435816706624, 0.028231822689122055, 0.047235254241968505, 0.02129087170033017, 0.015941050078254193, 0.006304648877630825, 0.031988594637368806, 0.01408817728588474, 0.06803340482292697, 0.08088850096100941, 0.1293289102613926, 0.08086836649454199, 3.5604528849944472, 22.346443198621273, 32.30189189314842, 43.909292444586754, 42.08466075360775, 29.284454807639122, 23.980952091515064, 34.181730821728706, 39.99582163989544, 35.48468850553036, 16.319955177605152, 42.25386567413807, 27.8408894687891, 10.811035484075546, 2.0594854513183236, 0.15772480139276013, 0.047421848721569404, 1.1634740559384227, 3.1278938334435225, 7.803581887856126, 6.574822347611189, 14.336085431277752, 11.881664134562016, 10.293397810310125, 21.14685706794262, 9.736071266233921, 20.617060996592045, 27.595179453492165, 41.54944807291031, 43.94276864826679, 40.78134968876839, 54.6775346249342, 57.543610632419586, 64.82101812958717, 64.75576803088188, 62.39472672343254, 61.25483728945255, 65.1888307929039, 60.017046108841896, 59.62074637413025, 55.9981157630682, 55.23619204759598, 57.33002409338951, 60.36013349890709, 60.256885439157486, 60.34866191446781, 61.77781082689762, 61.517266407608986, 62.24109336733818, 59.58165027201176, 60.46619340777397, 63.24145048856735, 60.10810822248459, 59.47433643043041, 56.534578576684, 62.20545507967472, 60.9285943955183, 62.195913791656494, 58.11134196817875, 60.39209358394146, 47.90277935564518, 21.59636914730072, 28.990952856838703, 43.9618094265461, 55.29302939772606, 57.356953248381615, 58.8310993462801, 59.0220694988966, 61.84603996574879, 56.917715817689896, 55.60461267828941, 44.49994795024395, 45.81866338849068, 55.11489875614643, 60.67211575806141, 55.91107003390789, 56.07676014304161, 52.85721190273762, 55.066614747047424, 56.1542683839798, 57.138062193989754, 52.722227945923805, 55.72636194527149, 51.896429657936096, 55.582851245999336, 54.13463495671749, 57.72119030356407, 59.778988882899284, 57.106223702430725, 52.455964833498, 50.976354628801346, 45.22088326513767, 38.5322579741478, 24.63099841028452, 20.963307917118073, 22.229358181357384, 18.259023427963257, 10.034107323735952, 9.887650832533836, 10.849933046847582, 14.58244901150465, 9.933633115142584, 4.509636489674449, 3.884118804708123, 0.16924379422562197, 0.25586689996998757, 0.062644010031363, 0.018163530039601028, 0.11671640735585243, 4.047300573438406, 25.418591648340225, 39.189862087368965, 47.04514257609844, 32.541552633047104, 22.236414402723312, 20.821813009679317, 31.603970043361187, 40.06697282195091, 43.06477256119251, 45.02162575721741, 24.311636947095394, 2.912951954640448, 0.01984655584237771, 0.04731591456220485, 0.06335264231893234, 0.06947490051970817, 0.014699424027639907, 0.059994360999553464, 0.012457433931558626, 0.039347237470792606, 0.06766866150428541, 0.04909078299533576, 0.005625933954434004, 0.04590585995174479, 0.01325111912592547, 0.03407395910471678, 0.04339537103078328, 0.02706764717004262, 0.05147150739503559, 0.034129887353628874, 0.06105459317041095, 0.01037729325616965, 0.05927628488279879, 0.02206374985689763, 0.007722958953308989, 0.05498132042703219, 0.04240802147251088, 0.06767352257156745, 0.017832027515396476, 0.04035705926071387, 0.03159355685056653, 0.017125259873864707, 0.013206354633439332, 0.0653371748921927, 0.020567539322655648, 0.04610080359270796, 0.0616336204984691, 0.0667678278114181, 0.037196348785073496, 0.033650708573986776, 0.05576420087891165, 0.03645574477559421, 0.07107759069185704, 0.07312261572224088, 0.028667658189078793, 0.02141564713383559, 0.04171718959696591, 0.045928165200166404, 0.08136471486068331, 0.0044330999389785575, 0.06374779884936288, 0.07140608751797117, 0.06189396219269838, 0.04668049143219832, 0.0810884874954354, 0.10746326559456065, 4.595072530210018, 31.09417039901018, 47.767339423298836, 56.53121955692768, 50.67150838673115, 39.20202523469925, 33.320035859942436, 36.604040041565895, 37.56711736321449, 38.882800564169884, 31.748117208480835, 38.52850757539272, 27.718184553086758, 12.205867487937212, 2.8544792672619224, 0.20611861866200343, 0.26789684663526714, 2.577247805893421, 4.75219932384789, 9.606838300824165, 12.387411296367645, 17.240812964737415, 14.68968115746975, 15.811943337321281, 15.122524481266737, 12.184501234441996, 18.59320979565382, 24.523659870028496, 34.04850997030735, 37.38271705806255, 42.78134576976299, 54.087190702557564, 56.383061707019806, 64.34907585382462, 63.46381075680256, 62.31267772614956, 58.29942427575588, 65.95765873789787, 61.12013831734657, 59.98466804623604, 58.06218780577183, 57.63399638235569, 58.125135228037834, 62.36224226653576, 62.452981397509575, 61.8179252743721, 59.999912828207016, 61.05776846408844, 60.0446592271328, 58.63031432032585, 60.06248027086258, 65.88767409324646, 61.921773701906204, 61.71574115753174, 58.05343307554722, 64.06878009438515, 62.093030512332916, 64.11142900586128, 57.517224848270416, 62.85258695483208, 49.20194484293461, 30.1865890994668, 38.08640509843826, 49.85229894518852, 59.01450790464878, 58.70301201939583, 59.33303341269493, 60.1626580953598, 63.48379388451576, 59.346302300691605, 55.322120636701584, 47.583573684096336, 49.03949595987797, 59.31658409535885, 63.182010278105736, 58.77469517290592, 56.19047284126282, 54.588110223412514, 58.78325991332531, 57.50032715499401, 60.007937997579575, 56.29415787756443, 55.84272690117359, 53.62826652824879, 58.68748985230923, 56.091727539896965, 60.34686081111431, 61.25589743256569, 56.844216361641884, 53.77616599202156, 50.61207577586174, 44.59147743880749, 38.51540207862854, 26.57230854034424, 21.07735689729452, 17.824883423745632, 13.651249129325151, 10.352083761245012, 12.502315230667591, 16.358416713774204, 12.97410836443305, 7.373236929997802, 12.33831413090229, 6.641099816188216, 2.3644162388518453, 0.7573125441558659, 0.25122577557340264, 0.012871234139311127, 0.3741078864550218, 4.122330397367477, 24.0256604924798, 36.79576255381107, 45.8402044326067, 39.162138774991035, 22.479325868189335, 19.724606685340405, 37.01438382267952, 46.816068068146706, 51.6937181353569, 52.75040723383427, 30.91277003288269, 4.0654075518250465, 0.10043582471553236, 0.030308472487377003, 0.02182636464567622, 0.034277982922503725, 0.08870560181094334, 0.030595216085202992, 0.03730140349944122, 0.016113857309392188, 0.022606549246120267, 0.010448542216181522, 0.023696890348219313, 0.021669153647962958, 0.011493874844745733, 0.03883653225784656, 0.020273684094718192, 0.04999562428565696, 0.05777229293016717, 0.04362734413007274, 0.027586675569182262, 0.07289034576388076, 0.05452558980323374, 0.015002319541963516, 0.0594060197181534, 0.042202943805023097, 0.09674784800154157, 0.09034773713210598, 0.05560566329222638, 0.0687176946667023, 0.17538347805384547, 0.08658294813358225, 0.16390450182370842, 0.156710255832877, 0.21168852603295818, 0.14518697338644415, 0.14094282378209755, 0.1714929024456069, 0.08816445741103962, 0.13254969759145752, 0.1531987841008231, 0.2263432857580483, 0.1481090165907517, 0.2028290490852669, 0.0992194446735084, 0.10227797625702806, 0.1495036605047062, 0.11106821082648821, 0.17209315148647875, 0.10199564843787812, 0.1760747589287348, 0.11806558730313554, 0.25118391844443977, 0.2059630793519318, 0.2249329083133489, 0.2641558286268264, 6.499718902632594, 43.633609637618065, 60.788142532110214, 69.04259920120239, 61.17991290986538, 45.21189294755459, 37.80881479382515, 49.14463251829147, 54.28010255098343, 43.90939883887768, 28.293192498385906, 55.89558206498623, 35.93376740813255, 13.646188750863075, 3.1765803834423423, 0.4491980915190652, 0.3002679627388716, 2.787801632657647, 5.6067064963281155, 14.639037474989891, 20.29520496726036, 30.544949769973755, 23.99082586169243, 15.932288579642773, 32.129772529006004, 18.964750058948994, 24.025434404611588, 30.534675121307373, 47.01434522867203, 48.68408963084221, 48.97541619837284, 58.450230583548546, 60.289616882801056, 66.09356984496117, 64.79887291789055, 62.83837951719761, 61.1698130518198, 67.79498934745789, 64.4084058701992, 63.41174215078354, 59.55429174005985, 58.358853086829185, 60.426895916461945, 64.77504819631577, 64.77580815553665, 62.32531204819679, 61.17929734289646, 61.20027221739292, 61.204159408807755, 58.95978324115276, 59.50213573873043, 66.2355150282383, 65.135238468647, 65.29172167181969, 59.56327065825462, 66.37005060911179, 65.5097995698452, 65.39049357175827, 59.432895854115486, 62.86131888628006, 56.10533460974693, 34.05938498675823, 41.53891123831272, 55.02403423190117, 62.1592153608799, 60.186653807759285, 62.668904811143875, 61.2000822275877, 65.694340467453, 62.6382290571928, 59.25733767449856, 49.30422015488148, 50.590994507074356, 60.043302699923515, 64.61408883333206, 59.80046533048153, 56.44194334745407, 54.79342460632324, 57.048949375748634, 58.69362272322178, 61.53553582727909, 58.19638900458813, 60.39351090788841, 56.35048225522041, 60.321113392710686, 59.41581577062607, 63.42697933316231, 65.43510317802429, 58.19350115954876, 56.446594297885895, 53.766153529286385, 48.97224336862564, 40.3200164437294, 28.965359330177307, 25.286653228104115, 27.593043968081474, 27.106485776603222, 20.648369416594505, 21.11218772828579, 21.379959359765053, 23.448433466255665, 17.05107394605875, 13.182634525001049, 10.364628788083792, 2.575145331211388, 0.7437688834033906, 0.3925169486319646, 0.25552180130034685, 0.6528301443904638, 5.049609839916229, 32.87694163620472, 50.83010047674179, 60.75926408171654, 45.900203213095665, 32.712448462843895, 31.406354047358036, 43.887067437171936, 54.50793832540512, 59.30428795516491, 61.008568704128265, 38.90531815588474, 5.990814110264182, 0.15844275505514815, 0.10074072124552913, 0.2947530336678028, 0.09591812689905055, 0.16829797154059634, 0.13120865158271044, 0.16330324346199632, 0.10499074123799801, 0.21614377212245017, 0.10958802697132342, 0.11685081030009314, 0.1275648400769569, 0.11052092886529863, 0.14665259630419314, 0.20473408279940486, 0.1527549055754207, 0.22250663459999487, 0.17934016417711973, 0.12858272530138493, 0.1100623409729451, 0.1511748880147934, 0.15397912269691005, 0.12608765449840575, 0.24799072416499257, 0.17180288268718868, 0.11786902949097566, 0.12953101191669703, 0.16029479942517355], [0.021316893253242597, 0.060016510396962985, 0.01686121671809815, 0.011932955385418609, 0.016372159952879883, 0.0736935054010246, 0.10586161442915909, 0.07856612050090916, 0.03131669494905509, 0.008637400387669913, 0.02377728535066126, 0.022335602261591703, 0.08807100617559627, 0.030830022333248053, 0.06982402905123308, 0.0796394218923524, 0.07421482703648508, 0.011047349635191495, 0.04010258795460686, 0.08123395586153492, 0.028972445252293255, 0.029717932593484875, 0.09213927420205437, 0.13022953615291044, 0.04853493664995767, 0.057591854565544054, 10.532722268253565, 28.826414085924625, 37.36724428832531, 42.60456785559654, 33.3947816491127, 24.831922128796577, 21.205848902463913, 23.484425134956837, 43.64611856639385, 38.1538362801075, 31.81331790983677, 43.46732296049595, 18.66881623864174, 4.1234062146395445, 0.294927972718142, 0.3790012520039454, 0.625120309414342, 2.7739152777940035, 7.421156158670783, 8.82913213223219, 11.44375093281269, 9.52507333829999, 13.308590166270733, 21.112202927470207, 12.700815629214048, 29.509666822850704, 35.97159057855606, 41.794147342443466, 39.97428819537163, 51.91595301032066, 51.218861415982246, 57.18177504837513, 59.227262288331985, 63.42859044671059, 59.76640775799751, 64.73648026585579, 63.380310237407684, 60.13640530407429, 59.49535310268402, 54.82092373073101, 54.052882343530655, 59.974005818367004, 58.95975284278393, 62.97281630337238, 60.07688909769058, 61.13324761390686, 59.06924016773701, 61.9085656106472, 62.736940160393715, 59.77816052734852, 62.416700944304466, 61.14444941282272, 58.47766891121864, 52.58511610329151, 52.779243886470795, 58.78306992352009, 60.246071219444275, 60.17735570669174, 58.02101321518421, 60.28112053871155, 52.100543305277824, 20.850547067821026, 28.05138297379017, 45.449646189808846, 52.299455031752586, 57.49159902334213, 55.01015357673168, 59.77871909737587, 59.34564873576164, 56.83047629892826, 51.06422111392021, 44.97833468019962, 42.35000051558018, 52.038656026124954, 58.53287234902382, 59.559516459703445, 57.47389197349548, 55.99092274904251, 57.973766550421715, 57.65382371842861, 58.3849310874939, 58.55900354683399, 53.51743407547474, 52.54573501646519, 50.08602440357208, 51.59517802298069, 56.04481905698776, 57.20677010715008, 58.29075314104557, 55.48404134809971, 53.125922083854675, 49.557005390524864, 46.42370492219925, 46.46420694887638, 39.27962847054005, 34.209727719426155, 22.895188853144646, 15.38509514182806, 14.652659744024277, 13.222908563911915, 7.10149023681879, 5.19290822558105, 11.569053959101439, 7.333181379362941, 3.0991906486451626, 0.40038006263785064, 0.08615748971351422, 0.042608687072061, 0.07239654296427034, 0.5247276183217764, 8.413539882749319, 36.60745985805988, 53.49803611636162, 35.0056292116642, 30.034709349274635, 34.97772350907326, 31.607365161180496, 32.53121338784695, 48.0375125259161, 48.16683478653431, 35.81540755927563, 6.314312601462007, 0.10471012035850435, 0.025549777055857703, 0.019527612312231213, 0.07536929711932316, 0.08035249964450486, 0.014686660942970775, 0.04213726002490148, 0.08560627436963841, 0.01899812890769681, 0.051957053801743314, 0.01771190534782363, 0.06512925479910336, 0.08490389096550643, 0.06463791592977941, 0.05082446965388954, 0.03793655945628416, 0.02058918591501424, 0.029779144933854695, 0.07023687838227488, 0.05368941943743266, 0.03940007838536985, 0.022234792631934397, 0.0278998563226196, 0.030171089820214547, 0.04726140010461677, 0.052964701098972, 0.04831814418139402, 0.09371918786200695, 0.027132330906169955, 0.011186525516677648, 0.0353028072277084, 0.03368285841133911, 0.03301610551716294, 0.0755850320274476, 0.08723215665668249, 0.04179747884336393, 0.03642396972281858, 0.02405334758805111, 0.07314807138754986, 0.02755556102783885, 0.03124761213257443, 0.036715307214763016, 0.09234419601853006, 0.05815976081066765, 0.024672213403391652, 0.016868959173734765, 0.07775596241117455, 0.0023786482415744103, 0.04279814995243214, 0.046101920524961315, 0.041479706051177345, 0.03215023440134246, 0.03505795044475235, 0.10609519056743011, 12.917911279946566, 37.268685176968575, 50.76603591442108, 54.49423626065254, 43.89970175921917, 32.15056501328945, 25.240151323378086, 31.441179178655148, 47.416682839393616, 40.06611026823521, 24.25926435738802, 40.31655862927437, 20.06154790520668, 4.679301660507917, 0.3457844437798485, 0.4500555095728487, 0.8774572878610343, 3.3827171847224236, 6.905316263437271, 11.45211048424244, 10.247433576732874, 18.505079224705696, 23.450549952685833, 11.382010895758867, 13.762282021343708, 13.86611619964242, 23.174129985272884, 31.979893371462822, 39.16798286139965, 48.77732142806053, 50.59990122914314, 56.136257350444794, 59.76041167974472, 64.62557941675186, 60.35867057740688, 63.625628873705864, 63.80630537867546, 61.70562230050564, 62.14117392897606, 58.380599319934845, 56.63819521665573, 60.741306245326996, 59.54244017601013, 63.515430986881256, 61.0945200920105, 60.443755611777306, 59.311530366539955, 59.69379365444183, 63.122858852148056, 59.81005981564522, 61.6575662791729, 62.72279351949692, 60.46297878026962, 54.591438844799995, 55.27434200048447, 60.61775207519531, 63.13764005899429, 61.758082285523415, 60.01328431069851, 60.3955589979887, 54.24170181155205, 26.949586495757103, 34.70894493162632, 49.419536367058754, 56.56126834452152, 59.09932695329189, 57.71656975150108, 61.204683780670166, 62.6451712846756, 57.608180567622185, 53.46429392695427, 46.088908687233925, 46.23118445277214, 53.97365279495716, 61.745812743902206, 59.762714356184006, 58.81768226623535, 55.588835924863815, 56.21779337525368, 58.24219934642315, 60.55333413183689, 59.57472704350948, 57.37550765275955, 53.83733130991459, 52.97143757343292, 54.78157304227352, 57.91543208062649, 58.29450733959675, 61.618637368083, 56.984778419137, 54.6268605440855, 50.76394222676754, 43.8473329693079, 39.40428838133812, 34.776151925325394, 26.712251231074333, 17.996354922652245, 11.258631516247988, 12.820397112518549, 13.158503919839859, 13.872216772288084, 10.124460775405169, 8.89814592897892, 9.599783979356289, 4.826785996556282, 2.39656750112772, 0.5226423020940274, 0.07051560678519309, 0.0517188726371387, 0.9260982403066009, 8.977203536778688, 35.7280882447958, 53.42049367725849, 34.864314794540405, 32.379825711250305, 38.29411335289478, 36.43956206738949, 38.28750170767307, 52.444082871079445, 56.96451410651207, 42.55259424448013, 8.89410674571991, 0.01017859063722426, 0.04523034229350742, 0.04784396005561575, 0.08453704736893997, 0.07102248622686602, 0.010417551984573947, 0.022614488370891195, 0.04009170435892884, 0.042232366249663755, 0.04341123814810999, 0.055333955606329255, 0.04961993057804648, 0.03461896638327744, 0.022427238945965655, 0.021334124066925142, 0.02948578323412221, 0.056074808235280216, 0.07120233829482459, 0.06581848734640516, 0.012223908815940376, 0.06131539499619976, 0.09542960076942109, 0.07344702331465669, 0.0582670011499431, 0.027674120974552352, 0.08594568818807602, 0.06423223574529402, 0.031589248683303595, 0.08097269761492498, 0.07709277924732305, 0.09229125120327808, 0.13044686667853966, 0.15599412785377353, 0.17274575162446126, 0.30097620910964906, 0.17116479895776138, 0.16629743826342747, 0.18953043065266684, 0.14338284207042307, 0.1337588342721574, 0.11130776125355624, 0.1318598713260144, 0.2653482818277553, 0.13865666755009443, 0.22603698656894267, 0.13889802881749347, 0.13154543819837272, 0.17093636590288952, 0.19387865904718637, 0.13464126270264387, 0.16648062999593094, 0.3311524383025244, 0.13491401681676507, 0.24174525460693985, 17.920816875994205, 52.794473469257355, 65.2170404791832, 65.32370075583458, 51.02814204990864, 39.244544953107834, 34.61338385939598, 36.410128846764565, 56.275561675429344, 52.16606318950653, 46.4212616533041, 55.99381819367409, 23.281459026038647, 5.702166398987174, 0.5163082201033831, 0.6222341861575842, 1.1716643976978958, 5.870684031397104, 13.980083484202623, 21.13532278686762, 24.59383450448513, 18.974441438913345, 28.263383097946644, 33.194125816226006, 23.005850315093994, 39.42462109029293, 41.89921170473099, 45.51431491971016, 46.636254116892815, 57.944713309407234, 54.5892159640789, 58.21616314351559, 60.29104940593243, 63.547809049487114, 59.1326017677784, 64.89587411284447, 66.66734665632248, 63.4856253862381, 64.6532267332077, 59.40908633172512, 60.53485952317715, 63.471980318427086, 62.35264018177986, 63.498407900333405, 62.1829716861248, 62.8941111266613, 58.86100374162197, 59.79813605546951, 63.60329747200012, 61.497302278876305, 63.69877874851227, 65.97899079322815, 63.22522535920143, 56.318043395876884, 56.74172826111317, 63.39651636779308, 65.67725658416748, 65.36457896232605, 60.39827585220337, 62.213818430900574, 56.8294807523489, 31.628965102136135, 40.05437269806862, 54.96568076312542, 60.34345239400864, 61.376521959900856, 59.62968349456787, 63.330616503953934, 66.86753511428833, 60.72693921625614, 56.65066994726658, 48.778662756085396, 48.06559681892395, 57.482939288020134, 64.09229323267937, 62.074635699391365, 59.98253256082535, 55.53686611354351, 56.2530592828989, 61.25370875000954, 61.757405921816826, 63.75215828418732, 59.62633587419987, 56.925174817442894, 55.86750917136669, 57.03757658600807, 61.80812560021877, 62.03481763601303, 62.65234149992466, 57.55154840648174, 54.533993527293205, 51.9743786752224, 49.103138744831085, 45.02914555370808, 43.24765294790268, 39.941435158252716, 28.962826766073704, 26.492539420723915, 27.649349346756935, 25.297155864536762, 17.76867873966694, 14.70163056626916, 24.70196720212698, 13.671617936342955, 6.930337445810437, 2.1887735137715936, 0.6490568281151354, 0.212136649643071, 0.23061648302245885, 1.264744084328413, 10.788601487874985, 45.424632132053375, 65.00897884368896, 47.02480226755142, 44.288804680109024, 45.77320642769337, 42.79855504631996, 47.02557362616062, 62.29432091116905, 63.409922048449516, 52.335332706570625, 11.655033845454454, 0.34205503296107054, 0.13513425656128675, 0.11302953644189984, 0.2906700043240562, 0.18250022898428142, 0.14777084958041087, 0.07929303930723108, 0.17043572792317718, 0.1444727007765323, 0.12893684848677367, 0.18449583440087736, 0.1304005121346563, 0.15550456271739677, 0.14098623942118138, 0.1339232941973023, 0.0732347097073216, 0.1185567703214474, 0.11777935578720644, 0.21633159485645592, 0.09504602174274623, 0.1505950331920758, 0.21599823696305975, 0.15437793801538646, 0.1621865783818066, 0.1422508739051409, 0.18584201607154682, 0.16379148757550865, 0.15123777760891244], [0.00722020121429523, 0.056551408051745966, 0.019505383133946452, 0.05149441749381367, 0.04394650844915304, 0.028123522934038192, 0.05291525179927703, 0.013044839179201517, 0.0717063010961283, 0.07673469299334101, 0.01688655735051725, 0.06606311406358145, 0.04599600491928868, 0.0730411204858683, 0.06567035467014648, 0.08951095820521004, 0.01867957314971136, 0.03170285293890629, 0.012088038274669088, 0.032705910052754916, 0.04747434453747701, 0.06039405947376508, 0.028004348860122263, 0.048391423842986114, 0.05140115550602786, 0.4197010165080428, 21.71658329665661, 44.97661717236042, 46.872225254774094, 48.713234066963196, 42.28145219385624, 30.884799733757973, 39.23767872154713, 30.41885733604431, 25.77613916248083, 16.078016459941864, 48.33384722471237, 33.61577779054642, 7.9043657798320055, 0.9117388701997697, 0.2621421741787344, 0.1363715503248386, 0.4966302932007238, 3.8866964913904667, 4.015672970563173, 7.40991541184485, 8.690299931913614, 18.823885917663574, 17.080472968518734, 10.058559961616993, 19.861802123486996, 20.085465721786022, 35.1917090266943, 43.55677776038647, 54.369006380438805, 54.484360590577126, 57.686171382665634, 62.56032943725586, 65.96619307994843, 61.79268702864647, 60.99594198167324, 62.75405064225197, 60.1440504938364, 59.39377695322037, 55.085172951221466, 51.21627375483513, 56.66934214532375, 58.996683061122894, 61.32550969719887, 58.846317529678345, 58.082315325737, 57.10811220109463, 58.76180626451969, 57.131271958351135, 59.817902594804764, 61.2051397562027, 63.159732073545456, 58.60050491988659, 54.443679973483086, 47.80387066304684, 52.86704957485199, 55.22096246480942, 59.61085930466652, 61.939241364598274, 61.194777712225914, 56.47625930607319, 57.82614827156067, 25.68114995956421, 27.448140643537045, 48.008926659822464, 49.569696709513664, 58.41725215315819, 55.91917499899864, 56.9583660364151, 60.065580904483795, 58.11736844480038, 55.409246161580086, 49.47854720056057, 41.726822555065155, 46.170699298381805, 54.92153853178024, 57.491944804787636, 58.175687715411186, 56.73642374575138, 55.14035739004612, 54.76677283644676, 55.57682856917381, 55.94586856663227, 58.776405081152916, 52.20932386815548, 46.29991136491299, 45.67036114633083, 54.24387909471989, 56.93536967039108, 59.142359644174576, 54.23787921667099, 55.96806697547436, 57.57837876677513, 54.581422582268715, 52.240489795804024, 47.55639374256134, 34.53628979623318, 28.24256781488657, 12.465408761054277, 10.58771101757884, 21.197918727993965, 11.788973808288574, 6.643264750018716, 11.25429879873991, 8.1095115467906, 3.4026915254071355, 2.4874165887013078, 0.2640671865083277, 0.13726558594498783, 0.057631607705843635, 0.1062134889070876, 2.638864587061107, 14.314973764121532, 36.49044133722782, 50.607725009322166, 39.11599405109882, 19.181473329663277, 16.70985985547304, 32.38054007291794, 45.23168608546257, 47.82233767211437, 41.38062313199043, 12.094162032008171, 0.21657430683262646, 0.05031947897805367, 0.0346346219885163, 0.009460851269977866, 0.010935746395261958, 0.06294111401075497, 0.034608598580234684, 0.06158070536912419, 0.056167576694861054, 0.054001485113985837, 0.008059243227762636, 0.026968466554535553, 0.03615335670474451, 0.03991782657976728, 0.11194058315595612, 0.058009962012874894, 0.09571625530952588, 0.05163459063624032, 0.009371912292408524, 0.05901649608858861, 0.04348138965724502, 0.034526973468018696, 0.08346937887836248, 0.040949126123450696, 0.00404391166739515, 0.05066635138064157, 0.08620932130725123, 0.08748290609219112, 0.016001462754502427, 0.06912945304065943, 0.05282514393911697, 0.011088986902905162, 0.056087224365910515, 0.019750497813220136, 0.03164014888170641, 0.00975166833086405, 0.03490490104013588, 0.07764402427710593, 0.0101047497264517, 0.03955436346586794, 0.030366304345079698, 0.06989906760281883, 0.024917912523960695, 0.10455773517605849, 0.05077435613202397, 0.033785352716222405, 0.06785562334698625, 0.0428400107921334, 0.025171973793476354, 0.07753000070806593, 0.0197422506971634, 0.0514671880955575, 0.02308940536750015, 0.8670852694194764, 26.179143637418747, 53.5321506857872, 57.227604389190674, 54.855570271611214, 46.45582839846611, 36.658114939928055, 43.38112458586693, 33.986352905631065, 29.11525748670101, 25.707782730460167, 41.39418080449104, 32.36236944794655, 8.742673471570015, 1.3951770728453994, 0.3779203584417701, 0.27836878784000874, 1.7271506530232728, 5.057541439309716, 7.929305741563439, 13.851505983620882, 11.808740347623825, 17.044407203793526, 19.018764160573483, 15.99101822823286, 17.71532580256462, 20.152448527514935, 33.32476660609245, 41.37824825942516, 50.931600630283356, 53.774798065423965, 57.97798432409763, 63.31253707408905, 64.85403835773468, 62.57664956152439, 61.07716262340546, 66.0956597328186, 62.7112877368927, 59.54723171889782, 56.281059980392456, 53.600626811385155, 59.049952402710915, 61.50147445499897, 62.99489311873913, 60.66183350980282, 59.402307495474815, 58.88927422463894, 58.53476084768772, 57.43164584040642, 60.35497337579727, 61.85995101928711, 64.45072799921036, 61.60086192190647, 56.36695057153702, 50.68075709044933, 53.628950491547585, 58.38483989238739, 61.26838356256485, 62.88279913365841, 62.31499180197716, 58.017714992165565, 58.11416521668434, 31.136963702738285, 33.60953472554684, 53.61534342169762, 53.66346403956413, 58.377187103033066, 57.04935975372791, 58.4596236795187, 62.51969821751118, 60.8340060710907, 56.53270907700062, 52.578379064798355, 43.876021429896355, 48.774520978331566, 56.1839409917593, 59.49655003845692, 59.96144749224186, 58.21848101913929, 55.8511358499527, 54.93268333375454, 57.99067944288254, 59.72192734479904, 60.335203036665916, 55.234079360961914, 50.06238967180252, 48.9218732714653, 55.307054445147514, 59.882362335920334, 60.5985327064991, 54.97728154063225, 55.562347546219826, 57.21415691077709, 55.55816397070885, 48.27476039528847, 40.323595851659775, 28.64728979766369, 24.19184647500515, 12.557703908532858, 9.941757079213858, 14.433629047125578, 18.235498890280724, 14.453719519078732, 12.07380747422576, 11.361015122383833, 6.9952484127134085, 4.673193488270044, 1.3058057497255504, 0.24093635816825554, 0.024369554448639974, 0.07189969735918567, 2.9337800620123744, 17.699064575135708, 37.28612624108791, 45.869299471378326, 38.504215478897095, 23.01273364573717, 24.22570265829563, 37.96660892665386, 49.73650395870209, 54.54994507133961, 47.992044165730476, 15.380809921771288, 0.6744871416594833, 0.04012908633740153, 0.03248252731282264, 0.06989301909925416, 0.035919027286581695, 0.07246360342833214, 0.035323045594850555, 0.08496045746142045, 0.016178644946194254, 0.04355761193437502, 0.03076326614973368, 0.030905489475117065, 0.06287650263402611, 0.03870945060043596, 0.08965473447460681, 0.04625810179277323, 0.08729641180252656, 0.013873223488189979, 0.05290361492370721, 0.041356283181812614, 0.02806510849040933, 0.018767564033623785, 0.09471971425227821, 0.00553243401554937, 0.0379299988708226, 0.10737770338892005, 0.009629030282667372, 0.0821371644269675, 0.15416409558383748, 0.2514077501837164, 0.08034668862819672, 0.10474608483491465, 0.18737070669885725, 0.08315654136822559, 0.12774285161867738, 0.0531388126546517, 0.14193035516655073, 0.18652068043593317, 0.12598808796610683, 0.16576801979681477, 0.12774207978509367, 0.1263079684576951, 0.1924933958798647, 0.2270922760362737, 0.11999306356301531, 0.13201978930737823, 0.12920004373881966, 0.137633424019441, 0.1415909265051596, 0.1690854792832397, 0.1426355290459469, 0.14981171116232872, 0.16897469147806987, 1.5184117038734257, 32.5868272036314, 65.10028794407845, 68.90095800161362, 65.14067977666855, 57.097400575876236, 47.24170982837677, 53.986853286623955, 43.035156950354576, 38.040537759661674, 27.830630019307137, 61.51418477296829, 41.15545481443405, 10.646027438342571, 1.6580808092840016, 0.6683912000153214, 0.4929934727260843, 2.626632093451917, 10.430123023688793, 11.506826598197222, 18.632324896752834, 17.575132325291634, 27.685588002204895, 28.60895175486803, 21.787077113986015, 30.958409383893013, 24.453667625784874, 37.48762562870979, 45.51974482834339, 57.12389275431633, 58.785828575491905, 60.829020738601685, 64.8272117972374, 65.77055677771568, 62.471007630228996, 62.79007650911808, 66.44181355834007, 65.3306619822979, 63.15574988722801, 58.70609365403652, 55.712154507637024, 61.55996851623058, 63.03867056965828, 64.44946646690369, 62.0244137942791, 60.089489221572876, 58.83491054177284, 59.2593477666378, 57.08477005362511, 59.82816204428673, 64.67161014676094, 67.1419107913971, 63.75407338142395, 58.5087588429451, 53.3653624355793, 55.940161272883415, 60.42064145207405, 63.20986658334732, 65.81783384084702, 63.43962885439396, 57.97760434448719, 60.17898201942444, 36.31165713071823, 38.2114601880312, 56.83474726974964, 56.56648926436901, 59.120225831866264, 59.904735535383224, 59.82004188001156, 65.6807903945446, 63.76550316810608, 60.07362127304077, 55.42626164853573, 46.584846675395966, 50.327820628881454, 59.488574266433716, 61.6288398206234, 62.497230023145676, 57.338809221982956, 56.1666215211153, 55.283165127038956, 58.74781921505928, 60.00128835439682, 64.77337628602982, 56.6205907613039, 51.73679642379284, 49.60081323981285, 59.10903923213482, 63.683940544724464, 63.026583418250084, 54.86506976187229, 56.15497514605522, 58.222292214632034, 55.41202761232853, 52.24203631281853, 47.17336669564247, 36.9918130338192, 32.34077140688896, 18.469387739896774, 18.292326740920544, 33.20104144513607, 20.876982249319553, 15.112223234027624, 20.742093287408352, 15.793686266988516, 10.041658468544483, 8.174196425825357, 0.9628889348823577, 0.47975821886211634, 0.2633911493467167, 0.2474817741313018, 4.211366744711995, 18.55775959789753, 47.416983023285866, 65.25913462042809, 52.05786779522896, 28.87384884059429, 28.18680390715599, 46.88413381576538, 58.57985682785511, 64.62977439165115, 56.42547883093357, 20.787726938724518, 1.2230355036444962, 0.1463230382069014, 0.11036573836463504, 0.13113081513438374, 0.13011399860261008, 0.13600562699139118, 0.2574100031051785, 0.23490131716243923, 0.15116170747205615, 0.12555277382489294, 0.12856127723352984, 0.15082869096659124, 0.12097266138880514, 0.10127986926818267, 0.1823958830209449, 0.1671888169948943, 0.1471669046441093, 0.1503364837844856, 0.2032384622725658, 0.15366525360150263, 0.19874140358297154, 0.1276776910526678, 0.12824295525206253, 0.13830189127475023, 0.08519962197169662, 0.12603145907633007, 0.09379112423630431, 0.18336771056056023], [0.03770058247027919, 0.010567100307525834, 0.050595491120475344, 0.0384611650952138, 0.03178689003107138, 0.025175556511385366, 0.058094618798349984, 0.025592159254301805, 0.031233578120009042, 0.021343261760193855, 0.028489730138971936, 0.047671629654360004, 0.05127464530232828, 0.03429595031775534, 0.017198151763295755, 0.08017622472834773, 0.04367142028058879, 0.042447488885954954, 0.04593167555867694, 0.04422461715876125, 0.041245795946451835, 0.03749772753508296, 0.030063914418860804, 0.03157440572977066, 0.02133081779902568, 1.2171049718745053, 21.89963847398758, 56.96501187980175, 52.782306522130966, 41.696792766451836, 28.636895455420017, 27.365063801407814, 22.647134363651276, 63.34635145962238, 68.47327575087547, 48.39369781315327, 40.8695999532938, 17.746354937553406, 5.379015114158392, 0.2919078472768888, 0.03888889819791075, 0.05786124675069004, 2.011213079094887, 2.0802150014787912, 5.953522436320782, 10.511595401912928, 8.965522963553667, 16.70237235724926, 31.149605624377728, 14.130333121865988, 18.95008284598589, 29.390054941177368, 37.77563497424126, 47.60727681219578, 56.52127929031849, 59.55331139266491, 61.17142416536808, 58.20367321372032, 60.245573446154594, 62.31664851307869, 61.86694644391537, 57.263337671756744, 60.23316711187363, 54.38933148980141, 54.072683081030846, 55.62931515276432, 60.129242688417435, 59.65940549969673, 58.19321237504482, 57.89102979004383, 56.64330214262009, 55.31211957335472, 60.56885629892349, 59.127574637532234, 60.05256660282612, 59.90495212376118, 61.26666225492954, 56.00981913506985, 50.41197091341019, 46.54244855046272, 51.73286743462086, 52.1655198186636, 58.10610964894295, 56.96314238011837, 62.15858839452267, 52.794173285365105, 59.56246890127659, 32.38434746861458, 31.56661994755268, 48.76303419470787, 50.06159171462059, 61.060542315244675, 54.083170518279076, 56.698695570230484, 62.49951750040054, 59.07828748226166, 56.25542275607586, 53.86328011751175, 45.94823643565178, 43.75404417514801, 48.29625964164734, 53.589607402682304, 57.780987694859505, 59.04909364879131, 57.00068436563015, 54.804721400141716, 54.48060259222984, 56.41090281307697, 58.632958978414536, 52.901544123888016, 49.04734633862972, 41.89583368599415, 50.661807507276535, 53.6303336173296, 58.476855754852295, 56.34557291865349, 54.03282701969147, 53.40797334909439, 57.260970398783684, 52.4464463442564, 53.913802206516266, 38.15805025398731, 35.36044657230377, 21.59875351935625, 17.238825671374798, 6.797030149027705, 17.730540186166763, 21.5573775395751, 4.922901839017868, 10.875976849347353, 5.1275289338082075, 3.8244000216946006, 0.9480122581589967, 0.19458141352515668, 0.014593220839742571, 0.15316510543925688, 0.10151750495424494, 6.8836569506675005, 27.09674309939146, 40.42055904865265, 47.3954039812088, 33.58381010591984, 29.251520074903965, 30.94240464270115, 34.81804847717285, 49.862676188349724, 43.83339911699295, 23.74108236283064, 0.6523931678384542, 0.03271406996645965, 0.022686851480102632, 0.051149712162441574, 0.027561626229726244, 0.02379939021921018, 0.025148679633275606, 0.027074851568613667, 0.04534659972705413, 0.04656966280890629, 0.0278693800282781, 0.06939693048479967, 0.027941535336140078, 0.037554999071289785, 0.04353767042630352, 0.05305725062498823, 0.044311622841632925, 0.009842351355473511, 0.04073530224559363, 0.03449374380579684, 0.029458880380843766, 0.0361953882384114, 0.01986745286558289, 0.022510285270982422, 0.016104662099678535, 0.04687634420406539, 0.026420681788295042, 0.03573318237613421, 0.04290646640583873, 0.04514161111728754, 0.06626966860494576, 0.04201667215966154, 0.04919893617625348, 0.01960135210538283, 0.013986752601340413, 0.013141755316610215, 0.01776410616002977, 0.005005417324355221, 0.030070387801970355, 0.04911624979285989, 0.07609888023580424, 0.022713904618285596, 0.028403967553458642, 0.0780777947511524, 0.02322122749319533, 0.039718199986964464, 0.021083224346511997, 0.02095723364618607, 0.026325480939703993, 0.05913813038205262, 0.04876667968346737, 0.02638698828377528, 0.028851892639067955, 1.8962395610287786, 28.64992495626211, 65.05930334329605, 62.04392574727535, 51.36558294296265, 35.97176916897297, 33.581363037228584, 33.60600471496582, 60.46952202916145, 50.99084325134754, 32.05946870148182, 41.45579069852829, 19.63370606303215, 5.587438205257058, 0.23286933166673407, 0.14550110965501517, 0.5912322434596717, 4.568199422210455, 7.5316148065030575, 10.474597737193108, 15.127076636999846, 11.125913187861443, 13.917037267237902, 12.163381017744541, 10.42754391208291, 21.41619421541691, 31.749034859240055, 41.212816536426544, 48.66422049701214, 58.34545500576496, 60.56179627776146, 63.55986200273037, 60.19538193941116, 61.52166657149792, 62.29201823472977, 63.601378574967384, 59.987700283527374, 62.14338921010494, 57.820938751101494, 55.954763889312744, 57.54090137779713, 62.41778388619423, 60.13127937912941, 59.59022641181946, 57.98604369163513, 56.71579085290432, 54.983118027448654, 60.786607414484024, 59.62265007197857, 63.38569834828377, 62.24669806659222, 62.759955525398254, 57.793071046471596, 52.03422546386719, 48.334124609827995, 53.909865617752075, 53.42131823301315, 60.71191102266312, 58.03373873233795, 62.83244803547859, 54.87513542175293, 59.766419157385826, 36.86654135584831, 36.746851578354836, 55.3626074641943, 52.194364070892334, 61.31938822567463, 54.84395809471607, 58.265948072075844, 63.59601706266403, 60.165302753448486, 59.493890181183815, 56.58221662044525, 48.65351267158985, 44.81601879000664, 51.590386480093, 56.92064546048641, 59.540950655937195, 59.238494485616684, 56.606102138757706, 54.898139387369156, 54.650563672184944, 57.7927328646183, 60.663828402757645, 55.81110879778862, 51.095155254006386, 45.56793384253979, 52.995209097862244, 56.06198273599148, 61.03051632642746, 57.63818375766277, 56.04272536933422, 54.42837819457054, 54.68117482960224, 54.031831473112106, 51.5909830480814, 38.9074270427227, 28.754911422729492, 21.509813591837883, 11.55970361083746, 9.101020842790604, 13.021076694130898, 14.061790499836206, 9.336947333067656, 11.998455617576838, 7.9009022656828165, 5.700119258835912, 1.9562339480035007, 0.6125996843911707, 0.1999825268285349, 0.10292267252225429, 0.2576821338152513, 7.04629534855485, 27.91352827101946, 37.79054157435894, 45.690222680568695, 33.5916642844677, 29.012539498507977, 37.294626384973526, 40.965225622057915, 55.3904789686203, 50.0588558614254, 28.47926091402769, 1.4762521348893642, 0.03556626965291798, 0.018706218106672168, 0.013575278098869603, 0.019663909588416573, 0.00945080259043607, 0.003252700839766476, 0.07413100145640783, 0.08219958646805026, 0.03536344440362882, 0.030045807870919816, 0.04066176654305309, 0.03022472112206742, 0.025296303938375786, 0.02317239974217955, 0.08600498578744009, 0.038415563831222244, 0.10334132544812746, 0.07159914981457405, 0.02555388113250956, 0.05113942599564325, 0.021285184993757866, 0.013020050519116921, 0.010913241694652243, 0.01463140990381362, 0.03209798349416815, 0.05363161355489865, 0.0208764230410452, 0.1171522781078238, 0.21930658287601545, 0.11799688669270836, 0.11992903106147423, 0.16754304408095777, 0.0965920340968296, 0.12304344636504538, 0.1504746123100631, 0.11205351576791145, 0.11595868942094967, 0.14220633020158857, 0.11554426673683338, 0.20435356884263456, 0.16977537976345047, 0.15952237212331966, 0.10618058207910508, 0.12717880454147235, 0.1435773738194257, 0.1596447968040593, 0.11795571976108477, 0.10595241619739681, 0.17354418378090486, 0.11976214431342669, 0.19010103831533343, 0.10443522885907441, 3.414138173684478, 36.48742809891701, 75.67298501729965, 72.37134978175163, 59.69613432884216, 44.43249396979809, 40.885091722011566, 34.311068281531334, 74.87057447433472, 79.45482328534126, 62.68111355602741, 52.515925616025925, 22.170128859579563, 6.466629803180695, 0.45257527905050665, 0.26987125631421804, 0.6558260461315513, 5.5491837579756975, 6.923417542129755, 15.929712317883968, 24.31295357644558, 19.185123033821583, 30.070949904620647, 41.323531195521355, 22.29287177324295, 23.126419745385647, 31.540864929556847, 42.05193690955639, 49.20058071613312, 58.46184276044369, 62.305891290307045, 63.949550092220306, 60.305154249072075, 60.65083310008049, 63.73955816030502, 63.565037325024605, 61.434446051716805, 65.23472473025322, 59.657513201236725, 57.847180142998695, 59.69527177512646, 64.13017719984055, 61.15733452141285, 60.526598766446114, 57.564627304673195, 56.054329946637154, 56.53671406209469, 62.7564787119627, 62.41568639874458, 65.24350985884666, 64.04196873307228, 65.14641746878624, 60.65619841217995, 54.3670304864645, 50.74167542159557, 57.23490759730339, 56.41311429440975, 62.420618534088135, 60.788134932518005, 65.26496350765228, 56.09403781592846, 60.43662339448929, 41.98576346039772, 43.028476908802986, 57.82263346016407, 53.822234719991684, 60.14249637722969, 56.68889209628105, 57.925178557634354, 66.29533901810646, 63.79008024930954, 62.11247406899929, 58.14989849925041, 50.551883205771446, 47.44714580476284, 53.38043622672558, 58.35451751947403, 61.99986711144447, 61.40046067535877, 58.086445704102516, 54.74383346736431, 56.265845596790314, 58.950557336211205, 63.22969771921635, 57.069426476955414, 54.495619386434555, 46.659706458449364, 55.178898721933365, 58.16708117723465, 64.66502889990807, 57.017213478684425, 55.553566217422485, 55.15215575695038, 58.11804100871086, 56.561249345541, 57.261426374316216, 42.952492386102676, 37.964914217591286, 22.797518894076347, 25.32914064824581, 16.79623492062092, 28.721015341579914, 33.62647421658039, 11.963819526135921, 23.181019015610218, 16.34137272834778, 10.484942682087421, 4.231298575177789, 0.5461175017990172, 0.22300563985481858, 0.2948835922870785, 0.47707235673442483, 9.431627802550793, 34.65247616171837, 53.17798689007759, 61.688880398869514, 45.89755855500698, 39.853770062327385, 42.84005641937256, 49.13234017789364, 64.97535064816475, 58.702829629182816, 35.854431465268135, 3.5545670008286834, 0.19330551323946565, 0.10627611132804304, 0.12297007022425532, 0.11465288800536655, 0.16151913529029116, 0.1416745813912712, 0.1906449138186872, 0.18597578076878563, 0.1586032222257927, 0.06103762767452281, 0.1868762433878146, 0.222318529849872, 0.11322747464873828, 0.14607343910029158, 0.1325196257675998, 0.2681008185027167, 0.2704075025394559, 0.16098916763439775, 0.14652568905148655, 0.16225040308199823, 0.0830319793021772, 0.11265670371358283, 0.11210105774807744, 0.1327767057227902, 0.14283521129982546, 0.08355241036042571, 0.09296542557422072], [0.07320060060010292, 0.025842969916993752, 0.005522003129954101, 0.040974886069307104, 0.025724311635713093, 0.05322308723407332, 0.029884973337175325, 0.028733373510476667, 0.07855932242819108, 0.08273527608253062, 0.04654424425098114, 0.044946749112568796, 0.009280797894462012, 0.04944084292219486, 0.034718629394774325, 0.028977118927286938, 0.06682547042146325, 0.02912675445259083, 0.06954734155442566, 0.027601130750554148, 0.03506064815155696, 0.08955185054219328, 0.05595404225459788, 0.025644549314165488, 0.13147699733963236, 5.0528026185929775, 34.02467764914036, 53.58466386795044, 46.1294487118721, 32.20019415020943, 28.58190480619669, 27.60954838246107, 44.971483647823334, 63.02010476589203, 76.17342576384544, 59.438641145825386, 28.02042033523321, 8.46623070538044, 0.8805991255212575, 0.028280502010602504, 0.17183816438773647, 1.0178710939362645, 2.1455199597403407, 7.252508858218789, 9.125127699226141, 11.639031004160643, 7.9820274375379086, 16.60597912967205, 12.251398544758558, 26.64140023291111, 34.1466549038887, 40.21309778094292, 51.690693497657776, 55.446427166461945, 61.60004496574402, 59.83799211680889, 58.22011113166809, 59.53258730471134, 58.53935860097408, 61.7175954580307, 59.75033842027187, 56.43995225429535, 54.34564143419266, 54.77281451225281, 57.24144324660301, 58.916917741298676, 56.76767326891422, 56.98446303606033, 56.74101009964943, 56.44403703510761, 57.498822435736656, 58.30067440867424, 60.637613609433174, 58.69961880147457, 55.893461778759956, 56.42880365252495, 53.89946177601814, 47.85345420241356, 45.653307661414146, 46.65747977793217, 50.1651855558157, 52.48507887125015, 55.80591827630997, 57.54042640328407, 63.69898393750191, 54.275846779346466, 61.22488349676132, 36.31238289177418, 31.110040247440338, 51.80648848414421, 51.02642074227333, 57.64685869216919, 50.08555702865124, 57.51565173268318, 54.00750517845154, 61.31415210664272, 58.115711733698845, 55.76345555484295, 51.81230217218399, 47.70611710846424, 42.834763303399086, 50.044317841529846, 56.40573889017105, 59.14547547698021, 55.41975259780884, 51.95668302476406, 54.271078035235405, 55.32152406871319, 57.690974324941635, 57.88835473358631, 50.14801047742367, 43.49153906106949, 45.27422100305557, 52.807491570711136, 54.06706318259239, 57.654845863580704, 57.47255064547062, 57.606466859579086, 57.06773556768894, 59.17564205825329, 51.468287631869316, 49.19812984764576, 37.49521762132645, 32.81583331525326, 18.303802125155926, 11.35448232293129, 20.719569995999336, 8.932872265577316, 12.749685756862164, 9.434533696621656, 7.138709239661694, 3.794336747378111, 1.629287616815418, 0.49127130419947207, 0.2573598932940513, 0.033129364674095996, 0.18248347128974274, 1.102288670372218, 13.671555239707232, 36.54430724680424, 43.79177615046501, 25.735867023468018, 18.384545892477036, 19.779452942311764, 36.814313158392906, 47.31838211417198, 50.90186342597008, 25.856913328170776, 5.737593322992325, 0.10137977718841285, 0.09254922173568048, 0.08343371126102284, 0.06401091246516444, 0.00593801261857152, 0.023786532510712277, 0.03259192359109875, 0.09438332097488455, 0.027375182035029866, 0.17798715474782512, 0.02542845260904869, 0.028207105460751336, 0.05711427140340675, 0.060355493769748136, 0.03929316459107213, 0.04292642275686376, 0.008139695746649522, 0.03624390985351056, 0.07787770431605168, 0.08739752200199291, 0.03121504298178479, 0.1702660135924816, 0.01389888509947923, 0.035787926899502054, 0.06347412447212264, 0.030376082140719518, 0.0451572889869567, 0.028217525214131456, 0.02900050771131646, 0.0034414023230056046, 0.014790001296205446, 0.024901878423406743, 0.01982445097382879, 0.009958516948245233, 0.0539130099787144, 0.05893740169994999, 0.05196251229790505, 0.025202440810971893, 0.07287800384801812, 0.01486135137383826, 0.035224525490775704, 0.023423492420988623, 0.018665197749214713, 0.03701860441651661, 0.02483784035575809, 0.074034292192664, 0.024632898130221292, 0.02709937954932684, 0.05010972949094139, 0.06167376326629892, 0.023950161230459344, 0.06323529392830096, 5.758817084133625, 40.356422290205956, 65.1865965127945, 55.02985171973705, 39.49597746133804, 33.81535828113556, 29.228755496442318, 34.64396461844444, 62.24843077361584, 84.2106480896473, 61.07912711799145, 30.078236013650894, 10.484282467514277, 0.9951711120083928, 0.19165568926837295, 0.32648836669977754, 1.5416115964762866, 4.828672120347619, 11.194287668913603, 10.167275927960873, 13.313049226999283, 16.289393417537212, 13.18917017430067, 16.441195271909237, 19.995019175112247, 25.55822465568781, 38.335200548172, 51.79205305874348, 56.056587025523186, 61.05709969997406, 60.51341347396374, 60.495721623301506, 60.3173553943634, 59.90829594433308, 61.73399917781353, 62.151562571525574, 59.135592207312584, 56.30177266895771, 55.3451132029295, 59.46688503026962, 59.81262847781181, 59.87706542015076, 57.01267272233963, 57.03216567635536, 57.29188174009323, 57.9374784976244, 57.74417906999588, 61.03201724588871, 59.13506783545017, 59.030786231160164, 58.95504109561443, 56.419539749622345, 48.62523838877678, 48.42287264764309, 47.93194279074669, 53.02009396255016, 54.42560814321041, 57.22919650375843, 59.10620458424091, 65.76587542891502, 54.543872997164726, 59.777651354670525, 40.75907528400421, 35.759470760822296, 55.49898974597454, 53.075232803821564, 57.953194454312325, 52.38077826797962, 56.855133175849915, 55.262061059474945, 61.89571090042591, 60.25096535682678, 58.323454186320305, 54.239117950201035, 47.81118527054787, 44.745536372065544, 51.595242619514465, 58.2275815308094, 61.39266349375248, 56.363458558917046, 51.14396743476391, 53.81278842687607, 56.961044892668724, 58.957100585103035, 59.1338898986578, 51.3182070851326, 44.522324949502945, 46.60992152988911, 56.10755369067192, 56.72202631831169, 58.356512412428856, 57.631830498576164, 60.64641013741493, 59.75356824696064, 59.34977151453495, 53.73618833720684, 50.62879107892513, 36.135456785559654, 29.495269395411015, 20.70605792105198, 11.669814102351665, 13.023083936423063, 12.739127073436975, 11.331901084631681, 11.429606191813946, 8.657368998974562, 8.419729750603437, 4.864305183291435, 1.355288119520992, 0.5938324914313853, 0.040337373793590814, 0.17272393248276785, 1.9100038474425673, 15.993841476738453, 37.331647798419, 45.28228037059307, 28.93690835684538, 24.14392914623022, 25.51407292485237, 42.851596400141716, 53.58911722898483, 57.95074738562107, 31.752724461257458, 7.057168465107679, 0.052214790557627566, 0.012389943021844374, 0.034440802701283246, 0.027804970886791125, 0.013482736922014738, 0.029774109461868647, 0.08930083393352106, 0.06100276528741233, 0.01699161577562336, 0.07252276744111441, 0.021288968091539573, 0.03276847681263462, 0.042090226415893994, 0.09247289184713736, 0.02937172626843676, 0.04428194435604382, 0.06993023038376123, 0.0031990700017558993, 0.082816459616879, 0.03923361095075961, 0.023110194779292215, 0.06360851257340983, 0.03618342481786385, 0.012547111346066231, 0.04141666431678459, 0.04957414748787414, 0.033137832579086535, 0.20538283861242235, 0.11646483413642272, 0.09563177663949318, 0.16841434029629454, 0.14297261252067983, 0.15002288186224177, 0.14725429995451123, 0.19097430864349008, 0.23475995287299156, 0.20803989056730643, 0.14266435406170785, 0.16723404347430915, 0.0816278433194384, 0.12623182410607114, 0.15408768405904993, 0.09351882283226587, 0.08395273223868571, 0.1244706186116673, 0.1224195450777188, 0.1332465445739217, 0.1273005167604424, 0.1835213796584867, 0.18034800072200596, 0.10896787352976389, 0.33730751427356154, 8.474137131124735, 52.17616684734821, 73.10217216610909, 64.39148917794228, 47.964404448866844, 43.508600145578384, 41.45856074988842, 55.34138560295105, 67.42036744952202, 84.01846200227737, 70.53573668003082, 36.2316220253706, 12.371232714504004, 1.288858896587044, 0.33013789274264127, 0.4932694329181686, 2.6506240060552955, 6.578424079343677, 17.063231393694878, 21.1147677898407, 25.34373376518488, 19.36742775142193, 25.194318182766438, 19.01321265846491, 30.736098513007164, 39.85505439341068, 42.695424780249596, 54.87413987517357, 57.869260758161545, 63.99787589907646, 62.08623647689819, 60.76641149818897, 62.69742228090763, 62.11575709283352, 65.26586785912514, 65.22778630256653, 60.171929597854614, 58.41336116194725, 59.46622386574745, 61.81794427335262, 61.73552289605141, 59.46334362030029, 58.57325278222561, 56.539145931601524, 57.463286742568016, 58.28343853354454, 59.80885908007622, 62.96573728322983, 61.94674216210842, 61.256330609321594, 62.00453706085682, 58.21693070232868, 51.56186141073704, 49.98786047101021, 49.69265431165695, 54.18388031423092, 59.44855101406574, 58.4378432482481, 60.83916999399662, 66.2470056116581, 55.83611525595188, 59.59954351186752, 45.306336879730225, 40.238803401589394, 58.181782588362694, 56.16697870194912, 59.337847754359245, 54.438413456082344, 57.185810431838036, 56.48793987929821, 61.95569448173046, 63.99897024035454, 61.33087120950222, 57.39360608160496, 51.074659153819084, 47.98675484955311, 53.45295533537865, 61.024159267544746, 61.72887705266476, 57.32428640127182, 50.91532610356808, 55.49182713031769, 56.64386071264744, 60.92936955392361, 62.939229905605316, 55.31892880797386, 47.76032879948616, 49.10963639616966, 58.10876190662384, 59.036995097994804, 62.43829518556595, 60.08176803588867, 61.30209155380726, 60.62040813267231, 62.130238115787506, 55.773468017578125, 53.100934624671936, 39.689907655119896, 35.71700803935528, 22.82503891736269, 15.651945322751999, 37.12317578494549, 18.15295021981001, 23.191977627575397, 19.026331454515457, 12.653018943965435, 10.61252273619175, 5.778221692889929, 2.430343651212752, 0.7179214234929532, 0.1353278532042168, 0.345084746950306, 2.064485982991755, 18.578422889113426, 46.2942648679018, 56.34107396006584, 38.59860621392727, 26.63166895508766, 32.413499504327774, 50.91569468379021, 60.483262091875076, 65.37040784955025, 39.562736079096794, 10.281219463795424, 0.21687079482944682, 0.15479636087547988, 0.16396155813708901, 0.11987497302470729, 0.0719431352626998, 0.17849855386884883, 0.15382138662971556, 0.17452536238124594, 0.09283930499805138, 0.31654863443691283, 0.11653486319119111, 0.15498206106713042, 0.17163395503303036, 0.16042719857068732, 0.15229495213134214, 0.10662442349712364, 0.10289808516972698, 0.09932686312822625, 0.19087359920376912, 0.17451139516197145, 0.09990783117245883, 0.2026486923568882, 0.11649603402474895, 0.17659920500591397, 0.13288281799759716, 0.1431488577509299, 0.1939670043066144], [0.024407255550613627, 0.06808318066759966, 0.022670091930194758, 0.07750553952064365, 0.033390519020031206, 0.03907521808287129, 0.04368788853753358, 0.03828869368589949, 0.03038057213416323, 0.03280866039858665, 0.011102314019808546, 0.065812104876386, 0.015096352435648441, 0.052590458290069364, 0.006027556446497329, 0.0603221045457758, 0.06605604881769978, 0.006362843923852779, 0.058780526524060406, 0.011134321921417722, 0.03649530866823625, 0.04606656832038425, 0.05766503032646142, 0.002598849487185362, 0.2911580406362191, 10.581059474498034, 39.15084198117256, 50.63042879104614, 43.69310304522514, 33.55542182922363, 24.70603298395872, 25.666328854858875, 51.26055657863617, 41.175130158662796, 20.951845832169056, 26.0103851929307, 17.3941233381629, 3.6330313654616475, 0.5371233844198287, 0.08785750513197854, 0.3270319750299677, 1.1843800591304898, 6.742836032062769, 8.672739174216986, 9.496635664254427, 10.717563349753618, 12.936401087790728, 11.542930360883474, 16.96104347705841, 17.714763432741165, 30.094634033739567, 48.96845877170563, 53.05740796029568, 57.656168192625046, 57.94806092977524, 64.19730439782143, 59.211371541023254, 57.2358613461256, 61.5435191988945, 57.605805695056915, 56.933519169688225, 55.00792309641838, 56.34775400161743, 57.43178263306618, 59.358632639050484, 56.64200261235237, 55.2473596483469, 55.8830351382494, 57.24788770079613, 54.925972893834114, 55.01171909272671, 56.82250052690506, 60.061849504709244, 55.48359677195549, 52.37704686820507, 48.007315546274185, 46.250859797000885, 43.81481811404228, 43.33912543952465, 48.71147856116295, 58.004962876439095, 53.444599583745, 56.98144979774952, 54.0557511895895, 60.76518416404724, 52.69622214138508, 58.97511161863804, 39.255959540605545, 32.0472751557827, 57.436832562088966, 52.27934271097183, 52.509838342666626, 55.32476529479027, 58.41349795460701, 56.661788150668144, 57.965114414691925, 55.19270718097687, 55.74314184486866, 53.94972927868366, 50.74104085564613, 40.77403128147125, 45.25736130774021, 55.28447985649109, 57.77015067636967, 57.37042732536793, 52.48703196644783, 54.70982529222965, 54.20773543417454, 54.747857451438904, 56.20613180100918, 53.93426790833473, 45.98252959549427, 43.24986442923546, 49.59687665104866, 54.57994066178799, 58.06097187101841, 56.520899310708046, 58.04456055164337, 56.760951429605484, 58.610654175281525, 59.15394142270088, 52.198395654559135, 42.04893507063389, 37.92622469365597, 25.880380868911743, 16.41927994787693, 7.430165475234389, 9.14882892742753, 7.629777314141393, 8.02792327478528, 8.06660519912839, 8.187315221875906, 0.9260353655554354, 1.433006061706692, 0.3311227820813656, 0.06897691942867823, 0.09912380410241894, 0.20010509993880987, 5.398159436881542, 20.017603263258934, 43.00106517970562, 33.08166705071926, 17.50906527042389, 20.153162889182568, 26.669678315520287, 39.429359436035156, 52.864902690052986, 42.759531140327454, 13.47134493291378, 0.44867487740702927, 0.018771033574012108, 0.0608191208448261, 0.06476183974882588, 0.019992189336335286, 0.048545820245635696, 0.03559394805051852, 0.029321809415705502, 0.0888160927570425, 0.020625777506211307, 0.07267203560331836, 0.06199585535796359, 0.08926343711209483, 0.020063875235791784, 0.043981786438962445, 0.024694297862879466, 0.01670441204623785, 0.035697533312486485, 0.040686216598260216, 0.03527027147356421, 0.07735586317721754, 0.05482031891006045, 0.023625618196092546, 0.040230055528809316, 0.02529575660446426, 0.029928526273579337, 0.06694905285257846, 0.010393986012786627, 0.06863166490802541, 0.11032330978196114, 0.04329314760980196, 0.055004200839903206, 0.031547142934869044, 0.07836034521460533, 0.10457738724653609, 0.059093319505336694, 0.0828946522960905, 0.0654637704428751, 0.0633081654086709, 0.032799687833175994, 0.009523088701826055, 0.051884297354263254, 0.024666812423674855, 0.020251540263416246, 0.04321280270232819, 0.05041483382228762, 0.006180443970151828, 0.051466397708281875, 0.023279287561308593, 0.051431843312457204, 0.02636964614794124, 0.29714749893173575, 12.823192812502384, 47.300789058208466, 60.140269696712494, 51.894609555602074, 39.20713596045971, 31.883579939603806, 32.30660364031792, 51.62029467523098, 47.48147316277027, 36.20943121612072, 32.46439777314663, 17.35599048435688, 4.96408355422318, 0.3103183937491849, 0.2064607635838911, 0.8695401158183813, 5.048206765204668, 6.272558066993952, 15.157799888402224, 12.87423262372613, 12.20026658847928, 8.65772807970643, 12.527961004525423, 14.403599258512259, 17.67291247844696, 31.154851242899895, 42.931190729141235, 53.14625099301338, 56.38780005276203, 58.84571336209774, 63.98726686835289, 60.33633157610893, 61.06800131499767, 62.96341560781002, 60.33770330250263, 60.19776061177254, 56.73065945506096, 57.0274843275547, 58.35253402590752, 60.919961258769035, 58.70989724993706, 57.45143137872219, 54.748852998018265, 57.96091563999653, 53.993996903300285, 56.96600362658501, 57.66011618077755, 61.58388443291187, 57.07570753991604, 55.72400227189064, 50.77012449502945, 47.90677674114704, 45.22460326552391, 46.1444541066885, 50.573336854577065, 59.33997943997383, 55.51351256668568, 59.42139007151127, 57.26568974554539, 63.26624795794487, 54.775033593177795, 59.752295315265656, 41.226313412189484, 36.212839633226395, 60.48260472714901, 52.62703165411949, 55.05247950553894, 55.08947052061558, 58.69342893362045, 57.68822707235813, 56.76205337047577, 55.57503506541252, 58.68200294673443, 56.535194143652916, 52.00810186564922, 43.55336934328079, 47.4254185706377, 55.22152483463287, 60.296673104166985, 58.26944388449192, 53.42973858118057, 53.76421183347702, 55.37912517786026, 56.012296602129936, 59.574016481637955, 54.684666842222214, 47.42161117494106, 45.7581402361393, 52.39215485751629, 58.63184563815594, 60.051346868276596, 58.642143085598946, 60.00167213380337, 58.436433523893356, 60.68484887480736, 58.35300140082836, 53.19475159049034, 43.75190868973732, 32.8618336468935, 25.100136436522007, 19.300047867000103, 12.427793629467487, 12.87454990670085, 8.100708369165659, 11.42984937876463, 12.298125587403774, 8.026776686310768, 6.92356145940721, 2.6495527010411024, 0.6945412780623883, 0.11904807208338752, 0.05956564826192334, 0.31575349741615355, 6.319126943126321, 23.98522686213255, 41.19025334715843, 33.38874377310276, 22.790971845388412, 26.034863479435444, 34.61111918091774, 45.371989756822586, 59.483007565140724, 49.927994683384895, 16.557094752788544, 0.6679374806117266, 0.04512459738180041, 0.05675362473994028, 0.04052247655636165, 0.06337049097055569, 0.0493748363078339, 0.059474787121871486, 0.059322353699826635, 0.04918952203297522, 0.005663761685354984, 0.0697835003666114, 0.10989129819790833, 0.07034675334580243, 0.05652264611853752, 0.014213994509191252, 0.08994627234642394, 0.05048724888183642, 0.06671139490208589, 0.040122536884155124, 0.07523968102759682, 0.03400316563784145, 0.03492920266580768, 0.030273166667029727, 0.042507877442403696, 0.03519585261528846, 0.06484145735157654, 0.06501386567833833, 0.10900641325861216, 0.08251146660768427, 0.15176363376667723, 0.11170864716405049, 0.11636338254902512, 0.11398195681977086, 0.2109481001389213, 0.16676656465278938, 0.1213321799878031, 0.2019395850948058, 0.1857647139695473, 0.20505587803199887, 0.08004646020708606, 0.1317742868559435, 0.07793942873831838, 0.21290224918629974, 0.16741483064834028, 0.14807987987296656, 0.09789168310817331, 0.10214944370090961, 0.09110910643357784, 0.12533388478914276, 0.20367727935081348, 0.06580854998901486, 0.6410012010019273, 17.295872010290623, 57.89410762488842, 70.55899903178215, 62.18959093093872, 47.43017591536045, 38.01990486681461, 37.7401714771986, 63.427207320928574, 52.26755194365978, 35.867191180586815, 36.1270060390234, 21.214865818619728, 5.052480110898614, 0.8944654720835388, 0.3734234778676182, 1.0951847140677273, 3.933377698995173, 12.569834757596254, 22.325669713318348, 20.2539923787117, 22.13524103164673, 21.89641624689102, 20.59682708233595, 24.07871324568987, 21.555321849882603, 32.384628653526306, 51.054474636912346, 56.772966384887695, 57.53494709730148, 58.68747465312481, 66.81364640593529, 61.2091713398695, 63.739105984568596, 64.22751277685165, 61.09491527080536, 61.67699843645096, 59.595660120248795, 60.88807716965675, 61.511167734861374, 63.465771451592445, 60.022867396473885, 56.09898895025253, 55.49180433154106, 57.98794358968735, 56.006285324692726, 57.75214724242687, 58.628912195563316, 61.985025107860565, 58.491443172097206, 57.216877564787865, 51.38420194387436, 48.75256955623627, 47.30943359434605, 46.963260769844055, 54.33123640716076, 62.64375776052475, 59.4964512437582, 61.290486976504326, 59.05027158558369, 62.625188156962395, 55.28902821242809, 57.77014687657356, 44.49941597878933, 42.554319351911545, 61.10434256494045, 55.81710487604141, 55.98271518945694, 57.20069423317909, 62.051867321133614, 58.263660594820976, 58.436346128582954, 57.22137652337551, 60.78564986586571, 59.62709203362465, 54.58354286849499, 44.526356533169746, 49.86391872167587, 58.696654960513115, 62.99519330263138, 59.40158173441887, 53.975294306874275, 55.016183853149414, 56.272525638341904, 56.741675063967705, 62.05009661614895, 59.0376790612936, 50.92953734099865, 47.4985608458519, 54.903652891516685, 60.78491270542145, 63.57377305626869, 60.41577011346817, 63.86889562010765, 61.83808699250221, 63.63669008016586, 61.66624501347542, 55.62452740967274, 43.68104249238968, 40.72503671050072, 28.095093928277493, 22.55478411912918, 13.010995835065842, 17.767337411642075, 20.931060947477818, 22.709046341478825, 20.893319472670555, 18.01283273845911, 6.4276928175240755, 3.046751799993217, 1.2535200803540647, 0.25976914213970304, 0.14654073980636895, 0.6577404902782291, 7.2873947862535715, 27.762269787490368, 56.1336050927639, 44.952473267912865, 28.717681020498276, 30.972309038043022, 39.57392267882824, 51.26059077680111, 67.89688467979431, 57.93248936533928, 20.743166729807854, 1.1938024847768247, 0.1447113012545742, 0.14835088251857087, 0.12697870668489486, 0.1251360133755952, 0.1158794057846535, 0.23795624932972714, 0.15115254936972633, 0.12804443074855953, 0.10818320821272209, 0.15591059171129018, 0.2322992731933482, 0.13389767525950447, 0.13077361945761368, 0.10520341107621789, 0.15152440988458693, 0.10347072631702758, 0.1714271926903166, 0.14081392757361755, 0.12228730920469388, 0.1394285901915282, 0.1654996443539858, 0.1752654617303051, 0.08906201823265292, 0.07236639692564495, 0.160451837873552, 0.19161927950335667], [0.011191658395546256, 0.054607025667792186, 0.040172802546294406, 0.045099386625224724, 0.03849942280794494, 0.01882446635136148, 0.03539532706781756, 0.02815808475133963, 0.01941008766152663, 0.012663701818382833, 0.0314794071164215, 0.08112851894111373, 0.031379473221022636, 0.02443675035465276, 0.0479115622874815, 0.04906690439383965, 0.0322993058944121, 0.038053332682466134, 0.13785571209155023, 0.04699126577179413, 0.05486149326316081, 0.05169520925846882, 0.0678375520510599, 0.08394643882638775, 1.899566757492721, 15.947293974459171, 42.61534787714481, 54.12908725440502, 47.44651883840561, 29.82868440449238, 21.03035531938076, 16.090586185455322, 13.444337882101536, 27.943666353821754, 34.14170376956463, 34.20283108949661, 8.293676264584064, 1.5767030697315931, 0.05552114009333309, 0.20587344275554642, 0.7508723647333682, 4.017062745988369, 1.491488367319107, 12.336164396256208, 6.722990171983838, 9.427273236215115, 12.252555582672358, 12.619772627949715, 21.978740729391575, 29.301626086235046, 41.633765548467636, 46.85186594724655, 59.915249571204185, 58.67702141404152, 60.06569489836693, 57.25385718047619, 58.77655327320099, 60.343760177493095, 56.89292974770069, 55.71672186255455, 54.43478465080261, 55.7643599063158, 57.93164201080799, 61.12966440618038, 57.65526384115219, 57.18656279146671, 56.36886186897755, 54.30385887622833, 54.67849217355251, 53.876001834869385, 55.705869644880295, 55.769702419638634, 56.80892005562782, 52.32131905853748, 47.802145555615425, 43.470560386776924, 44.12865847349167, 41.8384225666523, 49.128848165273666, 56.874926313757896, 57.414862141013145, 56.60869739949703, 60.06819136440754, 60.0888242572546, 60.83360329270363, 53.818985894322395, 60.56935027241707, 41.043953597545624, 33.25450457632542, 65.12469783425331, 49.392310827970505, 58.474241495132446, 57.35973849892616, 56.56604088842869, 59.47636552155018, 61.62840664386749, 53.55558782815933, 54.66780334711075, 56.40438236296177, 54.36822362244129, 41.75581879913807, 43.472954258322716, 49.49131451547146, 54.817823097109795, 55.333071649074554, 50.795127153396606, 51.05942577123642, 53.79620611667633, 54.06789153814316, 55.42373098433018, 55.56071363389492, 48.700189366936684, 45.11755160987377, 45.46687826514244, 49.49762597680092, 54.71977695822716, 57.04278990626335, 54.380265176296234, 56.64673715829849, 55.494312196969986, 56.01937562227249, 55.079116076231, 50.424806624650955, 41.44498407840729, 39.1172631829977, 33.867913261055946, 17.56576582789421, 15.08604833856225, 5.437272163107991, 9.195338431745768, 7.771034734323621, 6.6730238031595945, 9.663256723433733, 1.152157906908542, 0.5815405072644353, 0.05131130739755463, 0.02810921989294002, 0.09294341347413138, 2.0057988446205854, 13.702121749520302, 36.59781597554684, 41.49354167282581, 26.3831489905715, 12.652709260582924, 22.470981515944004, 35.537380278110504, 48.59523519873619, 50.79464077949524, 16.655009798705578, 1.6164000146090984, 0.0386304749554256, 0.013853814471076475, 0.02493218402378261, 0.03502364095766097, 0.04633477677998599, 0.0280423635194893, 0.06123214458057191, 0.07419848494464532, 0.049951666878769174, 0.05318026160239242, 0.11428812984377146, 0.045079819901729934, 0.039384797564707696, 0.030965803816798143, 0.009768772051756969, 0.02086124241031939, 0.03781993465963751, 0.03485066117718816, 0.05538392440939788, 0.028218120787641965, 0.02663643710548058, 0.05240820908511523, 0.08098092061118223, 0.014366044797498034, 0.029856159453629516, 0.06455952287069522, 0.0349130424001487, 0.027130687049066182, 0.002762282001640415, 0.03278126772784162, 0.08372720840270631, 0.061029085554764606, 0.06604282374610193, 0.07102600400685333, 0.035650265926960856, 0.012374855159578146, 0.03291370769147761, 0.059721091092796996, 0.0661480009148363, 0.03379428817424923, 0.021412235109892208, 0.07802656429703347, 0.06613947363803163, 0.03351659506733995, 0.08360445717698894, 0.030857518904667813, 0.016843770681589376, 0.08729376233532093, 0.0814155742409639, 0.07370105304289609, 2.2037884080782533, 19.968175515532494, 50.07306709885597, 62.24118456244469, 53.48668232560158, 36.21976286172867, 25.928402692079544, 22.930234372615814, 22.03526459634304, 32.38801047205925, 36.28469757735729, 33.01149241626263, 8.788903690874577, 1.7352929036132991, 0.030803386653133202, 0.3697502030991018, 1.8073878600262105, 5.091682132333517, 11.030805241316557, 14.98440284281969, 13.666976485401392, 16.487972661852837, 13.929807431995869, 10.913819018751383, 18.355412855744362, 27.525310702621937, 39.81702983379364, 47.90319353342056, 58.290156573057175, 57.82084375619888, 61.77867718040943, 59.33527909219265, 61.698125302791595, 61.48242607712746, 59.22714829444885, 57.20233574509621, 55.91351330280304, 57.10754983127117, 60.4618464410305, 62.064585238695145, 60.66162832081318, 57.75699958205223, 56.32403567433357, 55.21772123873234, 56.47450380027294, 56.36201463639736, 57.52658374607563, 58.47380451858044, 58.9225148409605, 53.77312995493412, 49.85327169299126, 44.602040871977806, 46.57052904367447, 43.71370553970337, 50.50160050392151, 58.276994079351425, 59.44576196372509, 58.51066254079342, 61.33251652121544, 60.931193456053734, 61.290931552648544, 54.12236161530018, 60.77608957886696, 43.34313042461872, 37.098416313529015, 67.90077567100525, 49.64305557310581, 57.43188142776489, 58.483098819851875, 59.19885501265526, 61.815432608127594, 62.978922575712204, 53.74522045254707, 55.415120646357536, 59.730454087257385, 54.381028935313225, 44.22749876976013, 46.268034875392914, 52.069947347044945, 58.09094466269016, 57.44426116347313, 52.71861433982849, 50.91692581772804, 54.8059107363224, 54.69996862113476, 56.635995134711266, 58.12971778213978, 50.75565107166767, 46.77306577563286, 47.72062472999096, 52.824697047472, 57.26853959262371, 58.547558560967445, 57.31945686042309, 60.04699990153313, 58.99577111005783, 60.11706054210663, 54.365020394325256, 50.50418056547642, 39.972468093037605, 32.20808632671833, 27.005756981670856, 17.39942405372858, 14.315206501632929, 7.606707802042365, 9.24692826345563, 11.49637145921588, 11.306476648896933, 11.764357779175043, 3.466613357886672, 1.428503303322941, 0.24876760435290635, 0.0882245045795571, 0.14273778215283528, 2.5211507035419345, 15.220124144107103, 39.93266522884369, 42.0757882297039, 25.136688575148582, 16.88641358166933, 25.922797992825508, 42.827729880809784, 55.07519468665123, 58.3965128660202, 21.426719650626183, 1.807964004110545, 0.035314588822075166, 0.005183706707612146, 0.05649980652378872, 0.02695572387892753, 0.1002471188257914, 0.07546575405285694, 0.011604325900407275, 0.030154057531035505, 0.018190852206316777, 0.11570430346182548, 0.06481623917352408, 0.05827011074870825, 0.0782769797660876, 0.05679249843524303, 0.04390043221064843, 0.04933780313876923, 0.027915344944631215, 0.04531018254056107, 0.0923708539630752, 0.012463449038477847, 0.03293583853519522, 0.024782934415270574, 0.05897500261198729, 0.05024121950555127, 0.04244484312948771, 0.024005521736398805, 0.16418645856902003, 0.15711085230577737, 0.18628387595526874, 0.09593604976544157, 0.10283013412845321, 0.14671557495603338, 0.09576780488714576, 0.09215848098392598, 0.10799155599670485, 0.15365026221843436, 0.11144917749334127, 0.14705581997986883, 0.2175531699322164, 0.08129021807690151, 0.1598940693656914, 0.13266337977256626, 0.14446903456700966, 0.1836653711507097, 0.20195039076497778, 0.09545966517180204, 0.17130791471572593, 0.18212287657661363, 0.17923647130373865, 0.24411833117483184, 2.851111222989857, 26.46681100130081, 59.964745715260506, 71.4424592256546, 61.677648201584816, 45.23910328745842, 32.59227991104126, 26.406358145177364, 23.056729584932327, 40.901959016919136, 45.83980545401573, 44.22105431556702, 10.08590329438448, 2.345639308914542, 0.15104265214176849, 0.7920104416552931, 1.6360056563280523, 12.821386009454727, 12.458429485559464, 24.403364025056362, 17.222081869840622, 15.193650014698505, 20.24400271475315, 17.789849303662777, 26.321259811520576, 32.338217943906784, 47.027188539505005, 47.450390830636024, 61.463506892323494, 58.985819444060326, 62.541889026761055, 61.33794263005257, 63.916491866111755, 62.239596247673035, 61.41375616192818, 59.02141593396664, 58.15228097140789, 58.42753820121288, 62.58886210620403, 63.76227334141731, 61.22485309839249, 58.851565048098564, 57.388217970728874, 56.16509020328522, 56.786995232105255, 57.73438699543476, 59.13031429052353, 59.153481647372246, 61.167681366205215, 55.24631090462208, 52.827402502298355, 46.26120284199715, 47.83947475254536, 45.6753046810627, 53.97247865796089, 61.11899457871914, 62.2529449313879, 62.03354090452194, 63.81160989403725, 60.426854118704796, 63.824514001607895, 54.949676021933556, 60.46749293804169, 45.04224345088005, 42.71745979785919, 62.98400290310383, 52.7972549200058, 59.22223135828972, 61.54904790222645, 61.18659295141697, 65.41488826274872, 66.1993257701397, 56.02639764547348, 55.939792692661285, 60.31172789633274, 57.80382066965103, 46.938075721263885, 47.21581421792507, 54.001550897955894, 59.03365507721901, 60.247040167450905, 54.168570935726166, 50.95249950885773, 54.854320138692856, 55.00764191150665, 57.7796995639801, 60.16396142542362, 54.33212175965309, 51.81409187614918, 50.08816748857498, 54.2451748251915, 61.13039016723633, 61.1402278393507, 59.943470656871796, 62.83911667764187, 60.39220757782459, 61.399681717157364, 57.23892778158188, 51.27028025686741, 44.50962983071804, 43.16551275551319, 35.642452239990234, 22.001868188381195, 24.843194223940372, 17.52964686602354, 22.83187285065651, 18.240662813186646, 16.904152929782867, 26.049091815948486, 4.252343270927668, 1.718185271602124, 0.36495705717243254, 0.23627734801266342, 0.33858863927889615, 3.0613862397149205, 17.802567221224308, 48.13845410943031, 53.0310183763504, 35.60946621000767, 21.642544269561768, 34.02692712843418, 50.13245791196823, 61.38803914189339, 67.12557166814804, 28.139190562069416, 2.5975558161735535, 0.14539303811034188, 0.10960078448988497, 0.20426605478860438, 0.1497481091064401, 0.1191133885004092, 0.1778342277975753, 0.17194291111081839, 0.20370926591567695, 0.14371619996381924, 0.31220900011248887, 0.17233765946002677, 0.14144043379928917, 0.16751549555920064, 0.13089090847643092, 0.13081961777061224, 0.09306838372140191, 0.10166488806135021, 0.21085258573293686, 0.20913243584800512, 0.08517882699379697, 0.09496987739112228, 0.15149822691455483, 0.1794772982248105, 0.19555785722332075, 0.13453691673930734, 0.13744748634053394], [0.06626997288549319, 0.014772578451811569, 0.03283467267465312, 0.06442493438953534, 0.05195384401304182, 0.04440331147634424, 0.053159770905040205, 0.03474284567346331, 0.0686125917127356, 0.018780991340463515, 0.011781162065744866, 0.02729102248849813, 0.04546463089354802, 0.11186131436261348, 0.04607663555361796, 0.03134816201054491, 0.015813565805729013, 0.04162956422078423, 0.06563031580299139, 0.035068318247795105, 0.046308026066981256, 0.12053952916176058, 0.037453117038239725, 0.059852466074517, 4.833166804164648, 22.785030864179134, 41.02878861129284, 59.43397119641304, 42.67292998731136, 31.614265590906143, 23.625595159828663, 22.86523126065731, 28.20858433842659, 46.61187842488289, 41.038637682795525, 15.575473476201296, 3.921476025134325, 0.35928031022194773, 0.017441034433431923, 0.37487390160094947, 1.6794557310640812, 3.603430478833616, 8.040223214775324, 12.67552038654685, 13.65261610597372, 11.982657965272665, 10.38420058786869, 13.885638602077961, 20.219564326107502, 28.907423838973045, 45.91649293899536, 52.037310898303986, 56.470878794789314, 59.18757721781731, 55.938823744654655, 60.72255805134773, 63.3470544219017, 54.8092545568943, 56.600698828697205, 54.76899951696396, 55.61277464032173, 58.05971413850784, 59.36424493789673, 58.568465039134026, 56.69081099331379, 56.31189912557602, 55.5733897536993, 53.91088396310806, 55.91962717473507, 54.25787374377251, 55.84178455173969, 57.05623738467693, 57.486697286367416, 48.62721428275108, 45.9117241948843, 42.295237854123116, 43.823876827955246, 42.86475129425526, 55.12612335383892, 59.17305439710617, 61.38652302324772, 55.03927141427994, 56.48001350462437, 50.85428237915039, 56.608040034770966, 54.030881524086, 58.50965939462185, 44.41015496850014, 32.034743428230286, 61.91502906382084, 49.026014283299446, 62.88257114589214, 53.88189911842346, 55.24267449975014, 52.23080411553383, 58.24486680328846, 55.88991276919842, 54.09795552492142, 55.510442331433296, 56.147998720407486, 44.65708091855049, 42.38012909889221, 48.013463616371155, 55.7475496083498, 56.58457249403, 55.3692989051342, 51.59843064844608, 53.5680815577507, 51.92300543189049, 55.24845398962498, 55.61912029981613, 53.75247426331043, 48.74621629714966, 43.59775476157665, 42.80746176838875, 48.252770975232124, 49.24665704369545, 49.207017570734024, 52.012760415673256, 57.519744113087654, 58.35223004221916, 55.81977613270283, 53.80308374762535, 46.128646954894066, 36.03471279144287, 37.45843179523945, 35.44658035039902, 20.45364886522293, 5.09307618252933, 6.015763571485877, 12.289671041071415, 5.22172967903316, 8.946583829820156, 3.7636408070102334, 0.5107228166889399, 0.33575179462786764, 0.148796898429282, 0.05170756601728499, 0.35421672568190843, 4.82349774800241, 21.773777827620506, 41.78221598267555, 32.43839576840401, 26.255511939525604, 28.187869749963284, 41.62322111427784, 46.51295453310013, 55.87795481085777, 29.163408502936363, 3.4616581862792373, 0.20471576659474522, 0.10250255014398135, 0.10667238107998855, 0.006674147971352795, 0.043658870563376695, 0.053110963563085534, 0.003213571567357576, 0.054012272230465896, 0.03473473399935756, 0.06117188589996658, 0.04647015193768311, 0.07420747977448627, 0.048168979919864796, 0.08750871056690812, 0.020286883191147354, 0.031222126781358384, 0.009797526563488645, 0.027193838250241242, 0.03546643965819385, 0.07131765320082195, 0.09211562195559964, 0.03329613638925366, 0.06465596496127546, 0.012234985370014329, 0.032586101442575455, 0.025568154487700667, 0.027779838055721484, 0.04423164529725909, 0.02368793448113138, 0.043925015852437355, 0.06037985105649568, 0.10406789544504136, 0.07622154240380041, 0.04153636902628932, 0.05506641879037488, 0.013266655059851473, 0.07249680711538531, 0.009058612795342924, 0.0477952157962136, 0.005859952134414925, 0.027790864514827263, 0.054612131643807516, 0.05162672016012948, 0.08347147915628739, 0.03749023555428721, 0.018446711328579113, 0.003720189633895643, 0.05117562053783331, 0.026992662424163427, 0.06312026845989749, 5.479239961132407, 27.44781956076622, 50.143747106194496, 65.12106522917747, 50.830902233719826, 36.47811859846115, 29.698408395051956, 22.206620201468468, 20.68578790873289, 37.139157727360725, 38.67890730500221, 17.37869616597891, 3.9868377428501844, 0.7143833977170289, 0.13122537959134206, 0.49518752843141556, 2.574963653460145, 12.210964914411306, 10.764172598719597, 12.254566624760628, 15.901854112744331, 16.983224786818027, 8.243488557636738, 15.993923172354698, 17.508666291832924, 34.22702819108963, 46.55463069677353, 53.03602650761604, 58.93550254404545, 59.68807876110077, 57.803668677806854, 61.99806600809097, 63.807475715875626, 57.65103466808796, 59.1174291819334, 57.2361995279789, 58.00553284585476, 60.56390516459942, 61.46000348031521, 59.29832227528095, 57.35729523003101, 56.530349403619766, 56.449200958013535, 56.14365555346012, 56.2407061457634, 55.43393723666668, 56.1253709346056, 58.86979267001152, 58.393530026078224, 50.17477624118328, 49.0259762853384, 45.05493476986885, 45.9867549687624, 44.512369483709335, 56.41537897288799, 61.476456597447395, 61.52811862528324, 57.0232817530632, 58.25093127787113, 54.557875245809555, 57.70702466368675, 53.28455597162247, 59.19347830116749, 45.57695835828781, 36.172922775149345, 63.670177683234215, 51.129053235054016, 63.20962719619274, 56.39647878706455, 57.046274319291115, 54.63463492691517, 60.75978085398674, 58.54993723332882, 54.99257192015648, 57.11708351969719, 58.73884789645672, 46.19623012840748, 46.27572946250439, 50.618983805179596, 58.323351591825485, 59.2411695420742, 55.9375774115324, 52.40597851574421, 53.12701262533665, 53.02061453461647, 55.61560168862343, 57.86266051232815, 56.6373972594738, 50.64549118280411, 45.41896663606167, 46.46189667284489, 51.520500630140305, 52.122540324926376, 51.92053936421871, 53.16424302756786, 59.01446610689163, 58.792842999100685, 57.703004479408264, 55.67359037697315, 48.834040984511375, 38.43999892473221, 32.14977465569973, 23.03294476121664, 10.51313241943717, 6.884408360347152, 8.569970838725567, 13.446140885353088, 9.302271343767643, 9.57740793004632, 6.711987387388945, 2.862299485132098, 0.7425353152211756, 0.2192321009351872, 0.02696009698411217, 0.4804952902486548, 6.077439486980438, 25.303571820259094, 43.932087421417236, 31.466360427439213, 22.729312554001808, 29.244813434779644, 45.81817701458931, 51.148090213537216, 60.902672186493874, 35.70031553506851, 4.572335025295615, 0.183567259227857, 0.05287524632876739, 0.01633333449717611, 0.018838235046132468, 0.11499786050990224, 0.04398865501570981, 0.020293699817557354, 0.048620996094541624, 0.09483365618507378, 0.11476659245090559, 0.058280975790694356, 0.031134089513216168, 0.02204152253398206, 0.03770903182157781, 0.02687568139663199, 0.06281814014073461, 0.030222522509575356, 0.011141505910927663, 0.05218944621447008, 0.015933545109874103, 0.02971924805024173, 0.06545309093780816, 0.04709083972556982, 0.05896485745324753, 0.04468715327675454, 0.016042373645177577, 0.11071967601310462, 0.13477845612214878, 0.12662869499763474, 0.22882107936311513, 0.18214181618532166, 0.18361892754910514, 0.2688486658735201, 0.11638065974693745, 0.17103418096667156, 0.06464231686550193, 0.19600687141064554, 0.14171765564242378, 0.13968697632662952, 0.15535077487584203, 0.11763527523726225, 0.11480110973934643, 0.1255912912893109, 0.12353893383988179, 0.2629848086507991, 0.13435574364848435, 0.0837807914649602, 0.2335112151922658, 0.1611268805572763, 0.28811585856601596, 6.805800078436732, 35.83063334226608, 59.120062440633774, 74.06615763902664, 59.1023363918066, 45.124140456318855, 34.77437362074852, 34.34958301484585, 41.83045819401741, 60.749228820204735, 51.80657587945461, 20.79194661229849, 4.941734103485942, 0.8643454976845533, 0.29392752796411514, 1.3248219480738044, 1.8800343805924058, 13.55546671897173, 21.01718332618475, 24.088881500065327, 23.60962651669979, 25.078688487410545, 17.018182910978794, 16.75776768475771, 24.38075713813305, 34.39101979136467, 48.8064506649971, 54.434005692601204, 59.307396188378334, 60.06834335625172, 59.35387909412384, 62.74249166250229, 66.69156655669212, 58.62269952893257, 61.49207375943661, 59.1913428157568, 59.87438656389713, 61.477186158299446, 63.15277844667435, 58.71812380850315, 57.64299049973488, 57.16435298323631, 57.03327901661396, 55.46042561531067, 58.71319927275181, 56.828739792108536, 57.77800865471363, 61.23814098536968, 60.826953649520874, 52.46135674417019, 49.13328252732754, 46.91050060093403, 48.075016513466835, 47.285559475421906, 59.78081278502941, 64.7997696697712, 63.41173455119133, 59.97076839208603, 59.42350275814533, 57.88452073931694, 59.647291749715805, 54.72649499773979, 58.25501225888729, 48.61610747873783, 41.45351842045784, 61.46117001771927, 53.12891252338886, 65.63665196299553, 59.347674027085304, 58.983881548047066, 55.8626264333725, 62.84382842481136, 60.966694951057434, 56.77906885743141, 59.736507162451744, 60.33942461013794, 49.05629865825176, 46.47730864584446, 53.85170593857765, 60.08627839386463, 61.03105969727039, 57.117250710725784, 52.855855375528336, 53.18830333650112, 53.59530709683895, 56.018923446536064, 60.29618673026562, 59.70702834427357, 53.729341104626656, 47.55390867590904, 47.230386435985565, 51.82372435927391, 54.054048880934715, 52.93995626270771, 56.532458290457726, 63.013892099261284, 62.10738994181156, 57.95473337173462, 56.29457585513592, 47.589824348688126, 39.476066529750824, 37.91765995323658, 38.61352801322937, 26.385708153247833, 8.905063457787037, 16.022320948541164, 27.692404836416245, 14.26907792687416, 15.214828178286552, 12.23318137228489, 3.0970228649675846, 0.7421232748311013, 0.5531664798036218, 0.16363486472982913, 0.7329421956092119, 6.812991667538881, 28.709302470088005, 54.65896502137184, 45.846367701888084, 37.630163580179214, 40.41791059076786, 53.72785538434982, 58.23493033647537, 68.07291403412819, 43.12918670475483, 7.0316024869680405, 0.35563692916184664, 0.2280362878809683, 0.1831204566406086, 0.14096854662057012, 0.17252235033083707, 0.17517621105071157, 0.0877637644589413, 0.1731250633019954, 0.1189411582890898, 0.28555455850437284, 0.08346757545950823, 0.14882115181535482, 0.09686262113973498, 0.18721043248660862, 0.13731959945289418, 0.21037281694589183, 0.09075881273020059, 0.07108454461558722, 0.13780165405478328, 0.17789622681448236, 0.14028914010850713, 0.08509634470101446, 0.11056019589887, 0.1459167420398444, 0.08614556340035051, 0.1628598547540605], [0.031223106416291557, 0.03144873044220731, 0.04871209472185001, 0.018258790260006208, 0.09905497732688673, 0.03227494118618779, 0.009602543959772447, 0.048388841169071384, 0.03934725602448452, 0.07979649002663791, 0.01622430372663075, 0.11638240379397757, 0.032269909424940124, 0.10046070892713033, 0.068568946007872, 0.03487217232759576, 0.041232771254726686, 0.03218730096705258, 0.04866596653300803, 0.050779666198650375, 0.033268910701735877, 0.05830632013385184, 0.14006890036398545, 0.03893801724188961, 7.622375786304474, 25.30664775520563, 48.13396655023098, 52.56082020699978, 30.062966533005238, 25.44144742190838, 18.08240320533514, 37.35629327595234, 42.998659908771515, 44.18009251356125, 31.203509531915188, 7.956770667806268, 1.339976484887302, 0.13042754115303978, 0.1548751027439721, 0.37231913243886083, 4.354835646227002, 7.198723694309592, 10.757346265017986, 10.724799111485481, 13.45674516633153, 22.942790798842907, 17.637751065194607, 23.874215818941593, 23.4511636197567, 39.47684168815613, 49.575168415904045, 56.546418741345406, 57.187843322753906, 55.25598518550396, 56.29376269876957, 59.06476780772209, 57.71859124302864, 60.63679665327072, 59.169577583670616, 59.206424206495285, 57.591913640499115, 56.622376665472984, 55.56586995720863, 54.88562285900116, 58.687136471271515, 58.2334940135479, 54.78574901819229, 53.24259102344513, 53.31902772188187, 54.305754974484444, 57.342331632971764, 55.80361559987068, 53.57615992426872, 48.79173405468464, 42.25631654262543, 43.860107883811, 42.70208202302456, 45.30406840145588, 55.785387977957726, 56.439838260412216, 59.44690190255642, 57.45647370815277, 57.81282618641853, 43.30921724438667, 57.43742153048515, 51.75277836620808, 57.38811157643795, 43.67307431995869, 26.92575417459011, 57.70957052707672, 51.94595240056515, 58.210630640387535, 55.87922394275665, 51.84688411653042, 47.71345071494579, 53.480446860194206, 54.76059816777706, 56.38164438307285, 53.93810950219631, 55.341681987047195, 43.67307052016258, 40.19440658390522, 46.555356457829475, 52.609370201826096, 53.6596604436636, 55.39041817188263, 52.22102344036102, 51.96933634579182, 51.67803257703781, 52.83291980624199, 53.25096197426319, 54.7389355301857, 50.697909370064735, 47.782303020358086, 43.89546878635883, 46.697370037436485, 46.01618818938732, 52.72058263421059, 54.507710337638855, 58.04728500545025, 54.35356020927429, 60.59444412589073, 55.441084653139114, 54.734995141625404, 45.7055776566267, 44.17749725282192, 31.345701701939106, 18.942542150616646, 9.302066154778004, 6.948350379243493, 5.617245230823755, 10.65122650936246, 7.511871540918946, 3.9313436206430197, 2.671722611412406, 1.00456123938784, 0.06327004870399833, 0.059923649168922566, 0.07112801962648518, 2.5680387625470757, 15.322791785001755, 42.00042687356472, 47.536254823207855, 31.306419409811497, 24.753429740667343, 33.535073921084404, 42.45747774839401, 49.332217052578926, 38.13623182475567, 6.579186888411641, 0.3489776677452028, 0.1088500427431427, 0.006221607654879335, 0.0435478564031655, 0.06895721540786326, 0.013965686739538796, 0.03299231226264965, 0.006772899068892002, 0.0633541117713321, 0.10247647849610075, 0.03762632317375392, 0.04459985073481221, 0.005506784464159864, 0.033393135090591386, 0.10241446463624015, 0.049568952454137616, 0.034825973634724505, 0.05072923726402223, 0.04943604122672696, 0.035284832410980016, 0.0560002928978065, 0.016422676089860033, 0.021979697921779007, 0.06090552167734131, 0.02515669482818339, 0.024126640237227548, 0.050851517225964926, 0.03597262148105074, 0.04218997848511208, 0.04726877705252264, 0.05902270415390376, 0.07328126463107765, 0.03212396979506593, 0.06744492624420673, 0.02765192333754385, 0.10041942325187847, 0.04777539674250875, 0.05210713832639158, 0.03723479945620056, 0.07430427067447454, 0.008655903984617908, 0.0475336161616724, 0.057683832637849264, 0.02960679412353784, 0.05188964452827349, 0.02752067452092888, 0.012190120687591843, 0.056984339898917824, 0.02714214951993199, 0.07812233845470473, 8.513327278196812, 29.891411438584328, 55.668825432658195, 60.52918262779713, 37.7189876139164, 31.431974172592163, 23.586217872798443, 39.18730862438679, 49.011426866054535, 45.86340218782425, 33.5644843429327, 9.300993662327528, 1.6601874399930239, 0.1677857115282677, 0.46647107403259724, 1.4316497719846666, 5.676816059276462, 9.92856228724122, 14.695893824100494, 16.579329259693623, 17.425847835838795, 13.904289901256561, 8.82795324549079, 16.612814962863922, 24.77104939520359, 42.84927472472191, 49.307905957102776, 56.55087970197201, 58.00073750317097, 56.813681200146675, 56.27039015293121, 59.24181930720806, 59.817363023757935, 61.713765263557434, 60.54249331355095, 59.53765243291855, 59.21703703701496, 60.153648778796196, 56.35970436036587, 55.845500752329826, 57.37416252493858, 57.90471285581589, 54.845348820090294, 54.2877097427845, 55.62519237399101, 56.38364687561989, 59.57898661494255, 57.87638157606125, 54.159755408763885, 50.60859136283398, 44.059376791119576, 46.518620029091835, 44.6007489413023, 46.817166209220886, 58.47125105559826, 59.52575907111168, 61.535015255212784, 57.81402312219143, 58.33386942744255, 48.2694710791111, 57.889737859368324, 52.224146872758865, 57.611455991864204, 45.14342822134495, 30.986252389848232, 59.451913833618164, 53.0556296557188, 59.671439453959465, 57.37385094165802, 53.844463527202606, 50.74611738324165, 56.04912802577019, 56.78470775485039, 57.57189251482487, 56.16368047893047, 57.37334556877613, 46.567926183342934, 41.38079032301903, 49.02087315917015, 55.66586919128895, 55.60233660042286, 56.39891445636749, 52.430946975946426, 52.00099244713783, 52.17731438577175, 52.182326316833496, 55.37356227636337, 57.05042749643326, 53.43313179910183, 48.87406803667545, 46.105844378471375, 47.471639290452, 48.474808260798454, 54.98440995812416, 55.66852144896984, 57.935392409563065, 58.85611340403557, 60.37230804562569, 57.41795517504215, 54.90674592554569, 46.79721347987652, 38.20524372160435, 30.21043661981821, 13.032334540039301, 9.006179831922054, 10.07759504020214, 13.696078173816204, 10.58414300903678, 10.323297455906868, 7.286352217197418, 4.665791010484099, 2.0053203077986836, 0.1798664210946299, 0.2093526755925268, 0.04936924793582875, 3.23116896674037, 15.091595090925694, 38.54610823094845, 40.981990322470665, 33.78077253699303, 29.982750937342644, 39.22843761742115, 48.065866604447365, 56.85231372714043, 46.069271340966225, 9.911164920777082, 0.4349583853036165, 0.09794105819310062, 0.10658455532393418, 0.09798732367926277, 0.03630096987762954, 0.04308333132939879, 0.009243342628906248, 0.060870247398270294, 0.027046846626035403, 0.05975618725642562, 0.06047448601748329, 0.006083719399612164, 0.03754163670237176, 0.020525327818177175, 0.05341554839105811, 0.04573260186589323, 0.03759521605388727, 0.029991365772730205, 0.02282028963236371, 0.02139560729119694, 0.034360506033408456, 0.028432673825591337, 0.015689788560848683, 0.021526618620555382, 0.04335270125011448, 0.0164310271065915, 0.2870106225600466, 0.09375253255711868, 0.17239866399904713, 0.10882192276767455, 0.2197433219407685, 0.09730497084092349, 0.1222815278742928, 0.1246295272721909, 0.11796033591963351, 0.19640705228084698, 0.1369275525212288, 0.18892886058893055, 0.07486533431801945, 0.16631452250294387, 0.17049501067958772, 0.07861888720071875, 0.2698350395075977, 0.1850912149529904, 0.2405634883325547, 0.08909789365134202, 0.08237218033173122, 0.19935266609536484, 0.17127992090536281, 0.3294552059378475, 10.310348700731993, 36.85300648212433, 64.42845359444618, 67.61276632547379, 44.18796569108963, 36.80739372968674, 29.821521788835526, 47.71777868270874, 54.83149476349354, 58.28258357942104, 41.13950327038765, 10.963046327233315, 1.916270067449659, 0.32518853957299143, 0.5969934468157589, 1.5300096315331757, 10.602025799453259, 16.585874408483505, 21.082220636308193, 20.95529794692993, 24.242873936891556, 36.244868114590645, 29.17197324335575, 30.342481434345245, 27.744156159460545, 41.76848351955414, 53.102469742298126, 55.851056054234505, 57.55430705845356, 57.25837893784046, 57.34998062252998, 58.53012889623642, 60.71300536394119, 62.55123272538185, 64.07287627458572, 62.690590247511864, 59.97378543019295, 60.13535276055336, 57.225195318460464, 55.70726417005062, 59.625116139650345, 59.64376553893089, 57.33425326645374, 56.06841579079628, 56.517167910933495, 58.540817722678185, 62.506387531757355, 61.065789833664894, 57.0744764059782, 53.080962896347046, 45.49107916653156, 47.31093071401119, 45.92231422662735, 50.116468369960785, 60.688671469688416, 61.74410663545132, 61.177963614463806, 61.43095783889294, 57.9205048084259, 48.69517743587494, 57.004883140325546, 53.97511191666126, 57.37173445522785, 47.33741149306297, 35.72198957204819, 59.71113212406635, 55.11480376124382, 62.07942724227905, 60.458597615361214, 55.716847255825996, 52.941761165857315, 58.01656745374203, 60.355516746640205, 59.99399654567242, 58.68960253894329, 60.13157956302166, 48.719218745827675, 43.692624270915985, 52.715582102537155, 58.670132383704185, 57.11423747241497, 58.953642770648, 54.02643956243992, 52.30344861745834, 52.521328926086426, 54.48763981461525, 55.7784229516983, 59.19946677982807, 56.1066797375679, 53.520242124795914, 47.94496089220047, 50.84771253168583, 51.147763431072235, 59.65211749076843, 58.42957869172096, 62.26894587278366, 59.99305039644241, 63.82068380713463, 57.633255422115326, 57.45090700685978, 48.669551610946655, 46.40320502221584, 34.412823021411896, 23.15461803227663, 14.43479748442769, 15.496413968503475, 17.44447823613882, 20.105857327580452, 21.52035042643547, 13.499538470059633, 7.632519816979766, 2.0235175313428044, 0.46817638096399605, 0.403529618633911, 0.4663391795475036, 3.6467172810807824, 19.21516042202711, 48.87577034533024, 58.142637088894844, 43.17740611732006, 38.464667201042175, 46.342598274350166, 57.47109912335873, 63.357929438352585, 55.82818128168583, 14.0509582310915, 0.7543513749260455, 0.23921274987515062, 0.16836336959386244, 0.2632152009755373, 0.19983814941952005, 0.3316622046986595, 0.1355101543595083, 0.11666633465210907, 0.12568564794491976, 0.2100817020982504, 0.11369609637768008, 0.09773870420758612, 0.19412383495364338, 0.14013759355293587, 0.2796417789068073, 0.11356443195836619, 0.19043225882342085, 0.1355460297781974, 0.19293881807243451, 0.12467803404433653, 0.1441999466624111, 0.07648804763448425, 0.1462373201502487, 0.15133155538933352, 0.08223103126510978, 0.17026534565957263], [0.04938965699693654, 0.005493665148605942, 0.07270926915225573, 0.032680484073353, 0.06041073924279772, 0.01794739993783878, 0.025076481651922222, 0.03728330622834619, 0.05136438208865002, 0.06381696701282635, 0.0884058112569619, 0.008894564762158552, 0.047483910821028985, 0.04895645055512432, 0.0793480101856403, 0.02838631371560041, 0.0518205023399787, 0.06139634104329161, 0.07148138582124375, 0.03106217354797991, 0.019177676695107948, 0.02490623483026866, 0.07951442938065156, 0.17695905757136643, 5.839446382597089, 33.772169798612595, 52.16126784682274, 52.38297455012798, 40.99991776049137, 24.734024181962013, 17.724340818822384, 17.139652892947197, 20.549747608602047, 34.6209454536438, 21.698969341814518, 4.469210458919406, 0.3007452527526766, 0.18991005403222516, 0.3178870235569775, 1.0582837066613138, 2.2626287257298827, 11.08710777014494, 9.702784102410078, 9.484793599694967, 17.9593563079834, 13.792422004044056, 5.7513566594570875, 23.646471239626408, 29.65403627604246, 49.07001972198486, 51.24680511653423, 56.8484341353178, 56.732354164123535, 56.127392426133156, 56.40430636703968, 56.00511498749256, 57.87593699991703, 55.84078520536423, 56.86600439250469, 58.736271634697914, 53.77886764705181, 54.94736194610596, 55.713013261556625, 54.49609436094761, 55.06080865859985, 55.00160023570061, 58.00876647233963, 53.63769382238388, 53.51173058152199, 54.51269567012787, 56.45878404378891, 52.60902442038059, 50.16016602516174, 44.12813410162926, 42.95771710574627, 43.96253518760204, 45.51887467503548, 43.47634747624397, 53.05548906326294, 56.70465365052223, 57.251102328300476, 55.26220925152302, 57.51072719693184, 59.33598205447197, 51.765253096818924, 49.825890362262726, 54.852192252874374, 42.39210985600948, 24.070110507309437, 58.381199687719345, 51.91138945519924, 58.72449226677418, 53.87062892317772, 53.42923700809479, 43.5292824357748, 44.47908326983452, 50.931007862091064, 55.854624062776566, 55.75893759727478, 55.39183169603348, 41.54586486518383, 41.25017613172531, 44.8392279446125, 50.36009229719639, 54.98703181743622, 55.452807024121284, 52.718283757567406, 50.204578042030334, 51.82772174477577, 51.3100603222847, 52.72761985659599, 55.77392399311066, 53.359921127557755, 49.14889968931675, 50.621332079172134, 49.025919288396835, 52.43351183831692, 51.295480504631996, 55.494517385959625, 55.31290613114834, 63.28811198472977, 57.31401935219765, 57.9422852396965, 54.91510167717934, 54.156084805727005, 45.27922913432121, 32.29962721467018, 13.540128841996193, 14.370655976235867, 8.006996847689152, 11.239028368145227, 7.482099188491702, 7.075523855164647, 4.881789470091462, 4.196329051628709, 1.515447625424713, 0.1284997828770429, 0.20929049846017733, 0.0961070776975248, 0.4540425643790513, 7.9229700565338135, 32.72989712655544, 51.27420924603939, 33.53982366621494, 25.463457740843296, 37.116742730140686, 38.578554689884186, 48.941214233636856, 44.734216779470444, 11.606788784265518, 0.6713504099752754, 0.012229979583935346, 0.11299921970930882, 0.11541549669345841, 0.07966228746226989, 0.0713532317604404, 0.044261004659347236, 0.028854633019363973, 0.03635832676081918, 0.029219999742053915, 0.044702178056468256, 0.04633508848201018, 0.0439649100007955, 0.0264008163503604, 0.043286390355206095, 0.05449883537949063, 0.012461848782550078, 0.05868510117579717, 0.03872036388202105, 0.047232304204953834, 0.01427529590728227, 0.008736458548810333, 0.029123019594408106, 0.030489582495647483, 0.04303599343984388, 0.015374974154838128, 0.009714432926557492, 0.014926466483302647, 0.007183653224274167, 0.037490688264369965, 0.005432811822174699, 0.05184837740671355, 0.03908406448317692, 0.07076340989442542, 0.03374969252035953, 0.08035927545279264, 0.05419413180788979, 0.04023700203106273, 0.04848384720389731, 0.0374206332344329, 0.06686924971290864, 0.036225118674337864, 0.11303203747957014, 0.21028421935625374, 0.08070521274930798, 0.04809198580915108, 0.017188945421366952, 0.0559160368720768, 0.03800737889832817, 0.2260644460329786, 6.854152958840132, 39.617779925465584, 60.62996841967106, 57.11313933134079, 44.5417495071888, 30.892503820359707, 22.924608774483204, 25.049637146294117, 28.91676753759384, 37.898850962519646, 22.64730915427208, 4.946548445150256, 0.5185211857315153, 0.20590456842910498, 0.4218986938940361, 1.4456799253821373, 7.470358293503523, 13.436724040657282, 15.719215963035822, 13.417732659727335, 12.31368100270629, 14.697372894734144, 10.283447094261646, 19.008658602833748, 28.666020892560482, 46.727863401174545, 52.584424540400505, 58.58205311000347, 57.92587012052536, 58.37820924818516, 56.86211720108986, 55.34319430589676, 57.8103107213974, 58.58385041356087, 60.94689041376114, 60.462602600455284, 56.065478548407555, 54.64634969830513, 56.135014817118645, 55.440347492694855, 56.03468880057335, 57.6924030482769, 58.61805997788906, 54.00668062269688, 55.610281974077225, 56.04690134525299, 57.97821991145611, 54.65948559343815, 52.45520867407322, 47.041456773877144, 43.12065616250038, 45.85049048066139, 47.16864354908466, 46.33374474942684, 56.067553237080574, 59.268414080142975, 58.27927015721798, 57.126571610569954, 59.64047111570835, 58.03620859980583, 54.25345838069916, 50.99545620381832, 56.01073108613491, 43.55874985456467, 27.658351063728333, 58.90174515545368, 53.219606056809425, 59.694325625896454, 55.951059088110924, 54.53748553991318, 43.8564258813858, 46.89011849462986, 53.16843420267105, 58.4223210811615, 58.20963129401207, 57.4158500880003, 43.884460777044296, 42.260910496115685, 46.386869698762894, 52.635831981897354, 55.6445637345314, 58.21776665747166, 53.79744865000248, 51.031938046216965, 51.50351174175739, 52.94503279030323, 54.76606987416744, 55.811378583312035, 55.244532600045204, 51.00404754281044, 51.54908649623394, 51.77230551838875, 53.75136472284794, 53.47275987267494, 56.3472106307745, 59.16251376271248, 62.410328686237335, 59.14037235081196, 59.646683782339096, 56.35498121380806, 54.3907830119133, 45.356494188308716, 32.380228489637375, 15.29231172055006, 13.020752761512995, 13.194689378142357, 11.800068262964487, 11.17339638993144, 8.968664444983006, 11.434571575373411, 8.233058117330074, 3.7683938769623637, 0.15983270859578624, 0.22448720410466194, 0.03314828201837372, 0.573879168368876, 9.47349775582552, 34.34590861201286, 55.614397153258324, 40.28581827878952, 33.940261378884315, 42.53028184175491, 44.071167558431625, 53.71603421866894, 51.80397681891918, 16.181551404297352, 0.952945165336132, 0.009372048662044108, 0.11408190926886164, 0.058381284470669925, 0.03528872868628241, 0.033884674339788035, 0.09147747143288143, 0.04517675180977676, 0.024047204460657667, 0.04317582519433927, 0.05768038165115286, 0.05103209288790822, 0.044474750611698255, 0.036827412332058884, 0.01585081234225072, 0.06282832982833497, 0.023756397604302038, 0.010510112642805325, 0.01977859552425798, 0.015025708325993037, 0.02216052405856317, 0.006180709751788527, 0.014629389406763949, 0.00510380059495219, 0.0644819313311018, 0.018548400403233245, 0.1406444952590391, 0.07064632125548087, 0.141233493341133, 0.09868432651273906, 0.0916113771381788, 0.20900373259792104, 0.0932201009709388, 0.22491609124699607, 0.1226376548584085, 0.22072021092753857, 0.189378171635326, 0.0762691066483967, 0.1844990998506546, 0.1481039254576899, 0.17173836036818102, 0.18896104011218995, 0.15615959709975868, 0.25323758949525654, 0.2510417526355013, 0.1399041584227234, 0.154134365147911, 0.1427781698293984, 0.15987524850061163, 0.3964024182641879, 9.00196110829711, 47.791787311434746, 67.4824333190918, 67.29546815156937, 53.42438846826553, 38.59086222946644, 27.678493782877922, 28.020355738699436, 32.87131033837795, 45.80332361161709, 27.647460848093033, 6.060680011287332, 0.6275013566482812, 0.36196008673869073, 0.584935387596488, 2.608839785680175, 11.342849247157574, 26.195471361279488, 19.453115053474903, 16.207391917705536, 27.14866541326046, 21.127626299858093, 12.327098082751036, 29.359470382332802, 33.94923649728298, 53.1909441947937, 53.085910230875015, 57.006030678749084, 58.004062324762344, 58.2038252055645, 56.15100435912609, 56.98740407824516, 58.65806423127651, 58.255620226264, 61.3044436275959, 60.16987770795822, 54.62076187133789, 55.20759858191013, 58.01831156015396, 56.050104573369026, 57.31047794222832, 59.94674228131771, 63.804610669612885, 57.189256846904755, 58.16916346549988, 59.968157932162285, 60.539575070142746, 56.790168061852455, 55.07855370640755, 48.73731717467308, 45.582475662231445, 49.38327111303806, 48.9439082890749, 48.58651466667652, 56.723975613713264, 62.13776931166649, 61.38415955007076, 60.92283010482788, 61.64254188537598, 60.27375653386116, 53.51340629160404, 51.32633864879608, 55.49287587404251, 45.361646711826324, 30.87681446224451, 58.646220266819, 54.85508389770985, 60.566371232271194, 58.79941284656525, 57.52279914915562, 47.88074053823948, 48.9856718480587, 56.51208758354187, 60.72682902216911, 62.46822617948055, 60.443729013204575, 46.29333011806011, 44.07359562814236, 49.5261662453413, 52.959570810198784, 57.10381083190441, 59.568305388092995, 55.684518590569496, 51.73510551452637, 52.690910026431084, 52.57885403931141, 55.9519824385643, 58.642545863986015, 58.035646229982376, 52.85210877656937, 56.78205169737339, 54.798151552677155, 56.44213333725929, 56.50821179151535, 60.04129260778427, 61.456690058112144, 65.82857966423035, 58.75475764274597, 59.79510761797428, 54.40034329891205, 55.61552569270134, 48.04106153547764, 39.29619938135147, 20.17600916326046, 19.50813040137291, 14.744145534932613, 16.783834286034107, 18.2393803820014, 18.118227683007717, 12.460400629788637, 12.362550180405378, 5.178617667406797, 0.1568008869071491, 0.5091392516624182, 0.12521966826170683, 1.0131227737292647, 10.362400207668543, 39.10243257880211, 60.52077367901802, 42.43141494691372, 39.220431447029114, 49.10961739718914, 50.8623493462801, 60.14715872704983, 62.80781015753746, 22.905093021690845, 1.5331441070884466, 0.11655530935968272, 0.18180312967160717, 0.17574585392139852, 0.15233952552080154, 0.14269329782109708, 0.18718263163464144, 0.19556253275368363, 0.16252072295174003, 0.1926322962390259, 0.12954043719219044, 0.09924064041115344, 0.15928494423860684, 0.10865395990549587, 0.16609965590760112, 0.22522806044435129, 0.15112339780898765, 0.17325680935755372, 0.10624809525324963, 0.18623958458192647, 0.0802169315284118, 0.09608643857063726, 0.11506652401294559, 0.08420330355875194, 0.14102564746281132, 0.13345059065613896], [0.06308398485998623, 0.04906128262518905, 0.11974778375588357, 0.08945272187702358, 0.03243246203055605, 0.04518102286965586, 0.03485467619611882, 0.04477232214412652, 0.01693937971140258, 0.00434188256804191, 0.12680853222263977, 0.044003601869917475, 0.038614841614617035, 0.037556112292804755, 0.025918657847796567, 0.04991228110156953, 0.05183875917282421, 0.011584281419345643, 0.09128069839789532, 0.012360374930722173, 0.031606622360413894, 0.03454682220763061, 0.056050673592835665, 0.2382846051477827, 10.90706393122673, 42.396776005625725, 52.02596090734005, 48.38973842561245, 37.8766867518425, 16.74662098288536, 18.65108449012041, 24.37356222420931, 38.812158554792404, 30.87353903800249, 16.690971069037914, 1.8102762987837195, 0.2682859991909936, 0.05680781636328902, 0.37554438749793917, 1.6986086033284664, 4.553612004965544, 8.822941314429045, 18.981303870677948, 22.53403913229704, 10.270803272724152, 15.577627010643482, 12.922440636903048, 20.347336269915104, 38.1464608758688, 55.826471373438835, 54.084181264042854, 57.281029522418976, 56.530896574258804, 58.08102339506149, 54.49209317564964, 59.24059957265854, 54.47331078350544, 55.34995414316654, 55.32649800181389, 56.98550797998905, 53.80656436085701, 53.23520801961422, 53.353731259703636, 56.38061463832855, 52.659234926104546, 56.61670356988907, 56.38998493552208, 55.912437960505486, 53.29480402171612, 52.36859232187271, 52.79158182442188, 48.31178180873394, 45.84858298301697, 41.304528415203094, 42.35253117978573, 41.3307736068964, 41.5452416986227, 40.79323165118694, 44.61614191532135, 47.74569198489189, 55.38909584283829, 53.64470064640045, 55.21088920533657, 54.72712576389313, 55.34505620598793, 49.84620787203312, 57.09862411022186, 40.477897971868515, 21.59859772771597, 57.59783372282982, 53.05724836885929, 58.70958186686039, 53.338414281606674, 54.41344879567623, 50.29770724475384, 43.26343730092049, 42.43406340479851, 48.71130757033825, 50.32750144600868, 46.06231391429901, 41.19902707636356, 41.52214653789997, 43.06875094771385, 49.50776003301144, 53.81594605743885, 55.04691660404205, 50.15833832323551, 50.38195252418518, 51.94930002093315, 52.46736042201519, 52.92787291109562, 52.82149001955986, 55.522438287734985, 52.56189554929733, 52.67685078084469, 51.729941591620445, 52.57817007601261, 53.99144344031811, 57.560778111219406, 55.584933534264565, 57.70047001540661, 56.24464653432369, 60.563000813126564, 60.63016980886459, 64.09898087382317, 47.07728125154972, 37.585496976971626, 15.96374899148941, 12.978146597743034, 14.26918812096119, 11.538276560604572, 8.962679766118526, 6.107715787366033, 10.130856782197952, 5.33244576305151, 3.1915161944925785, 0.8445734961424023, 0.03621537056460511, 0.06565513322129846, 0.23683289007749408, 2.153335902839899, 15.017856247723103, 34.90982495248318, 32.33390897512436, 18.014476150274277, 17.85286132246256, 30.202305056154728, 42.85753548145294, 52.24683165550232, 25.315987654030323, 2.974131046794355, 0.05594626454694662, 0.07364560718997382, 0.030810240386927035, 0.03766946050745901, 0.02802180046273861, 0.0417651954194298, 0.03875572721881326, 0.0271716053612181, 0.09524429391603917, 0.027415334079705644, 0.059093835297971964, 0.0390078459167853, 0.0618369912263006, 0.04363838357676286, 0.06144367522210814, 0.10681358209694736, 0.04609888143022545, 0.03134005033643916, 0.0853045097028371, 0.031057902488100808, 0.0522228391491808, 0.07622652221471071, 0.05558418182772584, 0.029572948478744365, 0.07266793152666651, 0.01909245958813699, 0.04029591742437333, 0.011527354054123862, 0.035083317052340135, 0.03243261046009138, 0.014033803836355219, 0.07170903962105513, 0.0648801306670066, 0.033318141067866236, 0.04600083258992527, 0.08590725235990249, 0.027201933226024266, 0.003832447587228671, 0.019554064310796093, 0.024250252354249824, 0.0834537937771529, 0.10042812864412554, 0.14722096268087626, 0.10602070862660185, 0.019843774643959478, 0.06674144446151331, 0.0334179636411136, 0.050314050167798996, 0.2656984864734113, 13.1460614874959, 50.264151245355606, 59.35431607067585, 57.588638216257095, 43.25835697352886, 21.51679191738367, 19.20925173908472, 19.30282361805439, 36.60489119589329, 35.21597072482109, 16.208455860614777, 2.6469154050573707, 0.09160061599686742, 0.09003550818306394, 1.205492082517594, 4.12394056096673, 7.737021334469318, 10.054470431059599, 17.18893814831972, 13.822620883584023, 8.813583366572857, 17.358593344688416, 10.817923564463854, 20.396251045167446, 37.97503687441349, 50.84455490112305, 55.659736320376396, 57.431539446115494, 56.960702911019325, 59.783320650458336, 55.162468403577805, 57.39756926894188, 54.4396597892046, 55.651768147945404, 56.38281852006912, 56.21297903358936, 54.9672044813633, 55.538773611187935, 54.27375689148903, 56.63492739200592, 54.0912526845932, 56.097465232014656, 58.40008847415447, 57.68968999385834, 55.376849099993706, 55.26275262236595, 54.20486658811569, 51.78279675543308, 47.70014002919197, 42.53108359873295, 44.336131140589714, 43.850494399666786, 43.26588436961174, 42.51670517027378, 47.80681170523167, 50.982639491558075, 57.94212944805622, 56.91177673637867, 56.82530477643013, 56.048250272870064, 58.35475690662861, 50.6850166618824, 56.83236859738827, 41.749837920069695, 23.964014500379562, 56.45463086664677, 52.88230575621128, 61.09183743596077, 55.91847583651543, 56.35832503437996, 50.42751207947731, 44.884662106633186, 44.56957921385765, 51.31979160010815, 53.31495054066181, 48.54031294584274, 44.28741775453091, 42.61877529323101, 44.832840487360954, 51.887184754014015, 55.07741376757622, 56.87722139060497, 52.077432945370674, 51.41186825931072, 52.03218497335911, 52.16701693832874, 53.80071647465229, 54.51678805053234, 56.89736030995846, 54.975195452570915, 52.96436995267868, 53.808171674609184, 53.92282672226429, 56.217139810323715, 59.13542881608009, 57.75769494473934, 58.767752945423126, 56.69405981898308, 59.846245273947716, 60.70361606776714, 62.57789209485054, 49.769189804792404, 39.43850934505463, 21.705415695905685, 13.097767978906631, 14.11399019882083, 14.962958693504333, 9.009135123342276, 10.038539785891771, 11.93237716332078, 8.309205081313848, 5.694208201020956, 1.1246915557421744, 0.1650493685156107, 0.12110597337596118, 0.3121862607076764, 2.840039567090571, 17.186306789517403, 40.88300563395023, 36.85095079243183, 26.63574993610382, 25.869595147669315, 35.682566687464714, 49.2060562223196, 59.614936485886574, 33.74631218612194, 3.758652862161398, 0.06544603311340325, 0.03708159791131038, 0.06741218268871307, 0.0708904284692835, 0.03541619626048487, 0.06511643790872768, 0.012996527220821008, 0.0502538063301472, 0.07852517621358857, 0.052304011551314034, 0.06094650678278413, 0.009738880198710831, 0.0036644622286985395, 0.06662736894213594, 0.0633245446078945, 0.0018019580988948292, 0.06336085047223605, 0.05959224312391598, 0.05620158190140501, 0.05720038650906645, 0.05604270292678848, 0.08589712204411626, 0.029671427764697, 0.08060543841565959, 0.02630979008245049, 0.21245517942588776, 0.20587473409250379, 0.27973698161076754, 0.22544887906406075, 0.11779555687098764, 0.1368221823940985, 0.13808074611006305, 0.10888439675909467, 0.12643640453461558, 0.09800289393751882, 0.15143570839427412, 0.12181722544482909, 0.19026607711566612, 0.08596130297519267, 0.06061668522306718, 0.11540222709299996, 0.17792763450415805, 0.18817234493326396, 0.23599896841915324, 0.10069114578072913, 0.10309121425962076, 0.2698660909663886, 0.1893091222154908, 0.6148339051287621, 17.728457897901535, 58.27117659151554, 69.28387105464935, 62.79102265834808, 51.85577183961868, 27.874192781746387, 28.717871010303497, 36.14618740975857, 51.68784745037556, 41.22107729315758, 20.00933300703764, 2.9078756645321846, 0.49708071746863425, 0.14151705312542617, 1.1886579170823097, 5.075180567800999, 14.487826488912106, 14.470244832336903, 25.09615994989872, 33.57958473265171, 18.93848016858101, 23.899075984954834, 19.02897611260414, 24.852406829595566, 38.96237589418888, 55.200302973389626, 55.74921011924744, 57.23260872066021, 57.573374435305595, 60.91012358665466, 56.348494961857796, 57.52326652407646, 54.132066294550896, 54.67656567692757, 56.643883511424065, 57.80905298888683, 54.73634786903858, 55.916176959872246, 55.739965215325356, 56.59259386360645, 55.211535170674324, 59.03774745762348, 61.338360607624054, 60.33204920589924, 57.598396092653275, 58.041098937392235, 57.61331029236317, 53.2890435308218, 50.52681215107441, 44.19914089143276, 46.1180417239666, 45.7440771907568, 45.35835228860378, 44.50715236365795, 49.90406356751919, 53.19801941514015, 59.849855080246925, 58.382700607180595, 59.59046579897404, 58.23102034628391, 60.478725135326385, 53.30906465649605, 58.418080508708954, 43.146574571728706, 27.947336956858635, 57.22871772944927, 54.05916340649128, 61.350915133953094, 58.96777421236038, 57.796388268470764, 54.25307460129261, 47.416185066103935, 46.749712228775024, 53.01285155117512, 54.34627220034599, 51.48811116814613, 45.58850593864918, 45.56242033839226, 47.63580188155174, 53.66480156779289, 58.19715656340122, 59.3916604667902, 52.37019203603268, 52.21998229622841, 54.1247820854187, 53.32944676280022, 55.08803799748421, 56.27722978591919, 59.17707838118076, 57.69743777811527, 56.59788317978382, 57.94755935668945, 57.622080221772194, 60.23071624338627, 60.82081317901611, 59.01322357356548, 61.49565316736698, 58.17267827689648, 64.22052875161171, 62.65586771070957, 66.90076053142548, 53.53718541562557, 46.96361035108566, 22.07817569375038, 19.13784597069025, 21.464727111160755, 22.603564001619816, 17.626395374536514, 14.456390775740147, 22.450975589454174, 12.468940671533346, 8.879609573632479, 2.3015286633744836, 0.358852269127965, 0.17717396869556978, 0.4949251050129533, 3.2044224394485354, 20.345727056264877, 47.77950257062912, 44.90804225206375, 29.35186129063368, 29.66634001582861, 43.218827694654465, 55.93848556280136, 65.951769053936, 42.27003760635853, 6.16440637037158, 0.20707294635940343, 0.22865178063511848, 0.22054531640606, 0.17237914551515132, 0.0953548145480454, 0.13108089828165248, 0.07994540937943384, 0.12239384450367652, 0.22493523865705356, 0.11801589309470728, 0.18069771555019543, 0.1385960340849124, 0.1536015179590322, 0.1850471759098582, 0.23903519846498966, 0.18709271302213892, 0.11289920046692714, 0.18649923236807808, 0.20409337186720222, 0.1355424674693495, 0.17006006761221215, 0.13909631583373994, 0.135595649771858, 0.161733808927238, 0.2540945028886199], [0.023548831886728294, 0.059359398001106456, 0.03658166497189086, 0.02983733302244218, 0.0851829607563559, 0.08307656011311337, 0.03108619130216539, 0.08275305794086307, 0.041789185343077406, 0.08426986678387038, 0.023727557745587546, 0.028781262444681488, 0.05337242590030655, 0.1288211773498915, 0.045669330065720715, 0.00904565118617029, 0.028785600297851488, 0.012035803138132906, 0.03233107352571096, 0.08191351080313325, 0.05608502389804926, 0.05829680580063723, 0.017198402238136623, 0.3245553985470906, 11.867782529443502, 50.376116037368774, 46.90442472696304, 46.348077580332756, 49.77436512708664, 20.13280738145113, 18.44533883035183, 32.95682854950428, 42.97280989587307, 21.25382322818041, 6.660794634371996, 0.6941243691835552, 0.1635744984378107, 0.1968373346608132, 1.2761619966477156, 2.885288489051163, 7.089327564463019, 13.688897509127855, 18.47080696374178, 8.680412862449884, 7.439335808157921, 20.74340231716633, 15.18661754205823, 27.22186468541622, 39.00575816631317, 50.48310689628124, 57.48655289411545, 58.374348655343056, 54.72089409828186, 52.85933218896389, 53.98017704486847, 56.05238065123558, 53.89247015118599, 54.78217341005802, 53.006597086787224, 50.438637882471085, 52.23160967230797, 53.12632106244564, 55.50163820385933, 56.02116532623768, 57.832148149609566, 56.27112731337547, 54.08598616719246, 50.073842257261276, 52.3649787157774, 47.08754450082779, 48.09417888522148, 44.89126995205879, 42.537623047828674, 40.17559379339218, 40.59162586927414, 42.03483022749424, 44.11701209843159, 45.182554721832275, 47.04407103359699, 42.470727637410164, 45.862190052866936, 47.882701233029366, 54.54541191458702, 55.2119455486536, 57.157194167375565, 46.474344804883, 57.409246042370796, 35.17308622598648, 22.096247524023056, 54.614591002464294, 53.635090962052345, 55.572842583060265, 55.43849319219589, 54.678271785378456, 53.23526121675968, 49.7658421844244, 42.387857884168625, 38.939474523067474, 41.15016549825668, 42.82915860414505, 44.2033738642931, 41.20010621845722, 42.40609310567379, 46.36296518146992, 53.47807198762894, 55.830818340182304, 55.08996829390526, 53.259549513459206, 50.10485999286175, 50.57370163500309, 51.544906720519066, 50.77184200286865, 51.89302124083042, 52.7156201004982, 54.89630788564682, 52.92409211397171, 54.92548651993275, 50.23707389831543, 53.17881524562836, 49.31628830730915, 54.15276378393173, 55.13689197599888, 59.186513274908066, 57.20680810511112, 53.096937239170074, 49.282454922795296, 47.081468626856804, 32.19735950231552, 23.686032816767693, 19.202936477959156, 17.789342030882835, 6.726195299997926, 8.251391183584929, 12.25078297778964, 7.24080216139555, 4.25059393979609, 1.0674292221665382, 0.19472841813694686, 0.07024253354757093, 0.09842540603131056, 0.9097070479765534, 9.307035338133574, 36.26581259071827, 47.67142117023468, 25.04049863666296, 23.890587240457535, 27.19120603054762, 46.21042616665363, 41.15955099463463, 37.911162301898, 9.117909036576748, 0.0931036654219497, 0.04398560107802041, 0.03381555070518516, 0.08090128074400127, 0.06457702271291055, 0.05393473264120985, 0.016038067333283834, 0.05493073564139195, 0.0329823860374745, 0.001602120573807042, 0.016602687719569076, 0.03464235887804534, 0.01532987105747452, 0.04272485544788651, 0.01204727303047548, 0.02190888404584257, 0.023728029009362217, 0.09713354957057163, 0.021733826251875143, 0.02484849017491797, 0.016227578453253955, 0.05933016109338496, 0.04764911289385054, 0.054695411745342426, 0.029313111444935203, 0.07138616085285321, 0.04886345945124049, 0.05480389889271464, 0.06784585668356158, 0.03380867470696103, 0.10848009696928784, 0.006822102996011381, 0.01912951687700115, 0.03388466691831127, 0.060039082818548195, 0.04544062612694688, 0.07911168067948893, 0.019878393977705855, 0.028122129551775288, 0.029207045554358047, 0.038327166621456854, 0.05601879092864692, 0.026236972407787107, 0.02548471853515366, 0.03747352609934751, 0.030189610115485266, 0.04581576322379988, 0.057483708806103095, 0.5972935119643807, 15.290306378155947, 57.825004532933235, 53.88636767864227, 51.45050838589668, 55.81412583589554, 22.90412027388811, 20.42869370430708, 34.56465147435665, 40.175210013985634, 23.509623482823372, 7.424586899578571, 0.7060950330924243, 0.20321070594945922, 0.3523306315764785, 1.485645705834031, 4.8360437247902155, 9.83917398378253, 11.495440509170294, 18.14712703227997, 15.022628791630268, 6.619682740420103, 14.128413274884224, 15.67432802170515, 30.108317099511623, 39.27772477269173, 51.38367757201195, 58.35049353539944, 57.860547825694084, 56.21156170964241, 54.99008685350418, 53.88214610517025, 56.4654640853405, 54.52051945030689, 55.01914009451866, 54.82507310807705, 52.9387441277504, 52.329363226890564, 53.541011810302734, 56.8255365639925, 57.12337218225002, 57.78287999331951, 58.94125923514366, 54.827033802866936, 52.14550629258156, 53.94494913518429, 50.924654603004456, 51.310957074165344, 47.757186368107796, 43.783108815550804, 43.83152961730957, 43.054843693971634, 43.6921226978302, 45.11962249875069, 47.43416950106621, 48.00967901945114, 45.46202592551708, 47.38652005791664, 50.065893083810806, 56.4964210242033, 56.41151078045368, 58.06015491485596, 49.208442494273186, 57.423575073480606, 36.98460102081299, 23.597590662539005, 53.86860363185406, 52.60918401181698, 57.16611988842487, 57.90104225277901, 57.00614087283611, 54.267673417925835, 51.60033814609051, 44.43681813776493, 42.35941641032696, 43.363352939486504, 43.80973018705845, 45.73929704725742, 42.53817781805992, 44.239566922187805, 48.227756917476654, 54.13379140198231, 57.009340301156044, 56.555439457297325, 54.332433342933655, 49.76478584110737, 51.49290271103382, 51.13159529864788, 52.587460577487946, 54.45234350860119, 55.12948237359524, 57.80785225331783, 58.020382449030876, 57.0180494338274, 53.77013571560383, 53.63652728497982, 53.76271851360798, 53.52697156369686, 56.87161289155483, 59.826341941952705, 59.0184710919857, 56.08708418905735, 54.62371811270714, 47.25216306746006, 32.892270013689995, 16.955556571483612, 13.167330846190453, 10.192159842699766, 8.40184886008501, 9.151498284190893, 14.437199905514717, 8.65444790571928, 5.834469124674797, 2.5243306579068303, 0.561893186531961, 0.04447031256859191, 0.0784285634290427, 1.1254635080695152, 10.419587139040232, 34.58944134414196, 42.73863986134529, 21.447970010340214, 29.246230758726597, 36.18084914982319, 51.0485165566206, 48.41531105339527, 46.271595284342766, 12.237251903861761, 0.13825886155245826, 0.0862043489178177, 0.04224162454192992, 0.04746114915178623, 0.046051621466176584, 0.026373115688329563, 0.05322880548192188, 0.029102903681632597, 0.0022319620575217414, 0.050536297421786, 0.011048277319787303, 0.09797541963052936, 0.05466873153636698, 0.07014721952145919, 0.05088797151984181, 0.05327550141373649, 0.05595921873464249, 0.049771120902732946, 0.03287536463176366, 0.028118016198277473, 0.049067219806602225, 0.024075662113318685, 0.08677491947310045, 0.028290862392168492, 0.04263485890987795, 0.17548194620758295, 0.1610461200471036, 0.12705364875728264, 0.09032239278894849, 0.14680059539387003, 0.13652118213940412, 0.1596784160938114, 0.19734189118025824, 0.15850463532842696, 0.2002586651360616, 0.15645470470190048, 0.14214145165169612, 0.10517932096263394, 0.2649523608852178, 0.19834580918541178, 0.12684016255661845, 0.1453292282531038, 0.16205640567932278, 0.1342221422237344, 0.15662257850635797, 0.12534191482700408, 0.1299021005979739, 0.09562862251186743, 1.2818625220097601, 20.839056484401226, 66.56016200780869, 60.60641348361969, 59.874044582247734, 61.87086783349514, 30.593328773975372, 28.2502681016922, 45.92283099889755, 55.59736266732216, 29.068594090640545, 8.721144776791334, 1.20839441427961, 0.39332606771495193, 0.6129025400150567, 1.767778191715479, 5.387123879045248, 18.753072917461395, 25.525894090533257, 32.828368842601776, 18.588370755314827, 13.76156385987997, 23.741990514099598, 20.164053104817867, 31.379561685025692, 41.132253259420395, 53.078432232141495, 56.84393137693405, 59.080369770526886, 56.13219536840916, 56.494289338588715, 56.14508807659149, 58.41583862900734, 56.493225395679474, 56.52061812579632, 56.106124967336655, 53.28350342810154, 53.16159076988697, 54.45769362151623, 57.74793326854706, 58.38659539818764, 61.41193225979805, 61.25451810657978, 57.8936630487442, 54.57038417458534, 56.52441792190075, 51.79047234356403, 52.69271872937679, 49.36508148908615, 45.853879898786545, 44.89791199564934, 44.436213970184326, 46.33803851902485, 48.30274969339371, 49.66583915054798, 51.479158848524094, 48.545115888118744, 49.9786801636219, 52.72796183824539, 58.65998312830925, 60.26299171149731, 59.43023979663849, 51.44260101020336, 59.18853856623173, 39.85294930636883, 27.57990427315235, 53.57680208981037, 53.984546810388565, 57.72168807685375, 60.64885340631008, 58.586164489388466, 57.71513722836971, 53.34713861346245, 46.467185989022255, 43.96164983510971, 44.06258761882782, 46.10639914870262, 48.853712528944016, 45.56275092065334, 47.092241048812866, 50.91472573578358, 56.866323575377464, 57.86951534450054, 58.69517683982849, 56.68692760169506, 52.08365321159363, 51.55750684440136, 52.76785969734192, 52.271112352609634, 54.66936506330967, 55.99224887788296, 59.518604055047035, 59.576357156038284, 59.28500398993492, 54.54911671578884, 56.267080530524254, 56.88855618238449, 57.12284781038761, 56.66382484138012, 63.71582083404064, 61.53818428516388, 57.654728069901466, 55.37823602557182, 51.2467785179615, 35.739035457372665, 26.376123167574406, 27.24696233868599, 27.446442134678364, 16.010735370218754, 16.13148719072342, 21.954061053693295, 16.625295393168926, 12.093974892050028, 3.500836221501231, 1.0808572266250849, 0.18328686099266633, 0.2102457167347893, 1.7193379160016775, 11.432459838688374, 44.89215150475502, 59.593011662364006, 35.1847629994154, 38.45962107181549, 37.15350955724716, 60.51710307598114, 52.98309534788132, 56.1083098500967, 16.94297354668379, 0.37861376185901463, 0.18415984930470586, 0.16535608330741525, 0.14606999553507194, 0.12160953541751951, 0.17558047373313457, 0.13943691708846018, 0.07791758733219467, 0.08434795556240715, 0.09908015097607858, 0.07861945865442976, 0.1212343797669746, 0.15989582083420828, 0.08708767534699291, 0.14052210026420653, 0.1173509361979086, 0.21126470033777878, 0.21843190246727318, 0.19247089396230876, 0.0988640969444532, 0.12416789657436311, 0.21859928645426407, 0.1601687233778648, 0.1252556178951636, 0.12392963006277569], [0.05758807703386992, 0.028411188650352415, 0.05416880601842422, 0.05744512083765585, 0.005640336721626227, 0.016891104860405903, 0.02260136719996808, 0.07062732969643548, 0.08596594139817171, 0.04812235078134108, 0.04017925923108123, 0.08647888418636285, 0.03276700364949647, 0.06755413327482529, 0.03979703462391626, 0.16289109917124733, 0.07360662959399633, 0.03316575959615875, 0.07486955713829957, 0.02268287913466338, 0.04203706637781579, 0.0031624484927306185, 0.06017770116159227, 1.2549872766248882, 23.035386130213737, 51.95677421987057, 48.61649505794048, 46.125078946352005, 34.199506267905235, 12.341913487762213, 20.11617947369814, 28.887423612177372, 37.250738739967346, 19.011934027075768, 3.6138663813471794, 0.3147726156748831, 0.13827616843627766, 0.16070059093181044, 1.9027335313148797, 7.220963425934315, 6.143673732876778, 6.293485444039106, 11.39000566676259, 12.94318562373519, 7.275151843205094, 19.1139205545187, 19.015724323689938, 29.001744277775288, 48.214989602565765, 56.81547090411186, 56.70303113758564, 56.418707594275475, 54.26741883158684, 54.876332357525826, 52.14160390198231, 53.22175674140453, 52.22279414534569, 54.81912262737751, 53.12664784491062, 53.32887299358845, 53.37677322328091, 52.3481760174036, 54.74590815603733, 56.77767813205719, 55.289039611816406, 52.373148277401924, 48.88138644397259, 44.76224027574062, 43.854651376605034, 42.581237107515335, 41.37316033244133, 40.549330338835716, 40.73698326945305, 41.17767982184887, 40.08892044425011, 43.69116134941578, 53.52936543524265, 56.54284693300724, 55.450895726680756, 52.36484192311764, 50.22239908576012, 48.14011462032795, 51.75780549645424, 52.677850127220154, 57.47665822505951, 47.56903946399689, 55.590671226382256, 29.177697636187077, 23.20298183709383, 55.5492040514946, 50.046666115522385, 54.78664197027683, 52.10006073117256, 53.45019668340683, 52.926033809781075, 53.04530940949917, 48.45571428537369, 43.60929474234581, 40.82206830382347, 42.71491013467312, 42.200961112976074, 44.39732685685158, 42.892713993787766, 46.33861608803272, 51.542239263653755, 55.33306024968624, 53.779874593019485, 53.54603514075279, 50.95034122467041, 49.10948060452938, 47.53256142139435, 47.42050543427467, 48.41844968497753, 49.40741501748562, 47.81008332967758, 52.80534848570824, 54.286307618021965, 52.5425735861063, 47.962736338377, 47.27067567408085, 49.029065519571304, 52.451192289590836, 54.21557441353798, 49.07163463532925, 37.3555751144886, 23.11041310429573, 21.652902513742447, 20.94117220491171, 14.910110179334879, 14.238128587603569, 11.324343290179968, 7.261445503681898, 10.626000612974167, 9.724286198616028, 7.572702951729298, 4.710700800642371, 1.6957709868438542, 0.475569388945587, 0.051993916276842356, 0.086123588407645, 0.10347511983127333, 2.5938101671636105, 20.81902965903282, 35.69311872124672, 39.823671877384186, 15.319247525185347, 25.975645557045937, 35.622651502490044, 43.5696704685688, 53.60544495284557, 19.637296870350838, 0.5876635224558413, 0.05782028762041591, 0.130328033992555, 0.04963496648997534, 0.013523154284484917, 0.06415446609025821, 0.0441358785610646, 0.03751030693820212, 0.024994581945065875, 0.01014846686302917, 0.04380672122351825, 0.0433780159073649, 0.023399534038617276, 0.025900556865963154, 0.011418882677389774, 0.07815146032953635, 0.1003239607962314, 0.041794714343268424, 0.04719574601040222, 0.061256052867975086, 0.030883629515301436, 0.03862688296067063, 0.02665860505658202, 0.11420014823670499, 0.0898545428935904, 0.08464272177661769, 0.022651200561085716, 0.11389642430003732, 0.14278749120421708, 0.03290700238721911, 0.04132331698201597, 0.08039222680963576, 0.10532285232329741, 0.06823706498835236, 0.05088544079626445, 0.05678728855855297, 0.12024446608847938, 0.08741681042010896, 0.060600317156058736, 0.018397089479549322, 0.10619671636959538, 0.021345675595512148, 0.0032655615632393165, 0.039762702872394584, 0.0983656854077708, 0.045416406137519516, 0.06291517594945617, 0.11321946687530726, 1.581323859281838, 26.380682922899723, 60.48007406294346, 54.56304296851158, 52.02436879277229, 40.878461077809334, 16.587443724274635, 18.245727941393852, 31.955620273947716, 39.468512535095215, 19.48686484247446, 4.165715519338846, 0.42070214403793216, 0.029269436054164544, 0.3932948678266257, 2.8688232600688934, 8.389567919075489, 9.484289176762104, 12.090997751802206, 18.091251030564308, 13.07796249166131, 8.86630553752184, 22.0997167378664, 22.84429058432579, 31.648602448403835, 47.78850428760052, 55.69045007228851, 56.384897008538246, 57.474545538425446, 55.31379148364067, 56.48262396454811, 54.05779168009758, 53.365495428442955, 52.932945638895035, 54.696020632982254, 53.952852711081505, 53.027161583304405, 54.38370019197464, 53.951344192028046, 56.444724798202515, 58.25487166643143, 57.75332897901535, 54.68780167400837, 51.56627297401428, 46.601782366633415, 46.09684646129608, 43.38922195136547, 45.18381245434284, 41.55179254710674, 41.46295331418514, 42.68178731203079, 40.66933549940586, 45.91822184622288, 54.762034490704536, 58.0447543412447, 58.155415803194046, 53.62282522022724, 51.78757309913635, 49.98139701783657, 53.86293813586235, 54.54271785914898, 60.23991174995899, 49.90470193326473, 57.160025015473366, 31.74061071127653, 24.865789711475372, 55.05814120173454, 50.48004426062107, 56.38662211596966, 54.03498910367489, 55.73539786040783, 55.40437862277031, 53.74340035021305, 49.84071336686611, 45.49744002521038, 41.83999568223953, 44.85655881464481, 44.27842743694782, 45.88284574449062, 45.307511016726494, 48.338995948433876, 54.809805527329445, 56.859274953603745, 55.79330675303936, 54.35337021946907, 52.29384273290634, 49.4995828717947, 48.08095179498196, 48.40480461716652, 48.91973778605461, 50.99198319017887, 50.01841463148594, 55.172245278954506, 57.080069705843925, 54.027723893523216, 50.23909159004688, 49.30765897035599, 49.76916700601578, 55.609149634838104, 57.65890024602413, 50.29396064579487, 38.30850698053837, 25.761743634939194, 25.11654205620289, 22.154633291065693, 14.665622748434544, 11.41682367771864, 11.357677951455116, 9.290533773601055, 12.46089555323124, 9.493148401379585, 13.387397937476635, 4.615256572142243, 3.8455480244010687, 1.0055513237603009, 0.20798148354515433, 0.01848470557888504, 0.1057361024140846, 3.5605516796931624, 24.355080015957355, 39.51458126306534, 38.26757177710533, 23.568030148744583, 29.676713459193707, 43.38973492383957, 48.20739381015301, 61.23769260942936, 25.671893656253815, 1.1893938900902867, 0.06387367451679893, 0.12329364661127329, 0.03952261438826099, 0.00829746149975108, 0.10501363649382256, 0.020321940392022952, 0.04418172473378945, 0.035328726735315286, 0.06137105607194826, 0.02871470478567062, 0.0659904429630842, 0.02800665137328906, 0.03572253626771271, 0.03875796108331997, 0.08156384792528115, 0.06790600033127703, 0.04018987194285728, 0.06400188052793965, 0.07876570627558976, 0.10488675892702304, 0.05754941113991663, 0.03861173943732865, 0.05339691306289751, 0.06740333628840744, 0.27490785636473447, 0.11957256268942729, 0.16218086384469643, 0.2930571371689439, 0.12414555792929605, 0.16210642643272877, 0.15829549811314791, 0.21853014797670767, 0.25015197694301605, 0.17198977031512186, 0.2971010998589918, 0.20081100112292916, 0.14853560307528824, 0.21966039435938, 0.09346331760752946, 0.14144343207590282, 0.1143396200495772, 0.13041522150160745, 0.1266453487914987, 0.18750705407001078, 0.11589001849642955, 0.14764496649149805, 0.21047361544333398, 2.583696534857154, 34.690812304615974, 69.61118549108505, 62.853236719965935, 58.479891791939735, 44.74933996796608, 21.252225413918495, 29.095616340637207, 42.01312959194183, 47.750806510448456, 23.525284342467785, 4.831793177872896, 0.6639410450588912, 0.25130631343927234, 0.7423910417128354, 4.559434717521071, 13.568379376083612, 16.473658829927444, 14.014759473502636, 23.023834750056267, 24.47248611599207, 12.452647145837545, 24.177266657352448, 24.493343196809292, 31.369273737072945, 49.27538350224495, 57.015549167990685, 56.97123974561691, 55.19232340157032, 57.61409305036068, 57.17300131917, 56.34233929216862, 55.17731040716171, 54.50018294155598, 55.18286570906639, 54.246337562799454, 53.51540118455887, 55.90106517076492, 55.0631645321846, 58.22457209229469, 60.86929477751255, 60.18925666809082, 56.99541784822941, 53.948444947600365, 48.77624608576298, 49.35230277478695, 45.82722432911396, 46.43964886665344, 44.76668603718281, 45.91984435915947, 43.99924121797085, 41.92249685525894, 48.24058122932911, 57.7265328168869, 60.39988316595554, 60.70312589406967, 56.46564647555351, 54.28382635116577, 51.874029859900475, 56.89118944108486, 56.01727433502674, 61.64166033267975, 51.854297518730164, 60.098046362400055, 35.009193420410156, 29.155634120106697, 55.3970792144537, 52.02229790389538, 59.633433893322945, 55.73156766593456, 57.652265802025795, 58.15315492451191, 55.673328191041946, 51.52854859828949, 47.565289065241814, 44.37284097075462, 47.158045917749405, 45.50563998520374, 49.28024344146252, 48.20224888622761, 50.642994716763496, 57.22638085484505, 60.04344329237938, 57.055690214037895, 56.04994498193264, 52.07973562180996, 49.562606289982796, 48.14906693994999, 48.181467801332474, 50.39193458855152, 49.741971865296364, 50.1934028416872, 55.3945941478014, 57.28579826653004, 54.680224880576134, 51.03114768862724, 50.73142357170582, 51.07332922518253, 56.055823266506195, 59.7058580070734, 53.18035036325455, 41.860457584261894, 26.33353505283594, 27.33828853815794, 24.82015796005726, 19.82486240565777, 21.997194439172745, 19.971124157309532, 18.88596698641777, 22.064760513603687, 19.7705215215683, 15.131048373878002, 11.136543117463589, 6.314694955945015, 0.8303417160641402, 0.26726103387773037, 0.20941323484294116, 0.2801399084273726, 4.326157635077834, 26.747139059007168, 50.85618607699871, 53.15968707203865, 24.59018100053072, 36.60522937774658, 50.070403441786766, 56.14604562520981, 68.2757319509983, 31.881581246852875, 2.759469165466726, 0.17799163731979206, 0.2405523115885444, 0.15579904691549018, 0.122445438610157, 0.17483247793279588, 0.17654272756772116, 0.16748318244935945, 0.17748227168340236, 0.20668947865488008, 0.06981620681472123, 0.12559762923046947, 0.1321833289694041, 0.18682730617001653, 0.16960881213890389, 0.17133662098785862, 0.17009644769132137, 0.11219332896871492, 0.19202762399800122, 0.15716450958279893, 0.1410200516693294, 0.15046858607092872, 0.14715552009874955, 0.2029149601003155, 0.1812370787956752], [0.0396263221045956, 0.03203773965651635, 0.01138283749241964, 0.06833669831394218, 0.059271846839692444, 0.06768546372768469, 0.03354665204824414, 0.08388435075175948, 0.028700837756332476, 0.0921256112633273, 0.061195174494059756, 0.05797073579742573, 0.025581405534467194, 0.020582692122843582, 0.02862831694073975, 0.03207824607670773, 0.03230266782338731, 0.06723443089867942, 0.032687868442735635, 0.014527822786476463, 0.031476638905587606, 0.029124693137418944, 0.050171865805168636, 2.0341127878054976, 28.019470386207104, 53.40679921209812, 54.03869770467281, 43.91528092324734, 30.760778188705444, 17.8347609937191, 20.296527296304703, 33.620903715491295, 27.503792457282543, 8.57521265745163, 0.5795191938523203, 0.1949181704549119, 0.0675598849193193, 0.6932074308861047, 1.7496338090859354, 5.61810445971787, 6.356074260547757, 9.376708399504423, 15.567029379308224, 12.705328837037086, 7.965571470558643, 19.314179308712482, 25.910792537033558, 42.70594261586666, 46.32341310381889, 54.01879817247391, 58.183807879686356, 59.815873503685, 54.282051846385, 53.71854968369007, 55.879079550504684, 58.381910249590874, 53.831882402300835, 53.02094131708145, 54.2824774235487, 55.11986128985882, 52.78458259999752, 54.707005843520164, 53.133407682180405, 53.81800934672356, 52.382902354002, 49.56473417580128, 43.83058726787567, 41.488328352570534, 42.39069253206253, 43.57147537171841, 43.035225346684456, 39.946519285440445, 41.09865926206112, 39.08362738788128, 44.444075748324394, 53.88531893491745, 55.43174475431442, 55.05366884171963, 56.70833185315132, 56.682352647185326, 55.661054849624634, 53.004814982414246, 54.63042475283146, 54.6765922755003, 56.40947788953781, 48.680039048194885, 49.529848247766495, 22.63831503689289, 29.762938432395458, 53.07275153696537, 50.73761723935604, 54.80716846883297, 54.91236962378025, 52.053722217679024, 52.3037526011467, 50.522290393710136, 47.47849032282829, 43.259713500738144, 42.024160400033, 41.723220348358154, 40.923712849617004, 42.52035677433014, 40.815057680010796, 41.66339635848999, 47.25377418100834, 52.635300010442734, 53.976605236530304, 52.06574857234955, 52.37751044332981, 51.15052208304405, 52.243989408016205, 51.52018524706364, 52.49324083328247, 50.417560413479805, 50.58761648833752, 47.733338847756386, 50.60971990227699, 52.74464674293995, 48.98631401360035, 53.93242880702019, 48.714032024145126, 53.703289702534676, 51.780406683683395, 49.798106253147125, 43.87175805866718, 38.62142778933048, 29.008944891393185, 26.3290835916996, 15.215890221297741, 11.02159833535552, 6.127167893573642, 4.229323631152511, 5.527443224564195, 11.75796652212739, 10.700668506324291, 2.5369858788326383, 3.281839247792959, 1.121683542151004, 0.08152932321536355, 0.054187953428481705, 0.1028864631371107, 2.2029724018648267, 11.834326274693012, 33.883321434259415, 29.72214762121439, 17.40078628063202, 28.264676928520203, 33.407974541187286, 47.216365188360214, 42.40108497440815, 26.698898747563362, 3.361352593638003, 0.05931198589678388, 0.05542347345908638, 0.02395112045633141, 0.08435251977061853, 0.01748194346873788, 0.01603888740646653, 0.05586571554886177, 0.01673473434493644, 0.05130654652020894, 0.07152131336624734, 0.030946489423513412, 0.04577434025122784, 0.04795662178366911, 0.02842252124537481, 0.028496466984506696, 0.0760397088015452, 0.04228083220368717, 0.011732398324966198, 0.0111322244265466, 0.06619511244934984, 0.014918979140929878, 0.07700202200794592, 0.05287746535032056, 0.029124763641448226, 0.04084781925485004, 0.04886554117547348, 0.020108444914512802, 0.055244652976398356, 0.07731799880275503, 0.0634470880322624, 0.016726335088605992, 0.033740816434146836, 0.00586621215006744, 0.13912508147768676, 0.03314041896373965, 0.04739877906104084, 0.03048093833058374, 0.01140268530434696, 0.0864544155774638, 0.04087437700945884, 0.07478493003873155, 0.01802152193704387, 0.06392693845555186, 0.03126022493233904, 0.06816085384343751, 0.03285187565779779, 0.05611820160993375, 2.792388224042952, 36.050846725702286, 61.269021928310394, 60.770161896944046, 50.198437571525574, 34.5408533513546, 19.32841144502163, 25.23863710463047, 35.7617012411356, 32.19740889966488, 10.081129800528288, 0.8724401914514601, 0.1423131549381651, 0.31384884961880744, 1.4778706105425954, 4.787041079252958, 11.172407492995262, 8.924894593656063, 10.500081069767475, 14.85047522932291, 11.076274551451206, 9.587733875960112, 19.746223725378513, 27.23022423684597, 41.003238782286644, 48.30373764038086, 56.14351496100426, 59.488220885396004, 58.05621452629566, 56.238517463207245, 55.356884971261024, 56.0042068362236, 58.934624791145325, 52.995535880327225, 53.1298016756773, 54.1032562404871, 55.74935831129551, 54.434606060385704, 58.19584183394909, 55.01062475144863, 55.12686051428318, 54.378080293536186, 50.6081809848547, 45.25114484131336, 43.13110940158367, 43.844885900616646, 45.240144431591034, 45.15428423881531, 41.16125330328941, 43.66528853774071, 42.71854653954506, 45.75452663004398, 56.28750063478947, 59.703623726964, 56.54251255095005, 57.82255746424198, 58.889065235853195, 57.69062094390392, 55.11038079857826, 56.49161048233509, 55.37071242928505, 57.95707784593105, 50.60099937021732, 51.041619926691055, 25.76139595359564, 32.03953117132187, 54.723770543932915, 52.32016772031784, 56.51724770665169, 55.13801671564579, 53.57522517442703, 53.592901825904846, 52.84881815314293, 49.41265493631363, 44.47295419871807, 43.69247987866402, 42.50352367758751, 43.21898728609085, 43.9944002777338, 42.88063444197178, 43.85981909930706, 49.84304644167423, 54.78720813989639, 54.962013959884644, 53.128091767430305, 53.12764719128609, 52.20546707510948, 52.01200045645237, 51.882237419486046, 50.90481586754322, 50.52109345793724, 50.7088527828455, 50.117976889014244, 53.04558299481869, 54.9817007035017, 49.21518713235855, 54.91443291306496, 50.01049965620041, 55.79798050224781, 54.196028262376785, 55.83894990384579, 50.4558889567852, 40.21112948656082, 30.04918087273836, 26.271940357983112, 15.185690391808748, 11.987604349851608, 8.343912418931723, 8.693527858704329, 9.39457694068551, 8.420332968235016, 11.032653842121363, 6.747319316491485, 6.3908803928643465, 4.700240436941385, 0.28852065559476614, 0.10117443976923823, 0.10652513898094185, 1.81434077443555, 14.10082295536995, 33.796249106526375, 34.7697264701128, 17.08517711609602, 31.53923101723194, 39.24993306398392, 53.35799463093281, 50.408581495285034, 32.61060252785683, 4.3693451676517725, 0.07169227450503968, 0.08650666277389973, 0.024125675445247907, 0.0893405759416055, 0.04090015921974555, 0.04191549145616591, 0.06065027482691221, 0.02764366137853358, 0.040517095985705964, 0.02618480684759561, 0.024928584607550874, 0.010626779185258783, 0.06348738665110432, 0.05305861988745164, 0.06910376730957069, 0.0587455379718449, 0.026031750021502376, 0.0482685946917627, 0.04353513228124939, 0.03797166675212793, 0.01582207638421096, 0.02552629364799941, 0.0266806301442557, 0.06520496870507486, 0.08945664783823304, 0.18044857657514513, 0.08257129855337553, 0.1333208632422611, 0.14796487666899338, 0.1678236055886373, 0.14887713943608105, 0.20178943377686664, 0.17763568845111877, 0.34567362628877163, 0.13981562020489946, 0.13814464502502233, 0.16166686720680445, 0.13876695069484413, 0.2030265939538367, 0.15494191087782383, 0.13703537173569202, 0.13484098948538303, 0.11302767365123145, 0.058693079263321124, 0.16660897701513022, 0.11726119570084848, 0.17057366349035874, 4.579454893246293, 43.235033825039864, 67.39137500524521, 69.40894514322281, 56.513155326247215, 40.7433745265007, 26.122243590652943, 32.599556520581245, 44.65113423764706, 36.79103180766106, 11.8168861605227, 1.1883795820176601, 0.3847374895121902, 0.39224181964527816, 1.4609486935660243, 4.34389840811491, 10.920361317694187, 20.293287970125675, 20.96613496541977, 27.149100489914417, 21.716383807361126, 13.173269927501678, 23.136903382837772, 27.328973338007927, 44.36661310493946, 50.997937470674515, 58.1758739054203, 58.4745454788208, 59.080704152584076, 59.21503074467182, 57.6884550601244, 55.57698056101799, 58.69189001619816, 53.826574087142944, 53.69738481938839, 54.14073742926121, 56.66936494410038, 54.965315982699394, 59.91098240017891, 56.31397761404514, 57.655233442783356, 56.95023447275162, 52.74819575250149, 47.82871372997761, 44.835302755236626, 47.26262390613556, 47.49235197901726, 47.998936995863914, 43.434013947844505, 45.68292707204819, 44.20283429324627, 49.46058176457882, 58.62524539232254, 59.53646309673786, 57.882928624749184, 60.693181827664375, 61.64165273308754, 60.37382796406746, 59.007223695516586, 58.18780526518822, 59.81700584292412, 58.782192170619965, 53.022358641028404, 53.94166611135006, 29.52564686536789, 34.999218955636024, 56.15765020251274, 53.99923302233219, 57.94789373874664, 58.21412265300751, 57.26412042975426, 55.7458359003067, 55.08054479956627, 51.41920946538448, 46.9057622551918, 46.67812407016754, 44.819161221385, 45.1080597192049, 46.862269788980484, 46.24497391283512, 46.390232518315315, 52.52163290977478, 57.29582592844963, 56.406582444906235, 54.443603977561, 54.64536175131798, 51.9610869884491, 52.542569786310196, 52.25310891866684, 52.04467870295048, 49.61690157651901, 51.17254950106144, 50.15900328755379, 51.158182471990585, 56.200416907668114, 49.78617109358311, 53.99414889514446, 48.29660162329674, 55.93227669596672, 55.630656480789185, 55.754123255610466, 54.12983201444149, 46.22182555496693, 34.438486844301224, 31.44870087504387, 19.98167809098959, 14.730082489550114, 10.755605958402157, 13.063520416617393, 15.443972032517195, 20.763670429587364, 19.97743371874094, 8.738797679543495, 7.185735991224647, 3.87079244479537, 0.2740974014159292, 0.13088083011098206, 0.27479297190438956, 3.572935927659273, 15.684697665274143, 44.56073708832264, 42.07119047641754, 28.54290559887886, 42.21583351492882, 46.50063179433346, 60.488912388682365, 57.666895017027855, 41.0396446287632, 6.448566047474742, 0.16352072241716087, 0.18361983296927065, 0.07898855837993324, 0.14101850800216198, 0.11642653931630775, 0.15996219852240756, 0.13472215679939836, 0.08287068834761158, 0.1289580442244187, 0.2189851735602133, 0.23023389105219394, 0.1345389205380343, 0.13183471251977608, 0.1963180094026029, 0.10233052031253465, 0.18980999768245965, 0.11223939407500438, 0.12577479472383857, 0.1653045931016095, 0.18548067921074107, 0.2078354882542044, 0.1830094461911358, 0.1102544458990451, 0.10119004713487811], [0.057618801947683096, 0.09822610969422385, 0.0630692309641745, 0.03962105656682979, 0.046253537584561855, 0.06278790504438803, 0.0319410563679412, 0.0160749242422753, 0.04966229978890624, 0.041972143299062736, 0.024800963037705515, 0.012066579074598849, 0.06252023464185186, 0.031229919331963174, 0.04342287502367981, 0.04449985004612245, 0.0637518435542006, 0.03674783183669206, 0.0817489915061742, 0.07972439780132845, 0.01842667148594046, 0.031917203741613775, 0.10599792469292879, 5.146664706990123, 35.146806836128235, 51.38327479362488, 47.28139489889145, 35.78586794435978, 27.303906083106995, 23.19791480898857, 30.37402544170618, 33.31329882144928, 26.24005626887083, 6.142956046387553, 0.4416551400208846, 0.08677595105837099, 0.4558141599409282, 1.3843874330632389, 6.227429788559675, 12.116300594061613, 5.122517002746463, 10.91036880388856, 19.45443358272314, 10.163672771304846, 12.26970311254263, 30.8104757219553, 34.26705524325371, 38.98995101451874, 55.02538315951824, 65.52329644560814, 59.61087450385094, 58.655313178896904, 54.160158187150955, 57.09747277200222, 53.61951559782028, 52.65006601810455, 53.32307830452919, 54.95256006717682, 53.52712355554104, 54.6942613273859, 54.32018280029297, 55.24680867791176, 49.047570526599884, 49.617794528603554, 44.986147060990334, 44.68131221830845, 40.54521515965462, 43.44489276409149, 44.41259063780308, 46.20359033346176, 44.999089166522026, 41.02542959153652, 39.53783601522446, 42.3627944290638, 50.34303121268749, 53.46375435590744, 52.77425475418568, 55.768049508333206, 53.55622999370098, 55.06764829158783, 55.52347183227539, 55.4679150134325, 55.53439624607563, 55.2811474353075, 52.05072037875652, 48.19732055068016, 42.19024948775768, 25.97736306488514, 36.802932769060135, 52.857956662774086, 56.49081252515316, 53.26183699071407, 50.860194861888885, 51.03774793446064, 51.59900821745396, 50.6838995218277, 48.078721314668655, 42.30985566973686, 41.618106588721275, 41.015664115548134, 43.247846737504005, 39.484247490763664, 40.310638546943665, 39.97470237314701, 43.25345143675804, 45.567348673939705, 50.00617928802967, 52.78829500079155, 50.383491441607475, 49.97438259422779, 48.985075280070305, 49.80842649936676, 49.60718549787998, 50.400590524077415, 50.98908394575119, 49.905142709612846, 47.784480303525925, 46.47001303732395, 52.00913920998573, 51.774866580963135, 54.882719814777374, 56.3992640376091, 53.89476142823696, 51.64734922349453, 51.52609393000603, 49.5623555034399, 45.62391623854637, 42.11108073592186, 29.538478776812553, 17.791333124041557, 14.863202646374702, 10.079781822860241, 9.517181161791086, 3.948668553493917, 12.540647573769093, 4.919726634398103, 5.604039039462805, 3.055500593036413, 0.2018378663342446, 0.1155991708219517, 0.08047712108236738, 0.5902568239253014, 9.051422104239464, 29.020633064210415, 37.01687648892403, 18.391111940145493, 19.164881519973278, 36.190295442938805, 39.35955338180065, 52.97983892261982, 35.50174579024315, 7.063791509717703, 0.18421963672153652, 0.05235546093899757, 0.043949298924417235, 0.04820268826733809, 0.027553744621400256, 0.024599332646175753, 0.02899893806898035, 0.03260615427279845, 0.03312807333713863, 0.018804736355377827, 0.038489641301566735, 0.05512925643415656, 0.01982246758416295, 0.0482339809241239, 0.05614167945168447, 0.011259282891842304, 0.013703596359846415, 0.08089008173556067, 0.07339076852076687, 0.024207703172578476, 0.007200353866210207, 0.02705372819036711, 0.055317338919849135, 0.021505723452719394, 0.016959052190941293, 0.045346551487455145, 0.0355989315721672, 0.042153171671088785, 0.01819537559640594, 0.037160128267714754, 0.05432787424069829, 0.018469148308213335, 0.031815503534744494, 0.052309210295788944, 0.05478891864186153, 0.035059802103205584, 0.06500973933725618, 0.05586944113019854, 0.03495254321023822, 0.07566549567854963, 0.040796885659801774, 0.03888652703608386, 0.02291885426529916, 0.03606285550631583, 0.02884748984797625, 0.04983103077393025, 0.03143759080558084, 6.635349774733186, 41.8104712665081, 58.607249557971954, 54.808726385235786, 42.229311391711235, 31.081817261874676, 24.068769179284573, 31.044624857604504, 36.2789598852396, 25.910686142742634, 7.223484590649605, 0.43259820726234466, 0.1891919519403018, 0.4360821156296879, 2.978109195828438, 7.047595353797078, 8.534923419356346, 8.989023752510548, 13.259013276547194, 17.061075009405613, 7.033561281859875, 12.189800050109625, 21.634883880615234, 33.855237141251564, 40.13516776263714, 56.24397397041321, 62.484048530459404, 59.915310367941856, 58.62455002963543, 56.06158375740051, 57.07839019596577, 54.303775280714035, 54.374006912112236, 53.98326627910137, 55.11602349579334, 53.50429058074951, 54.495148211717606, 55.64143270254135, 56.555678844451904, 53.433667570352554, 51.67175151407719, 48.18760447204113, 46.037809029221535, 42.44849883019924, 44.0249278396368, 47.87588819861412, 48.34484003484249, 46.773730739951134, 41.957101598381996, 41.79250203073025, 42.8245684504509, 51.42377682030201, 56.31284527480602, 54.96799483895302, 55.722505152225494, 54.32428278028965, 57.01185956597328, 57.00644865632057, 58.05551156401634, 57.59080410003662, 57.44261585175991, 55.39829134941101, 49.6709992736578, 43.358629792928696, 27.89490357041359, 39.23581302165985, 55.49658067524433, 59.49626885354519, 54.74255293607712, 53.39281976222992, 52.749977856874466, 53.457944467663765, 52.44665153324604, 51.148834973573685, 44.579565078020096, 43.15841093659401, 43.51643532514572, 44.271492809057236, 41.52155376970768, 41.07435196638107, 41.53657056391239, 45.33962309360504, 47.60120093822479, 52.597108259797096, 54.67380702495575, 52.6129762083292, 51.91909924149513, 50.048330426216125, 50.45524299144745, 50.765275955200195, 50.541171580553055, 50.266457721590996, 49.642337411642075, 51.21252715587616, 48.27346846461296, 51.83954671025276, 52.6274648308754, 55.52957430481911, 56.3011609017849, 54.549367502331734, 52.13761031627655, 54.013136476278305, 54.25625883042812, 50.00304825603962, 46.02827534079552, 32.9324908554554, 16.90665129572153, 12.610061299055815, 7.579487012699246, 13.338185828179121, 10.55753968656063, 12.941370271146297, 8.562825322151184, 7.3213868122547865, 4.816718436777592, 0.8882633142638952, 0.10127644054591656, 0.04781013667525258, 0.6379025266505778, 10.248661860823631, 31.246633417904377, 40.38590490818024, 22.244606763124466, 25.905328430235386, 43.72781418263912, 46.65617264807224, 58.25250059366226, 41.89884312450886, 9.053130112588406, 0.260665537789464, 0.1265375889488496, 0.02915479093644535, 0.040484482306055725, 0.01521059772130684, 0.05063390468421858, 0.03234207586501725, 0.03140637607430108, 0.038883476809132844, 0.02011538399528945, 0.08012080856133252, 0.0572410747554386, 0.06830837795860134, 0.03329809936985839, 0.03464137924311217, 0.03595586749725044, 0.03910675193765201, 0.08653986646095291, 0.03754228608158883, 0.0253370459904545, 0.029915178747614846, 0.06547620141645893, 0.0755564593418967, 0.01825666957302019, 0.15674719994422048, 0.18362421164056286, 0.14840995747363195, 0.12305111275054514, 0.161450560844969, 0.09757322011864744, 0.13311148853972554, 0.11920069475308992, 0.0829728895041626, 0.19289903895696625, 0.09573084593284875, 0.14404289337107912, 0.11050207089283504, 0.10542186966631562, 0.21811178448842838, 0.12852035521063954, 0.12136438919696957, 0.14617861626902595, 0.16985523485345766, 0.09578374621924013, 0.11996561152045615, 0.12677129125222564, 0.20378922490635887, 9.502135869115591, 51.50504685938358, 65.61514511704445, 60.26963755488396, 47.62674316763878, 37.95231409370899, 31.229515336453915, 40.35194993019104, 44.92089316248894, 33.28661285340786, 7.9134786408394575, 0.7457340904511511, 0.3471592871937901, 1.0623257397674024, 2.9537007305771112, 11.945362966507673, 19.485082738101482, 18.259903080761433, 17.746894508600235, 28.040496557950974, 17.207703441381454, 17.09033153951168, 34.48711283504963, 37.69226364791393, 41.50580741465092, 58.124888241291046, 66.15707963705063, 62.18866378068924, 60.7912203669548, 58.54600064456463, 58.70538309216499, 56.187691390514374, 56.78971208631992, 54.55603614449501, 55.24383723735809, 55.117482617497444, 56.21101073920727, 56.296992525458336, 58.107230588793755, 54.94887426495552, 53.834447264671326, 49.0592435002327, 47.27165602147579, 44.226282835006714, 47.466118186712265, 48.84094901382923, 49.97179493308067, 48.65666650235653, 43.991873413324356, 44.42618630826473, 46.483357921242714, 54.95444476604462, 58.52077379822731, 56.943296045064926, 56.00590914487839, 52.9038430005312, 57.90601998567581, 58.48864272236824, 59.59533333778381, 59.6181321144104, 58.06325554847717, 53.88627648353577, 51.257816925644875, 46.50682546198368, 33.11170443892479, 41.495927944779396, 56.15780979394913, 61.631290689110756, 58.45604807138443, 54.81642857193947, 54.96805563569069, 56.649955585598946, 55.23752957582474, 53.06261748075485, 46.2675067037344, 45.83097852766514, 45.8174854516983, 47.439398020505905, 43.22215251624584, 43.94940689206123, 42.54202701151371, 47.81712435185909, 50.112110003829, 53.70338089764118, 56.6081540286541, 55.27695246040821, 53.5889158397913, 51.88735954463482, 50.75891889631748, 50.95105178654194, 51.08098581433296, 51.81906200945377, 50.232730731368065, 51.30708508193493, 49.425505846738815, 51.07394099235535, 51.95560768246651, 56.48318633437157, 57.77187958359718, 54.71660412847996, 52.24601089954376, 53.80255177617073, 56.31929352879524, 54.56060349941254, 48.70535708963871, 34.595483019948006, 20.719721987843513, 19.673218242824078, 18.711584843695164, 20.538154430687428, 11.601413022726774, 26.268269754946232, 14.85123423859477, 14.194290339946747, 5.822524940595031, 0.7348907785490155, 0.24267915840027854, 0.18102148489560932, 1.0299594327807426, 12.620062362402678, 36.11717216670513, 51.15671955049038, 29.67464067041874, 30.714737959206104, 48.227369338274, 52.397398576140404, 65.38382112979889, 48.85088548064232, 11.974505502730608, 0.43777729966677725, 0.19458144321106374, 0.242451541707851, 0.08670464550959878, 0.23227622208651155, 0.15554291690932587, 0.10808186052599922, 0.07690738333621994, 0.18028384947683662, 0.13381687022047117, 0.12759203236782923, 0.14853164000669494, 0.11232767254114151, 0.2140342618804425, 0.18957344553200528, 0.11612109359703027, 0.1845820274320431, 0.17051075905328616, 0.20524381950963289, 0.18297901813639328, 0.12412937168846838, 0.18110564444214106, 0.19836571358609945, 0.20151930686552078], [0.03328326012706384, 0.03259667333622929, 0.08899585576727986, 0.10730481706559658, 0.03197752550477162, 0.042644013301469386, 0.03484087596007157, 0.03658612899016589, 0.028180488334328402, 0.0739662372507155, 0.026784107794810552, 0.038384156141546555, 0.04381004975584801, 0.04497875794186257, 0.053286911934264936, 0.03056129251490347, 0.06280248824623413, 0.050618627574294806, 0.028898104319523554, 0.026429888130223844, 0.04208108686725609, 0.03502389328787103, 0.050735575205180794, 7.675831792876124, 38.72976757586002, 50.68571962416172, 43.679393380880356, 34.39731225371361, 22.317486852407455, 23.6538390442729, 28.373178206384182, 37.002330869436264, 19.386700317263603, 2.3331415420398116, 0.15950660890666768, 0.08695712414919399, 0.5814224760979414, 3.8077531149610877, 7.925789030268788, 10.149114802479744, 5.528602637350559, 10.788375400006771, 11.500155106186867, 7.401326922699809, 11.912162248045206, 21.57052483409643, 36.208766251802444, 58.346469551324844, 63.87004315853119, 53.23868863284588, 58.25701855123043, 52.5405178964138, 54.702187702059746, 50.7557612657547, 52.289541363716125, 51.728740856051445, 51.416561007499695, 50.659569427371025, 52.71489813923836, 50.48191376030445, 54.209988713264465, 52.5502909719944, 50.5811720341444, 46.119797229766846, 43.5326224565506, 42.561136186122894, 41.919696405529976, 42.24853835999966, 47.35912352800369, 45.84450960159302, 44.777530655264854, 39.24060456454754, 40.49069568514824, 42.464735358953476, 53.976673632860184, 54.53451409935951, 55.08473977446556, 49.512448981404305, 48.93337905406952, 50.771184638142586, 50.36824285984039, 50.4912194609642, 51.498378217220306, 50.65421551465988, 50.829796493053436, 48.136877194046974, 44.59879204630852, 31.182084381580353, 40.97513169050217, 58.39684344828129, 52.796016186475754, 51.895175725221634, 48.09841565787792, 46.09630309045315, 47.09189146757126, 45.382458195090294, 43.500153198838234, 41.45356401801109, 42.28850461542606, 44.22555707395077, 45.28510361909866, 43.79963032901287, 40.9397441893816, 40.7378838211298, 41.21336750686169, 45.11541612446308, 48.07274803519249, 51.740470826625824, 50.314350351691246, 48.8897991925478, 46.84395097196102, 48.468462601304054, 48.9805269241333, 46.81799456477165, 50.14437407255173, 50.96634216606617, 45.66231697797775, 49.82500120997429, 48.6954852193594, 51.83221310377121, 53.99710513651371, 57.308916226029396, 54.41640883684158, 55.58557949960232, 52.87308745086193, 52.364857122302055, 48.9408228546381, 45.895100086927414, 34.399443939328194, 23.081209771335125, 13.82113041356206, 7.348859813064337, 6.2680168356746435, 9.79826632887125, 10.888761263340712, 6.683714529499412, 7.148828096687794, 9.788629096001387, 2.0017373375594616, 0.26182408968452364, 0.12082700748578645, 0.15190979233011603, 4.635385517030954, 20.09288102388382, 42.089064717292786, 35.70970103144646, 23.49122866988182, 17.376258596777916, 36.00064001977444, 44.164824932813644, 38.66245038807392, 11.762659270316362, 0.6101082649547607, 0.04654287869925611, 0.019538458800525405, 0.025518940819893032, 0.019240226756664924, 0.007312918187381001, 0.014835372494417243, 0.06598072082852013, 0.04599637228238862, 0.01740140374749899, 0.06791881722165272, 0.04801669121661689, 0.07239761907840148, 0.007777844948577695, 0.05288523192575667, 0.007002089114394039, 0.0513086801947793, 0.07930280597065575, 0.00988177516774158, 0.053615690776496194, 0.04567177173157688, 0.03805677253694739, 0.046985840672277845, 0.018645336022018455, 0.02384175757470075, 0.034572726872283965, 0.050687227994785644, 0.03405819217732642, 0.040840794827090576, 0.046770899862167425, 0.04325520159909502, 0.029600808702525683, 0.021938568097539246, 0.01475177419706597, 0.0197396828662022, 0.04407384985825047, 0.06095791730331257, 0.050670373821049, 0.0403392365842592, 0.018984905691468157, 0.028833769392804243, 0.036124754333286546, 0.013960519536340144, 0.01777921072061872, 0.020548347383737564, 0.028246882720850408, 0.10294283667462878, 11.997863799333572, 45.154478028416634, 57.24585101008415, 49.468158558011055, 38.63084748387337, 29.090256728231907, 29.1928094252944, 36.562158688902855, 41.26469895243645, 22.130823768675327, 2.7916852617636323, 0.12896001833723858, 0.1417288472293876, 0.7530993421096355, 3.9270071033388376, 6.868279175832868, 14.541054982692003, 9.88908240571618, 14.362218528985977, 10.335059724748135, 6.280238404870033, 10.217912960797548, 20.87228950113058, 38.95684339106083, 53.719967007637024, 64.6035785973072, 56.37212969362736, 60.214684903621674, 55.48010475933552, 56.031812354922295, 54.02852565050125, 53.25077958405018, 53.50932911038399, 52.89484888315201, 52.164205089211464, 52.871119156479836, 51.71255752444267, 57.388518154621124, 54.44693639874458, 52.04055592417717, 46.95165999233723, 44.84803967177868, 44.22178767621517, 42.81772881746292, 44.58810701966286, 50.50822734832764, 48.194041326642036, 47.82815136015415, 42.13363632559776, 41.95746637880802, 45.32125107944012, 55.96979968249798, 56.13339610397816, 55.86364097893238, 49.47842940688133, 48.96167993545532, 52.03188858926296, 51.78296014666557, 52.19930000603199, 52.50041104853153, 51.127054542303085, 52.20550887286663, 49.08644624054432, 46.91889055073261, 34.59116265177727, 42.72270731627941, 59.44518059492111, 55.7491759210825, 54.56167124211788, 51.02096803486347, 49.60832543671131, 48.80589209496975, 48.87383624911308, 45.00304475426674, 42.075507044792175, 44.1426607221365, 45.7596031576395, 47.51640468835831, 45.562629327178, 42.57809467613697, 42.64883928000927, 43.66285666823387, 47.466916143894196, 51.04219749569893, 53.566128462553024, 51.73928149044514, 51.97316654026508, 47.84668296575546, 49.8545978218317, 49.33450073003769, 48.43895338475704, 50.21734915673733, 51.51476673781872, 45.954920276999474, 49.91418622434139, 47.58243754506111, 51.839368119835854, 53.490341529250145, 55.71449898183346, 54.05023768544197, 54.241390228271484, 53.27149227261543, 49.713914170861244, 49.90194708108902, 46.17660418152809, 35.05444899201393, 24.427010156214237, 13.787645660340786, 6.626676740124822, 12.700696885585785, 14.792896918952465, 7.445817310363054, 14.546795524656773, 6.849381839856505, 3.5225287824869156, 2.6101115299388766, 0.188243116135709, 0.15063098282553256, 0.24068430997431278, 5.12208572588861, 22.955860197544098, 42.00287014245987, 30.462353602051735, 25.28919719159603, 22.54047978669405, 40.78014895319939, 51.092514395713806, 43.167667239904404, 15.277771800756454, 0.7375058101024479, 0.06946744193555787, 0.020129894837737083, 0.02019514260609867, 0.035816365998471156, 0.05641034433210734, 0.09232795782736503, 0.0433538701327052, 0.044983767438679934, 0.0561298533284571, 0.05978252607746981, 0.05737673935072962, 0.04860433858993929, 0.07974197927978821, 0.06973224022658542, 0.02292832035891479, 0.10318397529772483, 0.057504136420902796, 0.0060222844149393495, 0.02148074832803104, 0.023809219965187367, 0.03172995617205743, 0.024667359757586382, 0.0321567986975424, 0.17644253763137385, 0.11729941630619578, 0.12199127391795628, 0.1355541340308264, 0.17547333729453385, 0.1330399455036968, 0.16418452898506075, 0.09303598897531629, 0.10717367957113311, 0.11606072730501182, 0.09146110707661137, 0.1343553132028319, 0.23164158192230389, 0.06914618104929104, 0.13954699243186042, 0.10585784431896172, 0.23866396135417745, 0.18897536356234923, 0.10986340086674318, 0.05731620607548393, 0.0888108235085383, 0.280126134166494, 0.3410368360346183, 17.17222284525633, 51.627168506383896, 64.45182234048843, 56.620765551924706, 44.199194088578224, 32.46494494378567, 34.317896515131, 39.63797204196453, 47.86664329469204, 24.501244872808456, 3.2939762715250254, 0.411498622270301, 0.23629055824130774, 1.0868890467099845, 4.750614808872342, 12.476248629391193, 20.06909240037203, 15.016101691871881, 21.793694458901882, 21.95141449570656, 12.677083052694798, 15.443832390010357, 22.541957907378674, 41.00928045809269, 60.89313089847565, 65.1570113003254, 59.57678273320198, 62.50877380371094, 59.716622829437256, 55.38731373846531, 53.6684113740921, 54.560352712869644, 53.752227276563644, 54.355038329958916, 51.70819915831089, 54.273023530840874, 53.60073700547218, 58.90677608549595, 56.52464210987091, 54.98439095914364, 49.56134855747223, 46.50641888380051, 46.57074563205242, 45.94195157289505, 45.59802062809467, 52.82745569944382, 49.591967314481735, 49.19941797852516, 44.59922902286053, 43.92890319228172, 47.787884920835495, 57.70077779889107, 59.84042018651962, 56.12276807427406, 49.159185737371445, 50.2595154941082, 51.984273344278336, 50.509599074721336, 50.965506210923195, 51.61641888320446, 50.48086501657963, 51.618865951895714, 51.20980650186539, 48.11369463801384, 37.80769765377045, 44.23898175358772, 61.991841942071915, 57.84062169492245, 56.345759108662605, 53.83702352643013, 50.51507078111172, 51.53957940638065, 51.32775217294693, 48.09282995760441, 45.13889126479626, 46.44764743745327, 48.069966584444046, 50.17725370824337, 48.12135882675648, 44.284860491752625, 45.98599500954151, 44.28262621164322, 49.150157421827316, 53.215205892920494, 57.31227144598961, 54.36245173215866, 52.96041436493397, 50.56198686361313, 50.189340859651566, 49.49848473072052, 47.97717176377773, 51.00861109793186, 51.13785736262798, 47.47959986329079, 49.70108985900879, 49.06854920089245, 54.05057966709137, 53.96208241581917, 58.926238641142845, 55.03902442753315, 57.64406204223633, 53.59592266380787, 54.12014253437519, 50.55894322693348, 51.900871619582176, 34.22936126589775, 25.67958064377308, 15.13259869068861, 12.11470752954483, 16.024593226611614, 19.93062023073435, 19.84275184571743, 14.955575689673424, 15.708287749439478, 18.391712307929993, 5.259554274380207, 0.2608582586981356, 0.37792074435856193, 0.332899127388373, 6.650980236008763, 25.49031089991331, 51.93297989666462, 46.582992374897, 37.18086048960686, 27.18202192336321, 47.96384207904339, 56.51327311992645, 52.47511200606823, 19.77997351437807, 1.3661169447004795, 0.2512643375666812, 0.06921010222868063, 0.1410464127548039, 0.15357254451373592, 0.12045323965139687, 0.18584183795610443, 0.17222541704541072, 0.15314871881855652, 0.14044582232600078, 0.1714176041423343, 0.11061545621487312, 0.16257210925687104, 0.1311568942037411, 0.19118283729767427, 0.09985648939618841, 0.21663094754330814, 0.15503497619647533, 0.08810355677269399, 0.15577477868646383, 0.24200407118769363, 0.12594008585438132, 0.12914675753563643, 0.15075762290507555], [0.054405313640017994, 0.024666246536071412, 0.06074804907257203, 0.07608857180457562, 0.01749399223626824, 0.08001907495781779, 0.026582484824757557, 0.041011370049091056, 0.025119223791989498, 0.020747955422848463, 0.03333703243697528, 0.020385841162351426, 0.03116554915322922, 0.021101137936057057, 0.031276407462428324, 0.09987179990275763, 0.07863260951125994, 0.05178154700843152, 0.00620442786384956, 0.04468881568755023, 0.03312844070023857, 0.023901196182123385, 0.35643058188725263, 11.534178480505943, 49.198433831334114, 50.56425154209137, 53.689766228199005, 31.4208160713315, 15.176821667701006, 17.150873690843582, 24.72987860441208, 34.07402940094471, 11.075381599366665, 1.4989948645234108, 0.06223096774192527, 0.16085859417216852, 0.5146585742477328, 1.8184427730739117, 4.19224189594388, 6.782002430409193, 7.531375419348478, 14.331467729061842, 10.575415827333927, 5.040272315964103, 16.6540864482522, 29.758116491138935, 47.19550430774689, 40.83425045013428, 39.608778208494186, 46.72908313572407, 52.16014690697193, 50.87768532335758, 50.965635403990746, 53.7478157132864, 55.98132066428661, 56.198095232248306, 57.653603330254555, 53.72081436216831, 47.52592317759991, 49.91890177130699, 52.717383205890656, 51.73045456409454, 49.64367873966694, 46.46459452807903, 42.65356242656708, 40.5477724224329, 41.67125053703785, 44.173195883631706, 46.60043343901634, 49.6047992259264, 46.17010273039341, 41.85281999409199, 37.10709884762764, 45.8962020277977, 53.522206619381905, 50.64046785235405, 45.98962381482124, 47.59431570768356, 53.87257441878319, 51.55827820301056, 52.97328807413578, 51.56941540539265, 52.43434399366379, 51.09767071902752, 51.964240819215775, 50.525041446089745, 42.169920578598976, 28.490187227725983, 44.570244178175926, 56.26612298190594, 50.3720236569643, 49.85915757715702, 41.972201988101006, 43.3678063005209, 42.221062034368515, 42.436411678791046, 39.46202628314495, 39.78042259812355, 43.74277018010616, 45.08521154522896, 46.943821012973785, 48.831932097673416, 47.20607914030552, 43.56870152056217, 39.99249681830406, 38.726286962628365, 42.250046879053116, 48.45018558204174, 52.65930712223053, 53.40402536094189, 50.45058064162731, 49.50044542551041, 48.90994191169739, 49.231252670288086, 50.59399634599686, 49.51861225068569, 54.409291818737984, 53.257053047418594, 53.753032833337784, 53.596716821193695, 53.94990026950836, 53.13955955207348, 55.90776801109314, 56.06254890561104, 55.974462032318115, 55.25038808584213, 55.067009925842285, 50.303672924637794, 41.59862123429775, 29.415306486189365, 23.50625306367874, 8.408839534968138, 14.315612129867077, 14.40622491762042, 5.622247187420726, 12.581828813999891, 3.7689270358532667, 1.0645458893850446, 1.7995786853134632, 0.30799184984061867, 0.04469486048037652, 0.16744668362662196, 1.6556950123049319, 14.176637437194586, 38.51833552122116, 44.34890225529671, 32.14744158089161, 33.966757357120514, 37.66917988657951, 40.89657090604305, 40.78190065920353, 21.36417120695114, 2.298654830083251, 0.042701782076619565, 0.08333755860803649, 0.02372680632106494, 0.015773909144627396, 0.04036687416373752, 0.04167450126260519, 0.024834253927110694, 0.048647438816260546, 0.04203775286441669, 0.0393816323048668, 0.03659905349195469, 0.03128336880763527, 0.059495006935321726, 0.04268531753041316, 0.08523330063326284, 0.056736729748081416, 0.026845657812373247, 0.035705255359061994, 0.01500016731370124, 0.07815052522346377, 0.0391291944833938, 0.003807722241617739, 0.04233357292832807, 0.02370902817347087, 0.06864734648843296, 0.050658206309890375, 0.08663812681334093, 0.03682898197439499, 0.01682676622294821, 0.01626355962798698, 0.03998376640083734, 0.04583645430102479, 0.05717006977647543, 0.03910599865776021, 0.04154507812927477, 0.026030180379166268, 0.024593007692601532, 0.023243877840286586, 0.0663450188585557, 0.03792622504988685, 0.03306067519588396, 0.03173127719492186, 0.05330316867912188, 0.018587352024042048, 0.039866284423624165, 0.420207665883936, 15.072351023554802, 55.860103368759155, 57.06395477056503, 56.877342984080315, 35.94917558133602, 19.64202381670475, 20.41121654212475, 21.80863905698061, 34.64637748897076, 13.26993579044938, 1.3738473923876882, 0.09759048247360624, 0.17076423217076808, 0.5764938436914235, 3.4213599236682057, 8.157821204513311, 8.377762902528048, 7.7146723587065935, 16.12039938569069, 8.274460695683956, 6.470854226499796, 13.207235354930162, 27.173578776419163, 45.123703479766846, 43.95911157131195, 43.687350153923035, 50.40775313973427, 56.124629974365234, 54.5394766330719, 53.61110284924507, 55.80216787755489, 57.86968633532524, 58.213176503777504, 58.000144734978676, 53.39264117181301, 50.241785645484924, 51.89027018845081, 53.18324200809002, 53.14711354672909, 52.40137696266174, 47.31266722083092, 44.251186698675156, 41.15564860403538, 44.471833258867264, 47.051131054759026, 48.533180728554726, 51.90819002687931, 48.281087055802345, 42.5069472938776, 40.150746926665306, 47.974291518330574, 56.572443544864655, 53.99330914020538, 45.97664371132851, 48.25906723737717, 54.3205513805151, 51.81398548185825, 51.95447914302349, 50.68618319928646, 52.416298761963844, 50.12543588876724, 52.057419419288635, 49.78932872414589, 43.23116183280945, 30.74735540896654, 46.99001893401146, 57.75485649704933, 52.922397404909134, 50.974990501999855, 43.928390219807625, 45.02978011965752, 44.79776456952095, 44.13241647183895, 41.73590786755085, 42.23778113722801, 45.48677779734135, 47.921709939837456, 50.022020637989044, 49.60391387343407, 48.39082896709442, 44.38049755990505, 42.94271931052208, 41.22798152267933, 45.56466981768608, 51.17540314793587, 54.76268045604229, 55.21263711154461, 51.05528399348259, 50.83947077393532, 50.379657447338104, 49.10620518028736, 49.930840730667114, 50.848951265215874, 54.95686523616314, 54.64279308915138, 54.834527000784874, 55.79670377075672, 55.6532234698534, 54.92940790951252, 58.106235042214394, 57.486165314912796, 56.70995816588402, 56.2955068051815, 56.56868554651737, 52.12997652590275, 40.7809317111969, 29.165895469486713, 18.045784570276737, 7.542153066024184, 11.215891409665346, 13.130532670766115, 8.386698123067617, 10.934165976941586, 9.680155366659164, 9.465731922537088, 3.6533248890191317, 0.8243627962656319, 0.14672541583422571, 0.11472849058918655, 1.9776538736186922, 16.772539392113686, 41.34131424129009, 49.67234440147877, 34.62728351354599, 34.26137454807758, 43.114124312996864, 47.37922444939613, 47.86138437688351, 25.563941448926926, 3.079462582245469, 0.0631196227914188, 0.06781340998713858, 0.06073268661566544, 0.026612860929162707, 0.04654198441130575, 0.022628429614997003, 0.01280711072467966, 0.02184554916311754, 0.031877647270448506, 0.06133131406386383, 0.020172527511022054, 0.05996592190058436, 0.05469495903525967, 0.030237406281230506, 0.021342814616218675, 0.03092006896622479, 0.023503757547587156, 0.026386799036117736, 0.00999444895569468, 0.0642649941437412, 0.07894814843893982, 0.01250539058673894, 0.05579447308264207, 0.19420152297243476, 0.1710626349085942, 0.12391828262479976, 0.23787728481693193, 0.11844410488265567, 0.24071589577943087, 0.0749304577766452, 0.12557377660414204, 0.1212803038652055, 0.11646483413642272, 0.2017205031006597, 0.12695369630819187, 0.06778663329896517, 0.0968581905181054, 0.13964440673589706, 0.210686122009065, 0.17930866742972285, 0.10201305180089548, 0.17264676396735013, 0.10072102464619093, 0.16589749488048255, 0.11057430412620306, 0.5865305301267654, 20.540958680212498, 64.10135194659233, 64.41972926259041, 64.82908889651299, 43.61289694905281, 23.835748583078384, 27.438920438289642, 33.12845014035702, 43.32936376333237, 14.817671589553356, 2.0189288025721908, 0.20722573972307146, 0.4356367379659787, 0.6540688779205084, 5.2640356589108706, 10.695783868432045, 19.284033626317978, 16.943984292447567, 25.862597823143005, 17.9106505215168, 10.703549701720476, 20.9950153157115, 33.38619790971279, 49.47813302278519, 43.77755731344223, 45.469017550349236, 54.2055581510067, 60.0954283028841, 54.78070668876171, 52.358655855059624, 55.26970624923706, 58.16113069653511, 58.715220764279366, 60.80525681376457, 56.362899988889694, 50.86756266653538, 53.09625327587128, 56.99525445699692, 55.30377522110939, 53.93985740840435, 48.555553928017616, 46.57202236354351, 44.20813500881195, 45.21967113018036, 48.30926634371281, 51.49935856461525, 53.738027438521385, 50.20084664225578, 44.643390253186226, 41.79030954837799, 49.44251373410225, 58.61099995672703, 55.637226328253746, 47.40991920232773, 49.56495836377144, 54.56524685025215, 52.73699015378952, 54.451997727155685, 52.18263790011406, 53.12280245125294, 51.861570328474045, 52.98166282474995, 50.776257365942, 45.277439430356026, 35.33683083951473, 50.14260336756706, 59.14364397525787, 54.191749691963196, 52.859233394265175, 46.968010514974594, 47.04650290310383, 47.08755970001221, 48.498579785227776, 44.9614217877388, 44.69588443636894, 48.83564829826355, 50.17637975513935, 52.171341106295586, 54.608708918094635, 51.52609013020992, 47.14848943054676, 45.84631830453873, 42.32882805168629, 45.964533761143684, 53.4603725373745, 57.29218192398548, 57.393518686294556, 53.018604442477226, 51.348723247647285, 50.816048830747604, 49.62086856365204, 51.00720897316933, 52.465760707855225, 56.24084293842316, 56.207492128014565, 57.2139061242342, 57.77455843985081, 57.43485666811466, 58.04859213531017, 60.4579022526741, 60.12040436267853, 59.418908804655075, 58.826535791158676, 59.02295485138893, 54.04481537640095, 43.68651419878006, 31.191108897328377, 25.468123890459538, 13.441052008420229, 24.476812183856964, 25.214595794677734, 12.62591214850545, 22.023424431681633, 11.975276861339808, 8.96754065528512, 4.651807760819793, 1.0218059015460312, 0.17632499628234655, 0.2176128831342794, 2.498698658309877, 18.932930566370487, 49.82958376407623, 58.428594544529915, 43.43146428465843, 47.01760545372963, 49.855217188596725, 55.668095871806145, 55.50516441464424, 29.631837867200375, 4.191642478108406, 0.19551166595192626, 0.11079548639827408, 0.11356941176927648, 0.10930632997769862, 0.10579504378256388, 0.15446445759152994, 0.12031675869366154, 0.2140702708857134, 0.15988894854672253, 0.18876302026910707, 0.10719130557845347, 0.16178540303371847, 0.17510435631265864, 0.12418178957886994, 0.18233345355838537, 0.09891753899864852, 0.15574478107737377, 0.1341119481367059, 0.14150267030345276, 0.15115318761672825, 0.1353797293268144, 0.11154075851663947, 0.1293668191647157], [0.04517452536674682, 0.0549945529201068, 0.00939018767894595, 0.1165824274357874, 0.037336455134209245, 0.055008594354148954, 0.0442952510638861, 0.06978704041102901, 0.02015574755205307, 0.05084465978143271, 0.007892042922321707, 0.035197685720049776, 0.010878212324314518, 0.06120526399172377, 0.0512591047299793, 0.06147537234937772, 0.04989001667127013, 0.02822704511345364, 0.05405142794188578, 0.05671088074450381, 0.04639152510208078, 0.028787572555302177, 0.2466374624054879, 13.262212704867125, 44.93383526802063, 46.958628818392754, 43.11894245445728, 33.352672308683395, 26.35469801723957, 28.10807403177023, 52.97384284436703, 34.24441985785961, 7.243318101391196, 0.4229013650910929, 0.005845984915140434, 0.23234775027958676, 0.8288703637663275, 4.974060393869877, 5.283343847841024, 9.383634477853775, 5.5354085471481085, 10.669891107827425, 5.770124327391386, 5.597245479002595, 11.25211676582694, 19.938858188688755, 29.168650321662426, 27.235770039260387, 42.402194514870644, 39.86555702984333, 47.44723320007324, 51.41901567578316, 52.26033993065357, 55.76095148921013, 55.057860016822815, 54.827478379011154, 53.714419305324554, 54.54606167972088, 53.48788306117058, 48.9649173617363, 50.58779127895832, 49.990250542759895, 52.096196338534355, 46.961193680763245, 42.56918415427208, 40.222753062844276, 43.60281988978386, 47.6295930147171, 50.83655633032322, 48.68958033621311, 45.03590539097786, 38.58951710164547, 39.32206079363823, 50.90967580676079, 55.42353719472885, 55.465661734342575, 52.428845688700676, 50.18183246254921, 51.770363822579384, 52.19391569495201, 53.60466219484806, 54.37407910823822, 56.38599514961243, 53.224921971559525, 54.984045177698135, 53.13412584364414, 48.01994986832142, 21.257754117250443, 46.83631718158722, 56.92488223314285, 49.731552824378014, 47.48949073255062, 40.86904518306255, 41.69035591185093, 41.12178862094879, 38.42323802411556, 38.15808445215225, 38.473155945539474, 42.8850232064724, 46.418461203575134, 47.87717632949352, 53.31568770110607, 48.28547582030296, 45.35438910126686, 39.87328201532364, 38.60141806304455, 37.61528737843037, 41.72159783542156, 47.1323174983263, 52.49745100736618, 52.84688785672188, 53.945777490735054, 50.71501985192299, 50.735527351498604, 54.387598782777786, 55.91276854276657, 52.679009065032005, 51.99381843209267, 52.045089080929756, 52.53813162446022, 53.90239901840687, 53.11888486146927, 54.16828595101833, 54.810603484511375, 57.634771540760994, 54.818818643689156, 55.500338673591614, 56.43139511346817, 48.80972608923912, 32.43977889418602, 22.75124877691269, 7.44677628390491, 8.394608348608017, 11.618022881448269, 5.7294209115207195, 14.991327971220016, 5.772600369527936, 4.426334034651518, 1.4845673949457705, 1.268242271617055, 0.28110431449022144, 0.07698498971876688, 0.601955505553633, 9.102717451751232, 28.277904018759727, 26.398479267954826, 27.242560274899006, 25.203266702592373, 29.034517519176006, 44.46416147053242, 46.19146138429642, 30.127099491655827, 4.69291253015399, 0.10594556617434137, 0.11893132483237423, 0.07756195758702233, 0.09126860881224275, 0.041885397367877886, 0.03981056397606153, 0.06530715501867235, 0.02578550913312938, 0.041104379706666805, 0.08993679512059316, 0.10534972549066879, 0.05902979537495412, 0.010105658857355593, 0.033925952593563125, 0.07252128314576112, 0.028512745993793942, 0.018547368817962706, 0.017740413095452823, 0.01296479855227517, 0.006864576107545872, 0.06837371664005332, 0.04784019365615677, 0.03694398146762978, 0.023559596738778055, 0.048057616950245574, 0.04870617238339037, 0.05036329537688289, 0.04158067524258513, 0.022448445815825835, 0.0431653052510228, 0.04643302600015886, 0.04287439449399244, 0.06184132165799383, 0.1358001262997277, 0.09803899942198768, 0.017793433980841655, 0.07109063764801249, 0.08117373799905181, 0.03594365174649283, 0.05860249642864801, 0.011701766179612605, 0.04177493610768579, 0.03632365733210463, 0.04111362686671782, 0.06776851005270146, 0.3114973398623988, 17.293818220496178, 53.21096532046795, 53.46733756363392, 49.92949180305004, 33.13190795481205, 23.91113843768835, 22.03144960105419, 46.800982877612114, 35.1201930642128, 9.364494904875755, 0.4441754735307768, 0.09405877237441018, 0.18657073087524623, 1.50276948697865, 5.510619152337313, 11.593919824808836, 7.68042242154479, 7.92273779399693, 8.943361602723598, 7.832744373008609, 10.150976702570915, 14.082556385546923, 25.239900536835194, 29.539884701371193, 31.439685858786106, 45.06260275840759, 48.2855100184679, 52.56853759288788, 54.919019266963005, 52.29442410171032, 56.875560879707336, 56.764143258333206, 57.10869736969471, 56.29035808146, 54.86065819859505, 53.111995831131935, 52.192350178956985, 52.83184066414833, 52.92411491274834, 52.423708364367485, 48.14610689878464, 44.81627717614174, 41.749872118234634, 45.214659199118614, 49.872179478406906, 52.9251104593277, 51.66566044092178, 46.9488937407732, 41.912355199456215, 40.66189929842949, 51.86528652906418, 57.43636138737202, 55.07551766932011, 51.31550543010235, 50.59554286301136, 52.979664131999016, 54.041589349508286, 56.13894760608673, 55.96546411514282, 57.22111813724041, 55.436787083745, 55.28092324733734, 52.825267016887665, 49.40511234104633, 23.722847141325474, 49.37769681215286, 59.09832380712032, 52.34279930591583, 48.775394931435585, 43.15905690193176, 43.77828307449818, 42.05888293683529, 41.38356417417526, 38.88048268854618, 40.346979796886444, 43.76832760870457, 48.13256822526455, 49.95757229626179, 53.856733068823814, 49.81177031993866, 48.05396944284439, 42.59477578103542, 40.692784041166306, 38.897027000784874, 42.83178426325321, 48.22366073727608, 54.36851240694523, 54.36174876987934, 55.67118510603905, 50.099103301763535, 50.94203107059002, 54.51994188129902, 55.87119497358799, 54.82732258737087, 53.15607346594334, 54.52906899154186, 55.2507034689188, 56.11263021826744, 56.36244401335716, 56.389905139803886, 57.100546807050705, 59.13409888744354, 56.76470182836056, 58.09280276298523, 56.97181351482868, 48.90776462852955, 31.88343934714794, 18.160038739442825, 8.755190949887037, 10.832516681402922, 15.237322021275759, 6.764842551201582, 12.197443339973688, 10.503384992480278, 8.10406643897295, 3.901311932131648, 0.8386741939466447, 0.03155474623781629, 0.14631530502811074, 0.6924557837191969, 10.054155047982931, 31.661175973713398, 31.83843646198511, 32.28696629405022, 34.25999902188778, 33.19955192506313, 50.51075421273708, 51.739760264754295, 35.1538972556591, 6.16819191724062, 0.09662428041337989, 0.018863351178879384, 0.14323901385068893, 0.037502829800359905, 0.030816231374046765, 0.028133167143096216, 0.015619672303728294, 0.028523167602543253, 0.04915439618343953, 0.018563833364169113, 0.0332004735537339, 0.09874288196442649, 0.007305588087547221, 0.04342719061241951, 0.03480595049040858, 0.0072535510116722435, 0.05653147767588962, 0.04131850044359453, 0.056873808134696446, 0.018911987826868426, 0.07577196418424137, 0.03277838448411785, 0.03177547208906617, 0.06766185601009056, 0.1030240795807913, 0.16732661897549406, 0.14142256288323551, 0.1506159914424643, 0.10766439503640868, 0.1069297875801567, 0.11678752736770548, 0.12956893566297367, 0.10883736686082557, 0.15429407532792538, 0.09103323667659424, 0.07239207523525693, 0.1411507438751869, 0.15756440843688324, 0.17515877058031037, 0.1815829344559461, 0.08879235887434334, 0.17693824775051326, 0.16889580118004233, 0.17880841536680236, 0.14709671231685206, 0.5610279610846192, 22.831167988479137, 61.83855816721916, 59.834135323762894, 55.008261278271675, 44.57430236041546, 34.42350424826145, 37.51186452805996, 64.47322279214859, 42.5520508736372, 10.123529825359583, 0.6928186642471701, 0.18337988178245723, 0.5466446047648787, 1.8718597129918635, 12.178491856902838, 15.878448318690062, 19.979666098952293, 14.695613589137793, 20.740491673350334, 11.65264567360282, 11.966668423265219, 15.750240348279476, 28.54588083922863, 36.38935536146164, 36.791244596242905, 53.93024392426014, 50.994962230324745, 53.25329124927521, 55.21792642772198, 53.83129343390465, 56.00431703031063, 59.04754713177681, 58.77205051481724, 58.50338213145733, 56.921420618891716, 57.06593066453934, 52.384863048791885, 55.59485860168934, 53.90784412622452, 55.779118314385414, 50.81692658364773, 46.897702887654305, 43.33152584731579, 47.842389196157455, 52.0947790145874, 55.98521165549755, 52.24307745695114, 50.53110592067242, 42.944395020604134, 44.099191054701805, 54.501467272639275, 59.5363263040781, 55.791699439287186, 52.54515364766121, 50.325772538781166, 53.15440155565739, 55.67606784403324, 59.13776569068432, 58.46518658101559, 60.101287588477135, 56.886382699012756, 57.025557830929756, 54.6558453887701, 50.52151903510094, 27.219998985528946, 52.179769054055214, 61.2800033390522, 56.02562628686428, 51.636968180537224, 45.2120753377676, 45.106277614831924, 44.977145344018936, 43.012217581272125, 41.2503395229578, 42.92529344558716, 45.922078639268875, 50.39668433368206, 52.752386927604675, 57.42716588079929, 52.88439564406872, 51.039879620075226, 43.898634016513824, 43.533511608839035, 40.7906249910593, 45.10496288537979, 52.13358633220196, 57.93089345097542, 56.971790716052055, 57.503032609820366, 51.63648180663586, 53.28450657427311, 57.329203337430954, 59.10297475755215, 57.321786135435104, 56.018718257546425, 58.04791957139969, 58.03445689380169, 59.378665164113045, 59.07310076057911, 59.34463419020176, 58.820908293128014, 63.674961626529694, 59.353875294327736, 61.11890338361263, 62.49928951263428, 52.96186588704586, 35.29587283730507, 25.272854268550873, 12.861674297600985, 14.900841526687145, 20.502214059233665, 14.143356923013926, 28.660340197384357, 15.097995847463608, 10.805999804288149, 6.625872608274221, 2.607171912677586, 0.7251630036626011, 0.38548506970983, 0.8751684450544417, 12.576932776719332, 37.845718413591385, 39.12359744310379, 40.848628878593445, 36.83765530586243, 39.09502297639847, 57.77878761291504, 61.123288348317146, 41.64955370128155, 8.374783862382174, 0.17716850648866966, 0.23761472781188786, 0.23204816010547802, 0.10846381424926221, 0.12628319556824863, 0.24218723323429003, 0.143739978375379, 0.11958388786297292, 0.15549617644865066, 0.16031029546866193, 0.211437190300785, 0.3043435112340376, 0.16114356403704733, 0.10154249306651764, 0.17397117102518678, 0.08687805573572405, 0.29264387965667993, 0.12909350101836026, 0.19269500771770254, 0.12524451536592096, 0.14580910094082355, 0.18356253916863352, 0.11007423017872497], [0.026151235797442496, 0.015514592541876482, 0.01675231396802701, 0.06108526242314838, 0.008217255744966678, 0.03022024226083886, 0.0652280866052024, 0.003143708568131842, 0.015361138666776242, 0.009758753985806834, 0.11212842815439217, 0.06827986464486457, 0.07374115870334208, 0.02244965737190796, 0.04214239939756226, 0.025315968996437732, 0.035880457871826366, 0.02526043408579426, 0.0321232462010812, 0.15022332110675052, 0.04778361973876599, 0.07211918753455393, 0.824874818790704, 14.606881700456142, 43.915725499391556, 49.49702940881252, 44.290966764092445, 26.62322200834751, 17.69687969237566, 31.633559055626392, 33.907674327492714, 22.144852615892887, 4.655951438471675, 0.21089594200020656, 0.11295951480860822, 0.07241350846015848, 0.9571232192683965, 2.4259244883432984, 8.960836865007877, 2.326046610251069, 4.8373043071478605, 11.71266345307231, 7.697154823690653, 9.184414967894554, 12.836304008960724, 18.011791594326496, 24.358929209411144, 38.804707154631615, 38.437715247273445, 53.021879866719246, 53.6167873442173, 52.94398404657841, 54.030303955078125, 55.810272842645645, 52.32089728116989, 50.488502606749535, 48.98523107171059, 52.645137682557106, 54.29762341082096, 53.69334563612938, 50.89364066720009, 52.25422985851765, 47.63630345463753, 43.02470751106739, 39.60756607353687, 39.53702285885811, 44.7342623770237, 50.498245283961296, 51.67455196380615, 49.98088404536247, 43.006833270192146, 37.921307757496834, 38.76925505697727, 52.25232616066933, 53.24517868459225, 50.62898866832256, 43.08036312460899, 55.61304062604904, 56.91644288599491, 50.77767848968506, 51.486937031149864, 51.445108875632286, 48.3900386095047, 46.90416634082794, 48.59630674123764, 53.27598363161087, 50.35519815981388, 23.92938505858183, 45.67147448658943, 56.87708079814911, 51.699653416872025, 48.302232921123505, 46.65732778608799, 45.8471504598856, 43.65631341934204, 39.548426046967506, 37.51468777656555, 37.933220118284225, 39.794994816184044, 47.42431282997131, 49.950170293450356, 52.4261212348938, 52.590238228440285, 45.85155062377453, 42.96955347061157, 39.10051368176937, 39.08663682639599, 37.45309688150883, 41.872909516096115, 45.86981624364853, 48.5650610178709, 51.25719375908375, 53.011939600110054, 51.03218883275986, 54.399663135409355, 53.727813586592674, 52.63257175683975, 51.22304119169712, 50.46808250248432, 50.367266312241554, 48.89478072524071, 47.27361671626568, 50.5380367487669, 52.26385474205017, 51.75113305449486, 51.82326838374138, 52.116494849324226, 53.61554481089115, 51.36986531317234, 39.847887977957726, 21.646908335387707, 10.832016058266163, 9.926132317632437, 9.52217884361744, 5.815883846953511, 6.12210039049387, 12.533371914178133, 11.183181814849377, 3.21385994553566, 1.012044819071889, 0.12094497928046621, 0.040493009582860395, 0.1714344954234548, 5.141253797337413, 24.208694770932198, 43.408965691924095, 28.109004981815815, 19.543464705348015, 35.54257459938526, 46.7181321233511, 52.308156564831734, 35.30306205153465, 9.132607597857714, 0.16671345656504855, 0.06018561987730209, 0.048684802241041325, 0.06613522113184445, 0.05060493123892229, 0.031997556070564315, 0.01833786052884534, 0.04741125456348527, 0.03196417797880713, 0.030336154595715925, 0.10406448156572878, 0.047442402501474135, 0.05108441429911181, 0.022212585718079936, 0.03947922472434584, 0.028152754275652114, 0.026825536333490163, 0.08350712450919673, 0.05889880259928759, 0.027483027224661782, 0.05161150613275822, 0.07207534887129441, 0.009879366898530861, 0.0005635843945128727, 0.07554782074294053, 0.0818572189018596, 0.047007036409922875, 0.03346311590576079, 0.04871859593549743, 0.09807079302845523, 0.03573947949917056, 0.026539907812548336, 0.0666180846747011, 0.07684887241339311, 0.020926933611917775, 0.06211596082721371, 0.01579555759235518, 0.06623804569244385, 0.05012711430026684, 0.05651070867315866, 0.05992960119328927, 0.049145230659632944, 0.04521034883509856, 0.04371046095911879, 0.13422459131106734, 0.964021630352363, 19.336854591965675, 50.958225801587105, 56.31999269127846, 48.32629323005676, 34.082050770521164, 21.501932814717293, 31.639256849884987, 39.389852955937386, 24.929573088884354, 5.553392507135868, 0.33649818738922477, 0.11183387716300786, 0.3081392403692007, 1.386236627586186, 5.4478417709469795, 10.04569100216031, 7.4130260199308395, 12.277131713926792, 6.16426482796669, 6.434094049036503, 9.58848338574171, 14.826107136905193, 22.22159329801798, 27.334956116974354, 42.537984028458595, 44.86873336136341, 51.795499473810196, 52.538504004478455, 52.32882745563984, 53.76458801329136, 56.15570850670338, 55.2774578332901, 52.98506364226341, 52.05384001135826, 54.77070942521095, 57.13628388941288, 55.37431463599205, 52.66713470220566, 52.95064128935337, 49.480884075164795, 44.56391751766205, 41.36551134288311, 40.46945862472057, 46.13172098994255, 52.60502703487873, 54.228957295417786, 52.38578639924526, 45.986196398735046, 39.111742079257965, 41.31750471889973, 53.20707052946091, 55.613154619932175, 53.39299455285072, 46.62906490266323, 55.75253874063492, 59.084750935435295, 51.605840250849724, 54.14916157722473, 53.166678696870804, 51.798809096217155, 50.06675943732262, 51.660944893956184, 56.01632438600063, 51.33671589195728, 26.4841665700078, 48.18976275622845, 58.48481632769108, 52.73278757929802, 50.157300978899, 47.524034678936005, 45.98738953471184, 43.5824453830719, 40.85017539560795, 40.74523642659187, 39.08504091203213, 42.258543223142624, 48.68025563657284, 52.394909709692, 53.39484125375748, 53.78427475690842, 49.44477841258049, 44.43512722849846, 39.743819162249565, 40.894659608602524, 39.17588643729687, 42.813264057040215, 47.70922914147377, 51.34159862995148, 51.95753037929535, 53.84626083076, 52.618288323283195, 54.627685099840164, 55.28849624097347, 53.743936121463776, 54.07824218273163, 52.885721772909164, 53.053307980298996, 51.55364625155926, 50.52116945385933, 53.66098277270794, 54.93911258876324, 55.465832725167274, 53.746774569153786, 55.712146908044815, 54.407646507024765, 53.89182038605213, 37.42712527513504, 21.682603619992733, 10.946036539971828, 9.828548803925514, 13.014690186828375, 11.67265634983778, 9.9944232031703, 9.37560360878706, 7.833891436457634, 6.079664267599583, 1.7106293770484626, 0.158170698559843, 0.09648923180066049, 0.36885074980091304, 5.820749010890722, 26.514948718249798, 43.73094901442528, 40.21794252097607, 25.345111191272736, 39.569305926561356, 51.7852970212698, 57.929141744971275, 41.60677559673786, 11.808481961488724, 0.3419604536611587, 0.04494497909035999, 0.059933816592092626, 0.05889326988835819, 0.010312013946531806, 0.035175814628019, 0.03374949585122522, 0.06387396395439282, 0.028255404431547504, 0.03771315445192158, 0.07939540373627096, 0.07770881376927719, 0.02596837617602432, 0.04036177560919896, 0.03662663912109565, 0.01682130401604809, 0.03426837211009115, 0.09944118355633691, 0.05612981993181165, 0.026339004725741688, 0.0438546491204761, 0.015102017805475043, 0.03792928269831464, 0.18605789198772982, 0.1755831009359099, 0.15907922090264037, 0.22519101243233308, 0.15399537573102862, 0.12706402398180217, 0.15815778519026935, 0.15463504765648395, 0.14173926698276773, 0.13252047181595117, 0.2167266994365491, 0.19578960025683045, 0.1524553747731261, 0.09153992315987125, 0.22535559110110626, 0.11240490042837337, 0.1108529583143536, 0.18213108472991735, 0.10361554901464842, 0.2745978464372456, 0.11319281635223888, 0.17355427698930725, 1.6261131246574223, 27.97984041273594, 60.35955972969532, 61.313361749053, 56.435327902436256, 38.20046737790108, 27.329102531075478, 41.709449887275696, 44.98118452727795, 28.60869336873293, 6.209325660020113, 0.4901720053749159, 0.3285622538533062, 0.24975466076284647, 2.7544807456433773, 7.183094657957554, 18.800448775291443, 8.672927264124155, 13.567204289138317, 23.81830181926489, 14.43360909819603, 16.602357923984528, 18.514020144939423, 26.158195361495018, 33.18588025867939, 50.30281417071819, 47.34970383346081, 54.16411757469177, 53.55988919734955, 54.46240156888962, 55.066812336444855, 59.07828368246555, 58.42757619917393, 55.51036633551121, 53.306704983115196, 57.40107648074627, 60.909850001335144, 59.13867384195328, 54.11520279943943, 55.45351758599281, 51.189944967627525, 46.89742170274258, 43.99726912379265, 43.912096694111824, 48.603864535689354, 55.0827980786562, 57.75096170604229, 55.85414908826351, 48.25839467346668, 42.71039977669716, 42.97649949789047, 57.24902383983135, 58.36338244378567, 55.588740929961205, 50.24827569723129, 58.24125699698925, 61.71569176018238, 53.76708447933197, 57.13560752570629, 56.011171862483025, 53.21389116346836, 52.3443990200758, 53.47454197704792, 57.37486928701401, 50.173408314585686, 29.38153199851513, 50.710900872945786, 62.33035817742348, 55.02588093280792, 53.32781285047531, 50.81572964787483, 48.14353823661804, 47.17504620552063, 43.51966135203838, 42.86352775990963, 42.43720583617687, 44.43917401134968, 51.894567757844925, 53.23340691626072, 57.08323113620281, 56.532002314925194, 51.77381783723831, 48.62749546766281, 42.98468425869942, 43.43522988259792, 41.58990070223808, 46.06334365904331, 49.48900043964386, 53.49917985498905, 55.01298062503338, 56.14214323461056, 53.01436007022858, 57.460957467556, 58.127441704273224, 56.94252848625183, 56.68179027736187, 55.503564700484276, 55.43751284480095, 53.045134618878365, 50.78017495572567, 56.32885381579399, 58.08791242539883, 57.34078511595726, 56.56818017363548, 57.013200893998146, 57.44881331920624, 56.56676284968853, 43.51844921708107, 25.479080602526665, 17.0017221942544, 14.95078319683671, 18.760273531079292, 14.18112974613905, 14.708520546555519, 26.198005825281143, 22.384975031018257, 9.131271969527006, 1.832962625194341, 0.20381589769385755, 0.35030439030379057, 0.585849832277745, 7.324523543938994, 32.91837081313133, 55.499001145362854, 42.04155586659908, 31.408556029200554, 48.07827293872833, 56.26111105084419, 65.3120581805706, 50.48064082860947, 14.838030897080898, 0.5721559014637023, 0.17966846062336117, 0.22294594149570912, 0.18765647808322683, 0.19272850826382637, 0.16686650225892663, 0.09886552186799236, 0.18805700034135953, 0.11882613282068633, 0.1088523434009403, 0.2752159960800782, 0.2996133884880692, 0.09014775059767999, 0.1609193315380253, 0.17288154980633408, 0.11241021420573816, 0.17881886480608955, 0.33925529569387436, 0.18426462571369484, 0.19838022999465466, 0.11172019498189911, 0.15373600996099412, 0.12302136747166514], [0.05637786794977728, 0.08035345701500773, 0.01615002031030599, 0.019725457750610076, 0.0336509905901039, 0.013887718559999485, 0.0678996104397811, 0.08858442393830046, 0.06401912061846815, 0.10412117422674783, 0.05714594626624603, 0.05018980722525157, 0.01718920702842297, 0.007972848889039597, 0.026273406292602886, 0.025777690607355908, 0.041732047393452376, 0.0025507411555736326, 0.0578386817505816, 0.06757520284736529, 0.04739238916954491, 0.06906220703967847, 0.8119463094044477, 20.39068814367056, 44.795119911432266, 46.66612431406975, 32.90680043399334, 21.51787295937538, 17.72431991994381, 31.414046734571457, 40.43254740536213, 20.170862339437008, 2.9105694824829698, 0.04341427353210747, 0.1858128496678546, 0.47638673102483153, 1.8996953568421304, 5.364280454814434, 8.758332431316376, 7.501830104738474, 11.649487093091011, 2.1626183297485113, 6.3580249808728695, 10.736984107643366, 13.882423974573612, 26.848984993994236, 35.461122170090675, 48.38580943644047, 49.55460771918297, 52.99321800470352, 48.90147216618061, 53.01337592303753, 53.89886900782585, 53.869648575782776, 49.708263874053955, 48.81555877625942, 42.861095890402794, 45.888644233345985, 47.24102586507797, 50.290913209319115, 48.6208838224411, 47.3103379458189, 46.358299031853676, 41.8575469404459, 38.56311611831188, 42.748564928770065, 45.17718181014061, 51.77083499729633, 51.49903558194637, 50.003603026270866, 43.39676074683666, 38.36059458553791, 37.3242761939764, 50.42296752333641, 53.50595109164715, 45.99768318235874, 52.821091040968895, 53.45671333372593, 51.5039487183094, 49.99280780553818, 48.68820860981941, 45.126412734389305, 43.87259781360626, 45.48796333372593, 49.56616669893265, 49.114937111735344, 52.309847474098206, 22.561048083007336, 44.749111980199814, 54.53901685774326, 53.63263249397278, 51.47188983857632, 51.21851183474064, 50.4209004342556, 51.466657519340515, 48.929826244711876, 42.50811383128166, 35.515231266617775, 37.613999247550964, 42.14450754225254, 50.54136537015438, 51.57509610056877, 52.316193133592606, 49.405841901898384, 46.64169542491436, 45.707390159368515, 41.87490060925484, 37.68287435173988, 40.04786744713783, 40.57938292622566, 47.26587273180485, 53.9181187748909, 52.79839485883713, 51.30773484706879, 54.61507357656956, 52.2603627294302, 49.34969611465931, 46.16169758141041, 45.25402128696442, 42.55004458129406, 43.53674903512001, 44.17182795703411, 46.65024496614933, 46.29558339715004, 49.992222636938095, 48.17564271390438, 49.68316242098808, 49.711668491363525, 52.25498981773853, 41.729619204998016, 17.83843159675598, 10.307373460382223, 11.482807137072086, 18.0671489238739, 7.907581832259893, 8.193256203085184, 6.400393657386303, 6.137670055031776, 4.749764604493976, 1.2660045479424298, 0.1531100826105103, 0.1982397711253725, 0.12071596735040657, 2.0118737686425447, 16.896458342671394, 34.154949858784676, 23.853197246789932, 18.965563215315342, 29.052226468920708, 39.84168291091919, 51.490881219506264, 41.78856924176216, 16.024680621922016, 0.9238203812856227, 0.10068271498312242, 0.040537742534070276, 0.05568765205680393, 0.05519288817595225, 0.0679800369834993, 0.06085401291784365, 0.03861644094286021, 0.04928379705233965, 0.0483586060727248, 0.03070562168431934, 0.021879341002204455, 0.04920417573885061, 0.029635069950018078, 0.035540498574846424, 0.002953009779957938, 0.020866342820227146, 0.013098950093990425, 0.04499232811213005, 0.04624576358764898, 0.015704052639193833, 0.01986168081202777, 0.034541304339654744, 0.0763038985314779, 0.05343537486623973, 0.025747392428456806, 0.026424713505548425, 0.048730923008406535, 0.016340405309165362, 0.037878052244195715, 0.02998551950440742, 0.04677517463278491, 0.053557818100671284, 0.059856618390767835, 0.0917167027364485, 0.021901842919760384, 0.037298045281204395, 0.05343069933587685, 0.03578007126634475, 0.015582804262521677, 0.007459122207364999, 0.039856369330664165, 0.025353575474582613, 0.045978441994520836, 0.07403516050544567, 1.0339844855479896, 25.951309762895107, 52.419688180089, 51.59298554062843, 38.596132546663284, 25.57109836488962, 16.320154666900635, 34.07099336385727, 41.44203923642635, 21.65867630392313, 3.3336475677788258, 0.10317175212549046, 0.1108802248199936, 0.49221760185901076, 3.118143556639552, 6.921596489846706, 11.752894744277, 11.456011924892664, 15.960099287331104, 6.954185916110873, 9.23580626025796, 11.085699945688248, 16.61933921277523, 26.891191229224205, 41.55785322189331, 48.83386239409447, 49.2732822149992, 51.97662815451622, 51.456743851304054, 52.34142377972603, 54.58868779242039, 55.20935408771038, 51.46989494562149, 50.131656154990196, 46.19665950536728, 48.665436431765556, 50.10835200548172, 51.71844340860844, 52.15613432228565, 50.903421342372894, 48.041555508971214, 43.6844053119421, 39.76814545691013, 43.76410983502865, 48.18419985473156, 53.76705788075924, 54.915170073509216, 52.14655503630638, 45.97216375172138, 40.91514050960541, 40.51322467625141, 52.428492307662964, 55.4837791621685, 50.396319553256035, 53.683078587055206, 55.608575865626335, 54.25281621515751, 51.39691226184368, 51.64991408586502, 47.94793613255024, 46.87424674630165, 48.370739445090294, 50.84308058023453, 52.75063902139664, 53.86871002614498, 24.82971254736185, 46.4421871304512, 56.62649564445019, 55.36948889493942, 53.08173805475235, 52.71985687315464, 52.5688149780035, 52.66450524330139, 48.82721275091171, 44.86871436238289, 37.99277052283287, 39.794345051050186, 44.32618327438831, 53.283963203430176, 52.8951870650053, 53.36297616362572, 52.14544549584389, 50.12708880007267, 47.13955990970135, 43.84463511407375, 40.02830229699612, 43.315745294094086, 42.80506789684296, 49.350961446762085, 55.291182696819305, 54.28772874176502, 53.27221803367138, 57.01095901429653, 54.27783787250519, 51.32859192788601, 49.42562744021416, 47.26888597011566, 45.378016233444214, 46.518791019916534, 47.64481499791145, 48.89077574014664, 49.83308717608452, 51.47712215781212, 52.58635863661766, 51.415086686611176, 53.247055783867836, 54.05152961611748, 44.401996806263924, 25.562026351690292, 18.963853307068348, 9.597819484770298, 11.792752705514431, 13.16678462550044, 7.274787062779069, 12.577183563262224, 7.705020401626825, 5.3920013923197985, 2.079009753651917, 0.45665623038075864, 0.15565314068226144, 0.17001711210468784, 2.4102204060181975, 20.45773934572935, 38.56918819248676, 30.70779573172331, 25.35599760711193, 35.65727524459362, 45.809505879879, 57.94775694608688, 47.74394027888775, 19.84959337860346, 1.0776433115825057, 0.04791828614543192, 0.0199681511730887, 0.028600690493476577, 0.02505853281036252, 0.09379850860568695, 0.019036442281503696, 0.03789622373005841, 0.022955985768930987, 0.030117345340840984, 0.012589241214300273, 0.025178731048072223, 0.06906274880748242, 0.05701766232959926, 0.009001764283311786, 0.0633530727645848, 0.036902061256114393, 0.053786150965606794, 0.04096878561540507, 0.04100289472262375, 0.036905263623339124, 0.07624621881404892, 0.017201513692270964, 0.25416839111130685, 0.1310279089375399, 0.11070623571868055, 0.13993626373121515, 0.12985307432245463, 0.09349423547973856, 0.1878445383044891, 0.17456957953982055, 0.1258147816406563, 0.15347238426329568, 0.2009390215971507, 0.14261675270972773, 0.12350997523753904, 0.07843850820790976, 0.12080380052793771, 0.1303720730356872, 0.13417979527730495, 0.14192061818903312, 0.2479982198565267, 0.23623296758159995, 0.19434177404036745, 0.17830921715358272, 1.9343819143250585, 31.617535315454006, 60.900221318006516, 58.43131519854069, 46.5940497815609, 32.945436760783195, 26.576180532574654, 42.33693301677704, 51.11236833035946, 25.947302877902985, 4.503319328650832, 0.16413385514169931, 0.28656432463321835, 0.8723291067872196, 5.154880816116929, 13.85615123435855, 18.368752039968967, 18.13711266964674, 19.59962759166956, 11.113992277532816, 13.510873261839151, 14.131028484553099, 19.657050110399723, 32.16665714979172, 43.62216845154762, 53.63686926662922, 51.32919229567051, 54.53934744000435, 49.883385077118874, 53.647626489400864, 55.667058527469635, 57.78088890016079, 54.286349415779114, 53.23162101209164, 47.59115427732468, 50.39910480380058, 51.85370095074177, 52.9830801486969, 52.23959684371948, 51.974025294184685, 51.18579179048538, 46.248731911182404, 42.8484083712101, 46.3884200155735, 50.08386991918087, 56.585993617773056, 56.42282657325268, 54.12129387259483, 48.139388859272, 42.39541567862034, 42.14039236307144, 54.933553487062454, 58.29561688005924, 51.66564904153347, 55.71640267968178, 58.34035187959671, 57.357527017593384, 54.20289449393749, 54.10082817077637, 50.599962025880814, 48.68384264409542, 51.776967868208885, 53.81319500505924, 55.09130962193012, 54.80034403502941, 28.43250062316656, 48.87073181569576, 55.88043227791786, 58.343030735850334, 54.79970946907997, 55.38031071424484, 54.785118252038956, 55.858860835433006, 51.762277856469154, 47.76001341640949, 39.72977511584759, 42.33251005411148, 45.57794250547886, 56.54253534972668, 55.280866250395775, 55.21955654025078, 54.86771821975708, 52.31488600373268, 50.216695591807365, 46.72597490251064, 41.77648589015007, 45.05236230790615, 45.36483474075794, 52.662844732403755, 57.57357582449913, 55.97550317645073, 54.97113727033138, 60.10711267590523, 55.62769643962383, 53.89199137687683, 50.80596797168255, 49.12720285356045, 46.26393489539623, 48.64589408040047, 49.13082405924797, 51.363557651638985, 50.044701620936394, 55.25601178407669, 53.07932898402214, 55.579712614417076, 54.05246436595917, 57.06099092960358, 46.09828658401966, 23.727686181664467, 16.448257192969322, 21.12937420606613, 31.02330420166254, 15.604368075728416, 17.88747176527977, 17.19249665737152, 11.10549308359623, 8.819692488759756, 4.336965205147862, 0.6394576525781304, 0.5390437657479197, 0.4146213422063738, 3.016270073130727, 23.830596059560776, 46.08766995370388, 33.400333151221275, 31.46560236811638, 40.97626022994518, 53.274288922548294, 63.55493746697903, 56.870301961898804, 24.650470465421677, 2.07277808804065, 0.1795496279373765, 0.13683693628991023, 0.2500589709961787, 0.13186132593546063, 0.21802994044264778, 0.1556223415536806, 0.11464914015959948, 0.16196108423173428, 0.1874917361419648, 0.15288963506463915, 0.1028109273465816, 0.1431648584548384, 0.1841458078706637, 0.11720870359567925, 0.15774532919749618, 0.15760803187731653, 0.13316278578713536, 0.1741373527329415, 0.09772562756552361, 0.10476378505700268, 0.18155733036110178, 0.0994451911537908], [0.048911643389146775, 0.06940676394151524, 0.028887263397336937, 0.07243736108648591, 0.059869505785172805, 0.0639182330633048, 0.017921274484251626, 0.054460180617752485, 0.05876167597307358, 0.06990213267272338, 0.012492086661950452, 0.04491796120419167, 0.048521214339416474, 0.03468901399173774, 0.045174484548624605, 0.003533561989570444, 0.05539834433875512, 0.08070979922194965, 0.05292286994517781, 0.054697612213203683, 0.04466159000003245, 0.16928731376538053, 1.7936895950697362, 17.499394789338112, 43.066531866788864, 41.59145101904869, 34.40371870994568, 18.834453150629997, 21.34562060236931, 34.01677407324314, 30.734472200274467, 12.95577434822917, 1.0444609983824193, 0.10668419607100077, 0.07875418814364821, 1.0031025926582515, 0.9941587632056326, 4.3323570024222136, 8.630472142249346, 10.117204114794731, 16.49999901652336, 4.614177905023098, 5.970119945704937, 8.248323798179626, 23.273819535970688, 33.39565560221672, 44.747269079089165, 55.54840229451656, 52.3624936491251, 51.93274810910225, 54.2367734760046, 51.00379295647144, 53.26932638883591, 52.95667536556721, 52.564977183938026, 47.170444652438164, 42.282607331871986, 37.31839030981064, 38.78359168767929, 38.54219824075699, 39.3888384103775, 38.74212071299553, 38.1722728908062, 39.69861298799515, 38.98196384310722, 42.69149959087372, 47.38617807626724, 50.82012601196766, 51.261582523584366, 49.81203630566597, 46.71587124466896, 37.48770162463188, 37.03367918729782, 45.91972276568413, 55.49683526158333, 53.3349222689867, 55.2166572958231, 50.39189279079437, 50.412708073854446, 43.63188453018665, 39.89947780966759, 36.82640790939331, 38.358352705836296, 41.92506551742554, 48.4741584956646, 53.404777720570564, 53.9691424369812, 22.784215807914734, 40.38188852369785, 44.25510048866272, 55.7739619910717, 52.59383663535118, 52.0614206045866, 52.03289553523064, 53.93532805144787, 51.704000383615494, 51.97707653045654, 45.157669857144356, 35.98549023270607, 39.55218404531479, 50.10517157614231, 54.6063606441021, 54.47045713663101, 52.749856263399124, 51.64468176662922, 49.01133947074413, 47.072079330682755, 40.997820273041725, 39.883936643600464, 39.31449919939041, 38.55441078543663, 43.268985003232956, 52.893800139427185, 54.52933497726917, 52.75203734636307, 49.959833174943924, 49.32689733803272, 45.05541354417801, 40.18840670585632, 39.5477344840765, 41.36424981057644, 44.06701818108559, 44.90338750183582, 44.1399172693491, 46.84359759092331, 45.71893393993378, 51.4748764783144, 52.65856996178627, 54.73253667354584, 45.09422846138477, 32.658502757549286, 23.959737829864025, 11.627089194953442, 5.538084553554654, 14.587594885379076, 7.1144019439816475, 9.267411064356565, 6.30733760073781, 4.149836171418428, 2.261507548391819, 0.2987538924207911, 0.1633422655868344, 0.10229330160655081, 1.2870640866458416, 12.587148528546095, 34.71508540213108, 37.5610338896513, 23.410327211022377, 22.920693084597588, 35.92297598719597, 46.305371671915054, 51.93531297147274, 22.865844927728176, 2.1604821318760514, 0.04832708335015923, 0.03676323882245924, 0.045402646719594486, 0.02400232493528165, 0.031067379713931587, 0.04206900470308028, 0.03613849519751966, 0.00939938103329041, 0.04613909470208455, 0.03590625121432822, 0.032692551394575275, 0.02233541486930335, 0.06467842234997079, 0.045580346559290774, 0.05389360281697009, 0.032456860135425813, 0.012309432058827952, 0.04251577389368322, 0.09194518032018095, 0.06689861649647355, 0.010260717626806581, 0.038816917294752784, 0.05899698502616957, 0.003937064202546026, 0.006956774504942587, 0.04876391889411025, 0.07863402701332234, 0.07739868509816006, 0.04245785668899771, 0.020987329589843284, 0.08765765960561112, 0.036069301058887504, 0.09957033951650374, 0.040963434730656445, 0.022069182377890684, 0.06755957321729511, 0.03121089808701072, 0.05903535035031382, 0.023979253419383895, 0.02487011264747707, 0.10184446553466842, 0.05755288068030495, 0.07586339677800424, 0.16750908340327442, 2.5308945681899786, 24.08985424786806, 50.65092869102955, 47.421090602874756, 37.7933344244957, 24.15896113961935, 26.659779846668243, 40.72927728295326, 34.92911271750927, 15.75204810127616, 1.4856651797890663, 0.13584876665845513, 0.049799007101682946, 1.2175358925014734, 1.9971462339162827, 9.99555079266429, 9.615975860506296, 12.108526211231947, 19.598784036934376, 5.301335407420993, 8.598910085856915, 9.020019639283419, 22.534010633826256, 35.339327305555344, 45.70189945399761, 54.47169207036495, 54.29087497293949, 51.2020169198513, 53.079203590750694, 51.36719785630703, 52.81069479882717, 54.22801874577999, 55.2781417965889, 49.31715086102486, 43.28427158296108, 40.17220817506313, 40.801431611180305, 40.601433143019676, 41.458401158452034, 40.53200326859951, 39.9996480345726, 40.62471069395542, 40.68940222263336, 46.00316248834133, 49.43858094513416, 53.19700866937637, 52.57200300693512, 52.98819847404957, 48.38925965130329, 39.43656384944916, 40.28079114854336, 47.765701711177826, 56.61053270101547, 56.11675299704075, 56.89690053462982, 52.65399880707264, 52.45689198374748, 47.00103834271431, 42.07521066069603, 38.683497458696365, 40.38584791123867, 44.97122906148434, 51.45651586353779, 55.85973098874092, 53.64887662231922, 25.409886315464973, 41.04792058467865, 47.408277690410614, 56.98345609009266, 55.331407338380814, 54.251972660422325, 54.4081024825573, 55.80754838883877, 53.79984252154827, 54.357052221894264, 45.32172605395317, 38.86767357587814, 39.618030712008476, 51.36330686509609, 56.13295912742615, 54.211900010704994, 55.163368955254555, 53.81334699690342, 50.305705815553665, 48.09325933456421, 43.075708374381065, 42.20157288014889, 41.32955767214298, 41.458298563957214, 45.399815663695335, 55.58749459683895, 56.18846274912357, 54.87735070288181, 52.744901329278946, 50.82001581788063, 47.04777963459492, 42.080025002360344, 42.17098832130432, 43.54542016983032, 45.82209460437298, 47.0541974902153, 46.759557500481606, 48.26290123164654, 49.403759613633156, 53.80882903933525, 56.714996695518494, 56.12820938229561, 48.70517089962959, 32.622134909033775, 21.57451841980219, 8.580412678420544, 10.398724358528852, 19.441628269851208, 10.429416261613369, 9.655990563333035, 6.785463094711304, 6.78204707801342, 2.774278395809233, 1.2350653018802404, 0.2389643233618699, 0.0946789926092606, 1.6809362266212702, 14.425570629537106, 36.85638830065727, 33.47656466066837, 26.079902462661266, 29.356189258396626, 41.81872062385082, 54.1478468477726, 57.679259553551674, 27.112113274633884, 2.6763284392654896, 0.08339431064086966, 0.07943622185848653, 0.019594403747760225, 0.04808925470570102, 0.09514963297988288, 0.04380147052870598, 0.06281408801442012, 0.02334146098291967, 0.07855661358917132, 0.07621372016728856, 0.06457656258135103, 0.03522407649143133, 0.03252404676459264, 0.055856297694845125, 0.020957207671017386, 0.042977990888175555, 0.046762624915572815, 0.020081786969967652, 0.01578845523908967, 0.026332388479204383, 0.01947032222233247, 0.0301616942306282, 0.12656881852308288, 0.17284145898884162, 0.1262945355847478, 0.14687574526760727, 0.09772867037099786, 0.14980348816607147, 0.15340597688918933, 0.1419834335683845, 0.2083858649712056, 0.10106857240316458, 0.17901504412293434, 0.19076189113548025, 0.11422178184147924, 0.14016310859005898, 0.16576034598983824, 0.14950290351407602, 0.14072014979319647, 0.1197255119041074, 0.2547447133110836, 0.12091538985259831, 0.2796500315889716, 0.27318013657350093, 3.671325948089361, 31.030527614057064, 59.33864191174507, 56.19352027773857, 45.41776970028877, 29.598473757505417, 31.703150421380997, 46.82915456593037, 40.493720322847366, 17.444381341338158, 1.9312073034234345, 0.3450682119000703, 0.2769882447319105, 2.2518491791561246, 5.036720931529999, 11.727074179798365, 20.501769483089447, 17.95293465256691, 24.42131996154785, 11.31062127649784, 11.132863964885473, 13.915587645024061, 27.718283347785473, 40.841382667422295, 48.1413571536541, 56.657201796770096, 54.90554139018059, 52.88569137454033, 55.13647019863129, 51.83903753757477, 54.11385767161846, 57.31593444943428, 57.27688394486904, 52.205607667565346, 46.30708917975426, 42.96936348080635, 41.93344786763191, 42.82777927815914, 42.071741446852684, 43.04450064897537, 41.015990898013115, 43.42932499945164, 42.78772562742233, 48.170972764492035, 50.91596066951752, 55.083406046032906, 55.505749583244324, 55.86730018258095, 50.68787410855293, 41.970598474144936, 41.947187930345535, 49.28367465734482, 59.511357843875885, 57.535163685679436, 59.46688883006573, 54.34826709330082, 54.22318160533905, 48.28145943582058, 43.04877921938896, 40.50691321492195, 42.95978419482708, 47.04412043094635, 53.403740376234055, 57.71407328546047, 55.10709397494793, 28.480201363563538, 45.89614883065224, 52.0999239385128, 57.767722606658936, 56.41073562204838, 53.993301540613174, 55.33220149576664, 57.04410083591938, 56.26253977417946, 57.574016600847244, 49.666272327303886, 40.9388892352581, 42.83087611198425, 53.53898271918297, 59.603240713477135, 57.996249943971634, 57.019888535141945, 56.35751187801361, 53.097374215722084, 51.81786887347698, 45.77968887984753, 43.48971515893936, 44.18135404586792, 44.199965447187424, 46.261955201625824, 58.57026234269142, 59.13332752883434, 56.563859805464745, 55.47769568860531, 53.6583761125803, 48.53233717381954, 44.51530672609806, 44.36596713960171, 45.47965697944164, 47.30470284819603, 49.830408319830894, 49.68534730374813, 52.649784833192825, 50.580351278185844, 57.356250286102295, 57.967576682567596, 58.62424224615097, 51.58075399696827, 35.44651195406914, 25.774892829358578, 18.64386487752199, 10.148602779954672, 23.193271458148956, 16.848928593099117, 17.451692149043083, 18.869384676218033, 10.92935448512435, 4.9686547089368105, 1.8278301693499088, 0.7179475470911711, 0.34173077379819006, 1.939749838784337, 16.423153840005398, 45.654386803507805, 51.45966589450836, 35.32288558781147, 34.6319230645895, 46.77628420293331, 59.7904946655035, 64.66456532478333, 34.14923496544361, 3.5645466903224587, 0.19620683568064123, 0.17957055650185794, 0.19468578917440027, 0.12159257734310813, 0.19323849730426446, 0.16587368678301573, 0.21112204471137375, 0.1534341339720413, 0.19339997379574925, 0.15300049708457664, 0.1555442379321903, 0.20698596665170044, 0.136726193013601, 0.08448422871879302, 0.10036056351964362, 0.09645040263421834, 0.13232580648036674, 0.18530538392951712, 0.15929816931020468, 0.125450951163657, 0.12848393060266972, 0.17297762824455276], [0.026497020953684114, 0.04231541999615729, 0.03082624294620473, 0.05962410352367442, 0.02669850848178612, 0.08790218984358944, 0.13317004399141297, 0.061899257416371256, 0.05742543908127118, 0.014671818917122437, 0.02886508431402035, 0.009854392701527104, 0.06351082367473282, 0.05282242396788206, 0.04534154570137616, 0.026951074323733337, 0.027600575995165855, 0.030184982824721374, 0.06543601411976852, 0.0382839773374144, 0.054063921998022124, 0.09592907357728109, 1.7016311036422849, 26.415433958172798, 47.93368689715862, 38.40704329311848, 33.17655175924301, 18.950516022741795, 16.388733386993408, 26.525124572217464, 33.30196022987366, 10.580480005592108, 0.6067165907006711, 0.03545862484315876, 0.062128644131007604, 0.517236142186448, 2.0181192085146904, 7.883616043254733, 7.187055945396423, 10.907298568636179, 19.83515415340662, 5.124934623017907, 7.2253151424229145, 14.3533631041646, 26.97485513985157, 36.69946052134037, 49.135209023952484, 51.91268138587475, 56.39476127922535, 50.198027193546295, 53.801449835300446, 49.73680794239044, 51.189086213707924, 52.52552770078182, 53.740839287638664, 51.643101051449776, 50.21601922810078, 45.69265455007553, 40.981389954686165, 38.140396401286125, 38.804843947291374, 37.44324021041393, 39.87061835825443, 38.45734119415283, 40.83621874451637, 41.76271542906761, 46.233699917793274, 51.09008252620697, 52.998571917414665, 50.03209009766579, 47.5900599360466, 40.10072261095047, 38.67231085896492, 40.09914569556713, 50.2452776581049, 49.647311344742775, 51.59015089273453, 50.32412342727184, 42.330971136689186, 37.36775726079941, 38.09466205537319, 36.22137397527695, 42.25466363132, 45.86256243288517, 50.32580293715, 49.488061890006065, 53.66372622549534, 24.34263378381729, 36.088054329156876, 49.53009143471718, 43.51065203547478, 47.982293888926506, 50.7560196518898, 52.38542541861534, 49.610103741288185, 49.62567910552025, 53.01519222557545, 49.94787521660328, 40.24055130779743, 37.75165066123009, 48.173906207084656, 54.12659838795662, 54.34169724583626, 53.420128896832466, 51.97157822549343, 53.21842812001705, 51.44762434065342, 46.1393091827631, 38.327034786343575, 37.476325035095215, 37.941572070121765, 38.07829633355141, 40.027238354086876, 43.029829636216164, 46.546533331274986, 46.71151287853718, 43.4818609803915, 40.60026280581951, 39.439159110188484, 40.618874207139015, 41.3997171074152, 42.513862922787666, 44.02651995420456, 48.40111881494522, 48.129554986953735, 50.777230113744736, 50.81618942320347, 52.898200303316116, 56.769972145557404, 47.413312420248985, 39.73931260406971, 32.43848316371441, 6.58790267072618, 10.381636675447226, 20.721581988036633, 4.572182083502412, 10.677555296570063, 6.276296591386199, 5.521277105435729, 2.12147010024637, 0.8392847736831754, 0.08248630780144595, 0.11657754410407506, 0.41576380433980376, 8.126594480127096, 26.501731127500534, 34.052450358867645, 23.122291266918182, 19.44302659481764, 32.52242065966129, 45.13701416552067, 47.2531396150589, 25.9067115560174, 2.4510109797120094, 0.021946358792774845, 0.04743669538584072, 0.04463603414478712, 0.04522879491560161, 0.004090943884875742, 0.06741552977473475, 0.03945054442738183, 0.00911551696844981, 0.015033078780106734, 0.05829006709973328, 0.01534667142550461, 0.016541900258744135, 0.017649600194999948, 0.008908538475225214, 0.03083263654843904, 0.014553282162523828, 0.04033077239000704, 0.015648801600036677, 0.09825517219724134, 0.04518892303167377, 0.0674559100298211, 0.042764920290210284, 0.05944181350059807, 0.10173151807975955, 0.017802267393562943, 0.024116023814713117, 0.017161805080831982, 0.08165233419276774, 0.06223460797627922, 0.0343025331676472, 0.046060252643655986, 0.04168626430328004, 0.008192927216441603, 0.0575064593431307, 0.04107317981834058, 0.03552804533683229, 0.0024015801409404958, 0.01614905737369554, 0.016044538861024193, 0.03829174762358889, 0.026347524581069592, 0.06158841628348455, 0.009118813959503314, 0.07755533762974665, 2.698200303129852, 31.93265810608864, 53.698760345578194, 44.66805852949619, 37.37290218472481, 22.153820134699345, 21.610109210014343, 35.0142889469862, 34.22355517745018, 11.408282686024904, 0.7666856911964715, 0.09322752244770527, 0.0831596583884675, 2.4093690142035484, 5.26073838584125, 8.629216309636831, 11.83883948251605, 11.725729051977396, 17.60123312473297, 5.244441060349345, 6.638777190819383, 16.525176465511322, 28.957090973854065, 38.588871136307716, 48.06433908641338, 51.86287745833397, 54.49142821133137, 52.02515535056591, 52.916754707694054, 51.4993167668581, 51.54883950948715, 53.646976724267006, 55.88133282959461, 54.73133593797684, 50.99248856306076, 46.18240267038345, 40.84348775446415, 38.50761629641056, 39.85835641622543, 39.8165662586689, 40.77880002558231, 40.12124910950661, 43.37294362485409, 43.32007326185703, 49.47270691394806, 55.07247403264046, 55.12089103460312, 52.27309584617615, 50.39366349577904, 42.43187852203846, 39.95355650782585, 44.0082011371851, 52.48584263026714, 53.2917033880949, 53.53457495570183, 51.570870727300644, 45.660835057497025, 39.09565754234791, 39.81104135513306, 37.970332726836205, 43.3467972278595, 48.53141762316227, 51.05656072497368, 52.74875812232494, 55.443812906742096, 27.54040729254484, 42.393568977713585, 51.376385763287544, 45.52979528903961, 47.94544726610184, 50.271902829408646, 52.37941414117813, 50.56483671069145, 51.42055459320545, 56.09890915453434, 51.03800632059574, 41.839877888560295, 38.41612100601196, 50.16463078558445, 56.77210383117199, 55.05798541009426, 53.042030185461044, 54.08401407301426, 54.357876777648926, 52.220141887664795, 48.06120045483112, 40.49687035381794, 39.206790179014206, 40.60688965022564, 40.336682349443436, 43.123308420181274, 47.18581482768059, 50.9110589325428, 49.53963652253151, 47.68227718770504, 43.473991602659225, 41.02750048041344, 42.968398332595825, 42.0644686371088, 44.182284995913506, 46.77712395787239, 50.57668827474117, 50.304470881819725, 53.41311067342758, 54.62398789823055, 54.83492597937584, 59.025265127420425, 49.62282545864582, 37.482910081744194, 25.089212022721767, 11.295623481273651, 10.98831307142973, 11.240120809525251, 12.005634382367134, 11.06486851349473, 10.273316837847233, 5.937640713527799, 2.9926887759938836, 1.7767007066868246, 0.06367541718645953, 0.07587333413539454, 0.642191368388012, 9.826831296086311, 31.682397834956646, 38.07619124650955, 26.67091704905033, 24.87903770059347, 38.7360068410635, 50.276823565363884, 54.83542375266552, 31.128655448555946, 3.445173720829189, 0.06133869472250808, 0.02045938243099954, 0.011105367957497947, 0.05330735810275655, 0.024665253913553897, 0.048012757833930664, 0.021914741446380503, 0.07825812179362401, 0.014770746274734847, 0.03813918061496224, 0.03025278729182901, 0.042161031014984474, 0.07749986951239407, 0.024377667978114914, 0.053021145140519366, 0.032824612862896174, 0.029241560987429693, 0.035252344896434806, 0.0363532541814493, 0.023195163266791496, 0.04898405844869558, 0.01833263766457094, 0.13996497000334784, 0.21483582590008155, 0.13573079486377537, 0.11612716436502524, 0.18617148511111736, 0.13850967778125778, 0.17867341870442033, 0.16722123400541022, 0.14783850376261398, 0.14306009688880295, 0.0964084490260575, 0.1571307863923721, 0.26000787620432675, 0.2315044033457525, 0.12897015607450157, 0.0672736979322508, 0.09223487766576, 0.09204091737046838, 0.15081828605616465, 0.19712208188138902, 0.1563028316013515, 0.18601553019834682, 4.238141532987356, 40.7711586356163, 59.27665963768959, 50.85399739444256, 43.807993680238724, 30.01430444419384, 25.401902943849564, 37.69628003239632, 40.646304935216904, 13.817656449973583, 1.1744921584613621, 0.33515190181788057, 0.3241022728616372, 2.227396066300571, 7.514249263331294, 14.377732146531343, 18.551622927188873, 23.69048997759819, 31.08934845775366, 14.026303254067898, 13.685866221785545, 18.059135153889656, 30.060304775834084, 38.75302232801914, 50.627738535404205, 53.79144877195358, 55.67455172538757, 52.47359208762646, 52.79019109904766, 51.54611125588417, 51.14151656627655, 54.35284584760666, 59.409785494208336, 57.84914843738079, 55.51154047250748, 49.828941598534584, 44.86305646598339, 41.81379608809948, 41.840485855937004, 40.94520069658756, 43.87533746659756, 40.98187632858753, 45.99286124110222, 44.367585852742195, 51.061804443597794, 55.55079996585846, 56.735253408551216, 53.072310760617256, 53.41911435127258, 45.04179887473583, 42.32586421072483, 44.521090015769005, 54.88758735358715, 55.729245990514755, 56.702734753489494, 55.03142863512039, 46.38493940234184, 40.57586431503296, 41.68890438973904, 38.794983476400375, 46.11834570765495, 50.17584778368473, 54.056218564510345, 53.82669948041439, 56.13964296877384, 32.36179567873478, 44.17926035821438, 52.494213581085205, 47.48322106897831, 49.24818076193333, 51.01247929036617, 54.033906161785126, 52.08048418164253, 51.91759452223778, 58.511730283498764, 54.485268741846085, 45.34857161343098, 39.50258910655975, 52.851489409804344, 57.871688827872276, 56.326585337519646, 55.104510113596916, 55.115639716386795, 56.29537381231785, 55.96194930374622, 51.14698067307472, 42.45183125138283, 40.39013788104057, 43.04259315133095, 43.375660479068756, 44.515979290008545, 47.82644525170326, 52.24330544471741, 52.04318158328533, 48.55298526585102, 45.235333889722824, 43.57757784426212, 45.01113452017307, 45.058856159448624, 46.06632649898529, 48.67375038564205, 54.514055997133255, 53.35709787905216, 56.767323687672615, 58.141189366579056, 57.509720250964165, 61.60286441445351, 50.235208198428154, 41.908513605594635, 35.948586612939835, 12.701861523091793, 17.34107818454504, 29.055412597954273, 12.395684402436018, 19.390167631208897, 13.382934127002954, 13.659856617450714, 5.04546663723886, 2.462724088691175, 0.4355451272567734, 0.28100418392568827, 1.127938600257039, 11.424051839858294, 37.1050089597702, 50.073842257261276, 36.602710112929344, 30.999289490282536, 45.915125012397766, 57.28821113705635, 62.329962998628616, 38.20324122905731, 5.1294768042862415, 0.23990673216758296, 0.2003049899940379, 0.10918225772911683, 0.0789823243394494, 0.1511209487216547, 0.21648628811817616, 0.11269917682511732, 0.1536807051161304, 0.09153696199064143, 0.11700663162628189, 0.11818557773949578, 0.10977727462886833, 0.16485525236930698, 0.16326426586601883, 0.14872729982016608, 0.08561633789213374, 0.16521638142876327, 0.11490277654957026, 0.24131783691700548, 0.13671396241988987, 0.18152179633034393, 0.17120049626100808], [0.06172321998747066, 0.0025747932340891566, 0.05399802299507428, 0.06492677464848384, 0.018765981403703336, 0.04564822338579688, 0.04649265385523904, 0.02274049948027823, 0.05090110753371846, 0.03160603606374934, 0.06855131257907487, 0.06978864345001057, 0.009354264948342461, 0.04620325336873066, 0.017743446624081116, 0.028720664231514093, 0.0548718091158662, 0.04106105312530417, 0.050899979469249956, 0.049815323218354024, 0.0359096205647802, 0.0416703600785695, 1.1880842666141689, 24.537833109498024, 47.5310605019331, 46.467615365982056, 36.1773419380188, 18.657538443803787, 19.897432811558247, 35.79684175550938, 25.671395882964134, 6.807051636278629, 0.3468765883008018, 0.16431679454399273, 0.0631272817554418, 2.0444912184029818, 2.367384354583919, 9.881749749183655, 8.61271284520626, 8.588768430054188, 15.395518932491541, 0.27517915586940944, 9.70442846417427, 16.418434493243694, 30.891662165522575, 44.19453173875809, 47.1489530056715, 56.48679234087467, 53.54780584573746, 51.747975423932076, 51.72321975231171, 51.51204988360405, 52.004860639572144, 51.747470051050186, 53.56555089354515, 53.276048228144646, 49.90395337343216, 49.56542193889618, 49.830108135938644, 47.647379860281944, 43.886106088757515, 39.880148246884346, 38.38006094098091, 36.756180077791214, 37.374855279922485, 37.22153730690479, 43.16958613693714, 50.05890145897865, 51.833041459321976, 51.693402752280235, 48.76091010868549, 41.801066771149635, 38.80445636808872, 37.90314853191376, 41.72857046127319, 41.30273871123791, 41.520991399884224, 39.34379942715168, 38.545135483145714, 36.080773919820786, 36.79043523967266, 37.00481213629246, 49.611365273594856, 47.974044531583786, 55.304987356066704, 46.99435070157051, 52.93092414736748, 33.347234800457954, 43.005298152565956, 53.14911223948002, 45.76369933784008, 50.99656954407692, 50.01972176134586, 49.978303983807564, 51.60009115934372, 53.103222101926804, 53.52886766195297, 53.17891024053097, 44.165930673480034, 35.44367350637913, 46.466749012470245, 56.74670599400997, 51.56134083867073, 49.36853930354118, 51.08656011521816, 52.22552239894867, 51.72829627990723, 49.24780838191509, 41.383643969893456, 37.41127252578735, 33.48947636783123, 34.78385031223297, 36.911614537239075, 38.305220156908035, 37.505112290382385, 38.405926153063774, 37.209267765283585, 37.48455159366131, 39.94796700775623, 39.39094729721546, 40.05429670214653, 46.17683216929436, 47.68105745315552, 50.62659099698067, 51.23741202056408, 54.87438686192036, 54.03260663151741, 55.0386406481266, 52.98790208995342, 49.907893761992455, 37.897084057331085, 27.04515516757965, 17.27824855595827, 16.255522035062313, 11.198690682649612, 13.498879205435514, 8.840994145721197, 6.832975270226598, 4.0598289761692286, 2.6345359068363905, 1.9671683362685144, 0.2889185951789841, 0.05753083147283178, 0.1394495929707773, 5.4935756418854, 26.44963212311268, 36.72569811344147, 15.138651765882969, 16.941176243126392, 34.26445238292217, 49.768623635172844, 45.50804525613785, 26.453916393220425, 4.943064507097006, 0.2142346862819977, 0.11821055843029171, 0.052298575319582596, 0.03687776705191936, 0.04527737219177652, 0.09308754597441293, 0.059127105778316036, 0.06463516998337582, 0.020412421181390528, 0.014393640631169546, 0.017330395057797432, 0.05826660039019771, 0.01140966798629961, 0.038052115560276434, 0.04050044219184201, 0.0230322933930438, 0.012319459401624044, 0.0658517429837957, 0.05820202612085268, 0.050255613459739834, 0.032718830843805335, 0.07952268206281587, 0.05109469304443337, 0.07073652188410051, 0.01722564276860794, 0.01245539673618623, 0.051620196682051755, 0.016571703054069076, 0.04446734397788532, 0.041129096935037524, 0.14499296114081517, 0.036593928962247446, 0.050870634950115345, 0.027604832212091424, 0.03022822962520877, 0.02462142081640195, 0.03797817538725212, 0.07340913667576388, 0.03278026953921653, 0.031343954033218324, 0.010412910778541118, 0.06111074777436443, 0.011777178588090464, 0.03113574450253509, 2.342157745733857, 31.23685274273157, 55.20394317805767, 49.85425963997841, 41.82353876531124, 24.875441193580627, 22.396809495985508, 35.166307389736176, 29.577795267105103, 7.803836474195123, 0.4715994925936684, 0.09507765949820168, 0.14759111625608057, 2.198685994371772, 6.160195246338844, 11.455106623470783, 15.02159334719181, 11.716847028583288, 14.748445004224777, 6.725451964884996, 8.769061155617237, 19.36507947742939, 32.42658980190754, 45.098533630371094, 48.42076376080513, 55.02575933933258, 54.339679554104805, 50.53027756512165, 51.94077707827091, 51.58421941101551, 52.41661034524441, 52.566451504826546, 53.28685104846954, 54.386097863316536, 52.62614630162716, 51.67504973709583, 52.427910938858986, 48.51981304585934, 45.051765739917755, 41.98778495192528, 40.063408613204956, 38.51267762482166, 39.25976313650608, 39.25106160342693, 44.8259324580431, 52.18872517347336, 54.448258727788925, 54.403899908065796, 51.1062278598547, 43.8943250477314, 39.90825533866882, 39.890377297997475, 44.64745223522186, 44.57379698753357, 43.72955068945885, 41.69729433953762, 39.635745361447334, 38.17935571074486, 38.78665052354336, 38.86368378996849, 51.29592888057232, 51.57665781676769, 57.76566691696644, 49.44506339728832, 54.49623875319958, 35.285818576812744, 44.34345334768295, 51.995292752981186, 47.445116713643074, 52.46828377246857, 51.5258963406086, 51.48737780749798, 52.46195711195469, 52.9647271335125, 56.04668855667114, 54.847674295306206, 47.00279004871845, 37.83952094614506, 48.5310984402895, 58.561192229390144, 52.918977588415146, 50.80524981021881, 49.80057992041111, 53.48945237696171, 53.206983134150505, 51.43047206103802, 44.18149083852768, 39.62039418518543, 36.699996292591095, 37.172633931040764, 38.546226024627686, 40.35164214670658, 39.52146649360657, 39.795260801911354, 40.43139226734638, 39.788899943232536, 42.23039053380489, 41.129604801535606, 43.36597479879856, 48.120177090168, 49.61352735757828, 53.138989582657814, 55.02492718398571, 56.319715306162834, 57.540050223469734, 57.04819701611996, 54.688793420791626, 49.16764788329601, 40.51846459507942, 24.98912539333105, 14.607062190771103, 14.756208937615156, 13.854736760258675, 12.398873381316662, 11.992516536265612, 7.18212665989995, 8.624634705483913, 4.576786486431956, 2.4644838692620397, 0.6040784041397274, 0.06701892605633475, 0.2667622215813026, 6.1808376386761665, 30.47971487045288, 44.184830859303474, 23.76491468399763, 21.55273038893938, 38.98530386388302, 55.478311255574226, 52.97978572547436, 30.650388412177563, 5.761069413274527, 0.29954920755699277, 0.13735918560996652, 0.05349057581042871, 0.025076004822039977, 0.03952992454287596, 0.017279322310059797, 0.06086665911425371, 0.060030488748452626, 0.05618942923319992, 0.021986050705891103, 0.05190696996578481, 0.06603466754313558, 0.012552796197269345, 0.010107415891980054, 0.014686820504721254, 0.004534464787866455, 0.0398867491458077, 0.0850317555887159, 0.02961709142255131, 0.03295243666798342, 0.05865248749614693, 0.05344111908925697, 0.12225388287333772, 0.12473362090531737, 0.18941443297080696, 0.10487628722330555, 0.15840502426726744, 0.24600093718618155, 0.15662317222449929, 0.09565752916387282, 0.2800314064370468, 0.16629390564048663, 0.1296320033725351, 0.12313953222474083, 0.2866351848933846, 0.13685930462088436, 0.11847767964354716, 0.12314624866121449, 0.09449269127799198, 0.19364417006727308, 0.20382440270623192, 0.1760845849639736, 0.20187754154903814, 0.1939629521802999, 3.683764818124473, 39.7424740344286, 62.76393011212349, 57.351439744234085, 47.936817929148674, 29.759087339043617, 30.57930752635002, 47.09124930202961, 33.617833480238914, 9.073722157627344, 0.6844679592177272, 0.35596673958934844, 0.4999220743775368, 4.63246869854629, 7.705314410850406, 21.388679891824722, 17.46663674712181, 17.71318841725588, 24.195917956531048, 7.6525485422462225, 16.61420188844204, 19.45618148893118, 36.29423126578331, 47.952013313770294, 51.78874723613262, 56.78845055401325, 55.57159245014191, 50.176254361867905, 53.12357760965824, 51.34222559630871, 53.76808762550354, 52.585169300436974, 55.38724534213543, 57.578511759638786, 54.42340426146984, 53.498959466814995, 55.67686580121517, 52.327212542295456, 47.899405136704445, 43.90119127929211, 42.30968087911606, 41.18153661489487, 41.51642024517059, 40.3198416531086, 47.56426312029362, 55.1070711761713, 56.679890379309654, 56.95308431982994, 53.433120399713516, 45.23601785302162, 42.28039585053921, 41.59772828221321, 45.7866957038641, 45.18040403723717, 45.256745740771294, 43.980116844177246, 41.82313598692417, 40.716373175382614, 40.057036355137825, 40.77056206762791, 53.56892891228199, 54.68570038676262, 58.29809054732323, 52.03059285879135, 54.59241159260273, 40.32684847712517, 45.82184001803398, 49.84985567629337, 50.1470947265625, 54.583694860339165, 54.16165150702, 54.016050919890404, 54.954547360539436, 54.69798132777214, 58.189963549375534, 57.13256388902664, 48.42636466026306, 40.15163987874985, 50.449391305446625, 60.88396579027176, 54.20022703707218, 51.19094431400299, 50.96529722213745, 54.95606727898121, 56.78923711180687, 53.728208765387535, 47.16350242495537, 41.74052841961384, 36.995643228292465, 40.016553327441216, 41.172299310564995, 43.44535253942013, 41.949665397405624, 41.220191940665245, 40.7369414716959, 41.019300520420074, 44.122472405433655, 42.725093588232994, 44.136562049388885, 51.460988223552704, 51.059182584285736, 55.10066471993923, 58.22619840502739, 59.741302505135536, 58.72201479971409, 58.69817867875099, 54.05459225177765, 50.97998723387718, 42.99864090979099, 30.593760050833225, 21.729145422577858, 27.143132910132408, 21.732434146106243, 21.06257949024439, 18.734801597893238, 13.137406501919031, 14.03680494055152, 4.874658677726984, 4.867461863905191, 1.2333971913903952, 0.18843595578800887, 0.37285107420757413, 7.7750064712017775, 34.72154885530472, 50.43491028249264, 27.612174041569233, 26.921101324260235, 46.74803651869297, 62.577151134610176, 61.087323278188705, 38.69871944189072, 7.9575795494019985, 0.48875393928028643, 0.22551801754161716, 0.15362496982561424, 0.12211873035994358, 0.12788957421435043, 0.17112804780481383, 0.13579828577348962, 0.2282197171007283, 0.14400099171325564, 0.17764685035217553, 0.21548557619098574, 0.14853398519335315, 0.08835330430883914, 0.11509223200846463, 0.06679182886728086, 0.10159298879443668, 0.09297152602812275, 0.14362165034981444, 0.12592789978953078, 0.10981431521940976, 0.07158694890676998, 0.12990026007173583], [0.01010355023026932, 0.04395934389322065, 0.01138778390668449, 0.05311523833370302, 0.057288631578558125, 0.0794584046525415, 0.05251819166005589, 0.042141063531744294, 0.024370218670810573, 0.05302652942191344, 0.08315757295349613, 0.03838040829577949, 0.02276988852827344, 0.0317328616802115, 0.01937492470460711, 0.06407985798432492, 0.04305381982703693, 0.019519420857250225, 0.06962825791561045, 0.03863986312353518, 0.044519286893773824, 0.09814301141886972, 3.3343455428257585, 34.14984293282032, 48.51059094071388, 40.4092812538147, 18.8855642080307, 18.597872145473957, 26.136367432773113, 40.10003484785557, 27.27642595767975, 5.49196595326066, 0.18928822333691642, 0.12293167150346562, 0.4891682357992977, 2.7693778462707996, 8.035482969135046, 5.252252966165543, 14.457750152796507, 7.85648169927299, 10.870469994843006, 4.1657444927841425, 7.699376754462719, 29.212537966668606, 33.69316063821316, 45.54195463657379, 48.66904243826866, 55.66309534013271, 52.066747918725014, 56.485595405101776, 53.05999182164669, 55.018851310014725, 53.69966849684715, 53.176162987947464, 51.584591791033745, 52.003876492381096, 53.081263080239296, 53.79990711808205, 51.416268423199654, 48.88321794569492, 49.126625284552574, 48.31900902092457, 44.60507310926914, 40.767575427889824, 37.33106642961502, 35.26865869760513, 37.64062061905861, 42.58014656603336, 45.23441433906555, 48.49736765027046, 47.12138168513775, 43.889974281191826, 39.62873853743076, 38.236789628863335, 36.23430848121643, 37.39251673221588, 37.73025020956993, 36.57338708639145, 36.890597864985466, 35.36404877901077, 37.851524502038956, 40.57678386569023, 50.257205218076706, 51.00364476442337, 49.607728868722916, 48.18126641213894, 53.52215342223644, 32.99411594867706, 42.05088436603546, 51.24166399240494, 51.81809686124325, 52.25235275924206, 48.46804462373257, 49.1411405056715, 48.83842974901199, 52.82043747603893, 53.2093770056963, 51.3385283946991, 49.32126984000206, 36.482442766427994, 40.75685240328312, 50.54218232631683, 53.49482148885727, 52.617832347750664, 48.040552362799644, 51.90086022019386, 52.59688787162304, 51.11672669649124, 45.518247708678246, 39.247512593865395, 39.86026771366596, 44.57423396408558, 46.68800733983517, 48.25602360069752, 48.827395141124725, 44.65203478932381, 40.04245273768902, 37.26931594312191, 38.40607054531574, 40.25879792869091, 44.772815108299255, 49.72233831882477, 51.09560362994671, 54.42744344472885, 55.39046756923199, 55.08111856877804, 52.232628017663956, 50.15769235789776, 51.356106251478195, 49.93525609374046, 42.64041893184185, 31.516175754368305, 20.2400129288435, 12.849227115511894, 9.054365996271372, 13.558217771351337, 9.444169029593468, 10.302687361836433, 4.053702754899859, 5.0632639322429895, 1.3914026878774166, 0.7327356410678476, 0.06448999847634695, 0.07366942270891741, 3.661603219807148, 21.18499182164669, 38.6745223402977, 23.82289007306099, 17.98288084566593, 29.174838289618492, 45.00004291534424, 49.00586396455765, 28.794607892632484, 6.977169457823038, 0.22030260442988947, 0.051322910876479, 0.035234132592449896, 0.010723430932557676, 0.021410774934338406, 0.038490398292196915, 0.03240652025851887, 0.034275229554623365, 0.056881047785282135, 0.020171969044895377, 0.030748810968361795, 0.009107448895520065, 0.041629282204667106, 0.015593396565236617, 0.02874935009458568, 0.06624272864428349, 0.030388967679755297, 0.026663247190299444, 0.04488610080443323, 0.07344579134951346, 0.04394683870486915, 0.018320538802072406, 0.03311550506623462, 0.05133530845341738, 0.03239592981117312, 0.04909021154162474, 0.04458010589587502, 0.04824891664611641, 0.020704502676380798, 0.03623629541834816, 0.04256245127180591, 0.024799077982606832, 0.01854814065154642, 0.003203970263712108, 0.06951525108888745, 0.03382746588613372, 0.03276563438703306, 0.07399108435492963, 0.06949206639546901, 0.04278909204003867, 0.03795680524490308, 0.05647192774631549, 0.009398547972523374, 0.10166724809096195, 5.254527144134045, 42.181916534900665, 54.85004536807537, 47.13599570095539, 23.777919486165047, 18.876135013997555, 28.212790712714195, 40.16542173922062, 29.653181321918964, 5.224683070555329, 0.2838567621074617, 0.016094277598313056, 0.569060017587617, 5.2587558422237635, 11.557642221450806, 11.260463017970324, 15.753757059574127, 13.151881825178862, 12.328552454710007, 8.5128029063344, 10.851122383028269, 24.66686088591814, 35.274430587887764, 47.38078236579895, 49.34733264148235, 55.36224648356438, 52.593240067362785, 55.22591359913349, 53.869963958859444, 53.16612012684345, 53.98015044629574, 52.961398512125015, 51.21357969939709, 52.807833552360535, 55.27184173464775, 56.71978063881397, 52.36447714269161, 51.118805184960365, 50.40948584675789, 49.57149401307106, 45.63564620912075, 43.29988494515419, 39.3029972165823, 38.52309666574001, 39.67383831739426, 43.28942030668259, 48.94291274249554, 52.12198555469513, 49.77538727223873, 46.33463770151138, 41.000153347849846, 39.53893795609474, 39.093750044703484, 39.12975691258907, 38.61577369272709, 39.214404970407486, 38.50564420223236, 37.753976136446, 40.30450567603111, 42.866525799036026, 52.497823387384415, 54.951040148735046, 51.56000331044197, 49.19383227825165, 52.87283666431904, 36.1794850230217, 42.93414317071438, 51.55120678246021, 54.53559324145317, 52.681608125567436, 50.20080864429474, 50.71158103644848, 51.452062502503395, 54.25215885043144, 53.687569946050644, 54.29203771054745, 50.372369438409805, 39.59812358021736, 43.650967106223106, 54.6460685133934, 53.77145044505596, 53.915569111704826, 48.708868101239204, 53.185468688607216, 53.08166965842247, 52.76276037096977, 45.68831518292427, 40.15876069664955, 40.62739335000515, 45.886577144265175, 48.303099274635315, 50.11047229170799, 49.02935430407524, 45.81523597240448, 40.67705288529396, 38.99706043303013, 40.27263678610325, 42.66131401062012, 45.90499095618725, 50.281850695610046, 52.82858043909073, 55.84262050688267, 56.98807664215565, 56.75166092813015, 53.26190158724785, 51.122878566384315, 51.05116121470928, 49.76479724049568, 42.41360530257225, 30.777335800230503, 18.67955256253481, 14.619726911187172, 12.768361754715443, 13.946686126291752, 12.549111619591713, 9.06311122700572, 9.785212129354477, 4.085454326122999, 2.6291701197624207, 1.3278216496109962, 0.2753407956333831, 0.18014163913903758, 3.4817583952099085, 24.093530550599098, 42.83738896250725, 25.252329669892788, 22.591302059590816, 34.93717208504677, 49.88911896944046, 58.051525577902794, 36.22445560991764, 9.511625859886408, 0.3783166653010994, 0.052413181474548765, 0.02802524217258906, 0.03965596348280087, 0.019201714858354535, 0.037137889812584035, 0.029277942921908107, 0.026545722539594863, 0.0309398305034847, 0.017108641332015395, 0.05880567419808358, 0.04074136930285022, 0.00872446358698653, 0.009697805107862223, 0.026005322142736986, 0.02882909757317975, 0.08477283510728739, 0.029234594076115172, 0.05702978902263567, 0.02696121206099633, 0.035842552679241635, 0.03752230004465673, 0.1432459900388494, 0.1479278434999287, 0.1217535269097425, 0.11853582691401243, 0.15287624672055244, 0.12800713040633127, 0.12311625105212443, 0.11001744103850797, 0.0940469722263515, 0.09585321124177426, 0.18168710230384022, 0.15805470087798312, 0.11009061679942533, 0.08170064800651744, 0.13584720814833418, 0.1636568471440114, 0.15786241041496396, 0.10000166090321727, 0.18639577698195353, 0.13006056396989152, 0.12447487853933126, 0.22573874710360542, 6.866372153162956, 51.48906871676445, 61.469613164663315, 53.35024304687977, 29.598017781972885, 27.416440844535828, 36.72389701008797, 50.708267614245415, 34.87450584769249, 7.109514456242323, 0.4753074108157307, 0.3486440872075036, 0.88259496842511, 6.12880228087306, 15.038893818855286, 11.629305426031351, 24.104548059403896, 19.088826701045036, 19.569637700915337, 11.747155152261257, 13.224317338317633, 33.216179832816124, 38.25149863958359, 49.55646201968193, 51.89448796212673, 56.77434951066971, 52.91425064206123, 57.9739261418581, 52.529844269156456, 53.576513305306435, 54.62821327149868, 54.333763271570206, 51.729880794882774, 52.915751561522484, 55.637705102562904, 57.225529700517654, 55.998807325959206, 51.945359632372856, 54.889536648988724, 52.41261675953865, 48.96557852625847, 45.48984803259373, 40.94417095184326, 39.82961095869541, 41.98467671871185, 45.21875537931919, 49.651753306388855, 54.081643000245094, 51.437372490763664, 49.10364031791687, 42.8338323533535, 42.296472787857056, 39.54692892730236, 42.262411415576935, 41.08631372451782, 40.48586994409561, 40.748572647571564, 39.72572073340416, 42.77315340936184, 45.507399290800095, 55.819688737392426, 55.84377184510231, 52.4356397241354, 50.35286508500576, 53.566250056028366, 39.124330803751945, 45.260974913835526, 54.6316596865654, 57.689697593450546, 56.04434408247471, 53.03258769214153, 53.67655813694, 54.68728110194206, 56.48809567093849, 55.25635376572609, 55.8369892090559, 51.25442370772362, 42.39328779280186, 46.063765436410904, 55.84860518574715, 56.615259647369385, 55.20397737622261, 49.26841087639332, 53.19476678967476, 55.572147220373154, 56.45081587135792, 49.469891265034676, 43.33191342651844, 44.107250422239304, 49.892724975943565, 50.09750738739967, 53.746516183018684, 52.96697661280632, 48.635729625821114, 44.30887520313263, 40.03672644495964, 42.614561319351196, 44.77854140102863, 48.50995257496834, 53.7191728502512, 54.84616197645664, 58.34949038922787, 59.69163917005062, 58.97950418293476, 54.4858805090189, 51.79139569401741, 52.574503272771835, 51.42868995666504, 45.37828601896763, 35.18048822879791, 25.478419438004494, 20.837677158415318, 15.043765157461166, 22.968445122241974, 21.757206916809082, 22.123208977282047, 16.580581292510033, 10.153866447508335, 4.451260697096586, 1.6393740568310022, 0.5235962884034961, 0.37062501709442586, 5.405828850343823, 28.977138698101044, 51.1224339902401, 35.90412139892578, 29.97007481753826, 41.3931168615818, 53.73919777572155, 67.27717593312263, 45.49459017813206, 12.062045205384493, 0.45424796117004007, 0.12582373194163665, 0.13282387662911788, 0.11913796843145974, 0.23340452404227108, 0.12605660303961486, 0.08939191771787591, 0.07399315494694747, 0.15127231716178358, 0.13286162225995213, 0.20887893304461613, 0.12022672133753076, 0.11886836102348752, 0.1001169387018308, 0.14913136954419315, 0.14533399284118786, 0.1370632616453804, 0.06889093419886194, 0.09698535010102205, 0.17657648044405505, 0.20805684122024104, 0.16924774245126173], [0.05830731832247693, 0.08981689374195412, 0.03705863215145655, 0.051100745258736424, 0.06323708992567845, 0.01007403501716908, 0.09625767430406995, 0.03874547444866039, 0.027883376933459658, 0.0551259946951177, 0.052011197185493074, 0.09877551419776864, 0.029377778482739814, 0.03006723924045218, 0.012524257836048491, 0.037538508549914695, 0.06566316325915977, 0.030652793757326435, 0.03800155674980488, 0.005181571641514893, 0.012926723593409406, 0.07637054339284077, 4.4467859622091055, 31.693696528673172, 46.99743613600731, 43.92272092401981, 31.771157272160053, 26.3830653950572, 27.089388594031334, 36.25202693045139, 18.54844819754362, 3.2186429388821125, 0.19016526377527043, 0.09189920427161269, 0.39623038843274117, 2.0401843870058656, 6.222360385581851, 13.743471130728722, 16.76865980029106, 12.02658075839281, 10.400533061474562, 8.793530892580748, 11.146382689476013, 30.449671782553196, 36.9504826515913, 49.18334484100342, 52.46349982917309, 57.265970930457115, 51.988388523459435, 53.258287981152534, 53.658775091171265, 56.35708250105381, 53.75350020825863, 53.05700518190861, 52.08364941179752, 51.45234368741512, 50.248697474598885, 52.054314985871315, 53.133844658732414, 51.65096662938595, 49.38599556684494, 48.4797327965498, 49.41078543663025, 49.007456079125404, 45.75475461781025, 40.086397379636765, 36.94202810525894, 35.86165867745876, 38.5773691534996, 42.3051743209362, 42.10926063358784, 39.8981136828661, 37.45606452226639, 37.4466410279274, 37.51401901245117, 37.138925939798355, 37.55507580935955, 37.09921807050705, 37.00448915362358, 37.584467232227325, 36.49716317653656, 42.22279094159603, 50.16240410506725, 47.42645971477032, 50.13470359146595, 45.03160022199154, 52.12206915020943, 34.78367932140827, 42.456896379590034, 55.774231776595116, 48.44894304871559, 48.0180499702692, 43.45717750489712, 42.118801921606064, 44.31617461144924, 47.642861902713776, 50.17667233943939, 49.84484754502773, 46.0340890288353, 38.05200934410095, 36.72179572284222, 44.67102997004986, 50.003371238708496, 55.25414988398552, 48.652099147439, 48.289697393774986, 53.706967905163765, 50.20056165754795, 47.92468138039112, 46.770174130797386, 48.40714529156685, 51.90400645136833, 51.01740762591362, 52.090458646416664, 52.07664638757706, 50.16136676073074, 48.728934824466705, 45.23715399205685, 41.32506251335144, 44.108770340681076, 49.57382328808308, 50.35759203135967, 51.503523141145706, 50.91876491904259, 50.37477470934391, 49.28568474948406, 51.48111194372177, 51.31613239645958, 50.75450353324413, 48.564643040299416, 44.70319524407387, 34.333965852856636, 22.84715563058853, 16.166067235171795, 18.035962097346783, 10.792406983673573, 6.969667710363865, 1.0715406015515327, 8.44747681170702, 5.375277064740658, 1.635621995665133, 0.36565509159117937, 0.2696253976318985, 0.02984290840686299, 1.7495243274606764, 17.882799915969372, 37.30294033885002, 33.959701135754585, 24.533159360289574, 25.75756575912237, 37.912218645215034, 52.73931942880154, 36.79566755890846, 10.611907169222832, 0.20232898998074234, 0.020451139025681186, 0.06055411846318748, 0.06450952438171953, 0.06507321522803977, 0.05128479788254481, 0.02441254891891731, 0.06403193750884384, 0.06046342430636287, 0.051411178210400976, 0.018389113247394562, 0.03898441260389518, 0.03146170318359509, 0.018237466501886956, 0.015152495907386765, 0.020985220035072416, 0.011751734982681228, 0.023515004795626737, 0.06913976147188805, 0.043250930539215915, 0.014450966900767526, 0.0414714162616292, 0.021604520006803796, 0.025337396655231714, 0.04866584778937977, 0.003978142540290719, 0.03552922164089978, 0.021822538874403108, 0.03777945050387643, 0.03092465914960485, 0.03240905098209623, 0.02215135667938739, 0.06902584922499955, 0.024095262233458925, 0.011994673313893145, 0.027572825238166843, 0.08912056626286358, 0.0973341372446157, 0.025001571120810695, 0.024400828551733866, 0.043048647057730705, 0.03594249770685565, 0.03208209040167276, 0.015510833563894266, 6.583353839814663, 38.3587820827961, 53.98113839328289, 49.01282139122486, 34.80815000832081, 30.586506240069866, 30.43213002383709, 40.281174927949905, 21.54267232865095, 3.7332733115181327, 0.17333764408249408, 0.06911174539709464, 1.312377497088164, 5.2543143555521965, 11.030459459871054, 13.178230561316013, 11.410435270518064, 7.745221769437194, 6.859969021752477, 10.079509187489748, 12.659845277667046, 28.98488838225603, 39.0490036457777, 49.765940979123116, 55.67420594394207, 57.97871008515358, 55.7731868326664, 54.30602476000786, 54.99071761965752, 58.21848101913929, 54.03145909309387, 52.59663328528404, 53.540548235177994, 50.15692479908466, 51.50596261024475, 53.62071253359318, 54.63829033076763, 53.34273844957352, 53.01727831363678, 51.31917603313923, 51.6697034239769, 51.33692488074303, 46.954240053892136, 40.71621738374233, 37.66939267516136, 38.220017328858376, 41.02055445313454, 44.87504482269287, 45.080731585621834, 42.108143493533134, 39.02900151908398, 38.51489670574665, 38.30726444721222, 39.48802828788757, 40.04678450524807, 39.28245171904564, 38.59513700008392, 39.12628389894962, 39.195580780506134, 44.2096359282732, 51.71114020049572, 51.30595654249191, 51.77428901195526, 46.12085737287998, 52.006695941090584, 37.32314005494118, 43.30749973654747, 55.14104135334492, 51.308540403842926, 50.27188383042812, 46.29219777882099, 45.064149275422096, 47.47158609330654, 50.63607908785343, 52.81708985567093, 52.48141206800938, 48.80035199224949, 39.62382920086384, 39.11130890250206, 46.82376645505428, 52.79816687107086, 56.5891170501709, 49.96917687356472, 50.27329735457897, 55.02141237258911, 53.74429330229759, 50.33040449023247, 48.02426263689995, 50.365286618471146, 52.828002870082855, 53.98827061057091, 53.578451201319695, 54.01524916291237, 53.2231854647398, 51.027100905776024, 46.41926296055317, 42.993978559970856, 44.776014536619186, 50.94912528991699, 53.23257856070995, 55.67128390073776, 54.81050468981266, 52.4997802823782, 49.86698895692825, 52.62447439134121, 51.12576261162758, 51.13495051860809, 50.25726981461048, 45.55049657821655, 34.64005082845688, 21.11230742186308, 14.504749830812216, 15.42209755629301, 8.419281374663115, 10.994009915739298, 10.035423003137112, 7.783737927675247, 5.331606008112431, 1.6230821935459971, 1.2770477053709328, 0.2383348930743523, 0.06495779642136768, 2.205858821980655, 20.4766034334898, 37.06068433821201, 33.32397244870663, 27.71591417491436, 32.99709878861904, 43.50366421043873, 58.476779758930206, 42.597564831376076, 12.180241663008928, 0.14336543128592893, 0.04134208589675836, 0.04423089572810568, 0.0335697885020636, 0.0663277787680272, 0.08032362267840654, 0.00554295117581205, 0.041577135198167525, 0.019191866558685433, 0.020234489420545287, 0.05598719399131369, 0.06866607087431476, 0.04510953920544125, 0.06795628825784661, 0.018212944087281357, 0.026229881186736748, 0.02919661652413197, 0.020969315810361877, 0.07133077437174506, 0.03872604502248578, 0.010038774653367, 0.06007718839100562, 0.10252171239699237, 0.22036966489395127, 0.1283572311513126, 0.14977359445765615, 0.11858384386869147, 0.1005049335071817, 0.24129431083565578, 0.16927180287893862, 0.1756558462511748, 0.13490113313309848, 0.2554208692163229, 0.25672571326140314, 0.14899368630722165, 0.17685744271147996, 0.2036815244355239, 0.2009047195315361, 0.14507113897707313, 0.1278271447517909, 0.13975271576782688, 0.1172294985735789, 0.21536361164180562, 0.13060933764791116, 9.760454557836056, 47.48141996562481, 62.45782233774662, 57.80728608369827, 42.864971682429314, 37.59710535407066, 37.82511591911316, 48.60487148165703, 25.377532951533794, 4.307060334831476, 0.390916729811579, 0.3469003370264545, 0.9845679590944201, 4.67509813606739, 12.00187923386693, 22.921310551464558, 28.575716838240623, 19.944588281214237, 17.377843111753464, 15.700680557638407, 16.3388192653656, 32.8479377925396, 39.88267511129379, 54.80923555791378, 57.52547800540924, 61.256759986281395, 56.803459748625755, 57.764120399951935, 56.26166582107544, 58.67413356900215, 53.55021871626377, 52.16557301580906, 53.79829220473766, 51.62286713719368, 50.87760932743549, 53.32777105271816, 55.49451358616352, 54.65505503118038, 54.496945515275, 52.41800107061863, 55.03690794110298, 53.770185112953186, 50.98279908299446, 43.67370128631592, 40.11079967021942, 39.61517706513405, 41.84063784778118, 46.880896389484406, 47.50561326742172, 44.188398867845535, 41.0040595382452, 41.00331477820873, 39.751392155885696, 41.320882737636566, 41.10503152012825, 42.014030143618584, 41.419179663062096, 40.598678290843964, 40.20196817815304, 47.35471956431866, 53.38504157960415, 54.17851500213146, 53.17887984216213, 46.78299464285374, 53.4934763610363, 40.31254984438419, 45.80802395939827, 57.15957283973694, 53.94854374229908, 52.035517394542694, 48.145780116319656, 46.72271087765694, 49.91285249590874, 52.80020356178284, 55.71571111679077, 54.86586391925812, 50.94935327768326, 42.812089920043945, 41.473528146743774, 48.08017663657665, 55.8906689286232, 60.02792872488499, 51.0814455896616, 50.585754588246346, 56.86557501554489, 56.446301713585854, 53.02560746669769, 51.03535786271095, 53.28144393861294, 56.66556894779205, 56.52392014861107, 55.294990092515945, 55.83040416240692, 56.8013546615839, 53.09614688158035, 50.27811549603939, 45.54101228713989, 47.636550441384315, 53.40731218457222, 54.65075746178627, 56.26940220594406, 56.4249012619257, 53.15601646900177, 51.79418474435806, 54.40840266644955, 51.46882340312004, 51.88290998339653, 50.37342578172684, 48.86881671845913, 36.2315384298563, 25.010592341423035, 20.24611160159111, 24.377348721027374, 17.334272749722004, 17.21951700747013, 12.27216063067317, 13.674217946827412, 13.569657057523727, 4.139474127441645, 1.247727528680116, 0.6407353933900595, 0.2955283405026421, 2.551526273600757, 24.641869626939297, 48.52886036038399, 46.046521961688995, 34.25059832632542, 40.149124413728714, 49.26507845520973, 65.78132539987564, 51.057518273591995, 16.253819726407528, 0.6385433266405016, 0.12678450148086995, 0.22018849180312827, 0.21407267544418573, 0.191814805730246, 0.20421015622559935, 0.07768746218062006, 0.17787040007533506, 0.1940587189164944, 0.1725977673777379, 0.11271433890215121, 0.19030768191441894, 0.17753034800989553, 0.1458537337020971, 0.13338410906726494, 0.10793417313834652, 0.10700389844714664, 0.1571121287997812, 0.21982724400004372, 0.16228182561462745, 0.19247092364821583, 0.1096991338999942], [0.08134974574204534, 0.047337618671008386, 0.017244391274289228, 0.026617965049808845, 0.01086970638425555, 0.04488740327360574, 0.07456544728484005, 0.04257348700775765, 0.019226189033361152, 0.021719577016483527, 0.060524495638674125, 0.03463792825641576, 0.024513163734809496, 0.031151496586971916, 0.031584532334818505, 0.0631483290635515, 0.009725887048261939, 0.044195235532242805, 0.007928551949589746, 0.05379955044190865, 0.03526087217323948, 0.03126838484604377, 8.862362299114466, 35.345201790332794, 49.73870404064655, 40.19989348948002, 21.994285695254803, 9.743350725620985, 29.3587389215827, 40.77543720602989, 21.00090879946947, 2.222325000911951, 0.13127455429639667, 0.02022290263994364, 2.320534293539822, 10.215047914534807, 14.931198097765446, 10.924588590860367, 8.9491942897439, 6.758558163419366, 5.749773569405079, 9.87280597910285, 16.07526160776615, 29.608224034309387, 45.13203643262386, 51.08703888952732, 53.84609743952751, 49.18277107179165, 50.72027876973152, 51.275223791599274, 50.8200766146183, 52.20707058906555, 52.327717915177345, 53.15290063619614, 54.70941871404648, 54.0221381932497, 51.55174255371094, 50.96492484211922, 50.31227186322212, 51.065064668655396, 50.85684344172478, 51.48057997226715, 52.842590287327766, 52.30246067047119, 50.20365089178085, 49.109963178634644, 43.9618968218565, 39.13830645382404, 35.53603895008564, 35.69659933447838, 38.157503083348274, 36.63447640836239, 37.80477561056614, 39.68158230185509, 36.034055426716805, 36.048753038048744, 37.255017310380936, 37.16918371617794, 38.264642134308815, 37.78229981660843, 36.17608420550823, 39.77108649909496, 49.536418095231056, 50.851523727178574, 48.7360480427742, 46.68880149722099, 51.08122140169144, 35.74691243469715, 40.67714028060436, 53.315554708242416, 47.58820943534374, 48.96542273461819, 41.87884479761124, 38.20039138197899, 34.5060396194458, 38.608094304800034, 40.51019623875618, 42.84570291638374, 39.18034739792347, 38.13925266265869, 35.21972492337227, 38.02726127207279, 46.86656355857849, 50.942851826548576, 52.347028478980064, 48.3857486397028, 50.23345269262791, 53.57066161930561, 49.75840598344803, 50.838680416345596, 52.48927764594555, 52.69548498094082, 53.32467041909695, 49.88594613969326, 51.780064702034, 53.63851077854633, 50.64772166311741, 49.79074224829674, 48.72874863445759, 50.44690243899822, 49.64624360203743, 53.09173911809921, 52.175490483641624, 50.227361619472504, 48.31144742667675, 53.394446074962616, 54.56041730940342, 53.63615870475769, 51.73214167356491, 52.01321259140968, 46.64791189134121, 38.1799902766943, 26.15557160228491, 22.31843490153551, 15.542083717882633, 11.750891301780939, 6.6837905254215, 10.956077501177788, 6.844318611547351, 1.159795259591192, 1.6113555477932096, 0.9866876516025513, 0.8251135528553277, 0.11334407347021624, 0.7680779008660465, 13.23167184367776, 35.62275029718876, 27.964418940246105, 22.912278436124325, 27.85233825445175, 40.916869416832924, 47.479812651872635, 40.70866338908672, 15.461091063916683, 0.9954176831524819, 0.05773210563347675, 0.03302709672425408, 0.053847259405301884, 0.0608290804666467, 0.01002422948658932, 0.05571108165895566, 0.008777109687798657, 0.026807416797964834, 0.05535479140235111, 0.02978720651299227, 0.04254585313901771, 0.01024876441078959, 0.043075661233160645, 0.056948408819152974, 0.045630875683855265, 0.05204914319620002, 0.034416964917909354, 0.00998140199953923, 0.018767217079584952, 0.015611319431627635, 0.05913856082770508, 0.09174943887046538, 0.042630643511074595, 0.02407573447271716, 0.052240862205508165, 0.026204375426459592, 0.027046191680710763, 0.027292454833514057, 0.030809193958702963, 0.015776109612488654, 0.03253453331126366, 0.08135787225910462, 0.032230490251095034, 0.007109266834959271, 0.03813053830526769, 0.01991267934499774, 0.010857386732823215, 0.052428662675083615, 0.03406332412851043, 0.04973830684321001, 0.007458709851562162, 0.048329098281101324, 0.08443839367828332, 10.606248322874308, 43.02228324115276, 55.606242790818214, 46.06517516076565, 29.390782602131367, 15.963184721767902, 30.865346677601337, 41.37129843235016, 21.280607990920544, 2.71221490111202, 0.20261207479052246, 0.24406173499301076, 1.4672753540799022, 9.195200689136982, 12.772912010550499, 17.121790051460266, 14.859081767499447, 9.461700338870287, 10.286668371409178, 8.732476718723774, 15.251792594790459, 32.439113929867744, 44.507034569978714, 54.278658628463745, 55.76629400253296, 52.2572772949934, 52.30282545089722, 52.469723895192146, 53.768915981054306, 54.76422697305679, 53.924897611141205, 55.37088721990585, 54.20954413712025, 54.0917656570673, 51.80684566497803, 50.38913033902645, 49.89726573228836, 52.53074862062931, 53.26006628572941, 52.96733759343624, 55.83634324371815, 54.60307002067566, 51.72952741384506, 50.82195371389389, 45.73037892580032, 40.533637180924416, 37.821004539728165, 36.9876142591238, 39.905743673443794, 40.06663843989372, 40.01124881207943, 41.15557260811329, 37.79212608933449, 37.92369782924652, 39.10262256860733, 38.45891430974007, 40.9182221442461, 39.61832709610462, 37.6587038487196, 41.98178507387638, 51.091492250561714, 53.81604865193367, 51.33111119270325, 46.49525128304958, 50.553786903619766, 37.6560477912426, 41.80024601519108, 53.28659266233444, 49.22227755188942, 50.75620964169502, 42.37432301044464, 39.31009903550148, 37.431039065122604, 41.059338971972466, 43.06019000709057, 45.80337680876255, 41.18483483791351, 40.03385379910469, 37.60516472160816, 39.60434004664421, 49.65304143726826, 53.50421838462353, 54.650700464844704, 49.26262378692627, 52.52855233848095, 56.4017529040575, 52.681041955947876, 52.0697345584631, 53.70027266442776, 55.78743226826191, 54.6005317568779, 50.41356302797794, 54.323439225554466, 54.09377954900265, 54.445446878671646, 51.44005514681339, 50.37821352481842, 52.57063888013363, 52.376484498381615, 54.39517557621002, 53.912069499492645, 49.79691691696644, 49.60551738739014, 51.62592217326164, 53.94587628543377, 53.77643197774887, 53.55354353785515, 51.29195809364319, 50.74199080467224, 34.1886692494154, 23.042662739753723, 16.011662520468235, 15.302098095417023, 8.470571022480726, 16.745538040995598, 9.818378649652004, 9.537642113864422, 5.982063179835677, 3.0352621665224433, 2.789429370313883, 0.17374598857713863, 0.12135003606090322, 1.0194138111546636, 16.271412782371044, 38.86387757956982, 31.7423852160573, 23.933627530932426, 33.147509917616844, 43.47648806869984, 54.517004638910294, 46.402828842401505, 18.748055286705494, 1.25017661601305, 0.05306087972712703, 0.044456367613747716, 0.006170416163513437, 0.07262119848746806, 0.02855386283044936, 0.02680664496438112, 0.006585014180018334, 0.03194886005076114, 0.047991977698984556, 0.022340724935929757, 0.0344643176504178, 0.019318311824463308, 0.026513774937484413, 0.06818809066317044, 0.029568723803095054, 0.02929457445134176, 0.04040011866891291, 0.008747409865463851, 0.00825411822006572, 0.02623473668791121, 0.08852820625179447, 0.3473491285694763, 0.11895663948962465, 0.1452257580240257, 0.10709402486099862, 0.12968457711394876, 0.1440091701806523, 0.19917870667995885, 0.17182286130264401, 0.1487481690128334, 0.05831312562804669, 0.1416540684294887, 0.1857763805310242, 0.15741257986519486, 0.07774094134219922, 0.11621184341493063, 0.11356288829119876, 0.20211290626320988, 0.13482620590366423, 0.12406973270117305, 0.1230788319662679, 0.15018038044217974, 0.386523007764481, 14.43338681012392, 51.00324958562851, 64.1134124994278, 52.68682524561882, 32.78783641755581, 17.83281359821558, 39.262502789497375, 50.7170869410038, 26.711797155439854, 3.304663198068738, 0.42234938533511013, 0.3262151079252362, 3.663132875226438, 15.981849320232868, 25.966398753225803, 19.92754239588976, 17.33931887894869, 16.368795856833458, 12.575538251549006, 16.68441452085972, 20.79543672502041, 32.346854880452156, 48.51620323956013, 58.719104155898094, 58.775580525398254, 53.67075204849243, 56.496193036437035, 56.091058775782585, 56.328120455145836, 57.50508829951286, 56.35185398161411, 56.227334663271904, 55.32476529479027, 53.9659658074379, 51.241379007697105, 51.10762618482113, 50.081574842333794, 52.768095284700394, 52.525109723210335, 54.612782299518585, 58.33727024495602, 56.48014649748802, 54.18923422694206, 52.844003811478615, 46.7501188069582, 44.41925548017025, 39.52550947666168, 38.75359229743481, 42.59061120450497, 41.036699786782265, 40.89682549238205, 44.033025205135345, 38.68088699877262, 40.677014887332916, 41.24432444572449, 39.783838614821434, 43.59379917383194, 41.88402011990547, 40.13889916241169, 44.600650146603584, 53.05079251527786, 57.02565662562847, 51.37950539588928, 49.80410233139992, 52.24631108343601, 42.56360985338688, 43.1335374712944, 55.014040768146515, 52.233338579535484, 53.71596202254295, 44.921542927622795, 42.849495112895966, 38.90417821705341, 42.672253623604774, 45.13010233640671, 46.83517724275589, 43.34342680871487, 41.655409187078476, 38.236455246806145, 42.64828830957413, 52.1740997582674, 55.35370834171772, 55.60491286218166, 50.63623867928982, 53.30733574926853, 58.42667564749718, 54.73559930920601, 55.09990096092224, 56.46261803805828, 57.63669043779373, 55.38485907018185, 51.24590836465359, 54.376982152462006, 54.955326318740845, 57.00159631669521, 54.08172659575939, 53.05338017642498, 55.86508870124817, 55.05701646208763, 57.71300554275513, 55.44922761619091, 50.53838633000851, 50.033040046691895, 53.57724666595459, 53.70280712842941, 54.19493392109871, 53.15032057464123, 53.67371208965778, 50.34260183572769, 42.253500893712044, 30.25911010801792, 26.345947086811066, 22.388170659542084, 20.634142979979515, 20.31701009720564, 17.961032018065453, 16.5879699960351, 8.218143917620182, 6.030116826295853, 2.737022819928825, 1.4976305002346635, 0.3144878684543073, 1.4472115994431078, 17.835321463644505, 46.71619802713394, 40.66969648003578, 34.85695838928223, 41.62225976586342, 52.908524349331856, 60.722276866436005, 52.66123741865158, 22.939747162163258, 2.0153498696163297, 0.22950100537855178, 0.09340845805127174, 0.17891657596919686, 0.14290164835983887, 0.09370277155539952, 0.13092464650981128, 0.13039948797086254, 0.09049404412508011, 0.2370812720619142, 0.09745469913468696, 0.15259100968251005, 0.19152094493620098, 0.11801698405179195, 0.17384595586918294, 0.12795366608770564, 0.20156762067927048, 0.11338221243931912, 0.08635714228148572, 0.12294792453758419, 0.11886130319908261, 0.23953577707288787], [0.05562499994994141, 0.013834881356160622, 0.1315898631582968, 0.08542093783034943, 0.04336482052167412, 0.02963664330309257, 0.0931631114508491, 0.07420683410600759, 0.06189932792040054, 0.024233129151980393, 0.04037399135995656, 0.03651108672784176, 0.03973187776864506, 0.014620315723732347, 0.08762879006098956, 0.03930296465114225, 0.10541387673583813, 0.03730571908818092, 0.00768343124036619, 0.011192951587872813, 0.03880206691974308, 0.04356198318419047, 9.10845609381795, 39.01545524597168, 47.71986477077007, 37.992816120386124, 20.36463674157858, 25.72840042412281, 44.0483345836401, 46.05195187032223, 18.10360226780176, 1.5765775577165186, 0.06744036945747212, 0.0252945969987195, 1.3893000944517553, 5.616538468748331, 9.926968272775412, 14.247572030872107, 9.196062292903662, 5.167595883831382, 6.216387581080198, 7.718181470409036, 18.02021574229002, 33.75160150229931, 47.91687659919262, 51.10702961683273, 51.63251481950283, 50.40225863456726, 49.0134559571743, 46.14569664001465, 47.63820715248585, 48.792364820837975, 49.28204074501991, 52.197958678007126, 55.00039950013161, 52.53903217613697, 53.03683966398239, 52.111570313572884, 53.345755487680435, 52.60718151926994, 50.97364157438278, 49.64172564446926, 51.30075842142105, 51.848107650876045, 51.34583920240402, 48.55577811598778, 49.81247328221798, 45.43788582086563, 36.4148785918951, 35.1071597635746, 35.87606370449066, 35.33842675387859, 35.32364174723625, 36.23400829732418, 39.50710326433182, 39.239168241620064, 38.96332584321499, 40.80764427781105, 43.073333501815796, 38.27506497502327, 37.22140431404114, 38.12057286500931, 46.17816589772701, 47.711607813835144, 50.28831794857979, 44.57907870411873, 52.1643228828907, 36.37283004820347, 40.481412783265114, 54.45035621523857, 50.50461374223232, 49.98544380068779, 44.67914253473282, 44.4274478405714, 39.04913283884525, 37.07651428878307, 36.74868308007717, 37.20443442463875, 37.2307214140892, 36.79454281926155, 36.65673941373825, 35.46528294682503, 42.920273914933205, 50.74946880340576, 51.97834946215153, 49.16173540055752, 52.55379818379879, 51.323750987648964, 51.988012343645096, 49.60627354681492, 51.09287157654762, 50.18220864236355, 49.51684154570103, 51.68731167912483, 49.96349237859249, 50.191673934459686, 51.625306606292725, 50.87621480226517, 52.323815524578094, 50.238844603300095, 53.59908029437065, 51.24898999929428, 50.80243036150932, 50.86683310568333, 52.00034648180008, 49.07336734235287, 52.08861954510212, 53.43187026679516, 58.127209916710854, 54.80141557753086, 54.254149943590164, 44.75710675120354, 25.29815711081028, 18.702503331005573, 20.50855401903391, 1.4838747633621097, 15.214956421405077, 10.271092057228088, 6.800583433359861, 4.871635464951396, 1.98860369855538, 2.9410450346767902, 0.04577072599204257, 0.1355554402107373, 0.36334757634904236, 10.693551488220692, 38.47453907132149, 42.798824831843376, 43.64442005753517, 44.36097040772438, 41.1613254994154, 47.705220356583595, 39.06433962285519, 17.01934564858675, 0.6897226022556424, 0.04050662799272686, 0.0027728559825845878, 0.05231958180957008, 0.056000686236075126, 0.029135931108612567, 0.0727477420878131, 0.04478716138692107, 0.04662787316192407, 0.037101246271049604, 0.03432409997913055, 0.03494664684694726, 0.028297257849771995, 0.03597029855882283, 0.05154713595402427, 0.042553801540634595, 0.016325315591529943, 0.021016731625422835, 0.007377366755463299, 0.05442915513413027, 0.067721205559792, 0.023448658648703713, 0.1143710722681135, 0.0716183937038295, 0.18907773541286588, 0.036542056550388224, 0.03016180740814889, 0.030536588274117094, 0.0322602652158821, 0.023403834784403443, 0.08712573267985135, 0.03196353602106683, 0.07957724476000294, 0.043587145701167174, 0.051664046477526426, 0.0782225358125288, 0.06707846114295535, 0.026476982966414653, 0.045653114138985984, 0.021717174313380383, 0.013075129936623853, 0.029706778113904875, 0.16644318122416735, 0.06797348381951451, 11.395281683653593, 47.133229449391365, 54.68040347099304, 44.886983782052994, 23.69571089744568, 22.174819707870483, 37.248869240283966, 48.61532472074032, 19.992425814270973, 1.7326457519084215, 0.043980239061056636, 0.0070400239928858355, 1.7592110764235258, 6.2603578716516495, 9.960756059736013, 13.926090281456709, 9.300455041229725, 9.30843936279416, 10.932808499783278, 8.525786809623241, 19.613859727978706, 36.301317885518074, 49.299227222800255, 53.405780866742134, 55.90818978846073, 50.23608595132828, 51.7937895655632, 48.16816471517086, 49.56474557518959, 51.156552359461784, 52.94134698808193, 52.65640787780285, 57.495752200484276, 53.05563345551491, 54.31456670165062, 53.10280032455921, 53.50372061133385, 52.547946497797966, 51.50696575641632, 50.158513113856316, 51.86008840799332, 53.34790997207165, 53.15627485513687, 52.36440494656563, 52.10149705410004, 47.28951506316662, 39.099780321121216, 36.196033135056496, 37.804308235645294, 36.90835811197758, 37.708857357501984, 37.89232671260834, 40.94531089067459, 40.401810854673386, 41.89251646399498, 42.588817700743675, 44.35988746583462, 40.04196636378765, 39.30168628692627, 39.28640350699425, 48.72692473232746, 50.745680406689644, 51.901206001639366, 47.4331359565258, 52.692874521017075, 38.19007873535156, 42.24746681749821, 55.71601130068302, 52.17870131134987, 51.661674454808235, 46.450523883104324, 46.23525023460388, 40.197917595505714, 38.56564298272133, 38.50904881954193, 39.50296528637409, 39.24324922263622, 37.417439594864845, 38.01201269030571, 37.462904155254364, 44.93470922112465, 51.48652285337448, 54.41958166658878, 50.164790377020836, 53.203141540288925, 54.71144400537014, 53.892192766070366, 52.85884581506252, 53.474872559309006, 51.425703316926956, 49.357846677303314, 52.59263589978218, 50.44596768915653, 51.063065975904465, 54.29012641310692, 54.48146514594555, 55.07777854800224, 53.740900084376335, 54.996504709124565, 52.26828150451183, 51.79845571517944, 52.02024221420288, 51.230891570448875, 50.7602184265852, 53.16428102552891, 53.67682032287121, 59.54373590648174, 56.2813563644886, 55.044131353497505, 46.241641491651535, 25.464776270091534, 16.12316183745861, 14.54708905890584, 9.201233815401793, 10.768408421427011, 13.571933135390282, 9.164801370352507, 9.022465758025646, 6.439121179282665, 1.6502195061184466, 0.06520372931845486, 0.14178140612784773, 0.6556136137805879, 11.079863458871841, 41.56216599047184, 40.41851855814457, 40.162811279296875, 48.344680443406105, 49.90135431289673, 53.18325720727444, 45.91152660548687, 21.292873732745647, 1.434543791692704, 0.05029112893680576, 0.04964884094079025, 0.0962697045179084, 0.06992820432060398, 0.01908349629957229, 0.049549074028618634, 0.07704028714215383, 0.048784446698846295, 0.02526075506466441, 0.02431188586342614, 0.02672227576113073, 0.054726155212847516, 0.03164881345583126, 0.0765619135927409, 0.03416501320316456, 0.01826797248213552, 0.06501207710243762, 0.06762874880223535, 0.0370294731692411, 0.06372638046741486, 0.04164044039498549, 0.20942450064467266, 0.1397670540609397, 0.4130620899377391, 0.18829358217772096, 0.16750115726608783, 0.159323328116443, 0.07897092495113611, 0.10633065176079981, 0.18783239676849917, 0.15600978716975078, 0.19749973114812747, 0.11592333350563422, 0.18635671032825485, 0.16665306058712304, 0.225890664733015, 0.11800965905422345, 0.14874235057504848, 0.08586533585912548, 0.11627914136624895, 0.11831439973320812, 0.21462510048877448, 0.3313609817996621, 15.495764203369617, 54.02737431228161, 62.38498404622078, 50.780144557356834, 30.37440162152052, 37.03380458056927, 54.67850737273693, 56.843779385089874, 21.803155951201916, 2.4923275876790285, 0.1729624142171815, 0.22997219493845478, 2.654375354759395, 10.253271013498306, 18.752010874450207, 25.529346205294132, 18.605851717293262, 10.288300383836031, 11.682331580668688, 16.649150513112545, 21.94335512816906, 35.74629306793213, 51.986606419086456, 55.491789132356644, 58.227163553237915, 53.414999172091484, 52.774904519319534, 50.950181633234024, 51.3850113004446, 54.46216598153114, 55.359750017523766, 56.090758591890335, 60.79994849860668, 55.4177501052618, 54.46123883128166, 53.416492491960526, 54.13928970694542, 53.861399218440056, 51.16829752922058, 50.19224390387535, 51.160686537623405, 53.76518078148365, 54.092825800180435, 53.550659492611885, 54.423750042915344, 50.236579924821854, 40.440697968006134, 37.757213562726974, 39.96162727475166, 39.063488468527794, 39.47320148348808, 40.17265275120735, 43.063488230109215, 43.629331067204475, 43.11215601861477, 46.20608299970627, 48.99255707859993, 42.08374880254269, 41.525022983551025, 41.91978760063648, 51.041559129953384, 52.93459095060825, 53.73119160532951, 49.60644073784351, 53.04574638605118, 42.00155921280384, 44.260480999946594, 55.97544997930527, 54.59096387028694, 53.99201720952988, 50.52889063954353, 49.04098927974701, 42.6757076382637, 39.917492642998695, 40.396399945020676, 41.68999493122101, 41.502520591020584, 38.92177887260914, 40.62293238937855, 39.3799164891243, 47.38938130438328, 54.060755521059036, 56.21246226131916, 50.6619480997324, 54.53192263841629, 55.341347604990005, 55.89034974575043, 54.55201596021652, 53.46256501972675, 51.05907239019871, 50.06092295050621, 52.420869916677475, 50.29426082968712, 52.424703910946846, 55.38906164467335, 56.210288777947426, 57.82378099858761, 54.450436010956764, 57.51851297914982, 54.05606657266617, 52.53995552659035, 52.948004230856895, 51.539366617798805, 50.24256460368633, 55.56029565632343, 55.484303534030914, 62.6287941634655, 58.840177059173584, 57.873136550188065, 47.542429491877556, 29.797140397131443, 21.46343518048525, 25.353035666048527, 10.786661691963673, 25.33208169043064, 18.44213180243969, 17.77030125260353, 9.623280018568039, 6.406641472131014, 6.245114989578724, 0.16738374950364232, 0.2779488213127479, 0.8478780719451606, 13.737683091312647, 48.153531700372696, 57.80894659459591, 53.227281644940376, 58.1792177259922, 54.60114732384682, 60.19736923277378, 53.881180956959724, 25.94100471585989, 2.9942331556230783, 0.12454060313757509, 0.11692081709043123, 0.16712712968001142, 0.13979242066852748, 0.16586509271292016, 0.2058186722570099, 0.2383958679274656, 0.11008430854417384, 0.1533273686072789, 0.10585450465441681, 0.14000918716192245, 0.22487821202958003, 0.15638152894098312, 0.15304290340282023, 0.13831024785758927, 0.09139890025835484, 0.18187798268627375, 0.10728739885962568, 0.134452712663915, 0.14456322795012966, 0.22270668792771176], [0.010309146473446162, 0.05671889222867321, 0.02602009459224064, 0.051698597162612714, 0.04025823487609159, 0.014005205175635638, 0.034430301311658695, 0.006596303637707024, 0.016553307068534195, 0.0515967930550687, 0.03208618705684785, 0.038766595971537754, 0.04737262206617743, 0.04088788038643543, 0.06720007688272744, 0.034358049524598755, 0.0064462205045856535, 0.04357848112704232, 0.04504187389102299, 0.01886980600829702, 0.04171295564447064, 0.013555024888773914, 6.852987846359611, 36.88962511718273, 48.84754925966263, 44.37294356524944, 25.46043500304222, 38.389024659991264, 52.443482503294945, 43.60269449651241, 13.612765744328499, 1.010318761691451, 0.3897920495364815, 1.7676383117213845, 5.1350202318280935, 14.241299517452717, 12.776567414402962, 17.516459673643112, 16.071319319307804, 9.618361182510853, 17.200611121952534, 6.213381942361593, 18.8392161950469, 38.82943242788315, 50.60822278261185, 45.83996884524822, 53.21867510676384, 47.41225987672806, 48.808665946125984, 45.164330899715424, 43.80078926682472, 42.05538712441921, 47.15154446661472, 47.70858697593212, 50.177850276231766, 51.17785781621933, 52.46845856308937, 54.62956219911575, 52.91752986609936, 53.63903895020485, 53.161936551332474, 52.69132800400257, 53.13227154314518, 48.25323835015297, 50.92173255980015, 51.793132200837135, 52.58755177259445, 48.21024365723133, 40.62924765050411, 33.63023601472378, 33.83328191936016, 35.12034885585308, 42.56163775920868, 44.51072037220001, 46.574803814291954, 46.898911222815514, 49.55290541052818, 47.90244497358799, 45.273400247097015, 39.703773111104965, 40.475017726421356, 35.74569270014763, 44.324674755334854, 48.5064909607172, 50.635763704776764, 44.699916020035744, 52.94142298400402, 34.652738347649574, 40.124292746186256, 51.45784579217434, 50.046126544475555, 52.396927401423454, 50.31970426440239, 49.97997969388962, 48.589725494384766, 43.77008691430092, 39.80723015964031, 37.79657185077667, 37.48665668070316, 37.996479123830795, 37.47919388115406, 35.17487592995167, 40.49335554242134, 47.28934787213802, 51.43317751586437, 51.97239898145199, 46.52233622968197, 51.07187010347843, 50.09385958313942, 47.6179276406765, 48.801389336586, 49.5489764213562, 53.470977768301964, 52.05321304500103, 52.51966081559658, 50.10399743914604, 49.79789726436138, 49.166234359145164, 51.71958714723587, 51.41616962850094, 51.46216616034508, 50.01423105597496, 49.2123144865036, 48.78680191934109, 51.14769123494625, 50.4409671574831, 56.38675890862942, 50.984311401844025, 53.16518917679787, 53.21131490170956, 53.80504824221134, 48.16389374434948, 39.35233376920223, 20.9244854003191, 17.602498456835747, 5.47177953645587, 17.119892053306103, 8.786803353577852, 8.503947481513023, 8.838758915662766, 6.769595146179199, 1.816472103819251, 0.03951903352572117, 0.05273331429634709, 0.4068675613962114, 6.308376369997859, 36.56249687075615, 49.96344298124313, 55.22920802235603, 37.17631593346596, 31.831192150712013, 54.17294830083847, 37.432376593351364, 15.706081967800856, 2.551502287387848, 0.0343271427846048, 0.11920099161216058, 0.024876804964151233, 0.052119714018772356, 0.009709234182082582, 0.11549261325853877, 0.019132875095237978, 0.041638247348601, 0.046943998386268504, 0.0347827509540366, 0.03953649997129105, 0.02009662250202382, 0.05803717656817753, 0.0508511238876963, 0.0636291442788206, 0.05110408863401972, 0.05221264575084206, 0.019879618521372322, 0.04769676990690641, 0.07937356975162402, 0.05257654302113224, 0.08076763479039073, 0.016820702876430005, 0.0748562059015967, 0.020870838379778434, 0.05168903458979912, 0.04770536397700198, 0.030845084220345598, 0.10448946501128376, 0.0634956467547454, 0.0495138257247163, 0.011007346947735641, 0.03717674124345649, 0.0532429656595923, 0.04232611805491615, 0.02563702393672429, 0.08562304690713063, 0.0429731780604925, 0.03325532568851486, 0.02351578961679479, 0.03584056372346822, 0.06341775093460456, 0.04347184563812334, 9.469036795198917, 44.726389199495316, 54.06350277364254, 50.103074088692665, 28.167924620211124, 36.966248005628586, 51.95950247347355, 46.52126848697662, 15.334670897573233, 1.1570183211006224, 0.33194514107890427, 1.3741639629006386, 2.984971865080297, 2.8284513764083385, 6.950344797223806, 11.102237608283758, 10.201780926436186, 14.412913508713245, 11.057101730257273, 8.476701993495226, 25.292022339999676, 37.9935646802187, 50.336909741163254, 50.87915204465389, 53.13500739634037, 50.78179366886616, 49.38134841620922, 48.17790739238262, 45.792361199855804, 46.34786859154701, 50.17158821225166, 50.16489677131176, 52.759940922260284, 53.520363718271255, 53.42929020524025, 55.58423437178135, 54.09456230700016, 54.07558232545853, 54.29556392133236, 53.60793001949787, 51.5826652944088, 47.04576954245567, 51.3723161816597, 51.98811113834381, 53.239440992474556, 50.24387553334236, 41.64646826684475, 35.98434269428253, 36.17731153964996, 37.14107662439346, 43.78569647669792, 46.472494304180145, 49.86526004970074, 49.03565056622028, 51.07417277991772, 50.342552438378334, 48.20387899875641, 41.54835753142834, 42.07573123276234, 38.54558385908604, 45.613045021891594, 49.91536796092987, 52.11638085544109, 47.664634734392166, 52.09714248776436, 37.573113441467285, 42.0359967648983, 53.05237703025341, 51.45097576081753, 55.86236044764519, 52.20460072159767, 50.23300811648369, 50.05930423736572, 45.12316390872002, 41.250609308481216, 39.60852362215519, 39.93013456463814, 40.06500832736492, 38.54618802666664, 36.55498847365379, 42.28222735226154, 49.189834892749786, 53.3843158185482, 51.54302582144737, 46.90000556409359, 51.843707486987114, 50.40616862475872, 48.788052052259445, 49.249765276908875, 48.76690998673439, 53.6569169908762, 54.36086341738701, 53.48972216248512, 49.9560371786356, 49.7619853913784, 49.823291301727295, 52.646053433418274, 53.50158892571926, 54.80155996978283, 49.80390474200249, 49.2563047260046, 48.04908290505409, 51.82164587080479, 52.078762874007225, 56.751288548111916, 53.74874286353588, 55.10654680430889, 55.30090257525444, 55.49294427037239, 51.760742738842964, 38.82916644215584, 19.32113293558359, 13.541132938116789, 7.416907036677003, 9.415235482156277, 13.687174301594496, 9.88174594938755, 7.244394393637776, 10.617310479283333, 1.9802232482470572, 0.33121759886853397, 0.07308915228350088, 0.5154312984086573, 8.758377078920603, 40.07559075951576, 53.96692335605621, 60.07919177412987, 44.53288838267326, 38.3806537091732, 60.8310080319643, 44.411978870630264, 19.578812308609486, 2.99474042840302, 0.04145922648604028, 0.015838782128412277, 0.03145624097669497, 0.06764313904568553, 0.05683863775630016, 0.052548345120158046, 0.022901638294570148, 0.031073012614797335, 0.039624247801839374, 0.07496880454709753, 0.04202242009341717, 0.022354424982040655, 0.06351946969516575, 0.04283561727788765, 0.04364844338851981, 0.021845829323865473, 0.04961783030012157, 0.02958054992632242, 0.030637017553090118, 0.04329807918111328, 0.004495395814956282, 0.19995916401967406, 0.08749036467634141, 0.25403741688933223, 0.15528543619439006, 0.12736066040815786, 0.11611069610808045, 0.15321705577662215, 0.2246812015073374, 0.11586141612497158, 0.18072993960231543, 0.1208192297781352, 0.1419389492366463, 0.13246258429717273, 0.11658172239549458, 0.09025175517308526, 0.23759742092806846, 0.09616018578526564, 0.15949650085531175, 0.18326973222428933, 0.13326946209417656, 0.16174508957192302, 0.20971134072169662, 13.191187866032124, 53.22916254401207, 61.06110468506813, 58.1725262850523, 34.52951095998287, 49.69038583338261, 59.717489182949066, 49.23270419239998, 17.05521572381258, 1.6457554581575096, 0.6602100608870387, 3.0015501379966736, 7.477205526083708, 19.610348716378212, 23.834745436906815, 30.410165302455425, 28.505128026008606, 19.101303331553936, 26.286617070436478, 11.205745004117489, 22.51928072422743, 40.74467025697231, 56.556947976350784, 51.07551410794258, 56.489402800798416, 51.95159509778023, 52.04030513763428, 51.15808367729187, 47.89638429880142, 46.93438991904259, 52.82151281833649, 52.56736345589161, 55.74590049684048, 55.686403289437294, 55.538439229130745, 57.95502595603466, 56.02875731885433, 56.202571392059326, 56.03796802461147, 54.56984840333462, 53.58194321393967, 47.552248165011406, 50.59053473174572, 52.50611834228039, 55.865206494927406, 50.908592864871025, 45.27938112616539, 36.94374181330204, 36.794675812125206, 38.88794168829918, 47.027823105454445, 48.41952882707119, 51.20955191552639, 52.485793232917786, 54.18046049773693, 53.74617800116539, 51.76043875515461, 44.66872349381447, 45.63596159219742, 40.878195092082024, 48.007672727108, 53.64366330206394, 54.047642424702644, 48.74524734914303, 54.69022214412689, 39.434451162815094, 45.49892574548721, 51.75121285021305, 54.9553757160902, 56.86726972460747, 54.1565065830946, 54.176330119371414, 55.315638184547424, 48.060455694794655, 43.815730065107346, 41.184052079916, 41.51441015303135, 41.71638071537018, 40.899698138237, 37.94558845460415, 43.73409524559975, 50.87693676352501, 55.330457389354706, 53.17109785974026, 48.45411457121372, 51.221741661429405, 49.436456859111786, 48.80165532231331, 48.4728779643774, 50.140186697244644, 55.5492078512907, 54.53832529485226, 54.04367923736572, 50.499221831560135, 50.25233007967472, 50.54369084537029, 54.555173590779305, 53.501387536525726, 54.16380979120731, 50.59760995209217, 48.65280970931053, 48.33993449807167, 52.99536868929863, 52.857037112116814, 58.85895945131779, 54.81159143149853, 57.958700358867645, 57.54874035716057, 57.62312516570091, 55.890699326992035, 44.29328463971615, 28.43748975545168, 24.53249629586935, 14.368757978081703, 25.747940875589848, 17.85208996385336, 14.111464284360409, 19.234735071659088, 15.528980121016502, 4.912429125979543, 0.5014855717308819, 0.1900800206931308, 0.8046874520368874, 9.812580160796642, 44.65291254222393, 56.98353208601475, 65.52184492349625, 46.60028524696827, 45.09817644953728, 66.92835465073586, 51.80668607354164, 24.25687238574028, 4.465004559606314, 0.103550796629861, 0.17684363876469433, 0.11926898718229495, 0.1404975648620166, 0.1380469635478221, 0.1701188605511561, 0.11180062152561732, 0.18478755780961365, 0.0986383059353102, 0.1350311128771864, 0.16583646065555513, 0.10480047683813609, 0.18120803113561124, 0.14779643883230165, 0.15014069038443267, 0.24166787829017267, 0.20196947880322114, 0.11857616264023818, 0.09920285767293535, 0.14040525653399527, 0.18970565171912313], [0.019199683229089715, 0.04715255301562138, 0.048423877960885875, 0.03561347766662948, 0.11407563812099397, 0.049697136200848036, 0.0871647622261662, 0.06695570991723798, 0.039782592430128716, 0.009693598985904828, 0.0244751843274571, 0.05686328076990321, 0.001992863644773024, 0.001274587148145656, 0.06521369636175223, 0.03315347705211025, 0.027151565518579446, 0.10133507021237165, 0.03989290526078548, 0.08249035992776044, 0.14197357784723863, 0.1198373684019316, 11.891571152955294, 42.24006101489067, 52.51600161194801, 33.869258388876915, 20.895426459610462, 42.38349571824074, 50.56637182831764, 37.307720482349396, 8.12673982232809, 1.1426434549503028, 0.11432908155256882, 7.394379945471883, 43.548201620578766, 46.83225899934769, 9.159791339188814, 4.874076833948493, 2.1400435036048293, 10.2081598341465, 8.70814187452197, 10.012733470648527, 31.893379613757133, 35.462486296892166, 43.864454850554466, 51.62621855735779, 51.37499883770943, 52.31108620762825, 50.05197823047638, 45.496904253959656, 41.75962619483471, 39.48010191321373, 38.23123812675476, 40.44983267784119, 44.67109076678753, 44.88568805158138, 49.3406829982996, 50.756897404789925, 51.730302572250366, 50.26261232793331, 50.34146949648857, 49.77008655667305, 51.9132399559021, 52.749711871147156, 50.62161326408386, 51.47291198372841, 50.28994046151638, 50.49951821565628, 39.69696007668972, 35.345057398080826, 38.58846075832844, 44.10689704120159, 51.14599272608757, 51.232605278491974, 53.37096333503723, 50.58830425143242, 50.41554272174835, 47.14541159570217, 48.553950414061546, 41.77509516477585, 39.67192701995373, 36.060141026973724, 40.33395789563656, 44.21694673597813, 50.336636155843735, 46.886778473854065, 53.32449182868004, 34.1501697152853, 41.42828397452831, 53.80473665893078, 46.53809778392315, 49.01550404727459, 50.24606801569462, 48.73781494796276, 50.50616405904293, 48.55900414288044, 42.18234211206436, 38.519437462091446, 36.98854900896549, 35.84768682718277, 40.86304150521755, 39.68505911529064, 35.161101669073105, 48.08685287833214, 46.8095476180315, 46.691727340221405, 47.548379972577095, 50.950816199183464, 49.5645821839571, 50.448695942759514, 51.60023555159569, 51.448760479688644, 52.19864644110203, 48.955379873514175, 49.05657984316349, 51.604305133223534, 50.57482637465, 48.29753637313843, 48.27644370496273, 49.84360121190548, 48.96468177437782, 46.4592482149601, 48.53693872690201, 48.51356238126755, 52.10535764694214, 53.88589270412922, 52.02643968164921, 49.085568487644196, 51.98509030044079, 51.555055975914, 55.5000688880682, 52.19336472451687, 34.72489267587662, 21.49877328425646, 12.9061708599329, 10.1756383292377, 3.2979499083012342, 15.148757323622704, 7.771036634221673, 6.565348505973816, 4.4396029226481915, 1.1300477245822549, 0.2500625926768407, 0.055247154014068656, 0.31834377092309296, 6.027278378605843, 22.39544916898012, 41.91703274846077, 46.21242105960846, 21.80231809616089, 37.490809857845306, 51.0725312680006, 42.46718242764473, 21.460917815566063, 3.983824742026627, 0.05831170070450753, 0.03211019924492575, 0.09858015124336816, 0.04141742130741477, 0.02195187480538152, 0.03500119841191918, 0.019088689477939624, 0.008417901863140287, 0.022760439132980537, 0.08022986716241576, 0.05404774688940961, 0.03426370400120504, 0.01539639531983994, 0.02453169145155698, 0.019279944644949865, 0.017904127162182704, 0.02514158284611767, 0.01396466999722179, 0.059949731949018314, 0.009351403041364392, 0.0581844928819919, 0.015722404095868114, 0.02520704954804387, 0.03851547546219081, 0.05133329723321367, 0.007848618006391916, 0.07625893180374987, 0.08461207107757218, 0.05227187284617685, 0.016568498831475154, 0.01703612979326863, 0.006458235875470564, 0.04461213327886071, 0.047520391090074554, 0.025758507945283782, 0.03183757871738635, 0.007106008806658792, 0.04658210491470527, 0.020351186576590408, 0.042593955440679565, 0.09635978640289977, 0.04950572889356408, 0.10472744208527729, 15.007441006600857, 49.96071092784405, 55.84366925060749, 41.16503410041332, 23.485865257680416, 42.72804602980614, 50.64833343029022, 43.08914065361023, 11.25246349722147, 1.0447928868234158, 0.3018774138763547, 9.167740512639284, 43.00764262676239, 49.45491626858711, 16.37308582663536, 10.501334052532911, 9.006394520401955, 12.844082191586494, 12.523508593440056, 10.612185504287481, 31.077141612768173, 35.35546503961086, 47.79469035565853, 51.38789914548397, 52.83446252346039, 54.70853716135025, 52.086016684770584, 48.464579209685326, 42.599441930651665, 42.03861862421036, 40.97459591925144, 44.408908635377884, 48.03902864456177, 48.35122749209404, 52.231153696775436, 52.41444066166878, 54.12352815270424, 53.25182072818279, 52.82574959099293, 51.51124432682991, 53.83170761168003, 54.356873631477356, 51.66401132941246, 50.77581278979778, 51.77167475223541, 51.99589692056179, 41.20210871100426, 37.89342865347862, 40.35508096218109, 44.56441529095173, 54.97272178530693, 52.63737469911575, 54.37543943524361, 52.0608202368021, 54.19979386031628, 49.84352521598339, 50.88152691721916, 43.55973020195961, 40.68639658391476, 37.31222324073315, 43.26921299099922, 46.45965099334717, 52.96638764441013, 50.45569896697998, 52.401122376322746, 36.32986195385456, 42.84629188477993, 54.816683158278465, 47.72981643676758, 49.52286422252655, 50.80367289483547, 51.65414705872536, 51.57091252505779, 49.1103545576334, 42.23100610077381, 40.265515968203545, 40.040203258395195, 38.52435439825058, 41.63532346487045, 41.392622888088226, 37.5635227560997, 49.392774403095245, 50.111049860715866, 51.26870334148407, 48.59604075551033, 51.72783650457859, 51.35374277830124, 50.60513734817505, 53.60192634165287, 53.41285228729248, 55.125526785850525, 51.541475504636765, 51.5453626960516, 52.970909401774406, 49.872848242521286, 48.89757737517357, 49.43590208888054, 49.53436240553856, 49.33063253760338, 48.65240313112736, 48.69653396308422, 48.97395707666874, 51.38770155608654, 53.444257602095604, 55.291843861341476, 51.649180725216866, 54.47937525808811, 54.09130208194256, 60.20157180726528, 54.15923863649368, 41.09910763800144, 24.59306314587593, 14.397567082196474, 9.507036656141281, 10.479692313820124, 6.440333789214492, 11.322476640343666, 10.713618211448193, 4.930308116599917, 2.1472063567489386, 0.9738857229240239, 0.03418756336031947, 0.269429114414379, 7.50410333275795, 27.737846598029137, 50.3176561743021, 55.18829941749573, 29.05517891049385, 40.28901010751724, 59.2608866840601, 47.74031147360802, 24.357179403305054, 4.288108851760626, 0.0857987355266232, 0.015609182046318892, 0.041254839015891775, 0.020430447948456276, 0.0538169129868038, 0.03922433781553991, 0.07672470368561335, 0.06338981649605557, 0.013118912938807625, 0.06807902464061044, 0.034066199950757436, 0.03580059536034241, 0.062209215393522754, 0.06387838715454563, 0.06678027362795547, 0.020393542799865827, 0.06563280941918492, 0.016621285940345842, 0.018099226654157974, 0.04836775304283947, 0.0401152601261856, 0.08629742165794596, 0.12137843805248849, 0.19135790993459523, 0.1910687395138666, 0.27611473691649735, 0.11759442742913961, 0.17703294579405338, 0.15912455128272995, 0.15193909232039005, 0.1532772439531982, 0.18338440888328478, 0.12992325180675834, 0.1645455986727029, 0.13287935958942398, 0.13536954706069082, 0.06777711896575056, 0.16763466963311657, 0.17568772891536355, 0.15798682405147702, 0.16742712061386555, 0.1865074405213818, 0.24925326579250395, 19.138212651014328, 57.71940819919109, 65.16999900341034, 47.58653752505779, 31.14163175225258, 51.90044604241848, 54.58761624991894, 43.66583950817585, 12.487374432384968, 1.4572334429249167, 0.5150301230605692, 10.166824702173471, 51.68820843100548, 53.138408213853836, 13.38958092033863, 12.40585645660758, 11.674421355128288, 18.89903638511896, 18.043561689555645, 15.445810183882713, 34.47998061776161, 39.23380672931671, 49.834550097584724, 54.701028764247894, 54.68213997781277, 58.3397401124239, 54.00283522903919, 51.0929399728775, 45.264960899949074, 43.74663457274437, 41.13932088017464, 45.496611669659615, 48.48544009029865, 50.723470598459244, 54.321869909763336, 55.68818919360638, 56.938500702381134, 55.80801196396351, 56.76785185933113, 54.89471197128296, 55.725233405828476, 55.75247034430504, 51.654986813664436, 51.07303284108639, 51.80841118097305, 54.03973124921322, 43.37975285947323, 41.073101833462715, 42.24316544830799, 48.678078353405, 57.15561345219612, 53.89475762844086, 56.2928431481123, 54.662020057439804, 55.4229786247015, 53.21208246052265, 52.65001282095909, 46.48278795182705, 42.45795652270317, 39.673519134521484, 44.854940101504326, 49.056918025016785, 54.410211369395256, 53.21842432022095, 52.9606119543314, 39.82599355280399, 45.54991900920868, 54.265762120485306, 49.468998312950134, 50.58603577315807, 53.76363806426525, 51.499354764819145, 54.29415799677372, 51.46089322865009, 45.585724487900734, 42.75130458176136, 43.048380240798, 40.29285550117493, 44.23948712646961, 43.08387793600559, 39.331704676151276, 52.07871727645397, 52.886827513575554, 51.72868765890598, 50.95393963158131, 53.55773851275444, 52.19123683869839, 55.308110788464546, 55.659409537911415, 56.72245189547539, 57.46981859207153, 54.06428173184395, 53.44600930809975, 54.935552179813385, 50.97910948097706, 49.24276225268841, 47.96019047498703, 50.5533879250288, 48.788496628403664, 48.18630874156952, 49.5966562628746, 49.65176470577717, 52.66084223985672, 56.91598691046238, 56.37184850871563, 56.1175699532032, 57.86972053349018, 58.17552052438259, 61.29788897931576, 59.99452851712704, 42.667013704776764, 27.011519372463226, 16.013756208121777, 18.320582024753094, 10.537531860172749, 21.499432548880577, 17.242235988378525, 17.078215889632702, 12.605089265853167, 4.444724572822452, 0.9333848836831748, 0.17064076848328114, 0.5355409474577755, 8.33299845457077, 30.553791895508766, 54.28217723965645, 56.097431033849716, 33.456516936421394, 51.211261823773384, 64.6106082201004, 56.382400542497635, 29.078703448176384, 5.578123480081558, 0.1259041955927387, 0.05967932302155532, 0.15450684906682, 0.13140484574250877, 0.14130705501884222, 0.09777504717931151, 0.1472700631711632, 0.12802050390746444, 0.14058050728635862, 0.15993632725439966, 0.1357149425894022, 0.1956848832196556, 0.18847773870220408, 0.11163003888214007, 0.17900462436955422, 0.0756082464067731, 0.11877639408339746, 0.12567815225338563, 0.2746334992116317, 0.11966037360252813, 0.17049799411324784], [0.07953917258419096, 0.028055165566911455, 0.09401184637681581, 0.05890959713724442, 0.01083975330402609, 0.05183106681215577, 0.04469703868380748, 0.10566712720901705, 0.09158062253845856, 0.017914780692080967, 0.0254634188968339, 0.07740863729850389, 0.03980653782491572, 0.035178096732124686, 0.06056283127691131, 0.05229621900070924, 0.040642218373250216, 0.06923536493559368, 0.0157016035518609, 0.03158593499392737, 0.022009782733221073, 0.2545113820815459, 9.454691614955664, 40.57400241494179, 49.626712650060654, 30.634001791477203, 30.15402864664793, 38.750700652599335, 43.717501536011696, 27.71923329681158, 10.415036883205175, 0.5202010518405586, 0.029263446922414005, 0.1116216674563475, 2.6307515474036336, 3.4726355597376823, 5.776709374040365, 9.413561671972275, 7.37225990742445, 18.16847998648882, 8.853145893663168, 10.32596966251731, 30.97034264355898, 34.685162007808685, 45.79978600144386, 53.036284893751144, 48.19917105138302, 52.94304549694061, 49.11733478307724, 49.13254916667938, 37.48785741627216, 38.095315620303154, 37.09229864180088, 38.16386394202709, 36.00339487195015, 38.46308648586273, 40.30942641198635, 41.36477418243885, 42.741816490888596, 43.346485644578934, 43.86955037713051, 46.27502270042896, 49.15027141571045, 50.72196587920189, 53.438497111201286, 52.25399427115917, 52.04078771173954, 48.789792358875275, 35.770995542407036, 36.417983025312424, 43.90837289392948, 49.977654218673706, 52.01639302074909, 50.11848226189613, 48.16770114004612, 46.51921659708023, 47.9384708404541, 48.92417974770069, 45.65322406589985, 38.954438120126724, 36.947723999619484, 34.95345041155815, 38.33060659468174, 41.00438632071018, 50.22592909634113, 48.45154590904713, 55.3095319122076, 34.38477672636509, 36.25703126192093, 54.931847378611565, 49.49316881597042, 51.17077499628067, 49.25659731030464, 49.43113714456558, 48.188330233097076, 47.416185066103935, 38.40566396713257, 35.93810297548771, 37.60956488549709, 38.35954964160919, 36.84622384607792, 37.6493601500988, 34.63177867233753, 42.02561192214489, 49.99002255499363, 52.990767136216164, 53.855558931827545, 52.5075014680624, 49.65440936386585, 49.80436831712723, 47.8610347956419, 46.4918352663517, 45.12271173298359, 43.93555663526058, 47.56209343671799, 47.95989789068699, 48.920486345887184, 49.66369226574898, 50.86781345307827, 51.92959047853947, 49.67828348278999, 48.12306873500347, 49.68937128782272, 47.876211181283, 51.4808763563633, 51.55567914247513, 52.273574620485306, 47.14462883770466, 45.7235012948513, 46.992826983332634, 49.32797268033028, 48.314582258462906, 43.036426082253456, 20.794532373547554, 11.949542742222548, 8.056055065244436, 9.870325662195683, 7.199829434975982, 9.092830382287502, 6.49067253805697, 6.8390630185604095, 0.8023998560383916, 0.8035292860586196, 0.10314234081306495, 0.022527655237354338, 4.7397872898727655, 19.54664133489132, 49.05851773917675, 26.971959695219994, 19.654899425804615, 36.783458814024925, 48.30149956047535, 47.00638845562935, 18.628167919814587, 2.7613037545233965, 0.05827953231346328, 0.05253756542515475, 0.048032784688984975, 0.06339741608826444, 0.038681560690747574, 0.03532023656589445, 0.06536484957905486, 0.06962675135582685, 0.02879317577026086, 0.05828734712849837, 0.04113662973395549, 0.0348342077631969, 0.05168394716747571, 0.009169117656711023, 0.08499426970956847, 0.02199320872023236, 0.027612543126451783, 0.05115164916787762, 0.1057954371208325, 0.06981637750868686, 0.04653202478948515, 0.04059244995005429, 0.08026857016375288, 0.014727009656780865, 0.007301901468963479, 0.01710723681753734, 0.11485733484732918, 0.04396967458887957, 0.04863156798819546, 0.054880009847693145, 0.024992335092974827, 0.045623851256095804, 0.06537272376590408, 0.047269957067328505, 0.026063740297104232, 0.0593812319857534, 0.0291399294292205, 0.10033849204774015, 0.0214230370693258, 0.025209077466570307, 0.06643629560130648, 0.004138327694818145, 0.2862429153174162, 12.540212497115135, 48.01430717110634, 57.035254910588264, 36.598036363720894, 35.41844666004181, 46.4923482388258, 52.09605194628239, 35.79710394144058, 9.998613428324461, 0.8340513857547194, 0.041579740136512555, 0.9717489907052368, 5.617397697642446, 10.132721532136202, 9.23928877338767, 11.518679112195969, 6.56225404702127, 12.291792277246714, 10.128613002598286, 14.399028103798628, 27.99803763628006, 33.7349583953619, 49.37047339975834, 53.19123297929764, 50.214423313736916, 54.65273715555668, 50.92691168189049, 50.931608229875565, 40.96100404858589, 38.9403522759676, 39.92996357381344, 40.436822175979614, 38.72170440852642, 40.135019570589066, 42.1512483805418, 43.74250039458275, 46.13162599503994, 45.81013664603233, 45.53433604538441, 48.760963305830956, 49.97741103172302, 52.31038324534893, 55.23971825838089, 51.67311564087868, 53.495083674788475, 50.49582101404667, 38.788276836276054, 37.99500860273838, 45.68296127021313, 52.3011839389801, 53.880417197942734, 50.93268737196922, 49.9710463732481, 48.652479127049446, 50.78085891902447, 51.75363332033157, 48.41512866318226, 40.72405256330967, 39.25988093018532, 37.097344771027565, 39.536076709628105, 44.68771107494831, 52.469560503959656, 50.86824283003807, 55.66156022250652, 35.670031160116196, 39.99306298792362, 53.8825336843729, 49.504355415701866, 52.541163861751556, 52.215639129281044, 51.579773649573326, 51.342746168375015, 50.030072405934334, 41.3140507042408, 38.897714763879776, 39.481127858161926, 39.2244516313076, 39.12376843392849, 39.39033553004265, 37.53485329449177, 46.320688650012016, 52.75581814348698, 53.46361756324768, 56.601025611162186, 53.596074655652046, 52.80002877116203, 53.027203381061554, 49.27031837403774, 49.38478343188763, 48.60770232975483, 47.43170723319054, 50.56095711886883, 50.66705122590065, 49.887716844677925, 50.17638735473156, 51.000141352415085, 53.25854256749153, 50.657338947057724, 48.21144059300423, 48.53877782821655, 48.51125590503216, 53.74707095324993, 53.80562201142311, 53.57886157929897, 49.77336958050728, 49.32262636721134, 50.513577461242676, 53.76417003571987, 50.141140446066856, 42.70294077694416, 24.829418063163757, 16.99573751538992, 6.577308364212513, 14.702248983085155, 13.879619725048542, 15.33387104049325, 11.161581873893738, 7.806388512253761, 4.335196875035763, 0.316609549918212, 0.17204494157340378, 0.015586134650220629, 5.7956603821367025, 22.472446337342262, 53.79946634173393, 33.080470114946365, 23.081392161548138, 46.38000726699829, 52.276249676942825, 54.88216884434223, 23.198773562908173, 3.7660496402531862, 0.16633651976007968, 0.011842200001410674, 0.021769020750070922, 0.033151729294331744, 0.023281376707018353, 0.09409124133526348, 0.04997843243472744, 0.042855258216150105, 0.02729382409597747, 0.023230565566336736, 0.07063947865390219, 0.018080810259561986, 0.04876533268543426, 0.01852641798905097, 0.05389217047195416, 0.02398106240434572, 0.022963125229580328, 0.01746397236274788, 0.10582842558505945, 0.015045929994812468, 0.0406055933854077, 0.19305632973555475, 0.12250551546458155, 0.16748543857829645, 0.09775979604455642, 0.13411375897703692, 0.2302293194225058, 0.12314861611230299, 0.21024050685809925, 0.24696697597391903, 0.09277456745621748, 0.11666769278235734, 0.17969473265111446, 0.13962147437268868, 0.11773925754823722, 0.10559804810327478, 0.2940142701845616, 0.12535736634163186, 0.2162606900674291, 0.11209949181647971, 0.15861901512835175, 0.09412734681973234, 0.6584809755440801, 18.126627132296562, 55.02912595868111, 61.947996094822884, 43.97782176733017, 41.49660050868988, 48.49850378930569, 52.45840810239315, 36.788998916745186, 13.388604372739792, 0.9942000266164541, 0.1629067733301781, 0.6218441727105528, 4.170013088732958, 6.010484704747796, 10.82497788593173, 18.765165768563747, 16.38783473521471, 26.726245880126953, 16.85417991131544, 15.304106287658215, 35.498474165797234, 40.94826713204384, 50.485056191682816, 54.365567564964294, 51.20251849293709, 56.232342794537544, 53.26137341558933, 54.31994341313839, 41.43937937915325, 40.35488337278366, 40.97363457083702, 42.3222354054451, 38.507050126791, 40.83585016429424, 44.48089577257633, 45.09117342531681, 46.41941875219345, 47.939853966236115, 47.04345166683197, 50.173655301332474, 51.94488845765591, 53.86738769710064, 56.70328572392464, 54.11099262535572, 55.823290944099426, 53.727908581495285, 39.708488658070564, 39.62962009012699, 48.34582418203354, 55.21501578390598, 55.23065194487572, 52.310960814356804, 50.13058081269264, 49.66724507510662, 52.57209800183773, 54.47408974170685, 50.16620010137558, 44.15553443133831, 40.5765026807785, 40.114550068974495, 41.09877325594425, 48.130824118852615, 54.72731955349445, 53.95037144422531, 56.33242182433605, 38.34799446165562, 43.43792773783207, 53.93566243350506, 51.90713748335838, 53.78404296934605, 54.422917887568474, 53.20894382894039, 52.523677200078964, 53.038652166724205, 42.724827602505684, 40.862779319286346, 42.20967784523964, 41.5415520966053, 41.36825479567051, 40.90478226542473, 39.45885345339775, 45.62807321548462, 54.44048814475536, 58.5271118581295, 56.781481727957726, 56.50612950325012, 53.781603500247, 56.091263964772224, 51.483824998140335, 50.08675016462803, 49.90006238222122, 48.603195771574974, 52.253173515200615, 51.43848583102226, 50.957161858677864, 50.99495083093643, 52.064164057374, 55.486344024538994, 50.988426581025124, 48.41724134981632, 50.61133861541748, 49.30695600807667, 54.94815990328789, 55.67230224609375, 57.38752640783787, 51.02574437856674, 51.67147792875767, 50.56452892720699, 56.91611610352993, 53.610247895121574, 46.423427537083626, 23.23476143181324, 17.911725863814354, 13.319501280784607, 17.362725622951984, 20.38423229008913, 21.95975884795189, 13.939275573939085, 12.311509419232607, 7.088010460138321, 1.440841716248542, 0.2811025036498904, 0.1989249070174992, 6.798375751823187, 27.420804910361767, 58.670139983296394, 36.11469849944115, 32.936697229743004, 47.69165888428688, 60.722098276019096, 62.06733249127865, 29.172921292483807, 4.702584436163306, 0.2990035805851221, 0.14254920242819935, 0.08959919956396334, 0.11533754150150344, 0.12462710787076503, 0.16655670013278723, 0.2829320461023599, 0.15612720977514982, 0.16225993225816637, 0.12798026466043666, 0.16934091167058796, 0.12769465654855594, 0.1850302252569236, 0.1158262902754359, 0.1567836245521903, 0.13917870906880125, 0.15325554355513304, 0.07355833062320016, 0.20455849065911025, 0.13169440208002925, 0.21458024508319795], [0.036438452734728344, 0.08089710987405851, 0.03067825127800461, 0.02988229603943182, 0.020273518966860138, 0.011210711181774968, 0.02911183542892104, 0.03280791082943324, 0.0819413413410075, 0.04232951709127519, 0.01403281863531447, 0.057285028451588005, 0.03222852355975192, 0.04796011358848773, 0.028429985395632684, 0.02829841188940918, 0.035625671152956784, 0.03803932835580781, 0.04688356530095916, 0.0747157767182216, 0.08752280395128764, 0.6567752826958895, 9.19513039290905, 43.48474882543087, 44.31132987141609, 35.0774035602808, 23.788370825350285, 18.463532254099846, 24.688001051545143, 28.765205070376396, 8.865942656993866, 0.5513954779598862, 0.09112268773606047, 1.4907263894565403, 0.24333152105100453, 5.262249754741788, 15.384784508496523, 13.191139418631792, 6.881775576621294, 6.3370852544903755, 9.986043702811003, 14.555481858551502, 28.856194987893105, 32.592454701662064, 47.75177925825119, 48.729664385318756, 49.8531387001276, 52.726696506142616, 50.872559398412704, 46.125181540846825, 39.388386234641075, 35.308381766080856, 37.517511025071144, 36.05594605207443, 37.48689226806164, 34.79589186608791, 34.99288469552994, 35.94956316053867, 36.24962165951729, 36.21839873492718, 37.2916891425848, 37.50785954296589, 43.89435164630413, 47.34001435339451, 50.47971747815609, 48.6558723449707, 48.75973217189312, 39.439212307333946, 34.57668922841549, 38.94238516688347, 49.58603963255882, 51.152444779872894, 47.60638006031513, 43.05151127278805, 49.773418977856636, 49.44609314203262, 52.269432842731476, 45.55150352418423, 43.34173209965229, 37.168089374899864, 36.64213299751282, 35.00171922147274, 37.218083292245865, 39.87895131111145, 48.612904250621796, 47.97135427594185, 55.434028431773186, 36.776949763298035, 38.046378046274185, 54.50665019452572, 48.97876761853695, 47.99651652574539, 47.23572514951229, 49.93969425559044, 45.161013677716255, 42.94795922935009, 38.192001432180405, 36.61019191145897, 36.459222212433815, 38.51612403988838, 37.587081491947174, 37.174435034394264, 35.84810100495815, 35.121389999985695, 40.2075120806694, 46.00661650300026, 45.47923520207405, 46.2933187186718, 44.215829595923424, 42.39337898790836, 41.347447112202644, 38.9268022030592, 38.23373079299927, 44.46636155247688, 49.7523795068264, 49.17388714849949, 49.67308156192303, 51.192962005734444, 51.66285239160061, 49.20400433242321, 52.086685448884964, 52.76045009493828, 48.34396608173847, 48.5219257324934, 50.60585170984268, 51.96904756128788, 51.091811433434486, 46.384897604584694, 47.72543527185917, 50.6228481978178, 56.13728329539299, 53.15290063619614, 44.37565661966801, 27.21461657434702, 14.627430997788906, 4.610029477626085, 14.257651939988136, 4.17292800731957, 10.900416187942028, 11.736471075564623, 3.122544432990253, 3.046300574205816, 0.9039832488633692, 0.17140901007223874, 0.1153164348215796, 4.155642259865999, 17.004469446837902, 40.31794175505638, 42.07168824970722, 26.654097251594067, 34.5919606089592, 47.25756637752056, 44.38918389379978, 18.914438858628273, 2.17841693200171, 0.09627737090340815, 0.03527555185428355, 0.05024597296142019, 0.047421759663848206, 0.037393823149614036, 0.05153134305146523, 0.029499592747015413, 0.03287916071712971, 0.01871827058494091, 0.042783785684150644, 0.0511573637049878, 0.03380140908120666, 0.04921664010907989, 0.05196453465032391, 0.03917748974345159, 0.07320663426071405, 0.0371911908587208, 0.02222172712208703, 0.04915163910482079, 0.047675028690719046, 0.03148744457575958, 0.0339329955750145, 0.008175836483133025, 0.08863455601385795, 0.03818677083472721, 0.012728666642942699, 0.07144863484427333, 0.03320001342217438, 0.04789146492839791, 0.10564674783381633, 0.0685527449240908, 0.055107092193793505, 0.011200627250218531, 0.003620558163675014, 0.019686300183821004, 0.00930305861402303, 0.01831808971473947, 0.03561151468602475, 0.07536380522651598, 0.06124554776761215, 0.06862997281132266, 0.05977466673357412, 0.7084010343533009, 12.205117028206587, 48.11211012303829, 49.65363800525665, 39.697822630405426, 30.5551503226161, 25.87083388119936, 31.03795051574707, 29.379677698016167, 10.33637160435319, 0.5276452680118382, 0.11595448886509985, 0.9904501028358936, 2.329804371111095, 6.506374245509505, 8.251799661666155, 9.833393543958664, 8.745265882462263, 11.984268128871918, 15.642185546457767, 13.041657339781523, 26.19884368032217, 35.71664325892925, 50.19557632505894, 51.50682896375656, 50.20893640816212, 54.87357370555401, 52.75828421115875, 49.08999145030975, 40.92823840677738, 37.58685730397701, 38.261442705988884, 38.60312797129154, 38.78821603953838, 36.213808581233025, 38.08309927582741, 37.04255551099777, 37.4173180013895, 37.66380697488785, 37.493097335100174, 40.66691502928734, 47.38983727991581, 49.550686329603195, 52.83321999013424, 50.698175355792046, 50.41130214929581, 42.423393577337265, 36.633024886250496, 40.04931516945362, 50.7797721773386, 53.31893652677536, 49.00901399552822, 44.83525335788727, 52.17489391565323, 53.18178668618202, 53.80899243056774, 47.51586131751537, 45.35240940749645, 38.44150364398956, 38.40450502932072, 36.921965181827545, 40.356460288167, 42.23930865526199, 49.56548273563385, 49.74645562469959, 55.37353567779064, 38.52967031300068, 39.540123492479324, 56.90501309931278, 50.92747025191784, 50.830883234739304, 49.509602934122086, 52.20144309103489, 48.54398734867573, 44.963116496801376, 39.51328553259373, 39.09415662288666, 38.07459533214569, 40.15369176864624, 38.00485007464886, 38.713964223861694, 36.990471705794334, 36.62795975804329, 43.78625124692917, 47.96753168106079, 48.93244810402393, 48.864097371697426, 47.109313532710075, 44.78310115635395, 43.165790140628815, 41.44198223948479, 40.550432279706, 46.49438492953777, 51.52338467538357, 49.945135563611984, 50.35370483994484, 52.91678890585899, 53.78848113119602, 51.73272684216499, 53.04218977689743, 52.65744902193546, 49.13090005517006, 48.221772238612175, 50.74591979384422, 54.373550936579704, 52.452674210071564, 48.066337779164314, 49.35118183493614, 51.867555007338524, 55.41379451751709, 56.34494215250015, 47.92583271861076, 27.19511602073908, 17.231794148683548, 12.174711059778929, 16.23372070491314, 14.613708034157753, 10.441792197525501, 10.597159210592508, 5.470913657918572, 2.6763645373284817, 0.8460657473187894, 0.2076827542623505, 0.13275494595291093, 4.093592064455152, 21.19826450943947, 46.30184546113014, 41.15746110677719, 29.912640899419785, 40.44305004179478, 55.50664633512497, 50.14304034411907, 22.364296540617943, 2.492062789388001, 0.09410992119228467, 0.020639121321437415, 0.05458132509374991, 0.08352505479706451, 0.02488964040821884, 0.016456035627925303, 0.04792749248736072, 0.016114784993987996, 0.03683673370687757, 0.05678346278727986, 0.0734676253341604, 0.06554270526976325, 0.035197433389839716, 0.09546267829136923, 0.015435938803420868, 0.04076589357282501, 0.00910962988200481, 0.060822004088549875, 0.08935436504543759, 0.06690456109936349, 0.04760732626891695, 0.15130902378587052, 0.23552313301479444, 0.13622972590383142, 0.10185526378336363, 0.10898679829551838, 0.20972700003767386, 0.13790692028123885, 0.13378865376580507, 0.23853117629187182, 0.141617257904727, 0.15308860485674813, 0.12824602774344385, 0.11546986643224955, 0.2824215969303623, 0.10700072947656736, 0.1626139070140198, 0.11920731471036561, 0.1816533791134134, 0.19090999412583187, 0.18772523064399138, 0.19202633266104385, 1.47423111833632, 17.110248170793056, 58.48518490791321, 57.66507871448994, 47.48729445040226, 35.27824178338051, 28.92224494367838, 34.99460980296135, 38.0410735309124, 11.729271411895752, 0.9702620829921216, 0.4976455809082836, 2.871983740478754, 2.500116457231343, 11.942454222589731, 24.600370153784752, 26.488211452960968, 14.998451638966799, 14.760069530457258, 19.78508234024048, 19.337371364235878, 31.88431330025196, 34.38903629779816, 49.9129056930542, 51.56085826456547, 52.083873599767685, 55.37914417684078, 56.18862234055996, 51.719419956207275, 43.25912453234196, 39.47931155562401, 40.248580276966095, 40.60783579945564, 42.018969878554344, 38.03210221230984, 39.776508808135986, 38.92151288688183, 40.26244193315506, 38.36587630212307, 39.64456468820572, 42.01089531183243, 48.43896858394146, 51.92593887448311, 55.99252246320248, 51.97980858385563, 52.64267921447754, 43.54641951620579, 38.37941497564316, 43.690659776329994, 54.669463858008385, 55.13856388628483, 48.84805843234062, 45.303034856915474, 53.98382484912872, 54.26079958677292, 56.73861622810364, 51.10884591937065, 48.74074459075928, 40.199855491518974, 41.028150245547295, 38.75655233860016, 41.835272535681725, 43.95820342004299, 51.94028690457344, 52.217508628964424, 57.050089314579964, 42.44124881923199, 42.98825986683369, 57.36681751906872, 53.28846216201782, 51.688227429986, 50.62302678823471, 54.04261149466038, 50.55281415581703, 48.3203199505806, 42.736918553709984, 41.35528229176998, 40.20441144704819, 42.658885940909386, 41.01888634264469, 39.64899145066738, 39.740817323327065, 38.27424421906471, 43.883206844329834, 49.84514772891998, 52.01879069209099, 49.46204088628292, 48.72212938964367, 46.53639927506447, 44.87371489405632, 43.566919416189194, 42.231412678956985, 48.48741978406906, 54.10990968346596, 51.996542885899544, 51.23958170413971, 54.606170654296875, 55.27979090809822, 53.47368322312832, 56.83996818959713, 53.55919763445854, 49.2523605376482, 49.10991758108139, 52.82251216471195, 56.169554963707924, 55.35633020102978, 50.41293226182461, 53.276956379413605, 53.94708842039108, 59.127000868320465, 57.996610924601555, 50.5584492534399, 30.125005804002285, 18.093025535345078, 9.04364962130785, 21.525584645569324, 10.682740118354559, 15.054777916520834, 21.098989136517048, 9.6183374337852, 6.809686319902539, 1.2596553261391819, 0.5082638142630458, 0.1583066748571582, 5.668282667174935, 23.67235355079174, 52.072949185967445, 49.68123972415924, 38.12235876917839, 48.797707334160805, 61.14916495978832, 58.181748390197754, 28.41176513582468, 3.6734198732301593, 0.22787098190747201, 0.07929084997158498, 0.1585547302966006, 0.16747320798458531, 0.16247570427367464, 0.09105955323320813, 0.18522613740060478, 0.10398531667306088, 0.09367918610223569, 0.09726188916829415, 0.15441272989846766, 0.11171235048095696, 0.20015549176605418, 0.1922354253474623, 0.11106542035122402, 0.12764319602865726, 0.1483383699087426, 0.24508910486474633, 0.19957811571657658, 0.17106055689509958, 0.15189624071354046], [0.014273112137743738, 0.03131343321001623, 0.04821231763344258, 0.050019740374409594, 0.012322511483944254, 0.07028712920146063, 0.02702747100556735, 0.12205992999952286, 0.028200439119245857, 0.0309599482716294, 0.034563902736408636, 0.021382725462899543, 0.048157547134906054, 0.0396703203296056, 0.04563515787594952, 0.04110043519176543, 0.02779074762656819, 0.029130639595678076, 0.04072155767062213, 0.015335388925450388, 0.03204301632649731, 0.621377332136035, 10.698565319180489, 39.29431088268757, 46.332255229353905, 35.48010975122452, 21.3201866671443, 16.853779032826424, 36.48775868117809, 33.561778888106346, 8.281977642327547, 0.8092570630833507, 0.2940485574072227, 11.969138290733099, 11.325557325035334, 12.691194545477629, 8.577537182718515, 7.03876462765038, 4.529574494808912, 9.198751598596573, 12.244089636951685, 18.092354871332645, 29.54302903264761, 36.25869557261467, 47.48971112072468, 50.059513226151466, 52.53241293132305, 50.11855825781822, 47.67827220261097, 45.223303735256195, 37.089224606752396, 35.787741243839264, 40.841511860489845, 45.91030307114124, 47.02508345246315, 44.45203632116318, 39.01079289615154, 35.46522594988346, 33.19408021867275, 33.6827339977026, 34.09556284546852, 34.46977436542511, 38.46465200185776, 42.02872395515442, 44.17107939720154, 41.496167331933975, 38.525011762976646, 34.72946383059025, 35.19431948661804, 45.60023590922356, 53.85066859424114, 52.02097937464714, 48.913935497403145, 50.919954255223274, 51.56928241252899, 46.39715954661369, 45.58901511132717, 41.15220978856087, 37.15091809630394, 35.020828396081924, 37.56368614733219, 36.36512026190758, 41.767366379499435, 43.17585960030556, 49.72269169986248, 46.59978747367859, 53.81866291165352, 35.79760931432247, 36.31238669157028, 53.470970168709755, 46.12648107111454, 47.381325736641884, 43.02682399749756, 42.14424155652523, 39.73127223551273, 37.5979071110487, 35.00819407403469, 36.19276151061058, 37.92522914707661, 42.04179525375366, 41.146977469325066, 43.51655311882496, 39.185051545500755, 36.42059728503227, 32.76286415755749, 34.591409638524055, 35.509683564305305, 35.77290304005146, 36.17628559470177, 35.1850213855505, 35.10142207145691, 35.29176905751228, 41.909911930561066, 46.32378928363323, 51.937144473195076, 48.926866203546524, 47.173248901963234, 48.85441929101944, 47.073819637298584, 47.41716541349888, 47.82771818339825, 51.34827867150307, 49.98650014400482, 48.363151252269745, 50.13561554253101, 52.834390327334404, 49.49680522084236, 45.559441298246384, 49.29936021566391, 51.45194470882416, 52.74637185037136, 53.02585065364838, 43.89088623225689, 27.740029580891132, 22.31297079473734, 10.311998762190342, 16.390259005129337, 25.21395742893219, 12.73874044418335, 10.427626557648182, 9.125663470476866, 2.507562870159745, 0.5259245540946722, 0.2586973027791828, 0.025385673361597583, 2.7549607073888183, 17.32195571064949, 43.05911086499691, 41.60136468708515, 25.63829965889454, 39.97878335416317, 41.468478217720985, 48.7045743316412, 21.887570321559906, 2.0692756259813905, 0.037810149442520924, 0.0631917298596818, 0.007095643322827527, 0.03609170649724547, 0.04797255198354833, 0.05313427813234739, 0.03088108765950892, 0.03245720152335707, 0.055473375468864106, 0.029970201576361433, 0.04369457528810017, 0.012301389961066889, 0.09294699062593281, 0.04513173313171137, 0.0509120764763793, 0.07466348499292508, 0.03175674399244599, 0.017583641820237972, 0.04365766086266376, 0.06953056901693344, 0.08555807929951698, 0.08846491589793004, 0.046844172102282755, 0.06074440883821808, 0.03305748396087438, 0.003548134986885998, 0.10727021071943454, 0.04896011305390857, 0.030956992668507155, 0.016983281457214616, 0.09823652944760397, 0.0059847925058420515, 0.08137460768921301, 0.03248543282097671, 0.039067996985977516, 0.10466311272466555, 0.02358347348490497, 0.08734882227145135, 0.025583127317077015, 0.07894366586697288, 0.060777812905143946, 0.03308177074359264, 1.0112283378839493, 14.590401984751225, 46.27492010593414, 53.023654371500015, 41.451781913638115, 25.660807751119137, 18.95836640149355, 36.32695131003857, 35.76884105801582, 9.470040891319513, 0.8814519422594458, 0.6854426069185138, 9.370217397809029, 6.7623095121234655, 6.3420112151652575, 4.348286697641015, 10.359765999019146, 9.101928044110537, 10.618421919643879, 13.200753852725029, 15.855926927179098, 29.227568060159683, 37.98898592591286, 47.98051938414574, 51.640828773379326, 53.00235651433468, 52.31098361313343, 50.04337549209595, 47.32221990823746, 38.955467864871025, 37.99397885799408, 41.06632299721241, 47.31039874255657, 47.67875857651234, 44.757095351815224, 39.635198190808296, 36.25964552164078, 36.29004769027233, 35.80135591328144, 36.43934927880764, 36.16372726857662, 39.67880845069885, 44.70772460103035, 47.23625332117081, 44.4633749127388, 41.101683899760246, 36.6477756947279, 37.07594431936741, 47.09737457334995, 55.18999792635441, 52.20927447080612, 50.32953433692455, 52.20452472567558, 54.08652573823929, 49.37187932431698, 48.124581053853035, 44.53396372497082, 39.40566010773182, 36.37434996664524, 38.15603256225586, 37.133214846253395, 42.45516747236252, 45.32687857747078, 49.48214180767536, 49.13225278258324, 54.287918731570244, 38.01905371248722, 39.52539548277855, 54.41374897956848, 48.62175777554512, 48.78735288977623, 45.25907501578331, 45.02596512436867, 41.08890898525715, 40.160409808158875, 37.525581791996956, 38.25551122426987, 39.426270201802254, 43.447385430336, 43.21519888937473, 45.34171298146248, 40.26399984955788, 37.99294911324978, 34.60591346025467, 36.505450531840324, 38.55646267533302, 38.073660582304, 39.43600907921791, 38.21479260921478, 37.65241898596287, 37.10112176835537, 42.911329194903374, 47.89351545274258, 53.98704707622528, 50.14574959874153, 49.779342859983444, 51.455261930823326, 48.77923272550106, 50.44683784246445, 51.17755763232708, 53.445458337664604, 50.788496509194374, 48.71530495584011, 51.264428570866585, 54.79920409619808, 52.29006193578243, 48.49586673080921, 51.08332268893719, 54.116604924201965, 55.403937846422195, 53.98447461426258, 47.30564519762993, 29.225109592080116, 21.9974984228611, 16.129072420299053, 12.89157584309578, 14.864582922309637, 12.328431811183691, 10.454694405198097, 6.834315173327923, 2.9658603155985475, 1.197783483657986, 0.10565442906226963, 0.07062488060910255, 3.2409161562100053, 19.34209831058979, 45.999427288770676, 46.768578216433525, 28.40839471668005, 43.33039350807667, 47.82419957220554, 54.27817605435848, 27.452590204775333, 2.155701038427651, 0.039704440569039434, 0.07196586724603549, 0.03445106289291289, 0.021913103155384306, 0.03949659840145614, 0.019606771638791543, 0.08994011252070777, 0.015248224608512828, 0.016611979408480693, 0.010596416068437975, 0.06702314887661487, 0.017485771095380187, 0.06111569789936766, 0.024288981330755632, 0.05789283997728489, 0.05346370264305733, 0.028569167770911008, 0.011988961559836753, 0.04738472278404515, 0.05466234535560943, 0.010555804819887271, 0.11624041610048153, 0.12401980100548826, 0.18232797650853172, 0.12284344498766586, 0.11391728607122786, 0.16144658293342218, 0.14514150941977277, 0.10452827191329561, 0.11485685245133936, 0.23709564004093409, 0.1557296561077237, 0.20171947893686593, 0.14265282108681276, 0.19919442536775023, 0.14812751091085374, 0.16356851672753692, 0.13580024504335597, 0.1571453473297879, 0.13313960109371692, 0.12286267403396778, 0.10284203075570986, 1.4785451930947602, 18.262977115809917, 53.48676972091198, 59.023927599191666, 48.27793702483177, 32.5725057721138, 26.772440001368523, 47.03563928604126, 40.55076286196709, 11.169253662228584, 1.1796599999070168, 0.7653988071251661, 14.140599220991135, 15.718995574861765, 23.548427000641823, 19.507611729204655, 17.408980540931225, 13.855856750160456, 17.360487543046474, 18.33824347704649, 22.20142588019371, 32.43722163140774, 39.31883096694946, 50.32469339668751, 52.15580374002457, 56.30893528461456, 54.47342857718468, 53.02554666996002, 50.10812781751156, 40.521192848682404, 39.41268213093281, 45.82291916012764, 50.03312364220619, 50.1578975468874, 47.8919917345047, 42.20404274761677, 39.98859062790871, 36.06551393866539, 36.994898468256, 37.286342829465866, 38.080678805708885, 41.13347679376602, 46.66720725595951, 49.18176032602787, 46.043444126844406, 42.02003762125969, 38.04833114147186, 39.382580146193504, 50.45179657638073, 57.664459347724915, 51.92393638193607, 50.83339869976044, 55.091928988695145, 57.33549199998379, 53.11890386044979, 50.455926954746246, 47.14710630476475, 41.32167689502239, 39.46831874549389, 40.77045947313309, 40.04325449466705, 45.70368155837059, 49.08712260425091, 52.77511730790138, 52.26364575326443, 53.81121911108494, 41.247007101774216, 44.62314493954182, 55.494619980454445, 50.858454555273056, 51.196735203266144, 47.64665029942989, 46.73797085881233, 42.798034474253654, 41.590493470430374, 39.29590679705143, 40.98271228373051, 43.625987246632576, 45.31028866767883, 45.89519888162613, 46.694824174046516, 42.840436398983, 40.59811972081661, 36.2390848249197, 37.47577406466007, 40.366419553756714, 40.30127964913845, 40.46260379254818, 38.933155462145805, 38.93304906785488, 38.59874300658703, 46.17265619337559, 51.7487657815218, 55.977061092853546, 50.85110194981098, 50.15524908900261, 53.85985650122166, 51.795636266469955, 53.68151307106018, 52.787151262164116, 55.896676406264305, 51.3958141207695, 47.56766013801098, 52.912707924842834, 56.278487518429756, 55.098164454102516, 51.460072472691536, 52.21579872071743, 56.09907254576683, 56.008531004190445, 56.41355887055397, 48.422895446419716, 34.68492642045021, 26.055720560252666, 17.490932643413544, 25.213079676032066, 35.574641078710556, 28.072618134319782, 18.482441939413548, 19.783932901918888, 7.442404618486762, 1.8512481939978898, 0.36069573427084833, 0.15933578135445714, 4.191541783511639, 23.264833018183708, 56.216881424188614, 55.629489943385124, 36.80971160531044, 52.35812768340111, 54.058825224637985, 62.30882853269577, 32.333878576755524, 3.1681301118806005, 0.08281219968921505, 0.18442697793943807, 0.14503965707262978, 0.0899032797315158, 0.11241918677114882, 0.14804427162744105, 0.15438332600751892, 0.09559624260873534, 0.11171252117492259, 0.15446990495547652, 0.10302543771103956, 0.07176900515332818, 0.224281495611649, 0.11241906060604379, 0.16342394636012614, 0.1562461760477163, 0.08965089757111855, 0.08558599147363566, 0.10952446944429539, 0.10952762357192114, 0.15737434441689402], [0.03573111920559313, 0.07595391653012484, 0.025557124317856506, 0.1024313633388374, 0.08154430717695504, 0.04426538333063945, 0.01241482445038855, 0.03901090727595147, 0.0922519396408461, 0.05653656509821303, 0.0540201055991929, 0.014081091630941955, 0.02758133581664879, 0.019617961370386183, 0.08221505282563157, 0.03135169834422413, 0.014018137098901207, 0.0839693340822123, 0.03857495488773566, 0.06364808388752863, 0.02129151180270128, 0.1802338584093377, 7.292265174910426, 37.40185283124447, 44.30937297642231, 35.92087469995022, 23.498136699199677, 25.25466464459896, 37.749788761138916, 28.756197653710842, 6.181813236325979, 0.38383928302209824, 0.06824034528108314, 9.20276703312993, 40.868068635463715, 30.145973078906536, 2.127585872076452, 6.0691640060395, 8.489352464675903, 12.122610155493021, 21.581956520676613, 14.748706240206957, 26.049063317477703, 43.14804509282112, 48.36674585938454, 53.79097379744053, 49.46221947669983, 47.35478416085243, 45.60397490859032, 39.76343370974064, 37.19183050096035, 37.38902471959591, 48.06310035288334, 53.54404404759407, 53.05089130997658, 50.58487303555012, 46.37773118913174, 40.265379175543785, 38.92402835190296, 36.16015926003456, 35.18818661570549, 35.59030383825302, 36.88152775168419, 37.50875249505043, 37.50703118741512, 34.33377966284752, 35.07111109793186, 33.17621357738972, 38.58578950166702, 47.49694213271141, 51.16963505744934, 50.05097508430481, 52.09684990346432, 49.035232588648796, 43.608390390872955, 42.3763445019722, 39.86307196319103, 35.29270380735397, 34.79178808629513, 35.31038425862789, 36.99302516877651, 40.723577588796616, 44.42818500101566, 44.47815611958504, 48.11878256499767, 48.37903060019016, 53.25763441622257, 37.1181296557188, 37.08054967224598, 53.93119767308235, 46.487834081053734, 45.34682370722294, 39.57770347595215, 38.04017677903175, 35.68942151963711, 35.70121988654137, 35.80922149121761, 36.41407683491707, 39.20056991279125, 43.785107508301735, 48.43036584556103, 49.53744404017925, 49.02152292430401, 46.420725882053375, 41.812298968434334, 38.06397870182991, 34.64353144168854, 36.48792967200279, 34.32755559682846, 32.53267630934715, 35.34034185111523, 39.57721710205078, 42.31773264706135, 49.81417939066887, 50.93932941555977, 49.82323810458183, 51.61309026181698, 46.39559023082256, 43.68625961244106, 41.52922175824642, 45.418328270316124, 49.211083352565765, 51.61312445998192, 48.94901521503925, 49.60293352603912, 54.02558460831642, 50.00069618225098, 45.258033871650696, 49.126822873950005, 51.72733873128891, 55.29648341238499, 53.15985806286335, 47.996090948581696, 28.096450455486774, 23.10315739363432, 30.306261777877808, 13.539314735680819, 16.469173170626163, 6.632291413843632, 5.718133142217994, 1.0195137932896614, 1.3199919322505593, 0.7226411858573556, 0.08837687491904944, 0.049557957536308095, 1.7655363120138645, 17.290375605225563, 40.79165853559971, 38.403490483760834, 31.16195496171713, 34.650371074676514, 44.69759054481983, 44.30654972791672, 23.62771164625883, 2.0650284038856626, 0.019127570594719145, 0.018673635968298186, 0.021318154904292896, 0.04786697405506857, 0.050325583142694086, 0.038972415786702186, 0.01746069021464791, 0.031608229110133834, 0.065553073072806, 0.04201656825898681, 0.037595060202875175, 0.06536435976158828, 0.04852233127166983, 0.03282031953858677, 0.06745371327269822, 0.02608133105240995, 0.0067408999802864855, 0.05746959686803166, 0.0190306869262713, 0.06463791592977941, 0.013546971658797702, 0.04116806339879986, 0.02310682542884024, 0.023174067719082814, 0.05383452044043224, 0.025095577111642342, 0.031284259384847246, 0.03699743465404026, 0.030949886604503263, 0.08456245850538835, 0.026785651461977977, 0.013561764517362462, 0.06374005824909545, 0.030501781548082363, 0.012833491291530663, 0.07236553603434004, 0.028808146744268015, 0.014711461662955116, 0.0681672734208405, 0.031149118003668264, 0.022739790729247034, 0.037500547696254216, 0.6599528028164059, 10.232939254492521, 41.24552138149738, 50.38132555782795, 42.113007232546806, 29.697996117174625, 31.946082785725594, 40.83159439265728, 31.44804921001196, 8.432617709040642, 0.4937773587880656, 0.2805662574246526, 12.832725550979376, 41.30536437034607, 35.961509719491005, 6.768320789560676, 6.4032188057899475, 12.739031128585339, 14.548703022301197, 14.566776752471924, 19.046840853989124, 31.06204502284527, 41.03737995028496, 47.8456874191761, 54.01168495416641, 51.53288796544075, 50.44586129486561, 48.61009620130062, 41.74278549849987, 38.759018406271935, 38.3725069463253, 49.445272386074066, 55.910636857151985, 54.75758492946625, 51.87932677567005, 48.34432706236839, 41.77123077213764, 39.28787402808666, 38.07587966322899, 36.22724466025829, 36.6507775336504, 37.9898826777935, 40.01018866896629, 39.56183932721615, 36.972403675317764, 36.8149059265852, 33.55285696685314, 40.84477208554745, 49.20397773385048, 53.91285605728626, 49.55228604376316, 50.99070645868778, 50.9102001786232, 47.45329387485981, 43.79858918488026, 43.06824177503586, 36.20865985751152, 38.29819053411484, 36.21309041976929, 37.873665913939476, 43.232556357979774, 47.401882633566856, 45.89684419333935, 50.74600338935852, 50.46280078589916, 53.38404983282089, 39.35207538306713, 40.045690163969994, 53.93925704061985, 48.793025985360146, 46.72670066356659, 42.10044890642166, 40.65893165767193, 38.47799688577652, 38.033086359500885, 38.32735016942024, 37.88012936711311, 41.43593296408653, 46.552852392196655, 50.136732682585716, 52.04590983688831, 51.06694556772709, 46.98037885129452, 42.17492491006851, 37.26312607526779, 35.26758335530758, 37.90132462978363, 34.45448778569698, 34.50615741312504, 36.4655564725399, 40.84435410797596, 44.436985328793526, 50.45581676065922, 52.3522038012743, 50.277887508273125, 51.943858712911606, 48.90005864202976, 46.912237107753754, 44.57994505763054, 46.262015998363495, 51.621704399585724, 51.59610517323017, 47.84685775637627, 49.56782341003418, 54.68260735273361, 53.2028603553772, 47.670722007751465, 51.9421412050724, 54.523870870471, 56.21723100543022, 53.02407994866371, 47.42268271744251, 31.712275631725788, 20.261664167046547, 18.396437354385853, 15.620710048824549, 16.705782674252987, 13.541284929960966, 13.521863222122192, 8.813412375748158, 2.79722488950938, 1.588397417217493, 0.22301102784695104, 0.07558696161140688, 2.387309060432017, 19.535112753510475, 44.525060802698135, 41.864926144480705, 35.57276777923107, 41.342670768499374, 49.54071186482906, 50.00657066702843, 27.737415321171284, 2.9124636808410287, 0.023008129064692184, 0.016680273693054914, 0.042475193258724175, 0.0591507951321546, 0.007442187325068517, 0.007397782774205552, 0.017362728576699737, 0.06938367572729476, 0.023598600309924223, 0.02976757299620658, 0.05828007037052885, 0.1069124361674767, 0.030855589320708532, 0.11389858394977637, 0.0046348866453627124, 0.06528620418976061, 0.0507869206921896, 0.05133275546540972, 0.04289600583433639, 0.04184690958936699, 0.004503825684878393, 0.13793409772915766, 0.15348998800618574, 0.10343459856812842, 0.2237276901723817, 0.20323696313425899, 0.1166131003992632, 0.09479784013819881, 0.16714504512492567, 0.2436110287089832, 0.15602770261466503, 0.16844353638589382, 0.1322845579124987, 0.14659451582701877, 0.13999015849549323, 0.2012676149024628, 0.09675161811173894, 0.1455777438241057, 0.14491084992187098, 0.12287547608138993, 0.11119582311948761, 0.13284958462463692, 1.206520996056497, 13.97247914224863, 50.112163200974464, 57.7212131023407, 47.83412083983421, 34.541518315672874, 35.10496728122234, 48.87288250029087, 36.91124975681305, 8.640693593770266, 0.7792680035345256, 0.4038571729324758, 12.622100003063679, 48.76215644180775, 38.22394631803036, 6.503807008266449, 10.551740247756243, 12.736516613513231, 24.141795560717583, 28.411109670996666, 18.6458008736372, 27.652875557541847, 46.39984980225563, 51.12419329583645, 57.28855311870575, 55.56967735290527, 51.50205262005329, 50.06802476942539, 44.52908478677273, 41.42316944897175, 41.80299326777458, 53.780904337763786, 58.56538340449333, 57.19483494758606, 55.51120229065418, 50.070616230368614, 44.279381185770035, 44.38706360757351, 41.58791720867157, 38.45718540251255, 39.20401252806187, 41.2835269421339, 42.804570123553276, 41.621374413371086, 38.49125437438488, 38.654239028692245, 35.58648504316807, 43.22508975863457, 51.60972744226456, 54.462758749723434, 49.293474331498146, 52.86566264927387, 54.647759422659874, 48.25165003538132, 45.46006143093109, 44.56701435148716, 39.17995601892471, 39.927858486771584, 39.34734843671322, 39.60462503135204, 46.49348817765713, 49.38023507595062, 48.36433678865433, 53.323519080877304, 52.9438928514719, 53.005954921245575, 41.365317553281784, 43.73989753425121, 55.735899433493614, 52.194166481494904, 49.2220039665699, 44.359629079699516, 42.08225168287754, 40.18177226185799, 39.268916845321655, 40.33404529094696, 39.89712193608284, 44.18457247316837, 48.15398007631302, 53.554330095648766, 56.49807773530483, 53.77853326499462, 50.07337488234043, 47.02971160411835, 41.952169463038445, 38.500871658325195, 40.25093615055084, 37.331868186593056, 35.98735213279724, 39.51455466449261, 43.750840947031975, 47.03057795763016, 52.62582331895828, 54.068651497364044, 51.98916368186474, 53.52115787565708, 51.539974585175514, 48.011396527290344, 46.52769014239311, 48.54522988200188, 54.900711849331856, 55.0443859398365, 49.25755865871906, 49.83887046575546, 57.30980537831783, 55.29079131782055, 50.156206637620926, 54.279388189315796, 57.21503086388111, 59.48385491967201, 56.458506658673286, 50.91450534760952, 31.965864524245262, 28.817685954272747, 36.31552152335644, 18.01077324897051, 24.507161155343056, 15.261944700032473, 14.58897516131401, 10.461040064692497, 8.531768638640642, 3.090794524177909, 0.22748096846044064, 0.30362834804691374, 2.456303620710969, 23.32524597644806, 51.54119051992893, 51.15826986730099, 44.658395648002625, 46.02356739342213, 57.83997192978859, 58.337441235780716, 34.289417043328285, 4.7170046623796225, 0.27101288724225014, 0.1291110008605756, 0.1434606043039821, 0.150393896328751, 0.16039534559240565, 0.14488828863250092, 0.11473831662442535, 0.1390802112291567, 0.19576696475269273, 0.18894858687417582, 0.16252131666988134, 0.2227235643658787, 0.1456776962731965, 0.17147943988675252, 0.07861100559239276, 0.16908438090467826, 0.198431542085018, 0.08988193556433544, 0.09241701554856263, 0.15150257589993998, 0.11983558724750765], [0.006446336001317832, 0.02654040690686088, 0.016119892825372517, 0.00836158213132876, 0.02805423973768484, 0.021554913000727538, 0.043147211690666154, 0.02902744210587116, 0.034918972160085104, 0.0968829337216448, 0.023651999690628145, 0.054313762302626856, 0.021371483780967537, 0.017156552530650515, 0.06616250248043798, 0.04595106416672934, 0.046258932998171076, 0.16694239428034052, 0.013000216622458538, 0.03813385199464392, 0.045749292767141014, 0.45145790150854737, 10.010508690029383, 36.0846459120512, 46.230082511901855, 38.70164908468723, 22.235105372965336, 21.557381339371204, 34.35613006353378, 25.568033829331398, 6.743214586749673, 0.6114165228791535, 0.06522873227368109, 0.36153240187559277, 5.849899146705866, 3.505870713852346, 3.0076077254489064, 6.536832461133599, 14.599553793668747, 7.634359868243337, 10.253341309726238, 19.981774985790253, 35.37794083356857, 38.80922891199589, 46.91297806799412, 54.709046334028244, 47.31110170483589, 45.95359794795513, 41.863527819514275, 36.758642345666885, 34.4403525441885, 37.754375115036964, 50.29670409858227, 50.95608651638031, 51.931809559464455, 49.88948754966259, 48.85305896401405, 47.52380669116974, 45.01640483736992, 43.82557913661003, 42.884609028697014, 42.1959263831377, 41.10731519758701, 39.689075499773026, 39.047624319791794, 36.226157918572426, 36.46465592086315, 35.238921493291855, 42.65119895339012, 49.40720982849598, 50.736788883805275, 49.42621260881424, 51.35806314647198, 48.19292038679123, 44.85145948827267, 38.755906373262405, 35.83039775490761, 37.1586886793375, 35.27548313140869, 34.52629633247852, 42.023867815732956, 44.418377727270126, 50.033066645264626, 47.17894099652767, 52.089223712682724, 47.24307395517826, 51.59064866602421, 37.88076773285866, 34.73947249352932, 54.0030974149704, 46.448654383420944, 46.667613834142685, 40.18191285431385, 39.50947813689709, 35.85635796189308, 36.597462594509125, 34.30849201977253, 35.854089483618736, 39.82302971184254, 44.6103510260582, 49.085541889071465, 52.99032635986805, 49.80575904250145, 51.19902268052101, 50.51373705267906, 46.29853583872318, 43.89716349542141, 44.93858881294727, 43.43857750296593, 38.05568374693394, 32.80740536749363, 42.405899316072464, 48.984235525131226, 50.84988981485367, 50.00815898180008, 51.112801507115364, 47.613215893507004, 42.34944574534893, 40.419020131230354, 37.55811184644699, 43.77999298274517, 47.89747104048729, 51.60370476543903, 51.29541590809822, 48.68440501391888, 53.34595687687397, 52.94845640659332, 49.10611778497696, 49.70383331179619, 51.47347815334797, 50.381082370877266, 50.72571247816086, 51.811679005622864, 38.42503912746906, 22.084559351205826, 14.894052240997553, 17.324155792593956, 9.922413267195225, 11.849149279296398, 11.597399488091469, 7.845251401886344, 0.8909316023346037, 1.4438297809101641, 0.1733385495026596, 0.040955170916276984, 1.5611691470257938, 14.600279554724693, 39.34122696518898, 29.723411053419113, 22.521017231047153, 31.847947351634502, 43.59178148210049, 45.901677533984184, 26.68128289282322, 1.4597094850614667, 0.06247915676794946, 0.021513827705348376, 0.03449972180533223, 0.0753716794133652, 0.049897501230589114, 0.044597000887733884, 0.005614367119051167, 0.08357560989679769, 0.06738928001141176, 0.06532731174957007, 0.03580935641366523, 0.04515780106885359, 0.015065377974678995, 0.01903058117022738, 0.012523800487542758, 0.013457531731546624, 0.055399676493834704, 0.04437096868059598, 0.06026596478477586, 0.059180410535191186, 0.032406932150479406, 0.07020829085377045, 0.02764749642665265, 0.024834931136865634, 0.022973676714173052, 0.07526668778154999, 0.050287930280319415, 0.03938738394936081, 0.09287521752412431, 0.06814745065639727, 0.030724114149052184, 0.03631477753515355, 0.03424079761316534, 0.052998754545114934, 0.018966346433444414, 0.03812898350588512, 0.015096845036168816, 0.03564812854165211, 0.09025688341353089, 0.04533925988653209, 0.016475876946060453, 0.006798187287131441, 0.6987192726228386, 11.83616727590561, 42.16579020023346, 51.74375385046005, 43.80566820502281, 26.367360837757587, 24.247583784162998, 41.17829918861389, 29.787933491170406, 6.851902529597282, 0.5796414997894317, 0.13315557211171836, 0.5659330822527409, 9.905671365559101, 6.626222189515829, 4.195410925894976, 5.9761962946504354, 12.785988058894873, 11.760194152593613, 12.954725604504347, 21.654255241155624, 32.65394680202007, 40.33129423856735, 49.039321169257164, 55.6895837187767, 50.55233158171177, 47.77788385748863, 44.875512197613716, 39.208169505000114, 36.53120554983616, 39.42023612558842, 51.73990085721016, 52.87027560174465, 53.375606685876846, 50.52038289606571, 51.33102759718895, 48.612003698945045, 46.46305561065674, 44.49992895126343, 44.01811480522156, 42.26397693157196, 41.51612766087055, 40.609595105051994, 39.94726784527302, 37.72475950419903, 37.835120782256126, 36.83042049407959, 44.180081114172935, 51.79238364100456, 52.59338825941086, 48.71552914381027, 52.209019884467125, 50.0826083868742, 47.42716267704964, 40.340018570423126, 37.95507654547691, 37.9161362349987, 38.00689056515694, 37.02144004404545, 44.09881867468357, 47.84115806221962, 51.107409596443176, 49.61082570254803, 53.47279027104378, 47.741527408361435, 51.772902086377144, 40.07135398685932, 39.79074664413929, 55.85504584014416, 48.218238428235054, 49.103480726480484, 43.88014420866966, 40.25908671319485, 38.37478682398796, 37.74069964885712, 37.07874856889248, 37.81603820621967, 42.26599462330341, 47.16178871691227, 52.28385306894779, 54.416633024811745, 50.191312953829765, 52.31745466589928, 51.56928241252899, 49.108713045716286, 44.510492384433746, 45.22671975195408, 45.84394343197346, 38.96481916308403, 34.279495775699615, 42.75184415280819, 50.93494065105915, 52.81529255211353, 51.59330852329731, 51.01972930133343, 50.13379544019699, 45.17257645726204, 43.85443098843098, 39.615070670843124, 46.2643376737833, 50.3011042624712, 53.62380936741829, 50.573207661509514, 50.43251261115074, 54.44504030048847, 54.08446624875069, 51.68717868626118, 52.71396718919277, 54.736135080456734, 53.327250480651855, 54.859712049365044, 51.6597555577755, 37.30826385319233, 20.80889370292425, 16.962538696825504, 16.563833691179752, 14.730227831751108, 11.517802309244871, 16.055629961192608, 5.256986562162638, 3.9635238563641906, 1.3119310210458934, 0.11391580919735134, 0.08429844689089805, 1.4939178619533777, 17.694271132349968, 46.63015924394131, 39.09811221063137, 30.061344020068645, 38.24092000722885, 50.21910846233368, 52.883305102586746, 31.11092559993267, 2.2715257108211517, 0.0318227617390221, 0.040015905105974525, 0.03358352194481995, 0.07098305592080578, 0.035924292824347503, 0.07822367871995084, 0.03165140726196114, 0.03331191815959755, 0.019980736142315436, 0.0778347859159112, 0.0852472752740141, 0.026733090708148666, 0.05539999190659728, 0.033130407391581684, 0.03649611760920379, 0.08237202448071912, 0.011958681006944971, 0.017763299074431416, 0.0244879325691727, 0.020913196458423045, 0.02391519123193575, 0.12357681305729784, 0.11816680140327662, 0.0580951679876307, 0.07961013674503192, 0.16962721740128472, 0.18562412151368335, 0.10976626857882366, 0.13918244949309155, 0.13325166539289057, 0.2648286893963814, 0.19734077795874327, 0.2036415523616597, 0.3043176548089832, 0.1787959472858347, 0.21550749923335388, 0.13758680230239406, 0.16976496001007035, 0.4232940205838531, 0.19369514076970518, 0.09382254676893353, 0.12217370865982957, 1.0293046804144979, 15.74352040886879, 50.15809513628483, 58.132484033703804, 51.05027586221695, 32.28225074708462, 30.097590275108814, 46.23130604624748, 34.02979217469692, 8.740079160779715, 1.031514024361968, 0.25113211653660983, 0.7800846034660935, 7.986842729151249, 4.335260521620512, 6.11387905664742, 19.356543235480785, 25.222349278628826, 16.96737013757229, 15.821834206581116, 21.86806596815586, 36.72091796994209, 42.111282125115395, 47.88110911846161, 58.7156767398119, 51.9837261736393, 50.12550048530102, 46.13531179726124, 40.530893728137016, 37.8940100222826, 41.997687220573425, 54.10998187959194, 53.58120605349541, 52.072022035717964, 52.28156179189682, 52.209080681204796, 52.02705904841423, 49.602059572935104, 48.88893283903599, 46.32912799715996, 46.802654787898064, 44.48946811258793, 43.32420364022255, 41.93279430270195, 39.259200766682625, 40.10291889309883, 39.72393862903118, 46.46805614233017, 53.96319195628166, 53.08966062963009, 49.47581894695759, 54.21101085841656, 53.098704144358635, 49.288739785552025, 42.54265017807484, 39.85989153385162, 41.52661889791489, 39.738168865442276, 38.8586338609457, 45.43450400233269, 50.167172849178314, 54.20004464685917, 51.464856415987015, 54.83991891145706, 50.330761671066284, 50.7919505238533, 42.82893821597099, 42.56756544113159, 58.11032362282276, 52.25793465971947, 51.56579799950123, 45.927223563194275, 45.058187395334244, 38.86121392250061, 40.72076953947544, 37.99971655011177, 40.24221941828728, 43.66591550409794, 49.2288663983345, 53.380348831415176, 57.541611939668655, 52.30249486863613, 54.43305194377899, 53.964848667383194, 51.66034832596779, 47.943095192313194, 49.54138822853565, 48.275102376937866, 42.093335688114166, 36.107433289289474, 46.69774241745472, 54.02854084968567, 53.51276412606239, 53.331365659832954, 53.59339199960232, 51.82430572807789, 46.52113549411297, 44.73051957786083, 41.295937076210976, 49.058589935302734, 53.386531099677086, 55.95548965036869, 51.9994193315506, 50.505027920007706, 56.04992218315601, 57.56543666124344, 54.718952402472496, 55.05010463297367, 56.76099322736263, 54.52160619199276, 56.32437385618687, 55.33034719526768, 40.89242532849312, 26.028166338801384, 19.739211201667786, 24.11310900002718, 21.704034470021725, 22.89748203009367, 22.823731787502766, 13.54766858741641, 6.303704045712948, 3.950919220224023, 0.7374374137725681, 0.16514771792571992, 2.4191836500540376, 20.48088390380144, 51.47250920534134, 41.831233352422714, 35.45892208814621, 44.31038752198219, 57.97850489616394, 60.11805608868599, 36.38410784304142, 3.29139051027596, 0.16288885788526386, 0.1169973325158935, 0.18237692856928334, 0.19562159286579117, 0.11441987589932978, 0.1712185749784112, 0.10697563004214317, 0.14832878136076033, 0.12939934007590637, 0.15823890193132684, 0.10987544592353515, 0.10049734133644961, 0.07804069478879683, 0.13554518372984603, 0.16405490547185764, 0.17295288504101336, 0.10203466314123943, 0.07747986863250844, 0.09461896770517342, 0.14223954873159528, 0.15776100335642695], [0.02740967334830202, 0.07559695091913454, 0.0027104017044621287, 0.009601585661584977, 0.05736152161261998, 0.056421832778141834, 0.03828925771813374, 0.01792725990526378, 0.0877130164008122, 0.06935994926607236, 0.030297191842691973, 0.03905579978891183, 0.011918862928723684, 0.0751473059062846, 0.020131672281422652, 0.03215180404367857, 0.0378706641640747, 0.02920113991422113, 0.028329457782092504, 0.045081875650794245, 0.03328876686282456, 0.27089242183137685, 5.465107094496489, 28.510309047996998, 42.886771112680435, 43.50583769381046, 33.38682487607002, 30.919417776167393, 34.616199508309364, 25.91053795069456, 7.277914769947529, 0.4178588872309774, 0.02984055579872802, 0.027166117179149296, 1.3028757506981492, 4.082554131746292, 5.7856659684330225, 3.4953286545351148, 13.229236174374819, 14.936504513025284, 16.92783135920763, 29.494395442306995, 35.46922713518143, 41.45536512136459, 48.770911172032356, 52.326346188783646, 47.86208733916283, 45.18407464027405, 40.03380820155144, 37.5386568903923, 39.65707741677761, 35.22196680307388, 48.94381709396839, 50.69046176970005, 52.98082306981087, 49.23281438648701, 50.94720259308815, 46.73098303377628, 49.19091783463955, 50.72991505265236, 48.61712962388992, 48.278358802199364, 48.22928063571453, 47.652912363409996, 44.98000279068947, 40.71334473788738, 40.21375514566898, 41.00113369524479, 44.778321012854576, 49.91300828754902, 51.52792163193226, 47.95310765504837, 52.64012575149536, 45.997489392757416, 43.63516755402088, 35.58770477771759, 35.54693676531315, 33.75912889838219, 36.22582733631134, 36.36509746313095, 46.704357862472534, 48.31807807087898, 52.9402906447649, 48.523704037070274, 51.163334995508194, 45.228156074881554, 49.06837061047554, 39.9510258436203, 36.285180151462555, 52.56655789911747, 46.589235439896584, 46.15097835659981, 43.832175582647324, 42.54164323210716, 40.094741731882095, 37.42980793118477, 35.935887694358826, 36.91706724464893, 39.67797249555588, 45.717406421899796, 49.609503373503685, 47.17108681797981, 48.149929493665695, 48.89733798801899, 50.144115686416626, 50.58035887777805, 50.54923094809055, 50.38370802998543, 53.255517929792404, 47.43023671209812, 35.238792300224304, 40.51191754639149, 46.38983353972435, 49.103883504867554, 49.04303357005119, 45.69839984178543, 43.41330125927925, 39.07031290233135, 37.8112580627203, 35.412587374448776, 39.52198326587677, 46.55545525252819, 51.20122656226158, 50.004150196909904, 48.85753512382507, 51.11388444900513, 53.60570713877678, 51.62518881261349, 48.24025824666023, 48.31806667149067, 52.14061215519905, 50.94430714845657, 51.71172916889191, 45.746227875351906, 22.506057433784008, 21.91870205104351, 22.856731116771698, 15.221846401691437, 11.908029969781637, 18.73415183275938, 6.809269292280078, 2.234594067558646, 1.03487886255607, 0.1830102625535801, 0.06593275582417846, 1.196961896494031, 13.068755585700274, 29.562900066375732, 23.7308457121253, 25.12166988104582, 34.301139414310455, 38.315012231469154, 48.50916601717472, 21.091991811990738, 2.3322576144710183, 0.06927467649802566, 0.026172208890784532, 0.017254120830330066, 0.022296784227364697, 0.1269053973373957, 0.05637872884108219, 0.03989667908172123, 0.07720248351688497, 0.039101219226722606, 0.024420758927590214, 0.01978573312953813, 0.07651275373063982, 0.04631890966265928, 0.01899284852697747, 0.00930943459025002, 0.05498985141457524, 0.032446911645820364, 0.031469647874473594, 0.035946212155977264, 0.05864436840056442, 0.048703931097406894, 0.05117682652780786, 0.048851648170966655, 0.06646494250162505, 0.013061177560302895, 0.023132114110921975, 0.05229978502029553, 0.015541069587925449, 0.05664473683282267, 0.021623927168548107, 0.0813808936800342, 0.051699495161301456, 0.022661928305751644, 0.022942341383895837, 0.045216679354780354, 0.03014938200067263, 0.007646584999747574, 0.06507988713565283, 0.042765068719745614, 0.03231020804378204, 0.024263952400360722, 0.04917733596812468, 0.3917090763570741, 7.079469468444586, 33.85913573205471, 49.803414568305016, 48.256148993968964, 33.47167432308197, 32.750659212470055, 36.15971848368645, 27.484411597251892, 8.48802538588643, 0.4570174781838432, 0.10352197161410004, 0.37410384917166084, 2.7573783276602626, 7.585166282951832, 10.428314320743084, 8.159685004502535, 12.40976169705391, 10.670352783054113, 13.5700199380517, 21.592968329787254, 30.44464275240898, 41.67733021080494, 47.828033566474915, 53.79122458398342, 50.937182530760765, 48.23838874697685, 42.19973377883434, 39.177710339426994, 40.40333837270737, 37.73144334554672, 50.93486845493317, 52.345512360334396, 53.929905742406845, 49.3537200987339, 51.55966132879257, 49.889415353536606, 51.73038996756077, 51.85996301472187, 49.892166405916214, 50.043417289853096, 49.063358679413795, 47.56518267095089, 45.417078137397766, 42.079819813370705, 41.91702514886856, 41.71198435127735, 45.34536078572273, 52.21053600311279, 52.060865834355354, 48.36578831076622, 54.14897918701172, 49.12065580487251, 46.10726550221443, 38.08596812188625, 37.57112614810467, 36.1774293333292, 38.03807929158211, 38.20191130042076, 49.22279812395573, 52.783351466059685, 54.40728932619095, 49.5386865735054, 50.93319654464722, 46.82380445301533, 50.02042092382908, 42.93491072952747, 38.62407624721527, 54.42215412855148, 47.910416945815086, 47.199668884277344, 45.54137706756592, 44.743761867284775, 41.14331066608429, 39.43719081580639, 37.94307678937912, 38.71891915798187, 41.22449330985546, 47.825400307774544, 51.95512130856514, 50.08008912205696, 49.32091645896435, 50.05130186676979, 52.007991671562195, 53.84796693921089, 53.2013214379549, 52.43028201162815, 54.27755668759346, 48.874687403440475, 36.842583641409874, 42.4996592849493, 49.057081416249275, 52.72858880460262, 51.429115533828735, 47.83509358763695, 44.82684440910816, 40.612938925623894, 40.33173881471157, 37.03444294631481, 40.803943276405334, 48.73225584626198, 53.461349084973335, 52.598958760499954, 48.98063711822033, 53.461675867438316, 55.771188139915466, 53.16440261900425, 50.767274647951126, 51.454395577311516, 53.81458193063736, 53.805181235075, 54.07948091626167, 43.81756156682968, 25.351891927421093, 14.375013392418623, 8.248682878911495, 10.837082136422396, 13.95615141838789, 14.850835260003805, 8.659625127911568, 2.357164565473795, 2.1064112707972527, 0.22225592227187008, 0.11137103676446714, 1.6588159510865808, 14.894922394305468, 36.75101615488529, 29.966658800840378, 28.28590828925371, 38.680609613657, 44.92102235555649, 57.35553212463856, 26.964175812900066, 3.385220537893474, 0.0318438313115621, 0.014380936918314546, 0.03816031698079314, 0.09605322746210732, 0.017927699627762195, 0.07544536725617945, 0.024677721994521562, 0.1531167619396001, 0.021225065465841908, 0.10197564755799249, 0.020371510290715378, 0.03003210968017811, 0.028072576351405587, 0.017462092873756774, 0.061136221993365325, 0.020074998174095526, 0.04543670758721419, 0.02898023223679047, 0.03869010281050578, 0.04577833671646658, 0.0378564112179447, 0.23456723196431994, 0.21482101263245568, 0.20705985487438738, 0.12204801852931269, 0.11464967450592667, 0.16194334690226242, 0.1020013629749883, 0.21918815094977617, 0.1886394081520848, 0.182352660340257, 0.16266192396869883, 0.1279833519947715, 0.15562749205855653, 0.14932930032955483, 0.0788843905320391, 0.19642971747089177, 0.13867146597476676, 0.1758670317940414, 0.08330936441780068, 0.14778728072997183, 0.08372284457436763, 0.7959066575858742, 9.77724015712738, 40.19633688032627, 57.74758368730545, 56.854737997055054, 41.61678805947304, 40.241676047444344, 45.767476335167885, 33.693312630057335, 9.9224997125566, 0.6863027263898402, 0.28336234332527965, 0.500753220403567, 5.686275651678443, 13.568121939897537, 14.204479493200779, 9.97121499851346, 23.26318960636854, 21.74378603696823, 22.341161482036114, 33.469432443380356, 37.083084136247635, 43.362744972109795, 50.93031629920006, 58.26317422091961, 54.15187083184719, 49.22785945236683, 43.499469235539436, 41.42393320798874, 42.97629810869694, 39.548741430044174, 53.82397122681141, 55.56662991642952, 54.96786564588547, 49.777705147862434, 52.908490151166916, 50.923795849084854, 53.37965726852417, 55.594015046954155, 52.20624603331089, 51.93997532129288, 52.10407331585884, 51.37314073741436, 48.72417367994785, 44.563305750489235, 44.45040620863438, 45.020972192287445, 48.55101317167282, 55.888263657689095, 53.83002430200577, 48.772822469472885, 58.09664435684681, 50.54836079478264, 48.24884198606014, 40.20005688071251, 40.14628976583481, 37.481162175536156, 40.641828775405884, 41.036939173936844, 51.618428975343704, 53.96242819726467, 55.515826642513275, 50.70749245584011, 52.57669195532799, 46.11611142754555, 49.531444162130356, 44.69664439558983, 42.48085029423237, 55.1082719117403, 51.86963349580765, 49.95143182575703, 49.111730083823204, 46.69401101768017, 44.01345245540142, 41.22579284012318, 39.42801050841808, 40.459290370345116, 44.814506471157074, 50.78345037996769, 53.83267655968666, 51.12433008849621, 49.92941580712795, 51.243009120225906, 53.03125396370888, 53.62472511827946, 56.7209205776453, 53.80262017250061, 57.060474157333374, 51.860874965786934, 38.481371104717255, 44.53697316348553, 50.673324689269066, 54.291657730937004, 54.86046060919762, 49.50936734676361, 47.7390081435442, 43.205140829086304, 42.23030313849449, 39.85430583357811, 44.72978241741657, 50.015093609690666, 55.68551413714886, 54.69424992799759, 49.63324449956417, 53.91227848827839, 56.84537909924984, 55.63219539821148, 53.33934523165226, 54.69061732292175, 56.4963336288929, 56.0553976893425, 55.74696443974972, 48.94657574594021, 25.95518745481968, 30.776353552937508, 36.1938064545393, 27.938863411545753, 21.55258409678936, 29.02640875428915, 13.498825058341026, 5.038563357666135, 4.102348694577813, 0.4728419962339103, 0.27507774881087244, 1.863149986602366, 17.8549550101161, 38.639146238565445, 34.8848032951355, 35.57117946445942, 46.93242162466049, 51.47866867482662, 62.93082855641842, 32.650090008974075, 5.0756194442510605, 0.10081452783197165, 0.17759826936526224, 0.10137579185538925, 0.25381334766279906, 0.18494440329959616, 0.209033002902288, 0.07862106911488809, 0.22255895601119846, 0.07109094935003668, 0.1765177765628323, 0.10325246810680255, 0.18104005343047902, 0.12301817623665556, 0.08829581012832932, 0.15829249983653426, 0.12013076164294034, 0.26161489309743047, 0.057146847975673154, 0.13977373339002952, 0.11901270874659531, 0.1603404266643338], [0.03810206209891476, 0.0775792496278882, 0.023486671452701557, 0.10278451431076974, 0.02612605287140468, 0.10334383390727453, 0.03829911343927961, 0.013349843320611399, 0.02783340070891427, 0.05317416856996715, 0.04294373335142154, 0.01029810980980983, 0.02967209384223679, 0.028036391086061485, 0.025420250021852553, 0.04017861727334093, 0.03623334167059511, 0.01505593321780907, 0.08126750093651935, 0.033566808779141866, 0.0778394985536579, 0.363411401049234, 4.153537172824144, 26.929130293428898, 46.1461678147316, 46.84778116643429, 29.391956739127636, 26.790295243263245, 39.76542480289936, 27.641681358218193, 8.371396344155073, 0.48787122883368284, 0.0240038630363415, 0.37678534747101367, 1.03564677760005, 3.4304587729275227, 6.102034617215395, 6.71014211140573, 10.14184769243002, 9.1645391844213, 11.876777596771717, 22.13022530078888, 29.49017196893692, 40.63579089939594, 49.86692816019058, 48.44211481511593, 48.00345495343208, 42.59858317673206, 39.11579266190529, 38.36695544421673, 40.16013242304325, 34.980603754520416, 44.12395432591438, 47.23562255501747, 52.76790149509907, 48.54972884058952, 50.07082141935825, 46.83075807988644, 51.20935432612896, 48.65971393883228, 48.74629609286785, 49.62545871734619, 50.162225514650345, 48.97403307259083, 49.032872915267944, 47.36690931022167, 49.286433309316635, 49.21063497662544, 49.337593764066696, 49.53959472477436, 49.01120267808437, 52.051871716976166, 49.55621503293514, 46.65002837777138, 43.38784642517567, 33.654664903879166, 36.40485852956772, 34.58084620535374, 37.28595905005932, 35.79233139753342, 45.77041357755661, 48.90754424035549, 52.024695575237274, 48.30932334065437, 51.251927241683006, 45.96965208649635, 49.00966376066208, 38.537889271974564, 33.826666474342346, 52.79681794345379, 48.98100569844246, 50.65027512609959, 46.39420710504055, 44.43365290760994, 42.93802656233311, 39.4554678350687, 34.62941139936447, 36.25541254878044, 37.53243662416935, 43.13300170004368, 48.95990163087845, 51.47515006363392, 49.134532660245895, 52.018874287605286, 50.24859867990017, 50.30025690793991, 49.61321957409382, 49.88074041903019, 52.98042789101601, 46.82174116373062, 37.77108661830425, 40.40340296924114, 44.48843076825142, 45.25130443274975, 43.66936571896076, 40.242037028074265, 36.78872913122177, 34.21916261315346, 35.71811757981777, 35.291822254657745, 37.234289422631264, 43.01924340426922, 48.22446629405022, 50.14960639178753, 52.089888677001, 49.91562254726887, 52.70184203982353, 54.19838413596153, 53.530729562044144, 53.034305199980736, 54.136052280664444, 53.453468307852745, 51.6013602912426, 47.53296419978142, 31.739457473158836, 15.476325396448374, 9.8956798017025, 8.526305481791496, 8.342893123626709, 13.764294013381004, 5.294673414900899, 2.9934876831248403, 0.5735630134586245, 0.06003820708428975, 0.04443921287020203, 1.0198181332089007, 14.567538611590862, 41.348708644509315, 34.94882605969906, 26.78860243409872, 31.37158401310444, 39.73803207278252, 45.33307604491711, 23.291283398866653, 4.05550385825336, 0.07335963542573154, 0.04634668453945778, 0.021483785567397717, 0.0519903428357793, 0.03774172713747248, 0.061129256937419996, 0.01228025359523599, 0.010970215444103815, 0.1093196589499712, 0.02344007014471572, 0.025368058486492373, 0.06689175163046457, 0.06068626156775281, 0.014355525781866163, 0.020762577587447595, 0.06950829716515727, 0.010842235788004473, 0.037949075776850805, 0.06281841473537497, 0.018560302596597467, 0.05640032533847261, 0.04539288747764658, 0.06460413336753845, 0.008316338025906589, 0.0935682795534376, 0.04123410712054465, 0.004822794726351276, 0.07850707523175515, 0.06333474171697162, 0.03262691585405264, 0.018074299769068602, 0.09517374535789713, 0.05186245594813954, 0.008850038684613537, 0.027810377432615496, 0.014974969544709893, 0.07099402486346662, 0.016403155750595033, 0.01721246779197827, 0.08922142413211986, 0.062324270547833294, 0.028167732671136037, 0.2710241382010281, 6.038257414475083, 32.846752256155014, 52.971961945295334, 53.55969540774822, 35.77725000679493, 29.141713567078114, 47.03731879591942, 32.894747480750084, 10.025623328983784, 0.6076924258377403, 0.03984186034358572, 0.19385844294447452, 3.297702446579933, 7.5668849889189005, 10.99763872101903, 10.029876250773668, 9.948695506900549, 9.513020385056734, 16.742236018180847, 23.767002671957016, 29.404885545372963, 42.73492366075516, 50.05449749529362, 51.92554369568825, 48.6387200653553, 46.10794186592102, 39.34547893702984, 40.396570935845375, 42.46356502175331, 38.726442754268646, 45.630478486418724, 49.18964870274067, 53.753249421715736, 48.29026736319065, 49.34811919927597, 47.34938085079193, 50.46174444258213, 50.17089664936066, 48.99686984717846, 49.847473204135895, 50.1465817540884, 51.051499396562576, 52.25449964404106, 48.43481920659542, 50.95730625092983, 49.711299911141396, 51.42007201910019, 52.61573486030102, 48.1635669618845, 52.174745723605156, 50.52368491888046, 49.035240188241005, 44.93472062051296, 35.50896920263767, 36.9409641623497, 36.11228182911873, 38.498359993100166, 37.63542249798775, 47.565574049949646, 51.09310336410999, 52.360688745975494, 50.209107398986816, 52.58680321276188, 47.190769761800766, 49.084633737802505, 39.975067153573036, 36.092237904667854, 52.35818088054657, 50.51883637905121, 51.273817867040634, 49.49119292199612, 46.5968806296587, 44.73154932260513, 41.95208586752415, 36.33259780704975, 37.00090974569321, 38.5880845785141, 45.043489784002304, 51.253633350133896, 52.427207976579666, 52.4597380310297, 51.994426399469376, 50.880356580019, 50.94455033540726, 49.246653243899345, 50.14602318406105, 53.12924690544605, 50.91158330440521, 39.58576664328575, 42.47608155012131, 46.44365005195141, 47.32006162405014, 45.12650012969971, 43.45805145800114, 38.53961817920208, 36.60849720239639, 36.93620681762695, 38.71985770761967, 38.92292641103268, 44.32115234434605, 50.64343549311161, 53.05324338376522, 52.7197390794754, 50.76653748750687, 53.07395227253437, 54.77818742394447, 54.262083917856216, 55.33056378364563, 56.23208440840244, 55.38435749709606, 53.729048520326614, 48.0076689273119, 28.72804496437311, 17.81680505722761, 7.584919771179557, 12.957981079816818, 12.947925869375467, 7.773370184004307, 11.722617968916893, 2.0713465148583055, 1.430814885534346, 0.27104298875201494, 0.06323189489194192, 1.4359887829050422, 15.498829688876867, 39.84166771173477, 35.428930297493935, 32.701455652713776, 36.80664896965027, 45.597978830337524, 52.800340354442596, 28.661206550896168, 4.673419576138258, 0.013524985533877043, 0.02421073670120677, 0.040657951903995126, 0.01981397555937292, 0.036831015459029004, 0.012670105625147698, 0.006442559861170594, 0.0012403672985783487, 0.04214104497805238, 0.014371068209584337, 0.04399938276037574, 0.047524936744594015, 0.05364985925552901, 0.054696651131962426, 0.008840085556585109, 0.03556606185156852, 0.015734168991912156, 0.03972052661993075, 0.06575444742338732, 0.02509018169803312, 0.013749962963629514, 0.228902596863918, 0.25550396007020026, 0.10837923910003155, 0.2196585389901884, 0.14374968566698954, 0.2246299191028811, 0.1561413996387273, 0.3243573638610542, 0.08143141909386031, 0.18962962611112744, 0.16083236667327583, 0.09645340833230875, 0.094477150705643, 0.1082598052744288, 0.18859174742829055, 0.11719359346898273, 0.12459169258363545, 0.11828725939267315, 0.22702055488480255, 0.17160064744530246, 0.20961305068340153, 0.6502769188955426, 7.858653282746673, 39.902107268571854, 59.85007546842098, 60.56044355034828, 41.49734906852245, 36.546860709786415, 51.271632984280586, 36.33854828774929, 11.456807032227516, 1.0020685731433332, 0.14682611043099314, 1.2743209954351187, 2.2950445488095284, 8.970798030495644, 14.534688424319029, 14.761100225150585, 18.976050652563572, 17.428705282509327, 18.547764234244823, 22.31856979429722, 31.460987515747547, 43.61697033047676, 51.34778469800949, 51.87140040099621, 52.6203516125679, 47.439071238040924, 43.522123619914055, 41.556812077760696, 45.531949773430824, 40.28270244598389, 48.04868012666702, 52.12338387966156, 55.58506652712822, 48.07266443967819, 50.15013076364994, 47.974891886115074, 52.7454598993063, 50.611342415213585, 51.60155028104782, 50.88289484381676, 53.28033819794655, 51.47104248404503, 54.35145512223244, 51.90275251865387, 55.928575694561005, 53.09827096760273, 52.95698694884777, 52.50846281647682, 48.994954749941826, 54.22451913356781, 52.95837767422199, 52.04678378999233, 47.070931792259216, 36.72402620315552, 39.51568320393562, 38.0370419472456, 40.824617967009544, 40.46906344592571, 51.3748050481081, 54.315824434161186, 56.1997177451849, 52.33012318611145, 54.76652964949608, 48.243313282728195, 48.06430108845234, 41.93889297544956, 40.870299115777016, 53.65394935011864, 53.1908567994833, 53.918722942471504, 51.87290892004967, 49.79524880647659, 47.42314629256725, 44.233388453722, 37.82224327325821, 38.66040229797363, 42.228939011693, 48.34588497877121, 55.05937613546848, 54.976198598742485, 54.70919832587242, 54.373877719044685, 52.01967604458332, 50.773266926407814, 49.05640885233879, 48.96100357174873, 56.18137612938881, 50.768577978014946, 43.13834421336651, 44.898037388920784, 48.587282225489616, 49.76389668881893, 47.80827842652798, 44.1705322265625, 40.97065933048725, 38.278009817004204, 39.97816778719425, 39.38395567238331, 41.89774118363857, 46.28636509180069, 53.60219992697239, 54.3540807813406, 54.86588291823864, 52.10313096642494, 55.86350418627262, 57.63594187796116, 57.41607807576656, 57.66260504722595, 59.29091267287731, 59.703828915953636, 56.15788199007511, 50.67415304481983, 36.77801750600338, 22.889496758580208, 14.13884561508894, 20.154333226382732, 14.17273124679923, 22.005153112113476, 11.646200269460678, 6.422708909958601, 1.885119576472789, 0.4197866009781137, 0.25246629025787115, 1.5184260718524456, 19.97113175690174, 51.18429087102413, 46.30681939423084, 40.41823357343674, 41.69949822127819, 53.82101498544216, 60.07726147770882, 35.2169206738472, 6.391145903617144, 0.1630285003921017, 0.19978029158664867, 0.08833334053633735, 0.1467865688027814, 0.2243594211176969, 0.12498344265623018, 0.1197693134599831, 0.16576665424508974, 0.23469875537557527, 0.21269263699650764, 0.1686672939104028, 0.22813653718912974, 0.12828313512727618, 0.13896580174332485, 0.09220283172908239, 0.11140913120470941, 0.08945577952545136, 0.1514698175014928, 0.22386678348993883, 0.23064394248649478, 0.1707510367850773], [0.01011034273687983, 0.00736988822609419, 0.005115378098707879, 0.09470800316194072, 0.07249301474075764, 0.04686540865805, 0.03607311940868385, 0.04982226229913067, 0.027667376707540825, 0.07192858174676076, 0.030021853199286852, 0.06278169326833449, 0.057503193893353455, 0.026953035448968876, 0.021599456704279874, 0.07908755345852114, 0.0812918136944063, 0.050341531896265224, 0.04639187020075042, 0.04369089052488562, 0.14944694557925686, 0.25323880661744624, 2.3317543789744377, 20.096287541091442, 48.585146740078926, 42.81778961420059, 31.196920685470104, 26.03253610432148, 22.717747874557972, 20.960342176258564, 9.414804205298424, 0.4777622869005427, 0.12044566232361831, 0.3748163703130558, 3.323500924743712, 7.306330595165491, 15.284476540982723, 7.668670602142811, 7.085858825594187, 10.522818099707365, 17.294741570949554, 22.771167308092117, 29.898365065455437, 45.03040328621864, 48.96899454295635, 51.59062206745148, 46.47079959511757, 45.222942754626274, 37.99175597727299, 35.96508152782917, 37.67340525984764, 37.04535596072674, 40.02389073371887, 45.34088082611561, 50.80516241490841, 51.1578518897295, 47.2191846370697, 49.53311987221241, 51.01983569562435, 50.856360867619514, 49.85771365463734, 49.623197838664055, 51.880983486771584, 50.93424528837204, 51.114716604352, 50.50886191427708, 47.97426871955395, 50.755483880639076, 51.1534783244133, 48.66497665643692, 50.76486177742481, 49.031398594379425, 49.19066704809666, 45.4708718508482, 40.01572497189045, 34.48615908622742, 35.643079206347466, 33.718151897192, 35.258532240986824, 35.59472680091858, 39.62154932320118, 42.46970169246197, 45.05509436130524, 43.95761825144291, 48.7279012799263, 47.005218118429184, 52.08401419222355, 39.66628812253475, 32.70401291549206, 49.831077083945274, 46.8170066177845, 49.559965431690216, 47.35987588763237, 47.92432799935341, 46.078858226537704, 45.19597180187702, 37.20943495631218, 36.51011288166046, 35.12924037873745, 38.656819090247154, 40.88856853544712, 43.54183316230774, 47.47819013893604, 47.942855805158615, 48.658300414681435, 52.222516760230064, 47.029434219002724, 50.75854651629925, 50.417020842432976, 43.58520023524761, 36.15457355976105, 39.802172631025314, 41.7235167324543, 41.751031056046486, 39.534746780991554, 37.29912534356117, 38.17860335111618, 37.84918762743473, 37.25730858743191, 36.90645441412926, 34.01411421597004, 38.065107241272926, 43.49765673279762, 46.81615926325321, 50.94607025384903, 52.10956022143364, 51.919384226202965, 51.782747358083725, 54.318997263908386, 53.94024878740311, 51.008185520768166, 54.227764159440994, 51.11203774809837, 47.61726647615433, 34.31655898690224, 16.15644995123148, 4.4457904156297445, 9.512387719005346, 19.75438568741083, 7.4162420723587275, 12.20854064449668, 1.5835563582368195, 1.666118921712041, 0.2585504169110209, 0.10763336584204808, 1.0910164564847946, 12.382671050727367, 36.990300714969635, 42.411139234900475, 36.66905075311661, 31.452206186950207, 39.226469323039055, 48.968515768647194, 23.36030099540949, 3.3968244027346373, 0.08824824588373303, 0.03405737952562049, 0.03304613281216007, 0.041982021284638904, 0.028287938330322504, 0.0193632637092378, 0.03596724462113343, 0.030717791050847154, 0.025350662544951774, 0.03489772818284109, 0.011152972092531854, 0.02681216468772618, 0.06539286565384828, 0.11303203005809337, 0.013810881227982463, 0.026347713828727137, 0.033440094484831207, 0.027158968441653997, 0.05064010532805696, 0.024702422524569556, 0.058104329800698906, 0.04501278170209844, 0.030893013972672634, 0.045452058911905624, 0.04704338680312503, 0.032635469106025994, 0.046703676125616767, 0.06584524177014828, 0.09204315865645185, 0.03688546312332619, 0.0032706346064514946, 0.028160077417851426, 0.023935772842378356, 0.01979911219677888, 0.04222690033202525, 0.016888481368368957, 0.11480708402814344, 0.08539725589798763, 0.10647183793480508, 0.05178687933948822, 0.065318606357323, 0.038313867335091345, 0.28628818632569164, 4.414046918973327, 26.936247311532497, 53.53504613041878, 47.68042288720608, 35.07972903549671, 33.19239690899849, 30.774284563958645, 26.434871815145016, 11.287680957466364, 0.6556989904493093, 0.19547561241779476, 0.7520447205752134, 3.826305619440973, 7.391191916540265, 10.362157970666885, 13.124284856021404, 12.221984323114157, 8.423911426216364, 18.656662590801716, 25.886865220963955, 31.382709816098213, 42.973569855093956, 50.40187865495682, 53.35652031004429, 48.52138616144657, 46.37157931923866, 40.01430384814739, 36.89298793673515, 40.259341299533844, 39.18720602989197, 40.935340225696564, 48.17444957792759, 54.22830753028393, 51.79780974984169, 47.65102006494999, 49.04302977025509, 51.12181842327118, 52.010229751467705, 52.19137363135815, 51.23118035495281, 51.897501200437546, 51.19674660265446, 49.997409358620644, 49.94197033345699, 48.87088380753994, 51.35091952979565, 52.61827312409878, 48.578801080584526, 50.901578441262245, 51.75987258553505, 52.64215484261513, 47.62257859110832, 41.67760379612446, 36.245297491550446, 38.53111423552036, 35.44751510024071, 36.68288201093674, 37.17945456504822, 42.142565846443176, 45.49352243542671, 47.723227590322495, 47.72827371954918, 50.33322013914585, 49.13629576563835, 53.87152947485447, 41.220552921295166, 34.708048179745674, 50.03064237535, 48.304763585329056, 51.625067219138145, 48.63596901297569, 49.82701890170574, 47.683774307370186, 47.644362822175026, 39.43459555506706, 37.9672434926033, 36.56951129436493, 40.56060433387756, 43.832107186317444, 47.807529866695404, 48.705284893512726, 50.34793294966221, 52.520736157894135, 51.91789090633392, 48.836073875427246, 50.189204066991806, 53.22209112346172, 46.682148054242134, 37.88321480154991, 41.61389261484146, 45.98743513226509, 42.889480367302895, 41.243575885891914, 38.38432051241398, 38.80300484597683, 39.331146106123924, 40.61616875231266, 40.18713377416134, 36.22276470065117, 41.22207283973694, 46.583482548594475, 50.996900126338005, 52.23401494324207, 53.10445323586464, 52.271412536501884, 53.86729650199413, 55.868352726101875, 55.650901794433594, 54.40281316637993, 56.841928884387016, 51.819183602929115, 52.773506194353104, 34.19423595070839, 17.91696198284626, 9.94897099211812, 11.852290760725737, 10.844817571341991, 9.233876913785934, 13.197233341634274, 4.417888512834907, 0.5089270567987114, 0.3808003367157653, 0.03370530466781929, 1.0829053167253733, 15.44745834544301, 42.514033913612366, 45.71362942457199, 39.52497370541096, 38.21308650076389, 45.368756130337715, 55.57183563709259, 29.70963679254055, 4.588297493755817, 0.08635450023575686, 0.018369266363151837, 0.06719857032294385, 0.03797623467107769, 0.02566611427027965, 0.03605116668040864, 0.038222234361455776, 0.05176744991331361, 0.03938851201382931, 0.011384440531401196, 0.03332796710310504, 0.04103804283658974, 0.033054589584935457, 0.035471371229505166, 0.007349494935624534, 0.02845827792043565, 0.03650580263638403, 0.037477734076674096, 0.057470016181468964, 0.013003949625272071, 0.011000662980222842, 0.1301519965636544, 0.193002806045115, 0.17075419833417982, 0.17001534579321742, 0.13257963582873344, 0.27176278294064105, 0.12365682399831712, 0.25849502300843596, 0.1614952232921496, 0.12370835873298347, 0.09657390342908911, 0.10839023772859946, 0.15672230831114575, 0.12652390374569222, 0.08664037552080117, 0.17129621846834198, 0.20367946126498282, 0.1317319695954211, 0.19646499917143956, 0.164839489152655, 0.16249320411588997, 0.4549132223473862, 6.040650336071849, 33.16289149224758, 62.97242492437363, 55.1057830452919, 43.01618076860905, 36.52363635599613, 33.97422395646572, 30.225119031965733, 12.53971852362156, 0.9478493419010192, 0.31482444726862013, 1.0643240762874484, 5.391075666993856, 13.044136706739664, 24.745594561100006, 13.55023629963398, 15.659118387848139, 16.845352984964848, 18.114477284252644, 24.75805029273033, 31.525910831987858, 45.88294833898544, 50.01722529530525, 56.77494987845421, 51.93955734372139, 50.056013613939285, 40.85268706083298, 39.292095601558685, 42.76919782161713, 42.01844170689583, 43.47793959081173, 50.25622867047787, 55.65580353140831, 53.58143404126167, 47.16858275234699, 49.07028570771217, 52.472379952669144, 53.47774900496006, 53.061393946409225, 52.20028415322304, 53.97929169237614, 53.9251483976841, 53.07914279401302, 51.93358786404133, 49.49359439313412, 52.58384697139263, 53.22392262518406, 48.66736672818661, 51.44151046872139, 53.998241275548935, 55.08703865110874, 50.70028804242611, 43.34725700318813, 39.412157759070396, 40.226241275668144, 37.43003971874714, 38.62361267209053, 39.99817751348019, 44.11487281322479, 47.38302804529667, 50.06639085710049, 50.262821316719055, 53.33545424044132, 50.75944326817989, 53.67709770798683, 43.75731199979782, 39.59180071949959, 49.45247299969196, 49.75536994636059, 54.457218647003174, 52.16175802052021, 51.96474999189377, 50.53927168250084, 48.59849542379379, 42.14017957448959, 40.127317383885384, 38.72542440891266, 41.739950850605965, 45.944649428129196, 49.48544003069401, 51.16150729358196, 53.27740855515003, 53.56545589864254, 54.675064757466316, 49.527568370103836, 51.541570499539375, 55.97855441272259, 47.57251247763634, 40.52115485072136, 44.08157140016556, 47.58673891425133, 45.25338292121887, 43.45087744295597, 40.23764826357365, 40.88107533752918, 41.6498576849699, 43.96620959043503, 42.53556355834007, 39.43443216383457, 43.70793364942074, 48.2909931242466, 52.327117547392845, 55.02908796072006, 55.42166769504547, 54.45088058710098, 54.90208737552166, 56.99680857360363, 56.39096148312092, 56.854008436203, 59.55692499876022, 55.51999881863594, 55.09057246148586, 38.57417732477188, 20.60941580682993, 9.795579873025417, 17.01855529099703, 31.431624591350555, 19.508134201169014, 24.676132388412952, 8.31511091440916, 3.4262775722891092, 0.6148174591362476, 0.2699008828494698, 1.6706018499098718, 17.365246787667274, 48.16865108907223, 54.25877429544926, 49.647869914770126, 44.80223312973976, 52.84809239208698, 61.639315858483315, 38.019760474562645, 5.87925779633224, 0.13307540531968698, 0.08939898296375759, 0.2347131827264093, 0.09764256639755331, 0.12647722265683115, 0.16154381912201643, 0.15310165181290358, 0.09380340678035282, 0.143916193919722, 0.10681819083401933, 0.18383705959422514, 0.17942088015843183, 0.10338981737731956, 0.18333072192035615, 0.11092748478404246, 0.14748038782272488, 0.16393772035371512, 0.13242008892120793, 0.13810807198751718, 0.08036421073484235, 0.12327229502261616], [0.04669305599236395, 0.06938951642950997, 0.05978245557344053, 0.07232022791868076, 0.029103335982654244, 0.06096758377680089, 0.013735323173023062, 0.025108867121161893, 0.04690399291575886, 0.035469326612656005, 0.032955516580841504, 0.06757057926733978, 0.052480130616459064, 0.054414312180597335, 0.05794310192868579, 0.042010905672213994, 0.022484408436866943, 0.03876089998811949, 0.029788264073431492, 0.050708965500234626, 0.03432827455981169, 0.16058867506217211, 2.2409701254218817, 19.930122457444668, 51.54839873313904, 44.86344784498215, 27.39906057715416, 17.830839604139328, 25.794469378888607, 26.161168701946735, 12.797588836401701, 0.8542688540183008, 0.12566040008096024, 0.37494315882213414, 6.594275878742337, 8.35583807900548, 6.896969536319375, 14.61889760568738, 9.769923649728298, 5.786787858232856, 19.652444757521152, 30.2732415497303, 35.64512349665165, 42.81996309757233, 50.00188931822777, 51.06673277914524, 46.026310846209526, 43.27403873205185, 37.44178868830204, 38.82736913859844, 38.00942502915859, 37.16906972229481, 40.133560448884964, 46.83773450553417, 51.42573371529579, 50.93723572790623, 48.26640464365482, 50.50341300666332, 48.06943841278553, 47.409273236989975, 47.17110961675644, 46.16849921643734, 48.74425180256367, 51.34082347154617, 50.28639145195484, 51.318305879831314, 50.055344849824905, 50.059650018811226, 52.5887905061245, 50.20546719431877, 49.54231917858124, 50.41256748139858, 47.948601096868515, 45.372966304421425, 35.38939721882343, 34.378856644034386, 35.638234466314316, 35.795690417289734, 36.22574374079704, 34.879912957549095, 34.7321654856205, 34.73215788602829, 39.54530641436577, 41.68735407292843, 45.20510271191597, 45.292881801724434, 50.736196115612984, 42.685484513640404, 29.625235721468925, 51.49229094386101, 45.70580944418907, 45.746759846806526, 48.13718497753143, 49.13761809468269, 47.6612339168787, 46.947267428040504, 36.923773884773254, 36.061265766620636, 35.67409694194794, 36.903528571128845, 36.72404520213604, 40.14391869306564, 42.61866509914398, 44.865864515304565, 45.73469549417496, 50.955885127186775, 50.40648400783539, 50.2035216987133, 47.85324141383171, 45.738928467035294, 39.36222843825817, 40.80024227499962, 40.637386813759804, 39.41182337701321, 37.66336999833584, 42.370226830244064, 43.80480945110321, 47.12383635342121, 46.49603024125099, 47.24794529378414, 40.367707684636116, 35.44234737753868, 35.494685769081116, 44.46555979549885, 48.03281977772713, 50.96110984683037, 51.38807013630867, 52.74086594581604, 51.71208254992962, 52.973831444978714, 51.1648815125227, 52.161400839686394, 51.237210631370544, 51.17038741707802, 34.72326256334782, 21.959791146218777, 12.930888533592224, 17.400353103876114, 9.824707210063934, 4.732214296236634, 12.616307213902473, 1.0568627016618848, 0.28684037388302386, 0.4073408438125625, 0.09303601866122335, 0.7019360375124961, 12.537930719554424, 32.35930681228638, 36.403346210718155, 22.92638897895813, 27.905788086354733, 38.25822427868843, 49.50997531414032, 24.205269254744053, 2.311917068436742, 0.08498113369569182, 0.1061474897142034, 0.022573866917809937, 0.08728382497793064, 0.05882714453036897, 0.061435014358721673, 0.06487851278507151, 0.048330879435525276, 0.043331397901056334, 0.08146630003466271, 0.04276858649973292, 0.058715725899674, 0.0069540930326184025, 0.04523580821114592, 0.06087226232921239, 0.047311417147284374, 0.00899325370482984, 0.05397237437136937, 0.030287517947726883, 0.02844658723915927, 0.04559704117127694, 0.045546756955445744, 0.06689908404950984, 0.10028953256551176, 0.045590962981805205, 0.0065045069277402945, 0.10752198431873694, 0.028895510513393674, 0.033925551833817735, 0.019770956969296094, 0.0016814211403470836, 0.005715232409784221, 0.04218208203383256, 0.0592113914899528, 0.03957272791012656, 0.00902078367289505, 0.03639352311438415, 0.042789455692400225, 0.011936911032535136, 0.11514975587488152, 0.05185222173167858, 0.00568133759770717, 0.16574453824432567, 2.817580634728074, 25.157701447606087, 56.80643878877163, 50.82717843353748, 34.24498222768307, 24.646131098270416, 29.804403707385063, 30.642133355140686, 13.09780027717352, 1.026030562352389, 0.20662722730776295, 0.5222972924821079, 3.293620040640235, 6.277310186997056, 9.143355321139097, 8.527465369552374, 9.046471919864416, 9.98408680781722, 17.154135815799236, 28.34854982793331, 37.91016295552254, 45.07602743804455, 50.81370435655117, 52.812138721346855, 48.74903194606304, 44.04479317367077, 39.65496473014355, 41.418313309550285, 40.0053059309721, 38.533173725008965, 42.824849635362625, 47.81004533171654, 52.27077417075634, 50.81151947379112, 49.092453718185425, 53.32910098135471, 50.6523460149765, 49.27583567798138, 49.97187092900276, 48.75070005655289, 50.506631433963776, 52.122813910245895, 52.20251463353634, 51.042683869600296, 50.12386657297611, 50.907316133379936, 53.6251924932003, 50.03469295799732, 50.358640775084496, 52.17971585690975, 50.20015507936478, 48.56290653347969, 38.40430364012718, 35.311767384409904, 37.523978278040886, 37.81707935035229, 38.15585017204285, 36.34966269135475, 36.21418476104736, 37.48425900936127, 41.325092911720276, 44.621659219264984, 46.98577456176281, 47.986906841397285, 53.19559894502163, 44.87517021596432, 32.76268556714058, 50.82919992506504, 48.4476663172245, 47.47461833059788, 50.535889863967896, 51.823427975177765, 49.98081564903259, 49.67113986611366, 39.77019354701042, 38.37856002151966, 38.507388308644295, 39.4466333091259, 39.82435204088688, 41.1903103441, 46.02133311331272, 47.75654040277004, 48.33855897188187, 52.34155297279358, 50.80295093357563, 51.02088063955307, 51.74015164375305, 47.848845049738884, 41.64424918591976, 43.09567630290985, 43.205494210124016, 40.521458834409714, 40.55486284196377, 43.527295142412186, 45.62065601348877, 48.53207878768444, 49.16319452226162, 47.85625845193863, 41.718736588954926, 37.570343390107155, 39.46769557893276, 45.842989683151245, 50.692661851644516, 53.10930557549, 53.63819919526577, 54.25064653158188, 53.97321201860905, 54.765522703528404, 55.25193840265274, 55.24812340736389, 54.546160474419594, 52.07785852253437, 36.829892322421074, 24.243780188262463, 13.218586295843124, 5.5039196368306875, 15.154983289539814, 6.2972586415708065, 8.868386875838041, 2.570289191789925, 1.7747954651713371, 0.2575288951629773, 0.09601041296264157, 1.0430931905284524, 13.65140587091446, 35.90261667966843, 43.39037328958511, 32.0105767250061, 34.74112160503864, 45.2787047624588, 53.792778700590134, 30.914590135216713, 2.954183304682374, 0.11050393368350342, 0.06441605088184588, 0.045667942249565385, 0.0860864290734753, 0.027274570929876063, 0.014024296924617374, 0.13025959313381463, 0.0500193841435248, 0.03108639910351485, 0.05532002920517698, 0.009826470322877867, 0.03327427271869965, 0.05832368267874699, 0.022562732847291045, 0.010758955686469562, 0.045102210497134365, 0.024596325092716143, 0.07278749893885106, 0.04732959234388545, 0.04495571796724107, 0.053949178545735776, 0.11526461064931937, 0.14378913823748007, 0.11913021298823878, 0.15870413946686313, 0.12511817214544863, 0.33290414430666715, 0.06990572466747835, 0.15549918956821784, 0.12107973845559172, 0.13686368329217657, 0.10456028074258938, 0.10810660372953862, 0.11756923893699422, 0.17088541004341096, 0.2581036736955866, 0.254941382445395, 0.09882357568130828, 0.10982382213114761, 0.17373968032188714, 0.20992251142160967, 0.2203023520996794, 0.2756254537962377, 4.705206295475364, 32.448153644800186, 63.02682280540466, 56.4164999127388, 38.76630641520023, 29.37924452126026, 37.25931487977505, 36.77382633090019, 17.202104441821575, 1.3069351203739643, 0.3202159720240161, 1.2309440667741, 10.421102307736874, 17.44326040148735, 15.907201375812292, 21.136356331408024, 16.555559635162354, 10.943127796053886, 24.521824568510056, 32.58841551840305, 38.711631149053574, 45.59300869703293, 52.61229604482651, 55.71138694882393, 51.62375628948212, 47.08904542028904, 41.74342766404152, 43.00502076745033, 40.85400179028511, 40.62574803829193, 45.53213216364384, 50.178287252783775, 54.29956130683422, 52.626047506928444, 49.63720388710499, 53.8543201982975, 52.13146224617958, 52.20976464450359, 53.63493897020817, 50.7055127620697, 51.46620154380798, 54.83342885971069, 53.80042389035225, 54.34553883969784, 51.475214660167694, 51.7547694593668, 54.21039529144764, 50.144860446453094, 52.10461288690567, 53.92821103334427, 51.118702590465546, 50.66518172621727, 38.970055282115936, 37.381535321474075, 39.20394033193588, 39.323386922478676, 39.38856482505798, 38.19571763277054, 38.58119934797287, 39.15150314569473, 43.98580513894558, 46.5946539491415, 49.6129459887743, 52.6037123054266, 53.410959988832474, 48.13653141260147, 36.31902113556862, 52.26265400648117, 49.97513875365257, 48.56520541012287, 51.821490079164505, 53.64287294447422, 52.164873853325844, 52.72323489189148, 40.81251181662083, 41.46383486688137, 40.060782954096794, 40.93972139060497, 41.15637056529522, 42.82288134098053, 47.65160143375397, 50.23974135518074, 49.92565780878067, 56.52453571557999, 51.23595669865608, 52.09128700196743, 52.8656892478466, 51.341503635048866, 45.24931713938713, 44.20641750097275, 44.71497841179371, 43.089737221598625, 41.63518667221069, 45.95275439321995, 46.658764109015465, 52.35131084918976, 52.8174090385437, 51.585465744137764, 44.596835151314735, 40.219758823513985, 40.12590005993843, 49.13371570408344, 53.25802959501743, 56.847089007496834, 56.66867338120937, 58.48848693072796, 55.94876781105995, 57.96181619167328, 56.69583052396774, 57.47212126851082, 56.240113377571106, 57.520576268434525, 36.74235261976719, 25.451767668128014, 16.70463513582945, 27.586354427039623, 18.701876364648342, 10.85006508976221, 24.146556705236435, 6.229418981820345, 3.440591166727245, 0.7510571891907603, 0.2347396922414191, 1.4953121496364474, 15.286817215383053, 44.343096166849136, 48.33274148404598, 34.83627609908581, 40.40545865893364, 52.66463443636894, 63.19539315998554, 36.37454755604267, 4.549651192501187, 0.19899587117834017, 0.1704606640851125, 0.12811266380595043, 0.1783669859287329, 0.13335684256162494, 0.1208401880285237, 0.3690523764817044, 0.16771358961705118, 0.12152628129115328, 0.1277560173184611, 0.13908974040532485, 0.1372187861124985, 0.09506745496764779, 0.13224100868683308, 0.13200551038607955, 0.1562479868880473, 0.07716942083789036, 0.15287240239558741, 0.22670785838272423, 0.10186445899307728, 0.14656341983936727], [0.06493485663668253, 0.03956921755161602, 0.06944301043404266, 0.09901969562633894, 0.06920536732650362, 0.007041516637400491, 0.05020692115067504, 0.016786595624580514, 0.04303974499634933, 0.024227256908488926, 0.03816122240095865, 0.03963356175518129, 0.03141817251162138, 0.042044840374728665, 0.016831734901643358, 0.06574301834916696, 0.021729594154749066, 0.05565377672610339, 0.013675663776666624, 0.027876864587597083, 0.02486239802237833, 0.10048140000435524, 2.7513725124299526, 18.712711483240128, 45.478338450193405, 39.41289871931076, 31.589846201241016, 26.49815931916237, 20.747065320611, 27.622515186667442, 11.338861361145973, 1.4400666765868664, 0.2663100161589682, 1.4155078819021583, 2.074184250086546, 3.643119349144399, 6.334390724077821, 12.159930802881718, 10.667699575424194, 10.180605612695217, 18.61799206584692, 29.067161567509174, 39.15128655731678, 44.36652950942516, 52.029608711600304, 48.237043619155884, 46.799044981598854, 41.55567213892937, 40.35450719296932, 37.06639543175697, 37.83431522548199, 36.35101541876793, 43.41910734772682, 44.807081669569016, 51.76573947072029, 49.87787917256355, 48.173081651329994, 48.366555869579315, 44.74392905831337, 42.61307939887047, 43.55917923152447, 42.95639097690582, 44.705079942941666, 46.31221130490303, 47.398322224617004, 48.5675460845232, 48.58244128525257, 50.267597660422325, 48.81646312773228, 49.88827161490917, 50.554463267326355, 49.039055183529854, 45.50461404025555, 39.70334753394127, 33.89199256896973, 33.686290606856346, 34.007327780127525, 35.396301448345184, 34.469170197844505, 34.15656477212906, 35.55946469306946, 35.147399604320526, 35.74723161756992, 35.0794592499733, 42.12119959294796, 44.08371068537235, 49.75504316389561, 43.645529597997665, 29.858206920325756, 49.76214878261089, 46.55776172876358, 49.69753324985504, 49.859864339232445, 50.09284883737564, 47.17588596045971, 46.97988107800484, 37.645298168063164, 34.9820476770401, 35.07842570543289, 36.518339440226555, 35.988427475094795, 36.20987579226494, 36.62944547832012, 41.49007245898247, 45.49072578549385, 48.17520573735237, 49.45534564554691, 49.82221595942974, 51.491302996873856, 49.54553760588169, 42.64429472386837, 42.02520914375782, 41.40995755791664, 43.74167963862419, 44.352949038147926, 46.653721779584885, 51.51986986398697, 49.88048203289509, 51.6197969019413, 50.552054196596146, 48.441598042845726, 41.12697534263134, 33.86516980826855, 36.27119690179825, 41.07863053679466, 46.07819326221943, 47.78859928250313, 49.084470346570015, 50.529475808143616, 51.6974039375782, 49.141539484262466, 49.920885264873505, 50.21839030086994, 50.31989425420761, 40.130311623215675, 32.442708536982536, 15.829295106232166, 3.834575400687754, 8.301615938544273, 4.975320026278496, 5.344466418027878, 3.1932990113273263, 0.1999728343798779, 0.21045423054601997, 0.07423818984534591, 1.090519989375025, 12.818760350346565, 38.253451734781265, 39.92669954895973, 24.49726078659296, 29.48275286704302, 46.89383089542389, 46.66846118867397, 25.60254167765379, 2.9910862119868398, 0.04921449530229438, 0.05528033914742991, 0.07653282882529311, 0.03559949931513984, 0.03416206316614989, 0.018440538515278604, 0.07751032637315802, 0.026667818819987588, 0.04451163164048921, 0.08371479969355278, 0.04312885837862268, 0.027452875619928818, 0.02723483819863759, 0.03571495893993415, 0.0379696592426626, 0.017851124830485787, 0.0700404541566968, 0.06982540202443488, 0.12249869512743317, 0.07409802041365765, 0.06717737458529882, 0.052396048995433375, 0.05865991268365178, 0.039177118669613265, 0.06652677824604325, 0.11141147639136761, 0.08714588941074908, 0.04266160962288268, 0.024002816608117428, 0.038805028088972904, 0.12751839647535235, 0.008617088733444689, 0.04661522325477563, 0.13076410512439907, 0.07517014179029502, 0.10116508870851249, 0.06983893879805692, 0.03260941601183731, 0.08487255006912164, 0.04435078597452957, 0.023308561576413922, 0.04667364883061964, 0.09573296847520396, 3.5779967810958624, 24.29336942732334, 52.46357582509518, 46.32052905857563, 35.661816000938416, 29.043308347463608, 25.323083773255348, 31.770591102540493, 14.31059829890728, 1.4425477059558034, 0.2774202637374401, 0.46074944199062884, 3.2392589701339602, 6.567446943372488, 8.433245625346899, 14.41348347812891, 12.973879426717758, 11.047110166400671, 12.923895958811045, 30.072466023266315, 39.63735647499561, 46.172602996230125, 52.931813299655914, 49.87622246146202, 48.73738557100296, 44.136527851223946, 41.61860056221485, 39.521618485450745, 38.61798897385597, 38.07126671075821, 44.873289316892624, 47.19115354120731, 52.749309092760086, 50.26575095951557, 48.26626405119896, 50.99412627518177, 46.849441677331924, 46.09222590923309, 45.943946465849876, 44.35919590294361, 47.87942200899124, 49.428139105439186, 49.50403243303299, 50.347552970051765, 51.09480947256088, 52.02944532036781, 51.327079609036446, 51.573332995176315, 51.798303723335266, 51.98529548943043, 47.55407206714153, 41.52984492480755, 35.72464942932129, 35.959913805127144, 36.72655686736107, 36.82292729616165, 36.873696371912956, 36.352219954133034, 37.292715087533, 36.45783148705959, 37.10636928677559, 36.99231460690498, 43.45203258097172, 45.41987858712673, 51.74462780356407, 46.199957728385925, 32.79491923749447, 50.51526077091694, 48.895464688539505, 50.77759109437466, 51.79945506155491, 51.498864591121674, 49.43745240569115, 49.45495426654816, 40.392463356256485, 37.4545332044363, 36.96150965988636, 38.41652758419514, 37.21180222928524, 37.65250638127327, 39.12232831120491, 44.6016912907362, 46.417218670248985, 51.52596093714237, 50.796213895082474, 48.9938148111105, 51.0741575807333, 51.35586306452751, 44.067265167832375, 43.5267099738121, 43.84704798460007, 44.72333416342735, 44.91815730929375, 48.54518808424473, 52.06391707062721, 51.21821165084839, 52.53000386059284, 52.5753316283226, 50.484284833073616, 42.13952600955963, 37.48933173716068, 39.55213464796543, 42.38289155066013, 49.18750561773777, 49.98809225857258, 52.07390293478966, 52.34066762030125, 54.29622508585453, 51.762441247701645, 51.819251999258995, 54.17685069143772, 53.575741946697235, 40.4714535176754, 28.129293993115425, 12.883613370358944, 6.7511609103530645, 9.728403277695179, 5.846774289384484, 9.983085561543703, 4.062716346234083, 0.6189848855137825, 0.07853331015212461, 0.11150595179060474, 1.4842223259620368, 14.654873125255108, 43.15199688076973, 44.13267485797405, 28.936478979885578, 35.31020946800709, 54.70875754952431, 54.147835448384285, 29.190337657928467, 3.2351827388629317, 0.009197519648296293, 0.052147162350593135, 0.03126303025055677, 0.019405182065383997, 0.005263701414151001, 0.035642807342810556, 0.052326172080938704, 0.05230152906733565, 0.07648683051229455, 0.05485485846293159, 0.016210021094593685, 0.024314153124578297, 0.028216065038577653, 0.031818249481148086, 0.009255007335013943, 0.023573973994643893, 0.01761464689479908, 0.029538611161115114, 0.07731437712209299, 0.029420572573144455, 0.12418525540851988, 0.1674274620017968, 0.17140792653663084, 0.14854686887701973, 0.1798274731845595, 0.2165717093157582, 0.25460361619479954, 0.2346449496690184, 0.06320084343315102, 0.11860166283440776, 0.21732663677539676, 0.12780574121279642, 0.23861775523982942, 0.27048373594880104, 0.16158526064828038, 0.1570278505096212, 0.23543529241578653, 0.11808491282863542, 0.13178797205910087, 0.125310106377583, 0.09702869894681498, 0.14013615378644317, 0.2552727662259713, 4.6039151307195425, 29.760785847902298, 61.02670893073082, 52.37033262848854, 43.37932348251343, 37.35458716750145, 31.414723098278046, 38.93431819975376, 16.284862160682678, 2.038787961937487, 0.5771426588762552, 2.2455075569450855, 5.31058743596077, 10.588790159672499, 16.803184747695923, 24.061910547316074, 19.636943489313126, 19.248815216124058, 23.36316604167223, 32.63129621744156, 41.52887977659702, 48.633673936128616, 55.01695141196251, 53.86102303862572, 51.51322782039642, 45.90165853500366, 44.675992503762245, 42.43779860436916, 41.64364501833916, 39.08346779644489, 47.17048265039921, 49.71294902265072, 54.91167426109314, 50.209209993481636, 50.29844060540199, 53.61853525042534, 49.131926000118256, 46.11301839351654, 47.74652414023876, 47.75214783847332, 49.860764890909195, 52.56604492664337, 51.491979360580444, 53.31140153110027, 53.31693023443222, 54.59042049944401, 52.48828209936619, 53.39541882276535, 55.389479622244835, 53.84246863424778, 49.442046359181404, 42.95533083379269, 36.91185012459755, 38.006700575351715, 38.91605257987976, 38.98137107491493, 38.05151157081127, 38.708735704422, 39.1669987142086, 38.93135815858841, 39.826422929763794, 38.89476232230663, 45.47455005347729, 48.423032239079475, 54.4878526031971, 49.43737640976906, 35.92374734580517, 49.820357859134674, 49.79847863316536, 51.67278505861759, 53.42279635369778, 54.19802315533161, 52.69571676850319, 52.825293615460396, 41.96835279464722, 39.22113060951233, 38.69667515158653, 40.42894519865513, 39.62912231683731, 40.01632533967495, 40.02191483974457, 46.494377329945564, 50.08700855076313, 53.172948360443115, 51.49615153670311, 49.42071430385113, 54.05150681734085, 54.52582396566868, 46.81814655661583, 46.47294647991657, 47.77126081287861, 47.56485968828201, 47.31314979493618, 51.04300685226917, 55.3132139146328, 54.24074426293373, 53.40325020253658, 55.507835671305656, 53.40613044798374, 45.30501075088978, 39.47688348591328, 40.91697581112385, 44.71475422382355, 51.46151639521122, 53.460972905159, 55.181668773293495, 56.57650172710419, 56.73702031373978, 54.285201877355576, 55.67478351294994, 57.62974061071873, 55.60398571193218, 45.60587860643864, 32.19444885849953, 20.4566678032279, 11.11435990780592, 15.421069711446762, 13.241978790611029, 14.62006414309144, 11.201871111989021, 1.9610769068822265, 0.41223435779102147, 0.3175947954878211, 1.9268129579722881, 16.25004082918167, 48.19754093885422, 51.40411667525768, 37.25589506328106, 42.229379788041115, 61.57866731286049, 62.04527847468853, 35.07157847285271, 4.419308686628938, 0.11902050871867687, 0.2652312006102875, 0.12432221134076826, 0.0992630681139417, 0.08869913770467974, 0.16587477031862363, 0.13837036181939766, 0.1770570210646838, 0.21376343735028058, 0.13304022751981393, 0.14476581942290068, 0.1510130998212844, 0.08649603521917015, 0.1372560567688197, 0.10710016242228448, 0.23185171361546963, 0.28903074853587896, 0.1533019871567376, 0.25735888397321105, 0.1362166047329083, 0.2305362865445204], [0.014960507869545836, 0.017744715696608182, 0.07610277651110664, 0.004750129191961605, 0.02663517359906109, 0.02280283617437817, 0.03130213401163928, 0.03045430265046889, 0.05593144385784399, 0.07853023023926653, 0.019531209873093758, 0.06271749007282779, 0.022661483017145656, 0.04127794207306579, 0.040704117200220935, 0.04701308120274916, 0.021438904186652508, 0.09999951609643176, 0.046799498522887006, 0.01056430797689245, 0.03036913192772772, 0.025833481558947824, 1.752982260659337, 14.661722257733345, 41.38255722820759, 45.70636801421642, 36.39468267560005, 24.89022810012102, 24.077706299722195, 25.36397907882929, 15.864091739058495, 2.4305015802383423, 0.10274295404087752, 0.03532510876539163, 1.9605148932896554, 3.6688598804175854, 6.6619720961898565, 5.084478193894029, 8.798899054527283, 11.746569983661175, 10.241635087877512, 33.79926614463329, 42.471620589494705, 47.70856037735939, 49.108876436948776, 44.856988191604614, 46.90218664705753, 40.48382185399532, 37.93984696269035, 38.743215054273605, 41.57848231494427, 44.229087084531784, 46.64240978658199, 51.87282532453537, 52.88197137415409, 48.86730819940567, 48.71119737625122, 43.535647094249725, 44.02786128222942, 40.87840788066387, 38.95712457597256, 39.61669698357582, 40.59549406170845, 41.81938178837299, 43.17843206226826, 44.71692770719528, 45.55566810071468, 47.42645211517811, 46.60695008933544, 47.48122617602348, 46.563039645552635, 43.80916781723499, 40.93809127807617, 34.904626831412315, 33.96557182073593, 34.33732867240906, 34.80217672884464, 33.25709983706474, 33.49960282444954, 33.615234419703484, 34.982180669903755, 32.67951563000679, 35.250712260603905, 36.60470500588417, 41.71442002058029, 41.67032338678837, 48.92748937010765, 43.04144561290741, 31.217855662107468, 49.586856588721275, 48.95072132349014, 51.49036064743996, 49.122304916381836, 49.832133427262306, 44.1494357585907, 42.52654664218426, 35.773412212729454, 37.054057493805885, 37.2273775935173, 38.14479656517506, 37.17008426785469, 39.04357373714447, 38.252045810222626, 39.18708823621273, 44.892189502716064, 50.335606411099434, 51.55885577201843, 48.42521712183952, 50.188850685954094, 51.85206703841686, 50.01939877867699, 50.26190176606178, 48.45972687005997, 49.24380339682102, 48.73223304748535, 50.977889746427536, 50.16557693481445, 49.63624253869057, 48.59829783439636, 50.169635117053986, 49.90296922624111, 49.422811791300774, 38.22027571499348, 34.36091020703316, 35.761758238077164, 38.49399022758007, 40.379867032170296, 43.05842690169811, 44.24115143716335, 44.72282499074936, 46.79152898490429, 49.714541137218475, 50.256483256816864, 52.30704702436924, 40.60321904718876, 31.058146432042122, 13.70655421167612, 2.4811459751799703, 14.852253533899784, 3.9599518105387688, 7.104929052293301, 1.4426504191942513, 1.2737254961393774, 0.12322752867476083, 0.024767442082520574, 1.4545788103714585, 13.22306340560317, 33.89594815671444, 37.56798751652241, 26.823969036340714, 30.2254344150424, 41.837905794382095, 46.37393519282341, 22.357217520475388, 0.49800611624959856, 0.12123014952521771, 0.018595901565277018, 0.06451307926909067, 0.005434585555121885, 0.02035345198237337, 0.04481369316636119, 0.010499333875486627, 0.05603951540251728, 0.05027309474826325, 0.05214300261286553, 0.011782535966631258, 0.005021594288336928, 0.06641437255893834, 0.030110005500318948, 0.09192069686832838, 0.04136304785788525, 0.026127342352992855, 0.1106596807949245, 0.032856046527740546, 0.018690102369873784, 0.021288198113325052, 0.02280567859997973, 0.02965041570860194, 0.060496023143059574, 0.041523292384226806, 0.0014511867539113155, 0.03842897815047763, 0.10128697162144817, 0.023763648387102876, 0.046337942039826885, 0.14969620329793543, 0.017964493454201147, 0.10209834683337249, 0.028788236777472775, 0.0553378852782771, 0.020623228228942025, 0.06423633982194588, 0.030051971407374367, 0.020404348470037803, 0.053632745330105536, 0.048819045623531565, 0.014234178142942255, 0.05150302640686277, 2.717226119711995, 19.14984382688999, 47.842362597584724, 49.74133349955082, 41.98254123330116, 28.43587104231119, 27.23397083580494, 31.20634038001299, 16.9904899969697, 2.697977777570486, 0.06186089580296539, 0.4151144251227379, 1.73780718119815, 4.6598856523633, 8.154573328793049, 8.614833131432533, 10.369806960225105, 9.56859715282917, 15.323570743203163, 25.578365474939346, 40.01855581998825, 48.76186765730381, 52.61857710778713, 48.76548886299133, 49.10212799906731, 43.02819572389126, 39.77967023849487, 39.05538730323315, 42.89609581232071, 45.244012624025345, 48.85351113975048, 53.24070632457733, 53.673506900668144, 49.22585316002369, 50.44699363410473, 45.81390984356403, 44.832798689603806, 42.31959454715252, 42.39375896751881, 41.210407465696335, 43.37234705686569, 45.00999078154564, 45.94609335064888, 47.672264724969864, 48.98816451430321, 48.68140697479248, 49.642466604709625, 49.79844443500042, 49.89452227950096, 45.622624307870865, 43.21481131017208, 37.02612519264221, 37.57016479969025, 36.35491020977497, 36.64955019950867, 35.12851841747761, 36.03418841958046, 35.72151839733124, 36.65356658399105, 35.04892788827419, 37.57328063249588, 38.37626874446869, 45.52365101873875, 45.09375348687172, 51.68833002448082, 45.35310097038746, 33.91948789358139, 48.60441170632839, 49.93104211986065, 53.68673399090767, 51.28202922642231, 51.55866198241711, 47.88524329662323, 44.59595359861851, 37.600802555680275, 38.37995454668999, 39.167595282197, 39.62857514619827, 38.32548826932907, 39.75256249308586, 39.475587755441666, 41.205099150538445, 46.83412849903107, 51.52474880218506, 52.49945729970932, 48.491994738578796, 51.35649003088474, 52.78650909662247, 52.74453654885292, 51.07258826494217, 51.4258287101984, 51.634722501039505, 52.549850195646286, 51.41818352043629, 52.59045101702213, 49.933850169181824, 49.74276602268219, 52.279783487319946, 50.45819543302059, 51.043060049414635, 40.51702067255974, 36.08186446130276, 39.18825477361679, 41.30175456404686, 43.538295552134514, 46.17975041270256, 47.252440452575684, 48.029935732483864, 48.888750448822975, 51.63929745554924, 51.79314360022545, 54.64860677719116, 41.70402757823467, 32.58113890886307, 19.450552091002464, 6.648440547287464, 11.306490898132324, 6.1791191808879375, 8.738253358751535, 4.168553967028856, 1.1184117989614606, 0.4776051890803501, 0.08103618834866211, 1.4536634157411754, 14.974365681409836, 37.835531160235405, 42.72754065692425, 30.271014869213104, 36.528800278902054, 48.489471673965454, 54.15084108710289, 26.168371215462685, 1.1436676187440753, 0.04101206024643034, 0.032071069508674555, 0.02641779854457127, 0.010989138354489114, 0.00379880510536168, 0.07519163438701071, 0.027733739552786574, 0.027823617347166874, 0.06409213310689665, 0.058189157280139625, 0.02511040151148336, 0.03638219051936176, 0.07839477344532497, 0.07783667839248665, 0.03272056746936869, 0.034786647229338996, 0.0385646538779838, 0.030279244856501464, 0.04402510188810993, 0.016260835946013685, 0.05045311751018744, 0.07635927016963251, 0.14268256636569276, 0.19644849380711094, 0.12038893255521543, 0.09131473329034634, 0.10781929609947838, 0.21115475858096033, 0.12220864155096933, 0.14424444583710283, 0.19990944012533873, 0.09792759563424625, 0.21981375175528228, 0.12683697132160887, 0.23045163718052208, 0.1699658000143245, 0.1336748676840216, 0.14681085187476128, 0.22992211481323466, 0.18870140716899186, 0.09188060605083592, 0.09208917923388071, 0.20367527555208653, 3.5082486737519503, 24.537242241203785, 55.51727436482906, 58.28268617391586, 49.186266884207726, 36.77036851644516, 35.78003145754337, 36.069480925798416, 21.029259078204632, 3.4751013899222016, 0.30130688042845577, 0.9811020107008517, 4.355907188728452, 7.713119192048907, 14.794347491115332, 11.143999267369509, 16.768405213952065, 17.72913996130228, 12.04769242554903, 36.591021940112114, 45.54320476949215, 50.52400790154934, 53.96072968840599, 49.52972665429115, 51.19461111724377, 45.920782908797264, 41.81040666997433, 42.74595446884632, 45.23806594312191, 47.75733456015587, 51.016066297888756, 55.80923929810524, 54.916420206427574, 50.15056774020195, 53.20045128464699, 49.041859433054924, 48.67597706615925, 46.75784759223461, 44.080393463373184, 42.93706141412258, 45.0711864978075, 45.90516954660416, 49.154382795095444, 50.14511503279209, 50.88583968579769, 53.20616997778416, 51.53821147978306, 51.83039680123329, 51.40471704304218, 47.73469157516956, 44.13275845348835, 38.6696358025074, 38.99916552007198, 38.73178146779537, 38.5414382815361, 36.99639938771725, 37.71628215909004, 37.84903943538666, 38.677185997366905, 37.90154121816158, 39.64045710861683, 41.57775275409222, 48.21625113487244, 47.51586131751537, 53.40116411447525, 48.88879984617233, 37.89163514971733, 49.86255459487438, 50.350828394293785, 56.68848551809788, 54.27176579833031, 53.87587644159794, 49.34012822806835, 46.918833553791046, 39.287627041339874, 40.857151821255684, 40.529503002762794, 41.47880606353283, 40.162974670529366, 41.958705112338066, 41.802909672260284, 44.85047534108162, 48.47358472645283, 55.90063959360123, 54.01432201266289, 48.65143418312073, 50.99576398730278, 55.69347470998764, 54.39869038760662, 54.252136051654816, 53.31256806850433, 53.452035784721375, 53.553668931126595, 54.169315695762634, 53.57021704316139, 51.295225918293, 50.520128309726715, 52.77134791016579, 52.70990140736103, 54.078857749700546, 42.25456863641739, 38.06095406413078, 40.8256971091032, 43.02716217935085, 44.490923434495926, 48.12042027711868, 50.84592662751675, 48.53827625513077, 51.645852103829384, 54.77748446166515, 55.4529932141304, 55.922264233231544, 45.36386579275131, 34.70555551350117, 17.792410366237164, 6.3926962204277515, 26.052863113582134, 11.033727284520864, 15.598473642021418, 4.530068943277001, 2.956372224725783, 0.9047083568293601, 0.1359764309017919, 2.066860618069768, 17.38544460386038, 43.095550909638405, 51.11771084368229, 38.8869309425354, 43.266788721084595, 54.844467267394066, 61.94991119205952, 33.81990663707256, 1.7890087212435901, 0.1295198648585938, 0.13622258644318208, 0.16517816082341596, 0.12080282089300454, 0.08902456946088932, 0.14396922779269516, 0.14679443556815386, 0.11530268282513134, 0.25151007750537246, 0.1469319110037759, 0.12209757915115915, 0.21301352680893615, 0.15574007586110383, 0.2662311407038942, 0.17362516693538055, 0.12001027396763675, 0.15067987551447004, 0.12011196304229088, 0.14388616662472486, 0.1478852442232892, 0.2198921819217503], [0.031445275744772516, 0.0781484175240621, 0.06607049101148732, 0.011591021047934191, 0.01922209052281687, 0.016847743027028628, 0.06726527455612086, 0.002084492443827912, 0.00812561813290813, 0.042839810412260704, 0.03925745615561027, 0.008590204433858162, 0.029244848701637238, 0.04309222968004178, 0.013506010673154378, 0.019096700962109026, 0.031979150808183476, 0.08858466884703375, 0.01427414743375266, 0.07099526425008662, 0.0206000620892155, 0.011691470735968323, 0.9420715738087893, 12.491465862840414, 39.87396977841854, 46.79561756551266, 38.59781585633755, 27.2938347235322, 18.866382837295532, 32.688198164105415, 16.84329729527235, 3.5296341637149453, 0.14705935260280967, 0.20135083934292197, 3.300446611829102, 6.23027678579092, 7.357919001951814, 14.497475121170282, 15.036737434566021, 5.900741843506694, 18.05197063833475, 20.387393720448017, 35.44471465051174, 48.58599789440632, 52.04300299286842, 45.660337284207344, 43.863854482769966, 39.348967149853706, 39.07648757100105, 40.53072653710842, 44.53498587012291, 48.88101026415825, 50.2120104432106, 52.15057522058487, 46.69765502214432, 48.80271926522255, 48.71382683515549, 42.553392201662064, 39.75933752954006, 37.33013927936554, 35.625045374035835, 35.417439714074135, 35.13832949101925, 35.61514310538769, 35.65418981015682, 36.91727243363857, 39.11793194711208, 38.19005973637104, 40.406150221824646, 39.418340027332306, 38.06624338030815, 35.46836458146572, 34.479296654462814, 33.905839025974274, 33.336215391755104, 35.564161241054535, 34.63491730391979, 35.67327618598938, 37.256886810064316, 37.270592674613, 41.63058131933212, 42.55982905626297, 43.057176768779755, 41.99288807809353, 45.40309488773346, 45.564468428492546, 51.12584240734577, 43.753645196557045, 31.384056843817234, 50.96142143011093, 52.17913828790188, 44.81845445930958, 44.219219014048576, 41.802472695708275, 40.60983829200268, 38.12166340649128, 35.73523946106434, 36.46285101771355, 36.52854189276695, 35.43831579387188, 34.08931978046894, 35.81352286040783, 35.36832734942436, 37.81067669391632, 43.99232938885689, 47.88072533905506, 49.37116116285324, 48.522256314754486, 49.11227725446224, 47.32650987803936, 51.193520575761795, 47.40908324718475, 51.142660304903984, 50.69142311811447, 49.05699782073498, 49.753789231181145, 48.75927619636059, 51.16808094084263, 48.97353909909725, 47.1392597258091, 52.39255763590336, 50.16778081655502, 47.078212201595306, 37.496365159749985, 35.12792184948921, 37.26361244916916, 37.03025557100773, 41.08995012938976, 39.98624995350838, 43.33250239491463, 47.798174768686295, 52.19816006720066, 49.162160977721214, 54.37372572720051, 42.04326577484608, 30.15512488782406, 14.66958498582244, 10.111531969159842, 3.089182935655117, 3.6174037540331483, 9.978844039142132, 3.876912253908813, 0.37620385992340744, 0.4140310676302761, 0.18535295559559017, 1.1055260966531932, 15.309346206486225, 44.80439901351929, 49.51919361948967, 29.788942337036133, 34.252243638038635, 40.514170825481415, 45.80960087478161, 23.089998699724674, 1.4338812022469938, 0.0796967453788966, 0.01998848787479801, 0.05416888765466865, 0.028101846655772533, 0.0760350852215197, 0.027852839411934838, 0.02486296019924339, 0.021083556457597297, 0.052551050248439424, 0.044127380970166996, 0.029823375080013648, 0.008345077694684733, 0.04293365869671106, 0.04048998162033968, 0.044049162315786816, 0.06720019562635571, 0.05784631102869753, 0.07263688006787561, 0.053615679644281045, 0.0340303542179754, 0.07988972603925504, 0.011171473834110657, 0.04736688526463695, 0.057176181362592615, 0.030167416189215146, 0.08333560675964691, 0.023596067730977666, 0.04621057836629916, 0.06499046576209366, 0.032518280277145095, 0.040224923577625304, 0.015072798523760866, 0.025613620309741236, 0.024650056584505364, 0.035999806350446306, 0.02255488834634889, 0.013430912749754498, 0.06727711181156337, 0.07708267119596712, 0.09576968994224444, 0.010139890418940922, 0.0765940040582791, 0.030650478256575298, 1.349390004761517, 16.015743501484394, 46.36006973683834, 52.20803573727608, 42.37252190709114, 33.36618818342686, 25.412800759077072, 35.940861627459526, 20.564874596893787, 3.6747450521215796, 0.3306967893149704, 0.26252239127643406, 1.0962980543263257, 4.6460591442883015, 8.465962819755077, 11.8914695084095, 9.951700195670128, 7.976357191801071, 13.67950726300478, 22.79324982315302, 39.26410250365734, 50.84210783243179, 53.89087803661823, 49.51200820505619, 45.98944902420044, 42.06133760511875, 39.968558102846146, 42.24933631718159, 45.76047711074352, 50.63717722892761, 53.03490936756134, 53.1854572892189, 48.57647180557251, 49.292410388588905, 50.52264757454395, 44.297707602381706, 43.093620613217354, 39.18116055428982, 37.46131204068661, 37.16802857816219, 37.74517200887203, 38.522944673895836, 39.0134983509779, 38.50863844156265, 42.21586771309376, 40.66071756184101, 43.14123585820198, 41.713196486234665, 39.98886041343212, 38.039998188614845, 36.85870237648487, 34.40770089626312, 34.84259136021137, 36.236911341547966, 36.45044848322868, 36.594513952732086, 38.4032016992569, 39.23530384898186, 41.97806507349014, 43.218717500567436, 45.50178699195385, 43.77812348306179, 47.806845903396606, 46.374394968152046, 52.90985427796841, 45.35830669105053, 34.057922065258026, 53.15538190305233, 53.375656083226204, 47.92941592633724, 46.91724143922329, 46.61293476819992, 43.226313292980194, 40.35336725413799, 36.881223767995834, 39.06304769217968, 37.80984453856945, 38.15240755677223, 36.47686846554279, 36.89344771206379, 37.36698970198631, 41.63800612092018, 46.049892380833626, 50.23208096623421, 50.098092555999756, 50.228759944438934, 47.900229692459106, 47.6917614787817, 52.33829654753208, 49.96949225664139, 51.61486096680164, 49.58415113389492, 49.281751960515976, 51.59271955490112, 48.93089018762112, 50.112497583031654, 49.05206948518753, 49.7817063331604, 52.35349953174591, 51.991166174411774, 49.38644014298916, 40.197085440158844, 37.49539241194725, 38.875219970941544, 39.818500354886055, 42.78888836503029, 44.432440772652626, 45.52431598305702, 50.821262151002884, 54.200196638703346, 54.04078759253025, 55.35155385732651, 46.28914654254913, 28.057692535221577, 18.164083622395992, 8.081484250724316, 8.933651223778725, 7.595221493393183, 10.015836954116821, 3.9177743112668395, 1.08260192675516, 0.3884606366045773, 0.07685139571549371, 1.6798859392292798, 15.399156287312508, 48.120568469166756, 49.1118972748518, 33.61691392958164, 35.96439376473427, 49.080260172486305, 52.275056540966034, 27.95122604817152, 1.712617026641965, 0.06584951654076576, 0.0926697242539376, 0.023424690989486407, 0.011506675036798697, 0.05265650572255254, 0.06384644511854276, 0.03439499363594223, 0.03969405792304315, 0.05838309531100094, 0.029801761884300504, 0.019540418070391752, 0.04147280407778453, 0.059747645136667415, 0.03597333394282032, 0.03205374407116324, 0.037255676070344634, 0.031061431400303263, 0.03071159040700877, 0.06642416148679331, 0.04010569384263363, 0.033603118354221806, 0.11424760858062655, 0.18556847528088838, 0.12650060030864552, 0.11990532686468214, 0.18599448289023712, 0.19128102343529463, 0.11890304900589399, 0.1093467696045991, 0.14652708428911865, 0.09849599169683643, 0.1255400534137152, 0.10470793844433501, 0.17839094245573506, 0.13051440211711451, 0.07619656913448125, 0.20583716657711193, 0.15016001590993255, 0.24877653981093317, 0.15204805444227532, 0.08004927294678055, 0.11922726363991387, 0.11980448383837938, 1.8074815487489104, 19.676088988780975, 52.23545506596565, 59.63512480258942, 48.83274145424366, 39.634373635053635, 31.019322015345097, 43.07634674012661, 23.820418305695057, 4.949015937745571, 0.5991104675922543, 0.7003850082401186, 6.016463208943605, 12.355855889618397, 15.572803169488907, 28.579450137913227, 27.342914789915085, 10.7987754419446, 21.523542255163193, 26.138651110231876, 39.738210663199425, 52.69662871956825, 55.22391490638256, 51.82742916047573, 49.888795986771584, 43.483954668045044, 41.71470120549202, 44.25801493227482, 49.51460346579552, 52.9471530765295, 55.16319036483765, 53.65813672542572, 49.24870513379574, 50.80271154642105, 54.48828957974911, 47.565916031599045, 44.25790473818779, 42.15888597071171, 38.94359350204468, 39.12408001720905, 40.11904142796993, 40.72610445320606, 38.7854839861393, 40.251255333423615, 43.397611901164055, 42.119558081030846, 44.440028965473175, 43.428078666329384, 42.09449082612991, 39.694794192910194, 39.32001270353794, 37.59568803012371, 37.02683575451374, 38.97537499666214, 38.43953914940357, 38.88582140207291, 41.983631774783134, 41.39111056923866, 45.12420505285263, 44.68616455793381, 49.14124310016632, 45.94857841730118, 50.97136169672012, 50.43675698339939, 55.05520395934582, 48.1838084757328, 37.919328063726425, 54.13495413959026, 56.38578616082668, 49.32585999369621, 49.299166426062584, 47.491303235292435, 46.06141336262226, 42.01969563961029, 39.05001439154148, 41.06703735888004, 39.0429961681366, 38.47474426031113, 38.16907726228237, 37.95481435954571, 38.95922966301441, 42.874216586351395, 48.417389541864395, 52.40707665681839, 54.232437908649445, 50.11183261871338, 49.914197623729706, 47.86720186471939, 52.10142105817795, 49.57252375781536, 53.415257558226585, 51.73292823135853, 50.01116842031479, 52.62432619929314, 50.534692928195, 50.890258848667145, 50.03723122179508, 50.85905872285366, 53.84901188313961, 55.0925749540329, 50.99367789924145, 44.40098986029625, 38.90427701175213, 42.62143895030022, 41.332217529416084, 45.74590489268303, 44.968930184841156, 48.87387424707413, 53.24680879712105, 58.34383249282837, 55.33591389656067, 58.17935451865196, 46.04160122573376, 31.54154509305954, 19.0015871822834, 14.136084113270044, 9.949449766427279, 10.99707255139947, 19.920113794505596, 9.536720663309097, 1.9600773230195045, 0.5961698410101235, 0.3147154109319672, 1.8010867293924093, 19.734117574989796, 55.123315304517746, 58.83921191096306, 41.021238416433334, 45.90583451092243, 57.05170802772045, 60.12736938893795, 32.035788372159004, 2.8563898522406816, 0.2147466197493486, 0.17460091301472858, 0.0862774504639674, 0.09207173876347952, 0.18391939345747232, 0.14040338632185012, 0.11869525507790968, 0.09996592649258673, 0.14479528268566355, 0.1558847798150964, 0.17005890986183658, 0.11168262004503049, 0.14416825695661828, 0.19007901137229055, 0.11473453167127445, 0.13046273379586637, 0.19207761506550014, 0.2480052999453619, 0.15813813311979175, 0.1098127789737191, 0.12000000264379196], [0.0812807037436869, 0.012187572338007158, 0.0465302436350612, 0.03608863400586415, 0.03950403101043776, 0.020041989300807472, 0.015361610858235508, 0.07679126691073179, 0.05446637012937572, 0.034888930022134446, 0.019958772281825077, 0.008898182732082205, 0.04104341227503028, 0.007744782733425382, 0.03139479485980701, 0.10169736444368027, 0.026001347941928543, 0.014968280011089519, 0.08911240263842046, 0.07069583734846674, 0.08669421833474189, 0.05036944778112229, 0.4396500054281205, 8.91164280474186, 38.53884682059288, 48.71293008327484, 36.55604101717472, 21.469803638756275, 22.46487334370613, 31.585104055702686, 22.903324216604233, 5.4235610738396645, 0.20946303295204416, 0.0618318778288085, 0.4870109906187281, 1.7923614475876093, 6.16962444037199, 5.444181617349386, 2.5894862366840243, 7.227184167131782, 14.691757746040821, 14.549589324742556, 37.1422203630209, 47.94176526367664, 48.041521310806274, 44.286388009786606, 42.20134109258652, 39.32227738201618, 42.93768838047981, 45.246243104338646, 47.68019109964371, 51.659744158387184, 48.417020961642265, 47.95168273150921, 49.403090849518776, 51.317929700016975, 48.36224690079689, 43.46095450222492, 40.31163029372692, 34.53302577137947, 34.36103940010071, 34.04815658926964, 37.932380363345146, 34.5550037920475, 34.808377996087074, 34.29454296827316, 33.97227846086025, 34.31725814938545, 35.60715973377228, 34.75031331181526, 33.77144783735275, 34.20881576836109, 39.618106707930565, 44.83556494116783, 34.74753566086292, 32.61844530701637, 33.55390951037407, 36.22782222926617, 46.731028631329536, 45.98571002483368, 46.13351069390774, 44.35390658676624, 44.605722874403, 48.16974923014641, 47.174210250377655, 42.95027710497379, 50.72433315217495, 42.14796535670757, 27.278749532997608, 52.76830047369003, 48.04399497807026, 45.853005945682526, 40.552974343299866, 37.89892315864563, 36.285138353705406, 35.642041862010956, 33.88401299715042, 35.66400468349457, 34.079580903053284, 35.23080512881279, 34.83684606850147, 35.356821566820145, 35.590873807668686, 35.15193276107311, 40.46486847102642, 47.206307128071785, 49.34813819825649, 48.59507940709591, 49.84738200902939, 50.36662794649601, 50.075084790587425, 49.51550021767616, 50.09148471057415, 48.933314457535744, 49.3738704174757, 46.006612703204155, 48.55688765645027, 48.39960269629955, 51.40089064836502, 48.09469185769558, 47.53036893904209, 51.48777298629284, 51.419673040509224, 45.870105028152466, 39.45929042994976, 35.618433728814125, 37.5284506380558, 39.19167838990688, 43.22258569300175, 44.86777201294899, 48.81109781563282, 52.176022455096245, 53.28172892332077, 52.34341487288475, 46.29762388765812, 31.552587300539017, 31.99238710105419, 9.64507944881916, 10.127657353878021, 5.5607289634644985, 7.128255050629377, 3.0532449390739202, 1.8837416754104197, 0.5690398311708122, 0.023006251431070268, 1.795851916540414, 13.516069483011961, 31.92976266145706, 45.664342269301414, 37.103717029094696, 37.17217795550823, 39.86334174871445, 42.14817054569721, 21.81911889463663, 1.5926907118409872, 0.007751807161184843, 0.06653301228652708, 0.029496013739844784, 0.01730327512632357, 0.0512386771151796, 0.04226761084282771, 0.04378298363008071, 0.033493581067887135, 0.07891158282291144, 0.030623885249951854, 0.0024508684873580933, 0.06966135028051212, 0.061813921565772034, 0.052363479844643734, 0.05704984927433543, 0.10516378781176172, 0.03609504987252876, 0.03681493311887607, 0.039378852961817756, 0.03697952663060278, 0.002017661349782429, 0.005950232080067508, 0.03282111734733917, 0.035849139239871874, 0.025459084754402284, 0.005155904464118066, 0.05259156780084595, 0.04502411429712083, 0.07735457926173694, 0.02662470746145118, 0.07132851824280806, 0.04716735886177048, 0.0816700715222396, 0.0333089198829839, 0.04124087921809405, 0.02599017861939501, 0.07449311757227406, 0.013251225809653988, 0.023519821334048174, 0.024831693517626263, 0.07014241782599129, 0.09701059796498157, 0.034977935792994685, 0.8484757679980248, 11.553926020860672, 44.74401645362377, 53.91925871372223, 43.429545387625694, 24.990877099335194, 28.679519668221474, 39.133480712771416, 24.202829785645008, 6.659705992788076, 0.2338892949046567, 0.14494350441964343, 0.6677649461198598, 2.13996893260628, 7.335463631898165, 9.032257832586765, 7.277183784171939, 6.846591839566827, 14.12044795230031, 23.967791497707367, 41.00397974252701, 51.22617982327938, 49.98249135911465, 48.93039621412754, 45.556431859731674, 42.13178962469101, 42.23590783774853, 47.746733129024506, 50.256749242544174, 53.936483189463615, 50.22364541888237, 49.59474116563797, 49.092153534293175, 51.796631813049316, 49.51556861400604, 45.252862349152565, 42.62781120836735, 37.74353429675102, 34.95508052408695, 36.44392043352127, 38.871302381157875, 37.114675641059875, 36.6390323638916, 36.47133596241474, 36.30585864186287, 36.084341928362846, 35.43591812252998, 35.55449455976486, 36.418036222457886, 35.96663184463978, 40.78858070075512, 45.35292237997055, 36.45273216068745, 34.75918963551521, 35.211369171738625, 39.22909498214722, 47.09847651422024, 48.048201352357864, 47.95237049460411, 44.54221688210964, 46.83569021522999, 49.22784045338631, 50.73582373559475, 47.87675455212593, 50.368691235780716, 43.61448526382446, 30.522035099565983, 55.2744559943676, 49.38153460621834, 48.04851673543453, 43.547042682766914, 40.104723796248436, 38.536080569028854, 38.0272650718689, 36.60402484238148, 36.77929423749447, 36.41943834722042, 37.059707790613174, 37.48626530170441, 37.2210281342268, 37.24679455161095, 36.24535448849201, 42.88069523870945, 49.12496477365494, 52.444846630096436, 50.56566506624222, 52.64692358672619, 52.05501414835453, 50.78931726515293, 48.89341279864311, 50.15195086598396, 50.17265595495701, 50.35353384912014, 48.3511058986187, 52.755799144506454, 49.44035924971104, 51.62362329661846, 49.16239656507969, 49.86418090760708, 53.228463381528854, 53.392945155501366, 47.70731784403324, 39.53944332897663, 37.70153895020485, 38.752277567982674, 41.34201340377331, 44.97739613056183, 47.93546140193939, 50.47448515892029, 56.13973416388035, 55.42011737823486, 54.426409900188446, 45.33874534070492, 31.27074882388115, 16.62142340093851, 3.6480576591566205, 9.831193462014198, 12.058979719877243, 9.86958660185337, 6.568465288728476, 2.2273851418867707, 0.25041923916433007, 0.10685946166631766, 1.5773112745955586, 15.875345785170794, 38.19908805191517, 52.915211990475655, 41.76117271184921, 43.873817548155785, 46.6049399971962, 50.0791771709919, 26.052770018577576, 2.234771945513785, 0.04840781417442486, 0.04752884786284994, 0.05645037948852405, 0.010972628351737512, 0.05086693163320888, 0.03773462478420697, 0.05516610777704045, 0.0278275952587137, 0.03530326364852954, 0.0017826605198933976, 0.041430820783716626, 0.05713061349524651, 0.051673052439582534, 0.02266147559566889, 0.09254085773136467, 0.04522308037849143, 0.04202957068628166, 0.06337858780170791, 0.03957693217671476, 0.024775796809990425, 0.029919943335698918, 0.18843399651814252, 0.05930803396040574, 0.10324813396437094, 0.11667070590192452, 0.0662817656120751, 0.186534128151834, 0.11099698691396043, 0.21404393948614597, 0.10390615178039297, 0.196609421109315, 0.20122433284996077, 0.1550456482800655, 0.16972244979115203, 0.11097513066488318, 0.04708253138232976, 0.2062712487531826, 0.12342736677965149, 0.06955512668355368, 0.12078023733920418, 0.1334887815755792, 0.12328877070103772, 0.21499568450963125, 1.4068925566971302, 14.789033476263285, 50.173845291137695, 61.15962579846382, 47.90226638317108, 32.78776802122593, 32.36341819167137, 42.230143547058105, 29.836158603429794, 7.837625211104751, 0.546602332033217, 0.36587090813554823, 1.0002844501286745, 7.366651883348823, 9.478446990251541, 11.781258322298527, 8.684910871088505, 12.964647822082043, 18.5349665209651, 17.685778588056564, 41.232575476169586, 52.95330114662647, 53.05389314889908, 49.55181106925011, 47.36881300806999, 42.725188583135605, 46.7214797437191, 51.02820284664631, 52.379391342401505, 57.20651552081108, 52.66726389527321, 49.650560170412064, 50.41988968849182, 53.80040869116783, 54.015503749251366, 48.84833201766014, 45.74645586311817, 38.99701863527298, 37.05314554274082, 37.78972081840038, 41.48336201906204, 38.95266741514206, 39.828326627612114, 37.73919112980366, 37.75770753622055, 38.482161462306976, 38.32193166017532, 38.14890034496784, 38.725173622369766, 38.9151406288147, 42.72268071770668, 47.35522873699665, 37.87569880485535, 35.9765987098217, 37.90717251598835, 40.38796439766884, 51.37441746890545, 51.529316157102585, 50.87090648710728, 47.54454977810383, 49.105137437582016, 51.814741641283035, 51.63792572915554, 49.66532617807388, 52.821452021598816, 44.74624313414097, 33.64859662950039, 56.26709572970867, 51.97140343487263, 50.14722391963005, 46.20295196771622, 41.34061507880688, 41.216794922947884, 39.76471424102783, 37.70786941051483, 38.378195241093636, 39.14670020341873, 38.8407976180315, 38.79547744989395, 38.26632924377918, 39.252725914120674, 39.513737708330154, 44.237431436777115, 51.35540708899498, 54.49264034628868, 54.23529915511608, 54.254115745425224, 55.55754840373993, 52.22048006951809, 49.032059758901596, 51.80333085358143, 52.07626260817051, 52.846773862838745, 49.29809868335724, 53.34821775555611, 51.88620060682297, 53.14687795937061, 49.554554522037506, 49.73950579762459, 54.74643632769585, 57.063673585653305, 48.69404889643192, 43.01029488444328, 39.0833044052124, 41.537851095199585, 44.64195013046265, 47.975328862667084, 49.92973119020462, 54.32865634560585, 57.52210758626461, 58.35545226931572, 56.74376115202904, 48.34619276225567, 37.47225925326347, 34.54110413789749, 17.05988187342882, 15.563456621021032, 10.889367330819368, 14.683246202766895, 8.29516388475895, 2.8414785023778677, 1.3833411829546094, 0.1785779042984359, 2.496631806716323, 19.341545440256596, 43.544025644659996, 57.88289822638035, 48.606634587049484, 51.28387212753296, 55.5464605987072, 60.81841170787811, 32.20675639808178, 3.273416287265718, 0.19133886642521247, 0.12986439949600026, 0.17721779993735254, 0.11635818009381182, 0.27802775613963604, 0.12796953320503235, 0.1322007694398053, 0.09433260260266252, 0.09812329255510122, 0.19488400197587907, 0.15878590929787606, 0.1967304208665155, 0.11235338053666055, 0.12735344673274085, 0.1514360200962983, 0.27960677922237664, 0.15149160695727915, 0.1861214792006649, 0.13283854146720842, 0.0775224382232409, 0.09907662577461451], [0.050059575150953606, 0.027057850820710883, 0.030095667207206134, 0.004064256718265824, 0.021417385614768136, 0.06147254847746808, 0.02168486491427757, 0.027620335677056573, 0.09110348837566562, 0.03684620351123158, 0.051255486760055646, 0.044681464714813046, 0.028903854108648375, 0.08281899034045637, 0.013675127574970247, 0.0054471157909574686, 0.04478314636799041, 0.07521116029238328, 0.016798453289084136, 0.03498269295960199, 0.036763676689588465, 0.05677809334883932, 0.2638129860861227, 8.168427385389805, 34.89630527794361, 48.509899377822876, 41.58043920993805, 31.003205180168152, 22.17299960553646, 36.13302871584892, 25.430485010147095, 6.005834229290485, 0.8081747149117291, 0.12264249366126023, 0.6155092001426965, 1.7785607068799436, 8.689167592674494, 10.36232991144061, 8.824256993830204, 4.777958616614342, 7.095299893990159, 28.746019899845123, 37.495722994208336, 47.32368662953377, 49.522902220487595, 45.710091814398766, 41.03781692683697, 42.448217645287514, 43.73900458216667, 46.86944380402565, 48.70052754878998, 50.59447132050991, 46.77767872810364, 49.27098333835602, 49.46443475782871, 48.27810421586037, 49.03442703187466, 43.69900792837143, 40.86315929889679, 36.25070460140705, 35.928246304392815, 31.775105260312557, 35.4915851354599, 35.2545652538538, 36.4390604943037, 34.711084216833115, 37.064088955521584, 34.59026210010052, 36.54420085251331, 34.94900465011597, 37.000119388103485, 34.603808373212814, 39.32697772979736, 43.47421199083328, 34.888926073908806, 35.26443712413311, 35.903422236442566, 42.334227561950684, 52.61785514652729, 48.40621054172516, 48.624729216098785, 47.642740309238434, 48.77748101949692, 48.31693433225155, 42.44179219007492, 37.67909735441208, 43.490231931209564, 40.364705845713615, 26.362481899559498, 53.06663006544113, 48.55758301913738, 42.88558937609196, 36.61942161619663, 36.403638795018196, 34.80138257145882, 35.76838128268719, 34.74676050245762, 34.989658668637276, 35.9996634721756, 35.84515616297722, 34.675977900624275, 35.82374431192875, 35.84164135158062, 35.493956208229065, 33.79830479621887, 39.14999842643738, 44.43925000727177, 45.77130272984505, 47.18328416347504, 46.86583399772644, 48.018798530101776, 50.266723707318306, 50.00376641750336, 48.09643216431141, 46.653687581419945, 46.17034211754799, 46.96842469274998, 48.01327362656593, 48.41547064483166, 51.63664899766445, 49.598818346858025, 49.633856266736984, 52.48767793178558, 49.431893303990364, 46.96297578513622, 39.1405863314867, 37.79543191194534, 40.30832827091217, 45.85295654833317, 46.28737963736057, 50.61986155807972, 49.75392982363701, 54.41520810127258, 53.04398328065872, 46.97717942297459, 26.6018595546484, 12.013904638588428, 1.6724081779830158, 9.688806552439928, 13.09460274875164, 6.754419710487127, 3.8548950478434563, 2.526811924763024, 0.18243221857119352, 0.13949075248092413, 1.7855563689954579, 16.763801760971546, 33.95862199366093, 33.66711683571339, 30.046293027698994, 27.507483959197998, 43.651548475027084, 45.765941217541695, 18.213224485516548, 1.2754498911090195, 0.04146106701227836, 0.0375656637334032, 0.06509371334686875, 0.04660687409341335, 0.053787275319336914, 0.06107093155151233, 0.06278186396230012, 0.05223353720793966, 0.05620053918391932, 0.0541019719094038, 0.014407568887691014, 0.04310779993829783, 0.06554191117174923, 0.05556571719353087, 0.029111265830579214, 0.03291108791017905, 0.020210775946907233, 0.008368598209926859, 0.013126984722475754, 0.07701177382841706, 0.010914568283624249, 0.01776144556060899, 0.03356535416969564, 0.025267347191402223, 0.025949087757908273, 0.027944678331550676, 0.06677599885733798, 0.03911791383870877, 0.0640782252594363, 0.0658888800535351, 0.013193020095059182, 0.047442940558539703, 0.01821176592784468, 0.03682306705741212, 0.08320676992298104, 0.04234279040247202, 0.03618762166297529, 0.05563109298236668, 0.01751901931129396, 0.05332330314558931, 0.011839557027997216, 0.056312655433430336, 0.061213431326905265, 0.23831424652598798, 10.449600778520107, 40.389719903469086, 55.97973994910717, 44.197514578700066, 35.453070402145386, 25.62354315072298, 37.74852342903614, 31.81209247559309, 7.304778378456831, 0.7740282628219575, 0.06381986881024204, 0.7491032034158707, 1.5506267314776778, 5.674775568768382, 6.6131209675222635, 7.619503615424037, 8.388065099716187, 9.561820216476917, 25.962593257427216, 41.24221935868263, 50.692806243896484, 52.58923888206482, 47.09541767835617, 44.396373108029366, 43.33232760429382, 45.65709985792637, 49.87366519868374, 50.981446355581284, 52.73252159357071, 47.03956447541714, 49.28725026547909, 50.89552916586399, 48.300097435712814, 51.65441684424877, 44.918997064232826, 43.159984052181244, 37.492257580161095, 37.5089006870985, 32.95995198190212, 36.556044816970825, 36.95294871926308, 38.66842366755009, 35.55829055607319, 38.842952102422714, 36.93360775709152, 37.93316312134266, 37.17211335897446, 38.507027328014374, 36.4622088521719, 42.39146389067173, 45.52241608500481, 37.0695036649704, 36.709446385502815, 37.86297328770161, 42.495494708418846, 53.6815282702446, 50.53193047642708, 50.372833013534546, 48.69572840631008, 49.835416451096535, 49.97948572039604, 45.210612416267395, 39.518719241023064, 45.72860062122345, 43.0135665088892, 30.247847512364388, 54.45846877992153, 49.45488967001438, 45.109237655997276, 39.91178534924984, 37.90784887969494, 36.90229743719101, 37.86332666873932, 36.61771930754185, 37.476754412055016, 37.16394379734993, 38.86265404522419, 36.98808543384075, 37.63853073120117, 38.11141915619373, 35.80768257379532, 36.75475515425205, 42.31708288192749, 48.20799417793751, 47.31372356414795, 48.65871079266071, 48.8368946313858, 51.215935572981834, 51.84912219643593, 52.568001821637154, 49.18481536209583, 49.67755392193794, 48.4275957942009, 50.318028554320335, 49.84881453216076, 51.41285240650177, 52.74986006319523, 49.322208389639854, 51.21543399989605, 53.535000532865524, 52.21194952726364, 49.075723215937614, 39.986781924963, 38.935435339808464, 42.32619099318981, 46.08908347785473, 49.05609726905823, 53.097374215722084, 53.63345704972744, 56.3845132291317, 55.4714298248291, 46.933975741267204, 25.2725787833333, 14.22366751357913, 7.71371528506279, 16.76224574446678, 20.275639817118645, 10.69089638069272, 4.015519078820944, 1.3557100156322122, 0.10177144562476315, 0.1551054950687103, 2.2064682142809033, 18.223983608186245, 38.08087259531021, 37.24262237548828, 35.55078595876694, 35.20612545311451, 50.51611192524433, 53.59475992619991, 22.278966419398785, 1.6773420944809914, 0.033361931491526775, 0.06059135943360161, 0.05806833563838154, 0.08297545733512379, 0.05966378615994472, 0.04305081041820813, 0.049370661727152765, 0.014311126797110774, 0.04336371101089753, 0.02347728699533036, 0.04208257487334777, 0.056509944261051714, 0.024144253256963566, 0.039406186260748655, 0.03000474112923257, 0.04434969130670652, 0.1070014048309531, 0.01608046623005066, 0.03503917781927157, 0.13890784000977874, 0.02930327427748125, 0.1409458665875718, 0.1373610706650652, 0.118783845246071, 0.13346267282031476, 0.14140112965833396, 0.20906043268041685, 0.07511215779231861, 0.1553232708829455, 0.1345855274121277, 0.1613672325038351, 0.13498224987415597, 0.1660108208307065, 0.1571272240835242, 0.2770890580723062, 0.11442593924584799, 0.11794573787483387, 0.15417074522702023, 0.10334863560274243, 0.15062638150993735, 0.17751182400388643, 0.1749306046986021, 0.3390192333608866, 0.6884136912412941, 13.243569005280733, 47.08478204905987, 62.08625167608261, 54.4400055706501, 40.49283877015114, 30.509182289242744, 46.47728964686394, 35.50958476960659, 7.972871828824282, 1.1773209879174829, 0.38549994234927, 1.0934718372300267, 4.498255150392652, 15.98372831940651, 22.20164816826582, 17.486688271164894, 11.455209217965603, 10.430414658039808, 33.16515237092972, 41.16617403924465, 51.642713472247124, 54.68316592276096, 50.743795707821846, 46.6839187592268, 47.6480258256197, 48.78217376768589, 51.07520632445812, 53.264025673270226, 54.43891882896423, 49.90387737751007, 49.70416009426117, 49.97144915163517, 50.41830137372017, 54.43307854235172, 48.62896218895912, 44.80103239417076, 39.867662116885185, 39.59990568459034, 34.242519959807396, 38.31816226243973, 39.358295649290085, 40.96044547855854, 37.782630398869514, 40.2647940069437, 39.664103239774704, 39.72113057971001, 38.99465896189213, 41.24114781618118, 38.55484016239643, 43.209248408675194, 46.098985746502876, 39.45957541465759, 40.5734096467495, 40.14955759048462, 44.735409915447235, 55.82979239523411, 53.62959645688534, 53.75935189425945, 50.50654783844948, 50.864773616194725, 52.493913397192955, 46.50153614580631, 40.65994240343571, 45.93878634274006, 45.93973249197006, 36.10960677266121, 56.360164135694504, 52.355912402272224, 46.27447172999382, 40.19262447953224, 39.47178415954113, 39.05664503574371, 39.443764463067055, 39.366905987262726, 38.98422472178936, 38.565426394343376, 39.60542678833008, 38.09946119785309, 38.48091512918472, 39.55678179860115, 38.63458648324013, 38.690340891480446, 44.74090062081814, 50.38708984851837, 50.64110241830349, 52.30455815792084, 52.18685567378998, 53.23339931666851, 54.00268703699112, 55.27881056070328, 51.30490019917488, 51.979470402002335, 53.08529086410999, 51.8863146007061, 52.7338021248579, 53.1466955691576, 54.21906262636185, 52.34586954116821, 51.51263885200024, 56.32891081273556, 54.864780977368355, 52.08797737956047, 42.29973681271076, 41.445170268416405, 44.38468873500824, 50.52365072071552, 50.35592012107372, 55.68590171635151, 55.405773147940636, 59.99898187816143, 57.031618505716324, 49.816843047738075, 29.35488972812891, 16.08910046517849, 7.467501796782017, 23.04213646799326, 25.02358004450798, 16.406079456210136, 9.118289016187191, 4.10997393541038, 0.36257541622035205, 0.40732552588451654, 2.859326619654894, 22.090730220079422, 46.879866644740105, 45.295104682445526, 42.98929341137409, 41.338297203183174, 58.9881107211113, 61.59592978656292, 28.179645091295242, 2.7497333753854036, 0.160617470392026, 0.1591514318715781, 0.1539429949480109, 0.18032141699222848, 0.17405026912456378, 0.20067221950739622, 0.1264469133457169, 0.1689922358491458, 0.12318403139943257, 0.12848706246586516, 0.07855313291656785, 0.13247258844785392, 0.1588187419110909, 0.16127780370879918, 0.08409702058997937, 0.1294566784054041, 0.1951391078182496, 0.11520671570906416, 0.10120972146978602, 0.2762512327171862, 0.09034609698574059], [0.017706953367451206, 0.03910457744495943, 0.05330189218511805, 0.038300430751405656, 0.06583878508536145, 0.06234379645320587, 0.042935254314215854, 0.02026413450948894, 0.03843902683001943, 0.02688249802304199, 0.09550993825541809, 0.06654390701442026, 0.059584298433037475, 0.03955058964493219, 0.021257397129375022, 0.05160419597814325, 0.06090460141422227, 0.0077825510925322305, 0.06790273488149978, 0.074420758173801, 0.07302455574972555, 0.0393927199911559, 0.29326704621780664, 6.612249864265323, 33.125490099191666, 43.9797368645668, 40.20033806562424, 26.93979062139988, 29.563853815197945, 32.765444219112396, 29.97908603399992, 11.94190800189972, 0.9861082420684397, 0.17699423537123948, 0.6832976220175624, 0.6420884176623076, 4.184117456898093, 5.792457154020667, 5.877935467287898, 6.262566028162837, 9.508323837071657, 24.624179676175117, 40.107201263308525, 50.40013834834099, 46.95145100355148, 46.21712140738964, 43.505161330103874, 45.4984849691391, 47.020801082253456, 53.55460748076439, 51.87942557036877, 47.37723335623741, 49.927154928445816, 46.800982877612114, 49.37864676117897, 50.565353482961655, 47.982928454875946, 43.24909307062626, 43.85285787284374, 39.2782187461853, 35.4043760150671, 33.70967835187912, 35.44824466109276, 36.122655272483826, 36.131136417388916, 37.95037999749184, 37.31030814349651, 40.87009772658348, 38.37898179888725, 37.45611771941185, 33.77147063612938, 36.48660734295845, 34.155386835336685, 33.20505402982235, 33.78554508090019, 35.063549503684044, 36.17954961955547, 47.387097626924515, 49.303695783019066, 51.684758216142654, 49.59124155342579, 46.60702608525753, 48.003002777695656, 46.63397803902626, 44.40624117851257, 48.3115766197443, 44.64828439056873, 44.05491963028908, 29.176229014992714, 43.50893072783947, 48.767153173685074, 43.333710730075836, 35.21393783390522, 37.494822442531586, 38.14512334764004, 35.91656573116779, 38.24793443083763, 37.258387729525566, 34.63073752820492, 33.86560298502445, 34.586743488907814, 34.895921498537064, 34.484065398573875, 34.011914134025574, 35.32953143119812, 34.2211689054966, 38.45089294016361, 39.91006784141064, 41.465312987565994, 44.146749302744865, 45.08151434361935, 45.80817975103855, 43.967706710100174, 43.45834404230118, 43.14107246696949, 43.0104810744524, 43.53081755340099, 43.06302085518837, 45.23050054907799, 48.57430212199688, 52.93449215590954, 47.61924996972084, 51.22700817883015, 49.311952739953995, 49.70103286206722, 43.176433369517326, 38.69684614241123, 43.446336686611176, 46.916508078575134, 49.922120198607445, 50.21685518324375, 52.098141834139824, 52.5026985257864, 57.207967042922974, 43.07043805718422, 23.998110070824623, 11.329166181385517, 2.836364689283073, 14.982843026518822, 21.049561388790607, 11.134339235723019, 5.438137091696262, 1.0846680658869445, 0.05235610660747625, 0.20086382719455287, 2.1408616472035646, 17.67184093594551, 36.31964050233364, 46.078926622867584, 34.48450617492199, 34.91392493247986, 38.69943380355835, 46.01357392966747, 16.599397882819176, 1.5114701888523996, 0.04150190739892423, 0.07362010699580424, 0.045813559045200236, 0.034961730998475105, 0.049944186030188575, 0.062133601677487604, 0.018515072406444233, 0.02134390000719577, 0.03689519639010541, 0.07423948118230328, 0.009865084266493795, 0.023972332892299164, 0.06122358019638341, 0.03478191974863876, 0.04992608133761678, 0.05057091490016319, 0.02219700618297793, 0.03242537452024408, 0.01565780199598521, 0.04923586544464342, 0.05941894050920382, 0.07060078307404183, 0.10632571647875011, 0.08638945539132692, 0.015289834045688622, 0.025567488410160877, 0.02400174234935548, 0.01884284007246606, 0.01135499118390726, 0.08069667805102654, 0.007642879827471916, 0.07619379350217059, 0.014923947819625027, 0.06833216379163787, 0.0617080950178206, 0.06225970369996503, 0.05099270711070858, 0.058508009897195734, 0.03629247599747032, 0.028028383312630467, 0.039549198118038476, 0.07340877302340232, 0.011349806354701286, 0.41997581894975156, 8.362690061330795, 39.34245049953461, 50.42189598083496, 46.55753754079342, 30.373463071882725, 30.684649273753166, 39.06679429113865, 30.09488482028246, 12.18020936474204, 1.0133614484220743, 0.15157481655478477, 0.8078611129894853, 1.4668895560316741, 6.730015045031905, 6.4774867706000805, 9.375079236924648, 8.67885209619999, 12.689014412462711, 25.115234926342964, 41.256559789180756, 53.11691276729107, 50.66767819225788, 49.09160636365414, 45.20044416189194, 47.07016423344612, 48.67478393018246, 53.21038395166397, 52.76740752160549, 48.74248489737511, 51.068982258439064, 48.179195523262024, 49.38958257436752, 51.04518413543701, 51.70536071062088, 45.7108935713768, 44.487021043896675, 41.11494518816471, 36.1087404191494, 35.226796343922615, 36.64026729762554, 37.52135641872883, 37.12892487645149, 38.996817246079445, 39.81636866927147, 41.97045028209686, 39.68004338443279, 37.14298032224178, 35.19124165177345, 37.916360422968864, 35.62974572181702, 34.38077554106712, 35.80727219581604, 36.472882479429245, 38.28391470015049, 48.7650290876627, 51.92259885370731, 52.8110595792532, 50.707462057471275, 48.383388966321945, 48.336997255682945, 46.51367649435997, 45.91682732105255, 46.5794737637043, 43.760066851973534, 46.86217859387398, 31.584877967834473, 46.389761343598366, 51.51550009846687, 44.908114448189735, 37.185393646359444, 39.4419177621603, 39.819503501057625, 37.31909707188606, 39.935534074902534, 38.57215203344822, 37.51077018678188, 35.53534738719463, 36.51583157479763, 36.46845191717148, 36.88293367624283, 35.786456912755966, 35.91978415846825, 35.738872066140175, 40.59371955692768, 42.04943284392357, 45.64275562763214, 47.390072867274284, 47.36130841076374, 49.21126954257488, 46.45116984844208, 45.96158131957054, 45.03129243850708, 46.39084808528423, 46.42308555543423, 45.711573734879494, 46.90375216305256, 52.31247313320637, 53.74630719423294, 48.427303209900856, 52.07909345626831, 52.1627763658762, 51.07097715139389, 45.301594734191895, 39.93798114359379, 44.13186930119991, 47.507372573018074, 52.00066566467285, 53.6013525724411, 53.73455822467804, 55.15278272330761, 56.86365231871605, 46.56031519174576, 27.540006414055824, 13.009731452912092, 7.302493751049042, 4.897686392068863, 11.510828733444214, 7.804348496720195, 6.2177816312760115, 0.9046226239297539, 0.15008885879069567, 0.12201525270938873, 1.9126462494023144, 19.420698992908, 40.26260532438755, 48.13422493636608, 36.78119793534279, 37.97088369727135, 46.250920593738556, 53.478843346238136, 21.414243020117283, 1.9189719599671662, 0.05879057149286382, 0.06068284768844023, 0.005641406805807492, 0.09097435467992909, 0.02357338398724096, 0.09804240587982349, 0.014251335669541731, 0.05913475732086226, 0.03260714503994677, 0.043207930502831005, 0.02337826408620458, 0.031946845119819045, 0.030559381484636106, 0.03143191337585449, 0.031635725681553595, 0.029049572949588764, 0.028460077628551517, 0.053598970189341344, 0.03830210800515488, 0.05014952344936319, 0.004137323012400884, 0.07885308674303815, 0.18450494797434658, 0.1855044427793473, 0.07952504951390438, 0.18492853618226945, 0.20009604573715478, 0.1030141867522616, 0.08544962925952859, 0.15209958917694166, 0.1587621754151769, 0.1567270135274157, 0.1446042093448341, 0.193074022536166, 0.1815704515320249, 0.13502317189704627, 0.1358465402154252, 0.17252107383683324, 0.174273225129582, 0.24268617911729962, 0.15561695356154814, 0.16407103976234794, 0.12257389695150778, 0.6061448995023966, 10.873049106448889, 44.41249184310436, 56.692642495036125, 53.24897848069668, 37.01015084981918, 37.170680835843086, 42.41541400551796, 36.389549151062965, 14.797824304550886, 1.904033061582595, 0.39982879534363747, 2.0547634921967983, 2.9735480155795813, 12.62069882825017, 13.08706870302558, 12.356033530086279, 9.827767945826054, 14.371384587138891, 28.260852433741093, 45.96013739705086, 55.64319580793381, 51.154641062021255, 50.43989561498165, 48.02028805017471, 49.412841126322746, 49.87911410629749, 55.020610615611076, 53.05158667266369, 50.50053656101227, 53.18618685007095, 48.714647591114044, 48.24683949351311, 51.91557303071022, 53.309577628970146, 47.46217779815197, 47.491877004504204, 44.44404534995556, 39.00611534714699, 37.17188537120819, 39.53499376773834, 39.41066063940525, 39.62303124368191, 41.60743676126003, 41.0582560300827, 45.44575899839401, 41.137869358062744, 40.31562387943268, 37.7436026930809, 39.388352036476135, 37.98324443399906, 35.75327329337597, 38.65436442196369, 38.19509446620941, 40.00989228487015, 51.813841089606285, 54.74895179271698, 54.57919590175152, 51.62338770925999, 47.27341152727604, 49.151209965348244, 47.23880298435688, 43.448301181197166, 46.045613810420036, 46.06535755097866, 45.10281600058079, 35.34591615200043, 50.47958828508854, 52.6671727001667, 46.394769474864006, 39.26358573138714, 41.36118717491627, 42.70867466926575, 39.968926683068275, 41.908521205186844, 41.77544094622135, 38.6674053221941, 37.648189812898636, 38.38258020579815, 37.8542223572731, 40.185218676924706, 37.59802870452404, 39.15727883577347, 37.36729748547077, 43.097017630934715, 44.1084473580122, 46.0430945456028, 48.72964918613434, 49.633309096097946, 51.57870590686798, 49.07598540186882, 49.08628664910793, 47.26656809449196, 48.19159045815468, 48.94803486764431, 48.775402531027794, 49.13679353892803, 55.245091170072556, 55.018524527549744, 47.71520622074604, 55.08952371776104, 54.34980981051922, 54.11344729363918, 48.588558956980705, 42.332118675112724, 46.98982894420624, 50.11524483561516, 55.35073310136795, 57.03967027366161, 56.89125403761864, 56.39076389372349, 59.59843397140503, 46.236291378736496, 29.230870082974434, 15.184366162866354, 8.830756545066833, 23.307134248316288, 30.979146771132946, 20.986161790788174, 10.267305560410023, 4.09114214591682, 0.48456234857439995, 0.2978086634539068, 3.148863483220339, 22.177375070750713, 48.48904609680176, 59.64090809226036, 45.151221603155136, 47.80640132725239, 53.91626067459583, 64.20635551214218, 28.215045891702175, 2.745040152221918, 0.15811457735253498, 0.1525068946648389, 0.14525979291647673, 0.17910914844833314, 0.092859305877937, 0.2212014640099369, 0.11983392483671196, 0.08404651001910679, 0.07201090076705441, 0.14492806774796918, 0.12777872703736648, 0.12851576873799786, 0.1799608371220529, 0.10654270561644807, 0.1611718992353417, 0.10156687261769548, 0.14017979206983, 0.11056674164137803, 0.17804522038204595, 0.11734974876162596, 0.12870078615378588], [0.02348029454878997, 0.02737168837484205, 0.013458896355587058, 0.0038252844706221367, 0.037300019394024275, 0.017146854515885934, 0.020580172531481367, 0.0033614660605962854, 0.024444351802230813, 0.01684860762907192, 0.030038106233405415, 0.015143684759095777, 0.023773450302542187, 0.04429743297805544, 0.06443945821956731, 0.059075292738270946, 0.060265397041803226, 0.09184469352476299, 0.01328790924162604, 0.04862548608798534, 0.07676604873267934, 0.02561521778261522, 0.16269046696834266, 5.10709410533309, 28.473416827619076, 52.39381916821003, 38.135114684700966, 35.937232822179794, 28.51995673030615, 32.84511834383011, 34.16108652949333, 13.216299768537283, 1.7114521516487002, 0.0460833111719694, 0.4901405383134261, 1.6058780229650438, 4.849722515791655, 2.7054837998002768, 7.174583589658141, 11.211519744247198, 7.3438250832259655, 17.91221983730793, 36.28885455429554, 47.16878794133663, 52.5223358720541, 44.41086933016777, 46.96099229156971, 48.81472662091255, 51.63892887532711, 48.909527733922005, 50.769322738051414, 51.67618967592716, 50.791198164224625, 50.149731785058975, 49.827930852770805, 48.65403324365616, 49.804991483688354, 45.9491141885519, 43.243917748332024, 40.60609169304371, 35.4106380790472, 33.79221752285957, 34.83808100223541, 37.37757973372936, 39.184861555695534, 42.90688343346119, 48.071304112672806, 48.232799246907234, 49.202036038041115, 46.31129555404186, 39.2645812779665, 34.73437696695328, 35.35758912563324, 34.93344068527222, 32.75810681283474, 33.04942958056927, 32.94297829270363, 42.30626106262207, 50.15105031430721, 47.73323245346546, 49.472600519657135, 47.8293064981699, 52.80889369547367, 54.2059875279665, 51.97263456881046, 50.3000745177269, 50.0000312179327, 44.58126358687878, 29.392608404159546, 47.898470386862755, 50.50239086151123, 42.77561567723751, 40.35826899111271, 40.21467849612236, 41.91279977560043, 41.348811239004135, 41.21520660817623, 40.363212525844574, 36.907240971922874, 35.96216708421707, 34.60647203028202, 34.85881268978119, 35.705179274082184, 34.968725591897964, 35.62268570065498, 35.47028347849846, 34.995772540569305, 33.8393197953701, 35.71973629295826, 35.91950677335262, 38.57851669192314, 39.41090762615204, 39.944873973727226, 41.88127666711807, 40.493237748742104, 38.402171954512596, 39.194570034742355, 42.56151236593723, 43.56836713850498, 45.70810832083225, 51.02010168135166, 49.08773437142372, 51.9965922832489, 47.45324447751045, 48.84133279323578, 46.465153098106384, 36.89999856054783, 43.488974198699, 47.48426601290703, 50.142021998763084, 51.65920838713646, 52.55364999175072, 53.206451162695885, 53.22874836623669, 45.93593269586563, 20.709707625210285, 10.901090651750565, 13.151082918047905, 10.09395221248269, 11.850018482655287, 6.2521265633404255, 3.4327455377206206, 0.38856976199895144, 0.12930734344990924, 0.11303045670501888, 2.2627002093940973, 21.044766046106815, 41.52254171669483, 40.38246609270573, 35.46665087342262, 36.74197643995285, 44.571855291724205, 44.16622705757618, 12.363583724945784, 1.2813332816585898, 0.0784360665420536, 0.069169031776255, 0.028736399617628194, 0.04386147316836286, 0.045717183747910894, 0.06035607264493592, 0.011699712285917485, 0.041819056787062436, 0.07218553553684615, 0.009754035781952552, 0.046711168106412515, 0.07486101501854137, 0.01757182126311818, 0.046971060801297426, 0.06297293730312958, 0.02377879005507566, 0.0523579990840517, 0.03678344008221757, 0.09950586172635667, 0.02617223115521483, 0.02009373183682328, 0.051191691745771095, 0.052662138623418286, 0.023301715264096856, 0.05469263611303177, 0.057753583387238905, 0.06211455074662808, 0.034300269617233425, 0.025648573609942105, 0.021056529294583015, 0.032472686434630305, 0.048399008592241444, 0.07757503422908485, 0.06901213433593512, 0.03444045018113684, 0.052073890110477805, 0.024653537257108837, 0.050416963786119595, 0.04145924875047058, 0.007839960853743833, 0.07498827108065598, 0.03528788634866942, 0.026494781523069832, 0.19146923208609223, 6.836642548441887, 33.44696044921875, 56.53562352061272, 42.762069404125214, 40.58982476592064, 32.53498278558254, 31.75420068204403, 38.17362941801548, 15.067389439791441, 1.7362096044234931, 0.15242417488479987, 0.22146626230096444, 1.7522321571595967, 4.099270859733224, 7.2987367026507854, 8.574335854500532, 9.543965924531221, 10.451801810413599, 21.009726226329803, 39.76206958293915, 49.967140182852745, 53.41019243001938, 45.94293192028999, 49.1947328299284, 50.42362488806248, 52.644176334142685, 50.859457701444626, 51.009454652667046, 51.97818227112293, 52.49151572585106, 50.94030596315861, 51.27079322934151, 48.472570180892944, 51.40814445912838, 47.802384942770004, 44.670779183506966, 41.624186262488365, 38.183691278100014, 35.57463727891445, 35.98955221474171, 38.452515453100204, 40.288797318935394, 44.57745619118214, 50.17826825380325, 49.0223702788353, 50.10813921689987, 45.994753539562225, 40.64222015440464, 37.598469480872154, 36.619877591729164, 36.97364240884781, 36.168780997395515, 35.73674038052559, 35.05045920610428, 44.36940215528011, 52.60008729994297, 49.36956524848938, 52.18989931046963, 49.8907832801342, 52.08278685808182, 53.576000332832336, 52.24063038825989, 50.673229694366455, 50.185309275984764, 46.29098184406757, 30.94039835035801, 48.97737689316273, 53.443478643894196, 45.21142937242985, 41.972638964653015, 40.974383130669594, 42.781322970986366, 42.1567352861166, 43.30322876572609, 40.21379694342613, 38.11309486627579, 35.95895625650883, 36.44691467285156, 36.199369356036186, 37.86146476864815, 36.596725434064865, 37.131679728627205, 37.23814241588116, 35.74573829770088, 35.14466755092144, 37.374699488282204, 38.271158784627914, 40.62104009091854, 42.98580139875412, 42.5916713476181, 43.29447403550148, 42.67125807702541, 41.67537331581116, 41.40619955956936, 44.86231550574303, 46.0317749530077, 48.07660102844238, 52.842400297522545, 49.3237891048193, 52.700439915061, 49.792771339416504, 51.57521389424801, 49.04679536819458, 40.41578650474548, 45.429237484931946, 51.01738482713699, 52.78313867747784, 54.48059879243374, 54.50095809996128, 55.0845991820097, 55.859278813004494, 47.635794281959534, 24.55878708511591, 15.630076546221972, 10.38853045552969, 6.363094383850694, 11.380200292915106, 8.707166276872158, 4.960267608985305, 0.9289306914433837, 0.18978440843056887, 0.15926484687952325, 2.999196401797235, 21.82903066277504, 45.16100987792015, 49.55755636096001, 40.44441416859627, 40.841280072927475, 49.510769471526146, 51.97613798081875, 17.74381287395954, 1.2444390426389873, 0.039804600819479674, 0.0806189380818978, 0.027910914323001634, 0.08127141205477528, 0.05337059650628362, 0.03888933606503997, 0.016208881897910032, 0.08004677933058701, 0.01061968239810085, 0.03661758120870218, 0.060010291199432686, 0.028336654759186786, 0.06130377296358347, 0.014455140553764068, 0.03248212284233887, 0.04684837636887096, 0.11678081093123183, 0.06638578503043391, 0.02638137579197064, 0.015599641737935599, 0.026331863409723155, 0.1570339361205697, 0.1163580316642765, 0.12823066528653726, 0.10213963993010111, 0.11472399317426607, 0.10699738239054568, 0.12239666466484778, 0.09355768168461509, 0.13833742530550808, 0.13234988175099716, 0.12793641857570037, 0.09876958443783224, 0.14964606380090117, 0.22032616019714624, 0.16875320492545143, 0.17478441644925624, 0.17938234785106033, 0.151377969305031, 0.11813947552582249, 0.1382091228151694, 0.19534975901478902, 0.07214318859041668, 0.32613427320029587, 8.514198381453753, 39.30092632770538, 65.15921518206596, 49.78749342262745, 49.329644590616226, 39.337157383561134, 42.19342991709709, 43.65719877183437, 18.007372431457043, 2.586053595878184, 0.30262238171417266, 1.1395289283245802, 4.204173255711794, 8.506765030324459, 9.204866420477629, 15.971470177173615, 20.985736213624477, 12.63543538749218, 20.573355741798878, 39.93074633181095, 50.61879001557827, 57.216140404343605, 48.4700471162796, 53.384600803256035, 53.79605792462826, 56.92008689045906, 51.911606043577194, 51.19692139327526, 54.62278716266155, 53.29975135624409, 54.0127032995224, 53.38892117142677, 49.815737307071686, 53.08564804494381, 50.79406701028347, 47.852671444416046, 43.60546454787254, 39.821604788303375, 37.16715842485428, 38.031156063079834, 41.63959443569183, 42.62102857232094, 48.08618791401386, 52.87206910550594, 50.87911404669285, 51.92934349179268, 50.157954543828964, 43.36434468626976, 39.82049524784088, 39.01273459196091, 38.99931751191616, 36.688076332211494, 37.14003548026085, 36.46518789231777, 46.64578780531883, 56.75368621945381, 52.657228633761406, 52.60633036494255, 51.843167915940285, 54.79844033718109, 55.28395928442478, 54.02170121669769, 51.92758418619633, 51.507946103811264, 45.76660618185997, 35.256894528865814, 51.6089940816164, 54.51955050230026, 48.24892558157444, 45.49189232289791, 43.72994966804981, 46.822789907455444, 44.46376249194145, 47.22583808004856, 43.35228033363819, 40.70987552404404, 38.127078115940094, 37.786308601498604, 39.04208801686764, 38.9971212297678, 38.99610288441181, 39.59100276231766, 39.92749750614166, 39.15961191058159, 36.9757778942585, 39.65984746813774, 39.57314372062683, 42.330807745456696, 43.91281485557556, 45.595809146761894, 46.3957080245018, 44.77135218679905, 43.07889260351658, 42.825457602739334, 47.12586544454098, 48.48554268479347, 50.79672306776047, 55.017506182193756, 51.043189242482185, 53.29285092651844, 50.41175812482834, 54.75738734006882, 51.62437945604324, 43.06702584028244, 48.021344393491745, 52.22567819058895, 54.602431654930115, 57.82065376639366, 57.06719979643822, 57.70979851484299, 57.51305267214775, 49.43349301815033, 24.614644087851048, 15.81295408308506, 19.285145066678524, 21.504516676068306, 22.7393801137805, 12.494012676179409, 10.711998548358679, 1.6523992829024792, 0.31255769077688456, 0.2646792505402118, 3.254484278149903, 26.403886377811432, 53.043789491057396, 53.86657454073429, 48.24149698019028, 48.6363185942173, 60.16170434653759, 58.24132539331913, 21.584299094974995, 2.033458510413766, 0.19530664023477584, 0.14878435613354668, 0.16416852828115225, 0.13505886920029297, 0.2155283684260212, 0.20781594008440152, 0.13491732679540291, 0.14561094751115888, 0.20378769608214498, 0.14467588596744463, 0.20737106708111241, 0.1225469569908455, 0.12347106443485245, 0.15225980401737615, 0.19950508838519454, 0.1409113864065148, 0.16020241688238457, 0.12467200780520216, 0.21273949620081112, 0.08317942178109661, 0.11335612594848499], [0.03397973603568971, 0.02208969719504239, 0.08025750474189408, 0.0423603236413328, 0.021539867811952718, 0.04225483105983585, 0.016946500618360005, 0.05420775392849464, 0.06409710549633019, 0.03792323790548835, 0.023342485146713443, 0.026402556686662138, 0.0155315858683025, 0.04317028135119472, 0.04445987426151987, 0.14158013567794114, 0.07095236069289967, 0.03968218727095518, 0.024416615888185333, 0.06026947885402478, 0.016582616335654166, 0.06759696261724457, 0.1141727258800529, 3.48728543613106, 29.96786903589964, 47.85071074962616, 47.234623208642006, 28.742677979171276, 31.878024637699127, 49.64452609419823, 31.432095766067505, 19.44311399012804, 2.157474593259394, 0.31366384704597294, 0.11642204932286404, 1.0901990253478289, 4.178455285727978, 7.064194763079286, 4.763887021690607, 5.665837973356247, 12.754465900361538, 21.893157921731472, 36.81579127907753, 48.97807985544205, 47.8633526712656, 46.65857031941414, 47.83509358763695, 52.560843005776405, 53.06168273091316, 51.644446179270744, 52.043466567993164, 49.90883991122246, 46.4915768802166, 50.07381945848465, 48.5930123180151, 49.419863149523735, 50.050104930996895, 48.57334837317467, 45.23496150970459, 41.755780801177025, 37.124372720718384, 35.43551914393902, 35.68308345973492, 37.56648659706116, 40.68892724812031, 45.106509402394295, 50.67958675324917, 52.579340413212776, 51.062636598944664, 49.58757854998112, 47.11393028497696, 39.48375351727009, 36.818660125136375, 34.166379645466805, 32.88654372096062, 34.5566301047802, 32.33288303017616, 37.58631393313408, 43.305489644408226, 48.234490156173706, 48.00806790590286, 48.81164878606796, 47.865149974823, 49.2299797385931, 49.088653922080994, 48.757190108299255, 51.49636052548885, 53.33792790770531, 30.125159695744514, 45.71879334747791, 49.0451804548502, 44.026645347476006, 42.90506333112717, 42.23298579454422, 43.38951073586941, 42.529898062348366, 44.12848748266697, 45.02229832112789, 39.95773248374462, 34.24616776406765, 35.95565043389797, 34.71207216382027, 34.332746118307114, 34.08300071954727, 35.543117970228195, 37.80952535569668, 36.21785916388035, 34.86972950398922, 36.09575271606445, 32.59261429309845, 33.31207908689976, 34.33608613908291, 36.50072738528252, 37.584132850170135, 33.98916855454445, 35.469508320093155, 36.82114519178867, 37.958602756261826, 42.445774376392365, 43.679659366607666, 51.65464103221893, 52.15697027742863, 49.7851375490427, 50.59904247522354, 49.33515429496765, 47.22144551575184, 39.287824630737305, 39.36219044029713, 44.77724187076092, 49.385820776224136, 47.150955498218536, 48.891315311193466, 54.24324832856655, 51.66822910308838, 40.268491208553314, 24.74921766668558, 14.05687641352415, 3.17003452219069, 1.5469385543838143, 4.000634802505374, 3.9937495719641447, 5.226554945111275, 0.7364211464300752, 0.17155126493889838, 0.15920712263323367, 2.660714602097869, 19.4840244948864, 39.437623992562294, 32.90257506072521, 29.139209501445293, 42.392394840717316, 48.02748866379261, 44.5907136797905, 15.201559290289879, 1.406067288480699, 0.04810388243640773, 0.06500812887679785, 0.04459071860765107, 0.07436609899741597, 0.03331671243358869, 0.09103130709263496, 0.07363448981777765, 0.006892971605338971, 0.028557106015796307, 0.016760522121330723, 0.02395572362729581, 0.11394108674721792, 0.03332232678076252, 0.03402380476472899, 0.04652708208595868, 0.0211919137291261, 0.010275225686200429, 0.06411071648471989, 0.0387786261853762, 0.047760602028574795, 0.095906386122806, 0.03122899535810575, 0.04057686484884471, 0.04165512007602956, 0.046949026436777785, 0.013003565563849406, 0.03250658031902276, 0.012583971965796081, 0.015382309356937185, 0.053288782146410085, 0.06748653846443631, 0.033505147439427674, 0.02446403170324629, 0.04372527422674466, 0.023007418458291795, 0.051906194421462715, 0.07653472872334532, 0.022767610134906135, 0.002463738719598041, 0.05185590278415475, 0.0436833688581828, 0.05684454896254465, 0.04058925871504471, 0.14732403215020895, 4.377110050991178, 34.26218770444393, 53.85686606168747, 53.027290776371956, 34.926570653915405, 32.970956191420555, 50.364120081067085, 35.30503414571285, 18.92815802246332, 2.7817620942369103, 0.25138266559224576, 0.043071345644420944, 1.3957580854184926, 4.56190743483603, 9.070649072527885, 9.54417111352086, 7.233791537582874, 13.809898216277361, 25.139424428343773, 36.83444827795029, 49.884741604328156, 51.8098247051239, 49.30999584496021, 49.82927218079567, 54.5994184166193, 53.327687457203865, 52.170071974396706, 53.626507222652435, 54.69487689435482, 48.17255347967148, 51.03475369513035, 50.77722251415253, 51.99486717581749, 50.758793503046036, 49.27159130573273, 47.33800046145916, 42.98856005072594, 37.733195051550865, 35.55314563214779, 36.06881596148014, 38.9743946492672, 42.00087524950504, 46.8122872710228, 51.64708323776722, 53.83426867425442, 53.59162889420986, 51.84992395341396, 48.74248869717121, 41.334216222167015, 37.55532279610634, 36.26829385757446, 35.39210647344589, 36.56952269375324, 34.88865628838539, 40.721434503793716, 48.637659922242165, 49.21397499740124, 50.80830104649067, 52.03318431973457, 50.235645174980164, 51.228395104408264, 51.29577688872814, 51.48735500872135, 53.12370680272579, 53.1194244325161, 31.50254588574171, 46.86204940080643, 50.92186935245991, 47.506525218486786, 45.017662569880486, 44.737142622470856, 44.49846222996712, 45.01575507223606, 45.097952261567116, 45.768753066658974, 41.82963743805885, 35.803065821528435, 36.32375568151474, 35.78257352113724, 36.49755835533142, 36.50472477078438, 36.61704674363136, 39.23232100903988, 37.64306768774986, 36.65323980152607, 37.3933906853199, 36.53915852308273, 35.35470888018608, 36.81776337325573, 38.0406479537487, 39.45232540369034, 36.007361859083176, 37.24319614470005, 38.87004844844341, 41.01953610777855, 44.86648388206959, 45.90182192623615, 51.921356320381165, 53.24830211699009, 49.59967330098152, 51.18522562086582, 51.89055897295475, 50.37053033709526, 40.31178988516331, 41.26369200646877, 48.166762590408325, 52.13395491242409, 50.16722984611988, 53.609415739774704, 55.973922461271286, 52.48109668493271, 43.77399690449238, 23.085079863667488, 13.331998810172081, 7.629558350890875, 7.326510362327099, 12.083275616168976, 9.843353759497404, 6.526553062722087, 0.9484419913496822, 0.05858177937625442, 0.21405343897640705, 3.269011373631656, 21.79429292678833, 47.27253757417202, 38.298616111278534, 34.30215395987034, 47.22162030637264, 54.38142791390419, 51.9351077824831, 18.459441773593426, 1.8510957271791995, 0.03682330083393026, 0.01717301522148773, 0.04409815890539903, 0.024167259834939614, 0.0783180799044203, 0.026356053713243455, 0.038920120350667275, 0.05158785388630349, 0.039025419973768294, 0.028927192797709722, 0.022670214384561405, 0.01136614102506428, 0.03650979539088439, 0.05896292786928825, 0.0546962800581241, 0.03750251067685895, 0.0460040572215803, 0.030137403737171553, 0.045228316230350174, 0.06173645619128365, 0.0357855260517681, 0.14927512354915962, 0.16862377437064424, 0.12521404278231785, 0.14990033843787387, 0.1680833424325101, 0.12550756218843162, 0.07843421859433874, 0.10828845217474736, 0.17251942626899108, 0.18572619650512934, 0.11285107961157337, 0.16707124595995992, 0.06202514050528407, 0.1699958718381822, 0.11751756319426931, 0.300562001648359, 0.15753824030980468, 0.1830592888290994, 0.2686989598441869, 0.15159372647758573, 0.09154302533715963, 0.22668731573503464, 0.31330176803749055, 6.082864170894027, 40.23950256407261, 60.84956243634224, 60.37990003824234, 40.15270382165909, 41.79209925234318, 59.09417822957039, 41.95819593966007, 25.089358314871788, 3.5996017092838883, 0.7091412227600813, 0.30064066930208355, 2.991589684970677, 5.899103656411171, 14.931296892464161, 18.288557343184948, 11.311317589133978, 17.048782669007778, 23.59379656612873, 43.04959237575531, 54.23882156610489, 54.0627846121788, 52.131070867180824, 53.316041082143784, 56.300465539097786, 53.14424470067024, 51.018809750676155, 55.638237074017525, 56.42469987273216, 51.22302979230881, 52.181965336203575, 51.25842869281769, 53.50254647433758, 53.251866325736046, 51.592772752046585, 50.31341180205345, 46.59198269248009, 39.84440356492996, 37.433474734425545, 38.766367211937904, 40.66444896161556, 43.59922528266907, 48.81424404680729, 56.35894060134888, 56.1089102178812, 54.996812492609024, 53.18490631878376, 51.73292823135853, 44.1317705065012, 40.7417444139719, 38.387223556637764, 37.491083443164825, 38.3173681050539, 36.27451412379742, 42.08205409348011, 48.30374903976917, 52.42773994803429, 53.31078976392746, 53.127464801073074, 51.79135009646416, 52.94934555888176, 54.35873933136463, 54.39269430935383, 55.90818598866463, 54.969545155763626, 35.07611162960529, 50.1160503923893, 54.14180897176266, 48.452830240130424, 47.81654678285122, 46.491470485925674, 46.73798605799675, 46.02351799607277, 48.50404389202595, 50.12731298804283, 45.69152981042862, 38.82319696247578, 40.01263953745365, 37.28920787572861, 38.07462953031063, 38.42881992459297, 39.659148305654526, 41.27853021025658, 39.75384682416916, 37.77070663869381, 40.38753502070904, 36.60359926521778, 37.22014278173447, 38.985421657562256, 40.59667579829693, 42.77580566704273, 38.964917957782745, 39.79676552116871, 40.85913151502609, 41.83015041053295, 47.04994551837444, 48.061724826693535, 56.73070125281811, 55.218371003866196, 51.26373700797558, 52.80213765799999, 53.84682700037956, 52.981377840042114, 43.08213382959366, 42.3255830258131, 50.40258541703224, 55.45199006795883, 51.641710326075554, 55.295666456222534, 60.51900677382946, 56.01208761334419, 43.55273477733135, 28.91108874231577, 15.688490811735392, 8.721196074038744, 6.207826165482402, 13.93553752452135, 14.838348180055618, 10.214020069688559, 2.639915943145752, 0.4431193380150944, 0.4312646866310388, 3.9931653533130884, 25.64423494040966, 50.85778199136257, 45.43317027390003, 42.72670850157738, 54.38838914036751, 61.71865560114384, 60.32691188156605, 24.690474718809128, 1.983675006777048, 0.1265865410096012, 0.12384221248794347, 0.12610298726940528, 0.1394137620809488, 0.21148458385141566, 0.15664610458770767, 0.17257861996768042, 0.20694848819402978, 0.19071651622653008, 0.09166279312921688, 0.12660013715503737, 0.2627692592795938, 0.0963998178485781, 0.16575948509853333, 0.10295824366039596, 0.10075471072923392, 0.13050184497842565, 0.1909872516989708, 0.14703496563015506, 0.18175065983086824, 0.1432406168896705], [0.03562233890988864, 0.049343680948368274, 0.025820972659857944, 0.03193211348843761, 0.054400805092882365, 0.028456519030441996, 0.053095990733709186, 0.1343376946169883, 0.02611003175843507, 0.07087585268891416, 0.03381841168447863, 0.05309563079208601, 0.026180316854151897, 0.040766798992990516, 0.08068619150435552, 0.06543563562445343, 0.07331216023885645, 0.035773135896306485, 0.030838560742267873, 0.014367554140335415, 0.028239787789061666, 0.02741402047831798, 0.04523358918959275, 4.599071340635419, 25.00783558934927, 49.015070870518684, 51.75680615007877, 38.258026689291, 38.2716603577137, 34.856107234954834, 38.18666271865368, 20.750173553824425, 5.05813610740006, 0.17010189505526796, 0.11458948632935062, 1.2105269310995936, 4.633093765005469, 8.799494672566652, 8.85292835533619, 5.352721000090241, 6.343828942626715, 16.65111880749464, 30.292229130864143, 43.933964520692825, 49.8708039522171, 49.276082664728165, 51.1956712603569, 52.4880351126194, 49.53500837087631, 50.910135582089424, 51.41747675836086, 46.41137458384037, 45.3637707978487, 45.6516357511282, 49.55287121236324, 50.52004471421242, 49.54214818775654, 50.379494056105614, 45.52303925156593, 42.23173566162586, 36.56069576740265, 33.741744831204414, 36.4075031876564, 35.381174460053444, 38.55693005025387, 43.537319004535675, 48.06833267211914, 51.647979989647865, 51.733551397919655, 51.48963488638401, 48.95993962883949, 47.82444655895233, 41.55138976871967, 35.71190111339092, 33.695816695690155, 34.83676627278328, 36.130714640021324, 36.07719451189041, 37.092576026916504, 40.80873481929302, 42.81328305602074, 46.04965679347515, 45.20629204809666, 47.18964882194996, 45.157601460814476, 46.34787619113922, 48.18556398153305, 52.80444413423538, 31.41867868602276, 44.77250352501869, 49.67297896742821, 43.78809034824371, 45.29538206756115, 45.870405212044716, 47.556165754795074, 47.34667919576168, 48.19763973355293, 46.220803409814835, 44.99383024871349, 39.452819377183914, 34.30205896496773, 33.7749170511961, 35.07100470364094, 35.058963149785995, 34.87515561282635, 37.203720062971115, 33.99796508252621, 35.693149119615555, 35.62491998076439, 34.93957355618477, 34.76678162813187, 35.226788744330406, 35.074990689754486, 35.52650526165962, 36.23012110590935, 36.07223577797413, 36.403612196445465, 37.11402587592602, 42.827756479382515, 43.252786472439766, 47.48934634029865, 48.69227059185505, 51.33909836411476, 47.26494178175926, 49.43834535777569, 48.60095389187336, 40.43765813112259, 40.332479774951935, 42.3229193687439, 45.08254788815975, 47.76768900454044, 50.162962675094604, 51.76010437309742, 46.878426522016525, 40.25640405714512, 17.4394017085433, 8.716390281915665, 9.812464267015457, 8.007009197026491, 9.437782522290945, 10.314419232308865, 2.4841696629300714, 0.6734739616513252, 0.041760033782338724, 0.17907300585648045, 3.724277769215405, 21.778542771935463, 41.34626917541027, 41.96667328476906, 33.74609559774399, 38.27771723270416, 48.113466650247574, 45.73888286948204, 17.84506604075432, 0.6798864738084376, 0.04452007728104945, 0.04323167180700693, 0.0645851566514466, 0.026820385828614235, 0.03700889341416769, 0.0443180683942046, 0.03405096736969426, 0.03424577371333726, 0.040336824604310095, 0.03367528108356055, 0.014221621004253393, 0.04772846703417599, 0.06235604188987054, 0.04319681684137322, 0.028952410975762177, 0.04622115025995299, 0.016644780480419286, 0.04612268581695389, 0.038856566534377635, 0.04497520305449143, 0.05090093312901445, 0.054380377478082664, 0.04978374112397432, 0.044397919773473404, 0.06535112726851366, 0.06886390518047847, 0.05405699776019901, 0.0418694152176613, 0.05227410299994517, 0.07223845808766782, 0.03967634656873997, 0.029958753948449157, 0.046852929444867186, 0.08967780784587376, 0.0226982119056629, 0.0794894115824718, 0.06360511353705078, 0.017082577105611563, 0.05314958492817823, 0.05379080423153937, 0.015194157294899924, 0.03485816057946067, 0.020110034965910017, 0.10090869152918458, 5.317688779905438, 30.591324381530285, 55.6157498806715, 57.060876935720444, 40.707276463508606, 40.21541565656662, 40.80488942563534, 41.42751261591911, 24.422995671629906, 4.90028022788465, 0.2830186695791781, 0.06495390014606528, 0.608349374961108, 4.588461359962821, 6.191608160734177, 6.339073497802019, 4.811697956174612, 11.573626063764095, 24.780881367623806, 32.04154506325722, 48.766279220581055, 50.59372656047344, 50.77604077756405, 53.01464885473251, 55.68377763032913, 50.76884776353836, 52.47412025928497, 54.107196629047394, 48.344509452581406, 47.614819407463074, 47.77896299958229, 51.02358229458332, 50.93660116195679, 49.35966297984123, 51.45943030714989, 47.68837586045265, 44.83438320457935, 37.42968253791332, 35.72916358709335, 37.76250667870045, 38.17585609853268, 40.26773884892464, 46.31546773016453, 51.85716636478901, 52.25793845951557, 52.94528357684612, 53.35260272026062, 50.02501867711544, 49.61052931845188, 42.6095037907362, 37.40450128912926, 34.98891390860081, 36.1837749928236, 38.13807472586632, 37.46136523783207, 40.42547218501568, 43.379775658249855, 45.62230132520199, 47.93966017663479, 47.53644861280918, 49.3366514146328, 47.31894828379154, 48.89564707875252, 49.52251084148884, 53.702928721904755, 34.50945943593979, 46.53902493417263, 50.7216314971447, 46.02016657590866, 47.94900767505169, 47.86005824804306, 49.498644322156906, 49.55167807638645, 49.328941628336906, 47.60715901851654, 46.53185851871967, 41.02684311568737, 35.911439806222916, 34.88009534776211, 36.73720009624958, 36.89101204276085, 37.05327853560448, 38.88678275048733, 36.86642736196518, 36.74954943358898, 36.48321032524109, 36.43417775630951, 36.61096327006817, 36.19421303272247, 37.533967941999435, 38.02683189511299, 37.68259696662426, 38.96883174777031, 37.39357307553291, 39.61346335709095, 45.2007557451725, 45.00448487699032, 50.25151692330837, 50.864807814359665, 51.04373641312122, 47.65344813466072, 52.08001680672169, 50.767719224095345, 43.443840220570564, 42.96707220375538, 44.585447162389755, 46.88701406121254, 49.93114471435547, 52.56676308810711, 54.87611196935177, 51.082729920744896, 41.01249888539314, 21.964727081358433, 11.769968178123236, 10.809120386838913, 10.468728002160788, 15.961054936051369, 6.4755916222929955, 6.026993868872523, 0.6421638198662549, 0.1696948567405343, 0.24095123080769554, 4.4462663400918245, 24.188105575740337, 43.69124114513397, 44.083722084760666, 36.775654032826424, 43.885874301195145, 53.81910748779774, 52.639707773923874, 20.42304340749979, 0.7792801747564226, 0.028788272029487416, 0.05530511203687638, 0.06670318674878217, 0.047422182688023895, 0.015911328919173684, 0.0656201780657284, 0.03722658759215847, 0.026627993320289534, 0.028341424913378432, 0.0553682279860368, 0.0733773282263428, 0.05656829191138968, 0.06426184743759222, 0.025069848707062192, 0.09917721647070721, 0.05411912665294949, 0.05147220872459002, 0.023872781202953774, 0.08699346712091938, 0.035666778712766245, 0.0064726692562544486, 0.2702042134478688, 0.17449089704314247, 0.09866277454420924, 0.14321554714115337, 0.15602322004269809, 0.13452257844619453, 0.13633199385367334, 0.22730395139660686, 0.21350941504351795, 0.14599456364521757, 0.16609340702416375, 0.14064304064959288, 0.2075539916404523, 0.1448915243963711, 0.19031078409170732, 0.20806151675060391, 0.12079865744453855, 0.10765528888441622, 0.10356261904234998, 0.1600548779242672, 0.127372891001869, 0.08389333816012368, 0.1360391720663756, 6.404309347271919, 35.58322101831436, 63.61004590988159, 63.089766427874565, 48.995699509978294, 48.3463941514492, 45.8863415569067, 48.816649317741394, 28.224769569933414, 6.8373531103134155, 0.4651198606006801, 0.39625283097848296, 2.2180314688012004, 10.668944008648396, 16.37559749186039, 14.54143876209855, 12.107511665672064, 10.131422951817513, 22.12047692388296, 33.34560088813305, 49.408501759171486, 55.66516622900963, 54.085742980241776, 55.59260532259941, 56.07825726270676, 49.926166981458664, 56.21492072939873, 55.7267951220274, 51.80617690086365, 50.56145489215851, 49.74350318312645, 52.02110096812248, 53.17349173128605, 50.76991930603981, 54.34599481523037, 50.00089377164841, 46.38382226228714, 39.37383681535721, 37.94813431799412, 40.81631921231747, 39.67292636632919, 41.727198734879494, 46.580970883369446, 51.419528648257256, 54.792527854442596, 54.3887273222208, 54.657004326581955, 53.19531016051769, 52.906198874115944, 44.50522966682911, 38.37484382092953, 37.60902911424637, 38.28112185001373, 41.357660964131355, 40.34213125705719, 41.26175411045551, 44.23880696296692, 46.13474942743778, 51.41818732023239, 48.96180912852287, 51.62958897650242, 48.85261058807373, 49.88200955092907, 50.97112610936165, 57.3151782900095, 38.0745155364275, 48.475511223077774, 52.743332013487816, 47.67143256962299, 49.223242700099945, 50.052316412329674, 53.620590940117836, 51.24035686254501, 52.70434610545635, 50.3498974442482, 49.52355958521366, 44.739981070160866, 39.04269598424435, 37.03346639871597, 39.40707743167877, 39.586405009031296, 37.68452726304531, 40.11982038617134, 37.5944796949625, 39.315848127007484, 39.25046123564243, 37.971723452210426, 38.165497854352, 39.83930803835392, 39.04472127556801, 40.63770979642868, 40.76585792005062, 41.76898509263992, 40.13580992817879, 42.0990239828825, 48.30001763999462, 48.568028658628464, 53.15016858279705, 51.69024892151356, 52.69799284636974, 49.56675186753273, 53.68173725903034, 53.83183300495148, 46.06280408799648, 45.60279697179794, 46.70839324593544, 49.48830507695675, 52.04590603709221, 55.91689132153988, 56.06759503483772, 53.068149983882904, 44.531474858522415, 22.565966919064522, 12.519396264106035, 16.378259249031544, 17.56106738001108, 19.490898326039314, 17.383909486234188, 7.875491604208946, 2.0899643283337355, 0.2689649455714971, 0.6686599168460816, 5.595318032428622, 28.69947999715805, 53.83610017597675, 53.98770064115524, 47.97326557338238, 51.17172874510288, 62.29274019598961, 58.2916384935379, 25.183148682117462, 1.3805795623920858, 0.12669842719333246, 0.1297068118583411, 0.2098089034552686, 0.16935523512074724, 0.20069976802915335, 0.14116157923126593, 0.13563853106461465, 0.09060002281330526, 0.0863988658238668, 0.15738808899186552, 0.21472589898621663, 0.17082612728700042, 0.20740703155752271, 0.1639320800313726, 0.1773618211154826, 0.1290349307237193, 0.06638899852987379, 0.08745201790588908, 0.23184788413345814, 0.1052164209249895, 0.11904331491678022], [0.007283349168574205, 0.02132587138476083, 0.05200121900998056, 0.026432242593728006, 0.04503987751377281, 0.04754373163450509, 0.03731653589056805, 0.08364954264834523, 0.003237227060708392, 0.052960585890104994, 0.04938014637446031, 0.04973201343091205, 0.06606455383007415, 0.04896524871583097, 0.0271000307839131, 0.03603630146244541, 0.04386705782962963, 0.043003272148780525, 0.015490038585994625, 0.07781432490446605, 0.03838353273749817, 0.06326512826490216, 0.08674987198901363, 1.6207301197573543, 19.805188961327076, 41.92028157413006, 49.26395371556282, 44.20092299580574, 33.43916706740856, 31.741598658263683, 37.01087661087513, 27.714882530272007, 6.592327058315277, 0.533076839055866, 0.012830289851990528, 0.7126180955674499, 4.272918216884136, 2.9320689663290977, 4.403890063986182, 3.5443369997665286, 13.585262820124626, 21.230376586318016, 22.775994949042797, 41.582365706562996, 48.77636767923832, 52.107694521546364, 51.79812893271446, 47.98387460410595, 44.637207984924316, 51.314164102077484, 48.85193422436714, 43.817899748682976, 42.86895766854286, 42.3852626234293, 47.17196837067604, 51.65211036801338, 49.941157177090645, 49.03509199619293, 47.19072796404362, 43.40323179960251, 35.748595744371414, 33.45215857028961, 35.32394953072071, 34.97402250766754, 37.232936695218086, 39.74864490330219, 43.6573925614357, 48.404664024710655, 49.796210154891014, 51.09097167849541, 46.97225108742714, 48.49576033651829, 45.42281582951546, 40.65061390399933, 34.28055211901665, 34.045280143618584, 34.39894996583462, 35.80238565802574, 35.12279212474823, 35.87458558380604, 36.89188599586487, 39.01344135403633, 40.570407807826996, 40.907248333096504, 42.04036273062229, 44.50535126030445, 47.13216170668602, 54.34242680668831, 32.73985639214516, 41.48338861763477, 47.37422771751881, 49.043018370866776, 47.741451412439346, 47.596177607774734, 48.995357528328896, 48.7694938480854, 51.09364673495293, 47.87606678903103, 47.23778463900089, 44.15231600403786, 37.61288970708847, 33.39573919773102, 34.301002621650696, 34.71258893609047, 34.92391459643841, 36.28133475780487, 41.91628038883209, 43.90482768416405, 42.27726861834526, 37.246646359562874, 34.97705854475498, 34.160189777612686, 34.18347492814064, 36.02528549730778, 35.21835699677467, 35.43354704976082, 36.98153078556061, 35.36096714437008, 40.80831304192543, 46.259340941905975, 49.487149938941, 50.657760724425316, 45.84260210394859, 55.599015578627586, 48.12776908278465, 50.874865874648094, 44.721312671899796, 41.833437234163284, 40.1933578401804, 41.56887263059616, 44.896331280469894, 48.76051492989063, 52.0666491240263, 49.20904666185379, 32.24147513508797, 17.37653598189354, 11.210114769637585, 7.496629133820534, 11.3395282253623, 17.183494940400124, 6.987213743850589, 8.622139189392328, 0.4819087847135961, 0.009694038708403241, 0.0694292807020247, 4.225441664457321, 23.364467471837997, 40.83459623157978, 38.6198964715004, 31.42381601035595, 41.071540117263794, 50.46400152146816, 38.89132730662823, 13.59901713207364, 0.4020181903615594, 0.10037208165158518, 0.05045112484367564, 0.03529123714542948, 0.03715258062584326, 0.024049156309047248, 0.02481609357346315, 0.029311001890164334, 0.0872183452884201, 0.03074979060329497, 0.018010094718192704, 0.03026780093932757, 0.05504031003511045, 0.028675211397057865, 0.01593002918525599, 0.07957934503792785, 0.09316478128312156, 0.05403552371717524, 0.017095776202040724, 0.006175053194965585, 0.09211898388457485, 0.03862408877466805, 0.012316836837271694, 0.025116297874774318, 0.04274675993656274, 0.044905344693688676, 0.04509238446189556, 0.07732051468337886, 0.03371478189365007, 0.029413954471237957, 0.014195913936418947, 0.07771124801365659, 0.05673278894391842, 0.05659448230289854, 0.01976483610633295, 0.05509407121280674, 0.009029757165990304, 0.04867331008426845, 0.043390131468186155, 0.028528861730592325, 0.04236545559251681, 0.06367577341734432, 0.028689128521364182, 0.039813335897633806, 0.03674854800920002, 2.5852273777127266, 23.606191501021385, 49.13054287433624, 58.11129257082939, 49.890897274017334, 39.39915865659714, 39.54760529100895, 43.56341600418091, 29.705346822738647, 7.267129048705101, 0.5566733353771269, 0.053335730408434756, 0.06971854760195129, 3.9235435891896486, 5.958098340779543, 9.38873190432787, 7.935763020068407, 8.784021902829409, 19.04013231396675, 26.73305321484804, 42.801397293806076, 53.6229582130909, 55.330795571208, 52.97413542866707, 49.51005890965462, 48.31305094063282, 53.785460293293, 52.065360993146896, 47.88755737245083, 44.838072806596756, 44.453647434711456, 48.29774156212807, 53.39809387922287, 51.30171976983547, 49.1491162776947, 48.70333559811115, 46.73390507698059, 37.73251488804817, 35.763114765286446, 36.673602908849716, 36.88868656754494, 39.09843519330025, 41.98349878191948, 46.500715389847755, 50.25224648416042, 53.351759165525436, 52.524577751755714, 49.13425527513027, 51.048839539289474, 46.23680055141449, 41.78672254085541, 35.67328758537769, 36.353242099285126, 37.56210923194885, 38.10043774545193, 36.786639243364334, 38.60652878880501, 39.324956238269806, 41.818766221404076, 42.09847301244736, 42.33487732708454, 44.54159751534462, 47.70067200064659, 49.00337129831314, 55.23579686880112, 35.4879829287529, 43.714739084243774, 50.87257839739323, 50.988692566752434, 51.03056252002716, 49.438968524336815, 50.58626376092434, 49.76157121360302, 52.79978558421135, 48.428785130381584, 49.81321424245834, 46.45152322947979, 39.606692120432854, 35.56965194642544, 37.00735040009022, 36.937692537903786, 37.0065638422966, 37.4505016207695, 43.13016325235367, 43.65823231637478, 43.48176598548889, 38.48928987979889, 37.06403575837612, 35.78609973192215, 35.91778166592121, 36.90148048102856, 37.76756800711155, 37.15664058923721, 38.075875863432884, 38.29545088112354, 42.47140020132065, 49.31253030896187, 50.913361608982086, 51.79592885077, 46.9046451151371, 54.8302636295557, 51.00588284432888, 54.19019557535648, 45.11842556297779, 43.413407653570175, 42.53499358892441, 45.80339200794697, 48.302506506443024, 53.99619698524475, 54.87087965011597, 52.706637382507324, 36.396624371409416, 21.010704673826694, 13.905495386570692, 10.33608851954341, 12.81147139146924, 12.650426533073187, 8.170826956629753, 2.3722649551928043, 0.1655625636340119, 0.01388902752296417, 0.11255597943090834, 4.710366418585181, 28.310069292783737, 48.03524024784565, 49.2478995770216, 38.70516389608383, 46.51503302156925, 56.85755364596844, 45.00375531613827, 17.315819039940834, 0.7001554768066853, 0.07545150481746532, 0.053697182302130386, 0.04057131729496177, 0.0441724182019243, 0.00849575686515891, 0.03631398343713954, 0.0020375683016027324, 0.05545701482333243, 0.012936362236359855, 0.07490828982554376, 0.09926010694471188, 0.039737250917823985, 0.017014147379086353, 0.033615007560001686, 0.05417750027845614, 0.049045623309211805, 0.026971140141540673, 0.033176324068335816, 0.03843199127004482, 0.05854050112247933, 0.03853035923384596, 0.12372999233775772, 0.1627388846827671, 0.15010769449872896, 0.10548757200012915, 0.08549205042072572, 0.1583343421225436, 0.14875069231493399, 0.11983111951849423, 0.08931630029110238, 0.17120512726251036, 0.13388541497988626, 0.15376728406408802, 0.18242654856294394, 0.12482687918236479, 0.06657611622358672, 0.14060683868592605, 0.23208770173368976, 0.14719546248670667, 0.09422369985259138, 0.1525163941551, 0.1159251072385814, 0.1436647097580135, 0.1733656824217178, 2.974080699495971, 26.172879673540592, 53.855197951197624, 64.11558598279953, 54.74006026983261, 42.73791030049324, 42.63232536613941, 48.307978212833405, 36.37351021170616, 8.840499222278595, 1.0495838359929621, 0.28236249228939414, 1.2302804086357355, 10.099454317241907, 11.859222538769245, 16.087023876607418, 11.164266429841518, 20.302037000656128, 27.817043848335743, 26.259262338280678, 45.9370194375515, 53.81282262504101, 56.33341357111931, 52.79363751411438, 50.48724867403507, 48.60782012343407, 56.447392255067825, 53.28774780035019, 49.36184026300907, 46.75302565097809, 47.234022840857506, 50.42435824871063, 55.77849514782429, 53.07601936161518, 52.40084499120712, 52.879197522997856, 48.84599134325981, 39.311371967196465, 36.37643225491047, 39.11198906600475, 40.224861949682236, 40.8094871789217, 43.77032250165939, 48.31602618098259, 51.322516053915024, 53.25350023806095, 53.98019224405289, 51.60274341702461, 53.46711717545986, 48.85531984269619, 45.047665759921074, 38.678823709487915, 37.27079786360264, 39.33152988553047, 40.63856095075607, 38.91954459249973, 40.16520515084267, 42.044911086559296, 42.87837356328964, 44.392668306827545, 44.5944868773222, 45.72939097881317, 49.447271078825, 52.45009034872055, 57.23668970167637, 40.70485219359398, 45.10390654206276, 51.3683757930994, 53.223789632320404, 52.75447301566601, 52.5418022274971, 53.047106713056564, 52.17169068753719, 56.08900308609009, 51.35091193020344, 52.85250015556812, 49.80506747961044, 41.375299617648125, 38.29588025808334, 38.488883301615715, 38.633640334010124, 37.90330432355404, 39.58488889038563, 47.43391111493111, 47.9821152985096, 46.48165561258793, 42.17758856713772, 39.17166866362095, 37.522640749812126, 38.2826379686594, 39.99814711511135, 39.85509239137173, 38.467874228954315, 40.79338364303112, 39.11113791167736, 47.05284856259823, 52.507600262761116, 54.16012018918991, 52.16454707086086, 48.44977520406246, 54.315102472901344, 51.79564766585827, 56.063711643218994, 49.70813848078251, 46.31202511489391, 45.49710564315319, 47.98908032476902, 50.82511514425278, 54.885592460632324, 58.37339870631695, 52.9272535443306, 37.94789873063564, 22.340217232704163, 15.521514471620321, 14.477610737085342, 18.288811929523945, 27.390748523175716, 17.125985026359558, 15.839916486293077, 1.4304121071472764, 0.4247630276950076, 0.4155305027961731, 5.9645902924239635, 31.894382759928703, 51.880614906549454, 52.44296573102474, 44.05549339950085, 54.19983185827732, 64.17163297533989, 52.414163276553154, 20.948232226073742, 1.0241431323811412, 0.2779194916365668, 0.0987509565311484, 0.15075999777764082, 0.11192058227607049, 0.13825233065290377, 0.11733622683095746, 0.12253169843461365, 0.1514823449542746, 0.25510441744700074, 0.17543430032674223, 0.3904671664349735, 0.16741868981625885, 0.1054722689150367, 0.1210619046469219, 0.12710435228655115, 0.18542630947194993, 0.1416551964939572, 0.08879992878064513, 0.11373235771316104, 0.22118777880677953, 0.0926526177499909], [0.04011675184301566, 0.048445210995851085, 0.06079971368308179, 0.009320577009930275, 0.04198187656584196, 0.019985753060609568, 0.0055936083208507625, 0.023805984201317187, 0.011759476510633249, 0.023781265117577277, 0.027663174296321813, 0.026992834973498248, 0.06277117703575641, 0.05945135751971975, 0.09248536734958179, 0.03287849649495911, 0.05320307893271092, 0.02370203899772605, 0.04048306480399333, 0.01447835215003579, 0.07152040794608183, 0.048765280735096894, 0.05728412674216088, 0.857388605363667, 12.633025366812944, 38.97295452654362, 44.29661326110363, 45.08391581475735, 26.280850879848003, 24.624170176684856, 36.49117469787598, 28.332784473896027, 10.424583870917559, 1.021666971500963, 0.1449872911325656, 0.17317935882601887, 3.30660299398005, 3.6168689327314496, 5.399693604558706, 4.994737459346652, 3.6397446552291512, 7.790661631152034, 19.564154595136642, 31.774218007922173, 47.10464358329773, 50.37835791707039, 53.46991002559662, 46.746395006775856, 51.111935153603554, 52.13502265512943, 46.15522272884846, 44.239935502409935, 41.20169073343277, 40.909608006477356, 44.19184148311615, 49.686130061745644, 50.48243433237076, 48.69859345257282, 46.348761543631554, 41.53034269809723, 34.608945697546005, 33.50580409169197, 33.291522189974785, 35.40621131658554, 34.92928370833397, 36.9676311314106, 41.880566105246544, 46.56089276075363, 50.484866201877594, 49.075122848153114, 49.25019085407257, 49.31351825594902, 48.35874728858471, 47.65450447797775, 40.719014033675194, 34.05374228954315, 34.73290644586086, 35.64752496778965, 36.58061429858208, 38.05985972285271, 35.587271600961685, 35.736326202750206, 34.325648099184036, 37.257555574178696, 38.02034944295883, 45.277720615267754, 47.37843409180641, 52.491169944405556, 34.912617802619934, 40.094433948397636, 48.14018301665783, 45.54515786468983, 50.010720044374466, 47.786186411976814, 49.365951642394066, 48.989619836211205, 52.08829276263714, 49.687459990382195, 49.0902042388916, 47.42892198264599, 43.205357417464256, 31.84132430702448, 34.681286215782166, 34.06452231109142, 37.918651700019836, 42.302157282829285, 49.774532318115234, 48.9459677785635, 50.932637974619865, 47.00201489031315, 41.61205351352692, 35.76834708452225, 35.253558307886124, 34.03350077569485, 35.585763081908226, 36.89806066453457, 35.609386414289474, 37.79396899044514, 44.072600081562996, 46.40321642160416, 47.484144419431686, 51.384593322873116, 48.9112414419651, 49.19834263622761, 51.769387274980545, 51.37695953249931, 51.965612545609474, 48.25812868773937, 45.392140075564384, 43.329834938049316, 46.03961393237114, 46.71601943671703, 51.587437838315964, 45.18972113728523, 34.19093772768974, 20.464523881673813, 14.840448517352343, 12.985207568854094, 10.253966376185417, 12.360953316092491, 3.770854719914496, 2.4977173609659076, 0.16937430831603706, 0.23481298674596474, 0.21484649798367172, 6.622704053297639, 26.330897994339466, 39.57759328186512, 29.20010693371296, 30.06529960781336, 43.232590556144714, 53.45568358898163, 39.11921247839928, 10.913791470229626, 0.3291754162637517, 0.055470184233854525, 0.008930828880693298, 0.08285580828669481, 0.062338156130863354, 0.016423822708020452, 0.0347956754558254, 0.014448529873334337, 0.03899313283909578, 0.031152999436017126, 0.06334698715363629, 0.04758126204251312, 0.031883510237094015, 0.04238131528836675, 0.040794236192596145, 0.009830597591644619, 0.023069068665790837, 0.07003724065725692, 0.02702484194742283, 0.06979563448112458, 0.04384684914839454, 0.02581610417109914, 0.03178477119945455, 0.07250485199620016, 0.049887163113453425, 0.022424713788495865, 0.030298503588710446, 0.05266829102765769, 0.03511599381454289, 0.05864042388566304, 0.007321624507312663, 0.027978998950857203, 0.031898783636279404, 0.018240655881527346, 0.05427623189461883, 0.025077073514694348, 0.010265871842420893, 0.01529093427961925, 0.036546568808262236, 0.03121790025033988, 0.01856472394138109, 0.03746931812202092, 0.026472162717254832, 0.027499517746036872, 0.061511730164056644, 1.056729827541858, 16.56555499881506, 42.805805057287216, 52.11106114089489, 50.1675870269537, 33.50233107805252, 29.115386679768562, 42.80823312699795, 32.8894467651844, 11.548939738422632, 1.0456329979933798, 0.12009670448605902, 0.1333087810780853, 1.5303994668647647, 4.55970972776413, 7.3077702429145575, 7.0340443309396505, 6.329051060602069, 11.24777739867568, 23.371599689126015, 36.283679232001305, 49.197122901678085, 52.21222311258316, 53.74623499810696, 47.97906406223774, 51.263683810830116, 53.540814220905304, 49.04154025018215, 47.13822618126869, 43.84678199887276, 45.03150522708893, 45.797927901148796, 51.69428430497646, 52.265522852540016, 51.47282838821411, 47.72290080785751, 43.718770667910576, 37.133256644010544, 35.35319656133652, 35.89737296104431, 36.582088619470596, 36.23940400779247, 39.10231478512287, 42.99182407557964, 47.80341848731041, 51.628369241952896, 52.499400302767754, 49.531322568655014, 50.30122585594654, 49.09408003091812, 49.62797038257122, 41.52962073683739, 36.8147349357605, 36.6654409468174, 37.90668994188309, 37.73621208965778, 39.163278713822365, 37.85321921110153, 36.78229607641697, 35.48134848475456, 38.37860181927681, 40.32382383942604, 47.358998134732246, 50.604232996702194, 55.00975459814072, 38.30954432487488, 41.528625190258026, 48.41570623219013, 47.00215928256512, 51.53735272586346, 49.23850268125534, 50.13443000614643, 50.99026568233967, 52.21866376698017, 53.44906434416771, 51.544519141316414, 50.027560740709305, 44.74659651517868, 34.95187349617481, 36.567242816090584, 35.99119372665882, 38.809757083654404, 44.08258594572544, 51.45384460687637, 51.46036125719547, 52.69123300909996, 47.805713564157486, 42.39407815039158, 37.97133207321167, 35.79828567802906, 35.1052750647068, 37.617008686065674, 37.70815059542656, 38.16039092838764, 40.99596597254276, 45.845296159386635, 49.240805357694626, 50.43834909796715, 53.2754934579134, 48.62094461917877, 51.35455593466759, 52.6940980553627, 51.92049376666546, 54.32042978703976, 49.246379658579826, 47.23767064511776, 44.57031637430191, 48.88143204152584, 50.72099693119526, 55.61175249516964, 48.846527114510536, 34.912515208125114, 24.057358391582966, 18.658059015870094, 11.62693815305829, 14.135398250073195, 16.863521710038185, 8.006268236786127, 3.581137075088918, 0.3557702782563865, 0.1094596651091706, 0.11644172365777194, 7.12227369658649, 30.031517520546913, 44.989175498485565, 32.156348302960396, 33.28267626464367, 47.076779678463936, 59.463697001338005, 46.2322673946619, 14.19069193303585, 0.39752956246957183, 0.04923846667225007, 0.08246119352406822, 0.05315002279530745, 0.0750643560604658, 0.03355642613314558, 0.08057597515289672, 0.030735157306480687, 0.06846047370345332, 0.06934405988431536, 0.09317004311014898, 0.047257722762878984, 0.02580871052487055, 0.028712944040307775, 0.04793957465153653, 0.05856748190126382, 0.02291089102072874, 0.07000355457421392, 0.05666088225552812, 0.015315660784835927, 0.03734592864930164, 0.01999735653953394, 0.09450510740862228, 0.1723452442092821, 0.14067165786400437, 0.09733143582707271, 0.22785103297792375, 0.10778093448607251, 0.17561896151164547, 0.1307698493474163, 0.0770411777193658, 0.09192086014081724, 0.13354352238820866, 0.07890938606578857, 0.23218296380946413, 0.12360393113340251, 0.15911635797237977, 0.21485556702828035, 0.11055376889999025, 0.14258963463362306, 0.10103725377121009, 0.09927896491717547, 0.10920158325461671, 0.12714508135104552, 0.14808511943556368, 1.933587163221091, 18.66245537996292, 50.06527751684189, 59.073894917964935, 56.480028703808784, 39.003470689058304, 33.14654856920242, 45.27292527258396, 36.97825536131859, 14.12531929090619, 1.6384488064795732, 0.334782074787654, 0.603836226509884, 6.157213356345892, 8.518527299165726, 11.193730048835278, 10.904149487614632, 7.460366729646921, 10.209173429757357, 23.134348019957542, 35.080477595329285, 50.92301309108734, 52.793401926755905, 54.72582243382931, 48.11325006186962, 52.33164310455322, 57.64425963163376, 51.176717877388, 49.61793512105942, 45.594042241573334, 45.928656086325645, 48.17696124315262, 54.10252287983894, 54.416557028889656, 52.23411753773689, 51.202704682946205, 44.899709299206734, 38.21160838007927, 36.21802255511284, 38.104028552770615, 38.64461034536362, 39.80063371360302, 40.567398369312286, 45.576661974191666, 50.24346895515919, 54.47362616658211, 52.379881516098976, 51.20276167988777, 52.17802494764328, 52.345664352178574, 52.61878989636898, 44.852382838726044, 38.36296185851097, 37.94710457324982, 39.31161895394325, 40.72114571928978, 41.126644760370255, 39.09131437540054, 38.90542455017567, 36.45359091460705, 41.49400144815445, 42.448210045695305, 49.85915757715702, 52.392185255885124, 56.574244648218155, 42.84709744155407, 44.281524270772934, 48.86391118168831, 48.37596036493778, 53.76186355948448, 51.41883708536625, 53.685632050037384, 51.38514809310436, 54.55958515405655, 54.53162245452404, 53.78239385783672, 52.08025619387627, 46.978266164660454, 36.76507540047169, 38.19442570209503, 38.21361467242241, 41.611905321478844, 47.15653359889984, 54.62825506925583, 53.491568863391876, 57.172716334462166, 51.74275450408459, 44.903045520186424, 40.23395486176014, 38.6531712859869, 36.96306757628918, 40.08960820734501, 40.66101014614105, 39.80794072151184, 42.38957159221172, 48.84911857545376, 51.94759011268616, 52.95009031891823, 55.864708721637726, 49.42850388586521, 53.31585869193077, 56.72251269221306, 54.93493661284447, 57.17508740723133, 52.29761593043804, 50.05703955888748, 48.96401301026344, 50.64158499240875, 52.99828693270683, 57.45296269655228, 51.32624365389347, 39.40723702311516, 22.512912265956402, 18.50137822329998, 21.645595505833626, 19.579788856208324, 25.548592172563076, 10.280645694583654, 4.659047797322273, 0.3360398666700348, 0.519800113979727, 0.5873870279174298, 8.99977432563901, 33.68023373186588, 50.064365565776825, 39.442229345440865, 42.338559329509735, 56.748271510005, 65.86777076125145, 52.519372031092644, 16.27778884023428, 0.8720163954421878, 0.09753924459801055, 0.1456743269227445, 0.18512216251110658, 0.16757427365519106, 0.0829791087016929, 0.21999688411597162, 0.10773811256513, 0.16375651757698506, 0.1554723535082303, 0.21752571046818048, 0.13311193382833153, 0.06439962715376168, 0.17152905988041312, 0.14670122181996703, 0.07618015282787383, 0.21578764513833448, 0.1766333289560862, 0.0895027574733831, 0.11914332673768513, 0.16582086071139202, 0.08523695199983194], [0.07316562318010256, 0.02227662564109778, 0.023234359796333592, 0.033818185329437256, 0.05504274427948985, 0.11679634408210404, 0.011019230587407947, 0.01123078905948205, 0.019808463257504627, 0.05233368632616475, 0.09086799749638885, 0.007850230322219431, 0.03469506620604079, 0.015001801893959055, 0.040515248037991114, 0.010653894478309667, 0.019384201550565194, 0.02318250779353548, 0.03165639820508659, 0.043602237274171785, 0.002464706990394916, 0.04355111814220436, 0.06195146750542335, 0.16329600010067225, 9.76071959361434, 30.899985618889332, 49.91069421172142, 46.54196597635746, 33.927003890275955, 31.871813870966434, 29.473420567810535, 30.5679689347744, 14.834865666925907, 2.411527060903609, 0.18432690674671903, 0.13176316948374733, 0.9503572667017579, 3.7068616412580013, 9.046005494892597, 9.744620807468891, 6.17439603433013, 6.828054059296846, 13.035276532173157, 25.782463923096657, 35.716628059744835, 51.50062009692192, 46.83963060379028, 47.76746101677418, 52.99529269337654, 50.41742742061615, 49.42832909524441, 42.518586069345474, 38.335200548172, 39.41175878047943, 41.87446363270283, 46.447674036026, 49.60324890911579, 50.18278241157532, 46.158745139837265, 42.84704804420471, 34.40777309238911, 34.04752962291241, 34.26629528403282, 35.87091878056526, 36.525923833251, 38.360822573304176, 42.58733578026295, 46.570080667734146, 48.29429514706135, 53.38005244731903, 47.45392084121704, 49.823207706213, 48.54727417230606, 48.1897209584713, 46.71638801693916, 41.4840991795063, 35.20735278725624, 36.68131649494171, 35.054323598742485, 34.07613828778267, 34.38456013798714, 37.07251690328121, 34.85127389431, 35.974372029304504, 38.989175856113434, 47.680582478642464, 44.48851436376572, 55.03105625510216, 33.52207861840725, 41.26773118972778, 41.307693645358086, 49.909892454743385, 50.25184750556946, 43.981925547122955, 48.21617513895035, 47.95255288481712, 48.80716122686863, 50.85493594408035, 49.81372721493244, 48.12775008380413, 44.20758783817291, 33.6200525611639, 34.802727699279785, 36.78297623991966, 38.448005095124245, 44.85602304339409, 49.54038888216019, 52.252299562096596, 51.79237224161625, 50.14550261199474, 45.98398871719837, 41.342997550964355, 34.89453837275505, 35.7311774790287, 35.940371453762054, 35.86039714515209, 35.53021766245365, 39.08960446715355, 43.08788672089577, 49.48990859091282, 53.97969447076321, 45.39005398750305, 46.548015251755714, 47.45289869606495, 46.51451624929905, 53.32674130797386, 49.77623462677002, 54.9876169860363, 51.03503867983818, 50.87709255516529, 45.97353547811508, 47.04885497689247, 48.585112541913986, 45.24025462567806, 32.70398631691933, 23.02809052169323, 21.935100071132183, 10.120605882257223, 10.684467125684023, 11.903666853904724, 6.171246003359556, 1.6975958389230072, 0.5190297646913677, 0.2350081567419693, 0.20160622720140964, 7.572351945564151, 29.45123925805092, 51.14389903843403, 37.924275398254395, 36.580002531409264, 50.22182151675224, 48.996805250644684, 36.66738644242287, 9.07051607966423, 0.471341967349872, 0.056090723592205904, 0.04606037509802263, 0.02499220150639303, 0.060600981378229335, 0.0688542943680659, 0.06389159738318995, 0.06183395584230311, 0.010997994031640701, 0.013032859060331248, 0.029276067143655382, 0.02063784297206439, 0.02916718109190697, 0.05459306215925608, 0.02793093561194837, 0.051935583469457924, 0.056287522602360696, 0.03209114460332785, 0.10279177251504734, 0.03762204840313643, 0.032997930320561863, 0.018325221753912047, 0.022321963442664128, 0.019953400988015346, 0.01982476267585298, 0.03602204109483864, 0.03797683209995739, 0.03570047592802439, 0.03346224388224073, 0.040226437558885664, 0.07853405229980126, 0.08044329399126582, 0.076985494379187, 0.0099848390709667, 0.06776576410629787, 0.058720063752844, 0.010107400121341925, 0.027306679949106183, 0.039892114873509854, 0.053516725383815356, 0.06290949109825306, 0.04804665171832312, 0.022597198185394518, 0.004341591275078827, 0.0218281624984229, 0.2063833427382633, 11.693089753389359, 37.51809619367123, 58.43364827334881, 51.961873546242714, 35.999891459941864, 33.969519808888435, 34.35656324028969, 33.74518744647503, 16.612723767757416, 2.4477975396439433, 0.10459754397743382, 0.16922869894187897, 1.2182458606548607, 4.223703257739544, 7.410848261788487, 8.562768325209618, 6.597198396921158, 5.53860180079937, 14.481686018407345, 28.39863684028387, 41.16911128163338, 51.31870485842228, 48.43932196497917, 48.390232399106026, 54.554504826664925, 51.91370353102684, 50.83680711686611, 44.339691549539566, 40.874148309230804, 41.1910817027092, 44.75429110229015, 48.24051283299923, 51.989315673708916, 51.89475394785404, 47.19292804598808, 44.729740619659424, 36.497364565730095, 35.75077682733536, 36.44521236419678, 37.04184874892235, 38.29853631556034, 39.67165343463421, 44.981670901179314, 47.82708361744881, 52.08466395735741, 53.57197254896164, 47.78169505298138, 49.57549139857292, 50.158091336488724, 50.35699166357517, 48.26280623674393, 41.95924088358879, 36.76965795457363, 38.403524681925774, 36.04494944214821, 36.84102952480316, 36.88699185848236, 39.81809377670288, 37.289625853300095, 38.226233795285225, 39.62924391031265, 49.00481142103672, 46.51777647435665, 56.639072969555855, 36.76772005856037, 42.40762822329998, 44.34393972158432, 49.632457941770554, 51.64342403411865, 46.38367027044296, 50.03106415271759, 49.0947449952364, 50.080864280462265, 52.44288593530655, 53.40293101966381, 49.310151636600494, 45.7209288328886, 34.67559412121773, 36.85121297836304, 38.512020260095596, 40.288850516080856, 45.21015644073486, 52.87484675645828, 54.906669929623604, 53.03688906133175, 52.32258819043636, 48.66156063973904, 41.71440862119198, 36.30087710916996, 37.82853953540325, 36.994244903326035, 36.990103125572205, 38.00535164773464, 41.22688718140125, 45.9344507753849, 50.24924084544182, 55.06392829120159, 46.30066752433777, 48.80749560892582, 50.924251824617386, 52.6324387639761, 53.954524621367455, 51.93589814007282, 57.37132787704468, 53.712739795446396, 50.76292008161545, 48.86739559471607, 49.14983443915844, 51.84388227760792, 47.33661353588104, 37.61047683656216, 22.260324619710445, 16.26971997320652, 9.963541310280561, 16.180517859756947, 15.101922936737537, 6.719818767160177, 3.9941689744591713, 1.0040566977113485, 0.13911571557400748, 0.33656527753919363, 8.445571213960648, 32.904763743281364, 51.775440350174904, 37.7993419021368, 41.09139025211334, 55.479622185230255, 56.089284271001816, 43.00646468997002, 11.155775785446167, 0.5489118956029415, 0.07690206213737838, 0.007402584005831159, 0.019359732941666152, 0.038010918942745775, 0.08128011002554558, 0.09264882537536323, 0.00714299837454746, 0.03413904174522031, 0.01630300292163156, 0.029772764319204725, 0.0617482192319585, 0.041269618886872195, 0.016786480591690633, 0.042954672608175315, 0.05543591185414698, 0.008152601694746409, 0.07471913122572005, 0.02552214133174857, 0.05602242374152411, 0.03429653661441989, 0.026975409346050583, 0.08856650849338621, 0.09680831077275798, 0.09952395528671332, 0.20192811149172485, 0.11486746516311541, 0.20978755928808823, 0.11593301853281446, 0.10435232354211621, 0.1132306584622711, 0.1738764878246002, 0.19602763670263812, 0.17507613985799253, 0.09244173648767173, 0.19413449219428003, 0.142592083720956, 0.14291555620729923, 0.10445146705023944, 0.13217540283221751, 0.1764286743127741, 0.21903580287471414, 0.08183023441233672, 0.08688701345818117, 0.1837517719832249, 0.3969685878837481, 14.81758039444685, 40.60802198946476, 63.7092661857605, 58.066876754164696, 44.450079426169395, 42.38383010029793, 40.88474594056606, 39.748371317982674, 21.25045470893383, 3.2803580397740006, 0.5100006179418415, 0.35579233488533646, 3.1567169493064284, 10.619578957557678, 15.96093524247408, 16.74991350620985, 11.948328707367182, 10.700563061982393, 15.283857174217701, 29.21825286000967, 40.82889273762703, 52.00009569525719, 47.96307072043419, 48.775128945708275, 55.64242444932461, 54.38505671918392, 54.15980480611324, 47.15696677565575, 42.23874628543854, 42.96727739274502, 46.50338664650917, 50.76301887631416, 52.680449187755585, 54.21798728406429, 49.29782509803772, 47.8889063000679, 37.52821885049343, 37.40737393498421, 39.398976266384125, 39.0441133081913, 40.002695471048355, 42.01571725308895, 46.92102983593941, 50.60143254697323, 53.62442493438721, 55.23968406021595, 48.566375747323036, 52.49642126262188, 52.89151266217232, 52.62093298137188, 52.148375138640404, 45.76181463897228, 38.792076632380486, 39.99382294714451, 37.97331936657429, 38.9607647806406, 38.415437042713165, 41.376861333847046, 40.05042091012001, 40.3275590389967, 42.52473793923855, 51.052612736821175, 50.9709133207798, 58.34346391260624, 40.61998374760151, 44.54268425703049, 49.02346841990948, 49.88251492381096, 50.4498852789402, 48.13301660120487, 51.112964898347855, 51.042186096310616, 51.346914544701576, 54.80932295322418, 54.496690928936005, 52.62124076485634, 48.20913031697273, 37.5915652513504, 38.81371647119522, 41.2463915348053, 43.07423025369644, 47.894157618284225, 54.84999597072601, 58.46779704093933, 54.269740507006645, 53.07668812572956, 50.931634828448296, 45.89568145573139, 38.816771507263184, 39.36596743762493, 38.927444368600845, 39.89489905536175, 40.14145262539387, 44.0870963037014, 49.34366583824158, 52.94790543615818, 58.8960986584425, 47.43697755038738, 48.92297141253948, 53.03853817284107, 52.53580994904041, 55.46502336859703, 54.50288079679012, 60.28308503329754, 56.74049332737923, 54.105311930179596, 52.58320100605488, 51.368288397789, 55.480933114886284, 51.543174013495445, 36.351338401436806, 26.863015741109848, 27.60234396904707, 14.428213387727737, 23.313941583037376, 22.459969706833363, 14.843903481960297, 7.2248306684195995, 1.0796783398836851, 0.6924136891029775, 0.5594987806398422, 10.387960486114025, 38.414509892463684, 63.11614841222763, 49.5956265181303, 48.69601719081402, 64.29387241601944, 64.33932557702065, 50.06428577005863, 13.683821931481361, 0.7722349371761084, 0.20349408761831, 0.1103248905565124, 0.1501047852798365, 0.10124551525223069, 0.2513373055262491, 0.15327083179727197, 0.11265101886237971, 0.11738152752513997, 0.12886460783192888, 0.11554065989912488, 0.18755516008241102, 0.10580344489426352, 0.14640742039773613, 0.09353914283565246, 0.14577183028450236, 0.1873312541283667, 0.09369172097649425, 0.2105502792983316, 0.13041400437941775, 0.12161440390627831, 0.15166040102485567], [0.019311031355755404, 0.0460429197846679, 0.025814213549892884, 0.05854189636011142, 0.08010212128283456, 0.05592672008788213, 0.08022026377147995, 0.016181685896299314, 0.0553477113135159, 0.03149498108541593, 0.030817962433502544, 0.011063057190767722, 0.06577760985237546, 0.08632512603071518, 0.027181885961908847, 0.024819770915200934, 0.01963042017450789, 0.05638323738821782, 0.058920057708746754, 0.03301328906673007, 0.055003236047923565, 0.05715802843042184, 0.09475627244682983, 0.047500675937044434, 4.004900548607111, 26.770511604845524, 41.43567457795143, 49.69600573182106, 31.46038144826889, 17.876197770237923, 27.605307810008526, 29.524012953042984, 18.996626548469067, 4.133095219731331, 0.21458086848724633, 0.04173247412836645, 0.37522642174735665, 3.6866521881893277, 5.851423339918256, 4.608209375292063, 4.928482314571738, 3.634306197054684, 6.353843780234456, 17.738225273787975, 29.789280518889427, 44.159801602363586, 42.1677090972662, 49.898272678256035, 52.31171317398548, 50.851079151034355, 45.47565579414368, 42.637223303318024, 36.9347020983696, 37.05958999693394, 39.34196412563324, 43.74384932219982, 48.00565883517265, 48.49071800708771, 44.5235712826252, 40.58161340653896, 36.849187687039375, 33.980546817183495, 35.858976021409035, 37.524491250514984, 39.7437659651041, 47.20298990607262, 44.66339237987995, 47.62311816215515, 50.94622604548931, 51.22597463428974, 49.55885589122772, 51.44553065299988, 49.413878470659256, 51.67005680501461, 48.07887710630894, 47.47221685945988, 39.04619939625263, 35.887326300144196, 35.31818524003029, 36.442062333226204, 36.251738145947456, 36.28525994718075, 33.16658869385719, 40.54759383201599, 45.946895107626915, 47.47037015855312, 48.61703082919121, 55.19500605762005, 32.6339902728796, 30.233250595629215, 41.33490398526192, 39.02144372463226, 45.77729120850563, 46.19114600121975, 50.54763123393059, 51.13862492144108, 50.97170747816563, 49.16974917054176, 47.507999539375305, 47.77428925037384, 42.93077275156975, 34.021029844880104, 36.32971376180649, 34.60513450205326, 38.78013767302036, 44.83912155032158, 48.528670370578766, 52.12632492184639, 55.16842268407345, 50.76926954090595, 48.47643457353115, 44.30530719459057, 38.873342871665955, 34.224854707717896, 36.79470241069794, 35.23509509861469, 35.89821271598339, 41.25881686806679, 47.271572425961494, 46.415159180760384, 47.63844653964043, 47.83863119781017, 47.859332486987114, 53.10461662709713, 50.31459353864193, 45.8537545055151, 54.21186961233616, 51.03032313287258, 55.8924700319767, 52.415831387043, 52.42311179637909, 50.70282630622387, 44.30400386452675, 41.83903433382511, 30.01241024583578, 20.662158876657486, 15.686874948441982, 6.751715205609798, 15.75022229924798, 17.902165576815605, 5.407352093607187, 4.132984550669789, 2.61250255163759, 0.26164864597376436, 0.411485560471192, 9.544465597718954, 33.96347813308239, 49.351124837994576, 37.25132770836353, 40.34397795796394, 46.64107985794544, 50.21667659282684, 30.31625524163246, 7.69655398093164, 0.1818274869583547, 0.10010077472543344, 0.08845417702104896, 0.022451035911217332, 0.026221775078738574, 0.04941190287354402, 0.048403268519905396, 0.06104637388489209, 0.025069895091291983, 0.04405599749588873, 0.04703370919742156, 0.03301679200376384, 0.05269030683848541, 0.032958778319880366, 0.022941328352317214, 0.03466303140157834, 0.00801294248958584, 0.005794510479972814, 0.013239498948678374, 0.05509267226443626, 0.06030117969203275, 0.041989101373474114, 0.01706718496279791, 0.03549261891748756, 0.019225801261200104, 0.0429676898784237, 0.05115587198815774, 0.05110103098559193, 0.024956133129308, 0.001938761542987777, 0.0445981920347549, 0.0755673243838828, 0.03517825258313678, 0.05033409186580684, 0.07544983498519287, 0.023537818415206857, 0.04726993851363659, 0.04363825741165783, 0.004047808870382141, 0.03748219438421074, 0.06087376888899598, 0.029329544449865352, 0.044379225073498674, 0.029217084957053885, 0.07636039081262425, 0.10558215872151777, 5.694804769009352, 32.313735857605934, 48.260609954595566, 53.63939233124256, 37.47661381959915, 24.133369512856007, 32.33105532824993, 37.28446193039417, 21.19088150560856, 4.84760032966733, 0.2274664817377925, 0.05859034376044292, 0.5018693511374295, 3.4169561974704266, 6.798128290101886, 8.686765171587467, 9.673568420112133, 4.728987319394946, 9.004635214805603, 20.251767598092556, 31.15485694259405, 47.450862005352974, 44.52342689037323, 48.86831134557724, 55.06246916949749, 51.4343174546957, 49.24537271261215, 44.26629088819027, 38.31563159823418, 39.24118213355541, 41.00097790360451, 45.54475508630276, 51.268562749028206, 49.171079099178314, 46.495543867349625, 43.09824496507645, 37.49717451632023, 34.84265215694904, 37.43776090443134, 40.272762179374695, 39.87557329237461, 47.03083634376526, 47.13323324918747, 49.26053389906883, 51.077326610684395, 53.5074558109045, 51.83349743485451, 50.8833584189415, 52.01561026275158, 52.74840474128723, 49.22048784792423, 49.95829425752163, 39.91754963994026, 38.15285973250866, 36.55977621674538, 38.060912266373634, 36.772097423672676, 36.50187872350216, 35.23982584476471, 41.37423187494278, 47.30076625943184, 50.25139532983303, 50.5629938095808, 55.80875672399998, 35.85595518350601, 36.003166884183884, 43.24044853448868, 41.73576347529888, 47.62643538415432, 46.08197405934334, 50.93760810792446, 52.44839183986187, 53.10099922120571, 49.69403363764286, 50.6160693615675, 49.76244516670704, 44.48403060436249, 36.1821448802948, 38.52027341723442, 37.40909904241562, 41.77971951663494, 46.56940810382366, 50.63135974109173, 53.262961730360985, 55.081772133708, 52.108682468533516, 50.432284623384476, 46.32920779287815, 42.234327122569084, 36.745042875409126, 39.29315574467182, 38.18701229989529, 37.10391841828823, 41.95883430540562, 49.330054968595505, 49.70059208571911, 49.87296223640442, 47.767373621463776, 47.33016528189182, 54.983178824186325, 49.61837209761143, 49.0217699110508, 55.33427618443966, 52.25897580385208, 57.800959423184395, 57.561522871255875, 53.7815161049366, 51.939348354935646, 48.23100954294205, 45.11809878051281, 33.67362588644028, 21.755588203668594, 16.31065707653761, 13.484839908778667, 15.237312521785498, 14.119465705007315, 6.278708986938, 1.976237262133509, 0.6535249133594334, 0.2584287046920508, 0.6020490755327046, 10.313444584608078, 36.120990961790085, 50.96021689474583, 41.11461840569973, 43.82356904447079, 54.639468267560005, 58.93950752913952, 37.635908871889114, 8.878386989235878, 0.26065704762004316, 0.006921704780324944, 0.07379929113085382, 0.08406286695390008, 0.020482583822740708, 0.06591453609871678, 0.0501504066050984, 0.10840798247954808, 0.023911142816359643, 0.0292946097033564, 0.03508357309328858, 0.01406562249030685, 0.03530270703777205, 0.03381902024557348, 0.021852851896255743, 0.01921765062434133, 0.05630192768876441, 0.023204193348647095, 0.008271143087767996, 0.031267434897017665, 0.026982333583873697, 0.016226066327362787, 0.1125585546833463, 0.1321565968100913, 0.18674341379664838, 0.1537247293163091, 0.20145542279351503, 0.1478635735111311, 0.19266444607637823, 0.07934806213597767, 0.2826185035519302, 0.14246786304283887, 0.15664447186281905, 0.2533727197442204, 0.1437177139450796, 0.12457710196031258, 0.17840884305769578, 0.17764505435479805, 0.10312743106624112, 0.207205701735802, 0.16755785734858364, 0.13453335443045944, 0.17297639627940953, 0.17861232510767877, 0.22096992877777666, 0.27903508802410215, 6.54839476570487, 37.56419911980629, 56.05061374604702, 62.40128517150879, 43.77018190920353, 26.696789860725403, 38.76260541379452, 40.297886431217194, 26.999897696077824, 6.098402012139559, 0.6457892409525812, 0.21357631223509088, 1.8095935229212046, 8.363531716167927, 12.775775156915188, 12.731247246265411, 11.047720983624458, 7.43699655868113, 9.067451544106007, 19.874407947063446, 31.304677203297615, 47.56240501999855, 47.041441574692726, 51.53514884412289, 55.800419971346855, 55.61978906393051, 52.1047230809927, 47.75580324232578, 40.6636244058609, 42.64282800257206, 44.35997486114502, 48.55982109904289, 51.71432442963123, 52.13468827307224, 49.36453811824322, 45.14027439057827, 40.313606187701225, 36.823744252324104, 38.523286655545235, 42.051762118935585, 42.24292226135731, 50.6514872610569, 50.36290794610977, 52.40599371492863, 54.45222191512585, 55.3083273768425, 53.84217604994774, 52.91667491197586, 53.287717401981354, 55.34149959683418, 50.81550545990467, 53.44361163675785, 42.675529047846794, 39.952367171645164, 38.328604102134705, 40.37427373230457, 39.49458293616772, 39.507863223552704, 37.96759307384491, 44.350547567009926, 50.73795162141323, 52.20094531774521, 54.147140085697174, 56.4748115837574, 39.698669984936714, 38.735334277153015, 44.72857028245926, 43.27180825173855, 48.77297066152096, 46.32778286933899, 51.016571670770645, 55.077463164925575, 53.879303857684135, 53.961599841713905, 50.97265362739563, 52.758432403206825, 47.26022243499756, 36.77629619836807, 40.41575610637665, 38.88081707060337, 43.6565376073122, 47.546803057193756, 52.001250833272934, 55.792976170778275, 57.47343599796295, 54.397820234298706, 53.05695578455925, 48.441062271595, 44.452488496899605, 38.69855985045433, 41.940549686551094, 39.75534774363041, 39.96734216809273, 44.49568457901478, 52.66750708222389, 51.863242238759995, 50.64091242849827, 48.48946787416935, 52.61877849698067, 56.24870091676712, 51.93365626037121, 50.1325187087059, 55.48844911158085, 54.54886592924595, 59.34815660119057, 59.13121484220028, 57.22918510437012, 55.10954484343529, 52.38272376358509, 46.64646036922932, 33.929534554481506, 26.927899159491062, 19.986201748251915, 15.492398533970118, 26.46788064390421, 26.90216314047575, 15.10565148666501, 5.828817402943969, 3.1725725485011935, 0.675864270888269, 1.0708648315630853, 12.1369344368577, 43.719610422849655, 62.73081488907337, 48.60271319746971, 54.157456532120705, 59.72811721265316, 68.55963751673698, 45.705022886395454, 10.805229395627975, 0.5098910175729543, 0.2003176955622621, 0.2777520631207153, 0.23636330355657265, 0.09627015722799115, 0.20358114154078066, 0.16546785074751824, 0.18647817021701485, 0.14075816259719431, 0.1752792508341372, 0.10003609655541368, 0.05315411202900577, 0.07483434965251945, 0.17276777856750414, 0.1679654893814586, 0.12952893390320241, 0.10931407057796605, 0.18840349424863234, 0.11064178019296378, 0.196689187141601, 0.20613337255781516, 0.12230590000399388], [0.08656020130729303, 0.03764800130738877, 0.04560159424727317, 0.026905903505394235, 0.04337538870458957, 0.04961347018252127, 0.0285750789771555, 0.039535082469228655, 0.04479608571273275, 0.07568419037852436, 0.02782651543384418, 0.05635924746457022, 0.041076975903706625, 0.04214909356960561, 0.04791074221429881, 0.031615758198313415, 0.024828071836964227, 0.06748803018126637, 0.08824722914141603, 0.0695026048924774, 0.017006004163704347, 0.027081265579909086, 0.052631209618994035, 0.06048366267350502, 1.935585024766624, 23.107834942638874, 42.40462638437748, 47.28072613477707, 32.08941109478474, 26.451353430747986, 27.357108928263187, 27.488562874495983, 25.695152208209038, 8.137321304529905, 0.5679967871401459, 0.14942637324566022, 0.7845719845499843, 1.5537390019744635, 5.4102803114801645, 8.93160693347454, 9.056042656302452, 1.4000604045577347, 3.1546384608373046, 9.597856532782316, 19.794511534273624, 31.720777675509453, 48.59890200197697, 52.98317514359951, 49.97787460684776, 47.58850581943989, 45.795070454478264, 40.18059432506561, 37.05230578780174, 36.68423853814602, 35.94218775629997, 40.41213110089302, 43.43590624630451, 44.03884269297123, 43.19415181875229, 37.56133787333965, 34.48440358042717, 34.479684233665466, 36.20965160429478, 40.036361664533615, 44.76770058274269, 46.8431606143713, 47.73149974644184, 49.78665366768837, 51.16748057305813, 51.409683376550674, 50.42509160935879, 50.30209980905056, 50.566554218530655, 49.089778661727905, 51.31907343864441, 50.245380252599716, 46.447119265794754, 38.3130819350481, 33.17537002265453, 35.9330340474844, 32.8876456618309, 34.462018981575966, 40.76729044318199, 49.09499578177929, 47.281725481152534, 50.84292098879814, 46.97274886071682, 53.94173450767994, 35.175491496920586, 33.461148887872696, 49.74357157945633, 40.20693451166153, 52.59826719760895, 48.32378536462784, 52.32542283833027, 50.37004776299, 48.51793594658375, 47.036999613046646, 49.67474207282066, 44.83677327632904, 40.51386684179306, 33.59253443777561, 35.47300413250923, 34.92668464779854, 37.774973809719086, 42.55398117005825, 50.12306481599808, 50.442145094275475, 51.709540486335754, 49.43999066948891, 50.16195572912693, 46.68828472495079, 40.156260430812836, 35.31727708876133, 35.211806148290634, 35.847116857767105, 36.31975069642067, 38.39294224977493, 46.04017250239849, 47.48829759657383, 51.20142035186291, 46.790624633431435, 51.278396621346474, 49.435024335980415, 54.65077646076679, 48.866814225912094, 50.87273798882961, 50.57123936712742, 52.922689989209175, 53.041182830929756, 54.012809693813324, 47.77492381632328, 51.34356692433357, 39.981618002057076, 31.562231183052063, 15.204344540834427, 14.669372197240591, 11.165328472852707, 13.45259578898549, 8.4804960899055, 4.027283247560263, 3.0283838231116533, 0.7904391072224826, 0.212873067939654, 0.6581049144733697, 11.570544429123402, 33.00881735980511, 43.16043242812157, 40.442423075437546, 42.60978877544403, 46.70764088630676, 46.56380720436573, 22.93077014386654, 3.925996832549572, 0.15503815258853137, 0.02651923343364615, 0.045488873147405684, 0.09276073382352479, 0.06261664704652503, 0.021823852475790773, 0.03207834997738246, 0.01866549460828537, 0.06724514008965343, 0.0551575990539277, 0.017836079641710967, 0.04353086493210867, 0.0809287402080372, 0.04733191155537497, 0.05590136090177111, 0.01299246767302975, 0.07453870770405047, 0.0035790213178188424, 0.05838482822582591, 0.02873483554139966, 0.05420951281848829, 0.006765636690033716, 0.034186223783763126, 0.023342316308117006, 0.060328650288283825, 0.05822181919938885, 0.04351140210928861, 0.05539733872865327, 0.04274609200365376, 0.006873419724797714, 0.011224834252061555, 0.017536138802825008, 0.056802747494657524, 0.054686309304088354, 0.029520695716200862, 0.07729222401394509, 0.0778841610008385, 0.06063516470021568, 0.0594315607304452, 0.03311112268420402, 0.01366413172945613, 0.062118970236042514, 0.05507821522769518, 0.011269632141193142, 0.034662879261304624, 0.07664275573915802, 2.661377666518092, 27.615742050111294, 49.669323563575745, 55.33815577626228, 36.32616475224495, 26.142703592777252, 29.079516604542732, 32.48792991042137, 28.83187249302864, 8.674897458404303, 0.6106913555413485, 0.07891098168329336, 0.6706060655415058, 2.859855741262436, 4.58525575697422, 6.208050828427076, 7.7326862420886755, 4.698994103819132, 6.122728306800127, 10.700558312237263, 23.885478414595127, 36.38174057006836, 49.27179269492626, 54.034909307956696, 51.938592195510864, 48.8404056429863, 47.83971033990383, 42.11566708981991, 39.22388166189194, 38.894473537802696, 38.50524142384529, 41.90295070409775, 46.32885821163654, 46.89223498106003, 46.05691820383072, 39.54032488167286, 36.52683578431606, 35.33696763217449, 37.778344228863716, 40.569910034537315, 46.82680629193783, 48.47013831138611, 49.010191932320595, 49.93482671678066, 52.397527769207954, 52.76449307799339, 52.226445749402046, 51.41706258058548, 51.9171005487442, 51.49954855442047, 53.13800163567066, 52.81933553516865, 46.72691725194454, 39.18706923723221, 35.129278376698494, 37.779552564024925, 36.33672818541527, 36.170479506254196, 43.24285380542278, 49.14818912744522, 49.36263062059879, 52.92617440223694, 48.79614941775799, 55.033575519919395, 37.269182950258255, 36.494518518447876, 50.28987966477871, 40.50735019147396, 51.87878720462322, 50.489695742726326, 54.96524378657341, 52.44757488369942, 50.510602220892906, 48.77027280628681, 51.504492089152336, 46.44979812204838, 42.33506351709366, 36.55477948486805, 37.23313428461552, 36.9011726975441, 40.551815405488014, 45.580305978655815, 51.58902995288372, 52.90412798523903, 50.98010502755642, 50.45066423714161, 54.07593950629234, 49.511711820960045, 42.62690685689449, 37.07918934524059, 36.579428762197495, 36.51661433279514, 38.69891703128815, 40.56942366063595, 48.082999885082245, 49.59077797830105, 52.875192537903786, 49.842404276132584, 55.52109315991402, 52.4435319006443, 55.35048611462116, 52.06147760152817, 54.155013263225555, 52.03175559639931, 54.54596668481827, 55.57343915104866, 56.73363469541073, 53.08753274381161, 53.487742468714714, 42.37015463411808, 31.114155426621437, 15.65012902021408, 10.14331441372633, 11.821548510342836, 12.418113648891449, 8.672246150672436, 3.925641314126551, 2.6336638536304235, 0.2684494497952983, 0.12906768912216648, 0.8984516956843436, 12.754718586802483, 39.03135359287262, 52.80146509408951, 45.333254635334015, 49.064054042100906, 52.74830974638462, 53.011407628655434, 30.89697428047657, 5.28183912858367, 0.22169819829287007, 0.0648145322338678, 0.02272293841087958, 0.020796649587282445, 0.08441095647867769, 0.041440012282691896, 0.07863969702157192, 0.030352097783179488, 0.04386687600344885, 0.03046655921934871, 0.031137473706621677, 0.08263868556241505, 0.06511387007776648, 0.04619012848706916, 0.04163807665463537, 0.04461897588043939, 0.04015198159322608, 0.023812071667634882, 0.02973788337840233, 0.05262474180199206, 0.03796054937993176, 0.030207961572159547, 0.2007688768208027, 0.1484630655613728, 0.16005781682906672, 0.18749553593806922, 0.11533034266903996, 0.155857335194014, 0.12470463261706755, 0.12552230124128982, 0.08714489493286237, 0.1476811832981184, 0.18879401235608384, 0.13882936531445011, 0.09915033588185906, 0.10005033094785176, 0.20188497786875814, 0.1277883304283023, 0.14856579364277422, 0.13942925812443718, 0.19691159395733848, 0.21063601219793782, 0.1278854181873612, 0.1408342327340506, 0.08629540301626548, 0.18998183455551043, 3.0219982657581568, 31.16830062121153, 57.35482156276703, 60.91880992054939, 43.2635322958231, 37.06172168254852, 36.60234533250332, 39.08555008471012, 34.01577852666378, 11.195359211415052, 1.1472248216159642, 0.3408048109849915, 1.821794668212533, 5.321432054042816, 12.794015128165483, 18.867026902735233, 16.890937238931656, 4.817593339830637, 5.275424122810364, 11.65036579594016, 23.093859292566776, 34.790644347667694, 49.735208228230476, 55.30257448554039, 54.34412531554699, 51.71824961900711, 50.61863802373409, 44.1606717556715, 41.07850134372711, 40.133020877838135, 40.4723084717989, 44.99652050435543, 47.41797097027302, 48.54911707341671, 48.756555542349815, 40.73892496526241, 39.13159981369972, 39.13772888481617, 38.80502253770828, 43.84036414325237, 48.75470124185085, 50.98889395594597, 50.69346360862255, 51.81576758623123, 53.19209173321724, 55.56831702589989, 53.61622877418995, 53.10603015124798, 53.44370663166046, 51.56768649816513, 55.257087126374245, 54.285072684288025, 49.20256420969963, 41.95148929953575, 37.2276321798563, 38.932030722498894, 37.612399533391, 38.08109298348427, 45.22182181477547, 52.33365699648857, 52.258276641368866, 55.72788566350937, 51.08662851154804, 53.77312235534191, 39.04967240989208, 38.504610657691956, 47.97812171280384, 44.76384378969669, 53.67220737040043, 52.0078244805336, 56.25804841518402, 53.8056980073452, 51.89466655254364, 52.445025220513344, 54.94407132267952, 49.77200165390968, 44.567637518048286, 38.64506632089615, 38.9331478625536, 38.860146179795265, 43.52063030004501, 47.80031405389309, 54.76974807679653, 54.787903502583504, 52.600117698311806, 51.39292247593403, 55.912703946232796, 51.81181959807873, 43.87289799749851, 38.640020191669464, 38.885965794324875, 39.79606255888939, 39.950497671961784, 42.56018623709679, 50.929928719997406, 52.39791914820671, 54.697658345103264, 50.44414758682251, 56.03396683931351, 53.827174454927444, 57.377654537558556, 54.03901308774948, 56.36042632162571, 53.57315808534622, 56.99183464050293, 57.10246950387955, 59.61577624082565, 56.3818571716547, 56.47415801882744, 46.21193088591099, 34.729289039969444, 18.75023826956749, 17.901232726871967, 19.92041777819395, 21.66172944009304, 16.0806193202734, 9.485731199383736, 6.146138850599527, 1.610722525510937, 0.4004438279662281, 1.2394727091304958, 14.40581263974309, 42.836834192276, 56.56534552574158, 53.33458788692951, 54.073583632707596, 62.299203649163246, 61.01111076772213, 38.01021158695221, 6.633829856291413, 0.3801462077535689, 0.1569680927786976, 0.13524314446840435, 0.20132821868173778, 0.19958081713411957, 0.17501418536994606, 0.1598297993768938, 0.17465246259234846, 0.17474466701969504, 0.20310601859819144, 0.1276966603472829, 0.16818040050566196, 0.1181480176455807, 0.13935347000369802, 0.1434861490270123, 0.10992116964189336, 0.1335997029673308, 0.10638737410772592, 0.17057447985280305, 0.2055222139460966, 0.22987365256994963, 0.08246891185990535], [0.042316217804909684, 0.05025583610404283, 0.04640609346097335, 0.04487622281885706, 0.026004244173236657, 0.022191365860635415, 0.01100934146961663, 0.0469448852527421, 0.028553135525726248, 0.0300495297415182, 0.04657626421249006, 0.04294754056900274, 0.01992986748518888, 0.02418283937004162, 0.1116303876915481, 0.020287675433792174, 0.03485252396785654, 0.03776264456973877, 0.013795181093883002, 0.061386336892610416, 0.03688178207085002, 0.05978186185529921, 0.01701756311376812, 0.0563451095513301, 0.5950901645701379, 11.040020696818829, 39.55001436173916, 46.29215978085995, 43.72972548007965, 29.101762510836124, 32.619406655430794, 39.64444689452648, 33.231470212340355, 11.90193984657526, 1.4721928839571774, 0.2079330213018693, 0.27679887833073735, 2.3640110855922103, 3.8293962785974145, 4.476981991901994, 6.404673652723432, 4.418955305591226, 3.566248998977244, 4.063664395362139, 12.2001981921494, 23.612501062452793, 41.141361370682716, 52.33696661889553, 49.18974369764328, 46.19116500020027, 42.2646988928318, 42.077718526124954, 38.40106621384621, 37.9747024923563, 36.94853715598583, 36.18904910981655, 37.29558393359184, 38.08727525174618, 37.87786088883877, 36.656006053090096, 34.56276297569275, 35.22327773272991, 33.93313676118851, 41.53505824506283, 48.17066118121147, 49.00543838739395, 49.15795840322971, 49.9583550542593, 50.09550489485264, 48.49124237895012, 45.44844165444374, 47.9539056122303, 50.874721482396126, 49.97314766049385, 51.087806448340416, 51.017164438962936, 48.583353236317635, 43.22993069887161, 35.88670693337917, 36.301644667983055, 32.476253136992455, 36.215070113539696, 43.77576380968094, 50.890661627054214, 48.637420535087585, 49.84695643186569, 45.866495221853256, 50.39117842912674, 34.8650823533535, 38.95771734416485, 52.128456607460976, 52.623003870248795, 51.79682180285454, 49.925483018159866, 49.36959944665432, 48.03558222949505, 46.62342980504036, 45.692198574543, 45.382450595498085, 42.91233234107494, 36.24160408973694, 33.95274370908737, 34.693555757403374, 35.15997312963009, 37.951519936323166, 44.60870571434498, 47.449687868356705, 48.24653550982475, 49.20930124819279, 50.68215161561966, 48.666979148983955, 48.15515421330929, 43.3347062766552, 35.4368756711483, 35.17691642045975, 36.82630531489849, 36.27957925200462, 35.96600487828255, 42.902240082621574, 48.179993480443954, 51.04304865002632, 50.857588201761246, 50.204030871391296, 50.24466589093208, 48.46175596117973, 50.653900131583214, 51.385398879647255, 51.50227680802345, 54.140357449650764, 51.79291561245918, 51.726563572883606, 53.188014551997185, 46.2007062882185, 34.5453979074955, 24.92065116763115, 14.006936643272638, 10.42398065328598, 15.8845916390419, 11.584123950451612, 8.875959869474173, 3.2653457578271627, 1.3195877289399505, 0.19477649446344003, 0.05113763741974253, 1.7217981652356684, 12.459151446819305, 39.15523834526539, 34.13780897855759, 25.50867721438408, 35.05577132105827, 45.070734322071075, 45.654645189642906, 23.209449090063572, 2.2319396724924445, 0.08423657403909601, 0.05580390577961225, 0.044195936861797236, 0.0129793103224074, 0.024652490828884766, 0.01482452415075386, 0.012520471027528401, 0.039494917436968535, 0.049987794627668336, 0.12182135178591125, 0.04275899424101226, 0.039229080139193684, 0.04285383700334933, 0.0027685543091138243, 0.05209888935496565, 0.05869731692655478, 0.02620169998408528, 0.04667292152589653, 0.05450875418318901, 0.03482186213659588, 0.05347844540665392, 0.06414903356926516, 0.12040770146995783, 0.01705264443444321, 0.04925945831928402, 0.051789072385872714, 0.04726613871753216, 0.025862553338811267, 0.030910001732991077, 0.07043287958367728, 0.024117958964779973, 0.03719853069924284, 0.009369957660965156, 0.06101549312006682, 0.04337203790782951, 0.01325732069744845, 0.06148688305984251, 0.005378968544391682, 0.03470942305284552, 0.04497969304793514, 0.01811970621929504, 0.11278454607236199, 0.021327736030798405, 0.08193466201191768, 0.011588169345486676, 0.15435779612744227, 0.7252335967496037, 14.925415758043528, 46.67310453951359, 52.854354456067085, 48.17707143723965, 34.02637615799904, 33.71821269392967, 40.12080453336239, 35.57482726871967, 12.782558742910624, 1.5951249562203884, 0.14352998026879504, 0.14796639065025374, 1.7940294393338263, 5.275265006348491, 5.060071628540754, 9.963393118232489, 9.656233750283718, 6.8120241444557905, 6.139579452574253, 14.031820558011532, 28.219195269048214, 43.66180032491684, 54.25419934093952, 50.984748378396034, 47.437821105122566, 44.76919770240784, 43.55130225419998, 40.78035794198513, 38.26285623013973, 39.490414559841156, 38.75372149050236, 39.732792153954506, 40.42586736381054, 40.46893045306206, 38.37073624134064, 35.74420318007469, 36.14035092294216, 37.03476592898369, 43.31182770431042, 48.35374295711517, 51.15967199206352, 51.28959842026234, 50.87155245244503, 51.12092927098274, 51.20390921831131, 48.163597360253334, 51.34646616876125, 51.82385355234146, 53.36874805390835, 52.1638099104166, 50.650316923856735, 50.91771237552166, 43.91386739909649, 36.209237426519394, 37.03864172101021, 34.8312945663929, 37.99542278051376, 46.214586943387985, 52.958928644657135, 50.34112751483917, 51.56018190085888, 46.43401376903057, 51.867881789803505, 37.50691719353199, 40.2570766210556, 51.5330171585083, 54.48801979422569, 53.24377276003361, 51.20696045458317, 51.4280591905117, 49.78771761059761, 50.202605947852135, 49.220962822437286, 48.019501492381096, 44.58176515996456, 37.880319356918335, 35.46856977045536, 37.615526765584946, 38.04396137595177, 40.86060583591461, 46.70857943594456, 49.241979494690895, 50.293580666184425, 49.55191746354103, 51.46576836705208, 50.888507142663, 50.29008865356445, 45.25007329881191, 37.79580809175968, 37.72186405956745, 39.0886165201664, 37.96820864081383, 39.520486146211624, 45.74106015264988, 51.047125831246376, 52.722535729408264, 53.21951866149902, 52.11112953722477, 52.869781628251076, 50.90473227202892, 52.19086825847626, 52.82125823199749, 54.928613752126694, 55.71316905319691, 54.42925974726677, 54.95917171239853, 55.19104667007923, 51.16708539426327, 36.94244608283043, 24.644972160458565, 13.52625198662281, 8.004782516509295, 10.857468992471695, 9.817138966172934, 6.577895907685161, 3.9252993324771523, 1.6102143027819693, 0.24026165687246248, 0.11573689116630703, 1.538724701385945, 14.352797884494066, 42.63743229210377, 43.16736325621605, 33.84353756904602, 41.053893864154816, 52.817815616726875, 50.914079770445824, 26.417795531451702, 2.6941822562366724, 0.03247366606956348, 0.04024541427497752, 0.03637502137280535, 0.0039051263411238324, 0.057709815228008665, 0.09105368284508586, 0.006017594041622942, 0.031797959163668565, 0.1102803616959136, 0.03024708574230317, 0.029446993030433077, 0.04001485496701207, 0.019902044368791394, 0.008379375121876365, 0.03216387136490084, 0.06849941419204697, 0.04821701913897414, 0.04737462215416599, 0.03447364273597486, 0.025915088117471896, 0.04388831293908879, 0.07056282964185812, 0.24787134228972718, 0.1714153034845367, 0.1479654258582741, 0.19359030498890206, 0.0898264822899364, 0.1427556382259354, 0.08544371434254572, 0.2514452731702477, 0.13665171107277274, 0.0977979572780896, 0.08645286448881961, 0.1630604127421975, 0.1224055110651534, 0.15021337632788345, 0.22547568543814123, 0.09083088269107975, 0.1335708037368022, 0.0829984713345766, 0.11844537395518273, 0.19983782287454233, 0.1047627831576392, 0.19127750565530732, 0.13941319804871455, 0.2965029585175216, 1.1049843882210553, 17.095242775976658, 52.56149277091026, 60.41321665048599, 56.109958961606026, 39.963918551802635, 44.20623891055584, 50.44934190809727, 42.8761924803257, 16.166684702038765, 1.919521267991513, 0.3942275099689141, 1.111796353943646, 5.554272159934044, 9.376696050167084, 12.529602516442537, 15.826767291873693, 10.384011548012495, 6.170638985931873, 5.41265138424933, 13.38939568027854, 27.784329503774643, 44.89440478384495, 56.23226299881935, 53.92147779464722, 51.674605160951614, 47.62230880558491, 46.019011437892914, 43.4200306981802, 41.08284831047058, 39.75469797849655, 40.526200979948044, 41.35998263955116, 43.20433147251606, 42.981629222631454, 39.30774696171284, 37.234384417533875, 39.70134884119034, 39.41666431725025, 46.294078677892685, 51.68444283306599, 52.696947902441025, 51.761799082159996, 51.63693018257618, 53.69683384895325, 51.40712611377239, 50.26092901825905, 53.11988040804863, 53.51644612848759, 53.97712200880051, 53.59688401222229, 53.127498999238014, 54.47465591132641, 48.296624422073364, 39.277037009596825, 39.69595693051815, 36.997812911868095, 40.67412704229355, 48.75283554196358, 55.154975205659866, 52.07379274070263, 52.128027230501175, 48.53679433465004, 50.363458916544914, 42.049919217824936, 43.0574731528759, 52.98516243696213, 56.92407667636871, 54.79812875390053, 54.05594877898693, 52.897683531045914, 51.492803916335106, 51.4184495061636, 51.607728749513626, 50.266989693045616, 47.27118104696274, 39.621313735842705, 38.3784232288599, 39.71834912896156, 40.36248676478863, 43.935336247086525, 48.61516892910004, 51.97730451822281, 53.04085984826088, 51.46762266755104, 53.68764974176884, 53.43949265778065, 52.60150082409382, 48.38390953838825, 40.88521331548691, 38.922470435500145, 41.33024163544178, 40.406047627329826, 39.77947264909744, 47.146692126989365, 53.47165413200855, 55.778681337833405, 55.90203791856766, 53.23559179902077, 54.21614818274975, 51.617391631007195, 54.69749115407467, 55.48894688487053, 57.71399348974228, 57.39537678658962, 57.11953818798065, 55.064505860209465, 56.623406410217285, 50.113895907998085, 39.152764678001404, 27.131993807852268, 16.4790241420269, 13.572209570556879, 22.340545915067196, 22.97771282494068, 15.943961553275585, 9.830166567116976, 3.79768128041178, 0.43219744751695544, 0.24711975449463353, 2.790878755040467, 16.925308294594288, 48.83076936006546, 47.401966229081154, 36.890647262334824, 48.60392153263092, 59.9625114351511, 59.007960855960846, 32.20739856362343, 4.137707697227597, 0.15638118755305186, 0.10845295662875287, 0.08799951508990489, 0.09614825205062516, 0.22666923701763153, 0.20551587600493804, 0.17482898983871564, 0.1103188717388548, 0.2611651812912896, 0.15075698465807363, 0.16047957935370505, 0.18367911572568119, 0.1296014862600714, 0.07490011135814711, 0.12141913000959903, 0.09522716514766216, 0.1671281538438052, 0.12104217836167663, 0.13198526459746063, 0.14091015444137156, 0.1476118667051196, 0.18036581226624548], [0.011946673057536827, 0.03203748361556791, 0.01768896556313848, 0.0316945074882824, 0.004824113430004218, 0.014723066069564084, 0.03958621644414961, 0.05636970803607255, 0.008074746692727786, 0.07622549062944017, 0.10814523251610808, 0.07213606397272088, 0.014687530183437048, 0.029414512937364634, 0.04932710879074875, 0.030370332351594698, 0.020452923890843522, 0.04160927390330471, 0.011614822651608847, 0.04324528650613502, 0.0406707279762486, 0.013022864186496008, 0.04599990490532946, 0.03589642517908942, 0.5479595717042685, 6.8941975850611925, 32.445193603634834, 52.255745977163315, 44.812131598591805, 33.82265768945217, 29.59943700581789, 36.27608343958855, 36.71570084989071, 17.907690480351448, 2.777717448771, 0.2955475472845137, 0.164705858041998, 1.313102189451456, 2.296254546381533, 1.7577138380147517, 5.285272719338536, 10.02199737355113, 7.390766814351082, 1.7573828995227814, 6.796129597350955, 17.94956613332033, 33.14465247094631, 48.756426349282265, 47.58144959807396, 45.62006324529648, 43.36074247956276, 40.10375864803791, 38.28610338270664, 36.779925003647804, 36.47232010960579, 36.73825263977051, 36.334813088178635, 36.968733072280884, 35.108432695269585, 34.21600118279457, 33.72713841497898, 35.65519295632839, 36.901556476950645, 44.53160025179386, 47.527868673205376, 47.8897612541914, 48.962626084685326, 50.14236018061638, 49.746714010834694, 45.63486345112324, 46.645909398794174, 47.15241082012653, 48.555595725774765, 51.73309162259102, 49.253470078110695, 50.99685072898865, 49.863800927996635, 46.12846456468105, 35.62082380056381, 34.90005187690258, 32.288121432065964, 40.00578090548515, 45.727669671177864, 50.94701260328293, 46.113580763339996, 51.575878858566284, 45.84034122526646, 49.41126421093941, 36.552700996398926, 39.869136437773705, 56.34307265281677, 46.349662095308304, 48.85547183454037, 46.418556198477745, 47.95389041304588, 48.58676925301552, 46.78115174174309, 43.12217988073826, 43.83460745215416, 38.82821649312973, 36.444258615374565, 35.802260264754295, 36.708238050341606, 37.066509425640106, 38.6740929633379, 47.36717529594898, 48.31248477101326, 50.91029517352581, 48.42646725475788, 50.03383420407772, 52.46887654066086, 47.78422191739082, 43.11583422124386, 35.69805845618248, 34.926878437399864, 34.63258422911167, 35.71794658899307, 34.71206076443195, 35.98005652427673, 39.59995128214359, 45.46785481274128, 47.275474816560745, 46.15567110478878, 45.83259344100952, 46.59772798418999, 45.9698610752821, 48.27957093715668, 50.712306797504425, 54.41787175834179, 55.82819268107414, 50.67944996058941, 44.421284571290016, 38.01244206726551, 27.586115039885044, 16.04871053248644, 7.260663695633411, 1.665218013804406, 6.39776467345655, 5.273887580260634, 3.3436405565589666, 2.1019885456189513, 1.1419258872047067, 0.0529986729088705, 0.13280187937198207, 1.666294781025499, 17.615932635962963, 37.632154673337936, 34.93200056254864, 26.76169417798519, 39.304555132985115, 48.479550406336784, 49.88967753946781, 19.148447401821613, 1.2800868297927082, 0.06324365793261677, 0.05424306531494949, 0.01446266500352067, 0.004097020218978287, 0.0564627622225089, 0.05730855824367609, 0.07208651077235118, 0.023012010497041047, 0.027527828824531753, 0.03723427253135014, 0.02051665953331394, 0.03992990874394309, 0.07624796286108904, 0.023529968348157126, 0.043412703889771365, 0.05817040320835076, 0.09125269716605544, 0.04193105058220681, 0.047906033287290484, 0.057152094959747046, 0.013973898603580892, 0.08092214251519181, 0.05796486912004184, 0.07594449125463143, 0.024467558760079555, 0.07797701851814054, 0.050014118605758995, 0.014093919653532794, 0.03294446971267462, 0.04931120085529983, 0.03252127113228198, 0.06311807912425138, 0.03489574293780606, 0.011397083944757469, 0.055540484172524884, 0.05663643591105938, 0.05950619110080879, 0.010069961554108886, 0.04194323664705735, 0.03457647471805103, 0.016755575707065873, 0.025040723121492192, 0.01802298953407444, 0.03486823523417115, 0.021690796529583167, 0.04204440250759944, 0.5473934020847082, 8.599483855068684, 40.448073372244835, 57.38016240298748, 51.37215279042721, 35.55191069841385, 34.52887639403343, 42.713139429688454, 42.602170184254646, 19.286782778799534, 2.896122895181179, 0.3431971982354298, 0.46204187732655555, 1.2118143495172262, 3.142754123546183, 5.337708005681634, 8.800248932093382, 9.620273429900408, 7.262501372024417, 4.574039233848453, 8.762610051780939, 21.179016642272472, 34.26324404776096, 53.31411838531494, 49.483087956905365, 48.56398947536945, 44.43595178425312, 42.539826929569244, 38.82891945540905, 38.1051304936409, 37.65521563589573, 38.65862779319286, 38.10474291443825, 38.081586956977844, 37.018856182694435, 35.9354393184185, 35.844878777861595, 37.95194551348686, 37.882591634988785, 46.70736350119114, 49.70516324043274, 51.20339244604111, 48.55581611394882, 50.18646441400051, 51.423609629273415, 49.254910200834274, 49.90423835813999, 48.61833035945892, 50.31754978001118, 53.1541583687067, 49.93737258017063, 50.418821945786476, 51.77145056426525, 47.96294152736664, 37.88254223763943, 36.9598301500082, 34.360427632927895, 40.48746585845947, 49.07546862959862, 51.740702614188194, 49.069643542170525, 52.461113557219505, 48.12309913337231, 49.29921202361584, 38.395533710718155, 43.23504902422428, 57.42608293890953, 47.64391824603081, 50.165390744805336, 49.57891881465912, 49.962398037314415, 51.276158541440964, 47.86475479602814, 46.15227788686752, 45.70216543972492, 42.3589376360178, 38.028446808457375, 37.17826522886753, 37.80321769416332, 38.86260844767094, 40.7642088085413, 48.82838688790798, 50.22004321217537, 51.387861147522926, 49.25223134458065, 51.63758374750614, 54.22570466995239, 48.07586386799812, 45.35299837589264, 37.88254223763943, 36.56381919980049, 37.45228752493858, 38.52613650262356, 37.13232949376106, 38.76969963312149, 43.23539100587368, 48.80632147192955, 49.12873797118664, 48.635988011956215, 48.595941960811615, 47.45387144386768, 48.01257066428661, 51.189971566200256, 52.52898931503296, 55.73478229343891, 58.46157677471638, 52.49680884182453, 50.19184872508049, 40.97738116979599, 31.996962055563927, 20.561924055218697, 9.864741861820221, 4.481074372306466, 7.665395177900791, 6.314088888466358, 8.104362823069096, 2.9759691981598735, 0.7699497160501778, 0.1404108077986166, 0.0630827306304127, 2.250042613595724, 18.933724723756313, 44.96544197201729, 39.752307906746864, 29.293274134397507, 43.10318470001221, 54.74853001534939, 54.75344315171242, 23.28447036445141, 1.5328809712082148, 0.03356145789439324, 0.05202127555094194, 0.036801637543248944, 0.060122900977148674, 0.07952543543069623, 0.041300570155726746, 0.047409124599653296, 0.02524711067962926, 0.050120935920858756, 0.01500091781053925, 0.021516785163839813, 0.07310245899134316, 0.015428803981194505, 0.010026348318206146, 0.03062547530134907, 0.03361871829838492, 0.03652868304925505, 0.05664365329721477, 0.052858911658404395, 0.04216919463942759, 0.051289143157191575, 0.06185020516568329, 0.12536055757664144, 0.11544818087713793, 0.07812639058101922, 0.20846950501436368, 0.12075008387910202, 0.09560177903040312, 0.14685288711916655, 0.09760796747286804, 0.14735122444108129, 0.1548781752353534, 0.0989707509870641, 0.14213159593055025, 0.14891892235027626, 0.10599724933854304, 0.11843875399790704, 0.1483756405650638, 0.15687953971792012, 0.15747653815196827, 0.14641516841948032, 0.11396347734262235, 0.08201463584555313, 0.12635080522159114, 0.1584134847507812, 0.15859223844017833, 0.7287469832226634, 10.145163014531136, 45.83414375782013, 66.06523096561432, 57.543249651789665, 43.03505815565586, 40.05914144217968, 48.1335561722517, 47.58549638092518, 23.205894380807877, 3.9879662822932005, 0.4693878331454471, 0.7603822450619191, 4.094569087028503, 5.221144035458565, 10.406982265412807, 15.860980655997992, 17.46016949415207, 13.023003190755844, 3.4565764339640737, 9.499720148742199, 21.122593469917774, 36.34406939148903, 55.17734460532665, 52.00870603322983, 50.918916910886765, 47.463477328419685, 44.507832527160645, 41.30862079560757, 40.384153202176094, 40.66264785826206, 40.90231239795685, 40.98150014877319, 39.51962359249592, 38.218508809804916, 37.80938096344471, 36.64243698120117, 38.9816028624773, 40.989194735884666, 48.93055960536003, 52.60746270418167, 52.57905922830105, 49.54068906605244, 52.672629207372665, 55.44687174260616, 50.86956895887852, 50.33825486898422, 50.64055144786835, 52.872053906321526, 56.413501873612404, 51.49306610226631, 53.22047621011734, 54.82154689729214, 50.75179807841778, 40.256571248173714, 38.955407068133354, 34.703701213002205, 43.62200506031513, 50.382849276065826, 54.552893713116646, 50.86589075624943, 54.23607811331749, 49.42795671522617, 50.62589183449745, 40.76654568314552, 46.48150362074375, 58.952426835894585, 52.3239903151989, 52.67401613295078, 50.5488433688879, 51.13312281668186, 53.7290333211422, 50.209004804492, 47.205946147441864, 48.19597162306309, 44.14760045707226, 41.11897297203541, 39.39321957528591, 40.153490379452705, 41.68869540095329, 42.777264788746834, 51.15157462656498, 53.025934249162674, 54.01778742671013, 49.55133989453316, 52.46884234249592, 57.14020527899265, 51.11719027161598, 48.21735307574272, 39.39221262931824, 39.088890105485916, 38.32325778901577, 40.45826442539692, 37.873836904764175, 39.60585996508598, 44.0121491253376, 49.543474316596985, 51.28452189266682, 50.80342210829258, 51.597172915935516, 51.48494973778725, 50.48104740679264, 54.20901216566563, 54.1149216145277, 58.9117956161499, 58.46435822546482, 53.017479702830315, 48.67215447127819, 43.739213570952415, 29.796849712729454, 19.92834035307169, 8.037396166473627, 4.2274892795830965, 14.156543165445328, 13.558085728436708, 12.64256950467825, 8.060204442590475, 6.374546969309449, 0.3993654280202463, 0.44474728347267956, 2.3973654583096504, 23.72645314782858, 47.88331679999828, 47.67741344869137, 38.61120633780956, 51.79177567362785, 61.91293157637119, 63.05720217525959, 25.541182570159435, 2.0089920982718468, 0.13115827459841967, 0.18296435329830274, 0.10722492486820556, 0.2501136821229011, 0.16329853824572638, 0.16166737186722457, 0.18350788741372526, 0.06481400530901738, 0.15333532443037257, 0.09645668120356277, 0.176040145161096, 0.16532746609300375, 0.16398315463447943, 0.11641459816019051, 0.21375364100094885, 0.22947730118175969, 0.17578060127561912, 0.16012100328225642, 0.24100910348352045, 0.17486433091107756, 0.14086733252042904, 0.17094144219299778], [0.08477818599203601, 0.029644222486240324, 0.03164687645039521, 0.0610118454642361, 0.043236863130005077, 0.020918593727401458, 0.05277562413539272, 0.03853714617434889, 0.03884816913341638, 0.06730471970513463, 0.015425196215801407, 0.0037425753589559463, 0.032316260258085094, 0.01447604128770763, 0.02174870631279191, 0.0408052014245186, 0.07817716090357862, 0.04266668591299094, 0.053025434754090384, 0.027560180897125974, 0.015043129315017723, 0.14079693239182234, 0.06711280031595379, 0.03587493258237373, 0.10070522432215512, 3.5512509662657976, 23.96514303982258, 49.97681826353073, 48.859397023916245, 40.78586004674435, 29.134195670485497, 34.25057552754879, 35.22942580282688, 22.574174478650093, 5.96647784113884, 0.4256632528267801, 0.03745865345990751, 0.7013037276919931, 4.35074801556766, 2.3268345929682255, 7.776644183322787, 9.811653960496187, 5.899722073227167, 3.7457886524498463, 2.992268898524344, 11.840761229395866, 25.192703269422054, 46.958450227975845, 49.250434041023254, 45.167598724365234, 43.30581642687321, 42.169035226106644, 41.80485516786575, 40.655439645051956, 39.76447485387325, 37.79530271887779, 39.68388877809048, 37.94955924153328, 35.635274425148964, 36.581488251686096, 35.37698708474636, 35.91312311589718, 38.66015151143074, 45.86985424160957, 48.68689768016338, 48.33238810300827, 49.87266585230827, 50.68961821496487, 46.64031229913235, 46.981294602155685, 42.060209065675735, 45.546597987413406, 44.93811383843422, 49.98666353523731, 47.12563365697861, 51.39676406979561, 50.82805618643761, 46.557028368115425, 39.18366461992264, 36.08812652528286, 34.43041607737541, 40.85230328142643, 42.21077598631382, 49.32218559086323, 49.63632233440876, 49.60412286221981, 45.14758139848709, 49.668244421482086, 36.60976253449917, 40.71167662739754, 53.97509291768074, 46.27238944172859, 47.08618797361851, 44.31419491767883, 44.541320130228996, 43.20597678422928, 42.918275222182274, 40.328064411878586, 40.660557970404625, 36.62957467138767, 35.89622922241688, 35.094206258654594, 36.94831296801567, 37.45179355144501, 41.35122410953045, 47.550884038209915, 45.097462087869644, 50.069168508052826, 47.83980153501034, 52.4134337157011, 50.852743461728096, 47.59986720979214, 41.90358147025108, 36.19259811937809, 37.44105912744999, 35.88002689182758, 37.09469631314278, 37.92826898396015, 35.63508823513985, 37.77536518871784, 38.08951333165169, 40.81260681152344, 38.77895973622799, 42.563545256853104, 41.158905029296875, 44.47553426027298, 45.5156334489584, 47.72049553692341, 50.09013958275318, 55.322352424263954, 48.43889258801937, 40.196135491132736, 29.141485579311848, 19.182586669921875, 9.529270213097334, 6.2879434414207935, 3.2327128713950515, 5.335501749068499, 5.011632302775979, 6.075496366247535, 1.959535852074623, 0.37630960112437606, 0.19682296668179333, 0.1297174987848848, 2.8641100879758596, 17.38614186644554, 44.56989459693432, 42.259477972984314, 42.267924919724464, 41.607679948210716, 54.27588477730751, 39.690378829836845, 13.906764518469572, 0.8789636101573706, 0.07645707781193778, 0.008257618374045705, 0.018206218373961747, 0.031118537808652036, 0.05315452021022793, 0.007400470740321907, 0.0796556675049942, 0.023629597963008564, 0.04615617523086257, 0.022244373758439906, 0.046167997643351555, 0.06603952861041762, 0.05463556866743602, 0.05802787003631238, 0.024416422929789405, 0.04624260946002323, 0.017287524897255935, 0.027548731413844507, 0.08201229808037169, 0.0615814326738473, 0.027659734441840556, 0.001610309825537115, 0.027787806866399478, 0.042965919856214896, 0.0020750996372953523, 0.03755258709134068, 0.03129797798465006, 0.03384362986253109, 0.09733592582051642, 0.010099165065184934, 0.04036703743622638, 0.05262741724436637, 0.047981131210690364, 0.04836576037632767, 0.009006903655972565, 0.046233822431531735, 0.10823792676092125, 0.012950958425790304, 0.09920182608766481, 0.04508866259129718, 0.04200128743832465, 0.03277774994785432, 0.05412245889601763, 0.05416389300080482, 0.019245996954850852, 0.01897242276754696, 0.12212733927299269, 4.649204900488257, 29.93693109601736, 56.63356326520443, 53.31544451415539, 42.883830070495605, 32.941997945308685, 35.72707749903202, 39.026470854878426, 25.906599462032318, 6.295379167422652, 0.49650605767965317, 0.0660897497436963, 0.7597801554948092, 2.532898960635066, 6.291237864643335, 8.471867702901363, 9.386912751942873, 6.433020606637001, 7.376128574833274, 5.693367496132851, 15.078415498137474, 28.17833036184311, 49.004085659980774, 53.36096227169037, 49.65432196855545, 45.54562143981457, 43.749229833483696, 43.41091498732567, 42.22526840865612, 41.2808670848608, 39.192092567682266, 40.037269815802574, 40.44973008334637, 37.08927400410175, 37.848864644765854, 37.3253021389246, 37.645632550120354, 40.530198365449905, 48.420227989554405, 49.77675139904022, 49.663817659020424, 50.25001600384712, 52.44854383170605, 49.199721962213516, 49.41863961517811, 44.06848110258579, 46.16384066641331, 46.79346688091755, 53.589238822460175, 49.11506250500679, 53.73202756047249, 52.57242478430271, 48.66288676857948, 40.9960001707077, 37.99225755035877, 36.47420860826969, 41.85218542814255, 43.88461656868458, 51.18308253586292, 51.505461037158966, 50.9573670476675, 45.909885093569756, 50.95869317650795, 39.018263295292854, 43.33329655230045, 53.86964477598667, 49.449250772595406, 48.356102630496025, 47.25610725581646, 47.589223980903625, 44.87284854054451, 44.97521884739399, 43.23059566318989, 43.34296703338623, 38.422846645116806, 36.267514899373055, 36.71788953244686, 38.06880064308643, 40.70176675915718, 43.08198943734169, 50.46039931476116, 48.30963492393494, 53.019341602921486, 48.672568649053574, 52.832410633563995, 52.228889018297195, 48.65285910665989, 45.35580262541771, 38.1816241890192, 38.26532989740372, 37.84617438912392, 38.95898647606373, 40.1709770411253, 37.81886525452137, 39.127382040023804, 41.499872133135796, 42.39662401378155, 42.952431589365005, 44.33038204908371, 43.39652135968208, 46.998264491558075, 48.49150076508522, 50.63425898551941, 53.63928213715553, 55.91583497822285, 51.90537437796593, 42.92796470224857, 33.035184144973755, 23.55499304831028, 13.700187653303146, 8.196548726409674, 6.921909973025322, 4.584167115390301, 5.98871567286551, 6.3531422428786755, 4.204181805253029, 1.2073631258681417, 0.15160681796260178, 0.2570166054647416, 3.0373591789975762, 20.784544609487057, 48.76444771885872, 39.903558790683746, 41.9620793312788, 48.375705778598785, 60.25532752275467, 47.99915738403797, 16.604514308273792, 1.0688634077087045, 0.10472445865161717, 0.04373319665319286, 0.034604353495524265, 0.03632591346104164, 0.03467730290140025, 0.06886791277793236, 0.06890064891194925, 0.02710652828682214, 0.03986648480349686, 0.012276012221263954, 0.0391349275741959, 0.027063364977948368, 0.06762330143828876, 0.028059421783837024, 0.014845399837213336, 0.0836543740297202, 0.013820750864397269, 0.03731119242729619, 0.07474167767213657, 0.040626815098221414, 0.06213501917955, 0.03603336255764589, 0.1938801581854932, 0.24221211002441123, 0.08481538243358955, 0.11802453169366345, 0.13029647787334397, 0.19019785890122876, 0.2204011764843017, 0.08884366354322992, 0.14605012082029134, 0.24872813693946227, 0.16898301837500185, 0.11326305320835672, 0.09566572989569977, 0.07960856339195743, 0.2573779720114544, 0.06834347412222996, 0.2203540352638811, 0.1720761859905906, 0.0806397404812742, 0.11958749470068142, 0.08960531486081891, 0.24696437845705077, 0.11325419196509756, 0.09175896804663353, 0.23160356911830604, 5.8665175549685955, 36.01974539458752, 63.83221238851547, 60.96810467541218, 51.9419664144516, 39.85963694751263, 45.11753261089325, 46.41301989555359, 29.637985937297344, 7.6726684626191854, 0.895106925163418, 0.3115477762185037, 2.0973601564764977, 10.062538348138332, 9.032940845936537, 19.616722874343395, 18.22245229035616, 13.849828373640776, 9.14875103160739, 5.6514072977006435, 14.519760925322771, 28.24097190052271, 51.692707389593124, 56.7597620934248, 52.484128922224045, 48.99023920297623, 45.181156396865845, 45.53420305252075, 45.482856407761574, 44.31096889078617, 41.57994903624058, 43.2076220959425, 42.55335420370102, 38.801868706941605, 40.40404513478279, 40.22930771112442, 40.03449596464634, 43.573523461818695, 51.73904210329056, 51.687452271580696, 50.691529512405396, 50.86438983678818, 54.43862624466419, 51.42921432852745, 51.40876762568951, 46.15782178938389, 49.540506675839424, 48.25479246675968, 54.46782387793064, 50.34910708665848, 55.29055953025818, 54.115677773952484, 51.09797850251198, 43.30341875553131, 40.32750964164734, 38.65194395184517, 44.404956847429276, 45.01383617520332, 53.61163102090359, 54.112470746040344, 54.088710620999336, 48.015496507287025, 50.446047484874725, 41.27534598112106, 48.39708723127842, 57.105615735054016, 52.63473384082317, 49.63610954582691, 49.23247620463371, 48.85097287595272, 45.995285511016846, 47.67012543976307, 45.24452939629555, 44.407571107149124, 40.50947807729244, 39.492994621396065, 37.71364130079746, 40.332772359251976, 41.855647042393684, 44.89784359931946, 52.897968515753746, 50.02324417233467, 53.631215170025826, 49.16766308248043, 54.20635610818863, 55.12196637690067, 51.611243560910225, 47.847233936190605, 39.26639758050442, 41.16623103618622, 39.37955550849438, 41.73973426222801, 42.48248800635338, 40.120356157422066, 40.96046067774296, 43.27139027416706, 43.82942073047161, 43.56086254119873, 47.164725959300995, 45.57002753019333, 48.716372698545456, 51.29463694989681, 54.117847457528114, 55.91355510056019, 59.280934408307076, 52.21591651439667, 43.256498873233795, 32.79696732759476, 21.452634260058403, 12.375900764018297, 8.610036838799715, 9.387559667229652, 12.517670206725597, 11.947479452937841, 13.581024147570133, 8.973216600716114, 2.081358740106225, 0.6499333935789764, 0.5333818320650607, 3.842546660453081, 23.30501776188612, 58.381268084049225, 54.07925292849541, 54.51927691698074, 54.47642281651497, 68.82984101772308, 52.408873960375786, 19.15179882198572, 1.2704525655135512, 0.2971727913245559, 0.08424422558164224, 0.1349819530150853, 0.20995044586015865, 0.12109052928281017, 0.10711951763369143, 0.19058874808251858, 0.06816421577241272, 0.10402980100479908, 0.12060911292792298, 0.16071267309598625, 0.11658827555947937, 0.13223327550804242, 0.28910953493323177, 0.060019783268217, 0.13483048067428172, 0.09542367843096144, 0.10834281449206173, 0.24097655288642272, 0.1154741263599135, 0.17494477971922606, 0.08724981977138668], [0.03578445364837535, 0.042875110666500404, 0.02356581222556997, 0.06706805623252876, 0.02534438026486896, 0.011011994647560641, 0.09101669420488179, 0.04081167295225896, 0.04180929383437615, 0.043000207078875974, 0.016056179447332397, 0.07063855839078315, 0.06693021714454517, 0.04618551232852042, 0.004757835467898985, 0.019058600955759175, 0.015589060567435808, 0.032573455246165395, 0.04828162680496462, 0.05232943010923918, 0.03646485092758667, 0.09331816094345413, 0.04629340204701293, 0.03892673659720458, 0.01489269690864603, 1.539479554630816, 18.330923169851303, 43.184929713606834, 49.9724180996418, 37.905196622014046, 31.86357021331787, 34.81239818036556, 38.77661906182766, 30.668175257742405, 7.9230227787047625, 1.1544189043343067, 0.1419687835732475, 0.14047421689610928, 0.6730894697830081, 6.164801549166441, 4.92611694149673, 6.909858919680119, 3.3681599283590913, 5.6220149248838425, 2.3876555543392897, 6.373390406370163, 18.033630922436714, 42.32905983924866, 49.09324027597904, 49.33491490781307, 46.849228888750076, 47.677633836865425, 45.110711976885796, 48.11927653849125, 43.419004753232, 46.17477647960186, 43.86709190905094, 43.300291523337364, 40.4910072684288, 39.1883497685194, 36.943608820438385, 39.20818850398064, 42.46153973042965, 46.959529370069504, 48.12656454741955, 50.58207258582115, 48.6144507676363, 51.51009298861027, 44.996326714754105, 46.24144770205021, 40.54363824427128, 41.126853749156, 43.26016567647457, 49.53977331519127, 48.42518292367458, 49.48987819254398, 49.53918054699898, 47.29803420603275, 42.58852891623974, 37.03438974916935, 33.38403582572937, 39.21957269310951, 41.789002418518066, 49.8178081959486, 47.962021976709366, 52.184313610196114, 47.147900462150574, 49.37439478933811, 39.090809002518654, 41.23099096119404, 51.36888116598129, 45.461547151207924, 42.38610997796059, 39.43566329777241, 39.62444856762886, 38.99878554046154, 38.34020867943764, 36.74219682812691, 35.52077516913414, 35.372324734926224, 35.1737055927515, 36.73581697046757, 35.83780735731125, 38.147171437740326, 44.076817855238914, 47.49272435903549, 49.72394563257694, 51.937193870544434, 47.37268880009651, 51.741234585642815, 50.589235201478004, 46.16688810288906, 41.42296805977821, 36.43610805273056, 36.59102573990822, 36.90976023674011, 37.402551993727684, 36.59740559756756, 36.22816801071167, 34.94525425136089, 36.965389251708984, 35.65611630678177, 38.14942091703415, 38.28065827488899, 39.96670000255108, 40.423986464738846, 44.27519001066685, 47.50400975346565, 50.15477031469345, 54.203187078237534, 50.392048582434654, 37.670449018478394, 22.752487510442734, 17.013408467173576, 8.44879724085331, 4.711865438148379, 6.9205396715551615, 2.6752642588689923, 3.5045847203582525, 5.762941762804985, 2.790837432257831, 0.6071961368434131, 0.31776854710187763, 0.13243928086012602, 3.9561676885932684, 21.996877156198025, 48.87974873185158, 50.1434051245451, 36.04201599955559, 46.24919168651104, 58.52114237844944, 35.564659014344215, 8.1669863127172, 0.47573111776728183, 0.06505771918455139, 0.06737670802976936, 0.04768009755935054, 0.0050912119149870705, 0.04340751998824999, 0.0295115023618564, 0.04985949955880642, 0.0259784730951651, 0.05162274595932104, 0.1279631507350132, 0.023510204955528025, 0.019199464295525104, 0.05643514319672249, 0.03126875963062048, 0.019386509629839566, 0.0503524043597281, 0.04242865317792166, 0.03347447818669025, 0.07008887187112123, 0.016765116015449166, 0.028640003911277745, 0.07260703088832088, 0.05164695110579487, 0.08201918521081097, 0.006185247057146626, 0.0529720928898314, 0.03016419712366769, 0.00802304126409581, 0.06837529741460457, 0.02612929791212082, 0.0325441292807227, 0.021700273755413946, 0.032892103772610426, 0.03745069021533709, 0.018953056423924863, 0.031396973063237965, 0.02236875214293832, 0.03024565154191805, 0.10642791763530113, 0.049313364215777256, 0.0544975143566262, 0.04619741266651545, 0.05022459910833277, 0.04560025467071682, 0.07662179748876952, 0.014398094444914022, 0.05867624364327639, 2.2487827436998487, 21.270498633384705, 48.99211250245571, 56.79947376251221, 43.19955512881279, 35.97596414387226, 38.85660856962204, 43.477643206715584, 33.96038129925728, 8.88510787859559, 0.8627241721842438, 0.19594761834014207, 0.35930379177443683, 2.2024413803592324, 6.074503669515252, 5.342035023495555, 8.408569749444723, 7.496152734383941, 6.031270539388061, 4.4330373499542475, 10.44292263686657, 24.263444133102894, 44.23093378543854, 51.19620703160763, 50.49541063606739, 49.80664059519768, 50.06457455456257, 47.451591566205025, 48.969416320323944, 45.53777106106281, 46.20656557381153, 45.57850867509842, 43.26843403279781, 40.986105501651764, 39.076445773243904, 39.325305819511414, 40.10929875075817, 43.29894259572029, 48.33431079983711, 49.40849035978317, 49.89102266728878, 48.91118824481964, 52.953510135412216, 48.13358657062054, 47.84373812377453, 42.27509133517742, 43.24650160968304, 44.95735600590706, 50.60344263911247, 51.17755003273487, 51.61100797355175, 52.93324962258339, 49.6979284286499, 44.32620607316494, 37.49448046088219, 36.08386315405369, 41.135023310780525, 44.42065380513668, 51.245459988713264, 48.80278006196022, 52.48918645083904, 47.97844089567661, 50.00244028866291, 40.307233929634094, 44.53615240752697, 53.489946350455284, 48.07321161031723, 45.036638751626015, 40.79333044588566, 42.46911272406578, 41.45475335419178, 40.62893986701965, 38.642653450369835, 37.11690612137318, 37.02978819608688, 37.21499785780907, 37.20883458852768, 37.198419347405434, 39.786232486367226, 45.73619641363621, 49.11300301551819, 52.43562072515488, 51.954319551587105, 49.52234745025635, 51.98888249695301, 52.84509815275669, 48.52979511022568, 43.98369625210762, 38.531931191682816, 38.71571213006973, 37.46429868042469, 38.85788530111313, 38.22281777858734, 38.421482518315315, 36.82945914566517, 37.59753093123436, 38.381212279200554, 38.900595009326935, 39.46959547698498, 42.569009363651276, 42.45330937206745, 46.84447154402733, 51.08679570257664, 51.97811007499695, 56.29562459886074, 52.52954788506031, 39.756415486335754, 25.938943326473236, 19.136514142155647, 8.406344968825579, 6.663197530433536, 7.6634501572698355, 6.382916020229459, 6.942901946604252, 6.951757846400142, 2.6317214453592896, 1.7662773909978569, 0.22056844172766432, 0.1230414277233649, 5.118298754096031, 23.627635650336742, 50.380379408597946, 50.654553696513176, 41.44477128982544, 50.709529146552086, 64.1902519762516, 40.58545120060444, 11.49561719968915, 0.6062743300572038, 0.005486190793817514, 0.07554993586381897, 0.04733686910185497, 0.011691120998875704, 0.03557767275196966, 0.06786098165321164, 0.05280192584905308, 0.01340377611995791, 0.04862789064645767, 0.07343491888605058, 0.04792914376594126, 0.009342264420411084, 0.05291504399792757, 0.008265867345471634, 0.01103193151720916, 0.07399246474960819, 0.01828645010391483, 0.09258463702281006, 0.05402128190326039, 0.04951533228449989, 0.02260985736938892, 0.05278651515254751, 0.09928339553880505, 0.1360647613182664, 0.18338550726184621, 0.16303430398693308, 0.14708621834870428, 0.08135348616633564, 0.15382444427814335, 0.07738652871921659, 0.0963723509630654, 0.17089439003029838, 0.12791405024472624, 0.13996268418850377, 0.08820218077744357, 0.14233096648240462, 0.07610529981320724, 0.13519828906282783, 0.25861400412395597, 0.18722401378909126, 0.14232814632123336, 0.2016646639094688, 0.12157857301644981, 0.1734939106972888, 0.19063177780481055, 0.07859286750317551, 0.16630341997370124, 3.1160417944192886, 24.944380894303322, 55.08861556649208, 64.25870910286903, 50.52559241652489, 41.98240824043751, 46.504317596554756, 49.26953561604023, 38.42041477560997, 10.09022081270814, 1.7191370017826557, 0.4920749017037451, 1.1844149697571993, 4.587503336369991, 14.76416951045394, 12.826731372624636, 12.82637419179082, 8.446140233427286, 11.458253804594278, 5.8371432311832905, 10.011053960770369, 23.51831741631031, 47.24844306707382, 53.67949917912483, 54.40239518880844, 52.499126717448235, 52.89167605340481, 48.653326481580734, 52.29479268193245, 47.3853725194931, 49.91901956498623, 47.33186759054661, 45.96405118703842, 44.37610499560833, 42.48560383915901, 42.00044207274914, 43.11990760266781, 45.96718601882458, 51.69679217040539, 52.064973413944244, 51.29746399819851, 49.795336201786995, 55.384505689144135, 49.9468644708395, 49.314012229442596, 43.42647135257721, 45.71950390934944, 47.00929909944534, 52.15217873454094, 53.954148441553116, 52.40375183522701, 54.499050602316856, 53.4354230761528, 47.48402662575245, 40.90346373617649, 37.501966059207916, 42.518605068325996, 45.23611664772034, 53.82201433181763, 51.23996928334236, 53.16303089261055, 50.544971376657486, 49.029536694288254, 43.39338652789593, 48.66061829030514, 53.57928715646267, 52.196936532855034, 44.89103056490421, 43.60890716314316, 44.39021363854408, 42.4181042611599, 42.35266037285328, 40.22377900779247, 39.773069992661476, 39.82029765844345, 38.695022240281105, 39.92131523787975, 39.67082127928734, 41.86512753367424, 47.829207703471184, 52.468994334340096, 54.885223880410194, 52.86613002419472, 49.70880724489689, 53.5703956335783, 55.09798586368561, 52.2780317813158, 44.8546627163887, 39.05909590423107, 40.45520938932896, 38.86785976588726, 41.71004645526409, 40.19398480653763, 40.699274092912674, 38.73070612549782, 39.729421734809875, 40.79982429742813, 41.465784162282944, 41.03143706917763, 45.206934213638306, 43.81468512117863, 49.89020571112633, 52.849304527044296, 55.341210812330246, 57.35585130751133, 54.667723551392555, 40.32732345163822, 25.92718865722418, 19.411541484296322, 11.42372315749526, 8.840392827987671, 10.16235614195466, 7.996759247034788, 11.490079946815968, 13.39981472119689, 8.708542753010988, 4.020393742248416, 0.8008851623162627, 0.3707405843306333, 5.438519921153784, 27.922615483403206, 59.781192764639854, 62.0979056507349, 49.17512208223343, 58.90224672853947, 73.51030066609383, 48.957374766469, 13.145068790763617, 0.8335827046539634, 0.15606623492203653, 0.2145187061978504, 0.19957268319558352, 0.1265544060152024, 0.10852835141122341, 0.18243159516714513, 0.17115719936555251, 0.126501951017417, 0.14600265305489302, 0.15643575025023893, 0.1138415647437796, 0.0749115775397513, 0.13256742007797584, 0.13006653083721176, 0.16046911507146433, 0.14045866148080677, 0.1870300163864158, 0.1451335387537256, 0.14458065357757732, 0.16494861454702914, 0.10217497358098626, 0.21724189835367724], [0.04577291532768868, 0.021302835120877717, 0.07886205188697204, 0.07809270449797623, 0.036141059317742474, 0.0035812127407552907, 0.03558705349860247, 0.04750934422190767, 0.0076036647442379035, 0.06827713354141451, 0.041470685246167704, 0.02218670146248769, 0.02642627943714615, 0.03231469061574899, 0.03901866642991081, 0.04206724581308663, 0.02816400894516846, 0.030691396568727214, 0.03316888403787743, 0.043538512763916515, 0.054310099803842604, 0.062253881551441737, 0.04109564462851267, 0.03210636605217587, 0.029903016802563798, 0.4428287723567337, 10.556945018470287, 37.82645344734192, 51.023361906409264, 44.43733491003513, 37.46655575931072, 30.056259892880917, 28.970281966030598, 30.692577548325062, 15.049203615635633, 1.7610663268715143, 0.2796084713190794, 0.6447937537450343, 1.2953164125792682, 4.5562362391501665, 4.038954796269536, 9.293616358190775, 8.1949632614851, 5.047086300328374, 3.5303644370287657, 5.624486692249775, 14.867588561028242, 33.8334035128355, 46.096952855587006, 48.40616874396801, 48.985614851117134, 48.2514638453722, 49.08535569906235, 49.585047885775566, 47.216802164912224, 47.35287666320801, 45.51182985305786, 47.44722180068493, 44.86111477017403, 45.72257034480572, 42.9715521633625, 45.55126033723354, 43.773746117949486, 45.47067046165466, 49.23482067883015, 48.044352158904076, 50.825320333242416, 48.25624018907547, 45.784981995821, 42.84974589943886, 36.09058499336243, 39.04126726090908, 39.36999522149563, 45.93898393213749, 47.81261019408703, 48.05779203772545, 50.07810942828655, 47.386265471577644, 43.53329502046108, 38.1239964812994, 35.669559985399246, 37.97211863100529, 40.446545854210854, 46.91545553505421, 47.285620272159576, 50.77159881591797, 44.96331788599491, 49.74953345954418, 38.375554382801056, 41.28152824938297, 52.10397832095623, 46.237773299217224, 44.33192856609821, 36.4150457829237, 37.372761592268944, 37.26732864975929, 36.52913086116314, 35.25714911520481, 36.84393636882305, 34.93823602795601, 35.068713426589966, 34.87715430557728, 37.05382950603962, 38.39061677455902, 44.41823333501816, 49.18942831456661, 48.44410590827465, 51.735154911875725, 46.18153631687164, 49.24521692097187, 51.19970664381981, 47.78685137629509, 43.82714845240116, 39.84857574105263, 39.66752305626869, 42.3047449439764, 42.472752928733826, 41.78893782198429, 40.72616524994373, 38.99685524404049, 37.363596484065056, 37.46807187795639, 37.053259536623955, 39.3251196295023, 38.44555422663689, 41.55357465147972, 42.25119821727276, 46.32106103003025, 48.722030594944954, 49.812237694859505, 45.934967547655106, 32.55849972367287, 18.624185733497143, 8.962291236966848, 2.5907717552036047, 3.438496054150164, 5.41614149697125, 4.096732120960951, 5.003583859652281, 4.404011182487011, 1.1628404399380088, 0.9130639303475618, 0.05266341511742212, 0.36459993571043015, 5.023060189560056, 24.939921833574772, 42.02856056392193, 41.0086040943861, 31.931480169296265, 36.50318585336208, 51.830947771668434, 34.787935093045235, 8.84304128587246, 0.2798805426573381, 0.05043444507464301, 0.05229570691881236, 0.049149902479257435, 0.09333433976280503, 0.04070525639690459, 0.05316777867847122, 0.05563695223827381, 0.07021436904324219, 0.019356281954969745, 0.08934231256716885, 0.04723768106487114, 0.06672862757113762, 0.06708930392051116, 0.08086075948085636, 0.017283704692090396, 0.0535838637733832, 0.05544310697587207, 0.05546884836803656, 0.07751231532893144, 0.037730613476014696, 0.033601567265577614, 0.057732799541554414, 0.04930435825372115, 0.022679891990264878, 0.023740033248031978, 0.030336878189700656, 0.01880323536170181, 0.01833477319451049, 0.03862094948999584, 0.09171295489068143, 0.03689872901304625, 0.031338135595433414, 0.0792909316078294, 0.03617197347921319, 0.06792424974264577, 0.01586204660270596, 0.04406510364788119, 0.06699820529320277, 0.03978901571827009, 0.07400935603072867, 0.12644079804886132, 0.060955572116654366, 0.031330231722677127, 0.034758356559905224, 0.023471271888411138, 0.08762021083384752, 0.06358189915772527, 0.972398518351838, 14.078864883631468, 43.56180489063263, 55.308794751763344, 49.10036489367485, 41.916060000658035, 38.45913469791412, 38.03039610385895, 36.45913481712341, 15.06323816254735, 1.874861908145249, 0.3537922468967736, 0.3262305149110034, 0.6588107859715819, 4.269892629235983, 4.910504529252648, 7.52498653717339, 7.718086950480938, 7.248020824044943, 4.932234613224864, 6.332847056910396, 18.789708651602268, 40.27015171945095, 50.10631911456585, 49.93874050676823, 50.182155445218086, 51.735360100865364, 51.482084691524506, 52.54273317754269, 49.449258372187614, 48.733616173267365, 48.268669322133064, 48.29970225691795, 46.578200832009315, 46.17733754217625, 45.16888305544853, 46.514444053173065, 46.46071493625641, 47.910690531134605, 50.61853922903538, 49.3710395693779, 51.957750767469406, 51.54632404446602, 48.63015912473202, 45.89651741087437, 38.411964029073715, 41.58391982316971, 43.06435078382492, 49.982445761561394, 49.75204512476921, 50.78528568148613, 51.79701179265976, 48.56017827987671, 45.16313016414642, 39.568200185894966, 35.93203090131283, 41.13690420985222, 41.80180773139, 48.32494430243969, 50.18886588513851, 51.07125073671341, 48.50416548550129, 49.4675125926733, 40.10534316301346, 43.34115073084831, 54.46459025144577, 48.367429822683334, 46.322368159890175, 38.74887675046921, 38.33416700363159, 38.38289938867092, 38.27895596623421, 37.269954308867455, 37.898714169859886, 37.27963238954544, 38.06852325797081, 36.05653502047062, 38.25610779225826, 40.74777849018574, 47.566979974508286, 50.554489865899086, 49.4651073217392, 53.7431837618351, 49.01314437389374, 49.63793724775314, 54.49268214404583, 48.90556834638119, 44.95549030601978, 42.39728897809982, 41.04489974677563, 42.263045981526375, 44.31827589869499, 43.81873570382595, 41.641927510499954, 40.56199125945568, 38.902171924710274, 38.974668234586716, 39.24178630113602, 41.05297051370144, 40.46635799109936, 44.015333354473114, 44.00418095290661, 49.123410657048225, 51.715775951743126, 51.97079546749592, 48.71054761111736, 33.54771204292774, 21.55623570084572, 13.318366091698408, 6.147015178576112, 4.989068163558841, 7.602007454261184, 8.178038969635963, 5.648663369938731, 7.642670972272754, 2.704723603092134, 1.3352580880746245, 0.1137769830529578, 0.2976827952079475, 5.557608380913734, 28.601013980805874, 49.92949180305004, 48.89608405530453, 36.514927223324776, 42.45053932070732, 59.01429891586304, 40.69008618593216, 9.88166805356741, 0.27814350149128586, 0.0382461983099347, 0.055228266355698, 0.034047802109853365, 0.0071227108401217265, 0.014078488547966117, 0.036698137628263794, 0.05450220101920422, 0.04545206262264401, 0.05848692177096382, 0.09620090742828324, 0.05304823353071697, 0.01697449442872312, 0.039424480200977996, 0.058927345598931424, 0.014814979203947587, 0.027262269832135644, 0.05834209165186621, 0.0702525228552986, 0.03257070558902342, 0.05140677356394008, 0.0512994293239899, 0.10216380425845273, 0.16966917843092233, 0.13568892289185897, 0.17505212395917624, 0.16177582932868972, 0.11981941584963351, 0.08643926092190668, 0.15396520000649616, 0.09186010051053017, 0.08081007079454139, 0.1519179856404662, 0.10512037959415466, 0.10228952407487668, 0.15800690656760707, 0.12309558966080658, 0.1706457557156682, 0.1970561791677028, 0.29858842317480594, 0.2059328294126317, 0.36701271717902273, 0.13325625186553225, 0.12529683677712455, 0.11191926867468283, 0.10474878625245765, 0.14580018032575026, 0.13415454741334543, 1.2090644845739007, 15.404876880347729, 48.79371374845505, 64.8869825899601, 56.45880684256554, 49.47812542319298, 42.530034855008125, 38.25664736330509, 40.22771559655666, 20.824432969093323, 2.320864638313651, 0.7059027277864516, 1.009796883445233, 3.7220489513128996, 11.058859135955572, 10.274761710315943, 20.512374714016914, 18.240121342241764, 11.125123780220747, 8.340444155037403, 10.04652600735426, 17.848628349602222, 40.64054064452648, 51.149359345436096, 52.47402146458626, 53.336537182331085, 53.66589590907097, 54.00713659822941, 54.908471032977104, 52.496554255485535, 51.133536994457245, 49.63820703327656, 51.218945011496544, 49.15969870984554, 48.967539221048355, 47.196017280220985, 49.68587927520275, 49.52490471303463, 50.10605312883854, 52.69788645207882, 50.43850488960743, 54.84789468348026, 53.14664997160435, 49.65088315308094, 47.499886974692345, 40.6627656519413, 44.100631177425385, 44.559068977832794, 50.95930874347687, 51.49902418255806, 51.624501049518585, 53.36730033159256, 51.85172125697136, 48.658061027526855, 41.927489787340164, 38.07420015335083, 42.703544944524765, 43.58442887663841, 51.24273553490639, 51.79819352924824, 54.64695006608963, 49.20850329101086, 50.568150132894516, 41.02632634341717, 47.88081273436546, 56.203479543328285, 49.779901430010796, 48.60132247209549, 40.6100282818079, 40.77802486717701, 41.220750510692596, 38.75844083726406, 38.54937605559826, 39.33817572891712, 39.38071824610233, 38.7794841080904, 37.1963332593441, 40.4163982719183, 43.55214200913906, 48.68498258292675, 53.994494676589966, 52.447848469018936, 55.370811223983765, 50.42928658425808, 51.55379444360733, 54.783085361123085, 51.981940269470215, 47.851846888661385, 45.61843313276768, 43.645024225115776, 45.06354130804539, 47.44302302598953, 46.96443870663643, 44.83137756586075, 42.71632365882397, 40.6998136639595, 42.47734688222408, 39.61052231490612, 44.40831586718559, 42.80464231967926, 46.267400309443474, 47.757448554039, 53.035220950841904, 54.01029422879219, 52.7151071280241, 51.116327717900276, 36.13885000348091, 20.337743684649467, 12.125609144568443, 5.821282407268882, 6.868264926597476, 11.523372810333967, 11.44749753177166, 13.687540031969547, 13.892832566052675, 6.3171762228012085, 2.6218892354518175, 0.1618871366372332, 0.8540421724319458, 7.089799214154482, 32.16026969254017, 55.082866474986076, 52.08895392715931, 42.86287419497967, 48.89426775276661, 64.25193786621094, 46.141775250434875, 12.091598119586706, 0.43482720328029245, 0.2016164391534403, 0.16195232688914984, 0.11867388122482225, 0.31518234056420624, 0.15015182259958237, 0.24300102784764022, 0.16369751683669165, 0.18588362087029964, 0.14931736659491435, 0.1997631331323646, 0.0835564624867402, 0.18011891457717866, 0.1254714047536254, 0.15223117196001112, 0.15925326937576756, 0.1651162508642301, 0.11223048830288462, 0.1657479818095453, 0.14866929355775937, 0.10281545444740914, 0.11143744413857348, 0.1846841914812103], [0.1058548608853016, 0.07260804020916112, 0.02360243164730491, 0.03623030999733601, 0.058961165268556215, 0.020838339733018074, 0.09222233537002467, 0.03812020760960877, 0.04537823377177119, 0.03396104875719175, 0.030679247611260507, 0.024573572700319346, 0.06726114079356194, 0.06079274491639808, 0.02279076143167913, 0.028491346165537834, 0.026887507519859355, 0.08880940600647591, 0.013258185299491743, 0.039378760193358175, 0.019073050571023487, 0.05522461127839051, 0.008172550624294672, 0.02410494354990078, 0.03761127241887152, 0.0567428190697683, 6.80519781075418, 29.59862194955349, 50.30754491686821, 45.59963934123516, 30.713940002024174, 24.233433343470097, 35.21540455520153, 36.696386486291885, 17.42864638566971, 3.5021901363506913, 0.4489565669791773, 0.19320784660521895, 0.8163409517146647, 3.7962708435952663, 2.583380676805973, 4.814743017777801, 5.69573144428432, 5.217081578448415, 3.2482267264276743, 3.284848448820412, 12.853688076138496, 29.29310504347086, 46.0602468252182, 51.661982238292694, 52.671660259366035, 50.64688950777054, 49.812264293432236, 52.15176835656166, 50.71240559220314, 51.16057254374027, 49.47509318590164, 47.39704169332981, 47.653144150972366, 45.654686987400055, 46.59218408167362, 47.43597820401192, 45.97138099372387, 47.111354023218155, 49.86069269478321, 46.3685242831707, 49.79409746825695, 46.36078029870987, 45.76481647789478, 40.31719699501991, 37.914954498410225, 37.381862103939056, 37.839064970612526, 41.20933212339878, 44.41600285470486, 48.0124718695879, 46.928222849965096, 47.378950864076614, 42.54128225147724, 38.7853129953146, 36.05383336544037, 38.906830474734306, 41.15516982972622, 44.445208087563515, 45.99923349916935, 50.22174932062626, 46.217201203107834, 52.33700081706047, 38.813781067728996, 38.99476915597916, 54.48089137673378, 46.14800311625004, 45.11087916791439, 38.562568947672844, 35.976062938570976, 34.80785362422466, 37.244161292910576, 35.101015493273735, 36.8380580842495, 34.929074719548225, 36.38850040733814, 35.54084189236164, 36.06369383633137, 37.606141269207, 42.948289811611176, 48.13926726579666, 49.73448246717453, 47.41453595459461, 49.520432353019714, 48.778240978717804, 49.51302655041218, 48.28457526862621, 45.325031876564026, 44.7413793951273, 44.96714808046818, 45.97409784793854, 46.25720925629139, 46.765868961811066, 47.22739599645138, 47.09540627896786, 44.399390146136284, 40.157700553536415, 40.4350970685482, 40.73173575103283, 41.439329981803894, 42.74835214018822, 46.48338072001934, 47.84737452864647, 47.77927078306675, 50.942319855093956, 44.410196766257286, 25.75222134590149, 14.198960289359093, 8.492378052324057, 2.9224998923018575, 3.490674141794443, 6.007498539984226, 8.72473368421197, 3.3434750279411674, 5.213153539225459, 1.4792835409753025, 1.0833403933793306, 0.2436017370200716, 0.20957460743375123, 7.344784531742334, 26.02627594023943, 41.89954988658428, 28.985731936991215, 30.31271953135729, 42.792083993554115, 48.45694541931152, 33.78814034163952, 5.824279021471739, 0.09290865127695724, 0.0551556954451371, 0.029236929985927418, 0.03190440540493, 0.013334080103959423, 0.10138535071746446, 0.025103326988755725, 0.023324976027652156, 0.020506816799752414, 0.036058777404832654, 0.02513539518986363, 0.0787024678720627, 0.04749353647639509, 0.030925171231501736, 0.013352426922210725, 0.017958710268430877, 0.04830009143915959, 0.04077508136106189, 0.050898083281936124, 0.021791528233734425, 0.05682339033228345, 0.06287131502176635, 0.059542849485296756, 0.06681942191789858, 0.02075798183795996, 0.0568049665162107, 0.05415848645498045, 0.043415561158326454, 0.014657760784757556, 0.0729828915791586, 0.023122074708226137, 0.018206415043096058, 0.06846535703516565, 0.035752181356656365, 0.02345426742976997, 0.022273417707765475, 0.02818170360114891, 0.0544007086136844, 0.05182413515285589, 0.04857454136072192, 0.014250367166823708, 0.07850752052036114, 0.012825625453842804, 0.0821548052772414, 0.04871390927291941, 0.017468256410211325, 0.0195922626517131, 0.10307016695151106, 0.10973408163408749, 9.54181618988514, 34.6808872371912, 56.18683643639088, 52.54247099161148, 36.935435459017754, 28.065998889505863, 34.75427269935608, 40.57355023920536, 20.653928518295288, 3.4999655932188034, 0.4105327615980059, 0.14919094915967435, 1.2665201327763498, 1.8004677188582718, 4.177894815802574, 7.830772278830409, 7.204453786835074, 8.498870003968477, 8.22707248851657, 4.657430034130812, 15.701389219611883, 33.015649393200874, 50.373535975813866, 55.56829422712326, 54.98035557568073, 53.235018029809, 51.162666231393814, 53.34813416004181, 53.02651181817055, 54.77816842496395, 50.82970529794693, 49.43066596984863, 49.21414218842983, 48.22777211666107, 48.09060327708721, 50.37442892789841, 46.452959552407265, 48.704828917980194, 52.29694716632366, 47.237837836146355, 51.64442338049412, 49.60865221917629, 47.65401430428028, 43.295617774128914, 38.824181109666824, 39.15236569941044, 39.202124029397964, 43.13388705253601, 46.992055624723434, 49.90606226027012, 47.630546763539314, 49.36321958899498, 44.33246813714504, 41.59693792462349, 36.534914150834084, 39.632196351885796, 43.64241376519203, 45.92872068285942, 47.3881159722805, 50.28525531291962, 48.75441625714302, 51.675779297947884, 39.980090484023094, 42.20193386077881, 54.40275616943836, 48.68002384901047, 46.528902277350426, 40.93999117612839, 37.38177850842476, 36.795652359724045, 38.633169159293175, 37.485577538609505, 37.2514721006155, 36.42625518143177, 38.305296152830124, 37.17434003949165, 37.27215439081192, 39.942350909113884, 44.695740044116974, 51.21767967939377, 50.90092107653618, 50.618881210684776, 50.039051324129105, 49.030327051877975, 51.665139868855476, 50.33298075199127, 47.14810565114021, 46.177413538098335, 46.66655749082565, 47.745995968580246, 48.05596433579922, 48.201671317219734, 48.283393532037735, 47.818651869893074, 44.81421388685703, 41.88692696392536, 41.81802146136761, 43.297916650772095, 42.829660177230835, 44.451409354805946, 47.612163349986076, 49.280346035957336, 49.30207706987858, 54.04768042266369, 47.009462490677834, 28.349359184503555, 16.758957020938396, 9.872027020901442, 5.4179649241268635, 5.50793887116015, 6.599175240844488, 9.296591598540545, 6.376115335151553, 6.167039154097438, 2.876910651102662, 1.2339533865451813, 0.16515056777279824, 0.32675144320819527, 7.191742518916726, 31.78724940866232, 48.194090723991394, 39.025304317474365, 34.34590481221676, 46.06698006391525, 55.52308805286884, 39.48315694928169, 8.07618923485279, 0.1919517171336338, 0.01248553164259647, 0.018656607389857527, 0.017972972491406836, 0.013418005873973016, 0.05840072873979807, 0.04235701366269495, 0.020087262164452113, 0.040405610561720096, 0.01682940826867707, 0.003673107553368027, 0.05880293567315675, 0.06088820366130676, 0.048474670547875576, 0.054851964086992666, 0.011832482505269581, 0.03836622214294039, 0.022070792838349007, 0.053756672859890386, 0.05224377884587739, 0.041440468703513034, 0.037002993340138346, 0.04831510137591977, 0.15669475978938863, 0.12423904627212323, 0.12023428382235579, 0.12813489855034277, 0.16310041450196877, 0.1120130909839645, 0.19288327574031428, 0.18046370154479519, 0.13118432398186997, 0.11136538902064785, 0.11247847694903612, 0.11587625165702775, 0.17130775144323707, 0.1753776744590141, 0.16485385713167489, 0.2049208219978027, 0.18741067877272144, 0.25213823129888624, 0.21614731958834454, 0.2754064608598128, 0.15793272148584947, 0.10205278638750315, 0.06080065621063113, 0.1164757511287462, 0.19174912566086277, 0.2944691473385319, 10.275597665458918, 38.78297232091427, 61.844314858317375, 58.48240725696087, 41.498644798994064, 33.95380385220051, 44.31698776781559, 48.26032117009163, 23.1313518807292, 5.216274121776223, 0.8752971037756652, 0.7706789206713438, 2.7154758386313915, 8.095503598451614, 10.29225692152977, 11.896100509911776, 15.739951450377703, 13.814041893929243, 8.500980790704489, 5.2068734262138605, 16.31729532033205, 31.742636002600193, 51.771256774663925, 56.14540345966816, 55.49746222794056, 52.92261399328709, 51.99604131281376, 56.79354228079319, 55.97406305372715, 57.059463411569595, 54.33279052376747, 51.97443567216396, 52.35098786652088, 51.085773557424545, 50.648078843951225, 51.970818266272545, 51.01084537804127, 50.91108173131943, 51.728132888674736, 46.58371813595295, 52.7077317237854, 50.79017601907253, 50.51453121006489, 44.19322840869427, 41.40245296061039, 41.36578872799873, 41.43037386238575, 44.35669183731079, 49.46337081491947, 52.18805640935898, 50.5528711527586, 51.42375402152538, 47.37188324332237, 44.85799893736839, 38.82589481770992, 42.22639314830303, 46.049060225486755, 47.54022181034088, 49.78806719183922, 53.074529841542244, 48.87787163257599, 52.5743854790926, 43.36328074336052, 45.00485345721245, 57.2292535007, 51.742306128144264, 50.1813080906868, 42.67818510532379, 39.96430993080139, 37.72897727787495, 41.41416013240814, 38.14961090683937, 40.02744734287262, 38.205490708351135, 39.790818840265274, 39.02249626815319, 40.26167817413807, 42.28451482951641, 46.24925248324871, 53.868926614522934, 54.99227173626423, 52.49846175312996, 50.36757789552212, 48.57353836297989, 53.21313880383968, 53.44807259738445, 49.8920714110136, 48.17979969084263, 48.79297278821468, 50.83491861820221, 50.541095584630966, 51.302829310297966, 52.825874984264374, 51.56579799950123, 48.601326271891594, 44.05856743454933, 44.73980247974396, 46.11556425690651, 46.02569527924061, 47.752900198102, 50.98693326115608, 52.920744493603706, 51.51098974049091, 56.13803945481777, 48.64089734852314, 30.212594904005527, 17.602542154490948, 11.885800212621689, 7.170907761901617, 9.116997085511684, 13.299794588238, 17.59296476840973, 11.076018065214157, 14.008478410542011, 5.371408397331834, 1.9155599805526435, 1.13310121698305, 0.5239055561833084, 9.543834831565619, 33.88692744076252, 52.58653722703457, 44.158969447016716, 42.8370051831007, 56.05103552341461, 62.30428397655487, 44.12111587822437, 9.097749218344688, 0.27928836818318814, 0.15901172999292612, 0.2393559695337899, 0.10853054816834629, 0.15331723087001592, 0.21530125639401376, 0.14261706441175193, 0.14330307603813708, 0.16768666449934244, 0.11156852226122282, 0.19506465556332842, 0.11380065756384283, 0.13594906049547717, 0.11838614314910956, 0.17525011411635205, 0.1796278651454486, 0.1387411536416039, 0.15670690132537857, 0.1686801775940694, 0.15099043463123962, 0.11103401266154833, 0.13267145433928818, 0.19206640863558277], [0.07764652531477623, 0.017148990045825485, 0.01799186571588507, 0.02416176979750162, 0.021356342112994753, 0.049440445873187855, 0.013779971704934724, 0.055803831564844586, 0.018068750359816477, 0.034905969732790254, 0.035091016834485345, 0.030774641418247484, 0.031830929074203596, 0.046413429590757005, 0.06391359464032575, 0.07162496913224459, 0.06272834027186036, 0.034197916320408694, 0.07362307558651082, 0.023737712181173265, 0.02348774200072512, 0.0536042468593223, 0.051609891961561516, 0.01753725573507836, 0.07479761334252544, 0.06403555176802911, 2.5823568692430854, 22.586388923227787, 44.67230670154095, 47.30252556502819, 33.0850450694561, 30.117983780801296, 30.16049399971962, 29.20408722013235, 25.110914558172226, 6.789517002180219, 0.8170643972698599, 0.10195452603511512, 1.1953235906548798, 0.9952709160279483, 2.673067501746118, 4.853824870660901, 3.8486370211467147, 6.2297761626541615, 8.405611608177423, 3.619892857968807, 13.463118374347687, 25.182213932275772, 39.22993093729019, 49.87237326800823, 52.547783106565475, 51.176729276776314, 47.88781575858593, 48.53303633630276, 48.49889516830444, 49.180350601673126, 52.52813056111336, 51.08393445611, 51.69536344707012, 48.52580152451992, 48.821725845336914, 52.69867300987244, 51.69210322201252, 50.11619098484516, 46.769683957099915, 49.19235035777092, 50.22913612425327, 48.931969329714775, 44.90118741989136, 40.5668094009161, 35.20701840519905, 36.18299223482609, 37.073789834976196, 39.52977664768696, 42.43570491671562, 47.38149292767048, 44.266089498996735, 45.99374279379845, 40.38131855428219, 39.8052466660738, 36.2595771253109, 37.704115211963654, 37.50436373054981, 44.66449052095413, 45.0163896381855, 50.35329066216946, 44.26232770085335, 56.375720500946045, 39.10313934087753, 35.966757237911224, 53.10200236737728, 48.67356039583683, 49.223371893167496, 40.843054577708244, 38.95224563777447, 36.46372877061367, 36.78864173591137, 37.15773493051529, 38.33167053759098, 35.2977005392313, 35.36324322223663, 36.25780262053013, 37.045017778873444, 36.9374493509531, 41.97963058948517, 47.64077581465244, 45.31248115003109, 49.83541265130043, 51.090694293379784, 49.602462351322174, 49.49956767261028, 48.379376381635666, 46.721244156360626, 47.76268847286701, 46.79804943501949, 49.03796464204788, 51.667495742440224, 50.88397018611431, 50.01442104578018, 48.805014342069626, 47.52096064388752, 48.757927268743515, 46.650856733322144, 46.98599494993687, 47.57528252899647, 49.221715182065964, 46.29326172173023, 48.922477439045906, 49.888378009200096, 50.33467546105385, 37.44146570563316, 21.65060553699732, 10.882395654916763, 5.460674157366157, 3.7775727594271302, 4.411438833922148, 4.52177113853395, 7.69893835298717, 3.503394196741283, 4.3954146187752485, 2.3879422014579177, 1.6835882468149066, 0.31734929303638637, 0.7464760006405413, 8.153173103928566, 28.53434845805168, 40.166147500276566, 31.616100892424583, 36.75758980214596, 41.269319504499435, 45.994160771369934, 28.222556188702583, 3.367605395615101, 0.0239275962303509, 0.01214051275383099, 0.0398978145676665, 0.05478554558067117, 0.0678589333256241, 0.06450646673329175, 0.07463008834747598, 0.06339458850561641, 0.010036272688012104, 0.08310082092066295, 0.03048312952159904, 0.03796242701355368, 0.03412579811993055, 0.025025358809216414, 0.019032438394788187, 0.016151816307683475, 0.07536542310845107, 0.03175637662934605, 0.021448702391353436, 0.11126306912046857, 0.017884013104776386, 0.06943175205378793, 0.044781932956539094, 0.032318267767550424, 0.03130342905933503, 0.07527957146521658, 0.021104416373418644, 0.07047472929116338, 0.040100617552525364, 0.04157108298386447, 0.05905462763621472, 0.011579867496038787, 0.0542030932410853, 0.043901204044232145, 0.02886702503019478, 0.025854504747258034, 0.042142328893532977, 0.0211475165997399, 0.021151947221369483, 0.033440725310356356, 0.010527791528147645, 0.06997865551966242, 0.049409713537897915, 0.019615796154539566, 0.0600542857137043, 0.025671298171801027, 0.01433730976714287, 0.051330135684111156, 0.0610305921145482, 4.086386701092124, 27.916053235530853, 52.31532298028469, 53.130542635917664, 36.23052768409252, 30.213126875460148, 39.24661584198475, 38.51823292672634, 26.88687466084957, 7.52757134847343, 0.7143829821143299, 0.13274550583446398, 1.1149605154059827, 2.813606048002839, 3.1208271626383066, 8.837279845029116, 7.911255760118365, 7.700044568628073, 7.3430499248206615, 4.950157776474953, 14.015154652297497, 27.52867542207241, 42.73938462138176, 51.410439535975456, 54.475655257701874, 52.22819745540619, 48.43040384352207, 49.20362435281277, 51.620496064424515, 50.7199177891016, 52.45309218764305, 52.95654237270355, 51.6017060726881, 50.43742574751377, 49.70476046204567, 54.10106375813484, 52.37815260887146, 51.93032763898373, 49.87224407494068, 49.47658650577068, 52.66310691833496, 51.36788561940193, 45.88629975914955, 42.18942493200302, 36.50099337100983, 37.07999110221863, 39.439295902848244, 42.878597751259804, 43.78399036824703, 50.00937111675739, 47.24382631480694, 47.83028684556484, 40.3267040848732, 40.71174122393131, 38.74205231666565, 39.38716650009155, 39.803578555583954, 46.59769758582115, 46.864732056856155, 52.15979352593422, 47.16534152626991, 56.49439573287964, 40.88507652282715, 37.85715200006962, 55.57761512696743, 49.35832165181637, 51.7822951823473, 42.27242007851601, 39.37659926712513, 38.0507630109787, 38.736732602119446, 38.62222954630852, 39.97882895171642, 37.19651184976101, 37.574785351753235, 38.57380494475365, 38.572148233652115, 37.86546215415001, 44.31280419230461, 48.85800249874592, 48.74038740992546, 51.16958945989609, 51.59708172082901, 49.87027958035469, 49.25006166100502, 51.315562427043915, 49.8222653567791, 50.76936833560467, 49.94085319340229, 51.410884112119675, 52.946742698550224, 52.51443229615688, 52.737183943390846, 50.962591767311096, 50.235234797000885, 50.36780968308449, 47.79067777097225, 48.56028847396374, 50.2006908506155, 51.60123109817505, 50.287998765707016, 51.92905850708485, 51.31107106804848, 50.53206346929073, 42.811960726976395, 23.351979441940784, 13.509874865412712, 8.49137395620346, 5.078753801062703, 5.589658236131072, 7.9503794107586145, 9.931780714541674, 7.551255002617836, 7.509565064683557, 2.967576398514211, 1.3259758986532688, 0.044281291266088374, 0.7974930724594742, 8.672062810510397, 34.1335342079401, 40.179507583379745, 32.24040739238262, 40.91158390045166, 48.6590413749218, 53.17235179245472, 33.95684368908405, 4.264897797256708, 0.03064410135266371, 0.019263190661149565, 0.002086928775497654, 0.05753190387622453, 0.03169494535541162, 0.043633901004795916, 0.006381720450008288, 0.08384132845094427, 0.0389056410494959, 0.07583008176879957, 0.021256382242427208, 0.009893430597003317, 0.05065001671027858, 0.028083554570912383, 0.012246436708664987, 0.02935240074293688, 0.059302857480361126, 0.02738782266533235, 0.04495344328461215, 0.05054385619587265, 0.0628879465512, 0.04572157355141826, 0.001988711096601037, 0.23262825241545215, 0.08400555831030942, 0.3067705419380218, 0.11667469865642488, 0.14375865081092343, 0.17405650316504762, 0.12634607031941414, 0.18830872199032456, 0.1362067786976695, 0.16070581565145403, 0.08829438520479016, 0.11901370322448201, 0.11817325808806345, 0.1330570297432132, 0.16240635799476877, 0.09867691245744936, 0.12537250615423545, 0.13284572545671836, 0.28211277443915606, 0.22775691380957142, 0.09710463549708948, 0.1305984874488786, 0.17235118139069527, 0.10603141039609909, 0.20456853933865204, 0.16072165308287367, 4.6191969607025385, 31.066165901720524, 59.34041641652584, 59.905335903167725, 44.00187447667122, 40.360058695077896, 40.643527284264565, 40.190063416957855, 34.04696345329285, 8.601343855261803, 1.3990675890818238, 0.34151768835727125, 2.1670130314305425, 3.635789779946208, 11.32949011400342, 15.793941803276539, 12.760833408683538, 15.41880028322339, 16.121847108006477, 9.587630331516266, 16.51102602481842, 28.740430399775505, 43.58509764075279, 50.82525573670864, 53.047167509794235, 53.22222791612148, 51.57488711178303, 49.68145631253719, 50.844771489501, 50.83387367427349, 54.062400832772255, 54.068609699606895, 53.690993562340736, 52.189572528004646, 52.77455873787403, 58.24595354497433, 54.04584512114525, 53.43663901090622, 48.82735714316368, 50.849148854613304, 54.414702728390694, 53.341074138879776, 48.093384727835655, 45.51298879086971, 38.41880366206169, 39.20755013823509, 41.79540507495403, 44.70235548913479, 46.20804749429226, 51.75718232989311, 48.76159027218819, 48.74902054667473, 42.87453956902027, 42.91534177958965, 41.592465564608574, 40.62511347234249, 42.13528163731098, 47.199547290802, 50.265386179089546, 54.029574394226074, 49.672059416770935, 58.63605961203575, 43.193205669522285, 41.783694103360176, 57.821995094418526, 52.68428698182106, 54.33208376169205, 45.93524873256683, 42.28492520749569, 40.373631566762924, 40.01531459391117, 40.68213701248169, 41.66422851383686, 38.86504411697388, 38.868824914097786, 40.44046998023987, 40.191393345594406, 41.129380613565445, 46.47675007581711, 51.97836086153984, 48.76575864851475, 54.259492456912994, 53.655438870191574, 51.77305027842522, 52.10659638047218, 54.77637492120266, 53.43701899051666, 53.70157979428768, 52.47254714369774, 54.067484959959984, 55.911879390478134, 55.62686048448086, 56.420269310474396, 54.643773436546326, 53.1532996147871, 53.32001566886902, 50.71162663400173, 52.58952006697655, 51.54820874333382, 55.53686611354351, 51.107751578092575, 54.114879816770554, 53.50953429937363, 55.32640300691128, 43.24248522520065, 24.441310688853264, 13.817494958639145, 9.114653561264277, 9.245144259184599, 9.520351141691208, 11.823565252125263, 15.306231323629618, 11.432259399443865, 13.349459823220968, 7.406435273587704, 3.617296409793198, 0.7964796549640596, 1.0868935589678586, 10.463898461312056, 37.422508522868156, 50.230716839432716, 45.38999319076538, 49.38365489244461, 54.9295637011528, 60.34439094364643, 38.46077620983124, 5.986172184348106, 0.2629487996455282, 0.16000267525669187, 0.1437724696006626, 0.09689033293398097, 0.2644788706675172, 0.19282847555587068, 0.16448282782221213, 0.13699716597329825, 0.1371458626817912, 0.2041175658814609, 0.1729895471362397, 0.1261327028623782, 0.14145178865874186, 0.10033833619672805, 0.0939314198330976, 0.21858227642951533, 0.16549360327189788, 0.07801350249792449, 0.19065718894125894, 0.2007199841318652, 0.16397883533500135, 0.15969912201398984, 0.1603956424514763], [0.05741005435993429, 0.010256201658194186, 0.043869911387446336, 0.023181288815976586, 0.02627085330459522, 0.06090952185331844, 0.018907670382759534, 0.0461184778396273, 0.13533937133615837, 0.050261858632438816, 0.08915160287870094, 0.028920196200488135, 0.01982790567126358, 0.01970754972717259, 0.034408793871989474, 0.05383001931477338, 0.06136895208328497, 0.009661821150075411, 0.005446296181617072, 0.05650899802276399, 0.047540878076688386, 0.05047664359153714, 0.03495067299809307, 0.04579473446938209, 0.027988895490125287, 0.05198628699872643, 0.6320650305133313, 15.782701056450605, 40.98280347883701, 45.230283960700035, 37.39331088960171, 28.414485789835453, 22.22873881459236, 38.61136592924595, 29.43785447627306, 10.80546498298645, 1.9057847675867379, 0.15194566774880514, 1.2964928057044744, 1.5310668060556054, 0.6364558136556298, 6.612235615029931, 4.431766318157315, 6.996622513979673, 6.6643426939845085, 3.443540520966053, 9.251422472298145, 20.1823890209198, 39.021367728710175, 54.594748467206955, 56.08946666121483, 51.277488470077515, 51.178522780537605, 49.21243987977505, 49.855585768818855, 50.96215099096298, 52.5339974462986, 52.02877655625343, 50.69933049380779, 50.8995645493269, 48.43464441597462, 49.39234122633934, 47.54170373082161, 46.52206264436245, 48.196226209402084, 50.71429409086704, 49.66337688267231, 50.112223997712135, 45.29614582657814, 45.04858151078224, 40.797958597540855, 38.01752619445324, 35.15759825706482, 36.49410434067249, 40.15848711133003, 45.263410583138466, 43.950026258826256, 42.91174717247486, 39.26637478172779, 37.22553089261055, 34.12368133664131, 35.582958832383156, 36.78433656692505, 41.67691983282566, 42.50666230916977, 50.16033321619034, 44.41330499947071, 54.247633293271065, 41.14573493599892, 36.3741409778595, 50.70921376347542, 46.230451092123985, 49.96146708726883, 40.81680938601494, 39.26803529262543, 36.990239918231964, 38.96236829459667, 39.68996465206146, 40.295340567827225, 38.2144620269537, 38.43361906707287, 39.67122405767441, 38.98527726531029, 36.62713520228863, 39.81772139668465, 43.48506420850754, 48.01050737500191, 47.07548774778843, 47.92389862239361, 50.32201074063778, 52.696176543831825, 49.58572044968605, 47.683679312467575, 53.569225296378136, 50.0280699133873, 48.10098811984062, 49.6994711458683, 49.24621246755123, 54.013341665267944, 49.058050364255905, 49.44339148700237, 48.51247563958168, 49.372639283537865, 48.22716034948826, 51.173187866806984, 50.729166492819786, 53.035779520869255, 52.270967960357666, 50.79723224043846, 50.25880113244057, 36.91033020615578, 16.889470517635345, 7.606247551739216, 5.2260505221784115, 3.1628260714933276, 2.9073159070685506, 5.626110630109906, 5.440077837556601, 6.920315483585, 4.183433493599296, 3.0032144486904144, 0.5736393656115979, 0.04721966171928216, 0.8204120770096779, 9.324526749551296, 31.84934187680483, 44.93291951715946, 46.04248657822609, 40.46799190342426, 53.097537606954575, 45.13530045747757, 27.22645863890648, 3.643752965144813, 0.04862554545979947, 0.02937449262390146, 0.07837791185011156, 0.027698923549905885, 0.030136694986140355, 0.1051510451361537, 0.016288482802337967, 0.022695621810271405, 0.056224128347821534, 0.03978021013608668, 0.062347440398298204, 0.03603737015509978, 0.01455179693948594, 0.06663804844720289, 0.02843063291948056, 0.057175769470632076, 0.03328395774587989, 0.013757110773440218, 0.09504519795882516, 0.10726649998105131, 0.01577697606990114, 0.038543736445717514, 0.056813078190316446, 0.027768353320425376, 0.039528195338789374, 0.026530176401138306, 0.03859465148707386, 0.05227202127571218, 0.038097894939710386, 0.01058539981386275, 0.023924514462123625, 0.11146497781737708, 0.024161313376680482, 0.028934538204339333, 0.014174685729813064, 0.03794090102019254, 0.05558358439884614, 0.0301663641948835, 0.035914333202526905, 0.030160493806761224, 0.035696123231900856, 0.04435796996403951, 0.044827192832599394, 0.09481075350777246, 0.05939420472714119, 0.040801913710311055, 0.036801915848627687, 0.02502604158507893, 0.047561932806274854, 1.1747763119637966, 20.86791403591633, 46.02905809879303, 52.2405581921339, 42.749568074941635, 34.87978756427765, 23.279726319015026, 37.30364330112934, 34.62904281914234, 11.16604283452034, 1.6696844366379082, 0.0863676139852032, 0.15347605047281832, 1.6645541181787848, 4.388542687520385, 8.787519615143538, 9.885591343045235, 6.263176370412111, 9.347282778471708, 6.923489738255739, 11.861736103892326, 24.072046503424644, 40.91894030570984, 54.720734506845474, 55.20016238093376, 52.904998138546944, 51.26954309642315, 51.47847108542919, 50.285810083150864, 50.82501634955406, 52.55613885819912, 52.18600071966648, 50.61531700193882, 51.393914222717285, 50.53624324500561, 50.412191301584244, 49.397729337215424, 47.57364861667156, 46.47198513150215, 51.18121683597565, 50.72471313178539, 51.69432990252972, 47.90277935564518, 46.96374714374542, 42.70526245236397, 40.47978647053242, 36.514756232500076, 39.35131162405014, 41.71791963279247, 46.28617510199547, 47.11097024381161, 44.829686656594276, 40.60610309243202, 38.3917111158371, 36.33302338421345, 38.05672109127045, 37.32246749103069, 43.22436019778252, 44.576529040932655, 51.114097237586975, 48.03229920566082, 55.08389621973038, 43.99280056357384, 38.49226891994476, 52.216136902570724, 48.77541393041611, 51.990748196840286, 43.51904198527336, 39.76387068629265, 38.827783316373825, 41.38507269322872, 41.316740959882736, 41.30081981420517, 39.052161276340485, 39.31676007807255, 41.001772060990334, 40.58095224201679, 38.12101364135742, 42.18491457402706, 46.105680987238884, 49.49887990951538, 49.29988078773022, 51.77497297525406, 50.23134000599384, 53.87053392827511, 50.96220038831234, 50.19225150346756, 55.034115090966225, 51.93660870194435, 49.92157302796841, 51.96921095252037, 51.07446536421776, 54.76068556308746, 51.488069370388985, 52.53652051091194, 51.19530647993088, 51.52111999690533, 51.412924602627754, 54.1961270570755, 51.32137231528759, 55.46415701508522, 53.80959279835224, 53.63259069621563, 51.49409584701061, 39.66361686587334, 19.586957171559334, 10.070665162056684, 4.791142009198666, 5.019817538559437, 5.200337776914239, 7.548482101410627, 9.366948623210192, 6.236794861033559, 5.307821659371257, 1.5513814659789205, 0.43959603644907475, 0.16948058386333287, 0.9351274464279413, 10.575687512755394, 35.639803782105446, 46.741394475102425, 50.72043836116791, 45.9106070548296, 57.217702120542526, 49.64495167136192, 30.60617208480835, 4.426501700654626, 0.014756300370208919, 0.027676993086060975, 0.08335731457918882, 0.06803179436246864, 0.033145395063911565, 0.05127497926878277, 0.009959622748283437, 0.07937273112474941, 0.07541290571680292, 0.024242819745268207, 0.07612235436681658, 0.07498152495827526, 0.07328980675083585, 0.06557618355145678, 0.018020701863861177, 0.030362317156686913, 0.04005770286312327, 0.02984026821650332, 0.048527344479225576, 0.02645995067723561, 0.02690091627300717, 0.04784454264154192, 0.019135524562443607, 0.0755380243936088, 0.11780179091147147, 0.09105337114306167, 0.12226336752064526, 0.136880322243087, 0.13555312470998615, 0.09120768590946682, 0.1023236702894792, 0.16213210474234074, 0.15546114707831293, 0.2297266776440665, 0.10520864321733825, 0.14340197463752702, 0.20780816237675026, 0.10875927066081204, 0.16782819206127897, 0.1487122045364231, 0.1422994103631936, 0.16419517138274387, 0.14223876205505803, 0.361868268228136, 0.14256217516958714, 0.19457676768070087, 0.21409247594419867, 0.09610833192709833, 0.124008305137977, 1.6899018455296755, 24.11730967462063, 51.99982970952988, 59.3785397708416, 50.01630574464798, 40.52614018321037, 31.85707066208124, 48.08380924165249, 38.473095148801804, 14.377097580581903, 2.6075863279402256, 0.3423982614185661, 2.017815224826336, 4.266069084405899, 7.343330634757876, 16.89805045723915, 12.35136928036809, 16.218118742108345, 14.185304772108793, 7.934880517423153, 12.946666236966848, 26.27866979688406, 42.202598825097084, 58.2333268225193, 58.05464141070843, 54.21556681394577, 51.283089369535446, 52.128935381770134, 52.08206869661808, 51.82735316455364, 53.778537064790726, 53.60354885458946, 50.29332607984543, 50.72099693119526, 49.82849322259426, 50.121537297964096, 48.516780808568, 47.71006129682064, 46.007152274250984, 50.14489844441414, 50.612201169133186, 54.5218949764967, 48.73432293534279, 49.3166758865118, 45.638195872306824, 42.62091837823391, 39.93114911019802, 39.49097692966461, 43.937171548604965, 48.67652043700218, 48.03368233144283, 46.447704434394836, 42.73953661322594, 39.94904235005379, 36.5338160097599, 39.84413757920265, 39.037687852978706, 45.38291037082672, 46.94850616157055, 54.839527532458305, 50.257178619503975, 57.528312653303146, 46.62584647536278, 42.11564429104328, 53.98632891476154, 51.8595602363348, 54.433956295251846, 46.29011169075966, 41.802636086940765, 39.767400696873665, 42.73437649011612, 43.597010001540184, 43.97612325847149, 41.55069440603256, 41.23034879565239, 43.04038926959038, 42.73228280246258, 40.77924080193043, 43.313917592167854, 47.158422097563744, 51.13599166274071, 50.9595063328743, 53.25433999300003, 53.11092808842659, 53.23012389242649, 51.633726954460144, 51.877407878637314, 57.84390091896057, 54.449527859687805, 52.56640210747719, 52.332589253783226, 51.55019223690033, 56.259028762578964, 52.89970502257347, 53.9792574942112, 53.28558191657066, 52.83801533281803, 53.23489263653755, 57.0172780752182, 55.582250878214836, 57.40918144583702, 56.91800840198994, 56.504647582769394, 54.09445971250534, 42.077976912260056, 19.519786275923252, 10.37036458030343, 9.650351665914059, 8.843604605644941, 9.763520993292332, 12.606418244540691, 14.853703156113625, 15.810220129787922, 13.022126387804747, 6.856243321672082, 1.636602699290961, 0.45607993786688894, 1.3255754951387644, 12.010110542178154, 42.475857362151146, 55.05525715649128, 58.53779688477516, 51.77328206598759, 65.81116139888763, 58.92124190926552, 34.61204633116722, 5.196163700893521, 0.13948227715445682, 0.08342424887814559, 0.1707272880594246, 0.21183907811064273, 0.11028465873096138, 0.3060934954555705, 0.12847394129494205, 0.19552215992007405, 0.14625623007304966, 0.11392946471460164, 0.2730679832166061, 0.33376545121427625, 0.14198761928128079, 0.1585245248861611, 0.06351510586682707, 0.1830747106578201, 0.18927254917798564, 0.17704265308566391, 0.20363153336802498, 0.25673589552752674, 0.14496253308607265, 0.11016358475899324, 0.1870141492690891], [0.1041852067282889, 0.03427581214054953, 0.03868481871904805, 0.05811118353449274, 0.0805679673794657, 0.05702562557416968, 0.019104649363725912, 0.08384991509956308, 0.03559880169632379, 0.05857580508745741, 0.026301003053958993, 0.033544407051522285, 0.028142469964222983, 0.019601945823524147, 0.010500500902708154, 0.03775057353777811, 0.08743341226363555, 0.0904731749324128, 0.029537169539253227, 0.038991715337033384, 0.06957981793675572, 0.03530419875460211, 0.005372764189814916, 0.06979959754971787, 0.08165015970007516, 0.02736576418101322, 0.12406100504449569, 8.696964774280787, 32.3003301769495, 47.3254307359457, 40.38811258971691, 25.83233054727316, 36.61417409777641, 42.46003121137619, 27.923179753124714, 16.429875679314137, 2.6857450464740396, 0.28214925841894, 0.08909403448342346, 2.895990377292037, 3.7842064909636974, 7.787523474544287, 7.829241910949349, 2.6470234617590904, 4.909017384052277, 4.029228743165731, 9.833066761493683, 17.038808204233646, 29.386006258428097, 41.29502512514591, 46.48879922926426, 48.61188970506191, 52.65671566128731, 51.32193848490715, 51.03417232632637, 49.98865842819214, 52.33946308493614, 50.55788308382034, 50.127890557050705, 50.20405367016792, 50.6567195802927, 51.33222073316574, 51.72317035496235, 48.350098952651024, 49.097469449043274, 47.757254764437675, 50.304136499762535, 51.115339770913124, 48.58614228665829, 47.22545050084591, 43.8088296353817, 42.91900098323822, 36.74369774758816, 36.47836558520794, 37.50725157558918, 40.53404375910759, 35.9744556248188, 38.1793063133955, 35.70622801780701, 35.463128462433815, 35.28511941432953, 35.265539065003395, 36.2460308521986, 38.44465747475624, 38.28302934765816, 45.2225361764431, 45.79100087285042, 53.34503352642059, 42.2678679227829, 37.5437980145216, 51.151536628603935, 48.554900363087654, 49.592465087771416, 41.275433376431465, 40.662986040115356, 40.17212077975273, 45.42714759707451, 44.50155906379223, 47.02439948916435, 41.60610683262348, 39.16014388203621, 38.7539304792881, 39.47951674461365, 37.73574471473694, 37.7652083337307, 38.400876224040985, 44.910189136862755, 47.139711901545525, 47.52049706876278, 48.12071666121483, 49.09579373896122, 50.02270460128784, 46.56521312892437, 45.85090085864067, 48.51914048194885, 49.53888796269894, 49.84515532851219, 50.331688821315765, 53.659212067723274, 49.84277665615082, 53.39406989514828, 51.649112328886986, 52.941658571362495, 51.21484123170376, 53.10100682079792, 52.63868562877178, 55.391786098480225, 51.20646268129349, 54.02458146214485, 44.43157061934471, 31.299703270196915, 14.254379365593195, 7.352073015645146, 3.7576245423406363, 3.797305100597441, 4.946714211255312, 6.6708821430802345, 8.170568570494652, 5.8734184596687555, 3.402584418654442, 0.942123286658898, 0.28369405365083367, 0.1075112825492397, 1.3590670167468488, 12.134563364088535, 33.89153279364109, 35.833448991179466, 28.004016615450382, 34.11090262234211, 49.180460795760155, 41.5329759567976, 17.823813781142235, 1.6248950525186956, 0.013176556476537371, 0.041402990245842375, 0.03318454335385468, 0.0539043565368047, 0.07297564821783453, 0.046436439879471436, 0.018645829550223425, 0.07614365400513634, 0.057784968812484294, 0.01371087868392351, 0.026249826405546628, 0.01163664179330226, 0.08482126766466536, 0.12575428176205605, 0.05112936247314792, 0.010575782507658005, 0.07457046420313418, 0.04911642048682552, 0.015044851097627543, 0.028470298857428133, 0.05879310592717957, 0.007665109005756676, 0.025975083335652016, 0.03901713760569692, 0.018122823239536956, 0.06463098427047953, 0.08376156241865829, 0.1336332777282223, 0.007254745869431645, 0.022424715643865056, 0.05377019479055889, 0.03768095266423188, 0.06886005343403667, 0.014152886069496162, 0.029451729787979275, 0.06737440737197176, 0.021252682636259124, 0.034557267936179414, 0.04832886821532156, 0.03677488683024421, 0.014963084977352992, 0.011424867170717334, 0.05440253058623057, 0.026470871380297467, 0.02164808778616134, 0.07626905469805934, 0.01876833772257669, 0.06813714222516865, 0.051853097465937026, 0.3169444960076362, 11.815826017409563, 38.758581429719925, 52.33696661889553, 45.70125728845596, 30.31818363815546, 36.15091435611248, 46.136862114071846, 30.252777747809887, 17.52261344343424, 3.061417588032782, 0.21509973361389711, 0.12020485766697675, 1.2791144382208586, 2.328733066096902, 7.948285723105073, 9.297900628298521, 6.821340769529343, 9.214727841317654, 5.700323497876525, 9.327849671244621, 19.643123857676983, 33.432422429323196, 47.65407130122185, 52.41240777075291, 51.221346482634544, 55.15057124197483, 52.23420113325119, 52.89774052798748, 52.90128193795681, 53.25189672410488, 51.726829558610916, 51.67276605963707, 51.23007461428642, 50.15752896666527, 52.00225777924061, 50.27910724282265, 48.164121732115746, 48.69419328868389, 48.87590333819389, 50.383601635694504, 52.059623301029205, 51.441780254244804, 49.565744921565056, 45.9196999669075, 44.27372328937054, 38.386444598436356, 37.511457949876785, 39.71689760684967, 43.12449395656586, 39.50158976018429, 41.27789184451103, 38.47259737551212, 37.28185907006264, 37.44170889258385, 36.96245580911636, 37.72993862628937, 39.91618551313877, 40.1123271882534, 48.20414498448372, 47.20766745507717, 56.704193875193596, 46.98836602270603, 40.911355912685394, 52.61174887418747, 49.23900805413723, 53.37389297783375, 43.78275543451309, 42.36861191689968, 40.64174897968769, 46.774350106716156, 46.605247780680656, 48.71414601802826, 42.463397830724716, 42.32040010392666, 39.956603944301605, 41.61404460668564, 39.27615165710449, 39.98400427401066, 41.51862792670727, 47.15081870555878, 48.74301686882973, 49.972646087408066, 49.50127378106117, 51.42191872000694, 49.98943738639355, 46.939550042152405, 48.20748120546341, 50.962891951203346, 50.403238981962204, 51.06680117547512, 50.75354978442192, 54.20922115445137, 51.46582916378975, 54.10380721092224, 54.15426470339298, 54.0728160738945, 53.99504944682121, 55.31659193336964, 55.514530912041664, 57.96590097248554, 53.87260101735592, 56.36100389063358, 48.232920840382576, 33.94906550645828, 17.47771505266428, 8.401696868240833, 5.217034080997109, 8.606988452374935, 5.939406668767333, 9.753187447786331, 8.232344705611467, 6.891637472435832, 7.339381221681833, 1.5981503063812852, 0.3880514163756743, 0.11257826612563804, 1.1731128324754536, 13.809091709554195, 38.99663105607033, 40.2643608301878, 35.26010535657406, 38.98245021700859, 57.92935833334923, 49.0738271176815, 22.18843437731266, 2.010156260803342, 0.0354174059611978, 0.06870219862321392, 0.051300423801876605, 0.05305730628606398, 0.1035794138442725, 0.03604268764320295, 0.06215579931449611, 0.049257142818532884, 0.04931289666274097, 0.032078943695523776, 0.06078018035623245, 0.052522455298458226, 0.0574797680019401, 0.08224883538787253, 0.023763691060594283, 0.06929611714440398, 0.0499804102582857, 0.01757107354933396, 0.02225323685706826, 0.03690406876557972, 0.05369505233829841, 0.01631829858524725, 0.03888837127306033, 0.19214900967199355, 0.08731308786082081, 0.15350383648183197, 0.20134665363002568, 0.2164558897493407, 0.1581744835129939, 0.12361365326796658, 0.23393952345941216, 0.08569418918341398, 0.18002443917794153, 0.1186632239841856, 0.11815031088190153, 0.15823119843844324, 0.12386746777337976, 0.1267737997113727, 0.1586778971250169, 0.2107995073311031, 0.1716457403381355, 0.10959063933114521, 0.21633828902849928, 0.16017577378079295, 0.09736075808177702, 0.1946896780282259, 0.2200404481845908, 0.16132884862599894, 0.10953778357361443, 0.6003679626155645, 12.97108182683587, 43.744890466332436, 60.68207502365112, 53.13262492418289, 37.114519849419594, 48.13857950270176, 53.05240362882614, 36.5934082120657, 22.696945890784264, 3.724053343757987, 0.8620022109244019, 0.4899388225749135, 5.639652628451586, 7.91004647500813, 15.817208904772997, 18.857303224503994, 8.98768337443471, 14.447397608309984, 10.282224509865046, 14.69286348670721, 22.103898413479328, 36.3399276137352, 50.30331194400787, 52.692980915308, 51.30735866725445, 55.91125622391701, 54.59878385066986, 54.16112333536148, 53.364724069833755, 55.75821563601494, 52.41262435913086, 53.24441112577915, 51.97887383401394, 51.95867031812668, 53.476913049817085, 52.07006514072418, 48.39284285902977, 49.37212251126766, 49.242553263902664, 50.7191426306963, 53.46874728798866, 53.11475448310375, 51.45665265619755, 47.10909694433212, 47.20624253153801, 39.93516929447651, 39.80386734008789, 41.12164042890072, 43.72678443789482, 39.410964623093605, 42.7440469712019, 40.26609353721142, 38.5921161621809, 38.55827137827873, 38.71772222220898, 40.01460783183575, 41.99777841567993, 41.99671067297459, 49.223577082157135, 50.85658125579357, 57.74065665900707, 50.667142421007156, 45.80382518470287, 53.66990469396114, 52.55661003291607, 55.908417776227, 45.35593941807747, 46.05615824460983, 43.06432418525219, 48.610407784581184, 48.43306750059128, 49.901240319013596, 44.29889313876629, 42.781569957733154, 42.84229449927807, 43.24799492955208, 41.37261316180229, 42.474603429436684, 42.8927405923605, 49.15401041507721, 51.63458190858364, 52.0677624642849, 52.904272377491, 53.52669417858124, 51.52540996670723, 48.743237257003784, 47.72150628268719, 51.91775791347027, 53.07069584727287, 52.531155198812485, 52.453198581933975, 55.085780918598175, 51.637458354234695, 55.317302495241165, 54.52027626335621, 55.10000355541706, 54.55542057752609, 56.33131608366966, 56.66794002056122, 58.37936818599701, 55.19420810043812, 56.16846442222595, 49.93267983198166, 34.45663467049599, 18.055255562067032, 10.86885318160057, 7.91628479026258, 12.708750553429127, 14.309462159872055, 14.823924154043198, 17.61522587388754, 14.907402824610472, 13.036648258566856, 4.337030276656151, 1.7942473338916898, 0.3382578195305541, 1.8397262622602284, 16.764367930591106, 44.02890242636204, 47.303825095295906, 39.075074046850204, 45.42288422584534, 61.36277809739113, 57.64497019350529, 24.688415229320526, 2.222142848186195, 0.10326478775823489, 0.12572327483212575, 0.12951340817380697, 0.10350465730880387, 0.23381545121083036, 0.07697602457483299, 0.09770014963578433, 0.2104504604358226, 0.1929396641207859, 0.11827122900285758, 0.13882709434255958, 0.11324187231366523, 0.13004429609281942, 0.21277672232827172, 0.16343883384251967, 0.12548261118354276, 0.264411186799407, 0.20839209901168942, 0.08603223002864979, 0.18065915355691686, 0.1450724303140305, 0.1292832088074647, 0.060594899478019215], [0.08670837851241231, 0.04514962631219532, 0.008170300989149837, 0.02562023655627854, 0.05437444771814626, 0.011236026766709983, 0.024891323228075635, 0.10524735364015214, 0.015973151676007546, 0.07450301782228053, 0.040134437222150154, 0.03855562194075901, 0.04106815918930806, 0.06681318045593798, 0.03372335369931534, 0.047720047368784435, 0.057251750549767166, 0.05609601881587878, 0.02144766338460613, 0.08466417726594955, 0.04426868959853891, 0.0396562009700574, 0.04664460117055569, 0.05379729060223326, 0.013303958185133524, 0.024054084169620182, 0.08223359167459421, 4.432259816676378, 24.78043869137764, 43.34629565477371, 46.82350806891918, 30.176781825721264, 20.025991313159466, 29.138920716941357, 40.02440370619297, 20.190417990088463, 6.2077791430056095, 1.1302318959496915, 0.09499574865913019, 0.38367482309695333, 2.0656836312264204, 6.107531497254968, 8.419422917068005, 5.0518246460706, 8.807031568139791, 4.454828230664134, 7.5513471476733685, 15.424974951893091, 26.733096912503242, 41.30891337990761, 52.868615090847015, 53.17523963749409, 52.63146221637726, 51.622924134135246, 48.082091733813286, 48.779270723462105, 46.79165057837963, 49.09547455608845, 48.67878131568432, 50.085804015398026, 49.08901110291481, 51.360882595181465, 51.32525570690632, 49.404728561639786, 46.63556255400181, 48.46332907676697, 48.832874447107315, 50.6186418235302, 48.33762802183628, 47.832380533218384, 49.09091480076313, 47.30863943696022, 38.85821208357811, 34.67134214937687, 35.0590505450964, 34.9859082698822, 35.19669435918331, 36.571718975901604, 34.78815168142319, 36.340653374791145, 36.48445285856724, 36.18365339934826, 35.93432977795601, 38.70729178190231, 37.0980591326952, 42.45476469397545, 45.11981628835201, 49.87147271633148, 46.07709512114525, 37.93370269238949, 51.85452550649643, 48.086396902799606, 48.946640342473984, 43.21256943047047, 38.67798775434494, 38.37244234979153, 44.48006361722946, 46.9296857714653, 46.2839712202549, 43.746923357248306, 41.17460198700428, 40.3097227960825, 42.038512229919434, 39.687103405594826, 38.75916659832001, 37.527261301875114, 38.40032145380974, 44.282512217760086, 45.24285368621349, 49.73585419356823, 50.1447768509388, 45.08012741804123, 45.83204627037048, 47.020508497953415, 50.83668552339077, 50.1792524009943, 49.35478404164314, 49.454087913036346, 52.459380850195885, 49.79335270822048, 52.74722680449486, 49.316934272646904, 52.0220585167408, 53.926295936107635, 52.15996831655502, 51.14945814013481, 54.1884970664978, 55.27715004980564, 52.75511898100376, 39.29166242480278, 28.55821117758751, 16.24994583427906, 5.85639632306993, 2.730399062857032, 4.883924480527639, 2.485904269851744, 6.657157754525542, 4.882627800107002, 3.26344633474946, 3.495003296993673, 0.2516429516253993, 0.22996303683612496, 0.0028826706466134056, 1.7065803380683064, 13.52532958611846, 34.29665565490723, 33.65041673183441, 39.4503191113472, 37.171991765499115, 47.557298094034195, 44.543763399124146, 9.86222069710493, 0.9419584111310542, 0.03532173199346289, 0.05934419510595035, 0.005162158913663006, 0.1015696334070526, 0.05103585557662882, 0.07680950890062377, 0.08217024194891565, 0.05486516318342183, 0.03620235700509511, 0.01562990466482006, 0.027666825662890915, 0.03718470819876529, 0.014494168244709726, 0.023153222646215, 0.08011522761080414, 0.053613282507285476, 0.03398609995201696, 0.027364519228285644, 0.038626823588856496, 0.05426173775049392, 0.03913705382728949, 0.03635700202721637, 0.05253448551229667, 0.02805633073876379, 0.06980204663705081, 0.0636317789030727, 0.05059086011897307, 0.037310669213184156, 0.05781037252745591, 0.04671458198572509, 0.05555852949328255, 0.07683686446398497, 0.04645616245397832, 0.03457871229329612, 0.024952489184215665, 0.11042248297599144, 0.016016376212064642, 0.025746379396878183, 0.0053236061830830295, 0.026658645874704234, 0.03608803657698445, 0.0034767148690661998, 0.09775700556929223, 0.013168105269869557, 0.026807329595612828, 0.03721690256497823, 0.034804618335328996, 0.016737908881623298, 0.025807222518778872, 0.14922447939170524, 5.174287324771285, 29.030734822154045, 51.25632360577583, 50.74425928294659, 35.195402428507805, 29.00723498314619, 33.82425740361214, 41.827813535928726, 22.678296491503716, 6.238276781514287, 1.2461140402592719, 0.12377048391499557, 0.6543018529191613, 2.9128557723015547, 7.751446310430765, 7.46467474848032, 6.631105402484536, 8.074967600405216, 5.728686600923538, 7.897313358262181, 17.49664183706045, 31.439900547266006, 44.404063895344734, 53.15593667328358, 55.58875992894173, 53.837148919701576, 52.82094284892082, 50.38238950073719, 52.18605771660805, 49.38142441213131, 51.59239277243614, 51.785278022289276, 51.76924668252468, 51.7765498906374, 52.68447697162628, 52.68143713474274, 49.128278195858, 48.60321097075939, 48.38911525905132, 49.536801874637604, 52.63700611889362, 50.58187119662762, 50.34314140677452, 49.1800732165575, 49.194250255823135, 41.11839920282364, 36.43300361931324, 36.6914239525795, 37.311828061938286, 36.58838488161564, 37.41085074841976, 36.09729163348675, 37.724713906645775, 37.847029343247414, 38.681791350245476, 38.752630949020386, 40.137987211346626, 39.060539826750755, 44.28313918411732, 47.48823679983616, 52.625063359737396, 48.46184715628624, 40.200585052371025, 53.10045965015888, 50.518695786595345, 50.375071093440056, 46.01958520710468, 39.94179233908653, 40.610598251223564, 46.15091755986214, 48.26263904571533, 47.875721007585526, 44.6088121086359, 41.978821232914925, 42.63556659221649, 42.67996720969677, 41.60721257328987, 41.207124441862106, 39.9816408008337, 41.08902297914028, 48.43434803187847, 48.2697294652462, 51.55530296266079, 51.59457765519619, 48.06583620607853, 48.363117054104805, 49.83790151774883, 53.02938066422939, 51.5997301787138, 52.753150686621666, 51.92299023270607, 55.23913308978081, 51.23898133635521, 55.0606794655323, 51.27356328070164, 53.95410284399986, 54.643651843070984, 53.285274133086205, 52.30593368411064, 54.46812026202679, 55.58533251285553, 53.88660326600075, 41.235421523451805, 32.062405943870544, 16.410819701850414, 7.971326261758804, 4.218004988506436, 8.2219760119915, 7.2847244795411825, 6.79993461817503, 11.586954798549414, 8.657231256365776, 6.379295764490962, 1.131844671908766, 0.3552072256570682, 0.17504761170130223, 1.9732123869471252, 16.516638323664665, 38.36715303361416, 35.508422031998634, 37.63114772737026, 39.83379453420639, 51.07019439339638, 50.036281272768974, 13.274581991136074, 1.2872640509158373, 0.08412935596425086, 0.019701393612194806, 0.011913741182070225, 0.04195327048364561, 0.09861414160695858, 0.06001024667057209, 0.029889921606809366, 0.02444194909912767, 0.05976559026748873, 0.03565489692846313, 0.0561149584245868, 0.08845350166666321, 0.014252724413381657, 0.009068267208931502, 0.02406065588729689, 0.011877537363034207, 0.019020144718524534, 0.03016387428942835, 0.07327122337301262, 0.10193137844908051, 0.06570703902980313, 0.02160396339604631, 0.03946333163185045, 0.15876840945566073, 0.19762562907999381, 0.17964077851502225, 0.09820627950830385, 0.11684178578434512, 0.1538187000551261, 0.17688190389890224, 0.2589873340912163, 0.13963569392217323, 0.21158223564270884, 0.1127207807439845, 0.17412476590834558, 0.20712666300823912, 0.1643285056343302, 0.10785886741359718, 0.18499148514820263, 0.12000568749499507, 0.1315511972643435, 0.12224902922753245, 0.15088884945726022, 0.08528148828190751, 0.11521256383275613, 0.11442156057455577, 0.11051313631469384, 0.13009960093768314, 0.06533369421958923, 0.292410459369421, 6.05331220664084, 32.63830304145813, 57.04835660755634, 57.952825874090195, 41.23513273894787, 31.7431565746665, 40.26332348585129, 50.40337957441807, 26.810996532440186, 8.020742610096931, 1.8836979777552187, 0.5774031823966652, 1.818678597919643, 5.214911894872785, 12.661567535251379, 17.34729465097189, 15.722775422036648, 17.53325667232275, 12.442150209099054, 11.871841661632061, 22.421861551702023, 34.70852695405483, 45.06838604807854, 54.142192751169205, 55.64417615532875, 55.65468639135361, 53.09887133538723, 51.97570860385895, 53.79868358373642, 50.62835030257702, 52.83023715019226, 54.56634499132633, 54.69967603683472, 52.48249500989914, 55.94952017068863, 54.83853578567505, 50.42182378470898, 47.125006690621376, 50.093179419636726, 50.630645379424095, 51.55266210436821, 51.00054033100605, 52.06397786736488, 52.37920895218849, 50.84164425730705, 42.99022056162357, 38.14471676945686, 38.70061554014683, 38.35908606648445, 37.155432254076004, 38.76901566982269, 38.25971379876137, 38.963390439748764, 39.22054924070835, 40.251023545861244, 40.41144333779812, 42.630600258708, 42.11163930594921, 46.40826255083084, 50.027853325009346, 52.78378464281559, 52.378695979714394, 42.08759419620037, 54.72211383283138, 53.40070813894272, 53.36097367107868, 47.447749972343445, 41.83471016585827, 41.16066433489323, 48.60037252306938, 50.40552645921707, 48.8984589278698, 46.413016095757484, 44.77460481226444, 45.42011797428131, 45.660732463002205, 44.37553122639656, 43.54967974126339, 43.49041432142258, 42.434979155659676, 48.82340535521507, 49.15652208030224, 54.34761732816696, 55.0169438123703, 48.33141155540943, 49.79956157505512, 51.035335063934326, 53.63829419016838, 54.192562848329544, 53.66532973945141, 54.698224514722824, 57.98954330384731, 54.892401695251465, 56.95798605680466, 52.42178566753864, 54.951374530792236, 55.406073331832886, 53.767551854252815, 53.01408268511295, 55.376678109169006, 55.621901750564575, 54.72370594739914, 41.89586028456688, 32.26577863097191, 19.09214772284031, 10.697240140289068, 7.9581870418041945, 11.531192790716887, 8.835682980716228, 16.532202288508415, 16.00336566567421, 11.074068769812584, 9.273810870945454, 2.169209076091647, 0.7426116080023348, 0.29969324357807636, 2.4737917073071003, 17.353526316583157, 44.63219605386257, 46.00581854581833, 51.926964819431305, 48.92500050365925, 60.3394740074873, 57.80197776854038, 17.046215906739235, 1.5368319279514253, 0.1174397490103729, 0.1330833462998271, 0.1215106293966528, 0.20644771662773564, 0.19277952349511907, 0.18125248578144237, 0.19930009235395119, 0.10411220908281393, 0.1299744748394005, 0.1823646979755722, 0.15957828552927822, 0.11278001897153445, 0.13952002278529108, 0.1403226109687239, 0.11465950796264224, 0.19894571683835238, 0.11228195624426007, 0.16996533988276497, 0.13806484930682927, 0.18181623599957675, 0.292195919319056, 0.08306774339871481, 0.09926874554366805], [0.05286379127937835, 0.03282712132204324, 0.026329002430429682, 0.02568087373219896, 0.021585745525953826, 0.09538252634229138, 0.01337676194452797, 0.010261451425321866, 0.02931025046564173, 0.09703256553621031, 0.027111797535326332, 0.027249536433373578, 0.03710350611072499, 0.05902123841224238, 0.030878243378538173, 0.03221602579287719, 0.013718516311200801, 0.038493934625876136, 0.04604020723490976, 0.045373072134680115, 0.020824101629841607, 0.03413647391425911, 0.014408110655494966, 0.036844823116553016, 0.0243556280474877, 0.012795655675290618, 0.03424911337788217, 2.626811396330595, 13.885434363037348, 38.620272651314735, 52.514983266592026, 37.362361550331116, 25.336031578481197, 35.3187970072031, 33.0252780765295, 25.685683116316795, 10.376430004835129, 1.3106516771949828, 0.19414937967667356, 0.6689457327593118, 2.6005835412070155, 5.877439118921757, 4.564021546393633, 6.876140478998423, 4.545888444408774, 3.1713038915768266, 7.531108008697629, 15.75182581320405, 29.29787188768387, 43.486751317977905, 50.969587191939354, 54.73225548863411, 51.415968239307404, 47.01572075486183, 49.03090462088585, 46.83264657855034, 45.263425782322884, 45.10722376406193, 48.07306341826916, 47.33643114566803, 49.205680042505264, 47.6355054974556, 49.77497689425945, 52.62130156159401, 47.64081761240959, 47.20953315496445, 47.69434154033661, 46.23297415673733, 47.43082568049431, 48.16034093499184, 49.22278672456741, 47.60370880365372, 41.90941035747528, 36.35758526623249, 37.654782459139824, 37.28304460644722, 34.98002618551254, 35.330872759222984, 36.674750447273254, 37.820662558078766, 35.756176337599754, 37.29673147201538, 37.21412390470505, 40.07841780781746, 41.075142323970795, 45.87426960468292, 44.95753079652786, 50.186080634593964, 47.783442959189415, 38.814921006560326, 53.09384800493717, 49.86672677099705, 47.13151194155216, 41.67479954659939, 38.26866991817951, 37.89111837744713, 40.635783299803734, 43.2083972543478, 44.697233363986015, 42.240965366363525, 42.84050479531288, 43.94461914896965, 43.9452613145113, 38.296815007925034, 38.053761050105095, 37.36896939575672, 36.009273156523705, 39.6493486315012, 45.50246715545654, 45.23077413439751, 51.32199548184872, 48.710703402757645, 47.850148379802704, 51.06531165540218, 49.93304841220379, 45.99694982171059, 48.43406304717064, 48.34627255797386, 47.412016689777374, 46.191510781645775, 49.04285117983818, 47.74377688765526, 49.7971411049366, 53.532994240522385, 52.22689412534237, 53.869355991482735, 54.59868125617504, 52.576612159609795, 52.44272254407406, 37.573542818427086, 23.399545289576054, 14.831075370311737, 7.153738858178258, 2.7561025461182, 5.891809472814202, 5.42978941462934, 5.310511440038681, 6.26438470557332, 8.015982415527105, 8.356739580631256, 1.4755640155635774, 0.2696943876799196, 0.21464632591232657, 2.6745753083378077, 15.047478508204222, 30.551227033138275, 32.227119505405426, 32.734152898192406, 38.64009238779545, 52.113371416926384, 37.62918323278427, 9.039663635194302, 0.47451274876948446, 0.016428887865913566, 0.025854705127130728, 0.04211513660266064, 0.07889114407589659, 0.01956874955794774, 0.020106908668822143, 0.015318875211960403, 0.07754132588161156, 0.05771923308202531, 0.01023659875500016, 0.01618927806703141, 0.013929263986938167, 0.030198515887605026, 0.04554878672934137, 0.014600145077565685, 0.06466311184340157, 0.016821905155666173, 0.07311701992875896, 0.03615829940827098, 0.056743776440271176, 0.022690363693982363, 0.06389099624357186, 0.003373808672222367, 0.04659239108150359, 0.033651350531727076, 0.014091617140365997, 0.061919202635181136, 0.034810184442903847, 0.06998033277341165, 0.018359969108132645, 0.04214641441649292, 0.030531255943060387, 0.09884446713840589, 0.06667520778137259, 0.034977371760760434, 0.058310090244049206, 0.061383375723380595, 0.06680699094431475, 0.014179967038217, 0.020632145133276936, 0.036481408242252655, 0.012141390343458625, 0.004466489626793191, 0.05025720165576786, 0.06354525190545246, 0.07785687965224497, 0.04898332743323408, 0.07389049365883693, 0.04382687053293921, 0.019103409977105912, 3.033123118802905, 18.280646167695522, 44.4888411462307, 56.623011231422424, 41.1839646846056, 26.552515402436256, 39.111278504133224, 40.220959559082985, 29.185301028192043, 10.9086237475276, 1.2970178900286555, 0.12755345553159714, 0.703553503844887, 1.9469073484651744, 6.875409968197346, 6.263264240697026, 8.00434933975339, 7.535197539255023, 3.4619225095957518, 7.311940994113684, 19.65203057974577, 30.823765508830547, 46.70706331729889, 53.6953367292881, 56.02297022938728, 53.18719759583473, 50.70870079100132, 50.93059368431568, 48.726594150066376, 47.59712375700474, 48.387340754270554, 50.80130182206631, 49.18456457555294, 51.58513896167278, 49.438694939017296, 52.09685370326042, 52.15559095144272, 48.59589256346226, 47.1063344925642, 47.85857252776623, 47.8064127266407, 48.20846535265446, 51.1625712364912, 51.225849241018295, 48.95093031227589, 44.030194357037544, 38.84184256196022, 39.407886788249016, 39.607148095965385, 36.236010789871216, 38.46686348319054, 38.81666511297226, 39.00113381445408, 36.735163405537605, 38.31365570425987, 37.67589032649994, 40.70930555462837, 42.45765633881092, 48.00978161394596, 46.5029002726078, 53.184233754873276, 49.49431635439396, 41.55891716480255, 53.16111959517002, 51.757965087890625, 50.83346709609032, 43.55531103909016, 39.88317288458347, 38.13358336687088, 42.58481651544571, 45.19064448773861, 47.19023399055004, 44.796860218048096, 43.401711881160736, 45.94291292130947, 45.759097784757614, 40.34992843866348, 37.93656773865223, 39.46926489472389, 38.49746324121952, 42.677227556705475, 48.73677760362625, 47.55148820579052, 52.52062976360321, 48.605787232518196, 49.481818825006485, 53.2447075098753, 51.66901186108589, 48.37242655456066, 49.71630044281483, 52.0543871819973, 49.3969389796257, 50.13403482735157, 50.852880254387856, 49.50804881751537, 52.45344176888466, 55.25763429701328, 53.33919703960419, 54.204687997698784, 55.14919571578503, 55.64452573657036, 55.10087750852108, 39.938262328505516, 27.200325541198254, 15.359444618225098, 8.36618397384882, 5.583997964859009, 9.859628286212683, 7.181946644559503, 8.811773713678122, 7.199874557554722, 6.801260747015476, 3.8705753814429045, 1.5173646225593984, 0.3833020868478343, 0.22696357278618962, 3.0421312479302287, 16.402270160615444, 36.753292232751846, 37.08513602614403, 42.98615097999573, 44.10829156637192, 57.47242525219917, 44.241797402501106, 11.827000267803669, 0.6422545399982482, 0.07038379393634386, 0.012710367136605782, 0.020876718044746667, 0.02784964075544849, 0.04247341210430022, 0.047354843918583356, 0.005296190320223104, 0.08359781495528296, 0.08338361629284918, 0.06658438374870457, 0.03171369942720048, 0.06980012447456829, 0.010419219033792615, 0.04051172283652704, 0.0006757276048574568, 0.01975246450456325, 0.10718896781327203, 0.07934592475066893, 0.020088802120881155, 0.03524821855535265, 0.03342981945024803, 0.06014630831487011, 0.02926441728050122, 0.14911360252881423, 0.11046827348764054, 0.06761995435226709, 0.19103853410342708, 0.11712298553902656, 0.1811744415317662, 0.08322691181092523, 0.0806707919400651, 0.09390517006977461, 0.17194721556734294, 0.1409150377730839, 0.1350119209382683, 0.12582445924635977, 0.19496771623380482, 0.13240331638371572, 0.10295299667632207, 0.09624277940019965, 0.144099623139482, 0.11135914755868725, 0.14231918117729947, 0.19764388591283932, 0.18094511789968237, 0.10480724522494711, 0.14376975334016606, 0.2788623160449788, 0.13528535782825202, 0.13997475150972605, 3.480911278165877, 21.60704657435417, 52.47005067765713, 65.72194218635559, 48.021370992064476, 34.65642414987087, 45.39098113775253, 42.68232688307762, 34.1622606664896, 13.301866427063942, 2.3678275058045983, 0.5238911288324744, 1.9654233986511827, 6.292884601280093, 14.40173165872693, 11.981339436024427, 15.576320830732584, 11.22043501585722, 8.21865689009428, 10.856056418269873, 21.21833313256502, 30.531753078103065, 47.03811675310135, 55.07586345076561, 56.71880789101124, 54.644886776804924, 52.23979823291302, 51.83758981525898, 51.034632101655006, 48.204380571842194, 50.172344371676445, 52.39200286567211, 52.435928508639336, 53.710038140416145, 50.771047845482826, 53.78786936402321, 55.72511941194534, 49.5110734552145, 47.58218675851822, 47.7199749648571, 48.566409945487976, 49.156347289681435, 50.21251201629639, 52.90057897567749, 51.02745808660984, 45.50275593996048, 39.981815591454506, 41.42174832522869, 42.064787819981575, 37.99446523189545, 40.82196190953255, 40.5328544229269, 41.00821651518345, 38.959077671170235, 40.89222393929958, 39.93504010140896, 43.39573100209236, 44.23950992524624, 50.10791502892971, 49.51722152531147, 55.100341737270355, 52.81615890562534, 44.181145057082176, 53.74429330229759, 54.61788922548294, 51.43886961042881, 45.859632790088654, 42.37166315317154, 40.97089871764183, 44.16606746613979, 46.32044926285744, 48.84385205805302, 45.917344093322754, 46.688417717814445, 48.69569420814514, 46.44662149250507, 42.27199450135231, 41.544455140829086, 41.92981906235218, 39.89603139460087, 44.721251875162125, 51.17861017584801, 50.70210814476013, 54.89869795739651, 50.54624430835247, 49.513239338994026, 55.63142403960228, 53.38442221283913, 50.744206085801125, 52.07400552928448, 53.67034167051315, 51.29954628646374, 51.40590637922287, 52.47198477387428, 51.47228881716728, 54.52294372022152, 57.298512384295464, 54.351075142621994, 55.84575913846493, 56.704570055007935, 56.27963125705719, 56.566021889448166, 43.16733665764332, 29.46283433586359, 17.99402564764023, 10.517956260591745, 8.493338450789452, 11.540442444384098, 13.86976970359683, 16.093880608677864, 17.98064086586237, 18.443929105997086, 15.236071888357401, 3.751727733761072, 0.8926938171498477, 0.4430929769296199, 3.4362658113241196, 20.2704568952322, 41.28136865794659, 45.72296932339668, 45.89483790099621, 52.55576267838478, 64.28304299712181, 51.15724392235279, 15.055518876761198, 0.9823845012579113, 0.18082100112223998, 0.11057566225645132, 0.11408161983126774, 0.16903093142900616, 0.14335756452055648, 0.09173184997052886, 0.10049613163573667, 0.30235832557082176, 0.17255231825402007, 0.15141166280955076, 0.14793358772294596, 0.12220295669976622, 0.09654205045080744, 0.11850179202156141, 0.0834673157078214, 0.13987257261760533, 0.2356052739196457, 0.22120180539786816, 0.13608512585051358, 0.1837256335420534, 0.11170794954523444, 0.15305387234548107, 0.09558203790220432], [0.046092131597106345, 0.048175933843594976, 0.014018664023751626, 0.010081121599796461, 0.04888544928689953, 0.02816716121742502, 0.006489127772510983, 0.052459406142588705, 0.012970822008355753, 0.0683791640039999, 0.05198371916776523, 0.054694940481567755, 0.04453294983250089, 0.04122958373045549, 0.010367302093072794, 0.07494191653677262, 0.052253311732783914, 0.1063088548835367, 0.01693012884061318, 0.07879031589254737, 0.00906125855181017, 0.1040749903768301, 0.06690029375022277, 0.08079470091615804, 0.039370759841403924, 0.027191257431695703, 0.0688429172441829, 0.7400399772450328, 7.877816604450345, 29.401258639991283, 51.30070902407169, 38.81706789135933, 31.92483812570572, 24.519922770559788, 30.52999187260866, 31.059468761086464, 15.661798194050789, 2.748997639864683, 0.2514730591792613, 0.11350739048793912, 1.7484274925664067, 5.56233580224216, 5.767505317926407, 3.1953121908009052, 8.719835747033358, 4.091778136789799, 5.131452223286033, 11.967628821730614, 22.774570025503635, 39.28776763379574, 52.182102128863335, 52.401730343699455, 50.525144040584564, 50.86745627224445, 48.35207484662533, 47.88552068173885, 44.71054024994373, 42.67494387924671, 43.28084036707878, 45.17633445560932, 46.681669279932976, 46.406267657876015, 49.15591411292553, 49.39967483282089, 49.98824805021286, 48.87254811823368, 47.00346261262894, 53.44155974686146, 49.45704035460949, 47.757684141397476, 49.05593387782574, 48.8217144459486, 41.23702883720398, 37.13002681732178, 38.08622270822525, 35.18964573740959, 35.675476267933846, 36.75814837217331, 37.4650814384222, 39.52744357287884, 39.84506092965603, 43.04374448955059, 43.47274146974087, 45.885771587491035, 43.739179372787476, 48.385824635624886, 47.11255855858326, 51.214134469628334, 47.610996812582016, 37.3480287194252, 51.55438341200352, 48.68576914072037, 47.87532202899456, 41.49785824120045, 38.34424026310444, 36.822330728173256, 37.889427468180656, 39.92926441133022, 40.4428980499506, 41.136395037174225, 41.66822209954262, 41.92000798881054, 40.308066084980965, 38.38702216744423, 36.38041064143181, 37.516713067889214, 38.757449090480804, 42.189865708351135, 45.57945102453232, 47.26149536669254, 49.10946160554886, 51.04991868138313, 48.58130134642124, 49.44783344864845, 47.51299627125263, 44.633981958031654, 42.73545943200588, 40.012787729501724, 41.378001272678375, 42.86020293831825, 45.86063213646412, 46.641589030623436, 47.85096913576126, 49.81228709220886, 53.84916007518768, 51.56216159462929, 54.261886328458786, 50.93733072280884, 49.46465514600277, 37.14152880012989, 23.98761883378029, 11.36421075090766, 5.409828135743737, 3.2698606280609965, 10.497939884662628, 8.437065370380878, 5.961729045957327, 7.380953365936875, 6.076575508341193, 3.447386152110994, 0.9897825855296105, 0.4199606494512409, 0.15285356668755412, 4.470102936029434, 18.188791796565056, 35.00407509505749, 34.281194284558296, 36.24571166932583, 36.648201271891594, 46.406267657876015, 31.183733493089676, 5.941447159275413, 0.15545706526609138, 0.012856552602897864, 0.029805146077706013, 0.050744035688694566, 0.061916285994811915, 0.02257260712212883, 0.04012013603642117, 0.04225441545713693, 0.004837871920244652, 0.024197290840675123, 0.0203648439492099, 0.01926070632180199, 0.07416630542138591, 0.04810833161172923, 0.04390102963952813, 0.08319021260831505, 0.01996879498619819, 0.06550793565111235, 0.04048935450555291, 0.017904067790368572, 0.02895449269999517, 0.03893449575116392, 0.021486284749698825, 0.07178346961154602, 0.032057402859209105, 0.017695290516712703, 0.08353190482011996, 0.04355841716460418, 0.0748398712312337, 0.02907064808823634, 0.04816718021174893, 0.030358138865267392, 0.036291485230321996, 0.003720915547091863, 0.035801433987217024, 0.048359132997575216, 0.021793468949908856, 0.008680238079250557, 0.00891959183718427, 0.025306471361545846, 0.05003948521334678, 0.08365817382582463, 0.038731332824681886, 0.024787583970464766, 0.02719418149354169, 0.042644599598133937, 0.029103759006829932, 0.05490255629410967, 0.01593162665812997, 0.060080119874328375, 0.09705278163892217, 1.217586596030742, 9.623120427131653, 36.64794288575649, 58.326087445020676, 42.7803198248148, 35.31914658844471, 28.124226965010166, 33.07811804115772, 33.262993320822716, 17.747048400342464, 3.160636913962662, 0.12236789159942418, 0.3637900447938591, 1.3477166695520282, 6.365980328992009, 6.449541645124555, 7.410202771425247, 8.116246685385704, 4.5875052362680435, 7.9481489304453135, 13.363426923751831, 25.032655857503414, 41.56237117946148, 53.25273647904396, 55.36180570721626, 52.490945756435394, 52.6097159832716, 51.771161779761314, 47.701910734176636, 46.88442260026932, 44.382310062646866, 44.914228320121765, 47.48487398028374, 50.387762412428856, 49.01024892926216, 51.228060722351074, 52.291452661156654, 49.99460890889168, 47.543945610523224, 47.79097035527229, 52.32419550418854, 50.33123664557934, 49.20077830553055, 50.32611832022667, 51.325947269797325, 42.69485481083393, 38.314138278365135, 38.49408142268658, 37.37631820142269, 37.38158471882343, 38.55681225657463, 39.10547621548176, 40.85261486470699, 40.800641253590584, 44.250764921307564, 45.57799190282822, 46.82334087789059, 45.426440834999084, 49.51687574386597, 49.83978621661663, 53.45569118857384, 49.771788865327835, 38.91584739089012, 52.83341757953167, 50.614310055971146, 49.62270386517048, 42.6612114161253, 39.382006376981735, 39.08807694911957, 38.927915543317795, 42.875519916415215, 41.55824080109596, 42.997356578707695, 44.04854357242584, 43.89776386320591, 44.051761999726295, 40.589118003845215, 38.10207925736904, 39.24467794597149, 40.822113901376724, 42.4445204436779, 47.343779951334, 49.42511446774006, 51.73551969230175, 51.69063650071621, 48.21401305496693, 51.455527916550636, 50.72580747306347, 47.16469556093216, 44.93777945637703, 43.81417214870453, 43.82142975926399, 45.23898549377918, 46.81883051991463, 46.803608536720276, 49.233490750193596, 50.81756114959717, 53.59270803630352, 52.89879307150841, 53.78994785249233, 52.1617466211319, 51.3711154460907, 39.64170344173908, 24.48184311389923, 15.032935738563538, 7.316192016005516, 3.3716419665142894, 11.850922834128141, 7.993511371314526, 7.610204564407468, 7.609709165990353, 6.770287184044719, 2.96256969217211, 1.1335440119728446, 0.14693234144942835, 0.36803925584536046, 4.206553352996707, 21.118770875036716, 34.57846753299236, 39.234042316675186, 39.937798753380775, 43.31044837832451, 52.65274107456207, 35.65973371267319, 7.931052697822452, 0.2534748095786199, 0.03461889958998654, 0.024286973821290303, 0.08353660261491314, 0.04011927143437788, 0.029344916183617897, 0.017474405103712343, 0.04161069511610549, 0.03603505094361026, 0.022249360990826972, 0.028974948145332746, 0.04787257355928887, 0.05641248913889285, 0.02183894961490296, 0.043646888589137234, 0.03250966394261923, 0.1299063753685914, 0.02801119702780852, 0.034629530855454504, 0.008367094433197053, 0.0363639448187314, 0.06753039197064936, 0.04067755573487375, 0.057166919359588064, 0.15980576863512397, 0.0929883356729988, 0.21090900379931554, 0.16632051905617118, 0.12722815736196935, 0.16343935334589332, 0.09234057433786802, 0.16554712696233764, 0.20959967718226835, 0.1347521840943955, 0.16157101141288877, 0.12568229343742132, 0.1567101667751558, 0.10921910536126234, 0.07679259535507299, 0.1920551576768048, 0.1413774403044954, 0.1450835625291802, 0.09970182582037523, 0.2075744155445136, 0.05185734997212421, 0.31182343955151737, 0.1370039046742022, 0.1554176869103685, 0.17107018997194245, 0.15534299716819078, 0.22932853025849909, 1.4145863126032054, 11.531232688575983, 44.09062251448631, 63.508180975914, 51.533982306718826, 41.68619133532047, 34.720560908317566, 40.36750249564648, 40.126048251986504, 20.741755105555058, 3.8523731706663966, 0.37375002284534276, 0.5389444960746914, 4.89930653013289, 11.904452461749315, 14.242737740278244, 11.8214525654912, 18.00148654729128, 9.533107057213783, 8.904302548617125, 13.857465013861656, 26.659232676029205, 42.74337060749531, 55.201579704880714, 57.134684175252914, 53.47567431628704, 55.017369389534, 54.047900810837746, 51.36707626283169, 48.911800011992455, 45.97269952297211, 46.488761231303215, 49.97869536280632, 50.711474642157555, 49.64091628789902, 52.98709273338318, 52.65578471124172, 52.256939113140106, 47.794393971562386, 46.878426522016525, 53.04910160601139, 49.811732321977615, 50.36017209291458, 50.909269228577614, 53.002671897411346, 45.228080078959465, 40.81391014158726, 40.542426109313965, 39.39146786928177, 39.370018020272255, 39.93390016257763, 40.41731782257557, 42.62233190238476, 43.87383654713631, 47.839892730116844, 47.54929572343826, 50.34308820962906, 47.38783098757267, 52.77474492788315, 52.82013349235058, 55.43684408068657, 52.59987831115723, 41.6170958429575, 54.03495870530605, 53.58551122248173, 52.731685638427734, 45.379748940467834, 42.394898906350136, 40.37531487643719, 40.756240636110306, 44.722581803798676, 44.49384167790413, 45.24004943668842, 45.46163834631443, 46.12340323626995, 45.41703633964062, 43.18758197128773, 40.271348655223846, 41.14601992070675, 43.70845802128315, 46.17756173014641, 50.508003160357475, 52.18210972845554, 52.510814890265465, 52.37794741988182, 48.80611248314381, 52.9414077848196, 53.491876646876335, 48.116768673062325, 46.13136760890484, 45.68192012608051, 45.46222731471062, 48.22533644735813, 50.419859290122986, 47.960365265607834, 53.21732997894287, 53.41272309422493, 56.28925234079361, 53.15139591693878, 55.428351536393166, 54.29096236824989, 52.521910294890404, 42.1268916875124, 28.8018237054348, 14.718545358628035, 8.966238275170326, 9.517546892166138, 17.33322400599718, 17.12751444429159, 13.78959970548749, 17.14728858321905, 14.743832051753998, 7.5911471620202065, 3.198032369837165, 0.9262748120818287, 0.5401457659900188, 5.635512275621295, 23.52750912308693, 47.785939425230026, 45.654926374554634, 49.814449176192284, 50.6646915525198, 58.545115292072296, 41.815996170043945, 9.643065556883812, 0.4231052182149142, 0.1407463921350427, 0.10190919565502554, 0.1709405516157858, 0.1675609001540579, 0.15809339645784348, 0.16251199529506266, 0.23393768293317407, 0.153772464254871, 0.1105391040618997, 0.20015427464386448, 0.13028717134147882, 0.24121922033373266, 0.23523556563304737, 0.17029752518283203, 0.14332817547256127, 0.18143373308703303, 0.1515369670232758, 0.08796017384156585, 0.11043513659387827, 0.14634024119004607, 0.12487025029258803, 0.1055573858320713, 0.12904664181405678], [0.060505871442728676, 0.008267817338492023, 0.030151695646054577, 0.023404677122016437, 0.01422232326149242, 0.021549037046497688, 0.048431648247060366, 0.039732245131745, 0.0362665193824796, 0.025278149150835816, 0.0353772372181993, 0.0716965195897501, 0.060802563530160114, 0.02653266074048588, 0.09674758824985474, 0.02124595506757032, 0.03803030755079817, 0.006484568202722585, 0.024743489266256802, 0.018368498240306508, 0.010494925518287346, 0.10611300211166963, 0.07550541442469694, 0.04499145979934838, 0.07351211708737537, 0.020773309042851906, 0.05961652990663424, 0.11948917497647926, 4.666508221998811, 20.384587571024895, 48.386124819517136, 45.77711261808872, 39.02213528752327, 38.81099581718445, 40.02922184765339, 33.4624370187521, 17.65326753258705, 4.437446538358927, 0.49674396053887904, 0.2567059127613902, 0.8504201355390251, 5.442006234079599, 3.4058493934571743, 7.551425518468022, 4.5477493945509195, 1.9497891375795007, 6.526817623525858, 11.784421652555466, 21.384834498167038, 38.17482255399227, 48.43633912503719, 54.59319815039635, 54.0752137452364, 50.641843378543854, 51.71150878071785, 50.437095165252686, 46.986105144023895, 43.346280455589294, 40.781030505895615, 41.04285165667534, 44.704152792692184, 47.08625636994839, 48.560413867235184, 50.273301154375076, 49.35834065079689, 49.57303673028946, 50.767213851213455, 52.030467465519905, 47.05051928758621, 49.96713638305664, 51.11004285514355, 47.70072519779205, 40.974117144942284, 35.6916444003582, 35.22263556718826, 37.2178591042757, 35.98948001861572, 39.722004532814026, 37.63688921928406, 42.45565764605999, 44.68568578362465, 45.55425077676773, 46.11834190785885, 47.53862589597702, 47.54561372101307, 50.40604703128338, 47.96403206884861, 51.765914261341095, 48.59482482075691, 35.72773866355419, 49.51602078974247, 48.636580780148506, 46.97686403989792, 43.573299273848534, 39.23642858862877, 35.72676591575146, 35.957094356417656, 37.07879416644573, 38.97607035934925, 38.91286075115204, 37.68301874399185, 38.941165432333946, 39.28411602973938, 35.8435944467783, 35.80947607755661, 38.39983507990837, 41.63242042064667, 47.01631732285023, 47.65850946307182, 49.04639258980751, 51.68609954416752, 49.98346030712128, 49.42995920777321, 52.03242436051369, 49.09116558730602, 43.832262977957726, 36.63613311946392, 35.72395406663418, 41.16421714425087, 50.17089284956455, 47.90891222655773, 50.898998379707336, 48.69623377919197, 50.16455098986626, 52.76403330266476, 55.28163380920887, 49.122073128819466, 51.3892936706543, 52.12182216346264, 38.166413605213165, 24.330641627311707, 17.799504585564137, 8.188230022788048, 5.1720259711146355, 11.647992823272943, 4.4522505439817905, 8.357433043420315, 3.2482917979359627, 3.141537238843739, 0.8290717529598624, 1.0310288378968835, 0.2088754004216753, 0.5025166820269078, 5.4043839778751135, 25.60567270964384, 42.07713335752487, 22.49450795352459, 33.331233859062195, 46.2518135458231, 48.18738028407097, 26.930313929915428, 3.749407008290291, 0.025302684553025756, 0.07122933762730099, 0.02791009424981894, 0.0347293905360857, 0.011211013606953202, 0.024524821019440424, 0.03150574593746569, 0.007615501535838121, 0.03683059985633008, 0.038581185217481107, 0.03224609390599653, 0.015389110212709056, 0.03082879222347401, 0.05903003657294903, 0.09601655052392744, 0.0700303164194338, 0.029439326644933317, 0.07418478489853442, 0.006857735361336381, 0.046117264428175986, 0.007641392285222537, 0.038394186267396435, 0.07048572049825452, 0.10537570065935142, 0.05563302256632596, 0.030272268668340985, 0.04691624206316192, 0.06127822081907652, 0.02371749607846141, 0.03862300894979853, 0.03689760094857775, 0.03756415346288122, 0.03884767560521141, 0.028104685370635707, 0.04094603507837746, 0.07200292267953046, 0.02147424154827604, 0.03700048859172966, 0.02256893720186781, 0.005151256764293066, 0.08406413602642715, 0.05129660545208026, 0.074884734058287, 0.0989818164089229, 0.004292689773137681, 0.14115442492766306, 0.03668626326543745, 0.02262237925606314, 0.029018992754572537, 0.10710227012168616, 0.04664660125854425, 0.17421870696125552, 6.115798428654671, 26.58224120736122, 55.1938509196043, 50.15379376709461, 40.29782943427563, 36.82791642844677, 39.72262389957905, 38.2355622947216, 19.361918047070503, 4.168109390884638, 0.7127626659348607, 0.24351775558898225, 0.6212514045182616, 2.9253896372392774, 5.05233951844275, 5.741280550137162, 7.699791407212615, 5.003979513421655, 5.75725631788373, 13.695797938853502, 23.95760614424944, 38.93080338835716, 51.172443106770515, 56.093999817967415, 55.63952520489693, 52.31290630996227, 52.19180300831795, 52.93187789618969, 48.63107867538929, 45.16781911253929, 42.46206410229206, 44.27080124616623, 46.24190367758274, 49.880668222904205, 50.630181804299355, 52.52874992787838, 50.16705125570297, 51.05419345200062, 51.14249691367149, 52.437163442373276, 48.926695212721825, 49.310041442513466, 51.530174911022186, 49.71528969705105, 42.82650254666805, 37.74701111018658, 36.620702147483826, 38.021724969148636, 38.203663006424904, 40.21453410387039, 40.339767783880234, 43.2059083878994, 45.60346193611622, 48.532048389315605, 50.058517679572105, 49.29229639470577, 50.327246859669685, 51.6740769892931, 49.837981313467026, 51.85196444392204, 50.68260379135609, 38.095171228051186, 53.31215389072895, 50.403995141386986, 48.743906021118164, 45.18465980887413, 40.75907148420811, 38.153558894991875, 38.39768059551716, 40.14245197176933, 40.076305121183395, 40.64388446509838, 41.35640703141689, 40.19727163016796, 41.00170746445656, 37.60432116687298, 38.93271088600159, 40.237861052155495, 43.48209276795387, 47.39364467561245, 48.906594291329384, 49.93506610393524, 53.07767987251282, 50.27913764119148, 49.583786353468895, 52.9708182066679, 50.54760463535786, 46.98742367327213, 39.34768281877041, 37.19465754926205, 42.871644124388695, 50.736283510923386, 50.74020490050316, 51.805530935525894, 49.68404397368431, 50.63599169254303, 54.4544941931963, 54.847039729356766, 51.20987109839916, 54.62198920547962, 53.93550284206867, 38.94435726106167, 26.645167730748653, 15.553175322711468, 7.881369413807988, 4.477714402601123, 14.11757530644536, 9.236088395118713, 5.508148809894919, 6.233294298872352, 3.9561676885932684, 2.7308396017178893, 0.794152517337352, 0.1657160249305889, 0.5469843302853405, 5.722829690203071, 26.692539788782597, 48.08241471648216, 31.650204062461853, 42.502516731619835, 49.77239303290844, 54.70270827412605, 31.7453870549798, 4.920047717168927, 0.05700887901184615, 0.0474474342627218, 0.007615475560669438, 0.08196354639949277, 0.07255735894432291, 0.07068342121783644, 0.05278238881146535, 0.008615885526523925, 0.023831150429032277, 0.029095784630044363, 0.04256699321558699, 0.02005870803259313, 0.0664614989364054, 0.04306570903281681, 0.024809332608128898, 0.06007777468767017, 0.10589322249870747, 0.04932918680424336, 0.030085149119258858, 0.036339520738692954, 0.041760312087717466, 0.026491122735023964, 0.05459519583382644, 0.06342545442748815, 0.1998288874165155, 0.10213457106146961, 0.1582794974092394, 0.1347689121030271, 0.1229498467000667, 0.15856921701924875, 0.12397749116644263, 0.1097733857750427, 0.19777766545303166, 0.22941564355278388, 0.14240932243410498, 0.18790675996569917, 0.09545159060508013, 0.12985242123249918, 0.14773252507438883, 0.23494394612498581, 0.16161410050699487, 0.2762670849915594, 0.151211891497951, 0.1948689215350896, 0.06385205575497821, 0.3696611453779042, 0.10140915881493129, 0.11143915849970654, 0.13014733587624505, 0.21123090293258429, 0.19690783869009465, 0.4410192382056266, 7.294454807415605, 32.2625982016325, 62.19109185039997, 57.03309662640095, 49.38991315662861, 49.071703031659126, 51.13883391022682, 43.587776497006416, 23.952472619712353, 5.6905632466077805, 1.1098833940923214, 1.0959583288058639, 1.5579599817283452, 10.479610618203878, 11.005033124238253, 17.616785690188408, 13.088997099548578, 5.370873576030135, 9.23398520797491, 14.548005759716034, 25.72203006595373, 41.09596520662308, 52.47112222015858, 57.80007027089596, 58.039727210998535, 53.756395652890205, 54.76448155939579, 55.84764003753662, 50.62569424510002, 47.08312153816223, 43.90866547822952, 44.54725161194801, 48.548315316438675, 52.326448783278465, 52.558312341570854, 54.63506430387497, 50.64175598323345, 49.38901640474796, 50.5412969738245, 53.22683706879616, 49.928329065442085, 51.566421166062355, 54.37197782099247, 52.561321780085564, 44.781269654631615, 38.9818574488163, 39.464568346738815, 40.60400180518627, 38.91780808568001, 42.818462178111076, 41.58732824027538, 46.53032340109348, 49.54229258000851, 51.133441999554634, 52.43505075573921, 50.81277720630169, 52.176117449998856, 53.68826150894165, 52.57763050496578, 53.953707665205, 52.473375499248505, 41.37649655342102, 53.39991398155689, 52.40320086479187, 51.45813837647438, 47.84741252660751, 42.20305100083351, 40.498280078172684, 38.94759848713875, 41.63269780576229, 41.870705634355545, 41.88300937414169, 41.62238895893097, 42.194178476929665, 42.26098649203777, 39.62256766855717, 39.65221747756004, 42.419981360435486, 44.964100643992424, 51.4111652970314, 51.72071948647499, 53.250475600361824, 55.70339597761631, 49.98822145164013, 49.221878573298454, 53.98613512516022, 54.083143919706345, 47.55186438560486, 41.788504645228386, 38.44116926193237, 45.447081327438354, 55.62856659293175, 52.940750420093536, 55.990352779626846, 52.22499422729015, 53.12333822250366, 57.373641952872276, 57.37978242337704, 52.648891881108284, 56.11867569386959, 55.64068794250488, 39.59968149662018, 32.08237387239933, 20.57213220745325, 13.251395635306835, 10.996315442025661, 23.94371408969164, 14.034756850451231, 14.419615399092436, 11.699219774454832, 9.298437349498272, 4.053513240069151, 1.7466062027961016, 0.4328786500263959, 0.838307929225266, 7.159034349024296, 32.11408697068691, 54.1295812278986, 34.865952506661415, 44.440370947122574, 61.36308968067169, 61.25424072146416, 35.120326057076454, 6.5388439781963825, 0.18510565714677796, 0.14746265049325302, 0.09413071617018431, 0.19539850327419117, 0.13088339794194326, 0.2117216109763831, 0.16239960445091128, 0.1323519746074453, 0.13232672674348578, 0.1682147174142301, 0.11767019328544848, 0.07477848077542149, 0.13534288911614567, 0.10582882634480484, 0.25617037899792194, 0.31797136121895164, 0.1962984909187071, 0.17067434324417263, 0.09918892756104469, 0.09639109019190073, 0.09348641324322671, 0.1725458021974191, 0.16641705762594938, 0.20499672886217013], [0.025660850587883033, 0.0705374481913168, 0.05487551985424943, 0.025353911296406295, 0.039190191600937396, 0.049781377383624204, 0.0813948386348784, 0.0072311349049414275, 0.054155900070327334, 0.03866536331770476, 0.011576217984838877, 0.041989758174167946, 0.029677561615244485, 0.028081192685931455, 0.05470295938721392, 0.01713388362986734, 0.03439763197093271, 0.06658866594079882, 0.061518079237430356, 0.010049637839983916, 0.05479301529703662, 0.048871938488446176, 0.030729990103282034, 0.0344070832215948, 0.026923785553663038, 0.017568335024407133, 0.012303105249884538, 0.09625294682336971, 1.4125708770006895, 17.9646323248744, 44.4541148096323, 51.93075321614742, 44.87633675336838, 33.941728100180626, 31.042394377291203, 30.220276191830635, 25.892471820116043, 8.606865908950567, 0.8647204306907952, 0.13854865537723526, 0.5219680164009333, 2.559804366901517, 4.166537225246429, 3.481186288408935, 6.471715355291963, 6.0502528958022594, 4.767971802502871, 11.376771926879883, 22.15637169778347, 33.272724598646164, 50.575172156095505, 54.14083242416382, 53.45192179083824, 56.94508954882622, 50.87407931685448, 51.899936869740486, 49.350368678569794, 44.96463641524315, 38.7819691747427, 41.87047004699707, 44.632405042648315, 48.4819670766592, 50.05764752626419, 51.45872354507446, 49.53702986240387, 47.55480922758579, 48.68696987628937, 49.02107074856758, 50.426102355122566, 51.58439040184021, 48.395616710186005, 47.03728459775448, 38.052431121468544, 35.117153227329254, 36.973433420062065, 40.39484962821007, 36.757502406835556, 39.47999931871891, 39.39378194510937, 41.530544087290764, 43.732541128993034, 46.267290115356445, 46.033857241272926, 47.80681550502777, 48.752147778868675, 50.0285866856575, 49.02865134179592, 50.3661035746336, 46.916637271642685, 36.458629444241524, 49.24937389791012, 49.756266698241234, 48.239163905382156, 47.316094636917114, 42.15223632752895, 42.34021604061127, 37.36008167266846, 34.99955713748932, 34.196033254265785, 38.50763909518719, 37.28353098034859, 35.600228905677795, 36.26029148697853, 36.58593401312828, 37.13370501995087, 40.40764734148979, 44.1823647916317, 47.42563135921955, 47.75434412062168, 50.87009713053703, 49.53435480594635, 48.12630996108055, 49.9192513525486, 50.01333810389042, 49.283792451024055, 44.925384521484375, 35.97195915877819, 38.19401152431965, 49.551518484950066, 49.52675901353359, 51.229022070765495, 50.7404974848032, 53.75761918723583, 50.878209695219994, 49.70108985900879, 55.44131264090538, 53.93112927675247, 52.55827434360981, 46.20044410228729, 40.64794264733791, 24.107682891190052, 13.470809161663055, 6.598700266331434, 1.4651984092779458, 9.314999710768461, 4.4587538950145245, 3.6239460529759526, 6.138987634330988, 4.531329525634646, 2.3050921596586704, 0.876731111202389, 0.05664979085850064, 1.3824129640124738, 4.83140179887414, 25.770648457109928, 43.23896661400795, 39.84371580183506, 34.623548313975334, 50.408547297120094, 48.18418085575104, 25.65196182578802, 2.0726536447182298, 0.04325901623815298, 0.034793864615494385, 0.0540209034079453, 0.0626064054085873, 0.00743560447517666, 0.022018725612724666, 0.0653574281022884, 0.06608626907109283, 0.05512538613402285, 0.04614847173797898, 0.023543942988908384, 0.080590298603056, 0.046454856274067424, 0.0574780870374525, 0.028936603230249602, 0.061637308972422034, 0.0623637528042309, 0.04403749204357155, 0.012180767771496903, 0.027959254111920018, 0.058555050927679986, 0.0306153765268391, 0.04785753022588324, 0.011760618490370689, 0.0509449424862396, 0.09593492170097306, 0.05154651997145265, 0.008017570708034327, 0.03867792045639362, 0.12241440199431963, 0.04100355894479435, 0.0357590573548805, 0.06234915475943126, 0.04187001635727938, 0.029733562223555055, 0.04199877897917759, 0.025435356437810697, 0.045659990137210116, 0.10442508370033465, 0.017630671718507074, 0.03428594245633576, 0.01637184454011731, 0.058468327260925435, 0.02443877270707162, 0.07132131198886782, 0.06320983084151521, 0.05869554319360759, 0.011177275573572842, 0.02170428506360622, 0.010901580699282931, 0.05061225252575241, 0.02071073671686463, 2.210516184568405, 22.11042456328869, 50.609309524297714, 56.64413809776306, 49.25731547176838, 38.18412825465202, 38.58117274940014, 35.10309398174286, 27.463505119085312, 9.033646658062935, 0.9921636921353638, 0.15895589080173522, 0.7197070901747793, 2.509460630826652, 5.599759519100189, 7.822471149265766, 5.117443324998021, 4.915174953639507, 5.199112817645073, 12.681734953075647, 23.634857162833214, 34.67791959643364, 50.1181934773922, 55.60759551823139, 55.02309188246727, 56.32843963801861, 52.31167137622833, 51.86041139066219, 51.49467721581459, 47.22064755856991, 40.47645024955273, 43.88861395418644, 47.50000096857548, 50.80654554069042, 52.98321694135666, 51.84658773243427, 50.40622942149639, 48.373057320714, 50.44055677950382, 51.46574556827545, 51.26797758042812, 53.79565894603729, 50.41243448853493, 49.171603471040726, 39.717828556895256, 37.00667783617973, 38.78124341368675, 42.05126814544201, 37.651465237140656, 41.16461232304573, 40.384787768125534, 43.97233486175537, 46.59989766776562, 47.72532507777214, 48.730872720479965, 51.111817359924316, 50.54436720907688, 51.91882185637951, 51.281732842326164, 52.203901559114456, 49.51666675508022, 38.231686502695084, 51.331958547234535, 52.314426228404045, 49.93766136467457, 48.20570670068264, 43.97306442260742, 43.93802270293236, 39.092636704444885, 36.947587206959724, 35.58950588107109, 39.65940669178963, 38.090197294950485, 37.00817495584488, 37.86671608686447, 37.545492723584175, 37.53637321293354, 43.5030410438776, 46.48222558200359, 49.373110458254814, 50.49707494676113, 52.843874618411064, 52.05980949103832, 49.32093545794487, 51.025960966944695, 52.66724109649658, 51.19842231273651, 47.149469777941704, 38.2993570715189, 39.36337597668171, 50.111589431762695, 52.47513100504875, 54.09437611699104, 54.230199828743935, 54.86565113067627, 52.84726783633232, 53.2067209482193, 56.56777739524841, 55.320216938853264, 53.26606996357441, 49.453434348106384, 41.162412241101265, 25.065096616744995, 14.446993879973888, 6.471360074356198, 3.243796876631677, 9.273853618651628, 8.629296105355024, 5.540638966485858, 5.761798974126577, 5.26017839089036, 1.9266188121400774, 0.7897743210196495, 0.09934393994626589, 1.1723034759052098, 6.554228877648711, 28.423823788762093, 45.97098581492901, 34.94719594717026, 34.48625028133392, 57.250870540738106, 53.171774223446846, 28.671977072954178, 3.0624012602493167, 0.009296498956246069, 0.02783771629765397, 0.0391943958675256, 0.06191484251758084, 0.06534429950988851, 0.038352562914951704, 0.0019193214484403143, 0.04054131597513333, 0.013946539329481311, 0.03576167713617906, 0.023498061564168893, 0.040819231726345606, 0.094359408976743, 0.0301563823086326, 0.028811519805458374, 0.04432652145624161, 0.020923167212458793, 0.02479385326296324, 0.036755034379893914, 0.03792101146245841, 0.0457621541863773, 0.02380411769991042, 0.10014957093517296, 0.02951777722046245, 0.10724927473347634, 0.31347195734269917, 0.1251723340828903, 0.22203166008694097, 0.16959334578132257, 0.2604064391925931, 0.18567580467788503, 0.20656128006521612, 0.16638588742353022, 0.20157471561105922, 0.12352291829301976, 0.2055581338936463, 0.11963928918703459, 0.16931333346292377, 0.2099230606108904, 0.08500618117977865, 0.11534758275956847, 0.08758932264754549, 0.14044016716070473, 0.14870122075080872, 0.14478073659120128, 0.19112351001240313, 0.1847632450517267, 0.06450114553445019, 0.11558598285773769, 0.11390895175281912, 0.22648698039120063, 0.1068651168316137, 2.510153381153941, 25.135755725204945, 57.0411179959774, 62.180368825793266, 56.651927679777145, 45.739384442567825, 41.5691652148962, 41.869846880435944, 32.76569880545139, 11.585185993462801, 1.4212265750393271, 0.5512192624155432, 1.8274433026090264, 7.692984072491527, 11.900136843323708, 10.047837886959314, 13.062951397150755, 12.252209801226854, 6.847982089966536, 15.018548760563135, 27.306453846395016, 36.49644881486893, 53.405104503035545, 58.308893367648125, 56.30882889032364, 57.809022590518, 54.13235507905483, 55.56793324649334, 53.76489579677582, 50.242879986763, 41.485516503453255, 46.10552899539471, 49.58536706864834, 55.007197335362434, 55.369515493512154, 54.20897036790848, 50.84292858839035, 48.851843029260635, 50.37643902003765, 51.19885928928852, 51.78033448755741, 55.38279578089714, 53.07413846254349, 52.21356064081192, 41.11203074455261, 38.156724125146866, 40.633495822548866, 43.95840860903263, 40.022272020578384, 43.21142569184303, 43.31853814423084, 45.4636674374342, 47.48769722878933, 49.075749814510345, 49.62165132164955, 51.868755742907524, 52.6094575971365, 54.53740194439888, 52.46834836900234, 55.09381748735905, 48.936548084020615, 43.65366496145725, 51.83142274618149, 53.86488363146782, 51.72411270439625, 50.268300622701645, 45.816364511847496, 47.98097915947437, 41.03959523141384, 37.961585596203804, 37.020425498485565, 41.817196905612946, 40.494560077786446, 38.29852871596813, 39.88374665379524, 39.898531660437584, 40.04195116460323, 46.39156624674797, 48.17432798445225, 51.937076076865196, 52.49636046588421, 54.53017093241215, 51.83456897735596, 48.4565806388855, 50.23390866816044, 53.4618316590786, 53.73217195272446, 49.54424947500229, 39.79768507182598, 42.2422268986702, 53.9531072974205, 54.225860461592674, 54.772065952420235, 55.47964498400688, 56.0910701751709, 55.335799902677536, 54.154952466487885, 58.77589590847492, 57.08312854170799, 54.74700629711151, 49.797042310237885, 43.6488202214241, 26.72087486833334, 18.51058892905712, 10.028424728661776, 6.949160685762763, 19.583607651293278, 13.349165339022875, 10.237587355077267, 14.59700983017683, 12.248209565877914, 5.74199253693223, 2.4942286731675267, 0.2333223682944663, 1.9071866548620164, 6.611193045973778, 32.49791197478771, 50.15662841498852, 48.61709162592888, 49.31557394564152, 61.10360160470009, 60.74498064815998, 32.71281324326992, 4.4120411016047, 0.150852692022454, 0.19468308775685728, 0.08166290979715995, 0.21915059827733785, 0.1815875803004019, 0.15069817687617615, 0.09237708058208227, 0.1494568755151704, 0.17112405505031347, 0.14588895603083074, 0.0786441721720621, 0.13555322861066088, 0.19499701622407883, 0.11009926281985827, 0.08557780558476225, 0.1785666384967044, 0.14476108452072367, 0.12590697122504935, 0.09294986273744144, 0.10403225009213202, 0.15866024885326624, 0.14463356870692223, 0.2583127812249586, 0.13223979156464338], [0.005519289652511361, 0.020370797828945797, 0.03757959384529386, 0.03649170554126613, 0.0363187294715317, 0.057655315613374114, 0.03674953135487158, 0.0684547443233896, 0.0230410358926747, 0.06860007910290733, 0.13607348897494376, 0.04462747718207538, 0.004334002351242816, 0.027984405496681575, 0.020350796949060168, 0.036277885374147445, 0.03703322472574655, 0.055214848325704224, 0.03821407815848943, 0.10252545282128267, 0.07458417909219861, 0.03469985676929355, 0.029172385402489454, 0.04900951040326618, 0.017881415587908123, 0.03687570759211667, 0.10343525165808387, 0.03736264923645649, 0.5368223693221807, 10.43195167556405, 36.48593857884407, 47.26491138339043, 43.31533491611481, 37.77662672102451, 26.450099498033524, 34.11268472671509, 19.5202574506402, 10.517624728381634, 1.9131504348479211, 0.19947921711718664, 0.42259209731128067, 0.5464461247902364, 3.500684229657054, 5.015028845518827, 3.3366391947492957, 3.8408293901011348, 4.5192124508321285, 10.80536238849163, 20.87849646806717, 32.98075206577778, 43.77553202211857, 55.72570078074932, 51.80728264153004, 48.34326311945915, 48.36621768772602, 52.406369894742966, 49.53492097556591, 44.78118605911732, 39.082210063934326, 41.021006628870964, 46.74568444490433, 49.725826531648636, 51.1160047352314, 54.11246694624424, 50.2037762850523, 48.337107449769974, 50.77088065445423, 50.86005046963692, 51.1652272939682, 48.293014615774155, 47.30861283838749, 39.99702997505665, 36.28605790436268, 37.103827223181725, 38.04241105914116, 37.275099232792854, 38.72089125216007, 40.00194311141968, 38.65349426865578, 40.72281762957573, 41.51795156300068, 44.1162483394146, 42.7777473628521, 46.075180023908615, 45.71956470608711, 47.65284016728401, 46.72857016324997, 51.785654202103615, 47.950728982687, 36.30566105246544, 47.87889763712883, 50.67440763115883, 50.16073979437351, 49.211220145225525, 48.14623989164829, 45.053867027163506, 44.16868172585964, 41.22405633330345, 38.001787438988686, 35.98193742334843, 35.893972143530846, 35.522640869021416, 35.605142042040825, 35.29468350112438, 39.08451274037361, 42.98384070396423, 49.038637205958366, 49.50310908257961, 50.704030841588974, 48.53655494749546, 47.22948968410492, 48.54629762470722, 50.93734972178936, 51.60131849348545, 50.64493641257286, 45.647011399269104, 35.63604578375816, 42.46603488922119, 49.37268108129501, 51.164699122309685, 49.32308994233608, 50.216600596904755, 49.95410308241844, 52.55788296461105, 49.06411483883858, 51.06953702867031, 55.58405198156834, 51.25577263534069, 50.94478592276573, 35.92019833624363, 23.850299902260303, 9.469336029142141, 5.099940514191985, 2.7195451827719808, 7.496668556705117, 8.248540386557579, 2.6771271089091897, 3.9250753819942474, 1.8669324461370707, 1.5781699097715318, 0.21967507404042408, 0.2838018728652969, 1.4432837977074087, 10.35612864419818, 19.396632984280586, 53.705827966332436, 52.304812744259834, 44.99931335449219, 43.25278267264366, 49.29757431149483, 15.240823533385992, 1.088043472263962, 0.040879041407606564, 0.07312321686185896, 0.05307021223416086, 0.03593192210246343, 0.04690684647357557, 0.02753864748228807, 0.06576180210686289, 0.005977262026135577, 0.004596008311636979, 0.05799510792712681, 0.04122848535189405, 0.00572689386899583, 0.08175165581633337, 0.050807645166059956, 0.11341682620695792, 0.04339961982623208, 0.022655033753835596, 0.04662310115236323, 0.056917494657682255, 0.05894851536140777, 0.09723357623443007, 0.04108685388928279, 0.059681052225641906, 0.01015485211610212, 0.018553309710114263, 0.03947688324842602, 0.06080358027247712, 0.035216079850215465, 0.09167108291876502, 0.06318098356132396, 0.05438302694528829, 0.03398797016416211, 0.05664329706632998, 0.008970516155386576, 0.0288236205233261, 0.053133984984015115, 0.07237478319439106, 0.06101078790379688, 0.0500622543040663, 0.02997225361468736, 0.011054003916797228, 0.032072379399323836, 0.06899441927089356, 0.05284183112962637, 0.018421491295157466, 0.008721224112377968, 0.06186105907545425, 0.04631449017324485, 0.015003848366177408, 0.04989231732906774, 0.05266718893835787, 0.03410951168916654, 0.6735944864340127, 14.001668225973845, 42.933497205376625, 55.08114516735077, 47.594969272613525, 40.241094678640366, 30.81535466015339, 38.047878965735435, 28.22774861007929, 11.796000581234694, 1.8494757078588009, 0.06092771189287305, 0.21591815922874957, 1.9097876152954996, 4.3514457531273365, 6.396854147315025, 7.4068499263376, 5.928759165108204, 5.379522861912847, 11.90922025591135, 24.085568077862263, 35.288391038775444, 45.99797576665878, 53.97447355091572, 52.67242021858692, 50.98286747932434, 51.451127752661705, 53.28277386724949, 53.793637454509735, 49.02984447777271, 41.30238153040409, 43.566543236374855, 49.32043008506298, 51.56420588493347, 53.06156873703003, 53.99533823132515, 50.95509096980095, 49.05211888253689, 50.18184386193752, 50.68623259663582, 53.603765442967415, 49.01348255574703, 49.74313460290432, 42.5926972925663, 37.74851582944393, 38.533644899725914, 39.06280070543289, 39.69784922897816, 39.952933341264725, 42.31137938797474, 40.75518049299717, 43.60771022737026, 44.0353886783123, 45.974911004304886, 46.6352965682745, 47.411572113633156, 48.025527969002724, 48.824564293026924, 49.255168586969376, 52.50969775021076, 50.47503612935543, 39.257460460066795, 48.96865256130695, 52.81911514699459, 52.29923464357853, 51.82661980390549, 50.17431266605854, 47.01239213347435, 46.166264936327934, 41.42954170703888, 39.13394808769226, 38.43949355185032, 36.89222797751427, 37.31650561094284, 38.31193819642067, 37.699065282940865, 42.001658007502556, 45.404242426157, 50.39555959403515, 51.5085768699646, 52.906928434967995, 49.3101554363966, 48.91059547662735, 49.96043734252453, 51.53437748551369, 54.285201877355576, 52.926824167370796, 47.99726128578186, 38.0953536182642, 42.96632744371891, 50.58499462902546, 52.13426269590855, 50.651825442910194, 50.694504752755165, 51.39069579541683, 52.406882867217064, 51.6550400108099, 56.4785847812891, 56.93234123289585, 53.04504342377186, 51.20848037302494, 39.27088513970375, 26.18667483329773, 11.934326458722353, 5.152068492025137, 2.930343858897686, 6.773415366187692, 7.709011612460017, 5.380476135760546, 7.027847338467836, 2.787760547362268, 2.194714257493615, 0.4469612881075591, 0.13140426686732098, 1.4269778039306402, 10.221534166485071, 22.203513868153095, 54.56668317317963, 58.17996248602867, 48.61823156476021, 49.32405509054661, 54.19695541262627, 20.472657345235348, 1.237586229108274, 0.032083370606414974, 0.008872130565578118, 0.05640298593789339, 0.012238772178534418, 0.011804174209828489, 0.028701663395622745, 0.05627665013889782, 0.04896955317235552, 0.03984285482147243, 0.04408576132846065, 0.047059261341928504, 0.07622770965099335, 0.017823318412411027, 0.033733732634573244, 0.039727944385958835, 0.06564279130543582, 0.02193250289565185, 0.007503382503273315, 0.011622020556387724, 0.03754878729523625, 0.0679568448686041, 0.07052441607811488, 0.0903579565056134, 0.008163621660060016, 0.14076862687943503, 0.11945387843297794, 0.14841046213405207, 0.13489945587934926, 0.17202019836986437, 0.13410474930424243, 0.1427030941704288, 0.16092816309537739, 0.18095565639669076, 0.23754701425787061, 0.15039131365483627, 0.1653644398902543, 0.15614488773280755, 0.20615945162717253, 0.1270052310428582, 0.12678286875598133, 0.1321514166193083, 0.1621053132112138, 0.14721078041475266, 0.2299591331393458, 0.1397456059930846, 0.11272782372543588, 0.14784463390242308, 0.14696838014060631, 0.061766780345351435, 0.15593956515658647, 0.2526281081372872, 0.1119142072275281, 0.85096136899665, 14.903678074479103, 48.75480763614178, 60.19806079566479, 55.82602679729462, 48.887010142207146, 36.40099793672562, 45.53817383944988, 28.649921156466007, 14.253278374671936, 2.6109736086800694, 0.5011747009120882, 1.786754373461008, 4.223375525325537, 11.10905634239316, 16.00786082446575, 9.903528280556202, 7.9707638919353485, 7.592850895598531, 15.978135019540787, 26.49345327168703, 38.22299636900425, 47.6982781291008, 54.307119101285934, 53.88122275471687, 53.84611263871193, 54.03536908328533, 56.023992374539375, 56.351914778351784, 48.800769969820976, 44.18113365769386, 44.979486018419266, 51.57621704041958, 53.9871496707201, 57.55964197218418, 55.69561019539833, 51.94208420813084, 49.17905867099762, 51.55116878449917, 53.32966335117817, 55.48092171549797, 51.275140196084976, 51.331365779042244, 44.92604188621044, 39.613535553216934, 41.77264429628849, 40.860412046313286, 41.520007252693176, 42.30933889746666, 43.96990679204464, 42.350350096821785, 45.178857520222664, 46.108109056949615, 48.06294076144695, 47.90624476969242, 50.0141816586256, 50.2494840323925, 52.05099396407604, 49.878969714045525, 55.27722604572773, 52.04760454595089, 41.06360614299774, 50.470863953232765, 54.870381876826286, 55.952879190444946, 53.99373471736908, 51.22603163123131, 49.69264671206474, 47.782234624028206, 44.907582476735115, 42.81472697854042, 39.35726970434189, 39.360172748565674, 39.2939119040966, 40.19357442855835, 38.445827811956406, 43.89858081936836, 46.35167598724365, 53.34809236228466, 53.54364886879921, 53.91909912228584, 51.365229561924934, 49.50491398572922, 49.75401721894741, 53.52765932679176, 55.38215361535549, 56.353484094142914, 49.94478978216648, 39.892683774232864, 46.18681043386459, 53.622962012887, 54.246991127729416, 51.17243550717831, 50.80477103590965, 52.04814791679382, 52.76371791958809, 52.35522083938122, 56.872859224677086, 58.75805206596851, 54.92340423166752, 55.01909829676151, 38.92407774925232, 27.840876169502735, 11.86990661546588, 8.92598133534193, 8.195877112448215, 15.413291528820992, 15.697540026158094, 11.514244750142097, 12.611277233809233, 6.808950584381819, 4.101245328783989, 0.8877365675289184, 0.4799864738015458, 1.7144877137616277, 13.442287892103195, 25.015995651483536, 65.73664739727974, 60.83144120872021, 56.53979949653149, 57.09165908396244, 61.1921064555645, 24.381988272070885, 2.270914656110108, 0.09569737507263198, 0.19692406203830615, 0.21386724896728992, 0.10611407822580077, 0.1589397416682914, 0.1306938979541883, 0.14050385827431455, 0.10871929858694784, 0.155719191825483, 0.14960162399802357, 0.11451458878582343, 0.13283762120408937, 0.09361758042359725, 0.10124849126441404, 0.2171674312558025, 0.2181115173152648, 0.12404288921970874, 0.1621972059365362, 0.14302340510766953, 0.16671198711264879, 0.2004105827654712, 0.19016057340195403, 0.15418466791743413, 0.05476290636579506], [0.028132812767580617, 0.05322028562659398, 0.010619898548611673, 0.015183178147708531, 0.0551375462237047, 0.023580376873724163, 0.026019961005658843, 0.046018503126106225, 0.011760472843889147, 0.02801472965074936, 0.021867856266908348, 0.09996430861065164, 0.045054264046484604, 0.01594596866198117, 0.016621345312159974, 0.05994462968374137, 0.06813838903326541, 0.039497028847108595, 0.032267111528199166, 0.054046422155806795, 0.009579811976436758, 0.016543755627935752, 0.006950392498765723, 0.052373784565133974, 0.03258987155277282, 0.06129933492047712, 0.03275173396104947, 0.059427723826956935, 0.08134466203046031, 4.639488346874714, 25.50844732671976, 47.15119868516922, 43.569750264286995, 44.65678833425045, 35.425381287932396, 23.542012944817543, 36.21570087969303, 20.479679368436337, 3.1635371083393693, 0.32596007629763335, 0.1762751239584759, 1.613373002037406, 3.1657635513693094, 6.277765212580562, 5.847765561193228, 4.083107952028513, 5.11130902916193, 8.098460789769888, 20.38026150316, 33.06387260556221, 53.92705589532852, 58.137123584747314, 47.299861907958984, 48.83228547871113, 53.736868500709534, 48.921489492058754, 48.498253002762794, 43.84392835199833, 37.61003986001015, 42.70169444382191, 49.34838518500328, 50.66566430032253, 51.656974107027054, 47.27752670645714, 48.16929705440998, 47.38217309117317, 52.49249987304211, 51.03095769882202, 48.61103855073452, 46.42201401293278, 40.732408314943314, 37.27727651596069, 34.680093079805374, 36.60624772310257, 38.93154054880142, 40.9525191038847, 40.35053260624409, 36.428926438093185, 36.84541068971157, 38.89247864484787, 38.94034847617149, 38.922272846102715, 38.93876776099205, 42.48644359409809, 44.04058679938316, 47.57854275405407, 46.649975180625916, 51.51434116065502, 47.95662246644497, 32.37686187028885, 48.33805359899998, 48.23985926806927, 48.701048120856285, 45.191146060824394, 49.310622811317444, 48.61359961330891, 47.39595115184784, 46.51716850697994, 44.95512552559376, 35.171152129769325, 36.31483756005764, 36.93165846168995, 36.18082635104656, 36.859682723879814, 38.68107698857784, 45.27392841875553, 50.14327973127365, 50.612106174230576, 48.07127371430397, 47.72722877562046, 49.01553064584732, 47.448274344205856, 50.78224204480648, 49.6211763471365, 46.05722218751907, 43.3409683406353, 36.48429326713085, 40.77726490795612, 46.61756291985512, 50.02513267099857, 50.81565365195274, 51.645407527685165, 52.84606710076332, 54.008333534002304, 56.08791634440422, 45.393109023571014, 54.59790609776974, 46.678564846515656, 47.84753791987896, 34.992162734270096, 17.96391986310482, 10.142674148082733, 4.365355856716633, 1.0935940244235098, 4.803678011521697, 5.9487788658589125, 3.359956406056881, 3.1612531933933496, 3.509617787785828, 0.7225330104120076, 0.30195468629244715, 0.19425785198109224, 2.0835592970252037, 14.135349802672863, 28.032309897243977, 26.154709048569202, 30.044835805892944, 37.87676654756069, 48.31956759095192, 32.56741784512997, 10.565854590386152, 1.0004453477449715, 0.07473401870811358, 0.06865402581752278, 0.025869394085020758, 0.027302713169774506, 0.052225896797608584, 0.0303782770424732, 0.07080902229063213, 0.012682933647738537, 0.022519358026329428, 0.059642286141752265, 0.05424130642495584, 0.04125288345676381, 0.016001147341739852, 0.033025771990651265, 0.06427711341530085, 0.023191042491816916, 0.016287931757688057, 0.03816410564468242, 0.03362017290783115, 0.02681249679881148, 0.034588159833219834, 0.06224269367521629, 0.02965483519801637, 0.11076312133809552, 0.06594342048629187, 0.049439469948993064, 0.022817037170170806, 0.048692216296331026, 0.016564917968935333, 0.03718572865182068, 0.050067790725734085, 0.04889475581876468, 0.05759895320807118, 0.030444931180682033, 0.03980097171734087, 0.06763501252862625, 0.03735181388037745, 0.08552063052775338, 0.0469664631964406, 0.043309237371431664, 0.03419328531890642, 0.012640778732020408, 0.014020443322806386, 0.06994778959779069, 0.09591491339961067, 0.05247207831416745, 0.048230774846160784, 0.03914457920473069, 0.07670684761251323, 0.10294406121829525, 0.06897027720697224, 0.06375527969794348, 0.14967616531066597, 6.631311541423202, 30.538999289274216, 51.87522679567337, 49.59708943963051, 49.886086732149124, 37.128609493374825, 28.736949786543846, 30.915192402899265, 20.286032259464264, 3.6136704543605447, 0.24809838010696694, 0.01836555005866103, 1.6053280024789274, 3.6245651822537184, 5.723417233675718, 4.846290349960327, 4.500570651143789, 4.1588169895112514, 8.675263188779354, 20.785718746483326, 33.00680726766586, 50.94605125486851, 59.10888344049454, 50.187881737947464, 51.00233383476734, 55.4280399531126, 50.39057046175003, 52.40508556365967, 45.943114310503006, 40.228179171681404, 43.98822940886021, 49.98064465820789, 52.61613003909588, 52.21079058945179, 49.34238150715828, 48.84271211922169, 48.78864862024784, 53.44380162656307, 53.695743307471275, 50.83366468548775, 49.171071499586105, 44.47741895914078, 38.04806515574455, 36.19609773159027, 37.65414409339428, 40.72214886546135, 43.68713356554508, 41.63144767284393, 38.49711745977402, 39.63055483996868, 40.67062363028526, 41.01862795650959, 42.51390852034092, 42.033059522509575, 44.72216382622719, 46.286969259381294, 49.60202157497406, 49.27728720009327, 53.6007522046566, 50.120515152812004, 35.24645648896694, 48.538565039634705, 48.70356358587742, 50.596713200211525, 47.05465726554394, 52.732210010290146, 51.467299684882164, 49.83716055750847, 48.70376117527485, 45.983107164502144, 37.41021238267422, 37.330811843276024, 39.542285576462746, 38.44301216304302, 38.89601245522499, 40.543129071593285, 47.190784960985184, 51.06981061398983, 51.950238570570946, 49.59839656949043, 47.86428742110729, 50.368691235780716, 48.10976944863796, 51.99374243617058, 52.537329867482185, 48.24313089251518, 45.436920672655106, 37.67727345228195, 42.15017683804035, 49.01944063603878, 53.166997879743576, 52.018984481692314, 52.007296308875084, 53.20012830197811, 54.25673000514507, 55.76371394097805, 49.77933146059513, 56.79811343550682, 51.68743707239628, 51.46378107368946, 37.47060254216194, 20.18158346414566, 10.520242787897587, 4.633277105167508, 3.084298772737384, 4.686246737837791, 6.689418973401189, 5.3148427326232195, 6.10152211971581, 3.0587285198271275, 0.6578294886276126, 0.3888008667854592, 0.38371593807823956, 1.9152075494639575, 14.362888243049383, 29.986740723252296, 34.11796644330025, 37.45716646313667, 43.78107212483883, 54.28524747490883, 38.910611271858215, 13.154341243207455, 1.2448018044233322, 0.041811939590843394, 0.06995256160735153, 0.02925578610302182, 0.10152434755582362, 0.04064964356075507, 0.022938565707590897, 0.050106156049878336, 0.01769943170074839, 0.00986958724752185, 0.060786681569879875, 0.018273909663548693, 0.03009745207236847, 0.021324717345123645, 0.03556939780537505, 0.028044916507496964, 0.045811514428351074, 0.021842446985829156, 0.03513186835334636, 0.08824374846881256, 0.014071109744691057, 0.04779277413035743, 0.0682775120367296, 0.022484866713057272, 0.036623774431063794, 0.16425617592176422, 0.09014371331431903, 0.06590805714949965, 0.1254638348473236, 0.11171239500981756, 0.2651507221162319, 0.18618756002979353, 0.14591046347049996, 0.17854357254691422, 0.10311327831004746, 0.08994507006718777, 0.22807100554928184, 0.1504720444791019, 0.12535110261524096, 0.27251042251009494, 0.1243172018439509, 0.10986654015141539, 0.11346023442456499, 0.05200183870329056, 0.1482680588378571, 0.18536393938120455, 0.1396651571849361, 0.09447309115785174, 0.15912495204247534, 0.13160758564481512, 0.2581262943567708, 0.1811210811138153, 0.11893330636667088, 0.3037095390027389, 8.32156676799059, 35.29330037534237, 58.677002415061, 57.399108186364174, 55.63971899449825, 45.35139486193657, 33.74375492334366, 45.98669797182083, 23.9515283703804, 4.589304914698005, 0.5642274487763643, 0.9146127034910023, 4.107573414221406, 8.307985346764326, 16.662081219255924, 13.28900221735239, 10.592513009905815, 10.383547972887754, 11.778020896017551, 24.413536079227924, 35.57257018983364, 55.45259043574333, 59.30537089705467, 51.73914849758148, 51.07492133975029, 56.458651050925255, 52.782906889915466, 53.5216024518013, 47.71277815103531, 41.685955747962, 46.17947302758694, 53.03026221692562, 55.76537065207958, 53.611482828855515, 49.73176561295986, 50.328660383820534, 50.77172800898552, 54.227266386151314, 56.00692369043827, 52.328455075621605, 51.465764567255974, 44.745726361870766, 40.43062850832939, 38.102987408638, 39.8981174826622, 42.812758684158325, 45.39332181215286, 46.221893951296806, 38.96146014332771, 42.08220608532429, 42.43299566209316, 43.484418243169785, 44.01968792080879, 43.259447515010834, 46.48072846233845, 47.65256278216839, 52.301598116755486, 52.328462675213814, 57.234235033392906, 51.836316883563995, 39.05882231891155, 48.38618561625481, 49.42859128117561, 51.22266501188278, 48.10277782380581, 55.8209540694952, 53.40562127530575, 52.441115230321884, 50.59526167809963, 50.14085166156292, 39.47399564087391, 39.01360094547272, 40.70887617766857, 40.778431445360184, 40.892850905656815, 42.45033033192158, 49.114705324172974, 54.057031720876694, 54.25108350813389, 49.89141404628754, 48.07012237608433, 50.598719492554665, 48.67397837340832, 52.81373843550682, 53.61046448349953, 49.19489622116089, 48.311109244823456, 40.648406222462654, 44.52131800353527, 50.92001885175705, 54.09091830253601, 55.62928095459938, 55.407889634370804, 55.86304821074009, 55.11486455798149, 57.354019805788994, 51.24705970287323, 57.954429388046265, 54.78229880332947, 52.89710596203804, 39.958834424614906, 20.393051616847515, 13.133534509688616, 6.603271421045065, 4.9680286925286055, 14.298021923750639, 14.987703915685415, 10.710030253976583, 10.600084103643894, 9.196883048862219, 3.098824918270111, 0.8623801125213504, 0.46064191963523626, 2.6170879555866122, 17.75824259966612, 36.62242345511913, 35.807807967066765, 43.1707488745451, 48.428606539964676, 62.02422000467777, 43.71275559067726, 17.011231184005737, 1.7774879769422114, 0.09502219880232587, 0.14688845083583146, 0.12728272005915642, 0.17759467737050727, 0.1328900465159677, 0.07127139513613656, 0.16143144312081859, 0.138062474434264, 0.17898106860229746, 0.291336927912198, 0.13597997836768627, 0.10736060430645011, 0.10410085422336124, 0.15397259179735556, 0.22046997357392684, 0.15434363594977185, 0.17347350163618103, 0.12872879480710253, 0.15968646097462624, 0.15854362776735798, 0.1858415559399873, 0.1632029644679278, 0.08441845217021182, 0.19450918771326542], [0.08622179680969566, 0.07700124275288545, 0.07381776318652555, 0.013942054902145173, 0.04814312720554881, 0.039516079777968116, 0.04150769244006369, 0.023944094173202757, 0.0344021924684057, 0.04758116556331515, 0.07096555607859045, 0.04030812575365417, 0.03405989540624432, 0.03547654028807301, 0.023048041766742244, 0.08063251196290366, 0.002266414871883171, 0.06347445101710036, 0.027814379463961814, 0.03583565812732559, 0.09170459088636562, 0.011093818284280133, 0.04378340294351801, 0.003968412520407583, 0.02814717146975454, 0.004430052958923625, 0.08757556322962046, 0.03820746933342889, 0.04905782421701588, 1.4841769658960402, 20.98465897142887, 48.92217345535755, 49.014968276023865, 52.66686491668224, 41.8808700889349, 53.70553158223629, 55.18128879368305, 25.746386758983135, 5.7954575680196285, 0.5805368861183524, 0.07576910691568628, 0.8652736572548747, 1.890852281358093, 2.3207390075549483, 3.3059366047382355, 3.921132143586874, 2.4023740645498037, 8.212729208171368, 17.19078104943037, 32.50042364001274, 48.42172130942345, 38.148482367396355, 53.05981703102589, 56.148074716329575, 51.73646204173565, 49.05088394880295, 48.328079134225845, 41.40277214348316, 41.23461976647377, 44.595676213502884, 51.66075870394707, 51.37182980775833, 52.43981949985027, 49.17469270527363, 50.110559687018394, 53.60039122402668, 50.8914215862751, 48.808624148368835, 47.27661855518818, 42.3146890103817, 38.44456247985363, 36.75416238605976, 36.23784229159355, 38.73649321496487, 39.584809094667435, 38.7269177287817, 39.163818284869194, 36.58403791487217, 36.0115834325552, 36.09248109161854, 37.257760763168335, 37.08437226712704, 36.52115888893604, 41.05584315955639, 43.498173505067825, 47.175277993083, 45.782325938344, 52.45625741779804, 50.48312209546566, 30.998022258281708, 48.93000863492489, 47.49497763812542, 50.95178134739399, 41.11824341118336, 49.521401301026344, 49.45545203983784, 51.764747723937035, 46.81765638291836, 49.5283967256546, 39.137717485427856, 34.1000048071146, 33.84359076619148, 38.27609471976757, 37.035218104720116, 38.3633304387331, 45.21213613450527, 49.266754165291786, 49.85131859779358, 47.928389981389046, 46.939113065600395, 48.39035779237747, 48.64526331424713, 52.58952006697655, 48.37767407298088, 47.75624021887779, 39.23567242920399, 37.18743033707142, 36.35745607316494, 43.18885110318661, 46.420235708355904, 49.98722590506077, 48.80111575126648, 56.05233505368233, 49.70866285264492, 57.8452954441309, 49.73292455077171, 50.00853516161442, 55.17628066241741, 33.930389508605, 33.218383714556694, 16.65261972695589, 6.912869308143854, 3.0373636912554502, 2.4895941093564034, 1.4102259278297424, 4.243245609104633, 3.2462078472599387, 5.422246344387531, 1.189180389046669, 1.266281339339912, 0.29338950058445334, 0.6267291668336838, 2.8825466986745596, 13.568361327052116, 24.936161935329437, 39.651670306921005, 40.39144121110439, 49.354233071208, 48.80400739610195, 26.881169266998768, 7.753966525197029, 0.1507322266115807, 0.06411332142306492, 0.03684083036205266, 0.0961431312316563, 0.022323922712530475, 0.059991503730998375, 0.07034098685835488, 0.05355358043743763, 0.041881827637553215, 0.04671158370911144, 0.06167285413539503, 0.03808183115324937, 0.022932528336241376, 0.022554702809429727, 0.03990608580352273, 0.051019647071370855, 0.04945237589708995, 0.0407444046868477, 0.02549498800362926, 0.047264435488614254, 0.029130582079233136, 0.05093563966511283, 0.03889593375788536, 0.034626788619789295, 0.1313725474756211, 0.03009614403708838, 0.11679978022584692, 0.025649651579442434, 0.03277757183241192, 0.011947774219152052, 0.02156636619474739, 0.022304676967905834, 0.026893288850260433, 0.07237378129502758, 0.05292769390507601, 0.03558270080247894, 0.09637035458581522, 0.06931064839591272, 0.05371841514715925, 0.024176627593988087, 0.12280282724532299, 0.03698392385558691, 0.040242356626549736, 0.04666477645514533, 0.016123330824484583, 0.07892647772678174, 0.0243896443862468, 0.08492261535138823, 0.01645919903239701, 0.03032236549188383, 0.07902302371803671, 0.0143764543463476, 0.029487955871445592, 0.0229836697326391, 2.4425844568759203, 24.679932184517384, 56.21922589838505, 53.656039237976074, 57.90239877998829, 42.059015929698944, 46.509238332509995, 52.763535529375076, 26.819150894880295, 6.071403985843062, 0.5365560867357999, 0.036206932345521636, 1.1413585301488638, 2.75640819221735, 3.937160396017134, 6.435741735622287, 5.132661033421755, 3.5493237571790814, 8.831485155969858, 20.27628008276224, 35.3752201795578, 52.622669488191605, 45.960547775030136, 53.17523583769798, 57.06774316728115, 54.89672966301441, 51.173617243766785, 50.94694420695305, 42.66681991517544, 41.72203481197357, 46.0642746090889, 52.58024476468563, 53.95029164850712, 54.14157338440418, 48.53316552937031, 49.35882702469826, 54.31116968393326, 52.4090601503849, 51.21011808514595, 48.33507835865021, 45.114963948726654, 40.53295321762562, 38.772241696715355, 37.728160321712494, 40.46834148466587, 42.094509825110435, 40.60065038502216, 41.10574588179588, 37.3809539526701, 37.757308557629585, 38.97263914346695, 38.811660781502724, 39.42269079387188, 39.757145047187805, 40.98891735076904, 45.71592830121517, 50.22502854466438, 47.38847695291042, 53.77459667623043, 50.58891601860523, 35.15539437532425, 48.92737537622452, 47.724489122629166, 52.448053658008575, 42.82058246433735, 49.72591772675514, 50.7541311532259, 51.34288676083088, 48.61760459840298, 51.71979993581772, 40.850893557071686, 35.638903230428696, 36.03749044239521, 39.21626307070255, 38.282212391495705, 40.027606934309006, 47.46706813573837, 49.882203340530396, 51.830039620399475, 48.735314682126045, 48.101162910461426, 49.28187355399132, 51.120948269963264, 55.122346356511116, 51.25621721148491, 49.34029921889305, 40.544922575354576, 37.93015368282795, 38.396973833441734, 44.90197017788887, 49.54140342772007, 51.789488196372986, 51.61833398044109, 56.33784793317318, 51.0127604752779, 57.77949817478657, 51.741663962602615, 53.21659281849861, 56.06682747602463, 39.58574004471302, 35.13144426047802, 18.21434922516346, 8.652344718575478, 3.630134970881045, 4.128406271338463, 5.462041134014726, 5.91913428157568, 6.936525888741016, 4.861015034839511, 2.593127153813839, 1.0316328867338598, 0.28168458491563797, 0.42662932130042464, 3.5837886203080416, 15.798748545348644, 30.161776430904865, 40.55567979812622, 40.90847946703434, 53.147907704114914, 53.73113080859184, 32.40225590765476, 9.931094851344824, 0.306127070216462, 0.04514986379945185, 0.031568546473863535, 0.05113103601615876, 0.0555094067385653, 0.054385197727242485, 0.0674259198422078, 0.04053768687299453, 0.06433511967770755, 0.009586187024979154, 0.02527490782085806, 0.04064480475790333, 0.08008322620298713, 0.03620371142460499, 0.06364137487253174, 0.05930671664827969, 0.04548753728158772, 0.024120613998093177, 0.030694287233927753, 0.06712768779834732, 0.03928162419470027, 0.06651414689258672, 0.023088206799002364, 0.01530087813080172, 0.061466804254450835, 0.15645609993953258, 0.1814500306500122, 0.24621143995318562, 0.09817657875828445, 0.11614395916694775, 0.12383987472276203, 0.10328335629310459, 0.1344478887040168, 0.11928687294130214, 0.11653476671199314, 0.21384007151937112, 0.1537795740296133, 0.11509686300996691, 0.14793504233239219, 0.15023987099993974, 0.30728666111826897, 0.07235007709823549, 0.13551975775044411, 0.08072044904110953, 0.1094744264264591, 0.13962974189780653, 0.1400374184595421, 0.0887178917764686, 0.15851780102821067, 0.056160622771130875, 0.1729010237613693, 0.1526009989902377, 0.20457792008528486, 0.13521034154109657, 3.1070353277027607, 29.195307791233063, 63.142579793930054, 61.51741839945316, 63.01343992352486, 52.1417672932148, 63.85045140981674, 61.098813861608505, 30.257424898445606, 7.071832353249192, 1.1077353218570352, 0.24119168665492907, 3.115072133950889, 5.726581988856196, 7.360515687614679, 10.630569867789745, 10.399346575140953, 4.47271672077477, 10.960471965372562, 25.323769636452198, 39.392398819327354, 57.32930973172188, 50.37184126675129, 55.20833194255829, 57.42995113134384, 57.25503131747246, 53.51705029606819, 53.01900342106819, 45.645776465535164, 45.110172405838966, 48.230260983109474, 56.10300153493881, 54.86315846443176, 54.44713018834591, 49.75149415433407, 48.100760132074356, 55.52335783839226, 54.92865934967995, 54.63090352714062, 50.737860426306725, 46.49382635951042, 42.31455601751804, 40.28303682804108, 40.37354037165642, 43.088775873184204, 43.60083259642124, 43.791924342513084, 43.14045310020447, 39.332939609885216, 38.87215353548527, 40.8137733489275, 40.83568677306175, 41.380839720368385, 41.30347587168217, 43.93789730966091, 47.46185101568699, 52.23692178726196, 50.45360527932644, 55.186608508229256, 53.35466220974922, 38.40494580566883, 49.617357552051544, 46.88178554177284, 52.68914692103863, 42.10220441222191, 50.673461481928825, 51.67927511036396, 55.69049187004566, 49.734512865543365, 54.20874997973442, 43.9901977032423, 37.48012103140354, 37.510956376791, 42.578603848814964, 42.129015773534775, 41.87955915927887, 48.890722543001175, 52.46480315923691, 52.6060301810503, 48.974055871367455, 47.673355266451836, 50.499582812190056, 50.20375348627567, 57.114077880978584, 53.812081664800644, 53.47671926021576, 42.932091280817986, 39.86060589551926, 40.36393068730831, 46.78484134376049, 53.08668538928032, 53.81276562809944, 52.863865345716476, 57.93552540242672, 52.95022331178188, 57.660119980573654, 53.4853295981884, 53.89107942581177, 60.02255581319332, 42.66588896512985, 39.3354968726635, 19.894136488437653, 8.985159359872341, 5.387906162068248, 6.184992715716362, 6.736784856766462, 10.775715429335833, 10.951070319861174, 12.036264538764954, 4.82460206374526, 2.781769693829119, 0.8159996825270355, 0.9086750471033156, 4.441393576562405, 18.208721727132797, 36.35190837085247, 50.87304197251797, 52.95869305729866, 60.82147814333439, 61.20485857129097, 38.02064582705498, 11.455138921737671, 0.3857474634423852, 0.13515479920897633, 0.15079614036949351, 0.14849761995719746, 0.2223793265875429, 0.1916562087717466, 0.18445077119395137, 0.14203465660102665, 0.11239085899433121, 0.15104519028682262, 0.187876035051886, 0.13809723663143814, 0.16564461548114195, 0.12863659037975594, 0.19593218166846782, 0.15918799006612971, 0.15413662127684802, 0.07966993900481611, 0.2126966742798686, 0.17203591705765575, 0.12716991361230612, 0.17891895084176213, 0.09382066913531162, 0.12711612274870276, 0.29843637195881456], [0.035302825781400315, 0.04419760669406969, 0.009249470913346158, 0.06959628619370051, 0.02883236487832619, 0.04770016523252707, 0.04773836728418246, 0.03136098261165898, 0.025117784025496803, 0.06253783096326515, 0.0318351110763615, 0.04823435941943899, 0.032745718854130246, 0.062049520056461915, 0.06537297609611414, 0.03669283498311415, 0.035596040906966664, 0.051831820092047565, 0.0501130246266257, 0.027163842496520374, 0.06058806800865568, 0.02452995668136282, 0.056739230785751715, 0.022497262434626464, 0.014830786949460162, 0.06457004652475007, 0.04745216174342204, 0.06257648201426491, 0.06933060474693775, 1.0874524852260947, 15.914965309202671, 41.49651311337948, 51.16434194147587, 42.03604236245155, 49.51646536588669, 65.383061170578, 64.97773692011833, 30.438743568956852, 6.955943796783686, 1.091600675135851, 0.1838524962658994, 0.6480452511459589, 2.3670428479090333, 2.5631576869636774, 4.0166357439011335, 1.317947879433632, 2.926561636850238, 5.517054107040167, 19.463741183280945, 29.90316040813923, 29.891407638788223, 50.858659744262695, 56.441217586398125, 51.835477128624916, 50.41046619415283, 48.93940173089504, 45.66013589501381, 42.625485733151436, 42.79083386063576, 48.294241949915886, 49.18970189988613, 52.103244960308075, 49.76492643356323, 49.89769510924816, 52.13389411568642, 51.96154676377773, 47.60671064257622, 48.568211048841476, 41.47170044481754, 38.107072189450264, 38.892440646886826, 39.980546459555626, 37.28513069450855, 39.97489996254444, 38.936062306165695, 38.75868782401085, 36.610959470272064, 35.431400164961815, 35.94089962542057, 38.90385143458843, 37.20714747905731, 40.51987051963806, 40.70884197950363, 43.42134162783623, 47.07106478512287, 48.32388035953045, 45.58802716434002, 51.54048755764961, 53.267008513212204, 32.170213758945465, 47.20519758760929, 49.72350865602493, 51.55260130763054, 50.906191393733025, 52.36483812332153, 50.28647504746914, 49.63186517357826, 48.711740747094154, 49.90826614201069, 40.67276671528816, 31.628826409578323, 36.0129551589489, 35.765128657221794, 35.82016110420227, 38.34876962006092, 45.377708449959755, 47.920680195093155, 50.76261229813099, 45.045952051877975, 46.521519273519516, 48.74881915748119, 50.14577999711037, 49.32543441653252, 48.82016412913799, 45.7807832211256, 41.00876368582249, 36.928447633981705, 36.52423292398453, 37.19294384121895, 42.359070628881454, 45.57836428284645, 47.96306312084198, 46.22505538165569, 49.887287467718124, 50.20118102431297, 57.37813711166382, 42.95007951557636, 48.03302876651287, 35.83676241338253, 26.131285205483437, 13.07142399251461, 5.368704842403531, 3.4826489724218845, 2.511592791415751, 3.3561703842133284, 3.402762059122324, 5.323327202349901, 3.515028697438538, 2.0982894441112876, 0.15413271758006886, 0.2637551579391584, 1.0016136663034558, 4.829243514686823, 16.030990183353424, 27.530358731746674, 26.427530609071255, 31.724503375589848, 39.96752455830574, 48.23601767420769, 23.124772533774376, 4.196339026093483, 0.11241175787290558, 0.05460757856781129, 0.07187068680650555, 0.04305167502025142, 0.09631851557060145, 0.006778661381758866, 0.06645947287324816, 0.008688672587595647, 0.05042010307079181, 0.019466772901068907, 0.09380820105434395, 0.04561846326396335, 0.022982690097705927, 0.015968273910402786, 0.016013361237128265, 0.06403226405382156, 0.038921782761462964, 0.04699190772953443, 0.04210145511024166, 0.07802079780958593, 0.04311728829634376, 0.04277888008800801, 0.08848385550663806, 0.06644642591709271, 0.012415832843544194, 0.04140474171435926, 0.0321946222538827, 0.022007237166690174, 0.06351115021971054, 0.021556792489718646, 0.025903794485202525, 0.09839608377660625, 0.014916900199750671, 0.06169657317514066, 0.032893617753870785, 0.012063772828696528, 0.046975936711532995, 0.014139785307634156, 0.005224735878073261, 0.03863834172079805, 0.02517080862162402, 0.06299503103946336, 0.05723095186112914, 0.06296772742643952, 0.02981166027893778, 0.07298420518054627, 0.014793027403356973, 0.04965616964909714, 0.03625953206210397, 0.024446212737530004, 0.04716450159321539, 0.05362229960155673, 0.13369468302698806, 0.08532551990356296, 1.4276187820360065, 19.871879182755947, 47.70954452455044, 57.14583657681942, 48.7212136387825, 53.916511461138725, 68.48357319831848, 68.42057257890701, 37.586036548018456, 9.211850445717573, 1.3140699500218034, 0.16942165733780712, 0.476626266608946, 2.113766963593662, 2.269284543581307, 5.341020002961159, 2.8174851648509502, 2.856889287941158, 6.216590870171785, 23.309678211808205, 33.39850924909115, 38.759877160191536, 51.031911447644234, 57.86809042096138, 54.69719476997852, 52.6329555362463, 53.24699878692627, 47.48416341841221, 44.956349059939384, 44.600247368216515, 48.920949921011925, 51.345884799957275, 54.46497403085232, 52.60512962937355, 49.73547041416168, 51.507330536842346, 53.298866003751755, 51.75009950995445, 50.94860851764679, 44.09940004348755, 41.042342483997345, 40.15611983835697, 42.115484699606895, 39.87219527363777, 40.305014848709106, 42.0498052239418, 40.24899065494537, 38.91100265085697, 37.48130276799202, 38.1689290702343, 39.995817840099335, 40.08547022938728, 40.37180386483669, 42.392197251319885, 44.889883026480675, 49.123349860310555, 49.593912810087204, 50.30792109668255, 52.598514184355736, 52.934883534908295, 36.190759018063545, 47.38976888358593, 48.18039245903492, 51.546339243650436, 51.10778957605362, 53.003374859690666, 51.95075914263725, 52.20065273344517, 51.11494839191437, 51.828128322958946, 41.62300452589989, 34.40815307199955, 37.333118319511414, 38.109610453248024, 37.15977542102337, 40.64949296414852, 48.41282218694687, 50.722357258200645, 52.71865613758564, 46.87774635851383, 46.764531433582306, 49.254636615514755, 51.2090465426445, 51.296688839793205, 49.22516159713268, 48.77380281686783, 42.14003138244152, 39.63221155107021, 39.105894193053246, 40.942020267248154, 45.331324338912964, 47.821045741438866, 49.61238741874695, 50.55901542305946, 51.638461500406265, 51.92386798560619, 56.36720135807991, 47.30873063206673, 51.382355242967606, 37.71697752177715, 28.55223409831524, 14.525217432528734, 6.052713263779879, 4.764649830758572, 5.660538682714105, 4.854016285389662, 5.0957578886300325, 7.437872411683202, 5.585356866940856, 3.457057108171284, 0.8733336185105145, 0.2896629099268466, 0.808752877637744, 4.932219889014959, 16.92174408584833, 33.094635754823685, 34.13219287991524, 39.196352139115334, 46.38740547001362, 53.481199219822884, 27.934132665395737, 5.000188741832972, 0.1454888642183505, 0.0314136750967009, 0.06712698275805451, 0.019670485016831663, 0.043849209178006276, 0.06391827017068863, 0.021570939679804724, 0.03005316812050296, 0.09928873900207691, 0.008848794659570558, 0.07681240327656269, 0.018029102975560818, 0.03215699165593833, 0.04560228073387407, 0.023280588175111916, 0.04868837939284276, 0.05844755454745609, 0.03482287145743612, 0.015175519183685537, 0.01716925067739794, 0.06673359996057115, 0.030894945412001107, 0.060259556339588016, 0.05735735445341561, 0.008025552506296663, 0.10630589371430688, 0.1409685763064772, 0.1048920801258646, 0.201997353869956, 0.17930957284988835, 0.1083256708807312, 0.22402725066058338, 0.11714870837749913, 0.152362042281311, 0.17519215238280594, 0.17146213300293311, 0.12447121232980862, 0.117403962649405, 0.16520468518137932, 0.10357956969528459, 0.16948919277638197, 0.17113337642513216, 0.12718790327198803, 0.1941170368809253, 0.10853531275643036, 0.1571882879943587, 0.1080640044528991, 0.24961700721178204, 0.1627123454818502, 0.18933514191303402, 0.128381751710549, 0.1700818125391379, 0.25247359299100935, 0.19737687602173537, 1.812913950998336, 21.853691339492798, 54.90115262567997, 63.509769290685654, 54.4479775428772, 58.685498759150505, 72.11111694574356, 70.46919465065002, 37.084414064884186, 9.5442053116858, 1.676230060402304, 0.4095166426850483, 1.885211959015578, 5.534937372431159, 7.125625591725111, 8.970014322549105, 4.682909091934562, 5.992256132885814, 12.118540573865175, 34.93051864206791, 37.758722081780434, 42.84367762506008, 52.57532402873039, 61.54163829982281, 54.85334739089012, 56.31842717528343, 54.44679580628872, 49.77867789566517, 46.187239810824394, 47.013991847634315, 51.65253594517708, 53.54907117784023, 55.44421188533306, 53.40472832322121, 48.28990638256073, 53.42653915286064, 55.79606540501118, 52.74796776473522, 53.75237926840782, 46.3726432621479, 42.1018510311842, 42.14286983013153, 44.292201697826385, 41.929651871323586, 41.9403862953186, 43.5583508759737, 41.45299784839153, 39.90292802453041, 38.51292081177235, 39.822307750582695, 41.97375610470772, 42.72113800048828, 43.34553949534893, 46.21929109096527, 46.659254282712936, 51.67145133018494, 51.92585527896881, 51.9486578553915, 53.713742941617966, 53.74941922724247, 40.0758795440197, 47.600285187363625, 48.8204263150692, 52.35001511871815, 51.66185684502125, 54.68110643327236, 52.05774240195751, 52.984706461429596, 51.70681983232498, 54.147466868162155, 44.21305954456329, 35.74846275150776, 38.82920064032078, 40.005028545856476, 38.78806784749031, 42.808643504977226, 49.15776841342449, 52.365662679076195, 53.91917511820793, 48.15787486732006, 47.723219990730286, 50.773688703775406, 51.81544080376625, 52.4629070609808, 52.68685944378376, 50.84301598370075, 44.22649562358856, 41.17569252848625, 40.42895659804344, 44.646931663155556, 46.537759602069855, 50.673906058073044, 51.73138931393623, 52.62010082602501, 53.51322390139103, 54.382469058036804, 57.089751586318016, 50.897068083286285, 52.445944771170616, 43.714438900351524, 33.618863224983215, 17.542022801935673, 7.52583721652627, 6.434722915291786, 7.60685314424336, 10.206973347812891, 8.934058751910925, 13.671180959790945, 10.76195066794753, 7.5131397228688, 1.6971422382630408, 0.4475164145696908, 1.613840851932764, 6.09688731841743, 20.926951467990875, 39.230010733008385, 36.42757751047611, 44.08082664012909, 51.8000478297472, 59.565303549170494, 32.11556889116764, 6.839038794860244, 0.3197276685386896, 0.24799130304018036, 0.1624718599487096, 0.13155888591427356, 0.17918653960805386, 0.10729736590292305, 0.1774337945971638, 0.11194070189958438, 0.30261828505899757, 0.12254119050339796, 0.23847368953283876, 0.1211250911001116, 0.12002418181509711, 0.08530242426786572, 0.10888010714552365, 0.13393813715083525, 0.1563819742295891, 0.1463725246139802, 0.08715543342987075, 0.14674486010335386, 0.13776074687484652, 0.18519556091632694, 0.14816175360465422, 0.13390588341280818, 0.05063944852736313], [0.0139624769508373, 0.04441891884198412, 0.05044946614361834, 0.028370383515721187, 0.02612464093544986, 0.05618105409666896, 0.018355584870732855, 0.054860008967807516, 0.024693539016880095, 0.04437059018528089, 0.07394429194391705, 0.03789354086620733, 0.1013939522090368, 0.01414102376656956, 0.04373138210212346, 0.010620922712405445, 0.047633646536269225, 0.013292283274495276, 0.06769906729459763, 0.029147608802304603, 0.02747738875768846, 0.025493503708275966, 0.04255918582202867, 0.08564617222873494, 0.02835370003595017, 0.05990038283925969, 0.03046435504074907, 0.02868529347324511, 0.030681594653287902, 0.24894089583540335, 7.93440411798656, 36.89228117465973, 53.67850363254547, 49.269034042954445, 62.013588175177574, 60.98623730242252, 42.54961520433426, 18.687739223241806, 12.422295324504375, 2.026878450997174, 0.2371079893782735, 0.057174908579327166, 1.6158970165997744, 1.3784715067595243, 5.171883478760719, 2.018767073750496, 1.879121360834688, 11.206289324909449, 18.961767219007015, 22.91199915111065, 42.01173506677151, 49.70897823572159, 54.47814032435417, 53.94434116780758, 50.07544197142124, 49.63836282491684, 44.95980687439442, 42.646775990724564, 44.237602427601814, 47.816140204668045, 52.258390635252, 54.76854734122753, 50.090306773781776, 52.00356110930443, 49.831806644797325, 50.94464533030987, 48.2572091370821, 43.98528456687927, 36.777208149433136, 37.27591618895531, 37.36181437969208, 38.43901477754116, 38.179131522774696, 40.06139852106571, 39.10571560263634, 42.520953342318535, 37.94583164155483, 35.56669570505619, 36.10089763998985, 39.87352900207043, 42.72129379212856, 43.64955738186836, 44.220590740442276, 46.2131392210722, 47.53240942955017, 50.327425450086594, 48.123680502176285, 48.85448008775711, 41.58829338848591, 28.47985938191414, 51.76033616065979, 51.952142268419266, 51.0628379881382, 50.22095136344433, 49.022248685359955, 48.085606545209885, 51.27691090106964, 47.23741985857487, 48.62896978855133, 37.478118538856506, 34.6196573227644, 36.530757173895836, 38.773537427186966, 37.18690976500511, 38.958237916231155, 44.6793819218874, 46.95286452770233, 50.33066667616367, 49.77257922291756, 47.995703369379044, 48.44773471355438, 49.03772905468941, 54.04079519212246, 48.79900686442852, 46.46652102470398, 41.33264310657978, 38.399717286229134, 38.09179700911045, 36.00737705826759, 37.684257477521896, 39.00793544948101, 42.83327758312225, 45.12586556375027, 47.83525697886944, 50.11522963643074, 53.810177966952324, 55.722850933671, 42.73518204689026, 38.86947087943554, 22.884007953107357, 14.467072952538729, 3.2953959703445435, 3.4517540177330375, 5.886838864535093, 6.116074863821268, 4.4522856920957565, 6.154819959774613, 3.630281025543809, 1.742337488103658, 0.9399310417938977, 0.4886265570530668, 1.1518148565664887, 6.575288772583008, 20.2137316390872, 28.006448484957218, 27.46496994048357, 32.6135815680027, 42.92686656117439, 31.739276982843876, 15.530326198786497, 2.030337927863002, 0.06043124849384185, 0.03107172313320916, 0.08667565722134896, 0.015079181921464624, 0.049826581598608755, 0.027143828629050404, 0.040853441023500636, 0.06455039445427246, 0.03487113703158684, 0.08612825651653111, 0.03593196292058565, 0.01003013419904164, 0.05866326348041184, 0.027265954595350195, 0.031183420069282874, 0.05620856551104225, 0.014005034481670009, 0.07557930264738388, 0.010112148011103272, 0.05688994984666351, 0.06797562120482326, 0.027910699100175407, 0.02035506615357008, 0.0542793155182153, 0.05947214878688101, 0.03246415544708725, 0.016364898037863895, 0.019526617834344506, 0.049009143040166236, 0.03127414020127617, 0.05354268942028284, 0.011609366010816302, 0.03540193218213972, 0.03711663841386326, 0.005056478476035409, 0.10566478202235885, 0.03947393692214973, 0.05407487609772943, 0.025361230727867223, 0.031720508632133715, 0.023764449906593654, 0.03791289978835266, 0.06567180185811594, 0.020454651239560917, 0.016116827755467966, 0.011860177601192845, 0.06694672993035056, 0.06393893898348324, 0.0651069161540363, 0.06571396326762624, 0.09334924950962886, 0.01901475672639208, 0.024430770499748178, 0.010089927181979874, 0.4511713137617335, 10.536997988820076, 45.051089376211166, 59.16529901325703, 51.16040915250778, 64.78462368249893, 66.9356806576252, 55.268448516726494, 25.016014650464058, 11.642842199653387, 2.493421691469848, 0.3229738521622494, 0.1916863102815114, 1.873734318651259, 3.3791061909869313, 7.181670209392905, 2.915604212321341, 1.4351939130574465, 10.484136175364256, 22.56233811378479, 27.494758442044258, 42.46301405131817, 53.26643094420433, 55.83295002579689, 56.93108730018139, 53.60097259283066, 50.90499445796013, 47.195109128952026, 45.1830068975687, 45.02879597246647, 49.70815367996693, 52.48552344739437, 54.89705644547939, 50.145966187119484, 51.40486143529415, 51.945469826459885, 52.80035175383091, 51.34844206273556, 46.405959874391556, 39.70883063971996, 38.4559428691864, 39.958401247859, 39.1476159542799, 39.99658539891243, 42.2682099044323, 40.193639025092125, 44.275634586811066, 40.32046481966972, 37.279636189341545, 39.24207128584385, 42.833159789443016, 44.201527163386345, 45.7909020781517, 46.502318903803825, 48.07864911854267, 48.88977639377117, 52.67615161836147, 50.03737561404705, 51.80419720709324, 45.07856950163841, 34.12403091788292, 51.43690511584282, 52.318765595555305, 53.71369354426861, 51.852815598249435, 51.2781648337841, 50.88770158588886, 51.9835589826107, 49.48160983622074, 51.66696757078171, 39.94022682309151, 36.2734729796648, 38.54665920138359, 38.4960725158453, 39.07454587519169, 40.95773622393608, 47.51482017338276, 47.94658720493317, 51.82711757719517, 49.30793635547161, 49.337293580174446, 48.57621341943741, 52.48070150613785, 55.307552218437195, 51.45317204296589, 49.301362708210945, 44.12031792104244, 39.73231337964535, 38.64891551434994, 37.65002891421318, 40.239301174879074, 42.278233766555786, 46.262692362070084, 46.28695785999298, 51.18971697986126, 52.653489634394646, 56.369040459394455, 56.211899891495705, 47.20791444182396, 41.2376444041729, 26.78305473178625, 15.938902124762535, 4.489913173019886, 3.2041286677122116, 4.965907456353307, 8.25249407440424, 7.27211675606668, 8.63985288888216, 4.058430651202798, 2.038840209133923, 0.3823900467250496, 0.26316690200474113, 1.1204976495355368, 7.395706074312329, 22.008821815252304, 33.1592208892107, 28.827443830668926, 34.92719382047653, 48.9964746683836, 38.90436440706253, 19.53250039368868, 2.604180285707116, 0.031350841163657606, 0.04844395676627755, 0.08842184906825423, 0.08526598481694236, 0.02047495454462478, 0.05082258088805247, 0.03821294638328254, 0.010243856959277764, 0.05835647076310124, 0.031764347295393236, 0.0289078988134861, 0.006526493516503251, 0.05896666829357855, 0.053823941125301644, 0.06260599722736515, 0.039862967023509555, 0.016976173537841532, 0.02168634735426167, 0.01910373095597606, 0.023864495124144014, 0.0287662543632905, 0.02438931041979231, 0.01815843705117004, 0.06993406728724949, 0.042292142534279265, 0.11781268563936464, 0.10761402547359467, 0.12891458405647427, 0.11917178067960776, 0.07672310064663179, 0.12041486319503747, 0.07525547393015586, 0.17333072726614773, 0.25671274052001536, 0.09148801735136658, 0.1683113895705901, 0.10835585402674042, 0.17859258397947997, 0.11910806730156764, 0.20647409255616367, 0.10227319682599045, 0.06185563026519958, 0.10392613781732507, 0.15668557200115174, 0.1255167054478079, 0.09895224182400852, 0.18423197121592239, 0.14221385557902977, 0.20490087306825444, 0.14279604074545205, 0.14024395815795287, 0.1084209255350288, 0.14582257834263146, 0.07811890973243862, 0.5737942666746676, 12.845312375575304, 50.36639615893364, 66.76765367388725, 58.348802626132965, 73.14519345760345, 66.17732495069504, 50.70447541773319, 26.034810282289982, 15.9547795727849, 2.967936429195106, 0.5198859062511474, 0.41927671583835036, 4.915841342881322, 6.1456994991749525, 12.542785909026861, 7.827846435829997, 3.6405464122071862, 14.351050928235054, 23.2350692152977, 29.166034162044525, 45.38643278181553, 52.48687997460365, 58.540673330426216, 58.2542484998703, 56.07132263481617, 52.646756395697594, 50.819780230522156, 46.709958761930466, 48.191742449998856, 52.063274905085564, 56.116912588477135, 56.886587888002396, 50.55644676089287, 51.99739784002304, 52.643412575125694, 54.20072861015797, 53.27419772744179, 47.38742060959339, 41.42134174704552, 41.31772130727768, 41.565034836530685, 41.873319894075394, 42.3733464628458, 43.937068954110146, 42.14193508028984, 45.785304978489876, 42.48419791460037, 39.11092892289162, 41.131291911005974, 44.33509759604931, 47.45086580514908, 46.71673759818077, 49.17780093848705, 50.87043531239033, 51.02586217224598, 54.918658286333084, 51.60021275281906, 51.92775897681713, 45.287470892071724, 36.82403303682804, 50.79978950321674, 52.442084178328514, 54.51490715146065, 53.35471160709858, 54.479420855641365, 51.43524840474129, 55.471483021974564, 51.033473163843155, 53.98311048746109, 40.966126173734665, 38.71184013783932, 40.50942488014698, 42.17975825071335, 41.001395881175995, 42.72869199514389, 51.13533429801464, 50.34830912947655, 54.307890459895134, 51.18217818439007, 49.53420281410217, 50.64020946621895, 52.60391749441624, 57.583759278059006, 52.94125959277153, 51.63717336952686, 44.83815640211105, 43.69258627295494, 40.83914838731289, 39.35282774269581, 41.911310255527496, 43.409292474389076, 47.48901575803757, 48.05162496864796, 52.49988667666912, 53.950280249118805, 58.33098918199539, 58.18862982094288, 50.72579227387905, 43.52897845208645, 29.785248935222626, 18.98030262440443, 5.677560344338417, 6.349701527506113, 11.019309908151627, 13.219574242830276, 12.514688316732645, 13.834985420107841, 10.784269720315933, 6.4242202788591385, 1.6589371883310378, 0.8832515019457787, 1.625850226264447, 8.802657052874565, 26.61088217049837, 38.591082617640495, 36.84229105710983, 44.310216531157494, 56.34397320449352, 42.90425017476082, 21.55834648758173, 3.2850123150274158, 0.14230939967092127, 0.18938946712296456, 0.21192441025050357, 0.26285603118594736, 0.13350832974538207, 0.12529695552075282, 0.15236986451782286, 0.16337860113708302, 0.16588689701166004, 0.18256972369272262, 0.11058179239626043, 0.15050315530970693, 0.13792577083222568, 0.16064497438492253, 0.32300546765327454, 0.14532863453496248, 0.11088713421486318, 0.123429511586437, 0.08183548139641061, 0.12080440908903256, 0.21752808534074575, 0.10170039982767776, 0.14852939872071147, 0.2686590322991833, 0.13450812140945345], [0.08512871718266979, 0.09498586325207725, 0.010851616534637287, 0.02346016564843012, 0.04345441629993729, 0.0075389833273220574, 0.02794972122501349, 0.06425951709388755, 0.030507785522786435, 0.023551735539513174, 0.05947271652985364, 0.001879557059965009, 0.023063779008225538, 0.003712545744747331, 0.010494842954358319, 0.041703426468302496, 0.06013361387886107, 0.012792540510417894, 0.04584920439810958, 0.05252924966043793, 0.05389818557887338, 0.05284001657855697, 0.017576988466316834, 0.04387840526760556, 0.05742599198129028, 0.03857781215629075, 0.03437452149228193, 0.005463063153001713, 0.006766659462300595, 0.04512864579737652, 5.486890850588679, 24.278118945658207, 52.49613247811794, 50.557860285043716, 48.16300839185715, 31.641217544674873, 26.957889050245285, 39.87581267952919, 17.361363396048546, 4.2972977086901665, 0.2723027695901692, 0.0819998596853111, 0.8253111422527581, 2.2000776696950197, 4.037291910499334, 1.481832372955978, 0.1186697771481704, 1.7311428138054907, 8.771363832056522, 25.82964599132538, 30.431979931890965, 46.082870811223984, 53.132902309298515, 55.20082354545593, 50.34804694354534, 49.598278775811195, 47.36234575510025, 46.295921579003334, 46.794527024030685, 51.03948824107647, 50.50918869674206, 53.17938141524792, 49.177082777023315, 50.035099536180496, 53.10642912983894, 51.310425102710724, 48.35600383579731, 43.09590429067612, 36.46337918937206, 37.58094862103462, 36.33102469146252, 38.72642755508423, 39.939246475696564, 42.662598341703415, 39.98885281383991, 41.23800538480282, 41.93340606987476, 39.34477977454662, 40.910953134298325, 44.81498524546623, 46.756684854626656, 47.1189384162426, 45.29044233262539, 49.2322064191103, 50.410587787628174, 53.56232486665249, 52.50536598265171, 33.671007826924324, 34.105529710650444, 26.95946406573057, 48.57130028307438, 50.11758551001549, 48.29131230711937, 46.587092354893684, 46.09622709453106, 45.83062134683132, 45.805649086833, 44.503793343901634, 38.80595348775387, 33.629958629608154, 35.054357796907425, 38.42070735991001, 40.25353901088238, 37.22209207713604, 37.10570812225342, 41.47179923951626, 47.42853440344334, 48.20899352431297, 49.42560464143753, 47.739486917853355, 47.374945878982544, 48.37564118206501, 51.30481660366058, 47.93536260724068, 48.01203869283199, 44.54206869006157, 38.7317206710577, 38.58896613121033, 39.90165129303932, 41.07971727848053, 38.71761202812195, 42.73442968726158, 43.27259100973606, 45.38962081074715, 49.96575705707073, 49.388476833701134, 54.25338618457317, 47.81500406563282, 35.33716902136803, 22.107850201427937, 8.325584102421999, 3.1587284663692117, 1.5289270458742976, 3.2029464561492205, 3.1855441024526954, 4.260533731430769, 4.226521281525493, 2.9157702159136534, 2.3891251254826784, 0.21974817558657378, 0.22634717461187392, 2.3855471424758434, 8.64910539239645, 15.159551594406366, 25.83642292767763, 37.32409380376339, 41.242701932787895, 44.17262211441994, 26.68202195316553, 7.037496920675039, 0.8250637399032712, 0.02462822445522761, 0.07367131518549286, 0.039216044315253384, 0.07847968256101012, 0.07099032154656015, 0.049659208743833005, 0.0312840701371897, 0.04465685509785544, 0.025588728676666506, 0.05247906192380469, 0.0431274594302522, 0.07039350864943117, 0.0501848645217251, 0.03772553718590643, 0.022919329239812214, 0.08844466268783435, 0.14010220795171335, 0.030471318241325207, 0.05911566557188053, 0.04369228205177933, 0.010186539038841147, 0.015572929987683892, 0.01800107020244468, 0.050201666745124385, 0.051538890693336725, 0.06557891465490684, 0.03494749660603702, 0.025931393101927824, 0.01985675666219322, 0.06167553328850772, 0.09122045084950514, 0.06988525623455644, 0.03946837081457488, 0.06454463538830169, 0.05290106935717631, 0.04981395024515223, 0.10709093752666377, 0.014631654812546913, 0.03678837536426727, 0.021237283071968704, 0.05113801591505762, 0.07067223705234937, 0.07463862304575741, 0.060400935471989214, 0.04546683507214766, 0.05812226751004346, 0.05037426431954373, 0.06372074756654911, 0.032081960525829345, 0.012615236792044016, 0.11855964985443279, 0.03159534913720563, 0.02766807061561849, 0.05134477083629463, 0.02995824186655227, 7.475809575989842, 30.125598572194576, 59.65374380350113, 56.31307706236839, 58.046407252550125, 42.65436418354511, 31.900698021054268, 37.26319447159767, 18.1425653770566, 4.543530195951462, 0.35939032619353384, 0.15414848079672083, 1.1603182065300643, 2.541901390068233, 5.691620064899325, 2.5707354303449392, 1.2024986743927002, 4.034478161484003, 11.11116522923112, 27.09003645926714, 33.90471808612347, 47.594163715839386, 56.15801878273487, 56.66469879448414, 52.424985095858574, 50.526310577988625, 50.00117115676403, 47.75680258870125, 48.59739728271961, 51.24825283885002, 53.02665241062641, 54.57543030381203, 49.53295648097992, 49.64285038411617, 53.95518958568573, 54.135710299015045, 50.62737375497818, 44.91707816720009, 37.43002071976662, 38.85457567870617, 38.6714369058609, 40.197248831391335, 41.77877336740494, 42.98150762915611, 41.01673945784569, 43.41476038098335, 43.67935158312321, 41.519216895103455, 41.76147669553757, 46.14791952073574, 50.04469782114029, 50.27008652687073, 49.43691283464432, 50.39530120790005, 52.07507327198982, 56.271378099918365, 53.98788683116436, 39.429667219519615, 36.981724575161934, 30.33173941075802, 49.81905072927475, 51.727711111307144, 50.36924980580807, 49.25476960837841, 49.51892763376236, 48.11066620051861, 49.09781523048878, 46.72289326786995, 41.50105766952038, 34.635863453149796, 36.53593249619007, 40.7284527271986, 42.31539957225323, 38.32685239613056, 38.10731917619705, 42.79865384101868, 50.36935620009899, 50.03569230437279, 51.44514687359333, 47.629311829805374, 49.46058936417103, 49.94298107922077, 52.61995643377304, 52.123782858252525, 49.80226702988148, 44.54896531999111, 41.20880015194416, 40.03483034670353, 41.72092147171497, 41.46466702222824, 40.41555471718311, 43.221597746014595, 46.99155405163765, 48.67895230650902, 52.25538119673729, 51.01695545017719, 54.820422157645226, 49.268992245197296, 38.365709111094475, 23.951794356107712, 11.36659037321806, 4.250410599634051, 2.4992997385561466, 4.727084571495652, 6.9522256962955, 8.822655379772186, 6.0986200254410505, 3.43798759393394, 1.6091390792280436, 0.40318499493878335, 0.19451705447863787, 2.3490771744400263, 9.514640998095274, 20.304805152118206, 28.8986824080348, 40.867665857076645, 46.00597433745861, 49.638769403100014, 31.25334955751896, 10.57199601083994, 1.1168505577370524, 0.03723532638105098, 0.05001196637749672, 0.02551688321545953, 0.034790502686519176, 0.034742177740554325, 0.05332066481059883, 0.05051846361311618, 0.07041759134153835, 0.04426857456564903, 0.048808154606376775, 0.006550613779836567, 0.02226514832727844, 0.039737722181598656, 0.08664352964842692, 0.02221400322014233, 0.04400154241011478, 0.12299344045459293, 0.03652189239801373, 0.025030028773471713, 0.03396510459424462, 0.04344938453868963, 0.0796867189637851, 0.017519624161650427, 0.05920172501646448, 0.03943796502426267, 0.20747406233567744, 0.11642767480225302, 0.12043035923852585, 0.09997147775720805, 0.10853831103304401, 0.15333045594161376, 0.1522132268291898, 0.18967275973409414, 0.1461834996007383, 0.11707593337632716, 0.14542566292220727, 0.18370592209976166, 0.08739460536162369, 0.07963989686686546, 0.09395881250384264, 0.14684494613902643, 0.11077145565650426, 0.1352554195909761, 0.1434704748680815, 0.11322258389554918, 0.26321787270717323, 0.14780415716813877, 0.1729550669551827, 0.0812435666739475, 0.162551804096438, 0.21362897503422573, 0.12344759030384012, 0.11766734343837015, 0.10397993610240519, 0.1524908939609304, 8.546874728053808, 35.462056919932365, 67.56308779120445, 61.10897831618786, 59.158428981900215, 43.22225511074066, 37.23052002489567, 48.539036214351654, 21.346348263323307, 6.318131871521473, 0.5606977350544184, 0.8741778263356537, 2.423417097888887, 5.09764258749783, 11.402930673211813, 7.173751434311271, 1.6056709340773523, 3.1342354556545615, 10.240957774221897, 28.268651515245438, 33.8319443911314, 50.28270564973354, 57.0008135586977, 58.22744853794575, 53.6268226057291, 53.20116564631462, 52.43720903992653, 50.88702902197838, 50.94596765935421, 55.91933839023113, 54.14418004453182, 54.818347468972206, 48.749719709157944, 49.91105519235134, 55.02870038151741, 55.97475841641426, 52.11845174431801, 47.15908706188202, 40.075377970933914, 41.3111362606287, 40.68873345851898, 42.14322701096535, 43.747968301177025, 45.617350190877914, 43.56570728123188, 44.471020102500916, 45.26925466954708, 43.78133051097393, 44.35810536146164, 47.856915816664696, 52.71815836429596, 52.19249837100506, 51.578348726034164, 53.2555141299963, 55.43648689985275, 58.13353277742863, 55.20040936768055, 40.255131125450134, 38.872981891036034, 34.354203566908836, 49.35472324490547, 52.82571159303188, 52.80089132487774, 50.98658747971058, 50.636922642588615, 50.37839971482754, 49.717987552285194, 47.6397118717432, 41.17051340639591, 36.503607630729675, 37.937141507864, 42.0921615511179, 44.19175408780575, 40.676429718732834, 40.36432966589928, 44.485322535037994, 52.59957812726498, 52.15048022568226, 52.54222020506859, 48.62188696861267, 50.2902140468359, 48.84485140442848, 53.35297890007496, 53.06186132133007, 52.181262373924255, 49.055873081088066, 42.801473289728165, 41.58942572772503, 44.022974744439125, 43.91304664313793, 43.1334462761879, 48.07139530777931, 47.93101944029331, 50.635721907019615, 55.18756605684757, 53.75513032078743, 57.54864156246185, 51.519394889473915, 38.524555787444115, 23.768055215477943, 10.314206443727016, 4.959849631413817, 4.341444214805961, 9.564078245311975, 9.787882436066866, 12.399279959499836, 12.812370993196964, 10.30874328687787, 4.962308574467897, 1.1769089475274086, 0.6212886900175363, 3.6631340626627207, 12.44872385635972, 21.54368307441473, 36.258118003606796, 49.583535566926, 54.065068289637566, 55.586426854133606, 37.19171650707722, 11.574398372322321, 1.255685726646334, 0.1360227557597682, 0.18836497678421438, 0.190049696539063, 0.2219870570115745, 0.14768817432923242, 0.1675478828838095, 0.10624520087731071, 0.1600524436798878, 0.13298407662659883, 0.08939830018789507, 0.1368800550699234, 0.16384827671572566, 0.15858925500651821, 0.10649074043612927, 0.09540312094031833, 0.1640769769437611, 0.1934136589989066, 0.11187210518983193, 0.10304523078957573, 0.11433426174335182, 0.13685590558452532, 0.3097328986041248, 0.11030894180294126, 0.14189943729434162, 0.1423201014404185], [0.048732184659456834, 0.023845434916438535, 0.06396869168384, 0.04095356045581866, 0.03310576066724025, 0.03683823284518439, 0.0545147544471547, 0.018262962985318154, 0.06060167899704538, 0.02896975496696541, 0.041926274861907586, 0.06443736536311917, 0.013109400460962206, 0.08815785229671746, 0.010207380400970578, 0.05362235526263248, 0.01144744701377931, 0.015705123187217396, 0.06850003759609535, 0.017014433105941862, 0.007860641726438189, 0.04821075912332162, 0.007926197486085584, 0.05769723953562789, 0.04364496642665472, 0.10594335457426496, 0.010162426660826895, 0.04451915330719203, 0.0357408413401572, 0.09906947147101164, 2.3225125623866916, 19.117604456841946, 42.790453881025314, 44.90089863538742, 37.59807430207729, 30.973728261888027, 34.03434433043003, 26.497410759329796, 17.98131722956896, 7.724125301465392, 0.9252731502056122, 0.3089196828659624, 0.7894047314766794, 2.0765465358272195, 4.155551539734006, 5.038625579327345, 3.0310515174642205, 3.6634254595264792, 7.810721704736352, 14.93099955841899, 25.8555606007576, 39.13881562650204, 52.6598846912384, 56.95317551493645, 53.641239032149315, 50.83787865936756, 47.116704136133194, 46.75760060548782, 47.13655047118664, 48.371571600437164, 53.9348416775465, 53.967421129345894, 50.71299836039543, 50.486256927251816, 51.494422629475594, 51.688333824276924, 48.34376089274883, 42.164277881383896, 38.909839913249016, 37.27207839488983, 36.8532420694828, 38.04105453193188, 39.69898156821728, 41.27031125128269, 40.78876309096813, 41.529274955391884, 38.31218518316746, 37.86312907934189, 43.161245584487915, 45.12506760656834, 48.989312052726746, 51.129068434238434, 50.14148622751236, 47.499191612005234, 54.654792845249176, 44.32271406054497, 45.876519083976746, 43.91000680625439, 48.37774246931076, 36.46458372473717, 47.65860065817833, 51.46226495504379, 47.151597663760185, 47.004849538207054, 42.40347504615784, 39.40969169139862, 38.49501997232437, 37.77649372816086, 35.13887286186218, 35.786000937223434, 38.80465395748615, 42.97768123447895, 41.78513042628765, 40.27846187353134, 37.93023727834225, 38.66667576134205, 42.06216976046562, 48.724922239780426, 48.41715395450592, 49.5560934394598, 51.015731915831566, 48.027465865015984, 51.31651237607002, 49.53566953539848, 49.28583674132824, 45.798794254660606, 40.44745400547981, 38.159296587109566, 39.12507936358452, 39.59405779838562, 41.71040743589401, 45.42675241827965, 44.708081781864166, 48.20602208375931, 47.63987526297569, 51.25241361558437, 53.99376131594181, 45.887150913476944, 30.893119387328625, 16.705144308507442, 7.434908095747232, 2.820259490981698, 2.0024308003485203, 2.671623104251921, 7.992882505059242, 8.603021465241909, 6.612145369872451, 1.7792975110933185, 1.0322231613099575, 0.09761774897924624, 0.3444820042932406, 2.6343661034479737, 12.211557682603598, 18.324537612497807, 29.480186104774475, 35.08930452167988, 37.49134182929993, 43.605688735842705, 21.893452405929565, 3.9813204389065504, 0.31429553346242756, 0.021324927001842298, 0.06615091013372876, 0.017134069166786503, 0.020988567121094093, 0.10099083243403584, 0.013153497020539362, 0.07745955605059862, 0.02694958631764166, 0.0469087426608894, 0.026164063820033334, 0.07527012392529286, 0.017663277976680547, 0.05777993705123663, 0.04195067296677735, 0.014063427588553168, 0.03983731468906626, 0.024791853174974676, 0.013146336223144317, 0.040823098315740936, 0.06228079553693533, 0.023385282947856467, 0.0666611960332375, 0.020628853708331008, 0.033856238951557316, 0.010568659745331388, 0.02551224664784968, 0.03609447099734098, 0.027944162538915407, 0.07140659217839129, 0.04615416029992048, 0.016271769636659883, 0.03290708773420192, 0.02184908364142757, 0.05409951168985572, 0.030796833489148412, 0.05757321181590669, 0.03219841833924875, 0.022426352079492062, 0.022133676866360474, 0.1195325015578419, 0.02737573864578735, 0.03747236463823356, 0.02281319841131335, 0.05307272440404631, 0.08199739575502463, 0.026966843106492888, 0.00993054076388944, 0.051573775344877504, 0.035479746366036125, 0.06424472609069198, 0.04559122273349203, 0.022039528012101073, 0.017398069649061654, 0.01802706206945004, 0.06722703910782002, 3.178492155857384, 23.779333010315895, 48.7012305110693, 49.968143329024315, 41.105962470173836, 34.8555638641119, 38.01553130149841, 39.42346975207329, 22.25427344441414, 7.716929437592626, 0.6859840778633952, 0.1961185349500738, 0.854170712409541, 2.499786112457514, 4.823946123942733, 4.196023643016815, 3.9429812086746097, 2.6001337403431535, 8.743766862899065, 17.097034379839897, 27.45354775339365, 42.71054416894913, 55.22033169865608, 58.73170427978039, 56.436414644122124, 52.47324250638485, 49.747606962919235, 48.1673439592123, 49.644799679517746, 51.989057287573814, 55.12814104557037, 54.18256178498268, 51.674263179302216, 50.13780042529106, 51.988175734877586, 53.567124009132385, 49.44516979157925, 43.17296415567398, 40.790309607982635, 39.32291194796562, 39.237188547849655, 39.57793906331062, 41.68141879141331, 44.61255110800266, 42.076802775263786, 43.17298695445061, 41.19730956852436, 38.97041246294975, 45.095387399196625, 48.74979570508003, 50.537132397294044, 52.144199162721634, 50.73233552277088, 50.01244135200977, 53.10368187725544, 47.83827021718025, 50.233072713017464, 42.96174108982086, 47.223706394433975, 38.67419555783272, 49.56443399190903, 52.4032274633646, 50.6964198499918, 49.381318017840385, 45.64084433019161, 42.14744858443737, 40.31222306191921, 39.157294034957886, 36.47129036486149, 37.30413727462292, 38.88447247445583, 43.776360377669334, 44.51254427433014, 42.61220924556255, 40.093936175107956, 41.19886368513107, 45.142542868852615, 50.630018413066864, 51.25880107283592, 51.28762252628803, 52.66975276172161, 48.028624802827835, 51.64316564798355, 51.73473693430424, 50.91985926032066, 47.05159083008766, 42.13817708194256, 41.29508972167969, 40.78043393790722, 40.90778410434723, 44.03123930096626, 46.6013377904892, 46.53652846813202, 48.54109950363636, 49.33830812573433, 53.310827761888504, 55.18949255347252, 46.89928360283375, 33.425210416316986, 19.24338150769472, 7.91416022926569, 2.5472377287223935, 4.292449643835425, 5.192347280681133, 8.416697513312101, 7.437979755923152, 6.895648632198572, 3.6567553924396634, 1.1414241953752935, 0.22856028866954148, 0.5052502790931612, 3.2300399523228407, 14.090459011495113, 20.689608603715897, 30.069008208811283, 38.784667029976845, 42.80127950012684, 49.17632281780243, 26.13400775939226, 4.57662689499557, 0.3749475226504728, 0.07467443909263238, 0.07364038247033022, 0.027533777138160076, 0.008327255018230062, 0.034544781301519834, 0.05896536211366765, 0.09668039419921115, 0.05889977852348238, 0.02247589971375419, 0.08953325232141651, 0.0393809235538356, 0.07534161501098424, 0.05721753383113537, 0.042318054620409384, 0.018007120561378542, 0.038761215400882065, 0.015397794268210419, 0.03268125219619833, 0.02072601011605002, 0.04175559944997076, 0.04020255153591279, 0.021283277674228884, 0.016597325702605303, 0.027935462712775916, 0.034504389914218336, 0.12731139664538205, 0.15805290488060564, 0.11768255004426464, 0.15692207962274551, 0.16111237899167463, 0.11845094748423435, 0.12076224767952226, 0.177641655318439, 0.13685029494808987, 0.1050642435438931, 0.13797488616546616, 0.1638442839612253, 0.09597061900421977, 0.1761295145843178, 0.1485786773264408, 0.13266775844385847, 0.1670674906927161, 0.13659668824402615, 0.1440130441915244, 0.18549838685430586, 0.10378748978837393, 0.08721922102267854, 0.1526986507815309, 0.13174636726034805, 0.13867646805010736, 0.143204563355539, 0.1037665834883228, 0.07716248175711371, 0.09755610619322397, 0.18408259173156694, 3.619719254784286, 27.12348036468029, 56.168646812438965, 56.36801451444626, 49.52349878847599, 41.84892140328884, 44.24028128385544, 36.59343101084232, 24.113758765161037, 9.835838712751865, 1.7355270660482347, 0.5618092347867787, 1.8048580270260572, 6.73174062743783, 10.233257487416267, 8.887956775724888, 5.247340304777026, 6.312107294797897, 10.742561258375645, 18.98508846759796, 27.48262759298086, 43.84619303047657, 57.574316784739494, 61.537785306572914, 57.924543991684914, 54.77236233651638, 50.82113675773144, 52.6945274323225, 52.384741455316544, 52.24655047059059, 57.458054423332214, 56.49941526353359, 51.527651846408844, 51.003811955451965, 53.52829769253731, 56.35196037590504, 53.04884321987629, 45.10681338608265, 42.818899154663086, 41.33752964437008, 40.879817605018616, 42.10370533168316, 43.054296523332596, 46.55029512941837, 43.65017294883728, 45.421185716986656, 42.3975245654583, 40.69281063973904, 46.804740875959396, 49.997728541493416, 52.04377435147762, 53.930281922221184, 53.88518214225769, 50.1161377876997, 55.219218358397484, 49.435229524970055, 50.527047738432884, 44.835842326283455, 48.07349279522896, 42.239627838134766, 51.06550544500351, 55.47266095876694, 52.65018381178379, 52.59371504187584, 46.42584800720215, 44.072573482990265, 42.5247835367918, 40.90811848640442, 39.07399110496044, 39.26659896969795, 41.714355424046516, 45.915071815252304, 46.20905824005604, 45.69869242608547, 42.58392356336117, 44.114618226885796, 46.418666392564774, 53.131864964962006, 53.18925328552723, 51.4111652970314, 52.672902792692184, 49.18802239000797, 52.63367369771004, 54.27233196794987, 53.35784263908863, 49.51832726597786, 43.722893446683884, 41.54768876731396, 42.535343170166016, 43.61638516187668, 45.673062801361084, 48.11468258500099, 47.27109745144844, 52.62698605656624, 52.40695886313915, 55.98975621163845, 56.1960319429636, 49.463348016142845, 34.3229616433382, 20.036735236644745, 9.243937823921442, 5.0091329868882895, 6.184164835140109, 8.028629086911678, 17.398236617445946, 15.559507682919502, 14.33162922039628, 7.486401032656431, 3.41335232835263, 0.7516026974190027, 1.0009838500991464, 3.9240045519545674, 17.688343450427055, 26.592781841754913, 39.50532875955105, 48.599156588315964, 49.39857289195061, 53.64957958459854, 29.53372523188591, 5.444673215970397, 0.5094726837705821, 0.12079267573426478, 0.1882520961225964, 0.10367785231210291, 0.08392254167119972, 0.24422082176897675, 0.1243962999433279, 0.1726427415269427, 0.17108019412262365, 0.20974142738850787, 0.12067713818396442, 0.14220812619896606, 0.21400988975074142, 0.16150561335962266, 0.07323914032895118, 0.2250368386739865, 0.1446733478223905, 0.07029692555079237, 0.10022433489211835, 0.10128190275281668, 0.16842796612763777, 0.13218668347690254, 0.20150054537225515, 0.10499554293346591, 0.09302070815465413, 0.2007161991787143], [0.03225255059078336, 0.015019325855973875, 0.040392044102190994, 0.036067672044737265, 0.08141282087308355, 0.03738551109563559, 0.009338046238553943, 0.19095118332188576, 0.02917667501606047, 0.019564632493711542, 0.03486360423266888, 0.015056259762786794, 0.008751883160584839, 0.02587942421087064, 0.03813672410615254, 0.06951398943783715, 0.023273205661098473, 0.07544440246419981, 0.0895285396836698, 0.017464950142311864, 0.0311880844674306, 0.030403495220525656, 0.05911515348998364, 0.04821520829864312, 0.04446117673069239, 0.03234571238863282, 0.04715201124781743, 0.09945846075424924, 0.05759239262260962, 0.09464470538659953, 0.8808798948302865, 8.154286444187164, 36.32357329130173, 48.271842151880264, 46.82608813047409, 34.95027378201485, 27.930059283971786, 26.562102288007736, 26.718325205147266, 12.712123822420835, 1.2818415043875575, 0.26220763160381466, 1.0852806642651558, 1.1065006256103516, 3.723078933544457, 2.168257227167487, 2.5843512872233987, 2.42594419978559, 7.059130584821105, 10.767578165978193, 18.72798666357994, 32.56639949977398, 43.95883798599243, 54.21204440295696, 54.17153477668762, 51.693136766552925, 49.54796187579632, 48.9790678024292, 49.08844493329525, 50.5851998180151, 52.07905925810337, 52.75701887905598, 52.34179235994816, 50.945002511143684, 52.969047501683235, 51.57618284225464, 48.39495934545994, 47.29890055954456, 44.47642721235752, 41.64225809276104, 40.28475433588028, 39.936039447784424, 38.342461958527565, 38.67228426039219, 40.275327041745186, 38.4597996622324, 38.06359492242336, 36.19880698621273, 41.27534978091717, 47.501258701086044, 50.099061504006386, 49.42125767469406, 50.03907032310963, 49.54745650291443, 50.07383465766907, 50.42738288640976, 48.72124023735523, 50.953947231173515, 45.24709805846214, 34.4783429056406, 50.48928156495094, 51.16879150271416, 47.255039513111115, 45.919103398919106, 38.57726275920868, 37.07068920135498, 37.58008226752281, 36.288352981209755, 35.781216993927956, 38.26331980526447, 43.644021078944206, 46.14547245204449, 44.597108736634254, 43.953704461455345, 40.08804649114609, 35.00993438065052, 37.976541593670845, 42.54053749144077, 47.29184813797474, 48.42178210616112, 52.87832736968994, 50.57673007249832, 49.641805440187454, 51.70638665556908, 50.11790469288826, 45.952913984656334, 42.29488827288151, 37.16028459370136, 39.67535063624382, 42.25714489817619, 45.93192771077156, 46.78227648139, 49.31507997214794, 47.6569477468729, 49.28060442209244, 49.33344438672066, 51.547015607357025, 40.44368840754032, 26.751905903220177, 11.542222648859024, 3.6113440291956067, 0.9585449961014092, 2.603897675871849, 4.064320810139179, 5.364286629483104, 7.709006387740374, 4.983435440808535, 2.257077698595822, 0.918877855874598, 0.2770509710535407, 0.9274956153240055, 4.594786120578647, 15.167149286717176, 33.44322144985199, 37.563218772411346, 41.036221012473106, 45.17018638551235, 33.88216249644756, 13.026457205414772, 1.2077726726420224, 0.02348940626689, 0.05118669709190726, 0.04874854159425013, 0.059225878212600946, 0.025918750616256148, 0.04605264562997036, 0.05226320085057523, 0.021712205634685233, 0.035970402459497564, 0.043994543957524, 0.05664840675308369, 0.023840432841097936, 0.032789038014016114, 0.10028214077465236, 0.021512412058655173, 0.033279627314186655, 0.06360495026456192, 0.07435408362653106, 0.055307446091319434, 0.007700051173742395, 0.018032197731372435, 0.030365981510840356, 0.06447166000725701, 0.028358000781736337, 0.021363767300499603, 0.021702613375964575, 0.014238434359867824, 0.03985114090028219, 0.05260162019112613, 0.08102561274426989, 0.04059497696289327, 0.004745466185340774, 0.07531057839514688, 0.040591700380900875, 0.027248120786680374, 0.07084431883413345, 0.03556181305611972, 0.03910937171895057, 0.0746303480991628, 0.008454820926999673, 0.028028520609950647, 0.04638936174160335, 0.026297997355868574, 0.05178893879929092, 0.06317764389677905, 0.026670933984860312, 0.04758058668812737, 0.054341281138476916, 0.017434965520806145, 0.08421487364103086, 0.024124682822730392, 0.0277705612097634, 0.03306797421828378, 0.02220129950728733, 0.0164704444250674, 0.08692731207702309, 1.2032298976555467, 11.161790862679482, 44.56599600613117, 54.056184366345406, 53.187509179115295, 41.72507084906101, 30.65533384680748, 27.21235189586878, 30.06960667669773, 13.092198427766562, 1.3027450139634311, 0.2290822856593877, 0.7303903356660157, 1.9150097225792706, 2.2671756567433476, 5.362123595550656, 6.350514208897948, 4.983719475567341, 7.381440214812756, 12.475159037858248, 21.069751605391502, 34.61935713887215, 45.8073627948761, 57.42863640189171, 56.40978567302227, 53.93800690770149, 52.13009051978588, 50.53813174366951, 51.574336141347885, 52.55455434322357, 52.349718734622, 54.72575403749943, 51.49373106658459, 51.216733530163765, 53.987221866846085, 52.630542665719986, 50.09124152362347, 48.956212028861046, 45.54467909038067, 43.47021080553532, 41.70239746570587, 41.626595333218575, 40.03731161355972, 41.18204578757286, 41.56138703227043, 40.4290933907032, 39.61455009877682, 38.40197816491127, 42.231112495064735, 49.740797728300095, 51.06715075671673, 51.04254707694054, 50.027423948049545, 52.104297503829, 52.55599066615105, 51.35157689452171, 50.64476542174816, 51.738251745700836, 46.79122120141983, 37.52499662339687, 51.529118567705154, 52.38929361104965, 49.310056641697884, 46.164783015847206, 40.7362575083971, 38.684569001197815, 38.658791184425354, 37.80358247458935, 37.65437588095665, 40.27292937040329, 44.8168433457613, 48.70891369879246, 47.72721737623215, 45.32887727022171, 41.84996634721756, 37.75478929281235, 40.74975058436394, 46.859594732522964, 50.558228865265846, 48.91696013510227, 52.86071911454201, 50.315668880939484, 50.88920630514622, 52.04399473965168, 52.831586077809334, 49.71227265894413, 43.558293879032135, 39.40143093466759, 40.9208782017231, 44.07675325870514, 47.12593384087086, 48.60022813081741, 50.05306117236614, 50.130770802497864, 49.49479512870312, 52.19610057771206, 53.307810723781586, 43.476271480321884, 28.467158563435078, 12.372097168117762, 4.390208898112178, 2.163396100513637, 6.022584205493331, 6.078394185751677, 6.808866988867521, 8.497416581958532, 5.351423844695091, 3.8770108111202717, 0.9211802948266268, 0.2618947421433404, 0.9984174440614879, 4.948265478014946, 16.094068698585033, 31.836006492376328, 40.11705793440342, 43.33931542932987, 48.18530559539795, 40.320981591939926, 16.676936522126198, 2.202425468713045, 0.038787287048762664, 0.017661333549767733, 0.04751802363898605, 0.022770235482312273, 0.05271037451166194, 0.03520445039612241, 0.008345362493855646, 0.014892112467350671, 0.0607578825292876, 0.014782963880861644, 0.060667782090604305, 0.02045985369477421, 0.03842268473817967, 0.067303532268852, 0.03587880659324583, 0.05548242595978081, 0.05191233198274858, 0.0270544610611978, 0.004793169582626433, 0.012678939037868986, 0.012348268646746874, 0.05366558165405877, 0.04635800971300341, 0.014981480962887872, 0.02513258430553833, 0.04944031228660606, 0.18031053710728884, 0.06707299151457846, 0.14203363243723288, 0.3051944577600807, 0.19278632156783715, 0.09085352561669424, 0.16368114505894482, 0.3284686245024204, 0.13746571348747239, 0.09144919560640119, 0.16338519140845165, 0.14825529389781877, 0.15175793407252058, 0.11160116933751851, 0.07701483889832161, 0.09614720562240109, 0.10569302816293202, 0.1927968006930314, 0.25783673801925033, 0.11058581483666785, 0.09720688118250109, 0.2111971500562504, 0.1803825848037377, 0.15932974027236924, 0.17374022951116785, 0.1478456729091704, 0.15103153476957232, 0.22511618910357356, 0.10923987807473168, 0.17672266869340092, 1.4827011013403535, 12.82680831849575, 51.138237342238426, 60.91750659048557, 60.02939164638519, 50.03873214125633, 36.7294105142355, 35.852991342544556, 35.084106400609016, 15.169183127582073, 1.950164248701185, 0.597257592016831, 1.9749579182825983, 4.015236468985677, 11.66578821837902, 7.463288772851229, 6.275673899799585, 3.7885705567896366, 9.380634538829327, 12.68515381962061, 23.344742730259895, 37.53061652183533, 46.659391075372696, 58.18331390619278, 57.96176299452782, 56.250703409314156, 53.48425805568695, 52.78063081204891, 53.00346985459328, 55.59544377028942, 55.9291722625494, 56.15097016096115, 51.912328004837036, 52.35301315784454, 55.861182510852814, 55.460653603076935, 52.2890891879797, 51.77871577441692, 49.318495988845825, 44.978121891617775, 43.317356407642365, 43.37332360446453, 42.62641668319702, 42.15320147573948, 44.75722074508667, 41.48231327533722, 41.82874448597431, 39.93125930428505, 44.10768359899521, 51.47668518126011, 52.478744611144066, 52.21434339880943, 51.98487751185894, 52.733247354626656, 52.90104255080223, 53.6075234413147, 52.682216092944145, 52.796814143657684, 47.184199914336205, 40.513030886650085, 53.511418998241425, 55.69166600704193, 52.06181958317757, 49.007292687892914, 42.319761738181114, 41.24748207628727, 41.346280574798584, 38.71593251824379, 40.349518060684204, 42.64647580683231, 46.260180696845055, 50.45818403363228, 49.15324665606022, 48.04229646921158, 43.44141215085983, 39.81588989496231, 41.730664148926735, 48.74442279338837, 51.558506190776825, 50.95809280872345, 56.440841406583786, 51.53865225613117, 51.35716259479523, 53.659033477306366, 55.71984529495239, 50.78926406800747, 46.16259053349495, 40.61575077474117, 44.74322609603405, 45.406556501984596, 49.827664867043495, 51.310812681913376, 54.132005497813225, 51.02420546114445, 52.70010933279991, 53.23314093053341, 55.80763578414917, 45.21089740097523, 30.44898971915245, 13.869805801659822, 5.651941644027829, 3.417101064696908, 7.221935698762536, 9.660779256373644, 13.604117408394814, 17.399272061884403, 12.12669113650918, 6.018980098888278, 1.959759327583015, 1.1173777794465423, 1.5563815226778388, 6.926886280998588, 19.743489772081375, 44.25736516714096, 47.98285625874996, 53.95998112857342, 55.34149579703808, 44.51824776828289, 19.463099017739296, 2.5818909192457795, 0.1169129651680123, 0.14036617503734306, 0.11392786909709685, 0.14851623302092776, 0.15877238736720756, 0.13622896891320124, 0.16149477800354362, 0.16005472949473187, 0.17753410327713937, 0.11080295982537791, 0.12912713515106589, 0.1110762037569657, 0.10711598501075059, 0.17370551184285432, 0.14252442953875288, 0.13432366802589968, 0.18261515797348693, 0.15069388726260513, 0.12420970917446539, 0.08243495860369876, 0.2464448008686304, 0.09915471455315128, 0.21384860621765256, 0.1563253632048145, 0.07635625705006532, 0.13042224221862853], [0.043400896320235915, 0.012998609872738598, 0.023568205651827157, 0.06295281767961569, 0.010720158061303664, 0.09130506310611963, 0.05759923151344992, 0.0406634029786801, 0.02237598251667805, 0.061724915794911794, 0.02496532462828327, 0.03974017497966997, 0.10991822331561707, 0.031086584640434012, 0.06542848132085055, 0.014777671440242557, 0.04305910762923304, 0.011374282385077095, 0.027613404017756693, 0.04673762938182335, 0.02637634774146136, 0.02451655349432258, 0.012598480025189929, 0.04486318699491676, 0.017858360770333093, 0.01157958362455247, 0.032040786172728986, 0.04032680189993698, 0.0560630155086983, 0.050067341726389714, 0.074733528890647, 4.02934511192143, 16.43986914306879, 44.7688215225935, 45.102401822805405, 33.003060668706894, 24.19037975370884, 24.290783666074276, 24.242780841886997, 17.119893953204155, 1.9578194129280746, 0.3973385930294171, 0.2826326637296006, 1.6464926186017692, 1.6912991018034518, 4.667584514245391, 6.671867715194821, 0.47237569000571966, 1.815501730889082, 4.220293890684843, 16.61388650536537, 26.877960339188576, 41.54243744909763, 52.297988310456276, 54.921918511390686, 51.376891136169434, 49.60307411849499, 49.44862760603428, 52.05650746822357, 49.96750496327877, 53.99471506476402, 52.14349240064621, 50.21448791027069, 49.80075851082802, 51.66697517037392, 51.53781250119209, 48.55208471417427, 48.2247094810009, 46.81693062186241, 46.6744002699852, 45.265758857131004, 42.1722574532032, 41.012612879276276, 37.82771497964859, 36.796792298555374, 39.095148369669914, 37.07605451345444, 35.29901906847954, 38.96380841732025, 44.61268790066242, 48.968945145606995, 49.74615924060345, 50.03018639981747, 50.711242854595184, 47.98607088625431, 49.90610405802727, 49.77879948914051, 49.83765833079815, 53.80652256309986, 35.24606890976429, 47.706557884812355, 49.718853905797005, 47.725921645760536, 44.41145449876785, 38.68855878710747, 37.6314365118742, 36.43102012574673, 38.262780234217644, 38.26206587255001, 40.062352269887924, 44.48396600782871, 46.938151717185974, 48.88064928352833, 44.90827023983002, 42.46196910738945, 36.69841177761555, 36.74718976020813, 37.64536656439304, 42.923378348350525, 47.59929724037647, 48.94740790128708, 47.92616330087185, 51.60768695175648, 51.176421493291855, 48.222414404153824, 47.398090437054634, 42.94250272214413, 38.49495157599449, 40.52381470799446, 45.77704422175884, 49.71351899206638, 50.41304625570774, 51.17180094122887, 50.671291798353195, 52.790039107203484, 53.061823323369026, 48.301419764757156, 37.40320175886154, 21.806087493896484, 7.54394561983645, 2.3318899841979146, 1.5605282876640558, 6.617814190685749, 5.4681996535509825, 4.392949026077986, 4.728333279490471, 3.250020705163479, 4.642810793593526, 0.2959055593237281, 0.2182610600721091, 1.6994779254309833, 8.088217489421368, 20.190585181117058, 25.01138649880886, 33.32109980285168, 41.31183162331581, 49.91420142352581, 22.10397630929947, 6.83139075525105, 0.31051031313836575, 0.024352878390345722, 0.07021966055617668, 0.03206585592124611, 0.049002953528543, 0.05297903568134643, 0.019068172805418726, 0.04358319747552741, 0.032408665065304376, 0.01095400693884585, 0.11110290623037145, 0.04082091269083321, 0.03120301647868473, 0.02154287722078152, 0.03787926194490865, 0.04529841578914784, 0.025280557420046534, 0.04922056607028935, 0.029336309125937987, 0.06533684834721498, 0.03285855127614923, 0.031294437940232456, 0.043331661363481544, 0.018247411280754022, 0.008993628489406547, 0.04711957568360958, 0.040445489867124707, 0.06805287877796218, 0.0450736749189673, 0.0645938768866472, 0.04082371429831255, 0.06591901124920696, 0.05302528261381667, 0.06339144179946743, 0.053726649275631644, 0.047033727751113474, 0.03611001528042834, 0.051105669408570975, 0.02064586187771056, 0.02172483513277257, 0.03700368353747763, 0.017222471942659467, 0.04020309330371674, 0.04919293962302618, 0.024229769078374375, 0.09741271584061906, 0.034495220679673366, 0.040839692737790756, 0.02220368365669856, 0.019057877361774445, 0.040850583754945546, 0.030616814437962603, 0.008036343333515106, 0.05327772414602805, 0.06468210340244696, 0.04001662498922087, 0.08093195370747708, 0.13332610280485824, 4.383458085358143, 23.27371124178171, 52.76559121906757, 49.7648998349905, 38.47090266644955, 29.888629987835884, 26.469662748277187, 27.107192538678646, 18.459512069821358, 2.547249128110707, 0.2401590920635499, 0.11330632783938199, 1.7898354143835604, 2.7291717287153006, 5.490162950009108, 7.322910530492663, 2.392021520063281, 4.360228506848216, 6.536550801247358, 18.026567101478577, 29.53355424106121, 43.71216282248497, 54.77687269449234, 56.50414600968361, 53.467538952827454, 50.52037909626961, 51.517593786120415, 53.179301619529724, 52.147090807557106, 54.61364485323429, 52.88415625691414, 50.75046434998512, 50.62151826918125, 53.69098216295242, 53.471878319978714, 51.65716029703617, 51.3655411452055, 47.93331831693649, 48.51741537451744, 46.2316632270813, 43.89178678393364, 42.14382737874985, 40.44438377022743, 38.8125841319561, 39.67406630516052, 38.348602429032326, 38.33205811679363, 41.538322269916534, 47.653391137719154, 51.00027434527874, 52.15092860162258, 51.68703429400921, 52.341978549957275, 50.276910960674286, 50.43017953634262, 50.99665313959122, 52.40996070206165, 53.72551091015339, 37.958815544843674, 49.749107882380486, 52.6701707392931, 48.915436416864395, 46.45479865372181, 40.44420138001442, 38.55840817093849, 38.12885642051697, 38.84390965104103, 39.948020204901695, 40.482503324747086, 46.05252183973789, 47.8509197384119, 49.76723670959473, 46.37044318020344, 43.74861426651478, 38.58141973614693, 37.87684254348278, 39.45911183953285, 46.08796253800392, 50.15405215322971, 50.31154230237007, 50.30132085084915, 49.603758081793785, 52.56553575396538, 50.125926062464714, 49.27845373749733, 44.50968682765961, 41.21352329850197, 41.05070203542709, 46.6711438447237, 50.65144546329975, 51.66770853102207, 52.962770238518715, 52.81609810888767, 53.64337831735611, 54.02165561914444, 51.68461762368679, 39.53245170414448, 24.06877677887678, 11.65115900337696, 5.073158126324415, 2.7553311875090003, 6.200440786778927, 7.598962392657995, 9.436036515980959, 5.602211337536573, 5.795098962262273, 2.01988753862679, 1.105889689642936, 0.19965133600635454, 2.5679858028888702, 8.692025039345026, 23.045187704265118, 33.16804401576519, 37.69855611026287, 46.66901595890522, 53.69249448180199, 27.18373943120241, 9.234630223363638, 0.3994447487639263, 0.03025248857738916, 0.0357513983908575, 0.05313581437803805, 0.0541260731552029, 0.0254362191844848, 0.07756825842079706, 0.028040278084517922, 0.015824881702428684, 0.02827308424457442, 0.06414081799448468, 0.03512151168251876, 0.030364625235961284, 0.038717514034942724, 0.06253014231333509, 0.04905102985503618, 0.028335198294371367, 0.020584562334988732, 0.03893315988534596, 0.03302462908322923, 0.04836914828047156, 0.021740841402788647, 0.013475921223289333, 0.005428795411717147, 0.015040056823636405, 0.02032214262726484, 0.010822947369888425, 0.16612165316473693, 0.0933356533641927, 0.1395390959805809, 0.13332815113244578, 0.1690203187172301, 0.1878507575020194, 0.18524767452618107, 0.2100177141255699, 0.15527795534580946, 0.13579420396126807, 0.20372410886920989, 0.0827692070743069, 0.1394140292541124, 0.12802333891158924, 0.16511537512997165, 0.1467010733904317, 0.12726253364235163, 0.09429775876924396, 0.157506609975826, 0.10924945920123719, 0.148712842783425, 0.12139874321292154, 0.176310108799953, 0.27423591585829854, 0.09437965476536192, 0.07462488589226268, 0.16892229585209861, 0.15324810723541304, 0.14462317863944918, 0.1459390509990044, 0.3071892022853717, 6.099227042868733, 26.587777510285378, 58.73280622065067, 57.06205867230892, 46.905712857842445, 37.281513288617134, 33.73008705675602, 33.29523079097271, 21.80776510387659, 3.479057690128684, 0.7469490158837289, 0.8962473983410746, 3.5253983410075307, 5.15049347653985, 12.033416591584682, 13.745715860277414, 3.0624907929450274, 4.203535839915276, 6.65861782617867, 19.51780468225479, 30.933579616248608, 47.49299414455891, 56.68528608977795, 58.485276103019714, 54.38993565738201, 55.10654680430889, 53.80270376801491, 56.30255162715912, 53.22639249265194, 56.8567480891943, 54.54732321202755, 50.5400962382555, 50.4235602915287, 53.82523275911808, 54.63998883962631, 53.23260895907879, 51.8705378472805, 50.64066544175148, 51.345679610967636, 50.86204916238785, 45.954209715127945, 44.83364224433899, 42.312610521912575, 40.944155752658844, 42.851999178528786, 42.39654041826725, 38.58699783682823, 42.468147575855255, 48.77258688211441, 52.763011157512665, 52.2890891879797, 53.13973434269428, 55.534829422831535, 52.55678862333298, 52.70402692258358, 54.1084885597229, 55.5921645462513, 55.57512246072292, 42.6426912099123, 51.03935904800892, 54.30262394249439, 52.82510742545128, 48.6167648434639, 42.682965248823166, 40.16501136124134, 40.08343353867531, 41.72627918422222, 42.233890146017075, 42.677193358540535, 47.659600004553795, 49.66220274567604, 52.87801578640938, 48.17258767783642, 45.1216933876276, 40.28983846306801, 40.284123569726944, 40.72955086827278, 48.618356958031654, 52.50345468521118, 52.37463399767876, 51.602420434355736, 51.01198151707649, 53.38946834206581, 52.94949755072594, 50.91995805501938, 46.6575937718153, 43.94600227475166, 43.31256106495857, 50.23268133401871, 54.20460820198059, 53.74559663236141, 55.46956792473793, 55.465866923332214, 55.971065014600754, 55.31010568141937, 51.80487737059593, 41.783701702952385, 25.715224631130695, 10.414163880050182, 3.6684134043753147, 4.242298509925604, 12.187895402312279, 11.616713851690292, 11.498462297022343, 12.196875270456076, 12.879945617169142, 10.4002870246768, 2.4620864354074, 0.6121893064118922, 2.900295308791101, 10.663991924375296, 28.517988435924053, 36.059137880802155, 46.23988218605518, 53.122810050845146, 61.29631966352463, 32.95131504535675, 10.172535795718431, 0.5124722071923316, 0.06027772411471233, 0.22329506260575727, 0.11979679518844932, 0.15202478069113567, 0.19288934650830925, 0.17347099317703396, 0.147624661331065, 0.11958566901739687, 0.13288633577758446, 0.1798474369570613, 0.08500034789904021, 0.08186081089661457, 0.10003322444390506, 0.17402019730070606, 0.13521417102310807, 0.12213021880597807, 0.18377053347649053, 0.21201103372732177, 0.21449097956065089, 0.1268758747028187, 0.13357720104977489, 0.09897206458845176, 0.10969583876430988, 0.10531866661040112, 0.0912591241649352, 0.07681821429287083], [0.04360438579169568, 0.041183310822816566, 0.022020196920493618, 0.010073330904560862, 0.032233544188784435, 0.051579467617557384, 0.05368072146666236, 0.027745272527681664, 0.05159821426786948, 0.055220726135303266, 0.02226400356448721, 0.05865152270416729, 0.03918156784493476, 0.060853690083604306, 0.029595817759400234, 0.013935485967522254, 0.0789377954788506, 0.03847268322715536, 0.025693419738672674, 0.07057615861413069, 0.09440147390705533, 0.01754905031702947, 0.018080179434036836, 0.029943812660349067, 0.02435732756566722, 0.040855767656466924, 0.07948579732328653, 0.06354978642775677, 0.07400247632176615, 0.004277114412616356, 0.13967726903501898, 1.271787362638861, 7.85069128498435, 29.791302010416985, 47.443642392754555, 37.790940552949905, 23.509420193731785, 19.89091996103525, 29.968456104397774, 19.152043908834457, 3.8623025128617883, 0.5592013278510422, 0.16245155478827655, 0.9888362581841648, 1.0520762647502124, 3.968399944715202, 9.092322159558535, 6.773805320262909, 1.5697509865276515, 3.631775532849133, 9.36358105391264, 20.85404098033905, 34.14550356566906, 47.37702816724777, 54.73227068781853, 53.78410756587982, 52.53813162446022, 52.68053278326988, 52.579013630747795, 51.17467358708382, 52.42232903838158, 51.251934841275215, 51.03675998747349, 50.020477920770645, 52.86443151533604, 51.956557631492615, 51.33798502385616, 49.386968314647675, 49.517947286367416, 48.03539223968983, 47.701944932341576, 46.825818344950676, 45.75596675276756, 40.122335851192474, 38.715628534555435, 38.57030913233757, 38.13297159969807, 36.29444785416126, 36.82970613241196, 41.4987625926733, 46.05489291250706, 48.19164365530014, 50.08892364799976, 45.56710168719292, 44.96585234999657, 44.9572192132473, 47.31538787484169, 46.472802087664604, 51.0181637853384, 36.927649676799774, 48.66696774959564, 52.67221122980118, 46.76970295608044, 45.801313519477844, 38.4952137619257, 38.45775157213211, 42.364371344447136, 43.26309911906719, 43.493929132819176, 44.91798631846905, 47.360214069485664, 48.24154257774353, 47.29282468557358, 47.39091642200947, 42.78114818036556, 39.366176426410675, 39.326894134283066, 36.614991053938866, 40.30052348971367, 43.52380312979221, 49.294177293777466, 50.48531457781792, 49.15171533823013, 51.313160955905914, 50.672636926174164, 46.89402088522911, 44.24028128385544, 37.42898717522621, 41.2843818962574, 48.906244710087776, 52.17951066792011, 51.21418006718159, 52.45955564081669, 54.29180212318897, 52.368037551641464, 52.393575981259346, 43.01479384303093, 31.82001505047083, 17.609748467803, 6.404306972399354, 2.6850351970642805, 0.6254697125405073, 4.435414597392082, 6.166279669851065, 5.54533171467483, 4.332417324185371, 2.9007553216069937, 1.7743603885173798, 0.48506760271266103, 0.25441113277338445, 3.016073671169579, 7.952944748103619, 16.523937731981277, 22.619794830679893, 38.12214218080044, 39.471651166677475, 37.248147279024124, 16.523696444928646, 2.600742895156145, 0.4356587945949286, 0.09297825730754994, 0.04034176359709818, 0.0524169367417926, 0.02873793215258047, 0.03099364177614916, 0.019231701335229445, 0.020617463596863672, 0.09852719158516265, 0.02383064947935054, 0.048083276706165634, 0.005606482263829093, 0.027639958061627112, 0.01964417773706373, 0.034550889176898636, 0.012333409922575811, 0.031691164112999104, 0.10761352823465131, 0.0481584006047342, 0.09715332780615427, 0.04869250573392492, 0.0880127030541189, 0.017307941379840486, 0.01987781510251807, 0.041131015386781655, 0.02288717940245988, 0.00968795495282393, 0.06731375906383619, 0.05729883610911202, 0.027736303673009388, 0.056550235458416864, 0.04405137391586322, 0.03610687599575613, 0.06038966224878095, 0.02373690509557491, 0.047776083229109645, 0.0394472307380056, 0.030758356842852663, 0.038419627089751884, 0.03204896464012563, 0.04200598152237944, 0.013627749794977717, 0.023103734383767005, 0.01963501221325714, 0.015275677578756586, 0.0651774943980854, 0.06188558334542904, 0.04625903689884581, 0.01177041391201783, 0.02427389903459698, 0.04655449331039563, 0.05667299039487261, 0.030174360836099368, 0.059151411114726216, 0.05022112585720606, 0.06440123761422001, 0.016487094508192968, 0.08853967243339866, 1.833021640777588, 10.674574356526136, 38.09503823518753, 55.307825803756714, 43.93361873924732, 27.058956027030945, 22.27187030017376, 33.349533677101135, 22.710967138409615, 4.173673717305064, 0.4880743398098275, 0.21633450407534838, 1.2463809759356081, 1.787941928487271, 6.205720603466034, 5.533095421269536, 8.638256024569273, 4.194671865552664, 4.616177072748542, 12.054742947220802, 22.98972398042679, 37.994704619050026, 49.883309081196785, 56.696259900927544, 54.54794257879257, 55.26711478829384, 53.865104019641876, 54.0542084723711, 53.90666238963604, 53.218500316143036, 52.328462675213814, 51.08679190278053, 50.11168822646141, 53.95430043339729, 52.32505425810814, 52.79716372489929, 50.39459824562073, 51.2228512018919, 50.44239588081837, 49.815915897488594, 48.62492300570011, 47.91715018451214, 40.77524721622467, 40.50668902695179, 40.33670514822006, 39.526755809783936, 37.42019064724445, 39.397596940398216, 42.524399757385254, 48.311907202005386, 51.907661855220795, 53.654025346040726, 47.84675136208534, 48.18125121295452, 46.75004281103611, 49.46261465549469, 48.97524520754814, 52.98569820821285, 40.15805013477802, 50.70949874818325, 53.76563675701618, 48.419791013002396, 46.92400127649307, 41.33358545601368, 38.70550587773323, 41.989274471998215, 44.27973076701164, 44.546343460679054, 45.77363580465317, 49.27541770040989, 50.99116623401642, 49.64360274374485, 48.83106954395771, 44.19019237160683, 41.70966647565365, 39.9946703016758, 37.1291034668684, 41.366039514541626, 45.34833982586861, 50.623091384768486, 53.62812973558903, 49.6081430464983, 51.178727969527245, 51.4991457760334, 49.767954871058464, 47.269224151968956, 39.44501079618931, 43.347739577293396, 50.60804419219494, 55.14406219124794, 52.20569886267185, 53.19347865879536, 54.20425862073898, 54.11589816212654, 53.47415819764137, 46.40935689210892, 35.691040232777596, 17.673944123089314, 8.80453510209918, 5.757560301572084, 4.640331901609898, 8.031368739902973, 8.647552225738764, 7.9332285560667515, 6.543491128832102, 3.9977906551212072, 2.4104087334126234, 0.15340680809458718, 0.6823374016676098, 3.3401509188115597, 11.433894261717796, 22.059013321995735, 26.665331348776817, 43.144275695085526, 45.18064722418785, 43.58368791639805, 19.788245670497417, 3.5646754084154963, 0.3781469806563109, 0.014416423637158005, 0.0250754686203436, 0.06925190740730613, 0.019959161909355316, 0.04523377472651191, 0.08419504345511086, 0.027510618419910315, 0.08655724013806321, 0.05194748009671457, 0.05723905240301974, 0.04176278715021908, 0.04634941564290784, 0.048702751082601026, 0.0204723830029252, 0.07140709683881141, 0.03331047839310486, 0.03859615062538069, 0.04504502059717197, 0.04048037822940387, 0.034031793984468095, 0.06852721504401416, 0.050025295349769294, 0.043572261929512024, 0.08124014537315816, 0.023166874452726915, 0.03299511758086737, 0.17348634079098701, 0.11665941041428596, 0.09968086014850996, 0.1081978804722894, 0.09935532449162565, 0.13624293613247573, 0.18931329308543354, 0.12353888188954443, 0.1238423386530485, 0.10903526796028018, 0.11102708842372522, 0.12581849237903953, 0.25404599611647427, 0.1894985925173387, 0.09171244280878454, 0.16280502488370985, 0.14655178296379745, 0.09994928754167631, 0.12061651956173591, 0.1857263597776182, 0.1565827103331685, 0.10310158948414028, 0.08796201436780393, 0.205877079279162, 0.10603889866615646, 0.1511673626373522, 0.19118720112601295, 0.3750193922314793, 0.18184721324359998, 0.12235829562996514, 0.24130392906954512, 1.8707854393869638, 13.24878802523017, 44.85349237918854, 61.15902543067932, 50.60706004500389, 35.17372839152813, 30.889089703559875, 38.761788457632065, 26.07372209429741, 5.543380994349718, 1.1068367888219655, 0.41829164838418365, 3.3704421808943152, 6.528243971988559, 10.266296714544296, 19.639764837920666, 15.632192082703114, 3.1562806852161884, 4.124020831659436, 12.640095837414265, 23.98914635181427, 38.03195022046566, 51.39226891100407, 57.75173306465149, 57.48616151511669, 58.618398159742355, 56.98686830699444, 56.09276868402958, 56.590914353728294, 55.79092428088188, 53.45961257815361, 52.097096890211105, 50.966406762599945, 54.039761647582054, 53.95591154694557, 54.63492751121521, 51.78964398801327, 52.58440554141998, 51.85028113424778, 52.086248472332954, 49.75216291844845, 50.56066073477268, 43.43693599104881, 42.778062745928764, 42.8398360311985, 42.16390170156956, 40.015394389629364, 41.7364626377821, 44.69109669327736, 50.22828496992588, 53.11206042766571, 55.45853711664677, 48.99288386106491, 49.47261191904545, 49.4815756380558, 50.73090299963951, 50.43874427676201, 55.483095198869705, 43.730139657855034, 53.89820784330368, 56.73387408256531, 50.86907498538494, 49.47082981467247, 42.48254120349884, 40.97499869763851, 44.99925255775452, 46.97082236409187, 47.32918493449688, 47.44281403720379, 51.098567470908165, 51.850121542811394, 51.44583463668823, 52.670364528894424, 47.71580658853054, 43.07069644331932, 42.8816793859005, 38.852770775556564, 43.3026359975338, 47.69377917051315, 52.947308868169785, 55.570862889289856, 51.57195746898651, 53.81957866251469, 55.03885343670845, 52.13667556643486, 48.770679384469986, 42.65843756496906, 45.43799601495266, 54.298390969634056, 57.00545310974121, 51.78687013685703, 56.26921981573105, 57.13028401136398, 56.88567973673344, 55.606174394488335, 47.24497005343437, 34.624380469322205, 20.845136158168316, 7.831310899928212, 5.6812309473752975, 4.296935778111219, 9.654606487601995, 14.981709737330675, 15.745354760438204, 13.997344058007002, 9.477755427360535, 5.00928545370698, 1.3676680927164853, 1.1003676359541714, 4.2940279841423035, 11.94326737895608, 25.091558396816254, 33.78858871757984, 49.28762644529343, 50.236598923802376, 47.31796033680439, 23.591132909059525, 4.388964464887977, 0.48862531024497, 0.1386413793079555, 0.12055737039190717, 0.15720124589279294, 0.11427966936025769, 0.09993706436944194, 0.14396841143025085, 0.12148415698902681, 0.18488495727069676, 0.07390018610749394, 0.11136116620036773, 0.21330225194105878, 0.1294015665189363, 0.1398162287659943, 0.11254251687205397, 0.11551930088899098, 0.12345994706265628, 0.15488789736991748, 0.15870730101596564, 0.19994951609987766, 0.08911294440622441, 0.14011338469572365, 0.13384670455707237, 0.09165344206849113, 0.1637969646253623, 0.1364012065459974, 0.15518845233600587], [0.009490271859249333, 0.05146010429598391, 0.03812057868344709, 0.024949357321020216, 0.024277277661894914, 0.014913747927494114, 0.041385123040527105, 0.014129338651400758, 0.007621550967087387, 0.08197156159440055, 0.059353612959966995, 0.04356413170171436, 0.05756022423156537, 0.02312441803951515, 0.06084287699195556, 0.007585522016597679, 0.041687956399982795, 0.09897206458845176, 0.05141324880241882, 0.030260550156526733, 0.10971717551001348, 0.06424089660868049, 0.16188219393370673, 0.07195932892500423, 0.04360654544143472, 0.0672785441565793, 0.028477453161031008, 0.07442688089213334, 0.04720010612800252, 0.07692696861340664, 0.02842370311554987, 0.058543573613860644, 6.42101657576859, 24.333290085196495, 35.59487499296665, 40.50356559455395, 28.12040437012911, 20.19537102431059, 28.493808433413506, 21.242971010506153, 7.762560239061713, 1.436079740524292, 0.191095961490646, 0.6842928717378527, 2.1226812852546573, 3.599419556558132, 3.162829871289432, 2.968513760715723, 4.333350174129009, 4.17373213917017, 7.7144168224185705, 17.97059990465641, 31.61406610161066, 43.711026683449745, 54.02397349476814, 53.25210951268673, 52.56553195416927, 53.45174320042133, 57.389171719551086, 55.13254500925541, 53.288378566503525, 48.79070810973644, 49.86605800688267, 49.5133039355278, 51.7786967754364, 52.10933983325958, 52.65641927719116, 48.50419208407402, 53.44668947160244, 52.41694092750549, 49.892793372273445, 49.38814625144005, 47.15983562171459, 43.48540619015694, 40.88561229407787, 37.96942837536335, 39.95290294289589, 38.459195494651794, 37.60516472160816, 36.18816375732422, 38.66122305393219, 39.88394424319267, 42.22426526248455, 39.530434012413025, 39.247983768582344, 41.61027900874615, 48.577813133597374, 47.85019397735596, 54.04050260782242, 36.73667572438717, 46.540168672800064, 50.57744823396206, 48.761673867702484, 45.74084356427193, 38.59007567167282, 40.49081727862358, 38.81311610341072, 38.589376509189606, 42.20751576125622, 44.20666068792343, 46.599620282649994, 48.17770980298519, 47.13405780494213, 44.1071630269289, 41.31219260394573, 39.63816963136196, 39.343256056308746, 37.236922681331635, 38.61807256937027, 43.04730869829655, 47.2089783847332, 50.664550960063934, 51.85794532299042, 49.33970645070076, 49.603655487298965, 48.89214746654034, 44.82065074145794, 39.130642265081406, 40.86020305752754, 48.53455625474453, 51.38381436467171, 51.77145056426525, 51.37869983911514, 53.17549042403698, 53.22171114385128, 50.903223752975464, 40.05390912294388, 27.16658905148506, 13.635668065398932, 7.590976171195507, 6.146424785256386, 5.785292163491249, 6.600136114284396, 6.356574883684516, 10.09922917932272, 3.5111080203205347, 4.078668840229511, 1.2995878583751619, 0.15024187479866669, 0.32399724412243813, 6.262494307011366, 10.342327784746885, 18.861815482378006, 28.586538657546043, 30.355877615511417, 38.79710756242275, 20.382630676031113, 7.802297081798315, 1.7119367443956435, 0.13399762770859525, 0.055126176521298476, 0.02496667719242396, 0.0811689808324445, 0.040633828393765725, 0.038705272309016436, 0.05498195125255734, 0.06330208721919917, 0.06558606895850971, 0.03172499862557743, 0.05097923713037744, 0.053704306919826195, 0.06151801615487784, 0.04626557150913868, 0.05317828748957254, 0.04816074208065402, 0.023817821456759702, 0.021590370961348526, 0.07901696037151851, 0.05139674714882858, 0.0641141229425557, 0.04030798103485722, 0.04344891698565334, 0.0328788304614136, 0.0364934161916608, 0.0608147607272258, 0.02065908509393921, 0.07414542138576508, 0.05260481142613571, 0.054733947763452306, 0.01370418172882637, 0.06838991772383451, 0.06033496596501209, 0.017371357898809947, 0.03635715416749008, 0.013787843108730158, 0.08864795920089819, 0.021509935140784364, 0.030425243858189788, 0.07145537354517728, 0.010423257244838169, 0.04200789255264681, 0.04832130201975815, 0.06066793423087802, 0.03910006518708542, 0.01903970587591175, 0.004012989620605367, 0.0176693079265533, 0.034497239321353845, 0.06599835425731726, 0.04169119587459136, 0.042203196135233156, 0.014035272361070383, 0.04931327515805606, 0.004064161630594754, 0.04384821470011957, 0.03532672293658834, 0.037222843457129784, 0.12324695067945868, 8.004803415387869, 28.12810655683279, 43.53303283452988, 45.12751467525959, 34.303822070360184, 25.336747840046883, 34.44804333150387, 27.085043527185917, 8.22327934205532, 1.5075780102051795, 0.1998123968951404, 0.8357451448682696, 1.764163279440254, 6.7557254154235125, 7.123883385211229, 5.841361004859209, 7.453929875046015, 4.906128589063883, 6.838189540430903, 17.77011316269636, 31.503902412950993, 46.38780064880848, 55.801483914256096, 55.31188778579235, 52.717861980199814, 54.21115145087242, 57.49267816543579, 57.42162577807903, 53.23232777416706, 48.692962154746056, 49.82581056654453, 49.90950867533684, 50.984938368201256, 53.11080649495125, 52.859506979584694, 51.95494271814823, 56.16521559655666, 54.45980250835419, 53.46129588782787, 51.43824644386768, 49.40112255513668, 45.47358110547066, 41.61198891699314, 40.51213413476944, 40.71237199008465, 39.7294445335865, 39.508095011115074, 39.15824398398399, 40.52984118461609, 42.190808057785034, 43.86494502425194, 42.27268606424332, 41.41783073544502, 43.60520236194134, 48.57862628996372, 50.02015873789787, 56.328283846378326, 39.32428367435932, 47.365077808499336, 52.64046013355255, 50.72687141597271, 48.84337328374386, 40.85823476314545, 41.70110933482647, 41.31671816110611, 40.55711232125759, 43.6949497461319, 46.48346811532974, 48.96240949630737, 49.13886062800884, 49.456162601709366, 45.97182177007198, 43.47490355372429, 41.140092238783836, 41.83307245373726, 40.27955241501331, 40.64570836722851, 45.53865261375904, 48.13756875693798, 52.510651499032974, 52.33404457569122, 50.26867300271988, 50.23515120148659, 51.25988781452179, 47.00848214328289, 41.03277839720249, 42.41598017513752, 50.34877270460129, 52.91159838438034, 54.40948560833931, 51.579610258340836, 55.87340645492077, 53.84455092251301, 51.59393168985844, 40.470085591077805, 28.640590757131577, 15.398023948073387, 10.347085129469633, 6.918048430234194, 6.033133389428258, 10.129579100757837, 6.976694008335471, 8.072397038340569, 3.519693184643984, 1.9246368622407317, 0.9121976362075657, 0.12009070051135495, 0.408558797207661, 5.7717064674943686, 12.5962851382792, 21.92754417657852, 31.676627844572067, 37.57317043840885, 44.44343738257885, 26.577852442860603, 11.705307997763157, 2.1888343105092645, 0.18304190773051232, 0.002811930521602335, 0.03821722115390003, 0.048161506492760964, 0.03833712624327745, 0.06874473110656254, 0.06383062995155342, 0.038255029867286794, 0.02283851121319458, 0.06404022729839198, 0.014396595306607196, 0.057719648684724234, 0.06749390799086541, 0.07856805750634521, 0.04441043609404005, 0.02922019084508065, 0.019875800171575975, 0.01501095906860428, 0.07401818758808076, 0.059299803542671725, 0.047979468799894676, 0.027182047379028518, 0.040342320207855664, 0.00728782756596047, 0.04411882771819364, 0.04130540895857848, 0.051940978883067146, 0.14562467724317685, 0.12859672220656648, 0.11369358049705625, 0.18078944500302896, 0.12430872651748359, 0.16626476892270148, 0.09568438748829067, 0.14210199908120558, 0.09808543560211547, 0.1782658015144989, 0.09809466791921295, 0.10720113161369227, 0.1450101047521457, 0.11888983135577291, 0.1274967851350084, 0.13669150503119454, 0.15416782116517425, 0.14485977531876415, 0.23872052785009146, 0.09120505128521472, 0.19669840461574495, 0.09985591052100062, 0.24232396652223542, 0.153594215225894, 0.19096203352091834, 0.07247041634400375, 0.16266738617559895, 0.10314581406419165, 0.2954404999036342, 0.21288372518029064, 0.11351753564667888, 0.25452488916926086, 8.821288403123617, 33.66847716271877, 49.189869090914726, 53.71341995894909, 40.004340782761574, 31.353970058262348, 37.66319900751114, 29.55798503011465, 10.2852937951684, 1.8988743633963168, 0.47843707725405693, 2.392314816825092, 4.5666182320564985, 10.967017114162445, 8.633034154772758, 5.258347364142537, 8.442945554852486, 6.54891106300056, 8.729365635663271, 19.09015852957964, 34.080344662070274, 47.93215557932854, 58.114237412810326, 56.497933343052864, 55.764842480421066, 55.88039427995682, 62.47308611869812, 57.657566517591476, 54.094737097620964, 50.01312531530857, 51.70566849410534, 50.574795976281166, 51.84248015284538, 52.204672917723656, 53.91811117529869, 51.2777354568243, 57.71785408258438, 55.77200509607792, 55.17639845609665, 54.505574852228165, 52.44852103292942, 46.26898482441902, 43.99047128856182, 40.98937712609768, 42.859853357076645, 41.000468730926514, 41.34715832769871, 40.32405562698841, 41.89466334879398, 43.10441203415394, 46.27602964639664, 42.868832275271416, 43.70811603963375, 45.45961685478687, 52.044994086027145, 52.14909330010414, 58.34843784570694, 43.50564010441303, 49.383385106921196, 53.67519401013851, 53.35349567234516, 50.57981550693512, 42.96172969043255, 44.08865801990032, 42.21223130822182, 42.77812734246254, 46.578105837106705, 47.54656746983528, 50.80731689929962, 51.34500324726105, 51.187638491392136, 46.68452672660351, 45.261119306087494, 43.91806237399578, 43.941605910658836, 41.61897674202919, 43.310547173023224, 46.18963748216629, 51.02950617671013, 54.719792157411575, 54.30853262543678, 50.79458758234978, 52.70184203982353, 53.265800178050995, 49.3916192650795, 43.124364763498306, 44.46916960179806, 53.85031521320343, 55.6227795034647, 54.72346656024456, 52.93659724295139, 56.17196783423424, 55.45610524713993, 52.25978896021843, 41.92409656941891, 29.31947562843561, 16.573285683989525, 10.664351005107164, 12.043913528323174, 10.364164263010025, 16.335391849279404, 13.749711345881224, 19.0494342148304, 10.33188309520483, 9.48838820680976, 3.9906622376292944, 0.2654908929252997, 0.770660990383476, 8.26006991788745, 17.753962129354477, 27.19808366149664, 41.088126227259636, 41.926452443003654, 50.75749397277832, 29.284901283681393, 12.097438406199217, 2.4491519294679165, 0.3519415087066591, 0.17621263512410223, 0.12889053847175092, 0.19351536291651428, 0.10336807987187058, 0.19138939183903858, 0.14146918460028246, 0.17538432410219684, 0.16679479595040902, 0.10844444419490173, 0.15989775041816756, 0.11409352388000116, 0.16044155170675367, 0.27167684223968536, 0.17482363153249025, 0.10222008131677285, 0.18060560018057004, 0.08937055870774202, 0.22378030844265595, 0.19917009776690975, 0.1533221735735424, 0.08885463990736753, 0.08959897691966034, 0.10541746130911633, 0.09491992343100719, 0.12131444265833125, 0.19710854510776699], [0.04494491600780748, 0.030562711872335058, 0.04155143462412525, 0.050771736350725405, 0.060584661550819874, 0.005316558563208673, 0.03187198097293731, 0.0121852392112487, 0.020001998673251364, 0.03718406995176338, 0.10723178973421454, 0.006633577540924307, 0.05399066831159871, 0.06830440746853128, 0.023748579078528564, 0.02812003112921957, 0.07997942942893133, 0.025370077128172852, 0.014136580157355638, 0.01778611826011911, 0.06269302146392874, 0.03152014731313102, 0.07142796603147872, 0.011594431216508383, 0.053647387903765775, 0.045232769116410054, 0.05037238668592181, 0.07765413974993862, 0.05926315257966053, 0.060148560733068734, 0.02236533269751817, 0.03670098005386535, 2.1560522820800543, 13.609970044344664, 39.39712576568127, 39.046921357512474, 33.63594710826874, 22.582237645983696, 27.977296449244022, 24.712732024490833, 13.0832489579916, 2.854493516497314, 0.4214872472221032, 0.4885098914382979, 0.8628110331483185, 5.992979519069195, 3.3617705712094903, 5.724806534126401, 9.533127956092358, 3.7341786129400134, 3.078651800751686, 12.298454269766808, 25.051455348730087, 36.235057041049004, 47.72189386188984, 53.91775019466877, 52.621863931417465, 54.78751592338085, 52.8180056065321, 53.45368109643459, 49.93506610393524, 48.13689239323139, 50.45739747583866, 50.07669970393181, 51.793637573719025, 51.81148521602154, 51.78592398762703, 48.234087377786636, 49.84278805553913, 49.672230407595634, 51.02938078343868, 49.549443796277046, 49.69821721315384, 45.929754227399826, 41.80064499378204, 40.50668142735958, 39.20098789036274, 38.63064989447594, 39.75898414850235, 38.227366134524345, 38.00719454884529, 37.34995521605015, 37.65512824058533, 37.014706805348396, 38.301070779562, 43.96864905953407, 46.97588749229908, 47.75732696056366, 53.366498574614525, 34.01899695396423, 45.605825409293175, 49.68622885644436, 48.767521753907204, 45.73045112192631, 38.46119038760662, 36.615564823150635, 37.22010858356953, 39.54081505537033, 40.517670437693596, 42.1671087294817, 44.15037050843239, 44.0293850004673, 43.58550421893597, 41.6858721524477, 39.274798929691315, 38.99964429438114, 38.803909197449684, 39.05592307448387, 38.97366128861904, 43.32252413034439, 48.005582839250565, 51.42218090593815, 48.39582949876785, 49.395244270563126, 50.34959726035595, 48.01835775375366, 45.87344504892826, 41.13763377070427, 40.65700136125088, 45.60242459177971, 49.85068783164024, 50.212192833423615, 52.22470544278622, 54.79969806969166, 45.95041751861572, 42.03025907278061, 27.75071080774069, 20.835222490131855, 7.787380982190371, 5.899033360183239, 3.3861738117411733, 5.160175357013941, 8.798474427312613, 5.262956041842699, 5.037755900993943, 3.943500118330121, 1.3132254453375936, 1.2544300127774477, 0.25653290329501033, 1.4136129710823298, 6.250961925834417, 21.30608182400465, 31.335693039000034, 32.78588332235813, 36.151108145713806, 33.904288709163666, 18.817557357251644, 4.696791647002101, 0.17878701182780787, 0.07750950258923694, 0.039704830196569674, 0.00981979470452643, 0.03528432032908313, 0.06556032385560684, 0.03956628977903165, 0.07016339091933332, 0.09033368085511029, 0.024483483393851202, 0.0909616491117049, 0.04131704212340992, 0.025405698361282703, 0.06660391707555391, 0.030137884277792182, 0.08597381558502093, 0.036180248425807804, 0.048234426212729886, 0.03075406166317407, 0.011600009383982979, 0.01715182876068866, 0.04115536154131405, 0.019975858376710676, 0.040102602797560394, 0.02868634917831514, 0.061717100979876705, 0.035464161264826544, 0.02377674729359569, 0.03881239019392524, 0.017241589666809887, 0.018966520838148426, 0.05989605240756646, 0.025114971285802312, 0.02098270972055616, 0.012229177136759972, 0.01075188301911112, 0.04424913400725927, 0.030058673000894487, 0.05569777866185177, 0.026077145339513663, 0.024252150396932848, 0.03365139134984929, 0.08674648037413135, 0.04697494594438467, 0.08503687640768476, 0.026485593734832946, 0.011561301744222874, 0.03886881939251907, 0.0879187768441625, 0.05787039001006633, 0.009871670827124035, 0.008987971468741307, 0.07433999766362831, 0.045113836240489036, 0.06842127346317284, 0.049435328764957376, 0.016113209785544313, 0.03509975933411624, 0.02521619466278935, 0.0178178357964498, 2.7290491852909327, 18.464259915053844, 44.36326168477535, 45.39613366127014, 35.017853155732155, 24.80776872485876, 26.856172308325768, 26.038800068199635, 13.933466635644436, 2.997183697298169, 0.2668415423249826, 0.34702344448305666, 1.2404407071880996, 2.793683954514563, 5.710086598992348, 11.47262368351221, 8.169928304851055, 4.999747965484858, 6.293670684099197, 14.006253629922867, 27.919319160282612, 40.95083959400654, 50.722999423742294, 58.4513059258461, 55.85127264261246, 55.709133669734, 55.070775523781776, 54.67285707592964, 51.64008781313896, 49.57124322652817, 50.99663034081459, 50.00342443585396, 51.52307689189911, 52.767244130373, 51.68503180146217, 49.192483350634575, 50.26109240949154, 53.07326450943947, 52.377248257398605, 50.40481969714165, 51.55627191066742, 46.83292396366596, 43.68559844791889, 40.67068822681904, 41.19409114122391, 40.01431904733181, 42.15335726737976, 39.613467156887054, 38.40734727680683, 39.53069619834423, 39.97086077928543, 39.25733886659145, 39.973779022693634, 46.21698081493378, 49.20672878623009, 50.428614020347595, 54.563586339354515, 38.62413324415684, 48.289104625582695, 52.722091153264046, 49.513573721051216, 48.102105259895325, 40.28525970876217, 39.51508283615112, 38.58658745884895, 40.103694051504135, 42.24347323179245, 45.951903238892555, 45.87329685688019, 45.96137993037701, 45.635581612586975, 43.709252178668976, 40.48375345766544, 40.30794449150562, 40.54759003221989, 41.048695743083954, 40.0531567633152, 45.88394768536091, 51.02973036468029, 53.32313530147076, 49.1945656388998, 49.37402620911598, 51.75801448523998, 50.290107652544975, 47.349684834480286, 42.90240727365017, 42.890905290842056, 48.52411441504955, 53.08267280459404, 52.68231488764286, 55.01448534429073, 53.76442842185497, 49.014941677451134, 45.89677579700947, 32.621036767959595, 23.942785039544106, 10.491028055548668, 7.706176964566112, 5.970887029543519, 7.167432848364115, 7.979912851005793, 3.6059815669432282, 4.950400488451123, 1.7298799753189087, 1.3279832596890628, 0.6818193232174963, 0.49628106819000095, 1.1656939680688083, 6.963130161166191, 21.24257393181324, 32.94686168432236, 37.60286204516888, 38.5847407579422, 41.27605654299259, 21.393940709531307, 6.315324297174811, 0.49710105231497437, 0.06264091527555138, 0.05155056838702876, 0.07421624453854747, 0.02047785819740966, 0.0827361889241729, 0.06341953208902851, 0.012907409200124675, 0.06965027743717656, 0.041474336612736806, 0.013979059312987374, 0.06020313456247095, 0.09781060347449966, 0.023289159980777185, 0.08721602978766896, 0.04486513513256796, 0.03775310797209386, 0.04335009631176945, 0.057012994220713153, 0.023687181201239582, 0.047997139336075634, 0.08621148837846704, 0.1435325777856633, 0.005086188966743066, 0.03959028712415602, 0.07322696168557741, 0.02738149956712732, 0.020096615080547053, 0.17127876315498725, 0.1064810183015652, 0.12466433399822563, 0.1011820170970168, 0.1583575565018691, 0.14242973149521276, 0.28851079987362027, 0.1074776632594876, 0.10684886379749514, 0.12718092708382756, 0.18365754891419783, 0.11322927806759253, 0.08496043519699015, 0.16230802342761308, 0.19215950364014134, 0.1534832493052818, 0.17894387216074392, 0.1211373959085904, 0.08522101808921434, 0.11170649493578821, 0.21284124464727938, 0.08734432485653087, 0.11897431002580561, 0.10692272233427502, 0.24559910874813795, 0.14477059885393828, 0.20643924130126834, 0.12350521807093173, 0.16258183139143512, 0.14619212335674092, 0.09649161409470253, 0.15021134284324944, 3.1075530499219894, 20.908702947199345, 52.86786273121834, 52.04167686402798, 45.46475037932396, 32.05761060118675, 37.619436755776405, 32.86710016429424, 16.680983304977417, 4.114370299503207, 0.78323510941118, 0.9103524789679796, 3.0580773297697306, 15.02519840374589, 8.968771789222956, 13.77697678282857, 14.973094649612904, 6.483723660930991, 4.986858107149601, 15.821114145219326, 30.450811721384525, 42.78817780315876, 53.10970075428486, 60.06325922906399, 56.94202311336994, 56.619074642658234, 53.63300487399101, 53.70146580040455, 51.79402515292168, 50.5844284594059, 50.751159712672234, 50.98430760204792, 51.77678547799587, 51.707405000925064, 50.905727818608284, 49.13867063820362, 50.97259283065796, 51.9175261259079, 56.002124547958374, 54.04952712357044, 53.64337831735611, 49.07516084611416, 44.66389015316963, 43.03501255810261, 42.258303835988045, 41.81637994945049, 44.12699416279793, 42.39571586251259, 40.445474311709404, 41.43156319856644, 41.598340049386024, 41.51593007147312, 41.707485392689705, 48.67501191794872, 51.875496581196785, 51.960004046559334, 55.687193647027016, 41.273829862475395, 49.54264976084232, 54.29086737334728, 53.08073490858078, 49.49982985854149, 43.41061860322952, 40.15455812215805, 41.447100564837456, 42.3517370223999, 43.06173272430897, 45.804281160235405, 47.03871712088585, 46.52949504554272, 48.793804943561554, 44.790951535105705, 42.51149944961071, 41.324028968811035, 42.66291752457619, 44.18881304562092, 43.05319458246231, 47.88491651415825, 52.78580233454704, 56.16569437086582, 50.580556467175484, 48.87627571821213, 51.894894540309906, 52.1934749186039, 48.45399297773838, 45.22147223353386, 45.27176633477211, 50.97700819373131, 55.76139986515045, 54.27118822932243, 54.63916428387165, 56.93626642227173, 48.46735306084156, 48.481993675231934, 35.621469765901566, 25.662116780877113, 9.437192603945732, 7.69751057960093, 7.836721809580922, 13.346631824970245, 20.64050193876028, 14.875431340187788, 13.159643858671188, 7.265337444841862, 5.490837413817644, 2.4277258291840553, 1.0476384591311216, 2.2397698648273945, 8.756836261600256, 30.579943992197514, 42.999955639243126, 44.70400460064411, 48.86826194822788, 46.45670995116234, 25.041026808321476, 7.303053745999932, 0.4351894900901243, 0.18231216876301914, 0.09920574462739751, 0.14870785555103794, 0.10131797112990171, 0.24700372712686658, 0.126376201515086, 0.19306403322843835, 0.159668322885409, 0.12851210252847522, 0.13270167459268123, 0.14311237377114594, 0.16992023214697838, 0.18437747668940574, 0.17071139125619084, 0.15017845085822046, 0.26143137481994927, 0.14801633718889207, 0.15343270904850215, 0.080305017036153, 0.13349678192753345, 0.1549465418793261, 0.15507368661928922, 0.15952520712744445, 0.12247997816302814, 0.1703371261828579, 0.19796140637481585, 0.09940324496710673], [0.07223597189295106, 0.0053799602392246015, 0.024707519223738927, 0.033601270406506956, 0.045399685550364666, 0.028182508831378073, 0.036368175060488284, 0.015296960518753622, 0.040724522550590336, 0.02738140494329855, 0.04663521300244611, 0.10655550766387023, 0.037105780793353915, 0.05316370428772643, 0.02795991091261385, 0.06204298173543066, 0.09581896112649702, 0.0009544362944780005, 0.020248478904250078, 0.10357465667766519, 0.018636053609952796, 0.04234946231008507, 0.05202864507737104, 0.04248778379405849, 0.04211234983813483, 0.03198654259904288, 0.047165195501293056, 0.024151754514605273, 0.058242280210834, 0.00562701702619961, 0.04140984397963621, 0.03011770899320254, 0.9469968220219016, 6.390565484762192, 27.91211474686861, 41.443790942430496, 37.200752422213554, 37.665630877017975, 30.19617598503828, 28.248277008533478, 17.278936319053173, 6.663865819573402, 0.8024322730489075, 0.5164493469055742, 1.3641655119135976, 2.174510029144585, 5.502538410946727, 10.39003612473607, 9.087921045720577, 0.982696678256616, 2.848874805495143, 9.951438009738922, 13.354683592915535, 24.06123038381338, 34.163343608379364, 43.47089856863022, 50.05985140800476, 53.69341403245926, 51.98064833879471, 49.894233494997025, 50.611984580755234, 51.01926952600479, 51.78084746003151, 51.76295422017574, 51.05670891702175, 51.37997277081013, 51.59540981054306, 49.888188019394875, 50.0178636610508, 48.457511588931084, 48.58261227607727, 49.8048584908247, 49.08318221569061, 48.81563097238541, 44.68372508883476, 41.346409767866135, 38.91069106757641, 39.261362850666046, 41.40764348208904, 39.35532420873642, 39.56804059445858, 37.534644305706024, 39.74783554673195, 39.09818060696125, 45.15043884515762, 47.412582859396935, 48.769041672348976, 46.069571524858475, 54.522863924503326, 33.11201222240925, 44.13215048611164, 53.91251787543297, 47.10867136716843, 47.0784667879343, 39.73969258368015, 40.456254333257675, 40.41807018220425, 40.16811199486256, 36.69392801821232, 42.13761851191521, 39.0914511680603, 38.558282777667046, 37.31395974755287, 39.417276084423065, 38.77693444490433, 41.48816496133804, 40.5768446624279, 43.97602066397667, 43.94434556365013, 46.72846756875515, 48.433949053287506, 52.03872822225094, 50.408984273672104, 48.74060019850731, 51.68180197477341, 50.70972293615341, 47.462234795093536, 45.22198900580406, 40.45698009431362, 46.445918530225754, 48.16705137491226, 53.82837899029255, 45.667275711894035, 50.94892010092735, 41.611536741256714, 27.76536662131548, 18.217674046754837, 9.900621436536312, 3.7333457451313734, 4.090980179607868, 4.22005545347929, 1.8379042600281537, 3.2150193583220243, 2.6573420455679297, 3.394680842757225, 0.709921665256843, 0.45029406552203, 0.11625519226072356, 0.45311862020753324, 2.2678420459851623, 12.642355766147375, 24.609670154750347, 32.98504203557968, 39.693361669778824, 37.04081140458584, 25.671534575521946, 11.380157545208931, 2.5928029837086797, 0.09590411515091546, 0.028286851083976217, 0.033789965164032765, 0.03489134200208355, 0.039440028194803745, 0.03926176803361159, 0.01961883153853705, 0.009217236656695604, 0.10482910889550112, 0.01764961503795348, 0.0554861033015186, 0.025081890053115785, 0.02395502229774138, 0.041825802909443155, 0.05331876491254661, 0.022411369973269757, 0.02960944544611266, 0.032871857983991504, 0.04075394128449261, 0.00278441052614653, 0.05655924142047297, 0.04835348154301755, 0.014558394632331328, 0.06065748479159083, 0.032669370411895216, 0.019773263193201274, 0.0583157788059907, 0.010111626652360428, 0.015949028165778145, 0.04012391727883369, 0.06561290501849726, 0.019014027566299774, 0.023564279690617695, 0.024468109804729465, 0.02967443531815661, 0.022870377179060597, 0.04156098606472369, 0.0515144629025599, 0.02446671642246656, 0.05256122509308625, 0.0071527228283230215, 0.0062104568860377185, 0.023196768161142245, 0.04282140886061825, 0.05297975927533116, 0.030551820855180267, 0.06471771906944923, 0.044222194046596996, 0.011635199243755778, 0.031410628580488265, 0.02622775122290477, 0.030611101756221615, 0.05770321382442489, 0.03288966210675426, 0.0691144097072538, 0.049563419743208215, 0.05449137679534033, 0.022130956895125564, 0.0016031449695219635, 0.024512759264325723, 1.1279144953005016, 9.125699568539858, 34.87069845199585, 45.448453053832054, 42.12264731526375, 39.519038423895836, 32.04376794397831, 30.129765048623085, 19.92747399955988, 6.73813140951097, 0.9387572016566992, 0.17583779117558151, 1.2630721740424633, 2.655802653171122, 5.548732532188296, 8.829388618469238, 7.66722715459764, 4.00822869502008, 4.585904572159052, 12.019971963018179, 17.896036505699158, 29.02750689536333, 40.566710606217384, 47.14163839817047, 51.36961832642555, 55.387993901968, 52.04393394291401, 51.332285329699516, 52.40323506295681, 52.35775530338287, 51.790430545806885, 52.59783782064915, 51.08842581510544, 51.3277255743742, 51.25495187938213, 50.47141872346401, 51.08986213803291, 49.50234152376652, 50.2780395001173, 51.621396616101265, 52.04791992902756, 52.289738953113556, 47.57215529680252, 43.632769882678986, 41.418887078762054, 41.253755539655685, 42.6469773799181, 42.34786503016949, 41.533298939466476, 40.0077074021101, 40.56947685778141, 40.427425280213356, 46.3261641561985, 50.8240170031786, 52.22195439040661, 49.06482920050621, 56.018152087926865, 35.644982904195786, 46.686084643006325, 54.662422835826874, 49.3893887847662, 49.20864388346672, 42.147212997078896, 41.03503167629242, 41.15638196468353, 42.32370212674141, 39.366624802351, 44.78272117674351, 40.968356654047966, 40.118460059165955, 40.28049096465111, 41.42991028726101, 40.418617352843285, 43.10260333120823, 43.7384308129549, 45.80409117043018, 47.219093441963196, 48.25937882065773, 50.72828494012356, 52.846671268343925, 50.09750358760357, 48.92766796052456, 53.14586341381073, 50.6285896897316, 49.32940900325775, 46.37219488620758, 43.3034947514534, 47.27391690015793, 51.48335762321949, 53.35755005478859, 48.151928186416626, 52.59318307042122, 45.15643112361431, 33.55268597602844, 23.133996538817883, 11.827123761177063, 3.718855935148895, 0.9184865956194699, 3.561726054176688, 1.5515018720179796, 4.784646732732654, 4.610254615545273, 2.1925633354112506, 1.331810129340738, 0.23598716827109456, 0.385532389045693, 0.46481115685310215, 2.4906457029283047, 12.380231581628323, 27.563966028392315, 36.32510840892792, 43.17937061190605, 41.617016047239304, 31.819695867598057, 15.71427147835493, 3.4461728297173977, 0.06674976393696852, 0.11032264927052893, 0.03714698112162296, 0.10390219613327645, 0.027018247965315823, 0.0679230919922702, 0.024229633636423387, 0.0452675276028458, 0.04633168202417437, 0.06989471861743368, 0.04197114882117603, 0.03919113783922512, 0.0271560462351772, 0.030794414087722544, 0.06305015034740791, 0.009410534585185815, 0.03792842180700973, 0.02841961759258993, 0.03115781226370018, 0.09991963874199428, 0.04546388874587137, 0.017244155642401893, 0.048390696538263, 0.017887159810925368, 0.03129725439066533, 0.01337514406259288, 0.07145964831579477, 0.05930366642132867, 0.18207926797913387, 0.16194867552258074, 0.14207112573785707, 0.13256624748464674, 0.17926850239746273, 0.1040700328303501, 0.11923032128834166, 0.15464132622582838, 0.09311470115790144, 0.17225789342774078, 0.14818501251284033, 0.15183787822024897, 0.11702379008056596, 0.13485694566043094, 0.11854643962578848, 0.17296106350841, 0.1627929724054411, 0.1164383691502735, 0.20872195396805182, 0.23459299933165312, 0.11680455965688452, 0.14808209147304296, 0.0870296468201559, 0.18864408368244767, 0.2960764610907063, 0.11373951943824068, 0.1720183133147657, 0.15313671086914837, 0.13764997391263023, 0.10632383142365143, 0.10825806122738868, 0.1262122907792218, 1.3711736421100795, 10.979363601654768, 38.73585104942322, 53.25425639748573, 48.22414331138134, 50.812800005078316, 39.54328492283821, 39.83638219535351, 23.767703734338284, 7.820179872214794, 1.7194509599357843, 0.9560510236769915, 2.0145367132499814, 4.335425812751055, 12.677200846374035, 17.37606480717659, 18.024154230952263, 4.350925181061029, 4.359673261642456, 12.640367522835732, 18.005635924637318, 30.689106434583664, 42.66673631966114, 49.36317399144173, 52.29687497019768, 54.94818650186062, 52.292224019765854, 51.28618620336056, 53.053186386823654, 53.35408844053745, 52.464191392064095, 53.0202991515398, 51.919889599084854, 52.019809037446976, 51.66055351495743, 51.20246149599552, 49.84444856643677, 51.02146580815315, 50.52506424486637, 52.5075850635767, 53.968253284692764, 54.467793479561806, 49.092890694737434, 45.55893212556839, 43.594756722450256, 43.77579800784588, 45.154975801706314, 44.10856515169144, 43.546803295612335, 41.64989188313484, 43.91326703131199, 43.24710197746754, 48.96102637052536, 53.334933668375015, 53.788819313049316, 51.90787464380264, 57.22867213189602, 40.37757955491543, 47.57150933146477, 56.80527605116367, 50.835925564169884, 51.87008187174797, 44.19905349612236, 42.63049766421318, 43.24222303926945, 44.22229304909706, 40.09141691029072, 45.90863116085529, 41.90265811979771, 42.44448624551296, 41.43321231007576, 42.67002314329147, 43.56739059090614, 45.91113522648811, 45.12628734111786, 47.16729462146759, 49.55030634999275, 50.49620099365711, 52.926805168390274, 56.57621294260025, 50.17902061343193, 48.71134176850319, 53.16275350749493, 54.79565508663654, 51.72739192843437, 49.00270253419876, 44.90382827818394, 49.45240840315819, 52.844828367233276, 55.87650328874588, 48.25293816626072, 55.28994396328926, 48.50449986755848, 36.84084713459015, 25.216292403638363, 13.304413240402937, 6.12508038058877, 7.801197515800595, 10.785661395639181, 12.104497477412224, 18.110510297119617, 13.758061397820711, 9.942973013967276, 6.506256926804781, 2.1809604205191135, 0.8921996655408293, 1.155207718256861, 4.09207072108984, 18.2979504391551, 33.03303346037865, 44.528549015522, 53.182113468647, 47.557298094034195, 37.77142480015755, 17.120209336280823, 3.823854513466358, 0.20535638846922666, 0.1770780683727935, 0.16539710923098028, 0.202949202794116, 0.12838593742344528, 0.14543345547281206, 0.10713085765019059, 0.1490466608083807, 0.2653631544671953, 0.12466856423998252, 0.17246572446310893, 0.14409154857276008, 0.12025205083773471, 0.11653649591607973, 0.17495720327133313, 0.13350733526749536, 0.14303329051472247, 0.14825159800238907, 0.1609114054008387, 0.20661708957049996, 0.19120988115901127, 0.19438815827015787, 0.09061500677489676, 0.29732258641161025, 0.1208921532088425, 0.09401426577824168, 0.2025489477091469, 0.11759945919038728], [0.037089104735059664, 0.04691477261076216, 0.05740226923080627, 0.03587316256016493, 0.07041554301395081, 0.05926167199504562, 0.05344543096725829, 0.013291595860209782, 0.03798916659434326, 0.038694711547577754, 0.08294238723465241, 0.027379759230825584, 0.036373295879457146, 0.03411069541471079, 0.05910469662921969, 0.041968135701608844, 0.052042686511413194, 0.01654867792240111, 0.026675691151467618, 0.06037753184500616, 0.007688266332479543, 0.03379407666216139, 0.08003310154890642, 0.0744046238833107, 0.08332722791237757, 0.02833179369190475, 0.027435062220320106, 0.07115412838174962, 0.05505452587385662, 0.07550758891738951, 0.06359717997838743, 0.017619942118471954, 0.14610925514716655, 3.0806801794096828, 18.24434481561184, 44.299189522862434, 44.24234077334404, 35.10654799640179, 27.518087290227413, 26.656494922935963, 21.765526570379734, 9.907988291233778, 2.9329892294481397, 0.1788644029875286, 1.2708649621345103, 1.4682204346172512, 3.7076151883229613, 11.28784054890275, 3.2952278293669224, 4.775550020858645, 2.6653087930753827, 1.9672905234619975, 8.090010043233633, 15.9779754281044, 29.09330416470766, 40.83018086850643, 51.907388269901276, 49.885642156004906, 51.439473778009415, 52.25756607949734, 52.23873808979988, 53.69858555495739, 52.21680946648121, 52.74395138025284, 51.58063240349293, 53.357880637049675, 50.15572026371956, 48.624265640974045, 52.107215747237206, 49.011031687259674, 50.91521970927715, 50.20822964608669, 51.3169189542532, 48.004408702254295, 48.45954068005085, 43.818146735429764, 40.05214981734753, 37.3444265127182, 38.9934316277504, 38.283242136240005, 38.95207464694977, 38.797700330615044, 40.24126946926117, 41.88405431807041, 49.40016880631447, 48.27730245888233, 50.97357697784901, 47.57228448987007, 59.83797311782837, 35.17625145614147, 41.56563900411129, 52.78039142489433, 47.99758046865463, 49.25096981227398, 44.00508150458336, 38.98941904306412, 37.348674684762955, 37.30131022632122, 40.594487115740776, 39.24299083650112, 36.68758995831013, 38.144074603915215, 36.737735867500305, 38.62080082297325, 43.16844619810581, 43.31948049366474, 48.33393082022667, 50.14307074248791, 47.1918299049139, 45.88519021868706, 50.292474925518036, 50.809874162077904, 49.69631731510162, 52.59897015988827, 51.32602706551552, 49.72524516284466, 48.86229246854782, 43.79191294312477, 41.65816403925419, 44.21877443790436, 47.02713154256344, 48.70261363685131, 55.31224496662617, 40.673044100403786, 39.019395634531975, 23.254885151982307, 11.98409428820014, 7.329952027648687, 2.7535987179726362, 0.7199179194867611, 1.0413197544403374, 2.9245636565610766, 1.7899184161797166, 2.002403726801276, 1.117981115821749, 1.2447186838835478, 0.22635961300693452, 0.24380913760978729, 1.2492011371068656, 4.9785517528653145, 13.249498587101698, 24.30297341197729, 33.21481570601463, 34.58250291645527, 37.26462699472904, 16.27589274197817, 6.387477200478315, 0.22259098710492253, 0.023049167975841556, 0.01772989871824393, 0.05347531354345847, 0.00959310847974848, 0.039636482106288895, 0.03290788554295432, 0.014242185916373273, 0.01495573307693121, 0.03186479698342737, 0.07011414199951105, 0.07392512969090603, 0.04076657263794914, 0.03788431225984823, 0.04015981496195309, 0.0509280771802878, 0.08487884348141961, 0.07588151260279119, 0.04650148541259114, 0.06270122961723246, 0.03111468606221024, 0.08139963290886953, 0.04940981372783426, 0.049853551245178096, 0.03685238931211643, 0.05692907587217633, 0.02992586938489694, 0.06962048020795919, 0.059008354728575796, 0.04347229463746771, 0.050579137896420434, 0.0729409973428119, 0.03387590215425007, 0.027860179252456874, 0.039905473531689495, 0.029812573120580055, 0.014621917835029308, 0.026789954063133337, 0.017072001501219347, 0.012856225130235543, 0.022514153715746943, 0.016503486695000902, 0.02155518017389113, 0.009361930406157626, 0.03413252197788097, 0.04797924615559168, 0.1291735639097169, 0.034448135120328516, 0.04493940927204676, 0.03782834319281392, 0.047288915229728445, 0.08287141565233469, 0.13926055311458185, 0.08395975295570679, 0.04926600777253043, 0.03285543425590731, 0.01990559554542415, 0.00555646939574217, 0.06570375873707235, 0.010149235913559096, 0.06329481417196803, 0.21704514016164467, 3.965413304977119, 22.820120081305504, 50.07477320730686, 50.69341421127319, 38.36511254310608, 31.055060997605324, 33.126390650868416, 24.844586849212646, 11.9277860596776, 2.7066603116691113, 0.3579841641476378, 0.26730348472483456, 2.5589128397405148, 5.605303896591067, 7.517291475087404, 6.173141626641154, 3.6526081524789333, 2.820128872990608, 3.2879533572122455, 10.263253077864647, 19.951281622052193, 32.36477471888065, 42.911211401224136, 51.62883661687374, 52.61785514652729, 53.04607316851616, 52.44930379092693, 53.35424803197384, 53.58997978270054, 53.656537011265755, 53.728372156620026, 53.24226424098015, 52.848369777202606, 51.406107768416405, 49.55252543091774, 53.39804068207741, 51.333288475871086, 51.57604604959488, 51.61957271397114, 53.76832701265812, 50.74175901710987, 50.36177180707455, 45.6019002199173, 41.99302867054939, 38.55514034628868, 40.730523616075516, 39.915615543723106, 40.36887802183628, 40.933865904808044, 42.07632400095463, 44.15179543197155, 50.63904292881489, 50.75246684253216, 53.90150986611843, 50.667982175946236, 58.12130503356457, 36.358197033405304, 45.18941715359688, 53.12535211443901, 49.235402047634125, 50.85706003010273, 46.05450913310051, 40.029142051935196, 39.6931716799736, 39.294204488396645, 40.9735281765461, 40.20050145685673, 38.82008872926235, 38.83156791329384, 38.97311411798, 41.25598601996899, 44.997998625040054, 46.02788396179676, 50.00764220952988, 50.87126366794109, 49.86476227641106, 48.566854521632195, 51.89693883061409, 52.963336408138275, 50.614549443125725, 52.09145039319992, 51.78396709263325, 53.223550245165825, 49.24894832074642, 46.97515033185482, 43.56211647391319, 46.02781556546688, 49.288773983716965, 52.07948103547096, 53.235907182097435, 45.53834103047848, 43.73564176261425, 26.837245523929596, 15.08739821612835, 8.980968184769154, 3.4313408005982637, 2.438946864567697, 3.119285157881677, 1.855611428618431, 0.8195172843988985, 1.583393441978842, 1.5485070389695466, 0.08000546396942809, 0.11094616464106366, 0.1529782623401843, 1.496546370908618, 5.480559440329671, 18.128971606492996, 29.94933743029833, 36.96844048798084, 40.08383631706238, 40.14649115502834, 20.248570069670677, 8.732537515461445, 0.46710504626389593, 0.04458577219338622, 0.046557450768887065, 0.029833700209564995, 0.044916406404809095, 0.03748333729163278, 0.0591977805015631, 0.033298021444352344, 0.0191308564535575, 0.052428525377763435, 0.07578363074571826, 0.07086319907102734, 0.024374435924983118, 0.039161938038887456, 0.02518334164051339, 0.09130975347943604, 0.04480457959289197, 0.03770749186514877, 0.026022881356766447, 0.03771780029637739, 0.017992802677326836, 0.06275642313994467, 0.014369433629326522, 0.017304707471339498, 0.07085684628691524, 0.01674595747317653, 0.031330999845522456, 0.055046132183633745, 0.023501301038777456, 0.12632468162337318, 0.1095165878359694, 0.09780324136954732, 0.09598131335224025, 0.1633437944110483, 0.235011407348793, 0.1237878279061988, 0.1181377463217359, 0.13469416298903525, 0.0926885822264012, 0.11854615018819459, 0.15882362524280325, 0.12119806648115627, 0.09705853328341618, 0.16836644208524376, 0.1444005937082693, 0.10728143941378221, 0.16793724324088544, 0.08042518558795564, 0.10138947705854662, 0.12702022242592648, 0.14286728692241013, 0.18316595029318705, 0.15643419174011797, 0.11278289850451984, 0.15415649599162862, 0.09681300114607438, 0.13563860527938232, 0.1656582858413458, 0.20712736062705517, 0.21742390264989808, 0.09493090721662156, 0.35210887785069644, 4.648893792182207, 24.42737303674221, 55.974306240677834, 58.55740383267403, 45.7317316532135, 37.97711916267872, 37.71999076008797, 28.672431148588657, 14.222795460373163, 3.74065441545099, 0.4537467146292329, 2.6204158645123243, 5.194633807986975, 9.652465302497149, 20.99678222090006, 6.313396375626326, 8.992778901010752, 5.075756711885333, 2.7296269917860627, 8.633640222251415, 17.095349170267582, 31.973027139902115, 43.04063245654106, 54.19457674026489, 54.294249191880226, 54.51115295290947, 52.96888031065464, 52.335074320435524, 55.25245517492294, 55.39383798837662, 54.680156484246254, 53.27272720634937, 53.53812016546726, 50.69523051381111, 48.6778199672699, 53.319179713726044, 52.25195378065109, 52.47124761343002, 52.72003546357155, 55.13890206813812, 53.19003224372864, 52.212800681591034, 47.437562718987465, 44.24317292869091, 40.7384841889143, 43.218801096081734, 41.96282409131527, 43.06394420564175, 44.47008155286312, 44.963663667440414, 47.013752460479736, 52.52707801759243, 53.37188668549061, 55.68620190024376, 51.74172095954418, 56.125967502593994, 40.52904322743416, 47.280756533145905, 53.21896769106388, 51.571873873472214, 52.22742609679699, 48.502497375011444, 42.26550064980984, 40.95472298562527, 41.6194137185812, 44.15284797549248, 42.1689136326313, 40.821866914629936, 40.8536484092474, 41.22197404503822, 43.31255346536636, 46.09681226313114, 48.13153848052025, 54.62321653962135, 54.07731123268604, 51.98623403906822, 49.66957814991474, 54.8859154433012, 54.221889674663544, 50.67415304481983, 53.11962582170963, 53.24216164648533, 54.55905318260193, 50.37178426980972, 49.17611762881279, 44.90132801234722, 48.342073783278465, 51.765838265419006, 53.73365007340908, 56.934324726462364, 45.991048738360405, 43.751338720321655, 29.62344791740179, 16.198559291660786, 9.923727046698332, 4.347147708758712, 4.503199635073543, 9.189026020467281, 7.486646119505167, 5.582104241475463, 4.90093189291656, 6.174138123169541, 2.452728725038469, 0.5757488461676985, 1.0285479272715747, 2.4176779808476567, 6.890014009550214, 20.027364939451218, 36.59310422837734, 44.94793251156807, 48.30736264586449, 47.69683040678501, 23.112438395619392, 9.680003374814987, 0.6236462260130793, 0.12156524404417723, 0.1403269896400161, 0.12680167477810755, 0.19754054927034304, 0.13748612254858017, 0.3072322765365243, 0.12324635696131736, 0.1082922297064215, 0.18850248190574348, 0.14114838384557515, 0.1269090932328254, 0.11411088271415792, 0.19897139514796436, 0.10410831280751154, 0.17424453370040283, 0.206372611282859, 0.15457978734048083, 0.1882683639996685, 0.1662554920767434, 0.1673093269346282, 0.15814944345038384, 0.16020219423808157, 0.15063374361488968, 0.30415435263421386, 0.09124768024776131, 0.12728368485113606, 0.19033474061870947, 0.23385379055980593], [0.047317651187768206, 0.0472299887042027, 0.039474055665777996, 0.027914448801311664, 0.047256910111173056, 0.021047360060038045, 0.055908648791955784, 0.02567884210293414, 0.09553166091791354, 0.038250324651016854, 0.013924336126365233, 0.11312947404803708, 0.02895106026699068, 0.05320611431670841, 0.040930245886556804, 0.0017662881623436988, 0.02142162513337098, 0.03060659691982437, 0.014284826938819606, 0.040355404271394946, 0.03457657490798738, 0.03688618300657254, 0.06966897213715129, 0.03479187565972097, 0.04400156838528346, 0.051300895065651275, 0.047514940015389584, 0.020503996638581157, 0.016624143208900932, 0.028035793657181785, 0.045005274878349155, 0.028774831735063344, 0.05613996137981303, 0.17361332225846127, 8.232575543224812, 27.238878272473812, 38.52808199822903, 37.26276509463787, 21.530182398855686, 25.82078106701374, 23.518207222223282, 12.73930661380291, 5.275862999260426, 0.6184395554009825, 0.0908924883697182, 2.794867353513837, 4.017170090228319, 2.8817515913397074, 5.027315961197019, 2.2595991007983685, 2.0960544515401125, 1.8989235232584178, 4.348791120573878, 10.054448582231998, 21.41332156956196, 34.106122478842735, 41.4038360863924, 47.59260579943657, 51.68687470257282, 52.548322677612305, 54.744840413331985, 56.47831119596958, 52.99066074192524, 55.7012414932251, 52.05994628369808, 51.98913708329201, 52.11951568722725, 50.60235969722271, 52.06335850059986, 48.78150500357151, 53.0875289440155, 51.10473074018955, 51.94133564829826, 49.18796919286251, 49.934047758579254, 45.20322561264038, 44.665900245308876, 40.317652970552444, 40.641479194164276, 42.80515909194946, 44.57171089947224, 42.99608364701271, 41.31364032626152, 45.35414211452007, 53.68460230529308, 50.600744783878326, 55.197969898581505, 47.296423092484474, 67.46062248945236, 35.90084217488766, 41.690059527754784, 54.70062978565693, 50.1325149089098, 49.23905745148659, 45.85720472037792, 41.97809547185898, 37.974037528038025, 41.52688108384609, 39.781585335731506, 37.50783674418926, 35.83085373044014, 37.36425384879112, 41.53704933822155, 43.08922804892063, 46.24802514910698, 48.537417501211166, 50.07320009171963, 52.38892883062363, 48.51988524198532, 49.577182307839394, 49.798482432961464, 46.799269169569016, 46.91552773118019, 48.53965178132057, 49.25230734050274, 48.37555758655071, 48.45574468374252, 44.7351249307394, 43.0240273475647, 44.471605271101, 48.922690227627754, 48.838851526379585, 51.32348120212555, 44.16978366672993, 28.25526673346758, 19.237130843102932, 6.73125377856195, 1.3148676697164774, 0.40816195600200444, 2.4957716278731823, 3.518351619131863, 0.35943242080975324, 0.7082754629664123, 1.257696293760091, 0.40813375439029187, 0.07276537551661022, 0.026109868485946208, 0.22779231425374746, 1.7591171502135694, 8.05903410539031, 14.054094962775707, 25.11960469186306, 33.53822395205498, 34.61547754704952, 26.061488650739193, 11.055668257176876, 2.2044438729062676, 0.16497159143909812, 0.01870136631623609, 0.05617754373815842, 0.030641260782431345, 0.05288528758683242, 0.028911589142808225, 0.054030002138460986, 0.03431858211115468, 0.031515401278738864, 0.024035827336774673, 0.01627587556868093, 0.022115646388556343, 0.08081365536781959, 0.09480028180405498, 0.0037496563754757517, 0.042672931085689925, 0.046125353837851435, 0.02131305078364676, 0.010807142407429637, 0.03741085543879308, 0.041603585341363214, 0.05151267803739756, 0.0186216893416713, 0.019613072472566273, 0.02593338391307043, 0.08514189030393027, 0.017480665119364858, 0.04719038028270006, 0.006090799952289672, 0.028795107209589332, 0.027726557418645825, 0.017948587374121416, 0.042536093897069804, 0.08108854686724953, 0.03986174619058147, 0.08093230993836187, 0.06480980475316755, 0.065185991988983, 0.05200560510274954, 0.026424806274008006, 0.05006552346458193, 0.03910362378519494, 0.011642333138297545, 0.03728528776264284, 0.050344036644673906, 0.027954272445640527, 0.019592993667174596, 0.03400330664590001, 0.017085310064430814, 0.02565237711678492, 0.03650627761089709, 0.004830271864193492, 0.0031599217118127854, 0.02554265985963866, 0.03849243177683093, 0.0205503975666943, 0.07158041058573872, 0.018849109364964534, 0.02599947216367582, 0.02399821714789141, 0.02653412833751645, 0.05810404778458178, 0.5178550339769572, 11.914996895939112, 34.586770087480545, 45.402293130755424, 41.3391749560833, 25.91032326221466, 27.744201757013798, 27.96071033924818, 14.947500173002481, 5.989378737285733, 0.2939799235900864, 0.2199234114959836, 0.6634346628561616, 4.27437306381762, 4.965162221342325, 6.132837189361453, 3.0415570037439466, 1.0862877289764583, 1.4859889936633408, 5.971325431019068, 14.517964571714401, 26.207474917173386, 37.16309644281864, 45.46640329062939, 51.16287901997566, 52.12607033550739, 55.296791195869446, 55.68057060241699, 57.268140614032745, 56.06002204120159, 55.64978085458279, 52.64038033783436, 55.48871889710426, 52.28976175189018, 51.36059381067753, 52.09156818687916, 51.47486887872219, 52.773806378245354, 53.89459043741226, 53.40315140783787, 51.984204947948456, 50.990923047065735, 48.67303602397442, 46.59394718706608, 43.344741538167, 40.43404832482338, 44.18003171682358, 45.98257519304752, 44.18985418975353, 42.19517022371292, 47.635281309485435, 54.2150766402483, 52.41219878196716, 55.04339799284935, 49.729538932442665, 63.303725346922874, 39.99846629798412, 44.45164114236832, 54.66950945556164, 51.186411157250404, 51.964609399437904, 48.0762742459774, 43.03928732872009, 39.22095961868763, 42.24169112741947, 41.438197642564774, 39.36939485371113, 38.20039138197899, 37.73353323340416, 41.68594054877758, 43.57210233807564, 49.71646003425121, 49.90032456815243, 52.81814619898796, 54.27941478788853, 51.12754091620445, 52.03517161309719, 52.10560843348503, 47.94669359922409, 48.283454328775406, 51.80160574615002, 50.65701596438885, 50.935115441679955, 50.46545684337616, 46.91651187837124, 46.796491518616676, 45.275835916399956, 51.394187808036804, 51.46510720252991, 53.4199845045805, 46.418385207653046, 33.81440833210945, 21.420727372169495, 7.8378622233867645, 3.6101608676835895, 2.1363002294674516, 3.094028625637293, 1.3439361099153757, 0.13992627442348748, 0.09773991390829906, 0.291491057141684, 0.3204435738734901, 0.15133991197217256, 0.07630947948200628, 0.3141684480942786, 1.9005480548366904, 9.54267779365182, 15.712500773370266, 26.626613326370716, 39.90760937333107, 40.41980288922787, 33.063944801688194, 13.93457617610693, 3.4044028585776687, 0.10450540634337813, 0.0569264264049707, 0.02377865275775548, 0.05443269146780949, 0.028009838897560257, 0.02178936672862619, 0.03422032175876666, 0.08165770734194666, 0.024461387802148238, 0.01780427119228989, 0.044252258448977955, 0.03863869053020608, 0.03982945534517057, 0.04982889338862151, 0.036571516102412716, 0.017055256794265006, 0.07235182114527561, 0.02716488335863687, 0.023454844449588563, 0.04975064504833426, 0.03763071297726128, 0.05277314536215272, 0.010778991818369832, 0.007436010801029624, 0.03711860139446799, 0.03351547071360983, 0.039139031650847755, 0.02338483765925048, 0.0556401842914056, 0.1426047892891802, 0.18652445054613054, 0.07775012913043611, 0.14895678672473878, 0.20839140139287338, 0.10046384821180254, 0.22101368580479175, 0.1582590289763175, 0.2881326904753223, 0.2917142357910052, 0.16786927735665813, 0.19366374792298302, 0.08051065131439827, 0.0777180164004676, 0.11306181986583397, 0.10952636192087084, 0.0890591906500049, 0.1519231213023886, 0.1247323740972206, 0.12016345324809663, 0.12023439514450729, 0.07226646674098447, 0.16078495827969164, 0.11311831956845708, 0.16892484884010628, 0.1391439765575342, 0.21987254469422624, 0.2065519438474439, 0.1470309283467941, 0.11189283337444067, 0.07624231511726975, 0.09229759656591341, 0.17915246018674225, 0.6958060164470226, 13.511676918715239, 37.54104696214199, 54.4026155769825, 48.32105711102486, 30.168604664504528, 35.55455535650253, 32.50809542834759, 16.87501799315214, 7.135360194370151, 0.9291072038467973, 1.0452992096543312, 4.068794595077634, 8.534809425473213, 10.506434328854084, 14.67880329117179, 8.969192616641521, 5.9261206816881895, 5.813511349260807, 6.074514118954539, 13.61739294603467, 25.899832025170326, 39.579329788684845, 47.52246916294098, 49.31812360882759, 52.60597698390484, 55.0725120306015, 56.66737385094166, 58.925809264183044, 57.029931396245956, 55.84775023162365, 54.63401176035404, 56.63813441991806, 54.049238339066505, 51.61437079310417, 52.55648463964462, 50.28625465929508, 53.27362775802612, 54.95938830077648, 55.807339400053024, 53.55498366057873, 53.31295944750309, 49.77680839598179, 47.36329950392246, 45.279248133301735, 42.57170721888542, 45.593932047486305, 47.67966292798519, 46.75711043179035, 45.131496861577034, 49.9701876193285, 56.4028662443161, 54.720426723361015, 56.74476809799671, 49.85166437923908, 65.04069954156876, 45.41069068014622, 45.318591222167015, 56.84574767947197, 53.73824402689934, 54.0605503320694, 49.03738707304001, 47.4487379193306, 42.45122328400612, 43.07586416602135, 44.07658226788044, 42.51580461859703, 39.48606379330158, 39.70633417367935, 44.98712740838528, 46.88062280416489, 51.13219566643238, 54.11381967365742, 54.74624253809452, 56.273581981658936, 51.77644729614258, 52.26666659116745, 51.64031580090523, 48.524836376309395, 48.18548038601875, 51.36198453605175, 54.493373706936836, 52.27216109633446, 51.64975829422474, 48.862037882208824, 46.82400204241276, 48.923351392149925, 52.44413986802101, 52.49694183468819, 54.39740605652332, 48.48363138735294, 33.8535538315773, 22.807645350694656, 9.292813651263714, 2.444413108751178, 0.9479410119820386, 6.316089481115341, 7.905275356024504, 2.341425810009241, 0.9769769164267927, 4.958939105272293, 4.100957494229078, 0.42627724644262344, 0.37028624152299017, 0.48032337916083634, 3.0387798277661204, 12.313789296895266, 21.3083104044199, 36.34076736867428, 45.57057090103626, 46.928257048130035, 35.836690217256546, 15.99011767655611, 3.395965648815036, 0.2484331332379952, 0.22134679136797786, 0.19758374226512387, 0.08155666393577121, 0.19990626373328269, 0.10314220722648315, 0.2218808259931393, 0.21271044854074717, 0.1452620342024602, 0.08053187673795037, 0.1344327488914132, 0.08936677375459112, 0.1983166576246731, 0.10303372007911094, 0.07090032871928997, 0.15167444245889783, 0.1793311396613717, 0.09723060022224672, 0.06731161425705068, 0.08269134094007313, 0.10802746852277778, 0.08165721010300331, 0.10974030825309455, 0.2347445607301779, 0.12259067691047676, 0.24117144086631015, 0.18646279291715473, 0.18115714949090034, 0.1076051197014749], [0.06289981349254958, 0.0566231737320777, 0.07654997985810041, 0.033121984015451744, 0.02870475629606517, 0.009310493078373838, 0.01819556298869429, 0.026908718100457918, 0.045267954337759875, 0.04266619238478597, 0.08583250324591063, 0.08184086938854307, 0.035353032071725465, 0.020906608042423613, 0.03897806724125985, 0.024743593166931532, 0.043468728617881425, 0.02519087072869297, 0.011015979052899638, 0.010228368337266147, 0.05626538804790471, 0.015793127058714163, 0.043701996764866635, 0.03385471754882019, 0.051427060170681216, 0.011358550709701376, 0.07166003560996614, 0.009170095436275005, 0.06499209848698229, 0.051450675309752114, 0.03963168783229776, 0.03876767208566889, 0.02580966418463504, 0.0676457365625538, 2.5316542899236083, 16.2353603169322, 34.670601189136505, 40.74218899011612, 23.45030676573515, 22.956604957580566, 22.37093858420849, 19.618864059448242, 6.8304783292114735, 2.042319872416556, 0.19210614322219044, 0.33676164981443435, 4.837002698332071, 5.066404463723302, 4.747029701247811, 1.2572213192470372, 0.6654938554856926, 0.7320024585351348, 2.642662008292973, 7.555311284959316, 14.596506357192993, 21.475488133728504, 35.85063926875591, 48.52248050272465, 52.34905757009983, 56.85618571937084, 54.818362668156624, 57.07012563943863, 50.54293468594551, 55.02738185226917, 56.84708520770073, 51.77478678524494, 54.65941719710827, 49.979470521211624, 50.07159277796745, 51.42826437950134, 52.42164887487888, 49.728904366493225, 51.31533443927765, 50.18110670149326, 49.193110316991806, 48.83956588804722, 48.68940934538841, 48.34506422281265, 42.94540196657181, 39.76086884737015, 40.69306522607803, 40.44957049190998, 40.31423695385456, 45.11840656399727, 52.270538583397865, 51.79966025054455, 51.60815052688122, 49.24989826977253, 45.871081575751305, 29.986208751797676, 42.45811611413956, 53.86712171137333, 49.75645288825035, 49.97847497463226, 48.624573424458504, 42.911287397146225, 39.95077885687351, 39.81213569641113, 37.201945558190346, 38.53979676961899, 38.55620048940182, 42.86236122250557, 47.984942346811295, 48.58454257249832, 46.775721833109856, 48.62742327153683, 50.17063066363335, 49.522807225584984, 50.74974238872528, 50.47584168612957, 51.12770050764084, 49.942787289619446, 51.23586170375347, 47.638366743922234, 51.8449804186821, 50.46058930456638, 46.60944655537605, 45.2918254584074, 46.70196019113064, 48.49506877362728, 49.20238561928272, 48.51258963346481, 45.75725108385086, 36.12969249486923, 22.367366775870323, 8.325365614145994, 2.6817604852840304, 2.4738116562366486, 2.889141719788313, 1.6896853758953512, 4.192397212609649, 1.7118467367254198, 0.20823568396735936, 0.12555323395645246, 0.05174951220396906, 0.07766810696921311, 0.036181031391606666, 0.36882358719594777, 3.0670225247740746, 12.082251571118832, 24.7216634452343, 31.251744143664837, 31.085115484893322, 31.612618379294872, 16.81312121450901, 5.359984785318375, 0.5575398076325655, 0.05215880664763972, 0.14952215482480824, 0.032951776156551205, 0.03423072295845486, 0.07337553965044208, 0.04283039997972082, 0.11347493637003936, 0.05650944702210836, 0.030572910836781375, 0.04682058293838054, 0.08872928374330513, 0.06650326700764708, 0.04571305740682874, 0.025799272261792794, 0.05734962127462495, 0.05683793642674573, 0.05923437580349855, 0.03610720996221062, 0.043077416412415914, 0.025253472740587313, 0.020629254468076397, 0.012373653808026575, 0.053789101002621464, 0.013505751849152148, 0.059418417295091785, 0.071722168213455, 0.029550008694059215, 0.04059799750393722, 0.03291486544185318, 0.027597820771916304, 0.024746474555286113, 0.056979382352437824, 0.023111426744435448, 0.005776280086138286, 0.021379077807068825, 0.10738254219177179, 0.021618266437144484, 0.07177388106356375, 0.032472411839989945, 0.05087562960397918, 0.03289471613243222, 0.07879974116804078, 0.05372628562327009, 0.0025251011129512335, 0.03623878532380331, 0.04414151517266873, 0.03866419443511404, 0.051147775157005526, 0.03521313352393918, 0.0431827234569937, 0.06126456901256461, 0.10677664540708065, 0.008518208687746665, 0.07427416174323298, 0.03138821200991515, 0.044959944498259574, 0.029474452494469006, 0.012518533094407758, 0.04519970272667706, 0.040374418094870634, 0.022859504715597723, 0.019390858615224715, 0.031492071866523474, 3.9556863019242883, 20.887815468013287, 42.46233008801937, 44.7924068570137, 24.059501476585865, 27.635489590466022, 27.372089624404907, 22.099139168858528, 7.262417301535606, 1.8572333478368819, 0.03966856143961195, 0.5589750618673861, 2.5102058658376336, 0.5211048689670861, 7.440832452848554, 3.7204414000734687, 0.7851382135413587, 0.9310726483818144, 5.003026714548469, 10.63298748806119, 18.20665653795004, 26.30264651030302, 38.00275258719921, 49.11414295434952, 54.30759407579899, 57.374823689460754, 56.82974673807621, 60.03563851118088, 54.69445891678333, 57.43208661675453, 57.43028171360493, 54.089280590415, 55.74845775961876, 51.433755084872246, 52.791258841753006, 52.66042426228523, 52.553889378905296, 50.2304470539093, 54.29409720003605, 53.413490653038025, 52.11168810725212, 50.490261912345886, 51.43090523779392, 50.17176300287247, 44.00174908339977, 42.272188290953636, 43.234984427690506, 43.28845135867596, 42.017966732382774, 47.159315049648285, 53.34421657025814, 54.301510602235794, 53.870446532964706, 51.26391939818859, 48.322763219475746, 34.798251539468765, 44.924347177147865, 54.28361736238003, 50.78770995140076, 51.44346736371517, 50.29056742787361, 44.922614470124245, 41.80371142923832, 42.934260964393616, 39.351254627108574, 39.222696125507355, 41.255427449941635, 44.77050103247166, 49.56022761762142, 50.41130214929581, 49.14066553115845, 50.240140333771706, 50.77757589519024, 50.27207002043724, 51.36901415884495, 52.74727240204811, 50.36118283867836, 50.27329355478287, 50.13344585895538, 50.616760924458504, 54.207560643553734, 52.81215392053127, 50.08713774383068, 47.92439639568329, 47.806648313999176, 50.71940861642361, 50.96905142068863, 52.27636367082596, 48.1943529099226, 41.09308496117592, 24.000614136457443, 11.136730257421732, 4.947469420731068, 2.0695518236607313, 3.790974165312946, 2.5745437759906054, 4.821875710040331, 1.948244757950306, 0.3192274906905368, 0.05536614255106542, 0.15048049011966214, 0.09116590299527161, 0.023751898334012367, 0.7255613291636109, 3.806973919272423, 13.451040722429752, 26.781627908349037, 35.84318406879902, 33.33691455423832, 36.52911186218262, 20.826999731361866, 7.248244537040591, 0.9167825651820749, 0.03653677616966888, 0.02622579937451519, 0.09597627416951582, 0.044671538489637896, 0.05925816163653508, 0.041384926371392794, 0.061742014877381735, 0.05585693594184704, 0.05092519393656403, 0.048915075822151266, 0.0466037644946482, 0.06518283786135726, 0.03876854039845057, 0.015091120294528082, 0.0975758176355157, 0.022529352900164668, 0.08459596647298895, 0.039179712475743145, 0.03755977479158901, 0.05257469878415577, 0.021251860707707237, 0.03163932138704695, 0.04162836565228645, 0.04045389468956273, 0.027505955877131782, 0.026991957383870613, 0.002393503486928239, 0.04057605590787716, 0.05348963699361775, 0.21553647267865017, 0.11506230119266547, 0.16948300326475874, 0.20121985027799383, 0.09982287752791308, 0.12499892385676503, 0.15637661592336372, 0.10747208230895922, 0.14127935806754977, 0.12116024663555436, 0.1678305520908907, 0.11404780016164295, 0.19911580224288628, 0.09576721116900444, 0.1254709149361588, 0.09092756969039328, 0.1659862112137489, 0.09242876374628395, 0.1269591139862314, 0.12206021201563999, 0.15509611432207748, 0.08106245295493864, 0.23567703959997743, 0.13701554154977202, 0.10461269121151417, 0.17948372522369027, 0.12218769814353436, 0.2660568547435105, 0.1269844063790515, 0.13339804660063237, 0.11713854837580584, 0.08647723661852069, 0.14979735802626237, 0.24245977954706177, 5.12864132411778, 23.5863945633173, 48.81545998156071, 51.15074247121811, 32.918655797839165, 34.66627322137356, 29.860066920518875, 25.035703293979168, 8.858248069882393, 2.82948040869087, 0.7711742597166449, 1.94367395946756, 8.54366960003972, 10.129018630832434, 15.10959092527628, 7.277161460369825, 2.2266959538683295, 2.411772385239601, 7.507100896909833, 11.58073928207159, 18.767008669674397, 25.34123159945011, 39.67549502849579, 51.620325073599815, 55.94568617641926, 59.51447747647762, 57.24283777177334, 58.32203686237335, 54.73671644926071, 57.716793939471245, 59.36174467206001, 56.030140444636345, 57.096104845404625, 52.652596682310104, 53.66462677717209, 52.03296013176441, 52.42666840553284, 50.31441494822502, 54.55069363117218, 54.66062933206558, 55.024999380111694, 53.52362394332886, 53.52913364768028, 52.50652112066746, 46.45639456808567, 42.39519529044628, 44.74943496286869, 44.31359454989433, 44.34600681066513, 49.270964339375496, 56.07594698667526, 57.607880383729935, 54.75252740085125, 50.128954499959946, 50.54765023291111, 41.12635977566242, 46.605118587613106, 55.34706249833107, 52.797536104917526, 53.23490783572197, 53.65719057619572, 46.35611414909363, 42.293873727321625, 43.7394605576992, 41.19309179484844, 41.54495671391487, 42.12047383189201, 46.42410770058632, 53.18462133407593, 51.37982837855816, 50.275375843048096, 51.05917118489742, 51.49439223110676, 51.51193588972092, 51.730241775512695, 53.12398798763752, 49.93429474532604, 50.16915634274483, 50.72134651243687, 51.98549307882786, 54.3132633715868, 55.526880249381065, 51.76295422017574, 49.58775334060192, 50.59706278145313, 51.46314650774002, 54.0620968490839, 52.817686423659325, 49.13010969758034, 39.00460682809353, 25.816054120659828, 10.272542629390955, 3.9854973647743464, 5.205264212563634, 6.005815230309963, 3.4283318370580673, 7.2191366739571095, 3.3767379680648446, 0.7934600638691336, 0.7255033229012042, 0.9057783556636423, 0.2276521225576289, 0.2645069535356015, 1.3046033517457545, 5.0138922315090895, 16.804413981735706, 36.63289189338684, 43.36089447140694, 41.84480622410774, 43.20034548640251, 26.484641544520855, 8.562295250594616, 1.0091383312828839, 0.18894630105933174, 0.1686406062799506, 0.16925445146625862, 0.09664425160735846, 0.19409682077821344, 0.10448412896948867, 0.23998897697310895, 0.18516410869779065, 0.11943264558794908, 0.1719564330414869, 0.1683161690016277, 0.2590190386399627, 0.1925364404451102, 0.1546453041373752, 0.28996119392104447, 0.09228996728779748, 0.2032379130832851, 0.13829576113494113, 0.16596422879956663, 0.09577433578670025, 0.08533800282748416, 0.12208554151584394, 0.17296318605076522, 0.12812381086405367, 0.10556738256127574, 0.10380616964539513, 0.20118057582294568, 0.1397483964683488, 0.10450336543726735], [0.011200931530765956, 0.06776030932087451, 0.03929723898181692, 0.026794842960953247, 0.027876705025846604, 0.08070674899499863, 0.04404817154863849, 0.035629437552415766, 0.024150183016899973, 0.05264185201667715, 0.10439090779982507, 0.031402171807712875, 0.08338597632246092, 0.053562846151180565, 0.060899788586539216, 0.03885938669554889, 0.050945606708410196, 0.0411869992967695, 0.06278093627770431, 0.045421935137710534, 0.033864925790112466, 0.12032728234771639, 0.037877985450904816, 0.047709226855658926, 0.014981699896452483, 0.08419995647273026, 0.027567882534640376, 0.05400074667704757, 0.05285983563226182, 0.0435874945105752, 0.007778728104312904, 0.03167355294863228, 0.04582991597999353, 0.012598880784935318, 0.25882762391120195, 10.158003475517035, 27.35908482223749, 45.046989396214485, 38.12717691063881, 23.45298372209072, 23.970818035304546, 16.276552006602287, 10.419815126806498, 3.5117383114993572, 0.5420114658772945, 0.42555534455459565, 0.9345783165190369, 0.8902883087284863, 4.633238632231951, 2.056937450543046, 0.42415123083628714, 0.42408218141645193, 2.729033036157489, 7.0604481641203165, 8.770247641950846, 20.084268786013126, 27.336491234600544, 36.87639802694321, 42.840474396944046, 52.43151694536209, 53.22171114385128, 53.99784989655018, 54.629786387085915, 48.32929886877537, 59.230803698301315, 51.95873871445656, 52.63719990849495, 50.92832140624523, 51.89194589853287, 50.20559638738632, 50.152414441108704, 51.35977305471897, 50.85620507597923, 51.11078381538391, 50.335059240460396, 50.519090965390205, 50.01780666410923, 50.08992299437523, 48.306340500712395, 39.74577605724335, 39.859154373407364, 40.54918974637985, 40.920676812529564, 41.02426305413246, 49.77385975420475, 49.568754360079765, 51.49486720561981, 49.63650092482567, 43.6890372633934, 35.48080891370773, 41.89104214310646, 54.008059948682785, 51.49141699075699, 48.62120680510998, 49.7895073145628, 47.629870399832726, 39.892839565873146, 37.28219345211983, 39.68170389533043, 39.804805889725685, 43.278450295329094, 46.81436575949192, 47.98000641167164, 48.11058260500431, 51.3116904348135, 50.43937124311924, 49.65688683092594, 51.9694959372282, 50.71500465273857, 49.9489239603281, 48.19652259349823, 49.30364638566971, 50.69866932928562, 53.26141521334648, 50.88716961443424, 50.63963569700718, 46.78196869790554, 47.97928065061569, 47.76659086346626, 49.195219203829765, 51.198399513959885, 52.63247296214104, 40.07789343595505, 32.17414274811745, 14.963606558740139, 5.492251412943006, 1.1567550664767623, 1.5771756693720818, 4.244385547935963, 1.8045020336285233, 0.27575752639677376, 0.12206995641463436, 0.03573609530576505, 0.06150455359602347, 0.04158824885962531, 0.0956272346957121, 0.1310248364461586, 0.9585481428075582, 4.876465955749154, 9.104246869683266, 21.863908991217613, 26.36125836521387, 37.77211256325245, 35.48556625843048, 13.877007365226746, 2.29813520796597, 0.057381459409953095, 0.037405712355393916, 0.07439330613124184, 0.021823396054969635, 0.011451394311734475, 0.06316427781712264, 0.05392020510043949, 0.01968613691133214, 0.05935080764174927, 0.04199562485155184, 0.08483994010020979, 0.06195080699399114, 0.04775194116518833, 0.04949670437781606, 0.030482639704132453, 0.06274763611145318, 0.03923950731405057, 0.03233959338103887, 0.08740187840885483, 0.049775881780078635, 0.04294865007977933, 0.024573906666773837, 0.04402663813380059, 0.061298511136556044, 0.006872100557302474, 0.01994322614336852, 0.030187391093932092, 0.0817391209420748, 0.01887296384666115, 0.02650503985933028, 0.004242605009494582, 0.06873014790471643, 0.03357996705744881, 0.011891719805134926, 0.02162212746043224, 0.0432490751700243, 0.05056700378190726, 0.038101208629086614, 0.06279557142988779, 0.03635463828686625, 0.02395661977061536, 0.07024830745649524, 0.07417895903927274, 0.118176545802271, 0.05775960220489651, 0.017433774373785127, 0.024929942737799138, 0.04005169517768081, 0.03526356988004409, 0.029398458427749574, 0.05205198562180158, 0.049994885848718695, 0.04992312016838696, 0.007438520651703584, 0.018512962851673365, 0.057828325079753995, 0.026862740196520463, 0.04053376462252345, 0.07005022082012147, 0.04038899016450159, 0.03362402094353456, 0.045160795634728856, 0.0920376370777376, 0.019153588436893187, 0.4937450011493638, 13.199919797480106, 33.73190335929394, 49.34926673769951, 42.18535915017128, 25.119205713272095, 23.20867583155632, 19.116118736565113, 11.646650545299053, 3.6234280932694674, 0.37725198024418205, 0.32503595401067287, 1.6390126012265682, 0.44680867285933346, 2.071853312663734, 4.526237323880196, 0.2845934475772083, 0.28445282543543726, 2.676011868752539, 9.128722306340933, 11.317307967692614, 19.995288960635662, 30.34880429506302, 42.39570066332817, 46.984304040670395, 55.355239659547806, 57.098882496356964, 57.60921411216259, 55.80650344491005, 54.068712294101715, 60.708274617791176, 54.392375126481056, 53.992967158555984, 52.0715394616127, 52.43484556674957, 51.41252942383289, 52.072185426950455, 52.10394412279129, 52.37142696976662, 53.66391621530056, 53.05078871548176, 52.42118909955025, 52.311785370111465, 52.54058629274368, 49.47362266480923, 41.041107550263405, 40.817500948905945, 43.3468010276556, 42.63455584645271, 43.868801817297935, 51.80006302893162, 52.504769414663315, 53.63390162587166, 51.93616412580013, 43.03046800196171, 38.35025534033775, 43.73202435672283, 54.69692878425121, 52.962428256869316, 51.627708077430725, 52.31835141777992, 49.353294521570206, 42.65800438821316, 39.0995105355978, 40.880820751190186, 41.26901552081108, 44.68109183013439, 48.351189494132996, 50.76836138963699, 50.897668451070786, 51.928773522377014, 53.6158411949873, 52.04237602651119, 51.332988291978836, 50.37364237010479, 49.53606091439724, 49.331753477454185, 51.327592581510544, 52.735424637794495, 54.032910615205765, 53.69402199983597, 51.722721979022026, 49.34720724821091, 50.39807885885239, 49.0377252548933, 50.05895845592022, 52.99862131476402, 55.20091474056244, 44.12616580724716, 33.61017309129238, 18.038458563387394, 6.799155184999108, 2.6113115530461073, 2.1054950449615717, 1.9300964567810297, 2.3962644673883915, 0.22405171184800565, 0.08529578204615973, 0.08038079031393863, 0.11018660617992282, 0.02890577627113089, 0.1902136518037878, 0.08148731023538858, 1.1274670693092048, 6.0058788768947124, 13.17890502512455, 30.072207637131214, 31.47752232849598, 40.539458468556404, 38.99762660264969, 17.11080864071846, 3.345466358587146, 0.1148532159277238, 0.07328170249820687, 0.1095576657098718, 0.11704009506502189, 0.03590805092244409, 0.17186373879667372, 0.040351511706830934, 0.011134712476632558, 0.04705017003288958, 0.040147807012544945, 0.039255990413948894, 0.03117215797828976, 0.036610315582947806, 0.04821604692551773, 0.025582290545571595, 0.0065095131776615744, 0.04899218496575486, 0.04002901885542087, 0.085844503773842, 0.056206409572041593, 0.03964421157434117, 0.03274533293733839, 0.02584436886536423, 0.024983035982586443, 0.021637133686454035, 0.039639925671508536, 0.020119269138376694, 0.019729309497051872, 0.01566200069646584, 0.05049719737144187, 0.1017644620151259, 0.119498971325811, 0.12186190273496322, 0.10558696041698568, 0.14300719660241157, 0.17409445659723133, 0.1801892404910177, 0.15333811490563676, 0.10351652425015345, 0.20134114689426497, 0.2456454187631607, 0.14156980498228222, 0.13330222049262375, 0.1803095277864486, 0.17791685851989314, 0.1165262765425723, 0.14213388174539432, 0.13070764252915978, 0.10772017485578544, 0.1514119893545285, 0.12404708977555856, 0.36629942420404404, 0.17211884463904426, 0.13590144430054352, 0.07898127791122533, 0.29298975015990436, 0.19030741474125534, 0.13031733222305775, 0.16274906694889069, 0.22395771142328158, 0.12303740528295748, 0.09503773195319809, 0.1789444955647923, 0.2368018386187032, 0.8075609290972352, 15.395974908024073, 40.89250512421131, 57.74002969264984, 50.244111120700836, 35.28722830116749, 32.82060205936432, 22.87317283451557, 14.528431110084057, 4.904792010784149, 0.8900741545949131, 0.7789440115448087, 3.491073357872665, 4.019651357084513, 13.962297588586807, 7.9313072841614485, 0.6183385639451444, 0.5263837950769812, 6.66607397608459, 9.537295382469893, 12.276396453380585, 22.61917356401682, 31.869102716445923, 42.87694104015827, 47.55296252667904, 55.20140491425991, 56.341583132743835, 57.497819289565086, 57.38668665289879, 54.3809225410223, 61.013174057006836, 56.025364100933075, 56.90909408032894, 54.86039221286774, 54.86889995634556, 51.700382977724075, 51.709361895918846, 52.27373041212559, 53.14804449677467, 54.588873982429504, 54.73785258829594, 56.66276469826698, 54.72627080976963, 54.41326640546322, 51.316101998090744, 43.764459416270256, 42.64062412083149, 44.52574856579304, 46.332855597138405, 45.03358371555805, 52.83246763050556, 54.36420723795891, 56.01210281252861, 53.99318754673004, 44.93513859808445, 42.2993378341198, 46.670212894678116, 51.65080703794956, 53.150396570563316, 52.885679975152016, 55.19782170653343, 50.98322086036205, 43.70150439441204, 40.55490083992481, 43.40443253517151, 41.67476534843445, 47.26086840033531, 50.26684150099754, 51.68767265975475, 52.77905389666557, 54.221942871809006, 55.30313305556774, 52.93974347412586, 51.034483909606934, 51.50669977068901, 49.458564072847366, 48.521002382040024, 51.334531009197235, 53.55330415070057, 55.99704422056675, 54.011293575167656, 55.15272572636604, 50.258147567510605, 52.03023187816143, 50.672697722911835, 52.667256295681, 55.09505242109299, 55.253614112734795, 44.03313159942627, 34.63640682399273, 18.58201939612627, 7.094283923506737, 2.5256092892959714, 4.640491018071771, 7.953993016853929, 4.866481991484761, 0.7746421673800796, 0.3335007419809699, 0.18411612196359783, 0.5644204071722925, 0.254984189523384, 0.7350826088804752, 0.39286213635932654, 3.406703397631645, 11.06930572539568, 17.131692320108414, 35.341686978936195, 36.94704383611679, 48.557560220360756, 44.9121156334877, 21.203664019703865, 3.7218670360744, 0.16934903076617047, 0.21035521320300177, 0.2804598037619144, 0.15329109242884442, 0.18174313445342705, 0.2298379404237494, 0.10512555236346088, 0.11513877208926715, 0.13749728444963694, 0.11329969303915277, 0.2888426586287096, 0.16349578625522554, 0.16290441330056638, 0.14577781199477613, 0.09785911024664529, 0.1751160525600426, 0.13167322118533775, 0.13597022654721513, 0.1957942164153792, 0.19048686604946852, 0.08277101049316116, 0.20499834674410522, 0.13102244673063979, 0.12873036816017702, 0.058373870415380225, 0.17486667609773576, 0.10259206057526171, 0.19466509809717536, 0.0726384534209501, 0.16086619376437739], [0.015004534852778306, 0.08325352522660978, 0.023615059290023055, 0.009118151592701906, 0.018853204164770432, 0.033655321021797135, 0.01995572205487406, 0.07224994653370231, 0.010351296750741312, 0.05636349626001902, 0.041239873607992195, 0.04622549924533814, 0.05717362466384657, 0.014245474558265414, 0.04796241053554695, 0.037443042383529246, 0.032423214870505035, 0.030629340035375208, 0.022716991952620447, 0.0343656973564066, 0.026886006526183337, 0.0027160809895576676, 0.02555877188569866, 0.03637724039435852, 0.05658285655954387, 0.08536764420568943, 0.0610374310053885, 0.03697583815664984, 0.028413383552106097, 0.0638670397165697, 0.04697320931882132, 0.0759282530634664, 0.042605488415574655, 0.023686001186433714, 0.00338406399350788, 5.469294944778085, 26.206179186701775, 43.42416487634182, 41.12150363624096, 28.303052969276905, 23.46633430570364, 23.764720894396305, 18.36585469543934, 5.298598129302263, 0.9230699809268117, 0.04854705592151731, 0.8586363634094596, 0.24210323696024716, 2.419716096483171, 3.5253855166956782, 0.32183860370423645, 0.4515823448309675, 0.6964799459092319, 4.008151274174452, 5.960518810898066, 10.908523052930832, 18.724912628531456, 25.312731228768826, 36.54882900416851, 39.92310494184494, 48.69176521897316, 49.57927219569683, 55.47795407474041, 47.47812934219837, 57.104791179299355, 52.78364025056362, 48.013300225138664, 55.49693405628204, 50.579538121819496, 52.8077157586813, 51.96778602898121, 51.58034361898899, 49.41169358789921, 50.30819468200207, 52.44320131838322, 53.72587189078331, 54.802517518401146, 51.415181681513786, 49.5272795855999, 42.58672021329403, 39.042042419314384, 41.26035198569298, 41.86126694083214, 39.08266983926296, 45.65958872437477, 47.83646531403065, 51.919091641902924, 48.74629229307175, 59.41869221627712, 36.30122289061546, 39.96122449636459, 53.58345553278923, 50.799147337675095, 53.95304650068283, 47.952237501740456, 49.949440732598305, 41.64293825626373, 38.410197123885155, 37.016488909721375, 41.52470000088215, 44.2060337215662, 50.740923061966896, 48.60057391226292, 52.544051706790924, 49.402532279491425, 50.448646545410156, 50.46087048947811, 48.30587312579155, 49.64963302016258, 49.96259942650795, 48.6423222720623, 50.30722193419933, 50.88489733636379, 51.475541442632675, 48.58410559594631, 46.11791633069515, 46.56576409935951, 48.84071722626686, 53.46163406968117, 51.16695620119572, 53.70398506522179, 43.17874364554882, 34.92310903966427, 18.56011737138033, 7.234525373205543, 2.149689760990441, 3.917502388358116, 1.3560334732756019, 1.849240001756698, 3.439013776369393, 0.21445755322929472, 0.13424281845800579, 0.1364829170051962, 0.05788221984403208, 0.16623686417005956, 0.07236679768539034, 0.20848310115979984, 1.621727328747511, 10.589359179139137, 14.853986240923405, 20.33909071236849, 34.47010114789009, 35.3707592189312, 26.07007808983326, 5.166712906211615, 0.43211498006712645, 0.025552656588843092, 0.04122624777664896, 0.06037773593561724, 0.06691080998280086, 0.012799337655451382, 0.007308643880605814, 0.08411225688178092, 0.029672273813048378, 0.013281421943247551, 0.02121709294442553, 0.009644143192417687, 0.03431747631111648, 0.02875498670618981, 0.05599868243734818, 0.008635394733573776, 0.04520175847574137, 0.02503980100300396, 0.022595782538701314, 0.04941849685565103, 0.025928148061211687, 0.030353869660757482, 0.07867543143220246, 0.04560904169920832, 0.015442829644598532, 0.01983444770303322, 0.025416526295884978, 0.035645801908685826, 0.10386203110101633, 0.013779729579255218, 0.05691978047252633, 0.02959969177027233, 0.040484745768480934, 0.021279240390867926, 0.04409913111885544, 0.03446936054388061, 0.0040162708410207415, 0.041305067570647225, 0.025425884778087493, 0.05993213562760502, 0.045035513685434125, 0.02500347101886291, 0.01887594728032127, 0.03234404626709875, 0.005021539091103477, 0.022714223741786554, 0.03871860870276578, 0.022228107736737, 0.013141940853529377, 0.02449619452818297, 0.016126510927279014, 0.035671817895490676, 0.027030094497604296, 0.012178947654319927, 0.07155450963182375, 0.05212402960751206, 0.009199243286275305, 0.020344008153188042, 0.05537134129554033, 0.006372937132255174, 0.021024451816629153, 0.04590070944686886, 0.06003985465213191, 0.04040623767650686, 0.013177022174204467, 0.10555078071774915, 7.048534853383899, 30.34619763493538, 48.632951974868774, 42.914897203445435, 29.618931859731674, 24.094281010329723, 19.982686936855316, 20.20118471235037, 5.739168813452125, 0.7958356488961726, 0.0771317197359167, 0.49381740507669747, 0.4858457000227645, 1.4241273631341755, 2.7394523145630956, 0.45906150131486356, 0.09990310369175859, 0.6943382264580578, 3.5793145978823304, 8.129163142293692, 14.672884158790112, 22.48124286532402, 28.416391387581825, 38.90186794102192, 44.17270950973034, 52.59603291749954, 52.54570081830025, 58.792653009295464, 51.35960206389427, 60.00364042818546, 54.27991256117821, 52.22291573882103, 56.12651087343693, 52.241785526275635, 53.9068865776062, 53.11383493244648, 52.29881286621094, 50.200265273451805, 51.44395753741264, 53.23406808078289, 55.186817497015, 54.97744493186474, 53.624337539076805, 52.245927304029465, 44.05383288860321, 41.92157730460167, 43.34188029170036, 43.406761810183525, 41.127005741000175, 47.71729610860348, 50.05176164209843, 54.02083106338978, 52.13101767003536, 58.567993864417076, 39.55566085875034, 44.810820668935776, 52.98067107796669, 53.26795846223831, 55.46595051884651, 50.95577873289585, 51.96750484406948, 42.66501121222973, 40.32616451382637, 38.95576424896717, 43.1341340392828, 47.276409566402435, 52.45411433279514, 50.3270872682333, 54.44596365094185, 51.24262534081936, 51.19121789932251, 50.951074585318565, 49.35175180435181, 49.40412439405918, 50.402699410915375, 48.46607632935047, 52.060892432928085, 52.81315326690674, 53.032872676849365, 50.147854685783386, 49.28250811994076, 48.75472404062748, 51.308684796094894, 54.148606806993484, 54.109134525060654, 56.54850482940674, 47.00525611639023, 37.62760631740093, 20.938354656100273, 8.7314916215837, 3.651562496088445, 2.384338569827378, 1.5893832268193364, 1.2755103316158056, 1.129538076929748, 0.24731621582759544, 0.18432025710353628, 0.16720155224902555, 0.035584897559601814, 0.09759143242263235, 0.09678966060164385, 0.15664432343328372, 1.58647068310529, 12.291665934026241, 16.56967207789421, 24.354194663465023, 38.01322102546692, 40.92148996889591, 31.94596879184246, 7.21978216432035, 0.8723358751740307, 0.006556715161423199, 0.03848034219117835, 0.04590621989336796, 0.028774325219274033, 0.09569465139065869, 0.02157272454496706, 0.03657147157355212, 0.004771976164192893, 0.02218507059296826, 0.054342965813702904, 0.012282803800189868, 0.03377801658643875, 0.027395359174988698, 0.05418350796389859, 0.02621098425152013, 0.046844583994243294, 0.049694026602082886, 0.018073396204272285, 0.013962101238575997, 0.06432701542507857, 0.03214594478777144, 0.06856840424006805, 0.03180141015036497, 0.03904384750057943, 0.010554788077570265, 0.0656632448954042, 0.03850189044896979, 0.03166438742482569, 0.05649157981679309, 0.09815703058848158, 0.08435883544734679, 0.14296260836999863, 0.08500445197569206, 0.1525739106000401, 0.15799111366504803, 0.1685120366164483, 0.20310739899287, 0.11428571044234559, 0.09593363778549246, 0.2321914242929779, 0.10687260510167107, 0.16588078171480447, 0.1322293866542168, 0.09832163894316182, 0.13890640024328604, 0.12896567350253463, 0.17960865836357698, 0.12147194865974598, 0.09542939296807162, 0.07486812479328364, 0.09680641087470576, 0.08192594919819385, 0.15982689015800133, 0.18599759991047904, 0.16663085552863777, 0.1636592368595302, 0.1548367930809036, 0.16525102488230914, 0.16898365662200376, 0.15274689038051292, 0.195508623146452, 0.1307144554448314, 0.13601102982647717, 0.1977187389275059, 0.17733749351464212, 8.28030003234744, 33.93914803862572, 56.66590712964535, 51.507877707481384, 38.475549817085266, 34.624372869729996, 31.633817441761494, 24.168228842318058, 7.064736234024167, 1.2818206055089831, 0.4126204823842272, 2.554776049219072, 0.6147478159982711, 9.025627188384533, 11.704231705516577, 1.3858086755499244, 0.690666139125824, 3.3190136030316353, 6.566237658262253, 9.20028766617179, 13.260235860943794, 22.7699076756835, 29.68473482877016, 39.25979733467102, 44.34596121311188, 52.77001038193703, 53.65154027938843, 59.46194909512997, 51.164391338825226, 58.37076924741268, 55.14476515352726, 52.96484872698784, 56.63117699325085, 53.250202015042305, 53.905191868543625, 52.886014357209206, 52.729310765862465, 50.731685757637024, 52.21762262284756, 53.83804567158222, 56.37890852987766, 56.91530294716358, 55.24069860577583, 53.526880368590355, 47.08929240703583, 43.00451159477234, 44.910523518919945, 45.06470024585724, 42.75083340704441, 49.78949211537838, 53.85163754224777, 56.68517589569092, 54.59455847740173, 59.47460241615772, 42.75134637951851, 46.64880484342575, 51.217204704880714, 53.10851901769638, 55.79739913344383, 51.71657770872116, 53.21761876344681, 46.208583265542984, 40.58054946362972, 40.952997878193855, 45.00025950372219, 47.996596321463585, 54.987259805202484, 52.292387410998344, 56.209688410162926, 53.42218458652496, 52.99188807606697, 52.73563742637634, 48.96323025226593, 49.550017565488815, 50.053604543209076, 48.868246749043465, 54.05887082219124, 53.694139793515205, 55.45237384736538, 52.39941626787186, 50.17492063343525, 51.70634105801582, 53.39413069188595, 56.73217937350273, 55.744570568203926, 56.91176913678646, 46.7354591935873, 38.197378143668175, 21.15612667053938, 8.352530356496572, 4.550787331536412, 7.381050735712051, 4.5185954589396715, 4.603776438161731, 6.992500210180879, 1.520332619547844, 0.28276438009925187, 0.4218697501346469, 0.19604724424425513, 0.8079457771964371, 0.47377232287544757, 1.0982399876229465, 3.324392926879227, 18.88193540275097, 24.669446647167206, 32.09810882806778, 46.0228606313467, 45.109245255589485, 35.576210394501686, 9.03933685272932, 1.0421843267977238, 0.1105221534089651, 0.17712561035295948, 0.1518702507019043, 0.16694718855433166, 0.22710594639647752, 0.10183581951423548, 0.17345191998174414, 0.2309345972025767, 0.11662216944387183, 0.13248128641862422, 0.12175484793260694, 0.11945427919272333, 0.1714002082007937, 0.11831720505142584, 0.24195258098188788, 0.10184207581914961, 0.09607679807231762, 0.17745407007168978, 0.13171261438401416, 0.0943765822739806, 0.08309592274599709, 0.17482317140093073, 0.18874526809668168, 0.1742023797123693, 0.056526976550230756, 0.12685549532761797, 0.14102920977165923, 0.16216308198636398, 0.24010371300391853, 0.33077943488024175], [0.06505685087176971, 0.04461006639758125, 0.04079820297192782, 0.06958824131288566, 0.048397197751910426, 0.02322768974408973, 0.03530099638737738, 0.04112910064577591, 0.051811726443702355, 0.016632716869935393, 0.056220629121526144, 0.055343043204629794, 0.030919096752768382, 0.0695889834605623, 0.0546034373837756, 0.04002767556812614, 0.033322924209642224, 0.037521272170124575, 0.040508754245820455, 0.051280641855555587, 0.021584101668850053, 0.058639889539335854, 0.0609015400550561, 0.06109465430199634, 0.03355268941959366, 0.02425949765893165, 0.03378376452019438, 0.07395307155093178, 0.020509178684733342, 0.04294207465136424, 0.01702939665847225, 0.047173630009638146, 0.012558762136904988, 0.016647993979859166, 0.003913039954568376, 0.9685462375637144, 11.496499702334404, 39.647372737526894, 50.111163854599, 33.79237711429596, 33.7634302675724, 41.84712029993534, 30.99952507764101, 11.269896011799574, 1.779253575950861, 0.15804861526703462, 0.2568580530351028, 0.31671858625486493, 0.40794305212330073, 1.6250337450765073, 0.4072674602502957, 0.15765855729114264, 0.19393163354834542, 1.5856357966549695, 3.9118292927742004, 3.555492488667369, 11.608261205255985, 17.76528552174568, 24.64435089379549, 28.003931120038033, 38.55122655630112, 40.99563539028168, 49.7272514551878, 48.287527710199356, 45.79020671546459, 57.58825063705444, 48.416823372244835, 51.53907783329487, 54.056963324546814, 51.65715649724007, 51.474743485450745, 52.85819984972477, 52.75972433388233, 52.197871282696724, 53.63734424114227, 52.75069981813431, 53.39431308209896, 51.51596747338772, 47.39581435918808, 38.96973989903927, 42.4736762791872, 42.4466635286808, 43.28158512711525, 38.619577288627625, 46.17334395647049, 45.17731860280037, 52.238373309373856, 48.46619412302971, 57.24038690328598, 37.537646144628525, 41.615963503718376, 49.94038961827755, 49.08131271600723, 53.34468014538288, 48.99164892733097, 47.61540837585926, 43.195914924144745, 38.03039610385895, 37.64072321355343, 39.33271162211895, 48.44865806400776, 50.26369906961918, 50.895232781767845, 49.910534620285034, 53.20082746446133, 49.63186137378216, 50.16313746571541, 52.22763128578663, 51.28835968673229, 49.022909849882126, 51.51293143630028, 50.663350224494934, 49.667590856552124, 49.91171635687351, 49.0128555893898, 46.668111607432365, 53.17016690969467, 47.17786565423012, 50.913996174931526, 49.901643097400665, 45.09329751133919, 36.53840996325016, 21.23434167355299, 8.772495221346617, 1.891473310533911, 0.768223243067041, 0.5767244438175112, 0.9088527469430119, 0.508418952813372, 0.3827924985671416, 0.0797524064546451, 0.049061850368161686, 0.0818099218304269, 0.09399105139891617, 0.023556724627269432, 0.04051919997436926, 0.7827406015712768, 6.2243918515741825, 16.49245072156191, 29.162834733724594, 27.25056454539299, 33.657381758093834, 33.20282354950905, 16.357096284627914, 2.9195935232564807, 0.06869685515994206, 0.059156346396775916, 0.04273101527360268, 0.047289397625718266, 0.03171675336488988, 0.04160273187153507, 0.05423992231953889, 0.036512804799713194, 0.06916682759765536, 0.005697024280379992, 0.03367151097336318, 0.034375193135929294, 0.02050307266472373, 0.11079424701165408, 0.08475949871353805, 0.030761505404370837, 0.013847073914803332, 0.020243675353412982, 0.03540615871315822, 0.06254174950299785, 0.14297681307652965, 0.017495316969871055, 0.024730872755753808, 0.06824127296567895, 0.03130386321572587, 0.026416449691168964, 0.02739851515798364, 0.08375064542633481, 0.016813197908049915, 0.06499078488559462, 0.06008240939991083, 0.10156036398257129, 0.017331422932329588, 0.06643360160524026, 0.015265396978065837, 0.02528499360778369, 0.01952032256667735, 0.03715454731718637, 0.07806960886227898, 0.03609241153753828, 0.03995409162598662, 0.019547019473975524, 0.04089933914656285, 0.09857989149168134, 0.034736760062514804, 0.030314548821479548, 0.012322418715484673, 0.04737753879453521, 0.01951529637153726, 0.04064965098223183, 0.004458773146325257, 0.010550533716013888, 0.04213500018522609, 0.05615616617433261, 0.0899874021706637, 0.06450666711316444, 0.02327784037333913, 0.0753593523404561, 0.03793167612457182, 0.027411797746026423, 0.039061317656887695, 0.06037345745426137, 0.04149932101427112, 0.03134192797006108, 0.023921115425764583, 0.030690144194522873, 1.3309365324676037, 16.073718890547752, 45.44056847691536, 54.573310017585754, 35.911610797047615, 31.788909919559956, 35.96616826951504, 30.18305528908968, 11.96664372459054, 2.007862846367061, 0.20911943342071027, 0.7289580500219017, 1.2320100283250213, 0.6361122883390635, 1.0130622144788504, 0.2578402409562841, 0.15861080697504804, 0.20437897997908294, 0.40552088990807533, 2.0232553454115987, 5.599676873534918, 13.753646034747362, 19.482990950345993, 26.106109656393528, 33.31243246793747, 39.11323539912701, 43.64992216229439, 53.31809677183628, 52.03721970319748, 51.64395980536938, 58.289377614855766, 51.35899409651756, 53.767688646912575, 54.39192675054073, 52.98499904572964, 52.72508919239044, 52.94476680457592, 52.657133638858795, 52.04417712986469, 54.28737536072731, 54.07510355114937, 55.41633278131485, 51.51807636022568, 50.25549151003361, 40.17991416156292, 43.93961861729622, 42.7731192111969, 44.821676686406136, 41.035670042037964, 47.162624672055244, 47.23206214606762, 54.31613601744175, 50.757326781749725, 57.196427062153816, 38.34044806659222, 42.31828361749649, 50.38213491439819, 49.79385428130627, 54.99825641512871, 51.28718934953213, 49.22550357878208, 44.26380202174187, 38.69153022766113, 40.110237300395966, 41.44563764333725, 49.43866454064846, 52.962743639945984, 52.63396628201008, 52.66536019742489, 52.56110139191151, 50.64682871103287, 50.72349339723587, 51.41206204891205, 50.387504026293755, 49.205045476555824, 52.64335937798023, 52.023513838648796, 51.47304117679596, 50.686494782567024, 51.300864815711975, 48.99259127676487, 52.894734889268875, 48.83147992193699, 53.984109833836555, 52.46560491621494, 48.576441407203674, 39.82135020196438, 24.28275279700756, 11.421388182789087, 3.293082844465971, 2.223987649194896, 2.2080223308876157, 0.7079745666123927, 0.7084084558300674, 0.09529577670036815, 0.04454382600670215, 0.05717052619729657, 0.06874145081383176, 0.05813221228891052, 0.11050041590351611, 0.07154510662076063, 0.8226481976453215, 7.1885288413614035, 16.920883432030678, 29.539134241640568, 28.19236870855093, 36.80781550705433, 38.56354929506779, 20.987233333289623, 3.9748512860387564, 0.09622817393392324, 0.015194673087535193, 0.050925524192280136, 0.058179483385174535, 0.013421596013358794, 0.01550572016640217, 0.044242413860047236, 0.03831700661976356, 0.03888498707965482, 0.028729254590871278, 0.01584811463544611, 0.04968400389770977, 0.03388910125067923, 0.09542892541503534, 0.0321238213655306, 0.05177714236197062, 0.038392787319025956, 0.044396324155968614, 0.0031951804521668237, 0.043366627651266754, 0.04528522782493383, 0.03122837566479575, 0.06721125362673774, 0.03212596246157773, 0.059633551063598134, 0.011780303957493743, 0.027372905497031752, 0.01681232031842228, 0.04033497294585686, 0.01592080243426608, 0.042802172392839566, 0.19886375404894352, 0.13749400415690616, 0.16361963585950434, 0.10832020867383108, 0.12323964052484371, 0.11635872186161578, 0.10071179232909344, 0.12511343724327162, 0.14439750637393445, 0.0995370170858223, 0.09648598119383678, 0.09976165776606649, 0.1233723884797655, 0.13661873003002256, 0.11325270766974427, 0.1700566240469925, 0.1275898504536599, 0.10411679555545561, 0.11574932213989086, 0.14681623986689374, 0.10730463895015419, 0.12251649182871915, 0.10591590995318256, 0.1054990901320707, 0.1251256826799363, 0.10910292956396006, 0.13671856373548508, 0.1653763884678483, 0.22755448560928926, 0.1251638142275624, 0.14821634598774835, 0.20605926169082522, 0.1534054722287692, 0.12174142990261316, 0.10531937165069394, 1.6368350805714726, 18.487362675368786, 52.84001402556896, 63.60631451010704, 43.025938645005226, 42.736534774303436, 49.50631991028786, 37.85962946712971, 14.96078995987773, 2.2479199524968863, 0.43548029323574156, 1.56528313877061, 1.8988002673722804, 1.9560080976225436, 7.762541715055704, 1.7443552985787392, 0.3396364924265072, 0.7292480219621211, 3.3213483402505517, 7.071903124451637, 6.1752319894731045, 14.539831448346376, 20.01930557191372, 28.48371047526598, 32.60460264980793, 40.60100756585598, 44.337803050875664, 53.65505129098892, 54.27874222397804, 53.09243828058243, 60.322013944387436, 54.01181034743786, 54.75357614457607, 56.163372695446014, 53.327489867806435, 54.5578258484602, 54.447631761431694, 54.140950217843056, 54.19141910970211, 55.271286964416504, 55.367072224617004, 57.680391892790794, 55.692638754844666, 50.954410806298256, 42.49917671084404, 45.648736506700516, 44.33262772858143, 47.94881768524647, 42.701633647084236, 49.06800203025341, 48.32853510975838, 57.315664663910866, 52.29597821831703, 57.296335101127625, 42.133423537015915, 45.46552553772926, 51.013303846120834, 51.96498557925224, 55.95330476760864, 54.018505588173866, 51.799675449728966, 47.51917093992233, 42.170228362083435, 41.79342158138752, 43.297206088900566, 51.4271130412817, 55.44048048555851, 54.1516200453043, 53.04914340376854, 54.43736091256142, 50.85879273712635, 50.45136719942093, 51.71400144696236, 51.66536405682564, 49.85533878207207, 53.74794490635395, 53.83167341351509, 53.17146264016628, 54.40743371844292, 51.525166779756546, 51.687957644462585, 56.57065764069557, 51.834439784288406, 54.96142499148846, 54.04060520231724, 48.51787135004997, 39.81808237731457, 23.550845570862293, 11.12873263657093, 2.9600492399185896, 3.0218652728945017, 2.036116230301559, 2.5417705345898867, 2.62672898825258, 1.8464690004475415, 0.3348966920748353, 0.17578116530785337, 0.26914404064882547, 0.2165195214911364, 0.4325150273507461, 0.14498876058496535, 1.3263886515051126, 9.488039575517178, 21.8119752779603, 36.500434800982475, 37.923899218440056, 44.29940611124039, 44.367327466607094, 23.936388082802296, 4.772485010325909, 0.17095653747674078, 0.1495380070991814, 0.11729832534911111, 0.18048161698970944, 0.09623183272196911, 0.22400964691769332, 0.25605671165976673, 0.1146410359069705, 0.207267225778196, 0.1436779645155184, 0.08750308508751914, 0.12928531650686637, 0.10094141282024793, 0.23489343555411324, 0.07442737070959993, 0.1656885357806459, 0.10551353232585825, 0.10030831632320769, 0.1799159965594299, 0.20992816658690572, 0.19111378787783906, 0.12455828109523281, 0.1505303179146722, 0.1655709053738974, 0.13070960179902613, 0.13774148072116077, 0.17645650485064834, 0.16015361325116828, 0.13767701777396724, 0.20721428096294403, 0.10689910719520412], [0.09320833050878718, 0.05579748249147087, 0.05145074210304301, 0.010094022909470368, 0.04729051826871, 0.049022809689631686, 0.03160726802889258, 0.010311474961781641, 0.05045612691901624, 0.003335843180138909, 0.03500006663671229, 0.013679773419426056, 0.07742247093119659, 0.018921029040939175, 0.03116119645710569, 0.0441644735110458, 0.017607082554604858, 0.09140491165453568, 0.06451512017520145, 0.04538137305644341, 0.02808989622280933, 0.06214074484887533, 0.020344967379060108, 0.02383354014455108, 0.03590285217796918, 0.058103342744288966, 0.036963755992474034, 0.08213542037992738, 0.06815074579208158, 0.10990598530042917, 0.07315909970202483, 0.0606414024514379, 0.05677437518897932, 0.028191151141072623, 0.025357707381772343, 0.20875552872894332, 3.3574464032426476, 24.74276751279831, 42.49224208295345, 38.820776492357254, 35.92665798962116, 30.334712751209736, 29.369714632630348, 16.646146774291992, 5.085091385990381, 0.44067111157346517, 0.24553034134441987, 0.9390291839372367, 0.2142302185529843, 0.35397526051383466, 0.42125296604353935, 0.09889025022857822, 0.018586112637422048, 0.09521914253127761, 0.2784136135596782, 2.2677992982789874, 3.2536675594747066, 7.910319110378623, 14.953302461653948, 21.50945071130991, 22.54598379135132, 30.601399540901184, 34.09497007727623, 45.88381849229336, 37.5919946283102, 53.414132818579674, 52.39650942385197, 47.2052925825119, 56.557985320687294, 54.68941658735275, 56.72859996557236, 52.23731316626072, 54.54158551990986, 52.595143765211105, 52.79492564499378, 50.681254863739014, 50.4648070782423, 47.44720280170441, 42.446443140506744, 41.36034741997719, 43.64844024181366, 42.450421527028084, 42.35852725803852, 40.97738116979599, 44.22656401991844, 45.35950742661953, 53.2211297750473, 49.27923649549484, 57.04587534070015, 37.70457498729229, 42.89938643574715, 55.60367792844772, 51.49308130145073, 52.396695613861084, 49.07071888446808, 46.10506922006607, 39.59607549011707, 39.6744728833437, 37.47526489198208, 39.61512006819248, 44.38878871500492, 51.96498557925224, 51.01166993379593, 53.12049217522144, 50.78068032860756, 49.393880143761635, 47.06513710319996, 50.056948363780975, 50.60573771595955, 50.23414425551891, 51.5806096047163, 51.92243926227093, 48.503234535455704, 46.983069106936455, 46.01147644221783, 47.93774127960205, 50.17105244100094, 54.24015909433365, 45.81360965967178, 49.91336926817894, 32.570510879158974, 21.58189382404089, 12.281388435512781, 2.718730363994837, 2.504201475530863, 1.888291931245476, 1.4790586405433714, 0.23407870583469048, 0.3244016255484894, 0.3394282754743472, 0.01419449457898736, 0.06111275157309137, 0.04275488274288364, 0.08283325441880152, 0.036384209161042236, 0.12139057958847843, 1.9560820749029517, 9.601672478020191, 15.779618471860886, 25.43212652206421, 35.83842292428017, 36.88337065279484, 25.496875047683716, 7.706575468182564, 0.7058278005570173, 0.05796165562060196, 0.029512450455513317, 0.05522229948837776, 0.028789869502361398, 0.05314354755682871, 0.0874858524184674, 0.025933634387911297, 0.05920033348957077, 0.028480685214162804, 0.025393224714207463, 0.022037112321413588, 0.03913004795322195, 0.0917537507484667, 0.0441744331328664, 0.03473031450994313, 0.09323919643065892, 0.04621241147106048, 0.04414712580910418, 0.10318969725631177, 0.09406820507138036, 0.020274890084692743, 0.019387320426176302, 0.02033195753028849, 0.022579186261282302, 0.009292414360970724, 0.024627935017633718, 0.05796876168460585, 0.03788932917814236, 0.03363717180036474, 0.099842106574215, 0.03485577828541864, 0.0691020158410538, 0.040025623529800214, 0.006271997626754455, 0.03986908974184189, 0.015643764272681437, 0.018020607240032405, 0.03358253859914839, 0.006575416819032398, 0.019311858850414865, 0.007640152898602537, 0.011006763434124878, 0.013686169804714154, 0.05797338155389298, 0.0157433883214253, 0.07944917975692078, 0.05755153368227184, 0.07432351456372999, 0.06738384006894194, 0.07131256206776015, 0.007229490583995357, 0.0011884285572705267, 0.0018184129044129804, 0.047584427302354015, 0.04356137462309562, 0.02104904102452565, 0.03478348568023648, 0.061374859578791074, 0.03606978716561571, 0.03034760036825901, 0.052113643250777386, 0.031932833371683955, 0.06937695186934434, 0.061937552236486226, 0.046895447085262276, 0.038690811561536975, 0.33093041740357876, 4.468511771410704, 29.992647506296635, 49.51342932879925, 42.63383388519287, 40.488009229302406, 31.89631685614586, 32.44858302175999, 18.283231928944588, 5.074222544208169, 0.39709650445729494, 0.19804405194008723, 1.1044537229463458, 0.7054041826631874, 0.253004792612046, 0.32173013139981776, 0.023627013433724642, 0.03637523659563158, 0.4393656738102436, 0.9183226700406522, 2.0813653897494078, 6.107004275545478, 8.984255958348513, 16.78000219166279, 21.468241922557354, 22.48425990343094, 32.8998202085495, 36.33592262864113, 44.54353541135788, 43.0071372538805, 56.12103916704655, 54.61473539471626, 51.14392563700676, 56.20705895125866, 56.018554866313934, 55.74650086462498, 53.68363715708256, 55.11397920548916, 54.583052694797516, 54.71036486327648, 52.3058994859457, 51.82055152952671, 50.58150641620159, 45.096895918250084, 43.05051572620869, 45.19045829772949, 44.02847304940224, 43.385650143027306, 42.38453306257725, 45.77698342502117, 46.78088575601578, 55.25367110967636, 50.735983327031136, 57.548926547169685, 39.44782644510269, 44.51643526554108, 54.324681758880615, 52.58641183376312, 53.05218704044819, 51.77738964557648, 49.25902917981148, 41.739643067121506, 40.34903168678284, 40.07272571325302, 41.861487329006195, 46.55579723417759, 53.05968023836613, 52.364283353090286, 53.451864793896675, 52.59847238659859, 50.62111169099808, 47.72709958255291, 49.78029280900955, 49.80711556971073, 51.38987123966217, 53.306944370269775, 53.361182659864426, 50.52444867789745, 49.16377209126949, 48.51483911275864, 48.427842780947685, 52.01545067131519, 54.11626674234867, 49.845200926065445, 51.250870898365974, 36.289861500263214, 24.803267866373062, 13.009560462087393, 4.734301809221506, 4.090627273544669, 2.9613200342282653, 3.004062040708959, 0.28096446418203413, 0.4883203766075894, 0.29801741475239396, 0.09760113229276612, 0.03520086582284421, 0.07004594604950398, 0.09016951036755927, 0.038937527424423024, 0.13774134713457897, 2.387799946591258, 13.60471397638321, 20.523299127817154, 30.45555766671896, 37.925468534231186, 41.84008687734604, 29.64208971709013, 10.005897637456656, 1.1720376089215279, 0.016717883881938178, 0.027068402305303607, 0.06913609526236542, 0.03915429020707961, 0.043109284233651124, 0.0867111244588159, 0.009484132442594273, 0.05791360526927747, 0.03088310444582021, 0.03471266623819247, 0.04165969541645609, 0.017144388730230276, 0.010320243436581222, 0.07371645260718651, 0.032259018407785334, 0.11924739068490453, 0.05377429515647236, 0.048642191832186654, 0.03494317730655894, 0.04482838026888203, 0.08770613669184968, 0.038728234358131886, 0.041275129333371297, 0.06565938572748564, 0.027369680865376722, 0.00740881155252282, 0.05519804610230494, 0.009163584018097026, 0.033538796415086836, 0.05555057738092728, 0.03418764128582552, 0.24181376968044788, 0.2618345391238108, 0.13892119866795838, 0.1429357277811505, 0.10606778305373155, 0.11977925823885016, 0.07152903170208447, 0.14272317668655887, 0.11222975357668474, 0.19195648172171786, 0.09546760615194216, 0.1169591341749765, 0.16226710140472278, 0.09579993988154456, 0.16343332710675895, 0.16299750830512494, 0.11911726993275806, 0.14340835710754618, 0.18850565829779953, 0.08151407208060846, 0.12430787304765545, 0.11425598742789589, 0.15001831023255363, 0.10611238612909801, 0.12744403327815235, 0.1775757229188457, 0.17655175208346918, 0.16473981871968135, 0.10772007837658748, 0.2068733680061996, 0.3236398851731792, 0.1759001612663269, 0.20109460543608293, 0.13014191819820553, 0.13550760137150064, 0.4098775639431551, 6.335185831412673, 34.89462196826935, 55.54597042500973, 50.33331513404846, 47.87900783121586, 40.27750812470913, 40.69154150784016, 21.539054922759533, 6.572390478104353, 0.5852384807076305, 0.832569821504876, 2.248819316737354, 1.3674473483115435, 1.6155556286685169, 1.4261906524188817, 0.21455130132380873, 0.8261877670884132, 1.6522610653191805, 1.8714410229586065, 4.069809140637517, 6.074619088321924, 9.946660716086626, 16.849141381680965, 26.625152304768562, 25.04496529698372, 32.69646652042866, 37.18468688428402, 47.62159064412117, 44.12162125110626, 58.33630509674549, 57.93437406420708, 53.36062788963318, 57.856071665883064, 56.048919036984444, 56.224256828427315, 53.432451635599136, 56.688071340322495, 55.55448576807976, 56.96171745657921, 55.55929251015186, 56.02363519370556, 51.6984336823225, 46.222467720508575, 44.7214874625206, 46.689857840538025, 47.410918548703194, 45.517825931310654, 45.06742089986801, 46.708758026361465, 50.08747212588787, 56.53435058891773, 52.38608278334141, 56.63526937365532, 43.39320793747902, 47.80346408486366, 54.88361656665802, 55.70899687707424, 55.96977688372135, 53.0326446890831, 49.681741297245026, 42.78724305331707, 42.377077862620354, 42.67299458384514, 43.02031874656677, 48.01627926528454, 55.93666926026344, 54.421743750572205, 55.0698521733284, 51.35862171649933, 51.464856415987015, 47.07024782896042, 49.81702163815498, 49.96173307299614, 52.22529821097851, 53.98299649357796, 55.18991433084011, 52.39031195640564, 50.71512244641781, 49.04154025018215, 51.32567748427391, 53.205489814281464, 57.146630734205246, 51.774456202983856, 51.11910156905651, 38.31040307879448, 24.28851328790188, 14.253965187817812, 4.080313676968217, 4.924048902466893, 4.096343591809273, 3.259428762830794, 0.586200897814706, 1.260086721740663, 0.912585809128359, 0.20763815118698403, 0.27201318356674165, 0.13609968678792939, 0.20470279385335743, 0.10924935530056246, 0.5379783385433257, 3.068342241458595, 14.00682169944048, 24.907838255167007, 37.144876420497894, 46.543831676244736, 50.18495209515095, 33.44320625066757, 12.219988480210304, 1.4424039074219763, 0.10749075474450365, 0.15187209122814238, 0.19427380815614015, 0.11174728337209672, 0.14037445740541443, 0.16169625625479966, 0.14641622226918116, 0.23331680218689144, 0.1626559571013786, 0.28618876822292805, 0.20059925154782832, 0.06968613801291212, 0.1639793103095144, 0.15703344630310312, 0.19251353776780888, 0.2338189393049106, 0.09186957031488419, 0.1021946404944174, 0.1978234262787737, 0.14361471869051456, 0.19269463664386421, 0.08594983679358847, 0.07355600027949549, 0.16067436343291774, 0.11866489381645806, 0.12951602053362876, 0.13661283737747, 0.08602358400821686, 0.09558370031300001, 0.14356352534377947, 0.13609983521746472], [0.025531690916977823, 0.07267081848112866, 0.019723561563296244, 0.05904758094402496, 0.0440083330613561, 0.051684448117157444, 0.033374785489286296, 0.025376609883096535, 0.004122428572372883, 0.03577340678020846, 0.03626434860052541, 0.0353119690407766, 0.04219046459184028, 0.025426435822737403, 0.09177948842989281, 0.03780337734497152, 0.059520629583857954, 0.01102617708966136, 0.020420287946762983, 0.09592470232746564, 0.045625413476955146, 0.064168455573963, 0.04049365525133908, 0.037094741346663795, 0.023185498648672365, 0.0445796012354549, 0.03993738959252369, 0.12027263059280813, 0.04391889313410502, 0.020974297476641368, 0.045187854339019395, 0.06354934856062755, 0.05504921209649183, 0.018357946755713783, 0.07084264158038422, 0.08375835634069517, 1.1479160282760859, 11.08845479786396, 42.89889246225357, 45.074944496154785, 31.65135160088539, 26.21012717485428, 20.50148069858551, 19.09013383090496, 11.161484979093075, 2.0835870830342174, 0.32124162011314183, 1.003224898595363, 0.2589587465627119, 0.2725541201652959, 0.12294666288653389, 0.015540588119620224, 0.139827583625447, 0.41045026446226984, 0.389945495990105, 0.45582876540720463, 0.7300155214034021, 2.4601373774930835, 4.555305764079094, 10.008236411958933, 11.098491009324789, 19.115537367761135, 24.333128593862057, 31.796883791685104, 37.80040584504604, 38.319590985774994, 56.988734006881714, 47.053642719984055, 59.393545165658, 54.00671862065792, 56.599235907197, 55.24435020983219, 55.80097854137421, 50.70779263973236, 52.95738212764263, 48.593396097421646, 47.996801510453224, 43.66783060133457, 47.094718515872955, 45.234364941716194, 49.05197449028492, 44.75970581173897, 45.052993074059486, 41.29690982401371, 47.77429684996605, 49.91557314991951, 54.09210003912449, 49.259488955140114, 57.85195268690586, 40.485246777534485, 38.72360810637474, 56.736955717206, 52.5604934245348, 52.81563453376293, 48.90988111495972, 44.92016360163689, 38.90727885067463, 36.08493469655514, 38.9972086250782, 37.46278636157513, 42.97608532011509, 50.532253459095955, 52.450401932001114, 50.38086578249931, 53.511255607008934, 48.48063334822655, 49.632321149110794, 52.71205589175224, 51.69295437633991, 52.28474982082844, 49.76710371673107, 51.99108637869358, 50.4912194609642, 50.03248527646065, 49.40512754023075, 54.33048024773598, 50.067564994096756, 52.28191897273064, 42.66365848481655, 33.99801827967167, 24.855431467294693, 12.953076492995024, 6.225839573889971, 1.867442806251347, 2.0436609629541636, 2.5407132413238287, 3.8469769852235913, 0.5428068700712174, 0.2515329059679061, 0.06637301266891882, 0.14772035385249183, 0.09491714779869653, 0.048646666982676834, 0.031122875661822036, 0.1471217375365086, 0.32236680504865944, 3.730904613621533, 8.009543661028147, 15.35599060356617, 26.46886669099331, 34.279271587729454, 29.36096180230379, 17.93493501842022, 3.602906344458461, 0.0967308676626999, 0.03709387303388212, 0.032316802025889046, 0.03988444106653333, 0.07907207225798629, 0.058349153187009506, 0.05719066808524076, 0.04464781944989227, 0.05881279139430262, 0.047407573511009105, 0.021855531049368437, 0.0918874263879843, 0.019167468453815673, 0.04286586721718777, 0.0352041424048366, 0.09259887141524814, 0.047970963787520304, 0.05954612235655077, 0.06453748850617558, 0.04047380280098878, 0.0726780915283598, 0.07308245811145753, 0.09601868790923618, 0.03226433589588851, 0.02740613886999199, 0.07328732797759585, 0.045045610604574904, 0.06884132162667811, 0.038236246109590866, 0.03725528273207601, 0.057040780229726806, 0.022713763610227033, 0.01626286200917093, 0.06915969555848278, 0.010708545305533335, 0.03590259984775912, 0.054964321534498595, 0.07865695937653072, 0.057288828247692436, 0.04366992856375873, 0.04680112011556048, 0.04220920010993723, 0.012558343751152279, 0.009204811249219347, 0.05718484222597908, 0.02618693124532001, 0.05345210287487134, 0.06002288544550538, 0.061252746600075625, 0.02875573256460484, 0.035299463852425106, 0.03936524939490482, 0.003256553977735166, 0.02741428394074319, 0.026871799964283127, 0.03458646031504031, 0.02900313676946098, 0.030041375393921044, 0.028357312439766247, 0.08978231708169915, 0.07057370210532099, 0.027755747942137532, 0.05496618803590536, 0.041520720842527226, 0.033261726712225936, 0.03418405671254732, 0.059640152467181906, 0.034502152338973247, 1.5758479968644679, 14.376411717385054, 49.52472612261772, 49.624603763222694, 34.1430526971817, 28.181858472526073, 25.97962014377117, 24.098227098584175, 13.187041338533163, 2.2274449886754155, 0.06738556927302852, 0.2518328820588067, 0.3278205217793584, 0.09542327024973929, 0.1559597664163448, 0.04216563233057968, 0.06591912257135846, 0.15330174966948107, 0.2809474244713783, 0.2879749098792672, 1.393878967501223, 0.9667616989463568, 5.084054516628385, 11.335250604897738, 11.979859415441751, 19.19466432183981, 26.669953800737858, 35.94376467168331, 37.429994121193886, 44.46912780404091, 57.07625471055508, 50.644837617874146, 59.11801055073738, 54.042721688747406, 57.09337659180164, 55.203270614147186, 57.40793891251087, 53.50109875202179, 55.02167075872421, 50.84230922162533, 49.872589856386185, 45.378282219171524, 48.233597204089165, 46.70453265309334, 48.85683976113796, 46.600007861852646, 46.8426476418972, 42.933926582336426, 48.689162358641624, 51.096998155117035, 55.77887512743473, 52.50266432762146, 56.47636950016022, 42.41460084915161, 40.15577785670757, 56.69299967586994, 54.668228924274445, 55.53680531680584, 49.916709288954735, 46.71608783304691, 41.256027817726135, 39.22331169247627, 40.69994665682316, 39.24604207277298, 44.72049951553345, 52.39373177289963, 54.80183735489845, 51.442904993891716, 53.98713827133179, 47.98249527812004, 50.531584694981575, 50.9592479467392, 50.902520790696144, 51.39693886041641, 50.89993312954903, 53.242887407541275, 51.200124621391296, 52.516594380140305, 50.96558220684528, 52.130865678191185, 50.9643928706646, 52.63316452503204, 44.81227219104767, 36.04426167905331, 25.80880980938673, 13.914054427295923, 4.926808029413223, 3.5379602294415236, 4.22769826836884, 2.8950800886377692, 3.1083493446931243, 0.7122072426136583, 0.19805392250418663, 0.043230343362665735, 0.3480933839455247, 0.06346062480588444, 0.11144208998302929, 0.15146579506108537, 0.1606895329314284, 0.509971110150218, 5.342828230932355, 10.739417877048254, 17.51138884574175, 31.26871783286333, 39.76627215743065, 36.252087727189064, 22.06196766346693, 4.505242025479674, 0.12248934406670742, 0.05811056384118274, 0.003050400428037392, 0.060275427167653106, 0.049479326989967376, 0.04638434111257084, 0.014624027389800176, 0.013631504134536954, 0.1022441491659265, 0.04748772546008695, 0.002989538984365936, 0.11921823912416585, 0.007378403906841413, 0.09689527563750744, 0.06513336629723199, 0.02652461400430184, 0.026034139737021178, 0.06596602630452253, 0.033524083337397315, 0.025873038030113094, 0.010453362465341343, 0.027881272944796365, 0.0643345111166127, 0.034984132726094685, 0.03789122165471781, 0.018806946100085042, 0.02435406768199755, 0.08764146594330668, 0.005470070882438449, 0.007503259121222072, 0.06961303646676242, 0.06087069268687628, 0.15011720883194357, 0.13748665689490736, 0.07682009192649275, 0.08440375022473745, 0.14438708662055433, 0.18260215554619208, 0.22700594941852614, 0.16627088421955705, 0.1822659478057176, 0.10360316999140196, 0.10828169863088988, 0.08348970630322583, 0.14146332163363695, 0.09372988963150419, 0.1647538156248629, 0.09095773799344897, 0.13995642046211287, 0.06731067172950134, 0.13700139621505514, 0.10874472456634976, 0.12442787832696922, 0.11218771833227947, 0.12274634980713017, 0.12844927230617031, 0.08444226768915541, 0.08481276265229098, 0.11729658130207099, 0.2310849414789118, 0.14245250058593228, 0.12156634242273867, 0.19629531452665105, 0.14212944370228797, 0.17759470705641434, 0.11595891948672943, 0.2619399834657088, 0.14230745524400845, 2.228741906583309, 18.766704685986042, 54.631845876574516, 58.16408313810825, 43.164255023002625, 35.08132115006447, 31.307369358837605, 27.9819492995739, 14.918994102627039, 2.6786760007962584, 0.9502317546866834, 2.4002480786293745, 1.2117585400119424, 0.570922214537859, 0.6834511575289071, 0.23649277864024043, 0.24345173413166776, 0.89042516076006, 0.804201434366405, 1.111155019607395, 2.2552922694012523, 3.9019814087077975, 6.4471078757196665, 11.302218977361917, 14.143873695284128, 21.39052279293537, 28.36223479360342, 34.7619216889143, 40.20941577851772, 46.170406714081764, 61.81654214859009, 52.5739599019289, 59.802965596318245, 55.867949947714806, 58.17292906343937, 58.72426427900791, 59.716193452477455, 54.900890439748764, 56.95814184844494, 51.83011181652546, 51.467900052666664, 47.14340530335903, 50.73563374578953, 48.88084687292576, 51.164733320474625, 48.03616359829903, 49.59892854094505, 45.78081361949444, 50.94230845570564, 54.8261446505785, 57.2319171577692, 55.50369009375572, 57.83301830291748, 44.79525290429592, 43.90045031905174, 57.646596506237984, 56.26201540231705, 56.49778135120869, 53.43328379094601, 48.59269693493843, 42.45848089456558, 40.25754779577255, 42.89744094014168, 41.04408659040928, 47.41262845695019, 54.46678653359413, 57.25123532116413, 53.92896719276905, 54.45278808474541, 47.46839426457882, 51.4235108345747, 51.58390782773495, 54.03840132057667, 51.25350035727024, 51.715585961937904, 54.994369223713875, 53.244422525167465, 54.29752081632614, 53.36323834955692, 56.63427382707596, 53.542771115899086, 55.121677592396736, 46.85994811356068, 36.29930779337883, 27.398549504578114, 17.389025911688805, 7.5287592597305775, 4.341975236311555, 5.1525225676596165, 7.435096660628915, 7.467824779450893, 1.9846495357342064, 0.9809937165118754, 0.2710560505511239, 0.476612729835324, 0.44687469431664795, 0.16481274215038866, 0.22872197296237573, 0.605234254617244, 0.723682448733598, 6.174605498090386, 13.734724000096321, 25.733157768845558, 38.11198152601719, 45.66262476146221, 40.988601967692375, 24.564435482025146, 5.333313066512346, 0.25141929800156504, 0.15542452951194718, 0.1847256626933813, 0.09476651408476755, 0.17871444462798536, 0.18287508777575567, 0.08996679272968322, 0.0945364854123909, 0.11498980078613386, 0.11341315999743529, 0.12618823035154492, 0.1685187901603058, 0.15858305065194145, 0.2184270488214679, 0.18469058879418299, 0.27441385318525136, 0.13871920091332868, 0.20743601984577253, 0.14606257405830547, 0.13726186036365107, 0.13316533877514303, 0.0927736768790055, 0.20585143065545708, 0.20623008924303576, 0.15744710457511246, 0.09728531134896912, 0.10241568175842986, 0.15814809274161234, 0.12631295569008216, 0.1401488296687603, 0.18141198816010728, 0.10473975431523286], [0.03989184770034626, 0.0555857403378468, 0.05538742734643165, 0.07762112159980461, 0.038342373227351345, 0.05452888864965644, 0.03590723827073816, 0.005437152922240784, 0.031140880164457485, 0.029347036870603915, 0.03159113373840228, 0.03336096298880875, 0.043123722716700286, 0.051198794099036604, 0.007782139200571692, 0.05808703775983304, 0.027909827076655347, 0.045227032314869575, 0.014877889207127737, 0.04997929703677073, 0.07721872912952676, 0.022390207632270176, 0.051467670491547324, 0.04917742502584588, 0.0932547370030079, 0.0846127538534347, 0.014948182652005926, 0.016858444796525873, 0.012645825336221606, 0.028499853033281397, 0.023715369825367816, 0.015438992741110269, 0.030110033330856822, 0.007689485773880733, 0.006440345941882697, 0.07544589418102987, 0.19641754624899477, 5.174157656729221, 26.17808349430561, 45.61345539987087, 48.27672868967056, 28.253342136740685, 30.4798174649477, 20.448686331510544, 17.494983226060867, 5.573245966807008, 0.2987778786337003, 0.6617600214667618, 0.462636545416899, 0.09651519954786636, 0.09787384187802672, 0.06739418560755439, 0.10975167053402402, 0.09651447966462001, 0.25405116146430373, 0.10480455122888088, 0.573401462752372, 0.1354012664523907, 1.034089217428118, 3.1772087747231126, 3.079452132806182, 8.667658846825361, 13.525421731173992, 19.71334408968687, 25.38063358515501, 29.91117797791958, 40.20547538995743, 51.79795414209366, 51.068913862109184, 57.39250414073467, 57.441118732094765, 56.61503925919533, 53.868687227368355, 52.00046807527542, 51.28044471144676, 49.30247224867344, 48.49235191941261, 49.48045089840889, 51.96356825530529, 51.94517724215984, 51.519968658685684, 48.919714987277985, 47.74932458996773, 43.584987446665764, 44.67395581305027, 47.557529881596565, 52.65540853142738, 52.63217657804489, 56.389053985476494, 42.82632015645504, 37.544223591685295, 56.52356676757336, 52.65951231122017, 51.700211986899376, 46.42167583107948, 41.862517073750496, 38.71423780918121, 39.99608002603054, 38.36836136877537, 39.22231234610081, 42.237097173929214, 51.421998515725136, 51.128289476037025, 53.56431595981121, 48.67581367492676, 51.579283475875854, 46.8427350372076, 52.626511082053185, 51.73180349171162, 52.34851039946079, 52.396156042814255, 53.508538752794266, 52.1908188611269, 53.15971367061138, 49.56409960985184, 51.92990206182003, 48.786577731370926, 44.382678642868996, 32.975808531045914, 22.039108090102673, 13.551485482603312, 4.610141571611166, 0.7709499530028552, 3.788161603733897, 3.6579862888902426, 2.1085610054433346, 3.050511935725808, 0.3828238171990961, 0.19084066268987954, 0.06386654989910312, 0.20855142327491194, 0.05381281262089033, 0.044547540455823764, 0.31230052176397294, 0.16003862489014864, 1.2915328843519092, 7.109846938401461, 22.731107957661152, 32.30216167867184, 34.14450041949749, 33.1834863871336, 32.85125881433487, 9.034489262849092, 1.3630702206864953, 0.026424331299494952, 0.07084497934556566, 0.052154094009893015, 0.04266100106178783, 0.030120388146315236, 0.030006203160155565, 0.011780469085351797, 0.014926667790859938, 0.05193484503251966, 0.10068390984088182, 0.047028209883137606, 0.013218562035035575, 0.03558158758096397, 0.03893635112035554, 0.0063645550380897475, 0.012143452586315107, 0.024819730097078718, 0.01650776703172596, 0.05634040433506016, 0.00356985254711617, 0.03496885190543253, 0.09403186952113174, 0.019477508067211602, 0.08068182025454007, 0.005287412104735267, 0.028399728034855798, 0.06854749051854014, 0.016409736745117698, 0.02472076655976707, 0.06129235873231664, 0.03767979491385631, 0.02211324554082239, 0.02730813455855241, 0.04728668507596012, 0.010003579227486625, 0.014323577252071118, 0.014066278363316087, 0.03907839076418895, 0.053313284151954576, 0.03791545648709871, 0.04451798442460131, 0.04595571001118515, 0.06093716685427353, 0.05717066349461675, 0.06710474059218541, 0.04105995103600435, 0.016911003694985993, 0.03205931388947647, 0.029737718250544276, 0.04476699723454658, 0.022158258652780205, 0.0282605178290396, 0.014073037473281147, 0.032007838526624255, 0.057475033099763095, 0.029934550657344516, 0.023336592494160868, 0.07501307365600951, 0.05501322906638961, 0.016617389665043447, 0.007279174587893067, 0.011663441673590569, 0.053029579648864456, 0.06111872586188838, 0.06676971286651678, 0.03960052134061698, 0.03842984646325931, 0.07527390887844376, 0.1991079206345603, 6.193345617502928, 31.540420353412628, 51.394883170723915, 50.74257217347622, 29.19563077390194, 28.961170054972172, 26.92831713706255, 21.702850833535194, 7.338715782389045, 0.3897206549299881, 0.44827236619312316, 0.1509567114408128, 0.0572902309068013, 0.05029923690017313, 0.028653978552029002, 0.08555835389415734, 0.3722804813878611, 0.34260912041645497, 0.21708180225687101, 1.0777549305930734, 0.5585215799510479, 1.9032726273871958, 5.050413496792316, 6.110027013346553, 9.837046097964048, 15.456294771283865, 20.57655707001686, 26.826910078525543, 33.405075296759605, 46.59346081316471, 52.68163092434406, 53.13792183995247, 57.18142546713352, 58.71894456446171, 57.63936169445515, 54.294161796569824, 54.12494167685509, 53.826505690813065, 51.51222467422485, 49.44506719708443, 49.238145500421524, 53.9593655616045, 52.52806596457958, 54.064509719610214, 50.82204110920429, 48.95251862704754, 45.59750385582447, 46.320935636758804, 50.098366141319275, 54.33391906321049, 54.37207281589508, 56.923255920410156, 42.7754332870245, 41.5177957713604, 57.0851044356823, 53.30976381897926, 53.451530411839485, 48.40981274843216, 43.97820934653282, 40.194649770855904, 41.86614967882633, 39.759812504053116, 40.22717222571373, 44.3946897983551, 54.06802833080292, 52.39603064954281, 54.09494988620281, 50.223041251301765, 52.919653952121735, 47.72852450609207, 52.992431446909904, 51.68967895209789, 52.92286477982998, 53.016837537288666, 53.514257445931435, 53.121875301003456, 54.55072022974491, 50.600615590810776, 52.55502171814442, 51.072018295526505, 47.54295006394386, 36.36353574693203, 23.68230141699314, 14.832919221371412, 5.648707542568445, 2.3344660084694624, 4.582474306225777, 5.445191413164139, 2.431304049678147, 0.1828592355013825, 0.2712466340744868, 0.08802339740213938, 0.1641199176083319, 0.7328761147800833, 0.26710197678767145, 0.12809906766051427, 0.25804626115132123, 0.18581801501568407, 1.6242784168571234, 6.024509277194738, 22.465718798339367, 38.67806755006313, 37.282413840293884, 38.40947516262531, 34.70444977283478, 11.228471584618092, 1.6883979574777186, 0.006640480442001717, 0.04050411211210303, 0.0745289633050561, 0.04325713489379268, 0.0794586495612748, 0.017198493151227012, 0.022336617148539517, 0.022246355292736553, 0.0445312874217052, 0.01185318285934045, 0.04160862081334926, 0.044750443630618975, 0.0485890651907539, 0.052150743213132955, 0.024462246838083956, 0.022757199658371974, 0.023941299987200182, 0.04017628321889788, 0.052496784410323016, 0.0314451903977897, 0.06800689530791715, 0.08017655869480222, 0.014048216344235698, 0.005289901082505821, 0.033716462858137675, 0.027890410638065077, 0.0320241175359115, 0.03210492999642156, 0.020528656350506935, 0.060534822623594664, 0.08370476585696451, 0.02134183312591631, 0.15510479744989425, 0.14841697819065303, 0.09305331812356599, 0.13616753392852843, 0.12075785416527651, 0.1653097732923925, 0.08645736932521686, 0.10457562093506567, 0.10373664525104687, 0.16471240378450602, 0.09150468598818406, 0.1613102207193151, 0.12199974924442358, 0.16397533239796758, 0.13108993764035404, 0.14110027783317491, 0.065535721660126, 0.2102786087198183, 0.0995284304372035, 0.18460472230799496, 0.21299387473845854, 0.10370241740019992, 0.1150376173609402, 0.11968280872679316, 0.16978121304418892, 0.17296251811785623, 0.10721546990680508, 0.10029190001660027, 0.07550968919531442, 0.2620277350069955, 0.1554551356821321, 0.07807367583154701, 0.21956747747026384, 0.16285379882901907, 0.1318780836299993, 0.1378136916900985, 0.4690431203925982, 8.256870489567518, 36.719006672501564, 57.016088739037514, 58.92949506640434, 36.82563655078411, 43.86132001876831, 29.39809150993824, 25.736106410622597, 10.981604531407356, 0.7150656392332166, 2.269066055305302, 1.4105727779679, 0.46773610927630216, 0.30628081352915615, 0.17608617316000164, 0.4852959467098117, 0.8709864725824445, 1.1024280753917992, 1.057973310817033, 1.63161582313478, 1.035823943093419, 2.531932624988258, 5.539539400488138, 5.105109186843038, 11.804987099021673, 15.183168277144432, 23.23488872498274, 27.266430594027042, 37.592450603842735, 47.841230258345604, 57.31017395853996, 53.79054442048073, 58.881990015506744, 59.58622522652149, 59.22208696603775, 56.314425989985466, 56.31123796105385, 56.181098744273186, 53.953213691711426, 52.36850492656231, 52.587639167904854, 56.56227149069309, 55.970696434378624, 56.282971277832985, 53.662384897470474, 50.998442843556404, 49.14085552096367, 47.683303132653236, 53.0034888535738, 55.71438118815422, 58.80901113152504, 57.30693653225899, 45.741725116968155, 44.36378985643387, 57.78643660247326, 56.809615418314934, 56.56141273677349, 50.20597256720066, 45.72142280638218, 41.122400388121605, 43.9100182056427, 41.252364814281464, 42.33817555010319, 46.847025007009506, 55.090454667806625, 55.57409271597862, 57.62022212147713, 50.879478827118874, 53.72206449508667, 48.95028814673424, 54.230302423238754, 51.28137566149235, 51.91441789269447, 54.613321870565414, 54.63288702070713, 55.12852102518082, 56.35452903807163, 53.20083126425743, 55.83326920866966, 53.116867169737816, 47.71652854979038, 36.7535088211298, 24.945036359131336, 16.105846166610718, 6.488941255956888, 1.9443556666374207, 6.296586552634835, 8.517730291932821, 5.551985632628202, 5.0072297640144825, 0.861478135921061, 0.37731304415501654, 0.34627538931090385, 1.4960850519128144, 0.43748818861786276, 0.20759754086611792, 0.8348515396937728, 0.5422926507890224, 2.584985615685582, 9.973724763840437, 33.79928134381771, 44.57171089947224, 44.96169917285442, 45.44306494295597, 41.53144843876362, 13.139516338706017, 1.797555887605995, 0.14298966707428917, 0.2132733230246231, 0.25969555077608675, 0.12626180687220767, 0.11985372533672489, 0.19503655785229057, 0.11506509166792966, 0.12182907012174837, 0.09111770792515017, 0.18290423933649436, 0.15846273367060348, 0.08459004413452931, 0.11500432461616583, 0.14544448378728703, 0.13228224241174757, 0.1231728027050849, 0.17728643375448883, 0.0725142921146471, 0.19718911265954375, 0.114079705090262, 0.1164398757100571, 0.22243905463255942, 0.1709101235610433, 0.21413270034827292, 0.14450755203142762, 0.10586744770989753, 0.10936277772998437, 0.14701789623359218, 0.10099276201799512, 0.20884359197225422, 0.1774612392182462, 0.18888262478867546], [0.03842838072159793, 0.058622400829335675, 0.05648237347486429, 0.07071659521898255, 0.02885829180740984, 0.008386674144276185, 0.06957704230444506, 0.024956871566246264, 0.09948828024789691, 0.09238485086825676, 0.030236317179515027, 0.08544978511054069, 0.03651486797025427, 0.024649177139508538, 0.03423472684517037, 0.045587853383040056, 0.01427983321264037, 0.01269634703930933, 0.02088253833790077, 0.054999161657178774, 0.016471229246235453, 0.018744590852293186, 0.021923996027908288, 0.009691634149930906, 0.013168128461984452, 0.00915775352041237, 0.049128168684546836, 0.027154764175065793, 0.022940764320082963, 0.03626127610914409, 0.06715881347190589, 0.020124788861721754, 0.0690238454262726, 0.006821613642387092, 0.032025201071519405, 0.04640861305233557, 0.07861389996833168, 0.8420408132951707, 12.076816912740469, 33.93456928431988, 47.371157482266426, 37.19762898981571, 25.48589363694191, 25.346175134181976, 21.082786805927753, 15.397849157452583, 2.261075796559453, 0.14566825615474954, 0.0739609234733507, 0.037350155180320144, 0.049139334296341985, 0.034522921341704205, 0.05073231346614193, 0.1586403147666715, 0.2753003337420523, 0.20061124465428293, 0.9766255540307611, 1.8699621898122132, 2.1335456147789955, 1.5568635030649602, 1.9431467377580702, 2.52131100744009, 7.197734797373414, 13.113756570965052, 13.958082664757967, 25.867320969700813, 22.58608303964138, 43.07734988629818, 47.62347154319286, 50.674301236867905, 56.68844752013683, 54.35876213014126, 53.874056339263916, 52.47802644968033, 52.86410853266716, 51.523304879665375, 53.75525951385498, 51.59539461135864, 54.989927262067795, 52.44117222726345, 55.23144990205765, 53.64841304719448, 50.07607653737068, 46.01952441036701, 47.99341969192028, 48.11277128756046, 52.42636062204838, 50.99520541727543, 57.23227433860302, 40.82657866179943, 38.38266000151634, 57.91040875017643, 51.804349198937416, 50.99903181195259, 46.63995511829853, 42.97980152070522, 39.02281165122986, 40.03289245069027, 41.606460213661194, 40.79613469541073, 40.34672901034355, 46.99138306081295, 48.92753876745701, 52.90524132549763, 48.904846385121346, 51.64470076560974, 52.27518193423748, 52.14660823345184, 53.72966788709164, 54.80568274855614, 53.38266670703888, 53.29398326575756, 53.48463423550129, 51.4907406270504, 52.31692649424076, 48.305645138025284, 41.97396129369736, 32.96906389296055, 22.31158196926117, 11.946876235306263, 3.6499212216585875, 0.5608767410740256, 0.4942357982508838, 3.831234904937446, 4.9677912052720785, 1.3476874586194754, 0.3337906248634681, 0.008546128283342114, 0.03863234887830913, 0.16379830049118027, 0.7968378451187164, 0.12809023610316217, 0.14262019627494738, 0.1094681404356379, 1.2906427821144462, 8.083495292812586, 18.441225551068783, 24.87938728183508, 20.07246471941471, 31.529570035636425, 34.285514652729034, 18.88022929430008, 5.69775958545506, 0.2306424136622809, 0.10678642691345885, 0.04671818882343359, 0.019947007385781035, 0.056834778588381596, 0.04157458221015986, 0.016969395874184556, 0.03729126576217823, 0.05090498896606732, 0.04705105318862479, 0.037369391648098826, 0.03489976537821349, 0.03691531972435769, 0.06996128926402889, 0.04820124479010701, 0.010965051951643545, 0.04932155381538905, 0.0507662704330869, 0.024125257987179793, 0.04432094792718999, 0.039898449103930034, 0.03611890992033295, 0.03258689554058947, 0.03806668391916901, 0.037715247308369726, 0.03262902355345432, 0.06314412850770168, 0.017618185083847493, 0.0018001667399403232, 0.04626672183803748, 0.0664867096929811, 0.047937455819919705, 0.02450128009513719, 0.015749876547488384, 0.043963559292024, 0.027089813265774865, 0.0536477367131738, 0.056298836643691175, 0.028793814017262775, 0.03755397490749601, 0.03799426514888182, 0.027071049917140044, 0.011728470508387545, 0.10490025117178448, 0.018182488202000968, 0.0373331451555714, 0.02816896463627927, 0.0031357856778413407, 0.043035073176724836, 0.0321047444595024, 0.060727202144335024, 0.04973105606040917, 0.013672556960955262, 0.05576679097430315, 0.02704032314795768, 0.026061823700729292, 0.08980788406915963, 0.04196673304249998, 0.032107816950883716, 0.03064205859118374, 0.027095989789813757, 0.02496974226232851, 0.04561629248200916, 0.004348744187154807, 0.025308480726380367, 0.03645925513410475, 0.01897797959827585, 0.02858679563360056, 0.010216906794084935, 0.0127879577485146, 1.0183655424043536, 15.599879566580057, 39.74430933594704, 53.195321559906006, 42.00694352388382, 30.43073169887066, 26.705033518373966, 23.603069968521595, 17.06868790090084, 2.152428226545453, 0.20397964515723288, 0.0367083829769399, 0.04535282263532281, 0.040621527296025306, 0.01767505586030893, 0.14743642299436033, 0.2197799543500878, 0.5282285367138684, 0.6828272785060108, 2.2947733383625746, 2.4194320617243648, 4.344072723761201, 4.916404187679291, 4.021908435970545, 2.900254698470235, 8.583201728761196, 14.375225231051445, 18.04353129118681, 27.323777116835117, 28.025268875062466, 44.447772949934006, 49.668081030249596, 52.01923526823521, 57.0765320956707, 55.4268354177475, 55.66066727042198, 55.47567039728165, 54.16698262095451, 53.54453422129154, 55.34170858561993, 54.209183156490326, 55.702928602695465, 56.203813925385475, 56.42460487782955, 54.33623693883419, 51.26031719148159, 48.196062818169594, 48.921421095728874, 48.782082572579384, 53.01029808819294, 51.62619575858116, 56.829484552145004, 42.91704788804054, 40.7913089543581, 56.424924060702324, 55.743267238140106, 53.99351812899113, 49.63591955602169, 43.948627933859825, 40.414030998945236, 41.2200665473938, 42.706683576107025, 41.046476662158966, 42.62083858251572, 48.543706163764, 52.24511034786701, 54.8494677990675, 49.988715425133705, 52.98352472484112, 53.44967231154442, 51.43357269465923, 52.702092826366425, 54.19298082590103, 52.86095090210438, 54.39059302210808, 54.23339545726776, 53.5366952419281, 53.24741296470165, 48.70773196220398, 45.104932487010956, 36.84421755373478, 24.975391030311584, 13.810319043695927, 6.862797969952226, 2.3904308304190636, 3.1969727016985416, 5.844718124717474, 5.601593870669603, 2.023975169286132, 0.4204951145220548, 0.21146690589375794, 0.18067340279230848, 0.17671178880846128, 1.5649701305665076, 0.27044544112868607, 0.16075617779279128, 0.2455143109546043, 1.2819357868283987, 9.891441129148006, 24.920216090977192, 34.93339888751507, 26.300600320100784, 36.07024468481541, 39.69610132277012, 23.29118460416794, 7.14076635427773, 0.42660174309276044, 0.09091879750485532, 0.03938905749237165, 0.0457560017821379, 0.0798673354438506, 0.0613144116505282, 0.01368390903735417, 0.04236828688590322, 0.0483702243946027, 0.03922001851606183, 0.036498781919362955, 0.12954054109286517, 0.06403380029951222, 0.06383031824952923, 0.01594640652911039, 0.05299434618791565, 0.025362761407450307, 0.04449731932254508, 0.04959600744768977, 0.01744234061334282, 0.014148450809443602, 0.06753380584996194, 0.053918112243991345, 0.021885179849050473, 0.03712476493092254, 0.04051427953527309, 0.013877030705771176, 0.015292771095118951, 0.02828424985636957, 0.06580886169103906, 0.044658925689873286, 0.02250042398372898, 0.042420879181008786, 0.10938127205008641, 0.21543957787798718, 0.15203807997750118, 0.2061248230165802, 0.18311775522306561, 0.08583171656937338, 0.16265175654552877, 0.10647276561940089, 0.20331414649263024, 0.15746043354738504, 0.24016326293349266, 0.22660397255094722, 0.13513859070371836, 0.12585329910507426, 0.10748391956440173, 0.10698834303184412, 0.10591299331281334, 0.1822917745448649, 0.09335255206678994, 0.13105970254400745, 0.1869344277656637, 0.14694896555738524, 0.15435862733284011, 0.07492489166907035, 0.16005989484256133, 0.098630780557869, 0.21959073637844995, 0.14312043349491432, 0.1352731420774944, 0.12798369338270277, 0.2143577195238322, 0.09517119979136623, 0.15027616202132776, 0.09546521643642336, 0.14784466358833015, 0.12366655355435796, 0.19050665170652792, 1.6958075598813593, 19.567739702761173, 48.55717644095421, 59.489474818110466, 48.6966897547245, 36.114679500460625, 35.20735278725624, 30.784506015479565, 26.61162693053484, 3.2994111673906446, 0.43799255217891186, 0.16725823748856783, 0.3087117034010589, 0.20846908941166475, 0.18406947056064382, 0.20866216655122116, 0.3288584004621953, 0.7489483617246151, 1.0905224829912186, 3.637218978255987, 2.267326698638499, 3.4850245574489236, 3.8768742559477687, 4.04912875033915, 3.442702190950513, 10.25099778547883, 15.147465392947197, 17.426852881908417, 29.264433681964874, 30.24044170975685, 48.09720352292061, 52.73133225739002, 52.480458319187164, 58.516138046979904, 58.543587774038315, 58.37143801152706, 58.49376484751701, 56.69659048318863, 57.67699867486954, 57.73177653551102, 57.936558946967125, 59.72910895943642, 57.931885197758675, 59.51879024505615, 56.89653195440769, 54.84507143497467, 50.16360104084015, 51.62233516573906, 50.654785484075546, 56.18520252406597, 54.11615274846554, 57.16165892779827, 44.41073253750801, 43.366844952106476, 58.04371699690819, 57.57544532418251, 54.42133717238903, 52.162217795848846, 45.762699991464615, 43.11570882797241, 44.108348563313484, 44.87892061471939, 43.69825556874275, 45.01752197742462, 49.609605967998505, 53.49910005927086, 56.01664736866951, 53.07867921888828, 53.880812376737595, 54.16331961750984, 52.026264891028404, 54.922731667757034, 55.06077826023102, 53.3350894600153, 54.05349791049957, 55.06863243877888, 54.19307582080364, 56.852028742432594, 51.52081981301308, 46.95998154580593, 35.92277079820633, 25.337220914661884, 13.204764537513256, 5.444869855418801, 1.495009590871632, 2.014987701550126, 8.323952089995146, 7.833315767347813, 2.5873685628175735, 1.2936145788989961, 0.32096631301101297, 0.4036108689615503, 0.38748569204472005, 2.7169924322515726, 0.747584531782195, 0.43157181702554226, 0.6264203740283847, 1.7299088300205767, 11.712303422391415, 24.74769774824381, 33.14551122486591, 30.19475296139717, 42.61177606880665, 48.81782345473766, 26.70718990266323, 8.470040950924158, 0.6068168696947396, 0.22993459773715585, 0.17437920381780714, 0.08713440838619135, 0.13763557624770328, 0.18197346740635112, 0.2029256321839057, 0.11397195266908966, 0.10009353878558613, 0.1316982167190872, 0.11580553982639685, 0.19685085659148172, 0.15218655404169112, 0.14911271195160225, 0.17109475506003946, 0.16853553301189095, 0.16801076038973406, 0.1817659183871001, 0.18538831151090562, 0.12807322607841343, 0.0995146635978017, 0.1526910808752291, 0.11960595191339962, 0.13033852796070278, 0.10714285817812197, 0.14065181283513084, 0.097619218431646, 0.19475362147204578, 0.05844202183652669, 0.16979685751721263, 0.1323614889406599, 0.15347701526479796, 0.11255112578510307], [0.048524969606660306, 0.01904673030367121, 0.03885763151629362, 0.07901727949501947, 0.07195736965513788, 0.028423914627637714, 0.0065578937847021734, 0.011462379025033442, 0.057987437830888666, 0.05305623388267122, 0.03579501812055241, 0.037264548445818946, 0.022892786328156944, 0.12747161148581654, 0.06740853874362074, 0.010993019786837976, 0.02300760770594934, 0.01872777193057118, 0.034069743705913424, 0.06158377043902874, 0.029860532558814157, 0.04168063882389106, 0.019990992623206694, 0.0742426872602664, 0.011214857931918232, 0.08886157898814417, 0.016014316752261948, 0.05163981164514553, 0.053967869534972124, 0.011986567205894971, 0.03451566684816498, 0.07127989272703417, 0.06610410287976265, 0.043773617726401426, 0.06972467032028362, 0.054825350671308115, 0.09445306801353581, 0.09429721700144, 3.565528937615454, 21.394769065082073, 43.79661329090595, 34.469838961958885, 23.410351909697056, 28.25368981808424, 22.722165137529373, 12.625421024858952, 8.675059899687767, 0.6571072898805141, 0.047341956524178386, 0.03014014226209838, 0.03494952637993265, 0.13863661471987143, 0.1136146456701681, 0.2800843957811594, 0.24843062477884814, 0.6019130547065288, 2.0533174322918057, 1.948072579689324, 2.729985360056162, 1.7366472934372723, 0.7897164335008711, 0.3788474790053442, 1.7248656693845987, 5.833637919276953, 9.222666565328836, 14.506690576672554, 17.779563255608082, 27.91341807693243, 40.701162591576576, 40.09533829987049, 55.92872388660908, 53.12876433134079, 56.04720912873745, 51.43430985510349, 56.57138720154762, 52.549360021948814, 55.597146078944206, 53.710380122065544, 54.44342918694019, 54.251843467354774, 55.448125675320625, 52.70859807729721, 51.37999176979065, 45.48203185200691, 47.25822754204273, 47.036638632416725, 53.32733787596226, 49.13885682821274, 60.10985232889652, 45.79452708363533, 38.482606038451195, 54.971148669719696, 51.62315972149372, 51.73141971230507, 47.059258818626404, 43.44656087458134, 40.73458559811115, 43.50701563060284, 39.49197627604008, 43.2407259196043, 39.29097846150398, 44.21297214925289, 46.989809945225716, 50.16761742532253, 51.93491019308567, 51.45091876387596, 51.864940747618675, 52.88121901452541, 51.7353069037199, 51.506779566407204, 53.30271139740944, 53.03028501570225, 50.332296788692474, 53.14782410860062, 45.32125107944012, 39.55051973462105, 29.2259531468153, 22.267785519361496, 11.208162624388933, 4.781408831477165, 1.2707586865872145, 0.8466617809608579, 4.0361828450113535, 5.971408551558852, 3.7523720366880298, 1.6405338258482516, 0.07860491255996749, 0.03377018321771175, 0.23182990931672975, 0.38381734513677657, 1.12984087318182, 0.23906341491965577, 0.1547504961490631, 0.4450091131730005, 2.5927773350849748, 9.10465344786644, 10.55194828659296, 10.262400973588228, 22.16450896114111, 29.712754525244236, 24.503042176365852, 10.234827753156424, 1.4858702500350773, 0.02774787189991912, 0.025049445212061983, 0.029139716061763465, 0.020158278275630437, 0.038995043869363144, 0.05732864075980615, 0.03859459582599811, 0.02997587715071859, 0.03900967160006985, 0.025660099163360428, 0.05473530589370057, 0.01689688619080698, 0.043893285328522325, 0.029057012980047148, 0.03837276788544841, 0.061329818636295386, 0.03466172893240582, 0.026984339237969834, 0.02509189234842779, 0.016118595922307577, 0.019322785119584296, 0.0681931669532787, 0.02120030370861059, 0.02640614125994034, 0.05218318248807918, 0.033910460260813124, 0.027148422523168847, 0.015228234860842349, 0.0058453972269489896, 0.01999500578676816, 0.053468641635845415, 0.03323734345030971, 0.02153454661311116, 0.07424950759741478, 0.05252632930933032, 0.08104694206849672, 0.04640319537429605, 0.0961080944398418, 0.03378638801223133, 0.08877529689925723, 0.008034141937969252, 0.045574093965115026, 0.03700548695633188, 0.036139419171377085, 0.0470787167432718, 0.028137328736193012, 0.09932787244906649, 0.027119809019495733, 0.03141904453514144, 0.03692842605232727, 0.029572974453913048, 0.05198297702008858, 0.02814874296745984, 0.045093134031048976, 0.005253788176560192, 0.07387011428363621, 0.07253882751683705, 0.018609518119774293, 0.02393947430391563, 0.023370900125883054, 0.01939725407282822, 0.02276150040415814, 0.043379882408771664, 0.03094805721048033, 0.028280388833081815, 0.04914516015560366, 0.10512665074202232, 0.0737068269518204, 0.045590640147565864, 0.08271596539998427, 0.09055572401848622, 4.6600457187741995, 26.062852777540684, 49.85975034534931, 39.84604127705097, 23.64343900233507, 28.611539416015148, 28.593836165964603, 21.00226152688265, 10.936979725956917, 0.6057498988229781, 0.08281533897388726, 0.10343333691707812, 0.1685424498282373, 0.17783180839614943, 0.09834976634010673, 0.3718136704992503, 0.6670653086621314, 1.4386568334884942, 7.149702999740839, 2.7548581128939986, 6.773037286475301, 4.571976894512773, 3.0904140695929527, 2.016943171620369, 3.3845686353743076, 7.563144089654088, 13.616079166531563, 18.163597248494625, 22.728917375206947, 30.927482843399048, 43.47266547381878, 44.85353037714958, 58.24311129748821, 53.32169897854328, 55.94330370426178, 53.558213487267494, 56.80545464158058, 54.06379535794258, 56.51058666408062, 55.35144366323948, 57.43601940572262, 55.73617301881313, 57.91367657482624, 52.36931428313255, 53.65722097456455, 48.536866530776024, 48.648686930537224, 48.97988095879555, 54.82514150440693, 50.63155733048916, 61.80799260735512, 47.631713300943375, 41.66506826877594, 56.39136426150799, 53.428344056010246, 52.340504229068756, 50.68632759153843, 44.977563321590424, 42.29391552507877, 44.63940806686878, 42.23994702100754, 43.79480838775635, 42.317025884985924, 45.54937943816185, 49.63954076170921, 52.74985246360302, 55.10188065469265, 52.49793738126755, 53.1549297273159, 53.536106273531914, 53.567921966314316, 52.61784754693508, 53.881652131676674, 52.476711720228195, 52.18726985156536, 52.7933145314455, 47.40574702620506, 41.164657920598984, 33.536377251148224, 25.292793698608875, 17.315632849931717, 9.127824604511261, 3.115175203420222, 3.5836565773934126, 9.086743108928204, 6.897468259558082, 5.650478722527623, 4.175309529528022, 0.3503049543360248, 0.4394132306333631, 0.13317633740371093, 0.9731796139385551, 1.4273473341017962, 0.21682021004380658, 0.1330684736603871, 0.5507831764407456, 3.2622783724218607, 12.251911517232656, 15.968635529279709, 15.13491751626134, 24.861471243202686, 35.93692123889923, 31.21998354792595, 12.241224590688944, 2.259011557325721, 0.015312350806198083, 0.06087332731112838, 0.03433860525547061, 0.01181801062557497, 0.05019938835175708, 0.08017083673621528, 0.023128763314161915, 0.015244473052007379, 0.07981039787409827, 0.009535861063341144, 0.07518756741774268, 0.03214451986423228, 0.020066704673809, 0.04028929746709764, 0.0818870755028911, 0.042355855912319385, 0.06020424407324754, 0.07911933964351192, 0.036078618722967803, 0.031048740675032604, 0.011764512910303893, 0.0521614672470605, 0.04740663840493653, 0.027517305170476902, 0.05807710411318112, 0.04299192100006621, 0.05456473438243847, 0.060854595503769815, 0.052834469024674036, 0.04312813478463795, 0.07122901850380003, 0.05700263754988555, 0.03601046359108295, 0.1988901596632786, 0.11743894006940536, 0.16565119090955704, 0.24989142373669893, 0.1570684608304873, 0.13319425284862518, 0.1413722155848518, 0.059122467355336994, 0.2764182159444317, 0.21864464652026072, 0.12411139687174, 0.10673296259483323, 0.13206258154241368, 0.40719437354709953, 0.17164364748168737, 0.12521678872872144, 0.08895934952306561, 0.14300905197160318, 0.11147594676003791, 0.13409376551862806, 0.12122879881644621, 0.145846935629379, 0.12941016058903188, 0.1640994640183635, 0.2060807542875409, 0.2083176764426753, 0.12742182821966708, 0.13593534560641274, 0.18329679092857987, 0.11136408284073696, 0.07736595638561994, 0.17852798744570464, 0.1727130080689676, 0.22903615375980735, 0.11737881868612021, 0.1508731604553759, 0.27402229607105255, 0.22456829115981236, 6.019142540171742, 31.32432784885168, 60.00004202127457, 46.21458314359188, 30.782347731292248, 40.181855857372284, 30.79073578119278, 18.848679587244987, 14.314157757908106, 1.42546251649037, 0.3323578048730269, 0.35944414674304426, 0.2539541479200125, 0.3172989754239097, 0.19661846046801656, 0.6472214078530669, 0.7590146153233945, 1.5726280258968472, 8.086640574038029, 5.8953713066875935, 6.107099270448089, 5.335348332300782, 3.2635852647945285, 1.0490870126523077, 2.9842040687799454, 6.752132708206773, 11.721169296652079, 17.19291463494301, 21.747817620635033, 33.15428115427494, 46.14251621067524, 45.291612669825554, 58.05134318768978, 55.07224604487419, 58.16822491586208, 55.36645665764809, 58.97321552038193, 56.16909518837929, 57.930015698075294, 57.87906803190708, 58.68552155792713, 57.33411647379398, 57.745246812701225, 55.6427588313818, 54.4065597653389, 50.85711322724819, 50.99568799138069, 52.02243849635124, 56.40233427286148, 54.330385252833366, 62.41746470332146, 48.988179713487625, 44.67627748847008, 56.01709954440594, 55.221190452575684, 54.75057050585747, 51.49044044315815, 47.08982817828655, 43.89275573194027, 47.877719700336456, 43.319818675518036, 47.39955335855484, 43.3813601732254, 48.03489446640015, 51.687665060162544, 55.367767587304115, 56.31305806338787, 55.30171573162079, 55.91593377292156, 56.04027070105076, 53.782488852739334, 54.97666597366333, 55.442543774843216, 53.70928578078747, 50.18071532249451, 54.208426997065544, 47.054132893681526, 40.837833657860756, 33.305011466145515, 25.577001348137856, 14.29362365975976, 6.342451516538858, 2.657664315775037, 3.075898610986769, 10.046583004295826, 10.711436178535223, 7.162356795743108, 5.214464943856001, 0.530348407337442, 0.27718339988496155, 0.5094837269280106, 1.5965771907940507, 2.840852723456919, 0.7884108473081142, 0.5505471734795719, 1.1422303458675742, 3.78349379170686, 14.215814284980297, 18.832444958388805, 19.792332351207733, 35.74362941086292, 44.84176620841026, 38.22010472416878, 15.354679673910141, 2.9681767662987113, 0.24671231542015448, 0.18426680762786418, 0.22045094490749761, 0.08229184284573421, 0.1696091386838816, 0.1717302412725985, 0.10744405139121227, 0.15961165248882025, 0.15538966341409832, 0.09496856378973462, 0.15556299942545593, 0.10548758684308268, 0.1503385024261661, 0.13846491143340245, 0.21945115324342623, 0.11955691821640357, 0.1713439979357645, 0.12267573445569724, 0.12873954110546038, 0.13314981304574758, 0.09110014128964394, 0.247548122133594, 0.08860437286784872, 0.1768066649674438, 0.15574325225315988, 0.20043428696226329, 0.13040935853496194, 0.11354724381817505, 0.1557941487408243, 0.20977066800696775, 0.1348023532773368, 0.15997034730389714, 0.2820365410298109], [0.04418936514412053, 0.022487152527901344, 0.03531003574607894, 0.021135508650331758, 0.01405628070642706, 0.03146182934870012, 0.02909986644226592, 0.10066068061860278, 0.024874973714759108, 0.0385479889519047, 0.05285004299366847, 0.08968389345682226, 0.008730586305318866, 0.018927617456938606, 0.040231280072475784, 0.09054798341821879, 0.015131285326788202, 0.04120205747312866, 0.013950907796242973, 0.029375693047768436, 0.048008813319029287, 0.07770018259179778, 0.008420516078331275, 0.09811391922994517, 0.030319252182380296, 0.03098427772783907, 0.031935082079144195, 0.0627046063891612, 0.06837713794084266, 0.04330702206061687, 0.03836016250716057, 0.005402266415330814, 0.045196196078904904, 0.05678728855855297, 0.04980004610843025, 0.061703538231085986, 0.03565382823580876, 0.059399388628662564, 1.1297134612686932, 10.052500236779451, 32.83675119280815, 44.814799055457115, 41.392372101545334, 23.97197887301445, 19.78385880589485, 19.780636578798294, 11.267775725573301, 6.733966832980514, 0.15807844960363582, 0.13154711545212194, 0.011695732519001467, 0.13052117050392553, 0.10158374905586243, 0.39540013298392296, 0.5954770906828344, 2.069920403882861, 4.034557482227683, 4.159177495166659, 11.448719166219234, 5.314773861318827, 3.254769737832248, 0.9725300269201398, 0.9146471985150129, 2.54082462284714, 6.47376487031579, 6.901791477575898, 13.693349920213223, 13.918070811778307, 28.181501291692257, 29.72322106361389, 44.555785953998566, 49.4310649484396, 54.68888841569424, 54.08652953803539, 58.723606914281845, 56.690712198615074, 57.29321166872978, 53.801981806755066, 56.27103991806507, 53.525953218340874, 57.50099591910839, 51.56820327043533, 52.174008563160896, 46.31941191852093, 48.2116761803627, 47.49433547258377, 52.26024113595486, 49.99981842935085, 57.00914651155472, 46.961083486676216, 37.50873349606991, 57.54904434084892, 52.372616305947304, 51.93014144897461, 48.45030717551708, 46.240269765257835, 41.70884191989899, 42.37261690199375, 43.908042311668396, 43.53028558194637, 45.02516336739063, 44.95251886546612, 45.321824848651886, 47.27915681898594, 49.05765898525715, 50.31749278306961, 51.83470197021961, 51.13577887415886, 52.354377284646034, 52.95654997229576, 52.26158246397972, 52.240877375006676, 48.95124189555645, 45.815342366695404, 34.9811889231205, 27.318970374763012, 16.77056159824133, 8.341703787446022, 5.315607916563749, 2.114978148601949, 1.8062966060824692, 4.576314836740494, 9.365323260426521, 6.02361062541604, 5.503118354827166, 4.251151084899902, 0.49197824439033866, 0.6092732003889978, 0.21864353329874575, 0.6512021098751575, 0.5635564285330474, 0.15826288814423606, 0.13919652061304078, 1.9509726553224027, 4.303628169000149, 10.009815227240324, 23.580594174563885, 28.193972222507, 27.801316492259502, 27.301086634397507, 19.92171160876751, 4.680830603465438, 0.4662815888877958, 0.03380075599125121, 0.04840991816308815, 0.05470976488140877, 0.04425214712682646, 0.04074844568094704, 0.06745656311977655, 0.04908212955342606, 0.016295815221383236, 0.06759475843864493, 0.055948999361135066, 0.05894955807889346, 0.08785041762166657, 0.0541653142136056, 0.011091934156866046, 0.059543031311477534, 0.07018722870270722, 0.005061905430920888, 0.03984952672908548, 0.04420123208547011, 0.05449990036140662, 0.02627788886456983, 0.038134007845656015, 0.040856606283341534, 0.007406588356388966, 0.013060071760264691, 0.017542977693665307, 0.036631604089052416, 0.010189665335929021, 0.1145681792695541, 0.03548449611116666, 0.043620620272122324, 0.16481336555443704, 0.047410764746018685, 0.07968726815306582, 0.04706247855210677, 0.029613974402309395, 0.03655206812254619, 0.041271247901022434, 0.07733647085842676, 0.020186873225611635, 0.04826626805879641, 0.03247654931328725, 0.05991304758936167, 0.040632600139360875, 0.04623165907105431, 0.04963067687640432, 0.008668376704008551, 0.04381754173664376, 0.02690360284759663, 0.056740629734122194, 0.028960053241462447, 0.04039951010781806, 0.03947887591493782, 0.012158380886830855, 0.060712444537784904, 0.039751767326379195, 0.04190468207525555, 0.04268370335921645, 0.0355128387309378, 0.01679474997217767, 0.038467365739052184, 0.15276962978532538, 0.015274129273166182, 0.06329185300273821, 0.06306698967819102, 0.04368840433016885, 0.03643743599241134, 0.03669237114081625, 0.04790932100149803, 0.05761803382483777, 0.06442543904995546, 1.5996809117496014, 13.507276754826307, 38.67978125810623, 48.003834933042526, 43.62034074962139, 26.086863689124584, 23.546318113803864, 21.417896524071693, 16.645816192030907, 6.347911348566413, 0.19718700496014208, 0.10803369514178485, 0.08859237976139411, 0.01707800733129261, 0.240388534439262, 0.3301227232441306, 1.8484006030485034, 2.5088911363855004, 6.139209447428584, 3.995997626334429, 8.193340748548508, 7.459067199379206, 3.9984465949237347, 4.512442164123058, 2.8869088646024466, 5.723353112116456, 11.932631749659777, 10.78697232529521, 15.83816573023796, 19.065072275698185, 31.171695739030838, 34.70979228615761, 46.23050808906555, 52.171436101198196, 55.544648095965385, 55.97989574074745, 57.91450493037701, 59.46214288473129, 58.2407858222723, 54.254621118307114, 55.912445560097694, 55.48262782394886, 57.92505696415901, 53.813077211380005, 52.89545305073261, 49.074207097291946, 50.58117963373661, 49.68305602669716, 53.93540784716606, 51.439944952726364, 57.743643298745155, 47.91355557739735, 41.03193864226341, 57.69230045378208, 53.38271610438824, 55.02704747021198, 49.231853038072586, 46.96847788989544, 43.82626689970493, 42.92817749083042, 44.48621928691864, 46.29655234515667, 46.53823457658291, 46.04998357594013, 48.04490692913532, 49.94608551263809, 50.999875366687775, 52.674840688705444, 52.84960851073265, 51.647379621863365, 54.37353953719139, 53.017145320773125, 53.406871408224106, 52.24780820310116, 48.33177253603935, 47.8823896497488, 37.728384509682655, 29.58627261221409, 21.732907220721245, 11.324179898947477, 7.422529309988022, 3.9435580652207136, 4.63678146712482, 5.750640872865915, 10.00234767794609, 8.70138868689537, 9.084753915667534, 4.320475040003657, 0.8448760549072176, 0.6108812859747559, 0.4189080762444064, 0.8427122491411865, 0.4558825265849009, 0.2285990139353089, 0.16383286972995847, 2.623279723338783, 6.957243802025914, 14.028991609811783, 27.013166584074497, 28.461531065404415, 32.164134085178375, 34.78692054748535, 24.508766569197178, 6.478214906528592, 0.479388065286912, 0.04893845718470402, 0.037398877175292, 0.03064826665649889, 0.014082452544244006, 0.08587456817622297, 0.0987053441349417, 0.03990843099018093, 0.017556588682055008, 0.06114082701969892, 0.005617828310278128, 0.04635822493582964, 0.06624089553952217, 0.0632090812723618, 0.023448096471838653, 0.0416698739718413, 0.014363151349243708, 0.038681115402141586, 0.05586895131273195, 0.017668677101028152, 0.018491846894903574, 0.010088726758112898, 0.037499582904274575, 0.035460639774100855, 0.01454534767617588, 0.04384908672363963, 0.04053479620779399, 0.022075934066378977, 0.027360504209354986, 0.01850679560448043, 0.045648891318705864, 0.014256655940698693, 0.056817126605892554, 0.02124480659404071, 0.15605672058882192, 0.12516062299255282, 0.16060645692050457, 0.17330693401163444, 0.10715523720136844, 0.27615994855295867, 0.11281674043857493, 0.1938341450295411, 0.13606461288873106, 0.12439597339835018, 0.1551918068435043, 0.21756640984676778, 0.08350386648089625, 0.08983247142168693, 0.18256967916386202, 0.28047740750480443, 0.16922617563977838, 0.14918743137968704, 0.12611392652615905, 0.12263419645023532, 0.14652080571977422, 0.19260811706772074, 0.08848078301525675, 0.19710483436938375, 0.1710139203350991, 0.12172272778116167, 0.08184030535630882, 0.15976750350091606, 0.3071654832456261, 0.08569839716074057, 0.21649679692927748, 0.12367800489300862, 0.0992061231227126, 0.20834993018070236, 0.14098974235821515, 0.12445414293324575, 0.15365026221843436, 0.25589177676010877, 2.2137987334281206, 16.711784452199936, 43.89184758067131, 57.524110078811646, 51.28599241375923, 36.06071099638939, 28.359536938369274, 27.10030160844326, 19.38912458717823, 9.479782618582249, 0.6865795177873224, 0.39795460528694093, 0.27284394367597997, 0.21603150002192706, 0.4264777747448534, 1.1461642035283148, 1.2658406817354262, 3.0430068634450436, 10.73480112478137, 10.275346878916025, 17.222395353019238, 11.113048028200865, 11.277952529489994, 5.285397162660956, 2.508914885111153, 4.286679653450847, 9.414904899895191, 8.529369067400694, 16.721000857651234, 19.096986763179302, 32.513247951865196, 35.51153406500816, 46.375208124518394, 53.26206877827644, 58.1266475468874, 58.13874989748001, 60.61249315738678, 61.74697548151016, 60.42773187160492, 55.95528066158295, 56.06991671025753, 56.251767352223396, 59.85028065741062, 56.25667668879032, 55.232544243335724, 51.11952714622021, 52.34941855072975, 52.410450875759125, 55.46835198998451, 55.0692518055439, 56.65539689362049, 50.60805559158325, 44.33477081358433, 59.392720609903336, 55.73698617517948, 56.45674355328083, 50.99260255694389, 48.856687769293785, 44.129213243722916, 45.46275928616524, 47.202241346240044, 48.26717220246792, 49.15381662547588, 49.274247363209724, 50.741994604468346, 51.66699416935444, 52.661248818039894, 54.70284886658192, 54.79988805949688, 54.235903322696686, 56.88914135098457, 54.65519182384014, 54.030167162418365, 54.32341642677784, 49.854685217142105, 49.080457761883736, 37.506115436553955, 31.0337745398283, 19.37841486185789, 10.976451057940722, 6.442784182727337, 4.476441470906138, 4.881361993029714, 7.742479266598821, 16.593565195798874, 12.991171348839998, 16.474380791187286, 10.369132496416569, 1.1869886191561818, 1.407710937783122, 0.4734482418280095, 1.3160851481370628, 2.6555981766432524, 0.7045079057570547, 0.4918449546676129, 3.4295546589419246, 7.339336099103093, 18.744840659201145, 37.587176486849785, 40.12874610722065, 40.15842251479626, 41.04572430253029, 29.402947649359703, 7.708747051656246, 0.7267677050549537, 0.18003157863859087, 0.24678053363459185, 0.13243549590697512, 0.11869154433952644, 0.22357848880346864, 0.15489770856220275, 0.09551039838697761, 0.12795967748388648, 0.2225069611449726, 0.23473394801840186, 0.20303855737438425, 0.1463419629726559, 0.18892605527071282, 0.11947833219892345, 0.1336659025400877, 0.1934830646496266, 0.15439632843481377, 0.10461347788805142, 0.1201993806171231, 0.21646997571224347, 0.15481589420232922, 0.11457344851805829, 0.1705389458220452, 0.15133663167944178, 0.0932425435166806, 0.2115071748266928, 0.12293201289139688, 0.19917698489734903, 0.19283751491457224, 0.09171921119559556, 0.19299228239106014, 0.25745281018316746, 0.1715371641330421], [0.06419840865419246, 0.02059673541225493, 0.06152597568870988, 0.05976045831630472, 0.02680270601558732, 0.05377128574764356, 0.05558950673730578, 0.04825026364414953, 0.02353967007366009, 0.038349776150425896, 0.025458183044975158, 0.025365995315951295, 0.011041051584470551, 0.061332033947110176, 0.05600853815849405, 0.07360388364759274, 0.06495613401057199, 0.03987582473200746, 0.07037591232801788, 0.03475036734016612, 0.019766548612096813, 0.018359277055424172, 0.014400324598682346, 0.02637178353324998, 0.017848692441475578, 0.0213858332062955, 0.02788959798635915, 0.04730480090074707, 0.06257463406655006, 0.02049809099844424, 0.04692809045081958, 0.06962809464312159, 0.012712425668723881, 0.023719295786577277, 0.06184059435327072, 0.04199483446427621, 0.05307614199409727, 0.056311631269636564, 0.07255573364091106, 4.259114032611251, 20.41492134332657, 45.86070813238621, 38.52074459195137, 24.179590232670307, 25.603808909654617, 36.50047279894352, 18.23677372187376, 12.99429003149271, 3.8619113713502884, 0.2178622892824933, 0.07987898716237396, 0.06369276117766276, 0.038697101263096556, 0.4439435078529641, 3.1027159094810486, 2.7138898987323046, 4.313543261960149, 0.9580161119811237, 7.436234224587679, 4.195265583693981, 2.733808667398989, 3.928451263345778, 1.915081087499857, 1.8447738164104521, 7.17055675573647, 5.907943407073617, 7.838543336838484, 7.968136807903647, 15.114362519234419, 21.6791021078825, 30.045572966337204, 39.975982904434204, 46.04999117553234, 50.159311071038246, 53.6933646351099, 53.13968114554882, 55.593312084674835, 54.02140103280544, 56.497298777103424, 54.90164279937744, 54.51931111514568, 51.08465641736984, 51.1530527472496, 47.91957065463066, 47.45220713317394, 48.88129144906998, 52.69508600234985, 50.396646335721016, 57.80846782028675, 47.60595068335533, 37.578129172325134, 56.90013416111469, 52.7670731395483, 52.7545528113842, 48.004784882068634, 46.786346063017845, 44.820783734321594, 44.363185688853264, 45.54179884493351, 50.816349014639854, 49.36732716858387, 51.352059468626976, 49.07771050930023, 48.959916830062866, 47.52655394375324, 47.59343795478344, 47.329842299222946, 50.355475544929504, 51.57128110527992, 52.83277541399002, 52.038253247737885, 45.65844878554344, 44.13997806608677, 29.10353321582079, 22.441683188080788, 11.996924299746752, 7.74223655462265, 1.4678498357534409, 4.25508102402091, 4.861693773418665, 5.108491480350494, 5.521715981885791, 10.383884254842997, 7.719813957810402, 4.799153404310346, 2.7714940952137113, 0.32100677490234375, 0.9615652402862906, 0.18055856286082417, 1.2189259054139256, 0.18151572556234896, 0.4049009591108188, 0.6524138292297721, 3.594668861478567, 9.13283558562398, 16.364669278264046, 18.268173336982727, 23.53059645742178, 36.27430893480778, 21.663182862102985, 10.285712722688913, 1.2584595778025687, 0.04227948149491567, 0.08474363159621134, 0.014928315358702093, 0.010733819144661538, 0.026919087758869864, 0.028764632770617027, 0.03633297499618493, 0.021243168303044513, 0.03966993812355213, 0.009638447208999423, 0.06183747362229042, 0.032639198398101144, 0.00913558649699553, 0.06991310161538422, 0.03964776646171231, 0.015990716456144582, 0.020161983447906096, 0.0369825100642629, 0.04037405444250908, 0.03863006306346506, 0.00885763363839942, 0.04123979939322453, 0.02520459303923417, 0.01985321105166804, 0.06008821670548059, 0.005796961886517238, 0.04805235883395653, 0.025719931109051686, 0.07078430135152303, 0.018167381786042824, 0.06716510688420385, 0.038247894117375836, 0.010398875838291133, 0.044736086783814244, 0.04838221750105731, 0.023295199207495898, 0.09643787518143654, 0.02457971768308198, 0.03741420994629152, 0.020581142889568582, 0.03325145167764276, 0.04107847133127507, 0.07702716597123072, 0.05271238202112727, 0.08981776947621256, 0.020194921817164868, 0.011403157495806227, 0.03800648461037781, 0.010723385476012481, 0.041166189475916326, 0.021652212271874305, 0.026470984557818156, 0.03712850906595122, 0.0596845069230767, 0.01900776940601645, 0.06558235079864971, 0.06282965827267617, 0.031061240297276527, 0.06759774929378182, 0.019002125372935552, 0.01889148414193187, 0.015869423550611828, 0.08219738228945062, 0.03232852424844168, 0.045692726271227, 0.05892765359021723, 0.05666703837050591, 0.03848240907245781, 0.03163117631629575, 0.029776582669001073, 0.066821188229369, 0.057193462271243334, 0.09460629182285629, 5.014833630993962, 23.930393904447556, 52.85987935960293, 41.90311409533024, 28.9724288508296, 19.598219767212868, 28.95157177001238, 23.98023582994938, 15.934617854654789, 3.7258454225957394, 0.2583378955023363, 0.031802708908799104, 0.03455406927969307, 0.09345125028630719, 0.7637698820326477, 1.2727718660607934, 2.194605488330126, 3.190664565190673, 5.686933966353536, 8.105423916131258, 6.3735533226281404, 5.994451940059662, 6.337782992050052, 6.080501172691584, 6.010161722078919, 6.71657944098115, 6.210130741819739, 11.898890510201454, 10.832817815244198, 18.888940326869488, 24.003933258354664, 34.08252194523811, 42.67640300095081, 49.62146893143654, 52.18576893210411, 55.71914613246918, 54.92756500840187, 56.8913110345602, 55.669520795345306, 57.183245569467545, 56.65755517780781, 56.33805312216282, 53.35506118834019, 53.13579015433788, 50.661541521549225, 49.92566540837288, 50.14841705560684, 54.27444465458393, 52.603932693600655, 58.90918515622616, 48.89801435172558, 40.648733004927635, 58.54269482195377, 54.51302245259285, 55.04955366253853, 50.03266006708145, 48.901810348033905, 45.82152083516121, 45.46843998134136, 47.13254928588867, 51.704463958740234, 51.41857109963894, 51.782473772764206, 51.304979994893074, 50.42783126235008, 49.49499271810055, 49.613337367773056, 49.9592974036932, 52.05029100179672, 52.06545978784561, 54.657277911901474, 51.8750824034214, 48.88040229678154, 43.27837809920311, 33.211327493190765, 25.1180087774992, 15.911532193422318, 8.79579747095704, 5.605468237772584, 5.293931029736996, 2.1326680993661284, 6.569334017112851, 8.999962415546179, 11.740272771567106, 6.3144883420318365, 6.964785447344184, 4.785560108721256, 1.4583154348656535, 1.1224101344123483, 0.521753387292847, 0.393049840349704, 0.12212701272801496, 0.19412858469877392, 0.6779461435507983, 4.805323323234916, 9.600944817066193, 18.91442745923996, 25.780199244618416, 27.829531878232956, 42.57823906838894, 27.17352367937565, 13.422897532582283, 1.9288897840306163, 0.014587675141228829, 0.10162503473111428, 0.019085075218754355, 0.028404381300788373, 0.02061348939605523, 0.03942643947084434, 0.058870393186225556, 0.057413557296968065, 0.03826595057034865, 0.022259782599576283, 0.030083794699748978, 0.03668746183393523, 0.05857421689142939, 0.05910791012865957, 0.0748921258491464, 0.04001558969321195, 0.014945145412639249, 0.03470791278232355, 0.039380927264573984, 0.02853500485798577, 0.031215324997901917, 0.03740106651093811, 0.04940631450153887, 0.01186028057418298, 0.013456780307024019, 0.05455655591504183, 0.027076257938460913, 0.030248879884311464, 0.03222728417313192, 0.022567172745766584, 0.05013769732613582, 0.041571524561732076, 0.03099275862041395, 0.011516181948536541, 0.26470216806046665, 0.08705863510840572, 0.18741720967227593, 0.12243627308635041, 0.09613617730792612, 0.18405985232675448, 0.1692651680787094, 0.16653177881380543, 0.20656031527323648, 0.11845882909256034, 0.17265641188714653, 0.07782157568726689, 0.1343162465491332, 0.1617903308942914, 0.11810911426437087, 0.10294612438883632, 0.16610418300842866, 0.1245958634535782, 0.21357791527407244, 0.18212816066807136, 0.07244824839290231, 0.16041413677157834, 0.09510349365882576, 0.09140668538748287, 0.19762067153351381, 0.1560866885120049, 0.11300612168270163, 0.12430484508513473, 0.28941607160959393, 0.12346595103736036, 0.11293454153928906, 0.13125904340995476, 0.12801781733287498, 0.12724411353701726, 0.1385459688026458, 0.1111159309220966, 0.2464070700807497, 0.19995036214822903, 0.3162483614869416, 6.186567731201649, 30.723882168531418, 58.34619976580143, 49.36603903770447, 36.225694343447685, 35.0383872538805, 47.10538074374199, 29.07190941274166, 17.371970526874065, 6.167938755825162, 0.45295953343156725, 0.2590803103521466, 0.1360034747631289, 0.35977716324850917, 1.317431938368827, 8.639031182974577, 7.501000799238682, 16.66745413094759, 9.297790434211493, 14.67855155467987, 11.226907018572092, 5.568178463727236, 8.752345852553844, 6.13250233232975, 5.88284432888031, 10.629551522433758, 8.800481669604778, 10.672719106078148, 10.367459636181593, 20.355709120631218, 25.471595004200935, 32.76276916265488, 43.39508503675461, 50.33611558377743, 52.8490499407053, 57.99131780862808, 56.29527121782303, 59.39167946577072, 55.938557758927345, 59.107397720217705, 58.59320171177387, 57.56055012345314, 55.631393641233444, 54.98479373753071, 52.60085105895996, 51.73100933432579, 52.773403599858284, 57.14229516685009, 56.25419922173023, 59.583090394735336, 50.83474762737751, 44.628039076924324, 56.31512515246868, 57.207017093896866, 57.347161173820496, 53.325825557112694, 51.21829904615879, 49.94337625801563, 47.15439431369305, 50.17448365688324, 54.51661325991154, 54.61961813271046, 54.457579627633095, 54.38522391021252, 53.4773538261652, 52.06653133034706, 51.422161906957626, 51.215156614780426, 53.64451065659523, 55.13434611260891, 57.49418668448925, 55.66893182694912, 48.86300303041935, 44.194649532437325, 32.99535848200321, 23.48395586013794, 14.85687218606472, 9.269135221838951, 3.6791910510510206, 7.7237324975430965, 9.115014541894197, 10.327863860875368, 11.922692432999611, 16.260254681110382, 17.455140464007854, 13.845770191401243, 10.251619052141905, 2.129391012713313, 2.2059319680556655, 0.4542723926715553, 2.5818567210808396, 0.9499925456475466, 0.8132407336961478, 1.3868463761173189, 6.114550195634365, 15.128224175423384, 28.499722816050053, 32.89336435496807, 35.26662960648537, 52.48792491853237, 35.74853114783764, 16.031147874891758, 2.318247053772211, 0.18134865327738225, 0.22167341056047007, 0.11757528001908213, 0.1320969726657495, 0.10142325219931081, 0.16859736875630915, 0.18934100487967953, 0.0910248800937552, 0.10841593830264173, 0.11823985842056572, 0.1843654687399976, 0.09075954745640047, 0.1172900949313771, 0.34177678695414215, 0.13333218841580674, 0.09156329339020886, 0.14605369797209278, 0.12604501069290563, 0.09841075603617355, 0.0939080941316206, 0.15039428224554285, 0.15024809399619699, 0.13710882951272652, 0.11313942624838091, 0.09907781321089715, 0.08261599068646319, 0.1438363388297148, 0.12754300609230995, 0.2198734798002988, 0.11189200216904283, 0.10756122908787802, 0.08882559966878034, 0.10690205352148041, 0.10296460386598483], [0.056151661337935366, 0.07316442832234316, 0.02025745518039912, 0.022546689469891135, 0.019435313261055853, 0.033084620590670966, 0.024524017644580454, 0.09200585089274682, 0.04526264427113347, 0.029019783141848166, 0.03404514893190935, 0.08292605256428942, 0.004067941481480375, 0.09100787749048322, 0.029388708462647628, 0.08908329560654238, 0.015650334134988952, 0.03300630545709282, 0.019426201542955823, 0.042003101989394054, 0.06655255303485319, 0.04117474272788968, 0.053382871628855355, 0.03261033256421797, 0.034736507732304744, 0.00195956487004878, 0.05742257068050094, 0.05334976813173853, 0.052675278348033316, 0.07819862381438725, 0.018220621604996268, 0.04619542000000365, 0.06343605229631066, 0.07583504673675634, 0.01504918060163618, 0.015255577436619205, 0.04731116110633593, 0.021115420568094123, 0.057268537930212915, 0.34356289892457426, 7.493894230574369, 32.32750631868839, 45.68891555070877, 31.49372275918722, 29.616754576563835, 18.733830749988556, 26.085628755390644, 20.23608583956957, 8.053714390844107, 1.7313703265972435, 0.5729475058615208, 0.03189557755831629, 0.3364759823307395, 0.29887489217799157, 1.4852796192280948, 0.9886991092935205, 0.8937908301595598, 2.010469506494701, 7.0673044212162495, 5.715940659865737, 2.7585244411602616, 6.341107813641429, 5.7876228634268045, 8.145807199180126, 6.291511449962854, 2.3966810200363398, 4.063007030636072, 3.9351997012272477, 6.3628454972058535, 13.210888858884573, 17.19524770975113, 26.129748187959194, 33.092458471655846, 40.778321251273155, 45.90251728892326, 51.60754255950451, 55.53039126098156, 54.44804973900318, 57.573081851005554, 55.223747715353966, 55.798421278595924, 52.714217975735664, 52.5841623544693, 50.03917671740055, 50.607808604836464, 48.00391472876072, 54.10069517791271, 51.68291911482811, 56.094094812870026, 48.88201721012592, 39.62172411382198, 57.78534226119518, 52.77767077088356, 52.998203337192535, 51.51773817837238, 48.762661814689636, 46.78561270236969, 45.55584289133549, 51.158946231007576, 51.206287890672684, 52.99762196838856, 55.353506952524185, 52.32302136719227, 51.803019270300865, 51.733558997511864, 51.45135574042797, 48.89484532177448, 51.84324771165848, 51.165196895599365, 47.2623997181654, 48.05053062736988, 38.753436505794525, 29.606120847165585, 19.71025675535202, 10.269447695463896, 4.802256412804127, 1.9232122949324548, 3.554780026897788, 1.3420632854104042, 1.8396626156754792, 7.165572848170996, 7.829050971195102, 8.754999060183764, 4.489756906405091, 6.765149859711528, 1.5058648958802223, 1.0802468843758106, 0.5668403429444879, 1.1305675841867924, 0.09345647500595078, 0.1930047504720278, 0.39600409276317805, 3.1020782561972737, 7.113947868347168, 17.7800078317523, 19.34064868837595, 25.013518184423447, 27.77071673423052, 26.254140213131905, 16.788806319236755, 4.521648595109582, 0.246075285540428, 0.07160745444707572, 0.004246421503921738, 0.018943477152788546, 0.06861791291157715, 0.04860518092755228, 0.034659688026295044, 0.011715983873727964, 0.058965607022400945, 0.04106287509785034, 0.07662751944735646, 0.06683170446194708, 0.11000507685821503, 0.04970877678715624, 0.011886614756804192, 0.013801292680000188, 0.03190326249750797, 0.04685313724621665, 0.010164400773646776, 0.038964612103882246, 0.02464168515871279, 0.019616840727394447, 0.09556018165312707, 0.07427718228427693, 0.019318217200634535, 0.03830636793281883, 0.042316369945183396, 0.013441624723782297, 0.016477133031003177, 0.06857845291960984, 0.042007039082818665, 0.03746997863345314, 0.03227785782655701, 0.05280034507450182, 0.05537544908293057, 0.06184531812323257, 0.02625183577038115, 0.02268597760121338, 0.05835714240674861, 0.013603808110929094, 0.06258048219024204, 0.11050262750359252, 0.07663716736715287, 0.05196408565097954, 0.005018705478505581, 0.015524748832831392, 0.027448686196294148, 0.06728680426022038, 0.09853379669948481, 0.03478844322671648, 0.07667883153771982, 0.018376988409727346, 0.05444901871669572, 0.022768203853047453, 0.02440334628772689, 0.016144344735948835, 0.12085438531357795, 0.04250932834111154, 0.018385087096248753, 0.044880256391479634, 0.008118923960864777, 0.05629931532894261, 0.0322453480475815, 0.07870460525737144, 0.10634063364705071, 0.010013267965405248, 0.015218976568576181, 0.0452241713355761, 0.04747522769321222, 0.018631556195032317, 0.0587793984595919, 0.043035299531766213, 0.045947078833705746, 0.10335074330214411, 0.4376557358773425, 8.632399588823318, 37.038634121418, 50.284704342484474, 33.82235370576382, 29.935114793479443, 24.002559632062912, 28.605609834194183, 22.266421392560005, 9.460853934288025, 1.8799119559116662, 0.37657950539141893, 0.09889478475088254, 0.0801611368660815, 0.32478587992955, 0.5713289708364755, 0.9801165573298931, 2.8582845255732536, 3.7097898591309786, 5.9415787272155285, 7.6055037416517735, 6.824447102844715, 4.845211682841182, 7.037620889022946, 8.51003285497427, 4.320165356621146, 3.5351262940093875, 6.211428372189403, 7.917149243876338, 8.217332661151886, 16.032952778041363, 21.214900016784668, 30.107891522347927, 38.819070383906364, 43.67019407451153, 47.95082397758961, 53.48213016986847, 56.79142579436302, 55.28014428913593, 59.20620761811733, 56.00577235221863, 57.84141205251217, 54.690412133932114, 54.305473789572716, 51.445948630571365, 52.607911080121994, 51.49206295609474, 55.95113508403301, 54.667499363422394, 57.413368821144104, 50.45012466609478, 42.124608010053635, 57.00177110731602, 53.92668731510639, 55.123360902071, 53.07681731879711, 50.29079541563988, 48.820388317108154, 47.6881592720747, 51.988259330391884, 54.36344727873802, 55.72277493774891, 55.75604975223541, 54.315995424985886, 54.08471703529358, 52.37632490694523, 52.54743732511997, 50.94953566789627, 51.150028109550476, 53.20632576942444, 50.013995468616486, 48.78633074462414, 39.44930836558342, 33.050079345703125, 22.631805986166, 13.313436806201935, 6.449347380548716, 4.382474888116121, 3.011381635442376, 3.5752692399546504, 4.602602776139975, 5.988440662622452, 11.129779480397701, 11.144513189792633, 5.575668336823583, 7.4331017676740885, 4.331586118787527, 2.326263436116278, 0.713897617533803, 0.39305200742091984, 0.11214264028239995, 0.13071726076304913, 0.39818873803596944, 3.894919012673199, 9.485568758100271, 20.891611464321613, 25.627164356410503, 26.410243436694145, 32.922421395778656, 32.66834802925587, 22.079798206686974, 6.097268722951412, 0.35700337146408856, 0.0068598115194618, 0.10548222853685729, 0.05956453132966999, 0.07381906936643645, 0.020960753281542566, 0.04020819927973207, 0.008963244035840034, 0.03796997094468679, 0.030314179603010416, 0.041026090548257343, 0.038392946880776435, 0.018559163399913814, 0.032257853235933, 0.046582787690567784, 0.014608258607040625, 0.04993481641577091, 0.03464525696472265, 0.01093110055080615, 0.055351477712974884, 0.008865170148055768, 0.022617097019974608, 0.04563250098726712, 0.07842929815524258, 0.01962064237886807, 0.024279851058963686, 0.01746251404256327, 0.04656836033973377, 0.02133769008651143, 0.010485605071153259, 0.014051486432435922, 0.05225081811659038, 0.07645694422535598, 0.04478019633097574, 0.07432605270878412, 0.19754920271225274, 0.2412008002283983, 0.16405696864239872, 0.08001974289072677, 0.15605786349624395, 0.09026294676004909, 0.1536876367754303, 0.22450911230407655, 0.28262043313588947, 0.12424735090462491, 0.0838689660304226, 0.24110819504130632, 0.19448192120762542, 0.29020274814683944, 0.10898398555582389, 0.14605273318011314, 0.10367129172664136, 0.16013350104913116, 0.06927988637471572, 0.13621608522953466, 0.1125859770399984, 0.2670904289698228, 0.1763989735627547, 0.1474631848395802, 0.13962755998363718, 0.05957348163065035, 0.12791736022336408, 0.20667839096859097, 0.112078889796976, 0.21673005394404754, 0.0775386615714524, 0.17990847118198872, 0.12604509975062683, 0.20211443508742377, 0.11015995565685444, 0.1274007512256503, 0.13683217170182616, 0.1266399014275521, 0.170206923794467, 0.7605661195702851, 11.651394590735435, 42.97541655600071, 59.28615912795067, 43.21577645838261, 41.71081401407719, 29.625192023813725, 36.54625654220581, 26.62322010844946, 10.778618473559618, 2.7577618695795536, 0.9608089621178806, 0.2070719370385632, 0.7047465804498643, 1.496141217648983, 4.0978920087218285, 4.327149381861091, 7.637396855279803, 10.080896113067865, 17.165599800646305, 19.34784360229969, 11.671922039240599, 13.656161315739155, 12.449064888060093, 14.729559067636728, 11.641612015664577, 5.756308268755674, 6.999562131240964, 7.506066402420402, 7.7615737169981, 16.527211256325245, 21.364372596144676, 30.44911701232195, 38.603610545396805, 45.24630770087242, 51.16038255393505, 55.16022652387619, 57.02087268233299, 56.69530235230923, 60.5913320928812, 59.44862700998783, 59.48712274432182, 56.90343618392944, 55.94122141599655, 53.88383701443672, 54.51647266745567, 51.988988891243935, 58.60016293823719, 58.465023189783096, 58.034092113375664, 52.306982427835464, 45.83464913070202, 57.76583790779114, 55.543420761823654, 56.53980329632759, 56.104795038700104, 52.9628462344408, 51.21280074119568, 49.137097522616386, 53.89224976301193, 56.0415094345808, 58.164675906300545, 59.10804368555546, 57.96542599797249, 55.05568653345108, 55.84545135498047, 56.27982124686241, 52.294522896409035, 53.367672711610794, 55.46658128499985, 50.306150391697884, 51.24879240989685, 41.29862733185291, 32.81519494950771, 22.94925805181265, 13.09408787637949, 6.443712282925844, 3.698936691507697, 6.413886733353138, 4.648892842233181, 5.951110040768981, 14.885481800884008, 17.20999851822853, 20.389297418296337, 12.57424347102642, 17.958068177103996, 11.20213994756341, 4.908270249143243, 1.3823557295836508, 2.887176275253296, 0.8159903611522168, 0.5605563113931566, 1.1526268254965544, 4.7218080796301365, 11.736224088817835, 28.240472227334976, 32.826267555356026, 35.89829631149769, 42.039310187101364, 38.422595858573914, 26.976262964308262, 6.617293143644929, 0.578409000299871, 0.13239095220342278, 0.23362017731415108, 0.14946977404179052, 0.162099999433849, 0.09336803326732479, 0.09502231012447737, 0.162692648882512, 0.1435962540563196, 0.16654914506943896, 0.24666938959853724, 0.2785620727809146, 0.20600049843778834, 0.11345481674652547, 0.19963975850259885, 0.08375184028409421, 0.17078781762393191, 0.12942231696797535, 0.1122325069445651, 0.18262995639815927, 0.09455938808969222, 0.10617748732329346, 0.24842928891303018, 0.1738051080610603, 0.10687115049222484, 0.24506001267582178, 0.09046156774275005, 0.06848153585451655, 0.12814373010769486, 0.1252966289757751, 0.13735835440456867, 0.1546434932970442, 0.3399903484387323, 0.1302179289632477, 0.2179860498290509], [0.06167620493215509, 0.07112741106539033, 0.10546592355240136, 0.015094620448508067, 0.020993151738366578, 0.04765995567140635, 0.015886632099864073, 0.01962439393537352, 0.05745364811446052, 0.044164273131173104, 0.05523346881091129, 0.0149263662933663, 0.06558476277859882, 0.022141320987429935, 0.11393382112146355, 0.028324618979240768, 0.032118971430463716, 0.05722943045839202, 0.04083899882971309, 0.0226405804278329, 0.02562776378908893, 0.02984796057717176, 0.05006023566238582, 0.08401982981013134, 0.030612934860982932, 0.05263402978016529, 0.12288914644159377, 0.04291170967917424, 0.03111045025434578, 0.05313256748195272, 0.03174193814629689, 0.016587364225415513, 0.03879197371134069, 0.05681169779563788, 0.0063957488964661025, 0.055835881212260574, 0.1070339851139579, 0.08270249541965313, 0.05455688988149632, 0.0968990012188442, 1.6899098013527691, 17.151246070861816, 35.87022341787815, 43.23751129209995, 31.232329085469246, 14.422122314572334, 25.484176129102707, 22.661362700164318, 17.40738272666931, 5.685452995821834, 2.482514614239335, 0.23646194982575253, 0.13896595017286018, 0.24150227545760572, 0.16746339679230005, 0.9420680708717555, 2.352825435809791, 2.1529530733823776, 2.2136094560846686, 3.2791045820340514, 8.7705297768116, 7.566512133926153, 7.131426455453038, 3.9766901498660445, 1.8209543195553124, 1.2698469730094075, 2.281218278221786, 3.0870054150000215, 1.6260511404834688, 4.652474150061607, 11.0410893894732, 14.975515119731426, 23.384405001997948, 30.296047925949097, 38.733430579304695, 44.37648117542267, 50.29430642724037, 53.107922449707985, 57.23015025258064, 56.94510094821453, 55.087152644991875, 53.90753634274006, 54.80489619076252, 52.33183689415455, 51.78374670445919, 50.4728664457798, 54.84572879970074, 52.22597077488899, 58.19475129246712, 50.01087203621864, 41.993279457092285, 55.799827203154564, 52.80168168246746, 54.354703947901726, 51.45622327923775, 49.49731819331646, 49.189610704779625, 51.421561539173126, 50.58249056339264, 57.599802017211914, 52.42538407444954, 54.10767920315266, 56.415036991238594, 55.219142362475395, 50.845444053411484, 51.896600648760796, 51.85053952038288, 53.80528002977371, 50.301974415779114, 46.07697352766991, 40.453054904937744, 32.8471702337265, 15.789507441222668, 7.1681491099298, 3.758896761573851, 1.9662984204478562, 1.7389183840714395, 3.111383244395256, 3.461510706692934, 1.7637361586093903, 4.242385905236006, 8.1423968821764, 10.017848946154118, 2.815437074750662, 3.219465594738722, 3.985733902081847, 2.2723923018202186, 0.44751222885679454, 0.4219595796894282, 0.14625289040850475, 0.3736335353460163, 1.9992679450660944, 5.254507670179009, 8.999729678034782, 13.959269151091576, 18.08630559593439, 28.03777400404215, 30.776933021843433, 18.798520378768444, 6.82584922760725, 0.7582637399900705, 0.031316424065153114, 0.0966499735659454, 0.01696578532573767, 0.05757924918725621, 0.027234027402300853, 0.06686703811283223, 0.049401312426198274, 0.07855957475840114, 0.04884940688498318, 0.039030722618917935, 0.039914587105158716, 0.01657331536989659, 0.031821655938983895, 0.059382519611972384, 0.12068570998962969, 0.053766012788400985, 0.01276256794881192, 0.08437676573521458, 0.05351192368834745, 0.015585472283419222, 0.0754795060493052, 0.0496017331170151, 0.05548538712901063, 0.035494652402121574, 0.06679594036540948, 0.05972672028292436, 0.07173784237238578, 0.029384472654783167, 0.0862601213157177, 0.055052158422768116, 0.05872517343959771, 0.043080481482320465, 0.0182021124419407, 0.043152685029781424, 0.01631739502045093, 0.02983357775519835, 0.05195071214984637, 0.03847577427222859, 0.03337861126055941, 0.050536553462734446, 0.009795493078854633, 0.037942889975965954, 0.03178341306920629, 0.03183728185831569, 0.0940665575035382, 0.05153972189873457, 0.09063733799848706, 0.0462488138146, 0.01826856805564603, 0.03747338509128895, 0.06271403166465461, 0.026764075373648666, 0.10328883334295824, 0.048029099925770424, 0.025298801265307702, 0.0481067879445618, 0.01795891806978034, 0.027449942281236872, 0.012622252870642114, 0.04213993546727579, 0.03293177156592719, 0.028594859068107326, 0.07485433568945155, 0.06585080045624636, 0.04026247996080201, 0.08060630672844127, 0.04772404754476156, 0.03620361123466864, 0.026081280957441777, 0.018207455905212555, 0.028507437782536726, 0.07454167629475705, 0.061668879934586585, 0.0633381333318539, 0.0774949268088676, 2.0562841231003404, 21.190250739455223, 41.302119344472885, 48.99232529103756, 34.91974242031574, 17.573992386460304, 26.475979909300804, 27.556438632309437, 18.778242766857147, 7.264328124001622, 2.3188552586361766, 0.11488879448734224, 0.17540256609208882, 0.0756048844777979, 0.4868134605931118, 0.2852609648834914, 1.3126598694361746, 3.398417942225933, 4.04004106298089, 5.631920518353581, 6.821121331304312, 5.766482697799802, 5.773994894698262, 7.287629898637533, 6.223222939297557, 3.1982123851776123, 4.7794723603874445, 5.30921570956707, 4.196601686999202, 7.437312891706824, 14.89425078034401, 18.512454628944397, 26.31077617406845, 33.822961673140526, 42.734646275639534, 47.31194145977497, 52.63747349381447, 54.10012520849705, 58.05483140051365, 58.51083733141422, 56.099479123950005, 56.62778377532959, 56.17180444300175, 54.2008426040411, 54.55197796225548, 52.605296820402145, 55.356911569833755, 54.96123120188713, 58.02364267408848, 50.59977203607559, 42.62523494660854, 56.30160167813301, 54.84324373304844, 55.69433346390724, 52.41327412426472, 52.02119216322899, 50.98512075841427, 53.53297904133797, 53.5488735884428, 57.506471425294876, 55.513862147927284, 55.70979103446007, 57.68712133169174, 56.00863739848137, 53.98828960955143, 52.60948799550533, 52.799044623970985, 54.23692166805267, 52.99614004790783, 47.75283560156822, 42.79346711933613, 33.47698263823986, 20.041880160570145, 9.102722201496363, 5.701203625649214, 3.3895382937043905, 4.514793762937188, 4.7283385042101145, 3.8792975759133697, 7.1458908542990685, 5.534929297864437, 9.150875117629766, 7.127109887078404, 5.573818311095238, 4.535357309505343, 3.310421551577747, 0.6491574039682746, 0.6509616540279239, 0.10918027619482018, 0.08123155872453935, 0.28911835164763033, 2.275184914469719, 8.683714885264635, 13.902429901063442, 22.799337096512318, 24.81070976704359, 33.02710957825184, 37.86925055086613, 23.86707030236721, 8.953135628253222, 1.5092487330548465, 0.031134798264247365, 0.1095006316609215, 0.05157527819392271, 0.014195836010912899, 0.0701741965895053, 0.011008897108695237, 0.04060184182890225, 0.06999378048931248, 0.04497073532547802, 0.02091572718200041, 0.03913093853043392, 0.05567920641624369, 0.06814158026827499, 0.11421204486396164, 0.038889306379132904, 0.06581793073564768, 0.028720220798277296, 0.09179310683975928, 0.0373276792379329, 0.018243756203446537, 0.08888201773515902, 0.02958372817374766, 0.04284711314539891, 0.02955125364678679, 0.026835696335183457, 0.08469934022286907, 0.10046945142676122, 0.05538968718610704, 0.027186244224139955, 0.02819060937326867, 0.031222887482726946, 0.04207841142488178, 0.03261379468312953, 0.05782292595540639, 0.05384331117966212, 0.1241809583734721, 0.1275917948805727, 0.3083868505200371, 0.12358686173683964, 0.22674550011288375, 0.077543218358187, 0.12800131196854636, 0.09494950543739833, 0.11449763813288882, 0.15686005091993138, 0.187855982221663, 0.24070678220596164, 0.1754574553342536, 0.09817268990445882, 0.18880463991081342, 0.27699789265170693, 0.12410171926603653, 0.2265329787041992, 0.15969260595738888, 0.09764455535332672, 0.1265036579570733, 0.0827992640552111, 0.16192745009902865, 0.21962935774354264, 0.13337676180526614, 0.12305577343795449, 0.11581405226024799, 0.14547008788213134, 0.19993076944956556, 0.08282218157546595, 0.2188953588483855, 0.17524334572954103, 0.12869942060206085, 0.10252032458083704, 0.12046270945575088, 0.12048935997881927, 0.17768705991329625, 0.22530996386194602, 0.227128240512684, 0.24814618926029652, 2.9193567484617233, 26.32533509284258, 48.03634598851204, 59.06239673495293, 43.06093096733093, 23.81808713078499, 36.59361720085144, 32.590235620737076, 23.11663907021284, 9.349450562149286, 3.9240085892379284, 0.4158642317634076, 0.5275290179997683, 0.7406369014643133, 1.7647992703132331, 2.521096793934703, 5.595606341958046, 7.035333411768079, 12.656846288591623, 12.652269434183836, 18.584040887653828, 15.562229286879301, 14.994222465902567, 9.81041332706809, 4.2494445014745, 4.787741666659713, 5.193165186792612, 5.733140911906958, 3.6014992324635386, 7.169121857732534, 14.742917250841856, 18.04139580577612, 25.426559820771217, 34.12781931459904, 43.34641344845295, 47.42525517940521, 54.25285421311855, 54.33711089193821, 59.39888767898083, 59.7755728662014, 57.11095444858074, 59.68260705471039, 58.39598089456558, 57.69915908575058, 55.558684542775154, 54.456542283296585, 59.14064973592758, 57.0764447003603, 60.53731419146061, 53.16934235394001, 47.443342208862305, 57.56724916398525, 56.505316346883774, 58.101040720939636, 54.20261710882187, 54.08877141773701, 53.895270600914955, 56.13425865769386, 55.456185042858124, 62.51511566340923, 55.844110026955605, 57.497492507100105, 59.426455199718475, 58.427298814058304, 54.71079044044018, 54.732114896178246, 53.695750907063484, 56.81763298809528, 54.86324205994606, 50.25689363479614, 44.47080351412296, 35.41473425924778, 18.27413711696863, 8.245275411754847, 5.89591515250504, 4.212899962440133, 4.022309789434075, 7.3384493216872215, 9.020160231739283, 9.630071204155684, 10.778986103832722, 17.666262835264206, 19.60101831704378, 10.869508646428585, 10.066351443529129, 9.035098180174828, 5.753992768004537, 2.881731167435646, 1.590889727231115, 0.4310475935926661, 0.8126068208366632, 3.347778534516692, 9.724308997392654, 16.859142445027828, 26.338212601840496, 29.915661737322807, 40.97679980099201, 45.147695392370224, 30.153181292116642, 10.131595842540264, 1.6991250193677843, 0.13615307689178735, 0.22736560902558267, 0.22846536798169836, 0.19369295885553584, 0.20496447512414306, 0.15691442065872252, 0.14935465209418908, 0.2589182846713811, 0.1632117514964193, 0.13185908464947715, 0.16556418151594698, 0.14399683568626642, 0.10194590227911249, 0.15464981639524922, 0.26619412237778306, 0.07851267102523707, 0.10871866033994593, 0.24446789757348597, 0.20543272577924654, 0.16757635166868567, 0.23167208419181406, 0.23213344771647826, 0.15442908683326095, 0.1159177822410129, 0.10988759488100186, 0.10950849100481719, 0.20612519409041852, 0.16593026812188327, 0.12814059824449942, 0.28689829108770937, 0.1340352842817083, 0.1449471854721196, 0.11245351852267049, 0.16869689075974748, 0.09486231050686911], [0.030677729919261765, 0.04353433818323538, 0.017404797217750456, 0.03200409068085719, 0.06559481145814061, 0.03728358082298655, 0.04724270540464204, 0.10498409159481525, 0.046446559063042514, 0.009276348719140515, 0.009174781171168434, 0.005194227578613209, 0.06712889007758349, 0.050554706394905224, 0.027545323100639507, 0.04982460377505049, 0.04096687087439932, 0.045189680022303946, 0.0742758612614125, 0.0515819649444893, 0.04650760813092347, 0.020971542253391817, 0.0710072870424483, 0.024112728679028805, 0.009801131545827957, 0.037737315069534816, 0.08895074061001651, 0.05065235076472163, 0.02319452316442039, 0.021057720441604033, 0.007576318457722664, 0.03190584888216108, 0.0972774816909805, 0.0917251780629158, 0.08150259105605073, 0.03728975549165625, 0.04296331120713148, 0.037033035478089005, 0.04099364756257273, 0.04474748617212754, 0.11927388535696082, 4.922007936984301, 26.062220111489296, 39.812530875205994, 35.69534160196781, 22.40400440990925, 19.14102829992771, 18.895420879125595, 16.68025564402342, 10.844690278172493, 4.379627890884876, 1.8802729365415871, 0.21117219905136153, 0.21917988342465833, 0.24678498652065173, 0.127107662265189, 0.5436938256025314, 1.4468120271340013, 1.9455161481164396, 4.951902832835913, 2.3503325320780277, 1.0037442832253873, 3.192547601647675, 9.855966232717037, 6.169831529259682, 1.9256135285831988, 3.071683212183416, 2.1687129652127624, 1.8056558654643595, 1.5903737861663103, 3.537538214586675, 8.56628218665719, 13.934703469276428, 20.902570076286793, 30.3703985363245, 35.18890097737312, 41.60262241959572, 49.72239151597023, 54.40296895802021, 57.01604314148426, 57.88953647017479, 56.48341812193394, 57.60778918862343, 53.86292673647404, 54.551939964294434, 53.28253448009491, 56.69105418026447, 55.403466671705246, 58.09957779943943, 48.863067626953125, 40.9875912219286, 55.911981984972954, 55.53918398916721, 54.33689050376415, 52.05874554812908, 53.16201254725456, 53.45294013619423, 51.912567391991615, 54.9378814548254, 51.1970429867506, 57.290692403912544, 49.4025094807148, 58.53609077632427, 56.286204904317856, 53.619234412908554, 51.96555554866791, 54.87467564642429, 49.66078542172909, 47.37466849386692, 36.19825981557369, 26.446242704987526, 18.303199857473373, 9.616732969880104, 2.38715089391917, 1.3947596889920533, 1.296773396898061, 4.278856823220849, 0.83719203597866, 2.423860961571336, 6.868339022621512, 1.3255218230187893, 9.194009453058243, 3.9938355423510075, 4.98015764169395, 4.368037087842822, 1.3761763111688197, 0.7145517168100923, 0.11816048572654836, 0.07562553102616221, 0.26497875165659934, 1.7140082269906998, 5.202411040663719, 9.514321815222502, 16.720922961831093, 19.893355630338192, 23.323784954845905, 27.51956731081009, 27.75155246257782, 8.467198703438044, 2.7944740746170282, 0.05496119338204153, 0.023684557709202636, 0.007070367628330132, 0.019093667433480732, 0.04458788731426466, 0.0015123076013878745, 0.005273828483041143, 0.017666591666056775, 0.022949076374061406, 0.018358304841967765, 0.030811090146016795, 0.02124936152540613, 0.04437018571479712, 0.03935847358661704, 0.024590840621385723, 0.00894488886842737, 0.05512620620720554, 0.007546295337306219, 0.03633776927017607, 0.03227609893656336, 0.02415179904346587, 0.00505795442222734, 0.03201465144229587, 0.0230205637490144, 0.04415141171193682, 0.01254088379937457, 0.04526495606114622, 0.005203314249229152, 0.04422436853928957, 0.01821485140681034, 0.0741480708529707, 0.02702296245843172, 0.09682405914645642, 0.04623063861799892, 0.06468196981586516, 0.021078181453049183, 0.05644632736220956, 0.03750671123270877, 0.023279718006961048, 0.06611782519030385, 0.04641842424462084, 0.07224393513752148, 0.03180172556312755, 0.04131414032599423, 0.020795425043615978, 0.08228429520386271, 0.02740439296758268, 0.05928772137849592, 0.017272654113185126, 0.004647658543035504, 0.028260900035093073, 0.08045952476095408, 0.09098339403863065, 0.02860632710508071, 0.03137946951028425, 0.045133091261959635, 0.06040972992195748, 0.024394145511905663, 0.15292297233827412, 0.03607316764828283, 0.05145149909367319, 0.021111053029017057, 0.03581010227208026, 0.03652685365523212, 0.0718798597517889, 0.025376207267981954, 0.03427613126405049, 0.059013345671701245, 0.029641953369718976, 0.0356220160756493, 0.025597736494091805, 0.014268777067627525, 0.04829802826861851, 0.0349971648392966, 0.041243306040996686, 0.048411921961815096, 0.18622065981617197, 6.432071607559919, 31.62660352885723, 46.14287719130516, 40.86391165852547, 23.312621153891087, 24.95968647301197, 26.162760816514492, 24.86107986420393, 13.247242458164692, 5.479503097012639, 2.0708549162372947, 0.33316472719889134, 0.046198318086680956, 0.05206108806305565, 0.2370438678190112, 0.5582928203511983, 2.0698375208303332, 2.9286296758800745, 3.5249967500567436, 4.637875333428383, 5.118077415972948, 5.891600484028459, 7.721656858921051, 10.548730809241533, 6.582696475088596, 4.679691139608622, 4.546886365860701, 2.829921660013497, 3.0156412068754435, 7.717953007668257, 11.803261991590261, 15.671045947819948, 23.931712433695793, 32.997410371899605, 39.350346475839615, 44.37474466860294, 50.59619262814522, 55.835621282458305, 58.5622713714838, 58.690943866968155, 57.297877818346024, 59.14020135998726, 56.82144418358803, 54.73121054470539, 54.15201522409916, 58.33582252264023, 57.203551679849625, 59.38032187521458, 51.200166419148445, 44.73062217235565, 56.230370700359344, 56.49966225028038, 56.6385941952467, 54.30268853902817, 54.5708629488945, 55.21993651986122, 52.85896360874176, 55.720635652542114, 54.37164343893528, 58.296509832143784, 51.780038103461266, 59.13189880549908, 57.71316893398762, 54.14243973791599, 53.7931814789772, 56.34437598288059, 52.019052878022194, 50.555071234703064, 38.198571279644966, 30.28750218451023, 21.183874681591988, 11.064451485872269, 5.027695465832949, 4.182090265676379, 3.0868382239714265, 6.535338191315532, 4.93605388328433, 4.684268943965435, 10.30004745349288, 8.342352602630854, 4.825314050540328, 5.309727257117629, 5.236231600865722, 1.6957941418513656, 1.9739282922819257, 0.7029424491338432, 0.07346050813794136, 0.12439732410712168, 0.2161039039492607, 1.5425738948397338, 6.57104630023241, 12.822334058582783, 18.16448450088501, 21.93232621997595, 25.404065027832985, 33.775635212659836, 34.352752044796944, 12.787083350121975, 4.543047621846199, 0.021258354499877896, 0.07593775997520424, 0.015111025622900343, 0.04499521506659221, 0.033003533535520546, 0.02398059114057105, 0.009254050892195664, 0.015645148378098384, 0.05732462574087549, 0.014014682401466416, 0.03905592595401686, 0.05553675116971135, 0.03284914084360935, 0.030171525831974577, 0.012039769917464582, 0.01399119064444676, 0.04463069068151526, 0.017218210159626324, 0.02812354519846849, 0.03629288046795409, 0.03556896735972259, 0.017067004991986323, 0.0321058947884012, 0.01663802508119261, 0.03888900580932386, 0.009826751411310397, 0.031526396196568385, 0.007184050273281173, 0.006522726189359673, 0.04918652004562318, 0.08266776290838607, 0.004360877837825683, 0.032419255512650125, 0.0373995859263232, 0.011173134389537154, 0.044739804943674244, 0.10447608408867382, 0.12935994687722996, 0.0747504795435816, 0.15841398941120133, 0.22562396654393524, 0.16332158935256302, 0.21266559313517064, 0.26387998717837036, 0.12671668402617797, 0.1942727097775787, 0.12850634346250445, 0.15164791810093448, 0.18533886963268742, 0.138709656894207, 0.09108522412134334, 0.2495547558646649, 0.21919193590292707, 0.1789216374163516, 0.30230275355279446, 0.12455402116756886, 0.1425522897625342, 0.08565544165321626, 0.1548715404351242, 0.11081849297625013, 0.1811557394103147, 0.09659947783802636, 0.2130642006522976, 0.12772775633493438, 0.12612308462848887, 0.14652876154286787, 0.1231777825159952, 0.17866650188807398, 0.19724990939721465, 0.2301519876345992, 0.16268028470221907, 0.10473488582647406, 0.14444323751376942, 0.20245095452992246, 0.21396288211690262, 0.22502898675156757, 0.480334481690079, 7.993282433599234, 35.820704475045204, 54.943904131650925, 50.55274955928326, 32.07187883555889, 30.366712734103203, 31.242180056869984, 25.700378827750683, 15.558635629713535, 6.118582729250193, 2.7511886972934008, 0.43814261443912983, 0.5614581098780036, 0.8385371637996286, 0.9518603829201311, 3.1122239492833614, 8.089859001338482, 7.090160194784403, 14.03706332668662, 10.32813934609294, 8.94004913046956, 10.40708675980568, 20.035764388740063, 14.309625551104546, 6.559020420536399, 7.732946528121829, 5.760197835043073, 3.4808215079829097, 3.3743077609688044, 5.342356581240892, 9.945517927408218, 17.851443998515606, 24.776893481612206, 34.047605618834496, 38.65365006029606, 44.46992576122284, 53.120879754424095, 56.22470900416374, 61.23311385512352, 61.905293986201286, 60.17227157950401, 62.41071246564388, 58.578386306762695, 56.779980808496475, 56.76356568932533, 60.727611780166626, 59.73708473145962, 59.36654381453991, 52.91337288916111, 48.3187772333622, 55.413961708545685, 58.38694877922535, 57.82835975289345, 55.30782960355282, 55.57239420711994, 58.272559717297554, 56.36581443250179, 58.50386470556259, 54.52062584459782, 60.67642852663994, 54.582589119672775, 57.30193220078945, 57.90651015937328, 56.76141880452633, 54.95636746287346, 59.48260858654976, 53.08048412203789, 51.285171657800674, 38.41028831899166, 29.782718271017075, 21.82334616780281, 14.675696957856417, 4.846078036352992, 3.929232833907008, 3.742183595895767, 9.47868162766099, 4.376375740393996, 5.839639697223902, 14.967828132212162, 10.374787542968988, 19.278240837156773, 12.768622040748596, 13.004838265478611, 8.586421106010675, 5.405963743105531, 2.476338758133352, 1.477835699915886, 0.2408598130568862, 0.49036582466214895, 2.295420253649354, 8.81547661498189, 16.46451272070408, 26.980216652154922, 28.343800082802773, 35.26054993271828, 42.83852510154247, 40.8787726610899, 14.753199499100447, 5.470500905066729, 0.23514460801379755, 0.1502466097008437, 0.12707162357401103, 0.1012898437329568, 0.12588291079737246, 0.09033740643644705, 0.1445019562379457, 0.1390843524131924, 0.24675066961208358, 0.1102851633913815, 0.1900814159307629, 0.206176788196899, 0.22124159935628995, 0.09996374457841739, 0.1340237067779526, 0.12280831913813017, 0.1595060300314799, 0.12936273735249415, 0.1208203355781734, 0.14751359150977805, 0.17797067906940356, 0.14214571157936007, 0.097711155685829, 0.10261124509270303, 0.1364507820107974, 0.10812166190589778, 0.12054865015670657, 0.09306839114287868, 0.09319479373516515, 0.12578511057654396, 0.1742365481914021, 0.1430175272980705, 0.11241074113058858, 0.17767174198525026, 0.09309511588071473, 0.18599666480440646], [0.06534356478368863, 0.03385788280866109, 0.016111788572743535, 0.07996240456122905, 0.07366079895291477, 0.033056997854146175, 0.0435075095447246, 0.01903559623315232, 0.031484668943448924, 0.02113250480761053, 0.006107390663601109, 0.026503080589463934, 0.004291625718906289, 0.06953050964511931, 0.016093327649286948, 0.04745580197777599, 0.0054554774760617875, 0.04784864671819378, 0.055332189294858836, 0.04297821353247855, 0.035204524610890076, 0.09171201978460886, 0.033294247623416595, 0.015223873815557454, 0.03335235778649803, 0.037753920623799786, 0.08802373879007064, 0.044360096217133105, 0.04454950714716688, 0.02878598064853577, 0.055954609997570515, 0.04178312941803597, 0.04331616531999316, 0.06789561768528074, 0.028406815545167774, 0.04589590404066257, 0.023002839407126885, 0.024623029421491083, 0.011879064331878908, 0.0709714784170501, 0.017207599303219467, 0.7141742901876569, 11.731639634817839, 32.612924203276634, 43.64134982228279, 35.64132370054722, 20.087369419634342, 18.828605264425278, 18.253893703222275, 18.10911577194929, 11.834457367658615, 4.768418753519654, 1.969157529529184, 0.35713191144168377, 0.10105666835443117, 0.1598040765384212, 0.276140266796574, 1.3975304528139532, 1.5612208005040884, 1.9956647884100676, 2.7343496633693576, 4.532193029299378, 4.065512046217918, 4.929490685462952, 9.771496765315533, 4.403411764651537, 4.766418635845184, 4.13367516361177, 1.3062763307243586, 1.245672907680273, 3.239915859885514, 3.5478095384314656, 5.126605108380318, 7.958096796646714, 16.801748424768448, 25.839519761502743, 30.3007672727108, 39.58295479416847, 46.92079044878483, 54.973189160227776, 56.12311005592346, 56.92065306007862, 58.66895064711571, 57.49009810388088, 54.452168717980385, 56.970897763967514, 55.84828980267048, 56.22187815606594, 56.178739070892334, 47.59664498269558, 42.9688923060894, 54.35555510222912, 52.91984774172306, 56.945036351680756, 55.51795832812786, 53.8325359672308, 52.93442375957966, 53.992872163653374, 57.18119367957115, 54.926941841840744, 49.168335646390915, 60.5614010989666, 50.101470574736595, 54.99642111361027, 55.40506258606911, 53.21348838508129, 48.487062603235245, 45.474489256739616, 33.86186018586159, 25.23503489792347, 18.036940544843674, 6.962945396080613, 2.584935505874455, 1.191953408997506, 2.179241725243628, 3.219414772465825, 5.2712619211524725, 7.46474789455533, 3.110115062445402, 8.688174895942211, 6.67646499350667, 2.996837440878153, 3.1216464936733246, 2.720006383024156, 1.635759500786662, 1.5605542925186455, 0.3515016823075712, 0.3616860561305657, 0.23264888412086293, 1.037542400881648, 5.899551082402468, 8.036700803786516, 15.130624696612358, 18.57083849608898, 24.694177620112896, 30.699434280395508, 29.841605611145496, 16.737081594765186, 5.823833020403981, 0.7137413509190083, 0.06009827651723754, 0.05012827576138079, 0.06688228924758732, 0.0352916082192678, 0.05257524055195972, 0.04929222784994636, 0.0300389281619573, 0.03554772709321696, 0.038255501131061465, 0.04141970712225884, 0.016973685487755574, 0.017031860588758718, 0.011883678635058459, 0.04134077600610908, 0.04427454143296927, 0.023914137382234912, 0.049887333807419054, 0.036563563990057446, 0.05224502565397415, 0.039880882468423806, 0.035249072025180794, 0.016226613661274314, 0.044766511127818376, 0.05518905498320237, 0.03550648223608732, 0.051076658855890855, 0.04643323380150832, 0.03789363363466691, 0.0390363072801847, 0.04487442311074119, 0.029756568801531103, 0.018131406177417375, 0.01629043836146593, 0.048069999684230424, 0.026203757588518783, 0.01927526911458699, 0.03568043794075493, 0.04733322515676264, 0.06365928289596923, 0.10283258321578614, 0.04025541100418195, 0.038837931206217036, 0.03456052225374151, 0.028002114995615557, 0.022232395494938828, 0.06661137565970421, 0.09047064420883544, 0.11039635195629671, 0.014798140800849069, 0.054411247110692784, 0.019135962429572828, 0.03240349600673653, 0.02039196202531457, 0.032447980338474736, 0.06323530134977773, 0.020379577435960528, 0.058842484722845256, 0.07086300611263141, 0.0196759435129934, 0.014696402558911359, 0.01545126229757443, 0.02674583338375669, 0.035103996997349896, 0.0558714412181871, 0.04001413508376572, 0.035495743359206244, 0.09047626968822442, 0.019679837932926603, 0.023669772272114642, 0.0385503341385629, 0.03842549747787416, 0.018287682069058064, 0.04638011829229072, 0.033469045665697195, 0.05758220664574765, 0.017647370041231625, 0.05318300383805763, 1.045479343738407, 15.377471800893545, 36.97835795581341, 49.489262625575066, 38.8047831505537, 23.43486439436674, 22.49033957719803, 22.961698584258556, 21.75300244241953, 14.165160153061152, 5.506795607507229, 2.0330647565424442, 0.34586513007525355, 0.10341025612433441, 0.24487536633387208, 0.2865049825049937, 1.1187031958252192, 1.209657252766192, 2.2221561474725604, 3.6450845561921597, 4.297302458435297, 3.8378911977633834, 9.529925677925348, 10.590629260987043, 11.186849568039179, 6.873182812705636, 3.092892011627555, 4.813699973747134, 3.611225998029113, 4.089417513459921, 6.8059696443378925, 8.801105786114931, 11.000744104385376, 21.271150298416615, 29.52631752938032, 33.42045307159424, 42.45891787111759, 49.48911063373089, 56.10622376203537, 58.71785022318363, 57.75938965380192, 60.00862576067448, 59.642986580729485, 57.90811747312546, 58.51994164288044, 57.671234384179115, 56.55728615820408, 56.74683518707752, 51.236397475004196, 46.65183328092098, 53.745247051119804, 55.30830077826977, 57.76056759059429, 58.27544376254082, 56.17821089923382, 54.72740314900875, 54.999916926026344, 58.57346177101135, 54.59491565823555, 52.55942568182945, 58.49023103713989, 51.52789883315563, 54.18028190732002, 55.512612015008926, 55.70692598819733, 50.313047021627426, 46.290864050388336, 38.986629992723465, 28.543844148516655, 21.580867879092693, 12.31498148292303, 5.888961050659418, 3.174432311207056, 3.9035336254164577, 3.168865372426808, 8.443814758211374, 5.638679405674338, 6.4263529144227505, 9.44321433082223, 6.843452258035541, 5.880394885316491, 3.3350919652730227, 5.136922504752874, 1.4172845240682364, 0.8102318295277655, 0.43222342268563807, 0.13738409208599478, 0.5578304326627403, 1.3343400810845196, 6.241590678691864, 14.021562058478594, 19.623488411307335, 19.997359849512577, 24.57402426749468, 35.119315311312675, 36.87642462551594, 21.775542832911015, 7.3056822549551725, 1.2159607582725585, 0.05594677662884351, 0.07276291158632375, 0.015943590078677516, 0.016983971654553898, 0.03958801615226548, 0.05798236896225717, 0.012584382002387429, 0.04317093073041178, 0.051332889051991515, 0.05961128663329873, 0.03895267836924177, 0.018282461060152855, 0.04161861754255369, 0.008690799768373836, 0.019762568845180795, 0.03296336108178366, 0.049080474564107135, 0.021348319496610202, 0.03179228173394222, 0.047486975890933536, 0.06790859042666852, 0.03736685721378308, 0.0799270486459136, 0.02662446626345627, 0.03141609449812677, 0.039332765591097996, 0.04765102763485629, 0.0438688798021758, 0.03269079250458162, 0.057774411761783995, 0.057126765459543094, 0.013390378499025246, 0.026199499516224023, 0.044343308836687356, 0.03477939644653816, 0.0518156561156502, 0.17049299203790724, 0.13012962823268026, 0.11664287536405027, 0.2844379231100902, 0.14060174755286425, 0.07720529625657946, 0.2365916920825839, 0.12623313028598204, 0.16848894098075107, 0.10980379898683168, 0.18762115185381845, 0.20681755850091577, 0.11756578052882105, 0.1291636933456175, 0.15759090310893953, 0.1758807318401523, 0.18203914747573435, 0.1684664687491022, 0.1941201984300278, 0.12156375232734717, 0.1861581116099842, 0.25560174544807523, 0.08726427680812776, 0.1397950924001634, 0.21163748111575842, 0.14035720989340916, 0.16620680718915537, 0.2370185308973305, 0.09451848090975545, 0.13573984906543046, 0.3206321981269866, 0.16866622521774843, 0.12019869041978382, 0.13131105311913416, 0.24816738499794155, 0.13235574471764266, 0.25609088013879955, 0.18107346491888165, 0.16013022075640038, 0.1544397886027582, 0.1594583544647321, 1.510825885925442, 19.560626484453678, 42.95494705438614, 57.562655210494995, 47.420566231012344, 30.470654256641865, 30.590243339538574, 28.544866293668747, 25.96784647554159, 18.146346174180508, 6.765740253031254, 3.159208665601909, 0.5551509233191609, 0.49504708440508693, 0.9375717840157449, 1.547972692642361, 5.142303491011262, 5.661298641934991, 7.83694694750011, 9.970062710344791, 10.449398439377546, 13.332968708127737, 13.948063552379608, 20.580324567854404, 12.118767611682415, 12.118492126464844, 11.202838160097599, 5.0093980226665735, 3.7559274584054947, 6.429882925003767, 6.777454074472189, 6.976187210530043, 10.34331003203988, 19.101445823907852, 28.9872632548213, 33.65419752895832, 41.24524399638176, 50.353366658091545, 58.503644317388535, 57.45414823293686, 60.361357033252716, 62.09775745868683, 62.86148227751255, 59.921226650476456, 61.11686289310455, 59.486841559410095, 58.97821605205536, 58.04549150168896, 52.967219799757004, 50.61696231365204, 54.0789907425642, 54.93399806320667, 61.12244099378586, 60.892234146595, 58.5367177426815, 57.34504088759422, 57.5326482206583, 58.801719322800636, 57.63085015118122, 52.24919132888317, 59.450078532099724, 53.889369517564774, 55.610437765717506, 55.59381365776062, 57.46955640614033, 50.87935343384743, 46.89607657492161, 37.23411463201046, 29.310964085161686, 20.34632932394743, 9.192787818610668, 4.977713422849774, 4.864372629672289, 4.178319443017244, 6.960818935185671, 11.204162389039993, 14.871854782104492, 11.030452810227871, 17.98131722956896, 11.683152336627245, 12.673485595732927, 9.357390236109495, 8.276916313916445, 5.54704399779439, 4.6343296486884356, 1.6929477383382618, 0.7155536161735654, 0.7162526005413383, 1.8114878400228918, 8.674485180526972, 14.163490142673254, 24.527117684483528, 28.558370769023895, 35.93176111578941, 43.05465750396252, 44.19214926660061, 26.457157619297504, 8.282312024384737, 1.402569457422942, 0.1551962152007036, 0.2392002075794153, 0.20786964189028367, 0.12692573218373582, 0.15368806722108275, 0.21738964511314407, 0.12231107277330011, 0.1373853685799986, 0.1449894136749208, 0.2279522767639719, 0.2044759935233742, 0.12775821407558396, 0.09332258414360695, 0.19636617478681728, 0.19212033308576792, 0.1538588057155721, 0.12625787348952144, 0.15014221920864657, 0.13184596347855404, 0.2054179718834348, 0.14186716871336102, 0.10449130553752184, 0.1630661272793077, 0.13088798441458493, 0.1264686879585497, 0.15076844341820106, 0.21171956264879555, 0.17475933185778558, 0.11370371823431924, 0.1426363454083912, 0.10752848553238437, 0.12484192993724719, 0.1479222922353074, 0.16495226591359824, 0.07973996063810773, 0.11029599874746054], [0.07653089181985706, 0.0556551459885668, 0.01511045509687392, 0.04641060942958575, 0.08973227406386286, 0.021018123152316548, 0.06087038840632886, 0.023580356464663055, 0.007082705369612086, 0.00263620409896248, 0.0675291896914132, 0.03811379545368254, 0.09325983555754647, 0.009708362158562522, 0.007875564460846363, 0.03780423452553805, 0.03429284071899019, 0.030307914021250326, 0.029556207482528407, 0.042605395647115074, 0.03928194331820123, 0.03781432031246368, 0.08876627980498597, 0.0009341814609342691, 0.012305593299970496, 0.0780652895628009, 0.019687977437570225, 0.02571783454186516, 0.06614097277633846, 0.04419313896505628, 0.027748037027777173, 0.0205978931626305, 0.06486153244622983, 0.07730709665338509, 0.05508142872713506, 0.009671688931121025, 0.021222777795628645, 0.0331911781540839, 0.05947265715803951, 0.0577160047396319, 0.043664310505846515, 0.12542586657218635, 3.479825248941779, 15.816792827099562, 36.82028643786907, 35.237086191773415, 23.94578117877245, 16.661551147699356, 14.91755872964859, 15.018740650266409, 17.157789319753647, 15.161199755966663, 6.995032774284482, 2.8230490162968636, 0.6535110797267407, 0.02870940399589017, 0.3843958047218621, 0.19348208501469344, 0.5737870826851577, 1.2669624527916312, 2.190011772327125, 1.436735442839563, 2.358428710140288, 5.248414222151041, 9.068462289869785, 12.773220743983984, 4.096479909494519, 1.885074928868562, 3.3021004730835557, 2.8555263485759497, 2.3681331519037485, 2.136136363260448, 3.1943783909082413, 5.309275081381202, 8.663732707500458, 14.901266153901815, 21.57739106565714, 27.409629710018635, 38.22757892310619, 46.07984237372875, 54.11235295236111, 55.24965472519398, 57.53825291991234, 57.72890008985996, 59.08933728933334, 57.05149903893471, 61.54856152832508, 53.08849789202213, 54.284840896725655, 48.00907105207443, 46.477038860321045, 51.18985377252102, 53.30600582063198, 52.65194311738014, 57.67433501780033, 55.819817930459976, 57.7995041012764, 54.68434005975723, 58.757634088397026, 56.84110812842846, 57.6349463313818, 58.944948837161064, 48.0719842761755, 56.79941676557064, 52.66917519271374, 47.86481559276581, 41.4020349830389, 32.98161081969738, 27.750792503356934, 15.594862885773182, 9.519056361168623, 4.350877208635211, 1.0771586000919342, 1.3692457205615938, 5.399461816996336, 1.7377273854799569, 7.015005452558398, 4.648988787084818, 4.573563309386373, 6.696276180446148, 7.035114923492074, 3.0700523871928453, 2.1196222119033337, 3.992739776149392, 0.6198214937467128, 0.17645399639150128, 0.1491095800884068, 0.4636958276387304, 0.45964963850565255, 5.657659387215972, 11.56900741159916, 12.087424043565989, 18.32380425184965, 19.61123786866665, 25.69125361740589, 25.21638549864292, 23.277609832584858, 9.749898724257946, 0.9723353467416018, 0.11309110501315445, 0.09219060113537125, 0.02556847732194001, 0.015275284240487963, 0.06181234079122078, 0.07503487053327262, 0.008343380031874403, 0.061799520190106705, 0.025440208228246775, 0.046154156589182094, 0.048943166111712344, 0.03187485308444593, 0.03684497896756511, 0.012174086587037891, 0.08902025758288801, 0.01658762583247153, 0.024799803431960754, 0.02450068266625749, 0.060239633385208435, 0.02924287644418655, 0.01098259910577326, 0.04905216905171983, 0.039254120201803744, 0.020366721582831815, 0.03917493304470554, 0.08224993376643397, 0.0448795550619252, 0.01347266412267345, 0.07238745165523142, 0.06324926856905222, 0.042496444657444954, 0.05581277815508656, 0.026001490805356298, 0.002203467993240338, 0.046878886059857905, 0.058329794264864177, 0.04114119765290525, 0.040681348109501414, 0.011860537542816019, 0.01571254280861467, 0.035811979905702174, 0.04193361470242962, 0.08941655702074058, 0.04057891317643225, 0.07026905048405752, 0.02566957082308363, 0.04090578469913453, 0.03651069710031152, 0.05186691625567619, 0.0753966897900682, 0.06412935181288049, 0.01714809946861351, 0.06229699662071653, 0.04754147921630647, 0.02927877412730595, 0.11177345892065205, 0.03378066605364438, 0.02748885308392346, 0.027150413334311452, 0.02305645029991865, 0.053070227077114396, 0.028323253427515738, 0.07204610825283453, 0.048201144600170664, 0.009228714898199541, 0.02231901526101865, 0.02379145851591602, 0.05295608105370775, 0.10038855733000673, 0.006499818409793079, 0.07303130187210627, 0.04628497496014461, 0.03632332336565014, 0.05456039652926847, 0.03148769690596964, 0.013681073105544783, 0.050382216431898996, 0.044573051782208495, 0.10438005017931573, 4.362460412085056, 19.539237432181835, 43.59875410795212, 40.15857830643654, 27.308007963001728, 19.578766711056232, 18.819554150104523, 23.11305396258831, 20.583704486489296, 14.885476101189852, 6.711112009361386, 2.620749771595001, 0.3479887411231175, 0.0334631789883133, 0.22776247991714627, 0.21748336352175102, 0.19131767068756744, 2.499026390723884, 2.207547356374562, 5.522599434480071, 5.905614607036114, 5.725343255326152, 10.469707399606705, 11.514608580619097, 7.7835289388895035, 6.156423948705196, 5.376749960705638, 4.620102737098932, 5.380687024444342, 3.4616790851578116, 5.731974374502897, 7.016228036954999, 14.052936024963856, 19.869709499180317, 24.796160347759724, 30.373263582587242, 39.56191532313824, 47.355103343725204, 55.09837344288826, 56.02297402918339, 59.42562684416771, 60.879212245345116, 59.97036561369896, 59.22728508710861, 60.84684558212757, 54.82381537556648, 55.98919004201889, 53.11541184782982, 50.511776357889175, 50.595702454447746, 54.58057142794132, 56.49443373084068, 59.840173199772835, 57.06166349351406, 57.59141966700554, 54.87294293940067, 58.64665724337101, 57.932914942502975, 54.62962679564953, 62.06227496266365, 50.10412663221359, 56.46663822233677, 50.99975757300854, 50.36097764968872, 43.44664067029953, 35.65271928906441, 29.74097941070795, 20.3836053237319, 10.66362239420414, 6.8023123405873775, 4.157418664544821, 2.3127404367551208, 8.66745175793767, 6.930622905492783, 6.789829535409808, 7.316020550206304, 6.43441560678184, 8.16560983657837, 5.255876071751118, 4.843317484483123, 3.8777940440922976, 3.2562680449336767, 0.5379759042989463, 0.17437804606743157, 0.07743954032775946, 0.25312677200417966, 1.0095339850522578, 4.315538154914975, 13.947489783167839, 15.314364787191153, 18.093992583453655, 21.70317381620407, 28.679152987897396, 34.332164749503136, 27.478531412780285, 12.694312278181314, 2.3585628904402256, 0.25263259070925415, 0.018499190446163993, 0.07103721785824746, 0.010864772029890446, 0.06447681793360971, 0.03898616778315045, 0.034371534347883426, 0.01052913388775778, 0.018257617666677106, 0.039128289063228294, 0.03664990916149691, 0.035320622482686304, 0.06976364049478434, 0.031058049062266946, 0.03533467875968199, 0.006350083158395137, 0.03028307248314377, 0.020776416786247864, 0.025860174755507614, 0.03060606999497395, 0.028457721309678163, 0.09140883019426838, 0.042863303096964955, 0.03507961744617205, 0.03759692670428194, 0.021908509261265863, 0.038852881771163084, 0.02214951986388769, 0.04251044156262651, 0.017630742222536355, 0.05314985952281859, 0.0372129246534314, 0.047812233242439106, 0.02662554608832579, 0.05316800132277422, 0.03462448796199169, 0.025745681778062135, 0.1739417077624239, 0.15077338612172753, 0.12145758810220286, 0.13455811247695237, 0.1865618844749406, 0.11161390459164977, 0.09663249598816037, 0.22254853625781834, 0.08546401950297877, 0.15707675804151222, 0.1540320081403479, 0.22368939535226673, 0.16336194734321907, 0.16664980998029932, 0.16109477524878457, 0.1559457546682097, 0.15442087867995724, 0.09152211161563173, 0.2627827663673088, 0.2519673592178151, 0.13695879693841562, 0.1443330879556015, 0.13448594603687525, 0.26477000035811216, 0.16547092323889956, 0.2035639830864966, 0.12521986122010276, 0.11182519403519109, 0.2147433691425249, 0.20227608969435096, 0.13980056945001706, 0.16321898001478985, 0.1734114284045063, 0.18508946348447353, 0.1863822402083315, 0.12751064845360816, 0.15792271733516827, 0.11134992266306654, 0.17523573129437864, 0.1422552377334796, 0.1450105055118911, 0.22370996768586338, 5.47048713080585, 25.14035727828741, 49.683052226901054, 48.60386833548546, 33.958242014050484, 25.00157542526722, 23.637669011950493, 24.586345106363297, 25.513341464102268, 19.785036742687225, 8.657074514776468, 3.627453977242112, 1.080767575185746, 0.3016439639031887, 0.9395878133364022, 1.5387781360186636, 4.0302432887256145, 5.925848046317697, 8.312879484146833, 10.523138232529163, 8.076952993869781, 14.983542189002037, 14.970309399068356, 21.809862591326237, 10.976879484951496, 8.7168500572443, 11.054431423544884, 8.103229533880949, 8.303676377981901, 6.118526682257652, 6.338955229148269, 7.2938454151153564, 13.353111427277327, 18.213102892041206, 24.122863076627254, 29.996960274875164, 40.359773710370064, 48.29353138804436, 55.25809787213802, 55.05497217178345, 60.07006846368313, 61.267342418432236, 61.86893753707409, 60.991701409220695, 63.63735884428024, 55.75988754630089, 56.068814769387245, 54.88799013197422, 54.95088815689087, 53.62678460776806, 53.93598921597004, 56.27669781446457, 60.47005780041218, 59.20932725071907, 59.69038903713226, 57.25339740514755, 59.10348393023014, 57.61046044528484, 55.87364584207535, 59.1037081182003, 51.980473548173904, 55.24733304977417, 53.2146131247282, 50.452495738863945, 44.74893718957901, 35.94703629612923, 29.328802227973938, 18.107685148715973, 11.791441775858402, 6.217283383011818, 3.0533121479675174, 4.823527196422219, 12.672511897981167, 8.699618931859732, 13.487896844744682, 10.757265519350767, 12.549214214086533, 13.193258754909039, 16.38741295784712, 11.572781559079885, 8.065258171409369, 12.289153318852186, 3.203371320851147, 1.7187933577224612, 0.42353869182989, 0.7443921093363315, 1.0033740405924618, 7.463825019076467, 15.869026724249125, 17.919481247663498, 28.579311445355415, 29.43820595741272, 40.62262460589409, 41.81125022470951, 32.61331558227539, 13.008986692875624, 2.2723030066117644, 0.35395056183915585, 0.18778907018713653, 0.15574852150166407, 0.13313673640368506, 0.21554754552198574, 0.11705550205078907, 0.07521496008848771, 0.11492369769257493, 0.08796349124168046, 0.19161162053933367, 0.1121679697826039, 0.14746888453373685, 0.12613248021807522, 0.06549928963067941, 0.24617002811282873, 0.1150365783541929, 0.12591761362273246, 0.1906208979198709, 0.11156537555507384, 0.106492083723424, 0.12777452648151666, 0.15873232623562217, 0.1002360979327932, 0.1412504439940676, 0.13691343687241897, 0.12253492677700706, 0.17696793365757912, 0.13395876885624602, 0.18413648649584502, 0.10542075644480065, 0.199354091018904, 0.12639897060580552, 0.12730927410302684, 0.15133859094930813, 0.1220833818661049, 0.21950734866550192, 0.20909834158373997], [0.023345433328358922, 0.01151571068476187, 0.05367514051613398, 0.005366930445234175, 0.07060716554406099, 0.07418785738991573, 0.049692738975863904, 0.13557521102484316, 0.029477792159013916, 0.006638435361310258, 0.03109516572294524, 0.03838632321276236, 0.02639803886268055, 0.039149113727035, 0.04270570803782903, 0.03636222303612158, 0.03361760507686995, 0.049669546860968694, 0.017805794450396206, 0.06947242174646817, 0.017255992897844408, 0.029115854158590082, 0.021476239780895412, 0.02469440547429258, 0.045673185522900894, 0.16173193871509284, 0.023401227990689222, 0.03163921006489545, 0.04238838795572519, 0.05490586627274752, 0.043797978723887354, 0.0528834990109317, 0.04786649536981713, 0.038436280883615837, 0.0438805426529143, 0.051421735261101276, 0.029021059635851998, 0.043052172259194776, 0.058464241737965494, 0.010542788477323484, 0.040657669887878, 0.032065058112493716, 0.32830656913574785, 6.202522125095129, 20.85759188979864, 36.78432896733284, 35.47806926071644, 25.786816589534283, 18.848331905901432, 22.018308006227016, 22.7775851637125, 16.620940826833248, 12.695100735872984, 7.786108525469899, 3.2881103362888098, 1.1108171939849854, 0.12072286932379939, 0.17534507933305576, 0.17432415130315349, 1.2330242176540196, 1.6693267808295786, 4.108119634911418, 2.3607256868854165, 5.140152331441641, 9.215879179537296, 11.292315758764744, 5.695286868140101, 3.6896689888089895, 5.830256100744009, 5.061901230365038, 4.024492772296071, 2.5060370145365596, 3.4692242927849293, 2.1594861103221774, 6.181356310844421, 7.346317274495959, 12.919602189213037, 18.19265428930521, 26.984291933476925, 34.808036014437675, 47.0302701741457, 52.27813437581062, 57.8069669008255, 56.467861756682396, 57.44037017226219, 58.48671242594719, 57.98693664371967, 51.39517195522785, 52.5424025952816, 52.11371719837189, 39.81077536940575, 54.187676310539246, 60.23733168840408, 52.54846706986427, 56.524809300899506, 54.65898022055626, 57.050647884607315, 57.46813528239727, 55.75318090617657, 58.57022814452648, 60.449337512254715, 45.14919251203537, 51.70894391834736, 52.531455382704735, 42.93989226222038, 38.80756080150604, 28.20927780121565, 21.762311942875385, 17.490828149020672, 10.008889976888895, 3.3684890856966376, 3.5877546574920416, 4.3819923140108585, 2.1827643737196922, 5.670168790966272, 2.6868636114522815, 6.899912478402257, 3.951643081381917, 4.728473871946335, 7.406787229701877, 3.404790675267577, 3.657651669345796, 2.175976987928152, 1.2150058220140636, 0.4177958343643695, 0.18575965252239257, 0.1479125107289292, 0.615114199463278, 5.136842234060168, 14.577253740280867, 11.34626716375351, 19.777380153536797, 20.410756766796112, 25.09339939802885, 27.78826229274273, 21.231396831572056, 11.991650182753801, 2.9181840363889933, 0.3768950962694362, 0.02646145352628082, 0.0916212922311388, 0.0002963545261991385, 0.05700825931853615, 0.0632066024991218, 0.0631061231251806, 0.018079706314892974, 0.026715613130363636, 0.03488979833491612, 0.033426253430661745, 0.05937894246017095, 0.052937601576559246, 0.02980116260005161, 0.028491969569586217, 0.06838764675194398, 0.0497938157786848, 0.02517913922929438, 0.07474292448023334, 0.007828511370462365, 0.02278124895383371, 0.009199114338116487, 0.06972924937144853, 0.10855038577574305, 0.023678600118728355, 0.0363118015229702, 0.06702177590341307, 0.04270217912562657, 0.052705698981299065, 0.017538192696520127, 0.056189002498285845, 0.02663693063368555, 0.008842149654810783, 0.02876287016988499, 0.0497102017106954, 0.039200036189868115, 0.03942439485399518, 0.03556597279384732, 0.014195884250511881, 0.013960638279968407, 0.06825259813922457, 0.010128148715011775, 0.028618186624953523, 0.004116501595490263, 0.024983507246361114, 0.04391575756017119, 0.011464316958154086, 0.049289871531073004, 0.013710867551708361, 0.10053396632429212, 0.040270127792609856, 0.0763708476733882, 0.013929405922681326, 0.023539983631053474, 0.03534358082106337, 0.06522253534058109, 0.04816266424313653, 0.029712965770158917, 0.030002852363395505, 0.00963353233601083, 0.08203741235774942, 0.024133078368322458, 0.01651478774874704, 0.08118539713905193, 0.07308104060939513, 0.055090601672418416, 0.03005329614097718, 0.03416983345232438, 0.0329456237523118, 0.048270116094499826, 0.05783048472949304, 0.0708521633350756, 0.10266291341395117, 0.04646323141059838, 0.04169862477283459, 0.028225317764736246, 0.06766889899154194, 0.05998901753628161, 0.03426240524277091, 0.04439771939360071, 0.6852028041612357, 7.77750008739531, 25.71725942194462, 43.290062472224236, 37.516568675637245, 25.660156086087227, 17.83971592783928, 19.730608463287354, 28.91277775168419, 24.92642305791378, 14.431699700653553, 9.240940734744072, 2.8205212019383907, 0.4596505587687716, 0.17283292429056019, 0.07192626624600962, 0.21975635405397043, 0.754235303029418, 0.5817658232990652, 3.8148729829117656, 3.3094331296160817, 5.235300650820136, 10.219453778117895, 9.048977885395288, 6.378211872652173, 4.832463841885328, 8.423497248440981, 5.618019914254546, 4.056851835921407, 3.4262870717793703, 5.070369550958276, 4.144132677465677, 7.367319697514176, 9.571145866066217, 17.924306988716125, 22.138185873627663, 29.24020618200302, 36.57805323600769, 49.17727656662464, 53.03792640566826, 57.455611154437065, 58.60914185643196, 60.42298212647438, 59.64700676500797, 61.063844338059425, 53.99642497301102, 55.71466617286205, 56.03562355041504, 44.21103045344353, 52.58934147655964, 54.9800705909729, 55.55934950709343, 58.052623718976974, 57.23898857831955, 56.845675483345985, 59.26496006548405, 58.4295254945755, 55.31541779637337, 62.2122947126627, 50.280562564730644, 51.58871077001095, 52.71780878305435, 44.83535975217819, 41.666941568255424, 31.128011383116245, 24.907973147928715, 18.90424020588398, 12.616843935102224, 4.439538801088929, 4.123400039970875, 3.3216793974861503, 1.9940451253205538, 9.439420234411955, 6.851866906508803, 7.399242734536529, 6.2133311200886965, 6.021315548568964, 5.257916562259197, 3.3714743005111814, 3.047633352689445, 1.7272109747864306, 1.140005209017545, 0.45135711785405874, 0.04153430214500986, 0.06869152653962374, 1.0709313279949129, 4.2672631703317165, 16.259570717811584, 18.747217431664467, 19.261274747550488, 19.894900247454643, 27.239968813955784, 35.23457832634449, 26.07561819255352, 16.513712480664253, 4.104070952162147, 0.6862546945922077, 0.06256907538045198, 0.06580602668691427, 0.03184551598678809, 0.04878040941548534, 0.034259095264133066, 0.02886324935388984, 0.025311451172456145, 0.031742888095322996, 0.03904207747837063, 0.04187622071185615, 0.07644564131624065, 0.02448807172186207, 0.055629983471590094, 0.03966271331591997, 0.013197601001593284, 0.05760388849012088, 0.013803178662783466, 0.04166457132669166, 0.01403367952661938, 0.04995680254069157, 0.06538785615703091, 0.013429110258584842, 0.032612347495160066, 0.006178733783599455, 0.029289234698808286, 0.01932933271746151, 0.058264288600184955, 0.03154373276629485, 0.038751289175706916, 0.06499241761048324, 0.010019956571341027, 0.017580274325155187, 0.03153451900288928, 0.03523795465298463, 0.02559253032814013, 0.013336204501683824, 0.043225615881965496, 0.13994675769936293, 0.07439928042003885, 0.12081523702363484, 0.13258748775115237, 0.13787615083856508, 0.12102413675165735, 0.1273362140636891, 0.22800994163844734, 0.09426300399354659, 0.11519477455294691, 0.1268792588962242, 0.24003237776923925, 0.12420846978784539, 0.17202433955390006, 0.12267390877241269, 0.07460939727025107, 0.15393082372611389, 0.14806153398239985, 0.08444913997664116, 0.1948634147993289, 0.08610306802438572, 0.08537174828234129, 0.2397105676936917, 0.1585439988411963, 0.14061512105399743, 0.30634454917162657, 0.22507369372760877, 0.1554913228028454, 0.167514753411524, 0.12324770024861209, 0.1183338365808595, 0.0918427639408037, 0.12665155314607546, 0.13189139775931835, 0.22122962109278888, 0.15248986979713663, 0.11272701478446834, 0.15713752509327605, 0.15217061270959675, 0.202393957588356, 0.10368616436608136, 0.08173504655133002, 0.9347259742207825, 9.956258051097393, 31.127051934599876, 51.156312972307205, 48.20933170616627, 34.965818747878075, 29.339207969605923, 30.51292508840561, 35.64633183181286, 24.431245028972626, 16.792936697602272, 10.267816632986069, 3.9810829516500235, 1.9992973934859037, 0.3448375820880756, 1.2739476654678583, 0.43783304980024695, 4.709599334746599, 5.035108868032694, 9.654890522360802, 10.414857342839241, 13.59550992026925, 23.600584901869297, 20.09836982935667, 15.938231460750103, 8.050528261810541, 13.763839937746525, 11.66243014857173, 9.612434450536966, 7.13957654312253, 7.543955119326711, 4.2181911785155535, 8.850622829049826, 11.393396984785795, 15.330779906362295, 22.215654216706753, 28.98728035390377, 37.49330632388592, 49.512775763869286, 55.79484187066555, 59.65863034129143, 61.09655678272247, 61.37874484062195, 61.78929381072521, 59.364765509963036, 55.64561627805233, 58.215707167983055, 60.149890780448914, 48.884274289011955, 56.27691440284252, 54.8806831240654, 55.15362247824669, 59.87689822912216, 58.970521464943886, 59.260491505265236, 59.04308997094631, 59.20470669865608, 57.56707817316055, 61.806043311953545, 52.9610413312912, 52.6563660800457, 51.336229518055916, 44.52220715582371, 40.24407371878624, 30.90229969471693, 24.525871351361275, 19.691679552197456, 11.496533900499344, 6.670610457658768, 6.977497665211558, 12.388090509921312, 5.564314546063542, 14.081506691873074, 11.580037269741297, 14.881502464413643, 10.482431016862392, 12.637761812657118, 16.653919257223606, 13.799016550183296, 9.272798225283623, 6.29687343724072, 5.5502761993557215, 1.717391589190811, 0.2514090563636273, 0.45977182569913566, 0.9920974925626069, 6.889225076884031, 18.53507101535797, 19.682801328599453, 28.573626950383186, 29.211240336298943, 37.49647535383701, 43.30222561955452, 31.98331318795681, 16.867843978106976, 4.228098196908832, 0.8401188882999122, 0.09705128250061534, 0.19314624834805727, 0.12314613733906299, 0.10039076150860637, 0.28999007830861956, 0.10176214651437476, 0.10850372695131227, 0.19787243771133944, 0.15633367525879294, 0.16157000209204853, 0.25960667117033154, 0.11037370903068222, 0.09643802361097187, 0.17099489166866988, 0.1944964227732271, 0.10651616641553119, 0.09427427721675485, 0.18163276225095615, 0.10796502421726473, 0.11946737809921615, 0.07187413779320195, 0.09134635620284826, 0.20052966778166592, 0.11424841752159409, 0.11499121086671948, 0.14934251055819914, 0.15795645536854863, 0.229329168505501, 0.0666029225976672, 0.12134363132645376, 0.15184230142040178, 0.11141759168822318, 0.09423823110410012, 0.1369138079462573, 0.2540149446576834, 0.14151291194139048, 0.09959840012015775], [0.06592220990569331, 0.060818066995125264, 0.0031837799042477855, 0.032353386195609346, 0.09798250714084134, 0.06322054003248923, 0.04978835357178468, 0.05482441556523554, 0.023534257961728144, 0.03539432887919247, 0.0342527795874048, 0.07930903258966282, 0.03217935256543569, 0.11048799235140905, 0.021153644884179812, 0.0435935133282328, 0.07748611009446904, 0.07964366697706282, 0.03592893866880331, 0.039017768431222066, 0.06681801925878972, 0.045287072061910294, 0.04666509557864629, 0.0649023060395848, 0.03663981595309451, 0.02649989677593112, 0.08215242298319936, 0.009086659483727999, 0.011049950862798141, 0.05192673335841391, 0.08909889555070549, 0.024883623445930425, 0.012698725622612983, 0.05764342269685585, 0.07777322476613335, 0.09406974873854779, 0.05733193960622884, 0.06904271824168973, 0.005626852826026152, 0.09688143458333798, 0.008802917873254046, 0.05044561068643816, 0.0186045809823554, 1.225997325964272, 9.811234083026648, 24.14678279310465, 39.85025145113468, 36.788698732852936, 29.58361655473709, 23.353662751615047, 14.412614274770021, 18.736104927957058, 20.378764383494854, 13.594277836382389, 8.437489047646523, 3.4536536782979965, 0.7846499991137534, 0.19935766817070544, 0.21991113637341186, 1.1409362778067589, 0.17829321644967422, 2.6101438282057643, 3.364811595529318, 3.29324908554554, 9.116261824965477, 6.151336496695876, 5.807104418054223, 4.356127576902509, 5.411298181861639, 4.161025146022439, 3.7126940907910466, 2.8899722127243876, 3.968605608679354, 2.425529547035694, 1.6850046208128333, 3.4590303897857666, 7.20055234618485, 11.44518630579114, 16.062494292855263, 24.893592819571495, 35.68547733128071, 44.65175740420818, 49.80737775564194, 50.678769797086716, 55.57686276733875, 55.55908352136612, 58.00604581832886, 54.474051743745804, 50.81763714551926, 54.041452556848526, 33.537999764084816, 49.43695843219757, 70.13969913125038, 50.410382598638535, 55.27061440050602, 57.90282815694809, 56.658239141106606, 54.42408822476864, 62.291794046759605, 65.09083405137062, 41.410877108573914, 51.310949474573135, 49.50141817331314, 42.66933158040047, 32.98636056482792, 26.380470134317875, 19.75888654589653, 12.511966712772846, 8.139632530510426, 4.052395150065422, 0.34166721627116203, 1.6307503008283675, 2.6939336070790887, 0.08872767328284681, 7.7196344174444675, 7.0882536470890045, 5.532276090234518, 6.513455640524626, 3.6318491538986564, 3.028516103513539, 1.5527601982466877, 1.9535522419027984, 1.4633052796125412, 0.6441678560804576, 0.2896583086112514, 0.2570119744632393, 0.7787234452553093, 2.3728370619937778, 14.350452460348606, 15.664230063557625, 12.766298465430737, 14.268505107611418, 28.970407359302044, 32.53772623836994, 27.073885425925255, 17.257370576262474, 5.054258890450001, 0.6508109089918435, 0.15104023274034262, 0.03495627250231337, 0.008218567490985151, 0.042877659943769686, 0.0475416053814115, 0.008396611501666484, 0.0728319090558216, 0.023460781631001737, 0.006284010214585578, 0.051319945996510796, 0.014211987927410519, 0.07272959657711908, 0.06898829655256122, 0.03088934776315, 0.011169015469931765, 0.009449756162211997, 0.045021835903753527, 0.02430513603030704, 0.039141302622738294, 0.04598553692630958, 0.0026630292586560245, 0.01731186919641914, 0.016917606953938957, 0.015486853844777215, 0.0466949262045091, 0.10931740282103419, 0.1329932495718822, 0.12013795305392705, 0.026855363248614594, 0.01805711719498504, 0.038358704186975956, 0.10557182802585885, 0.03603747034503613, 0.042034376092487946, 0.02884123539843131, 0.021155472422833554, 0.025960299753933214, 0.03772927761019673, 0.029404030101432, 0.027322357818775345, 0.029678339014935773, 0.10757734111393802, 0.05480258529132698, 0.02785360939014936, 0.04386793356388807, 0.029041181114735082, 0.016342861817975063, 0.028395972767611966, 0.037965852025081404, 0.06618165731197223, 0.02878146096918499, 0.026362040989624802, 0.04089931317139417, 0.0377162714721635, 0.06999847828410566, 0.01498180008638883, 0.030031072528799996, 0.06351842326694168, 0.025550649079377763, 0.025518130023556296, 0.013002065497857984, 0.030873610521666706, 0.020349199476186186, 0.06345963032799773, 0.07357116977800615, 0.04547643846308347, 0.006286289535637479, 0.02452743523463141, 0.05040647723944858, 0.01966364241525298, 0.02540351644711336, 0.07319746873690747, 0.03685078627313487, 0.09930582324159332, 0.03317125519970432, 0.013310163467394887, 0.06341660060570575, 0.048649939853930846, 0.0770263718732167, 0.0688667104986962, 0.0440695045836037, 1.620926996693015, 11.5583879314363, 28.977550975978374, 43.85219670832157, 40.006312876939774, 30.968984216451645, 25.391392707824707, 20.681976713240147, 21.65342688560486, 23.867735266685486, 18.658541589975357, 8.675210941582918, 3.715714691206813, 0.5791564914397895, 0.1807047362672165, 0.17436718102544546, 0.2937009057495743, 0.30647546402178705, 2.2708476847037673, 2.0234215864911675, 3.6219760961830616, 3.8610388431698084, 6.739611430093646, 6.9469791278243065, 9.715930446982384, 8.670605588704348, 6.0886346362531185, 8.718381375074387, 4.617711715400219, 6.280588936060667, 4.006322147324681, 4.347425568848848, 4.7282767575234175, 10.402861386537552, 13.054844532161951, 19.734349362552166, 27.967738062143326, 37.40835428237915, 45.69978676736355, 52.201663479208946, 53.14913123846054, 58.06252978742123, 57.76146054267883, 59.73457306623459, 56.44798502326012, 56.822606921195984, 57.52300813794136, 39.47369545698166, 48.41366574168205, 59.85132560133934, 55.192217007279396, 54.9310190230608, 58.56821805238724, 55.93865655362606, 55.64589366316795, 58.616357669234276, 66.33365616202354, 48.365252539515495, 52.54629738628864, 51.74354486167431, 44.431403428316116, 34.23678606748581, 30.41607018560171, 22.371426858007908, 13.010859042406082, 11.636001616716385, 6.008295072242618, 2.59943719021976, 4.418277991935611, 6.095782527700067, 5.31704043969512, 8.52212380617857, 8.176689092069864, 5.716701569035649, 6.279659410938621, 5.4583292081952095, 4.388887519016862, 1.908942279405892, 2.8082200745120645, 1.5291601396165788, 0.2427907774108462, 0.22611192864133045, 0.11508646552101709, 1.2383932108059525, 2.762007904238999, 13.088846057653427, 22.430620081722736, 17.866662181913853, 13.839732315391302, 29.02967657893896, 37.46896103024483, 34.50709216296673, 20.36942258477211, 6.272151488810778, 1.0246796160936356, 0.24841168517014012, 0.0354826296097599, 0.04163050303759519, 0.0583538027422037, 0.050582878320710734, 0.06629260096815415, 0.013894142775825458, 0.0441333997878246, 0.057346274188603275, 0.04224422576953657, 0.053983591933501884, 0.0590039500821149, 0.05658606634824537, 0.01424839027095004, 0.023734754722681828, 0.05167854433238972, 0.024018212461669464, 0.026611094617692288, 0.018002730757871177, 0.021800892282044515, 0.039861408513388596, 0.036162095493637025, 0.08181941389921121, 0.028150195721536875, 0.05146332892763894, 0.07421955451718532, 0.0409433039749274, 0.07675714296055958, 0.03795612989051733, 0.04490530758630484, 0.022501192106574308, 0.05660003727825824, 0.07356381509453058, 0.0420089352701325, 0.04837629516259767, 0.04921542298689019, 0.027669328555930406, 0.02540042725740932, 0.14094749931246042, 0.18824134982423857, 0.1316919975215569, 0.1500153267988935, 0.1635454804636538, 0.28085809957701713, 0.10132987517863512, 0.1663312950404361, 0.12415323915774934, 0.09487463757977821, 0.17276972299441695, 0.3023584740003571, 0.15593578020343557, 0.15428478363901377, 0.1279060944216326, 0.15871819574385881, 0.1537473054486327, 0.21482113137608394, 0.10022311034845188, 0.12973580014659092, 0.10944810986984521, 0.14127264905255288, 0.09076149188331328, 0.14090550859691575, 0.12725407315883785, 0.18276406248332933, 0.1780880126170814, 0.16857997281476855, 0.09604362407117151, 0.11960545467445627, 0.18468696711352095, 0.12904321309179068, 0.11203592686797492, 0.18635071377502754, 0.23548752476926893, 0.19677925418363884, 0.17611541377846152, 0.11463126182206906, 0.12059443324687891, 0.24197202525101602, 0.15699028299422935, 0.09641468306654133, 0.12282179653993808, 1.9821243337355554, 14.233397841453552, 34.730789959430695, 54.149131178855896, 48.57030473649502, 42.67175205051899, 32.429663836956024, 25.182884596288204, 28.52286357432604, 29.330704025924206, 20.44265605509281, 11.152303721755743, 4.865124514326453, 1.340381638146937, 0.711750554619357, 0.8331153297331184, 2.179328170605004, 3.1640500808134675, 7.596381856128573, 10.209954287856817, 11.76089521497488, 16.13651242107153, 16.342269480228424, 13.031400740146637, 12.682390417903662, 13.46529945731163, 11.800790224224329, 10.234282482415438, 9.324470702558756, 8.741978108882904, 7.207315508276224, 5.284863766282797, 5.953823095187545, 10.163081903010607, 15.439568068832159, 20.312959514558315, 27.93295282870531, 39.000932425260544, 46.78737200796604, 52.942961901426315, 54.081445410847664, 58.84727507829666, 58.67565728724003, 61.323020830750465, 58.8615433126688, 59.996120631694794, 62.93001540005207, 41.93769223988056, 49.43554110825062, 61.015058755874634, 52.711535319685936, 57.69864231348038, 59.08533990383148, 57.000577971339226, 54.432067796587944, 59.26670417189598, 63.425269424915314, 51.734828129410744, 53.85834038257599, 51.18838705122471, 43.27113948762417, 34.8451030254364, 30.047923140227795, 22.97982931137085, 13.82912803441286, 11.059446204453707, 5.259765638038516, 2.4559217412024736, 5.407772921025753, 10.811241623014212, 6.394022349268198, 15.128180477768183, 14.314090311527252, 14.806218054145575, 14.859559591859579, 11.121784709393978, 9.175348654389381, 6.241534631699324, 5.570916216820478, 4.589402759447694, 1.29014061531052, 0.7160193286836147, 0.45803243934642524, 1.2859782949090004, 3.2282663974910975, 17.403845116496086, 21.600577421486378, 19.32366169989109, 22.727304361760616, 38.695098236203194, 45.25883562862873, 41.05401545763016, 24.76107493042946, 7.2653355449438095, 0.937053527450189, 0.3067110513802618, 0.2079223343753256, 0.10725597632699646, 0.11020731952157803, 0.11213590900297277, 0.19507183955283836, 0.21562447655014694, 0.1312559560756199, 0.13674287649337202, 0.11395783702027984, 0.11812812808784656, 0.14540322037646547, 0.1982659986242652, 0.13234965910669416, 0.21310632495442405, 0.14333304396132007, 0.10882817165111192, 0.15100247226655483, 0.14425973407924175, 0.1330986642278731, 0.27600296947639436, 0.13822298613376915, 0.15840391104575247, 0.09979699141695164, 0.11051218636566773, 0.24327335151610896, 0.16901081922696903, 0.19004525849595666, 0.19391604844713584, 0.09571102316840552, 0.13852986419806257, 0.19147001876262948, 0.14927859680028632, 0.14317817258415744, 0.18405830865958706, 0.16868939506821334, 0.10712668678024784, 0.130605656595435], [0.07413788116537035, 0.03114977851510048, 0.05177275255846325, 0.006862203554192092, 0.053918765333946794, 0.028110418461437803, 0.01675778730714228, 0.08494992638588883, 0.06920093670487404, 0.04722426303487737, 0.014522917190333828, 0.08328497744514607, 0.016742842308303807, 0.011856885248562321, 0.05685393713065423, 0.029038032553216908, 0.0668324540311005, 0.04722316465631593, 0.03366489843756426, 0.045266555389389396, 0.08360921434359625, 0.04173711255134549, 0.034661250247154385, 0.042543047820799984, 0.017205224430654198, 0.061329176678555086, 0.042645456778700463, 0.040967164022731595, 0.07578139688121155, 0.04672287548601162, 0.04183079014183022, 0.03633262989751529, 0.05169733180082403, 0.02020796135184355, 0.03787674235354643, 0.05311108601745218, 0.1525231180130504, 0.06472479173680767, 0.0358555291313678, 0.08517243710230105, 0.009233346827386413, 0.05952298961346969, 0.10066201648442075, 0.04458846990019083, 1.5954156406223774, 11.346953976899385, 27.218251079320908, 43.82340185344219, 34.51390899717808, 18.50499752908945, 20.508730709552765, 26.60739965736866, 19.84946608543396, 25.061931386590004, 14.106694590300322, 8.010226674377918, 4.5581313874572515, 2.092284341342747, 0.17996721959207207, 0.23076480865711346, 0.06528195168357342, 1.6046327585354447, 0.8406016998924315, 2.411699714139104, 3.9862387999892235, 5.4771101754158735, 4.033108334988356, 5.685869073495269, 8.474650103598833, 4.130240147933364, 5.456338590011001, 2.50485812779516, 4.3269859906286, 4.296510675922036, 3.2645527878776193, 2.291837758384645, 3.60521970782429, 3.943349551409483, 8.32008769735694, 13.513673711568117, 24.34042800217867, 33.463333770632744, 43.59428934752941, 47.367418482899666, 50.27378752827644, 53.79754364490509, 55.73830470442772, 58.32356438040733, 45.7658614218235, 55.76500207185745, 28.51594414561987, 34.549038112163544, 67.10970371961594, 51.60062313079834, 55.19657537341118, 52.066664323210716, 55.52995428442955, 62.84410960972309, 60.33928781747818, 45.37298530340195, 48.62822502851486, 45.25867223739624, 37.67161175608635, 31.16134699434042, 21.33767332881689, 18.58957529067993, 10.157220717519522, 5.026091951876879, 2.7699672896414995, 2.310368651524186, 2.243581535294652, 3.649586127139628, 2.5023198639974, 2.657709438353777, 6.828775070607662, 6.392886210232973, 3.63532739225775, 3.1184394657611847, 2.640087171457708, 2.6469987630844116, 1.1698611569590867, 1.2661279225721955, 0.23485058394726366, 0.15309452719520777, 0.456466656178236, 0.647992588346824, 2.5594982458278537, 10.701263174414635, 21.907437555491924, 8.401853609830141, 18.348647318780422, 31.117662638425827, 35.530058071017265, 27.011963948607445, 22.698080129921436, 9.654063116759062, 1.999194798991084, 0.05303580255713314, 0.03620682102337014, 0.027401428087614477, 0.09879029035801068, 0.042564840987324715, 0.03542915415891912, 0.10878051834879443, 0.1209332088183146, 0.06158211544970982, 0.0323093323095236, 0.026475882732484024, 0.032985284124151804, 0.04082461600773968, 0.044340945096337236, 0.03172282413288485, 0.08222428514272906, 0.05144817056134343, 0.04438129566551652, 0.056634283682797104, 0.03369162688613869, 0.058825868036365137, 0.041816978773567826, 0.029059818298264872, 0.026307148036721628, 0.024697591143194586, 0.0046690138424310135, 0.05260061829176266, 0.02289583284436958, 0.03105791547568515, 0.036423880665097386, 0.012327719505265122, 0.03904753226379398, 0.02815425155858975, 0.04079547186847776, 0.10406287110527046, 0.02150530599465128, 0.04168219733401202, 0.09592024944140576, 0.05558470504183788, 0.022961822760407813, 0.05546010586840566, 0.04080025129951537, 0.03193290387571324, 0.023273359656741377, 0.05104961870529223, 0.0927726824011188, 0.046805246456642635, 0.061843381117796525, 0.07161144720157608, 0.022959481284487993, 0.030678995281050447, 0.029343925416469574, 0.010956230598822003, 0.03056287700019311, 0.03577409697754774, 0.009361270822410006, 0.017338063298666384, 0.05588496685959399, 0.09060735523235053, 0.03411246172618121, 0.0508492648077663, 0.06769325627828948, 0.07138847635360435, 0.03432359160797205, 0.01838168620452052, 0.04355797187599819, 0.0650099768245127, 0.06971879993216135, 0.012196257321193116, 0.10421408369438723, 0.038302345492411405, 0.01780097976734396, 0.008967670019046636, 0.031050156321725808, 0.059312805969966576, 0.014875365905027138, 0.037758588732685894, 0.054848587315063924, 0.0299165609976626, 0.039960466674529016, 0.03180826017342042, 0.11922284786123782, 0.02649549027410103, 2.2227641148492694, 14.627023469656706, 31.942020803689957, 46.015333235263824, 36.91534213721752, 20.780197642743587, 20.952719785273075, 28.551838919520378, 27.114060670137405, 28.13561875373125, 17.70865336060524, 8.842037189751863, 4.7540901973843575, 1.5944107132963836, 0.29078450286760926, 0.11117223766632378, 0.20422121422598138, 0.3250246139941737, 1.0656544798985124, 3.5157378343865275, 4.001874485984445, 3.591187773272395, 5.694192526862025, 11.805840153247118, 6.749343182891607, 6.3148497976362705, 5.71432052180171, 6.411113357171416, 6.070352867245674, 5.755237676203251, 5.6515744887292385, 2.2194245690479875, 5.53002898581326, 7.993414476513863, 9.88621260970831, 17.407726608216763, 28.5671216994524, 37.01503738760948, 45.987583324313164, 50.48994652926922, 54.096272215247154, 54.8480124771595, 59.49940748512745, 60.241766050457954, 52.64613702893257, 56.841199323534966, 35.12646272778511, 35.47904580831528, 58.12711112201214, 59.85727608203888, 56.114313527941704, 54.183207750320435, 52.67061911523342, 61.56705513596535, 65.2142134308815, 51.689165979623795, 48.81214655935764, 49.235428646206856, 40.171661004424095, 33.88523653149605, 24.296072982251644, 22.392466329038143, 13.576238304376602, 6.687968401238322, 5.2651105262339115, 4.395498689264059, 2.3916954500600696, 8.006918001919985, 9.50189458206296, 8.414631374180317, 6.571177393198013, 8.949860204011202, 6.07460911385715, 3.782039419747889, 4.369786893948913, 2.78283909894526, 0.9926754771731794, 1.2865553889423609, 0.43257499288301915, 0.1821202493738383, 0.251891600782983, 0.9961473033763468, 2.9884149553254247, 8.966608755290508, 24.457252733409405, 16.14264339208603, 10.52866218611598, 25.654256902635098, 39.454080909490585, 34.55624632537365, 27.630150876939297, 12.059086114168167, 2.971078148111701, 0.17753751715645194, 0.06338272156426683, 0.018734516197582707, 0.06333788100164384, 0.027743727005145047, 0.04078632489836309, 0.041517392310197465, 0.06910756710567512, 0.10548233985900879, 0.009036430001287954, 0.04495574765314814, 0.041835179945337586, 0.006189407258716528, 0.024575199859100394, 0.02411205518001225, 0.0546646534348838, 0.13860336650395766, 0.05249285102763679, 0.0307991155932541, 0.05707624746719375, 0.01503721625340404, 0.03594844602048397, 0.011751275778806303, 0.039982475063879974, 0.026965407050738577, 0.03798690675466787, 0.05246250831987709, 0.043288687302265316, 0.03603779317927547, 0.045617828727699816, 0.034467197183403187, 0.03806646869634278, 0.02932326588052092, 0.054344231175491586, 0.0556240945297759, 0.010239764942525653, 0.05859140132088214, 0.031899978494038805, 0.08759795382502489, 0.2809706685366109, 0.1534989383071661, 0.14717373240273446, 0.09784717651200481, 0.1448297331808135, 0.2812342793913558, 0.18829367123544216, 0.14945114613510668, 0.14476543350610882, 0.16834318317705765, 0.10471413537743501, 0.18603053642436862, 0.0756456283852458, 0.17489312624093145, 0.1364302245201543, 0.18299743824172765, 0.1224414532771334, 0.11548582260729745, 0.11401594718336128, 0.14313071966171265, 0.179746356443502, 0.288578721228987, 0.12877964676590636, 0.16314397857058793, 0.12915757804876193, 0.21438964671688154, 0.18081800284562632, 0.10461676560225897, 0.14121759653789923, 0.17352957831462845, 0.15561776992399246, 0.08241524716140702, 0.16263048659311607, 0.17530907032778487, 0.16181848797714338, 0.2832848037360236, 0.14020355563843623, 0.07844166233553551, 0.17495053878519684, 0.20169660594547167, 0.23602999019203708, 0.19463241391349584, 0.23852182523114607, 0.1685047784121707, 3.1858718348667026, 17.743482291698456, 39.81548711657524, 54.495550990104675, 47.70684666931629, 27.293460443615913, 31.08670949935913, 37.131850719451904, 30.07426332682371, 33.863110318779945, 19.943815022706985, 11.234823893755674, 5.801594713702798, 2.313900562003255, 0.6463041133247316, 0.5818127270322293, 0.6780309265013784, 5.545181147754192, 4.159003654494882, 5.665779076516628, 9.417112581431866, 13.39253906160593, 11.114911828190088, 13.112405743449926, 17.46787168085575, 11.817245241254568, 10.522653758525848, 6.59628264605999, 11.335640083998442, 9.7281638905406, 8.323551211506128, 4.698104476556182, 6.865575620904565, 6.39522023499012, 11.10830683261156, 18.176923133432865, 27.82664403319359, 38.50768469274044, 46.72997608780861, 51.81032247841358, 53.88854496181011, 57.52341851592064, 61.201818734407425, 64.40053269267082, 55.43968252837658, 62.987259328365326, 38.47330033779144, 39.21636186540127, 61.829719841480255, 57.00136832892895, 55.642808228731155, 56.278666108846664, 55.59633672237396, 60.679882541298866, 63.83054047822952, 55.61597026884556, 52.670132741332054, 50.01108482480049, 39.81814317405224, 33.923204094171524, 23.412341102957726, 22.119162194430828, 10.801736433058977, 7.899709604680538, 4.971197247505188, 5.1697351690381765, 5.1673645712435246, 9.277547970414162, 8.883069287985563, 11.143484394997358, 16.091234050691128, 13.978539817035198, 11.318406108766794, 11.713261920958757, 9.353276006877422, 7.4805778451263905, 4.851938746869564, 4.368377644568682, 2.2700107796117663, 0.621206103824079, 0.8733408618718386, 1.148584911134094, 3.4105352545157075, 12.638557869940996, 26.518626920878887, 16.63299947977066, 25.993255712091923, 38.25266517698765, 47.52033367753029, 40.480402037501335, 32.20643721520901, 13.989865109324455, 2.9254463966935873, 0.29931359051261097, 0.15465446223970503, 0.11525819849339314, 0.1730693131685257, 0.13113887485815212, 0.10919154199655168, 0.2299724324257113, 0.21776438516099006, 0.21222754789050668, 0.13746771728619933, 0.12191437257570215, 0.12350954479188658, 0.13753148261457682, 0.11510239201015793, 0.06858970387838781, 0.21058964281110093, 0.2926161530194804, 0.22446787857916206, 0.1385755359660834, 0.0881725616636686, 0.19220777292503044, 0.29768237960524857, 0.07966892226249911, 0.17123950354289263, 0.08915962549508549, 0.09099402159336023, 0.10962965403450653, 0.12752893497236073, 0.08135589814628474, 0.16728933347621933, 0.16823491867398843, 0.18267320876475424, 0.14533575915265828, 0.1130457672115881, 0.21387550164945424, 0.08249819700722583, 0.15308921341784298, 0.14718223741510883, 0.11697323498083279], [0.0256452766188886, 0.05437406922283117, 0.010069274139823392, 0.11623896891251206, 0.019314042619953398, 0.07451868455973454, 0.005935262961429544, 0.039928034821059555, 0.06570194789674133, 0.0395854223461356, 0.042310688804718666, 0.06630690215388313, 0.12156891025369987, 0.10127412504516542, 0.015686087099311408, 0.05964296891761478, 0.055213783343788236, 0.10268474739859812, 0.05546504857193213, 0.0341207626479445, 0.007036488123048912, 0.09319837830844335, 0.06763480472727679, 0.03432643032283522, 0.05176574668439571, 0.015374056674772874, 0.018483306630514562, 0.000968810419408328, 0.13018033176194876, 0.06501815529190935, 0.024260994941869285, 0.044920020663994364, 0.04716420473414473, 0.025757927214726806, 0.025379146172781475, 0.09194673883030191, 0.007100874072420993, 0.04095731201232411, 0.04593882244080305, 0.02068387097097002, 0.04710312598035671, 0.05786237110442016, 0.040843537062755786, 0.0419828636222519, 0.18517892196541652, 2.903454601764679, 16.20097406208515, 36.141563057899475, 43.69678504765034, 37.36740007996559, 28.103998750448227, 25.129478462040424, 18.165464848279953, 23.84805992245674, 21.43765926361084, 14.174968376755714, 7.325402246788144, 4.690076932311058, 2.259741830639541, 0.6396180158481002, 0.12300864706048742, 0.3584293636959046, 0.6794708117377013, 1.9141408754512668, 1.5308248065412045, 3.2268542982637882, 3.8262702338397503, 15.97476840019226, 4.1817843820899725, 4.290869403630495, 7.1857530903071165, 6.763502173125744, 5.347138149663806, 3.605683045461774, 4.665790535509586, 1.3421373814344406, 2.645969493314624, 3.5885801631957293, 4.107528291642666, 7.511237449944019, 11.921926774084568, 21.385451965034008, 29.20620560646057, 37.52607576549053, 40.83489641547203, 49.48756791651249, 54.24210079014301, 59.35854144394398, 53.39791528880596, 60.900050327181816, 41.47180303931236, 40.38066878914833, 49.53112117946148, 46.593533009290695, 62.940164655447006, 57.219981998205185, 60.322124138474464, 44.72938723862171, 44.19341079890728, 47.18996800482273, 46.265963986516, 35.011541694402695, 31.878928989171982, 19.36302188783884, 13.441616278141737, 9.568849839270115, 7.459050575271249, 0.779915334424004, 3.1547104194760323, 4.550483347848058, 2.51399639993906, 5.74658221565187, 10.694931764155626, 4.987796181812882, 6.831614468246698, 8.513902947306633, 3.067445964552462, 2.7313927095383406, 2.9470252012833953, 2.949046455323696, 1.087646868545562, 1.1950408620759845, 0.25695957883726805, 0.1597721196594648, 0.6697182194329798, 2.7154974499717355, 5.940102031454444, 24.17678028345108, 13.605769369751215, 13.858798742294312, 39.95578318834305, 32.205878645181656, 33.062109500169754, 24.168637320399284, 15.180987194180489, 2.7818257408216596, 0.21948785986751318, 0.06689636036753654, 0.017232741411135066, 0.03679048677440733, 0.11757838219637051, 0.06653622578596696, 0.015404499572468922, 0.044703521343762986, 0.03007829909620341, 0.014179377958498662, 0.023895826743682846, 0.01670510224357713, 0.04138887088629417, 0.04595983264152892, 0.0483058430836536, 0.021036736216046847, 0.008108776946755825, 0.021368004963733256, 0.08748303225729614, 0.062236700832727365, 0.06828537138062529, 0.05740838452766184, 0.010092872580571566, 0.04243697265337687, 0.04075631615705788, 0.03033368324395269, 0.04165047052083537, 0.016274697409244254, 0.04707062733359635, 0.025040700857061893, 0.01414969947290956, 0.09617842035368085, 0.0076003195135854185, 0.0854789737786632, 0.04142506171774585, 0.054154089229996316, 0.0988814038282726, 0.029633748927153647, 0.01053585960107739, 0.03370884842297528, 0.030899040211807005, 0.030540504958480597, 0.04035882557218429, 0.0681746874761302, 0.04795449181983713, 0.04766328420373611, 0.030600305362895597, 0.04768547441926785, 0.009544982985971728, 0.0179346479853848, 0.09075317240785807, 0.06189634448674042, 0.023174654015747365, 0.09342688557808287, 0.04375409182102885, 0.04935781515087001, 0.01318930471825297, 0.04805367614608258, 0.006567138161699404, 0.03246063395636156, 0.022100361857155804, 0.08628309820778668, 0.036268831172492355, 0.03331673469801899, 0.08312966077937745, 0.05988093114865478, 0.05870234497706406, 0.05431659359601326, 0.08645806694403291, 0.02272973277285928, 0.04458371644432191, 0.02228226967417868, 0.034490318794269115, 0.018320998933631927, 0.026512190452194773, 0.10363957975641824, 0.030136507593852002, 0.07930316220154054, 0.029461785888997838, 0.039466641610488296, 0.04673866096709389, 0.028109357190260198, 0.11851729548652656, 0.02009374111366924, 0.1572328168549575, 4.40992271527648, 19.76460713893175, 42.17389516532421, 45.412392988801, 38.610153794288635, 31.073068231344223, 25.453620068728924, 21.199125163257122, 30.769322030246258, 28.319215402007103, 21.82549685239792, 9.50166279450059, 5.154751623049378, 2.1723370207473636, 0.251988495583646, 0.08319653570652008, 0.1772534378687851, 0.1659965715953149, 1.1788677424192429, 0.9628479089587927, 3.4749422734603286, 5.335671314969659, 7.869443753734231, 6.134042199701071, 5.445844028145075, 8.96492164582014, 7.744045732542872, 7.564967516809702, 9.175672587007284, 7.715815147385001, 7.245308244600892, 3.9291447261348367, 4.5249496679753065, 4.514169646427035, 9.062727447599173, 15.832168702036142, 24.53698955476284, 31.728563457727432, 40.32350465655327, 43.89837943017483, 53.33678796887398, 56.68030075728893, 62.67720736563206, 58.24742406606674, 61.93944275379181, 47.895289957523346, 40.41856415569782, 45.96935570240021, 58.68555195629597, 60.84706977009773, 57.84631758928299, 59.09021884202957, 53.64368990063667, 47.61366046965122, 49.10536162555218, 49.64395992457867, 37.162180691957474, 34.34411130845547, 24.814631156623363, 13.263948261737823, 14.21998456120491, 10.463905110955238, 2.666688119061291, 8.072023708373308, 6.996123315766454, 5.615744786337018, 10.340539030730724, 10.360944885760546, 9.489059820771217, 7.363229691982269, 5.893899360671639, 5.823907591402531, 3.7551086023449898, 2.600869950838387, 2.184759979136288, 0.5059238523244858, 0.23088347807060927, 0.19304892310174182, 0.11677010916173458, 0.5273612926248461, 4.172339038923383, 6.878150571137667, 24.049768298864365, 20.257347598671913, 10.058760400861502, 31.952565237879753, 39.454115107655525, 36.85003504157066, 28.290369249880314, 17.41236425936222, 4.060113960877061, 0.29050064622424543, 0.0915082854044158, 0.014523316094710026, 0.028296088967181277, 0.05613628032733686, 0.016886318007891532, 0.04031787015264854, 0.05192767217522487, 0.021161268596188165, 0.01584234258189099, 0.01708336749288719, 0.03229191781429108, 0.11878193792654201, 0.018245138453494292, 0.058798816753551364, 0.07488422939786687, 0.029455967451212928, 0.04867589275818318, 0.053669006665586494, 0.01331574441792327, 0.05752240809670184, 0.009385303419549018, 0.0345281015324872, 0.11265688182902522, 0.017241697278223, 0.04768036102177575, 0.03999337350251153, 0.04168605650193058, 0.10659424777259119, 0.029574404943559784, 0.03776789897528943, 0.07545998014393263, 0.07753921076073311, 0.052453335374593735, 0.04377592951641418, 0.036240726039977744, 0.07732401762041263, 0.0653299612167757, 0.004685962176154135, 0.03835144598269835, 0.14703778579132631, 0.2478372777113691, 0.18570451095001772, 0.21018922445364296, 0.1545279409037903, 0.14309873309684917, 0.09711344479001127, 0.13336416013771668, 0.15079516073456034, 0.09320128752733581, 0.15323525323765352, 0.12647705938434228, 0.13657590810908005, 0.21184335288126022, 0.24525484128389508, 0.13969937019282952, 0.11692211584886536, 0.21322702785255387, 0.14294939814135432, 0.2247427255497314, 0.1745663586189039, 0.1453062068321742, 0.17557992454385385, 0.06353397126076743, 0.13789293821901083, 0.12473670823965222, 0.1383348723175004, 0.1361388128134422, 0.21846267190994695, 0.13825810456182808, 0.1097384603053797, 0.10761086392449215, 0.18674439343158156, 0.1592111450736411, 0.11750573336030357, 0.28695041954051703, 0.08936232086853124, 0.2513368899235502, 0.11560853672563098, 0.14342318521812558, 0.15719391347374767, 0.219363386859186, 0.26040023483801633, 0.11222547138459049, 0.29782757337670773, 5.047670993953943, 22.66574766486883, 47.93923459947109, 53.70454363524914, 47.6235057413578, 38.1954288482666, 33.93757492303848, 26.49886228144169, 35.08103236556053, 31.646938137710094, 20.88039256632328, 11.728585548698902, 6.451094811782241, 3.472200958058238, 1.23866964597255, 0.37826584302820265, 1.1638884712010622, 2.0544314850121737, 4.929288821294904, 5.39161903783679, 8.093042280524969, 11.408229488879442, 27.13582020252943, 11.940890606492758, 12.150949984788895, 18.58678624033928, 16.6142550855875, 13.12520345672965, 11.401064023375511, 10.654105804860592, 7.7410590928047895, 6.037771515548229, 6.0328911524266005, 6.130085662007332, 9.808535277843475, 16.063685528934002, 24.607439674437046, 33.67919258773327, 42.13657356798649, 44.862030521035194, 53.115468844771385, 60.46725355088711, 68.11960592865944, 60.28756499290466, 69.27963808178902, 49.84100975096226, 46.75916992127895, 55.20613946020603, 53.87487709522247, 64.83006924390793, 57.617759853601456, 60.40613763034344, 53.19410562515259, 49.41635213792324, 51.7417361587286, 49.65559870004654, 39.956106171011925, 33.62132169306278, 23.189437463879585, 15.841143820434809, 11.61869639530778, 9.879433773458004, 2.711173282004893, 7.48867473565042, 11.659786440432072, 7.864669784903526, 13.625594805926085, 18.778928630053997, 11.958011537790298, 13.760900795459747, 17.365393079817295, 9.913625288754702, 8.34308311343193, 9.841136578470469, 8.060035351663828, 3.306941413320601, 2.2446837136521935, 1.08971550129354, 0.28552044939715415, 1.082237740047276, 4.449025942012668, 8.115052599459887, 29.754375591874123, 22.68195379525423, 20.869635343551636, 46.19373366236687, 43.53654004633427, 42.92115926742554, 35.61885930597782, 21.121721416711807, 4.273683875799179, 0.3814848937327042, 0.23327414353843778, 0.144302214612253, 0.1852962703560479, 0.26520279119722545, 0.17157829395728186, 0.18652842845767736, 0.08576289721531793, 0.12517839000793174, 0.13967625971417874, 0.13625546358525753, 0.08016553780180402, 0.2263464473071508, 0.06100125872762874, 0.1801791918114759, 0.14222616038750857, 0.1361338552669622, 0.2202172129182145, 0.15906182496109977, 0.13009461370529607, 0.1646796305431053, 0.14882027608109638, 0.1503636167035438, 0.23867770592914894, 0.09190283337375149, 0.09776410050108097, 0.2855245757382363, 0.21330808522179723, 0.19770998158492148, 0.15933388145640492, 0.18375901534454897, 0.25847955665085465, 0.09011782720335759, 0.11954198620514944, 0.10165824583964422, 0.14666325354482979, 0.18745060631772503, 0.15620902413502336, 0.08571610480430536, 0.08979928257758729], [0.0669687865593005, 0.06601735323783942, 0.04271365272870753, 0.05404131989052985, 0.020665860902226996, 0.058815674638026394, 0.04163992089161184, 0.06395905118552037, 0.002361235601711087, 0.14647425821749493, 0.02396474257693626, 0.05265768944809679, 0.022817161479906645, 0.05669205616868567, 0.018430795971653424, 0.059939898492302746, 0.03918480360880494, 0.030979407383711077, 0.03881323253153823, 0.07240764549351297, 0.0679603626485914, 0.08419873935054056, 0.04813889325305354, 0.0157582609608653, 0.0689207982213702, 0.020964677387382835, 0.036793076869798824, 0.060871535024489276, 0.048113389348145574, 0.025682178056740668, 0.021248710290819872, 0.05752056014898699, 0.1396068837493658, 0.02719294210692169, 0.017644514628045727, 0.04804340482223779, 0.008214154495362891, 0.06532452869578265, 0.06597521409275942, 0.009019626850204077, 0.06798923961468972, 0.09120980103034526, 0.08344337402377278, 0.10174278388149105, 0.044197358074598014, 0.2633189532207325, 4.098325660452247, 17.684347964823246, 36.15319803357124, 40.69536030292511, 35.54039731621742, 34.192860424518585, 20.39267923682928, 15.852090083062649, 17.773152999579906, 23.706793002784252, 22.435181736946106, 14.432797841727734, 6.952295517548919, 2.9620533948764205, 0.4596396640408784, 0.2527724707033485, 0.36271327757276595, 1.316683259792626, 0.6146880879532546, 2.1673227148130536, 4.784644832834601, 8.162657395005226, 4.6222724206745625, 3.815532485023141, 3.786988891661167, 5.594443129375577, 3.5726480931043625, 6.6922094486653805, 7.1006713807582855, 5.551515882834792, 2.378055131994188, 3.23772931471467, 0.9234934800770134, 2.2490218933671713, 5.324708903208375, 12.072338853031397, 15.74971692636609, 25.65826378762722, 39.86818268895149, 50.120670944452286, 46.77842728793621, 58.96824158728123, 56.83553762733936, 60.624580308794975, 54.09825570881367, 44.793919175863266, 39.16229076683521, 41.40269994735718, 67.66771137714386, 55.51928825676441, 50.37259742617607, 44.36685249209404, 50.3385778516531, 39.642478600144386, 35.560714825987816, 25.79602349549532, 17.705928906798363, 11.919735241681337, 5.670823305845261, 5.822794726118445, 4.094986589625478, 0.8427044714335352, 6.73708931542933, 5.128007708117366, 3.053590483032167, 9.736941419541836, 10.471067726612091, 10.48184584826231, 4.497042065486312, 4.463934917002916, 6.805096166208386, 1.669147121720016, 1.5463605104014277, 0.534055286552757, 0.3293293673777953, 0.19170909421518445, 0.19253946840763092, 1.2911176378838718, 2.7662978740409017, 6.998629281297326, 11.52084119617939, 30.424758419394493, 33.755944669246674, 38.74418780207634, 22.98272095620632, 27.97373604029417, 32.369269877672195, 18.811175599694252, 8.374742064625025, 0.1565282218507491, 0.033713995217112824, 0.023623985471203923, 0.04144221275055315, 0.005601995981123764, 0.03838702825305518, 0.03448707560892217, 0.0132766749811708, 0.03318600167403929, 0.04116798547329381, 0.02053195334156044, 0.02395666429947596, 0.0637207920954097, 0.04535164262051694, 0.04994898772565648, 0.037332013380364515, 0.06926404894329607, 0.011458541193860583, 0.03519413454341702, 0.07100100847310387, 0.05149152311787475, 0.018415526283206418, 0.05038441318902187, 0.026163338370679412, 0.03829317254712805, 0.02616609173855977, 0.02795303676975891, 0.06033852456312161, 0.07213325123302639, 0.07030465872958302, 0.017498563865956385, 0.01230940793902846, 0.03630954168329481, 0.04914693388855085, 0.00928242505324306, 0.06723967046127655, 0.08110724156722426, 0.05955998567515053, 0.011062754765589489, 0.02946529810287757, 0.027122792453155853, 0.07175108970841393, 0.018298916329513304, 0.045207614020910114, 0.04627999143849593, 0.0109000824886607, 0.06460865304688923, 0.04563008900731802, 0.023269339071703143, 0.03448929463047534, 0.0790332727774512, 0.0489324866066454, 0.028882040533062536, 0.055760864925105125, 0.009588239063305082, 0.028229859708517324, 0.03560777797247283, 0.03848521810141392, 0.017251985300390515, 0.05357190406357404, 0.04744255464174785, 0.03496654753689654, 0.0282567328758887, 0.055394570517819375, 0.06372990566887893, 0.03628137717896607, 0.02291478172992356, 0.020817028962483164, 0.020970004152331967, 0.03168539020407479, 0.06960558530408889, 0.019101235484413337, 0.04613460099790245, 0.07571760928840376, 0.02681755824596621, 0.05955798187642358, 0.024873697220755275, 0.0269174865752575, 0.02079284608043963, 0.07190146367065609, 0.035225627580075525, 0.038866552131366916, 0.04957098593877163, 0.026806923269759864, 0.04178394578048028, 0.021904292007093318, 0.27215131209231913, 5.699860397726297, 21.55364613980055, 42.14442394673824, 44.10382680594921, 38.07655602693558, 35.77155031263828, 19.949482418596745, 18.254993744194508, 25.037876777350903, 27.368350625038147, 23.67061324417591, 16.64180550724268, 8.369235210120678, 2.7000327548012137, 0.4162323963828385, 0.19220199901610613, 0.08112098614219576, 0.42661453771870583, 0.6117877748329192, 2.437424333766103, 3.3451367262750864, 4.052326278761029, 4.128661807626486, 3.5215434478595853, 3.746941890567541, 7.7182854898273945, 7.679949821904302, 5.982589926570654, 6.8226265255361795, 7.1978796645998955, 5.964304357767105, 3.9570848643779755, 3.4196341037750244, 3.762858286499977, 6.7225968930870295, 14.4322544708848, 21.270810216665268, 29.545407705008984, 41.81864082813263, 50.96659295260906, 52.55532570183277, 62.04162687063217, 61.47218182682991, 60.33636957406998, 60.96219219267368, 49.0397809445858, 35.743777602910995, 50.95735564827919, 66.43210887908936, 59.97909374535084, 51.79364137351513, 46.3644926995039, 51.80137775838375, 43.383146077394485, 37.09164507687092, 28.516388721764088, 19.01382252573967, 14.851312134414911, 8.510941006243229, 8.599440157413483, 4.934209082275629, 3.255360131151974, 8.971007019281387, 7.503143884241581, 6.533680055290461, 10.214211959391832, 7.368566505610943, 8.373041655868292, 7.489438969641924, 4.719773288816214, 3.2720830338075757, 2.0315982727333903, 1.2497849995270371, 0.5878652678802609, 0.28407703153789043, 0.18726126960245892, 0.14084719063248485, 1.544146416708827, 3.755700420588255, 10.540923178195953, 13.150935675948858, 35.292586013674736, 26.06250509619713, 27.420795410871506, 30.6925680488348, 30.52668794989586, 37.80657671391964, 22.471918165683746, 10.28655057772994, 0.36702643206808716, 0.028040589786542114, 0.04232070408761501, 0.03375374464667402, 0.020752950076712295, 0.017510662728454918, 0.0700526921718847, 0.021967231696180534, 0.0634111235558521, 0.0285883801188902, 0.05102095325128175, 0.02836654290149454, 0.08574640669394284, 0.030166325232130475, 0.026519825296418276, 0.01964185110409744, 0.13574044278357178, 0.06701769409119152, 0.02749433941062307, 0.04068604590429459, 0.05990146266412921, 0.040669069276191294, 0.036935424504918046, 0.028394286237016786, 0.02903048305597622, 0.039224779393407516, 0.05006373117794283, 0.04781981428095605, 0.04503639313043095, 0.058274433758924715, 0.030857979036227334, 0.026619556956575252, 0.03350470957229845, 0.05705599796783645, 0.02941932947578607, 0.03514553129207343, 0.018014065208262764, 0.06686495267786086, 0.033344246112392284, 0.045807247079210356, 0.07215432080556639, 0.2576812432380393, 0.1746135443681851, 0.1271059107966721, 0.12942506291437894, 0.08384316897718236, 0.17319038714049384, 0.2572795038577169, 0.08596925879828632, 0.10014015308115631, 0.16626663913484663, 0.13945484737632796, 0.23446723498636857, 0.12931592267705128, 0.146424489794299, 0.14869678270770237, 0.13091137690935284, 0.14706433983519673, 0.1732212901697494, 0.111978499480756, 0.1623431863845326, 0.2131643905886449, 0.19880401116097346, 0.13336821226403117, 0.15058393066283315, 0.12472803995478898, 0.13296981254825369, 0.11522419328684919, 0.1541860037832521, 0.16895313950954005, 0.1484778936719522, 0.10970244387863204, 0.11027344487956725, 0.30191069177817553, 0.13015526201343164, 0.12977480742847547, 0.19360845792107284, 0.06057256083295215, 0.12918862950755283, 0.1991627356619574, 0.1337531048920937, 0.21708808082621545, 0.34440410847309977, 0.25126837485004216, 0.21925363806076348, 0.11668920022202656, 0.48703598615247756, 7.290860675275326, 25.510922893881798, 50.043896064162254, 51.23389720916748, 47.08415128290653, 45.254671052098274, 30.053651332855225, 24.237540923058987, 28.950901105999947, 31.327092200517654, 30.029948204755783, 19.718766398727894, 8.857244923710823, 4.099150216206908, 1.0955880861729383, 0.64489456708543, 1.1748347338289022, 3.238021661527455, 3.902572989463806, 4.601234849542379, 11.380898505449295, 16.815824769437313, 12.154334653168917, 11.006499845534563, 11.594357751309872, 13.38177328929305, 12.945975624024868, 14.771045241504908, 14.709810577332973, 12.354037687182426, 7.048100251704454, 6.358895134180784, 3.1443037278950214, 3.640177119523287, 8.193083312362432, 15.68937236443162, 21.32889959961176, 31.245267391204834, 45.50264574587345, 55.6501380354166, 56.394081115722656, 65.2946475148201, 64.82602626085281, 63.11372794210911, 58.01344782114029, 49.11457993090153, 51.443520560860634, 47.92545273900032, 69.03907299041748, 61.9522138684988, 57.58759327232838, 48.74802120029926, 53.572227135300636, 43.039306327700615, 37.23570674657822, 28.961449339985847, 20.44711321592331, 14.45261662825942, 7.567826388403773, 8.97091867402196, 8.151863124221563, 4.994368404150009, 12.484902665019035, 10.951871126890182, 8.903580587357283, 17.835598848760128, 20.207323282957077, 20.73718775063753, 13.247762080281973, 10.728949438780546, 14.281106181442738, 4.8571691662073135, 3.6354230996221304, 2.803076575510204, 1.5563089703209698, 0.5986888089682907, 0.5385751440189779, 1.891040252521634, 3.9917024318128824, 9.707054123282433, 15.816791877150536, 39.34097997844219, 39.25927296280861, 45.76061390340328, 33.15412916243076, 35.29328517615795, 44.06176686286926, 25.534975603222847, 10.700425319373608, 0.8900200668722391, 0.09159884226392023, 0.06434415903640911, 0.12476528092520311, 0.1254509956925176, 0.19751323823584244, 0.15434844506671652, 0.11677044312818907, 0.19373609247850254, 0.09962453113985248, 0.13787733827484772, 0.0558838796132477, 0.13241452281363308, 0.12151761300629005, 0.15201372269075364, 0.13212504069088027, 0.2105052160914056, 0.1982646033866331, 0.10291680955560878, 0.15408486389787868, 0.18311322812223807, 0.17594111297512427, 0.14594068372389302, 0.1981367461849004, 0.1449157777824439, 0.2539065614109859, 0.13250337273348123, 0.14369533077115193, 0.21216201625065878, 0.12037696913466789, 0.07590693116071634, 0.11459931236458942, 0.1274669953272678, 0.14370572083862498, 0.09860585181741044, 0.15541134896920994, 0.14887681289110333, 0.12033158680424094, 0.11762673311750405, 0.10680768944439478, 0.1536340091843158], [0.03979931672802195, 0.03200332626875024, 0.02620166658743983, 0.09464617483899929, 0.040434814072796144, 0.0306209092377685, 0.0837496509484481, 0.0430086341657443, 0.03829328386927955, 0.013955343056295533, 0.08774841684498824, 0.07508575959946029, 0.04711655143182725, 0.04728279622213449, 0.023365987108263653, 0.0066380341377225704, 0.0707964577304665, 0.029315122665138915, 0.019036086050618906, 0.046721714024897665, 0.0440912383783143, 0.06039073836291209, 0.043456932180561125, 0.05862492042069789, 0.04017680272227153, 0.008081594860414043, 0.044968197180423886, 0.04913433222100139, 0.009724066931084963, 0.04773358043166809, 0.07644708850421011, 0.025144647916022222, 0.07614314192323945, 0.05421483401732985, 0.06297220999840647, 0.02963932987768203, 0.030404124190681614, 0.03945538694097195, 0.011817511531262426, 0.037721570406574756, 0.03556562769517768, 0.0310383394753444, 0.01626558198040584, 0.08160707802744582, 0.11092044922406785, 0.07056317845126614, 0.12794685317203403, 4.6723309345543385, 21.18686132133007, 37.74953417479992, 43.21350418031216, 34.08883340656757, 27.25746687501669, 20.97723986953497, 19.295571707189083, 19.28628120571375, 20.436699874699116, 17.773447483778, 14.766855966299772, 8.812436778098345, 3.4210709016770124, 1.1635468457825482, 0.22896676295204088, 0.14926541625754908, 0.19046556641114876, 4.349435660988092, 3.7557844910770655, 1.689751991070807, 3.0145908007398248, 2.5552108883857727, 4.798461841419339, 4.486538479104638, 5.789375519379973, 5.381292616948485, 5.698727108538151, 5.903454897925258, 4.515984524041414, 2.954725963063538, 3.2469193590804935, 1.3749184599146247, 0.7317910948768258, 3.0739657022058964, 8.935076147317886, 14.993642996996641, 22.827658876776695, 48.74982230365276, 42.544861659407616, 49.59799379110336, 51.63981802761555, 57.12795093655586, 55.59338428080082, 41.32962986826897, 31.996437683701515, 37.720579728484154, 59.58354637026787, 51.36535495519638, 50.45365087687969, 39.9923600256443, 35.4009447991848, 32.033637687563896, 23.30228380858898, 13.914492353796959, 9.633724708110094, 6.263186344876885, 1.4937760820612311, 4.422431644052267, 4.913460295647383, 1.1050322419032454, 14.137359894812107, 6.263249516487122, 5.603935495018959, 6.868781698867679, 6.113120997324586, 7.329746363684535, 8.151239957660437, 2.8653224604204297, 2.3579485109075904, 1.9874888146296144, 1.5388543694280088, 0.4162902245298028, 0.2578281587921083, 0.06110387919761706, 0.8925402816385031, 1.5288877417333424, 7.130633722990751, 12.149618156254292, 15.486126970499754, 42.26995401084423, 29.62295774370432, 16.72054298222065, 22.337836660444736, 33.37562307715416, 21.520644910633564, 10.266717541962862, 1.499252300709486, 0.05222244952165056, 0.09624052327126265, 0.018127873554476537, 0.0778643976082094, 0.05057653666881379, 0.02849495671398472, 0.04656135817640461, 0.009577220953360666, 0.0273741782802972, 0.025012992773554288, 0.05640862254949752, 0.04882714987616055, 0.021765606870758347, 0.05721690300561022, 0.01886807309347205, 0.01705770588159794, 0.0031616546266377554, 0.07397967754513957, 0.03778226695430931, 0.06477202943642624, 0.07720551147940569, 0.03857994212012272, 0.005261904952931218, 0.009916075377987, 0.018869854247896, 0.009312806723755784, 0.024090890983643476, 0.004943014300806681, 0.08233175554778427, 0.03368047982803546, 0.12729097274132073, 0.04909689087071456, 0.03086001623159973, 0.047451950231334195, 0.04823014030989725, 0.046246813726611435, 0.07354631525231525, 0.06340207677567378, 0.023714477392786648, 0.028671573018073104, 0.024824695065035485, 0.01740239080390893, 0.08324235590407625, 0.07842038496164605, 0.08995243959361687, 0.026783237626659684, 0.051865513596567325, 0.07953856402309611, 0.015113180634216405, 0.040285093200509436, 0.01984281356271822, 0.045464293216355145, 0.080920198088279, 0.022679071917082183, 0.04980306293873582, 0.018006306054303423, 0.0522091836319305, 0.05403648108767811, 0.03043252061615931, 0.011448342229414266, 0.066063700360246, 0.07526168570620939, 0.09918234471115284, 0.035402080611675046, 0.08449790650047362, 0.03489441820420325, 0.08847158038406633, 0.01317831629421562, 0.03866849518090021, 0.11479108332423493, 0.07365212324657477, 0.10789012667373754, 0.05220468621701002, 0.02636108732986031, 0.02522215410863282, 0.048068326141219586, 0.016374134065699764, 0.013013148545724107, 0.033810173845267855, 0.004507708972596447, 0.04312059456424322, 0.06415755342459306, 0.023161788885772694, 0.023707258151262067, 0.0481440140720224, 0.050984302288270555, 0.036436307927942835, 0.32830570824444294, 6.139908609911799, 26.601304784417152, 41.05838142335415, 46.55979461967945, 37.25737318396568, 27.831638865172863, 19.845732785761356, 17.61262111365795, 21.965217255055904, 29.1252813488245, 24.86029900610447, 16.345261819660664, 9.90419514477253, 2.849497734569013, 0.9999586176127195, 0.21441845688968897, 0.07025945451459847, 0.1710488012759015, 1.1016808217391372, 1.723114913329482, 0.5563923879526556, 2.164678769186139, 2.764720721170306, 3.8633115962147713, 4.100344302132726, 6.42954426817596, 7.850576816126704, 6.696197809651494, 9.473568052053452, 8.78510294482112, 7.330892002210021, 4.275499228388071, 2.4835757073014975, 2.2733500879257917, 4.326138161122799, 10.752091147005558, 20.08119475096464, 27.06821233034134, 50.4344467073679, 46.03020563721657, 53.256631270051, 54.857990741729736, 56.91739663481712, 59.56835098564625, 46.615545228123665, 31.37464664876461, 45.72236895561218, 62.30804957449436, 53.64600397646427, 51.85879647731781, 44.6869283169508, 39.93031695485115, 34.29493434727192, 25.517855621874332, 16.060719788074493, 11.653837859630585, 8.144020345062017, 5.543968062847853, 5.490307342261076, 3.5795444855466485, 4.898942224681377, 9.373049195855856, 5.846663620322943, 8.234602734446526, 12.904568295925856, 8.906557727605104, 6.499879444018006, 4.527395786717534, 3.3580025983974338, 2.9538536723703146, 0.6413728685583919, 0.5001931067090482, 0.33398420666344464, 0.20829168643103912, 0.18679284083191305, 0.8845492510590702, 2.770205964334309, 9.741183891892433, 15.466395579278469, 15.687701404094696, 41.40424266457558, 36.83958940207958, 23.80793407559395, 24.27329320460558, 35.8317656815052, 27.529560774564743, 11.947849933058023, 1.7851360165514052, 0.04022327972052153, 0.15539180079940706, 0.03125877774436958, 0.04112358277780004, 0.021523531286220532, 0.047271471048588865, 0.04101323655049782, 0.013375426078710007, 0.12327254735282622, 0.03552489491994493, 0.04344642708019819, 0.03592794790165499, 0.01002313852950465, 0.0369506607967196, 0.026038175165012944, 0.032453590974910185, 0.006910365691510378, 0.030054769304115325, 0.022603324614465237, 0.021825286676175892, 0.05844595521921292, 0.01484367712691892, 0.02283738871483365, 0.021593217097688466, 0.015332191196648637, 0.015720292685728054, 0.043797989856102504, 0.07039359770715237, 0.06221911564352922, 0.043958891183137894, 0.02666678909008624, 0.010198118397966027, 0.047003856307128444, 0.029279388254508376, 0.04210817154671531, 0.014482792976195924, 0.028482210327638313, 0.008724058188818162, 0.02611920099298004, 0.0867770345939789, 0.05779398219601717, 0.10279201742378063, 0.16985686757834628, 0.09181789457215928, 0.26248204812873155, 0.12012060164124705, 0.12374221550999209, 0.21527321805479005, 0.1270025147823617, 0.10535084613366053, 0.09644219448091462, 0.242265188426245, 0.16658871638355777, 0.13744523021159694, 0.18695672188187018, 0.10282124319928698, 0.10998188474331982, 0.14850118226604536, 0.17554611229570583, 0.10715881435316987, 0.13977348105981946, 0.14260787662351504, 0.12201423596707173, 0.12750484485877678, 0.24882339901523665, 0.1443513299454935, 0.10536657224292867, 0.14577142952475697, 0.19006940798135474, 0.11924820704734884, 0.1674514779006131, 0.2509824401931837, 0.15569474548101425, 0.2039161915308796, 0.16276028822176158, 0.11608530723606236, 0.2513684757286683, 0.17787482327548787, 0.21618068654788658, 0.20900031871860847, 0.107389622280607, 0.16103293950436637, 0.1953438960481435, 0.09237737744115293, 0.17924778163433075, 0.2019936579745263, 0.20870443928288296, 0.5759733903687447, 8.242701049894094, 30.12599755078554, 46.78205989301205, 55.9931418299675, 45.018665716052055, 40.215085074305534, 29.750636592507362, 28.21235753595829, 29.53486707061529, 30.836128145456314, 25.764944963157177, 18.418316580355167, 12.37250754609704, 4.767254590988159, 2.270712316967547, 0.35263722762465477, 0.38486000325065106, 0.45590363326482475, 5.900400336831808, 5.403294386342168, 7.27210583165288, 10.04445131868124, 6.235058354213834, 10.341270491480827, 10.867881383746862, 11.298597771674395, 12.594078406691551, 12.443133406341076, 15.295924376696348, 15.735419243574142, 9.382011014968157, 6.137364646419883, 3.6315147718414664, 2.803592635318637, 4.652051422744989, 12.258871793746948, 19.308855794370174, 27.646887078881264, 53.39934781193733, 51.25533185899258, 57.35734462738037, 56.178568080067635, 60.98664008080959, 58.51961486041546, 47.41897791624069, 47.06984885036945, 45.472403168678284, 67.32503816485405, 56.495987847447395, 55.99367380142212, 46.41199395060539, 40.96039228141308, 33.7613707780838, 26.93473309278488, 15.424359384924173, 12.194712236523628, 7.525549381971359, 3.87457181699574, 9.784523416310549, 9.853343423455954, 6.2825315818190575, 23.402590826153755, 12.88736091926694, 13.044328596442938, 16.143908724188805, 12.388386894017458, 13.606722168624401, 14.291474875062704, 9.191533885896206, 8.366069979965687, 6.608725553378463, 4.325661761686206, 2.3732859129086137, 1.2014639424160123, 0.5863696325104684, 1.3248603022657335, 2.442724574357271, 9.850088898092508, 18.064357973635197, 20.637357607483864, 53.0644565820694, 36.80735573172569, 25.303022749722004, 31.013728715479374, 43.74243959784508, 30.886070765554905, 15.011099260300398, 2.056495249271393, 0.07636410155100748, 0.1969285891391337, 0.1555214836844243, 0.13758004875853658, 0.15165859018452466, 0.14230586704798043, 0.18625502125360072, 0.107274136680644, 0.15787642216309905, 0.19762166601140052, 0.13802287343423814, 0.2655844035325572, 0.16530818509636447, 0.1415316734346561, 0.07851967689930461, 0.16940283647272736, 0.13284927292261273, 0.16202168801100925, 0.14102647866820917, 0.19695110589964315, 0.17817554151406512, 0.09588327564415522, 0.1507372286869213, 0.16286555444821715, 0.0754128018161282, 0.13230661454144865, 0.1529531629057601, 0.09535276622045785, 0.137368195282761, 0.10639187894412316, 0.18173767224652693, 0.11852183743030764, 0.08481190918246284, 0.07984346055309288, 0.13463157025398687, 0.12048023156239651, 0.1678411351167597, 0.20615133253159001, 0.07784615561831743, 0.17524052556836978, 0.16669377480866387], [0.04670324567996431, 0.019895537589036394, 0.02294771453307476, 0.033160360471811146, 0.019534349157765973, 0.05394713021814823, 0.034319387341383845, 0.07444849965395406, 0.04706093488493934, 0.05135724262800068, 0.12770549190463498, 0.04747019222122617, 0.05103041934489738, 0.04369904301711358, 0.03836857475107536, 0.04529762540187221, 0.028257816411496606, 0.02767472768027801, 0.08293571532703936, 0.02786150769679807, 0.014490165285678813, 0.02280345586768817, 0.08720419253222644, 0.06642497042776085, 0.0674955926660914, 0.052331463593873195, 0.04826698794204276, 0.022248127170314547, 0.03712769270350691, 0.061521671232185327, 0.047688580307294615, 0.03224140724341851, 0.01949686513398774, 0.05375298067519907, 0.055953326082089916, 0.01060517248333781, 0.019947515756939538, 0.0359938765905099, 0.006340593872664613, 0.04201173687761184, 0.03768913113162853, 0.05274072835163679, 0.08780638600001112, 0.0669848317920696, 0.0379553395032417, 0.022871117471368052, 0.05447556162835099, 0.6198093818966299, 6.757449572905898, 18.62399574369192, 36.029374077916145, 42.769137024879456, 35.48059232532978, 28.77045638859272, 25.994372852146626, 13.291744720190763, 19.872612543404102, 23.69897872209549, 23.732375130057335, 13.67090167477727, 9.25969272851944, 4.880553586408496, 1.8933982634916902, 0.35359934787265956, 0.21911313466262072, 0.7315465423744172, 2.0375397289171815, 0.3786368278088048, 1.5280093951150775, 1.8559617223218083, 1.6426731110550463, 3.619494829326868, 4.99465006403625, 4.8689523339271545, 2.7433145698159933, 5.835700258612633, 8.20852093398571, 3.9042335003614426, 4.308562204241753, 1.5964126121252775, 1.8086237437091768, 1.3842420908622444, 2.1369654312729836, 7.867073630914092, 15.029467474669218, 32.3106200248003, 42.87907272577286, 41.220150142908096, 47.39644132554531, 43.69458116590977, 54.70957450568676, 30.399028100073338, 20.124109648168087, 32.18189053237438, 42.45479129254818, 46.91332004964352, 42.112885639071465, 28.114545084536076, 26.14723864942789, 22.349555231630802, 12.43903437629342, 8.037492111325264, 2.5325291929766536, 2.543693231418729, 5.642621219158173, 2.9162416281178594, 2.2991324169561267, 4.765428313985467, 5.483202198520303, 3.944557411596179, 6.639378508552909, 12.325694058090448, 6.010349811986089, 5.368384709581733, 2.7025144966319203, 2.8765168972313404, 1.4172230148687959, 0.3604947606800124, 0.2792756032431498, 0.16991796117508784, 0.26862142025493085, 0.7395291421562433, 2.6675430731847882, 7.599112959578633, 11.734219696372747, 14.479340594261885, 37.158605083823204, 23.416157998144627, 6.98718904517591, 20.20783055573702, 34.25105810165405, 27.196742333471775, 13.425839524716139, 3.073486452922225, 0.2860298892483115, 0.030194602913979907, 0.0468041480780812, 0.07605777267599478, 0.03299151074315887, 0.06091138093324844, 0.09031924608279951, 0.07871731082559563, 0.010429382746224292, 0.03363706789969001, 0.019639804631879088, 0.0386205821268959, 0.034333547519054264, 0.05569717010075692, 0.060984226438449696, 0.024464174566674046, 0.037971087876940146, 0.04021712731628213, 0.015258363273460418, 0.10001822563936003, 0.02613923712488031, 0.02007069742830936, 0.07760771841276437, 0.04382766092021484, 0.04703688187873922, 0.0471598297735909, 0.01783862891898025, 0.03509976675559301, 0.09535715231322683, 0.020766240086231846, 0.0593681961618131, 0.043751583361881785, 0.035317331057740375, 0.013563337870436953, 0.05621628384687938, 0.04314255842473358, 0.027666220812534448, 0.08519455310306512, 0.03495798686344642, 0.0724166254804004, 0.021017694562033284, 0.010302032060280908, 0.04674433839682024, 0.020469429255172145, 0.034946067971759476, 0.03002568453666754, 0.015020760056358995, 0.07826158762327395, 0.0493662719236454, 0.03960612455557566, 0.07754068763460964, 0.09052327732206322, 0.08854934261762537, 0.10634972495608963, 0.05441824185254518, 0.035245743492851034, 0.04206022509606555, 0.0455472764588194, 0.12081587527063675, 0.03760599203815218, 0.04222995055897627, 0.013051283804088598, 0.019529462115315255, 0.02270527715154458, 0.00992028706605197, 0.014996245990914758, 0.09866759108263068, 0.05602763361821417, 0.03715285150974523, 0.06423654762329534, 0.06708399014314637, 0.024880723503883928, 0.05872437192010693, 0.04866168805165216, 0.019082663238805253, 0.04817060522327665, 0.06825938136898912, 0.018233677837997675, 0.028138672023487743, 0.02614629494928522, 0.10639774191076867, 0.03084322699578479, 0.03705157432705164, 0.011122242540295701, 0.06123771068814676, 0.05416888765466865, 0.033797861615312286, 0.06193088032887317, 0.06298941298155114, 0.7872659212443978, 8.549683727324009, 24.184604063630104, 41.19272701442242, 46.049523800611496, 37.40774631500244, 30.565179884433746, 23.04974365979433, 15.22274885326624, 22.012270130217075, 25.858492143452168, 26.377342902123928, 19.304885007441044, 11.939467582851648, 5.261856000870466, 1.9054609537124634, 0.23441679863026366, 0.233764807053376, 0.3970809490419924, 0.10074272504425608, 1.0442843078635633, 1.6335782990790904, 0.7601409580092877, 2.4030162300914526, 3.814969640225172, 4.158586151897907, 3.3645125990733504, 6.033275406807661, 4.781438279896975, 8.816413264721632, 9.768333435058594, 6.3022472988814116, 4.307827893644571, 2.9068323830142617, 3.7096668407320976, 3.957658871077001, 7.864642711356282, 18.279342837631702, 33.77213940024376, 48.05388584733009, 43.7743578851223, 51.38807773590088, 45.44668234884739, 56.8475715816021, 37.144625633955, 22.673835530877113, 37.383146435022354, 48.15539360046387, 51.93128898739815, 50.27801290154457, 31.543975062668324, 30.72426024824381, 24.429692812263966, 15.629815310239792, 8.2090263068676, 4.171868339180946, 3.341440949589014, 6.721704890951514, 5.299059329554439, 4.0511915646493435, 5.518765915185213, 3.8451162725687027, 7.452405206859112, 6.101305056363344, 8.790666796267033, 6.818367904052138, 4.698710544034839, 5.417671389877796, 3.4466067189350724, 0.615759986685589, 0.6719057739246637, 0.2941282343817875, 0.30111303145531565, 0.2386090869549662, 0.7193582213949412, 3.4341813856735826, 5.98450074903667, 12.52079363912344, 13.97911548614502, 30.305991992354393, 31.154089383780956, 11.856074407696724, 22.309530079364777, 36.46018736064434, 31.572969406843185, 15.885387696325779, 3.7933262391015887, 0.1136851793853566, 0.062405246280832216, 0.04225035219860729, 0.047052915979293175, 0.05206248701142613, 0.017776082568161655, 0.008251199724327307, 0.06524220225401223, 0.026213544661004562, 0.04731564367830288, 0.059988553693983704, 0.04042269109049812, 0.04632433847291395, 0.021845829323865473, 0.08294989034766331, 0.039280102791963145, 0.06672905059531331, 0.04000522931164596, 0.06342168431729078, 0.059227447854937054, 0.007671616713196272, 0.02148498228052631, 0.014898810350132408, 0.0359510286943987, 0.06435510571463965, 0.013894468393118586, 0.019153410321450792, 0.0035906361608795123, 0.10065699214464985, 0.048949971605907194, 0.01579001560457982, 0.0830632756697014, 0.062360145966522396, 0.010282878156431252, 0.020392843325680587, 0.01226634389240644, 0.03012656838109251, 0.05511318893695716, 0.02544781338656321, 0.028654165944317356, 0.07650370695046149, 0.04198726455797441, 0.14513600268401206, 0.08300903951749206, 0.16916347900405526, 0.262826582766138, 0.1723893723101355, 0.22870849556056783, 0.10347311603254639, 0.12254372122697532, 0.11526110029080883, 0.20296594564570114, 0.15327390428865328, 0.25145302119199187, 0.26018720876891166, 0.11936273527680896, 0.1438003298244439, 0.13596405187854543, 0.20338643167633563, 0.1565571062383242, 0.18659922934602946, 0.10693320888094604, 0.1342160566127859, 0.04380460610263981, 0.16951580619206652, 0.12031826525344513, 0.2260354725876823, 0.12979707185877487, 0.12360753054963425, 0.19674095936352387, 0.17785520089091733, 0.12379197651171125, 0.13297831756062806, 0.14173356728861108, 0.08312376812682487, 0.11829879236756824, 0.2804646722506732, 0.10294412801158614, 0.1241175047471188, 0.11401806972571649, 0.14394685946172103, 0.13712325686356053, 0.1297685140161775, 0.11533463228261098, 0.11434275191277266, 0.1287866081111133, 0.17408089013770223, 0.2027765050297603, 0.18236518779303879, 1.1961031425744295, 9.94931012392044, 27.59885385632515, 49.63810823857784, 54.09338817000389, 48.14352683722973, 38.3986609429121, 36.481534615159035, 21.676962822675705, 34.21238757669926, 32.96313241124153, 29.712034463882446, 19.951952286064625, 12.11151760071516, 7.121137557551265, 2.825977709144354, 0.617689392529428, 0.7929460820741951, 1.8564160354435444, 4.1240583546459675, 2.2389094484969974, 3.48385208286345, 4.775677789002657, 6.391232348978519, 7.663169447332621, 14.547558333724737, 11.474774368107319, 11.967237442731857, 15.260414332151413, 14.857729990035295, 9.959769062697887, 10.248357877135277, 3.872754327021539, 3.4310287423431873, 3.459350522607565, 3.4798501851037145, 10.857663732022047, 18.06833256036043, 36.58871926367283, 49.41735528409481, 49.422435611486435, 52.36764617264271, 46.79029785096645, 52.5476311147213, 41.871606186032295, 31.664314605295658, 42.202488631010056, 51.15027129650116, 55.540206134319305, 54.21484485268593, 35.590254440903664, 32.11608946323395, 25.578346475958824, 14.217205960303545, 10.064930319786072, 3.2373771211132407, 4.5819584839046, 8.922179639339447, 7.832536334171891, 6.219468740746379, 9.836638569831848, 12.632454447448254, 11.767551507800817, 14.171046037226915, 21.444679386913776, 15.609613694250584, 12.358395103365183, 9.231025166809559, 6.39816127717495, 4.606149410828948, 2.2137531358748674, 0.8330616576131433, 0.6202607264276594, 0.6452067440841347, 1.7324153892695904, 3.5616369964554906, 10.137568172067404, 16.385241374373436, 22.23058171570301, 46.11717537045479, 33.63841697573662, 15.415063183754683, 29.478744082152843, 43.39122824370861, 35.69109722971916, 19.84562449157238, 4.223478119820356, 0.2879694476723671, 0.15948948013829067, 0.24963562027551234, 0.16127630457049236, 0.12788529944373295, 0.16168803325854242, 0.2116379264043644, 0.13371472101425752, 0.13847230322426185, 0.12024700423353352, 0.1964153494918719, 0.20556257193675265, 0.15974031121004373, 0.09865541986073367, 0.12348314659902826, 0.10019328343332745, 0.22911406442290172, 0.1875282943365164, 0.1511154865147546, 0.22867190768010914, 0.11591614951612428, 0.10721925485995598, 0.13739397749304771, 0.10401732550235465, 0.12831237574573606, 0.12113703225622885, 0.06814096428570338, 0.13774326187558472, 0.31878223177045584, 0.13784216047497466, 0.09702389725134708, 0.22764179186196998, 0.11974537177593447, 0.14130373019725084, 0.10515867441426963, 0.17218027962371707, 0.09115078544709831, 0.15372091467725113, 0.12093667464796454, 0.17862492677522823, 0.13438373745884746, 0.14278563583502546], [0.014045077987248078, 0.04794231688720174, 0.032221424917224795, 0.017019179140334018, 0.04552125676127616, 0.007263544957822887, 0.1056999598222319, 0.05045197831350379, 0.035348660821910016, 0.02109280918375589, 0.0347132785100257, 0.04035780882986728, 0.09724675677716732, 0.02948439541796688, 0.0394974258961156, 0.04893834957329091, 0.03291553337476216, 0.11766318741138093, 0.019272105710115284, 0.028423597359505948, 0.06329841358819976, 0.01706362822005758, 0.034671005778363906, 0.0037085003441461595, 0.03215437558537815, 0.05651978884998243, 0.05682416587660555, 0.028286118213145528, 0.028202246248838492, 0.03677368084026966, 0.03296297887573019, 0.024565700368839316, 0.07230342569528148, 0.03617521666456014, 0.037467392248800024, 0.07613378344103694, 0.051626208078232594, 0.04038147220853716, 0.0636775248858612, 0.07091104533174075, 0.04432840280060191, 0.009310353925684467, 0.01961907088116277, 0.05170864584215451, 0.07570305577246472, 0.01460696727008326, 0.07493934128433466, 0.038075515476521105, 0.8462112082634121, 6.012354204431176, 16.51523619890213, 33.4799312800169, 42.040210738778114, 33.25488455593586, 32.54559561610222, 20.8321313560009, 12.75651779025793, 25.05571112036705, 26.88173733651638, 30.128427520394325, 15.901708770543337, 11.949989218264818, 5.8447931706905365, 2.2103487560525537, 0.5382472928613424, 0.6316766794770956, 0.37468456488568336, 0.23482705786591396, 0.9879852819722146, 0.25911881297361106, 2.2191920690238476, 1.0289790853857994, 3.0806402815505862, 4.385727513581514, 4.320376720279455, 5.277951937168837, 5.5359466932713985, 10.224130377173424, 3.172713378444314, 3.131297738291323, 1.7015787377022207, 2.5535985874012113, 1.982981781475246, 1.202362950425595, 8.149592746049166, 17.80004035681486, 34.367366060614586, 36.25464878976345, 40.767035856842995, 35.79971060156822, 37.151944041252136, 15.134357046335936, 16.97847694158554, 26.50953020900488, 32.542882561683655, 32.50505939126015, 34.053924679756165, 19.133119024336338, 17.997665852308273, 14.596153926104307, 11.68030058965087, 3.7967918906360865, 2.42723043076694, 0.8110904647037387, 7.517803497612476, 5.292540304362774, 2.1254071639850736, 5.926854992285371, 2.859802544116974, 7.02564250677824, 4.269456127658486, 9.816693440079689, 8.2842318713665, 4.304477423429489, 3.747173440642655, 2.134919003583491, 1.06175767024979, 0.8074015751481056, 0.3711044741794467, 0.6299190362915397, 0.6755950790829957, 4.2892782390117645, 9.350162073969841, 14.22780454158783, 14.58303987979889, 28.490462712943554, 32.14380897581577, 6.6091283317655325, 25.24081438779831, 27.940136343240738, 30.799196027219296, 18.00624769181013, 3.897075871936977, 0.3052544529782608, 0.04292516110581346, 0.0277746560095693, 0.01115322535042651, 0.04190815903712064, 0.02226983313448727, 0.06132219306891784, 0.067928183125332, 0.07367533020442352, 0.061382410931400955, 0.032067581414594315, 0.016016823356039822, 0.02346819939702982, 0.07142355767427944, 0.041077194837271236, 0.052152283169562, 0.01814543647924438, 0.07354017769102938, 0.0209749097484746, 0.0204122059585643, 0.01722719014651375, 0.06137154960015323, 0.054087655880721286, 0.019592249664128758, 0.019931136557715945, 0.015182824699877528, 0.03456436286796816, 0.06872978425235488, 0.06035482954757754, 0.0145566747050907, 0.027747315289161634, 0.00603808427513286, 0.11754010964068584, 0.05088439065730199, 0.023951307848619763, 0.049356260351487435, 0.023934956479934044, 0.06234547370695509, 0.05443399022624362, 0.034128937404602766, 0.019525641910149716, 0.01586980390129611, 0.056227148888865486, 0.07437729058437981, 0.047131249666563235, 0.01357194121737848, 0.08641595748485997, 0.07271533249877393, 0.07053551118588075, 0.037821593359694816, 0.03433417463384103, 0.01157575043180259, 0.035907494311686605, 0.035635118692880496, 0.02233900871942751, 0.06890697201015428, 0.01885161967948079, 0.015376294250017963, 0.04111567519430537, 0.02908873608248541, 0.0660876049369108, 0.018795771211443935, 0.10005506585002877, 0.03847816027700901, 0.01841584911744576, 0.03241391576011665, 0.08915654558222741, 0.04342454114521388, 0.03869048501655925, 0.04402403690619394, 0.0737997364194598, 0.030834085591777693, 0.01072458311682567, 0.01250478202564409, 0.05510684357432183, 0.05105441297928337, 0.024642278876854107, 0.08992379269329831, 0.10406106026493944, 0.06821065937401727, 0.020001666562166065, 0.057077327292063273, 0.0625594200391788, 0.05068097168987151, 0.03159462183248252, 0.028516538368421607, 0.019759926799451932, 0.025778442031878512, 0.034678085867199115, 0.08806394092971459, 0.012182444097561529, 1.0974541422910988, 7.6082452945411205, 22.719338089227676, 40.17281614243984, 46.640730276703835, 37.38009139895439, 32.204514518380165, 21.418559588491917, 18.29780414700508, 23.61727360635996, 25.66024348139763, 27.084701545536518, 16.16305399686098, 14.256267864257097, 6.03178683668375, 2.883534408174455, 0.49267761467490345, 0.36363624210935086, 0.050528794308775105, 0.23531604412710294, 0.1211585545388516, 0.6673182325903326, 0.4166245769010857, 0.9344057226553559, 1.5440808702260256, 1.182618378661573, 3.0517784552648664, 5.642089247703552, 7.070805933326483, 8.326041027903557, 7.331717507913709, 7.586173703894019, 4.9802540615201, 3.000836013816297, 2.5611088844016194, 1.8466424848884344, 9.794545378535986, 21.258941553533077, 37.54618048667908, 39.67994838953018, 42.41128362715244, 38.28160062432289, 42.685279324650764, 19.257467351853848, 19.274100959300995, 33.70278552174568, 36.84704840183258, 38.9540733397007, 37.49008409678936, 25.493244342505932, 18.933209851384163, 17.513197548687458, 11.711355373263359, 4.614446265622973, 2.388724246993661, 3.5210805851966143, 9.286706428974867, 5.155232772231102, 7.024669758975506, 6.3720818515866995, 6.1308845691382885, 5.0626374408602715, 3.852467928081751, 5.567946201190352, 5.5689246486872435, 3.6835356429219246, 2.4731464544311166, 1.5287952404469252, 0.2542253880528733, 0.3723271773196757, 0.09216421778546646, 0.38492569816298783, 1.0782738402485847, 4.619853375479579, 10.245357938110828, 15.213121119886637, 17.08873752504587, 23.382590599358082, 38.451633900403976, 12.926917746663094, 21.62902269512415, 31.7395106703043, 35.740012004971504, 22.522037476301193, 5.10865249671042, 0.2820944582344964, 0.036523970411508344, 0.08918491788790561, 0.02835302468156442, 0.06786263664253056, 0.015415795060107484, 0.053986701532267034, 0.07281820158823393, 0.019703195175679866, 0.019553481724869926, 0.007362225087490515, 0.03816527452727314, 0.03845481973257847, 0.06709293302264996, 0.02757792935881298, 0.027771496315835975, 0.06588839023606852, 0.030894229239493143, 0.011352981819072738, 0.01791309601685498, 0.06032168894307688, 0.0370740688231308, 0.022164008441905025, 0.014051560647203587, 0.03505368309561163, 0.04286406379833352, 0.06455073584220372, 0.051560179199441336, 0.03966278010921087, 0.01660809797613183, 0.06480224968981929, 0.04705564337200485, 0.0827163364738226, 0.04229769379890058, 0.048930152552202344, 0.046910512683098204, 0.06970111455302685, 0.009789486321096774, 0.04321820553741418, 0.04225368073093705, 0.037920903851045296, 0.02339006980037084, 0.018530759552959353, 0.14022335613844916, 0.24322745710378513, 0.2154502648045309, 0.2224476932315156, 0.1921616558684036, 0.0943892433133442, 0.2018406568095088, 0.17647830914938822, 0.06696244861814193, 0.1514982566004619, 0.113444693852216, 0.14732544223079458, 0.20515225332928821, 0.1502063704538159, 0.09364501020172611, 0.18406149989459664, 0.11880193880642764, 0.2179215571959503, 0.24435935105429962, 0.21281359222484753, 0.17881414474686608, 0.10072273158584721, 0.13956924201920629, 0.12373622637824155, 0.14602444251067936, 0.1041990403609816, 0.24295971990795806, 0.21430317166959867, 0.08409652335103601, 0.04407930093293544, 0.13864452601410449, 0.16892370593268424, 0.12214541056891903, 0.1187278724682983, 0.23503217264078557, 0.20076809014426544, 0.19066538225160912, 0.12854592961957678, 0.11800482025137171, 0.1602284811087884, 0.18850113119697198, 0.11786763425334357, 0.1419676109799184, 0.11256913028773852, 0.15561457868898287, 0.14848017948679626, 0.20756460435222834, 0.15533910831436515, 1.416780932340771, 8.015533089637756, 25.709167756140232, 46.07813246548176, 55.413224548101425, 46.13411106169224, 42.82472424209118, 30.898693688213825, 21.501153856515884, 36.2985098361969, 35.73738254606724, 40.65786771476269, 21.738369427621365, 17.416262850165367, 7.618918921798468, 3.488361253403127, 1.0768850147724152, 1.018385966308415, 1.0245748842135072, 1.2322535715065897, 3.3268005726858974, 2.6507133012637496, 5.103709911927581, 5.6462462246418, 7.2576238587498665, 11.535704098641872, 10.474177859723568, 11.281402744352818, 13.7777965888381, 21.742638498544693, 10.364103466272354, 9.03091175481677, 5.635336535051465, 4.652806632220745, 3.7239381624385715, 1.9005827279761434, 10.327807813882828, 21.780566163361073, 40.03229208290577, 41.168757900595665, 45.43396443128586, 41.17560513317585, 42.866164818406105, 23.990233093500137, 26.00125428289175, 37.26887136697769, 40.340333953499794, 42.043444365262985, 40.172690749168396, 25.706135518848896, 20.82283705472946, 16.267820075154305, 12.776719406247139, 5.093253348022699, 3.9683754835277796, 3.450983609072864, 12.951681967824697, 10.852451361715794, 8.431183286011219, 14.79335954412818, 11.485023368149996, 15.543919019401073, 11.713809091597795, 17.940545417368412, 16.537795588374138, 11.257444079965353, 7.269972721114755, 4.41951435059309, 1.5123368985950947, 1.433512147050351, 0.9072231687605381, 0.9374973317608237, 1.0609746747650206, 5.608528973534703, 13.448451161384583, 19.0569806098938, 23.25182631611824, 35.82028269767761, 44.30832423269749, 14.034943990409374, 33.01930479705334, 38.38745914399624, 40.182756409049034, 23.749369718134403, 6.349046062678099, 0.45893070520833135, 0.09613090805942193, 0.14206584164639935, 0.07116089676856063, 0.12443514395272359, 0.07458479507477023, 0.16692974808393046, 0.18067058263113722, 0.2164081993396394, 0.10243125943816267, 0.13874556199880317, 0.17693806963507086, 0.0636442618269939, 0.20593892986653373, 0.1228371961042285, 0.1210370723856613, 0.17344999039778486, 0.20012371300254017, 0.10818012829986401, 0.050399578976794146, 0.10660907588317059, 0.17851238750154153, 0.06370491755660623, 0.12612042773980647, 0.19548052543541417, 0.11350525310263038, 0.20377411477966234, 0.25901452638208866, 0.1400977253797464, 0.2040385568398051, 0.1436786027625203, 0.10067297058412805, 0.175601402297616, 0.14285320095950738, 0.10780770375276916, 0.1967344878357835, 0.16150555398780853, 0.09567350760335103, 0.18450813920935616, 0.17609095259103924, 0.1946705306181684, 0.15922416234388947, 0.18620170536451042], [0.030394439163501374, 0.025774163550522644, 0.04713586953585036, 0.02686458443349693, 0.08838705718517303, 0.01352235462036333, 0.07083532400429249, 0.048733034418546595, 0.0253943898860598, 0.023296837498492096, 0.040026484421105124, 0.04874641905189492, 0.05306417486281134, 0.09739368717418984, 0.021204149888944812, 0.0524422551097814, 0.06326943272142671, 0.058780159160960466, 0.10454617251525633, 0.06195121146447491, 0.015876995312282816, 0.06747458246536553, 0.04289357901143376, 0.07453712692949921, 0.05084170974441804, 0.014547682658303529, 0.04458493356651161, 0.02159479416150134, 0.05224541528150439, 0.016570497064094525, 0.12102047796361148, 0.05741480410506483, 0.04693681068602018, 0.013675029240403092, 0.02474566746968776, 0.12089347423170693, 0.05083594696770888, 0.08403286192333326, 0.05312675275490619, 0.08200147756724618, 0.10234315908746794, 0.02264037262648344, 0.04655009979614988, 0.036696842580568045, 0.009724790525069693, 0.04471265718166251, 0.04301493499951903, 0.053122210811125115, 0.04447694736882113, 0.678335385164246, 5.116323810070753, 19.26130134612322, 31.971294432878494, 43.26272293925285, 38.63452948629856, 31.52229342609644, 26.666317395865917, 39.11026015877724, 44.30186077952385, 29.27447084337473, 32.35059767961502, 19.738643132150173, 16.89004048705101, 8.993272874504328, 4.987881677225232, 1.6014980454929173, 0.6141323677729815, 0.5885844980366528, 0.13961411226773635, 0.23888589319540188, 0.5712504812981933, 1.607356381136924, 0.5729758855886757, 0.6887993705458939, 2.3437014129012823, 1.747746141627431, 6.330291219055653, 7.448209756985307, 7.443480910733342, 8.817898984998465, 5.8070117980241776, 3.89855541754514, 2.375490269623697, 0.5636462580878288, 1.965448334813118, 9.275906458497047, 19.076141081750393, 25.780754014849663, 29.8407069593668, 28.788093142211437, 14.564931001514196, 12.178023532032967, 15.967269502580166, 14.237494971603155, 16.399021334946156, 13.278941307216883, 25.464753471314907, 13.958058916032314, 9.01368347927928, 8.581969644874334, 8.697206061333418, 1.7589294165372849, 0.7198001851793379, 1.951061594299972, 7.4933218862861395, 3.9303924841806293, 4.283547196537256, 2.562242173589766, 2.4530025478452444, 4.0529717691242695, 2.9546981770545244, 3.327370067127049, 2.559526744298637, 1.6273215785622597, 4.2613848857581615, 2.333669951185584, 0.45016398187726736, 0.31524129677563906, 0.2820518292719498, 1.6979399579577148, 4.822231940925121, 7.242883499711752, 25.11365421116352, 27.399011179804802, 16.68757025152445, 38.85792709887028, 18.66434007883072, 21.523139476776123, 24.810626171529293, 27.874466367065907, 21.120294593274593, 7.149845967069268, 0.5677059839945287, 0.05361015064409003, 0.03614940476836637, 0.12809341249521822, 0.024185917427530512, 0.06048997092875652, 0.043110972619615495, 0.015985753343557008, 0.010047004143416416, 0.015039757181511959, 0.00396610907955619, 0.010594416908134008, 0.03594679474190343, 0.04534660343779251, 0.003924153152183862, 0.03051720337680308, 0.021721053890360054, 0.06550130085088313, 0.03942207564250566, 0.00971116469372646, 0.011909980348718818, 0.011655330927169416, 0.06693988732877187, 0.066165552707389, 0.025394432559551205, 0.06358384358463809, 0.037271710170898587, 0.06782616008422337, 0.13376454880926758, 0.017552198878547642, 0.029210099492047448, 0.02813120972859906, 0.03978250337240752, 0.02355663000344066, 0.034196079504908994, 0.014764522438781569, 0.05513229552889243, 0.02473613087204285, 0.09127041965257376, 0.06519664922961965, 0.05765442874690052, 0.0398898253479274, 0.031376923943753354, 0.033418921011616476, 0.037711655313614756, 0.02474985689332243, 0.01735115107294405, 0.04931967247102875, 0.06508985417895019, 0.0472205819824012, 0.03414636303205043, 0.04029487470688764, 0.07690916449064389, 0.022470777039416134, 0.05147778596438002, 0.06855977306258865, 0.059691742862924, 0.06914704936207272, 0.07247039407957345, 0.043707907971111126, 0.05233017596765421, 0.011656851402221946, 0.029280141534400173, 0.043567155953496695, 0.01442147951820516, 0.03846794832497835, 0.06426348016248085, 0.04569422912027221, 0.056233872746815905, 0.026184101807302795, 0.03691854435601272, 0.04962537423125468, 0.08219797600759193, 0.05681613583874423, 0.08531009065336548, 0.05895161011721939, 0.048774509341455996, 0.03520804239087738, 0.05105672848003451, 0.060775193123845384, 0.058543068953440525, 0.046796077222097665, 0.026526261572143994, 0.06831988124758936, 0.05413261147623416, 0.02661149908817606, 0.05889108055271208, 0.021670892128895503, 0.028058848474756815, 0.026512960430409294, 0.04725775244878605, 0.061391947529045865, 0.04584589441947173, 1.0575169790536165, 7.377210091799498, 23.792520202696323, 37.17916198074818, 46.44774243235588, 41.79486930370331, 31.370920948684216, 26.387704946100712, 38.03313955664635, 44.92031939327717, 35.0943848490715, 34.54043537378311, 21.521359272301197, 16.09834346920252, 8.109792731702328, 4.506366765126586, 1.7529452126473188, 0.5455717560835183, 0.455308846430853, 0.06045091911801137, 0.21838474640389904, 0.8444796886760741, 0.4004277678905055, 1.511957987677306, 1.8355107447132468, 2.3422544030472636, 2.2136265551671386, 4.07586601562798, 5.388318439945579, 8.519681487232447, 7.128387093544006, 7.3245330434292555, 5.774055691435933, 4.039973616600037, 1.940829218365252, 2.157700681127608, 11.934090871363878, 23.700639232993126, 29.982673041522503, 33.238819018006325, 33.75625245273113, 20.562076047062874, 15.768967643380165, 20.216786675155163, 20.846222899854183, 21.96892585605383, 20.992824733257294, 27.425862438976765, 16.516533829271793, 11.538746785372496, 9.746301267296076, 7.352484343573451, 4.011260457336903, 1.6810297966003418, 2.998506026342511, 9.62905190885067, 5.5422833282500505, 5.631858771666884, 3.5903397062793374, 4.570098370313644, 5.2874338533729315, 1.4995496347546577, 1.871454322244972, 2.9095720360055566, 0.6062843045219779, 1.2449852633289993, 0.1098612709029112, 0.17146358761237934, 0.1656965955044143, 0.5619935248978436, 1.7099067033268511, 5.41223768144846, 9.700025450438261, 29.535117857158184, 27.29572892189026, 16.88640598207712, 39.97519254684448, 24.587243758141994, 20.093118511140347, 28.644673638045788, 31.009400747716427, 25.145091824233532, 8.282946590334177, 0.899957602377981, 0.013245305326563539, 0.12198153694043867, 0.05479939776705578, 0.046982753337942995, 0.055290632735705, 0.08935072110034525, 0.03896428184816614, 0.10388123046141118, 0.008862437189236516, 0.028843775398854632, 0.03752591059310362, 0.052746472574654035, 0.07203452332760207, 0.042409861998748966, 0.047049520653672516, 0.005830160471305135, 0.044647875110968016, 0.03433245656196959, 0.04562026297207922, 0.061327269359026104, 0.052296931462478824, 0.06420646837796085, 0.017471547835157253, 0.042800632436410524, 0.042817126668524, 0.035302825781400315, 0.044036824110662565, 0.027991283350274898, 0.03819754310825374, 0.02834887050994439, 0.058371139311930165, 0.02322988093510503, 0.030901854806870688, 0.04718609809060581, 0.033620684989728034, 0.03397808104637079, 0.0625692683388479, 0.041637542308308184, 0.0539972660044441, 0.07669965620152652, 0.0353460521728266, 0.028466983312682714, 0.04251988539181184, 0.12012928476906382, 0.17694471927825361, 0.1747510940185748, 0.12775477051036432, 0.11554641896509565, 0.10036224077339284, 0.1159587042639032, 0.09809352501179092, 0.16712154872948304, 0.1805226132273674, 0.12384207147988491, 0.28736379579640925, 0.10556284061749466, 0.24325142847374082, 0.2647588978288695, 0.1644852026947774, 0.12303580966545269, 0.16087411990156397, 0.1091845212795306, 0.15048333996674046, 0.043155842868145555, 0.1641918910900131, 0.1837533453362994, 0.1958167925477028, 0.21520679583773017, 0.13243375928141177, 0.1315841931500472, 0.1447223444120027, 0.17470145918196067, 0.1046302801114507, 0.16840849217260256, 0.17352993454551324, 0.1068353492883034, 0.11217475301236846, 0.18289395316969603, 0.2615735406288877, 0.2268252958310768, 0.23483936267439276, 0.287008099257946, 0.21487371996045113, 0.33999955106992275, 0.17070466739824042, 0.2296746679348871, 0.18981410918058828, 0.05558547687542159, 0.18806139385560527, 0.1643339084694162, 0.13277811580337584, 0.06029627409589011, 1.2073806999251246, 8.337515462189913, 25.98938561975956, 43.18400636315346, 54.89789240062237, 52.71919570863247, 42.678865268826485, 37.541882917284966, 50.45584715902805, 52.07939364016056, 37.728152722120285, 40.097014009952545, 26.501372046768665, 23.322859704494476, 11.503335535526276, 6.6499770898371935, 2.3651902098208666, 1.1559753958135843, 1.156839255709201, 0.626556632341817, 1.6837233770638704, 3.2303888211026788, 4.585342202335596, 4.772810367867351, 4.48789500631392, 7.75081411935389, 8.464075271040201, 14.0933839045465, 15.769038889557123, 15.746755935251713, 18.892599530518055, 14.657491184771061, 10.050961319357157, 5.6333316676318645, 1.882834117859602, 2.9459904693067074, 12.83733470365405, 23.412854075431824, 29.05001498758793, 32.44018167257309, 32.86925084888935, 19.13294803351164, 18.481539487838745, 21.17018211632967, 22.91501808911562, 21.30356825888157, 24.74512528628111, 32.032581344246864, 19.404384568333626, 13.199639562517405, 11.253662332892418, 10.326212849467993, 3.025037865154445, 3.9070795476436615, 4.854071382433176, 14.797800555825233, 12.084414605051279, 12.234113272279501, 9.853699654340744, 8.318175449967384, 10.146605987101793, 7.784891165792942, 8.587636090815067, 7.8168161027133465, 4.670457635074854, 6.435153242200613, 4.04706166125834, 0.8583155774977058, 0.6125140702351928, 0.6992284453008324, 2.5080186082050204, 7.045367723330855, 8.918771222233772, 33.31399418413639, 33.132751509547234, 25.90283576399088, 48.96344684064388, 28.122089579701424, 30.465760119259357, 35.502608343958855, 36.473292857408524, 27.60266125202179, 10.351328551769257, 1.055267381016165, 0.1670650564483367, 0.42009316734038293, 0.25740810320712626, 0.15673477639211342, 0.14079697692068294, 0.16641682013869286, 0.11206354960449971, 0.16469031746964902, 0.1625380595214665, 0.15064751787576824, 0.07224124114145525, 0.17573243589140475, 0.12734311603708193, 0.14571259205695242, 0.1401900188648142, 0.07547147601144388, 0.11122444033389911, 0.10446455111377873, 0.13119983486831188, 0.09814002056373283, 0.147082032635808, 0.1141191205533687, 0.1299206691328436, 0.1527267781784758, 0.12964237859705463, 0.14794283488299698, 0.1458333246409893, 0.20358096342533827, 0.11759215645724908, 0.14295928354840726, 0.15283151005860418, 0.09744396767928265, 0.09123596173594706, 0.10248676466289908, 0.21460592339280993, 0.144835373503156, 0.1607979607069865, 0.15651964262360707, 0.2379334653960541, 0.18296136986464262, 0.07544181979028508, 0.1481079330551438, 0.2303547423798591], [0.020270197856007144, 0.013261531457828823, 0.06657008998445235, 0.027958966529695317, 0.05700376561435405, 0.06206801437656395, 0.047916156181599945, 0.07853203365812078, 0.03406401061511133, 0.03237928343878593, 0.05452102930576075, 0.021664010564563796, 0.05036653114075307, 0.07567728098365478, 0.022600072152272332, 0.037830176297575235, 0.025946829773602076, 0.043721515248762444, 0.006578997681572218, 0.04214046610286459, 0.018753830590867437, 0.022336216388794128, 0.0416405702708289, 0.041805857690633275, 0.05927389516727999, 0.04269554432539735, 0.03453425022598822, 0.045511549469665624, 0.024267433072964195, 0.048915558218141086, 0.04191746927972417, 0.015439909293490928, 0.018675231585802976, 0.061048626303090714, 0.05132527461682912, 0.033633275525062345, 0.1002335078374017, 0.05200328589126002, 0.10073804209241644, 0.005045388006692519, 0.022820959420641884, 0.11861554099596106, 0.017093622118409257, 0.060329763509798795, 0.02806604916258948, 0.011936707869608654, 0.0743401535146404, 0.03894192836014554, 0.06127996486611664, 0.0413629254035186, 0.6926828215364367, 4.3149857595562935, 16.075537092983723, 26.990895979106426, 44.567842707037926, 43.240307942032814, 39.67299856245518, 27.20585234463215, 17.29648567736149, 15.45186135917902, 17.207256965339184, 14.733299016952515, 13.847952224314213, 16.747901514172554, 9.17434360831976, 6.200739545747638, 2.3672145511955023, 1.17721245624125, 0.42894075508229434, 0.16476910386700183, 0.18299068469787017, 0.07243290077894926, 0.9270111413206905, 1.1439528409391642, 1.567244071047753, 2.9110359074547887, 2.2005963418632746, 2.9651483288034797, 6.852655364200473, 5.73390799574554, 3.398404405452311, 3.868496655486524, 2.4435823783278465, 1.8799504288472235, 0.5460105731617659, 2.381025147624314, 8.299707490950823, 17.50811532139778, 17.17533677816391, 14.443272929638624, 7.593282172456384, 5.868678689002991, 7.104968475177884, 7.604165263473988, 6.775155672803521, 3.1640522181987762, 8.8175000064075, 4.9193718284368515, 2.4684660555794835, 4.2164024244993925, 1.900182799436152, 2.2134016547352076, 1.993125337176025, 6.076658628880978, 9.78855499997735, 3.2461009779945016, 6.758880196139216, 2.55340242292732, 4.364616321399808, 1.6230705566704273, 1.41906009754166, 1.7782231187447906, 2.020479356870055, 0.197950882720761, 0.44649130082689226, 0.1867127779405564, 0.5653249961324036, 0.4387127619702369, 3.1500594690442085, 3.940968504175544, 11.33037831634283, 8.003776520490646, 27.160596773028374, 33.32322768867016, 29.434250369668007, 28.097094520926476, 24.405096732079983, 34.200953990221024, 30.006934739649296, 18.729098103940487, 6.618040753528476, 1.3063433021306992, 0.043245479464530945, 0.0418301964236889, 0.02226058040832868, 0.06065113571821712, 0.1475815722369589, 0.06094840668083634, 0.05197650178160984, 0.07065442550810985, 0.021109522349433973, 0.045201498724054545, 0.015703124954598024, 0.035545801219996065, 0.05857554904650897, 0.010971734063787153, 0.04998973905458115, 0.024483576162310783, 0.018820824261638336, 0.0461433546297485, 0.02811562462738948, 0.03042997504962841, 0.022529718407895416, 0.048384837282355875, 0.03543992272170726, 0.07393828054773621, 0.04308077091991436, 0.04517623230640311, 0.042716216848930344, 0.020286781145841815, 0.01583877470693551, 0.02618121670820983, 0.05317849158018362, 0.040947333836811595, 0.02524888997868402, 0.01604125300218584, 0.027794679153885227, 0.029539722527260892, 0.02766169185633771, 0.044255334651097655, 0.10983518441207707, 0.009240400013368344, 0.04205347897368483, 0.05278810334857553, 0.05301777579006739, 0.05592195921053644, 0.017186581681016833, 0.07577492535347119, 0.06950053430045955, 0.07608791871462017, 0.0716095176176168, 0.16813244292279705, 0.05543894352740608, 0.13933116104453802, 0.07373308413662016, 0.0294203851808561, 0.04527292672719341, 0.02257853131595766, 0.023240155969688203, 0.021443167825054843, 0.07990355967194773, 0.012904244867968373, 0.031034337443998083, 0.08844705240335315, 0.03249714762205258, 0.01265960145246936, 0.02965049548947718, 0.07378614027402364, 0.06725434272084385, 0.024192657983803656, 0.009543779779050965, 0.05413121994934045, 0.05840112949954346, 0.07976810287800618, 0.023031193159113172, 0.03980202927778009, 0.0314558365062112, 0.04262314781954046, 0.02392883376160171, 0.05072969368484337, 0.017760796181391925, 0.01918233923788648, 0.06362437969073653, 0.08162080775946379, 0.0208270906296093, 0.01817870510421926, 0.030952218803577125, 0.08703292711288668, 0.07862102458602749, 0.05771731463028118, 0.02474333712598309, 0.0885372752964031, 0.01705771701381309, 0.0715897096961271, 0.04703928643721156, 0.03145718350424431, 1.1390468291938305, 6.78612045943737, 20.86794823408127, 33.92190456390381, 47.69413635134697, 46.541369408369064, 42.766408771276474, 32.3602681607008, 21.474655978381634, 19.30925477296114, 26.072388365864754, 23.03581740707159, 20.87643887847662, 21.437568068504333, 9.975478369742632, 5.274908300489187, 3.0139032751321793, 0.8257377881091088, 0.30622262915130705, 0.12474513903725892, 0.09378535032738, 0.134249898546841, 0.6414920277893543, 0.5581369693391025, 1.1478393198922276, 1.863469525706023, 2.8945920523256063, 3.039240315556526, 7.281171195209026, 3.60835287719965, 5.367490807548165, 5.662418156862259, 5.534115666523576, 2.874370962381363, 1.1917200777679682, 4.040159806609154, 10.11238882318139, 18.354989178478718, 21.193809248507023, 17.442717030644417, 9.427066147327423, 9.317671917378902, 11.015997435897589, 12.183390744030476, 8.89203680679202, 5.970689440146089, 10.717402808368206, 7.50948621891439, 4.163359645754099, 5.974340569227934, 3.0759425461292267, 3.469396233558655, 1.6748651023954153, 4.497931692749262, 10.64900552853942, 4.4673908315598965, 5.942458380013704, 4.176111286506057, 3.680190872400999, 1.7975709680467844, 1.6261257114820182, 0.9003882855176926, 0.5549396784044802, 0.2474074554629624, 0.29975127952639014, 0.11487581432447769, 0.5332426051609218, 0.4790494084591046, 3.205818389542401, 4.121677307412028, 15.8449312672019, 9.959841258823872, 32.55438074469566, 35.869934633374214, 28.577356450259686, 33.758148550987244, 27.903888188302517, 35.747626796364784, 34.286080822348595, 23.07549487799406, 7.629686119034886, 1.8719215784221888, 0.038803206116426736, 0.05473944707773626, 0.029130340881238226, 0.08603805588791147, 0.09893862341414206, 0.05250478847301565, 0.00895526409294689, 0.014535513291775715, 0.051545380774769, 0.018020341922238003, 0.06828617290011607, 0.03892629130859859, 0.07138095839763992, 0.030735166583326645, 0.04105618834728375, 0.04711586865596473, 0.07198582359706052, 0.04735545619041659, 0.003583437792258337, 0.03823078019195236, 0.06571135090780444, 0.028408798934833612, 0.0023241764574777335, 0.09082044067326933, 0.03472065545793157, 0.0407092380191898, 0.05258511482679751, 0.017982954377657734, 0.0391120434505865, 0.05762941094872076, 0.04517567569564562, 0.06716630916344002, 0.003060964900214458, 0.028879127603431698, 0.03262016602093354, 0.02205482182034757, 0.04193880973616615, 0.038728887448087335, 0.04566941541270353, 0.08599995402619243, 0.02051950566965388, 0.12517703929916024, 0.050719418650260195, 0.04768729268107563, 0.10256315392325632, 0.09512870441540144, 0.1260793869732879, 0.27179914817679673, 0.3370482969330624, 0.18570696003735065, 0.1663139881566167, 0.18538135016569868, 0.11117232672404498, 0.1074910516035743, 0.08617950181360357, 0.09332219822681509, 0.20836514420807362, 0.16584376338869333, 0.12238669762155041, 0.12084961330401711, 0.1586987217888236, 0.20490914059337229, 0.1319458565558307, 0.12045402632793412, 0.12732747156405821, 0.13683022727491334, 0.15360457560746, 0.2543653274187818, 0.13120819145115092, 0.2114753663772717, 0.14342763810418546, 0.1379239748348482, 0.12065906688803807, 0.2706639590905979, 0.22005515755154192, 0.18414243852021173, 0.14240877324482426, 0.12610571837285534, 0.07932835069368593, 0.15297676320187747, 0.1974292568047531, 0.20234717259882018, 0.1249527622712776, 0.10571500315563753, 0.12703886517556384, 0.23175431415438652, 0.168203629727941, 0.15839199215406552, 0.15844685171032324, 0.09945507656084374, 0.14440427476074547, 0.14176093769492581, 0.15666983847040683, 0.1246357019408606, 1.3251049141399562, 7.0984057523310184, 24.065461456775665, 39.085656479001045, 56.154344379901886, 55.99536091089249, 51.16975665092468, 36.382534727454185, 25.49993198364973, 25.99033746868372, 27.582385540008545, 25.72089582681656, 21.653537079691887, 24.749363958835602, 13.031943161040545, 8.694948982447386, 3.3588309539481997, 2.03155315015465, 0.8215936948545277, 0.6298243382479995, 0.3460142423864454, 0.7716748234815896, 2.427103375084698, 3.473695465363562, 3.725147685036063, 6.603048657998443, 6.73668653704226, 7.9933346807956696, 15.142586454749107, 11.83443171903491, 12.3052435554564, 10.152167938649654, 6.093756761401892, 4.484388269484043, 2.7201151521876454, 3.569863080047071, 11.934363506734371, 21.46770615130663, 19.774368815124035, 18.7351967766881, 11.440309267491102, 8.67997208610177, 10.143837835639715, 11.166905388236046, 10.071280729025602, 6.234621852636337, 13.089107293635607, 7.657003803178668, 4.824400199577212, 5.37851401604712, 3.9694007160142064, 4.120340254157782, 2.501458735205233, 17.598208487033844, 23.34914669394493, 7.424025479704142, 13.94594706594944, 10.057094190269709, 11.08883572742343, 8.01462683826685, 5.911633484065533, 4.3413458950817585, 4.9585985485464334, 1.7395989038050175, 1.3464638055302203, 0.3766359679866582, 0.9385422756895423, 0.8308588445652276, 4.287708448246121, 5.406533237546682, 16.91551622003317, 11.97674073278904, 36.635236367583275, 43.37147310376167, 37.30433106422424, 41.02957896888256, 34.65583898127079, 43.235824182629585, 39.97576631605625, 25.93144252896309, 8.670055568218231, 2.067672349512577, 0.14433543314225972, 0.0990013126283884, 0.10407282330561429, 0.15296714496798813, 0.22110402001999319, 0.17774500680388883, 0.13306710810866207, 0.11904309227247722, 0.14562390540959314, 0.10855231535970233, 0.13277051621116698, 0.14601290953578427, 0.17410146247129887, 0.191772889229469, 0.16380717657739297, 0.11123290823888965, 0.20474932651268318, 0.10185902647208422, 0.09920164797222242, 0.1270420860964805, 0.1722939618048258, 0.11405789337004535, 0.12712649797322229, 0.3133747656829655, 0.18012940854532644, 0.1932669957750477, 0.20489961141720414, 0.16488617024151608, 0.14328689721878618, 0.08904059242922813, 0.15181399590801448, 0.12827605503844097, 0.14567809703294188, 0.13867201516404748, 0.11634394570137374, 0.10820440395036712, 0.14108901203144342, 0.13128104066709056, 0.1901785482186824, 0.1366671032155864, 0.20704746100818738, 0.17475332046160474, 0.1132599807169754, 0.1500903134001419], [0.08655254234327003, 0.058858492848230526, 0.06898100124089979, 0.03288364699983504, 0.030055316638026852, 0.013524792575481115, 0.046436380507657304, 0.025130914473265875, 0.01761778989020968, 0.027412543604441453, 0.08373352407943457, 0.052682391833513975, 0.024290267101605423, 0.04259843430190813, 0.09643329613027163, 0.06815194807131775, 0.05752610770286992, 0.019181485768058337, 0.031811785374884494, 0.03694550658110529, 0.04589215990563389, 0.024755510203249287, 0.037792890798300505, 0.014786310039198725, 0.0384562743420247, 0.06009167140291538, 0.016748907510191202, 0.05112875020131469, 0.05762026768934447, 0.07539052996435203, 0.0171534577748389, 0.009406711596966488, 0.05271412977890577, 0.040055747303995304, 0.04703902297478635, 0.0495521576522151, 0.044363298584357835, 0.062233810167526826, 0.07603867721627466, 0.05020163705921732, 0.04879372354480438, 0.05237610748736188, 0.05694505431165453, 0.039646107761655, 0.037843649988644756, 0.06633102195337415, 0.062098887719912454, 0.05136877931363415, 0.10261825838824734, 0.03492166244541295, 0.04588032636092976, 0.2614644152345136, 4.4418595265597105, 17.04621210694313, 32.6461648195982, 39.381079226732254, 36.447328850626945, 30.889047905802727, 32.74428315460682, 27.4466872215271, 23.241857551038265, 19.58614021539688, 18.963380232453346, 17.550194263458252, 13.422675244510174, 10.2137341350317, 7.617610841989517, 4.873978989198804, 1.510575811844319, 1.0347172524780035, 0.41713027632795274, 0.478070248500444, 0.292631292832084, 0.21841924142790958, 0.6534968304913491, 0.4247795627452433, 1.9214811315760016, 3.594037857837975, 5.641519753262401, 2.938021346926689, 3.942231461405754, 5.663784183561802, 7.208382301032543, 3.397837048396468, 1.8319065193645656, 0.3145492885960266, 0.4843243269715458, 1.240539620630443, 4.211090784519911, 1.2730471137911081, 5.227261232212186, 4.458635626360774, 3.2873458648100495, 4.213997628539801, 1.5079253353178501, 2.4005743861198425, 1.436804432887584, 1.6027839202433825, 0.870658146450296, 1.5154294576495886, 0.6171243509743363, 0.905423074727878, 0.5039743788074702, 5.178026324138045, 9.845709633082151, 3.2519184658303857, 3.439209940843284, 2.1728233946487308, 1.6675925301387906, 2.1600995399057865, 0.23598734638653696, 0.05483801542141009, 0.2921230997890234, 0.1373286684975028, 0.6514574086759239, 0.6806048727594316, 1.3104050466790795, 2.7086609043180943, 6.713896309956908, 10.978473499417305, 10.371090341359377, 13.381053227931261, 33.36859345436096, 49.29329574108124, 26.52644880115986, 23.444386683404446, 28.935308642685413, 29.81309574097395, 16.673849187791348, 6.810718914493918, 1.2908625765703619, 0.0443603411258664, 0.08428698813077062, 0.020418870444700588, 0.017418179995729588, 0.020091703918296844, 0.038805673757451586, 0.034060299876728095, 0.0517053729709005, 0.01849907170253573, 0.04858963664446492, 0.01044709317284287, 0.052828869520453736, 0.02128399755747523, 0.030366716237040237, 0.022208854570635594, 0.0635536752815824, 0.021262033696984872, 0.048156389384530485, 0.02842114270606544, 0.043788123002741486, 0.04457168251974508, 0.012343009602773236, 0.04047996633744333, 0.035215504685766064, 0.030770496523473412, 0.06122617771325167, 0.01792638417100534, 0.1030572758463677, 0.03164378540532198, 0.025371897245349828, 0.05530190966965165, 0.04797804016561713, 0.02638453177496558, 0.05888586696528364, 0.03604149278544355, 0.01953218765265774, 0.03738403793249745, 0.06907448958372697, 0.04584306683682371, 0.09235531339072622, 0.04975186959200073, 0.028804087196476758, 0.03279174314229749, 0.039695571904303506, 0.02244324150524335, 0.04043292530695908, 0.03114805673249066, 0.09483988280408084, 0.03436453960603103, 0.026205961767118424, 0.0631183834047988, 0.020574717746058013, 0.06947454428882338, 0.09410557962837629, 0.045570327565656044, 0.07090867045917548, 0.03249318455345929, 0.06048091672710143, 0.04768681028508581, 0.07445589144481346, 0.09378359143738635, 0.07846006759791635, 0.0049524604492035, 0.05472745768202003, 0.024328083236468956, 0.03630926708865445, 0.0004216267348056135, 0.02480726943758782, 0.028104739176342264, 0.01694375281658722, 0.048006965371314436, 0.018752843534457497, 0.06916297585121356, 0.06371086215949617, 0.054646133139613084, 0.03276455827290192, 0.0739090696151834, 0.030369339729077183, 0.03911453335604165, 0.03647396821179427, 0.05244696403678972, 0.026335388611187227, 0.038104043633211404, 0.08928707451559603, 0.012879879232059466, 0.030035406671231613, 0.02759121936833253, 0.04969918452843558, 0.014350527417263947, 0.0365957101166714, 0.042398822552058846, 0.06946318200789392, 0.04801021597813815, 0.04110501795366872, 0.05043771794589702, 0.042054766599903814, 0.39366706972941756, 6.915266504511237, 20.67116629332304, 38.12611676752567, 45.334162786602974, 40.68105407059193, 31.95052094757557, 30.59659469872713, 24.83720574527979, 22.495454102754593, 21.110702008008957, 22.195095419883728, 21.841072216629982, 19.11500919610262, 14.815950281918049, 9.472390115261078, 7.008541524410248, 1.673040131572634, 0.6574622739572078, 0.17737350251991302, 0.0793979196168948, 0.026119649992324412, 0.06657650214037858, 0.3038837655913085, 0.9231811249628663, 1.1561760725453496, 1.5570059954188764, 2.081018420867622, 1.6428240342065692, 2.3101038532331586, 3.8241967326030135, 4.167690938338637, 3.1881080148741603, 1.8233367917127907, 1.4741920516826212, 2.384911389090121, 4.289734689518809, 6.914206836372614, 3.482814501039684, 3.702516811899841, 4.266980085521936, 4.782050997018814, 5.455403840169311, 4.009042326360941, 3.112269309349358, 3.66403057705611, 2.1614669915288687, 1.725720267277211, 2.225244431756437, 1.4438473549671471, 0.9808450494892895, 1.6011052415706217, 9.451193902641535, 5.829156534746289, 3.4315566765144467, 3.2672309316694736, 1.7677084892056882, 1.317653157748282, 1.6427485132589936, 0.6321682187262923, 0.09219687228323892, 0.18631466024089605, 0.03312530512630474, 0.4241188138257712, 0.5852976150345057, 1.5807297849096358, 2.557316687889397, 9.077943731099367, 16.027705259621143, 16.81141510605812, 13.468513134866953, 35.70343516767025, 49.9030452221632, 29.32515062391758, 30.76164834201336, 31.840953826904297, 36.065088361501694, 21.008113212883472, 8.596661556512117, 1.6045210207812488, 0.05361175739380997, 0.05086620803922415, 0.03010945816640742, 0.0516669965145411, 0.014084753202041611, 0.0643952187965624, 0.08389664813876152, 0.024539881051168777, 0.032021022780099884, 0.06859024564619176, 0.02648570320161525, 0.05725435919885058, 0.025289465047535487, 0.052053199033252895, 0.014220388111425564, 0.13065615232335404, 0.04168106184806675, 0.027981331149931066, 0.020560641060001217, 0.01930546153744217, 0.005014292019041022, 0.018849079679057468, 0.016529244785488117, 0.0032854536721060867, 0.07604153448482975, 0.013872178915335098, 0.005636289233734715, 0.07241349361720495, 0.012131563380535226, 0.03968441371398512, 0.04958096040354576, 0.032186414100578986, 0.04663232604798395, 0.009098857608478284, 0.17843038018327206, 0.022753490775357932, 0.0846511303097941, 0.06687674540444277, 0.03030511797987856, 0.03127451127511449, 0.04004996968433261, 0.01844641075877007, 0.06766032718587667, 0.004589816944644554, 0.040285378927364945, 0.16580910509219393, 0.12554679211461917, 0.176722475735005, 0.10939957341179252, 0.105919709749287, 0.17448913073167205, 0.1271852760692127, 0.15711205458501354, 0.23367862886516377, 0.2316299598896876, 0.2286535024177283, 0.1943011488765478, 0.14342210168251768, 0.12414408847689629, 0.21151875233044848, 0.14461425802437589, 0.18021766474703327, 0.14079170767217875, 0.15054648189106956, 0.23328393988776952, 0.06941103871213272, 0.11668067294522189, 0.09456737359869294, 0.1287227388820611, 0.20411297940881923, 0.09023232574691065, 0.10604047201923095, 0.2765707124490291, 0.17618855985347182, 0.14218172058463097, 0.09307090702350251, 0.10275439053657465, 0.08651606578496285, 0.1225579333549831, 0.12299010079004802, 0.16651125100906938, 0.15053336072014645, 0.28511351498309523, 0.1989534351741895, 0.14324659859994426, 0.11530110947205685, 0.16114446945721284, 0.11480482047772966, 0.1012424130749423, 0.19348879402969033, 0.20305249490775168, 0.16273198270937428, 0.24972666695248336, 0.12259879600605927, 0.12126503046602011, 0.19002916873432696, 0.6295247480738908, 6.868741801008582, 22.514510080218315, 42.33939528465271, 52.79370591044426, 47.74146281182766, 41.25147566199303, 43.727335408329964, 40.44983267784119, 33.73498499393463, 31.1975172534585, 29.75428819656372, 27.726490907371044, 21.936542093753815, 16.718266904354095, 11.355865448713303, 6.78201287984848, 2.2276117047294974, 1.360775618813932, 0.8080619084648788, 0.7963466621004045, 0.9425629943143576, 1.3148310966789722, 2.0752220693975687, 3.7971336347982287, 5.157250938937068, 6.85420710593462, 11.31552966311574, 8.234578985720873, 11.22476963326335, 11.92546533420682, 14.371142350137234, 8.689766060560942, 3.7587927421554923, 1.2515652040019631, 2.161626582965255, 3.6386296525597572, 6.950551886111498, 2.343460600823164, 6.33748565800488, 7.257137959823012, 4.951104875653982, 6.209694240242243, 2.6211563497781754, 4.455536417663097, 2.8820111649110913, 2.90830812882632, 2.611806713975966, 2.82296447083354, 1.1613019974902272, 7.751312367618084, 2.638608100824058, 13.399047162383795, 19.94609110057354, 9.884174969047308, 11.72155687585473, 5.883177760988474, 7.333475863561034, 5.441801520064473, 2.8033040883019567, 1.4457923755981028, 1.8430744763463736, 0.6276822625659406, 1.0765445767901838, 1.2677008006721735, 2.1138764452189207, 3.537244205363095, 9.760307315737009, 16.022011265158653, 19.13307722657919, 20.397715866565704, 43.72713781893253, 55.504499450325966, 35.45168727636337, 34.55498479306698, 39.61854748427868, 40.242576599121094, 23.382886983454227, 10.011105258017778, 1.9693956105038524, 0.1447075163014233, 0.19151656626490876, 0.05444383110443596, 0.19993715191958472, 0.17830020748078823, 0.1394940773025155, 0.1930357574019581, 0.12450582609744743, 0.10903596557909623, 0.18745522247627378, 0.08783410521573387, 0.188245372264646, 0.11092221553553827, 0.14202140184352174, 0.09154376748483628, 0.2183892735047266, 0.09712418366689235, 0.1206567588087637, 0.0958182560862042, 0.1956277378485538, 0.24411172606050968, 0.1533028480480425, 0.0725890338071622, 0.12052165082423016, 0.17464904871303588, 0.15409139479743317, 0.10093726421473548, 0.2522459614556283, 0.10348500523832627, 0.12114156677853316, 0.24878121534129605, 0.11117600035504438, 0.07267524168128148, 0.16788342269137502, 0.26134415762498975, 0.1938750670524314, 0.19388314161915332, 0.2566101460251957, 0.16782494145445526, 0.21872836077818647, 0.16202476050239056, 0.0973704579519108, 0.11105402096291073, 0.13397028698818758, 0.11473859121906571], [0.05960127877187915, 0.058590440239640884, 0.03485581910354085, 0.0195243394409772, 0.04815182517631911, 0.009384093718836084, 0.020136932253080886, 0.04792680971149821, 0.05457044149807189, 0.014204191666067345, 0.10487279912922531, 0.031145444372668862, 0.0257481679727789, 0.016715494166419376, 0.04757501315907575, 0.0150318690793938, 0.038210515849641524, 0.03902457392541692, 0.04993363269022666, 0.08647515860502608, 0.0489033164922148, 0.08120425511151552, 0.045331990550039336, 0.02452557244396303, 0.044375313955242746, 0.004407823780638864, 0.1163875765632838, 0.026410230493638664, 0.04736578317533713, 0.02693215512408642, 0.024261106264020782, 0.026887706044362858, 0.035698624269571155, 0.06473287372500636, 0.04317963612265885, 0.057516125816619024, 0.030333425347635057, 0.03847040112304967, 0.019659026256704237, 0.0506720547855366, 0.07919215175206773, 0.03428053962124977, 0.03520425743772648, 0.0531431505078217, 0.04956720098562073, 0.0512541471834993, 0.031502881247433834, 0.04895151527307462, 0.07791971729602665, 0.03502481726172846, 0.0417130743880989, 0.11013576906407252, 0.20696624036645517, 3.671647268347442, 14.829236268997192, 30.841867737472057, 39.76471804082394, 42.945717349648476, 39.06449541449547, 34.55050103366375, 30.155311077833176, 18.332243598997593, 19.60490930825472, 28.257178030908108, 18.745252937078476, 13.380708396434784, 10.703791938722134, 8.786138389259577, 9.112781211733818, 3.1431167665868998, 1.402296822052449, 0.27392670745030046, 0.34276681195478886, 0.14142662985250354, 0.6859421613626182, 0.7650349172763526, 1.2729257578030229, 0.5815837893169373, 2.033447823487222, 0.39480332750827074, 1.7904743738472462, 1.8597749364562333, 3.419758784584701, 1.9712557294405997, 1.2416295683942735, 1.9371055369265378, 0.7038321357686073, 0.2741501829586923, 0.8576446166262031, 1.4355963352136314, 0.6462633842602372, 1.1166912037879229, 2.1407516906037927, 2.9243845911696553, 1.6971224080771208, 1.195843806490302, 1.1005263961851597, 0.16896792309125885, 1.0166163300164044, 1.0582606703974307, 0.6325456453487277, 1.4700684417039156, 4.2584495432674885, 2.9436253337189555, 3.9605685649439692, 3.7367821857333183, 2.841758974827826, 1.2834669859148562, 1.067871660925448, 0.3559313539881259, 0.5763585946988314, 0.23918909020721912, 0.17355595424305648, 0.3142583667067811, 0.5460659670643508, 2.313033021055162, 5.294349957257509, 5.898707052692771, 14.855805393308401, 9.712468832731247, 14.452178701758385, 15.101587604731321, 33.230269476771355, 40.298669189214706, 28.024305626749992, 27.224646136164665, 29.806782379746437, 16.86145842075348, 5.4609733913093805, 0.8796802279539406, 0.041822522616712376, 0.0705682324769441, 0.016473320247314405, 0.034376558687654324, 0.040980511548696086, 0.05117884516948834, 0.019041776467929594, 0.020340260307420976, 0.056965188778121956, 0.01623934706003638, 0.04391805821796879, 0.005623627730528824, 0.03432302015426103, 0.028203309375385288, 0.02788225443509873, 0.015038314631965477, 0.04460198440938257, 0.09748077820404433, 0.02470776413247222, 0.017583760563866235, 0.042908102841465734, 0.031892004117253236, 0.02064742595393909, 0.04474539702641778, 0.0494481827627169, 0.04880264415987767, 0.10026924224803224, 0.015411694694194011, 0.044469392305472866, 0.033908924015122466, 0.024145672614395153, 0.025872076948871836, 0.015886114451859612, 0.04324725319747813, 0.05606442558928393, 0.011017980996257393, 0.025546968026901595, 0.0028146718295829487, 0.04373800948087592, 0.07471620716387406, 0.03470861411187798, 0.040266235228045844, 0.05210153882217128, 0.062055405287537724, 0.01131911947595654, 0.04574160782794934, 0.04947368666762486, 0.05215085453528445, 0.053669789631385356, 0.07123379051336087, 0.024141462781699374, 0.04322248030803166, 0.03663628704089206, 0.012487753447203431, 0.02963562285003718, 0.03466073074378073, 0.03062919531657826, 0.02043892327492358, 0.08763440811890177, 0.03987221047282219, 0.016164579392352607, 0.025514454537187703, 0.08860861795255914, 0.060137821856187657, 0.1008743820420932, 0.03182852080499288, 0.025390612354385667, 0.08024573427974246, 0.022560552788490895, 0.02205981276347302, 0.022698018947266974, 0.02063358304440044, 0.04019678133772686, 0.057461986143607646, 0.051951075802207924, 0.023835718347982038, 0.07787613838445395, 0.06801516283303499, 0.008826906869217055, 0.034175540567957796, 0.06586155417608097, 0.035340946196811274, 0.03884769044816494, 0.12243987250258215, 0.03822431237495039, 0.014604278840124607, 0.09804650995647535, 0.03663203453470487, 0.053035936143714935, 0.04060900355398189, 0.03377190500032157, 0.039314761088462546, 0.028888129854749423, 0.06031030439771712, 0.07505934656364843, 0.01026262587402016, 0.06794744927901775, 0.10321824767743237, 0.5017162312287837, 5.5990836303681135, 19.04357872903347, 37.11921639740467, 45.56799463927746, 47.20755726099014, 42.447944059967995, 37.061098515987396, 27.81030870974064, 20.793145447969437, 21.8675434961915, 31.712608113884926, 26.088406406342983, 17.70105566829443, 14.269434157758951, 11.561978738754988, 9.71986323595047, 4.226420586928725, 1.7404512455686927, 0.4028686915989965, 0.4197529668454081, 0.024432637001154944, 0.15039229328976944, 0.2546283445553854, 0.3978370490949601, 0.2971430163597688, 0.9129713696893305, 0.5419437226373702, 1.319926385767758, 2.1672139456495643, 2.904264433309436, 1.5451420820318162, 1.878250613808632, 2.7687166817486286, 1.9548718398436904, 1.9314114237204194, 1.1697318451479077, 1.969304415397346, 0.9174936020281166, 2.877929708920419, 2.2019141586497426, 3.84655449539423, 1.8227349990047514, 2.6333962054923177, 1.7169252829626203, 1.959763839840889, 1.099451647605747, 2.1110581839457154, 0.8448303979821503, 1.865773389581591, 7.897709012031555, 3.1471276888623834, 4.506912035867572, 0.8988709794357419, 2.576822228729725, 0.7657555129844695, 1.0716459271498024, 0.5918752402067184, 0.4900311754317954, 0.12064086942700669, 0.10800350457429886, 0.24286208295961842, 0.6539783359039575, 2.629626332782209, 6.380095146596432, 7.47383083216846, 17.33855701982975, 14.047566913068295, 15.075213219970465, 15.61853751540184, 32.37703286111355, 44.15684916079044, 31.12317994236946, 29.935983046889305, 34.61406022310257, 20.70244811475277, 6.703532366082072, 1.2909384537488222, 0.10035483413957991, 0.062209801690187305, 0.024524975015083328, 0.01659922560065752, 0.07768997063976713, 0.028497999519458972, 0.00880984211107716, 0.036819645756622776, 0.046398145059356466, 0.013079655182082206, 0.05682875605998561, 0.05631577245367225, 0.039429218813893385, 0.012985448811377864, 0.08489610583637841, 0.0538380270882044, 0.05942991316260304, 0.037199180078459904, 0.048995186953106895, 0.014728860387549503, 0.0369254982797429, 0.01940044716320699, 0.025923236898961477, 0.0295083816308761, 0.07352960950811394, 0.03922056028386578, 0.018472410047252197, 0.027737261043512262, 0.026387197940493934, 0.035247799241915345, 0.035516193238436244, 0.02870937059924472, 0.017702099721645936, 0.045087118924129754, 0.05365853867260739, 0.005593145406237454, 0.03216251323465258, 0.018892328334914055, 0.0503003055928275, 0.03470709270914085, 0.06827305915066972, 0.0476425708620809, 0.0477565721666906, 0.01102488668038859, 0.03221373255655635, 0.03434791178733576, 0.2136772740050219, 0.11915765018784441, 0.1876341988099739, 0.17270744196139276, 0.10651598830008879, 0.10377935584983788, 0.11381702192011289, 0.0929883356729988, 0.146526564785745, 0.17892473959363997, 0.15722261974588037, 0.12193504138849676, 0.20850621163845062, 0.12623795424588025, 0.13056452677119523, 0.14976223959820345, 0.18701588589465246, 0.11445169177022763, 0.1800328106037341, 0.14637669548392296, 0.13647644547745585, 0.24505247245542705, 0.16828418243676424, 0.16478241799632087, 0.16279156232485548, 0.09334394315374084, 0.17434427834814414, 0.1259104593191296, 0.14795503579080105, 0.11951057851547375, 0.1585364734637551, 0.12810509389964864, 0.16246314713498577, 0.2082992414943874, 0.09328526153694838, 0.12505557941040024, 0.09728094752063043, 0.14904085721354932, 0.15823152498342097, 0.20522477600025013, 0.1976425648899749, 0.12583487899973989, 0.1600663218414411, 0.07335944246733561, 0.15094163100002334, 0.2541921101510525, 0.09136670589214191, 0.16649076773319393, 0.23609783733263612, 0.09853353694779798, 0.13784757815301418, 0.17854112345958129, 0.5720780650153756, 5.797643875703216, 20.87814688682556, 41.584945768117905, 53.06158013641834, 53.67135241627693, 50.21258421242237, 48.033401146531105, 38.503083139657974, 28.842810206115246, 30.30308324843645, 40.79592950642109, 30.282929129898548, 22.97986540943384, 18.932979963719845, 13.144306931644678, 12.453508749604225, 4.411990279331803, 1.968904605600983, 0.6352204049471766, 0.7072340813465416, 0.5304807471111417, 1.7618525284342468, 1.7859947704710066, 3.360378658398986, 2.234993283636868, 5.581416478380561, 4.012884870171547, 5.575443673878908, 6.256560925394297, 8.634584471583366, 5.8052515424788, 4.305086340755224, 5.428716447204351, 2.6438271207734942, 1.9027577550150454, 4.0010181069374084, 3.628338142298162, 1.9525502831675112, 3.2041930267587304, 5.072181578725576, 6.314769526943564, 3.2080491073429585, 2.5741485971957445, 3.289094245992601, 2.162392004393041, 2.1630876045674086, 4.523218860849738, 0.5780449323356152, 7.877871701493859, 11.751911547034979, 7.284457068890333, 10.711294636130333, 8.606678768992424, 7.752090850844979, 3.934102510102093, 3.0235789809376, 2.8160944394767284, 2.5006021186709404, 1.086623773444444, 0.46375579317100346, 0.6039553857408464, 0.8210383902769536, 3.407049416564405, 7.106751054525375, 8.81737556308508, 21.731151714920998, 17.260045632719994, 22.708472572267056, 22.795400507748127, 42.08580069243908, 48.898413330316544, 36.82041943073273, 38.06412309408188, 40.23287571966648, 22.602386064827442, 8.262546434998512, 1.321699465624988, 0.21025836293119937, 0.30581548693589866, 0.11708162564900704, 0.08969952308689244, 0.1994690200081095, 0.1253895161789842, 0.1065319222107064, 0.10538566770264879, 0.13220097724115476, 0.15112917171791196, 0.12654921098146588, 0.11908376196515746, 0.11542562700924464, 0.12200648052385077, 0.0917089101858437, 0.14858975016977638, 0.18210844922577962, 0.25762700708583, 0.12460692145396024, 0.06931446303497069, 0.18160027102567255, 0.11167530989041552, 0.06339559782645665, 0.15223105321638286, 0.16635016043437645, 0.11304963380098343, 0.16665499017108232, 0.13410673826001585, 0.08787404018221423, 0.12259317052667029, 0.1330671674804762, 0.13888459594454616, 0.07219808525405824, 0.17648669541813433, 0.11854193478939123, 0.12192537862574682, 0.14052368846023455, 0.13289196125697345, 0.12525443045888096, 0.1768382210866548, 0.13132415944710374, 0.11074965135776438, 0.12357532134046778, 0.08305327894049697, 0.1452536479337141, 0.13404096913291141], [0.07906591243227012, 0.050204316212330014, 0.033574690387467854, 0.07596650335472077, 0.08503700257278979, 0.057398651260882616, 0.018316841051273514, 0.057470454048598185, 0.09095603105379269, 0.02882619206502568, 0.032860187711776234, 0.11795678845373914, 0.05582948389928788, 0.11400836243410595, 0.06557984233950265, 0.04052658063301351, 0.06972776507609524, 0.02676443531527184, 0.038176766684046015, 0.0851010499172844, 0.02595370948256459, 0.02674992076208582, 0.0278595539930393, 0.06576202475116588, 0.1099531413638033, 0.015395315494970419, 0.004740251206385437, 0.017884482513181865, 0.02481087441992713, 0.061950172457727604, 0.09652390494011343, 0.025823566465987824, 0.04465612779313233, 0.045434180574375205, 0.01390383615216706, 0.07491092444979586, 0.03483125030470546, 0.08559722758946009, 0.041118116860161535, 0.03416151768760756, 0.01829484936024528, 0.056333068205276504, 0.05281888763420284, 0.04723998914414551, 0.039581373930559494, 0.07236883117002435, 0.060099193069618195, 0.06235116597963497, 0.05666115685016848, 0.06142530335637275, 0.016282040960504673, 0.06781828589737415, 0.02423763584374683, 0.053433538050740026, 2.658617589622736, 10.90166062116623, 24.49578646570444, 38.24892237782478, 41.75789348781109, 41.13804794847965, 37.433037757873535, 28.77539612352848, 18.64385537803173, 15.282571893185377, 21.924238353967667, 19.406478255987167, 17.688447944819927, 28.832491859793663, 16.190564520657063, 10.433985516428947, 6.45889294333756, 4.1980356350541115, 1.4362141583114862, 1.0731283226050436, 0.15724966360721737, 0.1864763890625909, 0.08071927644778043, 0.555737754330039, 0.3560657420894131, 0.48547557613346726, 0.5473219184204936, 1.4040537527762353, 1.087005534209311, 0.628545944346115, 1.7293310235254467, 2.553561539389193, 3.7251923326402903, 3.5132679669186473, 1.2852828134782612, 1.0855973535217345, 1.0110656591132283, 0.9949125477578491, 1.0370701574720442, 1.6717487946152687, 1.7490720329806209, 1.0916709713637829, 0.7886374101508409, 1.0487835039384663, 0.20496742887189612, 0.24648327380418777, 0.9873408009298146, 3.0426957551389933, 9.469928797334433, 0.9176149580162019, 1.2497807247564197, 0.4731535795144737, 0.4444676422281191, 0.26867446897085756, 0.2819576655747369, 0.3463210165500641, 0.03069187525397865, 0.19036546553252265, 1.0164280026219785, 1.2704689521342516, 4.775474024936557, 6.455559097230434, 9.422148261219263, 11.038259491324425, 13.712969217449427, 25.69810464978218, 21.618533357977867, 18.159259781241417, 28.856394477188587, 30.89788243174553, 29.25080381333828, 29.481569230556488, 15.30892537906766, 5.59325996786356, 0.5361157259903848, 0.0037265827722876566, 0.04907504946459085, 0.03541011436027475, 0.004411513646118692, 0.07747986121103168, 0.05739485517551657, 0.03391634178115055, 0.05687677672540303, 0.06791245701606385, 0.07230306946439669, 0.00743477466130571, 0.002898655116041482, 0.03156115097226575, 0.01010045176371932, 0.023996877571335062, 0.01078373970813118, 0.07513801421737298, 0.06713578462949954, 0.06254330059164204, 0.10933914774795994, 0.02195445376855787, 0.027126041204610374, 0.04079069985891692, 0.03790562303038314, 0.08429363035247661, 0.028542021864268463, 0.05725626651837956, 0.020485394707066007, 0.008593969905632548, 0.09076592250494286, 0.037712319535785355, 0.057926028821384534, 0.065298776171403, 0.021543235307035502, 0.056850846085581, 0.046054653139435686, 0.017511551450297702, 0.08313818063470535, 0.0776984979165718, 0.027516377485881094, 0.031347293697763234, 0.025947325157176238, 0.022055916488170624, 0.04149674947257154, 0.0034402420214973972, 0.05400552981882356, 0.05152458208613098, 0.018755353848973755, 0.04160495831456501, 0.07242586521897465, 0.028532179130706936, 0.03698966436786577, 0.04433483351022005, 0.052039751317352057, 0.042424378407304175, 0.05689289988367818, 0.10469819404534064, 0.06792265412514098, 0.011633228841674281, 0.03492262723739259, 0.039067399557097815, 0.023759885698382277, 0.019922553619835526, 0.06405371954315342, 0.024627816274005454, 0.14829317311523482, 0.03610880929045379, 0.026236295198032167, 0.04634767901734449, 0.028983017145947088, 0.028739969347952865, 0.11090772139141336, 0.07565453415736556, 0.038632308060186915, 0.02265664421429392, 0.06777499642339535, 0.05471959833812434, 0.0902563490672037, 0.02884272897063056, 0.055298955921898596, 0.027043729605793487, 0.034340813144808635, 0.05914249049965292, 0.019074735246249475, 0.03736790735274553, 0.00716895916411886, 0.023689904883212876, 0.04027760121971369, 0.024329300358658656, 0.031474297429667786, 0.09458830958465114, 0.008190137668862008, 0.06133639777544886, 0.01217243809151114, 0.0320353388087824, 0.051882211919291876, 0.010790025698952377, 0.051011706091230735, 0.12589831778313965, 0.033028952093445696, 0.09705724194645882, 4.258964415639639, 14.39727259799838, 29.842815846204758, 42.552142068743706, 44.524502232670784, 45.23871570825577, 39.4074460119009, 28.418961949646473, 21.329963542521, 20.617703162133694, 21.612856462597847, 25.926347002387047, 19.399281442165375, 27.018087320029736, 20.48379834741354, 11.116257905960083, 8.131602611392736, 3.7223982950672507, 1.8070394662208855, 0.6814749666955322, 0.1365798118058592, 0.08826967168715782, 0.11446361808339134, 0.14668964431621134, 0.21150120795937255, 0.32256519596558064, 0.19963477127021179, 0.13492557947756723, 0.27826396690215915, 0.9657967882230878, 1.3204437517561018, 2.266219058074057, 0.6028653786052018, 2.3754878947511315, 2.178631857968867, 2.215670133009553, 0.7419223606120795, 2.602504575625062, 1.3393355067819357, 2.871261779218912, 2.7110937237739563, 3.799208798445761, 1.0747523792088032, 2.292350730858743, 1.1181745491921902, 0.7123586407396942, 4.660049518570304, 4.0164505038410425, 7.806380912661552, 0.6659124267753214, 1.6249102517031133, 0.609123227186501, 0.8878180256579071, 0.024941690935520455, 0.06238635862246156, 0.06320832428173162, 0.09271406015614048, 0.2558206196408719, 0.6106984801590443, 1.3118063402362168, 4.804720105603337, 6.806052289903164, 11.9953578338027, 16.01115144789219, 22.18029711395502, 21.35690599679947, 16.76943115890026, 18.063533417880535, 33.34975026547909, 36.32232315838337, 33.689642027020454, 32.01776973903179, 19.97047819197178, 7.218684023246169, 1.1116272630169988, 0.03569970780517906, 0.05333939290721901, 0.013752852701145457, 0.06308342824922875, 0.05947089826804586, 0.11678854411002249, 0.014333393082779367, 0.07869307228247635, 0.051578046404756606, 0.043766248199972324, 0.034601128863869235, 0.007839199224690674, 0.03513458832458127, 0.039523286031908356, 0.01694025359029183, 0.08310672841616906, 0.050876382883870974, 0.0021495164082807605, 0.05106299591716379, 0.06632405318669043, 0.006024135609550285, 0.05082736774056684, 0.0785770003858488, 0.0694727928203065, 0.03738332918146625, 0.018317566500627436, 0.040903369008447044, 0.02800247308186954, 0.01752123462210875, 0.0838204518368002, 0.0295964226097567, 0.09162075788481161, 0.03966244614275638, 0.017819850727391895, 0.05091119332064409, 0.0672130125167314, 0.05778296872449573, 0.019749911516555585, 0.03701292327605188, 0.041634020817582496, 0.02954924613732146, 0.043243943218840286, 0.015109754695004085, 0.01922997398651205, 0.0192869523743866, 0.03804257154115476, 0.01962483180250274, 0.15108280233107507, 0.20054357562912628, 0.14650210359832272, 0.17204326431965455, 0.1061651528289076, 0.1522604571073316, 0.11696493776980788, 0.11087609105743468, 0.24073829379631206, 0.15808848344022408, 0.18406105460599065, 0.21396230324171484, 0.18772879295283929, 0.18652733007911593, 0.171692154253833, 0.10944168287096545, 0.26899237534962595, 0.17679614131338894, 0.1889750370173715, 0.17366626707371324, 0.08640319996629842, 0.20314334862632677, 0.0857653834100347, 0.16627342236461118, 0.17153538297861814, 0.21041887463070452, 0.08843118528602645, 0.16464451211504638, 0.15811573510291055, 0.294333542115055, 0.21269438846502453, 0.11952318760449998, 0.15504066104767844, 0.09476062143221498, 0.09620049924706109, 0.15441348688909784, 0.12564641801873222, 0.2266252425033599, 0.27642418281175196, 0.1456120310467668, 0.09805894093005918, 0.1490490059950389, 0.18541672092396766, 0.17610095674172044, 0.10409439753857441, 0.1593224226962775, 0.15041418664623052, 0.15926364460028708, 0.10835724184289575, 0.1394794718362391, 0.08255484513938427, 0.24113624822348356, 0.12366142531391233, 0.2370641878223978, 4.2794776149094105, 15.632174033671618, 32.619623243808746, 48.94671253859997, 53.92151579260826, 54.39130358397961, 49.25012245774269, 39.54775728285313, 28.58588509261608, 26.43977925181389, 31.308106519281864, 31.12980868667364, 26.126670353114605, 39.75959211587906, 21.58144734799862, 14.936327822506428, 9.313289802521467, 5.068035526201129, 2.3136732866987586, 1.3863964565098286, 0.4552897880785167, 0.43503114546183497, 0.4996388708241284, 1.2612951756455004, 1.2565080262720585, 1.5287488116882741, 2.0586525835096836, 3.7056110333651304, 4.449745528399944, 3.602670757099986, 6.883809417486191, 7.763855494558811, 8.738886024802923, 10.260153394192457, 6.700246492400765, 4.065725784748793, 3.419439601711929, 5.049809804186225, 4.797553215175867, 5.040312688797712, 5.683705564588308, 4.676074208691716, 4.611137118190527, 3.6572037683799863, 1.4332190877757967, 1.7172664334066212, 4.777539689093828, 6.400128146633506, 17.48467817902565, 6.542934458702803, 5.426669307053089, 3.3124779537320137, 3.9401779090985656, 2.1302844397723675, 0.9676919365301728, 1.2386393663473427, 0.6839100422803313, 0.5475073959678411, 1.57218131236732, 2.18131760135293, 6.775826336815953, 9.811906646937132, 15.179298184812069, 17.642903588712215, 22.07871526479721, 36.85268349945545, 27.650164403021336, 28.547117672860622, 40.27264058589935, 42.234429717063904, 37.009869664907455, 41.46755486726761, 20.964178070425987, 8.339704144746065, 1.0722249210812151, 0.11323036160320044, 0.12931154400575906, 0.12219229945912957, 0.14477442833594978, 0.1590434048557654, 0.20727684401208535, 0.0853773886046838, 0.21125708590261638, 0.1399521456914954, 0.13235388934845105, 0.09270130263757892, 0.07449623459251598, 0.1062593684764579, 0.11795534126576968, 0.15610567264957353, 0.2614707383327186, 0.2170352844404988, 0.15490167163079605, 0.10669705749023706, 0.1565741014201194, 0.1583567846682854, 0.20940643677022308, 0.11169978592079133, 0.08198664203519002, 0.16501153382705525, 0.1195311508490704, 0.1871021234546788, 0.12867558281868696, 0.18493177194613963, 0.24114758823998272, 0.15271810989361256, 0.12639739725273103, 0.08656201956910081, 0.1428088650573045, 0.1846526502049528, 0.17388785752700642, 0.2073460418614559, 0.22494583652587608, 0.15091599721927196, 0.1379155885661021, 0.07810423747287132, 0.10836004716111347, 0.06626530477660708, 0.1029779328382574, 0.0888046265754383, 0.17110858869273216, 0.09986890552681871], [0.048547323094680905, 0.06017112944391556, 0.06160074706713203, 0.006677202836726792, 0.026464657748874743, 0.04028699309856165, 0.03565536448149942, 0.04193845350528136, 0.04764251149026677, 0.008989297130028717, 0.05112209684739355, 0.0665994270821102, 0.022631153296970297, 0.008867453179846052, 0.06649834656855091, 0.04391245500301011, 0.07852970331441611, 0.01990497770748334, 0.032990323306876235, 0.11689697930705734, 0.016857185000844765, 0.03797703619056847, 0.02507898268959252, 0.02899994738982059, 0.010909565280599054, 0.05216066201683134, 0.01916954461194109, 0.029600613888760563, 0.023972859817149583, 0.028139176683907863, 0.03934911139367614, 0.006571619342139456, 0.05096991575555876, 0.09446171403396875, 0.05723165690142196, 0.056419331740471534, 0.03526288339344319, 0.02942850984254619, 0.0521669554291293, 0.05192957949475385, 0.06437012678361498, 0.0225773717102129, 0.02228828292572871, 0.002259656457681558, 0.03954830011934973, 0.03857490293739829, 0.04110691785172094, 0.041097782013821416, 0.052653622478828765, 0.009031523477460723, 0.046781753771938384, 0.10371972428401932, 0.11119192684418522, 0.01046933997713495, 0.03154676072881557, 1.9207395776174963, 6.101317880675197, 25.432637594640255, 32.5052759796381, 38.31197239458561, 45.589524284005165, 40.88625825941563, 29.535205252468586, 24.897202625870705, 25.868324115872383, 16.352629624307156, 29.10052377730608, 27.444025464355946, 27.040802501142025, 20.313616879284382, 13.82246034219861, 8.374038152396679, 7.9405911359936, 4.3683847691863775, 2.7205433417111635, 1.2482270831242204, 0.44364011788275093, 0.34187855024356395, 0.5355378601234406, 0.17960214230697602, 0.08628662340925075, 0.21412625850643963, 0.24074127722997218, 0.4774757585255429, 0.3940460103331134, 1.2112881965003908, 0.23422035214025527, 1.0878944490104914, 0.9210261655971408, 1.6409381479024887, 0.3119632008019835, 1.4059574506245553, 0.5301304534077644, 2.1329029742628336, 1.267996234819293, 4.6798312570899725, 0.6261735060252249, 1.6528019425459206, 0.731125061865896, 0.6065981439314783, 5.937391826882958, 1.125869017560035, 1.757108245510608, 0.9322515351232141, 0.7616392057389021, 0.07387243720586412, 0.5642780335620046, 0.0405757590488065, 0.5429108301177621, 0.08718597280676477, 0.8785046660341322, 1.502950214780867, 3.0317689664661884, 5.948148099705577, 8.511681966483593, 14.115210883319378, 16.108870804309845, 12.625675611197948, 15.467865150421858, 22.092415429651737, 20.31316850334406, 21.569998562335968, 28.029205463826656, 30.944671221077442, 27.809879332780838, 18.872943185269833, 7.519932333379984, 1.2318599363788962, 0.06713381793815643, 0.014588368121621897, 0.05185083762626164, 0.082896003004862, 0.09188712210743688, 0.02090440015308559, 0.026100259528902825, 0.0066714298554870766, 0.07577165248221718, 0.04227752964652609, 0.05074735679954756, 0.01352965828118613, 0.052689909789478406, 0.035898187779821455, 0.00434842923823453, 0.028201242494105827, 0.02653616182215046, 0.06385703556588851, 0.014397660288523184, 0.042207496881019324, 0.057141040670103393, 0.026593155052978545, 0.04192230066109914, 0.05769817464170046, 0.07588333828607574, 0.03606866281188559, 0.0410512419330189, 0.07551198243163526, 0.015215892017295118, 0.015176128672464984, 0.05419897432147991, 0.0410432527132798, 0.007464969867214677, 0.031151448347372934, 0.021787960358778946, 0.03332305408548564, 0.02445108679239638, 0.0606890075141564, 0.010586257922113873, 0.003578606874725665, 0.03461974563833792, 0.04552752790914383, 0.058771390686160885, 0.051393296162132174, 0.05029048697906546, 0.03664906682388391, 0.04156536473601591, 0.13561950239818543, 0.03432748417253606, 0.036401560573722236, 0.09417157882126048, 0.026880240038735792, 0.04180384647042956, 0.007263222123583546, 0.03512022034556139, 0.05333943001460284, 0.06955341232242063, 0.009369065228383988, 0.012493508802435827, 0.03149117386783473, 0.04018386054667644, 0.02641752394993091, 0.078143526770873, 0.04177024573436938, 0.03619003364292439, 0.05568853150180075, 0.013848164871888002, 0.07844172912882641, 0.06203577548149042, 0.009543140604364453, 0.049007339621311985, 0.0397733897989383, 0.042613384866854176, 0.03731612399860751, 0.05709457480406854, 0.08673851712956093, 0.023901114545878954, 0.029276837121869903, 0.006446610595958191, 0.027794232009910047, 0.05086624514660798, 0.04101410857401788, 0.010143980580323841, 0.023688127439527307, 0.019801101152552292, 0.031880044407444075, 0.04945859880535863, 0.0717015216650907, 0.026979489302902948, 0.03951203136239201, 0.049261595704592764, 0.032922936297836713, 0.06609780204598792, 0.0119185493713303, 0.024325704653165303, 0.02274917333124904, 0.05561323319852818, 0.05298642747220583, 0.031137770565692335, 0.07761159242363647, 0.0726337185187731, 0.05389907615608536, 0.06260806039790623, 2.6861240761354566, 9.457391370087862, 30.921608358621597, 40.6166323274374, 44.83963072299957, 49.99366655945778, 44.13359820842743, 29.526344127953053, 21.67369119822979, 24.80564273893833, 18.731130994856358, 31.24797474592924, 28.882837258279324, 29.60153639316559, 25.410327091813087, 19.628593437373638, 12.824913170188665, 8.968482054769993, 5.4578974563628435, 2.295632092282176, 1.2463213666342199, 0.3724409337155521, 0.24832804512698203, 0.17549861484440044, 0.1490682573057711, 0.0854169821832329, 0.463886737707071, 0.33211251022294164, 0.3153104055672884, 0.38177937793079764, 1.2049678293988109, 0.9801014768891037, 0.20542695187032223, 1.158084045164287, 1.1710139201022685, 0.9193496836815029, 1.3827214599587023, 1.8748798384331167, 2.187207047827542, 1.8379888054914773, 1.9785014656372368, 0.6938316067680717, 0.784167543752119, 0.4000466602155939, 1.8614422157406807, 4.87455228343606, 1.7387167573906481, 0.9993194206617773, 0.29415539698675275, 0.5878348695114255, 0.2821263705845922, 0.06586153191165067, 0.1363871354260482, 0.13953942252555862, 0.07634859066456556, 0.722879326203838, 1.175080295652151, 3.32253553904593, 7.201074818149209, 12.066471017897129, 17.77926307171583, 19.692200124263763, 14.059738609939814, 15.879570208489895, 24.29449986666441, 22.04965252429247, 24.574765227735043, 33.321046605706215, 36.15316763520241, 33.641133829951286, 22.998482510447502, 9.404237922281027, 1.4612253662198782, 0.040446877683280036, 0.016857376103871502, 0.02558181557105854, 0.0682565983152017, 0.061463672391255386, 0.02101301903167041, 0.02928955011157086, 0.025602304413041566, 0.05692121652828064, 0.07034330235910602, 0.05101613300212193, 0.040186951591749676, 0.06217770751391072, 0.008823015232337639, 0.0426905979111325, 0.024569062297814526, 0.04603503446560353, 0.03541658959875349, 0.03874079520755913, 0.022018803538230713, 0.06441900462959893, 0.025925825138983782, 0.017520518449600786, 0.08346626927959733, 0.03302996512502432, 0.04826853531994857, 0.0770587072474882, 0.004211599934933474, 0.03620029012381565, 0.04554494240437634, 0.055700491211609915, 0.03287292296590749, 0.048182991667999886, 0.06030928765540011, 0.029972199808980804, 0.04147783212829381, 0.09257149358745664, 0.021808007622894365, 0.05051368789281696, 0.01886176112748217, 0.05372858628106769, 0.023968742752913386, 0.01562580615427578, 0.04933206262649037, 0.033396255821571685, 0.06525910837808624, 0.08535852321074344, 0.08749295477173291, 0.18648674944415689, 0.16980304702883586, 0.2695558138657361, 0.0961628946242854, 0.12653482815949246, 0.13364657701458782, 0.07740994347841479, 0.2084647404262796, 0.11731854887329973, 0.09959576549590565, 0.1437610256834887, 0.09090272258617915, 0.11960525429458357, 0.11373276589438319, 0.17784677009331062, 0.0598813467513537, 0.14233601308660582, 0.17863436689367518, 0.14193212147802114, 0.25979173311498016, 0.14257692906539887, 0.13802523346384987, 0.10582811388303526, 0.11906440675375052, 0.12026244090520777, 0.1337462177616544, 0.11691249019349925, 0.1841902922024019, 0.09824720895267092, 0.07601204153615981, 0.1496005553053692, 0.11661169031867757, 0.0874398615269456, 0.15237378305755556, 0.247989566414617, 0.10657219114364125, 0.09337294628494419, 0.11367995466571301, 0.11264459186349995, 0.24075111810816452, 0.2416695110150613, 0.11755732004530728, 0.24714663508348167, 0.09916746465023607, 0.0872540871205274, 0.09547758803819306, 0.2043843234423548, 0.13671090477146208, 0.30401188996620476, 0.20118560758419335, 0.09116863409872167, 0.18305539997527376, 0.2766601264011115, 0.15195815067272633, 0.19602085347287357, 3.260434283874929, 10.14083219692111, 33.094894140958786, 45.01258224248886, 52.42125369608402, 58.13199765980244, 53.00302527844906, 37.28716358542442, 34.88375075161457, 36.93301118910313, 25.3769800812006, 41.12791009247303, 39.13033828139305, 38.6172404140234, 28.97880680859089, 21.263569705188274, 12.96304240822792, 10.965654887259007, 5.595002174377441, 3.4184827655553818, 1.6351588955149055, 0.6903338350821286, 0.7272235618438572, 1.091956787277013, 0.5163372529204935, 0.9445550967939198, 1.1543096601963043, 2.2173828911036253, 2.233645780943334, 2.203643540851772, 3.415452903136611, 2.3225016379728913, 4.724025735631585, 3.50384091027081, 6.355658182874322, 2.2591818356886506, 6.101050470024347, 4.036842109635472, 6.892164219170809, 4.6222462970763445, 11.479926891624928, 3.6199726536870003, 4.60805025883019, 3.588736429810524, 3.8923187647014856, 13.579650521278381, 5.872537856921554, 4.139450853690505, 3.31239958293736, 4.205264272168279, 1.231008069589734, 1.7839364684186876, 0.7148219179362059, 1.1910498887300491, 0.4464140284107998, 1.1622038553468883, 2.153623499907553, 4.181426726281643, 8.748824391514063, 12.822752986103296, 20.096205845475197, 25.653595738112926, 19.454425983130932, 24.059706665575504, 33.49202983081341, 28.409798741340637, 31.788839623332024, 41.260633170604706, 41.416082829236984, 39.55054633319378, 24.819690585136414, 9.99675627797842, 1.7061750660650432, 0.1497773645678535, 0.14603729650843889, 0.17793514503864571, 0.23717040399787948, 0.15834856167202815, 0.09567700311890803, 0.10519607123569585, 0.0990872533293441, 0.14244260033592582, 0.21776695299195126, 0.15372196852695197, 0.1448439824162051, 0.1206407803692855, 0.12096745893359184, 0.07843968822271563, 0.08827167548588477, 0.10671164811355993, 0.20260079414583743, 0.21709948021452874, 0.09974062530091032, 0.11908281201613136, 0.08976319193607196, 0.0746861204970628, 0.1405909567256458, 0.3438741556601599, 0.19295955367852002, 0.19311772019136697, 0.1741726344334893, 0.11943536926992238, 0.11581963321077637, 0.1642575117875822, 0.14780314784729853, 0.10618209606036544, 0.17615142278373241, 0.09935280861100182, 0.11998826928902417, 0.17668548709480092, 0.11242509426665492, 0.16543978272238746, 0.17634752788580954, 0.1212057402881328, 0.08495835718349554, 0.17398917552782223, 0.14083957619732246, 0.13671396241988987, 0.14625519106630236, 0.22123670118162408, 0.2423187714884989], [0.008688659600011306, 0.025208583938365337, 0.04493117143283598, 0.06005806695611682, 0.07027152925729752, 0.03379111549293157, 0.08297561318613589, 0.09189032076392323, 0.031015182612463832, 0.06433015470975079, 0.046724949788767844, 0.02230174733995227, 0.034002991233137436, 0.034455775530659594, 0.10943685891106725, 0.035172975913155824, 0.02031488071224885, 0.03012516757735284, 0.030136821151245385, 0.03506773937260732, 0.03888136910973117, 0.0190261060197372, 0.004410174997246941, 0.010545629975240445, 0.051153293024981394, 0.005906931473873556, 0.023675332813581917, 0.060082862109993584, 0.05591700908553321, 0.05524773288925644, 0.050673457444645464, 0.04532780483714305, 0.07900957600213587, 0.010880362697207602, 0.06550193167640828, 0.036136996059212834, 0.03448110874160193, 0.02004042707994813, 0.029843192278349306, 0.06322516361251473, 0.03561908830306493, 0.03593981484300457, 0.035770805552601814, 0.09175196959404275, 0.058020968062919565, 0.08412628347286955, 0.014875237884552917, 0.05263624509098008, 0.0923501183569897, 0.03528156325046439, 0.06437388947233558, 0.01869167943368666, 0.023547171331301797, 0.04250935431628022, 0.061164705621195026, 0.050621829941519536, 0.5074888933449984, 3.1087708845734596, 14.811984244734049, 27.470743730664253, 38.713732436299324, 41.784594655036926, 38.66582080721855, 32.783158868551254, 32.97638230025768, 26.972113586962223, 26.89445525407791, 27.918667495250702, 28.409152776002884, 26.20739322155714, 25.05677316337824, 20.527264215052128, 15.731295514851809, 14.114499371498823, 10.393411293625832, 6.223843256011605, 4.127776455134153, 2.0008040126413107, 0.85990478284657, 0.6469576188828796, 0.3544280299684033, 0.053609516107826494, 0.26106564444489777, 0.4906364710768685, 0.12964917666977271, 0.4933605092810467, 0.2241047754068859, 0.41005627310369164, 0.5897410016041249, 0.9641601447947323, 0.33792631700634956, 0.7707891147583723, 0.4867911961628124, 1.3847658690065145, 1.6254580160602927, 1.8424147367477417, 0.38920343737117946, 1.8870269553735852, 1.535699707455933, 0.5036401154939085, 0.8462011150550097, 0.5085040326230228, 0.8067291893530637, 0.035112810001010075, 0.1569658366497606, 0.19018562830751762, 0.19617922778706998, 0.5739998118951917, 0.6416695495136082, 2.0703941909596324, 2.9029235802590847, 6.706348014995456, 6.989911599084735, 11.792973093688488, 16.536154076457024, 14.363213125616312, 17.7391030266881, 18.226039297878742, 21.282942965626717, 21.76020685583353, 26.842730529606342, 27.19762958586216, 29.928410053253174, 21.938018314540386, 14.819644633680582, 5.273202667012811, 1.169080773834139, 0.0380638303613523, 0.020322124073572922, 0.02045151009951951, 0.022410061937989667, 0.026776317099574953, 0.020825472747674212, 0.0261799179497757, 0.03861529432469979, 0.027783513542090077, 0.02459456620272249, 0.026690756749303546, 0.08021021509193815, 0.033507329353597015, 0.03601690172217786, 0.036624338463298045, 0.043963633506791666, 0.03835027710010763, 0.025697716773720458, 0.04976194424671121, 0.0236468974253512, 0.03677173641335685, 0.08907256415113807, 0.036592184915207326, 0.01049810283802799, 0.06750971573637798, 0.04483738252019975, 0.0689410069026053, 0.0537759019061923, 0.1101341586036142, 0.007649857407159288, 0.02330517367227003, 0.02654161289683543, 0.05539307509025093, 0.0020492599105637055, 0.044289280485827476, 0.06850430494523607, 0.03537065065756906, 0.0281520714997896, 0.04963396830135025, 0.03771504692849703, 0.05137371459568385, 0.022746945032849908, 0.018203372237621807, 0.023206670266517904, 0.08468247120617889, 0.04440227246959694, 0.04703090758994222, 0.03081776390899904, 0.029491479217540473, 0.08388234695303254, 0.0328756206727121, 0.033932231162907556, 0.08280579495476559, 0.03967374905187171, 0.02435614569549216, 0.03582641096727457, 0.050741326849674806, 0.046305087162181735, 0.07429615900036879, 0.046075470381765626, 0.0155835074474453, 0.024822741361276712, 0.04651474388083443, 0.027875038904312532, 0.061628314142581075, 0.014882800369377946, 0.06209955194208305, 0.03798852463660296, 0.01730992105876794, 0.013477314605552237, 0.03330718696815893, 0.051972204746562056, 0.0685157859697938, 0.04679344259784557, 0.023954614116519224, 0.03746543297893368, 0.05781858439149801, 0.03885314523358829, 0.057052335469052196, 0.09033374764840119, 0.0534021600469714, 0.06488946688477881, 0.030601175531046465, 0.03008812513144221, 0.03176476289809216, 0.04011064396763686, 0.011484548831504071, 0.015970615386322606, 0.027276535765849985, 0.17321444756817073, 0.030795241582382005, 0.036514296516543254, 0.04759311043017078, 0.03967420918343123, 0.03277054740465246, 0.02718650212045759, 0.04354987133410759, 0.0264399460866116, 0.0195993891247781, 0.06590715915081091, 0.06661202132818289, 0.06600909313419834, 0.03387212462257594, 0.06965151682379656, 0.1365641228039749, 0.9502116870135069, 5.439392924308777, 18.282004594802856, 32.44768247008324, 46.43383517861366, 45.831138119101524, 42.28978134691715, 34.73970428109169, 33.18937227129936, 23.907566629350185, 30.16659267246723, 31.247317381203175, 30.150905214250088, 31.300981901586056, 27.9895830899477, 22.610048353672028, 17.261050678789616, 15.96667293459177, 11.105562429875135, 6.2955663073807955, 3.432827708311379, 1.9090498611330986, 0.9217578044626862, 0.46674783574417233, 0.06208710983628407, 0.2692572626983747, 0.046809101913822815, 0.18887765239924192, 0.24597349256509915, 0.17479326284956187, 0.09665060439147055, 0.01586718783073593, 0.5222033069003373, 0.8337088697589934, 0.169897522428073, 0.8357553568203002, 0.9588224999606609, 0.6661289557814598, 0.8665373863186687, 0.5150921072345227, 1.2145060300827026, 0.43103337404318154, 0.2813230699393898, 0.5771820817608386, 0.7085689972154796, 0.6059042655397207, 0.3078162873862311, 0.039552055386593565, 0.09044811260537244, 0.2034592066775076, 0.255658415844664, 0.26402375602629036, 0.605947250733152, 2.238478409126401, 3.6389122623950243, 7.974819224327803, 9.782633017748594, 13.158382326364517, 18.928591199219227, 16.879953928291798, 21.13410495221615, 17.83176865428686, 19.368126913905144, 24.954057075083256, 28.709716647863388, 30.995123013854027, 34.113634675741196, 28.365567214787006, 18.952370323240757, 7.174581689760089, 1.5348650584928691, 0.010998993147950387, 0.028429319318092894, 0.04138236596190836, 0.04790673090610653, 0.03465015142865013, 0.03838284254015889, 0.019809769437415525, 0.04376030730782077, 0.021348597801988944, 0.052924324554624036, 0.03428852141951211, 0.05038181567215361, 0.04630026320228353, 0.041165521543007344, 0.013550728781410726, 0.013251481850602431, 0.04716391900728922, 0.00809253968327539, 0.08087578054983169, 0.01714032176096225, 0.02957557197078131, 0.1436680048936978, 0.022070976519898977, 0.01488516318204347, 0.047712024752399884, 0.01594551224116003, 0.07648539074580185, 0.06566466981894337, 0.024897486764530186, 0.004520358415902592, 0.030581287828681525, 0.003799860346589412, 0.04666039036237635, 0.062068363185971975, 0.05898565985262394, 0.03918082198651973, 0.047155818465398625, 0.05977129367238376, 0.018419376174279023, 0.031136104444158264, 0.10407437439425848, 0.028515805497590918, 0.03344128192111384, 0.025665362845757045, 0.016444949797005393, 0.04918300597637426, 0.027470312379591633, 0.03906721030944027, 0.08080630810582079, 0.15962276986101642, 0.07092648942489177, 0.13462705799611285, 0.32422980351839215, 0.11831810305011459, 0.10679758139303885, 0.15735041757579893, 0.2699669636785984, 0.12638739310204983, 0.15809388627531007, 0.15375868999399245, 0.19099115539574996, 0.08214319066610187, 0.18487238528905436, 0.1824915161705576, 0.13940881937742233, 0.12431631868821569, 0.13818604202242568, 0.14259153453167528, 0.18958218803163618, 0.08581190864788368, 0.15830679360078648, 0.14254586276365444, 0.12813001521863043, 0.10463998740306124, 0.18165513058193028, 0.20564922509947792, 0.08963498592493124, 0.13424896344076842, 0.1843259864836, 0.20017220493173227, 0.10747134016128257, 0.11724749565473758, 0.16386277828132734, 0.12122325497330166, 0.20049552898854017, 0.09886886895401403, 0.09655541653046384, 0.17489996884251013, 0.13515649130567908, 0.2494143118383363, 0.1052749392692931, 0.12395510799251497, 0.19190064253052697, 0.1708030019653961, 0.13247080729342997, 0.20631237857742235, 0.12039244291372597, 0.12681455846177414, 0.09332255445769988, 0.2350682855467312, 0.2060040459036827, 0.1775865285890177, 0.16472561401315033, 0.15056582225952297, 0.23296877945540473, 1.1387012852355838, 6.375182960182428, 20.79927071928978, 37.99058943986893, 53.25536213815212, 54.217098131775856, 50.954144820570946, 44.55567955970764, 45.60868665575981, 38.90880636870861, 37.54527993500233, 39.99361775815487, 41.218622624874115, 35.47363869845867, 37.25921228528023, 30.157676450908184, 21.658210828900337, 20.56343637406826, 12.973958272486925, 9.151817467063665, 4.9922652170062065, 2.8321428783237934, 1.373627835419029, 0.7720400195103139, 0.6783257075585425, 0.7274755358230323, 0.527267069555819, 0.9293341229204088, 0.7600589655339718, 1.3724559545516968, 1.2012175493873656, 1.3423149031586945, 2.230537785217166, 3.0537659861147404, 1.7724768770858645, 2.6214068988338113, 3.8818092411383986, 5.252242516726255, 4.309604773297906, 3.1296127662062645, 3.6524535482749343, 4.265419794246554, 2.764257383532822, 1.909716606605798, 2.2095961589366198, 2.126745404675603, 2.18208278529346, 0.6057692540343851, 1.3249734649434686, 0.7602635014336556, 0.6278778926935047, 0.8895515638869256, 1.1944996286183596, 2.740796017460525, 4.177928064018488, 9.867262076586485, 10.835637263953686, 18.19364983588457, 23.77275176346302, 20.319791547954082, 31.294474750757217, 26.958873197436333, 29.824611023068428, 34.060030952095985, 35.583403408527374, 37.21360333263874, 41.763585582375526, 31.759472899138927, 22.235192768275738, 8.08095132932067, 1.672125686891377, 0.20745298534166068, 0.10451770373038016, 0.1010109594790265, 0.13854877412086353, 0.08803487100522034, 0.11386618920369074, 0.1386388114769943, 0.13028032873990014, 0.0733102454978507, 0.15267510985722765, 0.20787982415640727, 0.18064811039948836, 0.18584756733616814, 0.1379757618997246, 0.0803445660858415, 0.13688885694136843, 0.17958367767278105, 0.1012684401939623, 0.1668598229298368, 0.08931627802667208, 0.17435527697671205, 0.16175338678294793, 0.08054527250351384, 0.09902617457555607, 0.13470971840433776, 0.1377634037635289, 0.18932501901872456, 0.16666742856614292, 0.16166719375178218, 0.07838652076316066, 0.08698012330569327, 0.0819763336039614, 0.20803502207854763, 0.11109301340184174, 0.13557176745962352, 0.1324104706873186, 0.09039622906129807, 0.1351384719600901, 0.16386757255531847, 0.11668972714687698, 0.16454680095193908, 0.1548814109992236, 0.11869631634908728, 0.18881510419305414, 0.15742086223326623, 0.2822663396364078, 0.23126448184484616, 0.13027272914769128, 0.19590300042182207], [0.049732963379938155, 0.0803895624994766, 0.03563858823326882, 0.05869114596862346, 0.07913500638096593, 0.03853014772175811, 0.050930181168951094, 0.07482424902264029, 0.0678833870915696, 0.010535572946537286, 0.03726300477865152, 0.05355752866307739, 0.007226735360745806, 0.028095258239773102, 0.026066016835102346, 0.0032202314150708844, 0.05932094361924101, 0.06690399706712924, 0.03993774582340848, 0.12711386661976576, 0.002970694695250131, 0.03070331360504497, 0.02236129170341883, 0.028723085488309152, 0.027140546480950434, 0.0697738969756756, 0.0398730936285574, 0.019241974514443427, 0.02338287653401494, 0.037717644445365295, 0.00934842888455023, 0.016443268832517788, 0.02053378088021418, 0.03190021598129533, 0.01651696780754719, 0.07698349800193682, 0.03317914051876869, 0.10032653604866937, 0.0374701641703723, 0.04390621354104951, 0.036157149079372175, 0.05107103337650187, 0.020348346006358042, 0.03515233678626828, 0.05411212820035871, 0.030250623931351583, 0.03792611001699697, 0.10815198605996557, 0.066937467927346, 0.020952463491994422, 0.008960242048487999, 0.031764703526278026, 0.0964913098141551, 0.03993912992882542, 0.03888285340508446, 0.07159830376622267, 0.04103097759070806, 0.3861905256053433, 3.087138645350933, 10.097798556089401, 21.964438296854496, 34.046404883265495, 42.87777319550514, 38.910748064517975, 41.91854506731033, 27.875767797231674, 25.254026278853416, 40.11647656559944, 37.4287173897028, 27.606457248330116, 33.440721184015274, 30.69387137889862, 23.343224711716175, 23.850765377283096, 19.78101845830679, 19.470531418919563, 10.760921873152256, 7.741294680163264, 4.746437883004546, 2.912237592972815, 1.6894584568217397, 1.2323021376505494, 0.7578074675984681, 0.3208888624794781, 0.5913742608390749, 0.685957835521549, 0.27119682112243026, 0.21501582639757544, 0.3158593870466575, 0.06238622503587976, 0.1407987580751069, 0.3837007685797289, 1.0393034876324236, 0.4364658356644213, 0.5865838460158557, 0.04567330426652916, 1.5410482767038047, 1.1524242488667369, 0.158252720721066, 0.5205635167658329, 0.1350608581560664, 0.44056154089048505, 0.5199801293201745, 0.2959859784459695, 0.43283513048663735, 1.5957149933092296, 1.3546376419253647, 2.3274560971185565, 5.137882903218269, 4.033441292122006, 9.247620776295662, 11.677616033703089, 15.4733900539577, 16.693889312446117, 16.38974793255329, 22.993913255631924, 19.07176561653614, 15.586364641785622, 25.02176944166422, 34.36811462044716, 35.32388873398304, 30.923732444643974, 24.539753906428814, 15.060090981423855, 5.729982331395149, 1.2969414191320539, 0.08555893276934512, 0.028180447516206186, 0.025457053125137463, 0.04905201691144612, 0.03383771123480983, 0.019609311639214866, 0.06179103744216263, 0.06098425241361838, 0.06664797838311642, 0.052782162456423976, 0.0960500659130048, 0.0626361729518976, 0.02610298321087612, 0.05968038058199454, 0.044898205233039334, 0.07196960767032579, 0.06375955446856096, 0.025386345005244948, 0.04211902545648627, 0.015452965526492335, 0.06063675660698209, 0.058234372627339326, 0.024535079355700873, 0.06429398985346779, 0.026551036316959653, 0.023333111821557395, 0.016543425372219644, 0.034336783282924443, 0.03100743459071964, 0.022014224487065803, 0.030336816962517332, 0.06023971131071448, 0.0625853803649079, 0.03382602983037941, 0.05891913373488933, 0.10819858551258221, 0.06381059938576072, 0.03211287097656168, 0.11769219796406105, 0.03741288892342709, 0.022126164476503618, 0.013837977039656835, 0.07383993113762699, 0.03833259914244991, 0.049205340910702944, 0.023011492849036586, 0.012696512167167384, 0.025808359860093333, 0.055052844909369014, 0.017762577335815877, 0.016672290039423387, 0.08269434663816355, 0.08396852514124475, 0.022767183399992064, 0.05689246943802573, 0.09422761839232408, 0.06558077744557522, 0.06454293587012216, 0.06280800240347162, 0.024696234868315514, 0.04253100276400801, 0.014208759585017106, 0.04346892899775412, 0.034722644413704984, 0.021220310154603794, 0.05550185167521704, 0.09418838104465976, 0.03152506033075042, 0.02562879722972866, 0.027623092755675316, 0.031420532541233115, 0.040801349678076804, 0.05090311504318379, 0.023626204492757097, 0.049139126494992524, 0.04346542977145873, 0.021615088189719245, 0.03951566046453081, 0.05137154381372966, 0.036763435491593555, 0.017836224360507913, 0.011598467572184745, 0.047221346394508146, 0.14198671386111528, 0.07852972557884641, 0.07647911959793419, 0.04455940368643496, 0.04332396529207472, 0.007146397410906502, 0.005783526230516145, 0.01580405889399117, 0.07530025512096472, 0.039447431117878295, 0.06594723512534983, 0.07021048018941656, 0.01395459998093429, 0.01625199325644644, 0.055356149532599375, 0.02857680261513451, 0.022347220583469607, 0.012105561308999313, 0.01203702397106099, 0.04154812835622579, 0.07363579599768855, 0.023909170558908954, 0.059370882736402564, 0.0684523546078708, 0.6077826116234064, 4.9427966214716434, 14.120918177068233, 27.02535443007946, 40.0155957788229, 46.85763783752918, 43.35171416401863, 46.21968246996403, 31.702880635857582, 29.811746813356876, 45.10013334453106, 36.925206407904625, 29.56343773752451, 36.18460714817047, 36.50999888777733, 29.447796642780304, 27.108359076082706, 26.30581174045801, 21.909155063331127, 14.820382744073868, 8.380055129528046, 5.300250565633178, 3.0375748174265027, 2.299453499726951, 1.1887056520208716, 0.4801149247214198, 0.21714197559049353, 0.38049050490371883, 0.2684656286146492, 0.10419685102533549, 0.04526979857473634, 0.19783083291258663, 0.1231941394507885, 0.19477297668345273, 0.3622534131864086, 0.49360060889739543, 0.3810675098793581, 0.14681534928968176, 0.23211857507703826, 1.3866126886568964, 1.9523682491853833, 0.16503966122400016, 0.29969089839141816, 0.1552204685867764, 0.13011735311010852, 0.08430574220255949, 0.25929945171810687, 0.32685086131095886, 1.0161096509546041, 1.239816234447062, 2.944009588100016, 6.2615039851516485, 5.612302171066403, 10.239733289927244, 14.742010049521923, 20.833085104823112, 20.044374726712704, 20.939188711345196, 23.67406915873289, 20.923161171376705, 18.776390366256237, 28.122855238616467, 39.66537617146969, 40.32770723104477, 36.33081950247288, 28.722054585814476, 18.76852098852396, 6.864566300064325, 1.5847604186274111, 0.172431273967959, 0.019329924580233637, 0.04511735030973796, 0.026554741489235312, 0.011669830637401901, 0.02476847181242192, 0.01264307104065665, 0.050102816385333426, 0.0201342289801687, 0.04355745237262454, 0.02398729273409117, 0.017102275560318958, 0.04942289408063516, 0.023368890761048533, 0.08652339078253135, 0.007370380362772266, 0.08688388159498572, 0.021733963549195323, 0.05592504283413291, 0.053186681179795414, 0.039432146586477757, 0.03804253814450931, 0.02552615635067923, 0.013012974141020095, 0.06148073807707988, 0.12254110144567676, 0.03102383419900434, 0.036271896242396906, 0.028817564598284662, 0.023208909697132185, 0.03510033078782726, 0.05209382790781092, 0.02479153590684291, 0.017391323526680935, 0.047343355472548865, 0.057859792141243815, 0.016652708472975064, 0.05011316192394588, 0.03951089958718512, 0.03852645182632841, 0.07443499256623909, 0.016725923196645454, 0.03148073185002431, 0.026596977113513276, 0.10865136981010437, 0.015540219828835689, 0.03754880955966655, 0.04553539467451628, 0.007325247115659295, 0.05854024879226927, 0.12110916461097077, 0.18037261033896357, 0.17833036836236715, 0.16341713344445452, 0.3775083180516958, 0.14204233040800318, 0.18121411674655974, 0.2891421300591901, 0.1225655923190061, 0.1082696758385282, 0.127298527804669, 0.11388470578822307, 0.11225444482988678, 0.05382104674936272, 0.07508196722483262, 0.14862348820315674, 0.10976253557601012, 0.17689391184831038, 0.13511418888811022, 0.22935708810109645, 0.07908462197519839, 0.18556452705524862, 0.18402357614832, 0.21654068754287437, 0.08620208536740392, 0.19283503614133224, 0.16953697224380448, 0.1923000960960053, 0.11180393892573193, 0.17361885868012905, 0.05809128284454346, 0.11973726010182872, 0.17266375914914533, 0.1515139010734856, 0.22914475965080783, 0.13910162961110473, 0.1436533548985608, 0.18175824458012357, 0.1260796541464515, 0.11740476416889578, 0.14634240826126188, 0.28555645840242505, 0.12418564132531174, 0.12069325763150118, 0.13813722354825586, 0.17038146208506078, 0.10725719344918616, 0.15456672554137185, 0.17463861411670223, 0.1183325081365183, 0.059716660471167415, 0.0962175389577169, 0.1914250000845641, 0.18064350908389315, 0.11415777160436846, 0.1478617626708001, 0.17184920754516497, 0.6941358279436827, 4.96851316653192, 14.271120317280293, 29.69870287925005, 43.76452401280403, 57.06635624170303, 51.42340064048767, 55.300530195236206, 39.32215578854084, 34.33229774236679, 52.11191609501839, 50.7362113147974, 38.796450197696686, 46.81442655622959, 41.919137835502625, 34.682771936059, 33.61618436872959, 29.15273867547512, 25.00763799995184, 14.410437941551208, 11.988005228340626, 6.141650341451168, 3.7428670842200518, 2.534793158993125, 1.9593611801974475, 1.2480027764104307, 0.6091185961849988, 1.0783317871391773, 1.098493505269289, 0.5737611372023821, 0.3865599964046851, 1.7345968284644186, 0.7655092980712652, 0.7044636143837124, 1.1384545359760523, 1.8804911873303354, 1.7197911604307592, 1.4417828782461584, 0.5891724571119994, 3.12811897136271, 2.170929671265185, 0.7566744752693921, 1.2249896675348282, 0.5792983900755644, 0.9087882691528648, 1.5643063536845148, 0.8120065124239773, 0.8077426662202924, 2.1709413081407547, 2.2555772541090846, 3.49709864705801, 7.599604083225131, 5.975337540730834, 13.658477291464806, 18.128979206085205, 23.85662466287613, 25.2776363119483, 26.54820453375578, 33.836956322193146, 28.863407000899315, 24.9881811439991, 34.85244043171406, 47.34427012503147, 47.23088800907135, 41.73066034913063, 33.09683583676815, 21.664569787681103, 7.536604888737202, 1.8593742954544723, 0.27227035257965326, 0.17443090182496235, 0.28588009416125715, 0.11073831134126522, 0.09962063486455008, 0.12770688714226708, 0.20076763001270592, 0.13656833820277825, 0.12150046939495951, 0.1144749803643208, 0.1795069544459693, 0.091494741209317, 0.08800430936389603, 0.14743430045200512, 0.19318292528623715, 0.21887796290684491, 0.15364453283837065, 0.11080396914621815, 0.2720969868823886, 0.21758689312264323, 0.0800619859364815, 0.141654884791933, 0.1294203131692484, 0.17707097344100475, 0.15452718391316012, 0.18947199394460768, 0.10034062943304889, 0.08154018825734966, 0.04772870452143252, 0.15743920812383294, 0.19237451866501942, 0.19765366741921753, 0.1611564922495745, 0.11250083043705672, 0.1597736930125393, 0.15417056711157784, 0.10147746608708985, 0.20855360518908128, 0.11776150713558309, 0.1258317322935909, 0.23773992812493816, 0.13073529495159164, 0.18052267259918153, 0.16239955992205068, 0.21460092131746933, 0.1059393618197646, 0.10984988635755144, 0.08165227482095361, 0.12423134277923964, 0.15356142714153975], [0.057840496301651, 0.011957806200371124, 0.02705542585317744, 0.06957718331250362, 0.07544890730059706, 0.021974224582663737, 0.0472590474964818, 0.007272266120708082, 0.057350853239768185, 0.040378744815825485, 0.008980003585747909, 0.018914615029643755, 0.05348621569282841, 0.05250130780041218, 0.056368516889051534, 0.05247113207587972, 0.046015805419301614, 0.02506064422050258, 0.07729576405836269, 0.04131024033995345, 0.04494916480325628, 0.07892287088907324, 0.023984452163858805, 0.02048693466349505, 0.02930536156782182, 0.04974908282747492, 0.05990208235743921, 0.0575640908209607, 0.05375096203351859, 0.027602960144577082, 0.03481748717604205, 0.009290256566600874, 0.010216401205980219, 0.022462552187789697, 0.027299353096168488, 0.047908237465890124, 0.01626636309083551, 0.06511432278784923, 0.06550484089530073, 0.015529530119238188, 0.0384284549363656, 0.056807890578056686, 0.008646660535305273, 0.005521243820112431, 0.03188201480952557, 0.015076782001415268, 0.03711839730385691, 0.059238498433842324, 0.014675525944767287, 0.021656744938809425, 0.022045311197871342, 0.14312806277303025, 0.04719199445389677, 0.04621967709681485, 0.04094055802852381, 0.06701661055558361, 0.022808016365161166, 0.03063679119804874, 0.27638410683721304, 0.7889145577792078, 7.89276547729969, 18.094368763267994, 29.96885508298874, 40.09043276309967, 48.66059169173241, 39.932558834552765, 35.1239662617445, 43.592036068439484, 37.79315583407879, 24.532372802495956, 17.82722979784012, 23.039860390126705, 22.90439385920763, 30.904036201536655, 27.290604896843433, 15.677661392837763, 17.125092074275017, 16.484455950558186, 13.368085473775864, 9.741780459880829, 7.564421771094203, 4.81216105632484, 4.359435774385929, 3.0610794061794877, 1.110340200830251, 1.6095170401968062, 0.8464128349442035, 0.8308922115247697, 0.5198411992751062, 0.9675557969603688, 0.5352468194905668, 0.4851917194901034, 0.31237764575053006, 0.4929202969651669, 0.5898199661169201, 0.23718787415418774, 0.30328131979331374, 0.43403598479926586, 0.4450390365673229, 0.3744316112715751, 0.5157027463428676, 1.1812049732543528, 1.1623554909601808, 2.2085255663841963, 3.171248557046056, 5.079614454880357, 7.837097989395261, 7.622571000829339, 11.484385952353477, 17.210004217922688, 16.14026091992855, 19.213019236922264, 19.984239153563976, 15.25617565959692, 16.081037297844887, 19.536440782248974, 30.759877637028694, 29.7073645144701, 29.602074064314365, 29.127375036478043, 26.824696697294712, 18.52955751121044, 9.833773523569107, 3.5743254655972123, 0.48938414140138775, 0.01124578971939627, 0.021274991595419124, 0.026574460353003815, 0.030733639614481945, 0.0636786529503297, 0.03073080089961877, 0.041946023411583155, 0.05171981516468804, 0.008794449040578911, 0.02108312415657565, 0.04296142986277118, 0.023659998187213205, 0.022694679282722063, 0.026763776659208816, 0.036390016466611996, 0.021376945987867657, 0.052978156236349605, 0.030692582149640657, 0.029749902460025623, 0.041847514439723454, 0.053633112693205476, 0.02530861060222378, 0.02465690289682243, 0.0420626482082298, 0.047714551765238866, 0.03883659162966069, 0.032103282428579405, 0.05023720448662061, 0.014312760449683992, 0.020336369598226156, 0.014937724863557378, 0.0640963930345606, 0.015328944300563307, 0.02002098466618918, 0.05482700937136542, 0.03606772770581301, 0.0211414087243611, 0.09226963986293413, 0.10320293717086315, 0.029100068677507807, 0.08814857545075938, 0.04174221110588405, 0.012114930923416978, 0.017116103626904078, 0.025972927396651357, 0.017081786718335934, 0.07562765356851742, 0.05572472604399081, 0.021484216013050172, 0.0387078252970241, 0.021651295719493646, 0.03915376328222919, 0.05127348755195271, 0.045996045737410896, 0.012004632008029148, 0.04059410493937321, 0.028609900546143763, 0.04100787453353405, 0.03737548839126248, 0.016517431649845093, 0.040626529371365905, 0.12039504043059424, 0.02161665597668616, 0.02845414786861511, 0.06425062616472133, 0.02914828044595197, 0.0064784018832142465, 0.0965928281948436, 0.062067524559097365, 0.017729147293721326, 0.0918974305386655, 0.07072251013596542, 0.037715072903665714, 0.010565679094725056, 0.05589610278548207, 0.022192467949935235, 0.044798148883273825, 0.07949142280267552, 0.02468485588906333, 0.0362527970719384, 0.07458542590029538, 0.01755772787873866, 0.05469566778629087, 0.052839645504718646, 0.013031151192990365, 0.020953454259142745, 0.06320709973806515, 0.013244073361420305, 0.07582111662486568, 0.10217446892056614, 0.09550862465403043, 0.016662913003528956, 0.0749317862209864, 0.07567122505861335, 0.03015601494553266, 0.01973526152141858, 0.016192884904739913, 0.07744365924736485, 0.08086195433861576, 0.02875122216210002, 0.013020437363593373, 0.05706567186280154, 0.025347911032440607, 0.022935029373911675, 0.06220398696314078, 0.021066260705993045, 0.07177489780588076, 0.02680848177988082, 0.016377369829569943, 0.4461852984968573, 1.6507676267065108, 10.561445876955986, 22.749814353883266, 35.48852629959583, 48.29299941658974, 50.99754989147186, 42.47969135642052, 38.17747861146927, 46.17468908429146, 42.71337881684303, 29.047205038368702, 24.91126947104931, 27.92159143835306, 27.366648316383362, 35.125558376312256, 33.85036580264568, 23.668895736336708, 23.468424193561077, 21.306395307183266, 16.501427739858627, 11.560778953135014, 7.806241270154715, 5.212167492136359, 4.961121138185263, 2.5802890677005053, 1.5644911187700927, 1.2130060605704784, 0.7622474106028676, 0.8074917015619576, 0.9318701305892318, 0.6303310766816139, 0.6352935510221869, 0.26241083163768053, 0.21213396306848153, 0.32373585971072316, 0.6059916608501226, 0.15690564847318456, 0.435934339184314, 0.31690842763055116, 0.20917709829518571, 0.3140067489584908, 0.7219889271073043, 0.8162401977460831, 1.151582831516862, 2.071040393784642, 3.7523665744811296, 4.940124889835715, 8.874131217598915, 10.366744324564934, 13.98198053240776, 18.97503800690174, 21.61278996616602, 22.743058316409588, 20.579114332795143, 20.428330823779106, 15.857784077525139, 22.34884086996317, 30.466632172465324, 31.07549250125885, 34.704438373446465, 36.67952299118042, 33.44834737479687, 24.128444977104664, 13.317023813724518, 5.474116886034608, 1.106220509391278, 0.08704836378456093, 0.05214104334299918, 0.06797603680752218, 0.0334284316340927, 0.052152498392388225, 0.020679746485257056, 0.02199470043706242, 0.1102294577867724, 0.04311119897465687, 0.051858626466128044, 0.09953678702004254, 0.02624907312565483, 0.01295549202041002, 0.03083863681240473, 0.11008454603143036, 0.042843851406360045, 0.019424253405304626, 0.033324794421787374, 0.03468876537226606, 0.021234102969174273, 0.03110475056018913, 0.04676371958339587, 0.02048208101768978, 0.05034562855144031, 0.029799720978189725, 0.046724730855203234, 0.016478912330057938, 0.023039560874167364, 0.02265278875711374, 0.11377214425010607, 0.02946653748949757, 0.07157276646466926, 0.05497527934494428, 0.016022699310269672, 0.05669757774739992, 0.04875913946307264, 0.05651896135532297, 0.08566074800910428, 0.020868387437076308, 0.028810994735977147, 0.019654167044791393, 0.03788441616052296, 0.043005635889130645, 0.05201252562983427, 0.045392074825940654, 0.03154550649924204, 0.08453652786556631, 0.03599789532017894, 0.04334316836320795, 0.01042918607708998, 0.011091333944932558, 0.12876094464445487, 0.10465620332979597, 0.13718975329538807, 0.14135541336145252, 0.20732538047013804, 0.14183314866386354, 0.16133091179654002, 0.1653513780911453, 0.09578256620443426, 0.13788624404696748, 0.24657898116856813, 0.1269610138842836, 0.11497707295347936, 0.1339995869784616, 0.3125245019327849, 0.23712274327408522, 0.16925033996813, 0.17440391733543947, 0.22991123492829502, 0.22358810703735799, 0.16307892190525308, 0.11201037472346798, 0.08840536596835591, 0.14240466174669564, 0.13966937258373946, 0.09897137439111248, 0.24582053592894226, 0.12543199671199545, 0.08236561232479289, 0.14005064353113994, 0.16016023320844397, 0.15455911110620946, 0.07461213579517789, 0.14982772670919076, 0.13354341848753393, 0.16155170073034242, 0.11498133288114332, 0.18865704158088192, 0.1575437470455654, 0.18637008382938802, 0.09645223573897965, 0.178688588202931, 0.09769501397386193, 0.12142673702328466, 0.10037311323685572, 0.09626279512303881, 0.20172752381768078, 0.18517072865506634, 0.13926687621278688, 0.1217264607839752, 0.10581707814708352, 0.2495506888953969, 0.1436852672486566, 0.20980519271688536, 0.18437291990267113, 0.16066894575487822, 0.1517955312738195, 0.1325254442053847, 0.550766255473718, 1.7424317705444992, 11.007704380899668, 24.152277298271656, 41.728726252913475, 52.978360801935196, 60.985226556658745, 52.68022119998932, 46.54970996081829, 56.004362627863884, 49.65567849576473, 39.12570632994175, 29.33091301470995, 35.95449909567833, 33.363064751029015, 43.37589606642723, 40.55528461933136, 25.029131546616554, 26.541976667940617, 24.244179166853428, 20.09213626384735, 13.919155653566122, 10.31821807846427, 7.0206234510988, 5.871228352189064, 4.206032305955887, 2.3886059783399105, 2.7510614041239023, 1.4476897800341249, 1.4514712896198034, 1.3081976026296616, 2.1387342363595963, 1.1685890564695, 0.6962696509435773, 1.291682026349008, 1.1542543256655335, 1.411706660874188, 0.6629203842021525, 0.9347645658999681, 1.025455486960709, 0.7455870264675468, 0.7025830121710896, 1.7097518616355956, 1.886769044212997, 1.7621301510371268, 3.0205108830705285, 4.857670264318585, 6.668859226629138, 10.793641917407513, 11.096888445317745, 15.899032764136791, 23.473816104233265, 24.340954273939133, 28.03370252251625, 31.564169079065323, 25.212091729044914, 24.168361835181713, 29.306786209344864, 40.70276990532875, 41.19019255042076, 41.36671207845211, 42.48702876269817, 37.896510288119316, 26.58989019691944, 14.400704763829708, 6.236328911036253, 1.2917548161931336, 0.1533872153959237, 0.10965338791720569, 0.18506863882066682, 0.15301295032259077, 0.17504871007986367, 0.07331443121074699, 0.17370886635035276, 0.14639116736361757, 0.15697413386078551, 0.11420926923165098, 0.34911980386823416, 0.08414143812842667, 0.139081250235904, 0.14238113566534594, 0.24481495551299304, 0.13727748999372125, 0.1329765364062041, 0.16343233262887225, 0.1900663651758805, 0.18924933479866013, 0.12742239225190133, 0.1356198437861167, 0.0831484593800269, 0.17896382109029219, 0.17727708269376308, 0.12172327697044238, 0.12277817309950478, 0.16690797347109765, 0.09954746652510948, 0.24993203405756503, 0.09027918495121412, 0.1259249757276848, 0.08741269892198034, 0.11609585315454751, 0.1222259335918352, 0.1967346214223653, 0.14879890222800896, 0.2628584357444197, 0.12240381154697388, 0.061730389134027064, 0.14733048883499578, 0.08336921862792224, 0.1422534417361021, 0.1531300463830121, 0.13674298039404675, 0.06337212369544432, 0.16660305467667058, 0.15112988417968154, 0.19926378648960963, 0.1551922076032497, 0.11813609875389375], [0.03737488354090601, 0.012518210260168416, 0.02629982674989151, 0.01960581797902705, 0.07861087942728773, 0.02261320816614898, 0.01293367009566282, 0.02467069571139291, 0.03406043346330989, 0.037779591511934996, 0.09745849150931463, 0.05644075383315794, 0.04296353756217286, 0.011989868835371453, 0.021260465910017956, 0.03778949176194146, 0.026899407857854385, 0.012181489510112442, 0.01577055278175976, 0.06067118112696335, 0.05245236687187571, 0.032175500818993896, 0.02101235480949981, 0.06941937303054146, 0.04871685188845731, 0.03276255818491336, 0.0566969840292586, 0.017232533609785605, 0.06784641329431906, 0.020854655849689152, 0.024816904369799886, 0.03798683996137697, 0.013743854160566116, 0.016305696917697787, 0.03555528586730361, 0.04304534078983124, 0.07474717698642053, 0.08032174504478462, 0.03377360822923947, 0.03221702398150228, 0.07372265696176328, 0.014796734431001823, 0.08724947096197866, 0.08025354167330079, 0.04309585136070382, 0.02330228300706949, 0.01814115428715013, 0.06498665854451247, 0.01926062654092675, 0.07065078156301752, 0.031562178846797906, 0.01509448686192627, 0.024385000397160184, 0.046662947061122395, 0.04086966066097375, 0.042202275872114114, 0.07715632935287431, 0.0808086310280487, 0.011645503964246018, 0.06759826879715547, 0.4038855229737237, 2.935913410037756, 10.930179990828037, 19.9343516305089, 38.03904823958874, 48.652847707271576, 38.75105023384094, 40.41490875184536, 34.58279550075531, 32.61841870844364, 25.46408660709858, 28.43251772224903, 26.474687978625298, 30.37220723927021, 23.789375871419907, 27.55728978663683, 33.86249855160713, 23.907505832612514, 21.170886978507042, 15.421138107776642, 17.27765578776598, 15.286490432918072, 11.05240423232317, 7.925300756469369, 6.768969129770994, 7.183225275948644, 5.744636245071888, 5.294779809191823, 4.584767483174801, 3.9314963249489665, 3.8462640484794974, 3.528533885255456, 2.613654602319002, 2.7418421488255262, 2.063231812790036, 2.683698143810034, 1.5802945895120502, 2.3324086563661695, 2.2968568140640855, 3.3586860867217183, 3.319452479481697, 4.190660230815411, 7.383911032229662, 9.850657917559147, 12.022233791649342, 17.350634671747684, 20.092240758240223, 18.78034595400095, 21.663671135902405, 16.977724581956863, 22.145587876439095, 21.760966815054417, 31.3789689168334, 26.462458334863186, 26.431552693247795, 29.265851005911827, 33.32802303135395, 39.61080729961395, 31.227379851043224, 18.572290018200874, 9.478410892188549, 4.982733903452754, 2.433298942632973, 0.37350665777921677, 0.1243256326415576, 0.015536354167124955, 0.06160769356938545, 0.03344323376950342, 0.04031591830425896, 0.05766873735410627, 0.051958716212539, 0.01353310648482875, 0.01917649668030208, 0.08189342086552642, 0.014345666349981911, 0.015063917799125193, 0.026106916593562346, 0.014742646708327811, 0.03824860286840703, 0.041929302824428305, 0.05757264036219567, 0.06750129978172481, 0.009848606732703047, 0.02690582743525738, 0.03864315825921949, 0.08874175924574956, 0.06812999534304254, 0.055561234621563926, 0.09311786270700395, 0.055838382249930874, 0.031204923798213713, 0.05423048962256871, 0.09371636770083569, 0.05635559238726273, 0.044308891738182865, 0.00502730836160481, 0.07424771160003729, 0.03403294802410528, 0.05033788795117289, 0.08284336247015744, 0.03877650735375937, 0.011609212942857994, 0.06469637490226887, 0.05271312045806553, 0.041294247057521716, 0.05893356108572334, 0.04116003336093854, 0.018751437164610252, 0.06768927094526589, 0.026716255088103935, 0.06205036610481329, 0.061399866244755685, 0.03919742383004632, 0.1007619095616974, 0.03766404654015787, 0.01338164898697869, 0.07898115916759707, 0.04812897816009354, 0.007059601848595776, 0.03392006365174893, 0.019837060062855016, 0.0412838050397113, 0.019630414608400315, 0.03206698027497623, 0.018182974308729172, 0.03825804669759236, 0.019839401538774837, 0.043112750063301064, 0.09224232140695676, 0.08273038532934152, 0.022184770023159217, 0.01527216443719226, 0.045207168732304126, 0.029614410414069425, 0.02576823935669381, 0.024030617460084613, 0.04607203423802275, 0.030872517709212843, 0.05355070090445224, 0.015050928359414684, 0.025627151517255697, 0.0756206402729731, 0.06780002906452864, 0.04953791212756187, 0.03602316173783038, 0.027577933069551364, 0.049501220346428454, 0.019556702645786572, 0.044911163131473586, 0.027908886404475197, 0.023400610152748413, 0.012982961688976502, 0.025909891228366178, 0.028967419057153165, 0.014939252760086674, 0.04162968667515088, 0.03023175297130365, 0.025653729680925608, 0.051018177618971094, 0.034000486484728754, 0.06918741477420554, 0.04640280945750419, 0.004064057729920023, 0.0959643033274915, 0.030042481193959247, 0.01973369187908247, 0.033418219682062045, 0.03568611908121966, 0.03198309161234647, 0.0675601075636223, 0.056654195504961535, 0.03375662417965941, 0.026435584113642108, 0.012278802696528146, 0.09005717147374526, 0.15438734844792634, 0.8631717169191688, 5.339644951745868, 15.151989050209522, 26.623193509876728, 46.335625648498535, 52.24299006164074, 46.2172582000494, 45.34448303282261, 40.47821335494518, 35.983058363199234, 27.56083119660616, 30.743857696652412, 26.967922411859035, 34.28225442767143, 30.61490211635828, 27.241426035761833, 36.83641277253628, 29.140180349349976, 31.047273315489292, 20.843688435852528, 21.724103093147278, 19.42954681813717, 14.997948165982962, 11.140553802251816, 9.403939638286829, 8.10789093375206, 6.427100049331784, 5.972676733508706, 4.146497575566173, 4.106125691905618, 3.987487507984042, 4.251316851004958, 2.6832986902445555, 2.894559991545975, 2.280007805675268, 2.8903738036751747, 1.9864807999692857, 2.03944010194391, 3.4806528920307755, 3.3866134006530046, 3.687636572867632, 4.854967659339309, 7.805547807365656, 10.612108558416367, 14.197312127798796, 19.03495129197836, 22.357251718640327, 21.098753549158573, 25.167250335216522, 23.360975459218025, 25.925091169774532, 22.334310449659824, 31.236615255475044, 25.65317966043949, 27.441983073949814, 31.102518551051617, 37.714929431676865, 44.19882170855999, 36.651742681860924, 25.20335789769888, 15.224296320229769, 6.53079173527658, 3.6404157942160964, 0.6049508135765791, 0.04562952868582215, 0.03871978500683326, 0.045599453151226044, 0.022088626647018827, 0.02761413503321819, 0.053106581181054935, 0.02835573352058418, 0.06405519641702995, 0.04880761283857282, 0.04883571426034905, 0.08054000325500965, 0.06665841297945008, 0.008995524676720379, 0.026262121937179472, 0.023483457953261677, 0.022314308189379517, 0.06619019943173043, 0.02606979622214567, 0.0452571486675879, 0.0378735845151823, 0.051429067680146545, 0.04050103590998333, 0.013090230786474422, 0.05251809889159631, 0.11449568628449924, 0.03320026575238444, 0.05470411713758949, 0.016176767312572338, 0.06791538849938661, 0.05136720967129804, 0.02867864754080074, 0.05551882088184357, 0.05319002826581709, 0.09102560739847831, 0.07594873633934185, 0.023191916370706167, 0.029417232908599544, 0.010477727173565654, 0.05560932208027225, 0.07041178774670698, 0.012527642957138596, 0.030929895001463592, 0.021365550310292747, 0.007816741835995344, 0.04983434817404486, 0.03579331860237289, 0.028444384915928822, 0.040926746660261415, 0.04206496370898094, 0.07662664371309802, 0.02765188066405244, 0.012817058286600513, 0.14226072962628677, 0.14606322714826092, 0.06999715726124123, 0.1539715676335618, 0.1943260701955296, 0.1522483304142952, 0.131902054999955, 0.13863962783943862, 0.09206516333506443, 0.19710551714524627, 0.15853469230933115, 0.18287250510184094, 0.1752460768329911, 0.10849708472960629, 0.16696755308657885, 0.11842151390737854, 0.14831131120445207, 0.20625452074455097, 0.11353496869560331, 0.146563078451436, 0.08417100529186428, 0.1521028546267189, 0.121338443714194, 0.12351266923360527, 0.12742794351652265, 0.12783306709025055, 0.15630480571417138, 0.16059345449320972, 0.05675882348441519, 0.11837300713523291, 0.20590252010151744, 0.12186430729343556, 0.22446890274295583, 0.0715415517333895, 0.12475352530600503, 0.10711651193560101, 0.14749227702850476, 0.1365265404456295, 0.16971682431176305, 0.20940239948686212, 0.2444479041150771, 0.13038704957580194, 0.21661896927980706, 0.1292190872482024, 0.22708859498379752, 0.0866615044651553, 0.1713760884013027, 0.19972074165707454, 0.11920484335860237, 0.15436508401762694, 0.17795396590372548, 0.11642639830824919, 0.08872984035406262, 0.16363260860089213, 0.18022461124928668, 0.16866414720425382, 0.10517797767533921, 0.16273535205982625, 0.13054298964561895, 0.29950381780508906, 0.8763044059742242, 5.372573034837842, 17.12006874382496, 30.13495746999979, 49.69228193163872, 59.64663438498974, 51.3037184625864, 54.11872901022434, 47.758797481656075, 47.96060465276241, 38.79362314939499, 39.153665229678154, 39.60300251841545, 42.90933430194855, 36.62515930831432, 38.314077481627464, 45.45036815106869, 34.195201098918915, 34.73370440304279, 24.46130521595478, 26.8064633756876, 21.51805154979229, 16.431615985929966, 12.173377331346273, 10.662720892578363, 10.195938739925623, 7.638833178207278, 6.962091391906142, 6.4089821465313435, 5.690432628616691, 5.131771881133318, 4.897598521783948, 3.669566405005753, 3.8112201914191246, 3.383492105640471, 3.8342764042317867, 2.9208161076530814, 3.013632777146995, 3.82687677629292, 4.661565637215972, 5.077050067484379, 6.276765866205096, 9.350047130137682, 12.40163678303361, 16.552947275340557, 22.57252536714077, 27.428754083812237, 24.954811334609985, 30.976760499179363, 25.544475093483925, 32.60735750198364, 32.353234738111496, 42.327729910612106, 37.85364478826523, 36.05408415198326, 39.30313020944595, 43.61146442592144, 51.99541434645653, 41.966688483953476, 30.036280564963818, 17.08471544086933, 8.838688619434834, 3.640393470413983, 0.6947195122484118, 0.19344951957464218, 0.07920892428955995, 0.16683576250215992, 0.09498440122115426, 0.07289621615200303, 0.13712376152398065, 0.11630700901150703, 0.143313184089493, 0.05718451568100136, 0.14572793967090547, 0.2293178581749089, 0.14321765484055504, 0.08640357104013674, 0.1360536736319773, 0.12881853530416265, 0.09030711196828634, 0.21600620762910694, 0.1030584929685574, 0.09372407861519605, 0.12870884587755427, 0.08859883644618094, 0.14664591697510332, 0.16879455739399418, 0.2101436714292504, 0.22400863759685308, 0.1225011887436267, 0.16002629039576277, 0.13405400124611333, 0.2167068692506291, 0.15932469366816804, 0.2473733908846043, 0.1039484616194386, 0.1742637256393209, 0.15430982370162383, 0.1302981105982326, 0.25306894385721534, 0.1623197493609041, 0.13824027817463502, 0.15200264984741807, 0.1094547743559815, 0.17386881401762366, 0.12585297256009653, 0.13453402236336842, 0.0566647377127083, 0.08294719635159709, 0.08342457542312331, 0.10816422407515347, 0.11569988768314943, 0.13184381125029176, 0.23878539155703038, 0.07538611418567598, 0.12089412732166238], [0.10243209064356051, 0.03321516436699312, 0.04531181155471131, 0.018581531730887946, 0.055436731927329674, 0.01445169420549064, 0.05544671010284219, 0.050827657178160734, 0.03735917969606817, 0.04997775708034169, 0.06990490088355727, 0.0027759226759371813, 0.03371266677277163, 0.04243249750288669, 0.01904193231894169, 0.10704797459766269, 0.04967141336237546, 0.09848237328696996, 0.0064855914388317615, 0.04605122812790796, 0.06437968564569019, 0.04175653826678172, 0.03156236438371707, 0.03983086171501782, 0.039771274678059854, 0.03469931129075121, 0.06417868236894719, 0.01671373342105653, 0.04898024009889923, 0.021831509584444575, 0.01482355472035124, 0.03737561826710589, 0.04890952455752995, 0.03092907678365009, 0.0217664584852173, 0.016698038853064645, 0.019570697695598938, 0.02243258240923751, 0.05557772143220063, 0.04690949965151958, 0.04948729765601456, 0.017658133037912194, 0.006894955922689405, 0.025447312436881475, 0.0017781381734494062, 0.05068108672276139, 0.02695206323551247, 0.02928365003754152, 0.02613586220832076, 0.022830475609225687, 0.07222973785246722, 0.04069369002536405, 0.06113914234447293, 0.06715833849739283, 0.02441471784550231, 0.10696708792238496, 0.024926931473601144, 0.0351663188484963, 0.01821862708311528, 0.041219356935471296, 0.011112223546660971, 0.010632101311784936, 1.7884760373272002, 5.574987223371863, 15.323948822915554, 35.06348870694637, 37.8417856246233, 41.450778767466545, 41.97586119174957, 37.311337888240814, 35.54677717387676, 33.97304601967335, 23.837139308452606, 18.33759941160679, 10.726605914533138, 17.465380914509296, 24.123545140028, 26.936948373913765, 16.979157105088234, 30.733717940747738, 22.77454722672701, 16.316130682826042, 16.51996124535799, 12.099753431975842, 11.73482671380043, 12.17857165262103, 12.995194382965565, 11.322223953902721, 14.809412732720375, 11.19805421680212, 9.900881722569466, 10.794651713222265, 7.9872616566717625, 6.868716152384877, 7.483800072222948, 9.486501608043909, 10.074012782424688, 8.10282675549388, 10.590065941214561, 8.279933352023363, 11.914165690541267, 10.868412405252457, 12.65969043597579, 15.952949970960617, 27.742018774151802, 26.01331863552332, 24.172967188060284, 18.03747821599245, 20.689933486282825, 24.868434369564056, 30.91329250484705, 27.46802307665348, 25.55565219372511, 35.77588587999344, 32.32317455112934, 44.414019361138344, 33.44766341149807, 26.187873668968678, 15.518721621483564, 9.58112033084035, 3.4611910488456488, 1.0542112751863897, 0.07199232481070794, 0.0513017745106481, 0.07709650482865982, 0.005439942005978082, 0.020551805791910738, 0.05006902269087732, 0.03876228409353644, 0.07779952647979371, 0.040415674084215425, 0.021842185378773138, 0.04041290587338153, 0.017480672540841624, 0.013362727004277986, 0.004466746131583932, 0.030888885776221287, 0.013144842650945066, 0.014727097786817467, 0.047695122339064255, 0.07342514480114914, 0.017841519584180787, 0.022777664380555507, 0.026640569012670312, 0.07456521721906029, 0.03382754381163977, 0.008289349825645331, 0.041056607660721056, 0.028013080227538012, 0.020829287386732176, 0.04762153097544797, 0.03183792381605599, 0.04858947708271444, 0.0521768927865196, 0.02914793905802071, 0.01618311453057686, 0.010153771363548003, 0.05853625603776891, 0.027098488972114865, 0.02685445226234151, 0.012446460350474808, 0.03798376004851889, 0.08669297152664512, 0.0306125211136532, 0.01779269183316501, 0.055993316709646024, 0.052459591679507867, 0.057610115109127946, 0.054667135918862186, 0.021853464168088976, 0.016479116420669015, 0.015230384306050837, 0.01235708907188382, 0.03916366353223566, 0.08061092288699001, 0.054967984033282846, 0.08750334483920597, 0.032127862359629944, 0.026738320993899833, 0.05525385931832716, 0.05072253567050211, 0.015636736134183593, 0.041539986996212974, 0.0821134157013148, 0.03674551262520254, 0.05926590594754089, 0.012695792283921037, 0.019566927585401572, 0.02810730515193427, 0.08264926116680726, 0.02841210149199469, 0.10401184103102423, 0.017419274663552642, 0.03556929019396193, 0.039364885742543265, 0.03828171007626224, 0.01331823432337842, 0.057782708972808905, 0.00806207081041066, 0.03327435806568246, 0.03161034423101228, 0.10640294436598197, 0.05112503575219307, 0.014787060536036734, 0.02817528587911511, 0.035158196042175405, 0.04431889217812568, 0.014205209336068947, 0.04338623890362214, 0.013379365027503809, 0.050366917057544924, 0.04408440690895077, 0.0728505889128428, 0.023529727150162216, 0.04980523000995163, 0.047822307897149585, 0.021738707728218287, 0.022836345997347962, 0.020674833467637654, 0.03662389688543044, 0.01847081814048579, 0.037230120215099305, 0.04794729298737366, 0.006459469695982989, 0.0017708096970636689, 0.039157140054157935, 0.045302898361114785, 0.08679396298248321, 0.06735259565175511, 0.08556386805139482, 0.07913540714071132, 0.061632536962861195, 0.03659828536910936, 0.04964940126228612, 0.05230380374996457, 0.02929549285909161, 0.02908040361944586, 0.15836713020689785, 3.107420294545591, 8.89585180208087, 20.612698830664158, 41.56337432563305, 43.051131293177605, 46.26490384340286, 47.50977784395218, 43.98167096078396, 39.794687032699585, 37.20571115612984, 29.910152032971382, 23.42718120664358, 14.171871542930603, 20.640859119594097, 26.24138619750738, 30.442949943244457, 22.525556087493896, 30.636042281985283, 34.68964196741581, 21.37193039059639, 21.31699673831463, 16.367370933294296, 16.793111488223076, 17.60064795613289, 17.89893575012684, 16.442614495754242, 20.08331123739481, 13.191139418631792, 10.721102859824896, 12.33644938096404, 10.074812639504671, 9.59502188488841, 10.864366572350264, 11.097666453570127, 12.40279097110033, 10.73207002133131, 10.822660960257053, 11.309746373444796, 12.700846027582884, 13.621345683932304, 15.340496934950352, 23.10584954917431, 30.621652454137802, 30.55683173239231, 26.901652067899704, 21.301463171839714, 24.937077686190605, 23.560466654598713, 28.373704478144646, 26.853691041469574, 29.82642162591219, 38.047088608145714, 36.397403329610825, 48.36744882166386, 37.798186764121056, 32.909574285149574, 20.81752873957157, 13.750042878091335, 4.687863551080227, 1.4369133207947016, 0.22772948403144255, 0.019475105364108458, 0.02062286643194966, 0.03416605592065025, 0.04261959664290771, 0.028158619097666815, 0.03822562597633805, 0.048049115648609586, 0.10273711333866231, 0.04224489370244555, 0.04417921998538077, 0.010543021326157032, 0.024174326936190482, 0.03026355214387877, 0.004836414991586935, 0.026889732107520103, 0.0745719856058713, 0.11702097734087147, 0.026291913600289263, 0.017287189075432252, 0.028935898189956788, 0.06482476645032875, 0.02401375400950201, 0.011922763842449058, 0.03502454637782648, 0.025448319902352523, 0.0520057906396687, 0.019125125218124595, 0.09972800136893056, 0.10462134465342388, 0.05043153214501217, 0.05106892196636181, 0.027559689224290196, 0.04166660852206405, 0.07948553015012294, 0.07118511304724962, 0.030358931107912213, 0.03257233831391204, 0.0329067611892242, 0.11259413324296474, 0.0531908668926917, 0.012200471792311873, 0.032874236567295156, 0.004254952027622494, 0.07939725168398581, 0.037065018332214095, 0.021152134613657836, 0.047292562885559164, 0.01364806423225673, 0.013944296188128646, 0.03256373311160132, 0.04159630487265531, 0.021250892204989213, 0.012978357590327505, 0.1787338888971135, 0.14027653844095767, 0.15075027564307675, 0.17834595346357673, 0.10616310450132005, 0.09691363637102768, 0.10508836334338412, 0.10882991569815204, 0.14467922563198954, 0.11565445340238512, 0.15577961748931557, 0.05823455074278172, 0.08694389907759614, 0.1488641370087862, 0.21270525350701064, 0.2879899606341496, 0.17633036943152547, 0.27976245211903006, 0.14780540397623554, 0.1573964604176581, 0.14022786839632317, 0.14062739617656916, 0.16768519504694268, 0.12136366931372322, 0.14577782683772966, 0.15043861814774573, 0.1630068148369901, 0.180612116237171, 0.1763233041856438, 0.14857450645649806, 0.10724163803388365, 0.2020527477725409, 0.16018545138649642, 0.17208090604981408, 0.15891179238678887, 0.23374812357360497, 0.0924022393883206, 0.143467535963282, 0.09688888574601151, 0.17990633379667997, 0.08326422699610703, 0.07687320001423359, 0.10019536144682206, 0.11526484071509913, 0.07528069210820831, 0.2897143556037918, 0.0889533974986989, 0.109178502461873, 0.07364439748926088, 0.15879527520155534, 0.18269461230374873, 0.30307716981042176, 0.16497246717335656, 0.23259731970028952, 0.16983577574137598, 0.1652383935288526, 0.10676693811547011, 0.11770982397138141, 0.1701710038469173, 0.11377572882338427, 0.10399637467344292, 0.2311087941052392, 3.1581340357661247, 10.113205779343843, 23.74402340501547, 46.30288280546665, 50.45608274638653, 53.670368269085884, 55.80653004348278, 52.914113849401474, 50.31710900366306, 49.377415627241135, 38.37453983724117, 32.678284496068954, 20.345054492354393, 27.363317795097828, 37.51133255660534, 38.765398263931274, 29.19395126402378, 42.96293422579765, 40.84772452712059, 24.65126272290945, 28.997104726731777, 21.465010195970535, 21.416055522859097, 20.65146055072546, 19.73362360149622, 16.3397616147995, 21.46578725427389, 16.285622119903564, 14.55885797739029, 15.188751127570868, 12.893542237579823, 11.731315702199936, 11.341589614748955, 13.66091676056385, 14.760052431374788, 11.199823021888733, 13.508929666131735, 12.702915016561747, 16.6312762722373, 15.247010551393032, 18.215302973985672, 23.163524754345417, 38.09707872569561, 34.05085064470768, 35.99492132663727, 28.51712018251419, 31.80325224995613, 35.88891461491585, 40.29660589993, 38.22732053697109, 38.54431472718716, 45.90276427567005, 43.52323696017265, 55.98914064466953, 44.05591517686844, 36.539846286177635, 21.34473904967308, 15.50958026200533, 5.806763861328363, 1.9248633063398302, 0.27282325259875506, 0.11787941213697195, 0.1429489380097948, 0.10972176940413192, 0.10644780719303526, 0.1128794890246354, 0.08772099448833615, 0.12868374644313008, 0.22769724513636902, 0.1295878307428211, 0.12393567114486359, 0.1015251490753144, 0.08850740385241807, 0.11829113340354525, 0.14870925078867003, 0.1618885764037259, 0.20664950658101588, 0.15597426798194647, 0.16218749864492565, 0.06752213928848505, 0.13073170295683667, 0.15736267785541713, 0.12087909883121029, 0.14055451727472246, 0.1684133309754543, 0.07815503005986102, 0.1016753597650677, 0.11020386853488162, 0.1918009720975533, 0.16477524884976447, 0.17840021930169314, 0.13976638612803072, 0.06536208136822097, 0.08425710184383206, 0.11187223135493696, 0.21450120635563508, 0.1379415043629706, 0.14748856629012153, 0.22772624826757237, 0.18292360939085484, 0.25850381003692746, 0.1397220353828743, 0.08161838093656115, 0.13448959740344435, 0.18683416361454874, 0.13711561274249107, 0.12016664448310621, 0.14913254213752225, 0.19866839109454304, 0.12336229527136311, 0.14264838304370642, 0.1811844011535868, 0.13808890973450616, 0.12275000859517604], [0.045464957438525744, 0.09823589120060205, 0.023365642009594012, 0.07027171479421668, 0.038330231691361405, 0.021856020866835024, 0.04705479361291509, 0.039552686212118715, 0.06475152389612049, 0.02968340973893646, 0.021123224250914063, 0.05399743669840973, 0.02333486143470509, 0.09557267199852504, 0.046541015908587724, 0.026941899523080792, 0.04095682961633429, 0.04624973407771904, 0.010407194386061747, 0.016314047934429254, 0.0387989424780244, 0.031184945182758383, 0.0509975496242987, 0.031793610178283416, 0.0406762384227477, 0.03902417687640991, 0.03719142834597733, 0.03536860232998151, 0.0750260018685367, 0.02519109893910354, 0.029945877686259337, 0.04794019434484653, 0.07121971939341165, 0.027597009975579567, 0.015277935563062783, 0.03904899058397859, 0.06823503892519511, 0.01624636035558069, 0.036784438270842656, 0.07190705204266123, 0.04247179051162675, 0.03909514103725087, 0.041503413958707824, 0.02154524281650083, 0.01797297805751441, 0.025154097311315127, 0.029363928151724394, 0.07636885871761478, 0.03615137888118625, 0.017832498779171146, 0.0599689461523667, 0.05106135206006002, 0.05591387351159938, 0.04765712066728156, 0.03550245237420313, 0.04668609093641862, 0.08355629921425134, 0.03945505668525584, 0.04468236642424017, 0.03299570016679354, 0.043629080755636096, 0.013073192003503209, 0.04406026484502945, 0.3862306906376034, 4.755055345594883, 12.132888603955507, 24.798559918999672, 35.463770627975464, 36.419217959046364, 44.304087460041046, 36.550538912415504, 39.01039391756058, 26.64134133607149, 25.35019151866436, 22.502151243388653, 24.292301684617996, 32.21927672624588, 20.339711979031563, 28.076727613806725, 23.048803210258484, 16.31120804697275, 29.746232628822327, 26.265699192881584, 26.94125734269619, 23.859805092215538, 19.916162006556988, 11.698926240205765, 13.193654883652925, 15.671232137829065, 19.80660818517208, 18.034444078803062, 22.966516725718975, 17.729772627353668, 24.684754125773907, 12.486576475203037, 18.81321609020233, 25.865734554827213, 19.995288960635662, 18.89498770236969, 20.843050070106983, 22.79844604432583, 30.425824262201786, 16.95452492684126, 23.398310355842113, 32.97548934817314, 34.58401903510094, 22.980659566819668, 20.71521732956171, 23.615227416157722, 28.735372871160507, 31.840748637914658, 27.962602637708187, 36.5802039206028, 37.24564701318741, 37.88724258542061, 25.49682755023241, 21.463665068149567, 8.62319078296423, 3.481334480457008, 1.1521675251424313, 0.05704932234948501, 0.03269557564635761, 0.022645001772616524, 0.015457234731002245, 0.025010786739585456, 0.06196976515639108, 0.021308766736183316, 0.022166730268509127, 0.018249455897603184, 0.040800021233735606, 0.040836030239006504, 0.007916945687611587, 0.02141532244422706, 0.030784419213887304, 0.04500596136495005, 0.03664927833597176, 0.08044822927331552, 0.08147209620801732, 0.07800379520631395, 0.03250997564464342, 0.05485429443069734, 0.021669257548637688, 0.013352137484616833, 0.09016697222250514, 0.039134359831223264, 0.05373841973778326, 0.10496476606931537, 0.03761858999496326, 0.048050640762085095, 0.0324406182335224, 0.0690438759920653, 0.04153910755121615, 0.065740443096729, 0.06407768349163234, 0.04835580817598384, 0.06095924945839215, 0.04205597630061675, 0.023315803082368802, 0.03963723167544231, 0.05462984670884907, 0.09229139963281341, 0.03808286644925829, 0.025457843512413092, 0.10014173385570757, 0.019758366433961783, 0.013575817083619768, 0.03038678947632434, 0.05626417463645339, 0.04844427960051689, 0.019715381240530405, 0.031413957112818025, 0.04045974281325471, 0.03131528486846946, 0.03876764611050021, 0.03550186607753858, 0.011300742044113576, 0.013915678046032554, 0.03957273904234171, 0.03588400533772074, 0.022885236830916256, 0.04104181665752549, 0.02318038710654946, 0.06377495403285138, 0.05006894105463289, 0.020321556330600288, 0.017046440079866443, 0.040132292415364645, 0.03113464241323527, 0.04353946271294262, 0.020998552718083374, 0.04483232849452179, 0.03018783638253808, 0.0739460953627713, 0.02583859681180911, 0.05338163595297374, 0.005889552230655681, 0.04615074270986952, 0.042963841842720285, 0.04075683937116992, 0.025436365758650936, 0.03686808573547751, 0.041953953259508125, 0.05908785358769819, 0.03145613336528186, 0.06829664460383356, 0.03215399709006306, 0.04286269082513172, 0.028612965616048314, 0.06404511805158108, 0.0428741161886137, 0.042556807238725014, 0.053719376228400506, 0.01914938973641256, 0.031998613631003536, 0.011457048549345927, 0.08550848157028668, 0.024469542149745394, 0.04085495871549938, 0.09296693213400431, 0.029908247088314965, 0.06521353308926336, 0.02432276389299659, 0.01890158291644184, 0.051420380841591395, 0.09630446671508253, 0.0683867784391623, 0.013696553378395038, 0.019906705056200735, 0.07644061697646976, 0.04075198943610303, 0.08173496491508558, 0.02478650785633363, 0.04872551275184378, 0.03158256193273701, 0.029675750774913467, 0.04061914129124489, 0.018681252258829772, 0.060172224111738615, 0.16863410506630316, 0.7092609163373709, 5.918405670672655, 15.637993421405554, 31.089175567030907, 41.69019252061844, 44.12032552063465, 49.93041515350342, 43.68325777351856, 47.44995765388012, 32.60562479496002, 29.41244713962078, 23.534793332219124, 22.37780101597309, 30.534323640167713, 23.626083433628082, 23.2632390037179, 29.75513555109501, 23.372441343963146, 29.66330397874117, 30.71849025785923, 27.65410289168358, 27.227298393845558, 26.86593208462, 20.99170569330454, 21.73015806823969, 24.881004095077515, 25.290209837257862, 24.419000186026096, 31.983370184898376, 25.882425159215927, 28.5268609598279, 19.61724154651165, 19.944861866533756, 31.990977376699448, 25.18044512718916, 21.157355904579163, 29.168760515749454, 25.52513413131237, 31.851996034383774, 19.051474705338478, 25.85545990616083, 40.589444786310196, 38.1407155841589, 25.733678340911865, 21.28971040248871, 23.36374931037426, 28.933965414762497, 34.56860326230526, 30.879324227571487, 38.35508108139038, 42.821137234568596, 43.49411532282829, 32.19508342444897, 26.16874549537897, 12.768837679177523, 5.223832866176963, 1.936845132149756, 0.06993558868998662, 0.0729200613568537, 0.001732437995087821, 0.05951475919573568, 0.011754196129913907, 0.012954008652741322, 0.026210976830043364, 0.02715718172112247, 0.020715668288175948, 0.055749677048879676, 0.02606414105684962, 0.03793424395553302, 0.03566676386981271, 0.0232616467110347, 0.028311625828791875, 0.0637559402093757, 0.024455736347590573, 0.03979270419222303, 0.006241346463866648, 0.0767338766308967, 0.016389385200454853, 0.030534936995536555, 0.01590166059031617, 0.051340336503926665, 0.042503101722104475, 0.03444862122705672, 0.0528179228422232, 0.04161737073445693, 0.056731586664682254, 0.026127642922801897, 0.050272174485144205, 0.1113077909394633, 0.06058344071789179, 0.11193652360816486, 0.053074976822244935, 0.06236679560970515, 0.028307814900472295, 0.051561737709562294, 0.03350332175614312, 0.01896795874927193, 0.020789476729987655, 0.06241804832825437, 0.06438755983253941, 0.01294673003940261, 0.07967323414050043, 0.05781214997114148, 0.0379442740813829, 0.03696131803735625, 0.022147796225908678, 0.02881041215005098, 0.07811839022906497, 0.023017528365016915, 0.013512016503227642, 0.05352978718292434, 0.056529911744291894, 0.02892177326430101, 0.0729955080896616, 0.26525898661930114, 0.0784245780960191, 0.09165129726170562, 0.11700959279551171, 0.2768358966568485, 0.11927701722015627, 0.10423427753266878, 0.2092140424065292, 0.17888890870381147, 0.1310877557261847, 0.1031364630034659, 0.1441746691125445, 0.23550048266770318, 0.20546309446217492, 0.12821939948480576, 0.22507845831569284, 0.12251485910383053, 0.1276910793967545, 0.11994302054517902, 0.1026110076054465, 0.1346245050081052, 0.10524232187890448, 0.08065019734203815, 0.2192841106443666, 0.09140775408013724, 0.18625047930981964, 0.11539670551428571, 0.14457957004196942, 0.16590061190072447, 0.14792573580052704, 0.1523168306448497, 0.16234012873610482, 0.06111068469181191, 0.13707329548196867, 0.14519568620016798, 0.1364883643691428, 0.09203998968587257, 0.13241194013971835, 0.2715035359142348, 0.16870156629011035, 0.11913666225154884, 0.1792616894817911, 0.08389015434659086, 0.11621611818554811, 0.19140487303957343, 0.12905289069749415, 0.1415430282941088, 0.24330033600563183, 0.16038402041886002, 0.09416387532837689, 0.07246396708069369, 0.20182535372441635, 0.1266169096925296, 0.1591489085694775, 0.19303587614558637, 0.15863886015722528, 0.12192685549962334, 0.2635010762605816, 0.18477310077287257, 0.10208625724771991, 0.1380271778907627, 0.3382375440560281, 0.9194711584132165, 6.528970682993531, 16.8593742325902, 34.24285054206848, 45.321669057011604, 51.051514595746994, 59.086981415748596, 52.84117676317692, 57.05424249172211, 43.70435044169426, 39.01451289653778, 36.591109335422516, 37.261541560292244, 47.06812374293804, 30.776463747024536, 40.561987459659576, 34.71446603536606, 29.006733410060406, 42.77062274515629, 38.29268842935562, 39.291624426841736, 37.655417025089264, 35.14767698943615, 23.404768109321594, 22.709897495806217, 27.89866726845503, 29.9370089918375, 28.18885199725628, 34.09077890217304, 28.698598444461823, 35.80331280827522, 20.377172268927097, 26.851641051471233, 38.01191009581089, 28.083075173199177, 27.16226678341627, 29.470574520528316, 31.925495490431786, 43.23313772678375, 24.874048568308353, 33.011268228292465, 48.20213869214058, 50.61155520379543, 31.715153977274895, 32.31203354895115, 35.374562814831734, 39.96109530329704, 42.8794527053833, 37.29375623166561, 50.82619808614254, 48.11882056295872, 50.858203768730164, 34.94717314839363, 28.11652097851038, 14.045748710632324, 5.737989451736212, 2.1250164974480867, 0.2999404084403068, 0.23849102610256523, 0.07648664497537538, 0.16371854930184782, 0.12302872215514071, 0.09933631808962673, 0.12793429603334516, 0.15030256763566285, 0.20713119010906667, 0.16446152818389237, 0.10567407371127047, 0.23521569091826677, 0.07529662601882592, 0.12540118274046108, 0.1175900710222777, 0.20506362605374306, 0.15662915393477306, 0.19152642198605463, 0.11743234237655997, 0.16707293805666268, 0.2099909819662571, 0.13311472430359572, 0.20665453834226355, 0.1935443066759035, 0.13547882088460028, 0.14842352393316105, 0.14891207974869758, 0.1536478428170085, 0.1297882996732369, 0.147642235388048, 0.3131192590808496, 0.2081910363631323, 0.15567739406833425, 0.18144243105780333, 0.13428571459371597, 0.13167642726330087, 0.18815984716638923, 0.12436737102689222, 0.14139954146230593, 0.20926667551975697, 0.22824086830951273, 0.19322889391332865, 0.12682557193329558, 0.14109560230281204, 0.1537395574268885, 0.1350624463520944, 0.1349192563793622, 0.23314282792853191, 0.10076297825435176, 0.1329065370373428, 0.13442578754620627, 0.1249395520426333, 0.14199241355527192, 0.14925878145731986, 0.18210430804174393, 0.1661564747337252], [0.024863227372406982, 0.06398725279723294, 0.0552069518744247, 0.04550649544398766, 0.0347033411526354, 0.08840659793349914, 0.031194463226711378, 0.008830117585603148, 0.010096654750668677, 0.045344406680669636, 0.01768502846971387, 0.026402703260828275, 0.041364146236446686, 0.02445261190587189, 0.03508536909066606, 0.061168709507910535, 0.05346489379007835, 0.010988751510012662, 0.011385069501557155, 0.06354163022479042, 0.0846748567710165, 0.04462335826246999, 0.030803227091382723, 0.0030203170081222197, 0.03601586271543056, 0.07053836845443584, 0.004707906555267982, 0.03395181644009426, 0.04264260693162214, 0.04057559577631764, 0.02760555209533777, 0.043419108624220826, 0.03880302429024596, 0.03010329277458368, 0.025492357090115547, 0.013828395913151326, 0.04404772254929412, 0.01595157002157066, 0.03388783588889055, 0.06702000217046589, 0.05864945582288783, 0.020789233676623553, 0.025449329223192763, 0.02733787983743241, 0.056743924869806506, 0.0284368205757346, 0.03966830910940189, 0.08947623311541975, 0.021036431935499422, 0.04548475793853868, 0.049901690654223785, 0.02499897360394243, 0.06281584690441377, 0.05853903167007957, 0.028636870192713104, 0.004703381309809629, 0.04599876199790742, 0.03469871015113313, 0.0067248120740259765, 0.03152938334096689, 0.06318921397905797, 0.008101160656224238, 0.0603605700598564, 0.021162702796573285, 0.25214850262273103, 1.8338358658365905, 8.148080427199602, 15.559517182409763, 25.792717672884464, 33.90511326491833, 37.805714160203934, 40.95893315970898, 38.624475225806236, 40.72935327887535, 39.06199894845486, 44.898622557520866, 38.46113719046116, 34.24918480217457, 32.432038709521294, 23.853337839245796, 21.068269684910774, 19.484271481633186, 19.703365825116634, 18.025522157549858, 15.497555807232857, 27.397086583077908, 20.959741808474064, 16.96878746151924, 27.440510652959347, 19.788429960608482, 18.761090487241745, 19.210574068129063, 25.158753991127014, 21.652649827301502, 31.585299745202065, 22.14851561933756, 46.54632814228535, 52.68033139407635, 30.79447478055954, 15.489590484648943, 32.359211817383766, 35.84012523293495, 30.54697696119547, 28.909430131316185, 28.779798187315464, 39.709947779774666, 39.19171258807182, 28.493627943098545, 27.462703362107277, 34.16125752031803, 32.17397555708885, 35.3136482834816, 34.47158306837082, 24.81348741799593, 19.33084711432457, 8.140799067914486, 4.372115693986416, 0.9428995731286705, 0.07607382533024065, 0.021189373728702776, 0.04256811385857873, 0.02446519873046782, 0.07823348249075934, 0.04126115469262004, 0.0275205149591784, 0.020097511223866604, 0.004144732893109904, 0.010919279066001764, 0.023367584581137635, 0.025411804381292313, 0.023111732880352065, 0.08375115008675493, 0.012387400238367263, 0.007721587371634087, 0.009458413314860081, 0.011275684355496196, 0.013461747130349977, 0.03122914749837946, 0.03525943982822355, 0.04825609692488797, 0.07579246972454712, 0.051582577216322534, 0.024177518171200063, 0.024341464159078896, 0.05656700057443231, 0.014737319015694084, 0.11844498061691411, 0.0323953138286015, 0.037194133474258706, 0.02225008087407332, 0.062013622373342514, 0.05678928122506477, 0.04387240500363987, 0.08271366474218667, 0.013161015904188389, 0.08012615202460438, 0.031414758632308803, 0.030291789007605985, 0.037616211411659606, 0.04783306903846096, 0.004804126001545228, 0.020415042818058282, 0.03923715841665398, 0.04654129050322808, 0.19059927173657343, 0.0435198143532034, 0.012701803680101875, 0.03170877527736593, 0.07347365899477154, 0.049712880863808095, 0.042709641420515254, 0.06262567156227306, 0.018444601773808245, 0.0354751932900399, 0.030563225809601136, 0.024111101520247757, 0.02185014120186679, 0.011173143666383112, 0.01450912623113254, 0.11721242917701602, 0.06805894212448038, 0.041468024646746926, 0.04557025706162676, 0.029135344811948016, 0.017381074467266444, 0.04257183943991549, 0.05129804521857295, 0.054998137493385, 0.06118485864135437, 0.062912956927903, 0.012778630807588343, 0.019232632730563637, 0.03039945051568793, 0.06665312146651559, 0.0475811766955303, 0.034515852385084145, 0.0486956301756436, 0.005448272613648442, 0.022155403239594307, 0.02806726814014837, 0.07238359248731285, 0.033700788699206896, 0.024237420620920602, 0.02662064420292154, 0.03617564339947421, 0.04040828971483279, 0.01618457285076147, 0.013599848753074184, 0.02805860356602352, 0.05928394755756017, 0.031319203408202156, 0.05656458488374483, 0.01580348558491096, 0.029905272931500804, 0.039516914694104344, 0.06888979871291667, 0.050495160176069476, 0.05516657904081512, 0.05861664547410328, 0.012924015682074241, 0.023801080460543744, 0.009013846447487595, 0.04280304070562124, 0.052828042025794275, 0.03245048508688342, 0.026465609553270042, 0.03447286719165277, 0.052370745470398106, 0.09659104704041965, 0.022009497006365564, 0.04281478148186579, 0.026756787483463995, 0.034527912284829654, 0.08887935342499986, 0.04576358282065485, 0.022446278744610026, 0.009176004787150305, 0.07776198122883216, 0.026469207114132587, 0.0347065954701975, 0.3420522127998993, 2.6608357205986977, 9.816181417554617, 19.235386736690998, 31.79681919515133, 41.84180058538914, 43.71723175048828, 47.90047287940979, 45.539632961153984, 44.510473385453224, 42.29557603597641, 47.89116717875004, 41.83219090104103, 33.995236828923225, 34.14919316768646, 25.082982257008553, 18.20557549595833, 20.523994490504265, 18.126013465225697, 22.575361914932728, 22.751075886189938, 29.678847044706345, 21.522162929177284, 18.85228369385004, 30.298396199941635, 26.577835343778133, 26.759235709905624, 24.567000344395638, 30.976711101830006, 31.11355695873499, 34.19058434665203, 27.658463157713413, 51.883103772997856, 55.42528510093689, 30.904402881860733, 18.13558515161276, 33.81895288825035, 44.50961463153362, 30.72664462029934, 28.28173041343689, 33.68078090250492, 46.20665676891804, 41.264774948358536, 30.647561363875866, 30.793999806046486, 37.612851709127426, 36.63154676556587, 39.29059088230133, 40.03587149083614, 30.87390761822462, 23.58257196843624, 11.39550207182765, 6.2239073775708675, 1.532218619249761, 0.24080971808871254, 0.09509661394986324, 0.03924093223758973, 0.021723983518313617, 0.010892028330999892, 0.017573350087332074, 0.06718958291457966, 0.06848923192592338, 0.08488388266414404, 0.04639814877009485, 0.018607877973408904, 0.04647890556952916, 0.015483739607589087, 0.058543699778965674, 0.02874969333788613, 0.010528862076171208, 0.03228893066989258, 0.03451609729381744, 0.11463203365565278, 0.06926930334884673, 0.04342449661635328, 0.019482836687529925, 0.044107446883572266, 0.040559361295890994, 0.07378144990070723, 0.04314945668738801, 0.030755673979001585, 0.0650115947064478, 0.0495688225782942, 0.027879519620910287, 0.03802949489909224, 0.04175156958808657, 0.01284040810787701, 0.08130419271765277, 0.04752652865136042, 0.08173950685886666, 0.012726468030450633, 0.041610483604017645, 0.06780105322832242, 0.007241521261676098, 0.06244126270757988, 0.021758866314485203, 0.04571271601889748, 0.028991587096243165, 0.02967227752378676, 0.030168674129527062, 0.018086361524183303, 0.01671614169026725, 0.02788087589578936, 0.048445567226735875, 0.02890903615480056, 0.01794979521946516, 0.02179380477173254, 0.030088562998571433, 0.052874437387799844, 0.038454686145996675, 0.031017934124975, 0.020846328952757176, 0.14049462595721707, 0.29953059449326247, 0.15503809321671724, 0.1392858158214949, 0.1484480148064904, 0.17244820977794006, 0.0798413751181215, 0.12740532285533845, 0.12806576007278636, 0.11080750176915899, 0.10222755474387668, 0.1324883071356453, 0.08681702151079662, 0.124593740911223, 0.11304642772302032, 0.18477844423614442, 0.15943839069223031, 0.15127941209357232, 0.09915620626998134, 0.11695488909026608, 0.13012909388635308, 0.10429512622067705, 0.11686191282933578, 0.17153376509668306, 0.14232777524739504, 0.14580022485461086, 0.0998928101034835, 0.2046946599148214, 0.2028089962550439, 0.13282096741022542, 0.0837287149624899, 0.11249182076426223, 0.13740340276854113, 0.12190735185868107, 0.21676913544069976, 0.13551848125644028, 0.12112912838347256, 0.09635496244300157, 0.08105040047666989, 0.20590477623045444, 0.11052280649892054, 0.1424034297815524, 0.14672822115244344, 0.14369749784236774, 0.09724295698106289, 0.11106894555268809, 0.11453693485236727, 0.17527000367408618, 0.1621360084391199, 0.13614862400572747, 0.131383768748492, 0.10793787645525299, 0.1581422149320133, 0.21307626797351986, 0.15472745988518, 0.09465393770369701, 0.20422801229869947, 0.1475338521413505, 0.09855007199803367, 0.09493352699792013, 0.16291511507006362, 0.1437123111099936, 0.1258593105012551, 0.14541369950165972, 0.5214545095805079, 2.8671204764395952, 11.071700546890497, 22.251446396112442, 34.427049458026886, 46.060782596468925, 51.03727675974369, 56.877916753292084, 56.20697155594826, 54.22214426100254, 51.65171518921852, 59.4486004114151, 53.99487845599651, 46.92246995866299, 49.24962468445301, 35.009242817759514, 31.8062711879611, 30.34860100597143, 28.307958506047726, 28.969749994575977, 26.488116458058357, 41.07874073088169, 28.894044756889343, 25.903844609856606, 42.086758241057396, 34.238978549838066, 31.83292865753174, 30.417447611689568, 38.40283311903477, 36.247064396739006, 46.3862731307745, 28.731975853443146, 61.0633085668087, 64.69655960798264, 37.63063095510006, 25.319177582859993, 39.69133257865906, 52.884547635912895, 42.66171678900719, 35.78858859837055, 41.343734711408615, 56.063738241791725, 50.451124012470245, 36.771744042634964, 39.156933054327965, 46.211121529340744, 45.55290944874287, 45.43923854827881, 46.81435815989971, 35.805630683898926, 26.536810845136642, 13.772084545344114, 7.268007276579738, 1.9275941723026335, 0.25852660881355405, 0.16819197800941765, 0.10537968599237502, 0.13426769524812698, 0.15166538825724274, 0.20059880625922233, 0.150781030242797, 0.12685884983511642, 0.16717735823476687, 0.12262748001376167, 0.2576042676810175, 0.20071766863111407, 0.07620108881383203, 0.12758685217704624, 0.13348683714866638, 0.10200259494013153, 0.1687745490926318, 0.11489608237752691, 0.21627997106406838, 0.29174089373555034, 0.1134772296063602, 0.11567820212803781, 0.15335533273173496, 0.15455927437869832, 0.16053813480539247, 0.14732781710335985, 0.2517896593781188, 0.20452053722692654, 0.26716868102084845, 0.10047085408587009, 0.15666071005398408, 0.2042358196922578, 0.1353370409924537, 0.12951628770679235, 0.18044148164335638, 0.2256931792362593, 0.09759168475284241, 0.1886939411633648, 0.10388569819042459, 0.10508939492865466, 0.19390613335417584, 0.20652411330956966, 0.244015202333685, 0.09257639176212251, 0.1227787890820764, 0.12519562267698348, 0.3211539873154834, 0.12068534633726813, 0.0809734471840784, 0.12090600168448873, 0.14184851112077013, 0.10301650225301273, 0.12367531831841916, 0.15673033834900707, 0.16875506029464304, 0.09520789899397641, 0.20377582171931863, 0.11540871346369386], [0.027025250128644984, 0.08048144780332223, 0.023804635347914882, 0.04088883404619992, 0.054544562808587216, 0.050858229951700196, 0.013117729213263374, 0.05645226083288435, 0.036391140820342116, 0.08008829507161863, 0.04985562925867271, 0.03573244764993433, 0.04049751070851926, 0.03173066121235024, 0.026376984133094084, 0.029807661958329845, 0.0029751705415037577, 0.024853395771060605, 0.03161276734317653, 0.07597087460453622, 0.10951775300782174, 0.03218902646040078, 0.03161488988553174, 0.08318567066453397, 0.035023941527470015, 0.01587680606462527, 0.0982898824440781, 0.042236956433043815, 0.045357661438174546, 0.08827681856928393, 0.03148380434140563, 0.05185993264603894, 0.007549237952844123, 0.047766925126779824, 0.041826240776572376, 0.04382962761155795, 0.07554011725005694, 0.014656069615739398, 0.027001093221770134, 0.01184116285003256, 0.029904849907325115, 0.036742503216373734, 0.00719644042874279, 0.021063240164949093, 0.023213451640913263, 0.009493347133684438, 0.04893840152362827, 0.055711449022055604, 0.0387648370815441, 0.040213976899394765, 0.09123936819378287, 0.011619443448580569, 0.023769268300384283, 0.016641053043713327, 0.013200995399529347, 0.0032418392765976023, 0.018967771356983576, 0.029950286043458618, 0.029320093199203257, 0.004882517669102526, 0.013237850453151623, 0.024990553938550875, 0.08669823335367255, 0.03621125164499972, 0.03415722065255977, 0.0437020709796343, 0.7974757358897477, 3.1587973376736045, 6.834120433777571, 17.496729232370853, 22.885541170835495, 34.842842146754265, 35.21281309425831, 38.688881769776344, 49.16819505393505, 45.62673568725586, 46.45629197359085, 49.03642952442169, 41.219754964113235, 40.397847667336464, 39.64534364640713, 40.29962673783302, 42.187935411930084, 23.284210078418255, 19.821123406291008, 31.02359678596258, 25.400240533053875, 37.78571963310242, 25.073705054819584, 17.348647378385067, 29.520710930228233, 30.515366457402706, 33.61741550266743, 12.305356599390507, 26.30215633660555, 19.51612137258053, 34.3136977404356, 69.75600332021713, 51.0789605230093, 38.13942365348339, 41.156625151634216, 16.90719086676836, 24.379465207457542, 22.698557004332542, 34.17302928864956, 43.63982990384102, 39.758414179086685, 37.21171863377094, 30.77049996703863, 38.21132719516754, 39.75629389286041, 26.632377617061138, 22.603522203862667, 12.540464233607054, 4.95327265933156, 1.0884919669479132, 0.0929237985110376, 0.02009698800975457, 0.07710790421697311, 0.018228705448564142, 0.10582668153801933, 0.04891802956990432, 0.05362478950701188, 0.053556074053631164, 0.0481379507255042, 0.07357413836871274, 0.058403834627824835, 0.035360501788090914, 0.06397324847057462, 0.03152868572215084, 0.027832376545120496, 0.03499021091556642, 0.05171501346922014, 0.037882675824221224, 0.07207900023786351, 0.13344008184503764, 0.005614612955469056, 0.014888063124089967, 0.030128444159345236, 0.06178986484883353, 0.03876072929415386, 0.04434782109456137, 0.058319396775914356, 0.006798206304665655, 0.06661426261416636, 0.07275645490153693, 0.06534806962008588, 0.07343369434238411, 0.07522843006881885, 0.03229393645597156, 0.06412389702745713, 0.07525562235969119, 0.05403278148151003, 0.03694874976645224, 0.017634456671657972, 0.05966918157355394, 0.040305587608600035, 0.06029937998391688, 0.024300885379489046, 0.03998892803792842, 0.06960122147575021, 0.04579372143780347, 0.013661966513609514, 0.04169386018475052, 0.04745390579046216, 0.021218454785412177, 0.03980260073149111, 0.029448527420754544, 0.12228885287186131, 0.03840357072476763, 0.026474275982764084, 0.020402116460900288, 0.02064269661786966, 0.05199594976147637, 0.034773058505379595, 0.014292008145275759, 0.012603328104887623, 0.019660534671857022, 0.06967035253182985, 0.0516843256627908, 0.012673167911998462, 0.046243162360042334, 0.02921082679677056, 0.01761602357873926, 0.027642741115414537, 0.021215662454778794, 0.08922550594434142, 0.09397925867233425, 0.061019537824904546, 0.03322358403238468, 0.01602126325451536, 0.09177159197861329, 0.04659050973714329, 0.0420923934871098, 0.04140978089708369, 0.048202038888121024, 0.06347266986267641, 0.018435295241943095, 0.04798693480552174, 0.06841242706286721, 0.007267420360221877, 0.016959295244305395, 0.04451144610357005, 0.03529650639393367, 0.014627777090936434, 0.028700713446596637, 0.022577592499146704, 0.012788169260602444, 0.052462460080278106, 0.01852985042205546, 0.019307465336169116, 0.040420947043458, 0.008034690199565375, 0.06814919470343739, 0.07625487225595862, 0.02079884634440532, 0.059438982207211666, 0.03396609165065456, 0.012618400196515722, 0.03763499145861715, 0.042224781500408426, 0.013952719564258587, 0.01002067274384899, 0.01944135805388214, 0.01925055003084708, 0.06208098340721335, 0.03857590854750015, 0.08058747844188474, 0.021491635634447448, 0.020291211767471395, 0.05405867501394823, 0.0499308125290554, 0.03522632519889157, 0.05418573069619015, 0.06760389427654445, 0.009691220402601175, 0.01843807829573052, 0.015228030770231271, 0.06844759001978673, 0.026649686296877917, 0.051439832532196306, 0.10769598826300353, 0.9891632187645882, 4.582756916061044, 10.002088341861963, 21.966898664832115, 28.212577924132347, 41.55054621398449, 41.473828330636024, 47.51357764005661, 53.66865836083889, 51.59700192511082, 50.500825345516205, 51.36665068566799, 45.602789372205734, 42.8874246776104, 36.986082941293716, 37.83485859632492, 38.599932342767715, 23.977176994085312, 19.049844592809677, 36.21406316757202, 21.50578960776329, 27.936053462326527, 24.59384210407734, 21.573855355381966, 28.908941857516766, 25.93445386737585, 32.92093187570572, 15.776472240686417, 29.619517028331757, 21.169997826218605, 35.46741463243961, 78.01434338092804, 49.3801324814558, 27.045586444437504, 42.70378813147545, 23.905875720083714, 25.884380154311657, 20.864847600460052, 35.66474564373493, 48.2481200248003, 45.175376906991005, 40.16248069703579, 33.74460607767105, 42.83131308853626, 44.342906177043915, 32.27234087884426, 26.90765954554081, 15.368129052221775, 7.237084060907364, 2.0582153694704175, 0.28644249367062, 0.03990833822172135, 0.06822203649790026, 0.010068870597024215, 0.023356880956271198, 0.031242379991454072, 0.03670660553325433, 0.06386548120644875, 0.015787818847456947, 0.08630729222204536, 0.007932292373880045, 0.03251339323469438, 0.025667580011941027, 0.025318919033452403, 0.04626248046406545, 0.029296253560460173, 0.014258166211220669, 0.024865572559065185, 0.04642394582333509, 0.06008000113070011, 0.0271674882969819, 0.023646786103199702, 0.03439342399360612, 0.04294782629585825, 0.017240533961739857, 0.039921403731568716, 0.05169513875443954, 0.034070192705257796, 0.04681646030803677, 0.11806037000496872, 0.0434325711830752, 0.049495450148242526, 0.02846125207724981, 0.03651166560302954, 0.05289346976496745, 0.11231472206418402, 0.02766003686701879, 0.016539009593543597, 0.07848129302146845, 0.05101285642012954, 0.09005148662254214, 0.12156682481872849, 0.05098173445730936, 0.04746999555209186, 0.025278184402850457, 0.029833149164915085, 0.01104001165003865, 0.050412533164490014, 0.08297378750285134, 0.0066349013468425255, 0.05859683013113681, 0.02420324286504183, 0.05178441911994014, 0.04303241628804244, 0.03356992579938378, 0.05393217223172542, 0.02072656301606912, 0.04438189309439622, 0.051583404710981995, 0.024231398092524614, 0.11764279319322668, 0.1519283014931716, 0.1629634585697204, 0.1789037071284838, 0.1696013312903233, 0.07992428785655648, 0.08980670405435376, 0.07525790817453526, 0.12497302290285006, 0.17768949415767565, 0.16107893781736493, 0.1282810274278745, 0.13217378495028242, 0.11100034142145887, 0.1263508794363588, 0.29723118350375444, 0.08837922752718441, 0.12590760947205126, 0.10576921704341657, 0.19033760530874133, 0.17908189678564668, 0.1006090197188314, 0.058015197864733636, 0.1718081667786464, 0.1175032694300171, 0.1063647163391579, 0.2201889964635484, 0.12830934778321534, 0.08223701297538355, 0.1667371459188871, 0.07726415598881431, 0.13009878457523882, 0.09866687119938433, 0.09654750523623079, 0.20338117727078497, 0.20942301634931937, 0.1059792448359076, 0.275791427702643, 0.1290437177522108, 0.0765900632541161, 0.11782664543716237, 0.09189426156808622, 0.1468523676157929, 0.09896019022562541, 0.11835947778308764, 0.08819700058666058, 0.2347456887946464, 0.10846945457160473, 0.09798852595849894, 0.0781508962973021, 0.1856633959687315, 0.16499688383191824, 0.10758302596514113, 0.12113648306694813, 0.10463092577992938, 0.0919668139249552, 0.1377834120648913, 0.14131107745924965, 0.24091415310977027, 0.08496981594362296, 0.09618201976991259, 0.14098003506660461, 0.2628231985727325, 0.0816871112328954, 0.12399508748785593, 0.2088272201945074, 0.8270018734037876, 4.7788230702281, 11.370336022228003, 23.630800880491734, 31.673950888216496, 45.6483793258667, 48.901517763733864, 54.267194643616676, 64.89253029227257, 57.60158412158489, 61.388244330883026, 60.50062336027622, 55.960630774497986, 54.81395110487938, 51.56803607940674, 53.23506362736225, 57.42981813848019, 33.03022541105747, 28.725347109138966, 49.7050454467535, 36.28302566707134, 47.684948444366455, 37.625892609357834, 28.576526194810867, 43.04620295763016, 40.49938201904297, 48.85019011795521, 20.84853697568178, 41.561064049601555, 29.919049255549908, 41.38328678905964, 85.59882000088692, 58.770428001880646, 48.496976271271706, 51.019068136811256, 29.130779653787613, 36.065620332956314, 29.78219199925661, 45.35460568964481, 57.41710402071476, 55.01480832695961, 47.09025755524635, 42.11722120642662, 51.014660373330116, 51.84401527047157, 38.00884746015072, 28.410114124417305, 17.337187193334103, 7.592260027304292, 1.7381148459389806, 0.32163386000320315, 0.13659095886396244, 0.18364472460234538, 0.143162424210459, 0.2076848322758451, 0.15195519692497328, 0.12915352592244744, 0.1733843845431693, 0.12311796541325748, 0.1451204769546166, 0.1508909571566619, 0.1338187255896628, 0.09305826824856922, 0.0901261466788128, 0.13107717270031571, 0.17606500710826367, 0.09545596927637234, 0.10672085074475035, 0.18012437678407878, 0.3024889435619116, 0.15439644717844203, 0.1499190999311395, 0.1518177511752583, 0.25460507080424577, 0.25535882567055523, 0.15765135845867917, 0.13321065431227908, 0.12135667828260921, 0.12489920889493078, 0.20970780809875578, 0.1648908606148325, 0.12741531216306612, 0.20764959510415792, 0.08667960544698872, 0.1271626999368891, 0.20714431127998978, 0.11676256151986308, 0.11132341314805672, 0.23634522483916953, 0.13574776035966352, 0.16063943796325475, 0.13696305686607957, 0.21405677864095196, 0.15915209980448708, 0.16626760392682627, 0.1372769704903476, 0.0839977286523208, 0.25369012146256864, 0.10844937947695144, 0.14847669139271602, 0.17151898151496425, 0.09768537347554229, 0.16816598799778149, 0.11197884829016402, 0.07153734375606291, 0.10877064036321826, 0.10653331002686173, 0.09316380906966515, 0.11362933277268894, 0.15603297186316922], [0.027703053601726424, 0.13051112182438374, 0.037255423740134574, 0.016027233832573984, 0.027171625770279206, 0.03588543397199828, 0.07670607577892952, 0.03235468866478186, 0.02959831694170134, 0.02912268006184604, 0.04591494383930694, 0.00874805646162713, 0.057867710856953636, 0.12330103840213269, 0.0159596612866153, 0.02328200382180512, 0.03956700224080123, 0.011960273841395974, 0.005376243007049197, 0.039353720130748115, 0.01184920587547822, 0.09151408157777041, 0.06733983813319355, 0.014156197903503198, 0.0033557962842678535, 0.015805925395397935, 0.02612480235256953, 0.048328341290471144, 0.03572443987650331, 0.01698421656328719, 0.020809420093428344, 0.0077536963908642065, 0.047446959288208745, 0.03825860330834985, 0.026424257084727287, 0.06124198545876425, 0.05369507460272871, 0.023627566333743744, 0.10074534482555464, 0.011370772954251152, 0.0023720528679405106, 0.01929894177010283, 0.03290891712822486, 0.031127797956287395, 0.029801784148730803, 0.07410884092678316, 0.05239691359747667, 0.06299240383668803, 0.020415100334503222, 0.06093629483075347, 0.055567476083524525, 0.0014563190529770509, 0.017391223336744588, 0.02121197583619505, 0.0075348147765907925, 0.006619832038268214, 0.01947004762769211, 0.02914471257099649, 0.034210929879918694, 0.07950093713589013, 0.05486265101353638, 0.04647712441510521, 0.04780887502420228, 0.03395133404410444, 0.05170601863937918, 0.1365672843530774, 0.03883547840814572, 0.028215699530846905, 0.801066483836621, 2.654283447191119, 6.682203160598874, 12.657356411218643, 21.853077672421932, 22.058498449623585, 35.42413115501404, 38.56830283999443, 51.83196231722832, 52.3126707226038, 55.61948128044605, 47.33938738703728, 53.74537244439125, 53.76984313130379, 52.770033180713654, 45.082300901412964, 43.78812834620476, 27.890569902956486, 33.05167146027088, 33.720994144678116, 34.21661674976349, 31.07320312410593, 31.425088942050934, 29.355127215385437, 26.287745609879494, 23.393988087773323, 29.408710040152073, 34.6388690918684, 25.822422578930855, 57.993430495262146, 70.8520545065403, 53.11645299196243, 41.91812328994274, 24.595021940767765, 33.86250615119934, 36.363326758146286, 35.94509460031986, 47.0365322381258, 42.22982436418533, 43.332544192671776, 32.472137957811356, 25.46933602541685, 20.671601369976997, 11.122349929064512, 3.837712132371962, 1.7694156663492322, 0.20102763402974233, 0.03531354610458948, 0.17769664846127853, 0.02525122032238869, 0.03319245464808773, 0.05345760961063206, 0.031106249698495958, 0.023387459295918234, 0.03845790706691332, 0.033086446273955517, 0.046018640423426405, 0.032351159752579406, 0.056834767456166446, 0.009268762114515994, 0.0815423924359493, 0.02389825356658548, 0.03198133272235282, 0.018017386319115758, 0.08976092838565819, 0.09143216331722215, 0.032388100153184496, 0.06190010346472263, 0.018187787136412226, 0.014302696927188663, 0.04596528742695227, 0.02983951122587314, 0.030743018505745567, 0.0750790728488937, 0.04954902207828127, 0.04787067366123665, 0.059916750906268135, 0.014011816783749964, 0.05142553505720571, 0.023236666020238772, 0.03349479447933845, 0.04032335462397896, 0.025527206489641685, 0.019488951984385494, 0.06119884812505916, 0.04724333623016719, 0.01381317910272628, 0.09399444301379845, 0.02068577643512981, 0.0376828080334235, 0.02239581270259805, 0.04365704859083053, 0.02471335064910818, 0.0313758515403606, 0.0276196436243481, 0.08718962417333387, 0.03242600163503084, 0.039412936093867756, 0.01784457723260857, 0.00684815469867317, 0.06040494306944311, 0.003559225920071185, 0.022181320891832, 0.011633314188657096, 0.03078936191741377, 0.003178864103574597, 0.018389022334304173, 0.03948047524318099, 0.02274310441862326, 0.07841622151318006, 0.07052712491713464, 0.018223554943688214, 0.06558597247931175, 0.014074819555389695, 0.05480577652633656, 0.010897748434217647, 0.021500020047824364, 0.03415948791371193, 0.023972635317477398, 0.028962693431822117, 0.04223543874104507, 0.10347894189180806, 0.06539115129271522, 0.017133529254351743, 0.059941917133983225, 0.031067149648151826, 0.07583396320114844, 0.04239455520291813, 0.05545545260247309, 0.03181316948030144, 0.02996026050823275, 0.048397438949905336, 0.05289412656566128, 0.028590684487426188, 0.024687561017344706, 0.03611357016779948, 0.016458445752505213, 0.030931702131056227, 0.039146583003457636, 0.020352581814222503, 0.03906819365511183, 0.05878056363144424, 0.028939287949469872, 0.05548845590965357, 0.048011852413765155, 0.03443705485551618, 0.03386505566595588, 0.020936197470291518, 0.03523095620039385, 0.02155139336537104, 0.04453061948879622, 0.036555738042807207, 0.03722723326063715, 0.075110079778824, 0.020321667652751785, 0.03344191274663899, 0.06956870798603632, 0.027277007029624656, 0.045557625708170235, 0.03067484296479961, 0.012099512805434642, 0.026104255994141567, 0.021470358260557987, 0.024608574240119196, 0.0511518977873493, 0.05467607137688901, 0.01581096828886075, 0.03017778213688871, 0.03845105333311949, 0.04844819071877282, 0.06011083736666478, 0.08339913460076787, 0.05250799084024038, 0.1419264663127251, 0.04309157287934795, 0.13770875200862065, 1.067581451497972, 4.332838151603937, 9.01213601231575, 17.774213142693043, 27.66473852097988, 28.89163948595524, 42.37433061003685, 46.485527604818344, 57.06158749759197, 59.823332503437996, 61.56180761754513, 52.906791642308235, 57.30507083237171, 56.740766912698746, 55.93326844274998, 42.483677342534065, 42.192806750535965, 33.775232434272766, 34.98733699321747, 36.64921201765537, 35.43402202427387, 33.10423783957958, 34.77889157831669, 32.86765493452549, 32.16202899813652, 23.93530324101448, 27.458996661007404, 31.086012236773968, 27.167774587869644, 58.46291050314903, 72.42048874497414, 53.997409120202065, 46.055569276213646, 23.426787927746773, 35.48718877136707, 35.12346848845482, 39.0764419734478, 50.89972794055939, 48.69526103138924, 48.592392951250076, 36.82036243379116, 30.005350224673748, 25.79443898051977, 13.79113482311368, 5.9957975428551435, 2.7939152671024203, 0.3486819367390126, 0.049673988614813425, 0.1037662940507289, 0.042911327473120764, 0.026396382017992437, 0.06860920751933008, 0.007365935825873748, 0.0312282754748594, 0.015618546094628982, 0.029366442176979035, 0.029474964576365892, 0.06605392627534457, 0.030781320747337304, 0.03606388338084798, 0.01633403397136135, 0.020895351517538074, 0.021811738770338707, 0.08234683598857373, 0.03353661821165588, 0.017835936778283212, 0.02896756377595011, 0.040016502534854226, 0.008144515068124747, 0.034395450056763366, 0.0336323552619433, 0.06623983426834457, 0.08110644004773349, 0.0767064765386749, 0.04879885549598839, 0.014021350598341087, 0.04530606362095568, 0.06406526736100204, 0.06290411052759737, 0.04658760422898922, 0.03115128136414569, 0.030442650931945536, 0.04870602766459342, 0.01611364208656596, 0.04341917912825011, 0.05552102877118159, 0.005864635550096864, 0.03910099658241961, 0.10073614219436422, 0.029375620688369963, 0.025348677299916744, 0.06299493456026539, 0.06245017590117641, 0.06442041471018456, 0.16464795568026602, 0.04829968325793743, 0.019729368868866004, 0.08513046865118667, 0.06715753697790205, 0.08908949996111915, 0.05124284427438397, 0.01510576101281913, 0.0684266169264447, 0.05168071511434391, 0.026970112267008517, 0.02424628928565653, 0.02135319355147658, 0.08185120008420199, 0.10942863591481, 0.18895131797762588, 0.1457615738036111, 0.11723668256308883, 0.12269210623344406, 0.11672172855469398, 0.17078777309507132, 0.09133668601862155, 0.09346303559141234, 0.10033048427430913, 0.10268111829645932, 0.07554615091066808, 0.10637475017574616, 0.35170114191714674, 0.1854231330798939, 0.11153881408972666, 0.1589813019381836, 0.10342948517063633, 0.163589964795392, 0.10871670849155635, 0.14991003088653088, 0.1602723271935247, 0.1278941606869921, 0.08849262769217603, 0.15158286143559963, 0.08458108641207218, 0.17293678043643013, 0.12209288135636598, 0.14120024512521923, 0.1949512553983368, 0.1780420885188505, 0.10350373704568483, 0.2276680342038162, 0.1149610425636638, 0.1848164718830958, 0.12302527858992107, 0.177983726025559, 0.09872976821498014, 0.14858652924885973, 0.062470540433423594, 0.13467188371578231, 0.07555444070021622, 0.16835299436934292, 0.12338660060777329, 0.09527341579087079, 0.18888504419010133, 0.329586120788008, 0.12726379529340193, 0.14277873386163265, 0.170737826556433, 0.16174307093024254, 0.08210920030251145, 0.037604860262945294, 0.10905624847509898, 0.1183003954065498, 0.07935896428534761, 0.1515660888981074, 0.1107465269160457, 0.12741050304612145, 0.3077670087805018, 0.2030707962694578, 0.13568638474680483, 0.12280730981728993, 0.14626063843024895, 0.147827920736745, 0.28154354717116803, 0.11485711962450296, 0.245094136625994, 1.320908514317125, 4.439121773466468, 9.36911165714264, 17.0844304561615, 29.017614126205444, 34.19970765709877, 47.84295916557312, 51.9573175907135, 64.9611622095108, 66.0688179731369, 72.81296968460083, 63.188492730259895, 65.75620874762535, 64.99141618609428, 68.46220314502716, 56.235515624284744, 53.588828444480896, 42.995692268013954, 45.62902696430683, 48.532793149352074, 46.993864327669144, 45.16874246299267, 45.74497394263744, 41.696887761354446, 40.497474521398544, 36.52968183159828, 41.87936916947365, 49.15958471596241, 31.713968440890312, 70.00026181340218, 79.4190976023674, 62.144335359334946, 53.44564452767372, 34.24573078751564, 47.41788737475872, 47.422994300723076, 46.94159433245659, 59.47894178330898, 57.485272362828255, 54.57135312259197, 45.10098069906235, 35.21945893764496, 28.847605548799038, 15.430952031165361, 6.473515508696437, 2.927811532281339, 0.4503085225587711, 0.0997549487510696, 0.3043371584499255, 0.14529707841575146, 0.09268489375244826, 0.11713029569364153, 0.11558155223610811, 0.2022563188802451, 0.20627890771720558, 0.17869105213321745, 0.17804029252147302, 0.17705378530081362, 0.15760773501824588, 0.1238016392744612, 0.1898667571367696, 0.16659775574225932, 0.1390355042531155, 0.12484880222473294, 0.1771527432720177, 0.12829293147660792, 0.0753742027154658, 0.14621891488786787, 0.16880169685464352, 0.08879572080331855, 0.2294890271150507, 0.11122857409645803, 0.15862134547205642, 0.153039192664437, 0.16201796242967248, 0.16827601881232113, 0.18358949397224933, 0.12013160769129172, 0.09196923332638107, 0.1306812369148247, 0.11032083100872114, 0.12544070952571929, 0.19473282649414614, 0.08419560748734511, 0.1510902534937486, 0.14249842468416318, 0.13824078283505514, 0.10059220265247859, 0.23614117875695229, 0.11646384708001278, 0.19624731241492555, 0.19451610452961177, 0.11108692779089324, 0.16014743858249858, 0.19021963351406157, 0.238605851191096, 0.11525281050126068, 0.169547570112627, 0.14412807708140463, 0.1484900203649886, 0.22606729588005692, 0.11349521184456535, 0.12392063523293473, 0.08361278407392092, 0.08541142349713482, 0.0686246738769114, 0.09638521980377845, 0.1782332212314941], [0.04876467959547881, 0.024118933033605572, 0.03682921204017475, 0.052872040250804275, 0.04149345804762561, 0.02887113096221583, 0.06857598898932338, 0.044485675025498495, 0.015351344172813697, 0.024604015598015394, 0.046565094889956526, 0.020185901012155227, 0.02708528802031651, 0.04248495621141046, 0.04183811885013711, 0.023944576569192577, 0.03449186246143654, 0.014452862160396762, 0.056181243344326504, 0.01793096507753944, 0.05535360767680686, 0.06703765044221655, 0.03874139263643883, 0.05395677071646787, 0.03735679740202613, 0.07347932900302112, 0.01778836882294854, 0.0072080411246133735, 0.038492669264087453, 0.005462606732180575, 0.0706563625135459, 0.07598328331368975, 0.025749676387931686, 0.05570456931309309, 0.03791803916101344, 0.039361397648463026, 0.022367343917721882, 0.060526525412569754, 0.03456579892372247, 0.06962378276512027, 0.04657354424125515, 0.08046745089814067, 0.05622540855256375, 0.03532703092787415, 0.01199923566673533, 0.08345514448592439, 0.03734929057827685, 0.021435321468743496, 0.03355162814841606, 0.010772914556582691, 0.036882553904433735, 0.036560350490617566, 0.04217473106109537, 0.05930341409111861, 0.05818847450427711, 0.0591054461983731, 0.05130536650540307, 0.05615749461867381, 0.03617933558416553, 0.02552997655584477, 0.05138034939591307, 0.035559504976845346, 0.07650917657883838, 0.031964300433173776, 0.019971247784269508, 0.05515502380148973, 0.028209192751091905, 0.05256102842395194, 0.07049414387438446, 0.07412415885482915, 0.5727717059198767, 1.3838229258544743, 3.902511242777109, 8.568847049027681, 13.111558388918638, 17.996605709195137, 25.69416806101799, 32.213493436574936, 41.23765580356121, 44.21225778758526, 45.220902264118195, 54.04671907424927, 51.98612384498119, 52.327588722109795, 48.93114097416401, 49.58677299320698, 46.09876535832882, 47.06758417189121, 43.71966741979122, 49.83179524540901, 40.426361337304115, 43.04140001535416, 40.40466830134392, 49.17726516723633, 48.429909870028496, 45.93519173562527, 35.28240256011486, 40.10120138525963, 57.602606266736984, 56.3563035428524, 36.149512231349945, 42.647771537303925, 42.2655538469553, 42.29335315525532, 45.5534528195858, 35.508311837911606, 32.325963601469994, 25.854570753872395, 14.157889243215322, 9.285506643354893, 4.226020658388734, 0.988821474602446, 0.0629551628662739, 0.04530512109340634, 0.013552594355132896, 0.11341691526467912, 0.07818242273060605, 0.02307387036125874, 0.04729701206088066, 0.02248544929898344, 0.01655154446780216, 0.06634020232013427, 0.05904191464651376, 0.02029333987593418, 0.08071296819252893, 0.009487489733146504, 0.027539987058844417, 0.09404279393493198, 0.06095530123275239, 0.0072210018061014125, 0.05456165818031877, 0.0879307031573262, 0.036836537037743255, 0.04047226284455974, 0.04724359227111563, 0.047657803443144076, 0.022780041108489968, 0.025952542455343064, 0.06404089523130096, 0.052605045202653855, 0.039142875975812785, 0.0389781451667659, 0.03291757057013456, 0.009597049283911474, 0.022296047645795625, 0.0751311270869337, 0.04980821715435013, 0.009371518954139901, 0.041342408730997704, 0.05033816625655163, 0.0442189397290349, 0.06035358273948077, 0.05691440361260902, 0.044060557993361726, 0.02103991817421047, 0.021409008622867987, 0.039832535258028656, 0.0434189156658249, 0.016484231673530303, 0.06000026478432119, 0.021851319361303467, 0.021023694825998973, 0.041032643712242134, 0.040287456940859556, 0.03295664835604839, 0.03407152114959899, 0.024941338415374048, 0.03773944132262841, 0.1116424698557239, 0.033135710036731325, 0.06752543442416936, 0.047821480402490124, 0.02295496902661398, 0.040562218564446084, 0.035860293719451874, 0.048614799161441624, 0.041166430673911236, 0.016273871769953985, 0.05902260396396741, 0.014123486816970399, 0.019160410629410762, 0.045877042357460596, 0.024873329857655335, 0.06988982044276781, 0.03324556273582857, 0.020826636064157356, 0.03212770650861785, 0.01153435250671464, 0.025706368360260967, 0.02152529759769095, 0.057631919407867827, 0.03865745573421009, 0.04137062518566381, 0.04685361964220647, 0.05589895634329878, 0.0739289888588246, 0.07757569474051706, 0.002002508549594495, 0.040560749112046324, 0.039176532372948714, 0.05539778772799764, 0.08169913402525708, 0.014060634330235189, 0.009906116683850996, 0.07773947931127623, 0.03958751891332213, 0.006464508414865122, 0.02416330789856147, 0.015524439913860988, 0.026928093720925972, 0.04494284170505125, 0.053325240151025355, 0.01993066158320289, 0.02281656961713452, 0.01848083527875133, 0.07507581482059322, 0.05321473807271104, 0.03427064308198169, 0.05299735188600607, 0.032623605875414796, 0.048734251540736295, 0.0068464533251244575, 0.017505439864180516, 0.024429091390629765, 0.053848936659051105, 0.039459617182728834, 0.029038570610282477, 0.039710626369924285, 0.04311780779971741, 0.005037117698520888, 0.062170590317691676, 0.04222910451062489, 0.0706883861857932, 0.025359972787555307, 0.08285420524771325, 0.10720058984588832, 0.03882719232933596, 0.029041288726148196, 0.05623177989036776, 0.02313650205906015, 0.028179126493341755, 0.0863455721992068, 0.04274049621017184, 0.03025969668669859, 0.07232160089188255, 0.25681278202682734, 1.033121100626886, 2.54956700373441, 6.488277241587639, 11.461522579193115, 17.774120047688484, 23.924088142812252, 33.01334671676159, 40.91131791472435, 49.188873544335365, 54.36794623732567, 54.4107623398304, 59.69347447156906, 58.91831986606121, 58.90972852706909, 54.91765134036541, 52.11255066096783, 52.91911818087101, 51.64862595498562, 49.1526310890913, 55.541570261120796, 45.41506804525852, 46.167028695344925, 42.6781053096056, 50.53264483809471, 50.62397673726082, 49.68215927481651, 37.501475885510445, 44.48146194219589, 62.424091547727585, 59.47293810546398, 39.4576109200716, 43.85646007955074, 45.237495973706245, 48.17885734140873, 49.740721732378006, 41.999290734529495, 37.57462576031685, 31.392528489232063, 18.3679236844182, 11.699501909315586, 5.683579221367836, 1.6194336768239737, 0.1213596023444552, 0.03546294043189846, 0.028736477543134242, 0.037428811701829545, 0.04762677424878348, 0.03689492179546505, 0.02731029049755307, 0.049447596466052346, 0.06631189680774696, 0.06487938851932995, 0.04134732545935549, 0.0026988998070009984, 0.011121473489765776, 0.006992657808950753, 0.029773315363854636, 0.11027567874407396, 0.02474732060363749, 0.021025283022026997, 0.02248312081064796, 0.08921666696551256, 0.08063265297096223, 0.08893502192222513, 0.04768958591739647, 0.018792947339534294, 0.02242458205728326, 0.04605091642588377, 0.06697499833535403, 0.022761103355151135, 0.03473416254564654, 0.04761195355968084, 0.06267325064982288, 0.05600609649263788, 0.08106435285299085, 0.008768352345214225, 0.025978996309277136, 0.016148179784067906, 0.02812563248880906, 0.030481977337331045, 0.06173635971208569, 0.06977035693125799, 0.034006156492978334, 0.0408381342276698, 0.025987013359554112, 0.036765546901733615, 0.055791389459045604, 0.0336182804312557, 0.021721515877288766, 0.09613009169697762, 0.04898893435893115, 0.014681134725833545, 0.046192796507966705, 0.05733741294534411, 0.040538373359595425, 0.04093844290764537, 0.037974794904584996, 0.06179597643495072, 0.1054274060879834, 0.011227277773286914, 0.07634219335159287, 0.01600915325980168, 0.03911287465598434, 0.04602057371812407, 0.04160654279985465, 0.0432602519140346, 0.18213730392744765, 0.12888212251709774, 0.27183836326003075, 0.12408096139552072, 0.13220001244917512, 0.16762677318183705, 0.12391797834425233, 0.15078618074767292, 0.11452713108155876, 0.06682469116640277, 0.07090619168593548, 0.13071708264760673, 0.08415462609264068, 0.1397806650493294, 0.17462286574300379, 0.10805941055878066, 0.1574328404967673, 0.09228394104866311, 0.1644217935972847, 0.15236701467074454, 0.13274651515530422, 0.12002444156678393, 0.12346166142378934, 0.16293706779833883, 0.1367049675900489, 0.2734704647446051, 0.14923488430213183, 0.08821148730930872, 0.3413713665213436, 0.13660832511959597, 0.10602478301734664, 0.11250455601839349, 0.061950265226187184, 0.08349907220690511, 0.17115860944613814, 0.14650453784270212, 0.07716248917859048, 0.1478158385725692, 0.085671434935648, 0.1763054629554972, 0.22819409816293046, 0.1698635469074361, 0.299370379652828, 0.1749931974336505, 0.11421545132179745, 0.2068203192902729, 0.11468048105598427, 0.10040763052529655, 0.15395285066915676, 0.1089157747628633, 0.13176625681808218, 0.13399511924944818, 0.11455495419795625, 0.12258298083906993, 0.16618742229184136, 0.13622077560285106, 0.20606025616871193, 0.1090779562946409, 0.14548699400620535, 0.16973773803329095, 0.11816673460998572, 0.15146239602472633, 0.2279918035492301, 0.15154064807575196, 0.058370486221974716, 0.21559023385634646, 0.13069992419332266, 0.10256685724016279, 0.1991212199209258, 0.4012507206061855, 0.8808247977867723, 2.5544751528650522, 6.24618130736053, 11.54633117839694, 18.847632743418217, 27.02975459396839, 35.704905688762665, 47.12816812098026, 55.72562478482723, 63.26341710984707, 62.955736219882965, 67.78399273753166, 65.83655923604965, 68.62779065966606, 63.53422097861767, 65.42163670063019, 58.620909824967384, 62.58584126830101, 57.754997089505196, 67.02136605978012, 52.77809634804726, 58.20188730955124, 54.92499254643917, 61.79280862212181, 60.111113861203194, 60.02170845866203, 48.701177313923836, 50.387933403253555, 69.79378089308739, 66.2461544573307, 49.61862288415432, 54.93399806320667, 56.02930448949337, 54.935920760035515, 58.297927156090736, 48.016492053866386, 44.161526709795, 34.78982359170914, 20.786976478993893, 12.960100416094065, 6.259565614163876, 1.5815473347902298, 0.38092570030130446, 0.111372439423576, 0.1510800266987644, 0.23001906898571178, 0.2062187492265366, 0.12653025652980432, 0.16042500181356445, 0.13862373103620484, 0.1682457243441604, 0.12775506736943498, 0.13161522976588458, 0.16172925214050338, 0.15320089180022478, 0.12476918462198228, 0.07707635551923886, 0.24043638812145218, 0.192390326410532, 0.11727171193342656, 0.15964555379468948, 0.22475418430985883, 0.16073484846856445, 0.22182699060067534, 0.12036621541483328, 0.13983022567117587, 0.08724268031073734, 0.11680476745823398, 0.2066019200719893, 0.07839861034881324, 0.16068904311396182, 0.1664886748767458, 0.1423058967338875, 0.10939612242509611, 0.17322393221547827, 0.18834902060916647, 0.10784841797431, 0.11635423928964883, 0.18975896760821342, 0.14636737410910428, 0.17885702603962272, 0.19519414548994973, 0.14253317203838378, 0.1715312121086754, 0.18025392608251423, 0.1500007213326171, 0.1333145995158702, 0.09689657439594157, 0.17091286950744689, 0.3063670510891825, 0.1374427365954034, 0.11531863157870248, 0.1581842650193721, 0.24423732713330537, 0.12047157069901004, 0.15788525372045115, 0.17479946720413864, 0.13504951813956723, 0.16580671537667513, 0.1410026557277888, 0.09741067493450828, 0.12239710995345376, 0.13224865280790254, 0.12329516059253365, 0.1312905698432587, 0.21949375252006575], [0.06955134173040278, 0.04821426577109378, 0.08354743797099218, 0.033564879195182584, 0.04130617708142381, 0.08344033863977529, 0.026003232997027226, 0.03395774991076905, 0.051168417994631454, 0.008817861016723327, 0.06445269071264192, 0.017127143073594198, 0.057469374223728664, 0.014180317702994216, 0.01724099594866857, 0.04388706984173041, 0.05757484454079531, 0.026980257425748277, 0.052763879648409784, 0.04819783091079444, 0.025087916292250156, 0.06311793811619282, 0.027533086940820795, 0.027338822364981752, 0.008062872329901438, 0.029684988658118527, 0.017005161826091353, 0.038707346611772664, 0.0378134965285426, 0.0986754652694799, 0.05212565120018553, 0.0410431636555586, 0.039709030752419494, 0.04198219197860453, 0.023440051591023803, 0.08781478711171076, 0.03811566195508931, 0.04072396593983285, 0.03772645373828709, 0.07391571183688939, 0.05580748664215207, 0.050989868395845406, 0.03949535901483614, 0.02902738458942622, 0.07054633912048303, 0.01588183225976536, 0.06327975599560887, 0.04180584284767974, 0.011031446338165551, 0.02850778473657556, 0.06469440821092576, 0.03174390112690162, 0.054293546199915, 0.03396791733393911, 0.007903446021373384, 0.06922432919964194, 0.017978824325837195, 0.017957422642211895, 0.022837153082946315, 0.051256288279546425, 0.056899182163761, 0.025146404950646684, 0.03951400547521189, 0.014166120417939965, 0.02829096443747403, 0.024052445878623985, 0.019187096404493786, 0.01682689424342243, 0.0916358309041243, 0.05829790417919867, 0.06520246766740456, 0.0559756387519883, 0.12842625088524073, 0.7460064883343875, 2.4958312371745706, 4.889342989772558, 5.322489822283387, 11.363735776394606, 17.037183791399002, 15.09891064837575, 22.65843115746975, 35.242926478385925, 37.25135050714016, 43.51920537650585, 42.30597987771034, 49.11801114678383, 38.911321833729744, 46.53082497417927, 47.73227870464325, 44.33066703379154, 50.44010080397129, 43.615944385528564, 45.82654796540737, 48.87463040649891, 48.189872950315475, 46.92261055111885, 47.502657026052475, 46.692232713103294, 46.93880148231983, 44.40359652042389, 43.52556623518467, 41.28256939351559, 42.381907403469086, 33.96047629415989, 30.0098966807127, 20.00124704092741, 12.757443990558386, 5.5170512571930885, 2.624183362349868, 0.5537748627830297, 0.10397209160146303, 0.07275319687323645, 0.07184350935858674, 0.02423138139420189, 0.016856120018928777, 0.02357171972107608, 0.06345066518406384, 0.055332886913674884, 0.043469107113196515, 0.032720574890845455, 0.027761399396695197, 0.04237129629473202, 0.007424253790304647, 0.06432187234167941, 0.0921803001256194, 0.026010136825789232, 0.065206044819206, 0.0718377651355695, 0.0404278304631589, 0.09386292702401988, 0.04861678069573827, 0.026032588648376986, 0.038355123324436136, 0.05464643742016051, 0.030718950656591915, 0.06291139099630527, 0.031940625922288746, 0.044288119024713524, 0.0516428284754511, 0.041518357102177106, 0.04174381414486561, 0.024502434134774376, 0.08172487912815996, 0.056733089513727464, 0.059175601418246515, 0.0038153902505655424, 0.02002601086132927, 0.0662883187760599, 0.03891380096320063, 0.049235271726502106, 0.06345525165670551, 0.01715017748210812, 0.03165218651702162, 0.051372927919146605, 0.0035496677537594223, 0.03394291808945127, 0.11901762918569148, 0.016879918839549646, 0.06511046361993067, 0.026142823553527705, 0.03980622612289153, 0.04947698180330917, 0.04927955196762923, 0.07838934092433192, 0.05570800174609758, 0.051207310243626125, 0.03184247689205222, 0.004742885830637533, 0.029880301517550834, 0.060085422519478016, 0.1536551900790073, 0.03879508331010584, 0.01836809748056112, 0.0749637208355125, 0.04302549576095771, 0.02182003783673281, 0.07059816329274327, 0.009858650773821864, 0.05340173331205733, 0.05109317906317301, 0.04269217126420699, 0.04392365401145071, 0.045156951309763826, 0.026287189830327407, 0.017275455720664468, 0.0845569146622438, 0.01929235706484178, 0.006376895098583191, 0.013707603957300307, 0.016396604441979434, 0.062202799526858144, 0.041205527013516985, 0.05378220273996703, 0.030938203344703652, 0.03623393909947481, 0.05080564136733301, 0.037421523811644875, 0.10592828155495226, 0.0063222271091945, 0.004725773296740954, 0.03705760798766278, 0.0369228859199211, 0.021692802183679305, 0.031069142314663623, 0.02510859809262911, 0.016412109762313776, 0.020004766884085257, 0.016365677292924374, 0.04315449587011244, 0.03447975803283043, 0.055237216656678356, 0.0240778495935956, 0.047984010743675753, 0.03017429404280847, 0.03268143402237911, 0.02836268558894517, 0.04121951278648339, 0.020910534003633074, 0.022737029939889908, 0.06699755220324732, 0.04785852099303156, 0.014377935858647106, 0.025073201359191444, 0.044289106081123464, 0.03396296720893588, 0.051452868356136605, 0.039515745811513625, 0.04943785577779636, 0.03391639002074953, 0.049480013476568274, 0.055828882759669796, 0.06386410081177019, 0.01770382707036333, 0.04417207310325466, 0.06353066128212959, 0.028398473805282265, 0.045791272350470535, 0.024173707242880482, 0.058871046276181005, 0.03558874559530523, 0.053175396824372, 0.04912604243145324, 0.029698816724703647, 0.03784177977649961, 0.01609151680895593, 0.038254135579336435, 0.0628509208036121, 0.060020755481673405, 0.41459676227532327, 1.313483000267297, 3.9047811459749937, 7.242977544665337, 8.265254739671946, 13.654567301273346, 22.512632980942726, 21.758073270320892, 29.69435591250658, 42.56408102810383, 45.29620282351971, 51.357477977871895, 49.44531038403511, 55.76319336891174, 46.72349363565445, 54.120207130908966, 53.646486550569534, 52.9939703643322, 56.02210007607937, 52.411180436611176, 53.61817806959152, 55.797357335686684, 52.95213460922241, 52.696640118956566, 51.739760264754295, 49.95979517698288, 52.891767248511314, 51.63200564682484, 47.08362691104412, 47.03412316739559, 47.83314809203148, 39.74149748682976, 34.255386069417, 23.809108212590218, 15.393578186631203, 7.0604396145790815, 3.6898817773908377, 0.9068376081995666, 0.3118474257644266, 0.024145275565388147, 0.07257474004290998, 0.035824043516186066, 0.0329580621473724, 0.03426072798902169, 0.024037298644543625, 0.040990185443661176, 0.03525893516780343, 0.07293811038834974, 0.026137500499316957, 0.018125437454727944, 0.0610738147952361, 0.026141470989387017, 0.018208108995168004, 0.03836760253761895, 0.026370252853666898, 0.05206985282711685, 0.02497425452020252, 0.04209199272736441, 0.08269616489997134, 0.08237852569436654, 0.04767333288327791, 0.06262389782932587, 0.035306291611050256, 0.012265038640180137, 0.0238427205113112, 0.029361851993598975, 0.05324026795278769, 0.010146577169507509, 0.01940427850058768, 0.05595199021627195, 0.031161764200078323, 0.07806570516549982, 0.03135457416647114, 0.01188803411423578, 0.0446268760424573, 0.002773542005343188, 0.018926595148514025, 0.08883774120477028, 0.040675414638826624, 0.07301530858967453, 0.08426508735283278, 0.040644938344485126, 0.002488105978954991, 0.020051819046784658, 0.02895463927416131, 0.07799450351740234, 0.0634371729393024, 0.04276086074241903, 0.009496042985119857, 0.010940056417894084, 0.02151035630959086, 0.053718812196166255, 0.006611003727812204, 0.06824579264502972, 0.03989842312876135, 0.0065620813529676525, 0.03157900333462749, 0.026338795069023035, 0.05725337585317902, 0.0317347430245718, 0.034747513782349415, 0.015641522986697964, 0.05047316291893367, 0.08343227149453014, 0.14544622041285038, 0.11226812261156738, 0.20204525208100677, 0.09271141068893485, 0.08917855768231675, 0.13405947829596698, 0.11547139525646344, 0.173308537050616, 0.12787765532266349, 0.2092987362993881, 0.20759280596394092, 0.17609785456443205, 0.09927438586601056, 0.19575949874706566, 0.12958100298419595, 0.1458533774712123, 0.17586444912012666, 0.08656539634102955, 0.09869501343928277, 0.3435224964050576, 0.1401954365428537, 0.2716386364772916, 0.11554547643754631, 0.1915808956255205, 0.06992686103330925, 0.15055414085509256, 0.12082783126970753, 0.10080477601150051, 0.1681703666690737, 0.17638806399190798, 0.11286313951131888, 0.11009531459421851, 0.24691444676136598, 0.1466157115646638, 0.15146739810006693, 0.2500775543740019, 0.11995354419923387, 0.16720131476176903, 0.12549163569929078, 0.14411957206903026, 0.15428260172484443, 0.1222956286801491, 0.10750199086032808, 0.14695419027702883, 0.1533754004049115, 0.09179412358207628, 0.1733996727853082, 0.2062473219120875, 0.11087068080087192, 0.16727177426218987, 0.1476010907208547, 0.13286322529893368, 0.09627461011405103, 0.12753246759530157, 0.10583714582026005, 0.17053360235877335, 0.1160207181237638, 0.13841502426657826, 0.09575086165568791, 0.09475287341047078, 0.12354150909231976, 0.14760714664589614, 0.14546603575581685, 0.15507215779507533, 0.15908033412415534, 0.12571264727739617, 0.11896383090061136, 0.10003996314480901, 0.17965830804314464, 0.24910073960199952, 0.16841721982927993, 0.18336560286115855, 0.6350487610325217, 1.3455031695775688, 3.545156568288803, 7.097517549991608, 9.071728214621544, 15.428252276033163, 23.908022604882717, 26.1922662332654, 33.579219952225685, 47.74136021733284, 48.91092225909233, 55.31392827630043, 56.26852065324783, 61.907205283641815, 54.48822878301144, 59.68856893479824, 62.127065286040306, 61.0751411318779, 64.9228222668171, 60.49043230712414, 60.80719470977783, 63.41078080236912, 63.94411638379097, 60.3418792784214, 60.30564822256565, 59.36565846204758, 60.74304275214672, 58.4063695371151, 56.318883150815964, 53.643503710627556, 54.88586604595184, 47.57262647151947, 37.43641957640648, 28.253686018288136, 17.358766235411167, 8.00263088196516, 4.397345390170813, 0.994936830829829, 0.42865303927101195, 0.17123647558037192, 0.1892291335389018, 0.09713194653159007, 0.17572954151546583, 0.19240801921114326, 0.22655558452242985, 0.17917264660354704, 0.05692037790140603, 0.07416516251396388, 0.12745043059112504, 0.12618725071661174, 0.09395577711984515, 0.14539685274939984, 0.1584314595675096, 0.0754247503937222, 0.27697058161720634, 0.19170369138009846, 0.17996922339079902, 0.14212168083759025, 0.12677446764428169, 0.1374904121621512, 0.09434688894543797, 0.15338426164817065, 0.12188689084723592, 0.10611523597617634, 0.11688027356285602, 0.12021439426462166, 0.13573236821684986, 0.07048833285807632, 0.1426355290459469, 0.17762841540388763, 0.17021964420564473, 0.12869189522461966, 0.14337680098833516, 0.10468962966115214, 0.14549036335665733, 0.13665513979503885, 0.16018383350456133, 0.16981177468551323, 0.1471029908861965, 0.1300688463379629, 0.22436092025600374, 0.18591205996926874, 0.12387668524752371, 0.1143833102833014, 0.274025650578551, 0.13683396769920364, 0.1512662909226492, 0.17614895885344595, 0.24869855493307114, 0.12511173030361533, 0.07644550772965886, 0.1743816677480936, 0.18112479185219854, 0.14530062588164583, 0.09613470043404959, 0.07496465594158508, 0.12877381348516792, 0.132004129991401, 0.2076765350648202, 0.17256953608011827, 0.15804756141733378, 0.12169391760835424, 0.2330751737463288, 0.16854138113558292], [0.00782451119448524, 0.04077334102476016, 0.024667317084094975, 0.05319380579749122, 0.015354800725617679, 0.03619878727477044, 0.09163712966255844, 0.017394377464370336, 0.026225875444652047, 0.02989631891978206, 0.03224428306566551, 0.04552999926090706, 0.02262388210510835, 0.0158726166409906, 0.013707825673918705, 0.03284944141341839, 0.038371773407561705, 0.027539333968888968, 0.07841064056265168, 0.10164508756133728, 0.031973195073078386, 0.02171422056562733, 0.05044267178163864, 0.017258792649954557, 0.05336619928129949, 0.06212874061020557, 0.057895585923688486, 0.0451690631598467, 0.042286613534088247, 0.022578945063287392, 0.052043009345652536, 0.022920223527762573, 0.07547097877250053, 0.04281554589397274, 0.030738905152247753, 0.02821230977133382, 0.05289533255563583, 0.02812611302942969, 0.03552234935341403, 0.08798585957265459, 0.057739285912248306, 0.06226470577530563, 0.08018409149372019, 0.05467758535814937, 0.032907985732890666, 0.029629234813910443, 0.04812998005945701, 0.025011831312440336, 0.022196171266841702, 0.04255053609085735, 0.044463918966357596, 0.06287567142862827, 0.03434952966927085, 0.04953932591888588, 0.041695726686157286, 0.017833910715125967, 0.013213971851655515, 0.08317898391396739, 0.013254553414299153, 0.03709433687618002, 0.03463927896518726, 0.026019701253972016, 0.024326398561242968, 0.10015909268986434, 0.021052224838058464, 0.03579874370188918, 0.05883042853383813, 0.022034312569303438, 0.048036421212600544, 0.018938059474749025, 0.05527557455934584, 0.0348813935124781, 0.04962375263858121, 0.00482452021969948, 0.0038575331063839258, 0.10719063022406772, 0.2937020634999499, 0.5032550892792642, 1.8132980866357684, 3.2518481696024537, 5.557845868170261, 7.762436270713806, 15.061062779277563, 17.249121218919754, 15.590554866939783, 19.94668196886778, 21.16350967437029, 22.96389676630497, 30.915091708302498, 25.736758075654507, 27.423246279358864, 28.698769435286522, 27.094723507761955, 26.923527494072914, 31.055019199848175, 34.72952462732792, 38.870196640491486, 34.38610665500164, 40.29860459268093, 31.455152928829193, 28.012739047408104, 31.445712335407734, 17.659085020422935, 15.133985616266727, 8.841409273445606, 3.5049347765743732, 0.8834445790853351, 0.10096346202772111, 0.045128178244340234, 0.011461009762570029, 0.03856725881632883, 0.02190158502344275, 0.04257843713276088, 0.04607502509315964, 0.04620508276275359, 0.09593167851562612, 0.07304785176529549, 0.031008137775643263, 0.044059812134946696, 0.006763783640053589, 0.013787057359877508, 0.06790375162381679, 0.10399505365057848, 0.08319004933582619, 0.05976540101983119, 0.023300563079828862, 0.029122824780642986, 0.02972336696984712, 0.026597860269248486, 0.07112715131370351, 0.027456176321720704, 0.03196971068973653, 0.0044150462690595305, 0.016614389533060603, 0.027735487310565077, 0.007054762581901741, 0.030479695233225357, 0.028979100461583585, 0.05544901818211656, 0.0070551582393818535, 0.013950971806480084, 0.07383535208646208, 0.027234073786530644, 0.009846225366345607, 0.04636904915969353, 0.008896350555005483, 0.04571464189211838, 0.07062669887091033, 0.02534776445827447, 0.03834780945908278, 0.01955293624632759, 0.03325281351862941, 0.026038028590846807, 0.0386613705632044, 0.025780163814488333, 0.032767419252195396, 0.04676602395193186, 0.08024316644878127, 0.055563999121659435, 0.01541312240078696, 0.04980052479368169, 0.0510484535334399, 0.07200308595201932, 0.0582818069960922, 0.04232148334267549, 0.055850089629529975, 0.023257982356881257, 0.0279893352126237, 0.05937926900514867, 0.037272099798428826, 0.05192744210944511, 0.057493542262818664, 0.015521368350164266, 0.03607977647334337, 0.008720981059013866, 0.02102316419041017, 0.01950039961229777, 0.06232362487935461, 0.044373740602168255, 0.013251995787868509, 0.02943277719168691, 0.038808668323326856, 0.02221468970674323, 0.04934593707730528, 0.02517110919143306, 0.0629646994639188, 0.014019462760188617, 0.05656338260450866, 0.04326935435528867, 0.010228224546153797, 0.09946775244316086, 0.07318083720747381, 0.03166691443766467, 0.04028630290122237, 0.018940180161735043, 0.038593233985011466, 0.05512621362868231, 0.040111968701239675, 0.05882351913896855, 0.03664775693323463, 0.023724526072328445, 0.11397639071219601, 0.04957784338330384, 0.11639478281722404, 0.04917523569019977, 0.03362031762662809, 0.0381302711321041, 0.05175563863303978, 0.04446519917109981, 0.010320576475351118, 0.026729242672445253, 0.01900285824376624, 0.08318190797581337, 0.06092879542848095, 0.03752028140297625, 0.06101953040342778, 0.00126652916378589, 0.04573886930302251, 0.037373336163000204, 0.03082663257373497, 0.061935541016282514, 0.06469917279900983, 0.05933481064857915, 0.02833128903148463, 0.034421098680468276, 0.05168800300452858, 0.02168607090425212, 0.07511435454944149, 0.03406348740099929, 0.034354490926489234, 0.03438967985857744, 0.05649699749483261, 0.04056472331285477, 0.0866168197535444, 0.013008062978769885, 0.049489379380247556, 0.04332929020165466, 0.022587437088077422, 0.039309272906393744, 0.038287532224785537, 0.02380216770689003, 0.032768543605925515, 0.04101652426470537, 0.035284542973386124, 0.02510902297217399, 0.04560206551104784, 0.01990664011827903, 0.04850299832469318, 0.050768352157319896, 0.03763278728001751, 0.02309015122591518, 0.3918158862506971, 0.8035630686208606, 1.1265114205889404, 3.0621955962851644, 5.180660532787442, 7.808236638084054, 10.852676499634981, 18.505823984742165, 22.90814995765686, 21.782640852034092, 26.920063979923725, 27.50846430659294, 29.469447880983353, 37.734893560409546, 31.818559728562832, 37.30658434331417, 33.42651754617691, 34.012411907315254, 34.08092983067036, 39.253113493323326, 41.59229077398777, 45.0526586920023, 41.632230430841446, 45.75242914259434, 35.588483735919, 33.67975115776062, 35.610142573714256, 21.36267028748989, 18.469294644892216, 10.757343415170908, 4.805465815588832, 1.3027495262213051, 0.17450373619794846, 0.06094584256061353, 0.040656515848240815, 0.08859153371304274, 0.04732886503916234, 0.023740680771879852, 0.026765826842165552, 0.01057820933056064, 0.07183817331679165, 0.018983033623953816, 0.0314930181048112, 0.014775427371205296, 0.02372906430537114, 0.022108835328253917, 0.03780554441618733, 0.012198524582345271, 0.04670276328397449, 0.0519451052241493, 0.005358384614737588, 0.08881378467776813, 0.02603927168820519, 0.04081449311343022, 0.12399476836435497, 0.0661156210117042, 0.025250214712286834, 0.03950567486754153, 0.05493472839589231, 0.017762391798896715, 0.05117652595799882, 0.013946974413556745, 0.09581176971551031, 0.10263095653499477, 0.010850611852220027, 0.036173880798742175, 0.04487643062020652, 0.01219163745190599, 0.020219132529746275, 0.01777233472239459, 0.055091495960368775, 0.00872011924002436, 0.08256035187514499, 0.007045188876872999, 0.025279780020355247, 0.022103484443505295, 0.027133915391459595, 0.03548182809026912, 0.039975773470359854, 0.011655355974653503, 0.07054302914184518, 0.08161262929206714, 0.01171162468381226, 0.008483281362714479, 0.02339519989618566, 0.04586340168316383, 0.05764612782513723, 0.03273434915172402, 0.03672424267278984, 0.07304009632207453, 0.02693154470762238, 0.03439554282522295, 0.036994120964664035, 0.04696909039921593, 0.023696051721344702, 0.07977185072377324, 0.017344801999570336, 0.0271219185742666, 0.05967484416032676, 0.0229089521599235, 0.14854848675895482, 0.12001719820545986, 0.14174351206747815, 0.1981430989690125, 0.15232209989335388, 0.1103929454984609, 0.14335057348944247, 0.1915853633545339, 0.22594518290134147, 0.14065144176129252, 0.16886737692402676, 0.12969061819603667, 0.17772870924090967, 0.11046052546589635, 0.07267653301823884, 0.17483908304711804, 0.11290813592495397, 0.0850677868584171, 0.09368550177896395, 0.1154146803310141, 0.13423618365777656, 0.10426523251226172, 0.09704222829896025, 0.09228603390511125, 0.12934899277752265, 0.10256544715957716, 0.16747501882491633, 0.15121926844585687, 0.24288152722874656, 0.12802556535461918, 0.14573493070201948, 0.16890816536033526, 0.1569129215204157, 0.17808541510021314, 0.08327190822456032, 0.10621516616083682, 0.10901827277848497, 0.23498537280829623, 0.3026377590140328, 0.10315885359887034, 0.1563945907400921, 0.1154255453730002, 0.1943476518499665, 0.13126719219144434, 0.13177635002648458, 0.15547538147075102, 0.14016016968525946, 0.09883482664008625, 0.12721421982860193, 0.09899746830342337, 0.3116942464839667, 0.10716325981775299, 0.15056117641506717, 0.12653465004405007, 0.11828979011625051, 0.17496486223535612, 0.09765588794834912, 0.10866716271266341, 0.26147124299313873, 0.08694234798895195, 0.1842657834640704, 0.09069725158042274, 0.07933541593956761, 0.1280898501863703, 0.19266526243882254, 0.1346737242420204, 0.08719395831576549, 0.13489115866832435, 0.18360329791903496, 0.11718593450495973, 0.11880596124683507, 0.13947855157312006, 0.14253774366807193, 0.16413265286246315, 0.17115826805820689, 0.14698706741910428, 0.33145808440167457, 0.615200704196468, 1.2609328888356686, 2.464105077087879, 4.779244372621179, 8.908765409141779, 11.305688191205263, 19.05763227492571, 22.364511229097843, 23.821980021893978, 28.351373076438904, 30.897593647241592, 31.722527481615543, 41.11680708825588, 37.36175358295441, 38.47601719200611, 38.36663246154785, 36.863182336091995, 38.79912905395031, 43.85072238743305, 46.56419098377228, 50.4879554361105, 47.45281130075455, 50.59798613190651, 41.59405767917633, 38.695520013570786, 40.72452373802662, 25.75250633060932, 21.10307201743126, 11.790120396763086, 5.896293232217431, 1.7771221278235316, 0.3069745731772855, 0.17892427946208045, 0.10145753200049512, 0.2295115587185137, 0.1114430399320554, 0.144004761823453, 0.1538097794400528, 0.17923492763657123, 0.18101673515047878, 0.08477561073959805, 0.1173122035106644, 0.12791163084330037, 0.09494333076872863, 0.1945882264408283, 0.1612477912567556, 0.17262688925256953, 0.1927573184366338, 0.12417214165907353, 0.0832763611106202, 0.14088481751969084, 0.19513790553901345, 0.20368971774587408, 0.23627261311048642, 0.17271560558583587, 0.1074281991168391, 0.12813929206458852, 0.16641080874251202, 0.16320173250278458, 0.09064192447112873, 0.21115138923050836, 0.18744889937806875, 0.17252761957934126, 0.1369081379380077, 0.23377344565233216, 0.18781016202410683, 0.18585341545986012, 0.08865561074344441, 0.1497358488268219, 0.18132566154235974, 0.11654057030682452, 0.25223744160030037, 0.07872003450756893, 0.17114568123361096, 0.15629042289219797, 0.08661523897899315, 0.07477741208276711, 0.12222085730172694, 0.07561930440715514, 0.17524221766507253, 0.19991769280750304, 0.10795890892040916, 0.14484665414784104, 0.10839170718099922, 0.21930282760877162, 0.195916032535024, 0.12435072465450503, 0.17217229411471635, 0.15276584483217448, 0.16814225411508232, 0.09305210842285305, 0.10556812470895238, 0.2483034651959315, 0.0945589947514236, 0.15117543720407411, 0.11977054542512633, 0.1071753197174985, 0.12279287504497916, 0.08441425903583877, 0.24453430494759232], [0.12396587655530311, 0.03783138970902655, 0.05445868147944566, 0.01852622317528585, 0.1163813573657535, 0.0370339446089929, 0.017335128104605246, 0.013469111090671504, 0.050088251737179235, 0.036687947940663435, 0.025236774417862762, 0.07255093194544315, 0.02655034611962037, 0.05923418284510262, 0.027783869772974867, 0.054515396404895, 0.04631991156202275, 0.056558521537226625, 0.025520703420625068, 0.060293068017927, 0.035427955590421334, 0.024480201245751232, 0.07661165975150652, 0.05709720942832064, 0.03341434567118995, 0.04361051593150478, 0.06867393763968721, 0.10991216739057563, 0.011501953122206032, 0.05110788100864738, 0.04058624188473914, 0.02008709703659406, 0.03579885873477906, 0.01917626846989151, 0.05051866770372726, 0.01969390534213744, 0.01992793047975283, 0.006898178698975244, 0.031406761991092935, 0.027205124461033847, 0.013375071703194408, 0.059653255084413104, 0.08673646138049662, 0.14756479969946668, 0.0448542366939364, 0.09756579122040421, 0.07146863572415896, 0.06813198429881595, 0.01309682662395062, 0.023326859227381647, 0.010824324053828605, 0.05355417415557895, 0.05977813998470083, 0.0029597621642096783, 0.04256249208992813, 0.06808296544477344, 0.04716277981060557, 0.044465110113378614, 0.023637347840121947, 0.025825056327448692, 0.04504149910644628, 0.06471060187323019, 0.008691167131473776, 0.03466926544206217, 0.03138449385005515, 0.10472247711732052, 0.02245942217996344, 0.022581601951969787, 0.02638209938595537, 0.031979677733033895, 0.03435436847212259, 0.05280638244585134, 0.013154055486666039, 0.05399148096330464, 0.03263910562964156, 0.020631137667805888, 0.06169959371618461, 0.02805886517307954, 0.008035026949073654, 0.040668093351996504, 0.22259923978708684, 0.5095281370449811, 0.8706552372314036, 1.3502295222133398, 3.281088313087821, 3.2989478297531605, 5.2748845517635345, 4.766560653224587, 6.1643308494240046, 6.924954084679484, 7.133399499580264, 7.734902473166585, 7.341587953269482, 7.531366869807243, 7.340751998126507, 10.749229900538921, 11.470831129699945, 8.45755672082305, 11.02619418874383, 11.087064072489738, 6.665794216096401, 6.66668051853776, 2.999036335386336, 1.596611151471734, 0.6360864022281021, 0.12063344052876346, 0.028373546920192894, 0.06180395452247467, 0.07905909209512174, 0.11301557664410211, 0.019689432047016453, 0.06198671580932569, 0.0913881762244273, 0.09338172589195892, 0.03045407444005832, 0.03242702208808623, 0.02822588550770888, 0.060353987209964544, 0.11189255877980031, 0.04379601945402101, 0.07989906225702725, 0.05065707453468349, 0.054338171539711766, 0.03949761885451153, 0.03656073640740942, 0.04587141316733323, 0.021614987999782898, 0.026287221371603664, 0.01796482927602483, 0.0661457670503296, 0.02300082447618479, 0.034016520585282706, 0.03437062892771792, 0.052878511778544635, 0.018199663354607765, 0.03046389861992793, 0.05832517068483867, 0.03958888817578554, 0.01802527349354932, 0.006057221480659791, 0.06827404620707966, 0.022733122532372363, 0.05113343315315433, 0.04334278615715448, 0.01780346967279911, 0.04826585987757426, 0.06993693197728135, 0.04555312458251137, 0.0662025784549769, 0.036113002424826846, 0.020934299427608494, 0.06727350497385487, 0.022472326272691134, 0.012666014536080183, 0.06578440792509355, 0.10551262690569274, 0.06511096828035079, 0.06295439103269018, 0.05162635650776792, 0.04126840547542088, 0.03400611567485612, 0.06944489548914135, 0.055321643376373686, 0.038266447809292004, 0.012366289847705048, 0.0631223687378224, 0.03885339385305997, 0.035222291626269, 0.01949447727383813, 0.04965913081832696, 0.06029145384673029, 0.017821745059336536, 0.018391055818938185, 0.022652150510111824, 0.07525921435444616, 0.026488771982258186, 0.03313644105219282, 0.08163424805388786, 0.07274006828083657, 0.04868087256909348, 0.033847986269393004, 0.01714030877337791, 0.07554408031865023, 0.022745533096895088, 0.06913571676705033, 0.03190458723111078, 0.056931450744741596, 0.04801845752808731, 0.0271251283629681, 0.049833272059913725, 0.03390099787793588, 0.07261422972078435, 0.04215988810756244, 0.09955603090929799, 0.04541832458926365, 0.04188806167803705, 0.04494619250181131, 0.061536517896456644, 0.07878524702391587, 0.03539258112141397, 0.025837190441961866, 0.02685112558538094, 0.033521994191687554, 0.029590656122309156, 0.0800289009930566, 0.014409272116608918, 0.021892618024139665, 0.024797185506031383, 0.007028763757261913, 0.02808243763865903, 0.02380817724770168, 0.052832609944744036, 0.028232167787791695, 0.030714393869857304, 0.04983988459571265, 0.03185651090461761, 0.011837907604785869, 0.04082967003341764, 0.02590389096440049, 0.06640540741500445, 0.024203595385188237, 0.03799138932663482, 0.04383873747428879, 0.04694609124271665, 0.039414735801983625, 0.05099219131807331, 0.0283312073952402, 0.055524487179354765, 0.009884299397526775, 0.036756848930963315, 0.009177441770589212, 0.03922013354895171, 0.024021001081564464, 0.02480801344063366, 0.019943356019211933, 0.007288696342584444, 0.05219077465881128, 0.05125993593537714, 0.02636527675349498, 0.04246949727530591, 0.0692011890350841, 0.05764754532719962, 0.03242578270146623, 0.050077234554919414, 0.017408914281986654, 0.056954631727421656, 0.03884462908899877, 0.0320533099147724, 0.021709888278564904, 0.041837532553472556, 0.059207780941505916, 0.027948693350481335, 0.07612479603267275, 0.0871661797282286, 0.018546324245107826, 0.07882820995291695, 0.31465292209759355, 0.8812229451723397, 1.592429713346064, 2.4042723001912236, 4.626237507909536, 4.587009362876415, 7.445709491148591, 6.556445583701134, 9.614458791911602, 8.964795302599669, 9.525130335241556, 11.2988599576056, 10.253555998206139, 11.261018738150597, 9.959283638745546, 13.371364697813988, 15.131001826375723, 11.837364211678505, 13.699092362076044, 13.427790720015764, 8.899633549153805, 7.8406028263270855, 3.7949233409017324, 2.1608421625569463, 0.7329822715837508, 0.11663621829939075, 0.04645168730348814, 0.03530792804667726, 0.039887079401523806, 0.035953533442807384, 0.0046021338130231015, 0.08810274041024968, 0.04108290195290465, 0.020881866694253404, 0.1100768573815003, 0.04486224446736742, 0.07731229168712161, 0.054403755129897036, 0.06883585199830122, 0.046078899104031734, 0.039591140593984164, 0.031162228042376228, 0.016545123035029974, 0.05064955657871906, 0.025622249631851446, 0.05037426431954373, 0.02594865916762501, 0.028487169729487505, 0.04756660833663773, 0.03472206924925558, 0.02852102836186532, 0.08386700676055625, 0.05456668994156644, 0.06324053349089809, 0.042617492654244415, 0.037530693734879605, 0.0706888537388295, 0.03152977296849713, 0.011663041841529775, 0.03210014314390719, 0.06567489661392756, 0.010608736647554906, 0.04956880773534067, 0.03152843710267916, 0.01470209668696043, 0.02329414535779506, 0.005218576516199391, 0.048705964582040906, 0.030571947900170926, 0.08684435480972752, 0.023343080720223952, 0.020815505704376847, 0.09919318006723188, 0.05154141028469894, 0.041593510686652735, 0.09180311841191724, 0.09593507755198516, 0.0424177547392901, 0.059949089991278015, 0.044268600540817715, 0.05445924180094153, 0.02141923727322137, 0.042692898568930104, 0.033705679452396, 0.053093831083970144, 0.05751777338446118, 0.030341987876454368, 0.02050466642685933, 0.0333251432311954, 0.0205572141931043, 0.02410624045296572, 0.019055402299272828, 0.03787960704357829, 0.03306025217170827, 0.04080722377693746, 0.028885057363368105, 0.23745314741972834, 0.14823013509158045, 0.11099836730863899, 0.11291649250779301, 0.26997316803317517, 0.16486921958858147, 0.10333049009204842, 0.06028117881214712, 0.23912185162771493, 0.10238592163659632, 0.1988780329702422, 0.1520184872788377, 0.14949281030567363, 0.13664185535162687, 0.0949393528571818, 0.19801975402515382, 0.09439398563699797, 0.22596482012886554, 0.12333807899267413, 0.19257547741290182, 0.1206651673419401, 0.13595162832643837, 0.24762321263551712, 0.14671049866592512, 0.09515979298157617, 0.15332944662077352, 0.14777674223296344, 0.19734873378183693, 0.2545309450943023, 0.10524920158786699, 0.0834374368423596, 0.10909884033026174, 0.11865934997331351, 0.11694290340528823, 0.09299940851633437, 0.10997027755365707, 0.15347372012911364, 0.10790358923259191, 0.16597579146036878, 0.14623074472183362, 0.12391105410642922, 0.12477645766921341, 0.177418565726839, 0.18613856344018131, 0.23106068809283897, 0.1593013753881678, 0.158263081102632, 0.11814913828857243, 0.17627090855967253, 0.14206885476596653, 0.10006915923440829, 0.16774133109720424, 0.16371460107620806, 0.11778464730014093, 0.10077762824948877, 0.09031282650539652, 0.09325161256128922, 0.12030025332933292, 0.10113937329151668, 0.13704029959626496, 0.12011845683446154, 0.1060831751965452, 0.10177852571359836, 0.11707443423802033, 0.16469623980810866, 0.25149529392365366, 0.12120194791350514, 0.09627625026041642, 0.08684275177074596, 0.14946609298931435, 0.1069795634248294, 0.17016116296872497, 0.17292823089519516, 0.16198391269426793, 0.1572607216075994, 0.10129330214112997, 0.18662884103832766, 0.3142586338799447, 0.11844829059555195, 0.2987017045961693, 0.35150031675584614, 0.9146337804850191, 1.5760392928496003, 2.4883349519222975, 4.37765009701252, 4.250221559777856, 7.003056518733501, 6.950167631730437, 8.65395488217473, 10.034826435148716, 10.575619116425514, 10.79235378652811, 10.239975526928902, 11.844520177692175, 10.847875457257032, 14.775019828230143, 17.753162272274494, 14.833031315356493, 16.21466852724552, 15.607370864599943, 10.26310108602047, 9.450607784092426, 4.675668105483055, 2.4579123593866825, 0.9170624439138919, 0.324539368157275, 0.07383142612525262, 0.19938033336075023, 0.21417031239252537, 0.23913384473416954, 0.07952910906169564, 0.11879177880473435, 0.27623552887234837, 0.16499085759278387, 0.19703897618455812, 0.1077243457257282, 0.15196049585938454, 0.2065968289389275, 0.19880038948031142, 0.09602605743566528, 0.1899813298950903, 0.09931731168762781, 0.10044044829555787, 0.2079382460215129, 0.10902487047133036, 0.16099087457405403, 0.08415076692472212, 0.18550116248661652, 0.09602225021808408, 0.16827867570100352, 0.07599101649248041, 0.2024814419564791, 0.15106499078683555, 0.17996873357333243, 0.08316528386785649, 0.12075492268195376, 0.13979616109281778, 0.2175667363917455, 0.18244115402922034, 0.12953602883499116, 0.1579129506717436, 0.24822755833156407, 0.17751025065081194, 0.11149323137942702, 0.09540147337247618, 0.10860778347705491, 0.1396012434270233, 0.13133564789313823, 0.10177624732023105, 0.27590827143285424, 0.09214794990839437, 0.11859964419272728, 0.151300682045985, 0.0942603471048642, 0.1296274911146611, 0.15234534395858645, 0.1226461301848758, 0.12088174087693915, 0.19774952321313322, 0.17089122848119587, 0.18877392983995378, 0.1690181516460143, 0.10451710259076208, 0.16743092040996999, 0.14195149153238162, 0.34201109781861305, 0.15484479343285784, 0.1265455744578503, 0.11570232192752883, 0.18294122797669843, 0.08623214976978488, 0.08519899856764823, 0.16082553891465068, 0.1015204364375677, 0.2501544705592096, 0.1392142430995591], [0.1052922461531125, 0.010021942744060652, 0.011681386804411886, 0.06054935758584179, 0.04904418354271911, 0.030304331303341314, 0.010186384115513647, 0.045459439570549875, 0.004514432830546866, 0.04946805005602073, 0.06796529050916433, 0.030308140376291703, 0.0168469749041833, 0.031834762266953476, 0.02790889011521358, 0.033264123849221505, 0.05669085760018788, 0.05352663676603697, 0.06808696562075056, 0.013320976559043629, 0.11860875034471974, 0.049178111512446776, 0.051314468946657144, 0.0474325838877121, 0.009360792137158569, 0.07658120943233371, 0.0031440374323210563, 0.02226358796178829, 0.011550296621862799, 0.0284485724841943, 0.026682047646318097, 0.05005949722544756, 0.023602552246302366, 0.06353253149427474, 0.04664315398258623, 0.03800877042522188, 0.04238824694766663, 0.005008750031265663, 0.08569233381422237, 0.022386600794561673, 0.040817235349095426, 0.0070305152257787995, 0.047972997272154316, 0.09357470655231737, 0.06756810049409978, 0.029780410295643378, 0.037392457597889006, 0.025732096764841117, 0.06082808227802161, 0.035483831888996065, 0.06071892348700203, 0.019388884502404835, 0.05191279582504649, 0.034252460463903844, 0.019288102703285404, 0.011243699646001915, 0.011937147592107067, 0.00884874549228698, 0.04582223846227862, 0.049032791575882584, 0.042313924568588845, 0.035238860073150136, 0.036271287681302056, 0.0452205422334373, 0.020409216958796605, 0.042944000524585135, 0.103251881810138, 0.006011903624312254, 0.004443212628757465, 0.01636726734432159, 0.06540001253597438, 0.04993686845409684, 0.04761015756230336, 0.03687345888465643, 0.022917748465260956, 0.04105379121028818, 0.010604026792861987, 0.07845263869967312, 0.0356522474612575, 0.010583090806903783, 0.009238210677722236, 0.07728443888481706, 0.08794752764515579, 0.016938149601628538, 0.05618914350634441, 0.09527132293442264, 0.07358933755313046, 0.12294125262997113, 0.26326100633013994, 0.15537412284174934, 0.09583237915649079, 0.23912672011647373, 0.15848587383516133, 0.35830607812386006, 0.424956995411776, 0.35810047353152186, 0.5949055182281882, 1.1327101942151785, 0.5465930106583983, 0.7319648761767894, 0.4452934447908774, 0.2673533570487052, 0.06489822422736324, 0.059250929407426156, 0.015035679080028785, 0.02673099599633133, 0.05421151661721524, 0.021182013479119632, 0.08274713560240343, 0.009248285332432715, 0.0326662533916533, 0.04191817432001699, 0.03004221958690323, 0.018062438393826596, 0.02783408905088436, 0.005973405641270801, 0.04881484135694336, 0.019580495900299866, 0.027890386518265586, 0.041528223955538124, 0.009247481957572745, 0.042421061007189564, 0.012810413281840738, 0.04738134972285479, 0.056108579665306024, 0.058209618291584775, 0.033130544688901864, 0.028621479905268643, 0.08504057230311446, 0.018648250807018485, 0.07514432247262448, 0.02121326902852161, 0.0417404076870298, 0.04591467666614335, 0.01723122000839794, 0.09224080000421964, 0.05793149473902304, 0.02501946615666384, 0.03109107092313934, 0.05042558383138385, 0.03844499740807805, 0.007736918751106714, 0.048363893874920905, 0.023008323878457304, 0.027440821286290884, 0.0065989874292426975, 0.05201477433729451, 0.01813362519897055, 0.02764471708360361, 0.02969263463455718, 0.022019332318450324, 0.009151873855444137, 0.01480830358559615, 0.07301023972104304, 0.041120217138086446, 0.035178842590539716, 0.0413600273168413, 0.02251122408779338, 0.022183456421771552, 0.05233193114690948, 0.00497858497510606, 0.02327595717360964, 0.027747224376071244, 0.03453996105236001, 0.05682248120137956, 0.04954184922098648, 0.07911070846603252, 0.03208115900633857, 0.028885573156003375, 0.07954124317620881, 0.032618863551761024, 0.02788204663374927, 0.05071927393146325, 0.020375274834805168, 0.0755888615094591, 0.09895336246700026, 0.05199562321649864, 0.011069054671679623, 0.054972069556242786, 0.024433316066279076, 0.0290767652404611, 0.012715542688965797, 0.03080670034250943, 0.024764766640146263, 0.036011728952871636, 0.10389114555437118, 0.03777333149628248, 0.04030874915770255, 0.0819376009167172, 0.03825419866188895, 0.023140671073633712, 0.017366871616104618, 0.052277654176577926, 0.03814836098172236, 0.013085907776257955, 0.05663865122187417, 0.08482903052936308, 0.06026083283359185, 0.03223514722776599, 0.01797179618733935, 0.028544181514007505, 0.08167925931047648, 0.011945095066039357, 0.02207194316724781, 0.008098773723759223, 0.016849448111315724, 0.013470543435687432, 0.02670484085683711, 0.04347889975178987, 0.060749626136384904, 0.07231590861920267, 0.05526629029191099, 0.017793446968425997, 0.05408311764767859, 0.03610184052377008, 0.043292449990985915, 0.016999274739646353, 0.04958792917022947, 0.003457304692346952, 0.00995599457382923, 0.025692471645015758, 0.03344108154124115, 0.010045020753750578, 0.013575909852079349, 0.03715109633048996, 0.014285134002420818, 0.053938402561470866, 0.03930327635316644, 0.06163136808027048, 0.05800839979201555, 0.054851218228577636, 0.06504420467535965, 0.05246932494628709, 0.061133962153689936, 0.06788007711293176, 0.034815609542420134, 0.03233028684917372, 0.05447380644909572, 0.09471563986153342, 0.07034578113234602, 0.013299899565026863, 0.015229666278173681, 0.043349402403691784, 0.029127531852282118, 0.022931609928491525, 0.04430703636899125, 0.011742353308363818, 0.03478302554867696, 0.04357519712357316, 0.043927346196142025, 0.058200849816785194, 0.03913078639016021, 0.01549821519802208, 0.05221987797995098, 0.009610770666768076, 0.03418692140257917, 0.018608703612699173, 0.046289813762996346, 0.060879464872414246, 0.07473608187865466, 0.09011036861920729, 0.12145029279054143, 0.11309488254482858, 0.28220687876455486, 0.34453929809387773, 0.5825568933505565, 0.22877494746353477, 0.5755355232395232, 0.3219689248362556, 0.6788544135633856, 0.9393801901023835, 0.7043464144226164, 0.8664519502781332, 1.3364208256825805, 0.8129961811937392, 0.9448101581074297, 0.5622255499474704, 0.32287274196278304, 0.04568549404211808, 0.012912232232338283, 0.025139178287645336, 0.027592349288170226, 0.05367606820072979, 0.014509711600112496, 0.0061700112291873666, 0.03268574961111881, 0.018969617449329235, 0.012859501712227939, 0.06205409539688844, 0.017887224748847075, 0.05926322308368981, 0.035652021106216125, 0.07031408400507644, 0.029150527298043016, 0.017952914095076267, 0.038345148859662004, 0.026016226147476118, 0.023898188628663775, 0.04901621570752468, 0.017534611833980307, 0.016906357850530185, 0.06410821544704959, 0.056491193900001235, 0.030895611489540897, 0.06655063829384744, 0.04101793063455261, 0.010082501994475024, 0.01936965545610292, 0.080890452809399, 0.032937330252025276, 0.02395766063273186, 0.07772586090140976, 0.013427067497104872, 0.031644434784539044, 0.03934257307264488, 0.022932906831556465, 0.03233786417695228, 0.05935726061579771, 0.010605214229144622, 0.03798555975663476, 0.06275618565268815, 0.03934507411031518, 0.049575435114093125, 0.0455743203201564, 0.03519629048241768, 0.021851890815014485, 0.028079823423468042, 0.03286743478383869, 0.04807150624401402, 0.01940946611284744, 0.07107507481123321, 0.030086800397839397, 0.06178944182465784, 0.07003974911640398, 0.009495688609604258, 0.023345494555542246, 0.022552416994585656, 0.05083412499516271, 0.06895478116348386, 0.042914002915495075, 0.016308355661749374, 0.031018609479360748, 0.07228573289467022, 0.04153251356910914, 0.011670806561596692, 0.030971531341492664, 0.04376858225441538, 0.04477763963222969, 0.04696064475865569, 0.004055725266880472, 0.09409642894752324, 0.04945932611008175, 0.11712668885593303, 0.09162547052255832, 0.13198446307796985, 0.12346336094196886, 0.14659111679065973, 0.08166864659870043, 0.10735296760685742, 0.2103816336602904, 0.13053163478616625, 0.24683286988874897, 0.08276845008367673, 0.08129502719384618, 0.12509844586020336, 0.169735956878867, 0.10681902946089394, 0.1694072745158337, 0.2009305017418228, 0.14512375724734738, 0.12860406946856529, 0.19533862679963931, 0.25801102397963405, 0.14290430524852127, 0.09729987970786169, 0.18740063009317964, 0.192352699523326, 0.17319485486950725, 0.11655201422399841, 0.11752751539461315, 0.10002085284213535, 0.1732962767709978, 0.11140247414004989, 0.11452310121967457, 0.1072989466774743, 0.1859532788512297, 0.09682892021373846, 0.1414653254323639, 0.10728048204327933, 0.09104180848225951, 0.1701554484316148, 0.11915199502254836, 0.16223306651227176, 0.13857501646270975, 0.07974259526235983, 0.1564846429391764, 0.12148859503213316, 0.16497062664711848, 0.08015424231416546, 0.09074637433513999, 0.16886710975086316, 0.14263128396123648, 0.14444028376601636, 0.17507435870356858, 0.21804136951686814, 0.1532209594734013, 0.1436272164573893, 0.1310960529372096, 0.12296414046431892, 0.2237423401675187, 0.14113244251348078, 0.1096766468253918, 0.16170756658539176, 0.25251788436435163, 0.24395988264586776, 0.20683820504928008, 0.13051365996943787, 0.11262449450441636, 0.21056239114841446, 0.06505170778837055, 0.14676918770419434, 0.09821615007240325, 0.12155960372183472, 0.136698703863658, 0.10664682151400484, 0.14603754883864895, 0.09263691390515305, 0.18335501983528957, 0.07468110357876867, 0.14414940640563145, 0.08401225248235278, 0.11464318813523278, 0.10724449530243874, 0.1994512975215912, 0.16054046514909714, 0.1453552776365541, 0.33438716316595674, 0.2005270851077512, 0.20659261354012415, 0.2706318983109668, 0.4960727918660268, 0.5595472874119878, 0.34267558716237545, 0.5461791297420859, 0.400748880347237, 0.546834891429171, 0.8302844816353172, 0.7543950725812465, 1.0663396306335926, 1.579264251049608, 1.3307447615079582, 1.4912214316427708, 0.8052976161707193, 0.5216504365671426, 0.21584842703305185, 0.15859885839745402, 0.08998260789667256, 0.12139826081693172, 0.15916201489744708, 0.083888529043179, 0.16368209500797093, 0.10060533866635524, 0.09355411937576719, 0.08966333596617915, 0.1207857663393952, 0.24802846979582682, 0.15489463607082143, 0.06381111146765761, 0.132204465335235, 0.09686216842965223, 0.10479695905814879, 0.083866220084019, 0.1108899172686506, 0.08156421157764271, 0.12165239444584586, 0.1698882010532543, 0.1398574179620482, 0.12564549775561318, 0.09643784549552947, 0.1463667952339165, 0.15389055479317904, 0.08127823239192367, 0.22417893080273643, 0.10771345099783503, 0.1141017246118281, 0.17160456598503515, 0.14178744720993564, 0.12437375349691138, 0.1519258672487922, 0.09050571810803376, 0.11891926493262872, 0.1265651819994673, 0.1095217457623221, 0.1841695565963164, 0.09672864121966995, 0.22984467912465334, 0.15000542654888704, 0.09471225566812791, 0.14089789416175336, 0.13054159440798685, 0.147498243895825, 0.11388023805920966, 0.10523544959141873, 0.1486880995798856, 0.08197892369935289, 0.15816814557183534, 0.16100371372886002, 0.19522237678756937, 0.2228724243468605, 0.17153262218926102, 0.0634370170882903, 0.08558026209357195, 0.14000246330397204, 0.19433331355685368, 0.13013204763410613, 0.10446452884934843, 0.14349591569043696, 0.1311621189233847, 0.13449663296341896, 0.13324069645022973, 0.10741392019554041, 0.12631429155590013, 0.1462073967559263, 0.2763261302607134, 0.10847605968592688, 0.20072316052392125, 0.16153409698745236, 0.1580688907415606], [0.046290811951621436, 0.011533177130331751, 0.07331201923079789, 0.018359495988988783, 0.05742700130213052, 0.015107290764717618, 0.007804018641763832, 0.04679886398662347, 0.048365867987740785, 0.05444338581582997, 0.05556578027608339, 0.05146165167388972, 0.029067278737784363, 0.017133085821114946, 0.050311259692534804, 0.01895901958050672, 0.05121877642523032, 0.006918356766618672, 0.0391595817200141, 0.05172862445760984, 0.05400599737185985, 0.03073702937399503, 0.060086272278567776, 0.07651872059796005, 0.008126405737129971, 0.03923567041056231, 0.04944905849697534, 0.035841762291966006, 0.025012614278239198, 0.017508180244476534, 0.025165034712699708, 0.03822857230261434, 0.04250448582752142, 0.03215851305867545, 0.038065852713771164, 0.022456065817095805, 0.061870083591202274, 0.049734225030988455, 0.011946913327847142, 0.0708858271536883, 0.02129158045136137, 0.042215931389364414, 0.03567864194337744, 0.05857240605109837, 0.0400403440289665, 0.10876986852963455, 0.04240693793690298, 0.11609869558014907, 0.043637088529067114, 0.023510178980359342, 0.0715266123006586, 0.025760083153727464, 0.017986333004955668, 0.05357846093829721, 0.03179069724865258, 0.025112325529335067, 0.05256046810245607, 0.013979896084492793, 0.03525535430526361, 0.021078919889987446, 0.02997039267938817, 0.059335482292226516, 0.023375757482426707, 0.03422414753003977, 0.07051083477563225, 0.02096159747452475, 0.012061015750077786, 0.022838978766230866, 0.05594794551143423, 0.013667939874721924, 0.054449968665721826, 0.029967874943395145, 0.0013884983513889892, 0.046929574746172875, 0.008431490587099688, 0.04124165847315453, 0.028687803787761368, 0.02181923631724203, 0.03966236450651195, 0.05740651802625507, 0.018653369770618156, 0.02559716689574998, 0.004415947514644358, 0.08255593609646894, 0.07890647684689611, 0.027406773406255525, 0.07524543267209083, 0.007343280376517214, 0.022810686241427902, 0.06776818350772373, 0.009535204262647312, 0.032143837088369764, 0.05721904781239573, 0.06655130622675642, 0.11216269311262295, 0.06706288346322253, 0.09079194962396286, 0.03598722323658876, 0.041187500246451236, 0.027308687458571512, 0.04505329554376658, 0.1057917634898331, 0.03486593457637355, 0.054786951950518414, 0.032896393386181444, 0.05120739559060894, 0.01514841131211142, 0.05143969894561451, 0.04585188355122227, 0.048640677850926295, 0.023962785162439104, 0.07131649545044638, 0.031204096303554252, 0.05389205914980266, 0.035314978449605405, 0.0352446451142896, 0.06413903684006073, 0.03737138060387224, 0.058344919234514236, 0.05491875737789087, 0.09603115599020384, 0.04272310769010801, 0.024763163601164706, 0.05420111912826542, 0.056667346361791715, 0.03807035383943003, 0.03087067903834395, 0.04576987623295281, 0.020433396130101755, 0.03535363321134355, 0.006226695541045046, 0.013558805203501834, 0.03830839028523769, 0.031827266575419344, 0.03207944093446713, 0.0666860728233587, 0.01941957787494175, 0.003963158578699222, 0.0511964266479481, 0.02725999514950672, 0.06392419250914827, 0.010131438284588512, 0.021987074869684875, 0.022164986221469007, 0.0059803767271660035, 0.041566982617951, 0.03055901968764374, 0.07669322920264676, 0.05823958621476777, 0.010436826487421058, 0.03245607345888857, 0.057900643660104834, 0.041023660014616325, 0.04124623752431944, 0.04104744213691447, 0.09106166093260981, 0.020051859864906874, 0.07631483778823167, 0.03928588412236422, 0.041630165360402316, 0.033743729363777675, 0.04757879811222665, 0.07109442260116339, 0.022238230631046463, 0.00750197149500309, 0.0737997141550295, 0.04097265591553878, 0.061345251597231254, 0.06809975282521918, 0.0464768164238194, 0.06325536160147749, 0.033934561506612226, 0.005985624638924492, 0.01650304697250249, 0.04002581648819614, 0.05156051316589583, 0.039096272812457755, 0.041325346755911596, 0.014233885922294576, 0.032356347364839166, 0.014070869474380743, 0.027472724359540734, 0.04453492394532077, 0.025818024478212465, 0.02045596298557939, 0.02697195093787741, 0.06241614100872539, 0.09962757394532673, 0.04847934236750007, 0.03305224439827725, 0.05617417809844483, 0.00889623181137722, 0.02818713241140358, 0.02339527040021494, 0.02840148692484945, 0.016968186173471622, 0.032624247833155096, 0.02882613640394993, 0.01891008607344702, 0.010781324017443694, 0.021161313125048764, 0.028832912212237716, 0.07778889150358737, 0.05349028266209643, 0.02759961676929379, 0.04775525114382617, 0.019129177344439086, 0.010096050827996805, 0.06596829727641307, 0.03209781280020252, 0.030321009217004757, 0.03663750416308176, 0.026971140141540673, 0.03175664380250964, 0.040805505705066025, 0.05041095238993876, 0.039708986223558895, 0.07835015552700497, 0.006882563448016299, 0.024317503921338357, 0.06152788671897724, 0.03735153557499871, 0.05080706258013379, 0.040857559943106025, 0.07411110447719693, 0.03432657875237055, 0.029962765256641433, 0.017549760923429858, 0.03624225857493002, 0.0233480939277797, 0.04916711288387887, 0.0207881612732308, 0.07300228389794938, 0.029520402567868587, 0.03641228460764978, 0.005190865185795701, 0.010237319565931102, 0.06411856840713881, 0.024219644328695722, 0.02624754615681013, 0.06996525975409895, 0.05165919654245954, 0.03789326256082859, 0.02753756951278774, 0.0628917982976418, 0.017619186983210966, 0.04097233679203782, 0.058223459345754236, 0.06648171503911726, 0.05102941744553391, 0.024122623362927698, 0.03368224985024426, 0.04234691303281579, 0.00786684051490738, 0.07312133922823705, 0.054830820299685, 0.007119920828699833, 0.02713003210374154, 0.019843464797304478, 0.11796317834523506, 0.014906501783116255, 0.040642114472575486, 0.06814189939177595, 0.02296863567607943, 0.014516377941617975, 0.08989534617285244, 0.028104874618293252, 0.021859123044123407, 0.04145057304413058, 0.08909848736948334, 0.08399865633691661, 0.06601782821235247, 0.044808924867538735, 0.05634112050756812, 0.04626807996828575, 0.044276508124312386, 0.010304016377631342, 0.06047552502423059, 0.04296440958569292, 0.03933614607376512, 0.03316813075798564, 0.055026509799063206, 0.04653398034861311, 0.045678473325097, 0.048000363967730664, 0.027998994264635257, 0.1228521578013897, 0.08669147980981506, 0.04348977963672951, 0.07684534721192904, 0.045448630189639516, 0.029652957564394455, 0.07165187198552303, 0.05094679414469283, 0.034123749792343006, 0.06090493538067676, 0.03140773049381096, 0.02715272883506259, 0.016816860406834166, 0.03475407065707259, 0.06561945076100528, 0.011495970484247664, 0.025760632343008183, 0.009537885271129198, 0.03549154651409481, 0.055313253396889195, 0.040003281173994765, 0.027898062180611305, 0.026715472122305073, 0.018970096134580672, 0.07567469830974005, 0.05654068030708004, 0.029790104599669576, 0.036298071790952235, 0.05052916538261343, 0.02639944894326618, 0.03213274569134228, 0.007590838113173959, 0.05379733884183224, 0.04921457693853881, 0.03285927487013396, 0.006354691431624815, 0.03266131068812683, 0.0416258312179707, 0.03872978915751446, 0.02130198907252634, 0.040445211561745964, 0.06374364282237366, 0.01462379639633582, 0.058127084048464894, 0.03127926102024503, 0.07428017313941382, 0.034427410646458156, 0.06998644807026722, 0.03241976388380863, 0.07075592162436806, 0.045979863207321614, 0.07600110970088281, 0.043809018170577474, 0.03326330377603881, 0.030055639472266193, 0.038184614895726554, 0.06517536443425342, 0.03993932288722135, 0.03462055086856708, 0.05563589838857297, 0.017690141867205966, 0.03879594791214913, 0.05015371658373624, 0.04689797780883964, 0.042141442027059384, 0.02794245559925912, 0.1851721535786055, 0.11838286285637878, 0.14036757027497515, 0.12568299105623737, 0.12861722032539546, 0.16006241814466193, 0.143824479309842, 0.11936949624214321, 0.13002464402234182, 0.11427351695601828, 0.1326169806998223, 0.16114313359139487, 0.14389548799954355, 0.13111260283039883, 0.0953694645431824, 0.09832885261857882, 0.19573336030589417, 0.08203172008506954, 0.0802631227998063, 0.12270909399376251, 0.1381505376775749, 0.08489350831951015, 0.12075181308318861, 0.16484649502672255, 0.08954943856224418, 0.2228985182591714, 0.15135380497667938, 0.14743425592314452, 0.09583404898876324, 0.18800277903210372, 0.09924008380039595, 0.10322134243324399, 0.14227598818251863, 0.17316304642008618, 0.16175377269973978, 0.0946954608662054, 0.1263277541147545, 0.0888926452898886, 0.10834584245458245, 0.17504948191344738, 0.0962398701813072, 0.13114415894960985, 0.1305782565032132, 0.08118900397676043, 0.1434174261521548, 0.16511170892044902, 0.1715135935228318, 0.2119417319772765, 0.16311067098286003, 0.10210724518401548, 0.13858356600394472, 0.13403252349235117, 0.12164927742560394, 0.15315495285904035, 0.16237827512668446, 0.1049586062435992, 0.167514753411524, 0.08808158177998848, 0.1549964290461503, 0.047948254068614915, 0.13949499756563455, 0.11754243256291375, 0.11202650901395828, 0.08480995733407326, 0.1569893627311103, 0.1854894810821861, 0.11577045850572176, 0.10162851540371776, 0.15572141826851293, 0.12336843283264898, 0.10195949842454866, 0.17238187661860138, 0.13303437939612195, 0.15586285677272826, 0.11687927908496931, 0.11679369461489841, 0.10858967507374473, 0.13287967129144818, 0.1862559118308127, 0.18079591653076932, 0.08017725631361827, 0.11116064531961456, 0.10231748077785596, 0.21480869298102334, 0.146343358210288, 0.18983407295309007, 0.2206431166268885, 0.084964539273642, 0.17540583154186606, 0.19653035269584507, 0.17426406702725217, 0.15623301034793258, 0.13875322096282616, 0.17545246810186654, 0.17616337136132643, 0.1490487388218753, 0.18777051649522036, 0.10003084214986302, 0.11445675321738236, 0.1013503955618944, 0.1447561418171972, 0.21917042846325785, 0.10232171101961285, 0.14290155930211768, 0.13228136667748913, 0.15233427111525089, 0.13625930791022256, 0.10652569559169933, 0.15970986831234768, 0.11019669196684845, 0.18819233839167282, 0.10632876670570113, 0.099220951233292, 0.19638618308817968, 0.08201686228858307, 0.09655674497480504, 0.2075968135613948, 0.12433770738425665, 0.21477214962942526, 0.19413363130297512, 0.12600680493051186, 0.16066637792391703, 0.1298730677808635, 0.188560399110429, 0.15140474599320441, 0.14592214487493038, 0.09631148001062684, 0.16647883399855345, 0.11189741984708235, 0.097422378603369, 0.12336796527961269, 0.08435046402155422, 0.11943958466872573, 0.15425085264723748, 0.1282610636553727, 0.14926275936886668, 0.0837499849149026, 0.0895835179835558, 0.1429588085738942, 0.10972577700158581, 0.15149656450375915, 0.14466065709711984, 0.14114710735157132, 0.12137629324570298, 0.14553946384694427, 0.10509315761737525, 0.12070966651663184, 0.15074594150064513, 0.12668011098867282, 0.10723900340963155, 0.16256182309007272, 0.1370266143931076, 0.1584506218205206, 0.24259145138785243, 0.14723255502758548, 0.1530850277049467, 0.17611663090065122, 0.15417092334246263, 0.06165413717099, 0.10634991049300879, 0.10497840674361214, 0.16682179528288543, 0.11180488887475803, 0.11903702892595902, 0.058712508689495735, 0.14299245754955336, 0.17200048692757264, 0.19133430963847786, 0.1758537325076759, 0.11194302482181229, 0.11658606395940296, 0.11890981739270501, 0.19328127469634637, 0.08609037729911506, 0.13277200050652027, 0.14610259066103026], [0.037397619234980084, 0.01753440959873842, 0.05086274220957421, 0.044290761070442386, 0.04076394543517381, 0.04623277229256928, 0.05614357934973668, 0.03748706658370793, 0.07086538840667345, 0.012810234238713747, 0.025000296482176054, 0.00787863695222768, 0.014135480851109605, 0.05191843243665062, 0.0562011625879677, 0.026252872921759263, 0.013687339614989469, 0.04466448437597137, 0.01812575472285971, 0.09270387046854012, 0.03587682876968756, 0.06434883456677198, 0.04665657201258, 0.04420545119501185, 0.06643334185355343, 0.03392548875126522, 0.03632077779911924, 0.03128705357084982, 0.014938633066776674, 0.09757263382198289, 0.01625929227884626, 0.06368765520164743, 0.03268600565206725, 0.027743073915189598, 0.06095108954468742, 0.06736125651514158, 0.044518255308503285, 0.007874599668866722, 0.09840737184276804, 0.032884723113966174, 0.025527701873215847, 0.038870819480507635, 0.053074219831614755, 0.0027448120772533002, 0.04996891810151283, 0.030616576950706076, 0.06170133776322473, 0.04365980195871089, 0.026886637351708487, 0.04354498058091849, 0.04165501617535483, 0.01677348744124174, 0.062188572555896826, 0.01835398554248968, 0.06801649869885296, 0.013769482375209918, 0.029041849047644064, 0.04380208280053921, 0.027775720991485287, 0.03632576874224469, 0.030328957618621644, 0.032281338499160483, 0.02475123172189342, 0.04227466866723262, 0.06940738734556362, 0.009754429120221175, 0.03195099001459312, 0.033147001813631505, 0.047189868200803176, 0.028612672467716038, 0.05807090346934274, 0.02658659632288618, 0.016786562227935065, 0.03203013264283072, 0.0646655164018739, 0.04195577523205429, 0.07708160992478952, 0.03996973238827195, 0.016202996666834224, 0.05892916757147759, 0.01967977670574328, 0.027547352874535136, 0.035481271479511634, 0.02006547641940415, 0.0342640453891363, 0.033702484506648034, 0.02136044618964661, 0.057346778849023394, 0.014806421313551255, 0.03737514329259284, 0.010118292993865907, 0.06499333045212552, 0.05086655684863217, 0.04751636864966713, 0.05085558048449457, 0.040097797391354106, 0.01231031335919397, 0.033856836380437016, 0.04331246942456346, 0.04573714752041269, 0.05403678536822554, 0.07015413633780554, 0.01155271973402705, 0.04793983811396174, 0.16971222299616784, 0.06494238943560049, 0.016829771921038628, 0.024885918537620455, 0.003339919426252891, 0.04134045317186974, 0.06263543080422096, 0.05516662356967572, 0.01803746141376905, 0.040371824288740754, 0.059991218004142866, 0.034589057831908576, 0.03679775611090008, 0.01950444988324307, 0.007099906497387565, 0.061941786188981496, 0.04428058993653394, 0.06348095223074779, 0.03304294899862725, 0.02045071785687469, 0.05117555003380403, 0.04929536342388019, 0.06754303074558266, 0.02814160536217969, 0.03520533355185762, 0.03906819365511183, 0.04178712588327471, 0.030580488164559938, 0.014257586408348288, 0.06024434231221676, 0.08870511199347675, 0.07879928103648126, 0.08728366170544177, 0.020588510560628492, 0.026370102568762377, 0.06821223272709176, 0.042922964348690584, 0.028354575770208612, 0.04440030948899221, 0.03764889559533913, 0.026937780603475403, 0.06443343198043294, 0.03616194335336331, 0.02418622356344713, 0.07695422769756988, 0.05489905706781428, 0.017988685613090638, 0.04153409805439878, 0.008642487809993327, 0.06870075143524446, 0.06818419438786805, 0.02227514320111368, 0.004656675637306762, 0.0054569780058955075, 0.03761587373446673, 0.024208725481003057, 0.03702870504639577, 0.03346695280924905, 0.011698632461047964, 0.03700973575178068, 0.025963045700336806, 0.027446433778095525, 0.03676497173728421, 0.03136079707473982, 0.025777766677492764, 0.040340219929930754, 0.050791566536645405, 0.04498588255955838, 0.023247551471285988, 0.0202133066704846, 0.020871812448604032, 0.0034380390025035013, 0.006686311771773035, 0.07948391968966462, 0.02264017781271832, 0.03851225825201254, 0.020818949269596487, 0.0048961346874421, 0.02827584874466993, 0.019935795389756095, 0.019015380130440462, 0.030423716889345087, 0.014306164612207795, 0.025987323206209112, 0.08187093379092403, 0.05943431409832556, 0.015505534629483009, 0.026132767452509142, 0.08813621869194321, 0.04991855596017558, 0.02585433034255402, 0.033764201507437974, 0.07212143624201417, 0.036783402974833734, 0.03340455674333498, 0.034473093546694145, 0.03106607538938988, 0.05021906639740337, 0.03544012681231834, 0.03336414309160318, 0.05948879144852981, 0.03020819534867769, 0.022724274276697543, 0.048859073358471505, 0.052229225329938345, 0.020156190985289868, 0.049614305098657496, 0.045172165337135084, 0.0613199220970273, 0.04919536644592881, 0.04393475654069334, 0.029837186448276043, 0.0808481578133069, 0.08665823901537806, 0.035629701014840975, 0.0795540823310148, 0.09848374626017176, 0.01333044450802845, 0.01818953674955992, 0.011230229665670777, 0.009674605571490247, 0.017776223576220218, 0.0495566513563972, 0.02338471334951464, 0.05395834035880398, 0.014913011345925042, 0.02149799584003631, 0.04449950123671442, 0.021735483096563257, 0.017994307381741237, 0.02946011420135619, 0.038392382848542184, 0.03565880062524229, 0.02815099167492008, 0.030003898791619577, 0.11233667479245923, 0.05197152197069954, 0.036575497724697925, 0.02182165757403709, 0.032145937366294675, 0.04041380016133189, 0.020245202322257683, 0.05738045379985124, 0.04542505586869083, 0.04398119272082113, 0.015332018647313816, 0.017678814838291146, 0.02952209466457134, 0.05029072446632199, 0.02517866054404294, 0.02609165803733049, 0.02504335032426752, 0.12998683901969343, 0.0732893985696137, 0.021415660121419933, 0.026357695714978036, 0.04899725754512474, 0.09369644103571773, 0.034784903182298876, 0.05931346648139879, 0.04006550654594321, 0.005270721667329781, 0.03227171655453276, 0.07772937868139707, 0.017519533248560037, 0.029691950003325474, 0.029062666289974004, 0.018906091463577468, 0.03601568088924978, 0.04339685161539819, 0.06984213745454326, 0.07535370459663682, 0.030927353145671077, 0.006043656876499881, 0.008368315266125137, 0.0918704757350497, 0.05617781833279878, 0.026053005130961537, 0.07786598580423743, 0.017156884641735815, 0.04094790529052261, 0.021090784975967836, 0.027662810643960256, 0.05425724033557344, 0.028861707542091608, 0.02242878261313308, 0.041673933519632556, 0.06325940630631521, 0.022574865106435027, 0.02868313567887526, 0.06464581238105893, 0.01946989734278759, 0.06090130998927634, 0.03968125216488261, 0.014685589467262616, 0.13235483929747716, 0.07914879548479803, 0.0680051364179235, 0.030813639423286077, 0.018630014383234084, 0.033020332048181444, 0.015725322591606528, 0.03488078866212163, 0.0627800976508297, 0.029507331491913646, 0.01875698842923157, 0.045399904483929276, 0.042458884563529864, 0.022838117874925956, 0.03643616320914589, 0.002116607029165607, 0.07374130713287741, 0.03293440990091767, 0.05818397708935663, 0.020122003952565137, 0.06938747552339919, 0.04136308496526908, 0.04585932729241904, 0.06271895210375078, 0.04614263103576377, 0.08205609221477062, 0.1048522861674428, 0.019899816070392262, 0.019589930452639237, 0.04993826740246732, 0.04934313918056432, 0.0728233001427725, 0.04325718313339166, 0.02563715937867528, 0.046547628444386646, 0.030660885022371076, 0.01915604865644127, 0.015726849560451228, 0.08005372583284043, 0.02863218353013508, 0.04743452089314815, 0.029394591838354245, 0.025869125056487974, 0.0743093024357222, 0.036593134864233434, 0.06991242626099847, 0.030152126091707032, 0.035434278688626364, 0.02749792955000885, 0.018106972820532974, 0.04057772574014962, 0.01346829751128098, 0.014165316115395399, 0.12835203611757606, 0.17089740314986557, 0.14033901243237779, 0.1895366350072436, 0.15084296988788992, 0.07185300884884782, 0.10929493058938533, 0.13432328210910782, 0.15212761267321184, 0.13205464056227356, 0.060797067926614545, 0.12225442464114167, 0.1394030751544051, 0.16380622662836686, 0.13112664426444098, 0.1106682229146827, 0.1733938543475233, 0.1484716744744219, 0.1357186384848319, 0.2943947841413319, 0.08542485637008213, 0.12060203283908777, 0.14834349072771147, 0.13315938675077632, 0.14254802983487025, 0.08607498515630141, 0.1794283461640589, 0.12937729828990996, 0.16568360792007297, 0.0898994502495043, 0.16136414516950026, 0.10966942572849803, 0.12816016125725582, 0.10495768598048016, 0.18108566582668573, 0.14658365078503266, 0.13730245584156364, 0.18892127583967522, 0.1522048405604437, 0.1589737765607424, 0.1011805550660938, 0.1291137616499327, 0.13966778438771144, 0.14401492924662307, 0.2780155255459249, 0.11536363541381434, 0.19710063381353393, 0.15603510924847797, 0.07663097785552964, 0.14929244527593255, 0.19519159250194207, 0.10127644796739332, 0.18014946137554944, 0.14365531416842714, 0.22725522198015824, 0.1327861161553301, 0.16900465940125287, 0.12558870861539617, 0.13957020681118593, 0.08381475214264356, 0.10422230669064447, 0.09202239336445928, 0.14184312312863767, 0.25487827020697296, 0.17701707867672667, 0.07911726905149408, 0.16255630151135847, 0.11055451104766689, 0.12568451988045126, 0.15310757415136322, 0.11492152319988236, 0.12101212138077244, 0.1445723563665524, 0.0669129918969702, 0.19151074782712385, 0.16147748596267775, 0.22796907898737118, 0.11294510230072774, 0.11747895667213015, 0.24929064034949988, 0.2156697030295618, 0.10033927130280063, 0.10705424574553035, 0.07698192464886233, 0.1787179327220656, 0.1897942047799006, 0.10324607821530662, 0.19366555876331404, 0.0988776634039823, 0.12894945015432313, 0.05532743212825153, 0.17948293854715303, 0.10920859655016102, 0.11260609666351229, 0.15536920982412994, 0.12677822291152552, 0.10973817828926258, 0.12192669222713448, 0.129874418489635, 0.18863376782974228, 0.10850810562260449, 0.13239173887996003, 0.22100182628491893, 0.21315658319508657, 0.2702841872815043, 0.10689183414797299, 0.12032498168991879, 0.0925112831464503, 0.09448516590055078, 0.1009783791960217, 0.12712381139863282, 0.1500764352385886, 0.09578414697898552, 0.17205353564349934, 0.23098396486602724, 0.13142903975676745, 0.11970540712354705, 0.10554000473348424, 0.12977802834939212, 0.13798092724755406, 0.11792437886469997, 0.17251721466891468, 0.1349152933107689, 0.20776649820618331, 0.21124031336512417, 0.18516583048040047, 0.1430244738003239, 0.11758339169318788, 0.1209233605186455, 0.12849031307268888, 0.20147387258475646, 0.18758603342575952, 0.13243226014310494, 0.09589066001353785, 0.1220547646516934, 0.20130295597482473, 0.2193856512894854, 0.12326428724918514, 0.07511429517762735, 0.1359090142068453, 0.16038440633565187, 0.16683784051565453, 0.13545645255362615, 0.14884973934385926, 0.09785311369341798, 0.20300093048717827, 0.09281521488446742, 0.13947273313533515, 0.2689773542806506, 0.2721684705466032, 0.07916792805190198, 0.09789797652047127, 0.13620247424114496, 0.14667253039078787, 0.12654481746722013, 0.14980143983848393, 0.11767175179556943, 0.18205540050985292, 0.18761943007120863, 0.17116905888542533, 0.12651670491322875, 0.16659376298775896, 0.13965608814032748, 0.15952066518366337, 0.1343813180574216, 0.12533055996755138, 0.19718123105121776, 0.19585764035582542, 0.1056862152472604, 0.11536828867974691, 0.21912643394898623, 0.05854793002072256, 0.15732715866761282, 0.2063071241718717, 0.1126342908537481, 0.11694368266034871], [0.04192542139207944, 0.013423194413917372, 0.009170016583084362, 0.019285995003883727, 0.022748998926545028, 0.022354553002514876, 0.020947166412952356, 0.022439597560151014, 0.01603141954547027, 0.0455712441180367, 0.04222087409289088, 0.024563403421780095, 0.040307869712705724, 0.028909164175274782, 0.019252084421168547, 0.0648749282117933, 0.015489989418711048, 0.06120012090832461, 0.019160520096193068, 0.02547126896388363, 0.0033605694534344366, 0.0747197397868149, 0.021242138573143166, 0.04463843128178269, 0.05466515438456554, 0.021127289364812896, 0.022669149402645417, 0.018829592736437917, 0.04128630978811998, 0.04458861090824939, 0.03832498470728751, 0.10332418183679692, 0.04491173829592299, 0.03759888597414829, 0.029592873288493138, 0.017238268555956893, 0.03403842878469732, 0.042941269421135075, 0.033264090452576056, 0.06491682986961678, 0.04313027959142346, 0.020578725343511906, 0.019538978303899057, 0.07161415604059584, 0.07625620070029981, 0.054325718301697634, 0.03238684592361096, 0.02624760181788588, 0.005046205296821427, 0.06028393218002748, 0.06803212090744637, 0.012197039359307382, 0.08492827051668428, 0.09267544621252455, 0.10918359359493479, 0.03128661941445898, 0.03843034370220266, 0.03379061454324983, 0.03549978806404397, 0.06376906138029881, 0.02501272931112908, 0.008807809554127743, 0.07688186087762006, 0.07283770522917621, 0.01422101522621233, 0.027079232095275074, 0.07113210886018351, 0.015380826916953083, 0.044576276413863525, 0.023977867458597757, 0.1329627918312326, 0.03178355036652647, 0.025424955238122493, 0.020078322995686904, 0.014020680810062913, 0.04761692965985276, 0.03191294010321144, 0.055462644013459794, 0.021317557475413196, 0.02638543905050028, 0.04696451134805102, 0.05409735575085506, 0.008732673595659435, 0.029893396713305265, 0.03677674219943583, 0.016791002126410604, 0.05600869772024453, 0.032822813154780306, 0.09336845629150048, 0.019195859313185792, 0.028222388136782683, 0.03645470576884691, 0.03836465250060428, 0.07879036042140797, 0.0063832673640717985, 0.017981948767555878, 0.022155249243951403, 0.03827080421615392, 0.029583802388515323, 0.014519930045935325, 0.04604043730068952, 0.040612287557451054, 0.059872856581932865, 0.029287709585332777, 0.013828892224410083, 0.07939348157378845, 0.06982076360145584, 0.09961949195712805, 0.05532880881219171, 0.007293825974556967, 0.04056964746268932, 0.06008698845107574, 0.01650224545301171, 0.016131962001963984, 0.13834598968969658, 0.04306587972678244, 0.059230249462416396, 0.03358813439263031, 0.05096015280287247, 0.030314212999655865, 0.048910426266957074, 0.014637225558544742, 0.03406886797165498, 0.008851915390550857, 0.04130039204028435, 0.04041494306875393, 0.06967221532249823, 0.039274685113923624, 0.044216041642357595, 0.022336967813316733, 0.043671735693351366, 0.08915139507735148, 0.020966618103557266, 0.14187361055519432, 0.022982975824561436, 0.02719674004765693, 0.046641602893942036, 0.02703885555092711, 0.05625761405099183, 0.015053190054459265, 0.012777063948306022, 0.00804835128292325, 0.04530637161224149, 0.03278585048974492, 0.09563566549331881, 0.033340461159241386, 0.024851993111951742, 0.052971970435464755, 0.02891117168474011, 0.027639468244160526, 0.046826145335217007, 0.02328479244170012, 0.0908999024250079, 0.039766283734934404, 0.05726889045035932, 0.01963578033610247, 0.1137054325954523, 0.049933536211028695, 0.030697079564561136, 0.021613561220874544, 0.05419457709649578, 0.03246742831834126, 0.026535571814747527, 0.06800065384595655, 0.026299854580429383, 0.015096758761501405, 0.022083806397859007, 0.029852086918253917, 0.03917659916623961, 0.017226832060259767, 0.0206242301283055, 0.05462931236252189, 0.035979078165837564, 0.03040995004994329, 0.05680278831277974, 0.05518898818991147, 0.06285956682404503, 0.016328417768818326, 0.03371783212060109, 0.00900485068996204, 0.048089692572830245, 0.021106678068463225, 0.04473505148780532, 0.07498808554373682, 0.04117053475056309, 0.030841293701087125, 0.03981388137617614, 0.050758711659000255, 0.01875716097856639, 0.045785602342220955, 0.01975606948690256, 0.0395458287675865, 0.051780110952677205, 0.01687799667706713, 0.01555346994791762, 0.0351571125065675, 0.06939174287253991, 0.03328659979160875, 0.034737999449134804, 0.0552182622050168, 0.037433105026138946, 0.036171331521472894, 0.028496945669758134, 0.03109430483164033, 0.10029535100329667, 0.06234118409338407, 0.060803068190580234, 0.006265885112952674, 0.016785666084615514, 0.030067322732065804, 0.021134898233867716, 0.029967481605126522, 0.012314487939875107, 0.05397036686190404, 0.04879920059465803, 0.07377410263870843, 0.11143537354655564, 0.03282534016761929, 0.04865136477747001, 0.060404219475458376, 0.05155607883352786, 0.020124000329815317, 0.009191126046061981, 0.004538169960142113, 0.003399381921553868, 0.031400231091538444, 0.08827356054098345, 0.026782024215208367, 0.03531147551257163, 0.0361784561391687, 0.026654827524907887, 0.017464195007050876, 0.030887175125826616, 0.009386787714902312, 0.01869901556347031, 0.03485966342850588, 0.020052926702192053, 0.07866469255532138, 0.0530229967989726, 0.00518503376042645, 0.01994508707866771, 0.057242236216552556, 0.027197088857064955, 0.01188893489597831, 0.02669110555871157, 0.008429676036030287, 0.04697082702477928, 0.04055211422382854, 0.03525939158862457, 0.05377937886805739, 0.0285335595253855, 0.08423897117609158, 0.0531921508081723, 0.055139739270089194, 0.041464740643277764, 0.02807379718433367, 0.058141611589235254, 0.029163088147470262, 0.030552527750842273, 0.06027455885487143, 0.019652497212518938, 0.01406260380463209, 0.011833681073767366, 0.043420540969236754, 0.038967688306001946, 0.05183194996789098, 0.06018597981892526, 0.07287827102118172, 0.03898814560670871, 0.06728035499691032, 0.028798463572456967, 0.018521831516409293, 0.03709400290972553, 0.037088188182679005, 0.07447353971656412, 0.026359126204624772, 0.0330796556227142, 0.015947291540214792, 0.02125859013176523, 0.0516391103155911, 0.04815442269318737, 0.02989219628943829, 0.03519353340379894, 0.06387357803760096, 0.09516203426755965, 0.011025832918676315, 0.054033787091611885, 0.15617396507877856, 0.010843203363037901, 0.027743033097067382, 0.001641400131120463, 0.012516638762463117, 0.07269377310876735, 0.024606943370599765, 0.03350771155965049, 0.03018564333615359, 0.0077389253328874474, 0.07125941687263548, 0.029813205801474396, 0.013904419665777823, 0.04884650137682911, 0.035458242637105286, 0.03234393123420887, 0.04919055361824576, 0.02703251018829178, 0.049422107404097915, 0.019177912326995283, 0.026671590785554145, 0.061717561111436225, 0.08660533872898668, 0.04095682219485752, 0.03881575212290045, 0.04584731563227251, 0.03855328046483919, 0.05078755893919151, 0.011041501511499519, 0.019232174454373308, 0.03488566086161882, 0.029102944499754813, 0.057510838014422916, 0.037819055214640684, 0.05604685524303932, 0.05392168939579278, 0.029763572820229456, 0.06448745290981606, 0.03735156155016739, 0.013065034872852266, 0.03754502460651565, 0.03931491322873626, 0.04585839960782323, 0.06325681621092372, 0.006874848822917556, 0.017802317488531116, 0.043457344072521664, 0.033370766759617254, 0.011859865899168653, 0.032542815679335035, 0.03560103927156888, 0.03431401419220492, 0.02134523030690616, 0.01245104775080108, 0.034558997140266, 0.04022086774057243, 0.059569793156697415, 0.02571239831013372, 0.04101909580640495, 0.080975525197573, 0.020990255507058464, 0.019229246681788936, 0.09923217992763966, 0.02883314784412505, 0.02172671833250206, 0.13786604278720915, 0.10157369295484386, 0.14655213919468224, 0.05535350748687051, 0.21362376515753567, 0.10137541336007416, 0.13397159316809848, 0.13607948552817106, 0.13811467710183933, 0.12075383172486909, 0.13724244578043, 0.206972251762636, 0.15906117187114432, 0.17167270998470485, 0.16727983398595825, 0.11230421325308271, 0.08889630407793447, 0.17042594641679898, 0.2231255263905041, 0.15327627916121855, 0.18374000152107328, 0.09887878404697403, 0.21119645243743435, 0.10151134512852877, 0.10545450189965777, 0.08775228343438357, 0.11812024647952057, 0.1348554019932635, 0.25344022549688816, 0.0924466123979073, 0.16114056576043367, 0.23083051841240376, 0.16681536828400567, 0.08734993549296632, 0.0847152667120099, 0.14014804299222305, 0.14797161536989734, 0.1336546812672168, 0.12493609363446012, 0.1238534263393376, 0.18414876161841676, 0.0793818298552651, 0.15311548544559628, 0.17314045544480905, 0.1284778449917212, 0.16169435635674745, 0.10360304382629693, 0.07605459628393874, 0.1344271530979313, 0.11797249972005375, 0.1583068529726006, 0.12712485040538013, 0.13879837322747335, 0.22158298728754744, 0.15691841341322288, 0.09477867788518779, 0.0684560282388702, 0.0796977398567833, 0.18776667217025533, 0.1233787635283079, 0.1301501115085557, 0.15531633922364563, 0.15492172446101904, 0.18480266793631017, 0.15682187484344468, 0.15863642591284588, 0.1785918715177104, 0.08594956962042488, 0.09865750529570505, 0.14281177427619696, 0.2281372348079458, 0.11238836537813768, 0.12701812956947833, 0.15008706279331818, 0.1272948319092393, 0.17490268510300666, 0.1724126163753681, 0.12446666296455078, 0.10523817327339202, 0.16063937859144062, 0.1346362309413962, 0.1442666954244487, 0.10387662914581597, 0.14364302420290187, 0.0992406923614908, 0.1774698481312953, 0.10678871272830293, 0.07043328034342267, 0.18872015381930396, 0.2020368361263536, 0.1118928259529639, 0.12691602489212528, 0.11920988996280357, 0.22885199723532423, 0.08504425335559063, 0.13664428959600627, 0.18300350900972262, 0.16117648570798337, 0.13182231865357608, 0.16053978237323463, 0.0924814042809885, 0.19797483924776316, 0.19828645221423358, 0.10046844952739775, 0.1135302337934263, 0.1329635488218628, 0.16921626054681838, 0.1738782541360706, 0.28157572669442743, 0.10885363473789766, 0.12492096866481006, 0.3360187303042039, 0.12983878055820242, 0.07345654506934807, 0.22042206051992252, 0.08481274038786069, 0.18310263025341555, 0.10698946367483586, 0.15632530383300036, 0.1769055932527408, 0.13189126417273656, 0.0864064579945989, 0.13361107266973704, 0.07613665555254556, 0.18341390183195472, 0.17029734706738964, 0.1298001888790168, 0.16362126858439296, 0.15732099884189665, 0.08182437144569121, 0.12150962007581256, 0.13591144845122471, 0.15063227416248992, 0.2236081747105345, 0.12519958574557677, 0.16326883749570698, 0.1297267756308429, 0.1637565324199386, 0.14147809037240222, 0.12745917309075594, 0.09573367351549678, 0.10904072274570353, 0.13946277351351455, 0.15157346584601328, 0.1637996660429053, 0.09691920247860253, 0.11697001405991614, 0.09931669570505619, 0.18181628052843735, 0.18779138568788767, 0.16881127055967227, 0.11283486368483864, 0.16050775127951056, 0.12213132460601628, 0.0993983838998247, 0.0910511075926479, 0.12972733966307715, 0.12912329082610086, 0.06376773293595761, 0.05623916797048878, 0.09374937100801617, 0.10041658082627691, 0.10765888830064796, 0.14288518752437085, 0.08323825182742439, 0.12579296249896288, 0.22714342485414818, 0.2330630025244318, 0.08362681066500954, 0.10978270714986138, 0.1942074007820338, 0.10506688558962196, 0.056606122889206745, 0.16730377567000687, 0.09372158499900252, 0.1402478470117785], [0.04337346654210705, 0.059081029539811425, 0.041871871726471, 0.08922845969209448, 0.049192694714292884, 0.02155585738364607, 0.011993916323262965, 0.03412947917240672, 0.07011288034846075, 0.052190837741363794, 0.018283180943399202, 0.01739254621497821, 0.0560710715217283, 0.04122611790080555, 0.026441879381309263, 0.06844879972049966, 0.02663877487066202, 0.02297354869369883, 0.0067794281130773015, 0.010850371581909712, 0.019055858720093966, 0.04732544002763461, 0.0132070698782627, 0.07278503500856459, 0.03691431040351745, 0.041514293843647465, 0.03708322321472224, 0.0534896926546935, 0.020160959284112323, 0.09811209354666062, 0.01969528202607762, 0.07057567621814087, 0.04049175535328686, 0.07111138067557476, 0.04652001312933862, 0.0651714087871369, 0.03586009705031756, 0.06098961071984377, 0.08927646180381998, 0.010774855272757122, 0.043333075154805556, 0.05164194531971589, 0.0028951512513231137, 0.059650386683642864, 0.047918497657519765, 0.016110673495859373, 0.06505517361802049, 0.0376851977489423, 0.07058617018628865, 0.04374132688099053, 0.07990758953383192, 0.02648647132446058, 0.03243688523070887, 0.013734964159084484, 0.02260993900563335, 0.02291347369464347, 0.01601785494131036, 0.028439657435228582, 0.013277919933898374, 0.0301755928012426, 0.04248131226631813, 0.05980196663585957, 0.018397508792986628, 0.027409241047280375, 0.02853513287845999, 0.0429161885404028, 0.050296951085329056, 0.022256517149799038, 0.0363639670831617, 0.014564877292286837, 0.02546268231526483, 0.007598907577630598, 0.024904796919145156, 0.017987765349971596, 0.03439780637563672, 0.0396221178380074, 0.05991796431771945, 0.10282332863425836, 0.04651894072594587, 0.017790142555895727, 0.03950273596274201, 0.028329413253231905, 0.08897811843780801, 0.021371333496063016, 0.030342182690219488, 0.04337525511800777, 0.012019981477351394, 0.006269516070460668, 0.027361402208043728, 0.02592536315205507, 0.009601196034054738, 0.058658665875555016, 0.0193301323815831, 0.0891731696901843, 0.008327606610691873, 0.01544078317238018, 0.01644002193643246, 0.037489734604605474, 0.007264864589160425, 0.06343554763589054, 0.04690944399044383, 0.025138408309430815, 0.0320260656735627, 0.028217567887622863, 0.036132773238932714, 0.03609254512412008, 0.0549226462317165, 0.061531471292255446, 0.09124889736995101, 0.013665974111063406, 0.03594751833588816, 0.07801411105901934, 0.04801220122317318, 0.025377630336151924, 0.041106847347691655, 0.024386128461628687, 0.011785003607656108, 0.04252994891430717, 0.011191143530595582, 0.039969851131900214, 0.03317865441204049, 0.024899273485061713, 0.06195805035531521, 0.026147712451347616, 0.05470683339808602, 0.027543367541511543, 0.05811872746562585, 0.07380664581432939, 0.033760657752281986, 0.029533015367633197, 0.035092579055344686, 0.09817150246817619, 0.015730140985397156, 0.07056673333863728, 0.040890470481826924, 0.07161030429415405, 0.01848465919465525, 0.004080711059941677, 0.0774924925644882, 0.06576297470019199, 0.06273515318753198, 0.057457084258203395, 0.016279723604384344, 0.06980952006415464, 0.012271637260710122, 0.023001971094345208, 0.03745670532225631, 0.025449043496337254, 0.05298837189911865, 0.028730217527481727, 0.004846012816415168, 0.031025240568851586, 0.09580374709912576, 0.03221540238882881, 0.023037447608658113, 0.01593625023815548, 0.014041141821508063, 0.02400342887995066, 0.02614250628539594, 0.06433589151129127, 0.056904759403551, 0.05246429318503942, 0.025941117091861088, 0.04370407848909963, 0.02572561781562399, 0.027620840337476693, 0.0648253972758539, 0.0775719023658894, 0.059795613851747476, 0.010495890310266986, 0.028739440567733254, 0.02666636235517217, 0.011701561161316931, 0.009116667297348613, 0.08363518209080212, 0.0556465148110874, 0.03251644717238378, 0.08104965090751648, 0.09386783262016252, 0.04416942363604903, 0.07299464719835669, 0.013610129353764933, 0.03995505270722788, 0.04165713500697166, 0.013111823573126458, 0.006854304783701082, 0.02141756001947215, 0.03412823236430995, 0.08283890958409756, 0.04750994165078737, 0.0022646847401119885, 0.03371228085597977, 0.042209964522044174, 0.04138371667067986, 0.03700874498463236, 0.05074400229204912, 0.04963380873959977, 0.021729939253418706, 0.08518953618477099, 0.06880120854475535, 0.03154922465910204, 0.046796214519417845, 0.04488979669986293, 0.025454377682763152, 0.047368566229124554, 0.091905994922854, 0.04515944863669574, 0.045175642299000174, 0.043921698452322744, 0.013310829544934677, 0.06248674893868156, 0.0340496537683066, 0.05657870053255465, 0.039963335075299256, 0.04852413469052408, 0.014298835903900908, 0.047252742951968685, 0.06066544803616125, 0.012050448494846933, 0.07021059151156805, 0.06776781243388541, 0.054485049986396916, 0.1109224530227948, 0.03595455389586277, 0.07976738299475983, 0.05765524139860645, 0.06902106237248518, 0.0305605336689041, 0.014175928827171447, 0.012839607516070828, 0.025170229746436235, 0.04846490017371252, 0.02230560094176326, 0.037692352052545175, 0.031916721345623955, 0.023858483727963176, 0.07149964265408926, 0.0363005134568084, 0.033533412133692764, 0.02234171384770889, 0.027884558803634718, 0.0256236541463295, 0.016858791750564706, 0.033740894359652884, 0.013555032310250681, 0.02412772006209707, 0.033330431033391505, 0.03871481261739973, 0.07907896680990234, 0.016979077190626413, 0.019408527296036482, 0.011776636820286512, 0.03449454532528762, 0.06609097428736277, 0.05722623551264405, 0.01744029414112447, 0.03701332403579727, 0.023839065434003714, 0.022169941912579816, 0.003013759669556748, 0.0775931500538718, 0.013825455152982613, 0.027034469458158128, 0.035416875325609, 0.021171562184463255, 0.005849277267770958, 0.06176716626214329, 0.04632954463886563, 0.06162812489492353, 0.06960134764085524, 0.04616816091584042, 0.037901578325545415, 0.025939304396160878, 0.06073301687138155, 0.02043787684669951, 0.09897348951199092, 0.08161837351508439, 0.019735061141545884, 0.029757986303593498, 0.02973695383843733, 0.03991327350377105, 0.011675511777866632, 0.04504955511947628, 0.007974934324010974, 0.05513005795364734, 0.04267302014341112, 0.07132805811124854, 0.016179416779777966, 0.062192290715756826, 0.042537919580354355, 0.019257142157584894, 0.06805356897530146, 0.02576681443315465, 0.01075459185813088, 0.03465342801064253, 0.07490406700526364, 0.031367836345452815, 0.02045652516244445, 0.01535485360363964, 0.028618168071261607, 0.027606566982285585, 0.05412327896920033, 0.02003302601224277, 0.059162380057387054, 0.037241560421534814, 0.04609211304341443, 0.0737319709151052, 0.042538813868304715, 0.04269508419383783, 0.03992992358689662, 0.026251110321027227, 0.036345075714052655, 0.024521394152543508, 0.042428452798048966, 0.025907972776622046, 0.07677777466597036, 0.04238363449985627, 0.048681303014745936, 0.057123577935271896, 0.0006714421658671199, 0.07744545524474233, 0.029802316639688797, 0.0863764010136947, 0.05499229308043141, 0.11060938544687815, 0.04822045157197863, 0.03431633711443283, 0.04701258396380581, 0.0612541900773067, 0.03534393334120978, 0.03391963320609648, 0.07352195796556771, 0.028006987195112742, 0.05947411176748574, 0.054145699250511825, 0.06701801321469247, 0.025973625015467405, 0.07662889242055826, 0.05597980591119267, 0.03762967768125236, 0.015615477313986048, 0.014437857789744157, 0.043070395695394836, 0.12688987160800025, 0.02507076340407366, 0.019348467139934655, 0.03292662848252803, 0.04044681460072752, 0.034446654535713606, 0.029667243907169905, 0.010258801030431641, 0.026920111922663637, 0.1811313079087995, 0.3113992576254532, 0.14241589786252007, 0.1411914432537742, 0.11346805666107684, 0.10213703499175608, 0.1392672027577646, 0.1677066134288907, 0.09858002507826313, 0.12631199089810252, 0.0742770338547416, 0.0882063813332934, 0.13022033352172002, 0.1084070473734755, 0.06494175118859857, 0.1639848022023216, 0.16570351232076064, 0.17150289175333455, 0.07513710137573071, 0.13851303228875622, 0.14020031987456605, 0.15762274124426767, 0.18249163491418585, 0.15800735185621306, 0.14581374678527936, 0.13325291220098734, 0.22401965106837451, 0.13153912994312122, 0.11852896946948022, 0.19440960633801296, 0.10526235244469717, 0.15617099648807198, 0.10180499812122434, 0.12511849869042635, 0.19513281440595165, 0.16027208970626816, 0.1778683962766081, 0.12784599530277774, 0.22356941975886002, 0.15485160634852946, 0.13875771837774664, 0.17687446757918224, 0.057801414804998785, 0.19028638227609918, 0.20348850666778162, 0.10707978304708377, 0.11548677255632356, 0.15287670685211197, 0.14971763652283698, 0.2350345771992579, 0.1263557479251176, 0.19233031634939834, 0.13119477342115715, 0.09896516261505894, 0.15159445378230885, 0.09378976610605605, 0.08350161035195924, 0.07604321916005574, 0.11383179065887816, 0.09101269402890466, 0.17422226927010342, 0.15565633191727102, 0.14442319952649996, 0.10240596704534255, 0.08707055400009267, 0.12443962652469054, 0.12866652861703187, 0.1192162353254389, 0.1989887168747373, 0.1274256280157715, 0.19443331053480506, 0.12460620899219066, 0.14707769849337637, 0.04924298635160085, 0.1161681606026832, 0.23552763042971492, 0.1320658321492374, 0.20962197129847482, 0.20888506318442523, 0.07772632103296928, 0.12306167351198383, 0.17639918136410415, 0.25131907837931067, 0.10808704813825898, 0.2219575343769975, 0.17656815354712307, 0.1121472119120881, 0.16314798616804183, 0.08237335292506032, 0.1567801513010636, 0.1678224329953082, 0.10349368094466627, 0.09572298658895306, 0.2015379793010652, 0.10319531531422399, 0.1872770773479715, 0.14615388790844008, 0.13295786397065967, 0.06761418044334278, 0.16081814712379128, 0.11107399215688929, 0.10120963241206482, 0.22989140474237502, 0.16867444821400568, 0.11106734251370654, 0.1453644802677445, 0.11022779537597671, 0.1315757178235799, 0.17153645167127252, 0.11595287098316476, 0.12791942339390516, 0.21340797829907387, 0.1450975297484547, 0.08918347812141292, 0.18599693197757006, 0.149077445094008, 0.1070932752918452, 0.13951729168184102, 0.13639929180499166, 0.17729553248500451, 0.10036972162197344, 0.12072519966750406, 0.14279713912401348, 0.07920128758996725, 0.15814102749573067, 0.10736579934018664, 0.1309730642242357, 0.23548556549940258, 0.11279825353994966, 0.09205504044075496, 0.1779134149546735, 0.23689373134402558, 0.2561612951103598, 0.14384331501787528, 0.1251206360757351, 0.2302634879015386, 0.17139076808234677, 0.10638183026458137, 0.15640118101146072, 0.2224476041737944, 0.3235104843042791, 0.1904204735183157, 0.0934132894326467, 0.11181406924151815, 0.13650129258167, 0.22076769353589043, 0.12775655166478828, 0.16865190176758915, 0.18287146609509364, 0.15665266517316923, 0.08148919529048726, 0.11918559946934693, 0.18702296598348767, 0.08215146561269648, 0.14384726324351504, 0.13406170473899692, 0.1409837754908949, 0.14687006041640416, 0.12170120549853891, 0.16691855649696663, 0.18975945742568, 0.19639014615677297, 0.15310082060750574, 0.1314056769479066, 0.1601525890873745, 0.07791483396431431, 0.20241067075403407, 0.20815726864384487, 0.16000577743398026, 0.049065097264247015, 0.1129206782206893, 0.07549383692094125, 0.1810923748416826, 0.12967893679160625, 0.14440060855122283, 0.20344184042187408], [0.07067073791404255, 0.042863889393629506, 0.011559113336261362, 0.013165253567422042, 0.025558753332006745, 0.030978533504821826, 0.08093138225376606, 0.0626982090761885, 0.027504740610311273, 0.02019359151745448, 0.031164484171313234, 0.03660296089947224, 0.05644615666824393, 0.032094376656459644, 0.017367444925184827, 0.04053958306030836, 0.054360673457267694, 0.029803281431668438, 0.009404176234966144, 0.04257251108356286, 0.05850653302331921, 0.042306291579734534, 0.01678065658779815, 0.08295093677588739, 0.031835014597163536, 0.03278157200838905, 0.08933610821259208, 0.03965432333643548, 0.03737522492883727, 0.009489388703514123, 0.03631890387623571, 0.03228524590667803, 0.020453682736842893, 0.09699001820990816, 0.03707835843670182, 0.023597904546477366, 0.03589350111724343, 0.020715959581139032, 0.038442830336862244, 0.029010259531787597, 0.043279655365040526, 0.03092954990279395, 0.03451719938311726, 0.033089544740505517, 0.03139407497656066, 0.03081655977439368, 0.044260314462007955, 0.043847817651112564, 0.029583494397229515, 0.01114130274800118, 0.023159068914537784, 0.021525418196688406, 0.028509693911473732, 0.045646104554180056, 0.0378512310271617, 0.05066546451416798, 0.01998282899876358, 0.020644535288738552, 0.02354738098802045, 0.010193358448304934, 0.06519057846162468, 0.011137828569189878, 0.057909434399334714, 0.07087330712238327, 0.02521693124435842, 0.004919813836750109, 0.020885531048406847, 0.06912587588885799, 0.034161480580223724, 0.055274316619033925, 0.01815334220736986, 0.04566607574815862, 0.049243420507991686, 0.04238262146827765, 0.052274303379817866, 0.0239074561977759, 0.023746330371068325, 0.07239072452648543, 0.06018696316459682, 0.04020836255222093, 0.02958116961963242, 0.027868007055076305, 0.010531918796914397, 0.057873573823599145, 0.07395403634291142, 0.09947700702468865, 0.07802589636412449, 0.00968319222010905, 0.01401609804815962, 0.02741196472925367, 0.03849913708108943, 0.04103403894987423, 0.09496811107965186, 0.06154275935841724, 0.07560863974504173, 0.027403021849750075, 0.015825247210159432, 0.02043567452346906, 0.0668644331744872, 0.018332325962546747, 0.024579220444138627, 0.053049328198540024, 0.01205206266604364, 0.05290358894853853, 0.06419175901100971, 0.05682258139131591, 0.021427265455713496, 0.061617100291186944, 0.03478158207144588, 0.07789276249241084, 0.00873387216415722, 0.056734766767476685, 0.015087125684658531, 0.03528013461618684, 0.09999391288147308, 0.024714285755180754, 0.04235278342093807, 0.05022267694585025, 0.005610252374026459, 0.04134096154302824, 0.09602478094166145, 0.055480834053014405, 0.0182110312016448, 0.02062652707536472, 0.025539385133015458, 0.05122875089000445, 0.02869778938475065, 0.021604349312838167, 0.05353588021534961, 0.024322543104062788, 0.010402254465589067, 0.046954718709457666, 0.03626808160333894, 0.037574818124994636, 0.011372113458492095, 0.00865149933815701, 0.06403843872249126, 0.013425856868707342, 0.037408246789709665, 0.03372084524016827, 0.04896472550171893, 0.0442437942547258, 0.01497545936217648, 0.047940253716660663, 0.02983275211590808, 0.046914357008063234, 0.00558476284822973, 0.05743470479501411, 0.02909603139414685, 0.03392296173842624, 0.0737129793560598, 0.07572164657176472, 0.054971308854874223, 0.01955036470462801, 0.031059021275723353, 0.019567411836760584, 0.03162224827974569, 0.015203670700429939, 0.031487125452258624, 0.011879516114277067, 0.02474680295563303, 0.021416372583189514, 0.048434000855195336, 0.07098521557054482, 0.027204890684515703, 0.04224438904202543, 0.040233758845715784, 0.010174451308557764, 0.026880564728344325, 0.03960822483350057, 0.07087996418704279, 0.024433672297163866, 0.04912845070066396, 0.0641216483199969, 0.07728314012638293, 0.017837491577665787, 0.047011522692628205, 0.058571415283950046, 0.019469364851829596, 0.0059377820889494615, 0.02765055964118801, 0.013910894904256565, 0.04477172471524682, 0.0614427549589891, 0.03060906641621841, 0.026939355811919086, 0.06818596812081523, 0.03225561937142629, 0.07022982797934674, 0.03765262488741428, 0.030578996447729878, 0.012319198722252622, 0.013091567579976982, 0.07411671511363238, 0.02959598474262748, 0.02231353264505742, 0.03326858044601977, 0.060104551375843585, 0.05563570171943866, 0.030870875707478262, 0.004512044970397255, 0.023528508172603324, 0.013048321707174182, 0.030301661427074578, 0.0439586685388349, 0.012191908335807966, 0.04109264635189902, 0.07454949853126891, 0.03822635699179955, 0.07122171577066183, 0.06025002345268149, 0.01581179578352021, 0.01852462755778106, 0.010346518247388303, 0.09637369425036013, 0.0452161375869764, 0.07420493420795538, 0.02693908492801711, 0.03625150573498104, 0.020794330375792924, 0.01871234824648127, 0.019619627491920255, 0.01259268106878153, 0.01328929891315056, 0.010219148080068408, 0.04149393302213866, 0.05309049513016362, 0.03570721462892834, 0.01929907906742301, 0.0382765632821247, 0.03550637833541259, 0.06444670158089139, 0.012665713966271142, 0.06948314578039572, 0.04515913322393317, 0.025175213268084917, 0.05913880202569999, 0.06007378935464658, 0.04287760799343232, 0.017974094989767764, 0.009478523661528016, 0.06893998273881152, 0.018862664692278486, 0.03815869538811967, 0.020996945968363434, 0.06205305639014114, 0.01936907101480756, 0.011434768348408397, 0.03198147373041138, 0.09441399393836036, 0.07717783679254353, 0.06118493285612203, 0.025609627555240877, 0.007919327053969027, 0.06222734977200162, 0.019959570090577472, 0.04045234731165692, 0.014641784200648544, 0.022009706663084216, 0.056842949634301476, 0.015575241777696647, 0.03139456108328886, 0.04836426865949761, 0.07911854554549791, 0.011169194513058756, 0.018453091943229083, 0.04917550286336336, 0.014175613414408872, 0.012110597708669957, 0.013414913901215186, 0.08739764074562117, 0.03143644418742042, 0.0626451603602618, 0.04279328146367334, 0.03792352363234386, 0.034134306843043305, 0.04483763113967143, 0.032683519457350485, 0.054291750202537514, 0.02313302509719506, 0.10745123538072221, 0.026918353032669984, 0.04854536382481456, 0.04121232508623507, 0.025360351282870397, 0.06361554071190767, 0.05840327430632897, 0.07454079313902184, 0.04497855385125149, 0.03669197409180924, 0.057105536325252615, 0.03550391069438774, 0.0794042278721463, 0.025129112909780815, 0.011422107309044804, 0.038766469806432724, 0.03323618198919576, 0.03247896129323635, 0.0885062906309031, 0.01792551400285447, 0.016160545819730032, 0.03192025025782641, 0.07357252790825441, 0.03546749721863307, 0.020202606756356545, 0.019678531753015704, 0.03445894821197726, 0.019350890252098907, 0.05247086119197775, 0.018041606308543123, 0.04982214355550241, 0.07365642770309933, 0.07988119876245037, 0.023548136123281438, 0.07605775041156448, 0.03148095820506569, 0.012173050363344373, 0.06959161066333763, 0.011495968628878472, 0.011784863527282141, 0.025083827058551833, 0.0707557806163095, 0.017916465367306955, 0.021445498168759514, 0.006670857474091463, 0.08471524444757961, 0.07720424240687862, 0.06267921009566635, 0.04387752582260873, 0.04080104910826776, 0.006416629221348558, 0.035649690762511455, 0.08434351009782404, 0.03562302910722792, 0.012594032705237623, 0.024684243617230095, 0.056261068748426624, 0.024365025492443237, 0.012004042000626214, 0.02090114212478511, 0.023795158122084104, 0.009111457420658553, 0.03772303243749775, 0.049232414457947016, 0.01535234607217717, 0.04626996873412281, 0.03196392935933545, 0.03540831836289726, 0.03663635754492134, 0.055733000990585424, 0.021748056933574844, 0.03661306524008978, 0.21129457920324057, 0.19360292149940506, 0.11109073500847444, 0.13445930293528363, 0.13911524059949443, 0.13969062769319862, 0.09880446537863463, 0.17837232939200476, 0.09371651613037102, 0.16682045941706747, 0.13779984321445227, 0.10856847191462293, 0.16528491134522483, 0.10579697336652316, 0.09334705275250599, 0.13599572674138471, 0.1500676482100971, 0.13427622994640842, 0.1071911200415343, 0.09625696184230037, 0.16104609036119655, 0.14056403160793707, 0.10305514588253573, 0.19026595837203786, 0.1003577804658562, 0.1181316384463571, 0.0890674433321692, 0.09491634627920575, 0.18827162944944575, 0.13941174343926832, 0.12308021236094646, 0.15224163624225184, 0.15394870948512107, 0.23256778222275898, 0.18123318994184956, 0.1075259770732373, 0.1261102603166364, 0.14624165429268032, 0.15280166087904945, 0.08134263596730307, 0.12012133636744693, 0.10718026984250173, 0.11341759804054163, 0.14643523609265685, 0.08048892123042606, 0.07876653005951084, 0.0680469861254096, 0.08109454342047684, 0.15336281358031556, 0.12967007554834709, 0.12044842311297543, 0.11873708252096549, 0.1169293443672359, 0.11495792554342188, 0.16595094435615465, 0.13706498342799023, 0.17144087789347395, 0.13558002014178783, 0.13186701078666374, 0.07725321673206054, 0.12910715653561056, 0.08449804008705541, 0.17309145885519683, 0.1498529448872432, 0.08934194891480729, 0.18492651754058897, 0.12354645921732299, 0.1295514655066654, 0.09170303979772143, 0.0837003203923814, 0.22296633571386337, 0.162021123978775, 0.16954314691247419, 0.2085070131579414, 0.14981487271143124, 0.16422864224296063, 0.12793981761205941, 0.14111118740402162, 0.2631043834844604, 0.18108802585629746, 0.17744369484717026, 0.10507094513741322, 0.1529586993274279, 0.143226427026093, 0.15933082380797714, 0.2031789717148058, 0.12246719095855951, 0.17395839124219492, 0.07163411981309764, 0.1365486267604865, 0.2504257106920704, 0.10633313795551658, 0.12000155373243615, 0.10926410177489743, 0.251964598428458, 0.17861415079096332, 0.14916381624061614, 0.11856612880364992, 0.1336592380539514, 0.11279375612502918, 0.13320164463948458, 0.1258402966777794, 0.15357114927610382, 0.07030972017673776, 0.1797308455570601, 0.11881272221216932, 0.16286671219859272, 0.14610155165428296, 0.12709403643384576, 0.21465536527102813, 0.16726803383789957, 0.10860850336030126, 0.13460565445711836, 0.13161754526663572, 0.22726984228938818, 0.08683757157996297, 0.23867181327659637, 0.09000956270028837, 0.0641116886981763, 0.13215477112680674, 0.11768697324441746, 0.09532250885968097, 0.12071075747371651, 0.12034957646392286, 0.20359899761388078, 0.18820686964318156, 0.14959018008084968, 0.09387158788740635, 0.13244397123344243, 0.18107310868799686, 0.09609688058844768, 0.10862094175536186, 0.12327612450462766, 0.12121965555706993, 0.1360829736222513, 0.1466828165575862, 0.1079484965885058, 0.06699391567963175, 0.14434233511565253, 0.14521437347866595, 0.10715382712078281, 0.2892185712698847, 0.09045412400155328, 0.0755440654756967, 0.14662096597021446, 0.20149658230366185, 0.09788115945411846, 0.16477903380291536, 0.1560388645157218, 0.17645827116211876, 0.17366095329634845, 0.3289509908063337, 0.1617580177844502, 0.0863011101318989, 0.21040049905423075, 0.08592917540227063, 0.19054993375902995, 0.20853813883149996, 0.10685550601920113, 0.1143619958020281, 0.1297498564235866, 0.1109382756112609, 0.06459510143031366, 0.18696654791710898, 0.1448098584660329, 0.14014323387527838, 0.12283524425583892, 0.10794125322718173, 0.16434465476777405, 0.14019617869053036, 0.18289769359398633, 0.12824869947507977, 0.1531793992035091, 0.24217675410909578, 0.20838414318859577, 0.11076049413532019], [0.035687918789335527, 0.01821221307181986, 0.059217658927082084, 0.048853863481781445, 0.019854010715789627, 0.014860287319606869, 0.03052680676773889, 0.05735459737479687, 0.04563981856335886, 0.0099726223925245, 0.03824981627985835, 0.050209689361508936, 0.032648530905134976, 0.03622714844823349, 0.049221133813261986, 0.02378631728788605, 0.02370087939198129, 0.03954315332521219, 0.02663749281055061, 0.020263130754756276, 0.02758646591246361, 0.02428039653750602, 0.061939489241922274, 0.08098785227048211, 0.039048649196047336, 0.0462598124431679, 0.03623096308729146, 0.03220892343961168, 0.03812185146671254, 0.032082877078210004, 0.02488587771949824, 0.06261528891627677, 0.011046869094570866, 0.0441904783656355, 0.061869567798567005, 0.06763980680261739, 0.06294547041761689, 0.08351825672434643, 0.05569197135628201, 0.02032206470175879, 0.04440193108166568, 0.016236037081398536, 0.09565056039718911, 0.013366601015150081, 0.01888680304546142, 0.05768430761236232, 0.06827945646364242, 0.06301833447651006, 0.06062880449462682, 0.036258444815757684, 0.04930362723825965, 0.016058658220572397, 0.055495992419309914, 0.015052133421704639, 0.05634892419038806, 0.02321789896086557, 0.05007053667213768, 0.029004747229919303, 0.011568514491955284, 0.02033433240285376, 0.026871221089095343, 0.06310567041509785, 0.04634525961591862, 0.03670678364869673, 0.03114185979939066, 0.013468817942339228, 0.02662735692865681, 0.03201547893695533, 0.04069154892931692, 0.05940820905379951, 0.09178814929327928, 0.10489786145626567, 0.021435158196254633, 0.029160002668504603, 0.023810375860193744, 0.027146251741214655, 0.03475015582807828, 0.06528364378027618, 0.026271964670741, 0.017254150516237132, 0.023343420252786018, 0.03051010844501434, 0.0443241985340137, 0.0481390119966818, 0.04551366830128245, 0.04542179041891359, 0.02002844696107786, 0.0034063940574924345, 0.031148743219091557, 0.0719530058267992, 0.01447323968022829, 0.030801952452748083, 0.02106096548232017, 0.021453543049574364, 0.04751445390866138, 0.06556203079526313, 0.01815630337659968, 0.07292228037840687, 0.01406213903464959, 0.08145557600073516, 0.040658226498635486, 0.03875010916090105, 0.004125748291698983, 0.04176914364506956, 0.03934049505915027, 0.04345574474427849, 0.07912987071904354, 0.08652304197312333, 0.06997749034781009, 0.06235663560801186, 0.12317715911194682, 0.061921254673507065, 0.029139235521142837, 0.06294850580161437, 0.02866474154870957, 0.06330251024337485, 0.09004760519019328, 0.0372024789248826, 0.055979798489715904, 0.06357757985824719, 0.011740954359993339, 0.058430986100574955, 0.047364770143758506, 0.01489558757384657, 0.032568453170824796, 0.04390143782075029, 0.11210308381123468, 0.07017373645794578, 0.03928160193026997, 0.01269339236387168, 0.03561818288289942, 0.0474337564810412, 0.041424174851272255, 0.02983929414767772, 0.025481326920271385, 0.02176463651267113, 0.02274885235237889, 0.012612895316124195, 0.02944512652902631, 0.05205072397075128, 0.04589547359501012, 0.04702833233750425, 0.019453827990218997, 0.038317630023811944, 0.03321886026242282, 0.02019988307438325, 0.08306789182825014, 0.04867477953666821, 0.0759383240074385, 0.02447416387440171, 0.07319603639189154, 0.02705645743844798, 0.04121798767300788, 0.025103111765929498, 0.038986757790553384, 0.03427034251217265, 0.009019222379720304, 0.061820968257961795, 0.05083513060526457, 0.048844820412341505, 0.06186961974890437, 0.023582310168421827, 0.03609445244364906, 0.05770338451839052, 0.017687948820821475, 0.027550521845114417, 0.0997131881013047, 0.024296491865243297, 0.021103112048876937, 0.029346200099098496, 0.020426696391950827, 0.05253620729490649, 0.02688699543796247, 0.00662157701299293, 0.03491389215923846, 0.043154774175491184, 0.01952024093043292, 0.006990567271714099, 0.030818339073448442, 0.02367685050558066, 0.08291814869153313, 0.019162304961355403, 0.029421125473163556, 0.0652135924610775, 0.05205429741181433, 0.03133850666927174, 0.026790557058120612, 0.023000063774816226, 0.06691990871331654, 0.0473092203901615, 0.09162714777630754, 0.014425746867345879, 0.02429756241326686, 0.0240620919430512, 0.03394032428332139, 0.04197202455543447, 0.023681423990637995, 0.016520615463377908, 0.027487589577503968, 0.08265519092674367, 0.0341654696239857, 0.020474041702982504, 0.03335936366056558, 0.029448640598275233, 0.024437826468783896, 0.010734921233961359, 0.004737228809972294, 0.08004401854122989, 0.0360447804996511, 0.034075495350407436, 0.03617101610871032, 0.01956868090928765, 0.010886036416195566, 0.08934732948546298, 0.08018751279450953, 0.03916781955922488, 0.018841628516383935, 0.023928540613269433, 0.04968631939846091, 0.027543989090190735, 0.09896642426610924, 0.05170788885152433, 0.017521227200631984, 0.056529670546296984, 0.03148893258185126, 0.021807373086630832, 0.024515321529179346, 0.043906425053137355, 0.06371170820784755, 0.015340025493060239, 0.07080702591338195, 0.06760477743227966, 0.04540981215541251, 0.05484004148456734, 0.06199096831551287, 0.05075352033600211, 0.04349412120063789, 0.061471361041185446, 0.010977901310980087, 0.008892260393622564, 0.06586738745681942, 0.03556572788511403, 0.0335408632963663, 0.036810164820053615, 0.050121863605454564, 0.044310580124147236, 0.01825249128160067, 0.01578505620273063, 0.017704988531477284, 0.009587922722857911, 0.08570958132622764, 0.04670576527132653, 0.0798329220560845, 0.022418219996325206, 0.03659156893263571, 0.048278606263920665, 0.02588029994512908, 0.027564323936530855, 0.057961651909863576, 0.06816898778197356, 0.03158695915772114, 0.06869565288070589, 0.02821194240823388, 0.07390263519482687, 0.09159358785836957, 0.06027650699252263, 0.012350315118965227, 0.04357305231678765, 0.0651564916188363, 0.021156221991986968, 0.0405517913895892, 0.03873770787322428, 0.04648721391276922, 0.04536155771347694, 0.06688109438982792, 0.015539322757831542, 0.041328697552671656, 0.0038931151448196033, 0.021633493452100083, 0.07114393127267249, 0.06541495939018205, 0.11299018777208403, 0.023368102229142096, 0.0647967800614424, 0.06661931663984433, 0.015226801588141825, 0.07243719781399705, 0.03001046494318871, 0.012781771019945154, 0.05849718196259346, 0.016336518310708925, 0.03512695533572696, 0.10072246441268362, 0.03229160240152851, 0.04716530682344455, 0.03297140967333689, 0.07590913533931598, 0.012888746041426202, 0.013560983406932792, 0.030084935751801822, 0.037005780104664154, 0.097235008579446, 0.08463543388643302, 0.015100239434104878, 0.09425420954357833, 0.022819823934696615, 0.023055446545185987, 0.058848117623711005, 0.024551916831114795, 0.024402570743404794, 0.014346976240631193, 0.016069033445091918, 0.04259860499587376, 0.04125971121538896, 0.006051572345313616, 0.044110738308518194, 0.03812397029832937, 0.03864650905597955, 0.03391280544747133, 0.011074131889472483, 0.12883337825769559, 0.029427814079099335, 0.07800634819432162, 0.044020036730216816, 0.039077819310477935, 0.012304639640206005, 0.03856578565319069, 0.01571253167639952, 0.023283191258087754, 0.04918032311252318, 0.0538640319427941, 0.03729538097104523, 0.04560073706670664, 0.05195546560571529, 0.040331533091375604, 0.03799802412686404, 0.034142225558753125, 0.016193358023883775, 0.043112486600875854, 0.0229737991685397, 0.05974593077553436, 0.012448554134607548, 0.10888356555369683, 0.014655705035693245, 0.04736867755127605, 0.039884381694719195, 0.03137513907859102, 0.0408225973660592, 0.027960888692177832, 0.040736044393270276, 0.02002282148168888, 0.048714684817241505, 0.07995180669240654, 0.0854604275082238, 0.1656420179642737, 0.17537541833007708, 0.07132873346563429, 0.14599518704926595, 0.15663197409594432, 0.23356803401838988, 0.1311409825575538, 0.18492151546524838, 0.111653557542013, 0.09378077127621509, 0.1425713481148705, 0.17224371840711683, 0.2162793031311594, 0.055377196840709075, 0.08525167620973662, 0.18054303713142872, 0.20674625295214355, 0.13813251833198592, 0.10191655033850111, 0.07478789120796137, 0.2709599572699517, 0.14746361528523266, 0.20445438218303025, 0.1239490149600897, 0.15679302014177665, 0.14549123909091577, 0.10040426859632134, 0.1252887028385885, 0.10068926814710721, 0.16167124587809667, 0.07585031271446496, 0.12119278238969855, 0.13656933268066496, 0.144062441540882, 0.1256196413305588, 0.11392362401238643, 0.11588987006689422, 0.07866299303714186, 0.07881133351475, 0.10963533888570964, 0.19800252135610208, 0.18093492079060525, 0.21068484551506117, 0.186690513510257, 0.13040610792813823, 0.15509583230596036, 0.1245478613418527, 0.07161155110225081, 0.22858501703012735, 0.13329224602784961, 0.17745120538165793, 0.0709526649734471, 0.1549462747061625, 0.18996252387296408, 0.13819855463225394, 0.17213646322488785, 0.08982339495560154, 0.12023750474327244, 0.09732416277984157, 0.13983775104861706, 0.16327223653206602, 0.16918626293772832, 0.15069372399011627, 0.12582371709868312, 0.13059088785666972, 0.13646292354678735, 0.159767473815009, 0.11172852930030786, 0.20912424253765494, 0.17838286788901314, 0.10268835423630662, 0.1298137108096853, 0.09762206085724756, 0.07992358281626366, 0.1695231831399724, 0.1258619673899375, 0.07805335582816042, 0.16246141050942242, 0.1906788002816029, 0.11280317397904582, 0.14233905589208007, 0.2300715833553113, 0.2334428485482931, 0.15605191147187725, 0.08813122403807938, 0.16198921162867919, 0.15986564510967582, 0.23399576341034845, 0.14278280083090067, 0.11646613289485686, 0.1438083450193517, 0.13117936643538997, 0.13890892354538664, 0.17199765192344785, 0.13639328040881082, 0.20940051443176344, 0.13919617922510952, 0.18166930560255423, 0.12166100335889496, 0.10508866020245478, 0.08495441637933254, 0.11197837331565097, 0.16233230649959296, 0.18707558425376192, 0.21554404258495197, 0.18554497888544574, 0.22868744825245813, 0.16027587465941906, 0.21602539956802502, 0.1533546796417795, 0.14601988572394475, 0.1840840166551061, 0.10020449728472158, 0.19077744655078277, 0.14028789330041036, 0.11772658908739686, 0.13587621127953753, 0.12345523442490958, 0.12250721498276107, 0.13871106697479263, 0.10763604499516077, 0.12390560674248263, 0.14836084214039147, 0.19638165598735213, 0.21614329714793712, 0.13617231335956603, 0.1689809255185537, 0.12925953429657966, 0.1536939005018212, 0.08725820604013279, 0.13253331097075716, 0.1874875504290685, 0.1329829337191768, 0.09094900291529484, 0.10562085430137813, 0.12596448766998947, 0.23432404501363635, 0.1251015777233988, 0.12563098134705797, 0.1265842848806642, 0.1222174582653679, 0.148455495655071, 0.18461543892044574, 0.12721472448902205, 0.17466255580075085, 0.08981166160083376, 0.08945711539126933, 0.16877156565897167, 0.0936030046432279, 0.11754743463825434, 0.11258832964813337, 0.07950236205942929, 0.12271731699001975, 0.12888466066215187, 0.08567179858800955, 0.20677098131272942, 0.1860682523692958, 0.08101949744741432, 0.09091070809517987, 0.14205037528881803, 0.13031617447268218, 0.12138136953581125, 0.09115943888900802, 0.09977823734516278, 0.2675413282122463, 0.12026408847304992, 0.14152383635519072, 0.1492594345472753, 0.1082509069237858, 0.1098895986797288, 0.09673684937297367, 0.09771318917046301, 0.19131342560285702, 0.13507970870705321], [0.031775041643413715, 0.03052345597097883, 0.010595098756311927, 0.06322911925963126, 0.08364436245756224, 0.017352665054204408, 0.043595168317551725, 0.038862637302372605, 0.02954615880298661, 0.01603778902790509, 0.02838557898940053, 0.04771940912178252, 0.07856893324060366, 0.013568777812906774, 0.02946708853414748, 0.012191113310109358, 0.055019129140418954, 0.05538927158340812, 0.05595403112238273, 0.04128946762648411, 0.06439832839532755, 0.0480071509082336, 0.024585734645370394, 0.04033025288663339, 0.015326293905673083, 0.03875264730595518, 0.10058226529508829, 0.02959370263852179, 0.07858083728933707, 0.027015064151783008, 0.057366805704077706, 0.016688259202055633, 0.022685248441121075, 0.015331879494624445, 0.020627378689823672, 0.03386443597264588, 0.05028938117902726, 0.012395549019856844, 0.08486785969580524, 0.06599224638193846, 0.035810120825772174, 0.04583239475323353, 0.05548489360080566, 0.019911109702661633, 0.01693127731414279, 0.021535140331252478, 0.037943888164591044, 0.05438110849354416, 0.04249244819220621, 0.08164330225554295, 0.013765284602413885, 0.023214524044306017, 0.029097497135808226, 0.012078576819476439, 0.023835723914089613, 0.09250512332073413, 0.00747453244002827, 0.07125506788725033, 0.0336709543626057, 0.044841631315648556, 0.04257663000316825, 0.03175151185132563, 0.01497139146522386, 0.027506302831170615, 0.010790261330839712, 0.0361146945215296, 0.011870697544509312, 0.07319107142393477, 0.015225845145323547, 0.033272970249527134, 0.0496812319761375, 0.036139742005616426, 0.032651135843480006, 0.0098732942751667, 0.06395757431164384, 0.022964188356127124, 0.07355259382165968, 0.011771326753660105, 0.09720660658786073, 0.04808395206055138, 0.050777484284481034, 0.03356721324962564, 0.019134559770463966, 0.05828188863233663, 0.024378289526794106, 0.029897369058744516, 0.02512826871679863, 0.02573219324403908, 0.06551360565936193, 0.0813985567947384, 0.028110607709095348, 0.011075977054133546, 0.02477341637131758, 0.044687361078104004, 0.04612940967490431, 0.023712993097433355, 0.06723659054841846, 0.06210073937836569, 0.07181075838161632, 0.0211206489984761, 0.05343723394616973, 0.03420874796574935, 0.09067887600394897, 0.04720747936517, 0.05321776232449338, 0.059892927965847775, 0.024803191336104646, 0.04362749255960807, 0.025717300195537973, 0.03299518437415827, 0.05082507079350762, 0.05642490526952315, 0.030540456718881615, 0.08453626069240272, 0.01343761619864381, 0.033813973641372286, 0.014529988930007676, 0.04121786892937962, 0.023174513007688802, 0.026421752336318605, 0.06620139101869427, 0.017020956584019586, 0.026582134159980342, 0.04598502113367431, 0.014719166083523305, 0.01587155908055138, 0.051617521239677444, 0.030800586901023053, 0.03718778069014661, 0.022135984945634846, 0.04706717263616156, 0.02959170440590242, 0.018304905461263843, 0.04318191080528777, 0.02245009338366799, 0.0286326881905552, 0.05296770679706242, 0.044568094235728495, 0.06327096896711737, 0.038413534057326615, 0.014652195604867302, 0.00790398036770057, 0.028547370893647894, 0.13396486931014806, 0.016225732360908296, 0.05286792504193727, 0.05527924819034524, 0.01071734161087079, 0.004496878254940384, 0.00930584723391803, 0.019045852714043576, 0.007361483403656166, 0.04114240735361818, 0.009879171157081146, 0.0285781774437055, 0.05688691446266603, 0.0967576888797339, 0.05921992618823424, 0.06628060044022277, 0.028740063971781638, 0.017757139248715248, 0.037676881984225474, 0.03140076914860401, 0.031119591658352874, 0.06269984180107713, 0.020035476954944897, 0.04017881765321363, 0.04262535570887849, 0.018923081079265103, 0.015627629982191138, 0.06152214249596, 0.005722563901144895, 0.04744512618344743, 0.043950545732514, 0.1016775045718532, 0.04529628582531586, 0.020934522071911488, 0.04435444476257544, 0.028964172161067836, 0.05165957874851301, 0.08637672755867243, 0.033318519563181326, 0.02200483446358703, 0.012098124989279313, 0.024206528723880183, 0.02108136712195119, 0.014593259802495595, 0.02567799048847519, 0.02214285352238221, 0.03046032703423407, 0.024095043299894314, 0.04058072401676327, 0.07795657234964892, 0.05087460915092379, 0.056699778215261176, 0.03244690793508198, 0.05691738704626914, 0.007765963164274581, 0.00822169286038843, 0.060410011938074604, 0.03545216444763355, 0.06367310910718516, 0.01992912348214304, 0.06031544748111628, 0.019912315692636184, 0.051220988025306724, 0.044020849381922744, 0.001318695187819685, 0.027480023381940555, 0.041005161983775906, 0.024587033403804526, 0.020985663468309212, 0.022294982663879637, 0.025052478740690276, 0.023168457082647365, 0.0838216244301293, 0.04245113283104729, 0.029001281400269363, 0.025007133517647162, 0.048942824723781087, 0.012300768412387697, 0.01832980637118453, 0.02684387294721091, 0.025289702534792013, 0.03533413328113966, 0.056466417299816385, 0.035818822507280856, 0.014432818607019726, 0.021562186047958676, 0.0070264292389765615, 0.05250717076705769, 0.030800117492617574, 0.07640330179128796, 0.08013945873244666, 0.055099013916333206, 0.09227525049936958, 0.01718515675747767, 0.028017354998155497, 0.022673233070236165, 0.021355933931772597, 0.02049359172815457, 0.025613770594645757, 0.1250393412192352, 0.013947366824140772, 0.01630562084756093, 0.023146927378547844, 0.018615611152199563, 0.009929636271408526, 0.01835146038501989, 0.04693393115303479, 0.005982208440400427, 0.04170851389062591, 0.03929929844161961, 0.07890764944022521, 0.025100777711486444, 0.029873945022700354, 0.031831455999054015, 0.019554192331270315, 0.04692029790021479, 0.04937782716297079, 0.026410816790303215, 0.04690592621045653, 0.1065033717895858, 0.01678484601143282, 0.07091472638421692, 0.09636933042202145, 0.0500579609797569, 0.005696027483281796, 0.03790170077991206, 0.005684494972229004, 0.03945112330256961, 0.050128602306358516, 0.0443943352001952, 0.03029192259418778, 0.017201432056026533, 0.01925904020026792, 0.11069341140682809, 0.05678679131960962, 0.049872071540448815, 0.043175728715141304, 0.021402245802164543, 0.035250519213150255, 0.032954611160675995, 0.08290407015010715, 0.007701784088567365, 0.033449779512011446, 0.008212849243136588, 0.042161710080108605, 0.020009193794976454, 0.0411268890456995, 0.016870222680154257, 0.016393756450270303, 0.014009008682478452, 0.03808006855251733, 0.05966469529084861, 0.048024658171925694, 0.07514231867389753, 0.057542423819541, 0.0250823297756142, 0.03494968965242151, 0.027853592691826634, 0.018981551183969714, 0.03809956477198284, 0.045636645882041194, 0.051885974608012475, 0.048047564559965394, 0.030189689896360505, 0.00772132993915875, 0.032412887885584496, 0.02193666819948703, 0.028162303860881366, 0.020715697974083014, 0.06012443351210095, 0.02678048054804094, 0.03206602661521174, 0.015067791809997289, 0.018830902627087198, 0.019617185826064087, 0.03223635321774054, 0.11994361426332034, 0.02012058459513355, 0.041706810661708005, 0.05825448482937645, 0.0652731275476981, 0.026689391197578516, 0.061246950426721014, 0.06751750086550601, 0.016631343896733597, 0.020204879583616275, 0.08997630706289783, 0.08142312930431217, 0.016473171817779075, 0.030065385726629756, 0.0800424229237251, 0.032245526163023897, 0.040660267404746264, 0.04794245418452192, 0.03427416828344576, 0.035176660676370375, 0.05576392628427129, 0.043264942287351005, 0.04867764422670007, 0.024666960853210185, 0.03218301877495833, 0.017352366339764558, 0.020895767120236997, 0.019114317692583427, 0.030464360606856644, 0.044421768689062446, 0.021845105729880743, 0.0510992906492902, 0.041845057930913754, 0.19369140034541488, 0.0976713617274072, 0.20998590567614883, 0.12542179960291833, 0.25616254191845655, 0.17585287161637098, 0.09277418153942563, 0.12588515208335593, 0.10212490829871967, 0.09303253798861988, 0.13591183436801657, 0.21968185727018863, 0.2150622254703194, 0.1386701301089488, 0.15601855935528874, 0.09151241174549796, 0.12565864861244336, 0.18356901069637388, 0.23370596958557144, 0.09336607399745844, 0.19727106060599908, 0.20561106386594474, 0.04689533947384916, 0.11653196139377542, 0.14728769659996033, 0.16483278013765812, 0.2561538736335933, 0.10748564134701155, 0.12692862655967474, 0.1365355946472846, 0.13683591212611645, 0.1097867518546991, 0.12510608998127282, 0.13088755396893248, 0.278538353741169, 0.11411620391299948, 0.10454594987095334, 0.1378181148902513, 0.12155442353105173, 0.19044610729906708, 0.13620759506011382, 0.16832191322464496, 0.11190249613719061, 0.07584478371427394, 0.08701673345058225, 0.07742854912066832, 0.09444854091270827, 0.10202195015153848, 0.10710428134188987, 0.2170279817073606, 0.15183862036792561, 0.11443835537647828, 0.1207569710095413, 0.07735599676379934, 0.11458319291705266, 0.16578958660829812, 0.19044333166675642, 0.15830808493774384, 0.06680909864371642, 0.24747212621150538, 0.12129583701607771, 0.13629580673296005, 0.1453827222576365, 0.07684655691264197, 0.12321398447966203, 0.1485628547379747, 0.201134072849527, 0.1633234744076617, 0.21189560007769614, 0.13557069876696914, 0.19263155409134924, 0.10027036289102398, 0.12939019681653008, 0.15136821748455986, 0.14770441252039745, 0.09851905022514984, 0.18418291525449604, 0.2833637682488188, 0.13732102437643334, 0.11568137852009386, 0.11677569753373973, 0.07878420801716857, 0.0744269328424707, 0.13566192355938256, 0.13139208080247045, 0.11404238248360343, 0.1449730122112669, 0.09058387367986143, 0.1412113179685548, 0.2725301339523867, 0.09072409506188706, 0.10075739730382338, 0.0958789192372933, 0.1218192811938934, 0.1033957174513489, 0.21339662343962118, 0.255094175809063, 0.1477940788026899, 0.14620969741372392, 0.09924077399773523, 0.12118050726712681, 0.1285505754640326, 0.1841622983920388, 0.13215846702223644, 0.14953938749385998, 0.13578488258644938, 0.0888533188845031, 0.19026027352083474, 0.12036121333949268, 0.17404479207471013, 0.10915804145042785, 0.1930237197666429, 0.1692628674209118, 0.2119899122044444, 0.16749070782680064, 0.12562988296849653, 0.1735535348416306, 0.2536116022383794, 0.14757952390937135, 0.11037985401344486, 0.14510927052469924, 0.13153899635653943, 0.14129912888165563, 0.08046753995586187, 0.14037675806321204, 0.10047789706732146, 0.20437466067960486, 0.08735661482205614, 0.1294623632566072, 0.10369420924689621, 0.16603989817667753, 0.12933832069393247, 0.13781421119347215, 0.1376957050524652, 0.13783644593786448, 0.09030775021528825, 0.18003680335823447, 0.07850694906665012, 0.20843708800384775, 0.11626147083006799, 0.2350689089507796, 0.10095837831613608, 0.10370278847403824, 0.30032095208298415, 0.06873930600704625, 0.11817877224530093, 0.13485278963344172, 0.1262617771863006, 0.06695677860989235, 0.14666230359580368, 0.1944834500318393, 0.09944477555109188, 0.10563618707237765, 0.299986926256679, 0.1486213062889874, 0.16101162502309307, 0.13844945991877466, 0.1743600267218426, 0.2231310331262648, 0.1690492031048052, 0.20108523953240365, 0.11366974271368235, 0.08751585744903423, 0.1962246620678343, 0.11321570418658666, 0.12987429974600673, 0.12435541502782144, 0.1497434632619843, 0.14619516616221517, 0.09464780756388791, 0.14984959037974477, 0.10134666998055764, 0.10603336224448867, 0.0901024202175904, 0.19735937617952004, 0.07784648216329515], [0.03314028537715785, 0.05496071098605171, 0.05732512669055723, 0.007729877625024528, 0.03290448279585689, 0.023876445557107218, 0.024465538263029885, 0.024986023126984946, 0.053629038302460685, 0.017378920383634977, 0.05060637471615337, 0.05131032405188307, 0.02921742263424676, 0.016936238571361173, 0.010100138206325937, 0.06802887030062266, 0.026249384827679023, 0.03448672308877576, 0.021391963346104603, 0.036820150417042896, 0.024133772276400123, 0.0038966375632298877, 0.05259570898488164, 0.00977336409050622, 0.022187254362506792, 0.04301722452510148, 0.011612565594987245, 0.024404157084063627, 0.036751765219378285, 0.04782701682415791, 0.016265791637124494, 0.01587236431078054, 0.030636781921202783, 0.009023433140100678, 0.028912665256939363, 0.010527749782340834, 0.03242066930397414, 0.011276343939243816, 0.027655083031277172, 0.008270152320619673, 0.024833829047565814, 0.1030944574449677, 0.06555315470905043, 0.058544252678984776, 0.018461359468346927, 0.04845743045734707, 0.07888432373874821, 0.02482863586919848, 0.03703220056195278, 0.04282176880224142, 0.06889639640576206, 0.017106817504100036, 0.03284121099568438, 0.05176020284125116, 0.06369313967297785, 0.03474763623671606, 0.05548431843635626, 0.028717226232402027, 0.03533028153469786, 0.05273392656818032, 0.027803573793789838, 0.02255002542369766, 0.009519735122012207, 0.01001847505904152, 0.048549653438385576, 0.07209724222775549, 0.018302536154806148, 0.03954447434807662, 0.027139845151396003, 0.037104508010088466, 0.06134577110060491, 0.005328441739038681, 0.036911427159793675, 0.040398448836640455, 0.02374510953814024, 0.03304215118987486, 0.03459047162323259, 0.030139142218104098, 0.029784879880025983, 0.03775589102588128, 0.034307694804738276, 0.03142233967082575, 0.03346049983520061, 0.04000333683507051, 0.0646542728645727, 0.06415701907826588, 0.016523964404768776, 0.05422134265245404, 0.045041688354103826, 0.04926237495965324, 0.010949990064546, 0.08927240225602873, 0.040171815489884466, 0.024683230585651472, 0.014740003734914353, 0.009763722664501984, 0.10614695536787622, 0.059876185114262626, 0.05734782898798585, 0.10487972336704843, 0.03767085203435272, 0.018097016909450758, 0.030696940411871765, 0.07111938844900578, 0.035168489630450495, 0.025013950144057162, 0.04687150911195204, 0.10331809622584842, 0.028287090426601935, 0.0193604082960519, 0.04163226192758884, 0.0458501729008276, 0.023253099025168922, 0.0062231754418462515, 0.035154236684320495, 0.027509180508786812, 0.05306253471644595, 0.0688960995466914, 0.004795343147634412, 0.05784520151792094, 0.025514100161672104, 0.04257618471456226, 0.014531772867485415, 0.056065190001390874, 0.05340790798072703, 0.029335342478589155, 0.05746196387917735, 0.0680064425978344, 0.02122996920661535, 0.03331359912408516, 0.03175140423991252, 0.050478910852689296, 0.07901921650045551, 0.05443399764772039, 0.018428653020237107, 0.024507285925210454, 0.06304431706666946, 0.01720215008390369, 0.018953010039695073, 0.057741337950574234, 0.017058344128599856, 0.05507642294105608, 0.05349988234229386, 0.01885135436168639, 0.07616929520736448, 0.02381048718234524, 0.0378129881573841, 0.0694934393686708, 0.03737037870450877, 0.09813411306822672, 0.05560530706134159, 0.035410318450885825, 0.07359977957094088, 0.042833305487874895, 0.01147765056884964, 0.032573340213275515, 0.04216746172460262, 0.05338094946637284, 0.0036363494427860132, 0.063393838936463, 0.003598098919610493, 0.009512617925793165, 0.04889202471531462, 0.07695251333643682, 0.04634268436348066, 0.04360867911600508, 0.0305218251014594, 0.027493608395161573, 0.0023697888536844403, 0.06355470686685294, 0.038144564896356314, 0.020884757359453943, 0.02914641023380682, 0.034372269074083306, 0.048159498983295634, 0.06551252954523079, 0.05067432575742714, 0.03383257928362582, 0.04888435832981486, 0.011382948814571137, 0.08408148001763038, 0.015821449269424193, 0.029897215063101612, 0.04261400084942579, 0.05816501521621831, 0.009884432056423975, 0.03743778797797859, 0.047703464078949764, 0.04732816742034629, 0.021415882765722927, 0.05154493548616301, 0.009326968756795395, 0.012082046359864762, 0.05726652299927082, 0.06555250904057175, 0.02530950674554333, 0.051339854107936844, 0.018322227188036777, 0.015434914639627095, 0.0031692688298790017, 0.02030163708695909, 0.05441178516775835, 0.04147565763560124, 0.053973654576111585, 0.043776590027846396, 0.052943661212339066, 0.024263187988253776, 0.021106262465764303, 0.047138548688963056, 0.01256559175089933, 0.051750974234892055, 0.0027118934212921886, 0.032858959457371384, 0.02737635833909735, 0.06700487720081583, 0.04508735641138628, 0.014784245013288455, 0.01824966740969103, 0.04117335491173435, 0.020443370594875887, 0.035548751257010736, 0.0738236632605549, 0.044392973359208554, 0.045540790088125505, 0.09678684044047259, 0.04903321088931989, 0.046281115792226046, 0.05856400865013711, 0.05189284318475984, 0.08557840672438033, 0.034847180504584685, 0.025204440898960456, 0.03592598492105026, 0.031070511577127036, 0.028435193416953553, 0.05262396254693158, 0.07788143731886521, 0.020062823241460137, 0.009819809547479963, 0.028871446374978404, 0.013323633447726024, 0.04915496021567378, 0.02109082393872086, 0.05834802141180262, 0.06342687192955054, 0.036803233160753734, 0.05436006860691123, 0.0033283783341175877, 0.021944316031294875, 0.05818660058139358, 0.03424398513743654, 0.020223231040290557, 0.04861509602051228, 0.02687259406229714, 0.033642856651567854, 0.022967704280745238, 0.010568478846835205, 0.03526712105667684, 0.043297752636135556, 0.05257954871922266, 0.030482470865536015, 0.01658523982769111, 0.07268716799444519, 0.04947937894030474, 0.07285064086318016, 0.01373897082885378, 0.009380437713844003, 0.013102902958053164, 0.021009399206377566, 0.02388775032159174, 0.0358791442704387, 0.12230835651280358, 0.04439398639078718, 0.03740832471521571, 0.05403966119047254, 0.029900914669269696, 0.04826800468435977, 0.032395202506450005, 0.04799493515747599, 0.05843032187840436, 0.04541355257970281, 0.05430388802778907, 0.04344165135989897, 0.031231604007189162, 0.0170464716211427, 0.05126929441757966, 0.0771073327632621, 0.1295514209778048, 0.02223591884103371, 0.05491200754477177, 0.0314420474023791, 0.026414991370984353, 0.025464391110290308, 0.050600953327375464, 0.035162248168489896, 0.04731424844067078, 0.022217689838726074, 0.06283413342316635, 0.009390124596393434, 0.03001154476805823, 0.05605852922599297, 0.07083750591846183, 0.02471936390065821, 0.04060406456119381, 0.046783085927017964, 0.00864050627569668, 0.023432593006873503, 0.006363373167914688, 0.05040711548645049, 0.02138097770512104, 0.05596738606982399, 0.0033277245483986917, 0.015557289225398563, 0.041071650994126685, 0.0442227024177555, 0.014385578124347376, 0.02928823094407562, 0.06026918570569251, 0.01597642454726156, 0.05832328934047837, 0.022941649331187364, 0.0226282533549238, 0.018669839882932138, 0.023828139164834283, 0.07538215111708269, 0.04956061442499049, 0.05950486636720598, 0.04887405360932462, 0.004765006933666882, 0.040170769061660394, 0.02980982346343808, 0.04015067912405357, 0.031733659488963895, 0.03929723898181692, 0.013461795369948959, 0.08486546255880967, 0.019021346997760702, 0.03645682460046373, 0.027292953927826602, 0.08646879097796045, 0.021644948501489125, 0.032087066501844674, 0.016963898415269796, 0.008802839020063402, 0.031238639567163773, 0.028022204933222383, 0.0303246290422976, 0.032269256334984675, 0.006418929879146162, 0.05659371046931483, 0.03245727944886312, 0.057415850533288904, 0.12018444860586897, 0.13681084237759933, 0.19810234021861106, 0.126078526081983, 0.13827398652210832, 0.06078287806303706, 0.060828809582744725, 0.12339411856373772, 0.09542717394651845, 0.19095427065622061, 0.17332289018668234, 0.1909598961356096, 0.19038016005652025, 0.12557334615848958, 0.21638758247718215, 0.09947910730261356, 0.09338919189758599, 0.1091918685415294, 0.186101010767743, 0.14210021792678162, 0.18509111105231568, 0.0800881466420833, 0.13146969460649416, 0.07136652362532914, 0.11740549889509566, 0.12894094514194876, 0.12986526038730517, 0.12344526738161221, 0.09378388829645701, 0.24778313061688095, 0.10137309043784626, 0.11632694309810176, 0.13319530669832602, 0.0971894407120999, 0.16292972053634003, 0.08720204030396417, 0.2010661069652997, 0.09354290552437305, 0.14207534113666043, 0.2024617453571409, 0.11450272926595062, 0.16183379106223583, 0.27575725922361016, 0.1099754948518239, 0.07601127712405287, 0.1704935560701415, 0.17818345280829817, 0.1710385299520567, 0.19852083729347214, 0.21101087098941207, 0.1505810214439407, 0.10287375014740974, 0.1574804715346545, 0.17854573961813003, 0.14771869144169614, 0.16446224064566195, 0.10991547736921348, 0.14606658165575936, 0.08309770390042104, 0.12038579327054322, 0.17214569554198533, 0.10141286213183776, 0.11584802035940811, 0.11543898566742428, 0.09763836584170349, 0.18311447493033484, 0.08277947097667493, 0.10076236969325691, 0.10369164141593501, 0.13099163275910541, 0.1444338567671366, 0.1322326372610405, 0.07932072883704677, 0.10414032905828208, 0.11357983894413337, 0.147673791507259, 0.1825703025679104, 0.07481101652956568, 0.14736486511537805, 0.06455752649344504, 0.15967555140377954, 0.11776025290600955, 0.15423437696881592, 0.11962409742409363, 0.21501417882973328, 0.17171731306007132, 0.12110699753975496, 0.10965786306769587, 0.15269467286998406, 0.15270895179128274, 0.09552933057420887, 0.1507967192446813, 0.1464614042197354, 0.13617106655146927, 0.14276377216447145, 0.16687950468622148, 0.17632797971600667, 0.09965289602405392, 0.12396723468555138, 0.13476784341037273, 0.2037631903658621, 0.08610830016550608, 0.23781590920407325, 0.12503490317612886, 0.12388796589220874, 0.15281282278010622, 0.1381399398087524, 0.21803500188980252, 0.12800260330550373, 0.16058138717198744, 0.17386679537594318, 0.21977193915518, 0.18784789281198755, 0.08587830860051326, 0.11860582628287375, 0.18258407682878897, 0.09189792777760886, 0.1662020426010713, 0.23115396121283993, 0.17242778587387875, 0.11985823017312214, 0.18329551443457603, 0.08213117529521696, 0.19567801093216985, 0.12878332781838253, 0.12456950236810371, 0.1584827122860588, 0.21588918578345329, 0.12520187156042084, 0.11190257035195827, 0.14450765593210235, 0.19876038772054017, 0.22703674854710698, 0.10480694094439968, 0.13184361829189584, 0.07878205578890629, 0.08944647299358621, 0.1550946745555848, 0.11259984035859816, 0.17142447642982006, 0.08313294849358499, 0.17261207598494366, 0.12667588074691594, 0.06881620734930038, 0.1756274516810663, 0.07158144217100926, 0.17816440929891542, 0.14422989974264055, 0.13070492626866326, 0.12999185593798757, 0.15657499199733138, 0.09545847773551941, 0.13798002182738855, 0.10632382400217466, 0.10573409861535765, 0.08743540864088573, 0.1707374703255482, 0.16706155351130292, 0.13621949910884723, 0.17834488477092236, 0.08976799363153987, 0.07755874408758245, 0.18341928982408717, 0.17608762776944786, 0.23233868123497814, 0.12319865170866251, 0.13714310189243406, 0.08366350244614296, 0.13455891399644315, 0.12611046811798587, 0.28695439745206386, 0.10977375684888102, 0.11157864515553229, 0.17388134147040546, 0.16641934344079345, 0.16576022724620998], [0.0268796852833475, 0.023066550929797813, 0.02779569218546385, 0.04261575602868106, 0.022511244496854488, 0.035612683568615466, 0.043403375093475915, 0.05861804442247376, 0.013184539202484302, 0.06264472991460934, 0.019548798773030285, 0.057186875710613094, 0.049712995896697976, 0.06266102005611174, 0.047484508249908686, 0.019205546195735224, 0.008848387406032998, 0.020404684291861486, 0.02925987348135095, 0.04884375543042552, 0.019847628245770466, 0.047451412174268626, 0.037701933179050684, 0.07723823277046904, 0.036117247509537265, 0.018752747055259533, 0.03971426289353985, 0.03508165835228283, 0.03609831903304439, 0.038505912889377214, 0.06344610839732923, 0.052313870983198285, 0.014726941935805371, 0.0583512794401031, 0.014877305693516973, 0.03879598130879458, 0.019747263904719148, 0.009095938185055275, 0.04364071392046753, 0.016592436804785393, 0.03250151145039126, 0.03126037336187437, 0.044328606891212985, 0.029634663624165114, 0.057113625734928064, 0.025942102292901836, 0.02439659830997698, 0.01771737683156971, 0.00612227629062545, 0.16638662957120687, 0.06637214435613714, 0.04707375177531503, 0.02290020594955422, 0.010080163301608991, 0.04007195580925327, 0.028472584672272205, 0.029674785982933827, 0.050513257447164506, 0.023998890646907967, 0.059931645810138434, 0.01019395494950004, 0.09007976244902238, 0.008827874444250483, 0.07453504149452783, 0.034751517669064924, 0.03284734113549348, 0.01184981443657307, 0.03443702145887073, 0.05990528101392556, 0.023830022364563774, 0.02438265521050198, 0.03360183814947959, 0.041711103986017406, 0.029306125979928765, 0.041750133532332256, 0.04598669838742353, 0.03133752332360018, 0.12253163164132275, 0.06519306465634145, 0.02523959457903402, 0.053965988190611824, 0.017161740142910276, 0.06942543637705967, 0.018440479143464472, 0.011386647493054625, 0.06283415568759665, 0.07937017071526498, 0.03970118996221572, 0.0780850974842906, 0.05074184635304846, 0.011878382483700989, 0.114651062322082, 0.05324816440406721, 0.038065210756030865, 0.04655203680158593, 0.029553005115303677, 0.02626916677400004, 0.03907680256816093, 0.044872074213344604, 0.040273901613545604, 0.028715445077978075, 0.061114488198654726, 0.04482774944335688, 0.040812608058331534, 0.01601566003955668, 0.0561647565336898, 0.028308748151175678, 0.02365609077969566, 0.03423663045396097, 0.02279347027069889, 0.06148079002741724, 0.045905778315500356, 0.015003681382950163, 0.07213576711365022, 0.04019268097181339, 0.04624786015483551, 0.05706194257072639, 0.03426302493608091, 0.062475408922182396, 0.017688590778561775, 0.017834817990660667, 0.06346691079670563, 0.014688192550238455, 0.004014559262941475, 0.023988821558305062, 0.019334490643814206, 0.045244921784615144, 0.01609668215678539, 0.05131808320584241, 0.06192141052451916, 0.008687417430337518, 0.07102974443114363, 0.008265966607723385, 0.02062394625681918, 0.024744433649175335, 0.04508081066887826, 0.046013753380975686, 0.01985912040254334, 0.043787959730252624, 0.05513969845196698, 0.03388217701285612, 0.03088359797402518, 0.12877972098067403, 0.06173896093969233, 0.0712623780418653, 0.033583458862267435, 0.026569135443423875, 0.04133216709305998, 0.03955087908252608, 0.03315035632112995, 0.045656134680029936, 0.04058864273247309, 0.015804275972186588, 0.03594715097278822, 0.06210515144630335, 0.02384751849604072, 0.05387103039538488, 0.04152858760789968, 0.029114145363564603, 0.018119296182703692, 0.02329908991669072, 0.034712558626779355, 0.07288466091267765, 0.060889023734489456, 0.03682511538499966, 0.040864228139980696, 0.041778097656788304, 0.017450309424020816, 0.02662544033228187, 0.06628552087931894, 0.016344860050594434, 0.04770546416693833, 0.022961271715757903, 0.04254606094036717, 0.013397810180322267, 0.03508094589051325, 0.05399898778705392, 0.03128130192635581, 0.03381931339390576, 0.04225241165840998, 0.016503384649695363, 0.02786519060464343, 0.022521387800225057, 0.01152074151832494, 0.007425667581628659, 0.053304756875149906, 0.06888383184559643, 0.033613593768677674, 0.04783076838066336, 0.05666144999850076, 0.04351372132077813, 0.018947147073049564, 0.03401492125703953, 0.0055310132665908895, 0.03769479371840134, 0.021076313096273225, 0.046005615731701255, 0.06201037918799557, 0.06760373100405559, 0.02312259421159979, 0.04815670479729306, 0.015340852060035104, 0.03628302103606984, 0.026853198032767978, 0.031157519115367904, 0.023170640852185898, 0.07053797511616722, 0.044582632908714004, 0.08665750428917818, 0.05182455446629319, 0.046730137401027605, 0.019691892266564537, 0.02717402847338235, 0.03053418742638314, 0.0487012074154336, 0.04703552745922934, 0.11238964187214151, 0.09168717268039472, 0.021388245186244603, 0.02440979369566776, 0.00638145002994861, 0.04725506587419659, 0.0064791764998517465, 0.04636074081645347, 0.02930903519882122, 0.0586135210323846, 0.06159954849863425, 0.046158346012816764, 0.02714098805881804, 0.04058000042277854, 0.032261003652820364, 0.03885073325363919, 0.018518009455874562, 0.015577935773762874, 0.025475771944911685, 0.046247400023275986, 0.06033350022335071, 0.026176032806688454, 0.02314567129360512, 0.04040469400933944, 0.007112793891792535, 0.024172158009605482, 0.022640053502982482, 0.03307762584881857, 0.02182708638429176, 0.03317733709991444, 0.04049609320645686, 0.09285552834626287, 0.026429891840962227, 0.03244356827053707, 0.0066868159683508566, 0.04997314463253133, 0.025142139456875157, 0.024350113890250213, 0.04890655596682336, 0.017111209162976593, 0.01403331216351944, 0.036437157687032595, 0.06996544529101811, 0.027506696169439238, 0.07578790551633574, 0.03629234241088852, 0.0735667317348998, 0.06101220911659766, 0.0743778026662767, 0.011077311064582318, 0.017420784934074618, 0.08457779127638787, 0.0020332056328697945, 0.025697876335470937, 0.015841932545299642, 0.04095647709618788, 0.03306378479464911, 0.025971871691581327, 0.051964490121463314, 0.03237419230572414, 0.044798378949053586, 0.05778459402790759, 0.04227521414577495, 0.04225692762702238, 0.011867787397932261, 0.02664150597411208, 0.026669809631130192, 0.02020203901338391, 0.0453166614897782, 0.029983662279846612, 0.03239012250560336, 0.055738567098160274, 0.043762440982391126, 0.052855720423394814, 0.06583907452295534, 0.0629276514519006, 0.05652330662996974, 0.04875388876826037, 0.0509138910274487, 0.021016559076088015, 0.0250381979640224, 0.025491919222986326, 0.042688182220445015, 0.05832928960444406, 0.015142392494453816, 0.06523408315842971, 0.07018562566372566, 0.04130326415179297, 0.030637206800747663, 0.015270600360963726, 0.03156764847517479, 0.03295271497336216, 0.023556255218863953, 0.03307720282464288, 0.0574779089220101, 0.044727125350618735, 0.015163336829573382, 0.052155366793158464, 0.039508643458248116, 0.05029209001804702, 0.018992072982655372, 0.050651196725084446, 0.04880478896666318, 0.021487752346729394, 0.13730201055295765, 0.016691417040419765, 0.022899673458596226, 0.05515953234862536, 0.037678395965485834, 0.032297279831254855, 0.011435339802119415, 0.033566200218047015, 0.02696962430491112, 0.005841385454914416, 0.046270176535472274, 0.08128739049425349, 0.07988093901076354, 0.050324492185609415, 0.015933797440084163, 0.05161334294825792, 0.025977330187743064, 0.02936077773483703, 0.037052635598229244, 0.08403712185099721, 0.03441374399699271, 0.029373984252742957, 0.04978000441042241, 0.012746797310683178, 0.0271511109531275, 0.01201979872348602, 0.005548657363760867, 0.024073446802503895, 0.025183172801916953, 0.01715058937406866, 0.011559366594156018, 0.03509722861053888, 0.0861177031765692, 0.0973231608804781, 0.13681223761523142, 0.08401224506087601, 0.11250683441176079, 0.15526973234955221, 0.18286493519553915, 0.18091048928909004, 0.07134983272408135, 0.06355789810186252, 0.13182127964682877, 0.14129228628007695, 0.1340466836700216, 0.13642768637510017, 0.0846386028570123, 0.11867059351061471, 0.07123749383026734, 0.08102822510409169, 0.0917672504147049, 0.08447214655461721, 0.11284312378847972, 0.10691138231777586, 0.13206048868596554, 0.16164429107448086, 0.12199296601465903, 0.13697531714569777, 0.14733114192495123, 0.14318648463813588, 0.1687460209359415, 0.14065400959225371, 0.19833592377835885, 0.14570641738828272, 0.09489178861258551, 0.21255838248180225, 0.14196418225765228, 0.09865507847280242, 0.1106060977326706, 0.09613421803805977, 0.13974265224533156, 0.1606413972331211, 0.1726412572315894, 0.192893294733949, 0.144815543317236, 0.1387627501389943, 0.17273957695579156, 0.16113235760712996, 0.08759092568652704, 0.0931024928286206, 0.10164046398131177, 0.16685140697518364, 0.15758171532070264, 0.14491453097434714, 0.13639176642755046, 0.24879720120225102, 0.12302295566769317, 0.1332832215121016, 0.08530409410013817, 0.15631335525540635, 0.09300211735535413, 0.08284720679512247, 0.18074806284857914, 0.14348635682836175, 0.15531766024651006, 0.18346442724578083, 0.09671750900452025, 0.13582158921053633, 0.1221493365301285, 0.06866527677630074, 0.1914964837487787, 0.08774138128501363, 0.11397208625567146, 0.3080642537679523, 0.17301074287388474, 0.10085208050440997, 0.11347733350703493, 0.15876508463406935, 0.13298245874466375, 0.1723876950563863, 0.23095937009202316, 0.10410149989183992, 0.11299645891995169, 0.1002571897697635, 0.1260361642926, 0.15319655765779316, 0.14889692509314045, 0.1438782553304918, 0.16098980588139966, 0.13641744473716244, 0.371320498525165, 0.1192818114941474, 0.13180597656173632, 0.17867576389107853, 0.23273966362467036, 0.10675921977963299, 0.1622200640849769, 0.23804701399058104, 0.20298739371355623, 0.1555479783564806, 0.15191123209660873, 0.17663361097220331, 0.16243442601989955, 0.18711484386585653, 0.13601963873952627, 0.16249256586888805, 0.09333744936157018, 0.08989270412712358, 0.13512380712199956, 0.12285285542020574, 0.24452504294458777, 0.1293524808716029, 0.10088379247463308, 0.14430742448894307, 0.12830317311454564, 0.09111716615734622, 0.1274691623984836, 0.17146560625405982, 0.18487041117623448, 0.12523031065938994, 0.2184191078413278, 0.0929563120007515, 0.16557001479668543, 0.11050057175452821, 0.15039968508062884, 0.1829284630366601, 0.1229236637300346, 0.1308525394415483, 0.22994865401415154, 0.11328588167089038, 0.13916233729105443, 0.13880453305318952, 0.08701124155777507, 0.2061019351822324, 0.07554616575362161, 0.08870672245393507, 0.11762550115236081, 0.12761751771904528, 0.12369319665594958, 0.12607716053025797, 0.1327090515405871, 0.24548854358727112, 0.0988587386382278, 0.2843321819091216, 0.19321265572216362, 0.24035129346884787, 0.16617151064565405, 0.12320308975176886, 0.1408381512737833, 0.14557514630723745, 0.07732072248472832, 0.09522152482531965, 0.08644413683214225, 0.17247886047698557, 0.1428199972724542, 0.13198793632909656, 0.17689927015453577, 0.129424869955983, 0.1276956807123497, 0.09156900792731903, 0.13713677879422903, 0.15603028528857976, 0.0760769126645755, 0.1329851453192532, 0.16331679507857189, 0.19410777487792075, 0.17783290677471086, 0.12107358605135232, 0.1337190403137356, 0.08976028271717951, 0.09935488662449643, 0.16732863761717454, 0.0694046042917762, 0.13181510497815907, 0.10329099299269728, 0.11745483687263913, 0.12093989556888118, 0.13933591078966856], [0.045881161277065985, 0.007745498905933346, 0.03709599557623733, 0.06126976775703952, 0.0561355196259683, 0.011126169429189758, 0.0474964568275027, 0.05291424989991356, 0.025178766300086863, 0.03419871783989947, 0.052951680117985234, 0.06340655192616396, 0.02423149828246096, 0.04869281743594911, 0.040558582040830515, 0.027444875267974567, 0.017654780385782942, 0.03027894057595404, 0.05408862438343931, 0.014477687000180595, 0.04616721096681431, 0.06316915372735821, 0.012949404554092325, 0.05124577946844511, 0.05783251079265028, 0.05480274114233907, 0.033342973329126835, 0.022695070765621495, 0.05314151778293308, 0.07429233693983406, 0.02764811611996265, 0.1063333977072034, 0.010789757598104188, 0.02686413914489094, 0.13149614474968985, 0.07949384962557815, 0.045418918307404965, 0.03741366817848757, 0.030743393290322274, 0.04441746052179951, 0.03930888698960189, 0.040553372164140455, 0.029056871971988585, 0.04706750660261605, 0.031119281811697874, 0.05310998021741398, 0.012474886461859569, 0.04098517223610543, 0.06350217023282312, 0.05377987239626236, 0.031463681007153355, 0.07805199769791216, 0.04912181218969636, 0.021697607589885592, 0.020157601065875497, 0.022307996223389637, 0.07312381058000028, 0.02252308917377377, 0.0544564364827238, 0.03740834697964601, 0.005734285196012934, 0.03527985260006972, 0.04450227686902508, 0.09527970920316875, 0.03641283750766888, 0.013157928569853539, 0.023491762585763354, 0.06406744927517138, 0.03112256024905946, 0.07297610834939405, 0.01790396203432465, 0.031377784835058264, 0.05756961239967495, 0.039889624968054704, 0.05376708148105536, 0.03120092733297497, 0.03260116704041138, 0.0409918626974104, 0.021696349649573676, 0.046462890022667125, 0.0026011603495135205, 0.04935555160045624, 0.012703538450296037, 0.028189843105792534, 0.0569765547697898, 0.057706957959453575, 0.05921037103689741, 0.02863319285097532, 0.05718003310903441, 0.09637846625992097, 0.017068038432626054, 0.030153038933349308, 0.027273656232864596, 0.06422678095987067, 0.029985961082275026, 0.016706599526514765, 0.006553902421728708, 0.09694001972093247, 0.05204626366321463, 0.06008547446981538, 0.027322966379870195, 0.0324095222458709, 0.04178368973953184, 0.0485208989266539, 0.011510521217132919, 0.09137751898379065, 0.02412247678876156, 0.01876157861261163, 0.018091742094838992, 0.08297704553115182, 0.014245698130253004, 0.005687802631655359, 0.040826515905791894, 0.04681650854763575, 0.10622179353958927, 0.016572907188674435, 0.03805410822678823, 0.103221119788941, 0.0765863673586864, 0.02297028881002916, 0.04766705802467186, 0.06164878999697976, 0.027612708254309837, 0.04779219896590803, 0.052860425639664754, 0.03254955809097737, 0.025164906692225486, 0.011672859527607216, 0.08068279246799648, 0.04693026123277377, 0.0179600331466645, 0.008167721098288894, 0.02316606365639018, 0.0069532460565824294, 0.02932733841589652, 0.021830281330039725, 0.10098314378410578, 0.004288981817808235, 0.032348198583349586, 0.020325753175711725, 0.03340410032251384, 0.02300609186931979, 0.04775135857926216, 0.03839016011625063, 0.01767533045494929, 0.08035214341362007, 0.03590934968087822, 0.011814684876298998, 0.04237535955326166, 0.020192177726130467, 0.042466205850359984, 0.0033410878450013115, 0.013592242667073151, 0.04578621832479257, 0.01984248145163292, 0.04434526068507694, 0.002720895904531062, 0.026093155320268124, 0.028350100619718432, 0.03961688569688704, 0.05260252932203002, 0.05171787073777523, 0.028499426298367325, 0.07627114013303071, 0.06236196422833018, 0.030909150118532125, 0.01080100670151296, 0.04226158831443172, 0.03894736830261536, 0.03276443952927366, 0.007981668386491947, 0.061324334164964966, 0.03657746441604104, 0.057999048731289804, 0.009234530552930664, 0.015661158358852845, 0.06195102592755575, 0.0113482098095119, 0.03706017210788559, 0.026468240466783755, 0.09217955055646598, 0.03864774844259955, 0.012555294451885857, 0.024223494219768327, 0.044836547604063526, 0.05994558705424424, 0.06265362084377557, 0.08019685643375851, 0.025127979279204737, 0.04285794850147795, 0.03488180540443864, 0.031716011217213236, 0.05764253583038226, 0.01689249082119204, 0.009087080652534496, 0.00909074036826496, 0.012471967966121156, 0.012574304564623162, 0.0724908550910186, 0.036677001262432896, 0.02035697347309906, 0.012421292267390527, 0.036022653366671875, 0.008569543042540317, 0.043876197378267534, 0.0839791601174511, 0.04959830439474899, 0.05893647772609256, 0.04574462094751652, 0.018635682536114473, 0.03271029985626228, 0.052724623747053556, 0.05012896595872007, 0.04029177252959926, 0.016694662081135903, 0.024682751900400035, 0.03407722826523241, 0.04038713850604836, 0.009625105249142507, 0.027368200280761812, 0.025666695000836626, 0.06864103823318146, 0.0512367957708193, 0.04699577431892976, 0.062106175610097125, 0.04220635768433567, 0.00980898996203905, 0.04201729185297154, 0.015780013309267815, 0.021452761939144693, 0.013319459794729482, 0.02247713910037419, 0.08777517869020812, 0.03407728021556977, 0.022945957498450298, 0.04371906616142951, 0.005460931333800545, 0.028954173576494213, 0.033175003045471385, 0.07690499362070113, 0.03271725006925408, 0.08596218613092788, 0.02767457925074268, 0.03217520767066162, 0.014684097750432556, 0.02203768934123218, 0.011371295240678592, 0.04171263652096968, 0.020874129804724362, 0.04134375572903082, 0.013755034615314798, 0.058647752593969926, 0.02979592674819287, 0.0454430566605879, 0.025160015939036384, 0.033994348923442885, 0.018863640616473276, 0.05876883398741484, 0.05189239418541547, 0.03115634281130042, 0.058401849382789806, 0.061099879021639936, 0.11134916567243636, 0.02165678575693164, 0.026199191524938215, 0.09635191221605055, 0.05395632913860027, 0.045403826734400354, 0.03799504069320392, 0.03368463585502468, 0.0271746147700469, 0.0745970405114349, 0.02844436079612933, 0.06894030928378925, 0.026586820822558366, 0.006970346530579263, 0.021794372514705174, 0.021544252049352508, 0.0709118097438477, 0.06043320405296981, 0.03324560726468917, 0.04528306075371802, 0.02458535243931692, 0.03413021760934498, 0.0275790091836825, 0.08622438690508716, 0.05014697046135552, 0.049788401811383665, 0.014163212126732105, 0.03606867394410074, 0.04005119051726069, 0.0632861458871048, 0.04833421167859342, 0.03834064402326476, 0.016850713473104406, 0.020689984412456397, 0.026070514250022825, 0.028833585711254273, 0.006871659443277167, 0.06662820014753379, 0.04857170635659713, 0.045143143652239814, 0.04566576404613443, 0.03608091938076541, 0.07755475875455886, 0.031175482799881138, 0.03236788776121102, 0.05122691407450475, 0.061893461243016645, 0.02907198024331592, 0.05686086878995411, 0.04410761386679951, 0.0392178774200147, 0.06085633212933317, 0.03825497791694943, 0.025594317048671655, 0.026262851097271778, 0.045733626029687, 0.01605219968041638, 0.02247593682113802, 0.018018198970821686, 0.052453669341048226, 0.04838139742787462, 0.04157976611168124, 0.03869034400850069, 0.061313257610891014, 0.04117481323191896, 0.05097635759739205, 0.04711458474048413, 0.03748404975340236, 0.03213011848856695, 0.02059739963442553, 0.05646898513077758, 0.007317712461372139, 0.03971480095060542, 0.06444659768021666, 0.029141319100745022, 0.00909557638806291, 0.01683983915427234, 0.08090663162874989, 0.043851457885466516, 0.04165295300481375, 0.01951602924236795, 0.017818897067627404, 0.02510318412532797, 0.06435597402742133, 0.029614742525154725, 0.030131208659440745, 0.04435459690284915, 0.0406855115579674, 0.059427148662507534, 0.01782714418368414, 0.14366662449901924, 0.14515501650748774, 0.16017992980778217, 0.14266733749536797, 0.2331508876523003, 0.08027685995330103, 0.0928335459320806, 0.13007052359171212, 0.09743258313392289, 0.14975796482758597, 0.121266336645931, 0.13618985773064196, 0.12024059949908406, 0.1836525319959037, 0.1665623701410368, 0.10573387597105466, 0.1892209699144587, 0.10384157008957118, 0.14570462139090523, 0.07946903220727108, 0.17074575269361958, 0.14240552263800055, 0.22944993077544495, 0.08954304867074825, 0.16111965203890577, 0.10348797382903285, 0.1745627072523348, 0.15438549307873473, 0.1273342251079157, 0.15814729122212157, 0.10945383182843216, 0.15437599358847365, 0.12365338043309748, 0.14338588487589732, 0.2183863939717412, 0.17098050884669647, 0.08985825363197364, 0.12372178418445401, 0.08753054455155507, 0.2142906590597704, 0.09240120780305006, 0.10335666564060375, 0.0514802684483584, 0.09499828680418432, 0.1139706613321323, 0.1342091991682537, 0.11746386138838716, 0.2190639154287055, 0.13679151685209945, 0.08391805167775601, 0.1693353010341525, 0.262978455866687, 0.10024016490206122, 0.059488383267307654, 0.1635371832526289, 0.10569898018729873, 0.16334229527274147, 0.08337142280652188, 0.1400617609033361, 0.17684546444797888, 0.08794702298473567, 0.15468429657630622, 0.1886035327333957, 0.19775094813667238, 0.142574509663973, 0.12128696835134178, 0.16198438766878098, 0.11117369227577001, 0.16286307567497715, 0.14511563815176487, 0.11962360018515028, 0.09097359026782215, 0.1153799552412238, 0.14113462442765012, 0.13738418114371598, 0.16324439115123823, 0.09592272821464576, 0.10226653976133093, 0.11009517358615994, 0.17400943615939468, 0.12786794803105295, 0.1197962682635989, 0.14586266916012391, 0.08810239160084166, 0.11042741083656438, 0.20068173384061083, 0.17235575302038342, 0.13443482690490782, 0.16019435715861619, 0.23063303291564807, 0.1276612895890139, 0.12263525772141293, 0.12307676137425005, 0.19127021776512265, 0.14625505747972056, 0.09965181990992278, 0.13813631812809035, 0.11003318941220641, 0.10203639234532602, 0.1282373594585806, 0.09472724705119617, 0.11346162224072032, 0.17094853712478653, 0.1869186497060582, 0.18828457250492647, 0.12332208571024239, 0.16962439724011347, 0.11709164464264177, 0.1936489049694501, 0.18386401439784095, 0.16075479739811271, 0.08651694151922129, 0.15692665125243366, 0.1430990596418269, 0.18110053846612573, 0.11203491012565792, 0.10411637995275669, 0.23818704241421074, 0.10089591916766949, 0.1610239001456648, 0.12599306035554036, 0.13677317096153274, 0.06030551012372598, 0.16931924095842987, 0.11913148206076585, 0.13203623529989272, 0.1776044291909784, 0.23012843186734244, 0.1846186598413624, 0.11366324150003493, 0.09441227215575054, 0.08503570381435566, 0.16669447242747992, 0.1812468157731928, 0.15625304833520204, 0.1300758373690769, 0.13139550952473655, 0.15852814656682312, 0.16316146356984973, 0.07760109103401192, 0.1497842962271534, 0.17335443146293983, 0.08200277632568032, 0.14550487976521254, 0.05722743779188022, 0.15008556365501136, 0.19922068255255, 0.0962496739521157, 0.1263607500004582, 0.16102093155495822, 0.10174634619033895, 0.1377431134460494, 0.1065343564550858, 0.13780635927105322, 0.08117612771457061, 0.13790785538731143, 0.0845123412727844, 0.08163180638803169, 0.1194653743004892, 0.12635892431717366, 0.09133060782914981, 0.13172251463402063, 0.10593035956844687, 0.19280304957646877, 0.22066734032705426, 0.16154525888850912, 0.1640106734703295, 0.09338843490695581, 0.11284094187431037, 0.19182331074262038, 0.09352233319077641, 0.14705510751809925, 0.1869267094298266, 0.21046954847406596, 0.15534952806774527, 0.18387290532700717], [0.052161448693368584, 0.0180592286051251, 0.060443980037234724, 0.024402364797424525, 0.012570647631946485, 0.03410238336073235, 0.01583706405654084, 0.032175348678720184, 0.07081258459948003, 0.01213071918755304, 0.00999821349978447, 0.026940446769003756, 0.025903551431838423, 0.020447866154427174, 0.04030366173537914, 0.018829191976692528, 0.024619428149890155, 0.028050163491570856, 0.06224980344995856, 0.05142727168276906, 0.05846673906489741, 0.03707960895553697, 0.07656958739971742, 0.0640235809260048, 0.06260117326746695, 0.03348171041579917, 0.029436814475047868, 0.03847446809231769, 0.03446138245635666, 0.04891246346232947, 0.021535800842684694, 0.053948120985296555, 0.045406580102280714, 0.09680434028268792, 0.06298127162153833, 0.022652657025901135, 0.012812324312108103, 0.04740568845591042, 0.02500407957995776, 0.016274779045488685, 0.018047916419163812, 0.06372018353431486, 0.024473616540490184, 0.024634452929603867, 0.014126479527476477, 0.020901604111713823, 0.009780574982869439, 0.02260832112369826, 0.03127103060251102, 0.007418791583404527, 0.02204902750236215, 0.03483451575448271, 0.06118259138020221, 0.051584336106316186, 0.0761312898248434, 0.02161037740734173, 0.044940299849258736, 0.03199723694706336, 0.050535128539195284, 0.10673558979760855, 0.018250142384204082, 0.01948812077898765, 0.041302759491372854, 0.03340030423714779, 0.04859807115281001, 0.023391121794702485, 0.028439136076485738, 0.07737022373476066, 0.044483507954282686, 0.05841725265781861, 0.07170074983150698, 0.03733218778506853, 0.05762475026131142, 0.0438413906522328, 0.06464069156209007, 0.043360649651731364, 0.025838012370513752, 0.02193437125242781, 0.023000727996986825, 0.06557397195138037, 0.030312673043226823, 0.046322093476192094, 0.05696917411114555, 0.051888442249037325, 0.07906460625235923, 0.026983086863765493, 0.01221865162733593, 0.053545012342510745, 0.02315316698513925, 0.039390018573612906, 0.02961862581287278, 0.030658864525321405, 0.05292073627060745, 0.029349825490498915, 0.08009399476577528, 0.0126110353085096, 0.011756714793591527, 0.049460446753073484, 0.007796300305926707, 0.03469322567980271, 0.019433786292211153, 0.02607823258585995, 0.048070827178889886, 0.03182668770023156, 0.07856536351027898, 0.06183954050356988, 0.08138701639836654, 0.020875352493021637, 0.03520525562635157, 0.15182327275397256, 0.0069300748145906255, 0.01017409786072676, 0.05131594210979529, 0.023120798214222305, 0.03167811344610527, 0.034449270606273785, 0.031131896466831677, 0.04754051442432683, 0.046337986568687484, 0.008413215200562263, 0.03692399543069769, 0.06373559052008204, 0.028693791064142715, 0.0320768805249827, 0.052480772574199364, 0.026895366863755044, 0.016110833057609852, 0.02473996592016192, 0.02185021912737284, 0.08939153922256082, 0.0787034846143797, 0.05729529606469441, 0.0287618719812599, 0.0054765475124440854, 0.06134486939117778, 0.04603113076882437, 0.030039215744182002, 0.07537838842836209, 0.025319507185486145, 0.0603667447285261, 0.05722724112274591, 0.04806889017345384, 0.04752599801577162, 0.09850726492004469, 0.0645105040166527, 0.0427054260217119, 0.05266740787192248, 0.03726986593392212, 0.08095897530438378, 0.025910611111612525, 0.027793896188086364, 0.026683559772209264, 0.027974596159765497, 0.007968869122123579, 0.08729816327104345, 0.07421415168209933, 0.04357252910267562, 0.038723035613656975, 0.0692727840214502, 0.08782961522229016, 0.02794502528558951, 0.03175493315211497, 0.051479021640261635, 0.04015356236777734, 0.016746352666814346, 0.030391322143259458, 0.008643844084872399, 0.02084084633679595, 0.05672026891261339, 0.03690095545607619, 0.011013119928975357, 0.061264613541425206, 0.015322224153351272, 0.05052008891652804, 0.09159220746369101, 0.05835693089466076, 0.028904946921102237, 0.01866621449153172, 0.01606840261956677, 0.019226651020289864, 0.03125457347778138, 0.016846917387738358, 0.06654508702922612, 0.046593448641942814, 0.06345160029013641, 0.03768948736251332, 0.03382772934855893, 0.026891721063293517, 0.06057359241822269, 0.009103794745897176, 0.03531388007104397, 0.0615635506255785, 0.03528889938024804, 0.021930890579824336, 0.0194118651052122, 0.018473899908713065, 0.10138943995116279, 0.011360949702066137, 0.059978352874168195, 0.030428995414695237, 0.06525277785840444, 0.05101258553622756, 0.019062996325374115, 0.06066201189241838, 0.04163359779340681, 0.06230096711078659, 0.04233361374645028, 0.035924890253227204, 0.04131597343075555, 0.08458117546979338, 0.03589494830521289, 0.056086111144395545, 0.02892924483603565, 0.033903851435752586, 0.030419019094551913, 0.02946308464743197, 0.046087864247965626, 0.06657763762632385, 0.0068179080062691355, 0.030812136574240867, 0.03978121945692692, 0.023775109002599493, 0.05412921243987512, 0.012560851282614749, 0.04908469367364887, 0.05144586990354583, 0.037132268043933436, 0.0651921666576527, 0.023779840194038115, 0.03379928653885145, 0.08902810208383016, 0.021741791351814754, 0.047493974343524314, 0.00797942338977009, 0.050083453752449714, 0.03056734101846814, 0.032873694799491204, 0.02075146207062062, 0.046640523069072515, 0.032213049780693837, 0.041093384788837284, 0.04816904300241731, 0.11108390724984929, 0.025922407548932824, 0.022484868568426464, 0.07221272040624171, 0.06715642375638708, 0.018854458394343965, 0.028954173576494213, 0.08170429195160978, 0.041630209889262915, 0.0285100111796055, 0.07728776370640844, 0.003518708831506956, 0.03945609940274153, 0.04898225131910294, 0.08741254307096824, 0.05943734948232304, 0.07198166014859453, 0.029057736574031878, 0.04369974063592963, 0.007636693562744767, 0.06529495411086828, 0.012000449078186648, 0.09502494474872947, 0.07942282609292306, 0.025479753567196894, 0.03273709509812761, 0.023491979663958773, 0.06801449490012601, 0.05851064081070945, 0.034257603547303006, 0.01549217782667256, 0.009546254841552582, 0.008608917687524809, 0.04302066066884436, 0.01540154768008506, 0.0494305864413036, 0.03668776240374427, 0.07353428503847681, 0.03484718421532307, 0.07757864848827012, 0.019118644413538277, 0.05258661025436595, 0.039066620302037336, 0.11034423092496581, 0.04392204726173077, 0.05818034798721783, 0.06346266571199521, 0.015640558194718324, 0.04888305214990396, 0.04607295821188018, 0.031141477593337186, 0.02872627301258035, 0.02438066996546695, 0.014738057452632347, 0.011916435178136453, 0.11206368319108151, 0.047365193167934194, 0.032796978994156234, 0.03553394170012325, 0.07038158975774422, 0.014015023789397674, 0.05521095205040183, 0.04089682326593902, 0.05971020378638059, 0.07602062076330185, 0.010220148124062689, 0.005226395041972864, 0.03618856047978625, 0.07139101449865848, 0.060394200481823646, 0.12028106139041483, 0.024846857450029347, 0.05466132119181566, 0.037106125892023556, 0.03909126331564039, 0.03549025517713744, 0.06314794314675964, 0.01574833288032096, 0.048414604825666174, 0.033457698227721266, 0.05371956176531967, 0.046079667226877064, 0.04315127865993418, 0.021098343750054482, 0.045621487515745685, 0.034990593121619895, 0.023837538465159014, 0.010658186874934472, 0.04598741827066988, 0.06960103593883105, 0.04969967805664055, 0.01922899991768645, 0.07791970245307311, 0.05243721592705697, 0.013154087955626892, 0.09479607382672839, 0.05038670642534271, 0.042448064050404355, 0.036072952425456606, 0.009890949040709529, 0.04728834748675581, 0.026330030304961838, 0.10385389716248028, 0.05986474490782712, 0.007246968625622685, 0.05793622964120004, 0.05605563485005405, 0.008426187941950047, 0.10296831460436806, 0.044789966705138795, 0.13997115951497108, 0.16484640596900135, 0.11393177279387601, 0.07240507766255178, 0.0972820607421454, 0.10693101954529993, 0.16138269886141643, 0.13527668954338878, 0.12302146395086311, 0.13096558337565511, 0.08341552864294499, 0.10944165318505839, 0.10379411716712639, 0.06881242239614949, 0.13482182723237202, 0.15946582047035918, 0.2665643353248015, 0.11794533711508848, 0.1326965686166659, 0.16745403088862076, 0.23015733109787107, 0.05471889329783153, 0.14828955143457279, 0.1522965106414631, 0.17839480162365362, 0.10877777240239084, 0.08359549203305505, 0.12397367652738467, 0.08172082700184546, 0.12253069653525017, 0.1363312517059967, 0.14996413345215842, 0.12297925059101544, 0.1549396399059333, 0.14587259909603745, 0.10927396491752006, 0.05493023469171021, 0.13366511586355045, 0.22345400095218793, 0.2785334852524102, 0.08574872961617075, 0.1931819159653969, 0.08890230805263855, 0.16933864069869742, 0.17857244209153578, 0.08768893370870501, 0.19748444290598854, 0.1280804694397375, 0.1776805883855559, 0.14612872910220176, 0.08385455352254212, 0.24810822098515928, 0.133716739655938, 0.1384953543310985, 0.18391191260889173, 0.14151050738291815, 0.2554686338407919, 0.12605923024239019, 0.2358674450078979, 0.20357550121843815, 0.11063910846132785, 0.19369684770936146, 0.15555216406937689, 0.16264169302303344, 0.24977431283332407, 0.16605974320555106, 0.17590833973372355, 0.15174700965872034, 0.16155996825546026, 0.16887436795514077, 0.18585875892313197, 0.11553185060620308, 0.12237926130183041, 0.20078282919712365, 0.1764294906752184, 0.08199637901270762, 0.14373162179253995, 0.12497330491896719, 0.1311635586898774, 0.1534956877003424, 0.2143705586786382, 0.17480769020039588, 0.17041481420164928, 0.14795362571021542, 0.19719614821951836, 0.09040644101332873, 0.14312355051515624, 0.15668435487896204, 0.19203682662919164, 0.1656391384312883, 0.10436712196678855, 0.16465576307382435, 0.1589359121862799, 0.12619053100934252, 0.14961125707486644, 0.16404568799771369, 0.09754884798894636, 0.11349372754921205, 0.08039950727834366, 0.1393050522892736, 0.10175085844821297, 0.16459980513900518, 0.19674478884553537, 0.1308897210401483, 0.09306339648901485, 0.1400330546312034, 0.13447500678012148, 0.18409065145533532, 0.0793988918303512, 0.247642315516714, 0.1435440217028372, 0.1122386816132348, 0.22193673939909786, 0.1057619068888016, 0.23072691459674388, 0.11920488788746297, 0.1478740229504183, 0.14873863983666524, 0.17063046747352928, 0.15093245805473998, 0.09375391295179725, 0.23911508324090391, 0.2219547439017333, 0.10442346581839956, 0.11056768416892737, 0.0837166105338838, 0.1074852554302197, 0.1423860783688724, 0.193272769683972, 0.12290095401112922, 0.22847053332952783, 0.11974863722571172, 0.07495018406189047, 0.07564533152617514, 0.21926174231339246, 0.15230736084049568, 0.18682908732444048, 0.20355509215733036, 0.14072245045099407, 0.11744450617698021, 0.14814986439887434, 0.07453235491993837, 0.151670687191654, 0.15215890161925927, 0.14392438723007217, 0.11108680904726498, 0.16467572684632614, 0.10516814421862364, 0.1457879348890856, 0.1446406784816645, 0.09793981138500385, 0.15286456531612203, 0.05848321845405735, 0.042738217816804536, 0.27702345221769065, 0.19572461780626327, 0.12231250511831604, 0.2410608608624898, 0.1551161374663934, 0.15400371747091413, 0.13754360930761322, 0.12918475549668074, 0.14592784456908703, 0.10369814262958243, 0.24448064767057076, 0.09985606637201272, 0.16194161027669907, 0.12096263497369364, 0.17651701957220212, 0.22782381100114435, 0.18887173006078228, 0.13661423261510208, 0.12049166805809364, 0.24397151952143759, 0.19891704025212675, 0.10774144480819814], [0.055738303635735065, 0.034610468792379834, 0.019452987507975195, 0.01708757918095216, 0.007765401451251819, 0.09617450923542492, 0.01590340649272548, 0.07493221666663885, 0.06597730694920756, 0.05976384250971023, 0.018966470743180253, 0.08193754154490307, 0.0754189987492282, 0.07634252731804736, 0.008506214653607458, 0.0360501796239987, 0.12017495653708465, 0.005461593700601952, 0.05370095241232775, 0.05304500518832356, 0.08453289134195074, 0.08441661164397374, 0.027756495655921753, 0.03402003465453163, 0.028995307111472357, 0.0036881316373182926, 0.028547890397021547, 0.03325707344629336, 0.03539173507306259, 0.03497824007354211, 0.03546832471329253, 0.026522432090132497, 0.053179831156739965, 0.011421174986026017, 0.0620556316425791, 0.06545093128806911, 0.05013197165681049, 0.04162784985965118, 0.021387005799624603, 0.056848274543881416, 0.04422371544933412, 0.023690249981882516, 0.06310413416940719, 0.10214430803898722, 0.02378671804763144, 0.057373826421098784, 0.04339923762017861, 0.025180660632031504, 0.030401717776840087, 0.00721379833521496, 0.027277120207145344, 0.12785409955540672, 0.04723503159766551, 0.007930116953502875, 0.04512520223215688, 0.05093578438390978, 0.04281887813704088, 0.0403031162568368, 0.06076026853406802, 0.04813734587514773, 0.011147724180773366, 0.025203650511684828, 0.03281069759395905, 0.017453502514399588, 0.0429383861774113, 0.030127856007311493, 0.08531630985089578, 0.05882648030819837, 0.07483319932362065, 0.04956689299433492, 0.08807017497019842, 0.018227890941489022, 0.019075514501309954, 0.07253888688865118, 0.02341622493986506, 0.08333329125889577, 0.05110137237352319, 0.0680830619239714, 0.021401089907158166, 0.016307990154018626, 0.07785597423207946, 0.08417879784246907, 0.012115089557482861, 0.037117072570254095, 0.03277059935498983, 0.03950214966607746, 0.0443683748744661, 0.017340562480967492, 0.053406156512210146, 0.026878624012169894, 0.041453760568401776, 0.08366151349036954, 0.08113657124340534, 0.05471588759974111, 0.04242703158524819, 0.04263233560777735, 0.09739912711665966, 0.011132979561807588, 0.07177288658567704, 0.01118344003771199, 0.05550553272769321, 0.020280114804336336, 0.004084553065695218, 0.04027790550026111, 0.0168983649200527, 0.05699465575162321, 0.04781945805007126, 0.05692081947927363, 0.03815812022367027, 0.06251602666452527, 0.03917987574823201, 0.061370911353151314, 0.02917563044320559, 0.028642150573432446, 0.06369101713062264, 0.06763332785340026, 0.0482784207270015, 0.04110197514819447, 0.05740410975704435, 0.045219388193800114, 0.021587786432064604, 0.02743574314081343, 0.028503864341473673, 0.044344488851493225, 0.034327936882618815, 0.0236056878202362, 0.054311086860252544, 0.029787770545226522, 0.06147596606751904, 0.05562470309087075, 0.028556508586916607, 0.07277437776792794, 0.0653670092287939, 0.04660112244891934, 0.0667605918715708, 0.05849654000485316, 0.04839637396798935, 0.022965175412537064, 0.019644118365249597, 0.04794187159859575, 0.06097270088503137, 0.03143946472846437, 0.03618205555540044, 0.08876907028025016, 0.014835935598966898, 0.07154192280722782, 0.01868869600002654, 0.00939150220801821, 0.025383886641066056, 0.02156066650059074, 0.05356926943932194, 0.01730252926790854, 0.07448174786986783, 0.030925345636205748, 0.04302432316762861, 0.022469515388365835, 0.02181962594477227, 0.0391597598354565, 0.05959764224826358, 0.013203292346588569, 0.04014973288576584, 0.026941866126435343, 0.044898353662574664, 0.030101567281235475, 0.08729086795938201, 0.058408276381669566, 0.07457203755620867, 0.015224115013552364, 0.049585936503717676, 0.037425357004394755, 0.0344405911891954, 0.02403432077699108, 0.01944627849297831, 0.06253101804759353, 0.072797161701601, 0.04512738043558784, 0.03840452809527051, 0.025718105425767135, 0.042793311149580404, 0.05279776611132547, 0.01657711145526264, 0.053169021775829606, 0.07934400258818641, 0.036264422815293074, 0.011454477935330942, 0.02246845411718823, 0.01787485871318495, 0.058924087570630945, 0.012393870838423027, 0.014703561500937212, 0.011208613686903846, 0.02240039175376296, 0.07195817117462866, 0.04120149715163279, 0.022667427620035596, 0.040793408697936684, 0.010250507530145114, 0.00943809423915809, 0.06722482750774361, 0.012534165507531725, 0.08803126416751184, 0.03750769086764194, 0.06286397518124431, 0.04068253554578405, 0.051421609095996246, 0.05164723683265038, 0.07594948590849526, 0.02312710461410461, 0.03682753478642553, 0.03754916207981296, 0.033751154551282525, 0.01613785465451656, 0.04118384516914375, 0.03684740579046775, 0.031172016970231198, 0.07301541249034926, 0.009237524191121338, 0.025407145549252164, 0.039051287531037815, 0.0251334544736892, 0.009404653992532985, 0.05445944960229099, 0.038260985602391884, 0.053836323859286495, 0.025289359291491564, 0.0635971428710036, 0.0900593533879146, 0.033182621191372164, 0.021563527479884215, 0.0338772899704054, 0.015272118052962469, 0.016500917008670513, 0.029058855361654423, 0.05074938657344319, 0.011371043838153128, 0.04168582643615082, 0.03355522014317103, 0.06912544544320554, 0.06276835687458515, 0.03186698260833509, 0.09191012126393616, 0.006644510767728207, 0.06399448873708025, 0.03533201444952283, 0.05394187581259757, 0.051124764868291095, 0.05893487839784939, 0.043256244316580705, 0.019167368263879325, 0.04945737797243055, 0.04022091598017141, 0.04437918796611484, 0.06148614462290425, 0.010404698914499022, 0.027571550599532202, 0.0241712470233324, 0.10770605920697562, 0.00984275675364188, 0.0538473892811453, 0.051748001933447085, 0.0291567279418814, 0.027496790353325196, 0.022293181100394577, 0.05868431820999831, 0.06868999029393308, 0.03462621716607828, 0.0489801584626548, 0.020859745127381757, 0.07952638537972234, 0.05867598760232795, 0.03762685380934272, 0.04609539704688359, 0.05960396534646861, 0.07337301634834148, 0.034904800850199535, 0.02363990824960638, 0.0580122404062422, 0.07110892416676506, 0.014397986833500909, 0.05832148221088573, 0.031219970842357725, 0.0440286938828649, 0.04020311556814704, 0.050960342050530016, 0.02837686988641508, 0.032632177681080066, 0.03968315206293482, 0.07447771058650687, 0.034994322413695045, 0.003150273560095229, 0.0629621538973879, 0.05140078443218954, 0.037358741828938946, 0.01329336031631101, 0.024558195400459226, 0.02145723337889649, 0.02848314728908008, 0.013751160604442703, 0.005032807675888762, 0.03182779350026976, 0.06016873230691999, 0.02993392168718856, 0.020815861935261637, 0.03464906789304223, 0.08355945334187709, 0.023074503042153083, 0.013892837523599155, 0.047491703371633776, 0.02981172892759787, 0.0491289961792063, 0.03202309337211773, 0.06065221183234826, 0.045931252534501255, 0.04390427653561346, 0.06062437387299724, 0.04189897867036052, 0.05052079395682085, 0.024978874389489647, 0.08253182371845469, 0.020348694815766066, 0.034084423386957496, 0.05233486263023224, 0.054380217916332185, 0.061621096756425686, 0.026119943140656687, 0.01823609167331597, 0.03381368791451678, 0.005011573903175304, 0.014098536739766132, 0.039086702818167396, 0.0300904740288388, 0.03038461127289338, 0.03848567823297344, 0.02341725838050479, 0.06622580025577918, 0.034303549909964204, 0.05529863679839764, 0.06249460086110048, 0.012948789499205304, 0.005510823139047716, 0.059688763140002266, 0.059519668502616696, 0.05863611942913849, 0.046350818302016705, 0.1142010091280099, 0.011916995499632321, 0.011578111389098922, 0.007727076017545187, 0.014225820632418618, 0.03986482981417794, 0.045485225491574965, 0.03170205141941551, 0.09822015766985714, 0.14086578885326162, 0.11134958869661205, 0.15761416201712564, 0.06937792408280075, 0.22661584691377357, 0.09872052105492912, 0.17369218287058175, 0.16313390020513907, 0.12002599265542813, 0.10510863139643334, 0.1707709560287185, 0.13751793099800125, 0.14608222612878308, 0.15440719347679988, 0.0956335874798242, 0.1295101278810762, 0.09009680215967819, 0.14286661898950115, 0.11457071741460823, 0.15589294343953952, 0.1433613643166609, 0.14760210004169494, 0.1542800190509297, 0.2850262977881357, 0.1039448993105907, 0.1516772180912085, 0.13816557358950377, 0.10261871851980686, 0.10793075183755718, 0.2031282681855373, 0.11948602827033028, 0.18644343770574778, 0.1394116395385936, 0.19746041216421872, 0.12065358241670765, 0.11261243460467085, 0.07566073851194233, 0.082056715618819, 0.15581849118461832, 0.13745820295298472, 0.13081935059744865, 0.14222421596059576, 0.21269615477649495, 0.16846859129145741, 0.2679054258624092, 0.2553260821150616, 0.16065520117990673, 0.0926946010440588, 0.13613300921861082, 0.15298265585443005, 0.162866608297918, 0.1260881294729188, 0.10563085103058256, 0.2506878966232762, 0.11375264060916379, 0.11855284436023794, 0.19052743184147403, 0.1853921261499636, 0.16894206666620448, 0.17785953503334895, 0.14369507844094187, 0.14158571662846953, 0.06205693782249, 0.2367183766909875, 0.10941844622720964, 0.19550498662283644, 0.1909610242000781, 0.1250274816993624, 0.11992723506409675, 0.2118875551968813, 0.15576749079627916, 0.1349400365143083, 0.11567138179088943, 0.1319250467349775, 0.1424952334491536, 0.20035171561175957, 0.17405160499038175, 0.06839631503680721, 0.10698870668420568, 0.1766510069137439, 0.14092474506469443, 0.128158216830343, 0.18001127347815782, 0.09783451547264121, 0.1998837321298197, 0.12962529435753822, 0.13928109576227143, 0.10943104047328234, 0.09487971386988647, 0.20655326487030834, 0.2129484256147407, 0.16163004183908924, 0.15221027308143675, 0.13755895692156628, 0.19259248743765056, 0.16912163671804592, 0.16138640959979966, 0.19792198349023238, 0.10382231877883896, 0.15798517648363486, 0.15219256543787196, 0.15076388663146645, 0.0707689685805235, 0.0867941188334953, 0.15289874863810837, 0.12110992902307771, 0.18791949521983042, 0.1391530901310034, 0.13809590076562017, 0.10951534102787264, 0.15223037044052035, 0.1201011128432583, 0.1568857440724969, 0.2786222461145371, 0.15461232309462503, 0.12866470293374732, 0.13451644830638543, 0.12844928714912385, 0.12214469068567269, 0.136614425573498, 0.1622564738499932, 0.10275839071255177, 0.13295520708197728, 0.10677213314920664, 0.13400488591287285, 0.13950115739135072, 0.1204187075200025, 0.20672296435805038, 0.14337219967273995, 0.1072010573989246, 0.1821542694233358, 0.10342777080950327, 0.09716788132209331, 0.16599244525423273, 0.1778847086825408, 0.1120047715085093, 0.11341051053022966, 0.08085271460004151, 0.15307567664422095, 0.12374786325381137, 0.08358526523807086, 0.1647370876162313, 0.1906106562819332, 0.10883295850362629, 0.18998000887222588, 0.1207571491249837, 0.09638314921176061, 0.1086425753601361, 0.11278542180662043, 0.13882497180020437, 0.10003338029491715, 0.1482262313948013, 0.12099960134946741, 0.106060777179664, 0.1575997643521987, 0.17367337684845552, 0.12171668669907376, 0.2510991948656738, 0.11191340570803732, 0.1575822793529369, 0.20773783646291122, 0.13076161150820553, 0.10862318304134533, 0.1090531908266712, 0.19995062932139263, 0.17370129644405097, 0.14497563941404223, 0.17854376550531015, 0.0921985792228952, 0.11334684168105014, 0.11579523139516823, 0.1401145721320063, 0.1098341825127136, 0.1810424728319049, 0.10697188961785287], [0.007412065870084916, 0.08602986257756129, 0.059415868017822504, 0.0704023327853065, 0.06938409132999368, 0.044848173347418196, 0.0770363537594676, 0.07143937284126878, 0.06590984572540037, 0.009630964505049633, 0.04447539999091532, 0.04259810033545364, 0.014108877639955608, 0.10164142877329141, 0.02549200456996914, 0.003977690294050262, 0.008253563464677427, 0.04898660772596486, 0.031952570789144374, 0.019443391538516153, 0.02921947652794188, 0.042818388319574296, 0.11877872442710213, 0.029185655002947897, 0.009103625907300739, 0.019984014579677023, 0.03245820713345893, 0.0815015817352105, 0.08449150176602416, 0.03625183227995876, 0.07333181973081082, 0.03718216634297278, 0.025570950529072434, 0.02836773775925394, 0.03645227523520589, 0.015494809667870868, 0.015220261411741376, 0.05056167887232732, 0.011436457662057364, 0.06379700324032456, 0.08304839560878463, 0.025456592993577942, 0.023533705061709043, 0.03017397491930751, 0.06908133960678242, 0.019043316424358636, 0.0361061078729108, 0.07022475168923847, 0.057755639136303216, 0.023644964130653534, 0.024261284379463177, 0.054832408495713025, 0.05613063258351758, 0.025967335313907824, 0.07948639846290462, 0.03872725472319871, 0.02642980278324103, 0.10283376323059201, 0.03852157220535446, 0.09572173235937953, 0.020199667851557024, 0.04755460780870635, 0.021287695308274124, 0.02585445650765905, 0.01238615064721671, 0.014441946095757885, 0.029429675014398526, 0.0417695110081695, 0.1072817733802367, 0.03365683129231911, 0.024370498831558507, 0.03502219005895313, 0.03278997683082707, 0.02724651960306801, 0.06000799054163508, 0.03137433755910024, 0.026024291437352076, 0.048136002587853, 0.03850306304229889, 0.031067977142811287, 0.06411320267943665, 0.012205664042994613, 0.08929937932407483, 0.0805578741710633, 0.028179781438666396, 0.024792984950181562, 0.051183071700506844, 0.04192660882836208, 0.04143322163145058, 0.13187655480578542, 0.08065951129538007, 0.04498411624808796, 0.03651708328106906, 0.056034895533230156, 0.0848817898076959, 0.044139396341051906, 0.028758996159012895, 0.08519335082382895, 0.067458232952049, 0.0383577431057347, 0.06832652346929535, 0.04392981012642849, 0.02855689079297008, 0.06409213310689665, 0.04287761912564747, 0.02396399486315204, 0.038942737301113084, 0.010850182334252167, 0.06259611924178898, 0.02614584780531004, 0.020051434985361993, 0.03489017311949283, 0.04277268315490801, 0.06492921631434001, 0.04929172318952624, 0.0032026673306972953, 0.011749903733289102, 0.043061248725280166, 0.04347308131400496, 0.023065510067681316, 0.04207300858979579, 0.05868650754564442, 0.08250578175648116, 0.0012320005112087529, 0.03354585795023013, 0.02491630020813318, 0.12743750237859786, 0.009149364468612475, 0.014399695628526388, 0.0350437754241284, 0.04148094914853573, 0.06090424518333748, 0.031672977784182876, 0.008010903438844252, 0.06374451113515534, 0.018820538534782827, 0.11918368472834118, 0.06895120401168242, 0.026594164373818785, 0.04399348639708478, 0.025305677263531834, 0.07805735600413755, 0.028949221596121788, 0.004237903040120727, 0.08995439886348322, 0.035218157863710076, 0.011827260568679776, 0.009810662577365292, 0.04960753671184648, 0.02210936596384272, 0.013593808598670876, 0.027939579777012113, 0.0038916851190151647, 0.0499828667670954, 0.03770700946915895, 0.02940691148978658, 0.021577997504209634, 0.08874388178810477, 0.026662562559067737, 0.048540413699811324, 0.018067277196678333, 0.03990344004705548, 0.048112632357515395, 0.019876134138030466, 0.04891650074569043, 0.0633105551241897, 0.04472059816180263, 0.036002741544507444, 0.032101987380883656, 0.036696634779218584, 0.03682750138978008, 0.030367484359885566, 0.06411991169443354, 0.05503539330675267, 0.045148950957809575, 0.01808316657843534, 0.05419827670266386, 0.04934091273753438, 0.020793322910321876, 0.11030596579075791, 0.04525288131844718, 0.007634612302354071, 0.05531617745873518, 0.02393093589489581, 0.015376652336271945, 0.03312132721475791, 0.021223022704361938, 0.015588103196932934, 0.007727679940217058, 0.04598896935931407, 0.027878298787982203, 0.017962847741728183, 0.05488763170433231, 0.06079624785343185, 0.05594961534370668, 0.037012426037108526, 0.024393783714913297, 0.052008410420967266, 0.10361620210460387, 0.07428385419188999, 0.043353042638045736, 0.022487931782961823, 0.0402543163363589, 0.026931117972708307, 0.030269196176959667, 0.018824369872163516, 0.047475212850258686, 0.02931665520009119, 0.05855555187736172, 0.08447176063782535, 0.05147188960108906, 0.04312644639867358, 0.015115092592168367, 0.07635493602720089, 0.023500829775002785, 0.006288085533014964, 0.022842821235826705, 0.05056623194832355, 0.03301586431916803, 0.06055562502297107, 0.047243929948308505, 0.02302148030139506, 0.035914941763621755, 0.02334321801754413, 0.07851055590435863, 0.011674344750645105, 0.07763425761368126, 0.033504828315926716, 0.04117122865864076, 0.06229146019904874, 0.04637060024833772, 0.0018404432103125146, 0.021421530509542208, 0.07943143500597216, 0.04631283518392593, 0.1037826064566616, 0.06627490074606612, 0.05698766100977082, 0.030312099734146614, 0.017447622849431355, 0.03376800872501917, 0.007090214048730559, 0.039603111436008476, 0.04231809914926998, 0.09622936137020588, 0.017345980159007013, 0.012473312181100482, 0.04517818786553107, 0.019195590284653008, 0.01976886225747876, 0.07015904935542494, 0.0336603305186145, 0.02156262762582628, 0.09424696618225425, 0.03938766967621632, 0.024314370202773716, 0.07273986790096387, 0.0574878462794004, 0.08339425126905553, 0.047133991902228445, 0.061272966413525864, 0.004257159916960518, 0.012261741649126634, 0.05142803238413762, 0.068972986045992, 0.025431358117202763, 0.06179386873554904, 0.014336040694615804, 0.016870165163709316, 0.0593756324815331, 0.06720401768689044, 0.021427944520837627, 0.061009496566839516, 0.03810068541497458, 0.04315224345191382, 0.060738942920579575, 0.08523036172846332, 0.022501318271679338, 0.09102398951654322, 0.059483622389961965, 0.0233128159379703, 0.01909876042191172, 0.07583013371913694, 0.02008449209824903, 0.03835974319372326, 0.025755776841833722, 0.02541530175221851, 0.037380531284725294, 0.06728010266670026, 0.046064464331720956, 0.030464809606201015, 0.053917195691610686, 0.05673640320310369, 0.08682082872837782, 0.01749329090671381, 0.025230091378034558, 0.018836179297068156, 0.06659656239207834, 0.03138441221381072, 0.022798333193350118, 0.051099654301651753, 0.030123345604806673, 0.01475060995289823, 0.08835274769808166, 0.013276071058498928, 0.04859490960370749, 0.08895226201275364, 0.038662272272631526, 0.017306624067714438, 0.014365146798809292, 0.011513339522934984, 0.04200312054308597, 0.07710793390288018, 0.017780349917302374, 0.059539027424762025, 0.015317966081056511, 0.08638362211058848, 0.02800415961246472, 0.05438674139440991, 0.01884622426587157, 0.06546109871123917, 0.0478315550572006, 0.032732875988585874, 0.051268997558509, 0.02493848300218815, 0.06419003722839989, 0.013307169829204213, 0.04620634070306551, 0.019054489457630552, 0.025039294487214647, 0.06313685546047054, 0.04380046120786574, 0.0013433811068352952, 0.057382479863008484, 0.03990320998127572, 0.032060616358648986, 0.05214797129156068, 0.030675366178911645, 0.019324265704199206, 0.05101373957586475, 0.04441349003172945, 0.05101020695292391, 0.07199524887255393, 0.029466888154274784, 0.05440403343527578, 0.027216449634579476, 0.056409197713946924, 0.041686947079142556, 0.03483835265797097, 0.04993350652512163, 0.10742648475570604, 0.040142010839190334, 0.14681598753668368, 0.25526855082716793, 0.1414087144075893, 0.2558537491131574, 0.12577780784340575, 0.09391817991854623, 0.15057018608786166, 0.16763705934863538, 0.09199456282658502, 0.11599799356190488, 0.12738310295389965, 0.1381146177300252, 0.07680800234084018, 0.1646273091319017, 0.09573151386575773, 0.1328952712356113, 0.09955116242053919, 0.24134188250172883, 0.10780604876345024, 0.1271206498495303, 0.13894142961362377, 0.15422330412548035, 0.2583194011822343, 0.13787371659418568, 0.1440623524831608, 0.1344069666811265, 0.06949143556994386, 0.11496373655973002, 0.14478352706646547, 0.12293694817344658, 0.11798549472587183, 0.13980738236568868, 0.12669130257563666, 0.13846094836480916, 0.15548755269264802, 0.12177072247141041, 0.1510168402455747, 0.17715918511385098, 0.14955038612242788, 0.13804243644699454, 0.11209861608222127, 0.0976712058763951, 0.10782113662571646, 0.0929537441697903, 0.10260094408295117, 0.11593206116231158, 0.09180178254609928, 0.16623027389869094, 0.12980067869648337, 0.08797397778835148, 0.16158039215952158, 0.1979831513017416, 0.20458403538214043, 0.10898167747654952, 0.1704150516889058, 0.16448778536869213, 0.0489776351605542, 0.18229361507110298, 0.12379322331980802, 0.25695420568808913, 0.23491633823141456, 0.17119242169428617, 0.16016554698580876, 0.08423655919614248, 0.1292901998385787, 0.13746685639489442, 0.14979499799665064, 0.11130182407214306, 0.2850657800445333, 0.11846307417727076, 0.08427883192780428, 0.15247348317643628, 0.09098061840631999, 0.12674295605393127, 0.15475048130610958, 0.13126371894031763, 0.07575021183583885, 0.19375463132746518, 0.22982878232141957, 0.07207171234767884, 0.1901122447452508, 0.18129176023649052, 0.21309161558747292, 0.23902041488327086, 0.13165824464522302, 0.09202758097671904, 0.07600308381370269, 0.12309610916418023, 0.1104837324237451, 0.1823622192023322, 0.2023034155718051, 0.07979559944942594, 0.14207137806806713, 0.1494851810275577, 0.233506791992113, 0.10269250284181908, 0.15166503202635795, 0.12367454648483545, 0.09625273902202025, 0.08539661765098572, 0.20274079288356006, 0.15433305292390287, 0.16677953739417717, 0.11905063991434872, 0.20511746144620702, 0.1005965590593405, 0.10725343818194233, 0.07070077263051644, 0.18902701704064384, 0.09816874167881906, 0.1158854023378808, 0.11506552211358212, 0.15452507621375844, 0.20150842698058113, 0.05949768237769604, 0.13097006594762206, 0.20526001317193732, 0.13958111638203263, 0.16935979190748185, 0.07575017472845502, 0.11995336608379148, 0.13439947098959237, 0.21868595445994288, 0.09097134898183867, 0.1203939865808934, 0.1317379216197878, 0.2287677486310713, 0.14962044486310333, 0.16394684877013788, 0.0943581250612624, 0.1262512238463387, 0.1702921075047925, 0.10819964678375982, 0.09327737250714563, 0.1675482391146943, 0.08683996871695854, 0.12995039956877008, 0.13091795233776793, 0.1392476397450082, 0.14075826649786904, 0.17316234880127013, 0.12409793431288563, 0.10673604250769131, 0.0799727278354112, 0.2187363017583266, 0.11206339375348762, 0.19398150587221608, 0.1293289547902532, 0.1592032634653151, 0.16865037294337526, 0.11140398812131025, 0.0979342007485684, 0.08230128296418115, 0.1126343799114693, 0.12922220426844433, 0.11804811714682728, 0.0913979799952358, 0.15738535788841546, 0.1102061098208651, 0.18705896014580503, 0.10135740143596195, 0.0632212747586891, 0.18828672473318875, 0.18378959182882681, 0.20313907385570928, 0.1344284147489816, 0.1399131680955179, 0.07103663898305967, 0.15956442221067846, 0.1568468555342406, 0.14349069097079337, 0.21932676929282025, 0.18320439354283735, 0.1555951641057618, 0.1454241044120863, 0.16346559568773955], [0.03217590528947767, 0.023863270580477547, 0.053054296877235174, 0.04313788660510909, 0.031008176738396287, 0.03555293696990702, 0.03596313683374319, 0.041748582443688065, 0.06381860715919174, 0.03972248960053548, 0.04296540777431801, 0.027412283852754626, 0.022169227595441043, 0.06314969461527653, 0.04871176075539552, 0.04974463736289181, 0.04840475281525869, 0.015141443473112304, 0.028179608889331575, 0.04687386543082539, 0.022900415606272873, 0.07720055393292569, 0.014035635085747344, 0.03789949289057404, 0.023644906614208594, 0.02764623292023316, 0.02400053635938093, 0.012640351997106336, 0.020281213182897773, 0.018575243884697556, 0.019850212775054388, 0.03841109610220883, 0.03298834177257959, 0.04806640397873707, 0.016602975301793776, 0.013038912202318897, 0.0302298827591585, 0.03456302700215019, 0.046833006490487605, 0.014630805981141748, 0.07324702193727717, 0.03289057865913492, 0.02730974130827235, 0.04710501103545539, 0.06112588758696802, 0.050751746603054926, 0.0867385913443286, 0.04860338864091318, 0.05542485014302656, 0.044590206525754184, 0.02612824220705079, 0.017700173848425038, 0.021001079730922356, 0.031024680247355718, 0.055788509926060215, 0.031848992948653176, 0.029299103407538496, 0.045665979268960655, 0.004348638894953183, 0.017689958185655996, 0.06897186540300027, 0.02060398805042496, 0.009116622768488014, 0.057884546476998366, 0.024894674024835695, 0.06339963510981761, 0.055690000954200514, 0.030777110914641526, 0.037702437839470804, 0.0518657399516087, 0.07816101919161156, 0.013156206787243718, 0.07377374640782364, 0.019811513484455645, 0.04543700073554646, 0.02402961556072114, 0.07835923199309036, 0.02984466544148745, 0.09608453125110827, 0.028258128113520797, 0.04874559526797384, 0.030073866619204637, 0.02320377589057898, 0.023401220569212455, 0.042668170208344236, 0.050495642572059296, 0.02996667637489736, 0.01569873700645985, 0.028383506542013492, 0.059153626425541006, 0.033665429073153064, 0.02464306184265297, 0.048107778711710125, 0.04389899244415574, 0.024390037724515423, 0.058174652003799565, 0.03952582788770087, 0.038185130688361824, 0.018030891551461536, 0.02948973331513116, 0.06300487191765569, 0.041299078438896686, 0.05830203052028082, 0.03000113614689326, 0.031928094758768566, 0.01375141571770655, 0.05367968988139182, 0.060270139365457, 0.015255752769007813, 0.038008636838640086, 0.008147087537508924, 0.060662709511234425, 0.027103183056169655, 0.04697327240137383, 0.03432531710132025, 0.035296294881845824, 0.020251631176506635, 0.0071831369677965995, 0.023315348516916856, 0.019393381917325314, 0.04530080550466664, 0.024993260922201443, 0.1003945613047108, 0.03103176219156012, 0.05281129175273236, 0.031475021023652516, 0.012419687373039778, 0.02973733233375242, 0.0324263875518227, 0.011088904338976135, 0.0457844854099676, 0.05548121625906788, 0.086996339232428, 0.030206091360014398, 0.06007652045809664, 0.042553757011773996, 0.05515658973308746, 0.02673211849469226, 0.08154144990839995, 0.03184422464983072, 0.036435079673537984, 0.028394733380991966, 0.02926329107140191, 0.03248611930757761, 0.06309528776910156, 0.028386228368617594, 0.03310344887722749, 0.05900686672248412, 0.030327441781992093, 0.04423583101015538, 0.08189115731511265, 0.017769481164577883, 0.030613478484156076, 0.006244340102057322, 0.057880883978214115, 0.030699144590471406, 0.04859587068494875, 0.03833912262052763, 0.0384406929515535, 0.04684687351982575, 0.018714147954597138, 0.035727679351111874, 0.048976792822941206, 0.027303605602355674, 0.11448323304648511, 0.032165170123334974, 0.06248183592106216, 0.03269252541940659, 0.07194591089501046, 0.05929051185376011, 0.021402279198809993, 0.0713220912439283, 0.01573571265907958, 0.02904757100623101, 0.07015996219706722, 0.016750412214605603, 0.031328313270932995, 0.03823286191618536, 0.0035673807315106387, 0.03173046454321593, 0.007586631527374266, 0.03336945315822959, 0.06230957602383569, 0.011960689444094896, 0.03191649499058258, 0.06391303802956827, 0.01288623016080237, 0.06375566561473534, 0.08719262244994752, 0.031244391211657785, 0.037443970068125054, 0.03864560363581404, 0.02188648602896137, 0.05077339505078271, 0.03627689089626074, 0.04628129019693006, 0.020919013040838763, 0.04377102020953316, 0.021124294798937626, 0.01709547377686249, 0.1218851468001958, 0.012397468399285572, 0.010397823843959486, 0.016788987195468508, 0.05317135954101104, 0.026983283532899804, 0.04881677094090264, 0.03732738237886224, 0.01962562218977837, 0.006989361281739548, 0.01911792453029193, 0.06039492036506999, 0.08628723939182237, 0.11468695258372463, 0.040185311445384286, 0.04435008464497514, 0.06735349365044385, 0.038601553460466675, 0.04587399584124796, 0.06307967298198491, 0.07324604972382076, 0.04552755388431251, 0.05947966674284544, 0.01852046225394588, 0.03332178501295857, 0.06060815794626251, 0.03314550638606306, 0.023523860472778324, 0.007586740066471975, 0.061080965388100594, 0.0361687191616511, 0.05217806166911032, 0.008875950770743657, 0.09205273978295736, 0.014771479145565536, 0.02964063976833131, 0.026664690667530522, 0.03540384321240708, 0.01017984115605941, 0.03672405713587068, 0.04531610487902071, 0.04107624859898351, 0.09708817466162145, 0.03273861650086474, 0.013198636297602206, 0.010804928951984039, 0.0717978598549962, 0.03840789744572248, 0.06018345651682466, 0.03182737789757084, 0.03850234315905254, 0.02597233553387923, 0.06782431955798529, 0.04876542545389384, 0.06195508918608539, 0.05932018662861083, 0.04642812411475461, 0.061650233474210836, 0.01930288999574259, 0.031899518362479284, 0.06928722621523775, 0.07108287478331476, 0.024300931763718836, 0.045725332529400475, 0.041908277780748904, 0.05036005961301271, 0.020979329237889033, 0.02858034822565969, 0.058803028441616334, 0.06030761040165089, 0.02064039967081044, 0.03120082343230024, 0.062288662302307785, 0.026312009104003664, 0.03238512414100114, 0.0056402216887363466, 0.09444494149647653, 0.02313868397322949, 0.015579885766783264, 0.04574332961055916, 0.03747034599655308, 0.03590682266803924, 0.06771275991923176, 0.04097702716535423, 0.018844760379579384, 0.010122483345185174, 0.08244927463238128, 0.06297497820924036, 0.033602071925997734, 0.02305673602677416, 0.037356548782554455, 0.03000197291839868, 0.03500995575450361, 0.07384938609902747, 0.04593469238898251, 0.02306305726961, 0.026191686556558125, 0.0600655515154358, 0.09717253458802588, 0.009017041393235559, 0.018947067292174324, 0.05362336458347272, 0.033086409166571684, 0.06995318501139991, 0.030052221882215235, 0.023175605820142664, 0.024931742445915006, 0.05042697906901594, 0.028963669356016908, 0.015799843495187815, 0.036573041215888225, 0.03837243020825554, 0.02921360057371203, 0.058901114389300346, 0.015475943346245913, 0.0233059102538391, 0.04555600411549676, 0.012242460652487352, 0.04587027768138796, 0.012631178124138387, 0.024815516553644557, 0.03644672397058457, 0.02798493798763957, 0.031205832929117605, 0.031714289434603415, 0.046151677815942094, 0.057601483931648545, 0.046357349201571196, 0.05663225019816309, 0.1594459160696715, 0.011180061410414055, 0.031174009636742994, 0.035820770644932054, 0.019429600579314865, 0.026374069348094054, 0.03685234107251745, 0.007838908859412186, 0.056142180401366204, 0.048488990287296474, 0.09816504578338936, 0.020504510575847235, 0.06666938192211092, 0.059038972030975856, 0.04545406642137095, 0.09153553706710227, 0.01731914780975785, 0.00689742031681817, 0.028289951405895408, 0.011247667353018187, 0.030136130953906104, 0.08825295852147974, 0.030006166052771732, 0.12256982256076299, 0.06891056400490925, 0.12524644494988024, 0.12520890712039545, 0.16648122371407226, 0.1334762095939368, 0.11937061688513495, 0.12408221562509425, 0.12311894504819065, 0.13924183615017682, 0.1244621878140606, 0.12694612640189007, 0.15124671306693926, 0.1287549184053205, 0.13904896681196988, 0.2014142632833682, 0.10178224387345836, 0.1492619578493759, 0.09902793346554972, 0.21348869428038597, 0.07052103930618614, 0.12281695773708634, 0.10891659854678437, 0.13090909109450877, 0.194547304417938, 0.16691009601345286, 0.11311470530927181, 0.10569404490524903, 0.11958533505094238, 0.09651320317061618, 0.1438375114230439, 0.09187808274873532, 0.07515279779909179, 0.1741250924533233, 0.06892527337186038, 0.07263574458193034, 0.11471128018456511, 0.15414540830533952, 0.199205587268807, 0.07115274056559429, 0.21179297589696944, 0.11488495016237721, 0.10130493901669979, 0.16554810659727082, 0.14950998360291123, 0.10982140272972174, 0.1425102396751754, 0.15493742830585688, 0.1354003610322252, 0.14351095160236582, 0.1496835274156183, 0.10133261370356195, 0.11980214607319795, 0.19058477017097175, 0.11451190963271074, 0.2664585941238329, 0.10179537246585824, 0.14503567916108295, 0.11686397599987686, 0.085560906882165, 0.10270488186506554, 0.0934346929716412, 0.11918865711777471, 0.15405782003654167, 0.0933117042586673, 0.1474192793830298, 0.17831352161010727, 0.10378086240962148, 0.11878501041792333, 0.16466711793327704, 0.16632975137326866, 0.09623227058909833, 0.1491727220127359, 0.06510998864541762, 0.18471401097485796, 0.138551015406847, 0.18270857952302322, 0.11037560150725767, 0.20132061908952892, 0.23358492529951036, 0.18070607213303447, 0.11883653030963615, 0.07794595221639611, 0.11970054605626501, 0.14280677220085636, 0.1637894837767817, 0.17926476197317243, 0.08596116938861087, 0.1399750928976573, 0.19139331037877128, 0.1721479368279688, 0.15941602236125618, 0.17050039867172018, 0.17291502066655084, 0.13188924553105608, 0.11446384072769433, 0.137445482541807, 0.16171972296433523, 0.11164916402776726, 0.10228163504507393, 0.1695944886887446, 0.1534308833652176, 0.17980200267629698, 0.08208586717955768, 0.1407089878921397, 0.05981941081699915, 0.12614708568435162, 0.22088970261393115, 0.09478106760070659, 0.08976795652415603, 0.17777291155653074, 0.17864977387944236, 0.10599279645248316, 0.1884220479405485, 0.14891803177306429, 0.14285477431258187, 0.13216373627074063, 0.19149376748828217, 0.16447931004222482, 0.08583573900978081, 0.08389407288632356, 0.1157206084462814, 0.19500237453030422, 0.11038463344448246, 0.11867564753629267, 0.14473280869424343, 0.1949000175227411, 0.13412918080575764, 0.11463544753496535, 0.09838035024586134, 0.12146827502874658, 0.2553810307290405, 0.21088188572321087, 0.1577887003077194, 0.15890575130470097, 0.15783897339133546, 0.16956526291323826, 0.12709819246083498, 0.13859020080417395, 0.07275713767739944, 0.12642815185245126, 0.1734142634086311, 0.10118995065568015, 0.10473706031916663, 0.13361883553443477, 0.1175589527701959, 0.13907884567743167, 0.28343373793177307, 0.17006141832098365, 0.09833358009927906, 0.19981413352070376, 0.1070103254460264, 0.19245095987571403, 0.32935365044977516, 0.17085677798604593, 0.11007693901774473, 0.14957449107896537, 0.14197127718944103, 0.13535436271922663, 0.12871487211668864, 0.11927804138395004, 0.2130127401323989, 0.2067862101830542, 0.13997587957419455, 0.1822050174814649, 0.13526981725590304, 0.13580929924501106, 0.10931004813755862, 0.22828383865999058, 0.1321152740274556, 0.14478542696451768, 0.1704410120146349, 0.10824036100530066, 0.1472464480320923, 0.1580975524848327, 0.110165054211393], [0.03055861707252916, 0.0280506848503137, 0.03884569036017638, 0.10962782835122198, 0.019470695151539985, 0.020300842988945078, 0.050539559160824865, 0.053535371844191104, 0.029575471780844964, 0.03462121880147606, 0.012371299344522413, 0.031534496738458984, 0.038057522106100805, 0.04281646615709178, 0.04642867330403533, 0.009712464379845187, 0.009637950897740666, 0.04069401285960339, 0.01739996954711387, 0.07974805746925995, 0.025017477200890426, 0.03495901473797858, 0.02159332285373239, 0.057093142459052615, 0.03185137524269521, 0.11744420189643279, 0.04036029873532243, 0.06406238040653989, 0.020831376532441936, 0.04181387288554106, 0.06079920902266167, 0.04793828702531755, 0.033569643783266656, 0.051527895775507204, 0.029798976975143887, 0.018677686239243485, 0.019740718162211124, 0.01681747082329821, 0.07537302270065993, 0.011102157241111854, 0.046169121997081675, 0.036478250403888524, 0.030933154885133263, 0.0708163769741077, 0.022332657790684607, 0.048218818847090006, 0.053553469115286134, 0.034799371351255104, 0.0634918395371642, 0.043589271954260767, 0.028881994148832746, 0.015114772540982813, 0.06722808553604409, 0.06409229637938552, 0.07188699179096147, 0.048596909691696055, 0.006028101925039664, 0.028965411547687836, 0.05512343799637165, 0.03328016908199061, 0.05531490838620812, 0.021673645496775862, 0.02284239079017425, 0.024626179838378448, 0.02488365313183749, 0.07211057120002806, 0.02773223299300298, 0.03292136294476222, 0.03039562659978401, 0.08030878714635037, 0.051170058140996844, 0.07691749138757586, 0.02914515043812571, 0.06078802856791299, 0.039965238684089854, 0.013352125424717087, 0.032976092625176534, 0.008646225451229839, 0.019610077906691004, 0.01994457870750921, 0.0354255065030884, 0.0147018378629582, 0.031207235588226467, 0.0571357268927386, 0.036472743668127805, 0.03287048501078971, 0.061661421350436285, 0.013052826543571427, 0.03734344616532326, 0.005467415849125246, 0.04574401980789844, 0.03258916280174162, 0.027767570354626514, 0.03724418762431014, 0.021974165210849606, 0.04197420275886543, 0.02410495282674674, 0.024815310607664287, 0.04256236963556148, 0.04419099786900915, 0.04439163749339059, 0.12113423435948789, 0.08483784724376164, 0.029650100295839366, 0.02330845582037, 0.05919922768953256, 0.05535433869226836, 0.0041516232704452705, 0.08218072849558666, 0.08691434675711207, 0.016285163546854164, 0.020915604727633763, 0.021647790927090682, 0.05100644797494169, 0.03202615102054551, 0.073185312357964, 0.04482439864659682, 0.03978247368650045, 0.06451985507737845, 0.031520807824563235, 0.042122658269363455, 0.04350812181655783, 0.06112934228440281, 0.008952235202741576, 0.0403167495096568, 0.03742693406820763, 0.03310528569272719, 0.03696153697092086, 0.005939635138929589, 0.0501677580177784, 0.08431159774772823, 0.030643212630820926, 0.04782147669175174, 0.06975725802476518, 0.03464051093033049, 0.020201148436171934, 0.046402045045397244, 0.04313807585276663, 0.06053629949747119, 0.03576515780878253, 0.013852002703060862, 0.03941356320865452, 0.008761374301684555, 0.057446078208158724, 0.08934213445172645, 0.11545981775270775, 0.05126153526362032, 0.035337343069841154, 0.01135752283516922, 0.01620577972062165, 0.05590391760051716, 0.028391436389938463, 0.026890041954175103, 0.016769832363934256, 0.04903014581941534, 0.047199300897773355, 0.03385472497029696, 0.028540912353491876, 0.01906939178297762, 0.034500556721468456, 0.05122759313962888, 0.03555660689016804, 0.011039653563784668, 0.04316140155424364, 0.023993664071895182, 0.08061660773819312, 0.04070624716405291, 0.05943877811660059, 0.03489637376333121, 0.03113389655482024, 0.027564034498936962, 0.032370563203585334, 0.012452095106709749, 0.04138391333981417, 0.020156999926257413, 0.015277439251804026, 0.0663822004571557, 0.03143969108350575, 0.05699026965885423, 0.07976928289281204, 0.040161028373404406, 0.014124300396360923, 0.020861830562353134, 0.0841836811741814, 0.012165514781372622, 0.014601314887841, 0.005405840320236166, 0.07259329373482615, 0.12074242491507903, 0.023788248727214523, 0.016049988080339972, 0.03844497514364775, 0.008615387359895976, 0.03274716604209971, 0.021455424393934663, 0.035509929512045346, 0.008680785413162084, 0.023215451728901826, 0.05689163081115112, 0.03440110151132103, 0.030266954890976194, 0.049948857849813066, 0.02032326883636415, 0.03971504214860033, 0.025332945624541026, 0.046590316778747365, 0.004235358401274425, 0.054406393464887515, 0.009698021258373046, 0.05494039098266512, 0.05041135686042253, 0.033130615192931145, 0.029382155298662838, 0.011742754995793803, 0.04248309713148046, 0.043016423005610704, 0.07057555005303584, 0.029926320239610504, 0.044889956261613406, 0.006445951012210571, 0.009744432391016744, 0.05741857792600058, 0.039587055071024224, 0.0190502963232575, 0.03431628516409546, 0.03667175056762062, 0.02991799519804772, 0.04506348523136694, 0.05903329460124951, 0.012083544570486993, 0.013903185845265398, 0.02390602199739078, 0.07097332636476494, 0.013847943155269604, 0.04114840390684549, 0.049158726615132764, 0.01754516331857303, 0.019780105794779956, 0.03781689185416326, 0.020460718296817504, 0.03884706704411656, 0.027787756771431305, 0.03356663808517624, 0.02370969610637985, 0.05532323157240171, 0.03355031454702839, 0.03435160768276546, 0.06450735731050372, 0.010876205742533784, 0.08414358293521218, 0.07559950390714221, 0.024264082276204135, 0.026954135682899505, 0.022999909779173322, 0.05768733186414465, 0.02120748769812053, 0.029183276419644244, 0.013734917774854694, 0.015497284730372485, 0.04728235464426689, 0.04522344774159137, 0.008537842204532353, 0.03834821764030494, 0.01617293783056084, 0.07043787423754111, 0.042844103736570105, 0.052918825240340084, 0.05629433180729393, 0.047197523454087786, 0.014349298235174501, 0.0365398486610502, 0.06836863292846829, 0.019448983621259686, 0.07051876091281883, 0.05282537771563511, 0.036675016017397866, 0.01064929687345284, 0.06622442728257738, 0.03585221173125319, 0.025744616796146147, 0.04332035103288945, 0.03146387396554928, 0.05337956165021751, 0.019577902094169986, 0.04558757136692293, 0.051607984642032534, 0.05434855789644644, 0.035117103325319476, 0.041904433455783874, 0.06279623194132, 0.025025475697475486, 0.08530770835932344, 0.047577781369909644, 0.024091455015877727, 0.03987042931839824, 0.026400777387607377, 0.041141012115986086, 0.0480746752145933, 0.02851130993803963, 0.052922751201549545, 0.009026409152284032, 0.046733866693102755, 0.019682815800479148, 0.018866757636715192, 0.04527705306827556, 0.030412419546337333, 0.1426586543675512, 0.01708315783616854, 0.025619288462621626, 0.06188426232256461, 0.025329854579467792, 0.05706146388547495, 0.008730731024115812, 0.02995983562868787, 0.04750018983031623, 0.03849964174150955, 0.07664985067094676, 0.04554511309834197, 0.02261218771309359, 0.006612492197746178, 0.02101941263390472, 0.07072703723679297, 0.032587285168119706, 0.0021629699222103227, 0.024769000592641532, 0.032872707743081264, 0.048770353314466774, 0.029210945540398825, 0.02656186610693112, 0.06097502009652089, 0.06132564405561425, 0.04099713565665297, 0.02693127011298202, 0.048904644936556, 0.023360010964097455, 0.031043161579873413, 0.03810562440776266, 0.08659687082399614, 0.050157119330833666, 0.03610699473938439, 0.026666210214898456, 0.0287067415411002, 0.03202710468031, 0.0058064432869286975, 0.03448873801971786, 0.012585690965352114, 0.061302997419261374, 0.04862324109126348, 0.07508215276175179, 0.021000111228204332, 0.017691577922960278, 0.04254159692209214, 0.182922778185457, 0.10764409729745239, 0.21780725161079317, 0.18135974096367136, 0.17792647675378248, 0.10899499902734533, 0.12567212601425126, 0.19090344838332385, 0.17649113346124068, 0.05654636144754477, 0.11418281908845529, 0.1629218686139211, 0.2846649312414229, 0.14559525850927457, 0.18375364219537005, 0.08422330443863757, 0.08942318439949304, 0.14147981215501204, 0.07781025793519802, 0.13545759546104819, 0.07771999793476425, 0.10047915871837176, 0.1124382005946245, 0.20541322213830426, 0.15633205737685785, 0.2359846152830869, 0.12057916726917028, 0.1736791804432869, 0.1476687449030578, 0.11092673521488905, 0.09164910792605951, 0.17440405092202127, 0.08447438784060068, 0.18979142914758995, 0.10354045109124854, 0.15926495078019798, 0.07655394292669371, 0.13113513443386182, 0.08472534507745877, 0.09461246649152599, 0.11596371376072057, 0.14326733420602977, 0.1457008661236614, 0.17488948971731588, 0.134564702748321, 0.1852681874879636, 0.07660118062631227, 0.13151591556379572, 0.20442695240490139, 0.09302730584749952, 0.10322456335416064, 0.1692512899171561, 0.22811378294136375, 0.1317973676486872, 0.18930144840851426, 0.13483698188792914, 0.18083882750943303, 0.1241177273914218, 0.16675054910592735, 0.2076302547357045, 0.12357950705336407, 0.10973484604619443, 0.14893726824084297, 0.11819607912912033, 0.13949216256150976, 0.12648862204514444, 0.15228252857923508, 0.10182432364672422, 0.15418779978062958, 0.15120344585739076, 0.10276178974891081, 0.12322625960223377, 0.14558920258423313, 0.16444601729745045, 0.11728651777957566, 0.09846649874816649, 0.13476750202244148, 0.17243819078430533, 0.20357366069220006, 0.0767499441280961, 0.2164745918707922, 0.0601374136749655, 0.09411232575075701, 0.1455281238304451, 0.119785492279334, 0.07831921539036557, 0.15402633813209832, 0.08343688023160212, 0.1264148228801787, 0.08801568648777902, 0.10181496516452171, 0.1413237681845203, 0.18499289522878826, 0.06943495071027428, 0.13349693035706878, 0.22918401926290244, 0.13565137021942064, 0.12795831193216145, 0.19972627807874233, 0.10562437208136544, 0.13041036785580218, 0.2786460245260969, 0.1212962377758231, 0.10355250356951728, 0.23907554161269218, 0.13314469222677872, 0.1262607381795533, 0.12612376740435138, 0.11276900550001301, 0.26480758271645755, 0.11666892474750057, 0.18814423237927258, 0.1473579037701711, 0.14669564086943865, 0.10740108104073443, 0.14143743552267551, 0.11285514658084139, 0.15812297846423462, 0.11132260420708917, 0.08245124874520116, 0.13464086194289848, 0.1408358060871251, 0.12333634978858754, 0.09292459260905161, 0.21821685775648803, 0.10704116168199107, 0.12254666755325161, 0.2750540594570339, 0.12450396330677904, 0.11569215450435877, 0.3178734867833555, 0.17693167232209817, 0.12727783672744408, 0.153235015750397, 0.14322562550660223, 0.10053055986645631, 0.18955284351250157, 0.1798459971905686, 0.126621600065846, 0.12379225110635161, 0.1877014819183387, 0.1600039962795563, 0.10126550128916278, 0.10706987537560053, 0.24737944680964574, 0.234215721138753, 0.14906776748830453, 0.11624081686022691, 0.24590214248746634, 0.12426313638570718, 0.19816137064481154, 0.22102901857579127, 0.10979369835695252, 0.1452281032106839, 0.16362077876692638, 0.08305802126415074, 0.13525901158573106, 0.1243245045770891, 0.11186891395482235, 0.0818583024374675, 0.1522954271058552, 0.17328557500150055, 0.12863565527368337, 0.12752713897498325, 0.07203148052212782, 0.13735927466768771, 0.07514738754252903, 0.0707790617889259, 0.13807515031658113, 0.10768436623038724, 0.11434707121225074, 0.14157271420117468, 0.13310976675711572, 0.10706227578339167, 0.09693426807643846, 0.0793868319306057], [0.024880376549845096, 0.04550172343442682, 0.028693035928881727, 0.05375850967539009, 0.03083573501498904, 0.05673112282238435, 0.04217176989186555, 0.003408270995350904, 0.015828891155251767, 0.03404418413992971, 0.02882831646275008, 0.03297925417427905, 0.014988283674028935, 0.07039491130854003, 0.08292799699120224, 0.03514722338877618, 0.007675413262404618, 0.05693602608516812, 0.04483453267312143, 0.06050937437976245, 0.024931645966717042, 0.014901936647220282, 0.0475788537733024, 0.046513901543221436, 0.04400154983159155, 0.01648840439884225, 0.02341255316423485, 0.005869631131645292, 0.028425578893802594, 0.008084805576800136, 0.05708152413717471, 0.016628725970804226, 0.03362362760526594, 0.038323585758917034, 0.11738986184354872, 0.033695404417812824, 0.02524058349081315, 0.03313649671326857, 0.06149964057840407, 0.011655309590423713, 0.008254949425463565, 0.013391585416684393, 0.06207398124388419, 0.06956728306249715, 0.01463794544179109, 0.012249508272361709, 0.04446718441613484, 0.008688453654031036, 0.05337719419912901, 0.017340258200420067, 0.08644539848319255, 0.03261225843743887, 0.03884159741573967, 0.07441685447702184, 0.014544181576638948, 0.04997408344934229, 0.02214095733506838, 0.05313816698617302, 0.07664400996873155, 0.021886948015890084, 0.06817550383857451, 0.03498771729937289, 0.06335332509479485, 0.039350172664853744, 0.05330896485247649, 0.03494753000268247, 0.027227971477259416, 0.060483825945993885, 0.026856546974158846, 0.004559614781101118, 0.013678062769031385, 0.04570202909235377, 0.038269616779871285, 0.026169069606112316, 0.05807914873003028, 0.05419141183665488, 0.0500498604378663, 0.012899204757559346, 0.010529869541642256, 0.030375263922906015, 0.040116109885275364, 0.014899667530698935, 0.026121215923922136, 0.017339879705104977, 0.05891799082746729, 0.025427255895920098, 0.05066770208941307, 0.02169900282751769, 0.025087832800636534, 0.040041598258540034, 0.049520972606842406, 0.10811818865477107, 0.015176774340943666, 0.03078971443756018, 0.0312636647868203, 0.018724402580119204, 0.007527726338594221, 0.0441483392205555, 0.0937604290083982, 0.0789886548591312, 0.13899544312153012, 0.010529800892982166, 0.05271664937026799, 0.06254278108826838, 0.03380894930160139, 0.020875532463833224, 0.03239148063585162, 0.09739403598359786, 0.0577239716949407, 0.08065873946179636, 0.032147325182450004, 0.018036578258033842, 0.031078465544851497, 0.027869294681295287, 0.05682711591362022, 0.025458314776187763, 0.0574972752656322, 0.07461931978468783, 0.032999470276990905, 0.010261563675157959, 0.035902707459172234, 0.008753472284297459, 0.08146115695126355, 0.07923117387690581, 0.05150040291482583, 0.06106101274781395, 0.1036747575562913, 0.04095057702215854, 0.028150392390671186, 0.058590577536961064, 0.06057454978872556, 0.0485884232330136, 0.070373715570895, 0.011007863668055506, 0.036825887218583375, 0.015952714784361888, 0.03379253299499396, 0.01604011566087138, 0.04153237256105058, 0.01950504731212277, 0.040413510723738, 0.11136693268781528, 0.024394587089773268, 0.050788386433850974, 0.027464968916319776, 0.06161280325613916, 0.05164535548829008, 0.05095550695841666, 0.010022656133514829, 0.06957829653401859, 0.010846781442523934, 0.07717597400187515, 0.07112813837011345, 0.06619382853386924, 0.016982199776975904, 0.03412447709706612, 0.05912132815865334, 0.0589400326134637, 0.030494599413941614, 0.026365304584032856, 0.026417427470732946, 0.004991745108782197, 0.023200833275041077, 0.0359021842450602, 0.036651040936703794, 0.017560117594257463, 0.03441950677370187, 0.048247495433315635, 0.08391726500121877, 0.05829020439705346, 0.0315810813481221, 0.03181586347636767, 0.05943238822510466, 0.01959794193680864, 0.050904510280815884, 0.06163901220133994, 0.03206805638910737, 0.07637181246536784, 0.0321666469972115, 0.019714128866326064, 0.08116202690871432, 0.041631070780567825, 0.01169628727438976, 0.040590123317088, 0.030606797299697064, 0.09227861984982155, 0.0212101946817711, 0.04688761371653527, 0.03573588008293882, 0.03231482420233078, 0.016430513169325422, 0.08541352377505973, 0.019146163249388337, 0.05278828517475631, 0.0537692188663641, 0.03345969089423306, 0.013989827875775518, 0.014590785667678574, 0.0751164548273664, 0.021655347845808137, 0.0028738824585161638, 0.03849907028779853, 0.03141770124784671, 0.03279669697803911, 0.048237146183964796, 0.020169716626696754, 0.027414591932028998, 0.03910563129466027, 0.035528965599951334, 0.047033557057147846, 0.04647715781175066, 0.009454593109694542, 0.08740865421714261, 0.029853702944819815, 0.046585886157117784, 0.06492839253041893, 0.05408294695371296, 0.011911471137864282, 0.047965523845050484, 0.04610100768331904, 0.03695097992022056, 0.005516618384717731, 0.020536460033326875, 0.017647601962380577, 0.035570199324865825, 0.01126883154938696, 0.05212038195168134, 0.07813552641891874, 0.04320020474551711, 0.023498801856476348, 0.060519549224409275, 0.04762480755744036, 0.031358574342448264, 0.057759231131058186, 0.07613129724632017, 0.041369871905772015, 0.1120601654110942, 0.043856756819877774, 0.014736170542164473, 0.014829776700935327, 0.030865391236147843, 0.012618080145330168, 0.05321274911693763, 0.06338337465422228, 0.04249363933922723, 0.04824947696761228, 0.04156463372055441, 0.04511491606535856, 0.06228156737051904, 0.09124019939918071, 0.03868559426337015, 0.04401670448714867, 0.10398517566500232, 0.040425507540930994, 0.04809711404959671, 0.0036866893196929595, 0.040719735698075965, 0.016087240182969254, 0.021549541706917807, 0.0022397891643777257, 0.053499121640925296, 0.006651208186667645, 0.06051565294910688, 0.008086228644970106, 0.042962246225215495, 0.03398699052922893, 0.06112727540312335, 0.019264162874605972, 0.07399878784781322, 0.03513389441650361, 0.024510981820640154, 0.013764730774710188, 0.044008125260006636, 0.06084469896450173, 0.008275231393781723, 0.025444271486776415, 0.05747147821239196, 0.006964818458072841, 0.053672966023441404, 0.04026517766760662, 0.052818308759015054, 0.05211517578572966, 0.020201436018396635, 0.02516285650926875, 0.06108034940552898, 0.05201228072110098, 0.04448931154911406, 0.023329326868406497, 0.04081051520188339, 0.018090205849148333, 0.05307148130668793, 0.023439962533302605, 0.05081290699308738, 0.024172503108275123, 0.07615851180162281, 0.04355019045760855, 0.01989791988307843, 0.014302293384389486, 0.07038028357783332, 0.04609211675415281, 0.04069389782671351, 0.031049443859956227, 0.060580794961424544, 0.015542428645858308, 0.06082197440264281, 0.037767116009490564, 0.05499202219652943, 0.047163907875074074, 0.02315646026545437, 0.03324728080770001, 0.041583951824577525, 0.015432499876624206, 0.030272765907284338, 0.034036499200738035, 0.03245164654799737, 0.034123278528568335, 0.08180218123015948, 0.0534605893335538, 0.035771013353951275, 0.05366287281503901, 0.038278281353996135, 0.026582492246234324, 0.06503423021058552, 0.010584529645711882, 0.055170668274513446, 0.060059016905142926, 0.04371385628473945, 0.06776580863515846, 0.07203014465630986, 0.033976938138948753, 0.03184148241416551, 0.02295904341735877, 0.04650254297303036, 0.044247415935387835, 0.03322841912449803, 0.032813632788020186, 0.0357001419615699, 0.09319508317275904, 0.0712796403968241, 0.050126305359299295, 0.02965482221043203, 0.0066952402721653925, 0.038943494291743264, 0.08916155507904477, 0.024529030852136202, 0.03444439098529983, 0.06682996783638373, 0.055438349809264764, 0.033394593410776, 0.018008467559411656, 0.03946851924411021, 0.050145779314334504, 0.07035145856207237, 0.16099314554594457, 0.12578187481267378, 0.1606142643140629, 0.17699174175504595, 0.15229800977976993, 0.11342469297233038, 0.14517986361170188, 0.1261331036221236, 0.11422999741625972, 0.14887776284012944, 0.11919814176508226, 0.09837450954364613, 0.1350963328150101, 0.17757303634425625, 0.18579530529677868, 0.10494232352357358, 0.16701807850040495, 0.12607846671016887, 0.15325523185310885, 0.13939939410192892, 0.0812323676655069, 0.13499437656719238, 0.18234246323117986, 0.10167297747102566, 0.2115590509492904, 0.20653818442951888, 0.09343216224806383, 0.11767756281187758, 0.16534809779841453, 0.15009555296273902, 0.20304342586314306, 0.16571284853853285, 0.16523398517165333, 0.23995894967811182, 0.08372667405637912, 0.1760598417604342, 0.12194635171908885, 0.16400902590248734, 0.1307559118140489, 0.1986128042335622, 0.1535011053783819, 0.1090829806344118, 0.15568238130072132, 0.0629527508863248, 0.1414394096354954, 0.07325038386625238, 0.07633166969753802, 0.1588328872458078, 0.08942369648138992, 0.15290018840460107, 0.1819061249261722, 0.12971766205737367, 0.14828670158749446, 0.12670445343246683, 0.10607907854137011, 0.12060225548339076, 0.16525264276424423, 0.20004856312880293, 0.13232320896349847, 0.25296136213000864, 0.13496075727744028, 0.1563217118382454, 0.11425383519963361, 0.0765305504319258, 0.0791016839502845, 0.1313319816836156, 0.07678249472519383, 0.177027142199222, 0.19520144822308794, 0.07899079224443994, 0.0918305259256158, 0.18515129922889173, 0.13163495605112985, 0.13877786026569083, 0.07504201741539873, 0.25433492904994637, 0.14055914827622473, 0.07762665059999563, 0.13115088280756027, 0.11574647971428931, 0.14574573637219146, 0.1408454540069215, 0.16084688308183104, 0.16865040262928233, 0.11377413320587948, 0.21461597207235172, 0.17956074530957267, 0.0833246971888002, 0.1611878999392502, 0.104836040554801, 0.17926888831425458, 0.1500379474600777, 0.15254035068210214, 0.2118291927035898, 0.09878413795377128, 0.10094917568494566, 0.16121371183544397, 0.19188410748029128, 0.11058680931455456, 0.2611148339929059, 0.10956835263641551, 0.17661637830315158, 0.10186157946009189, 0.10778218129416928, 0.10486322542419657, 0.07707709024543874, 0.17035067779943347, 0.14656172774266452, 0.12327084041316994, 0.09272589741158299, 0.11256760146352462, 0.12849010527133942, 0.12916928913909942, 0.16756827710196376, 0.13323372026206926, 0.13610535679617897, 0.18248992797452956, 0.20691728830570355, 0.10148448680411093, 0.16947449825238436, 0.05975039108307101, 0.15822800720343366, 0.15831989992875606, 0.14152717601973563, 0.10191146662691608, 0.2650480385636911, 0.08860584232024848, 0.1606809240183793, 0.100460337853292, 0.19347222929354757, 0.23678080615354702, 0.18880707415519282, 0.0782249255280476, 0.18769150745356455, 0.16537478542886674, 0.07017046358669177, 0.085739378555445, 0.18585550831630826, 0.090103704133071, 0.17605464672669768, 0.2614732616348192, 0.11071871864260174, 0.17363238061079755, 0.1165497803594917, 0.15244345588143915, 0.0791722621943336, 0.09117199602769688, 0.08275852014776319, 0.15938459982862696, 0.09744442781084217, 0.13657311763381585, 0.2123745673452504, 0.07842030332540162, 0.10878543136641383, 0.12191629473818466, 0.1765698308008723, 0.08974125405075029, 0.18488464556867257, 0.14045495074242353, 0.09508390096016228, 0.18891848536441103, 0.1378630890394561, 0.1054285118880216, 0.12414230732247233, 0.1350755972089246, 0.12493457965319976, 0.2222461556084454, 0.11542989435838535, 0.09301448153564706, 0.13346126273972914, 0.22668065124889836, 0.14958427258534357, 0.10517900183913298, 0.23624978464795277, 0.1391901826718822], [0.049115682049887255, 0.02499277667084243, 0.024744031034060754, 0.0574196800153004, 0.05145204457221553, 0.015223879381665029, 0.011582572624320164, 0.07034031150396913, 0.02562793448305456, 0.021227230681688525, 0.016113284000311978, 0.043760455737356097, 0.028071505803382024, 0.09644531150115654, 0.010589218163659098, 0.027709458336175885, 0.013239341242297087, 0.0857046534656547, 0.08749736312893219, 0.07485092923161574, 0.042322715307818726, 0.039810122398193926, 0.06294645747402683, 0.07576676915050484, 0.029762090380245354, 0.06526490455144085, 0.028905917279189453, 0.0292192724373308, 0.0697280619351659, 0.02758408176305238, 0.048053382997750305, 0.007126631235223613, 0.04669461821322329, 0.04613744342350401, 0.025841459646471776, 0.07817668592906557, 0.06131552487204317, 0.04659902217099443, 0.0328026527131442, 0.06744631406036206, 0.05635888381220866, 0.02638230533193564, 0.05356223016860895, 0.10716784629039466, 0.05488424008945003, 0.059326680420781486, 0.010314453757018782, 0.04834673170989845, 0.03251338952395599, 0.024872917965694796, 0.04940362792694941, 0.046840865834383294, 0.039556541669298895, 0.03550164714397397, 0.0289375772990752, 0.08264901625807397, 0.023186884609458502, 0.046425500622717664, 0.028322720936557744, 0.028819189901696518, 0.05029530722822528, 0.03312789151095785, 0.03814717354543973, 0.10616429935907945, 0.0464624521555379, 0.030739133362658322, 0.032855564131750725, 0.005934111241003848, 0.04677845492551569, 0.03232128459785599, 0.06386195600498468, 0.017420117001165636, 0.03023574572580401, 0.04983626291505061, 0.055428746418328956, 0.10100581639562733, 0.008299353976326529, 0.058385392258060165, 0.035967111034551635, 0.019996792507299688, 0.024762551329331473, 0.016951580619206652, 0.0755859819764737, 0.08898774409317411, 0.0382856805663323, 0.02170460604247637, 0.02443995272187749, 0.11775527309509926, 0.044508603677968495, 0.048353095626225695, 0.05710895391530357, 0.021876617320231162, 0.03921179551980458, 0.03017056475073332, 0.04567242482153233, 0.0460107847902691, 0.02416116123640677, 0.047040818972163834, 0.008740548710193252, 0.013194862476666458, 0.02116337258485146, 0.009288158144045155, 0.04624115856131539, 0.016911133570829406, 0.06773840854293667, 0.06879600608954206, 0.007184086452980409, 0.05844465646077879, 0.05300957505824044, 0.02308023613295518, 0.03828130189504009, 0.08060834763455205, 0.02651574348419672, 0.025015879728016444, 0.013947162733529694, 0.012823447250411846, 0.02314779383596033, 0.011633184312813682, 0.04273585036571603, 0.08146474152454175, 0.021082508174004033, 0.029272502979438286, 0.01893114636914106, 0.009582197053532582, 0.033668920877971686, 0.0121565338668006, 0.013548927217925666, 0.0442300719441846, 0.06758176343282685, 0.012659955827984959, 0.027966733105131425, 0.041354368440806866, 0.012726288059639046, 0.03772647229197901, 0.027023574730264954, 0.014765269224881195, 0.025532405234116595, 0.0472801838623127, 0.08632527446025051, 0.04826185599085875, 0.053179166934569366, 0.02027019228989957, 0.031861498137004673, 0.05046350015618373, 0.020080482645425946, 0.043888097716262564, 0.029179330049373675, 0.027982418396277353, 0.05054581917647738, 0.020622046358766966, 0.07960972856380977, 0.03391293161257636, 0.037759460756205954, 0.052910301674273796, 0.06722723948769271, 0.01686246909230249, 0.046533616696251556, 0.04627799506124575, 0.05765942711150274, 0.03016372585989302, 0.012662136814469704, 0.019901745654351544, 0.03044989800400799, 0.1317728025605902, 0.03755769306735601, 0.011548507118277485, 0.009364489887957461, 0.00768462192354491, 0.054721943524782546, 0.061650600837310776, 0.03575667506083846, 0.0217171928670723, 0.026226057270832825, 0.06862245485535823, 0.065380798332626, 0.03351347062562127, 0.0658875293447636, 0.02672160782822175, 0.0019974503493358498, 0.06553607789101079, 0.0826305293594487, 0.008715850963199046, 0.02369951569562545, 0.025687156012281775, 0.02733393346716184, 0.05007404331990983, 0.047217913961503655, 0.012854326159867924, 0.034073335700668395, 0.08885250994353555, 0.05545536725549027, 0.05408694712969009, 0.0258256964298198, 0.039548211061628535, 0.01841419783886522, 0.005405777237683651, 0.06822230367106386, 0.048645268034306355, 0.00900500561328954, 0.10853642597794533, 0.03904174722265452, 0.031148951020441018, 0.02000757034693379, 0.06178189047204796, 0.019315025965624955, 0.059045246889581904, 0.022173684192239307, 0.03980158769991249, 0.054321050192811526, 0.03911565770977177, 0.005972725648462074, 0.022681623049720656, 0.06906856724526733, 0.013901171842007898, 0.02855601691408083, 0.015447844707523473, 0.022573278765776195, 0.045622923571499996, 0.04626240624929778, 0.040995473245857283, 0.045182770627434365, 0.029758706186839845, 0.038508150464622304, 0.013986070753162494, 0.007438466382154729, 0.027368033297534566, 0.030166059914336074, 0.04045189831231255, 0.035832774883601815, 0.01714731835818384, 0.05565188424952794, 0.013009205886191921, 0.05646587553201243, 0.03871977016387973, 0.025779273237276357, 0.01075112139005796, 0.05145008901308756, 0.04841018162551336, 0.011484538626973517, 0.04951405950123444, 0.032427574988105334, 0.01948669771081768, 0.04268705415597651, 0.024170178330678027, 0.040319094696315005, 0.017538491410959978, 0.0628234761825297, 0.008850858757796232, 0.043678036527126096, 0.051562405642471276, 0.005070835322840139, 0.017361977152177133, 0.046683326436323114, 0.03992685480625369, 0.060340758427628316, 0.027987069806840736, 0.04292208490369376, 0.023824500785849523, 0.08137247030390427, 0.07990180820343085, 0.035194609517930076, 0.020355088418000378, 0.029114399549143855, 0.011404518409108277, 0.038829222103231587, 0.04639030426915269, 0.015177525765466271, 0.03516679753374774, 0.017805425231927074, 0.04502507908910047, 0.06127608343376778, 0.025173456233460456, 0.02345185544982087, 0.012922834739583777, 0.0360991131310584, 0.03015250273165293, 0.028189249387651216, 0.014046944488654844, 0.026646172227628995, 0.05784978799056262, 0.07023876343737356, 0.07582798891235143, 0.04118086173548363, 0.0739671649353113, 0.013768390490440652, 0.0286451265856158, 0.024042946388362907, 0.01445940048142802, 0.03461369713477325, 0.045696745000896044, 0.04164569851127453, 0.027292924241919536, 0.019626477514975704, 0.05741374654462561, 0.007448177848345949, 0.017192735940625425, 0.0446124004520243, 0.11802649838500656, 0.044353565317578614, 0.029278421607159544, 0.15539071726379916, 0.017035415476129856, 0.036308376511442475, 0.05031583132222295, 0.017806942923925817, 0.025808337595663033, 0.07006225103395991, 0.029113744603819214, 0.029663948771485593, 0.030778806722082663, 0.07355599285801873, 0.03717374667758122, 0.020528986606223043, 0.026931789616355672, 0.05513980606338009, 0.03663508847239427, 0.06776777532650158, 0.055184932352858596, 0.027507566337590106, 0.04089996626134962, 0.0550862452655565, 0.06299631495494395, 0.037820810393895954, 0.010283838309987914, 0.03120220011624042, 0.048191173846134916, 0.052578880786313675, 0.041564362836652435, 0.047570690148859285, 0.053779542140546255, 0.0014016260161042737, 0.058467147246119566, 0.09696206892840564, 0.03978245142207015, 0.031937330786604434, 0.03867257328238338, 0.06504728458821774, 0.005577073734457372, 0.009907646435749484, 0.027705313441401813, 0.02397820513579063, 0.061763474077451974, 0.03801475584623404, 0.021944794716546312, 0.0982862756063696, 0.05097652829135768, 0.036644020219682716, 0.007820600076229312, 0.04225998156471178, 0.045596113486681134, 0.031133640513871796, 0.03751207324967254, 0.1681303055374883, 0.13678620307473466, 0.1273246662458405, 0.2456832682946697, 0.14676743623567745, 0.1524431590223685, 0.13483177201123908, 0.14840866613667458, 0.12796503579011187, 0.10315395542420447, 0.21484922908712178, 0.09482768189627677, 0.12023511502775364, 0.16761086153564975, 0.10574554253253154, 0.13364139682380483, 0.12709525355603546, 0.2785257075447589, 0.19528686942066997, 0.1774376240791753, 0.15976155147654936, 0.08287995035061613, 0.10149815716431476, 0.17730491323163733, 0.18427462986437604, 0.0979379189084284, 0.12830569641664624, 0.15546193375485018, 0.1798139957827516, 0.10354603946325369, 0.07428420300129801, 0.11360587348463014, 0.1501339813694358, 0.2007012820104137, 0.09196353363222443, 0.21100290032336488, 0.14527793100569397, 0.22261060948949307, 0.11680936877382919, 0.12418524056556635, 0.15972295979736373, 0.14708755421452224, 0.12337485241005197, 0.12986493384232745, 0.19433570327237248, 0.09178038642858155, 0.12362457026029006, 0.14213370362995192, 0.06842318820417859, 0.092367269389797, 0.18661631358554587, 0.1317863244912587, 0.15747282741358504, 0.16285201767459512, 0.14469240617472678, 0.17116831673774868, 0.1043452211888507, 0.156726019049529, 0.09186806375510059, 0.1257137901848182, 0.19493071275064722, 0.14438273763516918, 0.12937532417709008, 0.1382797901169397, 0.13280213170219213, 0.146315201127436, 0.1782014424679801, 0.12052084930473939, 0.11650879154331051, 0.145346668723505, 0.11919324359041639, 0.09634932954213582, 0.08848356606904417, 0.15026474779006094, 0.11570337577722967, 0.2530319255311042, 0.1336109242402017, 0.09803769324207678, 0.09507109891274013, 0.08647017879411578, 0.08626162045402452, 0.104982288175961, 0.13094282912788913, 0.16206937842071056, 0.1385909429518506, 0.11815037767519243, 0.11810337004135363, 0.1421594264684245, 0.09006474880152382, 0.1324668590677902, 0.1027488912222907, 0.11399493698263541, 0.15228733769617975, 0.1028663880424574, 0.13271786825498566, 0.1080538221867755, 0.09780405773199163, 0.1349050665157847, 0.04172174267296214, 0.13597754412330687, 0.12344111877609976, 0.09235999634256586, 0.09698285648482852, 0.1293167835683562, 0.16670417971909046, 0.18997706996742636, 0.15825200825929642, 0.14691381744341925, 0.0916571453853976, 0.15534286358160898, 0.13099556614179164, 0.1507127971854061, 0.14989100222010165, 0.12645699171116576, 0.11369854546501301, 0.1851836865535006, 0.12040202404023148, 0.15053016948513687, 0.09996696549933404, 0.1905518039711751, 0.15382186160422862, 0.15528902818914503, 0.1349703161395155, 0.12004979333141819, 0.2471761280321516, 0.08140385572914965, 0.1283345659612678, 0.12481467827456072, 0.20332443265942857, 0.0717572495341301, 0.16069802310084924, 0.1333682271069847, 0.1303389435634017, 0.14312355051515624, 0.17078107892302796, 0.06461897632107139, 0.08428622371866368, 0.1341656647855416, 0.1302643577218987, 0.09492225377471186, 0.24201336287660524, 0.11942731696763076, 0.09071155276615173, 0.10493242327356711, 0.21160093776416034, 0.12713008996797726, 0.10206564780673943, 0.18008222279604524, 0.1598905070568435, 0.15887213201494887, 0.13145023549441248, 0.1400066341739148, 0.12417831632774323, 0.21824108145665377, 0.13848466740455478, 0.17400297947460786, 0.20106055570067838, 0.14118111255811527, 0.21096643118653446, 0.10740657293354161, 0.1543963432777673, 0.10437315562739968, 0.09836678378633223, 0.21210552396951243, 0.09510614312603138, 0.09816478603170253, 0.1340267198975198, 0.11267381021752954, 0.21154762187507004, 0.19913089752662927, 0.093513702013297, 0.1195619351346977, 0.1259580161422491, 0.20281934179365635, 0.1944209760404192, 0.19220214744564146], [0.024311262459377758, 0.021129343258508015, 0.017672539979685098, 0.04840453759243246, 0.06155480441520922, 0.024834309588186443, 0.04292622979846783, 0.0339201378665166, 0.029526859252655413, 0.030337110110849608, 0.05217042125877924, 0.02350406182813458, 0.04251162157743238, 0.044631440250668675, 0.0139026320175617, 0.023201081894512754, 0.03264185528678354, 0.03404068120289594, 0.027016990025003906, 0.030034614428586792, 0.03953782841563225, 0.03746322508959565, 0.10725102620199323, 0.011125629516754998, 0.05371857841964811, 0.025836821223492734, 0.032445995093439706, 0.037901693358435296, 0.008228140268329298, 0.02740400148468325, 0.05211784009588882, 0.09153786741080694, 0.050440972263459116, 0.013395974292507162, 0.05277287076751236, 0.021751613676315174, 0.018649258272489533, 0.017036640019796323, 0.05734746162488591, 0.056672637874726206, 0.015264574121829355, 0.04587395131238736, 0.014756379223399563, 0.038690455330652185, 0.053637198216165416, 0.07114380510756746, 0.04909178489469923, 0.018585949364933185, 0.026799741135619115, 0.030980084593466017, 0.04036980193632189, 0.03859988362819422, 0.09210796299157664, 0.06894258025567979, 0.043153145161340944, 0.08876116640749387, 0.049834177480079234, 0.08353459881618619, 0.035900859511457384, 0.04551915277261287, 0.08631939665065147, 0.03676620370242745, 0.07856266951421276, 0.009363638273498509, 0.09725177369546145, 0.03462572363787331, 0.04753366440127138, 0.03939772577723488, 0.02519738678529393, 0.049488151125842705, 0.0608000439387979, 0.062130135847837664, 0.010651445390976733, 0.010231641208520159, 0.019331496077938937, 0.0259703725532745, 0.05302765748638194, 0.06516338617075235, 0.017003282337100245, 0.0817741799983196, 0.07160599241615273, 0.010896686235355446, 0.06626031012274325, 0.04463360732188448, 0.05181330350751523, 0.0232606949066394, 0.0667395000346005, 0.033407822193112224, 0.1032062248850707, 0.050099417348974384, 0.01634431642742129, 0.019418332922214177, 0.032888315108721144, 0.03673590181278996, 0.040307424424099736, 0.06812186140450649, 0.016401459943153895, 0.005951099001322291, 0.054923009884078056, 0.005710696032110718, 0.052191193972248584, 0.06920555286342278, 0.028032958653056994, 0.023474186673411168, 0.027015075283998158, 0.03086638756940374, 0.0625334374490194, 0.049610987698542885, 0.012233563229528954, 0.00811688491012319, 0.05303309371811338, 0.01813184775528498, 0.01978452899493277, 0.024611199587525334, 0.055291875833063386, 0.06757221941370517, 0.013881571721867658, 0.027845562653965317, 0.014674350568384398, 0.016346756237908266, 0.01752342766849324, 0.04298973537515849, 0.03702707603224553, 0.03307007449620869, 0.02911448675149586, 0.07905283579020761, 0.036719081035698764, 0.03640323040599469, 0.05515214797924273, 0.0776176928775385, 0.035164118380635045, 0.03145491624309216, 0.023707900109002367, 0.04346967485616915, 0.05096321787277702, 0.011273622112639714, 0.05000333520001732, 0.01866589536803076, 0.0353325302421581, 0.051688374078366905, 0.023261598471435718, 0.15449078899109736, 0.028326403844403103, 0.0259369313789648, 0.03554449875082355, 0.020886712918581907, 0.021548254080698825, 0.04493770975386724, 0.0121168957593909, 0.03562691796105355, 0.03663267649244517, 0.02685935043700738, 0.025096593853959348, 0.03137597770546563, 0.017626391381782014, 0.02575930946477456, 0.019894852957804687, 0.06276610816712491, 0.03003999314387329, 0.024432659265585244, 0.02360015882004518, 0.06813087107730098, 0.021261208057694603, 0.03972036334744189, 0.030574528718716465, 0.06056465696019586, 0.04045837726152968, 0.016573089014855213, 0.09052657245774753, 0.04440647673618514, 0.05891461034480017, 0.034916920121759176, 0.04962358194461558, 0.03095652697084006, 0.04894232748483773, 0.05907410530198831, 0.01189280797916581, 0.056629303871886805, 0.049825078749563545, 0.019665469953906722, 0.05855959658219945, 0.008493603709212039, 0.030046418287383858, 0.032752650513430126, 0.01817328742617974, 0.04260879097273573, 0.02177799331548158, 0.015101342451089295, 0.01955874355189735, 0.02217192159150727, 0.07412897539325058, 0.0247865802157321, 0.026765127367980313, 0.09387296828208491, 0.030091242151684128, 0.013048133387201233, 0.059071218347526155, 0.014679054856969742, 0.048050251134554856, 0.026774966390803456, 0.06974750620429404, 0.04752133732836228, 0.007471939561582985, 0.06521878007333726, 0.01836596380599076, 0.05360439528885763, 0.011658725325105479, 0.02244977240479784, 0.08807277990854345, 0.0631010097276885, 0.016898370486160275, 0.029256964262458496, 0.08202069919207133, 0.032159960246644914, 0.05023249927035067, 0.0022397425482267863, 0.02296718848810997, 0.01230059307999909, 0.025231061736121774, 0.0704084629251156, 0.01598956427187659, 0.029953239791211672, 0.034729657709249295, 0.06505674697109498, 0.03206817142199725, 0.015671271976316348, 0.038583155619562604, 0.07213292468804866, 0.0281821488897549, 0.03901144162227865, 0.060593489397433586, 0.0920550330192782, 0.04507020908931736, 0.020227626409905497, 0.009416275097464677, 0.02087419474264607, 0.010018710690928856, 0.04392835180624388, 0.040077748271869496, 0.008601988811278716, 0.024360223796975333, 0.07381309507763945, 0.07701060123508796, 0.024747005190874916, 0.04978924414899666, 0.06790133964386769, 0.03144183960102964, 0.03956281281716656, 0.023299934109672904, 0.05141462919709738, 0.02190944807807682, 0.010546046505623963, 0.06434286769945174, 0.062047705505392514, 0.011115259858343052, 0.04127067273657303, 0.03339552480611019, 0.028741045462084003, 0.04873359474004246, 0.010535470901231747, 0.03177981736371294, 0.04794124819454737, 0.018104451373801567, 0.0044937918482901296, 0.027053548219555523, 0.004320445168559672, 0.05309552689141128, 0.06450308253988624, 0.027715113501471933, 0.03719949549122248, 0.027307861819281243, 0.04593556070176419, 0.047224385489244014, 0.023434270260622725, 0.017398045529262163, 0.029836099201929756, 0.04051352254464291, 0.04515828717558179, 0.04014705373265315, 0.053035453747725114, 0.025540255301166326, 0.030723243980901316, 0.056258534314110875, 0.03075246604566928, 0.042966584078385495, 0.023805531491234433, 0.0564304045838071, 0.06305716364295222, 0.053296804762794636, 0.04849859367823228, 0.0058495949997450225, 0.010504976053198334, 0.05058599534095265, 0.03564830665709451, 0.03165561895002611, 0.024987371980387252, 0.0408689185132971, 0.057616167323431, 0.05752692406531423, 0.06344618261209689, 0.021363746891438495, 0.07688590558245778, 0.036615492062992416, 0.028200780507177114, 0.03779522485274356, 0.09538515354506671, 0.028020958125125617, 0.02819749464833876, 0.03445705944614019, 0.024391258557443507, 0.043050587773905136, 0.09079628376639448, 0.044997300501563586, 0.0074192252759530675, 0.026555813892628066, 0.02720930646319175, 0.06666012734058313, 0.19291788950795308, 0.010589269186311867, 0.02495123124390375, 0.06991584014031105, 0.061136418662499636, 0.02203351290518185, 0.046528128514182754, 0.0389278609509347, 0.035778163946815766, 0.026060632553708274, 0.012442484294297174, 0.025209394734702073, 0.03959741545259021, 0.09782457811525092, 0.0215909739563358, 0.06166972598293796, 0.03737695784366224, 0.010964751381834503, 0.02996121231262805, 0.047490831348113716, 0.043252377727185376, 0.012715390548692085, 0.009256993507733569, 0.04209087950584944, 0.03054031571082305, 0.03351917031977791, 0.017451179592171684, 0.07211805947008543, 0.013823089557263302, 0.01218873379912111, 0.08191990811610594, 0.05437823638203554, 0.013007784673391143, 0.05427260650321841, 0.025246978948416654, 0.11101439769845456, 0.14971848257118836, 0.09142446724581532, 0.1457272272091359, 0.20669296674896032, 0.11664530960842967, 0.06671952884062193, 0.09817484955419786, 0.12944290414452553, 0.12087188515579328, 0.12102608860004693, 0.0998072924267035, 0.07506004418246448, 0.10446716347360052, 0.1422595718759112, 0.12728687608614564, 0.1108046667650342, 0.16756232507759705, 0.049394369634683244, 0.10506670747417957, 0.13541651016566902, 0.09997763758292422, 0.20329440536443144, 0.10017447741120122, 0.14002208568854257, 0.18016362155321985, 0.16052148101152852, 0.1990449716686271, 0.057338344340678304, 0.10968418704578653, 0.2446810869150795, 0.18379514309344813, 0.22694862593198195, 0.1700930783408694, 0.13464250951074064, 0.06437886186176911, 0.17786560580134392, 0.13398190902080387, 0.2150679548503831, 0.11432029452407733, 0.08298830391140655, 0.07624021483934484, 0.1209592804661952, 0.2558799914550036, 0.18987593008205295, 0.1410945929819718, 0.15434845990967005, 0.11691649036947638, 0.11105537909315899, 0.14107698923908174, 0.2590522571699694, 0.13021197693888098, 0.29709427210036665, 0.16815921961097047, 0.1451714476570487, 0.14245514263166115, 0.11562611078261398, 0.15445176686625928, 0.2076506637968123, 0.13208024465711787, 0.21631397627061233, 0.09334206552011892, 0.13191173260565847, 0.07033942092675716, 0.19033487420529127, 0.264790216460824, 0.1967225392581895, 0.2308988553704694, 0.14886691264109686, 0.25616064202040434, 0.13684981997357681, 0.12234417998115532, 0.12888964789453894, 0.23215918539790437, 0.05999705128488131, 0.14529366453643888, 0.11408249556552619, 0.14462840335909277, 0.23043894645525143, 0.19331907969899476, 0.1690630812663585, 0.14283927826909348, 0.1461530863889493, 0.08251623861724511, 0.13604981446405873, 0.1059667841764167, 0.11124569544335827, 0.1015003390784841, 0.24531982373446226, 0.11019394602044486, 0.1263015711447224, 0.1898357947356999, 0.1687507113092579, 0.1845026176306419, 0.15065410814713687, 0.17586237110663205, 0.1351249945582822, 0.17891544790472835, 0.09732988473842852, 0.14539383962983266, 0.10412316318252124, 0.2105433476390317, 0.08782733682892285, 0.0779250384948682, 0.09788642128114589, 0.12285928984056227, 0.20210018585203215, 0.15136910806177184, 0.110601540945936, 0.12135409560869448, 0.13435682718409225, 0.13357967982301489, 0.10446582018630579, 0.14504970575217158, 0.12443706611520611, 0.16096669540274888, 0.13770992460194975, 0.16879797127330676, 0.1505935488967225, 0.11071785775129683, 0.13538470171624795, 0.12955367710674182, 0.0958503020228818, 0.10559816684690304, 0.16459468432003632, 0.20204149681376293, 0.13307040324434638, 0.12009317186311819, 0.10045765127870254, 0.16257684415904805, 0.1364315752289258, 0.10995828444720246, 0.1139756634074729, 0.06112186143582221, 0.13192970742238685, 0.18052282102871686, 0.19465631106868386, 0.06463433877797797, 0.13089524261886254, 0.17170408798847347, 0.15347285923780873, 0.20417812513187528, 0.08167022737325169, 0.1350016496144235, 0.16027790814405307, 0.10893016500631347, 0.10952994649414904, 0.08859304027282633, 0.07957065448863432, 0.10153790659387596, 0.08485482758260332, 0.14319038833491504, 0.16926466341828927, 0.19094055576715618, 0.22482142288936302, 0.15800778230186552, 0.12683275592280552, 0.08805584409856237, 0.09673098640632816, 0.1210271127638407, 0.11463278322480619, 0.14661820518085733, 0.12323840113822371, 0.10390087511041202, 0.10229048144537956, 0.08485670521622524, 0.14460541162407026, 0.10165943327592686, 0.20390804274939, 0.15657807933166623, 0.1609465535148047, 0.18110117671312764, 0.1313910714816302, 0.129135076131206, 0.1753212563926354, 0.2242087502963841], [0.030239055704441853, 0.07950657003675587, 0.07292063281056471, 0.011361617634975119, 0.04231339022226166, 0.043101803385070525, 0.03996201034169644, 0.029139460020815022, 0.044185309307067655, 0.06515387183753774, 0.04910163319436833, 0.054590947038377635, 0.02245187082735356, 0.056443484936608, 0.025651143296272494, 0.11937907736864872, 0.04243186667736154, 0.00835709584862343, 0.031907437078189105, 0.03653237894468475, 0.02952309099782724, 0.034269882380613126, 0.027818570742965676, 0.07321130236960016, 0.03641689705546014, 0.034149821440223604, 0.050771528549375944, 0.06299060041783378, 0.06327631985186599, 0.028948533254151698, 0.017267292096221354, 0.03454054363828618, 0.04491083658649586, 0.05414850456872955, 0.0021856808007214568, 0.009080328964046203, 0.019032835443795193, 0.051758317786152475, 0.03133967184112407, 0.03765703695535194, 0.02709220483666286, 0.011385452635295223, 0.023702391517872456, 0.013133213196852012, 0.029693658798350953, 0.020899989940517116, 0.06852462494862266, 0.009005597476061666, 0.037640928640030324, 0.00744331307032553, 0.03078864945564419, 0.02110095796524547, 0.025513421096547972, 0.030630494075012393, 0.014029308276803931, 0.02769529259239789, 0.03223701372917276, 0.030490684584947303, 0.019568892421375494, 0.014756448799744248, 0.010158419991057599, 0.05701886460883543, 0.06729145010467619, 0.09028650994878262, 0.10906759591307491, 0.03551144720404409, 0.018354655330767855, 0.014279794249887345, 0.023576157764182426, 0.07958063637488522, 0.01343986026768107, 0.02625212520797504, 0.016963850175670814, 0.10410696209874004, 0.02534324477892369, 0.05117690445331391, 0.023971774426172487, 0.03396914187760558, 0.03202695254003629, 0.025075301637116354, 0.05598545365501195, 0.027107450405310374, 0.06348553870338947, 0.056185306602856144, 0.01965105559065705, 0.0187421751616057, 0.07649969193153083, 0.024369185230170842, 0.049018768695532344, 0.027282849587209057, 0.04716090588772204, 0.016092281221062876, 0.04826984149985947, 0.04450717504369095, 0.03694009632454254, 0.0790504906035494, 0.06549327823449858, 0.035479965299600735, 0.00362300238066382, 0.04081437065906357, 0.012516123897512443, 0.04377552504593041, 0.02371857775870012, 0.03677792592498008, 0.04394294614030514, 0.02855582210031571, 0.014266300149756717, 0.015086226758285193, 0.06707598236971535, 0.03736070480954368, 0.03384093215572648, 0.026819975792022888, 0.009024405353557086, 0.05936975467193406, 0.04228143334330525, 0.0585942437464837, 0.0443578400881961, 0.03584009988117032, 0.05399529189162422, 0.03985529321653303, 0.03066052137000952, 0.048768011838546954, 0.012501490600698162, 0.055894637043820694, 0.032146375233423896, 0.08860043206368573, 0.010898200216615805, 0.031440570528502576, 0.07934291163110174, 0.017313184653175995, 0.013383705663727596, 0.03293391266197432, 0.013420159029919887, 0.03645749995484948, 0.010758946409623604, 0.06954872937058099, 0.06393116869730875, 0.04899835592368618, 0.07166023598983884, 0.027043269474233966, 0.053488033954636194, 0.009677158559497911, 0.05813090239826124, 0.02497508015949279, 0.027131874485348817, 0.03920658564311452, 0.02142811892554164, 0.060483469715109095, 0.05247661283647176, 0.043291084439260885, 0.019497789107845165, 0.020317788075772114, 0.08089190741884522, 0.02718043135246262, 0.041584248683648184, 0.013730411083088256, 0.005987898857711116, 0.02274312482768437, 0.061108933223295026, 0.011762507256207755, 0.03255984796851408, 0.014339757926791208, 0.010355390622862615, 0.06873221107525751, 0.022268250504566822, 0.010807507915160386, 0.012003357369394507, 0.016913428662519436, 0.05101267459394876, 0.05757421371527016, 0.05978359477012418, 0.060180740256328136, 0.09661023897933774, 0.033849615283543244, 0.009614277314540232, 0.018883878983615432, 0.027644008332572412, 0.026358324685133994, 0.053026789173600264, 0.029941597349534277, 0.02498781912436243, 0.030030564157641493, 0.05028316198149696, 0.03481939078483265, 0.07309363485546783, 0.02428428353596246, 0.019995020629721694, 0.012035960844514193, 0.0707654508005362, 0.02252699101518374, 0.058459180290810764, 0.057991556750494055, 0.030434246109507512, 0.018631402199389413, 0.05357572612410877, 0.029549214596045204, 0.03290200402261689, 0.07515440825955011, 0.02659280438820133, 0.05777123536972795, 0.014382918452611193, 0.0026542215891822707, 0.0368169406283414, 0.051022942207055166, 0.04186089165159501, 0.06336959297186695, 0.053955880139255896, 0.004835736854147399, 0.02324229706573533, 0.04128095519263297, 0.06978930396144278, 0.05322581833752338, 0.05465568829094991, 0.07919889787444845, 0.024627862658235244, 0.009463998903811444, 0.022749926611140836, 0.02808771430863999, 0.043489545860211365, 0.057713281057658605, 0.025473421192145906, 0.028495062470028643, 0.0745981908403337, 0.03484141772787552, 0.05513711948879063, 0.04228345198498573, 0.027427039603935555, 0.015551792694168398, 0.049100842807092704, 0.03995289676822722, 0.024321333403349854, 0.11968292747042142, 0.023658805184822995, 0.029950902026030235, 0.07643347751582041, 0.04306667382479645, 0.07595767179736868, 0.03523881554428954, 0.0450159321189858, 0.04137375704885926, 0.05299232383549679, 0.0112119876757788, 0.04922384636302013, 0.05166585360711906, 0.10512937442399561, 0.03580066957511008, 0.11742459435481578, 0.043507012305781245, 0.03205605586117599, 0.04012465200503357, 0.026480545275262557, 0.13354000460822135, 0.01802214163035387, 0.02437870698486222, 0.0469014621921815, 0.04060594590555411, 0.03396010251890402, 0.01374233925162116, 0.03402989779715426, 0.03570395288988948, 0.04718684765975922, 0.041660114729893394, 0.0706205316237174, 0.026086236648552585, 0.017715224603307433, 0.017591458490642253, 0.0133778399140283, 0.034877786674769595, 0.03262678597820923, 0.02140050917660119, 0.024752467397775035, 0.13418476766673848, 0.03351142971951049, 0.019240217479818966, 0.08716697382624261, 0.06319455002085306, 0.01886535683297552, 0.03928419202566147, 0.04164085228694603, 0.02485372417140752, 0.03897470160154626, 0.0667048640025314, 0.019268174182798248, 0.04718157470051665, 0.03088539026066428, 0.03208881797036156, 0.05625101264740806, 0.039578494397574104, 0.05082385367131792, 0.014554934368788963, 0.11643407211522572, 0.07162029360188171, 0.06722021877067164, 0.04436172152054496, 0.08061237749643624, 0.06446229410357773, 0.04809229380043689, 0.0733795175619889, 0.07972160732606426, 0.07583883168990724, 0.037633366155205294, 0.016098223968583625, 0.01732208300381899, 0.022482681088149548, 0.07548210356617346, 0.050209366527269594, 0.02689194185222732, 0.018141076361644082, 0.06914555764524266, 0.041430290148127824, 0.022534494128194638, 0.048075049999170005, 0.004835494264625595, 0.018992319746757858, 0.0263143468691851, 0.036087446569581516, 0.03957253124099225, 0.02515744068659842, 0.06245983866392635, 0.04714880516985431, 0.036724350284202956, 0.037278571326169185, 0.03451436437899247, 0.06161153047287371, 0.040204670367529616, 0.02161315489502158, 0.03182207154168282, 0.028455500432755798, 0.03963142436987255, 0.018049374739348423, 0.03195919816789683, 0.03409531811485067, 0.06030620032106526, 0.005267860688036308, 0.06983384024351835, 0.019274346996098757, 0.046550853076041676, 0.022990193210716825, 0.03073346149903955, 0.04639425991626922, 0.00901234267075779, 0.045859724341426045, 0.01382337992254179, 0.014057878179301042, 0.013260678915685276, 0.032577815363765694, 0.019167893333360553, 0.08877340442268178, 0.03758635852136649, 0.02589479037851561, 0.03608314582379535, 0.04331406504206825, 0.11342324578436092, 0.12127231093472801, 0.1529638795182109, 0.1087905299209524, 0.117067072133068, 0.12550060084322467, 0.18247397179948166, 0.14992619486292824, 0.1413292600773275, 0.0772470494848676, 0.07342093682382256, 0.11231656259042211, 0.15903184219496325, 0.156799491669517, 0.14255266083637252, 0.15584274457069114, 0.1305715474882163, 0.11290038048173301, 0.12721923674689606, 0.11682332857162692, 0.13114271918311715, 0.14302079274784774, 0.06277724038227461, 0.1305422920268029, 0.0868821152835153, 0.09417281820788048, 0.16608380363322794, 0.10043808084446937, 0.12860779504990205, 0.11233743920456618, 0.10864224881515838, 0.18597460817545652, 0.19376102864043787, 0.0950607459526509, 0.21677173295756802, 0.1801843274733983, 0.22927926649572328, 0.22699435707181692, 0.06977074284804985, 0.09307484782766551, 0.1201137293537613, 0.13244181900518015, 0.13249886047560722, 0.16809546912554651, 0.08518859365722165, 0.08470273183775134, 0.20442108943825588, 0.07512546450016089, 0.13370111002586782, 0.15583688160404563, 0.08530755992978811, 0.18849556508939713, 0.0974679242062848, 0.10381089712609537, 0.1798222484649159, 0.2469803940039128, 0.08834082138491794, 0.1436156834824942, 0.13833708391757682, 0.12232461696839891, 0.20605989993782714, 0.2089424608857371, 0.2541766141075641, 0.12209884080220945, 0.19395619863644242, 0.10219265896012075, 0.1060992426937446, 0.11267065608990379, 0.13247548282379285, 0.11432983112172224, 0.2043025239254348, 0.11698868649546057, 0.12223231606185436, 0.12204413709696382, 0.09598241173080169, 0.20938181231031194, 0.12084778762073256, 0.11349668871844187, 0.12603126611793414, 0.16709699848433957, 0.1928255069651641, 0.12084075206075795, 0.17263022891711444, 0.12337426611338742, 0.1610303865163587, 0.20807396998861805, 0.21939510625088587, 0.1309773389948532, 0.10859006099053659, 0.11394238550565206, 0.14064842864172533, 0.1023397377866786, 0.18592899577924982, 0.1443910348461941, 0.1485546020558104, 0.32152417057659477, 0.23717043368378654, 0.08054660094785504, 0.11489155527669936, 0.11842693900689483, 0.12205555874970742, 0.2717463963199407, 0.08028849682887085, 0.09953864238923416, 0.1284978978219442, 0.16459167120046914, 0.09117264911765233, 0.11534177916473709, 0.1407442695926875, 0.16740295628551394, 0.17083886254113168, 0.14174179028486833, 0.08621059780125506, 0.2156315863248892, 0.26662649761419743, 0.15227611642330885, 0.196637355547864, 0.12512684043031186, 0.22856361349113286, 0.12194228474982083, 0.13481033878633752, 0.22860800876514986, 0.12166009051725268, 0.1602708428981714, 0.1017658127238974, 0.1606672239722684, 0.16964234237093478, 0.1298900629626587, 0.2399586231331341, 0.16606158373178914, 0.09567747067194432, 0.14286035526311025, 0.15720691590104252, 0.12779190758010373, 0.0953349843621254, 0.20711554563604295, 0.13683172641322017, 0.09281018312321976, 0.10121257873834111, 0.12253846682142466, 0.17890321731101722, 0.1445293118013069, 0.17608041409403086, 0.1711706173955463, 0.15859896229812875, 0.1422936809831299, 0.1226608915021643, 0.18184580316301435, 0.13430144812446088, 0.2114460218581371, 0.10559573260252364, 0.13340903038624674, 0.12562762683955953, 0.11475471066660248, 0.1331081785610877, 0.17790749261621386, 0.16770607908256352, 0.11515380800119601, 0.1020436357066501, 0.07645232806680724, 0.14905614545568824, 0.10402976389741525, 0.10233612352749333, 0.1842411293182522, 0.09768641990376636, 0.08665466928505339, 0.08382606989471242, 0.09838514451985247, 0.13791679084533826, 0.1771202520467341, 0.1187326964281965, 0.4271568398689851, 0.18963063543196768, 0.09910815220791847, 0.0987921679916326, 0.15764868672704324], [0.052480442318483256, 0.03551171437720768, 0.013481106052495306, 0.006894453581480775, 0.062254501244751737, 0.06519915768876672, 0.027707897970685735, 0.025557929548085667, 0.054333206571755, 0.11747814773116261, 0.04222128227411304, 0.017779548397811595, 0.02170579904486658, 0.05154651626071427, 0.021408676511782687, 0.013344338440219872, 0.04499888869759161, 0.02476501711498713, 0.0682812747254502, 0.012806609774997924, 0.06592332312720828, 0.03127946882159449, 0.009501885542704258, 0.02519764097087318, 0.03892570130119566, 0.12887131684692577, 0.02547568659792887, 0.018336905013711657, 0.049548387542017736, 0.048579157519270666, 0.019862445224134717, 0.05126287855091505, 0.009490029733569827, 0.05280837511236314, 0.08343902503838763, 0.016425581598014105, 0.012667793835134944, 0.04150952183408663, 0.06309586664428934, 0.06475463349488564, 0.12797057221177965, 0.04471509142604191, 0.02607148460811004, 0.049427666090196, 0.05561953403230291, 0.03809196517977398, 0.0691104021097999, 0.04813312305486761, 0.032315399366780184, 0.028545419045258313, 0.0467525131534785, 0.020983162430638913, 0.015613067189406138, 0.047802099215914495, 0.09245920664398, 0.013247684837551787, 0.0745512722642161, 0.04716812327387743, 0.013853404434485128, 0.032282889587804675, 0.046822126605547965, 0.012272124295122921, 0.04500066985201556, 0.06981415848713368, 0.025973970114137046, 0.015693781315349042, 0.03552256086550187, 0.01257676385648665, 0.03720302811416332, 0.04728541971417144, 0.048553141532465816, 0.0647300980926957, 0.026115430882782675, 0.055159098192234524, 0.015182842325884849, 0.043525992732611485, 0.0939540182298515, 0.0381958250363823, 0.06011088931700215, 0.042530609425739385, 0.019772506202571094, 0.05326427271938883, 0.034789998026099056, 0.03530206136929337, 0.008388662172365002, 0.030921532852516975, 0.06817412344389595, 0.024104405492835212, 0.02779241189273307, 0.03002561588800745, 0.029098716113367118, 0.0762466418382246, 0.05627480219118297, 0.027286142867524177, 0.04536929460300598, 0.05025372469390277, 0.02270843498990871, 0.06902302164235152, 0.06327439768938348, 0.05797603473183699, 0.03127796597254928, 0.09439378525712527, 0.04742307326523587, 0.03506149419990834, 0.015729704973637126, 0.029394129851425532, 0.0609333447937388, 0.008381376137549523, 0.031427360299858265, 0.048228938030661084, 0.03600673058826942, 0.03827560962236021, 0.023743269011902157, 0.03560358854883816, 0.02843701538949972, 0.06701266975142062, 0.005249648847893695, 0.022802726707595866, 0.002759608182714146, 0.04658809775719419, 0.06056654943677131, 0.03467892078333534, 0.027990441012661904, 0.039072679937817156, 0.036317430713097565, 0.03584901678550523, 0.04674440890084952, 0.020339558977866545, 0.04761245450936258, 0.05482498701894656, 0.06644850393058732, 0.04688582142989617, 0.05458585590531584, 0.0418303300102707, 0.07052872053463943, 0.03455334197496995, 0.02427540188364219, 0.021513504871109035, 0.019338264464749955, 0.001285417865801719, 0.006842469847470056, 0.04995912917365786, 0.04581360728479922, 0.04803336727491114, 0.03650477847259026, 0.02209807233157335, 0.029641966357303318, 0.051504473594832234, 0.034189667348982766, 0.06322831774014048, 0.028853362091467716, 0.0013779124265056453, 0.04600368614774197, 0.06392828916432336, 0.01926774002640741, 0.021879641572013497, 0.004842300686505041, 0.006964940912439488, 0.05142085952684283, 0.029617831714858767, 0.01713457011646824, 0.008801213716651546, 0.02489011167199351, 0.09393076674314216, 0.0935015307914, 0.036649905450758524, 0.04457744529645424, 0.07273652823641896, 0.05647557911288459, 0.019769537611864507, 0.011776601568271872, 0.05872935173101723, 0.034956465460709296, 0.10696883196942508, 0.009941919743141625, 0.032307540022884496, 0.037543866856140085, 0.04743789766507689, 0.038096952412161045, 0.006417082859115908, 0.04977703581971582, 0.016575719928368926, 0.033971386874327436, 0.04033329940284602, 0.05629930048598908, 0.03228444809792563, 0.05228357280429918, 0.10537484718952328, 0.08562709161196835, 0.061731710156891495, 0.05337405120371841, 0.03434239391935989, 0.034452172403689474, 0.022898927600181196, 0.0174468825571239, 0.022278868782450445, 0.013218623262218898, 0.08011608108063228, 0.05690602476533968, 0.015422351934830658, 0.04086996123078279, 0.06292736201430671, 0.013349681903491728, 0.020214521937305108, 0.044988877125433646, 0.04145988328673411, 0.047139546877588145, 0.06959975944482721, 0.0671993569994811, 0.02882790086005116, 0.03561749268556014, 0.023482279793825, 0.04092725503141992, 0.04825808588066138, 0.029763780621578917, 0.05765015026554465, 0.04772895685164258, 0.014878079382469878, 0.044932106538908556, 0.1269910708651878, 0.006861682195449248, 0.03461941909336019, 0.035999208921566606, 0.025816265588218812, 0.06252940758713521, 0.010119588969246252, 0.06733787144185044, 0.07099803246092051, 0.05094504638691433, 0.045248651076690294, 0.04792840903974138, 0.020710708886326756, 0.04836468055145815, 0.05397129454649985, 0.0276075373403728, 0.04384759500680957, 0.030887542488926556, 0.04882976594672073, 0.030022834689589217, 0.08204645913792774, 0.035905130571336485, 0.04207249279716052, 0.06344190042000264, 0.012018074157822412, 0.04932506417389959, 0.08092127420241013, 0.06874387021525763, 0.014103114863246446, 0.052063904513488524, 0.08872326492564753, 0.023123477367335, 0.01909104950755136, 0.04362068706541322, 0.10865482079680078, 0.082427069573896, 0.01725977228488773, 0.0031313274575950345, 0.04775669833179563, 0.0022245781519814045, 0.0202228896523593, 0.03267614250944462, 0.02466257290507201, 0.026181244538747706, 0.010270048278471222, 0.11978839407674968, 0.03343147072882857, 0.07470940166967921, 0.031429542214027606, 0.05097278786706738, 0.03716444014571607, 0.04097272270882968, 0.03770169940253254, 0.06496610847534612, 0.02253961680253269, 0.022645395110885147, 0.01645791326154722, 0.05658857480739243, 0.07162543668528087, 0.03499941354675684, 0.013708996411878616, 0.03175381621986162, 0.030916436153347604, 0.0608253400423564, 0.07265847656526603, 0.019804605944955256, 0.04706814113887958, 0.08171022913302295, 0.06728222520905547, 0.050830147083615884, 0.06802544899983332, 0.04966322005202528, 0.04986303218174726, 0.054379060165956616, 0.058886675906251185, 0.06893537400173955, 0.053452952633961104, 0.013503439131454797, 0.03507663401251193, 0.09942557619069703, 0.08692239905940369, 0.023485944147978444, 0.01889223185571609, 0.05133981328981463, 0.01017283435430727, 0.021921493134868797, 0.07437963577103801, 0.03980605171818752, 0.06676428034552373, 0.031224479389493354, 0.014291572133515729, 0.054436802965938114, 0.009002924816741142, 0.06542632167111151, 0.05739451007684693, 0.006029056048646453, 0.04692469141446054, 0.012599718484125333, 0.03448200674029067, 0.0028777314219041727, 0.022697948443237692, 0.017627942470426206, 0.02317324950126931, 0.07915715948911384, 0.07267544948263094, 0.017233669095730875, 0.06303796428255737, 0.011397358539397828, 0.01774820007995004, 0.008881392568582669, 0.014956969680497423, 0.05498826321854722, 0.039273215661523864, 0.009179328681057086, 0.01902213738503633, 0.05446247014333494, 0.044311255478532985, 0.02754718589130789, 0.02107405696733622, 0.020063878946530167, 0.011283180974714924, 0.1008485775673762, 0.025232430998585187, 0.04159536234510597, 0.046295506035676226, 0.08078887505689636, 0.02490763563400833, 0.016713668483134825, 0.02691213940124726, 0.015869271410338115, 0.06145089631900191, 0.031457784643862396, 0.04033858720504213, 0.1419078087201342, 0.09021628793561831, 0.15597253135638312, 0.2764888684032485, 0.12915717728901654, 0.1776613964466378, 0.08309155149618164, 0.08053690849919803, 0.14299515896709636, 0.23544589028460905, 0.16336297150701284, 0.19492235616780818, 0.18349308898905292, 0.15589511051075533, 0.18271344801178202, 0.08620673121185973, 0.10292506223777309, 0.15754129795823246, 0.0953906009090133, 0.06888557589263655, 0.16477366065373644, 0.204647385107819, 0.10660582527634688, 0.1138405480014626, 0.12901192414574325, 0.2125289785908535, 0.11239317449508235, 0.12534365145256743, 0.18693427933612838, 0.1930252040619962, 0.13737665576627478, 0.12106985304853879, 0.1420213424717076, 0.18745633569778875, 0.14109947631368414, 0.1258615666301921, 0.11986983736278489, 0.1807756707421504, 0.11005929074599408, 0.11985612989519723, 0.17056833487004042, 0.08820439979899675, 0.12100046966224909, 0.2365695167100057, 0.17329654394416139, 0.12292439845623448, 0.10878200264414772, 0.12189361470518634, 0.1430509684723802, 0.17147624865174294, 0.1799616386415437, 0.11739110865164548, 0.140305764216464, 0.22863815480377525, 0.1699296574224718, 0.1622530451277271, 0.1409957982832566, 0.15516004292294383, 0.06452120578614995, 0.1254868265823461, 0.11762869238737039, 0.16705842164810747, 0.11581613769521937, 0.23134614777518436, 0.17142737080575898, 0.12783817306626588, 0.229621663747821, 0.07360337898717262, 0.11358736432157457, 0.19349778885953128, 0.19879899424267933, 0.09611987974494696, 0.1449542655609548, 0.17553220444824547, 0.1365148590411991, 0.13702563475817442, 0.18132419208995998, 0.20685856958152726, 0.18108070828020573, 0.1107698080886621, 0.15913528273813426, 0.10545193406869657, 0.12482239661039785, 0.14434073207667097, 0.09076275353436358, 0.10101778723765165, 0.17034905991749838, 0.054762509316788055, 0.2134451747406274, 0.11254639830440283, 0.16751221526646987, 0.239868437347468, 0.23518052796134725, 0.12101083746529184, 0.1417283425689675, 0.1069418920087628, 0.14977999177062884, 0.12950668431585655, 0.18868806335376576, 0.1552034734049812, 0.16121954511618242, 0.18835641240002587, 0.1820046969805844, 0.09446912808925845, 0.11901826743269339, 0.11463721384643577, 0.10146989618078806, 0.13565218658186495, 0.12324312861892395, 0.20042683579958975, 0.10136293043615296, 0.1606905274093151, 0.08281902002636343, 0.17550548713188618, 0.051998584385728464, 0.10082774548209272, 0.163627369038295, 0.2625894220545888, 0.11783970723627135, 0.1178738015005365, 0.134440986730624, 0.14508163294522092, 0.14719929196871817, 0.16505340579897165, 0.22605367004871368, 0.23410690744640306, 0.23611876589711756, 0.06336468737572432, 0.17324790358543396, 0.1955208834260702, 0.1744818576844409, 0.17851534124929458, 0.18573882785858586, 0.1264716565492563, 0.2115105590200983, 0.11249388393480331, 0.15424585057189688, 0.08136364616802894, 0.12443619780242443, 0.11876059375936165, 0.10392627140390687, 0.12167970548034646, 0.08384788161492907, 0.07980849055456929, 0.11510470751090907, 0.14380620763404295, 0.14850456645945087, 0.21741419535828754, 0.07430187353747897, 0.13075277995085344, 0.09968518686946481, 0.14417613856494427, 0.10411747090984136, 0.13553216645959765, 0.1306307115009986, 0.10393087271950208, 0.09781562039279379, 0.13197674474213272, 0.13380992371821776, 0.15089530614204705, 0.10124510707100853, 0.07347181104705669, 0.10206367369391955, 0.14996447484008968, 0.2303043653955683, 0.09992176870582625, 0.12934917089296505, 0.12701998493866995, 0.1736455611535348, 0.15592666662996635, 0.0877252544160001, 0.1315812097163871, 0.12275679924641736, 0.20169630908640102, 0.15330828056903556, 0.11714260050212033], [0.0860705842205789, 0.013744619500357658, 0.04145615399465896, 0.020915116765536368, 0.03472415468422696, 0.02754310964519391, 0.043277417789795436, 0.031959205589373596, 0.02401831265160581, 0.04721412158687599, 0.017454574917792343, 0.04075839417055249, 0.028803938766941428, 0.03361396855325438, 0.012574317552207503, 0.021456346512422897, 0.047797108272789046, 0.0578553466766607, 0.018862239812733606, 0.05903953977394849, 0.01904139240650693, 0.04603039604262449, 0.07321768483961932, 0.05235768738202751, 0.08191463144612499, 0.011820990348496707, 0.026058042458316777, 0.05827015527756885, 0.033724452077876776, 0.01503553436123184, 0.04882340203039348, 0.053605144858011045, 0.08366752488655038, 0.05147074298292864, 0.022879425814608112, 0.06085134118620772, 0.023188999730336946, 0.010824769342434593, 0.04798702757398132, 0.04090480135346297, 0.07224896689876914, 0.0109188727401488, 0.05308471751050092, 0.015883581872913055, 0.024174688733182847, 0.010172860329475952, 0.05896687238418963, 0.06959496517083608, 0.09487673785770312, 0.08440060351858847, 0.017109869586420245, 0.015810393124411348, 0.042397813231218606, 0.037110278208274394, 0.04925393674056977, 0.011323706876282813, 0.0271913687538472, 0.04182049655355513, 0.060826698172604665, 0.07559427918749861, 0.023240560440171976, 0.04296354869438801, 0.029959941384731792, 0.040816155524225906, 0.06689116533380002, 0.05233701114775613, 0.029788911597279366, 0.04390592410345562, 0.07672723440919071, 0.014210355202521896, 0.03194873017491773, 0.030906560023140628, 0.02821597041474888, 0.018259615899296477, 0.041134447819786146, 0.03475499092019163, 0.06656039753579535, 0.07559378937003203, 0.04372757117380388, 0.05672226157912519, 0.0904272730986122, 0.07651032690773718, 0.03694798535434529, 0.020482084728428163, 0.024843226492521353, 0.02995733273564838, 0.055018027051119134, 0.04614567384123802, 0.05988393313600682, 0.04154525995545555, 0.01318488708420773, 0.0796479862765409, 0.016802837526483927, 0.05371318671677727, 0.017656871386861894, 0.05117490436532535, 0.01426023309250013, 0.06341514599625953, 0.029874286410631612, 0.058458790663280524, 0.027827662052004598, 0.03362601361004636, 0.0668110282276757, 0.046083248089416884, 0.011833758999273414, 0.026692628816817887, 0.035511510286596604, 0.016296551802952308, 0.04688870467361994, 0.02750451982137747, 0.02204316268034745, 0.03821920639893506, 0.04587113857269287, 0.0751263253914658, 0.03492284246021882, 0.06685661093797535, 0.025812894382397644, 0.07905529229901731, 0.012743028128170408, 0.028238548402441666, 0.009563851162965875, 0.06709467706969008, 0.018631747298059054, 0.019075288146268576, 0.021692696427635383, 0.03713511046953499, 0.012696147587121231, 0.053666253297706135, 0.1222680059436243, 0.02301357457326958, 0.06032266486727167, 0.05409956364019308, 0.06344164808979258, 0.014711457952216733, 0.028225291789567564, 0.02374413361394545, 0.014517132149194367, 0.007067059505061479, 0.07316845818422735, 0.023156113311415538, 0.024175282451324165, 0.04564413786283694, 0.007654490727873053, 0.02973362716147676, 0.025547643381287344, 0.032602914798189886, 0.014820587057329249, 0.018249203567393124, 0.010307592601748183, 0.034111838322132826, 0.031170454749371856, 0.0814751983853057, 0.019416067516431212, 0.060463216505013406, 0.02350420840230072, 0.03133579040877521, 0.015539107535005314, 0.0643036600376945, 0.04479798561078496, 0.0088129980940721, 0.0038060746737755835, 0.043054706693510525, 0.007173707981564803, 0.05805487679026555, 0.020378601511765737, 0.0883076325408183, 0.12714901473373175, 0.09652268039644696, 0.052369138720678166, 0.03298173665825743, 0.017944945284398273, 0.03502984531223774, 0.024940418152255006, 0.047310823429143056, 0.0831127620767802, 0.06752778703230433, 0.07718747729086317, 0.025123854793491773, 0.05838835713802837, 0.029388029397523496, 0.08272172446595505, 0.062222091655712575, 0.026599062548484653, 0.027422358507465106, 0.007350417517955066, 0.031358596606878564, 0.034977980321855284, 0.02402500125754159, 0.03584973295801319, 0.036854727077297866, 0.010064132911793422, 0.010095999805344036, 0.043784482768387534, 0.03836989948467817, 0.005269187277008314, 0.05323975216015242, 0.03621801261033397, 0.02705394526856253, 0.01803768776881043, 0.03545069499523379, 0.028680970463028643, 0.019917816862289328, 0.05865665836608969, 0.07467293253284879, 0.03764605316973757, 0.03849184919090476, 0.01303443426877493, 0.015079468576004729, 0.01978245283680735, 0.028477000450948253, 0.021123378246556967, 0.03936748325941153, 0.053562560424325056, 0.02831226036505541, 0.0221250178583432, 0.04291756893508136, 0.07832478891941719, 0.014108731993474066, 0.03549528322764672, 0.04285544375306927, 0.02933525527623715, 0.030580964994442184, 0.04644372776965611, 0.042012456760858186, 0.028152845188742504, 0.016485814303450752, 0.039818234072299674, 0.039437768355128355, 0.049726959405234084, 0.03196727644535713, 0.0528780330932932, 0.03899581941368524, 0.019591728305385914, 0.03800778336881194, 0.11030438501620665, 0.020560075172397774, 0.023064415399858262, 0.0492143802694045, 0.03218602447304875, 0.04809681719052605, 0.05802998144645244, 0.03522811377479229, 0.016956104009295814, 0.04709396045655012, 0.0696446445363108, 0.04676282900618389, 0.05343854383681901, 0.039539969511679374, 0.015171454997471301, 0.020728331182908732, 0.0237618727987865, 0.05509939983312506, 0.030906702886568382, 0.04308600306103472, 0.02139880038157571, 0.025539344314893242, 0.016919191439228598, 0.03845012564852368, 0.006926819569343934, 0.052707613722304814, 0.03517253433528822, 0.017586471258255187, 0.0743764964863658, 0.013889868932892568, 0.024421690322924405, 0.0348193351237569, 0.09390983075718395, 0.06164341313706245, 0.10200986798736267, 0.015116780050448142, 0.062164092814782634, 0.04583148933306802, 0.03319238414405845, 0.052474174881353974, 0.028998394445807207, 0.0277119779275381, 0.03433688347286079, 0.07045191567158327, 0.049636966577963904, 0.06061255517124664, 0.032498012224095874, 0.01574831247125985, 0.05275999450532254, 0.021370082977227867, 0.058804601794690825, 0.022721595123584848, 0.054567480328842066, 0.06013843412802089, 0.012515577491285512, 0.043079850656795315, 0.03567546926205978, 0.018198553843831178, 0.037528007160290144, 0.0430102928658016, 0.07793991855578497, 0.04355908509751316, 0.023285432544071227, 0.018019495873886626, 0.021309032053977717, 0.07662891468498856, 0.0411641374375904, 0.048368116695201024, 0.09419883048394695, 0.0373190035315929, 0.033045635573216714, 0.03241663202061318, 0.043833854142576456, 0.008171530171239283, 0.023931201212690212, 0.01743418997648405, 0.003288604784756899, 0.024584059246990364, 0.06339563493384048, 0.09319043732830323, 0.03634660824900493, 0.06103043255279772, 0.03636222674685996, 0.047024788582348265, 0.05661313247401267, 0.023307678420678712, 0.021817670385644305, 0.03128620381176006, 0.03711018543981481, 0.01642709186853608, 0.04349205431935843, 0.04369885748019442, 0.06418093107640743, 0.049230061849812046, 0.042721897989395075, 0.012765409446728881, 0.01753412201651372, 0.019107536318188068, 0.05832898532389663, 0.05088934820378199, 0.07746553033939563, 0.04603216235409491, 0.04899346145975869, 0.07238895821501501, 0.07790763513185084, 0.09751867226441391, 0.05724464077502489, 0.028872019684058614, 0.01754547130985884, 0.07864666578825563, 0.07672800624277443, 0.018632713945407886, 0.02950376547232736, 0.05095301334222313, 0.0215178946746164, 0.011537606824276736, 0.051389837753959, 0.06665077627985738, 0.13714066764805466, 0.1240223168861121, 0.11686679616104811, 0.1291526947170496, 0.15305183886084706, 0.1604371433495544, 0.1264365529641509, 0.13552545744460076, 0.09003262865007855, 0.0933463625551667, 0.07357891779975034, 0.15317784069338813, 0.13419125403743237, 0.13989810249768198, 0.1778415305307135, 0.1310630125226453, 0.2336872526211664, 0.12989426351850852, 0.1607357242028229, 0.11983914955635555, 0.16058837820310146, 0.12447794360923581, 0.17561455315444618, 0.14011765946634114, 0.18998058774741367, 0.13650669541675597, 0.13669974287040532, 0.07431411155266687, 0.14954032259993255, 0.08575833300710656, 0.09159318709862418, 0.18486477085389197, 0.12395343816024251, 0.13832172146067023, 0.1510877747205086, 0.16026438621338457, 0.15733637614175677, 0.15593260381137952, 0.12050496734445915, 0.17821242625359446, 0.1386575135984458, 0.08497734874254093, 0.1661722082644701, 0.11562045561731793, 0.1533871708670631, 0.14591208135243505, 0.14038245775736868, 0.16299195704050362, 0.15173780702752993, 0.2323943274677731, 0.10424540974781848, 0.07349031278863549, 0.14441040490055457, 0.11918992619030178, 0.11440642818342894, 0.11520928354002535, 0.12935141217894852, 0.09648118691984564, 0.21146561455680057, 0.18991207267390564, 0.0805095380928833, 0.15152438019867986, 0.1700752371107228, 0.14445883745793253, 0.12206564453663304, 0.1264401152729988, 0.11658069823170081, 0.1427741622319445, 0.19774625776335597, 0.12920264125568792, 0.12851271108957008, 0.12475518771680072, 0.1303491258295253, 0.12467669817851856, 0.07881302561145276, 0.11473134785774164, 0.14051322417799383, 0.12270110106328502, 0.15224271977785975, 0.12724461819743738, 0.12443184139556251, 0.20387046039104462, 0.1757476053899154, 0.13008533685933799, 0.1420181363937445, 0.09714334591990337, 0.1683037751354277, 0.11358208765159361, 0.13715819717617705, 0.1463644500472583, 0.11600145197007805, 0.18906992801930755, 0.25092386989854276, 0.11940767974010669, 0.1659359084442258, 0.15139156545046717, 0.16044937394326553, 0.1785459028906189, 0.1091534698207397, 0.15564518485916778, 0.10440019948873669, 0.12730919988825917, 0.15334770345361903, 0.1331578430836089, 0.13816794846206903, 0.15761794697027653, 0.10111838535522111, 0.08688429719768465, 0.15805118309799582, 0.13663964375155047, 0.19100994657492265, 0.1106375276867766, 0.09420238537131809, 0.20739609230076894, 0.07674793290789239, 0.13924513128586113, 0.12451642396626994, 0.17813129466958344, 0.21216989785898477, 0.20573035668348894, 0.08997459270176478, 0.14502552658086643, 0.12622330425074324, 0.13462600414641201, 0.1993953692726791, 0.23175965761765838, 0.1431059170863591, 0.11438086861744523, 0.13335342868231237, 0.13623135862872005, 0.12961693777469918, 0.11913848793483339, 0.1113600232929457, 0.08562225280911662, 0.08343054971192032, 0.11136972316307947, 0.13145022065145895, 0.18357959372224286, 0.12776852992828935, 0.11734847226762213, 0.0872804259415716, 0.1040329402894713, 0.16150068549904972, 0.1339167039259337, 0.08454212365904823, 0.10442059370689094, 0.14695720339659601, 0.1275326160248369, 0.12051859317580238, 0.14127612230367959, 0.2040337774087675, 0.19455003552138805, 0.08015249084564857, 0.20305639860453084, 0.15421119227539748, 0.07331857981625944, 0.14378444786416367, 0.31270876235794276, 0.1751966794836335, 0.18762462510494515, 0.18502330844057724, 0.14885582495480776, 0.15814141341252252, 0.23114731156965718, 0.13335463096154854, 0.12341925510554574, 0.25030245480593294, 0.24039850890403613, 0.110719060030533, 0.11031179165001959, 0.0951488091959618, 0.17761093040462583, 0.09732296792208217, 0.16178240475710481, 0.18557228991994634, 0.19345320062711835], [0.031738479738123715, 0.027530174011189956, 0.07224161963677034, 0.026565254011075012, 0.03365335061971564, 0.01686292922386201, 0.02242242426291341, 0.01711221477307845, 0.028911923109262716, 0.05662585659592878, 0.0005134186903887894, 0.04843052760406863, 0.01846006442065118, 0.06522079871501774, 0.14171697286656126, 0.08403048705076799, 0.025671995790617075, 0.014563664808520116, 0.08184522579540499, 0.012664142468565842, 0.05662445393681992, 0.06082622319809161, 0.04173699751845561, 0.04929001253913157, 0.07826820758054964, 0.01064952044544043, 0.017633842544455547, 0.0512119412451284, 0.016574549190409016, 0.04484492645133287, 0.043519981336430646, 0.007474434105461114, 0.025679882965050638, 0.06346720023429953, 0.04477103822864592, 0.01821080113586504, 0.04276519859558903, 0.03738043480552733, 0.046957883969298564, 0.0437275229342049, 0.014484499915852211, 0.008095750399661483, 0.017848538445832673, 0.05716441461117938, 0.0421197713149013, 0.007856477350287605, 0.027874504557985347, 0.04002427282102872, 0.06983899816987105, 0.07309364969842136, 0.015337063396145822, 0.038155778747750446, 0.04001533736300189, 0.018338782647333574, 0.05729689910367597, 0.0027281893608233077, 0.03428906318731606, 0.06881231107399799, 0.043573056027526036, 0.018245546634716447, 0.028200038359500468, 0.048100101193995215, 0.027390939685574267, 0.06775504007237032, 0.02038333455857355, 0.047506757837254554, 0.007304393693630118, 0.0028003569605061784, 0.011357800212863367, 0.08514774584909901, 0.04470710962777957, 0.025615653794375248, 0.03832158196019009, 0.005187467077121255, 0.07293828850379214, 0.02593061941297492, 0.0351583296287572, 0.023385607637465, 0.026542835585132707, 0.033179225865751505, 0.026901769742835313, 0.13724752207053825, 0.04914996927254833, 0.024003293437999673, 0.05282322548737284, 0.04330752301029861, 0.042117366756428964, 0.05839981960889418, 0.06386037523043342, 0.05936319037573412, 0.041551865069777705, 0.04692416077887174, 0.0371467287914129, 0.0395394982479047, 0.06901836837641895, 0.02250774712592829, 0.01395961504385923, 0.046482994803227484, 0.07336120877880603, 0.007099751574060065, 0.0537581089156447, 0.03078318539337488, 0.03333052751258947, 0.022510188791784458, 0.026392329891677946, 0.025584277645975817, 0.013428055481199408, 0.019835230668832082, 0.02804658819513861, 0.03228986948670354, 0.10086155773024075, 0.008629673702671425, 0.036203429408487864, 0.04639336562831886, 0.09393086322234012, 0.020631831575883552, 0.0181214632539195, 0.07605195423820987, 0.07460128559614532, 0.04206932753731962, 0.019996766532131005, 0.03424513175559696, 0.03308096551336348, 0.040731268672971055, 0.021078157333249692, 0.045072454086039215, 0.042162615500274114, 0.03204502383596264, 0.046036656058277, 0.05564356477407273, 0.0426651682209922, 0.05100669288367499, 0.025166474479192402, 0.07458529973519035, 0.0626537692733109, 0.03230273461667821, 0.039444173089577816, 0.09641326556447893, 0.02268155811179895, 0.014559318606188754, 0.05026443759561516, 0.06106357315729838, 0.027727982342184987, 0.054780803257017396, 0.013864845568605233, 0.04175971094809938, 0.02870554853870999, 0.04749686871946324, 0.01937841465405654, 0.005845801697432762, 0.01806831620342564, 0.06300240798736922, 0.03466600370302331, 0.0568525270500686, 0.07042768454994075, 0.008640617597848177, 0.04078850310179405, 0.03981519868830219, 0.022627993603236973, 0.06139838194940239, 0.05502466927282512, 0.03545621657394804, 0.05839999772433657, 0.08079268969595432, 0.020514780044322833, 0.036913160074618645, 0.0645191129297018, 0.025267122691730037, 0.06605793387279846, 0.020217330966261216, 0.014047435233806027, 0.03170285664964467, 0.011677173260977725, 0.09896010858938098, 0.032249723008135334, 0.026942984914057888, 0.018645872223714832, 0.019322690495755523, 0.02119961351127131, 0.015450895862159086, 0.021641599560098257, 0.08268259844044223, 0.06786897458368912, 0.04222289273457136, 0.028127404366387054, 0.03674257000966463, 0.06403222694643773, 0.09404494616319425, 0.08462227560812607, 0.016355099833162967, 0.038731629683752544, 0.06273142018471844, 0.03636221561464481, 0.003855391314573353, 0.0005113332554174121, 0.07735932900686748, 0.0561021229805192, 0.06360491315717809, 0.033928075135918334, 0.013909616554883542, 0.02439303971186746, 0.04878041312622372, 0.05355989982490428, 0.02736877358984202, 0.022520951788465027, 0.020876797825621907, 0.015366825373348547, 0.038897213962627575, 0.02101172398397466, 0.00905960727322963, 0.14273695094743744, 0.044036274921381846, 0.06278843196923845, 0.0428145143087022, 0.04950347276462708, 0.04153073241468519, 0.07050301253912039, 0.013179294073779602, 0.037084562791278586, 0.03145682356262114, 0.07761825690977275, 0.02183399577916134, 0.05585326602158602, 0.03844741680950392, 0.034278569219168276, 0.041209991031792015, 0.032661911827744916, 0.019066441745962948, 0.0464415829628706, 0.03371929415152408, 0.02289641728566494, 0.07346717262407765, 0.025740252967807464, 0.023138978976930957, 0.04132055619265884, 0.030144025549816433, 0.03175120386003982, 0.08608559786807746, 0.038386037485906854, 0.04817715467652306, 0.010741799087554682, 0.07389372942270711, 0.022228653215279337, 0.02064659660391044, 0.02901558815210592, 0.03999424552603159, 0.021461114811245352, 0.04410293091495987, 0.05955218570306897, 0.03829165856586769, 0.04557886968541425, 0.02147880761185661, 0.057973585644504055, 0.021434941118059214, 0.025445694554946385, 0.04737963907246012, 0.013895378451707074, 0.053332654206315055, 0.031859101000009105, 0.05246371430985164, 0.0756404481944628, 0.07744230111711659, 0.055487821373390034, 0.10616836632834747, 0.040395673204329796, 0.036293756202212535, 0.04243155868607573, 0.03302842887933366, 0.0468913467193488, 0.08399056692724116, 0.00936175692913821, 0.03113499864412006, 0.036680259290733375, 0.028063345889677294, 0.011848520316561917, 0.010201141722063767, 0.01703608711977722, 0.05385171600210015, 0.023814062478777487, 0.02992064466525335, 0.042600864835549146, 0.030340754055941943, 0.04159774834988639, 0.04800551447260659, 0.05053144748671912, 0.013448035952023929, 0.053935693722451106, 0.027046076647820882, 0.04583004214509856, 0.036894892109557986, 0.04636074823793024, 0.04399242141516879, 0.04151780049141962, 0.05284751969156787, 0.054206599888857454, 0.03164568901411258, 0.02149713309336221, 0.030196677216736134, 0.03623696706199553, 0.017027142384904437, 0.008596688021498267, 0.04504985197854694, 0.02855184233339969, 0.04905723049887456, 0.09394250009790994, 0.04725180784589611, 0.030075514187046792, 0.009423866340512177, 0.0588190588314319, 0.01630944105272647, 0.014875628439767752, 0.07781610605889, 0.015443218344444176, 0.05127739495947026, 0.022372704079316463, 0.006944075430510566, 0.03219045880541671, 0.05351013511244673, 0.04922017644275911, 0.021329058909032028, 0.02218937319412362, 0.07529590613557957, 0.07048371669952758, 0.0659164805256296, 0.034436416608514264, 0.06300777371507138, 0.06337981234537438, 0.130780981562566, 0.013196555501053808, 0.07066736856359057, 0.05676431908796076, 0.04951351031195372, 0.03027497194125317, 0.06889672295073979, 0.01891884527140064, 0.06335584839689545, 0.04814852632989641, 0.033530406435602345, 0.015893567469902337, 0.044473169837147, 0.0399697435204871, 0.04443488614924718, 0.016009472383302636, 0.03908135935489554, 0.014663185884273844, 0.026721498361439444, 0.009818114667723421, 0.029325774339667987, 0.05701379202946555, 0.032181835049414076, 0.046231057931436226, 0.01257380268725683, 0.15972960944054648, 0.11016483156709, 0.1437663394608535, 0.220655050361529, 0.082965186011279, 0.23402365332003683, 0.09847143403021619, 0.2142874975106679, 0.10038978929514997, 0.18996265745954588, 0.17534932441776618, 0.15591773117193952, 0.11346017505275086, 0.167264174669981, 0.30801933899056166, 0.17504229792393744, 0.18506746622733772, 0.08095660043181852, 0.1475398486945778, 0.2355038668611087, 0.16885940625797957, 0.1795000079437159, 0.17529722565086558, 0.10232485030428506, 0.09451123754843138, 0.09671554231317714, 0.14636295090895146, 0.1459343160968274, 0.1403462706366554, 0.12580312992213294, 0.14989199669798836, 0.18395987019175664, 0.09075142836081795, 0.2654408128000796, 0.2406645836890675, 0.11108225226053037, 0.21513508952921256, 0.1579977633082308, 0.0881155498791486, 0.15564718865789473, 0.24336004920769483, 0.10045676070149057, 0.1060582538775634, 0.14906468015396968, 0.11293923933408223, 0.09416391243576072, 0.12678266095463187, 0.08803500459180214, 0.2249568054685369, 0.30098778661340475, 0.12012715480523184, 0.1895389356650412, 0.10074344492750242, 0.13299066689796746, 0.1598750555422157, 0.18289233528776094, 0.12460042024031281, 0.16367963107768446, 0.12960302992723882, 0.2072806141222827, 0.14704007160617039, 0.25325638067442924, 0.15302590822102502, 0.14566266036126763, 0.07772260287310928, 0.11955554524320178, 0.10816859532496892, 0.07315869152080268, 0.12809167586965486, 0.2492035715840757, 0.1737857676926069, 0.12920305685838684, 0.1366795861395076, 0.155265131033957, 0.20259899814845994, 0.14865302568068728, 0.11561120103579015, 0.08563366704038344, 0.13109721068758518, 0.17067030596081167, 0.15882663836237043, 0.24509980663424358, 0.09454627434024587, 0.21522937197005376, 0.1477503069327213, 0.10918644344201311, 0.1652372209355235, 0.23595589416800067, 0.15800990484422073, 0.09322915517259389, 0.11517550839926116, 0.16990846168482676, 0.14712101023178548, 0.10086958776810206, 0.18143213004805148, 0.12177343131043017, 0.09735676532727666, 0.116025542083662, 0.22670042206300423, 0.11308198401820846, 0.14451283612288535, 0.18744783068541437, 0.1957532053347677, 0.1790541404625401, 0.09007092347019352, 0.05005775317840744, 0.14553311106283218, 0.08811819192487746, 0.16074376908363774, 0.1373252843040973, 0.18937554443255067, 0.14772427239222452, 0.21984826162224635, 0.0995988528302405, 0.15546134003670886, 0.14008188794832677, 0.12951143406098709, 0.16360094858100638, 0.14669353317003697, 0.1103820359276142, 0.10487909996300004, 0.09856205026153475, 0.11397109919926152, 0.13342396239750087, 0.06399045887519605, 0.1428583514643833, 0.17734527122229338, 0.11610089975874871, 0.1322694032569416, 0.21622974250931293, 0.13123403303325176, 0.07549996706075035, 0.26729698351118714, 0.12069819291355088, 0.14323846466140822, 0.20253144786693156, 0.14122040185611695, 0.11582764098420739, 0.19848980067763478, 0.054467661466333084, 0.1294898969354108, 0.18704490386880934, 0.2048017072957009, 0.16318047739332542, 0.16654613194987178, 0.15518527594394982, 0.22179821011377499, 0.21954715746687725, 0.1790610424359329, 0.16062469891039655, 0.1250546591472812, 0.17833640944445506, 0.2104728139238432, 0.1706357070361264, 0.19320783176226541, 0.14874278102070093, 0.14311097853351384, 0.29798761010169983, 0.13497132546035573, 0.10189746230025776, 0.14344377239467576, 0.16108925367007032, 0.1284014483098872, 0.1768565076054074, 0.10222140233963728, 0.21428604290122166, 0.13936690287664533, 0.15911977185169235, 0.20345025637652725, 0.11469372097053565, 0.17798396351281554, 0.1282919815275818, 0.10257977803121321, 0.1529360786662437, 0.07145426774513908, 0.09750587021699175], [0.035105087954434566, 0.05704955241526477, 0.027808666782220826, 0.04572030076815281, 0.028870552087028045, 0.04669086294597946, 0.024287150081363507, 0.0768837533541955, 0.06468864914495498, 0.027368294904590584, 0.06529477599542588, 0.04631762574717868, 0.07052213026327081, 0.04970799753209576, 0.06153757174615748, 0.044826643643318675, 0.027607463125605136, 0.025131840302492492, 0.016143289030878805, 0.008821242427075049, 0.012480788391258102, 0.09067429695278406, 0.06551368729560636, 0.03858738215058111, 0.054411043020081706, 0.05361841816920787, 0.012470255460357293, 0.02048767124506412, 0.01220566033225623, 0.010426292628835654, 0.06309913951554336, 0.05122802729601972, 0.0069491257454501465, 0.0490025342151057, 0.026847086446650792, 0.027102468739030883, 0.03620968200266361, 0.025986974396801088, 0.01759806360496441, 0.05406679410953075, 0.05346263023966458, 0.03371974315086845, 0.02519338289857842, 0.0808046902238857, 0.016459538564959075, 0.04641123283363413, 0.048807315979502164, 0.016283124496112578, 0.01336738027021056, 0.02129856035026023, 0.02136883431376191, 0.07228107220726088, 0.02090972506266553, 0.04265891562681645, 0.0294362986824126, 0.027015782179660164, 0.03963114977523219, 0.02312748496478889, 0.04293397410947364, 0.029950571770314127, 0.013546541213145247, 0.03638975671492517, 0.013171925475035096, 0.05358424597943667, 0.05618307273834944, 0.018566989347164053, 0.03558119053195696, 0.048840322997421026, 0.07074877474224195, 0.02669979425263591, 0.022527044820890296, 0.0016925112618082494, 0.0357310820982093, 0.04198835922579747, 0.01005177708066185, 0.03006630970048718, 0.082729702553479, 0.04362557410786394, 0.018645575364644174, 0.01748629059875384, 0.013272208179841982, 0.009668514394434169, 0.035354419887880795, 0.020648049357987475, 0.025057712737179827, 0.009270170339732431, 0.018281438751728274, 0.0668474157282617, 0.010916439423453994, 0.037638509238604456, 0.06597812331165187, 0.03402108479349408, 0.04587260802509263, 0.0884899336961098, 0.03469216069788672, 0.018238524062326178, 0.01800343579816399, 0.08312675156048499, 0.041470388387097046, 0.08792144115432166, 0.018921708106063306, 0.005592297966359183, 0.017231283090950456, 0.010186342369706836, 0.05971351376501843, 0.011357868861523457, 0.02554950988269411, 0.010241450545436237, 0.014263084794947645, 0.023815986496629193, 0.017463721887907013, 0.024125020499923266, 0.030428279242187273, 0.04281638452084735, 0.030660094635095447, 0.06291592551860958, 0.02884584970161086, 0.03018815921677742, 0.010014598265115637, 0.024719161665416323, 0.015527769373875344, 0.053609504975611344, 0.020691001154773403, 0.07565575127955526, 0.02317064270755509, 0.022768645430915058, 0.08359690953511745, 0.0340651461010566, 0.05486593130626716, 0.02013741835980909, 0.05430167271697428, 0.014836653626844054, 0.05362674877687823, 0.033873163629323244, 0.009760531429492403, 0.021273100974212866, 0.06913734949193895, 0.06936049103387631, 0.042322151275584474, 0.033832931803772226, 0.04674477255321108, 0.04197513044346124, 0.06980247708270326, 0.010435273543407675, 0.04584319671266712, 0.03652955507277511, 0.04471476859180257, 0.032854428645805456, 0.04547077216557227, 0.0208798758831108, 0.04892871278570965, 0.04727267332782503, 0.05092005085316487, 0.02643251162226079, 0.04537510190857574, 0.03119037028227467, 0.05777112033683807, 0.012506351667980198, 0.038009609052096494, 0.02970336237922311, 0.011930332821066258, 0.030581838873331435, 0.05035343594499864, 0.00183493114036537, 0.011114034386991989, 0.0378221944993129, 0.028986488541704603, 0.029978443126310594, 0.044964248954784125, 0.04408027685713023, 0.015675732283852994, 0.06418909470085055, 0.01552165964312735, 0.04633338154235389, 0.05756116304837633, 0.04208295707940124, 0.05177151317184325, 0.022152058008941822, 0.04698546588770114, 0.03744372144865338, 0.020622256015485618, 0.018439480954839382, 0.04582649838994257, 0.05525748842046596, 0.021729119180236012, 0.03219258134777192, 0.01978318385226885, 0.049917843498406, 0.045054379079374485, 0.040869219083106145, 0.0572435757931089, 0.07068052684189752, 0.04777281035785563, 0.07316972725675441, 0.039265942614292726, 0.02599292085506022, 0.024769867050054017, 0.06074151075154077, 0.046844457829138264, 0.0684066976828035, 0.019613810909504537, 0.02350541624764446, 0.02997927618707763, 0.06076029079849832, 0.03517634155286942, 0.03785163920838386, 0.06060888525098562, 0.02377710352448048, 0.04822053691896144, 0.023081584986357484, 0.02665518746653106, 0.025014078164531384, 0.010069959698739694, 0.02547888710978441, 0.03132348931103479, 0.044084529363317415, 0.021825195763085503, 0.058015082831843756, 0.02631238388858037, 0.04828898890991695, 0.021088417524879333, 0.05858737145899795, 0.05932697356911376, 0.05748005001805723, 0.016593555592407938, 0.03696253144880757, 0.06262341543333605, 0.03950782338506542, 0.022017534465703648, 0.029027640630374663, 0.04335538040322717, 0.04682208578742575, 0.013827062830387149, 0.04181776545010507, 0.017482093753642403, 0.04902737018710468, 0.03789945949392859, 0.014599000314774457, 0.05470647716720123, 0.044088028589612804, 0.01760267790814396, 0.01908705489768181, 0.06199734707479365, 0.04013149831735063, 0.04090088281373028, 0.03277193522080779, 0.0832106290908996, 0.040723119891481474, 0.076084460306447, 0.023360985032923054, 0.02496413162589306, 0.01282752071347204, 0.0363732624828117, 0.04514421605563257, 0.04209784456179477, 0.033362206086167134, 0.029093515513523016, 0.03578042749722954, 0.05095251981401816, 0.07105354510713369, 0.04792179279320408, 0.049766415686463006, 0.05278143515170086, 0.05955893924692646, 0.039562887031934224, 0.031432110044988804, 0.042013647907879204, 0.039509125854237936, 0.02230893132946221, 0.045854985728510655, 0.029686376474273857, 0.018661403519217856, 0.035971011020592414, 0.04293369209335651, 0.021366234941524453, 0.07155299565056339, 0.03787683141126763, 0.02414713650068734, 0.057434597183601, 0.02072946295811562, 0.007363521990555455, 0.027644251385936514, 0.04773444503371138, 0.01500030461102142, 0.07056873713736422, 0.03731871780473739, 0.04422482496011071, 0.03567614090570714, 0.010349781841796357, 0.05151897144969553, 0.07887057916377671, 0.04197613234282471, 0.04910049399768468, 0.058177705941488966, 0.03424589245696552, 0.03307649778435007, 0.0023809813683328684, 0.03315507638035342, 0.030419538597925566, 0.044166373409098014, 0.007100622669895529, 0.00995939639324206, 0.024132894686772488, 0.0590192420349922, 0.016992597265925724, 0.09606021849322133, 0.03304482663224917, 0.010086274887726177, 0.04884090187260881, 0.05527674715267494, 0.025785212274058722, 0.08295078834635206, 0.02346172415855108, 0.02950936868728604, 0.02957334552775137, 0.012481955418479629, 0.03653781888715457, 0.005310894584908965, 0.044687557747238316, 0.06531177859869786, 0.08353098455700092, 0.04139205841056537, 0.04164103782386519, 0.018276527589478064, 0.032572445925325155, 0.0330926914466545, 0.0297290369780967, 0.0033466936110926326, 0.04395470175950322, 0.015663041558582336, 0.0423619823413901, 0.0675289670471102, 0.07962370320456102, 0.04087228044227231, 0.04938097386911977, 0.037669467928935774, 0.006235460768948542, 0.023543798270111438, 0.04452083056094125, 0.04857814077695366, 0.011643140223895898, 0.030087909908615984, 0.05142058493220247, 0.03582016950531397, 0.03153907207888551, 0.0637147287488915, 0.012450261074263835, 0.020617454320017714, 0.019928579858969897, 0.03776668927457649, 0.0760793246445246, 0.04684100684244186, 0.12189564818982035, 0.19534085324266925, 0.09873636590782553, 0.11567504800041206, 0.11181274079717696, 0.14477747114142403, 0.08624987967777997, 0.13548881019232795, 0.1557314966339618, 0.14155410113744438, 0.3152890020282939, 0.10882855756790377, 0.21645157044986263, 0.15728193218819797, 0.19937461882364005, 0.25782426993828267, 0.15127265854971483, 0.13377847149968147, 0.13332619186257944, 0.09058810392161831, 0.10685050394386053, 0.19914382573915645, 0.13441759423585609, 0.13290223258081824, 0.178896582510788, 0.09330639048130251, 0.07888735912274569, 0.11761579386075027, 0.13564935157774016, 0.09322942976723425, 0.16910263773752376, 0.12537569738924503, 0.07795443496434018, 0.15051707800012082, 0.09528650727588683, 0.07799757600878365, 0.12246980331838131, 0.13915260031353682, 0.10947424831101671, 0.10375796715379693, 0.10827680787770078, 0.13860206032404676, 0.16019953734939918, 0.23989889508811757, 0.06082825668272562, 0.18262859084643424, 0.25328698684461415, 0.09914416863466613, 0.07571738664410077, 0.10980436301906593, 0.1234209694666788, 0.2040074608521536, 0.16097989078843966, 0.08728694941964932, 0.17517389554996043, 0.13792170386295766, 0.10711045601055957, 0.09029018357978202, 0.09362147669889964, 0.16214936709729955, 0.18896936700912192, 0.15038568817544729, 0.13805301947286353, 0.12366724375169724, 0.09978832313208841, 0.07544901120127179, 0.14957380830310285, 0.12966125883394852, 0.15887087036389858, 0.10995254022418521, 0.13167877244995907, 0.09266373512218706, 0.10670487972674891, 0.18092301674187183, 0.10897384039708413, 0.05699118992197327, 0.1765322484425269, 0.1512444272520952, 0.1416904485085979, 0.12313700150116347, 0.04896972757705953, 0.1371146776364185, 0.13894819800043479, 0.08702210659976117, 0.16518405347596854, 0.14885861543007195, 0.0965482993342448, 0.0824148315587081, 0.12936132727190852, 0.1757563478895463, 0.16686133691109717, 0.1660310517763719, 0.15361598983872682, 0.1551287539768964, 0.11977392219705507, 0.18297854316188022, 0.06933069380465895, 0.1670785338501446, 0.22621464187977836, 0.17754539876477793, 0.10618766958941706, 0.09733560669701546, 0.15652008791221306, 0.1615340227726847, 0.1718086120672524, 0.07494864781619981, 0.1684355954057537, 0.06440034703700803, 0.21051253366749734, 0.12071824574377388, 0.2427892485866323, 0.10466295687365346, 0.10223113931715488, 0.15614088013535365, 0.20667942997533828, 0.2762077725492418, 0.10780852011521347, 0.2041194509365596, 0.1304460206301883, 0.09066792932571843, 0.1344184996560216, 0.137584071198944, 0.15889648930169642, 0.17271673365030438, 0.11126266093924642, 0.07624776990269311, 0.2024071232881397, 0.18173182412283495, 0.121272978867637, 0.16223392740357667, 0.13945015700301155, 0.11374827678082511, 0.1942500297445804, 0.20167590002529323, 0.10229795487248339, 0.10400878338259645, 0.13360405195271596, 0.15667966450564563, 0.13917479052906856, 0.135308112076018, 0.13779662229353562, 0.06914768018759787, 0.11966229576501064, 0.1224701818136964, 0.19020401872694492, 0.1870921638328582, 0.1646760682342574, 0.18802410835633054, 0.14798920426983386, 0.1809011827572249, 0.1413792066159658, 0.09192707191687077, 0.18451394280418754, 0.09862658742349595, 0.12276888141059317, 0.15210980112897232, 0.17068121553165838, 0.1819658381282352, 0.11872182396473363, 0.1395512226736173, 0.08382327941944823, 0.08666716705192812, 0.13829527131747454, 0.08227528553106822, 0.09903551821480505, 0.1373139294446446, 0.1443191504222341, 0.051741448769462295, 0.06681043450953439, 0.1112683086830657, 0.06591903351363726, 0.09797224323847331, 0.13447971199639142, 0.09518629507510923, 0.1798667327966541, 0.1934177556540817], [0.012537428174255183, 0.07268581728567369, 0.0662831831141375, 0.0884703038900625, 0.05042090830102097, 0.07453896003426053, 0.04893176301266067, 0.05329399573383853, 0.03141885528748389, 0.053620373728335835, 0.016780515579739586, 0.054884188139112666, 0.017475247441325337, 0.01569625637785066, 0.050563233671709895, 0.010705982112995116, 0.028686076439043973, 0.014459047961281613, 0.01608364262210671, 0.02744627978245262, 0.051414102272246964, 0.05210691939282697, 0.049154997323057614, 0.06750337037374265, 0.03135280043352395, 0.038357991725206375, 0.07006454427028075, 0.026027710882772226, 0.04780425144417677, 0.0288632586307358, 0.04039403305796441, 0.08712104972801171, 0.02700998415093636, 0.028528427574201487, 0.003465549025349901, 0.031128809132496826, 0.0042743489848362515, 0.03905605954059865, 0.024160133361874614, 0.042436954099684954, 0.007543744668510044, 0.01550764140120009, 0.0256961359991692, 0.0072927957808133215, 0.030989858678367455, 0.02513020943297306, 0.01959550954779843, 0.01965928044228349, 0.05656921959598549, 0.05564944258367177, 0.04310735093895346, 0.03889400788466446, 0.03851476671115961, 0.054992152072372846, 0.06056624886696227, 0.03062183692236431, 0.016244538383034524, 0.03867240629915614, 0.04322954926465172, 0.04418622214870993, 0.03568266438378487, 0.006455790498876013, 0.005777118249170599, 0.028491028897406068, 0.019345173859619536, 0.10723378611146472, 0.03805345513683278, 0.02572554731159471, 0.049771625563153066, 0.010626801449689083, 0.0696136598708108, 0.019135708243993577, 0.09286612621508539, 0.03329483763081953, 0.016391737808589824, 0.023613626945007127, 0.019901311497960705, 0.06089683483878616, 0.032426599063910544, 0.02228012672276236, 0.05539248879358638, 0.01525186948128976, 0.007854163704905659, 0.02843174799636472, 0.015721921699878294, 0.03659531306766439, 0.02061353578028502, 0.036659271354437806, 0.030430975093622692, 0.04520033726294059, 0.07489847863325849, 0.05570273620833177, 0.05587062114500441, 0.06686151653411798, 0.05347152487956919, 0.02233627576060826, 0.0905239452549722, 0.015491137892240658, 0.017480832102592103, 0.04934912831231486, 0.09241491527063772, 0.03699449574924074, 0.006848295242889435, 0.052730212119058706, 0.08152179041644558, 0.026786638518387917, 0.027708565903594717, 0.05101784736325499, 0.04719861812191084, 0.03938559537346009, 0.04955026517563965, 0.050019109548884444, 0.06285280585871078, 0.06428664259146899, 0.04662948733312078, 0.01413088510162197, 0.041394451836822554, 0.0376176066492917, 0.06659141188720241, 0.01935601107106777, 0.0598889834509464, 0.05846604886755813, 0.01696964078291785, 0.06947565751033835, 0.0076472858654597076, 0.06680190723272972, 0.010111498631886207, 0.05622974640573375, 0.05502114778209943, 0.06246926393941976, 0.059953784075332806, 0.08037117950152606, 0.03499126105452888, 0.05827839682751801, 0.05075285240309313, 0.026552693161647767, 0.007992185546754627, 0.08331142758834176, 0.016917640350584406, 0.07430842670146376, 0.008736985473660752, 0.05282435355184134, 0.028698377536784392, 0.05920099400100298, 0.0037759522911073873, 0.03283671729150228, 0.045066832317388617, 0.02315108711627545, 0.05387564655393362, 0.01687008909357246, 0.024604336576885544, 0.04144847647694405, 0.026302084734197706, 0.048268279279000126, 0.029886079137213528, 0.04000121058197692, 0.07089776830980554, 0.06775596033548936, 0.03350873572344426, 0.06767033133655787, 0.023895208905742038, 0.02520917394576827, 0.06374874137691222, 0.06143056889413856, 0.03046931258722907, 0.019848730335070286, 0.024077829184534494, 0.143015953944996, 0.0294408795889467, 0.043878998985746875, 0.08431812864728272, 0.03871394430461805, 0.0952344827237539, 0.01532755833977717, 0.03832818336377386, 0.04342587330029346, 0.019157835376972798, 0.05979097171803005, 0.018787049120874144, 0.08479362266371027, 0.07104613847332075, 0.02477824589732336, 0.029146528977435082, 0.05574397735472303, 0.024103583564283326, 0.05751875301939435, 0.022530874302901793, 0.04595553189574275, 0.027583027913351543, 0.08371220959816128, 0.02915473342000041, 0.036800984453293495, 0.00971263414612622, 0.025065293775696773, 0.010295658867107704, 0.015417820195580134, 0.06673741459962912, 0.043914755660807714, 0.06315282647847198, 0.011473642043711152, 0.02470083061780315, 0.08739939963561483, 0.09488818919635378, 0.01895969864563085, 0.06048172937880736, 0.033151350799016654, 0.06520646042190492, 0.06760307049262337, 0.04757669783430174, 0.021358741105359513, 0.017861195774457883, 0.043589097549556755, 0.018013998414971866, 0.036702074721688405, 0.05815418357087765, 0.03730455391632859, 0.018483301064406987, 0.016953469385043718, 0.038496576671605, 0.04820126705453731, 0.026370709274488036, 0.058560353572829627, 0.004995303706891718, 0.038901436782907695, 0.051130765132256784, 0.0192253374189022, 0.04851082427194342, 0.029720173879468348, 0.0071584021134185605, 0.0230351042773691, 0.04714210357633419, 0.027486071885505226, 0.03468652408628259, 0.023580601373396348, 0.0268557602976216, 0.042527132463874295, 0.04339620965765789, 0.021254671592032537, 0.07612697052536532, 0.04002604284323752, 0.036240050685591996, 0.04459552772459574, 0.043506002984941006, 0.06276297630392946, 0.07417129265377298, 0.020141943605267443, 0.05593728827079758, 0.039241440608748235, 0.08868112578056753, 0.03165833892126102, 0.04296042425266933, 0.04560200984997209, 0.0756640410691034, 0.023040353116812184, 0.013712362051592208, 0.021391692462202627, 0.030878898323862813, 0.03790320362895727, 0.08625756090623327, 0.026665935620258097, 0.038003723821020685, 0.03270168352173641, 0.05280588891764637, 0.01736910176987294, 0.03021487467776751, 0.03710997392772697, 0.06330751974019222, 0.015046103471831884, 0.05061702824605163, 0.06907921706442721, 0.07563811785075814, 0.05971339131065179, 0.04961459824698977, 0.04674616408010479, 0.021696047224395443, 0.014898019962856779, 0.04010193486465141, 0.07097428373526782, 0.03303386882180348, 0.007300129591385485, 0.025920092048181687, 0.09018147378810681, 0.02100318557495484, 0.04317789578635711, 0.017358158802380785, 0.027560444359551184, 0.09641811178880744, 0.03513494826620445, 0.04349701186583843, 0.052226390325813554, 0.027005694537365343, 0.057155226822942495, 0.04241625560098328, 0.020050770763191395, 0.02693971760891145, 0.0517952952941414, 0.0309530871163588, 0.03924409378669225, 0.025308475160272792, 0.0399933809239883, 0.01980925735551864, 0.0896911219751928, 0.028511463933682535, 0.042247008823323995, 0.043005120096495375, 0.06079497135942802, 0.08108649853966199, 0.04166601851466112, 0.032421871583210304, 0.04269918084901292, 0.07411262587993406, 0.03179647486831527, 0.010757655072666239, 0.045831344614271075, 0.07754142236080952, 0.07830409042071551, 0.014363147638505325, 0.031334087179857306, 0.06216699461219832, 0.04801590825081803, 0.020617042428057175, 0.027863646937476005, 0.06956161305424757, 0.021749066254415084, 0.04431883651704993, 0.05711350328056142, 0.013507479197869543, 0.050258838091394864, 0.017949683897313662, 0.06040590786142275, 0.01695235801889794, 0.07285988060175441, 0.021540745401580352, 0.0397007743595168, 0.0326539485831745, 0.08221090422011912, 0.011180904675711645, 0.04122368736716453, 0.06927380818524398, 0.006591607234440744, 0.06447664723964408, 0.03795188480580691, 0.031451884569833055, 0.05610868727671914, 0.031389733412652276, 0.05033959118009079, 0.040871204328141175, 0.026393912521598395, 0.05371088976971805, 0.030028742185095325, 0.024362277690670453, 0.06780196606996469, 0.19919708225643262, 0.16614479332929477, 0.1504893068340607, 0.23341730382526293, 0.21600220003165305, 0.11504961788887158, 0.10970205796184018, 0.13282240717671812, 0.18737818754743785, 0.2354754722910002, 0.08904558708309196, 0.16900740534765646, 0.08393403011723422, 0.13299844460561872, 0.23554919724119827, 0.05407046031905338, 0.088502416620031, 0.19719438190804794, 0.13678817718755454, 0.07710675388807431, 0.09629080377635546, 0.17109444335801527, 0.17896809586090967, 0.16129739640746266, 0.09260730221285485, 0.17146281577879563, 0.2129693393362686, 0.06740722514223307, 0.21631894866004586, 0.1389167903107591, 0.1697147759841755, 0.16864802775671706, 0.08381509353057481, 0.1103953352139797, 0.08914515361539088, 0.1468754929373972, 0.06337709608487785, 0.22983611474046484, 0.21667013294063509, 0.1589739101473242, 0.175574135791976, 0.10839601905900054, 0.1257150518358685, 0.14623688970459625, 0.07461808039806783, 0.11998930087429471, 0.14846814185148105, 0.10028143573435955, 0.19322889391332865, 0.09090068910154514, 0.09465965224080719, 0.13045412488281727, 0.17590600939001888, 0.1961346692405641, 0.12803939898731187, 0.09519388724584132, 0.13259504281450063, 0.14642438589362428, 0.0895745528396219, 0.17667465173872188, 0.1434204838005826, 0.09733456769026816, 0.15316860837629065, 0.2864185074577108, 0.12929837830597535, 0.20271622779546306, 0.2115498186321929, 0.12821147334761918, 0.0780341935751494, 0.18879203824326396, 0.11973049913649447, 0.08983736217487603, 0.22168553725350648, 0.10280841146595776, 0.1097225041303318, 0.18117928033461794, 0.16417885897681117, 0.1953996907104738, 0.1535068644443527, 0.09179911823594011, 0.09201236694934778, 0.13557593832956627, 0.13657690258696675, 0.10656986079993658, 0.12671128119109198, 0.0948715205595363, 0.1110612420598045, 0.08669362461660057, 0.07231131472508423, 0.08517371359630488, 0.14019638649187982, 0.09435889689484611, 0.13298318604938686, 0.13169554498745129, 0.15915186231723055, 0.17592469666851684, 0.17375529510900378, 0.08796598485787399, 0.12187066749902442, 0.1387407528818585, 0.2304127931711264, 0.13755411811871454, 0.22802335966844112, 0.17709999141516164, 0.21688912587706, 0.21398119832156226, 0.10476069772266783, 0.13238896324764937, 0.17499235138529912, 0.1424081201548688, 0.18194072385085747, 0.11867667170008644, 0.1669970460352488, 0.19744914636248723, 0.16277968796202913, 0.13416076661087573, 0.14772902213735506, 0.09382296979310922, 0.11510553129483014, 0.19261700799688697, 0.11888936380273663, 0.17412484012311324, 0.09089814353501424, 0.10723930026870221, 0.1034624884778168, 0.18451768322847784, 0.09699734320747666, 0.24043006502324715, 0.137645817885641, 0.14132495562080294, 0.20420856802957132, 0.15742035757284611, 0.13320370781002566, 0.09309921253588982, 0.1596950550447218, 0.12294658125028946, 0.07962210016557947, 0.1276498902007006, 0.17020284198224545, 0.31724512518849224, 0.07041632969048806, 0.15146009536692873, 0.21326517424313352, 0.1669480642885901, 0.1105070358607918, 0.08781976692262106, 0.14188803790602833, 0.0987102571525611, 0.07838790857931599, 0.1403579075122252, 0.1514821223099716, 0.11631224857410416, 0.10311266974895261, 0.1434246398275718, 0.11783183304942213, 0.14563935692422092, 0.15012572868727148, 0.10875403109821491, 0.10586185933789238, 0.15609280380886048, 0.08765293212491088, 0.11462853814009577, 0.31041793059557676, 0.08889093835023232, 0.0843189524312038, 0.06392714625690132, 0.11641459816019051, 0.18346028606174514, 0.12976144877029583, 0.1471782149747014, 0.1316676996066235, 0.21230461250524968, 0.13890044821891934, 0.13572362571721897, 0.10495646885829046, 0.12077461928129196], [0.032222445370280184, 0.06416574673494324, 0.06512109859613702, 0.06273675622651353, 0.03143549423839431, 0.037503839121200144, 0.013501516968972282, 0.051866752983187325, 0.035349406680325046, 0.007274734689417528, 0.028687514350167476, 0.061935819321661256, 0.05706551601178944, 0.05144489026861265, 0.014049673736735713, 0.058773813798325136, 0.04066164779942483, 0.022217578516574576, 0.009044754115166143, 0.058398669279995374, 0.018539142110967077, 0.01051503586495528, 0.006918915696587646, 0.03914498367521446, 0.07456443796399981, 0.03828332424745895, 0.025870998979371507, 0.05206491012359038, 0.060889172164024785, 0.022924112381588202, 0.03040101088117808, 0.02668938563147094, 0.0193152374777128, 0.03489712704322301, 0.030475505809590686, 0.027665565867209807, 0.03963457478675991, 0.017033947879099287, 0.03719102758623194, 0.04397898854222149, 0.0010041091081802733, 0.01816356714698486, 0.07519493694417179, 0.03656340442830697, 0.030818550585536286, 0.010503213452466298, 0.04480713258089963, 0.023700011079199612, 0.023994641851459164, 0.01987536972592352, 0.022445360336860176, 0.04112531940336339, 0.12885935342637822, 0.00930194075408508, 0.04241739850840531, 0.02491745795850875, 0.04586786570143886, 0.037650695303454995, 0.02507629611500306, 0.05748386094637681, 0.02747711601841729, 0.009983414147427538, 0.07689175370614976, 0.029163863691792358, 0.049533904530107975, 0.019452072810963728, 0.08208295796066523, 0.06397070290404372, 0.054070623591542244, 0.02863467343559023, 0.04250799247529358, 0.04043740045744926, 0.07593285437906161, 0.04970935195160564, 0.06839670837507583, 0.04597186285536736, 0.06457514507928863, 0.06259267567656934, 0.08790278356173076, 0.027871430211234838, 0.018541342578828335, 0.05443810914584901, 0.05962583272776101, 0.07078338850988075, 0.06049037539924029, 0.02634075248352019, 0.03207653913705144, 0.09729875906486996, 0.037184871471254155, 0.03288667867309414, 0.025033474194060545, 0.037856834242120385, 0.01637783738260623, 0.10613439822918735, 0.04283207352273166, 0.06505863202619366, 0.019429223939368967, 0.033939459681278095, 0.01826636758778477, 0.007100138882378815, 0.017567156864970457, 0.046210021755541675, 0.0038979989403742366, 0.06472269145888276, 0.043076752190245315, 0.07721161193330772, 0.010267728139297105, 0.034465267599443905, 0.09402458905242383, 0.08229934595874511, 0.027680714956659358, 0.005681246684616781, 0.012721486364171142, 0.07192919772933237, 0.032717120193410665, 0.043998644323437475, 0.07203781104180962, 0.03771811941987835, 0.12345915296464227, 0.05310602085955907, 0.05425898438261356, 0.05232698473264463, 0.07356397094554268, 0.0753889195038937, 0.020282658515498042, 0.03610683517763391, 0.07749162425170653, 0.03253689705161378, 0.09243727618013509, 0.013390020412771264, 0.06333916491712444, 0.13141853094566613, 0.05042742435762193, 0.09224160894518718, 0.042147906133322977, 0.05974225343379658, 0.029970917748869397, 0.05886069702683017, 0.058789432296180166, 0.06507418744149618, 0.06495628244010732, 0.07426930067595094, 0.013986270205350593, 0.029438564088195562, 0.06976994875003584, 0.030921117249818053, 0.06150173343485221, 0.01063822217474808, 0.05350511448341422, 0.050155868811998516, 0.034772071448969655, 0.010055722523247823, 0.037248996741254814, 0.03505081469484139, 0.05486131143698003, 0.020006394042866305, 0.05552023838390596, 0.009760921057022642, 0.02933213640062604, 0.07691386228543706, 0.04806367287528701, 0.05862441204953939, 0.026806270179804415, 0.04324263703892939, 0.0630579874268733, 0.04903083601675462, 0.07576535164844245, 0.027478952833916992, 0.008943275624915259, 0.04024840141937602, 0.019125455473840702, 0.030259264385676943, 0.025298411637777463, 0.01822411340981489, 0.025236054534616414, 0.037999846099410206, 0.03525851956510451, 0.027863418727065437, 0.03693369901156984, 0.03303958706965204, 0.04722603305708617, 0.05701077519915998, 0.03149586795188952, 0.028141327056800947, 0.04147936837398447, 0.008291934354929253, 0.017075294781534467, 0.022029176907381043, 0.02648006844538031, 0.025853280203591567, 0.027239343035034835, 0.0696027725643944, 0.015135181602090597, 0.024078161295619793, 0.031468697925447486, 0.054411625606007874, 0.023228765858220868, 0.011937802537431708, 0.08111329007078893, 0.07590884590172209, 0.03253658906032797, 0.08616523031378165, 0.09001779311802238, 0.024914988462114707, 0.027008768884115852, 0.06844902236480266, 0.027208566170884296, 0.02045324301434448, 0.038328866139636375, 0.02835900268109981, 0.03188754752045497, 0.009113703345065005, 0.08763047473621555, 0.0912146843620576, 0.02565269809565507, 0.06597278726985678, 0.03087805784161901, 0.02036056361248484, 0.05019588541472331, 0.04958930585416965, 0.02509951049432857, 0.024478863524564076, 0.04655920223740395, 0.009792697965167463, 0.018926070079032797, 0.02245511772343889, 0.04498604583204724, 0.029860899921914097, 0.05587649153312668, 0.025286880518251564, 0.04261349247826729, 0.03521332277159672, 0.051157975976821035, 0.015986187499947846, 0.02811264304909855, 0.021576140279648826, 0.009027698633872205, 0.04052447293361183, 0.02917974936281098, 0.03140498825814575, 0.052051236052648164, 0.013917225423938362, 0.07529865950345993, 0.03812995200860314, 0.05880639408132993, 0.06101471015426796, 0.02180882584070787, 0.0510465944535099, 0.020499334095802624, 0.03721199325809721, 0.03739914434845559, 0.009824610315263271, 0.04220465445541777, 0.02842149893695023, 0.01803896240744507, 0.01998913910938427, 0.06793317777919583, 0.04530132129730191, 0.026153963190154172, 0.07726418567472138, 0.07153560713049956, 0.029074811536702327, 0.02483881813532207, 0.05504677785211243, 0.02256882031360874, 0.04014175479824189, 0.01740432038786821, 0.07703831302933395, 0.023578306281706318, 0.03708625488798134, 0.06288045828114264, 0.04620230341970455, 0.1515836629550904, 0.030069541753618978, 0.027813327469630167, 0.01878085775388172, 0.060654698027065024, 0.08374755809199996, 0.011323090893711196, 0.034324586085858755, 0.049335958901792765, 0.0607901733746985, 0.07617527691763826, 0.01167830318081542, 0.07192398043116555, 0.040226634228019975, 0.010587778397166403, 0.03353640298882965, 0.023345433328358922, 0.04773204789671581, 0.029094545243424363, 0.04616059843101539, 0.005384078231145395, 0.020622458250727504, 0.10084802095661871, 0.007814227810740704, 0.052526596482493915, 0.0502861194399884, 0.051760555361397564, 0.07322055695112795, 0.035342014889465645, 0.054299772818922065, 0.061945114721311256, 0.04839414010348264, 0.06109613117587287, 0.043069787134299986, 0.10370906704338267, 0.12900612055091187, 0.05730748955102172, 0.05375228305638302, 0.049820395797723904, 0.013470825451804558, 0.040663744366611354, 0.02390831708908081, 0.050124201370636, 0.04485671175643802, 0.0369364078505896, 0.03926960882381536, 0.04976633033948019, 0.03545438346918672, 0.05124704483023379, 0.05338847855455242, 0.04529547688434832, 0.032146260200534016, 0.056722521330812015, 0.020109893957851455, 0.04303789704863448, 0.030454595798801165, 0.07843745435820892, 0.06509178376290947, 0.0397813344898168, 0.018764671513054054, 0.03597864029870834, 0.06756271250196733, 0.03872266082908027, 0.045272258794284426, 0.09673581778770313, 0.02709226420847699, 0.02750510426267283, 0.05320705684425775, 0.03146654569718521, 0.016391426106565632, 0.07836595585104078, 0.053911098948447034, 0.0789406082185451, 0.03238492376112845, 0.03716530103702098, 0.023118241515476257, 0.019094966191914864, 0.008093414489849238, 0.03001743370987242, 0.031754465599078685, 0.14829759631538764, 0.14820540673099458, 0.2661411330336705, 0.1483787872712128, 0.17330773553112522, 0.26362498523667455, 0.10527763326535933, 0.16284933110000566, 0.09809257506276481, 0.08606335570220836, 0.08930016600061208, 0.14253404777264223, 0.1375399876269512, 0.20656647509895265, 0.11501476663397625, 0.1738176800427027, 0.09893155074678361, 0.14477536344202235, 0.10712687973864377, 0.15507748641539365, 0.12040062138112262, 0.18553825502749532, 0.15104783233255148, 0.18477305624401197, 0.13797398074530065, 0.16423655353719369, 0.20134570368099958, 0.11981507428572513, 0.16120026411954314, 0.18320755509193987, 0.11145768250571564, 0.09613809947040863, 0.13541560474550352, 0.11205206115846522, 0.1342956445296295, 0.08695232245372608, 0.18810583365848288, 0.1758512092055753, 0.09264828360755928, 0.15488954493775964, 0.1591836559236981, 0.07682751340325922, 0.16180287319002673, 0.17941246420377865, 0.1393556667608209, 0.14469239133177325, 0.11977123562246561, 0.0979341339552775, 0.08005843847058713, 0.11123249263619073, 0.22362950403476134, 0.1247783427243121, 0.269521051668562, 0.06163638870930299, 0.1146734603389632, 0.1069778564851731, 0.16283919336274266, 0.079879907425493, 0.17515942367026582, 0.09583882841980085, 0.10632570163579658, 0.1999852727749385, 0.20337828289484605, 0.1436763021047227, 0.14377687795786187, 0.0852433344698511, 0.15046374726807699, 0.2741402084939182, 0.19398071919567883, 0.13351692381547764, 0.1358596613863483, 0.10988688241923228, 0.10681198647944257, 0.14302827359642833, 0.20419393287738785, 0.08494568130117841, 0.13241315726190805, 0.21904825611272827, 0.14729269867530093, 0.14465887594269589, 0.12728174042422324, 0.2602305501932278, 0.24636460439069197, 0.16256075439741835, 0.17628631554543972, 0.10697988996980712, 0.1262071105884388, 0.11567388282855973, 0.15701674798037857, 0.07761573360767215, 0.11836952646262944, 0.15329222049331293, 0.07416981577989645, 0.20329554827185348, 0.2660078729968518, 0.23527862504124641, 0.1855424407403916, 0.07973843181389384, 0.12394266959745437, 0.08245746794273145, 0.16273340763291344, 0.19292131823021919, 0.10474791793967597, 0.17663203761912882, 0.12543775577796623, 0.214003611181397, 0.18730861862422898, 0.11666823455016129, 0.19584736903198063, 0.2820635255193338, 0.12700889725238085, 0.15924433391774073, 0.10545293596806005, 0.1820158737245947, 0.09627792009268887, 0.14058289700187743, 0.12219827374792658, 0.12018519817502238, 0.39496475947089493, 0.11784873917349614, 0.11702156363753602, 0.12741446611471474, 0.11328617852996103, 0.1793291061767377, 0.11771596153266728, 0.12430368733475916, 0.24484191031660885, 0.11763147544115782, 0.17753968422766775, 0.1601516391383484, 0.23623296758159995, 0.3009996609762311, 0.1567123635322787, 0.11340138953528367, 0.19641721970401704, 0.1184822735376656, 0.1649201160762459, 0.14799604687141255, 0.1301502005662769, 0.20766402245499194, 0.11208162090042606, 0.10915040475083515, 0.11276344681391492, 0.10756885836599395, 0.15130178042454645, 0.16481303900945932, 0.12116100362618454, 0.1114774533198215, 0.14155129581922665, 0.09457124018808827, 0.1158930390374735, 0.12843195057939738, 0.15011189505457878, 0.1401289549539797, 0.1427310731378384, 0.10078038161736913, 0.1690803881501779, 0.0945736670109909, 0.08374454497243278, 0.23880664666648954, 0.19997289375169203, 0.13700449839234352, 0.12630235782125965, 0.09955235727829859, 0.09073629596969113, 0.13194594561355188, 0.15733122563688084, 0.15933866088744253, 0.17229955759830773, 0.11946258382522501, 0.08417657139943913, 0.08895381310139783, 0.12305520940572023, 0.08575154235586524, 0.1602144693606533, 0.0790270758443512], [0.019109360146103427, 0.0524123985087499, 0.04811565660929773, 0.02765172852377873, 0.04319665727962274, 0.06155826282338239, 0.08703424813575111, 0.039705820963718, 0.036126750710536726, 0.05836167692905292, 0.03898688024492003, 0.03251898902817629, 0.020426098963071126, 0.02352411836909596, 0.02554131471697474, 0.02615775742015103, 0.053330587325035594, 0.04717383781098761, 0.061858572880737484, 0.021058030288259033, 0.07169510950916447, 0.037809770947205834, 0.015438004757015733, 0.004950809634465259, 0.09620105585781857, 0.060110692647867836, 0.011335498675180133, 0.11252116528339684, 0.03911182451702189, 0.06645998495514505, 0.019906612287741154, 0.05285460349114146, 0.0337923251936445, 0.07621556069352664, 0.04740371063235216, 0.028546007197292056, 0.0393313926178962, 0.03756620179046877, 0.03443223089561798, 0.15641128906281665, 0.056280372009496205, 0.0667827895085793, 0.01846823732194025, 0.042014683203888126, 0.05079452399513684, 0.035586367012001574, 0.03120151362963952, 0.06770558335119858, 0.03453076584264636, 0.04115822994208429, 0.005543872830457985, 0.02595848149212543, 0.03276284391176887, 0.010463916732987855, 0.04222781317366753, 0.021554258055402897, 0.006163858824947965, 0.05297355121001601, 0.03698659558722284, 0.04376037781185005, 0.055091046961024404, 0.05417529981059488, 0.022995939289103262, 0.0383792542561423, 0.055612149662920274, 0.03929161721316632, 0.018401071101834532, 0.0271344014981878, 0.020746270747622475, 0.01768882455507992, 0.008678314989083447, 0.09170506586087868, 0.09228276103385724, 0.02156649235985242, 0.03911280415195506, 0.10711420385632664, 0.010467875163158169, 0.02791172511933837, 0.026997838904208038, 0.037692901241825894, 0.0686534024134744, 0.02018797160417307, 0.010847054181795102, 0.038206560202525, 0.0444172415882349, 0.026033974609163124, 0.10735449643107131, 0.031055453400767874, 0.019490217346174177, 0.03129920252831653, 0.015308474939956795, 0.0288867847120855, 0.03246931708417833, 0.02850076216418529, 0.03967973818362225, 0.06890620759804733, 0.03539121556968894, 0.0458967612212291, 0.026406189499539323, 0.045988483252585866, 0.07253246731124818, 0.07290836510946974, 0.10984545573592186, 0.02801386875944445, 0.03152570228849072, 0.019397827381908428, 0.07959133814438246, 0.02999070711666718, 0.056225230437121354, 0.058423111913725734, 0.009634774505684618, 0.031255315625458024, 0.0022795613222115207, 0.03646164856036194, 0.06605548478546552, 0.03987668562331237, 0.0735533656552434, 0.025409314475837164, 0.07563764287624508, 0.024265019237645902, 0.03273777045251336, 0.01793224899302004, 0.07801094950991683, 0.013384694575506728, 0.04681724698457401, 0.03333042361191474, 0.022759116254746914, 0.08506451398716308, 0.03604577868827619, 0.045791639713570476, 0.027934588833886664, 0.03849669170449488, 0.012606339369085617, 0.02298494251590455, 0.04698435266618617, 0.061068504728609696, 0.05113007122417912, 0.009730981892062118, 0.05095093532872852, 0.029162609462218825, 0.05626347701763734, 0.06467384329880588, 0.047262635780498385, 0.0005434625677480653, 0.04535045147349592, 0.07295879404409789, 0.04987047963368241, 0.037801818834850565, 0.025145147010334767, 0.03651837461802643, 0.09546570625388995, 0.05371245941205416, 0.025151728004857432, 0.030124173099466134, 0.013485552444763016, 0.01224060435561114, 0.02605071375000989, 0.047506872870144434, 0.005122459579069982, 0.04100808233488351, 0.018468784655851778, 0.034311275667278096, 0.03740982385352254, 0.010351251294196118, 0.03345857396197971, 0.09800112020457163, 0.02601757129014004, 0.03902299686160404, 0.024831910595821682, 0.027439476143626962, 0.032262692038784735, 0.07538738325820304, 0.07525629029260017, 0.06684596854029223, 0.04961925151292235, 0.08515156048815697, 0.036079999117646366, 0.021500400398508646, 0.01321679015745758, 0.031287309611798264, 0.03348502781591378, 0.04897150873148348, 0.00427028155172593, 0.023379039630526677, 0.038743908517062664, 0.007781492140566115, 0.09844677988439798, 0.0047109795104915975, 0.04826416407013312, 0.030526391165039968, 0.03820274185272865, 0.05860273391590454, 0.028890940739074722, 0.006446269671869231, 0.10610353230731562, 0.12700447405222803, 0.01970696528587723, 0.04763957629620563, 0.041170928088831715, 0.047690992287243716, 0.08346177928615361, 0.04169517749687657, 0.044947094211238436, 0.06195547881361563, 0.0022119519007901545, 0.007955901946843369, 0.026737597399915103, 0.041507900241413154, 0.020281775359762833, 0.04326182897784747, 0.017507232150819618, 0.08719812176423147, 0.024254972413473297, 0.028285479966143612, 0.05800780236313585, 0.027341382774466183, 0.06699230521917343, 0.05405006239016075, 0.02446211325150216, 0.014518853931804188, 0.05222814179433044, 0.01736822789098369, 0.047261774889193475, 0.08660868581500836, 0.016581113486608956, 0.009934278405125951, 0.04444903890544083, 0.017174018976220395, 0.07521596940932795, 0.03635056760685984, 0.08006893243873492, 0.02837092713889433, 0.03927487436158117, 0.04960449761711061, 0.052991147531429306, 0.06408737594028935, 0.015270809089997783, 0.004876171842624899, 0.014513350906781852, 0.05496523437614087, 0.06811098894104362, 0.04367763576738071, 0.023008266362012364, 0.019144793986924924, 0.01598601866135141, 0.04818466892174911, 0.014312177863757825, 0.007719101640759618, 0.07890177905210294, 0.029388992334133945, 0.07978662688401528, 0.03918968322977889, 0.026164130613324232, 0.009036442988872295, 0.029936175960756373, 0.021344764609239064, 0.04527501958364155, 0.031568891572533175, 0.04368704619992059, 0.03319480354548432, 0.04385379193990957, 0.0451121849619085, 0.0850687368074432, 0.011923084821319208, 0.01275742672078195, 0.01027374046316254, 0.044064469111617655, 0.031496628653258085, 0.042265874217264354, 0.08287160118925385, 0.03529378642269876, 0.04057317266415339, 0.0358747841528384, 0.0663735024863854, 0.03590698222978972, 0.06768556020688266, 0.07303488644538447, 0.041479223655187525, 0.07045426827971824, 0.0402870487596374, 0.027015531704819296, 0.016498119111929554, 0.02195457065681694, 0.04359317936177831, 0.015522753383265808, 0.026767081071739085, 0.03508361762214918, 0.08110065129585564, 0.03673695195175242, 0.02453297536703758, 0.04187119266134687, 0.06385436383425258, 0.058455981634324417, 0.03448493080213666, 0.017542356144986115, 0.022183799665072, 0.016497451179020572, 0.03344284414197318, 0.04205092598567717, 0.025075349876715336, 0.04476747591979802, 0.042823768890229985, 0.022348905258695595, 0.08308442687848583, 0.04035992024000734, 0.034518390530138277, 0.02923513213318074, 0.04557599015242886, 0.010893748258240521, 0.006762509929103544, 0.04342361346061807, 0.026548835849098396, 0.09010069101350382, 0.06559792847838253, 0.04905231005977839, 0.061387001114781015, 0.039498843398177996, 0.04674865027482156, 0.07594736336614005, 0.00599815394707548, 0.018897770132753067, 0.04495445260545239, 0.016064660339907277, 0.016564311263209675, 0.03689386423502583, 0.04740564021631144, 0.146246018121019, 0.011772931648010854, 0.04096247364941519, 0.039713197911623865, 0.07120852780644782, 0.032234805839834735, 0.04811514823813923, 0.03514665564580355, 0.03241512917156797, 0.003930318544007605, 0.042014623832073994, 0.030172518454492092, 0.040080123144434765, 0.03615834764786996, 0.0036743594637300703, 0.0196876508925925, 0.029782933597743977, 0.02781348146527307, 0.025521916832076386, 0.052895955959684215, 0.00678258224070305, 0.058346088117104955, 0.0301329007561435, 0.06685668515274301, 0.005687814691555104, 0.021594423087663017, 0.068571202136809, 0.11785404552938417, 0.13309881265740842, 0.129095861047972, 0.12227532351971604, 0.2233952228561975, 0.17407003993866965, 0.15281387662980705, 0.10752001020591706, 0.10938332779915072, 0.26779733947478235, 0.1107230230991263, 0.1683068773127161, 0.07303429272724316, 0.08585679373936728, 0.14677041966933757, 0.16129833151353523, 0.12675106030656025, 0.28870182868558913, 0.10727311251685023, 0.06640136271016672, 0.17783085844712332, 0.11061333367251791, 0.12604677700437605, 0.2286454278510064, 0.19643007370177656, 0.1633410039357841, 0.1686994734336622, 0.24513712181942537, 0.24751218734309077, 0.14365377050125971, 0.09024080107337795, 0.07974191248649731, 0.1505699337576516, 0.14488879329292104, 0.17664459475781769, 0.07932000895380042, 0.13927664287621155, 0.09214206467731856, 0.19976850628154352, 0.17045670101651922, 0.17507708980701864, 0.10221967313555069, 0.10989589951350354, 0.11345331760821864, 0.12173660594271496, 0.11144208256155252, 0.1644224170013331, 0.08290260811918415, 0.10435686548589729, 0.11890365756698884, 0.11224651127122343, 0.17682756384601817, 0.10173718066653237, 0.10922401095740497, 0.10922312780166976, 0.12151713061030023, 0.17005479836370796, 0.16749378031818196, 0.1296358328545466, 0.17417199618648738, 0.10247417783830315, 0.07496099715353921, 0.15672443085350096, 0.12943751615239307, 0.09707601086120121, 0.07727793767116964, 0.16942731250310317, 0.12186082662083209, 0.15136268106289208, 0.12339006643742323, 0.12825095560401678, 0.23017499421257526, 0.1371259879670106, 0.17077309341402724, 0.290141713921912, 0.09609601969714276, 0.0673877660301514, 0.12574219959788024, 0.11316316013108008, 0.16244296071818098, 0.08884575639967807, 0.09063858480658382, 0.18348896264797077, 0.14082816196605563, 0.09369227016577497, 0.2105660573579371, 0.1290498033631593, 0.10562069102888927, 0.08409387388383038, 0.15823859022930264, 0.10689121816540137, 0.14234083704650402, 0.1514820332522504, 0.1282292848918587, 0.14822675089817494, 0.13018180121434852, 0.28776345716323704, 0.10486671351827681, 0.16218257078435272, 0.2060696220723912, 0.15135189023567364, 0.25869454198982567, 0.06489802384749055, 0.08898946587578394, 0.08723279490368441, 0.1729415895533748, 0.1562126458156854, 0.1457851444138214, 0.11712930121575482, 0.10845727592823096, 0.1867857904289849, 0.23372654191916808, 0.139186026644893, 0.22276126546785235, 0.13081753975711763, 0.15540449152467772, 0.1533950079465285, 0.157117665221449, 0.14891147118760273, 0.08230684165027924, 0.12273336964426562, 0.20962062058970332, 0.1527730139787309, 0.129452136461623, 0.08136948687024415, 0.1099615053681191, 0.2644922590116039, 0.13616040931083262, 0.145254731469322, 0.1501222702790983, 0.1490609100437723, 0.11001548176864162, 0.16612715990049765, 0.09204574133036658, 0.12173603448900394, 0.18807026994181797, 0.1555195392575115, 0.1418621072662063, 0.15941241552354768, 0.19780951843131334, 0.1121832654462196, 0.18918506480986252, 0.10202577963354997, 0.09724999996251427, 0.19039258360862732, 0.0990709186589811, 0.1363481133012101, 0.19137109047733247, 0.1585823530331254, 0.23134573217248544, 0.09464514325372875, 0.14680063992273062, 0.11619336393778212, 0.16627701435936615, 0.06879015796585009, 0.11140950227854773, 0.12459314719308168, 0.10401515100966208, 0.09757181003806181, 0.08813767330138944, 0.17540756816742942, 0.10416612611152232, 0.11151312093716115, 0.1529558197944425, 0.13902732578571886, 0.18543203885201365, 0.13665738108102232, 0.11958166141994298, 0.09709791906061582, 0.08145123443682678, 0.19770759186940268, 0.11158459717989899, 0.17848819348728284, 0.2253476798068732, 0.13964139361632988], [0.017831899494922254, 0.048143112362595275, 0.029943387780804187, 0.03185944980941713, 0.033940138746402226, 0.03061530602280982, 0.06938748294487596, 0.017744120123097673, 0.0320414466841612, 0.020910456078127027, 0.055903910179040395, 0.009207123966916697, 0.028372734268486965, 0.02680395653442247, 0.03567204425053205, 0.024040211574174464, 0.023847008269513026, 0.011281512070127064, 0.035641590220620856, 0.036409720487426966, 0.010011454342020443, 0.019647934859676752, 0.019421611359575763, 0.03311023952846881, 0.035792943817796186, 0.03736742124601733, 0.023173576046247035, 0.039945156167959794, 0.061593347854795866, 0.021052801857877057, 0.06432483351090923, 0.012485581737564644, 0.01766607030731393, 0.04512968109338544, 0.08860651767463423, 0.05837919903569855, 0.012773518337780843, 0.0064935556110867765, 0.028299849800532684, 0.04157367307925597, 0.06578948421520181, 0.03533494964358397, 0.0205768013256602, 0.05363402553484775, 0.06583841401152313, 0.019863589986925945, 0.03835074094240554, 0.04639934362785425, 0.03684713490656577, 0.047138374284259044, 0.016978229286905844, 0.03606535654398613, 0.024815228971419856, 0.04163298552157357, 0.026526350629865192, 0.052211770016583614, 0.011929990505450405, 0.01591468528204132, 0.06047871254850179, 0.028314692754065618, 0.003536254362188629, 0.06162837722513359, 0.023036345519358292, 0.044875621679238975, 0.032213780796155334, 0.13230281474534422, 0.03163781853800174, 0.15486719144973904, 0.03999487264081836, 0.02740915384492837, 0.01992206380236894, 0.021446130849653855, 0.016647858537908178, 0.03335288100061007, 0.036740989235113375, 0.0631868391064927, 0.08727073349291459, 0.02516690678021405, 0.017786110838642344, 0.012899568409920903, 0.06617822116822936, 0.014561497737304308, 0.02328511342057027, 0.06130473404482473, 0.040101159320329316, 0.024033727058849763, 0.04747914252220653, 0.00894777489520493, 0.03350234583194833, 0.012743179340759525, 0.047696959154563956, 0.02880505569919478, 0.030541764754161704, 0.02147886698367074, 0.07675626722630113, 0.035417491308180615, 0.02888914845243562, 0.013925427083449904, 0.04612096774508245, 0.02083166782540502, 0.036875933947158046, 0.02364787520491518, 0.1036623191612307, 0.05507492009201087, 0.016350583864550572, 0.06770446270820685, 0.04449763102456927, 0.06563749979250133, 0.03921182891645003, 0.030615578762080986, 0.03592924666008912, 0.009169123222818598, 0.045106236648280174, 0.014820269789197482, 0.05069570332125295, 0.009805742138269125, 0.0650782098819036, 0.05303465593897272, 0.04244056093739346, 0.03484202257823199, 0.059181672186241485, 0.042100037608179264, 0.08254997665062547, 0.05257449469354469, 0.024646752171975095, 0.06803261072491296, 0.029815966590831522, 0.0023790724253558437, 0.08824771153740585, 0.07231314040836878, 0.002351582115807105, 0.06772909458959475, 0.030724904536327813, 0.06358524624374695, 0.01433177891158266, 0.04154649934207555, 0.048041827758424915, 0.055294213598244824, 0.03587295846955385, 0.025903954046953004, 0.036353454561321996, 0.01652086964895716, 0.0076418250500864815, 0.053877420286880806, 0.0072571434702695115, 0.04327938448113855, 0.024281546866404824, 0.011365759746695403, 0.0014063396974961506, 0.013974245557619724, 0.02135700447979616, 0.02860212654923089, 0.10439261473948136, 0.05027435639931355, 0.019281928034615703, 0.014018960882822284, 0.029665167749044485, 0.03876675553328823, 0.0667863072885666, 0.1044234583969228, 0.020360051530587953, 0.04113118979148567, 0.06780098643503152, 0.03432865305512678, 0.08975349206593819, 0.01558241834572982, 0.02137200328434119, 0.05562179758271668, 0.034153769665863365, 0.030556513083865866, 0.03856126968457829, 0.05458614163217135, 0.037838610805920325, 0.016727095789974555, 0.02270100980240386, 0.06126875843619928, 0.03928268917661626, 0.03514311931212433, 0.0417032483528601, 0.0368434538540896, 0.06553734696353786, 0.02756498444796307, 0.02379822875809623, 0.03923006348486524, 0.048987372138071805, 0.00978041078269598, 0.03497251440421678, 0.029613295337185264, 0.031558334521832876, 0.03045046018087305, 0.026527975933277048, 0.010158995155507, 0.013422906831692671, 0.0431207318615634, 0.05623112308967393, 0.06411258669686504, 0.01881863863673061, 0.09553104493534192, 0.034567286929814145, 0.061314474733080715, 0.008297298227262218, 0.05376465465815272, 0.046896040803403594, 0.049726031720638275, 0.04076344077475369, 0.060820512371719815, 0.058852685542660765, 0.016960193242994137, 0.03909652143192943, 0.06779530900530517, 0.04810062440810725, 0.04364050611911807, 0.029824575503880624, 0.05613262896076776, 0.0165940732404124, 0.08310811623232439, 0.04477221824345179, 0.02604151111881947, 0.028643020741583314, 0.028847313587903045, 0.015268995466612978, 0.058287035426474176, 0.019554958598746452, 0.03345035838719923, 0.00394558405787393, 0.12003701354842633, 0.028510269075923134, 0.038034615718061104, 0.03060805524000898, 0.08772232293267734, 0.01571807366417488, 0.0242979297763668, 0.04879569765762426, 0.009457381729589542, 0.02899216597143095, 0.07665977318538353, 0.0673654793354217, 0.029988417591084726, 0.023864435752329882, 0.03709727207024116, 0.05789748211100232, 0.0298911981008132, 0.0457944450317882, 0.011813636592705734, 0.04481040916289203, 0.020248946457286365, 0.01693966729362728, 0.047370288011734374, 0.012154875166743295, 0.03862502388074063, 0.01903331227367744, 0.04267114993126597, 0.03367543322383426, 0.017758773828973062, 0.054179574581212364, 0.0692369308671914, 0.03993196820374578, 0.07595218732603826, 0.06080763982026838, 0.015603933206875809, 0.04162007215199992, 0.007966561970533803, 0.036942894221283495, 0.047453820443479344, 0.02715958071348723, 0.007309177763090702, 0.06158943673653994, 0.028486653936852235, 0.07863099162932485, 0.04712566500529647, 0.023289271302928682, 0.012233999241288984, 0.02864957019482972, 0.013970620166219305, 0.04857251900830306, 0.011279220689175418, 0.030636650189990178, 0.03896604815963656, 0.054181274099391885, 0.02861954661057098, 0.037819571007275954, 0.025254591528209858, 0.0104546111288073, 0.02974449405883206, 0.05895048947422765, 0.014134213633951731, 0.01338363608738291, 0.04288090312911663, 0.012306801145314239, 0.06927967115188949, 0.030353895635926165, 0.03040509640413802, 0.022060784976929426, 0.051038408564636484, 0.017083167113014497, 0.047953014945960604, 0.002515362280064437, 0.03925908145902213, 0.026134398322028574, 0.08726516738533974, 0.015718435461167246, 0.03543885031831451, 0.011068487856391585, 0.04100524733075872, 0.1301504677394405, 0.024923673445300665, 0.008126174743665615, 0.01869893207185669, 0.04107971071789507, 0.04493175772950053, 0.009806047346501146, 0.018924663709185552, 0.07620137082994916, 0.05257377852103673, 0.0404915475519374, 0.014975633766880492, 0.04489303617447149, 0.028557469668157864, 0.09073671157239005, 0.03096374435699545, 0.04687267428380437, 0.03974727733293548, 0.052616381508414634, 0.02511627561034402, 0.05876432915101759, 0.026109551217814442, 0.01426457094567013, 0.03946213677409105, 0.05849003136972897, 0.0301016062439885, 0.010327455256629037, 0.008647114173072623, 0.045420903552439995, 0.03444312562351115, 0.010546705161686987, 0.04155681519478094, 0.0444321364921052, 0.02919479269621661, 0.038861787543282844, 0.03611456835642457, 0.07080226874677464, 0.036960920988349244, 0.008691802595421905, 0.009727397318783915, 0.036975552429794334, 0.0463664219569182, 0.027995947748422623, 0.03101157577475533, 0.02211798415373778, 0.022829087793070357, 0.011816495716630016, 0.008738883516343776, 0.14251712680561468, 0.11203273563296534, 0.12374515441479161, 0.1353049950557761, 0.17958787822863087, 0.07961245224578306, 0.11614307601121254, 0.18249495973577723, 0.1526522368658334, 0.05583212223427836, 0.11089077073847875, 0.12213759575388394, 0.12911766534671187, 0.13381004246184602, 0.08469361084280536, 0.18732879019808024, 0.09493668854702264, 0.13898613658966497, 0.1412983422051184, 0.10790246858960018, 0.1407086761901155, 0.1704855408752337, 0.1569597510388121, 0.14684933965327218, 0.10132153343874961, 0.09434193139895797, 0.09663351273047738, 0.11900022582267411, 0.12870108301285654, 0.1801186622469686, 0.21782541938591748, 0.11186101750354283, 0.10948519498924725, 0.11956360496697016, 0.20239124132785946, 0.11270788221736439, 0.1319579387200065, 0.10332519857911393, 0.07331684319069609, 0.18138417246518657, 0.2529260655865073, 0.09545618449919857, 0.0669538248621393, 0.20002628385555, 0.14478855882771313, 0.16619669913779944, 0.11986127297859639, 0.13780537963612005, 0.0936874833132606, 0.17862393229734153, 0.08205520163755864, 0.14056943444302306, 0.15076229843543842, 0.20011767192045227, 0.13429877639282495, 0.12196510579087771, 0.10474596609128639, 0.13675325171789154, 0.11725387812475674, 0.13710164552321658, 0.13176542561268434, 0.1692773393006064, 0.05390512465965003, 0.16169210022781044, 0.09272466544643976, 0.15685452934121713, 0.09840126396738924, 0.16202731349039823, 0.09580967685906217, 0.11239501502132043, 0.08437121447059326, 0.11971989384619519, 0.09194377766107209, 0.12251428765011951, 0.10364404748543166, 0.12451989721739665, 0.20596759160980582, 0.14897580054821447, 0.09557722136378288, 0.1602764832205139, 0.1280164666241035, 0.09508072456810623, 0.19976181210950017, 0.13022998144151643, 0.2694183384301141, 0.09397065718076192, 0.16876844863872975, 0.1280576706631109, 0.10299092784407549, 0.06053995828551706, 0.10028130214777775, 0.1539304674952291, 0.15736245521111414, 0.11508713345392607, 0.12777460069628432, 0.09559807571349666, 0.135317804524675, 0.2085599282872863, 0.12953853729413822, 0.22043283650418743, 0.07691325372434221, 0.07019967451924458, 0.1830414030700922, 0.1066658872878179, 0.05882848039618693, 0.14284759032307193, 0.17898850492201746, 0.1642683768295683, 0.08411888426053338, 0.14733057789271697, 0.1677567232400179, 0.10950486932415515, 0.1705202882294543, 0.1575297352974303, 0.1371789030963555, 0.0904003405594267, 0.15734140790300444, 0.12986065907170996, 0.1263550651492551, 0.15587284608045593, 0.15840386651689187, 0.10785492660943419, 0.12696211226284504, 0.11634384922217578, 0.1113995055493433, 0.13464463205309585, 0.06916707992786542, 0.0720052159158513, 0.2064393600448966, 0.15540832100668922, 0.12234772002557293, 0.11437968860263936, 0.14071878424147144, 0.11466750089311972, 0.12933971593156457, 0.15785978321218863, 0.16420323110651225, 0.11382091819541529, 0.15200873545836657, 0.0813586737785954, 0.24268368550110608, 0.09729739351314493, 0.18924295232864097, 0.15614294330589473, 0.09171781595796347, 0.14393551944522187, 0.09028844695421867, 0.14867122314171866, 0.16378102329326794, 0.10971404364681803, 0.08101309271296486, 0.1408226997591555, 0.21221981471171603, 0.157878203317523, 0.23171291715698317, 0.16271583357593045, 0.1270706587820314, 0.1918385989847593, 0.1291351651889272, 0.19800958660198376, 0.1412326324498281, 0.2588743792148307, 0.08262121540610678, 0.10509296465897933, 0.18170748167904094, 0.1413008209783584, 0.1748736374429427, 0.11399244336644188, 0.12373224846669473, 0.09371032661874779, 0.08064442343311384, 0.19458846392808482, 0.1223488109826576, 0.12400893596350215, 0.10304804352927022, 0.1373649892047979], [0.03549592518538702, 0.05197353690164164, 0.03037733637029305, 0.07795262412400916, 0.051829467483912595, 0.028975003806408495, 0.0871848373208195, 0.035613232757896185, 0.014396988644875819, 0.01885648445750121, 0.04112619142688345, 0.051882312109228224, 0.022337073569360655, 0.02178419024858158, 0.03519921825500205, 0.016070386009232607, 0.036790345766348764, 0.015172361345321406, 0.03250603855121881, 0.03715161212312523, 0.06701356775010936, 0.012346916082606185, 0.02747853908658726, 0.006405388930943445, 0.014498856762656942, 0.027744170438381843, 0.060781542197219096, 0.03077945795666892, 0.06611589560634457, 0.044848195611848496, 0.020311856460466515, 0.032818783292896114, 0.026741636538645253, 0.02644024665642064, 0.008489286265103146, 0.01987485207791906, 0.028449863821151666, 0.037570365238934755, 0.024465150490868837, 0.04430809764016885, 0.040448402796755545, 0.02528504926885944, 0.04345576329797041, 0.013412220832833555, 0.060186684859218076, 0.037914191125310026, 0.008457212497887667, 0.06255207277718, 0.04006236726127099, 0.011418070025683846, 0.02521257112675812, 0.007791465213813353, 0.045672395135625266, 0.016864417229953688, 0.01999823041842319, 0.010546018675086088, 0.0063075182060856605, 0.017946934240171686, 0.03042795455257874, 0.04231849990901537, 0.03363717551110312, 0.04327744376496412, 0.12094311648979783, 0.04015174039523117, 0.03256879455875605, 0.06207729493326042, 0.08636539496365003, 0.033041587157640606, 0.0580036314931931, 0.03204685322998557, 0.036175854911562055, 0.03635531735199038, 0.03626112396887038, 0.03193152719177306, 0.01141824628575705, 0.04648437890864443, 0.07132566839572974, 0.016203248997044284, 0.05180805652344134, 0.06314652564469725, 0.022563675374840386, 0.04836017200432252, 0.03423669724725187, 0.010567082681518514, 0.05907899605517741, 0.016650376273901202, 0.06053946475731209, 0.0689691342995502, 0.03134779464744497, 0.019963863414886873, 0.02126196319295559, 0.07318521587876603, 0.020866389204456937, 0.02358930119953584, 0.023725010323687457, 0.04840827801672276, 0.02259727054479299, 0.08357098631677218, 0.07122155991964974, 0.027025263116229326, 0.05960565744317137, 0.039916271780384704, 0.04163600235187914, 0.07380579234450124, 0.01345361504718312, 0.0443627531058155, 0.013346497162274318, 0.038253790480666794, 0.0253252272887039, 0.0641040519985836, 0.02130662749550538, 0.05483846071001608, 0.050630331243155524, 0.07988827885128558, 0.022397321117750835, 0.04050845367601141, 0.0544875992636662, 0.016370196972275153, 0.0646619986218866, 0.04436525785422418, 0.03925361925212201, 0.018953651997435372, 0.05555868905503303, 0.02154422978492221, 0.02632964438816998, 0.03323241187899839, 0.01574265545059461, 0.022037707894924097, 0.014417396778299008, 0.006015730323269963, 0.03010084925335832, 0.03389515717572067, 0.002010889484154177, 0.023828369230614044, 0.015423056975123473, 0.04626063622708898, 0.04246289587172214, 0.042181091266684234, 0.02126232870068634, 0.06250801889109425, 0.11518153463839553, 0.03783564221521374, 0.022531211980094668, 0.018154987919842824, 0.0712328554072883, 0.05254610383417457, 0.022704481198161375, 0.06860945984954014, 0.03598858878831379, 0.011319291097606765, 0.02506962791812839, 0.042905969166895375, 0.029671650408999994, 0.06033187120920047, 0.0683101145841647, 0.04129423221456818, 0.0351862380921375, 0.04328031587647274, 0.019450521722319536, 0.04766539561387617, 0.08747767395107076, 0.023827421136957128, 0.03621182680944912, 0.01843878890213091, 0.04695984323916491, 0.09037870695465244, 0.037625243348884396, 0.04204011660476681, 0.012276130964892218, 0.03331186991999857, 0.029055127924948465, 0.0067421973471937235, 0.03995764651335776, 0.03238927645725198, 0.049173795923707075, 0.03953745363105554, 0.005978547796985367, 0.04443316436663736, 0.03638323694758583, 0.038921957166166976, 0.03483817825326696, 0.05435999068140518, 0.06655766643234529, 0.09520329025690444, 0.04098269717360381, 0.05735161394113675, 0.04809660938917659, 0.15743438416393474, 0.052043847972527146, 0.05731892233598046, 0.03802447798079811, 0.009371201686008135, 0.05424987823062111, 0.06529433070681989, 0.026423028830322437, 0.03759397295652889, 0.026150443554797675, 0.01975427720026346, 0.022192145115695894, 0.010074335586978123, 0.018992685254488606, 0.028791136719519272, 0.020334369510237593, 0.036853944111499004, 0.06692869574180804, 0.055762390038580634, 0.04491341926041059, 0.031622162932762876, 0.04500483330048155, 0.04425429564435035, 0.03182789369020611, 0.011478142241685418, 0.11708642734447494, 0.11869524023495615, 0.0138217397761764, 0.006368169297275017, 0.06363227614201605, 0.025630984710005578, 0.03840964891423937, 0.026637253467924893, 0.028780021202692296, 0.04697818170825485, 0.09440695837838575, 0.06507633966975845, 0.05133544575073756, 0.02676170606719097, 0.06105218861193862, 0.006493272667285055, 0.06119376441347413, 0.10476097231730819, 0.024232635623775423, 0.023153228212322574, 0.011055978957301704, 0.058054557666764595, 0.013648316562466789, 0.04109173722099513, 0.04321663589507807, 0.02956611329864245, 0.03957760382036213, 0.06114938027167227, 0.03200648039637599, 0.10622384928865358, 0.03786700908676721, 0.03514738295052666, 0.03191517767845653, 0.016659248649375513, 0.03487946392851882, 0.06497517009847797, 0.05490129093232099, 0.0051693331624846905, 0.014029647809365997, 0.050229267217218876, 0.09094768189243041, 0.04772682317707222, 0.04409114560985472, 0.036935008902219124, 0.014592659590562107, 0.06715459065162577, 0.09527645859634504, 0.0576904637273401, 0.049760022084228694, 0.054918968889978714, 0.06523571588331833, 0.08972929063020274, 0.031100982305360958, 0.03586834231100511, 0.06182743236422539, 0.0468661396735115, 0.0448497875186149, 0.03280610741057899, 0.03906965197529644, 0.04763131990330294, 0.04747767306980677, 0.049837955011753365, 0.03783674430451356, 0.03271635578130372, 0.022559580575034488, 0.008665487894177204, 0.03092717317485949, 0.016499484663654584, 0.024954934560810216, 0.05628758197417483, 0.05314415611792356, 0.05449829732242506, 0.04775848690769635, 0.04433959438756574, 0.06894482154166326, 0.05575400748057291, 0.006858222395749181, 0.022290264460025355, 0.05695595646102447, 0.015198189939837903, 0.08381283740163781, 0.011297551736788591, 0.035775581272901036, 0.06321548600681126, 0.039480709019699134, 0.004818445277123828, 0.022932255596970208, 0.009224685963999946, 0.03687814554723445, 0.05717676394851878, 0.05001982572139241, 0.047830204348429106, 0.04482958996959496, 0.0374217612989014, 0.023261630012711976, 0.014155565222608857, 0.01200531107315328, 0.03597317809180822, 0.035492084571160376, 0.04234869789797813, 0.04096005424798932, 0.057020018648472615, 0.01957064388989238, 0.08807486534351483, 0.11637821065960452, 0.019359452780918218, 0.02562862468039384, 0.014270930223574396, 0.039565035549458116, 0.059398345911176875, 0.06504393750219606, 0.05429254058981314, 0.05308369334670715, 0.10337053638068028, 0.03946446340705734, 0.0741765322163701, 0.018484161955711897, 0.04789083410287276, 0.04469884210266173, 0.039592528410139494, 0.032387847822974436, 0.06052200944395736, 0.04616755606548395, 0.05442821260658093, 0.010036396070063347, 0.0724947068374604, 0.06264579860726371, 0.058073092804988846, 0.038135499562486075, 0.053349452718975954, 0.01698496242170222, 0.05297536205034703, 0.06177992749144323, 0.04790461949596647, 0.033953163438127376, 0.03564972786989529, 0.06158384094305802, 0.022231360198929906, 0.028436746360966936, 0.030882306637067813, 0.0916397939727176, 0.1810261158971116, 0.1334909041179344, 0.2327513598720543, 0.11425544566009194, 0.14961116801714525, 0.2451064859633334, 0.15468904632143676, 0.12985403911443427, 0.14808316016569734, 0.10954445548122749, 0.260727729764767, 0.08758881798712537, 0.12215732203912921, 0.10141931881662458, 0.11017123630153947, 0.11934478272451088, 0.18178582278778777, 0.1158543508790899, 0.12032634724164382, 0.1487219415139407, 0.0790161662735045, 0.08927098475396633, 0.13044054358033463, 0.13657752599101514, 0.09634955218643881, 0.12376793834846467, 0.1389572225161828, 0.14092927216552198, 0.09992420295020565, 0.13428788166493177, 0.14663548237876967, 0.1482303428929299, 0.12429522685124539, 0.1246184395859018, 0.08387183072045445, 0.22632483596680686, 0.1981186674674973, 0.11006176209775731, 0.08745198079850525, 0.21984257677104324, 0.12903129420010373, 0.16064007621025667, 0.1001244195504114, 0.1895854831673205, 0.1257674177759327, 0.18059415626339614, 0.13949851534562185, 0.13092482462525368, 0.11209923948626965, 0.1454467250732705, 0.07586946754599921, 0.1345878725987859, 0.18890387989813462, 0.13715239358134568, 0.17943743005162105, 0.12496845127316192, 0.1449315409990959, 0.07208527880720794, 0.16595135995885357, 0.11156347565702163, 0.20613441156456247, 0.20198120473651215, 0.1824349199887365, 0.1083997669047676, 0.1734916100394912, 0.0884640178992413, 0.1183322854922153, 0.09235201083356515, 0.11626693303696811, 0.23463187302695587, 0.20582965604262426, 0.12279977701837197, 0.0889859109884128, 0.1817208106513135, 0.12698258069576696, 0.3722028527408838, 0.097297200554749, 0.12125565714086406, 0.1861340957111679, 0.08978881829534657, 0.26479051331989467, 0.17953310773009434, 0.09951649670256302, 0.12471667025238276, 0.09685078388429247, 0.17384493170538917, 0.11050407469156198, 0.13152629078831524, 0.16003512195311487, 0.1257425855146721, 0.15967280545737594, 0.11675231988192536, 0.17163561744382605, 0.09879535180516541, 0.13720700080739334, 0.1147801143815741, 0.13408705650363117, 0.12455663352739066, 0.1526680149254389, 0.20749150280607864, 0.19561154418624938, 0.0964271288830787, 0.10176063995459117, 0.05250585716567002, 0.16116260754643008, 0.16685525130014867, 0.11306360102025792, 0.13093422021484002, 0.14391298784175888, 0.1316650427179411, 0.11748007731512189, 0.07180225336924195, 0.1863917990704067, 0.12301713722990826, 0.10555846936767921, 0.15522165602305904, 0.12106229056371376, 0.11246606081840582, 0.20391481113620102, 0.20181957981549203, 0.13661071483511478, 0.12273266460397281, 0.06144287370261736, 0.1402265770593658, 0.14081558998441324, 0.3510998538695276, 0.13095810252707452, 0.13338216464035213, 0.09508060582447797, 0.19097375945420936, 0.10002848212025128, 0.10858878449653275, 0.173072830948513, 0.11975568762863986, 0.08913819227018394, 0.16602297720964998, 0.10882814196520485, 0.13985013007186353, 0.25900262233335525, 0.44568627839908004, 0.16714747936930507, 0.06338438397506252, 0.09316740848589689, 0.15939956152578816, 0.10226297003100626, 0.12787758110789582, 0.20006552862469107, 0.19678066426422447, 0.17771598882973194, 0.11226810776861385, 0.198429063311778, 0.1110423840873409, 0.13847414375049993, 0.12525202590040863, 0.11433795763878152, 0.18770679569570348, 0.12232515873620287, 0.14008010679390281, 0.15949087537592277, 0.10888315737247467, 0.15600477025145665, 0.1552204240579158, 0.10400496132206172, 0.14058209548238665, 0.16769303212640807, 0.09785960748558864, 0.13120216521201655, 0.0849385344190523, 0.21893688943237066, 0.10622482892358676, 0.08896458908566274, 0.24676759057911113, 0.11256399462581612, 0.09312218200648203, 0.11205264745512977], [0.03196280500560533, 0.031604477553628385, 0.037616359841194935, 0.005794486360173323, 0.10125709275598638, 0.050410421754349954, 0.030050524219404906, 0.0104203953378601, 0.028271230730751995, 0.033814214839367196, 0.012559218557726126, 0.01606257304956671, 0.036820217210333794, 0.1372763916151598, 0.033056515458156355, 0.04421312871272676, 0.029207847073848825, 0.014764435236429563, 0.05059356153651606, 0.03216258002794348, 0.055788970057619736, 0.009122524697886547, 0.014941124827601016, 0.05836599251779262, 0.06000801280606538, 0.03982653499406297, 0.03892609463946428, 0.012347401261649793, 0.04293252692150418, 0.034897479563369416, 0.054700666150893085, 0.0392142928467365, 0.040112644055625424, 0.042607896684785374, 0.005478420507643023, 0.08412117007537745, 0.02075721371511463, 0.013347466592676938, 0.03597944923967589, 0.0497630314930575, 0.01396206969729974, 0.02648825062351534, 0.01578626219270518, 0.017623053572606295, 0.051576955447671935, 0.03390677920833696, 0.0322007969225524, 0.03689972720167134, 0.01726072408928303, 0.05134542392625008, 0.011725827534974087, 0.037463032131199725, 0.09032297166413628, 0.05250375688774511, 0.03177235135808587, 0.0419715755560901, 0.0626745939371176, 0.04974372452124953, 0.04331190539232921, 0.012906796928291442, 0.07978296067449264, 0.03100254383753054, 0.06103549028921407, 0.03448441129876301, 0.041512160169077106, 0.05825369444210082, 0.07040263706585392, 0.04373682946607005, 0.028239260864211246, 0.044314183251117356, 0.03189477603882551, 0.02995619724970311, 0.008741703677515034, 0.01615484983631177, 0.015053265196911525, 0.036080214340472594, 0.04522241244558245, 0.04186056881735567, 0.027494628848216962, 0.060689033489325084, 0.023867448871897068, 0.023125466323108412, 0.04643593150831293, 0.01573031539010117, 0.023139216464187484, 0.014126492515060818, 0.05920751747908071, 0.04838744593143929, 0.026974071624863427, 0.07121367831132375, 0.09979339942219667, 0.08014789695153013, 0.012910096702398732, 0.030528719653375447, 0.03297808529168833, 0.05336216570867691, 0.04007649404229596, 0.027453044458525255, 0.03640859984443523, 0.044362344924593344, 0.05160608474398032, 0.020685791278083343, 0.03208809066563845, 0.035031904772040434, 0.03268998727435246, 0.019915096891054418, 0.06065099471015856, 0.04513467203651089, 0.04574702921672724, 0.08575503044994548, 0.00672683860102552, 0.022405525560316164, 0.013565982699219603, 0.0441272251191549, 0.016564264878979884, 0.03416046383790672, 0.06609818054130301, 0.04300809610867873, 0.009903585960273631, 0.008491006192343775, 0.08638852028525434, 0.0838938650849741, 0.03242524835513905, 0.016351001322618686, 0.050765057021635585, 0.03464183566393331, 0.036732198495883495, 0.030254633384174667, 0.044367829395923764, 0.047669670384493656, 0.07063915953040123, 0.023212707637867425, 0.0590318140166346, 0.048820214506122284, 0.024472208315273747, 0.08658523394842632, 0.09979320646380074, 0.06284696515649557, 0.03593659392208792, 0.03430506389122456, 0.03629853563325014, 0.005368590072976076, 0.027496471229824238, 0.03655822052678559, 0.01876129103038693, 0.028285060652706306, 0.06582869929843582, 0.03381661939783953, 0.03137263804092072, 0.06358723519952036, 0.026374863446108066, 0.018352302722632885, 0.01989673801290337, 0.056354735206696205, 0.032856803518370725, 0.08522467687726021, 0.05703977833036333, 0.05416420099209063, 0.07926304911961779, 0.032589118272881024, 0.0113252811570419, 0.0027073802357335808, 0.08483062614686787, 0.00973190215518116, 0.020188047674309928, 0.03897223767125979, 0.028592228154593613, 0.023351815798378084, 0.018764497108350042, 0.010978091486322228, 0.029723203697358258, 0.036878056489513256, 0.020017299902974628, 0.023767173588566948, 0.00866256290464662, 0.02123220492649125, 0.0325966918899212, 0.0039047830978233833, 0.02138973319233628, 0.027923562374780886, 0.02214927866589278, 0.034693830530159175, 0.05278977689158637, 0.02946174136013724, 0.05022524106607307, 0.01757970287144417, 0.047080171352718025, 0.07418533408781514, 0.028048220920027234, 0.09290442103520036, 0.023766099329805, 0.059352191747166216, 0.02846138009772403, 0.0931680689973291, 0.03122299509414006, 0.09191040328005329, 0.024652845204400364, 0.01731930922687752, 0.05316397517162841, 0.035357035958440974, 0.10505734157050028, 0.01665944160777144, 0.024022195939323865, 0.012532228502095677, 0.024538647230656352, 0.0498222994065145, 0.07163336282246746, 0.058279862569179386, 0.08698690653545782, 0.07202837092336267, 0.033668427349766716, 0.053327422065194696, 0.06169081781990826, 0.022751167853130028, 0.03804095736995805, 0.022398035434889607, 0.033071250800276175, 0.00845263066366897, 0.01746174406434875, 0.03198927741323132, 0.028786904622393195, 0.0628741574473679, 0.04782887961482629, 0.07518217942561023, 0.04609095900377724, 0.0267606819033972, 0.037064409771119244, 0.0249632818668033, 0.0384339208540041, 0.062408482044702396, 0.0305503532581497, 0.016581143172516022, 0.016397187027905602, 0.05503490348928608, 0.05385760494391434, 0.02450957545079291, 0.04715394454251509, 0.016425843205070123, 0.05236475633864757, 0.03125502618786413, 0.021938041172688827, 0.03311650696559809, 0.021125463681528345, 0.06891825265483931, 0.02802698621962918, 0.012066927884006873, 0.04618566446879413, 0.023786656820448115, 0.018430391501169652, 0.011031436133634998, 0.022836921161797363, 0.025059970721486025, 0.01132981382397702, 0.012711278122878866, 0.058017435439978726, 0.0274442481531878, 0.05611667278571986, 0.03682255126477685, 0.06887528972583823, 0.04463808989385143, 0.061984990315977484, 0.07949933409690857, 0.08297200634842739, 0.004457505929167382, 0.04751885113364551, 0.03828641529253218, 0.0840000515745487, 0.12432871255441569, 0.04423474005307071, 0.03668889788968954, 0.044424336520023644, 0.020587124599842355, 0.02815986590576358, 0.06016439445374999, 0.03827212523901835, 0.03537928554578684, 0.046569466139771976, 0.033441137202316895, 0.11280591250397265, 0.011188940279680537, 0.021150466636754572, 0.05672526727721561, 0.0442072546138661, 0.008144459407048998, 0.04730590299004689, 0.11351595487212762, 0.07171467252192087, 0.06210128114616964, 0.05152447447471786, 0.04278318083379418, 0.010963538898067782, 0.041193467113771476, 0.04829511533898767, 0.07344530153204687, 0.04402940634463448, 0.056142629400710575, 0.07356449044891633, 0.1251905463868752, 0.0865004064689856, 0.039747566770529374, 0.031442336839972995, 0.0980530260130763, 0.03549388799001463, 0.06017675492330454, 0.08152653274009936, 0.014425096560444217, 0.02523578736145282, 0.05274097326037008, 0.074102458456764, 0.031234672787832096, 0.03440310902078636, 0.06293448663200252, 0.07347968523390591, 0.045191194003564306, 0.039918257025419734, 0.02797651646687882, 0.008659107279527234, 0.02897985188610619, 0.004032766464661108, 0.04159040479862597, 0.0204488123927149, 0.04290383178158663, 0.006905560285304091, 0.014152990897855489, 0.010616534764267271, 0.05678047935361974, 0.042082218642462976, 0.029677800957870204, 0.011699374608724611, 0.04032413016830105, 0.081083797122119, 0.06737436284311116, 0.04681817095843144, 0.03182092863426078, 0.04161417578870896, 0.019280148735560942, 0.08883521790266968, 0.037174600147409365, 0.026495733327465132, 0.03892556400387548, 0.029516368995246012, 0.08924936599214561, 0.042302116999053396, 0.03908022386895027, 0.048240623145829886, 0.016221242367464583, 0.03716795792570338, 0.02295017289725365, 0.04877681742073037, 0.032360488548874855, 0.03771747746213805, 0.044335583079373464, 0.145792179973796, 0.08842645780532621, 0.11689242252032273, 0.1572242079419084, 0.1734951723483391, 0.14209812507033348, 0.10358090556110255, 0.12629288801690564, 0.1816299420897849, 0.11512120545376092, 0.09976058165193535, 0.10876643238589168, 0.0966699818673078, 0.1771463904879056, 0.09740444831550121, 0.21847622352652252, 0.12246503873029724, 0.17906827095430344, 0.15479959663935006, 0.19117881485726684, 0.10931555487331934, 0.20100441965041682, 0.14542573713697493, 0.12284149313927628, 0.2290278417058289, 0.11491715195006691, 0.14348892465932295, 0.0712911956361495, 0.183420788962394, 0.1658569142455235, 0.1604326459346339, 0.23307854309678078, 0.13318070123204961, 0.18375269224634394, 0.11113201326224953, 0.21725901227910072, 0.1503593270899728, 0.0668320755357854, 0.13246875896584243, 0.15184457239229232, 0.178499533503782, 0.13198568020015955, 0.1800852210726589, 0.09767715790076181, 0.1270334771834314, 0.23160662676673383, 0.133397423196584, 0.12005034994217567, 0.12646744115045294, 0.10182973390328698, 0.17649791669100523, 0.09035118069732562, 0.22606857237406075, 0.2245733080781065, 0.1062824492692016, 0.12451317335944623, 0.1336830313084647, 0.12279508664505556, 0.15225996728986502, 0.14424224907997996, 0.17979008378461003, 0.1619313537958078, 0.1771059285965748, 0.09362428201711737, 0.12453619478037581, 0.15495440864469856, 0.11879448022227734, 0.14157719677314162, 0.1057819374545943, 0.22511130577186123, 0.09509529292699881, 0.10016411702963524, 0.13774182210909203, 0.08293841674458236, 0.14429105271119624, 0.11837428362923674, 0.16824084101244807, 0.07606930565088987, 0.16551427950616926, 0.16963974485406652, 0.14372097939485684, 0.08933134362450801, 0.21866159717319533, 0.13653197296662256, 0.13813481898978353, 0.12562474730657414, 0.14820315060205758, 0.11463918053777888, 0.1290177128976211, 0.13225411501480266, 0.17074177478207275, 0.26742118934635073, 0.1208859117468819, 0.13171536033041775, 0.15618681907653809, 0.08371074014576152, 0.11520268584717996, 0.13795734179439023, 0.07383706644759513, 0.1485838575172238, 0.15477621898753569, 0.09837490288191475, 0.1278384105535224, 0.10754507995443419, 0.07976667795446701, 0.095950781396823, 0.1383171053021215, 0.09420191039680503, 0.13322687766049057, 0.29424558277241886, 0.13875737698981538, 0.16101867542602122, 0.12434952237526886, 0.12765711871907115, 0.1464230054989457, 0.10132897717994638, 0.1355836566654034, 0.12884900788776577, 0.1069840311538428, 0.08129461159114726, 0.11390794243197888, 0.17920375743415207, 0.17639928526477888, 0.10327125928597525, 0.17399248550646007, 0.19045124296098948, 0.08229513055994175, 0.17609595466637984, 0.15279097395250574, 0.14988763286964968, 0.2546265040291473, 0.12408559981849976, 0.1349223288707435, 0.15977830917108804, 0.10599583925795741, 0.14861487929010764, 0.152974521915894, 0.1484982730471529, 0.13168172619771212, 0.1463306971709244, 0.12065959381288849, 0.09133734653005376, 0.0968856574036181, 0.13263908185763285, 0.14345805131597444, 0.16022935684304684, 0.09747737174620852, 0.11822215077700093, 0.09607661253539845, 0.2629046270158142, 0.0989306675910484, 0.11412695763283409, 0.15452360676135868, 0.1256513161933981, 0.23027460527373478, 0.30872871342580765, 0.15561831911327317, 0.1345138656324707, 0.1731580146588385, 0.11104793535196222, 0.2135509901563637, 0.14130390831269324, 0.28217078070156276, 0.1852252022945322, 0.06349505303660408, 0.15359555109171197, 0.09434331179363653, 0.09727251672302373, 0.09541429768432863, 0.10233032735413872, 0.14799739758018404, 0.09626471728552133, 0.09280925543862395, 0.0779844622593373, 0.13858518388587981, 0.10109701150213368], [0.0560146349016577, 0.059278585540596396, 0.0033562893486305256, 0.016638475935906172, 0.04577729028824251, 0.005301820901877363, 0.024997773180075455, 0.01332451289272285, 0.014339739373099292, 0.02626294386573136, 0.029166910208004992, 0.04576447339786682, 0.0306915765395388, 0.036683977450593375, 0.06284706163569354, 0.028257872072572354, 0.04777337810082827, 0.01652160623052623, 0.03304036632471252, 0.014643419708590955, 0.03563354905054439, 0.018231314097647555, 0.03253000621043611, 0.04578082291118335, 0.0026021917028629105, 0.027143670922669116, 0.012726282493531471, 0.04172776891209651, 0.03060153547266964, 0.0164619672432309, 0.07519751219660975, 0.04012734971183818, 0.03395009094674606, 0.042481802083784714, 0.06774407112970948, 0.021674222516594455, 0.03288952852017246, 0.11322944876155816, 0.04487730264372658, 0.010701356677600415, 0.023073148622643203, 0.024871494897524826, 0.07125949108740315, 0.02098451128404122, 0.029219014541013166, 0.008430503530689748, 0.05425108422059566, 0.04353883930889424, 0.06640764870098792, 0.026167023133893963, 0.06327367038466036, 0.058281699384679087, 0.018828088032023516, 0.02808492568874499, 0.01123959278629627, 0.0708598668279592, 0.037790757123730145, 0.05232727045950014, 0.03294296686362941, 0.044563722985913046, 0.0936380191706121, 0.04340133789810352, 0.045374816181720234, 0.02079952540952945, 0.04699206729128491, 0.06240322763915174, 0.027976032215519808, 0.020265839593776036, 0.11182403628481552, 0.02211014707427239, 0.06995658404775895, 0.0337693297478836, 0.046880548470653594, 0.015038036326586735, 0.06110263610025868, 0.016824241065478418, 0.044361105537973344, 0.06355231715133414, 0.04571621153445449, 0.05875690025277436, 0.07946593745145947, 0.04653336807677988, 0.03422555389988702, 0.06973942421609536, 0.02257951466162922, 0.05740153821534477, 0.013516378476197133, 0.07761474655126221, 0.03813482791883871, 0.05224390501098242, 0.04098130935744848, 0.016366803502023686, 0.008991367722046562, 0.06016002320393454, 0.05869929475011304, 0.013744262341788271, 0.08234034219640307, 0.011010668986273231, 0.05415302795881871, 0.04608611649018712, 0.0637335867213551, 0.025416797179786954, 0.03508024456095882, 0.04430793436767999, 0.024336848000530154, 0.021749839943367988, 0.056470951822120696, 0.026966208570229355, 0.01501509746958618, 0.013101546683174092, 0.04293686848541256, 0.059375072160037234, 0.05283341888571158, 0.07288888373295777, 0.041168000316247344, 0.05411588717834093, 0.024700633948668838, 0.044571389371412806, 0.023919018858578056, 0.09683660886366852, 0.019382123537070584, 0.01309571340243565, 0.0925444794120267, 0.0518830913642887, 0.06072717245842796, 0.024933792628871743, 0.06899493877426721, 0.06876922940136865, 0.011432824849180179, 0.04126450920011848, 0.0486889471358154, 0.02961753856652649, 0.049039897639886476, 0.009603255493857432, 0.031152324081631377, 0.01072045120963594, 0.016992665914585814, 0.044859428016934544, 0.09969007020117715, 0.037335753804654814, 0.031876797511358745, 0.059102258674101904, 0.057909549432224594, 0.13175956264603883, 0.020090846737730317, 0.021282633861119393, 0.040979754558065906, 0.029592338942165952, 0.05730917051550932, 0.057299763793707825, 0.029820790550729726, 0.058750918542500585, 0.03107819280558033, 0.054500816913787276, 0.046574984007747844, 0.04538826018688269, 0.06000988301821053, 0.04483798365981784, 0.0399610678141471, 0.01053055046213558, 0.07395929816993885, 0.028994509302719962, 0.04279868800949771, 0.008321655514009763, 0.026781491724250372, 0.05726867893827148, 0.03983851696830243, 0.05477130376675632, 0.03510512877255678, 0.04205476288916543, 0.07823485546396114, 0.04431771216331981, 0.03206972993211821, 0.035853317531291395, 0.04049136201501824, 0.039548671193188056, 0.01963474504009355, 0.05284727849357296, 0.03964705399994273, 0.046150037669576705, 0.03977718217356596, 0.05354270055249799, 0.02028645460086409, 0.03282490601122845, 0.020261260542611126, 0.020703326372313313, 0.008162795093085151, 0.04909135073830839, 0.04988053202396259, 0.020556006347760558, 0.029555437504313886, 0.020453868273762055, 0.029231593944132328, 0.10501424505491741, 0.0206654397334205, 0.034012260657618754, 0.03123891045106575, 0.05577739255386405, 0.04661201346607413, 0.010442698730912525, 0.07991088466951624, 0.03350171500642318, 0.07890233566286042, 0.010129572710866341, 0.02793096900859382, 0.08432672271737829, 0.040376243778155185, 0.018504289000702556, 0.04868793781497516, 0.03833921538898721, 0.03670889505883679, 0.02082583825540496, 0.02207849818660179, 0.11681022224365734, 0.07716803302173503, 0.09052421984961256, 0.03266647603595629, 0.023167347571870778, 0.02108904649503529, 0.012291595467104344, 0.031070830700627994, 0.05286389889079146, 0.014410736002901103, 0.03838831959001254, 0.06852840248029679, 0.03757132260943763, 0.037975678060320206, 0.08268079502158798, 0.02770085684460355, 0.06152695532364305, 0.024539704791095573, 0.08577377710025758, 0.06638752907747403, 0.05365791526855901, 0.006866709318273934, 0.015650382374587934, 0.022354859138431493, 0.03799475496634841, 0.06423697064747103, 0.011834341585199581, 0.03830435671261512, 0.06930916410055943, 0.05142001718922984, 0.048354049285990186, 0.13461935450322926, 0.03696413819852751, 0.06029715354088694, 0.03810079302638769, 0.06426252279197797, 0.11069738189689815, 0.026198432678938843, 0.012056308678438654, 0.04509896731178742, 0.0995891603815835, 0.04766267564264126, 0.05030025735322852, 0.020183663436910138, 0.0357216308475472, 0.052596666355384514, 0.012135982869949657, 0.062152745376806706, 0.03269158289185725, 0.01843301684857579, 0.037258340380503796, 0.08690126269357279, 0.044206768507137895, 0.04034581943415105, 0.026064452758873813, 0.016614012893114705, 0.053328156791394576, 0.07146494725020602, 0.010042965004686266, 0.011840522747661453, 0.005818939662276534, 0.06406575717846863, 0.06581265406566672, 0.023213121385197155, 0.06157303898362443, 0.032369383188779466, 0.04037807317217812, 0.039006751248962246, 0.07753393409075215, 0.041511161980452016, 0.12942448403919116, 0.011593570325203473, 0.028157470624137204, 0.061251117585925385, 0.013515114042093046, 0.0583859154721722, 0.03993120008090045, 0.041785734356381, 0.032551146287005395, 0.06733033864293247, 0.05662240189849399, 0.04472344800888095, 0.048679685132810846, 0.03421791348955594, 0.02811676196870394, 0.05759562467574142, 0.038178109971340746, 0.03412904872675426, 0.05775129386165645, 0.043257817669655196, 0.047363081757794134, 0.017339293408440426, 0.0273763249424519, 0.015682138873671647, 0.02335901834157994, 0.036992974346503615, 0.037273224152158946, 0.05454834405099973, 0.037937991801300086, 0.061932616954436526, 0.07802372187143192, 0.02944897085399134, 0.08143159720930271, 0.09703718911623582, 0.03146020775602665, 0.07265230189659633, 0.05993441031023394, 0.051070428526145406, 0.012686915270023746, 0.029073234472889453, 0.03855690956697799, 0.0022753220355298254, 0.030486042451229878, 0.05542708771827165, 0.013331530826690141, 0.025730809138622135, 0.11174185085110366, 0.0842109699442517, 0.04024585214210674, 0.03823921098955907, 0.06196080372319557, 0.004417811696839635, 0.00505213598444243, 0.056780690865707584, 0.037391043806564994, 0.016933474071265664, 0.02893174772907514, 0.0301768989811535, 0.033942008958547376, 0.047335700219264254, 0.07224040251458064, 0.04884404486801941, 0.05266468790068757, 0.03852150541206356, 0.008322200064867502, 0.026093018022947945, 0.07091805862728506, 0.04480440889892634, 0.016619773814454675, 0.11725021933671087, 0.21258198277791962, 0.14841770549537614, 0.1570338470628485, 0.1800166763132438, 0.08203722682083026, 0.10961234715068713, 0.11510400247061625, 0.1439843824482523, 0.09815661498578265, 0.13550121890148148, 0.1557697617681697, 0.13130383944371715, 0.141922814946156, 0.11253057571593672, 0.14059989218367264, 0.09015788833494298, 0.3538809187011793, 0.1352561468956992, 0.10806953345309012, 0.15457496338058263, 0.22949140198761597, 0.1333064804202877, 0.1260830828687176, 0.1204593623697292, 0.1404716045362875, 0.12585402640979737, 0.16158465208718553, 0.07754342615953647, 0.19333065720275044, 0.27917677885852754, 0.12812145083444193, 0.21514568739803508, 0.08517746144207194, 0.1671411859570071, 0.1787298812996596, 0.11828247996163554, 0.1926816935883835, 0.14670984557596967, 0.14693458273541182, 0.098101339826826, 0.11451249592937529, 0.13180708978325129, 0.08389802111196332, 0.09731137557537295, 0.11679013972752728, 0.11485904920846224, 0.10279272988555022, 0.19859362713759765, 0.08123492807499133, 0.14221176272258162, 0.15728501952253282, 0.14235283015295863, 0.1307765583624132, 0.04272749378287699, 0.17412299959687516, 0.13313272880623117, 0.20575306640239432, 0.09250158327631652, 0.20261266850866377, 0.17580469138920307, 0.10093466669786721, 0.19359472818905488, 0.0996177330671344, 0.11151020429679193, 0.1380575614166446, 0.16668267227942124, 0.21630976087180898, 0.27019227971322834, 0.17276543338084593, 0.18999566818820313, 0.09215796148055233, 0.145321213058196, 0.20002059900434688, 0.14077043771976605, 0.12837385525926948, 0.17074551520636305, 0.1648664884851314, 0.23347246024059132, 0.1588163521955721, 0.09951674161129631, 0.16620597598375753, 0.13454751460812986, 0.09584491403074935, 0.12351154116913676, 0.09272036841139197, 0.04996553390810732, 0.1293055622954853, 0.10592003629426472, 0.1187613581714686, 0.12565207318402827, 0.09377465597935952, 0.12556332716485485, 0.12285995035199448, 0.22031387023162097, 0.21433931426145136, 0.1411676054704003, 0.1087243748770561, 0.1460191435762681, 0.22982925729593262, 0.18952312791952863, 0.17122685734648257, 0.09625628648791462, 0.13340420642634854, 0.07614801041199826, 0.16694902908056974, 0.1086191383365076, 0.2662714244797826, 0.1178640645230189, 0.16667367744958028, 0.1402297682943754, 0.14793152455240488, 0.24011723493458703, 0.21905023022554815, 0.14919216628186405, 0.1327535358723253, 0.14885963959386572, 0.0900829907914158, 0.13997059548273683, 0.19670873531140387, 0.0997885680408217, 0.20810750022064894, 0.2514573256485164, 0.1832414118689485, 0.11443230687291361, 0.10569912119535729, 0.12572538253152743, 0.1994424214353785, 0.08191687273210846, 0.15993047913070768, 0.09766068222234026, 0.11258694183197804, 0.11547460133442655, 0.09824596956605092, 0.12814920715754852, 0.09170039775199257, 0.10127343484782614, 0.13485596602549776, 0.13859934406355023, 0.15476827800739557, 0.17282943619647995, 0.15147453756071627, 0.2108174079330638, 0.31752794282510877, 0.14348733646329492, 0.11284027394140139, 0.12560813804157078, 0.1415627694223076, 0.2094281668541953, 0.21861751360120252, 0.15820948319742456, 0.1857707550516352, 0.083332267095102, 0.17975376307731494, 0.15909726993413642, 0.09170744073344395, 0.1660732799791731, 0.1291797831072472, 0.05177636681764852, 0.07788761198753491, 0.15887130080955103, 0.11622189209447242, 0.11388895087293349, 0.09603738260921091, 0.1168923408840783, 0.17117437266279012, 0.08209307343349792, 0.20877776347333565, 0.12693068973021582, 0.1538512358092703, 0.21513688552659005, 0.12046042364090681, 0.1128670728940051, 0.21691850008210167, 0.08419330682954751, 0.12903359485790133], [0.049969099927693605, 0.009486597300565336, 0.0312165903596906, 0.04120511141081806, 0.020074918393220287, 0.047677425827714615, 0.027808863451355137, 0.05076658955658786, 0.048367189010605216, 0.04174082700046711, 0.0021595966290988144, 0.04040613377583213, 0.03152395453071222, 0.05079532180388924, 0.015980589851096738, 0.03994648090156261, 0.05447541690955404, 0.05053403016063385, 0.01035016404784983, 0.055371916459989734, 0.02767392430541804, 0.0483057094970718, 0.03456055936112534, 0.03490562092338223, 0.014931805308151525, 0.025049807009054348, 0.019959111814387143, 0.013425531251414213, 0.05964739953924436, 0.03080214355577482, 0.02051648512860993, 0.018032038169621956, 0.016487237371620722, 0.019179157279722858, 0.0578177012357628, 0.05003958911402151, 0.0647399018635042, 0.01572425760969054, 0.018253084999741986, 0.02429436004604213, 0.028655316273216158, 0.08066829832387157, 0.02167327627830673, 0.02770543589576846, 0.028850504822912626, 0.05354195098334458, 0.04331417636421975, 0.05832370494317729, 0.03762762564292643, 0.021860340166313108, 0.07103720301529393, 0.01291616375965532, 0.018633376312209293, 0.03697078413097188, 0.029254518885863945, 0.034006983987637796, 0.073070843500318, 0.0316634782939218, 0.038407600586651824, 0.03044758992473362, 0.04415315204823855, 0.04349181312136352, 0.07660258328542113, 0.02071615068416577, 0.06205042176588904, 0.009219198709615739, 0.06782785218092613, 0.010252745105390204, 0.09299699653638527, 0.027015540981665254, 0.01663863549765665, 0.05995028113829903, 0.01453871473131585, 0.0024363671536775655, 0.06376578108756803, 0.04551423975499347, 0.02250143330456922, 0.054760479542892426, 0.021907034242758527, 0.10040651730378158, 0.01782083036232507, 0.01687930471234722, 0.005785979956272058, 0.0711769716872368, 0.04134285401960369, 0.06457117458921857, 0.017142698488896713, 0.006421206417144276, 0.015734016851638444, 0.01170415960586979, 0.07363304262980819, 0.05234382777416613, 0.021682161641365383, 0.03331939900817815, 0.0194286190890125, 0.028970469284104183, 0.03555870345735457, 0.1090432089404203, 0.013318685178091982, 0.0324566189374309, 0.02450896874506725, 0.021274410864862148, 0.05821637554618064, 0.053087864216649905, 0.025487204729870427, 0.018105662929883692, 0.02487204965291312, 0.029969776696816552, 0.04452255234355107, 0.03890857253281865, 0.026998421490134206, 0.036461051131482236, 0.017132631255663, 0.030030347079446074, 0.011765418330469402, 0.05125878560647834, 0.03589186097087804, 0.022091261271270923, 0.03701363202708308, 0.08532415435183793, 0.05971285325358622, 0.07414174033328891, 0.01915618595376145, 0.022317024449876044, 0.055941908140084706, 0.048008204757934436, 0.03367398974660318, 0.09036173403728753, 0.06069695591577329, 0.020765514636877924, 0.04828642850043252, 0.04189305633190088, 0.038249430363066494, 0.06631833864958026, 0.04411502421135083, 0.05103668678202666, 0.05784854118246585, 0.0630902782722842, 0.018761942264973186, 0.041326883001602255, 0.06617030245251954, 0.02399979977781186, 0.10380054416600615, 0.055048989452188835, 0.04021389155241195, 0.03467159949650522, 0.0565966382418992, 0.03430819204368163, 0.02177362206566613, 0.042275306914234534, 0.027001566340913996, 0.0799669093976263, 0.022010838438291103, 0.034443967961124144, 0.004029036244901363, 0.03585692807973828, 0.03283244623162318, 0.019374772564333398, 0.016676915474818088, 0.05086199635115918, 0.015130337233131286, 0.07022549383691512, 0.01603025808435632, 0.010552517105679726, 0.02553436079324456, 0.02056802542938385, 0.029160318081267178, 0.031513382637058385, 0.012668107392528327, 0.028037046031386126, 0.02811159662087448, 0.05835565068991855, 0.01595899520907551, 0.012323061600909568, 0.051464356802171096, 0.02060996604996035, 0.007983130417414941, 0.022885600483277813, 0.05100352020235732, 0.04456866197870113, 0.0335103202087339, 0.04845881456276402, 0.06919236489920877, 0.03220728329324629, 0.019313764314574655, 0.04585977258102503, 0.011463381852081511, 0.05966681412246544, 0.006819323189120041, 0.0390023799991468, 0.06794485918362625, 0.03326812031446025, 0.020205306318530347, 0.020619242895918433, 0.03450869437074289, 0.009683907464932417, 0.025625119887990877, 0.03433394827879965, 0.05358249451091979, 0.056982113455887884, 0.04496183326409664, 0.021008178373449482, 0.01124136559155886, 0.042409713569213636, 0.060335789748933166, 0.05144694230693858, 0.08742166406591423, 0.022770222494727932, 0.09163469541817904, 0.006456259443439194, 0.08118408353766426, 0.06061110056180041, 0.02373167109908536, 0.03757255457458086, 0.019205431162845343, 0.019124846912745852, 0.025976124197768513, 0.02088198729325086, 0.04250718353432603, 0.06699122168356553, 0.02441709271806758, 0.04513551808486227, 0.057698282253113575, 0.07282058388227597, 0.031437561119673774, 0.010317974320059875, 0.048543111406615935, 0.012385184927552473, 0.06554113191668876, 0.03920962102711201, 0.09589411842171103, 0.04785693650774192, 0.07157307816669345, 0.02748849870840786, 0.05259778328763787, 0.020317585840530228, 0.013751481583312852, 0.026638561503204983, 0.0331360922427848, 0.02970330671814736, 0.06061231768399011, 0.014788401967962272, 0.045644256606465206, 0.018742074971669354, 0.05473816316225566, 0.08295018720673397, 0.018754138582153246, 0.07591136178234592, 0.042821241877391, 0.011789997333835345, 0.027029357916035224, 0.011092360891780118, 0.02397529962763656, 0.06324471920379438, 0.06342350257909857, 0.053525720213656314, 0.010303993185516447, 0.024303521859110333, 0.06608998723095283, 0.10098522921907715, 0.033965026668738574, 0.051817463245242834, 0.006278263672356843, 0.03106452801148407, 0.03432428551604971, 0.005167287617950933, 0.07152486825361848, 0.05070227874966804, 0.03245110478019342, 0.044358971863402985, 0.02789841284538852, 0.004024251711598481, 0.02378075303568039, 0.050277670088689774, 0.0429496519791428, 0.03635896871855948, 0.014462961862591328, 0.03196787387423683, 0.01638614572584629, 0.03676062646263745, 0.01770414619386429, 0.04417264455696568, 0.03185116744134575, 0.023825146454328205, 0.025938937033060938, 0.028260497419978492, 0.05608372885035351, 0.04049670176755171, 0.020642256895371247, 0.06721978832501918, 0.0363093895430211, 0.011488998934510164, 0.016935468593146652, 0.052958830710849725, 0.03372455968928989, 0.0336112856894033, 0.011711901133821812, 0.018282808014191687, 0.05248546294751577, 0.027461133868200704, 0.019763272030104417, 0.029516476606659126, 0.010238163758913288, 0.017031710303854197, 0.03955486441554967, 0.01885432480776217, 0.022958282715990208, 0.009306293450208614, 0.01925438322359696, 0.05781829124316573, 0.07060954041662626, 0.047987821671995334, 0.04473156339372508, 0.022692395323247183, 0.011506564642331796, 0.05871628993190825, 0.058470898802625015, 0.002476761092111701, 0.06428188542486168, 0.10096407801029272, 0.05732050311053172, 0.07911099790362641, 0.04481364863750059, 0.014495919713226613, 0.024186038026527967, 0.04137422831263393, 0.09549775961204432, 0.04218768524879124, 0.055243595415959135, 0.022186009409779217, 0.04112884089408908, 0.006900328144183732, 0.009274403364543105, 0.027543701507966034, 0.05439283442683518, 0.04806331664440222, 0.04825789663300384, 0.11060601609642617, 0.015539578798779985, 0.04594581347191706, 0.011248619157413486, 0.04772227752255276, 0.022920811679796316, 0.010889497607422527, 0.04981970560038462, 0.06917035279911943, 0.053074012030265294, 0.028001239261357114, 0.05023871846788097, 0.04345689507317729, 0.015321345636039041, 0.047317053758888505, 0.11720402064383961, 0.07684143609367311, 0.16331177816027775, 0.13780588429654017, 0.09921186734572984, 0.18178009340772405, 0.11412838997785002, 0.18852468696422875, 0.12438755002222024, 0.20963562681572512, 0.07618565214215778, 0.23011041252175346, 0.07837715485948138, 0.1711996056837961, 0.21069841197459027, 0.15426646743435413, 0.10230937652522698, 0.23514901637099683, 0.13796200248179957, 0.12257288763066754, 0.10498106363229454, 0.128924157761503, 0.16896611225092784, 0.10594478691928089, 0.08147014435962774, 0.11206816576304846, 0.20936198212439194, 0.140100248681847, 0.17173974076285958, 0.10432609604322352, 0.15563069813651964, 0.11490080985822715, 0.25471060420386493, 0.09447980017284863, 0.17258786712773144, 0.13327596330782399, 0.1432753642438911, 0.11468979500932619, 0.11687362391967326, 0.1996506383875385, 0.13784509937977418, 0.1587121101329103, 0.11487753610708751, 0.19352924107806757, 0.11098886781837791, 0.13741167029365897, 0.1545745923067443, 0.19917275465559214, 0.1145705467206426, 0.1208783418405801, 0.14975723752286285, 0.09459078093641438, 0.1307020170497708, 0.12844173208577558, 0.2611176541540772, 0.1340343788615428, 0.13958234834717587, 0.13488621596479788, 0.1845102765946649, 0.1585344399791211, 0.14016441476996988, 0.25510121136903763, 0.18888540042098612, 0.1426939805969596, 0.11164939409354702, 0.21152271539904177, 0.10725674816058017, 0.13302804145496339, 0.21748415019828826, 0.13419367343885824, 0.14911820384440944, 0.16156559373484924, 0.14359356748173013, 0.07896881725173444, 0.11528714225278236, 0.12878436682512984, 0.15793969767400995, 0.175936481973622, 0.1362034835619852, 0.25196914037223905, 0.09306024978286587, 0.0913235054758843, 0.1437401564908214, 0.20984762872103602, 0.17874859826406464, 0.17816862469771877, 0.08214155794121325, 0.11584675870835781, 0.0831720077258069, 0.10908722571912222, 0.16467127396026626, 0.13692842825548723, 0.10329715281841345, 0.1860432865214534, 0.09833306059590541, 0.1295862573897466, 0.09329899126896635, 0.18187302513979375, 0.13656718045240268, 0.16622767638182268, 0.15732758911326528, 0.09904302132781595, 0.16097272164188325, 0.11529196621268056, 0.12245930192875676, 0.1738652665517293, 0.14307851699413732, 0.1212517979729455, 0.09629695618059486, 0.1340886001707986, 0.1209096382081043, 0.1112543414637912, 0.15331874485127628, 0.16630891186650842, 0.10151092210435309, 0.1286442345008254, 0.14028352947207168, 0.16346951422747225, 0.09104163036681712, 0.20423366746399552, 0.10632575358613394, 0.16866965394001454, 0.13099737698212266, 0.09827093541389331, 0.10282506525982171, 0.1671311818063259, 0.10996360564604402, 0.1391446148045361, 0.12414280456141569, 0.0625791611673776, 0.08242531068390235, 0.16508036060258746, 0.11376403257600032, 0.09436149441171438, 0.11703129319357686, 0.21878333907807246, 0.1703702111262828, 0.14840415387880057, 0.09474349266383797, 0.16950088902376592, 0.10218000534223393, 0.2512875816319138, 0.3138933191075921, 0.20837434683926404, 0.1254450436681509, 0.2820860274368897, 0.11622336154687218, 0.12265165918506682, 0.15697400027420372, 0.21662765240762383, 0.1604677940485999, 0.20017422357341275, 0.10596947075100616, 0.1609749035560526, 0.09542627594782971, 0.10102373184054159, 0.12345020266366191, 0.09277675679186359, 0.19434633082710207, 0.1150426417007111, 0.1128485934168566, 0.21294753503752872, 0.1489000569563359, 0.09709218968055211, 0.06544850446516648, 0.14638741209637374, 0.25811252009589225, 0.13853620213922113, 0.08458090829662979, 0.1539803101331927, 0.11207978037418798, 0.18203585234005004, 0.13260838662972674, 0.2666728670010343, 0.1681070021004416, 0.08557432491215877], [0.003070637867494952, 0.017467430770921055, 0.018337307628826238, 0.035981419641757384, 0.1107226000749506, 0.05299311422277242, 0.038510172817041166, 0.017225271694769617, 0.004724756554423948, 0.08893284000805579, 0.033244074729736894, 0.01353020932583604, 0.014367574549396522, 0.03727889416040853, 0.04760829848237336, 0.10589962723315693, 0.02550581964896992, 0.025086858731810935, 0.07571792841190472, 0.029308244811545592, 0.0578920866973931, 0.05134797320351936, 0.023671030212426558, 0.11869455003761686, 0.015049482099129818, 0.0689940110896714, 0.07798118196660653, 0.0318679325573612, 0.038767352962167934, 0.1144589128671214, 0.0471505789028015, 0.028416706518328283, 0.04900460109638516, 0.03808302972174715, 0.06233395557501353, 0.01611512081581168, 0.0457834018743597, 0.04720236967841629, 0.06365806577377953, 0.04243909519573208, 0.02412876649032114, 0.03577672046958469, 0.06355733406962827, 0.029035572333668824, 0.04984871615306474, 0.049171432183356956, 0.013071975808998104, 0.08597950785770081, 0.016517409385414794, 0.0407029520283686, 0.06313304824288934, 0.02038360729784472, 0.011231582229811465, 0.027984488988295197, 0.020874153924523853, 0.1190477232739795, 0.026888490865530912, 0.0598596574855037, 0.06648798618698493, 0.05303352416376583, 0.027728557506634388, 0.06700891448417678, 0.09713695602840744, 0.041670593855087645, 0.0193436988411122, 0.05620115887722932, 0.021030949319538195, 0.02145034995919559, 0.055329777314909734, 0.038161422780831344, 0.011149034999107243, 0.07321958473767154, 0.050111169257434085, 0.031072901292645838, 0.025498446411802433, 0.037887199214310385, 0.05162183311767876, 0.06770743129891343, 0.02096765525493538, 0.07873053589719348, 0.011548264992597979, 0.05797286947199609, 0.03651420003734529, 0.02396095391304698, 0.02588703493529465, 0.023692700924584642, 0.05058176138845738, 0.06782466094591655, 0.11753485523513518, 0.05048931576311588, 0.06080892744648736, 0.047277990815928206, 0.022826549648016226, 0.024465391688863747, 0.04872019155300222, 0.06862775378976949, 0.024282584017782938, 0.08219639523304068, 0.05542877610423602, 0.04519023663306143, 0.05078311718534678, 0.0005977710793558799, 0.03389613309991546, 0.006084530195948901, 0.0556991442135768, 0.04482815020310227, 0.004856063351326156, 0.03672596074466128, 0.025227473452105187, 0.09482247201958671, 0.011990627681370825, 0.042467571402085014, 0.04197656278847717, 0.029903820177423768, 0.024430848425254226, 0.08312208345159888, 0.04798791072971653, 0.04048567345307674, 0.02022775443037972, 0.08430636560660787, 0.025721150086610578, 0.027137676224811003, 0.018337960718781687, 0.1302045554621145, 0.05073232459835708, 0.015272234013536945, 0.035501023739925586, 0.017667443280515727, 0.028190306948090438, 0.014671301269117976, 0.05679599766153842, 0.02282174609717913, 0.043089580212836154, 0.006284412829700159, 0.030513913807226345, 0.004642550711650983, 0.05231980074313469, 0.012307616580073955, 0.0026576853315418703, 0.027395090146455914, 0.042271555357729085, 0.07256261334987357, 0.1009205065201968, 0.03113040846074, 0.01065428317815531, 0.027301830014039297, 0.03652532112027984, 0.04265836643753573, 0.04149359534494579, 0.03183567510859575, 0.019376683594600763, 0.03827359098067973, 0.017882196698337793, 0.13593585026683286, 0.06789050428778864, 0.045056902381475084, 0.06082584099203814, 0.060407132405089214, 0.022516795761475805, 0.04926044166495558, 0.05217228776018601, 0.03781727034947835, 0.03293983871117234, 0.007517081621699617, 0.03334332213853486, 0.029862987212254666, 0.02403885158855701, 0.04774289067427162, 0.05374247928557452, 0.011164582065248396, 0.08701026934431866, 0.019517788132361602, 0.00811512323707575, 0.01363485122055863, 0.04008210096799303, 0.019188033365935553, 0.012987551872356562, 0.02513992971216794, 0.012114934634155361, 0.048810792941367254, 0.07047464765491895, 0.044558947265613824, 0.043545893422560766, 0.03739495492482092, 0.02256419487821404, 0.04831212165299803, 0.021723716345150024, 0.042546754848444834, 0.02574270391050959, 0.027131013594043907, 0.033408211820642464, 0.04598359621013515, 0.026155319465033244, 0.02369081586948596, 0.01952707982127322, 0.02344334116060054, 0.026053437431983184, 0.012255289602762787, 0.08908120275009423, 0.04382889288535807, 0.007111535023796023, 0.11733269420801662, 0.03784738670219667, 0.03323925819131546, 0.0324159418232739, 0.015014068667369429, 0.032132638079929166, 0.017813952508731745, 0.03396045874978881, 0.026344862126279622, 0.038982111946097575, 0.03746344773389865, 0.02034227338299388, 0.043890279630431905, 0.049532320044818334, 0.03361443610629067, 0.021414584007288795, 0.05152870471647475, 0.037995827369741164, 0.060025520069757476, 0.03371143109689001, 0.0240661867428571, 0.027532023814273998, 0.04446468337846454, 0.021972521353745833, 0.06714008166454732, 0.039994078542804345, 0.007843341336410958, 0.04229818732710555, 0.016712798314983957, 0.06789384395233355, 0.05246665321465116, 0.07132079990697093, 0.08440326782874763, 0.01066295888449531, 0.020329070575826336, 0.016918818510021083, 0.10144970976398326, 0.06270289202802815, 0.0533725260902429, 0.03277331190474797, 0.013416763704299228, 0.03280450066085905, 0.008159378430718789, 0.025008595548570156, 0.019178290822310373, 0.0333201634202851, 0.05142061461810954, 0.11833617434604093, 0.04599934087309521, 0.040616306287120096, 0.03484318032860756, 0.06307999210548587, 0.021146486869838554, 0.03947378478187602, 0.05113683961099014, 0.047462188158533536, 0.03474030010693241, 0.04276034866052214, 0.057683580307639204, 0.04289170879928861, 0.009024166938615963, 0.03671187849249691, 0.053777029970660806, 0.048992982774507254, 0.021845037081220653, 0.08826522622257471, 0.04559889654046856, 0.053208507742965594, 0.01705871705780737, 0.015829573931114282, 0.03090995905949967, 0.022022905759513378, 0.05943494863458909, 0.01667147924308665, 0.010445938205521088, 0.015523437086812919, 0.02033153079537442, 0.07591213361592963, 0.017423363897250965, 0.02698268239328172, 0.014655395189038245, 0.032370507542509586, 0.1450683336588554, 0.014666797360405326, 0.012713803280348657, 0.07336966184084304, 0.022032119522918947, 0.042252355997334234, 0.01613093412743183, 0.021791736035083886, 0.05967610210063867, 0.012846304471167969, 0.041829806796158664, 0.03774445824092254, 0.03118648884992581, 0.0414924413053086, 0.08056461287196726, 0.045537840051110834, 0.033104313479270786, 0.0662920592003502, 0.020206120825605467, 0.030792143115832005, 0.03829471250355709, 0.0309165252110688, 0.08222732052672654, 0.02806390435580397, 0.0514034264779184, 0.053942083613947034, 0.04857168780290522, 0.018376381704001687, 0.04416490024595987, 0.057551656136638485, 0.02807165979902493, 0.013116947175149107, 0.047555105047649704, 0.04810248348803725, 0.04253308077750262, 0.061959549493622035, 0.042262319329893216, 0.011796266626333818, 0.03981860885687638, 0.03668077137263026, 0.036897244717692956, 0.013585091146524064, 0.0081024306564359, 0.022090381826274097, 0.05651722472975962, 0.07119160683942027, 0.03393425351532642, 0.025276108244725037, 0.04690277579356916, 0.04614898753061425, 0.01044734086462995, 0.04232775820128154, 0.05655972381646279, 0.0361513900134014, 0.03970719022618141, 0.00646884905108891, 0.040941953266155906, 0.033790770394261926, 0.036613150587072596, 0.031481459154747427, 0.029414987911877688, 0.040392229639110155, 0.03525150998029858, 0.03671712918730918, 0.010902992635237752, 0.08240315015427768, 0.049825594542198814, 0.04101339240150992, 0.015384451380668906, 0.14427646208787337, 0.14025516458787024, 0.10549621059908532, 0.12513764610048383, 0.1361618936061859, 0.11447562603279948, 0.10488279585842974, 0.07671366794966161, 0.11167848628247157, 0.20861484721535817, 0.08972795476438478, 0.12679262057645246, 0.09755402817972936, 0.12043689755955711, 0.13145890377927572, 0.2107204686035402, 0.08161763136740774, 0.17268214956857264, 0.23259556823177263, 0.1324088973342441, 0.13490923738572747, 0.11451113779912703, 0.23401816142722964, 0.1501553997513838, 0.07457876141415909, 0.28389766928739846, 0.14009453414473683, 0.08662714302772656, 0.12442416758858599, 0.15694229572545737, 0.1271890610223636, 0.17216809355886653, 0.15189123863819987, 0.11237968967179768, 0.26731298421509564, 0.14218265569070354, 0.106492306367727, 0.20236499898601323, 0.120302093855571, 0.14093124627834186, 0.21230105019640177, 0.1467355090426281, 0.10175889590755105, 0.12739856931148097, 0.146122524747625, 0.07959435868542641, 0.09980419767089188, 0.16276282636681572, 0.12489303422626108, 0.09666200377978384, 0.21352612820919603, 0.06817804198362865, 0.0966040272032842, 0.08796565831289627, 0.1550830079941079, 0.24715263163670897, 0.18269713560584933, 0.16198784607695416, 0.17066754517145455, 0.1085198538203258, 0.11559192003915086, 0.23083164647687227, 0.1565605794894509, 0.08135537864291109, 0.08758066920563579, 0.1505628536688164, 0.13405851350398734, 0.07044217869406566, 0.1474055793369189, 0.09051591521711089, 0.1507999253226444, 0.10751789508503862, 0.23854098748415709, 0.06922259257407859, 0.08429259876720607, 0.12420555314747617, 0.09672465588664636, 0.10501141005079262, 0.2176115769543685, 0.2146379099576734, 0.11778581247199327, 0.14908161596395075, 0.10463083672220819, 0.11414416803745553, 0.09380564064485952, 0.1442766105174087, 0.13187455100705847, 0.12077041872544214, 0.1968973150360398, 0.13660173484822735, 0.16891000588657334, 0.18695733044296503, 0.13491210207575932, 0.08111317874863744, 0.122669767588377, 0.1980240733246319, 0.13202024943893775, 0.18058860499877483, 0.10791783104650676, 0.07256953016621992, 0.15650806511985138, 0.10411094743176363, 0.18626649485668167, 0.14363178808707744, 0.18741652689641342, 0.10571400125627406, 0.17026061075739563, 0.3108103189151734, 0.1313555968226865, 0.20654421066865325, 0.24002823658520356, 0.14144024084089324, 0.10321842579287477, 0.10866489174077287, 0.08384316897718236, 0.1438473374582827, 0.23109165049390867, 0.10136576544027776, 0.10542068223003298, 0.14692472701426595, 0.12467782624298707, 0.14776253752643242, 0.10926059141638689, 0.18584488076157868, 0.16825940954731777, 0.15142830176046118, 0.10022938149631955, 0.17529973411001265, 0.10322261892724782, 0.17503521783510223, 0.15153880754951388, 0.09856530828983523, 0.13181973597966135, 0.08952605348895304, 0.12875782762421295, 0.16232359368586913, 0.2270476581179537, 0.07779793828376569, 0.10073317360365763, 0.15774424566188827, 0.18312709144083783, 0.12101679691113532, 0.23703941493295133, 0.14018613001098856, 0.19076212862273678, 0.12252841814188287, 0.1107588762533851, 0.20585295947967097, 0.10554394553764723, 0.12658912368351594, 0.10314582148566842, 0.12235681133461185, 0.08697532161022536, 0.15487161464989185, 0.13576376106357202, 0.17877078847959638, 0.13452158396830782, 0.12518971518147737, 0.15118995361262932, 0.12239220435731113, 0.1591970887966454, 0.14770356647204608, 0.0921716021548491, 0.16446422960143536, 0.06017801657435484, 0.09923899284331128, 0.10781188946566544, 0.1591363365878351, 0.14611195656470954, 0.10773865433293395, 0.12830210442189127, 0.10704242333304137, 0.1251887355465442, 0.1499959419015795, 0.12717173929559067, 0.07650312807527371], [0.05718084947147872, 0.051042794657405466, 0.021864169648324605, 0.0326551211765036, 0.05030480671848636, 0.03768525341001805, 0.0244794999161968, 0.0661258700711187, 0.016607365105301142, 0.04470196654438041, 0.0494020805490436, 0.09601469515473582, 0.014380564916791627, 0.12585369986481965, 0.008112490468192846, 0.007322903784370283, 0.1013219787273556, 0.017587042711966205, 0.04411079025885556, 0.04274089696991723, 0.03165958944009617, 0.029373416509770323, 0.043366939353290945, 0.016710464260540903, 0.037683550181100145, 0.08631193806650117, 0.04033429016999435, 0.035206955144531094, 0.036360234080348164, 0.05100982845760882, 0.049746262666303664, 0.07513043688959442, 0.033278673654422164, 0.020265299681341276, 0.00783739395046723, 0.05415593346697278, 0.06273645194596611, 0.01986420411412837, 0.06278065426158719, 0.03456577665929217, 0.014713026666868245, 0.04102357095689513, 0.016999302570184227, 0.0335903051745845, 0.04650221271731425, 0.015274245233740658, 0.07871383757446893, 0.04923202111967839, 0.033314845932181925, 0.03733992467459757, 0.03915223074727692, 0.012745659969368717, 0.024126530770445243, 0.029472940368577838, 0.023774615474394523, 0.050588147569214925, 0.016724559500289615, 0.04066918059834279, 0.015947755382512696, 0.075784528744407, 0.032243195819319226, 0.0732594974397216, 0.05395954634877853, 0.023837698026909493, 0.0095554797371733, 0.04644440683478024, 0.018769367452478036, 0.03138543637760449, 0.011425852371758083, 0.06684780906653032, 0.04232332015817519, 0.03704588576511014, 0.029321798283490352, 0.025734172922966536, 0.019834147133224178, 0.09653282555518672, 0.042480469928705133, 0.03914666463970207, 0.10541430718149059, 0.027031255958718248, 0.046563888899981976, 0.02145977152395062, 0.05518059078895021, 0.004335212515798048, 0.05010555119952187, 0.048522650395170785, 0.010524826648179442, 0.04582183770253323, 0.06188062208821066, 0.06084058746637311, 0.03139452397590503, 0.003939404286938952, 0.017338935322186444, 0.025352946504426654, 0.04676677352108527, 0.010402683983556926, 0.06572942220373079, 0.02053355081443442, 0.020962269118172117, 0.018430385935062077, 0.01614732445887057, 0.05812191498989705, 0.016993294884741772, 0.09540572587866336, 0.05467564093123656, 0.03151870012516156, 0.05695825340808369, 0.04706231899035629, 0.036701054268633015, 0.03366045668371953, 0.03778920232434757, 0.03576021139451768, 0.04746913837152533, 0.046025479314266704, 0.035273273460916243, 0.09017575182951987, 0.040205520126619376, 0.02701138309930684, 0.010560953469394008, 0.01164605686426512, 0.08958958875155076, 0.02237097858596826, 0.028922923593199812, 0.06453466092352755, 0.039603983459528536, 0.09876210358925164, 0.02660291429492645, 0.06529617123305798, 0.023303516827581916, 0.016304348064295482, 0.034460595779819414, 0.009067352511920035, 0.05900771648157388, 0.01963507900654804, 0.020926577381032985, 0.09439226385438815, 0.05242626924882643, 0.06049938878277317, 0.02857803086953936, 0.03719939159054775, 0.01110795434215106, 0.03478271384665277, 0.038237474363995716, 0.06225479068234563, 0.05572217305598315, 0.05185185436857864, 0.021308638715709094, 0.022070252925914247, 0.08105587010504678, 0.009770543929334963, 0.04803930074558593, 0.036659590477938764, 0.035114943675580435, 0.07502752327127382, 0.03566557643353008, 0.03165194902976509, 0.02795550441078376, 0.015608061403327156, 0.03803356928983703, 0.023226934608828742, 0.003282978145762172, 0.031331823629443534, 0.018856530841731, 0.029803888137394097, 0.014188092627591686, 0.04935109129291959, 0.0690648119780235, 0.0360216737317387, 0.020548243483062834, 0.03792045856243931, 0.05566356936469674, 0.01959148154128343, 0.035495628326316364, 0.028509009280242026, 0.09328751024440862, 0.05727766634663567, 0.026684281510824803, 0.02429619686154183, 0.02805714524583891, 0.055984733771765605, 0.033460770719102584, 0.017455051747674588, 0.020709343334601726, 0.0065320689009240596, 0.06755108304787427, 0.038196997629711404, 0.005455905138660455, 0.018054441752610728, 0.029473719623638317, 0.05519670281501021, 0.07895460512372665, 0.026971154984494206, 0.004228973612043774, 0.07008659347775392, 0.08210675863665529, 0.046598049957538024, 0.04115554707823321, 0.06056178855942562, 0.09335085254861042, 0.07040910859359428, 0.04878953412116971, 0.05963071605947334, 0.05932400126766879, 0.027913795711356215, 0.014098096089583123, 0.07223891079775058, 0.012776153889717534, 0.01539363081974443, 0.011290439178992528, 0.03946227778214961, 0.03436235027038492, 0.054088973192847334, 0.0716590485535562, 0.027723306811822113, 0.033177103323396295, 0.03137070103548467, 0.0559416001487989, 0.03247459375415929, 0.03470775693131145, 0.03508502399199642, 0.03916032386769075, 0.021606768714264035, 0.010766010727820685, 0.04932687872496899, 0.04096898228453938, 0.018091294950863812, 0.023848249511502218, 0.02660041140188696, 0.02978491142130224, 0.06096819975937251, 0.04754081499413587, 0.07423805625876412, 0.07731766483630054, 0.07387530189589597, 0.02908039063186152, 0.013571601684816414, 0.03172691707732156, 0.10036281222710386, 0.026905671584245283, 0.023534003776148893, 0.0613696534128394, 0.11000892118318006, 0.034172683299402706, 0.03348315389303025, 0.03896907983289566, 0.02129676991899032, 0.02561821605922887, 0.02522684633731842, 0.005987053737044334, 0.010074339297716506, 0.035857688781106845, 0.015506619092775509, 0.006090307815611595, 0.039901469644973986, 0.024568670814915095, 0.01341270879493095, 0.04131925372348633, 0.018487442248442676, 0.03371185783180408, 0.021911464864388108, 0.033051569043891504, 0.013435535402095411, 0.06989573535975069, 0.04252700258803088, 0.03229186586395372, 0.021997887961333618, 0.0754497162415646, 0.044064584144507535, 0.04852746693359222, 0.024035027672653086, 0.07536704841186292, 0.026649279971024953, 0.016064613955677487, 0.040152545625460334, 0.010837007357622497, 0.05184229550650343, 0.032313128394889645, 0.03858124830003362, 0.022762264816265088, 0.016985700858640485, 0.05539221048820764, 0.012798637253581546, 0.003299719605820428, 0.05274152987112757, 0.04871340832323767, 0.059604254784062505, 0.07871337002143264, 0.07693758132518269, 0.027087807611678727, 0.020601091819116846, 0.03870794032991398, 0.03055571341974428, 0.026929232917609625, 0.0121371907152934, 0.03465294932539109, 0.03665590571472421, 0.07359359748079441, 0.06422609076253138, 0.031203320759232156, 0.0030816603839411982, 0.04483173106564209, 0.014444991684285924, 0.01450859745091293, 0.035247465275460854, 0.007402954151984886, 0.026011036679847166, 0.017431110063625965, 0.024015503622649703, 0.017262046967516653, 0.009910708722600248, 0.0007257939887495013, 0.02415038710751105, 0.025889016469591297, 0.05728476869990118, 0.010140553713426925, 0.03273331756645348, 0.020984622606192715, 0.021083981337142177, 0.06255109314224683, 0.059868874959647655, 0.0037695990431529935, 0.03375482076080516, 0.030096554073679727, 0.05868103420652915, 0.07991187172592618, 0.03859366443066392, 0.04177279872237705, 0.01682959009485785, 0.06961637613130733, 0.045485258888220415, 0.022607245009567123, 0.008509904982929584, 0.048174200928770006, 0.03152108984068036, 0.031128374976105988, 0.04779838476679288, 0.03674100407806691, 0.01721848289889749, 0.019593370307120495, 0.03263798127591144, 0.06842908827820793, 0.06307962103164755, 0.05131511090439744, 0.021244927193038166, 0.02043987322394969, 0.006421455036615953, 0.038053113748901524, 0.006893058807690977, 0.038095531199360266, 0.03577228242647834, 0.01313422715611523, 0.027916871913475916, 0.14089396077906713, 0.11735415711882524, 0.1947830550489016, 0.12207641309942119, 0.15808466880116612, 0.16795419389382005, 0.1161684277758468, 0.1623444480355829, 0.12425322871422395, 0.15334779251134023, 0.10841316267033108, 0.14130319585092366, 0.08524786899215542, 0.17682458041235805, 0.14401627995539457, 0.154266185418237, 0.16253420035354793, 0.14504541613860056, 0.13234146579634398, 0.13143159274477512, 0.06582067668205127, 0.16270602238364518, 0.18332548235775903, 0.13518843334168196, 0.15881593659287319, 0.1579615316586569, 0.2366711018839851, 0.09980066504795104, 0.20520013669738546, 0.13782863854430616, 0.16081629175459966, 0.15625214291503653, 0.13545140594942495, 0.08697266472154297, 0.20405148505233228, 0.12256019690539688, 0.18745308509096503, 0.0947127900144551, 0.18110953329596668, 0.09485113376285881, 0.13269235321786255, 0.09716816333821043, 0.11653438821667805, 0.11393544642487541, 0.15550589858321473, 0.09514778503216803, 0.16199926030822098, 0.09423812720342539, 0.10880393310799263, 0.1215938464156352, 0.08683063992066309, 0.10898069042013958, 0.16514970688149333, 0.11195675455383025, 0.16726837522583082, 0.1325371107668616, 0.1437378558330238, 0.19251117773819715, 0.0922073662513867, 0.13814001402352005, 0.15792869904544204, 0.18274159025168046, 0.15574031334836036, 0.12683622917393222, 0.12829949206206948, 0.15813906822586432, 0.14903141709510237, 0.13458285568049178, 0.23794544365955517, 0.13799873879179358, 0.14511646935716271, 0.07365600467892364, 0.14214643888408318, 0.12196661235066131, 0.10425015207147226, 0.2679853403242305, 0.16508669854374602, 0.11833656026283279, 0.254473116947338, 0.09287510620197281, 0.13847798807546496, 0.12048327436787076, 0.18083581438986585, 0.11894989336724393, 0.13550153060350567, 0.1959936908679083, 0.17080969613743946, 0.09190767959808, 0.2583140874048695, 0.14052486105356365, 0.12417096164426766, 0.11857823323225603, 0.10061275272164494, 0.06981072976486757, 0.12421698222169653, 0.10581325608654879, 0.0990213654586114, 0.14400621643289924, 0.15075302158948034, 0.18947659526020288, 0.1714643742889166, 0.16736290999688208, 0.09139692614553496, 0.16967472969554365, 0.13064151717117056, 0.09632555113057606, 0.14153453812468797, 0.14693544362671673, 0.21532381768338382, 0.2001735704834573, 0.1279722197796218, 0.12165421270765364, 0.11451026948634535, 0.13444024458294734, 0.11981281815678813, 0.25036586390342563, 0.12902611400932074, 0.1689088184502907, 0.12879437097581103, 0.09776682418305427, 0.15250984841259196, 0.11756460793549195, 0.11614862727583386, 0.10033585742348805, 0.19536049047019333, 0.20746898604556918, 0.12725767999654636, 0.19604595290729776, 0.1477390856598504, 0.1698699442204088, 0.10664421657565981, 0.09549252747092396, 0.16158883780008182, 0.10164352162973955, 0.09390582315973006, 0.15473139326786622, 0.1066581392660737, 0.13119428360369056, 0.14329228521091864, 0.14477246906608343, 0.07949393868329935, 0.14059760636882856, 0.18926028889836743, 0.20074670144822448, 0.2123148096143268, 0.133666718902532, 0.11232153497985564, 0.1661603042157367, 0.21984615392284468, 0.08924127658247016, 0.21162713557714596, 0.10521213131141849, 0.10855521715711802, 0.20303906203480437, 0.13371366716455668, 0.14310337894130498, 0.08641338223242201, 0.10041072528110817, 0.08714332157978788, 0.13828130409820005, 0.10563971227384172, 0.1450772988027893, 0.12025861142319627, 0.09622151686926372, 0.15684642508858815, 0.17851924494607374, 0.14126009191386402, 0.16162639047252014, 0.1122909584955778, 0.10968324451823719, 0.19065517029957846, 0.12486984953284264, 0.13648799329530448, 0.21342451334930956, 0.23747756407829002, 0.10486601589946076], [0.01549751386846765, 0.06954526354093105, 0.020112051752221305, 0.003561246185199707, 0.02268108684802428, 0.015423879831359955, 0.06070252202334814, 0.0416623263299698, 0.04917118727462366, 0.05085328724817373, 0.02028248225542484, 0.01990129479963798, 0.02757462309091352, 0.025335893806186505, 0.03476582256553229, 0.03610504289099481, 0.05560202305787243, 0.04599000094458461, 0.019852402110700496, 0.0049927126838156255, 0.03563607606338337, 0.05864646125701256, 0.06068930437322706, 0.01639395868551219, 0.04882413304585498, 0.06003417722240556, 0.043634724788716994, 0.04193675769784022, 0.06158692827739287, 0.01819286342652049, 0.02169136056181742, 0.029147521599952597, 0.0947535784507636, 0.0896255680709146, 0.030170707614161074, 0.03123262446024455, 0.031855223278398626, 0.029324896750040352, 0.0029314285893633496, 0.02903139218688011, 0.15701116702985018, 0.050859881230280735, 0.00807291080491268, 0.042790349980350584, 0.02720536936976714, 0.009794195248105098, 0.08685526438057423, 0.01072474453394534, 0.03359647613251582, 0.06786049183574505, 0.07315001581446268, 0.016681500092090573, 0.042177729337709025, 0.02583603454695549, 0.06980041391216218, 0.03966548894823063, 0.04231196900946088, 0.07988421188201755, 0.029070768687233794, 0.09129418322117999, 0.04839119748794474, 0.019293004588689655, 0.019510251622705255, 0.035233891394454986, 0.12609863828402013, 0.1186351856449619, 0.0433953227911843, 0.039004201971692964, 0.019634795135061722, 0.03704663162352517, 0.07723300805082545, 0.005288398233460612, 0.013221450844866922, 0.05314936599461362, 0.0377038776059635, 0.061274228064576164, 0.05956807879556436, 0.04452365443285089, 0.05871037130418699, 0.04715863862656988, 0.07915828013210557, 0.03313290100777522, 0.01399289943947224, 0.037144476373214275, 0.06259350688196719, 0.007160877175920177, 0.022242180712055415, 0.061656634497921914, 0.018132083387172315, 0.003170580112055177, 0.05018917268898804, 0.01442090620912495, 0.020372823892103042, 0.02498402860510396, 0.043807756519527175, 0.02184487380873179, 0.04675350763136521, 0.050272976004634984, 0.030358302137756255, 0.033445244989707135, 0.016430099421995692, 0.07152195903472602, 0.07383901829598472, 0.038639447520836256, 0.02518244735256303, 0.03104133218585048, 0.04298825850128196, 0.015320951370085822, 0.015614373369317036, 0.07482939210603945, 0.01525709698398714, 0.04800571856321767, 0.0256747788444045, 0.019047856512770522, 0.09099684175453149, 0.05626449375995435, 0.05800043654744513, 0.025992893024522346, 0.008293528117064852, 0.0845506286714226, 0.08237797650508583, 0.04485687873966526, 0.021377938610385172, 0.037251327084959485, 0.06563208953593858, 0.015175342923612334, 0.02047830719675403, 0.01049163131028763, 0.03810425514529925, 0.021714446920668706, 0.01955755054950714, 0.04939274804200977, 0.06988395005464554, 0.026844390595215373, 0.024568949120293837, 0.09721071808598936, 0.09705546079203486, 0.015366805891972035, 0.06744678903487511, 0.0637034184182994, 0.017852740857051685, 0.04732059380330611, 0.029382762004388496, 0.04092158502317034, 0.07189748575910926, 0.052677757121273316, 0.029394497214525472, 0.016322070550813805, 0.03871823020745069, 0.05733198042435106, 0.07304757717065513, 0.021965305822959635, 0.01918491820106283, 0.07977464119903743, 0.015801129266037606, 0.03584126134228427, 0.029084596753818914, 0.04679517551267054, 0.07484499947167933, 0.04844979746849276, 0.03448794763244223, 0.023319376523431856, 0.014725801811437123, 0.035409617121331394, 0.0644426049257163, 0.029901866473664995, 0.030714818749402184, 0.06268246812396683, 0.052707168433698826, 0.01674304083280731, 0.05187982591451146, 0.03812972565356176, 0.04525917102000676, 0.046286299693747424, 0.03768026617763098, 0.052019895156263374, 0.1342114107683301, 0.044418380784918554, 0.05668043413606938, 0.0400602410081774, 0.019648569395940285, 0.05668741403496824, 0.10553581159911118, 0.03921966599591542, 0.08665691057103686, 0.05107211691210978, 0.04337669117376208, 0.027111001581943128, 0.05088128105853684, 0.038011215801816434, 0.06617220235057175, 0.03771111725654919, 0.04544758005067706, 0.01487731960878591, 0.013887669392715907, 0.023265854688361287, 0.0867421091243159, 0.022631624560744967, 0.0566772651654901, 0.03510046437440906, 0.06633481432800181, 0.08755001850659028, 0.026060241070808843, 0.03196254896465689, 0.05811630064272322, 0.016798590586404316, 0.04469809995498508, 0.006826597164035775, 0.10812954351422377, 0.02101237707393011, 0.04625694033165928, 0.05053793756815139, 0.03129986303974874, 0.055548161690239795, 0.04209461993013974, 0.05043727265729103, 0.060981977730989456, 0.028140673966845497, 0.03547057342075277, 0.041310852611786686, 0.0017772685851014103, 0.035245068138465285, 0.03073540035984479, 0.021768000297015533, 0.02067535668174969, 0.02449144663842162, 0.04917021877190564, 0.0576124936924316, 0.05022699624532834, 0.02176206497097155, 0.012751864323945483, 0.023656764278712217, 0.0258595365085057, 0.02585742509836564, 0.055811575875850394, 0.03378525252628606, 0.019325952234794386, 0.04292036683182232, 0.08399596234085038, 0.034991843640455045, 0.016936127249209676, 0.055727308717905544, 0.043345387384761125, 0.09197859180858359, 0.03122434951364994, 0.025458676573180128, 0.05745242357079405, 0.006358642904160661, 0.030318140816234518, 0.075076616340084, 0.01831500238040462, 0.05598183939582668, 0.034295657169423066, 0.07407648328808136, 0.04344880195276346, 0.014973211582400836, 0.059979900252074, 0.03938877176551614, 0.0250680545650539, 0.04917878315609414, 0.014693837511003949, 0.09890983550576493, 0.009684579108579783, 0.051479849134921096, 0.022662984010821674, 0.027547601494006813, 0.021779639027954545, 0.06546137330587953, 0.03243253624532372, 0.019601183266786393, 0.045540916253230534, 0.03961962051107548, 0.032013612435548566, 0.037779075719299726, 0.06726798339514062, 0.03258405311498791, 0.010007764012698317, 0.10300428650225513, 0.011030611422029324, 0.07724315320956521, 0.07881904442911036, 0.009564373449393315, 0.06781207412132062, 0.031297822133637965, 0.0304823632541229, 0.050251598440809175, 0.021856735183973797, 0.06714801522321068, 0.0440033977793064, 0.04093977877346333, 0.02891151492804056, 0.079771064047236, 0.01605402350833174, 0.05435332619526889, 0.048867240693653, 0.03709252232511062, 0.07964508447912522, 0.035300829404150136, 0.05969730525976047, 0.040060133396764286, 0.03484154018224217, 0.031805488251848146, 0.03750698953808751, 0.010139044370589545, 0.00375591569536482, 0.023658506470383145, 0.049890859008883126, 0.1091213793552015, 0.021213102045294363, 0.05736675375374034, 0.0776315487746615, 0.0937207909009885, 0.0845603433845099, 0.07576559655717574, 0.047895316674839705, 0.020687908254330978, 0.03403039132535923, 0.05488963179232087, 0.025419268531550188, 0.054943604482105, 0.06379778249538504, 0.04295479135180358, 0.058349383252789266, 0.05115864390973002, 0.03693599966936745, 0.08295934530906379, 0.02684450191736687, 0.06999006232945248, 0.025981647631851956, 0.045339701464399695, 0.03822695813141763, 0.017859088075056206, 0.04741173695947509, 0.03840196397504769, 0.05199494044063613, 0.024290317196573596, 0.054252549962257035, 0.044247738769627176, 0.04429860186064616, 0.06345476183923893, 0.08161496705724858, 0.037407319105113856, 0.015124911205930403, 0.07155762665206566, 0.04635938639694359, 0.011821626740129432, 0.07517097299569286, 0.03239575169573072, 0.06984721374465153, 0.02243846764031332, 0.029540440555138048, 0.0333170426893048, 0.15616431715898216, 0.10596456515486352, 0.15749676909763366, 0.17222776223206893, 0.15396361181046814, 0.16337983310222626, 0.20541466190479696, 0.10405964276287705, 0.17604317312361673, 0.17858535546110943, 0.10745784049504437, 0.1054396663676016, 0.1370016040164046, 0.12716822151560336, 0.11536137928487733, 0.13109185238135979, 0.1442865256103687, 0.13120905234245583, 0.07566197789856233, 0.0872256480215583, 0.2255360220442526, 0.12837483489420265, 0.11214675178052858, 0.16302600677590817, 0.18837958225049078, 0.2041145379189402, 0.13269728107843548, 0.1684208563528955, 0.11898752025444992, 0.12464763567550108, 0.14839892915915698, 0.2216624713037163, 0.3224764351034537, 0.17603451968170702, 0.0848979018337559, 0.0817503422149457, 0.1279534731293097, 0.2312146095209755, 0.12495774950366467, 0.13537837861804292, 0.2496777445776388, 0.13732578896451741, 0.08724857296328992, 0.1475962222320959, 0.11832383985165507, 0.09525237590423785, 0.16466839442728087, 0.09334449234302156, 0.1192797557450831, 0.16872528532985598, 0.13484878203598782, 0.10925061695161276, 0.1688214676687494, 0.11754756080335937, 0.16208177228691056, 0.20657052722526714, 0.17759282200131565, 0.16701844957424328, 0.1905870411428623, 0.2530044363811612, 0.10666018017218448, 0.12567985919304192, 0.17294595338171348, 0.2228044139337726, 0.11191223311470821, 0.15259231586242095, 0.12781035737134516, 0.14329949888633564, 0.1471809163922444, 0.15580985258566216, 0.11122746087494306, 0.10200984572293237, 0.16720091400202364, 0.2430892692063935, 0.14709466398926452, 0.16849844047101215, 0.11289629866951145, 0.19779705035034567, 0.16372199286706746, 0.17540655884658918, 0.32406454207375646, 0.1351637495099567, 0.1234196632867679, 0.09695185697637498, 0.09559916667058133, 0.19114898052066565, 0.1616925306734629, 0.19198837922886014, 0.08106182212941349, 0.0950991669378709, 0.14896492066327482, 0.15414546767715365, 0.17867582326289266, 0.10852574647287838, 0.1575910218525678, 0.17600472987396643, 0.14428520458750427, 0.13514880265574902, 0.1838474496616982, 0.09118798188865185, 0.2121548619470559, 0.25496777321677655, 0.14268142345827073, 0.14335566462250426, 0.11422647221479565, 0.08402189298067242, 0.211853624205105, 0.09461378751439042, 0.08949218929046765, 0.18657741020433605, 0.13203101058024913, 0.11300549085717648, 0.10315104620531201, 0.10127497851499356, 0.1257349265506491, 0.11138690388179384, 0.13798092724755406, 0.15527791081694886, 0.17856099817436188, 0.12058783555403352, 0.1760014792671427, 0.10326754854759201, 0.1219534689153079, 0.12213836016599089, 0.10945206551696174, 0.1577387092402205, 0.15694472996983677, 0.1427357189822942, 0.07092056708643213, 0.0900343652756419, 0.16812586749438196, 0.1915897717117332, 0.11005292311892845, 0.1369931286899373, 0.1805161268566735, 0.22791033057728782, 0.10774436144856736, 0.23733042587991804, 0.1510964726912789, 0.19453210523352027, 0.09489560325164348, 0.12654833524720743, 0.2224004629533738, 0.13156393251847476, 0.15441992873093113, 0.14045364456251264, 0.11996465414995328, 0.20944820484146476, 0.22548457636730745, 0.12339121676632203, 0.1912122857174836, 0.1220401814498473, 0.2063362460467033, 0.16030664410209283, 0.11544111563125625, 0.15898609621217474, 0.1265631485148333, 0.18581957352580503, 0.19528351491317153, 0.08803224380244501, 0.11984029988525435, 0.10940087959170341, 0.09536393554299138, 0.18134982587071136, 0.11822639586171135, 0.14672096294816583, 0.0757087480451446, 0.11369369181920774, 0.1830182332196273, 0.09862125880317762, 0.1148961714352481, 0.12344013914116658, 0.15098531381227076, 0.11440687347203493, 0.11182155009009875, 0.18164108914788812], [0.04108204477233812, 0.019035284531128127, 0.03371249978954438, 0.0037728677398263244, 0.023470420273952186, 0.044806857986259274, 0.12297518362174742, 0.034275723082828335, 0.015808274292794522, 0.06483211371232755, 0.044880497589474544, 0.024219566403189674, 0.044432889771997, 0.05558234501222614, 0.05525220061826985, 0.03054689113923814, 0.03995864470198285, 0.04739376214274671, 0.030129900624160655, 0.01336815952527104, 0.030480702698696405, 0.04080225509824231, 0.04817559245566372, 0.025893235579133034, 0.047481914443778805, 0.043826221153722145, 0.08138510907883756, 0.06865700182970613, 0.06301537330728024, 0.0833584500651341, 0.017974946604226716, 0.08618008811026812, 0.02605883655633079, 0.026657146736397408, 0.028312815120443702, 0.020860479853581637, 0.029968067901791073, 0.024649783845234197, 0.029443234052450862, 0.024593113448645454, 0.006549373001689673, 0.11563764375750907, 0.022572523630515207, 0.020558605719998013, 0.0450890559295658, 0.05180794149055146, 0.042721174395410344, 0.04769962346472312, 0.04712778012617491, 0.07068566250381991, 0.0077061873435013695, 0.02076368524285499, 0.01055120164892287, 0.04341764659329783, 0.029996712946740445, 0.05540126468986273, 0.04727425781311467, 0.02357765319175087, 0.06139385484857485, 0.020655303851526696, 0.029706126879318617, 0.04491872190556023, 0.05858124131918885, 0.010372049982834142, 0.02262514561152784, 0.005618007353405119, 0.07079187125782482, 0.04460301228391472, 0.06181854143505916, 0.015663178855902515, 0.058894583489745855, 0.0672439081245102, 0.007124007279344369, 0.03788881338550709, 0.04782554737175815, 0.06594189166207798, 0.011213919115107274, 0.048607340577291325, 0.041511310409987345, 0.14298619382316247, 0.025327054827357642, 0.04268120974302292, 0.035089677257929, 0.006893451682117302, 0.032576049052295275, 0.017535439328639768, 0.017817668813222554, 0.08864404066116549, 0.039998702122829854, 0.058847256732406095, 0.036393630725797266, 0.06521762974443845, 0.024690909958735574, 0.024117459870467428, 0.010653680183168035, 0.010994856602337677, 0.04740833421237767, 0.045455205618054606, 0.06793208682211116, 0.03140474706015084, 0.05899725962080993, 0.05286919040372595, 0.03747064285562374, 0.058350919498479925, 0.009721322840050561, 0.12749075889587402, 0.04696317919297144, 0.037620708826580085, 0.04618736398697365, 0.0390809029340744, 0.06627510854741558, 0.0186542455048766, 0.012848383412347175, 0.07190063246525824, 0.027805900426756125, 0.008493665864079958, 0.025970801143557765, 0.00932342221858562, 0.030323968530865386, 0.03412012811168097, 0.011068315307056764, 0.04822168353712186, 0.017944657702173572, 0.04450434003956616, 0.037793109731865115, 0.03285985374532174, 0.03181230116751976, 0.04715263465186581, 0.025868516495393123, 0.037662792310584337, 0.019519005254551303, 0.01276442053494975, 0.050730331931845285, 0.03285187565779779, 0.05956852779490873, 0.03347598474647384, 0.04593915640725754, 0.023609274248883594, 0.003816200119217683, 0.10818300041137263, 0.07100540198734961, 0.08452381487586536, 0.04652945695852395, 0.018864119301724713, 0.01683928625425324, 0.046651310185552575, 0.05246303895546589, 0.06439841003157198, 0.015147822232393082, 0.02413118589174701, 0.009048546489793807, 0.013261239237181144, 0.021161576587473974, 0.024623548924864735, 0.0835814283345826, 0.024572157053626142, 0.018360850408498663, 0.06201335148944054, 0.06282765447394922, 0.042333580349804834, 0.06174254551297054, 0.10763954051071778, 0.051416833375697024, 0.04930895214783959, 0.007765580030536512, 0.02901336356444517, 0.03398140215722378, 0.025782245538721327, 0.05104209703858942, 0.025300190936832223, 0.005289858409014414, 0.0364754450856708, 0.046059803644311614, 0.017754196633177344, 0.02827699721819954, 0.08699188634636812, 0.01778650974301854, 0.05833010967762675, 0.07723313421593048, 0.01622280087758554, 0.01549806027469458, 0.08633540477603674, 0.031681605250923894, 0.05311943888955284, 0.04126706960960291, 0.020365873679111246, 0.025810118750086986, 0.0067972252782055875, 0.03303803227026947, 0.090252653171774, 0.044932793025509454, 0.02290145646838937, 0.017350147318211384, 0.03374751060619019, 0.03344706325151492, 0.028892078080389183, 0.06807289450080134, 0.06265224787057377, 0.03206875400792342, 0.0395996975566959, 0.022031073094694875, 0.014802010173298186, 0.026821393294085283, 0.018846929306164384, 0.06359617065754719, 0.04677704484493006, 0.04365400949609466, 0.0594024128804449, 0.025323705885966774, 0.03219520112907048, 0.045438600063789636, 0.03972036705818027, 0.04116460870136507, 0.01306658967223484, 0.036604864508262835, 0.06252129591302946, 0.09170390068902634, 0.02106977663061116, 0.037638887733919546, 0.02484012617060216, 0.048496634408365935, 0.05650110157148447, 0.03214018201106228, 0.02494659838703228, 0.022154679645609576, 0.0031776650712345145, 0.0426589490234619, 0.054529849730897695, 0.06204913413967006, 0.09185775532387197, 0.05406265663623344, 0.06545991127495654, 0.09605508283129893, 0.04520685331954155, 0.08231231127865613, 0.051844006156898104, 0.015021978106233291, 0.018869824561988935, 0.062066492973826826, 0.031124103916226886, 0.024354577908525243, 0.033548080682521686, 0.03439769134274684, 0.025855239473457914, 0.02490330891305348, 0.08089546972769313, 0.03678339926409535, 0.049496585634187795, 0.023222394520416856, 0.03952583901991602, 0.056535719049861655, 0.1193119575327728, 0.01108844513510121, 0.09289182678912766, 0.046625502000097185, 0.02308547012944473, 0.04157056348049082, 0.03534704665071331, 0.019860344946209807, 0.02926683668192709, 0.10547146739554591, 0.02649632890097564, 0.03031327789358329, 0.022939116752240807, 0.08450543929939158, 0.054136266553541645, 0.0858619887731038, 0.026873850147239864, 0.05856729265360627, 0.037568725092569366, 0.037757293684990145, 0.011660112213576213, 0.036905196830048226, 0.03677961431094445, 0.0439146703138249, 0.0704767627757974, 0.09602041711332276, 0.07785169203998521, 0.038433720474131405, 0.015336629239754984, 0.055744775163475424, 0.09467099225730635, 0.02504506839613896, 0.011439943900768412, 0.015478082586923847, 0.026570215268293396, 0.04371189330413472, 0.047630180706619285, 0.0725306045205798, 0.044413801733753644, 0.03042328273295425, 0.1024016403243877, 0.04836948966840282, 0.03803919105848763, 0.005360606883186847, 0.058316743597970344, 0.0026586767944536405, 0.015660317876609042, 0.03723725225427188, 0.03878768038703129, 0.030851860028633382, 0.03652813385997433, 0.03385263211384881, 0.055613700751564465, 0.013925632101745578, 0.024033064692048356, 0.04703783182776533, 0.03638465816038661, 0.01856601156760007, 0.02810037534800358, 0.02937333487352589, 0.012266063731658505, 0.0111739210660744, 0.0322938622412039, 0.024870415072655305, 0.027565227501327172, 0.026327117375331, 0.058411029749549925, 0.06465142301749438, 0.06632110686041415, 0.04089088237378746, 0.041370009203092195, 0.059243066352792084, 0.03552127323928289, 0.04420164397743065, 0.04708830529125407, 0.03405971729080193, 0.031902227201499045, 0.014740963888471015, 0.04759738520078827, 0.05861359153641388, 0.04821872978936881, 0.027983885993307922, 0.08033895544940606, 0.022117438675195444, 0.02014169869653415, 0.044902290755999275, 0.08222369142458774, 0.020364968258945737, 0.010459518580319127, 0.0765539874555543, 0.02221036484115757, 0.018644903720996808, 0.019449441897450015, 0.05511448769539129, 0.06011782468704041, 0.038196136738406494, 0.042250014521414414, 0.0574600268737413, 0.07528989473939873, 0.05662470997776836, 0.07830016445950605, 0.11515083941048943, 0.16450506256660447, 0.08034989470615983, 0.22337628324748948, 0.2450473516364582, 0.1715403702110052, 0.3553426230791956, 0.18462743202690035, 0.22267853084485978, 0.18707871611695737, 0.08941787804360501, 0.09864405015832745, 0.18928531411802396, 0.1294911140576005, 0.13361923629418015, 0.14707100432133302, 0.09081866694032215, 0.07820893966709264, 0.1539745955960825, 0.10851893355720676, 0.09843791121966206, 0.1540675718570128, 0.1237926963949576, 0.17919266974786296, 0.24488511815434322, 0.15491853322600946, 0.1348732877522707, 0.18368166871368885, 0.242906968051102, 0.21372272312873974, 0.07701615992118604, 0.18659952620510012, 0.1661825241171755, 0.1555178768467158, 0.18696690414799377, 0.12051605503074825, 0.14231947803637013, 0.10164338804315776, 0.1948169118259102, 0.14360092958668247, 0.10999109479598701, 0.13708515500184149, 0.16801439691334963, 0.06306373164989054, 0.14942626934498549, 0.17219586472492665, 0.1329345308477059, 0.2516738843405619, 0.1308546619839035, 0.12774255475960672, 0.09301691578002647, 0.10856023407541215, 0.15496791573241353, 0.14683526853332296, 0.15527127601671964, 0.12004637945210561, 0.21356004435801879, 0.1330286351731047, 0.1971230169874616, 0.0764018991321791, 0.09353854169603437, 0.10654332902049646, 0.26715980493463576, 0.18804335966706276, 0.1197853809571825, 0.11393586202757433, 0.17444797122152522, 0.18903752585174516, 0.12885237723821774, 0.18121368630090728, 0.1426268310751766, 0.1746593348798342, 0.07910595129942521, 0.1621335296658799, 0.14755473617697135, 0.23951524926815182, 0.13335613009985536, 0.18338285037316382, 0.18842942488845438, 0.15843346336623654, 0.1786085104686208, 0.16435100755188614, 0.13396792695857584, 0.13050589710474014, 0.11065234837587923, 0.11472701371531002, 0.11950006228289567, 0.10811240732437, 0.13524137815693393, 0.2014560016687028, 0.16524462756933644, 0.2264326106524095, 0.20162210916168988, 0.08795202506007627, 0.06928948234417476, 0.12513004650827497, 0.15686833328800276, 0.14205114712240174, 0.19691677414812148, 0.21561139990808442, 0.14072083256905898, 0.1604409728315659, 0.20311921398388222, 0.14029810525244102, 0.08780768475844525, 0.28816457313951105, 0.15468012570636347, 0.13085598300676793, 0.2120967220980674, 0.1002160896314308, 0.17526135023217648, 0.1307908521266654, 0.14059521665330976, 0.22096177999628708, 0.098274853953626, 0.1235882866603788, 0.2519879612373188, 0.14415624900721014, 0.13908454537158832, 0.19914263830287382, 0.1517226969008334, 0.15137130481889471, 0.14199523371644318, 0.1478752846014686, 0.1224231073865667, 0.12086155446013436, 0.1033226159051992, 0.21682037331629544, 0.07063961966196075, 0.10681258761906065, 0.11362020435626619, 0.1046388444956392, 0.0924167557968758, 0.14742920931894332, 0.1292634231504053, 0.06090057155233808, 0.12796577793778852, 0.16917842585826293, 0.1017037098063156, 0.2561019826680422, 0.16514253773493692, 0.14770951849641278, 0.21809956873767078, 0.1704769764910452, 0.1803970566834323, 0.16544059908483177, 0.15320397913455963, 0.1082388024951797, 0.08452269423287362, 0.15965423692250624, 0.12450428985175677, 0.14120223408099264, 0.10911943492828868, 0.09437728731427342, 0.11830423973151483, 0.13723901705816388, 0.11545258181286044, 0.18073525337968022, 0.15257790335454047, 0.1257398395682685, 0.2202167676296085, 0.16441208630567417, 0.15363068436272442, 0.1478001644136384, 0.14354587707202882, 0.18823238468030468, 0.13035734882578254, 0.22672682767733932, 0.1299096259754151, 0.13378791161812842, 0.1333394763059914, 0.15507373114814982, 0.228793976129964, 0.15157873509451747, 0.16212673159316182, 0.1802521597710438], [0.02804467159876367, 0.08367517642909661, 0.04950825961714145, 0.06679666767013259, 0.04682913247961551, 0.047498382700723596, 0.030031415772100445, 0.04888997267698869, 0.008950003193604061, 0.03816174932580907, 0.01484818289100076, 0.025983781306422316, 0.05260445148451254, 0.017889970695250668, 0.04008223826531321, 0.05295687144098338, 0.026523797641857527, 0.03939316899050027, 0.009692228795756819, 0.0471635479334509, 0.04499229842622299, 0.022279178629105445, 0.030603301784140058, 0.0071188280162459705, 0.06282487884163857, 0.002467673493811162, 0.04421975609147921, 0.023427397973136976, 0.06590833174414001, 0.026604090598993935, 0.0335716698464239, 0.029114225144439843, 0.023985160914890002, 0.020811958238482475, 0.04349006536358502, 0.03258824996009935, 0.0694574971566908, 0.012366201717668446, 0.034278276070836, 0.025248218335036654, 0.05134208426170517, 0.030699990638822783, 0.05844645245815627, 0.044379603568813764, 0.02183119231631281, 0.10303696326445788, 0.046707861838513054, 0.039210960603668354, 0.06097507204685826, 0.06104838139435742, 0.015840516898606438, 0.02055685796221951, 0.10805779267684557, 0.007037623608994181, 0.06521900271764025, 0.02675674852071097, 0.02525313691876363, 0.056933424857561477, 0.07029396438156255, 0.0449045431741979, 0.044101684106863104, 0.04583423527947161, 0.01642645918764174, 0.09281065067625605, 0.028829561415477656, 0.017286840266024228, 0.05863299127668142, 0.03406506817555055, 0.05737953724747058, 0.019776775407081004, 0.07600306154927239, 0.018894723616540432, 0.020541714438877534, 0.04929289949359372, 0.03252569804317318, 0.06901858359924518, 0.05104516210849397, 0.020832107547903433, 0.05196056044951547, 0.03493629759759642, 0.07406455697491765, 0.041713849932421, 0.02436986058455659, 0.03507035173242912, 0.08990547648863867, 0.0243246433819877, 0.020202148480166215, 0.01859364358097082, 0.055554061764269136, 0.06445509527111426, 0.02587014179880498, 0.016286608879454434, 0.02257571857626317, 0.011505626753205433, 0.06061029162083287, 0.01792781094991369, 0.1035604445496574, 0.003123744099866599, 0.05862872763827909, 0.020794961201318074, 0.01509093475760892, 0.07600738084875047, 0.028399766997608822, 0.05027528779464774, 0.07868660075473599, 0.0749901264498476, 0.03281015211541671, 0.017069680434360635, 0.03705410876136739, 0.08504046840243973, 0.023332482851401437, 0.05725920542317908, 0.01481653678638395, 0.03077357087022392, 0.050343082984909415, 0.03950888094550464, 0.012919238106405828, 0.015638658296666108, 0.06189467094372958, 0.06451374720199965, 0.020168334376649, 0.02183501623221673, 0.027669979790516663, 0.042452298002899624, 0.04989576460502576, 0.012061449906468624, 0.035738548103836365, 0.07951235136715695, 0.08044362795772031, 0.03296914241218474, 0.012150034508522367, 0.05243278901616577, 0.061958057776791975, 0.03074695745453937, 0.11706001430866309, 0.030450371123151854, 0.05373714695451781, 0.04499698508880101, 0.023364844200841617, 0.0199390255875187, 0.05578312193392776, 0.03259867713495623, 0.03206984867574647, 0.02255697934742784, 0.011558419428183697, 0.03554148934199475, 0.030592373659601435, 0.08869526369380765, 0.035994711506646127, 0.04742962271848228, 0.03258441676734947, 0.014088682873989455, 0.003677109816635493, 0.05543857245356776, 0.020614170316548552, 0.033387131115887314, 0.02293782170454506, 0.034049074893118814, 0.029549832433986012, 0.06912620985531248, 0.03086469918343937, 0.04611733493220527, 0.07970479768118821, 0.026846680120797828, 0.09295208918047138, 0.047434071893803775, 0.04059348895680159, 0.011341245681251166, 0.031979733394109644, 0.013631337151309708, 0.03869772466714494, 0.02023010703851469, 0.019353983152541332, 0.040870228403946385, 0.07893504211097024, 0.016546824408578686, 0.025215298519469798, 0.04735096619697288, 0.026582735299598426, 0.020807616674574092, 0.07390124737867154, 0.009758637097547762, 0.0310919652110897, 0.025141916812572163, 0.03497009129205253, 0.038153196073835716, 0.025967747205868363, 0.031215217386488803, 0.0525513433967717, 0.022142918460303918, 0.05323763703927398, 0.020949127538187895, 0.06660658138571307, 0.013969677638669964, 0.01319662600508309, 0.008009004468476633, 0.033040930356946774, 0.01684565759205725, 0.03080578379012877, 0.015023955002106959, 0.06499568306026049, 0.007403857716781204, 0.02157950591936242, 0.059324531903257594, 0.043277989243506454, 0.042244222058798186, 0.08529184124199674, 0.05033475608797744, 0.10851764964172617, 0.05738776395446621, 0.014922323443897767, 0.04236349632265046, 0.02023101616941858, 0.00872414075274719, 0.008781717497186037, 0.031160639846348204, 0.04448286970728077, 0.021879051564610563, 0.02741351396252867, 0.03810363545198925, 0.02303901725099422, 0.08455238013993949, 0.04489327366172802, 0.025848261429928243, 0.04149611864704639, 0.049131486084661447, 0.007850878773751901, 0.0311607511684997, 0.0374713590281317, 0.08564321848098189, 0.009699573274701834, 0.034309012116864324, 0.027506612677825615, 0.024006380772334523, 0.05369340105971787, 0.0930104887811467, 0.05766744230641052, 0.019691957204486243, 0.028661396318057086, 0.06761461088899523, 0.02061762130324496, 0.017522581620141864, 0.023162549587141257, 0.032454841493745334, 0.0334006122284336, 0.0353640455432469, 0.04008848714875057, 0.04301025204767939, 0.01378855742586893, 0.08478803429170512, 0.010964967532345327, 0.043703176779672503, 0.04094711861398537, 0.017233580038009677, 0.021919446662650444, 0.03713747420988511, 0.039329941719188355, 0.05751422962930519, 0.04200710587610956, 0.0177126864582533, 0.06106499808083754, 0.007716143254583585, 0.05391842765675392, 0.010643087880453095, 0.039516536198789254, 0.048167143104365095, 0.037571823559119366, 0.0543746369658038, 0.008141231064655585, 0.060551554342964664, 0.022896920090715867, 0.007037095756459166, 0.05030544867622666, 0.026649487772374414, 0.06107894303568173, 0.03234609088394791, 0.05804113592603244, 0.04161648757872172, 0.02405221210210584, 0.0453666785324458, 0.049776030209613964, 0.05272949594655074, 0.026214682002319023, 0.010473720503796358, 0.008728833909117384, 0.08830325386952609, 0.03013072255271254, 0.04541130016150419, 0.0012662530616580625, 0.054409480799222365, 0.05330335792677943, 0.028336519317235798, 0.03011277371115284, 0.034750211489154026, 0.039686803429503925, 0.038912064337637275, 0.01940924717928283, 0.0030647152971141622, 0.05484276516654063, 0.028129437851021066, 0.033968644638662226, 0.05288786283927038, 0.0380309866159223, 0.05290558532578871, 0.030121371491986793, 0.012210110435262322, 0.09354523586807773, 0.010759767410490895, 0.039407952572219074, 0.04528337245574221, 0.03590586158679798, 0.02511312148271827, 0.07280283913132735, 0.02465314948494779, 0.024332508291990962, 0.017230526100320276, 0.011980009403487202, 0.04612608114257455, 0.007620973947268794, 0.025993961717176717, 0.038891911317477934, 0.01666410043981159, 0.03475008903478738, 0.033274751403951086, 0.040320048356079496, 0.04556436811981257, 0.01141787242886494, 0.021540220332099125, 0.04380118480185047, 0.05804687272757292, 0.04755980284244288, 0.0519117976364214, 0.013636718649649993, 0.029087569055263884, 0.020404778915690258, 0.040172331282519735, 0.017166786747111473, 0.026945838471874595, 0.05484678389620967, 0.040234048283309676, 0.054761247665737756, 0.04696160955063533, 0.0601207042200258, 0.01573078665387584, 0.049138046670123, 0.022271560483204667, 0.02077499928418547, 0.05586683990259189, 0.01777483576006489, 0.018116544670192525, 0.02200537437602179, 0.03230714668461587, 0.1431936537846923, 0.16999389772536233, 0.18120078777428716, 0.16952285659499466, 0.13848946167854592, 0.20705894945422187, 0.14630161982495338, 0.20061782008269802, 0.08142804974340834, 0.08603410766227171, 0.08829619604512118, 0.08319570450112224, 0.14322568487841636, 0.05611507345747668, 0.0843472579435911, 0.12259717812412418, 0.16762465063948184, 0.10050166063592769, 0.10923060865025036, 0.07694040148635395, 0.10147032662644051, 0.10285715572535992, 0.1379718433599919, 0.13037061842624098, 0.12211021050461568, 0.1784773136023432, 0.11847323417896405, 0.13461568829370663, 0.16242761310422793, 0.10020581088610925, 0.12274954104213975, 0.1668090748717077, 0.1730119896819815, 0.16455766599392518, 0.1333238318329677, 0.18114386504748836, 0.1274658227339387, 0.10095541714690626, 0.11158368433825672, 0.147074596316088, 0.14969411044148728, 0.1008200716751162, 0.12793438509106636, 0.17281122389249504, 0.10386269161244854, 0.19426723272772506, 0.14216184586985037, 0.1434742598212324, 0.188418218458537, 0.14045554446056485, 0.09785178524907678, 0.13244714762549847, 0.14715467405039817, 0.14332396007375792, 0.14995320903835818, 0.1178638864075765, 0.1068429191946052, 0.10520619413000531, 0.18529255961766466, 0.1357071500387974, 0.24012259324081242, 0.19047245354158804, 0.16035292443120852, 0.17003152461256832, 0.20644667762098834, 0.19222487200750038, 0.11211794160772115, 0.0973935387446545, 0.0951776045258157, 0.13226376293459907, 0.14781707053771242, 0.09047497835126705, 0.06253825398744084, 0.17860735271824524, 0.16326747194398195, 0.15698249044362456, 0.16673468198860064, 0.08652162447106093, 0.12154596304753795, 0.1981019543018192, 0.1292604990885593, 0.15070785448187962, 0.14703869121149182, 0.11869171503349207, 0.15468015539227054, 0.124940769164823, 0.11625334431300871, 0.09664771001553163, 0.17869488161522895, 0.14516614872263744, 0.11507683244417422, 0.1885808675433509, 0.064783191337483, 0.16011160769267008, 0.15173470485024154, 0.07877748415921815, 0.24271935311844572, 0.18613164662383497, 0.07223703316412866, 0.1719859556760639, 0.17518787761218846, 0.12162077895482071, 0.08982417421066202, 0.11366894119419158, 0.19258433865616098, 0.12488157546613365, 0.09470598452026024, 0.11124484197353013, 0.11946083235670812, 0.16699473053449765, 0.14424049761146307, 0.14701960317324847, 0.07558785218861885, 0.10372973585617729, 0.16991422075079754, 0.10925324415438809, 0.14748390560271218, 0.0730079687491525, 0.14467745932051912, 0.11590574460569769, 0.13646920211613178, 0.1310690536047332, 0.16556511662201956, 0.13577645178884268, 0.11327559550409205, 0.16943041468039155, 0.19641221762867644, 0.19337762030772865, 0.2012794595793821, 0.09427956130821258, 0.22088793630246073, 0.24682163377292454, 0.14168302703183144, 0.11344343962264247, 0.16979699110379443, 0.15600413200445473, 0.2673801634227857, 0.164482991094701, 0.07984571668202989, 0.07099391354131512, 0.2061097277328372, 0.11218956627999432, 0.09287774082622491, 0.10580101807136089, 0.09742697249748744, 0.07831042094039731, 0.12619522138265893, 0.30861703504342586, 0.171746687265113, 0.1462049179826863, 0.08055614496697672, 0.211417805403471, 0.13880079262889922, 0.23707566142547876, 0.12441345839761198, 0.27791275293566287, 0.11661152704618871, 0.09433894054382108, 0.16656026244163513, 0.18583080964162946, 0.13056233001407236, 0.1388745621079579, 0.1443902333267033, 0.13017397897783667, 0.23296803730772808, 0.19716235081432387, 0.06794697430450469, 0.14012741128681228, 0.18612616957398131, 0.05795251236122567, 0.09954241249943152, 0.1177411871321965, 0.09306494015618227, 0.1533295653644018, 0.1667536364402622, 0.11750496894819662], [0.0738120857567992, 0.03406273041036911, 0.02631420771649573, 0.04287536670744885, 0.046847741832607426, 0.051026589862885885, 0.02648898534971522, 0.04843757800699677, 0.008423713807133026, 0.026429656209074892, 0.017937236225407105, 0.016881842857401352, 0.093985114217503, 0.003220160679120454, 0.030920479002816137, 0.002964463669741235, 0.031548968618153594, 0.044057366758352146, 0.020228207140462473, 0.034126469763577916, 0.052585916346288286, 0.01662587241298752, 0.08593512742663734, 0.01755176101141842, 0.06956629600608721, 0.024218056132667698, 0.035321038085385226, 0.08779657480772585, 0.04279561551811639, 0.08099957078229636, 0.010698966034397017, 0.06975361407967284, 0.04209887243632693, 0.04767126971273683, 0.04923114167468157, 0.04276757717889268, 0.05445905997476075, 0.049478581131552346, 0.0017551682390148926, 0.06904423964442685, 0.006461472567025339, 0.04529039688350167, 0.08210431697079912, 0.06299643369857222, 0.04607988244970329, 0.04007129529782105, 0.029074177000438794, 0.044420584963518195, 0.008514883866155287, 0.08216601912863553, 0.05944633317994885, 0.030416208210226614, 0.04638520571461413, 0.04405243889777921, 0.028782281042367686, 0.04066695415531285, 0.03203492691682186, 0.06354101424221881, 0.046570798294851556, 0.02679677625565091, 0.0352780417597387, 0.03926744917407632, 0.06502228905446827, 0.09281370090320706, 0.029929522606835235, 0.021763226432085503, 0.010202102803305024, 0.06790028579416685, 0.0686754219350405, 0.03411420577322133, 0.06415068855858408, 0.030879187761456706, 0.08614904407295398, 0.021904080495005473, 0.04386741034977604, 0.055459385985159315, 0.04658327750803437, 0.025887695446726866, 0.012803584595530992, 0.005323414152371697, 0.007479669957319857, 0.034898396115750074, 0.012738013992930064, 0.10692897121771239, 0.04663182138756383, 0.011583811083255569, 0.030419340073422063, 0.014911668986314908, 0.014968296709412243, 0.022557485863217153, 0.054670646277372725, 0.005220856764935888, 0.1105591346276924, 0.052702748944284394, 0.03006196999194799, 0.05726647475967184, 0.047866306122159585, 0.07218146114610136, 0.05677557004673872, 0.01374988411043887, 0.0353020762122469, 0.04994436043489259, 0.03257820870203432, 0.02013822359003825, 0.03511316994263325, 0.03565401377272792, 0.020127070965827443, 0.050289054634049535, 0.006599723083127174, 0.025369871182192583, 0.01930009209900163, 0.05474762925587129, 0.0575889676110819, 0.03441666063736193, 0.03745095738850068, 0.019905499066226184, 0.03450931406405289, 0.041717230415088125, 0.034736541128950194, 0.047161017209873535, 0.03579443924536463, 0.0398562505870359, 0.05253925752185751, 0.010902759786404204, 0.04010345997812692, 0.04700423851318192, 0.021846898016519845, 0.048646678114891984, 0.058536471260595135, 0.04475048073800281, 0.009580509595252806, 0.034909999594674446, 0.017893685144372284, 0.03095130781730404, 0.03989762903074734, 0.024112340906867757, 0.025579455541446805, 0.036424934514798224, 0.03708552387251984, 0.06264455922064371, 0.020219232719682623, 0.05022990546422079, 0.0154041943642369, 0.18727421265793964, 0.036937086915713735, 0.08498295937897637, 0.03290657936304342, 0.04060601640958339, 0.01912756317324238, 0.017566260721650906, 0.07506443769671023, 0.028998412999499124, 0.042200465031783096, 0.06426401450880803, 0.06373805445036851, 0.02245706029498251, 0.05090002770884894, 0.017512909580545966, 0.013813901769026415, 0.048264353317790665, 0.023081161962181795, 0.04800467584573198, 0.016980789696390275, 0.04055749850522261, 0.015853823606448714, 0.041820466867648065, 0.028692816995317116, 0.055721412354614586, 0.04727192375867162, 0.03480809900793247, 0.029288314435689244, 0.04609540817909874, 0.03781963780056685, 0.08579590794397518, 0.04302189263398759, 0.023631041440239642, 0.09929310283041559, 0.019488434336381033, 0.03843725680781063, 0.08992924747872166, 0.03586834231100511, 0.03757554914045613, 0.05559552926570177, 0.04498699578107335, 0.040483988777850755, 0.02673659550055163, 0.07434997954987921, 0.0738059556169901, 0.023120269434002694, 0.04606381866324227, 0.0589758857677225, 0.033068679258576594, 0.03643463067419361, 0.07428988043102436, 0.08205917954910547, 0.07591679430333897, 0.06009842123603448, 0.004483996426642989, 0.009877722113742493, 0.03640613591414876, 0.03352734878717456, 0.04242933224304579, 0.04295793434721418, 0.06557751941727474, 0.03150535259919707, 0.034509206452639773, 0.032592402276350185, 0.02441575314151123, 0.038406635794672184, 0.022588702449866105, 0.027113443247799296, 0.01895300818432588, 0.026452358506503515, 0.05507408146513626, 0.03463236957031768, 0.02147832521586679, 0.05753196695877705, 0.020526517109829, 0.05066350153356325, 0.031982546133804135, 0.018369874924246687, 0.04293008896638639, 0.0388864750857465, 0.04235437903844286, 0.029649719945155084, 0.04988077693269588, 0.03746062015125062, 0.047671299398643896, 0.03818473363935482, 0.05153216312464792, 0.00488322502860683, 0.05978024026262574, 0.03474934688711073, 0.06544097166624852, 0.060667529760394245, 0.013934943272033706, 0.09528101538307965, 0.010611860161588993, 0.017183876552735455, 0.11320499499561265, 0.019775137116084807, 0.06136269206763245, 0.03232650189602282, 0.05842159422172699, 0.025593637983547524, 0.02372149068833096, 0.04810519974853378, 0.01999175889068283, 0.09355870584840886, 0.03373058592842426, 0.05384376760048326, 0.07891112269135192, 0.02352548577619018, 0.030782309659116436, 0.039738972700433806, 0.03560866854968481, 0.02992940386320697, 0.05147073185071349, 0.04666455752158072, 0.02065584561933065, 0.050361020694253966, 0.014610073158110026, 0.05783883389085531, 0.020198565762257203, 0.01720988697343273, 0.023567572970932815, 0.030666300845041405, 0.02663855964783579, 0.0820135152025614, 0.03677851222164463, 0.09844476866419427, 0.02797029541397933, 0.05055520734458696, 0.06988682958763093, 0.03875229107507039, 0.06064893153961748, 0.06201289135788102, 0.0606475103268167, 0.025661058389232494, 0.0497666605951963, 0.048032521226559766, 0.04503611482505221, 0.07374316250206903, 0.029170340785640292, 0.027147858490934595, 0.05337104179488961, 0.045742557776975445, 0.04312679149734322, 0.02627812820719555, 0.0386866889311932, 0.01839236014347989, 0.016703296969353687, 0.05895398498978466, 0.04194763758277986, 0.04148562096816022, 0.06497707741800696, 0.027955014593317173, 0.01879666178865591, 0.015715941844973713, 0.044214895024197176, 0.06556543725309893, 0.09606242267182097, 0.05161268614756409, 0.005183040166230057, 0.054579814823227935, 0.05922744414419867, 0.06856324631371535, 0.0549485842930153, 0.03654974891105667, 0.03202935338777024, 0.011949443123739911, 0.007369717068286263, 0.10319523367797956, 0.012619389108294854, 0.01906030604004627, 0.058818064353545196, 0.03400933288503438, 0.016098548658192158, 0.03320746087410953, 0.02795070828142343, 0.014211127036105609, 0.07922915523522533, 0.06454545917222276, 0.05516418932529632, 0.023224238757393323, 0.05278285636450164, 0.006556824628205504, 0.04716164061392192, 0.01720592576020863, 0.022088955047365744, 0.0502761152893072, 0.038653366500511765, 0.02366115222685039, 0.03035914447536925, 0.03751943906536326, 0.03634875305579044, 0.003668648405437125, 0.025644304405432194, 0.00176061769025182, 0.040874714686651714, 0.04758768161991611, 0.0748326575558167, 0.04348103342636023, 0.0047698513026261935, 0.03945427743019536, 0.028571846924023703, 0.04393473056552466, 0.013769399811280891, 0.023820843853172846, 0.06992804104811512, 0.022715461273037363, 0.04789704216818791, 0.1472646603360772, 0.10601099391351454, 0.16781535290647298, 0.2119911293266341, 0.19041003892198205, 0.215441299660597, 0.10099377133883536, 0.13169413490686566, 0.12733504147036, 0.11021866695955396, 0.16073339385911822, 0.10548978360020556, 0.1558184763416648, 0.1782244342030026, 0.14747209061169997, 0.05840930054546334, 0.13330806861631572, 0.2522261906415224, 0.13870860304450616, 0.12898958550067618, 0.192697694292292, 0.12149655827670358, 0.21735302754677832, 0.13057540665613487, 0.13618101133033633, 0.139418363396544, 0.12026567666907795, 0.13424546050373465, 0.10240630101179704, 0.18647947639692575, 0.07773484830977395, 0.10049133736174554, 0.09725410403916612, 0.11141937284264714, 0.07449906959664077, 0.09764052549144253, 0.1180943677900359, 0.170015835610684, 0.08826818739180453, 0.15605005610268563, 0.225013401650358, 0.16318843321641907, 0.29691449424717575, 0.13526255905162543, 0.07691034450544976, 0.12870770297013223, 0.16449045710032806, 0.10700613231165335, 0.0998716514732223, 0.14139511826215312, 0.12987407710170373, 0.07125051852199249, 0.1378498788108118, 0.17822575522586703, 0.19907301000785083, 0.23294434795388952, 0.08483819605316967, 0.1757885274128057, 0.15314423624658957, 0.14974736695876345, 0.19545116607332602, 0.11149988844408654, 0.23159496020525694, 0.30451940023340285, 0.1121956593124196, 0.11405016019125469, 0.13706918398384005, 0.2226178380078636, 0.26289310888387263, 0.20754949422553182, 0.16188004170544446, 0.07384239506791346, 0.14748495945241302, 0.07674247812246904, 0.17938639997737482, 0.16021663643186912, 0.17188015510328114, 0.1206432814069558, 0.06399999547284096, 0.2072505868272856, 0.20917478279443458, 0.16960060398560017, 0.18011092906817794, 0.12974216777365655, 0.11095129288150929, 0.06439662887714803, 0.20931389095494524, 0.1599388208705932, 0.12488910084357485, 0.14208489999873564, 0.14523957681376487, 0.07648301587323658, 0.24655042332597077, 0.15676674811402336, 0.17180052265757695, 0.18968433723784983, 0.1254573930054903, 0.20893799315672368, 0.11224429967114702, 0.07890283290180378, 0.19633582094684243, 0.16101229295600206, 0.1306587943690829, 0.1511130077415146, 0.14168789552059025, 0.11594075171160512, 0.13294699892867357, 0.11656116490485147, 0.09582829734426923, 0.15384017780888826, 0.1652561902301386, 0.1406097924336791, 0.12116409838199615, 0.12925999442813918, 0.11984726865193807, 0.09435285581275821, 0.20810705493204296, 0.13162762363208458, 0.1460555533412844, 0.09487676754361019, 0.18942037015222013, 0.14246863487642258, 0.09812315154704265, 0.09345380327431485, 0.1462594955228269, 0.11773081932915375, 0.10847262354218401, 0.18544434366049245, 0.14292943436885253, 0.1054632592422422, 0.16641906142467633, 0.12496589828515425, 0.1340205452288501, 0.12938023719470948, 0.1316158234840259, 0.08774899572017603, 0.185622607532423, 0.17736455221893266, 0.05848287706612609, 0.13017564138863236, 0.15696865681093186, 0.1252142060548067, 0.09180232431390323, 0.2577110775746405, 0.11677047281409614, 0.16310866718413308, 0.20752175274537876, 0.2032050656271167, 0.1339883657055907, 0.15916155476588756, 0.17503061651950702, 0.1418812249903567, 0.08964678607298993, 0.10389332004706375, 0.13347677362617105, 0.10607749776681885, 0.10567612946033478, 0.07745825729216449, 0.061727658030577004, 0.13140057097189128, 0.12688305869232863, 0.18464359600329772, 0.0864531539264135, 0.1071194805263076, 0.14043103874428198, 0.16110099444631487, 0.09976136090699583, 0.07350151179707609, 0.14759675657842308, 0.1460765115916729, 0.12267356738448143, 0.12491362140281126, 0.10675778743461706, 0.330063410801813, 0.23574420396471396, 0.14683543180581182], [0.022647333971690387, 0.016221910300373565, 0.023172052788140718, 0.018056219196296297, 0.0032115789008457796, 0.011839366852655075, 0.049207259362447076, 0.07127905410015956, 0.07479713836801238, 0.010326509018341312, 0.06730493492796086, 0.033776035052142106, 0.04458815077668987, 0.07490145464544185, 0.018338888403377496, 0.0797883931954857, 0.0339702662313357, 0.06596533610718325, 0.07168814074248075, 0.04134640890697483, 0.04406340412970167, 0.0484503206826048, 0.0530730583705008, 0.034772312646964565, 0.028155255313322414, 0.014532247841998469, 0.08000345274922438, 0.01957531385414768, 0.029236952250357717, 0.011171072146680672, 0.06141772973933257, 0.08397529352805577, 0.026521543368289713, 0.06174227091833018, 0.029310142854228616, 0.0037688596785301343, 0.03609140221669804, 0.042125986801693216, 0.020400815847096965, 0.027285163232591003, 0.014239419560908573, 0.02428606283501722, 0.11736284766811877, 0.0159478871137253, 0.009746657906362088, 0.049331450354657136, 0.029196705581853166, 0.07539073776570149, 0.019256555860920344, 0.11781609209720045, 0.09521888277959079, 0.04132502763241064, 0.03688270975544583, 0.03426473558647558, 0.02105893199768616, 0.08058044288191013, 0.04043547458422836, 0.053650634799851105, 0.01750961073412327, 0.057981159261544235, 0.05307282459398266, 0.0796914983948227, 0.01891150914161699, 0.015504003949899925, 0.061541189716081135, 0.045440525937010534, 0.028408798934833612, 0.04131745772610884, 0.04824973671929911, 0.03705015311425086, 0.008255305656348355, 0.02006994043767918, 0.13639010401675478, 0.02454940837196773, 0.023178785922937095, 0.046531779880751856, 0.030529177929565776, 0.07392386803985573, 0.02564090351370396, 0.016285464116663206, 0.017413927489542402, 0.07071686239214614, 0.029724637897743378, 0.04455328838957939, 0.04516057299042586, 0.004146221826886176, 0.04504271622863598, 0.054069592006271705, 0.05205157744057942, 0.03503538915538229, 0.03272859379649162, 0.026168566801061388, 0.01751275372953387, 0.052557399321813136, 0.05101113463751972, 0.03167966082401108, 0.032019464269978926, 0.01991960729355924, 0.029404074630292598, 0.10749263237812556, 0.06717784213833511, 0.014815387385169743, 0.029716027129325084, 0.03474214063317049, 0.0562011403235374, 0.054979884371277876, 0.010972208110615611, 0.019634303462225944, 0.047160178582998924, 0.02296389706316404, 0.026231922092847526, 0.02405679115327075, 0.053517467531492, 0.035902492236346006, 0.046803387376712635, 0.039588168292539194, 0.0407853712385986, 0.026357050046499353, 0.04242787392286118, 0.07191313765360974, 0.027227533610130195, 0.007271890872289077, 0.01739508064929396, 0.029830982093699276, 0.02345912293094443, 0.014220174743968528, 0.02257304313388886, 0.037013479886809364, 0.07377336049103178, 0.04342723514128011, 0.01923486102896277, 0.01912078365421621, 0.009837572852120502, 0.03531386893882882, 0.04433996546140406, 0.06006254581734538, 0.07289767076144926, 0.01745899069646839, 0.03293304434919264, 0.012211039047542727, 0.00667199574309052, 0.04491400555707514, 0.11862751183798537, 0.02447777813358698, 0.04893601551884785, 0.04282160552975256, 0.012990178147447295, 0.02574467616796028, 0.016982082888716832, 0.022736501159670297, 0.009128006386163179, 0.05714726728911046, 0.01070481694114278, 0.020871183478448074, 0.04556708809104748, 0.027061409418820404, 0.03221694605599623, 0.026699170848587528, 0.04088638866960537, 0.026307042280677706, 0.016538180243514944, 0.030434606051130686, 0.07163613103330135, 0.05000937257136684, 0.012692331092694076, 0.0049397084967495175, 0.05222566302109044, 0.04188052145764232, 0.060739469845429994, 0.02940103368018754, 0.009918683099385817, 0.05786271991382819, 0.022111137841420714, 0.01118482970923651, 0.04674657968280371, 0.05008275242289528, 0.03748214243387338, 0.06744489655829966, 0.01427549072104739, 0.04770374980580527, 0.0625163754739333, 0.06866952186101116, 0.06020213637384586, 0.01716593327728333, 0.06860727051389404, 0.018422801185806748, 0.010661413361958694, 0.007979614492796827, 0.03782874395255931, 0.04278728491044603, 0.057119251214317046, 0.04827391589060426, 0.045778752319165505, 0.016810067900223657, 0.054964633236522786, 0.023697803189861588, 0.02241893431346398, 0.09985969547415152, 0.058285198610974476, 0.007089294713296113, 0.020105726798647083, 0.01240283783772611, 0.022319484669424128, 0.024405223921348806, 0.08470427550491877, 0.0736101102665998, 0.06496509915450588, 0.08856241183821112, 0.032223421294474974, 0.011721801383828279, 0.0039878948246041546, 0.011922392768610734, 0.005868638509127777, 0.03317679533211049, 0.021788362973893527, 0.006667859661320108, 0.07176486396929249, 0.03538384604325984, 0.04932733143505175, 0.04751432403281797, 0.018211647184216417, 0.03892860680934973, 0.07948414233396761, 0.04024777430458926, 0.09738061053212732, 0.09478758365730755, 0.022423071786761284, 0.03803706480539404, 0.04308505311200861, 0.06912951983395033, 0.05852558766491711, 0.04477216258237604, 0.044534460103022866, 0.04253830549714621, 0.021851365745533258, 0.032890689981286414, 0.031118855076783802, 0.0420032021793304, 0.05590130152995698, 0.05984582385281101, 0.053024907829239964, 0.04597883533278946, 0.015950430824887007, 0.005317301174727618, 0.04182693468465004, 0.0066094308385800105, 0.06163553523947485, 0.031021015893202275, 0.06907809642143548, 0.024440795059490483, 0.020476834033615887, 0.036612241456168704, 0.03800266254984308, 0.0357018451904878, 0.012550104984256905, 0.06656115452642553, 0.041242341249017045, 0.031110539312066976, 0.05119059336720966, 0.030538349019479938, 0.04889109703071881, 0.03079381294810446, 0.04463937752007041, 0.0350411630643066, 0.03314046720333863, 0.011225629277760163, 0.008576877316954779, 0.04744572361232713, 0.013056792395218508, 0.0586697350081522, 0.0514715482131578, 0.016941454014158808, 0.04942877931171097, 0.03395064013602678, 0.03485041255771648, 0.028499016261775978, 0.0577767346840119, 0.05619077252049465, 0.01544795139125199, 0.022351669758791104, 0.03550933579390403, 0.0795191345969215, 0.028904659338877536, 0.030918629199732095, 0.04927068701363169, 0.023805175260349642, 0.04611832569935359, 0.04771021762280725, 0.051681809782166965, 0.02807107535772957, 0.011526627677085344, 0.03974400075094309, 0.056697629697737284, 0.009346530841867207, 0.02238430384750245, 0.06260611597099341, 0.05479617684613913, 0.026159982007811777, 0.03993786456703674, 0.044229433697182685, 0.06128728244220838, 0.03825343796052039, 0.033333711326122284, 0.01498861671279883, 0.01919777219882235, 0.02054582964774454, 0.051716479210881516, 0.049865117616718635, 0.032714481858420186, 0.03965138443163596, 0.028785455579054542, 0.06829177611507475, 0.017316188495897222, 0.027488238956721034, 0.03989120574260596, 0.05926730860664975, 0.013051691057626158, 0.028199183034303132, 0.04870205717452336, 0.0360042555257678, 0.022243969287956133, 0.020145999442320317, 0.05306901737640146, 0.038809321413282305, 0.02674404480785597, 0.033013871652656235, 0.01276393813895993, 0.037869354273425415, 0.045175389968790114, 0.05768420371168759, 0.025063160101126414, 0.03828736153081991, 0.02795676791720325, 0.02039443152170861, 0.0384939865762135, 0.0702000901219435, 0.021799088863190264, 0.023324617941398174, 0.04141492026974447, 0.04452142056834418, 0.03327819867990911, 0.03587975283153355, 0.030037707329029217, 0.04800446804438252, 0.08100931518129073, 0.032207368640229106, 0.13327262364327908, 0.0426514904393116, 0.08457828851533122, 0.00862562714246451, 0.022444351016019937, 0.06855560219264589, 0.13566230947617441, 0.10782240569824353, 0.1062540992279537, 0.08087290843832307, 0.11822243279311806, 0.1101885580283124, 0.12900319648906589, 0.13550469215260819, 0.17294648772804067, 0.09319480115664192, 0.1357053391984664, 0.1204322517151013, 0.11911698049516417, 0.12237869726959616, 0.13867965928511694, 0.1468515512533486, 0.1384637685259804, 0.1487451558932662, 0.1947265033959411, 0.1457111374475062, 0.12186306048533879, 0.11699116526870057, 0.14568870974471793, 0.09431615661014803, 0.1447597931837663, 0.23282628710148856, 0.12351206067251042, 0.12339140972471796, 0.1406112322001718, 0.16472801857162267, 0.17781323986127973, 0.19307382957777008, 0.14790477755013853, 0.19359242753125727, 0.14217765361536294, 0.09233744247467257, 0.23309933807468042, 0.19862457469571382, 0.21880140295252204, 0.11181312671396881, 0.1817594765452668, 0.18037872563581914, 0.2368203626247123, 0.12088299510651268, 0.1110798551235348, 0.09094234585063532, 0.13257737969979644, 0.14366821269504726, 0.18083513161400333, 0.26521724823396653, 0.20863173849647865, 0.13618917495477945, 0.16625446791294962, 0.2203583694063127, 0.14278225164161995, 0.179560671094805, 0.09220453866873868, 0.12013724059215747, 0.049407772821723484, 0.0710520608117804, 0.12082640634616837, 0.14135473058559, 0.14239620126318187, 0.13206188392359763, 0.16694659483619034, 0.15861907450016588, 0.12433013005647808, 0.13420716568361968, 0.15445519558852538, 0.10809436571435072, 0.16311758779920638, 0.1178004773100838, 0.22896790585946292, 0.10540720482822508, 0.09579478195519187, 0.14228939136955887, 0.040133680231519975, 0.18883146112784743, 0.0999359659908805, 0.16153440868947655, 0.1276387579855509, 0.14565569901606068, 0.14962157292757183, 0.11472861675429158, 0.09144271665718406, 0.11959015901084058, 0.20790321665117517, 0.16708680137526244, 0.18357267690589651, 0.09516748163150623, 0.11307735301670618, 0.1502594636986032, 0.0761959160445258, 0.19316123973112553, 0.16511053632711992, 0.11012286311597563, 0.2020025934325531, 0.09024024446262047, 0.2062909008236602, 0.14652766316430643, 0.1532364555168897, 0.17781611939426512, 0.07813914809958078, 0.13340313773369417, 0.1731234899489209, 0.200951088918373, 0.11460152396466583, 0.09591936628567055, 0.11043606427847408, 0.19954534247517586, 0.09794027893804014, 0.16226109000854194, 0.16625032672891393, 0.08366544687305577, 0.1335495337843895, 0.1269075644086115, 0.1484082653769292, 0.10310322963050567, 0.08965674569481052, 0.2075340723968111, 0.2324662118917331, 0.08934177822084166, 0.12349125827313401, 0.11049343229387887, 0.14837914350209758, 0.13165049662347883, 0.11227267939830199, 0.08977750054327771, 0.1165400433819741, 0.11735498832422309, 0.17713430832372978, 0.17870003212010488, 0.1351927823270671, 0.14458978199400008, 0.08682923726155423, 0.18120938184438273, 0.16012769745429978, 0.08914755075238645, 0.1805978818447329, 0.14230141416192055, 0.09525043147732504, 0.10361156368162483, 0.1916721649467945, 0.13908427819842473, 0.1234814545023255, 0.10324929913622327, 0.22285707673290744, 0.14271777385147288, 0.07806311507010832, 0.1350326565443538, 0.07897013827459887, 0.1720336460857652, 0.15441412513609976, 0.12069615942891687, 0.10357229664805345, 0.0829020886158105, 0.15186382370302454, 0.07984879659488797, 0.08772218934609555, 0.16603458439931273, 0.12460677302442491, 0.13560183928348124, 0.12675573583692312, 0.1455164869548753, 0.11065528728067875, 0.16614639636827633, 0.13414506276603788, 0.15854095603572205, 0.17526010342407972, 0.14119510946329683, 0.16120783402584493, 0.12149801288614981, 0.18027083220658824, 0.040366339817410335, 0.11801990069216117, 0.1684675522847101], [0.02287775969307404, 0.05703580784029327, 0.027186819388589356, 0.06443527992814779, 0.03912106796633452, 0.04073025193065405, 0.0119229317533609, 0.07424406765494496, 0.04630778857972473, 0.049354045040672645, 0.1352913840673864, 0.026966177028953098, 0.03201229512342252, 0.032878218189580366, 0.02262834612338338, 0.0868055182218086, 0.011209672175027663, 0.053356937278294936, 0.026381748721178155, 0.021303426983649842, 0.06944436114281416, 0.06164872320368886, 0.05187079397728667, 0.08009274795767851, 0.06653598087723367, 0.010225379337498453, 0.025441978250455577, 0.008875397870724555, 0.0056222069815703435, 0.04213950131088495, 0.10383281274698675, 0.06846897871582769, 0.012678675575443776, 0.020963343376934063, 0.05368806501792278, 0.07629836210981011, 0.04233401450619567, 0.03994931961642578, 0.08172258589183912, 0.04507070632826071, 0.045189527882030234, 0.048551271320320666, 0.02944225812825607, 0.02940291873528622, 0.04990975408873055, 0.09055524904397316, 0.02479932660207851, 0.03000097472977359, 0.03551028945366852, 0.0711747600871604, 0.020186186739010736, 0.018788676279655192, 0.04934597418468911, 0.07042258599540219, 0.043842563245561905, 0.07512749056331813, 0.04409775814565364, 0.011196055620530387, 0.11155370157212019, 0.09625895821955055, 0.028279576181375887, 0.01852960922406055, 0.03200498496880755, 0.048684275316190906, 0.04779913433594629, 0.06123457882495131, 0.017956804804271087, 0.06987349319388159, 0.015117251314222813, 0.09162407528492622, 0.07306931467610411, 0.014157351015455788, 0.0063506894002784975, 0.019618723927123938, 0.02639831345732091, 0.017342898390779737, 0.00796862977949786, 0.05078673886600882, 0.04234571817505639, 0.033390541284461506, 0.044167267697048374, 0.03924748169083614, 0.03509848284011241, 0.015584570573992096, 0.013277710277179722, 0.016301770956488326, 0.046120934348437004, 0.009477372404944617, 0.030418815003940836, 0.0043773845936811995, 0.02771156603557756, 0.05240895494353026, 0.044005405288771726, 0.016733559896238148, 0.06268654993618838, 0.021662978979293257, 0.05828702058352064, 0.0330648275121348, 0.11938019059016369, 0.04837169384700246, 0.04621761021553539, 0.06269623496336862, 0.024034291091084015, 0.03850815417536069, 0.03290097614808474, 0.04083005966094788, 0.09143106493866071, 0.036533462480292656, 0.03271154666435905, 0.09388402628246695, 0.044571548933163285, 0.04008229763712734, 0.01859595166024519, 0.06292051941272803, 0.037864122132305056, 0.047274684548028745, 0.03152012504870072, 0.058998795866500586, 0.04775357760081533, 0.01767170506354887, 0.042695332813309506, 0.048774576134746894, 0.032739429152570665, 0.022710032462782692, 0.11982253286987543, 0.026677971400204115, 0.011581361068238039, 0.01861635329987621, 0.047959063449525274, 0.055659409626969136, 0.0415836475440301, 0.015243724410538562, 0.08873723214492202, 0.024247571345767938, 0.07110328384442255, 0.008566398191760527, 0.08204582089092582, 0.017192333325510845, 0.028999169990129303, 0.06719142344081774, 0.01750039325997932, 0.029107594054949004, 0.06470721767982468, 0.07338919516769238, 0.03377032793650869, 0.043459169755806215, 0.02566052775364369, 0.005873712943866849, 0.07287617074325681, 0.10825178265804425, 0.08648317379993387, 0.021501400442502927, 0.005658657100866549, 0.01804175102734007, 0.017205816293426324, 0.045065774756949395, 0.06328030518488958, 0.017477609326306265, 0.038089838926680386, 0.06112207665864844, 0.0387922817026265, 0.096530814334983, 0.09521647079964168, 0.014386080929398304, 0.062149290679371916, 0.033308752899756655, 0.08278531167889014, 0.024920068462961353, 0.06442655227147043, 0.009680908260634169, 0.04056369172758423, 0.01673815379035659, 0.02914378488640068, 0.045432941187755205, 0.042434018905623816, 0.032118637464009225, 0.014509037173411343, 0.025816738707362674, 0.03200220191502012, 0.048820054944371805, 0.03591415879782289, 0.07515002216678113, 0.04086935266968794, 0.03493567419354804, 0.010331605717510683, 0.013342516467673704, 0.07036377079202794, 0.03168759438267443, 0.03932693973183632, 0.03596687354729511, 0.04024278336146381, 0.06367134279571474, 0.033448744216002524, 0.01614077129488578, 0.014222857607819606, 0.07295601099031046, 0.013554732668126235, 0.032841092252056114, 0.03254366914916318, 0.0331861760787433, 0.012244591544003924, 0.05990642763208598, 0.03455867801676504, 0.08642518238048069, 0.023869771794124972, 0.02112371406838065, 0.0391410131851444, 0.04981669248081744, 0.016707781396689825, 0.02417343079287093, 0.07853624163544737, 0.07016767311142758, 0.07632899054442532, 0.030359493284777272, 0.06121866717876401, 0.03156896578730084, 0.033480407946626656, 0.03141343389870599, 0.019622644322225824, 0.018651306600077078, 0.023409870300383773, 0.058907470884150825, 0.06259890971705317, 0.026023966747743543, 0.03128931712126359, 0.024707242773729376, 0.04181992138910573, 0.0692817269009538, 0.028570310678333044, 0.0353299846756272, 0.019734695633815136, 0.053443223077920265, 0.029057133579044603, 0.05160247419553343, 0.024787281545286532, 0.08377553705940954, 0.04712945737992413, 0.02741242671618238, 0.018512753194954712, 0.03608006962167565, 0.004887602308372152, 0.045984063763171434, 0.007492961822208599, 0.029357363855524454, 0.11056542803999037, 0.00929650545003824, 0.0128732101075002, 0.005687417642548098, 0.06545463460497558, 0.04485323850531131, 0.07936462687212043, 0.012968122446181951, 0.07806120032910258, 0.03564766841009259, 0.005696264970538323, 0.04997452502720989, 0.08517130903783254, 0.04353508775238879, 0.04107732842385303, 0.05044795216235798, 0.004448917889021686, 0.004494819258979987, 0.06283106093178503, 0.029533566412283108, 0.037628742575179785, 0.020599390445568133, 0.06894865102367476, 0.0504297769657569, 0.03427095478400588, 0.12440349135431461, 0.02869819199986523, 0.04389261739561334, 0.021306894668668974, 0.07715511223068461, 0.07247431261930615, 0.035772126575466245, 0.03644783719209954, 0.047496486513409764, 0.012597102413565153, 0.04799640832061414, 0.010340232256567106, 0.06466503400588408, 0.12499022588599473, 0.038481503652292304, 0.02120258766808547, 0.07484853209462017, 0.03840764511551242, 0.024434373626718298, 0.057807426201179624, 0.0036302812259236816, 0.019964006278314628, 0.024770243689999916, 0.016238582647929434, 0.03479017243080307, 0.020559242111630738, 0.0030457647881121375, 0.027024439332308248, 0.049420166687923484, 0.04070119313837495, 0.06415151976398192, 0.04764106801303569, 0.06019284839567263, 0.03226094428100623, 0.03898440147168003, 0.028317683609202504, 0.04083253843418788, 0.023325677357206587, 0.00770125623603235, 0.015319480990001466, 0.020640076836571097, 0.017047742549038958, 0.02252418013085844, 0.047561142418999225, 0.038712396926712245, 0.027144405648868997, 0.09752384503372014, 0.03936756118491758, 0.06789428181946278, 0.05869657848961651, 0.08139656041748822, 0.054850516899023205, 0.03403022805287037, 0.03497495978081133, 0.021037765945948195, 0.09608852400560863, 0.03294373498647474, 0.030490538010781165, 0.022967759941820987, 0.02907155536377104, 0.008584619772591395, 0.04267641546903178, 0.029843659831385594, 0.03859846983687021, 0.02834091839758912, 0.03782047642744146, 0.0218017810038873, 0.03378892986802384, 0.05850342713529244, 0.0886646649450995, 0.028616023264476098, 0.019388468899705913, 0.03264313178078737, 0.004123258850086131, 0.05313372523232829, 0.027281641741865315, 0.04619067767634988, 0.05996237443468999, 0.05877609961316921, 0.02519648136512842, 0.047998185764299706, 0.03206968911399599, 0.015344952425948577, 0.14111849013715982, 0.1189921289915219, 0.16882920084754005, 0.08954959441325627, 0.15792887716088444, 0.14902123482897878, 0.16268591018160805, 0.2573623275384307, 0.08988617322756909, 0.13320798258064315, 0.20566348917782307, 0.10910490367677994, 0.08657384940306656, 0.12594335130415857, 0.135488839878235, 0.25769973755814135, 0.11201932502444834, 0.1537341100629419, 0.1315496684401296, 0.18832291185390204, 0.13362325873458758, 0.09486225113505498, 0.1146620609506499, 0.2022659668000415, 0.1725291632465087, 0.09786155933397822, 0.17091876215999946, 0.12741884478600696, 0.1622278121067211, 0.1467168514500372, 0.16879558155778795, 0.15670798486098647, 0.0946913419466, 0.10529804232646711, 0.2504856465384364, 0.1930384588195011, 0.1950805968954228, 0.12658752064453438, 0.20226440828992054, 0.16941485926508904, 0.2204314264236018, 0.15626391337718815, 0.1593703357502818, 0.15493212937144563, 0.18332712992560118, 0.2599443483632058, 0.16584371885983273, 0.18093916587531567, 0.17698118841508403, 0.15255185397109017, 0.16508813831023872, 0.2305128049920313, 0.1229956149472855, 0.18760209350148216, 0.1340679536224343, 0.206814278208185, 0.1295489867334254, 0.09517822050838731, 0.15876224962994456, 0.12149651374784298, 0.1901738133165054, 0.13190463767386973, 0.10363407302065752, 0.15382805111585185, 0.16788919660029933, 0.19886157213477418, 0.10296288950485177, 0.12694367731455714, 0.31359942862764, 0.14564382465323433, 0.1179543616308365, 0.12678919185418636, 0.19758432114031166, 0.21020737738581374, 0.126814944378566, 0.11441599446698092, 0.13937050971435383, 0.19195838161977008, 0.0746117572998628, 0.11715149143128656, 0.17809899640269578, 0.1361338107381016, 0.09891030305880122, 0.1065343564550858, 0.12322018141276203, 0.11585250293137506, 0.23948419780936092, 0.13704426266485825, 0.13638824864756316, 0.12669039715547115, 0.10812762135174125, 0.28002101636957377, 0.1605042038136162, 0.2474515835638158, 0.1739700132748112, 0.17022120271576568, 0.12211140536237508, 0.16246506187599152, 0.19399934710236266, 0.15274163597496226, 0.15890052658505738, 0.1565739678335376, 0.08969279180746526, 0.11071140848798677, 0.15929775370750576, 0.21082291466882452, 0.24248014407930896, 0.104769113677321, 0.1565455287345685, 0.1548949774587527, 0.10991610819473863, 0.1470925414469093, 0.18315707420697436, 0.08306727584567852, 0.11655380279989913, 0.13547877635573968, 0.15793980157468468, 0.14997965918155387, 0.11446759599493816, 0.08136577613186091, 0.12212589208502322, 0.18575046473415568, 0.10535532870562747, 0.12016313412459567, 0.2600741945207119, 0.14242049917811528, 0.0803722333512269, 0.12636374827707186, 0.11667243510601111, 0.12587087316205725, 0.09079875511815771, 0.10511465021409094, 0.1618258055532351, 0.13224126101704314, 0.1450641776318662, 0.13280478859087452, 0.16165202425327152, 0.1429491161252372, 0.07918951712781563, 0.21655737102264538, 0.13464386021951213, 0.12115228339098394, 0.20510873378952965, 0.1602778339292854, 0.11159572197357193, 0.17350749199977145, 0.1259380078408867, 0.07550343289040029, 0.258966910187155, 0.17111409542849287, 0.23128943284973502, 0.12351029436104, 0.1845117608900182, 0.1330066379159689, 0.15234629390761256, 0.14832406130153686, 0.10844911230378784, 0.05987774733512197, 0.171846060839016, 0.10034053295385092, 0.09193403326207772, 0.1434188213897869, 0.2105472661787644, 0.07573925031465478, 0.09981586423236877, 0.10617356878356077, 0.15375233720988035, 0.10263321266393177, 0.1469418260967359, 0.13357785413973033, 0.18134771817130968, 0.1827634242363274, 0.25041698303539306, 0.17418909526895732, 0.39887059363536537, 0.14623009163187817], [0.062213942874222994, 0.06176685827085748, 0.031729162074043415, 0.02501075705367839, 0.03640202070528176, 0.05148786432982888, 0.013416036399576114, 0.042409390734974295, 0.02727852657699259, 0.02236498945421772, 0.11520140935317613, 0.041932987587642856, 0.01150877253166982, 0.09397571120643988, 0.023917031758173835, 0.0682378516648896, 0.04395592259243131, 0.0772124802460894, 0.08616880004410632, 0.041419870394747704, 0.005621972277367604, 0.04911670992441941, 0.017008449540298898, 0.007556187238151324, 0.030295232572825626, 0.03186671172443312, 0.03549968416336924, 0.016304077180393506, 0.033598572699702345, 0.05984468836686574, 0.06307808478595689, 0.05848047621839214, 0.03551795583916828, 0.029525059544539545, 0.03385578253073618, 0.06418327626306564, 0.03928078927856404, 0.06615580830839463, 0.07055379770463333, 0.04066354769747704, 0.04147035870118998, 0.014555237721651793, 0.006615832789975684, 0.053968329666531645, 0.07907434322987683, 0.04858434142079204, 0.01879350395029178, 0.020001275079266634, 0.0475855145487003, 0.013131665818946203, 0.008116355202218983, 0.027404237116570584, 0.04355551536718849, 0.01811855960113462, 0.09612255889805965, 0.023912096476124134, 0.03557355754310265, 0.05736740684369579, 0.03226252876629587, 0.061235625253175385, 0.022576781702809967, 0.046633190650027245, 0.03681073256302625, 0.026873699862335343, 0.008722745515115093, 0.04087232126039453, 0.026875484727497678, 0.013461833405017387, 0.02632858682773076, 0.046163351798895746, 0.060697033841279335, 0.02242462844151305, 0.044352511467877775, 0.0167721905381768, 0.0316603798273718, 0.05931114726990927, 0.03713510675879661, 0.045429200763464905, 0.045638504961971194, 0.022656349210592452, 0.046537308880942874, 0.028123181546106935, 0.06409514622646384, 0.02809929366776487, 0.050853454231400974, 0.04484307850361802, 0.02177158858103212, 0.026201208311249502, 0.045909470500191674, 0.05309728949214332, 0.054312396750901826, 0.04892457902315073, 0.06642298147198744, 0.025436742398596834, 0.018433267323416658, 0.006813482486904832, 0.034813820966519415, 0.045995837936061434, 0.03459192252194043, 0.02815949854266364, 0.037222557730274275, 0.07426671058055945, 0.04110551890335046, 0.05500314699020237, 0.07678042413317598, 0.021811232254549395, 0.1261949838954024, 0.06341055952361785, 0.03521183105476666, 0.09700889844680205, 0.022854285562061705, 0.0578398543439107, 0.0151180064494838, 0.013876464818167733, 0.030168657431204338, 0.044780270545743406, 0.04631858682841994, 0.07623005483765155, 0.02180347866669763, 0.011923866859433474, 0.04916315352602396, 0.021021678039687686, 0.042734351227409206, 0.02232919567177305, 0.045233689379529096, 0.0605210706271464, 0.01035765788401477, 0.028492678320617415, 0.024440336783300154, 0.035828863765345886, 0.029910620105511043, 0.029282546092872508, 0.0264430222887313, 0.048849213926587254, 0.01914310374559136, 0.015741970819362905, 0.04508723024628125, 0.034527797251939774, 0.06557883301866241, 0.02363273724768078, 0.051849138108082116, 0.08080033381702378, 0.044019083070452325, 0.043641266820486635, 0.03886379876348656, 0.13638214819366112, 0.040855333500076085, 0.05076718698546756, 0.07622229939443059, 0.0510495148046175, 0.03390162128198426, 0.032879112477530725, 0.07235942073748447, 0.04115854164410848, 0.10380366118624806, 0.022232701630855445, 0.008298831689899089, 0.04622719876351766, 0.015125203426578082, 0.042283307266188785, 0.00549430525097705, 0.020599002673407085, 0.06175088354211766, 0.01517337623226922, 0.03502915882563684, 0.045417712317430414, 0.019633149422588758, 0.02953890616481658, 0.012660861248150468, 0.0369128595048096, 0.019882154811057262, 0.0712415533780586, 0.0270913328131428, 0.014457369779847795, 0.03746525486349128, 0.02623574786412064, 0.08026005772990175, 0.00296636148050311, 0.05405886426160578, 0.04987905515008606, 0.020640646434912924, 0.03702012210851535, 0.053295665566110983, 0.07508314723963849, 0.05050036634202115, 0.029776940755255055, 0.027988583788101096, 0.03934193853638135, 0.018150264149880968, 0.025113917436101474, 0.0015733029795228504, 0.02152130113245221, 0.08008307035197504, 0.10043733127531596, 0.0642182314186357, 0.03948542907892261, 0.07690434053074569, 0.013676296457560966, 0.020180720821372233, 0.1099679694743827, 0.09011163769173436, 0.039496995450463146, 0.021098393845022656, 0.060370811697794124, 0.03907036443706602, 0.04631149560736958, 0.07475483595044352, 0.03530389818479307, 0.0472582496877294, 0.06688346926239319, 0.03632930136518553, 0.03312084110802971, 0.029571215563919395, 0.020249447406968102, 0.03309713320049923, 0.011153606628795387, 0.05510578601388261, 0.030391314721782692, 0.029777914824080653, 0.005843818307766924, 0.018595051806187257, 0.031920873661874793, 0.04805639611731749, 0.009840219536272343, 0.05385635813581757, 0.03349878352310043, 0.0699635008641053, 0.059349219445721246, 0.04074082382430788, 0.04056179925100878, 0.042788112405105494, 0.013731688504776685, 0.012868935336882714, 0.0363744573405711, 0.11267969544860534, 0.022335986323014367, 0.010520806063141208, 0.005843439812451834, 0.05578922980930656, 0.04205991710477974, 0.039584060505148955, 0.01009683750453405, 0.019522688162396662, 0.021106472122482955, 0.04726610903162509, 0.018083073809975758, 0.04646176195819862, 0.02479335973475827, 0.008720466194063192, 0.014228143554646522, 0.05601528057013638, 0.0378117042419035, 0.05567824162426405, 0.013175391304685036, 0.0718126879655756, 0.04144255042774603, 0.07384086624369957, 0.021698364580515772, 0.07618983785505407, 0.03734719401109032, 0.03880232667142991, 0.05291531859256793, 0.06961850609513931, 0.03004595073434757, 0.053320512670325115, 0.03381682348845061, 0.03503332227410283, 0.059173786867177114, 0.017436455382267013, 0.04774897999595851, 0.04499664741160814, 0.02880911710235523, 0.06814561013015918, 0.029930294440418947, 0.05337384711310733, 0.023493172666348983, 0.010358235831517959, 0.03499705722788349, 0.09108883838052861, 0.07666006262297742, 0.08297862630570307, 0.009187964496959466, 0.04153351175773423, 0.09084755132789724, 0.02897263635531999, 0.07875481154769659, 0.047579492020304315, 0.015548370465694461, 0.04538113556918688, 0.017814846796682104, 0.04182100863545202, 0.02486236277036369, 0.03213538402633276, 0.01233931927345111, 0.01888869552203687, 0.038981985780992545, 0.04471867599932011, 0.02248870918265311, 0.034881378669524565, 0.05097294742881786, 0.01566469840327045, 0.06217383350303862, 0.0688095651275944, 0.04411407055158634, 0.03104452342086006, 0.06844119270681404, 0.04843316593905911, 0.02569387615949381, 0.025301549067080487, 0.06303026078967378, 0.02895287296269089, 0.018043958916678093, 0.023988799293874763, 0.03446157912549097, 0.07944422221044078, 0.04012932382465806, 0.07190979798906483, 0.10515206929994747, 0.0014145556201583531, 0.006929439350642497, 0.08293583407066762, 0.05146754061570391, 0.02221094000560697, 0.048138440542970784, 0.10545050172368065, 0.03894343491992913, 0.021177712733333465, 0.018046886689262465, 0.04678473349486012, 0.05553975686780177, 0.07625142126926221, 0.018224185769213364, 0.06880320492200553, 0.016896583765628748, 0.015094154750840971, 0.034738893737085164, 0.003437386608311499, 0.009288414184993599, 0.026419076893944293, 0.03510064991132822, 0.04162777564488351, 0.04296210521715693, 0.05153002573933918, 0.05311886743584182, 0.027606082730926573, 0.043315022412571125, 0.025558456472936086, 0.07229165523312986, 0.03473915348877199, 0.03913627086149063, 0.03626367324613966, 0.07387228877632879, 0.1359838226926513, 0.1736317275208421, 0.1387370569864288, 0.09193034478812478, 0.10827001722645946, 0.10310215351637453, 0.13644074817420915, 0.12662584515055642, 0.16452823241706938, 0.12520887743448839, 0.17912437731865793, 0.14061719906749204, 0.06194855086505413, 0.19448851147899404, 0.15661992161767557, 0.18311570689547807, 0.2447334973840043, 0.2358279627515003, 0.16191554605029523, 0.12406590321916156, 0.17532518977532163, 0.13135475077433512, 0.13827772694639862, 0.15031283895950764, 0.1739923222339712, 0.08449182088952512, 0.08818359739962034, 0.16501886624610052, 0.1263193678460084, 0.11446700227679685, 0.12896000349428505, 0.17648335575358942, 0.12170981441158801, 0.17025764216668904, 0.12773635040502995, 0.12457169912522659, 0.10505101847229525, 0.16144045279361308, 0.18155381258111447, 0.10904091570409946, 0.1246689204708673, 0.17055885022273287, 0.22961171896895394, 0.13923169841291383, 0.22134840924991295, 0.14338965498609468, 0.11276280856691301, 0.18707064155023545, 0.08361912201507948, 0.08259646478109062, 0.18132793251425028, 0.12894927203888074, 0.10448823304614052, 0.1592033525230363, 0.1679853640962392, 0.06067538539355155, 0.10635812606778927, 0.21476983412867412, 0.23258418368641287, 0.09191398043185472, 0.19128409592667595, 0.15674308844609186, 0.1961339864647016, 0.14217622869182378, 0.14752441202290356, 0.1019529601035174, 0.10839644950465299, 0.11201571076526307, 0.20216261531459168, 0.17879084130981937, 0.17835279606515542, 0.18452317512128502, 0.1453851565020159, 0.11758541033486836, 0.14275286259362474, 0.1015203473798465, 0.17110746062826365, 0.07112690640497021, 0.14434886601520702, 0.12561109178932384, 0.12906504707643762, 0.0996137032052502, 0.13673260516952723, 0.13152593455743045, 0.09728596443892457, 0.09120701797655784, 0.15678261523135006, 0.11032519483705983, 0.17264815920498222, 0.16933429171331227, 0.11834902834380046, 0.19989777356386185, 0.1945161639014259, 0.1327585379476659, 0.13682271674042568, 0.118431636801688, 0.19999909156467766, 0.12865389726357535, 0.13456154119921848, 0.15869990922510624, 0.15888212132267654, 0.15700307762017474, 0.15532148972852156, 0.27448803826700896, 0.1764583305339329, 0.16033913532737643, 0.25178241601679474, 0.1411850904696621, 0.11094923713244498, 0.17380804696585983, 0.09022491911309771, 0.1819826106657274, 0.1245635948725976, 0.07114267704309896, 0.10323778100428171, 0.1116911176359281, 0.15415241417940706, 0.1396827312419191, 0.20740458247018978, 0.13989353086799383, 0.22216441546333954, 0.10822547352290712, 0.09687971280072816, 0.20185576693620533, 0.08759014643146656, 0.20355817949166521, 0.12074532671249472, 0.14537593902787194, 0.1114590406359639, 0.2071802015416324, 0.12034331273753196, 0.21314096840796992, 0.07717679778579623, 0.22667401644866914, 0.07622781355166808, 0.09716457876493223, 0.09583460559952073, 0.11797065919381566, 0.1285135274520144, 0.10535013367189094, 0.10551661223871633, 0.1743721979437396, 0.08376797457458451, 0.11045510778785683, 0.121881295053754, 0.2689953736262396, 0.13788979151286185, 0.17983173311222345, 0.23096397140761837, 0.1521549088647589, 0.09853420488070697, 0.1076968120469246, 0.1630289011518471, 0.16553108172956854, 0.2916052291402593, 0.0667246051307302, 0.12969186500413343, 0.09450538200326264, 0.0921368102717679, 0.09597599957487546, 0.09885744730127044, 0.09520045525277965, 0.16201557271415368, 0.11996446119155735, 0.12290827900869772, 0.11602528233197518, 0.12123743741540238, 0.18339873233344406, 0.17674779781373218, 0.11560519706108607, 0.15762762457598, 0.25116907549090683, 0.0632142614631448, 0.0778903579339385, 0.22920898511074483, 0.08176989780622534], [0.04919358158076648, 0.042631229807739146, 0.01580265994562069, 0.034374862880213186, 0.014598719226341927, 0.008782240711298073, 0.02570720884250477, 0.003305772515886929, 0.029097940569045022, 0.027535209483176004, 0.04599947074893862, 0.05007554245821666, 0.009112072475545574, 0.04623302462277934, 0.06501049632788636, 0.03828679378784727, 0.011059311200369848, 0.03255102383263875, 0.025002272450365126, 0.034440134768374264, 0.05199282903049607, 0.030058326046855655, 0.04426032930496149, 0.08990023692604154, 0.03472413984127343, 0.02523146064049797, 0.016218761738855392, 0.044004956289427355, 0.03865633509121835, 0.04325249647081364, 0.06979067693464458, 0.045815566554665565, 0.035453132950351574, 0.022576137889700476, 0.026042019489977974, 0.03245077452447731, 0.046232341846916825, 0.0740244884218555, 0.05401404596341308, 0.04365956447145436, 0.0706155072839465, 0.07739089996903203, 0.04853916689171456, 0.01990618369745789, 0.025250344588130247, 0.08623600151622668, 0.051704716170206666, 0.08005981144378893, 0.022217713958525565, 0.029815521302225534, 0.05668190729920752, 0.03488574620860163, 0.05699800654838327, 0.04700194898759946, 0.0232188656082144, 0.020094514802622143, 0.04521278307947796, 0.0414131650904892, 0.13237713341368362, 0.014605715823563514, 0.059661288833012804, 0.023660643855691887, 0.025202418546541594, 0.058235979377059266, 0.02427041094051674, 0.03795546195760835, 0.032041268568718806, 0.03829633038549218, 0.034074552822858095, 0.03769066737731919, 0.0258470981134451, 0.03645761127700098, 0.04606372218404431, 0.016994781035464257, 0.0369266486086417, 0.026221652624371927, 0.030732951272511855, 0.025784228928387165, 0.05658479356497992, 0.06624605346587487, 0.046737907687202096, 0.08733517417567782, 0.023127972926886287, 0.07063138924422674, 0.057406454943702556, 0.034796410182025284, 0.05529612833925057, 0.05766616581240669, 0.01478468195273308, 0.04137296295084525, 0.02770661962131271, 0.007368781034529093, 0.03440901651629247, 0.02554835213231854, 0.06639055703999475, 0.006853755594420363, 0.05640498231514357, 0.012470329675124958, 0.039288307234528475, 0.027217308670515195, 0.023981212689250242, 0.041004620215971954, 0.059896108068642206, 0.0769930420210585, 0.045784270187141374, 0.07305378894670866, 0.02112778660375625, 0.010157478391192853, 0.04226267927151639, 0.03987176147347782, 0.038575192374992184, 0.07673494532355107, 0.028124515556555707, 0.04074884644069243, 0.047599277677363716, 0.052620366841438226, 0.03386725984455552, 0.025772421358851716, 0.017558547951921355, 0.0947980850469321, 0.07542678387835622, 0.04775184468599036, 0.027300431065668818, 0.04285602262825705, 0.03445698523137253, 0.024302195270138327, 0.053113260510144755, 0.02379511915933108, 0.049952494373428635, 0.00681589956911921, 0.049923895712709054, 0.04673811919928994, 0.044828113095718436, 0.01758175862050848, 0.005279770302877296, 0.08530076185707003, 0.0747111086093355, 0.032126704609254375, 0.02363868370593991, 0.02853306599718053, 0.013368295894906623, 0.03569816784875002, 0.04501833667745814, 0.032106425423990004, 0.0523611643438926, 0.054079759429441765, 0.003925990895368159, 0.04340482970292214, 0.05947706180450041, 0.1286056131357327, 0.06518701615277678, 0.08254918997408822, 0.06836572370957583, 0.026157787106058095, 0.015208424156298861, 0.011159967762068845, 0.04927634588966612, 0.06029204014339484, 0.06133744420367293, 0.02867773098842008, 0.013162389805074781, 0.019240093170083128, 0.046478337826556526, 0.04553015882265754, 0.02955980318802176, 0.028187729840283282, 0.007344563364313217, 0.03076353888900485, 0.10272059313138016, 0.04864778762566857, 0.03007167913892772, 0.026780476837302558, 0.04359194739663508, 0.06167026032926515, 0.037790745991514996, 0.06715793031617068, 0.027042844594689086, 0.006518282116303453, 0.021487733793037478, 0.01871444852440618, 0.021772579348180443, 0.07155562285333872, 0.007063862703944324, 0.0404836028610589, 0.041805824293987826, 0.05828456407471094, 0.0035568951125242165, 0.020244565930624958, 0.07700402580667287, 0.03881311749864835, 0.06813478219555691, 0.05734995153034106, 0.03820868645561859, 0.0785301931318827, 0.026966655714204535, 0.058965584757970646, 0.024860245794116054, 0.0022952493964112364, 0.02886928486987017, 0.026050761989608873, 0.015005933801148785, 0.09235182529664598, 0.03911532003257889, 0.04174776237050537, 0.027173599883099087, 0.036268074181862175, 0.04190268198726699, 0.0588569714454934, 0.051106277969665825, 0.04113573544600513, 0.02994185153511353, 0.029554322427429724, 0.0536428014311241, 0.02855140446627047, 0.024223676045949105, 0.040547060198150575, 0.028471812838688493, 0.04750473548483569, 0.10369685871410184, 0.014534552210534457, 0.02614466407976579, 0.010167380496568512, 0.0874661558191292, 0.03665418022137601, 0.036960086072213016, 0.06614878016989678, 0.0813986903813202, 0.06015490238496568, 0.02100877394695999, 0.027313466889609117, 0.02772273164737271, 0.020952767772541847, 0.02754952551185852, 0.017425224832550157, 0.06972263683564961, 0.03965323980082758, 0.07296508745639585, 0.02315297031600494, 0.06619338324526325, 0.018223291481263004, 0.00984888503808179, 0.04978060555004049, 0.07984324533026665, 0.022716695093549788, 0.061736667703371495, 0.01269507889446686, 0.03753767734451685, 0.031037480439408682, 0.020718349296657834, 0.04370931434095837, 0.02573256060713902, 0.04631213756510988, 0.024409797406406142, 0.04307281138608232, 0.024819564969220664, 0.002892588522627193, 0.05002661266189534, 0.024472714831063058, 0.05903780685912352, 0.05021584176574834, 0.08840915834298357, 0.02177393005695194, 0.09464686503633857, 0.017450500527047552, 0.013247021543065784, 0.02441280124912737, 0.0019776635326707037, 0.037462779800989665, 0.05943101896264125, 0.06274863801081665, 0.06176929993671365, 0.01938062625413295, 0.00789061243267497, 0.022559018398169428, 0.03786219625908416, 0.040039256782620214, 0.04422020880156197, 0.02295976515597431, 0.0151070291576616, 0.03215315104171168, 0.05048558276030235, 0.05694487248547375, 0.037455080018844455, 0.03680137779156212, 0.05536094009585213, 0.016591039711784106, 0.06300915410974994, 0.05991916659695562, 0.022630132843914907, 0.007564875468233367, 0.10092691125464626, 0.07132543832994998, 0.03740278829354793, 0.05839042401930783, 0.0528654833760811, 0.049838700870168395, 0.03888482380716596, 0.06317356950603426, 0.020373092920635827, 0.042358898717793636, 0.0061510526029451285, 0.06400285274139605, 0.04657122502976563, 0.06695731295621954, 0.01937553141033277, 0.0032322632523573702, 0.01277796751310234, 0.041592512498027645, 0.02365835247474024, 0.06694459254504181, 0.019499002519296482, 0.03448307543294504, 0.03343255797517486, 0.018352369515923783, 0.013231788034318015, 0.11308375775115564, 0.028600183977687266, 0.029330811667023227, 0.0211668161500711, 0.0319869582017418, 0.07161950692534447, 0.044166199004394, 0.07124508600099944, 0.013731529870710801, 0.051334944801055826, 0.1198135306185577, 0.015655618226446677, 0.047068237618077546, 0.04589515447150916, 0.041629211700637825, 0.05222931438765954, 0.06333210709271953, 0.038568891541217454, 0.018023099000856746, 0.04004211776191369, 0.012040062138112262, 0.03770951050682925, 0.0705449958331883, 0.056341996241826564, 0.04681292026361916, 0.04457251743588131, 0.040320679181604646, 0.06116406737419311, 0.03686754767841194, 0.029720468883169815, 0.06973103052587248, 0.09971964478609152, 0.05605150479823351, 0.025967769470298663, 0.06924969580722973, 0.02872841967473505, 0.05405601070378907, 0.222601109999232, 0.21778871276183054, 0.09853447205387056, 0.0630849199660588, 0.07431558100506663, 0.1643765374319628, 0.0719502376159653, 0.2772806806024164, 0.13720030663535, 0.1580210667452775, 0.12696735182544217, 0.09495680074905977, 0.14747738954611123, 0.0957823361386545, 0.22969783778535202, 0.14719273138325661, 0.08978745274362154, 0.1535295890062116, 0.08944012020947412, 0.2352546833571978, 0.20913412794470787, 0.12891814636532217, 0.09744393799337558, 0.14472532784566283, 0.08849181875120848, 0.172770420613233, 0.10990407055942342, 0.125852512428537, 0.15010457747848704, 0.08686143162776716, 0.19234103296184912, 0.12544569675810635, 0.10052759127574973, 0.1173331840254832, 0.18760803068289533, 0.2541337179718539, 0.12683967273915187, 0.14166442881105468, 0.1573751459363848, 0.12434139585820958, 0.12755255011143163, 0.15464932657778263, 0.1589825635892339, 0.12856434972491115, 0.1274360774550587, 0.1730572755332105, 0.2707371348515153, 0.15257727995049208, 0.07502281805500388, 0.2057131240144372, 0.18448253511451185, 0.10419329613796435, 0.13659933028975502, 0.10169393572141416, 0.105945514224004, 0.15064437116961926, 0.18686512601561844, 0.1318002917105332, 0.17442738404497504, 0.10272404411807656, 0.18495186930522323, 0.0661035388475284, 0.09049260435858741, 0.11326124978950247, 0.08469296517432667, 0.11450507445260882, 0.12055713290465064, 0.13038075616350397, 0.11079239164246246, 0.14097478066105396, 0.11181023233802989, 0.1415802544215694, 0.07933177199447528, 0.16310522361891344, 0.20097471890039742, 0.09949982806574553, 0.08636567697976716, 0.09558722551446408, 0.09975033259252086, 0.13847221416654065, 0.11748599223210476, 0.19624429929535836, 0.11735688080079854, 0.17459908733144403, 0.22789784765336663, 0.15880821825703606, 0.17879191000247374, 0.12157846169429831, 0.11818553321063519, 0.09067259743460454, 0.1293983604409732, 0.09568465466145426, 0.1638735839514993, 0.11919562588445842, 0.39649871934670955, 0.06141251615190413, 0.12878350593382493, 0.16479904210427776, 0.17084981664083898, 0.2174073675996624, 0.16788842476671562, 0.18384684110060334, 0.15097030758624896, 0.25183997699059546, 0.17616009106859565, 0.13225254166172817, 0.0998008060560096, 0.09716176602523774, 0.15579309489112347, 0.16274008696200326, 0.20044828386744484, 0.1556238258490339, 0.13286383386002854, 0.10052416997496039, 0.1521188553306274, 0.19332638243213296, 0.09430009653442539, 0.11168156619532965, 0.1815259672002867, 0.20549001957988366, 0.22085161559516564, 0.19053869764320552, 0.17505831347079948, 0.15303163760108873, 0.13877974532078952, 0.14710631570778787, 0.12767023988999426, 0.09352021806989796, 0.14642296097008511, 0.0843091041315347, 0.09645007608924061, 0.11515021600644104, 0.09796860671485774, 0.11521729131345637, 0.060209394578123465, 0.12703485757810995, 0.1380329963285476, 0.09952186985174194, 0.06092781950428616, 0.17986888502491638, 0.16292657383019105, 0.10061704233521596, 0.09313164438935928, 0.08995375319500454, 0.15777333785081282, 0.15015617158496752, 0.10131371120223776, 0.08535204426152632, 0.16396743594668806, 0.22912253974936903, 0.13721359107876197, 0.19597763079218566, 0.17495246836915612, 0.11479867549496703, 0.10505140438908711, 0.07572696777060628, 0.17507046984974295, 0.11777368577895686, 0.24271239177323878, 0.12354663733276539, 0.11179226494277827, 0.1632740325294435, 0.12310243968386203, 0.20987376716220751, 0.14103513211011887, 0.3037559677613899, 0.10896665640757419, 0.14575217821402475, 0.179127331066411, 0.2275376091711223, 0.14334650652017444, 0.10502158489543945, 0.13557576021412387, 0.15978071372956038, 0.07124931624275632, 0.1783915510168299], [0.0072752068808767945, 0.05285923078190535, 0.017360168167215306, 0.03302767188870348, 0.04404651284858119, 0.01863281042460585, 0.05016611044993624, 0.03466674213996157, 0.06077281454054173, 0.08871770623954944, 0.05062487645773217, 0.060953356805839576, 0.026937337170238607, 0.0613503315980779, 0.025749529813765548, 0.030580885213566944, 0.028464370952860918, 0.03631685183790978, 0.01685224600805668, 0.0629748149367515, 0.03030265033885371, 0.02925166718341643, 0.02577360879513435, 0.0301768544522929, 0.05150496341229882, 0.052887094716425054, 0.06285447569098324, 0.029376071543083526, 0.08930248892283998, 0.06529075355501845, 0.0530526752845617, 0.06747505001840182, 0.06616551560000516, 0.09233966891770251, 0.1610779284965247, 0.022345313263940625, 0.012287728877709014, 0.034689722742768936, 0.023974676223588176, 0.05322974429873284, 0.03036852336663287, 0.01017370637782733, 0.006673985162706231, 0.014817714945820626, 0.019476593370200135, 0.03985540082794614, 0.022053487809898797, 0.03639050628407858, 0.008421557868132368, 0.02712921388592804, 0.027783168443420436, 0.03206270921509713, 0.00894326449270011, 0.05594002679572441, 0.03034142941032769, 0.011012498380296165, 0.024877079558791593, 0.05742336106777657, 0.00811723464721581, 0.017967680978472345, 0.05069995953817852, 0.023584852024214342, 0.028428812802303582, 0.022544099374499638, 0.049714866108843125, 0.020189940150885377, 0.09717772220028564, 0.043526716326596215, 0.057052346601267345, 0.061399580517900176, 0.01712934725219384, 0.06779215487767942, 0.05770474635937717, 0.03342464297020342, 0.02315741392521886, 0.06584441056475043, 0.018521022575441748, 0.05778421924333088, 0.00495313765895844, 0.03396856671315618, 0.0786828158015851, 0.0861561241617892, 0.015905933505564462, 0.04469668987439945, 0.027633067220449448, 0.01199540247398545, 0.05666461154760327, 0.02474525557772722, 0.03181472056894563, 0.022937040594115388, 0.012612718128366396, 0.04624577471986413, 0.07232888878206722, 0.04881922002823558, 0.05122919246787205, 0.017996507849602494, 0.013991669329698198, 0.05114865460200235, 0.026439252178533934, 0.02775862747512292, 0.0224106964742532, 0.08282301278086379, 0.006539558098666021, 0.07495342724723741, 0.03519911435432732, 0.04789860067830887, 0.056314525645575486, 0.034893690899480134, 0.025319735395896714, 0.06594897917238995, 0.04472707340028137, 0.04575562328682281, 0.02621351868583588, 0.04442621786438394, 0.012004273921775166, 0.056624082862981595, 0.032663392412359826, 0.03210699316696264, 0.0350059741322184, 0.039500676502939314, 0.045589356232085265, 0.0730337732238695, 0.06468836712883785, 0.05505047374754213, 0.026868790555454325, 0.1052304994664155, 0.05974869527562987, 0.0652669306145981, 0.06506959354737774, 0.02460678937495686, 0.019327249137859326, 0.042973289382644, 0.009971949821192538, 0.03880794101860374, 0.06876682484289631, 0.03205177366908174, 0.039515504613518715, 0.021786515026178677, 0.07575842741061933, 0.05656293360516429, 0.019621451319835614, 0.013918554795964155, 0.011698515572788892, 0.011735657280951273, 0.035797270538751036, 0.052315455468487926, 0.01138120198447723, 0.00860837963045924, 0.0387251321808435, 0.013890595309931086, 0.028456149811972864, 0.047961449454305694, 0.03535000781994313, 0.017818006490415428, 0.016294896813633386, 0.04121214326005429, 0.06682336272206157, 0.07789052120642737, 0.03635948080045637, 0.017497784610895906, 0.02485400989826303, 0.03858415009744931, 0.007891767399996752, 0.053096447154530324, 0.011172138983965851, 0.08169286287738942, 0.06209360733919311, 0.019438014678598847, 0.00697227936143463, 0.03183515931596048, 0.023244141302711796, 0.023404263374686707, 0.024469707277603447, 0.05127843025547918, 0.013490919100149767, 0.01286388780499692, 0.049333665665471926, 0.018698963613132946, 0.046664839537697844, 0.04282979884010274, 0.07299146338482387, 0.06146190607978497, 0.035645972602651455, 0.027709389687515795, 0.04688047425588593, 0.06451697554439306, 0.05025360223953612, 0.008959868191595888, 0.07102360686985776, 0.048484262806596234, 0.04829036559385713, 0.032872548181330785, 0.029844489181414247, 0.05009887558117043, 0.06983043378568254, 0.03765560089959763, 0.06494644898339175, 0.01886108762846561, 0.048949663614621386, 0.019070226699113846, 0.032187698016059585, 0.06227119214599952, 0.03474975506833289, 0.018123901209037285, 0.044703680905513465, 0.14597106724977493, 0.042613499899744056, 0.03586965591239277, 0.03622857708251104, 0.010366431924921926, 0.07629802072187886, 0.04513390391366556, 0.03363385440025013, 0.05419307424745057, 0.008116091739793774, 0.08743082958972082, 0.031518236282863654, 0.004572472489599022, 0.05922877629927825, 0.06057228252757341, 0.040479799354216084, 0.0553315992874559, 0.06611107164644636, 0.030620363759226166, 0.01690303673967719, 0.043977942113997415, 0.05862443802470807, 0.023917133803479373, 0.08336315528140403, 0.011589956066018203, 0.02696818824915681, 0.02777340549073415, 0.01019802934024483, 0.021775991372123826, 0.035707667339011095, 0.02713595258683199, 0.04596746563038323, 0.04024510257295333, 0.05925235433096532, 0.024641672171128448, 0.017952602393052075, 0.008452856091025751, 0.022389242840290535, 0.004064772974743391, 0.018826741033990402, 0.05923269854974933, 0.002266827227686008, 0.08118291094433516, 0.11842319858260453, 0.05963002215139568, 0.04866579212830402, 0.0033971190669035423, 0.028036687945132144, 0.07087740377755836, 0.0591099399025552, 0.06753610650775954, 0.041537452561897226, 0.04224823336699046, 0.016830502936500125, 0.022873221460031345, 0.02948939934867667, 0.049584270382183604, 0.057617135826149024, 0.054124080488691106, 0.08427596723777242, 0.04962641694874037, 0.018086096206388902, 0.012014351359539432, 0.06739826741977595, 0.05819618912937585, 0.03634481596236583, 0.006931404650458717, 0.051611487579066306, 0.09185760689433664, 0.03734089317731559, 0.06519923190353438, 0.04166431157500483, 0.017883781183627434, 0.05091023223940283, 0.015232081968861166, 0.0101548344900948, 0.08006439049495384, 0.08414659605477937, 0.05022852506954223, 0.060415429616114125, 0.02311086642293958, 0.023037163737171795, 0.021118771364854183, 0.04734039059258066, 0.022108544035290834, 0.02337774643820012, 0.0361482915468514, 0.019224712159484625, 0.012158947702118894, 0.018567401239124592, 0.06321570122963749, 0.055651650473009795, 0.024996123756864108, 0.04990288922272157, 0.03216630932001863, 0.032264595647575334, 0.10058164189103991, 0.006249620946618961, 0.03047726469958434, 0.06187596882227808, 0.04491242849326227, 0.03778271595365368, 0.04085086206032429, 0.016948701086221263, 0.052724197012139484, 0.011844843902508728, 0.03375384854734875, 0.01033437949445215, 0.04141305005759932, 0.009517298094579019, 0.056867633466026746, 0.026515901190578006, 0.016141602500283625, 0.025333246194350068, 0.005107746965222759, 0.020917176225339063, 0.03909009072231129, 0.026833597912627738, 0.020504273088590708, 0.032331396359950304, 0.028472859266912565, 0.02450286272505764, 0.07109188445610926, 0.008660803086968372, 0.06038646730303299, 0.015597975616401527, 0.051579582650447264, 0.02306449332536431, 0.032834505691425875, 0.07812562616891228, 0.03859829172142781, 0.04837154541746713, 0.037965555166010745, 0.03200861407094635, 0.04638701655494515, 0.016810995584819466, 0.03494846139801666, 0.005366326522562304, 0.07541502825915813, 0.01743806027661776, 0.041824897489277646, 0.05125750911247451, 0.08564123694668524, 0.0682317660539411, 0.035447648479021154, 0.05968771300103981, 0.014555743309756508, 0.10006473603425547, 0.14675989601528272, 0.12071873556124046, 0.17361859150696546, 0.15466742013813928, 0.1347985237953253, 0.1832048239884898, 0.12848479149397463, 0.1493000448681414, 0.211665460083168, 0.12983352615265176, 0.09271967821405269, 0.14661667635664344, 0.11298189056105912, 0.08763310193899088, 0.09603393904399127, 0.17688980035018176, 0.12158445082604885, 0.1844384366995655, 0.12524985882919282, 0.133297604334075, 0.08781267941230908, 0.10614143378916197, 0.06905142363393679, 0.05327838094672188, 0.11073213667259552, 0.23821430891985074, 0.10359030857216567, 0.14085121307289228, 0.1784274709643796, 0.0923588831210509, 0.17972663015825674, 0.16304662363836542, 0.16434158227639273, 0.31799893942661583, 0.18077466142131016, 0.14886496821418405, 0.23833100422052667, 0.16036384884500876, 0.2877726301085204, 0.18084740673657507, 0.21190780098550022, 0.11272923380602151, 0.14806684775976464, 0.09869369241641834, 0.10528887680266052, 0.20761363062774763, 0.1346511481096968, 0.06746863786247559, 0.1454293736605905, 0.1332407706649974, 0.1625159732066095, 0.14267610968090594, 0.09381413081428036, 0.2133141559897922, 0.09123737181653269, 0.17066983098629862, 0.09920255339238793, 0.11678132301312871, 0.14359154884004965, 0.20678984670666978, 0.17364444793201983, 0.10175807954510674, 0.1324020398897119, 0.09997107699746266, 0.11532439064467326, 0.167202205338981, 0.20227742556016892, 0.21884055866394192, 0.09815162033191882, 0.06489561186754145, 0.23724709753878415, 0.2453756332397461, 0.23891590564744547, 0.20363326999358833, 0.1592112341313623, 0.1289645305951126, 0.15001519321231171, 0.1155586050299462, 0.1762522806529887, 0.12225146347191185, 0.12145439686719328, 0.11957334194448777, 0.08071754724369384, 0.09385077064507641, 0.20948056248016655, 0.1751508444431238, 0.10957564052660018, 0.14098879240918905, 0.07252079332829453, 0.07913577821454965, 0.1291756864520721, 0.15027399495011196, 0.17254412494366989, 0.12494213471654803, 0.09033319845912047, 0.07827236360753886, 0.1724480019765906, 0.09765369861270301, 0.09898282572976314, 0.16453019168693572, 0.12767414358677343, 0.14151736482745036, 0.08820824412396178, 0.21287470066454262, 0.13434051477815956, 0.1401774914120324, 0.11754507460864261, 0.15407534956466407, 0.1790012847050093, 0.21245155774522573, 0.11684496217640117, 0.11359304917277768, 0.12486406078096479, 0.11643448771792464, 0.15330666268710047, 0.07775808495352976, 0.08291595935588703, 0.12067252202541567, 0.1424968958599493, 0.1627291477052495, 0.1029332703910768, 0.1553887579939328, 0.18162734457291663, 0.11421580755268224, 0.25615333928726614, 0.20633382664527744, 0.16097635816549882, 0.11480741057312116, 0.09028606466017663, 0.11776568542700261, 0.14808446634560823, 0.14180255733663216, 0.15031194838229567, 0.11796804683399387, 0.07347325823502615, 0.15526536852121353, 0.14493547438178211, 0.2341662347316742, 0.1323722946108319, 0.08795287852990441, 0.10865807882510126, 0.10265405959216878, 0.12679391191340983, 0.0606742684612982, 0.1056879221869167, 0.08323388057760894, 0.1002437346323859, 0.1047444817959331, 0.09815286714001559, 0.13145807257387787, 0.16703771572792903, 0.16204616404138505, 0.11234428180614486, 0.153403127042111, 0.16996804130030796, 0.1043082399701234, 0.14054990111617371, 0.2408600802300498, 0.12650175805902109, 0.24829901230987161, 0.1542343175970018, 0.1467180685722269, 0.1552445290144533, 0.06367858615703881, 0.13256047357572243, 0.1912632564199157, 0.12232624969328754, 0.06198817784024868, 0.12037954438710585, 0.11209470496396534, 0.227300864062272, 0.17538744112243876, 0.12073792007868178, 0.11596289739827625, 0.09888694024994038], [0.020158643783361185, 0.06509344617370516, 0.017847723938757554, 0.06533687061164528, 0.03775921584747266, 0.03312036984425504, 0.02624327509693103, 0.09265966073144227, 0.007097056650309241, 0.031540144482278265, 0.04586975075653754, 0.003228164046049642, 0.05553415365284309, 0.024348024744540453, 0.041645691089797765, 0.06115666816185694, 0.07196381891844794, 0.06882135785417631, 0.023420683392032515, 0.005048241100666928, 0.05035115384089295, 0.020438986357476097, 0.012608336674020393, 0.030941236873331945, 0.06098189980548341, 0.005019304762754473, 0.018372119920968544, 0.047127334837568924, 0.025485540463705547, 0.025083211075980216, 0.04707368127128575, 0.1185716652253177, 0.028573069612320978, 0.06399267789674923, 0.11981991308857687, 0.009534059499856085, 0.0506311772915069, 0.036992217355873436, 0.015511431920458563, 0.01726387821690878, 0.010859009253181284, 0.07819117265171371, 0.052059340305277146, 0.02567904804891441, 0.0397812899609562, 0.047653165020165034, 0.05939931812463328, 0.0655503939196933, 0.026394038686703425, 0.0221723576032673, 0.08784707795712166, 0.08044301939662546, 0.06782456446671858, 0.03891226100677159, 0.08778231815085746, 0.043824395470437594, 0.07304034123080783, 0.07502033186028711, 0.05317271024978254, 0.017744808465067763, 0.07839279191102833, 0.005836916798216407, 0.01859393116319552, 0.017149003033409826, 0.008638941271783551, 0.013387036979111144, 0.03570824621419888, 0.09724686809931882, 0.042641133768483996, 0.05661202667397447, 0.02425955517537659, 0.040338464750675485, 0.007452692889273749, 0.026295748648408335, 0.00079378521036233, 0.007648453356523532, 0.06144126324215904, 0.023004789400147274, 0.04633777505659964, 0.028960363088117447, 0.04683724415372126, 0.05550333968130872, 0.08234473571064882, 0.05121084657730535, 0.04482495896809269, 0.020273146037652623, 0.015171680424828082, 0.014760589983779937, 0.02323821154277539, 0.0665412649686914, 0.04338300313975196, 0.029263459909998346, 0.06815663102315739, 0.026921117532765493, 0.03767874848563224, 0.06100757069361862, 0.03528960070980247, 0.0815312602207996, 0.0921814949833788, 0.023905598973215092, 0.04276559193385765, 0.016111192999233026, 0.009141901246039197, 0.028501033048087265, 0.025115659627772402, 0.06689042318612337, 0.04866920229687821, 0.05600728021818213, 0.008315632057929179, 0.05110424448503181, 0.04991948735550977, 0.044134976851637475, 0.03505744578433223, 0.02891689549869625, 0.017541905290272553, 0.023271463469427545, 0.05278342039673589, 0.031348314150818624, 0.018870407147915103, 0.10637536615831777, 0.010816132598847616, 0.0529746384563623, 0.0637806611484848, 0.054109849806991406, 0.08905284528736956, 0.006305360875558108, 0.03362855175510049, 0.030294727912405506, 0.026390788079879712, 0.008136821779771708, 0.010955126654152991, 0.03961067021009512, 0.058335827925475314, 0.007769681787976879, 0.05427208699984476, 0.07067799611832015, 0.05688328164978884, 0.02109662938892143, 0.0483716196322348, 0.06071777315810323, 0.039507218534708954, 0.02581087945145555, 0.061694116666330956, 0.027678416154230945, 0.01535732124466449, 0.0755612610373646, 0.07484144458430819, 0.049341469348291866, 0.015494745657633757, 0.05368533020373434, 0.02323803899344057, 0.05521725288417656, 0.04725381535536144, 0.03198787475412246, 0.03279209937318228, 0.06232830783119425, 0.05063750038971193, 0.04277090942196082, 0.03996649291366339, 0.025614227015466895, 0.1001330061990302, 0.03840565615973901, 0.08022321009775624, 0.03749224677449092, 0.058386023083585314, 0.01823945545766037, 0.016216275544138625, 0.08286190131912008, 0.04086947512405459, 0.02266350536956452, 0.08534105305443518, 0.04812820261577144, 0.12869008438428864, 0.05787582995253615, 0.024262152692244854, 0.08569417434046045, 0.029589062360173557, 0.0046834606746415375, 0.049647089472273365, 0.06764047473552637, 0.012929117019666592, 0.03549892717273906, 0.07017033000010997, 0.09443576112971641, 0.035490752416080795, 0.08189140222384594, 0.045530656061600894, 0.04001297362265177, 0.027286465701763518, 0.03765635046875104, 0.07866410625865683, 0.05049724561104085, 0.07595231349114329, 0.02146794071450131, 0.067545212659752, 0.02957311546197161, 0.03301326680229977, 0.022154737162054516, 0.0402889746328583, 0.04355145210865885, 0.014868152229610132, 0.008059441752266139, 0.038263557144091465, 0.02262438676552847, 0.009757990501384484, 0.020844115497311577, 0.012946384013048373, 0.09477922707446851, 0.0241898155582021, 0.027052149271185044, 0.0768296211026609, 0.011658223447739147, 0.046694184056832455, 0.0584763461665716, 0.03360115908435546, 0.0726372362987604, 0.015971737884683535, 0.037660402595065534, 0.03450794851232786, 0.003963438275604858, 0.003941163640774903, 0.044002143549732864, 0.029765005165245384, 0.014793951377214398, 0.033501488651381806, 0.021825793191965204, 0.06297537154750898, 0.0494866037479369, 0.008528505059075542, 0.014401830230781343, 0.009080943091248628, 0.0580202518904116, 0.04050896946864668, 0.053595114732161164, 0.03710372875502799, 0.0221628414146835, 0.06315451857517473, 0.0575925076554995, 0.04583180103509221, 0.025817694222496357, 0.020668697761720978, 0.03885954625729937, 0.04956714532454498, 0.06664236774668097, 0.020741665721288882, 0.07395813299808651, 0.011904662860615645, 0.08326712879352272, 0.041682067458168603, 0.01041631630869233, 0.04015231184894219, 0.06288338976446539, 0.07876224044593982, 0.05267529690172523, 0.04855850726016797, 0.035385267256060615, 0.11533203476574272, 0.02047567628324032, 0.013076640207145829, 0.05656259221723303, 0.017764172953320667, 0.04449808744539041, 0.02523891922464827, 0.019688791944645345, 0.035070752492174506, 0.049501335379318334, 0.023953033341967966, 0.09082211792701855, 0.046697041325387545, 0.005805021610285621, 0.043562703067436814, 0.05179704676265828, 0.011920918677787995, 0.010795626130857272, 0.0723733582708519, 0.009659980623837328, 0.07474027501302771, 0.02896863989008125, 0.048674942809157073, 0.031045504911162425, 0.026895159062405583, 0.026003355451393872, 0.04886333328613546, 0.09538458951283246, 0.028853568037447985, 0.018160952931793872, 0.011084500620199833, 0.02520543166610878, 0.017673193069640547, 0.03997377338237129, 0.009864121329883346, 0.02278367948747473, 0.015666015715396497, 0.02386678464972647, 0.03587704028177541, 0.07338479423196986, 0.03260110395785887, 0.03535955554980319, 0.041068942155106924, 0.015400075444631511, 0.018821657322405372, 0.05107926750497427, 0.048778858326841146, 0.0065061336226790445, 0.13485943927662447, 0.05551432717766147, 0.0504998468386475, 0.08547236124286428, 0.03552161462721415, 0.06311916265985928, 0.042831490936805494, 0.021790643222630024, 0.02751399704720825, 0.04678750912717078, 0.022692386046401225, 0.06389259928255342, 0.06491130086942576, 0.021977311916998588, 0.05886942097276915, 0.05807353438285645, 0.0691404813551344, 0.055245202165679075, 0.01518674602266401, 0.01568249881529482, 0.00397043811972253, 0.05799623599159531, 0.02801612859911984, 0.05962798495602328, 0.05974208273983095, 0.046892667742213234, 0.03359195645316504, 0.008654044904687908, 0.07602728524943814, 0.018241238467453513, 0.01907555717480136, 0.018084955154336058, 0.04604658228345215, 0.04101913291378878, 0.03932867635739967, 0.014500930137728574, 0.062454383878502995, 0.04177761897153687, 0.033650901532382704, 0.06785168996430002, 0.032883368694456294, 0.020492860712693073, 0.06930873365490697, 0.03142530084005557, 0.02537470998504432, 0.029325867108127568, 0.04496951078181155, 0.018804743776854593, 0.09446823751204647, 0.17522330774227157, 0.10268161553540267, 0.1021402188052889, 0.10258075766614638, 0.18463731743395329, 0.1387770735891536, 0.21738088777055964, 0.13346734835067764, 0.2258645262918435, 0.19228007295168936, 0.09982629140722565, 0.11253889519139193, 0.08900802698917687, 0.180639605387114, 0.13749315810855478, 0.2007706431322731, 0.20235603384207934, 0.10709372800192796, 0.13269267976284027, 0.1429809394176118, 0.14075281913392246, 0.15450782870175317, 0.12050081873894669, 0.09506343252724037, 0.053632114504580386, 0.10179923905525357, 0.13235402293503284, 0.16322890995070338, 0.08160854747984558, 0.11928225678275339, 0.17536723986268044, 0.10250923689454794, 0.07964844640810043, 0.2454003764432855, 0.09639189171139151, 0.20821503741899505, 0.10030301738879643, 0.19099885888863355, 0.10692955751437694, 0.15929846616927534, 0.19039016420720145, 0.19184602046152577, 0.1980890112463385, 0.19525133538991213, 0.15451900544576347, 0.20206809538649395, 0.13971678097732365, 0.11994795582722872, 0.10996175769832917, 0.2442079083994031, 0.1546951913041994, 0.16908365359995514, 0.1093382052204106, 0.1403085101628676, 0.10899036802584305, 0.1260674383956939, 0.14552684733644128, 0.13089355052215979, 0.07191072567366064, 0.17530812037875876, 0.09898773874738254, 0.1547457612468861, 0.13107426348142326, 0.07447327996487729, 0.0894457011600025, 0.13888778717955574, 0.17130341730080545, 0.11118161099147983, 0.19610781833762303, 0.1173990718962159, 0.15542979876045138, 0.1059370834263973, 0.08925260917749256, 0.15498623193707317, 0.10019199951784685, 0.1570990076288581, 0.1209928106982261, 0.24795768375042826, 0.09202910237945616, 0.217756251222454, 0.32700715761166066, 0.13358695287024602, 0.17953659582417458, 0.07998316243174486, 0.12620384513866156, 0.0899428287812043, 0.06602519773878157, 0.18986095354193822, 0.16620054346276447, 0.1319247201899998, 0.21451086911838502, 0.12503809441113845, 0.09458881424507126, 0.18677038344321772, 0.14957413484808058, 0.2020092579186894, 0.17976729985093698, 0.1894261737470515, 0.16179653524886817, 0.21198272821493447, 0.10695127275539562, 0.13913533795857802, 0.16048079647589475, 0.08674008306115866, 0.13353918824577704, 0.13458046596497297, 0.1708445028634742, 0.14406972943106666, 0.179741398897022, 0.3052081726491451, 0.08664418273838237, 0.08599875174695626, 0.10945474467007443, 0.07281245736521669, 0.09609396394807845, 0.18431265751132742, 0.14719154394697398, 0.0955333752790466, 0.1765525684459135, 0.13573149248259142, 0.10366259375587106, 0.18155802797991782, 0.13731394428759813, 0.1447603275300935, 0.19621906627435237, 0.11996806802926585, 0.15016154473414645, 0.19810012861853465, 0.14521308214170858, 0.19300178188132122, 0.17636697215493768, 0.13671102351509035, 0.15043484803754836, 0.12463605817174539, 0.1322036044439301, 0.10960022045765072, 0.0773837159795221, 0.0856401830969844, 0.22245930042117834, 0.2469658775953576, 0.13154572021448985, 0.16891977254999802, 0.1083712610125076, 0.21206626435741782, 0.1931185959256254, 0.1436406938591972, 0.17308745125774294, 0.1916536409407854, 0.13512054167222232, 0.1715924244490452, 0.19031421281397343, 0.1668056906783022, 0.15698658709879965, 0.09503293025773019, 0.1897142903180793, 0.1451773996814154, 0.16443429136415944, 0.12388482660753652, 0.08962026913650334, 0.18878792674513534, 0.1447825919603929, 0.23737519222777337, 0.15822247078176588, 0.1455793617060408, 0.0797881260223221, 0.16326457756804302, 0.231126724393107, 0.1410174393095076, 0.1154258570750244, 0.21726843755459413, 0.2171085195732303, 0.18267187289893627, 0.11255571225774474, 0.20471478695981205, 0.1319598386180587], [0.002130152847712452, 0.11491030192701146, 0.02940136950201122, 0.034958988762809895, 0.049218228305107914, 0.018824175058398396, 0.022404731462302152, 0.04175223009951878, 0.024791830910544377, 0.019959928176831454, 0.05030524458561558, 0.008149946661433205, 0.047051045767148025, 0.07054041678202339, 0.048191355672315694, 0.024524971304344945, 0.056273714944836684, 0.015533453297393862, 0.01925619591929717, 0.07664654069230892, 0.017931543952727225, 0.04423916696396191, 0.04746764294395689, 0.026450430777913425, 0.03487056557787582, 0.036133188841631636, 0.021831823141837958, 0.04188493352557998, 0.009024327428051038, 0.046925203496357426, 0.08113597010378726, 0.04086814667971339, 0.06697061224258505, 0.03274195987614803, 0.035025043616769835, 0.08426244530710392, 0.03963608876802027, 0.025200379495800007, 0.041523852705722675, 0.03786649329413194, 0.04395521384140011, 0.07179994528996758, 0.034822689631255344, 0.02296258717251476, 0.02774248947389424, 0.04543472605291754, 0.028145143551228102, 0.0986802447005175, 0.01795971031242516, 0.03756379352125805, 0.0868960602383595, 0.012673337678279495, 0.07601500270538963, 0.028823371903854422, 0.013231281518528704, 0.04193733286228962, 0.10110168703249656, 0.042032286946778186, 0.052916669301339425, 0.035652421865961514, 0.02779430622467771, 0.0517102414596593, 0.04625410532753449, 0.0442537761409767, 0.05396601416578051, 0.06363415377563797, 0.03566796985978726, 0.03438993589952588, 0.00814250477560563, 0.035972009209217504, 0.03763749620702583, 0.021116246207384393, 0.038243726958171465, 0.0061457852098101284, 0.04771158317453228, 0.03650268190540373, 0.04453797788301017, 0.021376404220063705, 0.019493106156005524, 0.08315482700709254, 0.016586664751230273, 0.008751282020966755, 0.010723362283897586, 0.014690259431517916, 0.04006531729828566, 0.04681499456637539, 0.01622670271899551, 0.06114712043199688, 0.08410031572566368, 0.05002226367651019, 0.07347541788476519, 0.013170708352845395, 0.04722316465631593, 0.02027446334977867, 0.1321650721365586, 0.06648895840044133, 0.0546828694496071, 0.025905939291988034, 0.00041042784232558915, 0.021026631875429302, 0.04910929215839133, 0.05052409280324355, 0.027520210678630974, 0.08146232212311588, 0.0576005859329598, 0.018626691417011898, 0.03846097213681787, 0.01753538366756402, 0.07655394292669371, 0.05974432402581442, 0.030624922401329968, 0.06910488795256242, 0.0663909874856472, 0.030795803759247065, 0.01696776871540351, 0.0628733188204933, 0.14672596502350643, 0.03467767768597696, 0.073572000983404, 0.022382129354809877, 0.048555000612395816, 0.010153749099117704, 0.05955474240181502, 0.026133619066968095, 0.026186374634562526, 0.03290505424956791, 0.03068124584387988, 0.04026761191198602, 0.016735871686250903, 0.03621699215727858, 0.05408726254245266, 0.03224210115149617, 0.0563158726436086, 0.01632037659874186, 0.045267850437085144, 0.035247272317064926, 0.044106860586907715, 0.030841742700431496, 0.06693370523862541, 0.11010099202394485, 0.035098523658234626, 0.018834470502042677, 0.037659233712474816, 0.045838138976250775, 0.05080880662717391, 0.05650628176226746, 0.01130733880927437, 0.046626763651147485, 0.054161514417501166, 0.0050480360823712545, 0.021016581340518314, 0.073161541367881, 0.03217175297322683, 0.08013397426111624, 0.07682657829718664, 0.029974678582220804, 0.04033519930089824, 0.024082328454824165, 0.017071318725356832, 0.023676492419326678, 0.022561838559340686, 0.005722319920096197, 0.0288650954462355, 0.06800814953749068, 0.040569999982835725, 0.04522610834101215, 0.06077857360651251, 0.05731317440222483, 0.10846494973520748, 0.052634812745964155, 0.06073820077290293, 0.08145711966790259, 0.044885065508424304, 0.014086266255617375, 0.042007692172774114, 0.027599303211900406, 0.05541830068978015, 0.10527031568926759, 0.01763902273523854, 0.07969368030899204, 0.041922968594008125, 0.047875130258034915, 0.05421186542662326, 0.012141374572820496, 0.009024675309774466, 0.049761309710447676, 0.03971128317061812, 0.008344153720827308, 0.05577306212217081, 0.06512783729704097, 0.02929766178567661, 0.0368739078840008, 0.043481330285430886, 0.046026822601561435, 0.04937344849167857, 0.01544161530546262, 0.03339406648592558, 0.002896504743148398, 0.033828467785497196, 0.018408581636322197, 0.036648781097028404, 0.023918744263937697, 0.037833308160770684, 0.025091003626585007, 0.05684589967131615, 0.06184180034324527, 0.056741687294561416, 0.05131767873535864, 0.021107125212438405, 0.07977269677212462, 0.01827097818022594, 0.051383945101406425, 0.031116641621338204, 0.0781819700205233, 0.01797080913092941, 0.034291330448468216, 0.04775191890075803, 0.018475000142643694, 0.02092322287353454, 0.055945681961020455, 0.08797949194558896, 0.03475246761809103, 0.013504430826287717, 0.0976503144192975, 0.043623997044051066, 0.04182703487458639, 0.025318486732430756, 0.048405906854895875, 0.06267956632655114, 0.04275569168385118, 0.026681737799663097, 0.048958532279357314, 0.043582900616456755, 0.06866788171464577, 0.06818302179453894, 0.08544874610379338, 0.04524571217189077, 0.0661864664289169, 0.03882383411109913, 0.0387333217804553, 0.039710626369924285, 0.01419867750882986, 0.018334782471356448, 0.03095137646596413, 0.029065694252494723, 0.02286179795191856, 0.07444843286066316, 0.027609576391114388, 0.025030629913089797, 0.06903203131514601, 0.017052206567313988, 0.011349319320288487, 0.041360402101418, 0.014824349746049847, 0.00845950016810093, 0.030913773698557634, 0.025569918943801895, 0.038126642029965296, 0.035359388566575944, 0.043603959056781605, 0.05520854007045273, 0.03978161279519554, 0.03020863136043772, 0.03905218552972656, 0.02504111274902243, 0.08729395529371686, 0.07997831620741636, 0.007049956711853156, 0.05319092997524422, 0.03656960507214535, 0.034563075241749175, 0.05210329400142655, 0.024696049331396352, 0.019496534878271632, 0.058681342197814956, 0.0735014004749246, 0.0846941971394699, 0.021425096529128496, 0.013246027992863674, 0.015104675621842034, 0.07070976003888063, 0.016789480723673478, 0.013303951691341354, 0.04573785998218227, 0.021573526064457837, 0.021188945138419513, 0.047074961476027966, 0.0743203901220113, 0.040993376678670757, 0.03168325652950443, 0.032397284230683, 0.03593534340325277, 0.09159165827441029, 0.05436065490357578, 0.05145944007381331, 0.013004093416384421, 0.03636358858784661, 0.014383641118911328, 0.040782911019050516, 0.06893494355608709, 0.0146969025809085, 0.008919048214011127, 0.06244835021789186, 0.03621723335527349, 0.02965979088912718, 0.038850796336191706, 0.05569475069933105, 0.03534785188094247, 0.0246031732604024, 0.02360263573791599, 0.0036170350495012826, 0.031911960468278266, 0.013264439749036683, 0.022033290260878857, 0.10161397673073225, 0.00537726485163148, 0.022634941960859578, 0.04521820075751748, 0.05953860811132472, 0.04379268350021448, 0.00270834317234403, 0.11915756113012321, 0.0007469516333458159, 0.05749308213125914, 0.0505982890172163, 0.00951227375480812, 0.07566340282210149, 0.04441109289473388, 0.02309153162059374, 0.04463788209250197, 0.03608295286539942, 0.0114103563282697, 0.08345504058524966, 0.0744766418938525, 0.018717302082222886, 0.059202225966146216, 0.08802422860753722, 0.002227093568762939, 0.02296281909366371, 0.0660266078193672, 0.06522453171783127, 0.03673513368994463, 0.026246091547363903, 0.08515747540513985, 0.11110785635537468, 0.06201436452101916, 0.05975455824227538, 0.053735911278636195, 0.08515311157680117, 0.010207880422967719, 0.01929800295329187, 0.06406382017303258, 0.17554639431182295, 0.22919663577340543, 0.09246258341590874, 0.13330781628610566, 0.2572480367962271, 0.1560279549448751, 0.10337461077142507, 0.10870535363210365, 0.15791027894010767, 0.1282634978997521, 0.22760328924050555, 0.20155292615527287, 0.1984443367109634, 0.18784658663207665, 0.14845055295154452, 0.11633846865152009, 0.12965906207682565, 0.22826335538411513, 0.10637302839313634, 0.13047480111708865, 0.21867238800041378, 0.06886721515911631, 0.11319030789309181, 0.15663488331483677, 0.12035605541313998, 0.12458663113648072, 0.17429483646992594, 0.08560796646634117, 0.17335845390334725, 0.15978046139935032, 0.1854221979738213, 0.15300325787393376, 0.14349977485835552, 0.21982675418257713, 0.11536092657479458, 0.22288440261036158, 0.16320312774041668, 0.12590719386935234, 0.1151231573021505, 0.1345060730818659, 0.13251446041977033, 0.20110925543121994, 0.11664268240565434, 0.16586130775976926, 0.32892887480556965, 0.1592938500107266, 0.1135789483669214, 0.19379025441594422, 0.09050425607711077, 0.14501188590656966, 0.13438188208965585, 0.08285715157398954, 0.1195065412321128, 0.14495977229671553, 0.1389219259726815, 0.11861102131661028, 0.1572651299647987, 0.1775909963180311, 0.21764724457170814, 0.21231026767054573, 0.09997351866331883, 0.16280861687846482, 0.09895313982269727, 0.137157722201664, 0.1223349550855346, 0.13646369538037106, 0.1162612927146256, 0.10926686998573132, 0.1333940093172714, 0.11882311970111914, 0.17174514359794557, 0.09512648539384827, 0.19160761294187978, 0.2934291015844792, 0.16273416462354362, 0.0778323739359621, 0.12330140205449425, 0.13184651266783476, 0.12329153891187161, 0.2383294011815451, 0.0734491903858725, 0.12037921042065136, 0.20471316907787696, 0.11756741325370967, 0.156611772836186, 0.0986383281997405, 0.0869319133926183, 0.184804612363223, 0.24140790395904332, 0.15937110758386552, 0.11528018832905218, 0.12944520480232313, 0.16427839582320303, 0.12839601578889415, 0.18658517306903377, 0.12250694780959748, 0.09257962752599269, 0.1368882632232271, 0.1513248315313831, 0.10130737326107919, 0.1661960015189834, 0.10568333571427502, 0.15942060883389786, 0.11778138927184045, 0.16055340820457786, 0.09255587880034, 0.1636657677590847, 0.11817673133919016, 0.23111105023417622, 0.0905204274749849, 0.18890322680817917, 0.14818100491538644, 0.11419892369303852, 0.08776864779065363, 0.17547623167047277, 0.1341414262424223, 0.3819022182142362, 0.13423441734630615, 0.17304611363215372, 0.09299209094024263, 0.16294368775561452, 0.04447906991117634, 0.1211251356289722, 0.16555230715312064, 0.08724199753487483, 0.11920811622985639, 0.08234273933339864, 0.13541665859520435, 0.13665896927705035, 0.1559403518331237, 0.15749366692034528, 0.22925707628019154, 0.09175275627058, 0.1783300715032965, 0.13035308889811859, 0.06495358102256432, 0.10752191010396928, 0.14198107353877276, 0.22867545514600351, 0.14453406154643744, 0.09713400228065439, 0.15736172790639102, 0.11249972463701852, 0.1284760341513902, 0.17978536372538656, 0.28060680837370455, 0.1419329972122796, 0.1905499040731229, 0.11063939789892174, 0.13690337334992364, 0.13848681963281706, 0.13181059272028506, 0.11969412647886202, 0.12199755248730071, 0.14029179699718952, 0.07252118666656315, 0.19398846721742302, 0.11997534107649699, 0.13185154442908242, 0.2021570343640633, 0.1396517243119888, 0.18360564310569316, 0.05253599207208026, 0.18061965645756572, 0.14414489414775744, 0.12701474537607282, 0.14068892021896318, 0.15865809662500396, 0.21975451352773234, 0.2403659137780778, 0.19643097912194207, 0.21608705719700083, 0.24401782953646034, 0.13350525725400075, 0.13062677811831236, 0.13960694312117994], [0.006225000197446207, 0.03141112953017, 0.024510879775334615, 0.02718125884712208, 0.0250885044442839, 0.02867832656193059, 0.04072373587405309, 0.04693788680015132, 0.0258526976176654, 0.05883131540031172, 0.022593292633246165, 0.0842419323453214, 0.04189531617157627, 0.030813602315902244, 0.03153107543766964, 0.05696963795344345, 0.03129319113213569, 0.020913114822178613, 0.022575620241696015, 0.022862877776788082, 0.01373346687614685, 0.07769296891638078, 0.05219880840741098, 0.07059975148877129, 0.0618182668404188, 0.015896127879386768, 0.06851619415101595, 0.019636589277070016, 0.058254384639440104, 0.012709611073660199, 0.05415640102000907, 0.013368277341214707, 0.06926748508703895, 0.027835072396555915, 0.019252475904067978, 0.07689160527661443, 0.04615905105310958, 0.0508518103742972, 0.05544346691749524, 0.04848595490329899, 0.050866456658695824, 0.0293085750672617, 0.03510504713631235, 0.03838814147457015, 0.0202027050909237, 0.02439765215967782, 0.02430954438750632, 0.04827029420994222, 0.004593811090671807, 0.06638354374445044, 0.017278333398280665, 0.07738294414593838, 0.0231236981562688, 0.06678083766018972, 0.03911986939783674, 0.034733294232864864, 0.09892772868624888, 0.040100665792124346, 0.042435588547959924, 0.030804167763562873, 0.08675325618241914, 0.0239263568437309, 0.04185461308225058, 0.03089332010858925, 0.0950336130335927, 0.010119212329300353, 0.01760858911438845, 0.03875924870953895, 0.03901680734998081, 0.050484773819334805, 0.018627650642883964, 0.05728797477786429, 0.04004635542514734, 0.03442605993768666, 0.014668440289824503, 0.05094438587548211, 0.071649044402875, 0.052847872211714275, 0.03522124148730654, 0.0646529221558012, 0.06636364676523954, 0.018242988080601208, 0.012104750512662577, 0.020965080002497416, 0.03996231833298225, 0.04573394144244958, 0.008759775901125977, 0.052154932636767626, 0.03355912383995019, 0.033862688214867376, 0.04172079643467441, 0.028078621144231874, 0.031599082140019163, 0.04271395329851657, 0.017009835501085036, 0.02158218136173673, 0.006608649264308042, 0.020644995420298073, 0.03553607537469361, 0.004858121419601957, 0.034510538607719354, 0.03927799509256147, 0.09996007094741799, 0.007403286726912484, 0.09265097018214874, 0.07186367351096123, 0.07993739418452606, 0.024912967965065036, 0.014441904349951074, 0.09765697148395702, 0.02488977956090821, 0.04380026824946981, 0.02082364706438966, 0.012250258769199718, 0.048889609024627134, 0.03855020797345787, 0.011732621896953788, 0.06534697866300121, 0.08555381937185302, 0.01257029696716927, 0.044946014386368915, 0.06846882286481559, 0.04793285079358611, 0.0014029034377927019, 0.02558270800363971, 0.0739971996517852, 0.010092732500197599, 0.09596023635822348, 0.06406246946426108, 0.009331933724752162, 0.04992133530322462, 0.060912549815839157, 0.01273660298465984, 0.022793833923060447, 0.0480615058040712, 0.027096917474409565, 0.0666721946618054, 0.03090679008892039, 0.05875312643183861, 0.012426883422449464, 0.02609360988572007, 0.0668346656311769, 0.0621894186042482, 0.019453753775451332, 0.01790455760783516, 0.0243571772807627, 0.024507436210114975, 0.05744157708249986, 0.04843820883252192, 0.0596986930759158, 0.03340004448546097, 0.012749028392136097, 0.03544931088981684, 0.021509742182388436, 0.05703148111933842, 0.03084265368670458, 0.027246467652730644, 0.06061689302441664, 0.038087438078946434, 0.01793852756236447, 0.0376852422778029, 0.07133925711968914, 0.0073634950877021765, 0.05356233406928368, 0.03581179436878301, 0.007847522410884267, 0.046081492910161614, 0.029565053882834036, 0.019723491059266962, 0.03576141367375385, 0.0831018525059335, 0.05853488306456711, 0.010604730905470205, 0.03786427798331715, 0.03237420714867767, 0.023428232889273204, 0.03564743834431283, 0.03755534045922104, 0.01803453178581549, 0.035909123325836845, 0.006031535749571049, 0.011675745554384775, 0.07601082441397011, 0.028173378559586126, 0.03345323049870785, 0.027396609693823848, 0.009379690000059782, 0.024010399502003565, 0.04503928008489311, 0.01126209655922139, 0.03774082171730697, 0.03226295179047156, 0.07618249801453203, 0.10116691439179704, 0.02564731938036857, 0.027430377413111273, 0.07084124634275213, 0.07873629496316426, 0.049956498260144144, 0.07564279338112101, 0.03902758333424572, 0.05307006751536392, 0.06470519161666743, 0.006371452373059583, 0.017358229306410067, 0.038151771150296554, 0.09167505340883508, 0.025946200803446118, 0.03693035563628655, 0.047559238810208626, 0.04216578818159178, 0.020444036672415677, 0.03562961566785816, 0.04307471128413454, 0.01925797336298274, 0.11224182831938379, 0.015378241459984565, 0.0220548811921617, 0.08650176459923387, 0.05894206609809771, 0.008542938903701724, 0.06250971098779701, 0.02808684228511993, 0.02493766849511303, 0.0039524461408291245, 0.005554263825615635, 0.029916000676166732, 0.083007325156359, 0.03628034930443391, 0.013684936911886325, 0.03496732308121864, 0.05523528336198069, 0.054533694055862725, 0.024232296091213357, 0.01804073985113064, 0.0042564548766677035, 0.01710093598376261, 0.03248002627515234, 0.08544209646061063, 0.04923110085655935, 0.043871217567357235, 0.018842545068764593, 0.042803515680134296, 0.039791312665329315, 0.05203689404879697, 0.03224771920940839, 0.013037713633821113, 0.013371598452067701, 0.028437180517357774, 0.024813460804580245, 0.0742042440106161, 0.05018870884669013, 0.04627684102160856, 0.043530044858925976, 0.07203558459877968, 0.08439591314527206, 0.025246177428925876, 0.03607573176850565, 0.019980311262770556, 0.022487213755084667, 0.03929310892999638, 0.04155193928454537, 0.02917099202022655, 0.01973998900211882, 0.03733508216100745, 0.01811362617445411, 0.030532703131029848, 0.03538023178407457, 0.027681471947289538, 0.05588847350736614, 0.017437561182305217, 0.04765897974721156, 0.08372425465495326, 0.07860549143515527, 0.028321529789536726, 0.019064938896917738, 0.04329883617174346, 0.040825001924531534, 0.10788860527100042, 0.0349427654145984, 0.09296344403992407, 0.02435433114442276, 0.03553586015186738, 0.012888951987406472, 0.009315528550359886, 0.020838417658524122, 0.0024155097889888566, 0.020749170689668972, 0.09439500237931497, 0.03959220557590015, 0.05071757441328373, 0.06287925600190647, 0.017351581518596504, 0.050952653400599957, 0.059775219633593224, 0.06721043726429343, 0.07016340576228686, 0.04650678805774078, 0.048735134696471505, 0.029366674098127987, 0.050981890308321454, 0.08946649613790214, 0.012065823011653265, 0.017098188181989826, 0.05861726887815166, 0.034553160148789175, 0.03788429370615631, 0.07583630838780664, 0.007368319975284976, 0.011427239260228816, 0.015891858674876858, 0.04075837932759896, 0.0033726295851010946, 0.060215673147467896, 0.08058560080826283, 0.013235096157586668, 0.014750900318176718, 0.022592361237911973, 0.021682371298084036, 0.03299851290648803, 0.04885580790869426, 0.05013588277506642, 0.025724372862896416, 0.013915327381255338, 0.048987405534717254, 0.028618991855182685, 0.05186875307117589, 0.01162180255050771, 0.01734932724502869, 0.03285193131887354, 0.03892881461069919, 0.08028912023291923, 0.06104638501710724, 0.029726261345786043, 0.003162358507324825, 0.018619503716763575, 0.022295941889751703, 0.05276735289953649, 0.03304222540464252, 0.06551601763931103, 0.019953927912865765, 0.04069210925081279, 0.03978271117375698, 0.03266706975409761, 0.059787030913867056, 0.031684944915468805, 0.08592121957917698, 0.05397953238571063, 0.06027048446412664, 0.008535697397746844, 0.035182100618840195, 0.060852933092974126, 0.1364565410767682, 0.11827708454802632, 0.09358050272567198, 0.11596824828302488, 0.18589435232570395, 0.12323398535954766, 0.08903997644665651, 0.15115373680600896, 0.0960798779851757, 0.14003271324327216, 0.04654450029192958, 0.1377406346728094, 0.26421917835250497, 0.18595673725940287, 0.08768073297687806, 0.08150848370860331, 0.09251968425814994, 0.16722403932362795, 0.14873310341499746, 0.11606946238316596, 0.12690355681115761, 0.22238377947360277, 0.11706454140949063, 0.19362390943570063, 0.10701189137762412, 0.13158814137568697, 0.15583035070449114, 0.15562970365863293, 0.11151841245009564, 0.12552339961985126, 0.11173987673828378, 0.11341247722157277, 0.14940154098439962, 0.1135502198303584, 0.1316283509368077, 0.12571077706525102, 0.15998238493921235, 0.1618410344235599, 0.1020224993408192, 0.20687946846010163, 0.08695576601894572, 0.17368262400850654, 0.16285289340885356, 0.11377203292795457, 0.08956814068369567, 0.19885259214788675, 0.1641491730697453, 0.14390513591933995, 0.08983460880699567, 0.14661344059277326, 0.07626320657436736, 0.14823288103798404, 0.17779527988750488, 0.13314538984559476, 0.12409468370606191, 0.10854729101993144, 0.16432464646641165, 0.10511813830817118, 0.1582944591064006, 0.07542817911598831, 0.12816495553124696, 0.0735656259348616, 0.15237500017974526, 0.13180662965169176, 0.18749954353552312, 0.12579717789776623, 0.08602136498666368, 0.10565997290541418, 0.20366414333693683, 0.13150185928680003, 0.08974638229119591, 0.11107040016213432, 0.13809070573188365, 0.17992656474234536, 0.14132256590528414, 0.22777662525186315, 0.19161917560268193, 0.09387529120431282, 0.13769267708994448, 0.1979665717226453, 0.1673012672108598, 0.07535588651080616, 0.1353792691952549, 0.1945492933737114, 0.13897368335165083, 0.12656086269998923, 0.16321844566846266, 0.11399380149669014, 0.09357390503282659, 0.1928254624363035, 0.11671815882436931, 0.12826740159653127, 0.09796438389457762, 0.11002288840245456, 0.1209243327321019, 0.1864990987814963, 0.11363751124008559, 0.12693143187789246, 0.11943556964979507, 0.11243848261074163, 0.09835300952545367, 0.11134408196085133, 0.22364687029039487, 0.10250494728097692, 0.13709906284930184, 0.19026785827009007, 0.16816851129988208, 0.07054026835248806, 0.08696023374795914, 0.16806146391900256, 0.16818540258100256, 0.11002975326846354, 0.1230406113609206, 0.10469139597262256, 0.1706220515188761, 0.16501212754519656, 0.0644709104381036, 0.14134389522951096, 0.14954335056245327, 0.13159305439330637, 0.10014014565967955, 0.21585706563200802, 0.13925001461757347, 0.14750465605175123, 0.17565664777066559, 0.24029581050854176, 0.06425127183320001, 0.18431908451020718, 0.14125736081041396, 0.07663272932404652, 0.23381833074381575, 0.15322940511396155, 0.09619834701879881, 0.1362446727580391, 0.09064031401067041, 0.09219581101206131, 0.12747968605253845, 0.19964686827734113, 0.1965621463023126, 0.2190150969545357, 0.08530517021426931, 0.1793386650388129, 0.13259060477139428, 0.10925258364295587, 0.17284641653532162, 0.16140953492140397, 0.0900368217844516, 0.10921810346189886, 0.1398682384751737, 0.18364039045991376, 0.19463511533103883, 0.0944880157476291, 0.23890067677712068, 0.09323993857833557, 0.2102920861216262, 0.19484851247398183, 0.115476716455305, 0.13477998494636267, 0.13268824171973392, 0.20626091805752367, 0.07992619517608546, 0.20057041168911383, 0.11850147289806046, 0.16525365208508447, 0.08230137944337912, 0.11270212315139361, 0.11642688812571578, 0.13559694110881537, 0.18001461314270273, 0.08280039954115637, 0.25114393152762204, 0.14928279735613614, 0.12358980806311592, 0.08475486771203578, 0.15405811689561233, 0.11832214033347555], [0.05431412595498841, 0.03316637557873037, 0.0398283866525162, 0.018703438763623126, 0.04225378834235016, 0.10711190319852903, 0.03041747542738449, 0.008746607418288477, 0.04282958361727651, 0.05935846289503388, 0.08948548769694753, 0.0024625025798741262, 0.02009154992265394, 0.05170373653527349, 0.02714016427489696, 0.04521382950770203, 0.03500388498650864, 0.05932714426307939, 0.07026856066659093, 0.04972472554072738, 0.04553930208203383, 0.0087223679474846, 0.0291895048940205, 0.0016647987717988144, 0.03152206576487515, 0.02275981201819377, 0.033431645133532584, 0.03491456380288582, 0.03058364785829326, 0.023333878089033533, 0.03358444220793899, 0.03719361397088505, 0.08617976156529039, 0.017349781810480636, 0.05853811882843729, 0.01741762152960291, 0.014262633012549486, 0.06204951634572353, 0.044837549503427, 0.016090880417323206, 0.06189681946125347, 0.05899320749449544, 0.045461172485374846, 0.03274207490903791, 0.055467623824370094, 0.020816340620513074, 0.015718964241386857, 0.022667566772724967, 0.01648077326535713, 0.00990937378446688, 0.039879665346234106, 0.03985085517342668, 0.06526267068693414, 0.019179105329385493, 0.03688398624944966, 0.03231132868677378, 0.033543097160873, 0.06282084897975437, 0.10093185395817272, 0.12566951365442947, 0.047726819466333836, 0.0562917713978095, 0.051461521798046306, 0.050871588609879836, 0.07578602046123706, 0.038937597928452305, 0.028757701111317147, 0.03459603773080744, 0.06968674657400697, 0.04007935131085105, 0.02600612922833534, 0.018501750855648424, 0.013242441564216278, 0.0833223965310026, 0.036062669969396666, 0.06859927016193978, 0.11374205758329481, 0.04374511554487981, 0.038012481163605116, 0.0038272956908258493, 0.02648100726219127, 0.06796721267164685, 0.07592711757752113, 0.05659884242049884, 0.04326437825511675, 0.04827220895094797, 0.07169879056164064, 0.007887161445978563, 0.010132941133633722, 0.07113497355021536, 0.009602998525224393, 0.009242152409569826, 0.036084426028537564, 0.04985996711184271, 0.0329996038635727, 0.0020401866913744016, 0.06314881888101809, 0.03950348182115704, 0.021604562680295203, 0.007665530638405471, 0.030288757334346883, 0.03557437019480858, 0.021836420746694785, 0.00878220824233722, 0.0667540832364466, 0.09379410766996443, 0.04228395664540585, 0.026041993514809292, 0.01761442796123447, 0.026412653605802916, 0.024017377545533236, 0.038270076911430806, 0.0526776940387208, 0.04406927080708556, 0.02770270664768759, 0.09333800597232766, 0.05492931813932955, 0.015801585686858743, 0.03206404137017671, 0.01646581156819593, 0.014657748724857811, 0.013527003247872926, 0.02600182477181079, 0.04184358476777561, 0.04553811464575119, 0.041882365694618784, 0.04719049160485156, 0.05798320758913178, 0.01652703318541171, 0.02285251182911452, 0.05658752837916836, 0.049638632699497975, 0.08796927257208154, 0.010500301450520055, 0.039307473198277876, 0.027591553334787022, 0.060392445302568376, 0.03685015544760972, 0.05500489103724249, 0.0783244104241021, 0.038544990675291047, 0.04987684355000965, 0.042110791328013875, 0.08847194403642789, 0.07983451025211252, 0.03949908088543452, 0.06657235353486612, 0.0461472286406206, 0.022044038414605893, 0.04359330552688334, 0.026637568880687468, 0.03780902879952919, 0.017962150122912135, 0.023801342067599762, 0.09497752151219174, 0.06101807579398155, 0.02706615545321256, 0.051319897756911814, 0.014657475057902047, 0.027844043106597383, 0.08006187461433001, 0.07256210126797669, 0.04087553475983441, 0.06929034323547967, 0.03861444827634841, 0.07658008878934197, 0.05159025844477583, 0.028174417566333432, 0.057340696948813275, 0.05631609157717321, 0.0010002889030147344, 0.06829334204667248, 0.008133098981488729, 0.01912224011903163, 0.09224100038409233, 0.04118427190405782, 0.06284780378337018, 0.042310113640269265, 0.009679020422481699, 0.025640267122071236, 0.0016770527895459963, 0.07329634507186711, 0.00746892412280431, 0.040722121702856384, 0.04426809959113598, 0.006854195316918776, 0.0323295818088809, 0.08956923906225711, 0.03332993008370977, 0.03860085955238901, 0.03752105694729835, 0.08769621417741291, 0.025340589745610487, 0.004682342814703588, 0.04032459772133734, 0.041804239808698185, 0.03563791287888307, 0.015532283487118548, 0.054334809610736556, 0.00541418762622925, 0.03371040693309624, 0.008545707114535617, 0.01813198690797435, 0.07986430748132989, 0.021468347040354274, 0.02440332402329659, 0.008599569409852847, 0.028131239414506126, 0.0643979424785357, 0.041320916134282015, 0.015148297206906136, 0.03401873960683588, 0.03403518188861199, 0.032433612359454855, 0.012340846242295811, 0.028679421229753643, 0.040604713940410875, 0.008133905139402486, 0.07635306581505574, 0.0354621574660996, 0.10256157314870507, 0.06524019845528528, 0.029169103254389483, 0.035884495155187324, 0.013699249229830457, 0.028578175588336308, 0.01878487648355076, 0.004129964154344634, 0.03315483518235851, 0.015439549351867754, 0.049464832845842466, 0.005241943499640911, 0.0353933715086896, 0.014286449459177675, 0.08786162405158393, 0.08318328094901517, 0.010096392215928063, 0.049392350993002765, 0.030602854640164878, 0.08327319214004092, 0.08244954922702163, 0.08632759738247842, 0.005508078584171017, 0.018155427642341238, 0.04295949656807352, 0.036332396120997146, 0.04448380110261496, 0.053262617730069906, 0.01858033130702097, 0.03974004510382656, 0.11109681319794618, 0.05818914985866286, 0.06726364183123223, 0.08069104515016079, 0.05176314174605068, 0.004736152695841156, 0.027815633693535347, 0.003714403433150437, 0.008632636727270437, 0.037759739061584696, 0.026572541901259683, 0.01243022401467897, 0.037569504347629845, 0.023971086084202398, 0.07003471735515632, 0.06987765664234757, 0.0180551783341798, 0.013374014142755186, 0.007080064251567819, 0.04292753597837873, 0.05167195777175948, 0.06854195409687236, 0.04113035858608782, 0.06407783934264444, 0.03402380476472899, 0.023377939396596048, 0.03861991048324853, 0.058101402028114535, 0.019710896813194267, 0.050658722102525644, 0.03050622886803467, 0.012741836053464795, 0.04610026553564239, 0.04396843520225957, 0.015173861411312828, 0.03475058256299235, 0.02997137973579811, 0.013878870304324664, 0.04237342254782561, 0.014592515799449757, 0.025419951307412703, 0.020055405475432053, 0.02675554067536723, 0.033942064619623125, 0.023286208088393323, 0.03473532029602211, 0.023928850459924433, 0.011295487638562918, 0.04357503756182268, 0.012624883784155827, 0.035001918295165524, 0.03386733777006157, 0.03370609505509492, 0.04058757403981872, 0.058042163800564595, 0.02321163337910548, 0.022002127479936462, 0.030586792709073052, 0.030636729970865417, 0.006118483452155488, 0.016271953318209853, 0.023244568037625868, 0.03252295580750797, 0.07176986604463309, 0.024228852525993716, 0.06050268391845748, 0.0035202979552195757, 0.032655956092639826, 0.019567191047826782, 0.05102247465401888, 0.02104818013322074, 0.0321219845500309, 0.06402271261322312, 0.038369238973245956, 0.06710856265272014, 0.041365637953276746, 0.05494914832524955, 0.03828234832326416, 0.012145306100137532, 0.07381013390840963, 0.09046869978192262, 0.028708435493172146, 0.060293810165603645, 0.03510031965561211, 0.07690639627981, 0.028224902162037324, 0.035152184645994566, 0.03874854322930332, 0.03890167427016422, 0.031400357256643474, 0.042017633240902796, 0.08555373031413183, 0.03680093621369451, 0.02918256024713628, 0.043456483181216754, 0.0488189491443336, 0.03758710066904314, 0.08726340107386932, 0.030761171437916346, 0.0685564630839508, 0.02938529087259667, 0.009716434869915247, 0.18108676420524716, 0.18210309091955423, 0.1490518409991637, 0.07219447841634974, 0.14540538744768128, 0.25479850417468697, 0.20089927216758952, 0.11498203049995936, 0.10374256016802974, 0.12342670626821928, 0.19235185347497463, 0.1585717106354423, 0.09361175456433557, 0.1352198261884041, 0.12580160109791905, 0.1574100714060478, 0.0870618931367062, 0.1522093528183177, 0.1524516343488358, 0.19088943663518876, 0.12753916176734492, 0.08596033818321303, 0.1032110043161083, 0.07340196752920747, 0.10528320679441094, 0.0965023307071533, 0.11238461753237061, 0.15148724312894046, 0.07871026784414425, 0.1462595400516875, 0.15311931492760777, 0.10213286412181333, 0.11384832570911385, 0.10315008883480914, 0.14819561038166285, 0.1346758913132362, 0.1014585338998586, 0.14396719430806115, 0.1383931902819313, 0.09967470774427056, 0.16828697291202843, 0.08843867355608381, 0.18828915897756815, 0.11195481012691744, 0.3193401190219447, 0.18201795173808932, 0.09913411253364757, 0.16423981898697093, 0.1393255652510561, 0.1691335259238258, 0.1431878947187215, 0.08718216558918357, 0.15279398707207292, 0.15722981857834384, 0.0823096840758808, 0.07838753750547767, 0.15199421904981136, 0.10136456316104159, 0.17357069329591468, 0.16130959731526673, 0.1689336507115513, 0.13770875200862065, 0.09342310062493198, 0.17512237565824762, 0.17595030076336116, 0.10326996794901788, 0.12124514832976274, 0.128240238991566, 0.1647866185521707, 0.18847404280677438, 0.13439581962302327, 0.17395334463799372, 0.10399869017419405, 0.15687478997278959, 0.17208359262440354, 0.18060395261272788, 0.23413795890519395, 0.135398015845567, 0.18266019149450585, 0.09753543738042936, 0.09985742450226098, 0.18150445976061746, 0.16249210573732853, 0.14889069105265662, 0.25044518464710563, 0.2531523018842563, 0.2514489839086309, 0.10494829781237058, 0.1825346497935243, 0.21539622161071748, 0.10151776470593177, 0.09822692605666816, 0.1087740616640076, 0.1779824198456481, 0.21000756154535338, 0.08691499242559075, 0.1439516240498051, 0.18148069619201124, 0.17877461796160787, 0.10347724979510531, 0.09181394634651951, 0.15506044670473784, 0.10452000438817777, 0.10874482846702449, 0.20001432043500245, 0.14215409784810618, 0.10212225883151405, 0.17071339505491778, 0.14871943305479363, 0.1045214812620543, 0.16531804081751034, 0.12635711347684264, 0.13421737763565034, 0.07664893782930449, 0.18536726420279592, 0.2137602015864104, 0.13786000170512125, 0.22418408130761236, 0.10194448477705009, 0.1609113163431175, 0.09857286335318349, 0.08805334306089208, 0.12682741245953366, 0.11097680049715564, 0.07414542138576508, 0.15568037750199437, 0.09160472007351927, 0.15115667571080849, 0.11561016202904284, 0.10954843339277431, 0.1205522941017989, 0.14050678233616054, 0.10174834256758913, 0.10392492811661214, 0.06188456289237365, 0.17414164234651253, 0.11726733326213434, 0.15588068315992132, 0.07457011539372616, 0.10658356826752424, 0.16666224837535992, 0.16421225562226027, 0.11680928713758476, 0.1872571135754697, 0.1485322485677898, 0.0669873328297399, 0.15548525203485042, 0.14025310141732916, 0.16462438507005572, 0.1132665116165299, 0.153356252994854, 0.12990352552151307, 0.10451453475980088, 0.17291641590418294, 0.16258932708296925, 0.09785916961845942, 0.1061301605659537, 0.17043369443854317, 0.12943944573635235, 0.09757614418049343, 0.17742432479280978, 0.08191010434529744, 0.12600113492226228, 0.13235145510407165, 0.1404335768893361, 0.17536403378471732, 0.10476253824890591, 0.11323594997520559, 0.13757062348304316, 0.2471892343601212, 0.11432901475927792, 0.16980136977508664, 0.10588917037239298, 0.14790501503739506, 0.13464936695527285, 0.17367627122439444], [0.016446235567855183, 0.012832671218347969, 0.004872098379564704, 0.06407533088349737, 0.062037181851337664, 0.020153586046944838, 0.0540289816854056, 0.052214111492503434, 0.02459025246935198, 0.04866304989263881, 0.008581297734053805, 0.02070531903882511, 0.04401836318720598, 0.03754152166948188, 0.0578392346506007, 0.016459594226034824, 0.032617661272524856, 0.03547426931618247, 0.02291044202138437, 0.010938458017335506, 0.025433014961890876, 0.04893249773886055, 0.043069442035630345, 0.033883034193422645, 0.018776403012452647, 0.050734384058159776, 0.029890157238696702, 0.04904242465272546, 0.02272749705298338, 0.010593633942335146, 0.09268277863156982, 0.01878333652712172, 0.017828569107223302, 0.024820045509841293, 0.033556745256646536, 0.06709860303089954, 0.03864413418341428, 0.025950033996195998, 0.012095622096239822, 0.05483346605615225, 0.01691728968580719, 0.04919605664326809, 0.045466233932529576, 0.006620907688557054, 0.01825720763008576, 0.007816350353095913, 0.06414567906176671, 0.03774614662688691, 0.013604541909444379, 0.03207649089745246, 0.030551922900485806, 0.059862826456082985, 0.05854673516296316, 0.07979542875546031, 0.0074070777100132545, 0.06007291733112652, 0.021653932199114934, 0.03605082900321577, 0.0568612250208389, 0.06468010702519678, 0.03570944849343505, 0.0474238191236509, 0.029743993109150324, 0.015525241433351766, 0.01230051979291602, 0.0554803702107165, 0.01875532416306669, 0.042314017337048426, 0.0518466853100108, 0.024147863805410452, 0.050747085915645584, 0.05507788868271746, 0.03160488202411216, 0.03291203785920516, 0.03758555700187571, 0.08794029912678525, 0.006464935613621492, 0.019094726849289145, 0.03635128006862942, 0.03291014538262971, 0.015246534367179265, 0.06547609009430744, 0.060365991448634304, 0.02096780368447071, 0.021119671218912117, 0.04616631667886395, 0.06187945320561994, 0.03141961227811407, 0.0815965914807748, 0.032330546600860544, 0.028092528991692234, 0.07617903960635886, 0.029757502052234486, 0.03134331578621641, 0.017781899150577374, 0.03832757480267901, 0.02314838013262488, 0.007802244908816647, 0.03089201021793997, 0.04536000662483275, 0.004991569312551292, 0.03712354038725607, 0.010586770931695355, 0.03881906210153829, 0.024735485203564167, 0.07357473208685406, 0.02207231238571694, 0.029845442841178738, 0.05771289514086675, 0.06030628937878646, 0.046167136752046645, 0.07253401839989237, 0.03463042885414325, 0.0727972952881828, 0.020181952786515467, 0.04384094165288843, 0.03984364520874806, 0.014035099811735563, 0.060414913823478855, 0.08981794759165496, 0.024490691503160633, 0.02006857674132334, 0.0667975062970072, 0.047380088071804494, 0.050861487980000675, 0.06522819050587714, 0.02825380324793514, 0.02405348488537129, 0.06593661499209702, 0.018673042250156868, 0.048451500697410665, 0.070513988903258, 0.09934750967659056, 0.019290058262413368, 0.011998211502941558, 0.024478909908793867, 0.03899953757354524, 0.017737513153406326, 0.03963402930821758, 0.07333061745157465, 0.042944241722580045, 0.05728700627514627, 0.04573721802444197, 0.03335947127197869, 0.027626753399090376, 0.021360971259127837, 0.03236670403566677, 0.05484764478751458, 0.025112473958870396, 0.02785414930258412, 0.013990188745083287, 0.02411773817584617, 0.045314156741369516, 0.0670283216459211, 0.020010678090329748, 0.06363800552207977, 0.014374744623637525, 0.1258475994109176, 0.02461948195559671, 0.05016855582653079, 0.0748510702396743, 0.040089956601150334, 0.0648814813757781, 0.0343273431644775, 0.08377278369152918, 0.0190255085908575, 0.07364171833614819, 0.029994267570145894, 0.012235994690854568, 0.022220834689505864, 0.027407797570049297, 0.03875720409268979, 0.05374466119974386, 0.029449638786900323, 0.07049872292554937, 0.043356141104595736, 0.020301978474890348, 0.010638958756317152, 0.029275254491949454, 0.009534791443002177, 0.04304794572817627, 0.027236326204729266, 0.030426127013924997, 0.029598806759167928, 0.0328997887118021, 0.0056973703067342285, 0.0062506891754310345, 0.07765094851492904, 0.0390017603058368, 0.02184742123063188, 0.015639495068171527, 0.035042784656980075, 0.026675386870920192, 0.02282416735397419, 0.06006899136991706, 0.012892666436528089, 0.051517980682547204, 0.020711117067548912, 0.0056940153353934875, 0.08261806127848104, 0.036896751189487986, 0.005520610675375792, 0.012912213678646367, 0.028047083578712773, 0.01269397680516704, 0.03182137763360515, 0.035183455038350075, 0.018124875277862884, 0.01707673454802716, 0.01475432811275823, 0.006373312844516477, 0.044649400224443525, 0.026022152196674142, 0.07585463943541981, 0.08489158615702763, 0.040483150150976144, 0.004535654543360579, 0.04151894710958004, 0.07704104413278401, 0.04259175497281831, 0.07719587098108605, 0.016562040291319136, 0.06820221373345703, 0.0023100842327039572, 0.06437089119572192, 0.01419276166416239, 0.020867739913228434, 0.021144074889889453, 0.030668241561215837, 0.057027121001738124, 0.04840060792048462, 0.04353575568529777, 0.11843771499115974, 0.063833821186563, 0.03921524650650099, 0.05542055681871716, 0.029637782499776222, 0.030737578563275747, 0.04864422902755905, 0.031875201893853955, 0.02022511795075843, 0.038240698995650746, 0.03257156648032833, 0.05729696589696687, 0.027907368712476455, 0.08354669582331553, 0.05032151617342606, 0.03310699263238348, 0.016442886626464315, 0.05454660000395961, 0.06220025024958886, 0.09756304527400061, 0.03222402614483144, 0.012612394366442459, 0.06396493641659617, 0.03693542079417966, 0.04472371147130616, 0.021994819180690683, 0.11037783537176438, 0.0054150318192114355, 0.08308698728797026, 0.045729544217465445, 0.03919490052794572, 0.05269645182124805, 0.04006088667665608, 0.043429791840026155, 0.04597515056957491, 0.020514863535936456, 0.00990322323559667, 0.06107053821324371, 0.032592528441455215, 0.022005687933415174, 0.022223593623493798, 0.015157287398324115, 0.053116589042474516, 0.05264089835691266, 0.023750254476908594, 0.026259585647494532, 0.044669070848613046, 0.03901963122189045, 0.055034302349667996, 0.061466767147067, 0.042656566729419865, 0.04293276811949909, 0.0708883727202192, 0.15044556464999914, 0.019882260567101184, 0.06404315136023797, 0.012837843987654196, 0.05391420112573542, 0.07302670797798783, 0.009239989976776997, 0.0077617913666472305, 0.002865301607926085, 0.04765150632010773, 0.029373043580562808, 0.0251662759546889, 0.058073434192920104, 0.024067613521765452, 0.045221132240840234, 0.047707319536129944, 0.10129986272659153, 0.07634649780811742, 0.017515538638690487, 0.08561706519685686, 0.041204402659786865, 0.030980297960923053, 0.03886115300701931, 0.05431784040411003, 0.04984386250725947, 0.03985449540778063, 0.06003541289828718, 0.026929958366963547, 0.0623092420573812, 0.03739157815289218, 0.04923624393995851, 0.006009591370457201, 0.07267080363817513, 0.05528851761482656, 0.0076621687094302615, 0.019209069541830104, 0.04589763695548754, 0.01996421407966409, 0.024259377059934195, 0.03001481578394305, 0.03107811488007428, 0.07153369981097057, 0.03330441133584827, 0.08109046902973205, 0.042953548254445195, 0.08716484386241063, 0.026091047620866448, 0.009728625573188765, 0.11809424904640764, 0.019467077181616332, 0.10879970286623575, 0.08015072453417815, 0.0688588956836611, 0.06502674194052815, 0.06451393273891881, 0.023587471805512905, 0.042007510346593335, 0.04933122771035414, 0.020824179555347655, 0.02754271074081771, 0.02266123625304317, 0.10473185786395334, 0.018823989521479234, 0.029430496942950413, 0.0638760939182248, 0.013265852612676099, 0.036510006902972236, 0.126048780803103, 0.08696789271198213, 0.205311473691836, 0.1985039608553052, 0.09932617293088697, 0.11327316125971265, 0.10236995061859488, 0.11175735431606881, 0.11721709728590213, 0.1722233835607767, 0.1489265961572528, 0.16300093702739105, 0.07021562327281572, 0.1274709583958611, 0.12969173141755164, 0.1048190008441452, 0.055989461252465844, 0.1092615858942736, 0.10884424656978808, 0.0877736350230407, 0.15018357167718932, 0.13346009014640003, 0.15840958105400205, 0.28868894500192255, 0.08770036278292537, 0.11970918465522118, 0.15086695610079914, 0.15789497585501522, 0.08863064489560202, 0.07500454637920484, 0.18970686884131283, 0.09110010418226011, 0.09184713519061916, 0.1616169503540732, 0.10804755103890784, 0.1482521471916698, 0.08696846416569315, 0.17113923939177766, 0.08751776476856321, 0.10700539758545347, 0.12862729869084433, 0.1980738714337349, 0.14024535339558497, 0.12981396313989535, 0.21782617637654766, 0.0616974266449688, 0.22754528297809884, 0.10444765241118148, 0.19336743804160506, 0.13937104406068102, 0.10280595495714806, 0.11062117817346007, 0.15681581891840324, 0.19963732425821945, 0.12512828019680455, 0.14315403794171289, 0.22281472978647798, 0.1624434653786011, 0.12570543360197917, 0.23864620918175206, 0.07341046512010507, 0.15426412224769592, 0.10465942425071262, 0.1188186371291522, 0.14682228094898164, 0.1482712203869596, 0.18376023246673867, 0.175911916885525, 0.1663322449894622, 0.1913821484777145, 0.15366320527391508, 0.2469296014169231, 0.13421544805169106, 0.09679580558440648, 0.16961672343313694, 0.2694515569601208, 0.09095596426050179, 0.07739881868474185, 0.12322385504376143, 0.10508760635275394, 0.10717285578721203, 0.11036258423700929, 0.19864191126544029, 0.123795130639337, 0.20520116086117923, 0.18297584174433723, 0.1209627759817522, 0.143593953398522, 0.16270602238364518, 0.11267821115325205, 0.11807989591034129, 0.1758880345732905, 0.10683227679692209, 0.11235583704547025, 0.15448041376657784, 0.144719093805179, 0.07175828111940064, 0.07973218293045647, 0.1967049206723459, 0.2789585280697793, 0.13109048682963476, 0.20107815944356844, 0.1126141934946645, 0.19505610602209345, 0.19285428745206445, 0.2969152363948524, 0.121334502910031, 0.12344056958681904, 0.151766914059408, 0.22792873583966866, 0.07526089160819538, 0.16451502218842506, 0.13707433448871598, 0.21406893501989543, 0.15142405667575076, 0.0868812098633498, 0.1072097998985555, 0.10012281651142985, 0.14809559856075794, 0.1729572340263985, 0.10404742701211944, 0.12675719044636935, 0.19309462455566972, 0.21962641883874312, 0.13685764221008867, 0.18231190158985555, 0.12688779359450564, 0.2112729530199431, 0.19618314632680267, 0.11190853721927851, 0.18676826090086251, 0.21077767334645614, 0.11497138068079948, 0.11235302430577576, 0.11059271681006067, 0.07989707330125384, 0.17291717289481312, 0.2347461340832524, 0.13849640818079934, 0.19922439329093322, 0.09874510098597966, 0.10171286048716865, 0.1519689118140377, 0.09410604718141258, 0.06645847839536145, 0.14510446140775457, 0.08913616620702669, 0.14694789686473086, 0.07871828303905204, 0.26978012057952583, 0.14889590092934668, 0.07381408213404939, 0.18466915556928143, 0.17143128934549168, 0.12149346352089196, 0.12364105336018838, 0.08221828116802499, 0.25881536363158375, 0.09074226283701137, 0.1651387824676931, 0.14630197605583817, 0.12190701789222658, 0.1008895218546968, 0.14566960686352104, 0.12714631331618875, 0.09414892847416922, 0.2783768030349165, 0.11640934375463985, 0.18496317963581532, 0.12360607594018802, 0.2097712765680626, 0.11955956026213244, 0.09262356266845018, 0.12471851077862084, 0.22600393131142482, 0.08824264266877435]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04877022343862336, 0.10409372218418866, 0.0254805049917195, 0.02815003059367882, 0.04678474091633689, 0.05155090235348325, 0.045436017389874905, 0.07064350851578638, 0.0039536270833195886, 0.05467838687764015, 0.022739584783266764, 0.030037462420295924, 0.04599328123731539, 0.023403007289743982, 0.015481521513720509, 0.049759576795622706, 0.05775074096163735, 0.08601997717050835, 0.04470952902920544, 0.017333654941467103, 0.04112990958674345, 0.023737949668429792, 0.043888235013582744, 0.01158257819042774, 0.07286946172825992, 0.026849316600419115, 0.028359696589177474, 0.05841720812895801, 0.04919991210044827, 0.028697691050183494, 0.010010526657424634, 0.06794345652451739, 0.05058015834947582, 0.022941252282180358, 0.03199037579179276, 0.03661720271338709, 0.01204306134241051, 0.05022108132834546, 0.09812462099944241, 0.006051884047337808, 0.043257231372990645, 0.03367752236954402, 0.014748008725291584, 0.0384865502564935, 0.009988146266550757, 0.03646966004453134, 0.0675896524626296, 0.019031462470593397, 0.01534548306153738, 0.028087385908293072, 0.0707862977287732, 0.07886573293944821, 0.08730549569008872, 0.10099684383021668, 0.06164244463434443, 0.05634954017295968, 0.005761448728662799, 0.03687850548885763, 0.02336029112484539, 0.03471614320005756, 0.1114306460658554, 0.0348925702564884, 0.13296831340994686, 0.03979822577093728, 0.03865987884637434, 0.016325580909324344, 0.038447836122941226, 0.06314513040706515, 0.052043914765818045, 0.06229377569979988, 0.01402818206770462, 0.030622465892520268, 0.007413283456116915, 0.019916262062906753, 0.04474642490094993, 0.06358629267197102, 0.022210396382433828, 0.028523675973701756, 0.035772724004345946, 0.014216158797353273, 0.04118711432965938, 0.05867950909305364, 0.07614980640937574, 0.061172932328190655, 0.08108582318527624, 0.026752599915198516, 0.045056386588839814, 0.040705894643906504, 0.045721877831965685, 0.0717870838707313, 0.10414127900730819, 0.08500958021613769, 0.03031799424206838, 0.010895644445554353, 0.043770070260507055, 0.04830403224332258, 0.051243148554931395, 0.012324434574111365, 0.0394558396510547, 0.008809387545625214, 0.027882120848516934, 0.01543378935821238, 0.02163670138543239, 0.06154673726996407, 0.06629976269323379, 0.11189824363100342, 0.04927635702188127, 0.04496948480664287, 0.04130890818487387, 0.013075047372694826, 0.0387612302438356, 0.0668966794910375, 0.05967314093140885, 0.0301477288667229, 0.04850438614084851, 0.02873568158975104, 0.018877086477004923, 0.014971012042224174, 0.01838822823629016, 0.11939153802813962, 0.022654952117591165, 0.044539050286402926, 0.028347729457891546, 0.04129266999370884, 0.04336092053563334, 0.06166893559566233, 0.02287916977365967, 0.014077632295084186, 0.03904527613485698, 0.042666400186135434, 0.032850881179911084, 0.06428966313251294, 0.0381872161233332, 0.09814905992243439, 0.060786818867200054, 0.02358899135288084, 0.025979513957281597, 0.05128899843839463, 0.04413575239595957, 0.04168866144027561, 0.0532052756898338, 0.017549037329445127, 0.003942658604501048, 0.038335397039190866, 0.053116782000870444, 0.0607868522638455, 0.02582582073955564, 0.03327147482195869, 0.026040835764433723, 0.02092400212859502, 0.004409349357956671, 0.029544080789492, 0.043950757244601846, 0.05294226597470697, 0.01868777944764588, 0.05938483511272352, 0.05155018989171367, 0.0351558953843778, 0.03475037847238127, 0.04953855408530217, 0.08701659986400045, 0.037153014782234095, 0.08140878358972259, 0.02024805773544358, 0.015244917412928771, 0.05350646148144733, 0.026160154557146598, 0.008298806642415002, 0.023353066317213234, 0.01564315756695578, 0.026155133928114083, 0.06836369022494182, 0.0909688627871219, 0.02531390025978908, 0.020996454295527656, 0.016020777147787157, 0.011176456428074744, 0.04496907662542071, 0.02857940755347954, 0.042054503137478605, 0.03963129078329075, 0.03559356584446505, 0.06152592373837251, 0.03353664789756294, 0.04282609181245789, 0.04191320935206022, 0.04712203219241928, 0.042739846830954775, 0.029733760748058558, 0.04032562930660788, 0.021840458030055743, 0.01688184100203216, 0.030418071000894997, 0.1707040291512385, 0.036984792168368585, 0.018802866143232677, 0.006783439421269577, 0.004836196521864622, 0.02053037071163999, 0.019726993996300735, 0.05176197286345996, 0.026711056343629025, 0.038093256516731344, 0.017219184228451923, 0.06790525076212361, 0.02850578835932538, 0.10642822933732532, 0.05111502418003511, 0.0660005807003472, 0.024694145722605754, 0.05099447713291738, 0.027992509749310557, 0.04417285606905352, 0.06953626871109009, 0.03486689936835319, 0.0626870545966085, 0.009009674649860244, 0.08044505288125947, 0.014594837793993065, 0.06510734659968875, 0.036597302023437805, 0.010369289193477016, 0.0816276429395657, 0.03097558717854554, 0.06895394253660925, 0.0575305605889298, 0.011405268905946286, 0.08482344215735793, 0.04796514906047378, 0.03252752001571935, 0.046536930385627784, 0.021154440837563016, 0.02701559478737181, 0.04667709239583928, 0.017481858121755067, 0.03399207424081396, 0.02808030210871948, 0.021946590713923797, 0.041715601400937885, 0.06241101276827976, 0.017905815548147075, 0.03171673110045958, 0.009667247177276295, 0.03695397077535745, 0.042319479543948546, 0.06828594283433631, 0.02342376516025979, 0.008617778003099374, 0.02261249755974859, 0.020786068416782655, 0.046609044875367545, 0.03710593664436601, 0.027322975656716153, 0.04640891362214461, 0.022663145427941345, 0.03372205865161959, 0.018382289199507795, 0.04268200013029855, 0.03983903647167608, 0.019745916906686034, 0.019300535532238428, 0.03709702716150787, 0.03327947517391294, 0.033676494495011866, 0.0147105358337285, 0.084112063923385, 0.03822912149189506, 0.017195498585351743, 0.034592256488394924, 0.06202905162354, 0.06538888774230145, 0.016871423104021233, 0.015571571857435629, 0.019101242905890103, 0.01178842490844545, 0.06505928511614911, 0.024762436296441592, 0.04728580934170168, 0.00270752425876708, 0.030947218583605718, 0.03156645361741539, 0.03915298031643033, 0.04114200659387279, 0.066724738717312, 0.1069654848834034, 0.04297557519748807, 0.017605600114620756, 0.0648032219032757, 0.04586212889989838, 0.03325597877847031, 0.01576493843458593, 0.06679194761090912, 0.01994056368857855, 0.025776265683816746, 0.031213232141453773, 0.028032858463120647, 0.04278401203919202, 0.03462236541963648, 0.019690298504428938, 0.03201100007572677, 0.07922403441625647, 0.03828325374342967, 0.024333428555110004, 0.005662998664774932, 0.09307683678343892, 0.005137078032930731, 0.009690507013146998, 0.11542685897438787, 0.05545013140363153, 0.07435861072735861, 0.013955561989860144, 0.040597162587800995, 0.04153056172071956, 0.04818706976948306, 0.08144753111992031, 0.012821276468457654, 0.03176054007781204, 0.013232984747446608, 0.008966816549218493, 0.05515833378012758, 0.011411564173613442, 0.06882854926516302, 0.03410573415749241, 0.028680617942882236, 0.07167360206949525, 0.03830529181868769, 0.035745732093346305, 0.031917559972498566, 0.029749464592896402, 0.0454418172739679, 0.0024496130981788156, 0.04367709028883837, 0.07326987266424112, 0.047075477268663235, 0.019345159016666003, 0.04227629025990609, 0.015355708928836975, 0.018602712625579443, 0.06742767131072469, 0.028323481637926307, 0.06789538019802421, 0.01735972287860932, 0.03317971197247971, 0.03681776441226248, 0.04140501630899962, 0.03309301057015546, 0.018934708677988965, 0.006255076195884612, 0.044061749140382744, 0.08975869452115148, 0.024585153914813418, 0.041550532914698124, 0.15250407450366765, 0.19348788860952482, 0.13118570437654853, 0.17370521498378366, 0.10377867307397537, 0.1390150803490542, 0.23072940821293741, 0.1414560931152664, 0.12575990724144503, 0.19671073911013082, 0.2432529127690941, 0.18288434977876022, 0.17430147127015516, 0.12964225985342637, 0.1527511651511304, 0.12575063039548695, 0.12982945918338373, 0.2505154808750376, 0.173824121884536, 0.10215051981504075, 0.07957012014230713, 0.08211331180064008, 0.10612941841827706, 0.11572566989343613, 0.11497248648083769, 0.0883509442792274, 0.0788846131763421, 0.1736415535560809, 0.11248163107666187, 0.16378232947317883, 0.20196984987705946, 0.14406995207536966, 0.29330973455216736, 0.11259260441875085, 0.10708132671425119, 0.17017838079482317, 0.07575039737275802, 0.11117243804619648, 0.18740022933343425, 0.08623660265584476, 0.10753834125353023, 0.23020941502181813, 0.11301870850729756, 0.13493035890860483, 0.1255834987387061, 0.09611809116904624, 0.1571507946937345, 0.17304590583080426, 0.12013818311970681, 0.2464410159154795, 0.1727161547751166, 0.1954995095729828, 0.2356521924957633, 0.1719849611981772, 0.11882841121405363, 0.14358009007992223, 0.08846267461194657, 0.11453601458924823, 0.07812357041984797, 0.10955321282381192, 0.2142124218516983, 0.11718748559360392, 0.2107172625255771, 0.11276465651462786, 0.13685385725693777, 0.06260779322474264, 0.06660834027570672, 0.22186570102348924, 0.11979321803664789, 0.19273349549621344, 0.09072919361642562, 0.09121708892052993, 0.05454478174215183, 0.09461008419748396, 0.30762047914322466, 0.13544494926463813, 0.09874468538328074, 0.16350844729458913, 0.15869802417000756, 0.09551802024361677, 0.1860704639693722, 0.08417700184509158, 0.14880233095027506, 0.1304824007092975, 0.15505355957429856, 0.14808789506787434, 0.13678253686521202, 0.10231640466372482, 0.09498296145466156, 0.19711911329068244, 0.19885544199496508, 0.21002851979574189, 0.10496517425053753, 0.16353262646589428, 0.25324147834908217, 0.16645639145281166, 0.1718149648513645, 0.08684720465680584, 0.12770863861078396, 0.11079995412728749, 0.08022180001717061, 0.08715864692931063, 0.07326126375119202, 0.14945830043870956, 0.11491989047499374, 0.20891333901090547, 0.1467556064017117, 0.14351890742545947, 0.23721856938209385, 0.11375167581718415, 0.18386238167295232, 0.15208709141006693, 0.11182661895873025, 0.07273699578945525, 0.09660312920459546, 0.16709017072571442, 0.11403166587115265, 0.1027770408836659, 0.11023613711586222, 0.17879006947623566, 0.08740384510019794, 0.20489452028414235, 0.06879421009216458, 0.08844860349199735, 0.15682907367590815, 0.09535761244478635, 0.10816990892635658, 0.06985585976508446, 0.19402925565373152, 0.0657800366752781, 0.11620356846833602, 0.20196640631183982, 0.11391246953280643, 0.16458622383652255, 0.15808661322807893, 0.12727264169370756, 0.12294721949729137, 0.12655937840463594, 0.19053739146329463, 0.10321579859009944, 0.2483277185820043, 0.12378114115563221, 0.15211949357762933, 0.21259831002680585, 0.15946095198160037, 0.19693681213539094, 0.11694969405652955, 0.16363771457690746, 0.08186366816516966, 0.1244399456481915, 0.16543414240004495, 0.11556964076589793, 0.13290178729221225, 0.17024092900101095, 0.1030596655618865, 0.16568191582337022, 0.21474498702446, 0.18544299295172095, 0.11863436186104082, 0.13890721660573035, 0.1729039181373082, 0.11092688364442438, 0.12435450218617916, 0.14741211023647338, 0.0971669981663581, 0.1616969984024763, 0.14637084736023098, 0.09800694606383331, 0.12283165226108395, 0.13725909957429394, 0.11881557205924764, 0.13555110606830567, 0.12759856326738372, 0.22152137418743223, 0.10853762083570473, 0.1334227601182647], [0.06492942411568947, 0.014743851770617766, 0.10650994721800089, 0.09307893706136383, 0.024931694206316024, 0.03881947399349883, 0.0491289293859154, 0.04356040240963921, 0.012859726211900124, 0.024471369688399136, 0.0103781012694526, 0.03139506574370898, 0.08073941833572462, 0.012887524280813523, 0.025026162184076384, 0.01094032730179606, 0.02747181151789846, 0.01741666601446923, 0.022007307670719456, 0.017054444142559078, 0.03768885653698817, 0.13505443115718663, 0.011872591876453953, 0.011672096970869461, 0.023503664779127575, 0.0068796458799624816, 0.02137837091140682, 0.03657173132523894, 0.02722480807278771, 0.09065581747563556, 0.03679328838188667, 0.04354724784207065, 0.028968944170628674, 0.046624043679912575, 0.05266750064038206, 0.026423381350468844, 0.04302795226976741, 0.03968901502958033, 0.013584939933934947, 0.05104580406623427, 0.016518478078069165, 0.08737625947105698, 0.03778962534852326, 0.04978011202183552, 0.008546208064217353, 0.06745344609953463, 0.06215886438440066, 0.03286985789600294, 0.020216167649778072, 0.021796005239593796, 0.027928607123612892, 0.012992513129574945, 0.05075122709968127, 0.035427005641395226, 0.04504240081587341, 0.027216308626520913, 0.028978078153159004, 0.01917647441587178, 0.0823416854836978, 0.06629776631598361, 0.038304148911265656, 0.06801936338888481, 0.05625008496281225, 0.021931738483544905, 0.03128550248220563, 0.02864524161850568, 0.04187612794339657, 0.037598652197630145, 0.025277859713241924, 0.0886671437183395, 0.03053015941986814, 0.02581532306066947, 0.06767549668438733, 0.01929857626237208, 0.08359164770809002, 0.040063769920379855, 0.09403526855749078, 0.04785334451298695, 0.048345050745410845, 0.02653820272826124, 0.04551510064629838, 0.008527672925993102, 0.09664416997111402, 0.04823453011340462, 0.01915831777296262, 0.03175139681843575, 0.04535226231382694, 0.018186916968261357, 0.0063033399146661395, 0.02175975689169718, 0.049327557790093124, 0.022905567966517992, 0.02557242554757977, 0.03056908506550826, 0.063613433012506, 0.011107039645139594, 0.010823450174939353, 0.04169694751908537, 0.035094471531920135, 0.07318043644772843, 0.03950471378630027, 0.0696290000632871, 0.012640323238883866, 0.04732154375233222, 0.0013022847952015582, 0.06785923760617152, 0.02069741145533044, 0.048947941832011566, 0.007512522515753517, 0.030142860377964098, 0.09735814572195522, 0.040784707016428, 0.01580066171300132, 0.02110359630023595, 0.0784670734719839, 0.0222516783469473, 0.05188682807784062, 0.027192398483748548, 0.01587344228028087, 0.03007470895681763, 0.015374614213214954, 0.12424417451256886, 0.02748175073065795, 0.09985081938793883, 0.007191772319856682, 0.011878902914759237, 0.031200118392007425, 0.005014029020458111, 0.03628859456512146, 0.037196025950834155, 0.04939380189171061, 0.026947630758513696, 0.01720409265544731, 0.01383453440212179, 0.052124326466582716, 0.061593885911861435, 0.0332091715245042, 0.03608758015616331, 0.02437465485854773, 0.10436902186484076, 0.010634544833010295, 0.05643034521199297, 0.008963549244072055, 0.021309340045263525, 0.09893792579532601, 0.05297555871948134, 0.045992487139301375, 0.0683385982119944, 0.03501298742776271, 0.03598880401114002, 0.046999073165352456, 0.05057471469626762, 0.04607144423061982, 0.02158142251573736, 0.04472819033253472, 0.025460058823227882, 0.008172248199116439, 0.048742318685981445, 0.03027494967682287, 0.033011036648531444, 0.017116409762820695, 0.01686758620053297, 0.09871843561995775, 0.013808884850732284, 0.08027276329812594, 0.03617650058004074, 0.06397555654984899, 0.06551552040036768, 0.06259358851821162, 0.07520048078731634, 0.08277173779788427, 0.020838638447457924, 0.016132590972119942, 0.056978257998707704, 0.023275224302778952, 0.05849537112226244, 0.03855345115880482, 0.0233664416737156, 0.011081521824962692, 0.085498714906862, 0.008503059598297114, 0.05216867721173912, 0.07826949149603024, 0.036438831230043434, 0.05552764872845728, 0.04080684157088399, 0.06414610950741917, 0.027452588037704118, 0.04139062235481106, 0.08090332165011205, 0.07468757510650903, 0.019500932103255764, 0.05592386281932704, 0.01093211636543856, 0.029103694068908226, 0.007268321141964407, 0.045676788649871014, 0.02119016040524002, 0.061674605603911914, 0.03803657498792745, 0.0059066758967674104, 0.0020967163118257304, 0.026946025864162948, 0.03683460374304559, 0.06271760881645605, 0.014046358191990294, 0.027872639911947772, 0.01941260910825804, 0.05907757113163825, 0.03341701740282588, 0.04112884831556585, 0.08108101406833157, 0.05823543389851693, 0.09975923836464062, 0.0394418093492277, 0.07460872933734208, 0.015343066443165299, 0.05837289820192382, 0.017605266148166265, 0.017947435189853422, 0.01742168293276336, 0.03908933744241949, 0.027740019977500197, 0.04987738902855199, 0.021828793323948048, 0.04344869434135035, 0.05130202684085816, 0.03620810864958912, 0.03474648961855564, 0.05068873455456924, 0.05948179299593903, 0.007962903182487935, 0.030702666081197094, 0.0242907810388715, 0.056729623684077524, 0.10931810043985024, 0.033379238375346176, 0.04054871889820788, 0.03275000475696288, 0.03607814745919313, 0.04439533338882029, 0.04098250421520788, 0.03662770410301164, 0.01790827762306435, 0.0348206635680981, 0.08193625762942247, 0.030806950817350298, 0.05473988865560386, 0.031576465189573355, 0.07447581068845466, 0.07998937420779839, 0.0305623927488341, 0.04991828878701199, 0.08902501474949531, 0.01920403963595163, 0.03331414831336588, 0.025013497433974408, 0.044977125216973945, 0.012071699893567711, 0.06369535127305426, 0.042665862129069865, 0.019598038416006602, 0.027683535117830615, 0.052124794019619, 0.016951322722889017, 0.06329370837192982, 0.05128286087710876, 0.07338657538639382, 0.007985648153407965, 0.036662243655882776, 0.010939450639853021, 0.03118832566542551, 0.020840302713622805, 0.05460694774228614, 0.007550477339464123, 0.02480148625181755, 0.027117719873785973, 0.021540506058954634, 0.029384103436314035, 0.0598814135446446, 0.04608704417478293, 0.011694395725498907, 0.02255914641864365, 0.04927779678837396, 0.004103489891349454, 0.05534551455639303, 0.05018638592446223, 0.06373483352945186, 0.06899657149915583, 0.04632153686543461, 0.05500124338141177, 0.05458949613966979, 0.035956806314061396, 0.034630896407179534, 0.03634084547229577, 0.017163641896331683, 0.048018991874414496, 0.04744195350212976, 0.05965442396700382, 0.026259210862917826, 0.026485096495889593, 0.023349854673142545, 0.01790675065421965, 0.03192708172718994, 0.01939274552569259, 0.023491107640438713, 0.020517154916888103, 0.03824266939773224, 0.029897949789301492, 0.02991743487655185, 0.09686153018265031, 0.04977092794433702, 0.07158298583817668, 0.05664781674568076, 0.10358051222283393, 0.0358569021045696, 0.017205406256834976, 0.026182634210272226, 0.052027390847797506, 0.03085234056925401, 0.051637076830957085, 0.030376058020920027, 0.01534457764137187, 0.013441320443234872, 0.04544748728221748, 0.02259900160424877, 0.10528936662012711, 0.046376029058592394, 0.025701984122861177, 0.04736042486911174, 0.02852658519259421, 0.06748610059730709, 0.10636980747221969, 0.03329391736770049, 0.04149656764639076, 0.03830541798379272, 0.040436825292999856, 0.06541433598613366, 0.04794661763298791, 0.018145839094358962, 0.06089730610256083, 0.024145815477822907, 0.019255676415923517, 0.02327541911654407, 0.09339693991933018, 0.014290419021563139, 0.05198960439884104, 0.008858975998009555, 0.029105462235747837, 0.03757041718927212, 0.049017095152521506, 0.018764040687528905, 0.12663114408496767, 0.10759278520708904, 0.15943258709739894, 0.2068551111733541, 0.14336704916786402, 0.1136678725015372, 0.1285926255513914, 0.14449641981627792, 0.10247978105326183, 0.12674852216150612, 0.13140248571289703, 0.10145378415472806, 0.15551738702924922, 0.17522816138807684, 0.13871155679225922, 0.12252945714863017, 0.11679922361508943, 0.12593690946232527, 0.1308263119426556, 0.12222196310176514, 0.19385621650144458, 0.20691187062766403, 0.203031002311036, 0.11885688742040657, 0.08646431582747027, 0.11117910253233276, 0.150706444401294, 0.1980836084112525, 0.12726686778478324, 0.16386412899009883, 0.11976905370829627, 0.18050762184429914, 0.09767741765244864, 0.22034784575225785, 0.22311193024506792, 0.12808397237677127, 0.19663928513182327, 0.1687456201761961, 0.09726359610795043, 0.17669322027359158, 0.1109419937711209, 0.1798194579896517, 0.09223661429132335, 0.17932165501406416, 0.1361284969607368, 0.08837610308546573, 0.15738063782919198, 0.11721731993020512, 0.21112737333169207, 0.10684667446184903, 0.09772570178029127, 0.12404945722664706, 0.11599624951486476, 0.184670313319657, 0.14964515838073567, 0.12331922102021053, 0.1307866515708156, 0.08448021369986236, 0.21720115444622934, 0.19634407362900674, 0.1811354936216958, 0.1857872455730103, 0.1261070542386733, 0.09533903648843989, 0.13492719735950232, 0.18371064215898514, 0.12229046333231963, 0.11301438920781948, 0.11542018706677482, 0.1651814708020538, 0.15878635458648205, 0.11094906643847935, 0.15119344170670956, 0.1352587147266604, 0.3139150788774714, 0.17996287060668692, 0.23891013173852116, 0.19257708045188338, 0.20736757898703218, 0.1666563854087144, 0.13419736933428794, 0.11795813916251063, 0.12459979683626443, 0.17159741168143228, 0.1399706696975045, 0.20944679476087913, 0.1613536215154454, 0.09978427842725068, 0.12221422250149772, 0.15162413968937472, 0.18731906806351617, 0.1262350450269878, 0.09458767133764923, 0.10271667459164746, 0.14402695203898475, 0.08829552069073543, 0.09248979797121137, 0.13784311042400077, 0.10155421899980865, 0.1153363095363602, 0.10341718778363429, 0.19397329771891236, 0.1399863141705282, 0.2046482014702633, 0.13791946257697418, 0.13212530786404386, 0.1186151550791692, 0.139264679455664, 0.120299837726634, 0.13483671471476555, 0.17208467616001144, 0.10247506099403836, 0.1401095255278051, 0.14073662547161803, 0.2188041340559721, 0.12687180773355067, 0.18580602190922946, 0.12051364305079915, 0.12339215929387137, 0.052825986276729964, 0.12043609604006633, 0.141027977806516, 0.11237778977374546, 0.14880941103911027, 0.12909136363305151, 0.13918621960328892, 0.09702386756544001, 0.14378826250322163, 0.11838015401735902, 0.09452928657992743, 0.13177214947063476, 0.1576886884868145, 0.1210334432835225, 0.10591604353976436, 0.09769452415639535, 0.16928611148614436, 0.09834035590756685, 0.09934893460012972, 0.16368139738915488, 0.19190329941920936, 0.13827707385644317, 0.1422739398549311, 0.1651705612312071, 0.09073648150661029, 0.1246792363235727, 0.09258149031666107, 0.19479596841847524, 0.12318246546783485, 0.12072029407136142, 0.05872649075172376, 0.2549901860766113, 0.10111944662639871, 0.14768283086596057, 0.12129636394092813, 0.12277699308469892, 0.13227568182628602, 0.17705415637465194, 0.08070931682595983, 0.10724284773459658, 0.18957767577376217, 0.14746098808245733, 0.1250212179729715, 0.1794048200827092, 0.16070568206487224, 0.14512775000184774, 0.09094174471101724, 0.2140330002293922, 0.12789953383617103, 0.13152286206604913, 0.13991432584589347, 0.26450377714354545, 0.11602379061514512, 0.08867000840837136, 0.12055963394232094, 0.13245801266748458, 0.09088919323403388], [0.03954543171857949, 0.04978805300197564, 0.025662114094302524, 0.059863342248718254, 0.04684975305281114, 0.05391866514401045, 0.04583304042171221, 0.06255415821215138, 0.03396814739971887, 0.04025408627057914, 0.05382630857639015, 0.0032627592599965283, 0.061283857430680655, 0.034009188166237436, 0.07874711547628976, 0.036697302712127566, 0.0470048173883697, 0.021464907185873017, 0.02684978044271702, 0.04088691930519417, 0.05288868291245308, 0.02365510557865491, 0.0840748155314941, 0.003042078633370693, 0.05145194809301756, 0.0484322382544633, 0.05951008737611119, 0.033543512763571925, 0.02242259681224823, 0.03304564299469348, 0.05519753030966967, 0.005823096153108054, 0.05706473675672896, 0.009221407526638359, 0.05274988645396661, 0.05021020144340582, 0.03713810503541026, 0.04919223087199498, 0.050280690629733726, 0.03020482043211814, 0.01876100530353142, 0.01337327199507854, 0.061041238222969696, 0.023833855557313655, 0.08656878795591183, 0.021292962701409124, 0.029848741687601432, 0.043834310563397594, 0.047830731273279525, 0.02381182861427078, 0.04962789753335528, 0.04140209224715363, 0.05517725854588207, 0.010404735094198259, 0.03558769174560439, 0.011897861077159178, 0.01613103988347575, 0.09147711520199664, 0.012263452299521305, 0.0225040271106991, 0.04762127864523791, 0.03453778655966744, 0.05826561704452615, 0.09725686482852325, 0.05079874681541696, 0.04305842856410891, 0.01301839738516719, 0.07271080539794639, 0.06774749985197559, 0.044440129422582686, 0.025482805649517104, 0.020734897334477864, 0.03144191010505892, 0.025756467039173003, 0.033064237504731864, 0.03569672437151894, 0.049601966893533245, 0.010729164023359772, 0.035495561533025466, 0.05942390547716059, 0.03378777582838666, 0.10209100699285045, 0.046263512049335986, 0.023654090691707097, 0.05956798602710478, 0.031975900201359764, 0.06078020262066275, 0.04266050011210609, 0.0425151801755419, 0.024357470429094974, 0.03646105484222062, 0.03301087337604258, 0.021130578934389632, 0.05186360256629996, 0.03912822598067578, 0.039091304133762605, 0.02037061600276502, 0.0114035397018597, 0.031231158718583174, 0.026085752397193573, 0.0314590017660521, 0.10761971774627455, 0.03904572513420135, 0.004688577319029719, 0.022550361245521344, 0.029574178588518407, 0.06413816110580228, 0.03616958376369439, 0.07778777086059563, 0.014920852136128815, 0.04996472496713977, 0.06636664504185319, 0.05130264653416816, 0.023969878238858655, 0.01409808588505257, 0.0015680309479648713, 0.02841259502019966, 0.02966227151773637, 0.029696840756514575, 0.029876833832531702, 0.033077195403166115, 0.04016245700768195, 0.09332344503491186, 0.07293051821761765, 0.06358819257002324, 0.09935105714248493, 0.03157460982038174, 0.028842725259892177, 0.05730279546696693, 0.012057064741384238, 0.03784997679758817, 0.10113379976246506, 0.04139063719776459, 0.07333530782489106, 0.02745301662798738, 0.025961841565731447, 0.07751331722829491, 0.022200583334779367, 0.04633994583855383, 0.03460026426182594, 0.03195240751665551, 0.038946767162997276, 0.026224613793601748, 0.05359446906368248, 0.01411321271007182, 0.0766100492910482, 0.03115239458566066, 0.04616922960849479, 0.031385543989017606, 0.04373543422843795, 0.04805728298379108, 0.014896048633090686, 0.05347460108168889, 0.05150156437593978, 0.03837557691440452, 0.012205525817989837, 0.025782631455513183, 0.06604476075153798, 0.06196471855218988, 0.02398504402663093, 0.013514767088054214, 0.05767620707047172, 0.047685437311884016, 0.1365265404456295, 0.028373322420520708, 0.021932332201686222, 0.04720676319266204, 0.06289769095019437, 0.028124888485763222, 0.03593401866964996, 0.018867664912249893, 0.012110567095078295, 0.022729524971509818, 0.013656946812261594, 0.003039787484340195, 0.03311977612611372, 0.02330977684323443, 0.02032915592280915, 0.0561775474488968, 0.048159877478610724, 0.06814950640546158, 0.021466571452037897, 0.0271542539485381, 0.0326960209349636, 0.04949533140461426, 0.025764819911273662, 0.02746707476035226, 0.07794915087288246, 0.029883529859944247, 0.043269933230476454, 0.13098701660055667, 0.0236862702149665, 0.04562995913147461, 0.02459272938722279, 0.04049401519296225, 0.026697688408603426, 0.028676918336714152, 0.03657497451058589, 0.061752286201226525, 0.02232838116469793, 0.0588855441310443, 0.04759217903483659, 0.07674657477764413, 0.011398062652006047, 0.05858256234205328, 0.027144735904585104, 0.04765423742355779, 0.01284393609239487, 0.04490047991566826, 0.07223566761240363, 0.02384861872997135, 0.04963255451002624, 0.053308946298784576, 0.00800610359874554, 0.06796933521400206, 0.03386272903298959, 0.009981690509448526, 0.02354973174078623, 0.02294816353241913, 0.013783471858914709, 0.02070833957986906, 0.016188988629437517, 0.06087967638450209, 0.03157489554723725, 0.02077445937175071, 0.027881959431397263, 0.05788995302282274, 0.029356810955505352, 0.039451193806598894, 0.015878392405284103, 0.019042845160583965, 0.051581489969976246, 0.14952677098335698, 0.032220897992374375, 0.0578800898802001, 0.031808378917048685, 0.11252702082856558, 0.0596874272741843, 0.007844867377571063, 0.09096625042730011, 0.0658158007718157, 0.04163140103628393, 0.04725298043922521, 0.10651949123712257, 0.03976845080615021, 0.0024710702109587146, 0.06386257940903306, 0.035035704568144865, 0.023931184514367487, 0.04329971932747867, 0.027742747370211873, 0.0047697446188976755, 0.044434377778088674, 0.03338694186822977, 0.029567246929218527, 0.04850420431466773, 0.037478201629710384, 0.09802252374356613, 0.0826566232717596, 0.014134894554445054, 0.052958715677959844, 0.010854329084395431, 0.03512872906867415, 0.03438247731537558, 0.054782729130238295, 0.003733290395757649, 0.0515578414342599, 0.049898143188329414, 0.0044956031524634454, 0.031853813197813, 0.01973692578758346, 0.04959591467923019, 0.009116969722526846, 0.047452744329348207, 0.02286068473040359, 0.043718784145312384, 0.021054852040833794, 0.07204236782854423, 0.02408018735877704, 0.031776704054209404, 0.05443653208203614, 0.027536235502338968, 0.017759278489393182, 0.03747816081158817, 0.048117749465745874, 0.02817230244545499, 0.030042021062399726, 0.03389391778910067, 0.022956924585741945, 0.019092843649559654, 0.04620884916221257, 0.014947037889214698, 0.0328156885370845, 0.07535535958595574, 0.012964871839358239, 0.022578876414627302, 0.013326467524166219, 0.009412331510247895, 0.013147408626537072, 0.02712702455028193, 0.039534221577923745, 0.04958800338499714, 0.02310055057023419, 0.05668225981935393, 0.012284057102078805, 0.032364618600695394, 0.01969661047041882, 0.10611337318550795, 0.034477316366974264, 0.07931042040581815, 0.0215117200059467, 0.10047811229014769, 0.02746680944255786, 0.014796816067246255, 0.04564044196740724, 0.03919965398381464, 0.012341816600383027, 0.036171583851682954, 0.019622803883976303, 0.055990080945775844, 0.05015783179260325, 0.008705713225936051, 0.06654288285062648, 0.008418876859650481, 0.025433048358536325, 0.022156596241984516, 0.04536478234513197, 0.06165406295622233, 0.08178347168723121, 0.04355492907052394, 0.04728547908598557, 0.0656845816411078, 0.0341728391504148, 0.021514640357054304, 0.05942194620729424, 0.017790335514291655, 0.04263568640453741, 0.05558880169701297, 0.059105576074216515, 0.13980335992528126, 0.008738750857446576, 0.039972823433345184, 0.05655348606524058, 0.06945331886527129, 0.03514211370202247, 0.016866163132363, 0.040175407484639436, 0.027743877290049568, 0.04043753033329267, 0.008943589182308642, 0.03764232387766242, 0.010604849649098469, 0.10327819094527513, 0.09318495285697281, 0.12426819783286192, 0.17201745242346078, 0.2480814146110788, 0.14236172108212486, 0.09606302381143905, 0.1797140878625214, 0.07491629759897478, 0.16476833203341812, 0.11702742660418153, 0.17606499226531014, 0.20627340098144487, 0.18264625396113843, 0.19966969673987478, 0.16106164577649906, 0.2692399558145553, 0.13585716777015477, 0.09865674830507487, 0.13804641435854137, 0.15422477357788011, 0.155565062595997, 0.27822890784591436, 0.19799992383923382, 0.16487195069203153, 0.19522028393112123, 0.15164113487116992, 0.09711332604638301, 0.13198302331147715, 0.12262868229299784, 0.11885204119607806, 0.1311927250935696, 0.12625971401575953, 0.09832564654061571, 0.1514788271742873, 0.1874719059560448, 0.19246326468419284, 0.17285937443375587, 0.18118897278327495, 0.06568976183189079, 0.12128912057960406, 0.13679767667781562, 0.14915979380020872, 0.053671555942855775, 0.1564950923784636, 0.13800394866848364, 0.14814388268860057, 0.09194284255499952, 0.15066483960254118, 0.0895175855839625, 0.1440740338875912, 0.08724388258997351, 0.1227480493253097, 0.11838236561743543, 0.1254696978139691, 0.1294801154290326, 0.2774853352457285, 0.12376721846521832, 0.10501456417841837, 0.1270476818899624, 0.13090028922306374, 0.1521693213726394, 0.10915151055087335, 0.2633869042620063, 0.1734709634911269, 0.24129491939675063, 0.17741688847308978, 0.2187482948647812, 0.19887504953658208, 0.0882368984457571, 0.09525360786938109, 0.2632801834261045, 0.21209967584582046, 0.15606268745614216, 0.10420143749797717, 0.12054469450959004, 0.18465910688973963, 0.0910028160433285, 0.11357608367688954, 0.2161280089057982, 0.1256268550059758, 0.2343170836684294, 0.20154200174147263, 0.08665378612931818, 0.14999285456724465, 0.13432699284749106, 0.1158263125398662, 0.11057154333684593, 0.13397416099905968, 0.12323085349635221, 0.17359776684315875, 0.15202801645500585, 0.15981066680978984, 0.16125867114169523, 0.1805638024234213, 0.12131661715102382, 0.08239111251896247, 0.17233494319953024, 0.1495957758743316, 0.11850654918816872, 0.11854507407406345, 0.1611305319238454, 0.09765811439137906, 0.1698808092623949, 0.13690580759430304, 0.09848657384281978, 0.21546776464674622, 0.15001241758000106, 0.11809840507339686, 0.21464954683324322, 0.11735216816305183, 0.14935937215341255, 0.1373301973217167, 0.10560221897321753, 0.12552112864796072, 0.08899033418856561, 0.09714796207845211, 0.1942805023281835, 0.11547748828888871, 0.09842833751463331, 0.14651659032097086, 0.11940157928620465, 0.2253618251415901, 0.15044831059640273, 0.14882115181535482, 0.1394966451334767, 0.10394495126092806, 0.27587564662098885, 0.165895446552895, 0.08057261322392151, 0.09992084844270721, 0.2521720138611272, 0.13728817692026496, 0.15797285683220252, 0.09103381555178203, 0.2479652684996836, 0.10080188905703835, 0.10926077695330605, 0.18942357623018324, 0.11078589042881504, 0.11732681639841758, 0.12370162745355628, 0.16416340746218339, 0.1598583720624447, 0.08396248405915685, 0.17538102896651253, 0.1466640253784135, 0.1154307700926438, 0.09229854651493952, 0.09041502766194753, 0.10130893919267692, 0.13566412031650543, 0.17121173237683252, 0.09369079329189844, 0.10376008969615214, 0.15079619974130765, 0.19458319467958063, 0.2221752656623721, 0.1333514545694925, 0.07805825400282629, 0.093096028722357, 0.08953510026913136, 0.09500430562184192, 0.2466980810277164, 0.11129003134556115, 0.06830272279330529, 0.23686520318733528, 0.14260477444622666, 0.1585883941152133, 0.12095633413991891, 0.22624961187830195, 0.08363764602108859, 0.11562712010345422, 0.09454821876715869, 0.07519521153881215, 0.24869031709386036], [0.021894209930906072, 0.07193979559815489, 0.03551096851879265, 0.05791677795059513, 0.0312791793840006, 0.029192438232712448, 0.041892970984918065, 0.019432264889474027, 0.03335430963488761, 0.04869908116234001, 0.024490817668265663, 0.0167594645608915, 0.03427443545660935, 0.04866661962296348, 0.06998157958150841, 0.09351672255434096, 0.04411650850670412, 0.011873939802171662, 0.07823663661838509, 0.025474827561993152, 0.08908828283892944, 0.0727899257617537, 0.0760521917254664, 0.022711266283295117, 0.04079084828845225, 0.037148012706893496, 0.004963765213688021, 0.060419055007514544, 0.04241339091095142, 0.024795417339191772, 0.06978934849030338, 0.04461138742044568, 0.024057735536189284, 0.030975340414443053, 0.029005311262153555, 0.04248184290190693, 0.017091521840484347, 0.059037146347691305, 0.022031646403775085, 0.04243572213454172, 0.015089494991116226, 0.017291050098720007, 0.03039573050045874, 0.06702009864966385, 0.0582570860569831, 0.022871694491186645, 0.01742674437991809, 0.04515729640843347, 0.08043291134526953, 0.048813880275702104, 0.03272061570896767, 0.10816564899869263, 0.01230990146723343, 0.0698256617761217, 0.0825026944221463, 0.06771322005079128, 0.015201053702185163, 0.048791745721246116, 0.0653037559823133, 0.08318226420669816, 0.02223192794190254, 0.004276680256225518, 0.04162685167102609, 0.056638851601746865, 0.022593647008761764, 0.05213066811847966, 0.05330281244823709, 0.12054793027346022, 0.027643062094284687, 0.012113541251892457, 0.0552051373233553, 0.039742668595863506, 0.035292851316626184, 0.04331499272666406, 0.04932856340019498, 0.032720563758630306, 0.04020714171929285, 0.01899786730064079, 0.05335210218618158, 0.0023812654717403348, 0.07932515945867635, 0.06385894288541749, 0.09634406029363163, 0.013320022899279138, 0.010878283756028395, 0.06781489428249188, 0.03216897734091617, 0.04297962361306418, 0.035651950602186844, 0.043949469618382864, 0.023721436882624403, 0.04644789863959886, 0.017108674728660844, 0.029945690293970983, 0.02588810177257983, 0.04360107210231945, 0.033782666141632944, 0.02693599944905145, 0.031874307605903596, 0.011458069002401317, 0.03798957106482703, 0.05273587099509314, 0.017318500285909977, 0.08301200068672188, 0.05071955965831876, 0.031352010046248324, 0.006512641793960938, 0.03007479986990802, 0.0073096972664643545, 0.028696453518932685, 0.02308191153133521, 0.06256741296965629, 0.052036916313227266, 0.021369932692323346, 0.04538801156741101, 0.024062956545094494, 0.04161075077718124, 0.08326849434524775, 0.015397340630443068, 0.04573099882691167, 0.025799637769523542, 0.0512217895447975, 0.003968460760006565, 0.02127101553924149, 0.034228155127493665, 0.007540511687693652, 0.03340717652463354, 0.07062960808980279, 0.0354966821760172, 0.028352421686577145, 0.060278514501987956, 0.010357753435528139, 0.021803345080115832, 0.04361919534858316, 0.027378657141525764, 0.05082213559944648, 0.03575924289179966, 0.04524835050688125, 0.03952633996959776, 0.0336077456449857, 0.035953340484411456, 0.015573080272588413, 0.044498024362837896, 0.010725841984822182, 0.01175950712422491, 0.05246972570603248, 0.04810222002561204, 0.029372904427873436, 0.05595754519163165, 0.10071921380585991, 0.03308494713564869, 0.04351925032096915, 0.06364659217069857, 0.01984244805498747, 0.04985853847756516, 0.026898879077634774, 0.04801623108505737, 0.06554274979862384, 0.04119797937164549, 0.010051813260361087, 0.04720684482890647, 0.055101514954003505, 0.058400183261255734, 0.03879976626194548, 0.01287098551983945, 0.04580959226586856, 0.028093163527955767, 0.05656977620674297, 0.016595733795838896, 0.015112970049813157, 0.04900890926364809, 0.009740121440700023, 0.05180342552193906, 0.03816550088231452, 0.013232390101620695, 0.06966420012759045, 0.032495889681740664, 0.07590009598061442, 0.0404724706459092, 0.020385297539178282, 0.037967276948620565, 0.0456005700834794, 0.04314417630666867, 0.03351971950905863, 0.037130787459318526, 0.07657406997168437, 0.031696006626589224, 0.03513311516144313, 0.02231434715213254, 0.013443761181406444, 0.03759937950235326, 0.04602812507073395, 0.02535162177082384, 0.014610010075557511, 0.1147069015132729, 0.015141911953833187, 0.07461863700882532, 0.02682192764041247, 0.05664692616846878, 0.06801334457122721, 0.017656561540206894, 0.031445149579667486, 0.021686310246877838, 0.015018893554952228, 0.025578160493751056, 0.04610216914443299, 0.04757682399940677, 0.0627850106684491, 0.04275661936844699, 0.00936171703870059, 0.011532408079801826, 0.05107882963784505, 0.014594761723856209, 0.01420903974576504, 0.016738482190703508, 0.049177777545992285, 0.05380035196139943, 0.03753262331883889, 0.016012086598493624, 0.01333392146989354, 0.07717451939242892, 0.04384425534226466, 0.04935509146889672, 0.03585784463211894, 0.030443085088336375, 0.009940402051142883, 0.03436299222812522, 0.08656396399601363, 0.04779068869538605, 0.025545706375851296, 0.07562892264104448, 0.075937990040984, 0.050144588167313486, 0.13007895438931882, 0.033835213907877915, 0.06914754660101607, 0.038243508024606854, 0.034396010378259234, 0.022585101178265177, 0.05663235038809944, 0.036656744341598824, 0.06722561418428086, 0.08232876469264738, 0.04870419084909372, 0.03605014622735325, 0.03639475879026577, 0.03764024586416781, 0.02289608517457964, 0.0499915647378657, 0.026561070153547917, 0.008361802920262562, 0.026745807408588007, 0.04040380343212746, 0.048802851961227134, 0.030892874819983263, 0.08241358475061134, 0.01824579154344974, 0.04862826543103438, 0.035438572012935765, 0.05496386511367746, 0.049581160783418454, 0.030848073220113292, 0.017398529780621175, 0.01564338948810473, 0.03823310682491865, 0.052534481801558286, 0.029507021645258646, 0.03694952902151272, 0.06125036801677197, 0.029291401770024095, 0.03318678092909977, 0.039835700517869554, 0.009281531692977296, 0.012869924248661846, 0.044369161551003344, 0.03449889431067277, 0.014158370540826581, 0.04406263600685634, 0.0434194017725531, 0.030306498374557123, 0.016888433128769975, 0.02903211207012646, 0.05599676398560405, 0.04151259061472956, 0.016462202875118237, 0.012839428472943837, 0.009460452365601668, 0.038666380060021766, 0.05603976773272734, 0.02459474802890327, 0.06395508811692707, 0.03716200590133667, 0.08047161434660666, 0.031905314535833895, 0.03635995206423104, 0.018587088561616838, 0.006253568244574126, 0.0347215349029284, 0.01746872210787842, 0.03966959302488249, 0.020696673018392175, 0.047883787410683, 0.025162244237435516, 0.051612585957627743, 0.04411107598571107, 0.015367720588983502, 0.04137971278396435, 0.04777671776537318, 0.022406065472750925, 0.060530900373123586, 0.03790231676248368, 0.10638396022841334, 0.009439759433007566, 0.031885565986158326, 0.018043441268673632, 0.00632559785117337, 0.050707781774690375, 0.0330157604184933, 0.02759672424872406, 0.04461643773538526, 0.053406913502840325, 0.03558308300853241, 0.006619832038268214, 0.06177522227517329, 0.026167848773184232, 0.045971844301675446, 0.019277961255284026, 0.06521685048937798, 0.05556245545449201, 0.060232957766857, 0.13637619616929442, 0.04560043278615922, 0.04986407860997133, 0.03898917348124087, 0.0355545140337199, 0.03767536058148835, 0.031346469913842157, 0.023092841511243023, 0.08874473525793292, 0.04856011029914953, 0.09398266513017006, 0.03619184819399379, 0.03316073154564947, 0.05098507412185427, 0.0328886342322221, 0.020160584499535616, 0.009010178382595768, 0.04431863242643885, 0.02276287708809832, 0.01806239757570438, 0.019127834057144355, 0.044789150342694484, 0.0972883689973969, 0.19387827313039452, 0.12973526580026373, 0.11293121671769768, 0.12318852139287628, 0.19376677286345512, 0.09388182210386731, 0.085491723875748, 0.09120833899942227, 0.2833355072652921, 0.2013536001322791, 0.12101272252039053, 0.08714023424545303, 0.07972967447130941, 0.14839149283943698, 0.21327065129298717, 0.09928488725563511, 0.10465711617143825, 0.20346698438515887, 0.09235804449417628, 0.16693457204382867, 0.10517699061892927, 0.1586990780197084, 0.2057217329274863, 0.13442379859043285, 0.16684967034962028, 0.12357280545984395, 0.19990981119917706, 0.14086926210438833, 0.1493684115121141, 0.17870825511636212, 0.23436974646756425, 0.10822714335517958, 0.1370265253353864, 0.13787270727334544, 0.08853102641296573, 0.08165611172444187, 0.13991383602842689, 0.09190526019665413, 0.1824547056457959, 0.08323382862727158, 0.11039931312552653, 0.09046340084751137, 0.19403354526730254, 0.10525910925935023, 0.16007660800823942, 0.17262878915062174, 0.1715991334640421, 0.17071167327230796, 0.10422720486531034, 0.15627623302862048, 0.24709078104933724, 0.1833678293041885, 0.1343661337159574, 0.19891383417416364, 0.1802903803763911, 0.13966211437946185, 0.30196771840564907, 0.1487737285788171, 0.16510678105987608, 0.06305049915681593, 0.09333259571576491, 0.10110680042998865, 0.19965218205470592, 0.1505259540863335, 0.10522146010771394, 0.12757713004248217, 0.19506738666677848, 0.13648474268848076, 0.06673333278740756, 0.1001962817099411, 0.07525378925492987, 0.11816130208899267, 0.15848974784603342, 0.10370520787546411, 0.0752578562241979, 0.09109989638091065, 0.11712178325979039, 0.16376904502976686, 0.14479690056759864, 0.09122602437855676, 0.13668582017999142, 0.13780438515823334, 0.12134262200561352, 0.12824225763324648, 0.15818356740055606, 0.1404823805205524, 0.14451684372033924, 0.17094148672185838, 0.15200358495349064, 0.1588518120115623, 0.1873841544147581, 0.11515878039062954, 0.13535749458242208, 0.1369355825590901, 0.11007456414517947, 0.2324505674187094, 0.24082181509584188, 0.1302199624478817, 0.1287774500087835, 0.13569947623182088, 0.11520559506607242, 0.11280828737653792, 0.13801405671983957, 0.15974457113770768, 0.1598158766864799, 0.09989906640839763, 0.0971433162339963, 0.0829266314394772, 0.16775808879174292, 0.07317141935345717, 0.14504185382975265, 0.19880332838511094, 0.1493216265225783, 0.1892660924931988, 0.12465943582355976, 0.17150743369711563, 0.1988842966966331, 0.10361284759710543, 0.09373791224788874, 0.07042407029075548, 0.176328128145542, 0.06976561460760422, 0.11705396580509841, 0.11701033494318835, 0.16223999817157164, 0.09857138647930697, 0.22932688269065693, 0.11334496404742822, 0.08421672901022248, 0.10587442389805801, 0.14925680734449998, 0.0947916877339594, 0.105959370121127, 0.14938996348064393, 0.2055936530814506, 0.11429548452724703, 0.1479960765573196, 0.152768561092671, 0.10528301383601502, 0.08705144369741902, 0.06237679976038635, 0.1533974421909079, 0.10771546221803874, 0.07653737819055095, 0.23668379260925576, 0.12788786727469414, 0.10824135548318736, 0.2632872189860791, 0.23954051197506487, 0.18243052647449076, 0.13016905111726373, 0.2124281504075043, 0.14441184466704726, 0.19451948872301728, 0.1475253768148832, 0.10606459181872196, 0.1840676151914522, 0.12005156706436537, 0.10010973986936733, 0.12099429499357939, 0.17388542328262702, 0.29015352891292423, 0.10286498538334854, 0.3007493494078517, 0.18926560267573223, 0.11473800492240116, 0.1308919326402247, 0.13316327560460195, 0.11211253877263516, 0.19075078860623762, 0.06918549261172302, 0.253632590174675, 0.09654518973547965, 0.1793157623615116, 0.12966491020051762], [0.02098671731801005, 0.05040521558839828, 0.017373608461639378, 0.07328661551582627, 0.0205798552633496, 0.059805874043377116, 0.018286498343513813, 0.0753912646905519, 0.03863016696413979, 0.0534184947173344, 0.027414517717261333, 0.06136645475635305, 0.10679568149498664, 0.010111334431712748, 0.03788826419622637, 0.048264605648000725, 0.006386572240444366, 0.05103123199660331, 0.033552336899447255, 0.032788466560305096, 0.036191243343637325, 0.02093223069095984, 0.05647217636578716, 0.0310498928593006, 0.03224292864615563, 0.020180459214316215, 0.014629612051066943, 0.024313999128935393, 0.0413728627609089, 0.014489052064163843, 0.0672275066608563, 0.022314102243399248, 0.04170841370068956, 0.03037787628272781, 0.08162061480106786, 0.028229035924596246, 0.06747070103301667, 0.10704625281505287, 0.05292321504384745, 0.01744160403177375, 0.018799053359543905, 0.02643088260811055, 0.08292505066492595, 0.018040769537037704, 0.049121856718556955, 0.023231630548252724, 0.025954345874197315, 0.0467594856309006, 0.004377682380436454, 0.011792009481723653, 0.047585837382939644, 0.03206404879165348, 0.030780951528868172, 0.051497623571776785, 0.06831486432929523, 0.05691744641808327, 0.056535685653216206, 0.013352449186641024, 0.04481878429942299, 0.0680037634447217, 0.012940210272063268, 0.0018691403215598257, 0.04287352989194915, 0.03563923019100912, 0.025436022515350487, 0.030263190346886404, 0.018741574021987617, 0.029150161790312268, 0.06882895744638517, 0.026951337786158547, 0.08151775313308463, 0.041996044164989144, 0.021212951760389842, 0.026622742625477258, 0.04344493165262975, 0.026131912127311807, 0.05810922426462639, 0.019320180181239266, 0.049011803639587015, 0.00879009819982457, 0.028035125724272802, 0.020373540064611007, 0.044367614173097536, 0.10157570417504758, 0.0733340832812246, 0.04113030663575046, 0.014206260402715998, 0.0201884966736543, 0.029687450733035803, 0.027922196823055856, 0.05287071180646308, 0.00526533042830124, 0.041534387491992675, 0.028493587451521307, 0.06920823943801224, 0.05001766978239175, 0.031249393286998384, 0.011195117731404025, 0.0477850780589506, 0.05533112431294285, 0.017544718029967044, 0.033594372143852524, 0.03306585909740534, 0.004126782660023309, 0.004383046252769418, 0.037650339072570205, 0.031868993828538805, 0.046125813969410956, 0.006406528127627098, 0.06002795802487526, 0.0404692385927774, 0.027423184146755375, 0.08627299015643075, 0.02728184212173801, 0.02314383633347461, 0.04320605286920909, 0.06019866683345754, 0.036245156661607325, 0.02459118200931698, 0.018923543066193815, 0.013030839490966173, 0.01661348967900267, 0.019610111303336453, 0.011747269109037006, 0.03975889936555177, 0.01148556279076729, 0.07719578192336485, 0.03216511817299761, 0.026375770721642766, 0.042185236161458306, 0.016463542451674584, 0.013831499018124305, 0.09299877769080922, 0.05961302696960047, 0.0684894916776102, 0.034085410443367437, 0.0474598281289218, 0.05127774376887828, 0.030055559691390954, 0.041346208527102135, 0.02170088602724718, 0.04855131213844288, 0.10236960923066363, 0.06916218917467631, 0.04343988504842855, 0.0427061793016037, 0.043143530638189986, 0.030853401840431616, 0.058104823328903876, 0.06688591092824936, 0.03849377877486404, 0.060681552640744485, 0.0240593033231562, 0.06761413591448218, 0.03360198657901492, 0.04155737922701519, 0.045663660057471134, 0.029641320688824635, 0.018981577159138396, 0.011706413879437605, 0.03648612830147613, 0.022577663003175985, 0.04504983713559341, 0.046404375389101915, 0.03178182858391665, 0.053217999811749905, 0.009907675193971954, 0.0006209804143963993, 0.020593575718521606, 0.044708638451993465, 0.049542305641807616, 0.0745983244269155, 0.026258349971612915, 0.061899209176772274, 0.025178460164170247, 0.04034202705952339, 0.08188584353774786, 0.022245420186663978, 0.03828993307251949, 0.0887553628126625, 0.03071239192649955, 0.03406027390155941, 0.030243291512306314, 0.010870436472032452, 0.009635119604354259, 0.04565850584185682, 0.01826307430746965, 0.011469130713521736, 0.17223181435838342, 0.034381631267024204, 0.02964931361930212, 0.017708997984300368, 0.005662558942276519, 0.03533544317178894, 0.022132235244498588, 0.036078941557207145, 0.035567353188525885, 0.07579462937428616, 0.036313701421022415, 0.05409686593338847, 0.07429647070239298, 0.017559468215040397, 0.017336471391899977, 0.0615498505794676, 0.026845746870094445, 0.035261822122265585, 0.04036871840071399, 0.07474704339983873, 0.05217288518906571, 0.03492469040793367, 0.09147963850409724, 0.046925077331252396, 0.04227438665111549, 0.06660995073616505, 0.015723554424766917, 0.015665646496927366, 0.04234250838635489, 0.0693896871234756, 0.04611848526110407, 0.031295744120143354, 0.03226287386496551, 0.007975603184604552, 0.03694874234497547, 0.029341116387513466, 0.029123501990397926, 0.03615098183217924, 0.08002057409612462, 0.04320624211686663, 0.07594404596602544, 0.021373212985054124, 0.06518262263853103, 0.030058862248552032, 0.07564982894109562, 0.023718486845609732, 0.057360471473657526, 0.03494689546641894, 0.0247501073681633, 0.019323851956869476, 0.015469193513126811, 0.012740845286316471, 0.028116619105276186, 0.051789703211397864, 0.050328106444794685, 0.03321260024677031, 0.08028339085285552, 0.060364384698914364, 0.036639760292018764, 0.025801073825277854, 0.011170500692969654, 0.01691642693913309, 0.05150056618731469, 0.042814094995264895, 0.032025661203078926, 0.062105682081892155, 0.017321929008176085, 0.027703517444024328, 0.02012530094361864, 0.02864980953745544, 0.08479910713504069, 0.09349975705845281, 0.07283482569619082, 0.05183804671105463, 0.012995828674320364, 0.05987775475659873, 0.05009928376239259, 0.048729030531831086, 0.016187563705898356, 0.05276565709209535, 0.028603634964383673, 0.05843603270477615, 0.010073928333440563, 0.06496532922028564, 0.07060927324346267, 0.03923999713151716, 0.06912126715178601, 0.05555835879931692, 0.05578699223406147, 0.03996616265794728, 0.02675434767297702, 0.038581882836297154, 0.021889167037443258, 0.021421755009214394, 0.05664750133291818, 0.043973270294372924, 0.01664105675445171, 0.03163519133522641, 0.09544441403704695, 0.08089853479759768, 0.11008252738974988, 0.05884595426323358, 0.04091960348887369, 0.06292839359957725, 0.05333634268026799, 0.034822151574189775, 0.02722189514315687, 0.01222671227878891, 0.03400902118301019, 0.019393381917325314, 0.012164070376456948, 0.0393004302168265, 0.022857076037325896, 0.03751313081011176, 0.022975263054831885, 0.032503648835700005, 0.03552269816282205, 0.04682949984271545, 0.0074673632934718626, 0.015272901018761331, 0.019091481808573008, 0.044953023971174844, 0.09618213851354085, 0.03584608530218247, 0.061033835299895145, 0.029732710609096102, 0.07741044813883491, 0.07239308455609716, 0.010947148566629039, 0.04429951099155005, 0.11813343444373459, 0.07160634122556075, 0.01652091603318695, 0.04105638130567968, 0.04348911170382053, 0.046036036364967, 0.02667834432941163, 0.03388347948202863, 0.021193650354689453, 0.04857130188611336, 0.054678828455507755, 0.024127747892634943, 0.049424586177337915, 0.01864469963038573, 0.0160852159751812, 0.017928985398611985, 0.0355142339685699, 0.02132383790012682, 0.018282785749761388, 0.034065543150063604, 0.03090434842306422, 0.06900650885654613, 0.023589813281432725, 0.010064625512313796, 0.029720810271101072, 0.043428144272184, 0.05468308838317171, 0.017946153129742015, 0.034974228765349835, 0.09729428391437978, 0.04352183670562226, 0.03221831902919803, 0.0450483120221179, 0.004251148984621977, 0.16546299710171297, 0.16694134043063968, 0.19832001213217154, 0.19338731275638565, 0.09483196408837102, 0.13699528091819957, 0.11789591750130057, 0.13394404464634135, 0.11614239323535003, 0.13357316376641393, 0.08014174454729073, 0.34271411946974695, 0.25179283577017486, 0.0949816033244133, 0.09605084516806528, 0.1840500411344692, 0.1462826505303383, 0.13748364377534017, 0.10620701737934723, 0.10585569209069945, 0.15321395359933376, 0.15197208820609376, 0.0792007458221633, 0.09117452675127424, 0.09725828975206241, 0.07619610900292173, 0.13551058480516076, 0.19575618876842782, 0.15728165017208084, 0.18340029084356502, 0.15764251205837354, 0.14937813364667818, 0.14664361631730571, 0.10930414064205252, 0.21255597792332992, 0.1774279761593789, 0.17917948920512572, 0.23060340638039634, 0.19477449066471308, 0.1570911260205321, 0.11844686567201279, 0.15932718728436157, 0.14841154566965997, 0.10271096005453728, 0.08325161048560403, 0.09670900399214588, 0.19003069755854085, 0.18508311070036143, 0.097895824292209, 0.11626705920207314, 0.2592193294549361, 0.17182008567033336, 0.07527508889324963, 0.13588198518846184, 0.155161690490786, 0.13126251666108146, 0.17814193706726655, 0.10506115620955825, 0.1650055224308744, 0.21678697667084634, 0.1505098197958432, 0.1459950237767771, 0.10232785600237548, 0.15202147071249783, 0.11649690233753063, 0.20394091989146546, 0.13913777220295742, 0.06854253297206014, 0.19288910902105272, 0.11503579909913242, 0.11354008951457217, 0.06830822952906601, 0.09496425933321007, 0.22903030563611537, 0.13849755108822137, 0.11035338902729563, 0.15699791227234527, 0.11967849684879184, 0.09267764296964742, 0.1209689283859916, 0.1294411823619157, 0.15379741525975987, 0.17416500515537336, 0.18453746888553724, 0.21534630475798622, 0.23347579990513623, 0.07214262455818243, 0.11824253015220165, 0.17580423125764355, 0.17433994420571253, 0.150715691561345, 0.21044817462097853, 0.09787611284991726, 0.08851716309436597, 0.11344559927238151, 0.20462700573261827, 0.09251560244592838, 0.08493685716530308, 0.24027286330237985, 0.08784546007518657, 0.07996297601494007, 0.2092778671067208, 0.09393189480761066, 0.11592879571253434, 0.1773670458351262, 0.1443876209668815, 0.11544406195753254, 0.31147311616223305, 0.09913860252709128, 0.14205101353581995, 0.19761608506087214, 0.19962938327807933, 0.20453089760849252, 0.11786387156462297, 0.14035330619663, 0.08622455017757602, 0.14769164758035913, 0.138059773016721, 0.2114898234140128, 0.14730501832673326, 0.13568435126217082, 0.11365161204594187, 0.12141166400397196, 0.18811288406141102, 0.16828010062454268, 0.12832065811380744, 0.09156949032330886, 0.074677311204141, 0.18701652414165437, 0.25269519828725606, 0.12646681774640456, 0.10257395217195153, 0.20830529741942883, 0.1495624237577431, 0.16837766335811466, 0.13624603830976412, 0.13983683078549802, 0.15418395545566455, 0.12466090527595952, 0.135737385135144, 0.1890666625695303, 0.11289986839983612, 0.19992548535810784, 0.28609125001821667, 0.12601335067301989, 0.1562305464176461, 0.1045173846068792, 0.15441804367583245, 0.14980776293668896, 0.17901559331221506, 0.10327128155040555, 0.22345112141920254, 0.18881627678638324, 0.14254279027227312, 0.16341561946319416, 0.09951588814146817, 0.12070778146153316, 0.14068589225644246, 0.10048389362054877, 0.1115559354366269, 0.15578548045596108, 0.09568514447892085, 0.14221299468772486, 0.12075062564690597, 0.11004964282619767, 0.12544775992864743, 0.1445961941499263, 0.18496300152037293, 0.168151575489901, 0.19244006514782086, 0.1547047501662746, 0.194245116726961, 0.17146804049843922, 0.20380273199407384, 0.1014721003593877, 0.10953473334666342], [0.055577895836904645, 0.03457106446148828, 0.04570604411128443, 0.05331637519702781, 0.032273824253934436, 0.08949556606239639, 0.05128548807988409, 0.11310788497212343, 0.04387442364532035, 0.026420247631904203, 0.08018325286684558, 0.018692685043788515, 0.003963590415878571, 0.04978428660251666, 0.041054277317016385, 0.04883232635620516, 0.0642575355595909, 0.012833937507821247, 0.05419966080808081, 0.05527937064471189, 0.05857768272107933, 0.06154728645924479, 0.05012708832509816, 0.08261472903541289, 0.015912764974927995, 0.031084888832992874, 0.07114688502042554, 0.024616259179310873, 0.07043511344818398, 0.10401826802990399, 0.018374231331108604, 0.025824690819717944, 0.052443787644733675, 0.026030822336906567, 0.05737032348406501, 0.026574254407023545, 0.05486074740474578, 0.04534305597189814, 0.048314366649719886, 0.03937081550247967, 0.04890840020379983, 0.031027326003822964, 0.030826901602267753, 0.06400318670785055, 0.05349592298443895, 0.0294870244761114, 0.009568369914632058, 0.0490316598006757, 0.06449144566431642, 0.07555504926131107, 0.03961175745644141, 0.07813450225512497, 0.0643878492701333, 0.024207801507145632, 0.03352950472617522, 0.024657632056914736, 0.03630948231148068, 0.03834774637653027, 0.05028963350923732, 0.014483880222542211, 0.06144435428723227, 0.053612581177731045, 0.05818738354719244, 0.02152213048248086, 0.0052634755229519214, 0.08104097520117648, 0.06414237650460564, 0.12276879977434874, 0.059933642187388614, 0.04122202124563046, 0.029991477094881702, 0.1101785538776312, 0.05160640757821966, 0.06724036065861583, 0.041200521227438, 0.020317558009992354, 0.03595338872401044, 0.04189147555734962, 0.04533903353149071, 0.0562526861904189, 0.020566457642416935, 0.09656017369707115, 0.019562250199669506, 0.03873354071401991, 0.044243389784242027, 0.08043112276936881, 0.015603313513565809, 0.07508447568397969, 0.046022840979276225, 0.044747471329174004, 0.045757304251310416, 0.08452051974018104, 0.03084860014496371, 0.02110479115799535, 0.058053592874784954, 0.08430447313003242, 0.035408299809205346, 0.037323875731090084, 0.026791406817210373, 0.016546453334740363, 0.049671520973788574, 0.029203219783084933, 0.02393642036622623, 0.03792354960751254, 0.03355300483235624, 0.011620336808846332, 0.08947627764428034, 0.030295382857730146, 0.01855363996583037, 0.030568205620511435, 0.04709643922979012, 0.04176016365818214, 0.05353429201932158, 0.021190279148868285, 0.016688537507434376, 0.025350148607685696, 0.08658412072691135, 0.04813189108972438, 0.030287909430626314, 0.03533977360348217, 0.037781198261654936, 0.07076650465023704, 0.02538655280659441, 0.004094585510756588, 0.0569803174585104, 0.02860809527192032, 0.02903872275055619, 0.01959898836503271, 0.0436036065366352, 0.010320209112251177, 0.030119748043944128, 0.006048603290764731, 0.040868035357561894, 0.046014198669581674, 0.04932012889184989, 0.03690216144605074, 0.05339388510037679, 0.054829907458042726, 0.0627543599694036, 0.04216306821035687, 0.009725656982482178, 0.02603321205242537, 0.05982111033517867, 0.01597705908352509, 0.02018580267758807, 0.007740776991340681, 0.016373813086829614, 0.06578043743502349, 0.042138837088714354, 0.022233710951695684, 0.05325327780155931, 0.052042263487237506, 0.012876789114670828, 0.01608480408322066, 0.08743480750126764, 0.021137894655112177, 0.028143930139776785, 0.05027888350014109, 0.03205292028724216, 0.003105069808952976, 0.03181679858244024, 0.050818684612750076, 0.0229645037688897, 0.03759005441679619, 0.022252990092965774, 0.07399213820463046, 0.032101686811074615, 0.06140580342616886, 0.03158829873427749, 0.015945835075399373, 0.044835033622803167, 0.04807945093489252, 0.022487256428576075, 0.02617230908072088, 0.014448045621975325, 0.03223719555535354, 0.024454892154608388, 0.05857518168340903, 0.07078347014612518, 0.03264836392190773, 0.03888356586685404, 0.05216089579334948, 0.05407473880040925, 0.0543976992048556, 0.018893474953074474, 0.02090491780109005, 0.13713747641304508, 0.05230670183664188, 0.04514673935773317, 0.042172437824774534, 0.038107442669570446, 0.033069803612306714, 0.1263688097242266, 0.042819842929020524, 0.03404794682865031, 0.00660482302919263, 0.042899438267340884, 0.03397700122150127, 0.01850555436249124, 0.022307467443170026, 0.012147096531407442, 0.031523999059572816, 0.0730001761985477, 0.0474270289123524, 0.036374902629177086, 0.0640444501186721, 0.051949884655186906, 0.06468339473940432, 0.027626308110484388, 0.025706724591145758, 0.09045143742696382, 0.011399476443330059, 0.021818529421580024, 0.06102977575210389, 0.024387573794228956, 0.08483284516842104, 0.03338845584949013, 0.061125642678234726, 0.08235083616455086, 0.05564586172113195, 0.030037004144105595, 0.01070238269676338, 0.017051735303539317, 0.03144619971862994, 0.06886415751068853, 0.07363952900050208, 0.05639330091071315, 0.06127076965640299, 0.03157749306410551, 0.05801312727271579, 0.009517490125290351, 0.026993256142304745, 0.002559143426879018, 0.049637920237728395, 0.05879778887901921, 0.08828121950500645, 0.061848234763601795, 0.02742664255492855, 0.0428820163506316, 0.03603045333875343, 0.01949977991898777, 0.0038680064335494535, 0.08643847424536943, 0.04102195307496004, 0.02898908049246529, 0.015325800377468113, 0.019640951250039507, 0.030762442365812603, 0.0712116967770271, 0.04913293327263091, 0.012655476966756396, 0.010126560518983752, 0.04908678281935863, 0.0390437881287653, 0.09647240731283091, 0.05342541895515751, 0.02731245014729211, 0.048652808254701085, 0.06049741838069167, 0.01577748258569045, 0.044549562808242626, 0.026350038606324233, 0.049710205421433784, 0.05289965927659068, 0.02905227807787014, 0.040439760487060994, 0.025102339932345785, 0.021121055324329063, 0.06471324391895905, 0.04212809079035651, 0.05304923914081883, 0.05609870910120662, 0.045837393117835745, 0.023251297461683862, 0.04499308139202185, 0.01842748599301558, 0.07368189821136184, 0.040643914180691354, 0.03995950559328776, 0.017971089291677345, 0.02114464448823128, 0.01902402986161178, 0.04896575708698947, 0.016923045041039586, 0.04998401338525582, 0.024555551499361172, 0.04708199332526419, 0.08432839997112751, 0.003230144652661693, 0.06273576174862683, 0.01721689655823866, 0.016080915229395032, 0.03905056764779147, 0.02097205990139628, 0.04168334766291082, 0.05158182764716912, 0.05200270330533385, 0.052758580713998526, 0.05962032599200029, 0.018254359638376627, 0.02437881088553695, 0.0733660624246113, 0.01892940232210094, 0.023851342411944643, 0.017674536356935278, 0.009469834039919078, 0.07895029324572533, 0.1003798222518526, 0.06841875016107224, 0.038313911863951944, 0.028202051435073372, 0.04033223071019165, 0.02469647235557204, 0.004862698151555378, 0.09698984009446576, 0.03870514243317302, 0.05761776294093579, 0.1075286116974894, 0.06691421644063666, 0.030976991693023592, 0.009134394422289915, 0.05488663351570722, 0.02431118453387171, 0.026897070092672948, 0.03666603231977206, 0.0676826732524205, 0.07989542573341168, 0.05814333708258346, 0.005554192393901758, 0.05354713117412757, 0.03653166648291517, 0.03521810220263433, 0.016035391890909523, 0.02569452924944926, 0.023925922687340062, 0.0227816719780094, 0.06049738498404622, 0.031644297487218864, 0.029495336530089844, 0.06226344412425533, 0.03501903593132738, 0.03224236461392138, 0.020903991971863434, 0.0751274979847949, 0.05843665981956292, 0.042412132970639504, 0.04734821282909252, 0.04437127667188179, 0.02680646128283115, 0.039667707969783805, 0.03546252482919954, 0.06994792318437248, 0.09241594685590826, 0.13279004953801632, 0.1399277735617943, 0.11036089214030653, 0.11139393944176845, 0.31739521713461727, 0.16645746014546603, 0.2642448269762099, 0.1250797585817054, 0.12974357785424218, 0.2539703861111775, 0.11040582918212749, 0.08029851582250558, 0.1478490125737153, 0.1362021773820743, 0.09890959059703164, 0.16710447933292016, 0.10698828366002999, 0.17816605686675757, 0.08011951722437516, 0.10793192443088628, 0.16997915867250413, 0.15805029252078384, 0.13371139619266614, 0.12865199736552313, 0.10062986664706841, 0.11491483644931577, 0.1865879783872515, 0.18747966882074252, 0.17080749938031659, 0.2288428391329944, 0.16864174918737262, 0.10932313962257467, 0.1181491902389098, 0.2080840038252063, 0.11216157989110798, 0.13594162417575717, 0.16274405003059655, 0.10661640088073909, 0.1076844849740155, 0.13851822732249275, 0.10466444859048352, 0.09556586650433019, 0.13194742990890518, 0.11287487286608666, 0.09933999172062613, 0.09647273385780863, 0.11396716581657529, 0.1504136374569498, 0.19259811291703954, 0.1765593368327245, 0.10350652752094902, 0.21204760676482692, 0.14010715065523982, 0.07603411300806329, 0.192218845768366, 0.12284982003620826, 0.11236634585657157, 0.14787572989007458, 0.18021999509073794, 0.2170143707189709, 0.1516887659090571, 0.12225992395542562, 0.16434686636785045, 0.1165523036615923, 0.09985735028749332, 0.2538808237295598, 0.3030086250510067, 0.11126028606668115, 0.08792894426733255, 0.20901401876471937, 0.17387810570653528, 0.1234245985688176, 0.11439928130130284, 0.09340773074654862, 0.08582958660554141, 0.07655291876289994, 0.21331976662622765, 0.12917681451654062, 0.14952922007068992, 0.08072944387095049, 0.14279504626756534, 0.15659269964089617, 0.06590445773326792, 0.19126315251924098, 0.20157884195214137, 0.1654888832126744, 0.20717297302326187, 0.18916731263743713, 0.08932228942285292, 0.14555507863406092, 0.18726931448327377, 0.19879011815646663, 0.08354651028639637, 0.14846043835859746, 0.21523156872717664, 0.1729149612947367, 0.11774768834584393, 0.08552172148483805, 0.15088233340065926, 0.14549175859428942, 0.12362671506707557, 0.09395087152370252, 0.12834223976824433, 0.09843233769061044, 0.12512075481936336, 0.2039267893997021, 0.08859614987159148, 0.11330822773743421, 0.11670917883748189, 0.13366587285418063, 0.15762873779749498, 0.11095846944954246, 0.113154677383136, 0.09081734591745771, 0.11006471584551036, 0.19335445045726374, 0.175098656618502, 0.114823114417959, 0.0954797254235018, 0.10836680070497096, 0.15092524437932298, 0.1190181115816813, 0.07092323139659129, 0.16786280582891777, 0.16082260000985116, 0.07803968546795659, 0.15012538729934022, 0.1434968804824166, 0.09572602197295055, 0.16668043099343777, 0.14136454177787527, 0.2120220471988432, 0.14237960684113204, 0.1856417252565734, 0.13377155468333513, 0.16254050860879943, 0.10241752228466794, 0.191188121389132, 0.1011371542699635, 0.11725188916898333, 0.23537798377219588, 0.2393040934111923, 0.08863727227435447, 0.11153660991112702, 0.13680345058673993, 0.23206629819469526, 0.1469767070375383, 0.11997812413028441, 0.12929882359458134, 0.20287185616325587, 0.1250435714609921, 0.12907997908769175, 0.1600300901918672, 0.19329432165250182, 0.11568393892957829, 0.1102478482061997, 0.15320547827286646, 0.16681878216331825, 0.09380684292409569, 0.199591607961338, 0.09878729208139703, 0.0722118817793671, 0.1617678883485496, 0.09759699110873044, 0.12756059499224648, 0.11602355312788859, 0.13652839581482112, 0.16007724625524133, 0.07602238707477227, 0.09898155665723607, 0.18707935436395928, 0.0617234982928494, 0.07918403265648521, 0.21653746662195772, 0.1665356825105846], [0.0461459001962794, 0.029638873456860892, 0.012824890727642924, 0.037363216979429126, 0.029889448487665504, 0.016199072560993955, 0.020011876658827532, 0.018577641021693125, 0.08004378847545013, 0.09817062673391774, 0.0703588874603156, 0.06102200917666778, 0.03246668245992623, 0.01710978238406824, 0.03343734482768923, 0.04621188825694844, 0.03806588239967823, 0.029941434077045415, 0.08581558970035985, 0.00799434705186286, 0.03436674378463067, 0.05409167832112871, 0.030710690552950837, 0.0574394879367901, 0.031822965829633176, 0.032490613011759706, 0.04794079177372623, 0.013894557450839784, 0.057247538861702196, 0.051571608273661695, 0.037780567436129786, 0.050963896937901154, 0.012901824538857909, 0.02035106412222376, 0.03356650078785606, 0.02733240649831714, 0.07307332969503477, 0.03341971510963049, 0.06481398304458708, 0.019539603563316632, 0.031472872506128624, 0.03921584022464231, 0.035255280090495944, 0.02728229112108238, 0.041145899158436805, 0.06100004531617742, 0.05018201838538516, 0.018771944560285192, 0.04619173152605072, 0.04432485162396915, 0.04083841995452531, 0.036206368313287385, 0.07370425169938244, 0.05896228591154795, 0.03277575728134252, 0.02546975312725408, 0.027175731702300254, 0.033910723723238334, 0.05260836631350685, 0.023984131184988655, 0.10009552031988278, 0.02881736607378116, 0.0694342159840744, 0.04923294509353582, 0.0913251233578194, 0.020739730571222026, 0.021961255552014336, 0.05304169520968571, 0.039600907257408835, 0.0235352413073997, 0.010191800865868572, 0.07345945428824052, 0.020948429919371847, 0.0064380531694041565, 0.04701354504504707, 0.06926555550307967, 0.0366533193300711, 0.06421770449378528, 0.08828467791317962, 0.08931791817303747, 0.01828806613048073, 0.01087550719603314, 0.04377599630970508, 0.01500773443694925, 0.06596887615160085, 0.015909892863419373, 0.06784801633330062, 0.02538967724831309, 0.03470856216154061, 0.012092253673472442, 0.06299640401266515, 0.0550917334476253, 0.055427711122320034, 0.04378159952466376, 0.01447707936677034, 0.029732669790973887, 0.024891017092159018, 0.02293177691171877, 0.08807665391941555, 0.018893406304414384, 0.010268184560118243, 0.019883306995325256, 0.06815906526753679, 0.021185915320529602, 0.0340097930165939, 0.014403925870283274, 0.02474159307894297, 0.06349829622195102, 0.07203189612482674, 0.10012519880547188, 0.04472887681913562, 0.04714802962553222, 0.07775998485158198, 0.07612789078848436, 0.015567914924758952, 0.05600468270131387, 0.02163944547646679, 0.025165363113046624, 0.011497799878270598, 0.011501397439133143, 0.03942604242183734, 0.05745296904933639, 0.02884151184844086, 0.07620505930390209, 0.016940864006755874, 0.028326220162853133, 0.021227291908871848, 0.01726273159874836, 0.09184484195429832, 0.0288182863369002, 0.0514779677905608, 0.011155378506373381, 0.0728431080642622, 0.0534078040800523, 0.01917778245115187, 0.05056020570918918, 0.028139386340626515, 0.05310719716362655, 0.07929151790449396, 0.03250268775445875, 0.05400407892011572, 0.008668126229167683, 0.015531708322669147, 0.0496259456849657, 0.009678220758360112, 0.016596813620708417, 0.09222709253663197, 0.0336871109175263, 0.022690610458084848, 0.03825484433036763, 0.014842910859442782, 0.0395607014070265, 0.09863719271379523, 0.015322455146815628, 0.017278194245591294, 0.022621583302679937, 0.021425116938189603, 0.04881588778516743, 0.052091608886257745, 0.018838492942450102, 0.027930529286095407, 0.03311137872515246, 0.03017593418917386, 0.036169324012007564, 0.07835466778487898, 0.036098370983381756, 0.043577991309575737, 0.06458816234953701, 0.022044199831725564, 0.022511012575705536, 0.09646495615015738, 0.015475361688004341, 0.006542936725963955, 0.028915387083543465, 0.019856717699440196, 0.03969420264184009, 0.044446749379858375, 0.021018854167778045, 0.023194070454337634, 0.021286018054524902, 0.009907084258884424, 0.04025080597784836, 0.055265125120058656, 0.021767028083559126, 0.04660567923565395, 0.02021058669924969, 0.07410873702610843, 0.03954176921979524, 0.0439245854067849, 0.026162438516621478, 0.01753338914568303, 0.013185470597818494, 0.11830973904579878, 0.08112253723083995, 0.019925503656850196, 0.025338981140521355, 0.06702081111143343, 0.06305657734628767, 0.004482759359234478, 0.055237743581528775, 0.030989595215942245, 0.017592284129932523, 0.019268621326773427, 0.030375501410162542, 0.028462116679293104, 0.03293600180768408, 0.03760842628253158, 0.06749334395863116, 0.025947635003831238, 0.04286564828362316, 0.05486235415446572, 0.06968248664634302, 0.049977994567598216, 0.02510008380340878, 0.02324027656868566, 0.05127759162860457, 0.15242142893839628, 0.06549015379277989, 0.04511094928602688, 0.05256961507257074, 0.027829289210785646, 0.055596497768419795, 0.009623980895412387, 0.016830976055643987, 0.0444891260121949, 0.020544753533613402, 0.036386743595357984, 0.03469739283900708, 0.0400663266191259, 0.022101072463556193, 0.04863901915086899, 0.05969583951809909, 0.04522039009316359, 0.026213218116026837, 0.0227977840040694, 0.02456652044202201, 0.055714940826874226, 0.030462957947747782, 0.07187675757450052, 0.03691243276989553, 0.1077950130274985, 0.015361323276010808, 0.03267465450335294, 0.009052798995980993, 0.06154555354441982, 0.05342692922567949, 0.00931603877688758, 0.07456274586729705, 0.022927938152861316, 0.04569340904708952, 0.021652568502759095, 0.03669741403427906, 0.016013168278732337, 0.03845373619697057, 0.047511500160908327, 0.027844994910992682, 0.06089838963816874, 0.030018285324331373, 0.05404519019066356, 0.05499602608324494, 0.052534548594849184, 0.018366219846939202, 0.015800025321368594, 0.09327342428150587, 0.0547955868387362, 0.025490193729638122, 0.08908878749934956, 0.02473606222338276, 0.007463959154847544, 0.03961777256336063, 0.03436786813836079, 0.03831945941783488, 0.021572717123490293, 0.02042160340351984, 0.013207235006120754, 0.028102444084652234, 0.08053292316617444, 0.04669650697906036, 0.031337794207502156, 0.08761782111832872, 0.025522315736452583, 0.033844910067273304, 0.026362369389971718, 0.062220956169767305, 0.034126399259548634, 0.056665004885871895, 0.028413804720912594, 0.038742509568692185, 0.07195344369392842, 0.04308457442675717, 0.059919942141277716, 0.03135768376523629, 0.0240934087196365, 0.024656795285409316, 0.019251153025834356, 0.12950497737620026, 0.044032738587702624, 0.022522387844219338, 0.012812771456083283, 0.026419687310408335, 0.045969076090841554, 0.08171421446604654, 0.024393631574639585, 0.0060010163178958464, 0.06849794473964721, 0.04647035231755581, 0.015695595866418444, 0.08754621871048585, 0.07236841556732543, 0.016961610745056532, 0.03626350255217403, 0.02796525808662409, 0.0546541854419047, 0.05000851539080031, 0.008807335507299285, 0.013830210464220727, 0.02411405526800081, 0.05172397861315403, 0.09197152656270191, 0.054726693269913085, 0.034031103787128814, 0.07596127121360041, 0.04891441531071905, 0.010502947206987301, 0.02000186879740795, 0.0348868594301166, 0.12159989491919987, 0.024289469292853028, 0.028902742742502596, 0.020824044113396667, 0.04855295970628504, 0.019610951785580255, 0.05237925048277248, 0.03566612933354918, 0.005236710430835956, 0.026386244280729443, 0.022129485587356612, 0.011371940909157274, 0.04124645645788405, 0.06979162688367069, 0.059281843568896875, 0.05249384179478511, 0.011723380303010345, 0.053840776745346375, 0.0708929963002447, 0.04972215028828941, 0.03596153008402325, 0.05416044943558518, 0.05340771873306949, 0.04997823947633151, 0.06901257220306434, 0.02951240778202191, 0.1632928237086162, 0.11087816907092929, 0.1369164648349397, 0.09159271212411113, 0.09284099709475413, 0.10892430203966796, 0.1515403512166813, 0.12120528015657328, 0.2121883476502262, 0.16941604670137167, 0.2581622143043205, 0.0618040806875797, 0.1384083300945349, 0.12285516349948011, 0.08391137977014296, 0.14537359384121373, 0.1988929501385428, 0.20100584457395598, 0.14096063532633707, 0.11565806024009362, 0.1581683979020454, 0.19040761952055618, 0.08733264345210046, 0.12796729191904888, 0.16568063932936639, 0.11878834266099147, 0.08045490860240534, 0.09202335073496215, 0.1658793567912653, 0.15898214798653498, 0.13023011502809823, 0.14945843402529135, 0.17928202432813123, 0.19263836700702086, 0.19324134715134278, 0.12472673377487808, 0.1980334986001253, 0.0945093524933327, 0.11203845759155229, 0.14018075686180964, 0.24782788212178275, 0.15502071211813018, 0.10172558089834638, 0.13690965191926807, 0.1399285750812851, 0.15766121417982504, 0.12244210636708885, 0.1730021636467427, 0.18209935049526393, 0.16604077391093597, 0.18617332563735545, 0.10406513465568423, 0.17718139017233625, 0.21559961460297927, 0.13804384652758017, 0.17484479758422822, 0.11427906079916283, 0.08365032932488248, 0.1392967253923416, 0.11619954602792859, 0.29157206998206675, 0.12034480445436202, 0.16478145320434123, 0.1071394442988094, 0.3526672994485125, 0.11066660503274761, 0.10400190367363393, 0.09012964219436981, 0.1541532453848049, 0.1209332088183146, 0.07336875642067753, 0.17862281907582656, 0.09948317427188158, 0.19803510163910687, 0.12761588499415666, 0.13237213133834302, 0.11994313186733052, 0.1288571418263018, 0.15917461656499654, 0.13128509279340506, 0.08530350780347362, 0.12155844597145915, 0.16657636704621837, 0.21439227391965687, 0.14090595388552174, 0.11652350833173841, 0.1934811202227138, 0.1453016500454396, 0.12429274807800539, 0.19979154254542664, 0.1997107671923004, 0.18763044354273006, 0.17052278184564784, 0.1254924520617351, 0.19662601553136483, 0.1101401106279809, 0.17724736710079014, 0.12903976952657104, 0.1264817942865193, 0.0936403866217006, 0.15986010868800804, 0.11227282040636055, 0.19068567256908864, 0.14677896921057254, 0.07245207045343705, 0.10850377890164964, 0.1314209058182314, 0.16717256396077573, 0.12231698769028299, 0.1864367732196115, 0.09882716767606325, 0.06661815146799199, 0.16810902074212208, 0.1962213372462429, 0.1762709382455796, 0.1729492039885372, 0.07134210696676746, 0.1984885983983986, 0.15826082497369498, 0.16721246181987226, 0.10567080084001645, 0.13639851997140795, 0.1116352561803069, 0.17412798682926223, 0.171600662288256, 0.14556149078998715, 0.19084320083493367, 0.11826748115709051, 0.14931439800420776, 0.10744004379375838, 0.08192643159418367, 0.18921797163784504, 0.14982175984187052, 0.10834245826117694, 0.15556574537185952, 0.23079510312527418, 0.1573846602695994, 0.17305671150097623, 0.14721864718012512, 0.04689760673500132, 0.19860033615259454, 0.13911354850279167, 0.1904809140251018, 0.1255128759657964, 0.10381140178651549, 0.12199991251691245, 0.20444676774786785, 0.15189376194030046, 0.09603610611520708, 0.09410324186319485, 0.20718233892694116, 0.09857205441221595, 0.24452841229503974, 0.143720370833762, 0.09641766650020145, 0.16182596882572398, 0.1388019058504142, 0.11532486561918631, 0.09792733588255942, 0.10897329862928018, 0.14736744778929278, 0.11341714533045888, 0.11048909815144725, 0.11415978282457218, 0.19121535820886493, 0.20941443712217733, 0.1262437875266187, 0.21694254566682503, 0.1263756671687588, 0.12028336204821244, 0.22535087104188278, 0.10116988298250362, 0.09184150971123017, 0.11195834274985828, 0.12419137070537545, 0.11388311017071828], [0.029514745547203347, 0.03777446698222775, 0.016731973555579316, 0.05358943730243482, 0.019056331839237828, 0.12052260077325627, 0.0024936215277193696, 0.024386312143178657, 0.04984103492461145, 0.020369267149362713, 0.016268153522105422, 0.03089152967731934, 0.0199377194076078, 0.03274276510637719, 0.01594594639755087, 0.018328811893297825, 0.0840385393530596, 0.07062329241307452, 0.041990307363448665, 0.06593311947654001, 0.07640072653885, 0.02615742530906573, 0.10092225798871368, 0.02465717749146279, 0.024166068687918596, 0.04100509890122339, 0.014322309107228648, 0.028964045995962806, 0.006351193596856319, 0.05316401227901224, 0.03530190180754289, 0.08212239568820223, 0.016455284203402698, 0.017145811798400246, 0.048609448276693, 0.013619318069686415, 0.03653532898169942, 0.051601535378722474, 0.05024997313739732, 0.0204821867737337, 0.08192433131625876, 0.02180657898861682, 0.051931026682723314, 0.034193096071248874, 0.0036665632023868966, 0.02572536363004474, 0.032454967658850364, 0.026658541974029504, 0.08183629033737816, 0.06201439420692623, 0.043348808685550466, 0.12620427558431402, 0.014498456930596149, 0.050209860055474564, 0.07762388238916174, 0.041679406858747825, 0.07014744216576219, 0.08337989813298918, 0.020673976287071127, 0.05010053799196612, 0.06396768236299977, 0.036161316238576546, 0.006389809859683737, 0.054842379249748774, 0.03394089944777079, 0.03503282874589786, 0.012533286062534899, 0.04470747699087951, 0.010153782495763153, 0.018428204020892736, 0.047503844907623716, 0.020600379357347265, 0.005103344174131053, 0.08340970278368331, 0.06763225173926912, 0.06585615134099498, 0.03260856254200917, 0.035106728100799955, 0.07465350310667418, 0.02653810995980166, 0.03409466502489522, 0.014581271334463963, 0.023165312231867574, 0.03579859156161547, 0.0552660231187474, 0.019171420390193816, 0.014732370746060042, 0.054333603620762005, 0.044509935833048075, 0.029104553104843944, 0.046353330471902154, 0.04760966774483677, 0.024733772697800305, 0.060881379613419995, 0.0542847591714235, 0.03080737755226437, 0.03432543213421013, 0.04736946051707491, 0.03099872548773419, 0.06229266247828491, 0.07249250265886076, 0.02925265609519556, 0.03969330464315135, 0.008164019636751618, 0.05306364793796092, 0.0166145231196424, 0.09446952142752707, 0.04088716050318908, 0.04432831745361909, 0.03423010326514486, 0.04744931931782048, 0.10968457296257839, 0.013117332164256368, 0.011400266830605688, 0.043169316559215076, 0.04966540938767139, 0.033762709790607914, 0.01397945636199438, 0.07231737807160243, 0.02495211811037734, 0.05247132132353727, 0.03948205972847063, 0.005376602020987775, 0.04404878010973334, 0.10364395842771046, 0.001810194314657565, 0.03758679267775733, 0.05668395562679507, 0.013897748685849365, 0.006901166771058342, 0.046791635468252935, 0.047276131735998206, 0.0460826914786594, 0.06329123702016659, 0.017115903247031383, 0.03177608807163779, 0.024634612491354346, 0.05983235016174149, 0.13416870759101585, 0.04176228248979896, 0.025246769291698, 0.053082999438629486, 0.03983504000643734, 0.03527420856698882, 0.04658616075175814, 0.040667889261385426, 0.030579441736335866, 0.09738107808516361, 0.03003699857799802, 0.04293842699553352, 0.04678340505051892, 0.07949850289151073, 0.043798208789667115, 0.09677512192865834, 0.054766991888755, 0.04954468422511127, 0.10137588833458722, 0.028609922810574062, 0.0319609310827218, 0.02895053148677107, 0.017427297279937193, 0.014825755188212497, 0.04586806237057317, 0.041290896260761656, 0.033966106493608095, 0.044492584420368075, 0.0416418096574489, 0.02779482201731298, 0.04215654844301753, 0.032576542580500245, 0.011679527724481886, 0.052332769773784094, 0.02161378572054673, 0.04406825406476855, 0.023472171742469072, 0.05834285977471154, 0.035452606025501154, 0.06243142925086431, 0.029630993703904096, 0.04883464927843306, 0.020891542444587685, 0.01639305326534668, 0.04540771558822598, 0.021982015277899336, 0.039544915925944224, 0.014232059311325429, 0.071875058056321, 0.04801200826477725, 0.03757590537134092, 0.023522298251918983, 0.017594516139070038, 0.05551430491323117, 0.05937350622843951, 0.01915012631798163, 0.019783061397902202, 0.010402051302662585, 0.05874203132407274, 0.027216885646339506, 0.11058346222853288, 0.013065924522379646, 0.04120483310543932, 0.02147861465346068, 0.043333694848115556, 0.04775171481014695, 0.019354871874384116, 0.019228190976718906, 0.019051878953177948, 0.01981451361643849, 0.0218247319207876, 0.046510446845786646, 0.016635715146549046, 0.03806851331319194, 0.08325439353939146, 0.0396753224049462, 0.06105797365307808, 0.0519643157167593, 0.014875822325848276, 0.08130440051900223, 0.07104738528141752, 0.03685028903419152, 0.027574457963055465, 0.02989182892633835, 0.026052259272546507, 0.029753533417533617, 0.049608761255512945, 0.01715831513138255, 0.042278371984139085, 0.019005431640835013, 0.050722320447675884, 0.024716677326068748, 0.08665080269565806, 0.019895103432645556, 0.11363070574589074, 0.037890275416430086, 0.03841706296952907, 0.030619538119935896, 0.08835798726067878, 0.06018884450895712, 0.047717787529109046, 0.026094005079357885, 0.032648230335325934, 0.055601087951799855, 0.015238336418406107, 0.006667904654023005, 0.036081097496207803, 0.019853561716445256, 0.02450376072374638, 0.021775672248622868, 0.027626248738670256, 0.027129436530231033, 0.027388271664676722, 0.015551021788269281, 0.034767792967613786, 0.04992481968656648, 0.037219700461719185, 0.02170871382986661, 0.03081983821175527, 0.03081742066569859, 0.0401215461170068, 0.07466102848411538, 0.05883969053684268, 0.028008387998852413, 0.04968710978573654, 0.10441698686918244, 0.07139084380469285, 0.038830160920042545, 0.06580229368410073, 0.011069834854424698, 0.009062618537427625, 0.07574269387987442, 0.031110645068110898, 0.05547504530113656, 0.04281109671865124, 0.019328427297296003, 0.06748066065483727, 0.01865851470938651, 0.07454676742781885, 0.019629368180176243, 0.019223918061470613, 0.01320128019870026, 0.010997320532624144, 0.005756532000305015, 0.11561199513380416, 0.005638815782731399, 0.07719859466305934, 0.058377785244374536, 0.004223972928230069, 0.032944158010650426, 0.015374038121080957, 0.07229106893646531, 0.039739592393743806, 0.02651570081070531, 0.017894119300763123, 0.0428356284101028, 0.014099581312621012, 0.021155275753699243, 0.02719802396313753, 0.06425368381314911, 0.028548139016493224, 0.041840330450213514, 0.04842472400923725, 0.04041308769956231, 0.007630073141626781, 0.08832928841002285, 0.021195520566834603, 0.05324079858837649, 0.021098484758113045, 0.07863721824833192, 0.032067132415249944, 0.07469895965186879, 0.05410794990893919, 0.021518137727980502, 0.05470405405503698, 0.050015517554129474, 0.12797829054761678, 0.03629207523772493, 0.02735672111157328, 0.04583744135743473, 0.01461092662793817, 0.06381988365319557, 0.015302972842619056, 0.016143036700668745, 0.07724713112111203, 0.09437356173293665, 0.041012390502146445, 0.04310180709580891, 0.027004317853425164, 0.027000742556992918, 0.05643909142236225, 0.008398087447858416, 0.027664413682941813, 0.05059101225924678, 0.05793692726001609, 0.020315570909588132, 0.05933684042247478, 0.06263540853979066, 0.020212842828186695, 0.07093690175679512, 0.02507734068785794, 0.00839160386021831, 0.029166557687858585, 0.03658403984445613, 0.03466087546257768, 0.03755713645659853, 0.06981970233027823, 0.0386420487484429, 0.031294185610022396, 0.04539551468042191, 0.05726583651266992, 0.024642482967465185, 0.03891848762577865, 0.027936427504755557, 0.1253938503214158, 0.1305373344803229, 0.1633097298326902, 0.09757181745953858, 0.12172018221463077, 0.2205919529660605, 0.10259008646244183, 0.17736878246068954, 0.17864162509795278, 0.12244503785041161, 0.13035951589699835, 0.15722337673651055, 0.0764611002523452, 0.07642363663762808, 0.10200036849710159, 0.1693388188141398, 0.15836668491829187, 0.1527039794018492, 0.14480205107247457, 0.1378724697860889, 0.19028736191103235, 0.09089737170143053, 0.26807190442923456, 0.1023433668888174, 0.13304966763826087, 0.23580802866490558, 0.08848614132148214, 0.17969654349144548, 0.14180778205627576, 0.13874608150217682, 0.11740034096874297, 0.1310644968179986, 0.11614391463808715, 0.12571141531225294, 0.1721070148050785, 0.13377054536249489, 0.23662669176701456, 0.21937224810244516, 0.14175780583173037, 0.09486186521826312, 0.13080885662930086, 0.19627612258773297, 0.0875117459509056, 0.13006068271351978, 0.1556543429614976, 0.11686039142659865, 0.0821308339072857, 0.1287460868479684, 0.2043113109539263, 0.20251706504495814, 0.08680462764459662, 0.25407072447706014, 0.16521425888640806, 0.12363522007944994, 0.15930167224723846, 0.08212426590034738, 0.23173874389613047, 0.12818028830224648, 0.10806741833221167, 0.1141116397047881, 0.1877384408726357, 0.1583981074509211, 0.19504642841638997, 0.1292010975885205, 0.07978428911883384, 0.13298011355800554, 0.12428665504558012, 0.13186448748456314, 0.07712312566582114, 0.09387047466589138, 0.14622207643697038, 0.10377352999057621, 0.11902850907063112, 0.2534926211228594, 0.09964522963855416, 0.1414702829788439, 0.1893023686716333, 0.11454009640146978, 0.2715862408513203, 0.16194729512790218, 0.13145865144906566, 0.1431948263780214, 0.1380116373184137, 0.13083787460345775, 0.20162276225164533, 0.0658256045426242, 0.13483600225299597, 0.1783290770254098, 0.2205769467400387, 0.07165554561652243, 0.21558603330049664, 0.19269595766672865, 0.09295531752286479, 0.11608723682002164, 0.1336476457072422, 0.15962634701281786, 0.18783649342367426, 0.16321532864822075, 0.17688464984530583, 0.1406089760712348, 0.25930242030881345, 0.08410131020355038, 0.09433122220798396, 0.11307935681543313, 0.07133725332096219, 0.07963958516484126, 0.2704969164915383, 0.14051727630430833, 0.14586445031454787, 0.12995022145332769, 0.1579824899090454, 0.3247443790314719, 0.10850124817807227, 0.19195011409465224, 0.1397561890189536, 0.13019618403632194, 0.13622834550915286, 0.11825939174741507, 0.146804187388625, 0.12699267390416935, 0.16388053045375273, 0.12944090034579858, 0.15402768884086981, 0.16458736674394459, 0.28136994398664683, 0.17956056719413027, 0.07638808034243993, 0.24075533350696787, 0.15522563393460587, 0.10540390969254076, 0.14667693874798715, 0.16228773311013356, 0.11513677571201697, 0.19885443267412484, 0.17690100678009912, 0.06431402041926049, 0.0971162278437987, 0.12611272424692288, 0.29919226421043277, 0.13583145977463573, 0.10561237897491083, 0.09760536995599978, 0.08450466746580787, 0.15646353625925258, 0.18071855505695567, 0.10363568348111585, 0.15416535723488778, 0.16270588879706338, 0.14772023510886356, 0.1251987396972254, 0.15476556174689904, 0.15361946308985353, 0.14979686820879579, 0.2566202392335981, 0.14544222765835002, 0.20185766683425754, 0.1664404055918567, 0.15234908438287675, 0.09973856213036925, 0.06973252224270254, 0.19023924105567858, 0.12736929900711402, 0.20367334596812725, 0.13398311130004004, 0.10696624187403359, 0.19423113466473296, 0.22960146248806268, 0.09704845491796732, 0.17138906114269048, 0.10917676583630964, 0.10527393736992963, 0.18290008330950513, 0.20840070792473853, 0.09443262926652096, 0.06316999977570958, 0.11022596969269216], [0.04906589136226103, 0.006993091501499293, 0.02650844631716609, 0.03148837968183216, 0.04007561088656075, 0.048826964339241385, 0.030110103834886104, 0.04708367800049018, 0.0777133705560118, 0.06339498184388503, 0.017482455550634768, 0.05949833917838987, 0.050619072862900794, 0.0687014045251999, 0.04539554807706736, 0.007511862932005897, 0.026860125981329475, 0.020646661541832145, 0.07006700077909045, 0.02554283055360429, 0.032327633671229705, 0.035024067692575045, 0.026482606590434443, 0.04263043942046352, 0.028221480861247983, 0.044060027357772924, 0.009534848959447118, 0.01813197392039001, 0.01898345293739112, 0.014026826720510144, 0.03756160047487356, 0.04742187840747647, 0.03889360341418069, 0.03500976279610768, 0.025432465772610158, 0.022148586613184307, 0.05932273961661849, 0.021079192629258614, 0.047282306404667906, 0.03273535847256426, 0.025452828449488152, 0.031433338299393654, 0.03870150962029584, 0.059385425120126456, 0.025004098133649677, 0.011062944013247034, 0.04162804652878549, 0.021745520643889904, 0.02747686368820723, 0.04247482218488585, 0.06812602485297248, 0.06060717460059095, 0.041432895086472854, 0.02054554206551984, 0.029220138894743286, 0.05049853694799822, 0.04944823100231588, 0.06358123864629306, 0.029978500642755534, 0.06610825890675187, 0.08036010665819049, 0.03279166892752983, 0.03362760922755115, 0.0674744563002605, 0.011483178641356062, 0.04045267014589626, 0.05240554106421769, 0.051359443095861934, 0.06188472245412413, 0.024574836206738837, 0.020776175588252954, 0.04339321138104424, 0.01249735219971626, 0.12274557797354646, 0.027655661906464957, 0.046984189393697307, 0.05387741286540404, 0.02683207279915223, 0.042107451663468964, 0.07018139542196877, 0.014114848218014231, 0.012530513213278027, 0.052120081381872296, 0.022524335981870536, 0.016609734411758836, 0.07810460112523288, 0.055790702972444706, 0.03396140498807654, 0.010518178860365879, 0.005559007076954003, 0.029882693088438828, 0.014289738101069815, 0.01231325690241647, 0.022837000942672603, 0.019381574347789865, 0.03520427970215678, 0.02881539381633047, 0.016442517407995183, 0.02678102973732166, 0.005941363879173878, 0.04939819911669474, 0.04726157450932078, 0.02520424979593372, 0.07548451554612257, 0.01573336932779057, 0.039745937756379135, 0.024446123679808807, 0.042649969036574475, 0.047576805445714854, 0.03941906994441524, 0.04248903060215525, 0.03477559293969534, 0.02333973920030985, 0.010107908492500428, 0.024680126552993897, 0.06539627211168408, 0.02132818688551197, 0.06472319611930288, 0.015089474582055118, 0.09896776755340397, 0.05163836445717607, 0.014575836030417122, 0.06478613766375929, 0.009885104627755936, 0.019661132100736722, 0.09662483702413738, 0.061231391300680116, 0.029535468165704515, 0.03419272499741055, 0.03871281252941117, 0.03772696582018398, 0.07773627323331311, 0.06403384482837282, 0.04439907381311059, 0.025144629362330306, 0.07098526009940542, 0.044607995805563405, 0.03413819940760732, 0.023402708575304132, 0.04072556897881441, 0.0524886653147405, 0.028402271746017504, 0.04053697070048656, 0.037403382011689246, 0.03143256275507156, 0.025317568324680906, 0.044078228529542685, 0.07106676275725476, 0.04961319558788091, 0.026236191297357436, 0.04363325162557885, 0.003570676794879546, 0.035789581888820976, 0.015594314972986467, 0.029864107855246402, 0.045662903066840954, 0.048929543991107494, 0.040137261094059795, 0.019451401167316362, 0.007134815268727834, 0.033403796041966416, 0.019609150222095195, 0.017477893197792582, 0.0645330356201157, 0.013323858875082806, 0.04089477122761309, 0.0827569913235493, 0.05164537033124361, 0.09390934836119413, 0.023370324961433653, 0.01642495448322734, 0.026320183860661928, 0.0467037354974309, 0.031116721402213443, 0.04807733952475246, 0.0350598651857581, 0.1392268596100621, 0.024254558666143566, 0.014057394855626626, 0.03220207341655623, 0.04505381133640185, 0.023522277842857875, 0.07867179490858689, 0.03593397043005098, 0.07989906967850402, 0.015209035500447499, 0.03712807490956038, 0.038023839733796194, 0.015383827048935927, 0.03754427132662386, 0.042276134408893995, 0.017010902338370215, 0.059577849169727415, 0.11811945238150656, 0.02835309147485532, 0.057314061268698424, 0.022299517186183948, 0.036507917757262476, 0.015390517510240898, 0.045962845761096105, 0.03218012068828102, 0.06641789033892564, 0.028826414709328674, 0.019359230136615224, 0.023646494810236618, 0.04200512063107453, 0.05299472097249236, 0.052103576017543674, 0.02352771036385093, 0.1036525821837131, 0.017880537998280488, 0.02832703095918987, 0.05529524147277698, 0.05219418482738547, 0.05230298367678188, 0.011803947854787111, 0.06779986579203978, 0.03294500776974019, 0.11453398852609098, 0.05534013769647572, 0.07508477996452712, 0.02391523576079635, 0.01840164441091474, 0.05185393980355002, 0.05452779769257177, 0.029140647457097657, 0.0571190174377989, 0.03844559112621937, 0.017540599110361654, 0.03530852176481858, 0.0027557464636629447, 0.073472627409501, 0.055640759455855004, 0.054123735390021466, 0.037470802417374216, 0.010317278556613019, 0.06702611004584469, 0.016087596413854044, 0.06437916614231654, 0.022427018157031853, 0.015484799951082096, 0.04459741277969442, 0.037479489255929366, 0.02377182314376114, 0.06037516439391766, 0.04093013827514369, 0.044033632875652984, 0.05956916604191065, 0.03948804886022117, 0.08149634217261337, 0.052252888708608225, 0.027285866417514626, 0.04583302557875868, 0.07712638369412161, 0.023324013091041707, 0.0691366741375532, 0.024668730875418987, 0.02025644585955888, 0.019460698422335554, 0.038324194320011884, 0.006287200058068265, 0.0933827500557527, 0.0640803255373612, 0.02797761855617864, 0.13637196592753753, 0.04678557212173473, 0.03697825384733733, 0.04304768597648945, 0.02327747115487, 0.027099327598989476, 0.0059725725805037655, 0.021874368612770922, 0.04730100110464264, 0.00998797278953134, 0.014465107597061433, 0.03199488804966677, 0.01820467285142513, 0.05148751552042086, 0.0184239626469207, 0.1375862382701598, 0.024401609662163537, 0.024613336972834077, 0.04374922704300843, 0.010478689182491507, 0.10304995827027597, 0.0807513520703651, 0.02071028957288945, 0.029853218693460803, 0.009384614149894333, 0.0225232376033091, 0.014821140885032946, 0.051474030697136186, 0.0615357980132103, 0.06782371099689044, 0.04102063947357237, 0.0587107906176243, 0.03639272901637014, 0.029961941472720355, 0.09158728702459484, 0.019475148037599865, 0.023828862758819014, 0.03668707962788176, 0.03644061980594415, 0.013239988766144961, 0.030808316369075328, 0.03591080800106283, 0.008351498199772323, 0.04251982973073609, 0.040806778488331474, 0.02233546310890233, 0.028074207220925018, 0.01371798103718902, 0.045844933338230476, 0.023537827692052815, 0.04339991668530274, 0.015294182103389176, 0.033680453852866776, 0.0689049088396132, 0.02583524415967986, 0.050401734915794805, 0.03999738481070381, 0.022830573943792842, 0.061533018670161255, 0.04840661189518869, 0.06964420666918159, 0.023172518485807814, 0.03293725232651923, 0.007052784758343478, 0.02760352046607295, 0.05320938718796242, 0.011196012019354384, 0.014290384697233094, 0.020603353514161427, 0.04874815567745827, 0.08201851727790199, 0.0370964223111514, 0.013102879765938269, 0.05293201691529248, 0.009283391700591892, 0.04923919397697318, 0.03849580854875967, 0.023798306683602277, 0.03420539345825091, 0.04942332081554923, 0.03086628181335982, 0.015635559830116108, 0.027378200720704626, 0.07764835841953754, 0.08250255341408774, 0.06665656503173523, 0.02336680903681554, 0.03875307404086925, 0.2403554049669765, 0.09125010707066394, 0.2832289645448327, 0.09466333329328336, 0.1608292051241733, 0.08312829522765242, 0.1768357423134148, 0.19291989330668002, 0.18556195922428742, 0.1343664454179816, 0.13548156683100387, 0.14130585273960605, 0.15580571140162647, 0.20646079326979816, 0.12251033942447975, 0.125590207753703, 0.11877047916641459, 0.19604923320002854, 0.12897500972030684, 0.12437592798960395, 0.11593762726988643, 0.1973790579359047, 0.11223382796742953, 0.11400908973882906, 0.10789975232910365, 0.15665943355998024, 0.1365679522859864, 0.11957504146266729, 0.12439155019819736, 0.10824999408214353, 0.16678219428285956, 0.16442338179331273, 0.10676723497454077, 0.19411939691053703, 0.12452115886844695, 0.09296216012444347, 0.13797013642033562, 0.14125195797532797, 0.12051823694491759, 0.11363329584128223, 0.1350514031946659, 0.12901746056741104, 0.14952715690014884, 0.17694731679512188, 0.2070674841525033, 0.07534264659625478, 0.1124831079505384, 0.15603261563228443, 0.13812108925776556, 0.16925942385569215, 0.09269078640500084, 0.10728956593084149, 0.12738987134071067, 0.16406392998760566, 0.2127426429069601, 0.14229298336431384, 0.10699888895032927, 0.1559332272154279, 0.1314187832758762, 0.15032355557195842, 0.23522943549323827, 0.15620094956830144, 0.09904164093313739, 0.13353314716368914, 0.07587014290038496, 0.10040389010100625, 0.1741748905624263, 0.1203431494650431, 0.1982910535298288, 0.13408301922027022, 0.1588889936101623, 0.1701384235639125, 0.10287729019182734, 0.26694369153119624, 0.1065653188561555, 0.16403724235715345, 0.11827961527160369, 0.128699034685269, 0.14504492632113397, 0.20561812911182642, 0.10578305067610927, 0.09319877164671198, 0.09982755305827595, 0.14166422100970522, 0.1350034010829404, 0.22908703540451825, 0.14009748789248988, 0.05905900259676855, 0.27354836056474596, 0.08173185531632043, 0.10802955395774916, 0.2265440663904883, 0.12634368060389534, 0.09459777938900515, 0.10973541749990545, 0.10245780606055632, 0.14686235692352057, 0.18259716831380501, 0.15248497162247077, 0.11424253971199505, 0.11851062357891351, 0.1684255021973513, 0.15110951964743435, 0.17549640324432403, 0.09041697208886035, 0.14048298908164725, 0.09431042723008431, 0.1146670852904208, 0.19086776592303067, 0.1637955248588696, 0.16625614516669884, 0.19957710639573634, 0.07261696082423441, 0.141687554132659, 0.11751903264666907, 0.12572835112223402, 0.11861204548040405, 0.13465954922139645, 0.10680152961867861, 0.2055901353014633, 0.11203963760635816, 0.13005075277760625, 0.13795231003314257, 0.1142343389801681, 0.07803381507983431, 0.2286063166684471, 0.12585533258970827, 0.2142920097685419, 0.0977509051153902, 0.14863457588944584, 0.12734425894450396, 0.1307896795333363, 0.19990575907286257, 0.19000577623955905, 0.12452587892767042, 0.23591875709826127, 0.17058200523024425, 0.11392660744604655, 0.10872645289055072, 0.07815876306267455, 0.16538974712602794, 0.15631101006874815, 0.13008604932110757, 0.1341791867162101, 0.12216776405693963, 0.12300375630729832, 0.14302765019237995, 0.20734696212457493, 0.1719766788301058, 0.05289723245368805, 0.22826623491710052, 0.09672267435234971, 0.10984423861373216, 0.11325212879455648, 0.055293137484113686, 0.13749850157182664, 0.21509824931854382, 0.15680292039178312, 0.18047027697321028, 0.09018641649163328, 0.08218473609304056, 0.0793431639613118, 0.14254344336222857, 0.18547809653682634, 0.10459180717589334, 0.10761986617580988, 0.16784367326181382, 0.10053780322778039, 0.19776573171839118, 0.11026574880816042, 0.1265636383322999, 0.380244497791864, 0.1670870537054725, 0.13865745422663167, 0.12088501374819316, 0.13550837320508435], [0.04458264033019077, 0.0048583913758193376, 0.025861035646812525, 0.022702911555825267, 0.01921216429764172, 0.05404696763434913, 0.03724887799762655, 0.06305052142124623, 0.012811214801331516, 0.009728347267810022, 0.0926401570905, 0.0110712950299785, 0.027329005606588908, 0.008395976037718356, 0.023435802795575, 0.03241728882130701, 0.07336126815062016, 0.0788637217192445, 0.03336309666337911, 0.03166125185089186, 0.045064891601214185, 0.08672053489135578, 0.00984919488473679, 0.04158024850767106, 0.06949321672436781, 0.008235506084020017, 0.029651530785486102, 0.043302294579916634, 0.03795603712205775, 0.043804049491882324, 0.027683210428222083, 0.07151892365072854, 0.02008417111937888, 0.028196550265420228, 0.05238586672930978, 0.037944222131045535, 0.03385880307178013, 0.10262295618304051, 0.049195173487532884, 0.04981255129678175, 0.05578986063483171, 0.03349902472109534, 0.06369258306222036, 0.021120955134392716, 0.017600499704713002, 0.03327125959913246, 0.019002657863893546, 0.020976865307602566, 0.042065613088198006, 0.10232635686406866, 0.06806109435274266, 0.03307036393380258, 0.027961751438851934, 0.025548825251462404, 0.04908851202344522, 0.08174868722562678, 0.0018237585709357518, 0.017630167058086954, 0.04661457387555856, 0.03014112004166236, 0.061053951212670654, 0.05761588901805226, 0.017317555902991444, 0.014870333216094878, 0.011382707616576226, 0.023218321985041257, 0.029753425806120504, 0.015532574780081632, 0.023026764392852783, 0.049351510606356896, 0.02172596319724107, 0.05719674256397411, 0.015841316562728025, 0.02479634316841839, 0.006365093558997614, 0.03247902437578887, 0.021963079379929695, 0.028537747093650978, 0.0654938274237793, 0.044227125617908314, 0.02635417793499073, 0.062295445532072335, 0.01970231573068304, 0.07963697280501947, 0.031172974340734072, 0.08299535431433469, 0.05360861810913775, 0.021384217179729603, 0.03505458480503876, 0.014143541502562584, 0.026302854712412227, 0.03051049992791377, 0.0009590530328296154, 0.046735874202568084, 0.015685589860368054, 0.011537751543073682, 0.053249823104124516, 0.03207395646313671, 0.04571513542032335, 0.08502870536176488, 0.05109370227728505, 0.06470257183536887, 0.09457921827561222, 0.05557919830607716, 0.037043399570393376, 0.015938126016408205, 0.022664520256512333, 0.029103799824952148, 0.03524727602780331, 0.04287906631361693, 0.02497263663826743, 0.0455211602820782, 0.02914332475484116, 0.017518520216981415, 0.027872927494172473, 0.019643038540380076, 0.05148724463651888, 0.01769832775607938, 0.011897878703166498, 0.0986174590070732, 0.014789766592002707, 0.029745369793090504, 0.007775212643537088, 0.029755412906524725, 0.02731693642999744, 0.02816685137077002, 0.03449644522333983, 0.038913578318897635, 0.08580775262089446, 0.04314030971727334, 0.05634841581922956, 0.025228757367585786, 0.03989757336967159, 0.08301905108965002, 0.013640831075463211, 0.027881317473656964, 0.06413487339159474, 0.02106550742610125, 0.009939876981661655, 0.04309186973841861, 0.05084855234599672, 0.029720916027144995, 0.05382667593949009, 0.024289983230119105, 0.10096445650560781, 0.0440120289567858, 0.03782254701945931, 0.03891922235197853, 0.03785991786571685, 0.027123256295453757, 0.04621060063072946, 0.04082805215148255, 0.07948261350975372, 0.05143727954418864, 0.07967322671902366, 0.043398302514106035, 0.06154433642223012, 0.030890984198777005, 0.043337502065696754, 0.040060730825643986, 0.013345574116101488, 0.062490348354913294, 0.030141804672894068, 0.02822689297317993, 0.02256106487038778, 0.021791068102174904, 0.009512296946923016, 0.04548139600956347, 0.03801215461862739, 0.014807715433562407, 0.004710800931206904, 0.04013094541733153, 0.06583054724615067, 0.061640674612135626, 0.04451940563740209, 0.03230212605558336, 0.04183568831649609, 0.005147576639501494, 0.035637653127196245, 0.0420658802613616, 0.03847875770588871, 0.009171461915684631, 0.06253599043702707, 0.01836394516431028, 0.047305120024248026, 0.06288147502345964, 0.062361830641748384, 0.08161380188539624, 0.08906196628231555, 0.015230220105877379, 0.04726287326775491, 0.05561342986766249, 0.04181985088507645, 0.02055838493106421, 0.02935913758847164, 0.043651111409417354, 0.027492517438076902, 0.054243276827037334, 0.058948771402356215, 0.04089073765499052, 0.08091083960607648, 0.015106967002793681, 0.0293252845222014, 0.01180792298328015, 0.03997328727564309, 0.007362861479123239, 0.02160128980904119, 0.04226825280056801, 0.06210846513567958, 0.03717000625329092, 0.0903938987175934, 0.033977787898038514, 0.028726120872306637, 0.10211126020294614, 0.0631369742040988, 0.052096852159593254, 0.049888012872543186, 0.024438960099359974, 0.045649247549590655, 0.008943140182964271, 0.010970231214741943, 0.00606988112849649, 0.01425721626219456, 0.05374695814680308, 0.037848466527066194, 0.05417737782408949, 0.04712635520263575, 0.030632950583822094, 0.06254225416341797, 0.056759988656267524, 0.1081666286336258, 0.05528379755560309, 0.006858650986032444, 0.03341260533488821, 0.029555513574450742, 0.044395144141162746, 0.03857862109725829, 0.0448208400484873, 0.03202679297828581, 0.029832666768925264, 0.012876010787294945, 0.0216917186480714, 0.047178839886328205, 0.03610848274547607, 0.06937215017387643, 0.004455603248061379, 0.009799209383345442, 0.030202922389435116, 0.00818851051008096, 0.023711538487987127, 0.024092199018923566, 0.034486095973988995, 0.03389477125892881, 0.08093622847809456, 0.0567151109862607, 0.041161473127431236, 0.06336499907774851, 0.07148275879444554, 0.013027265122218523, 0.045742750735371374, 0.008058424082264537, 0.05177410697797313, 0.04313853227358777, 0.045617209034389816, 0.03445971633482259, 0.02703558453504229, 0.06789568447857164, 0.03319517090858426, 0.027745986844820436, 0.021882871769776102, 0.010919652922893874, 0.042177822106168605, 0.09961930642020889, 0.03882574885210488, 0.06344975234242156, 0.014841902466287138, 0.010382360269431956, 0.0508988625369966, 0.08437446507741697, 0.06668694855761714, 0.03674549036077224, 0.046021809394005686, 0.06463003432145342, 0.04993810041924007, 0.016702445354894735, 0.07038308889605105, 0.03163962566759437, 0.015586401823384222, 0.042052599528688006, 0.062256371456896886, 0.025372262753080577, 0.016906150049180724, 0.058482958702370524, 0.010936885591945611, 0.017561844942974858, 0.08605151844676584, 0.006401744522008812, 0.03274154798418749, 0.013811120570608182, 0.01605364686838584, 0.08742303703911602, 0.047837191668804735, 0.017588497321412433, 0.043023595862905495, 0.005264136498226435, 0.051177219866076484, 0.05487068847287446, 0.03015515405422775, 0.03244573534175288, 0.05723642148950603, 0.03367186349350959, 0.019641786166175734, 0.10828566912095994, 0.019670878355100285, 0.07401119655696675, 0.07104496587999165, 0.03673125596833415, 0.028518668332253583, 0.027757883472077083, 0.04256122301740106, 0.04766338810441084, 0.10952655487926677, 0.01516983526016702, 0.053263385852915235, 0.02730034386331681, 0.00845127624415909, 0.07676943292608485, 0.0683236587792635, 0.08987136738141999, 0.016396327991969883, 0.03555973875336349, 0.054580445648753084, 0.03534332849085331, 0.01967923864867771, 0.031125630885071587, 0.013449597245198674, 0.019746744401345495, 0.033905513846548274, 0.019072775976383127, 0.03161587694194168, 0.06377289828378707, 0.0383848537603626, 0.03161968044878449, 0.036191391773172654, 0.03220772858185228, 0.00600961595409899, 0.022580325457965955, 0.08472613917547278, 0.009601673791621579, 0.041995012579718605, 0.058975199281121604, 0.0837303105799947, 0.1252227259101346, 0.08224102057283744, 0.16525337006896734, 0.10966642745188437, 0.1249928679317236, 0.14403701556148008, 0.15579965547658503, 0.15105474914889783, 0.11436088258051313, 0.3384976222878322, 0.21797729248646647, 0.124811872956343, 0.16788941924460232, 0.1242142214323394, 0.1356896650395356, 0.15933339163893834, 0.10741969410446472, 0.1771197177004069, 0.1613752922276035, 0.12866557866800576, 0.09202982226270251, 0.1988237671321258, 0.10842878487892449, 0.1442107671755366, 0.14948258351068944, 0.06196230657224078, 0.10878787303227, 0.14958007202949375, 0.11294827127130702, 0.15616075485013425, 0.21253387676551938, 0.1040874955651816, 0.10035848550614901, 0.20331876265117899, 0.15541382774244994, 0.07876929827034473, 0.13409142033196986, 0.24980667047202587, 0.1161966664949432, 0.15524254005867988, 0.15122615557629615, 0.14756831747945398, 0.1916833862196654, 0.1327025651698932, 0.09238087295670994, 0.06198753588250838, 0.136823310458567, 0.07325808735913597, 0.13935238646809012, 0.1653600760619156, 0.15662044112104923, 0.181588975538034, 0.19818565371679142, 0.20952431950718164, 0.16973401245195419, 0.18637478904565796, 0.06956835917662829, 0.1389682656736113, 0.1069036936678458, 0.23261818889295682, 0.1611027162289247, 0.14259698189562187, 0.12189640518045053, 0.10496052098460495, 0.06040250140358694, 0.0707083054294344, 0.2477884295512922, 0.1230934596969746, 0.1614783616969362, 0.16835738788358867, 0.09934054833138362, 0.11085819787695073, 0.14681637345347553, 0.113651894062059, 0.10182818281464279, 0.1548106101108715, 0.13998460723087192, 0.17783713701646775, 0.16379337263060734, 0.09600412697182037, 0.1551151875173673, 0.21456244838191196, 0.10350140670198016, 0.22576340124942362, 0.13740459020482376, 0.1962449523853138, 0.10162571008550003, 0.14228928746888414, 0.08772946239332668, 0.1713374225073494, 0.2046438227989711, 0.13923539430834353, 0.111885768128559, 0.13060779398074374, 0.052469447400653735, 0.11110222345450893, 0.15794462553458288, 0.1330065933871083, 0.10762361402157694, 0.22128730081021786, 0.09105921926675364, 0.18993273406522349, 0.19337180186994374, 0.17343899176921695, 0.10193055466515943, 0.1258182994206436, 0.15339908975875005, 0.1736441213870421, 0.14507192565361038, 0.18268877902301028, 0.1477111512213014, 0.192261652846355, 0.21310899668605998, 0.18821884790668264, 0.10469590823049657, 0.12727710942272097, 0.1351126897498034, 0.10922628192929551, 0.09906535997288302, 0.2371448592748493, 0.08169511158484966, 0.16137891390826553, 0.0668621547811199, 0.10083294051582925, 0.20556790055707097, 0.10986210210830905, 0.23837982269469649, 0.07269757290487178, 0.12284579759580083, 0.11537777332705446, 0.16750051901908591, 0.11898916782229207, 0.11315489260596223, 0.16805641731480137, 0.10634962847689167, 0.1219014369416982, 0.22126755968201905, 0.06698070545098744, 0.12814818299375474, 0.0800855565466918, 0.20524799037957564, 0.1518056244822219, 0.14536872535245493, 0.19829234486678615, 0.24566222098656, 0.2506942197214812, 0.11336762923747301, 0.12995817727642134, 0.1349220023257658, 0.06780029623769224, 0.23747563449433073, 0.12057346015353687, 0.1668431394500658, 0.09701528091682121, 0.12263801108929329, 0.12229099767864682, 0.13580354017904028, 0.11755798797821626, 0.08207040082197636, 0.16884457814740017, 0.12510230502812192, 0.15719873743364587, 0.1476504880702123, 0.14012932602781802, 0.1383845813688822, 0.15187553479336202, 0.12089648735127412, 0.1547827202011831, 0.16052667604526505, 0.07201254833489656, 0.07410211706883274, 0.1703694838215597, 0.10395301098469645, 0.2040566800860688, 0.19997690134914592, 0.13342234451556578], [0.03324152174172923, 0.036647541710408404, 0.02307594466401497, 0.03487607973511331, 0.044072974123992026, 0.051107253893860616, 0.029923271868028678, 0.010250482482661027, 0.03603991572163068, 0.058311741522629745, 0.04089160225703381, 0.044468635314842686, 0.052393603618838824, 0.005966741155134514, 0.028566612927534152, 0.03359316986461636, 0.025754567141120788, 0.025351514159410726, 0.02977258805913152, 0.016970876458799466, 0.07648381739272736, 0.017964892358577345, 0.07167044052039273, 0.08476577728288248, 0.015849062729103025, 0.06080161729187239, 0.058520819366094656, 0.08480038362904452, 0.0255864502832992, 0.05052178101323079, 0.07143880138755776, 0.016906309610931203, 0.041774988058023155, 0.03482947657175828, 0.026352602726547047, 0.015749796766613144, 0.04302970744902268, 0.017499517525720876, 0.042132183734793216, 0.012866242268501082, 0.05232948205957655, 0.03794827054662164, 0.05395853702793829, 0.02547449359553866, 0.01358279048872646, 0.02466867706971243, 0.05448217787488829, 0.032664928658050485, 0.04985038969607558, 0.03602447533921804, 0.04046963935252279, 0.0850412699219305, 0.04654165044485126, 0.02818997854774352, 0.08403223109780811, 0.025735352937772404, 0.07178842715802602, 0.05581736833846662, 0.011609453213168308, 0.04609492207237054, 0.049266197020187974, 0.02445163783704629, 0.05242427287157625, 0.03997565101599321, 0.0361469631025102, 0.03457616672676522, 0.009342905450466787, 0.029666485061170533, 0.02577500774350483, 0.054234671624726616, 0.03219557962438557, 0.014335541600303259, 0.02279332184116356, 0.05578920383413788, 0.008265256929007592, 0.04921025021758396, 0.03364537624293007, 0.09695225773612037, 0.02132033867383143, 0.06019301537889987, 0.05295723880408332, 0.016487780994793866, 0.060536418241099454, 0.022950438215048052, 0.0218646798748523, 0.021535747036978137, 0.005446625973490882, 0.051071482375846244, 0.025576319967512973, 0.033830256361397915, 0.11851588540594094, 0.07829537760699168, 0.022668850688205566, 0.020560041775752325, 0.04115636715141591, 0.0831065874081105, 0.021296499035088345, 0.04362521787697915, 0.037165868779993616, 0.049963259225478396, 0.03625953948358074, 0.012578378027683357, 0.020037629183207173, 0.07787524780724198, 0.04850937708397396, 0.041165833245031536, 0.02995451257447712, 0.052219792632968165, 0.01849107320595067, 0.050136758509324864, 0.018105210219800938, 0.02785597498586867, 0.05895334303204436, 0.041201007334166206, 0.01592698823515093, 0.051258010062156245, 0.026099350397998933, 0.025763202029338572, 0.03927674457372632, 0.07491907323128544, 0.016194892414205242, 0.060790767092839815, 0.042646410438464954, 0.016372148820664734, 0.0335301281302236, 0.02289460458996473, 0.030112098356767092, 0.04286871335352771, 0.03953815496060997, 0.0504836457548663, 0.06237417255761102, 0.032799873370095156, 0.01901938216178678, 0.037426377457450144, 0.11572172166779637, 0.03173276891175192, 0.06623918859986588, 0.04640839782950934, 0.022396578970074188, 0.025277410713897552, 0.025385779117641505, 0.03404567214602139, 0.03509333233523648, 0.0052663852056866745, 0.06507985002826899, 0.032211773286690004, 0.031171167211141437, 0.03745038964552805, 0.09428520905203186, 0.022108603407104965, 0.012201580375403864, 0.020941075235896278, 0.08017405023565516, 0.08172804067726247, 0.030567851244995836, 0.04471267202461604, 0.06296228006249294, 0.030226307462726254, 0.03274577080446761, 0.04759952258609701, 0.04981261066859588, 0.05661731447617058, 0.03233885865483899, 0.1161485975899268, 0.021914411190664396, 0.022934866101422813, 0.02278383162774844, 0.02740068779530702, 0.03775249198952224, 0.09940961259417236, 0.08330629192641936, 0.010434202995384112, 0.07599192191264592, 0.012939502448716667, 0.07428777273162268, 0.10648293304257095, 0.017987451792578213, 0.07058902745484374, 0.04892508739430923, 0.02345168661122443, 0.044479500356828794, 0.018619943439261988, 0.0687687544268556, 0.04050801580888219, 0.035767020599450916, 0.07833088937331922, 0.0038439095942521817, 0.0008965731854004844, 0.06134731476777233, 0.11615055685979314, 0.040833551465766504, 0.0222889044744079, 0.04727829509647563, 0.05770342904725112, 0.05708490090910345, 0.020812197581108194, 0.057611295123933814, 0.08096671590465121, 0.054758149199187756, 0.06895522645208985, 0.04015469785372261, 0.022417837790271733, 0.03267807580414228, 0.023258848814293742, 0.05892881876206957, 0.05016170209273696, 0.014325094016385265, 0.030624250757682603, 0.018652651742741, 0.03689459525048733, 0.018614546170283575, 0.030595587159041315, 0.05546391308598686, 0.03459483545157127, 0.04606856840837281, 0.0682022656837944, 0.011785870065068593, 0.0438211634173058, 0.03264138773374725, 0.02284984009747859, 0.028662878758041188, 0.04140125362027902, 0.03885831800289452, 0.08750494045671076, 0.050160536920884624, 0.018816139454429504, 0.02403266764304135, 0.08516305635566823, 0.027101093910459895, 0.049595024102018215, 0.014014603548275772, 0.014463545376202092, 0.12893009494291618, 0.03981014095188584, 0.04413245726027526, 0.025247155208489858, 0.09179879911243916, 0.03201165316568222, 0.05050655956438277, 0.02862130550056463, 0.024540074009564705, 0.06132910246378742, 0.01695338960416848, 0.012334657658357173, 0.008710649435670348, 0.010230260813841596, 0.03215007855033036, 0.019140892145514954, 0.05601382224995177, 0.01867160804977175, 0.04280865134205669, 0.02279861149872886, 0.011641063138085883, 0.029274729422468226, 0.007756249842714169, 0.06624096975428984, 0.05798322243208531, 0.060709334939019755, 0.04762020253110677, 0.005060492103439174, 0.012289619498915272, 0.0397298554162262, 0.018462305706634652, 0.024525273729523178, 0.04208559541439172, 0.023542564449599013, 0.046537423913832754, 0.04265320108970627, 0.04611642209056299, 0.05808388363220729, 0.03488331196422223, 0.03538133387337439, 0.006250156220630743, 0.05219031823799014, 0.031611305312253535, 0.03651287901448086, 0.04504772943619173, 0.022465960500994697, 0.0541342182259541, 0.028335456190689, 0.07642366632353514, 0.04876118779066019, 0.04268702075933106, 0.09305498795583844, 0.060998282715445384, 0.027256592402409296, 0.0421203242149204, 0.024243910702352878, 0.04768039070768282, 0.06629705385421403, 0.050836655718740076, 0.013397152451943839, 0.005951106422799057, 0.01614269902347587, 0.053277249171514995, 0.07108912366675213, 0.05609616724541411, 0.04220437243930064, 0.04749857936985791, 0.013000130347791128, 0.0321857906965306, 0.044314858605503105, 0.06926761867362075, 0.016209000641538296, 0.03287992141849827, 0.02660028709215112, 0.04474999092053622, 0.02089960587909445, 0.01752659292833414, 0.10994265481713228, 0.07160277891671285, 0.08038842701353133, 0.04292433732189238, 0.024242255713033956, 0.040599596832180396, 0.0353534884925466, 0.011874354477185989, 0.01189218828585581, 0.05977153487037867, 0.012662763929256471, 0.12216988659929484, 0.04070592061907519, 0.022632643158431165, 0.020744287357956637, 0.01206690654726117, 0.014023342337168287, 0.02328861635760404, 0.031088286013982724, 0.06250072357943282, 0.021997130970703438, 0.02039087292359909, 0.0328559908666648, 0.05838754077558406, 0.05073113345133606, 0.020104834366065916, 0.09159102744888514, 0.021006590177421458, 0.020576174210873432, 0.08005807481822558, 0.09561535291140899, 0.046260446979431435, 0.01613287484360626, 0.030964544021117035, 0.042863555427175015, 0.06737086732755415, 0.052926892385585234, 0.008063702607614687, 0.023887306888354942, 0.02637058867549058, 0.052455791883403435, 0.0035954051554654143, 0.06695579155348241, 0.08305408788146451, 0.15608756424626336, 0.18089128250721842, 0.16015652247006074, 0.15678372845286503, 0.11874758391059004, 0.1428637542994693, 0.10172755501116626, 0.10358309489674866, 0.1414302218472585, 0.1611540134763345, 0.10582826231257059, 0.13801585271721706, 0.3307618311373517, 0.11315386102069169, 0.11378050083294511, 0.16188085806788877, 0.12447536093532108, 0.19387917855056003, 0.0996623064565938, 0.12333142934949137, 0.17730149935232475, 0.2389567979844287, 0.1384852165938355, 0.08412500697886571, 0.12162466038716957, 0.23150407680077478, 0.2684900304302573, 0.14525027858326212, 0.15122637822059914, 0.15002887841546908, 0.10336445076973177, 0.10518963681533933, 0.20433796889847144, 0.1444405212532729, 0.13387891376623884, 0.1698217194643803, 0.21581093373242766, 0.12256873160367832, 0.26718233653809875, 0.12919692671857774, 0.18086947820847854, 0.17435937363188714, 0.08877491098246537, 0.14679551910376176, 0.08739493190660141, 0.14713423530338332, 0.2175574447028339, 0.08639322550152428, 0.15419185190694407, 0.16998956358293071, 0.1834884876734577, 0.1356651444802992, 0.131197638111189, 0.17017017264151946, 0.06954616153961979, 0.22050172265153378, 0.32070112880319357, 0.07745947441435419, 0.10489726031664759, 0.10837474910658784, 0.08560199959902093, 0.1349658632534556, 0.14640302688349038, 0.14695429417770356, 0.23104247578885406, 0.09640626711188816, 0.17287182767177, 0.08523173470166512, 0.14890385675244033, 0.08110839931759983, 0.12899497349280864, 0.14319567242637277, 0.1879844776703976, 0.11224991030758247, 0.1697156368754804, 0.11556851270142943, 0.14000238908920437, 0.13774315797491, 0.1598838425707072, 0.09048505671671592, 0.26097729918546975, 0.18777894729282707, 0.1293977815657854, 0.11431512917624786, 0.1257479438208975, 0.12633247417397797, 0.1275041769258678, 0.08330182419740595, 0.12172221569926478, 0.1328675149125047, 0.17437225731555372, 0.12597496679518372, 0.18183927226345986, 0.1589168983628042, 0.18532611953560263, 0.113110059464816, 0.11601329664699733, 0.12378820640151389, 0.0825919302587863, 0.1415727735729888, 0.08328826515935361, 0.12347981435596012, 0.345320007763803, 0.15398927527712658, 0.11659217183478177, 0.16306651319609955, 0.22240518301259726, 0.18535816547228023, 0.13438211957691237, 0.1333725909353234, 0.12829356972360983, 0.08079517589067109, 0.0945661861624103, 0.08892040161299519, 0.1978501584380865, 0.17042754945578054, 0.11835529949166812, 0.1595347808324732, 0.13728277408517897, 0.12227363884449005, 0.15967838640790433, 0.17839554377133027, 0.11614307601121254, 0.11804313733591698, 0.15866867965087295, 0.17193882929859683, 0.13482905575074255, 0.11968013699515723, 0.09641037118854001, 0.12919351283926517, 0.12680505897151306, 0.10263520904118195, 0.14720757433678955, 0.1820063593913801, 0.15045683045173064, 0.14467753353528678, 0.1322797339526005, 0.09137018656474538, 0.13827725197188556, 0.07149481869419105, 0.08855490130372345, 0.08190543623641133, 0.08725842126295902, 0.17336580116534606, 0.16916911932639778, 0.051417453069007024, 0.07636373789864592, 0.14431588497245684, 0.09932813962223008, 0.10561660179519095, 0.15332242590375245, 0.2114457546849735, 0.12896821164758876, 0.16894822649192065, 0.1787901733769104, 0.10267561898217537, 0.18809054541634396, 0.10368375238613226, 0.211903199669905, 0.14898475084919482, 0.20382075133966282, 0.16214810544624925, 0.20121832145377994, 0.09934268571669236, 0.15517451480263844, 0.1280230123666115, 0.11696171684889123, 0.1015600745449774, 0.13455944834277034, 0.11254082477535121, 0.1601358610787429, 0.14257850241847336, 0.15134436485823244, 0.17344155960017815, 0.2375191985629499], [0.04909533978207037, 0.03557618474587798, 0.034930746332975104, 0.03310675143438857, 0.04832299782719929, 0.02159777573979227, 0.01998454892600421, 0.03127769137790892, 0.04103112602024339, 0.010418757046863902, 0.06277946682530455, 0.0636268213565927, 0.019807301796390675, 0.0171153021074133, 0.008877192012732849, 0.0452216480334755, 0.013541930620704079, 0.045152554084779695, 0.013997315218148287, 0.05758330873504747, 0.07213812714326195, 0.054290247353492305, 0.06473089219070971, 0.02354080741497455, 0.03815378979197703, 0.08837950954330154, 0.0744765751005616, 0.03765413144719787, 0.020793974144908134, 0.0825166393769905, 0.01939867714099819, 0.08860616144374944, 0.07369092272710986, 0.07766166512737982, 0.06312157463980839, 0.021354965429054573, 0.03381946553417947, 0.05895840447919909, 0.015728523103462067, 0.06723386686644517, 0.030424184442381375, 0.07876175062847324, 0.017176256551465485, 0.024249510206573177, 0.08874643477611244, 0.00993448249573703, 0.02089327907015104, 0.028588881068571936, 0.017533027348690666, 0.04029619201901369, 0.0027866928621733678, 0.0893872273445595, 0.01970912122487789, 0.06195726367877796, 0.03615030276705511, 0.08005741430679336, 0.0902338174637407, 0.07762438704958186, 0.08621087981737219, 0.04041506923385896, 0.05442837587906979, 0.0318325432454003, 0.06604838985367678, 0.06644222536124289, 0.03103719100181479, 0.03830239744274877, 0.026007157102867495, 0.0709157060191501, 0.017315683835477103, 0.09557982630212791, 0.052190036221873015, 0.048175392075791024, 0.03530130808940157, 0.01919561625982169, 0.02149478234059643, 0.009886384832498152, 0.05685146948962938, 0.05539990284887608, 0.036647808883572, 0.03583781777706463, 0.054435288984677754, 0.013567940113716759, 0.058497593854554, 0.025985935390053783, 0.021467018596013077, 0.07317434341530316, 0.06799283903092146, 0.010341473498556297, 0.02838839172909502, 0.009833276744757313, 0.051505690717021935, 0.11142709859996103, 0.010988518661179114, 0.01223115403263364, 0.024536875353078358, 0.048809739091666415, 0.043753483259934, 0.03910482606443111, 0.027144854648213368, 0.032456596673000604, 0.01749257844494423, 0.0315964846231509, 0.03934471416869201, 0.03343091782880947, 0.053788481309311464, 0.031857839348958805, 0.041925057739717886, 0.015819328582438175, 0.055066730492399074, 0.03520137048326433, 0.032959728268906474, 0.03860046621412039, 0.04235553307808004, 0.03540747602528427, 0.035518720251275226, 0.06038209976395592, 0.010143689287360758, 0.08892065394320525, 0.05457285347802099, 0.021474720233527478, 0.04580890206852928, 0.007735036942904117, 0.02066796489089029, 0.02631125953485025, 0.04793497333594132, 0.06587214462342672, 0.0210670455271611, 0.013081768447591458, 0.0038508291936523165, 0.005536328899324872, 0.007980744412634522, 0.02147419516404625, 0.03802497893047985, 0.07284906751010567, 0.009571366335876519, 0.02492995572538348, 0.012973088341823313, 0.018093614162353333, 0.06141396705061197, 0.034441099560353905, 0.0314217311097309, 0.034387542473268695, 0.06362390471622348, 0.007220655779747176, 0.06526754659716971, 0.01845286929892609, 0.04968093511706684, 0.06692335227853619, 0.03991533667431213, 0.041313732144772075, 0.06175184462335892, 0.07334394642384723, 0.017097106501751114, 0.0340265470003942, 0.04090881266165525, 0.03986280375102069, 0.009604058868717402, 0.05094513173389714, 0.027649322109937202, 0.07671682949876413, 0.060434673505369574, 0.026967548146785703, 0.10374461591709405, 0.03911586922185961, 0.04340104103903286, 0.06572036058059894, 0.08766850238316692, 0.06459153169998899, 0.0596793712611543, 0.09429176221601665, 0.08320983499288559, 0.06381930477800779, 0.04564798960927874, 0.03816921904217452, 0.03214151045540348, 0.022766109141230118, 0.062115426480886526, 0.0195286550297169, 0.043695603162632324, 0.026456074810994323, 0.013150614704500185, 0.034053609415423125, 0.023039562729536556, 0.05938808943028562, 0.026660905714379624, 0.039530021022073925, 0.07241092578624375, 0.03752235941647086, 0.02965194082207745, 0.036517098124022596, 0.009389238657604437, 0.05226689674600493, 0.0052394522026588675, 0.030582608851545956, 0.01875385471066693, 0.08198280513170175, 0.032909770598053, 0.06230187995242886, 0.028254443350306246, 0.0173510954118683, 0.023476971582567785, 0.04623732536856551, 0.07003957842243835, 0.07200937194284052, 0.018033643063972704, 0.054939626570558175, 0.019186311583325732, 0.04436611503479071, 0.03647268429631367, 0.047909016720950603, 0.037844681573915295, 0.014080467299208976, 0.02588784758700058, 0.05476525897393003, 0.01797030447050929, 0.01940828238730319, 0.02978041215101257, 0.024367482001252938, 0.04690386303991545, 0.01439716768800281, 0.046336357554537244, 0.010228645714960294, 0.027851241939060856, 0.047445044547203, 0.07081746793119237, 0.032290507733705454, 0.027541567833395675, 0.13735195709159598, 0.012091842709196499, 0.052446244153543375, 0.03883179735566955, 0.07620557880727574, 0.051507341995602474, 0.06798275324399583, 0.05506676017830614, 0.028658767259912565, 0.052509530796669424, 0.009911773704516236, 0.013788485994155053, 0.04055364304804243, 0.05051625943451654, 0.049489635421196, 0.04997827658371534, 0.02920096550951712, 0.03355542052304372, 0.06260737762204371, 0.05837208555021789, 0.033659439941402525, 0.03651244485809002, 0.010757132786238799, 0.031016817192721646, 0.08285482865176164, 0.04244537005433813, 0.061674045282416046, 0.04227849072776735, 0.02554256709117908, 0.023736218608974013, 0.03327506681671366, 0.0797215553757269, 0.046832820953568444, 0.014343652346724411, 0.0478551701962715, 0.05792789161205292, 0.05111434882564936, 0.03066396493522916, 0.07156604260671884, 0.011424664007790852, 0.05271194415399805, 0.021072147792438045, 0.028340484241198283, 0.03541025165759493, 0.02256799467431847, 0.041103726616711356, 0.06501505311462097, 0.021528054676309694, 0.0633513880893588, 0.00672171499900287, 0.04512252678978257, 0.039986367628443986, 0.02146197384718107, 0.06130756162747275, 0.06642362714046612, 0.08275375555967912, 0.041912593369488604, 0.02224589330580784, 0.04496006324188784, 0.008567480799683835, 0.026699799818743486, 0.04010954929981381, 0.05559601166169159, 0.05313440058671404, 0.071649489691481, 0.004483180991883273, 0.0707098565180786, 0.10377018290455453, 0.08164048209437169, 0.014139464328764006, 0.025286249692726415, 0.054462878324557096, 0.006385539263646933, 0.026352311433583964, 0.030232931130740326, 0.013634240804094588, 0.04307295981561765, 0.03968948258261662, 0.027874068546225317, 0.035111741308355704, 0.06145096311229281, 0.03357501693244558, 0.019590091869758908, 0.0340763451094972, 0.04514836095040664, 0.03628850921813864, 0.01986216320801759, 0.037134090016479604, 0.03273720642027911, 0.019565643669920973, 0.0632884688093327, 0.0324871842894936, 0.008602249490650138, 0.16199240286368877, 0.028055577458871994, 0.03553993083187379, 0.10655365229467861, 0.0460721344279591, 0.013981379452161491, 0.03396020270884037, 0.01762436902936315, 0.03622552685556002, 0.09612045862013474, 0.013591850256489124, 0.023082367952156346, 0.0234705724142259, 0.058800445767701603, 0.05276757925457787, 0.021564202834269963, 0.014693840294057736, 0.06066744441341143, 0.06189240739331581, 0.029910061639384367, 0.06363190506817773, 0.04333952070737723, 0.036730751307914034, 0.0344128163123969, 0.02802797327603912, 0.05865150786121376, 0.03267114043410402, 0.03331762898596935, 0.061516988280345686, 0.02411552100966219, 0.01645518401346635, 0.022012001754774246, 0.13247946073533967, 0.13658427953487262, 0.12531622167443857, 0.08208321771235205, 0.14061203371966258, 0.12936971354065463, 0.10323039663489908, 0.12528154853498563, 0.09475210157688707, 0.16276162408757955, 0.24719699722481892, 0.15289778384612873, 0.07260652622790076, 0.08241395582444966, 0.07053434601402842, 0.09940781659679487, 0.17633966112043709, 0.07731434743618593, 0.09913726666127332, 0.2130735368700698, 0.20614057139027864, 0.17787332413718104, 0.13606482069008052, 0.11082063778303564, 0.1373974804300815, 0.2534124691737816, 0.15969952277373523, 0.20445622270926833, 0.11382335243979469, 0.25157036958262324, 0.12565329030621797, 0.15945657331030816, 0.11114142369478941, 0.22378750727511942, 0.14237528754165396, 0.09050306121935137, 0.14606334589188918, 0.16788677719887346, 0.08780375137575902, 0.16566345118917525, 0.10651394739397801, 0.12777369527611881, 0.17659130855463445, 0.1251424552174285, 0.14203959930455312, 0.07483782290364616, 0.08100204955553636, 0.1682661334052682, 0.12219094132888131, 0.1565350644523278, 0.0971569717512466, 0.23571684840135276, 0.1271260972134769, 0.18372267979430035, 0.13537371793063357, 0.2003915244131349, 0.15512106532696635, 0.17849512514658272, 0.1705479109659791, 0.09964549681171775, 0.14004564145579934, 0.10844982476555742, 0.09970654587959871, 0.21497439971426502, 0.15659844386391342, 0.12764058366883546, 0.0936875278421212, 0.14017599227372557, 0.1085100945783779, 0.2109885768732056, 0.14529053267324343, 0.1011580902559217, 0.07325658822082914, 0.10897100539295934, 0.07899964606622234, 0.12467755906982347, 0.1940928873955272, 0.11097356473328546, 0.18589525774586946, 0.13470142119331285, 0.16173131531104445, 0.09444781360798515, 0.1577075687237084, 0.1466908911243081, 0.09320998549810611, 0.2165606661583297, 0.23458422714611515, 0.1564307333319448, 0.1991637152968906, 0.08732022732147016, 0.10275528853526339, 0.1872768547036685, 0.06775783054763451, 0.1180955181189347, 0.21455523470649496, 0.14064779039472342, 0.09084493154659867, 0.1129170936474111, 0.143997770792339, 0.187595933675766, 0.13090962544083595, 0.12833426910219714, 0.27177400421351194, 0.07148386459448375, 0.10626632240018807, 0.14923907001502812, 0.214206870587077, 0.17218097724253312, 0.12746021209750324, 0.15293547010514885, 0.15898988116532564, 0.14668063464341685, 0.13625129271531478, 0.0685427407734096, 0.1666730540455319, 0.07902104960521683, 0.05704661351046525, 0.30943903781007975, 0.21664365311153233, 0.1301169375074096, 0.12405037006828934, 0.13862444349797443, 0.12506616243626922, 0.09813623561058193, 0.15529210068052635, 0.18181970925070345, 0.10599510453175753, 0.08761404358665459, 0.11600792349781841, 0.07544997599325143, 0.0816403262433596, 0.1043277584540192, 0.1052089846052695, 0.13847513822838664, 0.17603426735149696, 0.147435829276219, 0.18741410749498755, 0.08649307404994033, 0.33402523258700967, 0.15640509955119342, 0.12596322601893917, 0.1206975027162116, 0.1933605657541193, 0.10580748959910125, 0.32104931480716914, 0.17410883941920474, 0.19287805102067068, 0.13874024822143838, 0.11016742908395827, 0.1893644715892151, 0.17083325190469623, 0.12888955883681774, 0.11077995324740186, 0.2472096137353219, 0.10271077451761812, 0.12476289120968431, 0.07880751887569204, 0.1603291163337417, 0.17190835671499372, 0.1080553064821288, 0.15211805381113663, 0.14254506124416366, 0.16718740691430867, 0.09499055362539366, 0.11176546599017456, 0.16416294733062387, 0.19748571939999238, 0.1323776232311502, 0.12718019977910444, 0.23657932790229097, 0.18778963421937078, 0.11293514267890714, 0.08485827114782296, 0.14147206413326785, 0.12161643739091232, 0.12128529109759256], [0.024845031766744796, 0.055351021292153746, 0.059926940593868494, 0.0062371960029850015, 0.041176802187692374, 0.04414433533383999, 0.03607215461670421, 0.023109968424250837, 0.027631174743874, 0.0799469010962639, 0.05237910205323715, 0.023796963396307547, 0.02921804418292595, 0.031872400286374614, 0.03618321701651439, 0.035684968752320856, 0.029909415970905684, 0.03355685286805965, 0.03102391397987958, 0.016557873132114764, 0.030830326613795478, 0.039234349387697875, 0.04737208771985024, 0.01054027723512263, 0.01655917745665647, 0.044742825484718196, 0.03232336632208899, 0.06016265040670987, 0.03818423268967308, 0.05441510998934973, 0.021906960027990863, 0.03846828229143284, 0.026845390639209654, 0.021715803195547778, 0.04240200636559166, 0.020002954188385047, 0.03315729911264498, 0.07815739008947276, 0.02801593564072391, 0.08544205193175003, 0.04562758425890934, 0.06025242058967706, 0.01647171906370204, 0.057662098843138665, 0.05934382032137364, 0.05524516134755686, 0.04129590204684064, 0.03958082103054039, 0.06280642162892036, 0.019114512506348547, 0.03725803238921799, 0.0047924659338605125, 0.04313634293794166, 0.041879463897203095, 0.00902039868378779, 0.04867568124609534, 0.038580873515456915, 0.047555257187923416, 0.03593476823880337, 0.010043751681223512, 0.06775017158361152, 0.01331616280367598, 0.04508346755756065, 0.0667073650402017, 0.042912911958410405, 0.03339856761158444, 0.09687131911050528, 0.05349912906240206, 0.018157906415581238, 0.02333138632820919, 0.039687274693278596, 0.048832163083716296, 0.03293217232567258, 0.03159649575536605, 0.027234956942265853, 0.02141795335774077, 0.07362977718003094, 0.019989905376860406, 0.029132474555808585, 0.02467678874381818, 0.03210271097486839, 0.011983698805124732, 0.01830228753533447, 0.05317314811691176, 0.07636454683961347, 0.018915639193437528, 0.09020165278343484, 0.03856859839288518, 0.01755531775415875, 0.00902099611266749, 0.04901844215055462, 0.025634478370193392, 0.05943331590970047, 0.008506748999934644, 0.025850027741398662, 0.06450969507568516, 0.07002284299232997, 0.09310531298979186, 0.04581759261782281, 0.04168169638433028, 0.08181009252439253, 0.01877147144114133, 0.09107552425120957, 0.0074926960405719, 0.012617065258382354, 0.024714770006539766, 0.03565147191693541, 0.05791085190139711, 0.04100117665075231, 0.02239503344753757, 0.04877864310401492, 0.044786445214413106, 0.0374069109238917, 0.01630541304621147, 0.041925974292098545, 0.07576358533697203, 0.02010735395742813, 0.017838697567640338, 0.04498706628510263, 0.03158120751322713, 0.09220270556397736, 0.031364693350042216, 0.03202149775461294, 0.017777676330297254, 0.04594022138917353, 0.013187885360821383, 0.06762016215361655, 0.02385525353020057, 0.09741175847011618, 0.017909800881170668, 0.05715663319278974, 0.03294474801805336, 0.05394701518525835, 0.027660855084832292, 0.016865999859874137, 0.053664820952690206, 0.044056862097932026, 0.047032751826918684, 0.04265737567038741, 0.04540770816674922, 0.002567174856267229, 0.008366800357180182, 0.016924724150158, 0.027818272028525826, 0.07085119854309596, 0.024007519969018176, 0.08911616532714106, 0.026074703673657496, 0.06180012504046317, 0.027881699679710437, 0.05827081578900106, 0.05460662861878518, 0.04862934896664228, 0.04633836135326419, 0.05221246763539966, 0.04076350756804459, 0.03427654315601103, 0.06589219003217295, 0.025073399883694947, 0.035516916832420975, 0.06209682454937138, 0.07807476678863168, 0.0657103193225339, 0.05265311039693188, 0.05001002937206067, 0.013190304762247251, 0.04318882020015735, 0.033352992322761565, 0.004338528988228063, 0.08466855593724176, 0.003914301141776377, 0.007438011816702783, 0.03764053159102332, 0.05749063675466459, 0.025351055883220397, 0.03406471194466576, 0.0336250970576657, 0.014354015511344187, 0.01979316759388894, 0.053668835971620865, 0.03334701061248779, 0.02743107503192732, 0.0629527508863248, 0.010796883143484592, 0.02493458116077818, 0.008543104031559778, 0.02448936862492701, 0.04604701272910461, 0.012446046603145078, 0.018978946245624684, 0.02303910816408461, 0.06578886081115343, 0.03598967974539846, 0.0024108298521241522, 0.019093450355285313, 0.008492079523421125, 0.029336546613194514, 0.052103416455793194, 0.020798243349418044, 0.055097785661928356, 0.01575581743963994, 0.05079224931250792, 0.03707662923261523, 0.07042067125439644, 0.01736160607833881, 0.0375103329133708, 0.015480022375413682, 0.032835470483405516, 0.07647585414815694, 0.01367186676361598, 0.026360424963058904, 0.02233305112895323, 0.12168374276370741, 0.048389219664386474, 0.03147852396068629, 0.028353384623187594, 0.06047817078069784, 0.0541613956738729, 0.027386716865294147, 0.043699024463421665, 0.015170366823440418, 0.06664430475211702, 0.024270312605949584, 0.011701347793859895, 0.03432001074543223, 0.06533328603836708, 0.021981599675200414, 0.04502286377828568, 0.0795091972395312, 0.05689586847438477, 0.04414331117004622, 0.059084944368805736, 0.06683727056952193, 0.02608886014058953, 0.02765092514891876, 0.025987579247157555, 0.030901428071956616, 0.06644059263635427, 0.06340388019452803, 0.016198439880099613, 0.0028067146149624023, 0.010298455836164067, 0.04524609066720586, 0.07290948575246148, 0.025174554612021893, 0.032548415183555335, 0.03021865963091841, 0.037017290815128945, 0.023939440907270182, 0.029946423164801672, 0.02577129143901402, 0.054540670244023204, 0.0510453105380293, 0.04976446012733504, 0.013689883326151175, 0.060529015318024904, 0.06811236933572218, 0.014632422007707646, 0.018022752046817914, 0.08283469418529421, 0.02683250881091226, 0.030147838333505206, 0.012563803174998611, 0.048929406693787314, 0.05788305847090669, 0.014906548167346045, 0.03315162168291863, 0.04375065938802436, 0.029892877209931612, 0.03607198392273858, 0.036039017722941935, 0.04861331115534995, 0.04463159610168077, 0.03526997832523193, 0.02886282447434496, 0.06301774817984551, 0.0441793461504858, 0.03903224402165506, 0.022822041100880597, 0.0870979466708377, 0.02800265676341951, 0.020795653254026547, 0.05220516861299984, 0.04751977510750294, 0.014172064093145309, 0.013072524998278823, 0.06293546626693569, 0.06653778429608792, 0.06212484062416479, 0.013883391839044634, 0.008981649298220873, 0.02872255299735116, 0.07169936201535165, 0.02746022288192762, 0.036438879469642416, 0.020262512916815467, 0.061771199834765866, 0.007548440144091728, 0.03617591428337619, 0.018747631802398246, 0.08053286379436031, 0.045773438541800715, 0.037096485393703915, 0.08213271896238439, 0.02700190216273768, 0.007050773538139765, 0.08984887288534082, 0.021623626598739065, 0.04586893439409323, 0.03536070216796361, 0.10013958904892206, 0.044633484867517836, 0.026322590274503455, 0.0551625120715471, 0.038367253728210926, 0.02979807526571676, 0.02946805518149631, 0.07962310206494294, 0.05652818254020531, 0.06110117778007407, 0.024259230485768057, 0.034968558757100254, 0.1314642175566405, 0.04210439772577956, 0.08474029193166643, 0.040949181784526445, 0.01757497724611312, 0.007744851845927769, 0.07537438825238496, 0.03184348992363084, 0.10447117849253118, 0.06043925997801125, 0.04362546278571244, 0.00797076994786039, 0.032677493218216114, 0.042530735590844415, 0.02551090707129333, 0.03978960943641141, 0.09466260598856024, 0.011429946243879385, 0.05110349120514002, 0.04389842099044472, 0.053849957112106495, 0.013358475425775396, 0.014346793486765819, 0.03855490205751266, 0.02857325514924014, 0.034165291508543305, 0.041385156437172554, 0.018857118993764743, 0.06733244634233415, 0.0275552400489687, 0.10001408445532434, 0.12818986200727522, 0.18405759619781747, 0.10264525772072375, 0.1551230691256933, 0.0658829948224593, 0.1233305165078491, 0.10057065810542554, 0.16868939506821334, 0.0971051178930793, 0.1306628464953974, 0.10791216103825718, 0.11906352359801531, 0.11478266736958176, 0.10151957554626279, 0.1787906780373305, 0.1465066900709644, 0.11130613595014438, 0.1621315407101065, 0.08490521940984763, 0.15295711113139987, 0.23096584161976352, 0.09767715790076181, 0.20763577631441876, 0.07495093363104388, 0.09822007603361271, 0.149495912482962, 0.1366952306125313, 0.18814706738339737, 0.17291487223701552, 0.09994260079110973, 0.14804584498051554, 0.16327608085703105, 0.07411178725305945, 0.12448850437067449, 0.08716495518456213, 0.35693963582161814, 0.11697230729623698, 0.11697114954586141, 0.17184672877192497, 0.10472592810401693, 0.10917347070062533, 0.14857983507681638, 0.12281364033697173, 0.12009841142571531, 0.21453265857417136, 0.13236389349913225, 0.2024590439395979, 0.12998424150282517, 0.11802951150457375, 0.07618229021318257, 0.09015660441946238, 0.15150322898989543, 0.17531197954667732, 0.14537733426550403, 0.15723888762295246, 0.10997723147738725, 0.0725627840438392, 0.1915451983222738, 0.07433452803525142, 0.11443342009442858, 0.25066845235414803, 0.1145358438952826, 0.20191360992612317, 0.14586544479243457, 0.10454456947627477, 0.16392271412769333, 0.1873613111092709, 0.09571111964760348, 0.12469471752410755, 0.16863417928107083, 0.1751986684394069, 0.16610250575467944, 0.1443128421669826, 0.077261877595447, 0.15441641095094383, 0.13105964317219332, 0.1448962592985481, 0.0626561589888297, 0.14500395976938307, 0.21709848573664203, 0.10738117664004676, 0.12635309103643522, 0.19079969613812864, 0.17332991090370342, 0.14767100103199482, 0.12553600128740072, 0.14853475702693686, 0.15882641571806744, 0.08265207390650176, 0.11901392586878501, 0.15240481967339292, 0.12020952577586286, 0.11489184471429326, 0.1997437482350506, 0.12407362897647545, 0.17290347284870222, 0.27201229298952967, 0.08075349687715061, 0.0997115702193696, 0.17032050207490101, 0.14169908710755408, 0.13314970914507285, 0.15918668388621882, 0.10703324296628125, 0.1600239155231975, 0.19868431758368388, 0.11095158231910318, 0.13281345687573776, 0.054919636822887696, 0.3425839764531702, 0.20822076679905877, 0.14908728597220033, 0.05273526614473667, 0.11192457503057085, 0.1307573664234951, 0.21385020925663412, 0.17573136719875038, 0.14015780965564772, 0.1288117075455375, 0.15306491550290957, 0.11979102127952501, 0.11738357585272752, 0.06297078507486731, 0.12449893896700814, 0.11875962896738201, 0.09178183361655101, 0.12841963092796504, 0.2202093758387491, 0.12920038512675092, 0.20702050620457157, 0.12008012490696274, 0.2373197241104208, 0.14703843888128176, 0.24941318377386779, 0.08756837181863375, 0.24983338778838515, 0.11947654362302274, 0.20341261464636773, 0.11670813983073458, 0.16369914956158027, 0.14446806977503002, 0.11572353250812739, 0.10422448118333705, 0.1004083504085429, 0.13801089517073706, 0.15080238925293088, 0.09646523074479774, 0.1716760199633427, 0.13742945215199143, 0.18203372979769483, 0.23359614657238126, 0.1556857951800339, 0.12777237425325438, 0.23404624429531395, 0.09607811909518205, 0.11855999866384082, 0.13131391780916601, 0.1820073538692668, 0.17519310233183205, 0.20418014377355576, 0.12349349955911748, 0.1846771707641892, 0.13474736013449728, 0.1164012543449644, 0.12606562755536288, 0.16332598286680877, 0.11927908781217411, 0.12136910183471628, 0.12170547284767963, 0.10272607018123381, 0.0668225834670011, 0.18182413245085627, 0.05843481187184807, 0.11424683674704283, 0.09980767834349535], [0.036919149206369184, 0.045505248635890894, 0.045388794533209875, 0.07949049511807971, 0.030398906892514788, 0.013567728601628914, 0.10086436304845847, 0.019237222913943697, 0.05416336978669278, 0.06386652021319605, 0.021923014537605923, 0.008563939827581635, 0.04952395232976414, 0.034184190299129114, 0.049151086204801686, 0.08735985058592632, 0.03286070721514989, 0.041917231792467646, 0.023719579658063594, 0.02705557428271277, 0.007098051128195948, 0.05838831631990615, 0.10006413489463739, 0.02446319122100249, 0.02853646317817038, 0.08981419974588789, 0.04911878422717564, 0.03496442128380295, 0.027854819090862293, 0.01847084226028528, 0.01179521927042515, 0.04250947677064687, 0.01705249414953869, 0.01712532295641722, 0.0254184911318589, 0.06615037578740157, 0.0347103358944878, 0.062315320246852934, 0.05075084118288942, 0.027124690495838877, 0.03727715382410679, 0.020895733723591547, 0.016727722904761322, 0.04591325174260419, 0.02360084530664608, 0.06417761367629282, 0.04214052176394034, 0.06600196851650253, 0.06098476078477688, 0.02422054789349204, 0.015062491947901435, 0.027712360133591574, 0.010481317312951433, 0.019939066405640915, 0.07853664239519276, 0.02922011848568218, 0.02657682038261555, 0.0407624203216983, 0.04335124664066825, 0.005062828477093717, 0.02763146418146789, 0.011569717698876048, 0.02663980831130175, 0.09239799430361018, 0.05249863606877625, 0.0779412173142191, 0.07119879082893021, 0.08237966118031181, 0.04276828592992388, 0.035893827662221156, 0.025095751516346354, 0.03306969229015522, 0.014759034256712766, 0.02542404425184941, 0.047899572891765274, 0.048664133428246714, 0.04143429403484333, 0.04433192058058921, 0.06189549843838904, 0.015706748490629252, 0.015722992247901857, 0.015005320601630956, 0.046082376065896824, 0.0427760265301913, 0.019348916139279027, 0.01611240269994596, 0.05846713611390442, 0.06370343326125294, 0.02063400977931451, 0.0391504644358065, 0.05069492035545409, 0.015855050005484372, 0.008834598302200902, 0.07613364985445514, 0.03845633371383883, 0.04191463427559938, 0.01751949985191459, 0.03071136034122901, 0.021637855425069574, 0.0458328214881476, 0.013950522807135712, 0.020173585071461275, 0.013019665530009661, 0.021184690776863135, 0.05120866837387439, 0.005873193904335494, 0.061008587435935624, 0.030936106777517125, 0.032579926773905754, 0.03380787318747025, 0.029344255672185682, 0.032183671864913777, 0.021561521825788077, 0.026167106625507586, 0.06188281513459515, 0.023768034479871858, 0.05210428105783649, 0.04638126119971275, 0.0802569703955669, 0.05003176316677127, 0.03562784564564936, 0.04283181006030645, 0.00777530958657735, 0.0032502675230716704, 0.015199302233668277, 0.035358379245735705, 0.035438308550510556, 0.07053021225146949, 0.039617765141883865, 0.06080765466322191, 0.05655439519614447, 0.09104728553211316, 0.05754203048127238, 0.0415835362218786, 0.07324502556002699, 0.05229762537055649, 0.0378902494412614, 0.03132609424937982, 0.007111498844096786, 0.01609744842426153, 0.0643472166848369, 0.010733681847341359, 0.07532886491389945, 0.05091719358460978, 0.03302598350273911, 0.02873242356145056, 0.042878609892795794, 0.039277876348933205, 0.030025922023924068, 0.07755852886475623, 0.01621839066501707, 0.03532999209710397, 0.02050089075055439, 0.025930866177077405, 0.08606695511844009, 0.013173032202757895, 0.01622732241230551, 0.05981374080874957, 0.026015255789388902, 0.054079507099231705, 0.023474559602618683, 0.02262024558149278, 0.01895782657811651, 0.053586208960041404, 0.0034430352798153763, 0.03621245392423589, 0.047113645923673175, 0.06342126871459186, 0.07958432484883815, 0.05000455232220702, 0.010003761053667404, 0.06499048802652396, 0.015082042900758097, 0.04809340331121348, 0.036414930364117026, 0.057467871374683455, 0.03888330240442883, 0.011491639124869835, 0.06326139526208863, 0.002439454256091267, 0.06738282332662493, 0.029853211271984037, 0.04379390062240418, 0.02320998395589413, 0.048657984734745696, 0.031032522892928682, 0.02803743009280879, 0.03602801909437403, 0.03560250501323026, 0.03520802012644708, 0.05332569657184649, 0.027525363038876094, 0.06957333156606182, 0.027065138710895553, 0.08067142276559025, 0.0061068985269230325, 0.03539806930348277, 0.032129906976479106, 0.038503285686601885, 0.023542599701613653, 0.04798733556526713, 0.056238366450998, 0.04876094659266528, 0.05880185584828723, 0.028289567344472744, 0.1156131157767959, 0.06611601434997283, 0.025127817862085067, 0.013302125080372207, 0.00938123737796559, 0.09075523557839915, 0.0420045306236716, 0.03492125055345241, 0.011743519407900749, 0.0162169008035562, 0.06895071419421583, 0.07839038735255599, 0.014882637096889084, 0.03487731912173331, 0.02730634227191331, 0.0270944090152625, 0.04557207532343455, 0.0024680969818291487, 0.04846107811317779, 0.026376488749519922, 0.03316633476060815, 0.06277992695686407, 0.07082968368194997, 0.0262998731341213, 0.016103424568427727, 0.09609647240722552, 0.03161363194521982, 0.021907846894464456, 0.1251984725240618, 0.05042182485340163, 0.060568527260329574, 0.03114183753496036, 0.021045235662313644, 0.040152122601284645, 0.04559303728456143, 0.037112953650648706, 0.10170717563596554, 0.012266098983673146, 0.025486603590252344, 0.06449092616094276, 0.01789823450963013, 0.11469231831142679, 0.052228019339963794, 0.0644522528455127, 0.02621434618049534, 0.035903316020267084, 0.021147006373212207, 0.07663340467843227, 0.04886680282652378, 0.08693259616848081, 0.020826029358431697, 0.027372276526875794, 0.06556138512678444, 0.03990325079939794, 0.033335652042296715, 0.02866902188543463, 0.03019598516402766, 0.10449042238178663, 0.03958506611525081, 0.05142851849086583, 0.019581800224841572, 0.03561689154594205, 0.05963796684227418, 0.002754519368863839, 0.08263088559033349, 0.07185906477388926, 0.04284143200493418, 0.03279693075455725, 0.018690226679609623, 0.03506106746499427, 0.040589496202301234, 0.027336620041751303, 0.02149218853446655, 0.05021976030548103, 0.028008942754240707, 0.015268511215253966, 0.026459555483597796, 0.01602315387572162, 0.046979287508293055, 0.0550714616838377, 0.04485363184357993, 0.05147906987986062, 0.026772784476634115, 0.11202482433873229, 0.028630792003241368, 0.05022485143854283, 0.05204351771681104, 0.06299529821262695, 0.07948524071252905, 0.03687306183564942, 0.038524425763171166, 0.032987915037665516, 0.021659832273144275, 0.02960718746180646, 0.04002065856184345, 0.021511347076739185, 0.008080901880020974, 0.05545681815419812, 0.016502401304023806, 0.06390252921846695, 0.049418734342907555, 0.06915698671946302, 0.032045595289673656, 0.03896654168784153, 0.01058605939761037, 0.06919027204276063, 0.04218090201902669, 0.03267273605160881, 0.01788098699762486, 0.01607556434464641, 0.023943279666127637, 0.03131941492029, 0.021288947682478465, 0.0314533577329712, 0.03573013957065996, 0.04564336602925323, 0.03815888092503883, 0.02482859319570707, 0.09104085111175664, 0.049932846013689414, 0.1261494605569169, 0.006586454410353326, 0.05079307680716738, 0.007079553097355529, 0.04549655808659736, 0.06308975134743378, 0.07957991649163887, 0.03559378477802966, 0.051121770302415825, 0.026807485446624923, 0.0276995617969078, 0.05413078579294961, 0.040913710836321115, 0.02952561801066622, 0.010996663731930312, 0.06268437544349581, 0.05205714354815427, 0.044667979891528375, 0.03147999341308605, 0.016466828310512938, 0.016583796350460034, 0.09350590204121545, 0.06803865922847763, 0.004637229976651724, 0.01474711536502582, 0.056734685131232254, 0.10635587736032903, 0.08246105251600966, 0.12226667007780634, 0.21468093967996538, 0.164202221785672, 0.13547638664022088, 0.11752768608857878, 0.12623814720427617, 0.11735119594959542, 0.1253965517389588, 0.1632752051227726, 0.1157480308029335, 0.15564797533443198, 0.1471758697880432, 0.1592876308131963, 0.176732168183662, 0.2284327580127865, 0.1700993865961209, 0.17206260468810797, 0.136277980345767, 0.10913754333159886, 0.11107339843874797, 0.08448646258329973, 0.2729452616767958, 0.13042424601735547, 0.17485288699390367, 0.16669721837388352, 0.1765605539549142, 0.14899240981321782, 0.16433831682661548, 0.2321108864271082, 0.1626895318622701, 0.18809747707564384, 0.0924070188193582, 0.09177117637591437, 0.18275710113812238, 0.1971401457558386, 0.12836063018767163, 0.17560497944941744, 0.07651712498045526, 0.20167158072581515, 0.15063895349157974, 0.12190124398330227, 0.11805711197666824, 0.1076897319580894, 0.09284289699280635, 0.17171241488540545, 0.11686614307109267, 0.1311701934901066, 0.13108707295032218, 0.20446732523851097, 0.19541641871910542, 0.14928394026355818, 0.12816964590456337, 0.08621968168881722, 0.18144875415600836, 0.17782325885491446, 0.09575096555636264, 0.24136267747962847, 0.11765356175601482, 0.13384484918788075, 0.1229894180141855, 0.07756903767585754, 0.09049403670360334, 0.13303305837325752, 0.10529926687013358, 0.13916490512201563, 0.1287192656309344, 0.16269388084765524, 0.1583200483582914, 0.07571440321044065, 0.21484629018232226, 0.2092820528196171, 0.16149072587722912, 0.16583981516305357, 0.08481171622406691, 0.10166615713387728, 0.11936945171328261, 0.13419236725894734, 0.2554794098250568, 0.22080313850892708, 0.11402599586290307, 0.13894911826355383, 0.10723400875576772, 0.09770988661330193, 0.13218908803537488, 0.1376414837432094, 0.20037009118823335, 0.23242877796292305, 0.09041225202963687, 0.10174388226005249, 0.10314568789908662, 0.14238092786399648, 0.12309933008509688, 0.2081108547281474, 0.13619689329061657, 0.11614897608524188, 0.10471138200955465, 0.09771430239197798, 0.1568804748239927, 0.08862411399604753, 0.09543295527691953, 0.11064200283726677, 0.13251235272036865, 0.14335296320496127, 0.14764018706046045, 0.0810948625439778, 0.15830100484890863, 0.11176098341820762, 0.1614047258044593, 0.13326061569387093, 0.10044336493592709, 0.1204771368065849, 0.1574911584611982, 0.1490723539609462, 0.1539825217332691, 0.18355016014538705, 0.17798239015974104, 0.15193639090284705, 0.1133481552824378, 0.18943868635687977, 0.17340940976282582, 0.1420776714803651, 0.10310314057278447, 0.14101528708124533, 0.08624556779977866, 0.13254398305434734, 0.1715841272380203, 0.11483894442790188, 0.11707483499776572, 0.13306145294336602, 0.283647773321718, 0.27473253139760345, 0.15036995464470237, 0.07785778507241048, 0.20827120315516368, 0.14068702032091096, 0.09591349589754827, 0.12265781901078299, 0.13443521282169968, 0.05895113143196795, 0.15094237314769998, 0.07810162511304952, 0.20226072723744437, 0.13430210121441633, 0.11083979261456989, 0.08486174439894967, 0.19945208419812843, 0.16268984356429428, 0.20939169771736488, 0.29380088788457215, 0.14233832858735695, 0.11548108770512044, 0.054691704717697576, 0.1822062346036546, 0.1544860689318739, 0.08951463183620945, 0.05853215938259382, 0.1425167705747299, 0.10757717784144916, 0.13289340102346614, 0.23826335003832355, 0.17988893785513937, 0.15785371244419366, 0.11627658095676452, 0.08928495197324082, 0.18214062874903902, 0.1084410006296821, 0.1894408682710491, 0.20093488041311502, 0.1252239875611849, 0.10688482827390544, 0.17821310902945697, 0.075123713031644, 0.09030201341374777, 0.16452587238745764, 0.1752008800394833], [0.01185316523333313, 0.06184813828440383, 0.03575998875021469, 0.037778834521304816, 0.045481644629035145, 0.09677297712187283, 0.05173363024368882, 0.02785391923680436, 0.033068794291466475, 0.04023952904390171, 0.030693289045302663, 0.025687226516311057, 0.09767761061084457, 0.013532080465665786, 0.08048324380069971, 0.03303434008557815, 0.013057607829978224, 0.04188188700936735, 0.006062814027245622, 0.11610160479904152, 0.0228631393838441, 0.07877165829995647, 0.0541510390030453, 0.03814694347965997, 0.05582245205005165, 0.03179757324687671, 0.01217835393617861, 0.02373976236413, 0.027862637616635766, 0.022844413142593112, 0.04808245663298294, 0.0468959072168218, 0.04747307546494994, 0.050936700936290435, 0.028172137317596935, 0.026341238590248395, 0.039756149708409794, 0.018451806172379293, 0.014052827864361461, 0.035223263839725405, 0.068364669859875, 0.04853412028751336, 0.05940268747508526, 0.04075650169397704, 0.045264822474564426, 0.02688996773940744, 0.028561013423313852, 0.09064084093552083, 0.016468431349494494, 0.04841079760808498, 0.036081249636481516, 0.03498951700748876, 0.03982716581958812, 0.028780240136256907, 0.022328021223074757, 0.03568692431144882, 0.04074225616932381, 0.017268225346924737, 0.03972951031755656, 0.043168533593416214, 0.06791361476643942, 0.04265809555363376, 0.02185716191888787, 0.025310627388535067, 0.030965480982558802, 0.047512691307929344, 0.039901799900690094, 0.06485742094810121, 0.05304260062985122, 0.05622290751489345, 0.02177421578380745, 0.04915267069009133, 0.028145321666670498, 0.04102962317119818, 0.034197723362012766, 0.03687380769406445, 0.06507865517050959, 0.04903061708319001, 0.053927867775200866, 0.02699187389225699, 0.13149238948244601, 0.026435135114297736, 0.031796385810594074, 0.023831940816307906, 0.003994426651843241, 0.019401554818614386, 0.04062089275976177, 0.01495938258813112, 0.04367791778349783, 0.007203454188129399, 0.020201387778797653, 0.052427423288463615, 0.043659583025146276, 0.04143660953559447, 0.025159192155115306, 0.034224722694489174, 0.007429073111779871, 0.12081702559953555, 0.0472814232489327, 0.023916456593724433, 0.023869790347816888, 0.031340592104243115, 0.04482859920244664, 0.048438910162076354, 0.10285927826771513, 0.0681885879021138, 0.0303188532780041, 0.05123061368067283, 0.024987329306895845, 0.03912275264156051, 0.03597487389924936, 0.027471505381981842, 0.02942197708762251, 0.056516278491471894, 0.04981662939826492, 0.0104335860851279, 0.04078335259691812, 0.041433882142882794, 0.045704938311246224, 0.03703244547068607, 0.05119391447806265, 0.016715091551304795, 0.058747244911501184, 0.013596462704299483, 0.051725681842071936, 0.047369427120429464, 0.03611079082475044, 0.042155327610089444, 0.03573739777493756, 0.009711435577628436, 0.06636163554503582, 0.05521712671907153, 0.03438897110754624, 0.04348957554611843, 0.010855792970687617, 0.043540542537812144, 0.051345305182621814, 0.00934050367504824, 0.022772840420657303, 0.036336021512397565, 0.017824724782258272, 0.05399884677899536, 0.03294225811259821, 0.05069754755822942, 0.02053133735898882, 0.04148667852859944, 0.06596823790459894, 0.07673365398659371, 0.047884874657029286, 0.051551581418607384, 0.0873693500761874, 0.011078978113800986, 0.00963804088314646, 0.05386003918829374, 0.07458253152435645, 0.060028685329598375, 0.030434179316216614, 0.040805928729241714, 0.011320396897644969, 0.004508726178755751, 0.01763837892212905, 0.09818752543651499, 0.046613935628556646, 0.03628187070717104, 0.096616332011763, 0.03672717786685098, 0.06705929146846756, 0.07859772114898078, 0.060283802304184064, 0.003327436734252842, 0.0600308041612152, 0.04902803812001366, 0.006628421469940804, 0.0011270987488387618, 0.02796246946672909, 0.028348508712952025, 0.04194079869193956, 0.025995715041062795, 0.053589229501085356, 0.012575207201734884, 0.006622040391448536, 0.0734269036911428, 0.041165959410136566, 0.040083770800265484, 0.03001955439685844, 0.0339883041306166, 0.046390293136937544, 0.006344861685647629, 0.03561371886462439, 0.037693016274715774, 0.04662655213905964, 0.04290477801987436, 0.0266592952539213, 0.02960701491247164, 0.04671086011512671, 0.035763885025517084, 0.00899883094461984, 0.026671223422454204, 0.10026622170698829, 0.05126902353367768, 0.03693792183184996, 0.03157420906063635, 0.01816689382394543, 0.028930766238772776, 0.0392775460932171, 0.05295087117701769, 0.095359593979083, 0.024354095512535423, 0.042203526390949264, 0.08580883615650237, 0.051527654577512294, 0.08637453822302632, 0.031171831433312036, 0.031522024946752936, 0.03251808731874917, 0.008735813808016246, 0.037352292565628886, 0.04744400554045569, 0.03328452177811414, 0.08646254209452309, 0.03808849935012404, 0.02291358687216416, 0.026420960093673784, 0.051653485716087744, 0.03148003794194665, 0.06640142208198085, 0.028125649187131785, 0.0561287029995583, 0.03816901495156344, 0.07660941846552305, 0.02771588904579403, 0.043836169643327594, 0.055855069440440275, 0.05209030270634685, 0.040384207022725604, 0.02959437799290754, 0.030867703026160598, 0.01452569653338287, 0.05265024199616164, 0.023088399757398292, 0.045127053890610114, 0.01452333743145573, 0.021696642797905952, 0.025012235782924108, 0.07915609079645947, 0.057102734717773274, 0.019526443429640494, 0.016381468340114225, 0.009968332778953481, 0.01513072593297693, 0.012149029826105107, 0.05052842323493678, 0.010776510262076044, 0.07145509152906016, 0.028861071150458883, 0.020549462460621726, 0.08981401420896873, 0.006803397163821501, 0.04435448929143604, 0.0508549978985684, 0.057608723582234234, 0.04026984577649273, 0.024965090851765126, 0.06223316078830976, 0.020074894273420796, 0.019866421280312352, 0.02649574260431109, 0.0389885463664541, 0.05013895526644774, 0.04840528345084749, 0.032399150732089765, 0.03524457089952193, 0.052735789358848706, 0.0472825513134012, 0.02705757251533214, 0.07959907132317312, 0.014790395562158665, 0.04565716997603886, 0.021674337549484335, 0.05319242540281266, 0.14127521688351408, 0.07876365794800222, 0.06279393870499916, 0.02988450949487742, 0.0076001692286808975, 0.07460065477062017, 0.003274151690675353, 0.044954356126254424, 0.014658876789326314, 0.03791510025621392, 0.03667770259198733, 0.08988082234282047, 0.0707954409881495, 0.05320252232195344, 0.0786737393354997, 0.0816672142536845, 0.07529426598921418, 0.04130443303438369, 0.03980634857725818, 0.027248972401139326, 0.156931757228449, 0.029043489194009453, 0.03075298369367374, 0.010652015917003155, 0.02057349876849912, 0.08273048923001625, 0.056929806887637824, 0.044780270545743406, 0.016338249370164704, 0.05412465936387889, 0.006333430756058078, 0.010749746561486972, 0.036322228697827086, 0.036998310388298705, 0.005663895271936781, 0.02012782610108843, 0.05246263448498212, 0.026748698073788546, 0.018988505107699893, 0.08971520466729999, 0.022222014704311732, 0.07811372212017886, 0.03140273955068551, 0.025137085431197193, 0.008202414646802936, 0.03790294016653206, 0.06899502041051164, 0.01790260947018396, 0.0075937255314784124, 0.010632553094183095, 0.09688072954304516, 0.04323100016335957, 0.061608072064700536, 0.02653490759257693, 0.015461507646250539, 0.06857034866698086, 0.028518545877886936, 0.06060291838366538, 0.0323700622539036, 0.007047810513540753, 0.08389034730498679, 0.045908279353170656, 0.06753845911589451, 0.04336868711106945, 0.02279456122778356, 0.038373918214347214, 0.033661402922007255, 0.04341234023740981, 0.04304092872189358, 0.051576038895291276, 0.05210792500292882, 0.018035494722425938, 0.16806961270049214, 0.1981799688655883, 0.10296968015609309, 0.1643088535638526, 0.0858113520371262, 0.12071671691955999, 0.20349113387055695, 0.13135386019712314, 0.08868180113495328, 0.10846285687875934, 0.17425352853024378, 0.1432710004155524, 0.14395552774658427, 0.13468997727613896, 0.2003916134708561, 0.1348117191810161, 0.08401556246099062, 0.10894274440943263, 0.15844781650230289, 0.19218659203033894, 0.08185736733139493, 0.13003877451410517, 0.18834418180631474, 0.16479688987601548, 0.28704597847536206, 0.17291249736445025, 0.08782871722360142, 0.1556149052339606, 0.08579348112107255, 0.13567030982812867, 0.17775284388335422, 0.13753595034359023, 0.1469141143024899, 0.16683650464983657, 0.1118158726603724, 0.14861302392091602, 0.10276528526446782, 0.12431535389623605, 0.06784639845136553, 0.12605562340468168, 0.1579303020844236, 0.10811199172167107, 0.23517159250332043, 0.14222078723832965, 0.1382059315801598, 0.0878443468536716, 0.20859708019997925, 0.15625224681571126, 0.1112967032531742, 0.11872842907905579, 0.186697727185674, 0.22178048762725666, 0.1304775767493993, 0.11233971759793349, 0.18455470155458897, 0.2204027201514691, 0.1778278304846026, 0.17146704602055252, 0.14930225646821782, 0.18087357486365363, 0.14953144651371986, 0.10284992720698938, 0.12882646144134924, 0.07730221332167275, 0.10851584622287191, 0.17924214131198823, 0.16473275347379968, 0.1906174691976048, 0.2113915333757177, 0.12254106433829293, 0.09901805547997355, 0.1847484169411473, 0.12156859113019891, 0.19228759832913056, 0.11089468927821144, 0.17943872138857841, 0.10621619774610735, 0.14352187601616606, 0.09645272555644624, 0.07727378906565718, 0.17869042872916907, 0.10711753609939478, 0.24925492820329964, 0.1629343515378423, 0.12242970507941209, 0.13657314731972292, 0.0740452462923713, 0.09802471307921223, 0.15156645997194573, 0.1401310774963349, 0.10351277640438639, 0.08887318617780693, 0.15267757378751412, 0.11819299921626225, 0.12838872789870948, 0.11804297406342812, 0.1828550497884862, 0.1764837565133348, 0.12624401017092168, 0.17109659558627754, 0.12859743466833606, 0.16394484497141093, 0.1492737579974346, 0.1674711299710907, 0.2868869510712102, 0.23985074454685673, 0.13681814511073753, 0.15793954924447462, 0.12834580207709223, 0.2244950708700344, 0.11370066800736822, 0.06561353584402241, 0.15399304538732395, 0.1259078469593078, 0.16608182952040806, 0.15354615374235436, 0.18502877064747736, 0.1425902431947179, 0.17046666063833982, 0.16443216882180423, 0.16235798480920494, 0.10547136349487118, 0.18149503448512405, 0.2556101168738678, 0.18120573047781363, 0.23764098499668762, 0.13225749920820817, 0.10495139998965897, 0.06976438264246099, 0.13216352846939117, 0.11082624099799432, 0.15624481049599126, 0.16826853796374053, 0.1001763847307302, 0.09230194555129856, 0.10367526963818818, 0.11288129986496642, 0.08183539976016618, 0.08469395965221338, 0.09387676065671258, 0.1494642227771692, 0.1031478623917792, 0.15049684705445543, 0.1756254627252929, 0.09397773726959713, 0.23767999227857217, 0.162502005987335, 0.1852238070569001, 0.18358771281782538, 0.09636306669563055, 0.11006616303347982, 0.11335557675920427, 0.14198134071193635, 0.16227389947744086, 0.24310599721502513, 0.13746461510891095, 0.1265495820553042, 0.10118387988768518, 0.11376205846318044, 0.14405926514882594, 0.17572783457580954, 0.1529832644155249, 0.09977812602301128, 0.053818879678146914, 0.17494666477432474, 0.14380444132257253, 0.11962185613811016, 0.14319240697659552, 0.10081931468448602, 0.10082907392643392, 0.1567786224768497, 0.15568045171676204, 0.06629339506616816, 0.12664637295529246, 0.13818633888149634, 0.09276832599425688], [0.03839508797682356, 0.027738214703276753, 0.02841835408617044, 0.11722457071300596, 0.06438443539082073, 0.08057571540120989, 0.03004958725796314, 0.03634133900050074, 0.07928462335257791, 0.10912447411101311, 0.07767605537083, 0.02521020553103881, 0.022813571340520866, 0.02474656175763812, 0.028885732717753854, 0.02041684252617415, 0.014246270511648618, 0.03023966055479832, 0.025633975565142464, 0.03804824526014272, 0.046549750986741856, 0.00561473819288949, 0.01645560889301123, 0.005435830044007162, 0.027560344169614837, 0.029577863351732958, 0.046711683899047785, 0.008657778835186036, 0.06361791558447294, 0.025636773461883422, 0.01161370200861711, 0.052729373492184095, 0.07790746443788521, 0.04057207428559195, 0.024770390264166053, 0.007648420423720381, 0.09031428111484274, 0.017650763511483092, 0.08822985546430573, 0.033052544968086295, 0.035056132182944566, 0.018614123146107886, 0.029949994750495534, 0.004271808984412928, 0.05172031611436978, 0.032208470729528926, 0.08621983753982931, 0.014353271508298349, 0.04953924799337983, 0.0713467231253162, 0.029732113180216402, 0.10635497936164029, 0.021755702910013497, 0.04845379022299312, 0.02928388938016724, 0.01846797385951504, 0.032824534937390126, 0.01782046670996351, 0.02646088021720061, 0.038306716742226854, 0.02376679694862105, 0.015161835835897364, 0.022973036611801945, 0.00719663292329642, 0.007451647388734273, 0.026242371532134712, 0.041484537432552315, 0.03403419483220205, 0.04556931082333904, 0.07779351508361287, 0.05431309065897949, 0.019394849514355883, 0.05088443518616259, 0.017780732123355847, 0.026470661723578814, 0.016210594403673895, 0.03070553077122895, 0.04475150490179658, 0.06772613342036493, 0.03302842516859528, 0.014912695005477872, 0.007365082356045605, 0.03808075503911823, 0.02988267453474691, 0.041203289438271895, 0.07543327767052688, 0.1565394876524806, 0.026989838552253786, 0.01001949087367393, 0.02866630005883053, 0.056782230822136626, 0.037616486006299965, 0.08293398612295277, 0.020278712145227473, 0.06520585186081007, 0.06571466830791906, 0.021578747073363047, 0.013201430483604781, 0.011571978466236033, 0.0552473432617262, 0.044515353511087596, 0.004194485081825405, 0.007796897734806407, 0.057776582543738186, 0.034117207760573365, 0.0407945775805274, 0.12466656044125557, 0.056560035518486984, 0.04567161959130317, 0.010509459552849876, 0.12094261925085448, 0.026484512054594234, 0.017628081623115577, 0.032150538681889884, 0.09559841710142791, 0.04417297481268179, 0.06852828373666853, 0.02823361868649954, 0.032631865979055874, 0.04522388189798221, 0.054602535674348474, 0.04392844457470346, 0.00459101504930004, 0.044293848404777236, 0.010078170635097194, 0.03888030783855356, 0.07694649451877922, 0.04006026698334608, 0.015917585224087816, 0.01391483106999658, 0.0316039209428709, 0.05612403117993381, 0.027951198098890018, 0.03859128584736027, 0.01698868985840818, 0.008053988822211977, 0.025214780871465337, 0.04588488314766437, 0.030812132863502484, 0.031060266228450928, 0.017862321983557194, 0.056118680295185186, 0.06728534965077415, 0.10440989935887046, 0.03332730659167282, 0.06014306884026155, 0.047196157902362756, 0.06869122968055308, 0.03037959620996844, 0.03549996989022475, 0.051054153227596544, 0.01741230775223812, 0.023874710786913056, 0.022752184595447034, 0.02855530630768044, 0.06467503815656528, 0.03372430364834145, 0.013022921702940948, 0.04527015109488275, 0.051533346850192174, 0.10868233221117407, 0.03571993875084445, 0.03659689013147727, 0.013169812209525844, 0.0640109644155018, 0.07297397838556208, 0.0021025301111876615, 0.04646898676583078, 0.013703596359846415, 0.062109904902172275, 0.061788618040736765, 0.027318571010255255, 0.01780240283551393, 0.039226979861268774, 0.04021696404379327, 0.029226044534880202, 0.030093084533291403, 0.031061455520102754, 0.04637028483557515, 0.07649920211406425, 0.06210996056324802, 0.05065827310318127, 0.017056034193956293, 0.028414439257176127, 0.04299923115468118, 0.08304713395773433, 0.07017263065790758, 0.03752036303922068, 0.015874368109507486, 0.013408734594122507, 0.019924575972254388, 0.017049048728949856, 0.013393047447607387, 0.025188983818225097, 0.045117083136574365, 0.032128975581144914, 0.020093824605282862, 0.018709362957451958, 0.014391718468687031, 0.1393889298196882, 0.023177808143373113, 0.022137283704068977, 0.03821298720140476, 0.06078846643504221, 0.010205915586993797, 0.04784491000464186, 0.012383806388243102, 0.023143888283811975, 0.053564304471365176, 0.014137949419819051, 0.027849267826240975, 0.028578652418218553, 0.05737573745136615, 0.05883660320250783, 0.04027894450700842, 0.03839966331725009, 0.01624505046493141, 0.033538395655341446, 0.06509634797112085, 0.05607450024399441, 0.043925531645072624, 0.012082487937732367, 0.028596211632248014, 0.03278051815868821, 0.05110719823278487, 0.011910514695046004, 0.04897636979876552, 0.02359415484534111, 0.01990614844544325, 0.02237919601611793, 0.08486896549584344, 0.031567756086587906, 0.024857702082954347, 0.06142002297565341, 0.07230599352624267, 0.024206669731938746, 0.04788334212207701, 0.048400329615105875, 0.04748604078486096, 0.006978393266763305, 0.08661414060043171, 0.04377169185318053, 0.037059359456179664, 0.05206494352023583, 0.025505493103992194, 0.037988977346685715, 0.019486833152768668, 0.05330725049134344, 0.04748543964524288, 0.015603391439071856, 0.009736699212226085, 0.009447473130421713, 0.046110996991046704, 0.05561119600315578, 0.0396852374979062, 0.014125853340374306, 0.025167016246996354, 0.03118466687737964, 0.04213046937366016, 0.042705752566689625, 0.04646721303288359, 0.036365295527502894, 0.04230723781802226, 0.004815342635993147, 0.01885361605673097, 0.02583922578196507, 0.07173968289862387, 0.03203714222763665, 0.007167812082116143, 0.04725927756226156, 0.03727992945641745, 0.022843119950266555, 0.041893152811098844, 0.00416570598645194, 0.03431748002185486, 0.029046396557532717, 0.03943051015085075, 0.010158419063373003, 0.006350054400172667, 0.010460900830366882, 0.009760814373294124, 0.03695397077535745, 0.03343586053233594, 0.058475719051784836, 0.06588266827748157, 0.05530734590138309, 0.06866135081509128, 0.00812554948424804, 0.01973723563423846, 0.06893245736137033, 0.03191777519532479, 0.06233048974536359, 0.01371397065668134, 0.055235517138498835, 0.09937544411513954, 0.04436852330400143, 0.07644883255125023, 0.0561360057326965, 0.04505896555201616, 0.035622205323306844, 0.05340134368452709, 0.04139116783335339, 0.039337240741588175, 0.015697143244324252, 0.1065901065885555, 0.03741102984349709, 0.02892161184718134, 0.05729419397539459, 0.03841718542389572, 0.021700941688322928, 0.015074138100317214, 0.03267482890805695, 0.062037953684921376, 0.04210225662973244, 0.03670386329758912, 0.049409164348617196, 0.028184909679112025, 0.026888644861173816, 0.036340830629342236, 0.08376621568459086, 0.058282697573304176, 0.08371745658223517, 0.12444768624845892, 0.037613317035720684, 0.0012658564764933544, 0.07346712809521705, 0.03429203919949941, 0.09897306648781523, 0.020118562242714688, 0.008926541122491471, 0.01954101364390226, 0.02854544873116538, 0.027070302203355823, 0.037407319105113856, 0.03106146294157952, 0.07764950132695958, 0.07549400019343011, 0.014629339311795775, 0.04477652641071472, 0.03542400365404319, 0.03451559263339732, 0.02993451911606826, 0.01745601653965423, 0.03227670749765821, 0.030105432015261613, 0.07977803281391971, 0.03818791374214925, 0.021084940563014243, 0.10604221606627107, 0.030319113029690925, 0.08877347863744944, 0.014710580362589099, 0.10267961915815249, 0.1899257133482024, 0.11726286553312093, 0.22531613853061572, 0.11900576966581866, 0.09993681203923188, 0.20483599451836199, 0.09869646062725224, 0.14428284455789253, 0.19571825017919764, 0.24337915208889171, 0.12479557539336383, 0.12434265008778311, 0.1490901951910928, 0.11201790010090917, 0.11863013161928393, 0.1037452467426192, 0.07728370415861718, 0.08104470078251325, 0.08397038051043637, 0.10683509695809335, 0.15853473683819175, 0.13279511098517105, 0.1585993927437812, 0.1187566677981522, 0.09070425745449029, 0.12562853225972503, 0.1392885172390379, 0.13951659406302497, 0.26470638345927, 0.0744531158125028, 0.17592579504707828, 0.1725225878180936, 0.1593519453308545, 0.2077436845866032, 0.10768995460239239, 0.15139922441449016, 0.11486776944366284, 0.17471312574343756, 0.1830177879310213, 0.0945405598031357, 0.16429196228273213, 0.08790840904111974, 0.10567083794740029, 0.1405366018298082, 0.1980287636979483, 0.1391518730088137, 0.10247780694044195, 0.11628217675024644, 0.19999299111077562, 0.18051942199235782, 0.17620337312109768, 0.11604625542531721, 0.09524927372694947, 0.1780138720641844, 0.0889224796264898, 0.07525038279709406, 0.15398701914818957, 0.1624445043853484, 0.08665079527418129, 0.2402324607828632, 0.13600954553112388, 0.09957953472621739, 0.1122373309044633, 0.16305278346408159, 0.10602856797049753, 0.1824985517305322, 0.10466205887496471, 0.09845797889283858, 0.1989243578282185, 0.17683318932540715, 0.11756941705243662, 0.13085347454762086, 0.12810341664589942, 0.14687556715216488, 0.10365867521613836, 0.15406956081278622, 0.0874661335546989, 0.10242006785119884, 0.0834439454774838, 0.11801445332821459, 0.22282408084720373, 0.14509254251606762, 0.08686725006555207, 0.1293679472291842, 0.2575079369125888, 0.20031088264659047, 0.08202959754271433, 0.06655129138380289, 0.08080492028966546, 0.11226175498450175, 0.13056927651632577, 0.11799323532613926, 0.1179520832374692, 0.1406384987058118, 0.180354323820211, 0.13383073353907093, 0.1282651603105478, 0.10923548456048593, 0.1641592662781477, 0.12628257216420025, 0.19878142018569633, 0.08337458435562439, 0.11036135969334282, 0.18471117597073317, 0.15011291921837255, 0.2312324507511221, 0.0978811297682114, 0.1182145660277456, 0.1253895607078448, 0.217580258322414, 0.10036191422841512, 0.13391971704550087, 0.1402679888997227, 0.2222846879158169, 0.13111965323332697, 0.18211223417893052, 0.1843840372748673, 0.1309173586196266, 0.11582010818528943, 0.15423695964273065, 0.14278183603892103, 0.1409969708765857, 0.13696148351300508, 0.10533131280681118, 0.07676516557694413, 0.19784567586611956, 0.0700500352832023, 0.19926583481719717, 0.1528452249476686, 0.23476847272831947, 0.1609806774649769, 0.10965244538965635, 0.23750686406856403, 0.06529876874992624, 0.15836843638680875, 0.19254448532592505, 0.07049782492686063, 0.13434060383588076, 0.22635204310063273, 0.08422472194069996, 0.18445645604515448, 0.10737511329352856, 0.18969687953358516, 0.112689907400636, 0.1841005071764812, 0.24884557438781485, 0.17653190705459565, 0.1577727441326715, 0.1365178424748592, 0.15251240140059963, 0.2041572262533009, 0.09543806867441162, 0.1450515165925026, 0.26173414138611406, 0.18027930753305554, 0.17382109392201528, 0.07034276059130207, 0.16380658285925165, 0.13157160632545128, 0.16346238960977644, 0.10442462356877513, 0.2518382255220786, 0.11103191980510019, 0.10310055789886974, 0.14243075565900654, 0.088478868274251, 0.10175453950068913, 0.12145399610744789, 0.17410303582437336, 0.14500118413707241, 0.13112564978655428, 0.12952235847478732, 0.07843798128305934, 0.15759464353322983, 0.0879274080216419], [0.048903724673436955, 0.021961016209388617, 0.016729079179640394, 0.10079313171445392, 0.010033824528363766, 0.0203536672051996, 0.018918928763014264, 0.01574746271217009, 0.07151551719289273, 0.027087067319371272, 0.08603803362348117, 0.05029834632296115, 0.028664207202382386, 0.04624488785339054, 0.030594143681810237, 0.03850549728667829, 0.05086070130346343, 0.04121950907574501, 0.09498122482909821, 0.00966017265454866, 0.02064991585939424, 0.03476290592516307, 0.04279792359739076, 0.024326220445800573, 0.07742601839709096, 0.013312769333424512, 0.008293419577967143, 0.044861172063974664, 0.03136865641863551, 0.02510239188268315, 0.04751646141812671, 0.01723599387332797, 0.06112566865340341, 0.03889276478730608, 0.041126688665826805, 0.03141449145914521, 0.006498685706901597, 0.047670197309344076, 0.04331083669967484, 0.03562535945093259, 0.03815488445980009, 0.015094023947312962, 0.04788172424014192, 0.06013961414282676, 0.014653103808086598, 0.030242315588111524, 0.04350285998953041, 0.0495026935095666, 0.025796038353291806, 0.03019481442606775, 0.04024308764201123, 0.07098295202013105, 0.03884585734340362, 0.016726819339965004, 0.03105132891505491, 0.033889412952703424, 0.03979424414865207, 0.04649662063457072, 0.041511733434163034, 0.043533095085876994, 0.017845052207121626, 0.07969965459778905, 0.03005398448294727, 0.017953036549442913, 0.06002572787110694, 0.009215375721396413, 0.024440902670903597, 0.043428266726550646, 0.024957285313575994, 0.06840644535259344, 0.008212013399315765, 0.016725006644264795, 0.027202033415960614, 0.019286362366983667, 0.046122025305521674, 0.040291642653755844, 0.09804580491618253, 0.0031457796239919844, 0.02876545098843053, 0.03040449897525832, 0.07930935171316378, 0.020699574815807864, 0.05088311416329816, 0.013219154825492296, 0.0038802991821285104, 0.019909872171410825, 0.04318378843890969, 0.05863036036316771, 0.0463864302582806, 0.013065983894193778, 0.04809046440641396, 0.019488875914248638, 0.02604686756967567, 0.014175526212056866, 0.0128894325280271, 0.08032836500206031, 0.06153383132186718, 0.05798105907160789, 0.03757783866603859, 0.03986887080827728, 0.03985689996625297, 0.022107122822490055, 0.03794888281845488, 0.03526910259097349, 0.029344326176214963, 0.01215507554661599, 0.06092773415730335, 0.027480529897729866, 0.021743663419329096, 0.037868103754590265, 0.04993720613128971, 0.01195249520606012, 0.07186811155406758, 0.0656686032016296, 0.05942743067862466, 0.10844934979104437, 0.08703539846464992, 0.043284349449095316, 0.031705554356449284, 0.0343519082525745, 0.023685283158556558, 0.03794458207266871, 0.02348824480577605, 0.033812904948717915, 0.05926635865762364, 0.013324192841537297, 0.025809563994698692, 0.08661497922730632, 0.03426506955293007, 0.02305846708622994, 0.002775459529402724, 0.07249697038787417, 0.019112315749225672, 0.008476434122712817, 0.08555053165764548, 0.09427124925423414, 0.032870770737645216, 0.05593267211224884, 0.015960574128257576, 0.02279779513628455, 0.02186346460803179, 0.0867878551071044, 0.021872843499295413, 0.029463010432664305, 0.03146618575556204, 0.05376817614887841, 0.09573175135301426, 0.01553239573695464, 0.06352295036776923, 0.039783657412044704, 0.07375871049589477, 0.06113402152550407, 0.026142261376662645, 0.006342742390188505, 0.03333168526296504, 0.026503427543502767, 0.08622987879789434, 0.03363743526278995, 0.0048871839226194425, 0.06775753368856385, 0.018749926894088276, 0.059495363166206516, 0.04189553881587926, 0.037800052523380145, 0.00959461782258586, 0.025634951489337254, 0.030886716849636286, 0.03654470601759385, 0.0633244555501733, 0.06678368008579127, 0.037140209024073556, 0.04458479626919143, 0.01899470946227666, 0.011936666123801842, 0.039044378136168234, 0.029398905571724754, 0.06823547679232433, 0.038606922898907214, 0.0027496381244418444, 0.04761009076901246, 0.02888365284889005, 0.03436656937992666, 0.032267122660414316, 0.014242264769563917, 0.028301927814027295, 0.06463548168540001, 0.03400569636141881, 0.01929536461830139, 0.005486780801220448, 0.04177049435384106, 0.0534742671152344, 0.022252689523156732, 0.06923696797457524, 0.039269968765438534, 0.0013626638428831939, 0.02408518015727168, 0.0558025662030559, 0.015669457425246947, 0.010817207785294158, 0.03166681053698994, 0.04491764950216748, 0.057388873465242796, 0.026826961257029325, 0.024441589157504495, 0.007271704871527618, 0.018776844590320252, 0.04631596333638299, 0.01384085750032682, 0.05617434508167207, 0.052979417887399904, 0.015740430862933863, 0.014537778697558679, 0.0002068180907599526, 0.03593667184759397, 0.013176053671486443, 0.02053158968919888, 0.03796514698478859, 0.08059168641921133, 0.08064054942224175, 0.05442347770440392, 0.018934499021270312, 0.02681893492990639, 0.029700675804633647, 0.030446884884440806, 0.024942345880845096, 0.046771783017902635, 0.01206495655424078, 0.026834054333448876, 0.00751191766539705, 0.04710949360742234, 0.03374241576239001, 0.07392844709102064, 0.02535810443077935, 0.041092423707596026, 0.060253864066908136, 0.049865692781168036, 0.010504251531529007, 0.03142472567560617, 0.01723840399790788, 0.036829902237514034, 0.03744677538634278, 0.016855867688718718, 0.015838503823033534, 0.015873004413151648, 0.04485808472963981, 0.04955446573148947, 0.04958744677423965, 0.01798751673049992, 0.024372081461478956, 0.03911797692126129, 0.04328150702349376, 0.04625585308531299, 0.06333889774396084, 0.011019122975994833, 0.029719554186158348, 0.021194698638282716, 0.0757560896454379, 0.03922247502487153, 0.03520120350003708, 0.03465410707576666, 0.010968615188176045, 0.02340693139558425, 0.03254133880545851, 0.01532385780592449, 0.03429478143516462, 0.030759848559682723, 0.04089907568413764, 0.02330017159692943, 0.0749565516889561, 0.0359864625352202, 0.0266205866864766, 0.01528273911389988, 0.01772157738741953, 0.04823656359803863, 0.04856103798374534, 0.049444312462583184, 0.02167189959436655, 0.016951890465861652, 0.017455164925195277, 0.07054647270706482, 0.07922685457742773, 0.00930391301153577, 0.023414115385094192, 0.03698909291415475, 0.03576630071620457, 0.04940526436257642, 0.0672366499202326, 0.032074327536975034, 0.028596261727216188, 0.04274591388821136, 0.04141319848713465, 0.0275716396572534, 0.06192287997691892, 0.022991764708422124, 0.004452085004231776, 0.03255038558563683, 0.046893484104657546, 0.012697880501946202, 0.04158457522862591, 0.02894659624871565, 0.0896802124043461, 0.00953154176386306, 0.026227012785966508, 0.05589768727077171, 0.02338895657885587, 0.031477993325097486, 0.010003529132518452, 0.053960733785061166, 0.06841171460109763, 0.01668889744905755, 0.04378943289339077, 0.08939319421187975, 0.051220921232015826, 0.029870349317207, 0.017898928417707793, 0.011457785130915, 0.026980235161317978, 0.01566695824294584, 0.025882001318677794, 0.010119643702637404, 0.03710357290401589, 0.06889536482049152, 0.05288732107146643, 0.025030642900674138, 0.0425908050237922, 0.058219785714754835, 0.045705331649514847, 0.05582870093348902, 0.03444847650825977, 0.07543641695519909, 0.05414637089415919, 0.02460604166117264, 0.04045813235279638, 0.04615285783074796, 0.026198768500762526, 0.035319453600095585, 0.01839487045799615, 0.016650092402414884, 0.028283197862037923, 0.01890584284410579, 0.023116371303331107, 0.04604498666594736, 0.015363233378593577, 0.011677470120048383, 0.005269559742373531, 0.027842070849146694, 0.01880772349977633, 0.04861440211243462, 0.021198106951487716, 0.058738454172271304, 0.03859808392007835, 0.04391688933537807, 0.09998221663408913, 0.2008307125652209, 0.09119510650634766, 0.19480184622807428, 0.12065200906363316, 0.12527059443527833, 0.07348624581936747, 0.10295751635567285, 0.15981685632141307, 0.12904404429718852, 0.12723387189907953, 0.11348591273417696, 0.06518810710986145, 0.12519992713350803, 0.17551835597259924, 0.09806256261072122, 0.1277094698161818, 0.14710391114931554, 0.15856034093303606, 0.16584178927587345, 0.21651155082508922, 0.11853190095280297, 0.12852514948463067, 0.26130259735509753, 0.20118525135330856, 0.11549298433237709, 0.12425593755324371, 0.10028956225141883, 0.07647414720850065, 0.15793511120136827, 0.17412207933375612, 0.1225062576122582, 0.18778204947011545, 0.1646217578672804, 0.11721905655576847, 0.17686640785541385, 0.11220934451557696, 0.1418027502950281, 0.1129031486925669, 0.17405518214218318, 0.14812206354690716, 0.09100821145693772, 0.21634689794154838, 0.14159117883536965, 0.11002549334079958, 0.13268592621898279, 0.16661271743942052, 0.17366279382258654, 0.09205637630657293, 0.12489521614043042, 0.12707635847618803, 0.19426289858529344, 0.14713934127939865, 0.21428536012535915, 0.11034723662305623, 0.22939403221243992, 0.08957332829595543, 0.19713959656655788, 0.1917767632403411, 0.18184448214014992, 0.0708521633350756, 0.17982587014557794, 0.08981768783996813, 0.09124419957515784, 0.18127017858205363, 0.06724286169628613, 0.1919685787288472, 0.15984833822585642, 0.11093661320046522, 0.2836052037309855, 0.12464763567550108, 0.10807540384121239, 0.08698397505213507, 0.15687842649640515, 0.12144736130721867, 0.14189200097462162, 0.14300675131380558, 0.17058007564628497, 0.15964598424034193, 0.12287172823562287, 0.16443682950921357, 0.1077426470874343, 0.12614517094334587, 0.13166821910999715, 0.0762196870346088, 0.19145122758345678, 0.12409807532094419, 0.13087803963571787, 0.08296931977383792, 0.14905198942869902, 0.1519839625689201, 0.1697380348923616, 0.17369178211083636, 0.09290785717894323, 0.08669822593219578, 0.1960060847341083, 0.16427421011030674, 0.16286078986013308, 0.12600665650097653, 0.15418705763295293, 0.08907166615244932, 0.15081540652317926, 0.11699026727001183, 0.13942603720352054, 0.2187938627321273, 0.10068908261018805, 0.13539372623199597, 0.12408170354319736, 0.12184076636913233, 0.21727845654822886, 0.10297163942595944, 0.18276219227118418, 0.12107987204217352, 0.10733592789620161, 0.15230100805638358, 0.21975956013193354, 0.15227151510771364, 0.08415310468990356, 0.11441618000390008, 0.1016430689196568, 0.23189993837149814, 0.12949617550475523, 0.05961416616628412, 0.09559820930007845, 0.1500055007636547, 0.16410020616604015, 0.12292664716369472, 0.18658674642210826, 0.11515156671521254, 0.1209082652349025, 0.16956621286226436, 0.23153024492785335, 0.22263634717091918, 0.12408439753926359, 0.19161585078109056, 0.1816570750088431, 0.13054033275693655, 0.12534856447018683, 0.08433437425992452, 0.1379453783738427, 0.09217081547831185, 0.14636820531450212, 0.07966780904098414, 0.0829379862989299, 0.14933697413653135, 0.13614207826321945, 0.14729672111570835, 0.1503097070963122, 0.15703965065767989, 0.11296886586933397, 0.1132058929943014, 0.15066865424159914, 0.0921552897489164, 0.20256668503861874, 0.12312020669924095, 0.08168932283297181, 0.23781337105901912, 0.17509786994196475, 0.14726826717378572, 0.21966870641335845, 0.09717503562569618, 0.0654291121463757, 0.11822374639450572, 0.17071778856916353, 0.06306327151833102, 0.1648537680739537, 0.10638298801495694, 0.12918580934638157, 0.07242754247272387, 0.09580802929122001, 0.11153823521453887, 0.08770860062213615, 0.11721604343620129, 0.19086675660219043, 0.214638177130837, 0.16987515409709886], [0.03852250360068865, 0.07277867480297573, 0.026438057320774533, 0.03142766458040569, 0.04578941698127892, 0.049256419224548154, 0.039642597403144464, 0.04458570540009532, 0.016979594838630874, 0.028665953104791697, 0.0345564515737351, 0.023980685764399823, 0.061705167245236225, 0.04933048927341588, 0.04111663256480824, 0.04988851382222492, 0.056510563954361714, 0.049755732470657676, 0.052648583296104334, 0.05273694339848589, 0.07262919141794555, 0.0404389404138783, 0.017313416574324947, 0.012791610042768298, 0.04692158923717216, 0.01380648214762914, 0.06768835068214685, 0.004995136723664473, 0.020709458367491607, 0.04289357158995699, 0.016102010777103715, 0.06387550762156025, 0.03210960181604605, 0.0339492634520866, 0.007111080922186375, 0.07094174055964686, 0.022855363531562034, 0.040132106878445484, 0.043445009578135796, 0.02106912354065571, 0.04207426653010771, 0.023441020093741827, 0.045298137483769096, 0.02716916369536193, 0.060454607591964304, 0.031238502269843593, 0.09506613394478336, 0.022748431183572393, 0.036821341564063914, 0.04574976774165407, 0.02352215724386042, 0.029473578615579754, 0.011606335265241796, 0.050770085072144866, 0.022295841699815355, 0.0467923293763306, 0.06863234026241116, 0.014816948678344488, 0.04575880338961724, 0.05792208430648316, 0.0056482443051208975, 0.03881112854287494, 0.020336826019047294, 0.020056381399626844, 0.04980865502147935, 0.017031836468959227, 0.028413704530976247, 0.047718989808345214, 0.011621804405876901, 0.019268960859335493, 0.09808228889596649, 0.08005236770259216, 0.07635612346348353, 0.017325936605629977, 0.008472725239698775, 0.06093679206969682, 0.019232836821174715, 0.04829236939258408, 0.08253588326624595, 0.03192528944055084, 0.034239216838614084, 0.05185093039472122, 0.05140058776305523, 0.014635770021413919, 0.04814086736587342, 0.013718901300308062, 0.006900483067511232, 0.019508552104525734, 0.03442683919274714, 0.035583591379690915, 0.035518111690180376, 0.03361474780831486, 0.03354100430442486, 0.060299365140963346, 0.0414126344549004, 0.03821409300144296, 0.08447495187283494, 0.0064931103224807885, 0.04142233432503417, 0.05716483392461669, 0.02530872563511366, 0.05106014978082385, 0.037557811810984276, 0.06085235421778634, 0.06508794685942121, 0.11066250837757252, 0.048928397372947074, 0.03149756747006904, 0.04823469709663186, 0.03761664927878883, 0.026786003982124384, 0.03375523636350408, 0.06029367657902185, 0.06747663079295307, 0.09064326775842346, 0.10290419304510579, 0.03130424542177934, 0.08210920030251145, 0.08708525594556704, 0.049977705130004324, 0.005519928827197873, 0.06944565247977152, 0.04818537396204192, 0.0725452322512865, 0.01176214082079241, 0.09353223344078287, 0.017906630055222195, 0.06887425814056769, 0.030455376909230836, 0.020033653127029538, 0.07697044362430461, 0.06947920497623272, 0.013244292294984916, 0.04060672516061459, 0.04988527434761636, 0.03406203650229145, 0.01548851254483452, 0.057829887300613336, 0.04202586736937519, 0.0401884507300565, 0.01211005037475843, 0.029953911434859037, 0.02291697106556967, 0.07072178283124231, 0.023700999990978744, 0.10684869310352951, 0.11402128322515637, 0.025301064815721475, 0.04530624544713646, 0.08344627582118846, 0.012357800605968805, 0.05162451969226822, 0.06592584642930888, 0.014528424853779143, 0.03262628131778911, 0.07261120175826363, 0.08363072920474224, 0.02264384773297934, 0.010519042534724576, 0.013411780182650546, 0.07356484667980112, 0.06504427146865055, 0.03592609995394014, 0.03500670885841828, 0.04602295230142772, 0.04217795198201202, 0.06517045141663402, 0.03942416107747704, 0.030029233857931104, 0.05066033256298397, 0.05117100437928457, 0.029436027798510622, 0.06955314514925703, 0.01687522846623324, 0.027652491080516484, 0.02272942292620428, 0.029583256909972988, 0.09238499187631533, 0.011321286547172349, 0.040953530769911595, 0.04294032318284735, 0.04501491166593041, 0.10886709729675204, 0.01107488702473347, 0.05313946203386877, 0.014172608644003049, 0.04804553107533138, 0.03312272616312839, 0.05432427853520494, 0.02870196582080098, 0.04612103453837335, 0.03097221597272437, 0.05556548341701273, 0.0694190984359011, 0.030481893845717423, 0.017249968514079228, 0.04699655357399024, 0.035459734353935346, 0.020853455425822176, 0.005655434788423008, 0.06255034357309341, 0.03392525868548546, 0.06698308032355271, 0.04638100886950269, 0.028605074730876368, 0.006128749209892703, 0.006239703534447472, 0.021315464618965052, 0.037636442357324995, 0.029896589803684037, 0.008368702110601589, 0.03688594923005439, 0.03730349264515098, 0.05378468151320703, 0.05233733398199547, 0.03452778983046301, 0.03160869295243174, 0.030049097440496553, 0.013158967576600844, 0.007183083162090043, 0.024656518835399766, 0.008747023948671995, 0.07580507139209658, 0.018724313522398006, 0.06624831701628864, 0.07388889061985537, 0.01189141366921831, 0.023649936520087067, 0.01884678829810582, 0.035559560637921095, 0.0461824843659997, 0.03614617642597295, 0.05272308007988613, 0.03007912659086287, 0.028695394103124272, 0.025440085773880128, 0.05086254182970151, 0.04705348372226581, 0.004141909485042561, 0.04705346145783551, 0.017295087382080965, 0.03367593788425438, 0.028187343923491426, 0.02219498568592826, 0.023695804957242217, 0.030651808556285687, 0.033842835764517076, 0.05042866374424193, 0.010605653023958439, 0.0494299890124239, 0.03999418615421746, 0.042110884096473455, 0.03593254179577343, 0.026493245277379174, 0.027639479376375675, 0.09433113315026276, 0.06521395611343905, 0.01318078393524047, 0.01749547282088315, 0.03317352617159486, 0.033869697799673304, 0.02099604425893631, 0.02828600689099403, 0.05408086894021835, 0.013867801171727479, 0.08223033364629373, 0.0074117402527917875, 0.04096424367162399, 0.036742458687513135, 0.02505447882867884, 0.06449526772485115, 0.028648187944781967, 0.04680136502429377, 0.0393629524478456, 0.01849650016083615, 0.022081943607190624, 0.08827370154904202, 0.03369826910784468, 0.010957866106764413, 0.010091153581015533, 0.024042579025262967, 0.0761118381342385, 0.027793814551841933, 0.05229212234553415, 0.06922857428435236, 0.009609323478798615, 0.0860566170013044, 0.08070841882727109, 0.05342956384993158, 0.006746174331055954, 0.06136188312666491, 0.0520158838480711, 0.03431931683735456, 0.041744945920072496, 0.1082695645163767, 0.02544513608881971, 0.04031914664665237, 0.022782790765631944, 0.03841874764475506, 0.01470564229748561, 0.03295105627330486, 0.07039804317173548, 0.008022519905352965, 0.009468859043408884, 0.02886837573896628, 0.043203960012760945, 0.08209483232349157, 0.049239873042097315, 0.040031282405834645, 0.006120811940490967, 0.0208240812207805, 0.016127865346788894, 0.0735929592337925, 0.026607923791743815, 0.017927460285136476, 0.06893001569551416, 0.04014775506220758, 0.024917981172620784, 0.02220009166194359, 0.053318939317250624, 0.056458361286786385, 0.10171847854508087, 0.05379441849072464, 0.11821064748801291, 0.011931736407859717, 0.01851112047006609, 0.02557690069806995, 0.013920652290835278, 0.05243177969532553, 0.03099342098721536, 0.03830199668300338, 0.13178390508983284, 0.024606193801446352, 0.03436205712205265, 0.04095012802281417, 0.03696239415148739, 0.03756917780265212, 0.07715748710324988, 0.013916706848249305, 0.04832375481782947, 0.00452671954917605, 0.027739697143260855, 0.01755687626427971, 0.04701888108684216, 0.0512410890951287, 0.040415536786895245, 0.07761599335935898, 0.03523118997691199, 0.01941943686688319, 0.020152714023424778, 0.05640713083266746, 0.01715808506560279, 0.10095575111336075, 0.15680796699598432, 0.18973477359395474, 0.10163211481994949, 0.17985169688472524, 0.09418039553565904, 0.21101983613334596, 0.10946120135486126, 0.12274692868231796, 0.06897854473209009, 0.1456446707015857, 0.1222298966604285, 0.15228770877001807, 0.11431541119236499, 0.10457545024110004, 0.19144392485031858, 0.1373374555259943, 0.13505880982847884, 0.13527284521842375, 0.13266093068523332, 0.17029440816259012, 0.10255462664645165, 0.16147992020705715, 0.10498216201085597, 0.16986740607535467, 0.09627341525629163, 0.23143559141317382, 0.22838125296402723, 0.141367792384699, 0.09196333325235173, 0.09030166460433975, 0.12604322953848168, 0.11458855122327805, 0.1642388096661307, 0.11585410597035661, 0.1293202122906223, 0.07989625693880953, 0.1681225426727906, 0.12091577576939017, 0.10049285876448266, 0.2055788694997318, 0.14782245852984488, 0.12377567894873209, 0.1479977389681153, 0.11606659027165733, 0.20178398641292006, 0.21618739556288347, 0.11878741497639567, 0.15000542654888704, 0.1043437591579277, 0.11895495481439866, 0.1427949423668906, 0.11457251341198571, 0.10314093073247932, 0.165754379122518, 0.12790536711690947, 0.1695251720957458, 0.1022840321820695, 0.12417465753969736, 0.2263977297116071, 0.10902031368459575, 0.19298825995065272, 0.14533988549374044, 0.07840549005777575, 0.1635005508433096, 0.13998178706970066, 0.11174331288202666, 0.21215483226114884, 0.0896714253758546, 0.10072674660477787, 0.16154766344698146, 0.21431623346870765, 0.1458064143662341, 0.15036299329949543, 0.11895189716597088, 0.08669207352795638, 0.12237121642101556, 0.14532952511217445, 0.18504183244658634, 0.1745017323992215, 0.2026375156128779, 0.17463362688431516, 0.18967457057442516, 0.1255700213368982, 0.15902269893558696, 0.10603930684737861, 0.15223460068227723, 0.10997616278473288, 0.09663818083936349, 0.21278417349094525, 0.14103553286986426, 0.1275235618231818, 0.08951727388193831, 0.10320910441805609, 0.271094404743053, 0.17497658816864714, 0.1776220923056826, 0.15136456611799076, 0.08217519949539565, 0.11615849783993326, 0.1576511506573297, 0.17584168002940714, 0.07613856287207454, 0.13259017432574183, 0.14650734316091985, 0.13347506668651477, 0.12040614295983687, 0.15588574460707605, 0.16736926278099418, 0.14297964808065444, 0.19944708212278783, 0.2264529454987496, 0.19143153098411858, 0.13196976855397224, 0.14655818027677014, 0.15268624207237735, 0.15982168028131127, 0.16384768299758434, 0.21910317504080012, 0.1682814661762677, 0.10454773844685405, 0.13581446459284052, 0.13988493679789826, 0.10047065370599739, 0.09675048262579367, 0.1768519211327657, 0.1845638596569188, 0.11838412450742908, 0.19012447533896193, 0.08372311174753122, 0.11268498696153983, 0.18085657968185842, 0.09156534913927317, 0.13961556687718257, 0.12418565616826527, 0.08997834796900861, 0.14873633917886764, 0.10787186984089203, 0.13017774908803403, 0.25003073969855905, 0.07536022807471454, 0.0976736846496351, 0.12904352479381487, 0.20185851288260892, 0.22540724457940087, 0.2711434755474329, 0.1855743382475339, 0.1845297505497001, 0.0948761886684224, 0.24818372708978131, 0.08658142673084512, 0.08973755073384382, 0.18359575769864023, 0.11773602178436704, 0.10495348542463034, 0.2402089347015135, 0.10921304201474413, 0.10858658031793311, 0.08594317230745219, 0.13670596206793562, 0.15096512739546597, 0.23544342635432258, 0.14222129189874977, 0.17062292725313455, 0.09785580026800744, 0.12340747722191736, 0.1730942344875075, 0.1289742230437696, 0.17948586260899901, 0.13822726090438664, 0.09883163540507667, 0.13058426789939404, 0.18097707477863878, 0.1287108496762812, 0.10107218666234985, 0.13607831293484196], [0.022969413075770717, 0.0298815705900779, 0.012848810147261247, 0.047743525210535154, 0.03201910432835575, 0.014676718947157497, 0.03176655147399288, 0.051094778391416185, 0.08554521788028069, 0.03715432838362176, 0.013662565797858406, 0.08043686699238606, 0.04097989556612447, 0.04715964794741012, 0.08249308360973373, 0.00895095314263017, 0.07418746405164711, 0.021994694870954845, 0.019988424792245496, 0.010260909657517914, 0.049382907163817436, 0.011117355497844983, 0.02926330405898625, 0.07010928093222901, 0.01694407379545737, 0.06474559413618408, 0.07909602136351168, 0.020968460485164542, 0.06505909215775318, 0.02387516164162662, 0.019041592786379624, 0.02101243459037505, 0.028056807568646036, 0.06500566494651139, 0.04001320368843153, 0.025599649379728362, 0.08928747527534142, 0.019169179104210343, 0.037830462024430744, 0.06653268574154936, 0.012023770141240675, 0.06149050845124293, 0.0682728439278435, 0.016313739943143446, 0.045970326609676704, 0.030643299833172932, 0.026555181211733725, 0.052968170639360324, 0.00869372475790442, 0.04679369863879401, 0.01023355316647212, 0.039790347873349674, 0.0849449539964553, 0.028838532125519123, 0.04229797952575609, 0.056153219848056324, 0.02841604786226526, 0.07020106233539991, 0.02477528658346273, 0.010813797616719967, 0.04423680693435017, 0.05370678198232781, 0.0232882489945041, 0.0422863574931398, 0.014349455013871193, 0.030178630040609278, 0.04401877507916652, 0.025674070093373302, 0.03321238873468246, 0.032746635406510904, 0.052653941602329724, 0.038729221414541826, 0.05611433502053842, 0.04207932797726244, 0.040342676438740455, 0.04974686380592175, 0.03289216314442456, 0.043943573255091906, 0.06520257156807929, 0.05042324606620241, 0.031961706627043895, 0.051784608367597684, 0.03926530436729081, 0.047795419886824675, 0.0237069186187, 0.09808579183300026, 0.021859954249521252, 0.03431497527344618, 0.02026216225203825, 0.05964124713500496, 0.025978115008911118, 0.05688982368155848, 0.016299913731927518, 0.026505941568757407, 0.06175435679324437, 0.020307127124397084, 0.04984061190043576, 0.09501293679932132, 0.0526647472725017, 0.026962364245264325, 0.010085407502629096, 0.05263650484266691, 0.006495259303846979, 0.022553801100002602, 0.05925434328673873, 0.0207515993679408, 0.0757970116683282, 0.10276391971274279, 0.028526746609713882, 0.03880691685480997, 0.018838839896488935, 0.023783456308592577, 0.02337339745281497, 0.03848564112558961, 0.05032354594732169, 0.02335784760362003, 0.03128208489215467, 0.017128757244790904, 0.09438317254534923, 0.00654479905279004, 0.03157620914862491, 0.016875408437044825, 0.0033818421889009187, 0.03048169717658311, 0.05976635467959568, 0.029862434312235564, 0.059850376928807236, 0.02898036767874146, 0.050511431763879955, 0.007876057061366737, 0.04506084318563808, 0.014268984868976986, 0.047289189824368805, 0.02933757634309586, 0.056532101079938, 0.021243262926873285, 0.026037221505248453, 0.045035947841824964, 0.0405629681335995, 0.016996304293570574, 0.028459020068112295, 0.028864171472378075, 0.030846492445562035, 0.0605106248985976, 0.02980310146085685, 0.09785417496459559, 0.06508518607006408, 0.0333640280587133, 0.03107286975136958, 0.02120577890309505, 0.047645535742049105, 0.042449945394764654, 0.03365171418408863, 0.053725020261481404, 0.029103773849783465, 0.025204643134202342, 0.03350665028847288, 0.10137165067135356, 0.03446823247941211, 0.011010768248524982, 0.140253932622727, 0.042098649792023934, 0.04144799037021585, 0.031996030957088806, 0.04307187999074813, 0.03420046930841636, 0.030140884409775026, 0.01488585152401356, 0.02416948071186198, 0.012041449026582995, 0.04336127676651813, 0.06415141586330719, 0.037056286964798346, 0.07313549940590747, 0.016776589618530124, 0.04070764611242339, 0.03804879444942344, 0.07102415605913848, 0.040801108480081894, 0.06498338567325845, 0.03417866500967648, 0.03916718502296135, 0.00783778821642045, 0.05545280684600584, 0.04216673813061789, 0.06589089869521558, 0.03518604513374157, 0.008254047716036439, 0.012763498416461516, 0.06062422173272353, 0.049359288314008154, 0.05763955610746052, 0.03507197703584097, 0.10092344542499632, 0.04224092321237549, 0.03159908585075755, 0.008621859815320931, 0.03977115593443159, 0.07068031161907129, 0.058628197002690285, 0.040788922415231355, 0.0495349175616866, 0.10230677900835872, 0.06800705115892924, 0.01780080536263995, 0.04972110014932696, 0.055996337250689976, 0.049991074920399114, 0.044127158325864, 0.08071276039117947, 0.0411956972675398, 0.019712657558557112, 0.015693990972067695, 0.03840425350063015, 0.014771803835174069, 0.1060895279806573, 0.054725179288652726, 0.012602442166098626, 0.09847871449892409, 0.024498517450410873, 0.09838592377491295, 0.06277433116338216, 0.04490779007028323, 0.08845477073919028, 0.023781443233019672, 0.02467034133587731, 0.017043449224729557, 0.028155900981801096, 0.038730093438061886, 0.022943374824535567, 0.07404206247883849, 0.027928022682317533, 0.02801535119942855, 0.025547003278916236, 0.06365048844600096, 0.040091804548865184, 0.010948722847388126, 0.09745501825818792, 0.03520871032378636, 0.04533533763606101, 0.022045795449230354, 0.048721824277890846, 0.025920962216332555, 0.06859788234578446, 0.04522998977336101, 0.055293515979428776, 0.0420734056388028, 0.04265161289367825, 0.039380481975967996, 0.07133118997444399, 0.027042852016165853, 0.06913495977642015, 0.041234125674236566, 0.03653237523394637, 0.025664889726613183, 0.0625397902331315, 0.05360655122785829, 0.04022107183118351, 0.07753988611511886, 0.02188285878219176, 0.02465962286805734, 0.021654277297784574, 0.041279719516751356, 0.047641910350648686, 0.025800997755140997, 0.08271612867247313, 0.10430759430164471, 0.04680135018134024, 0.011266417714068666, 0.0823989199125208, 0.10466907217050903, 0.017221724228875246, 0.03053179956623353, 0.002230840023003111, 0.03135406208457425, 0.04087294095370453, 0.03510759641358163, 0.0349525914498372, 0.012489648706832668, 0.028986766847083345, 0.035278268114780076, 0.046884808398317546, 0.006513814851132338, 0.010688012862374308, 0.016690567281330004, 0.027395340621296782, 0.014571399842679966, 0.0695408032333944, 0.09092401480302215, 0.042098683188669384, 0.062108539350447245, 0.019993033529317472, 0.04282845926354639, 0.05379386187996715, 0.07764372741803527, 0.04812092585780192, 0.09391130020958371, 0.04849078999541234, 0.029690003721043468, 0.014809831482125446, 0.03542823018506169, 0.039354087493848056, 0.052990895201219246, 0.005657502597387065, 0.045046783197904006, 0.007037901450530626, 0.014577276724594412, 0.08212288550566882, 0.053715646936325356, 0.02983482085255673, 0.033961308508878574, 0.024132180369633716, 0.04580817105306778, 0.013048168639215874, 0.039995844854274765, 0.038866069735377096, 0.03387663316971157, 0.013599311623693211, 0.01253023583558388, 0.06010350494761951, 0.02702665835386142, 0.026046231178042945, 0.02629532005812507, 0.06433978778659366, 0.018205277701781597, 0.04404050145240035, 0.02991836441651685, 0.038999797325232066, 0.0506199782830663, 0.034321328057558276, 0.08538972309906967, 0.022287759711616673, 0.04745659236505162, 0.04233777719491627, 0.07243860047310591, 0.032859408456715755, 0.06474363486631773, 0.02002126111619873, 0.012934341739310184, 0.02441496089886641, 0.03346293407958001, 0.0744086092163343, 0.016726123576518148, 0.03298781484772917, 0.07871060923207551, 0.026028332431451418, 0.01748065769788809, 0.033184287312906235, 0.0999262290133629, 0.016312463449139614, 0.06919706269400194, 0.03399885004910175, 0.08422711907769553, 0.13662612182088196, 0.12701799598289654, 0.1460945012513548, 0.19557375402655452, 0.1415536113199778, 0.16878606722457334, 0.18357315188040957, 0.19101477053482085, 0.1596324029378593, 0.15711422165622935, 0.1252367821871303, 0.0936973761417903, 0.12661906192079186, 0.1844829655601643, 0.14471597678493708, 0.14272475003963336, 0.19199145172024146, 0.12607882294105366, 0.07373369269771501, 0.10159904471947812, 0.130937144276686, 0.10352561555919237, 0.15387272840598598, 0.17001029918901622, 0.1655983945238404, 0.10738647557445802, 0.13807372539304197, 0.10647786417393945, 0.08438018703600392, 0.12003774085314944, 0.1094125016243197, 0.18357926717726514, 0.1921440669684671, 0.11787179770180956, 0.13211052428232506, 0.099440545309335, 0.12287507532164454, 0.07225462948554195, 0.2943357388721779, 0.16524535487405956, 0.1071034352935385, 0.22430465061916038, 0.08494817491737194, 0.2088986593298614, 0.19212480081478134, 0.18737403152044863, 0.2005443029338494, 0.1034291586256586, 0.1273834888706915, 0.11995417502475902, 0.09082539821974933, 0.18619554553879425, 0.11487661584396847, 0.13145756791345775, 0.13817768543958664, 0.16925550531595945, 0.14254139503464103, 0.1522092637605965, 0.08239965463872068, 0.18109880184056237, 0.1766933241742663, 0.15625344909494743, 0.14500857592793182, 0.10592250022455119, 0.15518962492933497, 0.07547771747340448, 0.1797310682013631, 0.11211888413527049, 0.13967143575428054, 0.14022917457623407, 0.20894324756227434, 0.1871696737362072, 0.251201611245051, 0.0735097422148101, 0.21698324504541233, 0.20421313965925947, 0.15267404116457328, 0.13494834856828675, 0.1438682511798106, 0.11278532532742247, 0.15470669459318742, 0.14492768183117732, 0.11118430498754606, 0.12559495749883354, 0.26867797190789133, 0.13283530570333824, 0.07702142174821347, 0.08143900384311564, 0.262822070508264, 0.2267296626814641, 0.1332765570259653, 0.08698312900378369, 0.13936486939201131, 0.14740467391675338, 0.08006971911527216, 0.0982242172176484, 0.18945373711176217, 0.1593594707082957, 0.07743264577584341, 0.11212817582418211, 0.12059507891535759, 0.11892273076227866, 0.14605102624045685, 0.1161136275914032, 0.15049145906232297, 0.12403769418597221, 0.21629337425110862, 0.12387636612402275, 0.13326003681868315, 0.10930486052529886, 0.1333580448408611, 0.2060015671304427, 0.150418906705454, 0.11044584578485228, 0.12616421445272863, 0.09128994555794634, 0.09502954606432468, 0.1250542583875358, 0.14406414848053828, 0.186990222427994, 0.2110341447405517, 0.09021024685353041, 0.13683062803465873, 0.15398722694953904, 0.14990879892138764, 0.20497412304393947, 0.10047541829408146, 0.13255017256597057, 0.08756116556469351, 0.1258482673438266, 0.1618148514535278, 0.12439748737961054, 0.13032237882725894, 0.106790775898844, 0.10282565897796303, 0.14288450474850833, 0.07673979154787958, 0.14343550486955792, 0.13744735275395215, 0.09098121212446131, 0.13683095457963645, 0.1016468316083774, 0.24018300406169146, 0.17616409866604954, 0.15369499888038263, 0.1360271344310604, 0.1042064989451319, 0.1778837142046541, 0.12697909260168672, 0.1378386130090803, 0.2199676731834188, 0.14265957463067025, 0.1376098979380913, 0.11812996119260788, 0.0914783397456631, 0.17162711243145168, 0.14198037591995671, 0.15611925395205617, 0.07065680038067512, 0.21691582835046574, 0.24318387819221243, 0.19348114990862086, 0.14376942679518834, 0.12976164172869176, 0.16628774581477046, 0.07214847268187441, 0.0981720516574569, 0.1562242381623946, 0.10944935667794198, 0.09139653280726634, 0.2770752244396135, 0.2772078017005697, 0.1779516800888814, 0.269984804908745, 0.1061899182968773], [0.025664247768872883, 0.014265581194194965, 0.03720014858117793, 0.04593337878759485, 0.00920382326512481, 0.05007096711779013, 0.08655119163449854, 0.03339338371006306, 0.013693070850422373, 0.040464032426825725, 0.024279444733110722, 0.07108825535397045, 0.011381786425772589, 0.036634977150242776, 0.055025841866154224, 0.0207326096642646, 0.044085412519052625, 0.08045683076488785, 0.036995646078139544, 0.014000544488226296, 0.03683963179355487, 0.05665635515470058, 0.018245084647787735, 0.03225020911486354, 0.0326272572419839, 0.02760834071523277, 0.021696982330468018, 0.03136309031106066, 0.03128966593067162, 0.04745722690131515, 0.03325768942886498, 0.01475809265684802, 0.003991824960394297, 0.0578796260379022, 0.01346274902971345, 0.043453432954265736, 0.04927030109683983, 0.0489858024957357, 0.07863688428187743, 0.024334463851118926, 0.01867315913841594, 0.004160387106821872, 0.05069693528639618, 0.08784949735854752, 0.01722606579278363, 0.03135257036774419, 0.042293541482649744, 0.06066135880246293, 0.09709720659884624, 0.020870997941528913, 0.05282751139020547, 0.02111759691615589, 0.06888677075039595, 0.020863795398327056, 0.016447970338049345, 0.02898833277868107, 0.020680618508777115, 0.031790292778168805, 0.03753979988687206, 0.02430756841931725, 0.04809956684766803, 0.029313974191609304, 0.04961613449268043, 0.09462139452807605, 0.051705654987017624, 0.025152681664621923, 0.03374017447640654, 0.04411144334881101, 0.051503004142432474, 0.02467287577019306, 0.048489279724890366, 0.003216021350453957, 0.008143529867083998, 0.041557843069313094, 0.1205588472657837, 0.026548821006144863, 0.044984112537349574, 0.036538019267027266, 0.02734806952503277, 0.036661497797467746, 0.005091272678328096, 0.09299482946516946, 0.06668412097496912, 0.01160691414042958, 0.02193030984926736, 0.06428654611227103, 0.002926944162027212, 0.04229343016049825, 0.012418245751177892, 0.040470103194820695, 0.08748769294470549, 0.026518951417529024, 0.04098477518709842, 0.04445112434041221, 0.007449773002008442, 0.0524749652686296, 0.0548662318760762, 0.05134597682626918, 0.0634233393066097, 0.0967344745004084, 0.04497053123486694, 0.02606754751468543, 0.08984208965557627, 0.043151067147846334, 0.0732831793720834, 0.03880764415953308, 0.05691896039934363, 0.019821001842501573, 0.046393265438382514, 0.03559909855539445, 0.026121718728973065, 0.03910520827048458, 0.020403608177730348, 0.009395723172929138, 0.018516439813538454, 0.03497990619507618, 0.012752868078678148, 0.03717551298905164, 0.03744754350918811, 0.04112889655516483, 0.01330231711108354, 0.0053266448139766, 0.016720334824640304, 0.0564932385168504, 0.06745561317075044, 0.028769636701326817, 0.017841586377471685, 0.007590335308123031, 0.015856352474656887, 0.055971939145820215, 0.004710021212304127, 0.09985980679630302, 0.028313416260061786, 0.024785071800579317, 0.07605440332554281, 0.051454337808536366, 0.017523722672194708, 0.016423844972450752, 0.023009505748632364, 0.01340496912234812, 0.12881979695521295, 0.03542798898706678, 0.029420869432215113, 0.026489297051739413, 0.031096970997168683, 0.01508203547928133, 0.008045512568060076, 0.07982498107594438, 0.061843095390941016, 0.023192810658656526, 0.012692720720224315, 0.03428277719649486, 0.03647367877420038, 0.005028979585404159, 0.019668434833874926, 0.013025473763264017, 0.039342484014923684, 0.024438125183223747, 0.01350009019006393, 0.0385950411146041, 0.037332874271669425, 0.008141191174217965, 0.013404697310761549, 0.03921740244550165, 0.028737032298522536, 0.028538504084281158, 0.04750424195663072, 0.0356213073246181, 0.010195739814662375, 0.031111964235606138, 0.09656258567702025, 0.04285739560145885, 0.0705731677589938, 0.051638935910887085, 0.02923097796156071, 0.019344392749189865, 0.02514593183150282, 0.024289352404593956, 0.014981719377828995, 0.0620123866974609, 0.08776838061749004, 0.03429871481785085, 0.059509649508981965, 0.05148972340975888, 0.027151871654496063, 0.011656584229058353, 0.07957068417454138, 0.048101548381964676, 0.004849149781875894, 0.016251837405434344, 0.04592910401697736, 0.019311458090669475, 0.04074725082318764, 0.07382176336250268, 0.02963002334581688, 0.06330353440716863, 0.011147772420372348, 0.05544812018342782, 0.07672464431379922, 0.007706684118602425, 0.08556301458156668, 0.046820382558507845, 0.051723648357437924, 0.04604346897394862, 0.041735925115062855, 0.08220851450460032, 0.03937895686249249, 0.013289564230944961, 0.05193224009417463, 0.035915758126066066, 0.06923514229129069, 0.03857167830574326, 0.03456565420492552, 0.08506525613483973, 0.07349339270149358, 0.057327178728883155, 0.07517314748838544, 0.019145172482240014, 0.06412188580725342, 0.032985618090606295, 0.050850997722591273, 0.0675064354436472, 0.01691568108071806, 0.08259742957307026, 0.015477043580176542, 0.015257420745911077, 0.04050010822538752, 0.032258881110465154, 0.025834598491201177, 0.00917689536436228, 0.019125516701024026, 0.0676220768946223, 0.02086582888296107, 0.0230785273379297, 0.06813873784267344, 0.028940070915268734, 0.009458954154979438, 0.011562099552975269, 0.02252335449156817, 0.08821362469461747, 0.051044412539340556, 0.0795143329014536, 0.02344692202314036, 0.026639322204573546, 0.051295766825205646, 0.05304866768710781, 0.07660827555810101, 0.05553891453018878, 0.020453979595913552, 0.055610394483665004, 0.05235010634351056, 0.03791720053413883, 0.023934197633934673, 0.015439248782058712, 0.053876236561336555, 0.035760478567681275, 0.031894813146209344, 0.08119647740386426, 0.01809044148103567, 0.05189136260014493, 0.064115161949303, 0.04008929608971812, 0.014413203643925954, 0.08267028621048667, 0.06265311618335545, 0.04138011354370974, 0.09408504440216348, 0.014875209126330446, 0.004718784120996133, 0.060258751109358855, 0.029626416508108377, 0.018671364996407647, 0.025152303169306833, 0.047614885043003596, 0.042725560488179326, 0.05247501721896697, 0.1209690619725734, 0.014770790803595446, 0.02845587150659412, 0.04510731276241131, 0.05134778024512343, 0.06316972518106923, 0.0401154159771977, 0.058925968914991245, 0.04803704461664893, 0.020561989913403522, 0.09267013985663652, 0.0812262820545584, 0.025494119690847583, 0.005856162542841048, 0.03238752869947348, 0.029296069878910203, 0.019804537296295166, 0.03930389975721482, 0.02693811085919151, 0.03736046732228715, 0.06562572933034971, 0.07948363025207072, 0.01419571633960004, 0.009325319333584048, 0.07619980489835143, 0.041130477329716086, 0.013497964864654932, 0.09781799526535906, 0.018380968176643364, 0.048626057541696355, 0.021252595433907118, 0.02765980680123903, 0.06336942969937809, 0.028546966423164122, 0.06161138204333838, 0.08367329137399793, 0.033219884426216595, 0.0350580283702584, 0.03123291018710006, 0.1061064786335919, 0.022086435456003528, 0.02743059078056831, 0.038011753858882, 0.043045173806604, 0.0213363245347864, 0.023182765689853113, 0.04466171616513748, 0.062307906191563234, 0.08549423233489506, 0.04748464925796725, 0.0324834883940639, 0.02745117981248768, 0.03162425207847264, 0.03132212375930976, 0.01661338763369713, 0.04309933203330729, 0.03969213576056063, 0.013231759276095545, 0.025275482985307463, 0.021693924682040233, 0.02531662023102399, 0.062065105157671496, 0.0451666511798976, 0.03470375304459594, 0.05422548383648973, 0.06060958286980167, 0.02253982274851296, 0.03050382059882395, 0.020335217413958162, 0.018847871833713725, 0.022326766993501224, 0.05066326033556834, 0.10469529966940172, 0.04625799418136012, 0.03906377787643578, 0.03231173315725755, 0.1281421270687133, 0.10194822520134039, 0.13612616661703214, 0.15749596757814288, 0.12759344244841486, 0.10514253270230256, 0.1810611304244958, 0.09442451759241521, 0.11538352497154847, 0.07884107137215324, 0.15906506072496995, 0.13652133056893945, 0.13694009481696412, 0.12218108560773544, 0.10764863924123347, 0.11984488635789603, 0.1144464299432002, 0.14268093364080414, 0.0886401221214328, 0.1942597221932374, 0.1387955975951627, 0.11200155058759265, 0.18191100825788453, 0.13635923067340627, 0.19736942485906184, 0.18010867293924093, 0.19517878303304315, 0.1123625534819439, 0.11161058719153516, 0.14810330205364153, 0.16217929049162194, 0.09095266170334071, 0.08134573072311468, 0.18681798479519784, 0.19864743284415454, 0.10598992434097454, 0.11322757854941301, 0.2668776403879747, 0.29783451987896115, 0.23604038025951013, 0.0929102765803691, 0.05799320431833621, 0.16911149898078293, 0.12801662989659235, 0.147773610369768, 0.09196754865115508, 0.17656800511758775, 0.18034124717814848, 0.2086264395620674, 0.09296423071646132, 0.11692834988934919, 0.17073010822059587, 0.20652970910305157, 0.1534534594975412, 0.08805401841527782, 0.1526899528107606, 0.12781332596205175, 0.13504101312719285, 0.1473937346599996, 0.11361589989974163, 0.06531246879603714, 0.11374393521691673, 0.16704023903002962, 0.17696319875540212, 0.16084900562418625, 0.2224468026543036, 0.12827267084503546, 0.0955751581932418, 0.12503668433055282, 0.11718527399352752, 0.16150807728990912, 0.1515456649940461, 0.1410707551985979, 0.12245524980244227, 0.20445077534532174, 0.09284031431889161, 0.13898307894123718, 0.1273845278774388, 0.1227169756020885, 0.19284756359411404, 0.06889877127832733, 0.23615707556018606, 0.12365068643703125, 0.1631686624023132, 0.20577490038704127, 0.07303305334062316, 0.1295877862139605, 0.1496988453436643, 0.15681673918152228, 0.18749311653664336, 0.23053714743582532, 0.12117998776375316, 0.15282388078048825, 0.17404025013092905, 0.09668786762631498, 0.08139964775182307, 0.1294464070815593, 0.19146123173413798, 0.17324466782156378, 0.18068285775370896, 0.27836668014060706, 0.07758995139738545, 0.20085290278075263, 0.161361770296935, 0.20604389923391864, 0.20373546372866258, 0.2600956871174276, 0.3160639526322484, 0.11408749764086679, 0.1896640469203703, 0.159551375254523, 0.14530157583067194, 0.08866522897733375, 0.11079389820224606, 0.09745553776156157, 0.13858055288437754, 0.12758401717292145, 0.19599832186941057, 0.1286556338891387, 0.16631576931104064, 0.15037394739920273, 0.2272393845487386, 0.10943271772703156, 0.18136858736397699, 0.24421323701972142, 0.0810822015046142, 0.1406727117137052, 0.16450918890768662, 0.12369954944006167, 0.18595235858811066, 0.16693712503183633, 0.11927512474358082, 0.11958449642406777, 0.12208208310767077, 0.197655686060898, 0.31457161239814013, 0.09013573522679508, 0.12425008942955174, 0.08712171023944393, 0.30964134726673365, 0.16068977041868493, 0.12909066601423547, 0.16956391220446676, 0.10284161515301093, 0.08657727812533267, 0.08835149346850812, 0.1427762847742997, 0.11847323417896405, 0.14578219066606835, 0.12083743466064334, 0.11305853215162642, 0.10189172549871728, 0.07592398571432568, 0.13389702216954902, 0.06120330101111904, 0.12176932723377831, 0.16791840753285214, 0.13467311568092555, 0.1116327996714972, 0.1540307910181582, 0.2466662132064812, 0.1639402733417228, 0.1921177949407138, 0.06975155090913177, 0.17925760766956955, 0.1515039859805256, 0.12465253385016695, 0.0995197324664332, 0.12776939081959426, 0.07758354666293599, 0.18139573512598872, 0.24070675252005458, 0.24240658240159974, 0.1269615482306108, 0.12733158306218684, 0.09131057726335712], [0.015795503786648624, 0.08682606829097494, 0.056487267938791774, 0.007082926622388186, 0.05040570911660325, 0.02366014105064096, 0.03504929700284265, 0.013097553000989137, 0.07155097700888291, 0.00649442902613373, 0.07795502126100473, 0.027349672564014327, 0.05670894373906776, 0.038816664964542724, 0.06892678735312074, 0.03978681153967045, 0.03118435517535545, 0.045025071667623706, 0.029004016214457806, 0.03778823011089116, 0.0562929439911386, 0.04042668755573686, 0.016898724861675873, 0.05783467786386609, 0.043856426564161666, 0.02960397396236658, 0.004919267430523178, 0.037711310214945115, 0.01233717261129641, 0.03751994743652176, 0.02094384159136098, 0.0355041630245978, 0.04218955917167477, 0.04260555149812717, 0.019715281050594058, 0.04583859539707191, 0.024275938085338566, 0.03234145246096887, 0.07706723452429287, 0.03060316819755826, 0.041264019382651895, 0.02862067467503948, 0.010418645724712405, 0.011737626755348174, 0.03185088913596701, 0.049434890897828154, 0.05192390577576589, 0.03213058975234162, 0.04928763024508953, 0.0363333572022384, 0.038151541084516793, 0.031496880983468145, 0.043266871871310286, 0.00947923983403598, 0.0513614209194202, 0.08264380638138391, 0.04199913521006238, 0.06510041494038887, 0.04448083622264676, 0.04521333597949706, 0.050581779942149296, 0.07969000667799264, 0.0790765845158603, 0.04204688128083944, 0.05027413375501055, 0.014038001609151252, 0.02248310782306362, 0.016461167579109315, 0.00020139171567734593, 0.09196777129545808, 0.04696989191870671, 0.07218758386443369, 0.029545507568400353, 0.01703484773315722, 0.036624260537792, 0.019487059507810045, 0.10186024359427392, 0.03254410330555402, 0.04761639531352557, 0.032884081156225875, 0.048744890227681026, 0.045235362922539935, 0.02341117462492548, 0.05857700736669358, 0.033910849888343364, 0.027531563682714477, 0.05965727752482053, 0.04202336262096651, 0.041962376635638066, 0.07115130079910159, 0.05910949832468759, 0.04694566821854096, 0.022731289427611046, 0.01047438843670534, 0.0503033817949472, 0.004382686774988542, 0.01526885353086982, 0.05727315408876166, 0.028164227878733072, 0.03661610062408727, 0.03381059686944354, 0.05554039511480369, 0.05038240567955654, 0.08661907588248141, 0.02566244435001863, 0.047701616131234914, 0.02875104775739601, 0.030189337376214098, 0.08413600560743362, 0.04515034248470329, 0.05035579226387199, 0.030005902590346523, 0.009890144738164963, 0.05687126627890393, 0.06425319399568252, 0.033667633251752704, 0.04556059058813844, 0.015758773042762186, 0.03889294290274847, 0.08313286685734056, 0.042091536306543276, 0.0511612154514296, 0.05257348908344284, 0.02598895036499016, 0.020430446093087085, 0.05236870456428733, 0.006147458288978669, 0.06568798067746684, 0.01965254545211792, 0.023944893837324344, 0.05693872008123435, 0.05408434590208344, 0.05396158725488931, 0.05738731495512184, 0.02652649720403133, 0.027306921147101093, 0.07732230325927958, 0.07557536926469766, 0.08192715147743002, 0.0261185015187948, 0.09499446474364959, 0.04469081206480041, 0.07004832092206925, 0.04501317875110544, 0.024279587596538477, 0.026200015308859292, 0.0066026768308802275, 0.0099581699942064, 0.04235255706589669, 0.0038987146490399027, 0.0314588236506097, 0.04027653252705932, 0.04387273525935598, 0.042445540748303756, 0.007833636827854207, 0.06304758993792348, 0.045511861171689816, 0.03327038015413564, 0.028455760184442624, 0.051588028291007504, 0.06330389063805342, 0.021046502879471518, 0.03328476297610905, 0.013881434424547479, 0.08166322892066091, 0.05614194291410968, 0.010636373299348634, 0.043406759286881424, 0.05279552853608038, 0.08370798677788116, 0.06390765003743581, 0.06193619039549958, 0.04730622211354785, 0.06082304309529718, 0.011756558014894836, 0.05837162912939675, 0.09253929922124371, 0.03962787319323979, 0.07405542113701813, 0.04286311013856903, 0.06270876241615042, 0.014271544350776821, 0.01740079518640414, 0.03643298310635146, 0.059639863029588014, 0.04435075999936089, 0.025600836816010997, 0.04647858273528982, 0.01754803171934327, 0.05373930289351847, 0.10502370001631789, 0.021359216079872567, 0.027099121653009206, 0.02291082237206865, 0.021551604877458885, 0.03552355905412696, 0.031864941702224314, 0.1036314680823125, 0.07817246310878545, 0.04514300264418125, 0.04692281749157701, 0.03368056146427989, 0.04634596836694982, 0.07737987165455706, 0.01863827077613678, 0.04019131913082674, 0.04933205149427522, 0.013458366647682851, 0.027027216819988098, 0.026399968446639832, 0.03040190516912844, 0.06228276222827844, 0.09368222148623317, 0.021647356770699844, 0.019603997861850075, 0.03352617619384546, 0.024797615951683838, 0.026803732034750283, 0.01806583928555483, 0.011721100054273847, 0.036697209943667985, 0.07339153293287382, 0.03867554558382835, 0.021073602401884273, 0.07628795719938353, 0.01217540575453313, 0.051684919380932115, 0.04726542625576258, 0.06367981070070527, 0.06568111581145786, 0.04699471675849054, 0.022750065763830207, 0.03200696279236581, 0.07504190609324723, 0.061646938338526525, 0.019289249321445823, 0.05011709901737049, 0.06221846255357377, 0.030656634371553082, 0.06357788413879462, 0.048406296482426114, 0.02264854367240332, 0.06343451605062, 0.022834616793261375, 0.017085645886254497, 0.045853724077460356, 0.03148824238451198, 0.03520635400491301, 0.048861886098165996, 0.04219553346047178, 0.046173393056960776, 0.02896189376770053, 0.11697431109496392, 0.06458477073465474, 0.04944313986925408, 0.051683795027201995, 0.03401974892767612, 0.01285562399061746, 0.02421104840323096, 0.05727358082367573, 0.05339742885553278, 0.02169342744309688, 0.02708055682887789, 0.024001276651688386, 0.026946793987008277, 0.006468489109465736, 0.06560736859682947, 0.03387656637642067, 0.04222221366944723, 0.010552665535215056, 0.033086639232351445, 0.031989696726668626, 0.08263228824944235, 0.0358914490789175, 0.01680514746112749, 0.02488290541805327, 0.015733282125438564, 0.06460477903601713, 0.031125558525673114, 0.030533437857229728, 0.03783698921324685, 0.05076572866528295, 0.03633558364526834, 0.03930481630959548, 0.04489536280743778, 0.05621804273687303, 0.022740863132639788, 0.015508939231949626, 0.024870556080713868, 0.04875699094554875, 0.057556005122023635, 0.01593839690031018, 0.016508286535099614, 0.03880724711052608, 0.06430289562558755, 0.007890056749602081, 0.04265710107574705, 0.05148789772647433, 0.008224832145060645, 0.03948242709157057, 0.04501919014728628, 0.04399182398628909, 0.02599333460238995, 0.051303637301316485, 0.04212315550830681, 0.06307519783149473, 0.039021404954837635, 0.025927890164894052, 0.04194020868453663, 0.07119150293874554, 0.04351948038674891, 0.00833345009596087, 0.05162159934116062, 0.0465876969974488, 0.08818039132165723, 0.022746800314052962, 0.06448968677432276, 0.023896785969554912, 0.03186633322911803, 0.0484850012435345, 0.021540185080084484, 0.03904401819454506, 0.027660994237521663, 0.04366999535704963, 0.017991286840697285, 0.03748789407836739, 0.05936758760071825, 0.02193679250922287, 0.019572426899685524, 0.04464018275029957, 0.01845704759034561, 0.024811783550831024, 0.021855516206414904, 0.09122904491960071, 0.03104757735854946, 0.028349176645861007, 0.04846674441068899, 0.027329641998221632, 0.019328983908053488, 0.04698537682997994, 0.11586943131987937, 0.022297928990155924, 0.03640573886514176, 0.048009718739194795, 0.0431374190520728, 0.007234848890220746, 0.03711843070050236, 0.012369844735076185, 0.03317582311865408, 0.042624995767255314, 0.02731742810283322, 0.04454362562682945, 0.19647878827527165, 0.16737898491555825, 0.1709386962465942, 0.18766698689432815, 0.22814930212916806, 0.17792042082874104, 0.17511243087938055, 0.14276657748268917, 0.1547591495909728, 0.19035148347029462, 0.13998110429383814, 0.10878412518650293, 0.13857758429367095, 0.10675809171516448, 0.20687087439000607, 0.16671626188326627, 0.11513330988236703, 0.12236363167176023, 0.09412508326931857, 0.27317063708323985, 0.1864375895820558, 0.1630443229805678, 0.149670094542671, 0.14920988876838237, 0.1307540267589502, 0.16525480983546004, 0.10049596836324781, 0.13880278158467263, 0.09013923074235208, 0.16013247688533738, 0.09403238160302863, 0.10849444268387742, 0.15002484113210812, 0.13284769956953824, 0.10297269327566028, 0.11824605535366572, 0.18573973327875137, 0.14919189910870045, 0.17833796795457602, 0.14258173818234354, 0.14375942264450714, 0.05932105123065412, 0.12587948207510635, 0.05506870831595734, 0.07355056775850244, 0.09573829709552228, 0.15377423056634143, 0.11510158306919038, 0.09668639817391522, 0.08288377241115086, 0.13878093275707215, 0.11541488071088679, 0.17411443521268666, 0.1794425953994505, 0.15727210615295917, 0.2169435253017582, 0.1054161848151125, 0.0910731048497837, 0.17556551203597337, 0.07252397714182734, 0.12578953377669677, 0.12476900650653988, 0.14179853489622474, 0.2365457234554924, 0.1487017105682753, 0.07738988322671503, 0.17526903888210654, 0.13598281337181106, 0.10323046342818998, 0.1450367775396444, 0.19409018597798422, 0.12484457198297605, 0.16729455819586292, 0.18051606748485938, 0.13144410535460338, 0.10147812659852207, 0.24838723882567137, 0.17543091613333672, 0.13801472465274855, 0.1618768207845278, 0.20439330342924222, 0.1302386645693332, 0.09088025777600706, 0.16354041901649907, 0.18451015785103664, 0.1461152665433474, 0.14865093282423913, 0.08243417934863828, 0.17921831837156788, 0.12629459495656192, 0.21281053457641974, 0.08405269210925326, 0.16734040807932615, 0.12268533042515628, 0.12417427904438227, 0.12363983623799868, 0.19144107500324026, 0.1185569484368898, 0.10090855794260278, 0.10295215804944746, 0.0680494871630799, 0.2164187526796013, 0.12213042660732754, 0.12410541516146623, 0.08297309730551206, 0.18272198271006346, 0.12753588147461414, 0.13217414118116722, 0.13139577669790015, 0.15542320848908275, 0.16249590553343296, 0.1495987593079917, 0.10964642657199875, 0.13851260184310377, 0.19206716562621295, 0.09890999135677703, 0.14311084494693205, 0.14149783150060102, 0.1274688061675988, 0.2023752554669045, 0.15187039913143963, 0.13720410643145442, 0.1987428285065107, 0.07378211041213945, 0.1583924819715321, 0.15439910406712443, 0.10345597984269261, 0.14139050210360438, 0.1576785952784121, 0.1413814479019493, 0.12127485650125891, 0.13236742612207308, 0.1432677943375893, 0.07945841949549504, 0.1083540654508397, 0.08560447095078416, 0.15854202472837642, 0.12341680601821281, 0.22013655630871654, 0.11640753291430883, 0.15339628444053233, 0.1173161443148274, 0.1355002837954089, 0.14352077763760462, 0.11944584097363986, 0.07248680296470411, 0.10068707138998434, 0.08865064577548765, 0.14633743587182835, 0.25595764978788793, 0.1662637892877683, 0.13242592220194638, 0.1581276985234581, 0.18940802081488073, 0.1782252505654469, 0.14605883363401517, 0.05471576143463608, 0.1539634633809328, 0.08392464194912463, 0.1265623766812496, 0.12723311490844935, 0.1732833930873312, 0.08991134687676094, 0.07507073853048496, 0.19784205418545753, 0.1528010523179546, 0.08971423987532035, 0.09513960656477138, 0.13416852947557345, 0.14515868271701038, 0.11768600845243782, 0.11474829851067625, 0.13978565228171647, 0.11098403643700294, 0.14600058988435194, 0.1451470161555335], [0.06312797937425785, 0.062220336476457305, 0.01835193164879456, 0.04802248367923312, 0.015317481829697499, 0.029289839549164753, 0.043620249198284, 0.04404043094837107, 0.046879220026312396, 0.055494823536719196, 0.010280140559189022, 0.007427832797475276, 0.01443896173441317, 0.064489679352846, 0.06455887720221654, 0.04006944363936782, 0.04509834761847742, 0.045618723015650176, 0.021949592701275833, 0.03333742206450552, 0.10074308869661763, 0.0132414628569677, 0.01762219824740896, 0.052150650444673374, 0.06638165868935175, 0.09055616188561544, 0.032332119953935035, 0.04742123273899779, 0.05912824868573807, 0.06115553267591167, 0.04037251819681842, 0.034566496542538516, 0.04772609958308749, 0.028366101323626935, 0.07035925111267716, 0.030778994114371017, 0.10006978263845667, 0.05755112550104968, 0.07503074419219047, 0.015668793203076348, 0.022822258179076016, 0.05928450045757927, 0.035879166534869, 0.03791784249187913, 0.04530145859462209, 0.0286072807648452, 0.059893054130952805, 0.01618292157218093, 0.02044642824330367, 0.05307652420015074, 0.058499586521065794, 0.037282783014234155, 0.028940855736436788, 0.017782348149921745, 0.042595792256179266, 0.0486430453020148, 0.031290040715248324, 0.0335821823682636, 0.02462175292748725, 0.016051555867306888, 0.027494319001561962, 0.03500981103570666, 0.005005578277632594, 0.045003207997069694, 0.056579591109766625, 0.037572602814179845, 0.06567531221662648, 0.061363935164990835, 0.05201302657951601, 0.032130927429534495, 0.029313955637917388, 0.01439670941181248, 0.03657909343019128, 0.01945511561643798, 0.01086563663193374, 0.073265649843961, 0.02959192519483622, 0.0346043015451869, 0.04629736140486784, 0.0425169501977507, 0.02363886738748988, 0.02361149698117515, 0.028377415364957415, 0.0742152203747537, 0.011754473507608054, 0.1003115001367405, 0.01128086454627919, 0.0019195684444639483, 0.03398453402041923, 0.03021170385181904, 0.037090826517669484, 0.007785559573676437, 0.020797451106773224, 0.05417948552349117, 0.06011182442307472, 0.012722444662358612, 0.0023518349098594626, 0.04445866456080694, 0.019072063514613546, 0.03595961905375589, 0.04507619079959113, 0.041762171167647466, 0.04209087579511106, 0.06784861005144194, 0.052421144719119184, 0.06783482836908661, 0.030920966964913532, 0.0781295595515985, 0.015918318094918504, 0.04807599994819611, 0.06838642220827751, 0.03661951079266146, 0.04798263034899719, 0.0218748602856067, 0.021674202107533347, 0.04980401288776193, 0.020239259574736934, 0.018781620310619473, 0.027052162258769386, 0.07282339662197046, 0.01992010082176421, 0.01124220236306428, 0.06559593952260911, 0.041878395204548724, 0.049682823882903904, 0.046050578748690896, 0.0445356920681661, 0.03055557797779329, 0.04677142307627946, 0.023013179379631765, 0.08334717684192583, 0.05308583815349266, 0.03948482051782776, 0.06378686550306156, 0.021620455772790592, 0.029159312471165322, 0.05892147521080915, 0.10937638129689731, 0.015403018987854011, 0.03024979272595374, 0.06538249785080552, 0.033768654393497854, 0.04748608160298318, 0.054909135433263145, 0.016698003601050004, 0.03964329502196051, 0.045322108853724785, 0.021268716736813076, 0.03333026776090264, 0.02637195237184642, 0.028234136334504, 0.05921224124904256, 0.032430421124445274, 0.011673913377308054, 0.05581787299888674, 0.04009996075183153, 0.01984749465918867, 0.019748876220546663, 0.025860438217932824, 0.02614453791466076, 0.018543095902714413, 0.018291353844688274, 0.056166463473346084, 0.007715167330388795, 0.02878332932596095, 0.059432785274111666, 0.05415381834609434, 0.010093494129250757, 0.06508157923235558, 0.055824693336035125, 0.13157145789591596, 0.041058088245335966, 0.058879031785181724, 0.006662880778094404, 0.033255503803957254, 0.05397169901698362, 0.04797473760845605, 0.027944229332206305, 0.03770397037442308, 0.06007281714119017, 0.047500182408839464, 0.04219200825900771, 0.04732652356324252, 0.02019691077293828, 0.046619820859632455, 0.06606465030927211, 0.06746515718987212, 0.026570248664938845, 0.038331745672621764, 0.05180822350666858, 0.022006814142514486, 0.031770622153999284, 0.06445652019465342, 0.01772178518876899, 0.019933453913836274, 0.06280806919676252, 0.03616380243329331, 0.0924663980549667, 0.020839007665927056, 0.0060282879258011235, 0.053410034233820625, 0.05166205752175301, 0.038101427562651224, 0.035687918789335527, 0.06034204976458568, 0.08796962138148956, 0.09354401874588802, 0.022697067142871674, 0.03761930245673284, 0.051502224887371995, 0.017295521538471803, 0.015948629261401948, 0.03046809732040856, 0.049382677098037675, 0.012126223628001753, 0.022952453145990148, 0.0447524734045146, 0.058841174832195975, 0.07609640146256424, 0.053907588589936495, 0.08001195034012198, 0.04409682303958107, 0.0068595976881624665, 0.046457357311737724, 0.010229911076748976, 0.023418930068146437, 0.06714306509820744, 0.011369962157914415, 0.04036734542751219, 0.037183839885983616, 0.04973589115252253, 0.06158095027785748, 0.020754475190187804, 0.046510031243087724, 0.057480599207337946, 0.0469665745185921, 0.0710346203413792, 0.011350906588631915, 0.020571131317410618, 0.06018671083438676, 0.0188478773998213, 0.0588469672948122, 0.07287174012162723, 0.060445312192314304, 0.0350580061058281, 0.04818870991584845, 0.005827099575981265, 0.020391088146425318, 0.025901007720676716, 0.01910214461531723, 0.03236839242163114, 0.026636834154487588, 0.033767518907552585, 0.034613270399859175, 0.008087498645181768, 0.05032661843870301, 0.022319134004646912, 0.05917101865634322, 0.02761269897746388, 0.027744894032366574, 0.03298397052276414, 0.04128846572712064, 0.004861513962168829, 0.018053293279081117, 0.03659503476228565, 0.039840175668359734, 0.07580465578939766, 0.01976869341888232, 0.05849613924510777, 0.07318698961171322, 0.0313654280762421, 0.028232852419023402, 0.02155407622922212, 0.03959338187996764, 0.025458878808422014, 0.04711425819550641, 0.02439380969008198, 0.0722889241296798, 0.027926846378250048, 0.03671143320389092, 0.006426306363209733, 0.009909292148222448, 0.0053581206884700805, 0.01195076692965813, 0.03649368336482439, 0.025224295204679947, 0.05595626869762782, 0.0326991861948045, 0.0283466774635599, 0.09430547710508108, 0.016592954452789854, 0.03478435399301816, 0.0035352494478502194, 0.055815327432355843, 0.05954136147920508, 0.060504735956783406, 0.03666128257464152, 0.03286183899035677, 0.047503763271379285, 0.025671791700005997, 0.020393182858242653, 0.0800798049021978, 0.03283308818936348, 0.009420940423296997, 0.018235308707517106, 0.02683674461877672, 0.038665853135171346, 0.06706867963657714, 0.10985661763697863, 0.07698772082221694, 0.05019894306315109, 0.018044650969386566, 0.020957495253242087, 0.05698521563317627, 0.018974853301187977, 0.054634589032502845, 0.051977815382997505, 0.05024758342187852, 0.040128355321940035, 0.043047155340900645, 0.029598183355119545, 0.10797955546877347, 0.08857309134327807, 0.034661743775359355, 0.019813016333500855, 0.06639779297984205, 0.027815952817036305, 0.043381581926951185, 0.01851451950642513, 0.007082907604853972, 0.050292498199269176, 0.015617455137544312, 0.0373016966477735, 0.026708599834819324, 0.02772150339296786, 0.02432726316328626, 0.035868809864041395, 0.06889459298690781, 0.05357403031666763, 0.038036649202695116, 0.03602844211854972, 0.025640747662691865, 0.03291331435320899, 0.04686501531978138, 0.05014811707951594, 0.03122536996670533, 0.04089910908078309, 0.011338421809341526, 0.04669867776101455, 0.014761593738512602, 0.014751815015188185, 0.02575818511104444, 0.16262757737422362, 0.11637120478553697, 0.14270098647102714, 0.2588140871375799, 0.1794161749421619, 0.1332726384862326, 0.10655630176188424, 0.11085649093729444, 0.11143343654111959, 0.21548897522734478, 0.11883491242770106, 0.11155423591844738, 0.2000755030894652, 0.1731884723994881, 0.12244481520610861, 0.1668717121356167, 0.1813868441968225, 0.13385096448473632, 0.0864771920896601, 0.14351577556226403, 0.13071610301267356, 0.19290233409265056, 0.09578593555488624, 0.3192540002055466, 0.1256647490663454, 0.18828961910912767, 0.17717012437060475, 0.15227840223815292, 0.17609927948797122, 0.19531348283635452, 0.15932821144815534, 0.26631040207576007, 0.15210687706712633, 0.1469503904809244, 0.229800358065404, 0.09156273677945137, 0.1762309661717154, 0.20532478782115504, 0.19275270227808505, 0.12523933517513797, 0.11519957624841481, 0.23409598303260282, 0.1872276354697533, 0.18587609549285844, 0.12150859591201879, 0.13845656969351694, 0.10497380542801693, 0.07706261836574413, 0.03591478591260966, 0.09296973003074527, 0.15538249426754192, 0.11113804692286067, 0.23662361927563325, 0.0960675731766969, 0.11810621246695518, 0.1971288354252465, 0.12020691341604106, 0.2161679809796624, 0.12658183579333127, 0.15548225375823677, 0.11046295971027575, 0.12422356507158838, 0.08453729227767326, 0.14383261324837804, 0.12942313333041966, 0.19015091063920408, 0.22496268327813596, 0.10910489625530317, 0.12121391875552945, 0.10781286910059862, 0.07387574718450196, 0.10546857301960699, 0.14216116309398785, 0.0916642922675237, 0.13197282620240003, 0.16143715765792876, 0.10091359712532721, 0.098606215469772, 0.19410271343076602, 0.18559554882813245, 0.1217795540287625, 0.17014010081766173, 0.1590153665165417, 0.2267445798497647, 0.16570260690059513, 0.18063252529827878, 0.11927523606573232, 0.09117045236052945, 0.1013627003703732, 0.13712687854422256, 0.14444697793805972, 0.08206584403524175, 0.16021675517549738, 0.16705481481039897, 0.14458336983807385, 0.07158189488109201, 0.10688931826734915, 0.11868306159158237, 0.106868857255904, 0.1231817901134491, 0.16068807832198218, 0.17104017751989886, 0.2004474081331864, 0.11226759568671696, 0.19394766393816099, 0.17653383663855493, 0.11886773019796237, 0.21067803259938955, 0.12274726264877245, 0.08479086187435314, 0.17914977361215279, 0.12264307253644802, 0.11228707706322894, 0.11305165986414067, 0.09686665842309594, 0.1403767432202585, 0.11598451616009697, 0.17344881780445576, 0.1154928507457953, 0.20321541116572917, 0.10329179451218806, 0.11884044142789207, 0.2798830659594387, 0.14979839703300968, 0.10962458516587503, 0.1901898140204139, 0.10701834064093418, 0.08186710430891253, 0.11170519617735408, 0.10182266123592854, 0.22144601651234552, 0.1684168487554416, 0.3411618137033656, 0.20845497376285493, 0.09775540995178744, 0.07492377102607861, 0.24403112882282585, 0.2505360235227272, 0.07067302372888662, 0.1900099025806412, 0.138800926215481, 0.13604821142507717, 0.10837847468792461, 0.21466813021106645, 0.13534187979530543, 0.23083397682057694, 0.1065171386289876, 0.08584969138610177, 0.08215725436457433, 0.1208787648647558, 0.13641615340020508, 0.09106140860239975, 0.19034833676414564, 0.1686528665595688, 0.12872514344053343, 0.1437351544154808, 0.13501068897312507, 0.09207572409650311, 0.12228852632688358, 0.062438709719572216, 0.1613990854821168, 0.1406655425671488, 0.15794462553458288, 0.16516590054379776, 0.17260271008126438, 0.0776572641916573, 0.1455201383214444, 0.06330858101136982, 0.1823846172192134, 0.18984568014275283, 0.23507514299126342, 0.1316800934728235, 0.14925376453902572, 0.13610047346446663, 0.10527321748668328, 0.22567544190678746], [0.04279452085029334, 0.025673737982288003, 0.06832273851614445, 0.054312556312652305, 0.014796502509852871, 0.03236042546632234, 0.11311531387036666, 0.04520269729255233, 0.024950999322754797, 0.053758988360641524, 0.03868279265589081, 0.01408944543072721, 0.01882195232610684, 0.031898932065814734, 0.045722968789050356, 0.03882391574734356, 0.04221000905090477, 0.07043215227895416, 0.029098025916027837, 0.02976728355861269, 0.03616506408434361, 0.044219221745152026, 0.028087909122405108, 0.031563106531393714, 0.03584719481295906, 0.06330613192403689, 0.06624903689953499, 0.027416840639489237, 0.04032314311189111, 0.016275641792162787, 0.02577451607066905, 0.05295801434840541, 0.01642845742026111, 0.07434616491082124, 0.040346624664380215, 0.025920965927070938, 0.017723202690831386, 0.03139793414447922, 0.07006067025940865, 0.047547750364174135, 0.07355422654654831, 0.09323131482233293, 0.045267093446454965, 0.0688702282786835, 0.048403313048765995, 0.02086156153382035, 0.034053653944283724, 0.01621330695343204, 0.09795707373996265, 0.0209811066815746, 0.14208512264303863, 0.03146819697576575, 0.07090841812896542, 0.01081730240912293, 0.023851175428717397, 0.05795564422442112, 0.06275958468904719, 0.027933520141232293, 0.09163532624370418, 0.009377282658533659, 0.01725035999697866, 0.03696594532812014, 0.12603718845639378, 0.04504020034801215, 0.01146631890151184, 0.03182340740750078, 0.03833587201370392, 0.06622032320592552, 0.021127905347384512, 0.04382900420750957, 0.016236050068982877, 0.07277402895851992, 0.019851485558319837, 0.004364634960438707, 0.142307247442659, 0.02930012942670146, 0.023576731073262636, 0.017982063800445758, 0.057665586937218904, 0.04396605661895592, 0.04293471996788867, 0.03786569919611793, 0.06193575623910874, 0.028403021315170918, 0.07024403268587776, 0.054948977631283924, 0.10209654341451824, 0.02476036755979294, 0.05630517829558812, 0.010044876962638227, 0.01978133775992319, 0.04416043622768484, 0.07263631603564136, 0.027117163263028488, 0.004875432941844338, 0.01988248506677337, 0.07276324555277824, 0.045003037303104065, 0.023922245345602278, 0.011095751578977797, 0.06837874097982422, 0.045925192898721434, 0.06474101508501917, 0.027355021593393758, 0.02756061134277843, 0.035598141184891574, 0.003046430633730779, 0.032695831687306054, 0.03316856120363809, 0.008517765254509868, 0.010505688514967915, 0.017296258120040875, 0.08315137602039613, 0.024707055381441023, 0.03735723155841697, 0.03054846263694344, 0.07602626108564436, 0.025004419112519827, 0.020932117513439152, 0.052969090902479365, 0.03631073283031583, 0.053273382582119666, 0.018860688724089414, 0.07543165978859179, 0.02764619766821852, 0.00856080239827861, 0.02536295993195381, 0.008846250020724256, 0.044481040313257836, 0.01987174247915391, 0.033231016641366296, 0.02730350912315771, 0.009325507653556997, 0.03839009332295973, 0.027397984522394836, 0.015468017209059326, 0.016196627184399404, 0.051007323709200136, 0.012729512691294076, 0.03228430337912869, 0.008030164026422426, 0.026889837863564026, 0.017629465728532523, 0.007734329583399813, 0.028072951135982294, 0.045726698081125505, 0.08881778485374525, 0.04456191214558203, 0.04129477769311052, 0.06674787146039307, 0.033234252405236475, 0.03426236071391031, 0.039136909108492546, 0.035857265756931156, 0.011833276603283593, 0.005939135580774746, 0.05152224432094954, 0.061936999336467125, 0.01851947705290513, 0.053306708723539487, 0.02428255247650668, 0.08583075177739374, 0.039427189039997756, 0.022852469155623112, 0.05520911894564051, 0.04621488282282371, 0.0077324714311544085, 0.026268483998137526, 0.0393964604154462, 0.022656968903902452, 0.06501241849036887, 0.035268249121145345, 0.010635906673996942, 0.05801143517601304, 0.016507049003848806, 0.050699083803920075, 0.01578701918333536, 0.022506639470520895, 0.05135007719218265, 0.02526553078496363, 0.027830469225591514, 0.04526388365775347, 0.046968856622697785, 0.03248748114856426, 0.04096976153959986, 0.029019222820352297, 0.059512588413781486, 0.04900231899227947, 0.006512459503937862, 0.04800748858542647, 0.02387967389950063, 0.049370606066077016, 0.010780934389913455, 0.0640394257789012, 0.06878894826513715, 0.05769624876847956, 0.08404729669564404, 0.01935417796630645, 0.01261726749362424, 0.058888453349936754, 0.06748384446837008, 0.06823967734817415, 0.01063385556335561, 0.0496556464349851, 0.025687603156256955, 0.009972177103918511, 0.04160162607149687, 0.044431064088712446, 0.01090032368665561, 0.033111415832536295, 0.005718480233554146, 0.030128188118396793, 0.02143681875168113, 0.040343125438084826, 0.0632426782976836, 0.06837125270976685, 0.0430618609971134, 0.05573716443905141, 0.05113006009196397, 0.03981436377216596, 0.03618979986640625, 0.05302285208017565, 0.03386375690752175, 0.010116577705048257, 0.008351763517566724, 0.0533893246029038, 0.08264446689281613, 0.047273823656723835, 0.07312622998142615, 0.03352567524416372, 0.04288008305593394, 0.04943628242472187, 0.10371499680331908, 0.017673217189440038, 0.0630134808307048, 0.02975741484988248, 0.036143653123872355, 0.042082838335772976, 0.10887218842981383, 0.055326359724858776, 0.05135401428560726, 0.04555518404231407, 0.030388863779080566, 0.06443326128646731, 0.06763245954061858, 0.010529439095989801, 0.0669797406590078, 0.010052703837573063, 0.038785795331932604, 0.029671581760339905, 0.06063759152311832, 0.029748711313004605, 0.02635036886204034, 0.029034987892373465, 0.01670448255026713, 0.0286664169470896, 0.07354887566179968, 0.04340580562711693, 0.022147525342006702, 0.056492960211471654, 0.02768677830317756, 0.07627267637872137, 0.0630068386089988, 0.019149202344124205, 0.028612761525437236, 0.03877100803947542, 0.02955030184239149, 0.00666495322548144, 0.05173827979888301, 0.040814708336256444, 0.04120100362342782, 0.04285040828108322, 0.02191030896938173, 0.038089412191766314, 0.0478532888519112, 0.030509668722515926, 0.08426451589912176, 0.01669499048148282, 0.06869767894386314, 0.0104433239903301, 0.04613351746229455, 0.08487516242894344, 0.06713928014505655, 0.03160686726914719, 0.04122633683437016, 0.06297799132880755, 0.038901162188267335, 0.005866509472980397, 0.06856240026536398, 0.012343862144916784, 0.029754906390735414, 0.025526642457407434, 0.013752459362876834, 0.04104906372958794, 0.04455893984413706, 0.05572377980570309, 0.11900634111952968, 0.019978300042566843, 0.07253534684423357, 0.0191128853475675, 0.024930580984801054, 0.02785759286780376, 0.05105551135784481, 0.05247572225925978, 0.03394761588424444, 0.052830943823209964, 0.013967678478365997, 0.04716686162282713, 0.01759990042046411, 0.024567589134676382, 0.022145096663734876, 0.01583840919920476, 0.04342543543316424, 0.027042601541324984, 0.04449980922800023, 0.03927557198039722, 0.04489906983508263, 0.034938895114464685, 0.02814064057020005, 0.01473290880312561, 0.023449873915524222, 0.023063374537741765, 0.09627253210055642, 0.036681290876003914, 0.05332313245162368, 0.07342237659031525, 0.028242502194189, 0.023317816157941706, 0.051343446102691814, 0.06218093585630413, 0.06473306668340228, 0.008527586651325691, 0.08214500892790966, 0.05411349375208374, 0.03306614853499923, 0.0036565472237271024, 0.05810604045109358, 0.057822781236609444, 0.022698913235217333, 0.04856678220676258, 0.048664500791346654, 0.03556140487489756, 0.05286290070216637, 0.030492044570564758, 0.022372225394065026, 0.024231190291175153, 0.052444592874962837, 0.08694403266417794, 0.026890028966590762, 0.037539495606324635, 0.04136771967750974, 0.06097485682403203, 0.14844972174614668, 0.10614720769808628, 0.18619560491060838, 0.11129478109069169, 0.08548750105546787, 0.15197069296846166, 0.13533193501643836, 0.08774775633355603, 0.13865907210856676, 0.10878575048991479, 0.13801169669022784, 0.07733916485449299, 0.08797859394690022, 0.20350720878923312, 0.14306542550912127, 0.1314990094397217, 0.11179649518453516, 0.1628232075017877, 0.15763773262733594, 0.2013868631911464, 0.20177822734694928, 0.12279058180865832, 0.09411588063812815, 0.1504017334082164, 0.12109144212445244, 0.18966490781167522, 0.21011263481341302, 0.10911550154560246, 0.07930378560558893, 0.16976620681816712, 0.13357064046431333, 0.14722016116138548, 0.07616987408255227, 0.12153439296525903, 0.10969245457090437, 0.12820023723179474, 0.08466067432891577, 0.18612023239256814, 0.10987926798406988, 0.15698505827458575, 0.1329219588660635, 0.2813209325540811, 0.1486754830693826, 0.17901960090966895, 0.17879614024423063, 0.08287343429401517, 0.1512095017824322, 0.17518841195851564, 0.18668966746190563, 0.21332197822630405, 0.2817797876195982, 0.09934934278135188, 0.23568741482449695, 0.12489739805459976, 0.12268426915397868, 0.15137658891035244, 0.14758367993636057, 0.1590078411391005, 0.21521962014958262, 0.2092120682937093, 0.09676499161287211, 0.12147539222496562, 0.3648815955966711, 0.17063627106836066, 0.10975695462548174, 0.12792996189091355, 0.22763022920116782, 0.14359294407768175, 0.1369696471374482, 0.1622011690051295, 0.08689237176440656, 0.15329395711887628, 0.04544464856735431, 0.0957315658160951, 0.16890924889594316, 0.13046853739069775, 0.12604045390617102, 0.10237952432362363, 0.15781277557834983, 0.16898257308639586, 0.14400623127585277, 0.11906523795914836, 0.13828946772264317, 0.15504590061027557, 0.11857406236231327, 0.1746851170901209, 0.1946154038887471, 0.23276200226973742, 0.12917371233925223, 0.15601428458467126, 0.10559602204011753, 0.09959952818462625, 0.18287913990207016, 0.09691749553894624, 0.14455119031481445, 0.12255205554538406, 0.17618646699702367, 0.10566700846538879, 0.0619584511150606, 0.1047828359878622, 0.12198107680887915, 0.1769242508453317, 0.17932438611751422, 0.16620747512206435, 0.13766971504082903, 0.11813577220891602, 0.14227708656108007, 0.09472628225921653, 0.18494947958970442, 0.1263782795285806, 0.13124138029525056, 0.11879081401275471, 0.15356625110143796, 0.08340593267348595, 0.2082291233818978, 0.09131813232670538, 0.21691244415706024, 0.12094132049242035, 0.09184633367112838, 0.15830728341825306, 0.15954653645167127, 0.23723744961898774, 0.11139268521219492, 0.14491448644548655, 0.12776587303960696, 0.20130957593210042, 0.29106058180332184, 0.11607612686930224, 0.14147342968499288, 0.1893294570618309, 0.09799739462323487, 0.14639035100117326, 0.07969306432642043, 0.13223257788922638, 0.06709300723741762, 0.06752406145096757, 0.09542489555315115, 0.13958913157694042, 0.18852663139114156, 0.14073635829845443, 0.17167167097795755, 0.07004300714470446, 0.08830890903482214, 0.14438334619626403, 0.14491390757029876, 0.16695927071850747, 0.20331675885245204, 0.09724148752866313, 0.09473648678977042, 0.1781840019975789, 0.12508085696026683, 0.07201536107459106, 0.12622340815141797, 0.1265002737636678, 0.12712134746834636, 0.08520594506990165, 0.15723280201200396, 0.12168976900284179, 0.09164063259959221, 0.14030197926331311, 0.10597284010145813, 0.1694772145128809, 0.09721867390908301, 0.13348685199161991, 0.14465412619756535, 0.08505059871822596, 0.14751256734598428, 0.16104848007671535, 0.11955677720834501, 0.10420661768876016, 0.121268815419171, 0.1698936929460615, 0.07637997608981095, 0.15908557368675247, 0.13235638296464458, 0.22497659112559631], [0.07412366903736256, 0.006739585915056523, 0.014749343663424952, 0.06046523885743227, 0.10163048951653764, 0.02445091238769237, 0.004077499879713287, 0.014377425632119412, 0.04951787042955402, 0.02365840999118518, 0.016670299228280783, 0.02996467814227799, 0.020510796566668432, 0.08400450446060859, 0.05721776018617675, 0.028865742970083375, 0.02726597314904211, 0.07412874532747082, 0.04334414428740274, 0.023703879523964133, 0.08194216512492858, 0.04071852599736303, 0.016147704809554853, 0.019912606985599268, 0.026294219824194442, 0.04651439136068802, 0.05524027059436776, 0.02525716678064782, 0.0656051941041369, 0.06339795043459162, 0.04775227513164282, 0.054909948084969074, 0.021777091606054455, 0.03357206689543091, 0.03017617538716877, 0.037276504444889724, 0.05808952766528819, 0.02827632186381379, 0.034373612361378036, 0.026453944847162347, 0.07557097575045191, 0.019342375962878577, 0.09896447241771966, 0.04536120890406892, 0.04184666839137208, 0.023818739864509553, 0.05311199514835607, 0.03263677157519851, 0.08146033316734247, 0.04609458068443928, 0.07493817611248232, 0.04453433764865622, 0.06280567948124371, 0.06798194430302829, 0.04460399562958628, 0.04471650150662754, 0.022254452123888768, 0.06958406302146614, 0.0655392839689739, 0.01519417121016886, 0.015319279682444176, 0.018171333722420968, 0.016598316469753627, 0.08754125374252908, 0.012183554536022712, 0.01932054012286244, 0.055116075891419314, 0.1355508537380956, 0.009078652637981577, 0.045170324810897, 0.0021841369016328827, 0.026690435770433396, 0.04312663193559274, 0.023681787642999552, 0.07924062141682953, 0.010228437913610833, 0.08637093138531782, 0.03158345622068737, 0.010312302456441103, 0.03928579877538141, 0.06087997324357275, 0.08428039043792523, 0.053082183076185174, 0.03846464205707889, 0.04135011593461968, 0.06821626258897595, 0.12417913269018754, 0.03737185186764691, 0.04326711678004358, 0.034419684889144264, 0.04879313724813983, 0.017303571985394228, 0.03177200625941623, 0.030559040096704848, 0.03905320227204356, 0.022486831549031194, 0.06973093404667452, 0.02086442993459059, 0.09715394378872588, 0.019888592942152172, 0.02873864461435005, 0.04445283499080688, 0.02194396536651766, 0.02503572846762836, 0.06636656340560876, 0.03376902546733618, 0.03438756102696061, 0.01873465720564127, 0.0339584030007245, 0.05476373014971614, 0.09567611996317282, 0.07417863249429502, 0.04047077483846806, 0.05960453308944125, 0.04196416892227717, 0.068255603837315, 0.020296683251217473, 0.037718286403105594, 0.05533060109883081, 0.030921796314942185, 0.026163432994508184, 0.026791176751430612, 0.016751289804233238, 0.06296020947047509, 0.06751408698619343, 0.019080922902503517, 0.05747922994487453, 0.0032391137392551173, 0.05105623866256792, 0.007324651542148786, 0.040775816087261774, 0.011511220691318158, 0.04440435419382993, 0.03656524124380667, 0.035190305061405525, 0.04523173010966275, 0.07214723329525441, 0.026137441127502825, 0.04884401889285073, 0.07853444563806988, 0.05640287090500351, 0.04756168789754156, 0.0490990950493142, 0.042788654172909446, 0.03388336073840037, 0.008111529386951588, 0.013278138867462985, 0.04181621436146088, 0.06993514340138063, 0.03771458679693751, 0.02323304805031512, 0.023329167306656018, 0.008441662648692727, 0.0146621552266879, 0.00890818966581719, 0.003624866794780246, 0.055980455290409736, 0.04856837782426737, 0.010800361033034278, 0.0910213177849073, 0.04412583730299957, 0.15231635567033663, 0.03247060471039731, 0.07625985206686892, 0.06849166617030278, 0.01159421042757458, 0.03458110943029169, 0.04869738535489887, 0.02834540468029445, 0.04203457647236064, 0.07782574655720964, 0.022083290605223738, 0.01654545143537689, 0.0778222584631294, 0.06217331399966497, 0.0331906697829254, 0.0489318891777657, 0.03909302962711081, 0.03201009465556126, 0.043608582636807114, 0.04135645016503986, 0.020142127286817413, 0.027950906805926934, 0.07388375495793298, 0.04463562596356496, 0.04517689652857371, 0.010557712139416253, 0.06942070147488266, 0.027777303621405736, 0.030881816819601227, 0.04452076005691197, 0.03294665533758234, 0.027685288441716693, 0.05016393966798205, 0.05193347577005625, 0.009289747267757775, 0.04220320355670992, 0.01806863903766498, 0.025743158475961536, 0.04817283166630659, 0.024458627012791112, 0.02493904517905321, 0.012106013091397472, 0.05186850445170421, 0.057766493046074174, 0.015210814799502259, 0.00794972913354286, 0.11978983384324238, 0.01797165889001917, 0.035879734277841635, 0.06907931354362518, 0.08266124685178511, 0.0720916167483665, 0.03214373689843342, 0.017638968929531984, 0.030641707926406525, 0.04119599783734884, 0.011936303399124881, 0.04495406297792215, 0.05452465469716117, 0.0442412486881949, 0.08100252453004941, 0.026854409588850103, 0.05992269921989646, 0.040573877704446204, 0.04895912228676025, 0.04354635355412029, 0.04897779472230468, 0.047913380549289286, 0.025180419434036594, 0.005260460084173246, 0.03402335205464624, 0.029342053348955233, 0.06855354644358158, 0.03488924543489702, 0.023512078878411558, 0.011323256949253846, 0.036239991313777864, 0.05787968540971633, 0.022207262663869187, 0.012504883143265033, 0.05032239932916127, 0.036968438944313675, 0.044725414700224064, 0.041998270608019084, 0.014659494627267122, 0.03553872484189924, 0.035366516895010136, 0.02419185831968207, 0.02718354095122777, 0.07949286999064498, 0.010725290940172272, 0.019426836079219356, 0.015979428389982786, 0.020978789325454272, 0.03752249671379104, 0.02820124434947502, 0.034835450860555284, 0.028253994350961875, 0.03398445980565157, 0.08009555327589624, 0.028971834835829213, 0.029208377709437627, 0.011707429694070015, 0.047251032301574014, 0.031601976515958086, 0.029054921978968196, 0.023636750411242247, 0.06162588360894006, 0.031242097975336947, 0.03129831937258132, 0.03006940631166799, 0.02042270734818885, 0.009939856572600547, 0.03268318178015761, 0.00900381724932231, 0.01470243993026088, 0.0353847180667799, 0.011344769027346047, 0.0202278026699787, 0.01812258760764962, 0.006232443010958377, 0.013267821159388404, 0.05668000740115531, 0.03385722229722887, 0.0809088432288263, 0.03249922563554719, 0.05593997484538704, 0.00984664282441372, 0.03766865898796823, 0.03216523320588749, 0.040588672418380156, 0.04343880522355903, 0.02775705226667924, 0.022465086622105446, 0.025812334060901776, 0.027528897517186124, 0.025597313469916116, 0.034313305441173725, 0.0448815031995764, 0.03268977576226462, 0.054471542898681946, 0.07216229147161357, 0.05606713813904207, 0.034560310741653666, 0.07953811131301336, 0.02899698436522158, 0.035119177628075704, 0.008306342224386754, 0.019016649202967528, 0.022768860653741285, 0.047807617083890364, 0.034777748878696, 0.017554970800119918, 0.012216759150760481, 0.03187236317899078, 0.014620236870541703, 0.015235713854053756, 0.04417247757373843, 0.013530484848160995, 0.0778024505416397, 0.06482189433882013, 0.03950815735151991, 0.040318337705684826, 0.0261951449647313, 0.04419463068188634, 0.009343856327177491, 0.042586255658534355, 0.015714199653302785, 0.03752280470507685, 0.04990824010747019, 0.027765015511249658, 0.01154610441517434, 0.04649944821721874, 0.048816177222761326, 0.0596422787202755, 0.049088816303992644, 0.06933176249731332, 0.05259006124106236, 0.02815256688336376, 0.03845269347948488, 0.017182358860736713, 0.02051463718089508, 0.049032587485271506, 0.040145810635294765, 0.0587274555437034, 0.04407177184475586, 0.020229574547556695, 0.1126591899082996, 0.04004661146609578, 0.0326953789772233, 0.043053879198851064, 0.18233505659736693, 0.12752204784192145, 0.08863650044077076, 0.16655775398248807, 0.20053967193234712, 0.08314143866300583, 0.1287736650556326, 0.12460380443371832, 0.1382933565764688, 0.14169065630994737, 0.13565944478614256, 0.16568860999541357, 0.09855577911366709, 0.15980346797732636, 0.1058896082395222, 0.10993341507855803, 0.13810790871502832, 0.13190447440138087, 0.22744544927263632, 0.2031633717706427, 0.11542528562131338, 0.10040130742709152, 0.08205610705772415, 0.19294040626846254, 0.11566839835722931, 0.13149178092135116, 0.14268376864492893, 0.12258107351954095, 0.16226892708800733, 0.13901451631681994, 0.10926639501121826, 0.29085322574246675, 0.160615436907392, 0.06580726607353427, 0.167014263861347, 0.12257610855158418, 0.11403418175177649, 0.25167403277009726, 0.153968287340831, 0.11645714548649266, 0.2453463926212862, 0.13292135030496866, 0.18477494129911065, 0.08227196813095361, 0.1812227553455159, 0.20712785044452175, 0.15208691329462454, 0.09648558785556816, 0.13992513151606545, 0.11293771050986834, 0.1195398042909801, 0.1850966177880764, 0.149518889375031, 0.13856058911187574, 0.11407603888073936, 0.10143574996618554, 0.102242798457155, 0.20947447686921805, 0.1829042541794479, 0.0735046733461786, 0.08205359859857708, 0.11432318890001625, 0.14743354346137494, 0.10571011240244843, 0.06981868558796123, 0.11950778804020956, 0.19986335275461897, 0.22577845200430602, 0.10655920355929993, 0.14806028717430308, 0.09643653931561857, 0.24240232247393578, 0.2156935556558892, 0.07831462149624713, 0.14787737745791674, 0.1236628502374515, 0.2029206746374257, 0.09234486395143904, 0.08063138389843516, 0.12384056492010131, 0.16072151949629188, 0.1547918634605594, 0.13508341944543645, 0.09246516608982347, 0.17971848137676716, 0.1476621991605498, 0.17117331881308928, 0.1073785568587482, 0.1818056678166613, 0.10157323282328434, 0.09083114244276658, 0.08414828073000535, 0.2312060006079264, 0.16751139890402555, 0.10551213708822615, 0.11035610528779216, 0.14052180340513587, 0.10706769346143119, 0.2203323200228624, 0.0654315686551854, 0.08198774041375145, 0.08606068397057243, 0.07172534460551105, 0.11370078675099649, 0.136532848700881, 0.11142761810333468, 0.09344039266579784, 0.11050094282836653, 0.13970906264148653, 0.16023030679207295, 0.17329644004348665, 0.17506818403489888, 0.1326765157864429, 0.2695720817428082, 0.13405135920038447, 0.17044547974364832, 0.10049726712168194, 0.14905871328664944, 0.08493268629536033, 0.13025347783695906, 0.10492505374713801, 0.09881867750664242, 0.07457242347300053, 0.17121953977039084, 0.1359181574662216, 0.17999243777012452, 0.11167421151185408, 0.1714865496614948, 0.14965122914873064, 0.33243299927562475, 0.19596496975282207, 0.1172811965807341, 0.14736954064574093, 0.20124356931773946, 0.15640008263289928, 0.2095472815562971, 0.1161271495220717, 0.09499098407104611, 0.16501859907293692, 0.20712382800411433, 0.10516926486161537, 0.14085747679928318, 0.20089386933250353, 0.08932470140280202, 0.13778085907688364, 0.16827782965265214, 0.17729847138980404, 0.10384230481577106, 0.19417839765083045, 0.11432067301939242, 0.0878614088287577, 0.20090975129278377, 0.14461848826613277, 0.07507075337343849, 0.19335765653522685, 0.08409149901126511, 0.17829508666181937, 0.15526888630120084, 0.11697660433128476, 0.1907712867250666, 0.12708478927379474, 0.2869164588628337, 0.1024078817863483, 0.14303584350273013, 0.14129391900496557, 0.12598197266925126, 0.11111134444945492, 0.13980321149574593, 0.11542247288161889, 0.12661481683608145, 0.28724549745675176, 0.07177129096817225, 0.2514155278913677, 0.11517158985952847, 0.23545926378574222, 0.10984086926328018], [0.07542032719356939, 0.07999499968718737, 0.014181662845658138, 0.02991509340063203, 0.08299300912767649, 0.06734259892255068, 0.02952157887193607, 0.03025081503437832, 0.0788955895404797, 0.046569659098167904, 0.03537224998581223, 0.010608515858621104, 0.0954576168442145, 0.008326601928274613, 0.057756177193368785, 0.04434182454133406, 0.0541125734889647, 0.032117212540470064, 0.05383947798691224, 0.028545124041556846, 0.05618205599603243, 0.038358221790986136, 0.028188787400722504, 0.016055611704359762, 0.036893548822263256, 0.050480113131925464, 0.02027677885052981, 0.027060643151344266, 0.0758202928409446, 0.051507698226487264, 0.015168895515671466, 0.0200115297047887, 0.07656491929083131, 0.008142135557136498, 0.039519660640507936, 0.0458472080208594, 0.029903825743531343, 0.013329120702110231, 0.049178341578226537, 0.01198853946334566, 0.017770091581041925, 0.03482813699520193, 0.008959000806498807, 0.002806300171869225, 0.02240096506284317, 0.04199644121399615, 0.0322335293458309, 0.08436834235908464, 0.00942407599723083, 0.010560574046394322, 0.04641869512852281, 0.05307729232299607, 0.06401673832442611, 0.061411811111611314, 0.06931524971150793, 0.04215880828269292, 0.06860744120785967, 0.005893505558560719, 0.06018935288011562, 0.0359189604932908, 0.026071751781273633, 0.02534430976083968, 0.05000119039323181, 0.06890719465445727, 0.027312420461385045, 0.018531475725467317, 0.038720660741091706, 0.0670939868723508, 0.015944161532388534, 0.025838901092356537, 0.009115990087593673, 0.02881767777580535, 0.031086404669622425, 0.021235145686659962, 0.0365188458818011, 0.020112985002924688, 0.02675354429811705, 0.021503177886188496, 0.0666277993877884, 0.018166439258493483, 0.061121854014345445, 0.025938666149158962, 0.03277309297118336, 0.055078311706893146, 0.03436715567659121, 0.04624539251381066, 0.05690376492566429, 0.003956421733164461, 0.04684337429353036, 0.016953992599155754, 0.03256233787396923, 0.023059539489622694, 0.02399581815552665, 0.019431984728726093, 0.06328023097012192, 0.005249285659374436, 0.027884508708666544, 0.11489354423247278, 0.02153703466319712, 0.029598168512166012, 0.06407087057596073, 0.021053686868981458, 0.036914273296133615, 0.01869920852186624, 0.026514155288168695, 0.04993571070372127, 0.10278236208250746, 0.037045681674499065, 0.011992788258794462, 0.023152311659941915, 0.053271534634404816, 0.040727873347350396, 0.030488693773804698, 0.008519562179571949, 0.04199730210530106, 0.016174950906133745, 0.03374355124833528, 0.05590789551206399, 0.07471233315300196, 0.01926383818499744, 0.04815533182409126, 0.06153755690320395, 0.038894334429642186, 0.04355870289145969, 0.013448394965962507, 0.038793198255007155, 0.02242455979285296, 0.01585866240930045, 0.06433954287786037, 0.04066160698130261, 0.006251303766475758, 0.03570175984350499, 0.018043704731098842, 0.012335495357547188, 0.07662434305530041, 0.04845570867473725, 0.032334279603674076, 0.007645690247954917, 0.03730812364665326, 0.03193110416759737, 0.039697108149994165, 0.013494786617229693, 0.021126734609424602, 0.047837191668804735, 0.08234259090386331, 0.07434654340613633, 0.028055954098817892, 0.06468070816481486, 0.030332801943586674, 0.04699316938058473, 0.06453300593420863, 0.11017115466529503, 0.08406223612837493, 0.06186361948493868, 0.04244178919179831, 0.0204463336194749, 0.013579828391812043, 0.044948044160264544, 0.015616555283486377, 0.03280338743934408, 0.006197447037266102, 0.02122033984051086, 0.03958802357374225, 0.015934200055198744, 0.07349332590820268, 0.02235514115454862, 0.038626133391517214, 0.013929966244177194, 0.018521968813729472, 0.03378440647793468, 0.0240868574110209, 0.021650984017469455, 0.09289756359066814, 0.018879465060308576, 0.052765798100153916, 0.038266288247541524, 0.007904616759333294, 0.018522141363064293, 0.007724504939687904, 0.04510492304689251, 0.057007075592991896, 0.05029993080825079, 0.035476120974635705, 0.051136917536496185, 0.061968295703991316, 0.01091654425181332, 0.03383739953278564, 0.054088906399556436, 0.10491746899788268, 0.0663560842804145, 0.03277691132097971, 0.058885759353870526, 0.025440551471547224, 0.05773529686848633, 0.03224090629373677, 0.0673417083453387, 0.020793135518033523, 0.02068931276880903, 0.06491746069514193, 0.007573558596050134, 0.028413893778633792, 0.04803019830433186, 0.0038780414297434618, 0.03646859135187697, 0.012378971296129748, 0.04508908932621125, 0.03591903099732008, 0.02166339643736137, 0.03305974751128815, 0.01859587002400076, 0.06042958237230778, 0.05213416734477505, 0.01633942752960138, 0.06970642833039165, 0.030429902690229937, 0.04682649043388665, 0.04125819352339022, 0.014532412969856523, 0.04993808557628654, 0.020637136076402385, 0.04487540645641275, 0.023765297810314223, 0.034093982249032706, 0.03586323633498978, 0.07195080164819956, 0.07314713628147729, 0.025266900047427043, 0.040796644461806864, 0.032309261805494316, 0.06807180354371667, 0.08268073564977385, 0.04468438135518227, 0.08505705540301278, 0.01986628212762298, 0.0700690045778174, 0.02143094279745128, 0.05911630381888244, 0.012640219338209135, 0.026296336800442077, 0.09732710168464109, 0.10902334164711647, 0.0315091301308712, 0.001829603795613366, 0.029762351987301372, 0.012897543274448253, 0.009571485079504782, 0.036655542062362656, 0.018678033193282317, 0.018756964309432078, 0.011875892578245839, 0.03562066165613942, 0.0535058714740444, 0.016802410791569855, 0.0656300263653975, 0.04241000671754591, 0.011285396285529714, 0.041916322661563754, 0.03619044553488493, 0.059596369464998133, 0.036145604972261935, 0.007377591718977783, 0.09304378152592108, 0.05883277000975795, 0.061410482667270117, 0.0894839217653498, 0.009907585208566161, 0.06958458994631656, 0.043342530116206035, 0.03878796982462518, 0.04293127640266903, 0.04012366865936201, 0.026969756036123727, 0.028757918189512566, 0.1454678614391014, 0.01707490700937342, 0.028539728627947625, 0.010885492793022422, 0.016425653957412578, 0.02383550312515581, 0.01284382755329716, 0.01582205411978066, 0.1418004051083699, 0.051402970057097264, 0.038851735153002664, 0.059170150343561545, 0.04035081779875327, 0.021144145393918734, 0.02983432732435176, 0.06608462892472744, 0.06890769931487739, 0.04107103501155507, 0.06496419373434037, 0.017656301788520068, 0.012494842812884599, 0.04701531506725587, 0.04082213723449968, 0.03661853486846667, 0.061803067656001076, 0.035063624163740315, 0.05553509618039243, 0.07885414801421575, 0.012187641914351843, 0.03820557685685344, 0.06610804368392564, 0.03790941169427242, 0.013252948519948404, 0.015376061401184415, 0.017954817703866865, 0.026055687994812615, 0.03556481875421014, 0.02262496192997787, 0.03862135767121799, 0.04333860786573496, 0.017318784157396294, 0.03646970828413032, 0.06934235294465907, 0.02656645814568037, 0.04481405681872275, 0.08427175183896907, 0.044746165149263106, 0.021491036350198556, 0.046003092429600656, 0.017480236529081594, 0.01922337629366666, 0.025641645661380608, 0.012277959431230556, 0.023623939086974133, 0.06179073316161521, 0.05685627860657405, 0.025154546310659498, 0.09222575667081401, 0.0339491743943654, 0.00933358964175568, 0.031828094070078805, 0.029234827852633316, 0.07050372500088997, 0.024734553808229975, 0.05614653309748974, 0.03958171531849075, 0.02823702885507373, 0.017147418548120186, 0.10918996122200042, 0.024178620260499883, 0.023112836825021077, 0.036574302866938524, 0.04215770990413148, 0.04501348303165287, 0.024980252928799018, 0.09403413307154551, 0.06852691076346673, 0.03230263071600348, 0.0595208856248064, 0.16664877097355202, 0.14357658714288846, 0.09597225915058516, 0.1230118828243576, 0.17210860300110653, 0.09459186447202228, 0.16009112441679463, 0.10141907390789129, 0.1736624227487482, 0.10023529641330242, 0.12914870196254924, 0.1674044702667743, 0.24540392390917987, 0.19953890063334256, 0.11950104191782884, 0.19510657206410542, 0.11847089641378261, 0.12839606031775475, 0.09152957019978203, 0.11288774170679972, 0.10864757001399994, 0.12659525382332504, 0.1668421004433185, 0.1040204573655501, 0.09398990107001737, 0.16867312719114125, 0.09026706567965448, 0.12779132870491594, 0.14211709436494857, 0.12427620560629293, 0.16484382329508662, 0.13882274535717443, 0.17643759492784739, 0.08527375510311686, 0.13855165365384892, 0.22563722130144015, 0.1220450054097455, 0.22083282441599295, 0.09612606183509342, 0.17398824042174965, 0.08942644984927028, 0.10857502507860772, 0.19085694540990517, 0.12972300552064553, 0.11433638428570703, 0.13553197350120172, 0.15192169637884945, 0.1302698496147059, 0.18403398105874658, 0.20360244117910042, 0.11539888742845505, 0.1272260645055212, 0.16446966212242842, 0.11384867451852188, 0.16109220741782337, 0.11545109751750715, 0.1631431918940507, 0.1828192634275183, 0.1619847142137587, 0.14169718720950186, 0.16000542120309547, 0.1062816774356179, 0.1053232753474731, 0.20635110384318978, 0.1789566222578287, 0.12401446496369317, 0.09474954116740264, 0.16843155812239274, 0.09905514802085236, 0.07629730826010928, 0.1271259190980345, 0.10219664429314435, 0.10749406472314149, 0.1458971344982274, 0.154122416570317, 0.11799897212767974, 0.09170404911856167, 0.12958737061126158, 0.13070853310637176, 0.05885306774871424, 0.14777129486901686, 0.12940549990162253, 0.18485213950043544, 0.21777219255454838, 0.13810667674988508, 0.1780942318146117, 0.09869401896139607, 0.13098283088766038, 0.15648198605049402, 0.09766460076207295, 0.14721116633154452, 0.11022654114640318, 0.10189540655119345, 0.10712397794122808, 0.1806576841045171, 0.09730637350003235, 0.15942221187287942, 0.31818602001294494, 0.11967586964601651, 0.15586830413667485, 0.16036200831877068, 0.08499370567733422, 0.10953366465400904, 0.09563970277667977, 0.10087989619933069, 0.19573764991946518, 0.3032605693442747, 0.16228328022407368, 0.15937009826302528, 0.09918698313413188, 0.17799690656829625, 0.22647513571428135, 0.2038375535630621, 0.18625892495037988, 0.1791544639854692, 0.20157235558144748, 0.07260896047228016, 0.169929746480193, 0.1561765477526933, 0.10751922352937981, 0.13394002220593393, 0.09903230471536517, 0.15291964751668274, 0.28568562178406864, 0.1354293047916144, 0.08959857615991496, 0.11918622287339531, 0.16262158082099631, 0.09510986870736815, 0.13224111258750781, 0.2171937478124164, 0.07021174926194362, 0.1616919517982751, 0.08749990127398632, 0.1489077604492195, 0.14839092880720273, 0.1130951645609457, 0.06955996548640542, 0.14736035285750404, 0.13938701507868245, 0.12914744031149894, 0.10902187961619347, 0.10017483364208601, 0.14578704431187361, 0.0933678551518824, 0.1634308186476119, 0.12443333311239257, 0.18900889379438013, 0.118531804473605, 0.15023583371657878, 0.18847879255190492, 0.18110714358044788, 0.22978101769695058, 0.19381912396056578, 0.1730466925073415, 0.05383046831411775, 0.0872878399968613, 0.10237292663077824, 0.1354203693335876, 0.09028864733409137, 0.11768013064283878, 0.09069921085028909, 0.1451991594512947, 0.1454017063952051, 0.12386006856104359, 0.2628827781882137, 0.09257042489480227, 0.06702858139760792, 0.08273297542473301, 0.1187999350077007, 0.12317488071857952, 0.07011380803305656, 0.2092942240415141, 0.13677407638169825, 0.08124438303639181, 0.11397985654184595], [0.030253252989496104, 0.049383961013518274, 0.08594558428740129, 0.02552184261730872, 0.029331525984162, 0.04839323097257875, 0.07170195953221992, 0.015056587235449115, 0.0008556631064493558, 0.014002102070662659, 0.05841046942805406, 0.046126548695610836, 0.01877312271972187, 0.04442300436494406, 0.021911177282163408, 0.04517305962508544, 0.05257727774733212, 0.046316412335727364, 0.027504831523401663, 0.045933167275507, 0.026346789854869712, 0.03178496415785048, 0.05765842150140088, 0.032479206201969646, 0.014798752144997707, 0.03336274043249432, 0.03941485454561189, 0.06040214517270215, 0.06510834849905223, 0.020522734012047295, 0.0030103833614703035, 0.037834640315850265, 0.07717270113062114, 0.028256254190637264, 0.04096919008588884, 0.041084389958996326, 0.06453074238379486, 0.054476867808261886, 0.010960279014398111, 0.03104002600593958, 0.04500471455685329, 0.03311077016405761, 0.02247422617074335, 0.054108632684801705, 0.024881990721041802, 0.061488345090765506, 0.005653603075188585, 0.03699455512105487, 0.04727985360659659, 0.011854996482725255, 0.020470017407205887, 0.02567868068581447, 0.07383544856566004, 0.03171553624270018, 0.028389362087182235, 0.031218200820148923, 0.057922243868233636, 0.04216538000036962, 0.012435105491022114, 0.02094454292091541, 0.05666784360073507, 0.04638635604351293, 0.03278081501775887, 0.04487615231482778, 0.04464336656383239, 0.04780623297847342, 0.060651384337688796, 0.009613597321731504, 0.0031201203319142223, 0.029300849309947807, 0.020288992745918222, 0.03712470926984679, 0.06010748285916634, 0.0208665524769458, 0.04360738777904771, 0.02663927025423618, 0.02166256894270191, 0.012237765640747966, 0.05283781611069571, 0.018175187324231956, 0.11011227266862988, 0.04798844507604372, 0.03301009041024372, 0.08921190237742849, 0.03537095864885487, 0.04074751057487447, 0.020724262358271517, 0.022379433503374457, 0.05846703963470645, 0.007494027731809183, 0.03667754674097523, 0.05652639396430459, 0.06621409658691846, 0.0028821337491535814, 0.014390936430572765, 0.0417335687961895, 0.0398184492951259, 0.02980342058435781, 0.025925199879566208, 0.036684586011688225, 0.07395237393211573, 0.05497402511537075, 0.01725848651403794, 0.02859542495571077, 0.02762451953458367, 0.10386746362200938, 0.08134518895531073, 0.0026610349686961854, 0.05442974885227159, 0.05238821933744475, 0.02766201283520786, 0.027365127789380495, 0.06630379997659475, 0.04061740095494315, 0.021783195770694874, 0.05757899685704615, 0.03619909897679463, 0.02832464495440945, 0.04451483771845233, 0.02249615477921907, 0.02989592929225182, 0.06136084040917922, 0.016192048133234493, 0.01643678617256228, 0.008255201755673625, 0.06968129921006039, 0.028016627693432383, 0.03720990782312583, 0.004419234301167307, 0.03932292100216728, 0.03603230870794505, 0.044271929073147476, 0.05489695678988937, 0.03727951385371853, 0.0647474049765151, 0.061004090021015145, 0.007998801793291932, 0.030202516063582152, 0.09455253806663677, 0.02374353804043494, 0.041210462295566685, 0.1258630063966848, 0.00909310410861508, 0.017724924473441206, 0.012840900708397385, 0.051545937385526486, 0.02883072658732999, 0.06484614030341618, 0.03042689884750871, 0.06816650900873356, 0.05032162007410079, 0.017527208910905756, 0.04508134501520544, 0.021182236123422626, 0.05283776416035835, 0.037711837139795534, 0.018261012992297765, 0.027411803312133998, 0.04443486759555526, 0.05616458583972417, 0.025158372081932612, 0.034761892893584445, 0.03169643707224168, 0.026355951667937916, 0.021305608897819184, 0.09809218172449619, 0.016039020993048325, 0.03863877216645051, 0.045347308478085324, 0.03590172411350068, 0.01005650456136209, 0.02063576310320059, 0.03660233007394709, 0.03421852205065079, 0.05938796697591897, 0.015057104883453576, 0.03199400489393156, 0.027452025860839058, 0.038919912549317814, 0.018995197424374055, 0.04996147064957768, 0.07195446785772219, 0.05398145454819314, 0.04060419072629884, 0.02879695330193499, 0.03575670474674553, 0.06408255198039114, 0.04049906550790183, 0.027774707959906664, 0.007563111939816736, 0.03232794908399228, 0.051532107463572174, 0.0542049968498759, 0.028170092700747773, 0.01341569872238324, 0.06032047553162556, 0.01555481323521235, 0.03772021969780326, 0.018173179814766627, 0.0018220276274405478, 0.014917788921593456, 0.07755166399874724, 0.017289396964770276, 0.059551707017817535, 0.01610907602298539, 0.018810124347510282, 0.0075653740987036144, 0.06422342645237222, 0.010793929395731539, 0.06646564754191786, 0.06274840794503689, 0.06459944299422204, 0.0027318217098581954, 0.009188650055875769, 0.013685711528523825, 0.014628252993134083, 0.02421229892206611, 0.06109157809987664, 0.019014582321688067, 0.034811260557034984, 0.016066491589299403, 0.09608676511561498, 0.08811294494080357, 0.041352520493092015, 0.03303889316157438, 0.05353516404284164, 0.05065178673248738, 0.04449842883332167, 0.039382489485433325, 0.010637696177582256, 0.021748800936620682, 0.017463035401306115, 0.01998193285544403, 0.03291167791758198, 0.048884206189541146, 0.025268566168961115, 0.05513595060619991, 0.048920846020337194, 0.04919635350233875, 0.053342662067734636, 0.023816151624487247, 0.03682349750306457, 0.028510233823908493, 0.045274622534634545, 0.041825264852377586, 0.0071422947257815395, 0.008783831690379884, 0.018957282954943366, 0.048976803955156356, 0.0477684576617321, 0.09653652145061642, 0.03269461827585474, 0.03576038208848331, 0.02785982116620289, 0.05620156334771309, 0.043312313573551364, 0.04220267292112112, 0.050059274581144564, 0.016879503236850724, 0.0740059421514161, 0.028002434119116515, 0.0740405781834852, 0.013008858004468493, 0.0208032769660349, 0.04173723129497375, 0.040363905573030934, 0.014874177541059908, 0.058356830704724416, 0.0812135542219039, 0.03507029607135337, 0.015470211183128413, 0.04144987171457615, 0.03474620760243852, 0.009605803843442118, 0.01811508078390034, 0.04887476236035582, 0.0732544285710901, 0.024122565846482757, 0.07077592250425369, 0.010560884820733918, 0.07807739399140701, 0.10593072322080843, 0.07493951197830029, 0.03942750074202195, 0.07120240508811548, 0.010016212436312344, 0.04464774152438622, 0.03356467139383312, 0.03215863180230372, 0.012552505831990857, 0.0540548529534135, 0.004226581577313482, 0.0954205243033357, 0.06543196941493079, 0.027707899826054927, 0.01641564980673138, 0.05645047225698363, 0.036937914410373196, 0.020708100237243343, 0.08414609139435925, 0.0430811382830143, 0.026713123224908486, 0.034883627376984805, 0.04963740073435474, 0.051807191921398044, 0.02728848805418238, 0.027296792686684057, 0.05456667138787452, 0.037463284461409785, 0.043114828076795675, 0.04162500372331124, 0.03698563821671996, 0.02044858232693514, 0.017475831882620696, 0.01972939669940388, 0.007018083788352669, 0.05121883579704445, 0.06293034544796683, 0.036904083608533256, 0.03613763430621475, 0.0160108082491206, 0.06100853548559826, 0.07005920822848566, 0.04294137703254819, 0.13398118171608075, 0.05957221997960005, 0.04498524431255646, 0.006793638385715894, 0.044209165644133464, 0.0662733348144684, 0.0036515516421786742, 0.016886733610590454, 0.030067745756241493, 0.02991281871800311, 0.03802671926678158, 0.054258746895357035, 0.008067065464274492, 0.02610605013614986, 0.017227839525730815, 0.03792037321545649, 0.01002118853648426, 0.02334899007109925, 0.04316546481277328, 0.01085416766727576, 0.06139761011581868, 0.04891308686637785, 0.012196419665997382, 0.053608506786986254, 0.12485240906244144, 0.014690243660879787, 0.08996403936180286, 0.029230302607174963, 0.11173727179993875, 0.07117833723896183, 0.18536665564170107, 0.1584512006957084, 0.10701495644752868, 0.0933031844033394, 0.16598880873061717, 0.24675138207385316, 0.1452979541500099, 0.08933963341405615, 0.10879480469156988, 0.14528836560202762, 0.1260174621711485, 0.14959251042455435, 0.10284732969012111, 0.17617208417505026, 0.09685558557976037, 0.13990485604153946, 0.10105966663104482, 0.19998515403131023, 0.06220176423084922, 0.11387723978259601, 0.12279043337912299, 0.0912403552501928, 0.09448628654354252, 0.23023351997835562, 0.10675909361452796, 0.20418896048795432, 0.13503534311894327, 0.12066787618095987, 0.054897454028832726, 0.12533554719993845, 0.1081083774624858, 0.2281296203727834, 0.11341198740410618, 0.16393674071878195, 0.12719416699837893, 0.1445100604905747, 0.16990570089546964, 0.15942961850669235, 0.1163814909523353, 0.08573421320761554, 0.19692308240337297, 0.09007195505546406, 0.08757682488067076, 0.20565781916957349, 0.22062425123294815, 0.08858270215569064, 0.14026648976141587, 0.10263237403705716, 0.10904140552156605, 0.08857531036483124, 0.22724949260009453, 0.18372710299445316, 0.05346995894797146, 0.11190586548764259, 0.10468763328390196, 0.14783451100811362, 0.09405579636222683, 0.14503492217045277, 0.19236654799897224, 0.24589335545897484, 0.12828752864152193, 0.14264090219512582, 0.18103718874044716, 0.17660956538747996, 0.13959247124148533, 0.1384528144262731, 0.1124236841860693, 0.10180343218962662, 0.09271814196836203, 0.13169799407478422, 0.15742853604024276, 0.12693805183516815, 0.18306653219042346, 0.09216397287673317, 0.13374633650528267, 0.12180142512079328, 0.17050124472007155, 0.10091624659253284, 0.17520830151624978, 0.14878318354021758, 0.15958567732013762, 0.17487062432337552, 0.12852767278673127, 0.11585529340663925, 0.11405168901546858, 0.076448617328424, 0.11256153811700642, 0.18796810589265078, 0.12172282426035963, 0.10612000798573717, 0.2456287798122503, 0.12482704245485365, 0.19678091659443453, 0.11417018773499876, 0.11771303004934452, 0.08601667461334728, 0.17010860407026485, 0.14994688594015315, 0.1737262326059863, 0.16033422230975702, 0.19323834887472913, 0.08182257544831373, 0.10607200587401167, 0.18960224086185917, 0.15871023992076516, 0.16315205313730985, 0.17166773759527132, 0.10067783165141009, 0.10669264171156101, 0.10089270566822961, 0.13232895318651572, 0.0965795734373387, 0.22955115971853957, 0.11754991341149434, 0.1640394242713228, 0.10674715245841071, 0.13616177486255765, 0.09034623799379915, 0.22248809575103223, 0.14654814644018188, 0.11902900630957447, 0.17546962655615062, 0.15980897471308708, 0.14528156752930954, 0.07872850241255946, 0.10664909990737215, 0.1426395366434008, 0.15253849531291053, 0.10412266594357789, 0.12558523536426947, 0.09832044408540241, 0.13642033911310136, 0.14466157736023888, 0.1180885048233904, 0.1582429837435484, 0.13711326755583286, 0.27256887406110764, 0.11869849826325662, 0.11993612599326298, 0.2769193734275177, 0.11211014905711636, 0.13042311795288697, 0.09239073609933257, 0.16304312070133165, 0.24458943167701364, 0.1199466570687946, 0.20387210795888677, 0.14357053121784702, 0.2326238589012064, 0.1158236556511838, 0.16123297798912972, 0.19372320879483595, 0.1658520902856253, 0.14613337494665757, 0.11440541144111194, 0.10332300924346782, 0.12001468232483603, 0.11638989206403494, 0.11299401725409552, 0.10877962035010569, 0.14285931625636294, 0.15067613509017974, 0.0989495032990817, 0.13808718795189634, 0.1504264320828952, 0.07306494342628866, 0.18353056744672358, 0.17521046858746558, 0.10738335113273934, 0.1401993105537258, 0.3687365778023377, 0.13492084457539022, 0.12579363043187186, 0.1437173131853342], [0.001699831041150901, 0.04769985724124126, 0.048120974097400904, 0.05724530499719549, 0.030021031270734966, 0.06766866150428541, 0.021850777593499515, 0.03894875982950907, 0.038124493512441404, 0.06282206610194407, 0.07060519885271788, 0.023715790994174313, 0.08090117684332654, 0.031202274331008084, 0.01334844437224092, 0.0227155855827732, 0.03758503749850206, 0.011211175951757468, 0.0059404496460047085, 0.03404511924600229, 0.06556704029208049, 0.058315734277130105, 0.05361471856303979, 0.05407202253991272, 0.020617216832761187, 0.033045821110135876, 0.007422718936140882, 0.03661234906758182, 0.0454436986183282, 0.024462337751174346, 0.04067290617967956, 0.020955608342774212, 0.02212469873484224, 0.0693575743935071, 0.10950529234833084, 0.033356447020196356, 0.0487167888059048, 0.05452994621009566, 0.037703666093875654, 0.030702209660375956, 0.020582508441293612, 0.012321740578045137, 0.05996065265208017, 0.034818811909644864, 0.0333202079491457, 0.011184538416273426, 0.06319998254184611, 0.028632680769078434, 0.07746562681859359, 0.024268501765618566, 0.10468143635080196, 0.03627826758020092, 0.061764334968756884, 0.039229529138538055, 0.03011675718880724, 0.06596180348424241, 0.021468682862177957, 0.06892304692883044, 0.028981111681787297, 0.04119555997021962, 0.0028444581585063133, 0.07748320087557659, 0.0590628432109952, 0.026636507609509863, 0.023319571337196976, 0.032847025722730905, 0.039506680477643386, 0.03556521580321714, 0.04794307016709354, 0.04603753550327383, 0.023079529237293173, 0.04255255844327621, 0.04228923702612519, 0.01703716508927755, 0.019463381286186632, 0.07187980037997477, 0.1464098843280226, 0.03446993570833001, 0.029972739721415564, 0.032798459578771144, 0.05405837815487757, 0.03793740179389715, 0.015893907002464402, 0.03342972668178845, 0.06916390353580937, 0.03776323086640332, 0.03861382487230003, 0.02730757238168735, 0.051893214258598164, 0.09256237259251066, 0.09429053767235018, 0.0537765215995023, 0.01791198279534001, 0.04166359540249687, 0.03943030606023967, 0.026699089212343097, 0.04341396183008328, 0.05360385723179206, 0.048910864134086296, 0.0454933408764191, 0.05490467883646488, 0.023686116219323594, 0.05111870152177289, 0.08383035208680667, 0.042724662489490584, 0.03790065806242637, 0.03236951306462288, 0.04703442536992952, 0.004774845956490026, 0.05412267411884386, 0.02495740776794264, 0.03788251997320913, 0.07807628076989204, 0.03718974367075134, 0.021001248569518793, 0.041758200677577406, 0.029406746361928526, 0.025602692185202613, 0.028760968416463584, 0.0779635708022397, 0.03351741885126103, 0.020530827132461127, 0.0690981195657514, 0.05773632845375687, 0.04086934153747279, 0.04205336394079495, 0.05062886550149415, 0.0655318476492539, 0.049888012872543186, 0.0603252252767561, 0.033274692032136954, 0.04317903869377915, 0.02256994652270805, 0.07427780568832532, 0.04560927547572646, 0.025567249067535158, 0.030451161510427482, 0.027507896593306214, 0.04529756974079646, 0.03502383020531852, 0.015892862429609522, 0.06369670940330252, 0.013033434224780649, 0.04433200592757203, 0.03091447873885045, 0.026076562753587496, 0.021745064223068766, 0.05912798522331286, 0.06890122036566027, 0.03568938082025852, 0.04125167375605088, 0.06508042890345678, 0.11364125166437589, 0.06043843619409017, 0.04271071753464639, 0.07446406249073334, 0.021777536894660443, 0.027104580149170943, 0.02771076266071759, 0.0787693947495427, 0.06639739222009666, 0.016679425789334346, 0.048929948461591266, 0.05150803590368014, 0.04099703917745501, 0.03586773374991026, 0.04817220084078144, 0.0062867338965588715, 0.058221529761794955, 0.017588784903637134, 0.04169489177002106, 0.09926254118909128, 0.041309438820462674, 0.033282050426350906, 0.016424746681877878, 0.019057259523833636, 0.03594873174733948, 0.06369163311319426, 0.04738911258755252, 0.002073062905765255, 0.011986819536105031, 0.012897617489215918, 0.017733529675751925, 0.019080312486039475, 0.0609568040817976, 0.010836514757102123, 0.02797460172587307, 0.05474920631968416, 0.0814219938183669, 0.04059864688315429, 0.049068963853642344, 0.04719369768281467, 0.016445114924863447, 0.04627940885256976, 0.015230374101520283, 0.054120651766425, 0.022637580295850057, 0.01481278986830148, 0.03001500132086221, 0.040246612843475305, 0.09104549695621245, 0.017571886201039888, 0.01925480624777265, 0.017607184599910397, 0.10055778926471248, 0.033014101718435995, 0.009921754663082538, 0.06520012990222313, 0.022799778525950387, 0.01716638042125851, 0.06111750873969868, 0.014021180832060054, 0.07903048972366378, 0.06822323877713643, 0.03951324106310494, 0.06770577630959451, 0.08262669245596044, 0.021533988146984484, 0.07685306554776616, 0.021264482784317806, 0.08226398262195289, 0.05401581969636027, 0.07562861093902029, 0.05620975665806327, 0.011323670696583577, 0.05787414156657178, 0.020453671604627743, 0.05120554022141732, 0.006347136368276551, 0.04754412126203533, 0.03131696212221868, 0.026742618028947618, 0.047856309392955154, 0.04385686814202927, 0.1163345278473571, 0.06512733263662085, 0.05531244445592165, 0.09784813388250768, 0.030972741042205598, 0.05243579842499457, 0.07606100843986496, 0.02071952560072532, 0.04112303358851932, 0.023818181398382876, 0.03920948744053021, 0.06381146027706563, 0.002415168401057599, 0.03299609350506216, 0.007068532668199623, 0.019983422716904897, 0.024849748115229886, 0.040965753942145966, 0.024436505445919465, 0.021787741425214335, 0.01947163211298175, 0.030786679053562693, 0.016458000463899225, 0.017463734875491355, 0.030109211402304936, 0.026578404867905192, 0.02652702412888175, 0.03996702725999057, 0.0319349039637018, 0.0490049016661942, 0.0061980435384612065, 0.0350460983463563, 0.04147554631344974, 0.08707906643394381, 0.010204109385085758, 0.07166182418586686, 0.05542855717067141, 0.030313099778140895, 0.0460399994335603, 0.010824388064065715, 0.0747295435576234, 0.07408636127365753, 0.047806173606659286, 0.02669505192898214, 0.06677655546809547, 0.02037345100688981, 0.02535353836719878, 0.01526657606518711, 0.005641940224450082, 0.024181663065974135, 0.05599591422651429, 0.054174446340766735, 0.034349774578004144, 0.04923893422528636, 0.021330741728888825, 0.02828335371305002, 0.004922069038002519, 0.042039860563818365, 0.02185034900321625, 0.038564750357181765, 0.005787467962363735, 0.031087263705558144, 0.056665338852326386, 0.04591564145812299, 0.08933601915487088, 0.05172621618839912, 0.030725023279956076, 0.058776485529961064, 0.06699280987959355, 0.0324976522824727, 0.028271542432776187, 0.01173609607576509, 0.03437537125137169, 0.05490332070621662, 0.03633685271779541, 0.009660887899372028, 0.015028006200736854, 0.008896423842088552, 0.037789918496855535, 0.02212694558693329, 0.018752138494164683, 0.031400576190208085, 0.027136453536513727, 0.016470104892505333, 0.0435687255958328, 0.03398938395548612, 0.012003106894553639, 0.03438313040533103, 0.030503950474667363, 0.05476339618326165, 0.03053648251807317, 0.048280728806275874, 0.01839973709138576, 0.05395656291511841, 0.04328117676777765, 0.09076572212507017, 0.02286724717123434, 0.017279988387599587, 0.02260467161249835, 0.10129423724720255, 0.025584411232557613, 0.025733393667906057, 0.024336849855899345, 0.04217636749672238, 0.07265407562954351, 0.05055034256656654, 0.06217508402187377, 0.03805112108238973, 0.04164316407695878, 0.01753313681547297, 0.02630504033731995, 0.004237304219714133, 0.040968243847601116, 0.03184908571711276, 0.023803924741514493, 0.04357291130872909, 0.01894169228762621, 0.028081261334591545, 0.11944290206884034, 0.18412612611427903, 0.15305899316444993, 0.10743631821242161, 0.08330395416123793, 0.08645686466479674, 0.09204175599734299, 0.06949237067601644, 0.1590447555645369, 0.08161587247741409, 0.12113760370993987, 0.08294130369904451, 0.14216514100553468, 0.08559828143916093, 0.11564858301426284, 0.1635062653804198, 0.1232015312416479, 0.1332972481031902, 0.1650788466213271, 0.1337716734269634, 0.18930925580207258, 0.14850303763523698, 0.11494823309476487, 0.0816874897282105, 0.27851003338582814, 0.084873047308065, 0.07276666685356759, 0.14139954146230593, 0.3331297868862748, 0.09209339463268407, 0.1694223697995767, 0.1472597918473184, 0.07914728892501444, 0.1946006648358889, 0.20372381201013923, 0.08876587904524058, 0.13554726174334064, 0.15010134171461686, 0.07964886943227611, 0.07822409432264976, 0.1336142045329325, 0.1103869934740942, 0.15124950354220346, 0.09655857807956636, 0.15036429947940633, 0.1209727801324334, 0.1440161612117663, 0.15495678351726383, 0.16032478219131008, 0.07770620883093216, 0.0978286970348563, 0.07678837253479287, 0.2027645564521663, 0.15160882176132873, 0.08971151619334705, 0.1063733029877767, 0.13166076794732362, 0.16115131205879152, 0.17970852175494656, 0.16846596408868209, 0.15889691974734887, 0.17236091836821288, 0.1827250255155377, 0.12564120814204216, 0.18434912664815784, 0.13506091752788052, 0.1290445786435157, 0.07658621892915107, 0.10086293812491931, 0.21283401612890884, 0.102924683742458, 0.17296167206950486, 0.12581196147948503, 0.11819320701761171, 0.1163604659086559, 0.25465595244895667, 0.23532799270469695, 0.1839690876659006, 0.17826456954935566, 0.07863879902288318, 0.12297302397200838, 0.05793602926132735, 0.14436771656619385, 0.11700690622092225, 0.1255824597319588, 0.1128065655939281, 0.09821407948038541, 0.09236700221663341, 0.18019133334746584, 0.24467436305712909, 0.2301683890982531, 0.1820283121196553, 0.1418435387313366, 0.1768276232178323, 0.1415109378285706, 0.10256506866426207, 0.08064325083978474, 0.17697419738397002, 0.1683028697152622, 0.16050877544330433, 0.2988783654291183, 0.11533766766660847, 0.13369989290367812, 0.17803520138841122, 0.1391777888056822, 0.1587435623514466, 0.1912031721440144, 0.21645578584866598, 0.10375717305578291, 0.18091267120325938, 0.145738092251122, 0.09500363768893294, 0.13957081537228078, 0.17776449560187757, 0.1480072087724693, 0.15078803611686453, 0.1205363824556116, 0.08133533323416486, 0.11683268705382943, 0.20207435911288485, 0.14379370986716822, 0.11521526525029913, 0.3541057894472033, 0.15078778378665447, 0.10889846787904389, 0.1495213236194104, 0.14827730599790812, 0.1534563093446195, 0.10265579621773213, 0.0991104454442393, 0.1534739724593237, 0.2312419650843367, 0.08212542365072295, 0.11352760659065098, 0.1099195220740512, 0.09156249187071808, 0.12673363467911258, 0.1321335308603011, 0.11781220324337482, 0.227333756047301, 0.06641328902333044, 0.13398272538324818, 0.10447518608998507, 0.10478165597305633, 0.11587704575504176, 0.16540355107281357, 0.12684133514994755, 0.1750822106259875, 0.15222118265228346, 0.23478113376768306, 0.16333718929672614, 0.1490106518031098, 0.15947117877658457, 0.10346536058932543, 0.14183779450831935, 0.13003086321987212, 0.30727431178092957, 0.14066095609450713, 0.17649557150434703, 0.17170861508930102, 0.11515891397721134, 0.0839095540868584, 0.1291219549602829, 0.16455192177090794, 0.11867204069858417, 0.09029782770085149, 0.15061664453241974, 0.1444495902978815, 0.17887624766444787, 0.058641358991735615, 0.12925830233143643, 0.1316837448393926, 0.1198297094379086, 0.10707492197980173, 0.09508108079899102, 0.10629467244143598], [0.06107145847636275, 0.012201474619359942, 0.03643860858574044, 0.021762790420325473, 0.04645628861908335, 0.031439672529813834, 0.03072861898544943, 0.045859290185035206, 0.03880495387420524, 0.03253798800869845, 0.029860625327273738, 0.0021811502210766776, 0.042520004135440104, 0.03965810828958638, 0.018804504434228875, 0.03666253680421505, 0.06564766721567139, 0.05991364501824137, 0.04732182947918773, 0.042728748012450524, 0.056670400299481116, 0.05144365830346942, 0.10864343625144102, 0.009511707867204677, 0.022843006772745866, 0.03101304708252428, 0.031013015541248024, 0.012636499322979944, 0.049447548226453364, 0.013985735859023407, 0.033558648865437135, 0.03632317493611481, 0.029905402807344217, 0.03419274355110247, 0.05191135605855379, 0.08548707803129219, 0.05195363250095397, 0.06849450117442757, 0.03502318824757822, 0.03733594676305074, 0.060759058833355084, 0.04379871716082562, 0.033486456450191326, 0.02963348917546682, 0.060223417458473705, 0.13852863223291934, 0.04090843416634016, 0.06336701029795222, 0.06839125358965248, 0.013898732031520922, 0.04123099381104112, 0.0247919589310186, 0.09690008475445211, 0.11365061756805517, 0.007434084463966428, 0.06235895853023976, 0.00413446899074188, 0.030161621871229727, 0.033388659940101206, 0.030036061616556253, 0.06240883085411042, 0.02872669603675604, 0.016574751425650902, 0.0849012414983008, 0.03000009157403838, 0.03130470555333886, 0.03890952990332153, 0.04023976653115824, 0.030148077676130924, 0.024649127044540364, 0.03512512594170403, 0.03167582020978443, 0.02872916553315008, 0.015155680648604175, 0.06853117811260745, 0.03892471424478572, 0.02777195088128792, 0.0883239226823207, 0.04014165831904393, 0.038538218577741645, 0.020232708266121335, 0.03815330739598721, 0.032247555936919525, 0.0498504082497675, 0.03292858775239438, 0.03472514545137528, 0.01659079109231243, 0.022703252943756524, 0.04662715698941611, 0.018056388034892734, 0.04164644065895118, 0.029372733733907808, 0.037440953237819485, 0.025658880185801536, 0.0361898109986214, 0.005148368418304017, 0.021960723061056342, 0.057615577316028066, 0.042755762187880464, 0.06943121770746075, 0.08516668545780703, 0.08931945441872813, 0.04027242845040746, 0.05183802073588595, 0.022952527360757813, 0.056282494551851414, 0.06257110886508599, 0.0750172816333361, 0.031447925211978145, 0.05976379427011125, 0.02792529900034424, 0.04273815473425202, 0.019814717707049567, 0.023192255903268233, 0.026367668324382976, 0.0472614817408612, 0.03078931553318398, 0.036168143997201696, 0.028661715441558044, 0.035380309709580615, 0.05089914826385211, 0.031383729437948205, 0.0627529647317715, 0.016649452300043777, 0.11936075374251232, 0.08295337844174355, 0.03029002640687395, 0.02140991960914107, 0.0447264685499249, 0.08734157891012728, 0.08004172530490905, 0.04913216886052396, 0.07759764746879227, 0.03852803631161805, 0.029051079509372357, 0.009536753495922312, 0.032605130109004676, 0.010435547210363438, 0.03145685695926659, 0.019308999726490583, 0.07750270451651886, 0.06852258404251188, 0.007632144197486923, 0.027959515718976036, 0.03357730645802803, 0.014103671474003932, 0.0439659935364034, 0.021919628488831222, 0.03287470040959306, 0.015540115000476362, 0.04869938544288743, 0.06573673977982253, 0.014820519336353755, 0.044763824553228915, 0.025070479532587342, 0.10221850054222159, 0.06059022394765634, 0.011066850493079983, 0.0061115851895010564, 0.0271547845841269, 0.02125553619407583, 0.015462241444765823, 0.037093821083544753, 0.011902115438715555, 0.08097181445918977, 0.02502427527360851, 0.040076267687254585, 0.017023223845171742, 0.03278988406236749, 0.019372573951841332, 0.0471325410035206, 0.03169119379890617, 0.06361476887832396, 0.03607509352150373, 0.013298027497512521, 0.012194595838082023, 0.04430796405358706, 0.044223823060747236, 0.01097019874578109, 0.08160638040862978, 0.03196382174792234, 0.05856498086359352, 0.038905856272322126, 0.08254573156591505, 0.015666021281504072, 0.055728459046804346, 0.12356276420177892, 0.02431110475299647, 0.027504809258971363, 0.06061260341084562, 0.05885313083126675, 0.057394654795643874, 0.03699713037349284, 0.07078819762682542, 0.03356967346917372, 0.02222400737082353, 0.02398069318587659, 0.03609046711062547, 0.05698351240425836, 0.023229218568303622, 0.04495126508118119, 0.024748860560066532, 0.030862658277328592, 0.04443726473255083, 0.11657189636025578, 0.09616676121368073, 0.007487934235541616, 0.014396647256944561, 0.07245773304020986, 0.03335216853884049, 0.03066657172894338, 0.05316003065672703, 0.061768810119247064, 0.016928644545259885, 0.014245943966670893, 0.031064633767527994, 0.04428320600709412, 0.04628172064258251, 0.026539520040387288, 0.042759836578625254, 0.04564809350995347, 0.005113252773298882, 0.016282120741379913, 0.04717012336186599, 0.02031873616942903, 0.019904957298422232, 0.016529445165360812, 0.014438937614613678, 0.04870569740887731, 0.011524923520482844, 0.03711737314006314, 0.02926669938460691, 0.08267144396086223, 0.0656487952801399, 0.013751071546721505, 0.007823910982551752, 0.028706483644782566, 0.012461189198802458, 0.06045517533493694, 0.041410897829337046, 0.019440591786406003, 0.04519651520240586, 0.07631663378560916, 0.04740610776934773, 0.018910256767412648, 0.0306658370027435, 0.039680183472228236, 0.05547730143007357, 0.04470825253520161, 0.04611527176166419, 0.04332287804572843, 0.07520187602494843, 0.04445204460353125, 0.005235786456978531, 0.09785792281036265, 0.032354658978874795, 0.031943449794198386, 0.03641645918833092, 0.014302559629868483, 0.05672354549460579, 0.010772234563773964, 0.046578175242757425, 0.02514875384804327, 0.04795654385816306, 0.041819375910563394, 0.08374993296456523, 0.00954223147346056, 0.017671595596766565, 0.038957955039222725, 0.004378286766950623, 0.051116400863975286, 0.01958232343895361, 0.054759915510658175, 0.05123755647218786, 0.047325017003458925, 0.03438802115852013, 0.03306209640868474, 0.0569363414979307, 0.08858077999320813, 0.014035066415090114, 0.07011830544797704, 0.013458126377372537, 0.043467110735946335, 0.06833685416495427, 0.01711781798803713, 0.041298640571767464, 0.038866010363562964, 0.018013375010923482, 0.02366782970057102, 0.05376551183871925, 0.010863452862395206, 0.06455412003560923, 0.007152298412620439, 0.023563715658383444, 0.008197671395464567, 0.026729478304332588, 0.04296707389585208, 0.02072588395094499, 0.03187769551004749, 0.04440249511389993, 0.02263422022224404, 0.04136072864639573, 0.08090560746495612, 0.03798784557147883, 0.0558423601614777, 0.05853131333424244, 0.03349201513628941, 0.0604583925451152, 0.05632541295199189, 0.02519510282581905, 0.028756619431078434, 0.016880007897270843, 0.02063236963294912, 0.016554635512875393, 0.04136344861763064, 0.01902881485875696, 0.03796693556068931, 0.053739043141831644, 0.03587860621337313, 0.02087342847516993, 0.01060295253410004, 0.019652105729619507, 0.034406500635668635, 0.08001954993233085, 0.033837347582448274, 0.029136547091184184, 0.035494882467901334, 0.059541205628192984, 0.004744799180116388, 0.021106312560732476, 0.04674043841077946, 0.04274403996532783, 0.06142053134681191, 0.06615542981307954, 0.035065301417489536, 0.02775356602796819, 0.05325125915987883, 0.049019607322406955, 0.013449668676912552, 0.020834244933212176, 0.021992414622218348, 0.029120436920493376, 0.01784568859875435, 0.05825604333949741, 0.03568477579392493, 0.02278013573231874, 0.02439606952975737, 0.04271142628567759, 0.047491543809883296, 0.01133638461396913, 0.04567283671349287, 0.023464035948563833, 0.21254607767332345, 0.1540804110118188, 0.14451699214987457, 0.1912774462834932, 0.256819401984103, 0.14888877631165087, 0.19173272419720888, 0.2978741505648941, 0.13112864806316793, 0.10437412784085609, 0.24118275119690225, 0.104447889898438, 0.08201725562685169, 0.13431731524178758, 0.18777442019199952, 0.25153409340418875, 0.13057435280643404, 0.13917882781242952, 0.18142577726393938, 0.13388446503086016, 0.1298181340098381, 0.10881375914323144, 0.3717942856019363, 0.08160484416293912, 0.14904649753589183, 0.2182039147010073, 0.13937818352133036, 0.259809693088755, 0.15828573144972324, 0.17290641175350174, 0.07283346014446579, 0.17157401918666437, 0.11884028557687998, 0.13150362559827045, 0.2547666215104982, 0.24148349912138656, 0.15335479838540778, 0.07242962048621848, 0.10648047653376125, 0.13157935434719548, 0.15457796165719628, 0.1171574360341765, 0.10817857721121982, 0.10864866839256138, 0.1426129083847627, 0.29757001844700426, 0.10402006402728148, 0.11445411859313026, 0.12528813880635425, 0.10168355307541788, 0.13381167518673465, 0.1053454061911907, 0.13601981685496867, 0.18745589040918276, 0.08383663807762787, 0.07532810792326927, 0.2858516847481951, 0.14089951204368845, 0.102520643704338, 0.10181184072280303, 0.12271928368136287, 0.0678981261444278, 0.11667354090604931, 0.1465870498213917, 0.21634197008097544, 0.13896416901843622, 0.2156757886405103, 0.13091864995658398, 0.21306899492628872, 0.10166139996726997, 0.09669122213381343, 0.17126712627941743, 0.13107114646118134, 0.19015530415344983, 0.18091584759531543, 0.16543424630071968, 0.10066641742014326, 0.20828476961469278, 0.2181013350491412, 0.0766731244220864, 0.09026359985000454, 0.13957446673884988, 0.16127715061884373, 0.155659255979117, 0.11638097887043841, 0.15326447901315987, 0.08251053892308846, 0.13389283645665273, 0.14107799855992198, 0.17424616642529145, 0.13617327815154567, 0.16535977920284495, 0.15821614768356085, 0.11427802179241553, 0.16536343056941405, 0.08039367399760522, 0.1401635241927579, 0.16641088295727968, 0.1459845298086293, 0.14451445400482044, 0.16617366287391633, 0.24485498695867136, 0.192717079189606, 0.1284049215610139, 0.09282463273848407, 0.18191053328337148, 0.12920976587338373, 0.2292999575729482, 0.12040266970871016, 0.1582318069995381, 0.04484505632717628, 0.053448444086825475, 0.08005875759408809, 0.2000410674372688, 0.11464492476079613, 0.14599965477827936, 0.19505395379383117, 0.11909972556168213, 0.08990215908852406, 0.07956257250043564, 0.1276239744038321, 0.09559212368912995, 0.13382417295360938, 0.1324465242214501, 0.27949946466833353, 0.1750264159636572, 0.23264049785211682, 0.0774642761098221, 0.14127045229543, 0.1736633133259602, 0.22408010641811416, 0.163426365761552, 0.16673068923410028, 0.13667145220097154, 0.2252643069368787, 0.09382828357047401, 0.12205562554299831, 0.09679944952949882, 0.13644803606439382, 0.07051056018099189, 0.14899748610332608, 0.17628683504881337, 0.08760169424931519, 0.16308018355630338, 0.11140314949443564, 0.08754848226089962, 0.16954028222244233, 0.2075701704598032, 0.17736297886585817, 0.0881802206276916, 0.08552433384465985, 0.10971665600663982, 0.12904042261652648, 0.10215092799626291, 0.12503128149546683, 0.21071003400720656, 0.19779074209509417, 0.1270172093063593, 0.16684239730238914, 0.09458673623157665, 0.14887169207213446, 0.09798477811273187, 0.1363096700515598, 0.1086578710237518, 0.13005612592678517, 0.17725173092912883, 0.1581835822435096, 0.14736021927092224, 0.13183546951040626, 0.11146811710204929, 0.15412078384542838, 0.12389771029120311, 0.22416493389755487, 0.05847765976795927, 0.11951555832638405, 0.12284037249628454], [0.032805439477670006, 0.009837096022238256, 0.04439951168023981, 0.018516629061196, 0.017282404078287072, 0.05466803762828931, 0.04918745515169576, 0.010103405511472374, 0.038593085555476137, 0.05699514185835142, 0.04495448600209784, 0.0552671734476462, 0.024604787431599107, 0.06357959849992767, 0.024458628868160304, 0.07284582432475872, 0.09261827857699245, 0.07141526788473129, 0.01482559748183121, 0.059584331829682924, 0.017961665871553123, 0.06625810594414361, 0.028537099569803104, 0.06142053134681191, 0.038654535383102484, 0.031651162353227846, 0.03689775308885146, 0.06765981510397978, 0.028819223298341967, 0.060050834727007896, 0.02724102399952244, 0.023421351324941497, 0.022205364621186163, 0.06771551328711212, 0.03225801279768348, 0.06482113734818995, 0.039072527797543444, 0.02160764815926086, 0.04442389494215604, 0.05247416003840044, 0.08214330198825337, 0.029784839061903767, 0.04648985595849808, 0.05092386178148445, 0.0366092320473399, 0.028756090650858823, 0.019457184353086632, 0.028036736184731126, 0.006597261008209898, 0.04127655796764884, 0.0805492207291536, 0.04224879368848633, 0.013274225893837865, 0.00513759614477749, 0.04482265831029508, 0.021707133055315353, 0.03816199052380398, 0.06938986523891799, 0.040296648439834826, 0.03300523305370007, 0.045220134052215144, 0.024947763558884617, 0.0499761837272672, 0.03170195494021755, 0.016861164767760783, 0.10421475162729621, 0.02236404692666838, 0.045846677385270596, 0.03949780068069231, 0.029319083878363017, 0.050750551745295525, 0.04875050457485486, 0.018067314304062165, 0.029745776118943468, 0.027109400398330763, 0.06103800988057628, 0.020908378064632416, 0.0338654044753639, 0.10334165941458195, 0.03789885464357212, 0.04293372177926358, 0.09342866673250683, 0.03836031835817266, 0.032182339709834196, 0.05537979806831572, 0.12543385208118707, 0.02569472220784519, 0.04129549386561848, 0.07037266914267093, 0.06665188950137235, 0.10864840864087455, 0.0011826483864751935, 0.01775467531842878, 0.022910492116352543, 0.023998042743187398, 0.02187699210480787, 0.06481312957475893, 0.05246614484349266, 0.008800101422821172, 0.10476867581019178, 0.012970528860023478, 0.015973264853528235, 0.014888303394400282, 0.003298799806543684, 0.032149347534868866, 0.01682900750893168, 0.07778965591569431, 0.021969677072775085, 0.03275158924225252, 0.06778712311643176, 0.011089669678767677, 0.013850501709384844, 0.03311456624942366, 0.0703735374554526, 0.0739898078609258, 0.04556794527161401, 0.07005566076259129, 0.029891789963585325, 0.06542356830323115, 0.029776083574688528, 0.009326853723905515, 0.03846236737444997, 0.04815928747120779, 0.04601598353474401, 0.017428076534997672, 0.04073813353898004, 0.05940996423305478, 0.05413832601334434, 0.02967959881061688, 0.04367939836811274, 0.015391935939987889, 0.049511539909872226, 0.03937278590456117, 0.0907916082360316, 0.08506151571054943, 0.0458818217884982, 0.014940689743525581, 0.06299542437773198, 0.0373456948727835, 0.048647357180016115, 0.02486416618921794, 0.021221076422079932, 0.020868318788416218, 0.03727516857907176, 0.04381809463666286, 0.05068786624178756, 0.05769674600742292, 0.0758986859000288, 0.045421248651109636, 0.005018937399654533, 0.02654273725056555, 0.02850341348676011, 0.06678584715700708, 0.013042866921750829, 0.05550953661440872, 0.023460067313862965, 0.012342290647211485, 0.033205345753231086, 0.03930247854441404, 0.06368659393046983, 0.08427526961895637, 0.05683014758687932, 0.007186043867477565, 0.021736306880484335, 0.04093138508324046, 0.06069435468816664, 0.03644883538072463, 0.02906177756813122, 0.028660257121373434, 0.03146822295093443, 0.040937671074061655, 0.13001618353882805, 0.062031548950471915, 0.06175300237373449, 0.03208270267350599, 0.009450061370444018, 0.03876413946272805, 0.01545903536680271, 0.017918689954967704, 0.007214075712909107, 0.05460358952404931, 0.019618024452938698, 0.034817034465959296, 0.03362333445693366, 0.054137056940817274, 0.07712380844168365, 0.055652440860285424, 0.05513327145308722, 0.032000023711589165, 0.049735033971956, 0.023504226955992635, 0.040461227108608, 0.05011340312194079, 0.052060453526792116, 0.053743392127216794, 0.026828146837942768, 0.01449887717171805, 0.035708298164536245, 0.02102778962580487, 0.05862246391188819, 0.07051226712064818, 0.07975186468684115, 0.037100878907949664, 0.022400824054784607, 0.010107565249199979, 0.03230254165828228, 0.08959254992078058, 0.05174300727958325, 0.012390816900733626, 0.03625010678661056, 0.025231456929759588, 0.054237287695286795, 0.04793168562173378, 0.025976933138736058, 0.01664942075876752, 0.05685615986294579, 0.022590513290197123, 0.006121533215264208, 0.07053236447973177, 0.0664704195514787, 0.03580699638405349, 0.014408940005523618, 0.018593157474242616, 0.0432732432091143, 0.07008291984675452, 0.010447994882269995, 0.061947259528096765, 0.056900187773862854, 0.03349915088620037, 0.05223558553552721, 0.00705260061295121, 0.019249327342549805, 0.04116100557439495, 0.09248275498976, 0.07302959493244998, 0.039445594302378595, 0.03032249351235805, 0.020355773049232084, 0.06325734313577414, 0.03670682817755733, 0.051107149993185885, 0.1001123151218053, 0.041998155575129203, 0.025104037595156115, 0.05225989087193739, 0.07240691818878986, 0.06000760091410484, 0.05376617977162823, 0.012193577240395825, 0.02536011565098306, 0.011779534906963818, 0.025902506858983543, 0.07095863184076734, 0.03598638089897577, 0.051607090354082175, 0.007798678889230359, 0.0503313125227578, 0.08236571622546762, 0.022189376904862, 0.07089180886396207, 0.0476508049905533, 0.04068626854859758, 0.06449989872635342, 0.08318659834912978, 0.04498983078519814, 0.02024064368015388, 0.024661279712745454, 0.035609536862466484, 0.0464544852002291, 0.018593623171909712, 0.055581521228305064, 0.02740311832894804, 0.05566123902099207, 0.03628240505349822, 0.02200941351475194, 0.11128156344057061, 0.045460289329639636, 0.033408890885766596, 0.04444977734237909, 0.050874776134151034, 0.019341811930644326, 0.018425469206704292, 0.025232154548575636, 0.0692136274301447, 0.02275789356644964, 0.05237673831288703, 0.033115660917246714, 0.031729392139823176, 0.02981954559800215, 0.10270603961544111, 0.07724308641627431, 0.0486096263921354, 0.041209831470041536, 0.031560731658828445, 0.09690005506854504, 0.04754991743538994, 0.02602287393528968, 0.0586084966926137, 0.04564380018564407, 0.10218910407274961, 0.019892570853699, 0.024246189095720183, 0.02025983005296439, 0.05319514537404757, 0.039295814058277756, 0.06487611564807594, 0.01219089808728313, 0.03322877164464444, 0.09328744345111772, 0.05599931697361171, 0.04357708588941023, 0.02272988120239461, 0.07584781909827143, 0.020276259347156156, 0.024487711780238897, 0.011548629572644131, 0.07875168710597791, 0.02778985333861783, 0.03593998924770858, 0.06556265419931151, 0.06290706427535042, 0.043259468948235735, 0.054845615013618954, 0.01839160315284971, 0.038458222479675896, 0.02876318001653999, 0.03097518641880015, 0.009831549396039918, 0.05062450909463223, 0.04772211053932551, 0.011958593804592965, 0.013924391787440982, 0.05942496674833819, 0.024420163354079705, 0.05676410757587291, 0.022578477510251105, 0.03627963313192595, 0.023896400052763056, 0.02240478526800871, 0.07444989489158615, 0.00831329893117072, 0.017887742396851536, 0.03652165120001882, 0.039976474799914286, 0.020438585597730707, 0.05849068445968442, 0.03508256377244834, 0.11353642330504954, 0.055346141671179794, 0.05707286698452663, 0.013080316621199017, 0.02620727722387528, 0.1458319294033572, 0.07971774073666893, 0.1890653563896194, 0.13610918627819046, 0.18638167617609724, 0.12359216809272766, 0.13765706884441897, 0.08688106885529123, 0.22100926260463893, 0.18953948485432193, 0.1945432077627629, 0.1229114257148467, 0.18887878046371043, 0.2098520816070959, 0.11233453740715049, 0.3054184082429856, 0.19221891998313367, 0.1719985276577063, 0.12940005253767595, 0.09174230683129281, 0.10884396455367096, 0.16869571816641837, 0.11568396119400859, 0.16749504196923226, 0.10976596429827623, 0.23242919356562197, 0.1162845961516723, 0.1588274398818612, 0.13854289631126449, 0.09411879727849737, 0.12942807603394613, 0.12170999252703041, 0.11918309843167663, 0.24889813328627497, 0.12036861255182885, 0.1483179460046813, 0.12947833427460864, 0.11403901313315146, 0.12360588298179209, 0.1453974167816341, 0.19768255180679262, 0.1578278560191393, 0.14539907919242978, 0.11264636559644714, 0.10424955835333094, 0.10523139004362747, 0.07798261431162246, 0.12784565391484648, 0.17786850017728284, 0.14939780056010932, 0.14658228523330763, 0.1020497213175986, 0.11470069715869613, 0.12227868544869125, 0.10245350160403177, 0.10280918329954147, 0.1912635681219399, 0.11228888048208319, 0.14558835653588176, 0.11293022223981097, 0.11947412422159687, 0.06988441760768183, 0.1282145458390005, 0.07909121224656701, 0.05106866221467499, 0.20114302315050736, 0.1740394634543918, 0.11676454305415973, 0.1222123003390152, 0.2071613509906456, 0.1038023698492907, 0.15435481269378215, 0.07782995453453623, 0.14950137468986213, 0.16038497036788613, 0.11800076812505722, 0.10724564563133754, 0.09614477879949845, 0.17894643999170512, 0.08490063293720596, 0.12168426968855783, 0.3281836991664022, 0.13313529663719237, 0.2475148145458661, 0.2249592842417769, 0.23601611203048378, 0.13139688991941512, 0.1246555321267806, 0.21501784503925592, 0.17419687297660857, 0.10234402740024962, 0.18284988444065675, 0.18907858146121725, 0.08445746687357314, 0.10728650086093694, 0.10029263474280015, 0.1399964964366518, 0.09279643854824826, 0.11521512424224056, 0.2790472295600921, 0.07573162103653885, 0.15107734012417495, 0.13583476975327358, 0.268020280636847, 0.13982958742417395, 0.09804631699807942, 0.15925316547509283, 0.14750352798728272, 0.13306166074471548, 0.18617387482663617, 0.08915062324376777, 0.1299012842355296, 0.04536227759672329, 0.22535239986609668, 0.2614476130111143, 0.13774349936284125, 0.1602803127025254, 0.1194716825557407, 0.20931196137098595, 0.09389785249368288, 0.17575844074599445, 0.1547875886899419, 0.14094396668951958, 0.3071398049360141, 0.0694476043281611, 0.11756135732866824, 0.1580868210294284, 0.09909670829074457, 0.1815091204480268, 0.10469167056726292, 0.12219773198012263, 0.15540032065473497, 0.1970290462486446, 0.1389546992140822, 0.175894342828542, 0.16315451706759632, 0.15493255981709808, 0.16287061589537188, 0.10106707326485775, 0.10636246763169765, 0.12627437885385007, 0.09515477606328204, 0.07197668033768423, 0.19188143574865535, 0.14554841414792463, 0.15012933552497998, 0.13418605900369585, 0.19023049855604768, 0.09649133950006217, 0.09246116591384634, 0.0848195978323929, 0.10022202681284398, 0.12329343138844706, 0.11444231102359481, 0.11764642971684225, 0.10157910321140662, 0.16458974161650985, 0.10298575507476926, 0.16696648439392447, 0.09700284994323738, 0.18180982384365052, 0.15637829317711294, 0.07397547698928975, 0.11575571945286356, 0.2105788519838825, 0.1972739104530774, 0.15956189890857786, 0.09917001763824373, 0.12262847449164838, 0.1297115022316575, 0.1456539030186832, 0.3897997085005045, 0.10349805219448172, 0.16911218175664544, 0.07662418720428832, 0.08715711810509674], [0.029482039099093527, 0.09927730250637978, 0.05255827876680996, 0.01157906133812503, 0.08839903544867411, 0.02767281108390307, 0.01151424123236211, 0.0020442835784706404, 0.01392662750731688, 0.023988821558305062, 0.02230095509730745, 0.029408341979433317, 0.025640148378442973, 0.010708171448641224, 0.03498483405564912, 0.06819796864874661, 0.021832895545230713, 0.04936827943311073, 0.02069322388706496, 0.02374299627263099, 0.06962713727261871, 0.040458959847455844, 0.07466788592864759, 0.037945587682770565, 0.03768693066376727, 0.05767850401753094, 0.010752590842457721, 0.03153257457597647, 0.030405263387365267, 0.09528471127850935, 0.05978919427434448, 0.02560290740802884, 0.03553430535248481, 0.017326712149952073, 0.03732459190359805, 0.05562362326600123, 0.008441397330898326, 0.08248486803495325, 0.022466326008725446, 0.00994301626633387, 0.01801205213268986, 0.033736704936018214, 0.010904600312642287, 0.054175893528736196, 0.024628482351545244, 0.05120600406371523, 0.042478484683670104, 0.06942084248294123, 0.045365569021669216, 0.013481825935741654, 0.08248687925515696, 0.03648199082817882, 0.05220717241172679, 0.0389711726893438, 0.04536727967206389, 0.03459823448793031, 0.0373021159612108, 0.07047225793940015, 0.009691547875263495, 0.0361480466381181, 0.05682907889422495, 0.06820605805842206, 0.044595190047402866, 0.06856352832983248, 0.028605746374523733, 0.05494219069078099, 0.025778145172807854, 0.04906607689918019, 0.03010817054018844, 0.07005513383774087, 0.014664997652289458, 0.027177629744983278, 0.05353497850592248, 0.03351936327817384, 0.04125005958485417, 0.051604990076157264, 0.04230979080602992, 0.031842209718888626, 0.04375288212031592, 0.01707695162622258, 0.04598499886924401, 0.05520552324014716, 0.034045623906422406, 0.029754540883004665, 0.048938520267256536, 0.05250652880931739, 0.0291926924182917, 0.04723620048025623, 0.0293674904605723, 0.019798167813860346, 0.07380695009487681, 0.03665065873065032, 0.02669283847353654, 0.027754041002481245, 0.06036870399839245, 0.02729038238612702, 0.056285719183506444, 0.0011140098149553523, 0.10208104737102985, 0.039176487844088115, 0.06006106523273047, 0.010717893583205296, 0.02836176903656451, 0.0055502052055089734, 0.018194295771536417, 0.03277954223449342, 0.022096094508015085, 0.05536625387321692, 0.050749761358019896, 0.05848278058692813, 0.06469971456681378, 0.05635814166453201, 0.04293514670280274, 0.05941805364273023, 0.04066798574058339, 0.03401772286451887, 0.03049022259801859, 0.06118468794738874, 0.04100066827959381, 0.042692931965575553, 0.12626324663870037, 0.040814615567796864, 0.04285715440346394, 0.1001095023821108, 0.02312866497959476, 0.054764895321568474, 0.015954067348502576, 0.009005892479763133, 0.0073335995239176555, 0.07202678272733465, 0.006146277810330503, 0.043012292953790165, 0.021358390440582298, 0.029577282621175982, 0.038368159148376435, 0.04693713352025952, 0.060350992644089274, 0.018386508309049532, 0.03870386593916919, 0.04422576748766005, 0.042849669844144955, 0.03920180621207692, 0.022785659166402183, 0.0171974337354186, 0.016538330528419465, 0.09871860631392337, 0.013644515838677762, 0.041968837031163275, 0.00879239978530677, 0.031954248042893596, 0.04815140215214342, 0.04961487284163013, 0.06714733986882493, 0.024454246486129705, 0.03078682562772883, 0.056899315750342794, 0.08847802964737639, 0.036756689369212836, 0.04935772609314881, 0.08927228351240046, 0.08579952962463722, 0.017447038408135995, 0.04722465637314599, 0.03928331258066464, 0.018124097878171597, 0.056649019024916925, 0.03360481787240133, 0.1173223635123577, 0.07829407142708078, 0.04725587110442575, 0.010000223792303586, 0.04960567021043971, 0.011351997545716586, 0.013416687634162372, 0.06616374186705798, 0.02978219145006733, 0.02382658436545171, 0.044277150082052685, 0.04975553951226175, 0.070633986761095, 0.03942203853512183, 0.021135582865099423, 0.025231536710634828, 0.03215093573089689, 0.02911683750426164, 0.04175746224063914, 0.06591682191356085, 0.04978684701200109, 0.08488340768963099, 0.051088525797240436, 0.028604382678167894, 0.041490033036097884, 0.04634622069715988, 0.02388255528785521, 0.06545215583173558, 0.06047387374565005, 0.01926132601511199, 0.024621932898298837, 0.03837975520582404, 0.04324450725107454, 0.060677927249344066, 0.051110248459735885, 0.01867763614427531, 0.04746289319882635, 0.06312651734333485, 0.03133683683699928, 0.044875966777908616, 0.05265426814730745, 0.044390450057107955, 0.018958500077133067, 0.037661022288375534, 0.04957652978191618, 0.017850902186182793, 0.02688709006179124, 0.03284956386778504, 0.05584247890510596, 0.04809031597687863, 0.015655826027796138, 0.013950930988357868, 0.04780404364282731, 0.04871677025221288, 0.05008493804780301, 0.02588364703115076, 0.03498358724755235, 0.03788617505051661, 0.04163791338214651, 0.06967332112253644, 0.018930753030872438, 0.006004435763315996, 0.013658345760632074, 0.07672742736758664, 0.027881768328370526, 0.017586651229066774, 0.07219291248475201, 0.016467499954160303, 0.040361163337365724, 0.020336749948910438, 0.028743628135998733, 0.04351124254753813, 0.07029454325675033, 0.011272852134425193, 0.017481564973422792, 0.0471548722271109, 0.09087381593417376, 0.039479517872678116, 0.04030443356896285, 0.06839657478849404, 0.03574429974833038, 0.05982584894809406, 0.04034896985103842, 0.017051902286766563, 0.05093232226499822, 0.03816133743384853, 0.010663646298780804, 0.051709914914681576, 0.041512768730171956, 0.012596164524438791, 0.04570300872728694, 0.01633238083741162, 0.08030192970181815, 0.06063411456125323, 0.04850687975704204, 0.05721715904655866, 0.07702111004618928, 0.048724210282671265, 0.05626228215987794, 0.026451443809492048, 0.018271514381922316, 0.0508170407556463, 0.04296661376429256, 0.045017624215688556, 0.04825392985367216, 0.047490716315223835, 0.0645802658982575, 0.014582351159333484, 0.0489844517869642, 0.026868534514505882, 0.10139499863726087, 0.028512439857877325, 0.016773298193584196, 0.01826010200602468, 0.035187518296879716, 0.038367034794646315, 0.06127267326519359, 0.020424709291546606, 0.02433104997180635, 0.054954911101958714, 0.049166155513376, 0.015390560183732305, 0.04130393579544034, 0.02659067999047693, 0.029534609129768796, 0.01223860797836096, 0.06488033846835606, 0.05952286344836466, 0.08135601688991301, 0.03310361957119312, 0.02974561841256218, 0.04543611757981125, 0.10188086787820794, 0.05377446213969961, 0.054665744391968474, 0.03700710854900535, 0.03673867744510062, 0.07100765811628662, 0.042197971415589564, 0.007851825012039626, 0.03284440223069396, 0.05014223184844013, 0.04156466711719986, 0.02556306149926968, 0.07229745140648447, 0.03433765159570612, 0.013694264780497178, 0.07038587937131524, 0.04166745457041543, 0.05439348751679063, 0.05649199170875363, 0.03403838425583672, 0.059485229139681906, 0.09400979804922827, 0.048019025271059945, 0.01938721467013238, 0.05567432308453135, 0.08349574738531373, 0.020458631006476935, 0.04826573742320761, 0.05150275923369918, 0.060195405094418675, 0.047267801128327847, 0.035850734857376665, 0.07171574121457525, 0.03697081752761733, 0.05712671721994411, 0.033720503852237016, 0.02272616304253461, 0.02278783736983314, 0.0308682336617494, 0.026147732860408723, 0.009731104346428765, 0.0222806054080138, 0.027594989478529897, 0.024383670097449794, 0.03507743553200271, 0.028243789820407983, 0.10201550830970518, 0.03228173925890587, 0.09040342047228478, 0.05282528494717553, 0.05760588857810944, 0.060865623818244785, 0.040564096198068, 0.1344917347887531, 0.19937530159950256, 0.16450446884846315, 0.2911411493550986, 0.1332021047710441, 0.11966021775151603, 0.1260576568893157, 0.15215826337225735, 0.10181437144638039, 0.15319158526835963, 0.19071357732173055, 0.11588295325054787, 0.1797582011204213, 0.14923129230737686, 0.07734440441709012, 0.2650965750217438, 0.24458070402033627, 0.11677988324663602, 0.10630528515321203, 0.12857989029726014, 0.08796491616521962, 0.08745194369112141, 0.15082079451531172, 0.13493447040673345, 0.11913689973880537, 0.2066814189311117, 0.1296385342720896, 0.1418355235364288, 0.16014877444831654, 0.1721163807087578, 0.10691382398363203, 0.15067626867676154, 0.1386541739339009, 0.07438900909619406, 0.147746343864128, 0.17959561140742153, 0.1620367239229381, 0.18806436244631186, 0.08472481815260835, 0.11854880707687698, 0.18288696213858202, 0.08077993959886953, 0.08872469727066346, 0.15159927774220705, 0.1385040968307294, 0.07871912166592665, 0.14321873837616295, 0.155087104649283, 0.12390568837872706, 0.17420194926671684, 0.2021285952650942, 0.1588376666768454, 0.10915931794443168, 0.1340525021078065, 0.24865362531272694, 0.15450670063728467, 0.0648430603905581, 0.20017498056404293, 0.1860339503036812, 0.1634399322210811, 0.2396686511929147, 0.1894756156252697, 0.10259638729621656, 0.11814706027507782, 0.15844504086999223, 0.08987556051579304, 0.11164035473484546, 0.14381405955646187, 0.09472093137446791, 0.14735134318470955, 0.12480323435738683, 0.17006128473440185, 0.23839189001591876, 0.20420880551682785, 0.11899780642124824, 0.13965923484647647, 0.11560451428522356, 0.10824792349012569, 0.12683110835496336, 0.10068842209875584, 0.11838816179079004, 0.15541571279754862, 0.18748703092569485, 0.14536580129060894, 0.24284492450533435, 0.1683887213584967, 0.09713625098811463, 0.173985687433742, 0.12677084596361965, 0.12081151886377484, 0.15649515175027773, 0.08904475587769412, 0.1382208487484604, 0.1352743591996841, 0.14259576477343217, 0.09589278255589306, 0.11277479425189085, 0.09897115174680948, 0.19779526919592172, 0.12616700492799282, 0.11460003966931254, 0.25830135215073824, 0.11938937837840058, 0.14513460744637996, 0.16989231255138293, 0.14155750017380342, 0.08477791139739566, 0.16967965755611658, 0.20533456932753325, 0.15733594569610432, 0.19890526978997514, 0.135913155390881, 0.14827559905825183, 0.2349609264638275, 0.1353465553256683, 0.2702148410025984, 0.1076523054507561, 0.16853900626301765, 0.12944820307893679, 0.12724256986984983, 0.2203708078013733, 0.15827951225219294, 0.17748136626323685, 0.14424566295929253, 0.11922788704396226, 0.17736860434524715, 0.1027700053236913, 0.15917727345367894, 0.18658156623132527, 0.18282540841028094, 0.08309134369483218, 0.10887525349971838, 0.13606406369945034, 0.2314013338764198, 0.1505094487220049, 0.15270932286512107, 0.18385346105787903, 0.16665907198330387, 0.15469660138478503, 0.09371132851811126, 0.11312862057820894, 0.21365229331422597, 0.1484760976745747, 0.13032080547418445, 0.09561956088873558, 0.1771204746910371, 0.11444197705714032, 0.23819440451916307, 0.14509280968923122, 0.09822288135183044, 0.12938819301780313, 0.13907699030824006, 0.20486508670728654, 0.07385238437564112, 0.15942687256028876, 0.13848866015905514, 0.11851592993480153, 0.19101756101008505, 0.1095699927827809, 0.22074152540881187, 0.1649809573427774, 0.12497484858613461, 0.10867943783523515, 0.12198953729239292, 0.12592801853315905, 0.15142855409067124, 0.24555968586355448, 0.22668911173241213, 0.22726823925040662, 0.23755461385007948, 0.0758192760986276, 0.18976542429300025, 0.1237817645596806, 0.13897779484977946, 0.1650369301205501, 0.10136328666703776], [0.03542404818290379, 0.014818570271017961, 0.12056034640409052, 0.028624502301681787, 0.052429972565732896, 0.04664754378609359, 0.02605040390335489, 0.013198827400628943, 0.0821336689114105, 0.0285530353357899, 0.042077502293977886, 0.039929470876813866, 0.03693321290484164, 0.03616712725488469, 0.042491821077419445, 0.04915464851364959, 0.02521602582419291, 0.0443818968051346, 0.007718378510617185, 0.013250409447209677, 0.025461290788371116, 0.03613846180087421, 0.04201349205686711, 0.027648444520309567, 0.0455557963141473, 0.029063278561807238, 0.01963050181075232, 0.007970812621351797, 0.020985791488783434, 0.00709713875039597, 0.05401038346462883, 0.03907004160282668, 0.0282716055153287, 0.04254688843502663, 0.037918540110695176, 0.022248650384426583, 0.035158255413989536, 0.04203646894893609, 0.029127594934834633, 0.015277234233508352, 0.015534698250121437, 0.0641190804890357, 0.029145794251235202, 0.03072591200179886, 0.02653362367709633, 0.008148291672114283, 0.06573648744961247, 0.013753222847299185, 0.059205817960901186, 0.04237614994053729, 0.1066930424713064, 0.03895342051691841, 0.02694637096283259, 0.06949953240109608, 0.03375302847416606, 0.04620691586751491, 0.029417689329420682, 0.03680537425680086, 0.04518607689533383, 0.020416723782545887, 0.02545291750720935, 0.03997665291535668, 0.05312545028573368, 0.037895496425335295, 0.029879622452426702, 0.04624365217750892, 0.008916242895793403, 0.017446869569539558, 0.049922403995878994, 0.044437227625167, 0.034296276862733066, 0.058012533554574475, 0.017028183247020934, 0.03136134626402054, 0.040668141591595486, 0.0342784096574178, 0.05182647662877571, 0.03294432499387767, 0.0396747695049271, 0.019732216860575136, 0.014247975595935713, 0.05873432783118915, 0.0708758675318677, 0.07262567363795824, 0.05640709001454525, 0.06227785663213581, 0.02151676846551709, 0.04363313659268897, 0.021959157129458617, 0.02764317898254376, 0.030366578939720057, 0.03021534408617299, 0.03270075212640222, 0.061812982748961076, 0.04150451233726926, 0.004692671191151021, 0.05571268469793722, 0.052955880673835054, 0.007077871669025626, 0.06522516254335642, 0.09044242033269256, 0.06761155324056745, 0.037983433503541164, 0.02893680546549149, 0.01893732103781076, 0.025710349982546177, 0.020829908935411368, 0.018817573654814623, 0.03167652525007725, 0.0822846514347475, 0.05989145109197125, 0.07235496785142459, 0.029733215269516222, 0.029904061375418678, 0.00798728458903497, 0.020646899029088672, 0.012384415877022548, 0.019177695248799864, 0.03984268783824518, 0.03370374244695995, 0.06830663391156122, 0.06025616101396736, 0.010811191750690341, 0.019879401443176903, 0.009032713696797146, 0.013204471433709841, 0.04728148633148521, 0.045299065168364905, 0.013639654771395726, 0.03073038529691985, 0.02566348521213513, 0.05286022525979206, 0.04614876859704964, 0.04613931734638754, 0.02133592191967182, 0.04589572221448179, 0.02955951560579706, 0.04067856505571399, 0.028141874390712474, 0.028117730471421964, 0.012173169106972637, 0.013250231331767282, 0.025779492170840967, 0.09143959221546538, 0.013680229840247193, 0.0205482731689699, 0.019763876880460884, 0.05380856011470314, 0.01239135588548379, 0.08195337155484594, 0.03958832785428967, 0.1089838964981027, 0.019744469718716573, 0.11230074742343277, 0.09660169685957953, 0.011710074522852665, 0.0038952446448092815, 0.018286121703567915, 0.030931386718293652, 0.02009034393267939, 0.05547122695134021, 0.04710554909252096, 0.04236568565829657, 0.04654972501157317, 0.08414563126279972, 0.04396564472699538, 0.05145064562384505, 0.051999964780407026, 0.014971098316891585, 0.047871631031739525, 0.01691677389317192, 0.025631301978137344, 0.05383768570027314, 0.05369048813008703, 0.08929008021368645, 0.010100126146426192, 0.004556084941214067, 0.06303499569185078, 0.07797661033691838, 0.04206383564451244, 0.03375265368958935, 0.015121279320737813, 0.051781624933937564, 0.06599981628824025, 0.029813320834364276, 0.05010924338421319, 0.017660660050751176, 0.0679241532634478, 0.049064674240071326, 0.005204088402024354, 0.005580652277785703, 0.0427153633791022, 0.05271920235827565, 0.038509367586812004, 0.006968915113247931, 0.026348582141508814, 0.08740213073906489, 0.010623122252582107, 0.0428691141132731, 0.03814473187958356, 0.015441795276274206, 0.07602829457027838, 0.015351804304373218, 0.023873181962699164, 0.04844948947720695, 0.017965762526728213, 0.05330277534085326, 0.07684139156481251, 0.011832926866190974, 0.09174161663395353, 0.03720188520674128, 0.034750508348224685, 0.037503898493014276, 0.042480770498514175, 0.0365572000737302, 0.06229546037502587, 0.025663700434961356, 0.033218967873835936, 0.019404788727115374, 0.025191727909259498, 0.03689219069201499, 0.07147732627345249, 0.03763776709092781, 0.04431793109688442, 0.019127693049085792, 0.020788216934306547, 0.06183341407449916, 0.03460988249571528, 0.08594049315433949, 0.03287323466793168, 0.04207668964227196, 0.02314768251380883, 0.06879502645460889, 0.037375436440925114, 0.022348077764036134, 0.06250476828427054, 0.03305586607893929, 0.044927846611244604, 0.04100487996765878, 0.03854138754832093, 0.07332845038035884, 0.03354556109115947, 0.019575490114220884, 0.060040837997803465, 0.06651621748460457, 0.036116134288022295, 0.04834079823922366, 0.04388401590404101, 0.07450024961144663, 0.054225580315687694, 0.03352807980263606, 0.005674209733115276, 0.03708763157192152, 0.0575819951336598, 0.04569764671032317, 0.030131852472550236, 0.0367946094047511, 0.06413435388822109, 0.03031185482541332, 0.031703179483884014, 0.03864405625790823, 0.010727937624324113, 0.04687577275035437, 0.08007058742805384, 0.03516979581036139, 0.040690906971576624, 0.011202067016711226, 0.09444495633943006, 0.012966452613909496, 0.0419003108254401, 0.05579594253504183, 0.020337631249276455, 0.044852889695903286, 0.07053467255900614, 0.02912853375164559, 0.02893603734264616, 0.03763107662962284, 0.06939127531950362, 0.0027375394938644604, 0.03461468790192157, 0.09742274967720732, 0.029103211672918405, 0.05436201303382404, 0.04091610055183992, 0.03869309737638105, 0.0330176640272839, 0.021137206313142087, 0.04949887515977025, 0.02919054761150619, 0.058170681513729505, 0.04163864068686962, 0.02375988755375147, 0.03313069311843719, 0.09754644343047403, 0.02346954082895536, 0.07523711319663562, 0.0927738772588782, 0.042161008750554174, 0.011211889341211645, 0.021497580237337388, 0.02331922994926572, 0.08170108587364666, 0.059815444037667476, 0.11156064065289684, 0.03639814298367128, 0.07241816172609106, 0.0840562247321941, 0.034192339080618694, 0.025279086112277582, 0.052673359896289185, 0.033720949140843004, 0.013606266475107986, 0.04400957615871448, 0.06896313032484613, 0.04754060348204803, 0.027603329363046214, 0.01305237661654246, 0.030844553584756795, 0.0156117034930503, 0.0376076915563317, 0.02686839536181651, 0.054654122359352186, 0.048862917683436535, 0.02733333418291295, 0.05026166938478127, 0.049362030549673364, 0.017134943045675755, 0.04836889966099989, 0.07423319519148208, 0.018020846582658123, 0.09645648824516684, 0.039626567013328895, 0.05443592723167967, 0.028759049964719452, 0.02818628079694463, 0.013910842026234604, 0.02824133145622909, 0.01863539309852058, 0.03562161531590391, 0.12118676357204095, 0.0323544808634324, 0.04662791398004629, 0.06138312710390892, 0.05970854879706167, 0.039411603938788176, 0.04056955469422974, 0.042699704063124955, 0.11208841155166738, 0.04642933752620593, 0.06405039472156204, 0.032050252266344614, 0.1022316217131447, 0.12445426167687401, 0.14276764617534354, 0.1932490209583193, 0.14097626495640725, 0.15296499273972586, 0.0923103911918588, 0.1340368576347828, 0.11139915673993528, 0.0923303994932212, 0.09685696597443894, 0.13858947349945083, 0.10907484669587575, 0.1084062978043221, 0.1289216344594024, 0.08759025775361806, 0.1728258590446785, 0.11302773302304558, 0.13645139057189226, 0.17678790347417817, 0.17909291025716811, 0.1740275594056584, 0.21518074645427987, 0.1286280111526139, 0.23059798870235682, 0.09207705996232107, 0.1400045264745131, 0.10796922477311455, 0.15610671165632084, 0.1037354207073804, 0.16314307315042242, 0.15666023507947102, 0.15555865044007078, 0.09092801497899927, 0.15624237625161186, 0.16957134852418676, 0.17746521712979302, 0.1117377913033124, 0.1538102692575194, 0.14529906737152487, 0.1184564913273789, 0.14896066073561087, 0.1365872035967186, 0.12773315917002037, 0.13519159489078447, 0.09335808848845772, 0.1321994632598944, 0.11890438487171195, 0.18914562708232552, 0.17680515098618343, 0.15697202616138384, 0.2484706265386194, 0.21214013773715124, 0.11823383218143135, 0.13349179469514638, 0.14050891972146928, 0.17890467192046344, 0.23269020690349862, 0.13120724150212482, 0.13866429682821035, 0.15332683426095173, 0.09921239427058026, 0.14382722525624558, 0.11889944958966225, 0.11079095187596977, 0.21445108170155436, 0.12981503183254972, 0.12264377757674083, 0.13199375476688147, 0.1443262305110693, 0.12968889641342685, 0.1666076559922658, 0.1147425988165196, 0.15033833915367723, 0.1392114971531555, 0.13884631596738473, 0.07728550757747144, 0.10769618864287622, 0.14332042745081708, 0.12352089965133928, 0.10979185783071443, 0.10469998262124136, 0.15776550077134743, 0.13324170577106997, 0.14923783804988489, 0.07985673015355133, 0.14638714492321014, 0.22788463742472231, 0.1484683941816911, 0.09207066264934838, 0.18130370881408453, 0.10367724375100806, 0.17279068124480546, 0.09306367850513197, 0.22129255521576852, 0.13221837318269536, 0.11167377364472486, 0.14242743083741516, 0.1243677717866376, 0.11428464917116798, 0.13730886799748987, 0.150391417555511, 0.1470399825484492, 0.07978243374964222, 0.137599166482687, 0.15321251383284107, 0.17556128179421648, 0.1277617912273854, 0.13098299416014925, 0.10828829632373527, 0.1583284346270375, 0.09181992805679329, 0.2217104288865812, 0.21463108219904825, 0.1273349524126388, 0.1171807840000838, 0.06738585128914565, 0.13971179374493659, 0.10989941729349084, 0.1353315045707859, 0.16666380688548088, 0.23912124306662008, 0.10326586387236603, 0.0715301300806459, 0.153978425078094, 0.056784995322232135, 0.16039349022321403, 0.12434290241799317, 0.19535314320819452, 0.14257597911637276, 0.15200836438452825, 0.1766467173001729, 0.10268326310324483, 0.116199278854765, 0.09676813089754432, 0.1371837715851143, 0.14817506773397326, 0.18974718230310827, 0.11358328993082978, 0.13452799612423405, 0.16178000019863248, 0.1686332144890912, 0.09017787437187508, 0.1051557577739004, 0.16225424740696326, 0.11570729431696236, 0.1315810761298053, 0.14698574639623985, 0.16958531574346125, 0.17844007263192907, 0.21912496449658647, 0.2447869468596764, 0.18949293735204265, 0.18582793010864407, 0.15634160139597952, 0.21667439286829904, 0.14501430530799553, 0.1548507751431316, 0.0894806488940958, 0.16059988149208948, 0.09581572536262684, 0.21449713938636705, 0.14404287852812558, 0.17018706392263994, 0.18526205734815449, 0.13256057747639716, 0.18125257483916357, 0.16285068180877715, 0.21170163236092776, 0.11866087137605064, 0.16150041832588613, 0.09918821509927511, 0.1830821024486795, 0.10846855657291599, 0.1731956860749051, 0.22967392578721046, 0.195404959958978], [0.03529985719069373, 0.025918724641087465, 0.03648966834589373, 0.04236414941260591, 0.059903358851443045, 0.01455245188481058, 0.021026219983468764, 0.01566431990795536, 0.05087492085294798, 0.04374821772216819, 0.08739266835618764, 0.0594960756279761, 0.08874878738424741, 0.01323930506259785, 0.030245004018070176, 0.042502997821429744, 0.04657255718484521, 0.03367423465533648, 0.04009044270787854, 0.06276715459534898, 0.02917825764598092, 0.044670766656054184, 0.04825066069315653, 0.04168083920376375, 0.013036268301220844, 0.01566454811836593, 0.02791706116113346, 0.026031566339952406, 0.05509659822564572, 0.03292358938779216, 0.029705468223255593, 0.0753582910692785, 0.016314367057930212, 0.041422338035772555, 0.07856238007661887, 0.011516329450387275, 0.0334310217294842, 0.05860942437720951, 0.0783280617906712, 0.04142594487348106, 0.020801826067327056, 0.08574598366976716, 0.04932923875458073, 0.042384821936138906, 0.038136245420901105, 0.035123021953040734, 0.05464245950861368, 0.08398518635658547, 0.0228139182945597, 0.05002251229598187, 0.03795653807173949, 0.06452985180658288, 0.06863072980195284, 0.026919423580693547, 0.021431903878692538, 0.017867518872662913, 0.08527713929652236, 0.03461622414761223, 0.02165259633329697, 0.08845451098750345, 0.010012722486862913, 0.021863596339244395, 0.0797116180183366, 0.06899340252857655, 0.019258040156273637, 0.00761313362090732, 0.03218515244952869, 0.005826614860779955, 0.02604779896500986, 0.018613694555824623, 0.01772760177118471, 0.07004973842413165, 0.05220266386459116, 0.01804067120247055, 0.03806163731496781, 0.049983720236923546, 0.04133380723942537, 0.07183967987657525, 0.033963572059292346, 0.07488919436582364, 0.03702523921674583, 0.03927518235286698, 0.02487572328391252, 0.012880049926025094, 0.016232430243690033, 0.028927907114848495, 0.05115006468258798, 0.03804557352850679, 0.053723884775536135, 0.05541267521039117, 0.04547490221739281, 0.05907600520004053, 0.043646098201861605, 0.03120075292827096, 0.021337836660677567, 0.05286894920573104, 0.038981091493042186, 0.09882503029075451, 0.016268064464384224, 0.033713512821123004, 0.015959921038302127, 0.04341668922279496, 0.027783428195107263, 0.013228262832853943, 0.04915481178613845, 0.06880390996229835, 0.027348485127731692, 0.05179667568881996, 0.02778390873572789, 0.04487263453484047, 0.02777954490738921, 0.03793648524151649, 0.07733845239272341, 0.028800402433262207, 0.01631230017665075, 0.054047936137067154, 0.034164534517913125, 0.05261913487629499, 0.024902739314711653, 0.09846110333455727, 0.03173214179696515, 0.05343844364688266, 0.01692550526058767, 0.03883399040205404, 0.04010079566796776, 0.013787923817289993, 0.03874852096487302, 0.06835445048636757, 0.007305737444767146, 0.007349836323555792, 0.04695681156590581, 0.05529259200557135, 0.08087556532700546, 0.02396898766164668, 0.0504056534555275, 0.03429317468544468, 0.012796909904864151, 0.04201097988698166, 0.018648004042916, 0.016569886647630483, 0.04473728906305041, 0.043251138340565376, 0.05638671063934453, 0.04346468020230532, 0.011512511100590928, 0.05503934524313081, 0.03978689688665327, 0.055291415701503865, 0.019482580646581482, 0.03316055714094546, 0.01470199742470868, 0.023176785834948532, 0.040154530870495364, 0.041919409995898604, 0.028238353588676546, 0.037702589979744516, 0.05024120466259774, 0.03940621594665572, 0.07072308158967644, 0.02729934381932253, 0.048862112453207374, 0.050974316691281274, 0.04771400257595815, 0.02647206809342606, 0.032092424808070064, 0.053364406994660385, 0.02761669358733343, 0.03767181311559398, 0.01423286454155459, 0.003837013186966942, 0.03178709783242084, 0.04542492599284742, 0.021289934738888405, 0.018877695038099773, 0.004393856097522075, 0.041941132658394054, 0.025895771868817974, 0.07098924543242902, 0.04473282504477538, 0.05263610408292152, 0.02681888669030741, 0.027690774768416304, 0.05020883218094241, 0.024682692528585903, 0.04183978497167118, 0.013067492309346562, 0.03723402391187847, 0.009349926167487865, 0.07243684158311225, 0.03754270539502613, 0.024091282466542907, 0.04897430291748606, 0.058879031785181724, 0.09004030245705508, 0.022513240874104667, 0.04782003321452066, 0.021923990461800713, 0.03006381608429365, 0.030736658300156705, 0.00634661872027209, 0.06730379202053882, 0.013908322434872389, 0.05752631550421938, 0.08648650604300201, 0.04171125612629112, 0.0422865801374428, 0.018292018066858873, 0.0492911554465536, 0.03856800096400548, 0.021771065366920084, 0.035663691378431395, 0.03340139148349408, 0.03590431791963056, 0.024397798733843956, 0.04593762387230527, 0.02729768140852684, 0.02020419495238457, 0.03135580242087599, 0.031043601302371826, 0.0740219205908943, 0.043678563451976515, 0.04896959770121612, 0.06197360948135611, 0.057297652383567765, 0.051719128678087145, 0.019383457547519356, 0.008492342985846335, 0.011930586078960914, 0.04316778031352442, 0.0619894803094212, 0.062126833290676586, 0.012763476152031217, 0.03233525923860725, 0.06081461600842886, 0.011319671448291047, 0.10716084041632712, 0.03874572677887045, 0.01963709950359771, 0.07618601579451934, 0.027161872094438877, 0.03205821922165342, 0.044610715776798315, 0.036936764081474394, 0.030028408218640834, 0.02348707592318533, 0.019194178348698188, 0.044548631412908435, 0.03608178027207032, 0.06182033001095988, 0.01531366626295494, 0.024392774394073058, 0.020554342081595678, 0.03550011089828331, 0.02741061402048217, 0.048757799886516295, 0.034123749792343006, 0.05490871611982584, 0.05518898447917309, 0.05442503992526326, 0.04178337432676926, 0.007815235276211752, 0.015579143619106617, 0.029555068285844754, 0.07235485652927309, 0.06494627828942612, 0.07402244009426795, 0.016369106015190482, 0.007712451533734566, 0.045389930019155145, 0.03045395755179925, 0.015054360792419175, 0.044039577478542924, 0.06279287001234479, 0.06673402298474684, 0.06980735299293883, 0.013806340211885981, 0.026537017147347797, 0.0428542860026937, 0.03873039771860931, 0.005079723468952579, 0.07102411895175464, 0.03327536367578432, 0.0011555468927326729, 0.004461933303900878, 0.03302464021544438, 0.0610777110705385, 0.004222549860060099, 0.047793653575354256, 0.03146924340398982, 0.028201904860907234, 0.03353046951815486, 0.12182150021544658, 0.029344730646698736, 0.02631596475112019, 0.01820102334022522, 0.017121630771725904, 0.01958269265742274, 0.06345766363665462, 0.0163845055794809, 0.021979005869070534, 0.068121527438052, 0.013956684488221072, 0.01889175873657223, 0.02492325413186336, 0.06297319705481641, 0.03505515254801139, 0.07265908512636088, 0.03686429336084984, 0.03487335234240163, 0.0013880668620913639, 0.01998386243940331, 0.02653782237757696, 0.0548909750796156, 0.024278795353893656, 0.0332964814879233, 0.03229963615012821, 0.16320155438734218, 0.05425728486443404, 0.0220302047819132, 0.07300682584173046, 0.011488651980471332, 0.049241446395171806, 0.03215573371562641, 0.08911629891372286, 0.03627061232691631, 0.0664159533334896, 0.015030407048470806, 0.04968655688571744, 0.0380138133186847, 0.03072091920330422, 0.054460547980852425, 0.026029612636193633, 0.03747604940144811, 0.006927840022399323, 0.06959131380426697, 0.030139966002025176, 0.029890593250456732, 0.02432322402455611, 0.054145973845152184, 0.011879207195306662, 0.01654842188145267, 0.08790878011495806, 0.03477870253846049, 0.023196794136310928, 0.0386230163712753, 0.043040706077590585, 0.020657198183471337, 0.04174709443759639, 0.030566660097974818, 0.06294742226600647, 0.042077212856383994, 0.012120104620407801, 0.11972904452704825, 0.19694568822160363, 0.1600868793320842, 0.15283479035133496, 0.10993722229613923, 0.09461292662308551, 0.15607891080435365, 0.0928906467743218, 0.11396253481507301, 0.13507323717931286, 0.20859825279330835, 0.15160162292886525, 0.18948220589663833, 0.09674169559730217, 0.09398654656251892, 0.12546187557745725, 0.1668787031667307, 0.21234272920992225, 0.10844265561900102, 0.107923797913827, 0.14150182425510138, 0.06742925950675271, 0.12297971814405173, 0.08428863569861278, 0.1646998614887707, 0.1005918464215938, 0.07372496504103765, 0.1734511333052069, 0.14473165094386786, 0.12588605750352144, 0.13761497422819957, 0.18460261460859329, 0.10527945152716711, 0.10438806537422352, 0.06758209739928134, 0.13549399038311094, 0.1451576585532166, 0.11222450659261085, 0.18814151611877605, 0.14251631044317037, 0.11335474555380642, 0.1265905931359157, 0.0874971627490595, 0.18356129236053675, 0.09511749056400731, 0.10923325811745599, 0.1752701966324821, 0.17475247441325337, 0.12057979067321867, 0.11899365781573579, 0.08776875169132836, 0.18966003932291642, 0.15254507074132562, 0.12229815940372646, 0.11583148530917242, 0.09697844070615247, 0.12134976888773963, 0.15542919019935653, 0.09557227866025642, 0.16356514737708494, 0.19201889634132385, 0.10385150744696148, 0.20209433772834018, 0.15655875380616635, 0.11582698789425194, 0.10427509565488435, 0.12493086891481653, 0.0963030121056363, 0.09112047613598406, 0.08753888629144058, 0.1268678149790503, 0.16612978710327297, 0.19105451996438205, 0.11747894182917662, 0.11699316906742752, 0.1033970681601204, 0.09100620765821077, 0.1388155168388039, 0.09614123875508085, 0.12781498837284744, 0.13147140154615045, 0.1427729005808942, 0.16562952019739896, 0.20388821256347, 0.07479357605916448, 0.12882690672995523, 0.10557984322076663, 0.17213014012668282, 0.12883089948445559, 0.2084701877902262, 0.15804808092070743, 0.13780768029391766, 0.10655826103175059, 0.14801620360231027, 0.07846812732168473, 0.1554012854467146, 0.17489388323156163, 0.1670488331001252, 0.19187646335922182, 0.15683800913393497, 0.13029442954575643, 0.1553027133923024, 0.07121471731807105, 0.16862883581779897, 0.21886273403652012, 0.14704433153383434, 0.07899615055066533, 0.12106274327379651, 0.16215920797549188, 0.2101843708078377, 0.12730088783428073, 0.12056870298692957, 0.16708111652405933, 0.11915180206415243, 0.11729554229532368, 0.175997783371713, 0.10795327601954341, 0.16597648907918483, 0.11543145286850631, 0.2560303802601993, 0.12335653620539233, 0.1142666520900093, 0.1206936954986304, 0.14851820713374764, 0.1724937479593791, 0.14386750903213397, 0.10993279167450964, 0.15151719620916992, 0.20986373332561925, 0.2917453763075173, 0.10493118388694711, 0.12591967679327354, 0.10900423134444281, 0.12124662520363927, 0.21204193675657734, 0.11314114803099073, 0.0852312523056753, 0.15098801522981375, 0.14259517105529085, 0.15843251341721043, 0.34535500744823366, 0.12407090529450215, 0.11616295072599314, 0.19128099374938756, 0.09965059536625631, 0.15403107303427532, 0.08889188087778166, 0.28609769186004996, 0.08264100106316619, 0.16235381393926218, 0.16135004436364397, 0.1417343836510554, 0.16998819803120568, 0.11034271694370545, 0.15498353051953018, 0.1718894171062857, 0.17200544447405264, 0.10603872797219083, 0.1965599347022362, 0.09409513761056587, 0.12654943362576887, 0.06886401650262997, 0.14146569650620222, 0.09635045018512756, 0.08829053345834836, 0.1293979151523672, 0.11267614798271097, 0.11895661722519435, 0.20567484403727576, 0.1411983006983064, 0.14443652849877253, 0.24451503879390657, 0.1075754634803161, 0.14368514850502834, 0.19020440464373678, 0.1533018535701558], [0.028684957651421428, 0.04773091241077054, 0.06759009775123559, 0.004229569185554283, 0.03366500233823899, 0.0724787506624125, 0.0436920668289531, 0.025457802694290876, 0.057117228861898184, 0.0013882139000997995, 0.0393628633901244, 0.024901067627070006, 0.019912031821149867, 0.04552901962597389, 0.06416963558876887, 0.0665039497835096, 0.043650710649671964, 0.040054003256955184, 0.03815431671682745, 0.043249141963315196, 0.011614838422246976, 0.08777857772656716, 0.060715698855347, 0.01765934459399432, 0.03795456766965799, 0.030316040538309608, 0.0381178550014738, 0.03873540350468829, 0.010893434700847138, 0.037343694784794934, 0.03516867145663127, 0.02863999648980098, 0.05795696153654717, 0.019434203750279266, 0.04658162622945383, 0.03805362583079841, 0.03234406482079066, 0.0363329378888011, 0.025658177000877913, 0.0598621362587437, 0.022384097901522182, 0.03466048583504744, 0.009169229906547116, 0.050869295373559, 0.043583175211097114, 0.060653506880044006, 0.02669911518751178, 0.027120181948703248, 0.03171824508171994, 0.03108607626927551, 0.019583464491006453, 0.0575032940832898, 0.07012084359303117, 0.040155024398700334, 0.04608143353834748, 0.026112228515557945, 0.056434846337651834, 0.02704467213334283, 0.024119339359458536, 0.04780976189067587, 0.06653696793364361, 0.057717399977263995, 0.03305247446405701, 0.045163582399254665, 0.05460563785163686, 0.06277773762121797, 0.05619709561869968, 0.06934871315024793, 0.021254439670883585, 0.013006991503061727, 0.0241690558323171, 0.027795230198535137, 0.03361743438290432, 0.05897279472264927, 0.04766959245898761, 0.0483424940466648, 0.052935282365069725, 0.05319865944329649, 0.008245238423114643, 0.0605656440166058, 0.018064789146592375, 0.02565634946222417, 0.10201648794463836, 0.06463903657277115, 0.0035679686516232323, 0.03560160330380313, 0.025507845712127164, 0.018026540710707195, 0.040771652638795786, 0.03091603168286383, 0.04841217058128677, 0.043239041333436035, 0.011554518514458323, 0.12153501636930741, 0.0519457249174593, 0.011274433836661046, 0.04238308531057555, 0.02658208777575055, 0.070865752059035, 0.05781874766398687, 0.006796937232138589, 0.022347333760990296, 0.01816598840377992, 0.0951908592833206, 0.052081508256378584, 0.046626670882687904, 0.058781064581125975, 0.014683163572044577, 0.047705334291094914, 0.05071282837889157, 0.0685204095498193, 0.03236139767977875, 0.027235821544309147, 0.07546299326349981, 0.045934536537970416, 0.09227179951267317, 0.025478024363110308, 0.020810887690458912, 0.029395187411864754, 0.03760926119866781, 0.038819785695523024, 0.05009843771404121, 0.06039486099325586, 0.04067817913892213, 0.02684598250198178, 0.02237482291093329, 0.08356516787898727, 0.02540435136324959, 0.0479365058708936, 0.04607761147781275, 0.08353145953151397, 0.03417985986743588, 0.08653384022181854, 0.03049327653570799, 0.02253320093586808, 0.022287371939455625, 0.037569663909380324, 0.03322479373309761, 0.04046235146233812, 0.013000690669286996, 0.03180081272148527, 0.03881854259816464, 0.09066879021702334, 0.06121443693700712, 0.018150752111978363, 0.02657115965121193, 0.05923399359744508, 0.03388942779565696, 0.00814793822428328, 0.021112140275363345, 0.01009180481560179, 0.02734370940743247, 0.025926290836650878, 0.020400381690706126, 0.058325419304310344, 0.01081562515537371, 0.10509393687243573, 0.03191220166627318, 0.03133888887532521, 0.05764256180555094, 0.05168095631233882, 0.012969694871571846, 0.0557320324878674, 0.0377113139256835, 0.07369243670837022, 0.040084954525809735, 0.033383609625161625, 0.02155999856768176, 0.07482307642931119, 0.03835802883259021, 0.07222151485620998, 0.04950778093189001, 0.05999407898343634, 0.03923734766431153, 0.01967568190593738, 0.037075081854709424, 0.032303866391885094, 0.03791828035900835, 0.04552312697342131, 0.03092320268478943, 0.059447268286021426, 0.025084185144805815, 0.0057015152015083, 0.019768314923567232, 0.058414265513420105, 0.01230149386174162, 0.026494970770727377, 0.032634103554300964, 0.009381845011375844, 0.029048893884464633, 0.023333868812187575, 0.025284116018156055, 0.04269170000043232, 0.04743574172607623, 0.05708756150852423, 0.0660938018700108, 0.042044346846523695, 0.028247086811461486, 0.10757220545201562, 0.0029944610469101463, 0.0516091646568384, 0.01769342958141351, 0.04293353253160603, 0.06454643880715594, 0.028250587893126067, 0.06480009004008025, 0.024510957700840663, 0.026042147510452196, 0.038776856163167395, 0.005356260680855485, 0.03707397234393284, 0.037439023653860204, 0.04944758904457558, 0.018351421422266867, 0.029584255098598078, 0.049811204298748635, 0.03365892043802887, 0.04371120681753382, 0.017131107997556683, 0.04264981689630076, 0.03578752985049505, 0.01257368765436695, 0.038692177113262005, 0.06532251747557893, 0.005313879873938276, 0.022220079554244876, 0.016706896385585424, 0.048889449462876655, 0.06886179005960003, 0.007142156964619062, 0.06501820724224672, 0.019665195359266363, 0.07593313639517874, 0.03938955102057662, 0.08018153108423576, 0.1255038514500484, 0.05329165425791871, 0.058988212840631604, 0.04450000589713454, 0.04812531937204767, 0.07196996390121058, 0.024624337456771173, 0.05885345737624448, 0.0789613438246306, 0.05171379634703044, 0.014951405428291764, 0.04154895585088525, 0.05380050410167314, 0.008954416189226322, 0.02259967881400371, 0.1268326074932702, 0.009557663506711833, 0.034178947025793605, 0.046369179035536945, 0.05588912288658321, 0.0519332642579684, 0.03254586219554767, 0.009054504080268089, 0.013770166078757029, 0.0672476708132308, 0.04275487161066849, 0.025869514684018213, 0.08910797943826765, 0.007628765570188989, 0.0444018605776364, 0.03297453782579396, 0.0176956894210889, 0.10922240791842341, 0.032018269412219524, 0.07171720324549824, 0.04968222274328582, 0.0642266844806727, 0.05216553792706691, 0.019235200561524834, 0.06746778439264745, 0.014120263112999965, 0.0328155994793633, 0.043779688494396396, 0.07959163500345312, 0.011350999357091496, 0.01747526228427887, 0.027523368516995106, 0.05327305603714194, 0.07603823192766868, 0.011286238623142708, 0.008128340887196828, 0.03084982468863018, 0.02445852125674719, 0.037288657113094814, 0.10079063809826039, 0.015141343283175956, 0.08292487254948355, 0.06505144803668372, 0.09579058139934205, 0.06978300312766805, 0.010089044026244665, 0.031084708862181287, 0.02452760407322785, 0.021473705346579663, 0.022041906595404726, 0.040963100764201954, 0.04536157997790724, 0.014161953258735593, 0.012680215531872818, 0.0176889395879698, 0.040218407521024346, 0.04245367839757819, 0.04554564744466916, 0.036895441298838705, 0.03249479130317923, 0.03245457432058174, 0.04130407309276052, 0.029045019873592537, 0.051049370085820556, 0.04278661326679867, 0.01639771209738683, 0.026550095644779503, 0.01466745601646835, 0.01049128157319501, 0.023352058851742186, 0.04446378909051418, 0.020461868625716306, 0.015492643524339655, 0.0184379057463957, 0.02143667959899176, 0.03745929912838619, 0.05992602033074945, 0.09373868408147246, 0.04209794104099274, 0.02916626453952631, 0.05591349501628429, 0.04617651749867946, 0.05758165745646693, 0.04341945743362885, 0.008915534144762205, 0.0315289603167912, 0.09104193464736454, 0.04382861086924095, 0.05562511498283129, 0.03265242718043737, 0.07696366781601682, 0.035365733929211274, 0.04571917641442269, 0.022774725475755986, 0.03432017772865947, 0.02565886163210962, 0.03542864207702223, 0.046336127488757484, 0.07370390288997442, 0.037092169804964215, 0.08218024609959684, 0.023946602632349823, 0.12001074152067304, 0.2104342816164717, 0.12974010460311547, 0.06780394760426134, 0.22520649363286793, 0.12550618179375306, 0.10106361485668458, 0.13008793437620625, 0.138597889454104, 0.10544772609136999, 0.20581629738444462, 0.11042910293326713, 0.1189930121472571, 0.13201861671404913, 0.10958171871607192, 0.16479963582241908, 0.0832974529475905, 0.13759282854152843, 0.20854382368270308, 0.17264933179831132, 0.1751288175000809, 0.20074759202543646, 0.23055289580952376, 0.0926325649197679, 0.22091564809670672, 0.08103027343167923, 0.12860743881901726, 0.15471751510631293, 0.1354274939512834, 0.1761003481806256, 0.10962111191474833, 0.09172566788038239, 0.14331116544781253, 0.1280564980697818, 0.12078869040124118, 0.10826380545040593, 0.16727753332816064, 0.12366796363494359, 0.17929817346157506, 0.11894306560861878, 0.17969250620808452, 0.19179089373210445, 0.13672539149411023, 0.1713661287794821, 0.20325471530668437, 0.14412498974706978, 0.16493200528202578, 0.1537233786075376, 0.12063680245773867, 0.18524981191148981, 0.14056655491003767, 0.1724852726329118, 0.19486155943013728, 0.15232000703690574, 0.2198071317980066, 0.10625065566273406, 0.1945616872399114, 0.06729317188728601, 0.17283629364101216, 0.2042827382683754, 0.1929533196380362, 0.12358257954474539, 0.14792307891184464, 0.13719805050641298, 0.12233849512995221, 0.08882636408088729, 0.1248166969162412, 0.10625711234752089, 0.0906158157158643, 0.1034195552347228, 0.11136689558043145, 0.14183537510689348, 0.17193096253322437, 0.12877635163022205, 0.1831432999460958, 0.1452236800105311, 0.15774616040289402, 0.16647942771669477, 0.11244655717746355, 0.15073938091518357, 0.15500966896070167, 0.1280055718962103, 0.11791913930210285, 0.19716034701559693, 0.16690120508428663, 0.16259753523627296, 0.1884535001590848, 0.12777105323038995, 0.21577378181973472, 0.14074104867177084, 0.13853752316208556, 0.31976756639778614, 0.09132704552030191, 0.20558617223287, 0.09212843884597532, 0.13541955297114328, 0.14684043388115242, 0.0905945457634516, 0.22363177500665188, 0.12880504305940121, 0.08972741299658082, 0.14251813612645492, 0.13035203504841775, 0.21083165716845542, 0.18356421642238274, 0.13690542167751119, 0.12748580134939402, 0.12220954697113484, 0.1757172218640335, 0.15192953345831484, 0.1374280866002664, 0.1665760256582871, 0.13022426690440625, 0.11619437325862236, 0.1605983526678756, 0.2244575775694102, 0.151355882990174, 0.2082372276345268, 0.18250960973091424, 0.13747893855907023, 0.15825708454940468, 0.11799972169683315, 0.19745279772905633, 0.09319242628407665, 0.08572997554438189, 0.15634194278391078, 0.16545664431760088, 0.07895375165389851, 0.10957018574117683, 0.10261126735713333, 0.2108163243974559, 0.09669688472058624, 0.16896075394470245, 0.10588547447696328, 0.13561467843828723, 0.13331479247426614, 0.1264937873929739, 0.15928901120787486, 0.10108413523994386, 0.08262870367616415, 0.09565292784827761, 0.17140264244517311, 0.12541468982817605, 0.22196336765773594, 0.09024592931382358, 0.19458031514659524, 0.1768071696278639, 0.12594335130415857, 0.08485602986183949, 0.07817802179488353, 0.07538373931311071, 0.18039674498140812, 0.14587642857804894, 0.17621607868932188, 0.19150118896504864, 0.10797909533721395, 0.25652141484897584, 0.1265469696954824, 0.1836472182185389, 0.15632355236448348, 0.2349446140578948, 0.07263820109074004, 0.11956842892686836, 0.06911207194207236, 0.2125244663329795, 0.08774053523666225, 0.11679481525789015, 0.13122215867042542, 0.2342253245296888, 0.12717126432107762, 0.15200777066638693, 0.12338131651631556, 0.1864959520753473, 0.11586992855882272, 0.15232119447318837, 0.09524473920464516], [0.015240662123687798, 0.05367312558519188, 0.015642879261577036, 0.0469552864524303, 0.009334970036434243, 0.018597870111989323, 0.05048149723734241, 0.029371947057370562, 0.09581542850355618, 0.07140972404158674, 0.01661993894231273, 0.03167556787957437, 0.019568146562960465, 0.05721623507270124, 0.050609206009539776, 0.02856816030543996, 0.028349531021376606, 0.03402075082703959, 0.014166912660584785, 0.07588114895042963, 0.032860373248695396, 0.02750627314526355, 0.01376307021928369, 0.030395311187021434, 0.018568623927421868, 0.053312824020395055, 0.04180233991064597, 0.10447410255437717, 0.028517592218122445, 0.03780593033297919, 0.09834608528763056, 0.02773767108010361, 0.04530613783572335, 0.03339445611345582, 0.022000088429194875, 0.09083770302822813, 0.023843646340537816, 0.03420256958634127, 0.08887590243830346, 0.012705270437436411, 0.02559994623879902, 0.03093979525147006, 0.09366357131511904, 0.055221609291038476, 0.03715601305884775, 0.06964054788113572, 0.03708986172568984, 0.11903933700523339, 0.013826666709064739, 0.033014721411745995, 0.0346295976487454, 0.07166713054175489, 0.05745437912992202, 0.012083957390132127, 0.05688733377610333, 0.08175486931577325, 0.033629360696068034, 0.04242630428052507, 0.015639929224562366, 0.022820005760877393, 0.043126487216795795, 0.036054268857697025, 0.03430701202887576, 0.01153457607870223, 0.016366734853363596, 0.027311618941894267, 0.016074480809038505, 0.024384599637414794, 0.028834550503233913, 0.06663426349405199, 0.010239800194540294, 0.023186315011116676, 0.03517961442412343, 0.025467140767432284, 0.018819410470314324, 0.06967331370105967, 0.019355109361640643, 0.06955469623790123, 0.035273173270979896, 0.07289699540706351, 0.057405293482588604, 0.04374747928522993, 0.03288798485300504, 0.030566866043955088, 0.039153844918473624, 0.04003450332675129, 0.021904640816501342, 0.003772081063289079, 0.02704804704990238, 0.06349937233608216, 0.027157588046975434, 0.024454190825053956, 0.017976345552597195, 0.03476366662653163, 0.036225189178367145, 0.04924897548335139, 0.02198726597271161, 0.023376785356958862, 0.029923518632131163, 0.07530820352258161, 0.026284339983249083, 0.018458680315234233, 0.028962815886188764, 0.05248800851404667, 0.007112981284080888, 0.01749812414345797, 0.017756000052031595, 0.03553750029823277, 0.07916809874586761, 0.03681367888930254, 0.06165319835417904, 0.027477932380861603, 0.05720004141039681, 0.009460264045628719, 0.061301702371565625, 0.047439315167139284, 0.05023294455895666, 0.04352962183475029, 0.054089192126411945, 0.021030928910477087, 0.05522572449990548, 0.04320371510402765, 0.06864342794870026, 0.07978736903169192, 0.036784883559448645, 0.06823657517088577, 0.026239991093461867, 0.022247731976676732, 0.029380990126810502, 0.0343397147662472, 0.013938747706561117, 0.044043996967957355, 0.013831871019647224, 0.03579161537345499, 0.027845323311339598, 0.038382746060960926, 0.09936663482221775, 0.08419212681474164, 0.04216294575599022, 0.020306164187786635, 0.08588385244365782, 0.030289829737739637, 0.023281950016098563, 0.037365706884884275, 0.057117711257888004, 0.04500333787291311, 0.014601822331314906, 0.06036940532794688, 0.03117180174740497, 0.028824210530729033, 0.06811040264437906, 0.05918559443671256, 0.06242403746000491, 0.040273007325595245, 0.060049053572583944, 0.04034734454762656, 0.03441538043261971, 0.011336926381773083, 0.02622155057906639, 0.02728463074163301, 0.029133623029338196, 0.020892828215437476, 0.014864376553305192, 0.022505752604047302, 0.038277168132481165, 0.02391746405919548, 0.0590639267466031, 0.05069636754342355, 0.02249833669338841, 0.008022957772482187, 0.052270985979703255, 0.021958812030788977, 0.056131371020455845, 0.03532298251229804, 0.10427882123622112, 0.06578154323506169, 0.029375945377978496, 0.04225898337608669, 0.044063311361242086, 0.018720973857853096, 0.05337012524250895, 0.020875050067843404, 0.06201901407621335, 0.02297473984071985, 0.007898776057118084, 0.035235531540820375, 0.018938404573418666, 0.03136109393381048, 0.04888735289569013, 0.072908706497401, 0.03953154242481105, 0.0163796370907221, 0.06983001076150686, 0.024760397245700005, 0.05899547475564759, 0.04877833511272911, 0.00811465846709325, 0.04537882006843574, 0.019231549194955733, 0.04147819949139375, 0.018299786497664172, 0.021520366026379634, 0.09458327782340348, 0.07428594704833813, 0.058499575388850644, 0.044085011759307235, 0.0932598058716394, 0.028494377838796936, 0.03854186252283398, 0.031020537207950838, 0.02994734899402829, 0.05294471135130152, 0.004921592208120273, 0.012036648258799687, 0.0575691596895922, 0.017884829467220698, 0.015375415732705733, 0.036522949958452955, 0.05130749646923505, 0.028608047032321338, 0.012278189497010317, 0.05695698804629501, 0.030289629357866943, 0.025379905018780846, 0.042562109883874655, 0.046065933784120716, 0.008283095376100391, 0.02006830029131379, 0.0692839830298908, 0.015809619435458444, 0.05390651618654374, 0.05914098765060771, 0.015278460632544011, 0.03484050488623325, 0.033407707160222344, 0.02161973217880586, 0.0465449381590588, 0.06726830251864158, 0.03194269651430659, 0.034513911668909714, 0.026189011114183813, 0.045500510022975504, 0.024898922820284497, 0.05962609619018622, 0.01211411363328807, 0.057776456378633156, 0.028676241126959212, 0.035061627786490135, 0.04281161993276328, 0.03962621820392087, 0.022664922871626914, 0.06503030424937606, 0.015777302614878863, 0.037460542225744575, 0.020776184865098912, 0.055527092117699794, 0.08371587580768391, 0.011863341005664552, 0.0546171596943168, 0.026064423072966747, 0.025956377503462136, 0.028721771886921488, 0.016466171509819105, 0.011169470963068306, 0.04019268468255177, 0.04533694067504257, 0.04459561678231694, 0.020807505352422595, 0.060681103641400114, 0.04212202002236154, 0.057228239311371, 0.07297860196558759, 0.07407450175378472, 0.038598751852987334, 0.005071566802143934, 0.019353148236405104, 0.0597135211864952, 0.09610517779947259, 0.0072740788164082915, 0.06831835984485224, 0.10738626777310856, 0.045588588109239936, 0.04606927715940401, 0.023472668981412426, 0.028708593199553434, 0.05499540638993494, 0.061335006248555146, 0.040163380981539376, 0.05578599404543638, 0.019893097778549418, 0.017571708085597493, 0.039312534645432606, 0.07268172805197537, 0.03516195502015762, 0.09044361519045196, 0.05243276675173547, 0.02837202737282496, 0.007669486285521998, 0.07196292834123597, 0.04180798765446525, 0.07289340341230854, 0.012697897200268926, 0.028222195178386755, 0.061856257379986346, 0.023176676368166227, 0.027289309982734267, 0.07400416099699214, 0.14448264555539936, 0.03971054844441824, 0.04702114463725593, 0.02141674736776622, 0.05278152420942206, 0.08309737735544331, 0.04790212587977294, 0.06257707573240623, 0.1026720937807113, 0.02801769267534837, 0.024577832627983298, 0.04673040828492958, 0.03528569701302331, 0.07625780373928137, 0.01976009563804837, 0.008189097734430106, 0.08725787949515507, 0.06464547841460444, 0.04106184722331818, 0.02339404400117928, 0.03784857413847931, 0.04881429216766264, 0.0604529266274767, 0.1129056274658069, 0.005486928766913479, 0.02857053517800523, 0.006468163956014905, 0.030594746676797513, 0.06350654148263857, 0.01682925983914174, 0.06826419790741056, 0.04031458614917938, 0.09985289740143344, 0.0303182113202638, 0.03858162679534871, 0.06299771761405282, 0.015707420134276617, 0.011765355247916887, 0.034011781972367316, 0.04397842822072562, 0.024404188625339884, 0.03242063590732869, 0.014387775809154846, 0.06214042201463599, 0.01745517976814881, 0.06664896543952636, 0.10308244949555956, 0.15102599834790453, 0.10121389233972877, 0.11851312461658381, 0.17159076203824952, 0.09868716151686385, 0.08183406389434822, 0.2023902171640657, 0.20600839488906786, 0.11096800604718737, 0.1710601116064936, 0.15559121588012204, 0.2024757125764154, 0.098060885356972, 0.11321262427372858, 0.2215286620776169, 0.1412176262238063, 0.183740773354657, 0.18627635057782754, 0.09269978865631856, 0.1073695471859537, 0.06805352444644086, 0.13656729919603094, 0.13504168106010184, 0.09681570998509414, 0.21895280107855797, 0.20393136102939025, 0.1081829633039888, 0.15238585037877783, 0.21723983518313617, 0.16265043552266434, 0.0998421733675059, 0.12507757666753605, 0.1661102389334701, 0.14820831594988704, 0.10565633638179861, 0.07305924373213202, 0.19611286494182423, 0.11640255310339853, 0.13913134520407766, 0.09985726865124889, 0.1738347197533585, 0.17178009875351563, 0.13249134994111955, 0.1640900832717307, 0.15021824481664225, 0.24006509163882583, 0.14229773310944438, 0.17321732710115612, 0.09864324863883667, 0.20723811874631792, 0.13271577539853752, 0.08826316305203363, 0.17066393833374605, 0.2160439977888018, 0.06828478508396074, 0.1091533139697276, 0.1756932950229384, 0.15234596736263484, 0.17193249135743827, 0.19716564595000818, 0.16528069594642147, 0.11297397926682606, 0.12554287357488647, 0.12844992539612576, 0.04655209988413844, 0.282430027727969, 0.17247560987016186, 0.1427538867574185, 0.10432442621095106, 0.10104587752721272, 0.12579713336890563, 0.16307264333590865, 0.1214079606870655, 0.12812142114853486, 0.09843977401033044, 0.2435256223543547, 0.13697862712433562, 0.17308559588855132, 0.1998361901496537, 0.11483595357276499, 0.07750814445898868, 0.12026206983136944, 0.10649200208717957, 0.1249629000085406, 0.10584188072243705, 0.0580425831140019, 0.05155252023541834, 0.22666089527774602, 0.08575193569413386, 0.13880474085453898, 0.1655435498105362, 0.15347539738286287, 0.11617023861617781, 0.26233130309265107, 0.17493663093773648, 0.12075468519469723, 0.16324277326930314, 0.21216930414084345, 0.16135143960127607, 0.20183005894068629, 0.09189426156808622, 0.17339605110464618, 0.13766788935754448, 0.12415001081535593, 0.21227777644526213, 0.10915992650552653, 0.24890227447031066, 0.12958020146470517, 0.15896210999926552, 0.1354338022065349, 0.13351995177799836, 0.1485386904096231, 0.11190222896402702, 0.15028580994112417, 0.13638802600326017, 0.1930914184777066, 0.17023019754560664, 0.10038465363322757, 0.10440635931445286, 0.1244211544690188, 0.13098352850647643, 0.2325805026339367, 0.16302897536661476, 0.1754027442075312, 0.14519556745653972, 0.08668402122566476, 0.11823427747003734, 0.06585888986592181, 0.13098591822199523, 0.25745479913894087, 0.20602041768142954, 0.10717226949054748, 0.16465185937704518, 0.12696908845100552, 0.18756642588414252, 0.19886489695636556, 0.14791043271543458, 0.2706839673919603, 0.19273318379418924, 0.11686166792060249, 0.13142623443854973, 0.1253709476441145, 0.15112609922653064, 0.10989934307872318, 0.07435510036884807, 0.22051107371225953, 0.11355381182511337, 0.11925409969990142, 0.18411693832604215, 0.1333227928262204, 0.15733288804767653, 0.18650729209184647, 0.15936043550027534, 0.13707789679756388, 0.14338437089463696, 0.06627781738643534, 0.11827145906863734, 0.111052455031313, 0.1259362415294163, 0.2214030610048212, 0.12967366754310206, 0.15641992766177282, 0.14867030287859961, 0.12443409752449952, 0.15847367292735726, 0.11679904549964704, 0.07628638384630904, 0.12447907909518108, 0.21208461024798453, 0.14493020513327792, 0.14724199514603242, 0.2039673551917076, 0.23898082872619852, 0.10737802993389778], [0.0316486501833424, 0.0375388833344914, 0.0523578432330396, 0.03613938948547002, 0.021641243329213466, 0.024093527463264763, 0.03879264906572644, 0.062119912763591856, 0.014072308313188842, 0.03790933376876637, 0.015883394480624702, 0.06015895080054179, 0.0619397267291788, 0.020829790191783104, 0.013520967731892597, 0.06518781767226756, 0.06925662004505284, 0.024524320069758687, 0.04268201497325208, 0.03942008668673225, 0.03298240088042803, 0.08277984947199002, 0.021923556305409875, 0.010238886425213423, 0.04480926254473161, 0.028046102088410407, 0.03015193869941868, 0.023423961829394102, 0.02516925011150306, 0.033083529633586295, 0.01852212466474157, 0.0342418254876975, 0.06630264222621918, 0.016782441452960484, 0.005799731025035726, 0.05373561070882715, 0.022275161754805595, 0.0202023729798384, 0.0800632921163924, 0.044880293498863466, 0.02407290317933075, 0.0467279035365209, 0.057100040721707046, 0.05504513770574704, 0.05899809082620777, 0.012029198951495346, 0.04474291083170101, 0.06905497109983116, 0.012851680403400678, 0.032260992520605214, 0.03580884433176834, 0.06701733043882996, 0.034194817853858694, 0.05762273161963094, 0.03141370107186958, 0.01885997255158145, 0.03709678596351296, 0.01978354193852283, 0.031140709470491856, 0.04596814098476898, 0.04789982151123695, 0.04069999456987716, 0.02713256653805729, 0.028127649275120348, 0.021397162090579513, 0.03036825619346928, 0.030375724054465536, 0.038506350756506436, 0.03433192592638079, 0.05380984031944536, 0.017490314894530457, 0.039264072402147576, 0.03475070130662061, 0.017238372456631623, 0.04428305757755879, 0.049271878160652705, 0.037812045629834756, 0.019102493424725253, 0.02406768031505635, 0.03405775802093558, 0.06166689840028994, 0.05049140119808726, 0.0912247107771691, 0.0349247720441781, 0.03202458508894779, 0.08522711854311638, 0.05585422710282728, 0.027051692850363906, 0.06518926486023702, 0.053956258634570986, 0.058707721836981364, 0.02032006646913942, 0.018787258777592797, 0.08152056587277912, 0.009435317679162836, 0.0974370731273666, 0.03554626877303235, 0.039174387566163205, 0.04278815322322771, 0.02581624146841932, 0.015486649754166137, 0.04544522373180371, 0.02930327427748125, 0.05130217155965511, 0.02018378032516921, 0.004905097512164502, 0.010628309864841867, 0.03410440942388959, 0.03358580404892564, 0.0398810605838662, 0.021217629146121908, 0.04379776350106113, 0.03711769597430248, 0.05551565933274105, 0.06362499567330815, 0.0130095203712699, 0.07429014760418795, 0.014564511784556089, 0.026732389378594235, 0.02866026639821939, 0.04901025255094282, 0.05624427394650411, 0.06254099251236767, 0.03392104328668211, 0.01966103747690795, 0.08052611025050282, 0.0599408818379743, 0.06322214307147078, 0.03147534756863024, 0.05592763292952441, 0.04319221552577801, 0.04370761482277885, 0.028805057554563973, 0.017210100340889767, 0.02583785095339408, 0.02296044051036006, 0.03304582482087426, 0.012011407816316932, 0.04887381241132971, 0.03854214082821272, 0.09984483025618829, 0.09851798895397224, 0.01002261624307721, 0.026292384864063933, 0.04436155082657933, 0.02895702713431092, 0.047377943265018985, 0.03649359801784158, 0.029187846193963196, 0.024437915526505094, 0.04329329232859891, 0.06476440015831031, 0.09275861870264634, 0.05053414890426211, 0.016971509139693808, 0.029313115155673586, 0.08902525223675184, 0.07347222664975561, 0.034107956889783964, 0.0398167683306383, 0.10420496269944124, 0.016548817075090483, 0.05989553661493119, 0.04504065676883329, 0.011658360745059326, 0.011592392165766796, 0.027244380362390075, 0.058113840423175134, 0.021956515083729755, 0.0859623345604632, 0.018023165794147644, 0.043455254926811904, 0.024457126019115094, 0.01138622354119434, 0.024127439901349135, 0.06203610944794491, 0.02855316150089493, 0.076050996867707, 0.039825889325584285, 0.009118056968873134, 0.04730387321615126, 0.01232116912433412, 0.028531325660878792, 0.01685385275777662, 0.00484253770991927, 0.04164425132330507, 0.010406350193079561, 0.057983567530754954, 0.05032850349380169, 0.06647864254773594, 0.04278288397472352, 0.034463375122868456, 0.0898869005322922, 0.03366557379195001, 0.04581409339152742, 0.0286995705391746, 0.04162344521319028, 0.048786680563353, 0.024131545833370183, 0.03181662417773623, 0.05396984735853039, 0.0304245332517894, 0.018761151877697557, 0.015984603014658205, 0.003185597238370974, 0.024862921236490365, 0.09789391697268002, 0.07478870757040568, 0.0037175452689552912, 0.03617273789132014, 0.028058859606971964, 0.023544108116766438, 0.06198476396093611, 0.017262160145037342, 0.029671548363694455, 0.033207928427145816, 0.0421779556927504, 0.023659124308323953, 0.04185012308880687, 0.051074810908176005, 0.00793025981693063, 0.052150847113807686, 0.057396870106458664, 0.024432408790744375, 0.011242561377002858, 0.012538798364403192, 0.02858599225874059, 0.008606430565123446, 0.04512349529250059, 0.07739884094917215, 0.08484386606141925, 0.036295581885497086, 0.05058388393081259, 0.07603212405228987, 0.07618738876772113, 0.008998740959214047, 0.03369465113792103, 0.067013515799772, 0.03010945631103823, 0.0028868480103483307, 0.01633503401535563, 0.009019936696859077, 0.09737605374539271, 0.07298240176169202, 0.06843413488240913, 0.010988779340550536, 0.015902285849733744, 0.03229493093385827, 0.012954853773408104, 0.048055023144115694, 0.09918178067891859, 0.02322476382687455, 0.047626002415199764, 0.018837437237380072, 0.035535908391466364, 0.02391918398643611, 0.027651732234517112, 0.003960993826694903, 0.053965208935551345, 0.013515839491446968, 0.045929256157251075, 0.10648776442394592, 0.0234763481785194, 0.07196823469712399, 0.0453858890250558, 0.025681051847641356, 0.01941534206707729, 0.07560737067251466, 0.08095703087747097, 0.08457387273665518, 0.03467572954832576, 0.051616259588627145, 0.012839637201977894, 0.026579506957205012, 0.03830874651612248, 0.02111212357704062, 0.052190299684298225, 0.024712975864531472, 0.021017273393226787, 0.019139697287755553, 0.04959376987244468, 0.00984374381005182, 0.030277780970209278, 0.028086688289477024, 0.04273612124961801, 0.09236568119376898, 0.02329842569452012, 0.044430418420233764, 0.035339306050445884, 0.07933226923341863, 0.06007050535117742, 0.056079569112625904, 0.028025320098095108, 0.024372192783630453, 0.017712447115627583, 0.021861336499569006, 0.03408401149499696, 0.052909600344719365, 0.011459544948593248, 0.07354274552199058, 0.02435153139231261, 0.018633214895089623, 0.030988263060862664, 0.015501206053158967, 0.0576193993765628, 0.0313980714417994, 0.014622629369114293, 0.03502057588775642, 0.04235258304106537, 0.016198284029087517, 0.04013485282484908, 0.01689926106337225, 0.05077845649793744, 0.014291352272266522, 0.03297942857898306, 0.02757138918241253, 0.04037180573504884, 0.10038986350991763, 0.013217830091889482, 0.08716448763152584, 0.02132677680492634, 0.027177190022484865, 0.0846943307260517, 0.03832213486020919, 0.028893150483781938, 0.03668010343972128, 0.03617421847593505, 0.07026028571999632, 0.02279544438351877, 0.034471969192964025, 0.04379887301183771, 0.03341633462696336, 0.04602758330293, 0.024325754748133477, 0.016538892705284525, 0.029390092568064574, 0.10868421726627275, 0.04127833170059603, 0.024972167229861952, 0.0744989063241519, 0.02485311561031267, 0.11154753432492726, 0.03473475997452624, 0.03584528007195331, 0.0272499075072119, 0.02358730667765485, 0.01333547070316854, 0.047064230020623654, 0.03469669522019103, 0.019535577412170824, 0.04481770818529185, 0.027673232252709568, 0.111814677802613, 0.15665757819078863, 0.09248723756172694, 0.15776722255395725, 0.13834708806825802, 0.12022745606373064, 0.14348533266456798, 0.2314833560376428, 0.07047868493827991, 0.1239785153302364, 0.14115271798800677, 0.13374320464208722, 0.30203938018530607, 0.19623190542915836, 0.10007959383074194, 0.10040518143796362, 0.1791825913824141, 0.22294657974271104, 0.20378990768222138, 0.10028948803665116, 0.11988738173386082, 0.1826186163816601, 0.09599102064385079, 0.0889536646718625, 0.15647827531211078, 0.09570697104209103, 0.15767009026603773, 0.13643663667608052, 0.14388389565283433, 0.06806897596106865, 0.1819836942013353, 0.16354855295503512, 0.10943696281174198, 0.11997878464171663, 0.12115612771594897, 0.1150491058069747, 0.1484925436670892, 0.05867124527867418, 0.12627875752514228, 0.09955725545296445, 0.09047120824106969, 0.15078359807375818, 0.15786036208737642, 0.19474391418043524, 0.23462608427507803, 0.10955831137835048, 0.15792938182130456, 0.14262785523897037, 0.04529404082859401, 0.14288581092841923, 0.068701560376212, 0.11182776186615229, 0.1723938251961954, 0.19916450197342783, 0.17540428787469864, 0.21008832205552608, 0.15706663514720276, 0.16417317412560806, 0.16126818547490984, 0.136250491195824, 0.20453846751479432, 0.15671168075641617, 0.17673828348051757, 0.12219385796925053, 0.15968582272762433, 0.07245300555950962, 0.15490342309931293, 0.16460155660752207, 0.11759821238229051, 0.1408304477808997, 0.08926389724365436, 0.1670967016252689, 0.11601749720284715, 0.12449380330508575, 0.16836555150803179, 0.17889551381813362, 0.1339816566905938, 0.092527150263777, 0.11095381618360989, 0.08890405952115543, 0.15066659107105806, 0.16461055143736303, 0.11422480980399996, 0.171305020339787, 0.12150354188634083, 0.23971671267645434, 0.05656561646901537, 0.16120951127959415, 0.12437808021786623, 0.09645527112297714, 0.13772708305623382, 0.22341980278724805, 0.11737996901501901, 0.1614273464656435, 0.10444510684465058, 0.16777266457211226, 0.14198058372130617, 0.1328520040260628, 0.16422671265900135, 0.14987989969085902, 0.1376974565209821, 0.11853086194605567, 0.1884147006785497, 0.13814813311910257, 0.11873709736391902, 0.16888815705897287, 0.08974522454082035, 0.13563726941356435, 0.16785005573183298, 0.12103382920031436, 0.12131895491620526, 0.14971377735491842, 0.10990750670316629, 0.11759069442632608, 0.171605619834736, 0.14350096229463816, 0.11787045441451482, 0.08382724248804152, 0.09516375605016947, 0.11635985734756105, 0.20128351170569658, 0.14748010580660775, 0.15553006291156635, 0.1569923758506775, 0.14889882499119267, 0.14861271221889183, 0.17287516733631492, 0.12992060976102948, 0.12200218348880298, 0.1374754059361294, 0.15624040213879198, 0.14998578932136297, 0.1388973608845845, 0.13643816550029442, 0.1687407071585767, 0.1927997247548774, 0.17572753771673888, 0.08293721446534619, 0.11981425792328082, 0.11609195687924512, 0.1455181196797639, 0.18460242165019736, 0.08496670634485781, 0.20197439182084054, 0.1577637789887376, 0.17831038974691182, 0.23336303798714653, 0.14789339300477877, 0.12105780057027005, 0.09084400386200286, 0.09900307893985882, 0.17073074646759778, 0.258498199400492, 0.15928976819850504, 0.12478601653128862, 0.11575880678719841, 0.11727102173608728, 0.16913738509174436, 0.1737062688334845, 0.15398050309158862, 0.2737289696233347, 0.1436076089157723, 0.1246891514165327, 0.09648381412262097, 0.08508398794219829, 0.2103506712592207, 0.10914411876001395, 0.12722539657261223, 0.06373720840201713, 0.2379140062839724, 0.08276392298284918, 0.08303140784846619, 0.12269367958651856, 0.08925833855755627, 0.20292456349125132, 0.1440977380843833], [0.016604858501523267, 0.05975019812467508, 0.033089025237131864, 0.010666931229934562, 0.06725348182953894, 0.02381366357440129, 0.10002041497500613, 0.013968528237455757, 0.03509544003463816, 0.033296819165116176, 0.057923965650843456, 0.047903176018735394, 0.047647509854868986, 0.07446494564646855, 0.043833887539221905, 0.0543826484499732, 0.01586877231602557, 0.025353369528602343, 0.03524211439071223, 0.011922234134544851, 0.053370741225080565, 0.011964328750764253, 0.017692941619316116, 0.020913537846354302, 0.019866805341735017, 0.0244673936322215, 0.07440285757184029, 0.027676152603817172, 0.019407545805734117, 0.04562268608424347, 0.032391013082815334, 0.020800800048164092, 0.05060289033281151, 0.04375398792035412, 0.01091617039492121, 0.04003881891549099, 0.018169298382417765, 0.057919097162084654, 0.03782444320677314, 0.04493696760619059, 0.029140335755073465, 0.04165684928011615, 0.034446584031684324, 0.058282545433030464, 0.058900594885926694, 0.06295266925008036, 0.01945603587955702, 0.02165695645089727, 0.009987240846385248, 0.08674241340486333, 0.032844157321960665, 0.029118657621438615, 0.012800346048607025, 0.05093415908049792, 0.034123575387638994, 0.0345653053955175, 0.057573323138058186, 0.06401205537258647, 0.04557772677799221, 0.0565692604141077, 0.029855159409635235, 0.054332501531462185, 0.012812027453037445, 0.04343146167229861, 0.051506206509657204, 0.030770054945605807, 0.04526187614828814, 0.013028683551965514, 0.06764500925783068, 0.016945504285104107, 0.029365868867898826, 0.024340076342923567, 0.038948615110712126, 0.011535820103745209, 0.033182461629621685, 0.06336435340926982, 0.05667707591783255, 0.02752284715825226, 0.004639172548195347, 0.05890332227863837, 0.018753197909973096, 0.05670647609804291, 0.034178880232502706, 0.025048682655324228, 0.04125519895751495, 0.01649711721256608, 0.009084946050279541, 0.05040258838562295, 0.0037015960515418556, 0.043885377745027654, 0.04889603973424528, 0.005179397148822318, 0.0549814948317362, 0.016320909089699853, 0.06084659144107718, 0.026457729800313246, 0.055064448388293386, 0.03766810979868751, 0.040105244843289256, 0.04677382021327503, 0.004516219551078393, 0.02054775552096544, 0.025963539228541777, 0.00677051816637686, 0.01629457954550162, 0.02312587635969976, 0.057996492032543756, 0.03686670905153733, 0.02006835966312792, 0.05302857774950098, 0.007295606201296323, 0.010221908869425533, 0.03136440762318671, 0.0442295413085958, 0.025929159237421118, 0.035264323159935884, 0.053274677629815415, 0.040727813975536264, 0.02114954637363553, 0.04258799228409771, 0.023624722052772995, 0.05086075696453918, 0.1023905303736683, 0.03188726921507623, 0.031754970259498805, 0.03990618228272069, 0.04204142278467771, 0.06367377704009414, 0.0136017486511264, 0.03935259206627961, 0.03284263591922354, 0.024861770907591563, 0.02660944519448094, 0.01079530329661793, 0.020106821466470137, 0.01760511029715417, 0.0581095099914819, 0.12482028891099617, 0.009720250436657807, 0.02884483852540143, 0.04971974572981708, 0.045529568815254606, 0.03316533286124468, 0.10888628181419335, 0.016254687252512667, 0.041208877810277045, 0.0588265174155822, 0.018188683279731777, 0.025622373941587284, 0.041595380898797885, 0.07036803814116865, 0.04161072851275094, 0.015066562627907842, 0.05490329102030955, 0.09109243037528358, 0.04902822736767121, 0.032569566392339766, 0.04097975084732752, 0.0420533750730101, 0.024919602765294258, 0.032220393331954256, 0.04800553302629851, 0.03878028117469512, 0.019064558546233457, 0.05133779464813415, 0.05069006670964882, 0.03388090422959067, 0.06249052647035569, 0.02893069202400511, 0.03760973617318086, 0.011772013240261003, 0.04251463840773795, 0.05201613988901954, 0.03602616001444403, 0.04133611531869974, 0.06125165193225257, 0.06367544687236659, 0.02298504827194847, 0.02783232459478313, 0.046041134919505566, 0.051773201557807624, 0.013845092380506685, 0.043802513246191666, 0.011959865660173818, 0.013594133288279409, 0.0781967536022421, 0.07464764014002867, 0.05501344428921584, 0.03613311462686397, 0.05945966957369819, 0.01877088699984597, 0.06957331672310829, 0.02670844583917642, 0.06542209142935462, 0.02827519751008367, 0.08007304393686354, 0.02291115262778476, 0.027664079716487322, 0.03975281746534165, 0.03835636642179452, 0.050756210621329956, 0.0295264640590176, 0.04990258123143576, 0.0721909457934089, 0.0604938263859367, 0.025251114566344768, 0.031163868188741617, 0.0377410146757029, 0.0506559204950463, 0.05003793783544097, 0.03803563988185488, 0.061460755750886165, 0.07028652064036578, 0.047161796464934014, 0.06304120746790431, 0.010338426054659067, 0.027277112785668578, 0.026653359927877318, 0.021201992094574962, 0.03652195548056625, 0.09190766475512646, 0.032040337173384614, 0.022241052647586912, 0.017421675511286594, 0.07775592530379072, 0.10883741138968617, 0.052285788115113974, 0.04701629099145066, 0.043321011544321664, 0.06958262325497344, 0.037316027519409545, 0.06239064081455581, 0.02351569684833521, 0.007542671337432694, 0.07569005334516987, 0.026733753074950073, 0.03121519141132012, 0.008580770809203386, 0.06536773653351702, 0.04819433539523743, 0.025359970932186116, 0.021490212566277478, 0.0639244299964048, 0.027189426182303578, 0.06313074758509174, 0.04133011505473405, 0.05031360858993139, 0.052100525790592656, 0.03658936846477445, 0.029638346532010473, 0.032681901575415395, 0.04717186740890611, 0.03721406013937667, 0.015571542171528563, 0.023765392434142996, 0.0797723479627166, 0.00550670561096922, 0.0452701399626676, 0.043831315997522324, 0.02446674981911201, 0.01428771853170474, 0.020299343850638252, 0.059206356017966755, 0.006437111105697113, 0.01761778989020968, 0.05429411765362602, 0.05053372216934804, 0.042607473660609685, 0.058949391095666215, 0.053757463247166015, 0.05214683580561541, 0.025892400662996806, 0.05930916202487424, 0.07099940543412231, 0.016648461532895453, 0.026305758365197107, 0.09683157710242085, 0.004261372996552382, 0.03482034444459714, 0.03661234164610505, 0.03979231456469279, 0.032746338547440246, 0.01400917937644408, 0.14896196691552177, 0.05501449813891668, 0.021803764393553138, 0.02306625035998877, 0.03194087083102204, 0.04159269061347004, 0.03628177793871146, 0.012784163518517744, 0.01689732220256701, 0.051106381870340556, 0.027305245748721063, 0.021680142999684904, 0.07276282995007932, 0.042073724762303755, 0.021977961296215653, 0.07387710531475022, 0.030863326210237574, 0.0787777587538585, 0.07305677238036878, 0.04478891285543796, 0.032324717030860484, 0.03635683133325074, 0.04850023382459767, 0.024032595283642877, 0.02709173542825738, 0.04785478056874126, 0.015453505438927095, 0.030989057158876676, 0.0322306312591536, 0.02141741344530601, 0.06793149310396984, 0.06774515466531739, 0.03106493990344461, 0.0752341074985452, 0.060118288529338315, 0.008489274205203401, 0.030657742026960477, 0.01873928078566678, 0.05053190019680187, 0.048804688776726834, 0.014425019562622765, 0.03021419746801257, 0.09948435428668745, 0.04421429388457909, 0.09034450878971256, 0.05837984470417723, 0.08283562186989002, 0.019481788403936662, 0.0695245576207526, 0.013243965750007192, 0.04700874334957916, 0.04141374767641537, 0.04881798064161558, 0.05330657513695769, 0.062387100770138204, 0.030813489138381556, 0.07224093686090782, 0.02544470007705968, 0.02916531273513101, 0.018904067255789414, 0.0741782391560264, 0.050669624251895584, 0.030826009169686586, 0.006423633703889209, 0.07060644566081464, 0.08463648773613386, 0.0840078441251535, 0.03911470033926889, 0.0487217686168151, 0.1162102552189026, 0.1512325825751759, 0.12582996598212048, 0.13375846319831908, 0.11606830463279039, 0.126244603889063, 0.23370660783257335, 0.0533831054053735, 0.0964417566137854, 0.13762919377768412, 0.16970542492344975, 0.15412348526297137, 0.16052208957262337, 0.16741129802539945, 0.1564692211104557, 0.2441421095863916, 0.07171003409894183, 0.14374680613400415, 0.13830503798089921, 0.14823681442067027, 0.10381223299191333, 0.16877592948731035, 0.154439476900734, 0.13198499742429703, 0.09659383009420708, 0.1107139021041803, 0.1616332182311453, 0.12360586813883856, 0.1496934425085783, 0.16904288000660017, 0.11936430120840669, 0.12248843864654191, 0.08849172969348729, 0.1822770354920067, 0.14541882032062858, 0.14474328781943768, 0.1589629560476169, 0.2429224195657298, 0.1169216854032129, 0.15810203505679965, 0.09677808309788816, 0.08262266259407625, 0.10464588747709058, 0.2142075533629395, 0.10062056753668003, 0.17260581225855276, 0.15650263259885833, 0.12587832432473078, 0.17594273085705936, 0.15174807835137472, 0.09195655744406395, 0.14073632861254737, 0.1771575227030553, 0.21518019726499915, 0.18220160360215232, 0.106142576696584, 0.07637207221705467, 0.11367426239303313, 0.10559620015555993, 0.15152893698541448, 0.14106452115811408, 0.14284929726272821, 0.15779107518028468, 0.08547781602828763, 0.10157783413887955, 0.1402825943659991, 0.16809671593364328, 0.115032793401042, 0.18155480705900118, 0.13970080995932221, 0.10399500912171789, 0.14268283353885636, 0.08891870951629244, 0.10326167073799297, 0.15773054561577737, 0.23067349480697885, 0.1269349199719727, 0.07196004880825058, 0.14555277797626331, 0.1846587803447619, 0.16600375558482483, 0.23209239210700616, 0.09277294215280563, 0.11392430678824894, 0.09384809891344048, 0.1673669769661501, 0.1099082562723197, 0.09790118259843439, 0.08181936937035061, 0.15604310960043222, 0.0672673006192781, 0.1400091129471548, 0.159199612098746, 0.14311589155113325, 0.20125027833273634, 0.09704118187073618, 0.12577691726619378, 0.2502196904970333, 0.12374441226711497, 0.08455907431198284, 0.18780477403197438, 0.13680088275577873, 0.15011915325885639, 0.19498045148793608, 0.09089159037102945, 0.08656306599732488, 0.14782337879296392, 0.22817664284957573, 0.1889924774877727, 0.1836273880326189, 0.1035630346450489, 0.10848942576558329, 0.1508476899471134, 0.07689724559895694, 0.11789457421400584, 0.1549134124070406, 0.15357836295152083, 0.130188777402509, 0.1043875161849428, 0.18628018005983904, 0.12710350623819977, 0.1302815310191363, 0.23245659365784377, 0.24051907821558416, 0.25507986720185727, 0.16976798797259107, 0.3057216794695705, 0.2488615008769557, 0.09038983174832538, 0.13637649302836508, 0.1273752807173878, 0.08974946962553076, 0.2478841962874867, 0.12359724438283592, 0.09738354943692684, 0.12355863786069676, 0.12274627559236251, 0.20002629869850352, 0.12373036341159604, 0.17027693800628185, 0.26356843358371407, 0.20067732548341155, 0.19790215330431238, 0.13710871076909825, 0.10378805382060818, 0.09195312872179784, 0.1592921430710703, 0.08283440474770032, 0.12467073131119832, 0.19710655615199357, 0.1643176405923441, 0.1585921790683642, 0.10578603410976939, 0.16481467173434794, 0.33975707658100873, 0.1381220985786058, 0.09726036034408025, 0.2725335181457922, 0.13716596004087478, 0.10628461634041741, 0.15435635636094958, 0.1261553235235624, 0.1293285985593684, 0.22876271686982363, 0.15752091858303174, 0.13516585720935836, 0.1646030557458289, 0.19281542859971523, 0.1346131056197919, 0.09994742475100793, 0.12722679181024432, 0.24313204659847543, 0.2381149205029942, 0.1579440911882557, 0.25375498516950756, 0.17364202853059396], [0.03281336190411821, 0.08137691576848738, 0.002192597153225506, 0.0695012096548453, 0.0077703608531010104, 0.017519802277092822, 0.08724887724383734, 0.013780096942355158, 0.042659275568439625, 0.011240127132623456, 0.010829629482032033, 0.034739309339784086, 0.044745393315679394, 0.04560334942652844, 0.07765273709082976, 0.04619827726855874, 0.05704828705347609, 0.04113015820621513, 0.027805978352262173, 0.01957441956619732, 0.03322695709357504, 0.011995014701824402, 0.026672139974834863, 0.027187724808754865, 0.05358725909900386, 0.0246074888491421, 0.04247514130838681, 0.02565841263276525, 0.03690197961986996, 0.036793251274502836, 0.13731493876548484, 0.03294092595751863, 0.06963826206629165, 0.043591713620116934, 0.04943046769767534, 0.0150456795199716, 0.035707058777916245, 0.04509354221227113, 0.01962548674782738, 0.04679948367993347, 0.1019057966186665, 0.046281609320431016, 0.09392284060595557, 0.03023897035745904, 0.006518045092889224, 0.01570444968820084, 0.02404461436526617, 0.05748641393438447, 0.01776737903128378, 0.11149726866278797, 0.04747884566313587, 0.03828935790807009, 0.029202869118307717, 0.0701222982024774, 0.022787644411437213, 0.018908841120719444, 0.029122121595719364, 0.03237733159039635, 0.0888073502574116, 0.02885536403482547, 0.01935262873303145, 0.012616927961062174, 0.03365792224940378, 0.0378661704598926, 0.043553626601351425, 0.040642229505465366, 0.012381424094201066, 0.014785872172069503, 0.014405769179575145, 0.048110795542015694, 0.01537653173727449, 0.009092996497201966, 0.07731854799203575, 0.051040705511695705, 0.005825599509989843, 0.04141505385632627, 0.05092223647807259, 0.0858110848639626, 0.015363353977591032, 0.013971540429338347, 0.024497645426890813, 0.042127511915168725, 0.07510535229812376, 0.05263829712930601, 0.06066348505555652, 0.0631844939198345, 0.015507854768657126, 0.04148603286012076, 0.03644522854301613, 0.048645049100741744, 0.06795116001740098, 0.06635002835537307, 0.032527976436540484, 0.011233686218474759, 0.026693489708122797, 0.10187421081354842, 0.05620332223770674, 0.04302283516153693, 0.017411064654879738, 0.02220073547505308, 0.04297439147194382, 0.06781015938031487, 0.023826050019124523, 0.018113110381818842, 0.05640577641315758, 0.048754174495115876, 0.019791174927377142, 0.048304737283615395, 0.04004619215265848, 0.02358053458010545, 0.02438299845380243, 0.042109117785003036, 0.026496720383875072, 0.047091567030292936, 0.030126319761620834, 0.0013933683476352599, 0.0731292059936095, 0.03598349023377523, 0.05873772686754819, 0.021248953344183974, 0.05580009485129267, 0.016291816900775302, 0.0556409375712974, 0.12471782800275832, 0.04826948897971306, 0.0749317194276955, 0.021159305615583435, 0.024688306875759736, 0.021163841993256938, 0.04669220623327419, 0.04499658432905562, 0.03951229482481722, 0.024641438394610304, 0.033374622216797434, 0.050135073834098876, 0.05887847888516262, 0.021297437851899303, 0.02648672365467064, 0.009515287802059902, 0.03525150255882181, 0.02055685796221951, 0.050406555164954625, 0.01997131828829879, 0.0236688520089956, 0.09010614579892717, 0.060207683927728795, 0.04314098507165909, 0.04669371650379617, 0.02118934404279571, 0.04854032464209013, 0.03298938077932689, 0.01870996038633166, 0.008970980925369076, 0.039442989364033565, 0.023372154355456587, 0.027067387418355793, 0.06489435021649115, 0.023720991594018415, 0.03151086675643455, 0.028543793741846457, 0.05362692318158224, 0.10801649215864018, 0.016235588082054164, 0.02741109270573361, 0.03209468464774545, 0.04071172792464495, 0.0371274737699423, 0.09867273416602984, 0.039771745941834524, 0.07254521740833297, 0.06566299998667091, 0.09169259777991101, 0.021888966657570563, 0.09885679421131499, 0.04283820737327915, 0.049162444774992764, 0.01654568150115665, 0.039808229921618477, 0.04293473110010382, 0.04993942515284289, 0.027952643431490287, 0.037270240718498826, 0.06192426779307425, 0.030180999347066972, 0.03703093891090248, 0.02255937648442341, 0.026469947406440042, 0.03376042397576384, 0.030421798437600955, 0.025435701536480337, 0.025624602239986416, 0.04592174933350179, 0.08833731844788417, 0.07874874820117839, 0.0366111579205608, 0.06517367233755067, 0.05015389840991702, 0.052751764087588526, 0.021417407879198436, 0.04289615055313334, 0.027610724864644, 0.04477225164009724, 0.015761227696202695, 0.026806991918419953, 0.043404751777416095, 0.01814987452235073, 0.009754450456966879, 0.009415748172614258, 0.01568561769090593, 0.03250170440878719, 0.05868750573426951, 0.03276137445936911, 0.0151744208051241, 0.1195425279729534, 0.036177483925712295, 0.03467530281341169, 0.04477933172893245, 0.03883721132297069, 0.08559869704185985, 0.021647978319379035, 0.04762078511703294, 0.04244813826517202, 0.0161945473155356, 0.10420234291814268, 0.08463190868496895, 0.008002001377462875, 0.0154080674474244, 0.08212151995394379, 0.03942012750485446, 0.06370723305735737, 0.037371477083070204, 0.010070209245895967, 0.044194704896654, 0.021733655557909515, 0.015926811975077726, 0.034048147208523005, 0.03556161267624702, 0.06985367785091512, 0.02698334847082151, 0.034595885590533726, 0.034144140299758874, 0.05503256201336626, 0.02387739921687171, 0.04401704587507993, 0.03630744511610828, 0.07819753285730258, 0.035645308380480856, 0.06200501346029341, 0.04058888021972962, 0.02716030430747196, 0.024234418633568566, 0.04607180046150461, 0.0337018944992451, 0.03477718113572337, 0.03981756613939069, 0.03628497288445942, 0.02969899298477685, 0.02607928829092998, 0.044794430723413825, 0.08471174151054583, 0.037224220141069964, 0.0519154712674208, 0.04642835418053437, 0.033343489121762104, 0.06357608814141713, 0.056484629603801295, 0.02703283116716193, 0.05701239308109507, 0.0398247352859471, 0.018369197714491747, 0.05005471408367157, 0.039494746743002906, 0.02931361239461694, 0.06050173025869299, 0.016058906840044074, 0.07527958630817011, 0.045264763102750294, 0.04535816238785628, 0.008471375458611874, 0.026092639527632855, 0.012999120099266293, 0.028851812858192716, 0.0642141570278909, 0.030743096431251615, 0.027919131753151305, 0.018358542329224292, 0.020364760457596276, 0.008737775860936381, 0.011296485827188008, 0.05648160164128058, 0.006975352780500543, 0.038257645937846974, 0.01796491091226926, 0.0582576166925719, 0.02615117085952079, 0.058722308749565855, 0.055521789472550154, 0.031132813019212335, 0.011354101534379879, 0.12144679727498442, 0.09378667135024443, 0.05742503461078741, 0.03820574755081907, 0.005795203924208181, 0.027917396982957143, 0.023952480441948865, 0.012320786918280646, 0.04519367648754269, 0.03862550627673045, 0.06047869770554826, 0.07382544441497885, 0.04038367267639842, 0.05484214918396901, 0.049394944799132645, 0.025545543103362434, 0.07009299079072662, 0.01534791081212461, 0.06431074754800647, 0.016381045315938536, 0.051031053881160915, 0.04036304097098764, 0.05303260018990841, 0.03208781978173647, 0.040678880468476564, 0.027169870591023937, 0.05826363922096789, 0.04579439679218922, 0.014608124092774233, 0.09170035322313197, 0.018170435723732226, 0.02628797279612627, 0.027098767277493607, 0.025282303322455846, 0.052718471342814155, 0.08497794988215901, 0.04971853602910414, 0.062481776549248025, 0.03580107033485547, 0.033515845498186536, 0.05049948318628594, 0.01265610222617397, 0.04243182214850094, 0.027789378364104778, 0.030815487371000927, 0.03957831628213171, 0.06306543858954683, 0.025679294813016895, 0.07614429967361502, 0.023761056436342187, 0.028971708670724183, 0.05005921520933043, 0.06446187850087881, 0.11697370253386907, 0.14939159620553255, 0.10414533855509944, 0.13957890478195623, 0.15802655863808468, 0.17134411667939276, 0.16797644348116592, 0.09362717639305629, 0.17236436193343252, 0.04508606136369053, 0.08231838946812786, 0.11339820572175086, 0.14275988331064582, 0.13322653627255931, 0.11303185936412774, 0.12400917345075868, 0.2183652576059103, 0.1323210122063756, 0.09953746979590505, 0.13118364120600745, 0.20181034749839455, 0.12799999094568193, 0.12312728678807616, 0.0683522537292447, 0.11911933310329914, 0.17920801736181602, 0.10209970496362075, 0.0772508121735882, 0.11586490421905182, 0.10382320193457417, 0.18465610861312598, 0.15397179027786478, 0.16655604704283178, 0.1343958344659768, 0.13759955239947885, 0.0708768174808938, 0.12313476021518, 0.14912452694261447, 0.1758113261894323, 0.1267258866573684, 0.21369803929701447, 0.10146224463824183, 0.3516691701952368, 0.1436347418348305, 0.13130263716448098, 0.1253804619773291, 0.11895318850292824, 0.22496128804050386, 0.25078951148316264, 0.13959407428046688, 0.09491924807662144, 0.25643591943662614, 0.123184113035677, 0.1684479447430931, 0.15744560543680564, 0.20400415087351575, 0.19786725752055645, 0.12494654307374731, 0.15610825532348827, 0.22173950623255223, 0.08602099391282536, 0.13633181573823094, 0.17917237943038344, 0.15946061059366912, 0.15538449806626886, 0.16460226906929165, 0.0964392555761151, 0.13129025814123452, 0.1217487029498443, 0.13730717590078712, 0.0978028480312787, 0.15041564125567675, 0.13978997158119455, 0.102454733569175, 0.15022161416709423, 0.10023327777162194, 0.08863835580996238, 0.1096877790405415, 0.2518911851802841, 0.09605539453332312, 0.13844971224898472, 0.17070987727493048, 0.14425796776777133, 0.20471980387810618, 0.1663839429966174, 0.17354923038510606, 0.16330987826222554, 0.15289478556951508, 0.18146258778870106, 0.1353524628211744, 0.18190535309258848, 0.1809441382647492, 0.09047517130966298, 0.10964540982968174, 0.13869616464944556, 0.19876789825502783, 0.13570452283602208, 0.07162795998738147, 0.10862929091672413, 0.17194187210407108, 0.155290586699266, 0.1570181135321036, 0.15980158292222768, 0.08542490089894272, 0.14413958037039265, 0.08509330189554021, 0.1777699132799171, 0.09161154783214442, 0.1356500046676956, 0.11621328318142332, 0.17329029506072402, 0.09929804553394206, 0.17373323848005384, 0.21913658652920276, 0.20743833534652367, 0.13386386301135644, 0.1204411723301746, 0.19565433642128482, 0.14936152438167483, 0.17695184389594942, 0.16789133398560807, 0.20619615825125948, 0.15252188604790717, 0.2505575161194429, 0.23150464083300903, 0.09024082333780825, 0.0924615295662079, 0.1308896765112877, 0.20711884077172726, 0.10695693534216844, 0.09698213660158217, 0.09755991341080517, 0.11740856396500021, 0.18284807360032573, 0.17893970129080117, 0.13120216521201655, 0.11799264160799794, 0.06609796531847678, 0.11199913118616678, 0.15018952370155603, 0.11597387376241386, 0.18915141583420336, 0.08828924954286776, 0.12007795783574693, 0.24639271694468334, 0.2333465771516785, 0.1402533834334463, 0.12068392141372897, 0.13160742237232625, 0.18364039045991376, 0.1819131604861468, 0.0955825945129618, 0.1462731065112166, 0.13398118171608075, 0.1255447734729387, 0.1496141662937589, 0.1621649818844162, 0.09721957932924852, 0.09555429642205127, 0.14997734368080273, 0.1631449582055211, 0.2015746562392451, 0.07716705338680185, 0.10566154625848867, 0.11695794673869386, 0.13481422764016315, 0.09641195938456804, 0.12764337414409965, 0.13315886724740267, 0.2702814561780542, 0.11949707142775878, 0.17534697923110798, 0.12336810628767125, 0.20733870944241062, 0.10402732223155908, 0.21012807148508728], [0.0932846826617606, 0.06451335386373103, 0.035704810070456006, 0.028189546246721875, 0.06316611834336072, 0.02171837473724736, 0.024835070289555006, 0.056876951130107045, 0.021856276907783467, 0.03332801163196564, 0.02889737515943125, 0.020275400311220437, 0.04196160480205435, 0.13255593163194135, 0.018732653406914324, 0.0769535597646609, 0.012136964360252023, 0.03971336118411273, 0.012968174396519316, 0.0475485110655427, 0.029647211486008018, 0.05981365546176676, 0.029188350854383316, 0.03653547741123475, 0.01592518667166587, 0.02976189185574185, 0.04453568093595095, 0.08258733636466786, 0.0341722194571048, 0.07606551327626221, 0.017486735887359828, 0.04192805601633154, 0.009463100905122701, 0.024292024136229884, 0.021071101364213973, 0.03046661673579365, 0.047783404515939765, 0.014097648017923348, 0.05547411761654075, 0.03151327131490689, 0.040823153976816684, 0.026881104640779085, 0.022049055332900025, 0.031309251207858324, 0.07973432773724198, 0.056130395096261054, 0.057790019127423875, 0.010785745362227317, 0.03369085876329336, 0.042429450986674055, 0.02738179642619798, 0.019919648111681454, 0.03315613394079264, 0.046419281425187364, 0.0391355917963665, 0.08732598638744093, 0.022305031343421433, 0.017647974891588092, 0.05174937490664888, 0.008333245077665197, 0.028272987765376456, 0.026844635503948666, 0.06438724813051522, 0.037825767940375954, 0.019692897876666393, 0.06960596379940398, 0.04029255549539812, 0.05616313123027794, 0.022140330220281612, 0.011205992050236091, 0.04865660805080552, 0.038965632556937635, 0.024534942058380693, 0.017673102156550158, 0.029999562793818768, 0.07546812150394544, 0.024747613751969766, 0.04378052712127101, 0.058985793439205736, 0.029610028032038826, 0.029492160138033796, 0.021919342761975713, 0.041657487527118064, 0.07372718406259082, 0.012499856020440347, 0.01144752679465455, 0.017315505720034707, 0.051154729080735706, 0.03317088783660438, 0.06006782248732634, 0.09943440774804913, 0.020428295720194, 0.03541123871400487, 0.03152025492454413, 0.020723145426018164, 0.03581780576496385, 0.018258968375448603, 0.0436215108493343, 0.08672893600305542, 0.010746722309704637, 0.051765193784376606, 0.029645448885275982, 0.033649524848442525, 0.04170682921539992, 0.045856317883590236, 0.030563099644496106, 0.05783295608125627, 0.0636664371995721, 0.023346696834778413, 0.06131893504061736, 0.0146926973866357, 0.029118542588548735, 0.027338514373695944, 0.03129233395156916, 0.03383928087714594, 0.01791288079402875, 0.046257047943072394, 0.048962502769427374, 0.04642035382858012, 0.05550439724174794, 0.0582335377112031, 0.030664289624837693, 0.05069028564321343, 0.05498495323990937, 0.039963175513548777, 0.032300274397130124, 0.08073455726844259, 0.08709443631232716, 0.018130049902538303, 0.010976193443639204, 0.03131748533633072, 0.1322219948633574, 0.014791047724429518, 0.01712977213173872, 0.056976320993271656, 0.02795852309645852, 0.040140726923709735, 0.003682697029034898, 0.09954503970220685, 0.03463317851128522, 0.04298512663808651, 0.05535122909350321, 0.09446620402741246, 0.01702534638752695, 0.09387276048073545, 0.03434694328461774, 0.03955543586926069, 0.05917373491683975, 0.05270426663628314, 0.05653424588672351, 0.03376619417394977, 0.020404990427778102, 0.0286986855280702, 0.03030399548151763, 0.007317474974115612, 0.023959994687174913, 0.039271634886972606, 0.04032336575619411, 0.031642980175092816, 0.013530269625334768, 0.036827642397838645, 0.07787377093336545, 0.022370327351382002, 0.03466266774921678, 0.0555988652195083, 0.04326063412008807, 0.016237564050243236, 0.05267810221994296, 0.04575867351377383, 0.03648043973953463, 0.04065464934683405, 0.04408080378198065, 0.07515610777772963, 0.04195184556010645, 0.0741805620782543, 0.030037909564271104, 0.03947095348848961, 0.027590926220000256, 0.02421869066893123, 0.023943589512782637, 0.07747447321889922, 0.02113400951202493, 0.020332180174591485, 0.08074180805124342, 0.021846287600055803, 0.08979177204309963, 0.03208704794815276, 0.046489733504131436, 0.05568742570176255, 0.03410430552321486, 0.04822132359549869, 0.06363858439726755, 0.05207089183386415, 0.011209744534426136, 0.05580218028626405, 0.09291085545555688, 0.012621288078662474, 0.020995331797166727, 0.04772355401655659, 0.0464842750079697, 0.06206329802807886, 0.04949936868797522, 0.05653347776387818, 0.0416263173246989, 0.0291080152237555, 0.03348453428770881, 0.026459453438292257, 0.0027230921978116385, 0.028620875054912176, 0.021411737870948855, 0.04909051953291055, 0.03626347657700535, 0.06502185860881582, 0.04314469209930394, 0.010276599587086821, 0.012466040989238536, 0.03912018109986093, 0.021178180286369752, 0.07178266067057848, 0.060501370317069814, 0.04548337383312173, 0.015190239682851825, 0.023626191505172756, 0.003456195181570365, 0.017291671647399198, 0.02701256311411271, 0.019969416534877382, 0.03678651999507565, 0.03988527227193117, 0.018006563950621057, 0.03773786054807715, 0.03177138656610623, 0.028573765375767834, 0.08848195560858585, 0.06276967047597282, 0.04345830144302454, 0.03893836234055925, 0.027473828304209746, 0.03684100847749505, 0.018947006064991, 0.023042468237690628, 0.025275577609136235, 0.01599658869963605, 0.03374259016709402, 0.024899149175325874, 0.04563742513710167, 0.04787721198226791, 0.039024514553602785, 0.013589826976385666, 0.09061562275746837, 0.021251088874123525, 0.03631163825048134, 0.025902833403961267, 0.042353354874649085, 0.05142252935911529, 0.08277202723547816, 0.04979584184184205, 0.07709254918154329, 0.08317022657138295, 0.030822001572232693, 0.07588457025121897, 0.060379672941053286, 0.051030949980486184, 0.027405053479014896, 0.06076344121538568, 0.04987080246792175, 0.02347635931073455, 0.014690246443933574, 0.022479384097096045, 0.03493553689622786, 0.027428922803665046, 0.007731210707788705, 0.030015656266186852, 0.06015515100443736, 0.05310146036208607, 0.04814935011381749, 0.12290495418710634, 0.047108870203373954, 0.050809652675525285, 0.041009703927556984, 0.023753052373649552, 0.031004046686575748, 0.043901753233512864, 0.026704516167228576, 0.0118353555444628, 0.03877790630212985, 0.007013384138190304, 0.04351795156253502, 0.009402142750332132, 0.023603149675182067, 0.03436309612879995, 0.05384805721405428, 0.009521999600110576, 0.015855960991757456, 0.04592894445522688, 0.04176945163635537, 0.017444594886910636, 0.02826638079568511, 0.0043040219043177785, 0.030386349753825925, 0.06927505499334075, 0.05622626944386866, 0.0493935606937157, 0.12676404789090157, 0.008563132741983281, 0.06604331356356852, 0.051517902757041156, 0.018840654447558336, 0.03031321852176916, 0.04814050371351186, 0.025107765031862073, 0.058528140652924776, 0.01375263283989625, 0.029174327974033076, 0.02828260785463499, 0.03448713126999792, 0.030644316575489938, 0.01651233123993734, 0.05011171102523804, 0.030641284902230836, 0.029456791235134006, 0.0249158307997277, 0.053377431686385535, 0.023951584298629314, 0.057460127063677646, 0.023191144537122454, 0.05358997907023877, 0.012285994107514853, 0.028219786909176037, 0.03266951513069216, 0.004571708077492076, 0.01100741374102654, 0.017030229719239287, 0.09078316259547137, 0.021384193059930112, 0.01905377514049178, 0.029061339701001998, 0.04748192186525557, 0.03238919853174593, 0.07796673977281898, 0.01641288159589749, 0.03049159742658958, 0.0650981736544054, 0.03379316382051911, 0.07979931760928594, 0.06596026723855175, 0.018345844182476867, 0.05186100876017008, 0.052427215487114154, 0.037225025371299125, 0.01424059308192227, 0.03615599875047337, 0.189184604678303, 0.14390604133950546, 0.08591020610765554, 0.11259027407504618, 0.1566238104715012, 0.10201277720625512, 0.08480611300910823, 0.2071603713557124, 0.0937517978309188, 0.18837836512830108, 0.14167364628519863, 0.1408630280639045, 0.06834920350229368, 0.1925689761992544, 0.07145999712520279, 0.22852043533930555, 0.2442949326359667, 0.09628523766878061, 0.19767140474868938, 0.18775046366499737, 0.09911595960147679, 0.14153015945339575, 0.10748954504379071, 0.13526661117793992, 0.14333101047668606, 0.17907147703226656, 0.11926825245609507, 0.17392621171893552, 0.11631417815806344, 0.2096511673880741, 0.14406958100153133, 0.16329261590726674, 0.0728728978720028, 0.08116582670481876, 0.12091864788089879, 0.11173097096616402, 0.15477210748940706, 0.15404245757963508, 0.10580430578556843, 0.09801731386687607, 0.1991237432230264, 0.1416167087154463, 0.15904699685052037, 0.10813981483806856, 0.15789007768034935, 0.16377453692257404, 0.1348905946360901, 0.1146731709013693, 0.1424988402868621, 0.10759964265162125, 0.11551438044989482, 0.1098515784542542, 0.2348090533632785, 0.11441944545367733, 0.2663242950802669, 0.12374045661999844, 0.1646341072046198, 0.07796806821716018, 0.22175758494995534, 0.14472529815975577, 0.056830255198292434, 0.14383684349013492, 0.17220511188497767, 0.08934991215937771, 0.09561319326166995, 0.16050936916144565, 0.1331561806728132, 0.181616242043674, 0.13738323119468987, 0.10477957795956172, 0.1426233578240499, 0.09698538720840588, 0.05295156879583374, 0.19087677559582517, 0.16578188311541453, 0.1446810067864135, 0.14094539161305875, 0.10956545826047659, 0.12388257790007629, 0.19810395810054615, 0.12943690759129822, 0.1386926171835512, 0.11496997060021386, 0.1607364069786854, 0.19657379802083597, 0.19581584259867668, 0.09971115461667068, 0.1226524829689879, 0.14248907362343743, 0.13979843206470832, 0.16793522459920496, 0.07715372441452928, 0.06840487199951895, 0.0886436844302807, 0.10446622836752795, 0.0795452507736627, 0.12043204391375184, 0.17223629693035036, 0.16566845326451585, 0.14868996979203075, 0.24691931525012478, 0.19351720344275236, 0.14204681297997013, 0.12977470352780074, 0.12117448102799244, 0.13057649019174278, 0.256306963856332, 0.10272878644173034, 0.15730548795545474, 0.242763421847485, 0.06940365434275009, 0.2141326855053194, 0.2649298886535689, 0.11348730797180906, 0.11006040396750905, 0.14699674502480775, 0.11966920515988022, 0.16096905543236062, 0.153820006235037, 0.15902164508588612, 0.1541090282262303, 0.11887805347214453, 0.15777718217577785, 0.12856311775976792, 0.20808250468689948, 0.16011655039619654, 0.17336684017209336, 0.19597432081354782, 0.08199564428650774, 0.1848240863182582, 0.15496047941269353, 0.31250125786755234, 0.12237786606419832, 0.11222828412428498, 0.15399546478874981, 0.14119681640295312, 0.11546971058123745, 0.0902525418496225, 0.15515627281274647, 0.12975696619832888, 0.10477954827365465, 0.17072287970222533, 0.12795556598575786, 0.1306723162997514, 0.16792890150099993, 0.10957154387142509, 0.18824129045242444, 0.16988854244118556, 0.1788985714665614, 0.1219358058006037, 0.1706198399187997, 0.07397950685117394, 0.11966824036790058, 0.09443960545468144, 0.12090302567230538, 0.0968370541522745, 0.1129701646277681, 0.20565333659760654, 0.10796564762131311, 0.10149060952244326, 0.17690584558295086, 0.1358248249744065, 0.11628870764980093, 0.13267032627481967, 0.1164671644801274, 0.12819109397241846, 0.12321938731474802, 0.21477578615304083, 0.14347176620503888, 0.17176243563881144, 0.10949744042591192, 0.11833848984679207, 0.17021663108607754, 0.12134025455452502, 0.1398342926404439, 0.10702948027756065], [0.03294032110716216, 0.06691422386211343, 0.013458451994665666, 0.083887289656559, 0.05068005884822924, 0.052066053031012416, 0.031760376805323176, 0.012674400804826291, 0.046214303947635926, 0.015651460344088264, 0.029360937296587508, 0.05093466374091804, 0.024135746389220003, 0.04939487800584175, 0.039953086015884764, 0.0351043717819266, 0.05546206884901039, 0.11967258935328573, 0.05432776662928518, 0.06317614475847222, 0.04419878670887556, 0.09329504304332659, 0.039298348492593504, 0.016369684890378267, 0.06798095724661835, 0.04930028386297636, 0.026740341490949504, 0.001195444056065753, 0.055132833585958, 0.02774166568997316, 0.043744135909946635, 0.08111899718642235, 0.05357975598599296, 0.02571950994024519, 0.03699084809341002, 0.04610758311173413, 0.08268452802440152, 0.06844243209343404, 0.0533024116884917, 0.049267484646406956, 0.011163830640725791, 0.011879084740940016, 0.04145509643421974, 0.03240244586777408, 0.019857611987390555, 0.02295847938512452, 0.012851759256591322, 0.012787042123818537, 0.07524351050960831, 0.032065217674244195, 0.090433380973991, 0.05586844665231183, 0.06195743437274359, 0.04194665794784669, 0.06079645565478131, 0.03407536918530241, 0.05103743264044169, 0.0202240845101187, 0.008876737447280902, 0.030360973869392183, 0.013971337266411865, 0.04750585983856581, 0.018178953723690938, 0.05236437042185571, 0.044236892281332985, 0.04447350380360149, 0.05088891775812954, 0.010414756870886777, 0.028432926155801397, 0.0715564243728295, 0.022601647360716015, 0.019689619439304806, 0.07560251702670939, 0.02556672214268474, 0.061859482011641376, 0.01917536119435681, 0.04786492572748102, 0.006292485077210586, 0.02272117395477835, 0.03627155856520403, 0.057136944014928304, 0.015533972800767515, 0.05434337770566344, 0.08996936056064442, 0.05449511721963063, 0.023304470487346407, 0.027758458636526484, 0.008119773719954537, 0.019268229843873996, 0.03782419458730146, 0.07663931959541515, 0.005513466112461174, 0.14261368021834642, 0.09693204163340852, 0.03839869852527045, 0.06848572156741284, 0.03639446935267188, 0.055788109166314825, 0.025812875828705728, 0.06060707069991622, 0.018491127011657227, 0.01932150491484208, 0.03677980726934038, 0.11609543755184859, 0.051694352077902295, 0.025539724665577523, 0.06845865544164553, 0.028012005968776066, 0.023015337174001615, 0.01604725326615153, 0.04707648287876509, 0.00513980496180011, 0.02578399515186902, 0.07826592176570557, 0.021254441526252776, 0.058404294759384356, 0.029714925040025264, 0.0512422171595972, 0.029547060512413736, 0.03427859519433696, 0.07507088696002029, 0.04694578696216922, 0.028157914057374, 0.013046583226241637, 0.03585636033676565, 0.02948827313957736, 0.06590824268641882, 0.026638507697498426, 0.008205459307646379, 0.02324484448763542, 0.062134818799677305, 0.007309758957489976, 0.05210942414123565, 0.023699795856373385, 0.14939699904061854, 0.032093916524900123, 0.0170827682086383, 0.016289751874865033, 0.02413438825897174, 0.05543246828892734, 0.011650686010398204, 0.06449557200539857, 0.011197621552128112, 0.04501389863435179, 0.043180905195185915, 0.029105460380378645, 0.02374596857407596, 0.03201528226782102, 0.04254929670423735, 0.05404456678661518, 0.02470833744155243, 0.017388108171871863, 0.05523088984773494, 0.006265677775445511, 0.06261853952310048, 0.07099599155480973, 0.029046602503512986, 0.02133000143658137, 0.06819178655860014, 0.033166167777380906, 0.021561955982178915, 0.08777260343777016, 0.047668430997873656, 0.048564834069111384, 0.1218963680730667, 0.023204768513096496, 0.03147586336126551, 0.03499625941913109, 0.01922499417560175, 0.029837902620784007, 0.036238674001651816, 0.04032169592392165, 0.042751023574965075, 0.05445842172775883, 0.05270185094559565, 0.026417676090204623, 0.05550378125917632, 0.04070545677677728, 0.05636927016894333, 0.06087362045946065, 0.03225444677809719, 0.0446223600738449, 0.024847438180586323, 0.0625853581004776, 0.004535193020274164, 0.05020404903916642, 0.027727225351554807, 0.019580401276471093, 0.04964891144481953, 0.04129435466893483, 0.02736792197538307, 0.018274601716257166, 0.0718366593355313, 0.022063002143113408, 0.020052438740094658, 0.03973442333517596, 0.04546469768683892, 0.03809000219916925, 0.022829037698102184, 0.018848534200515132, 0.0873123160272371, 0.05870216315088328, 0.11661659591482021, 0.020957331980753224, 0.04971094756911043, 0.005745448488596594, 0.015582264350086916, 0.04197488924546633, 0.03128078984445892, 0.004205390014249133, 0.033340071531711146, 0.061696146440226585, 0.028931146589457057, 0.024282398480863776, 0.06453309499192983, 0.04312840195780154, 0.05561142235819716, 0.03143948699289467, 0.05280148427118547, 0.005457946044771234, 0.0314075226924615, 0.01748412352753803, 0.04247573502652813, 0.03875694063026458, 0.05227167246630415, 0.03639741196820978, 0.05433876896859147, 0.03675512343761511, 0.03522808779962361, 0.03267938569479156, 0.054130366479512304, 0.021371789916884154, 0.013454048275889363, 0.007492864879168337, 0.028299003752181306, 0.014791586709179683, 0.08727172054932453, 0.024026151586440392, 0.03129476448521018, 0.04005148366559297, 0.02981812252983218, 0.023897153332654852, 0.07370060033281334, 0.035760697501245886, 0.053919251440675, 0.04027140799735207, 0.04408345324918628, 0.031547432372462936, 0.03033995995792793, 0.02425403359666234, 0.04575275488605257, 0.02579645766672911, 0.014580637725885026, 0.058270266599720344, 0.04780896408192348, 0.0331075195572339, 0.0555429369705962, 0.05121085399878211, 0.04470949563255999, 0.049226469855057076, 0.03094768984738039, 0.025673450400063302, 0.06255311920540407, 0.042990407018805854, 0.03836466734355781, 0.04042826833028812, 0.014854474447929533, 0.02717752955504693, 0.03207981200830545, 0.07121799761080183, 0.05996355816023424, 0.07586950465338305, 0.008270280341093894, 0.023015769475023262, 0.07456037841620855, 0.06612408149521798, 0.022179189072630834, 0.011512269902596017, 0.03954784740926698, 0.017932781483978033, 0.05700971021724399, 0.028571297734742984, 0.01496020173362922, 0.03424556962272618, 0.02532653717935318, 0.0847688052454032, 0.0302113364887191, 0.023702942562522367, 0.014058174110687105, 0.04287850599212106, 0.026236508565489203, 0.06512157357065007, 0.04020671498437878, 0.04407079963129945, 0.0364804248965811, 0.03663233510451391, 0.0490910390362842, 0.08391411829506978, 0.03831033842288889, 0.05604892583505716, 0.0770043300872203, 0.04712961323093623, 0.026761641129269265, 0.01650962240091758, 0.012697779384325258, 0.03556454787030816, 0.008166614370566094, 0.00926195290958276, 0.05513421398063656, 0.05486913367349189, 0.02254505303426413, 0.025632773285906296, 0.021870891650905833, 0.0723919935990125, 0.08935150035540573, 0.03641876355686691, 0.045115520915715024, 0.10129896472790278, 0.03846555118798278, 0.08543578820535913, 0.043578622135100886, 0.07435805411660112, 0.0035359797675482696, 0.03456024765910115, 0.04000709581305273, 0.05129428995132912, 0.02489804337528767, 0.006545723490489763, 0.04826793789106887, 0.06356190569931641, 0.025875552055367734, 0.08232843814766966, 0.05170354728761595, 0.05074066262750421, 0.026831699869944714, 0.03451355543802492, 0.04955986485583708, 0.019615564233390614, 0.021686941072402988, 0.0213856124173617, 0.06740136959706433, 0.02073773976007942, 0.034108717591152526, 0.04943249747157097, 0.010386187896074262, 0.10837140944204293, 0.014687003258586628, 0.06655696139205247, 0.0982777334866114, 0.02897580347053008, 0.040445523263770156, 0.053302497035474516, 0.19863866065861657, 0.08488412757287733, 0.11215378734050319, 0.17388371634297073, 0.13926322484621778, 0.10471020199474879, 0.07842098610126413, 0.1295724682859145, 0.07019976357696578, 0.18495264113880694, 0.11561373918084428, 0.1687372784363106, 0.18068946286803111, 0.13385954371187836, 0.08908210074878298, 0.18569763866253197, 0.1476507552433759, 0.15561073436401784, 0.10782026831293479, 0.13686362392036244, 0.12481978425057605, 0.13742517738137394, 0.14886514632962644, 0.09565664600813761, 0.32804188958834857, 0.1490331388777122, 0.14301448449259624, 0.13492675207089633, 0.09454766957787797, 0.09946692123776302, 0.10492071960470639, 0.19970414723502472, 0.12407964779413305, 0.06661093037109822, 0.14451139635639265, 0.1408379286294803, 0.14214082824764773, 0.08568952849600464, 0.12267649886780418, 0.1179643435170874, 0.1878777123056352, 0.2680721419164911, 0.10785416219732724, 0.12409406030201353, 0.13231198769062757, 0.21343077707570046, 0.10434729920234531, 0.15638973709428683, 0.2601034945109859, 0.1553864573361352, 0.19448460778221488, 0.18776137323584408, 0.15637208882253617, 0.14533742156345397, 0.21029394149081782, 0.07903902442194521, 0.2529454801697284, 0.08422289625741541, 0.0923537697235588, 0.08608567950432189, 0.23901336448034272, 0.1098328763328027, 0.1514099261839874, 0.10065869908430614, 0.1024414788116701, 0.19774904823862016, 0.13061996520264074, 0.0787926759221591, 0.07520868151914328, 0.15023831248981878, 0.09880717421765439, 0.163436503498815, 0.12090398304280825, 0.11020109290257096, 0.14967254363000393, 0.10136465221876279, 0.1049860286002513, 0.11001732971635647, 0.18957684456836432, 0.12960068474058062, 0.15292464959202334, 0.12984149681869894, 0.19380868936423212, 0.17687160288915038, 0.08744321603444405, 0.1437446687486954, 0.09441537433303893, 0.13943292433395982, 0.09003470666357316, 0.1004044318688102, 0.14281722164014354, 0.11267631125519983, 0.2818984421901405, 0.17181872011860833, 0.08293386737932451, 0.15807248273631558, 0.25003501446917653, 0.14583912823582068, 0.10841262090252712, 0.19032072887057438, 0.06114185860496946, 0.09307461034040898, 0.20639846770791337, 0.147225801483728, 0.09977111272746697, 0.11729261081200093, 0.12471537891542539, 0.08808584170765243, 0.1114280559704639, 0.1680095581104979, 0.22353444976033643, 0.09868660490610637, 0.1272523365332745, 0.1691941000171937, 0.09131878541666083, 0.10079225598019548, 0.13993762928294018, 0.11354771137121134, 0.14277045149356127, 0.0857928502955474, 0.12491691653849557, 0.14358161890413612, 0.1419788322527893, 0.12577187066199258, 0.13126462436048314, 0.12944599147886038, 0.1351002958836034, 0.10834431363036856, 0.12687406386248767, 0.12243271819897927, 0.12710046343272552, 0.13044876657659188, 0.16590172512223944, 0.09563610336044803, 0.21080817561596632, 0.1824725468759425, 0.08794780966127291, 0.10227101491182111, 0.1094794285017997, 0.15868255781242624, 0.2110787626588717, 0.18746197602013126, 0.1243850341415964, 0.18294366222107783, 0.1853946049232036, 0.164708336815238, 0.09393355721840635, 0.08888010299415328, 0.11905514475074597, 0.15156331326579675, 0.13728676683967933, 0.08686470449902117, 0.1877368675195612, 0.11376503447536379, 0.11434161642682739, 0.18396821193164214, 0.12501096149208024, 0.09907033236231655, 0.1483158828341402, 0.1330118626356125, 0.11066658276831731, 0.15835022408282384, 0.13971848791697994, 0.16752897296100855, 0.15438788279425353, 0.13023692794376984, 0.291853848611936, 0.1573728007497266, 0.12367967472528107, 0.14578885515220463, 0.24059782008407637, 0.0810689467471093, 0.203536672051996, 0.1684873379417695, 0.12458511715522036, 0.10507121231057681], [0.04775129920744803, 0.0382845747662941, 0.06681175553239882, 0.024363646953133866, 0.031435223354492337, 0.028898829768877476, 0.08145112311467528, 0.05535210853850003, 0.025637508188083302, 0.015914920913928654, 0.095871683297446, 0.07242358682560734, 0.024434854167338926, 0.041386752054677345, 0.03888587394612841, 0.021559260130743496, 0.016282400902127847, 0.007821267081453698, 0.11882006947416812, 0.044354381680022925, 0.03216273587895557, 0.024691470280231442, 0.05461855122121051, 0.057071315895882435, 0.10540731615037657, 0.03368616096850019, 0.02236396714579314, 0.027483928934088908, 0.03601963282562792, 0.049943314006668516, 0.02857759485777933, 0.04046851499879267, 0.050153033807873726, 0.04599430911184754, 0.07415538842906244, 0.007017507696218672, 0.027074699428339954, 0.029443258172250353, 0.0689086269994732, 0.024731579651415814, 0.00952717515247059, 0.03716807295859326, 0.014692556378577137, 0.012315834010223625, 0.027930490323342383, 0.0566933771915501, 0.06599640983040445, 0.013111546195432311, 0.041155365252052434, 0.022641775285592303, 0.007263759716806817, 0.026098478374478873, 0.05316227565344889, 0.01807037380785914, 0.00360627506779565, 0.07346768470597453, 0.040531419435865246, 0.03430024364206474, 0.019547459196473937, 0.058532916373224, 0.03975155210355297, 0.059247612007311545, 0.029248839600768406, 0.05753654972068034, 0.029523543707909994, 0.04068726673722267, 0.01176216957901488, 0.008985678232420469, 0.05126663752889726, 0.045015030409558676, 0.08023929985938594, 0.051430559396976605, 0.0547479372471571, 0.039602777469553985, 0.02873087618354475, 0.038909344366402365, 0.03782443207455799, 0.04086222805199213, 0.02744588829955319, 0.01935479765961645, 0.012955280508322176, 0.01048770720444736, 0.032991677726386115, 0.05711667596187908, 0.04614792254869826, 0.04988947861420456, 0.04326835616666358, 0.03736997052328661, 0.11586955006350763, 0.08659068873384967, 0.008763240803091321, 0.05461289605591446, 0.03943662544770632, 0.01738444381771842, 0.07894811875303276, 0.029426394721667748, 0.00571108287658717, 0.013685391477338271, 0.0008473623006466369, 0.023034968835418113, 0.013495456405507866, 0.07112039776984602, 0.019207557415938936, 0.14912713930243626, 0.05444095157145057, 0.07095470587955788, 0.038526904536411166, 0.046647258059238084, 0.023747079940221738, 0.05611109925666824, 0.027062294429924805, 0.007906201244622935, 0.05282624231767841, 0.010769702912512003, 0.04667524073738605, 0.04233002175169531, 0.03716634375450667, 0.014773050643270835, 0.03967148550145794, 0.04941090468491893, 0.03212204763258342, 0.045379580769804306, 0.048146923290914856, 0.009561496699461713, 0.06266447846428491, 0.04356400553660933, 0.024411771519226022, 0.05172434597625397, 0.04107713917619549, 0.036781751696253195, 0.0513768019300187, 0.01701135690382216, 0.06460023709223606, 0.03369017969816923, 0.007331062770390417, 0.0272726153707481, 0.011210894863324938, 0.022195072888280265, 0.01954462604771834, 0.05173904421098996, 0.05782292595540639, 0.08882718786480837, 0.043683335461537354, 0.048278995891450904, 0.02339003825909458, 0.09866573571343906, 0.04704073362518102, 0.009604770402802387, 0.06896874838275835, 0.020228212706570048, 0.039010458276607096, 0.01667916603764752, 0.04506138866418041, 0.02622433919896139, 0.042115748874493875, 0.051939943587058224, 0.00812448728538584, 0.10955790319712833, 0.05765369402070064, 0.09723537223180756, 0.02202807296271203, 0.03124676237348467, 0.018651061691343784, 0.04131265974137932, 0.03702968097059056, 0.06549271420226432, 0.015675045797252096, 0.032015044780564494, 0.04813723084225785, 0.024063622622634284, 0.06277579319430515, 0.06715941461152397, 0.029795073278364725, 0.05760601103247609, 0.02181412848585751, 0.03677819680888206, 0.04575264727463946, 0.08229861123254523, 0.030857947494951077, 0.04451234039152041, 0.005620224519589101, 0.009926263210218167, 0.03498211037367582, 0.02728495357587235, 0.03627872029028367, 0.09101993739022873, 0.023355938428721856, 0.015484297146031167, 0.0529474610084435, 0.022300235214061104, 0.08003042239579372, 0.08255591383203864, 0.0909010972827673, 0.038193323998712, 0.029680867883143947, 0.026987740129698068, 0.025548094236000907, 0.05056534879258834, 0.03534955139912199, 0.05234074415056966, 0.042638432350941, 0.014909048277331749, 0.04500973147514742, 0.06927820169948973, 0.046174528542906046, 0.04669779460527934, 0.02949622710730182, 0.017804519811761566, 0.0779113829776179, 0.018018941118498333, 0.13002691499423236, 0.017908435329445638, 0.039022952332743444, 0.004347978383520967, 0.039857538213254884, 0.0639961363049224, 0.039722114815958776, 0.06819792411988601, 0.013352051209949423, 0.04406800173455849, 0.03040642484847922, 0.06046191032510251, 0.02939235982921673, 0.013490409801306669, 0.014023236581124365, 0.046464749102597125, 0.030961007687437814, 0.006001822475809604, 0.021557786967605352, 0.017756575216480996, 0.011862940245919162, 0.05106304044602439, 0.05917475908063352, 0.031864748743828386, 0.020953318817191757, 0.020782706487807445, 0.0037484037693502614, 0.045020848847343586, 0.04981200581823941, 0.031168514033197425, 0.04548049058939796, 0.048546632897341624, 0.0407098799769301, 0.06790114668547176, 0.051314676748006605, 0.04113960203540046, 0.028085452613595407, 0.026361823911429383, 0.06151961177238263, 0.03389290475752205, 0.018953657563542947, 0.0136011066933861, 0.1300974635523744, 0.0031931822195474524, 0.06621124673984013, 0.04275369159586262, 0.03889827523380518, 0.048682872657082044, 0.056562458630651236, 0.016366896270483267, 0.03046149962756317, 0.007155075436457992, 0.030530109324899968, 0.030035111667530145, 0.02608288028568495, 0.0020350250542833237, 0.03306271981273312, 0.02458839153405279, 0.04647566980565898, 0.04369552894786466, 0.05724236980313435, 0.06603923917282373, 0.008482208959321724, 0.0468510889186291, 0.06320702552329749, 0.03809659989201464, 0.04033309902297333, 0.03632208397903014, 0.04466695201699622, 0.0576118072058307, 0.030888078690622933, 0.012855759432568448, 0.031727128589409404, 0.016462278945255093, 0.07235534634673968, 0.07341400516452268, 0.024247899746114854, 0.11979554095887579, 0.05323412668076344, 0.045450188699760474, 0.044998584417044185, 0.02826795600412879, 0.06348485592752695, 0.026059437695948873, 0.07266484419233166, 0.03104618954239413, 0.050831675907829776, 0.02430682256090222, 0.037104404109413736, 0.03746331043657847, 0.052582253847504035, 0.050515276088844985, 0.03623596145189367, 0.08249323946074583, 0.09073026973055676, 0.0334248915896751, 0.0720709256711416, 0.00984425032584113, 0.03135551669402048, 0.01929411038872786, 0.019011827098438516, 0.05110398844408337, 0.031714805227238685, 0.023042605535010807, 0.02551339697674848, 0.035394607184571214, 0.053227547541609965, 0.047453041188418865, 0.08874004488461651, 0.04768293256347533, 0.04267260825145058, 0.10398746890132315, 0.03626266021456104, 0.014714751232531853, 0.05992488484480418, 0.048392010139650665, 0.054619556831312366, 0.08580561523558572, 0.05055699963122606, 0.040160672142519616, 0.030994337539596017, 0.020540382283797953, 0.04879601678112522, 0.013857941739843227, 0.018106184288626537, 0.026280655220034532, 0.011686245088640135, 0.08607541560195386, 0.017398299714841414, 0.049776193482102826, 0.022682656490360387, 0.03621898853452876, 0.12134230288211256, 0.09582311715348624, 0.05441866858745925, 0.018538761760282796, 0.0044877164418721804, 0.004413653814481222, 0.032980122487060726, 0.04889316020125989, 0.05409285091445781, 0.053349868321674876, 0.13842422689776868, 0.13822683045873418, 0.14216444338671863, 0.10431612157844938, 0.18082045193295926, 0.0857209213427268, 0.18916560569778085, 0.12994636228540912, 0.10163846018258482, 0.09017354022944346, 0.1282115327194333, 0.1615015315474011, 0.07087752994266339, 0.0909577973652631, 0.29016160347964615, 0.15584684122586623, 0.17838865664089099, 0.20574583788402379, 0.22166802256833762, 0.11479052671347745, 0.10713851661421359, 0.07730720055405982, 0.11310272704577073, 0.1166391497827135, 0.1295389825827442, 0.08197864910471253, 0.16221117315581068, 0.1542629793402739, 0.09505763635388575, 0.18379613757133484, 0.09033421520143747, 0.0883947458351031, 0.16964502894552425, 0.13171481114113703, 0.1711725172935985, 0.22597504692384973, 0.11573893207241781, 0.08620543987490237, 0.1374838367337361, 0.14041367248864844, 0.16423774097347632, 0.15158128808252513, 0.10960766419884749, 0.1101094821933657, 0.1826870275544934, 0.12195205883472227, 0.14081564935622737, 0.09558027901221067, 0.17164799646707252, 0.10633253681589849, 0.06577706808457151, 0.11096196496509947, 0.17039510275935754, 0.15224524307996035, 0.06137582066003233, 0.15922377642709762, 0.10026096730143763, 0.09818765902309678, 0.08077096703345887, 0.10427904388052411, 0.09655908273998648, 0.10685590677894652, 0.13731856044614688, 0.13053118949756026, 0.1384750788565725, 0.09383704833453521, 0.21649149799486622, 0.12621309229871258, 0.13102863624226302, 0.17017787613440305, 0.09952720589353703, 0.1534171833191067, 0.11545335364644416, 0.19172157713910565, 0.08448431777651422, 0.18727872491581365, 0.2326170014566742, 0.0827382669376675, 0.28257539961487055, 0.08706322900252417, 0.1269211753970012, 0.12052249687258154, 0.1657035420066677, 0.15287269925465807, 0.3842341649578884, 0.15991330583347008, 0.15645145409507677, 0.14026395161636174, 0.12520700722234324, 0.20297351555200294, 0.14110392919974402, 0.1376695220824331, 0.1452883062302135, 0.1538480891031213, 0.20427487150300294, 0.2802926127333194, 0.18685709597775713, 0.11407695172238164, 0.19631806877441704, 0.14615307154599577, 0.12039871406159364, 0.13016758166486397, 0.08907180716050789, 0.2687552443239838, 0.1626868749735877, 0.15392306086141616, 0.1451440030359663, 0.13435314613161609, 0.19963304948760197, 0.19777183217229322, 0.20299048104789108, 0.2581324690254405, 0.11328241584124044, 0.12071306555299088, 0.150818211841397, 0.18829943030141294, 0.23971828602952883, 0.11896619093022309, 0.1433083601295948, 0.15586883848300204, 0.05796422716230154, 0.12257495080120862, 0.22156152437673882, 0.11951547669013962, 0.16015106026316062, 0.15116929222131148, 0.1843754283618182, 0.07801058585755527, 0.13403066812315956, 0.13360733224544674, 0.1987888861913234, 0.09608155523892492, 0.16137086902745068, 0.10057576408144087, 0.16090488934423774, 0.11634632057393901, 0.09496501632384025, 0.07044676516670734, 0.10311235062545165, 0.135320728586521, 0.1599776351940818, 0.198152108641807, 0.1877565195900388, 0.1388547764508985, 0.14719613041961566, 0.15449411381268874, 0.22618556453380734, 0.1172045995190274, 0.25008978496771306, 0.24555089883506298, 0.2650034206453711, 0.09190992830554023, 0.18043257587123662, 0.10832869884325191, 0.16932381258811802, 0.08155979579896666, 0.10766365288873203, 0.1697159485775046, 0.12151402843301184, 0.16579455899773166, 0.11720903756213374, 0.13672530243638903, 0.13523453555535525, 0.13751739665167406, 0.0870013413077686, 0.15860160434385762, 0.24586944346083328, 0.26182313973549753, 0.1423047241405584, 0.13531974895158783, 0.11973977598245256, 0.16253930632956326, 0.15634464420145378, 0.18956977932248265, 0.09767806332092732, 0.13293554016854614], [0.02239280514913844, 0.010977648980770027, 0.02783617819659412, 0.03518425284710247, 0.04250756945111789, 0.07319144991924986, 0.0754510669503361, 0.036965511171729304, 0.04572558857034892, 0.06321686640148982, 0.03366119883139618, 0.04902694716292899, 0.023911671596579254, 0.01427122151653748, 0.012771391157002654, 0.03428829135373235, 0.03872144370689057, 0.0012000838705716887, 0.0355103154288372, 0.016985057045530993, 0.045133250823710114, 0.02738389670412289, 0.049609173147473484, 0.022543717168446165, 0.11421514704125002, 0.038654260788462125, 0.016384375703637488, 0.038797844099462964, 0.03030811254575383, 0.025045636139111593, 0.050799578020814806, 0.01939089943334693, 0.024955389126262162, 0.010694565098674502, 0.05001355086278636, 0.04059299171785824, 0.023937984442454763, 0.027417948294896632, 0.03097468175838003, 0.046664679975947365, 0.021302534551068675, 0.0416152296384098, 0.07535117387305945, 0.0009526970598017215, 0.019198584850528277, 0.019904435939679388, 0.07985690084751695, 0.03545876585121732, 0.09791133517865092, 0.0284420879688696, 0.01519952302260208, 0.043566985259531066, 0.05072237610875163, 0.016715800302335992, 0.042579899163683876, 0.03716059582075104, 0.02057425390376011, 0.023088243906386197, 0.044875347084598616, 0.060916746660950594, 0.01889219474833226, 0.027167868647666182, 0.015508349224546691, 0.02540019719162956, 0.012643879981624195, 0.05648861864756327, 0.006560910615007742, 0.029024879841017537, 0.04511778075539041, 0.06789650826249272, 0.010220434778602794, 0.014097692546783946, 0.017916016367962584, 0.01396440653479658, 0.0014005420166540716, 0.07635714020580053, 0.05312696426699404, 0.06099924379668664, 0.08437413853243925, 0.033785089253797196, 0.07599647127790377, 0.05829115805681795, 0.030073003872530535, 0.01782125524186995, 0.026059933079523034, 0.011288170062471181, 0.03543383711075876, 0.027803685115941335, 0.06119293691881467, 0.05050251114880666, 0.06603187706787139, 0.0357514651841484, 0.026625531245372258, 0.0249515522227739, 0.03985250645200722, 0.030678980438096914, 0.007384638875009841, 0.06814612221205607, 0.03378852168680169, 0.051352455775486305, 0.04674975236412138, 0.024922849661379587, 0.07543644664110616, 0.0977468084602151, 0.046008966528461315, 0.019614144875959028, 0.04605505018844269, 0.04448125553608406, 0.024401672744716052, 0.02524869702028809, 0.046662798631587066, 0.014880797498335596, 0.03880838259647135, 0.0752301889588125, 0.019509574412950315, 0.05519754886336159, 0.057879036030499265, 0.02858633735741023, 0.03441620050580241, 0.03339601091283839, 0.09185361413983628, 0.031140475693973713, 0.030571691859222483, 0.09363246048451401, 0.0017670042188910884, 0.032857801706995815, 0.049827672555693425, 0.012146837707405211, 0.049342730999342166, 0.035940716552431695, 0.008332469533343101, 0.004971557764292811, 0.013282339423312806, 0.05654948588926345, 0.0516500421508681, 0.04388932225992903, 0.02770817998680286, 0.029206746839918196, 0.01919500769872684, 0.04493733125855215, 0.03251157126214821, 0.03610454194131307, 0.02318023867701413, 0.03062447896809317, 0.028786472321371548, 0.02838306681951508, 0.022454249410657212, 0.04723731741250958, 0.052519872624543495, 0.030621087353210896, 0.05165273614693433, 0.039268592081498355, 0.013810668788210023, 0.033927871045307256, 0.0494225526927039, 0.03430843324167654, 0.05897653885767795, 0.011567308501980733, 0.08867162629030645, 0.08634828845970333, 0.029649224561580922, 0.05442475790914614, 0.01606177338544512, 0.10230579937342554, 0.0014386386601472623, 0.042726306346594356, 0.09110224898904562, 0.017686008104647044, 0.0644758902490139, 0.030716390247107483, 0.054237024232861586, 0.03968557146436069, 0.0330320060311351, 0.016442888481833506, 0.08678539117681794, 0.026497985745663755, 0.028841309613198973, 0.03992809419287369, 0.023177637449407484, 0.012747428136208327, 0.024433794751530513, 0.053282195585779846, 0.03126421397610102, 0.03643717252998613, 0.04265745359589346, 0.022206706053111702, 0.05199035025725607, 0.0655034753435757, 0.03317023845738731, 0.021448572515510023, 0.031133028242038563, 0.07850070018321276, 0.015806669398443773, 0.031327018223237246, 0.02760809951723786, 0.008144871299009537, 0.06186647675349377, 0.026304708226234652, 0.025865067364065908, 0.012120557330490556, 0.06694693773170002, 0.021422745776362717, 0.022143395290186163, 0.05395423257141374, 0.006476880480477121, 0.034326756867812946, 0.023610827192896977, 0.007218581940833246, 0.07986006981809624, 0.004960346232110169, 0.04239184636389837, 0.042939135746564716, 0.012126862802688265, 0.031204682600218803, 0.03026742058864329, 0.0013317843536242435, 0.007756600507491385, 0.024027793588174973, 0.031099395964702126, 0.0680904537148308, 0.02357545272388961, 0.030709393649885897, 0.07369865590590052, 0.03129757722490467, 0.03875037633406464, 0.04024308393127285, 0.021177193229959812, 0.05126139054482337, 0.036711002758238465, 0.0512162790982984, 0.04609287374478299, 0.03730149255716242, 0.03357312816660851, 0.042987653650925495, 0.061266138654900715, 0.04291207704227418, 0.03634979948401451, 0.03767633650568314, 0.047296615011873655, 0.03596946735342499, 0.08173287205863744, 0.05144291615579277, 0.020120289591432083, 0.01598669587110635, 0.04482400159758981, 0.03224999760277569, 0.018363219714956358, 0.0354074908682378, 0.02656371219927678, 0.0028348190517135663, 0.04123835591599345, 0.007187488272393239, 0.04916600708384067, 0.02070177157293074, 0.03839567427348811, 0.022950449347263202, 0.049919606099138036, 0.0405908098036889, 0.065604110568529, 0.038102080652606674, 0.04184023768175393, 0.054918397436267696, 0.02357383113121614, 0.021633081560139544, 0.050738387944875285, 0.06071312731364742, 0.03888423751050141, 0.02967868040286703, 0.03962871553085279, 0.04092272421985399, 0.009706958571769064, 0.04212453219224699, 0.07378823313047178, 0.06878859203425236, 0.06059166742488742, 0.04389738940517418, 0.02270640336064389, 0.03832072106888518, 0.056481197170796804, 0.06842114729806781, 0.04715273855254054, 0.020984715374652296, 0.057176982882083394, 0.016429681963927578, 0.033270424682996236, 0.03658616609754972, 0.06505469864350744, 0.040638259015395306, 0.016802757745608687, 0.07759571046335623, 0.012803314639313612, 0.022683105489704758, 0.022965450007177424, 0.048501384153496474, 0.03397305670659989, 0.09633115434553474, 0.033538243515067734, 0.031410513547598384, 0.0789182102016639, 0.008673337033542339, 0.017789450503187254, 0.03959329653298482, 0.04819795707589947, 0.03092382052273024, 0.08159215343766846, 0.02617727961478522, 0.03374108731804881, 0.021765389792562928, 0.004727897694465355, 0.03848747051961254, 0.017534186954435427, 0.05732168683607597, 0.04445545106136706, 0.04017742241558153, 0.040996311872731894, 0.05338662689609919, 0.040554233055445366, 0.019282265711808577, 0.02360665446758503, 0.033202236154465936, 0.11270438670180738, 0.03880698735883925, 0.034419755393173546, 0.02652325958479196, 0.016644034622004256, 0.03314352114102803, 0.017066114414774347, 0.0708597332413774, 0.034263971174368635, 0.0549654050701065, 0.046286425858852454, 0.00821491148599307, 0.04234466432535555, 0.036841335022472776, 0.02531596528569935, 0.023660341430513654, 0.08242683208663948, 0.06020627755788155, 0.00853332345286617, 0.039178840452223085, 0.052920996022294275, 0.006868906539239106, 0.09222330758348107, 0.04115074909350369, 0.07480867134290747, 0.006691430735372705, 0.036485423261183314, 0.044233804946998134, 0.021066785775474273, 0.011621006597124506, 0.039132259553298354, 0.027048432966694236, 0.0952813790354412, 0.10235247304080985, 0.09606915395124815, 0.11370591499144211, 0.13753189821727574, 0.14072898135054857, 0.24120868183672428, 0.14447802939685062, 0.14508636784739792, 0.16719586739782244, 0.19227060314733535, 0.18129697011318058, 0.1585349001106806, 0.15218296204693615, 0.14109692332567647, 0.13364549347897992, 0.13515862869098783, 0.06647497633821331, 0.13881937600672245, 0.08839946589432657, 0.10317212319932878, 0.08020185108762234, 0.12456509401090443, 0.12546223180834204, 0.15043901890749112, 0.09923330799210817, 0.10038862412329763, 0.0977410568157211, 0.08764821948716417, 0.09105668112169951, 0.10191128851147369, 0.11038134573027492, 0.11804223933722824, 0.1149235937919002, 0.08769342370214872, 0.09362716155010276, 0.09357853603432886, 0.14239113981602713, 0.0916841001890134, 0.11179722248925827, 0.10363762790802866, 0.10867079181480221, 0.10547249898081645, 0.19980322394985706, 0.10924064990831539, 0.08680965940584429, 0.23718486103462055, 0.1247621193761006, 0.19010133517440408, 0.15649537439458072, 0.09699804082629271, 0.13063416990917176, 0.11085107325925492, 0.16489614470629022, 0.15264082263456658, 0.10940058273263276, 0.14018089044839144, 0.09764013215317391, 0.17790384124964476, 0.1391700704698451, 0.09630448155803606, 0.09822007603361271, 0.0822597301157657, 0.12887829303508624, 0.21603283588774502, 0.12340050845523365, 0.22355289955157787, 0.07805107743479311, 0.1232830858498346, 0.21186073397984728, 0.07309852560865693, 0.1643726634210907, 0.11766107971197926, 0.07201096013886854, 0.06715785610140301, 0.15370239067124203, 0.21277691528666764, 0.12586370401550084, 0.2029181513353251, 0.10093286327901296, 0.1788223974290304, 0.12494848750066012, 0.09780490378034301, 0.1888240990228951, 0.10769647065899335, 0.11150229300255887, 0.10477253497811034, 0.14350499957799911, 0.12167052511358634, 0.15472242812393233, 0.09739721979713067, 0.10604222348774783, 0.12064800888765603, 0.12821417476516217, 0.13767133292276412, 0.09731438869494013, 0.10797484283102676, 0.15263190201949328, 0.144436958944425, 0.09005657033412717, 0.14056337851798162, 0.18744024593615904, 0.18227173655759543, 0.18289644678588957, 0.13890496047679335, 0.07560431302408688, 0.14934874459868297, 0.12177027718280442, 0.1484985847491771, 0.08368996743229218, 0.15903283667284995, 0.18840533477487043, 0.09228476483258419, 0.18788062152452767, 0.11605582170886919, 0.1332331117009744, 0.18899599526776, 0.11087704100646079, 0.11931733810342848, 0.1370910624973476, 0.19465838908217847, 0.10064456859254278, 0.17476017790613696, 0.1500692660920322, 0.14121534040896222, 0.09725993731990457, 0.1332459063269198, 0.1331304875202477, 0.1617756808991544, 0.15248644107487053, 0.11054321556002833, 0.11548829395906068, 0.058890887594316155, 0.17075881449272856, 0.18423093220917508, 0.17387258412782103, 0.0923945804242976, 0.14872283209115267, 0.05902765056816861, 0.12875810964033008, 0.09225743895513006, 0.1066408769111149, 0.08396616511163302, 0.17573559744050726, 0.28569108399096876, 0.10773876565508544, 0.08619652668130584, 0.11190496006747708, 0.11124409982585348, 0.07827420413377695, 0.1659861666848883, 0.2972567727556452, 0.1261214815895073, 0.13299482292495668, 0.08644781046314165, 0.1320296895573847, 0.13816138787660748, 0.08843447300023399, 0.1476944677415304, 0.21741958335042, 0.08415421791141853, 0.12895224062958732, 0.10519817893509753, 0.19523698225384578, 0.12308802717598155, 0.11929204571060836, 0.24904219899326563, 0.12914953316794708, 0.16430143208708614, 0.1069645349343773, 0.15576888603391126, 0.1132291296380572, 0.14418851758819073, 0.18234439281513914, 0.20633333682781085, 0.09585262494510971], [0.02629539983900031, 0.03733350138645619, 0.006065347997719073, 0.043985044467262924, 0.09363792269141413, 0.05261160207737703, 0.019284549671283457, 0.01835290386225097, 0.020245894374966156, 0.03251174566685222, 0.05710931014618836, 0.024284554419864435, 0.052166684545227326, 0.08138317949487828, 0.02290569227625383, 0.05710452329367399, 0.06676515607978217, 0.01766640241839923, 0.04648045294743497, 0.038009827985661104, 0.050100059306714684, 0.0446862775424961, 0.020524132960417774, 0.025100065249716863, 0.05251741240499541, 0.027908389165531844, 0.035267124767415226, 0.07639590257895179, 0.04363453554105945, 0.07865605395636521, 0.02671771897439612, 0.02243343958980404, 0.05515825956535991, 0.06144987215520814, 0.02600430354505079, 0.038808757381048054, 0.05507313893758692, 0.055677380732959136, 0.02354351254325593, 0.030005746739334427, 0.0879980975878425, 0.14497727213893086, 0.02896329271607101, 0.04725617909571156, 0.03491103860142175, 0.03165421629091725, 0.02150481061107712, 0.03899858391378075, 0.009528844984743046, 0.0702310302585829, 0.011441439328336855, 0.012550286810437683, 0.04704526814748533, 0.08564845062210225, 0.04075758894032333, 0.08353450975846499, 0.042809193109860644, 0.04423376412887592, 0.07342006108956411, 0.042554213432595134, 0.016823736405058298, 0.050950460354215465, 0.048315327730961144, 0.022489544098789338, 0.031571529907523654, 0.014510054843412945, 0.015473678868147545, 0.06780495692510158, 0.027166966938239057, 0.027479407399368938, 0.019743818484130315, 0.01101326743082609, 0.0029104313762218226, 0.023823777191864792, 0.027958083373960108, 0.05840371588419657, 0.007042850647849264, 0.008068806728260824, 0.018525495870562736, 0.02965936786495149, 0.0510445572581375, 0.023381306891678832, 0.03285971273726318, 0.06929669601959176, 0.014330747326312121, 0.031237871444318444, 0.05204260116443038, 0.021587936716969125, 0.05833284820255358, 0.01483904705310124, 0.03864694321237039, 0.05238268291577697, 0.039948403064045124, 0.025336940234410577, 0.014340548314066837, 0.018037715599348303, 0.006668269234069157, 0.0059530322960199555, 0.0470159273390891, 0.04040483872813638, 0.0200309832507628, 0.026378180846222676, 0.011370979827916017, 0.05607399929431267, 0.03445681824814528, 0.053375721035990864, 0.06732380774337798, 0.049350441913702525, 0.04382631021144334, 0.03638191963545978, 0.012429864073055796, 0.021328467046259902, 0.045829715600120835, 0.06111564965976868, 0.05738075436966028, 0.03911875617632177, 0.04486306454055011, 0.11025722895283252, 0.042195266287308186, 0.03924339987861458, 0.027948522656515706, 0.07117527216905728, 0.03292362278443761, 0.03922183677786961, 0.031632259851903655, 0.05483069042384159, 0.07436779109411873, 0.04263773844286334, 0.0734244917111937, 0.033723394517437555, 0.0233502405899344, 0.0428870406904025, 0.061270190781215206, 0.027061925211455673, 0.02546846735640429, 0.03578187097446062, 0.022357271118380595, 0.012640996737900423, 0.044887132389703766, 0.026431235128256958, 0.041344475612277165, 0.022661965413135476, 0.09527087022433989, 0.032789464748930186, 0.06717350057442673, 0.08239825197961181, 0.03178280450811144, 0.07034681271761656, 0.02660271948116133, 0.023846720687288325, 0.02102117894537514, 0.030638416501460597, 0.030600661593780387, 0.06199842689966317, 0.03329593972011935, 0.06836491476860829, 0.02419515159999719, 0.0775233213789761, 0.027262626063020434, 0.016881751944310963, 0.045841478640795685, 0.019751323452510405, 0.02524808845919324, 0.03082429295318434, 0.06383139436366037, 0.03358503963681869, 0.026075692585436627, 0.05685683150659315, 0.009426844208064722, 0.011733363116945839, 0.03509185917209834, 0.054256984294625, 0.024987641008920036, 0.04934822289214935, 0.053993072870071046, 0.02635519838804612, 0.06181639662827365, 0.0758104222768452, 0.013648337899212493, 0.051786434050882235, 0.055177228859975, 0.015376626361103263, 0.034647145730559714, 0.05427592390333302, 0.009390433515363839, 0.05219784732616972, 0.037850440639886074, 0.003169083061038691, 0.0646038365084678, 0.06601218046853319, 0.02210090733569814, 0.038032378142816015, 0.056031040076049976, 0.023889401600172278, 0.08227390513638966, 0.047072527231648564, 0.07963945157825947, 0.06483080011093989, 0.01474100470659323, 0.021594272802758496, 0.034020557868643664, 0.027953751086897682, 0.05516282748430967, 0.02542546732001938, 0.02535287414502818, 0.06949556191102602, 0.0754955067532137, 0.04527393604803365, 0.01577188122610096, 0.0729433425294701, 0.0481309337192215, 0.029359731306612957, 0.052450017974479124, 0.038252083541010506, 0.054636173517792486, 0.050798030642909, 0.06892985984450206, 0.07096459870808758, 0.03762352527701296, 0.0395614101580577, 0.029715845303144306, 0.030419559006986674, 0.005876512232134701, 0.02548677057347959, 0.03034207136806799, 0.09895361479721032, 0.01941640890436247, 0.020371586360852234, 0.05017776587919798, 0.06317142469924875, 0.03243084414862096, 0.00778712364990497, 0.05369753111153841, 0.09106494122534059, 0.02420362321572611, 0.03195617020537611, 0.05761701337178238, 0.04995144423446618, 0.05882781988475472, 0.04100017475138884, 0.05453432859212626, 0.03739554864296224, 0.003047079781026696, 0.013200685552874347, 0.02721168133575702, 0.040199608920374885, 0.04588166222674772, 0.03223584855732042, 0.009150819078058703, 0.025985786960518453, 0.016922197137319017, 0.03241672478907276, 0.027313246100675315, 0.02303749213751871, 0.03744922076293733, 0.012678206167038297, 0.041244682724936865, 0.015029474725452019, 0.04807199977221899, 0.03541365440469235, 0.0544508815073641, 0.03321923504699953, 0.0978994756587781, 0.010724185140134068, 0.04464810517674778, 0.03254667855799198, 0.02042663145402912, 0.05300587545207236, 0.027567552278924268, 0.02160774834919721, 0.014350923538586358, 0.028669016319327056, 0.018494064061087556, 0.07318570569623262, 0.01074947938832338, 0.026048574509331957, 0.024183878376788925, 0.09623262681998312, 0.026226400514133275, 0.04780781746376306, 0.0353673221252393, 0.0317804890073603, 0.06840776637545787, 0.015926515116007067, 0.06568023265572265, 0.02725328056840226, 0.04434883041540161, 0.002374869782215683, 0.027544577242224477, 0.03799822450673673, 0.02456854093907168, 0.0424867856054334, 0.06362462459946983, 0.047342138350359164, 0.03863054545945488, 0.011631402230705135, 0.06251374827115797, 0.014636899941251613, 0.08746556952246465, 0.005761412085121265, 0.041280246441601776, 0.03692828133353032, 0.015249451935233083, 0.04757072725624312, 0.02467768488713773, 0.041857084434013814, 0.08534831125871278, 0.03658805857412517, 0.04136830597417429, 0.03201889281626791, 0.12106618683901615, 0.0017470049624535022, 0.027208016981603578, 0.03632912696048152, 0.054562830773647875, 0.06199271978402976, 0.050651998244575225, 0.04629804789146874, 0.01099496885217377, 0.024108949291985482, 0.02005442769586807, 0.024783845401543658, 0.04187894068309106, 0.1327284364379011, 0.06729994769557379, 0.062066459577181377, 0.05990515484882053, 0.0651851533621084, 0.07798174599884078, 0.06250784077565186, 0.056544992185081355, 0.050726739937090315, 0.043121381240780465, 0.05144089380337391, 0.033457731624366716, 0.03757976824999787, 0.07235603654407896, 0.04497818277741317, 0.06898813328007236, 0.06602659297641367, 0.13498530752258375, 0.059820757815032266, 0.02643007923325058, 0.06288597985985689, 0.07038889249088243, 0.017347442189930007, 0.032049346846179105, 0.0647397014836315, 0.04396701398945879, 0.003409994633329916, 0.05667179553711321, 0.02942285096651176, 0.15568698261631653, 0.16180140373762697, 0.11464030118077062, 0.14345493429573253, 0.24853780574630946, 0.077136699546827, 0.1231331868621055, 0.10200867312960327, 0.20288233528845012, 0.26036036666482687, 0.17739500995958224, 0.06626696718740277, 0.13899286044761539, 0.15229045471642166, 0.2634944563033059, 0.12053040074533783, 0.15690640546381474, 0.11987587102339603, 0.20211522176396102, 0.12887437449535355, 0.16558040486415848, 0.13612958049634472, 0.10351296936278231, 0.1520996040198952, 0.20529462693957612, 0.12825824349420145, 0.09285376203479245, 0.12613786821020767, 0.16161071631358936, 0.22997814696282148, 0.1600388772203587, 0.19032527081435546, 0.12789016793249175, 0.17861336411442608, 0.13064224447589368, 0.11190128643647768, 0.13993172178743407, 0.12657983199460432, 0.1329692782019265, 0.1435220244457014, 0.22402076428988948, 0.3454376826994121, 0.1489344480796717, 0.23463767662178725, 0.09795138888875954, 0.1872217725031078, 0.1936581076006405, 0.1332200795877725, 0.17690580105409026, 0.17699485877528787, 0.08109391259495169, 0.09676927380496636, 0.1351033238461241, 0.22385887219570577, 0.12356136154267006, 0.09616736977477558, 0.16765381704317406, 0.12877850385848433, 0.10434965181048028, 0.11793904370279051, 0.12040103698382154, 0.13092124747345224, 0.11608793443883769, 0.09029246197314933, 0.11911707697436213, 0.10157515498576686, 0.1317219209158793, 0.16098066262202337, 0.1125537752523087, 0.1968970478628762, 0.15338218363467604, 0.08439142315182835, 0.09741042260429822, 0.10369667317718267, 0.13244018628029153, 0.21515947650186718, 0.15619812940713018, 0.11174205123097636, 0.11148728677653708, 0.15133415290620178, 0.19554340018657967, 0.157303350570146, 0.12017505301628262, 0.15661926852772012, 0.17937284836079925, 0.22701966430759057, 0.18364776740781963, 0.0806399185967166, 0.1532955007860437, 0.07506241163355298, 0.13970748928841203, 0.12363041838398203, 0.13137027650373057, 0.21927894529653713, 0.14794529881328344, 0.0969883038487751, 0.15786321193445474, 0.1483401659061201, 0.1557242384296842, 0.09509907788014971, 0.08681213075760752, 0.12213137655635364, 0.08911278855521232, 0.12444786436390132, 0.13170229853130877, 0.17416352086002007, 0.27517749345861375, 0.1304942899150774, 0.14588680380256847, 0.09383492579218, 0.16356780426576734, 0.12709241855191067, 0.09503437002422288, 0.09452576137846336, 0.11472765196231194, 0.11012314513209276, 0.14360118191689253, 0.17338178702630103, 0.13251538068288937, 0.15989067032933235, 0.24086641817120835, 0.135952593118418, 0.16966588329523802, 0.08159054297721013, 0.07048130471957847, 0.21308694005711004, 0.17569727293448523, 0.10393646109150723, 0.1269919762853533, 0.14384303300175816, 0.1749756679055281, 0.1534615785931237, 0.24552122777095065, 0.09659463161369786, 0.16582182550337166, 0.07697662571445107, 0.13717419788008556, 0.08974493510322645, 0.14427686284761876, 0.133159238321241, 0.11286100212601013, 0.08500973606714979, 0.1535697391955182, 0.07500301013351418, 0.13952162582427263, 0.15955910843331367, 0.13679215509910136, 0.20064747630385682, 0.25112068746238947, 0.16872170817805454, 0.12217593510285951, 0.13991027371957898, 0.1561266160570085, 0.1076104112144094, 0.23107766843168065, 0.19376898446353152, 0.18364488787483424, 0.13173747633118182, 0.13092682842398062, 0.11043581936974078, 0.18383229500614107, 0.16931548569118604, 0.157078004849609, 0.13227375224232674, 0.2323154520126991, 0.0966117974894587, 0.10362468485254794, 0.24553339899284765, 0.11226431539398618, 0.12791753833880648, 0.24739172193221748, 0.24758837622357532, 0.13711090752622113, 0.09436018823180348, 0.34024202555883676, 0.1590257417410612], [0.01979328262677882, 0.011140478964080103, 0.043106393568450585, 0.02887781214667484, 0.07643987482879311, 0.0031592711729899747, 0.08409166228375398, 0.07225267021567561, 0.012256914906174643, 0.038792381892562844, 0.04238022433128208, 0.028474733189796098, 0.06600180524401367, 0.05282129961415194, 0.07374417182290927, 0.04103274390217848, 0.023095908436516766, 0.022555951472895686, 0.031990004717954434, 0.006737531557519105, 0.041111849423032254, 0.04845818744797725, 0.018269974425493274, 0.022130053330329247, 0.07299008299014531, 0.029100434185238555, 0.06676141565549187, 0.05419869230536278, 0.03816255084529985, 0.025565974428900518, 0.01791441703971941, 0.03758706727239769, 0.04750633852381725, 0.07195126920123585, 0.020133043399255257, 0.03354480410052929, 0.090898373600794, 0.06583926748135127, 0.0994713518593926, 0.06334784062346444, 0.014385606882569846, 0.0647253186616581, 0.06803874828619882, 0.04197891539661214, 0.028191184537718073, 0.0026186179820797406, 0.030900253623258322, 0.022041368538339157, 0.05860150566149969, 0.02025385390879819, 0.017361290665576234, 0.006080250786908437, 0.05166684808500577, 0.018798606215568725, 0.031280504117603414, 0.04154330810706597, 0.04709311811893713, 0.030376653594430536, 0.046153377334121615, 0.028709570979117416, 0.012418241112754913, 0.0652023489237763, 0.026305930914531928, 0.019582883760449477, 0.05854806731804274, 0.0093620908955927, 0.021337166872399393, 0.03262762831582222, 0.0295000157711911, 0.02299654413945973, 0.06554260879056528, 0.024706884687475394, 0.08835478118271567, 0.021255647516227327, 0.05598081523203291, 0.041424750015721656, 0.10708154193707742, 0.03572011315554846, 0.031730779955978505, 0.05310072563588619, 0.02849502536264481, 0.03810583220911212, 0.03175728576024994, 0.02917237055953592, 0.044803692726418376, 0.01204673961183289, 0.031043909293657634, 0.057906703295884654, 0.10337153085856698, 0.0582936256978428, 0.07289974877494387, 0.027962614185526036, 0.02497371460776776, 0.044660038911388256, 0.03161018838000018, 0.03785392502322793, 0.053010588089819066, 0.03311503751319833, 0.02902484829974128, 0.06236622415599413, 0.053381665638880804, 0.02304418074345449, 0.06575254010385834, 0.036875896839774214, 0.011715397577063413, 0.025676014520286117, 0.023403719751513563, 0.020602754229912534, 0.024628066748846322, 0.07038681447738782, 0.015466490240214625, 0.045303080187295564, 0.0416412344929995, 0.022732640136382543, 0.031223663027049042, 0.036847060691798106, 0.07798483333317563, 0.08542649651644751, 0.04457718554476742, 0.0922163091308903, 0.017623612038732972, 0.01819189863454085, 0.019289099036541302, 0.03216565994080156, 0.0350276188692078, 0.02110475405061152, 0.023258863657247275, 0.02839667595253559, 0.042536795226624236, 0.06113854862633161, 0.06090156974096317, 0.05561314414080698, 0.027652700737235136, 0.016008199600037187, 0.07257710749399848, 0.03641847040853463, 0.012889486333733657, 0.0580369168164907, 0.04151504341280088, 0.009158645952993538, 0.04028880764963105, 0.070683562225895, 0.025468370877206326, 0.024593632952019107, 0.034803746311808936, 0.05285786523018032, 0.04194374872895423, 0.042688274988904595, 0.03845625578833278, 0.04199813702143729, 0.0667057694226969, 0.05122062437294517, 0.05088041645649355, 0.043216398407821544, 0.01427260933269281, 0.04635417280951515, 0.029716821227339096, 0.03194138662365731, 0.030445048068941105, 0.0388149654463632, 0.0796752305177506, 0.024415818079432938, 0.04025951879157219, 0.03383959628990851, 0.0535672211117344, 0.05771026051661465, 0.03859708202071488, 0.03753729884920176, 0.031499497054028325, 0.025629314877733123, 0.0729323439009022, 0.023248768593475688, 0.029924184709670953, 0.019564654758141842, 0.060103141295257956, 0.03421184643229935, 0.04933671960316133, 0.02323170661838958, 0.036594318589777686, 0.056058889167616144, 0.004623724744305946, 0.02635652868775651, 0.0017192470158988726, 0.013986247013235698, 0.07275990588823333, 0.033773934774217196, 0.04662021790863946, 0.029988660644448828, 0.06140972567663994, 0.06871846650028601, 0.06629556955886073, 0.06367579568177462, 0.010067696148325922, 0.027228661674598698, 0.03348146550706588, 0.09219083120115101, 0.021261323090584483, 0.018057330562442075, 0.018315703709959053, 0.0330014406790724, 0.020477396210480947, 0.042242374111083336, 0.019126687438983936, 0.09830392387812026, 0.035658930501085706, 0.046039502194616944, 0.013276311328809243, 0.10266955563565716, 0.012946209608344361, 0.06335268684779294, 0.007629649189766496, 0.036470472696237266, 0.11834488715976477, 0.004298191406633123, 0.05931597865128424, 0.09174776161671616, 0.0262930565077113, 0.05345278565073386, 0.03573683374270331, 0.041380829716217704, 0.04386172178783454, 0.024058932249317877, 0.007094127486197976, 0.037093891587574035, 0.04117704709642567, 0.10007969773141667, 0.017940119469130877, 0.015843286964809522, 0.05514045915333554, 0.030218765386962332, 0.0341727946215542, 0.03518247169267852, 0.007094251795933815, 0.03431403645663522, 0.059299194981576875, 0.020385727984830737, 0.03860447381157428, 0.02642235347593669, 0.014897530145390192, 0.03126157935184892, 0.04661110433517024, 0.08068268114584498, 0.0347977126511978, 0.013611249069072073, 0.016472240422444884, 0.019895736113539897, 0.13723106123507023, 0.06755951384548098, 0.03899812749295961, 0.0393343574978644, 0.05443826499686111, 0.019645194479380734, 0.07394807689706795, 0.01861275017290609, 0.02574363345047459, 0.033897276007337496, 0.022090847523941193, 0.02622637082822621, 0.029917817082605325, 0.026195781356364023, 0.029187159707362298, 0.021733757603215054, 0.04394823394250125, 0.018201798884547316, 0.007323164463741705, 0.03995086328359321, 0.021183546014071908, 0.07253007759572938, 0.027980318118352443, 0.06758629795513116, 0.029169322187954094, 0.03231748109101318, 0.04879194239038043, 0.042682560451794416, 0.031662821493227966, 0.022416143838199787, 0.042612201141309924, 0.009201570846926188, 0.06977598983212374, 0.05964067568129394, 0.01095954892662121, 0.010516916281630984, 0.04538840861641802, 0.03380590278538875, 0.03791392024140805, 0.05087896184704732, 0.05162836401723325, 0.06036306367604993, 0.018188612775702495, 0.06700301441014744, 0.03500628583424259, 0.01289125171751948, 0.060021282406523824, 0.05476158534293063, 0.026136301930819172, 0.03735994039743673, 0.05035489797592163, 0.04076022727531381, 0.04763312332215719, 0.04404523264383897, 0.052773835559492, 0.10028490898548625, 0.04543981347524095, 0.03604632045608014, 0.006871288369438844, 0.030210939439712092, 0.01959537410584744, 0.13915162067860365, 0.03771514711843338, 0.02832732967362972, 0.038463569653686136, 0.04577797677484341, 0.02284521466208389, 0.022517074066854548, 0.05883197962248232, 0.022927914033061825, 0.01425776545147528, 0.05635001514747273, 0.014126419227977749, 0.0696945094387047, 0.02219366837380221, 0.04524368981947191, 0.019908348913304508, 0.02612415853946004, 0.081153202772839, 0.07448723234119825, 0.04946258784912061, 0.07518997939769179, 0.0655393507622648, 0.05923053890001029, 0.04288277334126178, 0.08391217386815697, 0.0032983753908411018, 0.057425928898737766, 0.06166316168673802, 0.06964533473365009, 0.010105400961037958, 0.03475287951005157, 0.03549494555045385, 0.0291316080983961, 0.061218503906275146, 0.03708018411998637, 0.04553040744212922, 0.025498483519186266, 0.030183008711901493, 0.023420778015861288, 0.04370529932202771, 0.013642700359923765, 0.028752836333296727, 0.025778124763746746, 0.057849877048283815, 0.087171092745848, 0.12957928120158613, 0.08560934686101973, 0.13233720586868003, 0.15099129552254453, 0.1345790855702944, 0.14581120864022523, 0.1422722329152748, 0.16203228587983176, 0.20022988464916125, 0.06955403572646901, 0.09825749511946924, 0.11432418337790295, 0.32113463210407645, 0.12302754956181161, 0.22555889503564686, 0.20884066791040823, 0.07385775752482004, 0.0815237348433584, 0.16621832532109693, 0.1366777010844089, 0.09294882373069413, 0.08805441917502321, 0.08580291381804273, 0.1058798489975743, 0.16418875922681764, 0.1862149007502012, 0.16909385070903227, 0.1703865680610761, 0.08209840205381624, 0.16408712952397764, 0.2049082945450209, 0.3012865158962086, 0.23369446629658341, 0.19332607073010877, 0.14336549065774307, 0.1060756052902434, 0.2892663358943537, 0.14711323252413422, 0.15417105692904443, 0.1313726810622029, 0.16553500026930124, 0.19626123510533944, 0.18167904258007184, 0.14018841582583264, 0.1501629696576856, 0.111745272151893, 0.06443659352953546, 0.149769245472271, 0.12244186887983233, 0.3305644792271778, 0.12364808892016299, 0.16111634206026793, 0.21927055902779102, 0.12309030556934886, 0.06086931229219772, 0.12278926820727065, 0.10337891522794962, 0.10985280299792066, 0.2532942302059382, 0.24967780394945294, 0.10161600279388949, 0.13962144468678162, 0.07097635432728566, 0.18873649591114372, 0.13247033231891692, 0.09530241892207414, 0.1918334187939763, 0.09776322476682253, 0.07860914280172437, 0.0727439126058016, 0.3033359121764079, 0.14515624847263098, 0.17121011449489743, 0.16741279716370627, 0.11788050309405662, 0.09278931393055245, 0.15412456879857928, 0.1667072670534253, 0.15012694580946118, 0.13490450248355046, 0.10435101736220531, 0.11709655766026117, 0.10301685848389752, 0.08786108970525675, 0.11778791274991818, 0.1334332540864125, 0.15961530385538936, 0.16466419387143105, 0.17528153664898127, 0.1666021640994586, 0.2481800757232122, 0.30470089986920357, 0.09144831987214275, 0.167209419014398, 0.13498630200047046, 0.11824767323560081, 0.10476423034560867, 0.0969771048403345, 0.08041638371651061, 0.12488369800848886, 0.09704397234600037, 0.14092547236941755, 0.1558656175620854, 0.19718842988368124, 0.08977268400485627, 0.09269896487239748, 0.12579628732055426, 0.10726396183599718, 0.09715287509607151, 0.22708918870193884, 0.16196850570850074, 0.21866838040295988, 0.08625741247669794, 0.10382673455751501, 0.1743627875111997, 0.07008368425886147, 0.15877128898864612, 0.12809109699446708, 0.07910741333034821, 0.15534412523265928, 0.06790775179979391, 0.22138195432489738, 0.12892831378849223, 0.1549229712691158, 0.2476834601839073, 0.20218271267367527, 0.17560535052325577, 0.14309805032098666, 0.11891670452314429, 0.09790371332201175, 0.17446036508772522, 0.23951759445481002, 0.1305123241036199, 0.09998704059398733, 0.11971580461249687, 0.13885272812331095, 0.0723348259634804, 0.17476077162427828, 0.1728167009423487, 0.08613909187261015, 0.14685072004795074, 0.20133035606704652, 0.1184304864727892, 0.12840060226153582, 0.09969121310859919, 0.1324074575677514, 0.10267958947224542, 0.14065216906601563, 0.15633309638360515, 0.1875333409407176, 0.14702307642437518, 0.143722404318396, 0.10785526799736544, 0.18874647037591785, 0.12950358213856816, 0.17703146149870008, 0.09685700308182277, 0.15263868524925783, 0.22886761202244088, 0.16599192575085908, 0.20426923118066043, 0.10953953504213132, 0.15268165559973568, 0.1346684995223768, 0.22378054592991248, 0.24064012250164524, 0.11995154040050693, 0.1025850695441477, 0.11472764454083517, 0.11836260222480632, 0.10422053295769729, 0.13086947525152937, 0.09238186001311988, 0.08302210131660104, 0.11119173388578929, 0.1480240109958686], [0.024535802949685603, 0.06480400857981294, 0.0735865173919592, 0.024314782094734255, 0.02587322913313983, 0.024357680085813627, 0.007001802923696232, 0.009178567052003928, 0.01432056227713474, 0.04841129484702833, 0.0312631118868012, 0.03335454341140576, 0.015462481715076137, 0.05049954997957684, 0.010415341312182136, 0.06452145811636001, 0.01672680078627309, 0.019840041641145945, 0.015610263726557605, 0.07145651645259932, 0.05425676907179877, 0.01904932410980109, 0.05156790866749361, 0.11847901550936513, 0.02621008810820058, 0.059718196716858074, 0.049424493408878334, 0.0740740861510858, 0.00398664987187658, 0.036558350402629, 0.05698791333998088, 0.012627478517970303, 0.029131821465853136, 0.03168185015965719, 0.0232758551283041, 0.009240597610187251, 0.10160032863495871, 0.030174885905580595, 0.05486659181769937, 0.03339166934893001, 0.021732058085035533, 0.054123308655107394, 0.027195274305995554, 0.05818202524096705, 0.06269498073379509, 0.030827697555650957, 0.004386877590150107, 0.057036887665162794, 0.011205034679733217, 0.08169251406798139, 0.02783840649499325, 0.0047518217525066575, 0.05308727420924697, 0.02203456675488269, 0.02302197568496922, 0.038466701516881585, 0.05944555392488837, 0.06102181250753347, 0.045295024174265563, 0.05945489014266059, 0.09503921624855138, 0.018905113684013486, 0.07149019511416554, 0.02761794410616858, 0.02768260001175804, 0.03539398378052283, 0.05082820265670307, 0.09101473493501544, 0.020522492814052384, 0.01623854368517641, 0.027635482911136933, 0.034931733389385045, 0.02586785969469929, 0.0323068758007139, 0.04541364534816239, 0.07481952154194005, 0.009509970313956728, 0.05109884536068421, 0.07971025988808833, 0.02894830504374113, 0.02704877064388711, 0.09184930968331173, 0.012038098229822936, 0.052386798124643974, 0.03989968477981165, 0.01869890053058043, 0.05749816955358256, 0.05897142174944747, 0.07425945237628184, 0.04795026528881863, 0.02774845819658367, 0.07588679669424891, 0.019883130735252053, 0.04006514289358165, 0.03860720120428596, 0.036819356319028884, 0.0369601120473817, 0.009611000732547836, 0.07244631880894303, 0.05338369541277643, 0.08894308164599352, 0.02470594030455686, 0.01833039081247989, 0.060055721769458614, 0.02622904441523133, 0.01597510723513551, 0.031948303440003656, 0.04844450224481989, 0.026558810313872527, 0.026548776477284264, 0.060694543935824186, 0.008622312525403686, 0.014940737055439968, 0.042860709290835075, 0.06374745003995486, 0.020125727678532712, 0.08399424055824056, 0.0462889157643076, 0.026974077190971002, 0.03149762313114479, 0.01363395507723908, 0.04506834258791059, 0.10483918726094998, 0.04077831341419369, 0.02371367772866506, 0.025479707182967104, 0.044443595252232626, 0.038981239922577515, 0.011982311916653998, 0.02983875609061215, 0.01965095168998232, 0.04062203937792219, 0.043444456678116694, 0.04842269794608001, 0.13682532910024747, 0.02897819875215646, 0.030817370570730418, 0.01572962890350027, 0.017789806734072044, 0.056261436111526564, 0.029675978985324036, 0.04585288916132413, 0.016986906848615035, 0.02570534976257477, 0.02153992718376685, 0.042813267500605434, 0.02598685008706525, 0.05401636146416422, 0.009828528854995966, 0.03954969906772021, 0.03662456481833942, 0.016377742758777458, 0.01470542985771317, 0.031884337731753476, 0.029874748397560325, 0.011054068854718935, 0.025617648316256236, 0.06567465912667103, 0.012851871506427415, 0.018625917728058994, 0.034299063627258874, 0.0486192965763621, 0.0584969518968137, 0.0295766592171276, 0.11372397144441493, 0.05754088386311196, 0.06406106680515222, 0.06816063862061128, 0.01437721133697778, 0.018010541862167884, 0.019661169208120555, 0.057855350387399085, 0.016640283065498807, 0.025220951829396654, 0.05941353025264107, 0.024375393295485992, 0.03495235767331906, 0.06400789192412049, 0.01233227258126135, 0.04230697435559705, 0.02038503222138388, 0.02693201782676624, 0.026861569458560552, 0.009010727571876487, 0.039696959720458835, 0.008928050465328852, 0.03557005831680726, 0.012761877751472639, 0.005461159080368816, 0.023258852525032125, 0.05496530488017015, 0.052253612302592956, 0.05541280879697297, 0.0601150156580843, 0.05668415600666776, 0.04504224496486131, 0.027883324983122293, 0.033043594667105936, 0.03780632367124781, 0.018309293409402017, 0.011564050473680254, 0.03415479754039552, 0.014319656856969232, 0.014888901750964578, 0.042069134578923695, 0.009899125652736984, 0.025588634052837733, 0.028245455941942055, 0.03267844316724222, 0.01525223220596672, 0.0256413376700948, 0.04293747333576903, 0.042462157434783876, 0.025478391726210248, 0.049423001692048274, 0.018932426573883276, 0.044068714196328074, 0.06848334669484757, 0.02311597239895491, 0.003986654510299559, 0.005247161261650035, 0.02510623435227899, 0.06139963246823754, 0.07539009951869957, 0.01965137471415801, 0.012894511601189151, 0.08520826799212955, 0.013162986306269886, 0.060693671912304126, 0.03465904235781636, 0.06221761279448401, 0.027641887645586394, 0.013100863907311577, 0.09694172666058876, 0.01242514030309394, 0.008581357105867937, 0.04354206765128765, 0.01996334205614403, 0.03359718117280863, 0.026618638548825402, 0.043036564893554896, 0.019147834937029984, 0.020531812333501875, 0.018900605136877857, 0.018480809303582646, 0.017765178563422523, 0.08412349299760535, 0.021634595541399904, 0.05282043872284703, 0.08026687806705013, 0.02327079368114937, 0.05083217314677313, 0.05844686435011681, 0.0227314322910388, 0.05418201253633015, 0.051862723121303134, 0.03729898409801535, 0.00737542789465806, 0.024562922881159466, 0.018406861709081568, 0.05795719160232693, 0.010388176851847675, 0.014777375508856494, 0.05978169116133358, 0.06764744350221008, 0.05084660049760714, 0.06732091336743906, 0.044852292267023586, 0.027918721716559958, 0.038264577597146854, 0.0306438824190991, 0.07604020604048856, 0.06900692445924506, 0.014278203270805534, 0.05745683563873172, 0.06416619202354923, 0.05325997197360266, 0.04940504542901181, 0.0666749183437787, 0.11079694842919707, 0.03591423301259056, 0.014013350246386835, 0.05391392653109506, 0.07183088542660698, 0.023229918042488862, 0.038008818664820865, 0.03365375509019941, 0.024370517385250423, 0.054348698904505, 0.0642839189094957, 0.04961095801263582, 0.04156882314418908, 0.08620135064120404, 0.04124043392948806, 0.11050441607949324, 0.015173343763308367, 0.021874322228541132, 0.014112372227828018, 0.04758384842716623, 0.08090850926237181, 0.044091012023272924, 0.024501758780388627, 0.03609206643886864, 0.03814188574324362, 0.042162248137174174, 0.05584221915341914, 0.10182344791246578, 0.010583046278043184, 0.02405259059742093, 0.01981926521693822, 0.040413080278085545, 0.07140500398236327, 0.05749980598920956, 0.07136735483072698, 0.00627518144028727, 0.05825625856232364, 0.0783885690907482, 0.047048496489878744, 0.04753318200528156, 0.029156111959309783, 0.025206674763467163, 0.03407043019251432, 0.01997394549107412, 0.05066880788945127, 0.032972456101560965, 0.01795184911316028, 0.0731911307957489, 0.053184031712589785, 0.038526581702171825, 0.03208904803614132, 0.017200508082169108, 0.06341534637613222, 0.036019039107486606, 0.03297971801657695, 0.05121941467223223, 0.013005324453843059, 0.05674755397194531, 0.0677385792369023, 0.016969694588624407, 0.04236661705363076, 0.04052176038385369, 0.06203497767273802, 0.07690822196309455, 0.09735911051393487, 0.05014773487346247, 0.07927367667434737, 0.040280306347995065, 0.07705524141783826, 0.03045940862648422, 0.03168846640619449, 0.05636962268908974, 0.07833929790649563, 0.12973093165783212, 0.16210173605941236, 0.21364231884945184, 0.1191371372260619, 0.17677101219305769, 0.06643446991802193, 0.09915325252222829, 0.06731906541972421, 0.09583177059539594, 0.14967287017498165, 0.09347180035547353, 0.16859904601005837, 0.08459345059236512, 0.16731321578845382, 0.2789419633336365, 0.13247594295535237, 0.17382688267389312, 0.09828856884269044, 0.12577630870509893, 0.1937331832596101, 0.18575450201751664, 0.168288130662404, 0.10951865100651048, 0.30402076605241746, 0.10899637942202389, 0.15635595453204587, 0.09586981308530085, 0.1614621828775853, 0.09982983145164326, 0.08238825525040738, 0.13258670107461512, 0.1592080874252133, 0.11627258820226416, 0.1049487802083604, 0.09607413376215845, 0.1255414041224867, 0.25416637246962637, 0.10972551724989899, 0.0955168624932412, 0.170075103524141, 0.14917413209332153, 0.17754180677002296, 0.13941901648649946, 0.12373369565466419, 0.1678813446778804, 0.11849169881315902, 0.11961603770032525, 0.14896334731020033, 0.13727578305406496, 0.17775938962586224, 0.15120601368835196, 0.1501554442802444, 0.20182032196316868, 0.14729795308085158, 0.12012162580504082, 0.1558065871358849, 0.1269657933153212, 0.263611656264402, 0.14478018740192056, 0.10598570894217119, 0.11130992090329528, 0.10869893405470066, 0.1378766554989852, 0.14886631892295554, 0.2239830483449623, 0.11711767918313853, 0.10989884583977982, 0.15054701623739675, 0.10162575461436063, 0.06711626614560373, 0.13716959656449035, 0.1362763624638319, 0.1244049311208073, 0.108766580815427, 0.2184680153732188, 0.15765477233799174, 0.1042474209680222, 0.16092651552753523, 0.13565074681537226, 0.12712914001895115, 0.08635237027192488, 0.17454817600082606, 0.07141481517464854, 0.12760757294017822, 0.12761969963321462, 0.15564896981231868, 0.17872617056127638, 0.14242277015000582, 0.29022403294220567, 0.10215821588644758, 0.11838635095045902, 0.20295315101975575, 0.14472083043074235, 0.1640554695040919, 0.1891199784586206, 0.2746200514957309, 0.20076826825970784, 0.07740905290120281, 0.2621570468181744, 0.13888498186133802, 0.1231657003518194, 0.1334046814008616, 0.14577758935047314, 0.22801504761446267, 0.19403698883252218, 0.17197048931848258, 0.16687517054378986, 0.13860596402082592, 0.1683301362209022, 0.07180554850492626, 0.13006164750549942, 0.12846404104493558, 0.19067345681833103, 0.21413022157503292, 0.09472751422435977, 0.09657214453909546, 0.2513802610337734, 0.0753518714918755, 0.14356270898133516, 0.11979583039646968, 0.08332057826919481, 0.10870311976759695, 0.17447032470954582, 0.1991300069494173, 0.12810310494387522, 0.13730368780670688, 0.20342665608040988, 0.11555647506611422, 0.16200001729885116, 0.15839154686545953, 0.16637619497487321, 0.1399031194159761, 0.1569423996261321, 0.09228982627973892, 0.21289464959409088, 0.13111226144246757, 0.1714878558414057, 0.14704866567626595, 0.10333489102777094, 0.1139925250026863, 0.12795890565030277, 0.13151607883628458, 0.174600423197262, 0.0903528653725516, 0.14385000918991864, 0.07736735162325203, 0.095420323923463, 0.1482528744963929, 0.220649870170746, 0.1448575934045948, 0.1225703717500437, 0.12685237830737606, 0.11173547580256127, 0.13479533256031573, 0.10262559822876938, 0.18803953018505126, 0.10976722594932653, 0.14813494723057374, 0.14686860580695793, 0.09242992149665952, 0.20742003398481756, 0.15298893442377448, 0.16712799057131633, 0.14920071582309902, 0.19975234230514616, 0.15532229124801233, 0.26712465682066977, 0.26950472441967577, 0.0948824523948133, 0.13876712881028652, 0.14149186463328078, 0.25153575581498444, 0.10380362407886423, 0.1364597471547313, 0.10313302685972303, 0.14681891159852967], [0.02020045638346346, 0.10749148204922676, 0.023239985275722574, 0.025097460311371833, 0.039706277384539135, 0.037000399534008466, 0.06578611486474983, 0.029047335374343675, 0.030920226672606077, 0.045256744197104126, 0.02031391592026921, 0.006889360129207489, 0.05639743096253369, 0.03474457858828828, 0.03857929274090566, 0.05315297283232212, 0.007201696225820342, 0.011205468836124055, 0.05169763237063307, 0.023542775961686857, 0.02386543023021659, 0.06998283381108195, 0.018189074762631208, 0.02192642099544173, 0.04015495389467105, 0.02668264693056699, 0.03094936524576042, 0.055750296742189676, 0.03784799526329152, 0.03821315047389362, 0.04858305379457306, 0.08610232587670907, 0.06456979419454001, 0.019507368378981482, 0.02224485058832215, 0.05462038803671021, 0.07298891781829298, 0.021525826377910562, 0.03610418571042828, 0.056780820741551, 0.04844998300541192, 0.032413277513114735, 0.02702310903259786, 0.10223436023807153, 0.034327031462453306, 0.036070380883757025, 0.04973573159077205, 0.029609111479658168, 0.03327940466988366, 0.028354531241348013, 0.05736792634706944, 0.030250440249801613, 0.034596319746924564, 0.018156000951421447, 0.04889704905508552, 0.022170580159581732, 0.04508183483267203, 0.04767463164171204, 0.032176094537135214, 0.08382267085835338, 0.0329884939128533, 0.02755782272288343, 0.06029366915754508, 0.020352121682662982, 0.01699245625786716, 0.05640829971525818, 0.056104839241015725, 0.009714249245007522, 0.011989150807494298, 0.05221944011282176, 0.035254029571660794, 0.0160805682753562, 0.11379457195289433, 0.010319854736735579, 0.07948872880660929, 0.05500903593201656, 0.026065640195156448, 0.07780173807987012, 0.025069425682886504, 0.030516438964696135, 0.03983950773545075, 0.011985260098299477, 0.049300120590487495, 0.02902600790548604, 0.04623302833351772, 0.09466861738474108, 0.03178936138283461, 0.06598846142878756, 0.029016675398452207, 0.09643759316531941, 0.017009132316161413, 0.029744534876954276, 0.011289627454971196, 0.017217534805240575, 0.0665324556757696, 0.05782300388091244, 0.04965752406860702, 0.14222682832041755, 0.05759453742939513, 0.056071973231155425, 0.012401492695062188, 0.04917932863463648, 0.016668063508404884, 0.11726558921509422, 0.006926229098098702, 0.04270830555469729, 0.061701860977336764, 0.0290817450513714, 0.07193068202468567, 0.06823015559348278, 0.021930051952949725, 0.02948200941318646, 0.09335146110970527, 0.024345104393432848, 0.014497207339445595, 0.0534723857708741, 0.07333929315791465, 0.034912522896775045, 0.03907019374310039, 0.01908953367092181, 0.02768177437246777, 0.12023368268273771, 0.027308739408908878, 0.03147319905110635, 0.062265997112262994, 0.04880304120888468, 0.031162558298092335, 0.04767459824506659, 0.03344360113260336, 0.033556125563336536, 0.030052092006371822, 0.04066540306666866, 0.05052926928328816, 0.013359223139559617, 0.017063772938854527, 0.06543077455717139, 0.055343941203318536, 0.040183118398999795, 0.023740951655781828, 0.01813320031942567, 0.1094425808696542, 0.06034592748619616, 0.015987955666787457, 0.017238305663340725, 0.08169329332304187, 0.04278484695532825, 0.05970210324448999, 0.011297667697363067, 0.06698686527670361, 0.02359581911150599, 0.0373827428848017, 0.03413296726648696, 0.0733026755915489, 0.03333382264827378, 0.011905909668712411, 0.03803417785093188, 0.054387654236052185, 0.041412482314626686, 0.03156834980472922, 0.059446611485327594, 0.02993075828271685, 0.029110531104379334, 0.020370979655126575, 0.09547558423946612, 0.025242123447242193, 0.06544555071741343, 0.0636838331411127, 0.022924130935280118, 0.045559540449175984, 0.05084887889097445, 0.02889667568524601, 0.02927014294982655, 0.01871881977422163, 0.052964374553994276, 0.026693098225223366, 0.02444931677018758, 0.07343627701629885, 0.016877414091140963, 0.08850340367644094, 0.03143581336189527, 0.011501590397529071, 0.009645706340961624, 0.04114271163416561, 0.023294384700420778, 0.05056337839050684, 0.022773487944505177, 0.005019224054194638, 0.015173976444202708, 0.01510870455604163, 0.058511108363745734, 0.03037231945199892, 0.06868358555948362, 0.019070193302468397, 0.05045568534114864, 0.0536643571103923, 0.06349491202854551, 0.1323763170512393, 0.04469691251870245, 0.008983690204331651, 0.07206512207631022, 0.02621282106701983, 0.05136640444106888, 0.03845576226012781, 0.04694109287811443, 0.021182553391554393, 0.011354606194799999, 0.032532154727960005, 0.017462927789893, 0.05966983466350939, 0.012519793817773461, 0.013198729993746383, 0.037990112832630984, 0.021464948003995232, 0.034791018479154445, 0.03385808318853378, 0.02121377554431092, 0.044428997207432985, 0.05209455150179565, 0.02208703474025242, 0.030066081490076613, 0.020532244634523522, 0.04412126567331143, 0.028858653604402207, 0.04734494366857689, 0.009153211576631293, 0.050112924436689354, 0.025669572678452823, 0.04576586121402215, 0.026710859674494714, 0.023685049382038414, 0.029332945341593586, 0.08276061300421134, 0.04791398168890737, 0.03973826766014099, 0.012382877775962697, 0.04454751448065508, 0.044334781559882686, 0.07893392146797851, 0.032554337522014976, 0.018195357042714022, 0.029820150448358618, 0.032253719473374076, 0.1050778100034222, 0.033286455072811805, 0.007236173159981263, 0.025504279692540877, 0.02263691792904865, 0.027969085713266395, 0.014042889579286566, 0.057539113840903156, 0.05626347701763734, 0.0505362751573557, 0.01319191615039017, 0.05781217594631016, 0.009398229776707012, 0.038113361297291704, 0.029012636259722058, 0.03822817154286895, 0.04808578887605108, 0.04879031708696857, 0.08456654773908667, 0.05432960344478488, 0.05766661110101268, 0.05419737870397512, 0.03038648334040772, 0.03658673012978397, 0.04916915378998965, 0.026416509062983096, 0.024501217012584675, 0.058894698522635736, 0.05831007911183406, 0.011174897917953786, 0.025941469612007495, 0.07243369487696327, 0.026398306035844143, 0.09367822131025605, 0.07068181817885488, 0.028647597937379032, 0.008542677296645707, 0.06068782378861215, 0.04791633429704234, 0.09231984615325928, 0.03381158392585348, 0.029413115844363347, 0.06312424637144431, 0.019949580782849807, 0.03179798884957563, 0.02844092650775565, 0.09952431151759811, 0.044827285601058975, 0.022194421653694008, 0.08155310162692331, 0.01549607502965955, 0.01593899247382069, 0.04799516893399414, 0.0731715455185622, 0.04493321604968514, 0.040207100901170634, 0.0891133006371092, 0.02967617750982754, 0.03108010940195527, 0.06778491151635535, 0.08838497175020166, 0.057470454048598185, 0.030324608633236494, 0.01583613637194503, 0.12252078144229017, 0.027097854435851332, 0.014727355683135102, 0.025590943987481296, 0.038901585212443024, 0.04631614145182539, 0.02698902961128624, 0.03854620779748075, 0.028073385292373132, 0.06690968191833235, 0.04938213161949534, 0.05377857363782823, 0.059696967582567595, 0.026762617053464055, 0.031234591151587665, 0.021205346602073405, 0.012694907272816636, 0.04333081531513017, 0.06987206084886566, 0.03222517276299186, 0.046824353048577905, 0.008441128302365541, 0.05728929580072872, 0.057944300497183576, 0.08021302041015588, 0.08047771480050869, 0.032696291818865575, 0.013417217342066579, 0.0370499675773317, 0.025603874055377673, 0.05414234474301338, 0.10993469899403863, 0.031157875346252695, 0.04049190378282219, 0.02245679497718811, 0.024678232221049257, 0.04128819484321866, 0.03209982030966785, 0.05081121489638463, 0.020114575054321904, 0.08631566364783794, 0.028794938370992895, 0.047872710856609046, 0.04660710044845473, 0.024885341517801862, 0.029034080616838764, 0.1323357512592338, 0.2278551147901453, 0.14815436181379482, 0.08975749966339208, 0.06611231103306636, 0.2146988402819261, 0.1138823754445184, 0.12561078008729964, 0.11072835171944462, 0.15004597749793902, 0.14659882028354332, 0.10052079320303164, 0.09404726908542216, 0.1748752998537384, 0.0903196245781146, 0.1445528378826566, 0.19059922720771283, 0.10588700330117717, 0.11502091903821565, 0.12200987956020981, 0.3104126761900261, 0.22160467284265906, 0.1361974424798973, 0.19719022588105872, 0.11065796643379144, 0.13158762187231332, 0.1716352315270342, 0.11693922977428883, 0.1443996437592432, 0.13885670603485778, 0.11769830583943985, 0.10791464723297395, 0.16703796805813909, 0.13095937902107835, 0.1490998876397498, 0.1294514982146211, 0.17748127720551565, 0.13745480391662568, 0.14467750384937972, 0.18079746019793674, 0.20743285829667002, 0.1306226517772302, 0.1538641343358904, 0.13002695952309296, 0.11835550729301758, 0.1830645283916965, 0.09122868868871592, 0.0993385371111799, 0.2267853237572126, 0.08539669928723015, 0.12918871856527403, 0.12397609592881054, 0.08599684442742728, 0.1600049016997218, 0.09910554726957344, 0.11165832955157384, 0.1548659594845958, 0.1652514998568222, 0.13667689956491813, 0.12350676915957592, 0.10416354343760759, 0.16004831733880565, 0.10209042811766267, 0.06948731665033847, 0.1536971065797843, 0.16896195622393861, 0.130724192422349, 0.14570868836017326, 0.1268820048426278, 0.20512856397544965, 0.15980400232365355, 0.14255136949941516, 0.14664881135104224, 0.12149367132224143, 0.16945028939517215, 0.1118334467173554, 0.11598627505009063, 0.14926672243745998, 0.1387310604332015, 0.1397444333997555, 0.08527320591383614, 0.10927225055638701, 0.15559081512037665, 0.09504537607426755, 0.2168887251173146, 0.17866589332697913, 0.11985723569523543, 0.26323176571168005, 0.10908398995525204, 0.19357595185283571, 0.1360089666559361, 0.11152214545290917, 0.08680127313709818, 0.14404715329874307, 0.21427090308861807, 0.19218734902096912, 0.14279780705692247, 0.19862335757352412, 0.20666409720433876, 0.23951737181050703, 0.11225572874536738, 0.18324338598176837, 0.1281424387707375, 0.2044680673861876, 0.12542218551971018, 0.1547269255388528, 0.1058202025888022, 0.10585800759145059, 0.20045895595103502, 0.12469085835618898, 0.05859157201484777, 0.1893417173414491, 0.20680277491919696, 0.14156864723190665, 0.10365819282014854, 0.09892344649415463, 0.14758589153643698, 0.07930633859359659, 0.1656533282948658, 0.16928620054386556, 0.1078967095236294, 0.2031543175689876, 0.19235342682804912, 0.09120922957663424, 0.19241260568378493, 0.1704223989509046, 0.16466974513605237, 0.09805264009628445, 0.13901761849410832, 0.11515825346577913, 0.1824464529636316, 0.11781615146901459, 0.0968557785381563, 0.1301079723634757, 0.13888928631786257, 0.0852883754123468, 0.16041756549384445, 0.12277327492483892, 0.11971330357482657, 0.29230516345705837, 0.2245607360964641, 0.15389190550195053, 0.10427869507111609, 0.1413052887073718, 0.12544672092190012, 0.17487814970081672, 0.14502940059173852, 0.13404708442976698, 0.16926962096476927, 0.10086448179208674, 0.1524147199233994, 0.07355680179898627, 0.11760964145651087, 0.13734959706198424, 0.13929353415733203, 0.21418381948024035, 0.10556372377322987, 0.10338580977986567, 0.11612264468567446, 0.15300242666853592, 0.15545399277471006, 0.2071420254651457, 0.11932866327697411, 0.19225788273615763, 0.16208923829253763, 0.09090497871511616, 0.1237665134249255, 0.16879004513612017, 0.15141621959628537, 0.1282289286609739, 0.15033915551612154, 0.1470583729678765, 0.08325127651914954, 0.25010649813339114, 0.17440592113416642, 0.09693548519862816], [0.02359609556151554, 0.03719039304996841, 0.04461458978767041, 0.03592450433643535, 0.07679179383558221, 0.024954682230600156, 0.08354913006769493, 0.0785336441185791, 0.03956173299229704, 0.008471667679259554, 0.015598509962728713, 0.017651490816206206, 0.016764676292950753, 0.009863106442935532, 0.008018440876185196, 0.014687609036627691, 0.05397898690716829, 0.042432389891473576, 0.04395149568154011, 0.0587168539641425, 0.07308896674658172, 0.0632772698008921, 0.02459051593177719, 0.019412143410590943, 0.13646342820720747, 0.016239903670793865, 0.1125164155382663, 0.035584370634751394, 0.03357509856869001, 0.007391485651169205, 0.044147508015157655, 0.08205333884689026, 0.07743360314634629, 0.04400589510623831, 0.03754249388293829, 0.024493160999554675, 0.052147128953947686, 0.07654874789295718, 0.03398481974727474, 0.039179137311293744, 0.03952551989641506, 0.007116627548384713, 0.015648293228878174, 0.08425433363299817, 0.015248462095769355, 0.02472341788234189, 0.04990520472347271, 0.0477988003694918, 0.012160174101154553, 0.024161189066944644, 0.06015266480972059, 0.02451385764288716, 0.06620548025239259, 0.04997844727768097, 0.017705790050968062, 0.02145477872545598, 0.022945209784666076, 0.056165992209571414, 0.036669368273578584, 0.0186492879583966, 0.0306417134925141, 0.0775361382693518, 0.024585781029600184, 0.021998552183504216, 0.06272123049711809, 0.10079204075736925, 0.08766832426772453, 0.027143965926370583, 0.030951311528042424, 0.03411745266930666, 0.03314732835860923, 0.0032104946694744285, 0.1222406503802631, 0.023505100834881887, 0.025585953044355847, 0.004552012405838468, 0.04408866683661472, 0.032087044237414375, 0.005162046663826914, 0.01972422207472846, 0.07498600010876544, 0.031686195434303954, 0.014895911335770506, 0.04731266024464276, 0.06539373396662995, 0.008114621359709417, 0.008224164212151663, 0.050235278613399714, 0.03308374485641252, 0.03958558190788608, 0.025161323974316474, 0.023388596637232695, 0.0837583489192184, 0.04659150421503, 0.02304879319126485, 0.044481474469648674, 0.044285825788392685, 0.008920296877477085, 0.043981326307402924, 0.03464682289632037, 0.045749467171845026, 0.0077135703213571105, 0.01726150334434351, 0.05946005920122843, 0.08038041181862354, 0.047424464792129584, 0.062286836619023234, 0.05841237674758304, 0.026773010831675492, 0.03694139879371505, 0.03580569020414259, 0.010425769414723618, 0.016937236759986263, 0.040285801951540634, 0.03913395165000111, 0.016441016414319165, 0.012396258698572638, 0.01998599611397367, 0.11358443283825181, 0.13298743113409728, 0.02257682066556299, 0.011382858829165343, 0.12019171423162334, 0.018510038789827377, 0.10100036161020398, 0.08024637994822115, 0.023471757995139342, 0.04928023103275336, 0.032315032003680244, 0.01758747315761866, 0.016758759520598687, 0.03083247327595018, 0.04962078404787462, 0.05785122404631693, 0.01208286364999367, 0.039439720203517936, 0.027818043818115257, 0.04143838697928004, 0.008766662103880662, 0.03455376499914564, 0.027210043044760823, 0.024978651745186653, 0.01810794503398938, 0.03245807354687713, 0.038983065605862066, 0.023494579036196228, 0.02278912128531374, 0.06906947266543284, 0.03591434804548044, 0.017996591341216117, 0.03184777211572509, 0.04477764705370646, 0.012383797111397143, 0.03911425133992452, 0.030470119672827423, 0.0475745827134233, 0.0060415825737436535, 0.05938270143815316, 0.048964488014462404, 0.054790844515082426, 0.04951483504555654, 0.07266365675604902, 0.08297859661979601, 0.03957718450692482, 0.06489309598691761, 0.011254116616328247, 0.02639601836563088, 0.04895099576970097, 0.017558225117682014, 0.053194265929050744, 0.06509347585961223, 0.03836895324639045, 0.016775524636614136, 0.07856514828745276, 0.03695021179737523, 0.02218369576439727, 0.03486303648969624, 0.05513008392881602, 0.02790564136375906, 0.08093403914244846, 0.029935649035905953, 0.023693515431659762, 0.02614537468616618, 0.06254171981709078, 0.01450234300136799, 0.0035393690632190555, 0.0022377482582669472, 0.033652385827736, 0.0634320818062406, 0.02482631851307815, 0.010815347777679563, 0.024733195677981712, 0.09669899241998792, 0.07682738723815419, 0.016941969806794077, 0.057626924754003994, 0.030575319105992094, 0.02961356622108724, 0.04737036593724042, 0.016235220718954224, 0.03562408666766714, 0.03086097916821018, 0.016465130647702608, 0.06220281808055006, 0.06092204188462347, 0.0410388258023886, 0.00793175338912988, 0.012753187202179106, 0.030323770006361883, 0.02085324205836514, 0.03864191887259949, 0.013323167750058929, 0.021735677910328377, 0.10634366160957143, 0.05172944824153092, 0.041042031880351715, 0.03475154364423361, 0.01427806690116995, 0.04668183843023144, 0.06676974997390062, 0.006437455276682158, 0.045892601483501494, 0.027144854648213368, 0.024289235516334884, 0.025055929727386683, 0.03806112894380931, 0.02702509613300208, 0.027882460381079, 0.008645465677545872, 0.06429066503187642, 0.034726191879599355, 0.0868251702922862, 0.025029455464391503, 0.03621069132350385, 0.01272113477170933, 0.0815260132367257, 0.030522609922627453, 0.03885880039888434, 0.024088132049655542, 0.04689361398050096, 0.012510974320321111, 0.04858476073422935, 0.07238987847813405, 0.08555655789677985, 0.041775941717787646, 0.03015013713593362, 0.03064296586671844, 0.023744755162624642, 0.06401279009878635, 0.03738114355655853, 0.025173049907607492, 0.025340222382510547, 0.051846945061697625, 0.04004115668067243, 0.0744879744888749, 0.02178670427383622, 0.06595123530132696, 0.05659519476466812, 0.035005558529519476, 0.04408979861182161, 0.03078142093727365, 0.03277966097812168, 0.0529163204919314, 0.060596220500883646, 0.025345730973640457, 0.06142010461189784, 0.038893610835657455, 0.025461333461862523, 0.08705248270416632, 0.05954737287538592, 0.027238743750785943, 0.04248985067533795, 0.028729345503961667, 0.05194239638512954, 0.05666999953973573, 0.08924043053411879, 0.008765829970798222, 0.0459395423240494, 0.03443970803346019, 0.09337453448097222, 0.056551704910816625, 0.03305042984720785, 0.06732583380653523, 0.09233313059667125, 0.09804732631891966, 0.03221904633392114, 0.03820581805484835, 0.012894368737761397, 0.03010691074450733, 0.08016728927032091, 0.03441083106736187, 0.005913341774430592, 0.05184632165764924, 0.04580127650115173, 0.032190199053729884, 0.05018218907935079, 0.03652347317256499, 0.014315826447273139, 0.017734173488861416, 0.037587026454275474, 0.043832110095536336, 0.010650830336089712, 0.020407311494636815, 0.06172307155793533, 0.007356954911301727, 0.05854277951584663, 0.060181497246958315, 0.03977666267019231, 0.07782454427797347, 0.006397301376637188, 0.03555765331839211, 0.017161626965389587, 0.08548219469957985, 0.08693531242897734, 0.018110787459590938, 0.0630873764748685, 0.022488725880975835, 0.03606300764658954, 0.017939175086212344, 0.03461681415501516, 0.03763081687793601, 0.027827211197291035, 0.033210002729902044, 0.02684573017177172, 0.0186746063263854, 0.030955317270127125, 0.03893072564096656, 0.03388306016859133, 0.06875308768940158, 0.047106094571063295, 0.020863166428171098, 0.039419259192072786, 0.041111114696832374, 0.021365006687119603, 0.0784135126741603, 0.08647642025607638, 0.03907126243575476, 0.04997839161660522, 0.011810341457021423, 0.03224347412469797, 0.03206392262654845, 0.046193969101295806, 0.013211663772381144, 0.07388342841295525, 0.035847098333761096, 0.07488120143534616, 0.04985860898159444, 0.04793668027559761, 0.01755662764480803, 0.08139706507790834, 0.035516467833076604, 0.02737409478868358, 0.17770899779861793, 0.14427842135773972, 0.12120829327614047, 0.23702711012447253, 0.21414674178231508, 0.10334404913010076, 0.15329358604503796, 0.18642819399246946, 0.11444828531239182, 0.13190434081479907, 0.0898212130414322, 0.12139557424234226, 0.14504883001791313, 0.1305027652415447, 0.09193335790769197, 0.10402905143564567, 0.13727406127145514, 0.17005509522277862, 0.10258497306494974, 0.2302797557786107, 0.11124222219223157, 0.19284946349216625, 0.12877546105301008, 0.11000944068655372, 0.22086270328145474, 0.11913475493201986, 0.15274027042323723, 0.19708086299942806, 0.10799371564644389, 0.10923787427600473, 0.09362287193653174, 0.19255350984167308, 0.1703053919482045, 0.1337440506904386, 0.12436738586984575, 0.08927752307499759, 0.0921627038042061, 0.21139564487384632, 0.21185252582654357, 0.18565888371085748, 0.10871102364035323, 0.11305758962407708, 0.12537580128991976, 0.15654207032639533, 0.10951706281048246, 0.13482807611580938, 0.14198110322467983, 0.15087066683918238, 0.14769869798328727, 0.15336596028646454, 0.07130640966352075, 0.10456885996973142, 0.10187193984165788, 0.14988271985203028, 0.11235709869652055, 0.11870503658428788, 0.09204304733430035, 0.12574068561661988, 0.12252855914994143, 0.181346055760514, 0.08998774355859496, 0.1080923322297167, 0.1242404711956624, 0.12657174258492887, 0.1539082475937903, 0.13011511182412505, 0.15797643398400396, 0.1289651243132539, 0.13518050720449537, 0.21268891141517088, 0.11646791404928081, 0.09485770176979713, 0.18208427005447447, 0.14785867533646524, 0.15882061212323606, 0.10590239544399083, 0.14344043273013085, 0.10459523589815944, 0.20812795381061733, 0.14778552926145494, 0.1115174253936857, 0.15258010011166334, 0.11697215886670165, 0.1283285694080405, 0.17184157826704904, 0.10309560035238974, 0.11688407335896045, 0.2600091526983306, 0.14184220286551863, 0.2018962288275361, 0.19302085507661104, 0.18233622919069603, 0.19729494291823357, 0.09243741718819365, 0.13527591770980507, 0.23726437473669648, 0.14862746611470357, 0.18669762328499928, 0.1782557083060965, 0.14477301825536415, 0.11336356226820499, 0.10089988223626278, 0.12142111154389568, 0.12062716195941903, 0.3442282194737345, 0.18727326270891353, 0.1903873440460302, 0.1797689325758256, 0.15039278310723603, 0.05020672077080235, 0.12456362455850467, 0.06287066935328767, 0.18784798186970875, 0.17380487057380378, 0.1650457171490416, 0.23752935114316642, 0.15944542625220492, 0.14165405358653516, 0.163835808634758, 0.19072539231274277, 0.16861213749507442, 0.10866606433410197, 0.17722824937663972, 0.12422502710251138, 0.2073793049203232, 0.13803353067487478, 0.10890478355577216, 0.13264472217997536, 0.09335765804280527, 0.09928964442224242, 0.15655263850931078, 0.11103922995971516, 0.22999603272182867, 0.11064794744015671, 0.10477585237822495, 0.13301242666784674, 0.27183845231775194, 0.1653679576702416, 0.14155018259771168, 0.1559416580130346, 0.17927577544469386, 0.11926075676456094, 0.1367278999532573, 0.05087105426355265, 0.14547739061526954, 0.1547826311434619, 0.10688836089684628, 0.20099932851735502, 0.14508800057228655, 0.1380618807161227, 0.09170478384476155, 0.2003865223377943, 0.15698470204370096, 0.18509118526708335, 0.13980433956021443, 0.07782795815728605, 0.10023542257840745, 0.15460919123142958, 0.16500301397172734, 0.24239157617557794, 0.13996164518175647, 0.20741805987199768, 0.16483839077409357, 0.1383153538336046, 0.12493628659285605, 0.15273001394234598, 0.12644010043004528, 0.22597556642722338, 0.0883139853249304, 0.19111230358248577, 0.13361212651943788, 0.1398064917884767, 0.0929002501652576, 0.22140644519822672, 0.09097773145185784, 0.1393488241592422], [0.052033127649337985, 0.058628493861760944, 0.037308372266124934, 0.015402318585984176, 0.03129349170194473, 0.02774203119770391, 0.043863758983206935, 0.027612945741566364, 0.05488730515935458, 0.036602051768568344, 0.05029104358982295, 0.07982493654708378, 0.014952465771784773, 0.03611724379879888, 0.05501023078977596, 0.0511773720063502, 0.04191175103187561, 0.005920578641962493, 0.01271330882445909, 0.026478227919142228, 0.08540425435057841, 0.028990861646889243, 0.06259724730625749, 0.03134054015390575, 0.072695531998761, 0.07341657299548388, 0.04900969594018534, 0.028466218900575768, 0.03809031761193182, 0.048237086812150665, 0.03033460907317931, 0.023511993531428743, 0.0552170450828271, 0.026225389337923843, 0.021640002087224275, 0.060268309971434064, 0.03220261889509857, 0.045037625095574185, 0.04974059636879247, 0.011785955412051408, 0.05234131560428068, 0.03722511442902032, 0.017385434584866744, 0.016110786673380062, 0.01494020085374359, 0.08682055413373746, 0.0769072794355452, 0.05124257710122038, 0.04795631750312168, 0.005657429310303996, 0.019499559130053967, 0.005661263430738472, 0.03355668217409402, 0.0647956742614042, 0.04353361087851226, 0.011453470469859894, 0.041264935935032554, 0.02829556389770005, 0.02916092849773122, 0.01761991428793408, 0.05093476393085439, 0.08242916985182092, 0.046362488574231975, 0.035492622628225945, 0.02890562784159556, 0.07537608777056448, 0.02421217090159189, 0.02969143977679778, 0.07420237379847094, 0.008301607322209748, 0.04566779753076844, 0.043150803685421124, 0.023005785733403172, 0.0329940711526433, 0.018891344989242498, 0.040818920024321415, 0.06731268294970505, 0.004693987111750175, 0.05334573826985434, 0.016569524850638118, 0.05269082263112068, 0.043775899830507115, 0.047602925333194435, 0.08858231623889878, 0.03061056926526362, 0.05983332608593628, 0.04902363347355276, 0.03554317030648235, 0.07204131397884339, 0.0060317236057017, 0.032523156187380664, 0.03563412421499379, 0.07873044683947228, 0.061538287918665446, 0.03236752781958785, 0.062493309524143115, 0.017407609957444947, 0.053141629105084576, 0.014151072446111357, 0.01094824601750588, 0.02458377908624243, 0.0532114058296429, 0.022073473846830893, 0.020239098157617263, 0.03882419776346069, 0.023405844149237964, 0.06103580570197664, 0.01944210391229717, 0.03328026556118857, 0.03489695634925738, 0.019714884001587052, 0.02368349643802503, 0.03472413984127343, 0.055290632735705, 0.03911909385351464, 0.032107828083098866, 0.040471709944540635, 0.037156447215238586, 0.04552870421321131, 0.05390127291320823, 0.03094981424510479, 0.050444827720639296, 0.02140904758562101, 0.02431250370136695, 0.045521776264649816, 0.022288052859948948, 0.024118203873513266, 0.09855816140770912, 0.03334636494400911, 0.07544343767222017, 0.05512694093340542, 0.03200308136001695, 0.03547298540070187, 0.08171586945536546, 0.04226886507240124, 0.0591946597705828, 0.04889208408712875, 0.08756051247473806, 0.024583111153333448, 0.05375838722102344, 0.058985080977436155, 0.08401617844356224, 0.1376488755340688, 0.06410946967662312, 0.04116143973078579, 0.022575529328605626, 0.053709587300545536, 0.057594196041463874, 0.04717347786936443, 0.0261216667786357, 0.02405344963335665, 0.030236669699661434, 0.022182794054970145, 0.05647182755637914, 0.04366888213553466, 0.039515389580628835, 0.022722131325281225, 0.027648670875350945, 0.009216257949447026, 0.01013685225188965, 0.08738340635318309, 0.042966376277036034, 0.008748683576413896, 0.018748706061160192, 0.015876075049163774, 0.03486616835289169, 0.07526662098825909, 0.048932071003946476, 0.06800535164074972, 0.032797242456581444, 0.055286918286583386, 0.004051292326039402, 0.0272428255630075, 0.035104869020869955, 0.033872877902467735, 0.021546359748754185, 0.051209020894020796, 0.006377045383487712, 0.03060346505662892, 0.03970310841395985, 0.015443100528500509, 0.037282152188709006, 0.07369891565758735, 0.032324995336239226, 0.08825596421957016, 0.012298532692511799, 0.00711491968104383, 0.03183046152116731, 0.006963649575482123, 0.04724181111669168, 0.04889107476628851, 0.0496991808176972, 0.035160834377165884, 0.03386856602446642, 0.13014466414460912, 0.018922188646683935, 0.039245147636393085, 0.03958731482271105, 0.04713389542303048, 0.04485933524847496, 0.050015769884339534, 0.029017489905527327, 0.04422576748766005, 0.03999027132522315, 0.04303976726077963, 0.03958944849728141, 0.022301099816104397, 0.01813241178751923, 0.052598651600419544, 0.08870684119756334, 0.008151661022566259, 0.02772418625681894, 0.034965289596584626, 0.06333179539069533, 0.007581818235848914, 0.005989572400721954, 0.04201961477519944, 0.02863471796445083, 0.02443606201268267, 0.0036205929518473567, 0.05077062683994882, 0.03930871629563626, 0.016976808074105065, 0.05768253387941513, 0.011524990313773742, 0.08167955616954714, 0.04143023819779046, 0.03681066576973535, 0.029214628448244184, 0.07965620185132138, 0.04328143651946448, 0.04799958842340857, 0.022286728126346134, 0.016390342570957728, 0.030753801911487244, 0.0205243927121046, 0.020543208011076786, 0.05977328633889556, 0.041316622809972614, 0.019946281936427113, 0.027765000668296125, 0.06851398997241631, 0.012816980361094465, 0.03813332135905512, 0.05190846168261487, 0.0536105551145738, 0.03255813360738102, 0.06793895910959691, 0.04168900653894525, 0.0724836859444622, 0.017057963777915575, 0.06885068010888062, 0.05063231277745217, 0.06645227404078469, 0.05805286185932346, 0.04571216311887838, 0.018251463407068513, 0.03742746099305805, 0.021578470623353496, 0.050006808451144025, 0.010332915608159965, 0.08098260528640822, 0.031746179520268925, 0.01035687213516212, 0.03725606940861326, 0.05445626207801979, 0.016697190949344076, 0.026765711809275672, 0.03678542903799098, 0.0635487177351024, 0.02359856320254039, 0.05252149792795535, 0.05440400003863033, 0.01712027264147764, 0.052091916877543554, 0.018538852673373185, 0.051116237591486424, 0.04841047848458402, 0.06343476838083006, 0.015878913764026947, 0.01686045045062201, 0.04016838676761836, 0.1137265021679923, 0.04393395873194095, 0.05756155267590657, 0.10685771761927754, 0.02489502283424372, 0.026999920628441032, 0.011057877927669324, 0.06371465453412384, 0.02119242024491541, 0.03412006131839007, 0.016223812053794973, 0.026140456102439202, 0.056225037478725426, 0.02119602337188553, 0.018878971532103606, 0.06715552575769834, 0.06163468919112347, 0.05072741158073768, 0.012272693893464748, 0.04071254799782764, 0.12016887092613615, 0.04162146367889363, 0.07433847626089118, 0.027900702370970976, 0.05699108231056016, 0.029353877616813406, 0.04523232011706568, 0.038362708073691465, 0.027581282010942232, 0.08558327521313913, 0.06993043818511069, 0.04631989671906922, 0.07258599842316471, 0.013562688491219888, 0.07641733580385335, 0.13060334109468386, 0.051141337025910616, 0.007437347594532184, 0.11272517425823025, 0.06323440335108899, 0.022248069653869607, 0.06302488021901809, 0.02579142033937387, 0.014136582940409426, 0.033803657788666897, 0.05315197093295865, 0.04501235125644598, 0.0041835569572867826, 0.01833462290960597, 0.013380400323512731, 0.06362484724377282, 0.0212622043909505, 0.042894770158454776, 0.032968326049740426, 0.028252053634787444, 0.023607211078342516, 0.03478671031189151, 0.0020090313319087727, 0.011451809914433397, 0.00354059638993931, 0.029069610936858226, 0.0919757790688891, 0.05440088301838841, 0.02777225887257373, 0.057080199403571896, 0.013067277086520335, 0.06102897423261311, 0.046359861371456645, 0.02170365052734269, 0.030770949233556166, 0.18307303340407088, 0.14027503930265084, 0.07519559003412724, 0.1436133828246966, 0.1001245308725629, 0.1600043525104411, 0.08473517853417434, 0.14775106392335147, 0.14003412332385778, 0.12278321228222921, 0.13369165506446734, 0.13592917093774304, 0.114287699398119, 0.11217835242860019, 0.15457883739145473, 0.15730232640635222, 0.21149178268387914, 0.10771142493467778, 0.17364536819513887, 0.1189326829626225, 0.17391009227139875, 0.17420135554857552, 0.18618678819620982, 0.08330082971951924, 0.10813333588885143, 0.10680132923880592, 0.12733511568512768, 0.1191591122187674, 0.16447340254671872, 0.11829374576336704, 0.11987880992819555, 0.08423842940828763, 0.14110885706031695, 0.20531326968921348, 0.06053797304048203, 0.1638472970807925, 0.1162427019153256, 0.11683281321893446, 0.0903864401334431, 0.10501725075300783, 0.24597994924988598, 0.11505686125019565, 0.0795676487905439, 0.14061095018405467, 0.14999465056462213, 0.1732018607435748, 0.12993772368645296, 0.12897177395643666, 0.1018289991770871, 0.11764109367504716, 0.06626174246775918, 0.09440947425900958, 0.1498233777238056, 0.1445066911401227, 0.15157938818447292, 0.09324839164037257, 0.12635972583666444, 0.07527677356847562, 0.10974548844387755, 0.11632760360953398, 0.11645233636954799, 0.21114358183695003, 0.1328090188326314, 0.06639447557972744, 0.09073455934412777, 0.17444197466829792, 0.05038490671722684, 0.12081762673915364, 0.127687472559046, 0.11415378627134487, 0.18056332744890824, 0.19157160393660888, 0.09108449681662023, 0.1730675617000088, 0.0772469381627161, 0.17468266800278798, 0.10475743227289058, 0.14772974944207817, 0.13230331940576434, 0.08937200589571148, 0.28597559372428805, 0.09502237691776827, 0.13495137653080747, 0.14116897102212533, 0.10050100012449548, 0.1257195047219284, 0.24380505579756573, 0.07326725288294256, 0.18418092629872262, 0.11144591946504079, 0.11108093123766594, 0.08445151484920643, 0.2781314490130171, 0.11665099445963278, 0.16387640411267057, 0.175963971123565, 0.14833301160251722, 0.06755704249371774, 0.15668923821067438, 0.06691980481264181, 0.19999601907329634, 0.16743657557526603, 0.20938786823535338, 0.10858079898753203, 0.11207684146938846, 0.0798029986617621, 0.2421508976840414, 0.1165399097953923, 0.1459804776823148, 0.13777974585536867, 0.24237088509835303, 0.14941408328013495, 0.0865292017988395, 0.13537502411054447, 0.16243987338384613, 0.07571561291115358, 0.11547189991688356, 0.11877628276124597, 0.13013678253628314, 0.12159285193774849, 0.06629030773183331, 0.25822461408097297, 0.19754915818339214, 0.16854982677614316, 0.14669518073787913, 0.14125396177405491, 0.2505723590729758, 0.20492536394158378, 0.1465960149653256, 0.15558239916572347, 0.15570846037007868, 0.1475021624355577, 0.09876068608718924, 0.2026807382935658, 0.09402130133821629, 0.17182876879815012, 0.13318828598130494, 0.15443575131939724, 0.10775322269182652, 0.1039313328510616, 0.1459879140020348, 0.22940612921956927, 0.27920052758418024, 0.1896150058018975, 0.11784866495872848, 0.07498171049519442, 0.10617024396196939, 0.18473482079571113, 0.13001345243537799, 0.09195051636197604, 0.17261771630728617, 0.10123573374585249, 0.119112060056068, 0.10836564295459539, 0.09248309637769125, 0.1108688476961106, 0.08620816355687566, 0.10048059848486446, 0.10310028330422938, 0.12058082967996597, 0.17671906185569242, 0.12894723855424672, 0.05608022962405812, 0.07210773619590327, 0.1227962518169079, 0.1633185613900423, 0.16129496216308326, 0.21749740495579317, 0.09178178166621365, 0.08159001605235972, 0.15528404095675796, 0.08551306062145159, 0.2554439945379272, 0.09516969323158264, 0.09716512795421295, 0.198285962396767], [0.09842873085290194, 0.05396801054303069, 0.03444461734034121, 0.04525441014266107, 0.06014001861331053, 0.0315686652174918, 0.10535697627346963, 0.010213967889285414, 0.05024986923672259, 0.07808267066138797, 0.01871041124104522, 0.024503634558641352, 0.009771862169145606, 0.014696004582219757, 0.030568673173547722, 0.02647879195137648, 0.026207132505078334, 0.03684603652800433, 0.018482699924788903, 0.050076959960279055, 0.0499080619920278, 0.046482868638122454, 0.040158364063245244, 0.0671495588903781, 0.0064544124234089395, 0.05726592557039112, 0.07136898013413884, 0.04189590246824082, 0.02531851456296863, 0.047916501280269586, 0.07741480454569682, 0.037400524743134156, 0.010000084639614215, 0.028050289656675886, 0.020761703708558343, 0.054662393595208414, 0.0515237137733493, 0.03521017235470936, 0.03226121516490821, 0.013125780587870395, 0.0176033328534686, 0.03747779344848823, 0.024109116275212727, 0.0218475715155364, 0.017636755474086385, 0.11060338889365084, 0.06683707018964924, 0.04979175631888211, 0.024516150879208, 0.018090389530698303, 0.06022787776601035, 0.03673728962894529, 0.04455744070583023, 0.022536269716511015, 0.03117772408586461, 0.017482288567407522, 0.061010286954115145, 0.05610141051874962, 0.021193880420469213, 0.020168158116575796, 0.036714401794597507, 0.07579490396892652, 0.022559918252227362, 0.03689792378281709, 0.039888363317004405, 0.026514980927458964, 0.03512867711833678, 0.03508341724227648, 0.015004712968220701, 0.02869633291993523, 0.04512557701673359, 0.042738503543660045, 0.0043188657855353085, 0.022086706339905504, 0.06657981954049319, 0.06450463362853043, 0.016552718916500453, 0.026833915180759504, 0.09214593868819065, 0.08960500315879472, 0.07432425671140663, 0.012931819364894181, 0.007027356459730072, 0.013397529091889737, 0.02259560627862811, 0.038967755099292845, 0.029349766118684784, 0.056913776497822255, 0.023128943284973502, 0.013956942384538706, 0.011231927328481106, 0.026822333966265433, 0.026180155437032226, 0.04589747739373706, 0.0633877755899448, 0.04324999172240496, 0.07202693857834674, 0.01425589523933013, 0.052462285675574094, 0.02128097701643128, 0.03690525991260074, 0.04564161456073634, 0.05537579047086183, 0.09718560380861163, 0.019421798751864117, 0.02098906807077583, 0.043500733736436814, 0.03645427532319445, 0.01693487116426695, 0.026105988908966538, 0.07244499036460184, 0.041341859541716985, 0.06001581277814694, 0.0554679763445165, 0.1484626648016274, 0.05544478422962129, 0.054820485893287696, 0.05413419225078542, 0.039866937513579614, 0.044248736958252266, 0.021184009856369812, 0.048782275916892104, 0.01429147658200236, 0.10098678772919811, 0.025442523728997912, 0.017118465511885006, 0.034999728959519416, 0.016709239716874436, 0.024231088245869614, 0.04501680414250586, 0.07803983389749192, 0.033593514963286, 0.020393147606228013, 0.013798166382912314, 0.05753584839112591, 0.020664916519308463, 0.06570383295184001, 0.04746964303194545, 0.0546270079939859, 0.03129826742224395, 0.043863172686542384, 0.0008478197071326576, 0.010946660604531644, 0.05990551850118209, 0.050551036474644206, 0.03442750712565612, 0.06531220904435031, 0.031977692487998866, 0.007905610309535405, 0.019676309020724148, 0.037228732398943976, 0.0722069019684568, 0.017166593788715545, 0.040246393909910694, 0.08259270209237002, 0.018581828589958604, 0.03801929036853835, 0.03274549249908887, 0.06220507049874868, 0.04666752982302569, 0.010610262688715011, 0.03769375842239242, 0.024852206479408778, 0.03998426363978069, 0.0413804771960713, 0.03769188821024727, 0.011309969722788082, 0.0025760319249457098, 0.015551043125014985, 0.037793109731865115, 0.024162383924704045, 0.011581255312194116, 0.0413097208365798, 0.021286455921654124, 0.03499412203382235, 0.07278302378836088, 0.03536689167958684, 0.020917545443808194, 0.0711077441519592, 0.021948585235804785, 0.011075756265199743, 0.02626906287332531, 0.016750289760238957, 0.04470166968530975, 0.05399444213253446, 0.05746197130065411, 0.007891221921454417, 0.008789354196778731, 0.008761248136579525, 0.05125945353938732, 0.051468290184857324, 0.041529270383762196, 0.009295255858887685, 0.06835774562205188, 0.0356270404154202, 0.008517286569258431, 0.005575396944550448, 0.02616339403175516, 0.09625006729038432, 0.036584815388778225, 0.07846630163840018, 0.013407522110355785, 0.03005595674039796, 0.04564680959447287, 0.05797472484118771, 0.02561353310738923, 0.027341714885551482, 0.049578763646422885, 0.03699691886140499, 0.03130952580249868, 0.05459819039970171, 0.047139042217168026, 0.03505880762531888, 0.06463335172156803, 0.016050184749474283, 0.052462137246038765, 0.05067965066700708, 0.011595344985835254, 0.02825121315254364, 0.05918507122260053, 0.0356671868939884, 0.054395090555772185, 0.06970923364860937, 0.02727258382947184, 0.054812797243357636, 0.04987960433936678, 0.05273239774396643, 0.021372109040385112, 0.017381922370987013, 0.040802325602271594, 0.02543985941883875, 0.05901807686313987, 0.008460459393972997, 0.03753480894374661, 0.040648641661391594, 0.018977831168740522, 0.08209196021198295, 0.04667863606300671, 0.013673813973582583, 0.01611479983694153, 0.04348051021224819, 0.026127158671442885, 0.02811479898809921, 0.03689725956064649, 0.025991950496973004, 0.045561228835140355, 0.04674143288866617, 0.030684492739965208, 0.03487842492177151, 0.033038510955520906, 0.09178975233226083, 0.02534782197471941, 0.028017716795147862, 0.03742161286936607, 0.05748717092501465, 0.052634801613749005, 0.054942450442467816, 0.015545898186246632, 0.04208830425341148, 0.04454486501344945, 0.08630924407043494, 0.011004280950146494, 0.028331867906672414, 0.05359829112421721, 0.03422267807764001, 0.05245505344646517, 0.041851774367387407, 0.04919091355986893, 0.016324350799550302, 0.03721824956301134, 0.06280688176047988, 0.01961465139174834, 0.06908312818268314, 0.02707214829570148, 0.04051694384543225, 0.025215766072506085, 0.0212932113208808, 0.019024393513973337, 0.07069929575663991, 0.02102984351949999, 0.024157517291314434, 0.007347226746787783, 0.06031122095009778, 0.03234360097849276, 0.03709814038302284, 0.05734752841817681, 0.05319413605320733, 0.0285328507743543, 0.04363996064057574, 0.03214663127437234, 0.07057342751068063, 0.04618608749296982, 0.028383094650052954, 0.06848379198345356, 0.019241137742938008, 0.030569240916520357, 0.04080074111698195, 0.01831583729654085, 0.07146615695091896, 0.04068890688358806, 0.039726682734908536, 0.017796968459151685, 0.026644138742994983, 0.07182687782915309, 0.00937257280384074, 0.011594614898058353, 0.09382351156091318, 0.05321048556652386, 0.03663750416308176, 0.07158944994444028, 0.08150417925207876, 0.028626018138311338, 0.029138064783182926, 0.06334688325296156, 0.04964779822330456, 0.03772348143684212, 0.05276096300804056, 0.03657576489786152, 0.0226179616220179, 0.05555886717047542, 0.05577175223152153, 0.09208095623762347, 0.041691540973261, 0.04145124097703956, 0.054135921454872005, 0.04494219603657257, 0.04121234735066537, 0.030478040243906435, 0.0601486349478364, 0.005547369737541885, 0.046567388126277365, 0.0858433757093735, 0.02975013994728215, 0.057851012534229085, 0.028735651903843973, 0.019052767675020732, 0.058085197233594954, 0.038422796060331166, 0.04327314301917795, 0.012710306837107055, 0.09489576652413234, 0.020626911136787385, 0.026167058385908604, 0.03583942823752295, 0.013656488536071265, 0.049231783632421866, 0.04424342689162586, 0.03498908285109792, 0.03510320661007427, 0.04094831347174477, 0.03980226676503662, 0.01512480544988648, 0.22322835837258026, 0.1313025035778992, 0.25453177629970014, 0.11337495423504151, 0.21462735661771148, 0.11794040183303878, 0.16452066251076758, 0.11195797167601995, 0.21466959966346622, 0.1823277390212752, 0.1478487008716911, 0.09730763515108265, 0.12272633408429101, 0.14503300742944703, 0.21192936779698357, 0.11200019245734438, 0.06180471151310485, 0.13618289638543501, 0.09371103908051737, 0.1157787928241305, 0.12623078509932384, 0.16039381676819175, 0.1510683007654734, 0.1732728397473693, 0.19237181724747643, 0.1098315033596009, 0.1610135249211453, 0.16522966587217525, 0.10365785143221729, 0.1182246815005783, 0.08427827531704679, 0.12676312762778252, 0.1805860668537207, 0.16271803033305332, 0.07063433557050303, 0.09978315778425895, 0.12432809657184407, 0.11975447050645016, 0.10223390752798878, 0.16042697592638433, 0.12066949406289496, 0.13590027170721442, 0.152022227703128, 0.20871665503364056, 0.08199261632398702, 0.15400250034872442, 0.1776847889414057, 0.15759596455609426, 0.10703437103074975, 0.17122311692219228, 0.1734580352785997, 0.06037142768036574, 0.10581335998722352, 0.1353108580224216, 0.10599313784041442, 0.12223572994116694, 0.16241469973465428, 0.11510056632687338, 0.17849916242994368, 0.10520122174057178, 0.22698065702570602, 0.21041979489382356, 0.08142853956087492, 0.17177965346490964, 0.2116168345673941, 0.10677516111172736, 0.10657111502951011, 0.13632734800921753, 0.08126013141009025, 0.0775270395388361, 0.2426680113421753, 0.1820557122118771, 0.14538211369654164, 0.13277594873216003, 0.3721338923787698, 0.16019456495996565, 0.17268603842239827, 0.09900690842187032, 0.14245019992813468, 0.11513195175211877, 0.12242342651006766, 0.16051310958573595, 0.08705746251507662, 0.24689409707207233, 0.23218709015054628, 0.1593065555789508, 0.21990447188727558, 0.1889434808981605, 0.1484109222656116, 0.13435479369945824, 0.08051506709307432, 0.11458226523245685, 0.15654112037736923, 0.11470664918306284, 0.19664661755086854, 0.17322445171885192, 0.17638398217968643, 0.12160345722804777, 0.18533146299887449, 0.11596029245993122, 0.12912717967992648, 0.21803241921588778, 0.1795880266581662, 0.14863421965856105, 0.06340503052342683, 0.07588152002426796, 0.1846273578121327, 0.11911664652870968, 0.10616541258059442, 0.20135293219937012, 0.18602767173433676, 0.16639523848425597, 0.2466220554197207, 0.1104450887942221, 0.2262318300199695, 0.11352321307640523, 0.16396915772929788, 0.11910494285984896, 0.08365660047275014, 0.13481363392202184, 0.1469517411896959, 0.11158963636262342, 0.15400980308186263, 0.23076731711626053, 0.14153735828585923, 0.09300979116233066, 0.09552570147207007, 0.19320290390169248, 0.11094015324488282, 0.1570031073060818, 0.15690131433075294, 0.10421491489978507, 0.1313419858342968, 0.23510255792643875, 0.19864108006004244, 0.07098460700944997, 0.13567715242970735, 0.20467868889681995, 0.08761440723901615, 0.1409479446010664, 0.13549787923693657, 0.12979634455405176, 0.08838678259053268, 0.15280427323887125, 0.19480710063362494, 0.17902017978485674, 0.21870321681490168, 0.13781174726318568, 0.1208474684972316, 0.16337885346729308, 0.09388265330926515, 0.20027352293254808, 0.13070326385786757, 0.14187763299560174, 0.20510888221906498, 0.20497637917287648, 0.14032587641850114, 0.11935484624700621, 0.13735195709159598, 0.12824617617297918, 0.13718528556637466, 0.07209503062767908, 0.13456027954816818, 0.0929017789894715, 0.23362886044196784, 0.13862987601896748, 0.07616936200065538, 0.17224034905666485, 0.07510502575314604, 0.14748613204574212, 0.12971491611097008, 0.18003540812060237, 0.14890161546645686, 0.08157199670677073, 0.10116212753928266, 0.15304984990507364], [0.021920019971730653, 0.007518885504396167, 0.024715927756915335, 0.0270481750703766, 0.026876293668465223, 0.0483659310702933, 0.059342540116631426, 0.05156558945600409, 0.021561998655670322, 0.03417804902710486, 0.02945578748040134, 0.03609404055168852, 0.0654528608720284, 0.015030688136903336, 0.046759481920162216, 0.05742094537708908, 0.05767774702690076, 0.06046844493539538, 0.12741690035909414, 0.04957041077432223, 0.039649566169828176, 0.08026126000913791, 0.041941147501347587, 0.03470642848697025, 0.027398134807299357, 0.008905593076633522, 0.054391454032156616, 0.04685842133767437, 0.01656638185522752, 0.048758167249616235, 0.041324738194816746, 0.03615265908592846, 0.017027715693984646, 0.04303552588680759, 0.06469293133704923, 0.00966759134826134, 0.10164707651711069, 0.026873918795899954, 0.03797383753408212, 0.028625971754081547, 0.006238560163183138, 0.05725526832975447, 0.03641589886683505, 0.04051912575960159, 0.017341163620585576, 0.04150812659645453, 0.06405088453902863, 0.05952321967924945, 0.03783050284255296, 0.03806418288149871, 0.0073364312811463606, 0.014077766809350578, 0.003656344988485216, 0.04206807701848447, 0.025296613785030786, 0.022291399945970625, 0.038235351821640506, 0.06820377224357799, 0.03317047965538222, 0.08157518794178031, 0.04689293862611521, 0.012765293486154405, 0.015538151092187036, 0.0508393942436669, 0.015829863368708175, 0.030651281631435268, 0.03510185219056439, 0.020872840323136188, 0.07812437936081551, 0.023539421454188414, 0.012140953404013999, 0.06435775518184528, 0.0403681395255262, 0.012851114515797235, 0.013375433500186773, 0.01847635085141519, 0.023075894569046795, 0.022284959959506523, 0.045645425489055924, 0.036260994093026966, 0.0371421682939399, 0.036908937254338525, 0.044994302224949934, 0.016396077517129015, 0.03452791970630642, 0.004839386829189607, 0.035232629743404686, 0.05666677861881908, 0.07301808422198519, 0.07043864607112482, 0.031478460878133774, 0.01816596613934962, 0.03185172034136485, 0.014522749279421987, 0.056215326476376504, 0.011084927355113905, 0.038219777852646075, 0.05749924937845208, 0.06909806019393727, 0.0036353811719891382, 0.013653571895702044, 0.02725442718656268, 0.0337912416580366, 0.008443107981292997, 0.025024868991749827, 0.055103166232584044, 0.023798100737622008, 0.07638005772605538, 0.030893051080056466, 0.08328943033120595, 0.05479426581587177, 0.045311689100344665, 0.03897020789736416, 0.07739423963357694, 0.042416804790263996, 0.1050218372256495, 0.0508377355436096, 0.018763317093544174, 0.05788634989585262, 0.028003367369819898, 0.007303120910364669, 0.09898392410832457, 0.02201246559707215, 0.005174056004761951, 0.008670252482261276, 0.03588590152503457, 0.03419476590352133, 0.007875611772760749, 0.08385401175473817, 0.02039550763583975, 0.030280029677669518, 0.018960932466143277, 0.024899353265936952, 0.04632329204468988, 0.047071874141693115, 0.01960611483809771, 0.032120841642608866, 0.06455483249737881, 0.021916030927968677, 0.08869044715538621, 0.035035968030570075, 0.023341165979218204, 0.03962763941672165, 0.014647626758232946, 0.03432042634813115, 0.07370082297711633, 0.07088150043273345, 0.029164579864300322, 0.0689904265163932, 0.03906683181412518, 0.04240121597831603, 0.02895041830925038, 0.051252109988126904, 0.05008032931073103, 0.042164923579548486, 0.03370228412677534, 0.023088589005055837, 0.02426026763714617, 0.01966982821613783, 0.039568315842188895, 0.026595928829920013, 0.038450578358606435, 0.020588709085131995, 0.012290337526792428, 0.002612917592159647, 0.045859883903176524, 0.030984774966782425, 0.056858267562347464, 0.021247326185402926, 0.05628758197417483, 0.05587668078078423, 0.023338071223406587, 0.04459898242203053, 0.035046228222199716, 0.020115417391934898, 0.020705276365333702, 0.03014492725924356, 0.021354447781050112, 0.018159405553888064, 0.11101660929853097, 0.02122295591107104, 0.05927629601501394, 0.032539130916120484, 0.09138022040133364, 0.03323815610201564, 0.057318766484968364, 0.05125368705193978, 0.05566519837884698, 0.03468889153737109, 0.013760493111476535, 0.042313601734349504, 0.027901080866286065, 0.07136134343454614, 0.024458593616145663, 0.04454698755580466, 0.0029531681821026723, 0.048864075433812104, 0.08244496275437996, 0.04458685201825574, 0.06752825458534062, 0.04596916143782437, 0.012099689993192442, 0.015172083039942663, 0.015610324953740928, 0.004790811408383888, 0.0107659188870457, 0.03752438919036649, 0.05121757414599415, 0.029628127158503048, 0.02101935511745978, 0.029396942591120023, 0.029315085557755083, 0.030333950417116284, 0.04390698166389484, 0.030522762062901165, 0.03686214855406433, 0.06641508502070792, 0.023062778964231256, 0.05039724121161271, 0.024915650828916114, 0.037107847674633376, 0.03767794325540308, 0.0782461064227391, 0.0995508284540847, 0.044023684386047535, 0.06778109687729739, 0.05372687563067302, 0.025274384606746025, 0.015105549500731286, 0.044563322226167656, 0.03209969414456282, 0.04744515958009288, 0.03171990378177725, 0.03819508659944404, 0.039609928062418476, 0.06267084609135054, 0.02640469221660169, 0.05053383720223792, 0.03630453960795421, 0.03250734102039132, 0.04413963382830843, 0.046279564703581855, 0.02974712126160739, 0.05630630264931824, 0.024480848769599106, 0.041753206023713574, 0.030137708017718978, 0.05940459479461424, 0.06443872349336743, 0.004923493961541681, 0.04982860395102762, 0.003509296079755586, 0.024693266277608927, 0.008741141500649974, 0.049395861351513304, 0.0466690772009315, 0.029691810850636102, 0.02870400858228095, 0.03079307822190458, 0.03324305056594312, 0.05529171998205129, 0.04171566819422878, 0.04586403621942736, 0.06271834354265593, 0.07979530259035528, 0.025735850176715758, 0.00968504666161607, 0.03902235490386374, 0.015376594819827005, 0.03902075928635895, 0.04195136316411663, 0.02988385640492197, 0.010683191685529891, 0.043135348460054956, 0.01837388437706977, 0.008646154947200557, 0.003347292895341525, 0.023982097700354643, 0.04291930184990633, 0.023121840931707993, 0.02187638354371302, 0.031440455495612696, 0.030036534735700116, 0.07826430388377048, 0.015469578502234071, 0.02695638995646732, 0.02606853642646456, 0.07711761893006042, 0.0254122719343286, 0.1366746731218882, 0.014381972214323469, 0.08048429022892378, 0.025203080913343, 0.049754147985368036, 0.0638104064273648, 0.03599358715291601, 0.004488122303882847, 0.05531193608476315, 0.013077554904157296, 0.1058081872179173, 0.020773078977072146, 0.016085592615127098, 0.039040697083692066, 0.04182937635050621, 0.07530622198828496, 0.0365075800800696, 0.021602300985250622, 0.04079365360666998, 0.020221138183842413, 0.06309307616902515, 0.021758949806098826, 0.031233010377036408, 0.015957659343257546, 0.009361842276121024, 0.04741885786643252, 0.07768724695779383, 0.07481461594579741, 0.021776084140583407, 0.058406450698385015, 0.0355643845978193, 0.10102005078806542, 0.02909071947215125, 0.05284725622914266, 0.008471324435959104, 0.04297592029615771, 0.00952889044128824, 0.03743965076864697, 0.02935605025413679, 0.035238503842265345, 0.032512910838704556, 0.04575309627398383, 0.0194177967205178, 0.010953994878946105, 0.03510493952489924, 0.013979320920043392, 0.044042713052476756, 0.026379592782177497, 0.0943432524218224, 0.021498288988368586, 0.05142960202647373, 0.027077519589511212, 0.04803629133675713, 0.05564276325458195, 0.022805316802987363, 0.018720315201790072, 0.02316153284482425, 0.03499692364130169, 0.02200731323682703, 0.07656968387891538, 0.03384774136065971, 0.08453217888018116, 0.016320547292707488, 0.07728408265393227, 0.06850711768493056, 0.16854765970492736, 0.16337518725777045, 0.12510497675975785, 0.13275729113956913, 0.15561817068373784, 0.171997043362353, 0.10196799601544626, 0.10529900711844675, 0.15611993672791868, 0.18443206907249987, 0.12444059131667018, 0.09888190106721595, 0.22927908838028088, 0.14819967735093087, 0.24335037160199136, 0.11515995298395865, 0.24245369393611327, 0.13018563069636002, 0.1817282469710335, 0.17194389074575156, 0.18479079357348382, 0.17200951144332066, 0.12094396253814921, 0.08517876020050608, 0.10579386376775801, 0.07716771389823407, 0.11939406133024022, 0.1569800710421987, 0.10183420163230039, 0.13291533890878782, 0.12341725872829556, 0.1310780187486671, 0.15013460477348417, 0.13226587063400075, 0.1353259978350252, 0.14912995946360752, 0.1440238201757893, 0.11460325316875242, 0.16198256198549643, 0.14289554790593684, 0.17678054136922583, 0.08888052601832896, 0.09714483763673343, 0.13806335016852245, 0.28361039876472205, 0.13589329551905394, 0.1645405965973623, 0.2053445141064003, 0.11002527069649659, 0.11590276859351434, 0.14039859204785898, 0.11352095694746822, 0.12555522291222587, 0.11533158947713673, 0.13889494148315862, 0.14449309499468654, 0.13359594770008698, 0.181052892585285, 0.08717087752302177, 0.14204322098521516, 0.12608994031324983, 0.1205426907108631, 0.11484761271276511, 0.27085475041531026, 0.1123169633501675, 0.10378513718023896, 0.08328292169608176, 0.11295112853986211, 0.1160281321790535, 0.15657442796509713, 0.1280900283018127, 0.1775637298123911, 0.130613092915155, 0.11016058648237959, 0.17066911852452904, 0.12284347467357293, 0.21387382439570501, 0.136349642125424, 0.07018864620476961, 0.15496347768930718, 0.1256035960977897, 0.2368464565370232, 0.15445638302480802, 0.15155838540522382, 0.15505428687902167, 0.22301221528323367, 0.2905561588704586, 0.1823666869313456, 0.13186169700929895, 0.08237653673859313, 0.10915048638707958, 0.1452723945840262, 0.20619920105673373, 0.14860631490591913, 0.09541843144688755, 0.1889859911170788, 0.17663831618847325, 0.1679195652832277, 0.08483695666654967, 0.13348686683457345, 0.14257042785175145, 0.1737888401839882, 0.1462305962922983, 0.16119244188303128, 0.06350194758852012, 0.1410118880448863, 0.11561505278223194, 0.23851784731959924, 0.12004674310446717, 0.18445598107064143, 0.11768269847379997, 0.21947208180790767, 0.1383640684070997, 0.15408783248858526, 0.14528480329317972, 0.12392885822919197, 0.16749432950746268, 0.12037968539516442, 0.11976042995229363, 0.22500779101392254, 0.11046924570109695, 0.18463423009961843, 0.1878302445402369, 0.15835614642128348, 0.1338019678951241, 0.14571346779121086, 0.13432470703264698, 0.10221896809525788, 0.09395945075084455, 0.13579032995039597, 0.126725485897623, 0.23353463737294078, 0.10690320385037921, 0.11313449838780798, 0.15468391065951437, 0.16739252168918028, 0.08771326873102225, 0.26650193554814905, 0.17133225715951994, 0.10102745742187835, 0.0932248804019764, 0.07850686743040569, 0.26748361880891025, 0.19153277477016672, 0.07770461321342736, 0.10686132445698604, 0.21143891208339483, 0.11623357349890284, 0.14346611103974283, 0.1773280237102881, 0.1657355879433453, 0.12328651457210071, 0.15952786401612684, 0.08446224630461074, 0.11895101401023567, 0.18298413895536214, 0.11286692446446978, 0.13470127276377752, 0.09887685446301475, 0.23345705325482413, 0.09953354383469559, 0.132677911024075, 0.05340096147847362, 0.16981101769488305, 0.11258145736064762, 0.17352056864183396, 0.14057899330509827, 0.16575945541262627, 0.16305195225868374, 0.10699929713155143, 0.18575991969555616, 0.22471238655271009, 0.15336362994275987, 0.06165387370856479], [0.04625642082828563, 0.02005542588449316, 0.050416826488799416, 0.04137493706366513, 0.05696878819435369, 0.030978542781667784, 0.0687599228695035, 0.04283505695639178, 0.05946837867668364, 0.018787781991704833, 0.055803820432629436, 0.019026454829145223, 0.028284463223826606, 0.03114367435046006, 0.03657986526377499, 0.05064695164037403, 0.020117317289987113, 0.037378408742370084, 0.07350619474891573, 0.05321054864907637, 0.06953062838874757, 0.017658550495980307, 0.06756947346730158, 0.024438477703370154, 0.029291713472048286, 0.03869565036438871, 0.013464768599078525, 0.013286118810356129, 0.04752907050715294, 0.04892221899353899, 0.03684274881379679, 0.08023509188205935, 0.020530960719042923, 0.011272391075181076, 0.035289296429255046, 0.03338483416882809, 0.014212662354111671, 0.023891490745882038, 0.025137000084214378, 0.08976210840046406, 0.05212136158661451, 0.13074184069409966, 0.03613158580265008, 0.02147171639080625, 0.10766535240691155, 0.0510829337144969, 0.06963423962588422, 0.037657857028534636, 0.03522363862430211, 0.0529013810592005, 0.04253221246472094, 0.018642395261849742, 0.05242249542789068, 0.06397120756446384, 0.07897094721556641, 0.036891196214128286, 0.03205077548045665, 0.0062455864463117905, 0.06610566881136037, 0.09611835092073306, 0.10902459587669, 0.03332591506477911, 0.024339020637853537, 0.06673185591353104, 0.04607999748259317, 0.08783802375546657, 0.022141662375361193, 0.027350104865035973, 0.04080416612850968, 0.03410113655263558, 0.005040718970121816, 0.016097962361527607, 0.011191163011972094, 0.08203831035643816, 0.0791487806418445, 0.024673378575243987, 0.0121689722618612, 0.044416970704332925, 0.03448349474638235, 0.06312538185738958, 0.021843469294253737, 0.014582481035176897, 0.027915036953345407, 0.06878680345835164, 0.04228379708365537, 0.04746438120491803, 0.052099906097282656, 0.07548467139713466, 0.04976000353053678, 0.05019565905968193, 0.03879912430420518, 0.019861146465700585, 0.03002866797032766, 0.015037281191325746, 0.06765438258298673, 0.07181840250268579, 0.060436454659793526, 0.051038994861301035, 0.02297512946825009, 0.04083202264155261, 0.05208932307141367, 0.06599694417673163, 0.03228530156775378, 0.10851632861886173, 0.029527321239584126, 0.09468987249420024, 0.057862029716488905, 0.029574466170743108, 0.02948464774817694, 0.022642317053396255, 0.028253556483832654, 0.03565737199096475, 0.06839416280854493, 0.04509559796133544, 0.0476450718997512, 0.020603535340342205, 0.05234325260971673, 0.07325768659939058, 0.03400074623641558, 0.03483028551272582, 0.01656429270951776, 0.026988272620656062, 0.059013943100580946, 0.040325625595869496, 0.020077508488611784, 0.03404556824534666, 0.012230902630108176, 0.011559976082935464, 0.03156197846692521, 0.06014461621816736, 0.006944870456209173, 0.08506294063408859, 0.009081396729015978, 0.039032054773997515, 0.020900184754282236, 0.032669656138750724, 0.0635783294274006, 0.03067222874960862, 0.03306336919195019, 0.02957964450615691, 0.05532842660613824, 0.018434890771459322, 0.039472712378483266, 0.0740215866244398, 0.03459043080511037, 0.039952800289029256, 0.03527227156155277, 0.028601334306586068, 0.02602127831778489, 0.04458698560483754, 0.015789987774041947, 0.0278126780904131, 0.03445494432526175, 0.052635844331234694, 0.0500636272772681, 0.016335254804289434, 0.07747477007796988, 0.03700531997310463, 0.034716666414169595, 0.014882737286825432, 0.04784061668033246, 0.044127080400357954, 0.021167111153772566, 0.029410431125143077, 0.009779459905985277, 0.1399185709306039, 0.034749176193145104, 0.016229148095590062, 0.07951863735797815, 0.055580857006134465, 0.015154647207964445, 0.04373271425720304, 0.05074872977274936, 0.03192031705111731, 0.023121636841096915, 0.03856684321362991, 0.037780118436785415, 0.043392769803176634, 0.013123109783919062, 0.08106070148642175, 0.04103269937331788, 0.01738895236485405, 0.05441420456918422, 0.07814471420715563, 0.004908514638373163, 0.020155040656391066, 0.04601487402396742, 0.07072352687828243, 0.08248594414908439, 0.024415137158939615, 0.015049015473778127, 0.03207629422831815, 0.021480557225004304, 0.07415924017550424, 0.08914190300856717, 0.004705495503003476, 0.05477205333590973, 0.06239076697966084, 0.03299999349110294, 0.056025919257081114, 0.053816126310266554, 0.059565822666627355, 0.0256437941789045, 0.015628967703378294, 0.021071507690066937, 0.03635240442235954, 0.03083250852796482, 0.04389083253045101, 0.029974402132211253, 0.050434934892109595, 0.042532435109023936, 0.06574462138814852, 0.04799706512130797, 0.009101215782720828, 0.03479153056105133, 0.020975336483388674, 0.04480693591176532, 0.036836652070633136, 0.03035628906218335, 0.025983196865126956, 0.0610187066195067, 0.02389143508480629, 0.009923777943185996, 0.051127781698596664, 0.03606095560826361, 0.04624289147614036, 0.04902919587038923, 0.011357211133145029, 0.04476995469303802, 0.06402639366569929, 0.0228708855502191, 0.023771337037032936, 0.06977962635573931, 0.09540468687191606, 0.060464878915809095, 0.07771607939503156, 0.044644602239714004, 0.014288955135270953, 0.022385676820704248, 0.032641677171341144, 0.05749446994741447, 0.01604280223546084, 0.05148137053765822, 0.03236807700886857, 0.04365071807114873, 0.04542803188087419, 0.020299510833865497, 0.030206011579139158, 0.05314371454005595, 0.05906819409574382, 0.008510281622875482, 0.03587353363400325, 0.013261902531667147, 0.07050428161164746, 0.021357191872084513, 0.10418871708679944, 0.02930340971943224, 0.01994707046833355, 0.06623095818213187, 0.05404035509855021, 0.01084665156668052, 0.037246621868689544, 0.0412421297369292, 0.06116586708230898, 0.04831278587516863, 0.026242399362672586, 0.025174949805659708, 0.05964334370219149, 0.01651554473937722, 0.06302900656010024, 0.032396063397754915, 0.009475551360083045, 0.047469461205764674, 0.0417391683004098, 0.0836000859271735, 0.051972249275422655, 0.04940541650285013, 0.035014393797609955, 0.012338026081124553, 0.09342702658614144, 0.03455823643889744, 0.037402164889499545, 0.06294251666986383, 0.04183380697213579, 0.0608911388553679, 0.0016419813255197369, 0.06879487060359679, 0.039038630202412605, 0.03519592683005612, 0.014737834808329353, 0.06436516181565821, 0.05449825279356446, 0.060612837187363766, 0.031366596958832815, 0.013660731765412493, 0.019400840501475614, 0.08848613390000537, 0.05984356401313562, 0.04067819769261405, 0.027210239713895135, 0.05570686997089069, 0.018313044965907466, 0.04203920376312453, 0.057754993467824534, 0.08638827537652105, 0.04230345286487136, 0.06806041157688014, 0.03680224981508218, 0.01079700559785124, 0.059042493521701545, 0.05630580541037489, 0.03171594813466072, 0.017618890124140307, 0.029047314965282567, 0.02958150358608691, 0.0358798752859002, 0.002854829208445153, 0.024370508108404465, 0.020093542589165736, 0.08058177132625133, 0.010749830053100595, 0.03603162222134415, 0.04197508220386226, 0.024033728914218955, 0.034839721920434386, 0.026934110683214385, 0.0034910230124296504, 0.045192915786174126, 0.020896180867566727, 0.031580298382323235, 0.01714615133096231, 0.03246654516260605, 0.048513722358620726, 0.08709609130164608, 0.039542288723168895, 0.07803083906765096, 0.029155080374039244, 0.03576694638468325, 0.0718536322528962, 0.031884705094853416, 0.08624512993264943, 0.020416454754013103, 0.04131261150178034, 0.03216266537492629, 0.02890404521167511, 0.03346042190969456, 0.04059846505697351, 0.0705189019208774, 0.055175488523673266, 0.025245279430237133, 0.014456526514550205, 0.029269866499817, 0.0783898975350894, 0.10507755767321214, 0.1218365212844219, 0.10072341436170973, 0.14580059592844918, 0.1546590487123467, 0.2037041896255687, 0.21797211229568347, 0.10073547426145524, 0.06575476654688828, 0.12319002795265988, 0.11308601388009265, 0.19583184330258518, 0.11250414041569456, 0.06829124176874757, 0.09737600921653211, 0.12042157963151112, 0.1320780033711344, 0.17256169900065288, 0.1666186991496943, 0.18823818827513605, 0.12034539817250334, 0.14536986825987697, 0.12832183070713654, 0.1395151691394858, 0.14218823664123192, 0.09932475542882457, 0.07839073616196401, 0.16808596963528544, 0.12613786821020767, 0.09681835203082301, 0.17366855288855731, 0.07712279912084341, 0.10496764560230076, 0.18172144889831543, 0.14235844078939408, 0.1361500786151737, 0.12907347787404433, 0.20679110835772008, 0.13912629859987646, 0.1133047544863075, 0.28453840990550816, 0.15459538728464395, 0.09651227548602037, 0.15272424003342167, 0.15188037359621376, 0.17477034532930702, 0.17572103650309145, 0.11303185936412774, 0.09431551094166934, 0.11477518652100116, 0.13035292562562972, 0.11877878379891627, 0.15038969577290118, 0.1843417200143449, 0.10603031943901442, 0.15109573054360226, 0.2691631286870688, 0.16938309534452856, 0.19150164909660816, 0.2653090370586142, 0.10234496992779896, 0.15497208660235628, 0.1792938690050505, 0.22682783397613093, 0.11028203152818605, 0.19342900661285967, 0.11200820765225217, 0.16827187762828544, 0.11513325793202966, 0.13549283263273537, 0.08780489428318106, 0.1306981875677593, 0.205269111902453, 0.1124484273896087, 0.11892340611666441, 0.07349749677814543, 0.18729957926552743, 0.17789959616493434, 0.14431677554966882, 0.11440956746810116, 0.08229481885791756, 0.15825350739760324, 0.1870674206293188, 0.11215619189897552, 0.19725013204151765, 0.15246419148752466, 0.19795324275037274, 0.1738256507087499, 0.10949246061500162, 0.11257762045715936, 0.10307948090485297, 0.12026664888253435, 0.0990459305467084, 0.09966138619347475, 0.1655639143427834, 0.18291592074092478, 0.12791305576683953, 0.19134024681989104, 0.1546491781482473, 0.11772327168728225, 0.19120235578157008, 0.1811352709773928, 0.19248545489972457, 0.08855067848344333, 0.15647566295228899, 0.14694206358399242, 0.1296455698320642, 0.16373385238694027, 0.05837297983816825, 0.1974194307695143, 0.13818087667459622, 0.09263491752790287, 0.09107909398153424, 0.158952180063352, 0.14151026989566162, 0.17188422207254916, 0.2201218024129048, 0.10264885713695548, 0.08515354202245362, 0.1387205664650537, 0.1300661449204199, 0.133051983139012, 0.13273913820739836, 0.14036914362804964, 0.17189069360028952, 0.12836610723752528, 0.13891978858737275, 0.19109720829874277, 0.23071202711435035, 0.13457350461976603, 0.11575641707167961, 0.13335243420442566, 0.22364681091858074, 0.22353548876708373, 0.12051205485477112, 0.09910202206810936, 0.11282479274086654, 0.1258947851601988, 0.1496831711847335, 0.14795574825257063, 0.10727284534368664, 0.14699143124744296, 0.14041827380424365, 0.084978395170765, 0.1484261659788899, 0.10647872506524436, 0.2008934982586652, 0.12835739442380145, 0.14596789085771888, 0.08827577956253663, 0.09585416861227714, 0.10662357744877227, 0.119029243796831, 0.0847948323644232, 0.12095316516933963, 0.1768026573699899, 0.14362913119839504, 0.12297913926886395, 0.12256821952178143, 0.13335086085135117, 0.0793580366007518, 0.1849941717227921, 0.1384533042437397, 0.18383498158073053, 0.2735883177956566, 0.10179014032473788, 0.17385601939167827, 0.16256066533969715, 0.22761278873076662, 0.1730839186348021, 0.17159099952550605, 0.1686356932623312, 0.105758366844384, 0.1014060343732126, 0.09541856503346935], [0.025103763000515755, 0.018919904687209055, 0.007907524122856557, 0.05573840011493303, 0.034914211282739416, 0.032994167631841265, 0.08236911526182666, 0.02056940211332403, 0.04658892154111527, 0.06846660384326242, 0.04018675121187698, 0.04199560629785992, 0.05383611234719865, 0.008308452706842218, 0.04670760579756461, 0.06560518668266013, 0.050128016009693965, 0.042836886350414716, 0.07640457828529179, 0.007851740592741407, 0.023537864799436647, 0.041784962522797287, 0.037883985714870505, 0.039111249352572486, 0.03454859965131618, 0.008769219730311306, 0.0632526156550739, 0.015547400107607245, 0.05293239912134595, 0.024218959697464015, 0.02610141356854001, 0.06450139044318348, 0.027979358892480377, 0.015090969081938965, 0.0889298268884886, 0.05833787996380124, 0.03845064144115895, 0.035398314212216064, 0.026195918653684203, 0.08382120140595362, 0.018154750432586297, 0.03204681241186336, 0.03262574697146192, 0.014301938081189292, 0.05090557526273187, 0.10500430769752711, 0.00810050292784581, 0.019831894715025555, 0.03228414381737821, 0.013371177283261204, 0.016125410693348385, 0.017773499894246925, 0.05729465039621573, 0.021298439751262777, 0.03830430476227775, 0.00776846420194488, 0.024915663816500455, 0.03176576108671725, 0.02759074810455786, 0.010426706376165384, 0.04590474673022982, 0.015792097328812815, 0.0271656292170519, 0.06949320930289105, 0.02376070206082659, 0.041307858045911416, 0.021249209385132417, 0.014472720176854637, 0.04382782048196532, 0.015178559206106002, 0.10540284842136316, 0.08883681352017447, 0.012492855712480377, 0.022280048797256313, 0.11202555906493217, 0.03946078606531955, 0.0439698230184149, 0.004780948729603551, 0.0288812520011561, 0.057334889643243514, 0.029915475606685504, 0.08795972113148309, 0.069734192074975, 0.054503099017892964, 0.03290491695224773, 0.06708235741825774, 0.04528181394562125, 0.07036020848318003, 0.023387303444906138, 0.015104364847502438, 0.045353312452789396, 0.06159267250041012, 0.10322244081180543, 0.02740991269092774, 0.07276023243321106, 0.07155181563575752, 0.0733747603953816, 0.044482828889158554, 0.022696423329762183, 0.0714337250974495, 0.02351667091716081, 0.030902231446816586, 0.03467986702162307, 0.008424853003816679, 0.05301838435116224, 0.036331178998807445, 0.05604456571745686, 0.08485409285640344, 0.0480243687343318, 0.05207949703617487, 0.04572912861476652, 0.023986147971299943, 0.040827951961546205, 0.053846227820031345, 0.04778940849064384, 0.11365052851033397, 0.02696176125027705, 0.04947472196363378, 0.06337155966321006, 0.005382734016166069, 0.023713269547442906, 0.017798035296436865, 0.06783214921597391, 0.04978542208846193, 0.09648182516684756, 0.02462607779307291, 0.08205449659726582, 0.013779590426565846, 0.05140717803442385, 0.03564692997315433, 0.03685820032842457, 0.03819270059466362, 0.007728359469183488, 0.02042896179773379, 0.024080070470517967, 0.07129432749934494, 0.041597755771363154, 0.01963782309758244, 0.09038820644491352, 0.032611245405860245, 0.04612233329680748, 0.04673912852013018, 0.02924923479440622, 0.02160399864806095, 0.03398700908292085, 0.04728402076580096, 0.04525713011389598, 0.05515888668014668, 0.05692769176675938, 0.04195962697849609, 0.023307073570322245, 0.03600835960241966, 0.04511330931563862, 0.019898381870007142, 0.04155310816713609, 0.047952350723790005, 0.09751782621606253, 0.03199361526640132, 0.016361248526663985, 0.060260576792643405, 0.035390269331401214, 0.015917572236503474, 0.03604051315051038, 0.040992363647092134, 0.031303377108997665, 0.012445409283827757, 0.10206079416093417, 0.05861578458279837, 0.03091389615292428, 0.024598751915618777, 0.04682664257416036, 0.09269244139431976, 0.031726371598779224, 0.06325677910353988, 0.025455335053266026, 0.09017178876092657, 0.014687632228742586, 0.020700324384961277, 0.03610989653680008, 0.005653591479131137, 0.07330795968300663, 0.0469930209510494, 0.037615866312989965, 0.05035882393713109, 0.02272853049362311, 0.042130632646149024, 0.028710943952319212, 0.03727727627847344, 0.04709744855063036, 0.04640273153199814, 0.049001625084201805, 0.05190401250729337, 0.06086905996198766, 0.023163835357991047, 0.10004673153162003, 0.012914876133436337, 0.007832392802811228, 0.044856904714833945, 0.05604509264230728, 0.05196992264245637, 0.08050331147387624, 0.03808944929915015, 0.09416961212991737, 0.014562576634489233, 0.08415502685238607, 0.04481433512410149, 0.012503383077273611, 0.011186147021362558, 0.0042784836750797695, 0.0473049048014218, 0.07671304454561323, 0.058783658387255855, 0.10205208134721033, 0.044168462554807775, 0.03512949348078109, 0.014427819314732915, 0.04081471204699483, 0.05185304180486128, 0.002919696858043608, 0.041025392929441296, 0.06144118160591461, 0.02551787027186947, 0.0558547317632474, 0.03625601057137828, 0.07670188264455646, 0.024762280445429496, 0.026557771307125222, 0.03601732474635355, 0.04913376447802875, 0.052276333153713495, 0.031441613245988265, 0.05749817326432094, 0.009816186011448735, 0.0788673508213833, 0.06071004369005095, 0.06941766609088518, 0.04476520494790748, 0.013479192239174154, 0.029918427499069367, 0.04878860272583552, 0.04101763006474357, 0.06849093886557966, 0.030679700321343262, 0.017390499742759857, 0.032195594467339106, 0.04416231757204514, 0.015326961838582065, 0.03921960662410129, 0.08697665747604333, 0.008234535725932801, 0.03305301252112258, 0.04132766596740112, 0.0594204062508652, 0.05469573457958177, 0.09685592696769163, 0.05388282683270518, 0.04192247877654154, 0.03565139399142936, 0.11242708322242834, 0.04322221313486807, 0.04352592965005897, 0.0609350257582264, 0.04052462878462393, 0.03759211387659889, 0.0458229286596179, 0.044504840989247896, 0.026163501643168274, 0.05692493468814064, 0.14590031089028344, 0.046714036507182755, 0.05383737399824895, 0.02819144614477409, 0.03513780924549792, 0.05222541069088038, 0.08097171055851504, 0.04890695301583037, 0.05954200714768376, 0.029690230076084845, 0.03049519313208293, 0.08249798920587637, 0.07673525702557527, 0.044889369964948855, 0.04775709909154102, 0.048584779287921265, 0.04487174766836688, 0.01895197288831696, 0.13365557184442878, 0.04758336232043803, 0.07294249648111872, 0.030805590831732843, 0.04686337888415437, 0.030110946172499098, 0.04286669100110885, 0.05384158568631392, 0.043870516237802804, 0.029138972058717627, 0.055420746066374704, 0.006974653306315304, 0.05168282652448397, 0.047436632303288206, 0.02985943418025272, 0.0019092804222964332, 0.09517453945591114, 0.0403162856673589, 0.02300005820870865, 0.03488791327981744, 0.04532872138952371, 0.03265650157118216, 0.05499833416251931, 0.02548563508753432, 0.03644488344434649, 0.00938540917559294, 0.036084748862776905, 0.04274266328138765, 0.04758243463584222, 0.026481656641408335, 0.007794023767928593, 0.004417275495143258, 0.08234116598032415, 0.03209807997336611, 0.02949842015368631, 0.020618777198251337, 0.06283889058977365, 0.006170551141622127, 0.007492654758607387, 0.03744678651855793, 0.04006151379144285, 0.06395423464709893, 0.04731558801722713, 0.05452252473332919, 0.0746926068677567, 0.010516117545193993, 0.03286548293544911, 0.03332652362587396, 0.024402028975600842, 0.07905647973529994, 0.05600968848739285, 0.07489237075787969, 0.02422891375317704, 0.057327464455738664, 0.039568557040183805, 0.01565004284202587, 0.12574562832014635, 0.026162594367633574, 0.03907761521986686, 0.09758884232724085, 0.042765287653310224, 0.04913798729830887, 0.02917264700954547, 0.028734445913869422, 0.0654552951164078, 0.07117975474102423, 0.0810874039598275, 0.1476492709480226, 0.08380090366699733, 0.1656158349942416, 0.20884960336843506, 0.13859373342711478, 0.1989177823998034, 0.20054957218235359, 0.11259944702032954, 0.17127965373219922, 0.09667447186075151, 0.15529017109656706, 0.14471136062638834, 0.15965368773322552, 0.16210823727305979, 0.15557613543933257, 0.11263173786574043, 0.09156612839433365, 0.205893762758933, 0.10872267535887659, 0.09930161526426673, 0.16256963048363104, 0.1936135342111811, 0.08727805849048309, 0.11699560331180692, 0.10149967114557512, 0.15524898190051317, 0.08366846741409972, 0.14202533522620797, 0.15245982765918598, 0.10742995800683275, 0.13141467177774757, 0.13269077986478806, 0.13467330863932148, 0.29063360940199345, 0.16386711242375895, 0.12307952216360718, 0.13236329978099093, 0.13112686690874398, 0.141231014567893, 0.0952951681392733, 0.09490886543062516, 0.09720472153276205, 0.10804010729771107, 0.1351835796958767, 0.16796596435597166, 0.09656794398324564, 0.0946183071937412, 0.17466056684497744, 0.1253952010301873, 0.12168541259597987, 0.1535967385279946, 0.2805708290543407, 0.20296284346841276, 0.13888236950151622, 0.15608728223014623, 0.15262535627698526, 0.1332850768812932, 0.18357779772486538, 0.1659498459775932, 0.12787155486876145, 0.08596451647463255, 0.17941823811270297, 0.20581551070790738, 0.11311771100736223, 0.130206574103795, 0.07401020950055681, 0.051157230118406005, 0.13819441344821826, 0.11187966767465696, 0.1579645596211776, 0.1654913619859144, 0.17148338811239228, 0.132595888862852, 0.16715828503947705, 0.1141775943688117, 0.13974041095934808, 0.1805648414301686, 0.1898219611030072, 0.11982268872088753, 0.11971569329034537, 0.10219130825134926, 0.14326921926112846, 0.1872469313093461, 0.13159965950762853, 0.1014113704150077, 0.1836571778403595, 0.14006588724441826, 0.08760334923863411, 0.07099024733179249, 0.16941111884079874, 0.22058229020331055, 0.2283936765161343, 0.2138818841194734, 0.15008209040388465, 0.13788915326585993, 0.19922540261177346, 0.11851512841531076, 0.1702913802000694, 0.11245990099268965, 0.2389053671504371, 0.1621830160729587, 0.18756175035377964, 0.13447007891954854, 0.14828894287347794, 0.09595179813914001, 0.1515803232905455, 0.14493707742076367, 0.17530298471683636, 0.23691840033279732, 0.23087543318979442, 0.09444215102121234, 0.12233784946147352, 0.08649958268506452, 0.1876339761656709, 0.17295238038059324, 0.10439841833431274, 0.17572526674484834, 0.15516595041844994, 0.09476687031565234, 0.13083788944641128, 0.10601112007861957, 0.17733321874402463, 0.11909269000170752, 0.1299933550762944, 0.13360057870158926, 0.2069683332229033, 0.07630406922544353, 0.12765553052304313, 0.1270987861789763, 0.1359254601993598, 0.1393860948155634, 0.10178484139032662, 0.1428942268830724, 0.1488494424847886, 0.12627249379875138, 0.14504400605801493, 0.13145603908924386, 0.1783508516382426, 0.08867728887707926, 0.158153347147163, 0.09182736437651329, 0.26306884945370257, 0.13783882081042975, 0.10808777544298209, 0.15139399969484657, 0.17503266484709457, 0.13429696555249393, 0.11684761906508356, 0.12429688184056431, 0.08972782117780298, 0.1539746846538037, 0.18246748542878777, 0.21550157689489424, 0.1392421923810616, 0.10155684620258398, 0.12113685414078645, 0.12236845563165843, 0.06604915426578373, 0.18029137485427782, 0.14490740635665134, 0.15793279570061713, 0.171108974609524, 0.1027724173036404, 0.12636616767849773, 0.05360283306799829, 0.23260162415681407, 0.13627339387312531, 0.16953266778727993, 0.20369804464280605, 0.17733854736434296, 0.25812712556216866, 0.07564738727523945, 0.14130895491689444, 0.1669084039167501, 0.14966016460675746], [0.01460840147046838, 0.023570383855258115, 0.09456710642552935, 0.02995579648995772, 0.05826477841765154, 0.05491092029842548, 0.014128545481071342, 0.015160582534008427, 0.07257320379721932, 0.05026470105804037, 0.04210036786389537, 0.058757620136020705, 0.06324943926301785, 0.042214061177219264, 0.02751418072875822, 0.04598053485096898, 0.025063646207854617, 0.02375618238147581, 0.024504510292899795, 0.01887677291961154, 0.019241952250013128, 0.027269097590760794, 0.04288889605959412, 0.04043757486215327, 0.0845309543365147, 0.033437281745136715, 0.04672427072364371, 0.051425279016257264, 0.040251214159070514, 0.0229062080688891, 0.017674656955932733, 0.01954320297954837, 0.007145246154323104, 0.05106811673613265, 0.02029471655987436, 0.036260315027902834, 0.009155167135759257, 0.010034503593487898, 0.03783092586672865, 0.018085365190927405, 0.0542279255023459, 0.011133071402582573, 0.021976311873004306, 0.01575644826516509, 0.06228087717317976, 0.008385219534829957, 0.07363699085544795, 0.025545162752678152, 0.05514765427506063, 0.0379492093634326, 0.05539385434531141, 0.017473371663072612, 0.0457375445694197, 0.030128835642244667, 0.00657656946714269, 0.04220044647809118, 0.011091833039245103, 0.02955342257337179, 0.08031740348087624, 0.03393660983419977, 0.026366312049503904, 0.03372791790752672, 0.038370879119611345, 0.020738891944347415, 0.0575249388202792, 0.03994366074039135, 0.04838523433136288, 0.018989644304383546, 0.04724978549347725, 0.08488383071380667, 0.019350999718881212, 0.035616687455330975, 0.017368587832606863, 0.07330853855819441, 0.0935970526188612, 0.06286987525527366, 0.20495502016274258, 0.14860514231259003, 1.5922140749171376, 0.9326702845282853, 2.564401407726109, 3.994975481182337, 3.844422809779644, 2.651722622103989, 2.0346761075779796, 1.2482112902216613, 0.19461503281490877, 0.20962103619240224, 0.12061038942192681, 0.0554549850494368, 0.023270268611668143, 0.026735270766948815, 0.04992483081878163, 0.03750656280317344, 0.043767361421487294, 0.17850177478976548, 0.048337454863940366, 0.004650070059142308, 0.014324119947559666, 0.1350190900848247, 0.05038165611040313, 0.10176530806347728, 0.014327475382742705, 0.08743038430111483, 0.019352049857843667, 0.06864373222924769, 0.01756656500219833, 0.01037016028931248, 0.05786469402664807, 0.04475810259464197, 0.02985629118484212, 0.045150271980674006, 0.02485949622496264, 0.04137280338909477, 0.034126458631362766, 0.03468656119366642, 0.049936438008444384, 0.030524905014317483, 0.040301535482285544, 0.08840653114020824, 0.011040584031434264, 0.023182869590527844, 0.012580777020048117, 0.036700286145787686, 0.02171799809730146, 0.04525618387560826, 0.03029552386578871, 0.06509779515909031, 0.04264939016138669, 0.09392341205966659, 0.022550454013980925, 0.04245977885148022, 0.08304197603138164, 0.06098936210037209, 0.05234862204815727, 0.0034250866701768246, 0.095058645674726, 0.05832504823047202, 0.057110757334157825, 0.053203895295155235, 0.05361750161682721, 0.025957594625651836, 0.024102731949824374, 0.07258950878167525, 0.012613104972842848, 0.051238591768196784, 0.020616376350517385, 0.051749126287177205, 0.08932223747251555, 0.04565582668874413, 0.018098278560501058, 0.029730140922765713, 0.05247593377134763, 0.06871341989608482, 0.009672257601778256, 0.0163768707352574, 0.04531130689429119, 0.043532349227461964, 0.05234458476479631, 0.043177279803785495, 0.03360941547725815, 0.04313154124247376, 0.06573192324140109, 0.03989401848230045, 0.049135912995552644, 0.0396915234887274, 0.06096643344790209, 0.044368853559717536, 0.01335530088908854, 0.08657943035359494, 0.0603711716394173, 0.0816575218050275, 0.03327573103888426, 0.0751000310992822, 0.08862933871569112, 0.0678398749732878, 0.04215296015900094, 0.05612516666587908, 0.026090754472534172, 0.05226978370046709, 0.05921490184846334, 0.02050340477580903, 0.046363924629986286, 0.04101533311768435, 0.05212069365370553, 0.028228551673237234, 0.015198586061160313, 0.04801728864549659, 0.057650829330668785, 0.027020890011044685, 0.0211370486067608, 0.04870079552347306, 0.027635035767161753, 0.0421438502962701, 0.01703663816442713, 0.04933781427098438, 0.03258151496993378, 0.03388127159269061, 0.05775669669674244, 0.017251194913114887, 0.010124807195097674, 0.05276536765450146, 0.031209599328576587, 0.030939249772927724, 0.05234925287368242, 0.0645824997627642, 0.0339107311447151, 0.03177923477778677, 0.09188909622025676, 0.03441457149165217, 0.0514748025307199, 0.08620893539045937, 0.009202997625834541, 0.04390792419144418, 0.12011427854304202, 0.06675576791167259, 0.06805265613365918, 0.02119119199051056, 0.027037933432438876, 0.034299546023248695, 0.04825893192901276, 0.01954213614226319, 0.05437594685645308, 0.04531519203737844, 0.04960649399436079, 0.05420699693786446, 0.13555487617850304, 0.07349688821705058, 0.017680204509815667, 0.03592249682697002, 0.08580334426369518, 0.00834372605822864, 0.017568017756275367, 0.039838754455558956, 0.06718376447679475, 0.0119902788719628, 0.03779764796490781, 0.062465723895002156, 0.03228555389796384, 0.039980812653084286, 0.004755954123538686, 0.030902101570973173, 0.020807399596378673, 0.07577838376164436, 0.06030414086126257, 0.030591119430027902, 0.023252611063071527, 0.015183186496869894, 0.026757627965707798, 0.23938038619235158, 0.04568030642985832, 0.048531392894801684, 0.3643137338804081, 0.5054591491352767, 2.5198103254660964, 1.5792289841920137, 3.0579336499795318, 5.566796287894249, 5.081577999517322, 4.203813225030899, 2.951308283954859, 1.8623381364159286, 0.49699958588462323, 0.2980336232576519, 0.04337997146649286, 0.04231893406540621, 0.03397510874492582, 0.04497511399677023, 0.041156478473567404, 0.02271229230245808, 0.07747848823782988, 0.09413343985215761, 0.0274830012494931, 0.017625936816330068, 0.062167569776647724, 0.2048816959722899, 0.046373965888051316, 0.18127400806406513, 0.0793284694373142, 0.018408039868518244, 0.04255768668372184, 0.040778421025606804, 0.056520571815781295, 0.028908754138683435, 0.03300836120615713, 0.0075420813300297596, 0.021684516104869545, 0.042667480011004955, 0.044185505976201966, 0.01390375637129182, 0.017889052287500817, 0.04783870193932671, 0.03367592675203923, 0.047099107250687666, 0.042805200355360284, 0.03928161306248512, 0.0210115161826252, 0.03332325075461995, 0.03350388949911576, 0.01831410623708507, 0.013644218979607103, 0.005824524787385599, 0.03432819292356726, 0.08391845985897817, 0.036057230026926845, 0.036569898220477626, 0.013725298613280756, 0.0733720812422689, 0.032433200467494316, 0.008875568564690184, 0.062169488228391856, 0.07424340714351274, 0.02152641081920592, 0.0315709881397197, 0.02126587616658071, 0.025029859934875276, 0.06968620480620302, 0.02326640758838039, 0.08552889063139446, 0.08605574126704596, 0.04478541362914257, 0.03330925013870001, 0.03887820384989027, 0.011186999563506106, 0.10828219586983323, 0.02915305802162038, 0.06675555268884636, 0.03881762604578398, 0.0321946667827433, 0.0032556026371821645, 0.03764705135836266, 0.019158998693455942, 0.04334536140959244, 0.05124977593368385, 0.04796058114152402, 0.03196801117155701, 0.054074434519861825, 0.015422563446918502, 0.03295921618700959, 0.00357611812887626, 0.06757285023923032, 0.06087905669119209, 0.027927282390010078, 0.03891897744324524, 0.03264287573983893, 0.013098395338602131, 0.05824720436066855, 0.0437002786929952, 0.012740663460135693, 0.029610703386424575, 0.02659729252627585, 0.011814727549790405, 0.14860027382383123, 0.15515213162871078, 0.14252454828238115, 0.1434669125592336, 0.14751252281712368, 0.13339705212274566, 0.09876404059468769, 0.08671272007632069, 0.20397416810737923, 0.19209563441108912, 0.1514677394879982, 0.23426731524523348, 0.1811954888398759, 0.1675012760097161, 0.05337280068488326, 0.12263122785952874, 0.1410189681337215, 0.13618574623251334, 0.12239875009981915, 0.18159541737986729, 0.10174814218771644, 0.10556872584857047, 0.14701215201057494, 0.12329081902862526, 0.1374210065114312, 0.09237065358320251, 0.13137262169038877, 0.1592056086519733, 0.16064012073911726, 0.22934576292755082, 0.09341924145701341, 0.12141889994381927, 0.14473502029431984, 0.12880676484201103, 0.11451179088908248, 0.13629516848595813, 0.0714396993862465, 0.08655414538225159, 0.23598595114890486, 0.1088240156241227, 0.15102731937076896, 0.0955617921135854, 0.12298029701923952, 0.15407273720484227, 0.14294078922830522, 0.08502729528117925, 0.13324710860615596, 0.1428633090108633, 0.10557156085269526, 0.16513749113073573, 0.12451446469640359, 0.09774375823326409, 0.09236310594133101, 0.13085599784972146, 0.1251993779442273, 0.1397207292029634, 0.08828634774545208, 0.08849660560372286, 0.2241987906745635, 0.133706379274372, 0.14567204110790044, 0.13209361815825105, 0.1074356131721288, 0.119102367607411, 0.0724798341980204, 0.10736734300735407, 0.13396773400017992, 0.1460735430009663, 0.13457874418236315, 0.17735575034748763, 0.16508545173564926, 0.2079390178550966, 0.1659157665562816, 0.3078654472483322, 0.28727533179335296, 0.1237802134710364, 0.4934437188785523, 0.7888295967131853, 2.4700075853616, 1.9924527732655406, 4.375697001814842, 6.888376297429204, 7.047276170924306, 4.8858823254704475, 3.6147429468110204, 2.347312169149518, 0.6279088254086673, 0.3784680337412283, 0.2899571863235906, 0.14488727931166068, 0.17322222527582198, 0.08977558580227196, 0.15811479999683797, 0.12044862349284813, 0.24815090931952, 0.23505851888330653, 0.20407968666404486, 0.13433957967208698, 0.18439558509271592, 0.36038815858773887, 0.09942335716914386, 0.34036753757391125, 0.19636620447272435, 0.24040915130171925, 0.17836291895946488, 0.17877163452794775, 0.07119418209185824, 0.09804092900594696, 0.19268771982751787, 0.12277692629140802, 0.22833164781332016, 0.14575112436432391, 0.11540333289303817, 0.10032880702055991, 0.14057191321626306, 0.12365685368422419, 0.15696346177719533, 0.189536813122686, 0.15585101209580898, 0.1374651791411452, 0.11459349392680451, 0.1315144609543495, 0.09201931345160119, 0.08216261267079972, 0.1406448960187845, 0.09235408142558299, 0.1525213071727194, 0.22968695790041238, 0.17833056132076308, 0.18768318055663258, 0.16408831696026027, 0.14228069339878857, 0.1173286495031789, 0.15342794446041808, 0.2053544291993603, 0.1292764997924678, 0.27735177834983915, 0.12490573979448527, 0.1482905904413201, 0.19650609930977225, 0.1579312965623103, 0.08429390494711697, 0.21477358939591795, 0.18135359598090872, 0.14176261494867504, 0.12240729964105412, 0.1749883289448917, 0.12405399174895138, 0.2592289773747325, 0.13962604600237682, 0.13107841950841248, 0.12649332726141438, 0.07168934302171692, 0.17186419892823324, 0.10190202650846913, 0.10900545588810928, 0.1362972316564992, 0.10929789918009192, 0.09355503963888623, 0.13160718488506973, 0.1602263585664332, 0.12402654712786898, 0.12728050845908, 0.17457612528232858, 0.1027200513635762, 0.18996994534973055, 0.06720421064528637, 0.13732084626099095, 0.12237624818226323, 0.15625097032170743, 0.24003481201361865, 0.1910499928635545, 0.11027439482859336, 0.18879744107834995, 0.15372274036053568, 0.15822962508536875], [0.021266963412926998, 0.04569159078528173, 0.002746526670307503, 0.00544568576515303, 0.014349776920425938, 0.050770738162100315, 0.016599071605014615, 0.015998835551727097, 0.03264179591496941, 0.037201406521489844, 0.055253098616958596, 0.04676389398809988, 0.14885362819768488, 0.04704263723397162, 0.008488049661536934, 0.01390142138916417, 0.02780978371447418, 0.020569222142512444, 0.03813658309809398, 0.03571817243937403, 0.03423811103857588, 0.07789055089233443, 0.029265452576510143, 0.02206822500738781, 0.0035513519651431125, 0.0229734670574544, 0.0426069170498522, 0.0542124331695959, 0.028967715916223824, 0.03954939478717279, 0.04785599769093096, 0.08390305287321098, 0.05801251871162094, 0.020290107822802383, 0.013016118991799885, 0.0372221977886511, 0.05765271438576747, 0.019075354939559475, 0.04936420504236594, 0.023227990313898772, 0.01615124670934165, 0.038076079508755356, 0.0832516179070808, 0.030853524294798262, 0.029134118412912358, 0.04519874906691257, 0.06666972331004217, 0.01873949971923139, 0.05382428993470967, 0.05450836084492039, 0.08648344097309746, 0.05765305206296034, 0.011771337885875255, 0.030529222458426375, 0.05673391329764854, 0.07828435671399347, 0.04346981215348933, 0.03613731518271379, 0.03645894343208056, 0.007431889098370448, 0.04363966378150508, 0.06203572353115305, 0.05140307024703361, 0.014720130875502946, 0.034659906959859654, 0.05652752202877309, 0.03992947458755225, 0.05852417758433148, 0.09898126721964218, 0.055242667731363326, 0.015800633882463444, 0.17022804531734437, 0.09128342207986861, 0.7506882527377456, 0.995839104289189, 2.388234310783446, 5.759847778826952, 16.335367150604725, 24.728898257017136, 21.725324727594852, 20.272335894405842, 23.096198067069054, 24.364076033234596, 25.022126622498035, 22.655334323644638, 19.119206070899963, 13.885701298713684, 7.429655352607369, 1.955633342731744, 0.7449360738974065, 0.6621419603470713, 0.4548202164005488, 0.39379442227073014, 0.5667962890584022, 0.48628202348481864, 1.8800521921366453, 1.9025934138335288, 3.1706652883440256, 4.091557748615742, 4.069156050682068, 6.267923740670085, 5.816034413874149, 3.504575458355248, 0.9202308801468462, 0.19718694558832794, 0.0665917681180872, 0.10642993627698161, 0.053628017849405296, 0.025794765570026357, 0.04695643307059072, 0.060071388506912626, 0.030570302187697962, 0.04610248455719557, 0.053616700097336434, 0.016028937061491888, 0.06940673425560817, 0.04764053737744689, 0.07329129104618914, 0.06072499796573538, 0.02880512434785487, 0.019409527340030763, 0.09977072681067511, 0.03438076666498091, 0.074987603147747, 0.04273759441275615, 0.06801686977269128, 0.05767777671280783, 0.021734368019679096, 0.01290600283027743, 0.048048540484160185, 0.0868650087795686, 0.07916235452285036, 0.012146289445809089, 0.021889107665629126, 0.027262891380814835, 0.08390048504224978, 0.03467191862000618, 0.09104233540710993, 0.016425928552052937, 0.02304572997672949, 0.04985194820619654, 0.019371419912204146, 0.02399423738097539, 0.04713897913461551, 0.03914051965693943, 0.027297217566228937, 0.021305222981027327, 0.025119040110439528, 0.024015941489778925, 0.031840328374528326, 0.03401832771487534, 0.07619643554789945, 0.030437040295510087, 0.04072268944582902, 0.06299674540059641, 0.037471466639544815, 0.05479839957843069, 0.07540957347373478, 0.009253135267499601, 0.0029398957985904417, 0.09829417205764912, 0.0007936658289509069, 0.04881032909906935, 0.011345998209435493, 0.04576203544274904, 0.06379361162544228, 0.019983567435701843, 0.05899243937165011, 0.004074133312315098, 0.05374362961447332, 0.038783513227826916, 0.02825831365043996, 0.04345046807429753, 0.025431462017877493, 0.045344670143094845, 0.03194829601852689, 0.05126682677655481, 0.04530796722974628, 0.08521393057890236, 0.047906701220199466, 0.035404926748014987, 0.025411591013835277, 0.03246342814236414, 0.07775516831316054, 0.02821179397869855, 0.06290882316534407, 0.05660692069795914, 0.05866487765160855, 0.020430113982001785, 0.0707938898995053, 0.060824252796010114, 0.056756648991722614, 0.03949289137381129, 0.021520108130062, 0.05626063830277417, 0.04647687208489515, 0.024322606186615303, 0.03970965415646788, 0.03953381339670159, 0.06432132315239869, 0.06951250514248386, 0.045580773294204846, 0.04100486512470525, 0.044803061900893226, 0.04600046893756371, 0.07864009035984054, 0.10694048192817718, 0.008028402353374986, 0.05860554665559903, 0.06636961363255978, 0.06336762628052384, 0.056627389130881056, 0.05800775783427525, 0.04841510577534791, 0.06854880411992781, 0.026252544521412347, 0.026307120206183754, 0.049358245596522465, 0.06727064770529978, 0.03161425906000659, 0.0453855142404791, 0.06254241001443006, 0.025841298229352105, 0.04248651472153142, 0.060461598623078316, 0.025308879630756564, 0.039601411917828955, 0.0352791698242072, 0.0273302691130084, 0.020146697061136365, 0.018957761640194803, 0.03998840482381638, 0.021894683050049935, 0.023927178772282787, 0.043102604904561304, 0.03964253803133033, 0.04894824611255899, 0.00856903559906641, 0.009129594582191203, 0.04548329961835407, 0.04930887051159516, 0.02099584944517119, 0.022680316869809758, 0.0642826349940151, 0.03500259364955127, 0.03310483298264444, 0.08540734910639003, 0.33278952701948583, 0.4245562356663868, 1.1852943850681186, 2.138785058632493, 3.909650109708309, 8.6606814712286, 22.703044563531876, 32.43386261165142, 30.669070109725, 29.129993095993996, 29.80962462723255, 32.2375575453043, 33.19948732852936, 29.43362720310688, 25.70720326155424, 18.4992503374815, 10.817660428583622, 3.5258260555565357, 1.5549913910217583, 1.0586942033842206, 0.952538646524772, 0.685125858290121, 0.717970464611426, 0.7451199484057724, 2.3813797160983086, 2.3691170616075397, 3.862699829041958, 5.10234578512609, 5.208628457039595, 8.23099197819829, 7.360854819417, 4.3807493057101965, 1.405433553736657, 0.3871091263135895, 0.06312992380117066, 0.02487999063305324, 0.011851249564642785, 0.011604127375903772, 0.032630288915243, 0.027483066187414806, 0.03403222814085893, 0.01287341141505749, 0.07066416248562746, 0.014059548939258093, 0.11569777998374775, 0.03838457174424548, 0.07497826692997478, 0.04562751746561844, 0.01633691350434674, 0.04402820406539831, 0.021175844376557507, 0.04827470998861827, 0.08137779892422259, 0.04898228471574839, 0.028325247949396726, 0.04258724642568268, 0.07880975274019875, 0.06611385470023379, 0.020520585494523402, 0.027656430029310286, 0.019716346032510046, 0.015312109608203173, 0.017831478326115757, 0.02393829243374057, 0.05828357330756262, 0.022518174300785176, 0.05396317545091733, 0.014006960354890907, 0.01715943762974348, 0.0853773440758232, 0.04112790207727812, 0.0414311139320489, 0.04212130756059196, 0.024230121598520782, 0.02526407432014821, 0.009799124964047223, 0.01677838561590761, 0.04575659550027922, 0.03254050388932228, 0.02575068014266435, 0.025294593287981115, 0.058502915053395554, 0.046528622042387724, 0.021485733705048915, 0.03840763769403566, 0.018803383791237138, 0.031033663944981527, 0.0410618880414404, 0.05094745836686343, 0.04110890680749435, 0.03172341785102617, 0.05134777653438505, 0.06083250918891281, 0.04015538434032351, 0.095810730708763, 0.010082803491968662, 0.018778417943394743, 0.018492711496946868, 0.0027863466038979823, 0.011529712228366407, 0.03320577619888354, 0.05605623598967213, 0.023713555274298415, 0.068494360166369, 0.03574442591343541, 0.14476442418526858, 0.1362682433682494, 0.2539975487161428, 0.11256913028773852, 0.11822769462014548, 0.16117109771585092, 0.16785767016699538, 0.15064530627569184, 0.12277251793420874, 0.2776123018702492, 0.10342456473154016, 0.1306844429927878, 0.19623506697826087, 0.19249875418609008, 0.1323540080920793, 0.1392600781400688, 0.1050555455731228, 0.11656443035462871, 0.08418371828156523, 0.2771010808646679, 0.22798457503085956, 0.15369409346021712, 0.06832265687990002, 0.1380925759440288, 0.16791123838629574, 0.10570432365057059, 0.2097738889278844, 0.20545188803225756, 0.18443285574903712, 0.29859554779250175, 0.16951599915046245, 0.16068000375526026, 0.1329660275951028, 0.156190381385386, 0.12956727325217798, 0.11382026510545984, 0.1501069968799129, 0.12409702147124335, 0.15447781624970958, 0.12202077428810298, 0.10123910309630446, 0.1862991790403612, 0.14102555840509012, 0.13469426688970998, 0.11150568461744115, 0.16581971780396998, 0.11178717380971648, 0.062116573099046946, 0.205475295369979, 0.16485361964441836, 0.08765889157075435, 0.15433277090778574, 0.10600559107842855, 0.11008658693754114, 0.12838964816182852, 0.1130655973975081, 0.14085425587836653, 0.0887305973446928, 0.11457033891929314, 0.09684956676210277, 0.14169743953971192, 0.10814669454703107, 0.13511046330677345, 0.1730217266594991, 0.12128089758334681, 0.16970858647255227, 0.146127259649802, 0.2330004097893834, 0.19176695204805583, 0.2079381124349311, 0.14368399075465277, 0.34073493035975844, 0.5669921566732228, 1.198517675511539, 2.951128031127155, 5.776846641674638, 11.047384701669216, 27.039052695035934, 34.95348080992699, 36.61297716200352, 33.59597325325012, 34.84071806073189, 36.684561520814896, 38.977780267596245, 35.33617727458477, 29.65260375291109, 22.863958328962326, 13.176119774580002, 4.55738615244627, 2.0954564586281776, 1.1670501390472054, 1.1993130203336477, 1.1434224131517112, 1.2071414315141737, 1.2002076348289847, 3.5449064942076802, 2.9501973185688257, 5.263888416811824, 7.156447637826204, 7.133262706920505, 9.93162302300334, 8.730782009661198, 5.804075980558991, 1.8845865363255143, 0.6481096101924777, 0.2272800839273259, 0.1885365613270551, 0.11207741292309947, 0.17145083751529455, 0.15788489748956636, 0.16049716825364158, 0.08982252664281987, 0.1175216598494444, 0.1467170740943402, 0.1665364543441683, 0.293954957742244, 0.1300761490711011, 0.18536610645242035, 0.1680142039549537, 0.1365875152987428, 0.1421960737206973, 0.1815994843491353, 0.10799117007991299, 0.14462930877925828, 0.15322842547902837, 0.12809929030481726, 0.1372259997879155, 0.16477947909152135, 0.1517353134113364, 0.09157418069662526, 0.19343338528415188, 0.1310967653989792, 0.13683910336112604, 0.14764545630896464, 0.11405808632844128, 0.1506934716599062, 0.15092240937519819, 0.16373640537494794, 0.07082057752995752, 0.2106910350266844, 0.23713249509455636, 0.07799247003276832, 0.1391261798562482, 0.13682406744919717, 0.054920197144383565, 0.12111009229556657, 0.09228495036950335, 0.09565800413838588, 0.10612286525429226, 0.19408320978982374, 0.11564746979274787, 0.20082824863493443, 0.160325420438312, 0.07889845423051156, 0.15879356826189905, 0.10304788767825812, 0.09538189551676624, 0.1201561134075746, 0.06294543331023306, 0.10554058360867202, 0.15569934679660946, 0.14473686082055792, 0.2085738509777002, 0.18687437317566946, 0.19078319077380002, 0.16725748049793765, 0.09254077609512024, 0.12367257237201557, 0.16289204912027344, 0.14789919659961015, 0.11636566094239242, 0.16890616156160831, 0.20712851837743074, 0.18224408413516358, 0.09726692092954181, 0.10734933850471862], [0.04522888397332281, 0.07642269411007874, 0.051898676465498284, 0.051463540439726785, 0.05319707495800685, 0.04858122440055013, 0.03694555853144266, 0.04351271199993789, 0.017478275403846055, 0.061206855898490176, 0.008187784133042442, 0.03564663682482205, 0.01832894547987962, 0.06615024220081978, 0.0368820306903217, 0.016606530189164914, 0.08635573220090009, 0.06922191721969284, 0.0015961488361426746, 0.025066676025744528, 0.008451249341305811, 0.042199144008918665, 0.042558918648865074, 0.03805500622547697, 0.07029950080323033, 0.022323911580315325, 0.0211649570701411, 0.01061955623299582, 0.07015692681306973, 0.0339758879999863, 0.05420830682851374, 0.030720420108991675, 0.06855180239654146, 0.09599579265341163, 0.012328599877946544, 0.026818918231583666, 0.059820791211677715, 0.027040493841923308, 0.057096630553132854, 0.049932389592868276, 0.043757193998317234, 0.06831761769717559, 0.07001249745371751, 0.032751526159700006, 0.10668750604963861, 0.020736875158036128, 0.049102438424597494, 0.022551613619725686, 0.055757432492100634, 0.031943230860633776, 0.031930525292409584, 0.028007348992105108, 0.0327530995127745, 0.047682234944659285, 0.06770029925974086, 0.01463855400288594, 0.02204075070039835, 0.04792300249391701, 0.02209627076808829, 0.1024236821103841, 0.06379155587637797, 0.007317892896026024, 0.03566910163499415, 0.03491293849947397, 0.06817171888542362, 0.028711908744298853, 0.025885721333906986, 0.02918172347563086, 0.03571560460841283, 0.27935620048083365, 1.3509323657490313, 2.6939929788932204, 8.03763460367918, 9.926261510699987, 19.145912937819958, 33.17243658006191, 41.834542974829674, 56.00267171859741, 57.46592000126839, 59.800085350871086, 62.38876864314079, 62.19732731580734, 69.88126739859581, 59.74561907351017, 53.93389172852039, 60.05030572414398, 48.983764350414276, 37.3213579505682, 25.054941661655903, 20.28380937874317, 18.61262485384941, 14.326296206563711, 15.21778916940093, 16.78892221301794, 17.046772576868534, 15.291395019739866, 20.778634026646614, 20.863109193742275, 24.828371219336987, 27.14909289032221, 30.123324394226074, 32.653494626283646, 23.23413636535406, 15.227646790444851, 8.081252463161945, 2.215396072715521, 0.19028114271350205, 0.035303638433106244, 0.04515427215665113, 0.08141498052282259, 0.06829301550169475, 0.02517817814805312, 0.06046482696547173, 0.006947216106709675, 0.06332390636089258, 0.019753904271055944, 0.09221808286383748, 0.0772533577401191, 0.021225909658824094, 0.008825959703244735, 0.011873595631186618, 0.019039963772229385, 0.046329507531481795, 0.050499197459430434, 0.05100129375932738, 0.008160452689480735, 0.07749949101707898, 0.013165761010895949, 0.0595566274569137, 0.044130293899797834, 0.022065054181439336, 0.040190944346250035, 0.02667549819307169, 0.04906117872451432, 0.04034557823615614, 0.027688696754921693, 0.025171001580019947, 0.027118144753330853, 0.017764351068763062, 0.04011574623291381, 0.00896435169124743, 0.03221649334591348, 0.0605366965464782, 0.05918875598581508, 0.018515959272917826, 0.042179313822998665, 0.03928139041818213, 0.017797137297748122, 0.029732382208749186, 0.032064275146694854, 0.09377797337947413, 0.03150487391394563, 0.022656775945506524, 0.03841839141387027, 0.05421953181212302, 0.046935244754422456, 0.06477450820966624, 0.05927499725657981, 0.05010902073991019, 0.04220731876557693, 0.043935962530667894, 0.014342013128043618, 0.12132631702115759, 0.041058028873521835, 0.07293437738553621, 0.038143659476190805, 0.06265860065468587, 0.07379348011454567, 0.07554939409601502, 0.056547641652286984, 0.04465427984541748, 0.030846674271742813, 0.049599488120293245, 0.04750085776322521, 0.014888274636177812, 0.04982016202120576, 0.0011870555840687302, 0.04957924975315109, 0.04248765020747669, 0.040762323842500336, 0.03230434507713653, 0.05989679826598149, 0.02454826175380731, 0.044909014613949694, 0.059438510943436995, 0.012681897424045019, 0.04899482330074534, 0.030074566093389876, 0.0437852212053258, 0.049068782027461566, 0.02392674832663033, 0.014836066402494907, 0.002425321445116424, 0.03247953274694737, 0.017078391392715275, 0.05014196838601492, 0.05695641288184561, 0.013815692200296326, 0.0614395896991482, 0.024372261432290543, 0.11525095513206907, 0.0554333403124474, 0.07265187145094387, 0.0400738742609974, 0.07107969096978195, 0.0074531488462525886, 0.03189600429323036, 0.03951579405111261, 0.03577466472052038, 0.04159896918281447, 0.053461869538296014, 0.010804289777297527, 0.009878195232886355, 0.03813958137470763, 0.0523244243231602, 0.07748023228487, 0.025710798981890548, 0.012597294444276486, 0.022762732369301375, 0.038774837521486916, 0.06522375988424756, 0.03496636571071576, 0.048609578152536415, 0.022044875186111312, 0.03601057862397283, 0.06043270681402646, 0.03378510780748911, 0.08655600075144321, 0.015298523667297559, 0.10185946433921345, 0.02607380381959956, 0.03947574776248075, 0.026956532819895074, 0.03064683060074458, 0.029439081736200023, 0.017291426738665905, 0.04671012167818844, 0.05549549518036656, 0.022254711875575595, 0.10576494969427586, 0.047109604929573834, 0.03568306885426864, 0.06211787185748108, 0.05706659212592058, 0.13082142861094326, 0.50253568100743, 2.4319649767130613, 4.882764117792249, 11.917523760348558, 15.521333031356335, 25.843973122537136, 42.44662553071976, 51.77761763334274, 65.70377916097641, 67.9905116558075, 73.2167436182499, 73.37485313415527, 76.6583177447319, 84.35083776712418, 70.57508736848831, 63.82148176431656, 71.998300999403, 60.21036833524704, 49.43731561303139, 33.88797618448734, 26.25742133706808, 22.431511133909225, 17.358393855392933, 18.836552537977695, 20.416528657078743, 20.531799271702766, 18.595882952213287, 25.220897756516933, 24.61941283196211, 28.39990597218275, 31.73080913722515, 36.78688623011112, 38.09145502746105, 27.972936183214188, 18.68329916149378, 11.598997302353382, 3.8099776580929756, 0.7802349328994751, 0.08028201787965372, 0.1258762611541897, 0.03262471538619138, 0.08298238899442367, 0.02338625145057449, 0.11008399684214965, 0.052318657835712656, 0.07017352865659632, 0.07311735389521345, 0.02087851218675496, 0.037274474670994096, 0.029925463059043977, 0.06569850433152169, 0.012955397396581247, 0.06934181859833188, 0.07977950968779624, 0.01222695997057599, 0.025700238220451865, 0.0663899039500393, 0.03137684230750892, 0.04900617816019803, 0.03276355637353845, 0.030044188133615535, 0.012492040277720662, 0.02839059590769466, 0.09349286992801353, 0.08413070667302236, 0.01944143597938819, 0.044026415489497595, 0.025496409216430038, 0.02455246230965713, 0.05291931134706829, 0.023793872351234313, 0.03866742648824584, 0.019501958122418728, 0.04324018053011969, 0.03773756368900649, 0.0297907409913023, 0.018645749769348186, 0.05641359864966944, 0.11089111212641001, 0.03436785700614564, 0.028573616946232505, 0.020054867418366484, 0.015075416449690238, 0.02939301291917218, 0.00730414321878925, 0.024450628516206052, 0.07908990606665611, 0.03360787181009073, 0.05531329050427303, 0.007112245630196412, 0.04388942244986538, 0.03345287426782306, 0.04129114116949495, 0.1383414922747761, 0.10156491334782913, 0.06741941120708361, 0.05752125405706465, 0.03366091310454067, 0.019383810067665763, 0.02935358261311194, 0.07163886213675141, 0.02391610778431641, 0.0468771160376491, 0.01733351393340854, 0.06175428628921509, 0.05801703839097172, 0.028899720346089453, 0.1258853153558448, 0.12104740308132023, 0.0956063655030448, 0.2024546207394451, 0.19617805519374087, 0.15464905940461904, 0.12768193613737822, 0.14442300656810403, 0.1469352506683208, 0.17851687007350847, 0.16907575714867562, 0.19793044397374615, 0.11939591669943184, 0.21132390887942165, 0.08321295943460427, 0.15097412222530693, 0.1621674161287956, 0.1840294391149655, 0.14563779841409996, 0.12670814932789654, 0.14753778552403674, 0.14026833028765395, 0.23018327658064663, 0.1293309437460266, 0.22970396792516112, 0.08838546898914501, 0.1929690976976417, 0.09692859064671211, 0.2376159152481705, 0.1274956125416793, 0.13117869850248098, 0.10470892550074495, 0.2015739883063361, 0.12055137383867987, 0.10683303378755227, 0.09096591646084562, 0.10896546154981479, 0.12304652627790347, 0.1863497935119085, 0.11408911552280188, 0.14911116828443483, 0.16293262975523248, 0.09009289846289903, 0.10438633617013693, 0.1728806592291221, 0.16319143149303272, 0.11414017528295517, 0.06455961192841642, 0.10645578528055921, 0.14678104722406715, 0.20380461704917252, 0.13653952802997082, 0.10851500017452054, 0.1454109387123026, 0.1258755783783272, 0.14729635004187003, 0.15315026248572394, 0.15241569955833256, 0.11767305055400357, 0.14113048324361444, 0.16641371796140447, 0.18533726659370586, 0.10378350445535034, 0.25172206456772983, 0.1655345846666023, 0.12532040738733485, 0.1830298700951971, 0.11717732559191063, 0.22243590792641044, 0.6904937827493995, 2.9722320986911654, 6.566933495923877, 15.159645639359951, 20.286374241113663, 32.181096374988556, 49.16217237710953, 57.21538044512272, 74.053945094347, 79.61729496717453, 86.06554135680199, 84.74918559193611, 87.24046111106873, 95.15891700983047, 83.41576114296913, 75.16944363713264, 82.61956706643105, 71.2529481947422, 59.57168720662594, 41.974500864744186, 31.37925010174513, 26.801495142281055, 22.484250403940678, 23.550769574940205, 24.80979211628437, 24.758139587938786, 23.651133589446545, 31.927228197455406, 32.016253620386124, 35.72732828557491, 40.81093110144138, 44.810820668935776, 46.316554471850395, 34.80195254087448, 23.425866477191448, 14.418182875961065, 4.626142513006926, 1.1571707879193127, 0.1567270135274157, 0.24200984509661794, 0.22285154031123966, 0.17627510911552235, 0.09015741336042993, 0.2967650257050991, 0.20582536642905325, 0.1485134128597565, 0.08296028041513637, 0.2362668392015621, 0.13723183306865394, 0.1582158953533508, 0.11230862161028199, 0.07766765425913036, 0.12439845959306695, 0.14415715442737564, 0.253999448614195, 0.11312266113236547, 0.1366284818504937, 0.11955719281104393, 0.10180274199228734, 0.11753881088225171, 0.18704387970501557, 0.09002344828331843, 0.1146647623681929, 0.11532086544320919, 0.21018303494201973, 0.13572654977906495, 0.17160707444418222, 0.09950264080544002, 0.09653778310166672, 0.15891336573986337, 0.13725941127631813, 0.15418820054037496, 0.15914075978798792, 0.17579425679286942, 0.15627451124601066, 0.10491318680578843, 0.1349776634015143, 0.1269949003471993, 0.21253309008898214, 0.14134379132883623, 0.09445793650229461, 0.1749912233208306, 0.09865250322036445, 0.15287531161447987, 0.09709599689813331, 0.22942638985114172, 0.15701501135481521, 0.1557182418764569, 0.11227408205741085, 0.19411178247537464, 0.08794851470156573, 0.11960622650803998, 0.1218279791646637, 0.1420871858135797, 0.11274041797150858, 0.17409641586709768, 0.13779619184788316, 0.13829772040480748, 0.15405364916659892, 0.19997029623482376, 0.1585516578052193, 0.15678309020586312, 0.15225474257022142, 0.12469974928535521, 0.17801819136366248, 0.12090797579730861, 0.15148543228860945], [0.12019702800898813, 0.044574461862794124, 0.07581680474686436, 0.010362181274103932, 0.024647557402204257, 0.07609011547174305, 0.025157769086945336, 0.032148772370419465, 0.046215576730901375, 0.025761116594367195, 0.04604344670951832, 0.03728789270098787, 0.02626208297442645, 0.04097039236512501, 0.023236380293383263, 0.06252995677641593, 0.04751019769173581, 0.018389703254797496, 0.07041134245810099, 0.044647392714978196, 0.020132902391196694, 0.037482621119124815, 0.11305297346552834, 0.04785244651429821, 0.06263519331696443, 0.00933158677071333, 0.06653579534031451, 0.10160835125134327, 0.03924974153051153, 0.06937358251889236, 0.05335580550308805, 0.04837873682845384, 0.07216220983536914, 0.048045716612250544, 0.056570870874566026, 0.04866266026510857, 0.0783900311216712, 0.017113550638896413, 0.03432549892750103, 0.022500958330056164, 0.011498602325445972, 0.014313639894680819, 0.04960770740581211, 0.040357307880185544, 0.03840433513687458, 0.04432359739439562, 0.041493832832202315, 0.06120920108514838, 0.007248446891026106, 0.03649388745543547, 0.07306667263037525, 0.04498315145610832, 0.07741446315776557, 0.034405858677928336, 0.0143643925912329, 0.027260804090474267, 0.022620097151957452, 0.022073427462601103, 0.09489676842349581, 0.017274101301154587, 0.03126374271232635, 0.07723791364696808, 0.02753914101049304, 0.038569225507671945, 0.0781506513885688, 0.09761488428921439, 0.315464801969938, 1.102450992912054, 4.131208620965481, 13.029251955449581, 22.302095778286457, 28.685814030468464, 42.809620052576065, 51.543808579444885, 55.86062774062157, 65.15845522284508, 75.56493401527405, 69.58657801151276, 68.90259951353073, 71.68394386768341, 64.8515684902668, 68.55547294020653, 76.16831883788109, 74.9265530705452, 72.69816264510155, 79.66730028390884, 69.4020827114582, 67.3420612514019, 67.53382936120033, 59.8068717867136, 59.265917614102364, 55.285445004701614, 45.13959042727947, 48.75493302941322, 56.292850747704506, 50.11462166905403, 51.68176017701626, 52.05135874450207, 57.671336978673935, 64.57042157649994, 63.33616800606251, 61.00060813128948, 57.71223798394203, 46.428211480379105, 49.91552375257015, 31.954746320843697, 15.311945267021656, 3.9716865308582783, 0.5776029091794044, 0.06215780682396144, 0.03640602088125888, 0.04733732552267611, 0.07825015112757683, 0.02167434311559191, 0.041788357848417945, 0.07005412451690063, 0.02948626563011203, 0.03309682520921342, 0.02784045853331918, 0.01892485666758148, 0.013904108891438227, 0.03443655019509606, 0.03389660065295175, 0.0662792868388351, 0.027546766577870585, 0.04428446394740604, 0.02779935282887891, 0.10240849776891991, 0.09680481525720097, 0.060785724199377, 0.03618196649767924, 0.008690429622220108, 0.05174131889361888, 0.02668772136530606, 0.07038438765448518, 0.08851705919369124, 0.058449873758945614, 0.016855448375281412, 0.004910073148494121, 0.04438742580532562, 0.055734355410095304, 0.04631197058188263, 0.012927272782690125, 0.01790554651961429, 0.024903123376134317, 0.02881915650505107, 0.03132738929707557, 0.07278651930391788, 0.04014240788819734, 0.057799785790848546, 0.07924475517938845, 0.02653044728504028, 0.03439359468757175, 0.045340161595959216, 0.018561953875178006, 0.055497395078418776, 0.01738437516905833, 0.033821914621512406, 0.06767491780919954, 0.04583373804052826, 0.011071006520069204, 0.013528288091038121, 0.021361080725910142, 0.01909111630084226, 0.05108460725750774, 0.0360335369623499, 0.06046554684871808, 0.047390945692313835, 0.02243314273073338, 0.060762320572393946, 0.023985474472283386, 0.02432423149002716, 0.032136712470673956, 0.0318604294443503, 0.031028930898173712, 0.054784439780632965, 0.01652635412028758, 0.06758753734175116, 0.019597364916990045, 0.08041489199968055, 0.017880779196275398, 0.018390812765574083, 0.041305308768642135, 0.02235981111880392, 0.06733509580953978, 0.040088134628604166, 0.01980711440410232, 0.05251249567663763, 0.02552405607275432, 0.009511090956948465, 0.012617118136404315, 0.13235647202236578, 0.049736533110262826, 0.05087468336569145, 0.0998979457654059, 0.01984422364330385, 0.031425271154148504, 0.01951483623997774, 0.04825234536838252, 0.05167440314835403, 0.11441868846304715, 0.022173294564709067, 0.02404755327006569, 0.11097674854681827, 0.026481951645109802, 0.02775856995867798, 0.08384949207538739, 0.020513648269115947, 0.050060974099324085, 0.046933096236898564, 0.08782145901932381, 0.032334220231859945, 0.04330479561758693, 0.04361410792625975, 0.07792710166540928, 0.045924046280561015, 0.09739566870848648, 0.0036746008936461294, 0.03300859869341366, 0.039448510942747816, 0.08553568128263578, 0.030695944078615867, 0.042800851369975135, 0.04055862285895273, 0.024127775723172817, 0.022576147166546434, 0.04948631059960462, 0.03838843462290242, 0.03826876331004314, 0.027312272031849716, 0.032693445682525635, 0.04927375208353624, 0.03710122771735769, 0.006537521830978221, 0.07561622449429706, 0.014274483255576342, 0.03570978617062792, 0.043823824016726576, 0.018951746533275582, 0.05583044498052914, 0.05104315830976702, 0.1326552458340302, 0.3801814449252561, 1.9678157265298069, 7.2937926929444075, 17.246543057262897, 28.98450080305338, 36.49360656738281, 50.317564979195595, 61.9834253937006, 70.97231045365334, 77.1958976984024, 85.81778705120087, 77.92136996984482, 79.62534293532372, 79.64570984244347, 74.0096166729927, 77.91559427976608, 85.83417937159538, 85.51361337304115, 82.73375853896141, 87.58527740836143, 82.1004693210125, 77.73096978664398, 76.59491434693336, 71.24715730547905, 67.44527891278267, 64.16531771421432, 54.288306310772896, 55.97952716052532, 64.6347825229168, 58.626191541552544, 62.888362035155296, 60.615738183259964, 66.52850210666656, 74.78741973638535, 72.71829396486282, 69.47979614138603, 69.3800438940525, 56.49590045213699, 59.20981742441654, 39.57942098379135, 19.779283851385117, 6.101205311715603, 1.1116571864113212, 0.16255732567515224, 0.026101163093699142, 0.05538041405088734, 0.04752203123643994, 0.053100280347280204, 0.04060607207065914, 0.018896553010563366, 0.0605371826532064, 0.013023521914874436, 0.04467048463993706, 0.056039311311906204, 0.06951772244065069, 0.050903697629109956, 0.05985892275930382, 0.0789551246271003, 0.003721850421243289, 0.02368496217968641, 0.004957798810210079, 0.04385185122373514, 0.01816694020817522, 0.0401698599307565, 0.04028235838632099, 0.009104893124458613, 0.01037320773320971, 0.02394207738689147, 0.05384763047914021, 0.14746281376574188, 0.06187937528011389, 0.01297132295803749, 0.056175818244810216, 0.04185837577097118, 0.03221610371838324, 0.05160971013538074, 0.027305739276926033, 0.06026044691679999, 0.03633702341176104, 0.01501679049397353, 0.023634601893718354, 0.03805177046160679, 0.01432915634723031, 0.03490985858661588, 0.05265172629151493, 0.03451908443821594, 0.003601428611545998, 0.07032302688458003, 0.031675430582254194, 0.09119962618569843, 0.023780869923939463, 0.00897182790140505, 0.11124375101644546, 0.01462593192627537, 0.053815621649846435, 0.03780895087402314, 0.030165900352585595, 0.02425618211418623, 0.009909004565997748, 0.05459503627207596, 0.05492244214110542, 0.05958496636594646, 0.03451131786277983, 0.09988559642806649, 0.07261079357704148, 0.021356266042857897, 0.026888735774264205, 0.007237640293169534, 0.045110645005479455, 0.03908179722202476, 0.16695183439878747, 0.21129376284079626, 0.16439972212538123, 0.1567391847493127, 0.09945078694727272, 0.2274206466972828, 0.10346312672481872, 0.12576844193972647, 0.1383969752350822, 0.07651613050256856, 0.1418358797673136, 0.1645372124039568, 0.16404691996285692, 0.13490518525941297, 0.15576839621644467, 0.23619960062205791, 0.15231907193083316, 0.12031456193653867, 0.14900639187544584, 0.1564736443106085, 0.08235865840106271, 0.1102158913272433, 0.1758634694851935, 0.19359564845217392, 0.2830052812350914, 0.09481929562753066, 0.16659688000800088, 0.26217901438940316, 0.1188605091010686, 0.11451139012933709, 0.2366578471264802, 0.12822900287574157, 0.13102850265568122, 0.23484256875235587, 0.20068425714271143, 0.0942414000746794, 0.12851823266828433, 0.07543940038885921, 0.1656053410260938, 0.13115533569362015, 0.18664119037566707, 0.12501192628405988, 0.14043568458873779, 0.0890776701271534, 0.14477726334007457, 0.1703914365498349, 0.12605624680873007, 0.11134739193948917, 0.16926979908021167, 0.11270515111391433, 0.19276769366115332, 0.14177566190483049, 0.1471794766257517, 0.15429590101120993, 0.09945283527486026, 0.12533603701740503, 0.13201520283473656, 0.10794669316965155, 0.18143630091799423, 0.08461668723612092, 0.09736107720527798, 0.17683068086626008, 0.08822799267363735, 0.15138475253479555, 0.17428414954338223, 0.3431872831424698, 0.6090953224338591, 2.2971303993836045, 8.821160160005093, 18.762239925563335, 34.08234715461731, 43.66541773080826, 58.349676579236984, 72.06006288528442, 80.89485481381416, 87.17437505722046, 97.0658902823925, 89.97537195682526, 89.39142689108849, 93.63612592220306, 86.49041935801506, 91.86547413468361, 98.73160690069199, 98.27114760875702, 95.59362128376961, 98.21528300642967, 95.9972508251667, 90.30599221587181, 88.46002846956253, 82.93146952986717, 76.87439695000648, 73.92090663313866, 65.40816262364388, 70.69816276431084, 77.81960383057594, 71.16828113794327, 74.07611310482025, 71.92473694682121, 77.49923542141914, 86.33445292711258, 87.51601472496986, 79.15174394845963, 77.76566952466965, 66.28865137696266, 67.9543299973011, 44.322189688682556, 24.135930575430393, 8.156541623175144, 1.4411478373222053, 0.34024751745164394, 0.15377059404272586, 0.14515169168589637, 0.13263492583064362, 0.11269443450146355, 0.11728762357961386, 0.18663789523998275, 0.10942614229861647, 0.12448745794245042, 0.1253411578363739, 0.13766115065664053, 0.1511077384930104, 0.12888048979220912, 0.10778254494653083, 0.27930338925216347, 0.08735864088521339, 0.15175593027379364, 0.13862954947398975, 0.1871457023662515, 0.12950920761795714, 0.11219940715818666, 0.11610425426624715, 0.06910382668138482, 0.10267226447467692, 0.16463456733617932, 0.1922636418021284, 0.22854036942590028, 0.1372261333744973, 0.11905348976142704, 0.08513803855748847, 0.133027418050915, 0.16144563298439607, 0.14666396600659937, 0.26678825612179935, 0.13553679746109992, 0.10454347109771334, 0.08989585083327256, 0.06380720777087845, 0.12893389473902062, 0.09264222026104107, 0.10817265487276018, 0.18988204537890851, 0.1532868918729946, 0.11894732553628273, 0.15751072147395462, 0.12411703719408251, 0.2807981934165582, 0.07347235281486064, 0.09104633558308706, 0.19953976152464747, 0.0959520653123036, 0.17608924565138295, 0.14148472517263144, 0.09831277027842589, 0.09144972253125161, 0.141005668847356, 0.1678966626059264, 0.14203403319697827, 0.1519350105081685, 0.0930095833609812, 0.18200894206529483, 0.11214259575353935, 0.07970957711222582, 0.12301928203669377, 0.16996280173771083, 0.17686315724859014, 0.09384295583004132], [0.08023719958146103, 0.07168358395574614, 0.042326604161644354, 0.04552363163384143, 0.05265902902465314, 0.03155576669087168, 0.04729258143925108, 0.05971870879875496, 0.023843540584493894, 0.026636225593392737, 0.04277680578525178, 0.026721576286945492, 0.06942561449250206, 0.03922246389265638, 0.01735379126330372, 0.006959426755202003, 0.05671915569109842, 0.05502316642377991, 0.035873214510502294, 0.0379579963919241, 0.01763238793500932, 0.01822395384806441, 0.057801644870778546, 0.04242890179739334, 0.01746939931763336, 0.019577282400859986, 0.04201156989438459, 0.027409838476160076, 0.044907949632033706, 0.03136067090963479, 0.042730139539344236, 0.02952339156763628, 0.057639032893348485, 0.005521546709132963, 0.041208339753211476, 0.027808531340269838, 0.026766923365357798, 0.047702373121865094, 0.037702437839470804, 0.04093096205906477, 0.03987243682786357, 0.015053758725116495, 0.026863513885473367, 0.019158803879690822, 0.02387185908446554, 0.030442893985309638, 0.034630046648089774, 0.0418097465444589, 0.021641703460772987, 0.01688701748207677, 0.0666052455198951, 0.03276256931712851, 0.050490005960455164, 0.04905474059341941, 0.03801819198997691, 0.06626458489336073, 0.045196277715149336, 0.01691797802777728, 0.057349350390722975, 0.042042202039738186, 0.049686579150147736, 0.03937989939004183, 0.1727864658460021, 0.9991658851504326, 1.0087211849167943, 2.820699317380786, 7.837019143626094, 15.628550928086042, 26.52422022074461, 51.20735563337803, 59.39197964966297, 62.38069027662277, 67.08733811974525, 69.26609560847282, 76.07300475239754, 68.08189675211906, 63.58477346599102, 60.24625360965729, 67.11398229002953, 60.219324454665184, 56.04423388838768, 57.98620328307152, 52.29682557284832, 51.142394319176674, 61.21903941035271, 61.92596107721329, 54.974655881524086, 69.20877948403358, 64.59546983242035, 70.47135293483734, 70.01650214195251, 67.33959898352623, 59.858746603131294, 60.09164750576019, 65.0685216486454, 62.558285146951675, 66.54126182198524, 70.15833333134651, 64.72425252199173, 62.57900923490524, 60.39764888584614, 64.29046779870987, 66.22658550739288, 66.61442309617996, 65.83542689681053, 63.88575151562691, 50.95039822161198, 26.459910571575165, 18.010463565587997, 6.469506723806262, 1.8047325150109828, 0.08381251827813685, 0.029010738217039034, 0.02496227440133225, 0.04673160314268898, 0.029618332664540503, 0.09699504997115582, 0.050512463349150494, 0.032352388006984256, 0.06145199840830173, 0.045316015821299516, 0.0723097265290562, 0.11131559833302163, 0.0515280961553799, 0.03464665962383151, 0.045192511315690354, 0.004605638141583768, 0.03795419659581967, 0.05654651358781848, 0.02094480638334062, 0.04376670091005508, 0.012547920287033776, 0.05088518104457762, 0.05105428310343996, 0.020430216027307324, 0.05188885785173625, 0.037411126322695054, 0.04758980045153294, 0.009453852817387087, 0.04925928020384163, 0.019216459477320313, 0.015345146312029101, 0.029634507773153018, 0.018095324812748004, 0.037809852583450265, 0.03901534160831943, 0.055081614264054224, 0.02893493710871553, 0.032251630327664316, 0.045889480752521195, 0.03950923346565105, 0.0433704014722025, 0.025700525802676566, 0.020824767707381397, 0.023727409316052217, 0.026441870104463305, 0.020111168596486095, 0.022397319262381643, 0.06472184541053139, 0.024713217062526383, 0.02049617254670011, 0.06257518325583078, 0.06838084867922589, 0.020746216941915918, 0.10372661883593537, 0.013248473369458225, 0.021366361106629483, 0.05122992348333355, 0.03577895062335301, 0.08513263572240248, 0.04161400138400495, 0.009711609054647852, 0.08574020233936608, 0.04796438093762845, 0.01814198178180959, 0.027819387105409987, 0.08326787094119936, 0.041376298904651776, 0.07345641148276627, 0.05287637068249751, 0.03987182084529195, 0.004676892667703214, 0.02060969331068918, 0.04148710155277513, 0.0164619672432309, 0.03225567132176366, 0.03880590382323135, 0.027136852440889925, 0.04896463273325935, 0.04141339144553058, 0.026812608120962977, 0.058804683430935256, 0.0324418130912818, 0.03618104994529858, 0.028850204253103584, 0.06269529985729605, 0.011805706744780764, 0.012244694516994059, 0.023685379637754522, 0.08690083224792033, 0.026370883679192048, 0.0494808483927045, 0.05035402224166319, 0.05517628633242566, 0.017664960796537343, 0.04935726596158929, 0.030296978475234937, 0.026391344690637197, 0.05592623398115393, 0.048564685639576055, 0.06742845056578517, 0.05286270403303206, 0.03387413213204127, 0.029822632932337, 0.03724811729625799, 0.04581967063131742, 0.05654861015500501, 0.05584241953329183, 0.01888111262815073, 0.048959326377371326, 0.032824787267600186, 0.0557096122065559, 0.035586196318035945, 0.03112615038844524, 0.03326042053231504, 0.04463966324692592, 0.17670092376647517, 0.031375042599393055, 0.05554448063776363, 0.06962491082958877, 0.03576747330953367, 0.06875607854453847, 0.025657501646492165, 0.02013807330513373, 0.07931934844236821, 0.03598039547796361, 0.06957119418075308, 0.0731986339087598, 0.14774137147469446, 0.8693256648257375, 1.5984257915988564, 5.638543562963605, 13.208963312208652, 24.85757265239954, 35.19670195877552, 63.35083521902561, 70.3046178817749, 73.62057834863663, 75.25863245129585, 81.19608744978905, 83.90783473849297, 76.30482271313667, 72.70913645625114, 69.09306809306145, 75.83615586161613, 71.59803047776222, 65.51298379898071, 66.32283434271812, 63.14341954886913, 65.00870525836945, 71.24277234077454, 70.95948234200478, 65.27851358056068, 81.34776011109352, 77.85300403833389, 82.05500096082687, 78.43364328145981, 76.13978236913681, 67.82268986105919, 71.30657851696014, 73.24838072061539, 70.4632517695427, 76.01314276456833, 79.771369099617, 73.5796469449997, 71.31015792489052, 70.2579639852047, 73.62848952412605, 73.93121168017387, 74.74059864878654, 74.89755302667618, 72.7987052500248, 59.21406179666519, 32.73066088557243, 25.16932502388954, 10.17785931006074, 2.5681206956505775, 0.10348813710152172, 0.030077684969000984, 0.04756792935950216, 0.03474677534541115, 0.030193751299520954, 0.045429683159454726, 0.06180691569170449, 0.05726647475967184, 0.11569799520657398, 0.11073140194639564, 0.10123505096998997, 0.02850638578820508, 0.05331690212187823, 0.025715441115607973, 0.044653073855442926, 0.04211427200061735, 0.02031511077802861, 0.09290109621360898, 0.007875569099269342, 0.043599932905635796, 0.02466519825247815, 0.044350351818138734, 0.05773467717517633, 0.025466719598625787, 0.039000105316517875, 0.04150313565332908, 0.08208904357161373, 0.012855804889113642, 0.06840224479674362, 0.016503906008438207, 0.024861989841156173, 0.059807135694427416, 0.047746486379764974, 0.025489418185316026, 0.08388413552893326, 0.047249150957213715, 0.0639429985312745, 0.06053320103092119, 0.033967460913117975, 0.020728691124531906, 0.023447304229193833, 0.03273172565968707, 0.046402538573602214, 0.06417284166673198, 0.003530201220200979, 0.032542125481995754, 0.024039330273808446, 0.029168505825509783, 0.030385121499421075, 0.035758285521296784, 0.02211265924415784, 0.09245908790035173, 0.07257645440404303, 0.07376436566119082, 0.03564081467629876, 0.03779384816880338, 0.03739699212019332, 0.02819920344336424, 0.03407624491956085, 0.046043943948461674, 0.05793186210212298, 0.05844677158165723, 0.015441426057805074, 0.029650732976733707, 0.010493419886188349, 0.18374715582467616, 0.14057636610232294, 0.17500712012406439, 0.15569719456834719, 0.1482559321448207, 0.1272859558230266, 0.1234134440892376, 0.15639956312952563, 0.09117654539295472, 0.11412329142331146, 0.11371834596502595, 0.11260361046879552, 0.17943229438969865, 0.13576257362728938, 0.0940430536866188, 0.09577001648722216, 0.24786669644527137, 0.16182631021365523, 0.14157410943880677, 0.14231869135983288, 0.08661980318720452, 0.13332150148926303, 0.1376885359059088, 0.17230029974598438, 0.10879222943913192, 0.27138312987517565, 0.162175030563958, 0.212798704742454, 0.07968067788169719, 0.15645405161194503, 0.1209850849409122, 0.12921271962113678, 0.1659197741537355, 0.13580333237769082, 0.16073754988610744, 0.12388394345180131, 0.1420382337528281, 0.09882647747872397, 0.11378679424524307, 0.16691895725671202, 0.13888351240893826, 0.1175416013575159, 0.12859002803452313, 0.12789233500370756, 0.11155758300446905, 0.09945183337549679, 0.19146270118653774, 0.13812852557748556, 0.20849536143941805, 0.1129079726524651, 0.25344260036945343, 0.18327461555600166, 0.11273447336861864, 0.19490282284095883, 0.11270184113527648, 0.16308508173096925, 0.09743606380652636, 0.21770902094431221, 0.10887124590226449, 0.17490510450443253, 0.17698574520181865, 0.26252120384015143, 0.4094561724923551, 1.2676657713018358, 1.9489125721156597, 6.270034052431583, 15.06208872422576, 28.936594873666763, 42.500210255384445, 73.1346908211708, 79.38001289963722, 83.88174533843994, 87.04187616705894, 92.12257593870163, 94.75138887763023, 89.698176831007, 83.82651150226593, 80.33225700259209, 88.56011509895325, 81.37756571173668, 79.16138783097267, 77.10261270403862, 73.8808111846447, 73.28647747635841, 80.52449628710747, 84.62888404726982, 75.56968376040459, 95.7883608341217, 90.52052110433578, 93.48165661096573, 90.59267163276672, 88.01289886236191, 80.77066987752914, 81.8716835975647, 86.02109894156456, 82.07570225000381, 87.0161971449852, 93.97556930780411, 85.5214561522007, 83.51106002926826, 80.37490591406822, 86.4508330821991, 86.51656195521355, 86.7087784409523, 85.13606563210487, 83.29634115099907, 68.01720902323723, 40.82636587321758, 31.533590219914913, 12.126029022037983, 3.19323583971709, 0.20261833851691335, 0.15303899970604107, 0.15955449227476493, 0.1282167129102163, 0.12022267663269304, 0.1686776097631082, 0.2131798124173656, 0.16210137982852757, 0.2773877279832959, 0.1315702110878192, 0.1443819361156784, 0.19828257820336148, 0.09454019615077414, 0.07315862472751178, 0.19204518321203068, 0.09408477722899988, 0.10628624164382927, 0.14042646711459383, 0.06677960569504648, 0.12599619221873581, 0.18000661279074848, 0.2672543248627335, 0.15512948128161952, 0.1717777832527645, 0.17606197914574295, 0.09993184707127512, 0.12439809594070539, 0.112152013607556, 0.1793731897487305, 0.09326597311883233, 0.06291125740972348, 0.09837644654908217, 0.12966274312930182, 0.15324102714657784, 0.13297949015395716, 0.13174599618650973, 0.19401074649067596, 0.1275651517789811, 0.22536053380463272, 0.16956116625806317, 0.173888792633079, 0.07246997847687453, 0.20203162624966353, 0.1418570606620051, 0.07193007346359082, 0.12619960005395114, 0.13818926294334233, 0.17786573938792571, 0.12447744637029245, 0.10175133342272602, 0.1256764304707758, 0.1405910903122276, 0.15142613468924537, 0.16828811581945047, 0.09222868815413676, 0.14580843300791457, 0.14928463788237423, 0.2000851955381222, 0.13076702918624505, 0.1054820504214149, 0.16396035585785285, 0.2095666219247505, 0.14282937801908702, 0.13201593013945967, 0.14464900537859648], [0.021236999200482387, 0.07250781316542998, 0.11777844294556417, 0.025293101571151055, 0.06483969104010612, 0.044329478914733045, 0.00439433524661581, 0.017248654912691563, 0.023450055741705, 0.055551145123899914, 0.01676369851338677, 0.06295465078437701, 0.042255339430994354, 0.04806136108527426, 0.026860966463573277, 0.08633976118289866, 0.05757225073466543, 0.062004134015296586, 0.01817996489990037, 0.056146265924326144, 0.04880997286818456, 0.021367706249293406, 0.04242178089043591, 0.045175219274824485, 0.012791817844117759, 0.07395773965981789, 0.08368128430447541, 0.02986450861499179, 0.03283128848124761, 0.0576495194400195, 0.0516593598149484, 0.04829616918868851, 0.010924898051598575, 0.04117484662856441, 0.034815405451809056, 0.02767691701592412, 0.11967313112108968, 0.020820196077693254, 0.021938842692179605, 0.04446711020136718, 0.041624736550147645, 0.04050264637044165, 0.04579802589432802, 0.03321608091937378, 0.014207455260475399, 0.04817662404093426, 0.018121064349543303, 0.056578845251351595, 0.04544886025541928, 0.03216836506908294, 0.05405458949098829, 0.016889245780475903, 0.030632367997895926, 0.029070742712065112, 0.01889574406959582, 0.024739110594964586, 0.07297163319890387, 0.0584846025594743, 0.1811848464421928, 0.07396070082904771, 0.33220337878447026, 1.9789627846330404, 3.8162596710026264, 5.69190694950521, 19.45962220430374, 31.291790194809437, 48.92952226102352, 53.928344026207924, 60.488748997449875, 64.96988654136658, 68.58473896980286, 70.45180678367615, 62.86662720143795, 60.82316905260086, 43.958549201488495, 51.357778161764145, 57.56230182945728, 50.26798523962498, 39.42932903766632, 30.268826186656952, 36.75566330552101, 38.90437960624695, 29.154902659356594, 31.09550602734089, 45.318583622574806, 35.9445246309042, 35.53182117640972, 50.65484248101711, 35.48579804599285, 43.41836638748646, 42.442635744810104, 52.517829313874245, 61.0570465028286, 57.93627396225929, 50.91754138469696, 47.25797675549984, 52.19504803419113, 49.48420129716396, 57.29952692985535, 55.93587510287762, 54.420398622751236, 52.13899344205856, 58.108055144548416, 58.51801134645939, 68.70195508003235, 67.76277467608452, 62.33472414314747, 57.25660443305969, 50.14858424663544, 36.813386008143425, 18.472672663629055, 6.98668509721756, 2.0947618084028363, 0.2987972041592002, 0.12336426938418299, 0.13588551781140268, 0.03733862591616344, 0.01265970999156707, 0.014601700804632856, 0.03738706960575655, 0.04011825469206087, 0.08739634198718704, 0.014746486394869862, 0.05633185850456357, 0.038340822138707153, 0.08564282514271326, 0.04326217407651711, 0.03826276304607745, 0.06622724744374864, 0.058450185460969806, 0.03534468291036319, 0.01832009536883561, 0.035447028785711154, 0.01247709064045921, 0.061515036431956105, 0.08207653838326223, 0.008601835743320407, 0.06332660777843557, 0.009545694520056713, 0.04626557150913868, 0.03981395930168219, 0.012816892231057864, 0.046964952925918624, 0.05038065050030127, 0.04134238275582902, 0.03186307520081755, 0.0146225171192782, 0.03663578609121032, 0.036951191432308406, 0.03117952379398048, 0.06580648681847379, 0.06203061384439934, 0.027555247470445465, 0.01668376920861192, 0.013095237500238, 0.021282051275193226, 0.03422106019570492, 0.06792356696678326, 0.05607759871054441, 0.05289244560117368, 0.06584906383068301, 0.03093437015195377, 0.04747690494696144, 0.03251579408242833, 0.040521801201975904, 0.053783798357471824, 0.04955681462888606, 0.06934633827768266, 0.06685183150693774, 0.08225447571021505, 0.041833677096292377, 0.027689769158314448, 0.04160908094490878, 0.04022060056740884, 0.10524490455281921, 0.09090602514334023, 0.011653070159809431, 0.059022986170020886, 0.08482654433464631, 0.04542664406471886, 0.02932058116130065, 0.04270766359695699, 0.024175135877158027, 0.05920067858824041, 0.015041552251204848, 0.04824530609766953, 0.016533725502085872, 0.0787853509245906, 0.06809698461438529, 0.02399594432063168, 0.06148408887383994, 0.0631646192050539, 0.0241451531110215, 0.07802877589710988, 0.011232829965592828, 0.019941491373174358, 0.02104404822603101, 0.06288629156188108, 0.04410484565596562, 0.06212662177858874, 0.03652240447991062, 0.05094482745334972, 0.02657963126694085, 0.03529296263877768, 0.05190080642933026, 0.06278344473685138, 0.031239433665177785, 0.03133783131488599, 0.042696204836829565, 0.010003043025790248, 0.021500699112948496, 0.01647776571189752, 0.0297917373245582, 0.03130443838017527, 0.02848104886652436, 0.060891443135915324, 0.008132906950777397, 0.04809049038158264, 0.009361302363686264, 0.019056454293604475, 0.05218075937591493, 0.048873370833462104, 0.019336210571054835, 0.06486902813776396, 0.04754199871968012, 0.020846163824899122, 0.026866508451348636, 0.07997361841262318, 0.017570184827491175, 0.08337324106832966, 0.04531821628916077, 0.010726771524787182, 0.04306410228309687, 0.02993020723806694, 0.42335202684625983, 0.1465395078412257, 0.3844362369272858, 3.888021195307374, 7.6605770364403725, 12.566811069846153, 29.98364008963108, 43.978684321045876, 61.94786310195923, 67.42529958486557, 74.92276087403297, 76.5420363843441, 76.84554889798164, 81.79539129137993, 74.3350388109684, 67.77886301279068, 52.65519954264164, 61.73171170055866, 67.65581801533699, 60.15883170068264, 47.39307090640068, 40.72146490216255, 49.380390867590904, 51.10759198665619, 39.07002791762352, 42.371161580085754, 52.951990216970444, 47.2877861559391, 45.0773611664772, 61.29819296300411, 45.2325714379549, 51.29275985062122, 51.87800444662571, 62.59902276098728, 69.68365520238876, 65.9400200843811, 59.08624805510044, 57.28375397622585, 61.69660918414593, 58.24768245220184, 70.34995704889297, 65.26229605078697, 65.03206640481949, 63.005676940083504, 68.06294336915016, 69.07248839735985, 76.88525676727295, 75.4856550693512, 70.83529740571976, 71.7931804060936, 57.52149201929569, 45.117289423942566, 24.325863383710384, 10.368999503552914, 3.825968625023961, 0.42973847477696836, 0.21785069693578407, 0.09347545172204264, 0.04803265481314156, 0.04550776822725311, 0.03371157210494857, 0.040786213576211594, 0.05495379045896698, 0.022814246694906615, 0.00924812484299764, 0.040135068047675304, 0.051660224416991696, 0.07460479595465586, 0.022155332735565025, 0.07501961939851753, 0.06565833929926157, 0.07687330391490832, 0.0409447660058504, 0.04803449905011803, 0.029458696699293796, 0.013164222909836099, 0.0029945044161650003, 0.03792507101024967, 0.10187537598540075, 0.05649057049595285, 0.03454441764915828, 0.05096071312436834, 0.02436156337353168, 0.016152896132552996, 0.049299845995847136, 0.07298352982616052, 0.049685625490383245, 0.023716186187812127, 0.03790056529396679, 0.047643079233239405, 0.03147833842376713, 0.021920179533481132, 0.015832112076168414, 0.0676565570756793, 0.049795619197539054, 0.014915361171006225, 0.029182050020608585, 0.012215555016155122, 0.03301033160823863, 0.05397244116466027, 0.04990510453353636, 0.033343169998261146, 0.08490812120726332, 0.010639718530001119, 0.034982054712600075, 0.05684182156983297, 0.015578920974803623, 0.04488862039579544, 0.03289113155915402, 0.0677359223482199, 0.058230446666129865, 0.02138213545549661, 0.04556730702461209, 0.028967025718884543, 0.019852817713399418, 0.018491332957637496, 0.07452350109815598, 0.035763302439590916, 0.09107628866331652, 0.1128710359625984, 0.19519001914886758, 0.1581620005890727, 0.17122895020293072, 0.1557362760649994, 0.09183256683172658, 0.11694228000123985, 0.10042091496870853, 0.15041725913761184, 0.16799285978777334, 0.15724531462183222, 0.16862295800819993, 0.1435289709479548, 0.13772979931673035, 0.15368879452580586, 0.14667368814116344, 0.2065945728099905, 0.07744581147562712, 0.12826392834540457, 0.05238070138148032, 0.12706044683000073, 0.06885293623781763, 0.16873359738383442, 0.1379485844518058, 0.13426022924249992, 0.1740581210469827, 0.10749569744803011, 0.12839110277127475, 0.13897969474783167, 0.1095921904197894, 0.12719682388706133, 0.17976398987229913, 0.12154080512118526, 0.09233165372279473, 0.14930060890037566, 0.17314661527052522, 0.10755621216958389, 0.09721114111016504, 0.10622384928865358, 0.18227344349725172, 0.14315234584501013, 0.15913701936369762, 0.1614313540630974, 0.1004877824743744, 0.16280747397104278, 0.15356970950961113, 0.16221405268879607, 0.08782310658716597, 0.18767862376989797, 0.20023651944939047, 0.1265189758851193, 0.0964740697236266, 0.25224919721949846, 0.08815892098937184, 0.11548783382750116, 0.17100966040743515, 0.13817314349580556, 0.5102639319375157, 0.3065432369476184, 0.8278752921614796, 5.036649685353041, 8.828981090337038, 15.032585207372904, 35.49000822007656, 52.253602892160416, 72.04065352678299, 76.7864316701889, 84.90376889705658, 88.80508035421371, 88.22887167334557, 92.23781615495682, 83.72507214546204, 81.24189779162407, 65.84867298603058, 73.1005610525608, 77.75633722543716, 69.54068407416344, 57.83881299197674, 46.12259387969971, 56.23980179429054, 57.31601804494858, 46.2077397108078, 48.49440760910511, 61.92303903400898, 55.84372244775295, 56.44730485975742, 70.67564517259598, 55.015712678432465, 62.68887273967266, 61.03314198553562, 72.79738292098045, 80.03515854477882, 79.60925459861755, 67.66318202018738, 68.80053699016571, 71.53062209486961, 68.9794921875, 77.57152274250984, 76.55937865376472, 73.50846916437149, 71.4850701391697, 76.6372212767601, 77.61398926377296, 86.88659369945526, 86.80242821574211, 82.20957666635513, 82.86086931824684, 67.2770619392395, 54.471745267510414, 29.103272929787636, 13.549117259681225, 4.602297842502594, 0.8792945486493409, 0.2890622749691829, 0.23206367099191993, 0.13712012500036508, 0.1981819429784082, 0.1744515186874196, 0.11705890108714812, 0.22408087825169787, 0.21318892599083483, 0.12359504762571305, 0.11313184149912558, 0.10137851553736255, 0.23017269355477765, 0.12432546936906874, 0.12716664816252887, 0.23988488333998248, 0.19706515915459022, 0.12460448720958084, 0.1523128230473958, 0.15333202929468825, 0.0996251916512847, 0.13254073244752362, 0.1579791947733611, 0.15826183429453522, 0.13520162872737274, 0.07599866061354987, 0.11342843339662068, 0.0904980739869643, 0.09702714043669403, 0.14767417742405087, 0.1780973339919001, 0.14800793607719243, 0.07969507554662414, 0.11720374604919925, 0.11334997354424559, 0.11273880008957349, 0.07882373480242677, 0.11741456793970428, 0.16310761333443224, 0.16756971686845645, 0.08046693139476702, 0.206558741920162, 0.15734758257167414, 0.09237710284651257, 0.1356180923175998, 0.16795780073152855, 0.1042387897905428, 0.13153080304618925, 0.17317213030764833, 0.12868782825535163, 0.12877259636297822, 0.1197840079839807, 0.1554439144092612, 0.16217804368352517, 0.19108742679236457, 0.24313088884809986, 0.1853309286525473, 0.20291101187467575, 0.091593669494614, 0.14589802507543936, 0.10230087151285261, 0.24792450974928215, 0.23734336893539876], [0.08354475881787948, 0.03034030320122838, 0.02534627274144441, 0.03636184454080649, 0.036261565546737984, 0.04031109805509914, 0.09387120197061449, 0.014864412733004428, 0.028092195025237743, 0.04971139285771642, 0.0481398320698645, 0.025678294769022614, 0.039921388888615184, 0.014868234793539159, 0.005985792085994035, 0.009097966103581712, 0.034223104812554084, 0.08773175562964752, 0.02857432384189451, 0.04927795263938606, 0.04020993219455704, 0.03919537179172039, 0.07207609844044782, 0.08960918145021424, 0.02564607628301019, 0.0465885170706315, 0.06865930248750374, 0.015851483985898085, 0.00832750549307093, 0.028058171265001874, 0.02620081497298088, 0.059479996998561546, 0.03371123813849408, 0.04012980993138626, 0.029533471788454335, 0.03483579966996331, 0.01638645557250129, 0.08628644529380836, 0.07072106294799596, 0.014504176106129307, 0.0492306258820463, 0.04255978325090837, 0.018286904669366777, 0.050520853328634985, 0.021862655667064246, 0.025815085573412944, 0.03840740391751751, 0.01658688925090246, 0.009521561732981354, 0.04638720209186431, 0.050687320763245225, 0.0244146974364412, 0.034805957911885343, 0.06545546581037343, 0.023571116726088803, 0.17693536821752787, 0.8601316425483674, 2.4029072234407067, 5.25509568862617, 8.660089652985334, 14.122413396835327, 22.033854871988297, 37.54974089562893, 51.66238121688366, 56.357755064964294, 68.3547905087471, 68.6637595295906, 63.724545165896416, 65.55328443646431, 55.364704951643944, 45.29322758316994, 52.73608960211277, 36.724049001932144, 33.091428726911545, 33.08157205581665, 20.877010747790337, 25.572200305759907, 21.18469163775444, 25.41116114705801, 14.920786656439304, 14.860143810510635, 17.82153770327568, 16.462020054459572, 14.103080984205008, 26.153924390673637, 21.30039732903242, 22.35832516103983, 27.449119091033936, 25.099097192287445, 31.642127595841885, 35.147373005747795, 36.43407516181469, 33.719690814614296, 36.39030531048775, 36.32421165704727, 37.45035342872143, 35.91126501560211, 23.53135261684656, 30.00909872353077, 34.86377902328968, 33.40230904519558, 48.335154354572296, 38.9611903578043, 39.40933831036091, 45.61659403145313, 58.66917483508587, 64.17664110660553, 65.51397174596786, 62.29765713214874, 68.23099315166473, 48.39688204228878, 34.41341198980808, 23.690742664039135, 12.227293588221073, 4.53522764146328, 0.7359360787086189, 0.498460162198171, 0.03350753344420809, 0.037456170975929126, 0.02100366426020628, 0.0301650357505423, 0.00952893033172586, 0.013283313492138404, 0.044692582087009214, 0.06580324363312684, 0.04130223627726082, 0.006848996572443866, 0.025072305215871893, 0.08446723353699781, 0.09585673644323833, 0.04988011271052528, 0.02667037922947202, 0.028265299115446396, 0.0024032520605032914, 0.034093626018147916, 0.04831868223845959, 0.009512283959338674, 0.023949680689838715, 0.020113740138185676, 0.014228197360353079, 0.04408973552926909, 0.08050965683651157, 0.033015730732586235, 0.11751438680221327, 0.07603254707646556, 0.03459509891399648, 0.09708899844554253, 0.021010154341638554, 0.01180173068860313, 0.013854237495252164, 0.06280127112404443, 0.10217507006018423, 0.07188777104602195, 0.03097246644756524, 0.02701987326872768, 0.02523553317587357, 0.021474328750628047, 0.08295025400002487, 0.02768185415334301, 0.03367687670106534, 0.04642768995836377, 0.011888376429851633, 0.021232728140603285, 0.04276696119632106, 0.03278039199358318, 0.03205909124517348, 0.0072948872457345715, 0.10486868763109669, 0.04701391240814701, 0.03466333568212576, 0.029953377088531852, 0.049974743960774504, 0.025038914136530366, 0.04534790219622664, 0.027619797619991004, 0.04538692061032634, 0.022883973324496765, 0.04981356061762199, 0.02551469387981342, 0.04926702080410905, 0.014693829161842586, 0.04268238233635202, 0.055918255893629976, 0.07282534104888327, 0.03311481857963372, 0.056668667384656146, 0.01608947404747596, 0.037699558306485415, 0.04239895242790226, 0.03693508311698679, 0.04719936398032587, 0.006896560817040154, 0.020810477653867565, 0.009699533384264214, 0.009556946406519273, 0.01591317315615015, 0.043348129620426334, 0.07255842021550052, 0.028970812527404632, 0.07374495107796974, 0.017953988353838213, 0.021243403934931848, 0.07584042730741203, 0.025866852229228243, 0.07424092837027274, 0.008229808245232562, 0.0171877394313924, 0.06178007221024018, 0.06724575607222505, 0.061358116727205925, 0.024653372129250783, 0.04480901392525993, 0.0033061027716030367, 0.06671532086329535, 0.03771006340684835, 0.06756837508874014, 0.04780711984494701, 0.09911616740282625, 0.02471327086823294, 0.06481607590103522, 0.05334620211215224, 0.048959612104226835, 0.019532378755684476, 0.01810338824725477, 0.047067135528777726, 0.009969870880013332, 0.026996816595783457, 0.04213277745293453, 0.07004535975283943, 0.01799268022296019, 0.05219636674155481, 0.09385676719830371, 1.1861280840821564, 3.5396497137844563, 7.027123477309942, 12.416947111487389, 22.659567296504974, 32.96737298369408, 48.927869349718094, 67.00647845864296, 68.82544845342636, 77.32590392231941, 79.58950325846672, 73.73200356960297, 73.67129042744637, 67.20903798937798, 57.89094999432564, 62.390854731202126, 47.221502512693405, 45.67811653017998, 42.854271456599236, 31.670443676412106, 41.1003577709198, 36.56923770904541, 37.52325251698494, 24.607688561081886, 30.14165461063385, 29.98113412410021, 29.9161272123456, 24.45065438747406, 40.31912349164486, 32.25285552442074, 36.728844344615936, 43.32276351749897, 38.82919304072857, 41.60571165382862, 40.43658658862114, 42.911853566765785, 44.52180437743664, 47.316797599196434, 46.86575420200825, 49.18250508606434, 45.9119825810194, 30.35994339734316, 38.632507994771004, 44.735402315855026, 44.26139295101166, 57.934887036681175, 48.28297935426235, 48.87681528925896, 53.39307814836502, 68.94195780158043, 72.48867228627205, 74.6706748008728, 71.76952287554741, 77.37530887126923, 58.53767529129982, 44.110784232616425, 31.32804974913597, 16.56671203672886, 6.973948180675507, 1.4970940165221691, 0.5755411041900516, 0.009764704154804349, 0.02853585461707553, 0.03740989064681344, 0.02226563072326826, 0.05542796716326848, 0.031099934021767695, 0.02493049749318743, 0.09876179930870421, 0.048250259933411144, 0.04240843336447142, 0.028572869232448284, 0.07196370759629644, 0.061921369706396945, 0.02431019562209258, 0.04803414652997162, 0.030795193342783023, 0.011185559797013411, 0.029510596941690892, 0.03015274207427865, 0.048183574253926054, 0.05160635191714391, 0.01737317244987935, 0.03527330314682331, 0.1000722317257896, 0.02853509762644535, 0.0532727999961935, 0.08855879757902585, 0.026403066913189832, 0.010080166084662778, 0.023008934294921346, 0.03328701539430767, 0.030724242169526406, 0.07739184249658138, 0.04427530584507622, 0.04912671407510061, 0.016716214049665723, 0.057317849932587706, 0.018416509628877975, 0.012226117632962996, 0.009271542385249631, 0.042059186089318246, 0.018240080717077944, 0.02833716498571448, 0.056254092560266145, 0.04495074928854592, 0.04716213414212689, 0.024493135024385992, 0.0415742853510892, 0.10135219898074865, 0.010874644449359039, 0.0071226482214115094, 0.020779691512871068, 0.06836432847194374, 0.07219084931421094, 0.027642531458695885, 0.022137144551379606, 0.03278688578575384, 0.03156344791932497, 0.05647664409480058, 0.18601081013912335, 0.12214384463732131, 0.11632233436102979, 0.13205860363086686, 0.14175722695654258, 0.12540379510028288, 0.23598442232469097, 0.09602889986126684, 0.17030812305165455, 0.09150946541922167, 0.16665469331201166, 0.11742739225155674, 0.10132679526577704, 0.1496077244519256, 0.224559563503135, 0.10964970686472952, 0.16168702393770218, 0.1523646991699934, 0.10231181819108315, 0.11544744615093805, 0.1886865048436448, 0.20568275533150882, 0.14405119058210403, 0.22540832811500877, 0.1570797266322188, 0.14882309624226764, 0.22983443748671561, 0.06724830906023271, 0.17355604330077767, 0.10455538998940028, 0.059522570300032385, 0.0728605262702331, 0.2629359456477687, 0.13469613710185513, 0.1665455976035446, 0.10258460199111141, 0.09403093441505916, 0.1749107299838215, 0.10710128306527622, 0.14480687503237277, 0.20111391611862928, 0.17335603450192139, 0.10153905692277476, 0.13510136457625777, 0.12272366235265508, 0.111015496077016, 0.1395922337542288, 0.08485105005092919, 0.1883408272988163, 0.10622727058944292, 0.12146307999501005, 0.18457957834471017, 0.09868557332083583, 0.11203475427464582, 0.1988880371209234, 0.47873310511931777, 1.5444859047420323, 5.215310398489237, 9.629004411399364, 15.506221242249012, 27.21478756517172, 39.34253789484501, 55.385261848568916, 79.02272567152977, 79.05844375491142, 88.70360299944878, 87.52043008804321, 87.03489974141121, 88.77764582633972, 80.43634861707687, 67.56159827113152, 73.5648201406002, 55.67218065261841, 50.55308394134045, 51.19645781815052, 36.76228255033493, 40.97005896270275, 37.333513498306274, 43.61709952354431, 27.324119098484516, 27.701613642275333, 31.461648680269718, 28.302017524838448, 24.75013341754675, 41.54265023767948, 35.913883075118065, 36.292118579149246, 43.5189013928175, 41.34404629468918, 48.80441777408123, 53.66384021937847, 53.170068114995956, 52.0090252161026, 53.894997015595436, 54.52663332223892, 56.97658985853195, 53.85834418237209, 39.78017941117287, 45.876731872558594, 52.30724461376667, 48.89751277863979, 64.78495806455612, 58.11161555349827, 58.20976808667183, 65.07938906550407, 78.78780707716942, 83.84179428219795, 85.28440967202187, 81.82859390974045, 84.66776356101036, 69.67830508947372, 51.704395562410355, 35.93104675412178, 19.5293028652668, 8.448405861854553, 2.0544761326164007, 0.9300962195266038, 0.13461424852721393, 0.18020319286733866, 0.08698167439433746, 0.0873199081979692, 0.19894314900739118, 0.1444032951258123, 0.06000576038786676, 0.14874675893224776, 0.1109138886386063, 0.10908427197136916, 0.09972219777409919, 0.15993039007298648, 0.2450518638943322, 0.15999477880541235, 0.24959892849437892, 0.1476832464686595, 0.09142295326455496, 0.10816053560120054, 0.15036164259072393, 0.14664679270936176, 0.156986067595426, 0.14016543893376365, 0.22835094365291297, 0.18454447475960478, 0.14755092153791338, 0.10377146682003513, 0.22449562005931512, 0.11759776709368452, 0.08974395546829328, 0.15331844799220562, 0.1419855561107397, 0.14771946327527985, 0.13921229867264628, 0.15879594313446432, 0.24712171376449987, 0.11525355264893733, 0.09564763633534312, 0.13153194595361128, 0.1314312216709368, 0.10815194895258173, 0.16740175400627777, 0.05581402867392171, 0.13083331781672314, 0.13021463382756338, 0.11812721524620429, 0.11054756454541348, 0.1522138502332382, 0.1142553862882778, 0.09440446476219222, 0.13066531042568386, 0.19548304873751476, 0.09188428710331209, 0.12062597452313639, 0.13766477233730257, 0.08341874956386164, 0.06999735764111392, 0.13029208435909823, 0.24498613929608837, 0.1560883954516612], [0.057636817582533695, 0.032715101551730186, 0.04094668816833291, 0.06246968696359545, 0.05836342097609304, 0.024461671673634555, 0.04160548895015381, 0.055764022763469256, 0.07002417885814793, 0.02605265075544594, 0.007327468920266256, 0.019485612319840584, 0.0389203578379238, 0.043624338431982324, 0.015388101819553412, 0.045144464675104246, 0.028260412072995678, 0.03405414005101193, 0.007408199744531885, 0.03542483857017942, 0.04468884908419568, 0.06649119226494804, 0.08504474317305721, 0.017185757897095755, 0.034701207478065044, 0.027202033415960614, 0.055738945593475364, 0.035690304794115946, 0.0303284139954485, 0.04945190834405366, 0.04471227126487065, 0.029917715037299786, 0.031991923169698566, 0.04835970074054785, 0.01775383854692336, 0.017552532845002133, 0.048239658353850245, 0.03735637066711206, 0.04848731303354725, 0.05503543412487488, 0.04327075701439753, 0.07621023949468508, 0.040074211938190274, 0.039542804515804164, 0.028064379330317024, 0.050336737622274086, 0.07351929365540855, 0.03864014885039069, 0.021382667946454603, 0.09095099929254502, 0.017563687324582133, 0.09526665482553653, 0.724233181681484, 1.422293724026531, 1.6007929458282888, 4.661635933443904, 11.670334674417973, 15.942168049514294, 25.661909691989422, 34.18288975954056, 56.34133234620094, 62.185145169496536, 72.78620392084122, 62.32019752264023, 65.05712226033211, 56.531360149383545, 53.998944237828255, 52.295320853590965, 44.960962012410164, 40.252995640039444, 37.578832134604454, 35.2895537763834, 31.838831640779972, 13.507548440247774, 14.312116317451, 13.567771408706903, 18.166365399956703, 15.966258756816387, 16.039237640798092, 18.096975423395634, 16.396673060953617, 19.94205191731453, 19.61109157651663, 20.71818307042122, 14.918589424341917, 22.985278218984604, 12.680525667965412, 15.167547315359116, 17.507636547088623, 19.23451278358698, 17.865980118513107, 36.41458980739117, 29.81269296258688, 19.88533616065979, 17.38707471638918, 9.91198567673564, 12.925372179597616, 11.183259710669518, 22.252291850745678, 27.484618686139584, 29.01046670973301, 21.92540679126978, 25.035830587148666, 25.357945002615452, 31.91542223095894, 40.73425881564617, 41.23472236096859, 46.43578067421913, 70.36002650856972, 61.49143539369106, 64.28626522421837, 60.90996779501438, 54.03017856180668, 43.03007282316685, 32.26701356470585, 19.30769495666027, 6.299297707155347, 3.1944104516878724, 0.9876099333632737, 0.4252028837800026, 0.07356483183684759, 0.044906732509844005, 0.030808470364718232, 0.04273007645679172, 0.02717393570492277, 0.05054297675087582, 0.023772515196469612, 0.019645220454549417, 0.04077147081261501, 0.06748208557837643, 0.056803504485287704, 0.028923626778123435, 0.07178274230682291, 0.03946288263250608, 0.027513844906934537, 0.0804983390844427, 0.06214576918864623, 0.036120082513662055, 0.030350875094882213, 0.019614029843069147, 0.04331346390245017, 0.012831436470150948, 0.031929115211823955, 0.0759629781532567, 0.0017309448867308674, 0.051569634160841815, 0.09847343040746637, 0.027159979617863428, 0.07133007675292902, 0.03334177476062905, 0.06258185516344383, 0.023978494573384523, 0.10123458341695368, 0.0686308262811508, 0.06569978824700229, 0.011716023764165584, 0.13594450370874256, 0.04388945584651083, 0.020522129161690827, 0.0352756075153593, 0.04304560425225645, 0.037978097461746074, 0.06277243126532994, 0.03714105878316332, 0.0848543006577529, 0.03008171854162356, 0.033714499877532944, 0.03473086740996223, 0.01581698154041078, 0.07776399244903587, 0.06603228524909355, 0.0275802708347328, 0.050047363110934384, 0.04402184014907107, 0.03522877428622451, 0.007986419059307082, 0.05653538137266878, 0.038245701070991345, 0.041673840751172975, 0.007314401555049699, 0.005866899100510636, 0.04785492528753821, 0.006534355643452727, 0.03290070155344438, 0.01952440808963729, 0.011056975290557602, 0.039860510514699854, 0.028183451358927414, 0.03307184451841749, 0.019263843751105014, 0.03573235488147475, 0.03321981021144893, 0.013290552215039497, 0.044702912782668136, 0.008226325717259897, 0.06241775889066048, 0.07134457089705393, 0.05701875328668393, 0.04227687655657064, 0.047524498877464794, 0.0023801868064765586, 0.10182571888435632, 0.06001617271977011, 0.014952987130527617, 0.03558995158527978, 0.0624739023623988, 0.03392794154933654, 0.007609902959302417, 0.03398106819076929, 0.05010154731280636, 0.037837107956875116, 0.041758360239327885, 0.00673365522743552, 0.055381222991854884, 0.05035003319790121, 0.02974209692183649, 0.017505985342722852, 0.0469033435365418, 0.0429657640052028, 0.017799879533413332, 0.044196623348398134, 0.03926054348994512, 0.036781681192223914, 0.07022331934422255, 0.07109372498234734, 0.04550603531242814, 0.0520362891984405, 0.06489561186754145, 0.7261447166092694, 1.76440219162032, 2.05944056622684, 6.494800066575408, 13.499642014503479, 19.502717591822147, 33.88907052576542, 43.57080280780792, 68.67662563920021, 74.24598678946495, 82.77495592832565, 70.63674286007881, 73.66997569799423, 67.51453399658203, 64.54068437218666, 60.69651044905186, 57.08958059549332, 49.928063079714775, 44.88876208662987, 43.24826471507549, 40.73651969432831, 24.966723695397377, 28.424503952264786, 25.120594538748264, 27.387302108108997, 23.621650971472263, 32.477077692747116, 21.176309287548065, 26.336692683398724, 25.772567354142666, 27.410767748951912, 26.852021031081676, 24.21578709036112, 31.212613843381405, 16.555673629045486, 22.77405135333538, 23.601234667003155, 31.536029689013958, 29.606645219027996, 49.456804767251015, 36.12956330180168, 23.516829796135426, 28.305401243269444, 22.899999395012856, 29.017882011830807, 20.028989352285862, 30.81762693822384, 39.56484496593475, 35.914415046572685, 32.20683239400387, 36.73417165875435, 36.37857913970947, 39.574929624795914, 50.02960883080959, 47.94213004410267, 54.82084393501282, 76.19911998510361, 68.99433419108391, 69.6541079878807, 70.02874508500099, 61.377791091799736, 50.82996368408203, 41.05841562151909, 26.49012465029955, 9.985311292111874, 5.178928300738335, 1.130831551272422, 0.6178342597559094, 0.1413335051620379, 0.03557686010026373, 0.0771886647271458, 0.056018646209849976, 0.055142930505098775, 0.05584558479313273, 0.03729351446963847, 0.009657953632995486, 0.04168548504821956, 0.03466419286269229, 0.026846106811717618, 0.024159736312867608, 0.040194443572545424, 0.01077122617061832, 0.059922821674263105, 0.054649060912197456, 0.07227654510643333, 0.04060923361976165, 0.0405610199959483, 0.1585254303063266, 0.012751620342896786, 0.05553440598305315, 0.07019923665211536, 0.029147391724109184, 0.024861577949195635, 0.05434273574792314, 0.03224514395697042, 0.006417166814571829, 0.05847339241881855, 0.028259488099138252, 0.03543716564308852, 0.03199009377567563, 0.10743447026470676, 0.05749344207288232, 0.04742279495985713, 0.015548910378129221, 0.06692345617921092, 0.02507449269614881, 0.04417606214701664, 0.06297908970736898, 0.03040576062630862, 0.03968444339989219, 0.14766742388019338, 0.02668648012331687, 0.04891167307505384, 0.05822019389597699, 0.056517287812312134, 0.07774616606184281, 0.024536845667171292, 0.022947419529373292, 0.0898373473319225, 0.050647270763874985, 0.05842934966494795, 0.01191893436043756, 0.08272491570096463, 0.028519855768536218, 0.15644036640878767, 0.12498182477429509, 0.13239016552688554, 0.12172813061624765, 0.09800163228646852, 0.12805890262825415, 0.12344369402853772, 0.23469014646252617, 0.16552049870369956, 0.07205812362371944, 0.11491452474729158, 0.09570581329171546, 0.16254070156719536, 0.1477620328660123, 0.07092182873748243, 0.1401521693333052, 0.12991897703614086, 0.15320485486881807, 0.08949926937930286, 0.15349386201705784, 0.20252279442502186, 0.14045054238522425, 0.15459129062946886, 0.10189505774178542, 0.09504778805421665, 0.19200573064154014, 0.11308311950415373, 0.09845930733717978, 0.10784723053802736, 0.1368368769180961, 0.07618459829245694, 0.10001391376135871, 0.11098518676590174, 0.14006735669681802, 0.11771886333008297, 0.08710167967365123, 0.20900287170661613, 0.08282577357022092, 0.24642133415909484, 0.10644048961694352, 0.08076402053120546, 0.13850663497578353, 0.08664242384838872, 0.06957607009098865, 0.1631186861777678, 0.09334650356322527, 0.21027713926741853, 0.17260410531889647, 0.16558089468162507, 0.15739690570626408, 0.3136899112723768, 0.3231329983100295, 1.3096338068135083, 2.938384464941919, 3.3813642198219895, 9.342891164124012, 17.108388170599937, 25.201247110962868, 41.964097023010254, 54.091032296419144, 77.89804682135582, 87.18621522188187, 94.53110709786415, 81.08130320906639, 83.40062275528908, 80.05076050758362, 75.35669758915901, 70.8438241481781, 65.75088903307915, 58.72739151120186, 55.00704914331436, 50.76046921312809, 46.20723053812981, 26.27373956143856, 28.624177537858486, 25.327045060694218, 30.503837876021862, 27.124185226857662, 28.81197866052389, 28.58653485774994, 25.778305046260357, 30.113093443214893, 28.18151269108057, 31.822663508355618, 25.456517413258553, 36.92619435489178, 22.331549897789955, 26.57409444451332, 28.28926920890808, 31.495208479464054, 31.756030283868313, 53.47619108855724, 42.88612134754658, 33.68224002420902, 31.322281658649445, 20.452341735363007, 26.42013430595398, 24.118303321301937, 36.88313886523247, 42.321631237864494, 39.98346470296383, 35.6070951372385, 39.88718926906586, 38.335755318403244, 49.59856756031513, 57.16038979589939, 59.76646475493908, 64.52452763915062, 87.22178131341934, 78.49402204155922, 81.79258704185486, 79.67372953891754, 72.34083741903305, 60.246105417609215, 49.024691954255104, 31.761313900351524, 13.048222437500954, 6.489176843315363, 1.8780747544951737, 0.9568661393132061, 0.2961599675472826, 0.18092509475536644, 0.14066208415897563, 0.1078098188736476, 0.21597934188321233, 0.32396061171311885, 0.08935172299970873, 0.057253297927672975, 0.07703676936216652, 0.19647521112347022, 0.15517782478127629, 0.1120875432388857, 0.18355013045948, 0.10712587783928029, 0.11067000406910665, 0.22434168378822505, 0.16953437472693622, 0.07299331875401549, 0.14126604393823072, 0.23224042088259012, 0.13124443794367835, 0.2440896545886062, 0.18794432748109102, 0.08503373712301254, 0.10095655263285153, 0.07225468143587932, 0.20380872854730114, 0.07189635769464076, 0.1758174563292414, 0.14526786748319864, 0.12693196622421965, 0.1538455212721601, 0.24162983580026776, 0.19714232767000794, 0.184481481264811, 0.10182963742408901, 0.25065105641260743, 0.14789711858611554, 0.19713552959728986, 0.16811302833957598, 0.12269876329810359, 0.08398224745178595, 0.2724506350932643, 0.11172098165843636, 0.1832004898460582, 0.1537247293163091, 0.14927819604054093, 0.15209783770842478, 0.09355895817861892, 0.1732294834800996, 0.16426064365077764, 0.1688170593115501, 0.14916589425411075, 0.12058645515935495, 0.14560664305463433, 0.1151356402260717], [0.04566744129988365, 0.012098260431230301, 0.06264461859245785, 0.07089490361977369, 0.02063923078821972, 0.0802244123769924, 0.04697624099208042, 0.019792356797552202, 0.037567162871710025, 0.01928177589434199, 0.02670988003956154, 0.002151349513042078, 0.020603583579941187, 0.02390901656326605, 0.032276670390274376, 0.09062014985829592, 0.0041995822448370745, 0.07938416762044653, 0.04899585859675426, 0.04756127229484264, 0.06101412756834179, 0.03609619649068918, 0.01159863919383497, 0.019332917290739715, 0.037987682298989967, 0.05119073437526822, 0.03917753798305057, 0.05965912547253538, 0.058999782922910526, 0.025243281197617762, 0.014379036092577735, 0.020021587661176454, 0.036236573723726906, 0.03449793322943151, 0.0594450826611137, 0.01539402694106684, 0.033377709551132284, 0.05344022480130661, 0.027621645567705855, 0.031106743226700928, 0.05261983991658781, 0.0046629815733467694, 0.024610123473394196, 0.04665530665079132, 0.03532060763973277, 0.11026269115973264, 0.033328846548101865, 0.05934120425081346, 0.1743647616240196, 1.220302500296384, 1.7488267086446285, 4.392588520422578, 7.072841674089432, 7.714421572163701, 17.171882763504982, 32.34129957854748, 34.480953365564346, 46.7363141477108, 63.65931786596775, 61.89584769308567, 69.53968852758408, 58.76092091202736, 54.00099992752075, 46.84281103312969, 50.50656683743, 39.16450224816799, 32.00823985040188, 30.01013796776533, 29.70444817095995, 17.061211802065372, 26.740308925509453, 54.579416289925575, 17.902289070189, 12.686300408095121, 14.23585345968604, 12.008866108953953, 42.740376368165016, 38.59364368021488, 16.397750303149223, 35.36831974983215, 40.8292119204998, 43.45889501273632, 41.8768423050642, 40.19824057817459, 32.47605174779892, 31.819828860461712, 35.54616920650005, 35.78319288790226, 33.649200797080994, 26.894502751529217, 14.636246524751186, 14.442715309560299, 47.74777427315712, 29.034428223967552, 27.972499206662178, 24.10556450486183, 19.943507239222527, 17.158114202320576, 15.259551778435707, 14.772221278399229, 22.559849247336388, 29.909469969570637, 20.092892423272133, 18.83925799280405, 19.939509853720665, 28.113027065992355, 25.993267111480236, 28.536725230515003, 36.00144177675247, 47.71030068397522, 44.81333613395691, 50.72991885244846, 57.38846115767956, 58.16858969628811, 56.59759059548378, 52.2550468146801, 44.31245841085911, 32.621344551444054, 12.62388875707984, 8.089910298585892, 2.9663953743875027, 0.8656427124515176, 0.14877062640152872, 0.052976126462453976, 0.010842279389180476, 0.04380945232696831, 0.012536751892184839, 0.012199491229694104, 0.09376914182212204, 0.08650163843412884, 0.020430420117918402, 0.053696837203460746, 0.06444498721975833, 0.026541310471657198, 0.026432322374603245, 0.07684021897148341, 0.011599418448895449, 0.10303248069249094, 0.049874286851263605, 0.08495571513776667, 0.057858645523083396, 0.030552802345482633, 0.04764169883856084, 0.048128744383575395, 0.03464482280833181, 0.015464928019355284, 0.040577436302555725, 0.03652099439932499, 0.023951550901983865, 0.07787656140862964, 0.0326165443402715, 0.06573598278919235, 0.023108402492653113, 0.0646221156057436, 0.01684010261669755, 0.03776774312427733, 0.020217861601850018, 0.03142306326481048, 0.03366020064277109, 0.02604118828458013, 0.04487100180995185, 0.030599956553487573, 0.06644884531851858, 0.038487414858536795, 0.061744322956656106, 0.04975545787601732, 0.024761586537351832, 0.1432217811816372, 0.025276230699091684, 0.0027114785143567133, 0.06408129775081761, 0.027925198810407892, 0.0547607281623641, 0.05191533397010062, 0.017509716490167193, 0.05680968657543417, 0.050301596929784864, 0.040659246951690875, 0.02983498041430721, 0.03359032372827642, 0.03183646549587138, 0.0867919740267098, 0.116721060621785, 0.08026381299714558, 0.04661560175009072, 0.08307630036142655, 0.015938057367748115, 0.012264625820535002, 0.045838758669560775, 0.023374668380711228, 0.03876326743920799, 0.12432533578248695, 0.055552889170940034, 0.08370962692424655, 0.05513478914508596, 0.04062457381223794, 0.09465396738960408, 0.0299422560055973, 0.05330980719008949, 0.0483893680939218, 0.07454373946529813, 0.07899218748207204, 0.057070948532782495, 0.06154212482215371, 0.04687017324613407, 0.022545463070855476, 0.0513507302821381, 0.035347799930605106, 0.0019689168584591243, 0.0240695950560621, 0.06210942621692084, 0.022076926688896492, 0.0589165510609746, 0.01457838159694802, 0.007722902364548645, 0.02261572404677281, 0.022411908030335326, 0.021017841136199422, 0.03498381360259373, 0.030937750634620897, 0.07413117957185023, 0.04377195531560574, 0.018339975649723783, 0.07486028771381825, 0.28535370365716517, 1.6241310560144484, 2.34707064460963, 5.252496153116226, 8.81759975105524, 9.800017084926367, 21.65790304541588, 38.12018908560276, 40.25392659008503, 59.31327827274799, 75.51984563469887, 71.70944049954414, 77.9006838798523, 67.78643980622292, 61.81608237326145, 59.226137548685074, 60.653272569179535, 51.5979290753603, 43.13652031123638, 40.45066103339195, 40.42487181723118, 32.10940942168236, 40.35497836768627, 61.290931552648544, 33.13648670911789, 25.100419521331787, 24.69154056161642, 17.972129322588444, 52.797954082489014, 41.421068161726, 26.931484267115593, 40.04736587405205, 35.05444899201393, 42.331810891628265, 32.99694299697876, 34.16063815355301, 23.093334920704365, 33.92483800649643, 25.105089470744133, 31.362895779311657, 29.113874360919, 26.165422573685646, 17.22934328019619, 18.21970123797655, 40.44054977595806, 32.24180951714516, 23.489319272339344, 17.68709521740675, 14.027398545295, 14.113851506263018, 16.92525889724493, 23.233015425503254, 23.17693993449211, 31.740895695984364, 24.827502965927124, 22.43384040892124, 29.62567839771509, 37.227962762117386, 38.36585350334644, 37.24608778953552, 42.885209396481514, 55.485101491212845, 52.525968477129936, 57.191228941082954, 64.43947300314903, 65.92506408691406, 64.87417727708817, 59.51375551521778, 55.656837075948715, 41.467072293162346, 18.642443753778934, 11.157027818262577, 4.024861352518201, 1.3666181615553796, 0.30357512121554464, 0.036017317324876785, 0.05611824613879435, 0.015546259055554401, 0.03275125898653641, 0.04113362403586507, 0.11084511381341144, 0.04539685425697826, 0.023954500938998535, 0.05262425940600224, 0.05089986072562169, 0.06393501302227378, 0.020494365417107474, 0.0587824969261419, 0.020042326978000347, 0.10016236556111835, 0.05936987712630071, 0.025342278131574858, 0.030202896414266434, 0.03840246492472943, 0.017069268542400096, 0.08520667979610153, 0.04596630788000766, 0.019076627722824924, 0.05302860001393128, 0.04034824996779207, 0.13475442538037896, 0.052737073274329305, 0.03587089529901277, 0.0937157888256479, 0.01839853110141121, 0.030172600090736523, 0.10898461638134904, 0.03611092812207062, 0.018942337956104893, 0.04493595457461197, 0.05040935306169558, 0.06228299971553497, 0.08318812717334367, 0.011646209004538832, 0.023869122414907906, 0.011400201892683981, 0.053119398071430624, 0.013079542932246113, 0.03188557340763509, 0.06005881281453185, 0.047414712971658446, 0.013312186747498345, 0.03624548691732343, 0.0520072526705917, 0.012612215323315468, 0.034847570132114924, 0.03667222183139529, 0.03805937376455404, 0.20559127820888534, 0.1759189969743602, 0.1655276381643489, 0.10858958601602353, 0.08691739698406309, 0.2691757451975718, 0.11570529051823542, 0.17969442094909027, 0.10342304332880303, 0.11981876275967807, 0.06521751100081019, 0.14746288798050955, 0.0984943589719478, 0.06957179532037117, 0.13186463591409847, 0.2176070646964945, 0.09174053309834562, 0.20488456066232175, 0.1753857044968754, 0.15897532022790983, 0.22747038543457165, 0.15609128982760012, 0.13012110837735236, 0.14124452165560797, 0.1684205891797319, 0.18463994463672861, 0.12094057092326693, 0.23492442764109, 0.16470400267280638, 0.11788569812779315, 0.07866527143050916, 0.21706759755034, 0.12240739612025209, 0.18242208083393052, 0.1718693642760627, 0.06952878786250949, 0.13284096086863428, 0.15536060091108084, 0.12546145997475833, 0.08280120848212391, 0.1294900750508532, 0.1355919093475677, 0.0782351077941712, 0.10633662604959682, 0.13024651649175212, 0.36205558630172163, 0.1795943349134177, 0.2139274074579589, 0.7650814647786319, 2.549154250882566, 3.7520317174494267, 7.054602177813649, 11.800991613417864, 13.378070387989283, 28.934941962361336, 45.233559384942055, 49.47226233780384, 70.03773540258408, 86.98233336210251, 83.71881768107414, 86.20226562023163, 77.96875342726707, 71.90565437078476, 68.85289058089256, 71.54245465993881, 58.96295987069607, 49.29353132843971, 47.69344098865986, 44.793653190135956, 32.32746072113514, 43.03199551999569, 67.95058339834213, 28.5984206199646, 22.022793665528297, 25.6238167360425, 19.894448071718216, 55.79929523169994, 50.82672245800495, 29.780157208442688, 52.57938601076603, 55.1069799810648, 61.96539916098118, 57.119617983698845, 57.87429928779602, 46.80710054934025, 51.37092925608158, 54.980572164058685, 56.474724188447, 51.76266923546791, 43.40376377105713, 27.98831395804882, 28.423905484378338, 63.84592965245247, 41.97452746331692, 40.93819387257099, 38.51913347840309, 31.819669269025326, 31.759841479361057, 27.167459204792976, 24.043346643447876, 34.03109550476074, 44.016370698809624, 30.79699594527483, 33.17048728466034, 33.296024948358536, 44.27316091954708, 43.09556990861893, 43.8698011636734, 50.66441796720028, 64.47884649038315, 64.30754408240318, 69.26768392324448, 78.15014809370041, 76.22539177536964, 74.59874466061592, 69.66144919395447, 65.25656595826149, 49.998902678489685, 22.700736187398434, 13.543620854616165, 5.079536559060216, 2.0363223692402244, 0.534663253929466, 0.129331344505772, 0.20595755777321756, 0.14404534245841205, 0.15941525052767247, 0.1354373645153828, 0.25589786237105727, 0.165313380130101, 0.14456542470725253, 0.18019376759184524, 0.16978099039988592, 0.14798993157455698, 0.13724652759265155, 0.15972005057847127, 0.13924058934208006, 0.20151096512563527, 0.14622985414462164, 0.16650195932015777, 0.1211635788786225, 0.1435406820382923, 0.16730444360291585, 0.23098212433978915, 0.14458031218964607, 0.1827548598521389, 0.11302561790216714, 0.0955284177325666, 0.15823106485186145, 0.1464183151256293, 0.1604650926310569, 0.1716686281724833, 0.1666378614027053, 0.16409110743552446, 0.14035801141289994, 0.10850488470168784, 0.09940904114046134, 0.17780702066374943, 0.1205799613671843, 0.31697860511485487, 0.11834312084829435, 0.11971750413067639, 0.16543794219614938, 0.1145479928527493, 0.14918401750037447, 0.11091279026004486, 0.12011137674562633, 0.18130609852960333, 0.09100185867282562, 0.054583911478403024, 0.12191153015010059, 0.11642937432043254, 0.1279163805884309, 0.1411600355640985, 0.1322750435792841, 0.09891990644973703], [0.028497316743596457, 0.047033683222252876, 0.02666487063834211, 0.11935966278542764, 0.03888545463269111, 0.020406265066412743, 0.04477767302887514, 0.029934298327134456, 0.05393312960222829, 0.05399897294410039, 0.02264070659293793, 0.016971394106803928, 0.02398120897851186, 0.07509848001063801, 0.0652293482562527, 0.06069557181035634, 0.02751595817244379, 0.009446589047001908, 0.037172822703723796, 0.007210257826955058, 0.007125477659428725, 0.084217189141782, 0.04764240758959204, 0.007032588600850431, 0.014622627513745101, 0.0392650409048656, 0.032762253904365934, 0.040887750510592014, 0.02381842816248536, 0.11699253824190237, 0.044327790528768674, 0.007354852314165328, 0.0364852711209096, 0.06841879468993284, 0.039601745884283446, 0.03533930976118427, 0.017136813257820904, 0.0678561205859296, 0.020841209989157505, 0.10063136578537524, 0.05597530478553381, 0.10893428392591886, 0.019075755699304864, 0.04791992629179731, 0.04656649754906539, 0.017968473221117165, 0.1291586912702769, 0.7057417114265263, 4.136216752231121, 9.86138379201293, 14.333724807947874, 20.08642517030239, 30.552296675741673, 36.536244079470634, 42.91620433330536, 52.65253208577633, 63.69977429509163, 68.08837160468102, 66.17859408259392, 60.55404469370842, 47.01437182724476, 51.39239810407162, 47.239980921149254, 35.51234342157841, 38.42934049665928, 17.741808481514454, 20.09141430258751, 8.434126228094101, 12.476088088005781, 10.59839129447937, 8.075829204171896, 13.89438858255744, 16.333395056426525, 22.37050350755453, 27.61785663664341, 34.49771046638489, 33.31427916884422, 34.82802674174309, 49.32960279285908, 35.215142369270325, 53.28833296895027, 42.245449125766754, 45.1135466247797, 40.06851553916931, 31.02087613195181, 26.14987190812826, 24.330552332103252, 30.678601898252964, 22.809248864650726, 36.14587962627411, 43.86439025402069, 45.30715763568878, 38.583312034606934, 31.02789055556059, 37.87142403423786, 52.3239067196846, 56.97182111442089, 40.109234154224396, 47.05586940050125, 32.664650827646255, 61.775344759225845, 45.32443530857563, 33.65243822336197, 44.645472541451454, 31.25465288758278, 33.04004408419132, 15.481638461351395, 29.652128778398037, 31.891145333647728, 29.044368490576744, 30.749002620577812, 42.79754810035229, 37.09572225809097, 46.789784878492355, 54.383301213383675, 61.33676089346409, 58.96455958485603, 54.812704771757126, 49.390775710344315, 34.084076061844826, 22.377350740134716, 14.090515058487654, 3.8080855971202254, 1.0790872341021895, 0.06492749453173019, 0.05391895829234272, 0.040955389849841595, 0.10171122034080327, 0.012101572265237337, 0.03126825868093874, 0.04756200702104252, 0.04435101604030933, 0.02676658012205735, 0.07641568081453443, 0.0282629743378493, 0.044129399611847475, 0.11353067166055553, 0.01880551932117669, 0.018763972038868815, 0.07301828460185789, 0.038513052350026555, 0.01939786263392307, 0.09735479863593355, 0.07002843136433512, 0.02254532020742772, 0.039969532008399256, 0.07391034610918723, 0.021700769138988107, 0.01930355792865157, 0.06731827874318697, 0.044398446698323824, 0.01475606566600618, 0.04542936403595377, 0.031775190072949044, 0.04431415356521029, 0.12262091942830011, 0.05656475557771046, 0.030558780345018022, 0.0037171459007367957, 0.067214073787909, 0.02016816182731418, 0.04312250930524897, 0.09074465997400694, 0.07599362885230221, 0.025056835147552192, 0.051072276473860256, 0.029212322224339005, 0.06550492995302193, 0.055071057213353924, 0.04568636235489976, 0.03836669711745344, 0.006445582721426035, 0.13871503004338592, 0.03358353678777348, 0.033478363329777494, 0.01454798786653555, 0.0580259181879228, 0.08518348768120632, 0.05791223971755244, 0.03969463308749255, 0.022729042575519998, 0.007904971134848893, 0.05816258839331567, 0.03183302193065174, 0.08903507085051388, 0.031796066687093116, 0.03726138318597805, 0.016777237142378, 0.03938236703106668, 0.06182401848491281, 0.030641819248558022, 0.07842567647458054, 0.019916857636417262, 0.042430126341059804, 0.07200053296401165, 0.008202065837394912, 0.022437478728534188, 0.06226218247320503, 0.10133426869288087, 0.09799746141652577, 0.016665985494910274, 0.04630186995200347, 0.016585648008913267, 0.029348747520998586, 0.06656267592916265, 0.043705807693186216, 0.0617799126484897, 0.02629897884617094, 0.022697319473081734, 0.05893929788726382, 0.026139756628253963, 0.011805228059529327, 0.008667448091728147, 0.04299276333767921, 0.007943174114188878, 0.15169274382060394, 0.054891416657483205, 0.02229155579698272, 0.07219276405521668, 0.026661592200980522, 0.03808750487223733, 0.08105224842438474, 0.09117091249208897, 0.9000205958727747, 4.785811370238662, 11.192693654447794, 17.514250092208385, 24.47382364422083, 37.4956925958395, 44.013748839497566, 49.95559640228748, 64.08844023942947, 73.90991762280464, 78.52946653962135, 75.11185392737389, 69.06568676233292, 55.062894746661186, 63.4825399518013, 55.391341522336006, 46.42581760883331, 49.75758142769337, 32.13274396955967, 29.87645924091339, 20.613166205585003, 24.548451639711857, 18.69055487215519, 15.623927526175976, 26.26424577087164, 22.522096373140812, 21.742556802928448, 27.385516203939915, 29.59269616752863, 36.40687242150307, 31.82384144514799, 36.26802787184715, 34.62953679263592, 40.11164702475071, 35.472810342907906, 31.33271399885416, 26.602756306529045, 22.698471508920193, 21.037371642887592, 21.30084380507469, 22.00010508298874, 20.282188765704632, 22.730203606188297, 25.342151150107384, 28.11893954873085, 36.87235504388809, 30.479407086968422, 41.55644349753857, 41.92834474146366, 54.291881918907166, 44.493693485856056, 42.787034064531326, 23.653656654059887, 54.3365865200758, 56.54523320496082, 35.707546547055244, 42.74723879992962, 38.36553052067757, 45.40823221206665, 25.82742501050234, 33.406944796442986, 38.8424239307642, 39.099985510110855, 42.11340241134167, 53.39498184621334, 45.85699953138828, 52.99158789217472, 63.28032620251179, 66.91375583410263, 67.53444492816925, 61.06609761714935, 60.214669704437256, 44.76072035729885, 30.119629092514515, 19.002227447926998, 5.319747319445014, 1.5460213785991073, 0.06814328720793128, 0.05767411792476196, 0.022767506234231405, 0.052538441159413196, 0.026627030383679084, 0.07825607346603647, 0.00928545023270999, 0.0174840641557239, 0.06810501465224661, 0.039021108095766976, 0.019839206725009717, 0.03240851663576905, 0.05442763002065476, 0.03700691187987104, 0.044159831377328373, 0.04734883252240252, 0.02693251135497121, 0.04329077644797508, 0.10292751132510602, 0.1295755704632029, 0.06230985061847605, 0.0639653074904345, 0.07801348765497096, 0.012025704363622935, 0.04378495032142382, 0.03364712028997019, 0.052476449563982897, 0.04308959505578969, 0.03476741076156031, 0.020417131963768043, 0.06652542753727175, 0.04130739049287513, 0.028570056492753793, 0.03749262155906763, 0.03341341798659414, 0.03171338772517629, 0.0456221480271779, 0.021650442249665502, 0.03255575131333899, 0.03997454892669339, 0.004179634706815705, 0.025280720692535397, 0.051939943587058224, 0.024956036650110036, 0.021118793629284482, 0.035177302634110674, 0.04701728918007575, 0.056591387547086924, 0.06821822928031906, 0.04288928568712436, 0.05260820304101799, 0.09434733423404396, 0.10829668259248137, 0.2736848860513419, 0.10935322628938593, 0.19971443340182304, 0.19989427062682807, 0.13842688378645107, 0.1430866212467663, 0.1352725483593531, 0.23386443295748904, 0.13134621607605368, 0.12300141854211688, 0.09491663571679965, 0.206915907911025, 0.151596323994454, 0.16323164105415344, 0.208891267539002, 0.10686104244086891, 0.13014239317271858, 0.12589102989295498, 0.1271274479222484, 0.2033340508933179, 0.17969117034226656, 0.2602725854376331, 0.1602785909199156, 0.12556494504678994, 0.23817389155738056, 0.1379105864907615, 0.13740461989073083, 0.11862835788633674, 0.20447335147764534, 0.16626506578177214, 0.11214520069188438, 0.14448151749093086, 0.15412263921462, 0.1403022019076161, 0.12064032765920274, 0.10683362750569358, 0.23595791280968115, 0.11943887962843291, 0.30318807635921985, 0.20258728705812246, 0.21071111754281446, 0.08586270123487338, 0.10951094751362689, 0.15263932349625975, 0.2221144689247012, 0.3317074163351208, 1.8623272120021284, 6.821536459028721, 14.688661862164736, 22.61661060154438, 31.154450364410877, 46.56864054501057, 52.35570341348648, 60.08480407297611, 72.85979077219963, 84.67477038502693, 88.66882726550102, 85.10832712054253, 78.35777655243874, 64.14957135915756, 71.03009775280952, 64.19980466365814, 50.5268919467926, 54.33005467057228, 32.090121656656265, 34.11659851670265, 19.324961230158806, 23.698290959000587, 17.87551000714302, 19.636232927441597, 27.285313680768013, 23.590388149023056, 32.238214910030365, 41.94444067776203, 50.28338961303234, 44.974451288580894, 49.10535402595997, 60.75774796307087, 50.13512156903744, 70.16233071684837, 55.96392899751663, 58.25303636491299, 55.68222351372242, 44.05314512550831, 35.944642424583435, 36.98059603571892, 41.64981208741665, 34.75444748997688, 48.886641561985016, 58.04962567985058, 60.3890385478735, 51.55348666012287, 42.728859186172485, 54.39038783311844, 68.9521336555481, 75.68121537566185, 58.06425489485264, 63.00243191421032, 45.379604548215866, 77.66160070896149, 55.35632640123367, 48.172481283545494, 60.28612107038498, 45.49126535654068, 49.213963598012924, 28.794039823114872, 45.30221030116081, 45.31656213104725, 46.230261102318764, 46.527332961559296, 60.07905878126621, 54.5723182708025, 64.76593628525734, 71.83878555893898, 79.57707032561302, 77.97650501132011, 71.28776952624321, 68.61064597964287, 55.78688129782677, 37.23216153681278, 22.457743026316166, 6.772577036172152, 1.895082404371351, 0.23779649462085217, 0.10689557457226329, 0.12192909678560682, 0.1754139654804021, 0.1459397783037275, 0.10074328907649033, 0.15174494648817927, 0.15067730768350884, 0.17613128089578822, 0.16114194615511224, 0.16406618611654267, 0.10394993107183836, 0.18974906735820696, 0.13926818239269778, 0.16053740750066936, 0.15651458117645234, 0.16014432156225666, 0.09611777204554528, 0.1836514039314352, 0.22858357726363465, 0.15470417129108682, 0.16245799663010985, 0.16313263855408877, 0.09779728934518062, 0.11171629128511995, 0.14653713296866044, 0.21720446442486718, 0.2056128004915081, 0.15275171434041113, 0.13035535987000912, 0.10957095757476054, 0.15227112919092178, 0.24181379936635494, 0.08526660822099075, 0.08725347855943255, 0.1316304289503023, 0.12034422557917424, 0.141917634755373, 0.1837518610409461, 0.12054541439283639, 0.06101492908783257, 0.1249210280366242, 0.09870244233752601, 0.15443684969795868, 0.1460935958311893, 0.15090493921888992, 0.09797779450309463, 0.15692592394771054, 0.2521091094240546, 0.11589634159463458, 0.13697752874577418, 0.1384534823591821], [0.023351062518486287, 0.05016199153033085, 0.07972457591677085, 0.06965282300370745, 0.033431266638217494, 0.032655288159730844, 0.0347307857737178, 0.024595326904091053, 0.01023689746944001, 0.06046889022400137, 0.0455576553940773, 0.015605866501573473, 0.058374330546939746, 0.079463696165476, 0.008548600562789943, 0.01027924905429245, 0.03557853735401295, 0.050797132644220255, 0.029055220693408046, 0.026848218221857678, 0.06158925862109754, 0.05309050626237877, 0.03922905045328662, 0.04151525121415034, 0.04504701697442215, 0.07065642188536003, 0.014961061697249534, 0.01340629942205851, 0.0825572942267172, 0.03876339731505141, 0.03664911877422128, 0.05381070121075027, 0.04104454033949878, 0.016114428763103206, 0.08327249452122487, 0.09718437926494516, 0.023388733934552874, 0.05625871985103004, 0.028076118251192383, 0.03039832616195781, 0.05901698961679358, 0.020173800294287503, 0.05363304961065296, 0.06313177174888551, 0.128322483797092, 0.33779985504224896, 2.2704213950783014, 9.797832202166319, 13.51633071899414, 22.531884647905827, 39.937734156847, 46.5926818549633, 66.14886447787285, 61.4370147138834, 63.031454756855965, 62.026872262358665, 63.29672992229462, 55.00314675271511, 50.39313152432442, 49.77371156215668, 38.14034700393677, 34.266846254467964, 28.330759182572365, 22.47043054550886, 14.318772610276937, 12.577070519328117, 10.487777329981327, 10.36615440621972, 11.208170223981142, 27.103212252259254, 28.524174503982067, 24.381078220903873, 43.48166339099407, 54.53265979886055, 45.950797498226166, 50.88381439447403, 48.08688327670097, 42.92631559073925, 44.78275157511234, 31.658160835504532, 25.259915962815285, 19.599443301558495, 15.626571234315634, 16.597513183951378, 11.192507464438677, 14.976135436445475, 11.429679337888956, 16.98904797434807, 20.83088882267475, 15.118469148874283, 17.306581735610962, 10.97797192633152, 9.060717355459929, 17.428868673741817, 17.828103750944138, 23.291695676743984, 21.862940043210983, 21.851460859179497, 35.00574320554733, 47.87156023085117, 46.926395148038864, 38.5055910050869, 39.63514879345894, 41.38455592095852, 39.55210044980049, 35.336789041757584, 34.28522206842899, 49.85666871070862, 38.303590044379234, 20.873505435884, 17.975843623280525, 21.39627568423748, 23.406212031841278, 29.78030540049076, 40.0165419280529, 44.406989738345146, 49.73244957625866, 58.04172210395336, 56.695085763931274, 56.52438372373581, 51.36992610991001, 37.09502309560776, 22.9991227760911, 11.811963524669409, 1.9420823198743165, 0.15399758733110502, 0.056862983910832554, 0.08877197207766585, 0.01605570076208096, 0.02977628024382284, 0.01613352793356171, 0.030365053826244548, 0.056109796787495725, 0.009354904123028973, 0.0448331893858267, 0.05451938915939536, 0.03784323067520745, 0.0359665655560093, 0.05857975331309717, 0.06123902428953443, 0.025080613559111953, 0.031367732444778085, 0.032410557541879825, 0.02330124956642976, 0.014002318221173482, 0.032629917841404676, 0.026800989799085073, 0.006322171448118752, 0.04124195904296357, 0.0435701430978952, 0.02157361883291742, 0.060607156046899036, 0.01656298652960686, 0.06919219420524314, 0.022146081864775624, 0.07240215360070579, 0.06212991691427305, 0.06024003043421544, 0.05093866020615678, 0.008074451689026318, 0.03427732241107151, 0.022774423050577752, 0.03337941278005019, 0.01599541796167614, 0.01774663971445989, 0.03713183759828098, 0.0034599947457536473, 0.05906829799641855, 0.04337359270721208, 0.011036133928428171, 0.009939581050275592, 0.050687172333709896, 0.0714756861270871, 0.010505880545679247, 0.03564288155757822, 0.03378778696060181, 0.026699100344558246, 0.020814932395296637, 0.036367855936987326, 0.05649232567520812, 0.05608555824437644, 0.017417142844351474, 0.009916720118781086, 0.025758622978173662, 0.012418434071150841, 0.08155514995451085, 0.004444375945240608, 0.006801517210988095, 0.01740364317811327, 0.05305229678924661, 0.12596717424457893, 0.0427240168210119, 0.03556198003934696, 0.07212891709059477, 0.04567173833493143, 0.008117596444208175, 0.08312902253237553, 0.017840246800915338, 0.022521616010635626, 0.07078944443492219, 0.07766759488731623, 0.04968188877683133, 0.054081458947621286, 0.010658894698281074, 0.07550516209448688, 0.055371986964019015, 0.023516197798016947, 0.029760793477180414, 0.049506051727803424, 0.05373236752348021, 0.053123910329304636, 0.02819071141857421, 0.022686146439809818, 0.08420912199653685, 0.14497865253360942, 0.009866744821920292, 0.019757266200031154, 0.06633777549723163, 0.04571853074594401, 0.052084217095398344, 0.17614441690966487, 0.43538740603253245, 3.0002297088503838, 10.859993007034063, 16.50660116225481, 29.176992774009705, 46.826118528842926, 56.8986826390028, 77.48164996504784, 71.44787013530731, 74.57405358552933, 75.03328174352646, 72.74499133229256, 65.387864112854, 60.484531223773956, 59.62200790643692, 44.81674835085869, 48.51879470050335, 41.37501083314419, 30.89778743684292, 28.852011412382126, 19.912155121564865, 22.738363668322563, 18.13815951347351, 17.243619114160538, 20.284633934497833, 30.747566297650337, 34.356141462922096, 37.974303513765335, 37.715092822909355, 37.32370242476463, 43.511009216308594, 31.484114974737167, 34.13606107234955, 27.77356468141079, 23.45723569393158, 16.680812314152718, 13.95658079534769, 10.723953656852245, 11.626626569777727, 7.4797851126641035, 9.353318754583597, 8.011812139302492, 11.604810040444136, 10.928726568818092, 12.29192242026329, 13.484710715711117, 11.894182562828064, 9.957081656903028, 15.289516020566225, 16.191620863974094, 23.274115920066833, 24.979025535285473, 29.115772359073162, 43.81058134138584, 48.81526239216328, 56.987286284565926, 34.016572684049606, 39.52173247933388, 50.81243522465229, 42.7804110199213, 38.59457843005657, 34.747015088796616, 54.29818578064442, 48.50138023495674, 31.81401327252388, 28.964403681457043, 29.573731385171413, 33.18291261792183, 37.28978544473648, 46.600323244929314, 52.36410856246948, 57.99162179231644, 62.921777442097664, 64.31104749441147, 67.82984107732773, 62.572940960526466, 46.572250351309776, 34.33429643511772, 18.25184751302004, 3.9824520656839013, 0.3715536813251674, 0.04496863504755311, 0.035788134700851515, 0.023243337927851826, 0.03691016921948176, 0.009258339578082087, 0.013823353947373107, 0.011308101366012124, 0.0152189283289772, 0.038581942208111286, 0.022663512791041285, 0.07731491888989694, 0.02527665001252899, 0.09344431120553054, 0.016525341088708956, 0.0064228655810438795, 0.03530720074195415, 0.019545427567209117, 0.034678876254474744, 0.04482118514715694, 0.021442240140459035, 0.031189780274871737, 0.04685316322138533, 0.01045165459800046, 0.02469881383149186, 0.023499453091062605, 0.06152730784378946, 0.09475423154071905, 0.062281181453727186, 0.014755565644009039, 0.019782720009970944, 0.028599532743101008, 0.016266953098238446, 0.07603256934089586, 0.09476949751842767, 0.03222663108317647, 0.0343372359930072, 0.01977375115529867, 0.05620507370622363, 0.060516291196108796, 0.033354643601342104, 0.04953910698532127, 0.04539278357697185, 0.03187294576491695, 0.008563804385630647, 0.009385905486851698, 0.008719750949239824, 0.0838390649005305, 0.07125147589249536, 0.004020616115667508, 0.06802161951782182, 0.14471691189100966, 0.23968723457073793, 0.3250814328202978, 0.16189199028303847, 0.1408518958487548, 0.12120127255911939, 0.13393120549153537, 0.08378774538869038, 0.11630012188106775, 0.16714940895326436, 0.1821325096534565, 0.15659684082493186, 0.1592567574698478, 0.20946585311321542, 0.24047576647717506, 0.17000669235130772, 0.09910326145472936, 0.20113710081204772, 0.152580619615037, 0.1076461307820864, 0.20380883244797587, 0.11415850633056834, 0.09957741218386218, 0.15747466793982312, 0.1618287741439417, 0.24027465929975733, 0.08747791143832728, 0.1084742191596888, 0.22298833297099918, 0.19545821647625417, 0.112944204302039, 0.21224604221060872, 0.13465469557559118, 0.13472891034325585, 0.14534938498400152, 0.1338465858134441, 0.07723268892732449, 0.14811962930252776, 0.16704647307051346, 0.17094614740926772, 0.09257055848138407, 0.23160149110481143, 0.17731867264956236, 0.17983921396080405, 0.31256089685484767, 0.7981096487492323, 4.8843747563660145, 14.094710033386946, 21.849823147058487, 37.89740324020386, 57.868565395474434, 67.91731238365173, 86.73777848482132, 82.59998291730881, 85.9796279668808, 85.39230868220329, 84.1597156226635, 74.29489776492119, 71.45485416054726, 68.62963736057281, 54.0639853477478, 50.26263892650604, 43.41151535511017, 34.892904460430145, 27.95619808137417, 21.56266115605831, 22.155735231935978, 18.74244298785925, 20.691195018589497, 38.05649310350418, 43.27902026474476, 37.57863834500313, 58.10685820877552, 73.96449789404869, 62.13467627763748, 64.88572865724564, 62.782423719763756, 54.26495276391506, 56.07500463724136, 41.33382864296436, 32.55910389125347, 25.978081226348877, 21.73704519867897, 20.69067444652319, 15.033376514911652, 18.61096054315567, 14.717995338141918, 21.419194154441357, 24.96268831193447, 20.07838100194931, 22.715547792613506, 14.497738257050514, 12.42845194414258, 23.838229849934578, 24.3398542329669, 32.70703375339508, 31.321996673941612, 32.63092763721943, 48.414509296417236, 64.97308596968651, 59.844983741641045, 49.61476229131222, 57.737373635172844, 57.515020966529846, 56.46998584270477, 48.75065065920353, 47.23441421985626, 65.4356199502945, 51.03415332734585, 34.97195161879063, 30.654359199106693, 35.41574500501156, 39.11971405148506, 45.63256077468395, 57.85003758966923, 61.891238540410995, 67.23609253764153, 74.9401031434536, 72.75800183415413, 76.44052103161812, 72.03743129968643, 54.239915907382965, 39.633404687047005, 21.276202127337456, 4.750730227679014, 0.7032815809361637, 0.20756605896167457, 0.24235797172877938, 0.09952904641977511, 0.15767161909025162, 0.0869824610708747, 0.10797648297739215, 0.2615584305021912, 0.1580195379210636, 0.08322498222696595, 0.11376096750609577, 0.14119755855062976, 0.16776821168605238, 0.17198841960635036, 0.12561788986204192, 0.09416005326784216, 0.12330697558354586, 0.108796326094307, 0.17328263609670103, 0.22028724197298288, 0.09862626087851822, 0.12534141016658396, 0.16302961361361668, 0.18330364837311208, 0.12936267798068002, 0.1543072410277091, 0.11719357120455243, 0.18127632356481627, 0.15742727438919246, 0.07011923313257284, 0.10064693604363129, 0.15342206665081903, 0.21607133850920945, 0.19737079041078687, 0.17108975298469886, 0.1125538420455996, 0.08304172370117158, 0.11245668007177301, 0.15524487040238455, 0.07757824772852473, 0.14794997434364632, 0.15915014053462073, 0.14416347752558067, 0.19095660099992529, 0.12679554463829845, 0.10272033337969333, 0.1806762971682474, 0.174989590595942, 0.1533129857853055, 0.10491371373063885, 0.22140916145872325], [0.03576780727598816, 0.06891660508699715, 0.0023373310250462964, 0.035539570890250616, 0.014025728341948707, 0.01923274034197675, 0.026740098437585402, 0.04377666424261406, 0.06641627245699055, 0.04953642041073181, 0.02623315405799076, 0.007608856994920643, 0.08147732834913768, 0.021015592428739183, 0.02049664566584397, 0.06312912970315665, 0.006415279904103954, 0.05034147994592786, 0.06365616587572731, 0.04009109950857237, 0.05370372804463841, 0.06213226581166964, 0.10146136890398338, 0.06626038433751091, 0.06124070525402203, 0.06486975544248708, 0.046851905281073414, 0.054418787331087515, 0.05830118818266783, 0.03485521796392277, 0.032014369426178746, 0.030350338893185835, 0.019443645724095404, 0.04272937512723729, 0.04367601788544562, 0.008586658823332982, 0.024103201358229853, 0.04113303773920052, 0.030271522809925955, 0.03199132203008048, 0.03440124251937959, 0.06005746952723712, 0.02568808926298516, 0.131738678610418, 0.2930696646217257, 5.723569700494409, 15.345543064177036, 21.39052089303732, 40.55001050233841, 52.67522066831589, 60.23292392492294, 73.04862543940544, 60.20689532160759, 58.94654855132103, 59.17878448963165, 55.83704240620136, 49.92550201714039, 43.22338744997978, 35.70432052016258, 34.036449417471886, 23.140051513910294, 16.007511243224144, 10.532180797308683, 15.434855371713638, 16.50599129498005, 18.81156127899885, 20.99985245615244, 28.121500611305237, 30.822021402418613, 35.01206986606121, 33.64062085747719, 34.418971091508865, 40.47849453985691, 25.977292768657207, 20.22982757538557, 16.109851151704788, 15.948223024606705, 9.256321359425783, 9.503172263503075, 4.8099747486412525, 3.873266587033868, 1.7622786993160844, 1.5825438313186169, 0.7613181823398918, 0.9507739974651486, 1.1030018446035683, 1.464617990422994, 1.2010819441638887, 2.911112615838647, 1.4528926508501172, 1.179463122971356, 1.9619743712246418, 3.2753624953329563, 5.116106271743774, 10.92761417850852, 13.35171215236187, 22.873794101178646, 25.489566139876842, 24.60895959287882, 25.74180420488119, 20.590458624064922, 47.629931196570396, 35.722931921482086, 29.188285768032074, 45.13962462544441, 68.79584044218063, 58.33388842642307, 51.00240983068943, 33.13890717923641, 29.454968757927418, 39.08569447696209, 38.66004131734371, 25.08864015340805, 23.12379978597164, 25.78311938792467, 27.426743991672993, 36.82913236320019, 40.290788412094116, 52.000034898519516, 57.98389680683613, 55.17929770052433, 54.49196018278599, 57.47731178998947, 45.996999219059944, 27.613065093755722, 5.216525383293629, 0.4611731192562729, 0.13067255378700793, 0.05747544128098525, 0.06024008980602957, 0.010070853059005458, 0.059621398395393044, 0.04406846928759478, 0.004099133948329836, 0.039165355628938414, 0.03592752116674092, 0.030568908805435058, 0.0631916853308212, 0.023637266203877516, 0.019802871174761094, 0.03563421698345337, 0.03284101803728845, 0.061804663273505867, 0.03491860850772355, 0.021339692029869184, 0.01870831096312031, 0.08121778446366079, 0.050804453931050375, 0.01801278871425893, 0.06551281898282468, 0.03451239397691097, 0.019415885690250434, 0.005183541579754092, 0.03626259342127014, 0.01445979660275043, 0.06340039952192456, 0.034616424527484924, 0.019564714129955973, 0.08095254830550402, 0.07584374470752664, 0.04381074737466406, 0.07172001598519273, 0.011725053846021183, 0.010803150580613874, 0.005444267335406039, 0.09013620277983136, 0.022726445058651734, 0.09885432285955176, 0.021577318439085502, 0.059355943303671665, 0.03629019018262625, 0.03765344496059697, 0.046812359942123294, 0.10353717821999453, 0.037781873616040684, 0.04453298693988472, 0.010008996905526146, 0.07923800163553096, 0.07108427002094686, 0.030932724439480808, 0.05014624686737079, 0.03017768194695236, 0.04995088020223193, 0.0332164965220727, 0.02824281018547481, 0.04786912628333084, 0.02434931793686701, 0.027937542581639718, 0.013944740549050039, 0.04947707086103037, 0.017230648554686923, 0.06275691295741126, 0.08871012149029411, 0.01616995439690072, 0.061436290852725506, 0.008616856812295737, 0.05129965196829289, 0.07343257369939238, 0.01439098838091013, 0.01645961277972674, 0.052231796871637926, 0.0811280588095542, 0.06627024005865678, 0.05575540642894339, 0.061202711003716104, 0.06347241011098959, 0.03257330310589168, 0.048235754657071084, 0.02174922210542718, 0.048653680278221145, 0.048013540799729526, 0.029078080697217956, 0.023710271270829253, 0.03170204028720036, 0.10555000146268867, 0.06233992244233377, 0.04324058500060346, 0.046988479007268324, 0.03227794688427821, 0.08176738934707828, 0.46595931868068874, 6.693391185253859, 18.633134253323078, 27.424656003713608, 49.632640331983566, 63.83149042725563, 70.72636485099792, 81.40209719538689, 71.719950735569, 69.45402592420578, 69.39123049378395, 65.41404470801353, 60.55834226310253, 52.870116010308266, 45.66588498651981, 43.33002872765064, 37.174830213189125, 27.370493710041046, 24.843348115682602, 25.713585019111633, 20.716482661664486, 25.100204832851887, 27.276087775826454, 21.49937555193901, 27.69242763519287, 33.44490095973015, 34.883830547332764, 31.32377687841654, 28.029898926615715, 21.87212225049734, 15.928126852959394, 12.878583390265703, 11.323133055120707, 7.965671690180898, 5.363559918478131, 3.4321335330605507, 1.8708165502175689, 1.1016403301618993, 0.8363868354354054, 0.627824873663485, 0.8369631576351821, 0.868683677399531, 1.4195511024445295, 1.4801362389698625, 2.597037856467068, 1.2764491187408566, 1.286530690267682, 1.4183441922068596, 2.3568715061992407, 3.5050511453300714, 6.301567610353231, 9.49364997446537, 14.029504582285881, 17.363156899809837, 18.495849519968033, 21.516246646642685, 20.310917124152184, 36.129000931978226, 32.83559985458851, 30.935224927961826, 43.96288476884365, 61.97737231850624, 53.70012827217579, 51.59077025949955, 32.71651044487953, 30.09313691407442, 37.90899261832237, 44.415280893445015, 35.34789204597473, 30.705985128879547, 36.13631933927536, 39.011636450886726, 46.3144151866436, 46.91126435995102, 59.648902863264084, 65.33996388316154, 62.43041440844536, 63.49218003451824, 69.4385227560997, 55.68377383053303, 36.286646872758865, 8.804945480078459, 1.2434696196578443, 0.2044603045214899, 0.06100875812990125, 0.07175045146141201, 0.007283804661710747, 0.04478270479012281, 0.0701418389508035, 0.06571770369191654, 0.029204264355939813, 0.027587898257479537, 0.004115944984732778, 0.06695521267829463, 0.0797004412743263, 0.014607114771933993, 0.02843702837708406, 0.010880754180107033, 0.03176048441673629, 0.05810015522001777, 0.03968123361119069, 0.024718408385524526, 0.04970699934347067, 0.04445906532055233, 0.025088305919780396, 0.017746747325873002, 0.026632390545273665, 0.09002028673421592, 0.04475993941014167, 0.036287514740251936, 0.035209767884225585, 0.04978505843610037, 0.03581039542041253, 0.07029256914393045, 0.09113955675275065, 0.03471315976639744, 0.021102050777699333, 0.020662925708165858, 0.019328247326484416, 0.014080796627240488, 0.01492616034738603, 0.06326077185804024, 0.05613083667412866, 0.047142266848823056, 0.058564873252180405, 0.036343112733447924, 0.04671658949519042, 0.05770578165538609, 0.028717521236103494, 0.07295746559975669, 0.04728729363705497, 0.06003934999171179, 0.1317473320523277, 0.17325069406069815, 0.17466265970142558, 0.1731138865579851, 0.1125749116181396, 0.07661710711545311, 0.14180925150867552, 0.1579020411008969, 0.2717098529683426, 0.2712520369095728, 0.08634988407720812, 0.12305338372243568, 0.16982838395051658, 0.1397151779383421, 0.13613360293675214, 0.12183661776361987, 0.20536763942800462, 0.0945403816876933, 0.12972202588571236, 0.07323675803490914, 0.13481804227922112, 0.2017865690868348, 0.18166348716476932, 0.3562149731442332, 0.20711143413791433, 0.2572551020421088, 0.1667614735197276, 0.13615609001135454, 0.1335598051082343, 0.09035035691340454, 0.12482471211114898, 0.16530411812709644, 0.1121149210666772, 0.14312536135548726, 0.1382974087027833, 0.12350480246823281, 0.1601656954153441, 0.14217467018170282, 0.3325505554676056, 0.16606907942332327, 0.24834692536387593, 0.17441067087929696, 0.07984969459357671, 0.3387979546096176, 1.0758799687027931, 10.093894265592098, 24.98135671019554, 37.4947502464056, 62.22298353910446, 76.1349718272686, 81.03236183524132, 92.15772405266762, 80.27483448386192, 81.00935027003288, 76.92162081599236, 76.05884671211243, 68.2794101536274, 62.356158792972565, 50.96555180847645, 50.42857222259045, 36.68099731206894, 29.382238760590553, 22.01561015099287, 26.77923783659935, 24.512657560408115, 29.593195840716362, 31.404026672244072, 41.92107193171978, 46.82248592376709, 48.817378878593445, 44.25963744521141, 46.74638360738754, 54.67879995703697, 35.426597222685814, 27.1176153793931, 20.209990739822388, 20.158313512802124, 12.943242620676756, 11.74513841047883, 6.79795159958303, 5.07301420904696, 2.7701857779175043, 2.6496248971670866, 1.4842947595752776, 1.7832215130329132, 1.6733225039206445, 2.5888039357960224, 2.0260251592844725, 4.539130507037044, 2.348225307650864, 2.0326565159484744, 2.8544961288571358, 5.291512459516525, 6.969530917704105, 14.299560841172934, 18.16654399037361, 28.10390565544367, 32.70977720618248, 32.95497804880142, 34.690512120723724, 31.460204757750034, 63.07943098247051, 48.089953511953354, 43.15581947565079, 63.01139943301678, 84.46648076176643, 72.0577222108841, 65.62467500567436, 47.1359197050333, 42.597093656659126, 51.48816056549549, 52.6944400370121, 38.60895685851574, 36.863345727324486, 41.23612828552723, 42.85567358136177, 55.025394558906555, 57.28265203535557, 70.53037136793137, 74.83730345964432, 74.83138337731361, 75.42670503258705, 80.05484908819199, 63.54829162359238, 41.73529230058193, 10.961816143244505, 1.517301807180047, 0.30956558883190155, 0.1957776813651435, 0.10505257698241621, 0.20061287737917155, 0.20421213033841923, 0.15749059442896396, 0.17194078856846318, 0.1472143130376935, 0.0979329168330878, 0.11008733650669456, 0.22183795954333618, 0.13109197112498805, 0.09419296009582467, 0.1216593557910528, 0.11137474750285037, 0.1293352630455047, 0.17437421658542007, 0.07319630356505513, 0.14388524636160582, 0.17083325190469623, 0.2137589399353601, 0.1409126035287045, 0.15721093834144995, 0.11921793484361842, 0.12103929140721448, 0.19339375459821895, 0.16123416542541236, 0.20450324518606067, 0.25579785055015236, 0.14474903204245493, 0.22894844674738124, 0.1536329701775685, 0.12265081313671544, 0.11989489226834849, 0.14977657789131626, 0.0657784855866339, 0.09548693909891881, 0.10643332047038712, 0.1791415803018026, 0.09728818346047774, 0.17056849814252928, 0.12359376371023245, 0.24139353598002344, 0.1007159631990362, 0.09756841842317954, 0.10245952784316614, 0.1944271507090889, 0.13854985765647143, 0.09566801571054384], [0.10800217612995766, 0.019758945309149567, 0.021592673474515323, 0.024639145158289466, 0.022392849677999038, 0.01726826430967776, 0.028025776518916246, 0.0020358284291432938, 0.054956105959718116, 0.02909072132752044, 0.03864331782096997, 0.006980743091844488, 0.017180214053951204, 0.035944720439147204, 0.051400699085206725, 0.06043031709850766, 0.054111248755361885, 0.010856639019038994, 0.0077562813839904265, 0.03219379475922324, 0.058504373373580165, 0.14315786742372438, 0.02471683874318842, 0.020426408809726126, 0.08071312404354103, 0.03794119045778643, 0.012481086178013356, 0.045868585584685206, 0.02654496369359549, 0.04424798367836047, 0.07117640765500255, 0.029553361346188467, 0.06398094454198144, 0.06395059812348336, 0.01026168056341703, 0.04218440495606046, 0.03487085130473133, 0.020401066321937833, 0.04036187208839692, 0.045823299733456224, 0.018727443530224264, 0.02031757841905346, 0.21278145723044872, 0.9176167391706258, 5.319197773933411, 20.69099172949791, 32.43418179452419, 50.715453028678894, 62.20596805214882, 66.53452858328819, 66.75300166010857, 64.0256904065609, 63.505912497639656, 50.35638749599457, 41.60038433969021, 47.60627746582031, 33.902719393372536, 35.92689357697964, 20.36126632243395, 17.568452283740044, 11.565535347908735, 17.364370934665203, 18.158735409379005, 21.087574549019337, 36.59240886569023, 35.43594852089882, 45.176870226860046, 42.43123635649681, 31.734808422625065, 23.5123061388731, 22.951499931514263, 23.69854934513569, 15.57744462043047, 6.994976252317429, 3.363852621987462, 3.543939683586359, 1.4887727005407214, 0.7762181921862066, 0.35328512254636735, 0.09261436745873652, 0.038311778189381585, 0.03869663371006027, 0.026740525172499474, 0.09606431514839642, 0.05177239632757846, 0.0585848370246822, 0.02165801401133649, 0.10438142315251753, 0.08032000841922127, 0.3524142864625901, 0.2990065491758287, 0.4511561442632228, 0.3461268707178533, 0.47949033323675394, 0.6848227651789784, 1.366075740661472, 2.238979507237673, 6.617581928148866, 9.905973449349403, 12.44877990335226, 15.306561905890703, 10.923355557024479, 15.0401496514678, 23.4575092792511, 28.775168135762215, 30.05461648106575, 40.66849574446678, 43.97596746683121, 55.22340193390846, 70.0689697265625, 67.85732120275497, 42.842009514570236, 25.801508501172066, 16.802208200097084, 8.93974419683218, 11.088272407650948, 18.868495523929596, 32.267412543296814, 40.96948519349098, 49.71356458961964, 53.588931038975716, 47.61750966310501, 57.16606669127941, 55.25302514433861, 50.639331713318825, 39.48813088238239, 17.721048295497894, 3.734603002667427, 0.25848564226180315, 0.035654028615681455, 0.05583641926932614, 0.04572847923554946, 0.049972335691563785, 0.023248740762937814, 0.04996240204491187, 0.03220094906282611, 0.09671779844211414, 0.013632340906042373, 0.04892308730632067, 0.10673138924175873, 0.005984778590573114, 0.023608519113622606, 0.03858102565573063, 0.04111437272513285, 0.039616202921024524, 0.05865067294507753, 0.054798863420728594, 0.021300903681549244, 0.06342267879517749, 0.07752014498692006, 0.013778813026874559, 0.01688428266788833, 0.03528705514327157, 0.01970415069081355, 0.018180753431806806, 0.06545474592712708, 0.055388477485394105, 0.021483646414708346, 0.06933045631740242, 0.04403216713399161, 0.06417229989892803, 0.049239861909882165, 0.015925192237773445, 0.05704085073375609, 0.03685806674184278, 0.04706522449851036, 0.02801649781758897, 0.05765135254478082, 0.0795962214760948, 0.035705292466445826, 0.09028662127093412, 0.05423280512331985, 0.05262971048068721, 0.08264636679086834, 0.01700813227216713, 0.016593160398770124, 0.02978200591314817, 0.035594434157246724, 0.04612181750417221, 0.043812291041831486, 0.022731647513865028, 0.03555505580152385, 0.02976530944579281, 0.03069438556849491, 0.01246606881977641, 0.024119467379932757, 0.006678428308077855, 0.014623817733081523, 0.034785129537340254, 0.07452503734384663, 0.019291286516818218, 0.018129958989447914, 0.05483611923409626, 0.011413121756049804, 0.033804492704803124, 0.08874497274518944, 0.0500951425783569, 0.0449367894907482, 0.04423435413627885, 0.027502824013936333, 0.06062585816835053, 0.053489996935240924, 0.020929622041876428, 0.017646668711677194, 0.04028481118439231, 0.012851408591814106, 0.0858856707054656, 0.04980261393939145, 0.0347239246184472, 0.02151266253349604, 0.028232067597855348, 0.020311307271185797, 0.024212981697928626, 0.0221538558616885, 0.024598853960924316, 0.020364908887131605, 0.060587314728763886, 0.05217631391133182, 0.1827989285811782, 0.7512078748550266, 6.342836720868945, 24.262649975717068, 38.5633859038353, 60.7327339053154, 72.28250294923782, 75.80144092440605, 74.82850313186646, 73.52866128087044, 75.17769679427147, 58.663539737463, 54.121008887887, 56.878612115979195, 45.49770601093769, 47.93047986924648, 31.626244448125362, 30.85926130414009, 18.29615693539381, 26.465577967464924, 21.08815971761942, 29.344168603420258, 36.00394584238529, 32.611784264445305, 33.98359425365925, 34.04082678258419, 29.34213951230049, 22.38340761512518, 18.36318153887987, 14.21962358057499, 10.223666802048683, 4.926768131554127, 2.6459255581721663, 1.7481195903383195, 0.6132332410197705, 0.4847595520550385, 0.14652375946752727, 0.15109785308595747, 0.029059957450954244, 0.055630614297115244, 0.07730207973509096, 0.07083023287123069, 0.05949734098976478, 0.09103872114792466, 0.0034056769572998746, 0.08989312715129927, 0.031195001283776946, 0.14314968895632774, 0.132957789755892, 0.3099623112939298, 0.2192369248950854, 0.2998514397768304, 0.43470474891364574, 1.331828534603119, 2.393952766433358, 4.646337004378438, 8.21745140478015, 9.596785940229893, 11.61745861172676, 9.670553281903267, 13.620938155800104, 17.297418527305126, 27.006826624274254, 29.41588405519724, 38.77570331096649, 48.95075172185898, 59.004719629883766, 69.10533383488655, 71.58223092556, 47.944254130125046, 31.85600481927395, 27.587327174842358, 17.726212218403816, 18.076403327286243, 27.131889313459396, 44.33250233530998, 49.0365245193243, 57.67415642738342, 64.29625108838081, 56.46344639360905, 64.64644029736519, 62.2789241373539, 60.63069798052311, 51.73937648534775, 25.440049096941948, 6.227358542382717, 0.6405637494754046, 0.05566879779507872, 0.08143642116920091, 0.006976385757297976, 0.15252862474881113, 0.037525294610532, 0.05644408978696447, 0.02080016736726975, 0.03604618686949834, 0.02271810702950461, 0.05934209853876382, 0.03615699322836008, 0.048818025170476176, 0.037828005515621044, 0.0632998236687854, 0.07561177160823718, 0.02325279845535988, 0.04551999139948748, 0.02630448929267004, 0.04281116351194214, 0.04843518829147797, 0.029256138623168226, 0.03098510151176015, 0.033144567569252104, 0.019315050085424446, 0.021375910691858735, 0.031245552672771737, 0.045795840269420296, 0.03669527293823194, 0.017065138490579557, 0.03874689937219955, 0.08722912869416177, 0.013571667550422717, 0.0554984303744277, 0.025892740195558872, 0.03072579696890898, 0.060561228237929754, 0.11023041515727527, 0.08134853604133241, 0.00779974108809256, 0.013929183278378332, 0.04462650125788059, 0.06160602373711299, 0.03279634074715432, 0.008317531028296798, 0.07618468735017814, 0.021817601736984216, 0.08193941917852499, 0.1465993991587311, 0.13072987727355212, 0.15234483929816633, 0.08297591746668331, 0.14445235108723864, 0.11540831270394847, 0.141449146613013, 0.16816448885947466, 0.10209468062384985, 0.09756635525263846, 0.09625115082599223, 0.0966476951725781, 0.09841828883509152, 0.11268916525295936, 0.14824947546003386, 0.14795536233577877, 0.22774394106818363, 0.08056862046942115, 0.09791857853997499, 0.16694223100785166, 0.1738112382008694, 0.27005789161194116, 0.11281653263722546, 0.10689583432395011, 0.1624340846319683, 0.1371337063028477, 0.09184477516100742, 0.11800384061643854, 0.15808837953954935, 0.18342228810070083, 0.16493175295181572, 0.1267425256082788, 0.21118851145729423, 0.12422962099662982, 0.1306549203582108, 0.10332726917113177, 0.10720453065005131, 0.12640670378459617, 0.18898429902037606, 0.13242267159512267, 0.10534484958043322, 0.15993371489457786, 0.36689527973067015, 1.8441381817683578, 10.66693676635623, 31.86466835439205, 48.566288352012634, 75.39238527417183, 82.57653057575226, 86.98271334171295, 86.62518292665482, 80.64814165234566, 82.39933088421822, 68.90873998403549, 60.85351802408695, 64.79393318295479, 50.172078385949135, 52.104179710149765, 34.40312214195728, 33.365337029099464, 22.14058544486761, 27.098479606211185, 25.2871984988451, 31.740990690886974, 53.123057037591934, 47.72562526166439, 57.64713227748871, 58.47796909511089, 40.43773412704468, 32.7800240367651, 30.52932120859623, 29.04397141188383, 19.289032258093357, 9.688466470688581, 4.894225252792239, 4.6556213311851025, 2.25394737906754, 1.3410299783572555, 0.7982820051256567, 0.4453258024295792, 0.17213533516041934, 0.32451811304781586, 0.21903268585447222, 0.42044218454975635, 0.30898870259989053, 0.22137094085337594, 0.287723321816884, 0.31055754341650754, 0.33180374710354954, 0.7710726151708513, 0.4907210759120062, 0.7572345295920968, 0.48762525140773505, 0.8685015246737748, 0.9403536503668875, 2.002161252312362, 3.3597483672201633, 8.255289774388075, 12.707224935293198, 15.41196160018444, 18.885207027196884, 14.916423540562391, 19.92696102708578, 29.299042224884033, 33.95683228969574, 36.17807909846306, 48.26440595090389, 55.81878058612347, 71.05166539549828, 81.79291382431984, 79.28963094949722, 52.97987312078476, 38.75666633248329, 29.249694272875786, 20.08325044065714, 20.91112721711397, 32.531228587031364, 49.26947861909866, 56.7490428686142, 65.04318460822105, 71.28922864794731, 65.06519302725792, 74.87752050161362, 72.13703155517578, 69.28573295474052, 56.988494619727135, 29.496836811304092, 7.7713757660239935, 0.6997218250762671, 0.30731156759429723, 0.29664242290891707, 0.19009533862117678, 0.17364619940053672, 0.08137541663018055, 0.1920692584826611, 0.05809618472994771, 0.1757678363355808, 0.08760422497289255, 0.17296131583862007, 0.18477244768291712, 0.16585789388045669, 0.10454534130985849, 0.16701579268556088, 0.11676719252136536, 0.07779250576277263, 0.13548370421631262, 0.14203480503056198, 0.13468675635522231, 0.12462762737413868, 0.15222107875160873, 0.10726373919169419, 0.07740985442069359, 0.14866895216982812, 0.15959802665747702, 0.13823840796248987, 0.2726374485064298, 0.17533114179968834, 0.14852512395009398, 0.1323697713087313, 0.17978631367441267, 0.20990474440623075, 0.147163609508425, 0.09322995669208467, 0.13514345919247717, 0.1511218838277273, 0.14997122838394716, 0.11994532120297663, 0.13010299997404218, 0.19461363757727668, 0.16915633954340592, 0.1555431098677218, 0.14486216503428295, 0.15605054592015222, 0.20722768414998427, 0.10217414237558842, 0.10627484967699274], [0.09679843278718181, 0.060808014604845084, 0.037271201799740084, 0.0225203821901232, 0.0778010998328682, 0.01890182411443675, 0.036194286149111576, 0.022505092092615087, 0.04976136908226181, 0.049392317596357316, 0.023102687955542933, 0.03506755383568816, 0.047486230032518506, 0.06673052004771307, 0.04589201147609856, 0.045737611362710595, 0.018211348469776567, 0.006594745591428364, 0.011984145949099911, 0.02673062863323139, 0.022636157227680087, 0.06338849547319114, 0.07481026696041226, 0.04406694046338089, 0.050190671827294864, 0.04790232625964563, 0.08393644951866008, 0.053195438522379845, 0.06567029529833235, 0.02594492987554986, 0.019608048132795375, 0.025519721930322703, 0.034440561503288336, 0.05053302455053199, 0.058030987056554295, 0.03281849014456384, 0.02734170004259795, 0.032159433321794495, 0.042140273144468665, 0.022248138302529696, 0.03681689238874242, 0.10642448891303502, 1.0145985195413232, 7.289734510704875, 21.427067331969738, 40.01786045730114, 61.01529434323311, 70.86573377251625, 69.75465819239616, 59.97334845364094, 61.59691393375397, 58.23111534118652, 53.380683213472366, 40.52369311451912, 30.48936065286398, 25.67811582237482, 16.618470959365368, 12.289001327008009, 13.126213252544403, 16.51644453406334, 24.654621742665768, 27.873717807233334, 41.70566529035568, 36.03215552866459, 29.383139312267303, 39.66706708073616, 31.277972236275673, 13.575544841587543, 14.943844769150019, 9.958916958421469, 4.799330094829202, 3.372822040691972, 0.6636324303690344, 0.5179457541089505, 0.06406736021745019, 0.06819988338975236, 0.10220896394457668, 0.04931126022711396, 0.0355179075995693, 0.010516688071220415, 0.1041058414557483, 0.045419504604069516, 0.09153111386694945, 0.10724024279625155, 0.08215246009058319, 0.059305046816007234, 0.024861889651219826, 0.02696924209885765, 0.09525466914055869, 0.054397855055867694, 0.02786606262816349, 0.06939530518138781, 0.053924034582450986, 0.0324256788007915, 0.12956811930052936, 0.02753109612967819, 0.17531569028506055, 0.22877646144479513, 0.03345871125929989, 0.3718083567218855, 0.8561226795427501, 2.0565220853313804, 3.1651223357766867, 3.796407636255026, 2.725443416275084, 7.249439097940922, 11.364541333168745, 14.404852241277695, 22.816390581429005, 28.13359346240759, 32.810034826397896, 34.168283343315125, 30.396290346980095, 22.382425367832184, 32.78377063572407, 38.95395554602146, 15.487112067639828, 13.181892614811659, 23.010516464710236, 27.239011265337467, 38.92169147729874, 44.77599173784256, 49.27495792508125, 57.82086655497551, 58.90505097806454, 55.87217152118683, 52.79939420521259, 30.557331405580044, 9.533828068524599, 3.123009908013046, 0.15176237211562693, 0.09045515558682382, 0.05386957578593865, 0.04741305427160114, 0.05970933547359891, 0.05967475510260556, 0.02451866675983183, 0.10013168517616577, 0.030321684571390506, 0.04270092860679142, 0.03623483338742517, 0.009019040553539526, 0.004217237474222202, 0.005449850141303614, 0.059740438882727176, 0.03181772626703605, 0.046026180643821135, 0.03847125459287781, 0.05812519528262783, 0.02258424399769865, 0.13385504629695788, 0.020777492900379002, 0.0286237026375602, 0.039878715397208, 0.03095846768701449, 0.07157350119086914, 0.047716603803564794, 0.05637546339130495, 0.06208518396306317, 0.015152235228015343, 0.053692510482505895, 0.022950488310016226, 0.024714920291444287, 0.031208348809741437, 0.047223639630828984, 0.05061870178906247, 0.046643621535622515, 0.06538957051816396, 0.0684400720638223, 0.06377014491590671, 0.062040306293056346, 0.036973351961933076, 0.06425470797694288, 0.04081004393810872, 0.029796338640153408, 0.022322824333969038, 0.039807962748454884, 0.009225511603290215, 0.04199159498966765, 0.05582048535870854, 0.0406329044199083, 0.02099691813782556, 0.029748466404271312, 0.12525837868452072, 0.08797218921245076, 0.029868137717130594, 0.025252417035517283, 0.03786148750805296, 0.036361017046147026, 0.08303733018692583, 0.06828841418609954, 0.07303220729227178, 0.005842461569045554, 0.01476960151194362, 0.011676279900711961, 0.062416846049018204, 0.06145872968772892, 0.10326129224267788, 0.05807177920360118, 0.030060105345910415, 0.022516337485285476, 0.019862812587234657, 0.026396049906907137, 0.04707188156316988, 0.022588910251215566, 0.009610561937734019, 0.026103114942088723, 0.017842619818111416, 0.03881830511090811, 0.04141698715102393, 0.06931002499186434, 0.01412483010426513, 0.10701879335101694, 0.008896717918105423, 0.04533487379376311, 0.03236463715438731, 0.0660327379591763, 0.06707147011184134, 1.2514951452612877, 8.533549793064594, 24.77322667837143, 45.3046003729105, 68.89746978878975, 79.23991441726685, 76.97757661342621, 68.27128618955612, 70.76178655028343, 68.44304457306862, 62.16609679162502, 51.13854892551899, 41.27874679863453, 39.64149445295334, 26.346290968358517, 23.58494684100151, 23.302319906651974, 24.986703023314476, 27.923713624477386, 27.136099487543106, 33.678075447678566, 26.372443065047264, 29.481299445033073, 30.646220035851, 20.93075506389141, 15.512507054954767, 11.007472593337297, 7.0827890653163195, 4.226268595084548, 2.4595750076696277, 0.5358635145239532, 0.3175130404997617, 0.042952219810104, 0.049732080224202946, 0.09514728037174791, 0.04029661504318938, 0.08204336438211612, 0.013491127829183824, 0.2850369847146794, 0.04319629733799957, 0.0030912394231563667, 0.010618384567351313, 0.008342178680322831, 0.06247888959478587, 0.0482295985420933, 0.13485834089806303, 0.19451227504760027, 0.08757991963648237, 0.022322523764159996, 0.040107686509145424, 0.09361856005853042, 0.02233518480352359, 0.07844849751563743, 0.10872533224755898, 0.1577852270565927, 0.24032254266785458, 0.03574174676032271, 0.2943192038219422, 0.5963635712396353, 1.3432229356840253, 1.8209067033603787, 3.0536831030622125, 2.889436916448176, 5.6951377261430025, 11.906560398638248, 17.31242772191763, 27.122577913105488, 33.93339894711971, 35.23877330124378, 40.48866659402847, 33.01068685948849, 27.051991000771523, 35.54299637675285, 42.62882575392723, 25.616663619875908, 21.343971490859985, 32.6880119740963, 39.08368058502674, 47.46173322200775, 55.72348929941654, 57.65168063342571, 66.34342163801193, 66.10965818166733, 65.2350515127182, 64.00119692087173, 43.694828152656555, 17.38333571702242, 6.171068362891674, 0.10924329937552102, 0.06922361673787236, 0.021837600761500653, 0.020889729748887476, 0.0916830166534055, 0.047436391105293296, 0.011206262006453471, 0.022256192460190505, 0.08146373962517828, 0.060052545377402566, 0.010983441443386255, 0.04584851049003191, 0.004813350897165947, 0.028580800935742445, 0.01780410049832426, 0.041348791201016866, 0.04443382487806957, 0.05745047914388124, 0.02947506476630224, 0.01606587004062021, 0.07529800641350448, 0.0686716147174593, 0.11476681509520859, 0.03289348787802737, 0.054366436233976856, 0.050359684828436, 0.023337212187470868, 0.024470141433994286, 0.033103704918175936, 0.046714003110537305, 0.04729144224256743, 0.02487188823579345, 0.014673519362986553, 0.06664420827291906, 0.02613262644445058, 0.057412685273448005, 0.05736547725973651, 0.07219372142571956, 0.07396837463602424, 0.0274511315728887, 0.02666653490450699, 0.012283900323382113, 0.016848900777404197, 0.012585604690684704, 0.011527716778800823, 0.0627060016267933, 0.17080372927011922, 0.11872368675540201, 0.14260554627981037, 0.1150436807074584, 0.15395393420476466, 0.18494331976398826, 0.19596709229517728, 0.12281257906579413, 0.20654033665778115, 0.13445706164930016, 0.05234698190179188, 0.15002544969320297, 0.17362682934617624, 0.19910728238755837, 0.14539505675202236, 0.13215086743002757, 0.10632376463036053, 0.10514416542719118, 0.0904311693739146, 0.2020645627635531, 0.14362601417815313, 0.20639080874389037, 0.24184268375393003, 0.12862155446782708, 0.1565629246761091, 0.12109677816624753, 0.18075285712257028, 0.12157104021753184, 0.2027915112557821, 0.11175271589308977, 0.11961217111092992, 0.10321177614969201, 0.07677462795982137, 0.12214008937007748, 0.2096454380080104, 0.0853304922929965, 0.17131788918050006, 0.07490670162951574, 0.09990721518988721, 0.12849999067839235, 0.10199424577876925, 0.2624444360844791, 2.3960806522518396, 13.369982521981001, 34.82232324779034, 58.07340860366821, 81.39890536665916, 88.52231472730637, 87.9493510723114, 77.95442059636116, 79.36314180493355, 76.06760144233704, 68.476133197546, 56.0528252273798, 46.14696957170963, 40.78674919903278, 28.41671247035265, 23.930530697107315, 26.187220104038715, 25.98227620124817, 38.34625415503979, 39.830215126276016, 55.50546459853649, 47.026192992925644, 42.23352536559105, 50.30253678560257, 41.357197389006615, 17.970138229429722, 19.96152587234974, 12.120904047042131, 6.080214288085699, 5.071260603144765, 1.118383181747049, 0.7724983699154109, 0.3691326471744105, 0.2881144336424768, 0.35376045329030603, 0.15413951565278694, 0.13772455975413322, 0.2272653448744677, 0.6912889494560659, 0.12143659274443053, 0.2753115550149232, 0.39431024459190667, 0.32227302726823837, 0.3793577500618994, 0.5448911769781262, 0.23335659614531323, 0.5027820146642625, 0.15768091077916324, 0.18503377272281796, 0.19237868953496218, 0.23368420981569216, 0.17015427583828568, 0.38200742506887764, 0.291835383977741, 0.31663899833802134, 0.5121700640302151, 0.3587896912358701, 0.6717867334373295, 1.394461642485112, 2.650531860999763, 4.136387268081307, 5.269114561378956, 3.8287125527858734, 9.414849802851677, 12.98833480104804, 19.7143567353487, 30.6554801389575, 36.641616225242615, 44.64028961956501, 49.63643252849579, 41.3691059499979, 35.94824843108654, 45.57878226041794, 50.56777775287628, 26.64294295012951, 23.585816994309425, 36.66241630911827, 42.34014764428139, 54.997412860393524, 62.43787720799446, 67.38410979509354, 76.96392014622688, 76.1127582192421, 76.42499506473541, 74.05662775039673, 53.21547947824001, 22.610150948166847, 6.470256233587861, 0.5275548447389156, 0.1328688210924156, 0.10180105731706135, 0.15942846075631678, 0.20304906618548557, 0.19461006042547524, 0.09910705382935703, 0.11254647994064726, 0.1826198780327104, 0.20788377238204703, 0.18381541856797412, 0.12546181620564312, 0.07978989975526929, 0.13582386018242687, 0.1487662477302365, 0.09274830284994096, 0.14828465325990692, 0.10823437187355012, 0.14288000733358786, 0.0829405096010305, 0.2815918461419642, 0.15702215081546456, 0.1871184358606115, 0.07340093594393693, 0.16982025001198053, 0.13355664355913177, 0.12896108702989295, 0.13192813406931236, 0.1501149230170995, 0.18037455476587638, 0.11875332071213052, 0.11451042533735745, 0.21494287328096107, 0.16506778862094507, 0.14741573191713542, 0.20080233283806592, 0.27866840770002455, 0.16636530024698004, 0.19137523166136816, 0.12426459099515341, 0.1949906931258738, 0.1193564196000807, 0.09382937452755868, 0.17749422026099637, 0.17399968433892354, 0.11334092676406726], [0.04132991467486136, 0.04160321055678651, 0.03522421378875151, 0.03684486022393685, 0.0691752732382156, 0.04182345401204657, 0.0447792315389961, 0.05431408884760458, 0.021999218261044007, 0.07131020945962518, 0.0052486557615338825, 0.1313020582892932, 0.07405292009934783, 0.0065697551599441795, 0.025605135706427973, 0.07781683336361311, 0.019998948446300346, 0.0482295317488024, 0.01264860839000903, 0.08393836425966583, 0.04984856772352941, 0.00971811861745664, 0.023569007171317935, 0.038933085670578294, 0.09935810012393631, 0.04305978669435717, 0.017138067487394437, 0.07776204802212305, 0.030883367908245418, 0.032040199876064435, 0.061202013384900056, 0.03494506236165762, 0.026101014664163813, 0.07419954621582292, 0.06957496429095045, 0.025484668440185487, 0.03166447648254689, 0.036947955668438226, 0.04957677097991109, 0.03183073611580767, 0.0803706154692918, 1.0178733500652015, 7.07505933009088, 22.232113033533096, 40.31799115240574, 66.20456948876381, 66.9112403690815, 70.7019929587841, 67.17898920178413, 56.699478328228, 46.896931529045105, 40.95074459910393, 36.46823912858963, 26.10509131103754, 20.725123398005962, 17.280995808541775, 25.70820450782776, 30.404241420328617, 22.52653643488884, 33.42372469604015, 33.43184866011143, 41.18958458304405, 33.9032057672739, 36.73351809382439, 19.02346070855856, 17.82141800969839, 7.013935809955001, 3.4407806815579534, 2.216881080530584, 0.29265492281410843, 0.04936010838719085, 0.08614801990916021, 0.062403717456618324, 0.029253437205625232, 0.047162623959593475, 0.09282295548473485, 0.0381618086976232, 0.06704107174300589, 0.10283469091518782, 0.06972550894715823, 0.04828577169973869, 0.07710294667049311, 0.03210999144357629, 0.0311893015896203, 0.031233077170327306, 0.10774166745250113, 0.053381780671770684, 0.07662013507797383, 0.022381854760169517, 0.1551813870901242, 0.13428868318442255, 0.08589784934883937, 0.05988080498354975, 0.06592413948965259, 0.055465456753154285, 0.05233096264419146, 0.04974825162207708, 0.03375547756149899, 0.17225482093635947, 0.12278534224606119, 0.11391400577849708, 0.07475340360542759, 0.11980852854321711, 0.23961987724760547, 0.44183138525113463, 0.6867405935190618, 0.7793251192197204, 3.9957572892308235, 8.714050557464361, 16.044614352285862, 27.055790796875954, 27.70902704447508, 38.725910782814026, 31.256157606840134, 39.59211990237236, 38.265474289655685, 20.31130090355873, 26.892450861632824, 14.661749806255102, 16.292499750852585, 23.50010309368372, 20.622849985957146, 35.385608822107315, 41.41449831426144, 47.17533878982067, 50.59099830687046, 64.06969204545021, 60.656540393829346, 56.84318281710148, 31.594759337604046, 11.675137616693974, 1.6953088366426528, 0.07676502456888556, 0.029311792277439963, 0.04760095864185132, 0.07781417647493072, 0.07505183602916077, 0.020746018417412415, 0.02629532005812507, 0.04944235690345522, 0.0681932337465696, 0.048705586086725816, 0.023049201372487005, 0.011029716206394369, 0.07045281367027201, 0.06647962960414588, 0.05513963908015285, 0.08211771273636259, 0.026143226168642286, 0.03229068584914785, 0.01814652372559067, 0.04438788593688514, 0.03555472183506936, 0.029836739304300863, 0.028056369701516815, 0.028904828177473973, 0.038211870269151405, 0.08090986739262007, 0.02102450562233571, 0.0037139041069167433, 0.06102170860685874, 0.019100233585049864, 0.036419899042812176, 0.009471450066484977, 0.005749848960476811, 0.039029345934977755, 0.04461661214008927, 0.05571455119934399, 0.016310804749082308, 0.05987702003039885, 0.050308172358199954, 0.01690887558652321, 0.06714851246215403, 0.10605409042909741, 0.04036314487166237, 0.029502075230993796, 0.03964061586884782, 0.03738201929081697, 0.03139106927847024, 0.02658334757143166, 0.03698597589391284, 0.029533905944845174, 0.048783849269966595, 0.04997400181309786, 0.10097934398800135, 0.031709513714304194, 0.025400557133252732, 0.01408442572937929, 0.04338011989602819, 0.07048850355204195, 0.02303590765222907, 0.05999456137942616, 0.04883834517386276, 0.06903241723193787, 0.0143398924410576, 0.056940664508147165, 0.06654533935943618, 0.0384053926973138, 0.02039123843132984, 0.02871918179152999, 0.06028993986546993, 0.013631816764245741, 0.028423515723261517, 0.04910639036097564, 0.05779646096925717, 0.006443067768486799, 0.060512732597999275, 0.06572092461283319, 0.04309234471293166, 0.13193494698498398, 0.04110345944354776, 0.06733141475706361, 0.008088229660643265, 0.028393952270562295, 0.028359008247207385, 0.06252540741115808, 0.08927517046686262, 1.0046925698406994, 8.846039324998856, 24.70456436276436, 47.3857980966568, 76.18186131119728, 76.39146566390991, 79.73564341664314, 78.27879399061203, 68.16846370697021, 57.01591394841671, 50.86646072566509, 45.27770921587944, 34.67926472425461, 33.34527030587196, 27.307783775031567, 25.371624268591404, 34.665498062968254, 29.10266686230898, 33.2213019579649, 31.38874389231205, 35.15941075980663, 29.00750856846571, 23.885674104094505, 13.272471204400063, 11.495619099587202, 7.263084640726447, 2.8001443203538656, 1.6712341597303748, 0.2994662057608366, 0.14424837921978906, 0.11606374784605578, 0.05137766282132361, 0.10562999756075442, 0.18693926656851545, 0.2751567430095747, 0.09392214298713952, 0.20747725357068703, 0.2076552651124075, 0.33756670192815363, 0.14418927457882091, 0.07731438454356976, 0.08010015459149145, 0.2369156840723008, 0.06286576375714503, 0.2017630875343457, 0.2330420888029039, 0.07968210280523635, 0.14563040662324056, 0.5838237097486854, 0.32631701964419335, 0.26698492525611073, 0.13279508129926398, 0.42763968114741147, 0.3771614679135382, 0.4217971384059638, 0.06319747408269905, 0.12427611654857174, 0.31211768626235425, 0.039510250207968056, 0.15954908943967894, 0.05702111331629567, 0.10644834153936245, 0.24619747273391113, 0.32691611093468964, 0.7487213832791895, 0.948604135774076, 2.925496269017458, 7.561167245730758, 12.577503696084023, 22.974741384387016, 27.723616361618042, 32.696318328380585, 33.06029699742794, 42.8901719301939, 44.159125238657, 26.000471524894238, 32.52154290676117, 23.13935235142708, 24.001968763768673, 35.772177278995514, 29.998746179044247, 44.71843242645264, 49.4504439085722, 56.62079215049744, 62.72348888218403, 71.20680347084999, 67.66971006989479, 69.79041427373886, 44.30569477379322, 18.617444895207882, 3.174104103818536, 0.09860350663075224, 0.03957487642765045, 0.007970479582581902, 0.02577156603365438, 0.10149752633878961, 0.03242586804844905, 0.015170403003139654, 0.059245188895147294, 0.08927345610572957, 0.08522901844116859, 0.037400558139779605, 0.027535934932529926, 0.014345291565405205, 0.06298075211816467, 0.044588236123672687, 0.014801540764892707, 0.032675084949005395, 0.018760951497824863, 0.023639557584829163, 0.02328580361790955, 0.016499187804583926, 0.028987742771278135, 0.04998066258849576, 0.06656517696683295, 0.01522811518952949, 0.04549708872218616, 0.021534641236939933, 0.04860717359406408, 0.026915351045317948, 0.05226271474384703, 0.055341529223369434, 0.02025419715209864, 0.060461067987489514, 0.014354166723933304, 0.0585874048556434, 0.04429429740412161, 0.04345913264842238, 0.033542466335347854, 0.015128302820812678, 0.021774707456643227, 0.018992364275618456, 0.06832325801951811, 0.07064721183269285, 0.01044320895744022, 0.12389091221848503, 0.13462086848448962, 0.1076189310697373, 0.1497593749081716, 0.18819211574736983, 0.11087994280387647, 0.17908345529576764, 0.3020476328674704, 0.12984051718376577, 0.12681037274887785, 0.08417567340075038, 0.22272576112300158, 0.11249216957367025, 0.15862685220781714, 0.12262259668204933, 0.13644328631926328, 0.15723400429124013, 0.14836536924121901, 0.0913273794867564, 0.17265955859329551, 0.21451869135489687, 0.10143231382244267, 0.10191260211286135, 0.12631212448468432, 0.1586184510961175, 0.12510678760008886, 0.15528751420788467, 0.19049304071813822, 0.1323753225733526, 0.0766350374033209, 0.1738136279163882, 0.1845622863038443, 0.06962396830203943, 0.2169145073276013, 0.1358067017281428, 0.14135637815343216, 0.13391082611633465, 0.21819226298248395, 0.09591031208401546, 0.19421011704253033, 0.2230657686595805, 2.257400443777442, 13.243700098246336, 32.938566729426384, 59.409964084625244, 84.88211005926132, 83.84261503815651, 88.71774584054947, 84.89074319601059, 75.8754913508892, 64.00789976119995, 55.913011729717255, 51.15410529077053, 40.1255276799202, 34.49560917913914, 28.542787805199623, 37.23473779857159, 42.804159745574, 34.558909982442856, 47.116498947143555, 47.227487191557884, 54.01443600654602, 44.718774408102036, 47.20000706613064, 24.867155738174915, 23.160623610019684, 9.401901997625828, 5.223815767094493, 2.8247463377192616, 0.6870436272583902, 0.24531746370485052, 0.37734180979896337, 0.30929238942917436, 0.1973870286019519, 0.2895601373165846, 0.31598335539456457, 0.26308660162612796, 0.3491892688907683, 0.5040989408735186, 0.2934164257021621, 0.1595807049307041, 0.3091477003181353, 0.28705990116577595, 0.33800878445617855, 0.2868727018358186, 0.5724355427082628, 0.522241482976824, 0.42220926785375923, 0.11204269525478594, 0.3977819223655388, 0.32946013379842043, 0.2105681353714317, 0.10269522652379237, 0.3199599013896659, 0.14700260799145326, 0.3714743902673945, 0.1944991687196307, 0.22850439010653645, 0.31845251040067524, 0.20639367343392223, 0.30339341377839446, 0.16455209988635033, 0.36069546709768474, 0.43547613720875233, 0.6773476162925363, 1.0117612592875957, 1.2916313228197396, 5.592810166999698, 11.470721885561943, 22.427941225469112, 33.774613067507744, 34.84365530312061, 50.14920361340046, 43.09306204319, 50.92527016997337, 48.153470903635025, 29.940373711287975, 40.56725397706032, 27.61562805622816, 28.94133321940899, 38.37177358567715, 32.6312430202961, 49.033226296305656, 58.74823719263077, 67.30641916394234, 69.49312582612038, 80.38255110383034, 77.0618636906147, 80.83438485860825, 54.04110677540302, 21.360848285257816, 4.349023383110762, 0.20188620983390138, 0.2127827040385455, 0.22683194547425956, 0.14461194252362475, 0.30548187671229243, 0.15159292495809495, 0.18373308470472693, 0.13344091305043548, 0.2626471017720178, 0.17265676811803132, 0.16228132095420733, 0.1274170191027224, 0.13421489886241034, 0.1881859707646072, 0.19769951730268076, 0.2914887119550258, 0.0708634068723768, 0.21726365812355652, 0.1615586323896423, 0.12213491660077125, 0.16677645005984232, 0.1274644274963066, 0.15106317994650453, 0.2114494951092638, 0.0784682683297433, 0.13597079057944939, 0.14930163306416944, 0.16577606467762962, 0.11027489206753671, 0.12464333121897653, 0.09484338574111462, 0.10124331849510781, 0.13709532242501155, 0.10888110162341036, 0.15149160695727915, 0.17174670210806653, 0.13292941002873704, 0.11760886962292716, 0.18025330267846584, 0.14693103526951745, 0.14197552227415144, 0.18128214200260118, 0.1906387836788781, 0.12672009790549055], [0.026454228718648665, 0.0584331234858837, 0.048471687114215456, 0.03191772324498743, 0.035165472800144926, 0.05403642913734075, 0.033032807550625876, 0.04285742157662753, 0.04033897312183399, 0.05942629148194101, 0.018195499906141777, 0.09228404494933784, 0.006543573117596679, 0.02556744759203866, 0.0032950893000815995, 0.06550531586981378, 0.0716457937960513, 0.1056816584605258, 0.024412936691078357, 0.01634749281947734, 0.04073191805218812, 0.04307011367927771, 0.03174000856233761, 0.042165142513113096, 0.02648822464834666, 0.022121501933725085, 0.014914644998498261, 0.09511931624729186, 0.02765477132925298, 0.09266552369808778, 0.08472485525999218, 0.018196954515588004, 0.024443297952529974, 0.07138155211578123, 0.02718884174100822, 0.05605396501778159, 0.032863735177670605, 0.053718329800176434, 0.07596661467687227, 0.12868811027146876, 1.9264722825028002, 12.418000604957342, 24.376626759767532, 42.46120534837246, 68.0860461294651, 72.92976781725883, 69.87725481390953, 61.67330123484135, 51.92234426736832, 39.72870357334614, 40.11808007955551, 30.26182696223259, 27.735298834741116, 26.613466031849384, 18.1687193736434, 32.27900192141533, 45.04823952913284, 32.64164686203003, 40.19445598125458, 41.36006623506546, 36.5897262096405, 26.684505119919777, 19.15111295878887, 8.262863717973232, 5.425545042380691, 3.4019299037754536, 0.5932302237488329, 0.47084371908567846, 0.16393150115618482, 0.1096619077725336, 0.06706885033054277, 0.05221885381615721, 0.07310360932024196, 0.05049453306128271, 0.010649719897628529, 0.047875107993604615, 0.10165275394683704, 0.14277153502916917, 0.10788401879835874, 0.36851117270998657, 0.2531878062291071, 0.04895971971563995, 0.021443551886477508, 0.038749177765566856, 0.09651980086346157, 0.11291969116427936, 0.10449140943819657, 0.1108767070400063, 0.6619265594054013, 0.8950430410914123, 0.4889753367751837, 0.24629114661365747, 0.2072831374243833, 0.38192112813703716, 0.5710895243100822, 0.28392970038112253, 0.18333287414861843, 0.1207334894570522, 0.16640690504573286, 0.08511494292179123, 0.10537751892115921, 0.07565998894278891, 0.06173069341457449, 0.042901263950625435, 0.05864444261533208, 0.1175799110205844, 0.14949521486414596, 0.27441578276921064, 1.0096738650463521, 5.428847065195441, 5.878787096589804, 16.64209619164467, 26.03110358119011, 32.07327336072922, 39.514835849404335, 37.818793058395386, 40.745555609464645, 26.30536336451769, 22.19002079218626, 17.266984060406685, 15.01286806538701, 23.778586350381374, 29.5297297462821, 39.624855145812035, 28.542728908360004, 43.37122231721878, 52.66127161681652, 52.57255777716637, 61.06102868914604, 59.447635263204575, 45.7427054643631, 22.9804714769125, 5.392969865351915, 0.6818952003959566, 0.05346978454326745, 0.011507035906106466, 0.034841180240618996, 0.04215183580527082, 0.046777705356362276, 0.03595029025746044, 0.043056762442574836, 0.030513878555211704, 0.06792092492105439, 0.08415344607783481, 0.029956757571198978, 0.022671500155411195, 0.045611342357005924, 0.046806541504338384, 0.02471332838467788, 0.03834350129181985, 0.10382639316958375, 0.011584349140321137, 0.04879624684690498, 0.053990330634405836, 0.06232503495994024, 0.047909981512930244, 0.0426881859311834, 0.04252433456713334, 0.03229187699616887, 0.05344531964510679, 0.044120070815552026, 0.04977869080903474, 0.039978493441594765, 0.05479969833686482, 0.00754547851101961, 0.016443307795270812, 0.009348378789582057, 0.03858478092297446, 0.03366844590345863, 0.05051849329902325, 0.018180031693191268, 0.025020677712745965, 0.046177463736967184, 0.100679931929335, 0.02234670850157272, 0.07690779151744209, 0.13448587182210758, 0.14917180174961686, 0.031281205447157845, 0.026120837428607047, 0.015456466608156916, 0.07083822580170818, 0.022723585934727453, 0.04909910618152935, 0.02427448347589234, 0.008852035989548313, 0.025700741025502793, 0.06905802132678218, 0.040592550139990635, 0.01371587612084113, 0.06946053254068829, 0.015793787570146378, 0.04916058940580115, 0.07200137159088627, 0.04073342090123333, 0.03688532211526763, 0.026334778194723185, 0.012467169981391635, 0.03901024305378087, 0.01045417326167808, 0.0036727209408127237, 0.0700107311422471, 0.04711771660367958, 0.034834638208849356, 0.034279474639333785, 0.018704396134126, 0.04061840656504501, 0.009108739304792834, 0.06183592995512299, 0.0883241007977631, 0.04393858602270484, 0.031128742339205928, 0.0814502993307542, 0.06124769999587443, 0.07114329302567057, 0.16933751263422891, 2.02295848634094, 12.86585122346878, 26.099993884563446, 49.94210332632065, 78.33031162619591, 81.48896813392639, 78.63087549805641, 72.0673280954361, 60.43138347566128, 49.562716484069824, 47.78089329600334, 35.96556790173054, 35.20916908979416, 33.58531482517719, 23.43350026756525, 37.18836508691311, 50.879505425691605, 37.90466085076332, 42.21377782523632, 40.338825434446335, 30.47600246965885, 19.300686232745647, 13.57765942811966, 8.03565775975585, 4.20241822488606, 2.1533860126510262, 0.42219255468808115, 0.5438580480404198, 0.1217063856893219, 0.12587848759721965, 0.12452875846065581, 0.2988209231989458, 0.17629015987040475, 0.2662638545734808, 0.1620182889746502, 0.3379316604696214, 0.4357436369173229, 0.47348478517960757, 0.8120721182785928, 1.0232212068513036, 0.8448673272505403, 0.04936782301228959, 0.3064271650509909, 0.11322642822051421, 0.12589809513883665, 0.14957037958083674, 0.0540795961569529, 0.03055758548725862, 0.4048636736115441, 1.1491183075122535, 1.3786158990114927, 0.8437276259064674, 1.9936839072033763, 1.3750334037467837, 1.4260468538850546, 1.0881309863179922, 0.9703982225619256, 0.6931425374932587, 0.46367498813197017, 0.1916948746656999, 0.06972169430810027, 0.15019580227090046, 0.04854791681282222, 0.16210212197620422, 0.02720704476814717, 0.08230205479776487, 0.14245398488128558, 0.4418310587061569, 1.1006926372647285, 3.8178330240771174, 5.440670605748892, 10.186738483607769, 19.174774289131165, 24.184585064649582, 33.67906339466572, 33.448655158281326, 38.87574054300785, 36.443426460027695, 28.945317305624485, 27.912409231066704, 23.200527168810368, 31.97937659919262, 41.69262818992138, 50.670467242598534, 39.980759248137474, 50.6218146532774, 60.30754052102566, 62.01775275170803, 66.52414754033089, 66.66246011853218, 56.53414539992809, 34.0717077255249, 8.968846835196018, 1.2793661747127771, 0.051332499424461275, 0.013142541065462865, 0.02933350195235107, 0.03665775366243906, 0.03409155171539169, 0.020167386282992084, 0.007641768461326137, 0.0926797284046188, 0.06178705581987742, 0.03638213856902439, 0.05419181630713865, 0.014075144244998228, 0.05607715342193842, 0.007937039335956797, 0.06120105601439718, 0.0587069388711825, 0.03715601676958613, 0.021395993207988795, 0.04289937518478837, 0.02648420777404681, 0.05859812146809418, 0.0321475923556136, 0.03629220511356834, 0.01490838869358413, 0.03985925257438794, 0.01211664992297301, 0.03532147966325283, 0.05451489174447488, 0.06069497438147664, 0.032984965000650845, 0.03875653987051919, 0.027969775910605676, 0.040984597071656026, 0.038798753230366856, 0.019455113761068787, 0.0430017062171828, 0.01156123402324738, 0.03659216265077703, 0.05607609957223758, 0.020189596907584928, 0.007900438467913773, 0.034417989081703126, 0.19796771463006735, 0.18242493068100885, 0.12074853279045783, 0.0780568142363336, 0.08386328117921948, 0.13778185355477035, 0.12655643949983642, 0.09991990591515787, 0.13581663166405633, 0.11086484752013348, 0.09627043924410827, 0.13303927757078782, 0.2123018220299855, 0.1065951086638961, 0.16448536596726626, 0.12968761991942301, 0.12529052852187306, 0.294231214793399, 0.10791696273372509, 0.15456023917067796, 0.11627361236605793, 0.10303460323484614, 0.16810664586955681, 0.1435497510829009, 0.13020862243138254, 0.21094755094964057, 0.11679097093292512, 0.18418665567878634, 0.14264330675359815, 0.14353481907164678, 0.15276443475158885, 0.1292056989041157, 0.1776378703652881, 0.10278367568389513, 0.14337417378555983, 0.13680845266208053, 0.14763712941203266, 0.1294026500545442, 0.19474654138321057, 0.3961614577565342, 3.8086040318012238, 18.62702038139105, 36.06714025139809, 60.4926285892725, 89.08705562353134, 91.43209978938103, 89.41285014152527, 79.30629685521126, 68.89350280165672, 55.31444504857063, 54.08830784261227, 44.462649151682854, 42.140806540846825, 40.99744029343128, 27.638871408998966, 44.310132935643196, 61.92930109798908, 44.7171138972044, 52.859157398343086, 54.42352965474129, 48.365484327077866, 33.968353271484375, 24.774131029844284, 10.786660742014647, 7.381692426279187, 4.517615111544728, 1.0119481617584825, 0.7364464388228953, 0.19462972733890638, 0.2484108242788352, 0.26701725320890546, 0.3638954891357571, 0.32708395505324006, 0.374197656637989, 0.24723147740587592, 0.20183666405500844, 0.44632891891524196, 0.3938181116245687, 0.5098662595264614, 1.013723616488278, 0.8138218056410551, 0.13291035167640075, 0.41687316668685526, 0.31157784804236144, 0.42732432775665075, 0.3470552380895242, 0.3376049373764545, 0.20755032543092966, 1.585940255317837, 2.456308607943356, 0.9081656369380653, 1.1495929257944226, 1.8929904978722334, 0.9249797347001731, 1.2449494027532637, 0.7190130336675793, 0.8267699077259749, 0.9014104306697845, 0.29203635756857693, 0.2934896311489865, 0.24284324725158513, 0.5360739876050502, 0.23244099371368065, 0.22911298088729382, 0.24122756207361817, 0.4615489428397268, 0.3613680606940761, 0.4172983579337597, 1.8101955531165004, 6.406767340376973, 7.83567781560123, 20.952170714735985, 32.05506853759289, 41.5278310328722, 52.68072657287121, 50.825122743844986, 55.08289307355881, 37.79592968523502, 33.72378319501877, 29.832626692950726, 26.258033104240894, 36.47712305188179, 44.50143367052078, 56.52142748236656, 42.96226926147938, 60.32122738659382, 71.68389067053795, 74.26657408475876, 76.44351527094841, 76.0293298959732, 67.96330511569977, 43.14763471484184, 11.258001700043678, 1.8809122522361577, 0.1575642154784873, 0.20575578266289085, 0.16759135789470747, 0.1842279636184685, 0.2228418627055362, 0.09756509360158816, 0.13746219570748508, 0.18654702667845413, 0.11683577438816428, 0.18382971233222634, 0.12830557767301798, 0.098541544721229, 0.12913805956486613, 0.11609709254116751, 0.07600977056426927, 0.1653494781930931, 0.24445963004836813, 0.08231772153521888, 0.128136353159789, 0.187236288911663, 0.10758831747807562, 0.22415797255234793, 0.17911217641085386, 0.12101434782380238, 0.14000946917803958, 0.18002500321017578, 0.11119558563223109, 0.1340651631471701, 0.09724346906295978, 0.11621358746197075, 0.14136810408672318, 0.18762456573313102, 0.10424328720546328, 0.131111548980698, 0.1263910296256654, 0.1871312750154175, 0.08913072626455687, 0.12373376244795509, 0.18226002546725795, 0.18201489408966154, 0.12101802887627855, 0.16250941262114793], [0.04173733890638687, 0.037722431297879666, 0.061993461931706406, 0.06245489596039988, 0.0281194708077237, 0.0451877652812982, 0.05067882317234762, 0.026098185226146597, 0.028797704726457596, 0.04424082195328083, 0.02494127162208315, 0.10337305226130411, 0.033096290862886235, 0.056465419111191295, 0.08842656170600094, 0.020603262601071037, 0.007985203792486573, 0.01846356735768495, 0.008558951667509973, 0.07575507290312089, 0.0491238827817142, 0.035818785399897024, 0.044210223204572685, 0.039322472002822906, 0.05293475915095769, 0.03841235775325913, 0.02382212034717668, 0.04124108330870513, 0.05372167688619811, 0.024346670325030573, 0.02042466847342439, 0.006548181854668655, 0.017893573822220787, 0.030006939741724636, 0.0604968357947655, 0.06495286113931797, 0.03593593712139409, 0.009331654491688823, 0.1088424951012712, 1.4500048058107495, 8.538738414645195, 21.226945370435715, 51.8856306374073, 64.66561406850815, 70.3325691819191, 67.81974881887436, 59.536398500204086, 47.27729111909866, 40.89630112051964, 37.240635082125664, 28.897116892039776, 35.51821790635586, 24.0991485491395, 24.901724383234978, 32.14517690241337, 37.16867074370384, 32.22297392785549, 33.01609396934509, 36.971571519970894, 25.778966210782528, 15.544277150183916, 10.811897087842226, 5.07992128841579, 0.6699355796445161, 0.239208638377022, 0.04725717728433665, 0.06745138292899355, 0.10986231733113527, 0.2544394234428182, 0.10759899698314257, 0.141836057882756, 0.3250853513600305, 0.2915706153726205, 0.35993016441352665, 0.28222418564837426, 0.859918319620192, 0.4929829342290759, 0.8538001729175448, 0.376973437378183, 1.5404619206674397, 0.9352755197323859, 0.2636821009218693, 0.18692246434511617, 0.16068156226538122, 0.09689824422821403, 0.08437767857685685, 0.09052717359736562, 0.05824161969940178, 0.284152552485466, 0.702835104893893, 1.3082466437481344, 0.8487326698377728, 1.5861946041695774, 2.1630754927173257, 2.7538530668243766, 2.050022534094751, 0.08170918270479888, 0.2545231970725581, 0.8503385586664081, 0.04060888481035363, 0.31712578784208745, 0.25586057687178254, 0.20993624115362763, 0.15646292769815773, 0.07029103289823979, 0.1047168813238386, 0.08875603816704825, 0.07073885964928195, 0.024250308015325572, 0.006408384424503311, 0.8689787553157657, 2.868822072632611, 4.979121722280979, 12.921651229262352, 19.64548923075199, 35.62283009290695, 44.90981675684452, 33.372488245368004, 34.22414414584637, 25.913197807967663, 27.186908461153507, 16.260539665818214, 18.190908282995224, 29.028521440923214, 27.81518194824457, 37.03251264989376, 29.4889123365283, 51.78493984043598, 51.652763932943344, 55.46921454370022, 60.324791595339775, 55.824636071920395, 40.63435457646847, 15.414149332791567, 4.994340855628252, 1.1411357671022415, 0.04324423636717256, 0.02643264891958097, 0.04267183270712849, 0.0646967237116769, 0.051102099678246304, 0.04948882276949007, 0.029525508543883916, 0.052957535663153976, 0.02500795915693743, 0.034497398883104324, 0.017237246247532312, 0.03896889800671488, 0.003826347365247784, 0.024505358196620364, 0.0073303990120621165, 0.07758853389532305, 0.060513949720188975, 0.03190100636857096, 0.024629022263980005, 0.04151163695496507, 0.03412548641790636, 0.03537745986250229, 0.01889350649435073, 0.03849666201858781, 0.03864246806188021, 0.02786321463645436, 0.06487676873803139, 0.02189654769608751, 0.026297080803487916, 0.04782689436979126, 0.030253653749241494, 0.05637999791360926, 0.015202488830254879, 0.03004559450346278, 0.05382192990509793, 0.11224315676372498, 0.08312676640343852, 0.06759794967365451, 0.02164300221920712, 0.06984796331380494, 0.028103917247790378, 0.025993455201387405, 0.0188909015560057, 0.02106438492774032, 0.11981459931121208, 0.0371994027227629, 0.06907762144692242, 0.01970834196981741, 0.060592235167860053, 0.050329071236774325, 0.025892654848576058, 0.08485862737870775, 0.044588933742488734, 0.024917500632000156, 0.04023451212560758, 0.03793142008362338, 0.034069777102558874, 0.04281367197108921, 0.05597016541287303, 0.04293835649150424, 0.07869020017096773, 0.013548679526138585, 0.02007472729019355, 0.04067795649461914, 0.062004857609281316, 0.06705002204398625, 0.012409201754053356, 0.0380099615722429, 0.022296171955531463, 0.07014395407168195, 0.05681999129592441, 0.06859753353637643, 0.0244515914528165, 0.05352399100956973, 0.050981764143216424, 0.008045085833146004, 0.05320836673490703, 0.027431459093349986, 0.03774410572077613, 1.5886454726569355, 10.32149825245142, 25.51601842045784, 58.8163523375988, 75.71287527680397, 82.53281012177467, 77.03634425997734, 69.40188512206078, 55.29003135859966, 53.042322769761086, 45.05992390215397, 40.48181176185608, 44.80891317129135, 33.585702404379845, 33.48880760371685, 32.866423800587654, 40.981484949588776, 41.69123366475105, 27.446200847625732, 32.632819935679436, 22.197039015591145, 14.105602148920298, 7.89626176469028, 3.5656448313966393, 0.6434811023063958, 0.3238058293936774, 0.03274397109635174, 0.13832952885422856, 0.24471135169733316, 0.7232291449327022, 0.5915584915783256, 0.5746277282014489, 1.1842861329205334, 0.7632626686245203, 0.9848363196942955, 1.4586052880622447, 1.9881789525970817, 1.594166576396674, 2.2617257991805673, 2.4756728438660502, 1.8852176587097347, 0.9810858615674078, 0.518288507591933, 0.1062220087624155, 0.15999997383914888, 0.31708030903246254, 0.10506606922717765, 0.0977555954887066, 0.13764002913376316, 0.2709904743824154, 0.5500250577460974, 4.173058625310659, 3.0841534305363894, 5.31022360548377, 4.2656587064266205, 5.683819083496928, 3.2041552662849426, 4.471213901415467, 3.3564418321475387, 1.8510407488793135, 1.094725294969976, 1.1946524516679347, 0.6721053225919604, 0.984372328966856, 0.4450589854968712, 0.1747696180245839, 0.2588809694861993, 0.25626777845900506, 0.09036764153279364, 0.139909383142367, 0.08534422202501446, 0.4642188339494169, 1.9695524708367884, 3.464291919954121, 9.772718399763107, 18.39579328894615, 31.64100095629692, 37.866332307457924, 28.142217099666595, 36.28133475780487, 30.128763802349567, 34.36771564185619, 26.676899828016758, 30.28926908969879, 44.76040877401829, 38.114250004291534, 50.88780038058758, 42.30441816151142, 61.236222088336945, 65.05144536495209, 63.38469140231609, 68.22134166955948, 63.19138817489147, 51.46203696727753, 21.967841014266014, 6.815451560541987, 1.115195034071803, 0.10160299294511788, 0.025089489645324647, 0.04079645521414932, 0.05457158440549392, 0.02695900788239669, 0.06654138371231966, 0.11082924669608474, 0.056402440459351055, 0.028435377098503523, 0.01933612336870283, 0.021391278714872897, 0.02576329108705977, 0.05697475506167393, 0.047961360396584496, 0.014168920170050114, 0.09625220467569306, 0.06545493146404624, 0.03068123471166473, 0.010935919872281374, 0.04779065158800222, 0.015655226743547246, 0.03410017176065594, 0.016598485308350064, 0.047904485909384675, 0.011116483474324923, 0.01835474067775067, 0.054585403195233084, 0.040873271209420636, 0.05188000031921547, 0.04151247558183968, 0.04795537868631072, 0.020863988356722984, 0.03200389401172288, 0.03143214344163425, 0.03869801410473883, 0.07776402213494293, 0.08192911074729636, 0.058568832610035315, 0.03986013573012315, 0.042649130409699865, 0.07387318677501753, 0.13410350249614567, 0.09809385155676864, 0.1348352897912264, 0.15497450600378215, 0.15348611399531364, 0.1624345892923884, 0.16592462779954076, 0.19114095048280433, 0.20025254983920604, 0.16027182253310457, 0.27397108788136393, 0.1451141241705045, 0.3273610136238858, 0.222948138252832, 0.16759487567469478, 0.10382329099229537, 0.1170644152443856, 0.10941094311419874, 0.17788058234145865, 0.159011225332506, 0.1494826131965965, 0.16295866429572925, 0.14563505246769637, 0.1393134385580197, 0.2103777151205577, 0.09895670955302194, 0.12355992177617736, 0.10340670123696327, 0.13674231246113777, 0.2431718257139437, 0.14816865557804704, 0.21555305225774646, 0.12483844184316695, 0.10325111739803106, 0.10852108578546904, 0.2644789300393313, 0.11683178905514069, 0.3144174534827471, 2.7989832451567054, 13.840655665844679, 31.245012804865837, 70.29125779867172, 86.56467497348785, 91.4081534743309, 86.148392111063, 77.79250368475914, 63.51635053753853, 56.802722588181496, 50.37156768143177, 43.3015226572752, 47.79752880334854, 39.269980788230896, 37.41658464074135, 47.55156420171261, 48.410606905817986, 45.21891877055168, 46.82857319712639, 47.180255725979805, 33.808742836117744, 20.15430472791195, 13.255937341600657, 6.114193489775062, 1.306682552676648, 0.5521404754836112, 0.21606537164188921, 0.34380181110464036, 0.3521493397420272, 0.8231233502738178, 0.4002321377629414, 0.44911491160746664, 0.9459217765834183, 0.6803817534819245, 0.8409591182135046, 1.001972034573555, 1.9287104811519384, 1.2898388877511024, 2.203109906986356, 2.0808329433202744, 5.642639743164182, 3.065620637498796, 0.9786562481895089, 1.8006410845555365, 0.7102084311190993, 0.6583967269398272, 0.38749361818190664, 0.5138662573881447, 0.31406243972014636, 2.492327350191772, 5.440862970426679, 6.703621186316013, 3.3209864096716046, 4.94075708091259, 7.212226269766688, 6.14932925440371, 5.505867982283235, 4.052827376872301, 2.9686973383650184, 2.6200798200443387, 0.9911287226714194, 1.0334436083212495, 0.45742883579805493, 0.8885735913645476, 0.4825315059861168, 0.21187535428907722, 0.23655050288653, 0.2551699639298022, 0.2118077891645953, 0.39103339542634785, 0.21145513543160632, 1.3114612712524831, 3.7960889283567667, 5.672176983207464, 15.69807579740882, 26.151047945022583, 44.986610636115074, 55.920850709080696, 45.02544455230236, 47.26398803293705, 34.625254422426224, 39.32211399078369, 26.266010776162148, 27.85980675369501, 41.2100350856781, 39.09035682678223, 51.89687803387642, 45.95606781542301, 68.83693903684616, 72.67166286706924, 73.15387979149818, 78.22685837745667, 73.97022798657417, 64.97956842184067, 30.852214582264423, 8.7269033677876, 1.9032151554711163, 0.17834623547969386, 0.15507153439102694, 0.07681508985115215, 0.14761962956981733, 0.17782312526833266, 0.1268773144693114, 0.2071513023111038, 0.07641493866685778, 0.14290831284597516, 0.11413589309086092, 0.08933993027312681, 0.0790245970711112, 0.16384299262426794, 0.12384902540361509, 0.1492791756754741, 0.1956092138425447, 0.14461679616943002, 0.18663222523173317, 0.08539733753423207, 0.11750480567570776, 0.18420228530885652, 0.07888559281127527, 0.09185627844999544, 0.11394565837690607, 0.10741980542661622, 0.10489746069652028, 0.19587027170928195, 0.18978605599841103, 0.06352600059472024, 0.21147958177607507, 0.15005981113063172, 0.13352260866668075, 0.10256159541313536, 0.1496052902075462, 0.08770154279773124, 0.19489903788780794, 0.10652525030309334, 0.1478338727611117, 0.15318107645725831, 0.1808189379516989], [0.023553353421448264, 0.02341053452255437, 0.033487625332782045, 0.0582730867608916, 0.025409234694961924, 0.044234068409423344, 0.03281663106463384, 0.03251246555009857, 0.03948786332330201, 0.04243912859237753, 0.06849988916656002, 0.003936131879527238, 0.053094762479304336, 0.059607917282846756, 0.02710722776100738, 0.05881907738512382, 0.045353872774285264, 0.05867497828148771, 0.02329992854356533, 0.03137836742098443, 0.03565083366993349, 0.050949484430020675, 0.028459411551011726, 0.06219073591637425, 0.048127620029845275, 0.04652735296986066, 0.021506575067178346, 0.007145859817683231, 0.025858180233626626, 0.07905443882918917, 0.03802785104198847, 0.0053791081609233515, 0.022737564286217093, 0.05916213514865376, 0.025324418347736355, 0.04490698112931568, 0.042951392315444537, 0.15357353899162263, 1.6914513311348855, 8.822521436959505, 26.159574687480927, 44.01784121990204, 64.78745073080063, 68.94334852695465, 70.660400390625, 64.5780211687088, 51.686164140701294, 51.60117790102959, 33.66458997130394, 31.346826441586018, 25.657283440232277, 17.830864302814007, 29.231120869517326, 27.1811555698514, 33.670973628759384, 47.0157815515995, 37.82165430486202, 35.806409642100334, 25.16278937458992, 10.640468336641788, 3.4336021542549133, 1.1134952190332115, 0.17482985073002055, 0.1327454167767428, 0.14943266665795818, 0.11501669621793553, 0.08620335443993099, 0.29217662347946316, 0.365659871022217, 1.0270476015284657, 0.5452811904251575, 1.777200261130929, 0.49239052226766944, 0.7649325602687895, 1.1035684891976416, 1.6675459826365113, 0.6202048575505614, 0.9954102616757154, 3.1246841931715608, 1.504703820683062, 1.0147682041861117, 0.5763842433225363, 0.5634156579617411, 0.04560695255349856, 0.021073980897199363, 0.0814589973015245, 0.1253662572707981, 0.1217017398448661, 0.20971494755940512, 0.1338349489378743, 4.236176563426852, 2.59467794559896, 4.352350579574704, 2.6813572319224477, 2.532391450367868, 2.0412979647517204, 3.577198823913932, 2.3293476831167936, 1.0444444930180907, 0.47665200429037213, 0.8599712792783976, 0.11526150105055422, 0.6711332872509956, 0.4202032426837832, 0.3350941330427304, 0.2786794805433601, 0.26464466645848006, 0.05915178218856454, 0.07137882101233117, 0.0304108999989694, 0.07377860747510567, 0.0969005523074884, 0.31054543156642467, 0.9738460031803697, 2.932541803456843, 9.146582297980785, 26.89245656132698, 47.74508781731129, 47.43891164660454, 48.905781134963036, 24.76494502276182, 26.63073990494013, 21.732390448451042, 21.83246187865734, 24.00165718048811, 10.295631140470505, 29.19223565608263, 43.25090557336807, 31.1453802511096, 47.8022101521492, 46.49057753384113, 53.00815500319004, 54.02206979691982, 53.69108475744724, 23.45890760421753, 9.07278835773468, 0.7159723062068224, 0.061371404881356284, 0.03096819909842452, 0.0058257219643564895, 0.04397129618155304, 0.023277903455891646, 0.01961298898095265, 0.017624519314267673, 0.04359700142231304, 0.012828980889025843, 0.04605591850122437, 0.008823805619613267, 0.041609793406678364, 0.028927387611474842, 0.08474104150081985, 0.03481333485979121, 0.08214307192247361, 0.03269970569817815, 0.02575665814219974, 0.05141236564668361, 0.02578713814727962, 0.04793239066202659, 0.06847887896583416, 0.019553288766473997, 0.02420638957119081, 0.04697326497989707, 0.030172726255841553, 0.007595554925501347, 0.09298804623540491, 0.014442340361711103, 0.04444992206117604, 0.02787053592328448, 0.026751265904749744, 0.010444799008837435, 0.04938089223287534, 0.033820730895968154, 0.04458177572814748, 0.05569287677644752, 0.019032425407203846, 0.03778405181947164, 0.10343099173041992, 0.05289420449116733, 0.02843441972800065, 0.02833593673130963, 0.12070919896359555, 0.014691484902868979, 0.029893548853578977, 0.041875114911817946, 0.05870004803000484, 0.015066393789311405, 0.08724050581804477, 0.015693426939833444, 0.026159243570873514, 0.016337232627847698, 0.024126027965394314, 0.08228274411521852, 0.0420683590346016, 0.04423194957780652, 0.05445254391815979, 0.04160775992204435, 0.038568501913687214, 0.0423528427927522, 0.05357957415981218, 0.034844252732000314, 0.04839942048420198, 0.09158197324723005, 0.008280108231701888, 0.05333059474651236, 0.056089139106916264, 0.01847853091021534, 0.034201601083623245, 0.062204268979257904, 0.010520077830733499, 0.05175803948077373, 0.05312732420861721, 0.03542714664945379, 0.11027273983927444, 0.2748365805018693, 2.050980795174837, 9.906104542315006, 30.057107247412205, 52.179229483008385, 78.01666125655174, 77.11158782243729, 80.89432284235954, 72.35818728804588, 60.678244829177856, 56.81470714509487, 37.819393426179886, 33.69453236460686, 29.515995383262634, 27.83713337033987, 37.55924418568611, 31.786455251276493, 32.47986674308777, 40.42964816093445, 37.21332594752312, 30.42990144342184, 17.37708505243063, 9.016583673655987, 3.1997408531606197, 0.8946653769817203, 0.13426349469227716, 0.2652501402189955, 0.390223118592985, 0.7890733180101961, 0.3593518532579765, 1.5167966717854142, 1.8281100480817258, 1.9140506302937865, 2.178738252259791, 2.93288663495332, 2.9246059292927384, 3.6513665691018105, 3.282576408237219, 4.326210832223296, 5.040430007502437, 5.495209079235792, 6.401695562526584, 2.3614697344601154, 2.117849844507873, 1.0309438174590468, 0.18434232857543975, 0.2371288585709408, 0.10760533492430113, 0.08519787050317973, 0.08039584106882103, 0.13492373895132914, 0.4482299747178331, 0.7781981828156859, 5.675846636295319, 6.567074088379741, 7.490532360970974, 4.50032508932054, 10.136858560144901, 7.286171726882458, 7.659937720745802, 4.910492654889822, 4.476696057245135, 3.8967217784374952, 3.6303344601765275, 1.8767973105423152, 2.1846253238618374, 1.636641884688288, 1.9340130966156721, 1.2096263794228435, 0.6116452231071889, 0.6977293663658202, 0.16435223951702937, 0.1021907887479756, 0.09794502868317068, 0.08338123399880715, 0.1802521597710438, 0.5649047624319792, 2.5409559532999992, 8.160475362092257, 23.535163812339306, 41.06936663389206, 43.088509887456894, 42.71653264760971, 27.501649372279644, 22.973058074712753, 22.305813878774643, 29.47859399020672, 31.802142709493637, 22.5795815885067, 42.41649314761162, 59.86339755356312, 40.49039930105209, 56.560781970620155, 55.93451477587223, 63.19370225071907, 62.67846889793873, 64.0184935927391, 29.56234149634838, 10.293354112654924, 1.1824059463106096, 0.05714593884476926, 0.057838733700918965, 0.031803295205463655, 0.014045567804714665, 0.054031582913012244, 0.04194656517938711, 0.047136871435213834, 0.0362305103772087, 0.04944103588059079, 0.032302181716659106, 0.005198823328100843, 0.015865161767578684, 0.04306692244426813, 0.035416526516200975, 0.06240857110242359, 0.04901823434920516, 0.01871926691819681, 0.04654320524423383, 0.01015041685604956, 0.030877876015438233, 0.041952725005103275, 0.04430557804880664, 0.0356263539288193, 0.030562350075342692, 0.0836730761511717, 0.03296121256425977, 0.01401008479660959, 0.03261904166720342, 0.03865830549329985, 0.056422430207021534, 0.006334602421702584, 0.04192420055915136, 0.02140231074008625, 0.033531415756442584, 0.016349403849744704, 0.005067600950496853, 0.010411801267764531, 0.027569524536374956, 0.009581367703503929, 0.2438214869471267, 0.16114869969896972, 0.12668120936723426, 0.14152425195788965, 0.208147412922699, 0.09947919636033475, 0.11832956181024201, 0.23101452650735155, 0.1971947232959792, 0.21157429466256872, 0.2262749191140756, 0.11137952693388797, 0.14748895220691338, 0.16958138236077502, 0.1467321248492226, 0.18118680571205914, 0.22987439471762627, 0.14099119696766138, 0.13243226014310494, 0.13749737350735813, 0.15514570462983102, 0.11901722842594609, 0.10589748984784819, 0.17054500174708664, 0.19575520913349465, 0.24022085359320045, 0.1524464541580528, 0.128917166730389, 0.12837009999202564, 0.1365802125656046, 0.14152088260743767, 0.1690754306036979, 0.14680543419672176, 0.16259539785096422, 0.24987088108900934, 0.1856256800238043, 0.23230372607940808, 0.496702489326708, 3.787725339643657, 14.821004960685968, 40.23152679204941, 65.81008225679398, 87.50040516257286, 87.09857672452927, 90.27073010802269, 84.01883438229561, 70.21734416484833, 67.90842086076736, 46.168005242943764, 41.89027838408947, 37.50611923635006, 29.94159534573555, 43.91184590756893, 40.471286326646805, 46.80826708674431, 59.819335117936134, 51.12323954701424, 44.551609978079796, 29.297921285033226, 13.640030231326818, 4.631443228572607, 1.8704501073807478, 0.49172350962180644, 0.29596228909213096, 0.35594002227298915, 0.5990863032639027, 0.2395113158854656, 0.7721930800471455, 1.3776188087649643, 2.1272256039083004, 2.3584650456905365, 3.3069618372246623, 3.511788183823228, 3.470289185643196, 5.709200296550989, 5.464044101536274, 4.9331997614353895, 5.544308144599199, 8.510799463838339, 3.8259128155186772, 5.372077636420727, 2.118305820040405, 2.426537205465138, 0.6912760064005852, 0.3439477173378691, 0.33000258437823504, 0.319435796700418, 0.7088669249787927, 1.2233809288591146, 2.972562680952251, 12.089578527957201, 10.232238192111254, 12.073009517043829, 10.44703496620059, 11.728774588555098, 11.14413795992732, 11.370384469628334, 6.990074040368199, 4.543582918122411, 4.5842530857771635, 2.9572293162345886, 1.596723839174956, 1.8936231639236212, 1.9868179131299257, 2.7250078646466136, 1.1387896304950118, 0.847978291567415, 0.4909333004616201, 0.1935922642587684, 0.35313960222993046, 0.2951125893741846, 0.1909421439631842, 0.6736479210667312, 1.6661461140029132, 3.893454666249454, 12.139046173542738, 34.14723627269268, 59.65882793068886, 61.383175402879715, 64.67001423239708, 36.95572257041931, 38.42176370322704, 30.859745778143406, 34.11749146878719, 35.88027007877827, 19.19050544500351, 42.54044629633427, 61.955192908644676, 46.19731307029724, 67.32180833816528, 65.65013363957405, 75.32677039504051, 71.33933275938034, 76.46278023719788, 38.76297779381275, 13.452094215899706, 2.0542210713028908, 0.2837265597190708, 0.16686080256476998, 0.11691187421092764, 0.12445947897504084, 0.13761040259851143, 0.14377723418874666, 0.14964009693358094, 0.10739392673713155, 0.1788593118544668, 0.16852760687470436, 0.0828972201270517, 0.16601904382696375, 0.14510858774883673, 0.28958531096577644, 0.1708230102667585, 0.20938812056556344, 0.13582994579337537, 0.09326426617917605, 0.1213146281952504, 0.1404311426449567, 0.10315170671674423, 0.17547013121657073, 0.10932262011920102, 0.12706288107438013, 0.12585611926624551, 0.0888494226092007, 0.08732206042623147, 0.26731304358690977, 0.11789202122599818, 0.20063386531546712, 0.11055327166104689, 0.14995084900874645, 0.13117918831994757, 0.08739832352148369, 0.18886424921220168, 0.20143047178862616, 0.11571716488106176, 0.11607683190959506, 0.1171001348120626], [0.03567804451449774, 0.03343974567542318, 0.06128230263129808, 0.0894967609201558, 0.019399755110498518, 0.048471100817550905, 0.01721586311759893, 0.05659738781105261, 0.04673585935961455, 0.035250196378910914, 0.04594880432705395, 0.04802533352631144, 0.0045938069160911255, 0.01685053350229282, 0.07847466564271599, 0.03716813604114577, 0.04579551001370419, 0.04371058341348544, 0.08615188649855554, 0.04443018464371562, 0.02705405102460645, 0.0219049599400023, 0.0337750628386857, 0.036825794450123794, 0.022157768835313618, 0.04441676661372185, 0.026518880913499743, 0.02554195853008423, 0.020140752458246425, 0.03871471242746338, 0.07374587134108879, 0.055210488208103925, 0.014385092017619172, 0.055637030163779855, 0.056302911034435965, 0.07975591681315564, 0.27615205210167915, 2.9764123493805528, 13.423788584768772, 33.25255908071995, 48.48361238837242, 70.68723455071449, 70.26261493563652, 68.07665303349495, 53.46874728798866, 51.53286896646023, 40.16179293394089, 33.84958304464817, 28.87550175189972, 31.88792310655117, 24.424318000674248, 23.102988302707672, 29.022950939834118, 33.23511801660061, 38.301378563046455, 31.791716068983078, 17.686466351151466, 6.856489833444357, 3.6129150073975325, 0.6075730884913355, 0.5247536231763661, 0.15949008869938552, 0.04580897257255856, 0.25829906633589417, 0.6182691582944244, 0.6202826939988881, 0.2754237677436322, 1.3137825904414058, 1.7867540172301233, 1.6203525150194764, 2.1937436470761895, 2.782249180600047, 3.0216223234310746, 3.7027455121278763, 2.8198469756171107, 4.805269651114941, 5.311693651601672, 6.436533043161035, 4.52262656763196, 1.4975286182016134, 0.26604958169627935, 0.5732773756608367, 0.16768679808592424, 0.06829989521065727, 0.29250687919557095, 0.015528248059126781, 0.05259877034404781, 0.22486601112177595, 0.14320637419587, 0.6171973783057183, 1.4983187383040786, 5.049626938998699, 8.179815374314785, 3.42930197250098, 9.371855109930038, 3.268556585535407, 6.734618972986937, 4.458679324015975, 3.4679857967421412, 2.7915586810559034, 2.6734674302861094, 1.978665094356984, 3.068558592349291, 1.2580336444079876, 0.8898165996652097, 1.3727035350166261, 0.76425043749623, 0.47285223787184805, 0.13277145131723955, 0.1231284964887891, 0.12943732319399714, 0.1680947418208234, 0.07145506926462986, 0.03353619889821857, 0.5433617590460926, 2.510526948608458, 6.146834688261151, 17.329156324267387, 32.38070346415043, 38.097306713461876, 44.369523748755455, 64.6805852651596, 61.46631874144077, 65.29326438903809, 49.049193039536476, 26.5194533765316, 24.811158142983913, 23.06006770581007, 30.42596485465765, 35.59352986514568, 37.528667226433754, 48.96355323493481, 47.07131937146187, 51.28956042230129, 46.625192910432816, 28.23785226792097, 10.024113859981298, 0.782490586861968, 0.04333367629442364, 0.039104017123463564, 0.039856232033343986, 0.026874916984525044, 0.010956633213936584, 0.08633515244582668, 0.04802348186785821, 0.08852993545588106, 0.0629786221543327, 0.004048046821480966, 0.053101404701010324, 0.034606694971444085, 0.05437210624222644, 0.007057047005218919, 0.06532340063131414, 0.028827550195273943, 0.018068292083626147, 0.04387147360830568, 0.02726220860495232, 0.047417087844223715, 0.030222965942812152, 0.06683332234388217, 0.05404229952546302, 0.0278458539469284, 0.033721398140187375, 0.02726686558162328, 0.02319747505680425, 0.06502273434307426, 0.08112347233691253, 0.024807096888253, 0.06846435513580218, 0.03156263155688066, 0.01651469683565665, 0.08622042383649386, 0.03962014372518752, 0.09814531207666732, 0.014678916631964967, 0.023544002360722516, 0.015393305202451302, 0.031066932569956407, 0.04250544690876268, 0.0730898127949331, 0.021467428632604424, 0.046076869330136105, 0.00897027402970707, 0.012281292601983296, 0.035118168307235464, 0.047620863042538986, 0.04283222195226699, 0.02091695358103607, 0.01704522110230755, 0.038805937219876796, 0.07780164160067216, 0.08262402072432451, 0.008913568381103687, 0.08048282077652402, 0.05447212177386973, 0.04825036012334749, 0.015135889425437199, 0.04486839687160682, 0.021712038651457988, 0.02080025828036014, 0.028218707084306516, 0.04951292030455079, 0.03346578392665833, 0.045901314297225326, 0.05199440238357056, 0.03984186776506249, 0.047387776721734554, 0.03778272708586883, 0.024384152493439615, 0.138947396480944, 0.012218361262057442, 0.1404227563762106, 0.4381755361100659, 3.259658650495112, 15.279669798910618, 39.330811724066734, 61.51475474238396, 83.4282548725605, 79.36081632971764, 77.83750846982002, 65.59474781155586, 65.60265898704529, 53.5006769746542, 47.75390714406967, 38.85605379939079, 38.41244280338287, 28.395439311861992, 27.990297451615334, 36.404349356889725, 34.09232161939144, 36.382466331124306, 25.276192389428616, 16.642248183488846, 7.067090682685375, 3.1271186750382185, 0.6331397197209299, 0.34727740741800517, 0.18949951278045774, 0.21744647878222167, 0.6070402264595032, 1.1387205217033625, 1.6071741096675396, 2.640730761922896, 4.030139269307256, 4.405109323561192, 4.843713138252497, 6.012962646782398, 5.867211492732167, 7.433407651260495, 7.395384991541505, 7.102533280849457, 9.03774093836546, 8.929248210042715, 7.561662644147873, 10.035081021487713, 2.591923330910504, 1.759564457461238, 0.39782953856047243, 0.2887733420357108, 0.2713186520850286, 0.40987317042890936, 0.0391188378125662, 0.07385662203887478, 0.16931076563196257, 0.3717357449932024, 1.5648498432710767, 7.046532835811377, 8.174033984541893, 8.587480299174786, 6.944518759846687, 8.627310711890459, 8.811236042529345, 5.808360725641251, 9.312000721693039, 8.155034054070711, 7.953311428427696, 6.729097394272685, 6.100106220692396, 6.0901944525539875, 2.447871398180723, 3.8955317297950387, 3.06682659778744, 2.0442724926397204, 1.8368631158955395, 1.1933026928454638, 0.5843407195061445, 0.5676161544397473, 0.5226710380520672, 0.19190175575204194, 0.10521963442442939, 0.44302971626166254, 1.9872690201736987, 6.262091053649783, 17.326887845993042, 29.732587561011314, 36.02497011423111, 34.17634271085262, 47.79347822070122, 44.26846817135811, 55.08869916200638, 50.65838769078255, 29.854904897511005, 35.99211327731609, 33.044197261333466, 41.04089476168156, 44.04623329639435, 46.16209656000137, 56.34445957839489, 57.61030085384846, 61.61620169878006, 56.26008130609989, 32.34936274588108, 11.43730552867055, 1.0219063586555421, 0.05380311646149494, 0.07696746761212125, 0.06552433711476624, 0.041476310725556687, 0.05832534508954268, 0.10604013063129969, 0.08699010519194417, 0.04153381603828166, 0.029017094711889513, 0.04003531597845722, 0.03225660642783623, 0.026762618908833247, 0.07374982698820531, 0.010439857232995564, 0.017501857146271504, 0.08068770548561588, 0.04570738739857916, 0.06842270580818877, 0.03844049628241919, 0.010165452767978422, 0.02718643532716669, 0.04134367780352477, 0.06786480371374637, 0.07736502870102413, 0.03733285571797751, 0.05444381255074404, 0.04062699692440219, 0.05073664760857355, 0.03799013880779967, 0.024709498902666382, 0.04632367425074335, 0.014229726184566971, 0.07603688121889718, 0.02232364069641335, 0.004634723836716148, 0.02286233786435332, 0.011772907528211363, 0.032109297535498627, 0.10274365165969357, 0.14880506205372512, 0.21418197895400226, 0.1952061682823114, 0.08318465392221697, 0.17599576473003253, 0.08288253302453086, 0.13518850755644962, 0.1462093263398856, 0.16068082011770457, 0.26008900778833777, 0.10574788029771298, 0.11391500025638379, 0.041932779786293395, 0.1715342846000567, 0.17892787145683542, 0.12521644734079018, 0.35368006385397166, 0.23974164883838966, 0.10038778549642302, 0.15665578219341114, 0.13319352554390207, 0.11345831226208247, 0.14150077040540054, 0.14012666913913563, 0.10084435474709608, 0.0933390820864588, 0.2216919494094327, 0.12301148206461221, 0.1305016371770762, 0.13086477003525943, 0.1246703157084994, 0.17011906835250556, 0.18458478822140023, 0.21420068107545376, 0.18730714917182922, 1.01231211097911, 4.843660416081548, 20.196982137858868, 49.56234410405159, 73.56529891490936, 92.85282835364342, 90.55659636855125, 85.92880189418793, 73.10705870389938, 68.47468927502632, 55.15178717672825, 49.203407764434814, 41.90438702702522, 46.47640809416771, 38.47361572086811, 36.516804322600365, 43.175935596227646, 49.02051977813244, 51.980663537979126, 41.933371871709824, 23.949009105563164, 9.481312986463308, 4.580010138452053, 0.9833729232195765, 0.9206159063614905, 0.21042827022029087, 0.19901475141523406, 0.4317707719746977, 1.5489201480522752, 1.29586880793795, 2.2009618347510695, 5.4306381940841675, 5.905663529410958, 6.213616104796529, 8.429042100906372, 10.276666358113289, 8.001525141298771, 9.701770506799221, 12.583299335092306, 12.592510040849447, 11.559787206351757, 14.511322528123856, 15.581155121326447, 6.992157278582454, 3.7436849903315306, 2.297060340642929, 0.6205454736482352, 0.34639882331248373, 0.6655151105951518, 0.16988854244118556, 0.36652922281064093, 0.3914779715705663, 0.7451046898495406, 1.9344960269518197, 9.249343033879995, 15.624884124845266, 20.31056184321642, 12.888869438320398, 21.225892826914787, 12.677571326494217, 16.088032722473145, 13.898282423615456, 8.853184841573238, 9.998197350651026, 9.436670131981373, 8.633942306041718, 10.333758294582367, 5.048733511939645, 4.907914018258452, 4.574983008205891, 2.5745231145992875, 1.907859812490642, 0.7242832914926112, 0.5948733387049288, 0.5453121231403202, 0.494257053360343, 0.33653933205641806, 0.3240478882798925, 0.8239016553852707, 3.154920833185315, 8.157359529286623, 22.810155116021633, 42.1563895046711, 50.38421340286732, 58.79269100725651, 79.90085855126381, 71.82693019509315, 78.22303578257561, 60.202286168932915, 37.92805999517441, 36.18216387927532, 35.60635797679424, 45.23118831217289, 51.47209122776985, 53.755768686532974, 65.83316221833229, 71.1077731847763, 71.68425545096397, 68.68958294391632, 43.18478152155876, 17.412643544375896, 1.791404492687434, 0.1383601943962276, 0.1873650960624218, 0.22283582162344828, 0.07793202210450545, 0.26213929464574903, 0.2782035857671872, 0.1976468990324065, 0.1847758170333691, 0.2150008498574607, 0.0765964828315191, 0.15197110857116058, 0.1310731057310477, 0.27396776305977255, 0.06563430855749175, 0.0896562187699601, 0.18790175789035857, 0.11034415671019815, 0.16170946648344398, 0.11412219304475002, 0.1125451663392596, 0.12560239381855354, 0.09597987358574755, 0.1247461632010527, 0.23313787038205191, 0.0690734876843635, 0.2143354996223934, 0.11711318176821806, 0.23147963045630604, 0.13283963984576985, 0.17350119858747348, 0.1676907017827034, 0.17468198522692546, 0.18799451150698587, 0.14252729422878474, 0.12208777538035065, 0.23378721991321072, 0.11819098057458177, 0.14551538857631385], [0.07392948609776795, 0.032127324302564375, 0.07773478151648305, 0.043568740438786335, 0.0054751434618083294, 0.024273116068798117, 0.04565522925986443, 0.01706743914837716, 0.010897755855694413, 0.02311396488948958, 0.06672905059531331, 0.04366090404801071, 0.006305324232016574, 0.028004855375911575, 0.044462553414632566, 0.042997338678105734, 0.09399559334269725, 0.04482821328565478, 0.023673599898756947, 0.06494886838481762, 0.03399751789402217, 0.11138228030176833, 0.06476425172877498, 0.019931205206376035, 0.0944264026475139, 0.010725195388658904, 0.06591732657398097, 0.07572248519863933, 0.031193928880384192, 0.022105606985860504, 0.03462317064986564, 0.008634503228677204, 0.04423572710948065, 0.02348455076571554, 0.0466374060488306, 0.12292734478251077, 2.148273861967027, 12.603177018463612, 36.66738644242287, 59.37466777861118, 75.04373878240585, 75.94970136880875, 66.98381647467613, 60.322424322366714, 46.09289467334747, 36.03983111679554, 28.464122526347637, 21.57258052378893, 18.05386483669281, 16.741086579859257, 25.310620442032814, 33.45837123692036, 40.31802915036678, 25.594676099717617, 17.89273638278246, 10.044340174645185, 4.920057691633701, 1.2196218618191779, 0.33742465486284345, 0.21475876128533855, 0.054053309286246076, 0.052644913375843316, 0.15975365502526984, 0.8577609260100871, 1.5655330941081047, 2.9761629877611995, 4.036538600921631, 3.468274106271565, 4.168073767796159, 3.51386405993253, 3.8611055770888925, 3.846873678267002, 5.489761596545577, 7.503708628937602, 3.004774027504027, 5.310817323625088, 9.025455247610807, 5.918661681935191, 7.678242288529873, 1.7174261435866356, 1.2366493418812752, 0.44020311324857175, 0.09530420749797486, 0.5538452777545899, 0.6420671031810343, 0.02600305302621564, 0.07959160531754605, 0.1468694073264487, 0.2378074190346524, 0.9696303668897599, 5.592436837032437, 5.102973226457834, 5.299875335767865, 3.4321843553334475, 8.800263181328773, 7.328265868127346, 5.57897605933249, 6.053230985999107, 8.313959576189518, 4.795717438682914, 5.820581819862127, 2.7635976439341903, 4.380089091137052, 1.8737243441864848, 1.5023428411222994, 1.463900541421026, 1.9264601706527174, 1.8227638537064195, 0.839995751157403, 0.16208649234613404, 0.4267677169991657, 0.22959889465710148, 0.12060713139362633, 0.014432299103646073, 0.0629179367388133, 0.0650425793719478, 1.0276086651720107, 3.6637023696675897, 13.391454219818115, 28.470737971365452, 50.11196181178093, 60.548056215047836, 91.85326918959618, 97.6887072622776, 79.70441669225693, 47.786023020744324, 34.16248485445976, 25.5039369687438, 17.69390445202589, 17.436430267989635, 29.070110209286213, 43.49248141050339, 42.98711992800236, 51.84805065393448, 55.36237567663193, 48.90122517943382, 22.048062309622765, 5.7321529649198055, 0.1363507256610319, 0.12900508154416457, 0.05063442047685385, 0.04589525837218389, 0.03669741032354068, 0.049877374185598455, 0.05650839317240752, 0.013248794348328374, 0.024602525736554526, 0.046889339209883474, 0.042795745393959805, 0.04502886033151299, 0.058341097173979506, 0.08566949793021195, 0.042344070607214235, 0.06832759958342649, 0.045180106317275204, 0.052158513499307446, 0.06987266940996051, 0.013019683156016981, 0.028340731005300768, 0.03262546124460641, 0.02297179165907437, 0.0328384168096818, 0.06204752738995012, 0.05023506710131187, 0.1226364822650794, 0.039859100434114225, 0.05511336334166117, 0.023120065343391616, 0.05179909880098421, 0.0919717714714352, 0.029755078940070234, 0.07776984799420461, 0.027320270528434776, 0.01867282702733064, 0.050425075460225344, 0.03195704965037294, 0.04608932256815024, 0.03314431152830366, 0.044361784603097476, 0.07867470412747934, 0.0121139744805987, 0.03521357510180678, 0.009036015326273628, 0.023024838519631885, 0.00793678422269295, 0.03839876902929973, 0.08153026574291289, 0.053543361063930206, 0.0398016730468953, 0.043782876018667594, 0.06130114947154652, 0.01918088091770187, 0.04346786401583813, 0.04152180066739675, 0.07096844303305261, 0.046331043777172454, 0.08692507821251638, 0.06486245270934887, 0.008618458923592698, 0.06989252186031081, 0.06916903919773176, 0.01969563640159322, 0.09702840208774433, 0.054843403413542546, 0.04374616197310388, 0.034024817796307616, 0.026108937090612017, 0.014749707315786509, 0.0348075164220063, 0.05534215262741782, 0.0219155169907026, 0.26793493365403265, 2.525284169241786, 14.870578050613403, 44.08616915345192, 67.35883355140686, 83.97971168160439, 84.68569099903107, 77.63077676296234, 68.44073429703712, 56.95037506520748, 46.8471921980381, 38.55105936527252, 33.25738862156868, 29.78412039577961, 26.692857071757317, 31.835094541311264, 33.99331413209438, 37.270391285419464, 25.37074651569128, 17.591169364750385, 9.573486540466547, 4.164795493707061, 1.0721663804724813, 0.09557840880006552, 0.11888873297721148, 0.20154039870249107, 0.33380745677277446, 0.959374182857573, 2.9959300020709634, 3.3805646002292633, 4.424080280587077, 5.5527702905237675, 6.257548397406936, 6.08096569776535, 5.194892669096589, 6.689294530078769, 8.86581726372242, 13.009016141295433, 8.422976676374674, 8.732198383659124, 9.427180141210556, 11.554714478552341, 8.910057339817286, 8.248863369226456, 3.1130572920665145, 1.3435151637531817, 0.8070500346366316, 0.10761314231785946, 0.6164572492707521, 0.3095532691804692, 0.221902095945552, 0.10899934801273048, 0.1682976895244792, 0.9838561504147947, 2.663448555395007, 6.707894057035446, 9.75093511864543, 8.638319671154022, 9.060766752809286, 9.143414217978716, 9.861244149506092, 8.879737816751003, 10.708889365196228, 9.47578713297844, 11.137973740696907, 7.623921828344464, 6.53348246589303, 9.484706204384565, 6.148833855986595, 5.967516610398889, 6.1559926718473434, 4.297899501398206, 4.969304474070668, 2.7418566355481744, 2.2936602355912328, 1.0914491582661867, 0.5078266002237797, 0.39518312900327146, 0.18491919996449724, 0.06653056319919415, 0.057316495513077825, 0.8325536723714322, 3.916530115529895, 11.931550707668066, 24.618276692926884, 46.08290880918503, 62.3322656750679, 86.61155685782433, 99.42416533827782, 83.8799062371254, 49.660432040691376, 37.722407430410385, 32.953249141573906, 28.897639364004135, 27.52985905855894, 38.78644913434982, 53.11970941722393, 53.778681457042694, 61.90698489546776, 65.67450553178787, 58.00313137471676, 26.22627440840006, 7.641342468559742, 0.21451973036164418, 0.15037111239507794, 0.08098904712824151, 0.01756417714204872, 0.014353120295709232, 0.06828768688137643, 0.01112294015911175, 0.01870868760306621, 0.018821187913999893, 0.048098149345605634, 0.05862193327629939, 0.07199369778390974, 0.04283165792003274, 0.04043445413117297, 0.03211755021766294, 0.035313783591846004, 0.05025960621424019, 0.027704740132321604, 0.05982691021927167, 0.024849308392731473, 0.011223517867620103, 0.047629390319343656, 0.02050407085334882, 0.01535515695650247, 0.04484317498281598, 0.03553732589352876, 0.18658725108252838, 0.030289768510556314, 0.010978623049595626, 0.06621196662308648, 0.01101786410799832, 0.03331033367430791, 0.021864349619136192, 0.06378083184245043, 0.05639246228383854, 0.02377384178544162, 0.04971818721969612, 0.03125349736365024, 0.12156219381722622, 0.14046639465959743, 0.13022074912441894, 0.10944918598397635, 0.10572680330369622, 0.1946916669839993, 0.1871830175514333, 0.14566497586201876, 0.050596467044670135, 0.18952217797050253, 0.25507945159915835, 0.19402033503865823, 0.16191965754842386, 0.11596654876484536, 0.1522038906114176, 0.10578499510302208, 0.13675783819053322, 0.20561137556796893, 0.1257999090012163, 0.1260440013720654, 0.19516257452778518, 0.21344682230846956, 0.13815911690471694, 0.18163973843911663, 0.2194559623603709, 0.09632489061914384, 0.24192607146687806, 0.17456754605518654, 0.09425475131138228, 0.12068703843397088, 0.13264405424706638, 0.08198128372896463, 0.09855963828158565, 0.11988137033767998, 0.18802860577125102, 0.43650781153701246, 4.79751949198544, 21.640640571713448, 55.03075987100601, 79.63634714484215, 98.55088859796524, 95.88916182518005, 87.26674050092697, 77.38122135400772, 61.130808144807816, 48.48808094859123, 41.342670768499374, 32.183847427368164, 26.652400642633438, 25.19581340253353, 37.14607335627079, 47.36376687884331, 55.93811698257923, 35.842416509985924, 25.3256144374609, 13.80528336390853, 6.544347507879138, 1.8686707341112196, 0.7173722342122346, 0.5071195412892848, 0.47604673833120614, 0.23081053979694843, 0.826781663345173, 2.381715760566294, 4.5965207275003195, 6.825346229597926, 9.977793395519257, 11.751902047544718, 12.593528386205435, 10.752759911119938, 12.613554261624813, 13.219320606440306, 15.500108320266008, 19.892219491302967, 12.928017787635326, 15.382725019007921, 22.36016236245632, 19.070534482598305, 18.73596053570509, 4.8487787414342165, 4.584093019366264, 1.8876756518147886, 0.28360220545437187, 1.7946687550283968, 1.2380888708867133, 0.7470709655899554, 0.4376476019388065, 0.40322406159248203, 0.6126103713177145, 2.9274303652346134, 17.45512716472149, 15.827942378818989, 18.739747032523155, 12.508049122989178, 18.801634311676025, 20.848778262734413, 15.855007376521826, 19.62187919765711, 21.247939243912697, 16.458096764981747, 15.142613053321838, 11.900733411312103, 12.374094910919666, 8.415481578558683, 8.504049126058817, 7.0251608826220036, 5.265701869502664, 7.084782058373094, 3.2933702040463686, 1.4780622627586126, 1.1362278554588556, 0.31891789636574686, 0.34837115497794, 0.2249139835475944, 0.21148661733604968, 0.19890731811756268, 1.4902635267935693, 5.223105680197477, 17.266436889767647, 35.34080162644386, 57.636109068989754, 66.7086124420166, 96.80084690451622, 99.33987826108932, 87.48164936900139, 57.506615817546844, 48.3162921667099, 40.7481736689806, 29.922442473471165, 31.074460856616497, 45.484684109687805, 61.260491386055946, 59.08633925020695, 73.0744032561779, 76.26721993088722, 71.04389861226082, 35.27451418340206, 11.704915668815374, 0.3898524009855464, 0.22609287028899416, 0.18450230592861772, 0.13967685343232006, 0.16690004733391106, 0.17427883576601744, 0.140342945815064, 0.09323214602773078, 0.12618919514352456, 0.20843520294874907, 0.2311794168781489, 0.2385749333188869, 0.13457271794322878, 0.16104478418128565, 0.1140274950012099, 0.1679028372745961, 0.17855130572570488, 0.1565932043013163, 0.19535087223630399, 0.08441525351372547, 0.11620400633546524, 0.14180282450979576, 0.12423489766661078, 0.10416602963232435, 0.20471716183237731, 0.1333286557928659, 0.28411868086550385, 0.1191309848218225, 0.14784429251449183, 0.14747731533134356, 0.1341649968526326, 0.18630676378961653, 0.13460629270412028, 0.1490344450576231, 0.21399866847787052, 0.10379218016169034, 0.09196472106850706, 0.13436812267173082], [0.024631604937894735, 0.020257737196516246, 0.040235480628325604, 0.025063931934710126, 0.05715904517273884, 0.06678135716356337, 0.02490258717443794, 0.0492336798197357, 0.03192117052094545, 0.06688199980999343, 0.020154502599325497, 0.04895305522950366, 0.057040539031731896, 0.06379017548169941, 0.06896661841892637, 0.018428740222589113, 0.032690061489120126, 0.047876083917799406, 0.04409881941683125, 0.0028074068995920243, 0.04561983252642676, 0.016956517756625544, 0.016704668087186292, 0.0642231667006854, 0.054904764183447696, 0.0606473990046652, 0.033829076346592046, 0.05479462204675656, 0.01749339480738854, 0.10204242600593716, 0.03585248632589355, 0.0485152103647124, 0.04461412965611089, 0.07739611726719886, 0.023831476974010002, 2.2243239311501384, 18.523306846618652, 39.56732243299484, 62.70831249654293, 75.294950902462, 75.44331014156342, 63.59831973910332, 62.87581890821457, 45.15274152159691, 39.0004688501358, 29.167626276612282, 25.516751781105995, 22.3841105774045, 29.521001614630222, 26.372239775955677, 33.989689126610756, 41.71053662896156, 35.41626177728176, 16.600401028990746, 7.627706900238991, 1.5624704584479332, 0.09745436516823247, 0.07177192921517417, 0.029073258592688944, 0.0704259256599471, 0.3096513217315078, 1.0892956238240004, 1.2099385564215481, 1.650333737488836, 1.5161581872962415, 3.572031338699162, 3.3980883099138737, 3.90159762930125, 3.0927350325509906, 3.7125701224431396, 4.941264828667045, 7.172141270712018, 12.575012929737568, 5.1542680989950895, 7.716398891061544, 8.856484964489937, 6.790114045143127, 4.82954939827323, 5.390408802777529, 2.2329302318394184, 0.7380908005870879, 0.3518762590829283, 0.05042303084337618, 0.5463454895652831, 0.1995861902832985, 0.4099911719094962, 0.3989731287583709, 2.779707354493439, 3.241670415736735, 3.662836253643036, 5.412484193220735, 7.8363171312958, 5.156488129869103, 8.512921649962664, 4.079967895522714, 7.988484241068363, 3.396809916011989, 8.31819349899888, 7.937844833359122, 7.549739833921194, 4.912318456918001, 5.287339333444834, 6.808879338204861, 1.5942907822318375, 4.752842914313078, 4.478436838835478, 3.1629110919311643, 4.595862412825227, 3.2665182324126363, 2.6428807340562344, 2.3883117316290736, 1.506214002147317, 0.39559410070069134, 0.3738048824016005, 0.09856300021056086, 0.2695279091130942, 0.042329702628194354, 0.2717774180928245, 1.6333588608540595, 7.730775894597173, 15.14514846727252, 32.51575581729412, 42.479767352342606, 35.96100054681301, 41.150929257273674, 57.92961671948433, 56.383711472153664, 37.65896983444691, 23.376125246286392, 22.858135141432285, 42.236249819397926, 29.640569798648357, 34.0843952447176, 51.37616917490959, 51.1894927918911, 47.66956686973572, 38.2476494461298, 16.690887473523617, 2.413292066194117, 0.046403711166931316, 0.02730542386416346, 0.06763383993529715, 0.02419391406874638, 0.021661012287950143, 0.06542880786582828, 0.02675843505130615, 0.05508021902642213, 0.023237231907842215, 0.010141336679225788, 0.036225040748831816, 0.047011500428197905, 0.04441612836671993, 0.011525926347530913, 0.018741525782388635, 0.07534646123531274, 0.027899553897441365, 0.009248959759133868, 0.05856036841578316, 0.09084353630896658, 0.017862002860056236, 0.05010130240407307, 0.05002381847589277, 0.07772699638735503, 0.00537554306902166, 0.051726553865591995, 0.026480035048734862, 0.04701290308730677, 0.027561535316635855, 0.03868794687150512, 0.022203045409696642, 0.03307158847746905, 0.03078446188737871, 0.04824768839171156, 0.018549352207628544, 0.049502207402838394, 0.026086177276738454, 0.04159958887612447, 0.012215038295835257, 0.016200063328142278, 0.027328805226716213, 0.019081505488429684, 0.06695691219647415, 0.0124710950149165, 0.027837473244289868, 0.06674992720945738, 0.03527836459397804, 0.05352870735805482, 0.0459457615215797, 0.05210433300817385, 0.054186517372727394, 0.05425486546300817, 0.05024516773119103, 0.014443757863773499, 0.034027593428618275, 0.04894737408903893, 0.06265993652050383, 0.04179851785011124, 0.004289507814974058, 0.04772519416292198, 0.12262102332897484, 0.012541329087980557, 0.05470523035910446, 0.02097857039188966, 0.03983866539783776, 0.02432388824672671, 0.011458225781098008, 0.036736399051733315, 0.05866664396307897, 0.03059615675738314, 0.015937584248604253, 0.030159104135236703, 3.0148971593007445, 20.12591265141964, 47.55847983062267, 72.72006466984749, 83.88907134532928, 85.75129061937332, 73.16393405199051, 73.5127629339695, 59.77272301912308, 49.08071994781494, 41.3510113209486, 33.157415986061096, 27.288224324584007, 29.73319362848997, 17.51384161412716, 30.93638576567173, 34.65928539633751, 25.77888261526823, 12.701497692614794, 5.750347338616848, 1.757933869957924, 0.3141687746392563, 0.12076106024323963, 0.2139612048631534, 0.24117875844240189, 0.8077109616715461, 3.936904384754598, 3.886099923402071, 4.731268147006631, 6.203150516375899, 8.612091578543186, 8.58016474172473, 7.780568422749639, 6.686941981315613, 8.451868426054716, 12.032176908105612, 7.490852968767285, 14.115888196974993, 12.436050586402416, 8.077538162469864, 8.768302146345377, 10.147270951420069, 10.064958818256855, 6.182942250743508, 4.565768027678132, 1.955627049319446, 0.8470941858831793, 0.2446964493719861, 1.0236784885637462, 0.39228783280123025, 0.17304238805081695, 0.436215553781949, 2.1418391447514296, 3.511008988134563, 5.687808869406581, 3.7913192342966795, 6.730668609961867, 6.2071616761386395, 7.513823686167598, 11.12702937796712, 10.044867396354675, 7.823574990034103, 10.969259943813086, 8.561470694839954, 6.784894075244665, 8.919869363307953, 7.062444007024169, 6.63561481051147, 6.83222908526659, 7.419958747923374, 7.57080115377903, 6.7527819983661175, 5.395045028999448, 5.082033025100827, 6.774741495028138, 3.401722339913249, 2.4682822404429317, 2.5025378772988915, 1.1671245913021266, 0.5145560984965414, 0.28635673108510673, 0.12942124827532098, 0.1259485018090345, 2.0970906084403396, 7.909029079601169, 19.2946008592844, 38.3300594240427, 57.62438289821148, 46.060945987701416, 44.365039989352226, 47.297323644161224, 51.23284466564655, 34.794512540102005, 25.753247290849686, 29.554595611989498, 51.58505916595459, 39.818929731845856, 43.58161702752113, 59.429859817028046, 60.377870947122574, 57.345018088817596, 44.22202326357365, 20.054269395768642, 3.156031798571348, 0.08980957616586238, 0.04316711609135382, 0.02250951343739871, 0.04646576213417575, 0.029166572530812118, 0.052604815136874095, 0.056686879688641056, 0.019527102085703518, 0.02841210149199469, 0.01717157916573342, 0.025460062533966266, 0.01467493872041814, 0.04796655543032102, 0.06648968570516445, 0.029504357335099485, 0.014571345109288814, 0.02510529368009884, 0.0478286792349536, 0.03198348123987671, 0.1447750220540911, 0.0331869738874957, 0.06802308154874481, 0.0286435550879105, 0.019524478593666572, 0.012306238040764583, 0.021387443666753825, 0.04052667711221147, 0.0012782654175680364, 0.029507917788578197, 0.025362360647704918, 0.07918167262687348, 0.08917052764445543, 0.02657602813997073, 0.04699047909525689, 0.008486931801598985, 0.01889320777991088, 0.05716144973121118, 0.15287479211110622, 0.15376459748949856, 0.17096737283281982, 0.08554662796086632, 0.20473559678066522, 0.10420787933981046, 0.149796511977911, 0.11915583934751339, 0.15421482879901305, 0.1451904614805244, 0.23068369191605598, 0.21778798545710742, 0.12302766830543987, 0.1609391171950847, 0.1642347130109556, 0.1243529214116279, 0.11816287544206716, 0.11802940760389902, 0.12902396178105846, 0.18340388283832, 0.1935624299221672, 0.10004894313169643, 0.11998937508906238, 0.17281281208852306, 0.08044846676057205, 0.1593723098631017, 0.1544326639850624, 0.10163300539716147, 0.14937019266653806, 0.22897725692018867, 0.11095432084403001, 0.16025591088691726, 0.12142649953602813, 0.15682208264479414, 0.10110935341799632, 5.3726124577224255, 29.43275135010481, 58.993468433618546, 86.32094845175743, 95.36943331360817, 92.76047050952911, 80.2554403245449, 80.19452199339867, 60.69347061216831, 52.168681249022484, 42.062154561281204, 35.95458649098873, 31.336937472224236, 41.36394202709198, 39.5430151373148, 48.705265894532204, 55.937862396240234, 45.058221593499184, 21.538800336420536, 10.676282364875078, 2.5486104050651193, 0.4284708568593487, 0.28967861377168447, 0.30300387530587614, 0.1497897584340535, 0.5907452164683491, 3.6461900593712926, 4.3071334809064865, 6.65200618095696, 9.231746178120375, 11.84256898239255, 13.011147826910019, 13.064059987664223, 10.882844030857086, 16.666471883654594, 16.492676809430122, 16.3809647038579, 25.559573583304882, 15.855138469487429, 20.31764656305313, 21.99087157845497, 20.10600931942463, 15.69886140525341, 15.476557184010744, 7.858711229637265, 3.4487343672662973, 1.6082936245948076, 0.4164056433364749, 2.619741400703788, 0.6787917762994766, 0.7194059563335031, 0.6228567590005696, 3.454121290706098, 5.613517630845308, 8.337648455053568, 16.712878793478012, 18.88210829347372, 14.685832913964987, 22.248243167996407, 17.24543921649456, 18.77638466656208, 13.605416938662529, 19.440057054162025, 18.60564462840557, 18.891812972724438, 14.510509371757507, 14.913248810917139, 19.376302175223827, 10.117825381457806, 15.298683028668165, 14.193976856768131, 10.928116701543331, 11.564195919781923, 7.678437028080225, 8.293376080691814, 5.448816418647766, 4.58982216194272, 1.8756343354471028, 1.1536057479679585, 0.43490723648574203, 0.4471659130649641, 0.25885074923280627, 0.7142844842746854, 2.6742314267903566, 8.951202481985092, 18.724840432405472, 40.357820615172386, 52.42259502410889, 48.040081188082695, 53.17514844238758, 68.29289942979813, 67.93089285492897, 49.47923116385937, 35.38706414401531, 37.25668162107468, 57.12591424584389, 44.878434240818024, 52.833611369132996, 71.3869746029377, 69.85199376940727, 69.40905153751373, 56.94011561572552, 27.25446503609419, 5.732429400086403, 0.38263816153630614, 0.14702257176395506, 0.11159955145558342, 0.12930789263918996, 0.1365743050700985, 0.17587249400094151, 0.13633205322548747, 0.15200926980469376, 0.07595480710733682, 0.09138081411947496, 0.17277561564696953, 0.10709793597925454, 0.16618344438029453, 0.16353212180547416, 0.06016854677000083, 0.16512347938260064, 0.12265580036910251, 0.13742701790761203, 0.18574607121990994, 0.27123894542455673, 0.1332541144802235, 0.147902729222551, 0.1407558619393967, 0.09212518823915161, 0.2169722761027515, 0.11025311003322713, 0.07795039768097922, 0.14653987891506404, 0.07754934107651934, 0.1920465042348951, 0.15901913662673905, 0.19034780241781846, 0.10858843568712473, 0.14647223957581446, 0.1021968966233544, 0.1377103995764628, 0.1740748787415214], [0.06056300197087694, 0.07327024373807944, 0.07312997782719322, 0.02636720077134669, 0.009103216798393987, 0.0631915962731, 0.011806144611909986, 0.005286615223667468, 0.01902167725347681, 0.05099646237795241, 0.011519983600010164, 0.021374754796852358, 0.029721099708694965, 0.032681682641850784, 0.04149482731008902, 0.04770052888488863, 0.06824034528108314, 0.049612709481152706, 0.0265988751561963, 0.06836157510406338, 0.040885182679630816, 0.0305282873523538, 0.011518283154146047, 0.03380360583832953, 0.05747170827817172, 0.06440624711103737, 0.07061569282086566, 0.10145511259906925, 0.06600268839974888, 0.05157352672540583, 0.08372160518774763, 0.03765646179090254, 0.04596037440933287, 0.2192979442770593, 2.7387329656630754, 14.135142713785172, 47.564304918050766, 62.17020057141781, 72.57561922073364, 71.71019285917282, 63.24791394174099, 59.067857041954994, 45.282325968146324, 33.08360114693642, 37.612935304641724, 21.201794520020485, 24.956895522773266, 31.459142714738846, 42.86120608448982, 48.23407597839832, 47.60851934552193, 26.55389092862606, 10.70443220436573, 3.615778391249478, 0.6140326231252402, 0.08909781943657435, 0.05404862262366805, 0.16393772035371512, 0.025191139757225756, 0.6910299696028233, 0.5420380644500256, 2.089470592327416, 2.387360595166683, 6.2164075300097466, 4.477756200358272, 3.7345429183915257, 5.854550572112203, 4.50283532962203, 3.6360821267589927, 3.6299711046740413, 7.862196592614055, 5.051122633740306, 12.537735030055046, 10.408414788544178, 3.239335441030562, 5.546911479905248, 8.793351352214813, 4.816339882090688, 5.47363811172545, 2.430971092544496, 0.0731786924006883, 0.673305286327377, 0.14058074477361515, 0.45131763559766114, 0.013562842486862792, 0.9868838754482567, 7.536485670134425, 10.660890340805054, 18.373439088463783, 14.26912922412157, 3.9187793573364615, 6.51725591160357, 4.004566641524434, 4.943276345729828, 8.60056584700942, 6.687206542119384, 9.100814703851938, 7.10339535959065, 6.704532187432051, 8.00122020766139, 5.775180906057358, 3.541529425419867, 5.152933420613408, 8.189409859478474, 5.667421538382769, 6.939749540761113, 5.330372974276543, 4.130848115310073, 2.9740849742665887, 5.763955833390355, 1.6372057981789112, 1.4615635480731726, 2.2106099920347333, 1.139895727392286, 0.23745915881590918, 0.14646052848547697, 0.09136270571616478, 0.019977945667051245, 0.14517077972413972, 0.7455365604255348, 2.996187200769782, 10.160612035542727, 20.373142585158348, 39.252159744501114, 64.77692529559135, 84.96610835194588, 88.91325294971466, 62.262011244893074, 39.12936553359032, 21.217951253056526, 26.28535933792591, 31.956802010536194, 30.360315777361393, 39.01176184415817, 48.75132702291012, 55.9528411924839, 41.910785883665085, 22.048550583422184, 11.145374793559313, 0.3811171744018793, 0.026641019867383875, 0.014504381124424981, 0.02020682586589828, 0.004476104149944149, 0.061818511749152094, 0.055147097664303146, 0.11996501038083807, 0.1145490986527875, 0.018299022085557226, 0.02623198332003085, 0.05505494147655554, 0.01733486835291842, 0.08802324897260405, 0.07376734909485094, 0.07939866918604821, 0.054663243354298174, 0.01907482059323229, 0.025713895593071356, 0.06639728089794517, 0.027641934029816184, 0.06762140896171331, 0.03401811249204911, 0.10544988574110903, 0.047324490078608505, 0.045928209729027, 0.05573726833972614, 0.024970699632831383, 0.021885821806790773, 0.033369701777701266, 0.014054074672458228, 0.054363634626497515, 0.0573584194353316, 0.05600140240858309, 0.0036045845945409383, 0.04004976559372153, 0.07916456612292677, 0.03808004257734865, 0.08423261097050272, 0.07061158132273704, 0.1007668893726077, 0.029791583328915294, 0.12261561307241209, 0.025528655532980338, 0.03007225430337712, 0.009416373432031833, 0.1097148229018785, 0.045497285391320474, 0.011921580116904806, 0.06540005706483498, 0.028514256264315918, 0.11362811565049924, 0.038635120799881406, 0.05585145889199339, 0.019286202805233188, 0.02330939649255015, 0.06894387901411392, 0.016126251175592188, 0.02224903815658763, 0.027923937159357592, 0.035858193441526964, 0.05891924876777921, 0.024306601771968417, 0.04301070104702376, 0.018655653730093036, 0.07389197053271346, 0.0314763531787321, 0.028905486833536997, 0.05218152378802188, 0.05071467632660642, 0.13925590727012604, 3.1730669969692826, 16.32872510701418, 51.72138825058937, 71.62408947944641, 82.65602231025696, 81.13127052783966, 72.27419659495354, 71.52676150202751, 54.417567774653435, 44.82072673738003, 47.862231731414795, 27.80419673770666, 28.344960920512676, 32.839722633361816, 30.115443617105484, 39.164452850818634, 38.24110619723797, 20.81840079277754, 10.461559686809778, 3.828335660509765, 0.8601061126682907, 0.2411111191031523, 0.17696710245218128, 0.3661321441177279, 0.6337476870976388, 1.778955648187548, 3.666260107420385, 3.8007218297570944, 7.9269888158887625, 7.209991039708257, 8.398948665708303, 8.696342557668686, 6.351702595129609, 10.977270863950253, 10.197422560304403, 9.043346587568521, 11.116425096988678, 10.932494066655636, 7.428167257457972, 9.908591508865356, 10.429809540510178, 12.871614564210176, 7.925442773848772, 12.021354138851166, 5.897721480578184, 5.7550847344100475, 1.4381549041718245, 1.4815932232886553, 0.6114578456617892, 0.8361817651893944, 0.11877995639224537, 0.7148650218732655, 6.336455438286066, 10.291855093091726, 14.775268714874983, 11.07753038406372, 3.171062604524195, 2.359234979376197, 4.647660758346319, 7.549269134178758, 6.913785059005022, 9.626331254839897, 8.74888138845563, 8.453127108514309, 6.75789462402463, 5.56127043440938, 7.07938302308321, 6.881637359037995, 10.021754186600447, 7.735116686671972, 10.794471222907305, 11.777231488376856, 8.280776906758547, 7.6815528608858585, 7.105133291333914, 8.421331364661455, 5.473756855353713, 5.286564650014043, 3.595195608213544, 1.8163818586617708, 1.5100035862997174, 0.5632067879196256, 0.3282096149632707, 0.06191744745592587, 0.1804020142299123, 0.6364618695806712, 3.314329879358411, 12.081407066434622, 19.69677697867155, 33.4772714227438, 53.478508964180946, 74.90436226129532, 84.67099338769913, 66.91649168729782, 45.7142373919487, 29.73995916545391, 36.48126482963562, 38.348165452480316, 37.00867272913456, 49.045598432421684, 58.878433406353, 63.53636406362057, 52.382788360118866, 28.582159392535686, 13.189402911812067, 0.8803740469738841, 0.04744440630020108, 0.03476398575003259, 0.05791713047074154, 0.01777882109308848, 0.036157802169327624, 0.03902202835888602, 0.03571119625121355, 0.01096236630473868, 0.04798101988853887, 0.042069902701769024, 0.023717431140539702, 0.01415319406078197, 0.04108937348064501, 0.022882949160702992, 0.021273544407449663, 0.037782882936880924, 0.05020444237743504, 0.08528338075848296, 0.04944332169543486, 0.09375358640681952, 0.06307926480076276, 0.056758508071652614, 0.04560757224680856, 0.07536580160376616, 0.05673274441505782, 0.03623903394327499, 0.0707880269328598, 0.022240484904614277, 0.030508360687235836, 0.0035440411147646955, 0.05286861523927655, 0.06407020264305174, 0.026619145064614713, 0.03064563759835437, 0.05587955289229285, 0.05193575045268517, 0.11353728419635445, 0.23056033212924376, 0.19225996074965224, 0.1692533679306507, 0.135667756840121, 0.19843133428366855, 0.14290145540144295, 0.10689000104321167, 0.10986161229084246, 0.15909737383481115, 0.12387100781779736, 0.12734221061691642, 0.14796026051044464, 0.11184751041582786, 0.1602264030952938, 0.1666218161699362, 0.13123211829224601, 0.11841513143735938, 0.11209526899619959, 0.18647065968252718, 0.09376442918437533, 0.09147641016170382, 0.08145725325448439, 0.10753324269899167, 0.2159013570053503, 0.1133891886274796, 0.19589933421229944, 0.11884968858794309, 0.1534496300155297, 0.13346028310479596, 0.26035184680949897, 0.15467237768461928, 0.16234486363828182, 0.37864721787627786, 5.3074136562645435, 24.29251827299595, 63.96550923585892, 82.38983899354935, 93.87536868453026, 88.41627761721611, 80.1812607049942, 75.56082263588905, 58.811674788594246, 46.51613876223564, 47.304459661245346, 30.96000149846077, 35.65047360956669, 44.21388030052185, 58.90035443007946, 66.26956880092621, 59.93240185081959, 34.42518375813961, 13.528989739716053, 4.7798162419348955, 1.0195547598414123, 0.4016145213972777, 0.206352781096939, 0.5605218757409602, 0.5775595677550882, 2.2059143939986825, 2.470105905085802, 6.188042527064681, 8.923973143100739, 11.88174108043313, 10.44757928699255, 13.684465046972036, 15.30394859611988, 16.396353878080845, 15.267438255250454, 14.044462479650974, 18.993497416377068, 17.376239597797394, 25.16012951731682, 24.200312420725822, 14.89510003477335, 14.537882152944803, 19.908108338713646, 13.77199525013566, 11.515563279390335, 6.527554783970118, 1.2314691510982811, 2.1171813178807497, 0.8091249607969075, 0.9689385665114969, 0.24941582581959665, 1.27384566469118, 6.637351792305708, 8.572968877851963, 17.314103431999683, 17.845362424850464, 12.092364728450775, 18.93506795167923, 16.774560883641243, 15.838304422795773, 20.036056973040104, 18.114082105457783, 23.40508159250021, 19.26687754690647, 18.734602108597755, 15.57771535590291, 13.24168335646391, 11.32812313735485, 16.587614715099335, 20.113532915711403, 16.890029087662697, 19.128390178084373, 15.49135833978653, 11.693566627800465, 13.763505555689335, 13.18962899968028, 9.192253947257996, 5.475159455090761, 5.461800321936607, 2.660050350241363, 1.8585087731480598, 0.5538639798760414, 0.3206126648001373, 0.22531217546202242, 0.4015891399467364, 1.212182454764843, 4.127455847337842, 13.203939981758595, 28.07764906436205, 48.200557976961136, 73.23111444711685, 90.78519970178604, 94.20671090483665, 73.68723437190056, 51.00141428411007, 35.101642459630966, 40.435955822467804, 46.76960036158562, 42.77364358305931, 56.85850739479065, 66.71162948012352, 75.92858210206032, 63.835328221321106, 40.134255811572075, 18.278717771172523, 1.7978819576092064, 0.15735145658254623, 0.18022446281975135, 0.0863048728206195, 0.14658041502116248, 0.25227253034245223, 0.16541671677259728, 0.1681122713489458, 0.1606528856791556, 0.14279699069447815, 0.11634873997536488, 0.24290987726999447, 0.11273827316472307, 0.2769914211239666, 0.0855734788638074, 0.13535363541450351, 0.14516099821776152, 0.1910155126824975, 0.1845786877674982, 0.15999127586837858, 0.21088436449645087, 0.17709512292640284, 0.2076030327589251, 0.12155504693510011, 0.1270054536871612, 0.10447974287671968, 0.14988524315413088, 0.1687565297470428, 0.12500106124207377, 0.12229775864398107, 0.12231690605403855, 0.20579841162543744, 0.2207100880332291, 0.10414150907308795, 0.1557881076587364, 0.11501976870931685, 0.17921186168678105], [0.07674391046748497, 0.04380458383820951, 0.031083502872206736, 0.001227706027293607, 0.01888101985969115, 0.0600134082196746, 0.03290257547632791, 0.06325776615994982, 0.05345566889445763, 0.04078819139976986, 0.04941332037560642, 0.035862969161826186, 0.02996080969751347, 0.019997647832497023, 0.10455824725795537, 0.025871538891806267, 0.023767181010043714, 0.08148623412125744, 0.03799540063482709, 0.025074488985410426, 0.03907888429239392, 0.06765130267012864, 0.009132033464993583, 0.07468770127161406, 0.016228918029810302, 0.10305748364771716, 0.05092774692457169, 0.11654768750304356, 0.06193614586663898, 0.06841358481324278, 0.010506336038815789, 0.04488132879487239, 0.07995835243491456, 1.0813984600827098, 8.993318472057581, 33.14960740506649, 64.11490961909294, 78.7205658853054, 70.75971186161041, 56.25984951853752, 45.35637639462948, 36.63300208747387, 36.52497388422489, 26.47000852972269, 17.25191216915846, 33.23829464614391, 36.18562929332256, 39.02866333723068, 50.63249967992306, 25.932424776256084, 19.15853776037693, 9.360684659332037, 2.1424537617713213, 0.36882714950479567, 0.11083642326411791, 0.07311243345611729, 0.13968752551591024, 0.300352894118987, 0.7853132416494191, 2.0779987704008818, 4.549977974966168, 5.599103579297662, 7.343915803357959, 3.9478995697572827, 7.823148462921381, 7.039905991405249, 4.823271185159683, 7.057371279224753, 7.2954940516501665, 7.337361630052328, 11.338673271238804, 7.267002230510116, 5.182847790420055, 9.857040625065565, 6.103062937036157, 7.262437250465155, 3.452753364108503, 11.802982706576586, 3.6122899409383535, 6.310723694041371, 3.2933566672727466, 1.2178283580578864, 0.25767423736397177, 0.07979572561453097, 0.28058219875674695, 3.9283225452527404, 23.71294107288122, 28.40129479765892, 28.922343738377094, 28.336018100380898, 7.979693412780762, 1.0751406708732247, 3.5973930777981877, 3.4254375798627734, 7.475935919210315, 6.3293298706412315, 3.4099904587492347, 6.890974882990122, 4.322296567261219, 2.4632805213332176, 7.091412702575326, 4.684439459815621, 4.677695771679282, 3.1961324717849493, 6.256873933598399, 4.050192218273878, 5.148474359884858, 3.9145668083801866, 5.257868589833379, 7.398092821240425, 2.6460039289668202, 4.60625865496695, 3.877630177885294, 1.765323760919273, 2.201140900142491, 0.6395272363442928, 0.21468755963724107, 0.22757348458981141, 0.054955371233518235, 0.03860609169350937, 0.3672912600450218, 4.093223009258509, 16.44051320850849, 33.464466109871864, 50.16705885529518, 57.542124912142754, 45.29143027961254, 18.68287168443203, 18.650719709694386, 24.953036829829216, 18.41820828616619, 24.57106612622738, 32.92890764772892, 36.98509119451046, 49.805481657385826, 54.85293321311474, 46.03534676134586, 43.396779745817184, 19.79853931814432, 2.615600097924471, 0.22985757765127346, 0.11857628138386644, 0.03623822871304583, 0.04749389641801827, 0.10943896661046892, 0.06517842950415798, 0.1512133312644437, 0.052434688914217986, 0.08309636803460307, 0.04878577514318749, 0.05937986272328999, 0.00996196144114947, 0.05116550135426223, 0.018050452708848752, 0.01643493822484743, 0.03575349124730565, 0.12023822462651879, 0.021890278403589036, 0.08574234714615159, 0.02937785640824586, 0.03720069034898188, 0.022491755698865745, 0.0656310431077145, 0.058246629196219146, 0.04271074722055346, 0.07277414028067142, 0.05903501638385933, 0.02584980509709567, 0.027618934873316903, 0.039750368378008716, 0.048403899345430546, 0.044755159979104064, 0.07065688943839632, 0.036273443620302714, 0.09214923382387497, 0.023796258356014732, 0.023562685928482097, 0.05836189215187915, 0.10956677186186425, 0.06249480866244994, 0.027428774374129716, 0.02291876149683958, 0.0412006325495895, 0.05061674994067289, 0.025944764747691806, 0.041886744365911, 0.009398715883435216, 0.06991947666392662, 0.035381363559281453, 0.05129046046931762, 0.05986418829706963, 0.00822381540274364, 0.012608033321157563, 0.05189637580770068, 0.03547910069755744, 0.033324968826491386, 0.12204182159621269, 0.05610121756035369, 0.026320974247937556, 0.023574150254717097, 0.023671967173868325, 0.05067757265351247, 0.0607932050479576, 0.04616869155142922, 0.07375511107966304, 0.06552788458066061, 0.018523349208408035, 0.0605329783866182, 0.02194747758039739, 1.7156042600981891, 11.41059486195445, 39.27561588585377, 73.29542979598045, 88.5429248213768, 80.17734691500664, 68.24949815869331, 57.12470971047878, 47.908562645316124, 48.490364626049995, 35.78604273498058, 25.56675899773836, 33.198111802339554, 39.307735562324524, 36.35430224239826, 42.35369011759758, 28.99144873023033, 19.88391123712063, 8.902603089809418, 1.9469451089389622, 0.11658773379167542, 0.189655571593903, 0.38251193705946207, 0.7632402854505926, 1.431568788830191, 3.0095845693722367, 3.432073686271906, 7.172711240127683, 6.072937678545713, 9.901334848254919, 7.814666368067265, 8.013624642044306, 8.04410945624113, 10.696101151406765, 10.994554236531258, 9.859451595693827, 9.81708861887455, 10.751731116324663, 7.6458855997771025, 5.756035633385181, 11.555899064987898, 6.44747550599277, 8.802193477749825, 8.155721817165613, 7.631833478808403, 5.3674884326756, 3.5920204035937786, 3.372603552415967, 0.5738219933118671, 0.4954382259165868, 0.07851371745346114, 0.8171504864003509, 3.9378239354118705, 22.13488955050707, 25.739626921713352, 27.923833318054676, 22.70921353250742, 7.339857621118426, 2.0741778379306197, 4.709296301007271, 4.466436607763171, 4.522995622828603, 6.165897790342569, 4.855910958722234, 6.771473195403814, 6.43965695053339, 5.91612009331584, 9.679677542299032, 6.389765627682209, 6.925364462658763, 8.678173832595348, 10.602817106992006, 9.450354147702456, 11.56889721751213, 10.263833496719599, 7.932095741853118, 8.088036049157381, 6.423963792622089, 7.0195642579346895, 8.03011765703559, 4.5955342054367065, 4.2076685931533575, 3.3058090740814805, 0.46946448215749115, 0.3657885594293475, 0.23454470036085695, 0.08408211084315553, 0.723169120028615, 2.9313888028264046, 13.882901798933744, 33.747311532497406, 62.18019783496857, 70.60005962848663, 61.55258931219578, 31.912055611610413, 25.59287879616022, 27.58146408945322, 22.704699374735355, 31.832297891378403, 38.958743289113045, 42.231188490986824, 55.046301037073135, 60.90822368860245, 53.92912298440933, 49.90881711244583, 24.54515151679516, 3.5622881865128875, 0.18168383685406297, 0.09262799329007976, 0.035655279134516604, 0.033367174764862284, 0.07004783110460266, 0.04758968541864306, 0.06565285482793115, 0.015485806488868548, 0.12799829884897918, 0.019609834853326902, 0.0760038556472864, 0.05021028307965025, 0.07746039467747323, 0.015175006174104055, 0.02916491012001643, 0.03956772212404758, 0.05898805698961951, 0.04868383002758492, 0.04778800954227336, 0.06635431796894409, 0.05553262111789081, 0.02794070042000385, 0.07683372517931275, 0.08122007769998163, 0.04857210340560414, 0.08195175367291085, 0.02608107872219989, 0.06711666690534912, 0.05093611835036427, 0.04365037297247909, 0.014188820859999396, 0.015830952470423654, 0.12149501460953616, 0.01656949330936186, 0.06609199102967978, 0.020796224707737565, 0.13691417902009562, 0.2915565442526713, 0.18405572598567232, 0.11262404921581037, 0.09418423243914731, 0.20419163221959025, 0.1187165844021365, 0.17407671926775947, 0.16270726919174194, 0.13995119574246928, 0.12200835073599592, 0.1801815369981341, 0.10712482398957945, 0.1370986324036494, 0.1524315369897522, 0.10218281066045165, 0.08642279266496189, 0.18468236579792574, 0.13688202918274328, 0.08447767555480823, 0.19040004961425439, 0.11988741141976789, 0.11238682171097025, 0.22592777211684734, 0.2156397796352394, 0.20238595723640174, 0.15927591972285882, 0.17439495219150558, 0.09975701192161068, 0.19811719801509753, 0.20675058709457517, 0.18145283596822992, 0.1989888059324585, 3.2711278600618243, 16.34097944945097, 51.45067937672138, 85.43110460042953, 100.2841579914093, 90.06071537733078, 74.54188451170921, 61.33803382515907, 50.455641970038414, 48.332391902804375, 36.48750029504299, 24.81102705001831, 45.35134546458721, 48.80205810070038, 53.20642076432705, 67.39783465862274, 38.392919450998306, 25.33313423395157, 11.657355520874262, 2.8450951958075166, 0.6947556103114039, 0.30089706648141146, 0.33569758816156536, 0.5823728407267481, 1.324379628058523, 3.3854357013478875, 7.1373156644403934, 10.990508403629065, 12.411356661468744, 17.78339345008135, 13.026226367801428, 19.777140766382217, 17.373241558670998, 15.292867440730333, 18.42350710183382, 20.51347855478525, 15.917743910104036, 23.488325625658035, 17.369154877960682, 15.719341356307268, 28.377768360078335, 16.119751520454884, 16.07056885957718, 12.35089335590601, 25.199983678758144, 13.489715047180653, 22.026574462652206, 11.849735397845507, 4.912076694890857, 1.4886076468974352, 0.22956402855925262, 1.3545598648488522, 4.633414847776294, 19.83014602214098, 20.74232317507267, 25.86472950875759, 24.674599170684814, 10.543875619769096, 6.947590420022607, 10.837686304003, 12.083234768360853, 16.861996091902256, 17.180324010550976, 14.234126452356577, 18.402545526623726, 13.24118273332715, 10.235140286386013, 18.06232698261738, 14.311739187687635, 12.467134818434715, 11.39152368530631, 13.622749708592892, 14.496715161949396, 16.78249105811119, 12.457125205546618, 13.705693557858467, 17.141501493752003, 11.582330446690321, 13.529330771416426, 9.574426040053368, 5.766402902081609, 6.674044048413634, 2.545407176949084, 1.0930910264141858, 0.7383232412394136, 0.33435504301451147, 0.2988925256067887, 0.6245606113225222, 5.126210879534483, 19.077748395502567, 36.54059864580631, 57.36582577228546, 66.51305973529816, 53.63427020609379, 27.949567437171936, 32.80455932021141, 38.59200976788998, 29.788256473839283, 36.12054258584976, 47.34977222979069, 51.027325093746185, 63.284422382712364, 70.6705990433693, 64.53209683299065, 62.91287072002888, 30.898032523691654, 5.883846525102854, 0.3721897612558678, 0.20318259339546785, 0.13584652537247166, 0.18623213341925293, 0.2032092958688736, 0.12790311098797247, 0.19833828380797058, 0.20642662479076535, 0.2839926938759163, 0.1314946752972901, 0.20901587413391098, 0.151621334371157, 0.17106640501879156, 0.1688624342205003, 0.11631592220510356, 0.2115176836377941, 0.20035331865074113, 0.14940272842068225, 0.23901291919173673, 0.14963849389459938, 0.15965817030519247, 0.049054529081331566, 0.17467209981987253, 0.1719362911535427, 0.17034436954418197, 0.19828297896310687, 0.1366478667478077, 0.14933624683180824, 0.16784493491286412, 0.19355290074599907, 0.18658836430404335, 0.12165366351837292, 0.2728011069120839, 0.2583592396695167, 0.27769925189204514, 0.2048239717260003], [0.14441809355048463, 0.046858068817527965, 0.07763735979096964, 0.03323568103951402, 0.022511444876727182, 0.027727438719011843, 0.00886638448719168, 0.04192413376586046, 0.011087747516285162, 0.08373488220968284, 0.05090150087198708, 0.010259083046548767, 0.03227680397685617, 0.029064664522593375, 0.03768546121136751, 0.028786982547899242, 0.05383331445045769, 0.06386892477166839, 0.03350329578097444, 0.06415174982976168, 0.03311548280180432, 0.029189360175223555, 0.026676607703848276, 0.04630605566489976, 0.02950953752588248, 0.05826468193845358, 0.05526548506168183, 0.1755982852773741, 0.15838250750675797, 0.10331394762033597, 0.10088478695251979, 0.03477664678939618, 0.6892725045327097, 5.16543997451663, 25.00999577343464, 67.5482913851738, 71.0161828994751, 66.18412658572197, 60.976582020521164, 46.4837758988142, 37.31037274003029, 31.608290411531925, 22.374366000294685, 33.437833338975906, 48.72665874660015, 39.020391181111336, 44.04519595205784, 45.92926785349846, 32.18775361776352, 16.52611691504717, 6.007847171276808, 1.1893211002461612, 0.2420264988904819, 0.1599009268102236, 0.13550742325605825, 0.13328734785318375, 0.33046345808543265, 0.8218139642849565, 3.0288466857746243, 2.7324640145525336, 8.403421975672245, 2.90562286041677, 9.806702826172113, 6.371509982272983, 7.271236153319478, 7.059732852503657, 5.962792513892055, 8.933687321841717, 6.750701609998941, 8.976025599986315, 5.32238295301795, 7.258520135655999, 2.0572739699855447, 3.1018448062241077, 7.04042418859899, 12.827023956924677, 6.703976467251778, 9.99306382611394, 4.333686456084251, 6.4433099795132875, 3.7644461262971163, 1.5040490683168173, 0.7394482777453959, 0.5150460347067565, 2.588290963321924, 15.374820493161678, 43.28631207346916, 64.5401220023632, 52.849087938666344, 40.62794432044029, 23.879284746944904, 3.263770742341876, 0.9781445818953216, 4.489585440605879, 4.791121110320091, 7.5805899035185575, 4.615825591608882, 4.88089794293046, 2.7566202683374286, 3.2533709378913045, 4.232709724456072, 4.736789250746369, 6.855075359344482, 5.290880743414164, 9.496707860380411, 9.720178619027138, 5.9769548289477825, 7.9948412999510765, 4.217393221333623, 7.621915061026812, 6.4355802442878485, 6.846284531056881, 3.620134857483208, 2.6102093746885657, 1.5722535084933043, 1.5872916765511036, 0.5560192361008376, 0.16921918460866436, 0.27308341988828033, 0.1394244490074925, 0.04502160212723538, 0.23201375413918868, 1.7807733756490052, 5.370386727154255, 14.273396395146847, 27.03192997723818, 28.714078813791275, 29.060840606689453, 35.37524297833443, 28.672077767550945, 21.200764775276184, 21.35769445449114, 22.732394188642502, 31.40465173870325, 50.59358596801758, 50.66115774214268, 62.244235798716545, 55.93394100666046, 43.46987262368202, 15.328173246234655, 0.8077172550838441, 0.015433850585395703, 0.10039378947112709, 0.058292772228014655, 0.031172506787697785, 0.10680042381864041, 0.11550665469258092, 0.14213221933459863, 0.13561608851887286, 0.06503414857434109, 0.16915779415285215, 0.018718702885962557, 0.025433859154873062, 0.05402133014285937, 0.03614531182392966, 0.04135227558435872, 0.019325091343489476, 0.05517043078725692, 0.03600717587687541, 0.04747366918309126, 0.04520107941061724, 0.035277889619464986, 0.024318351825058926, 0.04381315935461316, 0.06474917870946229, 0.053764383774250746, 0.04135895491344854, 0.04168389685219154, 0.01842601654061582, 0.03821853475528769, 0.06414889998268336, 0.04196464389679022, 0.0591124186757952, 0.022269219007284846, 0.059868908356293105, 0.03155932899971958, 0.1252223993651569, 0.07205799003713764, 0.05220795537752565, 0.0258864041097695, 0.012693132612184854, 0.04341017687693238, 0.03330373969220091, 0.050808825180865824, 0.05289027852995787, 0.013614612853416475, 0.01300698408158496, 0.047091440865187906, 0.05411613950855099, 0.0380112232232932, 0.04470336178201251, 0.043454360638861544, 0.0501613161759451, 0.047842791173025034, 0.04290765013138298, 0.036853268757113256, 0.03275629445852246, 0.03957954824727494, 0.05104394869704265, 0.012171610596851679, 0.033834401256171986, 0.08388173839193769, 0.053291732183424756, 0.19945925334468484, 0.09339325144537725, 0.04998971307941247, 0.027427520144556183, 0.04064207736519165, 0.8074018126353621, 6.208657370880246, 27.046923972666264, 76.1780235171318, 80.66305965185165, 77.98767641186714, 73.3574728667736, 57.15187065303326, 49.257250875234604, 41.48764818906784, 29.518279060721397, 31.58732883632183, 33.91957148909569, 31.86596028506756, 35.64251683652401, 34.97630998492241, 33.33044350147247, 20.564639009535313, 7.874996680766344, 1.4466581353917718, 0.6811975815799087, 0.36697522387839854, 0.5160736420657486, 1.0499883955344558, 2.292528608813882, 3.3045237930491567, 4.200165895745158, 6.23466270044446, 9.317636769264936, 8.370331451296806, 10.214838925749063, 11.657417267560959, 11.965287197381258, 11.84953210875392, 7.996089532971382, 11.687690243124962, 10.548398327082396, 9.12486456334591, 8.640739191323519, 8.390291780233383, 5.662095174193382, 4.847550457343459, 6.2075236067175865, 7.962390091270208, 5.2058242075145245, 3.4993158280849457, 3.3678205590695143, 2.605540850199759, 3.3400454744696617, 1.9604451907798648, 0.6993955175857991, 0.8165799232665449, 2.7199448738247156, 15.617757607251406, 43.98360125720501, 59.940305426716805, 51.13852232694626, 39.76463824510574, 21.864684149622917, 3.3196871168911457, 2.255728058516979, 3.467243886552751, 4.034955035895109, 3.6681041959673166, 2.4281445192173123, 4.823500122874975, 3.710125428624451, 5.9703270345926285, 6.92403738386929, 7.73529052734375, 14.54234216362238, 6.994072375819087, 10.762714426964521, 9.87878305837512, 10.81707525998354, 14.647786505520344, 10.418082419782877, 9.856900032609701, 7.1378533355891705, 11.490400079637766, 11.469045225530863, 5.866751242429018, 4.402540186420083, 6.252017319202423, 3.366730730049312, 1.0172779695130885, 0.48889803467318416, 0.17092458059778437, 0.1925605454016477, 0.5531091860029846, 2.3294932628050447, 8.12272533774376, 16.557334139943123, 30.60942281037569, 28.672763630747795, 25.7014237716794, 31.71762004494667, 33.77007611095905, 28.50589368492365, 28.006463684141636, 31.081526577472687, 38.405891954898834, 57.756232023239136, 60.72286203503609, 70.55085986852646, 64.50366675853729, 48.25812488794327, 18.445000648498535, 0.8825667668133974, 0.024068075508694164, 0.03636032313806936, 0.03458153616520576, 0.04974771356501151, 0.004787896623383858, 0.07938885799376294, 0.021142162004252896, 0.06041934073437005, 0.06826291399192996, 0.05796914760139771, 0.02704141410504235, 0.11145008291350678, 0.013678846662514843, 0.0597214658773737, 0.018151523945562076, 0.01631321487366222, 0.009120293616433628, 0.05876770963368472, 0.04854110760788899, 0.04557474334433209, 0.03193922697391827, 0.056325175464735366, 0.11939920441363938, 0.06332835924695246, 0.02361058785027126, 0.009615206854505232, 0.04437078314367682, 0.01953949595190352, 0.03435905142396223, 0.05141733432537876, 0.03398158398340456, 0.06522236464661546, 0.010148727542400593, 0.031696318328613415, 0.036746863333974034, 0.22472115873824805, 0.20087769051315263, 0.15941709105391055, 0.07129385994630866, 0.15680200012866408, 0.19251288467785344, 0.10544427510467358, 0.0958778134372551, 0.13290607690578327, 0.2377568490919657, 0.18963575625093654, 0.13752909289905801, 0.11940702665015124, 0.0669875109451823, 0.09603143800632097, 0.1329561125021428, 0.20415517792571336, 0.15318480203859508, 0.16074117156676948, 0.1088337526016403, 0.08635405494715087, 0.13934040820458904, 0.159199389454443, 0.27708424895536155, 0.11409598038881086, 0.21636733668856323, 0.20581347722327337, 0.408337518456392, 0.2947988687083125, 0.1994251590804197, 0.2373365857056342, 0.09922662124154158, 1.2407737830653787, 9.678481556475163, 38.82361114025116, 89.69878479838371, 92.21669688820839, 87.81246721744537, 78.54959025979042, 62.3579066991806, 51.728577464818954, 43.961619436740875, 32.34824940562248, 42.91260972619057, 59.462230280041695, 52.82350771129131, 58.22773352265358, 60.98790921270847, 44.12064090371132, 21.600049249827862, 7.447740007191896, 1.7238597921095788, 0.6924551900010556, 0.42654486489482224, 0.5335889803245664, 1.0918058641254902, 2.64936413615942, 4.365512123331428, 7.060797745361924, 8.811641670763493, 20.148306749761105, 14.311873130500317, 23.676250241696835, 18.785458579659462, 18.772839456796646, 16.809268221259117, 15.757760144770145, 18.48747856914997, 19.035908840596676, 18.19804809987545, 15.354741420596838, 19.05535239726305, 11.46333983168006, 10.189198851585388, 16.12372800707817, 24.55000765621662, 15.033197924494743, 20.083470828831196, 13.06127853691578, 13.430112395435572, 8.570953086018562, 5.43210681527853, 1.8297000252641737, 1.1967926868237555, 4.458174426108599, 16.000608913600445, 37.561383470892906, 61.08801484107971, 50.389210134744644, 37.407655119895935, 24.27260734140873, 6.623941836878657, 6.27701997756958, 10.565433762967587, 10.933665353804827, 13.505721688270569, 10.301387831568718, 11.600294932723045, 8.117226082831621, 9.850522074848413, 10.122929457575083, 11.675934623926878, 16.012768261134624, 13.466313052922487, 19.22679729759693, 21.48669183254242, 14.713134448975325, 18.007560521364212, 14.962240532040596, 16.814743727445602, 14.598599094897509, 16.985991038382053, 16.708419732749462, 8.601482547819614, 6.415002923458815, 6.9937764666974545, 2.6693197153508663, 0.6397624674718827, 0.5243262054864317, 0.3284940356388688, 0.28436961583793163, 0.769015084952116, 2.3963739490136504, 8.758620265871286, 19.63879019021988, 38.34434665739536, 42.276029884815216, 43.25514994561672, 48.95280361175537, 43.10183197259903, 35.28854303061962, 35.2426452934742, 34.80140917003155, 43.96574981510639, 67.0756347477436, 67.34699338674545, 79.57789108157158, 73.18310782313347, 59.4064112752676, 25.368297547101974, 1.3947722758166492, 0.19714085821760818, 0.20096789114177227, 0.1664228760637343, 0.1142184273339808, 0.30145718017593026, 0.15602697530994192, 0.33049424237105995, 0.21654310694430023, 0.16879820876056328, 0.3195880854036659, 0.1464457597467117, 0.27253426029346883, 0.17731136991642416, 0.20067367411684245, 0.10048304015072063, 0.12501611199695617, 0.1622412004508078, 0.19458028546068817, 0.23610604548593983, 0.09539424485410564, 0.13138188369339332, 0.112817786866799, 0.20552886358927935, 0.18533778609707952, 0.3118955763056874, 0.20609752682503313, 0.13371360779274255, 0.12798412382835522, 0.15735069959191605, 0.20943230803823099, 0.08203549761674367, 0.2627437293995172, 0.19016251782886684, 0.1852966265869327, 0.12942451372509822], [0.035358598179300316, 0.17614636133657768, 0.13391042535658926, 0.08332644123584032, 0.08041387525736354, 0.01988403430004837, 0.012119485854782397, 0.055167384271044284, 0.05294452952512074, 0.042542888259049505, 0.030597514887631405, 0.08310283214086667, 0.0634729593002703, 0.009468249554629438, 0.07224862551083788, 0.09947012731572613, 0.09456867235712707, 0.0575022550765425, 0.03762956635910086, 0.06388539302861318, 0.03203583233698737, 0.0578757520270301, 0.08510631174431182, 0.052980898472014815, 0.03972605562012177, 0.08671508010593243, 0.12018990339129232, 0.10353356396080926, 0.23634984099771827, 0.12280714654480107, 0.16573070461163297, 0.06279985362198204, 1.9597125425934792, 22.765902690589428, 56.98773846030235, 68.83687824010849, 67.1361654996872, 61.88419371843338, 48.863101825118065, 34.621165841817856, 30.989771001040936, 22.78555143624544, 41.21269874274731, 75.94239056110382, 106.18648007512093, 81.91782832145691, 76.52838751673698, 43.86016488075256, 19.958313144743443, 5.087359864264727, 0.807790223043412, 0.1736674693529494, 0.02638403824676061, 0.09331151872174814, 0.5398861924186349, 1.4172677812166512, 2.0327308494597673, 2.675776043906808, 3.3578149834647775, 2.570504117757082, 4.448502995073795, 8.303707726299763, 5.830208603292704, 5.789045412093401, 5.334890931844711, 5.105015616863966, 7.32411696575582, 7.910087797790766, 6.413730466738343, 6.847686655819416, 7.200544271618128, 3.0711719021201134, 3.5395722929388285, 5.059174876660109, 4.966305010020733, 5.419324776157737, 7.271084161475301, 4.9288993421942, 6.877854187041521, 2.317264094017446, 4.91098852828145, 4.061729349195957, 2.9242314118891954, 5.691393027082086, 12.14236719533801, 35.74241727590561, 70.20435646176338, 60.4682756960392, 66.69012263417244, 55.77686883509159, 40.60544192790985, 13.181349243968725, 5.610711006447673, 6.549175623804331, 11.756857931613922, 11.957144234329462, 10.388321466743946, 13.194182105362415, 12.177596054971218, 10.58146795257926, 7.699915850535035, 4.51677868142724, 7.5192497950047255, 5.294918026775122, 11.521494761109352, 6.012314781546593, 11.289384216070175, 13.88324473053217, 6.284657092764974, 9.503740333020687, 7.368658175691962, 9.00203425437212, 11.392370089888573, 6.9975225906819105, 1.6250739991664886, 6.117928689345717, 1.500675561837852, 0.6940139376092702, 0.22449492244049907, 0.13604334293631837, 0.10818550144904293, 0.06535028864163905, 0.5787100153975189, 2.5133506720885634, 10.431508049368858, 23.77069417387247, 51.83715283870697, 52.64941245317459, 34.52638752758503, 24.056091159582138, 20.352388098835945, 19.405243322253227, 20.28964776545763, 29.924268275499344, 32.42034673690796, 43.1668084859848, 53.43885809183121, 60.046004354953766, 54.16444055736065, 28.715209253132343, 6.25667349435389, 0.3543691331287846, 0.05611437212792225, 0.07607480496517383, 0.10509689062018879, 0.2281788841355592, 0.10993385294568725, 0.2313229037099518, 0.10768093008664437, 0.08974070486146957, 0.05160959510249086, 0.12187028158223256, 0.04456890688743442, 0.052679052168969065, 0.0556383474759059, 0.03650960614322685, 0.09118733622017317, 0.054375479303416796, 0.04826348871574737, 0.0432315901707625, 0.0149646546196891, 0.07113738553016447, 0.07202287903055549, 0.048902726484811865, 0.038499018337461166, 0.010586414700810565, 0.08681749648530968, 0.0007733915720109508, 0.07569395704194903, 0.019597537466324866, 0.09255244265659712, 0.037707143055740744, 0.04543349037703592, 0.06200612668180838, 0.05443650239612907, 0.030240964879340027, 0.03937989196856506, 0.08525742785423063, 0.10010119774960913, 0.04956438082444947, 0.029527560582209844, 0.029169797162467148, 0.01824384155042935, 0.058148016323684715, 0.04562088266538922, 0.0296702551713679, 0.026734797647804953, 0.0334508073865436, 0.13399983930867165, 0.04136301075050142, 0.009664466906542657, 0.06883581489091739, 0.0508945246838266, 0.083789600757882, 0.015609831425535958, 0.0894147164945025, 0.014552093798556598, 0.041054047251236625, 0.014014636944921222, 0.03442531407927163, 0.0448436573788058, 0.14635879488196224, 0.16390312142902985, 0.06297212094068527, 0.14580990246031433, 0.0939949402527418, 0.07717700558714569, 0.07991470673005097, 2.5006847642362118, 26.65789894759655, 64.57097634673119, 80.26677131652832, 77.51902475953102, 71.23344764113426, 58.482540249824524, 45.1464718580246, 37.65239238739014, 28.78045365214348, 36.75717942416668, 62.31250673532486, 82.03265056014061, 63.66687186062336, 60.52112706005573, 41.17376983165741, 23.751121424138546, 7.193895103409886, 1.0871747438795865, 0.2642682788427919, 0.16562793200137094, 0.13966192142106593, 1.2926636799238622, 3.5792644880712032, 5.852213222533464, 7.393439020961523, 8.249846566468477, 8.022803999483585, 11.152595356106758, 9.149899519979954, 9.51670428737998, 16.252782382071018, 9.111113101243973, 11.645312067121267, 10.119450744241476, 11.343336571007967, 12.140191812068224, 12.14699724689126, 7.96069823205471, 4.7683057095855474, 6.278083445504308, 5.320759015157819, 4.841162050142884, 7.189382845535874, 5.8523286413401365, 4.39189363270998, 5.679151508957148, 4.49110820889473, 5.085333622992039, 5.131144914776087, 3.233352187089622, 7.858797200024128, 12.103196997195482, 39.236158803105354, 70.47186970710754, 65.91450825333595, 69.72710207104683, 58.52773502469063, 41.752478778362274, 14.59017589688301, 6.827001515775919, 7.261658767238259, 11.091089006513357, 12.11803900077939, 9.819629732519388, 12.593640480190516, 10.547832157462835, 10.218218844383955, 6.012254459783435, 5.1518799271434546, 8.288895171135664, 6.607508668676019, 10.772180669009686, 11.520514413714409, 14.19963950291276, 16.7747812718153, 11.787878517061472, 11.254617031663656, 10.452413577586412, 10.115070529282093, 11.063893865793943, 9.312120415270329, 6.359775736927986, 7.721815500408411, 6.037781964987516, 2.3012215923517942, 2.2399163944646716, 0.5942157364916056, 0.5902821756899357, 0.12118535349145532, 0.5989968893118203, 2.478368324227631, 9.349157977849245, 21.57753925770521, 43.09816136956215, 50.112934559583664, 38.952724412083626, 28.086196705698967, 28.933131359517574, 27.939454279839993, 25.784238427877426, 35.47266595065594, 41.38834811747074, 51.274304240942, 60.875473245978355, 67.80756667256355, 62.3730830848217, 34.89367201924324, 6.8278346210718155, 0.27159116871189326, 0.0516735904966481, 0.07114633583114482, 0.13586996239610016, 0.007325016122194938, 0.02633144595165504, 0.019694599250215106, 0.01791304963262519, 0.039180194871732965, 0.06594213657081127, 0.06347888163872994, 0.037614419125020504, 0.035544940328691155, 0.09133814804954454, 0.0585748996672919, 0.05597907118499279, 0.03722119588928763, 0.03982173700933345, 0.0580196321971016, 0.003817798519776261, 0.03664839518023655, 0.048504152364330366, 0.022006001490808558, 0.09024676051922143, 0.05428993565146811, 0.031155715696513653, 0.04190412175375968, 0.03532379887474235, 0.041308555664727464, 0.22987524076597765, 0.039940462083905004, 0.026735270766948815, 0.03511485461785924, 0.10771576649858616, 0.0521528583340114, 0.15715506946435198, 0.2905392675893381, 0.4082582867704332, 0.18351550184888765, 0.1849304954521358, 0.07734026323305443, 0.14758615870960057, 0.1108319777995348, 0.13150318030966446, 0.1865577878197655, 0.16225835890509188, 0.1391831916407682, 0.24265487532829866, 0.15122066368348897, 0.2620010473765433, 0.21012158511439338, 0.326038328348659, 0.15044970583403483, 0.11620334582403302, 0.2011069399304688, 0.09093342523556203, 0.17801323381718248, 0.1014027392375283, 0.14298249792773277, 0.14935566141502932, 0.22640948533080518, 0.24892682471545413, 0.21554931183345616, 0.3181584714911878, 0.23420626617735252, 0.1952060792245902, 0.13034321833401918, 3.491255035623908, 36.48009829223156, 76.6616539657116, 90.54487019777298, 89.09538477659225, 82.17493012547493, 66.2753900885582, 49.192088171839714, 42.12772764265537, 32.28359967470169, 53.19746844470501, 89.1502158343792, 114.04266491532326, 87.48977333307266, 86.0229304432869, 52.137416526675224, 25.490016415715218, 6.782016204670072, 1.5686948806978762, 0.4465212835930288, 0.3039803932188079, 0.143846788269002, 1.7611322295852005, 3.6324013117700815, 5.670314133167267, 10.454360973089933, 14.637238271534443, 13.338240925222635, 20.37155047059059, 20.685664415359497, 15.797513611614704, 21.39606099575758, 17.097376361489296, 15.579707399010658, 15.393113661557436, 22.109626606106758, 14.095967765897512, 18.981687650084496, 18.701794669032097, 9.436918068677187, 11.516519878059626, 11.502478681504726, 12.475821152329445, 13.209099154919386, 14.257250111550093, 8.79078458994627, 14.000620432198048, 4.726565424352884, 7.799558853730559, 6.418097382411361, 4.30189736187458, 8.78846576437354, 17.400157414376736, 39.14717897772789, 65.95608562231064, 62.22378149628639, 67.4807234108448, 57.333500906825066, 42.90053777396679, 19.582256823778152, 12.687761429697275, 15.267847683280706, 18.024300523102283, 16.653009206056595, 12.275852132588625, 17.726529501378536, 16.564967930316925, 15.443600602447987, 12.421847898513079, 10.193526819348335, 14.720737840980291, 12.891794331371784, 21.98019415140152, 16.052531227469444, 22.159747816622257, 24.553467370569706, 17.341363169252872, 21.38513658195734, 16.85932483524084, 18.90539914369583, 23.400592133402824, 15.025341846048832, 7.71871249191463, 15.14546575024724, 5.689152097329497, 2.5527229718863964, 2.144844545982778, 0.6452819681726396, 0.5913559743203223, 0.09799881954677403, 1.0936631332151592, 3.84008985478431, 13.202183526009321, 29.37696274369955, 61.48348622024059, 63.95873799920082, 48.44158284366131, 37.21866466104984, 32.36520789563656, 30.7479215785861, 32.507441863417625, 41.900693625211716, 44.09564584493637, 56.818389147520065, 71.85574024915695, 78.33535775542259, 74.69560906291008, 44.74119320511818, 12.298911195248365, 0.5465379729866982, 0.17958422686206177, 0.2067121141590178, 0.2277951195719652, 0.317466760170646, 0.2866006304975599, 0.46144783264026046, 0.18393342004856095, 0.1711182514554821, 0.21010458993259817, 0.29204330407083035, 0.14244224410504103, 0.11356602757587098, 0.11948559782467782, 0.15350162488175556, 0.30370793596375734, 0.2886748738819733, 0.14401157473912463, 0.15144884440815076, 0.1276370807318017, 0.16551517008338124, 0.1803516669315286, 0.2282810481847264, 0.13022092723986134, 0.12219497861224227, 0.23169381427578628, 0.23003456502920017, 0.21344450680771843, 0.10714270974858664, 0.37871427834033966, 0.08312494814163074, 0.18794177449308336, 0.13257536105811596, 0.19808746757917106, 0.1518833273439668], [0.03676719818031415, 0.13634443224873394, 0.06360870553180575, 0.04392854476463981, 0.10086450405651703, 0.08123892082949169, 0.016260375814454164, 0.03751116782950703, 0.11256086276262067, 0.03009824617038248, 0.02210743823525263, 0.015791720688866917, 0.0540950662252726, 0.02997591425810242, 0.03667972865514457, 0.11329880988341756, 0.0675403219065629, 0.11348336716764607, 0.06424500810680911, 0.047615263538318686, 0.04834764826227911, 0.03332017826323863, 0.08827600962831639, 0.05092853731184732, 0.05009862325096037, 0.02798601781250909, 0.056843339261831716, 0.10957325081108138, 0.17838749889051542, 0.24716573796467856, 0.14736824930878356, 0.6847329949960113, 14.810268636792898, 49.073416739702225, 66.72145575284958, 69.31567534804344, 57.90483444929123, 42.36592926084995, 32.9251154512167, 29.08319480717182, 31.978738233447075, 43.316174671053886, 51.24585136771202, 66.02046176791191, 77.55826145410538, 81.9008432328701, 54.582528322935104, 21.63371354341507, 5.462036384269595, 0.4611636494519189, 0.21628302871249616, 0.060056341462768614, 0.513916426571086, 1.2816554331220686, 1.1569977784529328, 2.20166337210685, 2.9516723519191146, 3.329321024939418, 4.395877243950963, 6.167050553485751, 4.833663152530789, 6.597877135500312, 7.481390051543713, 17.03568287193775, 12.361570782959461, 14.527698699384928, 7.52725406549871, 10.972162988036871, 11.033985670655966, 7.77942705899477, 5.73452546261251, 8.867444526404142, 9.12332659587264, 6.7195827048271894, 9.199184775352478, 11.747162751853466, 10.55680537596345, 12.56240900605917, 13.558879885822535, 14.900148063898087, 14.962100889533758, 12.697099428623915, 10.957158543169498, 19.633521772921085, 28.907914012670517, 53.39102245867252, 69.37175273895264, 62.09761306643486, 60.235557183623314, 66.2187959253788, 53.446951657533646, 19.864040203392506, 16.747257448732853, 19.18527502566576, 27.143085412681103, 28.755384497344494, 23.198011703789234, 30.66142302006483, 23.64257264882326, 25.511572659015656, 16.153092831373215, 15.035336259752512, 21.360160522162914, 6.841131057590246, 5.780120640993118, 7.331579765304923, 9.213417861610651, 15.697567574679852, 12.01195439323783, 7.139780782163143, 6.769223716109991, 11.764496471732855, 10.029378477483988, 5.92035829089582, 3.9351626532152295, 4.679233739152551, 7.217680877074599, 1.661671616602689, 1.6760239214636385, 0.6871252635028213, 0.5456561234313995, 0.10921505323494785, 0.034231012396048754, 0.06385956628946587, 0.8098149206489325, 5.388986254110932, 13.610736653208733, 28.426305055618286, 37.37647779285908, 34.44493889808655, 32.80955985188484, 18.995370715856552, 19.045725613832474, 18.876632787287235, 29.216712042689323, 38.97028706967831, 52.0681082457304, 59.1641628742218, 55.34247614443302, 51.78017869591713, 22.977089658379555, 1.3355695526115596, 0.10848748133867048, 0.04679684905568138, 0.12055187849909998, 0.14236614428227767, 0.23874381644418463, 0.1199613961216528, 0.1516716816695407, 0.13199574372265488, 0.13731033744988963, 0.033296451802016236, 0.0013117496132508677, 0.0325559702469036, 0.03100682602962479, 0.01934244832227705, 0.05508594840648584, 0.03514805459417403, 0.024391692713834345, 0.050266241014469415, 0.035748852824326605, 0.0541515919030644, 0.04239419897203334, 0.05796244600787759, 0.01322404094025842, 0.19877855549566448, 0.05457991501316428, 0.07563634411781095, 0.05544978259422351, 0.07478674830053933, 0.039142118985182606, 0.03400246430828702, 0.058796809244086035, 0.02130055672751041, 0.013363423695409438, 0.03217112956917845, 0.06819056201493368, 0.07875698604038917, 0.01545648794490262, 0.04348793539975304, 0.014796862451476045, 0.042146596242673695, 0.03885620659275446, 0.01864620062406175, 0.03550134657416493, 0.056445692825946026, 0.07455725397448987, 0.018780072932713665, 0.06423481841920875, 0.05962503120827023, 0.0994029852154199, 0.0803731165069621, 0.04275483079254627, 0.03957103952416219, 0.012694378492597025, 0.016689789881638717, 0.03869297121127602, 0.042331127551733516, 0.04276106854376849, 0.027956966441706754, 0.04900284962786827, 0.06047874594514724, 0.03641815870651044, 0.08979138612630777, 0.08765230872086249, 0.1903089287225157, 0.17249128402909264, 0.8828545419964939, 16.39859575778246, 54.27324391901493, 76.4023406803608, 80.5927786231041, 72.47695371508598, 56.94394201040268, 47.45525076985359, 35.94518959522247, 33.04001748561859, 34.75936062633991, 52.39600025117397, 73.51976975798607, 87.79118075966835, 88.24478521943092, 61.84437185525894, 26.85696456581354, 7.519425535574555, 0.6360279209911823, 0.23399567435262725, 0.23981921811355278, 1.0528691159561276, 2.681423253379762, 3.868776415474713, 4.832172682508826, 7.7695338148623705, 10.032036434859037, 7.723741522058845, 14.27652932703495, 11.807726752012968, 11.183586493134499, 11.63237851113081, 7.743644854053855, 16.17354903370142, 13.55564245954156, 10.099226329475641, 7.579036736860871, 9.538161735981703, 13.361476678401232, 9.659367632120848, 5.646853717043996, 7.890845155343413, 8.936844002455473, 8.32196194678545, 11.38364290818572, 10.480119790881872, 13.084486741572618, 13.93228204920888, 15.663178469985723, 16.1058746650815, 14.551592767238617, 12.270187586545944, 24.033056795597076, 32.210335806012154, 59.985891580581665, 75.47196820378304, 69.83883127570152, 67.62811750173569, 71.74791723489761, 58.73316340148449, 22.539119459688663, 18.376199640333652, 19.352049976587296, 28.28327313065529, 28.99401169270277, 25.279217027127743, 28.784874714910984, 25.58442234992981, 21.924441643059254, 16.452784650027752, 11.662812978029251, 11.230787560343742, 5.650530494749546, 8.272987324744463, 7.85324189811945, 11.336449440568686, 18.724329359829426, 15.175391044467688, 9.914180058985949, 14.974885303527117, 16.530135199427605, 11.996262185275555, 8.997832629829645, 9.012345001101494, 9.802256114780903, 4.493544353172183, 6.003687344491482, 4.184042410925031, 2.1963949548080564, 1.3420446426607668, 0.49252550408709794, 0.1230055077758152, 0.1628448485280387, 1.0178815433755517, 5.979419946670532, 17.29848627001047, 30.34083992242813, 42.14212886989117, 39.28125858306885, 30.928330197930336, 21.52118258178234, 26.614890955388546, 28.15792355686426, 36.390594094991684, 45.88058486580849, 58.58405940234661, 65.48367217183113, 61.879291981458664, 57.406483590602875, 27.56950993090868, 1.6492447396740317, 0.13902177452109754, 0.02298727100424003, 0.05542483901081141, 0.0602266272471752, 0.022913607281225268, 0.016777539567556232, 0.07174101876444183, 0.04185664656688459, 0.0755514795309864, 0.061542852126876824, 0.03960215035476722, 0.017201467308041174, 0.06583035428775474, 0.04530881698883604, 0.0229384766498697, 0.0018204800176135905, 0.01018328286590986, 0.016453133830509614, 0.027381701802369207, 0.027709731075447053, 0.05614010238787159, 0.047886043539620005, 0.06257810731767677, 0.13432555308099836, 0.02609286217193585, 0.03954374333261512, 0.028551235627674032, 0.0558497074234765, 0.05965094700513873, 0.0447061967861373, 0.045410105303744785, 0.013334834311535815, 0.0544174180686241, 0.07666489400435239, 0.14786332118092105, 0.29225638951174915, 0.20414714788785204, 0.1234616465808358, 0.18384759809123352, 0.18539683136623353, 0.1870528151630424, 0.12408671304001473, 0.2129496427369304, 0.18641958507942036, 0.1430212677223608, 0.1402603299356997, 0.17345524480333552, 0.11266136440099217, 0.11965065146796405, 0.26764983020257205, 0.14944183960324153, 0.2210028949775733, 0.1386121683754027, 0.12273042331798933, 0.24790463503450155, 0.07554230658570305, 0.15792199003044516, 0.19444521458353847, 0.23078788944985718, 0.2169126519584097, 0.11166172858793288, 0.37928083387669176, 0.4488024674355984, 0.44976966397371143, 0.3217023453908041, 1.4699988579377532, 23.246719390153885, 66.77774593234062, 86.82559177279472, 91.31535485386848, 81.96137398481369, 65.78811183571815, 48.69757890701294, 42.448449432849884, 45.43467879295349, 58.40706869959831, 62.54697695374489, 71.37103825807571, 80.27542725205421, 87.30216220021248, 60.827314630150795, 26.015452221035957, 7.454061442986131, 0.9025538130663335, 0.5478906410280615, 0.38216520566493273, 1.1607057857327163, 2.564653856679797, 3.6743258871138096, 8.1560960970819, 11.580826677381992, 14.849092103540897, 15.185198318213224, 20.255985371768475, 18.262878321111202, 19.280539713799953, 18.448690250515938, 26.12365521490574, 20.3472887724638, 26.2840199097991, 17.370368912816048, 18.780461847782135, 17.678232192993164, 18.6222630366683, 14.014731924980879, 14.310064427554607, 17.058187164366245, 10.648459307849407, 12.956564705818892, 16.205815002322197, 14.96622746810317, 18.165721334517002, 18.45768626779318, 19.740117453038692, 20.960824750363827, 17.34370194375515, 15.5293002538383, 26.24031275510788, 38.1566671282053, 59.09608192741871, 77.00353682041168, 69.30726259946823, 67.40219682455063, 72.33858034014702, 62.61810913681984, 26.54838502407074, 22.51272227615118, 25.329495929181576, 35.14532491564751, 32.58650042116642, 27.102750577032566, 35.738761872053146, 29.181845113635063, 29.01845008134842, 21.263828091323376, 21.055337078869343, 28.73303409665823, 13.517246469855309, 13.775028437376022, 13.075186740607023, 19.28665168583393, 27.456623688340187, 18.98626070469618, 19.49813313782215, 16.01454086601734, 22.102581784129143, 23.496706075966358, 13.933295644819736, 13.194397743791342, 12.014024332165718, 15.650335159152746, 7.739354409277439, 6.638154024258256, 2.6590856770053506, 1.6096685570664704, 0.35230406268965453, 0.1346357262809761, 0.23548066732473671, 1.422834601253271, 6.989688836038113, 18.60920313745737, 36.80614359676838, 50.48477500677109, 48.84681969881058, 44.37244959175587, 30.641428492963314, 30.595133677124977, 29.86393131315708, 42.10337094962597, 53.639061748981476, 67.76843637228012, 75.64343020319939, 73.09413179755211, 68.52072760462761, 37.344137728214264, 3.4714160626754165, 0.3191211854573339, 0.15359396289568394, 0.213098858948797, 0.28772023448254913, 0.44972816307563335, 0.34324457694310695, 0.3656420297920704, 0.2522652572952211, 0.27403307205531746, 0.16978099039988592, 0.10347411051043309, 0.06688732843031175, 0.192645862698555, 0.14492921065539122, 0.09773477824637666, 0.2237498210160993, 0.15073072747327387, 0.10688324749935418, 0.1338702454813756, 0.1747869249084033, 0.16362107562599704, 0.1842204827698879, 0.182409004191868, 0.2803438506089151, 0.16387494950322434, 0.15622674662154168, 0.14751268608961254, 0.16490344743942842, 0.17755932145519182, 0.203677294193767, 0.18132296012481675, 0.13108971499605104, 0.10023873997852206, 0.17332795163383707], [0.0725258250895422, 0.06326156595605426, 0.08616654391516931, 0.058137826636084355, 0.06659838807536289, 0.02684858558495762, 0.09546695306198671, 0.06820286682341248, 0.08194682581233792, 0.06583173468243331, 0.0069708108367194654, 0.010448577468196163, 0.058480917796259746, 0.07891852190368809, 0.08288432902190834, 0.07030768669210374, 0.09231602409272455, 0.0963042960211169, 0.10334718841477297, 0.035271061860839836, 0.01827425105147995, 0.11851667950395495, 0.05552107330004219, 0.03443077628617175, 0.07459916305379011, 0.10049898890429176, 0.015232589412335074, 0.12116189420339651, 0.025380409679200966, 0.16641912079649046, 0.06607219795114361, 4.092391803860664, 29.48540322482586, 51.864100992679596, 57.294936776161194, 51.28933243453503, 45.62069021165371, 33.86646553874016, 21.24695509672165, 22.280550934374332, 38.84309649467468, 64.6376171708107, 56.249844655394554, 38.42861473560333, 36.69319085776806, 35.71211390197277, 23.217014484107494, 5.618556635454297, 0.7962915650568902, 0.11671190251945518, 0.07654626911971718, 0.04189930150459986, 0.7085299899335951, 2.2592566441744566, 3.212677021510899, 3.500784211792052, 7.298098336905241, 9.562885109335184, 7.357118194922805, 7.043631691485643, 11.832595467567444, 7.335384786128998, 9.533019661903381, 9.220333490520716, 10.906453114002943, 9.724467638880014, 8.241580110043287, 4.505311846733093, 13.021197337657213, 16.362003721296787, 13.65946238860488, 12.057356256991625, 17.111036628484726, 22.561570554971695, 17.974606789648533, 23.32992732524872, 24.511261135339737, 27.392524927854538, 26.640142500400543, 29.709152318537235, 29.90870051085949, 26.84618454426527, 21.91849496215582, 39.93663601577282, 42.68341362476349, 54.024250879883766, 53.873729556798935, 53.12383979558945, 52.922697588801384, 59.00875881314278, 56.81302383542061, 35.54615020751953, 37.43182562291622, 38.807066828012466, 44.44514349102974, 48.63697595894337, 44.321802109479904, 49.00620214641094, 43.96451108157635, 42.74118572473526, 30.41782569140196, 19.7982220351696, 13.681984730064869, 11.768602151423693, 10.72768410667777, 10.059185978025198, 10.62657818198204, 16.25945672392845, 13.911298625171185, 7.902377061545849, 13.784469980746508, 12.673116065561771, 10.55250495672226, 7.9506173729896545, 7.23302872851491, 7.206660993397236, 4.5497936848551035, 3.6037209257483482, 2.908305278979242, 1.5227599767968059, 0.7422147667966783, 0.6201849086210132, 0.04788785437995102, 0.04824513911444228, 0.13063819234957919, 0.734125713352114, 5.140884267166257, 19.130164682865143, 37.03364498913288, 39.500814601778984, 46.11712597310543, 38.815118595957756, 27.44014397263527, 24.526076540350914, 21.597343795001507, 34.43459965288639, 44.2496819794178, 49.61647979915142, 54.89094257354736, 57.387746796011925, 37.904828041791916, 14.476330205798149, 0.28963738004677, 0.06298717169556767, 0.18419093044940382, 0.10122223407961428, 0.23713464732281864, 0.20582288765581325, 0.1029966572241392, 0.08837257046252489, 0.07141425114241429, 0.06023025263857562, 0.021049749775556847, 0.024205265217460692, 0.0587324798834743, 0.029372344106377568, 0.030264776687545236, 0.0215510482667014, 0.09323150778072886, 0.0967742461943999, 0.07831842871382833, 0.023147125903051347, 0.020757870515808463, 0.033860161202028394, 0.052958589512854815, 0.11936839786358178, 0.07747893352643587, 0.12096800812287256, 0.028455177598516457, 0.045845608692616224, 0.07680888549657539, 0.01921391947689699, 0.05530907881620806, 0.05859497105120681, 0.07610491389641538, 0.03791744544287212, 0.019859766071022023, 0.09646320468164049, 0.048495450682821684, 0.04818400841031689, 0.048215638744295575, 0.1083687822392676, 0.06129128632892389, 0.013320702892087866, 0.03071619172260398, 0.04997834708774462, 0.007959354788908968, 0.019979528296971694, 0.0035522481084626634, 0.103373341698898, 0.0614184978621779, 0.0698942733288277, 0.02667119559191633, 0.04828927092603408, 0.06545438969624229, 0.019613120712165255, 0.0397694935236359, 0.020573263136611786, 0.03364914264238905, 0.030286569854069967, 0.01178990549306036, 0.09254479853552766, 0.03375252381374594, 0.09596092655556276, 0.08585931704146788, 0.061548258672701195, 0.05130786383233499, 5.1854573003947735, 35.04629842936993, 63.54611054062843, 73.25063779950142, 67.72432073950768, 56.89261056482792, 46.126408874988556, 27.651980705559254, 27.52419736236334, 46.51268854737282, 73.62974345684052, 57.74803966283798, 52.560052648186684, 52.52729840576649, 50.24093449115753, 31.78312472999096, 8.3420486189425, 1.3566714827902615, 0.07849505986087024, 0.40066881745588034, 0.7627759978640825, 2.1113146701827645, 5.857893442735076, 5.94972881488502, 10.244328193366528, 9.52617147937417, 10.205057300627232, 9.394294805824757, 9.018242284655571, 13.837853316217661, 12.307561431080103, 13.522936664521694, 14.91805175319314, 16.05008415877819, 8.732166085392237, 13.429449331015348, 8.270031083375216, 4.740610895678401, 14.68752572312951, 10.950809083878994, 12.932852078229189, 18.028831779956818, 21.415894031524658, 19.234510883688927, 24.291984401643276, 24.615214057266712, 28.07205766439438, 26.877377070486546, 30.73087189346552, 31.819359585642815, 29.936326928436756, 25.246759168803692, 45.95427431166172, 49.34081219136715, 62.18006484210491, 63.38737025856972, 60.485849753022194, 61.47134207189083, 65.90004622936249, 64.25972744822502, 40.54368004202843, 39.57018367946148, 39.06266011297703, 44.96204875409603, 46.7807337641716, 44.4127806276083, 48.619455099105835, 43.179655596613884, 43.4594801813364, 31.762328445911407, 21.83231558650732, 14.803389105945826, 12.044671587646008, 8.416415378451347, 8.043466340750456, 10.436013657599688, 14.482640717178583, 15.631649661809206, 13.211017102003098, 18.5367239266634, 15.263448469340801, 9.070496130734682, 11.427568551152945, 8.71832912787795, 9.983651731163263, 7.05742827616632, 8.836742173880339, 6.892333785071969, 4.459606474265456, 3.416248722933233, 1.4678042382001877, 0.30011804890818894, 0.04709130727860611, 0.22198787337401882, 0.8281447808258235, 5.155562404543161, 19.739646278321743, 35.632219389081, 37.20217354595661, 40.39720930159092, 30.580964237451553, 23.85217510163784, 27.995043396949768, 30.038568042218685, 40.25082975625992, 54.1561646014452, 57.53394775092602, 61.446992978453636, 67.07988291978836, 45.00674195587635, 17.12695587426424, 0.37799736368469894, 0.0535590092476923, 0.13677662936970592, 0.0369149189646123, 0.09826666064327583, 0.09059227479156107, 0.04820085516257677, 0.04345024542999454, 0.027169263885298278, 0.04272646961908322, 0.03515106771374121, 0.08307820768095553, 0.03136067090963479, 0.02817423202941427, 0.04933261552650947, 0.060082620911998674, 0.004144794584135525, 0.06032785247953143, 0.05881036457139999, 0.04190684914647136, 0.024727713062020484, 0.028723215364152566, 0.06748375541064888, 0.114049959811382, 0.03264732120442204, 0.07102171439328231, 0.027719237987184897, 0.025677858757262584, 0.019691151974257082, 0.023342451750067994, 0.013069737306068419, 0.03898148854204919, 0.03915571141988039, 0.06335837912047282, 0.16334513027686626, 0.23175426962552592, 0.1613350975094363, 0.25567530712578446, 0.2583815634716302, 0.1441873746807687, 0.16690512362401932, 0.23481312033254653, 0.1857522310456261, 0.17729103507008404, 0.11301294201985002, 0.09335110487882048, 0.14786090177949518, 0.18171770847402513, 0.20898249233141541, 0.2584724023472518, 0.2592545369407162, 0.21344609500374645, 0.1966817062930204, 0.0911327735229861, 0.09670996136264876, 0.2845300384797156, 0.3376181179191917, 0.10591336438665166, 0.17910433933138847, 0.2492369682295248, 0.16680993576301262, 0.3214358846889809, 0.2675652550533414, 0.31792570429388434, 0.2217780682258308, 7.526744892820716, 44.0425930917263, 75.53928539156914, 86.15309625864029, 75.17541691660881, 67.0902943611145, 55.46743243932724, 35.98860986530781, 35.88861063122749, 52.263421565294266, 76.1185947060585, 67.55874842405319, 49.4163179397583, 49.767647087574005, 48.49964752793312, 29.674429781734943, 7.924077222123742, 1.3927829638123512, 0.2946168347261846, 0.38767630525399, 0.7042426918633282, 2.499523451551795, 5.918123535811901, 8.739027567207813, 14.264680612832308, 21.65103681385517, 18.86910729110241, 20.950029529631138, 21.081958450376987, 22.999229170382023, 18.616599440574646, 19.44387584924698, 17.10828747600317, 26.126548759639263, 19.145475961267948, 19.180743768811226, 15.788603089749813, 22.21205770969391, 29.229946732521057, 20.10390993207693, 16.477166041731834, 21.552479602396488, 25.367552787065506, 23.865109607577324, 30.750788524746895, 29.59262017160654, 35.146103873848915, 30.944200046360493, 35.846809074282646, 38.87859418988228, 35.02261810004711, 30.700555220246315, 52.6653677970171, 57.66382858157158, 65.30257388949394, 66.82839721441269, 64.2914329469204, 65.1727120578289, 68.98404434323311, 66.55067011713982, 48.20291385054588, 42.9594612121582, 44.42510336637497, 48.0650420486927, 52.51553423702717, 49.10395570099354, 54.56924803555012, 47.46659696102142, 46.05110451579094, 34.960803017020226, 23.26260443776846, 16.732046864926815, 17.15252660214901, 17.021836414933205, 18.928435407578945, 17.812560684978962, 25.432155020534992, 23.28507263213396, 17.36197706311941, 22.13275406509638, 20.726035349071026, 22.65384290367365, 18.78434333950281, 15.047057680785656, 14.394044671207666, 8.252565320581198, 10.435181502252817, 8.514464367181063, 4.93482512421906, 3.20599555503577, 0.7611534849274904, 0.42533914209343493, 0.21373296476667747, 0.2938838303089142, 0.9930494602303952, 6.444841772317886, 23.63647397607565, 44.8406832665205, 52.96418376266956, 61.959213092923164, 51.94381311535835, 40.32484978437424, 36.15771219134331, 33.3284106105566, 46.353564485907555, 60.451894775033, 66.92336171865463, 71.17417082190514, 79.00102883577347, 56.03433161973953, 22.64649599790573, 0.9680392616428435, 0.27806783211417496, 0.28670652012806386, 0.37324269069358706, 0.4642804025206715, 0.34661042445804924, 0.3550802590325475, 0.1685063072363846, 0.19264350266894326, 0.1236413576407358, 0.1116525853285566, 0.12618603359442204, 0.14402340457309037, 0.19037469784962013, 0.1256967059453018, 0.16034260857850313, 0.13092188572045416, 0.19003933615749702, 0.14030920778168365, 0.22270082496106625, 0.15586649329634383, 0.08688710993737914, 0.17872217780677602, 0.23240115522639826, 0.16635222360491753, 0.25057547609321773, 0.10937282640952617, 0.13354099908610806, 0.17597833910258487, 0.19471777573926374, 0.1400202006334439, 0.20860984514001757, 0.1806030175066553, 0.1560199397499673], [0.04491699641221203, 0.04948175381287001, 0.035191555580240674, 0.030769132827117573, 0.07034894268144853, 0.040342620777664706, 0.05284621722239535, 0.024358025184483267, 0.07259734586114064, 0.043650907318806276, 0.019857083207170945, 0.03513793912134133, 0.03643397387349978, 0.030333341856021434, 0.054621000308543444, 0.03711617086082697, 0.0733749607752543, 0.03307361082988791, 0.01629339767532656, 0.031298649628297426, 0.03995512321125716, 0.009436874333914602, 0.09208661140291952, 0.06902316265041009, 0.05815699631057214, 0.06669920883723535, 0.10118315258296207, 0.13485155766829848, 0.05627764461678453, 0.16795665782410651, 0.40655743272509426, 12.253115102648735, 37.360689640045166, 49.68983106315136, 49.631386399269104, 39.11677300930023, 28.834317661821842, 27.98808977007866, 32.217813804745674, 33.60524095594883, 30.10575033724308, 42.0179895311594, 49.04405951499939, 29.55820731818676, 29.10694543272257, 22.222070172429085, 12.480429355055094, 2.6975814113393426, 0.13662278215633705, 0.020234201838320587, 0.19828369142487645, 0.5116779904346913, 1.939967495854944, 6.392514780163765, 5.045477086678147, 4.721547793596983, 4.762763706967235, 7.127707405015826, 6.08290976844728, 13.428088054060936, 11.846785806119442, 9.985319841653109, 13.248186707496643, 7.482849173247814, 14.439237546175718, 9.873661883175373, 9.20412641018629, 5.051476964727044, 10.584403295069933, 28.819707445800304, 25.305422320961952, 24.732196480035782, 30.710478387773037, 38.682733699679375, 35.20049035549164, 37.68000170588493, 37.35812097787857, 46.52513287961483, 43.0516404658556, 48.29589486122131, 42.24328324198723, 46.0493528097868, 38.90275329351425, 47.681946605443954, 40.775277614593506, 40.64900279045105, 47.016374319791794, 50.17750069499016, 46.713576167821884, 50.528370067477226, 51.504423692822456, 49.91889417171478, 55.12247174978256, 56.48331552743912, 60.75026236474514, 59.42462369799614, 60.48291251063347, 59.86145965754986, 58.67943048477173, 53.91127534210682, 49.110187366604805, 41.81623935699463, 35.18740005791187, 22.659506499767303, 19.631118401885033, 11.548051536083221, 8.083434496074915, 15.113366022706032, 18.080771192908287, 8.277947008609772, 21.353482380509377, 22.330333963036537, 7.3502415139228106, 7.937039276584983, 7.746876105666161, 12.79194613918662, 3.425512150861323, 6.475417306646705, 4.940260732546449, 4.14219525642693, 2.5248075323179364, 1.8613231158815324, 0.14695514022605494, 0.0720682687824592, 0.12149876245530322, 0.2411480780574493, 0.7747337780892849, 5.712407799437642, 24.361723959445953, 42.167982682585716, 42.836100831627846, 37.23932035267353, 35.95640279352665, 24.147407859563828, 22.615354768931866, 29.009803645312786, 27.288281321525574, 39.02155391871929, 49.46541890501976, 51.32517211139202, 54.38544049859047, 25.72990134358406, 1.8449253332801163, 0.08483530167723075, 0.06516711917356588, 0.07449186334270053, 0.2625686419196427, 0.155654298432637, 0.037245278581394814, 0.13816426740959287, 0.07143555820221081, 0.03209143404092174, 0.02238651730294805, 0.03332508014864288, 0.04122188394831028, 0.04345446082879789, 0.030076948387431912, 0.029631509496539366, 0.08406258493778296, 0.0435104298958322, 0.02430145126709249, 0.01617421061382629, 0.0790851711644791, 0.07588313048472628, 0.029498243893613108, 0.06975777010666206, 0.07481363631086424, 0.040243800103780814, 0.06420099874958396, 0.06629306852119043, 0.07979505026014522, 0.05756733400630765, 0.03730062424438074, 0.08430272166151553, 0.057283525602542795, 0.03084038085944485, 0.037273970010573976, 0.04996945986931678, 0.05030931155488361, 0.02039863022218924, 0.11463696151622571, 0.024640417941554915, 0.06077931204345077, 0.0386687623540638, 0.02316180558409542, 0.05932069499976933, 0.034363797458354384, 0.032971057153190486, 0.07154125487431884, 0.02590626583696576, 0.03801049962930847, 0.022227194895094726, 0.04113780232728459, 0.02701846318814205, 0.05337138689355925, 0.05075320121250115, 0.09540999322780408, 0.03635241184383631, 0.11121272924356163, 0.06866008916404098, 0.03421606925257947, 0.05622579075861722, 0.041668044577818364, 0.11533659155247733, 0.0737093279894907, 0.06576506013516337, 0.26323396246880293, 14.362382870167494, 45.472532361745834, 62.95976400375366, 60.46409212052822, 51.68306350708008, 41.26642405986786, 37.516473680734634, 36.88058540225029, 36.83215320110321, 32.90837734937668, 49.25189696252346, 62.88565658032894, 34.40060667693615, 30.178461335599422, 25.55206898599863, 12.996550910174847, 3.0441254284232855, 0.06874404090922326, 0.06378396370564587, 0.5189587560016662, 2.2235195618122816, 5.441436264663935, 9.192409738898277, 10.633190777152777, 7.834115624427795, 12.359365001320839, 10.852146428078413, 14.101232383400202, 14.565075393766165, 15.864521116018295, 14.195134844630957, 15.48249151557684, 14.01020161807537, 14.17453519999981, 8.410085868090391, 9.262409582734108, 7.392577892169356, 5.496676750481129, 21.29400797188282, 21.717350855469704, 24.494578130543232, 30.53467132151127, 36.6868831962347, 34.65257115662098, 36.290488466620445, 36.023472994565964, 45.4564668238163, 44.495038613677025, 50.25185890495777, 45.098818615078926, 50.50358399748802, 42.82587178051472, 54.77977193892002, 46.47859677672386, 47.55347929894924, 55.40463700890541, 54.91925485432148, 56.29341311752796, 58.37013088166714, 56.99091129004955, 55.420968532562256, 57.70381383597851, 57.39097282290459, 60.71383751928806, 60.41484676301479, 59.93413455784321, 60.72185128927231, 60.00421039760113, 56.45078167319298, 49.768547639250755, 41.92372038960457, 29.00321289896965, 22.427428252995014, 14.459518007934093, 9.788749739527702, 14.971731472760439, 12.032646182924509, 9.327804073691368, 14.668045118451118, 19.15184061974287, 14.113809708505869, 12.546814642846584, 16.22282098978758, 12.686810530722141, 10.602049548178911, 8.606171496212482, 14.509653467684984, 8.63596759736538, 3.3837132062762976, 6.052987799048424, 5.03901980817318, 1.288537576328963, 0.4461391072254628, 0.12105756308301352, 0.1970440079458058, 1.0821942798793316, 6.354116415604949, 24.306640215218067, 39.225929751992226, 43.0753093957901, 41.93307548761368, 40.971605479717255, 26.00846629589796, 25.305167734622955, 35.30887573957443, 35.17150171101093, 46.6881213337183, 56.17824889719486, 60.14356791973114, 61.91865026950836, 30.210643708705902, 2.430276917293668, 0.08430552697973326, 0.018037203517451417, 0.046453412796836346, 0.06948794005438685, 0.04914688935969025, 0.033258272014791146, 0.05553193092055153, 0.060292778580333106, 0.018617791210999712, 0.0255730823482736, 0.03177422899170779, 0.02332289430341916, 0.05663384581566788, 0.06604050824535079, 0.032135955480043776, 0.09134297943091951, 0.02838866632373538, 0.07251541275763884, 0.042604950358509086, 0.04587976603943389, 0.03678282409964595, 0.028744229275616817, 0.05350772313249763, 0.04007526578789111, 0.030229140611481853, 0.00512476394760597, 0.031727911555208266, 0.04996419062081259, 0.07322699879296124, 0.059470504929777235, 0.011995755921816453, 0.0549257224338362, 0.0180216481021489, 0.09848084446275607, 0.19263989583123475, 0.24353718501515687, 0.08286949348985218, 0.18242683057906106, 0.13649217900820076, 0.28764619783032686, 0.16401134140323848, 0.1802658598171547, 0.2153720275964588, 0.18870347033953294, 0.16327284509316087, 0.1786504714982584, 0.11026534804841504, 0.1443699875380844, 0.06743080317392014, 0.1899779011728242, 0.14281226409366354, 0.20792695053387433, 0.13853332260623574, 0.2096074548899196, 0.15814377344213426, 0.2689665782963857, 0.18788744928315282, 0.16584324388531968, 0.2440617943648249, 0.22988882206846029, 0.312070693471469, 0.2501634357031435, 0.2768106636358425, 1.2462495267391205, 20.504338145256042, 57.89208613336086, 75.98983481526375, 70.82351803779602, 61.80794321000576, 48.59066404402256, 46.21336340904236, 48.76474790275097, 49.51830066740513, 44.65192839503288, 53.43325339257717, 61.28570683300495, 40.53304821252823, 40.90378291904926, 31.17701355367899, 16.112805493175983, 3.5307831270620227, 0.30061196302995086, 0.19205840828362852, 0.5876831151545048, 1.1772233806550503, 6.961249737069011, 15.416074879467487, 18.385718129575253, 11.240117959678173, 16.300965696573257, 22.29613959789276, 17.084633745253086, 22.328259274363518, 23.16808070987463, 20.996590331196785, 23.966837748885155, 17.608652226626873, 26.281417049467564, 18.63493725657463, 16.853927224874496, 13.981366865336895, 17.75586772710085, 36.13311991095543, 30.293361470103264, 28.282222487032413, 33.7657405436039, 41.49291470646858, 36.401476711034775, 39.26883704960346, 40.636881440877914, 51.25118248164654, 49.94757883250713, 55.83993025124073, 49.31200213730335, 54.39091220498085, 49.514823853969574, 63.54920357465744, 52.86478489637375, 53.50281625986099, 60.774550661444664, 62.16500245034695, 58.863750994205475, 64.3518877029419, 62.86591283977032, 63.235260620713234, 60.63484735786915, 59.46555130183697, 62.77852512896061, 62.477661073207855, 64.7711344063282, 66.50225311517715, 63.07462424039841, 58.2539027184248, 52.204775512218475, 46.29656754434109, 36.10276333987713, 27.74207767099142, 24.703872799873352, 18.961100354790688, 19.69688717275858, 26.042451672255993, 28.335345536470413, 16.864730045199394, 31.8570364639163, 33.434136137366295, 17.167229913175106, 14.466806966811419, 14.635229129344225, 24.555008187890053, 12.760072499513626, 17.490932643413544, 12.244225479662418, 12.390050254762173, 9.235648568719625, 7.068064855411649, 1.186547961551696, 0.3554850263753906, 0.3299891366623342, 0.6554765836335719, 1.3094933331012726, 7.925005322322249, 30.628121607005596, 53.44613090157509, 56.775736436247826, 52.174650728702545, 51.52073621749878, 35.833722576498985, 35.52843935787678, 42.00454585254192, 39.53408561646938, 54.11384627223015, 67.35077038407326, 68.66841048002243, 76.50450959801674, 40.04889339208603, 4.527598600834608, 0.4007848002947867, 0.22975404805038124, 0.37214175914414227, 0.5635002627968788, 0.27003895200323313, 0.22441251436248422, 0.30738702917005867, 0.12664212787058204, 0.0969870644621551, 0.19810998433968052, 0.13737483008299023, 0.12562566756969318, 0.13243424909887835, 0.24954139720648527, 0.14407440496142954, 0.23118559154681861, 0.14382229739567265, 0.1458782542613335, 0.08974970711278729, 0.19376150361495093, 0.18148629198549315, 0.16814118542242795, 0.19808078825008124, 0.2935914834961295, 0.2165491777122952, 0.1608406490413472, 0.13372358225751668, 0.1205349872179795, 0.18405631970381364, 0.16532431938685477, 0.14275972003815696, 0.19589808740420267, 0.19817977590719238], [0.04610317475453485, 0.07008866406977177, 0.04723904661659617, 0.07166780589614064, 0.01509862804596196, 0.06937254351214506, 0.07028579333564267, 0.07029817235888913, 0.06756729155313224, 0.028553502888826188, 0.0065028653898480115, 0.009767349911271594, 0.017097017444029916, 0.031885907374089584, 0.03921002920833416, 0.014200067180354381, 0.07555135336588137, 0.02936753870017128, 0.06343292043311521, 0.010686300356610445, 0.03831391557469033, 0.034921807164209895, 0.06371937459334731, 0.036574555197148584, 0.09181363464449532, 0.04148591782723088, 0.05559697645367123, 0.08337204621057026, 0.11870775284478441, 0.051016088473261334, 3.3263647835701704, 16.634323708713055, 28.08325756341219, 50.86098901927471, 46.34840816259384, 37.365902960300446, 32.674374505877495, 27.712144777178764, 17.26195503026247, 21.343051940202713, 30.315073505043983, 25.823813304305077, 19.983249306678772, 48.8627902418375, 42.27315343916416, 19.729449525475502, 5.806126920506358, 0.43697661138139665, 0.05049240309745073, 0.3365495440084487, 0.8130115584935993, 3.8113413099199533, 4.04421703889966, 5.496646827086806, 5.477822162210941, 11.723748408257961, 8.41706894338131, 6.431062761694193, 9.17209317907691, 7.614488359540701, 13.62474175170064, 11.431620083749294, 10.962457358837128, 21.952567733824253, 11.477539669722319, 5.141216274350882, 18.295079693198204, 19.993960931897163, 15.061660297214985, 35.75562536716461, 35.36087214946747, 43.195375353097916, 48.69660995900631, 50.986036509275436, 47.42315389215946, 51.371970400214195, 53.795677945017815, 56.47462919354439, 53.8625505566597, 57.667597979307175, 55.073982551693916, 61.26198090612888, 55.677785351872444, 49.92550201714039, 36.21575407683849, 34.79806534945965, 45.37304989993572, 44.796472638845444, 44.40078467130661, 43.26196298003197, 40.20127281546593, 55.70014715194702, 66.63422763347626, 64.12304118275642, 67.41840675473213, 64.05071586370468, 68.36030781269073, 65.58115974068642, 66.15778639912605, 65.83620965480804, 58.92736718058586, 53.18075694143772, 43.98884877562523, 41.601949855685234, 29.967975430190563, 23.915071226656437, 32.58826732635498, 16.885773316025734, 11.769402008503675, 19.948471672832966, 17.1693255007267, 11.917036436498165, 6.56050899066031, 18.78633253276348, 10.021355208009481, 7.630752911791205, 6.4830216486006975, 13.768910765647888, 8.285062126815319, 2.2725309943780303, 4.766380162909627, 4.554129252210259, 0.934067718917504, 0.2554426883580163, 0.5567471939139068, 0.10551276049227454, 0.16913784522330388, 1.2085101893171668, 9.631194043904543, 19.523169994354248, 36.19280330836773, 28.581032752990723, 22.44571477174759, 34.592105001211166, 24.1649629175663, 19.371778517961502, 26.15520492196083, 43.306568786501884, 51.28498546779156, 52.90116414427757, 53.71275119483471, 42.71434776484966, 9.04320314526558, 1.4724336960352957, 0.11850179944303818, 0.19095386989647523, 0.13295139244291931, 0.12108933442505077, 0.09666897996794432, 0.07376973138889298, 0.03959941182984039, 0.01346693845334812, 0.048378146821050905, 0.022087255529186223, 0.02692662241315702, 0.035493943651090376, 0.019158692557539325, 0.026797056416398846, 0.034783741721184924, 0.13944453152362257, 0.06309844931820408, 0.04664065294491593, 0.11541694388142787, 0.08032566358451732, 0.03606413200031966, 0.05371382496377919, 0.045106663383194245, 0.06969075417146087, 0.0183449517498957, 0.03854709095321596, 0.03987595089711249, 0.03262673402787186, 0.013056572533969302, 0.1446743423002772, 0.010498046249267645, 0.01861583565187175, 0.06802560485084541, 0.02935492590040667, 0.03483804837742355, 0.029871124861529097, 0.038776833898737095, 0.020546766609186307, 0.06439122604206204, 0.045412090548779815, 0.06801278053899296, 0.0449670876696473, 0.039344343094853684, 0.07090433631674387, 0.04657267221773509, 0.09987699493649416, 0.07176701619755477, 0.07014741990133189, 0.013618092598335352, 0.03815440948528703, 0.057204824552172795, 0.015523258043685928, 0.03444776404649019, 0.04209159567835741, 0.06754415881005116, 0.048832537868293, 0.07339869465795346, 0.05315300251822919, 0.023348375943896826, 0.0484668965509627, 0.09651298794778995, 0.04118115859455429, 4.236096767708659, 21.97371929883957, 43.846318423748016, 61.66358135640621, 60.59464551508427, 49.07644137740135, 44.756753370165825, 33.6991985142231, 25.123041607439518, 33.6723605543375, 42.66621954739094, 37.55002208054066, 27.47459102421999, 43.71259979903698, 38.25086027383804, 19.709726683795452, 5.233602616935968, 0.7233447418548167, 0.09822130057727918, 0.7055866322480142, 2.4014167534187436, 6.4286707900464535, 7.833282994106412, 11.71019358560443, 11.847789902240038, 10.90017395094037, 14.147069323807955, 12.47714253142476, 15.723607577383518, 13.394282218068838, 17.044990472495556, 17.360660433769226, 15.556164812296629, 11.971240527927876, 8.677862249314785, 8.13275869935751, 10.731375608593225, 16.20537992566824, 19.89133793860674, 32.453306168317795, 34.62159521877766, 43.421315029263496, 47.04206854104996, 49.777895137667656, 48.692035004496574, 51.4114198833704, 52.3448321968317, 57.09801234304905, 54.23224791884422, 58.56887921690941, 56.44765444099903, 64.35211569070816, 60.27768172323704, 56.430935338139534, 40.98481357097626, 42.11470954120159, 53.04931819438934, 51.7539981007576, 52.45769754052162, 52.0862028747797, 47.24971599876881, 59.032724127173424, 68.33486437797546, 66.33817031979561, 66.61210522055626, 66.39702156186104, 68.29589366912842, 69.19054806232452, 69.72702607512474, 69.28696408867836, 59.918654188513756, 55.92993602156639, 45.39046436548233, 40.011989772319794, 29.760603457689285, 21.812803633511066, 16.351962760090828, 12.805715650320053, 9.665499553084373, 16.76042754203081, 19.998834170401096, 15.815789680927992, 13.002990614622831, 21.798831783235073, 15.602996349334717, 15.308006778359413, 13.715380188077688, 7.480205940082669, 9.828535504639149, 8.409087471663952, 8.27872596681118, 6.234601428732276, 4.039842998608947, 1.711470556911081, 1.3804089277982712, 0.04578851527185179, 0.19960260658990592, 1.3742293906398118, 10.34357886761427, 22.18531284481287, 37.34260641038418, 29.982809834182262, 27.335024513304234, 31.299800164997578, 23.123098723590374, 21.770441606640816, 29.005015902221203, 47.73403041064739, 58.07838633656502, 58.98041233420372, 60.97590945661068, 50.09859412908554, 11.7895314283669, 1.8599769193679094, 0.09925874881446362, 0.02328006496099988, 0.09460149012738839, 0.01173593002022244, 0.038258440035860986, 0.023244289732247125, 0.018224230298073962, 0.026466186573088635, 0.053905636741546914, 0.058062532043550164, 0.04325089343183208, 0.04857953230384737, 0.03246400701755192, 0.017842122579168063, 0.07588822903926484, 0.08174498390872031, 0.04229057660268154, 0.03448861556535121, 0.020248454784450587, 0.02489510632585734, 0.04631514697393868, 0.10735288597061299, 0.054610673323622905, 0.03547190186509397, 0.06774407855118625, 0.059826472352142446, 0.12340004832367413, 0.08848888726788573, 0.06525330478325486, 0.08901607186999172, 0.0308970271362341, 0.04613168064679485, 0.19120382523396984, 0.20474459161050618, 0.13402364740613848, 0.13773159531410784, 0.09039504162501544, 0.2219352254178375, 0.16877444519195706, 0.18995574064319953, 0.24906437436584383, 0.09591306545189582, 0.10901761968852952, 0.1768036963767372, 0.06500299321487546, 0.33305824385024607, 0.17434929526643828, 0.18416799808619544, 0.17024128523189574, 0.14656359795480967, 0.12527037179097533, 0.08666025765705854, 0.15029125730507076, 0.13961650198325515, 0.2495395566802472, 0.21762367396149784, 0.20939338981406763, 0.17889214446768165, 0.1471941711497493, 0.12939154752530158, 0.374608242418617, 0.34860849380493164, 6.581398844718933, 31.500091217458248, 52.17262163758278, 76.13335311412811, 72.65349984169006, 60.863716676831245, 55.40987312793732, 46.99393272399902, 32.62048579752445, 34.26938071846962, 46.373125836253166, 39.72340665757656, 32.122123539447784, 63.26769568026066, 51.97474725544453, 24.315472841262817, 6.794310444965959, 0.781979039311409, 0.2720063558081165, 0.8866581378970295, 2.7218269603326917, 9.692082926630974, 8.671676181256771, 18.071929067373276, 16.061911024153233, 22.94714916497469, 20.196619257330894, 18.951363377273083, 19.82829362154007, 19.528560005128384, 22.844241186976433, 23.637952096760273, 22.1163522452116, 32.723175287246704, 23.767878524959087, 11.67468449100852, 26.736520528793335, 25.28561968356371, 21.63522396236658, 40.38850396871567, 38.56048285961151, 46.0267174243927, 52.6225820928812, 53.24330918490887, 51.555306762456894, 52.81310386955738, 54.6915140748024, 58.89376558363438, 57.8541299700737, 59.990409538149834, 61.50106027722359, 68.19115608930588, 65.17413318157196, 65.78258693218231, 47.8407096862793, 47.786608189344406, 57.62640818953514, 55.75520999729633, 56.53234429657459, 57.459391951560974, 52.427576556801796, 66.22587114572525, 69.9680395424366, 67.20632493495941, 68.69786649942398, 66.286880671978, 73.33933264017105, 71.95853233337402, 72.02897295355797, 71.61240890622139, 60.76567813754082, 56.722269505262375, 48.10530088841915, 46.315680518746376, 35.255788788199425, 30.260742120444775, 39.021531119942665, 23.58503233641386, 20.738947056233883, 33.143770918250084, 30.283018425107002, 20.408186204731464, 13.3368606492877, 32.358018681406975, 22.133143544197083, 14.607749953866005, 17.615489959716797, 22.36178297549486, 18.77380270510912, 10.137257538735867, 12.233205121010542, 9.71577275544405, 3.86861112434417, 1.3927285792306066, 1.2669112742878497, 0.15703426266554743, 0.2817718021105975, 1.8648216594010592, 11.823555752635002, 26.113713048398495, 46.1160696297884, 38.665437027812004, 35.2369873970747, 46.55721835792065, 36.33609361946583, 28.6267177015543, 38.04537869989872, 55.42570307850838, 68.3496455848217, 69.5036056637764, 69.94266450405121, 61.76154009997845, 21.067175343632698, 2.947999374009669, 0.39382580027449876, 0.4044954793062061, 0.30826855218037963, 0.23029464326100424, 0.2639286423800513, 0.18290965701453388, 0.1100545038934797, 0.14418096252484247, 0.15088358020875603, 0.17171683808555827, 0.1964044399210252, 0.10190817149123177, 0.15646772197214887, 0.14033145736902952, 0.23609329538885504, 0.3080574260093272, 0.23336612532148138, 0.18434357538353652, 0.13481207541190088, 0.26707327051553875, 0.17793235456338152, 0.3416981193004176, 0.13488142169080675, 0.1564032441820018, 0.1536263947491534, 0.1370940459310077, 0.23822780116461217, 0.18774743570247665, 0.11157278961036354, 0.17040277656633407, 0.15489270648686215, 0.1274082320742309], [0.03730449083377607, 0.0442338791617658, 0.018253268681291956, 0.010324115592084127, 0.04941224797221366, 0.054972262514638714, 0.02242149472294841, 0.06419011144316755, 0.14208923414116725, 0.12109745352063328, 0.10959065417409874, 0.037355973618105054, 0.060393142921384424, 0.05308272113325074, 0.05041324933699798, 0.07446772127877921, 0.03289823391241953, 0.03347770281834528, 0.03695084262290038, 0.016535703325644135, 0.023250920821737964, 0.06223238153324928, 0.05998647196975071, 0.06070032897696365, 0.07813064308720641, 0.09012020949739963, 0.085766867705388, 0.10643246700055897, 0.07293138653039932, 0.0702769988856744, 12.03274592757225, 25.22520862519741, 35.45826852321625, 53.73967655003071, 41.26207709312439, 36.08055353164673, 22.86200523376465, 22.829940654337406, 20.2192622423172, 20.272972360253334, 17.638710513710976, 15.914049558341503, 37.40176163613796, 40.98374202847481, 26.051052510738373, 8.300790432840586, 0.370223069912754, 0.17893965676194057, 0.17752847779775038, 0.43590726563706994, 1.7691863724030554, 3.9753462094813585, 9.12102296948433, 8.967076130211353, 12.063621170818806, 3.30515265930444, 12.556992396712303, 8.295124936848879, 19.166977107524872, 13.847772683948278, 19.445184879004955, 20.369162298738956, 16.527118161320686, 12.944993376731873, 16.206261478364468, 26.185582391917706, 29.206344299018383, 35.21265730261803, 34.35857713222504, 52.181801944971085, 53.47397580742836, 59.28073301911354, 54.54279765486717, 58.83507773280144, 58.70922088623047, 63.1568518280983, 60.19094377756119, 66.50049760937691, 61.71196796000004, 64.12993401288986, 64.12039652466774, 67.75465071201324, 61.25630401074886, 54.72181744873524, 35.67497469484806, 31.59282524138689, 40.58212257921696, 45.600851476192474, 42.80546687543392, 43.09058457612991, 31.569238007068634, 51.26263506710529, 65.5597896873951, 64.20900017023087, 64.90905180573463, 70.06329283118248, 66.38062924146652, 62.4650077521801, 62.79864124953747, 66.48358091711998, 61.909716948866844, 59.89551343023777, 55.00909723341465, 52.36637324094772, 43.69502954185009, 36.35279752314091, 33.660949766635895, 26.610222905874252, 12.019654680043459, 19.58677288144827, 19.09977201372385, 14.537637066096067, 16.849595457315445, 20.90584360063076, 14.726727269589901, 10.708640478551388, 8.826761059463024, 8.706103283911943, 10.325710326433182, 4.015135299414396, 6.275462536141276, 4.497008342295885, 3.967770840972662, 2.0609604846686125, 0.9088850452098995, 0.052971213444834575, 0.03857120704196859, 0.08748065738473088, 3.6708547733724117, 10.72736682370305, 21.7116017639637, 46.928188651800156, 56.66156776249409, 40.1180686801672, 29.44881308823824, 25.35495076328516, 27.968558818101883, 34.73194509744644, 41.56927540898323, 45.22803448140621, 50.377016589045525, 49.539066553115845, 26.512062773108482, 4.115519262850285, 0.3721123997820541, 0.10760475604911335, 0.1398319029249251, 0.05835457828652579, 0.07752556266495958, 0.023859192478994373, 0.014465389613178559, 0.05531394730496686, 0.04940716426062863, 0.06243652038392611, 0.0932412596012, 0.0368955080921296, 0.006090304104873212, 0.02251588477520272, 0.09303291648393497, 0.07316802773857489, 0.0303358948440291, 0.01139663680078229, 0.07193686411483213, 0.0819143420085311, 0.02091456943162484, 0.03942106261092704, 0.06924122048076242, 0.044741597230313346, 0.05741186148952693, 0.04843847229494713, 0.011266515120951226, 0.05087059784273151, 0.04906529022264294, 0.011300584337732289, 0.12249232750036754, 0.0510366570961196, 0.013502821293513989, 0.0083303228711884, 0.05203063032240607, 0.03481854473648127, 0.010169150518777315, 0.10210667373030446, 0.053239826374920085, 0.01702231656963704, 0.047939726791810244, 0.070414837973658, 0.08673522941535339, 0.02921409595728619, 0.05547059241507668, 0.05957193425274454, 0.04896685917628929, 0.0203437298478093, 0.03078413719777018, 0.04601903747243341, 0.06926743313670158, 0.04016461665742099, 0.022272451060416643, 0.045837734505767, 0.05417476917500608, 0.012822469470847864, 0.0795255541743245, 0.023824779091228265, 0.03151884113322012, 0.03883429839333985, 0.08682818341185339, 0.10779654927318916, 12.910875007510185, 31.58428329974413, 43.496596589684486, 64.80982393026352, 52.40328066051006, 47.084067687392235, 33.891407400369644, 32.84431278705597, 24.53920293599367, 21.62823423743248, 23.48197616636753, 19.834762774407864, 35.55554710328579, 39.8479525744915, 27.156088314950466, 8.524038903415203, 0.7515573967248201, 0.08802517113508657, 0.49147963989526033, 1.5616999310441315, 6.059284061193466, 9.74075736477971, 13.92618527635932, 12.240640372037888, 8.161658998578787, 14.942644983530045, 20.577995292842388, 14.522167146205902, 15.100593008100986, 15.844727028161287, 14.72237840294838, 16.41917735338211, 11.248239073902369, 9.365039225667715, 9.587853569537401, 18.542241230607033, 24.9154644459486, 33.41691166162491, 36.225823536515236, 49.458776861429214, 53.64850044250488, 59.841803312301636, 55.8713735640049, 60.756938606500626, 58.79212103784084, 63.326330333948135, 61.265951693058014, 65.23401036858559, 62.35595740377903, 64.96396645903587, 63.11453349888325, 69.15403202176094, 67.1694441139698, 60.065873488783836, 40.61743788421154, 39.403376430273056, 49.48437988758087, 51.6244288533926, 50.73857098817825, 50.716087594628334, 41.44509047269821, 55.95385193824768, 65.69247096776962, 66.45097106695175, 66.01094707846642, 71.04764521121979, 68.6442893743515, 65.07645562291145, 65.49792900681496, 68.68538036942482, 63.83837565779686, 59.95175801217556, 55.933325439691544, 53.16909536719322, 43.21783974766731, 36.42266817390919, 34.53772231936455, 19.800872392952442, 17.535462453961372, 16.604523807764053, 16.13165058195591, 16.62524599581957, 16.22763343155384, 22.222826331853867, 14.678771942853928, 14.58754263818264, 8.477347008883953, 9.799223877489567, 12.039208430796862, 7.825768897309899, 10.32931823283434, 4.332225434482098, 6.647461149841547, 4.4534484297037125, 2.3989637475460768, 0.2734085399424657, 0.17800705914851278, 0.1081556745339185, 3.404129035770893, 11.111320070922375, 24.3230040371418, 35.994241163134575, 46.16236634552479, 41.067451536655426, 28.972765132784843, 29.74323268979788, 30.631045550107956, 40.03097355365753, 50.10166436433792, 54.158862456679344, 57.74159520864487, 56.87306061387062, 31.584080010652542, 6.049879565834999, 0.4016393388155848, 0.04126122148591094, 0.1282345986692235, 0.10396722311270423, 0.055183325603138655, 0.045602956088259816, 0.023701107602391858, 0.07604587604873814, 0.02270782642881386, 0.008024572871363489, 0.06741422359482385, 0.04108113193069585, 0.019522762377164327, 0.056373967963736504, 0.1360691845184192, 0.051675794675247744, 0.0185881368452101, 0.07396504981443286, 0.018414971527818125, 0.0045082581618771655, 0.01575602153025102, 0.062105210818117484, 0.022117368171166163, 0.019738547380256932, 0.06674453921732493, 0.06271795762586407, 0.04837914129893761, 0.05282509569951799, 0.05468144823680632, 0.08728251879801974, 0.0302020188246388, 0.029626687392010354, 0.12487869593314826, 0.09518714854493737, 0.10846399978618138, 0.11373404980986379, 0.11080526790465228, 0.16730466624721885, 0.1701831750688143, 0.21824197203386575, 0.24650895211379975, 0.23324522946495563, 0.342558654374443, 0.0816920019860845, 0.1417871651938185, 0.1361498114420101, 0.12827405123971403, 0.13190153549658135, 0.15193832048680633, 0.13596964767202735, 0.15308496833313257, 0.13469447469105944, 0.16139671060955152, 0.19948554021539167, 0.23265311436261982, 0.19291499513201416, 0.22546047141076997, 0.1578235812485218, 0.23625465313671157, 0.17605518107302487, 0.14844258228549734, 0.3158566262573004, 17.824609838426113, 44.16643984615803, 60.53671382367611, 74.46308434009552, 62.197285518050194, 57.17881500720978, 40.045872554183006, 41.682353541255, 36.0205053538084, 35.52985668182373, 29.68695390969515, 28.097351007163525, 51.3152052462101, 53.95822562277317, 31.930127441883087, 10.399505216628313, 0.772522771731019, 0.320333112613298, 0.354637464042753, 1.0793677065521479, 5.480286804959178, 14.8769636079669, 22.54130434244871, 19.619829207658768, 20.19773829728365, 16.28421049565077, 30.39803445339203, 19.116550013422966, 35.62134437263012, 27.90629915893078, 32.21255108714104, 31.087862737476826, 28.998601846396923, 22.297490425407887, 22.521594800055027, 33.43221344053745, 34.5309092849493, 38.113402649760246, 38.31919960677624, 54.61299128830433, 55.51053732633591, 62.692778930068016, 57.162529081106186, 60.74711233377457, 59.24184590578079, 63.56632545590401, 60.93837887048721, 66.64341554045677, 63.608556389808655, 65.51628962159157, 65.77599048614502, 72.23453432321548, 66.91763162612915, 67.32012882828712, 46.893716901540756, 45.05117677152157, 53.00195753574371, 56.90861910581589, 55.89278541505337, 55.95522366464138, 47.051241248846054, 60.030653178691864, 67.18905106186867, 64.39752325415611, 65.81898897886276, 73.33901345729828, 70.97824573516846, 67.95873016119003, 68.68186935782433, 70.77127084136009, 64.32540312409401, 59.49360519647598, 55.953023582696915, 53.72388079762459, 45.37698648869991, 38.133184388279915, 41.02239355444908, 29.394683092832565, 19.09335795789957, 27.079089246690273, 27.771085314452648, 27.321288250386715, 32.37144336104393, 34.038128927350044, 25.75905527919531, 22.567652128636837, 16.58056039363146, 17.92414739727974, 19.936055839061737, 10.94541622325778, 13.846646044403315, 17.02613778412342, 9.442309979349375, 5.586813613772392, 3.1041738437488675, 0.37199347803834826, 0.1959728662041016, 0.17045882355887443, 5.241422122344375, 14.401149339973927, 30.172298066318035, 57.182242423295975, 68.5617046058178, 56.865559816360474, 44.87345650792122, 37.234471812844276, 39.24490973353386, 47.19095595180988, 56.63121499121189, 61.38158328831196, 67.61440023779869, 66.47683247923851, 42.31019385159016, 11.340936999768019, 0.7812126085627824, 0.3398974612355232, 0.3865708317607641, 0.23479545721784234, 0.28069491614587605, 0.11961534750298597, 0.152833009196911, 0.14307602337794378, 0.2067762950900942, 0.1909761194838211, 0.10897683125222102, 0.16921096161240712, 0.14571495208656415, 0.20418510132003576, 0.31246020225808024, 0.19141808326821774, 0.11772224010201171, 0.14571766834706068, 0.17460270901210606, 0.2163497923174873, 0.1644527114694938, 0.18129480304196477, 0.1590843714075163, 0.08314637394505553, 0.08160114084603265, 0.17461361858295277, 0.1369622108177282, 0.17590249161003157, 0.17638809367781505, 0.09995850501582026, 0.2237993519520387, 0.14129908435279503], [0.04154361609835178, 0.1134487014496699, 0.09192437049932778, 0.018951575839309953, 0.06301866844296455, 0.041573784401407465, 0.03734090059879236, 0.028025579849781934, 0.03992248726717662, 0.03735450787644368, 0.07761465749354102, 0.05337657821655739, 0.01577243227075087, 0.037470639144885354, 0.05732188350521028, 0.041283931204816326, 0.02048547819867963, 0.04049874267366249, 0.027774925038102083, 0.01289235195145011, 0.01834962356952019, 0.017217330714629497, 0.0721923632954713, 0.041073532338486984, 0.13178847671952099, 0.05615648900857195, 0.06503276817966253, 0.047550848830724135, 0.05071337756817229, 0.8701423835009336, 15.314412284642458, 34.3631786853075, 49.562005922198296, 49.34789501130581, 36.90474070608616, 32.40566052496433, 26.92485172301531, 14.8051892593503, 20.018044039607048, 25.507301688194275, 22.337395884096622, 40.361772403120995, 42.1133454144001, 25.115620605647564, 14.46133716031909, 2.008133106864989, 0.36953020084183663, 0.13053065515123308, 0.5388560320716351, 2.32410728931427, 6.918748067691922, 8.767058663070202, 7.141607059165835, 11.482585798949003, 9.514614399522543, 13.680642452090979, 16.078033559024334, 13.540352080017328, 10.457173772156239, 8.932534083724022, 12.105573769658804, 18.42240136116743, 14.66987757012248, 17.90022388100624, 23.62678449600935, 35.11271886527538, 41.718873381614685, 49.633411690592766, 55.58001659810543, 56.713959351181984, 59.61828030645847, 65.72733789682388, 60.056089013814926, 63.45268115401268, 57.60161451995373, 63.35233993828297, 62.19719812273979, 63.4568153321743, 61.94307915866375, 63.134520426392555, 63.148659467697144, 64.78856027126312, 62.77404896914959, 55.912669748067856, 39.5073426514864, 26.70222356915474, 38.660318702459335, 42.1024513989687, 42.6306838542223, 39.63101841509342, 30.3829188644886, 53.82661588490009, 62.727429270744324, 63.09034779667854, 64.58815902471542, 68.73131230473518, 62.70316757261753, 60.47303684055805, 63.40183608233929, 66.1485604941845, 62.738175094127655, 58.912183195352554, 58.08784402906895, 59.86555963754654, 56.401179134845734, 51.3122034072876, 35.599662736058235, 34.07415099442005, 36.75923131406307, 32.48762212693691, 33.795021772384644, 23.224956057965755, 14.402771852910519, 20.874804966151714, 13.340933080762625, 19.61140885949135, 12.577324155718088, 4.273073533549905, 4.847335768863559, 11.589336320757866, 11.710079591721296, 5.6198737397789955, 6.482549523934722, 2.5838117161765695, 2.78158706612885, 0.38372134091332555, 0.17248456017114222, 0.11603241437114775, 0.413421259727329, 4.768210239708424, 11.024665720760822, 24.849368892610073, 30.896805189549923, 34.702732264995575, 23.73310089111328, 23.59931007027626, 53.422933146357536, 65.65752044320107, 50.51133558154106, 35.95603421330452, 49.96036894619465, 51.120074316859245, 35.362061485648155, 18.820078521966934, 0.9875267534516752, 0.09932787244906649, 0.06244339267141186, 0.0009416532066097716, 0.05657517533109058, 0.012098646348022157, 0.05916830981732346, 0.14928420743672177, 0.060215131379663944, 0.02221889211796224, 0.03009085623489227, 0.13270645402371883, 0.06984178864513524, 0.05231673196249176, 0.03262304555391893, 0.0395340991235571, 0.016887067577044945, 0.030872504721628502, 0.013043065446254332, 0.031002059586171526, 0.036798746878048405, 0.04188612838333938, 0.029864054049539845, 0.06900492066051811, 0.004563269394566305, 0.025118208905041683, 0.02409943310340168, 0.010514238056202885, 0.041774401761358604, 0.037577768162009306, 0.04240011017827783, 0.039088699195417576, 0.09118554022279568, 0.026494161829759832, 0.009812350963329664, 0.062027211097301915, 0.07864487721235491, 0.018984022535732947, 0.029091244541632477, 0.008100407376332441, 0.022248362802201882, 0.034373497328488156, 0.053173931082710624, 0.02271069668495329, 0.0281186303254799, 0.01759189264703309, 0.0177375187195139, 0.0254625116212992, 0.029312267251953017, 0.024517308629583567, 0.07702128074015491, 0.04076777120644692, 0.0838637858396396, 0.03430050339375157, 0.0509299362602178, 0.038366771332221106, 0.06517160174553283, 0.05441088345833123, 0.072162595752161, 0.026463509275345132, 0.013523442794394214, 1.0659253341145813, 21.01603388786316, 44.001870676875114, 60.09515471756458, 61.76988825201988, 48.53215478360653, 42.51135505735874, 30.09143080562353, 23.341997377574444, 26.843767873942852, 29.443844854831696, 27.927270233631134, 32.580724731087685, 39.45197582244873, 25.946164838969707, 15.793670117855072, 2.4961128970608115, 0.25736217910889536, 0.2893916401080787, 2.286229971796274, 6.524061346426606, 8.79135075956583, 8.358725924044847, 12.507174219936132, 14.376626405864954, 15.563334077596664, 12.11958171799779, 16.775795817375183, 19.95800156146288, 13.124814927577972, 14.136909618973732, 13.330648932605982, 11.760095357894897, 8.351314421743155, 12.72665899246931, 20.54080668836832, 30.70244751870632, 39.67396751046181, 47.551089227199554, 56.312700882554054, 58.90650250017643, 60.67676290869713, 66.2789922952652, 61.8356741219759, 64.54949229955673, 59.25710588693619, 63.59782576560974, 60.4216293990612, 63.331209272146225, 61.285718232393265, 63.3112945407629, 64.35299724340439, 65.04851192235947, 66.50793001055717, 60.08542723953724, 46.38375386595726, 35.36648444831371, 45.72348989546299, 47.52306193113327, 49.84282985329628, 48.04533250629902, 39.005959555506706, 56.80577762424946, 65.12633174657822, 63.03180433809757, 67.00278505682945, 68.62117901444435, 64.35122653841972, 63.249908834695816, 66.32630735635757, 69.12596672773361, 64.86148595809937, 59.95471425354481, 59.46971967816353, 58.97272914648056, 57.307662293314934, 47.03859932720661, 38.995247930288315, 35.20292982459068, 31.354129649698734, 20.82766279578209, 17.7369599416852, 19.443547166883945, 11.873904000967741, 18.02991472184658, 19.054575338959694, 13.95479679107666, 13.415595274418592, 8.379482310265303, 11.056451015174389, 9.783168788999319, 11.604357864707708, 13.320433180779219, 6.601027641445398, 8.809870015829802, 4.823462124913931, 1.2352328491397202, 0.35480186459608376, 0.06018352331011556, 0.4465223225997761, 6.076275324448943, 10.253828633576632, 25.472073778510094, 32.0707692950964, 37.59907364845276, 31.21799625456333, 21.6755872964859, 44.61979731917381, 64.10577490925789, 53.74074429273605, 40.777587890625, 55.58481954038143, 57.4209950119257, 40.50576567649841, 21.018910333514214, 1.384767412673682, 0.09516621998045594, 0.14237901312299073, 0.06287222786340863, 0.06118521858297754, 0.010358470535720699, 0.011345526945660822, 0.07420824418659322, 0.025324409070890397, 0.028877359436592087, 0.03443776360654738, 0.059602455075946636, 0.0940198615717236, 0.10575640015304089, 0.04453533954801969, 0.11497987085022032, 0.08282256007078104, 0.049078763913712464, 0.014442501778830774, 0.04527032549958676, 0.03209466238331515, 0.026663594144338276, 0.09833781034103595, 0.03615589484979864, 0.006875367862448911, 0.037475496501429006, 0.014036769644008018, 0.03865817190671805, 0.06562397044035606, 0.033547056518727913, 0.036319679420557804, 0.04519009562500287, 0.144862640008796, 0.2941413258668035, 0.20094682899070904, 0.17406779865268618, 0.2297957567498088, 0.21461856958922, 0.07183556837844662, 0.18239402765175328, 0.2011976600624621, 0.1511415804270655, 0.2200036376598291, 0.17220451816683635, 0.13347387925023213, 0.16364608600270003, 0.11665687969070859, 0.17476802982855588, 0.1533836530870758, 0.0875018753868062, 0.10958255734294653, 0.31578202557284385, 0.17578471277374774, 0.12199318123748526, 0.20535386516712606, 0.19417821953538805, 0.25229173712432384, 0.1762078853789717, 0.1009363736375235, 0.21034967678133398, 0.1624302106210962, 3.1724595045670867, 28.35708227008581, 58.935757130384445, 72.01038435101509, 71.74034804105759, 60.264705419540405, 51.24064564704895, 44.742853716015816, 29.25966303795576, 33.85808318853378, 42.68168471753597, 37.17399425804615, 58.76573525369167, 55.98316736519337, 32.77958706021309, 18.46028722822666, 2.704570423811674, 0.5577235040254891, 0.4388586088316515, 1.9347424199804664, 6.356233851984143, 15.770045835524797, 15.009882375597954, 19.216568246483803, 24.128418378531933, 23.42338901013136, 21.836008988320827, 26.991511546075344, 24.79354038834572, 22.791644409298897, 26.319329515099525, 21.40725329518318, 28.862010575830936, 26.86430387198925, 24.226770401000977, 29.115075096488, 38.901271373033524, 44.21219319105148, 52.045225873589516, 58.72867964208126, 58.29852752387524, 61.15046069025993, 66.69471278786659, 61.29156991839409, 65.18547937273979, 58.526728078722954, 61.973671317100525, 60.50800636410713, 64.3545551598072, 62.42356337606907, 63.74961622059345, 64.06905367970467, 68.08939754962921, 66.08932927250862, 66.14167526364326, 53.134137243032455, 41.43867261707783, 51.937881633639336, 52.00711011886597, 53.04718650877476, 53.16515117883682, 45.465723127126694, 61.39883816242218, 66.7435173690319, 64.34455409646034, 67.25994765758514, 72.39103272557259, 66.1249865591526, 65.92348337173462, 68.20545852184296, 71.5725490450859, 64.61364805698395, 58.589337319135666, 56.90658241510391, 59.573005735874176, 59.29410070180893, 53.94765459001064, 39.280871003866196, 42.0140415430069, 44.10195730626583, 37.82573148608208, 42.01257862150669, 34.305186197161674, 25.056064501404762, 32.57062487304211, 23.045134507119656, 29.285845533013344, 21.81795995682478, 12.292789723724127, 11.224650889635086, 18.55509214103222, 17.68526181578636, 13.464749436825514, 17.547665499150753, 11.773568484932184, 6.524602817371488, 0.47956258873455226, 0.42189919855445623, 0.1546563027659431, 0.7226234930567443, 7.591807851567864, 14.479397591203451, 32.760880663990974, 40.14832645654678, 48.17919932305813, 36.71855449676514, 35.51290579140186, 63.50431278347969, 77.68994718790054, 63.15219707787037, 50.26859700679779, 63.51438224315643, 68.03651198744774, 51.73985905945301, 29.60994154214859, 2.892499789595604, 0.21592341363430023, 0.25618750776629895, 0.28650700114667416, 0.1752581589971669, 0.08068857379839756, 0.16515939933015034, 0.3402489423751831, 0.12188313557999209, 0.12273159591131844, 0.15849114308366552, 0.26220582076348364, 0.15919981990009546, 0.23755091795464978, 0.2105609216960147, 0.22765204834286124, 0.18437581427861005, 0.1475488138385117, 0.1073117858322803, 0.17185839533340186, 0.1325696613639593, 0.2339852842851542, 0.28250765637494624, 0.20117713225772604, 0.0926151244493667, 0.2543709083693102, 0.12014383828500286, 0.1107623717689421, 0.1985040499130264, 0.130898151837755, 0.19398491975152865, 0.11003160121617839], [0.061804889628547244, 0.020556240124278702, 0.006045246927897097, 0.06995215342612937, 0.036283369845477864, 0.03376427572220564, 0.021401466547104064, 0.13339820987312123, 0.06472950437455438, 0.06045564288797323, 0.07572553542559035, 0.029317248918232508, 0.03809969093708787, 0.04599187115672976, 0.05668760328262579, 0.014444493517657975, 0.04126924781303387, 0.04893653131148312, 0.04422057987540029, 0.04090007016202435, 0.08886842158972286, 0.035511202295310795, 0.04319628620578442, 0.06531381208333187, 0.06744042140780948, 0.010079078838316491, 0.0648206401092466, 0.08136308213579468, 0.09471066005062312, 7.07630661316216, 24.302194453775883, 41.4848667383194, 50.21667659282684, 47.04487279057503, 35.79459227621555, 31.746308505535126, 35.13291098177433, 19.441662468016148, 23.512822911143303, 18.776656351983547, 30.191325545310974, 47.6537711173296, 35.514003932476044, 13.284308519214392, 4.3484230153262615, 0.2301574795274064, 0.09320134689914994, 0.48564606229774654, 2.082106349989772, 2.952195298857987, 8.748696148395538, 6.3050230499356985, 14.038120619952679, 10.517117455601692, 5.6277260184288025, 16.050420440733433, 19.290519878268242, 15.974223129451275, 8.792850729078054, 16.391404643654823, 16.663048267364502, 20.073559060692787, 16.175730116665363, 26.944033093750477, 35.10806791484356, 49.61263820528984, 55.75711369514465, 64.7932568192482, 64.92818757891655, 64.71622735261917, 67.07388684153557, 67.00595408678055, 64.19969066977501, 65.08895695209503, 62.728219628334045, 61.874200254678726, 61.586646884679794, 67.31816813349724, 64.86737564206123, 66.88487738370895, 67.82606407999992, 63.90345856547356, 64.54565450549126, 56.276488825678825, 42.61668160557747, 25.53611934185028, 33.3414401113987, 42.30993166565895, 46.635551154613495, 35.95638379454613, 32.140997126698494, 49.95450586080551, 58.8612887263298, 60.47660864889622, 67.45610073208809, 66.0275749862194, 62.41680733859539, 56.601572781801224, 59.575122222304344, 63.46972703933716, 61.7465765029192, 59.42616641521454, 60.42530000209808, 63.219947442412376, 59.6122994273901, 56.17968142032623, 59.87905651330948, 43.161443173885345, 45.93872554600239, 41.91959761083126, 32.83078171312809, 35.45877769589424, 14.5087880641222, 20.05522694438696, 16.852390207350254, 11.450761556625366, 6.081056892871857, 9.07602483406663, 11.958940587937832, 7.4043002631515265, 11.029677651822567, 5.268971119076014, 6.893212962895632, 6.613487647846341, 2.88055750541389, 3.3050541020929813, 0.14258984243497252, 0.11303329170914367, 0.177344425173942, 0.5938935850281268, 4.780553402379155, 11.08917960897088, 30.622125528752804, 48.035939410328865, 44.18173782527447, 59.86972041428089, 92.23109811544418, 77.81162425875664, 34.692674204707146, 34.728646874427795, 43.662799671292305, 60.115590021014214, 45.40815621614456, 29.055120013654232, 3.227923703379929, 0.20191224437439814, 0.10666858870536089, 0.02441218155581737, 0.05114839856105391, 0.03916207162546925, 0.027060552238253877, 0.05699982481019106, 0.05866325976967346, 0.029766554398520384, 0.14858635113341734, 0.022479944418591913, 0.022226319160836283, 0.024575450333941262, 0.017966007435461506, 0.02338537757168524, 0.018416049497318454, 0.021449852720252238, 0.07698047746089287, 0.12709605507552624, 0.02975868763314793, 0.03836871575913392, 0.028918140451423824, 0.0508481812721584, 0.0412286078062607, 0.0895397164276801, 0.06581635738257319, 0.0430427395622246, 0.0168818762540468, 0.014747997593076434, 0.04490958606766071, 0.028062805977242533, 0.05257371172774583, 0.06323700086795725, 0.045944073135615326, 0.037580796124530025, 0.029674199686269276, 0.08362622436834499, 0.028158897403045557, 0.013489492321241414, 0.06890447839396074, 0.04250552112353034, 0.025844936608336866, 0.03201866275048815, 0.07650175510207191, 0.03655413500382565, 0.030406567711906973, 0.031598625719198026, 0.05896452348679304, 0.015537888557446422, 0.027327083444106393, 0.045057362513034604, 0.04409013628901448, 0.032812645731610246, 0.040268773373099975, 0.06631337368162349, 0.01716040242172312, 0.029350263357628137, 0.019507746874296572, 0.018960928755404893, 0.039054029766703025, 8.297829441726208, 30.87392281740904, 51.32339000701904, 60.863382294774055, 55.96746280789375, 44.11747947335243, 38.0349862575531, 44.0244110673666, 22.613988742232323, 31.550924889743328, 22.469651587307453, 24.50569063425064, 42.95270897448063, 36.16248473525047, 15.985088646411896, 4.537204960361123, 0.46538171998690814, 0.18999670719495043, 0.9964803792536259, 4.378714039921761, 7.469762675464153, 9.267772044986486, 11.782825738191605, 12.82922213897109, 15.278936438262463, 17.16120343655348, 12.210416793823242, 20.022639892995358, 21.169851534068584, 12.773825861513615, 11.358071230351925, 11.705080009996891, 14.947109743952751, 17.459242343902588, 27.140583246946335, 35.78232653439045, 47.080602273344994, 55.654325410723686, 64.96246933937073, 64.09226283431053, 64.10054638981819, 65.94903320074081, 66.55043452978134, 65.06348311901093, 65.41921243071556, 62.32149325311184, 60.279300436377525, 61.63847990334034, 66.80486887693405, 65.97242474555969, 65.52999928593636, 68.02768886089325, 63.134752213954926, 65.5784922838211, 57.90710672736168, 49.27419796586037, 33.934592083096504, 41.950087174773216, 48.66973020136356, 52.345527559518814, 45.89136488735676, 40.41045539081097, 55.641615092754364, 62.2843312472105, 62.55888171494007, 67.93371230363846, 67.36388728022575, 64.75845068693161, 60.24203583598137, 61.59210339188576, 65.88186040520668, 64.1597168147564, 60.65569303929806, 60.38892835378647, 63.19221273064613, 58.233345821499825, 58.801685124635696, 54.297026842832565, 43.44606690108776, 42.321152463555336, 34.6561885625124, 25.091098621487617, 26.188439838588238, 13.382018376141787, 12.718699369579554, 13.769397139549255, 11.195586249232292, 9.816216565668583, 14.512443467974663, 12.851162161678076, 8.727709874510765, 11.347298808395863, 15.709061957895756, 11.164782252162695, 11.472117360681295, 6.604641247540712, 4.14334611967206, 1.031937226653099, 0.3376477147685364, 0.12237721297424287, 0.8883494033943862, 4.840094782412052, 11.34038032963872, 26.745850928127766, 42.58996523916721, 31.46863840520382, 45.347686260938644, 92.27867916226387, 84.94025453925133, 42.40853637456894, 39.376226887106895, 52.61569686233997, 65.54021313786507, 53.07073764503002, 34.20987211167812, 4.632894275709987, 0.2870736754266545, 0.07271280177519657, 0.05329456347681116, 0.0368759005505126, 0.02295642734679859, 0.01834043207054492, 0.04259595923940651, 0.004795342219949816, 0.040385631946264766, 0.041000697965500876, 0.09560159349348396, 0.04196544912701938, 0.043159572160220705, 0.06044436966476496, 0.08135448806569912, 0.04727373830974102, 0.024125332201947458, 0.03073279542149976, 0.048359945649281144, 0.03286641804152168, 0.1591539997025393, 0.04287611627660226, 0.06282603659201413, 0.010118470181623707, 0.06011154982843436, 0.011414186737965792, 0.017255677485081833, 0.03246345411753282, 0.014166102791932644, 0.03573641071852762, 0.07375240224064328, 0.11539679457200691, 0.11515125501318835, 0.10153727576835081, 0.10449178051203489, 0.10216483584372327, 0.1564656142727472, 0.1515480101807043, 0.2670277620200068, 0.2027467152220197, 0.20044543402036652, 0.13962803495815024, 0.06325348396785557, 0.13818933715811, 0.1517032229457982, 0.15024730731965974, 0.15471531834919006, 0.14702329906867817, 0.10891367448493838, 0.14492364454781637, 0.12811379187041894, 0.24984101706650108, 0.16124710848089308, 0.14980222651502118, 0.1435810251859948, 0.16051299084210768, 0.22679445217363536, 0.1930263766553253, 0.14416839054320008, 0.24188955780118704, 13.378186281770468, 41.60600043833256, 65.61121612787247, 71.70823976397514, 67.5710141658783, 53.38912256062031, 49.65570889413357, 50.77484764158726, 33.11498746275902, 38.392026498913765, 31.13780915737152, 45.5935824662447, 63.048778027296066, 44.48916032910347, 17.616721093654633, 5.721333045512438, 0.7302733731921762, 0.35508002154529095, 1.1967112286947668, 4.3386694137007, 9.17813865467906, 21.994741670787334, 17.903123125433922, 22.48432070016861, 22.870353385806084, 15.431066025048494, 26.225193366408348, 30.072361528873444, 27.33027096837759, 20.608294866979122, 29.30847141891718, 28.49455699324608, 29.734457060694695, 22.78011202812195, 31.76860000938177, 40.938300266861916, 53.935909420251846, 58.22467848658562, 66.65334060788155, 66.23554542660713, 65.93096137046814, 65.48885509371758, 67.29679808020592, 64.50310438871384, 66.85992792248726, 63.05931106209755, 61.62271074950695, 61.33048743009567, 67.74982497096062, 67.3711296916008, 69.69565495848656, 69.0528130531311, 65.93951851129532, 66.19788184762001, 63.13203155994415, 55.21959833800793, 39.85506199300289, 48.01956228911877, 53.16378325223923, 57.70976431667805, 52.207013592123985, 47.89644509553909, 57.783362567424774, 63.74336555600166, 63.60724925994873, 70.23415446281433, 71.24515861272812, 67.84488067030907, 62.39789575338364, 65.70792853832245, 68.79387974739075, 65.27611970901489, 60.49029931426048, 60.960615277290344, 62.958848252892494, 59.70323234796524, 58.98323938250542, 61.19667001068592, 45.82467086613178, 51.65918938815594, 44.7900053858757, 38.63014072179794, 42.061083018779755, 24.18873254209757, 28.2225276902318, 26.110979095101357, 21.232778057456017, 14.758347272872925, 17.429619133472443, 23.247707337141037, 15.185547899454832, 19.018515273928642, 16.9561455398798, 11.190751008689404, 14.470319878309965, 8.459727354347706, 7.519513880833983, 0.9724978473968804, 0.42422731581609696, 0.2651324652833864, 1.0779375582933426, 7.1040114015340805, 15.805603377521038, 35.12014366686344, 58.42870473861694, 57.882913425564766, 71.96244612336159, 96.1634387075901, 82.16261878609657, 46.69980950653553, 50.55336892604828, 60.349566265940666, 73.90781253576279, 62.95481286942959, 43.38219612836838, 9.212049935013056, 0.733116629999131, 0.31671282718889415, 0.10739247212768532, 0.10317806780221872, 0.15182904666289687, 0.12650327204028144, 0.19123376347124577, 0.12186145744635724, 0.13995964138302952, 0.19661215221276507, 0.17229560937266797, 0.15597772639011964, 0.20615645335055888, 0.17607936024433002, 0.2735153498360887, 0.10966942572849803, 0.1000313987606205, 0.1429775997530669, 0.22174747689859942, 0.09065025136806071, 0.32309511909261346, 0.1579391336417757, 0.15238267398672178, 0.15671518369344994, 0.1610160036943853, 0.14584068674594164, 0.18683009664528072, 0.0636861337989103, 0.13241009961348027, 0.1322093783528544, 0.10551211482379586], [0.024436559251626022, 0.054063142742961645, 0.010741703536041314, 0.03745237489056308, 0.07486166068702005, 0.07266816159244627, 0.03183590517437551, 0.03507756540784612, 0.0562409120175289, 0.030234363475756254, 0.01700421744317282, 0.016466112138004974, 0.025474616049905308, 0.058590451371856034, 0.02270414166559931, 0.014580672977899667, 0.03604425728553906, 0.01891467811219627, 0.027731472291634418, 0.033194488132721744, 0.0599911215249449, 0.05554897063120734, 0.09134077525231987, 0.045686406883760355, 0.031445721033378504, 0.03872287234116811, 0.027870958947460167, 0.07604757556691766, 0.9413160081021488, 12.645621690899134, 27.536001428961754, 45.268555507063866, 52.0477831363678, 45.48431172966957, 39.290286898612976, 34.94047410786152, 21.649744883179665, 22.964474335312843, 23.950158543884754, 40.75811393558979, 70.93697234988213, 36.04730911552906, 16.558893956243992, 9.202073570340872, 2.006398024968803, 0.14431134302867576, 0.2000924982712604, 0.8955414674710482, 4.167589768767357, 11.53145782649517, 4.343664245679975, 9.140761960297823, 12.05181235447526, 15.27983034029603, 25.86775604635477, 8.914152570068836, 20.212705694139004, 29.941606745123863, 13.513053394854069, 11.914577018469572, 18.992108590900898, 25.373092889785767, 27.71170400083065, 40.13438880443573, 47.546476274728775, 58.33538934588432, 64.28090751171112, 66.27146869897842, 64.76557910442352, 62.46996268630028, 63.76407444477081, 68.30879777669907, 65.21358266472816, 68.66985440254211, 61.50259539484978, 63.57749305665493, 64.79630425572395, 64.94521826505661, 64.12517666816711, 64.1925622522831, 66.95705831050873, 64.7205439209938, 61.612869277596474, 52.67585523426533, 47.491759210824966, 28.737799040973186, 28.079121485352516, 40.42939357459545, 49.50710266828537, 33.306725174188614, 36.31063498556614, 50.007220432162285, 54.90961477160454, 59.36965964734554, 64.22302141785622, 63.319452702999115, 63.360372707247734, 56.04635797441006, 61.23523414134979, 63.54779005050659, 63.63776542246342, 59.21768680214882, 58.543690368533134, 58.668536469340324, 64.66937586665154, 56.899013221263885, 59.549200013279915, 61.511030942201614, 54.436946734786034, 41.993518844246864, 34.83002923429012, 37.64328807592392, 27.186570279300213, 23.057440146803856, 25.242378003895283, 6.4546694699674845, 10.971042048186064, 11.061414498835802, 11.263026930391788, 7.414433844387531, 7.607043609023094, 16.91250868141651, 8.797012455761433, 11.260592211037874, 8.855047691613436, 3.6021328484639525, 1.1715642968192697, 0.18871614622185007, 0.07429855613736436, 0.09632132831029594, 0.5399639694951475, 3.4072479559108615, 16.766064539551735, 34.93098981678486, 53.12150292098522, 34.91166025400162, 33.55278477072716, 25.048179924488068, 24.626049175858498, 32.733119353652, 44.82227325439453, 52.07592062652111, 55.30479356646538, 29.791303910315037, 11.79060012102127, 1.035779770463705, 0.06107530651206616, 0.04756329093652312, 0.03978001346695237, 0.11102901058620773, 0.07559561505331658, 0.028719252295559272, 0.03832987174973823, 0.02183656361012254, 0.03651123515737709, 0.05615919042611495, 0.06551989165018313, 0.028511708842415828, 0.042478532923269086, 0.02832318663422484, 0.042284108785679564, 0.04286055715056136, 0.056967975542647764, 0.03536528121912852, 0.07261349499458447, 0.032452132654725574, 0.05396787324571051, 0.04059835002408363, 0.04633158183423802, 0.03564319325960241, 0.020081764705537353, 0.0289165299909655, 0.019056226083193906, 0.026509229282964952, 0.010379939940321492, 0.012079536045348505, 0.037570398635580204, 0.02457743186823791, 0.04862909292569384, 0.06975801501539536, 0.04411713933222927, 0.09811874318984337, 0.07347236023633741, 0.02541042398661375, 0.02610871073557064, 0.01997971939999843, 0.025254782631236594, 0.05931621613854077, 0.04523914416495245, 0.020790179914911278, 0.05617741386231501, 0.01696980034466833, 0.02867810948373517, 0.04233421859680675, 0.032705553821870126, 0.030974791225162335, 0.015347557364293607, 0.09854020143393427, 0.038621728745056316, 0.023269292687473353, 0.012872973547928268, 0.07727793024969287, 0.017421586453565396, 0.04698962191469036, 0.7979216182138771, 14.836416933685541, 36.0978540033102, 55.391451716423035, 62.452039048075676, 54.733923599123955, 44.155230447649956, 44.091781452298164, 32.301568910479546, 24.86926842480898, 29.86490786075592, 42.69518919289112, 59.400498792529106, 39.04287077486515, 18.095683492720127, 8.750203717499971, 1.9209122308529913, 0.2116663655033335, 0.7516257930546999, 2.9665637528523803, 7.542457524687052, 9.297343008220196, 11.71198708936572, 13.29710053279996, 13.309355825185776, 12.701719030737877, 18.247194662690163, 17.811519540846348, 18.427029512822628, 24.045341536402702, 16.32593795657158, 10.200902223587036, 21.907790936529636, 23.738703690469265, 29.18075267225504, 37.841903418302536, 48.573200181126595, 58.01579609513283, 65.73117569088936, 66.26848965883255, 65.894133746624, 61.948315277695656, 63.62573906779289, 68.65677550435066, 63.98367986083031, 67.06689521670341, 62.48983941972256, 62.506695315241814, 65.49795940518379, 67.47478812932968, 64.79527831077576, 65.8323186635971, 67.99457743763924, 65.500368475914, 60.93823827803135, 57.05155223608017, 57.0839910954237, 35.41071407496929, 36.85417681932449, 47.3072525113821, 53.69094796478748, 41.418545097112656, 43.72216008603573, 54.045997112989426, 58.66625279188156, 61.587205454707146, 67.43766412138939, 64.55712988972664, 63.865870982408524, 58.807232826948166, 62.760711684823036, 66.1902442574501, 64.76364120841026, 60.85842736065388, 60.85577130317688, 59.057506397366524, 63.18240165710449, 57.68658176064491, 58.94721731543541, 58.97455304861069, 52.223922684788704, 41.85371674597263, 34.84285354614258, 34.33670170605183, 24.84406627714634, 16.424926444888115, 16.66278038173914, 13.979889694601297, 13.656682837754488, 14.421112518757582, 19.341564439237118, 14.390474762767553, 21.245537772774696, 16.92743808031082, 16.29686951637268, 13.23121776804328, 10.904726106673479, 6.973889283835888, 3.7381987972185016, 1.0569658898748457, 0.3587410954060033, 0.010140876547666267, 0.6046621478162706, 3.5974804731085896, 18.05069960653782, 35.40228992700577, 53.22608470916748, 47.2624035179615, 48.607664331793785, 38.302381709218025, 31.986869797110558, 40.22312544286251, 49.01605501770973, 59.72085200250149, 61.487270817160606, 35.51160246133804, 14.83557052910328, 1.2748287431895733, 0.03483336171484552, 0.07634877620148472, 0.02112292368110502, 0.04447232378879562, 0.02931955699750688, 0.013353950180317042, 0.03631725630839355, 0.03408390759432223, 0.05194228135223966, 0.021211868224781938, 0.026507783950364683, 0.08986882181488909, 0.12142488165409304, 0.04156949849857483, 0.05663664000167046, 0.024815236392896622, 0.08099111772025935, 0.04122952806937974, 0.015766548895044252, 0.036770411679754034, 0.04334703495260328, 0.0402602906251559, 0.06255193176912144, 0.07445587660185993, 0.06460302014602348, 0.013898381366743706, 0.0297858057092526, 0.031063784008438233, 0.06216158435563557, 0.006960132259337115, 0.13962856930447742, 0.13069590175291523, 0.24266375141451135, 0.14260993979405612, 0.17490007274318486, 0.1518366314121522, 0.10555537461186759, 0.16006801393814385, 0.17908480600453913, 0.11558140380657278, 0.15913924580672756, 0.16453688585897908, 0.16094107646495104, 0.09057789196958765, 0.21656957193044946, 0.14787157386308536, 0.1302922031027265, 0.11599498044233769, 0.056992317986441776, 0.13488949625752866, 0.17821364337578416, 0.18630213278811425, 0.17433148372219875, 0.08243626478360966, 0.14982894383138046, 0.20511517563136294, 0.1831314997980371, 0.18453084892826155, 2.2340929694473743, 21.767578460276127, 47.709840908646584, 69.92569461464882, 71.5756344795227, 65.13776153326035, 58.981214091181755, 53.465319871902466, 37.85128131508827, 35.5350586026907, 36.56561650335789, 55.719419717788696, 85.57622641324997, 46.283530443906784, 23.286816738545895, 11.707918457686901, 3.0784874595701694, 0.3840814606519416, 0.6558851210866123, 2.4500320572406054, 8.707513008266687, 16.96838278323412, 17.518760450184345, 21.088307909667492, 24.482815861701965, 28.710185922682285, 35.00269956886768, 19.368126913905144, 33.911515921354294, 44.927280619740486, 26.857901215553284, 17.630520053207874, 26.183439306914806, 29.05978236347437, 32.0485632866621, 43.82552973926067, 52.22487263381481, 61.29254646599293, 67.98670426011086, 67.96604096889496, 65.43851539492607, 62.17711240053177, 64.9375730752945, 68.07658463716507, 64.3931382894516, 66.72356083989143, 63.290889635682106, 63.494627103209496, 67.39037945866585, 69.85603675246239, 68.31799328327179, 70.66469416022301, 70.10647371411324, 68.49948674440384, 61.85566104948521, 60.27307257056236, 62.62299187481403, 41.826878786087036, 42.176205441355705, 51.212591752409935, 58.548588305711746, 47.482521906495094, 49.62952829897404, 57.563597559928894, 61.73381678760052, 64.72965583205223, 68.62298011779785, 68.60563784837723, 67.78447911143303, 60.62483109533787, 66.15536972880363, 67.98206090927124, 67.88793995976448, 62.311739176511765, 59.36856530606747, 60.316044464707375, 65.89116990566254, 62.17595346271992, 60.23655652999878, 63.42116944491863, 54.64330606162548, 46.68764255940914, 38.48515570163727, 41.24722748994827, 32.334410548210144, 30.221332535147667, 37.11380548775196, 15.037532541900873, 18.85401640087366, 18.96160002797842, 21.258683167397976, 16.173828318715096, 22.653267234563828, 32.30660364031792, 18.685978017747402, 19.767713472247124, 17.52144120633602, 11.64753494784236, 4.009013352915645, 0.603036725660786, 0.30551752948667854, 0.1802211083122529, 0.674189570127055, 5.0323202926665545, 21.17272987961769, 43.966095596551895, 63.490751311182976, 45.811888352036476, 43.85248929262161, 36.47254429757595, 38.24504278600216, 46.195713356137276, 60.33293455839157, 67.94033914804459, 72.15370506048203, 45.093004927039146, 22.59426400065422, 2.2108755027875304, 0.2304837721749209, 0.15010747185442597, 0.1376338247791864, 0.16413437464507297, 0.17103930178564042, 0.10646434224327095, 0.10880193673074245, 0.08129481197101995, 0.1391374901868403, 0.1514035733998753, 0.13984446006361395, 0.20269654603907838, 0.232252087444067, 0.1485812896862626, 0.24470814561937004, 0.14132452517515048, 0.20884166238829494, 0.15448511898284778, 0.17968097323318943, 0.10348409981816076, 0.19146958831697702, 0.12872020073700696, 0.19910101866116747, 0.34125146514270455, 0.08914206628105603, 0.16182668128749356, 0.09706427750643343, 0.18785195978125557, 0.08775007183430716, 0.09357196060591377], [0.07185041133197956, 0.041557442309567705, 0.05527121073100716, 0.02609575654787477, 0.021918136772001162, 0.010176092382607749, 0.025258454406866804, 0.01623835072678048, 0.06447373059927486, 0.04138486699957866, 0.02594449200842064, 0.024866067942639347, 0.032278711296385154, 0.0433177275408525, 0.04400102290674113, 0.026100754912476987, 0.031190871231956407, 0.03811182876233943, 0.03688527758640703, 0.03287814026407432, 0.09722112299641594, 0.02297478808031883, 0.03215048673155252, 0.01621743886062177, 0.10628685020492412, 0.02528794178942917, 0.006431728679672233, 0.06622178523684852, 5.3592870477586985, 17.15142846107483, 42.36222445964813, 48.89768376946449, 49.81759540736675, 45.21807141602039, 36.03529796004295, 23.23755618184805, 18.251340240240097, 19.181053452193737, 34.05343450605869, 54.5333893597126, 42.63846963644028, 22.715760581195354, 15.55038532242179, 3.5800439212471247, 0.032087860599858686, 0.3244296193588525, 0.5346900306176394, 3.1474991189315915, 9.513716697692871, 8.315449096262455, 6.779392920434475, 12.626006193459034, 10.197161324322224, 9.294488411396742, 18.499820306897163, 12.366624511778355, 15.459411554038525, 18.644261956214905, 17.846777848899364, 20.257940366864204, 31.249418668448925, 38.118589371442795, 41.502847373485565, 53.285498321056366, 64.01519536972046, 64.38899651169777, 64.8667524755001, 62.690145671367645, 65.09737730026245, 64.0714019536972, 66.87860772013664, 66.12671926617622, 61.15494824945927, 65.07507249712944, 63.428024277091026, 61.90614894032478, 63.31516653299332, 63.87616842985153, 61.15455687046051, 60.645916163921356, 65.37081822752953, 66.68247744441032, 60.438154712319374, 51.56493544578552, 49.066573306918144, 38.146270886063576, 27.147812359035015, 37.792217284440994, 56.01151384413242, 38.1329981982708, 40.06256885826588, 48.14046800136566, 54.93473142385483, 59.57109443843365, 63.64696092903614, 63.60409542918205, 63.13664071261883, 54.870716258883476, 54.74169418215752, 56.324157267808914, 63.123535215854645, 61.45015440881252, 62.80231565237045, 62.06151120364666, 57.2756490111351, 58.29196147620678, 57.92594611644745, 58.482574447989464, 63.66343304514885, 57.4860855191946, 48.2289082556963, 50.47848254442215, 36.84601865708828, 27.655943892896175, 20.276456773281097, 15.147931817919016, 11.360694989562035, 17.470824122428894, 15.726847853511572, 8.67860795930028, 17.795072123408318, 15.894001834094524, 14.706826787441969, 14.280174281448126, 8.674552626907825, 4.819274274632335, 3.9258811762556434, 0.9182166319806129, 0.13174578838516027, 0.016850735737534706, 0.03894166489772033, 0.6747499213088304, 5.943931275978684, 16.985763050615788, 21.56032618135214, 27.87148542702198, 24.91865437477827, 23.263168707489967, 23.45825593918562, 20.398245938122272, 34.903562888503075, 41.19559966027737, 58.7065876275301, 38.90388943254948, 22.683449015021324, 4.457618705928326, 0.02916998269938631, 0.07351650318014435, 0.05624664881906938, 0.05786107234598603, 0.05054972287325654, 0.019270244774816092, 0.032842238870216534, 0.045549454662250355, 0.0720063439803198, 0.06918332554050721, 0.014874675707687857, 0.03735662299732212, 0.0471511318028206, 0.06659585735178553, 0.027547430800041184, 0.08846355776768178, 0.04026133334264159, 0.021089567853778135, 0.047873753574094735, 0.1178068968874868, 0.07266641754540615, 0.045353653840720654, 0.04123522034205962, 0.021750274099758826, 0.03558326483471319, 0.04409310859045945, 0.02006814072956331, 0.00784181622293545, 0.0243980770392227, 0.039798633952159435, 0.005916630416322732, 0.01928956658957759, 0.016826591818244196, 0.0932981600635685, 0.041749799565877765, 0.02743242759606801, 0.0073800482277874835, 0.02543462727771839, 0.11331766043440439, 0.04195795343548525, 0.04828113327675965, 0.02364615342230536, 0.10218993527814746, 0.02696907140489202, 0.029018254317634273, 0.046285668868222274, 0.03182662090694066, 0.0271966584114125, 0.028646911450778134, 0.05329292704118416, 0.045097861511749215, 0.011381281765352469, 0.053803172122570686, 0.041248274719691835, 0.054506613087141886, 0.07984310432220809, 0.051568198105087504, 0.0719019460666459, 5.713569112122059, 21.86738010495901, 48.59863601624966, 59.32300195097923, 58.93479958176613, 53.894978016614914, 45.848427191376686, 32.453864738345146, 24.79447703808546, 26.059286668896675, 30.074941590428352, 48.75116363167763, 53.07600036263466, 25.099078193306923, 12.361104357987642, 3.624208001419902, 0.22582240198971704, 0.5531455809250474, 2.4971675779670477, 6.601003892719746, 8.33328913897276, 14.044582173228264, 14.57667427137494, 15.314625073224306, 14.49538428336382, 18.513421677052975, 20.48606112599373, 22.270316183567047, 21.725522316992283, 15.660591758787632, 15.872767623513937, 19.644983857870102, 28.223458640277386, 32.57108084857464, 40.752475038170815, 53.26197378337383, 62.66499862074852, 64.17852580547333, 65.70869609713554, 63.87055993080139, 64.71132561564445, 63.19437861442566, 66.60894379019737, 64.244444668293, 60.87037391960621, 66.00490540266037, 64.12054851651192, 63.73483881354332, 64.83540415763855, 64.93835583329201, 64.08436685800552, 61.61063499748707, 65.95858588814735, 67.78229802846909, 61.40954218804836, 56.368432492017746, 55.64465492963791, 45.373540073633194, 35.20386457443237, 45.88235177099705, 59.652463272213936, 45.56035704910755, 49.04788210988045, 53.24768275022507, 56.96696117520332, 61.55900716781616, 65.84019184112549, 64.23159375786781, 64.47221964597702, 56.874462738633156, 59.22184377908707, 57.30851724743843, 66.51380449533463, 63.95103961229324, 65.16124427318573, 62.508652210235596, 59.909967854619026, 60.00402420759201, 58.95691819489002, 60.868158638477325, 63.26654054224491, 58.08700807392597, 49.61289279162884, 44.566417783498764, 34.82912868261337, 25.43169144541025, 20.288228541612625, 16.680989004671574, 14.539579711854458, 18.271686248481274, 15.220389179885387, 14.373003300279379, 20.269639939069748, 19.95422076433897, 18.241065591573715, 12.036718614399433, 9.565676059573889, 7.5390880554914474, 5.5948801059275866, 3.906270428560674, 0.651079744566232, 0.1848439165041782, 0.07447566225891933, 0.6684489094186574, 5.864815721288323, 18.005008958280087, 26.75261076539755, 30.36818515509367, 32.12781943380833, 25.724475234746933, 28.27508457005024, 28.33986159414053, 41.67731121182442, 46.24259144067764, 64.27432626485825, 44.018308594822884, 26.052382439374924, 4.89352704025805, 0.04869719239650294, 0.02026603811827954, 0.02823678765707882, 0.018298701106687076, 0.09129226105869748, 0.039042244461597875, 0.06307996984105557, 0.06075766359572299, 0.015100256132427603, 0.11756106046959758, 0.03299133633845486, 0.052665923576569185, 0.04158833049586974, 0.053025965389679186, 0.03726035531144589, 0.08801406118436716, 0.03993663631263189, 0.021048619855719153, 0.05470916745252907, 0.04509527141635772, 0.03436399783822708, 0.046600933201261796, 0.043065790669061244, 0.07958556423545815, 0.05080228685983457, 0.08771734312176704, 0.03295057758805342, 0.043760440894402564, 0.03534145827870816, 0.00302758727229957, 0.14692563243443146, 0.07017125768470578, 0.12236847789608873, 0.2155457198387012, 0.14262580691138282, 0.12821453099604696, 0.12332238999078982, 0.15137790993321687, 0.1726476990734227, 0.09871224610833451, 0.11532225325936452, 0.08831282015307806, 0.18933626997750252, 0.11285169559414499, 0.11324100400088355, 0.1318339555291459, 0.1393654927960597, 0.16575791174545884, 0.14577782683772966, 0.16751545103034005, 0.1752118786680512, 0.1591216865926981, 0.12044290895573795, 0.1662444934481755, 0.2670282666804269, 0.23979492019861937, 0.09302313497755677, 0.4449431214015931, 8.280757907778025, 28.664238788187504, 61.85221843421459, 69.90489453077316, 67.93667614459991, 63.94205689430237, 52.55427695810795, 38.25827747583389, 31.0454361140728, 34.51364301145077, 49.146365225315094, 68.74424681067467, 56.397835314273834, 31.630500219762325, 19.071564227342606, 4.239183627068996, 0.48954607802443206, 0.6033356627449393, 2.414484964683652, 7.636728091165423, 15.65153019502759, 20.7354873418808, 17.988823726773262, 25.67856039851904, 21.600172743201256, 21.39400340616703, 27.721260488033295, 20.95756072551012, 27.98453126102686, 25.707839727401733, 23.49714495241642, 30.683395341038704, 36.545986756682396, 44.636322632431984, 45.9961898624897, 56.863640919327736, 67.42141619324684, 67.29620531201363, 66.35595336556435, 63.02465692162514, 64.10002961754799, 64.16156351566315, 66.78404599428177, 64.1490925848484, 60.39738290011883, 65.54740995168686, 64.11829143762589, 65.74039399623871, 66.95759788155556, 68.60768213868141, 65.90102657675743, 65.32769054174423, 69.88573595881462, 69.40577611327171, 62.33456455171108, 58.85513685643673, 60.323180481791496, 52.6383588463068, 43.42940479516983, 49.67054709792137, 63.74667897820473, 54.847940281033516, 54.18037690222263, 56.729625910520554, 59.80953924357891, 63.01864184439182, 67.91321620345116, 69.19268354773521, 67.17850282788277, 58.98094430565834, 58.93651708960533, 58.211238607764244, 67.2664225101471, 65.16479328274727, 66.84316322207451, 64.12125527858734, 60.001223757863045, 62.82238617539406, 60.568172335624695, 61.56792908906937, 67.23550736904144, 59.08036217093468, 51.776633486151695, 52.85046726465225, 40.34444533288479, 32.96476252377033, 25.335404612123966, 22.908127158880234, 22.475932650268078, 28.719575218856335, 22.9646947234869, 14.874003566801548, 23.974349945783615, 24.44426503032446, 24.712380543351173, 25.099895149469376, 15.550966691225767, 10.794551968574524, 8.051351867616177, 4.202064843848348, 0.5915597977582365, 0.2316721880924888, 0.4006917349761352, 1.0817137244157493, 7.573066307231784, 21.59758698195219, 30.99444855004549, 37.834132835268974, 37.92986489832401, 34.641813933849335, 35.58457374572754, 32.15778462588787, 48.874231427907944, 54.15835328400135, 76.32995456457138, 53.691867515444756, 32.24581070244312, 8.096962720155716, 0.18093595979735255, 0.13517730112653226, 0.14908182376530021, 0.14584482792997733, 0.2844402682967484, 0.10267079502227716, 0.2192909680888988, 0.14605078875320032, 0.1035782189865131, 0.11273717478616163, 0.14294212509412318, 0.1047865096188616, 0.11188371237949468, 0.14985160902142525, 0.06903317422256805, 0.21841670328285545, 0.09754519662237726, 0.10042107081972063, 0.17881179956020787, 0.21180618612561375, 0.1363540653255768, 0.15710936801042408, 0.17331402894342318, 0.16886684257769957, 0.09135914340731688, 0.1691202266374603, 0.0749054028710816, 0.2159950605710037, 0.10880854184506461, 0.0955842123948969], [0.07256443161168136, 0.029844231285096612, 0.04773755092173815, 0.024981568385555875, 0.020093793064006604, 0.08241993011324666, 0.04871457349509001, 0.05707792843168136, 0.08243697724537924, 0.03601193304348271, 0.040164572128560394, 0.0475974223081721, 0.04431222769198939, 0.0468698578333715, 0.10307925083907321, 0.00859564252095879, 0.02823058886860963, 0.014470310979959322, 0.019744046694540884, 0.062415628926828504, 0.025692826020531356, 0.044402257626643404, 0.023773927132424433, 0.05076243352959864, 0.00961309822741896, 0.06448800209909678, 0.06344884692225605, 0.5254135408904403, 6.15734064951539, 29.499832950532436, 48.170296400785446, 48.88248838484287, 48.93535494804382, 39.68521110713482, 26.54378157109022, 25.047218576073647, 20.064490847289562, 25.04624392837286, 45.07990323007107, 54.10226449370384, 40.618539825081825, 24.137851372361183, 5.536830145865679, 0.6962663261219859, 0.220657529134769, 0.5338214803487062, 3.3268789434805512, 7.040015235543251, 7.625076491385698, 7.6495785266160965, 13.031489085406065, 11.053657215088606, 13.511238042265177, 14.699088502675295, 17.412206567823887, 33.73671770095825, 21.509422212839127, 21.521201580762863, 30.86026445031166, 23.88920221477747, 43.77792589366436, 43.45255695283413, 54.64662328362465, 59.66527618467808, 62.11756959557533, 65.22963300347328, 62.9688873142004, 62.5692817568779, 62.9932402074337, 64.49447125196457, 62.83446952700615, 64.67287927865982, 65.46108618378639, 63.07317651808262, 60.94746418297291, 59.952730759978294, 59.032055363059044, 59.25143279135227, 58.288176879286766, 58.12241457402706, 62.343767657876015, 62.88006328046322, 62.90572710335255, 52.64267921447754, 55.87232731282711, 47.65482746064663, 33.219953030347824, 24.582271724939346, 52.53104880452156, 33.45035366714001, 41.519414484500885, 51.938626393675804, 53.293257504701614, 58.53691153228283, 58.94764669239521, 62.32405051589012, 63.20644296705723, 57.001410126686096, 52.989893183112144, 53.102074563503265, 59.66852121055126, 59.8035279661417, 59.65242147445679, 63.90616402029991, 62.47314691543579, 62.42414474487305, 56.81703262031078, 58.3128147572279, 60.02715736627579, 60.363370925188065, 60.90859606862068, 57.18778632581234, 55.369378700852394, 39.40615028142929, 32.70388372242451, 37.74710990488529, 21.418200507760048, 15.826831888407469, 23.59231274574995, 24.3104837089777, 26.255608834326267, 13.828450720757246, 19.456861652433872, 9.135478343814611, 10.34185566008091, 8.334551621228456, 5.26433109305799, 5.3769404254853725, 1.0629922477528453, 0.2328741259407252, 0.06010041761328466, 0.08916031569242477, 1.5897749620489776, 9.786461312323809, 30.363209322094917, 48.03311996161938, 53.51620674133301, 41.77031122148037, 25.206572525203228, 26.719396747648716, 31.93848319351673, 40.836530327796936, 53.55417050421238, 52.183466255664825, 31.475630030035973, 8.94150635227561, 0.35019413684494793, 0.013741384664172074, 0.04526784672634676, 0.02534480514441384, 0.05606020276900381, 0.020770333030668553, 0.06077435078623239, 0.030247364047681913, 0.025846784556051716, 0.01618629463337129, 0.07313230817089789, 0.047530870215268806, 0.024233155127149075, 0.024447880714433268, 0.03580881835659966, 0.019477617533993907, 0.005210315484873718, 0.039220656763063744, 0.07085182194714434, 0.04435448186995927, 0.0364699123747414, 0.08300402259919792, 0.03956002605264075, 0.04930168652208522, 0.03361187569680624, 0.043100163238705136, 0.019306407775729895, 0.058050572333741, 0.06816883193096146, 0.03027010716323275, 0.014120134164841147, 0.04592015000525862, 0.032561658808845095, 0.10938491599517874, 0.061573320999741554, 0.02073061328701442, 0.041769125091377646, 0.048806009799591266, 0.04805523836694192, 0.05795146964373998, 0.06298004707787186, 0.0439184107381152, 0.046835002867737785, 0.05934125991188921, 0.10151865528314374, 0.054260995602817275, 0.03440791813773103, 0.03362503397511318, 0.06475624395534396, 0.04104548286704812, 0.032714181288611144, 0.036823638511123136, 0.06112619557825383, 0.06914609199156985, 0.032313506890204735, 0.06157492403872311, 0.08821579176583327, 0.7195673882961273, 8.228086084127426, 32.29075849056244, 59.31615851819515, 59.1663021594286, 57.9837030172348, 50.43261520564556, 31.513403803110123, 29.847295805811882, 18.983589448034763, 26.309704631567, 40.7537517696619, 57.19311363995075, 41.56705252826214, 22.2980584949255, 4.926523994654417, 1.1655242834240198, 0.4230177338467911, 1.2346961279399693, 5.726714031770825, 11.441494803875685, 12.082354165613651, 9.369000513106585, 15.714431069791317, 11.825523097068071, 10.452225487679243, 13.945537637919188, 11.597841214388609, 14.416382722556591, 12.603954076766968, 19.68371517956257, 23.59790414571762, 24.00150328874588, 38.63264098763466, 42.501950562000275, 55.27776561677456, 58.75927560031414, 63.791387379169464, 65.35716935992241, 63.40353839099407, 62.89216563105583, 63.897865265607834, 63.844158947467804, 64.06790614128113, 63.8757960498333, 66.05181768536568, 64.42799001932144, 63.25649008154869, 60.503439009189606, 61.41352437436581, 60.91093674302101, 61.66148006916046, 60.148621648550034, 64.05458405613899, 66.643787920475, 62.686604261398315, 55.619705468416214, 58.955489471554756, 54.31367374956608, 38.436077535152435, 33.66725742816925, 60.52473306655884, 40.56053973734379, 52.48316377401352, 56.42134465277195, 57.02719934284687, 58.54258082807064, 63.22433240711689, 63.65872509777546, 64.28471490740776, 58.70644323527813, 57.10486337542534, 57.29362204670906, 62.69249014556408, 62.688713148236275, 63.610152304172516, 65.39140552282333, 62.59116478264332, 62.64150828123093, 58.95129829645157, 57.97219343483448, 61.88621141016483, 60.99219158291817, 62.23700478672981, 56.95641674101353, 51.9727523624897, 38.504747450351715, 30.966805033385754, 24.431615509092808, 14.485706202685833, 8.91449835151434, 14.635448567569256, 15.69248154759407, 24.820353649556637, 19.242074377834797, 13.568610213696957, 17.80141208320856, 12.788647916167974, 12.774362582713366, 6.935382625088096, 5.922624869272113, 1.6848319675773382, 0.9257398720365018, 0.07133931649150327, 0.07883562400820665, 2.0247624395415187, 10.13872331008315, 29.245353005826473, 45.12464202940464, 48.179187923669815, 37.020167112350464, 23.411062471568584, 26.810198575258255, 37.71923080086708, 46.239000633358955, 60.60819558799267, 58.450777754187584, 38.28720532357693, 11.35195355862379, 0.24911279208026826, 0.0422345258994028, 0.08375634512049146, 0.052805068844463676, 0.01069730547897052, 0.05348804137611296, 0.07531365830800496, 0.036994454931118526, 0.035582396521931514, 0.01158843837401946, 0.029720194288529456, 0.04216313871438615, 0.017335963020741474, 0.0187320392797119, 0.04455316222447436, 0.045474471771740355, 0.027301208465360105, 0.0940592547704, 0.08753415138926357, 0.030728110614290927, 0.014938292606530013, 0.05532682356715668, 0.027108828944619745, 0.013485218478308525, 0.025783703858905938, 0.08402875042520463, 0.06795218418119475, 0.03796833450905979, 0.08460797442239709, 0.06080139835830778, 0.11168699129484594, 0.14596468477975577, 0.19101707119261846, 0.17978003510506824, 0.17067358625354245, 0.2399425333715044, 0.1167533292027656, 0.13104100042255595, 0.170514736964833, 0.13307314919074997, 0.13928683998528868, 0.2008292727987282, 0.13683758937986568, 0.14244098245399073, 0.3358404367463663, 0.13759722205577418, 0.1358203127165325, 0.12672222044784576, 0.16406149574322626, 0.1337650089408271, 0.10236442161840387, 0.21283328882418573, 0.22622659045737237, 0.2711913292296231, 0.14802341727772728, 0.11204835042008199, 0.17074097326258197, 1.1595916142687201, 10.167017541825771, 42.455319464206696, 68.50758031010628, 69.74813774228096, 64.85656142234802, 56.58318556845188, 40.64580336213112, 41.382922008633614, 31.760422848165035, 39.19207736849785, 62.32021652162075, 69.7274212539196, 54.43327233195305, 30.17356149852276, 7.288183718919754, 1.3303029164671898, 0.7496841566171497, 1.6480644280090928, 8.783257193863392, 13.690092545002699, 18.23661793023348, 20.156727097928524, 26.485411003232002, 21.909206360578537, 24.78530243039131, 28.77409089356661, 26.738167740404606, 44.66328978538513, 29.394151121377945, 28.913528211414814, 34.57396477460861, 26.3554522767663, 47.705957517027855, 46.55433811247349, 57.38606348633766, 62.92822949588299, 63.451845198869705, 67.05412790179253, 63.89553979039192, 63.68999361991882, 62.20839612185955, 65.4462593793869, 63.49561125040054, 67.01506599783897, 67.24835827946663, 67.10121497511864, 64.05100464820862, 64.73325803875923, 64.2322625219822, 64.03339639306068, 62.524223774671555, 63.65188926458359, 67.69762337207794, 68.75424787402153, 64.0872623026371, 58.903094083070755, 63.21155749261379, 60.03468856215477, 47.374474704265594, 38.61850194633007, 60.95184154808521, 46.26164361834526, 55.551970303058624, 60.49390912055969, 59.58427973091602, 61.119461953639984, 65.26031255722046, 68.07934328913689, 68.61661925911903, 61.49741627275944, 58.43090862035751, 56.92615136504173, 64.36168357729912, 64.66116070747375, 64.45038601756096, 64.88510549068451, 63.23054127395153, 61.291463524103165, 58.43320369720459, 60.37791274487972, 62.17949867248535, 63.02922047674656, 65.07853791117668, 62.969825863838196, 60.20262815058231, 44.635653868317604, 36.427022740244865, 42.06557437777519, 31.275580264627934, 25.453105196356773, 32.59424440562725, 31.760850325226784, 38.652498722076416, 27.372712790966034, 30.61892420053482, 24.955240711569786, 23.465610444545746, 17.955723702907562, 12.204269673675299, 9.06594017520547, 2.6827137591317296, 0.8309275971259922, 0.15759412402985618, 0.23919005499919876, 2.539980593137443, 13.25577300041914, 37.087396904826164, 61.406490951776505, 68.34666654467583, 53.35299029946327, 35.55862493813038, 37.85897970199585, 44.98600646853447, 55.328021720051765, 68.32573726773262, 67.01005026698112, 46.22575834393501, 14.325846880674362, 0.8024429006036371, 0.24428341450402513, 0.2682494558393955, 0.16968701966106892, 0.1591275495593436, 0.15226369287120178, 0.1869697094662115, 0.10918532279902138, 0.13043463608482853, 0.2168838566285558, 0.20138837717240676, 0.1466084088315256, 0.10301956732291728, 0.21491343970410526, 0.13133120985003188, 0.17329459951724857, 0.10042720095952973, 0.12518787465523928, 0.18256400915561244, 0.15747459372505546, 0.10714733332861215, 0.17050578666385263, 0.12924242037115619, 0.08400414080824703, 0.1276120258262381, 0.19380865967832506, 0.14161976636387408, 0.11154282168718055, 0.15792515157954767, 0.17826574214268476], [0.06631205265875906, 0.030303279309009667, 0.04315908234275412, 0.11462122056400403, 0.059691045244107954, 0.030630941218987573, 0.03904659715772141, 0.03506680797727313, 0.021098694414831698, 0.010085024368891027, 0.021681759026250802, 0.03155938466079533, 0.046447074855677783, 0.04122929058212321, 0.02229289722890826, 0.03819206605840009, 0.025822052484727465, 0.036576347483787686, 0.012138495039835107, 0.04505726603383664, 0.04804416552360635, 0.058607149694580585, 0.06789057850255631, 0.013464598832797492, 0.044963733162148856, 0.016885577715584077, 0.00803146000180277, 1.0259358049370348, 17.34004084020853, 36.30969263613224, 42.754678800702095, 46.69458858668804, 39.84813876450062, 38.679089695215225, 31.50272447615862, 21.78056426346302, 27.422742806375027, 36.59173630177975, 37.71821245551109, 31.14847518503666, 22.410927638411522, 13.776914086192846, 1.1057523032650352, 0.41365815326571465, 0.07332712935749441, 1.1597893224097788, 4.444333668798208, 12.08068035542965, 6.704115159809589, 10.597523041069508, 14.978421963751316, 9.028603378683329, 10.293235369026661, 17.24132213741541, 19.888983964920044, 21.38123419135809, 22.81564202159643, 28.20819105952978, 31.865074932575226, 39.80154946446419, 51.69519245624542, 50.76495297253132, 60.43653219938278, 62.13708154857159, 67.16090977191925, 62.231844663619995, 64.34774592518806, 61.506110206246376, 64.36567336320877, 65.42096793651581, 64.67351764440536, 61.113872453570366, 65.38115367293358, 61.35710880160332, 62.14374639093876, 57.36006908118725, 56.335100680589676, 54.776165932416916, 55.24360924959183, 55.60767911374569, 62.248582765460014, 62.05416239798069, 65.00333234667778, 57.78995521366596, 55.86555227637291, 55.77727921307087, 41.6330473870039, 20.59594552963972, 47.886269241571426, 24.085752367973328, 45.606862753629684, 51.58148355782032, 55.296035036444664, 54.113610684871674, 57.47393377125263, 62.91724048554897, 62.81726025044918, 58.975339606404305, 54.11817044019699, 49.14044514298439, 56.27477511763573, 56.554204523563385, 60.079282969236374, 61.244908422231674, 60.670481845736504, 57.47092433273792, 60.61460964381695, 55.99694922566414, 61.40162721276283, 61.93100340664387, 61.624884232878685, 57.950048223137856, 59.181976318359375, 50.77949479222298, 49.46986846625805, 36.84468112885952, 24.719377867877483, 18.475364819169044, 13.039594050496817, 20.293973833322525, 20.165415331721306, 24.172986187040806, 13.581057395786047, 11.1295210942626, 7.806761842221022, 9.610887933522463, 6.471400447189808, 4.9965570867061615, 1.0573452757671475, 0.6491707032546401, 0.10998578844009899, 0.04649196365789976, 0.22116426756838337, 2.9130400624126196, 10.667036511003971, 26.931467168033123, 37.5550302118063, 33.179625794291496, 25.13359934091568, 24.259783029556274, 24.983136914670467, 38.67322281002998, 48.25269117951393, 50.35715125501156, 39.15769301354885, 10.529633034020662, 0.620725667104125, 0.049499821398057975, 0.051381213997956365, 0.09161209702142514, 0.037917794252280146, 0.06265076357522048, 0.027556087952689268, 0.05562207959883381, 0.03464246277872007, 0.04852023099374492, 0.07650671264855191, 0.029706755849474575, 0.05352298539946787, 0.05175641788810026, 0.01853644997027004, 0.019065360065724235, 0.022196909703779966, 0.02501096299965866, 0.015913707502477337, 0.03175648053002078, 0.013946375129307853, 0.02483141335687833, 0.04176354414084926, 0.03795479402469937, 0.013402471795416204, 0.013754541087109828, 0.08185376791516319, 0.024366858597204555, 0.059464285732246935, 0.04801783783477731, 0.04595592152327299, 0.05651898361975327, 0.04140788842050824, 0.08384940301766619, 0.015224752332869684, 0.06405689593520947, 0.03409961886063684, 0.016347542914445512, 0.06339306710287929, 0.05826937973324675, 0.07084009601385333, 0.033550180960446596, 0.08232553635025397, 0.021527514763874933, 0.029463444589055143, 0.017421905577066354, 0.02671607697266154, 0.017501777365396265, 0.004756444868689869, 0.04130188375711441, 0.016100693464977667, 0.13800944056129083, 0.0279769190819934, 0.025400353042641655, 0.04213914508000016, 0.0233425834812806, 0.022650681057712063, 1.1383528914302588, 18.112731277942657, 45.99715881049633, 53.61199200153351, 54.75120507180691, 47.21927583217621, 44.01351325213909, 35.70952244102955, 27.958191074430943, 29.35484793037176, 33.4533517062664, 42.595573738217354, 36.5614253282547, 29.657214805483818, 14.92360420525074, 1.5941032860428095, 0.44036133913323283, 0.09636461036279798, 2.0704856235533953, 6.404329771175981, 11.892112623900175, 12.023621667176485, 15.074488408863544, 19.80562973767519, 13.939063735306263, 8.17695127800107, 8.263258896768093, 15.730784442275763, 6.127980099990964, 16.111194379627705, 25.640509240329266, 28.28113194555044, 35.0310118496418, 43.72019559144974, 50.68437069654465, 61.174600794911385, 63.02585385739803, 66.39590442180634, 62.088261768221855, 64.3131373822689, 63.45222517848015, 63.20354752242565, 64.92333143949509, 64.79830294847488, 63.118185102939606, 66.05550348758698, 63.2710736989975, 62.37407103180885, 58.588470965623856, 58.986795991659164, 57.25765697658062, 56.30366116762161, 59.397367760539055, 63.309968411922455, 63.752713054418564, 64.75729554891586, 59.12879817187786, 59.50072221457958, 60.24161785840988, 47.79462955892086, 27.676432393491268, 51.556511297822, 32.80494309961796, 53.86602357029915, 56.20544023811817, 56.71837471425533, 55.50349250435829, 60.40313199162483, 65.25887623429298, 64.15592461824417, 60.05068950355053, 55.95804311335087, 52.08909071981907, 58.48232366144657, 59.4385689496994, 63.02505970001221, 61.55693247914314, 62.29041092097759, 59.611851051449776, 58.51706899702549, 58.19613441824913, 61.88390113413334, 64.98931869864464, 63.05425353348255, 60.16412861645222, 58.75698432326317, 51.727403327822685, 43.04059825837612, 32.00667433440685, 23.125158213078976, 19.020479768514633, 11.248755846172571, 14.695609789341688, 9.001424387097359, 15.78487453982234, 13.513920698314905, 14.866738356649876, 13.35253480821848, 10.724866557866335, 7.873781695961952, 5.834515197202563, 5.263149831444025, 0.5877136322669685, 0.8218058303464204, 0.07523079009843059, 0.17899200785905123, 3.119596028700471, 12.632929421961308, 28.9506047219038, 40.4990666359663, 34.9961107224226, 24.90920428186655, 29.06000655144453, 33.70175197720528, 45.608295276761055, 55.218439400196075, 57.2021609544754, 44.550751224160194, 12.510457243770361, 0.8506829151883721, 0.07635250920429826, 0.02670021913218079, 0.10003821909776889, 0.05242161969363224, 0.009830142098508077, 0.04398165656311903, 0.004907839283987414, 0.04827577868127264, 0.03803228908509482, 0.059387410365161486, 0.07187128052464686, 0.0934433464135509, 0.03730676180566661, 0.04362285413662903, 0.025294251900049858, 0.013552170403272612, 0.027052652076235972, 0.028048695894540288, 0.07079483242705464, 0.10644464564393274, 0.025988139568653423, 0.01634476171602728, 0.015349722580140224, 0.009227545087924227, 0.035270290027256124, 0.08474914575344883, 0.014162749212118797, 0.054669841047143564, 0.057329817063873634, 0.11361569209839217, 0.17475737258791924, 0.18258830707054585, 0.2229580088169314, 0.1372057243133895, 0.19895941688446328, 0.21397070435341448, 0.16802315425593406, 0.13660424330737442, 0.16851524269441143, 0.13506583054549992, 0.07798465521773323, 0.1365764276124537, 0.13082335819490254, 0.13971596461487934, 0.12268251026398502, 0.11029861110728234, 0.11792527686338872, 0.04002287758339662, 0.1469523794366978, 0.11674672408844344, 0.1751574347144924, 0.15117013826966286, 0.07217380218207836, 0.17224922514287755, 0.10488583124242723, 0.1986732892692089, 2.034389697946608, 25.75108900666237, 53.74284937977791, 64.87116023898125, 65.80059796571732, 55.26448152959347, 53.57692748308182, 45.757631063461304, 33.582331985235214, 41.445504650473595, 50.60388721525669, 51.28905884921551, 42.728464007377625, 30.37433512508869, 16.473970413208008, 1.8363389815203846, 0.6135231535881758, 0.07913309906143695, 3.303110981360078, 10.253440104424953, 22.182538993656635, 19.37247958034277, 20.917199291288853, 26.28609649837017, 20.319003090262413, 23.052544109523296, 28.06462336331606, 34.160926938056946, 32.246156483888626, 31.82595033198595, 34.927402809262276, 35.386380180716515, 42.95685835182667, 55.58291204273701, 54.08208757638931, 64.84328493475914, 63.32340449094772, 68.48129332065582, 63.675478398799896, 65.32365515828133, 62.472550347447395, 64.9206867814064, 66.27734318375587, 66.21371179819107, 63.85962411761284, 68.96684646606445, 66.03651210665703, 66.22847020626068, 60.88651545345783, 60.99289834499359, 59.0039748698473, 59.35970038175583, 60.915013924241066, 67.86287650465965, 67.16302245855331, 66.88790202140808, 60.26768445968628, 64.62256997823715, 62.737969905138016, 57.011468186974525, 33.44153434038162, 61.925805285573006, 35.19886024296284, 56.67136363685131, 58.66852506995201, 58.497693836688995, 57.85669103264809, 61.74423582851887, 66.05988845229149, 67.46954441070557, 62.27685704827309, 57.86410063505173, 54.22357298433781, 60.65105348825455, 60.48749506473541, 65.11976569890976, 65.02009704709053, 63.30174945294857, 58.71211253106594, 59.251713976264, 56.49212345480919, 63.76514598727226, 65.3045117855072, 64.04905155301094, 62.990139573812485, 62.05788999795914, 54.29410099983215, 51.544040367007256, 39.21522572636604, 30.4458586871624, 25.929329842329025, 19.426284693181515, 29.55380905419588, 32.792567163705826, 31.724319085478783, 23.588089272379875, 20.7078343257308, 14.891578573733568, 20.37274930626154, 17.62525163590908, 12.160415276885033, 3.857727558352053, 1.4660781808197498, 0.7963147794362158, 0.3420667885802686, 0.5158429825678468, 3.6373422341421247, 14.771938193589449, 33.62213484942913, 51.92470394074917, 48.783009722828865, 38.123126327991486, 37.794953137636185, 38.3384607732296, 51.24967776238918, 63.474484384059906, 64.57188069820404, 54.58690568804741, 19.482367783784866, 1.9144847569987178, 0.14484996412647888, 0.16326683369698003, 0.2913078060373664, 0.15095286711584777, 0.14297713962150738, 0.1746035402175039, 0.09755942359333858, 0.11033524351660162, 0.14887595199979842, 0.17478886933531612, 0.14913503575371578, 0.17990525026107207, 0.20109190401853994, 0.1243095428799279, 0.12666785070905462, 0.13647824147483334, 0.10845320153748617, 0.13740310590947047, 0.14917995053110644, 0.16837926639709622, 0.12959084386238828, 0.10856532520847395, 0.22703196911606938, 0.14202825928805396, 0.09481865738052875, 0.11743191193090752, 0.2455748850479722, 0.11541977888555266, 0.19653778901556507], [0.02655917953234166, 0.021925315195403527, 0.0362944501102902, 0.03451435324677732, 0.06259228233830072, 0.027999068479402922, 0.04570062272250652, 0.04872943871305324, 0.04264353461621795, 0.042956082688760944, 0.0392383272992447, 0.04016786355350632, 0.03976016472734045, 0.017007460628519766, 0.07166866678744555, 0.027594136008701753, 0.07867698252084665, 0.042098260164493695, 0.04184389275906142, 0.06851136276964098, 0.029025172989349812, 0.03105191335635027, 0.03797921810473781, 0.01236740028616623, 0.036751442385138944, 0.06701750113279559, 0.08950241608545184, 3.2733065681532025, 23.513556271791458, 39.095585346221924, 52.385942190885544, 49.17469650506973, 36.757734194397926, 32.11275704205036, 33.25136974453926, 20.607215724885464, 21.42072357237339, 39.916497096419334, 34.69202443957329, 36.128012984991074, 19.27630104124546, 6.220041560009122, 0.1428124273661524, 0.42227822821587324, 0.26903378718998283, 1.544313132762909, 5.713739627972245, 8.70637971907854, 12.326457817107439, 7.161311851814389, 16.295725777745247, 10.008633490651846, 5.04585849121213, 6.12907444126904, 10.183464959263802, 6.926164794713259, 19.12677526473999, 39.767640084028244, 41.59392848610878, 42.946754693984985, 53.760598227381706, 58.142021521925926, 63.81190627813339, 59.84973728656769, 62.669710367918015, 62.17781916260719, 64.3623599410057, 59.3871995061636, 63.0048181861639, 62.21240870654583, 64.72160026431084, 61.169448271393776, 61.76040776073933, 58.26094754040241, 56.053011417388916, 51.75573840737343, 53.13905417919159, 52.97550715506077, 54.60277743637562, 57.85941168665886, 58.188196644186974, 64.42568734288216, 61.63613922894001, 58.59128661453724, 55.58871053159237, 59.94155555963516, 46.34987108409405, 28.022935800254345, 48.421504721045494, 26.367366537451744, 47.1796515583992, 54.631655886769295, 54.18160043656826, 53.69269207119942, 58.34273815155029, 59.05561789870262, 62.17661462724209, 61.72535464167595, 59.34564873576164, 55.651186779141426, 52.80899628996849, 51.72222040593624, 57.82006099820137, 60.50595447421074, 62.197551503777504, 60.86947716772556, 57.242191806435585, 58.73455412685871, 56.61870226264, 60.63400760293007, 59.9768328666687, 58.71994011104107, 60.45860521495342, 56.3818533718586, 53.559980392456055, 46.28880076110363, 33.59849251806736, 23.0805467069149, 23.40391505509615, 16.453069634735584, 13.757677618414164, 12.78827078640461, 9.279126785695553, 17.769072018563747, 14.663285873830318, 11.349385846406221, 3.9795122109353542, 4.699910329654813, 5.943590719252825, 1.3505794596858323, 0.8205507101956755, 0.040992341382661834, 0.07417527798679657, 0.6858265050686896, 6.808513607829809, 20.527847483754158, 33.98425541818142, 32.99175627529621, 31.963064074516296, 22.5329751893878, 21.198859177529812, 33.00476297736168, 53.421466425061226, 49.3202780932188, 43.983221277594566, 25.201551094651222, 1.454666443169117, 0.026302806472813245, 0.033016981251421385, 0.026025805418612435, 0.0439804245979758, 0.03605928948672954, 0.01982144527573837, 0.035876086622010916, 0.028952982429473195, 0.06481345611973666, 0.055279032967519015, 0.07239733706228435, 0.09667168880696408, 0.02219630670879269, 0.03386246557056438, 0.010964192915707827, 0.023015133083390538, 0.022784935572417453, 0.017783678449632134, 0.027706933178706095, 0.04037810656882357, 0.024713391467230394, 0.033395932987332344, 0.047301605954999104, 0.08230232939240523, 0.044523283359012567, 0.07612151573994197, 0.02491270821337821, 0.046910950550227426, 0.11966670412220992, 0.016826487917569466, 0.051204486371716484, 0.017149335144495126, 0.053897536199656315, 0.0079256408753281, 0.029853792002541013, 0.031951401906553656, 0.09572675669915043, 0.07414139152388088, 0.024368441227125004, 0.03351671010022983, 0.06346307389321737, 0.015807144372956827, 0.022054033288441133, 0.01835522492910968, 0.028149360805400647, 0.11633455753326416, 0.04599662832333706, 0.007781617841828847, 0.02310508323716931, 0.055116101866587996, 0.06339311163173988, 0.009907420080708107, 0.04499170470808167, 0.04253403443726711, 0.05774329722044058, 0.08375479403184727, 3.409887864254415, 28.85777000337839, 46.671318635344505, 60.855433121323586, 57.49162942171097, 45.17366319894791, 42.067101895809174, 38.11041980981827, 21.90353136509657, 29.856022037565708, 41.8209321051836, 34.5255933701992, 31.64410348981619, 17.58276991546154, 7.326019713655114, 0.2819889842066914, 0.3153317794203758, 1.1865807347930968, 3.9619616651907563, 7.092840950936079, 12.839407492429018, 13.241838198155165, 11.546847950667143, 21.52828250080347, 17.780988179147243, 9.676419217139482, 7.798263598233461, 14.179119653999805, 12.43248162791133, 20.923419557511806, 30.18502928316593, 38.246771693229675, 43.03678326308727, 54.39400523900986, 59.46930170059204, 65.23741498589516, 62.08788558840752, 62.17248424887657, 61.9581301510334, 63.413205072283745, 59.81752261519432, 64.4562529027462, 62.720977216959, 67.18004554510117, 63.05281721055508, 63.404613733291626, 60.529258623719215, 58.96147795021534, 55.45468032360077, 55.98673537373543, 53.91937270760536, 55.8260951936245, 58.743088468909264, 60.737008675932884, 64.68076765537262, 62.27626048028469, 60.23459583520889, 58.23130153119564, 62.150893807411194, 52.90613427758217, 32.410448268055916, 49.813799411058426, 34.161527305841446, 54.09498788416386, 58.32014836370945, 55.86668461561203, 54.94726315140724, 58.74470718204975, 61.006228029727936, 64.6743232011795, 63.16269211471081, 60.902030020952225, 57.934697046875954, 54.389905259013176, 54.99260991811752, 60.6256328523159, 63.3290433883667, 62.6188500970602, 60.86226135492325, 57.69108831882477, 57.14387588202953, 57.911012917757034, 62.17871591448784, 61.52112700045109, 61.784502267837524, 62.32140205800533, 59.41814884543419, 54.231700748205185, 45.748902931809425, 32.48134106397629, 24.238956347107887, 19.32824805378914, 18.347853161394596, 10.42431028559804, 12.938553672283888, 16.118999160826206, 16.759169809520245, 16.864868737757206, 13.028911873698235, 9.50440814718604, 7.982065435498953, 8.75195162370801, 1.797585692256689, 0.796718270285055, 0.23393238399876282, 0.2514482714468613, 0.7931997184641659, 6.7056407779455185, 20.246550478041172, 33.38478058576584, 33.19732904434204, 36.792479529976845, 26.699962690472603, 24.138710126280785, 39.39527906477451, 57.3582261800766, 57.51140736043453, 50.95040962100029, 28.72101154178381, 1.8446904583834112, 0.09503949084319174, 0.06349000643240288, 0.015464707230421482, 0.04321533713664394, 0.006366221159623819, 0.014987753966124728, 0.062391048995777965, 0.06496412694104947, 0.09121403869357891, 0.024977174871310126, 0.05403009490692057, 0.03646057615696918, 0.06910767842782661, 0.05471911223139614, 0.03197120982804336, 0.04789189166331198, 0.027977223362540826, 0.015865987406868953, 0.040638199643581174, 0.08740252407733351, 0.07907969411462545, 0.015176486758718966, 0.011072582656197483, 0.1071997957478743, 0.0879324323614128, 0.06852662132587284, 0.0353497925971169, 0.01599269984581042, 0.07382341093034483, 0.08975155506050214, 0.10643876041285694, 0.16664157214108855, 0.16728642425732687, 0.1413904724176973, 0.1293983159121126, 0.2149641580763273, 0.1926831778837368, 0.20087561249965802, 0.14796731091337278, 0.12381058215396479, 0.18561505246907473, 0.12319113375269808, 0.11637088566203602, 0.20111367863137275, 0.14967048045946285, 0.19507042947225273, 0.13807339884806424, 0.0817703505163081, 0.09851307593635283, 0.12620109919225797, 0.10675676327082328, 0.1510609980323352, 0.1057781079725828, 0.21110322384629399, 0.1917988940840587, 0.2794617635663599, 5.404847552999854, 34.61900755763054, 57.2048170119524, 72.13710755109787, 64.46063786745071, 50.62241122126579, 45.83766996860504, 49.03966315090656, 30.873816423118114, 33.354978784918785, 56.50024361908436, 47.701747342944145, 45.12595675885677, 24.717876948416233, 7.9919506050646305, 0.40688914305064827, 0.9087753854691982, 1.0010978439822793, 5.585694573819637, 14.31413495913148, 23.692526668310165, 25.58159340173006, 24.819460697472095, 32.66200616955757, 17.57231667637825, 11.304094176739454, 13.023754600435495, 16.249607652425766, 12.84675819799304, 22.56396632641554, 41.82567425072193, 46.58249080181122, 46.449007764458656, 56.177496537566185, 61.674414575099945, 66.79214715957642, 63.22457939386368, 64.12457630038261, 63.23136202991009, 64.75078269839287, 60.322948694229126, 66.61332875490189, 64.88968044519424, 68.89826774597168, 66.42058029770851, 67.84116446971893, 63.948896527290344, 61.19970604777336, 56.917586624622345, 58.226623982191086, 56.66135497391224, 59.958673641085625, 61.6244662553072, 64.48207631707191, 69.10204321146011, 64.43014830350876, 59.119849652051926, 61.97243258357048, 63.86153921484947, 60.46265199780464, 40.15059873461723, 57.572549879550934, 39.284644201397896, 56.45753771066666, 61.697954311966896, 59.75639909505844, 56.44587993621826, 59.31398883461952, 62.447338700294495, 67.19026699662209, 66.30346298217773, 63.74658778309822, 60.20200498402119, 56.53574511408806, 54.62753690779209, 62.12640032172203, 63.41412082314491, 66.28404602408409, 61.54624365270138, 58.12456525862217, 57.66008198261261, 56.20249919593334, 62.244201600551605, 64.02880623936653, 62.27685704827309, 65.29141768813133, 61.51717521250248, 59.16833125054836, 48.079827055335045, 35.56003466248512, 27.289052680134773, 28.493386656045914, 21.272434629499912, 20.903037451207638, 22.20306359231472, 18.247650638222694, 30.231588184833527, 28.349944353103638, 25.23387026041746, 11.016237773001194, 14.10579213872552, 13.457005452364683, 2.970442157238722, 1.8041461589746177, 0.2535102842375636, 0.3106696077156812, 1.1420722980983555, 8.655867129564285, 26.66381523013115, 43.759151101112366, 46.873691976070404, 45.94109661877155, 32.08942249417305, 32.13690474629402, 46.36726275086403, 66.05994164943695, 64.27118763327599, 56.857500448822975, 35.52560091018677, 3.057510210201144, 0.19793724204646423, 0.14480987330898643, 0.12954119418282062, 0.1222100219456479, 0.12059573200531304, 0.17155828565591946, 0.12567644531372935, 0.24015383765799925, 0.20402451540576294, 0.0907845281471964, 0.16692412260454148, 0.2060937715577893, 0.11242747656069696, 0.08896530896890908, 0.14976615813793615, 0.10284504387527704, 0.13867162924725562, 0.07072003878420219, 0.21092298586154357, 0.11527400623890571, 0.1124740760133136, 0.11820964558864944, 0.13516962731955573, 0.2525772264925763, 0.16051266429712996, 0.14783464459469542, 0.07536960139987059, 0.1396166207268834, 0.23934075550641865], [0.024032474684645422, 0.03466481255600229, 0.04321728898503352, 0.011488457166706212, 0.05595747468760237, 0.06070421040931251, 0.0661322228552308, 0.007372247791863629, 0.02172938264266122, 0.029153610921639483, 0.07985196556546725, 0.026361664349678904, 0.04790301274624653, 0.06864430368295871, 0.007998956716619432, 0.020934555468556937, 0.06415766474674456, 0.05258546363620553, 0.014717958238179563, 0.015069430100993486, 0.04281315988919232, 0.0130124861789227, 0.08038450105232187, 0.04455086156667676, 0.07513787320931442, 0.02169647024857113, 0.2155073656467721, 5.1071620266884565, 24.799160286784172, 49.651460722088814, 54.57409657537937, 45.711231753230095, 30.407473146915436, 28.162547908723354, 75.59992253780365, 71.6978207230568, 25.150702223181725, 36.61771930754185, 35.65904974937439, 29.806687384843826, 13.1341633759439, 2.0511467987671494, 0.12745219690259546, 0.1269774598767981, 1.6120049566961825, 1.582865270320326, 4.584382753819227, 11.086962427943945, 8.582867346704006, 9.091553650796413, 15.580829288810492, 15.50061559304595, 7.276078043505549, 5.325741022825241, 19.81025028973818, 13.969592247158289, 29.38829943537712, 36.88354164361954, 42.125816345214844, 52.96282723546028, 58.956758603453636, 64.2543925344944, 61.59577019512653, 61.22801452875137, 63.31805817782879, 61.7570411413908, 58.66276457905769, 62.525690495967865, 62.54119746387005, 61.66398413479328, 62.57246978580952, 59.27174650132656, 55.52078537642956, 52.13806629180908, 49.39894527196884, 51.261426731944084, 50.87570562958717, 52.19019189476967, 52.589432671666145, 57.795890495181084, 58.988528698682785, 60.617299899458885, 61.96762964129448, 64.10144314169884, 55.32615602016449, 60.672051161527634, 55.842977687716484, 27.68896982073784, 47.96661972999573, 33.04789446294308, 52.28275492787361, 56.61610320210457, 53.11226561665535, 55.91032527387142, 55.15513859689236, 54.07096177339554, 55.68007282912731, 61.52213774621487, 56.91453918814659, 57.93006509542465, 51.60356417298317, 50.103647857904434, 53.95166717469692, 59.60866682231426, 58.239794075489044, 60.39732590317726, 58.213366493582726, 58.85394752025604, 56.990622505545616, 58.35386775434017, 60.400817915797234, 59.918088018894196, 56.11608803272247, 59.78057719767094, 57.68353812396526, 55.31949497759342, 44.75746773183346, 38.66767130792141, 25.099431574344635, 27.927629314363003, 7.920406144112349, 10.230371542274952, 13.151559792459011, 12.069281917065382, 16.720520183444023, 6.8022410944104195, 7.8090607188642025, 5.732557168230414, 8.618052508682013, 0.21124340069945902, 1.0788799077272415, 0.13925375504186377, 0.038208174373721704, 0.1810790310264565, 0.988924722187221, 8.83572667837143, 31.874988600611687, 45.56890279054642, 30.332094691693783, 24.264886155724525, 20.83845231682062, 35.575275644659996, 46.04811407625675, 50.24586662650108, 48.92816573381424, 26.15421887487173, 4.219875913113356, 0.15566758287604898, 0.0783676108403597, 0.011359229774825508, 0.040490267347195186, 0.0010159803400711098, 0.003153241918880667, 0.0512632867321372, 0.07965753771713935, 0.03805331412877422, 0.026886993582593277, 0.04434464099176694, 0.04514625696174335, 0.035855210007866845, 0.050839705945691094, 0.010697988254833035, 0.07553435818408616, 0.03050078150408808, 0.05052531363617163, 0.0303092480316991, 0.066998643160332, 0.03826811022008769, 0.14617023000027984, 0.12415646007866599, 0.03243711529648863, 0.07856698881369084, 0.04144654318224639, 0.012971822052350035, 0.03904874196450692, 0.0209182300750399, 0.049439124850323424, 0.049000292929122224, 0.037790697751916014, 0.040608996132505126, 0.035545214923331514, 0.045307855907594785, 0.04953375238983426, 0.017741780502547044, 0.0290299116022652, 0.0634644617093727, 0.028499563595687505, 0.0335710056242533, 0.0956336320086848, 0.051749586418736726, 0.02416620969597716, 0.01400930554154911, 0.021354828131734394, 0.06255547923501581, 0.017332213319605216, 0.04383211380627472, 0.1341199188027531, 0.06287196069024503, 0.022387341086869128, 0.08495313988532871, 0.12490152439568192, 0.044999753299634904, 0.2016655248007737, 7.289760634303093, 29.594544768333435, 56.02680042386055, 63.072994127869606, 50.9095162153244, 37.048578187823296, 31.574116945266724, 75.28719171881676, 52.69497960805893, 23.11469167470932, 42.00069285929203, 36.617563515901566, 26.77794400602579, 12.7301225066185, 2.652288554236293, 0.1725167693803087, 0.6615296588279307, 1.8536808947101235, 7.535797907039523, 12.791553810238838, 11.433918010443449, 17.11735188961029, 12.367907892912626, 11.232210583984852, 15.939063616096973, 15.515970569103956, 13.119078185409307, 17.665808759629726, 15.946431420743465, 29.07157313078642, 35.63126564025879, 41.67207129299641, 53.89740228652954, 58.58857735991478, 65.43080940842628, 62.20391236245632, 63.60063761472702, 62.05106936395168, 60.81097170710564, 59.820304065942764, 64.27096724510193, 63.91539752483368, 64.11505401134491, 62.99854852259159, 61.57700300216675, 58.65060903131962, 53.63952912390232, 51.39736823737621, 52.40776062011719, 53.25672246515751, 52.71747440099716, 54.830085039138794, 58.96279647946358, 60.37113390862942, 62.531830966472626, 62.30764299631119, 64.51066598296165, 57.54804879426956, 62.56982892751694, 61.50163024663925, 34.84899401664734, 46.90607763826847, 42.10650198161602, 56.75248548388481, 59.55983944237232, 54.17373485863209, 56.13382928073406, 55.60684695839882, 54.790023788809776, 56.85088500380516, 63.56338821351528, 58.46806302666664, 62.10868567228317, 54.10263307392597, 52.84007482230663, 55.52582770586014, 60.33803768455982, 60.79342044889927, 60.96379570662975, 59.11966726183891, 57.643613666296005, 56.75489455461502, 60.12197367846966, 62.552669048309326, 58.83137673139572, 59.191255420446396, 62.532138749957085, 59.46550950407982, 53.467402160167694, 45.515040680766106, 38.040503561496735, 24.201670847833157, 24.088856801390648, 12.341986633837223, 11.943326275795698, 18.37678100913763, 13.81887523457408, 14.012563191354275, 14.062764197587967, 11.303311418741941, 11.684346422553062, 9.62995721027255, 5.948096327483654, 2.358773066662252, 0.6003008130937815, 0.04199336501187645, 0.2410342326038517, 1.4031780185177922, 10.341484230011702, 29.595496617257595, 44.77270491421223, 35.25595597922802, 28.912319876253605, 25.089690797030926, 38.89670021831989, 54.001672491431236, 57.36289992928505, 55.02223312854767, 31.347493305802345, 5.529973413795233, 0.04684674735472072, 0.032682343153283, 0.04330636525992304, 0.013234482958068838, 0.04328620481828693, 0.04818835368496366, 0.06623688052059151, 0.017982384779315908, 0.07622837016242556, 0.06091188930440694, 0.019015096258954145, 0.025085559973376803, 0.058392999271745794, 0.022261066515056882, 0.01826797248213552, 0.03629197504778858, 0.04478038928937167, 0.046997510944493115, 0.028088625294913072, 0.05637069138174411, 0.038603516441071406, 0.04634062490367796, 0.10262685245834291, 0.02630058559589088, 0.004177212986178347, 0.02266729588882299, 0.0375117949442938, 0.048484311046195216, 0.015427059934154386, 0.08638693951070309, 0.09603456986951642, 0.10999061982147396, 0.10900509965722449, 0.12084039582987316, 0.16709956631530076, 0.2550469752168283, 0.135238929069601, 0.11754395396565087, 0.12940984888700768, 0.16378802916733548, 0.12209892243845388, 0.1462179352529347, 0.14899147470714524, 0.11270614559180103, 0.14908298151567578, 0.2063564324635081, 0.1477909172535874, 0.11659915544441901, 0.096862175851129, 0.21156047587282956, 0.07553233212092891, 0.15364331571618095, 0.1593224672251381, 0.1557028348906897, 0.07931353742606007, 0.5040406971238554, 9.487238768488169, 36.088901683688164, 67.22128853201866, 70.1564334332943, 61.10663764178753, 45.38677856326103, 39.407415613532066, 88.09783950448036, 85.51804393529892, 37.143873274326324, 48.99542212486267, 45.672857612371445, 38.03873285651207, 16.362277306616306, 3.4540965920314193, 0.21199835784500465, 0.8402688021305948, 3.7786198407411575, 11.532924547791481, 15.269305855035782, 21.012272089719772, 19.883730746805668, 23.696429058909416, 31.605750247836113, 28.943896181881428, 22.211147658526897, 9.587921965867281, 24.660779312253, 19.052827432751656, 32.885418981313705, 41.68003186583519, 45.88191859424114, 55.46180114150047, 62.9970134049654, 67.4021664261818, 63.62380497157574, 62.55131632089615, 62.94435203075409, 61.82887628674507, 59.86555203795433, 66.64868965744972, 67.25719660520554, 65.52477076649666, 65.45128270983696, 64.31291699409485, 59.21506494283676, 55.796217396855354, 54.93061624467373, 54.84037108719349, 56.50588631629944, 56.085913851857185, 57.612512335181236, 62.52333082258701, 64.20487359166145, 66.78209289908409, 65.05578473210335, 65.13980582356453, 59.20073211193085, 63.54764185845852, 62.82329812645912, 41.88795290887356, 54.42511036992073, 44.77824121713638, 59.85477201640606, 58.805895298719406, 55.987727120518684, 55.37854380905628, 55.37426143884659, 54.14866000413895, 57.8545593470335, 65.6810411810875, 61.14731065928936, 63.47467817366123, 56.295860186219215, 54.37312535941601, 58.06529603898525, 62.996390238404274, 64.24123764038086, 62.912688329815865, 59.92231719195843, 57.090120166540146, 57.02588461339474, 59.478333815932274, 63.03805500268936, 61.81099824607372, 61.551935747265816, 64.42327827215195, 61.290923953056335, 60.91233886778355, 49.053608402609825, 42.338851913809776, 28.040264770388603, 31.985064893960953, 15.191114600747824, 19.11397185176611, 24.52197276055813, 19.759266525506973, 25.84313526749611, 12.949092406779528, 20.885985866189003, 13.510249145328999, 20.02758152782917, 5.658284453675151, 2.8330721659585834, 1.0208713891915977, 0.22844481049105525, 0.4606522503308952, 1.5081828902475536, 11.69892244040966, 39.42524425685406, 57.7398245036602, 41.10642224550247, 36.430659145116806, 32.595920115709305, 48.78846623003483, 59.645920023322105, 64.66015756130219, 64.49430406093597, 38.61861974000931, 7.67788415774703, 0.2740733261452988, 0.15852816140977666, 0.1244942560151685, 0.16072695201728493, 0.1656813221052289, 0.1311466228798963, 0.16444880777271464, 0.16156758269062266, 0.16430435614893213, 0.17631503666052595, 0.09841416991548613, 0.11744550065486692, 0.0796963223547209, 0.10917868057731539, 0.05262405531539116, 0.2278835538891144, 0.13761221343884245, 0.1009499178326223, 0.1129563309950754, 0.14994304161518812, 0.124047965509817, 0.16246575949480757, 0.18481826788047329, 0.07177051913458854, 0.13186643191147596, 0.15364621009211987, 0.11876388889504597, 0.13975566951557994, 0.1104415932786651], [0.04589684285747353, 0.036724465317092836, 0.07497664904803969, 0.017305688961641863, 0.03711189980094787, 0.022667848788842093, 0.05235982476733625, 0.05708048884116579, 0.03795014818024356, 0.014842534219496883, 0.023595652128278743, 0.02094331652187975, 0.05723035443224944, 0.01705322887573857, 0.03146892056975048, 0.0339894767239457, 0.012284136882954044, 0.010438859044370474, 0.030322690181492362, 0.018294135043106508, 0.02841537065251032, 0.03622341544541996, 0.061480185177060775, 0.14061102439882234, 0.010929288782790536, 0.016756952391006052, 0.28147951466962695, 7.084114719182253, 32.340551018714905, 55.50756208598614, 60.49934662878513, 54.80544716119766, 44.154261499643326, 26.374569050967693, 35.38436248898506, 47.99083963036537, 38.48217286169529, 37.92361043393612, 27.775531075894833, 20.869954526424408, 5.320455506443977, 0.8879238262306899, 0.07598212556331418, 1.0278556519187987, 1.6753933927975595, 4.266103282570839, 9.056639224290848, 6.9037246238440275, 13.758943900465965, 7.603927301242948, 13.434725347906351, 23.675617575645447, 14.143731202930212, 17.0205045863986, 24.67545222491026, 28.72728120535612, 39.391627460718155, 43.67286913096905, 48.48142370581627, 57.981149554252625, 60.21739035844803, 60.722637847065926, 59.511186853051186, 59.11343179643154, 59.83260400593281, 59.823974668979645, 60.495687425136566, 61.23228169977665, 59.77195926010609, 59.10383351147175, 59.251949563622475, 53.798740580677986, 52.047498151659966, 48.10487151145935, 45.866039246320724, 50.35132996737957, 51.3732623308897, 52.02805459499359, 55.55064797401428, 59.19523000717163, 60.431201085448265, 61.1652646958828, 59.817963391542435, 57.74527721107006, 62.94505879282951, 54.73637066781521, 63.43813173472881, 27.812928669154644, 33.24387274682522, 46.073910892009735, 56.578428223729134, 55.813118889927864, 57.15018354356289, 57.87295036017895, 60.57754643261433, 55.9484638273716, 56.49411454796791, 58.831749111413956, 61.53416030108929, 58.981385082006454, 54.96224194765091, 47.059756591916084, 47.17748947441578, 53.47839117050171, 60.934495478868484, 59.75733384490013, 59.80237662792206, 57.86126598715782, 57.149074003100395, 55.72956137359142, 62.43846237659454, 58.29201467335224, 57.0154769718647, 52.65123635530472, 59.3596737831831, 61.2471617013216, 56.705482006073, 42.60946199297905, 37.69718438386917, 42.684678956866264, 19.233291149139404, 12.065141089260578, 21.639109253883362, 13.93179852515459, 10.905839446932077, 13.809882067143917, 9.35335960239172, 9.782051648944616, 7.426101118326187, 3.963229372166097, 1.3920732331462204, 1.03564677760005, 0.29226936225313693, 0.10494812711840495, 0.815561399795115, 3.1055177841335535, 17.266898564994335, 31.124561168253422, 44.296240881085396, 28.076151944696903, 22.396277524530888, 28.29078532755375, 32.20963664352894, 49.64505426585674, 52.367026805877686, 38.282341584563255, 9.616352040320635, 1.2713806657120585, 0.05390102058299817, 0.028044510181644, 0.041417566026211716, 0.05235940916463733, 0.0032093756499307347, 0.01699290340184234, 0.039104959651012905, 0.07314967442653142, 0.00611132543781423, 0.018902710980910342, 0.022260057194216643, 0.04110222747840453, 0.061085807901690714, 0.026387648795207497, 0.04162636927503627, 0.12910539022414014, 0.007608476180394064, 0.024963254036265425, 0.06425778788980097, 0.015685593571106438, 0.06419671655748971, 0.10691260686144233, 0.04218129164655693, 0.1199958095094189, 0.020446339185582474, 0.08882261623512022, 0.08348673771251924, 0.031218367803376168, 0.09077286158571951, 0.03498264843074139, 0.055992927082115784, 0.04996155228582211, 0.029817098366038408, 0.04561242589261383, 0.020076888795301784, 0.01998377152631292, 0.007419684015985695, 0.08429846915532835, 0.04165709418884944, 0.043578243639785796, 0.04677709308452904, 0.06769823608919978, 0.06836029861005954, 0.024744166476011742, 0.029749549939879216, 0.009764307105797343, 0.06497417562059127, 0.04035963080241345, 0.01352327302811318, 0.03914379994967021, 0.03508066016365774, 0.08698076155269518, 0.09447630465729162, 0.08074397512245923, 0.4870749043766409, 9.01968240737915, 36.992477998137474, 63.5412809997797, 66.56936511397362, 60.60388661921024, 46.7769605666399, 30.95170084387064, 52.7113339304924, 58.25867906212807, 27.527288496494293, 37.02549822628498, 27.92863816022873, 18.94533310085535, 5.510367415845394, 1.3063512579537928, 0.043080058458144777, 0.7006955228280276, 4.624392706900835, 7.665723385289311, 9.255569949746132, 16.37251205742359, 18.54096259921789, 13.340020179748535, 15.180038195103407, 21.862892545759678, 16.61571230739355, 17.0728961750865, 16.796508505940437, 23.591871969401836, 31.70133601874113, 41.22933804988861, 50.16163654625416, 56.37148752808571, 60.812590420246124, 62.197277918457985, 60.16315586864948, 60.170557871460915, 60.136257112026215, 59.88063342869282, 61.91527605056763, 62.34729006886482, 62.80940607190132, 60.46267859637737, 61.37286655604839, 57.14387588202953, 53.67228336632252, 50.58882862329483, 48.23078155517578, 53.24517108500004, 53.14728453755379, 53.65322358906269, 56.57679431140423, 61.431976184248924, 63.005376756191254, 65.28191059827805, 59.854639023542404, 60.83374388515949, 64.24200519919395, 55.79155884683132, 63.3511696010828, 36.383013501763344, 32.50551536679268, 53.33872586488724, 58.188926205039024, 55.43134577572346, 56.254552602767944, 59.383775889873505, 61.73880212008953, 56.921686604619026, 56.12404480576515, 59.22875940799713, 63.16082261502743, 61.03316478431225, 57.10891015827656, 49.97208371758461, 49.2852857708931, 56.26462206244469, 62.28001847863197, 60.82036480307579, 59.41387787461281, 58.09990078210831, 55.27251809835434, 56.22367545962334, 62.043910548090935, 61.94143004715443, 60.05504406988621, 57.63420917093754, 61.89763739705086, 62.6469761878252, 54.59754131734371, 44.36856999993324, 34.13467034697533, 36.80655397474766, 21.830630376935005, 15.648304168134928, 14.161335658282042, 10.780544970184565, 12.541929055005312, 16.601989343762398, 20.17155010253191, 15.472813434898853, 8.948483727872372, 7.996552158147097, 4.902120279148221, 1.3584648678079247, 0.48677323618903756, 0.09603036189218983, 0.6747630424797535, 3.3187352679669857, 18.30462098121643, 37.06430174410343, 43.300283923745155, 30.182365626096725, 24.15555652230978, 35.45860670506954, 38.42707201838493, 53.66583131253719, 59.53352205455303, 44.32834915816784, 12.131987102329731, 1.4393131295219064, 0.055296247082878835, 0.04412887639773544, 0.030175323772709817, 0.013924585673521506, 0.02528513090510387, 0.057127834152197465, 0.01097894959457335, 0.04767628292029258, 0.038518202854902484, 0.05904885743802879, 0.06430898865801282, 0.034797397238435224, 0.01723315886920318, 0.04013352438050788, 0.052501144527923316, 0.007195601338025881, 0.02411388271866599, 0.00884343820871436, 0.04801977484021336, 0.06213432156073395, 0.0640348021988757, 0.04524718533502892, 0.046703687257831916, 0.0179150831172592, 0.013109326246194541, 0.011915774666704237, 0.026750635079224594, 0.05731653262046166, 0.18485930864699185, 0.12073038727976382, 0.10416147284558974, 0.1335825296700932, 0.2324691359535791, 0.16215582378208637, 0.12411543415510096, 0.2210947877028957, 0.11304368177661672, 0.19345483335200697, 0.12842121912399307, 0.18764706765068695, 0.15820448112208396, 0.07406597447698005, 0.15735446970211342, 0.12260419884114526, 0.1457809587009251, 0.13426491961581632, 0.16798000579001382, 0.07981655769981444, 0.12439448910299689, 0.12725879321806133, 0.13580578146502376, 0.1863673230400309, 0.18160660896683112, 0.1503862818935886, 0.7998516177758574, 12.49887926504016, 45.623027086257935, 70.97924128174782, 74.3229478597641, 68.44334095716476, 59.90184009075165, 37.84082427620888, 48.98962743580341, 58.62379767000675, 49.80178825557232, 53.66529934108257, 36.81520611047745, 25.477108508348465, 7.283136639744043, 1.3893953268416226, 0.45227895432617515, 2.271056673489511, 6.353924525901675, 12.199478130787611, 20.11072676628828, 23.267276287078857, 27.4183464422822, 12.62665405869484, 26.475489735603333, 35.37145838141441, 19.26932841539383, 20.249839201569557, 28.91403168439865, 33.97836573421955, 44.06365156173706, 44.87199358642101, 51.60699538886547, 59.04576502740383, 62.28049725294113, 62.97502018511295, 60.14057748019695, 60.07895238697529, 61.265970692038536, 60.41801959276199, 64.30194318294525, 64.2765149474144, 64.61039543151855, 63.81134390830994, 64.9425508081913, 58.59660252928734, 56.182709857821465, 51.43471643328667, 52.834382727742195, 54.70982529222965, 55.10600343346596, 55.39915770292282, 60.35931274294853, 63.27937625348568, 66.01571202278137, 66.68414935469627, 62.0111221075058, 60.697262808680534, 65.15419945120811, 58.06943021714687, 64.05007749795914, 41.71398684382439, 49.65481594204903, 54.094892889261246, 54.48743462562561, 57.44066655635834, 58.72604638338089, 62.03752689063549, 64.23594072461128, 57.87594459950924, 56.60441502928734, 60.41683405637741, 66.67724892497063, 63.13126020133495, 59.02979828417301, 52.13892884552479, 51.73792116343975, 58.04627425968647, 65.84318608045578, 63.5400802642107, 62.201290503144264, 58.872361332178116, 56.75435498356819, 56.15416958928108, 64.54386860132217, 63.38917136192322, 62.41303414106369, 56.85571834445, 64.24868524074554, 66.42232060432434, 59.377886205911636, 46.632351726293564, 39.64553743600845, 44.6161875128746, 25.321409963071346, 22.787842713296413, 30.765408240258694, 23.782752826809883, 21.633063778281212, 27.937113605439663, 18.055491149425507, 15.385838951915503, 17.373273856937885, 12.598660960793495, 3.7997763929888606, 1.9196577044203877, 1.1311757890507579, 0.3704163251677528, 1.3408734742552042, 4.2759001068770885, 20.622080527246, 41.929925456643105, 56.44054502248764, 40.15471771359444, 34.18994218111038, 40.27369312942028, 44.98905010521412, 64.08940538764, 67.43644058704376, 54.246801137924194, 17.15068180114031, 2.02800081577152, 0.22335017449222505, 0.08808827595203184, 0.14137536229100078, 0.16782777645858005, 0.07657247435417958, 0.113240417704219, 0.1320149950333871, 0.17360362980980426, 0.10916727376752533, 0.18626766745001078, 0.2040902993758209, 0.07780276224366389, 0.10212038119789213, 0.12122883592383005, 0.2011829655384645, 0.23361190978903323, 0.16105682181660086, 0.1442797720665112, 0.21776919427793473, 0.12477240554289892, 0.20746347930980846, 0.2722209255443886, 0.16388097574235871, 0.11149457466672175, 0.14859907154459506, 0.13062306737992913, 0.1000788739474956, 0.16872139647603035], [0.00847590441480861, 0.03836664887785446, 0.021477783448062837, 0.03301486613054294, 0.03187335023540072, 0.046551621198887005, 0.12938973668497056, 0.07531766590545885, 0.03585038233723026, 0.015563043652946362, 0.01567100109241437, 0.04317302358685993, 0.03611950363847427, 0.03044245055207284, 0.05826323103974573, 0.04523186740698293, 0.03303423247416504, 0.050601539624040015, 0.11211191536858678, 0.01783511856046971, 0.026890179251495283, 0.09609801607439294, 0.04159747375524603, 0.0049344165199727286, 0.07203116882010363, 0.04373971270979382, 0.9107364958617836, 10.011410191655159, 39.86257418990135, 54.856155440211296, 51.592548564076424, 40.858474150300026, 30.160729587078094, 22.44352038949728, 14.427792560309172, 13.192583341151476, 28.656076826155186, 36.535970494151115, 32.96369858086109, 8.996470402926207, 1.8385451193898916, 0.37832871777936816, 0.3037066594697535, 0.3474468248896301, 2.268049609847367, 7.6192875020205975, 10.999707709997892, 8.779996018856764, 20.009036622941494, 16.523572951555252, 6.098422911018133, 14.994474202394485, 25.39513360708952, 37.84959800541401, 25.035693794488907, 25.595607049763203, 38.558924943208694, 47.678963765501976, 53.931345865130424, 58.53281915187836, 57.42881499230862, 60.27308776974678, 59.04740273952484, 58.86954188346863, 58.40530939400196, 61.20451278984547, 61.512858644127846, 59.49744679033756, 56.046392172575, 57.39128440618515, 55.25135703384876, 52.79259257018566, 48.038812056183815, 45.61052195727825, 46.466087847948074, 51.36343605816364, 49.27372679114342, 51.8076778203249, 55.66350191831589, 60.90462528169155, 62.39548668265343, 57.978269308805466, 58.63909184932709, 62.3389533162117, 57.98469856381416, 53.156613036990166, 64.41787496209145, 36.53187431395054, 18.426039665937424, 59.65051017701626, 53.994502276182175, 54.1365272551775, 59.901125729084015, 58.357754945755005, 59.93183948099613, 60.24143926799297, 57.82434716820717, 54.53485228121281, 57.905370220541954, 59.03506100177765, 54.0459743142128, 48.36489915847778, 44.771390184760094, 48.142307102680206, 53.919786885380745, 57.69813694059849, 59.82432045042515, 58.19141507148743, 57.37573944032192, 56.05614244937897, 59.08704221248627, 60.64397446811199, 57.95915253460407, 56.17857187986374, 57.74207018315792, 57.15226203203201, 59.847685396671295, 57.00208269059658, 38.3719065785408, 37.240190505981445, 29.582472816109657, 23.425247110426426, 19.124953262507915, 9.716104287654161, 8.612268269062042, 17.547498308122158, 16.83627527207136, 21.684782803058624, 7.202571462839842, 9.031450375914574, 6.8036954663693905, 0.9858953941147774, 0.17024213128024712, 0.023131915586418472, 0.07068492777762003, 1.5469301235862076, 8.771824557334185, 27.691291496157646, 41.81273974478245, 35.65281808376312, 29.87384308129549, 20.562609918415546, 26.29067525267601, 37.584630623459816, 40.74368230998516, 40.701633766293526, 20.417446307837963, 2.9956065444275737, 0.09487584728049114, 0.02688381719053723, 0.020712337900476996, 0.03094865649472922, 0.04770550127432216, 0.004507350422500167, 0.021210359809629153, 0.02792565523122903, 0.02769088423519861, 0.03337082984216977, 0.028255129836907145, 0.054491566042997874, 0.05709822988137603, 0.05919355768128298, 0.056689254561206326, 0.04198126800474711, 0.058657712215790525, 0.05053499866335187, 0.015855922029004432, 0.034290354524273425, 0.0351882307586493, 0.013553667686210247, 0.03336141940962989, 0.009431617145310156, 0.0831932776782196, 0.004643655120162293, 0.028027305343130138, 0.055060455633793026, 0.01596617734321626, 0.03067289297177922, 0.020601605756382924, 0.007605359623994445, 0.021063986023364123, 0.0022099583065937622, 0.038236350010265596, 0.0995902439171914, 0.017254152371606324, 0.0038162230794114294, 0.032261315354844555, 0.04533387560513802, 0.05685431562596932, 0.006213785882209777, 0.00875239431479713, 0.016377013598685153, 0.02601075466373004, 0.03344385346281342, 0.06285205628955737, 0.0616348376206588, 0.06783562246710062, 0.05242290731985122, 0.017874450531962793, 0.011187470827280777, 0.026035757618956268, 0.058413118895259686, 0.8522531809285283, 12.33405550941825, 45.863869562745094, 60.917989164590836, 59.35948759317398, 48.62276092171669, 38.932596892118454, 24.425509236752987, 17.226637825369835, 22.847387418150902, 33.42092804610729, 33.143257945775986, 27.48652808368206, 10.024705678224564, 2.299476061016321, 0.5997072136960924, 0.9866701962891966, 1.513597599696368, 6.264812182635069, 7.989737223833799, 14.644780866801739, 12.056410107761621, 13.004229348152876, 10.997813511639833, 12.78063129633665, 16.794217228889465, 16.996554471552372, 20.799538604915142, 22.073463946580887, 27.84218329936266, 36.37063376605511, 48.02883759140968, 54.686365351080894, 59.13689933717251, 58.573720157146454, 59.93616744875908, 59.70716133713722, 59.7373279184103, 58.96039500832558, 61.613769829273224, 62.79433228075504, 61.114275231957436, 59.35725711286068, 58.39184671640396, 56.24044395983219, 54.043903425335884, 51.287246346473694, 46.48104764521122, 48.144047409296036, 54.99785743653774, 52.111091539263725, 53.41270789504051, 58.59166659414768, 62.75308929383755, 63.020298555493355, 60.173286125063896, 58.55042740702629, 62.04649440944195, 58.84609334170818, 55.297433361411095, 62.21775121986866, 44.05860923230648, 20.415183529257774, 61.202377304434776, 55.10404273867607, 55.89365176856518, 61.555074378848076, 61.081638783216476, 61.03219963610172, 60.59734337031841, 59.885964542627335, 54.89950731396675, 60.28067596256733, 61.835199147462845, 57.014306634664536, 50.894605815410614, 46.91176973283291, 49.683018028736115, 57.55155220627785, 60.31556949019432, 61.651596799492836, 58.88603299856186, 56.18999406695366, 56.287971809506416, 60.41909493505955, 61.43305152654648, 59.59938392043114, 59.06181916594505, 57.88821794092655, 60.618268847465515, 60.00080958008766, 55.95563784241676, 42.02821098268032, 37.54918612539768, 29.669680036604404, 19.70982737839222, 16.987100578844547, 15.895854234695435, 12.390589825809002, 16.220801398158073, 16.12459436058998, 13.547645788639784, 12.692428529262543, 7.946029119193554, 4.4620416685938835, 5.100359916687012, 0.9641540294978768, 0.1600325689651072, 0.15771984384628013, 1.5954864118248224, 10.31924307346344, 27.61667300015688, 43.10108721256256, 33.47433798015118, 32.42587924003601, 24.96285930275917, 31.880228519439697, 44.35892231762409, 48.509846180677414, 49.815649911761284, 24.97725673019886, 3.747649840079248, 0.10767030253191479, 0.05531219212571159, 0.011590868907660479, 0.07738474014331587, 0.05328755018126685, 0.08502469034283422, 0.02627095720526995, 0.05825800260936376, 0.011122591349703725, 0.04589962220052257, 0.03831759291642811, 0.02863405559764942, 0.10219434363534674, 0.049149694677907974, 0.011172840313520283, 0.025586787960492074, 0.03538502234732732, 0.006456864757637959, 0.007999432618817082, 0.07748592455754988, 0.04510747974563856, 0.022267384047154337, 0.005589994525507791, 0.05750936114054639, 0.030744378491363022, 0.058677943161455914, 0.05670033111528028, 0.0294347271847073, 0.09514547695289366, 0.09887435342534445, 0.12318122608121485, 0.06274011815548874, 0.1495144810178317, 0.10083637665957212, 0.16827576648211107, 0.15699081734055653, 0.08198466792237014, 0.08688285000971518, 0.11318134274915792, 0.12569358892505988, 0.11386247104383074, 0.13904350460506976, 0.15083094709552824, 0.0927380463690497, 0.20350950944703072, 0.12372295677778311, 0.22225540276849642, 0.11068630163208582, 0.11304197483696043, 0.12089185634977184, 0.12054968174197711, 0.10502876888494939, 0.1150773445260711, 0.1983384322375059, 1.2545567122288048, 17.013870142400265, 53.670892640948296, 69.18430119752884, 66.3501624763012, 54.990869611501694, 44.965799152851105, 33.245772644877434, 23.096781335771084, 23.65188404917717, 38.56499321758747, 46.70606017112732, 41.021838784217834, 11.848904192447662, 2.4365494307130575, 0.7472448656335473, 1.3412311300635338, 1.6013304982334375, 8.03349757567048, 14.571928326040506, 20.191447734832764, 21.82389333844185, 31.818037256598473, 31.970420479774475, 17.426626794040203, 20.782184936106205, 32.59419120848179, 43.909946009516716, 29.06882207840681, 33.0762105435133, 42.218128591775894, 49.02514033019543, 57.48444400727749, 60.95213793218136, 59.16957378387451, 61.331714764237404, 59.87390398979187, 59.959042221307755, 60.28072156012058, 64.63608205318451, 64.96446043252945, 63.82622390985489, 60.088330283761024, 61.17995470762253, 59.30092513561249, 56.922336369752884, 52.31298990547657, 49.48411010205746, 50.53610645234585, 59.18663486838341, 53.87762814760208, 55.890836119651794, 60.53838573396206, 65.35791411995888, 65.33591330051422, 61.687911450862885, 60.07247373461723, 64.91893887519836, 63.23426887392998, 55.85937760770321, 63.2311986386776, 47.29917414486408, 33.723137229681015, 57.44247905910015, 55.55328123271465, 57.962918132543564, 64.94548425078392, 62.0937030762434, 64.20349806547165, 64.14685070514679, 61.57225705683231, 55.79658217728138, 60.61701871454716, 64.0322944521904, 58.78825284540653, 52.72131599485874, 48.70588906109333, 53.50526712834835, 59.628330767154694, 63.88399600982666, 63.68282340466976, 59.66266572475433, 57.36608795821667, 55.88422067463398, 60.30503265559673, 64.64555114507675, 63.15773718059063, 61.66347116231918, 60.52613899111748, 60.86608774960041, 63.65128509700298, 60.664352774620056, 43.0058491230011, 39.601102620363235, 33.87721136212349, 27.463130839169025, 26.47375512868166, 21.24869540333748, 23.682388812303543, 32.73072928190231, 26.422754265367985, 37.584767416119576, 21.020918525755405, 17.138341963291168, 13.576337099075317, 4.782473249360919, 0.7403253181837499, 0.3374917450128123, 0.40213755739387125, 2.2978834714740515, 11.880964022129774, 34.10123594105244, 55.96596948802471, 48.97918559610844, 42.13946521282196, 30.54554633796215, 40.67164197564125, 50.690328776836395, 54.90747168660164, 57.62348614633083, 30.914307050406933, 4.408189533278346, 0.22977519925916567, 0.13863271102309227, 0.10368605304392986, 0.2100654787500389, 0.18311356951016933, 0.2099163070670329, 0.11235235637286678, 0.131358758371789, 0.11857874531415291, 0.047693400556454435, 0.11667981205391698, 0.09111229024711065, 0.2527219452895224, 0.18723933171713725, 0.19254920538514853, 0.08653642289573327, 0.157638207601849, 0.08000307425390929, 0.09100260082050227, 0.1813008589670062, 0.18955597537569702, 0.09604407678125426, 0.14570986095350236, 0.10308198194252327, 0.13062651094514877, 0.16190797614399344, 0.22257653006818146, 0.19970793218817562], [0.07306049796170555, 0.006030199883753085, 0.04639084232621826, 0.024329656589543447, 0.07788195682223886, 0.055093514602049254, 0.025603419489925727, 0.02278145675518317, 0.012830829764425289, 0.05396693813963793, 0.01265624416191713, 0.005402020578912925, 0.015550595981039805, 0.0343837352556875, 0.06516077381093055, 0.02958339606266236, 0.030005010157765355, 0.05471286705869716, 0.046037175561650656, 0.042458528332645074, 0.12076284139766358, 0.04611767260939814, 0.034469041420379654, 0.013972854030726012, 0.049714213018887676, 0.05365171833545901, 0.7269635726697743, 14.435038771480322, 41.712288334965706, 57.793439626693726, 55.257687494158745, 50.05702815949917, 38.07839132845402, 28.016639538109303, 27.795024029910564, 34.03713338077068, 33.2971078902483, 33.58464986085892, 16.64644505828619, 4.9850384797900915, 0.7262145378626883, 0.21723098878283054, 0.5686084949411452, 0.9718062845058739, 8.39834164828062, 7.721117762848735, 8.833985421806574, 12.290184013545513, 10.162884313613176, 9.610536452382803, 15.699226185679436, 30.06205078214407, 17.256538420915604, 20.94160918146372, 22.33863841742277, 33.187787756323814, 41.869702488183975, 53.26567478477955, 61.91390052437782, 57.89475359022617, 57.294157817959785, 58.474781066179276, 59.34842638671398, 58.55675406754017, 58.786607533693314, 60.32713986933231, 59.98286314308643, 57.01760485768318, 55.86132310330868, 51.289769411087036, 50.62938004732132, 48.95833611488342, 47.76287466287613, 46.07831485569477, 45.86674600839615, 50.189177468419075, 52.37993851304054, 49.70120385289192, 58.17232869565487, 57.850257977843285, 62.320262119174004, 57.94116050004959, 51.143458262085915, 44.074313789606094, 55.204315558075905, 52.10694596171379, 61.96744345128536, 45.916667729616165, 28.257320523262024, 51.35038375854492, 52.89600782096386, 59.44975934922695, 57.18833349645138, 57.00765319168568, 56.11160807311535, 58.83017219603062, 57.36143700778484, 58.224727883934975, 60.15432894229889, 58.86156231164932, 54.5303001254797, 46.74828730523586, 42.78112158179283, 48.35758835077286, 51.53557062149048, 55.77800117433071, 56.39461688697338, 60.25206349790096, 56.14349216222763, 56.66898116469383, 56.34194031357765, 58.47383111715317, 60.43747074902058, 56.20421290397644, 56.832520589232445, 57.05909863114357, 60.52191361784935, 56.510256081819534, 53.543884456157684, 55.33081077039242, 46.59797877073288, 28.884604163467884, 20.030013397336006, 14.09796740859747, 11.836072281002998, 13.367599099874496, 26.97833575308323, 8.436776585876942, 7.211336167529225, 5.7522111386060715, 5.037217754870653, 2.9221218125894666, 0.4642325488384813, 0.13872343115508556, 0.02515991945983842, 0.6363457383122295, 3.865686231292784, 21.897996962070465, 39.29805748164654, 38.23991306126118, 27.88587525486946, 27.846984341740608, 27.520684450864792, 34.85594004392624, 44.1555268317461, 48.870116248726845, 29.958743825554848, 6.60394256003201, 0.2589560451451689, 0.0960156079963781, 0.053641580598196015, 0.010507777660677675, 0.04412991911522113, 0.06288675911491737, 0.05350547071429901, 0.029150434529583436, 0.013633542257593945, 0.03829890934866853, 0.02197802808950655, 0.01076922979336814, 0.08370876603294164, 0.0952925112505909, 0.014233852525649127, 0.05273867260257248, 0.02579977135610534, 0.06795055145630613, 0.04925989618641324, 0.07917934228316881, 0.05140178262081463, 0.016710017116565723, 0.03559264187060762, 0.12418242782587186, 0.03127068921457976, 0.0331626277329633, 0.016367204261769075, 0.027144967825734057, 0.08333725432748906, 0.041679417990962975, 0.01605436860700138, 0.047999859307310544, 0.05742468580137938, 0.03805302840191871, 0.051570424548117444, 0.03739441315701697, 0.04577187261020299, 0.028062557357770856, 0.04819046509510372, 0.07646081823622808, 0.011304948166070972, 0.017634039213589858, 0.027384822533349507, 0.016233491514867637, 0.015582182713842485, 0.05643134340061806, 0.059148312648176216, 0.03808228015259374, 0.020834736606047954, 0.06897370592923835, 0.10013650913606398, 0.0732221377256792, 0.05490130577527452, 0.16279871662845835, 1.2084565171971917, 17.412615045905113, 49.965597465634346, 65.12879401445389, 60.56748457252979, 52.57769130170345, 41.1694722622633, 30.703859142959118, 28.398536145687103, 34.361225590109825, 35.1201930642128, 34.7143330425024, 20.51987551152706, 5.111323278397322, 0.9401202003937215, 0.18226542830234393, 0.9611496969591826, 4.890159945935011, 13.547048270702362, 9.481430780142546, 11.784338057041168, 14.623824041336775, 14.514616951346397, 13.342167064547539, 9.797146338969469, 10.491201896220446, 16.95409554988146, 21.60605862736702, 27.3517607152462, 37.266420498490334, 44.167397394776344, 52.79472425580025, 59.54408548772335, 60.14075607061386, 58.5861074924469, 59.75524015724659, 60.49219161272049, 61.60284921526909, 59.78316105902195, 62.28004887700081, 60.045567378401756, 59.70548562705517, 56.83533623814583, 53.72499033808708, 53.64892601966858, 51.31730653345585, 48.85259918868542, 45.80445595085621, 48.5118068754673, 52.10199862718582, 53.41285228729248, 51.685392782092094, 60.384140610694885, 61.445792242884636, 63.062453493475914, 58.99246908724308, 52.33090594410896, 51.235865503549576, 57.68315054476261, 53.94919730722904, 61.60930506885052, 48.03437389433384, 31.670681163668633, 53.542573526501656, 53.24199065566063, 60.730982199311256, 59.186323285102844, 58.591772988438606, 58.36793839931488, 60.366106778383255, 59.49417896568775, 59.16889362037182, 61.137666776776314, 60.92938095331192, 56.81184969842434, 50.38019321858883, 45.47974057495594, 51.117802038788795, 53.6146442592144, 58.36879335343838, 58.44073869287968, 61.38488911092281, 55.11629708111286, 56.49994723498821, 56.132544949650764, 59.63377587497234, 60.42629174888134, 58.586704060435295, 60.554736256599426, 60.23166239261627, 61.38089932501316, 59.101891815662384, 52.48811490833759, 46.20543323457241, 38.932520896196365, 25.152220241725445, 18.450280465185642, 14.181667417287827, 15.540345311164856, 19.3970737606287, 17.782988771796227, 17.34222572296858, 9.498439617455006, 8.340817485004663, 6.918379012495279, 4.193509602919221, 2.5429183105006814, 0.45940585783682764, 0.21392696216935292, 0.733572724275291, 3.8681641733273864, 23.19058120250702, 40.37168987095356, 36.84091553092003, 26.898551434278488, 30.0100676715374, 32.86660619080067, 40.889282897114754, 49.22636233270168, 56.12744562327862, 35.57282097637653, 8.057192154228687, 0.31268536986317486, 0.12951535260071978, 0.03644046766567044, 0.03262147220084444, 0.05706661439035088, 0.010524461140448693, 0.055149220206658356, 0.03110621630185051, 0.03409085038583726, 0.06458678937633522, 0.025859553206828423, 0.04429296153830364, 0.06006472773151472, 0.13264944223919883, 0.06289950921200216, 0.05277646647300571, 0.01626026634767186, 0.03558527976565529, 0.008132511757139582, 0.007177187262641382, 0.04014372891106177, 0.06611565811908804, 0.027236545138293877, 0.02774450069409795, 0.013951968139735982, 0.0363440701039508, 0.03334538530907594, 0.05249316272966098, 0.3436407056869939, 0.10777697141747922, 0.17440837022149935, 0.13525865535484627, 0.3043154877377674, 0.1283236563904211, 0.1322204660391435, 0.18387772928690538, 0.15861496300203726, 0.14506969921058044, 0.15638050477718934, 0.10975274664815515, 0.05399788198701572, 0.1299257157370448, 0.1805515866726637, 0.16820843884488568, 0.09521134998067282, 0.11610075875069015, 0.1448483907734044, 0.22584450314752758, 0.16292730113491416, 0.16655365732731298, 0.12840015697292984, 0.19336237659445032, 0.13354870257899165, 0.2299093350302428, 1.9577225181274116, 22.058848030865192, 58.85362073779106, 71.62511542439461, 66.95230096578598, 63.710463121533394, 52.09671691060066, 41.10435135662556, 40.1942165941, 48.32674540579319, 44.29268807172775, 42.34978772699833, 20.750194452703, 6.6921211034059525, 1.277778809890151, 0.894724273821339, 1.1456815106794238, 6.887695658951998, 19.772619009017944, 16.908602491021156, 21.16748236119747, 19.957190304994583, 25.595829337835312, 18.08440189808607, 24.502014331519604, 40.21820850670338, 25.83317220211029, 25.18761344254017, 25.83702329546213, 37.34775513410568, 44.56646718084812, 57.118014469742775, 63.713096380233765, 58.371681198477745, 59.17444512248039, 58.23970288038254, 60.92185355722904, 61.94917023181915, 60.909283831715584, 63.33484947681427, 63.16589154303074, 62.109578624367714, 60.53800195455551, 56.43394097685814, 55.204581543803215, 53.57937455177307, 51.9294460862875, 49.29953120648861, 50.24549424648285, 54.33054104447365, 56.51606597006321, 54.14593555033207, 64.10455897450447, 62.901741117239, 65.41634738445282, 61.09974101185799, 54.80544336140156, 54.44033995270729, 60.98719485104084, 56.41548916697502, 62.57332853972912, 52.368672117590904, 38.10537368059158, 53.08652199804783, 56.166872307658195, 60.76647609472275, 60.90410850942135, 60.4280586540699, 61.49963155388832, 62.573214545845985, 62.48883627355099, 60.68954922258854, 62.33598567545414, 62.82925620675087, 59.100915268063545, 51.294811740517616, 46.33311778306961, 52.03360989689827, 57.644711807370186, 61.37067027390003, 60.73798142373562, 64.0361550450325, 55.383665934205055, 56.75190411508083, 56.15930311381817, 60.78122690320015, 62.434818372130394, 61.3600954413414, 62.93118953704834, 62.60874643921852, 63.18468913435936, 59.75441940128803, 54.95758719742298, 61.01750582456589, 50.74368551373482, 35.47556519508362, 22.515720315277576, 23.17769229412079, 21.845286190509796, 20.526684746146202, 36.87120370566845, 22.59747862815857, 16.61048948764801, 15.935615301132202, 12.525183353573084, 6.174867209047079, 2.246541576460004, 0.3550502465805039, 0.24896805844036862, 0.958791864104569, 5.897617936134338, 26.430787034332752, 49.43951569497585, 48.83799657225609, 40.70850759744644, 40.09848453104496, 38.85756231844425, 48.532853946089745, 58.30586113035679, 64.56156805157661, 44.932288751006126, 10.632832646369934, 0.5038957705255598, 0.18354606349021196, 0.14620481408201158, 0.1662355728331022, 0.16244460828602314, 0.10732388283940963, 0.14389811520231888, 0.1039364017196931, 0.12457637465558946, 0.15537903585936874, 0.10793308218126185, 0.11770312237786129, 0.15214022918371484, 0.3245723492000252, 0.1431915460852906, 0.09022973565151915, 0.1299251220189035, 0.1057991998095531, 0.14711477619130164, 0.13316746131749824, 0.09204105837852694, 0.09470476739807054, 0.09261963670724072, 0.1322152413194999, 0.08547961944714189, 0.13076852832455188, 0.08225805286201648, 0.10892096237512305], [0.07241550483740866, 0.012892220220237505, 0.05954459724307526, 0.10234269153443165, 0.0490971914405236, 0.0433103134855628, 0.05082475909148343, 0.01294751114983228, 0.01717516002827324, 0.0034429411198289017, 0.002309687879460398, 0.02710490854951786, 0.016545408761885483, 0.04053026539622806, 0.05808603957120795, 0.041525964115862735, 0.03788083529798314, 0.09786994560272433, 0.011496358256408712, 0.002127498974004993, 0.047473765662289225, 0.011289283283986151, 0.040112495626090094, 0.02860685588530032, 0.028957631984667387, 0.05086572564323433, 2.1736327512189746, 25.60867264866829, 49.823207706213, 57.13901974260807, 48.25827307999134, 38.40259753167629, 35.48554725944996, 25.707317255437374, 20.044522918760777, 31.02430734783411, 48.128080666065216, 22.163253128528595, 12.73990223184228, 1.5043264534324408, 0.27979516598861665, 0.12042765782098286, 2.8525845939293504, 3.3956820890307426, 6.7429647501558065, 4.406993547454476, 14.568423964083195, 11.30126427859068, 9.947107192128897, 5.107998456805944, 8.742268793284893, 12.878103666007519, 16.52122277766466, 31.308355405926704, 42.136296182870865, 46.51752948760986, 50.599509850144386, 56.70818746089935, 58.243654668331146, 60.746929943561554, 55.60948021709919, 58.42482514679432, 56.440617218613625, 59.128304198384285, 60.19222430884838, 58.89580987393856, 56.562453880906105, 54.08386968076229, 51.041312143206596, 49.85460162162781, 50.389700308442116, 47.51410201191902, 44.992811903357506, 43.51879499852657, 46.13734848797321, 50.23211136460304, 49.986538141965866, 50.8906464278698, 55.61295323073864, 58.46199095249176, 60.070433244109154, 54.45311486721039, 63.29629674553871, 48.557636216282845, 59.37764301896095, 53.65804173052311, 53.168369606137276, 49.93781715631485, 29.921610318124294, 48.91244977712631, 53.73702809214592, 56.72689385712147, 59.23252500593662, 58.43563176691532, 53.404572531580925, 53.65159347653389, 56.599129512906075, 57.913919761776924, 56.146068423986435, 57.48780682682991, 53.533526211977005, 45.72687551379204, 43.63934352993965, 46.73172779381275, 47.03457534313202, 52.07775592803955, 55.59974893927574, 57.279836386442184, 55.65294608473778, 55.57680957019329, 56.45026870071888, 56.340192407369614, 59.691145196557045, 60.6870261579752, 59.38849903643131, 58.66203501820564, 58.912715166807175, 60.8659091591835, 55.61696581542492, 50.1840515434742, 44.13971588015556, 40.85268326103687, 33.709313571453094, 28.25064428150654, 11.80208120495081, 20.710290893912315, 8.500995989888906, 12.538511138409376, 9.337557200342417, 5.2200843673199415, 0.9455238666851074, 5.498210918158293, 4.664834886789322, 0.5764698574785143, 0.13102333730785176, 0.11827101378003135, 1.7918345821090043, 8.692503813654184, 24.137321300804615, 49.133358523249626, 44.335891753435135, 32.026870250701904, 26.86561670154333, 32.153639048337936, 45.91067165136337, 51.30494959652424, 37.66911908984184, 12.609120849519968, 0.6544422078877687, 0.013061223944532685, 0.0139032517108717, 0.02021031395997852, 0.018776620090648066, 0.03684926115965936, 0.049055950294132344, 0.08728420347324573, 0.03127981020952575, 0.04071390983881429, 0.02963340753922239, 0.0956932561530266, 0.06701002028421499, 0.07545127475168556, 0.023849620629334822, 0.021084923864691518, 0.050001290583168156, 0.060778992919949815, 0.028704806391033344, 0.07636687718331814, 0.0014106863636698108, 0.07582194783026353, 0.021291326265782118, 0.04673669427575078, 0.06129888592113275, 0.026422513037687168, 0.05159768363228068, 0.026406516044517048, 0.05193353514187038, 0.0520097091794014, 0.02432520926959114, 0.030833877790428232, 0.04746810678625479, 0.015709700383013114, 0.04104757201275788, 0.027272197912679985, 0.03080637936363928, 0.009065333870239556, 0.05336937938409392, 0.020026179699925706, 0.03229044465115294, 0.06554765539476648, 0.018228310254926328, 0.04079336787981447, 0.014421839459828334, 0.08498188326484524, 0.05696660256944597, 0.08783483252045698, 0.02942386214272119, 0.016902424467843957, 0.0551834925863659, 0.01428988096449757, 0.06611024044104852, 0.0313678623206215, 2.547456929460168, 28.84368985891342, 56.32099963724613, 64.49368089437485, 55.82181662321091, 44.59677055478096, 42.897885516285896, 28.953663557767868, 22.553207203745842, 31.314803659915924, 46.377412006258965, 27.870947755873203, 12.586031388491392, 2.2141039045527577, 0.37951950856950134, 0.32178208173718303, 2.8555983072146773, 5.071965465322137, 11.457382701337337, 10.189799219369888, 11.82806896045804, 18.887371011078358, 13.227042742073536, 14.264008048921824, 9.915967863053083, 8.786510769277811, 16.051733270287514, 27.116838321089745, 37.9711876809597, 42.540632486343384, 51.263528019189835, 56.207381933927536, 59.37821678817272, 61.216421350836754, 56.34303465485573, 58.489273488521576, 57.92531915009022, 60.346564427018166, 62.50820763409138, 61.70651525259018, 61.427526623010635, 57.36775986850262, 52.91651912033558, 51.341982409358025, 52.68943950533867, 49.15562152862549, 48.331662341952324, 46.60504639148712, 48.53396348655224, 51.97791628539562, 54.148796796798706, 55.15873700380325, 58.267749175429344, 61.06452450156212, 61.98404096066952, 57.30140782892704, 60.84462650120258, 50.23561857640743, 61.38966165482998, 54.30961176753044, 53.89355309307575, 52.10760332643986, 35.15441782772541, 51.18697352707386, 54.09646600484848, 56.494897305965424, 60.44277526438236, 59.18812058866024, 55.34006707370281, 56.419942528009415, 58.60753454267979, 58.5857655107975, 56.71321839094162, 59.22103062272072, 56.75185091793537, 47.97713756561279, 45.179142504930496, 48.32288481295109, 50.81931285560131, 54.00553308427334, 57.96697251498699, 59.684997126460075, 56.20954021811485, 56.075152829289436, 56.83636978268623, 55.105494260787964, 60.12871831655502, 61.47882007062435, 61.08402505517006, 60.47323822975159, 63.20714212954044, 61.73472873866558, 58.74169774353504, 51.13859832286835, 44.10747841000557, 34.52011026442051, 25.373290479183197, 17.360297553241253, 15.262313280254602, 16.613519825041294, 10.9798632748425, 9.39226096495986, 9.978768043220043, 11.591013930737972, 6.1312631238251925, 5.009453119710088, 2.6181381242349744, 1.041928434278816, 0.1235187919519376, 0.16859019960975274, 1.9252423360012472, 11.392728220671415, 25.573792420327663, 45.57938642799854, 44.454992562532425, 34.344194903969765, 30.81254281103611, 37.88824573159218, 51.27655752003193, 58.437744453549385, 44.077342227101326, 14.874550737440586, 0.9678977786097676, 0.06065161440346856, 0.040879074804252014, 0.07529442926170304, 0.011796681301348144, 0.019329039569129236, 0.038089482695795596, 0.041373014901182614, 0.03743003253475763, 0.033415444049751386, 0.04263335977157112, 0.05510387498361524, 0.012541884771053446, 0.0003923634170632795, 0.12161709048086777, 0.10079314655740745, 0.03153339464915916, 0.02199127913627308, 0.0920130497252103, 0.030213349564292002, 0.03332493542984594, 0.023638718957954552, 0.08938881554058753, 0.049569776238058694, 0.0314397467445815, 0.022679062640236225, 0.04854292958043516, 0.025989493988163304, 0.16786014894023538, 0.280087809660472, 0.08994832809548825, 0.2557833935134113, 0.14541871641995385, 0.1727941693388857, 0.1955238965456374, 0.16811981156934053, 0.11321653539198451, 0.07736798987025395, 0.1381050143390894, 0.08974897238658741, 0.11990627681370825, 0.10980929087963887, 0.16225292638409883, 0.14556837792042643, 0.13144282886059955, 0.14730366761796176, 0.20340936403954402, 0.12874625012045726, 0.1637994879274629, 0.12924096576170996, 0.14230090950150043, 0.14173007919453084, 0.12320555368205532, 0.2167922756052576, 4.554150151088834, 36.96302577853203, 65.4885283112526, 71.34613439440727, 61.7400598526001, 51.64066158235073, 48.6160808801651, 38.814157247543335, 32.87352181971073, 43.43873329460621, 62.310960218310356, 30.939273610711098, 16.69112306088209, 2.378627951256931, 0.49756263848394156, 0.36857927218079567, 5.759669663384557, 6.899858806282282, 16.71949803829193, 19.865265637636185, 28.541279286146164, 24.868869446218014, 14.503836929798126, 16.661273762583733, 17.09764614701271, 18.153075613081455, 23.424910828471184, 34.737257212400436, 43.83842244744301, 48.224234506487846, 52.91064843535423, 57.945872247219086, 59.53466959297657, 62.91304171085358, 56.652433052659035, 58.37183699011803, 58.28800588846207, 61.4738879352808, 65.00020891427994, 64.754498898983, 61.83661267161369, 59.54588279128075, 54.810698479413986, 53.927667662501335, 55.25853484869003, 51.6216854006052, 48.87357026338577, 48.64796116948128, 50.502592250704765, 54.44203846156597, 55.52216090261936, 57.510286420583725, 59.419604167342186, 64.10917952656746, 65.20008578896523, 57.96589337289333, 61.9388347864151, 52.91711188852787, 59.52342599630356, 56.96989081799984, 55.85005670785904, 56.0210095345974, 41.27528138458729, 55.21470420062542, 55.585267916321754, 58.139688447117805, 64.64995890855789, 64.04212832450867, 58.20409879088402, 59.33306381106377, 60.740550085902214, 61.16246424615383, 59.93406616151333, 62.2372517734766, 58.35673660039902, 50.52125684916973, 47.77624234557152, 51.201177164912224, 53.088140711188316, 57.86084420979023, 60.39271295070648, 61.77363485097885, 57.33931079506874, 57.23151057958603, 58.42659965157509, 56.85269370675087, 61.254616901278496, 63.88083457946777, 62.62292727828026, 64.07295987010002, 65.69421127438545, 64.60442215204239, 58.94323132932186, 52.59222932159901, 52.50967875123024, 42.93833054602146, 37.80044384300709, 34.02204819023609, 17.269851006567478, 34.549125507473946, 18.758533224463463, 18.267158791422844, 20.56414693593979, 14.316547829657793, 10.17028346657753, 12.643377911299467, 6.1246890015900135, 0.9927140094805509, 0.6626308872364461, 0.3422767570009455, 2.777079320512712, 11.250031627714634, 31.90890558063984, 63.41706566512585, 56.82364046573639, 43.16777363419533, 38.25095906853676, 44.67866376042366, 60.59466451406479, 64.249247610569, 52.85614416003227, 19.285186864435673, 1.9816366536542773, 0.15914681571302935, 0.20202902873279527, 0.1511613215552643, 0.08053992904024199, 0.1559363293927163, 0.11771086297812872, 0.14254500187234953, 0.10889487588428892, 0.10200486591202207, 0.0732594083820004, 0.18953391874674708, 0.13749369245488197, 0.148604222049471, 0.12368190116831101, 0.21871411154279485, 0.10920494518359192, 0.10416737291961908, 0.20648892066674307, 0.0942405837122351, 0.11498021223815158, 0.1717141069821082, 0.1829847920453176, 0.14819097938016057, 0.2901640080381185, 0.1587452692911029, 0.18749657494481653, 0.07052515080431476], [0.054900630420888774, 0.056450453703291714, 0.06737249263096601, 0.016769288740761112, 0.0101800869924773, 0.08520917341229506, 0.05033021043345798, 0.0895968172699213, 0.04481904034037143, 0.048900581678026356, 0.057846503987093456, 0.044713217503158376, 0.05180575215490535, 0.06135716677817982, 0.043656195121002384, 0.015681355907872785, 0.023159953925642185, 0.017958636053663213, 0.03509725458570756, 0.05905069425352849, 0.045524563029175624, 0.07652236454305239, 0.09004600957268849, 0.036157998838461936, 0.024792159310891293, 0.021212452666077297, 3.2145588705316186, 26.75045058131218, 47.116628140211105, 56.66774623095989, 51.69203482568264, 33.594115152955055, 16.765473671257496, 23.879858516156673, 23.963492028415203, 41.270030066370964, 32.05272026360035, 17.477101385593414, 6.028570784255862, 0.414303703000769, 0.3423570276936516, 0.17411710694432259, 1.155540319159627, 4.9152034521102905, 14.359866455197334, 8.789609503000975, 4.59884287789464, 15.68917477503419, 13.265536576509476, 18.858230374753475, 7.97418275848031, 9.730466566979885, 28.109058178961277, 39.01862047612667, 47.572193294763565, 50.55244937539101, 54.713343903422356, 55.647652968764305, 57.36060485243797, 56.429468616843224, 57.34617702662945, 56.263960897922516, 60.2526942640543, 59.144761115312576, 58.29775236546993, 54.05554600059986, 52.39819273352623, 48.841963559389114, 48.60258400440216, 47.614101245999336, 47.31658101081848, 48.52146975696087, 47.22907170653343, 41.11501358449459, 45.62137417495251, 46.574891209602356, 47.88921408355236, 48.07805635035038, 54.75744053721428, 58.41224402189255, 58.48120652139187, 57.702027931809425, 59.78617049753666, 59.26404431462288, 52.88157619535923, 52.552996426820755, 54.771723970770836, 47.64145977795124, 33.962505385279655, 53.83435606956482, 52.0018246024847, 59.27389718592167, 55.241378769278526, 54.94365334510803, 48.367969393730164, 46.03471599519253, 52.471240013837814, 58.64231787621975, 59.18079078197479, 59.14352998137474, 50.82090876996517, 41.353663578629494, 41.45927131175995, 45.4390599578619, 47.728501707315445, 50.33615358173847, 54.45956312119961, 56.57142899930477, 54.7037760168314, 54.645950719714165, 53.725628703832626, 53.30043911933899, 55.63039809465408, 55.988566875457764, 58.33653308451176, 61.29705682396889, 61.76898010075092, 57.158755883574486, 58.42520132660866, 55.255149230360985, 51.02765567600727, 40.396073162555695, 31.57205555588007, 20.726126544177532, 30.368454940617085, 23.109029978513718, 13.841527719050646, 16.412989385426044, 6.626733262091875, 8.620793111622334, 6.292898375540972, 2.363704014569521, 1.8673156318254769, 2.067050845362246, 0.3297797025879845, 0.11895183779415675, 0.18453260039677843, 7.0808150712400675, 29.32995356619358, 50.40999881923199, 29.978652857244015, 30.601650327444077, 25.707283057272434, 27.768474854528904, 39.99564304947853, 52.62851357460022, 48.520960584282875, 16.651295498013496, 2.181863822042942, 0.044693250019918196, 0.012931686705996981, 0.029034410872554872, 0.10613584541715682, 0.03459857216512319, 0.04330808333179448, 0.03255609641200863, 0.053026915338705294, 0.028505235459306277, 0.045659600509679876, 0.05378381691116374, 0.02363293391681509, 0.02864141955797095, 0.07307464329642244, 0.013537785725930007, 0.029384984736680053, 0.043131363127031364, 0.03462724132987205, 0.025166752784571145, 0.05058618829934858, 0.024121951719280332, 0.016646775002300274, 0.07328312000026926, 0.054018179725972004, 0.07103145879227668, 0.024965204029285815, 0.07276324555277824, 0.07007100095506757, 0.014973335892136674, 0.05873499576409813, 0.02109990040480625, 0.019198328809579834, 0.09093020431464538, 0.049095083741121925, 0.03543701350281481, 0.0019075032105320133, 0.05068183258117642, 0.030510447977576405, 0.03719123167684302, 0.06119570884038694, 0.05935399887675885, 0.025737499599927105, 0.05574714261456393, 0.056666118107386865, 0.016266572747554164, 0.06923437787918374, 0.009534126293146983, 0.023431997433362994, 0.036414700298337266, 0.02389154084085021, 0.07121606060536578, 0.030034081937628798, 0.02559247466706438, 4.570113094523549, 32.80342698097229, 55.205223709344864, 65.38504466414452, 55.89760735630989, 40.887132212519646, 24.38035435974598, 28.07429764419794, 24.302340745925903, 40.68772651255131, 34.938824996352196, 15.89832790195942, 6.2405371852219105, 0.5647327029146254, 0.27757225558161736, 1.1057897075079381, 2.8956733318045735, 4.4902527797967196, 8.912784643471241, 14.108053967356682, 9.987926501780748, 23.78030765801668, 18.788173533976078, 18.22456117719412, 10.461853221058846, 11.485052816569805, 28.248153515160084, 34.7565221786499, 44.10963289439678, 50.95253750681877, 54.77930836379528, 56.69957332313061, 57.90104225277901, 58.110806196928024, 58.23733940720558, 58.51389616727829, 60.4435770213604, 60.66336862742901, 61.089827343821526, 58.426398262381554, 54.36021365225315, 51.196985989809036, 51.883118972182274, 50.64286932349205, 50.15591025352478, 50.9060849994421, 50.12393496930599, 44.60043355822563, 47.41483233869076, 48.94510142505169, 49.6233194321394, 50.653223767876625, 59.253279492259026, 61.00335918366909, 59.97155115008354, 58.91884043812752, 60.587346106767654, 58.89736399054527, 53.29971335828304, 53.25280487537384, 54.76913630962372, 48.58790539205074, 39.21122834086418, 54.597320929169655, 51.38126090168953, 59.91907976567745, 57.29327246546745, 55.97921557724476, 48.79345916211605, 47.87884443998337, 54.996143728494644, 62.11755059659481, 60.62995322048664, 62.4319913238287, 52.87543572485447, 44.22410175204277, 44.410128369927406, 48.4347166121006, 51.66289798915386, 52.00396008789539, 55.03367431461811, 59.418950602412224, 56.754966750741005, 55.487468764185905, 54.23603251576424, 54.66319799423218, 57.16732822358608, 57.90842525660992, 60.274250507354736, 63.055724054574966, 63.72009180486202, 59.9139728397131, 59.612056240439415, 57.34031394124031, 49.3357964605093, 37.99720108509064, 31.523144580423832, 18.241418972611427, 15.761975068598986, 14.879698511213064, 14.573425445705652, 15.508344378322363, 15.946499817073345, 16.52698516845703, 7.289160741493106, 8.40922236442566, 4.886984741315246, 1.8148074368946254, 0.29683012689929456, 0.29880480375140905, 0.2707896789070219, 5.857769474387169, 25.592004843056202, 54.72841389477253, 40.77980697154999, 35.16552083194256, 32.052750661969185, 32.42207944393158, 46.93612642586231, 59.35829445719719, 54.90397967398167, 19.84168980270624, 2.8728424943983555, 0.0486244545027148, 0.04689424851676449, 0.009439251061849063, 0.06132849390269257, 0.04667696623073425, 0.09304012273787521, 0.021530260710278526, 0.07885843762778677, 0.04813801380805671, 0.07994704952579923, 0.0239542430426809, 0.0943591418035794, 0.056810183814377524, 0.07731128236628138, 0.021740509291703347, 0.03132673620712012, 0.05213827142142691, 0.01767284054949414, 0.042865173309110105, 0.07920102041680366, 0.06371074341586791, 0.05295078211929649, 0.0384525339177344, 0.061011912257527, 0.11651165623334236, 0.046385417226701975, 0.04614552541170269, 0.13926487241405994, 0.22631161089520901, 0.1608904916793108, 0.15660389122786, 0.18747609166894108, 0.17008711147354916, 0.12759464472765103, 0.18444112327415496, 0.16746577166486531, 0.1594551929156296, 0.15981506032403558, 0.14018923218827695, 0.2524005062878132, 0.17418740317225456, 0.11816832280601375, 0.14388751733349636, 0.1397145100054331, 0.13368657877435908, 0.13005099026486278, 0.2070198828005232, 0.0502463477459969, 0.12740426900563762, 0.2229936170624569, 0.10800994641613215, 0.10679559243726544, 0.19697670999448746, 6.390634831041098, 38.08070920407772, 63.32628473639488, 70.7209387421608, 64.16569769382477, 46.50086738169193, 27.55762416869402, 35.41028089821339, 33.99502784013748, 54.029593393206596, 41.84882640838623, 21.741774044930935, 7.263164911419153, 0.8834265300538391, 0.8641613856889307, 1.4624280016869307, 3.5259269876405597, 9.879409074783325, 23.593798466026783, 16.981163397431374, 15.704955328255892, 30.074761100113392, 26.533923000097275, 28.120596259832382, 12.536948472261429, 16.087242364883423, 35.23820333182812, 42.11363419890404, 48.78193438053131, 52.54449248313904, 55.979648754000664, 57.082847356796265, 58.203574419021606, 57.852598652243614, 58.97217057645321, 58.73555347323418, 63.48864242434502, 62.994547337293625, 62.37705007195473, 60.33010371029377, 57.14994415640831, 53.61019469797611, 54.28787313401699, 53.65234203636646, 52.24026180803776, 53.98152977228165, 51.854145526885986, 45.87843418121338, 49.69265051186085, 51.986743211746216, 51.95366218686104, 52.95270077884197, 59.930057376623154, 64.09242242574692, 63.335556238889694, 62.97184355556965, 63.392838165163994, 59.06909577548504, 54.79612626135349, 52.139388620853424, 56.73173859715462, 51.70376859605312, 44.13929030299187, 57.38728702068329, 51.77348345518112, 62.372520714998245, 60.65809451043606, 60.08335255086422, 51.59751869738102, 50.306040197610855, 56.796452924609184, 64.39335107803345, 63.22865657508373, 65.50831764936447, 54.72902186214924, 45.22846765816212, 46.106684133410454, 50.01947097480297, 54.699280858039856, 55.209563076496124, 59.444359838962555, 61.156688556075096, 57.680350095033646, 57.621848434209824, 54.26577731966972, 55.71610629558563, 58.90642270445824, 60.26759326457977, 62.6684108376503, 65.55623307824135, 65.92443332076073, 62.68593929708004, 61.80065140128136, 57.93992176651955, 51.54048375785351, 43.24232183396816, 39.78328764438629, 26.06971900910139, 39.92276296019554, 33.48098762333393, 23.038515262305737, 27.44686011224985, 17.036507427692413, 16.25087298452854, 19.016493782401085, 14.090294670313597, 5.877741677686572, 4.84649458900094, 0.6151185929775238, 0.4257747234078124, 0.5147359357215464, 8.679005987942219, 34.51998867094517, 57.84129045903683, 40.81350356340408, 42.02481396496296, 37.50509709119797, 40.803335309028625, 53.46314258873463, 66.77569404244423, 63.599809259176254, 26.051413491368294, 4.361195079982281, 0.1850829622708261, 0.2256275140098296, 0.10843242140254006, 0.15890460839727893, 0.09930947460816242, 0.17199140304001048, 0.08824520307825878, 0.2220192365348339, 0.10856504319235682, 0.23305325070396066, 0.20388076140079647, 0.2401404789998196, 0.19375660544028506, 0.17511280195321888, 0.1085200319357682, 0.131173518311698, 0.0849635670601856, 0.09375791312777437, 0.1837689898093231, 0.09175067083560862, 0.1176360173849389, 0.18628059566253796, 0.19746305420994759, 0.1556122928741388, 0.14325047261081636, 0.13624146668007597, 0.12069356191204861], [0.0425590670784004, 0.027760570046666544, 0.07048457016935572, 0.09595150128006935, 0.05236982891801745, 0.022227781191759277, 0.013923920523666311, 0.07136248634196818, 0.07445651484886184, 0.035579045725171454, 0.03784942760830745, 0.07647999533219263, 0.008609415854152758, 0.07368813225184567, 0.07686735931201838, 0.10662335480446927, 0.018891526815423276, 0.030764499970246106, 0.05093155414215289, 0.06386636436218396, 0.034826626724679954, 0.0120112380500359, 0.010677633927116403, 0.008836746819724794, 0.09828805676079355, 0.6576179468538612, 6.880882624536753, 34.69257541000843, 59.797262102365494, 53.70306171476841, 45.876526683568954, 27.643208876252174, 20.420330353081226, 15.022588893771172, 25.522713661193848, 28.75269614160061, 34.169088900089264, 13.404006846249104, 1.7691216571256518, 0.16183448868105188, 0.1441150004393421, 0.5061321286484599, 4.283341057598591, 3.9376296708360314, 4.4769800920039415, 6.682713758200407, 8.303717225790024, 17.907035015523434, 15.143968630582094, 21.283541433513165, 16.0867502912879, 15.901689771562815, 28.932240307331085, 36.59166790544987, 50.22300325334072, 54.77751486003399, 56.145658046007156, 55.65448500216007, 58.422678261995316, 58.823412358760834, 54.000099375844, 61.13149970769882, 58.79238322377205, 57.127274572849274, 55.39271704852581, 50.681779235601425, 49.36483830213547, 47.697673961520195, 48.20926330983639, 49.64050970971584, 50.71296036243439, 50.86026705801487, 49.65663604438305, 42.52687342464924, 45.9913033246994, 43.509363904595375, 48.4194528311491, 45.989221036434174, 46.57127000391483, 51.914110109210014, 56.5362086892128, 55.964453369379044, 57.432664185762405, 54.58174556493759, 56.2791258841753, 52.742328867316246, 57.641417384147644, 41.363208666443825, 33.77542242407799, 51.83035500347614, 55.273825228214264, 62.14183509349823, 54.29263047873974, 54.18980799615383, 47.653596326708794, 44.12428870797157, 45.30849136412144, 48.52134436368942, 51.59425087273121, 48.77303905785084, 44.53982301056385, 44.259736239910126, 47.222942635416985, 46.29327692091465, 47.01907977461815, 46.68197326362133, 52.33327701687813, 54.118862003088, 58.155632391572, 55.10538026690483, 53.936380594968796, 52.65928812325001, 52.94545456767082, 47.96862982213497, 50.72896130383015, 53.536672443151474, 58.658220022916794, 62.8544070571661, 61.73247165977955, 56.749992817640305, 57.67380304634571, 44.88359056413174, 34.99582193791866, 30.060376971960068, 28.330958671867847, 6.963827898725867, 7.017652960494161, 6.136473119258881, 10.722651276737452, 18.674696423113346, 3.475748305208981, 5.224139699712396, 3.1517363665625453, 1.2091039074584842, 0.17381770972860977, 0.12476021947804838, 0.11108293503639288, 3.2371930684894323, 14.777806978672743, 27.948906272649765, 30.80114722251892, 29.004143849015236, 17.496643736958504, 16.629193983972073, 27.922820672392845, 40.93829266726971, 47.06007197499275, 25.287692472338676, 3.781594606116414, 0.42794221022631973, 0.07347853490500711, 0.066558215621626, 0.058611773274606094, 0.03345192060805857, 0.06142315483884886, 0.0065808609360829, 0.03957820124924183, 0.028151885962870438, 0.021326081041479483, 0.0732036582485307, 0.06135915944469161, 0.028431664504751097, 0.05698481487343088, 0.06854355713585392, 0.01703658064798219, 0.01604389133717632, 0.03011915432580281, 0.02279536460264353, 0.007254298725456465, 0.014286791774793528, 0.03958151122787967, 0.01471096720706555, 0.013658074876730097, 0.03094672691076994, 0.04150298722379375, 0.023668454959988594, 0.051744306038017385, 0.03377564913535025, 0.030425908080360387, 0.04339804647315759, 0.03848490639938973, 0.09029839173308574, 0.055335985380224884, 0.0466267599404091, 0.1566895647556521, 0.012682102442340693, 0.0246896872704383, 0.07392167128273286, 0.026934361158055253, 0.017060004684026353, 0.04256203937984537, 0.07940578638226725, 0.012482296806410886, 0.011467136191640748, 0.06471857996075414, 0.031809295469429344, 0.10598469219985418, 0.004817923918380984, 0.0711684073030483, 0.027304700270178728, 0.059292827354511246, 0.6312411872204393, 7.33375989831984, 40.097219198942184, 66.33383855223656, 59.48836527764797, 52.552627846598625, 31.268225759267807, 20.71472715586424, 18.020312637090683, 26.65543667972088, 33.3543062210083, 30.044408328831196, 15.141491163522005, 1.7767857271246612, 0.15320109960157424, 0.431847064755857, 1.8781214207410812, 6.331521878018975, 10.267148818820715, 9.764468092471361, 14.048267975449562, 10.091075766831636, 10.095117799937725, 16.93280339241028, 20.31780045479536, 14.065959826111794, 19.34803169220686, 31.29353430122137, 35.15969954431057, 52.11356520652771, 55.03436207771301, 56.74545966088772, 55.716151893138885, 58.69833067059517, 58.56411427259445, 55.06378769874573, 60.94144530594349, 60.98627530038357, 59.2783809453249, 58.442513197660446, 52.51655638217926, 52.71641805768013, 49.826832711696625, 49.897166937589645, 50.92695727944374, 52.72053703665733, 51.87586136162281, 51.772655099630356, 44.76404517889023, 47.52817265689373, 45.87421640753746, 49.51146103441715, 46.75863794982433, 48.751171231269836, 54.11499761044979, 57.665591686964035, 59.379026144742966, 60.469807013869286, 56.376883238554, 55.46952232718468, 53.309311643242836, 59.45721834897995, 44.69247221946716, 37.88221925497055, 52.57430948317051, 56.27653822302818, 63.03587391972542, 56.77950203418732, 56.53263308107853, 49.38413366675377, 46.73536419868469, 47.14910879731178, 51.46625094115734, 54.40937541425228, 52.45774693787098, 48.630371913313866, 44.86664727330208, 47.97338716685772, 48.562146574258804, 48.77227529883385, 50.6960778683424, 55.17762579023838, 55.785148590803146, 59.31355945765972, 57.3511927574873, 54.678750559687614, 52.92001113295555, 53.739038184285164, 51.921192929148674, 54.2670426517725, 56.17297478020191, 60.11251978576183, 63.723249435424805, 62.89961323142052, 61.04816637933254, 58.837623596191406, 45.64079873263836, 34.66257601976395, 30.127751156687737, 17.40393441170454, 10.804021060466766, 9.568163026124239, 8.938630856573582, 13.477568998932838, 15.2741021476686, 9.029743317514658, 7.971445005387068, 5.283554261550307, 2.8692032396793365, 0.35814464616123587, 0.2178516171989031, 0.23019987100269645, 3.404082488268614, 18.127865865826607, 32.75334186851978, 34.01370383799076, 29.73555140197277, 21.148219294846058, 21.153799295425415, 33.78618724644184, 47.07578793168068, 54.45112757384777, 29.504765085875988, 4.972253115847707, 0.34464696887880564, 0.05733566518756561, 0.04822862261789851, 0.01630945404031081, 0.02682058806385612, 0.016470132723043207, 0.08197791437851265, 0.028425955533748493, 0.06022959954862017, 0.01873650515335612, 0.12776585819665343, 0.05121114714711439, 0.027355869497114327, 0.018197067693108693, 0.007694899741181871, 0.06011550547555089, 0.03425276845518965, 0.0319385998591315, 0.041605444421293214, 0.01239773000634159, 0.049848226335598156, 0.13182717229938135, 0.039678161119809374, 0.043579976554610766, 0.045682781492359936, 0.039734323145239614, 0.0384600592951756, 0.14876298228045925, 0.08441522382781841, 0.08011013647774234, 0.16594270651694387, 0.1823805205640383, 0.1728791304049082, 0.11585897445911542, 0.11346281709847972, 0.19892602023901418, 0.1631137731601484, 0.14063392707612365, 0.1945153475389816, 0.15004971792222932, 0.2623437118018046, 0.1251905018580146, 0.24477801140164956, 0.13018794619711116, 0.15033551899250597, 0.10789441628730856, 0.12753421906381845, 0.23804909200407565, 0.09072089640540071, 0.13247272203443572, 0.18512781767640263, 0.23994440358364955, 1.0677294060587883, 11.857107002288103, 49.565425738692284, 76.20247900485992, 66.42744272947311, 59.46771718561649, 38.78516100347042, 30.56056883186102, 25.211022086441517, 36.365675032138824, 39.02325242757797, 40.78207165002823, 17.120955996215343, 2.577520916238427, 0.3814644698286429, 0.3713820967823267, 2.180080055259168, 9.406608045101166, 13.283190429210663, 13.344073612242937, 18.32031413912773, 16.002351120114326, 32.76174321770668, 25.805566683411598, 29.470950700342655, 23.5517955198884, 19.946642071008682, 32.49606907367706, 37.422250136733055, 52.396129444241524, 57.78440371155739, 57.162099704146385, 57.03508011996746, 58.308954164385796, 61.402504965662956, 56.84895470738411, 64.47317719459534, 62.951362654566765, 62.19567060470581, 60.793306455016136, 54.618535190820694, 55.31798645853996, 52.829332798719406, 52.622627690434456, 54.42659609019756, 55.52944891154766, 54.35438096523285, 54.407604709267616, 46.63256071507931, 50.000130012631416, 47.91800893843174, 52.08499073982239, 49.76820185780525, 49.54978957772255, 57.662916630506516, 60.88678143918514, 60.109468549489975, 62.79217779636383, 55.721931383013725, 55.66035568714142, 53.53215828537941, 59.26105387508869, 46.87931187450886, 38.39704982936382, 57.87408649921417, 55.74112415313721, 65.55399879813194, 59.917119070887566, 59.36652481555939, 50.76376363635063, 49.050933346152306, 49.663407281041145, 52.51989260315895, 55.88574059307575, 52.34187975525856, 49.253538474440575, 48.76733176410198, 50.64138740301132, 50.92540696263313, 51.84552378952503, 52.35284596681595, 58.17818038165569, 56.856257915496826, 61.41761675477028, 58.32446873188019, 55.51821291446686, 53.678207248449326, 54.73103955388069, 51.48808836936951, 56.841438710689545, 59.64153125882149, 63.46338137984276, 66.09014242887497, 67.25928649306297, 62.375359162688255, 65.12675732374191, 51.08682610094547, 43.68897266685963, 39.93754796683788, 35.35771831870079, 12.724724896252155, 15.21273734048009, 14.745781347155571, 22.852045968174934, 31.744600497186184, 11.64437161758542, 13.806685488671064, 9.300606083124876, 3.447960396297276, 0.2707588055636734, 0.3661116905277595, 0.5149104888550937, 4.046651758253574, 17.839543037116528, 36.32227376103401, 46.96232222020626, 38.73509868979454, 27.813126258552074, 26.932377219200134, 40.695098116993904, 55.63302755355835, 60.36342412233353, 37.79173471033573, 6.237384779378772, 0.7546122546773404, 0.27782734658103436, 0.2706336497794837, 0.10877335662371479, 0.1500813927850686, 0.14449658308876678, 0.16942654066951945, 0.08007622032891959, 0.17524279654026031, 0.11990401326329447, 0.21780425333417952, 0.3306144999805838, 0.15031604503747076, 0.17216570384334773, 0.20923911215504631, 0.15225742914481089, 0.07234085220261477, 0.11221983106224798, 0.12480503035476431, 0.10549370213993825, 0.13044541206909344, 0.24283745849970728, 0.11206958326511085, 0.1488712170976214, 0.07803470565704629, 0.10134457712410949, 0.11997373803751543], [0.02123703630786622, 0.029243642711662687, 0.05605490383459255, 0.040127230968209915, 0.052380419365363196, 0.024566331194364466, 0.021276872939779423, 0.08681031249579974, 0.03897541777405422, 0.06569624078110792, 0.054676327417837456, 0.05085403310658876, 0.04549655437585898, 0.03592540233512409, 0.013170888323656982, 0.03158076222462114, 0.036165698620607145, 0.04821985414309893, 0.03146538423607126, 0.02690412977244705, 0.010348543382860953, 0.04959325036907103, 0.020278992305975407, 0.06295544488239102, 0.048042250782600604, 1.376292323693633, 13.270745147019625, 43.9155089110136, 56.733760088682175, 57.21277378499508, 47.43543863296509, 36.62844233214855, 23.716281093657017, 30.14264825731516, 57.670128643512726, 46.162415742874146, 21.35592944920063, 4.7177712712436914, 0.8739306614734232, 0.030844963621348143, 0.515281087718904, 2.454053428955376, 3.1304470589384437, 4.832685180008411, 9.178976509720087, 17.427272759377956, 10.670911353081465, 15.034904982894659, 19.89309534430504, 19.20412391424179, 19.456597566604614, 25.728750005364418, 41.500343307852745, 42.97953553497791, 54.13202069699764, 57.64402024447918, 57.03677482903004, 57.70878776907921, 58.69065508246422, 57.637294605374336, 63.36539603769779, 59.507926627993584, 58.76433312892914, 55.98781831562519, 52.3640363663435, 47.70070619881153, 45.563180297613144, 43.37881051003933, 48.47681075334549, 50.714168697595596, 54.06632602214813, 53.547159880399704, 50.67942336201668, 43.40728618204594, 42.80311480164528, 42.16173201799393, 46.628734320402145, 47.78232581913471, 49.757125452160835, 50.84749214351177, 51.60241283476353, 51.7827245593071, 57.739262133836746, 55.13081230223179, 54.98936869204044, 50.44639706611633, 54.795005321502686, 37.865956127643585, 27.767712995409966, 42.64076471328735, 55.12611195445061, 60.364708453416824, 55.215764343738556, 54.314570501446724, 47.60700322687626, 47.34459690749645, 43.2534172385931, 41.07306383550167, 40.56871309876442, 43.41218791902065, 43.32850120961666, 45.03147102892399, 46.87827453017235, 47.21711754798889, 44.69191364943981, 45.076274424791336, 46.63588173687458, 51.62024527788162, 53.680152744054794, 56.04548782110214, 56.59097135066986, 54.630781933665276, 52.296426594257355, 50.247196555137634, 48.25796529650688, 50.14433607459068, 52.00486443936825, 51.68890759348869, 53.86320412158966, 46.43317021429539, 33.303244560956955, 30.322038531303406, 25.151277892291546, 22.76924841105938, 15.210036635398865, 21.554989367723465, 20.08059438318014, 12.503911145031452, 15.027025155723095, 16.631333269178867, 5.478812484070659, 7.357788858935237, 5.206972220912576, 1.1608988628722727, 1.0052320221439004, 0.05826147957122885, 0.04224885306030046, 0.665850976947695, 5.8296172600239515, 19.15902603417635, 28.524539284408092, 29.883006289601326, 25.154836401343346, 21.133724972605705, 34.91477228701115, 47.769877687096596, 48.065832406282425, 37.654972448945045, 6.182054523378611, 0.8592214132659137, 0.06359076040098444, 0.11066878694691695, 0.049236384948017076, 0.046451023081317544, 0.03005425722221844, 0.021957780445518438, 0.06205592108017299, 0.04480195610085502, 0.03783213556744158, 0.046545539298676886, 0.083813371747965, 0.09473655358306132, 0.02243012590042781, 0.04350306779087987, 0.1618512612185441, 0.0327833754272433, 0.10649227668181993, 0.012567363628477324, 0.04851386336667929, 0.004651315475712181, 0.11968469378189184, 0.009337204828625545, 0.05310848107910715, 0.09090934996493161, 0.02170217365346616, 0.06668236950645223, 0.07967063662363216, 0.0669353008561302, 0.06876030878629535, 0.03890098778356332, 0.08255123830167577, 0.07968376521603204, 0.11394393659429625, 0.028523664841486607, 0.10161001366213895, 0.030320905316330027, 0.11131782477605157, 0.028311380920058582, 0.04636641824617982, 0.023020888438622933, 0.015173151732597034, 0.029676001249754336, 0.06166071259940509, 0.0575363382085925, 0.04736815062642563, 0.07444033602951095, 0.029093203811498825, 0.02295128426339943, 0.037370846257545054, 0.09235921708750539, 0.04042635358928237, 1.9580460945144296, 16.90519217401743, 48.64720121026039, 63.26758548617363, 63.75902071595192, 52.615955248475075, 39.983666092157364, 25.271982215344906, 27.91269041597843, 47.11127042770386, 37.34503448009491, 22.301727198064327, 5.635063424706459, 0.952357443748042, 0.07526284345658496, 0.44696811586618423, 2.3744346387684345, 7.454193960875273, 9.039675984531641, 12.619643434882164, 12.797779776155949, 9.592480771243572, 13.035551067441702, 18.247893825173378, 22.65982948243618, 14.319505020976067, 24.376909844577312, 39.12794440984726, 42.09803223609924, 54.19308342039585, 55.996003076434135, 57.93094664812088, 57.64546416699886, 57.66657963395119, 58.639133647084236, 66.4222902059555, 63.19686748087406, 61.453646421432495, 57.698330730199814, 54.69029054045677, 50.26940256357193, 48.67761477828026, 47.058274671435356, 51.510640159249306, 53.168335407972336, 56.33378595113754, 55.79384632408619, 52.35852666199207, 44.78464387357235, 43.80770489573479, 45.01456193625927, 48.553684428334236, 48.86646084487438, 52.18201853334904, 51.58904515206814, 54.650263488292694, 56.941639333963394, 58.31301614642143, 55.29515728354454, 55.23052275180817, 51.40348210930824, 55.361885502934456, 41.19149588048458, 32.66322210431099, 44.84889082610607, 56.10880762338638, 63.402907624840736, 58.04686322808266, 55.8892136067152, 49.530775398015976, 48.43738026916981, 45.83793215453625, 43.77690754830837, 43.440257012844086, 46.76961936056614, 45.15508599579334, 47.49873943626881, 48.036771565675735, 49.32628557085991, 48.73376056551933, 47.176208943128586, 48.57427552342415, 53.28869394958019, 55.868360325694084, 57.64897897839546, 57.303615510463715, 55.12025646865368, 52.2143130004406, 51.58012703061104, 50.35687766969204, 53.628505915403366, 56.45992398262024, 57.18302898108959, 55.67580185830593, 48.58162432909012, 36.608789786696434, 34.035461470484734, 29.960828013718128, 23.63117516040802, 15.566315967589617, 14.306775704026222, 14.83214596286416, 12.98643870279193, 17.546164579689503, 9.93298714980483, 12.39437822252512, 11.371013335883617, 5.561566818505526, 4.18905814178288, 1.3078261725604534, 0.182545114075765, 0.04640642000595108, 0.8419623831287026, 6.709697060286999, 23.07101871818304, 31.336339004337788, 32.344992980360985, 21.94215439260006, 23.795653134584427, 39.07818987965584, 52.08917811512947, 54.73459996283054, 44.17702987790108, 8.382583893835545, 0.9046135994140059, 0.08695958807948045, 0.07651156629435718, 0.03389156889170408, 0.04978908829798456, 0.03598931238229852, 0.07483247201889753, 0.03753498705918901, 0.030372440050996374, 0.025469254032941535, 0.04422380450705532, 0.08608688920503482, 0.072071897884598, 0.02882459830289008, 0.021631105591950472, 0.1104081743687857, 0.02805265710776439, 0.02542946007451974, 0.033947860792977735, 0.039870336549938656, 0.01775139131495962, 0.05634597044263501, 0.032995199217111804, 0.04263058413926046, 0.06383983258274384, 0.07053464287309907, 0.06919911844306625, 0.22351196268573403, 0.12052200705511495, 0.1281751081114635, 0.24215195153374225, 0.24647793034091592, 0.11580459729884751, 0.15417197719216347, 0.20111062098294497, 0.25319617765489966, 0.19881030457327142, 0.15670801454689354, 0.1425771220237948, 0.11118186332168989, 0.14983069529989734, 0.12775871873600408, 0.21005027956562117, 0.13229307776782662, 0.2010076108854264, 0.13134927372448146, 0.16670468437951058, 0.17510612262412906, 0.1509305729996413, 0.18738522310741246, 0.24809334834571928, 0.06939552040421404, 2.780492724850774, 21.119935512542725, 57.67092280089855, 69.11421775817871, 70.54164156317711, 61.08065463602543, 49.67261418700218, 36.23558521270752, 42.4696408957243, 72.43454039096832, 56.20704375207424, 27.009894959628582, 6.661148015409708, 1.3380509382113814, 0.2381832871469669, 1.3544691447168589, 3.901972146704793, 9.070712719112635, 16.71936884522438, 20.12106031179428, 37.431932017207146, 20.861163698136806, 22.50018484890461, 30.015577375888824, 27.89908144623041, 24.05823614448309, 33.135145381093025, 44.85820412635803, 44.344749078154564, 56.63702867925167, 58.29314701259136, 58.09623397886753, 58.80853995680809, 60.170633867383, 61.40078365802765, 66.75499275326729, 65.24074360728264, 62.89903566241264, 60.84268860518932, 57.78868228197098, 52.037911266088486, 50.40779493749142, 48.7081803381443, 52.28970855474472, 55.5565794557333, 58.73645402491093, 58.36391061544418, 55.02110458910465, 47.879570201039314, 45.99440395832062, 46.51412107050419, 50.59750355780125, 52.27598749101162, 54.53950323164463, 55.908459573984146, 56.800860688090324, 58.7768230587244, 59.468439146876335, 55.8992450684309, 55.404545813798904, 51.20933532714844, 55.360179394483566, 45.478399246931076, 32.830150946974754, 49.31470759212971, 57.81972661614418, 65.74297785758972, 60.730492025613785, 58.744479194283485, 51.77325166761875, 51.30313329398632, 48.83736580610275, 45.30985929071903, 44.60494011640549, 47.49214679002762, 46.35302111506462, 49.600912034511566, 49.43293444812298, 49.50521036982536, 49.60142120718956, 50.63367381691933, 50.88279224932194, 55.18217034637928, 56.99119247496128, 58.89336280524731, 59.670831486582756, 56.53995908796787, 51.892371475696564, 51.8253430724144, 51.709738075733185, 55.5499792098999, 57.77587316930294, 59.31282989680767, 60.0106168538332, 52.82923400402069, 38.29060234129429, 36.593886986374855, 33.65864709019661, 30.94749826937914, 22.010871805250645, 28.341056630015373, 28.155269399285316, 19.655948169529438, 29.67712003737688, 28.555762208998203, 13.80403608083725, 13.8862076215446, 10.706889722496271, 4.730882467702031, 1.5701364283449948, 0.2886270498856902, 0.16793411137769, 1.0570955579169095, 8.170050848275423, 25.808078348636627, 39.127803817391396, 43.74759592115879, 37.74179019033909, 33.627747148275375, 47.70487457513809, 60.352815091609955, 64.48494896292686, 51.82499349117279, 14.336291570216417, 1.4720667782239616, 0.2630781114567071, 0.3477585269138217, 0.16978829313302413, 0.11505807095090859, 0.15336221986217424, 0.087790786055848, 0.23240246140630916, 0.19706271006725729, 0.20292776956921443, 0.34101412631571293, 0.16360238834749907, 0.23596407263539732, 0.12377043938613497, 0.1563362727756612, 0.19674247334478423, 0.1591411160188727, 0.15718643262516707, 0.08330181677592918, 0.10998517987900414, 0.12813863897463307, 0.2944722049869597, 0.12420682222000323, 0.21662986400770023, 0.25955656135920435, 0.09412429659278132, 0.19165248319040984], [0.0382213215198135, 0.04866142829996534, 0.075589722400764, 0.061651769719901495, 0.040779638147796504, 0.04304481015424244, 0.048310244019376114, 0.04711974266683683, 0.08149087254423648, 0.030386956459551584, 0.012573336061905138, 0.05849019835295621, 0.055352190174744464, 0.03023587560164742, 0.04433013942616526, 0.05012569308746606, 0.01720863459922839, 0.027848484860442113, 0.08766345577896573, 0.05888077583222184, 0.09289493638789281, 0.01205040025524795, 0.011721293012669776, 0.012509433436207473, 0.06750896616722457, 2.8124304860830307, 15.925916321575642, 41.460624039173126, 54.276557341217995, 50.38758002221584, 41.84934318065643, 24.071324542164803, 21.635484248399734, 26.713522262871265, 38.1324852257967, 34.698050916194916, 14.732256922870874, 3.417124575935304, 0.07403230323689058, 0.0946432062482927, 0.25726442341692746, 2.578923278488219, 6.824957225471735, 9.407440200448036, 7.380629908293486, 10.141490511596203, 6.396034341305494, 10.87010046467185, 15.380608532577753, 34.39698167145252, 18.88933550566435, 27.58166167885065, 42.760348096489906, 51.23321324586868, 59.95892062783241, 57.06572167575359, 59.07853066921234, 54.489866495132446, 54.95280705392361, 60.28881132602692, 57.556773126125336, 55.67282661795616, 55.91025687754154, 49.93402116000652, 47.25440874695778, 45.24859517812729, 45.009918585419655, 47.40422710776329, 51.750479489564896, 57.44052596390247, 57.60526232421398, 54.95841555297375, 49.97865356504917, 42.037167102098465, 41.496072337031364, 45.413449332118034, 53.269797563552856, 55.64112491905689, 55.19171543419361, 55.27269288897514, 54.52235855162144, 52.236914187669754, 57.739604115486145, 52.014645114541054, 52.656943649053574, 50.14530502259731, 52.78666488826275, 40.042338743805885, 29.0699715167284, 44.913164377212524, 61.87428005039692, 55.274991765618324, 54.307084903120995, 50.7017357647419, 48.10247004032135, 46.151601523160934, 43.716676980257034, 40.47186389565468, 40.849958807229996, 43.01327392458916, 41.02614775300026, 41.69741593301296, 43.987043872475624, 44.24612157046795, 44.95394378900528, 44.80503357946873, 47.35309325158596, 52.05299645662308, 52.97233432531357, 55.67885309457779, 57.98562191426754, 55.058821365237236, 53.455208614468575, 53.53768698871136, 53.097039833664894, 49.24734480679035, 49.112357050180435, 52.23572105169296, 45.533177107572556, 44.227346777915955, 40.257874578237534, 28.60653318464756, 24.19971015304327, 23.689543828368187, 12.214531973004341, 11.478856299072504, 7.554182270541787, 7.87966663017869, 10.14737544581294, 6.3593558594584465, 14.462890326976776, 10.212531499564648, 3.815383343026042, 4.2506499867886305, 0.7625721744261682, 0.46648873714730144, 0.05353565014956985, 0.31825046811718494, 3.6415920685976744, 13.037049137055874, 29.032887406647205, 35.52261807024479, 25.200489051640034, 20.64181476831436, 28.723994381725788, 39.55178886651993, 47.92366683483124, 40.7547777146101, 18.79982940852642, 2.8409199323505163, 0.028472720114223193, 0.032908134162425995, 0.04661037331970874, 0.02048085276328493, 0.014283290693128947, 0.0616720414836891, 0.03926368277461734, 0.08547017190721817, 0.021108603941684123, 0.0564677197689889, 0.031019398011267185, 0.043803741500596516, 0.09032750618644059, 0.05672613930073567, 0.06997344564297237, 0.1006342082109768, 0.02925319415226113, 0.07633369576069526, 0.06326572198304348, 0.031626292984583415, 0.030295885662781075, 0.06639558880124241, 0.08492078224662691, 0.03712243829795625, 0.059417842130642384, 0.027252354739175644, 0.04847489319217857, 0.02858577518054517, 0.029278297297423705, 0.05768094568338711, 0.07406829739920795, 0.09333787238574587, 0.031477418160648085, 0.07157707092119381, 0.01215319884067867, 0.02835131403116975, 0.09733646016684361, 0.028159628418507054, 0.05609233776340261, 0.04022514993266668, 0.09632053421228193, 0.04016290600702632, 0.03524777326674666, 0.025675649012555368, 0.05799066617328208, 0.04664498337660916, 0.06061250693164766, 0.04022687913675327, 0.017636710945225786, 0.07837633849703707, 0.03824468803941272, 3.6382997827604413, 19.885871931910515, 46.21874012053013, 61.40377789735794, 56.548991203308105, 49.12492677569389, 29.452666081488132, 26.4179665222764, 30.9670577198267, 42.40159414708614, 38.16949523985386, 15.024257954210043, 3.544404683634639, 0.3185410040896386, 0.03075841064855922, 1.2093561189249158, 5.348989125341177, 7.899242229759693, 13.004821166396141, 13.932993561029434, 11.523290164768696, 10.627312492579222, 8.99210823699832, 17.812505587935448, 21.175957806408405, 19.321265928447247, 30.186463706195354, 39.841302931308746, 51.8785136193037, 59.10246178507805, 58.21740947663784, 57.5305051356554, 55.48325099050999, 54.81033369898796, 61.22308239340782, 60.94257764518261, 58.029273971915245, 57.33355030417442, 52.57763810455799, 49.638051241636276, 47.24459387362003, 48.1916094571352, 47.88816913962364, 53.44517335295677, 57.24742412567139, 59.38940338790417, 58.06180402636528, 51.63598023355007, 45.053300857543945, 43.243241384625435, 46.53744801878929, 53.4394546598196, 56.91319786012173, 58.297463580965996, 57.298299595713615, 56.434769332408905, 55.4601976275444, 57.45930075645447, 52.41636335849762, 52.230397537350655, 49.85263332724571, 52.549002841115, 45.15740007162094, 34.498402029275894, 47.262475714087486, 61.09698995947838, 58.38305778801441, 58.7391746789217, 53.34230147302151, 49.414186254143715, 48.08917075395584, 45.645134299993515, 43.191670551896095, 42.93463334441185, 44.779392555356026, 42.717573791742325, 44.025041833519936, 46.75571970641613, 46.17521345615387, 47.38330163061619, 46.41344927251339, 50.09394697844982, 54.48479376733303, 54.59566041827202, 56.6685251891613, 59.21324484050274, 55.1321080327034, 54.00568127632141, 53.92281532287598, 54.0500894933939, 52.491109147667885, 52.98803888261318, 56.10707871615887, 50.9246090054512, 48.83987367153168, 41.815866976976395, 29.45513214915991, 25.971885658800602, 23.446195386350155, 17.43761770427227, 13.55725072324276, 9.81776213273406, 11.45153196528554, 11.0976218059659, 7.282026624307036, 12.05634931102395, 14.618402682244778, 5.835595764219761, 5.4946481343358755, 2.385328891687095, 0.27990049158688635, 0.0781903785536997, 0.34029893344268203, 4.378571547567844, 14.957647528499365, 29.741575978696346, 39.57512341439724, 32.55464293062687, 24.772459119558334, 35.129673555493355, 47.279350608587265, 54.27946038544178, 47.58288972079754, 23.053600452840328, 3.34620731882751, 0.032088042426039465, 0.033170780225191265, 0.026474704573047347, 0.03479416889604181, 0.03590906024328433, 0.0392464278411353, 0.04408107095514424, 0.024988845143525396, 0.059115984695381485, 0.057610927760833874, 0.041542925901012495, 0.024239658196165692, 0.055837762556620874, 0.056358464498771355, 0.08411763003095984, 0.14800293400185183, 0.05127499782247469, 0.1149920272291638, 0.025410026937606744, 0.02354710639338009, 0.0431132287485525, 0.0926497382170055, 0.0605961871042382, 0.031121484134928323, 0.041814258802332915, 0.013474822844727896, 0.07197480270406231, 0.15493296057684347, 0.14443875494180247, 0.20444883091840893, 0.22489590483019128, 0.1444488184642978, 0.14271879801526666, 0.20535549789201468, 0.15700659540016204, 0.13856171717634425, 0.22758147009881213, 0.19529212382622063, 0.1532338431570679, 0.14608982572099194, 0.24154114915290847, 0.19911810290068388, 0.15255028061801568, 0.11561192834051326, 0.19510946644004434, 0.19471507432172075, 0.18709514726651832, 0.11684375247568823, 0.09221653919667006, 0.3518777136923745, 0.16277968796202913, 4.984012059867382, 25.431121475994587, 54.65939059853554, 67.87061288952827, 63.38079281151295, 55.98186023533344, 35.61788655817509, 32.600825652480125, 37.93186359107494, 49.75423000752926, 42.492766454815865, 18.166597187519073, 4.747840957716107, 0.38540132576599717, 0.34948458429425955, 0.9141941322013736, 5.849263155832887, 12.314667999744415, 24.09617330878973, 19.072523675858974, 15.290869697928429, 20.888277143239975, 22.667997144162655, 21.914609670639038, 40.86827002465725, 22.360415048897266, 32.947443053126335, 46.72146074473858, 54.64916154742241, 62.130477502942085, 57.50345058739185, 59.546661749482155, 56.154978945851326, 57.32613690197468, 62.04692758619785, 64.77530658245087, 61.56816467642784, 60.98580792546272, 54.48576271533966, 52.148907110095024, 50.610647052526474, 49.93779815733433, 50.33932261168957, 56.587707325816154, 60.771712213754654, 62.717371210455894, 60.02203144133091, 54.28180865943432, 46.34621188044548, 45.985227450728416, 49.42579463124275, 56.87802314758301, 60.3939288854599, 60.19116036593914, 58.60288359224796, 59.989227801561356, 57.11424507200718, 60.326661095023155, 52.70958602428436, 52.104350700974464, 48.520318418741226, 54.820722341537476, 48.19481648504734, 37.92896434664726, 50.6290228664875, 65.11476516723633, 59.308064952492714, 59.93504650890827, 54.947513937950134, 51.30232013761997, 50.59753395617008, 47.35840156674385, 45.86912848055363, 44.902840331196785, 45.86331479251385, 45.1816313713789, 44.923249036073685, 48.24602633714676, 48.28095406293869, 49.08294662833214, 48.90451580286026, 50.58832325041294, 57.11789287626743, 57.13064879179001, 60.3250689804554, 60.885804891586304, 57.35435798764229, 52.585959658026695, 53.28901693224907, 53.73763605952263, 52.582881823182106, 54.560421109199524, 59.70692954957485, 55.64461313188076, 53.40799614787102, 47.279950976371765, 34.62226018309593, 30.334575958549976, 29.324677549302578, 17.926064394414425, 15.430633798241615, 11.450962945818901, 16.42233118414879, 18.985966220498085, 13.436627145856619, 27.41100523620844, 20.668776221573353, 11.451058890670538, 9.578708410263062, 1.6339662345126271, 0.7664245145861059, 0.13798762141959742, 0.716334949247539, 4.581310143694282, 16.683821752667427, 39.410740435123444, 49.049242436885834, 37.50070072710514, 34.051010236144066, 42.27271646261215, 51.454403176903725, 61.35180048644543, 54.59339573979378, 29.549439288675785, 4.901748849079013, 0.16374447994166985, 0.2036044152919203, 0.10115978235262446, 0.09138525958405808, 0.09928321742336266, 0.18199637008365244, 0.14263036369811743, 0.17569047486176714, 0.14772973459912464, 0.1749002657015808, 0.1956664037425071, 0.11358055882737972, 0.14389480522368103, 0.2399304512073286, 0.2088457887293771, 0.24984478717669845, 0.09245003369869664, 0.17739806760801002, 0.16930254263570532, 0.15116059425054118, 0.24586524290498346, 0.20135637576458976, 0.18376563530182466, 0.14081999834161252, 0.1324607734568417, 0.12348819320322946], [0.029474439506884664, 0.041164029826177284, 0.012125446228310466, 0.026561955164652318, 0.07744589311187156, 0.03023781446245266, 0.02087618184305029, 0.09475510727497749, 0.14942905982024968, 0.014602258343074936, 0.08713284245459363, 0.0319490678521106, 0.04166498692939058, 0.04207232952467166, 0.01749882361764321, 0.013504100570571609, 0.037692801051889546, 0.037854837864870206, 0.01658343455346767, 0.01477746920500067, 0.05009289016015828, 0.05554094801482279, 0.017058479570550844, 0.0623487911070697, 0.03427357085456606, 4.274994330480695, 19.649967290461063, 49.49676342308521, 51.01869575679302, 44.557997435331345, 27.472066059708595, 16.793430671095848, 20.37148777395487, 36.28057859838009, 27.51932792365551, 20.431013479828835, 7.564130611717701, 0.4692201077705249, 0.17549022857565433, 0.10781786375446245, 1.7653348040767014, 4.032423421740532, 7.389915185049176, 5.558194499462843, 14.34408400207758, 7.611458022147417, 6.311145471408963, 7.467983420938253, 20.333351120352745, 28.38487207889557, 24.80937983840704, 39.4731330871582, 51.03288799524307, 54.08215597271919, 58.15068505704403, 56.57158479094505, 55.41801229119301, 54.89752382040024, 58.96360583603382, 57.16625288128853, 54.468409046530724, 57.04795762896538, 50.26170037686825, 44.938178434967995, 43.365051448345184, 46.03684388101101, 48.54877129197121, 52.113690599799156, 55.41718393564224, 57.033712193369865, 56.78091935813427, 52.91801244020462, 45.82257337868214, 40.387481823563576, 43.39549161493778, 53.68066571652889, 59.50109079480171, 57.8837987780571, 58.56045126914978, 58.24514038860798, 55.39473094046116, 56.18195369839668, 55.12702390551567, 55.137917920947075, 50.9895209223032, 51.26130893826485, 47.41634085774422, 41.09104827046394, 30.94354648143053, 45.1606260985136, 61.51508912444115, 55.74376121163368, 56.05553448200226, 45.406674295663834, 41.91754572093487, 39.61983561515808, 42.76817187666893, 42.50961475074291, 45.61309061944485, 44.03582185506821, 44.749438762664795, 41.59944199025631, 40.066152065992355, 39.58487369120121, 42.11143031716347, 42.41312272846699, 45.29135048389435, 46.19793243706226, 53.763307482004166, 55.25778628885746, 58.196001425385475, 55.858800038695335, 56.323917880654335, 52.61617183685303, 58.1887324154377, 53.33710715174675, 51.88107468187809, 43.34440715610981, 52.94331148266792, 51.55140437185764, 46.989312171936035, 49.16742369532585, 46.119128465652466, 34.872537553310394, 27.728890478610992, 21.577516458928585, 19.707192219793797, 14.801954682916403, 14.985902812331915, 7.689462136477232, 11.782961580902338, 14.282369613647461, 5.185453975573182, 6.582559207454324, 4.405342061072588, 0.19139857962727547, 0.057481471230858006, 0.13044107792666182, 0.5608626105822623, 12.6135428622365, 27.63795755803585, 32.7066195756197, 21.108340434730053, 18.461313173174858, 25.243134163320065, 34.08286772668362, 45.93900293111801, 41.440884098410606, 25.029201842844486, 2.9485909547656775, 0.037494280259124935, 0.01635028143937234, 0.036737649570568465, 0.018699453430599533, 0.021558970693149604, 0.05295618495438248, 0.03716493367392104, 0.0364289235585602, 0.03610989653680008, 0.0862908165436238, 0.03536426076607313, 0.03691261459607631, 0.02610166404338088, 0.03600808129704092, 0.025731293389981147, 0.0303246958355885, 0.027926913171540946, 0.008588411219534464, 0.03795092001382727, 0.017299814862781204, 0.029092470940668136, 0.053913303127046674, 0.046701779938302934, 0.03422868947382085, 0.12429564245394431, 0.08363764602108859, 0.009447864613321144, 0.04330579380621202, 0.03263299404352438, 0.03195397344825324, 0.0354421936935978, 0.02453060049447231, 0.023076584766386077, 0.018723415523709264, 0.004897180187981576, 0.03421387620619498, 0.015303932996175718, 0.04076876197359525, 0.016402400615334045, 0.048354357277275994, 0.04050287643622141, 0.01624061984330183, 0.02755664085270837, 0.032133083368535154, 0.02688884524104651, 0.02768398597254418, 0.04505112847255077, 0.01459994933611597, 0.06310163313173689, 0.022993415987002663, 0.04279647269868292, 4.834487233310938, 24.397670030593872, 55.043033212423325, 56.58644199371338, 50.610700249671936, 34.692347422242165, 24.17464479804039, 21.506756655871868, 35.46655207872391, 31.592126078903675, 21.187712475657463, 8.723050374537706, 0.7524173974525183, 0.2460518485167995, 0.45803371584042907, 1.6336219967342913, 5.5528762098401785, 11.114426404237747, 10.342608969658613, 13.952132184058428, 12.539963610470295, 8.845746740698814, 9.812420569360256, 11.393587924540043, 18.167370446026325, 26.851435862481594, 36.8789628893137, 50.8749570697546, 56.77304998040199, 59.34803120791912, 57.225795686244965, 57.102218717336655, 56.124793365597725, 58.96303206682205, 60.08131965994835, 57.49593459069729, 59.0328723192215, 53.361482843756676, 45.79271838068962, 44.9978656321764, 48.14965210855007, 50.63564971089363, 54.42292168736458, 56.638240814208984, 58.15200358629227, 58.06519344449043, 55.04872150719166, 48.43921177089214, 42.822911739349365, 44.548068568110466, 54.77939575910568, 62.00835965573788, 60.414394587278366, 59.522977620363235, 61.1286536604166, 57.78932064771652, 57.582832127809525, 56.3492701202631, 54.85630743205547, 50.88694542646408, 50.504393354058266, 48.680681213736534, 44.2157232016325, 34.13209788501263, 46.40374839305878, 63.58196921646595, 57.4408945441246, 58.11646029353142, 46.63116618990898, 44.51307624578476, 42.19493083655834, 44.81214679777622, 45.22228918969631, 47.56342336535454, 45.80431915819645, 46.382051557302475, 43.70390586555004, 43.041536808013916, 41.06842428445816, 43.8743457198143, 44.205927327275276, 47.71014869213104, 49.114526733756065, 56.612953171133995, 58.76717157661915, 59.851234406232834, 58.022525534033775, 55.61637684702873, 52.53223054111004, 57.68381550908089, 54.00400176644325, 53.62461492419243, 49.63226795196533, 57.090454548597336, 55.181942358613014, 53.014633655548096, 53.94781798124313, 49.2302381247282, 40.01300431787968, 27.617001682519913, 23.140594884753227, 13.705431371927261, 8.330766074359417, 10.045675802975893, 10.290977340191603, 9.251685608178377, 12.941821496933699, 9.68743672594428, 6.254473887383938, 3.264184445142746, 1.3528775051236153, 0.15657083597034216, 0.12290274258702993, 1.1729451664723456, 11.234352719038725, 28.193322457373142, 36.92931018769741, 23.753027021884918, 22.655847296118736, 30.10932594537735, 37.43361912667751, 52.66084223985672, 46.59046657383442, 30.092471949756145, 4.545338898897171, 0.03755894358619116, 0.09686307384981774, 0.04156717186560854, 0.02996568746311823, 0.03840848003164865, 0.05676771070284303, 0.019287690811324865, 0.02090861369651975, 0.040281764668179676, 0.02233603456261335, 0.0877535821928177, 0.02287299881572835, 0.02906111149059143, 0.06099259415350389, 0.023891112250566948, 0.02430838292639237, 0.025204643134202342, 0.0488122883689357, 0.03658676352642942, 0.02878822935599601, 0.047631086126784794, 0.054732478311052546, 0.018572726148704533, 0.018367700431554113, 0.04949100468365941, 0.03405094139452558, 0.08216411180910654, 0.10154676783713512, 0.1435985547141172, 0.08075633930275217, 0.21086861612275243, 0.14844132063444704, 0.18203323998022825, 0.19084498198935762, 0.16907154174987227, 0.10792819142807275, 0.1505354535765946, 0.09140925321844406, 0.11101617143140174, 0.1150429088738747, 0.11726433498552069, 0.11103232798632234, 0.13789645599899814, 0.11598403376410715, 0.13404390803771093, 0.2809478994458914, 0.14402232103748247, 0.12895571388071403, 0.11379941817722283, 0.11600447993259877, 0.2607700618682429, 6.46830266341567, 31.268404349684715, 63.63105118274689, 64.87613797187805, 58.02712328732014, 39.960772320628166, 28.035762012004852, 29.668959975242615, 49.10850405693054, 37.764683961868286, 26.845382787287235, 9.568417612463236, 0.9708548511844128, 0.5077662190888077, 0.5322702135890722, 3.420653874054551, 9.058968499302864, 17.522163167595863, 13.794865272939205, 30.25858573615551, 21.947722993791103, 17.845499217510223, 15.666085314005613, 29.575080312788486, 35.47548159956932, 28.25512044131756, 44.71212096512318, 55.9392037242651, 59.226935505867004, 63.17420169711113, 61.218591034412384, 58.128232061862946, 58.81335809826851, 59.35085825622082, 61.948357075452805, 59.40208710730076, 61.41007035970688, 55.44683374464512, 48.21189656853676, 47.01250992715359, 49.9430038779974, 53.91809217631817, 58.02961215376854, 56.99231341481209, 58.82756933569908, 58.79305958747864, 55.97087122499943, 49.83293518424034, 44.050397872924805, 47.218629866838455, 57.84612759947777, 64.38686102628708, 62.40213252604008, 61.00621663033962, 63.77719894051552, 60.695860683918, 60.331969410181046, 58.56109343469143, 55.29784373939037, 51.00343957543373, 51.072584465146065, 50.390840247273445, 46.81278504431248, 39.67789649963379, 49.94323946535587, 65.26372477412224, 61.46341569721699, 60.569604858756065, 49.737529903650284, 46.58236160874367, 44.43114124238491, 47.2141233086586, 46.45272396504879, 49.302958622574806, 49.31762583553791, 50.11644937098026, 46.40006259083748, 45.35585202276707, 44.32077616453171, 46.02476432919502, 45.24291068315506, 49.527070596814156, 51.5223853290081, 58.54696959257126, 59.512250795960426, 62.386344373226166, 58.93818899989128, 56.62878692150116, 52.18103438615799, 59.98948238790035, 54.45082738995552, 54.718549624085426, 50.48827461898327, 58.72962199151516, 56.61263398826122, 54.90329951047897, 57.473420798778534, 54.3654877692461, 42.89462149143219, 33.215735256671906, 26.066720969974995, 24.56821247935295, 25.376742593944073, 26.27404734492302, 19.629416093230247, 25.935073234140873, 23.84564895182848, 14.085733015090227, 15.245287343859673, 7.986799981445074, 1.2138285976834595, 0.13718420203076676, 0.39850958331953734, 1.2125703901983798, 15.146101266145706, 34.951113536953926, 42.93104633688927, 32.38775588572025, 30.075880140066147, 37.77444563806057, 47.14965216815472, 59.776203632354736, 57.119944766163826, 36.02789215743542, 7.130363937467337, 0.28645178535953164, 0.2408114992431365, 0.1462907696259208, 0.10469593791640364, 0.16788002365501598, 0.18620019138325006, 0.1156490579887759, 0.10631514829583466, 0.13719839189434424, 0.21640573540935293, 0.2319096605060622, 0.14663579408079386, 0.15447558980667964, 0.1832532713888213, 0.1716223478433676, 0.08128414730890654, 0.1820166752440855, 0.09588841130607761, 0.1251574614434503, 0.15684008714742959, 0.14563451812136918, 0.22409744298784062, 0.16168132424354553, 0.10581215028651059, 0.19506470009218901, 0.1638897182419896], [0.07069803410558961, 0.019788113568210974, 0.07090030645485967, 0.05021315148042049, 0.08254449217929505, 0.06278249478782527, 0.06740660915966146, 0.021986119354551192, 0.0563356360362377, 0.06825351840234362, 0.03585024503991008, 0.04876997852989007, 0.02641114333528094, 0.07412185819703154, 0.010524624412937555, 0.035419602718320675, 0.04011777971754782, 0.05786228575743735, 0.0051430685562081635, 0.03170050033077132, 0.06590506629436277, 0.02649372396263061, 0.047462266084039584, 0.06968520290683955, 0.24601708631962538, 6.600508019328117, 29.733195528388023, 52.028358578681946, 57.507094591856, 47.27066047489643, 25.77264714986086, 10.63896456733346, 28.069593496620655, 31.511011831462383, 30.432802587747574, 18.87957952916622, 2.8650987474247813, 0.2512877597473562, 0.24139925051713362, 0.579321188852191, 2.37936036195606, 6.336327670142055, 11.477948147803545, 12.680041193962097, 10.09290536865592, 7.128950413316488, 7.591954618692398, 5.181472739204764, 16.434066854417324, 19.66628171503544, 31.37216918170452, 30.978200621902943, 33.30282278358936, 46.2765996158123, 54.27700191736221, 57.97237582504749, 49.826688319444656, 51.82324938476086, 55.91130182147026, 55.69633975625038, 54.46531981229782, 52.37100139260292, 45.92350356280804, 43.1646654009819, 43.42296414077282, 46.362372413277626, 50.73253691196442, 54.721954241395, 57.629516422748566, 58.457655385136604, 55.96238248050213, 49.59015481173992, 43.19132477045059, 41.50764271616936, 49.589892625808716, 57.12076932191849, 55.74824497103691, 60.65655559301376, 56.48713432252407, 53.25898714363575, 52.3630940169096, 53.738772198557854, 54.137116223573685, 51.95063754916191, 52.85484082996845, 50.5197711288929, 41.601246893405914, 44.07405160367489, 31.643442325294018, 54.32164952158928, 57.05798529088497, 52.89539985358715, 51.10976926982403, 43.87418232858181, 42.60253496468067, 45.17829895019531, 49.2026250064373, 51.39165714383125, 54.190187975764275, 54.758344888687134, 52.11505472660065, 48.9554026722908, 47.001976892352104, 41.627400889992714, 38.9827997982502, 37.863683849573135, 39.02698002755642, 44.14597414433956, 45.66682733595371, 50.68350814282894, 53.755992874503136, 55.79232640564442, 53.66651527583599, 55.42055815458298, 53.36171843111515, 53.43200325965881, 55.37005126476288, 55.59787943959236, 55.58010399341583, 53.38004484772682, 51.77335046231747, 50.48811122775078, 49.26643878221512, 42.03181318938732, 36.68687179684639, 31.1463226005435, 14.937743246555328, 7.729920465499163, 4.10416642203927, 5.857406118884683, 4.786743745207787, 13.694066181778908, 5.2233536168932915, 4.809116944670677, 3.8100185059010983, 0.649470352800563, 0.1319083187263459, 0.028990368118684273, 0.5036375031340867, 4.209620738402009, 20.139637514948845, 38.20737160742283, 41.71157777309418, 18.779434002935886, 23.473550118505955, 34.2384921759367, 43.654516115784645, 42.16743931174278, 34.31981921195984, 6.8665246199816465, 0.21563562360825017, 0.04203460244752932, 0.08008370117750019, 0.05642458243528381, 0.03636565546912607, 0.043504143905011006, 0.012524127032520482, 0.06358260419801809, 0.11063995450967923, 0.03628762235166505, 0.007639222430952941, 0.059994179173372686, 0.02442458655423252, 0.0225631410285132, 0.015703759490861557, 0.04654795127862599, 0.02257914729852928, 0.01502714159869356, 0.021763447221019305, 0.06579237859114073, 0.062140544469002634, 0.029297012406459544, 0.01811504738725489, 0.03320928655739408, 0.026036570270662196, 0.06520947354147211, 0.04549179720925167, 0.0173570047627436, 0.024236951212515123, 0.0351291372498963, 0.011393168188078562, 0.07526564135332592, 0.08577112021157518, 0.013004564680159092, 0.03204471584467683, 0.05313189212756697, 0.04060173421748914, 0.011427137214923277, 0.04142571851843968, 0.05961917937383987, 0.025928159193426836, 0.0056528029472247, 0.020953439416189212, 0.035475260083330795, 0.056529833818785846, 0.03709009550220799, 0.04705340579675976, 0.014440419126913184, 0.04081458959262818, 0.0245238079878618, 0.3538850153563544, 7.785301068797708, 35.54705075919628, 58.749597519636154, 63.15410077571869, 50.73121838271618, 28.766250014305115, 13.146590609103441, 24.271606095135212, 36.217118203639984, 32.58084252476692, 19.723776429891586, 3.0048873089253902, 0.3631706483429298, 0.03506617715174798, 0.5151784932240844, 3.127177571877837, 5.856859423220158, 11.28671295940876, 11.167828738689423, 14.209649115800858, 14.486621953547, 6.2261369079351425, 8.976348582655191, 11.62536408752203, 15.976204723119736, 29.6174119412899, 30.747425705194473, 36.74551025032997, 47.39401325583458, 57.862075343728065, 59.76772628724575, 54.33714509010315, 55.26528708636761, 57.5687500834465, 57.54091277718544, 57.9519709199667, 54.10821497440338, 47.56152726709843, 44.927227422595024, 45.69251395761967, 48.059691935777664, 52.56094940006733, 56.200116723775864, 58.157695680856705, 59.185225144028664, 57.450644820928574, 51.94292016327381, 45.7025758177042, 44.199365079402924, 51.69836908578873, 59.37737703323364, 58.313806504011154, 62.85322532057762, 58.67482513189316, 54.301278814673424, 54.31268200278282, 55.111771523952484, 53.886884450912476, 51.068872064352036, 52.88925938308239, 50.338463857769966, 44.32665064930916, 46.55548185110092, 34.80210453271866, 55.02829000353813, 59.263200759887695, 55.20700201392174, 54.398394003510475, 45.6403199583292, 44.13012519478798, 47.759534642100334, 51.94181062281132, 53.09003300964832, 56.23537503182888, 56.742533817887306, 53.67307372391224, 50.95752663910389, 48.06196801364422, 43.01554620265961, 41.15589939057827, 40.56748956441879, 42.54834987223148, 46.2266892939806, 48.95354077219963, 53.442448899149895, 55.845800936222076, 56.61494426429272, 55.83060935139656, 55.476244166493416, 53.84238883852959, 53.551320657134056, 54.47930306196213, 55.45918308198452, 56.252382919192314, 54.699752032756805, 50.37795893847942, 50.79249009490013, 51.66165545582771, 47.31624282896519, 38.84615533053875, 30.69075744599104, 14.028383642435074, 8.480775374919176, 10.869767982512712, 15.986526869237423, 14.592309482395649, 11.946956980973482, 11.7363865301013, 6.039917450398207, 4.9627944733947515, 0.9603544708807021, 0.22828971646958962, 0.16512365749804303, 0.7702538778539747, 4.826336670666933, 22.545793801546097, 35.19087307155132, 38.695227429270744, 25.631923601031303, 29.755338840186596, 39.85239453613758, 50.61108022928238, 48.06763730943203, 38.8347065448761, 8.926232121884823, 0.3533163224346936, 0.029042824971838854, 0.03621548930823337, 0.05102002927742433, 0.1172431540908292, 0.04834671315620653, 0.04206710109428968, 0.031119394989218563, 0.08565199066651985, 0.08048431249335408, 0.021899892926739994, 0.018114628073817585, 0.0052273630808485905, 0.02051911233138526, 0.07325531172682531, 0.01783780513505917, 0.12884143798146397, 0.0423107259121025, 0.01002152064756956, 0.02854138732800493, 0.06230213970411569, 0.05208918206335511, 0.011462016300356481, 0.05347018159227446, 0.027193791866011452, 0.09457875072257593, 0.2113546189502813, 0.2151086542289704, 0.12344542323262431, 0.16435071069281548, 0.18978516542119905, 0.18921774899354205, 0.1396624112385325, 0.13325592532055452, 0.20831356494454667, 0.182491471641697, 0.17522342648589984, 0.16014107095543295, 0.18655654101166874, 0.3056051325984299, 0.08427141787251458, 0.10146827829885297, 0.1534811861347407, 0.20748221111716703, 0.2095690561691299, 0.21415425231680274, 0.2087017081794329, 0.14286635181633756, 0.11945715130423196, 0.18208524968940765, 0.6434944609645754, 10.364828277379274, 43.33435669541359, 66.03049322962761, 71.59594058990479, 59.70501825213432, 38.23894411325455, 20.58178558945656, 41.55286028981209, 44.10906292498112, 41.20774760842323, 23.380842693150043, 4.469609912484884, 0.5000472301617265, 0.5386370094493032, 1.0001343581825495, 5.25781586766243, 12.775944247841835, 20.4517774656415, 20.726911202073097, 23.462506011128426, 21.53386440128088, 14.601696878671646, 12.470134757459164, 22.99135409295559, 23.47436137497425, 36.36838808655739, 35.00172682106495, 38.85986119508743, 51.30331948399544, 60.844421312212944, 64.34922024607658, 57.87135824561119, 56.466661021113396, 59.19721730053425, 61.770671010017395, 59.61331017315388, 58.089899718761444, 50.195925906300545, 48.301598355174065, 47.63382978737354, 50.252197086811066, 54.535802230238914, 58.19568984210491, 59.454771280288696, 58.89509171247482, 60.190419405698776, 54.1048863530159, 47.50374376773834, 45.840056240558624, 53.15106153488159, 61.42601050436497, 59.78713944554329, 65.38647338747978, 59.090857207775116, 56.17226801812649, 54.61346626281738, 56.88122257590294, 53.71225722134113, 52.161385640501976, 52.48945243656635, 52.21992909908295, 46.43693581223488, 50.306279584765434, 40.07415823638439, 57.03155390918255, 61.37401029467583, 58.7089055031538, 55.99345341324806, 48.55758301913738, 47.11400628089905, 52.007820680737495, 54.83370244503021, 56.523942947387695, 58.67616645991802, 59.543291330337524, 57.43495926260948, 54.03067633509636, 51.28748193383217, 46.361316069960594, 43.7876495718956, 43.443627431988716, 44.131888300180435, 48.1907507032156, 51.67221128940582, 55.28292194008827, 58.198281303048134, 59.21962469816208, 57.81942643225193, 56.17261379957199, 53.89552138745785, 53.48904959857464, 54.29290406405926, 57.133802622556686, 59.31559234857559, 56.056492030620575, 52.00063146650791, 52.42104470729828, 53.801157251000404, 52.108887657523155, 41.06446869671345, 35.32466009259224, 17.595227546989918, 11.94594718515873, 11.479705553501844, 12.74575486779213, 13.754529487341642, 24.672173000872135, 15.269480645656586, 12.623124998062849, 10.415625851601362, 2.0247011678293347, 0.6517843692563474, 0.3948913759086281, 1.0321076237596571, 5.526568321511149, 26.39294296503067, 48.75394508242607, 54.68415766954422, 31.61174062639475, 33.87839689850807, 46.381124407052994, 59.13590379059315, 55.855034440755844, 46.0781704634428, 13.279385883361101, 0.5965964868664742, 0.13107386272167787, 0.10908374504651874, 0.10046284631243907, 0.24564160412410274, 0.158820359793026, 0.09959938717656769, 0.26184302929323167, 0.2027752879075706, 0.1509222757886164, 0.11548222319106571, 0.14146274275844917, 0.0541647167847259, 0.07964454271132126, 0.10620395230944268, 0.106853984616464, 0.1847979924059473, 0.19516229251166806, 0.1638013729825616, 0.1599704215186648, 0.19133877736749128, 0.11701696974341758, 0.13226489099906757, 0.1492582174250856, 0.14136620418867096, 0.16214662115089595], [0.08430958652752452, 0.04331836578785442, 0.073897737020161, 0.06591813551494852, 0.02876080514397472, 0.04417185416969005, 0.06210891042428557, 0.05415361425548326, 0.062463497451972216, 0.031002013201941736, 0.003159386437801004, 0.03147704337607138, 0.07142386195482686, 0.043885630075237714, 0.04762271470099222, 0.04164798061538022, 0.04623535867722239, 0.03683715302031487, 0.08073368895566091, 0.012064300681231543, 0.016356966334569734, 0.10222194410744123, 0.06695199917885475, 0.04255308536812663, 0.49452672014012933, 10.37122143432498, 33.97073954343796, 51.66920565068722, 47.823618203401566, 40.40947884321213, 22.650839164853096, 26.788030564785004, 27.795726992189884, 30.07647480815649, 31.380475535988808, 7.789722606539726, 1.292402681428939, 0.03612855412939098, 0.008561704107705737, 0.648654643446207, 1.3522624131292105, 4.556357357650995, 12.169534787535667, 8.053365759551525, 9.343654923141003, 12.674972265958786, 4.042937932536006, 11.161925755441189, 9.742918498814106, 9.75449362769723, 21.209213621914387, 24.459937289357185, 40.32976672053337, 46.121434941887856, 50.69231227040291, 48.688991367816925, 50.481161400675774, 53.50335203111172, 57.17036806046963, 53.717747926712036, 53.35416443645954, 47.55260154604912, 45.945283994078636, 43.08752194046974, 44.10975828766823, 47.47983545064926, 51.80053420364857, 59.1459808498621, 58.99379521608353, 56.426417380571365, 55.2751399576664, 47.97356195747852, 40.05537584424019, 44.50176425278187, 56.15630127489567, 55.81446021795273, 59.04943183064461, 54.56877686083317, 52.36533209681511, 52.15560235083103, 54.258713498711586, 53.158585131168365, 55.16368433833122, 55.30436038970947, 54.96470421552658, 50.111099258065224, 40.99585197865963, 45.56355647742748, 41.979360803961754, 58.98163966834545, 54.801179990172386, 55.20298942923546, 46.764444038271904, 42.46326103806496, 43.41768242418766, 47.15008534491062, 50.89894138276577, 55.06000690162182, 57.02623039484024, 52.937026619911194, 54.666925594210625, 54.14018265902996, 51.3372478634119, 47.97468289732933, 43.93287017941475, 39.197887256741524, 37.58168578147888, 42.46994487941265, 45.35594321787357, 46.539423912763596, 53.76739986240864, 57.740736454725266, 55.69674253463745, 56.55646540224552, 50.14842085540295, 54.695986434817314, 54.20460820198059, 54.14068043231964, 53.53330962359905, 54.23444800078869, 50.190480798482895, 59.952647164464, 53.07319611310959, 50.56542947888374, 36.85134597122669, 35.15159837901592, 15.932017844170332, 12.132099196314812, 12.623020503669977, 14.229770936071873, 10.517512634396553, 7.200005650520325, 8.716485276818275, 2.1466266503557563, 2.2543233213946223, 2.074644500389695, 0.44859487388748676, 0.031718660684418865, 0.15217684675008059, 2.3145458148792386, 12.6589922234416, 35.321475863456726, 38.08554634451866, 28.02822131663561, 22.673307359218597, 32.40016222000122, 41.21450364589691, 42.98756830394268, 36.30542926490307, 9.085452128201723, 0.858854673570022, 0.04737932737043593, 0.023247902136063203, 0.022955169406486675, 0.03357865716679953, 0.022262378261075355, 0.06312291792710312, 0.021803667914355174, 0.056025184530881234, 0.009916883391269948, 0.04162199060374405, 0.0653077190509066, 0.024602924640930723, 0.07134610714274459, 0.07451714089256711, 0.06573954509804025, 0.031008516270958353, 0.12153082323493436, 0.044546980134327896, 0.06578893502592109, 0.05766308961028699, 0.118098019156605, 0.08662106483825482, 0.03503639476548415, 0.04496706911595538, 0.03150675896904431, 0.06510296050691977, 0.08027611780562438, 0.017151103311334737, 0.020294336209190078, 0.031092885474208742, 0.03978744978667237, 0.009835773144004634, 0.01331970377577818, 0.057159186180797406, 0.034108554318663664, 0.08742720048758201, 0.04137741954764351, 0.05025629623560235, 0.03781735940719955, 0.005864849381396198, 0.030620009383710567, 0.029355046499404125, 0.04856005834881216, 0.015507317639276152, 0.1255662809126079, 0.09936693910276517, 0.007199911360658007, 0.04300977707316633, 0.07898600539192557, 0.7386293623130769, 12.23873857408762, 40.941902473568916, 57.873075753450394, 55.096576139330864, 46.438090950250626, 28.992147892713547, 25.984177999198437, 36.19282990694046, 33.23392108082771, 32.67372474074364, 9.656164404004812, 1.9585787784308195, 0.0465351566526806, 0.11320873541990295, 0.893880600342527, 3.8782307831570506, 8.069168161600828, 11.170470546931028, 10.087771844118834, 12.628744896501303, 11.144782975316048, 10.211716443300247, 10.584523938596249, 10.263483915477991, 14.57933222874999, 19.341803826391697, 27.22131561487913, 42.13039889931679, 53.64946559071541, 55.626241117715836, 54.677903205156326, 54.54492934048176, 55.684260204434395, 58.07856112718582, 57.05357372760773, 54.854335337877274, 50.975986048579216, 47.92113997042179, 44.39766123890877, 45.443900898098946, 49.41955916583538, 53.68303678929806, 58.83754380047321, 58.26140731573105, 57.5041763484478, 56.65402516722679, 51.8244843184948, 41.94298155605793, 45.117194429039955, 58.01025979220867, 59.14617083966732, 61.02955497801304, 56.97478115558624, 52.98391990363598, 51.180787459015846, 53.85628469288349, 52.319700345396996, 54.27667513489723, 55.3969956189394, 54.94235381484032, 51.08988493680954, 41.544797122478485, 47.06821873784065, 42.632275968790054, 60.34952446818352, 55.98606660962105, 57.12163187563419, 48.27730245888233, 43.34488593041897, 45.849635526537895, 50.25181710720062, 54.07255008816719, 56.252280324697495, 56.58282458782196, 55.913646295666695, 56.478193402290344, 58.72523322701454, 53.14903624355793, 48.605631440877914, 45.201591700315475, 40.10467819869518, 40.58765888214111, 46.89020588994026, 47.64118619263172, 50.01005508005619, 56.03537656366825, 60.47459475696087, 57.50058554112911, 56.99422851204872, 51.33564434945583, 54.395281970500946, 54.39474619925022, 53.987693041563034, 53.413585647940636, 54.553372487425804, 51.2681295722723, 57.25126191973686, 54.49630714952946, 52.174650728702545, 39.34487856924534, 33.092405274510384, 19.44739256054163, 7.200179016217589, 12.964208945631981, 17.365674264729023, 15.189275499433279, 11.21596835553646, 11.833867449313402, 8.391222730278969, 2.333563081920147, 2.3263762425631285, 0.3131295007187873, 0.013075507504254347, 0.11243863104027696, 2.673045415431261, 14.4342702627182, 37.98712022602558, 41.56488284468651, 28.59535038471222, 25.43120127171278, 36.87213845551014, 45.84283009171486, 50.47214448451996, 41.68663211166859, 11.997402124106884, 0.9918393439147621, 0.006645205603490467, 0.023515693137596827, 0.04711842535471078, 0.029582280985778198, 0.013268024322314886, 0.025196546303050127, 0.022108915109129157, 0.0582531897816807, 0.0466324485023506, 0.05423692404292524, 0.03728645664523356, 0.043526656954782084, 0.027259401431365404, 0.058202022410114296, 0.04055299737956375, 0.06373720840201713, 0.05154636412044056, 0.051409571460681036, 0.051162128293071873, 0.031009744525363203, 0.04328039380197879, 0.017430779807909857, 0.04998404307116289, 0.04435263021150604, 0.03486650974082295, 0.18259716831380501, 0.12266552250366658, 0.15693393914261833, 0.10620649787597358, 0.12811641907319427, 0.12237294562510215, 0.13144324446329847, 0.12412485943059437, 0.14862314681522548, 0.13562492007622495, 0.10835640321602114, 0.10287782453815453, 0.26094084489159286, 0.1203007876756601, 0.20247980923159048, 0.11456978230853565, 0.12902883026981726, 0.13563324697315693, 0.15775420528370887, 0.19995779846794903, 0.19117860705591738, 0.14148200891213492, 0.22682216396788135, 0.12218242889503017, 1.0128825553692877, 16.725420020520687, 48.14951531589031, 67.84497946500778, 59.70741592347622, 53.750376775860786, 32.815255746245384, 38.16845029592514, 40.25834955275059, 42.17007257044315, 38.449008241295815, 11.635205559432507, 1.7268404946662486, 0.25952663796488196, 0.21020053478423506, 1.6250360012054443, 4.330299412831664, 10.284824520349503, 23.56156099587679, 17.17771165072918, 20.589073598384857, 21.203863508999348, 12.391596771776676, 17.61962603777647, 14.250603318214417, 14.063000734895468, 25.92116978019476, 33.5614825040102, 48.64482253789902, 56.93188525736332, 58.931391164660454, 56.7717694491148, 54.43742550909519, 54.948346093297005, 60.79383842647076, 59.91075821220875, 58.97597797214985, 52.681881710886955, 50.28278924524784, 47.808149233460426, 48.490706607699394, 50.43730415403843, 55.03603018820286, 61.81143142282963, 60.36851964890957, 58.37666653096676, 58.92374977469444, 53.05890507996082, 44.238024204969406, 49.690066650509834, 61.603935956954956, 59.91227053105831, 63.354258835315704, 56.797756254673004, 54.931535795331, 52.325780019164085, 54.34828609228134, 53.00068460404873, 55.5646426230669, 55.54592102766037, 55.4389263689518, 52.53410004079342, 45.94932697713375, 50.37520028650761, 47.103009670972824, 61.296730041503906, 58.25560882687569, 59.9285526573658, 50.03121234476566, 46.35679431259632, 48.55437979102135, 51.694044917821884, 55.79643778502941, 59.388552233576775, 59.06930096447468, 57.01471321284771, 57.40113727748394, 59.214449375867844, 55.770758762955666, 51.326315850019455, 48.79728555679321, 43.550713285803795, 43.16322907805443, 48.28906662762165, 50.57804860174656, 50.897341668605804, 58.70893970131874, 62.86851570010185, 59.745109900832176, 59.38067525625229, 50.58435246348381, 54.99899737536907, 56.06495417654514, 54.6867149323225, 55.67452512681484, 56.18144452571869, 51.23114235699177, 59.154287204146385, 54.806856885552406, 54.77281831204891, 40.42777866125107, 40.70442281663418, 22.674259208142757, 19.80210542678833, 20.95738973468542, 24.284867383539677, 21.714119128882885, 16.4686468988657, 22.229109294712543, 9.903953857719898, 9.947739858180285, 3.885722793638706, 1.729591190814972, 0.1967116742162034, 0.47073910594917834, 3.6296763829886913, 16.50076847523451, 43.72341401875019, 50.34224085509777, 39.540381878614426, 33.62820692360401, 41.59431606531143, 54.499099999666214, 58.15109543502331, 49.31694187223911, 17.490892745554447, 1.502409337554127, 0.09434797990252264, 0.2088209119392559, 0.10619446024065837, 0.16276779875624925, 0.13877471355954185, 0.15825518465135247, 0.0959634647006169, 0.10398727594292723, 0.32493184553459287, 0.16986507573165, 0.1267729388200678, 0.072654632240301, 0.21340362931368873, 0.1775672030635178, 0.15483567985938862, 0.1522718119667843, 0.21191768639255315, 0.18980661348905414, 0.11843985979794525, 0.16964191192528233, 0.22191717638634145, 0.12169460780569352, 0.12212857123813592, 0.14908850309439003, 0.17124003788921982], [0.00899878456039005, 0.042044576912303455, 0.0680014182580635, 0.05551400805416051, 0.015029002533992752, 0.02088156241370598, 0.024369483944610693, 0.03574649279471487, 0.04196873684122693, 0.028639716329053044, 0.018300788397027645, 0.022970502177486196, 0.04524979769485071, 0.09401636605616659, 0.08334949234267697, 0.03422910136578139, 0.03990875753515866, 0.04901814158074558, 0.06398303739842959, 0.028629105472646188, 0.04349594688392244, 0.04258599961758591, 0.04169069492490962, 0.026326837214583065, 1.2029635556973517, 18.586672246456146, 40.863026306033134, 53.47102336585522, 48.43393765389919, 30.039808675646782, 18.47991317510605, 17.29982189834118, 22.27073796093464, 31.321781985461712, 23.729071207344532, 5.774046666920185, 0.7096496829763055, 0.06162143443361856, 0.22415702260332182, 0.47927264648023993, 3.9642603043466806, 4.7608324605971575, 6.700526727363467, 9.46729363873601, 9.405403509736061, 8.045800365507603, 7.98214428126812, 8.831940181553364, 9.177144058048725, 15.01584330573678, 25.610091872513294, 38.70544508099556, 43.33013512194157, 46.03219673037529, 47.207713052630424, 52.22296133637428, 56.59978307783604, 55.4619987308979, 53.11726614832878, 53.469127267599106, 49.22384686768055, 46.54824323952198, 44.170631021261215, 41.17455258965492, 46.08651861548424, 50.174711644649506, 55.65456859767437, 57.8598752617836, 55.707131177186966, 55.374257639050484, 55.75784705579281, 45.59830941259861, 39.47996512055397, 48.12959298491478, 56.994163915514946, 55.016837418079376, 55.640630945563316, 53.53168711066246, 58.2335814088583, 54.36932176351547, 57.22271025180817, 56.08011536300182, 55.55027939379215, 51.58133156597614, 55.81398144364357, 51.49533458054066, 47.13779680430889, 48.81087742745876, 43.196617886424065, 59.03409585356712, 54.41349059343338, 51.14992171525955, 43.92977334558964, 43.52989040315151, 46.326099559664726, 49.86758552491665, 51.38935066759586, 54.22715999186039, 53.941723108291626, 55.05890496075153, 54.411548897624016, 54.71081703901291, 55.37223234772682, 52.89668418467045, 50.18385775387287, 44.95648965239525, 39.56986449658871, 39.760849848389626, 41.899663880467415, 46.146817579865456, 49.205098673701286, 52.422104850411415, 55.76004333794117, 53.75399798154831, 52.17900529503822, 52.38688454031944, 54.571037739515305, 53.20092245936394, 53.915774300694466, 53.578021824359894, 51.20743162930012, 53.32204855978489, 53.467728942632675, 51.387036591768265, 45.6671579182148, 36.59106753766537, 21.844889111816883, 5.801981342956424, 12.30559978634119, 23.65625761449337, 21.663522943854332, 10.002388525754213, 9.609387014061213, 8.147459160536528, 1.9482375145889819, 1.3110726233571768, 0.16881282906979322, 0.08592691927333362, 0.1660765305859968, 0.8204777422361076, 7.878861548379064, 21.504704765975475, 35.98863646388054, 29.093043878674507, 21.06553953140974, 27.609766870737076, 34.7319944947958, 42.202591225504875, 37.356855645775795, 16.475906409323215, 1.899047491606325, 0.021768222941318527, 0.03342987511132378, 0.02441024455038132, 0.08162420679582283, 0.041568162632756867, 0.016413269368058536, 0.06581011592061259, 0.07478940518922172, 0.039234327123267576, 0.05296675684803631, 0.057771710344241, 0.1075482415035367, 0.036257643296266906, 0.06593285972485319, 0.03008813626365736, 0.03001270622917218, 0.04073895361216273, 0.02880288677260978, 0.039817499346099794, 0.04050560382893309, 0.053543257163255475, 0.023068905393301975, 0.027948845490755048, 0.028439809575502295, 0.03465652647719253, 0.030995042579888832, 0.07832807663362473, 0.07160213324823417, 0.1177287487371359, 0.07443750844686292, 0.05454796184494626, 0.023117037380870897, 0.03523298597428948, 0.03237007709685713, 0.07605510094435886, 0.026898053438344505, 0.05310748289048206, 0.015169774032983696, 0.018009443483606447, 0.0725390798470471, 0.04590119184285868, 0.023229172184073832, 0.054176776684471406, 0.030166803917381912, 0.046117067759041674, 0.013588476267614169, 0.021075645163364243, 0.0408740319107892, 0.03870921311317943, 1.5806781314313412, 21.41016013920307, 48.00493687391281, 58.51755537092686, 51.18567779660225, 34.344400092959404, 19.196393229067326, 21.442217119038105, 26.443516351282597, 33.46384294331074, 27.49432146549225, 5.925500839948654, 0.7671965262852609, 0.01976019768335391, 0.17169628059491515, 0.3881172597175464, 5.781913194805384, 11.74541674554348, 10.185266062617302, 8.978713005781174, 9.325557444244623, 12.855969853699207, 10.421927813440561, 10.191675368696451, 11.251053772866726, 15.527309160679579, 27.09632322192192, 43.12810376286507, 50.552000999450684, 51.523460671305656, 51.29907891154289, 54.71525140106678, 58.59894700348377, 58.16027194261551, 56.45814187824726, 55.983972921967506, 52.07801431417465, 49.054014980793, 46.38876959681511, 43.280939161777496, 48.39215889573097, 50.64054384827614, 55.67708618938923, 58.37339110672474, 57.153808549046516, 57.2680152207613, 57.3738319426775, 48.0842500180006, 41.547130197286606, 50.305181443691254, 58.41168165206909, 56.217937767505646, 55.917324498295784, 53.88471096754074, 57.76022180914879, 55.270849987864494, 58.66277977824211, 57.07611031830311, 57.07510717213154, 52.51249819993973, 56.85407303273678, 51.774995774030685, 47.491766810417175, 51.486990228295326, 46.3289076089859, 58.92095312476158, 56.65803015232086, 52.38431207835674, 45.75613014400005, 45.42560487985611, 48.30202013254166, 52.15528316795826, 52.92377293109894, 56.338547095656395, 56.15571230649948, 55.93379281461239, 54.75230321288109, 55.344015061855316, 55.326828584074974, 55.41788309812546, 50.81097990274429, 46.65255904197693, 42.161481231451035, 42.295997813344, 45.01599445939064, 49.341967329382896, 50.90914003551006, 55.147812590003014, 57.65687495470047, 54.55571696162224, 51.68740287423134, 52.56077840924263, 53.95821802318096, 54.63575966656208, 54.39254231750965, 53.6070142686367, 50.75382336974144, 53.92885699868202, 52.85854563117027, 51.61092437803745, 45.18408603966236, 37.6024516671896, 24.29409708827734, 9.514101427048445, 17.792902439832687, 20.940140560269356, 14.56175247207284, 14.298308808356524, 10.586044806987047, 8.148278016597033, 3.9928385708481073, 1.9644254771992564, 1.0636720550246537, 0.4241769388318062, 0.21974609757307917, 1.0786711564287543, 8.388493526726961, 25.294368714094162, 38.824044317007065, 34.174423813819885, 26.56977977603674, 32.19140522181988, 41.82486489415169, 49.01334956288338, 44.30847242474556, 19.83735803514719, 2.5196958566084504, 0.03114121784165036, 0.029037796921329573, 0.053308645728975534, 0.02587289702205453, 0.09380552932270803, 0.019897441197826993, 0.042999498327844776, 0.05339537681720685, 0.033823599296738394, 0.03280748780525755, 0.03945852251490578, 0.06375539102009498, 0.012833710225095274, 0.04979055775038432, 0.10204423684626818, 0.00210379640066094, 0.035153524222550914, 0.04805430697160773, 0.03974275023210794, 0.05695885083696339, 0.03799710015300661, 0.026056686183437705, 0.011176099269505357, 0.1025691578979604, 0.03987526441051159, 0.11754486680729315, 0.12548072612844408, 0.19434401532635093, 0.1901378488400951, 0.1625275210244581, 0.11394512403057888, 0.09502807661192492, 0.09703191986773163, 0.19565924943890423, 0.19618556572822854, 0.12473301234422252, 0.23926581343403086, 0.16823536396259442, 0.16144276829436421, 0.21225088101346046, 0.10130809314432554, 0.11629058528342284, 0.13865717221051455, 0.1510647829854861, 0.1434188659186475, 0.10797431590617634, 0.14937547675799578, 0.17825112183345482, 0.08367187387193553, 2.154057389125228, 26.153415217995644, 56.29007309675217, 66.36436611413956, 59.28411103785038, 41.50926522910595, 27.813435941934586, 26.383677162230015, 33.89378987252712, 42.10516445338726, 31.178520172834396, 6.823291014879942, 1.1693260981701314, 0.15086674829944968, 0.5627847136929631, 1.1193736223503947, 10.166403874754906, 18.412472493946552, 15.310263857245445, 24.3910925835371, 25.381342247128487, 21.583427041769028, 15.150365587323904, 15.304847247898579, 14.241619650274515, 19.44322608411312, 32.44477942585945, 48.83099354803562, 53.03786940872669, 53.64873982965946, 53.35664190351963, 54.648420587182045, 58.45941089093685, 58.58778700232506, 58.01806837320328, 59.901889488101006, 54.04784381389618, 51.5140637755394, 48.10649782419205, 45.63584379851818, 48.976286351680756, 53.9100556075573, 58.33649508655071, 59.965885654091835, 57.080616876482964, 58.41010473668575, 59.928035885095596, 50.966148376464844, 44.00932967662811, 52.235097885131836, 60.19416980445385, 58.68011064827442, 57.12500609457493, 54.14560116827488, 57.50842072069645, 55.36411598324776, 61.10946848988533, 61.364180222153664, 59.26094748079777, 56.13828644156456, 57.29616031050682, 52.35150843858719, 50.104404017329216, 56.07230678200722, 48.58019940555096, 61.43429026007652, 59.59110036492348, 53.65076892077923, 49.23518545925617, 47.29570873081684, 50.22100456058979, 54.25616383552551, 56.28860257565975, 58.87348607182503, 56.28670647740364, 57.66788676381111, 56.16513580083847, 55.065645799040794, 58.82653199136257, 57.785361260175705, 54.05402608215809, 50.064433962106705, 44.10300984978676, 44.447883144021034, 45.85344672203064, 52.839029878377914, 53.350626826286316, 59.19291213154793, 58.965308144688606, 55.173495411872864, 52.53412663936615, 54.1704898327589, 53.67582857608795, 55.33814437687397, 54.73751440644264, 56.09268508851528, 52.67716996371746, 55.865187495946884, 55.039096623659134, 53.32036904990673, 47.64963313937187, 41.552309319376945, 27.43890143930912, 10.804390590637922, 20.808992497622967, 34.18974079191685, 31.865263022482395, 18.53389497846365, 17.79534000903368, 13.320472128689289, 9.134945422410965, 4.635983984917402, 1.2161598913371563, 0.26392442698124796, 0.40811134153045714, 1.1427365499548614, 10.966407246887684, 29.16520580649376, 47.91981004178524, 41.21048346161842, 31.942484378814697, 39.88126918673515, 47.712337374687195, 57.486104518175125, 51.40106163918972, 27.652607671916485, 3.9337505539879203, 0.06960978585993871, 0.1425392131204717, 0.10722217892180197, 0.20628030295483768, 0.2193007050664164, 0.11599759280215949, 0.12516436341684312, 0.17219628032762557, 0.13083264988381416, 0.08723191916942596, 0.22507703339215368, 0.16253607056569308, 0.11334980285027996, 0.20006434118840843, 0.19924395630368963, 0.14714248798554763, 0.13574124430306256, 0.11113225817098282, 0.10661062697181478, 0.11029947199858725, 0.10632576100761071, 0.11802558554336429, 0.06229097780305892, 0.23006497824098915, 0.14654016093118116], [0.0039888053470349405, 0.056859495816752315, 0.061063788380124606, 0.05268370914564002, 0.0362759483687114, 0.06083994550863281, 0.09879956720396876, 0.016213041635637637, 0.05566937295952812, 0.07947780439280905, 0.03399415596504696, 0.04933611104206648, 0.03468015645921696, 0.010685113848012406, 0.010112981999554904, 0.015800750770722516, 0.06892133998917416, 0.10004644209402613, 0.03760483057703823, 0.11154417239595205, 0.030347535430337302, 0.050044862073264085, 0.022595120171899907, 0.07101674200384878, 1.3947101728990674, 17.37096168100834, 46.473995223641396, 54.18555222451687, 49.707070738077164, 38.90166275203228, 31.940614879131317, 26.893353313207626, 32.77150109410286, 31.722734570503235, 18.80267735570669, 3.094966937787831, 0.1682883978355676, 0.014083628848311491, 0.2525056240847334, 0.6787240924313664, 3.3333369344472885, 7.448527039960027, 8.518087472766638, 4.511863645166159, 7.899334849789739, 9.647251032292843, 10.007210467010736, 9.401999842375517, 12.795757334679365, 27.04686127603054, 35.41573740541935, 50.35498917102814, 50.1360335201025, 52.346230521798134, 53.083364367485046, 57.57941611111164, 54.268163591623306, 54.49063025414944, 54.84154522418976, 53.59675481915474, 47.30895482003689, 44.45207431912422, 41.97861224412918, 42.633571699261665, 45.02403482794762, 50.165622532367706, 55.3425407409668, 56.98499880731106, 53.67659233510494, 55.88687673211098, 52.75638811290264, 42.483650743961334, 39.70919921994209, 51.17686226963997, 55.14755420386791, 59.99903507530689, 54.47028994560242, 51.37032128870487, 57.960011288523674, 51.937828436493874, 53.11090908944607, 49.964506924152374, 52.53747045993805, 49.10404309630394, 53.476046696305275, 52.84891314804554, 50.68250499665737, 30.53224705159664, 40.438452288508415, 60.22494055330753, 51.36590972542763, 51.608446910977364, 41.14863038063049, 42.773647382855415, 42.33600586652756, 46.14918105304241, 49.58435632288456, 52.18369424343109, 53.75087454915047, 56.15590609610081, 54.18850086629391, 53.675881773233414, 51.851778253912926, 55.57488687336445, 52.63858303427696, 49.42843548953533, 43.90632480382919, 38.79788652062416, 39.48014371097088, 42.56212033331394, 46.79219774901867, 50.89810162782669, 54.45664867758751, 53.78527030348778, 52.588976696133614, 52.01561026275158, 52.79673054814339, 49.533845633268356, 54.33930717408657, 54.69927325844765, 56.34444817900658, 57.722265645861626, 56.40479654073715, 51.20186112821102, 46.51043526828289, 36.7764937877655, 30.421811677515507, 10.206960048526525, 19.04918532818556, 18.194358497858047, 5.761637482792139, 10.3604338131845, 9.303644970059395, 7.16056851670146, 1.419464775826782, 2.1944183483719826, 0.46809679304715246, 0.05528508518182207, 0.050410651820129715, 0.31158408208284527, 3.848731778562069, 20.21330416202545, 37.85985365509987, 30.71087546646595, 21.731750182807446, 25.629335939884186, 39.070529490709305, 45.09667173027992, 41.92422956228256, 25.638744235038757, 3.4617610182613134, 0.2586967684328556, 0.029827332582499366, 0.023203530981845688, 0.10185928622377105, 0.04851821235206444, 0.03580203512683511, 0.061918145074741915, 0.030572589857911225, 0.022730957316525746, 0.040275820065289736, 0.02680886955204187, 0.06802293311920948, 0.07482522865757346, 0.024012920948734973, 0.05309408712491859, 0.04443554666067939, 0.032939634620561264, 0.040446016791975126, 0.05226491892244667, 0.049975285728578456, 0.028371598782541696, 0.03320078525575809, 0.07126506461645477, 0.06597988962312229, 0.10326633884687908, 0.051000688908970915, 0.010161414556932868, 0.06686450738925487, 0.019450521722319536, 0.13032801914960146, 0.04671145754400641, 0.05227081157499924, 0.03321437026897911, 0.11001616454450414, 0.038208623373066075, 0.012931282235513208, 0.010587646665953798, 0.028160559813841246, 0.004846562933380483, 0.013031255093665095, 0.03305096419353504, 0.12320124922553077, 0.020308997336542234, 0.020395344363350887, 0.02061332797893556, 0.029463082792062778, 0.08724449857254513, 0.03462824322923552, 0.06896151986438781, 1.8512838170863688, 21.785213313996792, 52.783720046281815, 61.85899347066879, 54.5357870310545, 44.46362189948559, 34.42510776221752, 31.403504200279713, 35.338875129818916, 32.21891574561596, 20.70419792085886, 3.621759032830596, 0.3738842031452805, 0.11572026705835015, 0.42329853284172714, 1.9723417586646974, 6.570707643404603, 10.429383013397455, 11.631206274032593, 11.005062572658062, 11.130839623510838, 6.024286039173603, 10.512658394873142, 5.290400544181466, 14.64667221531272, 27.276826836168766, 39.83751453459263, 51.4466667920351, 53.38827520608902, 52.563457265496254, 55.66621117293835, 59.38615836203098, 58.14717024564743, 56.79697349667549, 56.49861350655556, 55.585602298378944, 51.21502362191677, 48.099730387330055, 44.356034472584724, 44.22384716570377, 46.92752368748188, 52.40175314247608, 57.95843817293644, 57.74095684289932, 55.693820491433144, 57.99996994435787, 55.84302328526974, 45.18527917563915, 39.74817372858524, 51.628984808921814, 58.78150440752506, 58.447228744626045, 54.47028614580631, 52.226479947566986, 59.486499577760696, 54.87508602440357, 55.332934856414795, 51.63421332836151, 55.262524634599686, 52.148367539048195, 55.53970456123352, 55.040589943528175, 52.33688302338123, 35.379624143242836, 43.92295651137829, 62.46394760906696, 54.332167357206345, 52.05658346414566, 43.46522927284241, 45.743492022156715, 44.85630802810192, 49.479709938168526, 51.310744285583496, 54.579416289925575, 56.26895762979984, 57.784426510334015, 56.850691214203835, 54.162164479494095, 52.84638628363609, 56.633886247873306, 56.94293886423111, 51.23285986483097, 46.86906762421131, 41.12876124680042, 42.164680659770966, 45.05176953971386, 49.59531493484974, 52.64205604791641, 57.14648634195328, 55.9423803538084, 53.35766404867172, 53.13890978693962, 53.255107551813126, 50.551222041249275, 55.13300098478794, 56.02835834026337, 57.292459309101105, 58.99854116141796, 57.258048355579376, 52.056279480457306, 48.21821182966232, 37.00382798910141, 26.76556997001171, 14.097473435103893, 16.53533522039652, 12.800097651779652, 14.471684955060482, 15.51845183596015, 10.816004667431116, 13.100714720785618, 5.643229186534882, 2.7261831890791655, 1.3628760748542845, 0.19999450509203598, 0.07460653258021921, 0.36186595272738487, 4.776349402964115, 22.3480961099267, 37.20203295350075, 32.675575241446495, 23.260309360921383, 29.73009679466486, 44.18160483241081, 51.3076588511467, 47.9390674084425, 30.058678463101387, 4.640856273472309, 0.11228258706978522, 0.020579341326083522, 0.017789793746487703, 0.07719970046309754, 0.03478800535958726, 0.04877083199971821, 0.10064021960715763, 0.004104952386114746, 0.017161437717732042, 0.10626735398545861, 0.045702233182964846, 0.018365114046901, 0.03990832337876782, 0.03223632353183348, 0.04824105359148234, 0.016193022202060092, 0.06143823156889994, 0.005006529154343298, 0.03466689428023528, 0.06420983772841282, 0.030910790264897514, 0.03277761265053414, 0.0024740490061958553, 0.013539663359551923, 0.09834489785134792, 0.13756352855125442, 0.12640131579246372, 0.17807067604735494, 0.161324366054032, 0.2605659712571651, 0.17940201476449147, 0.15210126643069088, 0.0834823887271341, 0.15959817508701235, 0.10593644517939538, 0.121470041340217, 0.12982343294424936, 0.10172476453590207, 0.09780246953596361, 0.08397974641411565, 0.1815984898712486, 0.19102478952845559, 0.14617064560297877, 0.12332981146755628, 0.21664380154106766, 0.10026591742644086, 0.14644997514551505, 0.0976960158732254, 0.19102351303445175, 2.992082233540714, 26.4240974932909, 60.97126990556717, 68.2578881084919, 61.828021332621574, 52.14503891766071, 43.42926800251007, 37.5509150326252, 45.933896005153656, 42.00231917202473, 23.69619157165289, 4.760568849742413, 0.44995125266723335, 0.24361916264751926, 0.9912363637704402, 2.943945466540754, 13.00901424139738, 17.357299514114857, 19.174291715025902, 16.045123524963856, 16.146635077893734, 21.45256206393242, 19.45195611566305, 15.694942865520716, 17.173564173281193, 31.394468285143375, 44.28289979696274, 56.108765825629234, 57.125097289681435, 57.531766667962074, 56.78272806107998, 61.98637783527374, 59.930984526872635, 59.08700041472912, 59.64046731591225, 58.1642959266901, 53.090515583753586, 51.062989979982376, 46.41250692307949, 47.006187066435814, 50.43362595140934, 53.95149618387222, 59.52041655778885, 60.16229711472988, 56.0381618142128, 60.0674732029438, 58.45252186059952, 46.28273628652096, 43.64680252969265, 54.06189925968647, 61.16801954805851, 59.87499453127384, 55.44651836156845, 53.29257734119892, 60.080217719078064, 57.21648618578911, 58.086814284324646, 54.34673957526684, 55.872521102428436, 54.17455181479454, 57.313289791345596, 55.17019718885422, 52.71296784281731, 37.92163833975792, 46.21303662657738, 64.1076748073101, 56.877274587750435, 54.47964124381542, 44.89825777709484, 47.909292206168175, 46.85272850096226, 51.05767406523228, 54.47837591171265, 56.530132815241814, 58.80271486938, 60.4216293990612, 58.72616797685623, 54.873493909835815, 52.29133486747742, 58.34649235010147, 58.36754322052002, 53.24878469109535, 48.949778974056244, 42.06530839204788, 43.97509731352329, 47.63500392436981, 53.70354048907757, 55.63055008649826, 59.12405602633953, 58.14451038837433, 55.610452964901924, 53.75949628651142, 54.3524506688118, 50.70423603057861, 55.72233036160469, 57.633821591734886, 58.803759813308716, 60.2060441672802, 60.0443210452795, 53.95907297730446, 51.08697809278965, 43.94854053854942, 33.24183605611324, 14.301590882241726, 24.88281089812517, 29.8876990377903, 17.75074940174818, 23.8455368578434, 19.57936517894268, 18.36797308176756, 8.683246560394764, 7.2984816413372755, 2.7430609334260225, 0.4279478802345693, 0.33598889596760273, 0.7915566628798842, 5.181187754496932, 26.89092144370079, 48.042490258812904, 44.32389959692955, 34.29467596113682, 38.79182204604149, 51.4530960470438, 57.50104911625385, 55.9990581125021, 36.35751686990261, 7.152682989835739, 0.4900499666109681, 0.14552877692040056, 0.21142334182513878, 0.20309944316977635, 0.12403542321408167, 0.10104982575285248, 0.23284534545382485, 0.052069047596887685, 0.16730273666325957, 0.1707483798963949, 0.1368984900182113, 0.13156108267139643, 0.11967040743911639, 0.11849917966173962, 0.14093197358306497, 0.13495262333890423, 0.12240579308127053, 0.14405833004275337, 0.15713706496171653, 0.1327706646407023, 0.1491840768721886, 0.17195978754898533, 0.13241527980426326, 0.14935675979359075, 0.23348762973910198], [0.03618276059569325, 0.024000751582207158, 0.154124895343557, 0.0719193642726168, 0.016112408266053535, 0.0112047062793863, 0.07119529531337321, 0.04118494725844357, 0.021853807411389425, 0.014345436284202151, 0.05391654260165524, 0.038780459290137514, 0.05613677014480345, 0.03615506735513918, 0.02222194234491326, 0.046831284707877785, 0.03922890573448967, 0.010885299834626494, 0.03956581109378021, 0.06380384584190324, 0.024629333966004197, 0.03129048229311593, 0.0610392232920276, 0.12626997049665079, 1.1877619964070618, 17.68743719905615, 47.90455386042595, 54.96198356151581, 44.47744935750961, 31.196552105247974, 15.905944593250751, 21.38751145452261, 35.979509353637695, 32.766291573643684, 14.231665134429932, 1.6596204391680658, 0.14755613141460344, 0.018383458082098514, 0.1411716575967148, 0.5481870844960213, 5.127499010413885, 9.270539246499538, 7.143734944984317, 6.453848239034414, 5.034777335822582, 3.502222434617579, 5.760376900434494, 7.526123626157641, 20.637813583016396, 35.67142188549042, 41.91031090915203, 46.06480658054352, 52.66152620315552, 53.56901630759239, 54.473272785544395, 51.83222070336342, 54.01864618062973, 53.14565062522888, 51.01465277373791, 48.63549403846264, 47.00191609561443, 42.14890770614147, 40.30651196837425, 42.423351779580116, 46.232989355921745, 51.07131913304329, 55.925874039530754, 54.38061475753784, 54.928476959466934, 56.02841533720493, 53.764215633273125, 40.28082154691219, 38.63424830138683, 49.2240596562624, 55.83650663495064, 49.24652025103569, 47.565410658717155, 56.08109951019287, 56.890068501234055, 51.33346326649189, 51.410781517624855, 43.866373747587204, 45.2257964015007, 46.50888495147228, 51.39650948345661, 53.23857843875885, 42.461877912282944, 24.82265442609787, 42.56992131471634, 57.41013899445534, 50.79428359866142, 49.116704016923904, 46.010085716843605, 45.44198960065842, 42.97375224530697, 44.228247329592705, 43.38914595544338, 46.176341995596886, 48.43084841966629, 52.17130310833454, 54.23369564116001, 56.32080964744091, 50.09470693767071, 53.69944430887699, 54.9528868496418, 52.04287759959698, 50.1007030159235, 40.847067162394524, 39.062416926026344, 40.01479782164097, 43.349023908376694, 46.11949324607849, 52.62607790529728, 54.014379009604454, 52.615294083952904, 51.800712794065475, 54.03749316930771, 54.05478224158287, 53.1773941218853, 53.60963612794876, 53.08712996542454, 55.62615752220154, 55.973759070038795, 54.443345591425896, 52.870142608881, 38.643348813056946, 32.5580969452858, 20.81574473530054, 26.28463927656412, 8.396298307925463, 17.64110818505287, 15.701034888625145, 8.241598159074783, 9.679950177669525, 2.394199278205633, 0.36865957255940884, 2.2825026093050838, 0.5653806868940592, 0.06585379873286001, 0.1927563684876077, 1.7186982440762222, 11.696022246032953, 31.252882182598114, 30.766067504882812, 35.4553996771574, 29.083882570266724, 28.523406945168972, 39.31249290704727, 47.763471230864525, 30.392095372080803, 8.978196233510971, 0.19026267807930708, 0.10067500406876206, 0.04157992567343172, 0.048728971160016954, 0.039382923641824163, 0.06236755260033533, 0.034336783282924443, 0.03224132189643569, 0.0716927346365992, 0.028560647915583104, 0.06939278930076398, 0.031407381684402935, 0.04227430130413268, 0.03828432614682242, 0.053184213538770564, 0.011910268858628115, 0.07067080470733345, 0.013040864050708478, 0.036899619590258226, 0.05960380207397975, 0.03841322977677919, 0.03357034882355947, 0.032239407155429944, 0.056899994815466926, 0.09147833232418634, 0.022975919855525717, 0.01625425309612183, 0.017584988818271086, 0.03215193763026036, 0.020147227696725167, 0.015799752582097426, 0.051296360543346964, 0.02780812130367849, 0.006555994814334554, 0.07512970216339454, 0.030773426151426975, 0.05483714339789003, 0.012550627270684345, 0.03326864723931067, 0.08008636548765935, 0.07179595995694399, 0.06933451586519368, 0.07249528571264818, 0.03684311617689673, 0.03397816268261522, 0.0751594771281816, 0.06351767369778827, 0.04142694306210615, 0.13645254832226783, 1.768916230648756, 21.068193688988686, 54.95998106896877, 62.282446548342705, 50.496109798550606, 37.52262555062771, 20.43586391955614, 21.497792936861515, 31.875113993883133, 33.72922830283642, 15.326587781310081, 2.2896103654056787, 0.046503055054927245, 0.13711194653296843, 0.29251845669932663, 3.1005552504211664, 8.289082311093807, 11.497003175318241, 15.480672363191843, 8.657073564827442, 10.983526278287172, 10.037377048283815, 5.537200151011348, 7.761834478005767, 23.57396923005581, 37.97913305461407, 43.324070647358894, 50.59941865503788, 54.3382204324007, 54.72629740834236, 57.65237599611282, 54.19473633170128, 55.04544988274574, 57.82465875148773, 54.37823988497257, 50.676497519016266, 49.38883401453495, 44.22091372311115, 41.867901384830475, 44.46288473904133, 47.498291060328484, 52.305371314287186, 57.94894628226757, 57.839006781578064, 55.38481347262859, 56.37419678270817, 55.35985641181469, 43.28302524983883, 40.978080332279205, 51.832604482769966, 55.65438620746136, 53.337977305054665, 50.26083402335644, 56.76589876413345, 59.38582397997379, 54.246869534254074, 53.675642386078835, 47.0562531799078, 48.62211115658283, 49.17394794523716, 54.464096277952194, 55.066717341542244, 43.873380571603775, 28.214736208319664, 45.04236124455929, 58.88779230415821, 52.37635910511017, 51.66236221790314, 47.47504770755768, 47.827323004603386, 45.25638855993748, 45.631078854203224, 45.9121535718441, 49.89639177918434, 52.13225640356541, 55.140463784337044, 56.86470866203308, 57.074529603123665, 51.029023602604866, 54.42930914461613, 55.47299154102802, 53.90116028487682, 50.95028042793274, 42.98450566828251, 41.042935252189636, 42.705422043800354, 46.02493532001972, 49.196898713707924, 55.043367594480515, 56.34755641222, 54.08583417534828, 52.03762248158455, 52.92320296168327, 55.314095467329025, 57.38235868513584, 56.87765836715698, 56.56535692512989, 58.12256656587124, 57.85946108400822, 55.09565278887749, 51.93024404346943, 40.955106765031815, 30.683334544301033, 20.880989134311676, 13.136130720376968, 11.196035575121641, 10.96468023955822, 13.126555234193802, 11.02727523073554, 10.321858283132315, 7.694227080792189, 4.349775267764926, 2.040311680175364, 0.601290778722614, 0.05732117475417908, 0.1368069535237737, 2.4069924792274833, 14.796547573059797, 34.959678277373314, 35.08944891393185, 41.07092835009098, 36.264034286141396, 36.39124006032944, 46.19533337652683, 55.2069678157568, 35.306356474757195, 10.260434579104185, 0.3223408595658839, 0.035707552306121215, 0.030905710264050867, 0.04591527409502305, 0.07261016275151633, 0.10454774586833082, 0.03342699186760001, 0.02596522019302938, 0.05228938382060733, 0.039713817604933865, 0.028973779262742028, 0.020071129729331005, 0.024802688531053718, 0.02569718984887004, 0.060312252535368316, 0.031044636598380748, 0.00854237765452126, 0.033793397597037256, 0.008736374129512114, 0.06277253516600467, 0.043456772618810646, 0.05695630898117088, 0.029296379725565203, 0.024905919417506084, 0.03737942548468709, 0.10382822627434507, 0.09557018580380827, 0.25465535873081535, 0.18733229313511401, 0.1390278898179531, 0.08718611381482333, 0.26259999023750424, 0.08942461674450897, 0.11499155225465074, 0.15155403641983867, 0.06407285211025737, 0.17822510213591158, 0.13539798615965992, 0.1316198310814798, 0.1332595173153095, 0.17127521568909287, 0.12350233111646958, 0.19761379924602807, 0.10590223959297873, 0.1866484634228982, 0.15014929929748178, 0.1357612229185179, 0.1430819754023105, 0.20673387392889708, 2.823787364177406, 27.338265739381313, 62.63666734099388, 68.54487910866737, 57.76494115591049, 43.70419465005398, 23.181623183190823, 30.43440230190754, 46.711098700761795, 41.86925411224365, 18.54917585849762, 2.3723466508090496, 0.2773007779615, 0.22084832045948133, 0.43142101261764765, 2.847703993320465, 11.044660247862339, 19.132419861853123, 18.984292410314083, 18.923090994358063, 15.421137157827616, 11.042292974889278, 16.63071770220995, 12.103427834808826, 27.68961388617754, 42.62074738740921, 46.66639789938927, 51.23489275574684, 57.564053535461426, 56.843874379992485, 61.23680345714092, 57.598669677972794, 59.881780967116356, 60.17007529735565, 57.089527398347855, 53.862634152173996, 51.202472895383835, 46.37799717485905, 42.721654772758484, 46.683006808161736, 49.47066642343998, 55.33816337585449, 60.58157041668892, 57.41558790206909, 57.45225593447685, 59.9780298024416, 59.07117426395416, 45.50691291689873, 42.94948674738407, 54.99985612928867, 58.65823522210121, 55.647462978959084, 52.4844329059124, 58.928776904940605, 61.62365309894085, 56.15607708692551, 55.21010264754295, 47.93086364865303, 49.64205242693424, 51.54877871274948, 57.277761697769165, 58.586377277970314, 46.203696727752686, 32.931715697050095, 48.41235101222992, 62.05008901655674, 54.33114521205425, 53.42175520956516, 49.41300451755524, 48.97836484014988, 47.37777292728424, 49.87546630203724, 46.98738567531109, 52.31003746390343, 53.08679178357124, 55.87895415723324, 60.22497855126858, 59.98058706521988, 51.69853247702122, 56.77121847867966, 57.85064935684204, 56.61383852362633, 54.498362839221954, 45.13561584055424, 43.217592760920525, 44.35524791479111, 48.57668839395046, 51.427785605192184, 58.51792775094509, 58.73384356498718, 55.34721828997135, 52.54331834614277, 54.72055971622467, 55.46069160103798, 58.05606633424759, 57.947920337319374, 59.32995557785034, 60.494384095072746, 59.90239106118679, 57.12044253945351, 55.79843267798424, 42.45744735002518, 35.82139603793621, 24.54084824770689, 33.92553336918354, 19.13619875907898, 25.74455715715885, 28.23345970362425, 16.85675047338009, 17.991819866001606, 9.384637624025345, 5.376273086294532, 4.248267514631152, 1.0124841704964638, 0.25392250274308026, 0.4139640071662143, 2.74528072681278, 16.476662568747997, 40.93224339187145, 44.88813132047653, 48.20881873369217, 40.24171404540539, 41.29806496202946, 55.22163882851601, 62.11234487593174, 42.9092963039875, 13.959474340081215, 0.8224282250739634, 0.18870694359065965, 0.14120331761660054, 0.1676335564116016, 0.1115198596380651, 0.1318911009002477, 0.16451830248115584, 0.10214033012744039, 0.15369428641861305, 0.06636807738686912, 0.16542449448024854, 0.0676800608925987, 0.12693034834228456, 0.12086519098374993, 0.12476860574679449, 0.10029953671619296, 0.1418287106207572, 0.11062185352784581, 0.07504867448005825, 0.12160682657849975, 0.11355470240232535, 0.12371353892376646, 0.14774675946682692, 0.07697063658270054, 0.24290395493153483], [0.060989135745330714, 0.047604175852029584, 0.0308632538508391, 0.025563892704667524, 0.03965412295656279, 0.029188519692979753, 0.05845460495038424, 0.028701926858047955, 0.05371302344428841, 0.08089413386187516, 0.004980635621905094, 0.029001090297242627, 0.004437273591975099, 0.014925535087968456, 0.06677308963844553, 0.05177699764317367, 0.012106388803658774, 0.04352786665549502, 0.006923220153112197, 0.03816463256953284, 0.08647242750157602, 0.049009165304596536, 0.0481632913579233, 0.0632153895276133, 1.9593687797896564, 23.2030426338315, 46.16126820445061, 53.53246986865997, 49.87639345228672, 33.09322603046894, 23.149511106312275, 40.060577765107155, 42.30750359594822, 25.62356024980545, 8.078182227909565, 0.9167029475793242, 0.09245844223187305, 0.07784133907989599, 0.28722804214339703, 3.9298536255955696, 4.891822831705213, 9.62482938542962, 12.70936232060194, 8.342468496412039, 13.33683405071497, 8.330179005861282, 8.401071801781654, 7.843735758215189, 22.608328945934772, 33.64819385111332, 42.797992676496506, 48.735109493136406, 51.381967663764954, 55.84809981286526, 52.81238190829754, 49.916401505470276, 48.61775279045105, 47.02893644571304, 46.01253658533096, 42.74435855448246, 41.99736803770065, 40.7252798974514, 41.265219524502754, 45.315125808119774, 48.80774639546871, 51.23025320470333, 55.07755436003208, 52.79706113040447, 54.757326543331146, 53.38042102754116, 52.858572229743004, 41.27083942294121, 38.06272476911545, 46.92319951951504, 61.12140364944935, 51.35712459683418, 56.54020607471466, 55.30843377113342, 51.61409720778465, 51.59608617424965, 41.542961820960045, 40.57990349829197, 41.84497341513634, 48.446005806326866, 47.192620262503624, 58.099349811673164, 38.4712902456522, 21.048309355974197, 45.26634402573109, 58.87411303818226, 53.48244555294514, 53.56724180281162, 54.11798804998398, 53.53641405701637, 50.81667959690094, 46.249564066529274, 43.3882150053978, 40.0500675290823, 40.40219463407993, 48.015925884246826, 52.253868877887726, 54.73903812468052, 53.762311935424805, 52.04090930521488, 53.98565635085106, 54.47055973112583, 52.30205029249191, 44.58249852061272, 41.035259664058685, 43.37608985602856, 41.09018571674824, 44.530144929885864, 49.5440024882555, 53.725275322794914, 53.812967017292976, 52.38870844244957, 51.087437868118286, 54.639734253287315, 54.72329556941986, 52.55204647779465, 54.80080381035805, 55.18585614860058, 57.16318264603615, 54.267939403653145, 52.79893442988396, 45.96518352627754, 32.16936260461807, 31.51257924735546, 11.305052675306797, 8.359963707625866, 9.031942449510098, 12.115975711494684, 12.149956338107586, 10.854273363947868, 5.529963439330459, 3.5755739361047745, 0.5471699859481305, 0.07439913941198029, 0.06252568200579844, 0.09497836756054312, 1.2237522401846945, 9.607377871870995, 23.670615144073963, 33.68242621421814, 24.524070248007774, 22.455641739070415, 23.164537400007248, 38.97569037973881, 43.62024575471878, 36.02077893912792, 12.886381521821022, 0.7614501658827066, 0.029559999857156072, 0.038340503015206195, 0.02851140270649921, 0.01249269151230692, 0.07995378822670318, 0.006803755250075483, 0.027848501558764838, 0.07415114334435202, 0.03533919843903277, 0.01463503065679106, 0.11448867298895493, 0.0721278038690798, 0.02241237372800242, 0.006868091568321688, 0.028692744635918643, 0.03851240668154787, 0.0837100796343293, 0.10717611381551251, 0.06247581710340455, 0.04413575239595957, 0.0625782112183515, 0.030205124712665565, 0.050426682209945284, 0.046524042991222814, 0.009670212057244498, 0.028506257767730858, 0.04326549889810849, 0.02410084689472569, 0.04104082960111555, 0.05085998884169385, 0.03131863195449114, 0.05351717809389811, 0.023549993347842246, 0.03930235980078578, 0.08233448665123433, 0.024040543685259763, 0.053255686070770025, 0.0954007831751369, 0.04684748579165898, 0.051574383905972354, 0.06634327481151558, 0.032329273817595094, 0.008062108845479088, 0.011330421457387274, 0.0475733433268033, 0.04421927369548939, 0.04069474758580327, 0.05056141540990211, 3.4330100985243917, 27.686959728598595, 54.112797528505325, 59.07683216035366, 55.43646790087223, 38.56911599636078, 24.75202951580286, 35.69909580051899, 44.36645731329918, 28.211247995495796, 9.197161383926868, 0.9876865823753178, 0.14334371604491025, 0.051889715032302774, 1.9484188361093402, 6.195818334817886, 8.529425114393234, 8.703335132449865, 12.618764732033014, 10.837102085351944, 8.523337841033936, 6.12862654030323, 7.7017967496067286, 9.28604431450367, 26.701672598719597, 35.96380099654198, 45.5471071600914, 51.118934378027916, 51.19650341570377, 57.245201244950294, 55.27132876217365, 52.676197215914726, 51.91679276525974, 50.52446387708187, 48.52051980793476, 45.6822507083416, 43.781995475292206, 42.89787411689758, 42.86153666675091, 45.96072256565094, 50.823158249258995, 54.9962767213583, 58.709939047694206, 53.91227088868618, 54.92580950260162, 56.43448814749718, 54.2994587123394, 44.03357617557049, 39.77640621364117, 49.644199311733246, 61.29718981683254, 54.04641889035702, 57.356824055314064, 57.33959957957268, 53.70759107172489, 53.44340644776821, 45.09295552968979, 42.63181619346142, 43.21189306676388, 50.677534863352776, 49.95516702532768, 59.352081790566444, 40.85020959377289, 25.65797310322523, 44.97255519032478, 61.37497164309025, 56.600820422172546, 54.45641689002514, 55.89360997080803, 56.67506843805313, 53.36194261908531, 47.52511382102966, 44.02750410139561, 41.16800554096699, 44.19279523193836, 50.87355114519596, 54.39051702618599, 57.6390615105629, 54.173389077186584, 52.236013635993004, 54.92412619292736, 56.13072484731674, 53.3948640525341, 46.850444823503494, 43.26910279691219, 44.91401553153992, 43.06962110102177, 46.76003247499466, 52.71563149988651, 57.37824350595474, 56.332570016384125, 54.05586898326874, 52.745167315006256, 56.164907813072205, 55.874603390693665, 56.22690908610821, 56.484675854444504, 57.31074392795563, 58.36003862321377, 55.48007056117058, 56.31862096488476, 44.611840546131134, 32.56304807960987, 25.105860829353333, 12.022632770240307, 14.060107190161943, 14.859394300729036, 19.353567995131016, 11.92953871563077, 12.261503152549267, 9.829129222780466, 3.83641782682389, 2.72601671051234, 1.182924855966121, 0.05643140277243219, 0.083875118434662, 1.1924166278913617, 9.817747883498669, 28.70020005851984, 36.26816846430302, 29.715950153768063, 27.688641138374805, 27.908406145870686, 43.781497702002525, 51.432949528098106, 40.87374173104763, 15.613540783524513, 1.1815235624089837, 0.030054229391680565, 0.07407557044643909, 0.08156568103004247, 0.024846078194968868, 0.005453635094454512, 0.012300439084356185, 0.0583444850781234, 0.08276865046354942, 0.048414983320981264, 0.032165559750865214, 0.11780629574786872, 0.05152893478225451, 0.03685671974380966, 0.03713693986355793, 0.015219779015751556, 0.0749314745189622, 0.059373524782131426, 0.012494584916566964, 0.03357820816745516, 0.02771664603642421, 0.008658848455525003, 0.03624560937169008, 0.0351534611399984, 0.03854396280075889, 0.20392150530824438, 0.11364482881617732, 0.11157506058225408, 0.10963386943330988, 0.16157862584805116, 0.121953179477714, 0.12865647993749008, 0.15524555317824706, 0.17473777988925576, 0.17590805771760643, 0.1712941998266615, 0.11325235886033624, 0.1734980518813245, 0.15974135021679103, 0.14097513689193875, 0.10942931869067252, 0.1660622368217446, 0.13438020483590662, 0.0845372403273359, 0.09040143893798813, 0.13118509581545368, 0.13717833906412125, 0.16333110368577763, 0.19314124627271667, 4.282146971672773, 33.32199655473232, 59.7098021954298, 65.56583896279335, 61.559729129076004, 45.65971791744232, 33.7301554530859, 51.64789639413357, 55.09417846798897, 34.303385093808174, 10.986547116190195, 1.322226687334478, 0.37380031077191234, 0.2486798379686661, 2.319995672442019, 9.202634040266275, 12.2271016985178, 23.207463696599007, 19.48774829506874, 18.228963240981102, 26.73193797469139, 16.130841225385666, 12.657814286649227, 10.723468232899904, 27.681292332708836, 37.1929856389761, 46.37014679610729, 53.31068716943264, 53.696024492383, 59.67547483742237, 58.88841167092323, 55.04752457141876, 54.2901948094368, 51.70344181358814, 51.351261511445045, 47.00701542198658, 46.15592949092388, 45.51695957779884, 44.45001482963562, 49.59599129855633, 53.74019332230091, 56.76743768155575, 58.33766922354698, 53.823469653725624, 55.86783975362778, 57.53425553441048, 56.78466975688934, 47.09030695259571, 41.41955204308033, 51.83499075472355, 64.72181305289268, 56.67921021580696, 58.42132933437824, 60.71102946996689, 58.07983785867691, 56.53621628880501, 46.837780103087425, 45.38336634635925, 46.304607912898064, 53.81283022463322, 52.624128609895706, 60.36386489868164, 42.69487001001835, 29.419155679643154, 46.92520201206207, 60.03468856215477, 60.688481479883194, 56.00464001297951, 57.41818316280842, 58.97440105676651, 55.812252536416054, 49.971205964684486, 46.991592049598694, 43.256928250193596, 45.6199074536562, 52.84239649772644, 56.3333223760128, 58.926770612597466, 56.07634596526623, 52.895361855626106, 56.43478453159332, 59.091997146606445, 56.508599370718, 48.81906598806381, 45.2396010607481, 47.5096220523119, 45.24626210331917, 49.31390963494778, 55.30213750898838, 59.60438825190067, 56.94736562669277, 54.69015374779701, 52.85524740815163, 58.712895289063454, 57.41665944457054, 59.22875940799713, 59.52643923461437, 60.691920295357704, 59.98530641198158, 56.775683239102364, 56.37937590479851, 50.763148069381714, 34.72624160349369, 32.36989304423332, 17.15599961578846, 12.783501092344522, 18.19647878408432, 18.819755539298058, 21.25910684466362, 21.7392585799098, 16.889299526810646, 9.849369786679745, 3.5494201770052314, 0.9791516466066241, 0.10048184529296122, 0.46398229664191604, 1.6214945912361145, 12.033313047140837, 33.90369214117527, 45.75363367795944, 36.687905341386795, 35.251639410853386, 33.81752036511898, 51.78644075989723, 58.5559257119894, 48.7512244284153, 18.793232962489128, 1.6560555179603398, 0.1135044961120002, 0.1436766138067469, 0.15816906583495438, 0.20395038969581947, 0.22161852131830528, 0.13501974317478016, 0.2113832361646928, 0.18377966189291328, 0.20289983513066545, 0.15582644700771198, 0.29000017151702195, 0.14653631660621613, 0.11903177452040836, 0.12903708295198157, 0.11532597884070128, 0.13041099125985056, 0.16592142172157764, 0.22791561466874555, 0.17455595370847732, 0.12597668857779354, 0.1557969392160885, 0.10302678841981106, 0.08121640406898223, 0.11778161191614345], [0.02789993981423322, 0.04974022529495414, 0.05843222919793334, 0.07177863823017105, 0.008736478030186845, 0.0185178016545251, 0.04258434833900537, 0.10531730848015286, 0.08507523059961386, 0.0036548323987517506, 0.05805043503642082, 0.04826294694794342, 0.07137312873965129, 0.03435513288422953, 0.041284651088062674, 0.04036069578432944, 0.016190339338209014, 0.07182856992585585, 0.05858772768988274, 0.038853022779221646, 0.03538831377227325, 0.08697375567862764, 0.019387151587579865, 0.19759704155148938, 1.9228479894809425, 24.92528311908245, 48.30750323832035, 49.630983620882034, 36.43320120871067, 16.608352102339268, 14.244202561676502, 25.305673107504845, 31.17353294044733, 21.897721476852894, 4.475293457508087, 0.5519052443560213, 0.03258238699345384, 0.11266224013525061, 0.5585203331429511, 4.868894387036562, 8.646512981504202, 7.39173861220479, 19.388963095843792, 6.026192586869001, 3.786776103079319, 8.035819251090288, 4.127837251871824, 8.574845027178526, 23.735523261129856, 37.73170933127403, 46.968344897031784, 53.99007171392441, 53.89391027390957, 52.62595251202583, 53.26781406998634, 48.304565995931625, 46.369763016700745, 43.50296884775162, 41.74827620387077, 39.6745602786541, 41.27748906612396, 41.33955493569374, 41.56164541840553, 48.70508350431919, 52.46446117758751, 54.94038172066212, 53.9824303239584, 53.29306751489639, 54.31301638484001, 54.61872898042202, 52.69833102822304, 44.48641687631607, 36.727753803133965, 41.53913922607899, 55.19480086863041, 58.34536001086235, 55.41511684656143, 53.60113978385925, 49.57021728157997, 41.98587745428085, 38.63823428750038, 39.6939392387867, 43.59635643661022, 52.38866664469242, 49.089607670903206, 52.73387432098389, 43.84469211101532, 20.365223810076714, 47.296810671687126, 47.317192777991295, 59.45241540670395, 55.997314006090164, 53.02777715027332, 53.32783944904804, 55.01275263726711, 52.33000919222832, 52.31806643307209, 43.70646312832832, 40.64881660044193, 42.56248891353607, 49.287094473838806, 53.95837001502514, 54.37436409294605, 49.44155618548393, 53.61152462661266, 52.12175756692886, 53.78707140684128, 49.744365736842155, 43.21006536483765, 40.82861915230751, 38.98189164698124, 41.86894632875919, 46.01588040590286, 51.28206342458725, 52.33007378876209, 52.30429217219353, 55.20034097135067, 56.629193499684334, 52.72932216525078, 49.41460803151131, 51.14973172545433, 53.78058135509491, 54.61747504770756, 56.157722398638725, 51.80344484746456, 52.60661914944649, 37.12082751095295, 27.359107621014118, 17.964831814169884, 21.016666553914547, 13.736682794988155, 18.336577266454697, 8.2819795422256, 8.886778838932514, 9.56746481359005, 2.980008856393397, 2.526226043701172, 1.3846753863617778, 0.22625839890679345, 0.07253736548591405, 0.3321421070722863, 5.191728388890624, 22.203530967235565, 29.631476886570454, 27.571814507246017, 26.660013534128666, 27.346045821905136, 36.68704278767109, 52.17591606080532, 45.07151708006859, 19.67305865138769, 2.2349293995648623, 0.016702178181731142, 0.08457537929643877, 0.060535776283359155, 0.03679671339341439, 0.011435817559686257, 0.08601182838901877, 0.02460914198309183, 0.11084935889812186, 0.027692401927197352, 0.0465308187995106, 0.018225757266918663, 0.07465615999535657, 0.02323499804333551, 0.022835212366771884, 0.03869212516292464, 0.049815954043879174, 0.06074791919672862, 0.05563665908994153, 0.10504142250283621, 0.04303708810766693, 0.03142084053251892, 0.03118947599432431, 0.019677605923789088, 0.08962539737694897, 0.0908699567662552, 0.006652933216173551, 0.04059020495333243, 0.033116417907876894, 0.02677218333701603, 0.02182861335313646, 0.12058913431246765, 0.029116188125044573, 0.021541185124078766, 0.06370925912051462, 0.04324243665905669, 0.043944571443716995, 0.013722153762500966, 0.0163085708845756, 0.036715500173158944, 0.06450296379625797, 0.06938377962796949, 0.07099351278156973, 0.07356138827162795, 0.021903408851358108, 0.03674904153740499, 0.03438839594309684, 0.0645664322655648, 0.1689564049593173, 3.0046215606853366, 31.93842239677906, 56.6659527271986, 54.7859276086092, 44.04546573758125, 23.247448951005936, 18.749934285879135, 29.746318124234676, 36.66414141654968, 24.862301498651505, 5.815839674323797, 0.44347841874696314, 0.0032425883819087176, 0.2741908823372796, 1.3803158327937126, 6.803275588899851, 10.639234352856874, 9.226239323616028, 11.22727369889617, 13.071143757551908, 9.86252848058939, 8.690357878804207, 9.943393841385841, 12.138836234807968, 23.020952604711056, 38.82616080343723, 46.939987018704414, 55.96197210252285, 53.78539949655533, 54.932071566581726, 54.570593163371086, 52.0528444647789, 49.54360730946064, 46.00732706487179, 42.83725216984749, 44.05372269451618, 42.09009826183319, 42.86687918007374, 43.295575976371765, 51.53808608651161, 54.32237148284912, 56.94988489151001, 55.57052470743656, 53.09969209134579, 53.83945919573307, 56.7599368840456, 54.42824140191078, 47.11650274693966, 38.73961664736271, 44.333551079034805, 57.372775599360466, 59.117448180913925, 57.437166944146156, 54.65213678777218, 50.3343790769577, 44.577068611979485, 39.3658534437418, 41.5616150200367, 45.51673538982868, 54.22673441469669, 52.1345628798008, 56.12145334482193, 44.149329364299774, 23.999052420258522, 47.22832694649696, 49.618850871920586, 59.81593810021877, 57.55116082727909, 54.97354254126549, 56.731092631816864, 57.860008254647255, 54.395821541547775, 51.86870254576206, 45.889407992362976, 41.47108867764473, 44.084957018494606, 51.25590942800045, 55.592821910977364, 54.769090712070465, 50.872715190052986, 54.040696397423744, 53.79411622881889, 57.21816949546337, 51.41198605298996, 46.08606643974781, 42.68095515668392, 40.81727676093578, 43.38396683335304, 47.39287331700325, 53.94682623445988, 54.90831524133682, 54.93302531540394, 57.20637112855911, 58.16074311733246, 55.5150742828846, 53.04157041013241, 52.889890149235725, 57.06404596567154, 56.606949493288994, 57.95696385204792, 54.654526859521866, 55.98893165588379, 35.65490037202835, 28.145224638283253, 16.39588650316, 14.540394768118858, 14.738636780530214, 15.36826679483056, 15.256542339920998, 9.714282285422087, 9.324199967086315, 7.8858674224466085, 3.7142569944262505, 2.777310158126056, 0.4331290506524965, 0.027009021214325912, 0.5879492789972574, 6.245661685243249, 25.178672522306442, 35.05897834897041, 32.1429730206728, 29.961295388638973, 31.653703674674034, 41.68514259159565, 55.769421234726906, 51.8239751458168, 23.348728716373444, 2.661917000077665, 0.04749438252474647, 0.0660340218746569, 0.04373527837742586, 0.027724583305825945, 0.08099240163573995, 0.015836861821298953, 0.013990193383506266, 0.11672598106088117, 0.02177394118916709, 0.0782588565198239, 0.025438673837925307, 0.09638140516472049, 0.019503850598994177, 0.03167374961776659, 0.05545931919186842, 0.022481989035441075, 0.08685864857397974, 0.026919212068605702, 0.02346399698581081, 0.025764307829376776, 0.009503062774456339, 0.0862399794277735, 0.03851515633868985, 0.030050132736505475, 0.14400226820725948, 0.0965484551852569, 0.10135862597962841, 0.17767474026186392, 0.08314480059198104, 0.17820536100771278, 0.23145133978687227, 0.18032564723398536, 0.2564602915663272, 0.168677298061084, 0.18623438954818994, 0.10542810370679945, 0.12032238417305052, 0.15346521511673927, 0.09699428555904888, 0.21869539457838982, 0.11521655658725649, 0.20205693348543718, 0.1761757949134335, 0.1639817445538938, 0.18547152110841125, 0.14154596719890833, 0.17392499459674582, 0.340741936233826, 5.190317239612341, 38.60123947262764, 62.969791665673256, 61.993772238492966, 47.45879977941513, 27.34316937625408, 22.652554772794247, 34.96319688856602, 42.39544987678528, 28.675774969160557, 6.212689429521561, 0.8324201451614499, 0.09903342535835691, 0.4263452271698043, 1.9637437700293958, 10.803620181977749, 18.60240340232849, 17.94874917715788, 32.415471598505974, 14.278237335383892, 15.006332416087389, 17.03850992023945, 11.11208287999034, 13.658963665366173, 29.480385594069958, 42.092100754380226, 48.21996733546257, 56.539172530174255, 56.656977608799934, 57.99384847283363, 57.3856683075428, 54.32166092097759, 52.48045451939106, 47.45939254760742, 44.72297318279743, 44.933641478419304, 45.22081106901169, 46.181194335222244, 45.70733696222305, 54.088220447301865, 56.671025454998016, 59.29294556379318, 56.36217422783375, 52.93399818241596, 55.15310950577259, 58.28065328299999, 57.367699071764946, 49.76005129516125, 40.69695241749287, 45.98703235387802, 59.6948803961277, 61.984534934163094, 60.3172641992569, 58.01282465457916, 52.40282468497753, 46.64800688624382, 43.05662199854851, 44.40981298685074, 49.96611803770065, 56.9137754291296, 53.15803796052933, 56.00741006433964, 47.36727029085159, 28.46534226089716, 51.453624218702316, 53.6185884475708, 60.402182042598724, 60.405088886618614, 57.09752596914768, 58.18632714450359, 58.87198895215988, 56.49609424173832, 55.460653603076935, 49.08059075474739, 43.07085983455181, 46.04417748749256, 51.959559470415115, 57.06595726311207, 56.008865386247635, 51.19626022875309, 54.17432002723217, 55.030034109950066, 58.99289846420288, 54.446681812405586, 48.95221084356308, 45.78272491693497, 43.146384581923485, 45.998302549123764, 50.54114878177643, 56.96209363639355, 57.3042006790638, 57.641846761107445, 61.125929206609726, 60.84881007671356, 58.89578327536583, 54.507478550076485, 56.206979155540466, 58.7107066065073, 60.592662021517754, 59.15250509977341, 56.22120939195156, 57.38829776644707, 42.447944059967995, 32.17571206390858, 22.187581323087215, 30.13064280152321, 23.57420291751623, 28.574939779937267, 19.599158316850662, 19.08852081745863, 19.556714594364166, 8.315790127962828, 7.893080385401845, 3.0118905706331134, 0.6718659354373813, 0.15537456813035533, 0.7576457387767732, 7.403036830946803, 29.86272107809782, 42.22067825496197, 40.74755050241947, 37.37602561712265, 38.82174164056778, 48.6320324242115, 63.85906174778938, 58.50606858730316, 28.156280145049095, 3.5866904770955443, 0.11109782251878642, 0.23479565017623827, 0.25842077855486423, 0.059593664336716756, 0.18439272040268406, 0.3026294766459614, 0.10244852921459824, 0.1557161787059158, 0.11617927797487937, 0.11461140937171876, 0.13485479343216866, 0.17417404451407492, 0.1297133872867562, 0.12258788643521257, 0.22812537528807297, 0.14912886108504608, 0.15885553759289905, 0.13722502015298232, 0.2307350336923264, 0.16017175134038553, 0.1263887289678678, 0.15084055048646405, 0.0796888637705706, 0.13072030356852338], [0.027544783188204747, 0.03053309461392928, 0.03378095178049989, 0.016412202530773357, 0.05394838073698338, 0.03574045542336535, 0.023565964365843683, 0.035120350221404806, 0.058627989201340824, 0.037023027616669424, 0.06135118135716766, 0.017634651485423092, 0.029833783701178618, 0.04645788052584976, 0.013150929189578164, 0.05286238119879272, 0.06124625651864335, 0.03726320144778583, 0.056026598322205245, 0.054892563275643624, 0.06048672403267119, 0.03469865820079576, 0.11050044558942318, 0.39541274949442595, 3.344639427959919, 27.4881923943758, 49.774703308939934, 40.99688932299614, 29.59932681173086, 17.72909626364708, 19.71664611250162, 34.851349890232086, 39.36295039951801, 15.402809791266918, 3.6319961585104465, 0.19018941326066852, 0.22540846170159057, 0.10326319956220686, 3.0021823290735483, 7.840769542381167, 10.343048796057701, 4.136469438672066, 5.816300874575973, 13.859390560537577, 6.080662189051509, 3.0577180115506053, 12.460897453129292, 13.580551072955132, 25.325097665190697, 36.415110379457474, 49.38309632241726, 50.73216453194618, 52.211755737662315, 53.22428360581398, 53.81475292146206, 51.82370916008949, 51.62993095815182, 50.14514543116093, 47.80642032623291, 43.113208562135696, 41.45180091261864, 40.23257553577423, 44.70957890152931, 49.74521689116955, 52.1059238165617, 54.96873579919338, 54.3979874253273, 52.63073265552521, 55.764413103461266, 52.39715538918972, 53.41723345220089, 50.417533814907074, 40.98290987312794, 38.26973766088486, 45.458374321460724, 49.4649363309145, 53.92679750919342, 48.23460415005684, 40.18514648079872, 38.408927991986275, 39.90328140556812, 38.78958776593208, 45.604848861694336, 51.05896219611168, 53.09140853583813, 48.12228977680206, 53.442988470196724, 20.699615366756916, 33.592150658369064, 47.41198629140854, 51.57216265797615, 53.322489336133, 51.526572704315186, 52.707796320319176, 53.41741964221001, 53.62011596560478, 51.97100445628166, 49.609966948628426, 43.56239765882492, 39.85470101237297, 46.03424862027168, 53.90404812991619, 54.82157349586487, 52.7265977114439, 51.635528057813644, 53.805454820394516, 50.97056373953819, 52.7306254953146, 45.39785876870155, 40.36789767444134, 38.848723992705345, 38.56700710952282, 41.19397334754467, 43.443996012210846, 48.807518407702446, 52.79290035367012, 53.93385373055935, 50.05117267370224, 48.129562586545944, 47.58737727999687, 50.53201787173748, 56.30409814417362, 54.66911047697067, 55.726912915706635, 57.8046528249979, 45.72139620780945, 46.04269556701183, 26.699846796691418, 15.183975733816624, 20.5518089979887, 16.961491852998734, 22.13537972420454, 9.612276758998632, 7.164025381207466, 7.092295680195093, 5.883710207417607, 2.367839142680168, 2.7637040382251143, 0.4079510079463944, 0.05607355400570668, 0.15120568714337423, 3.1934486282989383, 17.00649093836546, 28.882058300077915, 30.17494462430477, 23.739098869264126, 23.11506975442171, 39.19753387570381, 46.97429917752743, 48.04679162800312, 20.171495005488396, 3.442928516305983, 0.11227043069084175, 0.031334658633568324, 0.07809791437466629, 0.019467077181616332, 0.05368681449908763, 0.06113011040724814, 0.03981740286690183, 0.01102580972656142, 0.04704896033217665, 0.034132896762457676, 0.014389962361747166, 0.03733131576154847, 0.04604058944096323, 0.03344138582178857, 0.04721245546534192, 0.03542026322975289, 0.044475221875472926, 0.0324356384226121, 0.023666790693823714, 0.06203554541571066, 0.07099386901245452, 0.013856691221008077, 0.052695360864163376, 0.028957088361494243, 0.036901593703078106, 0.06448793530580588, 0.06661999941570684, 0.03890767453412991, 0.023185212921816856, 0.021179158065933734, 0.03148771545966156, 0.038461903532152064, 0.04439067270141095, 0.056316210320801474, 0.03223950734536629, 0.06216931753442623, 0.05667520941642579, 0.035738685401156545, 0.012327250096859643, 0.06526271521579474, 0.024920942341850605, 0.05094593325338792, 0.06355662902933545, 0.0453884123271564, 0.04465851750865113, 0.05438351676275488, 0.048816726412042044, 0.35048393066972494, 5.157971475273371, 36.42240218818188, 56.06535695493221, 46.9051580876112, 35.244461596012115, 21.920436657965183, 21.377079114317894, 32.802591025829315, 42.603815495967865, 17.15022012591362, 3.906756090000272, 0.2285401467815973, 0.1910603087162599, 0.1255035397480242, 4.39098215661943, 6.926887230947614, 10.528131164610386, 8.706729300320148, 6.768061928451061, 16.67127102613449, 5.7743587251752615, 7.6300575491040945, 12.292467691004276, 12.121467366814613, 21.252098120748997, 39.46020618081093, 49.68236446380615, 50.81294819712639, 53.114499896764755, 55.14538452029228, 56.01866886019707, 54.78754632174969, 52.99916468560696, 51.81113563477993, 48.48251424729824, 44.30023066699505, 42.8949710726738, 43.53129252791405, 46.005385369062424, 51.43377788364887, 55.02432681620121, 55.83915889263153, 54.0927954018116, 54.05342951416969, 56.03865198791027, 55.0018510222435, 57.61019065976143, 52.38150402903557, 42.542357593774796, 40.71188181638718, 48.63894425332546, 53.27673979103565, 55.9025014936924, 51.433394104242325, 42.70066849887371, 39.76377949118614, 41.04269206523895, 41.41660340130329, 48.076114654541016, 53.77799369394779, 53.885185942053795, 50.827136635780334, 53.96731473505497, 23.82682666182518, 38.92609544098377, 51.732840836048126, 52.196165174245834, 53.67746248841286, 51.82293400168419, 52.863975539803505, 54.60571467876434, 55.841066390275955, 55.154846012592316, 50.80785647034645, 44.883058592677116, 41.78329512476921, 46.755715906620026, 56.29245936870575, 56.18103414773941, 53.12399558722973, 52.49072916805744, 54.019250348210335, 54.98068615794182, 56.13158740103245, 48.18180598318577, 42.38524742424488, 39.997877329587936, 41.47044651210308, 43.72202329337597, 47.59685397148132, 52.0386104285717, 54.39090460538864, 56.69378623366356, 54.41834673285484, 49.60403546690941, 51.386899799108505, 52.95245759189129, 59.09014664590359, 58.52963872253895, 57.82024338841438, 58.034760877490044, 49.0412362664938, 48.525094762444496, 25.912899523973465, 18.7009834125638, 11.562425214797258, 19.499540962278843, 12.048318441957235, 12.178122326731682, 14.205480739474297, 10.565351117402315, 8.078232575207949, 5.0918535981327295, 3.4876060439273715, 0.3912742668762803, 0.02563822992669884, 0.31456368626095355, 3.9702449832111597, 19.815410412847996, 31.48181039839983, 34.028329253196716, 29.538936652243137, 27.431710325181484, 44.359575882554054, 53.306807577610016, 54.39557455480099, 24.656223356723785, 4.098907029256225, 0.1987751416163519, 0.025542661715007853, 0.06145896346424706, 0.029701612766075414, 0.0424824254878331, 0.06990314941504039, 0.06115447140473407, 0.048242641787510365, 0.03729785603354685, 0.04002135989139788, 0.03273270900535863, 0.019264467155153397, 0.03693325743370224, 0.034430104642524384, 0.01966256444575265, 0.03340454932185821, 0.025106278881139588, 0.027309874894854147, 0.020138824729656335, 0.06830696045653895, 0.04371102128061466, 0.01670723591814749, 0.023800069284334313, 0.045125562173780054, 0.10731476926594041, 0.14354586222907528, 0.14320065965875983, 0.09388775928528048, 0.09561484825098887, 0.13012352777877823, 0.1414816823671572, 0.15224889444652945, 0.13771100813755766, 0.12716397643089294, 0.11361702054273337, 0.16695704427547753, 0.11412332110921852, 0.08101368643110618, 0.1367217698134482, 0.18593267683172598, 0.25233199121430516, 0.18946512165712193, 0.20275386952562258, 0.1764131337404251, 0.158919733366929, 0.1527398548205383, 0.15056801901664585, 0.6043335841968656, 8.591417837888002, 44.71732288599014, 63.5076642036438, 55.131161883473396, 40.4450449347496, 27.688897624611855, 30.880614258348942, 48.103074207901955, 49.14272882044315, 21.388071924448013, 4.769459422677755, 0.54596824105829, 0.4026103054638952, 0.29204713355284184, 4.99206050299108, 12.707530818879604, 18.281898200511932, 14.887209758162498, 14.558990970253944, 22.39426553249359, 13.605506233870983, 9.140746761113405, 19.82199925929308, 19.998419992625713, 32.274882942438126, 39.96754355728626, 52.111118137836456, 50.759230479598045, 52.196970731019974, 57.7467705309391, 57.65593260526657, 55.91569438576698, 55.66039748489857, 54.46811646223068, 52.20235504209995, 48.24081301689148, 44.98103253543377, 44.45468097925186, 47.828436344861984, 53.50312024354935, 56.91296607255936, 57.71513342857361, 58.70947927236557, 54.96920317411423, 56.46394416689873, 54.780322909355164, 59.11346599459648, 54.95855234563351, 45.18253192305565, 43.11032451689243, 49.61684837937355, 54.23015423119068, 58.82694996893406, 52.061663791537285, 43.50747920572758, 41.63995921611786, 45.11263847351074, 44.816360771656036, 50.90146064758301, 56.77671678364277, 57.30265416204929, 52.73564122617245, 54.99674789607525, 28.371253609657288, 41.341960206627846, 52.92479507625103, 51.888548880815506, 52.942832708358765, 51.726073399186134, 53.07878941297531, 55.33136934041977, 57.02863946557045, 57.86976993083954, 54.43997137248516, 48.708294332027435, 44.3525006622076, 48.67723859846592, 58.995071947574615, 57.634102776646614, 54.18183222413063, 52.77073994278908, 55.4484486579895, 56.100337877869606, 57.69473612308502, 50.270762890577316, 45.317888259887695, 42.322402596473694, 43.107702657580376, 45.549288243055344, 50.07965974509716, 52.67730675637722, 57.17187657952309, 60.053626745939255, 56.618725061416626, 52.14533530175686, 53.06830197572708, 55.02885617315769, 61.27047725021839, 60.487282276153564, 59.48989659547806, 62.12505519390106, 51.03248901665211, 52.14043736457825, 32.97735504806042, 21.06660347431898, 28.08646649122238, 24.501345567405224, 36.50610409677029, 26.159238405525684, 18.07087082415819, 19.78438887745142, 14.459941685199738, 6.188552649691701, 4.2259907349944115, 1.2002339959144592, 0.1977559205261059, 0.5770464765373617, 4.266189727932215, 23.590156361460686, 39.951637610793114, 42.60976977646351, 36.74645259976387, 34.66522827744484, 51.243795678019524, 58.712982684373856, 61.10221467912197, 31.643278934061527, 5.851312195882201, 0.3079950559185818, 0.19573610625229776, 0.19661227095639333, 0.12033877821522765, 0.15529941825661808, 0.16173645097296685, 0.1420581975253299, 0.13858757360139862, 0.11531082418514416, 0.20940168702509254, 0.12676553218625486, 0.1389651486533694, 0.11451453683548607, 0.07692452694755048, 0.08131096110446379, 0.14251703774789348, 0.13488887285348028, 0.10696395605918951, 0.13520916894776747, 0.19955740979639813, 0.12521585362264886, 0.10975762997986749, 0.12783287413185462, 0.33768218010663986], [0.04670328649808653, 0.03923256452253554, 0.0945875006436836, 0.013973906952742254, 0.10633035490172915, 0.030834773933747783, 0.014734036867594114, 0.0252176659705583, 0.03280363976955414, 0.03566639279597439, 0.03271023306297138, 0.05332586355507374, 0.1075446791946888, 0.026582392056297977, 0.020483279586187564, 0.03775683726416901, 0.043991404672851786, 0.07675938424654305, 0.03380275236850139, 0.0625361166021321, 0.031774087983649224, 0.01112241787268431, 0.03132281395664904, 0.19008049566764385, 5.075651742517948, 29.334887601435184, 49.44457322359085, 39.991299882531166, 30.38835257291794, 15.784374866634607, 20.19026219844818, 31.735211201012135, 28.809993267059326, 13.533422201871872, 1.7369327531196177, 0.06744468133547343, 0.07113555242540315, 0.3127171634696424, 3.0063697043806314, 4.517172910273075, 7.44721801020205, 6.751321451738477, 5.477826911956072, 16.27104800194502, 4.310503425076604, 8.088994547724724, 9.638906680047512, 11.528063658624887, 17.91883148252964, 45.23355558514595, 53.01387369632721, 55.434104427695274, 50.8300206810236, 49.763410314917564, 51.42706744372845, 54.50284279882908, 54.07497055828571, 51.524368822574615, 51.093764528632164, 51.51076175272465, 45.20167149603367, 39.121800139546394, 38.174997344613075, 44.071494340896606, 47.5308895111084, 50.28384938836098, 51.980739533901215, 55.288481041789055, 53.14625859260559, 55.793815925717354, 52.37382464110851, 52.48081550002098, 46.875690668821335, 39.097515642642975, 39.01309937238693, 41.461539790034294, 39.9959584325552, 38.07898789644241, 39.39362235367298, 36.563256829977036, 38.65556135773659, 39.655169919133186, 44.93102341890335, 48.70769016444683, 52.586480230093, 46.78233727812767, 53.84049654006958, 30.946217738091946, 43.864101469516754, 58.99207390844822, 49.89898324012756, 56.10644035041332, 51.20335064828396, 53.59832413494587, 54.43407028913498, 54.98327761888504, 54.01355445384979, 53.99786129593849, 47.33010448515415, 38.57215203344822, 41.35541528463364, 53.590808138251305, 53.11229221522808, 52.81375363469124, 51.777895018458366, 51.84305012226105, 54.09805431962013, 55.58731220662594, 48.676376044750214, 44.37758691608906, 37.26833179593086, 37.09958665072918, 37.69005596637726, 38.40369947254658, 38.990027010440826, 39.282003343105316, 41.48230567574501, 43.47344443202019, 43.03842477500439, 46.92550599575043, 47.02103666961193, 50.07099241018295, 50.838448628783226, 52.65689805150032, 51.84709310531616, 56.78264066576958, 37.68643096089363, 39.75694365799427, 19.51993826776743, 5.77899020165205, 15.906639005988836, 5.75355009175837, 13.485667314380407, 8.453299049288034, 7.205643123015761, 8.13475739210844, 3.2581451442092657, 3.1030106311663985, 0.5564112681895494, 0.016934218074311502, 0.1531965725007467, 1.7340515577234328, 13.66066787391901, 31.859215646982193, 38.253615126013756, 27.115536890923977, 23.456804417073727, 32.74120531976223, 44.26539033651352, 43.70620854198933, 21.341997496783733, 2.661056346260011, 0.2632267487933859, 0.09145424963207915, 0.04021107881271746, 0.05043693869083654, 0.09787133341887966, 0.005267809665383538, 0.06150131412141491, 0.0274219614584581, 0.008223187360272277, 0.04950464535795618, 0.020723499801533762, 0.026462375644769054, 0.0186973364543519, 0.033992270909948274, 0.012915025490656262, 0.03489067777991295, 0.022410794808820356, 0.005320687687344616, 0.08344041285454296, 0.052770558977499604, 0.033342490933137015, 0.04127454674744513, 0.04205424709653016, 0.023414566239807755, 0.03838455319055356, 0.09671491148765199, 0.07719775603618473, 0.015044837182358606, 0.07288817127118818, 0.013263712444313569, 0.026123152929358184, 0.04113772440177854, 0.01927220404468244, 0.018449193812557496, 0.04210806764604058, 0.05379719783377368, 0.03110937414021464, 0.043380550341680646, 0.049382150173187256, 0.06591014258447103, 0.10814946275786497, 0.052312928455648944, 0.05374387081246823, 0.04400141624500975, 0.019500978487485554, 0.08462216428597458, 0.05779007849923801, 0.20241895312210545, 7.425468452274799, 37.84901283681393, 56.04244038462639, 46.382488533854485, 34.35345880687237, 19.612934477627277, 23.33750791847706, 34.81497444212437, 33.12129132449627, 13.85336883366108, 2.6399130932986736, 0.07531999624916352, 0.22449765354394913, 0.8860322402324528, 5.911908019334078, 8.547749631106853, 10.87052509188652, 10.552065130323172, 9.557344056665897, 16.135190092027187, 10.401156228035688, 9.45929316803813, 14.01894399896264, 18.46528396010399, 21.77962191402912, 43.17691594362259, 52.53464721143246, 56.570110470056534, 52.068868204951286, 50.49785390496254, 53.99044789373875, 56.28064960241318, 55.33460296690464, 55.004016906023026, 52.85938538610935, 52.19607777893543, 45.52297465503216, 40.5337093770504, 40.719838589429855, 47.39728108048439, 50.22005081176758, 52.24602609872818, 54.136413261294365, 56.32856883108616, 54.7350749373436, 54.00244005024433, 53.68243262171745, 54.357489198446274, 48.34529221057892, 41.69968821108341, 41.350920125842094, 44.51221749186516, 43.33486966788769, 41.55083119869232, 41.221597865223885, 39.210776165127754, 39.69293989241123, 41.91573701798916, 47.46251218020916, 51.92272424697876, 54.35755379498005, 49.073390141129494, 55.57862967252731, 32.615017890930176, 45.42648263275623, 58.843574076890945, 51.02337710559368, 56.18377760052681, 52.964373752474785, 56.68905548751354, 55.9416051954031, 55.655396953225136, 54.95337702333927, 55.56317210197449, 48.9847256988287, 39.9964714050293, 43.58889363706112, 55.8882712572813, 54.3282725661993, 53.58035869896412, 51.137173399329185, 52.97526016831398, 54.65718291699886, 57.07633450627327, 51.730446964502335, 45.96791557967663, 39.36726316809654, 39.89653296768665, 40.071228593587875, 40.53271383047104, 40.91437295079231, 42.276037484407425, 44.95308883488178, 44.784005507826805, 44.353496208786964, 47.98191010951996, 51.11114859580994, 52.462424486875534, 55.09709671139717, 53.094262182712555, 55.12742668390274, 57.59663678705692, 42.45193384587765, 39.004173651337624, 17.34497107565403, 10.681398790329695, 17.48106077313423, 13.213821351528168, 13.268124237656593, 12.788349632173777, 10.86676899343729, 10.292496308684349, 5.8835449162870646, 1.6204718523658812, 0.7599273382220417, 0.061294492406887, 0.07805947854649276, 2.4133053654804826, 16.024652123451233, 37.116913720965385, 42.244643568992615, 31.151505522429943, 30.670164451003075, 41.32507011294365, 48.82942043244839, 50.318663120269775, 26.669558621942997, 3.9575895247980952, 0.248993914865423, 0.031017817236715928, 0.032465238982695155, 0.05926557940256316, 0.05731977209507022, 0.041562503756722435, 0.027028636177419685, 0.02514642535970779, 0.03431026634643786, 0.05832995753735304, 0.041261139849666506, 0.05285573526634835, 0.06479814561316743, 0.03500804101349786, 0.02355660959437955, 0.041300547891296446, 0.04127177482587285, 0.05872508067113813, 0.09753857666510157, 0.021750539417553227, 0.02625226064992603, 0.03238001074350905, 0.018938020511996, 0.01788877954822965, 0.1754000279470347, 0.23488586564781144, 0.29805413621943444, 0.10822570358868688, 0.1999977111699991, 0.1054880692390725, 0.06788553189835511, 0.08098841630271636, 0.1635495771188289, 0.05865159320819657, 0.16012296255212277, 0.17211366444826126, 0.26167577889282256, 0.22103320428868756, 0.1126702553301584, 0.1704017524025403, 0.22814655618276447, 0.14497042953735217, 0.19577769620809704, 0.10994799085892737, 0.1315160046215169, 0.13372359710047022, 0.12926600582432002, 0.45319663477130234, 10.9506855905056, 45.310752242803574, 63.3057202398777, 52.99346499145031, 40.72543188929558, 24.341917522251606, 30.481183491647243, 42.86179505288601, 37.67533175647259, 17.399135269224644, 2.752858945168555, 0.28578910685610026, 0.33405159367248416, 1.0928537766449153, 5.089768460020423, 10.163042955100536, 16.372903436422348, 15.323056820780039, 13.593838009983301, 25.69659423083067, 14.024879280477762, 17.875831089913845, 17.51658696681261, 16.347853280603886, 23.02091270685196, 48.057480454444885, 54.63584706187248, 56.522415429353714, 54.10781219601631, 49.98914860188961, 55.08943252265453, 58.530193492770195, 58.85138265788555, 57.44012698531151, 55.06246916949749, 55.996379256248474, 48.79728935658932, 43.42604197561741, 42.2713865339756, 48.1712843477726, 51.82319238781929, 55.601622238755226, 56.91841498017311, 59.61927205324173, 57.87849426269531, 56.708301454782486, 55.96500813961029, 57.02648878097534, 51.77198253571987, 43.212789818644524, 42.617373168468475, 45.79972140491009, 44.719845950603485, 43.186867609620094, 42.94186815619469, 41.312420591712, 41.48249186575413, 44.07973989844322, 49.84091855585575, 54.31298978626728, 56.04337893426418, 51.173180267214775, 55.04709139466286, 36.76259033381939, 46.24649003148079, 57.68264137208462, 54.27769348025322, 59.3182560056448, 55.87742663919926, 58.255092054605484, 58.15361090004444, 57.132909670472145, 56.27368837594986, 58.36099237203598, 52.164607867598534, 42.46892653405666, 45.37000626325607, 58.68638411164284, 56.07917681336403, 53.5979213565588, 51.538207679986954, 52.64508068561554, 56.95169739425182, 60.62006235122681, 54.69701997935772, 48.34134042263031, 41.3048779964447, 42.245939299464226, 41.92493632435799, 42.063416093587875, 43.13358686864376, 43.02830971777439, 45.80763638019562, 47.9513331502676, 46.68199986219406, 51.05222895741463, 53.03469277918339, 55.19752912223339, 55.94325430691242, 56.462982818484306, 54.62101265788078, 62.47687451541424, 41.70786917209625, 43.84757235646248, 23.76628641039133, 11.978284399956465, 24.616982862353325, 15.901892110705376, 21.71149156987667, 18.220238909125328, 16.016499660909176, 18.898141533136368, 11.684760600328445, 5.880665145814419, 1.567090298049152, 0.22189440729562193, 0.3991639200830832, 2.693245131522417, 18.58360581099987, 41.63209743797779, 48.47368352115154, 37.68171541392803, 33.85296866297722, 44.28948484361172, 59.063038900494576, 55.180297046899796, 35.41863664984703, 7.347515160217881, 0.4985695844516158, 0.21113231603521854, 0.14482514670817181, 0.20323659206042066, 0.20785885106306523, 0.0926847527443897, 0.10827557591255754, 0.21326735615730286, 0.0858745607547462, 0.30639145290479064, 0.1855362215428613, 0.11433368286816403, 0.2299573371419683, 0.13529101299354807, 0.0879584594804328, 0.09736601248732768, 0.13358935742871836, 0.16214247996686026, 0.18390683631878346, 0.1213804938015528, 0.10920275584794581, 0.23743426718283445, 0.14242768316762522, 0.2106465506949462], [0.010379911182099022, 0.018777490258798935, 0.08025834336876869, 0.05742300483689178, 0.027526431731530465, 0.04584677757520694, 0.017586155845492613, 0.021208534126344603, 0.045891777699580416, 0.08180652279406786, 0.028601078265637625, 0.017789506164263003, 0.02792169772874331, 0.04675644282542635, 0.022968687626416795, 0.07896733295638114, 0.04761174575833138, 0.02324097975360928, 0.025198724506481085, 0.07152074933401309, 0.09692165156593546, 0.027735715520975646, 0.031691453550592996, 0.22629946935921907, 9.778005816042423, 40.80365069210529, 48.6677049100399, 36.84808574616909, 23.904027119278908, 22.151238173246384, 41.4123248308897, 51.01685665547848, 40.84048591554165, 9.002886358648539, 1.2850435450673103, 0.014933535439922707, 0.46150542329996824, 0.6812920421361923, 10.166077092289925, 6.869677025824785, 8.000866826623678, 7.7645461075007915, 5.451849130913615, 14.541696198284626, 5.421220874413848, 7.331481445580721, 11.795565504580736, 20.942139253020287, 28.010580763220787, 50.44510133564472, 50.34944526851177, 56.29510782659054, 53.122893646359444, 52.71406598389149, 50.10339707136154, 51.93358786404133, 51.137473583221436, 56.097944006323814, 52.776732221245766, 51.48581989109516, 50.63005641102791, 50.110749676823616, 41.032387018203735, 39.22383986413479, 37.97532185912132, 39.96503569185734, 42.98456646502018, 48.24875459074974, 53.37217167019844, 52.756194323301315, 55.244566798210144, 53.463355377316475, 51.017316430807114, 44.46146361529827, 38.555356934666634, 37.72547006607056, 39.32896502315998, 37.51889035105705, 36.29861623048782, 36.55530385673046, 36.84485971927643, 39.09362465143204, 42.28854641318321, 46.12823277711868, 46.986834704875946, 48.35989862680435, 55.92983342707157, 31.071508415043354, 43.04633215069771, 53.677682876586914, 52.371039390563965, 50.76773062348366, 48.62141199409962, 49.055743888020515, 50.922891497612, 52.826270163059235, 53.851014375686646, 52.16227479279041, 53.22605811059475, 43.18237245082855, 39.36325058341026, 51.581787541508675, 52.283340096473694, 53.33308696746826, 51.784613057971, 50.78410014510155, 50.45387506484985, 55.356242805719376, 51.98440633714199, 47.39296831190586, 42.968474328517914, 43.634502589702606, 45.08688725531101, 45.83192087709904, 44.75204162299633, 42.29341775178909, 38.80847655236721, 38.23526211082935, 40.4477845877409, 44.05939199030399, 50.32475799322128, 47.520398274064064, 50.725674480199814, 50.98832778632641, 52.3448321968317, 53.302905187010765, 49.67621639370918, 27.816297188401222, 30.055870413780212, 10.2440251596272, 23.804664351046085, 8.621497973799706, 5.393770672380924, 17.016492001712322, 7.4464271776378155, 6.390400668606162, 6.113000828772783, 2.474948507733643, 0.14745481341378763, 0.03897539550962392, 0.06582031302968971, 1.0655777715146542, 9.264906998723745, 27.33099102973938, 38.4018337726593, 31.439077891409397, 17.39782813936472, 30.802486650645733, 43.89967516064644, 46.791791170835495, 29.143431074917316, 7.542281309142709, 0.17767200915841386, 0.017205165058840066, 0.03873427915095817, 0.026454102553543635, 0.04539839050266892, 0.031146030669333413, 0.07148603908717632, 0.024579973724030424, 0.0165792228654027, 0.03564020982594229, 0.06131114991148934, 0.004385962429296342, 0.022266335763561074, 0.02616085588670103, 0.10071207434521057, 0.012596733195096022, 0.010113410589838168, 0.031139477505348623, 0.03412637328437995, 0.053779015215695836, 0.012698385162366321, 0.016102400404633954, 0.04718909636721946, 0.03980971421697177, 0.006340878207993228, 0.023111879454518203, 0.054384785835281946, 0.0978348939679563, 0.03324441611766815, 0.04155596543569118, 0.0475776366511127, 0.022094467349234037, 0.029965628091304097, 0.05902077456994448, 0.032856632824405096, 0.03938809641113039, 0.06759200507076457, 0.03828827437246218, 0.047517615457763895, 0.05743572153733112, 0.06163304904475808, 0.040618644052301534, 0.0327424979332136, 0.0802158925216645, 0.029450742731569335, 0.05507103123818524, 0.029222010962257627, 0.2678061561891809, 13.194582983851433, 48.4297426789999, 54.8541871458292, 42.91818402707577, 28.12827754765749, 24.001037813723087, 34.46195438504219, 48.67290303111076, 40.17959117889404, 11.230475977063179, 1.3974523195065558, 0.07513661897974089, 0.31224851205479354, 0.5795249529182911, 2.5267185922712088, 11.432320196181536, 12.350003253668547, 12.642534356564283, 13.22849901393056, 15.6432418897748, 11.6418675519526, 9.58246735855937, 10.935928132385015, 21.15095514804125, 28.053773045539856, 49.843331426382065, 52.659474313259125, 55.037417113780975, 53.13406124711037, 51.31727613508701, 49.77319099009037, 51.94091007113457, 53.068149983882904, 56.07973538339138, 55.18342047929764, 55.02690687775612, 53.512817323207855, 50.63855655491352, 42.40659087896347, 41.334850788116455, 40.53012616932392, 43.19984771311283, 47.25119411945343, 50.849502235651016, 54.64587092399597, 54.81426648795605, 56.78036458790302, 55.25947339832783, 52.46834076941013, 45.0842197984457, 40.160512402653694, 39.221400395035744, 40.508167147636414, 38.70647482573986, 38.08897756040096, 39.3015418946743, 38.74524034559727, 39.46219727396965, 44.8657239228487, 48.378510028123856, 48.94388169050217, 50.335427820682526, 57.592008635401726, 34.00974445044994, 44.650951847434044, 54.32426758110523, 54.24814246594906, 53.27734015882015, 51.77751883864403, 52.375542148947716, 53.71062330901623, 54.03218865394592, 54.88434612751007, 54.51962649822235, 54.670493602752686, 45.12151479721069, 40.26758685708046, 55.1613512635231, 54.8373806476593, 54.2375448346138, 53.620522543787956, 51.57693140208721, 52.4931800365448, 57.285847663879395, 53.38749244809151, 48.93015682697296, 44.74915757775307, 44.09220702946186, 45.62086880207062, 48.19386273622513, 45.557435005903244, 43.51690270006657, 41.54527969658375, 40.16049340367317, 42.65285946428776, 47.07565113902092, 50.75323820114136, 50.30168183147907, 52.27729842066765, 55.025162771344185, 53.39395210146904, 57.5046893209219, 49.00108002126217, 30.7305546104908, 30.234941504895687, 11.003216821700335, 11.764916349202394, 16.54438253492117, 14.532750528305769, 14.130688402801752, 10.718079172074795, 8.632065206766129, 6.38470952399075, 3.277750904671848, 0.8044018142390996, 0.17186520824907348, 0.09133374711382203, 1.481146509759128, 10.454737152904272, 30.55805716663599, 38.09113584458828, 32.228814214468, 23.391229435801506, 36.24788135290146, 50.09860172867775, 52.015975043177605, 33.37202467024326, 9.002736266702414, 0.30891422065906227, 0.016261865675915033, 0.04484872995817568, 0.058033016830449924, 0.02497527497325791, 0.0975252922216896, 0.04406763066072017, 0.10671492098481394, 0.05508133595867548, 0.02307490009116009, 0.013650083801621804, 0.0138601607613964, 0.03228023640986066, 0.04487067155423574, 0.07479315303498879, 0.03038567996554775, 0.08002688235137612, 0.03345908233313821, 0.047365801729029045, 0.03238844154111575, 0.024851902198861353, 0.0509169672295684, 0.01472707273933338, 0.05046464306360576, 0.05755703299655579, 0.11120518160169013, 0.2131937351077795, 0.1462774703395553, 0.10423522006021813, 0.148345984343905, 0.13170664751669392, 0.13484772818628699, 0.23868912016041577, 0.1456762565067038, 0.11029722329112701, 0.15070758730871603, 0.11063041791203432, 0.14040010602911934, 0.0961059051041957, 0.1893129071686417, 0.15233339538099244, 0.13861568615539, 0.0968556004227139, 0.21428567182738334, 0.1323504457832314, 0.16489718371303752, 0.11450433972640894, 0.5195790133439004, 17.868372090160847, 55.87612710893154, 61.09885185956955, 48.86152870953083, 34.812956750392914, 32.10401751101017, 52.42932066321373, 63.00026223063469, 48.613717406988144, 12.386168763041496, 2.137779062613845, 0.24921179458033293, 0.9069896000437438, 0.9521971398498863, 15.716730896383524, 17.272178381681442, 18.47512163221836, 19.630005061626434, 16.139715649187565, 28.190634101629257, 15.19108135253191, 16.07120532542467, 19.32423736900091, 27.541252747178078, 30.70169135928154, 52.46824957430363, 53.259591311216354, 56.23866945505142, 54.101204350590706, 54.14797604084015, 49.882640317082405, 52.77817614376545, 53.869819566607475, 58.16409453749657, 56.882959082722664, 57.75861069560051, 54.73246447741985, 54.542653262615204, 44.62574020028114, 44.39352326095104, 41.766234040260315, 44.5526397228241, 49.549451395869255, 51.98754496872425, 56.00023224949837, 58.57194945216179, 58.057802841067314, 56.5072238445282, 55.06001830101013, 47.86157436668873, 42.510739490389824, 41.38114370405674, 43.32024045288563, 40.56426353752613, 40.21894946694374, 40.09245425462723, 40.471081137657166, 42.55027636885643, 46.86672694981098, 50.5573321133852, 51.01366862654686, 53.47014561295509, 59.54525202512741, 37.74112902581692, 47.38910011947155, 55.54400973021984, 56.07724271714687, 55.34939557313919, 54.696921184659004, 54.4907670468092, 56.43690101802349, 55.81699088215828, 57.24281497299671, 55.350197330117226, 58.30319367349148, 47.86737285554409, 43.98409143090248, 55.55896192789078, 56.56192950904369, 55.479451194405556, 53.3690482378006, 50.63449077308178, 53.740257918834686, 59.17012855410576, 56.97870634496212, 53.19080360233784, 47.88622364401817, 46.74741715192795, 49.70156103372574, 51.12314835190773, 48.166420608758926, 45.62094859778881, 43.110119327902794, 41.5904288738966, 45.12562997639179, 49.880360439419746, 54.52517420053482, 52.4026270955801, 55.577523931860924, 57.23394624888897, 58.02605174481869, 59.10856805741787, 51.78731091320515, 31.934276819229126, 33.698252364993095, 15.344686210155487, 34.38740238547325, 24.699181951582432, 17.286955788731575, 28.380133733153343, 14.423796124756336, 17.377662621438503, 9.669679328799248, 3.6173595814034343, 0.9522412531077862, 0.438697028439492, 0.2179825765779242, 1.794965851586312, 12.536902874708176, 34.299972876906395, 52.67024293541908, 41.8985353410244, 26.409204192459583, 43.81194926798344, 55.70414833724499, 61.658318638801575, 41.87271572649479, 13.920784816145897, 0.543356949929148, 0.044903003217768855, 0.1547488634241745, 0.11986723984591663, 0.08637196297058836, 0.13944533304311335, 0.16996799677144736, 0.1849015220068395, 0.17867334448965266, 0.08721611142391339, 0.14073104452108964, 0.10677148748072796, 0.14325600903248414, 0.09686592369689606, 0.13004607724724337, 0.06965988824958913, 0.32230618642643094, 0.10801760538015515, 0.11655197711661458, 0.09954297653166577, 0.179109089076519, 0.13148829282727093, 0.15218324406305328, 0.08760300042922609], [0.04806499389815144, 0.059035391168436036, 0.017970182016142644, 0.05245485677733086, 0.02396347907051677, 0.027496753245941363, 0.050061823858413845, 0.021917702615610324, 0.010832228854269488, 0.07194664562121034, 0.03989913559053093, 0.04779132694238797, 0.026335767106502317, 0.027543256219360046, 0.02429896136163734, 0.036156907881377265, 0.03603709556045942, 0.06335849786410108, 0.05381802620831877, 0.06228251731954515, 0.061150797773734666, 0.06850382254924625, 0.06912646218552254, 0.30764223891310394, 10.037640184164047, 37.22828574478626, 45.34527339041233, 37.91798673570156, 24.27607275545597, 16.653413884341717, 46.106513142585754, 55.7551833987236, 35.05209691822529, 7.506500529125333, 0.8449312706943601, 0.09445055955438875, 0.13408169819740579, 1.1128752585500479, 3.506050016731024, 12.016529347747564, 10.889760609716177, 6.755002029240131, 14.748599845916033, 12.822931576520205, 13.117376826703548, 8.879854660481215, 16.909759528934956, 44.04189392924309, 36.65279522538185, 52.02816478908062, 52.002143785357475, 55.126419737935066, 53.4788129478693, 52.65762001276016, 51.28522485494614, 51.97508543729782, 50.94259724020958, 54.90067005157471, 54.19675022363663, 55.208723321557045, 53.56382578611374, 50.19089497625828, 48.820243924856186, 45.07643781602383, 43.00904095172882, 38.496558889746666, 36.90921686589718, 39.08273063600063, 45.16883745789528, 51.904112845659256, 50.359035953879356, 54.16779197752476, 49.76806126534939, 44.452480897307396, 37.1297038346529, 37.21926122903824, 38.19652318954468, 37.36859321594238, 42.407065853476524, 42.450516521930695, 43.29194717109203, 38.443787321448326, 42.51873426139355, 40.002456083893776, 46.259074956178665, 45.7145793735981, 56.34517773985863, 33.34623925387859, 41.09319515526295, 56.50611810386181, 50.07715567946434, 49.7405431419611, 43.45123462378979, 43.096918836236, 46.13453283905983, 53.04820105433464, 52.323173359036446, 53.746242597699165, 51.933842450380325, 45.258299857378006, 35.29873788356781, 46.61718674004078, 52.32348874211311, 56.06525056064129, 52.56017044186592, 50.85624687373638, 52.89374694228172, 53.733524680137634, 52.80790954828262, 52.02778480947018, 50.430259332060814, 50.22595189511776, 50.725967064499855, 52.93521411716938, 53.66984389722347, 52.409421131014824, 47.39873260259628, 46.54822424054146, 45.870602801442146, 44.151833429932594, 46.71747475862503, 49.64833348989487, 52.80123710632324, 50.64395606517792, 54.915246069431305, 54.11899879574776, 47.02124185860157, 34.69849169254303, 21.403755582869053, 24.96848490089178, 9.011111967265606, 14.224797002971172, 20.484495609998703, 10.360178276896477, 13.630758728832006, 9.020922090858221, 5.694610979408026, 1.4026409410871565, 1.068915061186999, 0.23653870273847133, 0.04152543348027393, 0.42009794677142054, 7.51186584122479, 32.71378979086876, 64.03470352292061, 49.75105717778206, 32.64262720942497, 33.53015698492527, 39.21254687011242, 46.6353839635849, 36.60499379038811, 8.72882416471839, 0.22859318065457046, 0.06694048104691319, 0.07716963606071658, 0.07797522252076305, 0.06864953582407907, 0.0641411445394624, 0.04659347832784988, 0.023857483683968894, 0.02603157190605998, 0.0529617362190038, 0.08621331406175159, 0.057998499542009085, 0.027198498937650584, 0.041385100776096806, 0.08179729047697037, 0.07511283314670436, 0.08051654396695085, 0.00202721997993649, 0.012173790655651828, 0.06733720350894146, 0.07567496548290364, 0.00645065205389983, 0.1530039554927498, 0.037775424352730624, 0.047721516821184196, 0.039096777472877875, 0.025342562003061175, 0.054314415392582305, 0.011663794193736976, 0.10900185647187755, 0.03742830333067104, 0.029616542233270593, 0.03447032162512187, 0.01100718553061597, 0.03274141068686731, 0.04007302821264602, 0.05899766038055532, 0.09471581797697581, 0.039518684716313146, 0.11169620134751312, 0.07620666976436041, 0.0525836119777523, 0.07279890574864112, 0.055365652733598836, 0.04078594269230962, 0.07604416168760508, 0.022551817710336763, 0.3568379022181034, 14.320893846452236, 46.255028173327446, 51.96283109486103, 42.41317592561245, 28.051379173994064, 23.415836915373802, 44.781843423843384, 59.673084765672684, 35.57303376495838, 8.970243260264397, 1.0176372877322137, 0.01685035167611204, 0.053285902613424696, 1.7610892443917692, 5.134677775204182, 9.476625937968493, 13.409276213496923, 13.451775033026934, 17.1911496296525, 15.699762906879187, 16.44277598708868, 9.022972080856562, 16.504064798355103, 30.66524561494589, 39.81424458324909, 51.07945829629898, 52.552335262298584, 54.045096561312675, 53.62934947013855, 52.35556282103062, 52.59357824921608, 51.33849419653416, 53.35088521242142, 53.974762335419655, 55.417468920350075, 55.702286437153816, 55.37420064210892, 52.31857940554619, 50.23000247776508, 46.88248090445995, 43.63916493952274, 39.72426921129227, 38.99529352784157, 40.87827108800411, 48.84180396795273, 54.63129110634327, 55.17643265426159, 55.80742299556732, 51.20450958609581, 46.39846287667751, 40.370014160871506, 38.374961614608765, 39.99739855527878, 37.34171345829964, 42.64960303902626, 44.94337275624275, 44.39411602914333, 40.84303177893162, 45.21995611488819, 42.96541169285774, 47.77277313172817, 48.594038262963295, 57.66631364822388, 34.96289290487766, 43.209772780537605, 56.67959399521351, 52.95987479388714, 51.393906623125076, 44.69513587653637, 45.384646877646446, 48.46145577728748, 53.89412686228752, 56.00250072777271, 54.52506020665169, 53.662008717656136, 46.51916719973087, 38.2015161216259, 49.60948437452316, 54.6566167473793, 55.744209587574005, 54.14288431406021, 50.38651987910271, 53.079591169953346, 55.26565946638584, 54.53173644840717, 52.22467124462128, 51.46459802985191, 52.21745163202286, 53.172955960035324, 54.65583398938179, 55.5394271761179, 54.03161108493805, 49.55320939421654, 46.68530188500881, 46.5793027728796, 48.27295169234276, 49.06228333711624, 51.576308235526085, 53.52319076657295, 53.45481723546982, 57.0644411444664, 55.49710504710674, 48.74552093446255, 34.648425579071045, 24.84908200800419, 23.95262461155653, 7.557812025770545, 11.182046625763178, 16.543124802410603, 12.501350082457066, 10.462168604135513, 10.94480350613594, 7.068441035225987, 5.260715112090111, 0.26444378192536533, 0.35509810026269406, 0.046635877224616706, 0.603906997712329, 8.529503960162401, 30.30451387166977, 59.52150709927082, 49.74241644144058, 27.290350310504436, 37.535769045352936, 46.97066277265549, 52.95046269893646, 41.09837427735329, 11.740355417132378, 0.36339445039629936, 0.025315820566902403, 0.029655547659785952, 0.03167632487020455, 0.04081375838723034, 0.058429954515304416, 0.03609484949265607, 0.051230250028311275, 0.019774851389229298, 0.09379758092109114, 0.0334515384020051, 0.07759313521091826, 0.03355636305059306, 0.013592907816928346, 0.0766210033907555, 0.03846386280201841, 0.10147461624001153, 0.049905972846318036, 0.018485466280253604, 0.043758010360761546, 0.030938138406781945, 0.023987667518667877, 0.07660841656615958, 0.002667510902938375, 0.1957208031672053, 0.11018570075975731, 0.18032168416539207, 0.23871030105510727, 0.14548807754181325, 0.25466058345045894, 0.10789239764562808, 0.14987624832428992, 0.12018038905807771, 0.1648756762733683, 0.11091627093264833, 0.15927912580082193, 0.1953700790181756, 0.1294518544455059, 0.12538691866211593, 0.1759759642300196, 0.1407110659056343, 0.18163583474233747, 0.2089305271510966, 0.1647599012358114, 0.13132438209140673, 0.1427955212420784, 0.18089368706569076, 0.8115158637519926, 19.678273871541023, 56.04256957769394, 56.9348680973053, 48.671516105532646, 34.04943332076073, 27.725482061505318, 57.10207052528858, 62.26793892681599, 39.835565239191055, 9.425793215632439, 1.3569856784306467, 0.26401289098430425, 0.5748988792765886, 2.058541914448142, 10.63574519008398, 20.347047485411167, 20.280193872749805, 19.794718623161316, 25.396474935114384, 20.519820414483547, 23.104175738990307, 17.359486296772957, 22.417491786181927, 42.65660986304283, 40.25858134031296, 54.62672375142574, 52.304383367300034, 55.08459538221359, 54.472235441207886, 53.50155472755432, 52.965684682130814, 51.96378864347935, 50.96704512834549, 55.46372763812542, 56.73003628849983, 59.702164605259895, 58.947711288928986, 55.17795257270336, 54.96005706489086, 49.71806354820728, 48.615408316254616, 42.648345306515694, 40.15695959329605, 43.50094735622406, 50.24714335799217, 57.21973121166229, 56.9148887693882, 57.83310569822788, 52.535194382071495, 48.950063958764076, 41.63786172866821, 40.14099285006523, 42.115252912044525, 40.038736537098885, 45.63386030495167, 47.47221305966377, 47.6554886251688, 43.444729372859, 47.77616634964943, 45.80216847360134, 49.6713450551033, 51.49130679666996, 58.66467967629433, 40.00060938298702, 44.9398959428072, 57.14468143880367, 55.773038640618324, 52.9003281891346, 47.95425519347191, 46.8700897693634, 50.9444135427475, 57.82843194901943, 57.07137577235699, 56.23600199818611, 56.058258935809135, 48.61738421022892, 40.120219364762306, 50.85824936628342, 58.6223803460598, 59.57900561392307, 57.26338326931, 51.11179456114769, 53.444025814533234, 55.56679330766201, 57.45244212448597, 55.90611509978771, 54.454870373010635, 54.52043205499649, 56.67678974568844, 57.03806675970554, 59.70081947743893, 58.13748836517334, 53.04032787680626, 50.18074192106724, 49.80116128921509, 50.31385637819767, 50.30589580535889, 55.45368477702141, 58.504871651530266, 55.45286402106285, 60.089333429932594, 57.53827191889286, 49.53517556190491, 36.192506924271584, 25.816540494561195, 31.70046016573906, 14.815850537270308, 20.94302460551262, 27.495930679142475, 19.514918737113476, 22.920024320483208, 15.816862173378468, 11.814980562776327, 7.2941194754093885, 2.3293111100792885, 0.6475332879927009, 0.21230063459370285, 0.8942561864387244, 10.152136590331793, 36.940435990691185, 72.39081993699074, 60.83648733794689, 43.630729392170906, 46.10593557357788, 50.79939052462578, 60.852936655282974, 46.77111268043518, 15.151207242161036, 0.7069865602534264, 0.24478387436829507, 0.10598678505630232, 0.18807084881700575, 0.1891111914301291, 0.16691095690475777, 0.18127771880244836, 0.200511900766287, 0.0998542110028211, 0.21063295454951003, 0.15729494945844635, 0.15768618002766743, 0.1020939830050338, 0.16987717273877934, 0.18626517383381724, 0.11948826955631375, 0.24336758942808956, 0.10180818935623392, 0.0988103802956175, 0.12651697208639234, 0.13118410133756697, 0.23749683023197576, 0.2729943621670827, 0.12716739031020552], [0.05476496953633614, 0.0370283673692029, 0.012160351288912352, 0.021616490848828107, 0.13155297841876745, 0.08914277132134885, 0.05075170949567109, 0.038962133330642246, 0.04010108139482327, 0.02084656272927532, 0.05810675291286316, 0.033116544072981924, 0.07371367697487585, 0.04272048048733268, 0.08305776151246391, 0.017781201531761326, 0.02355580621951958, 0.046980927654658444, 0.06456869581597857, 0.04953973038936965, 0.02513049701519776, 0.0525686948094517, 0.04698446027759928, 0.38278356310911477, 16.327497772872448, 44.51837316155434, 43.431741669774055, 35.569306164979935, 16.3380479067564, 34.1681769490242, 52.849251329898834, 50.45387126505375, 27.121048495173454, 5.5636633560061455, 0.3202974301530048, 0.4345401405589655, 0.5537313432432711, 1.765604114625603, 2.1231816709041595, 7.8787637036293745, 11.830398235470057, 13.238164745271206, 15.43727109208703, 15.752672217786312, 16.3575978577137, 9.121918771415949, 19.33020494878292, 30.88606506586075, 43.00006203353405, 52.30943329632282, 56.50615230202675, 53.5573623329401, 55.81188015639782, 53.96973140537739, 52.07566224038601, 53.85498896241188, 51.86669625341892, 51.75263777375221, 53.91513213515282, 53.581684827804565, 55.08856236934662, 54.06952545046806, 52.72722087800503, 50.29877118766308, 50.6543143093586, 48.01361560821533, 41.7713637650013, 35.84894835948944, 37.09778554737568, 38.977172300219536, 44.38638724386692, 44.90452744066715, 44.02020089328289, 38.832799047231674, 38.574960082769394, 35.915186405181885, 38.3308269828558, 40.821813717484474, 46.64542682468891, 50.441442131996155, 48.08541655540466, 38.74480716884136, 38.62370386719704, 38.11875656247139, 44.747527465224266, 45.173644199967384, 56.26201160252094, 33.73699128627777, 39.28943574428558, 56.92017048597336, 46.83773450553417, 50.395350605249405, 44.63326759636402, 40.00895753502846, 38.21967914700508, 43.27270120382309, 47.943722158670425, 53.50207909941673, 50.656548589468, 44.470427334308624, 37.90525361895561, 39.90946747362614, 46.148284301161766, 53.57919596135616, 54.552635326981544, 53.99525463581085, 49.77721497416496, 51.807031854987144, 54.05614256858826, 52.93867193162441, 52.895627841353416, 55.58654084801674, 52.94996112585068, 53.81524309515953, 54.54862654209137, 54.53566923737526, 50.95302768051624, 49.56120416522026, 51.62423886358738, 51.52085021138191, 50.74053168296814, 53.11708375811577, 53.9881794154644, 55.061340630054474, 53.699182122945786, 51.297372803092, 41.332046538591385, 39.78196531534195, 30.808758214116096, 14.197568614035845, 14.50951762497425, 7.142385067418218, 15.90339682996273, 11.633701790124178, 8.841646760702133, 7.295821784064174, 5.443572225049138, 3.5858248360455036, 0.7289911794941872, 0.21980953635647893, 0.08787835948169231, 0.2654253167565912, 5.508478917181492, 20.20652912557125, 46.489437595009804, 63.644624054431915, 46.484611853957176, 29.463115520775318, 41.96510776877403, 51.34412929415703, 30.420384854078293, 9.99055976048112, 0.3733066044514999, 0.022053643660910893, 0.020440407570276875, 0.010912134039244847, 0.04798967333044857, 0.023082950538082514, 0.04254550804034807, 0.060451750323409215, 0.09257225799956359, 0.01310746531089535, 0.056204654392786324, 0.028634118680201937, 0.022065280536480714, 0.04376054850581568, 0.04607919596310239, 0.04065447494213004, 0.014267128572100773, 0.05318643256032374, 0.0747632073762361, 0.05672819876053836, 0.06268465003813617, 0.032665719045326114, 0.040669804002391174, 0.011383626952010673, 0.05962057832221035, 0.03894467059581075, 0.023135956580517814, 0.03314001078251749, 0.01517929857072886, 0.0704964816395659, 0.08490852938848548, 0.034129842824768275, 0.030053778536967002, 0.025187570026901085, 0.018131363503925968, 0.012437028581189224, 0.026416217770020012, 0.018421084969304502, 0.015908555142232217, 0.03788262758462224, 0.012748366953019286, 0.04383656298159622, 0.022894565627211705, 0.019786529082921334, 0.036440300682443194, 0.06934526216355152, 0.0231804668874247, 0.8283747872337699, 20.329619720578194, 53.45201298594475, 48.97672712802887, 41.21997155249119, 20.61919078230858, 27.422045543789864, 54.12685677409172, 55.660971254110336, 31.88148245215416, 7.15835846029222, 0.46735657495446503, 0.07955219727591611, 0.3639077197294682, 3.4212720533832908, 4.171801367774606, 9.13110002875328, 12.127634435892105, 9.64680265635252, 15.205323938280344, 12.883270438760519, 14.22576880082488, 11.240520738065243, 19.37078107148409, 32.119406685233116, 42.81731463968754, 53.66270028054714, 57.753059193491936, 54.814521074295044, 56.82518318295479, 53.822827488183975, 52.82348871231079, 53.544519022107124, 52.544515281915665, 51.966383904218674, 54.22687120735645, 54.469602182507515, 56.8262243270874, 55.50108723342419, 53.82090479135513, 52.29828469455242, 51.44842229783535, 50.36199979484081, 43.93873706459999, 38.62301990389824, 38.42247426509857, 42.21809059381485, 48.167704939842224, 47.565710842609406, 46.89035028219223, 40.53045675158501, 41.2715195864439, 37.434367686510086, 39.45826828479767, 42.569104358553886, 48.15424606204033, 51.72857366502285, 49.69026803970337, 39.98499222099781, 41.415835842490196, 41.48568369448185, 48.29081833362579, 48.49338926374912, 57.96469643712044, 37.1689747273922, 40.916158854961395, 56.838463470339775, 50.18211744725704, 52.64628142118454, 46.92228376865387, 42.4288272857666, 41.47578522562981, 45.04062473773956, 51.136006861925125, 54.78417970240116, 52.90747560560703, 46.10156200826168, 38.28044928610325, 41.348879635334015, 49.92334373295307, 54.153937920928, 56.42332814633846, 53.548721596598625, 49.909094497561455, 53.73397305607796, 56.49219185113907, 54.87041987478733, 55.92024274170399, 57.31447912752628, 55.888161063194275, 56.69637769460678, 56.62139251828194, 56.17191083729267, 53.29169198870659, 51.998541578650475, 53.078124448657036, 53.615024238824844, 53.065604120492935, 54.71120081841946, 56.037215664982796, 58.0100280046463, 55.20773537456989, 50.906286388635635, 44.38305862247944, 40.10516457259655, 31.14114347845316, 18.474336974322796, 15.868725590407848, 8.610278125852346, 8.549113757908344, 15.254187416285276, 9.056200347840786, 16.2740346416831, 8.279222790151834, 4.429981838911772, 1.3055075844749808, 0.47231803997419775, 0.035146985901519656, 0.4241265618475154, 6.690092487260699, 24.420094527304173, 55.262368842959404, 63.30338716506958, 47.478741109371185, 32.1222223341465, 46.03521376848221, 56.877779960632324, 35.887102112174034, 12.154059167951345, 0.4335259215440601, 0.033379820961272344, 0.013853554719389649, 0.07870276473113336, 0.02181946638302179, 0.05297447518387344, 0.04432781279319897, 0.018605215518618934, 0.011919885237148264, 0.02899811242969008, 0.029807188839185983, 0.06847578421002254, 0.024554785231885035, 0.10690420574974269, 0.0233782158466056, 0.016566444937780034, 0.023930928473419044, 0.054397855055867694, 0.04299983600503765, 0.04694203911640216, 0.05344148645235691, 0.02755656292720232, 0.003744726659533626, 0.024938455171650276, 0.15846659283852205, 0.13277939229737967, 0.13634334871312603, 0.14823890727711841, 0.19728946586837992, 0.1386034704046324, 0.1909696331131272, 0.15698056085966527, 0.08701749044121243, 0.16642024886095896, 0.10272869738400914, 0.10776447365060449, 0.16822921897983178, 0.15347294829552993, 0.1452776341466233, 0.1149659555812832, 0.10892544494709, 0.11996189336059615, 0.14773460308788344, 0.08313199112308212, 0.13898839271860197, 0.28813298733439296, 0.14161425962811336, 1.4347752230241895, 25.890940502285957, 62.59605512022972, 56.162259355187416, 47.07603871822357, 23.936465978622437, 44.309505969285965, 62.148108556866646, 57.462351992726326, 32.7360375970602, 7.488464321941137, 0.5126899830065668, 0.6627389439381659, 1.3109656353481114, 4.96918810531497, 4.4051059987396, 16.06870125979185, 20.389920584857464, 22.778728902339935, 23.553858809173107, 27.47461572289467, 27.28626172989607, 15.588293988257647, 21.972324773669243, 33.609378933906555, 48.44797410070896, 55.754636228084564, 59.740014374256134, 57.3006022721529, 58.86627785861492, 55.945632979273796, 53.892690539360046, 54.46071445941925, 51.99498496949673, 52.64666900038719, 54.43886183202267, 54.39763784408569, 57.98046939074993, 57.206287533044815, 57.19540871679783, 56.95218376815319, 54.469507187604904, 53.75422976911068, 47.17757686972618, 41.99467018246651, 39.76721830666065, 42.38736391067505, 50.34191407263279, 49.1526310890913, 47.62355133891106, 42.183383256196976, 42.72704288363457, 39.68836113810539, 41.47611200809479, 44.78349633514881, 51.967987418174744, 53.634293004870415, 52.4654833227396, 42.584881111979485, 42.970036044716835, 43.09356741607189, 50.33641576766968, 51.58370643854141, 59.263044968247414, 40.69297783076763, 43.90046551823616, 59.34654548764229, 51.556841880083084, 55.01795455813408, 50.17440766096115, 43.63989070057869, 43.46386894583702, 46.41451321542263, 51.65556438267231, 57.77735508978367, 56.566124483942986, 49.49056215584278, 40.372525826096535, 42.718808725476265, 50.78563906252384, 56.57813563942909, 57.98510134220123, 55.67379176616669, 50.480792820453644, 52.99922928214073, 58.60505327582359, 56.704904437065125, 58.50853085517883, 59.452745988965034, 56.70458525419235, 56.95607855916023, 58.09583880007267, 59.53922934830189, 55.63618518412113, 54.179856330156326, 54.57071855664253, 54.97970961034298, 54.79986146092415, 57.89202153682709, 58.97346630692482, 59.82807084918022, 55.99753439426422, 52.18801461160183, 44.91716556251049, 42.75939054787159, 33.85613389313221, 18.743890710175037, 21.347332410514355, 15.672643762081861, 28.620273247361183, 24.39618621021509, 16.381002701818943, 18.249256052076817, 14.40580504015088, 9.764552637934685, 1.6758572054095566, 1.1102241883054376, 0.2944589057005942, 0.6950379826594144, 7.4447709415107965, 27.134655565023422, 53.23494963347912, 73.53474855422974, 57.3994729667902, 41.81459404528141, 55.53945757448673, 64.11729589104652, 43.506962433457375, 14.8507659137249, 1.001108530908823, 0.12713077274383977, 0.18309736100491136, 0.15056125062983483, 0.07993405451998115, 0.13309004047187045, 0.1249255402944982, 0.14446131623117253, 0.23758735740557313, 0.07308439511689357, 0.1086165482411161, 0.2637946105096489, 0.1370805685291998, 0.17252965306397527, 0.08513675464200787, 0.16688351228367537, 0.06836833606939763, 0.13343206665012985, 0.08267062759841792, 0.16511384630575776, 0.16822817997308448, 0.13832764379912987, 0.13057105767074972, 0.15631191548891366], [0.0255254550211248, 0.06721738376654685, 0.012479185352276545, 0.06682664301479235, 0.019203651863790583, 0.0028481617073339294, 0.030104719553492032, 0.030691038482473232, 0.046175285533536226, 0.03710653407324571, 0.08422841783612967, 0.03383148090506438, 0.13427755096927285, 0.10290483871358447, 0.08908688017982058, 0.03131403063889593, 0.07339500618400052, 0.035678426720551215, 0.06326538059511222, 0.013457696859404678, 0.0997229473432526, 0.01861940723756561, 0.0419562613387825, 0.8555281301960349, 16.586256287992, 41.11854739487171, 42.94488899409771, 31.129941679537296, 22.98287484794855, 47.36572377383709, 37.33499921858311, 32.62340784072876, 16.08923725783825, 3.8152133021503687, 0.4981495882384479, 0.012969306171726203, 0.1336050612735562, 3.501490973867476, 4.815528150647879, 4.760795412585139, 11.583925411105156, 7.538846293464303, 19.37381900846958, 12.08953958004713, 13.701560329645872, 12.71609365940094, 25.072842501103878, 38.05134817957878, 49.457807913422585, 53.77743512392044, 54.50240582227707, 51.818454042077065, 51.25238701701164, 51.4638988673687, 56.10999695956707, 54.84332732856274, 54.913581758737564, 53.189576268196106, 50.35944253206253, 50.94702400267124, 52.964673936367035, 53.224192410707474, 54.37284417450428, 52.77678161859512, 51.37018069624901, 50.23374527692795, 50.811169892549515, 41.66385233402252, 36.342883855104446, 35.860484540462494, 36.58067129552364, 36.70433185994625, 35.87551653385162, 36.20698034763336, 37.83428482711315, 40.65201222896576, 45.50404407083988, 47.863759249448776, 55.67338518798351, 52.513060569763184, 47.97824330627918, 41.14916235208511, 39.35562439262867, 37.794523760676384, 44.32277485728264, 44.913901537656784, 56.09545513987541, 37.290081828832626, 40.003356635570526, 54.02817986905575, 50.107713639736176, 49.62704323232174, 46.950200870633125, 44.03004616498947, 39.44117300212383, 38.07287022471428, 38.139518648386, 42.97062501311302, 40.037999376654625, 37.30505682528019, 36.2453430891037, 37.88161888718605, 40.12308441102505, 46.69005163013935, 52.73507125675678, 53.301636055111885, 52.252307161688805, 50.6152980029583, 52.49013639986515, 55.493521839380264, 52.939051911234856, 51.57874770462513, 51.24547518789768, 50.62176525592804, 52.30824775993824, 52.6633121073246, 55.372407138347626, 51.465483382344246, 53.67010988295078, 52.511510252952576, 55.25132283568382, 54.92272786796093, 55.135440453886986, 50.77966198325157, 52.77188368141651, 50.33029429614544, 45.96503533422947, 37.82689042389393, 34.255750849843025, 26.86585608869791, 13.716927655041218, 14.557829182595015, 4.87701740115881, 9.02151770889759, 6.635991465300322, 13.466274105012417, 7.256618337705731, 3.900501150637865, 0.12165604581241496, 0.23582299036206678, 0.13976852351333946, 0.08995866621262394, 3.540036818012595, 16.05617143213749, 25.21026022732258, 48.9881607145071, 47.20204375684261, 33.07165838778019, 38.18793185055256, 50.921276584267616, 37.23600313067436, 7.852943139150739, 0.29562493844423443, 0.04118106582609471, 0.06853593527921475, 0.04572258658299688, 0.03269448840001132, 0.03998081636382267, 0.02675878942682175, 0.026499876366870012, 0.06255111540667713, 0.0407592550618574, 0.04077284007507842, 0.03674668521853164, 0.033961308508878574, 0.0533495083800517, 0.02284188612975413, 0.04321664331655484, 0.017444949262426235, 0.020269474262022413, 0.03045056222617859, 0.023802616706234403, 0.09846194196143188, 0.07269385474501178, 0.07909493782790378, 0.01687375159235671, 0.03681274378322996, 0.029367290080699604, 0.040033323311945423, 0.029297747132659424, 0.041835855299723335, 0.016997018610709347, 0.08343237539520487, 0.08235099201556295, 0.11166151336510666, 0.061294518382055685, 0.024692058432265185, 0.04513702464464586, 0.05349018618289847, 0.06417552824132144, 0.05274328505038284, 0.04339951592555735, 0.03722676570760086, 0.012965839414391667, 0.0690401133033447, 0.03816081050899811, 0.03436810562561732, 0.07074344612192363, 0.04424192404258065, 1.3309941231273115, 21.46493799984455, 48.478273674845695, 48.88207420706749, 36.07286274433136, 21.406143754720688, 49.39257301390171, 48.60530465841293, 42.076483592391014, 21.255536936223507, 4.007817842066288, 0.8066656021401286, 0.02101018402754562, 0.3773232561070472, 2.183256447315216, 5.906669525429606, 7.562910877168179, 8.593984600156546, 12.838459443300962, 13.819904029369354, 19.31760862469673, 16.722235791385174, 13.464359007775784, 24.470447525382042, 37.08062566816807, 51.05591855943203, 56.8631811439991, 55.02798981964588, 54.14758086204529, 53.44890475273132, 53.78838613629341, 56.8893351405859, 56.763223707675934, 54.77565295994282, 53.337908908724785, 50.788557305932045, 51.297665387392044, 52.49448336660862, 53.81563827395439, 55.51023334264755, 55.553361028432846, 53.78783516585827, 53.09180371463299, 51.739099100232124, 43.85756962001324, 38.22828188538551, 37.05277696251869, 38.9337520301342, 38.7932051718235, 39.101357236504555, 37.789903208613396, 39.64760072529316, 42.431882321834564, 46.7189908772707, 50.51614232361317, 55.74057698249817, 54.10126134753227, 51.13579407334328, 43.95969294011593, 40.982761681079865, 40.74033848941326, 45.3390721231699, 47.0207554847002, 57.82707542181015, 40.157392770051956, 41.81023187935352, 55.541114285588264, 52.77606725692749, 51.5156102925539, 50.03948450088501, 43.82519155740738, 41.046123281121254, 39.480637684464455, 41.51683822274208, 44.35835234820843, 42.66620434820652, 38.677847161889076, 37.17131160199642, 39.27147410809994, 42.24215470254421, 48.979732766747475, 53.17937761545181, 54.61134597659111, 52.53366306424141, 49.703795313835144, 53.602230325341225, 55.75615234673023, 54.90848243236542, 53.43236044049263, 52.72889658808708, 51.96343146264553, 53.70929338037968, 55.531200617551804, 57.785524651408195, 54.791463911533356, 55.66140443086624, 55.12085683643818, 56.679385006427765, 56.0381618142128, 58.33125896751881, 52.43695445358753, 52.38644756376743, 51.40636995434761, 45.76047331094742, 38.99225369095802, 33.99937100708485, 25.624172016978264, 15.012651477009058, 9.495605919510126, 6.504991594702005, 14.852985944598913, 11.015754248946905, 15.669181197881699, 8.563217651098967, 8.696847930550575, 1.538267182186246, 0.3404746443266049, 0.06734134469297715, 0.21638848789734766, 4.108984088525176, 20.68093366920948, 33.34082834422588, 54.782553389668465, 51.18165381252766, 38.65241892635822, 42.90753319859505, 58.88266257941723, 44.41731758415699, 10.318014789372683, 0.7759767863899469, 0.010980090646626195, 0.12093288969481364, 0.021284761969582178, 0.05227040339377709, 0.04504247503064107, 0.031851171152084135, 0.06079057784518227, 0.0898471733671613, 0.052480913582257926, 0.06480400115833618, 0.019954363924625795, 0.04756852678838186, 0.009436723121325485, 0.0582657840277534, 0.016848642881086562, 0.019117714873573277, 0.04602997672918718, 0.05572881898842752, 0.028045181825291365, 0.10567820747382939, 0.03598449955461547, 0.02253123609989416, 0.0336827285354957, 0.081296971620759, 0.16491644986672327, 0.11834577773697674, 0.1551176662906073, 0.10917764157056808, 0.10062075307359919, 0.11150348786031827, 0.1788167274207808, 0.18724083085544407, 0.17511946643935516, 0.11325152023346163, 0.15513673948589712, 0.3407726314617321, 0.19360256526852027, 0.19020335079403594, 0.16524455335456878, 0.23237682762555778, 0.2047315298113972, 0.16995233745547011, 0.12689376046182588, 0.1609374993131496, 0.09504271176410839, 0.1417130246409215, 1.9554654392413795, 27.661841176450253, 55.77826716005802, 56.22465580701828, 42.919878736138344, 32.04959683120251, 59.202875196933746, 46.96848928928375, 44.425509944558144, 22.850546948611736, 5.278176125138998, 0.9899409301578999, 0.17104933562222868, 0.7030737795867026, 5.052487710490823, 11.813551839441061, 12.718803863972425, 19.443803653120995, 21.41203533858061, 30.932984948158264, 17.37445369362831, 19.621900096535683, 17.134988643229008, 28.87202873826027, 45.03998637199402, 53.4855879843235, 59.0917843580246, 58.1805020570755, 56.24163709580898, 56.6915063560009, 56.0375614464283, 60.094368159770966, 59.06720347702503, 56.32090464234352, 53.86608436703682, 50.191552340984344, 50.92324107885361, 53.190818801522255, 53.825905323028564, 56.01904883980751, 57.05314055085182, 55.432869493961334, 55.157665461301804, 55.64915008842945, 46.65550388395786, 40.90404890477657, 40.03691643476486, 40.01781105995178, 39.88092340528965, 39.70169462263584, 39.72920894622803, 41.8112426251173, 44.62627597153187, 49.74773235619068, 52.88973055779934, 58.77216450870037, 56.17582082748413, 54.44379776716232, 46.25136896967888, 44.92196090519428, 41.630368530750275, 47.96429045498371, 50.3257155418396, 61.035383865237236, 45.100771710276604, 44.155762419104576, 54.8677372187376, 55.58632045984268, 53.3624441921711, 52.67930544912815, 46.19070142507553, 42.3747143894434, 41.35978884994984, 42.528910115361214, 46.901134103536606, 44.59015130996704, 40.83412505686283, 39.22972194850445, 41.64350442588329, 44.4877278059721, 51.09148845076561, 55.87125577032566, 56.648454666137695, 53.78904730081558, 51.13091133534908, 54.88588124513626, 59.14045214653015, 54.58948574960232, 53.422169387340546, 54.64664228260517, 51.64261467754841, 53.01706552505493, 54.60042916238308, 59.091164991259575, 55.74353702366352, 57.63833574950695, 57.584591433405876, 59.241933301091194, 59.94465999305248, 58.78776267170906, 52.52095654606819, 52.01829671859741, 52.96544909477234, 46.309547647833824, 41.73272743821144, 35.982689782977104, 35.839775651693344, 22.42239162325859, 21.937469244003296, 12.668390069156885, 18.774957843124866, 15.200032722204924, 24.653478004038334, 16.494542509317398, 10.892562009394169, 3.0958546651527286, 0.6101894262246788, 0.47235342557542026, 0.6468715891242027, 5.010488564148545, 21.725843399763107, 38.37460443377495, 58.59179578721523, 58.64817716181278, 47.504621520638466, 51.48252546787262, 65.39910390973091, 53.43189686536789, 13.108496703207493, 1.2702932115644217, 0.0896016412298195, 0.21854405582416803, 0.12292525192606263, 0.0645054574124515, 0.25914116646163166, 0.12054571867338382, 0.1083613904484082, 0.13628930551931262, 0.2269168323255144, 0.17218871042132378, 0.07816798795829527, 0.15260807907907292, 0.16241892997641116, 0.14883305586408824, 0.09281555627239868, 0.21485831297468394, 0.10580259884591214, 0.12178657474578358, 0.13977011170936748, 0.20211948169162497, 0.18449120339937508, 0.10610212222672999, 0.08378495491342619], [0.001186107954254112, 0.03540017700288445, 0.045920547054265626, 0.0565303978510201, 0.031205806953948922, 0.035447143818601035, 0.023318413586821407, 0.03377749337232672, 0.03547098531271331, 0.05505376888322644, 0.08586494994233362, 0.019226810582040343, 0.07192484132247046, 0.07113036481314339, 0.06759526309906505, 0.025670550458016805, 0.03084372237935895, 0.016021452502172906, 0.05319361654983368, 0.02852340508979978, 0.0363910554733593, 0.03839523640635889, 0.06781277916161343, 1.4075860194861889, 16.30618281662464, 38.08118797838688, 42.399546056985855, 30.252682752907276, 22.970210127532482, 27.68956258893013, 30.223754905164242, 32.59810119867325, 23.06766539812088, 3.680882197804749, 0.1843075515353121, 0.1470143932965584, 6.634627338498831, 3.513928181491792, 4.25690540112555, 6.658901860937476, 8.262301348149776, 10.054403934627771, 6.547857094556093, 18.982358314096928, 14.990248829126358, 15.736211501061916, 25.941977463662624, 36.30798652768135, 53.524805679917336, 54.90517280995846, 50.73402643203735, 48.06159183382988, 48.28911602497101, 47.08568640053272, 47.620522901415825, 51.63981802761555, 50.149389803409576, 52.1940790861845, 53.195834532380104, 53.645388409495354, 53.86342070996761, 54.58331488072872, 51.75170682370663, 49.90697041153908, 50.690226182341576, 51.16467632353306, 51.67379580438137, 47.062519043684006, 36.408586129546165, 34.71727788448334, 34.30700249969959, 35.61125211417675, 39.356528744101524, 40.770603865385056, 44.38787296414375, 47.698308527469635, 51.4471759647131, 54.056853130459785, 50.92780463397503, 48.196860775351524, 53.24211224913597, 41.3015303760767, 39.25491459667683, 35.84456339478493, 42.62158714234829, 44.490057080984116, 55.305504128336906, 39.43828135728836, 42.92265638709068, 51.91575162112713, 50.07399424910545, 51.82231083512306, 48.09437267482281, 47.75049112737179, 41.692624390125275, 38.900294825434685, 35.3544656932354, 36.579755544662476, 37.200444638729095, 36.03343985974789, 38.5089386254549, 40.29646150767803, 36.03935994207859, 43.38128037750721, 50.270728692412376, 56.20796710252762, 52.08953909575939, 52.18707226216793, 50.82471236586571, 50.613006725907326, 51.60178206861019, 51.6232281178236, 51.73588067293167, 53.06552812457085, 52.453825548291206, 50.99637195467949, 53.52132126688957, 50.842256024479866, 54.193300008773804, 52.87339523434639, 55.24681247770786, 52.175783067941666, 52.90815196931362, 50.980811789631844, 50.31498111784458, 48.34713511168957, 51.582961678504944, 41.879023388028145, 39.65306103229523, 31.070868149399757, 17.387768179178238, 11.000886596739292, 4.235264612361789, 12.899963892996311, 9.598379954695702, 16.733669377863407, 6.060397876426578, 4.761606669053435, 1.9728094898164272, 0.6218726118095219, 0.15535435202764347, 0.10709344598581083, 2.011559810489416, 13.494895119220018, 31.155685298144817, 34.2962870746851, 45.97354307770729, 28.93764741718769, 38.94525021314621, 49.667309671640396, 40.52299775183201, 11.88532143831253, 0.6134092784486711, 0.09854918884229846, 0.009550219765515067, 0.047709030186524615, 0.016294381020998117, 0.014457102606684202, 0.06762487479136325, 0.05266417581879068, 0.05202341293625068, 0.12299255729885772, 0.038162684431881644, 0.010867581058846554, 0.03565546096069738, 0.01977548407012364, 0.0789055714267306, 0.016587687059654854, 0.04861255787545815, 0.058962426919606514, 0.058888924613711424, 0.07944517215946689, 0.036172938271192834, 0.018708691313804593, 0.0641236372757703, 0.01720164727885276, 0.026818454389285762, 0.05201004314585589, 0.09470113087445498, 0.09533165211905725, 0.02940461639809655, 0.06775648726033978, 0.008166829593392322, 0.023893171710369643, 0.00763999287300976, 0.037435008634929545, 0.010861814571399009, 0.07921558877569623, 0.0495514711656142, 0.05834224750287831, 0.04236626824422274, 0.011299874659016496, 0.022017211631464306, 0.04525274031038862, 0.01894413395348238, 0.016870844228833448, 0.04092178540304303, 0.038890271171112545, 0.05932279898843262, 1.9057072279974818, 21.055992543697357, 45.201523303985596, 49.121328368783, 35.1028735935688, 28.488553315401077, 32.64505907893181, 35.47499142587185, 36.55579783022404, 22.214713767170906, 3.97897572722286, 0.23515410750405863, 0.15969377855071798, 4.795796759426594, 1.5348087740130723, 7.062473930418491, 11.11138941720128, 6.216840706765652, 11.12777603790164, 14.553824197500944, 18.894925005733967, 15.997096002101898, 11.70534884557128, 24.097928814589977, 41.112007945775986, 53.01974818110466, 57.64101080596447, 52.71500453352928, 51.17746643722057, 51.784958839416504, 50.7001056522131, 50.8013816177845, 53.77287536859512, 52.8632003813982, 54.13081996142864, 56.158451959490776, 53.128836527466774, 54.22286242246628, 54.05560679733753, 51.76177628338337, 50.95364324748516, 51.706960424780846, 52.28455223143101, 53.11606541275978, 49.15819399058819, 39.25478160381317, 36.48801326751709, 36.34058877825737, 35.46662047505379, 40.373665764927864, 41.31553642451763, 46.71817772090435, 48.71613331139088, 52.277655601501465, 55.71677125990391, 53.74950282275677, 50.95674388110638, 54.76519212126732, 44.213025346398354, 40.79950511455536, 38.834565952420235, 44.2201841622591, 46.82747885584831, 56.73959657549858, 41.166417226195335, 44.232381507754326, 52.553220614790916, 51.273346692323685, 53.7232880294323, 50.986310094594955, 50.28543770313263, 43.845330476760864, 40.44835455715656, 38.64144891500473, 38.972737938165665, 38.49027022719383, 37.19832435250282, 39.77903567254543, 41.85506947338581, 37.539120465517044, 45.22921621799469, 52.46877774596214, 55.475856587290764, 52.634665444493294, 53.616327568888664, 51.340815871953964, 50.48299290239811, 49.809228256344795, 52.2898605465889, 52.669053599238396, 53.96961361169815, 52.96017877757549, 50.65430670976639, 53.01830045878887, 52.196765542030334, 54.07586731016636, 54.76293504238129, 56.89930580556393, 54.640771597623825, 53.09320203959942, 49.1616328060627, 51.14189274609089, 49.91111218929291, 50.78413814306259, 43.19165535271168, 38.54070872068405, 27.726785391569138, 18.567378781735897, 13.134016133844852, 9.095473140478134, 14.552006945014, 12.507244516164064, 14.097323343157768, 11.165234427899122, 9.925641193985939, 2.435490475036204, 0.6308972463011742, 0.22941325383726507, 0.09437272310606204, 2.300433134660125, 14.27061589434743, 31.46035484969616, 40.38269408047199, 51.44455410540104, 36.26078546047211, 43.530543968081474, 55.64754657447338, 46.318260580301285, 13.922535572201014, 0.8442767558153719, 0.041983386836363934, 0.04483234333747532, 0.02126869818312116, 0.03310119645902887, 0.04209931030345615, 0.028023754166497383, 0.05274741881294176, 0.061258208806975745, 0.025039901192940306, 0.08076710044406354, 0.01074982448699302, 0.046647202398162335, 0.07341385673498735, 0.054691129553248174, 0.024910119973355904, 0.08150676192599349, 0.027588857483351603, 0.02034729772276478, 0.06177163028041832, 0.05768768067355268, 0.026460564804438036, 0.06980689286137931, 0.018354980020376388, 0.17337080324068666, 0.12888966273749247, 0.19541977322660387, 0.20330197527073324, 0.09969537655706517, 0.175718127284199, 0.07940672148833983, 0.15423084434587508, 0.14419749757507816, 0.13242730259662494, 0.1585393084678799, 0.18812435766449198, 0.23891170509159565, 0.15715490619186312, 0.13609728222945705, 0.10378994629718363, 0.13648653868585825, 0.1849354529986158, 0.11276364719378762, 0.17060538288205862, 0.16713800956495106, 0.11925187325687148, 0.10347683419240639, 2.5218451162800193, 26.7140656337142, 53.047528490424156, 55.5808449536562, 43.17453347146511, 35.60362212359905, 35.76027251780033, 41.67301744222641, 43.737351670861244, 28.4542278572917, 5.368412733078003, 0.5185595992952585, 0.558020897442475, 8.846737537533045, 7.921878090128303, 8.336405921727419, 16.6034921631217, 16.082148738205433, 15.630664564669132, 15.239053778350353, 25.976546108722687, 20.80659292638302, 19.5449523255229, 31.208306774497032, 40.70054702460766, 56.387777253985405, 58.87531377375126, 55.59058003127575, 53.80324333906174, 53.31511773169041, 52.72548817098141, 53.06091137230396, 57.27259397506714, 56.47950433194637, 56.43448054790497, 58.337019458413124, 54.24214258790016, 54.55351307988167, 55.22828847169876, 51.642781868577, 51.03107929229736, 51.071908101439476, 53.78605306148529, 54.31745074689388, 52.34803922474384, 42.1977236866951, 38.7031652033329, 38.119128942489624, 38.648725524544716, 42.83745735883713, 44.26997289061546, 47.91319839656353, 52.93523691594601, 55.78850381076336, 57.79038459062576, 55.05327746272087, 54.60360959172249, 56.623774990439415, 46.7484050989151, 43.54064002633095, 41.04369141161442, 45.98882585763931, 49.70798648893833, 59.82552878558636, 46.186924427747726, 46.81984506547451, 54.62362311780453, 53.23152981698513, 55.07153928279877, 53.53186950087547, 52.8734028339386, 47.685822397470474, 43.97915929555893, 39.837898313999176, 40.413062050938606, 40.23362807929516, 39.07533623278141, 41.38322979211807, 44.80220653116703, 38.59238214790821, 47.58550778031349, 55.265192091464996, 57.65905983746052, 52.99107111990452, 53.57796102762222, 51.22179865837097, 50.68897224962711, 51.2877631187439, 52.89240561425686, 52.84605950117111, 54.638791903853416, 52.28486381471157, 51.22708797454834, 52.20281861722469, 51.64148613810539, 55.3879901021719, 55.05977891385555, 57.786303609609604, 54.86454539000988, 54.26108457148075, 50.198224782943726, 51.274574026465416, 49.89815108478069, 52.0524150878191, 44.57747898995876, 44.45876955986023, 33.20109464228153, 21.99176263064146, 21.405765675008297, 10.600519180297852, 26.507031843066216, 22.163435518741608, 24.42421730607748, 14.953576046973467, 14.352266862988472, 5.669113397598267, 1.516583883203566, 0.3880890877917409, 0.4898300237255171, 3.149750498123467, 16.958476714789867, 41.62667512893677, 47.14132681488991, 56.553645953536034, 40.188212916255, 52.008850425481796, 62.48237282037735, 54.77550856769085, 18.760341927409172, 1.969006487634033, 0.19989168795291334, 0.18046747165499255, 0.13426068937405944, 0.10584101983113214, 0.10521384567255154, 0.19405762053793296, 0.25707942084409297, 0.19179040391463786, 0.1974685164168477, 0.17436560767237097, 0.07840188322006725, 0.19152449240209535, 0.16493743780301884, 0.11266821442404762, 0.12554391258163378, 0.16863067634403706, 0.12229499043314718, 0.17465308599639684, 0.24909236817620695, 0.11687106351018883, 0.08731389680178836, 0.14254184032324702, 0.1450896926689893], [0.02232471866591368, 0.03735615544428583, 0.061052218297845684, 0.02392567963397596, 0.03203087850124575, 0.040197245180024765, 0.014411293541343184, 0.05977749060548376, 0.07661130352062173, 0.004866439967372571, 0.053431504566106014, 0.05707799893571064, 0.020819027195102535, 0.01860218013462145, 0.0334036439016927, 0.008402717521676095, 0.04152081732172519, 0.01850563414336648, 0.035713485776796006, 0.03722001587448176, 0.06372677380568348, 0.045820639134035446, 0.04176673908659723, 1.4625664567574859, 19.047484919428825, 40.92879697680473, 44.13933590054512, 28.568996898829937, 18.659356646239758, 29.816416762769222, 32.256514728069305, 36.677425503730774, 18.32001205533743, 2.9978764476254582, 0.5516035167966038, 1.2575644883327186, 16.02688640356064, 14.10648750141263, 6.206453489139676, 4.451841115951538, 1.966580436564982, 10.923976823687553, 15.738843809813261, 23.777549006044865, 17.77720358222723, 16.177172139286995, 25.04423763602972, 54.401635229587555, 53.893993869423866, 52.2536750882864, 47.62594521045685, 45.73063351213932, 44.06829871237278, 41.4398505538702, 43.063754215836525, 46.36735014617443, 46.761863976716995, 51.05510540306568, 49.558396115899086, 50.89793063700199, 49.295480623841286, 53.159614875912666, 55.52105896174908, 51.22128948569298, 51.13807015120983, 52.58734278380871, 52.08971008658409, 47.7565898001194, 38.25634337961674, 33.99163082242012, 36.76838882267475, 44.21600818634033, 49.65600907802582, 49.80015054345131, 51.16485111415386, 52.876161485910416, 53.62792454659939, 47.56769813597202, 49.84735921025276, 53.16239632666111, 48.62683430314064, 41.597861275076866, 38.04303042590618, 37.956106290221214, 42.665778771042824, 44.49691191315651, 53.94117593765259, 39.792087972164154, 44.55145798623562, 54.9599202722311, 46.36679917573929, 47.83730886876583, 48.58209170401096, 45.1006843149662, 44.86895754933357, 38.94029147922993, 37.57708042860031, 39.07740332186222, 37.086899131536484, 36.41948774456978, 40.023772940039635, 42.14348919689655, 33.869121596217155, 43.495935425162315, 47.448882311582565, 53.33340995013714, 51.471194475889206, 45.80423176288605, 53.056625202298164, 54.88741256296635, 54.4029575586319, 55.33932611346245, 52.76960380375385, 53.292744532227516, 51.04871794581413, 51.25345095992088, 51.38808533549309, 48.8546434789896, 50.76582692563534, 51.63721136748791, 50.79481936991215, 48.948597237467766, 52.088254764676094, 49.01454269886017, 51.78137183189392, 52.94049583375454, 52.45586983859539, 51.076581850647926, 42.32684835791588, 31.132493242621422, 21.58545423299074, 3.8155809324234724, 5.749390264973044, 13.540273234248161, 10.482487063854933, 13.86885205283761, 7.636283515021205, 13.310729451477528, 0.8120895735919476, 0.7427385449409485, 0.09212267978000455, 0.019138636016577948, 1.7991248471662402, 12.371259313076735, 32.37850338220596, 37.10454158484936, 16.987765543162823, 21.12361181527376, 37.742816135287285, 43.90532545745373, 39.40285965800285, 15.36499422043562, 1.4563530776649714, 0.021044517634436488, 0.04926355497445911, 0.06381847357260995, 0.08722846076125279, 0.06389560498064384, 0.0393629524478456, 0.025936985184671357, 0.055483713585999794, 0.08148174412781373, 0.013223430523794377, 0.020594828092725947, 0.03503540399833582, 0.05469413896207698, 0.019081345926679205, 0.04258038898115046, 0.0023529402460553683, 0.00659261516375409, 0.05612662498606369, 0.029453965507855173, 0.02157582301151706, 0.03824660278041847, 0.047790451208129525, 0.016241421362792607, 0.03219742386136204, 0.028346430699457414, 0.06846234391559847, 0.05657258894643746, 0.06816868350142613, 0.08162416226696223, 0.026599784287100192, 0.052077367072342895, 0.07646291851415299, 0.029619325287058018, 0.021367509580159094, 0.05062105439719744, 0.01120225626436877, 0.02280076929309871, 0.02479422248143237, 0.0035263687232145458, 0.04905373869405594, 0.032752810075180605, 0.033973750614677556, 0.07115431391866878, 0.03078189962252509, 0.03585910999390762, 0.05981165908451658, 1.8507995805703104, 22.665109299123287, 48.672158271074295, 49.233323559165, 33.36865045130253, 23.930709287524223, 33.69588129222393, 37.67693147063255, 40.291628167033195, 20.564572513103485, 3.7594503443688154, 0.5273376626428217, 1.2777714477851987, 18.730346336960793, 15.704822335392237, 7.3293193615973, 8.222460485994816, 10.676566399633884, 13.635695613920689, 9.543794933706522, 13.300796784460545, 10.15868078917265, 14.754493329674006, 29.904420040547848, 49.387363493442535, 56.16926617920399, 53.20944160223007, 51.21065765619278, 48.68594393134117, 47.74225316941738, 45.152756720781326, 46.58952422440052, 47.988320365548134, 51.40873342752457, 53.017779886722565, 52.211816534399986, 53.52467268705368, 52.29130066931248, 54.40147563815117, 54.6364626288414, 51.71338587999344, 50.45519359409809, 52.54569701850414, 54.07764561474323, 50.48508659005165, 40.66727600991726, 36.39681816101074, 38.495988920331, 45.07466331124306, 50.6319335103035, 51.98665201663971, 54.36749026179314, 54.434127286076546, 54.4454088807106, 48.30600991845131, 51.69204622507095, 54.20968472957611, 50.73640130460262, 43.67381528019905, 40.43885886669159, 39.68437135219574, 44.848773032426834, 46.630242839455605, 56.926060169935226, 41.34274676442146, 46.42201781272888, 55.54052911698818, 48.497439846396446, 51.59461945295334, 50.054273307323456, 46.36760853230953, 46.14309757947922, 40.213378965854645, 38.13743636012077, 40.99161900579929, 38.98849569261074, 38.380562514066696, 42.59360924363136, 43.730390444397926, 36.49618282914162, 45.40881358087063, 49.26184482872486, 55.0195998698473, 51.49346888065338, 46.244187355041504, 54.64700326323509, 55.117885395884514, 54.90720950067043, 56.23696714639664, 53.17180082201958, 54.3423318117857, 51.69532544910908, 53.5587340593338, 50.64143680036068, 48.81036825478077, 49.53908555209637, 52.560269236564636, 51.000407338142395, 49.33080732822418, 52.55782216787338, 50.704760402441025, 52.86270260810852, 52.171888276934624, 52.81858317553997, 50.76152175664902, 41.16659201681614, 31.592758744955063, 21.31939820945263, 10.306072030216455, 10.1385941170156, 10.465961750596762, 11.849174927920103, 11.671664603054523, 10.23511653766036, 6.069855093955994, 3.3385580917820334, 1.330607256386429, 0.0824854988604784, 0.033323247043881565, 1.900763337034732, 13.062534369528294, 36.62169769406319, 44.450113624334335, 26.714130230247974, 27.057137824594975, 45.42785815894604, 51.12348273396492, 46.44946373999119, 19.302099756896496, 1.6916377586312592, 0.033902530412888154, 0.07081589457811788, 0.010048095100501087, 0.06899555475683883, 0.07791439609718509, 0.009607611900719348, 0.013272542146296473, 0.030566691639251076, 0.061426869287970476, 0.05190428710193373, 0.05761418578913435, 0.024729787364776712, 0.013703467411687598, 0.030990734412625898, 0.03679032721265685, 0.02984106045914814, 0.04253364109899849, 0.008354439887625631, 0.012192832309665391, 0.060144315648358315, 0.007279262254087371, 0.02213941923400853, 0.01719160416541854, 0.10896653766394593, 0.12267160069313832, 0.18370142468484119, 0.21753105393145233, 0.13096675596898422, 0.18176404817495495, 0.06844522256869823, 0.16680318221915513, 0.17434260109439492, 0.17113950656494126, 0.15527516487054527, 0.18899684131611139, 0.03873428657243494, 0.11283051469945349, 0.0906801524979528, 0.07972810853971168, 0.11170901823788881, 0.15531182696577162, 0.09835645309067331, 0.17553242709254846, 0.09149860779871233, 0.15511376259382814, 0.18743628286756575, 3.2919514551758766, 29.95726190507412, 55.62743805348873, 57.42249213159084, 39.43638525903225, 31.30279440432787, 40.16835518181324, 42.5779464840889, 44.65502142906189, 23.099883869290352, 4.219615627080202, 1.3033648557029665, 1.6381528973579407, 19.6535561978817, 20.966760031878948, 13.525359984487295, 17.09165196865797, 13.172055892646313, 16.584039106965065, 25.184738896787167, 37.87890583276749, 26.80203091353178, 22.623459734022617, 30.25806326419115, 57.42810823023319, 57.86987252533436, 57.233307883143425, 52.88923658430576, 52.055276334285736, 50.064570754766464, 46.439770460128784, 47.144815027713776, 50.444915145635605, 53.13772805035114, 56.94305665791035, 54.248799830675125, 56.87941387295723, 53.84461931884289, 58.166803792119026, 56.30175746977329, 52.087422609329224, 50.776603147387505, 55.3546316921711, 54.778943583369255, 51.517920568585396, 42.46429458260536, 38.117312639951706, 40.57681426405907, 49.74330559372902, 54.67879615724087, 54.76647645235062, 55.3165577352047, 57.76077277958393, 56.0445948690176, 49.88704428076744, 53.71778592467308, 57.02738933265209, 53.53976167738438, 46.67147442698479, 42.02982969582081, 43.836070373654366, 47.1670476347208, 49.94131296873093, 58.268136754631996, 45.382845774292946, 49.702355191111565, 57.3662893474102, 51.28040671348572, 51.88512526452541, 53.62492270767689, 48.22903744876385, 48.88623118400574, 42.099346965551376, 40.94067133963108, 43.58769290149212, 41.26176930963993, 40.32728925347328, 44.53503146767616, 45.16754172742367, 38.28104205429554, 48.3005154132843, 51.688223630189896, 57.23722547292709, 54.52958956360817, 48.77061478793621, 54.73156772553921, 56.43568128347397, 56.88644729554653, 58.33385422825813, 55.5738989263773, 57.886796817183495, 53.910560980439186, 52.003876492381096, 52.765883803367615, 49.310273230075836, 50.13638310134411, 54.53147046267986, 51.416158229112625, 48.74678246676922, 51.798482313752174, 50.70564195513725, 51.64325684309006, 53.006281703710556, 53.46733756363392, 52.205041497945786, 46.11869528889656, 37.897581830620766, 28.32825131714344, 13.334503825753927, 11.783079374581575, 23.973447494208813, 22.177481465041637, 26.053550876677036, 18.385478742420673, 19.560787975788116, 4.2433092556893826, 2.161794723942876, 0.3777135960990563, 0.23816504515707493, 2.8195985639467835, 16.06280207633972, 41.29378639161587, 50.21004214882851, 29.04102087020874, 33.699966073036194, 51.292976438999176, 57.578029185533524, 54.594748467206955, 23.307354636490345, 2.602578434161842, 0.12543925491627306, 0.20893098728265613, 0.23668607842409983, 0.20987747790059075, 0.1500327672692947, 0.19127300824038684, 0.1317668060073629, 0.10604428665828891, 0.2926109579857439, 0.14926890435162932, 0.13825463131070137, 0.15166368131758645, 0.12052686070092022, 0.08728027751203626, 0.11731509046512656, 0.14565517951268703, 0.2016029172227718, 0.09135996719123796, 0.08671708390465938, 0.1842070498969406, 0.11690623388858512, 0.14447702007601038, 0.1595593013917096], [0.035165335502824746, 0.05351327810785733, 0.03256630094256252, 0.02327312031411566, 0.05261924248770811, 0.010214261037617689, 0.01862940211140085, 0.02126281109667616, 0.08582199443480931, 0.049327112501487136, 0.0368453351984499, 0.10106239031301811, 0.05214771525061224, 0.03987642587162554, 0.04592835444782395, 0.025849111189018004, 0.07756557926768437, 0.01896385281725088, 0.05144417409610469, 0.03019836931343889, 0.06423429149435833, 0.09444204712053761, 0.15287124464521185, 1.2679251073859632, 16.127588599920273, 39.78788919746876, 45.856589153409004, 31.74703996628523, 28.14635317772627, 19.245748780667782, 27.392884008586407, 28.09660814702511, 14.85967168584466, 2.977677443996072, 0.22821542748715729, 0.08110186841804534, 0.058498220969340764, 0.4550346377072856, 12.553025409579277, 15.411774460226297, 6.502240067347884, 13.104911595582962, 12.020432688295841, 10.50234954804182, 11.288095135241747, 9.660332780331373, 29.84365750104189, 50.52691474556923, 51.27012826502323, 49.617821127176285, 47.5850024074316, 41.51672802865505, 38.54807272553444, 36.489141806960106, 35.91291792690754, 36.195527762174606, 39.78582210838795, 40.25230027735233, 44.93851661682129, 45.01011237502098, 47.059327214956284, 49.5587494969368, 51.787352710962296, 52.54125505685806, 51.35592386126518, 53.76857399940491, 51.87802344560623, 47.163996398448944, 36.78940549492836, 37.79272645711899, 46.44497238099575, 53.94668564200401, 52.13164463639259, 51.60546027123928, 51.00897207856178, 50.559668987989426, 51.67573370039463, 52.05791339278221, 56.019489616155624, 48.68543095886707, 45.6572100520134, 39.387827664613724, 37.78888866305351, 36.080378741025925, 42.44287513196468, 44.599312618374825, 56.06927074491978, 41.55343405902386, 43.1186118721962, 52.33708821237087, 46.03633090853691, 46.186624243855476, 43.06231029331684, 42.06400506198406, 39.919909313321114, 39.084250554442406, 37.492455169558525, 38.819001987576485, 41.13880790770054, 39.650735557079315, 36.26345671713352, 35.20005337893963, 34.09014813601971, 39.62228648364544, 48.89645263552666, 51.20212331414223, 48.48379857838154, 52.40223191678524, 51.880162730813026, 51.95033356547356, 48.744035214185715, 48.594836220145226, 45.5902424454689, 49.28127318620682, 52.82535061240196, 50.1170839369297, 49.4092009216547, 49.015534445643425, 51.26040078699589, 50.741455033421516, 52.782519310712814, 51.11752465367317, 49.673157557845116, 51.95029936730862, 50.60641407966614, 51.35966666042805, 52.993658781051636, 47.97616861760616, 45.7296721637249, 33.948107957839966, 24.10720031708479, 11.172854918986559, 12.844870649278164, 8.31290228292346, 9.50764462351799, 7.9822563752532005, 11.19724391028285, 5.023660082370043, 2.295190365985036, 1.1632567550987005, 0.16050439677201211, 0.18407046503853053, 1.008345598820597, 8.051971234381199, 24.422439001500607, 36.944174990057945, 28.746263086795807, 34.178573191165924, 42.00411267578602, 45.78266032040119, 34.33155298233032, 12.571060191839933, 2.4751731706783175, 0.07303153193788603, 0.06178026887937449, 0.027980835766356904, 0.0449448455037782, 0.0214109530497808, 0.013897078897571191, 0.027737012424040586, 0.04927713998768013, 0.07432556289131753, 0.06184701021993533, 0.026874709183175582, 0.0160179792510462, 0.05731597600970417, 0.050999954182771035, 0.01888714814413106, 0.0413530993682798, 0.011885268686455674, 0.028383111348375678, 0.010548061436566059, 0.05634312430629507, 0.04043371198349632, 0.07029188636806794, 0.017147546568594407, 0.03276676245150156, 0.08476926537696272, 0.08943298074882478, 0.03598121184040792, 0.06027212832123041, 0.05200779443839565, 0.03751687865587883, 0.04069170478032902, 0.11639602220384404, 0.015960145537974313, 0.0276760357155581, 0.04728929743578192, 0.04211958948872052, 0.044149010864202864, 0.07929038984002545, 0.008471803121210542, 0.0289874626105302, 0.04486418518354185, 0.04387099121231586, 0.045833697222406045, 0.02982847363455221, 0.07871741472627036, 0.09290715213865042, 1.6566083882935345, 19.76328670978546, 46.732065975666046, 52.98259757459164, 37.16436177492142, 32.25724808871746, 26.588024497032166, 28.20176750421524, 31.156507954001427, 16.129862777888775, 3.2330693397670984, 0.30931690998841077, 0.40519873844459653, 0.1985781459370628, 1.993143861182034, 7.527749463915825, 6.368821626529098, 6.542154075577855, 10.61037015169859, 13.09386558830738, 10.660696551203728, 8.85864419862628, 14.936401918530464, 33.61341051757336, 53.654238134622574, 53.99447947740555, 51.20628409087658, 48.44873026013374, 43.80338452756405, 40.49121245741844, 38.66382971405983, 38.18399906158447, 39.477423056960106, 43.942042887210846, 42.977692633867264, 46.92957177758217, 48.470537289977074, 49.04236480593681, 52.209654450416565, 54.089755564928055, 52.761597633361816, 52.597716227173805, 55.12189798057079, 53.02769735455513, 49.91966173052788, 38.19419011473656, 39.11413595080376, 47.103876024484634, 52.86383494734764, 54.068780690431595, 52.85844303667545, 52.741762697696686, 50.55571720004082, 52.70707055926323, 52.06552818417549, 55.85283815860748, 51.07185870409012, 47.9226902872324, 40.21151326596737, 40.26516258716583, 38.07043835520744, 45.767571330070496, 46.97714902460575, 58.18156220018864, 45.600080117583275, 46.290837451815605, 53.69823217391968, 49.136873334646225, 48.258687257766724, 45.767183750867844, 44.99679408967495, 42.849134132266045, 40.563495978713036, 38.87425482273102, 40.67061983048916, 42.74727299809456, 40.93660555779934, 37.962873727083206, 37.54142314195633, 36.307997927069664, 41.69860526919365, 52.15636610984802, 54.39440801739693, 52.36851252615452, 53.4072931855917, 52.58851312100887, 54.41952466964722, 51.623676493763924, 51.05938397347927, 47.42512598633766, 52.772898226976395, 53.62153708934784, 52.01212204992771, 49.81706343591213, 50.83356589078903, 50.87469108402729, 50.82961030304432, 50.879007652401924, 50.95974192023277, 49.78884615004063, 52.452761605381966, 51.26299984753132, 53.07178258895874, 54.08402167260647, 50.545613542199135, 46.320088282227516, 36.085060089826584, 21.90136168152094, 12.799876313656569, 14.99784842133522, 10.24662896990776, 11.37410731986165, 11.204952746629715, 13.34104422479868, 7.4215480126440525, 3.8752044830471277, 0.9871555608697236, 0.23148345993831754, 0.039148419818957336, 1.0734589048661292, 9.138820264488459, 28.236108161509037, 40.897361263632774, 29.144897796213627, 37.94368475675583, 45.69710411131382, 50.805519595742226, 41.94505624473095, 14.360413625836372, 2.9203226091340184, 0.056639367394382134, 0.10309660225175321, 0.059436570227262564, 0.023178752526291646, 0.03173699544277042, 0.01822579994041007, 0.044249159982427955, 0.07482131753931753, 0.03524406252836343, 0.05213112825003918, 0.042886276278295554, 0.018646848147909623, 0.01942051669175271, 0.03805530308454763, 0.04286573363060597, 0.017301720326940995, 0.022172112694534007, 0.031817629787838086, 0.04534995794529095, 0.021592972188955173, 0.04436723196704406, 0.040645131302881055, 0.03720185181009583, 0.15021054132375866, 0.1550954909180291, 0.24029909080127254, 0.1590343951829709, 0.11506316208397038, 0.16110546217532828, 0.0966812031401787, 0.14459950412856415, 0.27533954882528633, 0.19648511137347668, 0.07106661432771944, 0.20606306148692966, 0.15765453485073522, 0.11229928539250977, 0.19559771055355668, 0.10552826395723969, 0.27043460577260703, 0.09532220457913354, 0.17891043098643422, 0.15016622026450932, 0.132423042668961, 0.13413649838184938, 0.30979877163190395, 2.551303510554135, 25.623075775802135, 56.59731701016426, 59.08456854522228, 44.6060686558485, 38.11903014779091, 29.955441802740097, 37.94826351106167, 39.183911606669426, 19.220126755535603, 4.583839857950807, 0.3481930395355448, 0.4896336217643693, 0.0817048411408905, 1.4932615659199655, 19.945555329322815, 28.24077431112528, 14.620143938809633, 24.906660318374634, 22.21212800592184, 17.955262027680874, 20.34253142774105, 14.778655283153057, 33.365808203816414, 54.02757950127125, 56.32814705371857, 53.720362186431885, 51.44566744565964, 46.08390815556049, 42.40717224776745, 41.04746840894222, 40.43222822248936, 41.59227177500725, 45.546537190675735, 44.684884026646614, 48.34775447845459, 50.37400335073471, 53.286604061722755, 55.162707790732384, 55.30838817358017, 54.26087558269501, 53.22995290160179, 56.10023148357868, 56.50913514196873, 51.34357452392578, 39.97677706182003, 41.6705209761858, 51.17215812206268, 56.265606209635735, 56.20834328234196, 54.40771110355854, 53.87588024139404, 50.59357836842537, 52.757292464375496, 53.15266124904156, 58.55553813278675, 53.4605473279953, 49.3679541349411, 43.16178895533085, 42.25923478603363, 38.92820052802563, 47.048490196466446, 49.67875085771084, 60.64550578594208, 48.91647756099701, 50.054573491215706, 56.14398993551731, 52.16185301542282, 49.13444146513939, 48.73998463153839, 46.05067513883114, 45.52036039531231, 43.62572506070137, 40.51111958920956, 42.19836965203285, 45.59116579592228, 44.640054032206535, 39.97555732727051, 39.76035587489605, 37.175574973225594, 43.32150958478451, 53.66071678698063, 57.722041457891464, 53.725697100162506, 56.69850558042526, 55.32166466116905, 56.14145167171955, 53.64039547741413, 52.7578130364418, 49.38555099070072, 53.30015793442726, 56.501467153429985, 52.471874579787254, 50.60087017714977, 49.032941311597824, 51.29233427345753, 50.7670808583498, 51.57592825591564, 51.912472397089005, 50.126526430249214, 53.292109966278076, 52.36269123852253, 53.96121986210346, 55.92723436653614, 54.1117449849844, 52.14392177760601, 40.43206483125687, 30.436575785279274, 18.925786949694157, 21.425429619848728, 15.149313993752003, 14.601688329130411, 20.971017703413963, 19.73365779966116, 12.317294608801603, 9.150394443422556, 2.799404072575271, 0.2615732734557241, 0.3291120962239802, 1.8995812442153692, 10.885130558162928, 32.972517907619476, 48.330222219228745, 40.8369293063879, 47.530140951275826, 54.260598197579384, 59.43859934806824, 50.79009622335434, 19.098635874688625, 3.7841939041391015, 0.14707366121001542, 0.1891849609091878, 0.08932985190767795, 0.10772844980238006, 0.147361911367625, 0.1565341293462552, 0.11057604075176641, 0.1416023407364264, 0.13840374362189323, 0.17628705769311637, 0.15240470092976466, 0.19338136073201895, 0.1024213146592956, 0.1283009912003763, 0.09406046447111294, 0.1738429575925693, 0.07314809365198016, 0.13063366524875164, 0.1427176847937517, 0.15391730179544538, 0.1337858781334944, 0.1460492450860329, 0.17589612398296595], [0.03964775904023554, 0.019504305164446123, 0.0773784689954482, 0.016666467890900094, 0.0379400030215038, 0.009082060951186577, 0.13626497791847214, 0.050317066998104565, 0.05068604426924139, 0.028785585454897955, 0.0346359281684272, 0.05559214136155788, 0.029944100242573768, 0.022778237689635716, 0.04083803403773345, 0.0352023278537672, 0.05987867130897939, 0.07077420072164387, 0.04378111712867394, 0.05085804070404265, 0.012025815685774432, 0.022084307347540744, 0.038979484743322246, 1.187625559978187, 13.818817287683487, 38.05411443114281, 46.27544827759266, 39.55538347363472, 19.56903163343668, 17.547635100781918, 28.88069987297058, 24.87407896667719, 13.658024165779352, 2.319175866432488, 0.19775278866291046, 0.12008085221168585, 2.129131914116442, 11.064127553254366, 23.47570840269327, 13.80588848143816, 11.076372396200895, 10.047017131000757, 5.644721081480384, 5.48652084544301, 5.135461958125234, 15.922999028116465, 38.64138811826706, 49.01548504829407, 54.70644727349281, 47.542402893304825, 45.79478546977043, 39.797422885894775, 36.84042155742645, 37.241623029112816, 41.18630535900593, 39.069834128022194, 38.197917714715004, 35.65870776772499, 36.72209590673447, 38.21615293622017, 42.33348660171032, 47.01613113284111, 51.08846001327038, 52.11272545158863, 53.82404342293739, 50.365655198693275, 50.173845291137695, 43.049261793494225, 35.26918686926365, 38.42264525592327, 48.272564113140106, 52.63070985674858, 51.08842581510544, 49.793740287423134, 51.75036929547787, 53.503830805420876, 54.46634195744991, 51.88916064798832, 49.6497356146574, 46.655849665403366, 40.36550000309944, 37.604644149541855, 38.38806711137295, 38.04575487971306, 43.70199456810951, 46.05164408683777, 52.23221763968468, 41.97310633957386, 43.712671995162964, 53.70321750640869, 43.20195659995079, 41.62341110408306, 37.694744914770126, 38.50629776716232, 36.1420152336359, 38.02842780947685, 40.04923157393932, 44.66040574014187, 44.25373636186123, 49.196693524718285, 46.76540918648243, 42.67137587070465, 38.638606667518616, 33.911508321762085, 35.77927529811859, 48.9561702311039, 51.32611446082592, 52.993134409189224, 49.934184551239014, 48.15591797232628, 42.20396675169468, 41.6498538851738, 41.23257167637348, 49.028389155864716, 51.36895336210728, 52.10315376520157, 49.44878339767456, 49.30164769291878, 50.09866252541542, 50.87380573153496, 51.96462459862232, 52.45535306632519, 48.49408462643623, 52.08438277244568, 50.52169382572174, 49.40621808171272, 51.103370413184166, 54.58214834332466, 40.211167484521866, 37.86030203104019, 21.55873976647854, 14.11231828853488, 13.500494118779898, 5.481382571160793, 10.518035106360912, 8.327518198639154, 10.517807118594646, 2.9273804929107428, 2.5475113140419126, 1.2784076761454344, 0.13079171301797032, 0.12564907490741462, 0.8495797275099903, 9.347029142081738, 23.755453191697598, 30.91365348547697, 24.918941259384155, 30.288619324564934, 51.207256838679314, 47.609632685780525, 32.476424127817154, 14.174721390008926, 1.740361237898469, 0.058858559641521424, 0.021884033230890054, 0.03134551254333928, 0.014922974678484024, 0.041260405123466626, 0.08023256115848199, 0.028324307277216576, 0.05593775953457225, 0.04244966708938591, 0.03342915151733905, 0.037024326375103556, 0.09659158138674684, 0.027774377704190556, 0.05537598713999614, 0.09593640599632636, 0.06989341985899955, 0.031353824597317725, 0.019867002010869328, 0.02810598412906984, 0.030242627290135715, 0.04580314671329688, 0.043379470516811125, 0.07063684402965009, 0.044247438199818134, 0.05830462061567232, 0.029002147857681848, 0.06082031199184712, 0.06464614634751342, 0.05349846112949308, 0.041816967641352676, 0.06312235389486887, 0.02962405647849664, 0.0326477516500745, 0.04165771017142106, 0.008925898237066576, 0.015152273263083771, 0.018331281389691867, 0.0452875136397779, 0.04480620118556544, 0.024936148947745096, 0.05491312076628674, 0.02707795374590205, 0.05199943785555661, 0.04493876360356808, 0.05930240105953999, 0.028506623275461607, 1.8024926539510489, 17.689853869378567, 44.43453446030617, 51.83535933494568, 45.025721937417984, 25.52235458046198, 21.30586713552475, 35.33502593636513, 30.4308095946908, 16.387621946632862, 2.603565431199968, 0.28073187510017306, 0.06367163223330863, 1.187228956259787, 4.879217008128762, 21.180572658777237, 12.325910646468401, 10.635716691613197, 12.59757136926055, 13.360684420913458, 17.00311291962862, 11.735447980463505, 19.939010180532932, 39.548794627189636, 51.45445257425308, 55.444496870040894, 49.45938102900982, 48.41132126748562, 42.127146273851395, 39.209594428539276, 38.43197375535965, 40.55307313799858, 41.114185228943825, 39.643721133470535, 37.708120197057724, 39.20459009706974, 40.24487167596817, 43.87053072452545, 49.8684024810791, 54.17208194732666, 53.30170825123787, 54.08064365386963, 51.98795534670353, 51.19277961552143, 45.5702593177557, 37.70569212734699, 40.44155292212963, 51.291072741150856, 55.66610857844353, 51.33738085627556, 50.03354161977768, 50.63388280570507, 54.57352660596371, 55.85815027356148, 53.52473348379135, 52.52472214400768, 49.97390381991863, 44.2585165053606, 40.32819740474224, 40.03946229815483, 39.515272825956345, 45.724633634090424, 48.32130789756775, 54.69927705824375, 45.41729852557182, 45.509595572948456, 55.91186799108982, 45.594395622611046, 44.376408979296684, 38.93814839422703, 40.351543352007866, 38.43027524650097, 40.371290892362595, 42.463644817471504, 46.177782118320465, 47.62194782495499, 49.95658814907074, 49.26543563604355, 45.11582650244236, 39.00651052594185, 36.15208089351654, 40.38448378443718, 50.98144255578518, 53.13812702894211, 55.03615938127041, 52.02959731221199, 50.46800270676613, 45.56835561990738, 43.980151042342186, 43.42768348753452, 51.68053284287453, 53.38184595108032, 51.514086574316025, 49.94663268327713, 48.59212316572666, 50.67197576165199, 53.098662346601486, 52.65040799975395, 51.786896735429764, 48.8148558139801, 51.64291486144066, 49.71643723547459, 50.21212063729763, 54.462785348296165, 55.331992506980896, 44.24880042672157, 41.21010348200798, 24.579988047480583, 17.223540991544724, 16.225731633603573, 15.24101922288537, 10.892992336302996, 14.068014565855265, 8.50888341665268, 6.916067311540246, 2.948486697860062, 0.48592724720947444, 0.4120865516597405, 0.04431493282027077, 1.1982791195623577, 9.463955517858267, 27.05477435141802, 37.88600765168667, 30.56820072233677, 38.572946190834045, 56.954167261719704, 54.62028689682484, 40.85555210709572, 17.288378812372684, 2.657062285579741, 0.021320147570804693, 0.0028912009383930126, 0.06627176888287067, 0.0243187117666821, 0.03626814839662984, 0.029331104815355502, 0.01688597290922189, 0.010077529605041491, 0.015331283921113936, 0.04249981400789693, 0.010691649385989876, 0.014160684186208528, 0.07905144055257551, 0.06437205636757426, 0.005179022364245611, 0.03597331167839002, 0.04453838606423233, 0.041188739633071236, 0.05193535711441655, 0.026144196526729502, 0.006480100009866874, 0.041648433325462975, 0.030047551917959936, 0.14557173242792487, 0.13726019795285538, 0.14929401862900704, 0.2735697937896475, 0.1832196075702086, 0.09637626208132133, 0.22136973857413977, 0.17722410819260404, 0.12827209196984768, 0.12932699552038684, 0.09584233135683462, 0.12869844096712768, 0.08364149034605362, 0.1033215546340216, 0.11952575543546118, 0.11255425022682175, 0.13881952443625778, 0.144763266434893, 0.17052012495696545, 0.15759694419102743, 0.18458097358234227, 0.2031730642192997, 0.1896508812205866, 2.7554606180638075, 22.833172380924225, 50.817139372229576, 58.7131042778492, 51.00990682840347, 30.749500393867493, 29.039823934435844, 40.287896767258644, 35.198343470692635, 18.496854566037655, 3.171201297082007, 0.5006259272340685, 0.28983882861211896, 4.107640385627747, 16.97194319218397, 31.272297240793705, 20.882687643170357, 22.585780955851078, 24.165223203599453, 17.626543566584587, 15.922549702227116, 13.343353550881147, 21.24036245048046, 42.88188077509403, 54.69522267580032, 59.167552292346954, 51.24658852815628, 50.79934872686863, 43.973075821995735, 42.16466926038265, 41.898284554481506, 45.82925722002983, 44.24727290868759, 43.17858025431633, 39.413442090153694, 40.708990171551704, 41.480010598897934, 45.990851148962975, 52.50808283686638, 55.8369056135416, 54.951013550162315, 56.305747255682945, 54.33353528380394, 54.31956343352795, 48.046461045742035, 39.04570922255516, 42.594467997550964, 52.9493797570467, 56.69952392578125, 52.29795031249523, 50.15602804720402, 52.561287581920624, 55.82761511206627, 56.07183940708637, 55.08369863033295, 52.83587224781513, 51.41852930188179, 44.4526556879282, 42.40371823310852, 42.63349190354347, 42.42810532450676, 48.171006962656975, 51.934176832437515, 54.81259077787399, 47.73937672376633, 48.74134875833988, 57.44410157203674, 48.5500518232584, 46.691727340221405, 41.371347829699516, 41.893276423215866, 40.07513478398323, 42.876352071762085, 44.98765558004379, 48.78597356379032, 49.18111816048622, 52.95430429279804, 51.606125235557556, 47.83594474196434, 41.754245683550835, 37.36486941576004, 40.66834755241871, 51.334762796759605, 56.09319046139717, 55.38328595459461, 55.80350920557976, 52.029103338718414, 46.636615097522736, 47.50544987618923, 44.693691954016685, 54.15477767586708, 56.31034500896931, 52.742841839790344, 49.38156120479107, 48.722098991274834, 52.05504074692726, 54.18039970099926, 54.14060823619366, 53.75293783843517, 48.647949770092964, 51.822219640016556, 50.48524238169193, 49.48065988719463, 54.59228239953518, 57.982213497161865, 45.15086442232132, 41.690078526735306, 25.288057252764702, 18.75961236655712, 19.218705631792545, 15.32326865941286, 21.715386360883713, 19.3517953902483, 21.124744154512882, 9.553186129778624, 6.538310581818223, 2.250264664180577, 0.7128814689349383, 0.18998976069269702, 1.361808213405311, 11.889057587832212, 32.54433788359165, 42.468010783195496, 35.48454411327839, 42.78604231774807, 62.05812178552151, 60.62899947166443, 50.09942628443241, 22.284525521099567, 2.863343716599047, 0.19688763743033633, 0.08035783568629995, 0.16917803994147107, 0.18588428880320862, 0.2030644434853457, 0.20362170733278617, 0.12732371629681438, 0.12721089500701055, 0.13073381065623835, 0.1817903944174759, 0.10942707740468904, 0.22429354808991775, 0.1404708475456573, 0.2602429885882884, 0.27494953537825495, 0.1406838884577155, 0.17298297170782462, 0.08031179284444079, 0.10757332609500736, 0.20126495801378042, 0.12387065900838934, 0.13193212682381272, 0.12697851372649893], [0.14858963142614812, 0.05569500302954111, 0.0813701844890602, 0.02405650171567686, 0.051496636515366845, 0.057151048531522974, 0.07080431707436219, 0.0702273343631532, 0.025780273281270638, 0.065569185098866, 0.061149658577051014, 0.01353367979390896, 0.04042098044010345, 0.07521523468312807, 0.10432709052111022, 0.008587621759943431, 0.0175714631768642, 0.016587857753620483, 0.027657292775984388, 0.08020377325010486, 0.05104676885821391, 0.0387108569702832, 0.010410957074782345, 1.0000245203264058, 14.64286481961608, 35.826571360230446, 47.56577543914318, 44.01785261929035, 28.28969668596983, 16.64369210600853, 25.96499092876911, 19.989169389009476, 9.73671343177557, 2.1330497413873672, 0.1136445690644905, 4.851057669147849, 16.264286264777184, 27.07734704017639, 9.137661326676607, 2.4844748340547085, 6.824261387810111, 4.57594103179872, 13.467766474932432, 16.663276255130768, 10.703213419765234, 19.601212106645107, 37.83430002629757, 51.7438830435276, 48.766571804881096, 47.41160251200199, 42.92543023824692, 38.99062357842922, 39.35597017407417, 45.53350009024143, 48.612216487526894, 48.91817606985569, 46.44700527191162, 39.019334837794304, 35.90200871229172, 35.41308134794235, 38.337419629096985, 43.70015166699886, 49.94197033345699, 52.76370272040367, 53.36955361068249, 50.085967406630516, 48.485185503959656, 38.80722261965275, 35.28684452176094, 42.98037528991699, 54.822101667523384, 52.583052814006805, 51.273019909858704, 51.41324758529663, 53.54536637663841, 49.12369944155216, 50.07573075592518, 47.59275019168854, 47.543596029281616, 41.31939321756363, 38.02976153790951, 36.33472189307213, 37.235585153102875, 37.39505499601364, 45.3611945360899, 46.09213471412659, 54.532758593559265, 40.67027784883976, 43.18917028605938, 54.81864385306835, 44.91754934191704, 39.98587377369404, 36.12056918442249, 38.43145698308945, 36.98250353336334, 39.99269440770149, 42.210574597120285, 48.796593993902206, 51.54658243060112, 52.18245171010494, 51.30990833044052, 51.795970648527145, 46.287964805960655, 42.902867048978806, 34.41905848681927, 33.84415693581104, 39.0866444259882, 42.27862514555454, 40.741242840886116, 38.471278846263885, 36.7716908454895, 39.14457231760025, 43.5321930795908, 48.98304998874664, 52.34383665025234, 50.81446811556816, 45.83727478981018, 49.730781465768814, 51.325552091002464, 55.088379979133606, 53.7882911413908, 53.85288767516613, 52.62949012219906, 49.816235080361366, 51.01168133318424, 51.70970007777214, 52.96178229153156, 52.37525716423988, 47.32191972434521, 32.571145445108414, 22.816202491521835, 13.047896604984999, 18.39947909116745, 16.25969611108303, 9.009206369519234, 10.245641972869635, 8.875372800976038, 9.188209064304829, 1.8026990303769708, 0.515595639590174, 0.39233072893694043, 0.10965031542582437, 0.6943061063066125, 6.263699317350984, 22.723890244960785, 31.333173774182796, 26.0235932841897, 34.66226063668728, 51.16344518959522, 43.61327312886715, 39.29541662335396, 11.151613108813763, 1.3183491141535342, 0.04958158380759414, 0.03934780150302686, 0.030685008532600477, 0.052563514618668705, 0.04998482974770013, 0.061997591983526945, 0.03903238502971362, 0.004844156519538956, 0.0973951343621593, 0.03504532651277259, 0.036127541097812355, 0.0425673680001637, 0.060159659551572986, 0.04230292222928256, 0.005538755722227506, 0.05097656168800313, 0.0519246108160587, 0.0151543030369794, 0.034844082038034685, 0.04779315262567252, 0.050915609099320136, 0.032848758637555875, 0.024543881227145903, 0.06923153545358218, 0.01576682163431542, 0.06092092124163173, 0.016190979440580122, 0.07180763393989764, 0.04416442527144682, 0.033226196392206475, 0.013983524258947, 0.007759362224533106, 0.0063420470905839466, 0.06257375833229162, 0.04434503804077394, 0.03509166250296403, 0.08149460554705001, 0.025068831964745186, 0.04225952514389064, 0.03035946730960859, 0.05024151265388355, 0.051605060580186546, 0.05946907629549969, 0.03406443363928702, 0.04785540768352803, 0.043931661784881726, 1.4971506572328508, 17.399237863719463, 41.03584103286266, 52.857021912932396, 47.30890542268753, 31.94654256105423, 22.26517505943775, 32.43730902671814, 26.411026194691658, 13.421743344515562, 2.433501756750047, 0.26966686884406954, 4.209667760878801, 16.118089109659195, 30.566137433052063, 18.975100703537464, 7.063413904979825, 9.618301335722208, 10.97699822857976, 13.785285037010908, 11.404257752001286, 6.471067490056157, 20.77360689640045, 37.32929952442646, 53.71150106191635, 52.71460935473442, 50.359385535120964, 44.06150087714195, 41.91255658864975, 41.30460821092129, 47.32989549636841, 50.60794919729233, 51.482863649725914, 47.48766303062439, 40.53983084857464, 36.698027998209, 38.14888134598732, 40.103557258844376, 47.71549880504608, 52.33297683298588, 54.34663698077202, 54.13320243358612, 52.61028595268726, 50.181870460510254, 42.301522716879845, 36.84666462242603, 45.07164627313614, 55.50932519137859, 54.43063527345657, 51.10265605151653, 51.90510079264641, 54.02360871434212, 52.481830045580864, 50.97807973623276, 49.946233704686165, 49.77131389081478, 43.77194121479988, 40.13377703726292, 37.84489385783672, 40.02893306314945, 38.181042820215225, 46.49761475622654, 47.27990537881851, 55.72246715426445, 44.022108390927315, 45.076506212353706, 56.09822519123554, 47.36403286457062, 43.02935466170311, 38.66900123655796, 39.74228024482727, 38.584934547543526, 42.128871381282806, 44.15191322565079, 50.40269561111927, 53.22130836546421, 55.84532976150513, 53.382301926612854, 54.801487773656845, 46.572900116443634, 43.94892431795597, 34.70361761748791, 36.70646354556084, 41.77416041493416, 45.43723605573177, 43.76147277653217, 42.38174021244049, 38.853663727641106, 39.84082795679569, 45.69303072988987, 51.15379370748997, 53.57161536812782, 51.53679795563221, 48.18186677992344, 50.75866810977459, 51.84100583195686, 56.586472392082214, 54.62905302643776, 56.50821939110756, 50.37068992853165, 50.767840817570686, 49.99400094151497, 54.039529860019684, 51.01151794195175, 55.7547540217638, 48.16123388707638, 39.88084740936756, 25.63375700265169, 15.577760953456163, 15.55233746767044, 17.936669625341892, 15.040353890508413, 12.886080387979746, 9.838523268699646, 6.222969777882099, 4.270700560882688, 1.7669358244165778, 0.3124433703487739, 0.12668535055126995, 1.1390482541173697, 8.015138860791922, 26.709568575024605, 36.52790732681751, 28.20947539061308, 35.835953056812286, 55.63636377453804, 49.850714430212975, 44.74106781184673, 14.55276120454073, 1.6910147108137608, 0.03277364587120246, 0.05049729013990145, 0.030895416675775778, 0.030523287132382393, 0.01947740416653687, 0.04893493569397833, 0.0024948191685325583, 0.06597893967409618, 0.049785889641498215, 0.04021122724225279, 0.08242234951467253, 0.018543776823207736, 0.010930951193586225, 0.03822462407697458, 0.01872258617368061, 0.0035676089419212076, 0.04185716235951986, 0.03847492080240045, 0.05892077388125472, 0.09915669608744793, 0.016741270810598508, 0.030210859658836853, 0.08306173942401074, 0.3204408724559471, 0.11062136371037923, 0.17335146287223324, 0.1618439139565453, 0.30743880139198154, 0.11504946203785948, 0.17817465093685314, 0.13734995329286903, 0.1264828332932666, 0.23767607373883948, 0.16593846143223345, 0.13741174450842664, 0.118906321877148, 0.18979614920681342, 0.19509120960719883, 0.13698606344405562, 0.13282243686262518, 0.2714251057477668, 0.19123321428196505, 0.21709326101699844, 0.19277407613117248, 0.17059192032320425, 0.11490981953102164, 2.0107609033584595, 20.703479759395123, 49.502535313367844, 61.70191749930382, 54.79332201182842, 39.28570434451103, 26.717817932367325, 36.72893173992634, 29.566682763397694, 14.947540070861578, 3.386686546728015, 0.5132367974147201, 7.5789327174425125, 23.03821697831154, 32.20062352716923, 10.84758572280407, 4.835207294672728, 10.978355705738068, 11.065179146826267, 25.102587305009365, 24.52333878725767, 17.984497658908367, 21.907285563647747, 41.57682180404663, 55.899290665984154, 54.93891499936581, 52.70984821021557, 48.83466795086861, 42.69597575068474, 44.42962892353535, 51.17489017546177, 54.83486518263817, 53.29717889428139, 51.40145681798458, 43.76614272594452, 39.0791018307209, 41.01230129599571, 42.260937094688416, 49.97585691511631, 54.32270206511021, 56.58801890909672, 57.36830323934555, 54.279156401753426, 53.31591188907623, 43.841583877801895, 40.30841946601868, 47.703597843647, 59.287150874733925, 54.38264384865761, 51.3706024736166, 54.5079193264246, 56.852199733257294, 52.43304826319218, 54.579948261380196, 51.776865273714066, 51.0869362950325, 44.53227661550045, 41.35923407971859, 40.61013467609882, 42.64205664396286, 41.13566167652607, 48.99214670062065, 49.5161347836256, 56.97939030826092, 47.670285031199455, 47.93570838868618, 58.853571340441704, 50.80613136291504, 46.53463616967201, 40.37716157734394, 41.93153277039528, 40.50039656460285, 42.64575004577637, 47.96011447906494, 52.78382644057274, 54.874136075377464, 57.113146930933, 57.00171411037445, 57.68704153597355, 49.6001672744751, 47.07651749253273, 37.63199508190155, 37.52336651086807, 42.724827602505684, 47.67337806522846, 44.959316700696945, 43.03521014750004, 41.085150986909866, 42.30390898883343, 48.48319061100483, 53.825297355651855, 56.18587888777256, 51.11440882086754, 46.28710225224495, 50.84404952824116, 53.32266412675381, 58.45526151359081, 57.715824991464615, 58.81863221526146, 52.652323096990585, 50.192992463707924, 51.29844814538956, 54.067006185650826, 53.659538850188255, 55.628118216991425, 51.33693628013134, 38.569507375359535, 27.49883372336626, 18.541960045695305, 25.39455033838749, 24.02264155447483, 16.092168800532818, 16.841243505477905, 20.438823960721493, 17.913190685212612, 6.722338031977415, 2.6871345844119787, 1.7915283422917128, 0.18190162751125172, 1.357857494149357, 8.797750566154718, 30.386515371501446, 46.39969401061535, 39.145518466830254, 45.28489463031292, 63.32246974110603, 56.756125688552856, 54.25940126180649, 19.15971949696541, 2.920397180132568, 0.15540302207227796, 0.15757626795675606, 0.1203593060199637, 0.17349546920740977, 0.21453485533129424, 0.1973258311045356, 0.12434410469722934, 0.09242468193406239, 0.27540197828784585, 0.11333811402437277, 0.18491538532543927, 0.0833373136993032, 0.12311370548559353, 0.10476021532667801, 0.0903194687271025, 0.09381479874718934, 0.21155271300813183, 0.12135606972151436, 0.14048542332602665, 0.18541292112786323, 0.15837470011319965, 0.18476251774700359, 0.15607300330884755], [0.0064761939938762225, 0.01556154358695494, 0.0394187693746062, 0.0329910172149539, 0.009224795430782251, 0.03007525814609835, 0.06005434879625682, 0.0546213862253353, 0.020601835822162684, 0.051140101350029, 0.057694207862368785, 0.02440698466671165, 0.02394504041149048, 0.043915939386351965, 0.015535961756540928, 0.027070476608059835, 0.06319691747194156, 0.06796319023123942, 0.08722972241230309, 0.015466253680642694, 0.055974280621740036, 0.044193743815412745, 0.02984165974339703, 0.4324258508859202, 9.369924813508987, 38.24788123369217, 45.54898425936699, 40.55288314819336, 26.235789097845554, 20.905476920306683, 25.805072709918022, 23.25203910470009, 11.144368797540665, 2.4520331248641014, 0.38308146118652076, 2.94489280320704, 5.630571590736508, 0.5815105244982988, 5.051951939240098, 3.24744610581547, 9.201100822538137, 12.89414830505848, 10.253065824508667, 18.87103758752346, 10.042187590152025, 22.933281809091568, 43.05775813758373, 53.85494716465473, 50.354438200592995, 45.71811318397522, 43.61813306808472, 39.57899160683155, 43.607121258974075, 49.709559604525566, 53.48340690135956, 50.85971228778362, 48.89182448387146, 43.98886397480965, 37.625911608338356, 36.502843871712685, 35.95264479517937, 39.66300129890442, 44.25728917121887, 47.911359295248985, 48.5579439997673, 47.94046573340893, 40.83471782505512, 35.578919649124146, 35.05020081996918, 48.31093065440655, 54.46699172258377, 52.30825535953045, 50.614013671875, 52.697042897343636, 47.463682517409325, 44.564464688301086, 45.87517015635967, 43.024977296590805, 40.30862845480442, 37.17284291982651, 35.76528824865818, 35.92595122754574, 38.95929045975208, 39.82833422720432, 45.66181540489197, 45.27151554822922, 56.87651462852955, 40.283276215195656, 39.768198654055595, 54.51616108417511, 44.13346141576767, 40.18082991242409, 35.00058688223362, 37.19618506729603, 35.68901114165783, 40.46023651957512, 44.08137001097202, 46.50950811803341, 48.62942576408386, 53.771769627928734, 51.39466658234596, 53.00713285803795, 52.18729645013809, 50.31887970864773, 45.31243555247784, 38.29926587641239, 32.8454565256834, 34.06215883791447, 35.30934691429138, 36.381634175777435, 35.18388144671917, 41.474067717790604, 47.1988595277071, 52.62325465679169, 50.82325704395771, 50.1831129938364, 51.35469652712345, 52.319844737648964, 51.336563900113106, 48.41235101222992, 48.01238067448139, 50.40847510099411, 52.89509207010269, 52.31514818966389, 52.47752487659454, 52.49570690095425, 50.54085999727249, 55.839299485087395, 47.001342326402664, 43.604016825556755, 29.145558960735798, 21.82307828217745, 16.42793968319893, 23.094389364123344, 14.204937368631363, 17.317403554916382, 4.887026064097881, 4.42893167026341, 2.5645593367516994, 0.892633970361203, 0.2575747895753011, 0.07621188706252724, 0.666083061369136, 5.79709243029356, 22.869606725871563, 29.686589129269123, 29.013954922556877, 44.19119171798229, 56.979215517640114, 45.56044824421406, 40.95782361924648, 12.334103006869555, 2.2455588541924953, 0.03667684912215918, 0.06496452770079486, 0.055397416654159315, 0.07353369132033549, 0.02126173312717583, 0.012820679039577954, 0.10577029315754771, 0.0439114827895537, 0.02764903267234331, 0.02815116607962409, 0.01931798342411639, 0.07941587959066965, 0.02488327278115321, 0.011610596120590344, 0.03400371853786055, 0.04234709114825819, 0.02321997882972937, 0.03203534251952078, 0.06609846255742013, 0.021439260417537298, 0.052456214907579124, 0.050606771765160374, 0.0517258673789911, 0.05939742564805783, 0.0767983247351367, 0.08628336538095027, 0.020149483825662173, 0.06758380433893763, 0.009681681021902477, 0.034815646649803966, 0.0739550827711355, 0.029376147613220382, 0.055401869540219195, 0.030397055234061554, 0.09201310909702443, 0.03502125866361894, 0.01426973629349959, 0.039065128585207276, 0.013816199643770233, 0.03276862153143156, 0.02020588333834894, 0.12290597835090011, 0.07732823301921599, 0.06964652216993272, 0.06876570419990458, 0.050307485871599056, 0.6156071042641997, 12.686317507177591, 44.48143534362316, 51.299698278307915, 45.692719146609306, 31.495544761419296, 21.34586948901415, 30.333684906363487, 24.85384315252304, 12.031093016266823, 2.8126074140891433, 0.3263602720107883, 4.943896662443876, 10.418173614889383, 1.7028064280748367, 4.794658720493317, 8.375350032001734, 9.799844194203615, 14.98257989063859, 15.975180678069592, 11.594837475568056, 12.504353821277618, 25.252960436046124, 42.3163191229105, 55.379919335246086, 52.783910036087036, 47.73084618151188, 44.166128262877464, 41.5280020236969, 44.5378091186285, 52.52335421741009, 53.700553849339485, 52.28027746081352, 51.64367102086544, 45.10516807436943, 39.64040011167526, 38.258604258298874, 38.28590579330921, 42.61515028774738, 48.48648503422737, 48.39041478931904, 51.10742099583149, 50.370207354426384, 44.70381461083889, 37.01546296477318, 37.282284647226334, 50.72182908654213, 55.84598332643509, 52.50119000673294, 49.769379794597626, 54.643902629613876, 51.117209270596504, 47.059217020869255, 48.33250969648361, 44.03037294745445, 42.24638007581234, 39.4084719568491, 38.057397454977036, 37.286555618047714, 40.8696873486042, 41.45323723554611, 48.60797971487045, 48.30863177776337, 56.67486324906349, 42.14859612286091, 43.88667605817318, 56.862147599458694, 45.80877251923084, 42.899762615561485, 36.35410085320473, 38.21362227201462, 38.64578068256378, 41.33556514978409, 45.088167786598206, 49.58875268697739, 51.02787606418133, 53.85643668472767, 51.543979570269585, 54.123987928032875, 53.57456021010876, 52.231229692697525, 45.328520089387894, 38.66622358560562, 34.36818301677704, 36.354587227106094, 36.484707444906235, 38.65104719996452, 38.2831509411335, 43.56141731142998, 50.17446085810661, 53.55714574456215, 52.09416724741459, 49.60347689688206, 50.52913002669811, 52.53671430051327, 53.96207481622696, 51.53877764940262, 50.8139019459486, 52.836396619677544, 54.60484832525253, 52.36158549785614, 52.092328146100044, 53.237237110733986, 51.98221005499363, 55.0274920463562, 49.3718983232975, 43.28841716051102, 26.98577955365181, 19.632826410233974, 13.524847961962223, 17.48954761773348, 14.527295920997858, 13.124355152249336, 11.537362709641457, 7.331234933808446, 6.422451473772526, 1.5649510128423572, 0.25712911505252123, 0.0319238162774127, 0.7699526846408844, 7.517103860154748, 24.917060360312462, 39.36221323907375, 35.36757118999958, 50.209517776966095, 59.64253440499306, 51.269334107637405, 48.348548635840416, 16.586902253329754, 2.7836617548018694, 0.06705234496621415, 0.024748688010731712, 0.07996412634383887, 0.012745629355777055, 0.035697596395039, 0.011605998515733518, 0.0520561639132211, 0.06268355165957473, 0.04349802118667867, 0.04095592419616878, 0.031011258506623562, 0.06376454170094803, 0.08470551489153877, 0.026358970353612676, 0.03788315450947266, 0.0824171990097966, 0.05592686480667908, 0.05000624441890977, 0.026716355278040282, 0.06568779514054768, 0.025088140791922342, 0.05236952463747002, 0.053235317827784456, 0.17236048792256042, 0.1701305716414936, 0.165321039094124, 0.17367627122439444, 0.2674920199206099, 0.15193640574580058, 0.07963336596731097, 0.22226470930036157, 0.10107714420882985, 0.15661952085793018, 0.1535265165148303, 0.13909199653426185, 0.15401277167256922, 0.1312872747075744, 0.0908539115334861, 0.12531184300314635, 0.12895238905912265, 0.17311219446128234, 0.22234158095670864, 0.1497638871660456, 0.1745047009899281, 0.12873496947577223, 0.14824686310021207, 1.0255508380942047, 16.274826899170876, 51.70798256993294, 57.659614607691765, 52.33494132757187, 38.96569311618805, 29.98110182583332, 36.75217129290104, 31.638983264565468, 14.93733761832118, 3.5862836614251137, 0.5960227770265192, 4.1186118219047785, 7.920464091002941, 0.8479343564249575, 11.14227605983615, 9.351030327379704, 13.830865491181612, 20.193474926054478, 19.16774846613407, 27.8214231133461, 17.955621108412743, 27.98178780823946, 48.97818624973297, 58.19043092429638, 54.46575678884983, 49.37523074448109, 47.643367275595665, 44.20166015625, 47.38057337701321, 54.42106358706951, 56.039632335305214, 54.12827789783478, 53.83230417966843, 47.8235650062561, 42.98305794596672, 40.14365650713444, 40.70115879178047, 43.84962424635887, 49.76974457502365, 51.213458105921745, 51.610248014330864, 53.15176449716091, 45.22566340863705, 38.7667927891016, 39.02059257030487, 52.434761971235275, 58.26659023761749, 53.908657282590866, 50.9765750169754, 56.859635934233665, 52.02637128531933, 48.38683158159256, 51.97280555963516, 46.30173906683922, 44.10061217844486, 42.74463593959808, 38.609219044446945, 39.74520988762379, 42.81785801053047, 44.284784495830536, 50.16799360513687, 50.12676581740379, 59.64984521269798, 45.98688416182995, 47.31910027563572, 57.93296433985233, 47.400415912270546, 44.47823591530323, 38.737032786011696, 40.71899123489857, 40.381443947553635, 45.00514604151249, 48.59063744544983, 51.04921951889992, 52.89471209049225, 57.21138305962086, 53.53402778506279, 55.98587282001972, 56.647998690605164, 54.39811661839485, 49.297581911087036, 41.93561755120754, 35.86891248822212, 38.279647529125214, 39.08179208636284, 40.985968708992004, 40.07600873708725, 45.44479764997959, 52.3925918340683, 56.40293464064598, 51.23406819999218, 49.957013726234436, 51.304543018341064, 54.6698210388422, 54.43025529384613, 53.311283737421036, 52.58111111819744, 54.42549794912338, 57.047851234674454, 53.85894455015659, 52.23653420805931, 53.805120438337326, 51.738122552633286, 58.742609694600105, 50.43830730021, 46.799740344285965, 33.55491645634174, 29.18841116130352, 23.964751660823822, 33.69380660355091, 22.783832028508186, 25.821394734084606, 11.058995928615332, 10.066137704998255, 9.449710082262754, 1.7170024663209915, 1.0000672680325806, 0.23829331796150655, 1.0941959358751774, 8.327659741044044, 30.343089401721954, 42.42221184074879, 42.69032925367355, 55.07433973252773, 66.07797548174858, 58.41224402189255, 54.89459037780762, 21.72176241874695, 4.120847526937723, 0.1820713863708079, 0.139301861054264, 0.13875647156964988, 0.17043189844116569, 0.131674007861875, 0.11337863528751768, 0.25967301917262375, 0.1484494100441225, 0.14390803029527888, 0.1085384891484864, 0.11004027692251839, 0.13792400452075526, 0.24860148201696575, 0.23051130585372448, 0.13219070591730997, 0.1484685722971335, 0.08802143071079627, 0.09837993464316241, 0.14211414061719552, 0.16076965519459918, 0.11726653174264356, 0.17379641009029, 0.1712822067202069], [0.016221281330217607, 0.029253988250275142, 0.04153676978603471, 0.013371508466661908, 0.02945334210380679, 0.07748958334559575, 0.03435365972109139, 0.043030230663134716, 0.015866274989093654, 0.041138106607832015, 0.04572974459733814, 0.028418524780136067, 0.06235169290448539, 0.07953703519888222, 0.03404090384719893, 0.019422438854235224, 0.040724715508986264, 0.051593468233477324, 0.03230258618714288, 0.046267493671621196, 0.0029677212341994164, 0.044328332296572626, 0.026967930352839176, 0.2651690680067986, 9.681203160434961, 31.46730277687311, 48.776588067412376, 38.93182933330536, 25.368514135479927, 16.46574765443802, 21.837188825011253, 27.079632617533207, 13.50737364962697, 1.6297286306507885, 0.2546117204474285, 0.16269569168798625, 0.4772677196888253, 2.5243817176669836, 4.4623499270528555, 9.903524480760098, 7.018296075984836, 18.886012583971024, 12.7900424413383, 4.126174841076136, 4.829069199040532, 22.374688982963562, 35.52709423005581, 51.29096254706383, 46.84675142168999, 46.94192111492157, 40.08512444794178, 40.7034120708704, 46.46454893052578, 49.21639546751976, 50.55103965103626, 53.738198429346085, 48.08766983449459, 48.77846896648407, 42.73922123014927, 38.6789833009243, 35.021215975284576, 36.53030879795551, 37.98580929636955, 40.34588165581226, 40.47673903405666, 38.21695849299431, 36.2759580463171, 35.82631677389145, 39.35733050107956, 49.16666753590107, 52.575301229953766, 50.80114223062992, 51.82734176516533, 48.117395639419556, 46.33671998977661, 44.0225225687027, 40.42614474892616, 37.11449325084686, 36.93771153688431, 35.60128144919872, 38.12835484743118, 36.86805747449398, 43.351349383592606, 46.007623448967934, 47.67390623688698, 46.97270326316357, 55.101268887519836, 39.78627808392048, 40.75702339410782, 54.05499503016472, 45.18385425209999, 42.34344206750393, 36.46268002688885, 39.91705946624279, 38.41832868754864, 39.45617079734802, 42.48743154108524, 46.98174677789211, 48.04469794034958, 52.51740373671055, 53.25120136141777, 51.92318022251129, 49.023449420928955, 51.45905792713165, 51.27836622297764, 49.6876385807991, 43.26766647398472, 43.73595334589481, 43.37521210312843, 39.015280455350876, 36.360066533088684, 46.76456943154335, 50.996197164058685, 53.58674615621567, 47.92943112552166, 52.40292727947235, 49.93294961750507, 53.69383201003075, 47.82918870449066, 48.573595359921455, 45.269953832030296, 49.84234347939491, 49.919984713196754, 57.27138563990593, 49.73889023065567, 52.60219618678093, 49.229451566934586, 54.937729462981224, 48.618847131729126, 47.86906756460667, 25.946343429386616, 23.368212170898914, 13.455365840345621, 13.458898700773716, 16.319903880357742, 9.628328997641802, 12.260196972638369, 7.066874569281936, 4.900054140016437, 2.533541126176715, 0.13145140808774158, 0.03823441300482955, 0.5778747133444995, 5.455650826916099, 18.49819779396057, 31.519099697470665, 34.22319419682026, 45.307701006531715, 49.48167063295841, 44.8830471932888, 30.292039141058922, 12.979251388460398, 2.4588672956451774, 0.035247513515059836, 0.015249578100338113, 0.037838978169020265, 0.06684740830678493, 0.007302758649530006, 0.037355138701968826, 0.08262456249212846, 0.05155769671546295, 0.05620646152237896, 0.07360642179264687, 0.003606847217270115, 0.017558889339852612, 0.05015121554606594, 0.041736704370123334, 0.05468739283969626, 0.05271927286230493, 0.02179315168177709, 0.06113687137258239, 0.04101314007129986, 0.022860022363602184, 0.021023809858888853, 0.03015970898559317, 0.02613878812553594, 0.029757396296190564, 0.06465887418016791, 0.06008318123349454, 0.02613248729176121, 0.008915642683859915, 0.04169291765720118, 0.024134030172717758, 0.03899778239428997, 0.03644022646767553, 0.0906705268425867, 0.04757587033964228, 0.03829198511084542, 0.07398003377602436, 0.08772788161877543, 0.029337650557863526, 0.04048069364216644, 0.01490074642788386, 0.09207496710587293, 0.08893266931409016, 0.02196337067289278, 0.026409219317429233, 0.059527746780076995, 0.009549749429424992, 0.4749021981842816, 12.013156078755856, 38.173572421073914, 53.003553450107574, 45.27397021651268, 28.928113728761673, 19.693549051880836, 23.280923254787922, 29.4951706007123, 15.456675700843334, 2.05579727422446, 0.26897637464571744, 0.07966965698869899, 0.4290371452225372, 2.6283158781006932, 6.854329649358988, 11.061247307807207, 9.549510776996613, 13.250858914107084, 16.889626309275627, 8.462548702955246, 10.806685667484999, 26.929255686700344, 40.558024272322655, 54.39089700579643, 49.94287468492985, 49.328177869319916, 44.20742064714432, 42.97182574868202, 47.6176730543375, 51.584230810403824, 52.24818058311939, 54.840504080057144, 51.22595563530922, 50.518585592508316, 44.27695691585541, 41.6439414024353, 37.41481393575668, 37.92815878987312, 40.94627223908901, 42.793189734220505, 42.654675766825676, 41.93853199481964, 37.95805178582668, 37.832096144557, 41.18252836167812, 50.503963977098465, 54.10840876400471, 50.13091139495373, 53.16196694970131, 50.903257951140404, 47.92618229985237, 47.018741592764854, 42.72871859371662, 39.23369653522968, 39.17139507830143, 37.38703362643719, 39.844791144132614, 37.60632365942001, 44.772609919309616, 47.316155433654785, 49.69651870429516, 48.61903332173824, 56.14884227514267, 43.12272325158119, 43.623996153473854, 56.06366604566574, 47.670380026102066, 43.57214033603668, 37.97228582203388, 41.44051931798458, 38.97464543581009, 41.117985025048256, 44.533754736185074, 49.010970890522, 49.49870891869068, 53.62657181918621, 54.11581836640835, 52.43500515818596, 51.50805629789829, 52.97609232366085, 53.23528401553631, 50.08073128759861, 44.08793605864048, 44.35183569788933, 44.21757750213146, 40.47770798206329, 38.02923336625099, 48.31687733530998, 52.39481471478939, 54.97917763888836, 48.40912498533726, 53.1146252900362, 51.88023492693901, 55.23836553096771, 49.553532376885414, 51.213587298989296, 47.6518028229475, 51.409348994493484, 51.960555016994476, 56.27249903976917, 51.3654575496912, 52.29751333594322, 50.01977115869522, 55.18946595489979, 49.45383332669735, 45.80835074186325, 28.14449317753315, 25.499643199145794, 9.409737177193165, 11.393072102218866, 15.103621445596218, 13.516859840601683, 10.739310532808304, 9.80803370475769, 7.982045486569405, 2.6630065916106105, 0.180517477565445, 0.047624224971514195, 0.5455005099065602, 6.682151388376951, 22.660889625549316, 35.77395558357239, 38.833201825618744, 49.11162368953228, 56.86741791665554, 49.29680675268173, 38.91110144555569, 16.464425325393677, 2.9101448552682996, 0.04728405416244641, 0.003991068433606415, 0.017315377699560486, 0.01942119575687684, 0.008991617269202834, 0.029366668532020412, 0.041246975961257704, 0.06696005148114637, 0.014139642444206402, 0.046647788694826886, 0.023404307903547306, 0.027039423293899745, 0.028381534284562804, 0.018542914076533634, 0.05547911598114297, 0.01691701323579764, 0.07031921966699883, 0.033017074019880965, 0.07777551800245419, 0.008247247787949163, 0.011559515023691347, 0.023101574734027963, 0.04282236623112112, 0.13151273917173967, 0.12689132621744648, 0.22059455048292875, 0.24482069973601028, 0.1484269229695201, 0.1417206390760839, 0.16307155980030075, 0.18145243520848453, 0.10422972074593417, 0.1725778481340967, 0.15849583345698193, 0.13288550457218662, 0.18604582466650754, 0.15493086772039533, 0.09078564879018813, 0.12012936640530825, 0.12435586773790419, 0.29157937271520495, 0.16012403124477714, 0.11491088080219924, 0.13642516307299957, 0.1420751927071251, 0.13272580923512578, 0.5584416061174124, 15.700417421758175, 45.48098310828209, 60.94871051609516, 52.80714198946953, 37.012571319937706, 28.037008345127106, 32.60455325245857, 36.01314514875412, 17.528229542076588, 2.4779178109019995, 0.5649591470137239, 0.3290530509548262, 1.1150917271152139, 7.509592138230801, 12.211715374141932, 18.740468993782997, 15.10846333578229, 23.766134418547153, 19.332104846835136, 11.572530772536993, 9.774629697203636, 26.259218640625477, 39.6460922062397, 56.94899193942547, 51.5919253975153, 52.75752805173397, 44.549687281250954, 46.19021885097027, 49.69732046127319, 54.85001876950264, 54.032131657004356, 56.985553577542305, 53.492271825671196, 53.675634786486626, 48.52225251495838, 43.7984561920166, 39.15952831506729, 40.3288471698761, 42.976347506046295, 43.51439483463764, 44.21802207827568, 42.96563968062401, 40.335249826312065, 40.86684890091419, 43.59395116567612, 52.91613154113293, 55.206280052661896, 51.06507606804371, 53.70918318629265, 53.725678101181984, 50.378388315439224, 48.68449620902538, 43.050804510712624, 41.371382027864456, 40.485273376107216, 39.35332551598549, 41.556663885712624, 41.29208408296108, 47.3623913526535, 51.75591319799423, 50.74861764907837, 50.7842331379652, 56.70491203665733, 46.00677229464054, 45.54478548467159, 57.68280476331711, 50.29024064540863, 45.400552824139595, 40.289956256747246, 42.22836524248123, 42.11577728390694, 44.084569439291954, 46.73071324825287, 50.23395046591759, 51.873216703534126, 55.48374496400356, 53.418593779206276, 52.082501873373985, 51.35797195136547, 53.87837290763855, 55.42749658226967, 54.590967670083046, 48.835017532110214, 48.826528787612915, 48.02719987928867, 42.50219374895096, 40.25177210569382, 50.77962778508663, 53.93382713198662, 55.82300215959549, 48.10134910047054, 54.03632663190365, 54.168536737561226, 57.81016252934933, 51.36575013399124, 54.48138915002346, 50.542243123054504, 54.750920087099075, 55.0279176235199, 59.6150466799736, 51.689595356583595, 53.47463317215443, 51.269539296627045, 58.48100893199444, 51.30931556224823, 52.28073723614216, 30.636522956192493, 29.405936188995838, 20.089238919317722, 21.659098081290722, 27.485572434961796, 16.328115239739418, 17.992374636232853, 17.04549964517355, 13.024652302265167, 5.85775570012629, 0.6524293846450746, 0.24609337910078466, 1.0356083046644926, 7.655356591567397, 23.98997090756893, 44.910781905055046, 47.51626409590244, 54.11647953093052, 59.79660853743553, 59.54147882759571, 45.40738485753536, 21.810014583170414, 3.937016953714192, 0.13707144011277705, 0.1976660909713246, 0.11635210190434009, 0.11298384983092546, 0.09510134885204025, 0.11419573245802894, 0.18622204021085054, 0.13960415264591575, 0.18868144339649007, 0.19854933576425537, 0.20045465149451047, 0.05778211525466759, 0.16583616379648447, 0.1293570376583375, 0.15809836884727702, 0.12217980169225484, 0.09269009620766155, 0.1487679546698928, 0.22311096545308828, 0.19380388024728745, 0.08151256552082486, 0.10709165740991011, 0.13699767063371837], [0.05447685667604674, 0.07007668580627069, 0.0653460064495448, 0.014376549897860968, 0.03382717273780145, 0.048298239780706353, 0.06893929996294901, 0.04607458722603042, 0.04952640141709708, 0.03365752891113516, 0.035559204407036304, 0.09271354065276682, 0.08374139084480703, 0.02234749888884835, 0.017285227950196713, 0.042860720423050225, 0.05317474002367817, 0.019571048360376153, 0.03305817415821366, 0.0650050860713236, 0.020828738197451457, 0.03658966161310673, 0.014254231900849845, 0.121565474109957, 3.9583513839170337, 28.60348954796791, 47.223147824406624, 43.620842322707176, 25.829522497951984, 19.307157285511494, 33.87534946203232, 26.17152314633131, 11.750863753259182, 1.6997397551313043, 0.1769146029255353, 0.01723856355965836, 1.3516504084691405, 1.4645846234634519, 2.423805627040565, 9.430027138441801, 10.590612161904573, 12.725720442831516, 23.91278564929962, 10.920375566929579, 18.96784119307995, 31.99246309697628, 39.35531660914421, 51.73827454447746, 50.01204617321491, 46.544302850961685, 41.94067507982254, 41.2317281216383, 45.51373355090618, 51.07373580336571, 49.67728413641453, 50.59861309826374, 52.566930279135704, 49.66498039662838, 45.89558266103268, 46.324872225522995, 44.55576695501804, 41.91851086914539, 38.606407195329666, 36.36052630841732, 38.05081620812416, 36.213132217526436, 35.865321680903435, 36.012001410126686, 41.86975568532944, 51.09056130051613, 52.60154262185097, 50.71120485663414, 51.172108724713326, 46.9057584553957, 45.30515514314175, 39.4145630300045, 37.35207550227642, 36.41913816332817, 34.65925879776478, 35.50558738410473, 38.391467928886414, 44.13998566567898, 50.3593323379755, 47.891379967331886, 50.848316699266434, 47.38858714699745, 55.0304064899683, 39.8774503916502, 39.18212950229645, 55.179772675037384, 45.43892316520214, 43.59377257525921, 35.743572413921356, 37.94736675918102, 37.79953949153423, 37.70954132080078, 37.83172756433487, 44.0614552795887, 48.134399726986885, 50.263163298368454, 51.57612964510918, 54.622627571225166, 50.60462437570095, 49.75522555410862, 50.18364496529102, 52.57177881896496, 52.40822419524193, 51.94503664970398, 53.735086396336555, 46.26136623322964, 36.88005343079567, 50.884076580405235, 51.46747067570686, 49.498378336429596, 50.45965075492859, 51.57873250544071, 51.32282383739948, 48.36838357150555, 45.72576217353344, 42.755115777254105, 41.61962650716305, 45.31944237649441, 47.337806671857834, 52.94012725353241, 53.05309899151325, 53.53869393467903, 51.77761763334274, 51.428944543004036, 46.96818150579929, 47.17292211949825, 35.48963584005833, 26.1932959780097, 14.90301026031375, 11.280959118157625, 8.140711672604084, 11.644011586904526, 16.10571887344122, 5.032675098627806, 5.68534042686224, 2.5766783114522696, 0.1704526340472512, 0.03709758006152697, 0.5254834215156734, 5.850410694256425, 22.9105419293046, 44.47487309575081, 33.10518018901348, 43.754321560263634, 47.629646211862564, 47.26117618381977, 35.63962519168854, 10.839750543236732, 3.021966442465782, 0.046834464810672216, 0.04313754521717783, 0.06309051575954072, 0.03367714387422893, 0.10138600380741991, 0.039136278282967396, 0.049522004192112945, 0.0415594795049401, 0.054021793985157274, 0.052796393138123676, 0.05431114252132829, 0.011013361126970267, 0.01360557071166113, 0.058036126429215074, 0.03230415582947899, 0.10430328984512016, 0.06827088465797715, 0.014929657718312228, 0.03584899452107493, 0.023582017020089552, 0.0509410016820766, 0.0434088224574225, 0.06662699786829762, 0.04728054380393587, 0.05822950042784214, 0.14019522874150425, 0.02194174077885691, 0.0087486826487293, 0.024741173765505664, 0.04207399564620573, 0.006719294669892406, 0.0493407977046445, 0.010346195413148962, 0.00435220491453947, 0.05003477257560007, 0.03046161466045305, 0.012133210020692786, 0.07923124067019671, 0.02457864899042761, 0.01983747566555394, 0.033892674691742286, 0.010284641684847884, 0.1369892546790652, 0.01503452040196862, 0.03860118238662835, 0.023678488796576858, 0.1343897933838889, 6.095830500125885, 35.115405321121216, 52.15355046093464, 48.535916581749916, 31.582292206585407, 22.187699116766453, 33.01873102784157, 33.76013204455376, 13.56418440118432, 2.370978961698711, 0.2388155079097487, 0.19298754748888314, 1.6014592163264751, 3.5855327267199755, 7.489288877695799, 11.361279208213091, 13.444289434701204, 10.983740016818047, 9.77989811450243, 9.927110765129328, 10.853917133063078, 25.692355558276176, 41.87068283557892, 52.83745676279068, 52.03547939658165, 47.992078363895416, 45.14967128634453, 43.108147233724594, 48.49588192999363, 51.99701026082039, 51.414193734526634, 52.2222887724638, 53.51330749690533, 51.03181265294552, 49.18054439127445, 46.6531366109848, 44.92861434817314, 41.72855146229267, 41.24860301613808, 38.46282809972763, 40.32898776233196, 37.45861038565636, 36.950665041804314, 36.99583321809769, 43.54157097637653, 52.59345665574074, 54.235584139823914, 49.956850335001945, 52.564418613910675, 49.53498177230358, 47.096888199448586, 42.929594814777374, 37.72460751235485, 38.40991593897343, 35.61048075556755, 38.127807676792145, 39.20408472418785, 45.929632633924484, 52.86741815507412, 50.17885722219944, 53.137078285217285, 49.19729769229889, 54.59837727248669, 41.72610819339752, 42.203225791454315, 56.75934411585331, 48.09180401265621, 45.77807776629925, 39.033458679914474, 39.730527475476265, 39.115446880459785, 40.34435033798218, 40.88616706430912, 46.17245100438595, 51.27014346420765, 51.74597293138504, 55.120218470692635, 55.56363187730312, 50.94260483980179, 48.98226723074913, 52.23091430962086, 54.657988473773, 54.241150841116905, 53.624972105026245, 55.60728393495083, 49.04179483652115, 39.037668853998184, 51.612812876701355, 52.8253848105669, 49.55293960869312, 50.507710576057434, 53.68454150855541, 51.548284739255905, 50.62854029238224, 47.19063296914101, 46.052833423018456, 44.2536261677742, 48.376845717430115, 49.92981858551502, 55.29779054224491, 53.41083459556103, 53.378555327653885, 50.35098798573017, 53.44368003308773, 47.50424914062023, 49.92814287543297, 31.46314959973097, 25.647145584225655, 13.348437678068876, 9.611865431070328, 15.186895877122879, 15.658316630870104, 9.060297477990389, 10.081459432840347, 5.139032816514373, 2.3784875962883234, 0.582302485127002, 0.08794046982075088, 0.6691352475900203, 6.609492162242532, 23.339252024888992, 43.55239659547806, 37.77669511735439, 49.6994711458683, 55.410120114684105, 53.21642942726612, 42.782994881272316, 15.340026710182428, 3.742987965233624, 0.021222913237579633, 0.024546925887989346, 0.052820364508079365, 0.0889661475957837, 0.02278423238749383, 0.03444147434493061, 0.04013098994619213, 0.04372163770312909, 0.06548768986249343, 0.06017402381985448, 0.045122879309928976, 0.05247955545200966, 0.02146704457118176, 0.030490250428556465, 0.07405727650620975, 0.06385915068676695, 0.02129525408236077, 0.06755015536327846, 0.050057612170348875, 0.02130865541403182, 0.06783519202144817, 0.057687368971528485, 0.07371410742052831, 0.16633831575745717, 0.20556217117700726, 0.1698574612964876, 0.14236449671443552, 0.1476261901552789, 0.0877609739836771, 0.1638753799488768, 0.1440384701709263, 0.14802601479459554, 0.15153558662859723, 0.08960234627011232, 0.1418219570768997, 0.18245160346850753, 0.09054709284100682, 0.22474021709058434, 0.08610262273577973, 0.1594922854565084, 0.15475958003662527, 0.08616490376880392, 0.18234786606626585, 0.1478183173458092, 0.10221510150586255, 0.11630798864644021, 0.2803231298457831, 8.439478240907192, 40.635646507143974, 58.54513429105282, 54.535038471221924, 38.64844053983688, 30.917783863842487, 45.3532225638628, 35.79509384930134, 15.389075428247452, 3.3707594638690352, 0.41464981099125, 0.5581310321576893, 3.3766211243346334, 4.575687870383263, 7.392869051545858, 18.064656257629395, 18.873908333480358, 25.42443573474884, 35.92833369970322, 20.83786904811859, 26.453726403415203, 35.9526713937521, 43.947898373007774, 55.88168241083622, 54.999548345804214, 51.01004362106323, 47.63514831662178, 46.68818213045597, 50.96531242132187, 54.23152595758438, 52.65249028801918, 52.47316651046276, 55.57670697569847, 55.564832612872124, 51.5596841275692, 49.735155031085014, 48.67759197950363, 45.98050430417061, 43.58909882605076, 41.14362984895706, 41.570540741086006, 40.09662643074989, 39.64742973446846, 40.23608274757862, 45.185256376862526, 55.48201605677605, 55.523612424731255, 50.19607029855251, 55.37803843617439, 53.219640254974365, 48.66558462381363, 44.71091642975807, 39.052263870835304, 39.938706904649734, 37.481701746582985, 40.018567219376564, 40.586484745144844, 49.34969611465931, 55.121943578124046, 52.877267226576805, 54.24666054546833, 51.81160680949688, 55.62994971871376, 43.91736701130867, 45.80827854573727, 58.53715091943741, 50.53077533841133, 47.28836752474308, 41.12798988819122, 41.73519350588322, 41.53302915394306, 41.918700858950615, 43.1721206009388, 49.81845796108246, 52.91118040680885, 54.38241966068745, 56.625036522746086, 57.62553043663502, 52.55360059440136, 49.241816103458405, 51.36195033788681, 56.128608360886574, 57.59478248655796, 56.78447976708412, 57.41518132388592, 51.3800335675478, 41.4399341493845, 55.483433380723, 54.96400125324726, 49.2388104647398, 51.424183398485184, 54.549496695399284, 53.65343637764454, 52.145768478512764, 49.06591974198818, 48.8754815608263, 47.24033050239086, 50.10932095348835, 52.157954424619675, 57.779821157455444, 56.261369436979294, 54.148872792720795, 51.22375175356865, 55.19687935709953, 48.80465716123581, 51.240451857447624, 39.62530352175236, 32.563154473900795, 20.21819069981575, 22.86499947309494, 21.030701100826263, 23.080404214560986, 29.198617413640022, 16.730150766670704, 13.425925020128489, 4.204377494752407, 0.8917431556619704, 0.23991455440409482, 0.8538228529505432, 8.120207022875547, 28.52189652621746, 55.34597955644131, 44.46522921323776, 55.18689349293709, 59.536808878183365, 57.56356716156006, 53.67522820830345, 20.65802089869976, 4.731071507558227, 0.1479196798754856, 0.10928960196906701, 0.12522363133030012, 0.19334980461280793, 0.1741396533907391, 0.21482527256011963, 0.12529403145890683, 0.21431311644846573, 0.16317819157848135, 0.1130508583446499, 0.09833672680542804, 0.11938124443986453, 0.08578012988436967, 0.17559507919941097, 0.14719152910402045, 0.19765328150242567, 0.12912392907310277, 0.12031291436869651, 0.13263010187074542, 0.16984318237518892, 0.1685157770407386, 0.11033696529921144, 0.14827041886746883], [0.017685674138192553, 0.04323934932472184, 0.022783410458941944, 0.019693831127369776, 0.00636458101325843, 0.0693474366562441, 0.06533174237119965, 0.06485804435214959, 0.040853485552361235, 0.021028021546953823, 0.08306487128720619, 0.021029160743637476, 0.06931998461368494, 0.026361918535258155, 0.008221348689403385, 0.08501768446876667, 0.10365186230046675, 0.04938996869896073, 0.0961754888703581, 0.02542417041695444, 0.04893340686976444, 0.038056212215451524, 0.047291360606322996, 0.06716044619679451, 5.8564965426921844, 24.98630404472351, 47.60508053004742, 51.80481277406216, 32.373411655426025, 21.536389365792274, 22.159402035176754, 27.749551869928837, 14.578771758824587, 2.178478203713894, 0.13525494461646304, 0.13044489256571978, 0.39350320352241397, 2.7716641360893846, 10.666270852088928, 8.774999286979437, 7.74272340349853, 4.975668657571077, 6.93110310472548, 4.022440407425165, 9.498925041407347, 24.30103361606598, 41.30425103008747, 48.545176684856415, 47.89069980382919, 47.98858255147934, 43.71017172932625, 41.845364794135094, 45.77106714248657, 50.38781180977821, 52.571509033441544, 48.27319487929344, 52.670090943574905, 47.82093554735184, 51.98186047375202, 50.437095165252686, 50.09675122797489, 49.34390142560005, 47.12081931531429, 44.39405143260956, 41.98554687201977, 42.06562377512455, 43.84942665696144, 45.0740971416235, 48.23866233229637, 51.7053759098053, 49.846846237778664, 50.9920933842659, 51.98931187391281, 46.28962151706219, 44.75331835448742, 36.80568762123585, 36.154117584228516, 36.553145572543144, 36.62021577358246, 35.351942628622055, 40.047552064061165, 47.52433866262436, 51.460946425795555, 53.09311084449291, 53.667206838727, 48.223409950733185, 54.2305114120245, 41.23659186065197, 41.28478467464447, 55.850018709897995, 47.06261023879051, 43.04873742163181, 38.69442567229271, 37.36215256154537, 35.39236105978489, 37.01272331178188, 37.08696752786636, 39.00628633797169, 42.869029864668846, 47.75282800197601, 48.522134721279144, 50.64061984419823, 53.7123142182827, 53.24807032942772, 52.386698350310326, 50.00747501850128, 49.379646107554436, 50.87563343346119, 53.40930327773094, 45.92298299074173, 40.041233003139496, 46.994833275675774, 51.96291469037533, 50.72534389793873, 52.49280385673046, 52.05781079828739, 47.77354449033737, 45.11564031243324, 40.332916751503944, 40.294500812888145, 39.13048267364502, 42.33513191342354, 45.350353717803955, 50.8967375010252, 50.73419742286205, 55.911715999245644, 53.967120945453644, 56.212595254182816, 53.25505055487156, 48.82511526346207, 38.32471691071987, 25.900250002741814, 10.35431519150734, 10.931570716202259, 14.455087445676327, 14.023645296692848, 5.834259185940027, 6.147615546360612, 7.280347589403391, 1.392144716810435, 0.34905491047538817, 0.0028020655236105085, 0.26790334784891456, 5.24948101490736, 21.971186734735966, 33.15811514854431, 41.92921869456768, 45.333091244101524, 50.731066390872, 37.15990461409092, 39.76401127874851, 12.07834443077445, 1.9874676782637835, 0.05382401905080769, 0.032691471569705755, 0.06835547465016134, 0.017967083549592644, 0.0468467510654591, 0.10059667780296877, 0.09409846985363401, 0.011271001403656555, 0.01088977127437829, 0.0669972924515605, 0.0324070434726309, 0.03373086052306462, 0.053855259757256135, 0.06863651113235392, 0.03896835994964931, 0.010880172521865461, 0.009868280139926355, 0.09077600829186849, 0.02561277611675905, 0.06955216551432386, 0.08073857228737324, 0.05229340255027637, 0.06771696047508158, 0.022724934788129758, 0.021167142695048824, 0.023511102954216767, 0.020584068806783762, 0.04881638873484917, 0.01038171089021489, 0.05016466697270516, 0.06485330202849582, 0.030224199763324577, 0.06415787254809402, 0.06580711764399894, 0.07041754681267776, 0.08364514913409948, 0.04764243356476072, 0.024253480696643237, 0.03670802303531673, 0.029563758835138287, 0.06187420251080766, 0.13557872880483046, 0.014081118533795234, 0.05722561210859567, 0.03410104749491438, 0.048230132888420485, 0.07069755170959979, 7.187553718686104, 31.11320547759533, 54.41491551697254, 54.98063676059246, 35.52680924534798, 24.36242312192917, 29.10370610654354, 28.329619243741035, 16.350484639406204, 2.9035674082115293, 0.11067095401813276, 0.19468236045213416, 0.8286820957437158, 2.3414476588368416, 5.671617463231087, 10.162059757858515, 15.577096939086914, 11.535955835133791, 10.699255932122469, 12.352780904620886, 10.707097761332989, 21.68341677635908, 44.662776812911034, 53.92921797931194, 49.40320864319801, 50.78579105436802, 46.752972453832626, 43.69038999080658, 48.25707994401455, 52.97637350857258, 54.508208110928535, 48.34740109741688, 52.17406176030636, 50.099977254867554, 53.8129898160696, 53.874090537428856, 52.080837562680244, 51.61193132400513, 49.76071625947952, 45.90833857655525, 43.05296279489994, 43.11467908322811, 44.73773919045925, 46.329040601849556, 50.07169917225838, 53.453844487667084, 50.81782713532448, 51.535164043307304, 54.42166395485401, 49.170102551579475, 48.73660281300545, 38.75953137874603, 37.538273110985756, 37.252376452088356, 36.69230170547962, 36.4525193721056, 40.57388462126255, 47.73390881717205, 54.051879197359085, 55.01898430287838, 56.10064946115017, 48.69014650583267, 53.64232197403908, 41.41324818134308, 43.124680146574974, 56.002322137355804, 48.39593969285488, 45.31920678913593, 40.63075616955757, 39.60589416325092, 36.739468574523926, 38.30411061644554, 39.349506720900536, 40.466243997216225, 45.06394408643246, 50.52829027175903, 50.078899785876274, 51.66414812207222, 55.69974437355995, 52.32681356370449, 51.1062316596508, 49.89306315779686, 51.25195004045963, 52.601892203092575, 55.19982799887657, 48.15932258963585, 41.630368530750275, 51.138674318790436, 54.419539868831635, 50.344722121953964, 53.09782259166241, 54.3917291611433, 50.86117900907993, 46.41261711716652, 42.10769131779671, 42.11010038852692, 40.84801711142063, 45.24289168417454, 48.98176185786724, 53.89391787350178, 53.769782334566116, 57.03920669853687, 54.69174586236477, 56.911335960030556, 52.54741072654724, 48.83650705218315, 40.72085693478584, 27.552844025194645, 12.923874109983444, 11.858358085155487, 12.794591747224331, 13.343486543744802, 7.290959944948554, 12.084141969680786, 4.19204430654645, 2.7961367228999734, 1.00598901277408, 0.052888037243974395, 0.3742090263403952, 6.6943425592035055, 23.57919964939356, 37.960601449012756, 42.655944898724556, 48.73403415083885, 55.09227856993675, 44.89887334406376, 45.818439200520515, 17.076882161200047, 2.4507901165634394, 0.21307660936145112, 0.01448514001822332, 0.0480053140927339, 0.05133052902237978, 0.0332420820632251, 0.11350503787980415, 0.06655879449681379, 0.028475707258621696, 0.09898877033265308, 0.04586174669384491, 0.05551955560804345, 0.10673194585251622, 0.05646790530590806, 0.018319520204386208, 0.03670490230433643, 0.003358728695275204, 0.0050782322159648174, 0.0540239573456347, 0.06428684297134168, 0.04373817275336478, 0.012372439468890661, 0.0236390844656853, 0.02802134218654828, 0.13774925842881203, 0.19177345326170325, 0.14179411169607192, 0.11635418733931147, 0.07996782966074534, 0.17635613679885864, 0.16260212170891464, 0.15546925133094192, 0.1143586338730529, 0.1086651069635991, 0.1959503346006386, 0.2619938040152192, 0.1281704325811006, 0.11245387475355528, 0.0580300779256504, 0.17553270910866559, 0.12480606936151162, 0.2074299193918705, 0.18624657561304048, 0.0915291991259437, 0.1648842406575568, 0.10078029255964793, 0.21073882933706045, 0.21921050443779677, 9.828115627169609, 38.64527150988579, 60.54992191493511, 63.43275502324104, 42.6633583009243, 31.613938808441162, 33.944076374173164, 36.37475274503231, 19.17987361550331, 3.4462129650637507, 0.3214678564108908, 0.41694144427310675, 0.9453660564031452, 8.075372278690338, 18.0660754814744, 18.379913941025734, 17.77858290821314, 16.0777485743165, 20.241287760436535, 9.70596358180046, 15.16223045065999, 27.779822945594788, 46.63224533200264, 55.671071112155914, 51.87094062566757, 53.650464937090874, 49.24934729933739, 46.91047020256519, 50.90799629688263, 55.280961245298386, 54.360859617590904, 48.317462503910065, 52.41097904741764, 50.61499781906605, 56.61563962697983, 56.58500947058201, 54.557145684957504, 55.113230645656586, 52.13253378868103, 49.60207857191563, 47.419794872403145, 46.55261680483818, 47.285654470324516, 50.60849256813526, 52.67172485589981, 56.18137612938881, 50.07512278854847, 52.26190164685249, 55.514462515711784, 51.009249463677406, 51.06474928557873, 41.60326078534126, 39.12245750427246, 40.157236978411674, 39.48334313929081, 39.91256430745125, 42.61914387345314, 51.77721865475178, 58.15798446536064, 56.74877308309078, 58.056970685720444, 50.48386685550213, 53.52218382060528, 45.00623278319836, 47.41131752729416, 59.59327384829521, 51.43313191831112, 47.25317761301994, 43.46931405365467, 41.49197615683079, 38.92549507319927, 41.21092043817043, 41.14981211721897, 43.59199807047844, 45.75481541454792, 50.60721203684807, 53.662084713578224, 54.63489331305027, 57.09237724542618, 54.15423050522804, 53.63307327032089, 50.68926863372326, 51.35726518929005, 51.78736411035061, 57.00323022902012, 50.710532292723656, 43.57948914170265, 52.99764856696129, 55.286235362291336, 51.46443083882332, 55.434609800577164, 57.64667250216007, 52.4836615473032, 49.69112679362297, 43.17563161253929, 44.42285008728504, 43.097017630934715, 47.117665484547615, 48.56122702360153, 57.44408257305622, 54.18984219431877, 58.65703448653221, 56.24759517610073, 57.512190118432045, 54.51180271804333, 51.33721366524696, 42.41987116634846, 32.383393719792366, 17.033515088260174, 17.147856652736664, 22.441635690629482, 28.94147951155901, 17.423636354506016, 17.768538147211075, 12.909963056445122, 3.722690404392779, 1.423506096471101, 0.08619372878456488, 0.6828262098133564, 7.952298782765865, 28.418422378599644, 43.58177661895752, 56.71025834977627, 56.55896566808224, 60.73853239417076, 51.918210089206696, 53.51441703736782, 22.423898242413998, 3.246545079164207, 0.3588256111834198, 0.230531818815507, 0.1420702351606451, 0.06464852864155546, 0.14063081005588174, 0.19602647895226255, 0.21581382810836658, 0.09929081701557152, 0.1599980442551896, 0.13968375540571287, 0.18193128373241052, 0.23882481444161385, 0.11196138555533253, 0.16846951155457646, 0.1681778475176543, 0.18813091824995354, 0.15972076304024085, 0.13319014135049656, 0.11318028889945708, 0.08147098298650235, 0.20708455354906619, 0.19584747293265536, 0.1641911340993829], [0.06218024936970323, 0.034571981013868935, 0.028808781280531548, 0.04476295995118562, 0.015970728563843295, 0.05793916483526118, 0.06071208088542335, 0.05011380388168618, 0.027357292565284297, 0.025347105802211445, 0.07841323065804318, 0.03391842721612193, 0.06886711125844158, 0.09985957673052326, 0.010184056554862764, 0.026907747742370702, 0.03339233728183899, 0.029747974731435534, 0.02167081976949703, 0.044486420883913524, 0.0274309470114531, 0.05745439026213717, 0.017980336451728363, 0.050568673614179716, 3.4363669808954, 23.022780306637287, 42.16037929058075, 52.700189128518105, 31.80089447647333, 19.57619234919548, 23.835902474820614, 27.229956351220608, 13.590219654142857, 3.4512921050190926, 0.14886473072692752, 0.22262551181484014, 2.3362668743357062, 3.2704360596835613, 5.9460026398301125, 9.910581652075052, 20.680867172777653, 8.084442391991615, 7.007016856223345, 12.990139704197645, 7.848452730104327, 17.2983380779624, 40.19167833030224, 50.1894548535347, 48.08633990585804, 46.28991410136223, 42.11576208472252, 41.520881205797195, 47.352899461984634, 50.47871433198452, 52.22684092819691, 49.25597034394741, 50.80202378332615, 48.08920495212078, 49.457731917500496, 49.4957260787487, 49.72153276205063, 48.257642313838005, 50.18050633370876, 49.9363162368536, 52.22619876265526, 49.579207599163055, 49.92473445832729, 50.09905770421028, 51.619116738438606, 53.91363501548767, 53.79708766937256, 51.60849630832672, 51.53925642371178, 46.44339166581631, 42.65670865774155, 36.28600470721722, 35.88543780148029, 34.45937052369118, 37.129646837711334, 35.90892054140568, 38.10100391507149, 45.069962963461876, 51.293257623910904, 46.79134279489517, 53.25201831758022, 49.54027108848095, 55.27813419699669, 40.00584550201893, 36.9319586455822, 57.604699954390526, 47.25663162767887, 46.26605898141861, 40.86109980940819, 40.05316436290741, 36.93391554057598, 35.962117686867714, 37.08693712949753, 37.12550885975361, 37.98366241157055, 42.454263120889664, 45.08759781718254, 48.0481443554163, 48.651954755187035, 49.76631335914135, 53.69743421673775, 53.07017907500267, 48.759530782699585, 50.02099849283695, 52.180772200226784, 45.286536142230034, 41.14826940000057, 48.42898651957512, 50.748287066817284, 51.29757039248943, 52.610741928219795, 47.28494390845299, 41.68275631964207, 38.522420302033424, 38.11924293637276, 37.4598491191864, 37.29455418884754, 37.0894867926836, 42.638021260499954, 47.24631518125534, 48.117334842681885, 49.82234515249729, 53.50218929350376, 56.505000963807106, 55.92715077102184, 55.10039113461971, 38.17601568996906, 33.19324426352978, 15.27977904304862, 12.223400697112083, 9.091838635504246, 10.974060986191034, 4.632900450378656, 11.381114143878222, 1.0244217049330473, 2.612398057244718, 0.6579481728840619, 0.08466364291962236, 0.5628447385970503, 4.830986196175218, 20.09031616151333, 34.81233738362789, 30.66182389855385, 43.421725407242775, 46.43707640469074, 40.601045563817024, 40.57074598968029, 17.90107313543558, 3.8185352738946676, 0.013847732570866356, 0.006640697056354838, 0.0455569466430461, 0.030254586999944877, 0.014650486809841823, 0.05829611560329795, 0.036841516848653555, 0.01869384836027166, 0.02615757373860106, 0.012891525384475244, 0.01572522240167018, 0.03199800878064707, 0.14161212224280462, 0.014685009664390236, 0.055051984018064104, 0.029201755896792747, 0.035108461015624925, 0.06783343313145451, 0.025736664683790877, 0.049563490247237496, 0.03251843612815719, 0.11561552033526823, 0.04056081590533722, 0.01765372096997453, 0.037164295426919125, 0.08214989225962199, 0.034439526207279414, 0.03088221201323904, 0.042642955741030164, 0.03741057342267595, 0.05384805721405428, 0.12281525821890682, 0.018076596716127824, 0.035847762555931695, 0.0716978480340913, 0.10221898293821141, 0.03281877587141935, 0.05597504503384698, 0.07381899515166879, 0.05656297071254812, 0.03482443367829546, 0.028867778310086578, 0.028064060206816066, 0.012871223007095978, 0.048682932028896175, 0.037716553488280624, 0.049616164178587496, 4.3018812127411366, 29.378176778554916, 50.169676914811134, 57.38072857260704, 37.4227175116539, 23.598732501268387, 29.516392461955547, 30.454007349908352, 16.076192557811737, 3.6422271095216274, 0.20398359338287264, 0.10835418419446796, 0.49653452646452934, 3.822390642017126, 8.88399263843894, 10.928604025393724, 15.738716516643763, 11.416327804327011, 7.736322171986103, 14.026100914925337, 13.249699976295233, 20.677971728146076, 45.111893713474274, 51.38060733675957, 51.691233068704605, 48.47892343997955, 45.962322279810905, 46.493879556655884, 50.27111627161503, 51.96345426142216, 51.65677651762962, 49.592712074518204, 50.58592177927494, 49.19285573065281, 52.4984123557806, 50.9321554005146, 50.969913974404335, 50.705953538417816, 52.23127529025078, 51.95176228880882, 54.07394081354141, 50.4063206166029, 51.080586835742, 53.2651200145483, 54.28812012076378, 54.4862262904644, 51.67143613100052, 52.1829304844141, 54.41092573106289, 48.95519368350506, 46.15447796881199, 36.199908927083015, 37.89644569158554, 35.89545786380768, 38.13653200864792, 37.01312229037285, 40.632154494524, 47.31595404446125, 52.939633280038834, 51.445184871554375, 55.095394402742386, 50.553794503211975, 54.24018569290638, 42.41946838796139, 39.9650052934885, 59.49066035449505, 48.86796936392784, 48.35031174123287, 44.295081943273544, 42.00759328901768, 39.632694125175476, 38.016329258680344, 38.622347339987755, 38.713063672184944, 40.36654494702816, 46.07084445655346, 48.18415425717831, 51.430753245949745, 50.403341576457024, 54.24425907433033, 54.080544859170914, 52.23585784435272, 50.24363614618778, 51.116643100976944, 53.42679753899574, 48.92811253666878, 42.12968073785305, 50.02484388649464, 53.74444529414177, 53.74628819525242, 54.008599519729614, 47.97868028283119, 43.581130653619766, 40.96463285386562, 39.18129734694958, 38.20164531469345, 39.4975695759058, 40.2543293684721, 44.424130618572235, 49.596443474292755, 51.99322186410427, 52.28296011686325, 55.21792642772198, 57.043401673436165, 57.47509650886059, 53.570904806256294, 39.5258666574955, 32.10967920720577, 15.310810077935457, 14.159045331180096, 14.325046073645353, 16.164834201335907, 10.828240010887384, 4.678538851439953, 3.9897089637815952, 4.939203439280391, 0.6209009326994419, 0.08985389722511172, 0.48116773541551083, 5.7069118693470955, 22.05972768366337, 42.17202186584473, 39.2997407913208, 48.86495232582092, 52.80426174402237, 45.736219212412834, 46.611061468720436, 20.424914807081223, 3.475767304189503, 0.0709614965307992, 0.03869340165692847, 0.03731013486685697, 0.04230445105349645, 0.01458788294257829, 0.022436829349317122, 0.010852341056306614, 0.02449458777846303, 0.01787839319149498, 0.05383252406318206, 0.022778773891332094, 0.04990819557860959, 0.08819138995022513, 0.04032922501210123, 0.03594122863432858, 0.06479827919974923, 0.03039645223907428, 0.00873810147822951, 0.01689024025836261, 0.048634525446686894, 0.02513757524866378, 0.02680693254660582, 0.04092811963346321, 0.1558122126152739, 0.12628414551727474, 0.16194873489439487, 0.18799381388816983, 0.10036054867669009, 0.20333286345703527, 0.08623523710411973, 0.18952755111968145, 0.2393110399134457, 0.0796319410437718, 0.12230902444571257, 0.22102514456491917, 0.2079248131485656, 0.16256495495326817, 0.22978236840572208, 0.12496809504227713, 0.1581005210755393, 0.12101911983336322, 0.10906942159635946, 0.21298507286701351, 0.1367708554607816, 0.20990097429603338, 0.06752043977030553, 0.1344428866286762, 6.388376802206039, 36.623772382736206, 59.56957831978798, 62.53346487879753, 43.54143798351288, 30.36785077303648, 37.15968802571297, 36.51435725390911, 19.400145895779133, 5.156260142102838, 0.44400418584700674, 0.4278595052892342, 3.5028230398893356, 5.813334658741951, 12.68936874344945, 20.380164608359337, 28.130101449787617, 19.29583389312029, 12.140529993921518, 20.24281717836857, 12.878731582313776, 21.7199195176363, 45.15317849814892, 55.95358595252037, 53.3285766094923, 51.32134951651096, 47.407137751579285, 47.994685024023056, 53.002755492925644, 54.4067307561636, 52.479044795036316, 48.99732202291489, 51.88244640827179, 48.63042891025543, 53.82435880601406, 52.08505913615227, 50.98069779574871, 51.211683601140976, 53.46567705273628, 53.129832074046135, 56.59337282180786, 54.44414734840393, 54.27680432796478, 55.35842388868332, 55.917043313384056, 55.23857071995735, 52.891725450754166, 53.64178240299225, 54.810269102454185, 52.22028627991676, 46.92406967282295, 39.49271723628044, 40.134829580783844, 38.031619638204575, 40.2021049708128, 39.98740129172802, 42.01874189078808, 51.18866823613644, 55.581255331635475, 53.13826762139797, 55.79980440437794, 53.01913261413574, 53.96660417318344, 44.1381161659956, 44.048418179154396, 60.57570353150368, 52.8279572725296, 50.67799463868141, 45.760598704218864, 44.552510529756546, 40.74809767305851, 40.01704350113869, 40.745931789278984, 40.297468453645706, 41.63202524185181, 47.13220350444317, 49.15893495082855, 54.040517807006836, 53.76125179231167, 54.91459250450134, 56.076627150177956, 53.814707323908806, 48.71905915439129, 51.49257592856884, 55.16668237745762, 52.2721990942955, 45.55504873394966, 52.54882425069809, 53.68688218295574, 54.19708080589771, 56.87588386237621, 50.662673860788345, 44.97438669204712, 42.54561401903629, 41.02550558745861, 40.071407184004784, 41.49174056947231, 40.98797880113125, 48.09754550457001, 52.231966853141785, 54.592305198311806, 54.28828351199627, 58.703703582286835, 61.86583690345287, 58.972527757287025, 58.781318217515945, 40.055964812636375, 37.28903688490391, 22.58621223270893, 21.4269932359457, 19.111397489905357, 23.15408606082201, 17.040358521044254, 16.97906021028757, 5.56778091005981, 6.856154026463628, 1.970980481710285, 0.45782968460116535, 0.9668504598084837, 6.448248289525509, 26.80304355919361, 45.79148344695568, 43.0248899012804, 55.27804680168629, 58.76413933932781, 54.91997301578522, 52.887952253222466, 26.556184105575085, 5.560742737725377, 0.18919760710559785, 0.10756132556707598, 0.13578992919065058, 0.20475320052355528, 0.07768548806780018, 0.1195858619757928, 0.20607444603228942, 0.10760726450826041, 0.15678116062190384, 0.091421394754434, 0.07287827844265848, 0.1364575355546549, 0.19310315925395116, 0.17591353476746008, 0.13240552798379213, 0.18994448968442157, 0.1502487322431989, 0.10767911182483658, 0.13834460929501802, 0.1111482217675075, 0.14057324908208102, 0.10284884367138147, 0.1746269772411324], [0.05681192415067926, 0.015744579468446318, 0.029520766220230144, 0.016238985263044015, 0.04598384111886844, 0.02107062638970092, 0.04675181924540084, 0.02986239349411335, 0.05881345190573484, 0.019428248015174177, 0.050069479111698456, 0.048565168035565875, 0.0603443689760752, 0.04810948565136641, 0.02568052677816013, 0.038224000672926195, 0.015630288726242725, 0.01395326318743173, 0.07928557330160402, 0.11412890948122367, 0.0501588819315657, 0.016607930992904585, 0.020923940901411697, 0.035344942662050016, 3.8707881700247526, 22.358802035450935, 42.699935138225555, 46.61376312375069, 32.50134319067001, 20.99697981029749, 21.06920063495636, 24.098107405006886, 17.9840549826622, 3.974768165498972, 0.1285560821997933, 0.13420881325146183, 0.3941316541749984, 2.517928476445377, 3.59681099653244, 8.079558704048395, 11.706634126603603, 10.205154195427895, 8.036317974328995, 18.64748988300562, 13.227275479584932, 19.59270816296339, 42.26787552237511, 48.45551669597626, 48.566759526729584, 46.46832212805748, 44.527830854058266, 42.469511702656746, 47.060691341757774, 50.71915403008461, 49.819457307457924, 50.23732848465443, 50.05361594259739, 51.742461919784546, 49.53658148646355, 54.87899221479893, 51.37929640710354, 50.31197167932987, 52.640273943543434, 52.251235619187355, 52.414885237812996, 50.2339618653059, 52.66848362982273, 52.14345060288906, 53.91813777387142, 51.11967533826828, 53.35655830800533, 50.16100957989693, 50.80819085240364, 47.887709364295006, 41.75445847213268, 33.95015984773636, 35.35476207733154, 34.391889944672585, 36.327490881085396, 35.600073114037514, 35.983316749334335, 36.66391722857952, 42.70512945950031, 43.735337778925896, 49.68588687479496, 48.65120239555836, 55.33090956509113, 40.359021350741386, 35.629814118146896, 54.60906609892845, 49.452336207032204, 49.130288287997246, 44.599099829792976, 44.28396753966808, 41.05203956365585, 38.72564099729061, 37.081978395581245, 36.75241068005562, 36.801937222480774, 38.15863162279129, 40.87727554142475, 43.96124325692654, 45.490205213427544, 47.53934405744076, 48.780771642923355, 52.44256675243378, 49.23514366149902, 49.53031562268734, 51.838965341448784, 45.73540225625038, 44.46438565850258, 48.98787572979927, 51.94764330983162, 51.259154453873634, 45.90516574680805, 43.19050781428814, 39.431981295347214, 40.316520631313324, 42.143568992614746, 46.485159024596214, 43.326738104224205, 37.696751207113266, 35.42403236031532, 41.26866213977337, 46.947267428040504, 49.40341003239155, 50.74247717857361, 54.03807453811169, 54.321584925055504, 53.53462055325508, 45.5651979893446, 33.46547305583954, 18.99116814136505, 10.804025810211897, 14.993587899953127, 9.911051876842976, 4.3872179836034775, 5.60059642419219, 4.11330065689981, 3.517291476018727, 0.602737907320261, 0.13558092556195334, 0.43698242981918156, 5.0761656649410725, 20.0866911560297, 33.42658594250679, 33.98867078125477, 39.87034857273102, 46.58697836101055, 46.241246312856674, 37.740258872509, 17.059059217572212, 3.8873557560145855, 0.05795957760710735, 0.019780061265919358, 0.050101413726224564, 0.03568004089174792, 0.03514949436066672, 0.016414401143265422, 0.02961690774100134, 0.04785809425811749, 0.024672708786965813, 0.06573204940650612, 0.05063177100964822, 0.01841788260207977, 0.023895236736279912, 0.016378291948058177, 0.1022724546783138, 0.057693165144883096, 0.023912601136544254, 0.03327041726151947, 0.04716738112620078, 0.01556777391670039, 0.058592288187355734, 0.038432206492871046, 0.05265065388812218, 0.01473828473535832, 0.022076323693909217, 0.007395970078505343, 0.10499856347450987, 0.023416690637532156, 0.009841550763667328, 0.029167017819418106, 0.03304818113974761, 0.0276952684725984, 0.002760287479759427, 0.03587896244425792, 0.033468114270363, 0.018794025309034623, 0.04206061101285741, 0.01478835372836329, 0.014395227899512975, 0.04331800955696963, 0.04564338087220676, 0.05080607552372385, 0.03273051595897414, 0.01293586778047029, 0.044219563133083284, 0.024884868398658, 0.046321703848661855, 4.538772376254201, 27.069511860609055, 50.456930100917816, 50.880276784300804, 39.08079273998737, 27.714607045054436, 27.255078703165054, 28.416748568415642, 20.703981332480907, 4.450263725593686, 0.29709011607337743, 0.05786438974610064, 0.5384025501552969, 2.8299831692129374, 8.583424016833305, 7.618681434541941, 11.228257846087217, 15.580726694315672, 13.443886656314135, 12.225318644195795, 14.936347771435976, 25.943873561918736, 42.95227959752083, 52.85350330173969, 50.507300198078156, 49.98091444373131, 44.71278212964535, 46.02649323642254, 49.526572823524475, 53.230667263269424, 49.86808329820633, 49.57274414598942, 49.825263395905495, 50.67921817302704, 50.33175341784954, 54.96475741267204, 51.153303533792496, 52.462546080350876, 53.6274191737175, 52.28124260902405, 52.08647646009922, 51.54967926442623, 52.773764580488205, 53.346766233444214, 53.13547097146511, 52.334124371409416, 54.31448310613632, 51.85928665101528, 53.0329866707325, 50.737852826714516, 43.24769854545593, 35.81527076661587, 36.79866939783096, 35.84499277174473, 37.34208583831787, 37.041202783584595, 37.239194959402084, 38.866355046629906, 45.00662796199322, 46.24433934688568, 52.70463488996029, 50.457332879304886, 56.36141426861286, 42.442506551742554, 37.895472943782806, 56.15150973200798, 51.9138403236866, 50.00343203544617, 47.301636412739754, 46.527161970734596, 43.18143010139465, 40.44026859104633, 37.377625331282616, 38.74697685241699, 39.83872666954994, 39.65626426041126, 43.69171231985092, 47.280346155166626, 48.59756827354431, 50.898215621709824, 50.17885722219944, 53.63427400588989, 48.48533749580383, 49.82308991253376, 53.37021857500076, 47.335990369319916, 46.56497374176979, 52.12072782218456, 53.24561566114426, 53.895133808255196, 46.92043326795101, 46.00840620696545, 39.913856238126755, 41.21533580124378, 44.391167387366295, 46.85479938983917, 43.31576809287071, 39.733795300126076, 39.785632118582726, 43.15380558371544, 50.61697371304035, 52.58025996387005, 53.13428923487663, 56.681649684906006, 56.38026125729084, 54.84622277319431, 47.14790426194668, 35.57453468441963, 20.036951825022697, 13.30390501767397, 12.454602140933275, 15.62034621834755, 10.995779670774937, 4.5250636618584394, 4.558739829808474, 3.2372723892331123, 0.43818571837618947, 0.1887171110138297, 0.4832001216709614, 6.448523299768567, 24.844524152576923, 38.110647797584534, 35.69269694387913, 42.67297178506851, 52.61033535003662, 51.08899958431721, 44.40231218934059, 22.21058338880539, 4.136806670576334, 0.2055635812575929, 0.042059861443703994, 0.020868096144113224, 0.02844253696821397, 0.053992382672731765, 0.04748768093122635, 0.024780984422250185, 0.07795703990268521, 0.020516598306130618, 0.02345928063732572, 0.03972590347984806, 0.01727825732814381, 0.02455832713167183, 0.023798468100721948, 0.05560541096201632, 0.06340572814224288, 0.025833056679402944, 0.06648298411164433, 0.013706451773032313, 0.03954233696276788, 0.05273245711578056, 0.07443983136909083, 0.053347126086009666, 0.19083754566963762, 0.17292079457547516, 0.08573357496061362, 0.22402860136935487, 0.1510276459157467, 0.1792195948655717, 0.19134569418383762, 0.16388030780944973, 0.11003315230482258, 0.14884724572766572, 0.1282295075361617, 0.26337102230172604, 0.1386608977918513, 0.17454284738050774, 0.1358998561045155, 0.13681712094694376, 0.15146227728109807, 0.08876869920641184, 0.18379701330559328, 0.16417036880739033, 0.15888078545685858, 0.08392080504563637, 0.08364379100385122, 0.15532959398115054, 5.879815416410565, 33.692111894488335, 58.940430879592896, 57.27252557873726, 44.38617825508118, 30.97072832286358, 31.14217322319746, 34.97180722653866, 24.114594720304012, 5.724542923271656, 0.367173733538948, 0.3999703674344346, 1.240246680099517, 6.6703088488429785, 10.695707872509956, 14.72369123250246, 23.47901802510023, 23.27291328459978, 15.872815120965242, 27.607602886855602, 20.123893059790134, 22.9896916821599, 47.24164143204689, 55.46502336859703, 53.123984187841415, 51.35407716035843, 50.00764600932598, 49.35104504227638, 52.64013335108757, 54.474405124783516, 50.29171496629715, 51.28780111670494, 49.6467337757349, 51.75146363675594, 50.38561172783375, 57.289047092199326, 53.61967898905277, 53.146923556923866, 54.68000449240208, 53.89465503394604, 52.65252448618412, 50.4831562936306, 53.864587247371674, 52.38538362085819, 53.95349867641926, 53.80769670009613, 55.17082795500755, 53.58633577823639, 56.064346209168434, 52.2821469604969, 45.70064552128315, 37.29928873479366, 38.77166412770748, 38.21812503039837, 39.736033380031586, 38.91678974032402, 40.39094723761082, 40.23791044950485, 45.71196511387825, 48.92007976770401, 56.064099222421646, 53.185970261693, 57.777070105075836, 43.27086590230465, 41.59527361392975, 57.6761095225811, 54.739695489406586, 52.51274898648262, 50.1925440877676, 48.95545206964016, 44.264022409915924, 42.99510709941387, 39.99233342707157, 40.7075310498476, 42.65505954623222, 41.98601424694061, 44.20288749039173, 48.1227495521307, 49.458879455924034, 52.733213156461716, 52.46315024793148, 55.402197539806366, 49.42881926894188, 49.501148387789726, 54.91146147251129, 49.961926862597466, 49.863576740026474, 53.40985804796219, 54.4691614061594, 55.81902377307415, 49.43401739001274, 48.67489032447338, 43.82340185344219, 44.08451244235039, 47.205277383327484, 50.20295172929764, 47.93267235159874, 41.833593025803566, 40.985600128769875, 45.04956565797329, 52.389004826545715, 55.74362441897392, 55.867615565657616, 59.13553521037102, 58.82893726229668, 57.79543071985245, 50.749221816658974, 38.65274950861931, 26.722130700945854, 15.546095352619886, 21.715519353747368, 20.486215017735958, 13.517982680350542, 12.276998721063137, 11.682463623583317, 6.909025814384222, 1.5921828453429043, 0.4779745708219707, 0.7717021938879043, 7.699287934228778, 27.035513184964657, 43.95626172423363, 47.220909744501114, 51.281159073114395, 58.630865290760994, 60.36351531744003, 50.78531987965107, 27.28119470179081, 4.914732277393341, 0.33796476025599986, 0.17634113057283685, 0.218505731318146, 0.21126703068148345, 0.11876905424287543, 0.14340650173835456, 0.09026572239235975, 0.1736885611899197, 0.104499150038464, 0.11933474146644585, 0.15945182356517762, 0.13941987737780437, 0.127913486212492, 0.06210979729075916, 0.15338832861743867, 0.1850991856190376, 0.18087597942212597, 0.07644869896466844, 0.19545398623449728, 0.12205644190544263, 0.19411740795476362, 0.14620408677728847, 0.13799480540910736], [0.02425101862172596, 0.02396971125563141, 0.03561381534382235, 0.07026786304777488, 0.04750953346956521, 0.07793586642947048, 0.0293655868517817, 0.018722691929724533, 0.07320155054912902, 0.011886679694725899, 0.05594535541604273, 0.01907512116304133, 0.07599218166433275, 0.06331225464236923, 0.020161951906629838, 0.0367047761392314, 0.021060956205474213, 0.01705157945252722, 0.053371108588180505, 0.0807474557950627, 0.02743849836406298, 0.062395902641583234, 0.03812419294263236, 0.07162618625443429, 2.4041875172406435, 19.221817664802074, 41.41419053077698, 48.576878383755684, 31.0357466340065, 17.254300341010094, 24.753843918442726, 28.525361940264702, 17.68256016075611, 4.69242425635457, 0.5801047780551016, 0.035957618965767324, 0.6568236707244068, 2.277419907040894, 10.83754951134324, 5.6567474361509085, 7.269249809905887, 10.611045565456152, 9.122415594756603, 10.03447400406003, 19.037848636507988, 35.618597120046616, 43.07469002902508, 50.45942276716232, 50.88234007358551, 46.59197509288788, 44.51155252754688, 43.4808312356472, 47.70197153091431, 50.53647503256798, 50.035817697644234, 48.916200175881386, 51.08527198433876, 50.509040504693985, 50.61500541865826, 46.83514304459095, 49.62672784924507, 48.105844259262085, 49.15603570640087, 49.358773827552795, 50.42574517428875, 50.988909155130386, 50.571972727775574, 51.342050805687904, 51.29637345671654, 51.38213865458965, 51.565889194607735, 51.646821051836014, 46.509025543928146, 44.800504222512245, 36.327669471502304, 33.9551717787981, 34.49245534837246, 33.524449691176414, 34.491011425852776, 35.01684620976448, 38.499936908483505, 34.706129282712936, 37.60521411895752, 40.20762227475643, 45.22016130387783, 45.06197199225426, 53.48595656454563, 40.66683903336525, 32.2637989372015, 54.18896824121475, 50.8049002289772, 49.36796173453331, 47.4842394143343, 47.52978757023811, 44.301514998078346, 40.86921997368336, 36.564001590013504, 35.948776602745056, 36.46313980221748, 38.90315607190132, 37.9400597512722, 40.5395382642746, 41.16859830915928, 47.396350130438805, 48.26705440878868, 51.673206835985184, 49.92039509117603, 48.301959335803986, 50.35732224583626, 49.60180498659611, 47.47812934219837, 48.17963629961014, 47.28293001651764, 46.24696880578995, 41.48208528757095, 42.00415067374706, 44.27532680332661, 45.13895206153393, 50.699041709303856, 51.6256295889616, 50.12690261006355, 44.76295843720436, 37.970693707466125, 41.656214743852615, 41.14624410867691, 44.588980972766876, 47.431543841958046, 49.443117901682854, 52.31109760701656, 54.85483691096306, 45.22312134504318, 36.0107246786356, 16.14974521100521, 17.035825364291668, 13.59724072739482, 21.282426193356514, 13.868575617671013, 1.551450218539685, 2.832960309460759, 4.199891360476613, 0.4514454334275797, 0.12157457284047268, 0.20707564777694643, 6.677924115210772, 19.886907376348972, 42.89820849895477, 35.275118350982666, 40.01490041613579, 52.77018517255783, 47.98216089606285, 44.643302857875824, 14.886176213622093, 2.7664258796721697, 0.12218467018101364, 0.1049949269508943, 0.12993083655601367, 0.047926635306794196, 0.0073057026565948036, 0.05486097747052554, 0.04669362744607497, 0.03423381771426648, 0.02201753817644203, 0.06693959046970122, 0.0552939315821277, 0.024932360283855814, 0.05318928240740206, 0.06090389266319107, 0.027424564541433938, 0.026561151789792348, 0.015824677611817606, 0.06462621968239546, 0.05700982525013387, 0.0659549460397102, 0.08130235961289145, 0.040540588670410216, 0.017701468896120787, 0.03798293626459781, 0.026772530291054863, 0.04852827587455977, 0.09206520044244826, 0.009346785027446458, 0.06859780813101679, 0.08827315978123806, 0.029219608259154484, 0.06064107219572179, 0.03800202059210278, 0.011636151048151078, 0.00396380749407399, 0.02616016940010013, 0.029352096462389454, 0.017023708096530754, 0.031037703083711676, 0.0025202834149240516, 0.013481927053362597, 0.027671970601659268, 0.1158436194236856, 0.030739285502932034, 0.042580173758324236, 0.04474944915273227, 0.03408783355553169, 3.5851477598771453, 23.64197038114071, 47.3809951543808, 54.62235018610954, 36.3809160143137, 18.67569576948881, 25.744097381830215, 33.576829880476, 20.48143297433853, 5.5988988652825356, 0.49842038308270276, 0.11317934637190774, 0.33902796101756394, 2.257427992299199, 4.738520057871938, 8.774701952934265, 8.622515369206667, 9.445905536413193, 10.902288537472486, 11.065093651413918, 19.6385945007205, 32.24455676972866, 42.162252590060234, 53.19208413362503, 51.70647405087948, 47.52599157392979, 45.8974027633667, 47.584679424762726, 49.24454055726528, 52.25175619125366, 50.89201435446739, 50.91829754412174, 51.28769472241402, 52.60564260184765, 53.448099195957184, 50.15753656625748, 51.72872945666313, 52.036520540714264, 51.77296668291092, 50.66322483122349, 51.90530978143215, 52.07594342529774, 50.615989565849304, 53.32526318728924, 53.25857676565647, 51.872221156954765, 52.8730608522892, 53.62798534333706, 49.55190606415272, 46.91758722066879, 37.774837017059326, 36.76400005817413, 37.95376181602478, 35.34154638648033, 36.50142274796963, 36.31775200366974, 39.31865997612476, 37.65847206115723, 40.405025482177734, 43.637519627809525, 47.069943845272064, 49.41688410937786, 55.97220495343208, 42.63636454939842, 36.281045973300934, 55.56531898677349, 51.82313919067383, 51.18214778602123, 49.08811815083027, 50.443319231271744, 45.18107660114765, 43.48548598587513, 38.01674723625183, 36.70182779431343, 37.96210616827011, 39.57825444638729, 39.252794310450554, 42.178872898221016, 44.403250738978386, 50.25363340973854, 50.32830320298672, 54.12961542606354, 50.30802749097347, 47.951397746801376, 52.778567522764206, 51.28826089203358, 48.60772892832756, 50.28468534350395, 48.976989313960075, 48.4137911349535, 42.82094344496727, 42.42457531392574, 45.44541321694851, 46.58898465335369, 52.46760740876198, 53.36837947368622, 52.38685414195061, 45.77262505888939, 39.18239548802376, 42.68950469791889, 44.96206775307655, 48.6060456186533, 50.28294883668423, 52.50176377594471, 54.77508299052715, 57.11223118007183, 48.61734241247177, 37.955600917339325, 18.31822045147419, 12.031491994857788, 13.161853440105915, 20.604255683720112, 9.026955217123032, 6.10098872333765, 4.340973515063524, 1.3247065292671323, 0.6806972553022206, 0.08271031023468822, 0.3661094047129154, 7.470912588760257, 21.14338595420122, 44.509462639689445, 43.63787680864334, 46.073781698942184, 55.8130618929863, 53.00814360380173, 48.68533596396446, 19.223025999963284, 3.8413150515407324, 0.09925103790010326, 0.049575067750993185, 0.12005978263914585, 0.016206764921662398, 0.03310491461888887, 0.0771901935513597, 0.05658694208250381, 0.04343366214015987, 0.03656738605059218, 0.06583781287190504, 0.05228285663179122, 0.032880949293030426, 0.07347886144998483, 0.024710960933589377, 0.07310436631087214, 0.0339145828911569, 0.07210398092865944, 0.023362762476608623, 0.04736899667477701, 0.040112391725415364, 0.0199033264289028, 0.0269598910381319, 0.08269189012935385, 0.10407294947071932, 0.09989738173317164, 0.17778822948457673, 0.17744454089552164, 0.10927540468401276, 0.1668577003874816, 0.12580868118675426, 0.09680117131210864, 0.1650480623356998, 0.15029476024210453, 0.1452666355180554, 0.09603226921171881, 0.2461311247316189, 0.1345435218536295, 0.1381842460250482, 0.09542843559756875, 0.08935490681324154, 0.10439492281875573, 0.1158622992807068, 0.20670709724072367, 0.14408531453227624, 0.15288688911823556, 0.12780268356436864, 0.11339895529090427, 4.150696350261569, 29.220065362751484, 54.68794226646423, 62.229211404919624, 44.12638999521732, 27.66918808221817, 36.743788942694664, 39.63697649538517, 23.63549552857876, 6.7909519001841545, 0.8475702290888876, 0.21333924058126286, 1.2608219822868705, 4.9149474408477545, 20.57919602841139, 17.039247080683708, 17.640321627259254, 17.589803338050842, 15.088070780038834, 20.720863826572895, 26.184862330555916, 40.755750462412834, 46.91297806799412, 56.23118385672569, 55.15376307070255, 50.79247109591961, 49.907027408480644, 49.93235684931278, 51.198536306619644, 53.01473245024681, 50.9966379404068, 50.62939144670963, 53.12441736459732, 54.483737424016, 55.679776445031166, 52.06487461924553, 55.243700444698334, 54.387477189302444, 54.683390110731125, 53.475377932190895, 55.090523064136505, 53.765553161501884, 53.59957046806812, 56.290251687169075, 55.40789343416691, 55.127970054745674, 56.11539267003536, 55.45001417398453, 51.06102928519249, 50.04493720829487, 38.745084553956985, 37.21692435443401, 39.33314099907875, 36.49244002997875, 37.555148005485535, 38.653270080685616, 40.59023894369602, 39.29085686802864, 42.71733060479164, 45.93348182737827, 49.89237539470196, 52.19496063888073, 56.43307842314243, 45.94828583300114, 39.78097356855869, 55.582429468631744, 54.49610196053982, 54.04078759253025, 51.20031081140041, 53.18612605333328, 47.92202532291412, 44.44110810756683, 40.013175308704376, 40.30821047723293, 39.07925382256508, 42.566813081502914, 42.285289987921715, 44.318861067295074, 45.89498609304428, 52.83430673182011, 53.291859179735184, 56.570532247424126, 51.09317556023598, 48.49223792552948, 53.344547152519226, 53.48965376615524, 51.441248282790184, 54.080100283026695, 51.39984950423241, 50.27422450482845, 45.98413310945034, 46.11287020146847, 48.97768847644329, 48.526405692100525, 54.30342189967632, 55.92354476451874, 53.79426062107086, 51.2192489951849, 42.9146084189415, 46.05031415820122, 46.21821574866772, 50.096891820430756, 52.23190985620022, 55.47976277768612, 57.639213502407074, 61.24762527644634, 49.77517068386078, 40.70894077420235, 21.846200041472912, 20.79639047384262, 21.586685366928577, 31.630348227918148, 28.33865325897932, 9.901222754269838, 8.613223917782307, 7.676440235227346, 1.671820634510368, 0.2109787063091062, 0.7029845437500626, 9.02065610513091, 25.88179249316454, 53.27002555131912, 48.35277400910854, 53.694903552532196, 62.540524899959564, 60.48074282705784, 59.305579885840416, 23.989028558135033, 5.084637310355902, 0.15737977693788707, 0.1225360919488594, 0.23007033654721454, 0.18955780105898157, 0.14974899968365207, 0.22170116688357666, 0.1652002619812265, 0.13521764427423477, 0.16477645112900063, 0.12305493481107987, 0.17134496272774413, 0.11986608209554106, 0.14971762167988345, 0.12627724354388192, 0.19292776007205248, 0.20656905777286738, 0.22863273712573573, 0.10206159568042494, 0.1585385069483891, 0.13056029652943835, 0.14669430500362068, 0.0841787904209923, 0.20172268501482904], [0.04749037492729258, 0.038798304231022485, 0.046019813016755506, 0.07397553636110388, 0.02354281306907069, 0.053022911451989785, 0.034891854083980434, 0.031395366313518025, 0.041167621820932254, 0.08328299591084942, 0.04181274111033417, 0.03134925296762958, 0.015759184934722725, 0.023463811448891647, 0.03334674715006258, 0.0342875937349163, 0.03287109357188456, 0.033456892997492105, 0.043323078425601125, 0.007731130926913465, 0.10124830572749488, 0.026385678393126, 0.04875935468589887, 0.022448644340329338, 1.440175564493984, 12.000416312366724, 40.2617921680212, 45.20943447947502, 37.60649845004082, 29.534166008234024, 26.151055544614792, 27.300974540412426, 23.45577847212553, 6.4719699416309595, 0.5671951489057392, 0.02824742263328517, 0.2692088152980432, 1.3534683734178543, 3.347981348633766, 5.46925694681704, 5.698050269857049, 12.523345202207565, 20.272242799401283, 9.658633321523666, 20.72619304060936, 34.23955611884594, 40.499275624752045, 52.133567333221436, 48.01779918372631, 46.64716713130474, 44.641862735152245, 45.36967188119888, 47.944459319114685, 53.724462166428566, 50.218272507190704, 50.61497122049332, 52.39596985280514, 47.52450205385685, 41.86200030148029, 44.75533604621887, 43.78195367753506, 43.432083651423454, 43.846668004989624, 45.33895052969456, 45.252288579940796, 45.70921026170254, 45.362117886543274, 45.45786514878273, 46.55818350613117, 45.96901372075081, 49.09684628248215, 47.51046560704708, 45.1775997877121, 41.20837077498436, 35.14802277088165, 34.011674746870995, 35.08442938327789, 34.78719413280487, 34.07306805253029, 34.212858751416206, 34.051413014531136, 34.92378920316696, 35.69388248026371, 37.874342277646065, 43.759648874402046, 45.30818738043308, 54.75978881120682, 42.15417422354221, 31.38986673206091, 51.17845058441162, 46.847879961133, 52.206850200891495, 51.16593025624752, 49.633290097117424, 47.02344574034214, 42.446914315223694, 36.96897625923157, 36.63194194436073, 37.33075864613056, 38.97395767271519, 37.91053533554077, 37.862388119101524, 40.78034274280071, 44.55955155193806, 46.31215810775757, 52.006312161684036, 50.83098962903023, 49.97226610779762, 48.97817485034466, 52.19077326357365, 49.38360549509525, 49.853245094418526, 46.16793304681778, 45.0328503549099, 47.68383890390396, 45.30407600104809, 49.87986646592617, 50.850307792425156, 50.739353746175766, 52.34867379069328, 51.510108187794685, 49.41285252571106, 39.070024117827415, 39.255324974656105, 41.97474405169487, 44.18224699795246, 44.82460632920265, 48.1990722566843, 51.81065686047077, 51.160162165760994, 50.66034458577633, 37.84510284662247, 18.949763663113117, 12.698589898645878, 7.84281050786376, 14.06533095985651, 6.996878050267696, 5.367570128291845, 2.9389900574460626, 0.7158954197075218, 0.3037698904518038, 0.042934990851790644, 0.4630586790153757, 5.107466010376811, 25.753942653536797, 42.47045785188675, 32.76182681322098, 40.24425990879536, 51.1515936255455, 47.046217918395996, 40.80889821052551, 19.868446066975594, 1.8856940581463277, 0.06238693749764934, 0.0356245171133196, 0.04604894231306389, 0.05445558672363404, 0.1076586582348682, 0.05169638185179792, 0.11821955326013267, 0.02337640500627458, 0.034225468552904204, 0.016099758358905092, 0.022294019727269188, 0.022595309419557452, 0.024687126860953867, 0.02866902188543463, 0.029254370456328616, 0.04935905453749001, 0.02561315461207414, 0.04534983178018592, 0.0773736895644106, 0.01896740770462202, 0.06763818149920553, 0.02456292659189785, 0.05554388691962231, 0.04226550314342603, 0.029847658151993528, 0.021420823613880202, 0.03992503283370752, 0.012733385774481576, 0.03456117905443534, 0.012448892739485018, 0.030031658825464547, 0.02231397793366341, 0.08086857429589145, 0.056342259704251774, 0.03420596491196193, 0.05446007300633937, 0.046685393317602575, 0.09979991547879763, 0.061825213342672214, 0.027518498172867112, 0.010420007565699052, 0.008564909257984255, 0.030449454570771195, 0.04216924287902657, 0.05305747326929122, 0.014811565324635012, 0.05082264768134337, 1.5321560413576663, 16.403607688844204, 46.37297764420509, 51.639574840664864, 40.04000186920166, 32.3269097507, 33.57428401708603, 34.552598521113396, 25.552885942161083, 7.912824125960469, 0.5909871566109359, 0.034154092500102706, 0.2097217901609838, 1.4756506984122097, 5.904212957248092, 6.642439719289541, 9.489459749311209, 8.180028162896633, 9.387352578341961, 11.843075305223465, 21.570939011871815, 32.78517656028271, 44.55450922250748, 52.753363475203514, 52.40688666701317, 47.6072958111763, 45.505563989281654, 46.25384263694286, 51.07687063515186, 53.66460397839546, 50.49999698996544, 50.70046663284302, 53.61821986734867, 49.171481877565384, 45.98574802279472, 46.08464531600475, 45.90897314250469, 45.50352729856968, 48.06797929108143, 49.028499349951744, 48.69258977472782, 48.54023315012455, 49.153467044234276, 48.4017039835453, 50.28955668210983, 49.01653379201889, 51.99333965778351, 49.97924633324146, 48.984543308615685, 42.323937714099884, 37.45700687170029, 35.19479066133499, 36.24994844198227, 35.59345006942749, 35.39076894521713, 35.44624596834183, 36.77188463509083, 36.48717351257801, 36.65645822882652, 38.4531956166029, 46.08201205730438, 47.46515303850174, 56.02441415190697, 44.273928478360176, 33.77599239349365, 51.25001594424248, 49.08298842608929, 54.4099035859108, 52.087620198726654, 52.33300723135471, 49.004644230008125, 43.42889562249184, 38.89813654124737, 39.19971115887165, 39.62822936475277, 41.50974400341511, 40.29224373400211, 40.06037637591362, 41.54398776590824, 47.01456941664219, 48.73022675514221, 53.33203822374344, 51.003074795007706, 48.523172065615654, 49.75333325564861, 53.32621693611145, 52.173089012503624, 52.155777141451836, 49.335500076413155, 47.75139547884464, 50.77117703855038, 47.4193274974823, 51.61135755479336, 52.40858897566795, 53.8961635529995, 53.167708441615105, 53.80376771092415, 50.6573199480772, 39.90856312215328, 41.126599162817, 44.40049208700657, 46.226814687252045, 47.36340209841728, 50.80415926873684, 53.909975811839104, 56.657114401459694, 52.0659651607275, 36.65920548141003, 17.202619314193726, 14.373830705881119, 11.240674629807472, 18.755664378404617, 13.321708962321281, 5.964493872597814, 3.9573368383571506, 1.941068961750716, 0.11128347818157636, 0.06515586821478792, 0.37388743890915066, 6.709808679297566, 27.793027237057686, 47.97639660537243, 35.814419612288475, 42.31802523136139, 57.01568216085434, 52.28905498981476, 49.44717988371849, 23.445935100317, 3.0532102659344673, 0.03380134599865414, 0.010698293463065056, 0.015539466548943892, 0.05671430204529315, 0.10036043735453859, 0.018115511229552794, 0.0632647423481103, 0.0118864802425378, 0.10566130134975538, 0.04013074874819722, 0.031125098394113593, 0.03021002845343901, 0.048649193995515816, 0.032671986482455395, 0.01879866929812124, 0.046907540381653234, 0.02818577613652451, 0.07696499626035802, 0.04573862439428922, 0.057672529728733934, 0.0938089877308812, 0.0346513759723166, 0.04129878529056441, 0.16378847445594147, 0.09554285250487737, 0.14728008216479793, 0.20405994553584605, 0.08086410656687804, 0.1225680933566764, 0.1347341647488065, 0.10265045275446028, 0.1376425227499567, 0.20997238374548033, 0.19338495272677392, 0.1379906345391646, 0.177426224690862, 0.1919584855204448, 0.18503371335100383, 0.06889863027026877, 0.16965427610557526, 0.14716890844283625, 0.13174756953958422, 0.15771914622746408, 0.14501498808385804, 0.16703574161510915, 0.13024797110119835, 0.13014954747632146, 2.5948391994461417, 19.873564392328262, 53.794074431061745, 58.10659222304821, 50.05629479885101, 41.650613844394684, 38.59861001372337, 38.44001032412052, 30.91062694787979, 9.42563647404313, 0.9803410421591252, 0.1036895856668707, 0.9817584254778922, 2.6129039051011205, 10.595447402447462, 13.47741985693574, 15.145486649125814, 29.618016108870506, 34.520133063197136, 16.727819591760635, 25.916879810392857, 37.62185342609882, 44.485151544213295, 56.27134770154953, 53.1713030487299, 52.04220503568649, 48.494350612163544, 49.540233090519905, 53.22441279888153, 56.478991359472275, 50.33975958824158, 50.91828994452953, 56.79716728627682, 53.1733625382185, 46.54254734516144, 49.47957694530487, 47.28019416332245, 47.74420626461506, 48.96871715784073, 50.339535400271416, 50.24243541061878, 51.54309421777725, 51.6395216435194, 50.53725019097328, 51.91690295934677, 50.18337517976761, 53.387610241770744, 53.081776052713394, 49.84907291829586, 44.118691608309746, 38.01478274166584, 36.99823088943958, 38.00281718373299, 38.298935294151306, 36.46111071109772, 38.23737099766731, 36.70826084911823, 38.28128144145012, 39.65438716113567, 41.72447428107262, 46.82356506586075, 49.778544902801514, 58.13635602593422, 47.15834990143776, 36.85883916914463, 52.798778638243675, 49.64796490967274, 55.69432586431503, 54.514766559004784, 55.06647415459156, 49.461717903614044, 46.07587158679962, 40.900629088282585, 40.33737011253834, 40.66946469247341, 42.234251126646996, 41.156039983034134, 42.20425173640251, 46.015470027923584, 49.80742335319519, 50.86638852953911, 55.079667046666145, 53.56735959649086, 49.32657055556774, 49.556602612137794, 54.0184485912323, 53.77277657389641, 55.11572331190109, 51.082961708307266, 48.72562900185585, 52.44276814162731, 51.473877131938934, 57.165546119213104, 55.526006296277046, 54.94321256875992, 55.62220573425293, 57.00117073953152, 54.136037081480026, 42.37029902637005, 43.012791350483894, 46.013532131910324, 48.545708656311035, 49.08945567905903, 53.78648243844509, 55.4040290415287, 57.33424186706543, 57.392979115247726, 40.21954603493214, 25.838104337453842, 19.258193112909794, 14.184206631034613, 21.99930712580681, 14.447207618504763, 13.174409866333008, 14.400002751499414, 3.679590504616499, 1.0593016957864165, 0.24888251849915832, 0.8749379043001682, 7.720240484923124, 32.898212894797325, 50.99298633635044, 44.75241780281067, 51.98726378381252, 63.487947061657906, 61.356257647275925, 54.93176378309727, 29.33501299470663, 3.904965673573315, 0.20373170846141875, 0.06423946426366456, 0.14090491487877443, 0.16449897695565596, 0.2722463069949299, 0.1738240328268148, 0.25053388613741845, 0.05495646590134129, 0.22149701690068468, 0.10191720342845656, 0.12246749523910694, 0.15726406127214432, 0.044415582888177596, 0.10240823801723309, 0.07522014027927071, 0.1376410384546034, 0.13384625926846638, 0.1111331710126251, 0.15069079992827028, 0.22639121365500614, 0.14086210780078545, 0.08369847244466655, 0.18238754128105938], [0.034906901128124446, 0.09323713326011784, 0.04418535754666664, 0.03194969496689737, 0.010030693592852913, 0.0025562615746821393, 0.012093006025679642, 0.033899513582582586, 0.09343594720121473, 0.04550889629172161, 0.026822174404514953, 0.016062842078099493, 0.057858827349264175, 0.02711298868234735, 0.04042182277771644, 0.037967759344610386, 0.05456605911604129, 0.022816293167124968, 0.08705795975401998, 0.06026924507750664, 0.10735817748354748, 0.05139336295542307, 0.05785899062175304, 0.03437945677433163, 0.9761980175971985, 12.775612715631723, 34.79567527770996, 48.05490419268608, 34.97699394822121, 20.86382545530796, 15.892344173043966, 24.509834311902523, 21.927340887486935, 9.141229335218668, 0.9920270775910467, 0.16868776234332472, 0.07615514245117083, 2.051530103199184, 2.225920083001256, 4.421864999458194, 7.591198459267616, 2.9454722721129656, 2.7418248122557998, 11.432348694652319, 21.093295142054558, 30.06368849426508, 43.79215992987156, 49.21634986996651, 48.44789430499077, 43.627640157938, 46.13460123538971, 47.16586969792843, 51.54945507645607, 52.015503868460655, 51.04287005960941, 51.963127478957176, 46.430742144584656, 41.50393411517143, 41.62884101271629, 39.01591882109642, 38.627689853310585, 37.25004717707634, 38.12541380524635, 37.32360363006592, 39.04619559645653, 39.421417862176895, 39.45025831460953, 39.04777631163597, 40.18039293587208, 39.63778205215931, 41.1788197606802, 39.79320891201496, 36.15738920867443, 31.71273160725832, 34.39832299947739, 34.70546431839466, 34.9139591306448, 33.8237140327692, 36.520174741744995, 37.65602879226208, 39.9756371229887, 36.86216399073601, 41.75064727663994, 41.372119188308716, 44.733282029628754, 43.93658258020878, 52.51762792468071, 38.56585957109928, 27.117446288466454, 47.86866098642349, 45.966969430446625, 49.155705124139786, 48.51349018514156, 50.046134144067764, 48.995615914464, 44.6911308914423, 36.905603259801865, 39.18112255632877, 35.62292128801346, 35.9577327221632, 36.10781706869602, 37.79400698840618, 36.44865497946739, 41.4944726228714, 47.69615024328232, 49.956679344177246, 49.000133872032166, 49.84314143657684, 50.2523984760046, 50.70931255817413, 52.16667875647545, 50.92310808598995, 49.515827000141144, 50.674840807914734, 49.522507041692734, 51.27043604850769, 50.549428537487984, 55.731449872255325, 49.31227192282677, 49.83883626759052, 53.768847584724426, 47.66276143491268, 42.227400094270706, 38.61229307949543, 40.20291432738304, 45.73520086705685, 46.257813423871994, 49.192981123924255, 51.18665054440498, 56.02995045483112, 44.362551122903824, 38.29527609050274, 19.582688100636005, 10.449827816337347, 12.732927706092596, 23.38122647255659, 10.020714942365885, 2.1011796640232205, 2.060793056152761, 0.46073341160081327, 0.39362298615742475, 0.03017832204932347, 0.6162640533875674, 6.331072077155113, 18.391526117920876, 35.853789299726486, 30.509714260697365, 45.166834965348244, 56.33711077272892, 48.63525465130806, 34.87118862569332, 15.64665600657463, 1.735925569664687, 0.05562681450101081, 0.019330406976223458, 0.06590832432266325, 0.023950426548253745, 0.025783484925341327, 0.06419165511033498, 0.05121020461956505, 0.030680481431772932, 0.017907045657921117, 0.053880837876931764, 0.05164486196008511, 0.06401872728019953, 0.04786768651683815, 0.0060616650898737134, 0.03154123915010132, 0.024088237805699464, 0.07334361245739274, 0.06014948470692616, 0.0031336457413999597, 0.057023978006327525, 0.01473413056373829, 0.05011216002458241, 0.015592938289046288, 0.02586437160061905, 0.049018664794857614, 0.027278667585051153, 0.009024578830576502, 0.06734215363394469, 0.024309976688527968, 0.036606230059987865, 0.058414803570485674, 0.0677237288618926, 0.009476746217842447, 0.046571555285481736, 0.020746905283886008, 0.006222366037036409, 0.06638860519160517, 0.0649876233364921, 0.03297069721156731, 0.06226431985851377, 0.006942373129277257, 0.03586530692700762, 0.03664263982500415, 0.06974570278543979, 0.019064899934164714, 0.06308624098892324, 0.03727710558450781, 1.2585573038086295, 14.49240144342184, 40.364816039800644, 53.8980558514595, 43.507631197571754, 27.96722698956728, 19.144520312547684, 30.442091189324856, 27.111693397164345, 9.929166454821825, 1.0014171455986798, 0.12075880411430262, 0.35296896763611585, 1.7616794002242386, 5.217093452811241, 5.994980111718178, 7.349263541400433, 7.106846049427986, 8.998555541038513, 13.05164035409689, 24.101337231695652, 32.707596123218536, 44.468447640538216, 52.61616803705692, 51.44058711826801, 46.465111300349236, 46.438493728637695, 50.51400303840637, 54.47481170296669, 52.851747795939445, 50.793462842702866, 51.6809394210577, 50.079724341630936, 45.552043095231056, 44.76191349327564, 42.17205986380577, 40.21561324596405, 40.86707688868046, 40.13446480035782, 39.70018230378628, 41.49865239858627, 41.111415177583694, 41.30252592265606, 41.31191901862621, 44.391904547810555, 43.63830238580704, 45.54946683347225, 42.43580371141434, 38.73575985431671, 33.91508772969246, 36.587199345231056, 36.78275965154171, 36.642980352044106, 36.44339606165886, 37.71279774606228, 39.759177938103676, 40.844623893499374, 37.96245574951172, 42.20443032681942, 43.13367806375027, 46.63442261517048, 45.48256762325764, 55.47414667904377, 42.60542280972004, 30.339644886553288, 51.44944064319134, 48.396448865532875, 50.72228506207466, 50.26125580072403, 52.396353632211685, 51.259849816560745, 46.0126543790102, 38.539656177163124, 41.215442195534706, 36.86271496117115, 37.66541428864002, 37.63241305947304, 38.34535360336304, 38.50059047341347, 43.813704773783684, 49.846276268363, 51.55226692557335, 50.76705425977707, 50.712546184659004, 51.26179151237011, 51.074222177267075, 52.43119016289711, 51.07855014503002, 49.810068011283875, 53.27640540897846, 51.38744696974754, 51.856220215559006, 52.837194576859474, 55.08622169494629, 49.625530913472176, 52.5483188778162, 54.88732896745205, 49.44448582828045, 44.73650425672531, 40.3186447173357, 42.537493854761124, 46.912461295723915, 49.45734053850174, 50.31127631664276, 55.62125198543072, 55.303444638848305, 50.78778974711895, 37.66236685216427, 21.561386324465275, 15.913338046520948, 12.240467481315136, 19.82099801301956, 10.456554405391216, 5.000167842954397, 5.351519789546728, 1.9060556218028069, 0.3586313466075808, 0.03031556185305817, 0.66764697432518, 6.810703240334988, 23.398352153599262, 43.23991276323795, 40.74995577335358, 50.924232825636864, 60.56033335626125, 53.240949511528015, 41.407267302274704, 20.9168117120862, 2.172810807824135, 0.05331570726411883, 0.01066529386662296, 0.05266272492008284, 0.02918382375355577, 0.042936838799505495, 0.06855759856989607, 0.025676335499156266, 0.03413018421269953, 0.05616337242827285, 0.018093729195243213, 0.017640059886616655, 0.059217833331786096, 0.022703791000822093, 0.06228202750207856, 0.03325687306642067, 0.044529628721647896, 0.02754634726443328, 0.034183021416538395, 0.05571062152739614, 0.039419040258508176, 0.0926873651042115, 0.05783773922303226, 0.031297284076572396, 0.12053294631186873, 0.20429072377737612, 0.13140646362444386, 0.10251161176711321, 0.196475789998658, 0.08412555616814643, 0.11886674314155243, 0.1827138487715274, 0.2409820002503693, 0.08835890752379782, 0.06043083289114293, 0.12077286781277508, 0.13546311703976244, 0.15676443261327222, 0.13383862999035046, 0.15870431758230552, 0.15454238309757784, 0.0974570146354381, 0.21589567215414718, 0.1794192919624038, 0.17993938905419782, 0.05126365038449876, 0.14369859622092918, 0.11328652733936906, 1.4640635764226317, 17.833883240818977, 47.89371304214001, 61.294328570365906, 49.91128318011761, 32.17091292142868, 25.162975564599037, 36.20216220617294, 29.61362924426794, 11.676304154098034, 1.7538140597753227, 0.3324500983580947, 0.8247984072659165, 5.460489392280579, 7.554127173498273, 12.199320439249277, 20.28912529349327, 10.952961668372154, 9.77350590750575, 16.37224607169628, 24.78921052068472, 34.321323931217194, 47.02486306428909, 54.058095663785934, 54.39034603536129, 48.72591778635979, 51.14951513707638, 52.613272592425346, 56.750087812542915, 53.47927652299404, 51.28707155585289, 54.128053709864616, 52.40444719791412, 46.938273310661316, 46.57635413110256, 44.51797418296337, 42.38078646361828, 41.70651264488697, 42.07109548151493, 42.254659831523895, 43.443661630153656, 42.775311693549156, 42.712729051709175, 42.44964636862278, 45.993347615003586, 43.69794778525829, 45.94963476061821, 43.2783704996109, 40.73597252368927, 35.01989744603634, 38.630931079387665, 39.03067722916603, 38.028705194592476, 37.44772017002106, 40.376872792840004, 41.79432213306427, 44.04333405196667, 40.72658322751522, 45.98037511110306, 46.3385970890522, 48.93162354826927, 48.25925722718239, 56.21440775692463, 43.36955800652504, 33.041700795292854, 50.91442935168743, 51.85835190117359, 51.76330380141735, 51.978132873773575, 54.71894480288029, 53.27749975025654, 50.30414789915085, 41.296415850520134, 43.81424054503441, 38.75673472881317, 39.59499254822731, 40.29914416372776, 40.791913121938705, 41.60940885543823, 45.62484338879585, 51.614287197589874, 54.76048797369003, 51.76808014512062, 52.45013974606991, 52.219233736395836, 53.12613867223263, 53.25957231223583, 51.741671562194824, 52.37176135182381, 53.74829448759556, 53.04204158484936, 53.183796778321266, 53.90891566872597, 55.691609010100365, 50.67717768251896, 51.62104703485966, 56.51938319206238, 53.264702036976814, 46.11948184669018, 43.60390283167362, 42.34849199652672, 51.215225011110306, 51.74775503575802, 53.43737617135048, 56.38039045035839, 60.850622579455376, 51.48246847093105, 42.12588854134083, 25.329203344881535, 16.352319940924644, 20.46326044946909, 32.045660242438316, 21.03631529957056, 11.195990927517414, 8.086121901869774, 4.0912732388824224, 1.0531187150627375, 0.25344797351863235, 1.0705354367382824, 8.659499734640121, 24.600028172135353, 48.89081373810768, 43.64494442939758, 57.058091685175896, 67.4655470252037, 60.83394147455692, 49.9437752366066, 24.053285010159016, 3.6781408824026585, 0.12974080222193152, 0.08664787863381207, 0.1763962721452117, 0.14924279559636489, 0.1069447047484573, 0.22354393440764397, 0.11736122236470692, 0.16588904923992231, 0.1451748318504542, 0.13132530235452577, 0.10958640166791156, 0.1832972510601394, 0.16048931633122265, 0.11383507837308571, 0.1869991430430673, 0.07893950241850689, 0.14198116259649396, 0.11354975969879888, 0.13112821761751547, 0.20627429155865684, 0.1989594762562774, 0.1804010642808862, 0.13547980051953346], [0.03532308270223439, 0.0677605097007472, 0.09546997360303067, 0.02344027609069599, 0.05299201584421098, 0.0872701323532965, 0.0312773425685009, 0.036579572115442716, 0.07764843263430521, 0.025295474588347133, 0.05691652244422585, 0.03976721884100698, 0.026102853335032705, 0.011804702062363504, 0.05061636402388103, 0.036192367697367445, 0.04669763133279048, 0.07696785352891311, 0.06892612684168853, 0.07341013115365058, 0.041052117667277344, 0.08129218476824462, 0.024292898015119135, 0.05195010358875152, 0.3092678094981238, 8.122046124190092, 31.549995839595795, 47.43987679481506, 33.22260148823261, 23.542571514844894, 27.33177188783884, 30.17467863857746, 32.62085057795048, 13.052865788340569, 0.9466324571985751, 0.058467833732720464, 0.20729164243675768, 0.9462726640049368, 5.843828022480011, 5.1902393437922, 4.202476646751165, 1.5108288545161486, 6.240251725539565, 12.80751770362258, 20.15239343047142, 28.928799591958523, 39.638944789767265, 48.25239859521389, 48.03508445620537, 46.92911960184574, 48.15947838127613, 49.352162182331085, 51.95741258561611, 49.849335104227066, 51.12692154943943, 50.98475217819214, 44.99971233308315, 41.64087116718292, 38.244096636772156, 35.42138770222664, 35.47874942421913, 34.06710237264633, 33.872841596603394, 35.10076090693474, 36.321555599570274, 34.30346488952637, 32.94619672000408, 34.07667025923729, 34.36054542660713, 33.478228971362114, 34.238951951265335, 34.62372690439224, 36.82662449777126, 44.89202231168747, 38.68602432310581, 34.18833486735821, 34.88184705376625, 36.12327083945274, 43.05566444993019, 43.45588177442551, 45.1628527790308, 44.58490379154682, 44.9832022190094, 47.32500895857811, 49.34386342763901, 49.33594845235348, 54.11690130829811, 41.33056841790676, 27.149966843426228, 47.967843264341354, 51.198255121707916, 50.858864933252335, 50.246827974915504, 49.15627509355545, 46.53319604694843, 39.317854419350624, 36.03236831724644, 35.388378873467445, 35.94405725598335, 37.376002818346024, 38.78275193274021, 38.07328060269356, 35.36708861589432, 35.93855895102024, 43.56638744473457, 46.92349970340729, 45.585048124194145, 46.334554105997086, 47.77909979224205, 48.547604754567146, 53.08008134365082, 49.37629848718643, 51.198255121707916, 51.817245706915855, 51.94882124662399, 51.99017822742462, 52.61155508458614, 46.39455668628216, 52.38576740026474, 49.99969683587551, 53.21194186806679, 51.609237268567085, 45.36133512854576, 41.54167748987675, 40.64487621188164, 44.51068237423897, 45.778537541627884, 50.49946501851082, 55.015917867422104, 53.87835010886192, 49.045993611216545, 31.62675742059946, 17.374544888734818, 17.221095822751522, 11.859450526535511, 17.56557773798704, 11.212421245872974, 5.0588214956223965, 1.4305613678880036, 1.7166069312952459, 0.16496753931278363, 0.2951631444739178, 0.5667576973792166, 7.841765088960528, 23.4865815192461, 38.49954932928085, 25.881378315389156, 42.55489692091942, 50.752926617860794, 45.28566598892212, 35.81191934645176, 12.755935471504927, 1.824938643258065, 0.033424130888306536, 0.13316774333361536, 0.060138794069644064, 0.04715080896858126, 0.03094409970799461, 0.031088644100236706, 0.1161052190582268, 0.083548937109299, 0.05462588735099416, 0.058405382005730644, 0.03570957465854008, 0.12634071201318875, 0.05165176393347792, 0.09387209254782647, 0.07437864871462807, 0.08782142191193998, 0.05286696396069601, 0.03509070513246115, 0.0321678863838315, 0.04723085330624599, 0.04745256250316743, 0.09042024496011436, 0.022193466138560325, 0.0036932967532266048, 0.021966398635413498, 0.047646511666243896, 0.00937894228627556, 0.008476478651573416, 0.05693509468983393, 0.031530860214843415, 0.027279751120659057, 0.06632835022173822, 0.0636963160650339, 0.05523136853298638, 0.08036662271479145, 0.022986016774666496, 0.058955335698556155, 0.026798867256729864, 0.04159206720942166, 0.013246101279946743, 0.07035840506432578, 0.049050350789912045, 0.006217977625055937, 0.03059518083318835, 0.04781971038028132, 0.058632776053855196, 0.0058241435090167215, 0.6915113562718034, 10.281574744731188, 38.79488468170166, 53.74521665275097, 39.14440132677555, 25.56916806846857, 29.25247572362423, 35.996186658740044, 34.17294189333916, 14.042393490672112, 1.676678080111742, 0.05590950597252231, 0.17291839001700282, 1.0912315011955798, 4.5464356150478125, 3.920676405541599, 8.213741853833199, 9.0780358761549, 10.442393515259027, 14.872676488012075, 20.331736207008362, 31.200881972908974, 41.846265345811844, 52.47471682727337, 49.71548728644848, 49.47491839528084, 50.12065954506397, 52.11662404239178, 51.64743281900883, 49.5962268859148, 49.46217007935047, 51.38651221990585, 47.55428105592728, 44.29309085011482, 41.19301959872246, 38.1143905967474, 37.3325065523386, 36.53643026947975, 35.77471174299717, 36.28643408417702, 36.48665674030781, 36.917386427521706, 35.299410447478294, 36.11610822379589, 37.25029036402702, 37.06656642258167, 35.148942321538925, 36.54343329370022, 37.70787701010704, 43.653444573283195, 39.96436692774296, 35.49826517701149, 36.73528119921684, 37.40851007401943, 43.5533731430769, 45.0907326489687, 46.94426938891411, 44.70353342592716, 46.53090476989746, 47.6273587346077, 49.57407407462597, 49.558266922831535, 54.20783042907715, 41.83681905269623, 29.26538933068514, 49.28295649588108, 52.01731637120247, 51.44733175635338, 51.12659476697445, 50.03415338695049, 49.47503998875618, 41.878715604543686, 38.82819749414921, 37.25951626896858, 38.030111119151115, 38.55786480009556, 40.56385315954685, 40.19208110868931, 37.51898914575577, 40.02490907907486, 45.58817535638809, 49.45914924144745, 48.21906678378582, 48.90149116516113, 49.955683797597885, 52.1956218034029, 53.273114785552025, 51.25726595520973, 52.078667879104614, 52.74156130850315, 52.85828724503517, 54.18703034520149, 51.20811179280281, 49.49199087917805, 52.11150951683521, 50.42400486767292, 53.103016912937164, 53.601827546954155, 45.95793351531029, 42.93465614318848, 42.30115793645382, 47.820008397102356, 47.91141629219055, 52.86341316998005, 54.7122647613287, 56.222516521811485, 51.38428173959255, 36.472282111644745, 19.999962709844112, 19.892185293138027, 9.909217525273561, 9.7131366468966, 10.837946590036154, 5.240977546200156, 4.588873162865639, 2.4187454860657454, 0.3258508024737239, 0.11501989487442188, 0.647458479506895, 8.638863041996956, 24.959040507674217, 40.43697036802769, 28.538594730198383, 48.99340063333511, 56.08556047081947, 50.67247353494167, 42.51659117639065, 16.969984397292137, 2.527470476925373, 0.017711703112581745, 0.036141322780167684, 0.10475545073859394, 0.05191950484004337, 0.10099576771608554, 0.03365303149621468, 0.05873048350622412, 0.060712388876709156, 0.06602668203413486, 0.034027560031972826, 0.02272220554004889, 0.05125507486809511, 0.0550799592747353, 0.06046873066225089, 0.07457911022356711, 0.05777798520284705, 0.026755503567983396, 0.05437078150862362, 0.01045066754159052, 0.03831601956335362, 0.0849422748433426, 0.03329332736029755, 0.06941051920875907, 0.2274163719266653, 0.218555306782946, 0.18694504047743976, 0.13713858963456005, 0.12655321857891977, 0.19001857086550444, 0.1575873704859987, 0.14774267765460536, 0.18037369387457147, 0.16047481476562098, 0.13616253185318783, 0.20450809883186594, 0.10107646143296733, 0.1607836372568272, 0.13674379675649107, 0.1520958635956049, 0.11227630850044079, 0.15515179024077952, 0.11106321617262438, 0.11764283772208728, 0.09835929551627487, 0.18180581624619663, 0.1067973067983985, 0.10299976682290435, 0.7352071709465235, 12.35354371368885, 43.665269538760185, 63.01143743097782, 44.479638040065765, 34.19286422431469, 36.87174707651138, 42.416550144553185, 40.88534630835056, 17.151852138340473, 2.025698139332235, 0.3867504314985126, 0.4685768735362217, 2.827071575447917, 12.306844219565392, 14.93894113227725, 14.393847081810236, 11.99706869199872, 11.339482627809048, 14.157816097140312, 23.923428878188133, 31.02045815438032, 43.34933929145336, 52.92007572948933, 54.39511097967625, 50.671291798353195, 53.81172068417072, 53.956291526556015, 52.00282394886017, 50.70170536637306, 51.83673106133938, 54.32608388364315, 50.46398252248764, 45.60840927064419, 42.85526320338249, 39.153794422745705, 39.65679243206978, 38.15140441060066, 38.17143313586712, 39.07814808189869, 39.836036413908005, 37.964047864079475, 37.371123880147934, 38.133750557899475, 39.65695962309837, 37.90141202509403, 38.29502530395985, 39.0243885666132, 40.94175048172474, 48.16068671643734, 42.224835231900215, 37.576586455106735, 38.510629534721375, 39.59880754351616, 46.961125284433365, 47.45284169912338, 50.81143967807293, 48.990478590130806, 49.597009643912315, 51.41815312206745, 52.81150795519352, 53.42245437204838, 55.308547765016556, 43.415679931640625, 32.424579709768295, 49.50912036001682, 53.61086346209049, 54.13903512060642, 52.719784677028656, 53.741774037480354, 52.20879189670086, 42.5457926094532, 39.97018441557884, 38.4345044195652, 39.6936010569334, 40.302013009786606, 41.37501463294029, 41.845493987202644, 38.79744954407215, 40.78357636928558, 47.76746481657028, 51.32740259170532, 50.9172298014164, 51.92202128469944, 52.279114723205566, 53.81283022463322, 56.230895072221756, 50.8406563103199, 53.08952383697033, 53.92606794834137, 53.36972840130329, 54.00063514709473, 53.768623396754265, 47.52137862145901, 52.96229526400566, 51.17727644741535, 55.74351042509079, 55.55124074220657, 49.184929355978966, 45.495901107788086, 43.952796310186386, 51.94077707827091, 50.68482667207718, 56.74165226519108, 59.99863229691982, 58.833550214767456, 52.72313989698887, 35.18366485834122, 20.831715278327465, 23.493434451520443, 17.480276115238667, 28.387955613434315, 22.536353208124638, 12.477463614195585, 5.971780456602573, 4.709008941426873, 0.45747855969239026, 0.5503319506533444, 1.2026862893253565, 10.329070296138525, 32.31604613363743, 46.91879555583, 39.073075354099274, 52.433793023228645, 62.10926704108715, 57.78284199535847, 49.56725724041462, 21.6258080676198, 3.2797576719895005, 0.21592117234831676, 0.2456968347541988, 0.3476842527743429, 0.19135259615723044, 0.18690040771616623, 0.14917995053110644, 0.22815682750660926, 0.17816055013099685, 0.1465029496466741, 0.13704524229979143, 0.08709365705726668, 0.18149013631045818, 0.12762643833411857, 0.23749415850033984, 0.2365297672804445, 0.21161361364647746, 0.1515216045663692, 0.14781199424760416, 0.11126859069918282, 0.11805416565039195, 0.16336319415131584, 0.11864306725328788, 0.12127547990530729], [0.04009263946500141, 0.021546133393712807, 0.001487267190896091, 0.01625917539058719, 0.012918404117954196, 0.05624316443572752, 0.07623773606610484, 0.02174004173866706, 0.0356454530992778, 0.02789028632832924, 0.025864941198960878, 0.035268605352030136, 0.05096820510516409, 0.05709070079319645, 0.07034972193650901, 0.08996756456326693, 0.07165857357904315, 0.027567092147364747, 0.06504409335320815, 0.0897049333434552, 0.018430727322993334, 0.09191849268972874, 0.06905062211444601, 0.09031333116581663, 0.23714809503871948, 6.369406320154667, 28.047022707760334, 49.038344621658325, 39.68525290489197, 28.890273459255695, 17.246782444417477, 28.784376941621304, 31.21397417038679, 13.514073640108109, 3.5248145973309875, 0.035104227063129656, 0.18269146559759974, 0.8728566253557801, 3.213681117631495, 1.6528857755474746, 4.621022287756205, 8.742629773914814, 11.877791192382574, 15.807370282709599, 22.429647333920002, 28.380055837333202, 35.87633728981018, 47.993560284376144, 48.088908568024635, 49.46432076394558, 48.887815698981285, 52.990797534585, 48.727167919278145, 50.24952583014965, 50.82698464393616, 48.65702748298645, 44.90999534726143, 42.41154961287975, 37.230200842022896, 35.59523977339268, 36.17387652397156, 34.515656903386116, 34.54957388341427, 35.2486527711153, 36.34926751255989, 37.636904418468475, 35.17634645104408, 35.35759672522545, 35.78054063022137, 34.61426921188831, 36.78916610777378, 34.227024391293526, 35.92942424118519, 46.460008174180984, 38.03083688020706, 34.00024116039276, 35.208523124456406, 44.386793822050095, 51.54231145977974, 47.639233097434044, 50.17902821302414, 48.52118097245693, 52.71485634148121, 47.58102022111416, 50.17587058246136, 46.24906629323959, 49.12456579506397, 39.15175773203373, 24.905442483723164, 54.83185574412346, 51.0746743530035, 49.024015590548515, 46.65929228067398, 44.06563125550747, 40.779590383172035, 36.75615727901459, 35.471636205911636, 36.78410857915878, 39.581697061657906, 37.129244059324265, 36.2890787422657, 35.83655342459679, 33.58704753220081, 33.87800931930542, 36.228061616420746, 38.97702030837536, 42.93298423290253, 43.79926934838295, 45.41459307074547, 45.89502789080143, 48.737879544496536, 48.99658866226673, 49.88292910158634, 48.39486055076122, 47.739521116018295, 47.86606192588806, 52.21119336783886, 50.73139317333698, 50.392717346549034, 52.33291983604431, 50.32370924949646, 53.05866189301014, 48.934344202280045, 42.76465326547623, 39.33600224554539, 42.08418197929859, 47.2771505266428, 51.92836694419384, 53.250612393021584, 52.268908470869064, 43.953138291835785, 29.743090197443962, 21.94775339215994, 21.648517549037933, 11.343754548579454, 11.379627473652363, 4.280591430142522, 2.1149574872106314, 6.485415520146489, 1.17166000418365, 0.5131060013081878, 0.06706834567012265, 0.9448393096681684, 7.540705343708396, 25.929869413375854, 38.46842899918556, 33.70972394943237, 43.703617081046104, 45.62835440039635, 44.93861921131611, 34.62226778268814, 17.07321345806122, 0.654913738835603, 0.06854562772787176, 0.04245144453307148, 0.02238166365714278, 0.05763847999332938, 0.025526701829221565, 0.022830907910247333, 0.09887358159176074, 0.05034400695876684, 0.04837369764572941, 0.03541611091350205, 0.0305301464322838, 0.11901562538696453, 0.06934742181329057, 0.04369383314042352, 0.0559912201424595, 0.026943897755700164, 0.06994910319917835, 0.0641463247302454, 0.048997138801496476, 0.046096640144241974, 0.02781893253995804, 0.06382566498359665, 0.08207071994547732, 0.04539515844953712, 0.022489668408525176, 0.06460515753133222, 0.046517148439306766, 0.040064526911010034, 0.05971178827167023, 0.047446280223084614, 0.02119429045706056, 0.05886526494577993, 0.032871056464500725, 0.06782695418223739, 0.02720650300034322, 0.043140558336745016, 0.03590425483707804, 0.003310452684672782, 0.026103678974322975, 0.029456787524395622, 0.03105069808952976, 0.010900186389335431, 0.059187605656916276, 0.015962099241733085, 0.03012509892869275, 0.06324155765469186, 0.062300447607412934, 0.31713214062619954, 7.855463353917003, 33.018240854144096, 56.14527806639671, 43.8720316439867, 31.79131519049406, 25.359939895570278, 31.762959212064743, 39.37876135110855, 15.955345742404461, 3.3051524218171835, 0.09215736034093425, 0.23111692804377526, 0.5239155306480825, 4.387506293132901, 3.6462503811344504, 4.314870340749621, 9.651047978550196, 9.221969302743673, 16.52070790529251, 22.75218542665243, 31.048544347286224, 41.10110253095627, 49.63121920824051, 51.225511059165, 49.18866455554962, 50.228091180324554, 52.96225726604462, 49.786589071154594, 49.62277606129646, 51.76358878612518, 51.102101281285286, 46.98502600193024, 44.738255962729454, 39.54778388142586, 37.98968888819218, 37.707253843545914, 37.28582225739956, 36.73056945204735, 37.50187486410141, 37.69548587501049, 38.253493532538414, 36.229862719774246, 36.766188740730286, 37.0687323063612, 36.872769221663475, 37.44223706424236, 35.914475843310356, 37.84336254000664, 48.00123207271099, 40.27632638812065, 35.254356265068054, 37.16803997755051, 45.920003950595856, 53.391717821359634, 50.917647778987885, 52.79711052775383, 50.710273906588554, 55.53164519369602, 49.9539814889431, 52.47738428413868, 50.30901923775673, 49.53219652175903, 39.63303990662098, 28.974953815340996, 54.97152104973793, 52.25173719227314, 52.239144667983055, 50.35687766969204, 46.94616548717022, 42.945793345570564, 39.74011816084385, 38.682406917214394, 38.84552076458931, 40.93962259590626, 38.172500878572464, 38.14138054847717, 36.83187581598759, 36.30943804979324, 37.42133818566799, 38.94813805818558, 40.465833619236946, 44.228874295949936, 45.765211656689644, 46.52722656726837, 48.94220598042011, 51.60602644085884, 51.3543963432312, 51.94311775267124, 50.408136919140816, 50.974329337477684, 50.825662314891815, 54.96542997658253, 51.387629359960556, 52.52382919192314, 52.1675793081522, 52.08144173026085, 55.42784996330738, 50.94875290989876, 44.49718929827213, 43.15035916864872, 45.20627684891224, 50.89586354792118, 53.39148983359337, 55.697783678770065, 56.05851352214813, 47.86814421415329, 33.01307313144207, 26.180370971560478, 19.099279940128326, 8.026656042784452, 7.180101368576288, 10.199774634093046, 9.542786087840796, 5.564018161967397, 3.134606173262, 0.22308809246169403, 0.13433456275379285, 0.9118554764427245, 8.89671815559268, 29.651241526007652, 45.526367872953415, 38.52246209979057, 48.08694787323475, 53.3471842110157, 51.5335339307785, 40.92511497437954, 20.845101960003376, 1.3700055610388517, 0.07778039391268976, 0.053187590310699306, 0.046193267771741375, 0.013767632572125876, 0.012785163562512025, 0.022148080097394995, 0.11122133815661073, 0.07743972586467862, 0.06272436236031353, 0.044282898015808314, 0.0270298718533013, 0.08623882167739794, 0.006638315689997398, 0.08316673105582595, 0.034668341468204744, 0.030140194212435745, 0.07741458190139383, 0.037107064708834514, 0.05931447209150065, 0.06647786329267547, 0.030029530717001762, 0.06888222138513811, 0.1556368134333752, 0.09734601160744205, 0.1441838569007814, 0.17502516915556043, 0.2360200008843094, 0.1532189705176279, 0.12188169581349939, 0.12714938580757007, 0.1701129085267894, 0.15778530127136037, 0.07652050175238401, 0.19908022368326783, 0.11196168983587995, 0.07682404015213251, 0.11400465169572271, 0.15508759446674958, 0.14674760604975745, 0.17576802929397672, 0.191396115696989, 0.20020007999846712, 0.18501005368307233, 0.08066416456131265, 0.11794801626820117, 0.19628081296104938, 0.20999123429646716, 0.6671250960789621, 9.913758281618357, 39.057066813111305, 62.289685159921646, 50.78376956284046, 40.68157844245434, 28.164442107081413, 38.69443707168102, 43.33876445889473, 18.121366314589977, 4.500271892175078, 0.32405516132712364, 0.47563175903633237, 3.0483059165999293, 7.883599419146776, 8.140052407979965, 16.26497022807598, 15.753108244389296, 21.049796976149082, 20.44822085648775, 26.241089813411236, 34.945136457681656, 40.78491009771824, 53.52001793682575, 52.31714688241482, 54.01997610926628, 51.246284544467926, 53.660918176174164, 49.77741256356239, 49.119873046875, 51.71001546084881, 53.971916288137436, 49.51371431350708, 47.21274018287659, 42.08428457379341, 40.55237777531147, 39.60866801440716, 38.882260993123055, 39.38395947217941, 40.63262186944485, 40.06114013493061, 41.93642310798168, 39.04863506555557, 39.39776033163071, 39.043003767728806, 38.46495218575001, 41.67611427605152, 39.06639911234379, 38.84910777211189, 48.782914727926254, 40.59335857629776, 37.0708791911602, 38.274160623550415, 49.4753173738718, 54.81913022696972, 53.22240650653839, 53.95882599055767, 53.35097260773182, 58.14511455595493, 53.40011537075043, 54.038287326693535, 50.20464263856411, 49.26427289843559, 43.74291457235813, 32.60558679699898, 53.89037266373634, 55.412050411105156, 53.54130059480667, 51.5189541131258, 48.379178792238235, 44.833938628435135, 41.28236800432205, 40.55182300508022, 39.95404668152332, 42.19252556562424, 39.104932844638824, 39.554539918899536, 39.393531158566475, 37.61361546814442, 38.32579605281353, 39.93548087775707, 42.01343737542629, 45.756293535232544, 47.721548080444336, 49.87956628203392, 51.51951268315315, 53.96403931081295, 55.482700020074844, 54.78244699537754, 54.24593098461628, 53.14776711165905, 53.52686136960983, 56.3180585950613, 55.63946820795536, 52.65118695795536, 52.58135810494423, 54.319742023944855, 56.99953302741051, 55.04309020936489, 46.77578262984753, 44.14068102836609, 46.8922995775938, 52.06541419029236, 56.32136061787605, 58.42834755778313, 57.33549199998379, 47.185932621359825, 33.578577786684036, 25.682707875967026, 23.453743681311607, 19.405456110835075, 23.05578723549843, 13.66064127534628, 10.521512869745493, 16.958241127431393, 6.8478576466441154, 1.193986537400633, 0.3596018085954711, 1.2361135706305504, 10.364153813570738, 34.579113498330116, 50.73426961898804, 43.56566548347473, 54.87311773002148, 58.93131136894226, 62.112238481640816, 48.041677102446556, 26.366880163550377, 2.4502764316275716, 0.2606539009138942, 0.13439391972497106, 0.17019320890540257, 0.11826054207631387, 0.10822200769325718, 0.08706708074896596, 0.2327913764747791, 0.2110756901674904, 0.13127252081176266, 0.19398484553676099, 0.09919754389557056, 0.24154288577847183, 0.1635034749051556, 0.1511962915537879, 0.17928686313098297, 0.08571347018005326, 0.16901402530493215, 0.17434929526643828, 0.17562233086209744, 0.11285382555797696, 0.15995940804714337, 0.2756806102115661, 0.19506434386130422], [0.03267425374360755, 0.020830343091802206, 0.08555263935704716, 0.0669477615156211, 0.0660648506891448, 0.04388420515169855, 0.06530369661049917, 0.05592173656623345, 0.025600109511287883, 0.051221618850831874, 0.023170800413936377, 0.03507247427478433, 0.0682006923307199, 0.019668889399326872, 0.022165978843986522, 0.0033078660680985195, 0.045668343009310775, 0.05771332929725759, 0.06017302563122939, 0.029255954941618256, 0.016839692580106203, 0.019534308339643758, 0.05466234535560943, 0.03159226551360916, 0.13499445078196004, 4.593800073489547, 24.846256859600544, 44.6587148308754, 44.412305653095245, 25.5889593064785, 24.133272618055344, 31.61017131060362, 32.895572036504745, 22.099648341536522, 4.567144978791475, 0.21023495559347793, 0.4141652776161209, 0.6483738147653639, 3.0712792463600636, 2.0786243118345737, 1.9713495369069278, 8.06442791596055, 7.058351626619697, 18.03864475339651, 16.043835394084454, 25.08919682353735, 35.86613103747368, 44.94394652545452, 48.283325135707855, 51.4937424659729, 46.801883429288864, 48.744772374629974, 47.11951978504658, 48.99246968328953, 49.40082997083664, 50.48760965466499, 44.29367981851101, 41.4601718634367, 38.65776523947716, 36.10317751765251, 34.84970837831497, 34.77801762521267, 36.98063023388386, 40.186890587210655, 44.502516612410545, 47.4325317889452, 45.331711918115616, 45.37652671337128, 38.65619972348213, 35.35804510116577, 34.08669412136078, 34.58684988319874, 33.49548764526844, 34.005097299814224, 35.85614517331123, 37.586766108870506, 36.397224739193916, 49.11135010421276, 51.11879378557205, 52.53749705851078, 47.80870400369167, 53.96663077175617, 44.26397681236267, 35.55291764438152, 52.15255491435528, 47.05969199538231, 44.96131919324398, 37.3212743550539, 26.884752474725246, 49.885642156004906, 50.39195358753204, 46.30851410329342, 43.73575955629349, 39.37575191259384, 36.857668831944466, 32.96114891767502, 34.41579066216946, 36.76030285656452, 36.42870604991913, 36.74541525542736, 36.989890336990356, 36.59977287054062, 36.102546751499176, 35.07375955581665, 35.1995138078928, 35.581997483968735, 35.158134028315544, 35.455787256360054, 38.58833156526089, 41.321593299508095, 42.2160729020834, 46.14300258457661, 46.1534558236599, 43.43453451991081, 45.240178629755974, 45.241447761654854, 44.93727408349514, 48.80335383117199, 50.99448345601559, 53.89768727123737, 51.70809656381607, 52.362961024045944, 53.07353429496288, 47.80767425894737, 42.38831385970116, 44.691419675946236, 47.59770892560482, 51.18009589612484, 54.40490685403347, 52.382754161953926, 44.16380658745766, 30.54457549005747, 22.411788292229176, 21.49944394826889, 3.7498534843325615, 3.247441593557596, 8.725037667900324, 7.9282137751579285, 1.7899287468753755, 2.4108955822885036, 0.10614285129122436, 0.03906381127308123, 1.167912574019283, 8.162094075232744, 27.396811097860336, 42.63731449842453, 31.023142710328102, 50.45555077493191, 46.14418052136898, 49.845664501190186, 32.97398842871189, 12.448325827717781, 1.2529324181377888, 0.0763286639994476, 0.06771749482140876, 0.05029728505178355, 0.009059564599738223, 0.04942320207192097, 0.05473277888086159, 0.07907892970251851, 0.057178808565367945, 0.010918818006757647, 0.04223352771077771, 0.004242586919644964, 0.015749787489767186, 0.040607882910990156, 0.021106939675519243, 0.09551898503559642, 0.1053730957210064, 0.02200500701292185, 0.050049737983499654, 0.06806741745094769, 0.04085566004505381, 0.024565229105064645, 0.04981635480362456, 0.05234556439972948, 0.025727857246238273, 0.05751628166763112, 0.005288375969030312, 0.06094884083722718, 0.1292793793254532, 0.01779611498932354, 0.060614696267293766, 0.08898054526071064, 0.10530242099775933, 0.08690600501722656, 0.045371602682280354, 0.00656658804473409, 0.015952204557834193, 0.038175171066541225, 0.02244736228021793, 0.014730615566804772, 0.047580616374034435, 0.0602006446570158, 0.051290590345161036, 0.05873511821846478, 0.038305662892526016, 0.060141848007333465, 0.1067300236900337, 0.06105878630478401, 0.3702606225851923, 6.219861069694161, 29.86441008746624, 53.22536654770374, 49.23364274203777, 32.37941153347492, 24.862480089068413, 35.47984376549721, 37.56406232714653, 23.26458603143692, 5.434570983052254, 0.28584945830516517, 0.18342963536269963, 0.5343973869457841, 2.8242383524775505, 4.130361266434193, 8.258125372231007, 12.54270801320672, 7.727889474481344, 13.375465627759695, 20.074199326336384, 27.465129531919956, 39.46752078831196, 47.682539373636246, 52.32292257249355, 53.10093082487583, 48.61457236111164, 49.15189012885094, 48.48103232681751, 49.66633312404156, 50.440397188067436, 50.987552627921104, 47.94835790991783, 43.1819848716259, 40.202496349811554, 36.52476489543915, 37.84147024154663, 37.320753782987595, 38.29116851091385, 41.02905459702015, 45.900245010852814, 47.844232097268105, 45.362820848822594, 45.93560591340065, 39.10972818732262, 36.803259551525116, 36.2470605969429, 36.361620649695396, 35.303476229310036, 35.72646573185921, 37.37283758819103, 37.786661982536316, 37.88225345313549, 51.050348058342934, 52.98302315175533, 54.106159284710884, 49.679503217339516, 53.63110117614269, 47.63074815273285, 37.34047472476959, 53.49343456327915, 46.35927937924862, 45.81820361316204, 41.91419430077076, 29.720470011234283, 53.747021555900574, 54.02811527252197, 47.8823858499527, 45.13025052845478, 41.905838549137115, 39.5286101102829, 35.17796516418457, 36.968417689204216, 36.69958971440792, 38.07368338108063, 38.77104856073856, 37.91854150593281, 38.26558828353882, 38.225994408130646, 36.431540697813034, 37.1053509414196, 36.6715282201767, 36.96948543190956, 38.52328285574913, 41.160371750593185, 43.813491985201836, 46.50470897555351, 47.401084676384926, 48.314684852957726, 47.059653997421265, 48.217835649847984, 47.876921743154526, 48.232970237731934, 50.7188006490469, 51.191084906458855, 54.20730985701084, 53.26150260865688, 53.94204989075661, 54.89298686385155, 49.71189267933369, 43.59251104295254, 46.2067973613739, 48.58451597392559, 54.99768264591694, 56.18172191083431, 55.15122480690479, 46.56956009566784, 31.62432935088873, 24.88914705812931, 16.357960738241673, 7.660934217274189, 9.207645021378994, 12.832680903375149, 9.800035133957863, 7.4213010258972645, 2.093665567226708, 0.2996371075278148, 0.020876178132311907, 1.1248897388577461, 9.51676793396473, 30.8882100507617, 45.9445658326149, 33.03969830274582, 53.25871355831623, 51.84860922396183, 55.673996955156326, 39.50964152812958, 16.396087892353535, 1.59490124322474, 0.04651448041840922, 0.06718121891026385, 0.036573018951457925, 0.01927474218973657, 0.045716530657955445, 0.04076139615790453, 0.07134344283258542, 0.030137088324408978, 0.045985176984686404, 0.027612660014710855, 0.009956464909919305, 0.04309250056394376, 0.05171623430214822, 0.09122735282289796, 0.02392085752944695, 0.03348160651512444, 0.01727484901493881, 0.06135118877864443, 0.03932260187866632, 0.02283791563968407, 0.007570830739496159, 0.03931384453608189, 0.03322101620142348, 0.16354007762856781, 0.11923075173399411, 0.2105237846262753, 0.23395377269480377, 0.1985975308343768, 0.13032603019382805, 0.12152261508163065, 0.28301522601395845, 0.0927750498522073, 0.11923963524168357, 0.16704507783288136, 0.12191403118777089, 0.17496416461654007, 0.12410046503646299, 0.188566944852937, 0.08851935243001208, 0.17500231100711972, 0.17934391944436356, 0.1833054146845825, 0.16639419947750866, 0.16792590322438627, 0.16253672365564853, 0.26507947593927383, 0.15534623293206096, 0.4658313427353278, 7.8833728563040495, 36.43929608166218, 60.111303851008415, 56.796810105443, 38.20139452815056, 35.44129863381386, 41.335287764668465, 43.40402215719223, 27.20073401927948, 6.604229444637895, 0.753024771111086, 1.1025884980335832, 1.12102463375777, 8.51035488769412, 5.769189577549696, 12.4491560831666, 18.406123034656048, 15.522816851735115, 25.618717409670353, 21.425308026373386, 31.01498454809189, 41.90949395298958, 51.8141108751297, 54.79749798774719, 55.833580791950226, 48.70998524129391, 51.063632145524025, 50.76531395316124, 51.671398133039474, 51.219742968678474, 55.267867147922516, 51.13542929291725, 47.043147683143616, 42.77759537100792, 39.740817323327065, 39.911207780241966, 40.40591083467007, 40.56742116808891, 44.48868155479431, 49.73710812628269, 52.04258121550083, 49.19924698770046, 50.09896270930767, 42.064255848526955, 40.11804208159447, 37.81840167939663, 38.07310201227665, 36.47476337850094, 37.12668299674988, 38.70245844125748, 40.939964577555656, 40.02413012087345, 53.85923333466053, 55.45536428689957, 58.15600097179413, 50.5033940076828, 54.105756506323814, 48.581742122769356, 39.22218695282936, 54.570866748690605, 48.4080496430397, 48.63714314997196, 44.69524227082729, 34.91066470742226, 53.575844541192055, 56.32116682827473, 48.91898162662983, 48.209954872727394, 41.94534122943878, 40.237184688448906, 36.483609303832054, 39.34487856924534, 39.08341459929943, 39.57235336303711, 40.11156342923641, 38.99310104548931, 41.24189257621765, 39.957899674773216, 38.95435072481632, 39.0847597271204, 38.978741616010666, 38.48962426185608, 38.18322390317917, 42.215445935726166, 46.42614059150219, 47.09112390875816, 50.284970328211784, 51.41719937324524, 47.96466663479805, 50.05935363471508, 50.38110896945, 50.21032713353634, 53.61280515789986, 55.70188745856285, 55.02732865512371, 53.20770129561424, 55.476517751812935, 57.025702223181725, 53.76996852457523, 45.40669709444046, 49.9288534373045, 52.04587563872337, 57.041095197200775, 58.89671802520752, 58.13743896782398, 46.56670264899731, 36.41008324921131, 24.23572652041912, 27.865331657230854, 9.607242029160261, 6.30158138461411, 19.921783804893494, 13.732912447303534, 8.973878715187311, 5.078209955245256, 1.0590887884609401, 0.17340053367661312, 1.6454922035336494, 11.422640215605497, 34.57495652139187, 53.54310929775238, 41.262734457850456, 61.26155152916908, 58.22811350226402, 65.6343112885952, 48.500620275735855, 19.073770008981228, 3.2223237538710237, 0.1538148705731146, 0.11369950283551589, 0.15815787424799055, 0.106696582515724, 0.17985583806876093, 0.10322166897822171, 0.27331440593115985, 0.13957434799522161, 0.08196376904379576, 0.12906382995424792, 0.07466407128958963, 0.10532449989113957, 0.10828466722159646, 0.22055046691093594, 0.21063178195618093, 0.17000936408294365, 0.1019229476514738, 0.16900651477044448, 0.1823228705325164, 0.1340983816771768, 0.17131873522885144, 0.07698489323956892, 0.1464194431900978], [0.009959410308510996, 0.01582435106683988, 0.03456607351836283, 0.03179261570039671, 0.04353620839538053, 0.08207421546103433, 0.0707183986378368, 0.029534013556258287, 0.04530051977781113, 0.043097673333249986, 0.025306174502475187, 0.05940427567111328, 0.04120091085496824, 0.047742872120579705, 0.028340109456621576, 0.027955304030911066, 0.06903316680109128, 0.03360482158313971, 0.030841959778626915, 0.053211743506835774, 0.017841226435848512, 0.03471862197329756, 0.05542959246668033, 0.09217042956152, 0.15518019965384156, 3.5218761675059795, 20.0275207310915, 47.17419505119324, 40.29736205935478, 30.628600381314754, 20.642667822539806, 25.06339430809021, 35.905626118183136, 20.672047846019268, 6.881564687937498, 0.9311831986997277, 0.16052130289608613, 0.6298188166692853, 2.9865031829103827, 4.782681288197637, 5.197570575401187, 10.906921438872814, 5.202121306210756, 8.79127286374569, 19.9288647249341, 23.233674690127373, 33.366640359163284, 41.17261469364166, 44.58345226943493, 45.70944964885712, 45.239038690924644, 45.929522439837456, 48.846131935715675, 47.52367749810219, 49.45854127407074, 48.92771355807781, 46.27225264906883, 42.479417771101, 39.37450557947159, 35.11756740510464, 36.32257394492626, 34.771060198545456, 39.9114091694355, 46.410968005657196, 51.55391223728657, 55.10978803038597, 51.5985294431448, 53.28617848455906, 47.20349907875061, 42.98237778246403, 37.65033669769764, 36.061881333589554, 34.63534668087959, 36.09362483024597, 33.58057647943497, 36.4749039709568, 37.41128772497177, 49.63332809507847, 48.40131640434265, 52.787732630968094, 49.13463905453682, 48.750673457980156, 55.83060175180435, 48.445918411016464, 52.62783721089363, 50.91559588909149, 48.77114675939083, 44.09291759133339, 31.070607863366604, 48.893363401293755, 50.77631056308746, 42.063552886247635, 42.43127815425396, 36.71811372041702, 36.0510329157114, 35.09263314306736, 37.064886912703514, 35.20728059113026, 35.50467923283577, 35.42870990931988, 35.46818219125271, 33.92211355268955, 35.16834408044815, 35.77950708568096, 36.23852625489235, 36.73150420188904, 35.50947077572346, 34.879483580589294, 34.911082684993744, 34.79710020124912, 35.75583055615425, 35.899580642580986, 38.65576274693012, 38.734201937913895, 40.06754659116268, 42.66011327505112, 45.394378155469894, 44.6903595328331, 48.35843950510025, 50.938193276524544, 52.76048429310322, 50.997158512473106, 54.41296622157097, 50.662039294838905, 46.259819716215134, 41.770634204149246, 47.270174100995064, 50.77726051211357, 54.04345124959946, 46.341028958559036, 37.53983482718468, 26.170436404645443, 24.199833646416664, 11.119207497686148, 4.873243253678083, 6.833790326490998, 11.213197354227304, 13.563928864896297, 7.006164751946926, 1.3319756579585373, 0.1527227705810219, 0.19905895373085514, 1.0976929357275367, 10.097970496863127, 25.728738605976105, 50.811359882354736, 49.74891409277916, 58.58877494931221, 49.295256435871124, 54.04843658208847, 39.76366929709911, 13.085848968476057, 1.705332223791629, 0.019327844711369835, 0.06217997106432449, 0.030335904120875057, 0.0992145093914587, 0.058175249432679266, 0.04666016029659659, 0.06446285071433522, 0.03010188454936724, 0.039285357197513804, 0.06079214748751838, 0.04036780184833333, 0.0397733897989383, 0.02953402654384263, 0.0012846655135945184, 0.01360942153041833, 0.05400749279942829, 0.051331408467376605, 0.05692667873518076, 0.03199039805622306, 0.06802936753956601, 0.1232052048726473, 0.007232666976051405, 0.029467437343555503, 0.036228595636202954, 0.03990341036114842, 0.032609512491035275, 0.03174291407049168, 0.016185036693059374, 0.044802405100199394, 0.05036016722442582, 0.013381544158619363, 0.0156597742534359, 0.04941322018567007, 0.03909254723112099, 0.033818218726082705, 0.019942201979574747, 0.06341500498820096, 0.051845442212652415, 0.007041095932436292, 0.1006277886335738, 0.03158960862492677, 0.021256584477669094, 0.020877515853499062, 0.033423659624531865, 0.010976166540785925, 0.086634215695085, 0.10276661370880902, 0.14223426464013755, 4.23237344250083, 25.529897175729275, 50.9319806098938, 47.06745497882366, 35.72573237121105, 26.466875597834587, 27.462425976991653, 38.41826409101486, 25.501265712082386, 7.118540396913886, 1.2430310994386673, 0.11382369382772595, 0.8504387782886624, 1.4182602404616773, 6.572504946961999, 4.4549730978906155, 8.58010584488511, 7.737825466319919, 7.334675174206495, 22.362031862139702, 25.658801458775997, 36.438950300216675, 43.675061613321304, 49.50097739696503, 48.357242569327354, 48.43121699988842, 49.17268641293049, 50.364891439676285, 48.56949917972088, 50.35548314452171, 51.30655311048031, 49.29200381040573, 44.6502260863781, 41.79152928292751, 37.43230439722538, 38.00687536597252, 36.188957914710045, 42.91997753083706, 48.28265257179737, 53.57532396912575, 54.226616621017456, 54.861197769641876, 54.06332038342953, 48.46149377524853, 44.349491223692894, 38.51261302828789, 38.72239977121353, 37.39025205373764, 37.495901584625244, 35.89315138757229, 36.21154010295868, 39.9158701300621, 50.6755855679512, 50.08494906127453, 54.90027107298374, 51.212584152817726, 49.96270962059498, 53.79003144800663, 47.709020152688026, 52.28135660290718, 50.681916028261185, 48.241607174277306, 46.81530050933361, 33.05791072547436, 51.13326720893383, 54.581585973501205, 43.95149677991867, 44.82595145702362, 40.160478204488754, 37.60145992040634, 36.077867075800896, 38.57624441385269, 36.550573110580444, 38.1355706602335, 37.01658010482788, 37.505385875701904, 36.61964200437069, 36.36268839240074, 37.229463681578636, 37.6742298156023, 37.58490800857544, 36.989495158195496, 36.545918360352516, 36.317474618554115, 36.48986756801605, 38.62837381660938, 38.94616596400738, 41.99633829295635, 41.86163552105427, 42.57129304111004, 45.251429826021194, 46.874026358127594, 47.456831485033035, 51.35172128677368, 52.50246673822403, 53.93586002290249, 51.86142973601818, 56.4951328933239, 53.500357791781425, 47.42179736495018, 44.68903340399265, 50.65563663840294, 53.217873349785805, 56.20406471192837, 49.73600998520851, 39.25809882581234, 32.868893668055534, 25.839154981076717, 12.26444324478507, 8.06534556671977, 10.61810178682208, 12.46971108019352, 7.904245611280203, 7.0811062306165695, 3.954297238960862, 0.21125540864886716, 0.11866691245813854, 1.3061518874019384, 10.601891856640577, 29.76822964847088, 50.98914094269276, 52.69390806555748, 62.93374679982662, 54.166435450315475, 59.63604435324669, 43.490600511431694, 16.411410570144653, 1.93721204996109, 0.04311934775614645, 0.04883041532593779, 0.08850775266182609, 0.023485682540922426, 0.028451926991692744, 0.022924012191651855, 0.008002545000636019, 0.02791356193483807, 0.04035640617075842, 0.017440138290112372, 0.036920195634593256, 0.03173901037371252, 0.02425396680337144, 0.07968131612869911, 0.015779414025018923, 0.06988711160374805, 0.048791493391036056, 0.024197741695388686, 0.028282407474762294, 0.04809098019904923, 0.003784393061323499, 0.008961834882939002, 0.06321222055703402, 0.14337255590362474, 0.12088709176168777, 0.1180310254858341, 0.11218546220334247, 0.08974527649115771, 0.166082022478804, 0.24678765825228766, 0.15094902279088274, 0.11252757743932307, 0.16581964358920231, 0.10897467902395874, 0.13096357957692817, 0.14954916900023818, 0.2242560696322471, 0.13021454476984218, 0.1659573268261738, 0.17878487444249913, 0.14050868223421276, 0.15155460045207292, 0.12121766660129651, 0.09731816622661427, 0.09177036743494682, 0.1991507870843634, 0.22424490773119032, 0.3923678066348657, 5.714312922209501, 31.177190244197845, 59.471304193139076, 53.45496542751789, 42.86348596215248, 31.834847554564476, 33.85787419974804, 44.79098193347454, 26.74780212342739, 9.41143473610282, 1.672436676453799, 0.6401006493251771, 1.3426894205622375, 6.924818716943264, 14.459661450237036, 11.379221845418215, 20.914286747574806, 10.543490890413523, 14.49054904282093, 27.57577769458294, 29.47677008807659, 39.808571487665176, 45.22781029343605, 51.50646038353443, 49.15114916861057, 48.346086367964745, 51.98540188372135, 52.65487655997276, 51.01328104734421, 50.94071254134178, 54.4051880389452, 53.11749413609505, 46.88906215131283, 43.839338198304176, 39.31630030274391, 40.29551535844803, 38.77273567020893, 44.48998108506203, 51.119447350502014, 55.492055118083954, 57.329503521323204, 57.572147101163864, 57.06668682396412, 52.3147302120924, 46.336655393242836, 42.48495027422905, 40.437019765377045, 40.33842645585537, 39.33503329753876, 38.366301879286766, 39.903737381100655, 41.99394442141056, 52.86537766456604, 52.24176272749901, 55.94304911792278, 52.47512720525265, 51.098001301288605, 55.579043850302696, 44.47827011346817, 53.39527063071728, 52.04228103160858, 49.54450026154518, 45.50779826939106, 35.46922713518143, 53.917051032185555, 55.52906893193722, 47.36591376364231, 47.192715257406235, 40.2737121284008, 38.78323070704937, 39.72036302089691, 41.20678626000881, 38.42641845345497, 39.56558592617512, 38.59390206634998, 39.16663393378258, 38.76725256443024, 38.10147128999233, 39.97192472219467, 38.87720346450806, 40.65783731639385, 39.35981936752796, 38.10036174952984, 39.358535036444664, 38.1781055778265, 39.95582118630409, 40.060038194060326, 44.260849580168724, 43.098013177514076, 44.65869963169098, 47.61682190001011, 49.58240702748299, 50.15342898666859, 53.946404457092285, 54.32147093117237, 55.874603390693665, 52.478642016649246, 59.25118200480938, 54.751588851213455, 51.64101116359234, 46.56539551913738, 53.079727962613106, 56.57577596604824, 58.031177669763565, 49.93324600160122, 38.8771540671587, 30.36421626806259, 30.4507053270936, 14.788191821426153, 12.677425034344196, 14.39751673489809, 19.15033020079136, 23.760734908282757, 11.799400448799133, 3.3376003056764603, 0.35325217118952423, 0.4748916003154591, 1.6803535516373813, 13.635123744606972, 33.963816314935684, 62.210235223174095, 62.35460847616196, 70.13066321611404, 61.096841767430305, 66.99924364686012, 52.38162562251091, 18.647563979029655, 2.7103335270658135, 0.1539664765005, 0.17226234631380066, 0.17185833596158773, 0.18560892232926562, 0.1199378255114425, 0.11979828690527938, 0.1170458912383765, 0.1105069690675009, 0.13779965025605634, 0.1264352022553794, 0.23538147186627612, 0.14972211909480393, 0.19761249306611717, 0.3215410024859011, 0.1095314159465488, 0.09984282645746134, 0.10113590004038997, 0.18095313309459016, 0.16606189543381333, 0.1793946823454462, 0.14911617035977542, 0.2281760046025738, 0.1925026430399157], [0.05038593088102061, 0.03314558802230749, 0.03853028130833991, 0.07350353786023334, 0.026573137474770192, 0.04537627079116646, 0.03426764109462965, 0.12068858952261508, 0.027785211204900406, 0.026645047873898875, 0.08906209986889735, 0.02417754785710713, 0.07288913606316783, 0.017696659779176116, 0.01429910122169531, 0.051171126833651215, 0.028662166296271607, 0.039258469187188894, 0.04593117089825682, 0.019464765391603578, 0.07954213375342079, 0.06899730622535571, 0.05653967469697818, 0.02599444782390492, 0.08633702265797183, 3.7157113663852215, 17.894115708768368, 44.170004054903984, 49.18378561735153, 42.67274759709835, 27.42301259189844, 31.110631115734577, 29.787994287908077, 28.123206719756126, 10.550509113818407, 1.4325038949027658, 0.16171112889423966, 0.5086347099859267, 0.5250876490026712, 3.535993597470224, 6.449382528662682, 8.717791456729174, 7.234152518212795, 4.494862407445908, 12.37640518695116, 19.971523135900497, 31.085922941565514, 38.85513424873352, 46.376872435212135, 49.343251660466194, 50.95539875328541, 44.38139051198959, 49.53843578696251, 48.783104717731476, 48.30115757882595, 48.978437036275864, 47.57315844297409, 42.81313106417656, 40.264007449150085, 35.96299543976784, 34.73451375961304, 35.249082148075104, 41.02048985660076, 45.01099772751331, 51.46041825413704, 52.4057961255312, 53.27997341752052, 48.95911127328873, 50.20208157598972, 48.2727275043726, 45.649652257561684, 37.377469539642334, 35.275958105921745, 34.483628422021866, 36.47542454302311, 35.00212959945202, 36.023457795381546, 42.064985409379005, 50.52872344851494, 48.917872086167336, 53.813970163464546, 49.871594309806824, 54.67648588120937, 52.221205830574036, 50.35606451332569, 48.89437794685364, 53.52654978632927, 48.9113250374794, 30.22929310798645, 48.04704621434212, 47.46154323220253, 45.615533888339996, 37.58031025528908, 36.07335291802883, 36.91915713250637, 35.90146914124489, 36.37641325592995, 35.76527684926987, 34.329360499978065, 36.40738159418106, 36.939672231674194, 36.6574651747942, 35.51316797733307, 34.78223159909248, 37.468615248799324, 37.34921805560589, 34.99358005821705, 35.61250604689121, 35.43727844953537, 36.91704824566841, 35.58601386845112, 34.07196991145611, 35.286548137664795, 35.593111887574196, 36.40580467879772, 38.52799840271473, 40.08390091359615, 44.064848497509956, 46.11062832176685, 50.41739322245121, 53.44266168773174, 53.52892845869064, 53.87907586991787, 56.89068026840687, 49.697252064943314, 42.90618807077408, 44.51172351837158, 50.525710210204124, 53.11700016260147, 49.381728395819664, 38.41632999479771, 29.438169859349728, 20.485107377171516, 6.8128871731460094, 7.6095144264400005, 18.614935129880905, 9.536068048328161, 4.564496520906687, 7.0059130154550076, 3.600741885602474, 0.28875766787678003, 0.09021389822009951, 1.3811722118407488, 9.614708628505468, 31.045601405203342, 40.19693724811077, 36.72818697988987, 49.27131772041321, 44.49250414967537, 51.001874059438705, 37.65388570725918, 10.942102801054716, 1.1403399473056197, 0.023933256961754523, 0.042851643956964836, 0.07141231413697824, 0.023262240429176018, 0.060339058909448795, 0.029801730343024246, 0.02865047747036442, 0.05448522810183931, 0.02267236661282368, 0.018887060941779055, 0.0520641976618208, 0.015541170705546392, 0.05966965283732861, 0.06147029605926946, 0.007084219814714743, 0.004139127822782029, 0.07425094736390747, 0.008342019118572352, 0.03186152040143497, 0.014809804579272168, 0.024073298372968566, 0.028602959609997924, 0.05366201563447248, 0.03870407374051865, 0.05597862218564842, 0.03466252674115822, 0.015653297159587964, 0.02087369193759514, 0.017359342527925037, 0.0447743630502373, 0.034316095916437916, 0.02382627822953509, 0.016096769359137397, 0.04535920510534197, 0.05688587174518034, 0.058447591654839925, 0.0065486368839628994, 0.04471895059396047, 0.08249821185017936, 0.023501542236772366, 0.052084517665207386, 0.0018784960207085533, 0.030922655350877903, 0.004682235203290475, 0.02735333691816777, 0.013764053564955248, 0.011666172777040629, 0.040778688198770396, 4.4784073904156685, 21.88735943287611, 51.49843901395798, 52.93627806007862, 46.858128011226654, 28.667286224663258, 29.411489591002464, 33.126219660043716, 28.13718616962433, 11.360783334821463, 1.2761889514513314, 0.1608840498374775, 0.48495999129954726, 1.4275363739579916, 4.874889515340328, 8.187577407807112, 8.12661062926054, 7.557218782603741, 7.768471296876669, 20.142090283334255, 25.790882371366024, 30.52053228020668, 42.71202228963375, 46.74083210527897, 50.50937108695507, 51.438265442848206, 47.32460618019104, 52.26907566189766, 49.445640966296196, 50.05876466631889, 50.86082562804222, 49.93162728846073, 45.181395784020424, 41.72647297382355, 38.21742206811905, 35.64931087195873, 36.88653968274593, 43.00771862268448, 47.6741836220026, 53.51143039762974, 55.13083890080452, 53.2761812210083, 50.944257751107216, 51.300891414284706, 50.020287930965424, 45.643401592969894, 37.830659821629524, 36.0890156775713, 36.1541897803545, 37.28950425982475, 37.00388878583908, 38.04334960877895, 44.52446423470974, 50.86308650672436, 50.7239493727684, 56.533263847231865, 53.33268418908119, 55.476456955075264, 54.08140741288662, 53.0264738202095, 51.1052019149065, 53.66603650152683, 49.303076416254044, 31.90274991095066, 49.28563915193081, 50.6674350053072, 46.03348106145859, 39.54671613872051, 38.009865805506706, 37.97717235982418, 36.737865060567856, 39.327570497989655, 37.974003329873085, 37.32808358967304, 37.87845365703106, 38.14749822020531, 37.738313376903534, 37.30660334229469, 36.272549629211426, 40.025771632790565, 39.39795412123203, 36.263741701841354, 37.253584787249565, 36.1860054731369, 38.37678551673889, 36.9045203179121, 37.48850718140602, 36.9829823076725, 37.430328503251076, 36.71169586479664, 42.37752243876457, 42.89533965289593, 46.984364837408066, 47.81125366687775, 51.51842974126339, 53.6822996288538, 53.77348333597183, 55.146304070949554, 57.83340968191624, 51.224211528897285, 45.66308453679085, 47.11217477917671, 53.36658217012882, 57.468842044472694, 50.969484597444534, 37.0526097714901, 27.744319550693035, 21.94823406636715, 10.471549350768328, 9.981125816702843, 11.818812657147646, 13.781131859868765, 3.446760135702789, 5.397976096719503, 3.601334416307509, 0.30844212567899376, 0.1454892649780959, 1.114703791681677, 12.011320777237415, 32.96804554760456, 47.96863742172718, 41.8639761954546, 55.38852587342262, 50.13919875025749, 57.513588443398476, 44.713568687438965, 13.71070833876729, 1.6675235400907695, 0.0786157776019536, 0.06161923025501892, 0.03982244947110303, 0.028259053942747414, 0.06635806581471115, 0.028530941599456128, 0.07090893021086231, 0.030441315066127572, 0.06792479893192649, 0.01501568191088154, 0.05122360038512852, 0.04459762429178227, 0.06964210639125668, 0.02154401456209598, 0.010508981795283034, 0.01684054048382677, 0.026832312141777948, 0.05683116803993471, 0.01564285885251593, 0.05809241090901196, 0.02868338800908532, 0.020462521715671755, 0.030053837908781134, 0.19727493461687118, 0.09917047776980326, 0.09764609902049415, 0.12917432090034708, 0.08702078557689674, 0.13732112827710807, 0.09303763654315844, 0.16856156755238771, 0.12232243505422957, 0.13866536552086473, 0.16954096499830484, 0.16295737295877188, 0.16418855142546818, 0.08524068500264548, 0.19174351502442732, 0.20040250819874927, 0.11892584036104381, 0.18129394215065986, 0.09027548163430765, 0.1203877005900722, 0.08814735090709291, 0.1188828403246589, 0.12728499103104696, 0.15861873311223462, 0.14319504902232438, 5.147571433335543, 26.68875139206648, 58.083641454577446, 60.733904242515564, 52.60621257126331, 38.24926815927029, 42.43223950266838, 41.3970572501421, 35.21840259432793, 13.692927192896605, 2.5258854869753122, 0.4425320914015174, 1.0426023043692112, 3.2428744761273265, 9.950134679675102, 12.952234838157892, 16.81962836533785, 15.649417508393526, 8.683019522577524, 15.251475311815739, 22.435242533683777, 32.86349415779114, 43.297118693590164, 48.76310259103775, 51.82500869035721, 53.75087074935436, 48.08188654482365, 51.654033064842224, 49.78416860103607, 52.01158627867699, 52.31680490076542, 51.59985937178135, 48.04533630609512, 44.03132289648056, 39.82944756746292, 37.56802171468735, 39.210734367370605, 44.67359863221645, 49.00903679430485, 54.26268048584461, 56.52879908680916, 52.98468366265297, 52.54633918404579, 52.971243783831596, 53.335002064704895, 49.419426172971725, 41.38628862798214, 38.26138950884342, 36.96580342948437, 39.100217297673225, 38.80103275179863, 39.8612404614687, 46.07958398759365, 53.27456250786781, 52.89110228419304, 59.276253059506416, 55.53218476474285, 56.858264207839966, 56.15570850670338, 54.550758227705956, 51.20401941239834, 54.69876788556576, 50.284088775515556, 35.42681001126766, 52.60394789278507, 52.490200996398926, 50.94986245036125, 41.97541281580925, 39.51273076236248, 41.57384656369686, 38.67747478187084, 42.02838197350502, 38.959978222846985, 38.30814599990845, 40.17771027982235, 41.420954167842865, 39.90640863776207, 38.52767542004585, 38.18015366792679, 40.95317266881466, 41.38277381658554, 38.80819536745548, 39.472183138132095, 38.57039652764797, 42.31354907155037, 39.83502946794033, 38.4249859303236, 39.884324222803116, 38.57192024588585, 39.99790392816067, 45.18788203597069, 45.225834399461746, 49.474238231778145, 50.47410137951374, 54.52168598771095, 55.727874264121056, 54.785631224513054, 54.997678846120834, 60.071052610874176, 54.36767265200615, 47.544496580958366, 48.22195842862129, 56.63606733083725, 59.717557579278946, 53.04923839867115, 42.162108197808266, 31.903741657733917, 25.394922718405724, 10.835659112781286, 13.225294835865498, 31.835123039782047, 18.59172597527504, 11.97804881259799, 12.769446596503258, 7.0603332202881575, 0.9375684591941535, 0.15551211778074503, 1.8995428900234401, 12.844402324408293, 39.618004113435745, 51.300127655267715, 49.98029127717018, 59.04015272855759, 55.38963921368122, 66.00892558693886, 51.369405537843704, 17.495410703122616, 2.0558423968032002, 0.19823031616397202, 0.11815437785116956, 0.14551963366102427, 0.13819531886838377, 0.15906020707916468, 0.15558707469608635, 0.2331001395941712, 0.12893813982373103, 0.12458520621294156, 0.1185307654668577, 0.12039558219839819, 0.15123043034691364, 0.16102988185593858, 0.12227788392920047, 0.10385991598013788, 0.16045041295001283, 0.2585978846764192, 0.14162650506477803, 0.11174851533723995, 0.16706989525118843, 0.1021782612951938, 0.2451821553404443, 0.09996381879318506], [0.0178562345172395, 0.0095771690030233, 0.048356594852521084, 0.046416965924436226, 0.02929629808932077, 0.10897274943999946, 0.03938211470085662, 0.012923525864607655, 0.04061034313053824, 0.026308693559258245, 0.015730539889773354, 0.067614618310472, 0.010208480634901207, 0.022440341563196853, 0.015524553091381676, 0.04311349221097771, 0.0683199628838338, 0.028759717897628434, 0.06920904095750302, 0.05942430994764436, 0.03674418789159972, 0.07757034385576844, 0.06938024700502865, 0.04175716909230687, 0.05542192237044219, 2.0455299876630306, 14.618759863078594, 39.42797631025314, 50.61335250735283, 39.99182425439358, 29.554278329014778, 22.659242413938046, 33.05009074509144, 30.307804495096207, 11.951257400214672, 2.6382618444040418, 0.11817799299024045, 0.4536636534612626, 0.6135132384952158, 1.9019166938960552, 3.6594959953799844, 5.1321908086538315, 4.667030218988657, 4.720052098855376, 23.793671540915966, 20.8452520519495, 24.971275851130486, 33.32489959895611, 45.060520470142365, 46.47401802241802, 46.36881306767464, 50.170064494013786, 51.414459720253944, 50.92890277504921, 53.00200313329697, 49.84505653381348, 48.46815101802349, 45.36363400518894, 41.28135345876217, 36.37240827083588, 36.68536327779293, 36.506411880254745, 37.75875248014927, 41.71758905053139, 47.52569139003754, 50.47040797770023, 51.76928848028183, 50.38724943995476, 49.190313667058945, 50.821949914097786, 46.27262502908707, 41.58222511410713, 37.32751742005348, 35.78450761735439, 34.57534410059452, 35.66411107778549, 36.521649062633514, 37.14515380561352, 43.50392259657383, 48.208472952246666, 48.24835941195488, 50.76517716050148, 48.68346266448498, 49.247485399246216, 49.07020591199398, 47.12035574018955, 50.6922172755003, 53.046559542417526, 32.88509979844093, 46.23366191983223, 48.4189360588789, 44.31497007608414, 41.24650552868843, 36.952200159430504, 40.72140030562878, 40.59049732983112, 41.33313328027725, 39.725621938705444, 39.740517139434814, 36.45770989358425, 35.12651212513447, 33.65574024617672, 36.01782649755478, 36.92636154592037, 36.1712546646595, 37.05144323408604, 39.45734113454819, 38.15206937491894, 37.60918490588665, 35.01138970255852, 35.34864440560341, 35.04272662103176, 35.34182757139206, 36.40059515833855, 37.087662890553474, 38.701109513640404, 41.34514443576336, 42.06219635903835, 45.6881669908762, 46.36694736778736, 50.96198379993439, 52.46500834822655, 53.059858828783035, 53.69311764836311, 53.77789869904518, 46.42416089773178, 47.30806186795235, 47.560041546821594, 52.1685254573822, 42.98288315534592, 29.808116108179092, 27.05886673182249, 20.072554014623165, 9.794813264161348, 7.1369195356965065, 4.708497393876314, 11.366704367101192, 2.309520822018385, 3.148962752893567, 4.854808067902923, 0.16554387635551393, 0.04160096556006465, 1.6443900251761079, 8.758954647928476, 29.105444513261318, 38.968588560819626, 46.76210716366768, 46.62473313510418, 39.115754663944244, 48.82654018700123, 31.345827095210552, 12.0956658013165, 0.5094675184227526, 0.09454729108256288, 0.0282378322299337, 0.04016230486740824, 0.03062148254684871, 0.03813742543570697, 0.053005378213129006, 0.03145694972772617, 0.024321481832885183, 0.06315655205980875, 0.029462379607139155, 0.009830284961935831, 0.10517275295569561, 0.05176817350729834, 0.061108369191060774, 0.024093918946164194, 0.025406813438166864, 0.07090027676895261, 0.03562953774235211, 0.05544220897718333, 0.030100318617769517, 0.027668784932757262, 0.08652473406982608, 0.030914345152268652, 0.053053079755045474, 0.022029813299013767, 0.019818378350464627, 0.046933281773817725, 0.07031662215013057, 0.0759618946176488, 0.032972203771350905, 0.047517329730908386, 0.06438632786739618, 0.068731305655092, 0.050600207468960434, 0.013526759266824229, 0.021433683177747298, 0.060891261309734546, 0.022179445113579277, 0.00607892883635941, 0.04795144901436288, 0.014495209106826223, 0.05822214574436657, 0.05298036412568763, 0.02832963775290409, 0.015734686639916617, 0.016553718960494734, 0.028287264831305947, 0.06814992942963727, 3.1192001374438405, 17.540455386042595, 45.608587861061096, 57.387017235159874, 46.21844373643398, 35.22722952067852, 29.90319650620222, 36.26205079257488, 36.55884526669979, 13.925857543945312, 2.4210588494315743, 0.16719387844204903, 0.12012707316898741, 0.7118032174184918, 3.313766084611416, 8.933547679334879, 6.98389794677496, 5.9822778683155775, 8.294327929615974, 16.129384003579617, 25.41586149483919, 28.536381348967552, 35.624220818281174, 44.88862909376621, 49.96234104037285, 48.84824842214584, 51.35978825390339, 52.015264481306076, 52.0765133947134, 52.29403652250767, 51.06675937771797, 50.582916140556335, 46.67187340557575, 44.336492121219635, 39.31063860654831, 38.79884406924248, 37.368570417165756, 40.707721039652824, 45.48835851252079, 49.99611742794514, 51.618086993694305, 53.16687248647213, 50.7608187943697, 52.25232616066933, 50.70213474333286, 49.643511548638344, 44.00471672415733, 38.558685556054115, 37.04102799296379, 36.11566744744778, 37.042832896113396, 38.34914579987526, 39.39074590802193, 45.67745916545391, 51.81226037442684, 51.4173399657011, 52.163699716329575, 50.73907636106014, 50.81137888133526, 50.61010368168354, 50.1766761392355, 52.318738996982574, 52.11804896593094, 35.59759184718132, 47.52287574112415, 49.78322245180607, 44.64932173490524, 42.88959816098213, 39.17280860245228, 42.1475625783205, 40.949901044368744, 41.88023932278156, 41.6667477786541, 42.978312000632286, 38.29360418021679, 36.35821223258972, 37.02909663319588, 37.40600600838661, 37.784765884280205, 37.8812351077795, 39.835306853055954, 39.63806323707104, 39.41699869930744, 37.61513538658619, 37.895153760910034, 37.3090124130249, 37.567208558321, 35.903103053569794, 37.6104312390089, 38.69373790919781, 39.79827404022217, 42.68887773156166, 43.74368213117123, 47.58683770895004, 49.0183424949646, 52.99678981304169, 54.82579506933689, 53.058487102389336, 53.84402275085449, 54.33104261755943, 48.565828576684, 49.13465045392513, 50.98067879676819, 55.12938737869263, 47.914539724588394, 37.817189544439316, 27.0810841396451, 12.386205811053514, 10.919834095984697, 11.505360826849937, 12.03538678586483, 17.11158949881792, 4.393844828009605, 4.230420347303152, 2.163707446306944, 0.16835192567668855, 0.05351615764084272, 2.426677797921002, 10.85319897159934, 35.74773319065571, 46.558932065963745, 48.46022844314575, 52.42331698536873, 46.59573309123516, 55.0558765232563, 37.679454535245895, 14.14430782198906, 0.7022840157151222, 0.06990354275330901, 0.06866887619253248, 0.0505786369467387, 0.053378177544800565, 0.08227450627600774, 0.06493533161119558, 0.02477391917636851, 0.038715907285222784, 0.06736889321473427, 0.06495815265225247, 0.00782313451054506, 0.0910659579676576, 0.015451707586180419, 0.05253875286143739, 0.01045607872583787, 0.04887689232418779, 0.025304649388999678, 0.04383579485875089, 0.0578534875967307, 0.005825947855555569, 0.03905630816007033, 0.10072920311358757, 0.06365062945405953, 0.23270080477232113, 0.13531250559026375, 0.17196177650475875, 0.12468610861105844, 0.15361315483460203, 0.24660560942720622, 0.1397426225594245, 0.14509988977806643, 0.13975645619211718, 0.1394674787297845, 0.1535041630268097, 0.1673996017780155, 0.11916766918147914, 0.13602921244455501, 0.05870638968190178, 0.14495260315015912, 0.18665303505258635, 0.12256413770955987, 0.15666836901800707, 0.11117269037640654, 0.19966760388342664, 0.17957849748199806, 0.14673760189907625, 0.08969913717010058, 0.1769443036755547, 3.302295212633908, 21.364387795329094, 52.778111547231674, 63.60124558210373, 54.77177336812019, 41.63147047162056, 33.80728371441364, 45.55700182914734, 40.83499900996685, 15.553081277757883, 3.393937745131552, 0.39898203453049064, 0.9116971318144351, 1.1670324462465942, 7.91528781875968, 11.533808000385761, 11.288717351853848, 14.25873963162303, 10.28447113931179, 29.939343966543674, 28.99167861789465, 30.175649486482143, 36.19753785431385, 47.4310764670372, 50.268874391913414, 50.355072766542435, 53.17881144583225, 53.96248139441013, 51.530946269631386, 54.74582456052303, 52.57856145501137, 55.83671562373638, 49.550325348973274, 47.74786926805973, 41.49685509502888, 40.9443761408329, 40.07031284272671, 42.5175791233778, 46.28574572503567, 52.46975429356098, 54.261456951498985, 54.72193144261837, 52.29931063950062, 52.95140124857426, 54.04068119823933, 52.02967710793018, 46.68222405016422, 40.40647700428963, 39.492884427309036, 38.7860007584095, 38.98468069732189, 39.31710205972195, 40.49705274403095, 47.60685883462429, 53.573906645178795, 53.833478316664696, 55.71205951273441, 53.428188264369965, 54.069776237010956, 53.80444787442684, 51.60450652241707, 54.7224710136652, 52.8346411138773, 37.5786991417408, 50.13024643063545, 53.147307336330414, 48.60379993915558, 46.05186067521572, 41.79235763847828, 44.54121753573418, 44.59897443652153, 45.08163593709469, 43.71027432382107, 46.31273187696934, 40.840603709220886, 37.518848553299904, 38.3542413264513, 40.40593363344669, 41.695033460855484, 40.45815423130989, 41.54945567250252, 43.03541533648968, 42.43082977831364, 42.56184294819832, 40.10728485882282, 38.676680624485016, 38.69478665292263, 37.87870444357395, 40.553582310676575, 41.71809442341328, 41.538785845041275, 46.23254477977753, 46.418719589710236, 50.684249103069305, 51.95290222764015, 56.17153085768223, 55.52282586693764, 53.45688432455063, 54.69522647559643, 58.60644780099392, 50.92309668660164, 52.07784332334995, 53.55405271053314, 59.061066806316376, 49.07792329788208, 36.71470150351524, 32.81455658376217, 22.95669235289097, 19.4041470810771, 14.976272229105234, 18.142586275935173, 20.07300429046154, 7.933097938075662, 10.869813580065966, 6.680749263614416, 0.43639595503918827, 0.5063839245121926, 2.7311742212623358, 12.160402927547693, 38.92859190702438, 51.587019860744476, 57.5342783331871, 56.88851438462734, 51.8142856657505, 61.97886183857918, 44.769015312194824, 17.12759803980589, 0.8119142486248165, 0.19745615223655477, 0.2773505315417424, 0.1901466803974472, 0.11110015286249109, 0.18901060073403642, 0.2368881058646366, 0.23307389725232497, 0.14314951084088534, 0.16610096208751202, 0.16741135739721358, 0.11906292987987399, 0.19970119348727167, 0.1665262275491841, 0.19321644067531452, 0.17801793903345242, 0.1131699285178911, 0.09577973120030947, 0.12348257514531724, 0.20944906573276967, 0.15914026997052133, 0.1496988453436643, 0.2096412968239747, 0.12988843023777008], [0.0247721287450986, 0.09005855928990059, 0.06183790406794287, 0.07588226959342137, 0.04989721921447199, 0.08987125605926849, 0.04832568440178875, 0.05007215455407277, 0.027420525402703788, 0.02895725720009068, 0.10229818493826315, 0.046592005164711736, 0.06317396284430288, 0.07486775371944532, 0.03589646228647325, 0.05476394908328075, 0.03896306843671482, 0.0229895790835144, 0.01550764140120009, 0.04620976571459323, 0.022697376989526674, 0.01727938168187393, 0.02146141167031601, 0.09349789426778443, 0.01832490634114947, 0.4530465428251773, 11.906790286302567, 37.2586765140295, 48.388104513287544, 48.86521451175213, 22.772656828165054, 26.115307062864304, 33.09177450835705, 30.15405524522066, 16.38094000518322, 3.3860310819000006, 0.42762142431456596, 0.11074704641941935, 0.8811372716445476, 1.967162280343473, 8.871428612619638, 4.780712993815541, 4.236358478665352, 7.1431331522762775, 11.46506778895855, 16.881677135825157, 21.154766343533993, 29.7530285641551, 38.76320578157902, 47.496242970228195, 52.8161209076643, 52.28201396763325, 49.22473981976509, 52.312359139323235, 50.33262737095356, 49.57948498427868, 48.14913533627987, 45.56842781603336, 44.300185069441795, 39.9665442109108, 35.069689974188805, 35.15384025871754, 34.962277337908745, 39.56011801958084, 44.674784168601036, 46.728805750608444, 49.945906922221184, 50.45985594391823, 50.9986936300993, 50.09014718234539, 47.93064326047897, 47.02113926410675, 40.75929567217827, 35.949821546673775, 34.01040181517601, 34.352949634194374, 35.91593116521835, 35.83461932837963, 36.5330408513546, 40.39006568491459, 42.908182963728905, 45.49213171005249, 46.84819154441357, 48.26370298862457, 45.19623018801212, 46.03981152176857, 47.535361871123314, 55.10229863226414, 34.913750141859055, 47.03199528157711, 49.65905271470547, 44.387257397174835, 44.33856301009655, 44.2781500518322, 43.967433124780655, 46.16721868515015, 45.22477425634861, 46.033857241272926, 47.42083601653576, 43.169358149170876, 37.03964866697788, 35.9187164157629, 36.0387671738863, 37.56364814937115, 40.76922073960304, 45.14532811939716, 45.987336337566376, 48.5017754137516, 42.634548246860504, 39.362676814198494, 36.95272833108902, 35.26699438691139, 36.47166274487972, 38.04523430764675, 36.4092168956995, 40.44360861182213, 40.0988645106554, 41.3901150226593, 44.32278245687485, 46.82430222630501, 50.44577769935131, 54.46579858660698, 53.21296401321888, 54.22567047178745, 55.4343818128109, 52.637967467308044, 47.56202884018421, 46.11540086567402, 47.15943664312363, 44.767275005578995, 38.733164593577385, 22.409069538116455, 11.327179837971926, 8.870729450136423, 6.992528233677149, 11.994142848998308, 17.066512517631054, 1.7446262715384364, 4.503037193790078, 0.6630943436175585, 0.10210800217464566, 0.26058989809826016, 1.422778673004359, 14.44909991696477, 30.55529471486807, 37.815886214375496, 41.934728398919106, 38.82908284664154, 37.94072091579437, 43.8996447622776, 32.070149928331375, 9.744483064860106, 0.46876998036168516, 0.04626721907698084, 0.032458559653605334, 0.03932990461180452, 0.036351743910927325, 0.10241546653560363, 0.023146124003687873, 0.008087004189292202, 0.021140672142792027, 0.05357248293876182, 0.055800985428504646, 0.02212941508332733, 0.054104602822917514, 0.014769953104405431, 0.03841966419713572, 0.06414754927391186, 0.036302743610576726, 0.019127819214190822, 0.034569075505714864, 0.07567849068436772, 0.0640658313932363, 0.037527283566305414, 0.06917083519510925, 0.030803266054135747, 0.02483321677573258, 0.012063336816936499, 0.026600667442835402, 0.049551946140127257, 0.05007773550460115, 0.030111996311461553, 0.050252273795194924, 0.039475168887292966, 0.036075624157092534, 0.031122751352086198, 0.057575182217988186, 0.04019968684588093, 0.026930496424029116, 0.13759797904640436, 0.06513025669846684, 0.0508097380225081, 0.013209792632551398, 0.010457265234435908, 0.015093096262717154, 0.023928614828037098, 0.012959001451235963, 0.025340200118080247, 0.02712833073019283, 0.040170000938815065, 0.0317370659467997, 0.8897900604642928, 14.857115373015404, 43.85077938437462, 55.14893352985382, 53.12716841697693, 28.255287632346153, 28.641774393618107, 38.511503487825394, 33.081883639097214, 18.518610298633575, 3.6414483888074756, 0.4735774645814672, 0.13625944149680436, 0.8387840911746025, 2.1263288520276546, 6.355489091947675, 9.408392999321222, 6.641311654821038, 7.943906933069229, 10.565289370715618, 18.32240402698517, 22.645253464579582, 32.89615720510483, 41.76387436687946, 50.401232689619064, 51.63724556565285, 52.975898534059525, 51.320836544036865, 52.26665899157524, 52.65257768332958, 50.48251412808895, 51.02385587990284, 48.25345493853092, 44.83396142721176, 40.917169600725174, 36.44988231360912, 37.71194279193878, 36.89670033752918, 42.06809364259243, 47.34731376171112, 49.41393546760082, 52.22952738404274, 51.20370402932167, 51.26747600734234, 52.04995281994343, 50.044720619916916, 48.54332618415356, 41.736067458987236, 38.658886179327965, 36.99501246213913, 36.66080519556999, 38.07999484241009, 37.83676989376545, 39.06418763101101, 43.13795283436775, 46.000825613737106, 49.33215245604515, 48.526979461312294, 50.68294957280159, 47.07790061831474, 48.136269226670265, 49.69935715198517, 54.88382935523987, 37.58689910173416, 48.72968338429928, 51.644533574581146, 47.5621922314167, 46.068868562579155, 45.72260834276676, 44.80146177113056, 47.96878181397915, 47.70171694457531, 48.66509445011616, 47.90071226656437, 44.62769329547882, 38.228095695376396, 37.516013905406, 38.12248036265373, 39.08698260784149, 43.07887360453606, 45.818868577480316, 47.62694455683231, 49.79471303522587, 43.50914351642132, 40.78300639986992, 38.04430715739727, 38.42348501086235, 37.95682445168495, 39.541514217853546, 37.52230256795883, 41.56171761453152, 42.06880800426006, 42.7895837277174, 46.55341096222401, 49.53402042388916, 54.95085395872593, 55.10201744735241, 52.73486986756325, 52.71423697471619, 56.59566789865494, 55.415230840444565, 49.039982333779335, 49.702662974596024, 52.23748795688152, 47.521796599030495, 36.90154507756233, 23.249662332236767, 10.286246594041586, 13.283108733594418, 16.071543507277966, 9.364646896719933, 14.62814250960946, 4.93004260584712, 4.474827982485294, 1.3347889319993556, 0.06660414714133367, 0.10268803511280566, 1.8122321250848472, 14.31129651144147, 36.104089468717575, 39.766336753964424, 46.51920139789581, 45.17565809190273, 43.29262733459473, 52.14594706892967, 38.76153767108917, 12.781028375029564, 0.5604486109223217, 0.10886493022553623, 0.020802837243536487, 0.047798841187614016, 0.032464389223605394, 0.07026279417914338, 0.007384606406048988, 0.008837286732159555, 0.030814199744781945, 0.018825703882612288, 0.10241120660793968, 0.020468555376282893, 0.05545662519580219, 0.08097963669570163, 0.038216608882066794, 0.0861784553853795, 0.01577345272380626, 0.0525984400883317, 0.06101257276895922, 0.06295702565694228, 0.04293539161153603, 0.014854319524602033, 0.04548243872704916, 0.10105760346050374, 0.11793335143011063, 0.17829934658948332, 0.19114776339847594, 0.18656528351129964, 0.17934620525920764, 0.18594505585497245, 0.1898421029909514, 0.21281951456330717, 0.10286497796187177, 0.10426736989757046, 0.2353941329056397, 0.1610257852007635, 0.16888937418116257, 0.12795555114280432, 0.14658198837423697, 0.11056734278099611, 0.17619430407648906, 0.06976594115258195, 0.1041456799430307, 0.13033661321969703, 0.1065853716863785, 0.09817376601858996, 0.10514194640563801, 0.2643594442633912, 0.1807741419179365, 1.326105804182589, 18.75104572623968, 49.8720882833004, 62.67259821295738, 61.68031185865402, 32.653202041983604, 38.1649012863636, 44.33344088494778, 38.642345666885376, 22.2734472155571, 5.066347466781735, 0.7111399155110121, 0.35193040617741644, 2.931388565339148, 6.131180003285408, 18.76929994672537, 15.453100092709064, 8.69075495749712, 12.488669212907553, 17.65438087284565, 22.37355474382639, 23.0242071300745, 33.07294271886349, 41.53853505849838, 51.10364779829979, 54.78116266429424, 55.81232473254204, 53.12456175684929, 53.89785446226597, 53.66162493824959, 53.089090660214424, 53.726905435323715, 50.173655301332474, 49.15145315229893, 43.318564742803574, 39.06010664999485, 38.06537322700024, 38.50901082158089, 44.413008615374565, 49.401468336582184, 51.0773304104805, 55.07649801671505, 53.05312179028988, 51.92029997706413, 54.0201660990715, 51.900237053632736, 50.952172726392746, 45.176209062337875, 39.72554214298725, 38.573478162288666, 38.87009024620056, 40.431677252054214, 39.86620679497719, 40.47713801264763, 44.731439128518105, 45.768684670329094, 50.04359968006611, 50.78425593674183, 53.35612513124943, 49.04095508158207, 50.198988541960716, 52.65436738729477, 57.870298102498055, 41.49283491075039, 50.77423967421055, 53.46997082233429, 50.19597910344601, 48.71352665126324, 49.951268434524536, 46.65517710149288, 51.23695984482765, 49.25324209034443, 50.618915408849716, 51.838399171829224, 48.013566210865974, 41.18116043508053, 39.636535719037056, 41.451713517308235, 41.19128309190273, 46.22999511659145, 48.87584634125233, 50.737225860357285, 52.28474982082844, 46.00867219269276, 43.154626339673996, 40.94279162585735, 40.52889123558998, 39.980014488101006, 41.233928203582764, 39.557283371686935, 44.89363722503185, 44.476130828261375, 46.02638304233551, 49.39560525119305, 52.40735024213791, 56.775109469890594, 56.93891488015652, 54.326087683439255, 52.972664907574654, 59.083455204963684, 58.1076143682003, 52.69725948572159, 50.37292420864105, 55.57010293006897, 48.89041855931282, 41.725143045187, 27.232602909207344, 18.313618898391724, 15.176721923053265, 16.312585473060608, 18.105198182165623, 26.52234312146902, 6.664793444797397, 6.92646355368197, 2.5476970290765166, 0.42042407614644617, 0.7893767079804093, 2.0549610815942287, 17.76323363184929, 40.20026966929436, 49.92272436618805, 52.35243558883667, 50.08654497563839, 51.45998887717724, 59.608590826392174, 45.56056223809719, 14.613607339560986, 0.6068755290471017, 0.2119012107141316, 0.09756786923389882, 0.11205953458556905, 0.0791759803541936, 0.218014043639414, 0.1612478357856162, 0.09276442971895449, 0.08872465274180286, 0.1157284232613165, 0.1354188850382343, 0.08238668931880966, 0.23241653252625838, 0.10358354018535465, 0.08281788454041816, 0.20657132874475792, 0.12230434891534969, 0.11628198379185051, 0.11606859407038428, 0.16430296091130003, 0.21534643834456801, 0.09100193288759328, 0.16875069646630436, 0.251306610298343], [0.05297051953675691, 0.013252770404506009, 0.01839559590735007, 0.023561442831123713, 0.0046947561622801, 0.003234477635487565, 0.06889308642712422, 0.03689043551275972, 0.04490820938372053, 0.02902808591898065, 0.05804857595649082, 0.021529744917643256, 0.11092597822425887, 0.030838312122796196, 0.04067227535415441, 0.03315870919323061, 0.0012317449341026077, 0.037234035044093616, 0.11761504429159686, 0.009584677682141773, 0.022592394634557422, 0.0732805670122616, 0.05434636856080033, 0.08410397451370955, 0.06382834413670935, 0.046613705562776886, 8.270528856664896, 31.395237743854523, 46.47457659244537, 47.08959259092808, 33.37929368019104, 24.954666942358017, 24.336614906787872, 37.46855825185776, 21.83272786438465, 5.914644822478294, 0.6882178829982877, 0.044224865778232925, 0.23974947107490152, 1.525737235788256, 5.516452789306641, 6.223082821816206, 2.5728949019685388, 3.2947668666020036, 3.569715362973511, 10.414686352014542, 15.885090362280607, 26.278578601777554, 36.56516432762146, 46.03327967226505, 49.872855842113495, 49.515716806054115, 49.062355533242226, 51.23692184686661, 52.04196184873581, 51.7673771828413, 50.48553116619587, 48.38887967169285, 45.65155975520611, 40.18985062837601, 35.777990967035294, 35.769897401332855, 34.95758458971977, 36.13269813358784, 40.816361010074615, 45.96975088119507, 47.37208843231201, 49.86152485013008, 50.77708192169666, 50.696613639593124, 48.42270165681839, 47.38096095621586, 44.215563610196114, 40.81019774079323, 35.35342454910278, 35.311664789915085, 36.18097834289074, 35.763019770383835, 34.225531071424484, 36.7247823625803, 36.49750895798206, 38.58870394527912, 38.70709039270878, 41.41380675137043, 41.13563507795334, 45.26995003223419, 48.00800330936909, 54.688459038734436, 35.27438499033451, 41.22024893760681, 53.327714055776596, 49.39547225832939, 47.63707481324673, 45.5737741291523, 49.65070456266403, 49.46400538086891, 49.06248852610588, 49.49308522045612, 49.084968119859695, 47.1140518784523, 39.84686203300953, 33.88063117861748, 36.08921326696873, 40.30745431780815, 46.041589826345444, 50.76428420841694, 52.350596487522125, 48.417731523513794, 48.4822216629982, 45.612744837999344, 42.37735144793987, 35.545131862163544, 35.829512402415276, 36.13444223999977, 36.87262862920761, 37.43552282452583, 38.00004333257675, 40.32880537211895, 42.39845551550388, 42.404785975813866, 47.22231186926365, 52.029156535863876, 51.510518565773964, 56.486913934350014, 48.5335037112236, 58.27089920639992, 52.33301103115082, 52.04164646565914, 47.03057415783405, 45.00323474407196, 35.372917503118515, 23.660804070532322, 4.554113103076816, 8.126225899904966, 16.133113503456116, 9.653222411870956, 14.028164204210043, 3.7685881415382028, 4.217113461345434, 0.8384196669794619, 0.1542918785708025, 0.06475448506535031, 2.1760672330856323, 14.479342494159937, 33.85609969496727, 46.1177871376276, 39.46915850043297, 36.182038486003876, 48.91114644706249, 48.644032180309296, 32.91168697178364, 6.108527518808842, 0.5902614549268037, 0.14333173778140917, 0.0312792016484309, 0.03969571291236207, 0.03363694173458498, 0.032655358663760126, 0.05404824412835296, 0.011342115849402035, 0.021481980293174274, 0.014800607514189323, 0.020437056773516815, 0.02545630541135324, 0.07616772185429, 0.026804650442500133, 0.05015750524762552, 0.020884647892671637, 0.024453027508570813, 0.03671368562208954, 0.12677877210080624, 0.04644215812732, 0.047298704157583416, 0.05872157031262759, 0.06017416853865143, 0.043186690236325376, 0.051758525587501936, 0.015236041326716077, 0.05024333091569133, 0.029450321562762838, 0.037114259830559604, 0.033109716314356774, 0.01858143339632079, 0.08207173668779433, 0.011012007635144982, 0.017765017146302853, 0.056202246123575605, 0.09745367497089319, 0.05932659136306029, 0.006790106690459652, 0.02423232392175123, 0.017579847590241116, 0.020532294729491696, 0.034256972721777856, 0.036755334949702956, 0.09734784471220337, 0.03789863571000751, 0.03509141017275397, 0.042748889900394715, 0.06840188856585883, 0.02462418531649746, 0.23595737846335396, 10.269177909940481, 37.541677728295326, 54.766890630126, 52.09554277360439, 36.22665949165821, 30.744857043027878, 31.29105493426323, 37.85614125430584, 23.568119443953037, 7.039036313071847, 0.8515078865457326, 0.06206322752404958, 0.296146193286404, 2.0081464061513543, 4.494020277634263, 4.708001995459199, 9.672087449580431, 5.53630149923265, 5.251920958980918, 13.285496905446053, 18.21243602782488, 29.334957897663116, 37.34455570578575, 48.31818446516991, 51.760605946183205, 51.87135860323906, 50.31832113862038, 54.3395009636879, 52.646475210785866, 52.44233876466751, 51.559912115335464, 51.99851118028164, 48.544036746025085, 42.84672126173973, 37.996984496712685, 37.745791375637054, 36.97103574872017, 38.09662654995918, 43.25077638030052, 47.974755093455315, 49.8435328155756, 53.03956791758537, 52.01876409351826, 52.524038180708885, 50.49078248441219, 48.81779685616493, 45.70102170109749, 41.00228123366833, 37.72170066833496, 36.66377283632755, 36.74266040325165, 36.77901305258274, 35.95421031117439, 38.42761538922787, 38.27969312667847, 42.38310053944588, 39.87117312848568, 43.5622950643301, 42.947887033224106, 47.411503717303276, 49.26283277571201, 56.613029167056084, 36.29806146025658, 44.48477916419506, 54.40606199204922, 51.10593147575855, 49.37334984540939, 48.89266423881054, 50.83678811788559, 51.887990310788155, 49.64622460305691, 50.59877268970013, 51.051548793911934, 48.517445772886276, 41.52843900024891, 35.3840509057045, 37.403289154171944, 41.40952818095684, 48.68110679090023, 52.577805295586586, 53.828075006604195, 50.78327178955078, 50.29117539525032, 47.802521735429764, 43.934272304177284, 36.603036895394325, 38.05537596344948, 37.49230697751045, 39.299854785203934, 39.70079027116299, 40.14046087861061, 42.294044718146324, 44.44869250059128, 45.4381138086319, 50.34030295908451, 53.80649596452713, 52.42811992764473, 55.39260305464268, 52.514185309410095, 58.86503532528877, 55.16841508448124, 52.20041714608669, 51.262825056910515, 44.48907673358917, 36.14354655146599, 22.616872787475586, 11.102369651198387, 12.35962813720107, 16.728832237422466, 10.862482823431492, 9.329599477350712, 8.429344184696674, 3.5981713235378265, 1.3339804066345096, 0.37927528261207044, 0.23763736331602558, 2.6165752205997705, 16.88168853521347, 38.54296959936619, 49.44453522562981, 47.00299143791199, 42.19977557659149, 53.150369971990585, 53.648492842912674, 39.24555189907551, 8.706377819180489, 0.660988959716633, 0.06139919089036994, 0.03276402763731312, 0.021492617124749813, 0.032254877223749645, 0.030968568316893652, 0.06220667724846862, 0.04613320576027036, 0.09370302388560958, 0.0336852741020266, 0.040768071776255965, 0.03288661930128001, 0.10991010422003455, 0.038686232510372065, 0.035038743662880734, 0.041013091831700876, 0.018553864465502556, 0.030373161789611913, 0.05271616697427817, 0.04104231018573046, 0.019196629291400313, 0.03700762063090224, 0.05800965773232747, 0.013814331286994275, 0.12303216572036035, 0.10016703367000446, 0.12798584561096504, 0.10006783821154386, 0.05809319016407244, 0.24043442885158584, 0.09941753873135895, 0.16332927800249308, 0.0893093241029419, 0.07856310738134198, 0.12516952876467258, 0.223149141529575, 0.24994304752908647, 0.16100696433568373, 0.13266487891087309, 0.09177429339615628, 0.09620918979635462, 0.12750845169648528, 0.1834128182963468, 0.14291579369455576, 0.10217298462521285, 0.13052186812274158, 0.1769675180548802, 0.2985680289566517, 0.1701810970553197, 0.5721925932448357, 12.270730007439852, 43.3244164288044, 62.230541333556175, 59.00101862847805, 44.62952099740505, 35.691503807902336, 36.795051991939545, 46.26055687665939, 28.027598150074482, 8.628388904035091, 1.4268315117806196, 0.2743968431605026, 1.491577543783933, 4.872329877689481, 12.419208940118551, 15.325366146862507, 10.520194340497255, 6.941599566489458, 5.634769415482879, 12.951017003506422, 17.116367742419243, 30.55097244679928, 38.592522740364075, 49.46397878229618, 53.09274226427078, 53.35107520222664, 51.20884135365486, 57.1597970277071, 54.43709872663021, 54.41824793815613, 53.09914872050285, 53.95715028047562, 52.005214020609856, 44.61350105702877, 40.04810303449631, 39.349704310297966, 38.001882433891296, 40.373126193881035, 45.39109893143177, 50.4863291233778, 51.39072619378567, 54.66100551187992, 54.56122286617756, 53.36844027042389, 52.32877805829048, 52.780034244060516, 47.60811276733875, 44.757080152630806, 39.974447786808014, 37.96674191951752, 38.796963170170784, 38.92492890357971, 37.844475880265236, 41.10727719962597, 38.490923792123795, 42.86553405225277, 43.101854771375656, 45.827535912394524, 45.95057711005211, 49.293508529663086, 51.20872735977173, 58.57810512185097, 40.396871119737625, 44.48555052280426, 57.57967829704285, 54.857766553759575, 50.58773048222065, 50.00399820506573, 53.47619108855724, 55.15194296836853, 52.32087828218937, 54.32055898010731, 53.483319506049156, 51.64138354361057, 44.19149570167065, 36.89799226820469, 39.2875624448061, 44.978258684277534, 49.96207885444164, 54.2919997125864, 56.026367247104645, 53.175862804055214, 52.097492069005966, 51.73029877245426, 45.90693265199661, 38.75746808946133, 40.02546764910221, 39.98387888073921, 40.59902787208557, 42.79697433114052, 41.48140512406826, 45.16728334128857, 46.28093518316746, 46.72808758914471, 51.973383128643036, 57.44529090821743, 52.1345666795969, 58.62950876355171, 53.25055919587612, 60.65988801419735, 57.25079834461212, 56.63219913840294, 51.72042690217495, 49.99962463974953, 41.24632313847542, 27.91758645325899, 11.151439268141985, 16.664668880403042, 28.199508525431156, 16.979652978479862, 22.07387812435627, 12.927829697728157, 8.084421493113041, 1.7390976869501173, 0.713840858079493, 0.3420267126057297, 3.9487039390951395, 19.593109041452408, 43.30950602889061, 59.22017566859722, 50.391661003232, 49.14565846323967, 60.92972293496132, 62.10374593734741, 47.11798086762428, 10.304478015750647, 0.8208735147491097, 0.31988081813324243, 0.10186304149101488, 0.12544014549348503, 0.13159344031009823, 0.12169811816420406, 0.19254947255831212, 0.13321387523319572, 0.14268323429860175, 0.19067050307057798, 0.10832203435711563, 0.11964359364355914, 0.23570245073642582, 0.11709102866007015, 0.14119326893705875, 0.1253273242036812, 0.22899532079463825, 0.11480061992187984, 0.12254716479219496, 0.17671045294264331, 0.10522497788770124, 0.11248585389694199, 0.09714650004752912, 0.18665088282432407], [0.04860363726038486, 0.028455817700887565, 0.01589801107911626, 0.016151541713043116, 0.022218691738089547, 0.023615601057827007, 0.02047754835075466, 0.052847734914394096, 0.0440504944708664, 0.044084633263992146, 0.0496302835381357, 0.055548666350659914, 0.0566469447221607, 0.021004833142796997, 0.010602597230899846, 0.028683586533588823, 0.04238900022755843, 0.013577716053987388, 0.016950562021520454, 0.018186779670941178, 0.03153009580273647, 0.04099882404261734, 0.07118287176126614, 0.04238818015437573, 0.03899395662301686, 0.03266570420237258, 5.41083793155849, 26.447082459926605, 44.83929254114628, 44.663567170500755, 31.78761798888445, 26.316859647631645, 35.143831595778465, 33.633329048752785, 23.02457571029663, 9.23971340060234, 1.364043562207371, 0.08505230565788224, 0.3538586542708799, 0.6724689155817032, 2.763164942152798, 5.474261278286576, 12.803879398852587, 6.353212064132094, 2.0496204681694508, 6.7281232215464115, 10.221367925405502, 18.535452894866467, 31.402297765016556, 44.8121277987957, 49.57472003996372, 48.59368868172169, 46.41703628003597, 48.030870482325554, 48.11834178864956, 52.05219089984894, 49.314225018024445, 50.417602211236954, 48.06023150682449, 44.62234318256378, 37.100388407707214, 34.23325605690479, 35.19585080444813, 35.7562143355608, 38.00082229077816, 42.06644453108311, 46.541430205106735, 50.2070365101099, 50.3910568356514, 50.38911893963814, 51.1419041454792, 48.68472419679165, 45.8392620831728, 45.07700778543949, 41.81150861084461, 37.99542278051376, 34.71310570836067, 34.70501974225044, 35.55987507104874, 35.29986262321472, 35.60948520898819, 36.11788272857666, 35.58080054819584, 37.84894824028015, 41.10483393073082, 47.29548454284668, 47.33638554811478, 53.79654809832573, 33.39706152677536, 44.097956120967865, 51.31149284541607, 50.81121928989887, 53.664007410407066, 49.13819566369057, 48.75883162021637, 51.26516953110695, 51.05690270662308, 53.259857296943665, 49.22026365995407, 50.61310552060604, 40.57213291525841, 32.5055343657732, 34.61446300148964, 38.52009862661362, 49.69691388309002, 48.91589239239693, 50.44315204024315, 53.144503086805344, 51.242218762636185, 51.174852177500725, 48.035399839282036, 42.69498400390148, 37.2579051554203, 36.787866577506065, 37.22370699048042, 37.48933553695679, 37.11791306734085, 39.229315370321274, 43.02221864461899, 46.63797542452812, 53.14898684620857, 52.629573717713356, 42.647539749741554, 53.890570253133774, 43.34648944437504, 55.00085927546024, 55.49815759062767, 52.41764388978481, 47.78419151902199, 40.524126291275024, 26.980902515351772, 19.293567314743996, 8.469962105154991, 15.877491720020771, 14.388176836073399, 5.255216332152486, 7.71373713389039, 6.4206247217953205, 3.479639058932662, 1.5830043191090226, 0.0977323811093811, 0.30335010203998536, 2.618061415851116, 15.440575014799833, 39.257623851299286, 44.39222753047943, 30.464300997555256, 39.93823193013668, 47.55784146487713, 50.67902438342571, 30.04386305809021, 5.390058271586895, 0.3863880259450525, 0.09355704343761317, 0.010229292311123572, 0.0424922960519325, 0.06014571088599041, 0.049068863663706, 0.04352711337560322, 0.008439541034022113, 0.039824375344323926, 0.016736033103370573, 0.011492874800751451, 0.054210733651416376, 0.04167018938460387, 0.031037038861541077, 0.04327679438574705, 0.11324484090437181, 0.051169831785955466, 0.06580547007615678, 0.029994634933245834, 0.018064976538880728, 0.02837316471413942, 0.054830824010423385, 0.03321310490719043, 0.07060214120429009, 0.05964194475382101, 0.03505874454276636, 0.043080229152110405, 0.020664664189098403, 0.03313785113277845, 0.028111960273236036, 0.011346308056090493, 0.019392875401536003, 0.029076483224343974, 0.07340595286223106, 0.018469252208888065, 0.06081303894461598, 0.015616996861353982, 0.02581460132205393, 0.03945203985495027, 0.047869679183349945, 0.0252456189627992, 0.0722601955931168, 0.039842539408709854, 0.03427241310419049, 0.027749317232519388, 0.04037074446387123, 0.09850711649050936, 0.05153793332283385, 0.008369769875571365, 0.10478358555701561, 7.393846549093723, 31.9586943089962, 51.48966148495674, 49.4986367225647, 35.930290594697, 28.43802932649851, 35.91436944901943, 40.915695279836655, 25.45073412358761, 9.516778383404016, 1.598829401191324, 0.031406843627337366, 0.23414741386659443, 1.6963110328651965, 3.54384183883667, 4.980219388380647, 9.255463555455208, 6.181679293513298, 4.381783325225115, 9.167434629052877, 13.360521979629993, 21.3815875723958, 34.407377913594246, 46.27258703112602, 51.76941007375717, 49.55790214240551, 49.56962451338768, 49.108542054891586, 52.21872076392174, 52.51828148961067, 50.20636774599552, 52.20470331609249, 50.81035293638706, 45.519592836499214, 39.86918963491917, 36.76566816866398, 35.722802728414536, 37.391027212142944, 39.46802236139774, 44.88840110599995, 50.20423986017704, 52.889358177781105, 52.35359072685242, 51.65228895843029, 51.27890959382057, 50.77792547643185, 48.067299127578735, 46.35535418987274, 42.500955015420914, 40.093164816498756, 36.24689720571041, 36.761154010891914, 36.774985268712044, 37.08894342184067, 37.32262708246708, 37.45319567620754, 37.729319259524345, 39.31770242750645, 42.86062091588974, 48.72861564159393, 50.02320237457752, 56.82020545005798, 35.643121004104614, 44.77502278983593, 54.46382649242878, 52.440849244594574, 54.78967800736427, 50.48571355640888, 50.92587433755398, 52.91434943675995, 54.539377838373184, 56.14528946578503, 51.31851866841316, 51.77250690758228, 43.95612493157387, 35.465906113386154, 36.631394773721695, 40.429104790091515, 51.633521765470505, 50.69974847137928, 53.82835619151592, 53.23522321879864, 53.2675176858902, 52.53186956048012, 49.07606139779091, 44.146715104579926, 38.06286156177521, 38.333551436662674, 38.403311893343925, 39.42931763827801, 39.149344861507416, 41.25235341489315, 45.044812113046646, 48.25269117951393, 53.34383279085159, 53.05147647857666, 47.15248301625252, 54.80568274855614, 46.21928349137306, 56.32205218076706, 56.472569704055786, 54.10774379968643, 51.74989432096481, 42.37632930278778, 29.392325319349766, 18.453514091670513, 7.695234026759863, 12.882467731833458, 16.627472676336765, 10.727107487618923, 9.846395496279001, 11.100436504930258, 2.682565567083657, 1.374216447584331, 0.07118602588889189, 0.41827348060905933, 2.7985011460259557, 18.652306124567986, 39.16691891849041, 49.037041291594505, 36.456022784113884, 43.255624920129776, 54.16480153799057, 57.55360409617424, 37.22962707281113, 6.929919943213463, 0.4595471330685541, 0.06308293101028539, 0.04776220506755635, 0.02201126146246679, 0.06402701706974767, 0.03471694471954834, 0.05388786601542961, 0.09084630451980047, 0.05054151843069121, 0.052321604161988944, 0.05325315534719266, 0.004935173974445206, 0.07022964244242758, 0.05142056637851056, 0.04298184263461735, 0.020661719718191307, 0.0839939436991699, 0.09960076757124625, 0.09488769937888719, 0.031289962789742276, 0.02296305843628943, 0.08721338032046333, 0.06237667359528132, 0.039186551366583444, 0.14801560988416895, 0.10357537656091154, 0.15956749470205978, 0.11838937891297974, 0.1270883812685497, 0.08143043203745037, 0.12303436247748323, 0.13989174971356988, 0.1314885006286204, 0.10281928392942064, 0.16414905432611704, 0.18322737043490633, 0.15179591719061136, 0.09251238152501173, 0.12394001270877197, 0.11143587820697576, 0.157013556745369, 0.2534722862765193, 0.137356246705167, 0.10017373526352458, 0.13649822009028867, 0.13881464110454544, 0.14251205051550642, 0.23530863749329, 0.1506036421051249, 0.35980005108285695, 8.712517339736223, 37.13427118957043, 60.485009998083115, 56.58934123814106, 43.117350339889526, 37.10625149309635, 46.39926843345165, 45.50272174179554, 29.76943038403988, 12.046717777848244, 2.2750630835071206, 0.5419168272055686, 0.8083754510153085, 4.070971878245473, 5.698899524286389, 13.13777033239603, 18.014844730496407, 12.265319097787142, 5.253188665956259, 8.319212794303894, 14.20247320085764, 21.68939385563135, 35.65075859427452, 48.18681411445141, 53.46187345683575, 51.673104241490364, 50.77973797917366, 51.47125907242298, 53.391641825437546, 55.02158336341381, 51.64139874279499, 53.967424929142, 54.80262391269207, 49.292152002453804, 41.65840342640877, 38.68688687682152, 38.92759256064892, 39.104872047901154, 42.63904720544815, 46.92229896783829, 52.431896924972534, 54.81786869466305, 53.525318652391434, 53.13836641609669, 54.03807073831558, 53.90795812010765, 51.413429975509644, 50.53905129432678, 45.29131628572941, 41.51000998914242, 37.29347884654999, 38.75825084745884, 38.558244779706, 38.90660248696804, 39.63862180709839, 40.158042535185814, 39.086264446377754, 41.29323922097683, 44.85262222588062, 49.966779202222824, 51.28011032938957, 58.188626021146774, 39.440325647592545, 45.890308544039726, 55.05447819828987, 54.590040519833565, 55.861148312687874, 52.89307817816734, 53.58305275440216, 56.11907847225666, 54.73932310938835, 57.55644254386425, 55.11004641652107, 54.1301853954792, 44.97607760131359, 36.19726426899433, 37.60328762233257, 42.908722534775734, 54.19922389090061, 53.560185581445694, 54.41494211554527, 57.629945799708366, 54.71145920455456, 54.42452900111675, 51.0027252137661, 46.99250780045986, 40.56159608066082, 40.058389082551, 40.379376858472824, 42.46471256017685, 40.940006375312805, 44.20658089220524, 46.518190652132034, 53.19219432771206, 56.544446647167206, 56.517836675047874, 48.2198229432106, 57.345987036824226, 51.926303654909134, 55.887055322527885, 58.96821118891239, 55.82081347703934, 53.11959162354469, 45.91748848557472, 30.605771206319332, 22.780520506203175, 16.30878947675228, 26.472370103001595, 28.41626789420843, 11.564317513257265, 22.388463243842125, 14.893278982490301, 8.189106825739145, 4.270903374999762, 0.4666675650514662, 0.5334936885628849, 4.373397650197148, 21.107990853488445, 49.958290457725525, 57.26337566971779, 42.37915635108948, 52.48922824859619, 60.054192915558815, 64.3569566309452, 43.341325521469116, 8.944455944001675, 0.5696494015865028, 0.1608368640881963, 0.12036103522405028, 0.09449032382690348, 0.15186171600362286, 0.12869674887042493, 0.22281250334344804, 0.19184079574188218, 0.1496050675632432, 0.19252033584052697, 0.1253269679727964, 0.13895817246520892, 0.09294348768889904, 0.07532391478889622, 0.11638396230409853, 0.2998524490976706, 0.1178603240987286, 0.18055333814118057, 0.1555689811357297, 0.11756791049265303, 0.17714880988933146, 0.2079284199862741, 0.13830984709784389, 0.13541986467316747], [0.03222446030122228, 0.03031770665984368, 0.024993329570861533, 0.04792526604433078, 0.012513556994235842, 0.0382554937095847, 0.05917772767134011, 0.054438847582787275, 0.008033538015297381, 0.05218128630076535, 0.014526021222991403, 0.07256619050167501, 0.05632458545733243, 0.06969021240365691, 0.0149057837552391, 0.01597529091668548, 0.03240663529140875, 0.014356289266288513, 0.10982829728163779, 0.04515929649642203, 0.007293164535440155, 0.02920117331086658, 0.03036179579794407, 0.02244324150524335, 0.041131393882096745, 0.05278106407786254, 2.1290936786681414, 20.86654230952263, 40.737169459462166, 45.05115017294884, 43.81815053522587, 31.214251555502415, 26.712228432297707, 32.66359068453312, 29.213470816612244, 12.443867716938257, 3.0718406662344933, 0.23904308007331565, 0.03759918283321895, 1.2460049148648977, 2.8853155625984073, 1.9192280899733305, 9.902363643050194, 3.1065990636125207, 2.3435636702924967, 6.433102302253246, 7.562334258109331, 15.743636302649975, 25.23699749261141, 40.73043242096901, 48.29112611711025, 48.30475978553295, 44.99634951353073, 46.40633225440979, 48.81565757095814, 49.77154187858105, 51.8731103092432, 52.31864780187607, 47.639149501919746, 47.137998193502426, 39.40857455134392, 35.53037725389004, 33.84110189974308, 36.192191541194916, 37.957728803157806, 44.87623795866966, 45.416090190410614, 50.46896405518055, 51.85528166592121, 49.67077128589153, 48.253561332821846, 50.00089377164841, 48.61345902085304, 47.68677994608879, 47.68970958888531, 43.87423172593117, 39.55033354461193, 36.29983976483345, 35.44067166745663, 34.668739289045334, 35.82298435270786, 38.252326995134354, 35.38913123309612, 39.226248934865, 44.008919298648834, 48.194922879338264, 48.256870955228806, 55.465954318642616, 30.807661972939968, 36.21160089969635, 39.23000693321228, 46.07475444674492, 54.622095599770546, 48.85557442903519, 51.1571641266346, 49.219161719083786, 46.07843264937401, 49.40757840871811, 49.49916109442711, 46.96807511150837, 42.19627596437931, 36.02478392422199, 34.94398891925812, 40.650712698698044, 46.20368532836437, 49.739897176623344, 51.40899941325188, 50.70490479469299, 53.00065040588379, 49.942855685949326, 48.903584852814674, 46.41928195953369, 41.4112950861454, 34.495624378323555, 38.0440753698349, 37.80331648886204, 36.34780079126358, 36.05738237500191, 40.77574118971825, 46.82464800775051, 46.829340755939484, 57.89198733866215, 45.70913426578045, 46.94251388311386, 53.15643444657326, 45.62201254069805, 60.7404550909996, 47.70718105137348, 48.7957314401865, 30.772143378853798, 22.552652433514595, 13.63745966926217, 5.783065007999539, 7.628845889121294, 14.578009899705648, 13.222905714064837, 6.060995869338512, 6.525780279189348, 2.1828406071290374, 1.6649384913034737, 0.145232422510162, 0.42312970908824354, 4.10495487973094, 19.011510349810123, 37.456748485565186, 51.21228016912937, 38.858516067266464, 40.466099604964256, 48.36806818842888, 47.295454144477844, 26.550501510500908, 3.1748764123767614, 0.13826864305883646, 0.031150921422522515, 0.13304042047820985, 0.07763980145682581, 0.06912302604177967, 0.06937734520761296, 0.034797308180714026, 0.03495210905384738, 0.023463729812647216, 0.03213904652511701, 0.0429658307984937, 0.01986313727684319, 0.09518567909253761, 0.06609866293729283, 0.037635510961990803, 0.019853593257721514, 0.016706818460079376, 0.03694916536915116, 0.06708060594974086, 0.06760249161743559, 0.04033608616737183, 0.06251180384424515, 0.02533625745854806, 0.03304632948129438, 0.0390103469544556, 0.030039976445550565, 0.03359570800967049, 0.04001370834885165, 0.03956485743401572, 0.025991252878156956, 0.07034825990558602, 0.025098760925175156, 0.118989360780688, 0.0381431733694626, 0.019745241552300286, 0.03738785999303218, 0.05237342091277242, 0.10321894529624842, 0.023883434732852038, 0.031216330608003773, 0.03140513668768108, 0.12910228804685175, 0.07249823946040124, 0.023154103946581017, 0.07351325999479741, 0.07023717524134554, 0.028773360427294392, 0.005818959143653046, 0.05982704751659185, 0.08470866159768775, 3.2911202497780323, 25.557905472815037, 46.712060049176216, 52.18655928969383, 46.389442160725594, 37.723668962717056, 33.51875759661198, 37.01984412968159, 31.768372021615505, 14.185514710843563, 3.252414814196527, 0.3070082073099911, 0.10679479833925143, 1.1137162009254098, 3.7153178500011563, 5.0395470298826694, 8.432677555829287, 6.3806575164198875, 4.7047992423176765, 6.4399960823357105, 11.590461060404778, 18.557641804218292, 28.148006089031696, 44.96209055185318, 50.35651668906212, 52.75731146335602, 47.12101690471172, 49.09196734428406, 50.38006402552128, 52.58429154753685, 52.193360924720764, 53.927333280444145, 50.5189123749733, 49.8317002505064, 41.22378274798393, 38.35261881351471, 36.57507039606571, 38.56161519885063, 40.86478181183338, 46.33660979568958, 47.40687556564808, 51.93093180656433, 53.06599169969559, 49.64699976146221, 49.49378438293934, 53.73314470052719, 50.65706916153431, 49.42962862551212, 48.94959278404713, 44.722581803798676, 39.64172624051571, 37.31812432408333, 37.05908082425594, 36.366096809506416, 36.61909483373165, 39.981447011232376, 37.21796929836273, 41.49999752640724, 45.20633764564991, 49.37809579074383, 49.1968797147274, 57.734603583812714, 33.829949498176575, 38.98452490568161, 40.622749999165535, 48.40345948934555, 56.49987503886223, 49.619398042559624, 51.47387333214283, 49.95874643325806, 45.88853403925896, 51.13590806722641, 52.11082175374031, 49.28977333009243, 43.41483257710934, 36.22351326048374, 36.26170501112938, 40.26609733700752, 47.71779388189316, 52.371229380369186, 53.775364235043526, 53.43852750957012, 53.34464594721794, 51.93732686340809, 51.185563802719116, 48.07371698319912, 42.16627657413483, 36.07929199934006, 39.87954027950764, 39.53870236873627, 38.45299422740936, 39.1446179151535, 43.92717808485031, 48.31927880644798, 50.28467394411564, 59.241017550230026, 46.30288280546665, 52.02380642294884, 55.11294186115265, 50.09570248425007, 62.629991099238396, 51.44073911011219, 49.522336050868034, 36.63495518267155, 27.563717141747475, 13.750804737210274, 8.68270793929696, 11.520883943885565, 17.044587694108486, 11.581014767289162, 9.26646301522851, 9.912491999566555, 2.3434145282953978, 0.7918029371649027, 0.06171058121253736, 0.35289234830997884, 4.519015336409211, 20.440246984362602, 43.93200382590294, 53.64017128944397, 42.77672901749611, 44.56089287996292, 54.08152520656586, 53.225624933838844, 32.91764885187149, 3.828276051208377, 0.09213526660460047, 0.04665112464863341, 0.0908860019990243, 0.054323907461366616, 0.02368454101087991, 0.06031334720319137, 0.07193289362476207, 0.07352436252404004, 0.07327874875045381, 0.02913278996857116, 0.05434079132101033, 0.05494896278833039, 0.05825415828439873, 0.0666911862208508, 0.052602106297854334, 0.0603282346855849, 0.060515682635013945, 0.04874186226516031, 0.0630207167705521, 0.08577571410569362, 0.022164822948980145, 0.030183266608219128, 0.019943632469221484, 0.06270402009249665, 0.23525003751274198, 0.12425039371009916, 0.18186334753409028, 0.14681393920909613, 0.1319133653305471, 0.11005529057001695, 0.14625226700445637, 0.10064616421004757, 0.14174711890518665, 0.14071945217438042, 0.10655965626938269, 0.17187487101182342, 0.10630033502820879, 0.19188198493793607, 0.12414581768098287, 0.09376053290907294, 0.11539430095581338, 0.19374768482521176, 0.23596858489327133, 0.10183489925111644, 0.2589976944727823, 0.1435016153845936, 0.08923841931391507, 0.08079154678853229, 0.1423593907384202, 0.1022973537328653, 4.415307501330972, 28.03377091884613, 55.19464507699013, 59.11316581070423, 55.11845916509628, 44.122601598501205, 39.70549061894417, 44.15931522846222, 37.98740901052952, 16.517759263515472, 4.699501376599073, 0.6108327198307961, 0.49714412656612694, 2.8672608314082026, 5.8631419111043215, 10.015820804983377, 19.426429085433483, 11.777227688580751, 6.123106861487031, 10.943225640803576, 11.685701049864292, 19.015652127563953, 28.55846766382456, 45.7864411175251, 52.51610040664673, 54.92371581494808, 49.95876543223858, 50.93394510447979, 53.23537901043892, 54.4430910050869, 53.456872925162315, 56.45295135676861, 52.40859657526016, 53.23530301451683, 44.54448916018009, 40.7878777384758, 38.52069139480591, 41.00812152028084, 43.144610077142715, 49.14522908627987, 50.25849334895611, 54.48121815919876, 57.12948225438595, 50.07844001054764, 50.52614338696003, 54.04772222042084, 52.93200708925724, 50.978334322571754, 52.96356439590454, 46.05624943971634, 43.39274816215038, 40.3935045003891, 38.783158510923386, 38.13791133463383, 39.15718004107475, 42.45162986218929, 38.652103543281555, 44.244343265891075, 48.735341280698776, 50.294086039066315, 52.381629422307014, 58.22940543293953, 37.80219554901123, 43.28440077602863, 46.58312916755676, 48.17810118198395, 55.7831346988678, 49.14975844323635, 52.66989715397358, 50.945089906454086, 47.08410568535328, 52.809205278754234, 53.060656785964966, 52.10824929177761, 46.175319850444794, 38.831651508808136, 37.02195681631565, 43.42314653098583, 49.689329490065575, 55.199881196022034, 55.1034651696682, 53.488164246082306, 55.028001219034195, 53.11527505517006, 53.34343001246452, 51.722592785954475, 44.84848044812679, 37.83274210989475, 41.37820266187191, 41.5669309347868, 41.00794292986393, 39.54328492283821, 47.533184587955475, 49.735291823744774, 52.77277663350105, 61.17634490132332, 49.433781802654266, 51.6756197065115, 57.815049067139626, 52.723892256617546, 61.57974265515804, 52.27626867592335, 52.785057574510574, 33.280024006962776, 27.448602318763733, 17.051070146262646, 13.414811566472054, 15.07589528337121, 21.0647339746356, 21.086465008556843, 13.860354758799076, 13.595164138823748, 4.8480563051998615, 3.239804240874946, 0.2734767581569031, 0.8867303933948278, 5.79732421785593, 25.501636192202568, 48.89430195093155, 62.71001100540161, 52.41134002804756, 53.54425683617592, 62.89362855255604, 60.30938722193241, 37.956535667181015, 6.586825903505087, 0.2166506738285534, 0.15475809574127197, 0.28365970705635846, 0.23055432073306292, 0.2459985326277092, 0.21852333506103605, 0.19366484630154446, 0.11004314161255024, 0.200551561138127, 0.08808346683508717, 0.20306972757680342, 0.13121654803398997, 0.18958821427077055, 0.10857799366931431, 0.14155337383272126, 0.15197979169897735, 0.07736062776530161, 0.15016099554486573, 0.21501731069292873, 0.12421251449268311, 0.16585891804425046, 0.11184392584254965, 0.13638888689456508, 0.2188209511223249], [0.03520470272633247, 0.02231047685199883, 0.040926345900516026, 0.035280928714200854, 0.014485716110357316, 0.055588660688954405, 0.02697725543839624, 0.05638246926537249, 0.0335724008618854, 0.037903229604125954, 0.012910272962471936, 0.05491104275279213, 0.021357592631829903, 0.06628621107665822, 0.040216570705524646, 0.07839754907763563, 0.07358632443356328, 0.012184549941594014, 0.013117674479872221, 0.0709823879878968, 0.029968800772621762, 0.05138811968208756, 0.09652363776694983, 0.027022724971175194, 0.02194248478190275, 0.0391529209446162, 0.43401232513133436, 10.202739425003529, 34.250442534685135, 49.240607768297195, 42.817896008491516, 32.70693875849247, 28.28467335551977, 36.84951066970825, 30.31772766262293, 15.272372290492058, 4.363426510244608, 0.6779459654353559, 0.246598529338371, 0.5007029324769974, 3.68248428683728, 3.003953746519983, 4.144613351672888, 3.598203621804714, 4.719505878165364, 2.3333096830174327, 6.685609677806497, 9.490641485899687, 20.19260097295046, 40.01330830156803, 48.07410076260567, 46.59077435731888, 42.31656990945339, 45.3021989017725, 43.29789385199547, 46.66326306760311, 50.482764914631844, 51.73733979463577, 50.72936028242111, 47.31663800776005, 41.74607992172241, 34.46561358869076, 37.69599884748459, 38.72987017035484, 39.600836634635925, 46.21270604431629, 44.979356825351715, 47.95722283422947, 50.25071516633034, 47.799949273467064, 47.840029522776604, 49.805284067988396, 52.0279747992754, 49.81537252664566, 48.08968372642994, 48.12105104327202, 44.574059173464775, 40.20130701363087, 35.16320675611496, 36.363436952233315, 38.53535860776901, 36.480565667152405, 37.13443458080292, 40.81200264394283, 45.12748807668686, 49.82327230274677, 48.18613775074482, 55.33236488699913, 32.042434215545654, 30.607386119663715, 47.39638812839985, 45.567778050899506, 49.92775909602642, 48.151137828826904, 50.9072857350111, 54.95610527694225, 51.93628191947937, 50.438261702656746, 51.18382349610329, 47.237332463264465, 43.07844802737236, 35.38348473608494, 35.507506281137466, 37.25208766758442, 42.28080242872238, 46.85194954276085, 49.09296669065952, 51.177580431103706, 51.914368495345116, 50.107044875621796, 50.43721295893192, 46.828972175717354, 43.22747603058815, 36.82368725538254, 35.98802849650383, 37.554608434438705, 37.951329946517944, 37.80597634613514, 41.8919312953949, 47.39746727049351, 48.674928322434425, 51.664847284555435, 54.87042747437954, 44.19198587536812, 47.78663098812103, 50.455873757600784, 48.3157753944397, 46.14907085895538, 36.64210259914398, 28.847483955323696, 21.07347920536995, 8.227474316954613, 4.639542018994689, 12.077982500195503, 19.696273505687714, 9.554973933845758, 6.121804006397724, 14.073493871837854, 1.5453390777111053, 0.42676664830651134, 0.009745423158165067, 0.7520080881658942, 4.924024203792214, 22.901876494288445, 35.59451401233673, 37.49602697789669, 27.11126022040844, 36.55856028199196, 55.599528551101685, 46.55113868415356, 24.569375216960907, 2.934476137161255, 0.13588099071057513, 0.11351278590154834, 0.037482702755369246, 0.0470458729978418, 0.03655347820313182, 0.04372471019451041, 0.0490483024623245, 0.07631434797076508, 0.05689629520929884, 0.05202946143981535, 0.027046343820984475, 0.05034802568843588, 0.043160455315955915, 0.0318847310700221, 0.04974975447112229, 0.027674896518874448, 0.0834137771744281, 0.035609937622211874, 0.02046017467364436, 0.015243101006490178, 0.07320181030081585, 0.07330750697292387, 0.03268514105002396, 0.06405782361980528, 0.04594793230353389, 0.015269596606231062, 0.037155493555474095, 0.028824177134083584, 0.025944443768821657, 0.039395881540258415, 0.022240405123739038, 0.037710542092099786, 0.004835534618905513, 0.0017372180059282982, 0.011053854559577303, 0.03274828668509144, 0.02889348445023643, 0.07577093259897083, 0.01893504821055103, 0.033234460206585936, 0.04341468542406801, 0.03483232270809822, 0.026948842314595822, 0.07238290971145034, 0.05416957785200793, 0.019125125218124595, 0.057071891060331836, 0.11232538672629744, 0.04933926888043061, 0.04679239988035988, 1.0960445366799831, 13.691719807684422, 40.175639390945435, 54.921249747276306, 47.94314078986645, 38.206733241677284, 31.294850930571556, 38.682023137807846, 35.610716342926025, 16.933443658053875, 4.464154355227947, 0.6050100666470826, 0.09709662772365846, 0.788919604383409, 4.235181966796517, 5.5149798933416605, 6.464845798909664, 7.8080471232533455, 4.926135940477252, 5.335918301716447, 7.428075112402439, 13.308042045682669, 24.97586790472269, 41.77802100777626, 50.35328306257725, 49.10055488348007, 45.20811215043068, 46.02691501379013, 45.957124158740044, 49.53685887157917, 54.01960372924805, 52.499263510107994, 53.00908975303173, 49.31106358766556, 43.17930981516838, 36.15947149693966, 39.032094553112984, 40.11954680085182, 41.12852565944195, 46.61435969173908, 47.527568489313126, 50.80467604100704, 52.17565007507801, 49.20270100235939, 48.58275666832924, 50.02991661429405, 52.27800138294697, 51.258690878748894, 50.00262267887592, 49.47064742445946, 46.889358535408974, 41.15250997245312, 37.06122010946274, 37.0665892213583, 39.060840010643005, 39.332495033741, 38.89837212860584, 42.95364752411842, 46.360039338469505, 51.91275738179684, 49.35745529830456, 55.78324109315872, 34.541750103235245, 34.49253514409065, 49.96282361447811, 47.22391538321972, 50.411283150315285, 48.54076512157917, 50.59496149420738, 53.98102059960365, 51.76192827522755, 51.574233546853065, 52.1392822265625, 49.67551343142986, 45.5069737136364, 38.28127384185791, 38.00461068749428, 38.90998810529709, 45.94075843691826, 48.30585792660713, 52.35766790807247, 51.27028025686741, 52.772788032889366, 52.00884662568569, 53.919254913926125, 49.31921035051346, 44.58105839788914, 38.712885081768036, 38.28805647790432, 38.82462568581104, 40.084383487701416, 39.69673588871956, 44.87365409731865, 49.57241356372833, 50.166933462023735, 54.00145210325718, 55.39803296327591, 47.587749660015106, 53.301670253276825, 52.520523369312286, 51.90354287624359, 48.84121499955654, 41.973934695124626, 28.756885416805744, 19.277592971920967, 7.385622365400195, 8.370122462511063, 8.807335551828146, 11.874462570995092, 12.608281094580889, 7.812254447489977, 8.626122325658798, 1.3696619169786572, 0.3958714858163148, 0.031540385680273175, 0.6390976218972355, 6.157323075458407, 25.18950194120407, 37.9936558753252, 48.21050584316254, 35.03327272832394, 42.77884170413017, 64.16455015540123, 51.01069338619709, 28.524265699088573, 3.31554913893342, 0.06375115335686132, 0.07150828867452219, 0.06153144902782515, 0.011922165485884761, 0.01036318224578281, 0.019955133902840316, 0.02910823230195092, 0.06492572822025977, 0.0443348001135746, 0.03329025115817785, 0.025309465927421115, 0.027802160002465826, 0.09070928921573795, 0.0527309431345202, 0.0553112829948077, 0.034040933533106, 0.045517275138990954, 0.027798725714092143, 0.05990647587168496, 0.014785631901759189, 0.05064882185251918, 0.053696744435001165, 0.06364845496136695, 0.0503144917456666, 0.15591167524689808, 0.15310530317947268, 0.16365718853194267, 0.10898342894506641, 0.17987446597544476, 0.08453234215267003, 0.18559035379439592, 0.16771350055933, 0.08983923980849795, 0.18682858266402036, 0.14866684447042644, 0.15639939985703677, 0.09848628440522589, 0.13252050150185823, 0.14837179624009877, 0.19663541112095118, 0.18464166641933843, 0.09668767466791905, 0.12230070497025736, 0.1355639600660652, 0.1781315469997935, 0.18639641522895545, 0.16696547507308424, 0.1409014267846942, 0.09996753695304506, 0.10331309415050782, 1.4624278829433024, 14.99585922807455, 46.89669594168663, 62.83385016024113, 53.93515706062317, 44.23481337726116, 39.207500740885735, 49.199558570981026, 41.03803351521492, 20.711664520204067, 6.052120495587587, 1.4350915560498834, 0.39448022609576583, 1.9048020453192294, 9.355003014206886, 10.617851950228214, 13.326529953628778, 14.096852168440819, 9.729344677180052, 5.3681619465351105, 9.974934998899698, 14.9047258682549, 27.30055846273899, 44.59754951298237, 52.930243983864784, 52.681444734334946, 47.318632900714874, 50.082509592175484, 49.16491962969303, 51.25035412609577, 55.35445690155029, 54.65685233473778, 56.052908822894096, 52.40676887333393, 45.9156683832407, 38.90224412083626, 40.3681256622076, 41.907305270433426, 43.89190457761288, 51.27526178956032, 49.52936187386513, 52.4764571338892, 52.88747727870941, 50.0425661355257, 48.493176475167274, 52.689796686172485, 54.93817023932934, 53.422982543706894, 52.099110782146454, 52.00206398963928, 48.65076161921024, 44.577908366918564, 37.90611617267132, 40.40172725915909, 42.87827096879482, 40.02059631049633, 42.1260367333889, 44.881557673215866, 49.66554656624794, 52.582023069262505, 53.17826047539711, 57.16505594551563, 40.548661574721336, 38.04920129477978, 49.53909695148468, 49.05262045562267, 51.30091421306133, 50.37932686507702, 49.485318437218666, 53.952012956142426, 51.27974174916744, 53.46172146499157, 54.0433144569397, 51.67755000293255, 46.53276666998863, 39.78635407984257, 39.28020603954792, 42.09797523915768, 45.89319258928299, 51.93606913089752, 54.43068087100983, 54.940328523516655, 53.17978039383888, 52.41516262292862, 56.46571107208729, 50.589501187205315, 46.97176851332188, 41.02170579135418, 39.06493619084358, 41.104358956217766, 41.06414571404457, 43.16857159137726, 47.74610236287117, 53.6519430577755, 54.65192399919033, 55.615404099226, 55.59777684509754, 49.374379590153694, 52.65655606985092, 52.90003180503845, 52.76120625436306, 49.42898266017437, 41.259630024433136, 31.813547797501087, 24.851882457733154, 14.743403624743223, 11.330291870981455, 20.354139804840088, 31.253645941615105, 16.897472888231277, 16.553587540984154, 24.350850842893124, 2.7962324302643538, 0.8278684050310403, 0.24934668734204024, 1.1202774988487363, 6.942234607413411, 27.87078246474266, 47.74163760244846, 49.614503905177116, 39.79223616421223, 49.69176895916462, 70.20455405116081, 57.95048899948597, 32.77001917362213, 4.31383584626019, 0.18564119091024622, 0.24961308867204934, 0.09521671570837498, 0.17940669029485434, 0.09268250403692946, 0.16481869417475536, 0.1149349486513529, 0.16925695992540568, 0.18694407568546012, 0.15821380249690264, 0.1226152568415273, 0.2152796450536698, 0.16392817633459345, 0.15626370557583869, 0.16579475195612758, 0.15717849164502695, 0.14929072349332273, 0.15935069852275774, 0.3317919321125373, 0.17364136059768498, 0.12543420831207186, 0.17465560929849744, 0.24109496996970847, 0.13258702761959285], [0.038364370484487154, 0.06696182521409355, 0.02585315774922492, 0.05366496567148715, 0.07747508177999407, 0.0864942095358856, 0.030415967012231704, 0.06405173800885677, 0.06754430723958649, 0.06718036544043571, 0.05745260168623645, 0.05381707625929266, 0.06770200619939715, 0.1798791711917147, 0.034959745753440075, 0.08607071038568392, 0.009342626217403449, 0.007106192488208762, 0.0424439377093222, 0.049282297914032824, 0.06734851383953355, 0.012379153122310527, 0.02658026023709681, 0.021921799270785414, 0.03881893222569488, 0.07921932177850977, 0.46788379666395485, 7.5287502352148294, 32.081701308488846, 46.91998869180679, 46.1754110455513, 42.86983922123909, 29.00302480906248, 29.767661578953266, 31.31564151495695, 22.31657300144434, 7.306137755513191, 1.005133108701557, 0.04336149570008274, 0.45922789082396775, 2.015997259877622, 4.356271494179964, 4.3826088309288025, 4.585100440308452, 3.236056691966951, 3.5504226107150316, 2.8128828993067145, 6.878432705998421, 19.619580321013927, 34.715750366449356, 45.84274269640446, 46.469123885035515, 46.038682982325554, 42.956033796072006, 43.33707734942436, 43.66345703601837, 47.1002472192049, 48.60251560807228, 49.69026803970337, 46.227715238928795, 39.44726027548313, 35.711319744586945, 38.990832567214966, 39.06823441386223, 45.28798386454582, 46.442532911896706, 47.54948191344738, 50.625010281801224, 49.82825003564358, 48.21649432182312, 48.65643851459026, 50.74294075369835, 46.714195534586906, 49.19280253350735, 51.233942806720734, 50.247652530670166, 47.24718913435936, 44.42096918821335, 36.63454860448837, 36.31936691701412, 36.42927601933479, 36.81763797998428, 36.685427874326706, 41.86104275286198, 44.939876943826675, 49.96891088783741, 46.45098365843296, 53.31407658755779, 35.331910103559494, 39.362137243151665, 53.857873007655144, 48.41606341302395, 50.835746973752975, 51.384600922465324, 48.535513803362846, 50.80683432519436, 49.70457427203655, 47.79162771999836, 52.610905319452286, 47.00676843523979, 39.04467947781086, 32.711418718099594, 36.56617507338524, 34.9333380907774, 40.38843937218189, 45.36211408674717, 47.40588761866093, 48.2283078879118, 51.590945050120354, 50.05409091711044, 51.313358545303345, 50.57106837630272, 46.26222878694534, 38.95291820168495, 36.3212326169014, 37.554908618330956, 39.4713319838047, 37.50395715236664, 41.44325517117977, 45.83613105118275, 48.37545499205589, 50.50104573369026, 52.9253688454628, 56.6315683722496, 56.511320024728775, 50.08391171693802, 48.28243978321552, 40.04990793764591, 31.814414151012897, 20.04860009998083, 12.853329945355654, 9.196174386888742, 8.475899286568165, 6.045844657346606, 10.330622512847185, 11.697510816156864, 6.012789756059647, 4.873574310913682, 1.5306981070898473, 0.48687728529330343, 0.18703926354646683, 0.9138984011951834, 8.895855601876974, 23.765459954738617, 38.93828898668289, 36.9356482475996, 34.20352645218372, 35.91911159455776, 45.45123070478439, 47.18138426542282, 16.98812272399664, 2.2270628716796637, 0.03530197973304894, 0.07172815734520555, 0.05159160544280894, 0.004196220779704163, 0.06067295114917215, 0.07363669399637729, 0.04749988926050719, 0.051408777362667024, 0.01060148772012326, 0.04644011351047084, 0.06459038879256696, 0.002535793141760223, 0.035564106292440556, 0.057810951402643695, 0.046960099280113354, 0.06726322622853331, 0.018218183649878483, 0.023914621633593924, 0.04433467023773119, 0.02925102337030694, 0.030022432074474636, 0.04395562573336065, 0.059083474916405976, 0.061634763405891135, 0.04245089534379076, 0.052802311765844934, 0.02006278242333792, 0.02611164964037016, 0.05267843618639745, 0.0761574950593058, 0.07579480748972856, 0.09211291311657988, 0.044800753821618855, 0.009537544810882537, 0.05927045531279873, 0.009493241377640516, 0.03986464798799716, 0.029154059920983855, 0.048451430193381384, 0.05648209516948555, 0.06531534090754576, 0.03130738841718994, 0.011285581822448876, 0.024042840632318985, 0.11171274381922558, 0.12804938829503953, 0.022443443740485236, 0.002925438529928215, 0.07854050898458809, 0.0288666446795105, 0.4426820349181071, 9.765518736094236, 37.2838843613863, 54.67562712728977, 50.25519132614136, 47.83442862331867, 32.22236976027489, 36.056694611907005, 37.55448304116726, 23.94073884934187, 8.44872884452343, 1.0702661261893809, 0.03025119352969341, 0.3482523519778624, 3.334082644432783, 4.092387529090047, 7.274761889129877, 7.991644721478224, 4.8587441816926, 6.365246018394828, 6.8669558968394995, 9.895280823111534, 21.3643079996109, 38.08767423033714, 49.141786471009254, 49.06494319438934, 47.95803219079971, 46.20749652385712, 45.50090543925762, 47.07608811557293, 49.494608938694, 50.667123422026634, 51.64535813033581, 49.26163583993912, 40.52898243069649, 37.5665245950222, 41.20221510529518, 40.77318772673607, 45.85546061396599, 50.258508548140526, 48.62512819468975, 51.676603853702545, 50.242815390229225, 49.56708624958992, 49.8593095690012, 50.47386199235916, 48.374375849962234, 50.54923474788666, 53.404865115880966, 51.925927475094795, 49.484486281871796, 45.80447494983673, 37.34686978161335, 38.20167191326618, 38.24422962963581, 38.53438965976238, 37.21459127962589, 43.914722353219986, 46.54614195227623, 50.611213222146034, 48.36329184472561, 56.34542852640152, 37.3057521879673, 40.94414435327053, 55.06982557475567, 47.30616956949234, 50.47138072550297, 51.33945174515247, 49.0113964676857, 52.012038454413414, 50.98244570195675, 49.45985980331898, 54.55536738038063, 49.99131068587303, 41.60316579043865, 35.26889428496361, 38.30103278160095, 37.58227474987507, 41.534036099910736, 48.117429837584496, 49.31013263761997, 50.76768882572651, 51.21695011854172, 51.59940719604492, 53.16635951399803, 51.962242126464844, 47.681011855602264, 40.274434089660645, 37.67062000930309, 38.345471397042274, 39.98658433556557, 39.95929419994354, 43.86619135737419, 48.20445276796818, 51.39546073973179, 53.20035628974438, 55.43783962726593, 56.048235073685646, 56.32805585861206, 51.75435908138752, 50.943923369050026, 41.904447823762894, 34.68844883143902, 23.887999579310417, 14.13756413385272, 8.795438390225172, 12.175604961812496, 7.928973259404302, 6.476166341453791, 8.895242884755135, 4.686192590743303, 4.58905222825706, 1.9424456753768027, 0.43269127258099616, 0.0329743077600142, 0.9039695339743048, 9.234064053744078, 24.797893054783344, 40.37414073944092, 41.22343696653843, 35.364170372486115, 41.94002531468868, 52.82832205295563, 53.680452927947044, 21.46426733583212, 2.611440746113658, 0.03750605814275332, 0.02553195252403384, 0.028244916029507294, 0.016348683966498356, 0.061378522077575326, 0.07888118445407599, 0.034921762635349296, 0.013714659926336026, 0.03515429976687301, 0.11022663762560114, 0.09680626244517043, 0.04408520842844155, 0.10203272613580339, 0.013676885537279304, 0.046826649995637126, 0.06290075602009892, 0.04731046348751988, 0.10140163343749009, 0.09620546421501786, 0.03365628210303839, 0.013254162859084317, 0.05607610699371435, 0.020780127524631098, 0.06961604958632961, 0.17785110423574224, 0.1818147220183164, 0.10383382948930375, 0.11152706589200534, 0.20170709991361946, 0.2608597429934889, 0.18022174655925483, 0.2854893682524562, 0.13564840162871405, 0.139735869015567, 0.16616327280644327, 0.2731683512683958, 0.16720535204512998, 0.1797917758813128, 0.11790242613642476, 0.17289627401623875, 0.17164090153528377, 0.1032681942160707, 0.13053997652605176, 0.2202769261202775, 0.21886881964746863, 0.1393376474152319, 0.1997404679423198, 0.10054748825496063, 0.17611719493288547, 0.1797092193737626, 0.8024077524896711, 12.291232757270336, 41.626192554831505, 63.32919538021088, 58.789438381791115, 55.91908000409603, 39.66777764260769, 42.35427908599377, 42.54659056663513, 29.46162410080433, 10.252509154379368, 1.579755493439734, 0.2689719514455646, 1.5321534289978445, 6.753651201725006, 7.868199795484543, 13.207515589892864, 12.948780823498964, 9.890518728643656, 7.872299775481224, 5.836404645815492, 9.851641114801168, 24.379537403583527, 39.9361914396286, 51.89525172114372, 51.70056536793709, 51.19237683713436, 47.02243499457836, 48.00045311450958, 48.15562918782234, 52.17743217945099, 53.732187151908875, 53.553102761507034, 51.36893056333065, 43.481074422597885, 39.67666156589985, 45.00794269144535, 42.944026440382004, 49.507509246468544, 50.53305521607399, 50.08289337158203, 52.8446801751852, 51.83624088764191, 51.10647864639759, 51.177880614995956, 50.643139109015465, 48.27390544116497, 50.724063366651535, 54.87835384905338, 54.87294293940067, 51.42292946577072, 47.875762805342674, 40.74046768248081, 39.401985704898834, 39.066619500517845, 39.53345485031605, 39.679530411958694, 45.08280627429485, 49.62757520377636, 52.71506533026695, 51.67465075850487, 54.75714795291424, 39.29457686841488, 43.564312756061554, 51.14734165370464, 50.035414919257164, 50.70837780833244, 54.13619667291641, 51.16626463830471, 52.16147683560848, 50.63453257083893, 49.618189707398415, 57.14601516723633, 52.245197743177414, 44.40200440585613, 37.20274731516838, 39.19058784842491, 39.43262726068497, 44.08896580338478, 49.92403529584408, 51.92975006997585, 51.1594820022583, 54.47896488010883, 52.2529911249876, 54.90756668150425, 54.881348088383675, 50.91117672622204, 42.33902670443058, 38.900766000151634, 40.16937732696533, 43.94066356122494, 40.91953307390213, 45.09069465100765, 50.762042328715324, 54.15755532681942, 56.26288175582886, 56.8505772203207, 59.073955714702606, 58.41740794479847, 53.23756009340286, 52.20515549182892, 45.053266659379005, 35.77994026243687, 24.709663689136505, 16.489224694669247, 13.433053437620401, 14.458894841372967, 13.740510139614344, 20.893260575830936, 20.471675097942352, 16.231119744479656, 11.664957962930202, 4.3331673089414835, 0.948689334327355, 0.4104600311256945, 1.6716528497636318, 12.273408863693476, 30.78458771109581, 49.006711319088936, 51.118881180882454, 46.561306938529015, 47.83092901110649, 60.24632580578327, 60.7005762308836, 25.18250461667776, 3.229180248454213, 0.11392740154406056, 0.10355980630265549, 0.14265537407482043, 0.0953101743652951, 0.21353656280552968, 0.21140355616807938, 0.1338408119045198, 0.12316996027948335, 0.10980088976793922, 0.16357341490220279, 0.16018332884414122, 0.20315155677963048, 0.17747565172612667, 0.16039893758716062, 0.23591657518409193, 0.22991760255536065, 0.11735239822883159, 0.13418807764537632, 0.15675442846259102, 0.14956696570152417, 0.11823366890894249, 0.14194179908372462, 0.1438150243484415, 0.18888329272158444], [0.05854489092598669, 0.09967515303287655, 0.026477201899979264, 0.03653677616966888, 0.021577162588073406, 0.07201098240329884, 0.05898758943658322, 0.04901359592622612, 0.017098154785344377, 0.04676821699831635, 0.06016986408212688, 0.040783289514365606, 0.01403608965119929, 0.035376925516175106, 0.00709318820554472, 0.01749899431160884, 0.049587209286983125, 0.02825080868205987, 0.0888381790718995, 0.033110762742580846, 0.056430809054290876, 0.011705311790137785, 0.062155279811122455, 0.056784319967846386, 0.09618832802516408, 0.04669202069635503, 0.244622724421788, 3.451022794470191, 23.396657444536686, 41.03924185037613, 53.33401791751385, 36.28757402300835, 22.083719596266747, 26.19314208626747, 32.78485357761383, 28.8885198533535, 9.713702816516161, 2.637158716097474, 0.05556765419896692, 0.22115843428764492, 2.4882245203480124, 3.6612826120108366, 3.600030611269176, 7.64412154443562, 2.4694340536370873, 6.878955652937293, 5.049066944047809, 5.416534775868058, 17.259435765445232, 34.180803671479225, 48.360339403152466, 46.92437745630741, 43.77807408571243, 42.717125415802, 40.81981122493744, 41.65252894163132, 42.306101471185684, 45.52805498242378, 44.60536189377308, 41.52023144066334, 37.3481123149395, 37.210263311862946, 36.54778026044369, 41.68841041624546, 46.04754790663719, 46.82313948869705, 49.70028430223465, 48.32519128918648, 48.37611995637417, 51.73207327723503, 50.06570689380169, 51.27377226948738, 52.07834109663963, 50.61162739992142, 48.75647194683552, 50.70332407951355, 49.82620194554329, 47.88459733128548, 41.094840466976166, 36.55346855521202, 36.147977113723755, 35.89279420673847, 36.48394748568535, 41.11317828297615, 42.40583851933479, 49.476081132888794, 45.24701066315174, 55.0605882704258, 35.57048790156841, 38.409098982810974, 51.42343483865261, 50.89916177093983, 53.97053316235542, 48.831913098692894, 52.55112312734127, 51.95528469979763, 53.84460411965847, 50.92133358120918, 51.6030739992857, 46.895233020186424, 35.645351484417915, 34.182483181357384, 36.13600395619869, 35.09726509451866, 37.85023257136345, 42.1400997787714, 47.07119397819042, 47.52197898924351, 52.16762490570545, 51.98569066822529, 50.58574698865414, 48.609929010272026, 47.60690823197365, 39.383670687675476, 38.07885490357876, 39.05347980558872, 38.51792894303799, 37.31033094227314, 39.72617670893669, 44.482905864715576, 48.21487940847874, 49.09691087901592, 51.77673228085041, 50.97029395401478, 53.07793825864792, 54.486393481492996, 49.38320651650429, 38.97245295345783, 28.45092013478279, 14.371019806712866, 6.856760093942285, 3.1667263247072697, 7.022193716838956, 5.415517380461097, 2.7518189884722233, 8.363505117595196, 3.771912488155067, 3.373997127637267, 1.2580140517093241, 0.18477213598089293, 0.19941294332966208, 0.8361819433048368, 9.567540809512138, 32.24537752568722, 38.491892740130424, 41.260306388139725, 34.037247374653816, 36.056933999061584, 48.20814236998558, 42.23555065691471, 15.00725956633687, 0.8316303812898695, 0.08789129511569627, 0.07462873021722771, 0.029746416221314576, 0.09144224910414778, 0.06006151052133646, 0.035739397862926126, 0.04966680833604187, 0.06293940707109869, 0.022724151822330896, 0.060376537367119454, 0.03349202255776618, 0.039100551293813623, 0.021651234492310323, 0.023852425947552547, 0.012383186694933102, 0.06173400339321233, 0.042667617308325134, 0.046128841931931674, 0.07016833362285979, 0.03260586483520456, 0.013420404866337776, 0.036765227778232656, 0.07676930676097982, 0.03443403802521061, 0.04467067017685622, 0.04665731044951826, 0.039125134935602546, 0.02539331191655947, 0.017653201466600876, 0.021967003485769965, 0.09296524003730156, 0.01720771619147854, 0.04933828553475905, 0.06010569428326562, 0.046015371262910776, 0.033671741039142944, 0.030457944740192033, 0.03276578281656839, 0.06171960943902377, 0.018923060670203995, 0.018545682287367526, 0.048588657009531744, 0.06217499125341419, 0.0241011771504418, 0.04583101435855497, 0.05588227657426614, 0.09485739006777294, 0.0363185958849499, 0.02380256846663542, 0.009719831123220501, 0.2837354951770976, 5.006795162335038, 29.61679257452488, 48.621358796954155, 58.46788443624973, 40.70562355220318, 29.269259423017502, 33.88179771602154, 37.66465052962303, 29.71112061291933, 11.041105538606644, 2.2745655477046967, 0.12657028797548264, 0.2670987113378942, 2.2177146608009934, 3.142426866106689, 5.398982567712665, 7.156172627583146, 6.832633763551712, 6.374065820127726, 5.065449764952064, 8.423837330192327, 18.254184387624264, 37.307891473174095, 48.774665370583534, 50.211763456463814, 46.08200065791607, 45.689542517066, 42.41761788725853, 44.49397087097168, 45.27929753065109, 48.7549140304327, 47.304965034127235, 43.78535829484463, 39.21927250921726, 40.04952795803547, 38.29963065683842, 41.577555164694786, 49.0274316072464, 49.1639506816864, 51.00771054625511, 49.03207875788212, 48.74605670571327, 53.91371861100197, 50.43282799422741, 52.33564428985119, 52.43714064359665, 50.44846035540104, 49.40572410821915, 51.251661255955696, 50.132830291986465, 49.551750272512436, 41.66972301900387, 37.335656583309174, 37.764452174305916, 38.178314566612244, 37.55981035530567, 42.332042679190636, 44.60766077041626, 51.575373485684395, 48.67513731122017, 56.70952118933201, 38.302708491683006, 40.70155777037144, 51.36778302490711, 51.61929152905941, 55.27497656643391, 52.398025542497635, 52.85116642713547, 53.559269830584526, 55.655507147312164, 52.34460420906544, 52.35045589506626, 49.71993304789066, 37.837469056248665, 35.561691373586655, 37.64803782105446, 37.436784356832504, 40.814001336693764, 45.28785467147827, 48.11601631343365, 50.43365254998207, 52.98715353012085, 51.21805585920811, 50.987818613648415, 51.71661950647831, 47.908178865909576, 42.08128273487091, 37.92473517358303, 39.61876407265663, 40.22113434970379, 38.53378169238567, 41.596067771315575, 46.84450574219227, 51.431927382946014, 51.676467061042786, 53.588809445500374, 55.50829164683819, 55.433872640132904, 56.16007827222347, 50.91515131294727, 40.84729515016079, 30.886321552097797, 18.79068709909916, 10.43174933642149, 6.0343108512461185, 7.755601862445474, 8.743301387876272, 6.772491065785289, 7.852803496643901, 5.083946222439408, 4.883985752239823, 1.059671938419342, 1.0381991718895733, 0.14916620595613495, 1.5266013331711292, 11.110438518226147, 32.0394741743803, 45.482487827539444, 44.591895416378975, 40.101626962423325, 40.71808308362961, 54.24981817603111, 48.75965237617493, 17.615790143609047, 1.3227505842223763, 0.043432430175016634, 0.02936633456556592, 0.06399333840818144, 0.09327162828412838, 0.03836418494756799, 0.04823123868845869, 0.036544294125633314, 0.02948284804006107, 0.011341808785800822, 0.043150699784746394, 0.05003648693673313, 0.030306099470180925, 0.04226425262459088, 0.04274115672160406, 0.08377624952117912, 0.04498514412262011, 0.08240267517976463, 0.022667859921057243, 0.12354789156233892, 0.08727064443519339, 0.04637329424440395, 0.05230634931649547, 0.08954607663326897, 0.03587639090255834, 0.1258817530469969, 0.24198446364607662, 0.11873519004439004, 0.1364265731535852, 0.15656399336876348, 0.10309642413631082, 0.18508343724533916, 0.0729770731413737, 0.1271032539079897, 0.258342704619281, 0.1194891230261419, 0.1614540340960957, 0.12527841667179018, 0.13917965901782736, 0.13473385304678231, 0.1130433329672087, 0.11840534250950441, 0.12854861619416624, 0.26368699909653515, 0.1286230090772733, 0.13615194882731885, 0.16743513580877334, 0.2054339725873433, 0.11132831874419935, 0.16209591762162745, 0.11667963393847458, 0.5401876824907959, 6.22726877219975, 32.33572147786617, 54.60138291120529, 65.1517827808857, 47.44075834751129, 34.112373143434525, 38.85916583240032, 43.33991579711437, 35.51567584276199, 13.539841957390308, 3.5601546010002494, 0.4626356845255941, 0.7712352345697582, 4.917081501334906, 10.240730736404657, 11.40230180695653, 16.060833781957626, 9.226367566734552, 14.643525034189224, 8.888830728828907, 7.228371128439903, 19.544956125319004, 41.52870498597622, 53.21294501423836, 51.80179953575134, 48.44740033149719, 48.295279294252396, 45.68386182188988, 45.926391407847404, 48.15940998494625, 50.29103480279446, 49.27479453384876, 45.64689740538597, 41.57737657427788, 42.00376309454441, 40.198354572057724, 44.05678912997246, 50.74238978326321, 51.56883783638477, 53.954148441553116, 51.198863089084625, 50.474165976047516, 55.563700273633, 52.87317484617233, 53.95863600075245, 55.19675396382809, 50.92068761587143, 49.52665261924267, 50.99983736872673, 52.62141935527325, 51.75532802939415, 45.992276072502136, 40.180476531386375, 39.201481863856316, 40.53880110383034, 39.916421100497246, 44.77082021534443, 48.2392854988575, 52.61419974267483, 52.02577471733093, 57.43485666811466, 40.83843022584915, 42.50604674220085, 51.161416098475456, 53.87785993516445, 56.58207602798939, 52.903071641922, 53.83410148322582, 56.11665420234203, 56.39504626393318, 53.05447071790695, 55.69728210568428, 51.17815800011158, 38.73344957828522, 37.24106825888157, 41.54104292392731, 39.3309561163187, 43.32231514155865, 47.663202211260796, 50.96325673162937, 52.81178914010525, 54.98173110187054, 52.03743629157543, 52.69956596195698, 54.635470882058144, 51.895931884646416, 44.245741590857506, 40.815091878175735, 42.98061467707157, 42.05382540822029, 41.5000469237566, 43.881622329354286, 49.094323217868805, 53.82614850997925, 55.37720628082752, 56.13842323422432, 57.39469662308693, 59.300066381692886, 58.592646941542625, 54.60678242146969, 42.72918216884136, 32.48649738729, 17.81074818223715, 10.410213991999626, 6.755168745294213, 11.314483769237995, 11.77260808646679, 8.685042914003134, 19.11494839936495, 6.5492786932736635, 10.831025261431932, 3.932153689675033, 1.3095567421987653, 0.4084626742405817, 1.867325606290251, 12.952990997582674, 40.295667350292206, 48.76523047685623, 55.82728832960129, 48.95710498094559, 48.198927864432335, 62.70034432411194, 52.54251278936863, 21.063854321837425, 1.4126942516304553, 0.1713727042078972, 0.1268679485656321, 0.13520492386305705, 0.14494221308268607, 0.2059445553459227, 0.11214915633900091, 0.13951401138911024, 0.15870810253545642, 0.14031063270522282, 0.16726632689824328, 0.16217495634919032, 0.17331983253825456, 0.0894717728078831, 0.07628777908394113, 0.12964662368176505, 0.09580770274624228, 0.2058907793252729, 0.13351428176974878, 0.19351399736478925, 0.17314866359811276, 0.08611582554294728, 0.09016164360218681, 0.13373777212109417, 0.13493338687112555], [0.06115201489592437, 0.023202126467367634, 0.05332895460014697, 0.018230811292596627, 0.02145940416085068, 0.023288187767320778, 0.07789915980538353, 0.023600040076416917, 0.008601493427704554, 0.01149630352301756, 0.04048530237923842, 0.06168190091557335, 0.04329342962591909, 0.015715492845629342, 0.024835884796630125, 0.03497813988360576, 0.014691316064272542, 0.03209649177733809, 0.06727225074428134, 0.023659415601287037, 0.06781766991480254, 0.038197264802875, 0.04862610578129534, 0.01410910306731239, 0.038559722306672484, 0.07414035993861035, 0.053365223357104696, 1.740502780303359, 16.74284588545561, 44.15275298058987, 51.247329488396645, 48.51331539452076, 36.72877214848995, 25.17461434006691, 34.62708592414856, 27.579961270093918, 16.927647069096565, 3.6456193774938583, 0.2614224690478295, 0.1929124421440065, 1.9205164583399892, 1.625938096549362, 6.1194452829658985, 4.072396801784635, 5.536487214267254, 3.61818864941597, 5.2416496351361275, 7.4457755126059055, 12.887625955045223, 29.522933810949326, 43.87797072529793, 49.698316007852554, 48.573336973786354, 45.31894840300083, 41.64962589740753, 41.34679734706879, 39.62165951728821, 41.2311315536499, 40.20926758646965, 39.197537675499916, 36.221928745508194, 36.44350245594978, 39.59302045404911, 46.22509717941284, 47.380311191082, 49.86687496304512, 47.60050557553768, 47.742332965135574, 49.83316697180271, 50.627514347434044, 47.500092163681984, 49.34235870838165, 50.37816792726517, 53.9067117869854, 49.77190665900707, 51.026082560420036, 50.542106330394745, 50.139639526605606, 46.814745739102364, 39.464978724718094, 36.03290028870106, 37.25483112037182, 35.549969002604485, 38.95812392234802, 41.85515686869621, 47.68800728023052, 45.613603591918945, 54.71350349485874, 37.497493699193, 37.69560366868973, 55.95861688256264, 50.262350142002106, 49.0192886441946, 48.331962525844574, 49.068769589066505, 48.733916357159615, 51.26986987888813, 50.89551776647568, 48.93608070909977, 43.27749654650688, 34.905956760048866, 34.33524638414383, 35.658377185463905, 37.06143669784069, 38.58151853084564, 42.832396030426025, 44.488829746842384, 49.58149127662182, 50.277176946401596, 50.65373294055462, 52.08379000425339, 49.416732117533684, 48.18023666739464, 42.09148898720741, 37.06312380731106, 38.55055779218674, 37.37841188907623, 38.59513700008392, 37.880448549985886, 38.85386511683464, 43.234486654400826, 44.9429015815258, 46.57444663345814, 49.2887169867754, 48.029696345329285, 51.44458830356598, 49.88643631339073, 37.38860294222832, 25.21702766418457, 15.824394319206476, 6.623850166797638, 4.994804430752993, 9.341580234467983, 6.177049716934562, 4.967317180708051, 4.100149087607861, 3.1335576670244336, 2.4185742577537894, 1.1250652419403195, 0.9039223927538842, 0.12652040080865845, 1.984121601562947, 10.83176052197814, 23.733976744115353, 35.855871587991714, 37.28511929512024, 29.39540695399046, 39.62221048772335, 50.00900633633137, 36.436849012970924, 10.265975631773472, 0.449379620840773, 0.01966112838999834, 0.033139231527457014, 0.08075725214439444, 0.048906192314461805, 0.11197475163498893, 0.009457504183956189, 0.06054247416614089, 0.05741022134316154, 0.0403459418885177, 0.03315474612463731, 0.05177658204047475, 0.04157707211561501, 0.052320928807603195, 0.02308506936969934, 0.04130366491153836, 0.03477443890005816, 0.03881769283907488, 0.0414701100817183, 0.06113169860327616, 0.10019571025623009, 0.060269515961408615, 0.03399499830265995, 0.05409863966633566, 0.019656120748550165, 0.05834310839418322, 0.022175576668814756, 0.03305025544250384, 0.033959130305447616, 0.029736887045146432, 0.03156971535645425, 0.05537065109820105, 0.02766174751741346, 0.024535422599001322, 0.027523804528755136, 0.01721950335195288, 0.03383501352800522, 0.02639220929268049, 0.03100910813373048, 0.04669201698561665, 0.03902344215021003, 0.03760990686714649, 0.06082928455725778, 0.029073163968860172, 0.06974130184971727, 0.07198217965196818, 0.06020206586981658, 0.0653088693798054, 0.03579620926757343, 0.16793155838968232, 0.025486544218438212, 0.11950116808293387, 2.6303604058921337, 21.469968929886818, 47.8077008575201, 56.611307859420776, 50.21030813455582, 37.80657671391964, 28.67462743073702, 39.4655866920948, 33.072399348020554, 17.941730953752995, 3.8878965144976974, 0.4036095627816394, 0.12282277617487125, 0.4468924761749804, 2.814203565940261, 4.805212654173374, 10.184730291366577, 6.768641397356987, 5.980896642431617, 6.160096451640129, 6.761536728590727, 14.420705940574408, 32.502331137657166, 46.57573476433754, 52.47033566236496, 51.32075294852257, 47.15173065662384, 44.33244913816452, 42.986842542886734, 41.182076185941696, 42.86606602370739, 43.628662303090096, 41.617916598916054, 39.193103313446045, 38.762954995036125, 40.728087946772575, 47.72239923477173, 49.00425285100937, 51.28273218870163, 50.77889822423458, 48.44100147485733, 51.87949396669865, 52.28794164955616, 50.26154078543186, 49.84588868916035, 50.2785524725914, 54.64751623570919, 49.47522237896919, 51.53954520821571, 52.82736450433731, 52.30800837278366, 48.55874575674534, 41.48433096706867, 38.79847548902035, 39.977715611457825, 36.74861468374729, 42.01908387243748, 44.883674159646034, 49.85041804611683, 47.48584292829037, 56.248799711465836, 39.91380304098129, 38.040974736213684, 55.96168331801891, 51.78476504981518, 51.42892934381962, 49.96849291026592, 51.098096296191216, 51.34710073471069, 54.770367443561554, 52.64164187014103, 50.4910484701395, 46.607029885053635, 36.96038492023945, 36.03215552866459, 38.410402312874794, 38.69130223989487, 40.76813019812107, 45.18569715321064, 48.11611890792847, 50.007228031754494, 53.36798809468746, 51.3200917840004, 53.29104982316494, 53.03823418915272, 51.25125467777252, 43.49399372935295, 39.57584157586098, 38.95511068403721, 39.23897445201874, 40.684732273221016, 40.01298151910305, 41.581928730010986, 46.132796332240105, 47.506806403398514, 50.555569007992744, 50.771082043647766, 51.70905031263828, 53.70379127562046, 51.49394765496254, 39.347850009799004, 27.64307778328657, 18.45303151756525, 9.21892661601305, 5.222271624952555, 6.495484029874206, 10.762803722172976, 7.899594185873866, 6.17814120836556, 6.096796123310924, 3.1746142264455557, 1.3212571456097066, 0.30720250157173723, 0.1111799560021609, 2.331383661366999, 11.15580428391695, 30.41095945984125, 44.466407150030136, 41.08978293836117, 33.29971455037594, 43.96800309419632, 55.955755636096, 43.043379709124565, 13.426436092704535, 0.5009973573032767, 0.11341094097588211, 0.08349031486432068, 0.047202124769682996, 0.009504034987912746, 0.01872605014796136, 0.026022658712463453, 0.02714742618991295, 0.022277891002886463, 0.03311593922262546, 0.017844399117166176, 0.01653499828535132, 0.03100227109825937, 0.006999653478487744, 0.043758652318501845, 0.09143115399638191, 0.053068193592480384, 0.024186783884942997, 0.026025608749478124, 0.07195634549134411, 0.04142094279814046, 0.014103991525189485, 0.016556472328375094, 0.05995349092700053, 0.07212096126750112, 0.17149431252619252, 0.086971774144331, 0.15287565300241113, 0.1437043256009929, 0.11764104914618656, 0.18889883329393342, 0.1493212702916935, 0.12855464243330061, 0.09417953464435413, 0.14068705000681803, 0.1543267149827443, 0.08556414264603518, 0.12805452395696193, 0.11857589546707459, 0.15197860426269472, 0.09976987334084697, 0.14431995194172487, 0.10693985110265203, 0.1708951173350215, 0.23181775293778628, 0.15372475900221616, 0.19242700334871188, 0.08731936643016525, 0.20462569955270737, 0.19587171147577465, 0.1535013725515455, 0.19555457693058997, 3.5924678295850754, 24.599403105676174, 55.13032592833042, 63.221026584506035, 61.17635250091553, 49.41017746925354, 35.1284272223711, 46.68204925954342, 36.835801005363464, 22.580769024789333, 4.9833285715430975, 0.8504288038238883, 0.3510769660351798, 4.170989161357284, 6.615363797172904, 15.367235150188208, 13.724468350410461, 13.710385356098413, 11.309675127267838, 10.54844107478857, 11.182407606393099, 17.828573025763035, 32.357889488339424, 47.920543402433395, 55.122346356511116, 54.611307978630066, 49.47809502482414, 46.28240950405598, 45.55673964321613, 43.49551364779472, 45.91338090598583, 46.13458603620529, 43.586112186312675, 42.017153576016426, 41.054425835609436, 42.77834393084049, 49.63249213993549, 51.27580136060715, 53.54128539562225, 51.322535052895546, 49.48163643479347, 52.918924391269684, 54.879410192370415, 52.12644651532173, 51.66006714105606, 52.65678785741329, 55.725677981972694, 50.556427761912346, 52.11886212229729, 54.591944217681885, 55.3860218077898, 52.36808694899082, 42.599871307611465, 40.28718240559101, 41.30502998828888, 39.23267439007759, 42.57535882294178, 46.78209789097309, 52.312017157673836, 48.429111912846565, 56.53437338769436, 42.92500086128712, 41.16548627614975, 57.4062480032444, 54.40888524055481, 53.314585760235786, 53.05782973766327, 53.61263416707516, 54.156856164336205, 56.70947179198265, 54.442992210388184, 52.56350286304951, 46.829830929636955, 38.248846381902695, 37.98934690654278, 40.64757026731968, 40.325678139925, 43.510006070137024, 47.68830746412277, 50.3434681892395, 54.196602031588554, 55.12445904314518, 52.98225179314613, 55.50886161625385, 54.84358191490173, 54.97554123401642, 45.86722858250141, 41.913187354803085, 42.28600054979324, 40.75977824628353, 41.653068512678146, 41.00565925240517, 43.43972124159336, 48.35948444902897, 48.68786662817001, 51.66380614042282, 54.23292048275471, 51.729109436273575, 56.6523190587759, 53.979496881365776, 44.01276469230652, 29.469603672623634, 21.11197493970394, 10.62364948913455, 9.536781460046768, 17.61482309550047, 13.672148957848549, 11.1080826446414, 10.177068952471018, 12.455202508717775, 7.212462807074189, 3.167516919784248, 1.8175626453012228, 0.4088200331898406, 3.2586120441555977, 14.269266966730356, 32.177501767873764, 50.58491103351116, 47.93076105415821, 42.21286967396736, 51.35237865149975, 64.43636476993561, 49.419502168893814, 15.156964883208275, 0.7592751388438046, 0.2198046975536272, 0.15108378196600825, 0.3178478084737435, 0.1333497921586968, 0.23986279702512547, 0.15014903212431818, 0.14370386546943337, 0.15174733620369807, 0.14867952035274357, 0.12378968327539042, 0.12494321825215593, 0.19357443787157536, 0.08650226183817722, 0.1429054036270827, 0.20383284834679216, 0.11929487329325639, 0.12920595123432577, 0.12467136955820024, 0.152801007789094, 0.1853659877087921, 0.09988952981075272, 0.14488821441773325, 0.1940597579232417, 0.10145367283257656], [0.02138451218343107, 0.03934736734663602, 0.04186148908047471, 0.021027746952313464, 0.03210860362742096, 0.02396971125563141, 0.021578388987109065, 0.012480759633035632, 0.08179612530511804, 0.05864643899258226, 0.049196665204362944, 0.02350951104745036, 0.009565097043378046, 0.02382173257501563, 0.0864904023183044, 0.014123394048510818, 0.07470151263987646, 0.07825427746865898, 0.014662807388958754, 0.02034428089245921, 0.06833039748016745, 0.06821871909778565, 0.03513592419039924, 0.036629147580242716, 0.034882799882325344, 0.17337786848656833, 0.021405912011687178, 0.3266343619907275, 10.41865048930049, 32.60212138295174, 54.40795809030533, 42.79008150100708, 39.45636838674545, 32.63545699417591, 31.96024462580681, 29.521373994648457, 16.602897495031357, 6.165441814810038, 1.0230818018317223, 0.01512483884653193, 0.3083753620740026, 1.8619008036330342, 2.5913015892729163, 6.15898453630507, 4.9967860244214535, 4.012233205139637, 2.2061010589823127, 4.293187279254198, 8.870631605386734, 23.550452291965485, 37.19543270766735, 51.16749957203865, 46.89606137573719, 47.89114058017731, 43.94442915916443, 43.30135926604271, 40.722384452819824, 41.225644648075104, 37.89678007364273, 36.93159766495228, 37.05129124224186, 41.19314879179001, 42.779255881905556, 46.55430391430855, 47.46560141444206, 50.833182111382484, 48.28273996710777, 51.44963063299656, 48.53011429309845, 48.981104493141174, 46.691924929618835, 46.79970234632492, 47.4283330142498, 51.52793303132057, 51.61563232541084, 49.80500668287277, 51.281535252928734, 51.55532956123352, 47.97879047691822, 46.29399128258228, 41.09797149896622, 38.02185036242008, 36.23970419168472, 40.87795950472355, 40.88506892323494, 49.31153476238251, 46.84503011405468, 54.517099633812904, 39.10003870725632, 39.61379013955593, 53.563350811600685, 49.00165759027004, 48.827771320939064, 45.949931144714355, 46.4393524825573, 47.02277697622776, 48.998195976018906, 47.414786741137505, 45.00685214996338, 35.96775658428669, 36.014273688197136, 34.66291040182114, 35.31161919236183, 37.4092548340559, 40.069093108177185, 46.3914180546999, 48.40172678232193, 50.31837813556194, 50.05760572850704, 51.663809940218925, 52.44220957159996, 50.267802849411964, 47.21419930458069, 44.62521582841873, 38.94903101027012, 37.86486938595772, 39.03161957859993, 38.10411594808102, 38.75945158302784, 39.6852833032608, 40.67529737949371, 41.69638618826866, 43.420380279421806, 46.614713072776794, 48.49064581096172, 49.75483037531376, 48.989844024181366, 32.74575747549534, 22.87436217069626, 13.405921943485737, 4.943762719631195, 2.865977450273931, 2.6174712600186467, 11.257231291383505, 7.4291713535785675, 4.884313959628344, 7.14530473574996, 3.170299557968974, 0.6502851715777069, 0.5073299549985677, 0.07150676727178507, 1.7898736498318613, 12.762208934873343, 30.24440109729767, 38.48678961396217, 35.71640387177467, 38.9932644367218, 49.84871193766594, 47.58917458355427, 31.406627632677555, 6.751492917537689, 0.12850282568251714, 0.041135282735922374, 0.06045445174095221, 0.016613528641755693, 0.014645253741036868, 0.11002381608705036, 0.023348201539192814, 0.0689419568516314, 0.021205476477916818, 0.11396830872399732, 0.06831196253187954, 0.04233428910083603, 0.041021400174940936, 0.01608342554391129, 0.0210037700162502, 0.042518319460214116, 0.06843334820587188, 0.05187460861634463, 0.03218724530597683, 0.13577137549873441, 0.01031120315019507, 0.05363495693018194, 0.01684098762780195, 0.006364064756780863, 0.0641104715759866, 0.05071959676570259, 0.02816817239363445, 0.058868715932476334, 0.021993856244080234, 0.0743950204923749, 0.06502326868940145, 0.08674842480104417, 0.05092499726742972, 0.07163153713918291, 0.07034558075247332, 0.04754681896883994, 0.040392641531070694, 0.09014295632368885, 0.024871871537470724, 0.08246413985034451, 0.03458008526649792, 0.01420171845893492, 0.09613726826501079, 0.030195551007636823, 0.049305067004752345, 0.043978431931464, 0.043540542537812144, 0.027955842087976635, 0.028255328361410648, 0.038900163999642245, 0.07467682880815119, 0.024046972539508715, 0.6639841489959508, 13.40273866429925, 40.60757361352444, 59.24561530351639, 51.006582006812096, 44.60025116801262, 37.44696021080017, 37.21402890980244, 33.95557835698128, 19.93368286639452, 6.093932026997209, 0.9933691774494946, 0.12896350643131882, 0.3186383144930005, 2.6002938067540526, 5.115545326843858, 4.977268371731043, 8.061744309961796, 6.001776047050953, 7.075919983908534, 6.830861158668995, 11.734505631029606, 26.410501822829247, 41.03127367794514, 54.02064107358456, 48.69035929441452, 49.49033036828041, 46.41684629023075, 45.240273624658585, 42.38627336919308, 42.50223934650421, 39.99676398932934, 39.5112906396389, 39.61606241762638, 41.20716243982315, 44.351182132959366, 49.52132910490036, 50.074442625045776, 52.560037449002266, 47.93058626353741, 52.40411661565304, 49.44312930107117, 49.65584568679333, 48.96052099764347, 48.774752765893936, 48.76323938369751, 53.604441806674004, 50.91962747275829, 50.45915678143501, 51.68486841022968, 53.27659159898758, 50.099274292588234, 47.76532553136349, 43.21927987039089, 38.875143975019455, 37.21315115690231, 41.80920213460922, 41.92112132906914, 49.656556248664856, 49.097154065966606, 55.25779768824577, 40.53717099130154, 40.699806064367294, 55.419938787817955, 49.521659687161446, 50.24148166179657, 48.75280514359474, 48.38811971247196, 50.09150750935078, 51.49156138300896, 50.20712770521641, 47.403159365057945, 39.59053158760071, 36.57217875123024, 36.657016798853874, 36.21568948030472, 38.71255449950695, 41.23517073690891, 48.03652837872505, 50.21831810474396, 52.13485546410084, 52.11848594248295, 51.33643090724945, 53.521632850170135, 51.902748718857765, 49.33812573552132, 46.56397059559822, 41.85570403933525, 39.91437681019306, 40.617270693182945, 40.75567826628685, 40.42261093854904, 40.41234388947487, 42.3245494812727, 43.77069108188152, 46.08114950358868, 50.47061316668987, 51.476107612252235, 52.91604034602642, 51.27536818385124, 37.165714502334595, 26.801650933921337, 16.594893224537373, 9.741041399538517, 5.669116247445345, 5.609028171747923, 10.409499630331993, 8.440148904919624, 8.318475633859634, 7.799707045778632, 3.2232233555987477, 1.1948407790623605, 0.1670945790829137, 0.07347701350226998, 2.4608075665310025, 13.824956808239222, 34.403920099139214, 42.121701166033745, 41.382827013731, 40.6034242361784, 54.378293082118034, 53.56965847313404, 37.05744311213493, 7.606363445520401, 0.19412500754697248, 0.0849186151754111, 0.01443690320229507, 0.014903843039064668, 0.06057282800611574, 0.03086164710111916, 0.029770537876174785, 0.17211378319188952, 0.047829217292019166, 0.0394912066985853, 0.03777799960516859, 0.04443239995453041, 0.02630058745126007, 0.012727338198601501, 0.042340823711128905, 0.06123543229477946, 0.018138245068257675, 0.03225705171644222, 0.058220624341629446, 0.11300811805995181, 0.027631547673081513, 0.04043392349558417, 0.06812718260334805, 0.015876550023676828, 0.022401553214876913, 0.09184409980662167, 0.17923402221640572, 0.1703498317510821, 0.10604743336443789, 0.16614400665275753, 0.10206905426457524, 0.15198598121060058, 0.07362795149674639, 0.19889508752385154, 0.170987737365067, 0.16477245837450027, 0.1781295135151595, 0.1487742183962837, 0.08353817596798763, 0.1848944419180043, 0.0926810791133903, 0.15024583786725998, 0.1364411786198616, 0.10388747192337178, 0.10579348527244292, 0.10503998273634352, 0.13938854390289634, 0.11761326313717291, 0.177324594988022, 0.13058423821348697, 0.258857398875989, 0.11995950364507735, 0.9362661384511739, 15.814521498978138, 45.70830591022968, 66.22356086969376, 54.68180939555168, 51.02214217185974, 43.6826878041029, 42.91434623301029, 41.470807492733, 23.280558474361897, 8.378168530762196, 1.5956892259418964, 0.46702050080057234, 1.3004582491703331, 6.252111364156008, 8.70679484680295, 13.13126603141427, 14.57939587533474, 11.310991756618023, 7.443212075158954, 8.492314405739307, 11.556867063045502, 26.940508782863617, 42.430142015218735, 55.43898716568947, 50.81803612411022, 52.84942612051964, 49.296012595295906, 48.170604184269905, 45.05388602614403, 45.15235014259815, 42.16774709522724, 40.79477436840534, 40.782797411084175, 44.608162343502045, 46.7594663053751, 50.868983790278435, 52.48102068901062, 54.77781884372234, 49.2635091394186, 53.61043408513069, 52.220578864216805, 53.13341148197651, 50.212527215480804, 49.92309294641018, 51.03361755609512, 54.68132682144642, 53.1139375269413, 49.91458520293236, 53.0988447368145, 56.07373930513859, 52.015777453780174, 51.02640554308891, 46.810227781534195, 41.731367111206055, 39.36640061438084, 44.4024033844471, 45.9330752491951, 51.81235156953335, 52.14738339185715, 56.71964764595032, 43.754579946398735, 42.730607092380524, 57.07590892910957, 54.34607841074467, 53.473611027002335, 51.053847670555115, 49.89137224853039, 52.13599540293217, 53.74024271965027, 52.49108634889126, 49.42604921758175, 41.36478178203106, 39.39011514186859, 37.17028185725212, 38.60964082181454, 40.11109985411167, 44.46342810988426, 49.89547602832317, 51.65751367807388, 55.84961973130703, 53.810702338814735, 51.18710272014141, 55.860430151224136, 54.154181107878685, 52.23960444331169, 48.40265393257141, 43.25866475701332, 41.8982807546854, 42.21212491393089, 41.833927407860756, 41.93767324090004, 42.883932664990425, 44.406621158123016, 46.2944320589304, 47.08442106842995, 52.213720232248306, 54.81982558965683, 55.258656442165375, 53.56720380485058, 38.255697414278984, 27.333438098430634, 17.519256323575974, 8.27079389244318, 5.834169890731573, 9.00624917820096, 20.025734826922417, 16.570352241396904, 13.829948790371418, 15.879245325922966, 8.117817901074886, 3.12874190043658, 0.7604775368236005, 0.3138088627019897, 2.843923671171069, 17.246911637485027, 37.97663278877735, 50.85210509598255, 50.11401370167732, 51.189044415950775, 64.70078498125076, 61.38231284916401, 43.239392191171646, 9.915416892617941, 0.3504661488113925, 0.15600344922859222, 0.12839873204939067, 0.07654360480955802, 0.16208140121307224, 0.19123371894238517, 0.104844716261141, 0.17652740963967517, 0.11840963212307543, 0.198431764729321, 0.1406488590873778, 0.14670784177724272, 0.11152145525556989, 0.11180533416336402, 0.07251904185977764, 0.19291784497909248, 0.16625458665657789, 0.07987171411514282, 0.11421007075114176, 0.22836026502773166, 0.09899206546833739, 0.08399267462664284, 0.2506467222701758, 0.1680116806528531, 0.17087427782826126], [0.06220556402695365, 0.056255012823385186, 0.008332167108164867, 0.026626241851772647, 0.07120539594325237, 0.03745405585505068, 0.039883450299385004, 0.02886189493437996, 0.023856819461798295, 0.03978058863140177, 0.010354187415941851, 0.0317513188929297, 0.01726091704767896, 0.04461027048819233, 0.12977592064999044, 0.05562259910220746, 0.023816333450668026, 0.016753119198256172, 0.038073886462370865, 0.023790740488038864, 0.010996348319167737, 0.060402082090149634, 0.027313754471833818, 0.009541569106659153, 0.03606212078011595, 0.012634471404453507, 0.03464023633569013, 0.10751429566880688, 5.570663055405021, 24.52127929776907, 46.697199046611786, 42.94109679758549, 38.32947425544262, 25.06286233663559, 33.31174090504646, 30.271575339138508, 20.68576890975237, 9.52217124402523, 1.7077351198531687, 0.16198536730371416, 0.2345543631236069, 1.400709932204336, 3.6888541700318456, 5.178222488611937, 4.663302144035697, 3.5164692951366305, 8.340684492141008, 3.8120665960013866, 4.679465051740408, 16.454038582742214, 29.387267790734768, 46.63162216544151, 52.71953009068966, 48.471688628196716, 45.670353546738625, 46.38897478580475, 43.03172193467617, 44.723645746707916, 42.40081138908863, 43.55215720832348, 43.83291654288769, 44.96201075613499, 45.30590370297432, 49.879193902015686, 48.611471727490425, 48.92188087105751, 49.70490865409374, 52.16958560049534, 47.11738429963589, 45.9449078142643, 42.77460113167763, 46.22179135680199, 47.08040088415146, 50.076046139001846, 50.56680880486965, 50.94748757779598, 51.72727033495903, 51.78775168955326, 50.780771523714066, 49.99237082898617, 42.08800457417965, 40.70062682032585, 37.637702375650406, 39.83966901898384, 39.02646325528622, 49.54907901585102, 47.21991419792175, 55.25924161076546, 39.189269319176674, 41.18978217244148, 52.67709396779537, 46.91387102007866, 48.472630977630615, 41.42571531236172, 40.55574059486389, 39.945044964551926, 40.3036355227232, 40.627055168151855, 35.72639353573322, 36.032588705420494, 35.75519219040871, 35.31061224639416, 38.320852518081665, 38.36655266582966, 42.63989835977554, 48.097602501511574, 46.90095171332359, 48.786577731370926, 51.969815120100975, 48.21360267698765, 53.67965877056122, 49.984539449214935, 47.44214907288551, 44.71511900424957, 42.03484162688255, 40.718330070376396, 38.58074337244034, 39.83304597437382, 37.929712906479836, 38.790883496403694, 38.99809017777443, 42.54386231303215, 45.109537839889526, 47.24524363875389, 48.37020747363567, 48.980572521686554, 47.144256457686424, 35.77321082353592, 21.80649407207966, 12.719084098935127, 8.538416381925344, 5.999817727133632, 3.8529395777732134, 7.569760484620929, 6.852054996415973, 5.4148984886705875, 3.4070978639647365, 0.9008235996589065, 0.7967300852760673, 0.3385390341281891, 0.08689701760886237, 3.2846620213240385, 13.118923343718052, 30.824835151433945, 30.605096742510796, 34.6898889541626, 42.29868046939373, 58.62534798681736, 47.49508783221245, 28.108389414846897, 6.584534626454115, 0.07960031070979312, 0.018678157503018156, 0.018895768189395312, 0.027260874594503548, 0.05119056368130259, 0.04061833977175411, 0.0923587717988994, 0.040705378851271234, 0.0319058451714227, 0.02350820486753946, 0.0373498323460808, 0.034340022757533006, 0.02763811939075822, 0.024214104196289554, 0.01323762966421782, 0.0704656305606477, 0.06503756987513043, 0.007699609132032492, 0.04727980907773599, 0.03608402897953056, 0.04265342744474765, 0.050896765969810076, 0.03149212752759922, 0.10498161282157525, 0.037828328349860385, 0.01464841807319317, 0.04194496956188232, 0.057351910800207406, 0.02512636325263884, 0.04196482201223262, 0.05950675142230466, 0.019357441560714506, 0.06333435580017976, 0.020337597852631006, 0.02535269046347821, 0.018570230677141808, 0.03020177762664389, 0.02426695624308195, 0.09530020732199773, 0.03266973035351839, 0.0363502893014811, 0.09578906741808169, 0.04458810253709089, 0.03030819418199826, 0.06448877393268049, 0.029738339799223468, 0.06170194632431958, 0.0200121493980987, 0.06713298673275858, 0.03530430265527684, 0.06856999243609607, 0.018419828884361777, 0.1886617616401054, 8.0194715783, 29.977214634418488, 53.727779388427734, 49.42980721592903, 43.27500008046627, 29.231014475226402, 34.15722593665123, 35.74690863490105, 23.583795502781868, 10.229108110070229, 1.4593979017809033, 0.12671007891185582, 0.11612799557042308, 0.8340108348056674, 2.6268403697758913, 5.926787545904517, 7.550803301855922, 7.037218110635877, 6.892198892310262, 8.49086668342352, 9.190008267760277, 21.83701403439045, 33.14204961061478, 49.786657467484474, 54.238517582416534, 52.23780333995819, 48.763965144753456, 47.92009882628918, 45.0857625156641, 45.209917053580284, 44.68644954264164, 45.07470890879631, 46.288709565997124, 45.767100155353546, 48.199243247509, 50.84824450314045, 50.58644615113735, 50.89334808290005, 49.73339572548866, 52.078565284609795, 48.81086602807045, 48.30400362610817, 45.624125227332115, 48.48000258207321, 48.39640326797962, 51.57780535519123, 51.02744288742542, 51.67926751077175, 52.65067398548126, 53.126066476106644, 52.51960761845112, 50.52825227379799, 44.56657737493515, 41.8241885304451, 39.40114974975586, 39.79834243655205, 41.87712348997593, 50.709734335541725, 50.37342958152294, 57.025204449892044, 40.99250055849552, 42.641452476382256, 53.7593936920166, 49.42571483552456, 49.986503943800926, 43.79299968481064, 42.70722694694996, 42.94426202774048, 43.74834448099136, 44.08111162483692, 38.850935474038124, 37.566440999507904, 37.75732755661011, 37.215244844555855, 39.86868806183338, 40.242739990353584, 44.995084181427956, 48.9002638310194, 51.359013095498085, 51.58978991210461, 52.8398734331131, 49.99682039022446, 54.53902065753937, 52.38631837069988, 50.760594606399536, 46.32592096924782, 42.96569287776947, 41.33107379078865, 40.66115453839302, 41.30962014198303, 40.40015794336796, 40.9718182682991, 41.67157731950283, 43.72671224176884, 47.683515921235085, 49.127313047647476, 49.90837633609772, 51.65802665054798, 50.78925646841526, 36.04027569293976, 22.57956638932228, 14.006940443068743, 6.8502291943877935, 5.446528941392899, 7.768891649320722, 9.347734954208136, 9.355247151106596, 9.139526076614857, 7.159182541072369, 2.827011728659272, 0.2317099634092301, 0.056523028324590996, 0.3715920355170965, 3.495019683614373, 16.07909370213747, 33.98476839065552, 36.79231993854046, 42.14582607150078, 48.076483234763145, 64.84595239162445, 55.69814845919609, 34.1180956363678, 7.207950074225664, 0.11611695983447134, 0.06371918905642815, 0.0072837081825127825, 0.01757171550707426, 0.011243431545153726, 0.027203801582800224, 0.1410966709954664, 0.05745654249039944, 0.02200157457991736, 0.024489203497068956, 0.04921669577015564, 0.02159408169973176, 0.012178605338704074, 0.03786621869949158, 0.055942561230040155, 0.009033945661940379, 0.11767564807087183, 0.033248724284931086, 0.06857818574644625, 0.02235816169559257, 0.004101553813598002, 0.04993414106138516, 0.017509755452920217, 0.042297500840504654, 0.038680057841702364, 0.16225093742832541, 0.14075394719839096, 0.1591343031032011, 0.10099510720465332, 0.21872313605854288, 0.1721555067342706, 0.08705768515937962, 0.08218298462452367, 0.16803676524432376, 0.11103939323220402, 0.1284270969335921, 0.14584277960238978, 0.135402082814835, 0.2185430465033278, 0.2532942598918453, 0.18679347907891497, 0.21920755069004372, 0.17748803074937314, 0.2595453994581476, 0.14967665512813255, 0.13803774607367814, 0.17438692215364426, 0.10143389459699392, 0.16956701438175514, 0.1537726423703134, 0.13077700365101919, 0.09392381281941198, 0.36583053530193865, 9.016720466315746, 34.18757490813732, 60.77939920127392, 56.256646290421486, 49.16992776095867, 36.02349579334259, 44.961623176932335, 41.766370832920074, 27.81462337821722, 11.941770259290934, 2.4551757937297225, 0.5089996685273945, 0.7333168911281973, 4.388532238081098, 9.690752048045397, 11.805501971393824, 12.200837507843971, 13.137024622410536, 15.827630795538425, 7.672036746516824, 6.088265581056476, 19.23492506146431, 32.96623684465885, 51.97087146341801, 56.435096114873886, 54.01338346302509, 51.90961875021458, 50.868254229426384, 47.603826597332954, 48.80300045013428, 47.52601817250252, 48.95830571651459, 50.06992846727371, 50.25881253182888, 49.71980385482311, 54.79119412600994, 52.83423073589802, 51.43753208220005, 51.17035321891308, 56.430764347314835, 50.22531732916832, 51.98717638850212, 47.49565400183201, 50.22148713469505, 50.772153586149216, 53.039879500865936, 53.13167117536068, 51.53925262391567, 53.618018478155136, 54.5340733230114, 53.88895533978939, 54.61109139025211, 47.500418946146965, 43.0713652074337, 41.1389485001564, 41.10218547284603, 44.09109368920326, 53.01836125552654, 52.19618417322636, 57.57644847035408, 43.3185875415802, 45.823283940553665, 55.153310894966125, 51.18356131017208, 52.60519042611122, 46.440971195697784, 44.041753336787224, 42.717380002141, 45.02494677901268, 45.116730853915215, 39.6307448297739, 40.4657956212759, 39.53324966132641, 39.905941262841225, 42.49486394226551, 42.32899524271488, 47.95337364077568, 52.29258880019188, 54.53574903309345, 52.469773292541504, 56.07802167534828, 51.40715271234512, 56.04048728942871, 54.558148831129074, 52.72765785455704, 49.276854023337364, 46.07377029955387, 44.1105904430151, 41.531307846307755, 43.59121531248093, 42.77078993618488, 42.13468126952648, 43.65356616675854, 45.982438400387764, 50.36239877343178, 51.25986881554127, 52.61541947722435, 54.05531421303749, 53.602427914738655, 39.66718107461929, 24.893419928848743, 16.50125864893198, 12.746759913861752, 10.819967854768038, 10.80107431858778, 16.63323886692524, 19.273510091006756, 12.170676626265049, 11.790996249765158, 6.254915138706565, 2.1374016953632236, 1.0515906033106148, 0.6272122159134597, 4.4632405042648315, 17.650980055332184, 42.38394409418106, 43.41639809310436, 48.17966289818287, 53.999647200107574, 70.87587162852287, 62.56517417728901, 39.557815343141556, 8.453486189246178, 0.278482039575465, 0.21125273691723123, 0.06401203310815617, 0.1161014341050759, 0.13365560153033584, 0.18491633527446538, 0.20635974244214594, 0.16365398245397955, 0.11983868200331926, 0.14489076740574092, 0.14461240265518427, 0.21415913564851508, 0.06694790994515643, 0.1371090076281689, 0.18222109240014106, 0.16163333697477356, 0.18003242468694225, 0.19209092919481918, 0.2274300719727762, 0.17068031011149287, 0.08187773186364211, 0.08869088502251543, 0.11288188616163097, 0.14359699620399624, 0.14917031745426357], [0.0277337117222487, 0.01021192605549004, 0.019448111597739626, 0.05000970282708295, 0.06533767955261283, 0.04940018436172977, 0.0815100347972475, 0.031126339636102784, 0.03100303736573551, 0.04158978881605435, 0.01648155623115599, 0.03712962970894296, 0.05593252368271351, 0.02680975456314627, 0.026051073691633064, 0.028935484442627057, 0.03085327938606497, 0.06718823220580816, 0.04560841087368317, 0.026159935623581987, 0.02891274132707622, 0.02909984417783562, 0.029920974920969456, 0.03619995986809954, 0.03013804383954266, 0.026185376445937436, 0.06762344986782409, 0.10003695002524182, 3.2833943143486977, 17.006137557327747, 42.04870328307152, 50.89655511081219, 44.3310622125864, 39.732731357216835, 27.10982959717512, 25.73617670685053, 24.546601139009, 12.18088572844863, 2.6700901240110397, 0.49388568266294897, 0.07242482621222734, 0.6521242728922516, 2.504702811129391, 2.9247816698625684, 7.343917228281498, 5.120854591950774, 4.27600460126996, 8.240666259080172, 8.768850266933441, 15.366878919303417, 25.589417181909084, 38.23865532875061, 48.71705286204815, 49.99696858227253, 48.24956014752388, 49.67189222574234, 44.38295602798462, 46.17460548877716, 47.92322225868702, 46.02803595364094, 47.756722792983055, 48.587058037519455, 46.10600396990776, 51.65645353496075, 49.65955048799515, 48.69751051068306, 49.2996110022068, 48.013790398836136, 46.266731545329094, 44.04106177389622, 40.30623838305473, 43.071532398462296, 44.38330180943012, 49.67230260372162, 49.934176951646805, 52.13548623025417, 48.782914727926254, 47.410447373986244, 52.752850502729416, 52.92938902974129, 46.26317113637924, 41.750198900699615, 36.09815798699856, 37.424522414803505, 40.36151021718979, 48.57022114098072, 45.691586807370186, 56.309862434864044, 36.99989899992943, 37.768430560827255, 52.16087646782398, 47.056754752993584, 46.753185242414474, 37.42818541824818, 37.15167425572872, 35.21740324795246, 36.35899119079113, 34.94668297469616, 36.18894651532173, 34.881121292710304, 36.336143016815186, 35.24458318948746, 37.86139257252216, 39.37577851116657, 45.516917780041695, 47.652783170342445, 49.557427167892456, 49.31754983961582, 51.16412155330181, 49.158140793442726, 51.59757189452648, 51.791699677705765, 48.39815117418766, 49.92305874824524, 48.197556138038635, 45.994863733649254, 45.6903100758791, 45.135741233825684, 45.76898105442524, 43.37232045829296, 43.98123398423195, 43.7007824331522, 45.51421992480755, 47.11006209254265, 48.60608361661434, 50.26066303253174, 44.4391056150198, 33.856000900268555, 19.878340736031532, 10.305628404021263, 7.3247182834893465, 4.055128153413534, 5.416456405073404, 6.55253179371357, 4.009062275290489, 8.276045210659504, 6.0938080586493015, 3.2113860407844186, 0.3065644920570776, 0.3231696010334417, 0.14804805658059195, 4.103564629331231, 13.414798267185688, 35.52390620112419, 36.49455651640892, 28.557409420609474, 33.5920936614275, 42.588053941726685, 52.36201487481594, 18.81029214709997, 3.406612202525139, 0.18897457688581198, 0.054199645965127274, 0.06817399727879092, 0.05270382505841553, 0.08401066428632475, 0.004912846925435588, 0.07541574814240448, 0.015868332593527157, 0.04066663503181189, 0.04277802290744148, 0.014390347350854427, 0.01336724297289038, 0.01655829430092126, 0.05833690032886807, 0.07131386824767105, 0.059493745284271426, 0.023001867193670478, 0.03279737604316324, 0.03867724510200787, 0.05827166183735244, 0.0774754528538324, 0.052827604158665054, 0.02481072413502261, 0.040949022222775966, 0.04690187408414204, 0.04816012238734402, 0.012896424486825708, 0.052158546895952895, 0.017279042149311863, 0.038555937353521585, 0.1255667262012139, 0.0033574700591998408, 0.025972352232201956, 0.07009874243522063, 0.017933629387698602, 0.018559232048573904, 0.028530631752801128, 0.015732144784124102, 0.011529313323990209, 0.041309564985567704, 0.03179571416694671, 0.09496578073594719, 0.03130112098006066, 0.10157809389056638, 0.028756760439136997, 0.035914414838771336, 0.04739164331112988, 0.042456049559405074, 0.07305726219783537, 0.017635449294175487, 0.04646242618036922, 0.06072637093893718, 0.08966269771917723, 4.295419659465551, 21.87249083071947, 46.772651597857475, 56.479515731334686, 47.05041289329529, 40.18350876867771, 34.303951263427734, 31.30931295454502, 28.926187232136726, 13.976767212152481, 2.923451503738761, 0.2725270466180518, 0.18527945328969508, 1.1625314690172672, 2.092350125312805, 6.5659085009247065, 8.150229211896658, 6.956632984802127, 9.150877017527819, 13.033296838402748, 12.193641643971205, 16.278161220252514, 27.44400266557932, 42.677501142024994, 51.62949778139591, 51.64284646511078, 50.442650467157364, 51.18672274053097, 46.77506826817989, 48.528746366500854, 50.72522610425949, 47.804322838783264, 50.32515697181225, 51.352975219488144, 48.30466479063034, 52.49928630888462, 50.217740535736084, 48.44272658228874, 50.2730655670166, 51.815349608659744, 48.71277429163456, 46.43941327929497, 42.84142814576626, 45.590991005301476, 46.88685826957226, 52.36062794923782, 51.01216770708561, 53.37555728852749, 49.714970514178276, 48.322162851691246, 53.31418298184872, 54.433990493416786, 47.80308410525322, 43.36895003914833, 37.53709897398949, 40.39999075233936, 40.84192983806133, 49.935780465602875, 48.93086738884449, 58.05998012423515, 39.69824060797691, 40.378176122903824, 53.996945545077324, 49.66563396155834, 48.260644152760506, 40.21378934383392, 40.01974895596504, 37.89944753050804, 38.55623848736286, 37.58183777332306, 37.81745173037052, 37.40609720349312, 37.833422273397446, 37.08292834460735, 38.94629895687103, 40.96612997353077, 47.08325833082199, 49.09417122602463, 49.598620757460594, 51.028423234820366, 53.58474746346474, 49.025311321020126, 50.6128965318203, 53.47070798277855, 49.11165788769722, 51.67017839848995, 49.015276059508324, 49.08132791519165, 47.21768371760845, 46.04200780391693, 47.078090608119965, 44.68961477279663, 44.9432435631752, 45.156913697719574, 46.6761139780283, 49.98441785573959, 51.345010846853256, 53.03827978670597, 47.15696677565575, 38.15100163221359, 21.59937858581543, 12.488613165915012, 6.4399780333042145, 7.047588704153895, 6.772172832861543, 9.379282761365175, 7.394792223349214, 10.517639927566051, 7.143129827454686, 0.9166318795178086, 0.8191076782532036, 0.3100900200661272, 0.3658017696579918, 4.105578046292067, 15.342870857566595, 36.4133320748806, 34.219990968704224, 32.663047313690186, 38.58312964439392, 51.809665113687515, 58.12882483005524, 23.379565961658955, 4.714236035943031, 0.16993825149256736, 0.022892892084200867, 0.07965665456140414, 0.04443290832568891, 0.04051953765156213, 0.024205474874179345, 0.04479693918256089, 0.03006225757417269, 0.07463091213139705, 0.04653860021790024, 0.012374310608720407, 0.09384110788232647, 0.0414671452017501, 0.03144255948427599, 0.05440009634185117, 0.054972366415313445, 0.031565206809318624, 0.02155069203581661, 0.08125679174554534, 0.029594960578833707, 0.05395994710852392, 0.048201671525021084, 0.011224739628232783, 0.07642483891686425, 0.00508410538714088, 0.16549438994843513, 0.09815143479499966, 0.14295996632426977, 0.23343848471995443, 0.1203899121901486, 0.14094904297962785, 0.12381936176097952, 0.22108319535618648, 0.26115603803191334, 0.12184331193566322, 0.09018667624332011, 0.12653226032853127, 0.09212488395860419, 0.09164919698378071, 0.11265287423157133, 0.11013366136467084, 0.20863123383605853, 0.21207286947173998, 0.1939389659673907, 0.0633626761555206, 0.1366558819427155, 0.12761714664520696, 0.12805535516235977, 0.09792994824238122, 0.2440093393670395, 0.17512964870547876, 0.15368716180091724, 0.276259247912094, 4.739992478862405, 24.346908554434776, 53.40160869061947, 63.77398431301117, 54.895247742533684, 50.315095111727715, 38.398269563913345, 38.21418844163418, 33.09437356889248, 16.750318184494972, 3.6072827596217394, 0.8287703816313297, 0.4014819738222286, 2.0864039193838835, 7.206635344773531, 10.041901655495167, 16.076376847922802, 11.102900672703981, 11.642465069890022, 15.562602616846561, 14.622438065707684, 19.21751819550991, 29.444120340049267, 41.7201729118824, 52.01668940484524, 53.718758672475815, 54.132210686802864, 55.84985911846161, 49.50923815369606, 48.97095523774624, 54.34332735836506, 49.89839807152748, 52.807088792324066, 53.03215071558952, 50.56362457573414, 56.65184028446674, 51.68164238333702, 48.782470151782036, 51.98968045413494, 52.39069573581219, 51.229132264852524, 47.75565505027771, 45.93731202185154, 48.072436451911926, 49.20094929635525, 52.94666290283203, 53.356113731861115, 53.39801028370857, 49.960159957408905, 46.732278764247894, 55.805496498942375, 56.63555055856705, 50.55164761841297, 45.704319924116135, 40.020634308457375, 41.74103759229183, 43.26527640223503, 51.472797989845276, 51.68688230216503, 58.108636513352394, 42.9996782541275, 42.08972588181496, 55.644153356552124, 51.75340533256531, 50.13100638985634, 41.427960991859436, 41.71129658818245, 39.34014022350311, 39.64804530143738, 39.067185670137405, 38.94496142864227, 38.775380328297615, 39.660124853253365, 38.837575390934944, 40.663935989141464, 43.527336940169334, 50.581422820687294, 51.27955935895443, 54.60057735443115, 53.992188200354576, 55.59650011360645, 50.91525390744209, 53.25856536626816, 55.82568101584911, 52.53798723220825, 54.675475135445595, 52.38979518413544, 51.466288939118385, 48.918506652116776, 48.742002323269844, 51.688994988799095, 48.06356392800808, 48.62901158630848, 48.36158573627472, 49.17254962027073, 51.571858674287796, 54.05676573514938, 56.52845710515976, 49.085028916597366, 38.05652730166912, 23.233395405113697, 13.979976139962673, 11.755087226629257, 9.077798388898373, 11.262606102973223, 14.827134981751442, 13.6306456848979, 16.909168660640717, 15.127216279506683, 7.946838950738311, 1.3950783968903124, 0.49352683941833675, 0.6046511640306562, 5.341962352395058, 18.201025240123272, 47.205535769462585, 47.633685395121574, 40.68064369261265, 46.276379227638245, 57.41280645132065, 64.05319333076477, 28.37712049484253, 5.606446685269475, 0.37632518622558564, 0.25021093315444887, 0.18421240820316598, 0.13596721342764795, 0.18970844219438732, 0.0682405530824326, 0.13071113062324002, 0.1632385133416392, 0.19888468261342496, 0.12260576477274299, 0.13467934972140938, 0.1360432687215507, 0.12400436433381401, 0.08416082302574068, 0.13245165988337249, 0.12062837908160873, 0.11455244573880918, 0.09682128351414576, 0.12308147401199676, 0.18146518530556932, 0.1892155670793727, 0.1614989191875793, 0.05770441239292268, 0.19949468347476795, 0.15352022310253233], [0.04882676024863031, 0.014124442332104081, 0.01334282260359032, 0.015526074494118802, 0.049002853338606656, 0.0296515530499164, 0.034415681002428755, 0.055685410770820454, 0.08071954362094402, 0.049181002177647315, 0.04709030166850425, 0.017815722530940548, 0.07449001539498568, 0.02880793523218017, 0.06995555988396518, 0.026122854214918334, 0.016592412684985902, 0.04538012253760826, 0.045518113765865564, 0.041521511229802854, 0.023637698504899163, 0.022950621896598022, 0.03927299301722087, 0.014351595182233723, 0.07227454872918315, 0.09150076744845137, 0.03856903254927602, 0.04714484210126102, 0.9260884439572692, 10.828854627907276, 36.883815228939056, 47.73398481309414, 42.00414687395096, 27.25830662995577, 24.43194229155779, 29.520051665604115, 29.86839037388563, 15.803158208727837, 4.691818663850427, 0.5141505296342075, 0.41790487070102245, 0.1427631636033766, 0.24929622130002826, 4.96333546936512, 5.465805307030678, 4.845604486763477, 8.36459280923009, 12.909040655940771, 7.479649744927883, 8.532720487564802, 18.66572130471468, 33.24781693518162, 44.78890344500542, 51.92040257155895, 53.35638351738453, 51.5800092369318, 51.522541120648384, 49.7786170989275, 49.459833204746246, 49.81713563203812, 47.915630266070366, 50.60455597937107, 51.25704936683178, 52.35377311706543, 47.233954444527626, 50.885121524333954, 50.30396930873394, 50.30740812420845, 46.21812455356121, 43.513000309467316, 37.60723941028118, 39.33436833322048, 43.64487983286381, 48.80106635391712, 50.754659324884415, 51.17767922580242, 47.908665239810944, 51.60243943333626, 51.46914258599281, 50.207690075039864, 42.67703376710415, 41.14936754107475, 37.27502703666687, 40.187183171510696, 40.73633350431919, 50.25562450289726, 45.207071006298065, 56.012338399887085, 39.176304414868355, 36.35379686951637, 52.24671386182308, 46.224945187568665, 45.74052058160305, 38.62129099667072, 38.876747488975525, 36.12514793872833, 37.72048473358154, 36.91447578370571, 36.71668119728565, 35.04415914416313, 36.971556320786476, 36.99048310518265, 39.19646993279457, 43.13166417181492, 46.68279021978378, 47.99260273575783, 47.71498963236809, 52.64611043035984, 51.15292735397816, 51.620898842811584, 52.14710220694542, 49.72741864621639, 52.22625195980072, 48.20369280874729, 48.431349992752075, 47.67781622707844, 46.30148068070412, 47.218139693140984, 47.86894977092743, 47.26300768554211, 47.094220742583275, 48.395118936896324, 48.642968237400055, 49.243317022919655, 50.95792181789875, 49.66516278684139, 44.012221321463585, 28.95267941057682, 16.961923129856586, 9.46498716250062, 1.7411879310384393, 4.802690064534545, 5.139885395765305, 7.216629758477211, 6.423342525959015, 10.066159553825855, 5.188491912558675, 0.7571033178828657, 0.42033347475808114, 0.06851802725577727, 0.553705160273239, 4.796247035264969, 18.881331235170364, 36.86332292854786, 42.24435858428478, 37.44677782058716, 41.40746109187603, 52.5309120118618, 43.83234277367592, 19.44474410265684, 2.2933382028713822, 0.02325313242181437, 0.07895396687672473, 0.02791146165691316, 0.03268947148171719, 0.018479764730727766, 0.024896427348721772, 0.07666484947549179, 0.09967096731998026, 0.04489767088671215, 0.0651475932681933, 0.03351661733177025, 0.06011524201312568, 0.018335706445213873, 0.02281033928738907, 0.016178615260287188, 0.06952369672944769, 0.05327937542460859, 0.04441341581696179, 0.10491988097783178, 0.035177072568330914, 0.06766190053895116, 0.010772331042971928, 0.06589774871827103, 0.021322064167179633, 0.008321466266352218, 0.08455975708784536, 0.048179548102780245, 0.03837833399302326, 0.04813166844542138, 0.05792277821456082, 0.053025906017865054, 0.04327032285800669, 0.011274316948401975, 0.06955053278943524, 0.01707343941234285, 0.05057377587945666, 0.02200188442657236, 0.0050570216353662545, 0.007666071478524827, 0.025796780500968453, 0.06267037111683749, 0.042119181307498366, 0.028375491347105708, 0.006731845314789098, 0.07739746797597036, 0.058881788863800466, 0.05464487891003955, 0.040150894346879795, 0.07493157841963693, 0.03582236997317523, 0.0693125334510114, 0.02999085369083332, 0.033781931415433064, 1.6193424817174673, 14.535982254892588, 42.11500972509384, 54.520838633179665, 47.22609646618366, 35.75440563261509, 27.557947151362896, 31.89366839826107, 28.51759895682335, 19.323220923542976, 4.317833706736565, 0.8262589538935572, 0.08447584245004691, 0.9503012197092175, 1.8849542853422463, 6.943782549351454, 7.821147870272398, 7.523178309202194, 11.142652239650488, 11.585603021085262, 8.260479345917702, 12.155164908617735, 23.476905338466167, 35.81423342227936, 47.97530606389046, 55.166971161961555, 55.38710094988346, 53.62830072641373, 53.18179048597813, 51.33525677025318, 52.88042485713959, 50.85012160241604, 49.46824595332146, 51.985637471079826, 52.99400836229324, 51.681972965598106, 48.88992078602314, 49.756217300891876, 53.218397721648216, 50.94488851726055, 47.780536115169525, 44.38014417886734, 40.042775720357895, 41.79161287844181, 45.712759271264076, 50.20673632621765, 51.98862411081791, 53.87002855539322, 51.06119267642498, 52.131507843732834, 53.22822779417038, 53.133305087685585, 45.755590572953224, 42.553848177194595, 39.85411584377289, 41.89771458506584, 42.55078934133053, 51.49018965661526, 48.93450379371643, 56.05344459414482, 42.50088281929493, 38.77331703901291, 53.53374280035496, 48.806693851947784, 48.75563979148865, 39.68624845147133, 39.86861206591129, 37.12917186319828, 39.76769708096981, 38.46161596477032, 38.13401274383068, 37.23984092473984, 40.096413642168045, 37.97575123608112, 41.00116029381752, 43.539899066090584, 48.90429921448231, 50.422028973698616, 51.28697656095028, 53.92123840749264, 51.71419903635979, 52.103442549705505, 53.11760053038597, 52.21284627914429, 53.887484818696976, 51.43875181674957, 49.699250757694244, 49.07396011054516, 48.84585075080395, 49.42929424345493, 51.1539077013731, 50.47913610935211, 49.96104910969734, 50.09731359779835, 51.262798458337784, 52.218906953930855, 51.39468178153038, 53.087779730558395, 47.84103646874428, 33.12544830143452, 19.439943060278893, 9.813874941319227, 5.831562280654907, 7.242240384221077, 9.70431162044406, 9.720511101186275, 8.315492793917656, 6.836956981569529, 4.64233391918242, 2.033324330113828, 0.5699331988580525, 0.1673687729635276, 0.5297155631706119, 4.607536336407065, 20.948002338409424, 40.57304486632347, 47.00670003890991, 39.25715647637844, 43.30210022628307, 55.00834487378597, 50.82378141582012, 23.28040838241577, 2.9046109272167087, 0.028174282124382444, 0.054921781629673205, 0.012378166993585182, 0.07516767043853179, 0.05375401597120799, 0.0076919195544178365, 0.05401144844654482, 0.012944158497703029, 0.04088734604010824, 0.07884831473347731, 0.00834467786262394, 0.09310126828495413, 0.009622814795875456, 0.058718508953461424, 0.07696416505496018, 0.06744426573277451, 0.05102506846014876, 0.026589423905534204, 0.0533719286613632, 0.03259321492805611, 0.05763366716564633, 0.03291554450697731, 0.08230678969994187, 0.04168991566984914, 0.05186194757698104, 0.11532384145539254, 0.1906717350357212, 0.10982431937009096, 0.21236269298242405, 0.3069634409621358, 0.10587216034764424, 0.2120768028544262, 0.12587637989781797, 0.1453372582909651, 0.13050004898104817, 0.1412472824449651, 0.16258986142929643, 0.2064569341018796, 0.20529991103103384, 0.1353664745693095, 0.14493004186078906, 0.12616323481779546, 0.1393823989201337, 0.29671179887373, 0.12460616446333006, 0.11530165866133757, 0.24903471814468503, 0.20181643310934305, 0.13833083503413945, 0.25893790705595165, 0.17826339695602655, 0.12905158451758325, 0.17526629293570295, 1.8824802618473768, 16.50571011006832, 47.5681959092617, 61.383543983101845, 54.42796781659126, 39.776516407728195, 34.04521934688091, 40.53631603717804, 39.17371295392513, 21.852866783738136, 6.6985285095870495, 1.0129380086436868, 0.7689016847871244, 1.165146678686142, 4.373249933123589, 12.35239902511239, 14.1352310590446, 14.930416289716959, 14.678901135921478, 19.90477591753006, 12.03097902238369, 12.130519431084394, 24.065351262688637, 38.88493224978447, 51.050066873431206, 54.6635589748621, 56.74346476793289, 54.614678397774696, 55.762106627225876, 53.869424387812614, 55.262368842959404, 54.28842030465603, 52.11742579936981, 54.995638355612755, 54.73835416138172, 53.83164681494236, 49.93586786091328, 50.81757254898548, 52.82665394246578, 54.398469999432564, 50.517187267541885, 47.043987438082695, 41.767864152789116, 42.38755390048027, 47.52998895943165, 52.74467334151268, 54.102747067809105, 55.505973771214485, 52.84558832645416, 51.821748465299606, 55.17343081533909, 53.479949086904526, 47.96843983232975, 44.83504816889763, 42.36071974039078, 43.97551529109478, 45.390023589134216, 54.29879754781723, 51.434955820441246, 56.43591687083244, 45.003504529595375, 42.552123069763184, 55.25343172252178, 51.768357530236244, 49.4555926322937, 41.80725283920765, 42.30758719146252, 39.49211306869984, 41.165414080023766, 40.42153179645538, 40.065927878022194, 38.842439129948616, 42.094604820013046, 40.5421981215477, 43.0809672921896, 47.15549245476723, 51.66160225868225, 52.60721571743488, 51.689629554748535, 55.4238373786211, 53.08640420436859, 51.912077218294144, 53.425581604242325, 54.268881753087044, 57.6248312741518, 53.05600583553314, 52.45993562042713, 52.10354894399643, 51.79909408092499, 50.854156985878944, 53.49634900689125, 51.787763088941574, 52.35234059393406, 52.15885877609253, 55.25801807641983, 54.76396478712559, 54.78570342063904, 54.96246613562107, 50.32490998506546, 33.31318862736225, 19.974399581551552, 13.289634883403778, 6.991763049736619, 9.923520907759666, 15.433435197919607, 16.63222812116146, 15.7689324952662, 17.85882130265236, 10.786053724586964, 2.462574471719563, 1.2349762441590428, 0.5812295770738274, 0.9449056873563677, 6.179414615035057, 25.321846939623356, 50.04217095673084, 56.28303587436676, 49.148432314395905, 52.06485942006111, 67.31602504849434, 57.17380307614803, 28.488914296031, 3.5348612582311034, 0.13834245706675574, 0.20527261483948678, 0.07112039776984602, 0.21998990792781115, 0.08619945074315183, 0.084656154649565, 0.09746917101438157, 0.16771712223999202, 0.15214226266834885, 0.16410019132308662, 0.09645317084505223, 0.1765224669361487, 0.11079482588684186, 0.16401186090661213, 0.18138942687073722, 0.16192408074857667, 0.19482920179143548, 0.12484371109167114, 0.17515020619612187, 0.19965057901572436, 0.21218049572780728, 0.1108466723235324, 0.13140440045390278, 0.12704671709798276, 0.09813220574869774], [0.02770638770016376, 0.03478799793811049, 0.09358575713122264, 0.059387536530266516, 0.08421571968938224, 0.06502585136331618, 0.02617827594804112, 0.016825020320538897, 0.02056637044006493, 0.049238403589697555, 0.08606705159763806, 0.02617776201077504, 0.029514420857594814, 0.012189620665594703, 0.13374620291870087, 0.07438933564117178, 0.013419283295661444, 0.02968736724142218, 0.11129748992971145, 0.028558183985296637, 0.001964846642295015, 0.07390933678834699, 0.019660881625895854, 0.03749504467123188, 0.050767101638484746, 0.02103539849485969, 0.044514251421787776, 0.08788566221483052, 0.21400012308731675, 6.676156260073185, 29.080325961112976, 45.263984352350235, 42.96748638153076, 30.937550403177738, 29.458080790936947, 30.090197771787643, 31.70437965542078, 22.449835650622845, 8.119740597903728, 1.3710484863258898, 0.02520349280530354, 0.9543840412516147, 1.3958919094875455, 6.8854552041739225, 5.421035159379244, 6.250782385468483, 13.753059916198254, 11.34202279150486, 6.57897362485528, 7.222395474091172, 16.996465176343918, 24.376292377710342, 36.583426147699356, 48.66833187639713, 49.013125374913216, 48.79470929503441, 52.60127663612366, 53.37276443839073, 52.99680881202221, 51.79192766547203, 52.108982652425766, 49.66673210263252, 49.70765970647335, 48.352534621953964, 48.60945403575897, 49.44763965904713, 49.30702060461044, 51.5905574709177, 45.78348107635975, 43.53603087365627, 38.2997902482748, 37.03838713467121, 38.45040276646614, 45.62049642205238, 49.370025023818016, 53.72545771300793, 51.85696877539158, 52.244753167033195, 50.133860036730766, 47.60842055082321, 39.63136039674282, 36.500461399555206, 37.41660363972187, 36.92923419177532, 40.13739824295044, 48.71913135051727, 45.180727019906044, 53.26032467186451, 42.379566729068756, 37.746281549334526, 53.224184811115265, 47.05529563128948, 45.19050769507885, 38.347496688365936, 39.98080104589462, 37.80171297490597, 39.727354645729065, 41.64701923727989, 41.85105688869953, 39.805003479123116, 39.06296409666538, 41.76415555179119, 48.13617043197155, 46.001175194978714, 44.132617861032486, 47.67389103770256, 48.898698315024376, 48.89565087854862, 53.10396306216717, 51.36749044060707, 48.36810998618603, 50.248431488871574, 50.41838876903057, 55.598183423280716, 51.173951625823975, 54.490371868014336, 54.23334985971451, 52.494205981492996, 51.84523120522499, 53.60571473836899, 52.20405355095863, 50.298767387866974, 52.504108250141144, 53.00902895629406, 53.72065857052803, 52.43233770132065, 39.73993577063084, 24.693467058241367, 13.244167473167181, 6.343584805727005, 4.93180476129055, 7.268538773059845, 6.564798960462213, 8.900540750473738, 5.452168313786387, 5.693812072277069, 3.436345369555056, 0.8721133496146649, 0.8141399791929871, 0.08374318684218451, 0.786260993918404, 4.854168752208352, 19.363867342472076, 30.717318020761013, 28.126729130744934, 34.34291437268257, 46.50283947587013, 54.32774439454079, 44.25916627049446, 18.711037673056126, 0.9194239578209817, 0.01348769817923312, 0.03964715790061746, 0.028944957957719453, 0.06236584566067904, 0.029232350934762508, 0.03621055031544529, 0.06218965238076635, 0.028340018543531187, 0.04222927520459052, 0.00583634070608241, 0.016129657633427996, 0.04169977881247178, 0.035849528867402114, 0.024282956946990453, 0.07613812500494532, 0.036846600560238585, 0.052253404501243494, 0.007097732932379586, 0.042926786409225315, 0.0032136314030140056, 0.050695079917204566, 0.029928973417554516, 0.05978419962048065, 0.07849572779377922, 0.048751317226560786, 0.010438186473038513, 0.020302505399740767, 0.018504749132262077, 0.015071636134962318, 0.014751616490684683, 0.03861157987557817, 0.015449731617991347, 0.018227649743494112, 0.022966127216932364, 0.05888971129024867, 0.03390715770365205, 0.07384440628811717, 0.029712232899328228, 0.02020836396695813, 0.011014913143299054, 0.0344331103406148, 0.09782604014617391, 0.02796515604131855, 0.027615563667495735, 0.05203904627705924, 0.03560821583960205, 0.03037708404008299, 0.0383433343085926, 0.0336603082541842, 0.035380447006900795, 0.05175495214643888, 0.020493966512731276, 0.03651667509984691, 0.45900201075710356, 8.756996802985668, 33.93535204231739, 52.65955410897732, 48.23014318943024, 32.7007032930851, 31.535644009709358, 33.39753270149231, 38.14362622797489, 22.57934980094433, 9.13872241973877, 1.7281182948499918, 0.05745764457969926, 0.40115412266459316, 0.9720738139003515, 3.7276161275804043, 4.695293102413416, 7.175810923799872, 7.423951383680105, 7.481594290584326, 7.454305104911327, 8.541150335222483, 18.667440712451935, 27.312007248401642, 41.153459921479225, 50.69505952298641, 52.01371796429157, 50.39690472185612, 53.863071128726006, 53.862007185816765, 54.645677134394646, 52.89239041507244, 54.22829233109951, 50.97641542553902, 50.977331176400185, 48.53720471262932, 48.66755671799183, 48.58286686241627, 51.153877303004265, 51.06084309518337, 47.587962448596954, 43.941518515348434, 39.832787588238716, 39.75703105330467, 42.29803070425987, 47.86677248775959, 51.59159101545811, 55.16972981393337, 52.900009006261826, 54.01034362614155, 51.85617461800575, 50.16987830400467, 41.995988711714745, 39.34652008116245, 37.92871356010437, 39.49734918773174, 43.17114785313606, 50.34610144793987, 48.42774398624897, 54.71823424100876, 44.339569956064224, 39.209070056676865, 54.24675174057484, 47.329120337963104, 47.77813084423542, 40.258030369877815, 41.44073210656643, 39.61164705455303, 40.78869849443436, 42.48355954885483, 42.80623823404312, 41.38409234583378, 39.993484765291214, 42.260667309165, 48.30359324812889, 49.12059500813484, 48.33654507994652, 49.76048447191715, 50.56999683380127, 51.444679498672485, 54.03887629508972, 51.999449729919434, 51.1275789141655, 51.134730130434036, 53.091826513409615, 56.63004845380783, 51.917385533452034, 56.10389828681946, 56.08315899968147, 53.344452157616615, 54.47057493031025, 53.81924048066139, 54.24636796116829, 54.01157855987549, 55.599494352936745, 54.13723781704903, 56.96770213544369, 53.65000896155834, 44.99508038163185, 27.044790387153625, 17.719857059419155, 5.454394044354558, 5.269107911735773, 9.276505876332521, 9.496470373123884, 9.352342206984758, 7.853174926713109, 7.824689755216241, 4.785574832931161, 0.8283976453822106, 0.48620478075463325, 0.06894095495226793, 0.739070673007518, 5.818911334499717, 21.58039290457964, 37.1417947858572, 36.72907993197441, 38.47491905093193, 51.35963246226311, 61.28279618918896, 48.57127368450165, 22.318738885223866, 1.398948251735419, 0.03418965250602923, 0.007613564530402073, 0.06009790173266083, 0.05792051837488543, 0.09844676504144445, 0.052668665812234394, 0.06398094454198144, 0.036501271824818105, 0.0365373253589496, 0.07321044889977202, 0.031138460763031617, 0.0886411165993195, 0.037681587200495414, 0.03434068326896522, 0.048205389684881084, 0.07492650212952867, 0.06576864470844157, 0.030186027397576254, 0.043787948598037474, 0.011076086520915851, 0.0575516524259001, 0.06951575574930757, 0.10067176830489188, 0.02835495055478532, 0.07690663376706652, 0.12402832086081617, 0.11474211642052978, 0.20239370525814593, 0.19655365613289177, 0.3069182293256745, 0.18775635631754994, 0.17132217879407108, 0.08707927423529327, 0.1938134094234556, 0.18550794571638107, 0.14417990867514163, 0.18983376125106588, 0.12983181921299547, 0.10394699216703884, 0.19039975275518373, 0.21625939873047173, 0.20908851554850116, 0.12998876860365272, 0.3082665038527921, 0.10602565875160508, 0.08388789821765386, 0.2871258929371834, 0.1364160791854374, 0.14079529966693372, 0.18311918014660478, 0.15586888301186264, 0.17714245710521936, 0.13608134089736268, 0.6758887914475054, 9.925694391131401, 39.42560903728008, 59.81983669102192, 56.27296641469002, 42.92996719479561, 40.98002962768078, 39.84714321792126, 42.19578579068184, 28.132502920925617, 10.832159500569105, 2.3524124454706907, 0.2826240548165515, 1.925811474211514, 4.755188813433051, 14.355209805071354, 14.408211261034012, 12.885158937424421, 23.36992397904396, 20.37299819290638, 12.096048630774021, 12.062689270824194, 22.961594089865685, 30.117256119847298, 42.40886315703392, 57.450876608490944, 55.533054918050766, 52.273016050457954, 54.461189433932304, 53.15123252570629, 54.53270919620991, 54.44879449903965, 55.05736604332924, 52.01604723930359, 51.489802077412605, 48.99187691509724, 49.52516309916973, 48.469518944621086, 52.512984573841095, 54.9721822142601, 49.95694912970066, 46.771682649850845, 42.49738700687885, 41.15919001400471, 43.63516375422478, 50.457598865032196, 54.19799655675888, 57.58719049394131, 53.49165625870228, 55.59341847896576, 53.317268416285515, 51.691191270947456, 42.85828784108162, 39.36762414872646, 39.56801779568195, 39.9606279283762, 44.72111128270626, 51.518418341875076, 50.191081166267395, 56.59587308764458, 47.25669622421265, 42.99935907125473, 55.54616801440716, 51.3540505617857, 49.54744130373001, 42.646775990724564, 43.434887900948524, 43.047548085451126, 42.50817842781544, 45.983373150229454, 46.285734325647354, 45.089315325021744, 41.841515600681305, 46.0001340508461, 51.60562366247177, 52.26361155509949, 50.293649062514305, 52.14373178780079, 52.96431675553322, 54.33552637696266, 54.99007545411587, 54.630523547530174, 51.11141838133335, 50.50836034119129, 54.28444191813469, 59.16599057614803, 54.324123188853264, 59.650525376200676, 59.51147943735123, 57.45359726250172, 57.35408440232277, 58.975495398044586, 56.705463007092476, 57.448562532663345, 58.610859364271164, 58.67152690887451, 59.06637892127037, 57.07737945020199, 45.374193638563156, 28.73721957206726, 18.05251970887184, 11.26366339623928, 9.981440249830484, 14.871927928179502, 13.794061616063118, 15.765488930046558, 14.003335386514664, 12.724211923778057, 10.426858998835087, 4.7828389797359705, 1.477083102799952, 0.30749262194149196, 1.7607824108563364, 6.86226362362504, 24.547651782631874, 43.736580312252045, 40.34826032817364, 47.426501512527466, 58.15898761153221, 67.85805836319923, 55.07421433925629, 25.56729096919298, 2.1605951758101583, 0.1476502208970487, 0.13921016128733754, 0.1698520584614016, 0.18235035968245938, 0.1695014233700931, 0.18265401682583615, 0.17708436178509146, 0.12751502712490037, 0.1086008147103712, 0.20957570581231266, 0.12140103644924238, 0.2550160721875727, 0.11572099436307326, 0.10355600650655106, 0.16862313612364233, 0.15632972703315318, 0.11958693066844717, 0.14110916876234114, 0.155582414008677, 0.11274153119302355, 0.1408047991571948, 0.09550036455038935, 0.19898919184925035, 0.15315882686991245, 0.10460949255502783], [0.02738104129093699, 0.02542403497500345, 0.05140859182574786, 0.08010829595150426, 0.07558270168374293, 0.07049994746921584, 0.03414184335269965, 0.04734425347123761, 0.06243836833164096, 0.08554771891795099, 0.03805853513767943, 0.009791000302357133, 0.05382788192946464, 0.033511990041006356, 0.06343286106130108, 0.09912392284604721, 0.04326825597672723, 0.002339066954846203, 0.07067545797326602, 0.03351288061821833, 0.04733963360195048, 0.015243524030665867, 0.02421426190267084, 0.03160104140988551, 0.06842832386610098, 0.03693776969157625, 0.03905591853254009, 0.04483976852498017, 0.09663183547672816, 3.118855068460107, 20.090931728482246, 42.186932265758514, 49.25223894417286, 40.288155153393745, 27.365297488868237, 24.617737121880054, 26.710982099175453, 25.07901906967163, 9.942503739148378, 2.5703081907704473, 0.08620883891126141, 0.44821115385275334, 0.5679772538132966, 2.3441652255132794, 4.041969934478402, 4.318772731348872, 5.783059308305383, 2.6350821275264025, 2.6760268304497004, 5.891067562624812, 9.484949391335249, 15.017707105726004, 32.492451667785645, 42.588456720113754, 50.35325646400452, 51.278191432356834, 49.10228759050369, 49.90881711244583, 49.25606533885002, 48.90294648706913, 49.23360474407673, 48.650944009423256, 48.70610184967518, 49.550481140613556, 50.46236000955105, 48.65973673760891, 52.20283001661301, 48.54852810502052, 51.11489899456501, 43.4653926640749, 41.1578144878149, 36.324196457862854, 38.33255968987942, 40.08847966790199, 45.61388857662678, 49.1853891313076, 46.32599696516991, 47.74591617286205, 43.53172950446606, 39.50582653284073, 34.47811111807823, 35.16051650047302, 35.918632820248604, 36.50676906108856, 39.28240992128849, 46.20702534914017, 47.42265231907368, 50.545339956879616, 47.239209562540054, 40.283044427633286, 52.17240124940872, 45.72129741311073, 44.1391459107399, 38.6216139793396, 40.400876104831696, 44.78626638650894, 48.87585774064064, 47.45076321065426, 49.84784558415413, 47.12145008146763, 48.74044440686703, 47.136797457933426, 49.256069138646126, 49.602659940719604, 49.31685447692871, 46.206071600317955, 47.219013646245, 48.22740353643894, 49.50485698878765, 50.03943890333176, 52.816907465457916, 44.47032853960991, 49.52395856380463, 48.2205943018198, 52.568252608180046, 54.57555569708347, 56.40129312872887, 52.674806490540504, 54.12380173802376, 53.95640552043915, 55.329119861125946, 55.92775113880634, 54.74391706287861, 55.368804931640625, 53.433872759342194, 46.004074439406395, 33.799680322408676, 20.625222958624363, 12.499899510294199, 3.8995977491140366, 4.121715780347586, 7.239287467673421, 8.904511537402868, 8.345113154500723, 7.331968769431114, 4.904923103749752, 2.363339471630752, 1.267544177826494, 0.2256782620679587, 0.10067456620163284, 0.8218353381380439, 7.1358446683734655, 20.76784260571003, 31.281447149813175, 38.29143829643726, 39.85671490430832, 48.19931544363499, 51.22959204018116, 36.3659942150116, 8.490158021450043, 0.5248024268075824, 0.07856417607399635, 0.023838345550757367, 0.05125147174112499, 0.08783596800640225, 0.07622706398251466, 0.015824653492018115, 0.0208636747993296, 0.012230507436470361, 0.030910400637367275, 0.03768121612665709, 0.10586709147901274, 0.04890996984613594, 0.013338194385141833, 0.012899022003693972, 0.04801261311513372, 0.04308676747314166, 0.031017869187053293, 0.03125963863567449, 0.0293336503818864, 0.07546905661001801, 0.026226758600387257, 0.033545037877047434, 0.03104295006778557, 0.011078247098339489, 0.05481047432112973, 0.040684528212295845, 0.05211944684560876, 0.0401915714610368, 0.03348458994878456, 0.036700193377328105, 0.0530025246553123, 0.0466186816629488, 0.030629373432020657, 0.06640301027800888, 0.014675912789243739, 0.04917737307550851, 0.02923141211795155, 0.022763418855902273, 0.05334416862751823, 0.05451747070765123, 0.029667633534700144, 0.012397422015055781, 0.016519351956958417, 0.08329144155140966, 0.029348116695473436, 0.024972580977191683, 0.005981912045172066, 0.059993648537783884, 0.01630438146094093, 0.013800322321912972, 0.009087271755561233, 0.025992974660766777, 0.05554395371291321, 0.16969953227089718, 4.016996249556541, 24.797704964876175, 48.745733723044395, 54.372969567775726, 44.7170303016901, 31.478952951729298, 30.155453570187092, 31.45964238792658, 29.12619709968567, 12.42934299632907, 2.8102061804383993, 0.2878134185448289, 0.25913597142789513, 0.7164393248967826, 3.277586088515818, 5.495606632903218, 9.828203022480011, 8.638447914272547, 7.164845187216997, 5.91711089015007, 6.863597352057695, 13.062853552401066, 20.99321611225605, 36.45649775862694, 48.40550757944584, 52.31898978352547, 53.55423130095005, 48.86549569666386, 51.0142157971859, 49.280182644724846, 49.39480349421501, 51.38587765395641, 49.27096053957939, 48.91717292368412, 49.906693026423454, 50.73582373559475, 49.03864860534668, 53.532625660300255, 50.12740038335323, 50.54698146879673, 45.65421961247921, 41.71112559735775, 38.56991395354271, 39.94239270687103, 43.772123605012894, 48.157620280981064, 51.83890454471111, 50.48562616109848, 49.614838287234306, 46.56567670404911, 41.964097023010254, 37.41822995245457, 36.56090095639229, 39.02197189629078, 40.44922091066837, 41.44505247473717, 49.43940930068493, 49.611433669924736, 53.17864045500755, 48.45406137406826, 43.587259724736214, 53.04581478238106, 49.0333516895771, 47.05215319991112, 39.53662008047104, 42.20143988728523, 46.228984370827675, 50.53264483809471, 47.87376791238785, 50.42602255940437, 48.96993689239025, 49.69298109412193, 47.780243530869484, 51.026287749409676, 50.90448148548603, 51.25081390142441, 49.15175713598728, 49.267362132668495, 49.44740787148476, 51.182808950543404, 52.12399944663048, 52.49853394925594, 46.30438752472401, 49.05379839241505, 50.661146342754364, 54.42959412932396, 55.27687266469002, 58.92144329845905, 54.073925614356995, 55.40742605924606, 56.44087180495262, 57.43638798594475, 57.28729538619518, 56.62279464304447, 56.31305806338787, 55.437398850917816, 50.56310020387173, 38.490657806396484, 21.518157944083214, 12.718993853777647, 5.919054485857487, 5.782835595309734, 8.661553524434566, 12.95847600325942, 7.086609285324812, 6.7854611948132515, 6.618921356275678, 3.707145438529551, 2.046034885570407, 0.2727490081451833, 0.011402807758713607, 1.062427859287709, 8.353306464850903, 24.3136565387249, 34.48932811617851, 37.19317562878132, 44.70835156738758, 51.71272471547127, 56.58833809196949, 42.68090195953846, 11.745958216488361, 0.8202975487802178, 0.06015475395543035, 0.0019733987346626236, 0.010469120115885744, 0.06303691043285653, 0.04246178636094555, 0.024402494673267938, 0.027402593259466812, 0.0063939909341570456, 0.009061750224645948, 0.06521410454297438, 0.06252190447412431, 0.0323780292092124, 0.012933987363794586, 0.0660603161668405, 0.06292705031228252, 0.023746148544887546, 0.03321659300127067, 0.05885911625227891, 0.051427861690171994, 0.051071137277176604, 0.031414999830303714, 0.03338162809086498, 0.03518974845064804, 0.009660268206062028, 0.025809667895373423, 0.15323724219342694, 0.12184493723907508, 0.13771059253485873, 0.1454351030406542, 0.1494581816950813, 0.1702553266659379, 0.14725833723787218, 0.08311051336931996, 0.11646104176179506, 0.12473768787458539, 0.14868047030176967, 0.10316391504602507, 0.16336613305611536, 0.10128740206710063, 0.11558400132344104, 0.10332939913496375, 0.14674052596092224, 0.15900255704764277, 0.18572481611045077, 0.17377766343997791, 0.12175096650025807, 0.13158845307771116, 0.15344063518568873, 0.11360622229403816, 0.13268450129544362, 0.08548974234145135, 0.22167434566654265, 0.14211365079972893, 0.35137079714331776, 5.233949823305011, 27.485714927315712, 56.904819309711456, 64.52252894639969, 52.13781550526619, 38.341493010520935, 34.882785603404045, 38.855301439762115, 33.3529344946146, 14.456620663404465, 3.696050033904612, 0.4716346407076344, 0.9859903296455741, 2.1727407490834594, 6.138081857934594, 11.908419448882341, 14.410912916064262, 14.068471491336823, 10.096926502883434, 6.865782709792256, 8.515449464321136, 13.28919030725956, 19.095753729343414, 38.3903431892395, 45.99854953587055, 54.96620133519173, 55.052920281887054, 51.638822481036186, 51.882605999708176, 50.19064798951149, 49.18562851846218, 50.74867084622383, 48.91217619180679, 48.88121545314789, 49.52520489692688, 51.164596527814865, 48.15715290606022, 55.4375546425581, 51.25589802861214, 53.885520324110985, 47.98775799572468, 45.302856266498566, 39.8175960034132, 40.85635766386986, 43.52274298667908, 49.367441162467, 53.73303070664406, 52.04398334026337, 51.397885009646416, 46.3829293102026, 44.171497374773026, 38.41660737991333, 38.21379326283932, 40.569754242897034, 40.925050377845764, 43.069328516721725, 50.89034244418144, 52.46698044240475, 54.06460091471672, 51.50595501065254, 46.687995940446854, 54.005726873874664, 50.886288061738014, 48.093684911727905, 41.65112301707268, 44.517514407634735, 48.386637791991234, 53.94652985036373, 50.31739018857479, 53.19106198847294, 51.675444915890694, 52.935191318392754, 50.05452409386635, 54.87679973244667, 52.9772512614727, 54.1168063133955, 51.374250277876854, 52.07232981920242, 51.50575362145901, 54.52844202518463, 54.34503726661205, 54.51514273881912, 46.65890850126743, 51.30236953496933, 54.11627434194088, 55.00910863280296, 55.507702678442, 59.807544350624084, 55.70658020675182, 56.225020587444305, 55.41055329144001, 58.789643570780754, 59.81120355427265, 58.467363864183426, 59.31967332959175, 55.80815635621548, 50.2384190261364, 39.17280860245228, 25.583696588873863, 15.780560821294785, 7.282326333224773, 9.79598930105567, 16.208083480596542, 17.302384860813618, 17.06706538796425, 14.466507732868195, 16.30474839359522, 8.820847626775503, 3.1127837067469954, 1.5313187800347805, 0.46629183052573353, 1.5111270197667181, 10.827808734029531, 28.4486972540617, 43.31600368022919, 51.408885419368744, 51.03469289839268, 61.035022884607315, 63.472383096814156, 49.342335909605026, 13.952621407806873, 1.1929239006713033, 0.15429181919898838, 0.15673902147682384, 0.09652366003138013, 0.3265909611945972, 0.1739481496042572, 0.1515527005540207, 0.20066325436346233, 0.08402195977396332, 0.1448104521841742, 0.1418201017077081, 0.2080660141655244, 0.09245454595657066, 0.22521814535139129, 0.13162147864932194, 0.16943546128459275, 0.0986232997092884, 0.08949635273893364, 0.1035556651186198, 0.14834127912763506, 0.15352568530943245, 0.06921618041815236, 0.11770205368520692, 0.1451118680415675, 0.19679602672113106, 0.09470971752307378], [0.028031865840603132, 0.03962695293012075, 0.10560296112089418, 0.027036632818635553, 0.025849801386357285, 0.02729001316765789, 0.02301923344930401, 0.02328766269783955, 0.04097401033504866, 0.023924833585624583, 0.023454144975403324, 0.02341773892112542, 0.030851175397401676, 0.006273154913287726, 0.031250209649442695, 0.05756312231824268, 0.0760100748448167, 0.03970636644226033, 0.011982285941485316, 0.036943788509233855, 0.040904645502450876, 0.05577128096774686, 0.015853825461817905, 0.040981702695717104, 0.020178206796117593, 0.03269112276029773, 0.07159821470850147, 0.06423056591302156, 0.057506314624333754, 1.1918618576601148, 15.949446558952332, 39.00042325258255, 45.112410485744476, 38.636547178030014, 28.230239376425743, 24.474129527807236, 33.585626408457756, 28.912661857903004, 16.93111438304186, 4.214369058609009, 0.6805111246649176, 0.1549752926803194, 0.40497840964235365, 2.018995061516762, 2.308948952704668, 7.1335087437182665, 4.222983196377754, 5.701054008677602, 7.156639052554965, 3.988929530605674, 11.662041619420052, 19.564302787184715, 31.08823511749506, 44.31085869669914, 49.78043720126152, 50.97230784595013, 50.36204159259796, 50.38236290216446, 49.9629832059145, 50.51897317171097, 49.26120266318321, 49.14169907569885, 49.603328704833984, 48.567618280649185, 48.67932848632336, 47.81870886683464, 49.918381199240685, 52.581947073340416, 49.31345745921135, 48.34452845156193, 42.96421475708485, 38.29806514084339, 37.35434778034687, 36.351175010204315, 37.661394104361534, 38.89340199530125, 39.50613051652908, 37.22277224063873, 36.344031393527985, 36.32374048233032, 35.53744487464428, 36.77721194922924, 36.2897627055645, 39.45710174739361, 38.456281051039696, 44.671721532940865, 45.660956650972366, 49.53756183385849, 44.173914045095444, 39.59942311048508, 51.01581931114197, 46.2825994938612, 45.91766707599163, 37.7852750569582, 42.31709808111191, 45.99973127245903, 50.717725306749344, 50.57895675301552, 52.55928888916969, 51.328614726662636, 49.48631778359413, 47.51887835562229, 51.64059318602085, 50.62914825975895, 49.96127709746361, 46.71600803732872, 46.566182076931, 47.06085093319416, 47.10021302103996, 48.03993299603462, 51.48305743932724, 48.71378503739834, 44.862752482295036, 45.57276338338852, 48.8961448520422, 50.22700823843479, 51.93696968257427, 52.185875326395035, 54.04250890016556, 53.39102625846863, 54.12135846912861, 53.01244877278805, 54.909964352846146, 56.29565879702568, 50.81332057714462, 43.62762875854969, 30.505359694361687, 17.365271486341953, 10.316903349012136, 3.0503696808591485, 3.0771772423759103, 6.903404016047716, 9.665116723626852, 5.548383900895715, 4.770108237862587, 5.3870839811861515, 2.9149653716012836, 1.3968398398719728, 0.23244411073392257, 0.173055034247227, 1.4285842864774168, 10.132834576070309, 16.278653293848038, 43.5336522012949, 35.19920602440834, 39.999849423766136, 46.82048723101616, 50.437368750572205, 29.520268253982067, 6.102114412933588, 0.3903049626387656, 0.04031222240882926, 0.03928524958610069, 0.00742009451641934, 0.02278306164953392, 0.07176061888458207, 0.061357842132565565, 0.04927562600641977, 0.00948757693549851, 0.048565628167125396, 0.04318475694162771, 0.07421085654641502, 0.01343037654805812, 0.009488746745773824, 0.013570446717494633, 0.027066606307926122, 0.029213092202553526, 0.032954967391560785, 0.05312683068041224, 0.01330914023128571, 0.07227253750897944, 0.059388649751781486, 0.09933912340784445, 0.007718395672782208, 0.09976987334084697, 0.06407170920283534, 0.007685575119467103, 0.05917330076044891, 0.013117618818796473, 0.023002084271865897, 0.025386751331097912, 0.02366539731156081, 0.0582329625467537, 0.06549433208419941, 0.049254459954681806, 0.030721692892257124, 0.027877209686266724, 0.04290247736207675, 0.02130704866431188, 0.07891502638813108, 0.07435514489770867, 0.07791687487042509, 0.052441872903727926, 0.02679537359654205, 0.01948156761500286, 0.02384239953244105, 0.042760114884004, 0.03831157038803212, 0.04259045250364579, 0.025287010394094978, 0.026361514064774383, 0.09023910155519843, 0.05367076555558015, 0.05625743593554944, 0.037646828714059666, 1.9397328584454954, 18.48788134753704, 44.827019199728966, 52.1889341622591, 44.264580979943275, 34.80676308274269, 25.95971491187811, 36.79256692528725, 32.24732682108879, 15.853083729743958, 4.620764376595616, 0.4920662037329748, 0.17539419466629624, 0.7940703467465937, 2.115097129717469, 4.138733642175794, 6.303442334756255, 6.683742552995682, 6.6989692859351635, 5.836559487506747, 6.634453972801566, 13.697984721511602, 21.12118374556303, 32.76178881525993, 45.718177780508995, 52.62388542294502, 52.990459352731705, 53.03063079714775, 53.258090391755104, 51.477042362093925, 51.77489697933197, 49.6195500344038, 50.444185584783554, 48.68787042796612, 49.25478860735893, 48.99952590465546, 47.56379194557667, 50.91752998530865, 54.59527283906937, 51.02539099752903, 50.8355113863945, 44.00209106504917, 40.72206147015095, 39.06851179897785, 37.88108691573143, 40.559901371598244, 39.99248541891575, 42.1004793047905, 40.15926606953144, 39.076882749795914, 38.143611028790474, 38.255150243639946, 38.23402717709541, 36.95998974144459, 41.13427475094795, 40.5614060908556, 46.61037750542164, 47.521933391690254, 51.426379680633545, 47.07822360098362, 41.467570066452026, 54.19117972254753, 50.310474559664726, 46.60181276500225, 39.72908355295658, 43.58284056186676, 48.33502896130085, 51.98760576546192, 52.97568194568157, 54.15332995355129, 52.7678406983614, 50.54469779133797, 50.096386447548866, 53.44914793968201, 52.621673941612244, 51.812332570552826, 49.82222355902195, 49.065991938114166, 49.036577716469765, 49.495437294244766, 50.754256546497345, 53.54967914521694, 48.45359019935131, 46.9917668402195, 47.568078115582466, 50.24723835289478, 52.71072216331959, 52.556606233119965, 52.608496248722076, 54.23699006438255, 54.010161235928535, 54.559778943657875, 53.71936284005642, 54.87590678036213, 58.331274166703224, 53.05546626448631, 44.48529213666916, 31.57984133809805, 19.860456995666027, 12.586683053523302, 5.498709641396999, 9.870908930897713, 11.416116915643215, 10.26313528418541, 7.8799435403198, 8.639346566051245, 8.039896432310343, 2.651696498505771, 0.8947404229547828, 0.12620630906894803, 0.03229549496609252, 1.4937918749637902, 10.74551085010171, 21.42313454300165, 45.727783665061, 37.92158514261246, 44.42859537899494, 52.92881526052952, 57.08018749952316, 34.77853439748287, 7.656432408839464, 0.4807773360516876, 0.0316267382731894, 0.05249907393590547, 0.013615726074931445, 0.020671991042036097, 0.014683042973047122, 0.03143534580885898, 0.026626983999449294, 0.01540040755571681, 0.03898350718372967, 0.05581061479460914, 0.010216980081168003, 0.06157568845083006, 0.017387742664141115, 0.03380662637937348, 0.056699741107877344, 0.0502235304156784, 0.024439227272523567, 0.028993410924158525, 0.015176188971963711, 0.005672193874488585, 0.034358806515228935, 0.051750744169112295, 0.019939248231821693, 0.06783588221878745, 0.05830697693454567, 0.14168198802508414, 0.13276113546453416, 0.15829082258278504, 0.12745148444082588, 0.12343820213573053, 0.10405476685264148, 0.20117903215577826, 0.15481118898605928, 0.07442180460202508, 0.14298653521109372, 0.10778889773064293, 0.15078033262398094, 0.10277731547830626, 0.20935310603817925, 0.10731355956522748, 0.23424948885804042, 0.19117422838462517, 0.12840967130614445, 0.22955540480324998, 0.11433521911385469, 0.21145252307178453, 0.12273255328182131, 0.1140359257988166, 0.1319775462616235, 0.07070019375532866, 0.20661582791944966, 0.1466513198101893, 0.1798268497805111, 0.1820792382932268, 2.2850406356155872, 20.861805863678455, 50.06017819046974, 60.05802311003208, 51.49867840111256, 40.65474808216095, 34.67733062803745, 45.54819770157337, 38.61045017838478, 21.493953242897987, 5.810363218188286, 0.869879781967029, 0.4956293437862769, 2.36947875469923, 8.959334995597601, 8.582189083099365, 18.014637641608715, 14.213258922100067, 10.95821963623166, 13.424085918813944, 7.943314164876938, 15.10350365191698, 24.929043017327785, 34.510348588228226, 46.6812627017498, 53.312818855047226, 52.0841433852911, 53.85134495794773, 53.96940842270851, 52.913574278354645, 53.310022205114365, 51.347583308815956, 50.85773639380932, 50.55365391075611, 49.29330714046955, 50.01078464090824, 48.05733606219292, 51.916503980755806, 56.89024709165096, 52.73581601679325, 54.56475667655468, 46.16470701992512, 42.2816763818264, 41.6409357637167, 39.659380093216896, 41.8106422573328, 40.728722512722015, 43.04209917783737, 40.284845530986786, 39.91920255124569, 40.23336589336395, 39.90338400006294, 39.543288722634315, 38.05691868066788, 43.94092954695225, 43.06349202990532, 49.17950324714184, 50.70754945278168, 54.156555980443954, 49.30575527250767, 46.10416106879711, 55.40893077850342, 52.16748811304569, 50.499229431152344, 41.904003247618675, 44.348856657743454, 50.010864436626434, 53.17163743078709, 56.04769930243492, 57.41868853569031, 55.06785348057747, 53.54583755135536, 52.44730889797211, 55.527214631438255, 54.852218851447105, 54.9186696857214, 50.32398663461208, 50.47474354505539, 52.063267305493355, 52.21287287771702, 52.85474203526974, 54.47932966053486, 51.49980314075947, 47.35609509050846, 48.66983659565449, 50.0209528952837, 52.38588899374008, 53.9809750020504, 53.72787818312645, 55.96011780202389, 55.35689257085323, 56.24154970049858, 53.492116034030914, 55.86560547351837, 57.24653497338295, 54.124611094594, 46.49881549179554, 34.188281670212746, 21.49853579699993, 13.82124250754714, 6.480462485924363, 13.02818326279521, 15.29659029096365, 20.575206242501736, 14.974161442369223, 13.536622580140829, 10.899633429944515, 9.616517331451178, 5.27995252981782, 0.3413910779636353, 0.5156876659020782, 2.2039574990049005, 12.358975522220135, 25.70444840937853, 55.34196697175503, 45.86283981800079, 51.51236146688461, 62.88097903132439, 64.88689139485359, 39.08436454832554, 10.052485037595034, 0.7273867749609053, 0.1235140793141909, 0.1210200326750055, 0.1463648656499572, 0.09710473197628744, 0.10673340788343921, 0.19175555265974253, 0.13059219403658062, 0.18624474992975593, 0.1802521152421832, 0.15276493941200897, 0.13288563815876842, 0.11698256377712823, 0.10884402392548509, 0.06819862173870206, 0.13010451395530254, 0.13489228673279285, 0.06883869442390278, 0.14020492119016126, 0.09188405703753233, 0.1756081113126129, 0.13072456349618733, 0.1873952866299078, 0.1205154464696534, 0.20022638171212748, 0.16362343565560877], [0.14345745759783313, 0.05462226195959374, 0.039835481584304944, 0.011079965170210926, 0.040020198430283926, 0.05204326909733936, 0.1083999672846403, 0.03166483642417006, 0.036643938583438285, 0.01967464846529765, 0.04884825655608438, 0.04219128837576136, 0.033677581741358154, 0.06107503562816419, 0.07398145869956352, 0.017602223342692014, 0.04060825769556686, 0.01963678965694271, 0.07178228217526339, 0.019202392068109475, 0.03411871432035696, 0.02988960619404679, 0.03870006985380314, 0.0323239823046606, 0.025697447745187674, 0.05659771806676872, 0.03187327973137144, 0.07850658541428857, 0.033281037394772284, 0.5070860555861145, 6.905801212415099, 29.654003977775574, 44.781664833426476, 42.15813361108303, 35.39716400206089, 30.120143964886665, 32.883557081222534, 36.26360110938549, 19.937638454139233, 7.197399940341711, 1.447396008297801, 0.2865740022389218, 0.4642072267597541, 1.04896993143484, 3.6335775861516595, 4.162212582305074, 4.84282398596406, 6.787604754790664, 3.160255034454167, 4.783273581415415, 5.976661769673228, 16.920151971280575, 27.50834461301565, 38.67262244224548, 49.302742034196854, 53.95367346704006, 54.10442657768726, 51.43734589219093, 51.662411615252495, 52.964039370417595, 49.01843748986721, 51.06690376996994, 49.81606028974056, 45.28190039098263, 48.397888988256454, 48.38718496263027, 51.90651051700115, 51.54406696557999, 49.4401578605175, 47.26538635790348, 44.068021327257156, 40.24921864271164, 37.904801443219185, 40.043041706085205, 35.94841942191124, 35.608976036310196, 34.238222390413284, 35.79855166375637, 35.38179002702236, 37.75198884308338, 40.41720762848854, 40.68019151687622, 42.38288015127182, 44.110244661569595, 44.95337761938572, 48.41168224811554, 45.88194899260998, 52.12439462542534, 45.746227875351906, 38.20887632668018, 52.546289786696434, 47.030156180262566, 44.74824942648411, 36.63154296576977, 41.67606867849827, 44.45032261312008, 48.475838005542755, 50.74343092739582, 52.28255733847618, 50.72781376540661, 50.775873586535454, 52.33682222664356, 50.941160917282104, 50.51285929977894, 49.029768481850624, 44.67821538448334, 43.22836518287659, 43.89412745833397, 45.572466999292374, 48.24925996363163, 49.70560021698475, 50.48185296356678, 48.70115451514721, 51.60086631774902, 51.70624226331711, 53.71496647596359, 52.03392148017883, 51.22064732015133, 50.39343170821667, 49.14931766688824, 51.075054332613945, 53.666355684399605, 55.831616297364235, 52.330658957362175, 52.38778509199619, 42.917306274175644, 29.325198121368885, 13.973716925829649, 8.251762613654137, 7.8226943872869015, 5.645092986524105, 6.6256175469607115, 11.012556720525026, 4.1072870045900345, 6.200218023732305, 5.702902609482408, 1.830390163231641, 0.6859818811062723, 0.35748122551012784, 0.24243389343610033, 2.6030113734304905, 10.047686845064163, 28.368103578686714, 43.65433372557163, 40.053202360868454, 37.20958314836025, 45.45957125723362, 47.55507901310921, 25.703131780028343, 6.631877711042762, 0.21766233985545114, 0.14922857604688033, 0.035987134178867564, 0.04196888898150064, 0.04310371070459951, 0.05653876556607429, 0.058306450009695254, 0.07106829158146866, 0.06494619665318169, 0.012704336259048432, 0.0970056775258854, 0.054358907145797275, 0.05390832702687476, 0.05574815935688093, 0.04963128543749917, 0.0639093792415224, 0.0773338956059888, 0.022786800218455028, 0.06470851643825881, 0.06167188192193862, 0.034749487895169295, 0.030431515006057452, 0.05732857396651525, 0.025507867976557463, 0.05733884157962166, 0.0698096833366435, 0.08979559410363436, 0.018270518048666418, 0.007116907245290349, 0.03245787687774282, 0.01341103989034309, 0.018678717824514024, 0.05471980242873542, 0.015495409879804356, 0.08108778245514259, 0.015458534417120973, 0.07227859343402088, 0.034525192313594744, 0.05862866455572657, 0.038464063181891106, 0.021254935054457746, 0.04213901520415675, 0.020026365236844867, 0.04717048701422755, 0.04456889575521927, 0.03794459691562224, 0.06707253880449571, 0.0649881131539587, 0.04488930317165796, 0.01723884928651387, 0.04901113199593965, 0.042527017430984415, 0.08807675782009028, 0.04019437306851614, 0.05487903763423674, 0.6605272844899446, 10.94593869522214, 35.41691154241562, 51.59178100526333, 48.26832354068756, 38.115948513150215, 34.77403163909912, 38.27493578195572, 37.48138636350632, 22.219507209956646, 7.720384877175093, 1.49901885073632, 0.05048743441875558, 0.3601906285621226, 1.9597574276849627, 2.269162475131452, 5.954512758180499, 6.4917198568582535, 9.12192827090621, 5.062348656356335, 6.708058398216963, 8.859770838171244, 18.446474969387054, 29.882525615394115, 42.10557863116264, 49.67439629137516, 54.93128500878811, 54.939754754304886, 53.281964510679245, 54.69444751739502, 54.86552953720093, 50.592837408185005, 50.85552491247654, 49.197122901678085, 49.02851454913616, 48.29747557640076, 49.53724645078182, 50.62851369380951, 55.08249029517174, 52.13400810956955, 49.65986967086792, 45.963462218642235, 41.53122425079346, 39.26545903086662, 39.899663999676704, 37.50065512955189, 37.856103256344795, 35.79087607562542, 38.06247778236866, 38.35075691342354, 38.72146122157574, 41.63074471056461, 41.42667666077614, 43.92090082168579, 44.599115028977394, 45.518779680132866, 50.10109439492226, 48.53360630571842, 53.19224372506142, 48.984835892915726, 40.79212971031666, 53.588828444480896, 49.25363726913929, 45.43773762881756, 39.100893661379814, 42.52241626381874, 47.59713515639305, 50.92394784092903, 53.386702090501785, 53.10567297041416, 52.75027044117451, 52.311048209667206, 54.1507612913847, 54.20332387089729, 52.5896492600441, 49.630573242902756, 48.275778740644455, 46.18146792054176, 45.36895751953125, 49.21852335333824, 51.12607799470425, 51.82247422635555, 51.73048876225948, 48.5402787476778, 53.1226010620594, 52.359453812241554, 55.1273924857378, 54.514492973685265, 52.9165381193161, 53.458803221583366, 52.7747867256403, 53.32896798849106, 53.57153557240963, 55.64831033349037, 54.912004843354225, 51.68259613215923, 44.56758812069893, 30.993012227118015, 16.5753223747015, 9.685440883040428, 7.741134138777852, 9.075845293700695, 9.357168897986412, 9.553296323865652, 7.58784418925643, 8.008600361645222, 5.554659264162183, 2.9508430464193225, 0.6939849641639739, 0.04725233477074653, 0.12289365127799101, 2.806225181557238, 12.596948202699423, 26.158303655683994, 48.232681453228, 43.28052118420601, 39.44391645491123, 53.798713982105255, 51.5689480304718, 30.21078050136566, 8.466465342789888, 0.24281041463837028, 0.08637733611976728, 0.04608649127476383, 0.0290956213575555, 0.02850148575817002, 0.046423964377027005, 0.09448418626561761, 0.05173904421098996, 0.062277633987832814, 0.01698225172731327, 0.024007612737477757, 0.017811872639867943, 0.03828770662948955, 0.022245420186663978, 0.06634112258325331, 0.06409238543710671, 0.03974789702624548, 0.05689306686690543, 0.029260728806548286, 0.06232497558812611, 0.061279048313735984, 0.0346290002198657, 0.10674025790649466, 0.040844568648026325, 0.06069883726013359, 0.02664800162165193, 0.2624444360844791, 0.11146589065901935, 0.23081711522536352, 0.11805129353888333, 0.06206891608599108, 0.11061404613428749, 0.1260398601880297, 0.12777146883308887, 0.14991972333518788, 0.08847555087413639, 0.18856690032407641, 0.15003827400505543, 0.18242942809592932, 0.14279783674282953, 0.13169723708415404, 0.14639732718933374, 0.15886197943473235, 0.14618259418057278, 0.17112387693487108, 0.07259571313625202, 0.1885900998604484, 0.19191624247469008, 0.16216729738516733, 0.10829123522853479, 0.1737188853439875, 0.22314997273497283, 0.17769031052011997, 0.2293230383656919, 0.13662809593370184, 0.8461401402018964, 11.834278777241707, 40.04675790667534, 58.87128598988056, 55.32006874680519, 45.49400880932808, 40.24110607802868, 45.72356969118118, 45.64592085778713, 25.3048200532794, 9.56428723409772, 2.4412352917715907, 0.5516804626677185, 0.8071769122034311, 3.1957342056557536, 10.548825804144144, 11.016124729067087, 15.816137362271547, 17.954551465809345, 10.016377475112677, 9.149033166468143, 9.78051083162427, 20.66776167601347, 32.912834510207176, 42.81753122806549, 52.63017788529396, 57.35499255359173, 56.702632158994675, 53.65881308913231, 54.68634255230427, 55.36152832210064, 51.67361341416836, 51.93545736372471, 51.35987564921379, 49.38059225678444, 48.88416409492493, 51.01600930094719, 52.69250974059105, 55.54379694163799, 54.77080821990967, 52.20371536910534, 47.7395249158144, 43.318291157484055, 42.19209998846054, 43.14625918865204, 39.13433566689491, 39.360602125525475, 38.399709686636925, 39.562086313962936, 39.50345925986767, 41.31411910057068, 45.57359553873539, 43.95509518682957, 46.597914174199104, 46.8955560028553, 49.10282716155052, 52.26766213774681, 50.79468257725239, 54.61473919451237, 50.397527888417244, 44.52064923942089, 56.10251896083355, 51.366962268948555, 47.33259715139866, 40.62929704785347, 44.94073949754238, 50.12450493872166, 52.284027859568596, 53.78623925149441, 54.37597140669823, 55.23298501968384, 53.53727661073208, 56.287352442741394, 54.88207004964352, 54.48719143867493, 53.40568587183952, 50.067067220807076, 47.8191876411438, 48.03852707147598, 50.74181221425533, 52.11174130439758, 53.23195159435272, 52.172686234116554, 48.35718557238579, 51.2628972530365, 54.02489684522152, 56.935156881809235, 56.04679875075817, 53.7867484241724, 55.20128332078457, 53.734117448329926, 54.94556084275246, 54.927261024713516, 57.04964853823185, 54.10507254302502, 50.23284092545509, 45.43875977396965, 32.08349861204624, 16.896614134311676, 13.191045373678207, 15.357857253402472, 11.259061843156815, 14.117425214499235, 20.11743150651455, 9.732551705092192, 17.79060546308756, 16.347596794366837, 6.905809761956334, 2.3581684241071343, 0.8479017019271851, 0.5887946742586792, 3.806840688921511, 14.006759002804756, 36.625486090779305, 56.06368884444237, 51.34281076490879, 49.97801139950752, 58.35107870399952, 61.28341555595398, 33.752859234809875, 10.178805459290743, 0.5096839880570769, 0.17688150313915685, 0.22860210126964375, 0.12530347157735378, 0.1533676969120279, 0.09957868125638925, 0.2901157090673223, 0.20417726424057037, 0.20758140657562762, 0.0934868362674024, 0.18809557717759162, 0.12044210743624717, 0.14378038089489564, 0.14009379199706018, 0.24840692058205605, 0.17868382361484692, 0.1638391482993029, 0.1435697148554027, 0.20797706034500152, 0.13628691580379382, 0.10666175352525897, 0.09646447375416756, 0.13595260796137154, 0.13041075377259403, 0.14352876314660534, 0.21123344107763842], [0.05988061944663059, 0.005590307155216578, 0.024721059708099347, 0.06485589212388732, 0.04900582935079001, 0.026792659191414714, 0.044463254744187, 0.031537572940578684, 0.011347835024935193, 0.01827173702622531, 0.01749242073856294, 0.03322291238873731, 0.023240137415996287, 0.06530216778628528, 0.044880946588818915, 0.016812437206681352, 0.06652111565927044, 0.04361952560429927, 0.03488367932732217, 0.0614601509005297, 0.057997386320494115, 0.02943229479569709, 0.02921702001913218, 0.059581660098046996, 0.046086899455985986, 0.029012038830842357, 0.04624593428161461, 0.026343581921537407, 0.061560010581160896, 0.09947458762326278, 4.260506657883525, 20.292706601321697, 44.30362768471241, 43.148964643478394, 32.14884750545025, 23.739254660904408, 26.275605261325836, 32.399102076888084, 24.79596085846424, 10.769268125295639, 2.356575597077608, 0.28501184075139463, 0.28412806161213666, 1.7644519452005625, 1.5994234755635262, 3.5338139394298196, 3.0431930534541607, 4.650314440950751, 4.1293376963585615, 5.1587889064103365, 8.722997177392244, 13.098447192460299, 26.738061346113682, 38.473353534936905, 45.85796847939491, 52.216558679938316, 53.197457045316696, 53.67280013859272, 52.162217795848846, 52.182873487472534, 50.665588304400444, 49.436266869306564, 50.92531196773052, 50.777537897229195, 49.808901473879814, 50.39429806172848, 49.853020906448364, 52.23167806863785, 49.898246079683304, 49.076494574546814, 44.504393711686134, 39.92473125457764, 38.813180699944496, 39.59949150681496, 36.16860240697861, 37.8603932261467, 36.774335503578186, 36.57807603478432, 38.65070141851902, 45.58204248547554, 48.664304092526436, 51.71169497072697, 49.26629438996315, 49.70600679516792, 48.11778321862221, 47.41329722106457, 46.18742220103741, 51.77691467106342, 42.141133323311806, 36.16952195763588, 52.238912880420685, 48.12384769320488, 43.675217404961586, 37.8590252995491, 40.3297933191061, 41.99590511620045, 45.10828770697117, 47.77047425508499, 51.09811909496784, 52.634760439395905, 52.87645787000656, 51.43236815929413, 49.42601881921291, 48.32993723452091, 45.66466145217419, 42.412579357624054, 40.39025567471981, 40.326536893844604, 43.7223044782877, 46.427550315856934, 50.41754141449928, 51.676577255129814, 48.4688463807106, 49.895837008953094, 51.793671771883965, 50.834785625338554, 47.907217517495155, 48.70720759034157, 48.01169291138649, 52.17524729669094, 49.762973338365555, 48.90880197286606, 55.40724366903305, 59.42705936729908, 50.13476058840752, 40.53073413670063, 22.824068069458008, 15.047332216054201, 7.777245976030827, 4.829653417691588, 11.989210713654757, 10.853392761200666, 5.325320670381188, 9.49927082285285, 6.156665710732341, 5.260372180491686, 1.2566086021251976, 0.6648501462768763, 0.11968340986641124, 0.3736288449726999, 3.1378597486764193, 17.07600060850382, 21.754094883799553, 42.02890634536743, 42.72637411952019, 35.88864102959633, 44.60288442671299, 39.400211200118065, 19.09302167594433, 2.533851759508252, 0.05772047246864531, 0.008005482050066348, 0.03275101407780312, 0.11213016477995552, 0.04828341167012695, 0.03020205407665344, 0.033725160828907974, 0.04397116630570963, 0.01104476788896136, 0.08317337327753194, 0.1298723998479545, 0.08305047362227924, 0.05656749781337567, 0.05920253766817041, 0.019442063094174955, 0.03472973192401696, 0.017333987052552402, 0.06565626128576696, 0.04239330839482136, 0.0028492981209637946, 0.0293689506361261, 0.07265347448992543, 0.052827147737843916, 0.032788878452265635, 0.023456174749298953, 0.05480303800140973, 0.058090087986784056, 0.030188417113095056, 0.05547511209442746, 0.04604466383170802, 0.04253089144185651, 0.02320179992238991, 0.033635294166742824, 0.06345039801090024, 0.026173049373028334, 0.026807108806679025, 0.022763031083741225, 0.028752630387316458, 0.08820937960990705, 0.0466422968020197, 0.045058635296300054, 0.021129684646439273, 0.03775263670831919, 0.03763609354791697, 0.02509695008484414, 0.0179516450225492, 0.05802240040793549, 0.029501474091375712, 0.06803163108997978, 0.06335277590551414, 0.024882061225071084, 0.04791065315657761, 0.035419224223005585, 0.019239317625761032, 0.12898443499580026, 0.33249970350880176, 5.4009290132671595, 24.920803159475327, 50.659406036138535, 48.28968599438667, 38.587343618273735, 29.501273073256016, 34.38756577670574, 33.9971861243248, 25.6581611931324, 11.388733685016632, 2.1271712193265557, 0.311405046377331, 0.39847876934800297, 1.1030401987954974, 2.795278918929398, 4.947313629090786, 5.444841831922531, 6.9499405939131975, 4.442894970998168, 4.719550525769591, 7.622180096805096, 17.4939401820302, 27.80506119132042, 41.79269202053547, 48.25501665472984, 55.479587987065315, 55.75163818895817, 55.56865140795708, 53.40314760804176, 54.16421256959438, 51.9046638160944, 51.97341352701187, 51.52748845517635, 49.61185164749622, 49.71362918615341, 49.57598157227039, 51.226954981684685, 53.11981961131096, 50.888415947556496, 51.200269013643265, 46.52223743498325, 41.756388768553734, 39.02042157948017, 42.341158390045166, 37.809548154473305, 39.615397453308105, 38.521143570542336, 37.651902213692665, 40.16948752105236, 46.52869328856468, 49.17096510529518, 54.32480715215206, 49.96542647480965, 52.02216491103172, 49.97260048985481, 49.76702392101288, 48.04719440639019, 53.3828566968441, 44.64161574840546, 38.995316326618195, 54.05047707259655, 49.26720254123211, 45.600121915340424, 39.91420581936836, 42.81837858259678, 44.25173006951809, 47.19085715711117, 49.43793497979641, 52.608040273189545, 53.033070266246796, 52.10837088525295, 52.917089089751244, 50.345090702176094, 50.232730731368065, 48.68367165327072, 45.13517126441002, 42.61431433260441, 42.34522797167301, 47.05109305679798, 48.65701608359814, 53.49179305136204, 53.155480697751045, 49.49207067489624, 50.00619828701019, 53.36905583739281, 54.7211866825819, 49.550830721855164, 49.66927036643028, 49.61059011518955, 53.20409528911114, 51.76687180995941, 52.44963437318802, 56.035954132676125, 59.1957201808691, 50.199091136455536, 42.81083218753338, 24.24829624593258, 16.575671955943108, 8.380801789462566, 6.24414699152112, 7.017720881849527, 9.225613307207823, 9.159356262534857, 7.761474447324872, 6.456063995137811, 5.471260389313102, 2.3032015236094594, 0.7973862031940371, 0.19364820735063404, 0.3825311438413337, 3.774799145758152, 18.63421529531479, 28.15149810165167, 45.76848708093166, 49.01355095207691, 39.71062034368515, 51.57633863389492, 45.814905390143394, 23.166196011006832, 3.752497429959476, 0.05934025059104897, 0.015578440434182994, 0.021954379553790204, 0.08796756563242525, 0.016846900689415634, 0.04182561737252399, 0.07535116645158269, 0.03445432463195175, 0.028827700480178464, 0.009770486412890023, 0.09949903396773152, 0.025043012647074647, 0.03330683444801252, 0.06298692678683437, 0.06296334875514731, 0.018069687321258243, 0.012024856459902367, 0.07843253391911276, 0.04297027255233843, 0.0536595554149244, 0.029681815976800863, 0.05125863717694301, 0.011335582166793756, 0.06432595415390097, 0.012860617716796696, 0.04916687168588396, 0.18981099216034636, 0.10352852477808483, 0.11178611996001564, 0.14181581209413707, 0.21839825349161401, 0.10328606513212435, 0.107375989027787, 0.1880264832288958, 0.09773540165042505, 0.10611683159368113, 0.10248840480926447, 0.12509014864917845, 0.16989281721180305, 0.19776792847551405, 0.1761020254343748, 0.12225221304106526, 0.18296432361239567, 0.1288401911733672, 0.1651830886839889, 0.12720273138256744, 0.1521326889633201, 0.22755907208193094, 0.175539878255222, 0.20143997127888724, 0.1776457074447535, 0.1266602214309387, 0.1317070928052999, 0.11243686472880654, 0.2094426387338899, 0.657803543144837, 7.122011035680771, 29.09524206072092, 57.50248923897743, 56.203145161271095, 45.72834223508835, 35.24723544716835, 37.49942019581795, 41.981598883867264, 33.67609955370426, 14.085177294909954, 3.267758865840733, 0.6933706440031528, 1.5445638005621731, 5.232001952826977, 4.129499187693, 13.119875192642212, 10.181395020335913, 12.379674911499023, 9.94050219655037, 9.929774422198534, 12.474459875375032, 19.994280114769936, 30.977068282663822, 43.28593969345093, 49.1525436937809, 55.84843419492245, 57.664098367094994, 58.4054271876812, 55.614552944898605, 56.990158930420876, 53.64770628511906, 52.67070271074772, 53.32560516893864, 50.38089998066425, 50.183055996894836, 50.9148283302784, 52.39659681916237, 54.91903826594353, 53.32792304456234, 54.08796966075897, 48.85736793279648, 42.65334203839302, 39.5902656018734, 42.23851449787617, 38.933619037270546, 42.00573518872261, 41.30742006003857, 38.76574024558067, 43.03130775690079, 49.16827864944935, 51.850611716508865, 56.54710650444031, 53.599186688661575, 55.30947871506214, 52.919980734586716, 51.92410737276077, 50.09213447570801, 55.35485588014126, 45.47497943043709, 42.9876708984375, 55.2949482947588, 51.678275763988495, 46.61084108054638, 42.921045273542404, 45.58859333395958, 46.067831218242645, 47.94200465083122, 51.941723227500916, 53.82557854056358, 55.69413587450981, 54.25414614379406, 54.922887459397316, 52.75340147316456, 51.46350748836994, 50.573431849479675, 47.00816676020622, 44.3221440911293, 45.74466995894909, 48.795796036720276, 51.09818369150162, 55.12701630592346, 54.75812450051308, 49.117304384708405, 51.36414282023907, 54.26622949540615, 56.10149681568146, 51.51714541018009, 52.87364222109318, 51.27199396491051, 54.66924346983433, 54.53926384449005, 54.09635201096535, 57.27617338299751, 62.05895774066448, 53.07719349861145, 43.992154598236084, 26.871992759406567, 19.183221235871315, 12.087453491985798, 9.040698129683733, 20.45278251171112, 18.482730723917484, 13.233260158449411, 17.684517055749893, 14.869532156735659, 12.509563341736794, 5.888128420338035, 2.1154609601944685, 0.5657071131281555, 0.578162963502109, 5.007472475990653, 22.469556592404842, 28.90786461532116, 54.380489364266396, 51.596245765686035, 47.813104167580605, 58.25522504746914, 50.86055584251881, 26.845200397074223, 4.5049703400582075, 0.1273778040194884, 0.16441383777419105, 0.06576059982762672, 0.3026615967974067, 0.24982201808597893, 0.11689471575664356, 0.1740115141728893, 0.12254771398147568, 0.12732793169561774, 0.19857379695167765, 0.33632304053753614, 0.141587512625847, 0.22231775801628828, 0.14031437312951311, 0.17330945731373504, 0.1230417171609588, 0.10618337997584604, 0.17948975146282464, 0.16645398689433932, 0.11538963284692727, 0.1840046959114261, 0.1743374951183796, 0.202121069887653, 0.11955052832490765, 0.11961344018345699, 0.1597910889540799], [0.03207818299415521, 0.01915004653710639, 0.010230343377770623, 0.02044348933850415, 0.03654493237263523, 0.018562972472864203, 0.0387406022491632, 0.043347936662030406, 0.013333858387341024, 0.020565466875268612, 0.033483413644717075, 0.028190212324261665, 0.042740856151795015, 0.03234592018998228, 0.04081831517396495, 0.023138663564168382, 0.0324692354479339, 0.04596723556460347, 0.07623714234796353, 0.04037160906591453, 0.08430871079326607, 0.026832009716599714, 0.048860520546440966, 0.035387471434660256, 0.060156824547448196, 0.02593604822322959, 0.02051837946055457, 0.03599603624024894, 0.04149456013692543, 0.06259047891944647, 2.996399039402604, 12.815817408263683, 38.3381187915802, 46.72486916184425, 38.87201674282551, 29.16985485702753, 22.041486762464046, 41.945276632905006, 32.02277787029743, 16.873406879603863, 4.441388351842761, 0.3822213120292872, 0.10823556673130952, 0.9723366529215127, 2.0877357479184866, 3.5820449888706207, 3.9338785596191883, 6.357283545657992, 2.2003609919920564, 2.369918106123805, 3.7057195650413632, 14.022562354803085, 24.600886926054955, 37.58069023489952, 49.65473994612694, 59.059307500720024, 54.02667514979839, 52.24292926490307, 49.82400566339493, 49.83467549085617, 48.60397472977638, 50.767514035105705, 50.89989133179188, 50.39213217794895, 49.72078800201416, 51.56763710081577, 52.27523513138294, 53.02197486162186, 52.07912765443325, 47.90856644511223, 45.85145942866802, 40.03634266555309, 37.4125150591135, 38.08502197265625, 37.04262390732765, 36.46031655371189, 35.8396502584219, 42.1112023293972, 46.86036229133606, 49.846128076314926, 50.894168838858604, 51.711831763386726, 47.87477865815163, 51.836419478058815, 49.14316959679127, 51.246721521019936, 48.05897377431393, 53.046928122639656, 44.49778966605663, 34.91426691412926, 52.357413321733475, 47.31828711926937, 46.81274704635143, 39.22890119254589, 36.30770914256573, 36.136524528265, 41.07789717614651, 42.13745132088661, 47.20915697515011, 47.69127890467644, 49.251756370067596, 48.34689952433109, 47.94143468141556, 44.25878629088402, 41.920543760061264, 39.44632552564144, 39.161941185593605, 39.559624046087265, 44.00239124894142, 46.81218847632408, 47.9027945548296, 53.65584924817085, 50.079063177108765, 51.17029242217541, 53.93902525305748, 51.44681878387928, 45.41490085422993, 43.55233579874039, 47.32879355549812, 50.50006918609142, 54.292695075273514, 53.50687824189663, 42.26825550198555, 55.08595570921898, 53.42820726335049, 39.038124829530716, 23.20369239896536, 11.935174763202667, 6.551008550450206, 3.1157109746709466, 5.200900146737695, 8.493435345590115, 8.619870711117983, 5.46301388181746, 3.575108698569238, 2.0999753661453724, 1.7962343897670507, 0.36064265586901456, 0.2127949197893031, 0.5627195234410465, 4.548560651019216, 19.35379598289728, 22.041577957570553, 31.260059997439384, 40.89996412396431, 44.564411491155624, 44.72952403128147, 35.932361483573914, 14.673715364187956, 1.9560767314396799, 0.03177077800501138, 0.03756224614335224, 0.052713432160089724, 0.00889834971530945, 0.07643184479093179, 0.061021638102829456, 0.021725825899920892, 0.047194172657327726, 0.06459288240876049, 0.008936579597502714, 0.04611797688994557, 0.036778423163923435, 0.13507715571904555, 0.013877615147066535, 0.03659050395071972, 0.08703873070771806, 0.040470377789461054, 0.06756007787771523, 0.09641722121159546, 0.028121654577262234, 0.05818297518999316, 0.05100660382595379, 0.0740367487014737, 0.12992190109798685, 0.02129195894667646, 0.03563716702046804, 0.02425258826406207, 0.024767675859038718, 0.04040314663143363, 0.07441741108777933, 0.050305430122534744, 0.06118698489444796, 0.02414359274553135, 0.022716370403941255, 0.014995439833001, 0.0226167667642585, 0.04703025821072515, 0.058588547763065435, 0.037006459169788286, 0.045729555349680595, 0.04104475927306339, 0.0554860810370883, 0.017169074417324737, 0.01619835638848599, 0.00850845408422174, 0.05347853075363673, 0.05764233545050956, 0.018044257631117944, 0.028148739256721456, 0.032389844200224616, 0.06635428828303702, 0.03793326060986146, 0.034710974141489714, 0.05072303662018385, 0.09986924691474997, 0.04171887798293028, 3.7601989042013884, 17.355460412800312, 46.077357307076454, 53.10485601425171, 42.21370942890644, 32.62930512428284, 24.90885280072689, 43.237325102090836, 35.758646205067635, 16.518181040883064, 3.6908564250916243, 0.4459945665439591, 0.20045824348926544, 1.0526923066936433, 2.674397430382669, 5.378220956772566, 6.1674856301397085, 5.447162082418799, 7.165743364021182, 5.282264230772853, 6.433228170499206, 14.59818871691823, 27.296581976115704, 41.212645545601845, 50.149929374456406, 57.79088616371155, 55.74170172214508, 54.573678597807884, 51.71963274478912, 51.84634454548359, 51.99227571487427, 50.530007779598236, 51.64599649608135, 50.55520802736282, 51.20371922850609, 51.78644455969334, 52.46161513030529, 53.438907489180565, 52.700823694467545, 50.0339861959219, 48.34611676633358, 42.08021879196167, 38.55163313448429, 38.61627146601677, 38.16677838563919, 39.13116283714771, 36.95085123181343, 42.899565026164055, 47.518718764185905, 51.93822741508484, 52.44547359645367, 53.64592798054218, 51.37735091149807, 53.376910015940666, 50.57117477059364, 52.16431148350239, 50.780984312295914, 54.21645596623421, 45.808327943086624, 39.81125794351101, 54.55675430595875, 49.80139687657356, 47.795260325074196, 40.46825408935547, 38.49589392542839, 39.500917196273804, 43.51331949234009, 45.26059113442898, 49.77332018315792, 51.41477130353451, 51.26397639513016, 49.62780699133873, 50.46824209392071, 47.07293428480625, 44.74484480917454, 40.37207365036011, 40.97523048520088, 40.45281931757927, 46.66206993162632, 48.43226954340935, 50.62034033238888, 53.64264875650406, 49.35344271361828, 53.048573434352875, 54.804531410336494, 53.46079811453819, 48.41388612985611, 46.501159965991974, 49.21117454767227, 54.3554563075304, 57.85829834640026, 54.113295301795006, 48.44225160777569, 56.564015597105026, 54.34438370168209, 40.40076971054077, 26.266233064234257, 12.504041288048029, 8.596870545297861, 4.874249724671245, 6.999150328338146, 10.111725758761168, 8.42329965904355, 5.33935284242034, 7.008011927828193, 4.431194448843598, 1.4522667531855404, 0.471348735736683, 0.14130408642813563, 0.6767173251137137, 5.522088361904025, 20.60945000499487, 23.925609961152077, 36.969918608665466, 45.21411582827568, 49.97289687395096, 49.49642524123192, 41.62922099232674, 17.771994061768055, 2.7467996953055263, 0.019905743974959478, 0.08633120422018692, 0.09324877755716443, 0.02740929299761774, 0.028410420527507085, 0.08747900981688872, 0.034836415652534924, 0.056167175935115665, 0.01886826976260636, 0.023739205753372516, 0.06777026894269511, 0.08239840040914714, 0.046820761053822935, 0.06395353702828288, 0.023294611055462155, 0.07493091048672795, 0.042260159680154175, 0.049495828643557616, 0.05726727256842423, 0.017367875370837282, 0.053128363215364516, 0.02729202253249241, 0.05709980323445052, 0.11045810606447048, 0.05061023388407193, 0.024403914030699525, 0.08924261244828813, 0.17770113103324547, 0.17259516986086965, 0.180111404042691, 0.13738665991695598, 0.12533919856650755, 0.0974496896378696, 0.23091451468644664, 0.11780029919464141, 0.05778482780442573, 0.23961391038028523, 0.17149481718661264, 0.1054945778741967, 0.11325585437589325, 0.13973625493235886, 0.12548427359433845, 0.1561080475221388, 0.10776669267215766, 0.1586618073633872, 0.16533844987861812, 0.16776686097728088, 0.20350802515167743, 0.14030137070221826, 0.11889141955180094, 0.13111904467223212, 0.18218273820821196, 0.15230183926178142, 0.15057797863846645, 0.1886681144242175, 0.1432837950414978, 4.46272705681622, 20.959209837019444, 51.836024299263954, 60.60678966343403, 52.656506672501564, 39.65680383145809, 31.671933196485043, 53.03094618022442, 40.07295370101929, 20.92514656484127, 5.743559002876282, 0.5846662551630288, 0.3942572552477941, 3.636245517991483, 7.9810755886137486, 10.115599650889635, 14.484857898205519, 13.7154970318079, 9.33223083615303, 6.195406531915069, 5.428024884313345, 16.95090562105179, 30.443554110825062, 44.780258908867836, 53.525018468499184, 62.115076929330826, 57.795453518629074, 57.700287625193596, 54.68153201043606, 55.85868984460831, 53.24126489460468, 52.43305206298828, 51.56764470040798, 51.72837607562542, 51.05206936597824, 52.26187504827976, 54.090929701924324, 55.6914684176445, 55.616198256611824, 52.60360211133957, 51.722797974944115, 42.792813554406166, 40.879183039069176, 40.69641284644604, 40.10505057871342, 40.84247700870037, 38.20308543741703, 45.82527883350849, 49.590166211128235, 53.75515691936016, 54.6202526986599, 54.53914985060692, 52.52170890569687, 55.65046101808548, 52.378224804997444, 53.45195218920708, 51.661613658070564, 54.57684002816677, 45.9927624464035, 42.617236375808716, 55.77752240002155, 51.85384914278984, 49.59783419966698, 42.39419214427471, 39.696785286068916, 38.53100784122944, 45.46880096197128, 46.05619624257088, 50.493039563298225, 51.739501878619194, 53.64358730614185, 52.798622846603394, 52.07363694906235, 49.071281254291534, 45.791316255927086, 41.8921060860157, 42.658859342336655, 43.057332560420036, 48.781508803367615, 50.89057803153992, 52.79782488942146, 53.954756408929825, 48.22174184024334, 52.67239362001419, 56.64663076400757, 55.2923758327961, 49.583615362644196, 47.811740040779114, 50.781303495168686, 55.84578953683376, 56.885797530412674, 56.08086012303829, 48.299892246723175, 59.167510494589806, 58.537234514951706, 45.27943052351475, 26.306357011198997, 16.299259588122368, 10.682267993688583, 7.129062982276082, 16.277722343802452, 18.509397692978382, 18.862653337419033, 13.444829005748034, 10.794405676424503, 6.047047292813659, 4.094497365877032, 1.3522917428053916, 0.7948095258325338, 1.1431709141470492, 6.392509555444121, 25.613154508173466, 31.019910983741283, 43.979052901268005, 53.44328485429287, 56.03002265095711, 59.396672397851944, 48.03095027804375, 21.656090542674065, 3.2562540331855416, 0.14077999658184126, 0.15043746039737016, 0.16283221717458218, 0.0914155317877885, 0.15223497175611556, 0.1404110898147337, 0.1104535863851197, 0.12029879871988669, 0.19237724976846948, 0.17992690613027662, 0.17839714681031182, 0.1750983449164778, 0.18978623411385342, 0.1631176471710205, 0.12053517275489867, 0.20932154991896823, 0.1360164920333773, 0.15467316436115652, 0.1606301759602502, 0.0582657172344625, 0.11859577760333195, 0.15275790385203436, 0.19593682751292363, 0.254236074979417, 0.1347471374901943, 0.11857596968184225], [0.0875541077402886, 0.016830961212690454, 0.07368569800746627, 0.0448568267893279, 0.03768680078792386, 0.02477176323736785, 0.0688749409164302, 0.05640005074383225, 0.10716932316427119, 0.007158248117775656, 0.048658018131391145, 0.03016342529008398, 0.012085407361155376, 0.08884030161425471, 0.015176050746958936, 0.061658805279876105, 0.01884772711491678, 0.07513835560530424, 0.026047095780086238, 0.03187139838701114, 0.05348952196072787, 0.014966756752983201, 0.04572173682390712, 0.03717919775226619, 0.00948176499150577, 0.04734190086310264, 0.014036509892321192, 0.0266719544379157, 0.019868523413606454, 0.05078403373772744, 0.8190692053176463, 9.865062944591045, 34.68363828957081, 46.88829459249973, 48.11775282025337, 27.061228305101395, 34.06209044158459, 26.48918990045786, 28.75465113669634, 23.92811592668295, 4.744485262781382, 1.1683088215067983, 0.31598641304299235, 0.6465361977461725, 1.773433475755155, 3.7593786232173443, 4.538282677531242, 2.7283493103459477, 5.28782095760107, 3.500289050862193, 5.295168338343501, 10.286176297813654, 22.29799959808588, 43.87908786535263, 53.0321279168129, 51.79451912641525, 50.150598138570786, 49.91096019744873, 48.426653444767, 49.78454478085041, 51.204049810767174, 52.03251555562019, 49.512688368558884, 52.24467717111111, 51.92838974297047, 52.93653264641762, 54.158186092972755, 51.0113887488842, 49.198487028479576, 46.315988302230835, 41.689717546105385, 39.534180611371994, 37.31446132063866, 36.98019325733185, 40.48499599099159, 41.03065811097622, 38.61301504075527, 45.55993527173996, 49.7498944401741, 51.03341996669769, 52.51420430839062, 53.42422887682915, 52.08693243563175, 53.18136490881443, 51.06020852923393, 53.03660027682781, 47.13594630360603, 50.43271020054817, 44.146927893161774, 33.01660314202309, 54.653538912534714, 48.62217955291271, 48.193456158041954, 42.41343431174755, 39.88741725683212, 35.694908425211906, 36.59774757921696, 35.93403719365597, 38.957044780254364, 41.74379624426365, 43.33183363080025, 44.04232330620289, 40.13655848801136, 39.68936048448086, 37.95384541153908, 35.883765891194344, 38.564328253269196, 43.2252911478281, 49.18802998960018, 47.89433240890503, 52.770181372761726, 51.06257200241089, 50.09450554847717, 51.34373791515827, 51.738301143050194, 50.05195163190365, 47.05720692873001, 41.94490045309067, 48.1791765242815, 50.52595719695091, 53.84292080998421, 56.17288738489151, 53.76564435660839, 39.74843971431255, 40.756119042634964, 37.21590980887413, 24.033843353390694, 11.111025586724281, 7.954497914761305, 5.040910681709647, 2.6916499296203256, 5.643522245809436, 5.217527104541659, 3.186188405379653, 5.262860571965575, 5.166794126853347, 1.3835263042710721, 0.5463791533838958, 0.2556733478559181, 1.1110087274573743, 6.583249820396304, 23.236478939652443, 38.83965767920017, 35.73601461946964, 37.42546856403351, 41.12830527126789, 47.09700979292393, 30.614075660705566, 12.925428226590157, 1.1615284415893257, 0.033124934052466415, 0.04987777865608223, 0.023588163858221378, 0.07633790373802185, 0.05778286111308262, 0.01647829634748632, 0.02477404719684273, 0.039212934716488235, 0.07928477178211324, 0.12508361774962395, 0.046659069339511916, 0.02759292816335801, 0.04878511463175528, 0.04980000900104642, 0.04280683679098729, 0.008607220952399075, 0.029866774020774756, 0.026418570378154982, 0.06257937639020383, 0.018713895624387078, 0.0741260290669743, 0.02152416211174568, 0.04896470323728863, 0.0604622220271267, 0.003326707110318239, 0.02395932675426593, 0.07666687553864904, 0.049414177556172945, 0.030690374260302633, 0.010221428328804905, 0.12206701750983484, 0.01942620896443259, 0.0585550472169416, 0.049095966896857135, 0.02437013703456614, 0.00934036173930508, 0.023642691303393804, 0.023976639204192907, 0.02434901922242716, 0.01937805656780256, 0.03572477013221942, 0.09278693905798718, 0.05100166112242732, 0.016222520716837607, 0.022008304003975354, 0.021082923776702955, 0.09652021646616049, 0.037078892783029005, 0.028605074730876368, 0.020310090148996096, 0.020164324923825916, 0.03658626999822445, 0.06627740178373642, 0.07436929023242556, 0.0703338770836126, 0.09722536808112636, 1.3320301612839103, 12.140144314616919, 39.97135855257511, 52.04862289130688, 52.982346788048744, 30.053195357322693, 32.5790224224329, 32.92154364287853, 33.38402822613716, 24.361400976777077, 5.876623587682843, 1.1523160734213889, 0.08295223553432152, 0.4746741510462016, 2.4834747752174735, 3.4895781381055713, 5.941168824210763, 5.369207840412855, 7.020050156861544, 4.470174182206392, 7.072349125519395, 13.348713163286448, 22.613460570573807, 43.38366664946079, 53.64948458969593, 55.514599308371544, 52.22278654575348, 53.84213425219059, 50.89663490653038, 51.908228024840355, 53.12376379966736, 52.30101674795151, 50.382248908281326, 51.859366446733475, 52.467330023646355, 53.54700788855553, 55.28533861041069, 53.22988450527191, 51.962793096899986, 48.60037252306938, 45.28929479420185, 42.472315952181816, 39.77406553924084, 38.474820256233215, 42.0672120898962, 43.329036980867386, 39.938209131360054, 47.223432809114456, 52.7120178937912, 52.66406826674938, 53.347161412239075, 54.76719081401825, 52.6068889349699, 54.45308066904545, 52.152338325977325, 52.860209941864014, 48.39569270610809, 49.42647099494934, 44.77239713072777, 36.847291588783264, 55.961804911494255, 49.26665537059307, 49.41876880824566, 44.14147898554802, 42.073542550206184, 36.68354697525501, 37.417842373251915, 37.90535621345043, 43.302624598145485, 43.49601522088051, 46.18876352906227, 47.015637159347534, 43.49124647676945, 42.36156329512596, 41.36658288538456, 38.88253837823868, 39.59719642996788, 45.25982737541199, 51.01606249809265, 49.18217070400715, 53.76300349831581, 52.42842771112919, 50.56877709925175, 51.275242790579796, 54.73290525376797, 52.47716389596462, 48.26154850423336, 44.59780789911747, 49.271838292479515, 51.3929832726717, 55.888187661767006, 56.67725712060928, 53.05569425225258, 46.19596414268017, 47.29948952794075, 40.746190175414085, 27.01240472495556, 14.247431438416243, 8.3476010710001, 6.546923769637942, 5.578360967338085, 9.557642340660095, 11.17778705433011, 6.797273335978389, 7.261162418872118, 4.143250649794936, 1.4893058594316244, 0.31008622027002275, 0.33336816472001374, 1.160621833987534, 7.783692805096507, 23.65057121962309, 40.42657792568207, 39.370086416602135, 41.775212958455086, 47.169509902596474, 52.30150692164898, 36.06615610420704, 16.081312783062458, 1.500053582713008, 0.0679047461017035, 0.045650739266420715, 0.049997041787719354, 0.008217422728193924, 0.025047324525075965, 0.032379227777710184, 0.02411398661934072, 0.02438127667119261, 0.10697801975766197, 0.006337524164337083, 0.06017812789650634, 0.013447720539261354, 0.08390719405724667, 0.054513863869942725, 0.07497101614717394, 0.07079129238263704, 0.012121683539589867, 0.018817067139025312, 0.13646425941260532, 0.050339973386144266, 0.05635804518533405, 0.04213817657728214, 0.0373423960263608, 0.03322251533973031, 0.04466997997951694, 0.06024454640282784, 0.19052799587370828, 0.11482822039397433, 0.19812628190265968, 0.1244760214467533, 0.19084318599198014, 0.08438591641606763, 0.17796505359001458, 0.1071912758925464, 0.10253159038256854, 0.18977088649990037, 0.08611601107986644, 0.14923786773579195, 0.13503884605597705, 0.16373705846490338, 0.14706601708894596, 0.2188960267812945, 0.21032523043686524, 0.1423138377140276, 0.18569987994851544, 0.18880892952438444, 0.2164438075851649, 0.26230541698168963, 0.13505759270628914, 0.23325000889599323, 0.1197542181762401, 0.1405797354527749, 0.1432959662633948, 0.11948428422329016, 0.20892654923954979, 0.12858639151090756, 1.591537354979664, 14.898982476443052, 45.638556852936745, 57.54666566848755, 59.51904483139515, 36.9305033236742, 45.142611265182495, 35.7525285333395, 38.03958781063557, 28.32433372735977, 6.851918203756213, 2.055353648029268, 0.6348428002092987, 1.7176289577037096, 3.9071918791159987, 11.3622728548944, 9.82287760823965, 10.35186717286706, 12.80613362789154, 7.365246908739209, 10.339011512696743, 14.179215598851442, 26.25687226653099, 47.70517475903034, 57.83685989677906, 58.67656163871288, 54.32677164673805, 55.56220695376396, 53.2044068723917, 54.67448338866234, 56.173217967152596, 54.17330928146839, 51.25268340110779, 51.631583869457245, 52.0583351701498, 53.82692366838455, 58.01252067089081, 53.54828841984272, 54.98657204210758, 49.71889570355415, 46.19168937206268, 44.05767448246479, 40.85866034030914, 40.54805360734463, 42.87707783281803, 44.753572940826416, 42.33015418052673, 49.64302517473698, 54.720460921525955, 54.45881836116314, 54.793204218149185, 56.21614046394825, 54.86857317388058, 56.57609894871712, 53.67197558283806, 53.89064624905586, 49.81529273092747, 50.856455862522125, 46.86333753168583, 40.86440943181515, 56.411058604717255, 51.7874439060688, 51.53300195932388, 45.78813582658768, 45.367923974990845, 38.60245160758495, 38.667865097522736, 39.82532478868961, 43.35120499134064, 46.01948261260986, 45.6738455593586, 48.76381695270538, 43.73592294752598, 44.23778101801872, 42.66765207052231, 40.24010673165321, 42.43469417095184, 48.290825933218, 53.89078304171562, 52.828295454382896, 56.67411848902702, 51.10609866678715, 51.125356033444405, 52.17995524406433, 56.81577488780022, 54.811675027012825, 50.325308963656425, 44.696503803133965, 53.18893790245056, 54.1551348567009, 57.483798041939735, 56.478030011057854, 55.22298015654087, 47.59418651461601, 50.93322314321995, 46.06000743806362, 30.74506603181362, 14.43498557433486, 12.663206197321415, 10.373424366116524, 8.345466535538435, 12.796397600322962, 14.372642319649458, 11.62815123796463, 13.106481861323118, 10.295993071049452, 4.737083734944463, 1.6349621373228729, 0.525503073586151, 2.021807385608554, 9.226540457457304, 29.485475420951843, 49.00180198252201, 46.975678503513336, 49.13387529551983, 53.05867329239845, 61.063886135816574, 41.92722000181675, 18.265718668699265, 2.2066076193004847, 0.12790455075446516, 0.14668229705421254, 0.123966165992897, 0.16877587011549622, 0.17160474410047755, 0.135085022484418, 0.06757544775609858, 0.12234346009790897, 0.19843445130391046, 0.23811535094864666, 0.14554869616404176, 0.1527927996357903, 0.16629543446470052, 0.13516324484953657, 0.14305616350611672, 0.11078944531618617, 0.10477205258212052, 0.07283818020368926, 0.2040422527352348, 0.12405224770191126, 0.23534003034001216, 0.12174192714155652, 0.11011927112122066, 0.11589994101086631, 0.10365455629653297, 0.11560324521269649], [0.02166052803659113, 0.018736293641268276, 0.05126450756506529, 0.024135898529493716, 0.04391480761114508, 0.0467651073995512, 0.08915689439163543, 0.03673081439046655, 0.02650513077242067, 0.08486594495479949, 0.03423755813855678, 0.09979387439670973, 0.019107833177258726, 0.07792535761836916, 0.05082792435132433, 0.07973276922712103, 0.028541784377011936, 0.07167298608692363, 0.08010160920093767, 0.09464502451010048, 0.02310506097273901, 0.030024827356101014, 0.02387239714153111, 0.004748424571516807, 0.013799236930935876, 0.02727462659095181, 0.0885951034433674, 0.02901351013861131, 0.08759171978454106, 0.06623321431106888, 0.3470560099231079, 5.02513867802918, 27.87585899233818, 51.035669445991516, 45.53925298154354, 44.527469873428345, 29.799921847879887, 35.84576033055782, 56.07514142990112, 28.966231383383274, 9.653042871505022, 1.2668549898080528, 0.2789332950487733, 0.28247390349861234, 2.1552588371559978, 2.3242018092423677, 4.120345003902912, 3.5275777615606785, 7.088985582813621, 5.410106470808387, 4.2943628411740065, 12.43954449892044, 24.266787953674793, 33.805106431245804, 37.372343614697456, 46.982898116111755, 52.855030819773674, 52.13418669998646, 49.22711469233036, 49.92443047463894, 51.884114518761635, 52.46421039104462, 50.55392749607563, 52.58589506149292, 51.25513046979904, 51.5216101706028, 51.74479499459267, 50.73506757616997, 47.318017333745956, 43.608724772930145, 39.485775008797646, 38.420342579483986, 37.244229689240456, 37.410432770848274, 37.03483812510967, 38.859948590397835, 40.59835910797119, 46.1628033220768, 48.354240730404854, 50.24079009890556, 47.98173151910305, 49.67471547424793, 47.82391078770161, 48.72024089097977, 50.14237158000469, 51.84696011245251, 46.430339366197586, 52.46195711195469, 48.73444452881813, 30.722234956920147, 52.37616531550884, 50.52260957658291, 48.923393189907074, 46.11155167222023, 45.24470418691635, 40.806242153048515, 38.748926147818565, 36.01452447474003, 37.25923888385296, 35.92186264693737, 36.766625717282295, 35.990707352757454, 37.60933689773083, 36.66584752500057, 37.10058219730854, 39.2008662968874, 41.28846287727356, 47.55251035094261, 48.47906023263931, 50.46744793653488, 51.179765313863754, 49.36871789395809, 52.20990143716335, 52.28671431541443, 53.23399968445301, 49.237180352211, 45.80757178366184, 42.22666673362255, 46.21670722961426, 48.911165446043015, 51.301130801439285, 53.20967718958855, 54.638309329748154, 54.452503100037575, 37.9584089666605, 28.547066375613213, 23.651450872421265, 7.758407536894083, 5.3442707285285, 6.166103929281235, 4.14936357177794, 8.777493853121996, 8.366412911564112, 3.268190142698586, 5.848630489781499, 3.0652670189738274, 0.5815528566017747, 0.39155853912234306, 0.21332470932975411, 1.7566623631864786, 8.540610764175653, 24.04335994273424, 32.033911272883415, 33.09658125042915, 35.53845942020416, 42.66446404159069, 54.27892081439495, 30.459138974547386, 8.169449530541897, 0.7690141350030899, 0.0994601751153823, 0.015292375901481137, 0.03893150860676542, 0.06542847389937378, 0.07808324211509898, 0.08591259582317434, 0.027562305294850376, 0.013569547791121295, 0.019427834267844446, 0.0056773754567984724, 0.02519964848033851, 0.04511232968070544, 0.04492833271797281, 0.02849589738616487, 0.054075959633337334, 0.0033501717325634672, 0.08986537824966945, 0.017554087644384708, 0.05708811069780495, 0.03381245223863516, 0.04496506160649005, 0.04531707338173874, 0.038522603790625, 0.03687763346533757, 0.030822541484667454, 0.05420724555733614, 0.04230495942465495, 0.05764987938164268, 0.04275506085832603, 0.022986838703218382, 0.024533005052944645, 0.03555341194442008, 0.06111730093834922, 0.05755168211180717, 0.06789423729060218, 0.06763809244148433, 0.05063550030172337, 0.029175405943533406, 0.020146238784946036, 0.09030559798702598, 0.02946655047708191, 0.03642227762611583, 0.03142138972179964, 0.005181736769372947, 0.052498561854008585, 0.048793753230711445, 0.004758647191920318, 0.05745766313339118, 0.03076225682889344, 0.013234649013611488, 0.03687526230351068, 0.01859818923549028, 0.032289854643750004, 0.0631522030744236, 0.02495416087185731, 0.03775299293920398, 0.39689609489869326, 7.171443533152342, 34.01015482842922, 58.652330338954926, 48.373277708888054, 43.919095918536186, 34.91294078528881, 34.27617095410824, 49.53263349831104, 30.52515473216772, 9.495767410844564, 1.617522973101586, 0.2877049759263173, 0.324872859637253, 2.12455197237432, 5.3003104124218225, 5.829113312065601, 5.276659056544304, 5.854034274816513, 5.604076562449336, 5.416853483766317, 11.590353716164827, 26.859214045107365, 37.24231079220772, 44.768517538905144, 49.34058420360088, 55.06545960903168, 53.690735176205635, 50.698973312973976, 52.59441800415516, 53.97269144654274, 53.634353801608086, 51.30257852375507, 53.22804920375347, 52.21591271460056, 52.63129502534866, 52.67368175089359, 52.801795676350594, 49.969078078866005, 45.97082622349262, 41.25448130071163, 39.98594596982002, 38.315065428614616, 39.68224726617336, 40.408053919672966, 40.72838053107262, 41.756088584661484, 47.567758932709694, 51.356835812330246, 52.231134697794914, 49.94858957827091, 52.15555675327778, 50.811333283782005, 50.4949926584959, 52.3297394067049, 52.59346045553684, 48.09259817004204, 51.46859921514988, 49.78671446442604, 35.748664140701294, 54.55380566418171, 53.14524404704571, 51.48247227072716, 48.857295736670494, 46.712573021650314, 41.653368696570396, 40.805409997701645, 36.96983881294727, 38.636976554989815, 38.27626571059227, 38.01532991230488, 38.89649122953415, 40.3538878262043, 38.54149907827377, 39.32003930211067, 40.05295917391777, 41.68660931289196, 50.090983137488365, 51.33215233683586, 52.36168049275875, 52.44226656854153, 50.06254926323891, 52.82782427966595, 53.248093128204346, 53.941593915224075, 51.170383617281914, 48.87306869029999, 45.2680729329586, 48.3638846129179, 51.865909695625305, 53.967386931180954, 55.48904187977314, 55.48414394259453, 53.348859921097755, 40.25931090116501, 32.78757803142071, 24.38207946717739, 10.926621481776237, 5.896053845062852, 5.884096836671233, 7.07446513697505, 5.260410653427243, 7.536678509786725, 6.017278265208006, 3.9040337735787034, 1.4382293564267457, 0.8112684614025056, 0.4510482359910384, 0.288580086780712, 1.6206016391515732, 10.311668179929256, 27.485452741384506, 35.28481923043728, 36.482400968670845, 40.8770589530468, 48.30388203263283, 61.1625250428915, 35.43602451682091, 10.70432011038065, 0.8001962711568922, 0.020075534375791904, 0.02349009460886009, 0.09035642768139951, 0.026735083374660462, 0.030276287398010027, 0.05370340521039907, 0.038241615548031405, 0.028189418226247653, 0.03741172746231314, 0.010424807405797765, 0.013082369587209541, 0.07960204733535647, 0.03087885936110979, 0.06835478445282206, 0.013921841582487104, 0.04451129767403472, 0.02175794419599697, 0.03656936387415044, 0.05826741675264202, 0.03703640482854098, 0.045110322171240114, 0.05334597946784925, 0.025351445510750636, 0.03652174025774002, 0.07113109953934327, 0.08476000337395817, 0.1586297614267096, 0.23076702025718987, 0.12967829854460433, 0.19678088690852746, 0.09828575610299595, 0.10383742148405872, 0.13776764884823933, 0.10729969624662772, 0.10010231839260086, 0.37700704182498157, 0.19704298378201202, 0.13912855472881347, 0.10990672744810581, 0.17501074180472642, 0.08945590569055639, 0.16541647928534076, 0.09633325462345965, 0.19075344549492002, 0.26796503516379744, 0.18352871207753196, 0.11414179316489026, 0.13650335575221106, 0.08026828814763576, 0.08466129773296416, 0.11365147103788331, 0.1323691479046829, 0.2313501256867312, 0.1446235051844269, 0.1746442395960912, 0.14557948044966906, 0.6277353409677744, 8.54454355314374, 37.343624755740166, 63.58649857342243, 55.94081103801727, 55.985481441020966, 40.93572400510311, 45.4480654746294, 63.61259937286377, 35.412431582808495, 11.979489885270596, 1.7526542907580733, 0.6253844546154141, 0.8873787929769605, 5.828732857480645, 6.852445900440216, 11.914754658937454, 12.964934706687927, 13.758400529623032, 11.662849076092243, 9.458976835012436, 15.225032530725002, 30.31796135008335, 42.206174433231354, 48.972110375761986, 51.63962043821812, 57.15460650622845, 55.35174384713173, 52.05934211611748, 54.96487520635128, 55.78479140996933, 54.55992713570595, 52.17166408896446, 53.144495487213135, 52.175988256931305, 53.70379127562046, 54.460015296936035, 55.8224093914032, 52.42636062204838, 48.04017998278141, 42.99207866191864, 40.92367485165596, 40.99005728960037, 40.896152928471565, 41.222156435251236, 44.1491773724556, 43.48320230841637, 50.442540273070335, 52.95520104467869, 53.36811348795891, 50.75967125594616, 53.86787787079811, 51.98075093328953, 52.35171742737293, 54.72791992127895, 54.1288136690855, 49.51935701072216, 51.63112409412861, 50.516450107097626, 38.828417882323265, 55.233197808265686, 54.863948822021484, 54.77438762784004, 50.448053777217865, 49.197046905756, 44.30978715419769, 44.09422092139721, 38.599803149700165, 41.05825982987881, 38.91552820801735, 40.040974617004395, 41.17931753396988, 42.55920208990574, 39.58689138293266, 40.914923921227455, 42.60065786540508, 44.339828342199326, 52.17789575457573, 53.47187452018261, 53.81846912205219, 54.372711181640625, 52.838653698563576, 52.68409699201584, 53.63075539469719, 55.63794448971748, 51.76005117595196, 50.6919626891613, 47.23513998091221, 50.26824362576008, 52.918008640408516, 56.52358956634998, 56.71080932021141, 57.278806641697884, 55.60761071741581, 44.70559671521187, 36.42630077898502, 28.26672501862049, 11.542788818478584, 9.139107149094343, 10.871436093002558, 11.34588623419404, 16.57738946378231, 17.47393425554037, 12.356775440275669, 11.722283586859703, 7.470700275152922, 2.0612219581380486, 0.9157933120150119, 0.5526166968047619, 2.4960862984880805, 12.261962927877903, 31.187770776450634, 43.82124736905098, 45.875694528222084, 47.990756034851074, 57.31944166123867, 65.67626103758812, 40.22399179637432, 12.657856084406376, 1.164638337213546, 0.1506364598753862, 0.08233133252360858, 0.26952811691444367, 0.08292280195746571, 0.18270936619956046, 0.16408153373049572, 0.07060034520691261, 0.07193010314949788, 0.24926988990046084, 0.05106720018375199, 0.0931818358367309, 0.20643933035898954, 0.09476589810219593, 0.10278490764903836, 0.12899809051305056, 0.0961601709423121, 0.12800937169231474, 0.14726679772138596, 0.09881825448246673, 0.09957659582141787, 0.18516776006435975, 0.14710603369167075, 0.11608331085881218, 0.15539940039161593, 0.17669740598648787, 0.17108766012825072], [0.026456596169737168, 0.052177894685883075, 0.04919522914860863, 0.014820472952123964, 0.005909583724132972, 0.08442407022812404, 0.055994214708334766, 0.05106188269564882, 0.03103389772149967, 0.027573574807320256, 0.11272675503278151, 0.026967013800458517, 0.06544355434016325, 0.029639320600836072, 0.020954693645762745, 0.09053296234924346, 0.038733065739506856, 0.04463381141249556, 0.05691432568710297, 0.0775646218971815, 0.014032109884283273, 0.02984917398862308, 0.03972771803091746, 0.050208872999064624, 0.01612536987522617, 0.02978059583256254, 0.15051532653160393, 0.053864521760260686, 0.1271567033836618, 0.034331655042478815, 0.017556813181727193, 1.465079546906054, 19.384363442659378, 43.0308023840189, 54.305447190999985, 41.50914743542671, 44.058339446783066, 65.81154897809029, 65.55751740932465, 44.260078221559525, 15.917848404496908, 2.727559902705252, 0.32011753355618566, 0.4413971398025751, 1.3138591800816357, 3.2938613276928663, 4.2141201719641685, 3.1324041914194822, 3.5074538039043546, 2.6800334779545665, 4.441423499956727, 6.77693160250783, 15.904291681945324, 22.124324217438698, 40.99593937397003, 52.22943618893623, 52.83154807984829, 51.829712837934494, 49.92317274212837, 49.48901563882828, 52.37983971834183, 52.71105274558067, 49.39907066524029, 52.41080805659294, 50.036984235048294, 53.66869255900383, 52.52743519842625, 47.57905952632427, 42.31034964323044, 39.75529834628105, 37.89465218782425, 38.76103989779949, 39.859044179320335, 42.0993659645319, 40.90360812842846, 43.29197756946087, 41.96968652307987, 44.772058948874474, 46.055706068873405, 47.4934197217226, 46.88785761594772, 47.33651094138622, 44.95251886546612, 48.60425591468811, 45.772655457258224, 51.490847021341324, 47.41333141922951, 50.12189447879791, 48.22907544672489, 28.634019009768963, 53.67926359176636, 51.80040121078491, 52.80143089592457, 47.531983852386475, 48.30227851867676, 48.13936986029148, 47.77452103793621, 43.87041673064232, 36.73297472298145, 34.31221961975098, 36.224296018481255, 36.81320361793041, 37.19436876475811, 38.042578250169754, 37.16479115188122, 38.553840816020966, 44.23871956765652, 47.728775292634964, 50.342845022678375, 49.529738053679466, 49.45378012955189, 51.693797931075096, 50.1423753798008, 52.96334780752659, 51.35287642478943, 49.876765832304955, 45.379714742302895, 40.76004423201084, 44.17229913175106, 44.60840553045273, 47.28671081364155, 52.12279491126537, 51.40709191560745, 53.99549022316933, 44.92191530764103, 30.5465741828084, 19.856632500886917, 11.578255165368319, 3.47598769236356, 4.1220055148005486, 6.760486559942365, 6.011177692562342, 7.983161676675081, 6.165280798450112, 2.822776618413627, 0.6929217930883169, 0.5328775278758258, 0.525831637205556, 0.42056463891640306, 2.3140098061412573, 13.332488983869553, 20.898234508931637, 31.491288989782333, 30.600660480558872, 39.7318460047245, 46.240509152412415, 38.64520691335201, 21.140756495296955, 5.5199946742504835, 0.21810161706525832, 0.06911568620125763, 0.06646486086538061, 0.04373842879431322, 0.05041543125116732, 0.050196627562399954, 0.05178819665161427, 0.041464306486886926, 0.011689839866448892, 0.032340235338779166, 0.01438919794964022, 0.0355065972689772, 0.022834375595266465, 0.016083830014395062, 0.011002829123754054, 0.060945668155909516, 0.0830322910042014, 0.015873839329287875, 0.04471191132324748, 0.061943563632667065, 0.0283367401061696, 0.04783764808962587, 0.06953839867492206, 0.033284907694905996, 0.014280886134656612, 0.005851591376995202, 0.09294920964748599, 0.029161000857129693, 0.03017202121554874, 0.03114054248726461, 0.02915956294600619, 0.0751847324136179, 0.03429711548960768, 0.06719606928527355, 0.0763658233336173, 0.02618251175590558, 0.01506351332864142, 0.04214919375954196, 0.04533357503532898, 0.04244557043421082, 0.0377385359024629, 0.022801177474320866, 0.03418567459448241, 0.039122700691223145, 0.05392346312873997, 0.04356397585070226, 0.026729070123110432, 0.04338818704127334, 0.07442133704898879, 0.016367246935260482, 0.054324927914422005, 0.04022511653602123, 0.019662466111185495, 0.032841793581610546, 0.029171758287702687, 0.08222988835768774, 0.08103517902782187, 0.07536851044278592, 2.6555549539625645, 23.877774327993393, 50.15208385884762, 58.82893346250057, 47.2498793900013, 41.95759557187557, 61.84738889336586, 67.91888549923897, 43.4844334423542, 15.781520269811153, 2.7339511597529054, 0.1772367989178747, 0.24798497994197533, 0.902109177550301, 2.938549518585205, 3.67991182487458, 5.509914765134454, 6.3342206832021475, 2.5384200643748045, 4.849073700606823, 9.618704114109278, 18.79549764096737, 31.685129888355732, 44.845026433467865, 53.19156736135483, 55.039989575743675, 52.719150111079216, 51.065760031342506, 51.8532145768404, 54.97876726090908, 53.8457440584898, 51.81346110999584, 52.21427880227566, 51.38016276061535, 55.709882229566574, 55.268475115299225, 50.04462942481041, 45.95189943909645, 41.47036291658878, 39.53583352267742, 39.99871328473091, 42.83078111708164, 43.105962350964546, 42.939269095659256, 44.330028668046, 44.27311532199383, 46.887017861008644, 48.87243412435055, 50.298254415392876, 48.97094003856182, 50.21951504051685, 48.259245827794075, 51.71195715665817, 49.84055757522583, 53.31378400325775, 49.79209117591381, 53.745752424001694, 50.384631380438805, 32.55262903869152, 53.431053310632706, 54.47446972131729, 53.03277388215065, 49.44672770798206, 50.69612726569176, 49.724530801177025, 49.523358196020126, 44.93321590125561, 40.255218520760536, 37.15452030301094, 38.76281440258026, 38.531228229403496, 39.72021482884884, 39.046708568930626, 39.13985297083855, 39.01634439826012, 45.56461662054062, 50.50540789961815, 52.86125488579273, 51.77487798035145, 51.963974833488464, 52.29837208986282, 51.261096149683, 54.601367712020874, 53.46927545964718, 51.390707194805145, 47.57500134408474, 43.35270591080189, 46.561470329761505, 46.95500761270523, 50.70132918655872, 54.67167153954506, 54.419327080249786, 55.461227372288704, 47.14186258614063, 33.62479470670223, 22.394343428313732, 11.150046642869711, 5.673381518572569, 6.4118030201643705, 6.290749115869403, 7.016846453770995, 6.5437352657318115, 4.831552365794778, 5.99398978985846, 1.8214564863592386, 1.1732119834050536, 0.504111765185371, 0.2718087664106861, 3.121391194872558, 12.561650946736336, 25.89403733611107, 34.795549884438515, 35.053628236055374, 45.09040206670761, 49.64459829032421, 45.881227031350136, 24.801227375864983, 6.420239517465234, 0.25402670027688146, 0.047914308233885095, 0.044783320772694424, 0.05076440022094175, 0.0431925272278022, 0.035243988313595764, 0.0808148056967184, 0.07132508209906518, 0.0746961023833137, 0.09129816113272682, 0.09320249722804874, 0.046496513023157604, 0.02795092350424966, 0.017769701953511685, 0.039256702875718474, 0.04268863864126615, 0.014108160539763048, 0.06007371142914053, 0.031725202716188505, 0.002560354055276548, 0.03725038826814853, 0.03590257387259044, 0.020609765670087654, 0.057122542639262974, 0.03553559668944217, 0.048876617729547434, 0.028249289134691935, 0.11635274757281877, 0.13424973527435213, 0.15399218449601904, 0.07495002821087837, 0.14313549909275025, 0.19347090827068314, 0.15669139043893665, 0.17635471187531948, 0.0794065507943742, 0.07852606679080054, 0.17949430824955925, 0.14135186589555815, 0.19056093238759786, 0.1519002631539479, 0.08874774095602334, 0.12755274306982756, 0.1507046929327771, 0.14587935263989493, 0.12790741544449702, 0.09670421713963151, 0.11525326321134344, 0.09445455973036587, 0.12648272939259186, 0.130491633026395, 0.09571332382620312, 0.0936653079406824, 0.25736820534802973, 0.23883860354544595, 0.17066992004401982, 0.17116907372837886, 0.17092435795348138, 3.448934806510806, 27.130500487983227, 57.01783284544945, 66.93429753184319, 54.84789088368416, 55.113511830568314, 73.81464913487434, 71.20219811797142, 49.86258879303932, 18.20746399462223, 4.572158809751272, 0.5716039217077196, 1.199035991448909, 2.9332865634933114, 7.065741755068302, 13.582419622689486, 8.716397881507874, 9.980457052588463, 6.566907372325659, 7.059365222230554, 11.546146888285875, 25.895027182996273, 39.02510292828083, 48.892215862870216, 57.3652558028698, 57.0250790566206, 55.67615523934364, 54.433492720127106, 54.41311061382294, 56.8121574819088, 55.22784389555454, 51.96780502796173, 53.96058909595013, 53.49363215267658, 57.36736848950386, 57.239258363842964, 51.7260430008173, 47.05518163740635, 43.799409940838814, 40.71486845612526, 42.00168840587139, 44.919658228755, 44.866464883089066, 44.77828301489353, 47.554015070199966, 45.70382595062256, 49.15242590010166, 50.46460568904877, 50.94714939594269, 50.85440397262573, 50.93576520681381, 50.57548373937607, 53.044929429888725, 52.04948164522648, 54.39890697598457, 52.56964713335037, 53.323218896985054, 48.47491845488548, 34.83560353517532, 53.016484156250954, 55.10201744735241, 55.15913598239422, 52.34615072607994, 52.64760375022888, 52.85329811275005, 51.52036003768444, 47.78095789253712, 42.23974943161011, 37.994138449430466, 40.08230119943619, 39.92354191839695, 41.927113607525826, 41.75673075020313, 39.975975304841995, 42.09772825241089, 49.6098567545414, 53.087213560938835, 54.719655364751816, 53.91063317656517, 51.41786053776741, 52.14430935680866, 51.329557076096535, 56.15065477788448, 54.01211813092232, 52.99914188683033, 49.90183688700199, 44.87700931727886, 48.37649613618851, 48.25972840189934, 52.40738444030285, 57.72228844463825, 56.66242651641369, 57.00186990201473, 49.252569526433945, 37.553605288267136, 22.91892807930708, 12.704941257834435, 6.30408545024693, 9.85483294352889, 14.04553022235632, 14.67650631442666, 15.560424383729696, 13.84191244840622, 11.321153361350298, 7.352663408964872, 3.5190624184906483, 1.174431242980063, 0.9703042369801551, 3.3676305692642927, 18.422988429665565, 30.370134450495243, 42.57441647350788, 44.54825095832348, 53.61066207289696, 59.405575320124626, 50.733650252223015, 28.367442414164543, 7.847509430721402, 0.38518711226060987, 0.1921464566839859, 0.3094892663648352, 0.15608946414431557, 0.10815630535944365, 0.10642952809575945, 0.14163882471621037, 0.2188767903135158, 0.23957902943948284, 0.14345407340442762, 0.17719206225592643, 0.16392534133046865, 0.1747207104926929, 0.11527693772222847, 0.11537230369867757, 0.10773206406156532, 0.14543556317221373, 0.12820550648029894, 0.18611460691317916, 0.09653181623434648, 0.19554234633687884, 0.0941112199507188, 0.17593288997886702, 0.1503309325198643, 0.1359365033567883, 0.08556895918445662, 0.1671441100188531], [0.02972886257339269, 0.01956013322342187, 0.049914474147954024, 0.04432222442119382, 0.023505651879531797, 0.05010353997931816, 0.044979292288189754, 0.025755886308616027, 0.12119584003812633, 0.05794876080472022, 0.02653903949976666, 0.04182162832876202, 0.06568738695932552, 0.08854108993546106, 0.05024821795814205, 0.05100297472381499, 0.035564299250836484, 0.059358674407121725, 0.024700262874830514, 0.04202043484838214, 0.01015535677652224, 0.04347984227933921, 0.06982041479204781, 0.015177609257079894, 0.03221167309675366, 0.03526878346747253, 0.06365505265421234, 0.0381222596479347, 0.0006919559393736563, 0.05072196792752948, 0.0014604827333641879, 1.5093111922033131, 14.45554532110691, 35.213265269994736, 48.11804920434952, 54.27187219262123, 55.98906844854355, 70.61848863959312, 59.48230840265751, 41.47057570517063, 19.75767821073532, 4.452355038374662, 0.331135131418705, 0.07599260468850844, 0.6789839034900069, 3.4162620222195983, 2.505645635537803, 5.19151940010488, 3.2275855215266347, 1.828945646993816, 3.64317468367517, 13.98167559877038, 20.116654448211193, 32.8693762421608, 45.35634219646454, 50.836525931954384, 54.16597567498684, 50.120575949549675, 52.871229350566864, 50.75419194996357, 52.6900664716959, 51.961599960923195, 49.35742110013962, 51.59880682826042, 53.216630816459656, 52.4395003169775, 49.53554794192314, 45.12586936354637, 39.28897596895695, 38.36808778345585, 38.67907449603081, 42.77760677039623, 44.289089664816856, 47.21145585179329, 45.21999031305313, 45.13194143772125, 42.657255828380585, 42.778697311878204, 42.594870775938034, 42.93701961636543, 40.37371136248112, 39.457253739237785, 39.58802752196789, 43.58548142015934, 45.03282755613327, 52.033967077732086, 46.12620368599892, 46.312549486756325, 44.53891485929489, 30.01613974571228, 53.708263635635376, 52.12689869105816, 52.763277143239975, 48.830035999417305, 51.15203060209751, 48.593506291508675, 51.47575423121452, 46.543626487255096, 43.97974066436291, 33.717984706163406, 36.947948187589645, 36.376721039414406, 39.688972905278206, 38.239096105098724, 37.85554848611355, 37.68593318760395, 43.86041946709156, 49.72480058670044, 52.40104258060455, 52.19430707395077, 48.26383598148823, 48.43093201518059, 50.84202043712139, 52.807035595178604, 52.73682676255703, 49.32037688791752, 44.60887290537357, 42.876857444643974, 41.83588810265064, 44.93793524801731, 47.48444840312004, 49.452887177467346, 51.81889481842518, 53.84877249598503, 44.073850214481354, 31.425372026860714, 21.003433763980865, 10.390092171728611, 3.368189139291644, 4.790629036724567, 5.259133446961641, 2.3181826947256923, 2.6496073231101036, 1.320944968611002, 2.2844359930604696, 0.6566598638892174, 0.3940344031434506, 0.3241129597881809, 0.8041673549450934, 4.108187081292272, 14.813681803643703, 28.019508384168148, 25.112434476614, 30.434683486819267, 31.925358697772026, 41.38438493013382, 30.45807123184204, 13.87935183942318, 2.479157019406557, 0.15210567478789017, 0.11002400162396953, 0.0456542830215767, 0.025181324854202103, 0.12008493402390741, 0.04739355805213563, 0.03377463981451001, 0.010735142950579757, 0.013785584196739364, 0.034249718228238635, 0.01821494231990073, 0.04704470782598946, 0.04611373180523515, 0.06879351247334853, 0.039555829207529314, 0.02757258032943355, 0.06902959707076661, 0.046871598169673234, 0.04877940380538348, 0.02309639639861416, 0.021509124344447628, 0.052176748067722656, 0.07944390308693983, 0.08815823079203255, 0.05582366546150297, 0.035767087392741814, 0.011155470347148366, 0.034412363602314144, 0.04043872519105207, 0.049360115808667615, 0.018950405101350043, 0.03772137002670206, 0.031933041173033416, 0.038792819759692065, 0.04342792533861939, 0.04733110632514581, 0.07110854567144997, 0.05828282002767082, 0.028266471708775498, 0.023419911558448803, 0.04169520347204525, 0.001745488777942228, 0.06536440429044887, 0.047990152015700005, 0.0628881469310727, 0.025855721869447734, 0.0829072242777329, 0.022287902575044427, 0.04766368125274312, 0.057223404219257645, 0.04548939636151772, 0.017548207979416475, 0.032754795320215635, 0.06980264777666889, 0.036777402710868046, 0.026819929407793097, 0.04149493863224052, 0.04815333915757947, 2.0239925058558583, 17.580871917307377, 43.78721259534359, 57.352442890405655, 57.127555757761, 61.21931679546833, 73.53631407022476, 65.08492156863213, 46.55987821519375, 21.157247610390186, 4.559513088315725, 0.5703849589917809, 0.19255065999459475, 0.4954224033281207, 2.99028682988137, 4.670675648376346, 8.517748340964317, 3.883750936947763, 3.2325000828132033, 3.616729765199125, 14.843737240880728, 26.488817520439625, 35.357258543372154, 46.981268003582954, 53.679613173007965, 55.714821964502335, 52.09669031202793, 53.85653927922249, 52.894297912716866, 53.98714207112789, 52.58428394794464, 50.47211788594723, 52.77829393744469, 56.393488347530365, 54.71183158457279, 51.04693964123726, 48.11431400477886, 41.31064608693123, 39.87936168909073, 39.51873444020748, 44.194102361798286, 45.840622410178185, 47.76262767612934, 48.6157388985157, 46.365047469735146, 44.39813621342182, 45.71923792362213, 45.37644311785698, 45.584250167012215, 42.34816521406174, 42.82871402800083, 42.644898891448975, 46.0171115398407, 49.0575297921896, 52.419258803129196, 48.78172159194946, 50.0897254049778, 45.72419285774231, 34.010808393359184, 54.35696482658386, 51.54350459575653, 52.660648450255394, 52.61096231639385, 52.01410934329033, 50.18735356628895, 52.49105215072632, 49.30669002234936, 44.19115372002125, 34.835493341088295, 38.600867092609406, 37.76087276637554, 41.03131927549839, 39.48833607137203, 39.76455084979534, 41.0638303309679, 47.675559148192406, 52.08744540810585, 54.073849618434906, 53.66222530603409, 50.91832414269447, 49.001798182725906, 51.94673515856266, 54.72926124930382, 53.18927988409996, 51.13392077386379, 46.720917373895645, 44.44864310324192, 43.81226845085621, 48.0915342271328, 50.09147711098194, 51.71314649283886, 54.52360488474369, 55.693280920386314, 45.18109939992428, 33.12382958829403, 24.114347733557224, 8.5970538854599, 3.3557721180841327, 3.522690273821354, 4.604381555691361, 7.377390107139945, 6.078756591305137, 7.887344593182206, 4.434979520738125, 1.9275780231691897, 1.0376930865459144, 0.5496415751986206, 0.9386663034092635, 4.985925732180476, 18.512994199991226, 33.35245572030544, 30.650242120027542, 33.59476111829281, 38.93686406314373, 49.017970114946365, 37.57856234908104, 18.050182834267616, 3.0404505506157875, 0.08133479888783768, 0.02963080260087736, 0.03487383473839145, 0.03283008991274983, 0.06823294606874697, 0.021997771073074546, 0.021279041866364423, 0.03439827021793462, 0.0284708814433543, 0.09391262123244815, 0.015249301650328562, 0.024214343538915273, 0.02173649427277269, 0.05480735359014943, 0.02470892188284779, 0.008464832499157637, 0.02236042153526796, 0.09072160144569352, 0.04430212706211023, 0.016728027185308747, 0.023246263845067006, 0.07899376083514653, 0.0366885973198805, 0.03658096364233643, 0.056611310501466505, 0.04596691644110251, 0.043724892020691186, 0.13717422756599262, 0.12177208802313544, 0.13301365863298997, 0.09415390086360276, 0.17358004435664043, 0.13472862832713872, 0.16784209990873933, 0.1351436521508731, 0.20848106767516583, 0.257417899556458, 0.10594826759188436, 0.16162990825250745, 0.17708228377159685, 0.18042991898255423, 0.23314555903198197, 0.2702699083602056, 0.1272227248409763, 0.20802596787689254, 0.11759660934330896, 0.08089935116004199, 0.1217340084258467, 0.19728253420908004, 0.18522910599131137, 0.0985835948085878, 0.07876031086198054, 0.0643471721559763, 0.12180446792626753, 0.11644579804851674, 0.11017419747076929, 0.223113993415609, 0.20255537470802665, 2.302358206361532, 21.22790101915598, 50.015264600515366, 63.629804849624634, 67.09917828440666, 65.84763184189796, 75.47027349472046, 67.14214637875557, 49.03700329363346, 24.607696160674095, 5.659076236188412, 0.7214884820859879, 0.5514681490603834, 1.898527038283646, 7.777732349932194, 7.614633701741695, 14.19636882841587, 9.010263662785292, 5.63305570743978, 6.490788906812668, 18.315383903682232, 32.936594635248184, 39.72288228571415, 49.18257728219032, 55.65537415444851, 57.27704353630543, 53.31498093903065, 56.074499264359474, 54.421067386865616, 55.6150621175766, 53.944158777594566, 51.70654244720936, 53.70423585176468, 56.83847866952419, 58.09621877968311, 54.09182645380497, 50.01247175037861, 43.00676107406616, 40.87760992348194, 41.86411678791046, 45.67533127963543, 48.1806356459856, 50.147949680686, 50.34710839390755, 49.07858446240425, 46.84595346450806, 47.94969543814659, 46.906860396265984, 46.65635883808136, 43.21496330201626, 43.463811948895454, 44.07915472984314, 47.38616667687893, 50.67044824361801, 55.2512164413929, 49.63072903454304, 52.287698462605476, 47.9095733910799, 38.37918698787689, 53.88000302016735, 52.31324069201946, 54.131070747971535, 54.50009174644947, 54.91810731589794, 52.37448200583458, 56.445864737033844, 50.71126565337181, 47.258273139595985, 36.40148811042309, 40.86480841040611, 39.91607151925564, 44.256270825862885, 41.34451366961002, 42.29674257338047, 41.97702772915363, 49.25178296864033, 53.4666384011507, 54.95067536830902, 53.78183528780937, 51.17120437324047, 48.439599350094795, 52.49458596110344, 56.48806147277355, 55.91233156621456, 53.76171916723251, 48.10506910085678, 45.79239919781685, 45.736238211393356, 49.733209535479546, 52.05971449613571, 52.886006757617, 56.402535662055016, 58.99331644177437, 48.27928215265274, 36.147616133093834, 27.936019264161587, 13.445177637040615, 5.76170445419848, 9.355170205235481, 10.36269374191761, 9.30205000564456, 10.742209777235985, 11.163547318428755, 7.472661444917321, 2.7676985738798976, 1.6004409897141159, 0.8790077827870846, 1.6621977696195245, 5.950060822069645, 19.659039303660393, 41.99144795536995, 34.287023171782494, 41.13267123699188, 45.91130621731281, 55.5805067718029, 42.8243138641119, 20.123207196593285, 3.461108165793121, 0.27974220633041114, 0.21249840210657567, 0.0961750435817521, 0.13186502183089033, 0.2739319915417582, 0.10079807441798039, 0.1322355167940259, 0.1332597399596125, 0.15798486478161067, 0.15786521573318169, 0.11400022107409313, 0.21181696210987866, 0.22924134274944663, 0.1347512935171835, 0.12042108239256777, 0.10769928339868784, 0.17946226231288165, 0.19055511394981295, 0.14696171565447003, 0.1887907914351672, 0.10388963899458759, 0.19453237240668386, 0.18889443977968767, 0.15891970368102193, 0.17730561085045338, 0.15858300612308085, 0.12691880052443594], [0.08714857598533854, 0.04616716272721533, 0.015008207556093112, 0.08027054427657276, 0.03995821425633039, 0.046524365825462155, 0.05059506067482289, 0.08247679346823134, 0.009530620573059423, 0.00688196787450579, 0.06305534538114443, 0.00959207040068577, 0.07351009102421813, 0.04409464483615011, 0.07162460547988303, 0.044211978383827955, 0.009336502571386518, 0.00782656044975738, 0.0744756919448264, 0.03640106333477888, 0.034105697050108574, 0.037423694593599066, 0.04875688704487402, 0.1101774258131627, 0.07961861207149923, 0.04575966428092215, 0.034896629804279655, 0.05164105103176553, 0.029672661585209426, 0.06202890319400467, 0.026499939449422527, 0.39796223456505686, 7.21122644841671, 24.602344147861004, 46.166052147746086, 39.97595630586147, 42.106669172644615, 56.07344292104244, 45.375409573316574, 40.23077443242073, 21.959787346422672, 6.159250047057867, 1.0465505300089717, 0.2563341264612973, 0.18167417409131303, 1.5453790943138301, 1.8547727423720062, 3.1708645401522517, 1.136995058041066, 0.7526504911947995, 8.708789739757776, 16.14827089011669, 16.764373630285263, 28.540646620094776, 41.611118763685226, 50.243689343333244, 55.0583615899086, 52.33843334019184, 53.92019346356392, 53.42226058244705, 53.57289969921112, 51.477521136403084, 50.22025980055332, 53.4893611818552, 54.03703719377518, 51.90358467400074, 46.587297543883324, 45.35281978547573, 39.0309964120388, 40.45390225946903, 42.34997771680355, 47.79345542192459, 48.63006412982941, 50.85974268615246, 50.59710457921028, 49.37565252184868, 46.19343727827072, 42.1986698359251, 40.11739231646061, 40.39488762617111, 38.4663201123476, 38.34913060069084, 37.23690368235111, 44.245878383517265, 45.81457860767841, 50.17091944813728, 47.53897167742252, 44.7737080603838, 40.014049261808395, 28.000289015471935, 47.94214144349098, 47.463082149624825, 50.66268905997276, 50.19538253545761, 53.24265941977501, 52.19995357096195, 52.206652611494064, 49.234030321240425, 48.11320826411247, 36.272230446338654, 34.61546994745731, 38.41413751244545, 44.61014583706856, 42.60053247213364, 39.63515639305115, 38.15070904791355, 43.92187736928463, 47.36615315079689, 51.72018751502037, 48.73131349682808, 49.649883806705475, 49.5482012629509, 48.94175000488758, 53.57812061905861, 50.37761315703392, 48.42251166701317, 43.08273419737816, 43.09461995959282, 44.82468232512474, 44.98749598860741, 46.77272379398346, 49.52841192483902, 50.42666472494602, 52.688827738165855, 43.68250161409378, 31.97459265589714, 19.21295464038849, 7.137498054653406, 3.266588766127825, 2.59879098739475, 5.172262508422136, 7.441886896267533, 3.8858446246013045, 4.050069199874997, 4.351083822548389, 1.4985607378184795, 0.5418493214529008, 0.6562938960269094, 1.0190789541229606, 7.056519649922848, 11.830231044441462, 29.65129092335701, 34.190253764390945, 34.37185741961002, 40.09613625705242, 36.433942168951035, 23.647341392934322, 6.562637351453304, 0.7942703110165894, 0.026574378716759384, 0.02259391974803293, 0.03872623055940494, 0.06714878705679439, 0.11770723387598991, 0.020851603767368942, 0.0475979306793306, 0.059612355325953104, 0.020430091717571486, 0.01771960327459965, 0.041467301052762195, 0.01040276283674757, 0.05338291986845434, 0.03734267804247793, 0.05551472793740686, 0.07512207288527861, 0.009306439096690156, 0.046786952516413294, 0.057802483497653157, 0.06919266175827943, 0.02576290145952953, 0.034970807464560494, 0.016514320195710752, 0.05112026003189385, 0.034355236784904264, 0.020138286672590766, 0.026583685248624533, 0.05986883043078706, 0.00674195243846043, 0.03961605078075081, 0.04678957229771186, 0.09486668175668456, 0.045450682227965444, 0.08617979867267422, 0.02921135186625179, 0.031027290751808323, 0.0629934725293424, 0.06429711429518647, 0.028276865486986935, 0.021620209008688107, 0.02643788106070133, 0.038240205467445776, 0.028205224116391037, 0.019494143307383638, 0.049754526480683126, 0.05469013507536147, 0.07623878249432892, 0.023240202353917994, 0.03731063210580032, 0.023439723190676887, 0.0019652320952445734, 0.04363255029602442, 0.024355683708563447, 0.02833180667948909, 0.039947579280124046, 0.07171593417297117, 0.010610942681523738, 0.014574911128875101, 0.6539171235635877, 9.578447174280882, 30.074869394302368, 54.32980388402939, 49.05854053795338, 48.62046204507351, 63.04899461567402, 55.85077486932278, 45.40220573544502, 23.24088480323553, 6.913417428731918, 0.8321376540698111, 0.2559424506034702, 0.6046589417383075, 0.890321081969887, 4.266620054841042, 7.47172337025404, 3.7565803108736873, 1.5986763406544924, 10.449296794831753, 18.9205090329051, 21.692365296185017, 31.268197260797024, 44.46333311498165, 53.57839800417423, 57.907574102282524, 55.84576293826103, 55.21321088075638, 54.76884752511978, 55.667290315032005, 53.35054323077202, 51.098362281918526, 53.66259768605232, 55.143131241202354, 53.96094247698784, 49.92288015782833, 46.57796524465084, 41.68405584990978, 41.30885638296604, 44.387428387999535, 49.96180146932602, 50.506604835391045, 52.74729900062084, 51.97545401751995, 52.03694611787796, 47.09813453257084, 43.79174955189228, 42.59207792580128, 42.04623721539974, 39.64954622089863, 40.4973529279232, 40.08225940167904, 45.39811335504055, 48.275436758995056, 51.68437063694, 49.74473811686039, 47.498773634433746, 40.97180686891079, 33.07827763259411, 50.00825397670269, 47.3543281853199, 49.88535337150097, 50.51679968833923, 54.02286775410175, 53.24980303645134, 52.724610418081284, 51.04406699538231, 49.90383937954903, 38.00138846039772, 36.37631066143513, 38.86452354490757, 46.947354823350906, 43.832399770617485, 41.572015061974525, 39.96742196381092, 44.35796096920967, 48.6737047880888, 54.11138020455837, 49.76459965109825, 50.00504694879055, 49.68448095023632, 51.82296819984913, 54.37747612595558, 51.984786316752434, 50.554660856723785, 45.37101320922375, 44.70853015780449, 46.86956539750099, 46.889153346419334, 47.47214466333389, 51.269873678684235, 53.51183697581291, 53.94084915518761, 46.718979477882385, 33.56783576309681, 21.210298463702202, 9.723853021860123, 3.8856909703463316, 3.991513391956687, 5.816834745928645, 7.49139491468668, 6.88157276250422, 7.882779138162732, 5.636859303340316, 2.47419994790107, 0.9883304696995765, 0.38157228904310614, 1.1753049585968256, 8.382632341235876, 13.137930873781443, 29.62137322872877, 34.750332310795784, 38.38319957256317, 44.63993243873119, 43.01110804080963, 29.63148258626461, 8.928189966827631, 1.3281136401928961, 0.07099942027707584, 0.048173581235460006, 0.06764670135453343, 0.057162603770848364, 0.04448925217729993, 0.035143839195370674, 0.07434764920617454, 0.06328776376903988, 0.043248692963970825, 0.019162022945238277, 0.039871011904324405, 0.06068376053008251, 0.05697437656635884, 0.01433082710718736, 0.011877104134327965, 0.0636923752608709, 0.061294069382711314, 0.035274939582450315, 0.09227479036781006, 0.03843998048978392, 0.07455435217707418, 0.03965424912166782, 0.07065901198075153, 0.008678237063577399, 0.03645310644060373, 0.06524503725813702, 0.06640102132223547, 0.17371060297591612, 0.12874994601588696, 0.13558116304920986, 0.21524371026316658, 0.13848641887307167, 0.13494560262188315, 0.22568451095139608, 0.20904496632283553, 0.11936508788494393, 0.15927730011753738, 0.1449252327438444, 0.07818268248229288, 0.2215549341053702, 0.13973732362501323, 0.15141443844186142, 0.17441108648199588, 0.07449327342328615, 0.1434532570419833, 0.14735616714460775, 0.1607036782661453, 0.10608034761389717, 0.16043752926634625, 0.13159903610358015, 0.13353305810596794, 0.10473492293385789, 0.1813151824171655, 0.10623855865560472, 0.17425415193429217, 0.2529498439980671, 0.18103444279404357, 0.08847478646202944, 0.8928126795217395, 10.644526518881321, 35.55966228246689, 62.15674169361591, 51.945796608924866, 52.522829845547676, 64.82356399297714, 56.401205733418465, 50.474568754434586, 27.492628656327724, 9.393672589212656, 1.4842667360790074, 0.8763414539862424, 0.7475356094073504, 2.9666202748194337, 3.726604669354856, 8.040397055447102, 6.637051133438945, 3.448583325371146, 16.226915270090103, 20.242957770824432, 20.233220793306828, 32.08977967500687, 45.29008895158768, 54.14925277233124, 59.35791067779064, 58.37934538722038, 57.83233433961868, 57.559106200933456, 57.45143137872219, 53.82527455687523, 52.46384181082249, 52.614154145121574, 58.80311004817486, 56.58796951174736, 51.56567640602589, 48.2048175483942, 42.81856097280979, 44.704247787594795, 47.26027563214302, 52.91195556521416, 51.845911368727684, 55.90427979826927, 54.81581300497055, 53.69064398109913, 49.533621445298195, 44.95884172618389, 44.41015116870403, 43.385049775242805, 41.756776347756386, 40.9393148124218, 41.61129355430603, 48.52527715265751, 50.83725929260254, 53.41979071497917, 53.31250347197056, 50.18481530249119, 43.16398523747921, 36.82596333324909, 48.69592599570751, 47.53760375082493, 50.43932944536209, 51.987309381365776, 55.284263268113136, 55.67198306322098, 53.73994253575802, 54.121491461992264, 52.328455075621605, 39.29637037217617, 37.93918579816818, 42.69469141960144, 49.37368422746658, 45.37725247442722, 43.824811577796936, 42.03549139201641, 46.70435406267643, 51.127867698669434, 56.363834738731384, 50.93083307147026, 49.325073435902596, 50.232764929533005, 53.59624944627285, 55.531295612454414, 54.9934496730566, 52.91464202105999, 47.542832270264626, 46.87405675649643, 49.62463416159153, 49.52102892100811, 50.107645243406296, 54.572306871414185, 55.04405155777931, 56.30345977842808, 47.556097358465195, 36.6861916333437, 21.14620730280876, 9.90531513467431, 6.301282625645399, 6.410064613446593, 12.624705713242292, 13.879077304154634, 10.645591411739588, 14.35169119387865, 11.60302983596921, 5.204357486218214, 1.564297447912395, 1.394225936383009, 1.4822117588482797, 10.455418266355991, 16.91038839519024, 41.17963671684265, 46.24109052121639, 43.98003324866295, 54.73755620419979, 47.75413893163204, 35.09355649352074, 10.547080747783184, 1.7158456658944488, 0.12187081592855975, 0.1391170365968719, 0.10561361836153083, 0.11982326759607531, 0.26257665711455047, 0.19439954281551763, 0.19386463245609775, 0.2548577869310975, 0.13940665230620652, 0.07760971479001455, 0.11763609159970656, 0.14139388629700989, 0.13456301065161824, 0.10740838377387263, 0.17799646127969027, 0.2147347602294758, 0.15680299460655078, 0.09109796679695137, 0.14812918816460297, 0.15950426372000948, 0.14949898497434333, 0.15094703383510932, 0.1198920572642237, 0.17508454096969217, 0.1225679375056643, 0.13363830948946998, 0.12572809879202396], [0.038307796567096375, 0.04642373802198563, 0.051656068390002474, 0.014767946522624698, 0.06407469263649546, 0.06847719429060817, 0.03458040810073726, 0.05336975045793224, 0.03746489492186811, 0.09768228614120744, 0.06879654043586925, 0.05577431264100596, 0.05494233169883955, 0.05316501046763733, 0.07249908550875261, 0.021847358148079365, 0.031234713605954312, 0.04078535639564507, 0.014467265391431283, 0.001314747078140499, 0.05793450414785184, 0.011259167858952424, 0.04078915990248788, 0.013983492717670742, 0.05207745613006409, 0.03494911077723373, 0.002186715169045783, 0.05266051332000643, 0.010514522855373798, 0.013960669821244664, 0.011628958709479775, 0.19562013825634494, 4.318683436140418, 21.098975837230682, 48.61319303512573, 48.56966257095337, 45.328409895300865, 34.26657646894455, 34.54274944961071, 49.01521906256676, 24.323391616344452, 8.611715398728848, 2.273370986804366, 0.2329573206952773, 0.8143165509682149, 1.5983050293289125, 10.691924225538969, 9.51333386823535, 2.8120851796120405, 8.415801711380482, 3.4143899101763964, 4.8994537722319365, 11.689934972673655, 23.56002777814865, 33.18112291395664, 46.458343863487244, 54.56219561398029, 53.83779488503933, 53.94026778638363, 53.051438480615616, 51.14906296133995, 54.44172687828541, 49.40470576286316, 53.752185478806496, 54.515249133110046, 51.4354307949543, 47.58974455296993, 42.44296632707119, 39.48970399796963, 42.66209676861763, 44.33867700397968, 48.72497923672199, 51.055014207959175, 53.01845625042915, 50.15903748571873, 51.63440331816673, 46.54018007218838, 45.64407415688038, 39.86027531325817, 39.114409536123276, 37.42631211876869, 37.057291120290756, 40.012308955192566, 43.52350674569607, 46.31082817912102, 48.19407172501087, 48.92259523272514, 43.25674585998058, 40.85525572299957, 31.383065097033978, 50.13235531747341, 52.8938115388155, 51.76031336188316, 51.66763253509998, 49.20936964452267, 49.907654374837875, 51.12913303077221, 51.15174561738968, 44.58303049206734, 34.50982041656971, 35.81910476088524, 43.51944096386433, 47.73693725466728, 46.652410849928856, 43.964499682188034, 39.24124293029308, 41.97792828083038, 47.318993881344795, 51.44255541265011, 52.60852284729481, 49.774790704250336, 46.454768255352974, 51.441445872187614, 52.88452863693237, 50.402159839868546, 48.92460912466049, 46.87920928001404, 43.949931263923645, 44.43193919956684, 46.62074714899063, 47.54223570227623, 47.72413574159145, 50.8502621948719, 49.63391326367855, 42.362817227840424, 29.114402532577515, 18.202320970594883, 4.691206896677613, 1.9449117430485785, 1.6477970173582435, 2.316050296649337, 6.854733852669597, 6.053789081051946, 5.773784480988979, 3.657965390011668, 1.8557382468134165, 0.4994411626830697, 0.3582402050960809, 1.9255691184662282, 8.697788380086422, 23.828941248357296, 33.629582449793816, 33.886897042393684, 33.551770225167274, 42.89191983640194, 31.212649941444397, 13.848146013915539, 5.148351341485977, 0.09352511624456383, 0.020441620981728192, 0.018264235768583603, 0.05309783868142404, 0.049793025391409174, 0.008166387087840121, 0.0488302372104954, 0.0331212418677751, 0.06076484758523293, 0.03712790792633314, 0.04090267881110776, 0.03311500411655288, 0.03256449752370827, 0.01567220522701973, 0.04447577477549203, 0.01830969973525498, 0.07710408957791515, 0.029045852934359573, 0.07104953008820303, 0.022477769925899338, 0.03617749876866583, 0.03492015959636774, 0.03725402108102571, 0.02513073450245429, 0.0081044446596934, 0.002122154119206243, 0.08067235045018606, 0.05521108192624524, 0.055977022857405245, 0.03851400972052943, 0.0208206283787149, 0.05321524273313116, 0.018295509871677496, 0.09211214128299616, 0.03433185542235151, 0.03125149727566168, 0.017975497648876626, 0.04960907295753714, 0.03466880531050265, 0.08618674517492764, 0.025107397668762133, 0.047497703635599464, 0.061132915725465864, 0.0511653529247269, 0.027944919529545587, 0.02121039135090541, 0.03310741936729755, 0.02612016392959049, 0.07129862453439273, 0.03255679032008629, 0.05801953200716525, 0.03737777420610655, 0.0933663485920988, 0.0927764673542697, 0.010244450677419081, 0.047779767992324196, 0.04223529773298651, 0.025661930412752554, 0.029250951010908466, 0.18395526887616143, 5.762207452207804, 25.746607147157192, 53.178857043385506, 50.64844362437725, 47.80248373746872, 40.22716082632542, 40.06984926760197, 53.22588711977005, 26.062569692730904, 8.940183073282242, 2.4231297383084893, 0.19528790842741728, 0.16822676989249885, 0.7154817169066519, 2.2128765704110265, 4.256443725898862, 2.098753019236028, 9.212379567325115, 8.595856949687004, 6.885804310441017, 14.946502726525068, 27.208413407206535, 37.29872636497021, 47.527807876467705, 56.911772936582565, 55.620134845376015, 56.34569451212883, 56.19352787733078, 53.154545947909355, 54.115301594138145, 49.636823907494545, 55.81114299595356, 55.80798916518688, 54.025124832987785, 49.141281098127365, 44.888306111097336, 42.10083648562431, 44.77058082818985, 45.811002999544144, 51.369302943348885, 52.87060238420963, 54.459920302033424, 51.85550965368748, 53.14745172858238, 48.39056298136711, 47.41265885531902, 41.019634902477264, 40.45137919485569, 40.18215984106064, 39.53165754675865, 41.80305026471615, 45.357428938150406, 49.422238022089005, 50.507102608680725, 52.195530608296394, 44.14633892476559, 42.25930318236351, 34.476990178227425, 50.45445263385773, 52.5183080881834, 53.7317805737257, 53.327790051698685, 53.3091938495636, 50.62521927058697, 52.449398785829544, 52.417089119553566, 46.089056879282, 37.05133303999901, 38.20761099457741, 44.32083696126938, 47.475773468613625, 48.47943641245365, 45.36336421966553, 40.59166006743908, 42.753212079405785, 49.81098756194115, 52.60254196822643, 52.78177835047245, 51.18601597845554, 47.999666556715965, 52.57074147462845, 54.344729483127594, 53.349072709679604, 50.68349674344063, 47.309475392103195, 46.54848262667656, 46.14658959209919, 48.22410151362419, 49.119147285819054, 49.92180861532688, 53.34928169846535, 52.387598901987076, 43.75568948686123, 30.712629072368145, 19.309171177446842, 7.289979597553611, 3.391079348511994, 3.202436571009457, 5.683996248990297, 7.363796336576343, 7.015221565961838, 7.156287571415305, 2.254511173814535, 2.1971382899209857, 0.8774748025462031, 0.5335994891356677, 2.088003633543849, 9.73034592345357, 21.047190316021442, 35.91892160475254, 40.28062395751476, 39.05471093952656, 48.402836322784424, 38.341956585645676, 19.831738136708736, 6.0816985834389925, 0.2697671775240451, 0.11953581895795651, 0.012526824739325093, 0.034096012022928335, 0.033895988381118514, 0.03527419743477367, 0.02377099564910168, 0.03603040138841607, 0.03135625513095874, 0.011603734965319745, 0.0366725075582508, 0.09043193378602155, 0.06924299421370961, 0.05510858019988518, 0.046598350527347066, 0.03432192919717636, 0.028295584306761157, 0.02154457673896104, 0.0684128055581823, 0.02489933842298342, 0.045555239703389816, 0.00785471660492476, 0.08437986791250296, 0.013180503774492536, 0.08795720525085926, 0.01460495326682576, 0.11962217526161112, 0.04220846538373735, 0.16412549855886027, 0.19458914670394734, 0.12651769939111546, 0.12802848941646516, 0.1450744637986645, 0.10096782585605979, 0.08087376190815121, 0.15178726374870166, 0.04786963836522773, 0.11445682001067325, 0.13287232402944937, 0.26759425818454474, 0.07737308100331575, 0.13772565813269466, 0.2354962524259463, 0.22916224465006962, 0.18664501985767856, 0.1227067042782437, 0.12404869281454012, 0.08253645471995696, 0.12943321169586852, 0.14258675510063767, 0.12125735665904358, 0.12534592242445797, 0.20271273970138282, 0.15405844344059005, 0.05642421507218387, 0.21549276018049568, 0.185044608078897, 0.15891128772636876, 0.1432664881576784, 0.41057705297134817, 7.096647871658206, 31.850987188518047, 63.54483760893345, 60.68397872149944, 57.606379464268684, 46.10764168202877, 47.71993316709995, 58.55645388364792, 31.325994059443474, 12.052458319813013, 2.9847728507593274, 0.7625134557019919, 1.0715343081392348, 3.86346691288054, 16.732613034546375, 19.88248061388731, 7.032040413469076, 16.112011335790157, 6.629632981494069, 5.893925484269857, 16.79733496159315, 27.48050920665264, 38.71444679796696, 50.08022591471672, 58.37152160704136, 57.4055602401495, 58.005760833621025, 57.119659781455994, 53.74372333288193, 55.7534658908844, 50.30398070812225, 56.13516680896282, 58.46910797059536, 55.52018880844116, 51.43207177519798, 46.30159467458725, 44.6444807946682, 47.361380606889725, 48.68460640311241, 53.17386031150818, 54.4520129263401, 54.90324631333351, 54.827307388186455, 55.160059332847595, 50.40728196501732, 50.06469614803791, 43.63509155809879, 42.11399517953396, 41.48347981274128, 41.862129494547844, 43.22003223001957, 46.51875302195549, 50.4291345924139, 51.60741336643696, 54.049846306443214, 47.70890235900879, 44.531501457095146, 37.481591552495956, 50.493571534752846, 53.94141532480717, 55.18282391130924, 56.26739591360092, 55.12373708188534, 52.90010780096054, 54.041357561945915, 53.882613480091095, 49.18070398271084, 39.062485322356224, 39.6606720238924, 47.07266829907894, 49.06542956829071, 50.60665346682072, 48.56646314263344, 42.8044219315052, 45.02819560468197, 51.212052181363106, 53.55294317007065, 55.861133113503456, 52.31913797557354, 51.17353364825249, 53.95269691944122, 57.28611744940281, 55.76843708753586, 52.90836475789547, 51.47712975740433, 48.09680834412575, 48.69920141994953, 50.58937579393387, 50.712375193834305, 51.26233488321304, 55.92866308987141, 53.21007616817951, 45.56686609983444, 32.80097231268883, 21.9146191701293, 7.033250173553824, 4.103375114500523, 5.633828965947032, 8.476421758532524, 15.837078038603067, 13.93466642126441, 13.312908634543419, 7.698608245700598, 4.231390245258808, 1.5383621770888567, 0.753829259192571, 2.929688631556928, 12.40609584376216, 31.036033518612385, 44.53165344893932, 48.88517864048481, 45.98660297691822, 55.18144838511944, 43.83686453104019, 23.68229191750288, 7.646819399669766, 0.448885677033104, 0.3198723873356357, 0.18325968354474753, 0.1355601751129143, 0.14812479465035722, 0.0998419729876332, 0.09790096737560816, 0.19262909016106278, 0.12473314593080431, 0.16636270273011178, 0.14496021758532152, 0.2040275136823766, 0.10637961866450496, 0.1382494659628719, 0.21206155914114788, 0.09494730125879869, 0.10670051589841023, 0.14418379752896726, 0.13961311778984964, 0.19489605445414782, 0.13072129804641008, 0.16480196616612375, 0.15813762845937163, 0.10061254492029548, 0.12666920141782612, 0.12214714719448239, 0.20165409572655335, 0.1923925380106084], [0.03488425078103319, 0.012986726233066292, 0.051201963069615886, 0.04462558470549993, 0.09045364902704023, 0.029193534755904693, 0.04022237058961764, 0.0649123992479872, 0.008438558616035152, 0.021929547292529605, 0.053112180685275234, 0.11181274821865372, 0.031216835268423893, 0.04107158791157417, 0.04112675174837932, 0.01981435405468801, 0.03868426210829057, 0.013969142364658182, 0.025617052742745727, 0.04110758578462992, 0.022932530191610567, 0.013709505710721714, 0.027676844656525645, 0.03787131354329176, 0.05756296646723058, 0.07519058795878664, 0.05658565445628483, 0.045314386807149276, 0.052825195889454335, 0.03279142401879653, 0.012600740792549914, 0.06683572690235451, 1.3359776744619012, 16.016404666006565, 40.759755447506905, 47.34170526266098, 43.51352088153362, 32.92611099779606, 45.896198228001595, 44.41438414156437, 25.62663808465004, 10.223161429166794, 3.4881121292710304, 0.24413700361037627, 0.5563402001280338, 0.34184304589871317, 1.588751629460603, 1.9524430576711893, 6.7648207023739815, 14.697925765067339, 0.3970482648583129, 2.3879177402704954, 4.4772437028586864, 16.07694111764431, 28.588649444282055, 41.047582402825356, 50.53620524704456, 55.13094149529934, 53.29484581947327, 53.41368444263935, 52.42055833339691, 54.03215445578098, 51.86765760183334, 55.05533315241337, 53.12692902982235, 51.978767439723015, 47.23417103290558, 42.53262631595135, 39.74737197160721, 44.408627450466156, 45.70813491940498, 50.67680150270462, 50.81018954515457, 53.32136079668999, 52.135075852274895, 53.18989545106888, 49.697905629873276, 46.966099217534065, 42.491687312722206, 40.32883197069168, 39.04007412493229, 43.40626023709774, 44.403292536735535, 50.109446346759796, 46.48320592939854, 50.58155581355095, 48.373133316636086, 42.20739796757698, 50.32064661383629, 32.45984561741352, 49.234630689024925, 53.028936088085175, 48.6166812479496, 48.41067150235176, 49.28620532155037, 46.473839432001114, 46.727202236652374, 44.2736890912056, 37.32646107673645, 34.5927319675684, 36.352041363716125, 47.234323024749756, 49.16045106947422, 49.182972460985184, 45.0705823302269, 39.52564246952534, 40.412769466638565, 44.55640912055969, 48.03384952247143, 51.24981835484505, 50.61497502028942, 48.258550465106964, 49.43343982100487, 51.518999710679054, 50.97045734524727, 49.21585589647293, 47.26491138339043, 43.37330840528011, 47.20090761780739, 47.010819017887115, 50.087905302643776, 50.053270161151886, 52.59172394871712, 47.76732422411442, 39.26438368856907, 23.55812408030033, 11.790733113884926, 5.757668595761061, 2.598381321877241, 4.5735367108136415, 4.096096605062485, 4.9273737240582705, 5.912165930494666, 4.456628859043121, 2.7752848668023944, 1.5566185349598527, 1.1218380276113749, 0.6397174042649567, 3.0754385981708765, 10.607461407780647, 15.666023567318916, 21.45793117582798, 26.11394103616476, 38.003398552536964, 36.0554026812315, 22.22341150045395, 11.43180912360549, 1.9185068411752582, 0.03874732610711362, 0.10668041853932664, 0.006503577851617592, 0.03514221389195882, 0.029067909563309513, 0.02462208503857255, 0.0481304698769236, 0.033831495748017915, 0.03290922140877228, 0.045565039763459936, 0.012958428142155753, 0.054461178806377575, 0.026332232628192287, 0.08936826547142118, 0.03488787617243361, 0.0831831844698172, 0.015652046640752815, 0.04103308529010974, 0.00580236379391863, 0.0381259110145038, 0.03736219652637374, 0.025702210477902554, 0.05968193167063873, 0.056441262204316445, 0.02418508993287105, 0.05187371061765589, 0.032046330015873536, 0.046425467226072215, 0.0471233791904524, 0.07524256798205897, 0.02389499182754662, 0.029322228729142807, 0.0712900007783901, 0.037479225793504156, 0.0244599795769318, 0.06488868020824157, 0.024473030243825633, 0.06768913735868409, 0.010024047660408542, 0.014174614298099186, 0.015463411255041137, 0.03548685985151678, 0.059347152564441785, 0.04730786597065162, 0.05746755967265926, 0.037996484170434996, 0.08229936080169864, 0.03625431847467553, 0.004596903527271934, 0.03527977467456367, 0.042135189432883635, 0.018931944177893456, 0.020051130704814568, 0.029408336413325742, 0.04553509039396886, 0.034178282803623006, 0.04219146278046537, 0.048525644961046055, 0.005358935659387498, 0.010815185432875296, 2.4735691817477345, 19.884148724377155, 49.637785255908966, 55.82252338528633, 52.6349276304245, 39.51230898499489, 51.86263047158718, 51.00973203778267, 29.11023985594511, 12.232887838035822, 3.839706787839532, 0.20231729373335838, 0.4866595094790682, 0.2832760167075321, 3.145572622306645, 2.919271965511143, 7.220036750659347, 21.055452972650528, 0.46669885399751365, 4.538880195468664, 8.183221891522408, 20.50857111811638, 31.10032606869936, 44.83712285757065, 53.018277660012245, 57.48054541647434, 54.95330482721329, 56.194002851843834, 53.48758287727833, 55.301909521222115, 50.46754293143749, 54.74925197660923, 55.192293003201485, 53.595113307237625, 49.0798269957304, 44.7917190939188, 42.111677303910255, 45.9817848354578, 48.38753454387188, 52.744274362921715, 51.58965311944485, 54.70596469938755, 53.20822946727276, 54.37974460422993, 53.002516105771065, 50.04289671778679, 43.778127282857895, 43.54475140571594, 41.238765344023705, 44.05951738357544, 45.73791392147541, 53.0060651153326, 48.988890275359154, 52.22902961075306, 48.95264022052288, 43.885308131575584, 48.83763559162617, 34.87783446907997, 50.454673022031784, 55.01215986907482, 50.75621344149113, 50.1845683157444, 50.13498857617378, 49.69957374036312, 50.64097702503204, 48.37287113070488, 40.14376290142536, 35.66687732934952, 38.678147345781326, 49.39901366829872, 52.41808086633682, 49.06086601316929, 47.35756181180477, 40.491292253136635, 42.570373490452766, 46.43760457634926, 49.89218160510063, 54.02846485376358, 52.42254942655563, 48.904082626104355, 51.14036902785301, 53.26317451894283, 52.372669503092766, 50.95764063298702, 47.86725886166096, 46.25298768281937, 49.97283607721329, 49.25471641123295, 52.044925689697266, 51.71212434768677, 55.642215460538864, 50.83663232624531, 42.68057517707348, 25.421431995928288, 14.00108590722084, 5.7570934016257524, 3.566621853969991, 4.4616004172712564, 7.549442499876022, 6.44988315179944, 5.222949888557196, 5.930193588137627, 2.772332662716508, 1.671600602567196, 0.31419935112353414, 0.6088980298954993, 2.9228416364639997, 12.387207057327032, 20.266155526041985, 28.653111085295677, 31.026285141706467, 41.7517302185297, 41.87422424554825, 29.804124422371387, 13.690767958760262, 2.7520443638786674, 0.07826440778444521, 0.06873443009681068, 0.032417062466265634, 0.09030312663526274, 0.029065651579003315, 0.029208745072537567, 0.059516224937397055, 0.021885511960135773, 0.031149362912401557, 0.015601326413161587, 0.017868899267341476, 0.039837815638748, 0.006576870964636328, 0.020651982740673702, 0.06236042798263952, 0.043004730468965136, 0.0679378533095587, 0.07903263453044929, 0.05889421241590753, 0.02367159424466081, 0.04699045683082659, 0.022787752022850327, 0.013107170307193883, 0.062051527565927245, 0.03075624172197422, 0.04831789185118396, 0.02742321197729325, 0.021370919748733286, 0.13628972112201154, 0.11070412801927887, 0.11060157063184306, 0.2314288675552234, 0.23722257697954774, 0.141677639039699, 0.09929421605193056, 0.20078422443475574, 0.0678749340295326, 0.27265175711363554, 0.12650324235437438, 0.27265870361588895, 0.1497013241169043, 0.10587437936919741, 0.1295250005205162, 0.14555533096427098, 0.24866495048627257, 0.1385130619746633, 0.17080389254260808, 0.15061657031765208, 0.15399592492030933, 0.08957751400885172, 0.17320493323495612, 0.13140664173988625, 0.2321551035856828, 0.21758307848358527, 0.13042725913692266, 0.23035380727378651, 0.13049365166807547, 0.1547722113900818, 0.1783631119178608, 0.20570018095895648, 3.0753039428964257, 22.97406692057848, 57.0073302090168, 60.063513815402985, 60.743722915649414, 46.66739724576473, 58.71998190879822, 56.15209870040417, 34.63470831513405, 16.291568800807, 4.419892430305481, 0.6999841297511011, 1.0675968881696463, 1.211512740701437, 5.680530834943056, 8.768091257661581, 18.358452692627907, 20.775856375694275, 0.6248651293572038, 4.8228237591683865, 6.230061147361994, 19.7556035220623, 33.54788303375244, 44.986010268330574, 56.09291687607765, 59.76808726787567, 56.075065433979034, 56.619298830628395, 55.22610358893871, 57.326262295246124, 51.62312172353268, 56.29030108451843, 57.98037439584732, 56.8728706240654, 51.275406181812286, 46.829728335142136, 43.66732142865658, 47.493970692157745, 50.727646574378014, 54.2635278403759, 52.94690988957882, 56.977646201848984, 54.58803802728653, 56.51696652173996, 54.38582047820091, 51.51995345950127, 46.47500216960907, 44.042764082551, 43.6964962631464, 45.83776116371155, 47.27994717657566, 54.054409861564636, 50.86165778338909, 52.78032302856445, 51.62562198936939, 45.209472477436066, 49.755898118019104, 37.89764642715454, 51.36358045041561, 57.63032577931881, 52.462451085448265, 52.50267192721367, 53.187319189310074, 51.38795234262943, 53.16887877881527, 48.28860305249691, 41.77484817802906, 37.61484280228615, 40.40623761713505, 50.71411170065403, 54.196868017315865, 51.23361602425575, 48.51852111518383, 43.31796817481518, 44.74870540201664, 48.64351160824299, 51.02230176329613, 54.48919013142586, 53.320141062140465, 48.334493190050125, 51.868421360850334, 54.614917784929276, 54.70073997974396, 54.64129596948624, 50.56477591395378, 47.97509707510471, 52.11822375655174, 50.439299046993256, 55.349638760089874, 53.70084263384342, 55.636401772499084, 51.639840826392174, 43.628061935305595, 26.41875497996807, 14.459055382758379, 7.636805037036538, 5.658648759126663, 10.805303491652012, 10.92929843813181, 13.418978992849588, 13.750233817845583, 13.081748988479376, 5.984810907393694, 3.6580705968663096, 1.8062949436716735, 1.4546786737628281, 4.187314035370946, 15.06050705909729, 23.91893371939659, 32.60996036231518, 39.39011514186859, 54.10307765007019, 45.92829130589962, 34.45823438465595, 16.672078482806683, 2.855898728594184, 0.20763126405654475, 0.17014980810927227, 0.13018937112065032, 0.16789719695225358, 0.16365894000045955, 0.11685553035931662, 0.15110451757209376, 0.12325458737905137, 0.08317082771100104, 0.10197399999015033, 0.10924349233391695, 0.14758240344235674, 0.17991069762501866, 0.14138823113171384, 0.16738740087021142, 0.11881747937877662, 0.12087972223525867, 0.14767247048439458, 0.12430046641384251, 0.06267657547141425, 0.08513906272128224, 0.13142889132723212, 0.1208350968954619, 0.1924579805927351, 0.1408680746681057, 0.2740785211790353, 0.14096066501224414, 0.0965345102304127], [0.03998245651018806, 0.016603596850472968, 0.014831873268121853, 0.02457672126183752, 0.028866514803667087, 0.0672872198629193, 0.08013414495508187, 0.048979750281432644, 0.0077818056979594985, 0.09005216939840466, 0.006023290952725802, 0.03792173876718152, 0.019635166208900046, 0.02248445111035835, 0.024597553347120993, 0.025702236453071237, 0.022177296596055385, 0.06875527702504769, 0.05303699741489254, 0.038154917856445536, 0.06286093237577006, 0.039718704647384584, 0.013341322537598899, 0.04980481811799109, 0.07137436812627129, 0.04825391872145701, 0.021854876104043797, 0.08050034288316965, 0.0332704543689033, 0.09921312157530338, 0.1013542027794756, 0.031008863224997185, 0.564360263524577, 8.913014531135559, 21.728567853569984, 37.3711808770895, 45.494365990161896, 35.44949099421501, 36.20843566954136, 44.880657121539116, 25.79568911343813, 12.698658294975758, 5.499447751790285, 0.6917898694518954, 0.13160556700313464, 0.8484508318360895, 0.7861914695240557, 3.291287678293884, 5.960679352283478, 5.337376948446035, 1.1110287951305509, 1.4938934007659554, 6.73010908998549, 14.010876081883907, 22.024746760725975, 36.459024623036385, 45.32327637076378, 54.36619073152542, 55.438477993011475, 55.057818219065666, 48.974253460764885, 56.97778679430485, 48.68276350200176, 53.31370800733566, 55.00283896923065, 53.49806271493435, 47.32369802892208, 44.8594656586647, 43.36726672947407, 43.936407789587975, 46.64226919412613, 49.29166562855244, 51.500965878367424, 53.850216418504715, 53.06460477411747, 53.66070158779621, 52.070608511567116, 48.48597966134548, 44.060250744223595, 40.62363155186176, 41.07348941266537, 43.89231875538826, 46.057712361216545, 47.101998925209045, 52.690826430916786, 50.852743461728096, 48.65127459168434, 51.19115710258484, 49.06629592180252, 33.76319468021393, 51.3414466381073, 52.198832631111145, 49.59644727408886, 45.79094387590885, 41.34141683578491, 39.923933297395706, 40.12435734272003, 35.00023350119591, 34.457155242562294, 35.4524814337492, 43.18468652665615, 49.11692440509796, 50.227015838027, 51.68634653091431, 47.733585834503174, 43.39184761047363, 38.902833089232445, 40.099210292100906, 47.92085878551006, 50.9158618748188, 52.7819037437439, 50.505704283714294, 49.734949842095375, 53.639164343476295, 51.3837231695652, 50.523567125201225, 47.43918523192406, 47.10004203021526, 49.15356583893299, 50.07616773247719, 52.25726209580898, 53.57328727841377, 50.95551274716854, 46.42497405409813, 33.19900095462799, 21.099519208073616, 10.605947189033031, 3.5544278332963586, 3.0071147019043565, 1.7223782278597355, 6.175598194822669, 2.9310282971709967, 3.1157024251297116, 5.0245026871562, 1.6444197110831738, 0.9162367600947618, 0.45338552619796246, 0.44585029303561896, 4.946642490103841, 10.237373616546392, 25.054808668792248, 29.461819790303707, 32.187407836318016, 36.26224458217621, 34.365359768271446, 13.362063746899366, 6.9135599210858345, 0.5946956388652325, 0.05709529097657651, 0.025830522245087195, 0.05641234813083429, 0.08480719654471613, 0.03524913881847169, 0.026184604612353723, 0.004011873152194312, 0.014557688664353918, 0.10247194397379644, 0.05331101689080242, 0.018226645988761447, 0.011744996281777276, 0.04253574508766178, 0.0776981639501173, 0.053943003877066076, 0.03700871158798691, 0.02859101845388068, 0.06342919485177845, 0.015138734634092543, 0.050142176187364385, 0.07678893656702712, 0.012225138925714418, 0.02433553439914249, 0.0381605025177123, 0.08761432560277171, 0.06405774940503761, 0.05424994873465039, 0.011846230790979462, 0.006301597722995211, 0.0516749857342802, 0.0897690474812407, 0.045815841149305925, 0.011072988982050447, 0.09618400130420923, 0.015874674245424103, 0.03443892877839971, 0.007353002047238988, 0.0725911118206568, 0.030780541492276825, 0.06648663547821343, 0.006560591491506784, 0.03991192650573794, 0.04726667677459773, 0.03691938669362571, 0.04697203672549222, 0.05356148431019392, 0.018531256791902706, 0.012533873286884045, 0.024136067368090153, 0.03357805602718145, 0.033970949007198215, 0.032844695379026234, 0.040101307749864645, 0.028377669550536666, 0.04513319887337275, 0.10171271947911009, 0.03173874691128731, 0.03124641727481503, 0.05054350367572624, 0.058487860587774776, 0.9235523769166321, 11.85575807467103, 29.729211442172527, 44.068165719509125, 49.87481273710728, 40.407016575336456, 43.89850862324238, 49.79880541563034, 31.961631551384926, 13.87550549581647, 5.5705025140196085, 0.5917137488722801, 0.44398836325854063, 0.5326970969326794, 1.045541090425104, 3.880887790583074, 10.391765031963587, 6.49928905069828, 5.965725956484675, 4.825333999469876, 4.309593848884106, 15.19725602120161, 24.851692467927933, 38.764995485544205, 47.23915636539459, 56.95543259382248, 55.70130608975887, 56.54601216316223, 52.15828500688076, 56.76179118454456, 50.25800317525864, 54.38574068248272, 56.66907235980034, 54.197168201208115, 50.55496484041214, 46.41259431838989, 45.99386438727379, 46.30830891430378, 48.720195293426514, 50.52127584815025, 52.42101430892944, 54.67936992645264, 54.83230412006378, 55.75772166252136, 53.20639416575432, 49.91992771625519, 44.25212524831295, 42.963929772377014, 43.02752695977688, 45.103670954704285, 49.3322816491127, 49.99611742794514, 53.63267429172993, 52.64190785586834, 50.51303789019585, 51.326049864292145, 50.805724784731865, 37.196276262402534, 51.78732231259346, 53.461288288235664, 52.54954241216183, 49.23455469310284, 45.093688890337944, 41.99081338942051, 41.96282409131527, 37.57447376847267, 36.30903147161007, 37.293604239821434, 43.94767418503761, 50.34939967095852, 51.54912069439888, 52.89505027234554, 49.308137744665146, 45.849506333470345, 40.635433718562126, 42.43511974811554, 49.10629637539387, 53.56853373348713, 54.7324188798666, 50.924593806266785, 50.45547477900982, 54.62092526257038, 53.40139590203762, 51.463727876544, 50.28272844851017, 48.67990605533123, 51.20667926967144, 51.97844825685024, 54.35966268181801, 54.98688742518425, 53.87268841266632, 48.04215207695961, 35.0223521143198, 23.426852524280548, 12.223038766533136, 4.28338760510087, 4.6085508819669485, 3.9661927381530404, 7.256790278479457, 7.924488075077534, 7.6011771988123655, 6.096572410315275, 2.4551351834088564, 1.2902609026059508, 0.32671564200427383, 0.8117249712813646, 5.867260415107012, 15.102858636528254, 26.719077564775944, 28.60189363360405, 32.907697185873985, 43.09877313673496, 38.72481644153595, 18.37380576878786, 9.322795942425728, 0.6937363743782043, 0.06833808613009751, 0.020561314559017774, 0.054897164591238834, 0.07864755636546761, 0.034741064519039355, 0.04269738856237382, 0.013898835932195652, 0.051590314105851576, 0.05834503426740412, 0.02420711130980635, 0.009734411542012822, 0.03261576137447264, 0.020834942552028224, 0.05405128322308883, 0.022253517017816193, 0.07525901397457346, 0.029811647291353438, 0.04981589467206504, 0.03899954128428362, 0.052478902362054214, 0.06285635332460515, 0.018854985319194384, 0.05431351368315518, 0.06673676150967367, 0.029281713032105472, 0.051596143675851636, 0.025433378614252433, 0.0136135005595861, 0.15869450639002025, 0.16175513825146481, 0.17866820882773027, 0.2603537467075512, 0.06995967880357057, 0.14350738929351792, 0.18545083003118634, 0.09622686775401235, 0.13648073509102687, 0.12921534682391211, 0.05756216123700142, 0.11832107164082117, 0.11745089606847614, 0.15251897682901472, 0.11236954451305792, 0.1267814141465351, 0.1865391747560352, 0.25293045910075307, 0.13759915163973346, 0.14380585140315816, 0.11988709229626693, 0.09793575925868936, 0.0882236882171128, 0.09837540754233487, 0.12748844339512289, 0.19369331508642063, 0.10621547044138424, 0.2310279296943918, 0.08730814515729435, 0.2781844086712226, 0.2196740498766303, 0.15089619671925902, 1.546800455544144, 12.822904977947474, 33.87878827750683, 52.36536629498005, 59.80472110211849, 45.648702308535576, 48.51291261613369, 56.18695043027401, 38.71173374354839, 18.65333776921034, 7.324547292664647, 0.9056527842767537, 0.6491796090267599, 1.3967053033411503, 2.417373522184789, 6.504267733544111, 13.427539933472872, 8.374425731599331, 4.800372188910842, 3.365003722719848, 8.880494926124811, 17.799871265888214, 26.106371842324734, 40.62009774148464, 47.9624779522419, 58.22594001889229, 57.89956413209438, 57.549424320459366, 53.02918307483196, 57.74358630180359, 49.77170147001743, 54.697175770998, 59.97414641082287, 57.55238436162472, 52.41230517625809, 48.60186204314232, 48.09849165380001, 47.12097130715847, 51.18339031934738, 52.5387129932642, 55.15177957713604, 56.88990131020546, 55.645285695791245, 57.33700431883335, 55.72980456054211, 51.684929206967354, 47.52151921391487, 44.27974596619606, 44.68683712184429, 46.44026443362236, 51.83245249092579, 50.511852353811264, 56.00456781685352, 55.24667948484421, 51.83815598487854, 53.07828404009342, 50.79245209693909, 40.22725582122803, 53.342453464865685, 54.74857561290264, 54.80888597667217, 51.326589435338974, 45.00128924846649, 42.420847713947296, 43.03572691977024, 38.49629670381546, 38.01781117916107, 39.531041979789734, 47.24804408848286, 52.62562192976475, 54.061690270900726, 56.64229139685631, 52.93027438223362, 48.58575090765953, 42.640251740813255, 43.4705375880003, 51.34521223604679, 56.13122262060642, 55.84853678941727, 52.36397556960583, 50.160124227404594, 55.11195011436939, 55.22547282278538, 52.670991495251656, 52.258481830358505, 52.1169014275074, 53.333869725465775, 54.18389931321144, 56.778787672519684, 56.98298491537571, 53.8825336843729, 49.27017018198967, 35.6497098505497, 22.866924069821835, 12.866248302161694, 5.934694446623325, 6.1314398143440485, 5.103020248934627, 13.438236359506845, 11.094519272446632, 13.649776708334684, 14.895715601742268, 5.974565232172608, 2.029344756156206, 0.7432984211482108, 0.8698395872488618, 7.665606066584587, 16.694746166467667, 34.990601018071175, 42.78595112264156, 43.680062144994736, 50.69849453866482, 46.8341588973999, 21.964341402053833, 10.251736845821142, 1.0075734090059996, 0.15346843603765592, 0.06596788909519091, 0.16854801593581215, 0.23325962712988257, 0.12873390078311786, 0.0925099101732485, 0.09366158235934563, 0.1402248998056166, 0.20764137210790068, 0.06856552470708266, 0.12375063146464527, 0.09661786825745367, 0.17900784529047087, 0.2433881172328256, 0.1822472902131267, 0.1814060064498335, 0.2247895995969884, 0.16887554054846987, 0.16161119128810242, 0.11215357211767696, 0.12931035656947643, 0.14507029292872176, 0.087519360386068, 0.25192146480549127, 0.1811672723852098, 0.17236704850802198, 0.12243212448083796, 0.08985957465483807], [0.09692710635135882, 0.0499177321762545, 0.05249652465863619, 0.0051271884512971155, 0.02556750325311441, 0.012477868967835093, 0.042655420111259446, 0.07639268907951191, 0.04239548659825232, 0.11003078485373408, 0.05591506094788201, 0.00447360079306236, 0.05014727845264133, 0.03965705072914716, 0.04045294102979824, 0.05123307018948253, 0.045623506157426164, 0.08525901605025865, 0.06306563154794276, 0.009750765693752328, 0.0437310852430528, 0.0591731040913146, 0.04926777408400085, 0.06121780999819748, 0.07047694831271656, 0.03754660167032853, 0.04727601299236994, 0.03195555793354288, 0.12251788706635125, 0.03641209164925385, 0.0056961889004014665, 0.03769225186260883, 0.02674997827853076, 2.9730528546497226, 14.856591951102018, 32.78471298515797, 44.14381206035614, 39.8343151062727, 36.94572530686855, 48.25067728757858, 29.830322116613388, 17.83234242349863, 8.064497262239456, 1.486815211828798, 0.7691454060841352, 0.14760484598809853, 0.9216632845345885, 3.458149549551308, 13.075943849980831, 3.826619340106845, 5.2039561327546835, 5.528928944841027, 1.4757342939265072, 6.692379014566541, 18.212304934859276, 29.51257936656475, 39.98235896229744, 50.71973919868469, 53.87128248810768, 54.11022126674652, 47.70636789500713, 58.24842721223831, 50.5829693377018, 54.22921568155289, 54.39985312521458, 51.64443477988243, 48.716973066329956, 46.923951879143715, 41.79882109165192, 43.13122719526291, 45.37918657064438, 48.108211532235146, 48.720727264881134, 50.60904733836651, 52.16254837810993, 50.95816880464554, 50.31556248664856, 46.47807240486145, 42.58225925266743, 38.39371740818024, 38.920961916446686, 43.834596052765846, 46.299216002225876, 48.482913225889206, 49.791665598750114, 49.76852864027023, 50.88817276060581, 51.30157917737961, 50.93820087611675, 33.631759732961655, 49.97360363602638, 50.936874747276306, 48.63829828798771, 42.3182038217783, 38.66120785474777, 37.234076634049416, 37.8098863363266, 36.985524371266365, 38.28771069645882, 41.80846497416496, 48.95790673792362, 48.7997592240572, 53.523946925997734, 50.966570153832436, 49.01085689663887, 45.958727672696114, 41.20744362473488, 39.03126239776611, 45.53147479891777, 50.62101289629936, 50.02896286547184, 51.30868099629879, 50.96405848860741, 51.689158380031586, 52.60441146790981, 49.18940171599388, 48.43340568244457, 46.6746586561203, 50.8605520427227, 51.99049361050129, 55.22073067724705, 53.398998230695724, 49.90830034017563, 38.50594438612461, 28.597489669919014, 15.798711497336626, 7.239633249118924, 1.3743951567448676, 2.9873507749289274, 3.627148331142962, 5.778021728619933, 5.797077231109142, 4.652982847765088, 2.786024515517056, 2.610295107588172, 1.5485497866757214, 0.196607164980378, 2.06765026319772, 4.830091819167137, 16.966560781002045, 28.762193731963634, 30.26918336749077, 37.36171178519726, 39.829546362161636, 33.63250069320202, 9.63338177651167, 2.8657283261418343, 0.2510799583978951, 0.053430829211720265, 0.04461569187697023, 0.02510174992494285, 0.010386534850113094, 0.04534960171440616, 0.04614999685145449, 0.01261709030586644, 0.054767537367297336, 0.03352481435285881, 0.013322108334250515, 0.031708493261248805, 0.007444469893016503, 0.053237210304359905, 0.053219168694340624, 0.053012261632829905, 0.03823847997409757, 0.021724347170675173, 0.053487265831790864, 0.04403380356961861, 0.07354163230047561, 0.05561576763284393, 0.003820378874479502, 0.026938955052173696, 0.015982730947143864, 0.1001021773845423, 0.03905450474121608, 0.05193937584408559, 0.040611048170831054, 0.07685276126721874, 0.04548876182525419, 0.019053096075367648, 0.03630843959399499, 0.056531002701376565, 0.036469563565333374, 0.035859147101291455, 0.019917662866646424, 0.005933214169999701, 0.06563342540175654, 0.049402666845708154, 0.04589475742250215, 0.008003989405551692, 0.023917111539049074, 0.05020610478823073, 0.043956230583717115, 0.06798158065066673, 0.08947880094638094, 0.03963627059420105, 0.04125493920582812, 0.019621646133600734, 0.10832601226866245, 0.030661870223411825, 0.05638995011395309, 0.05904950310650747, 0.062278621044242755, 0.026237247002427466, 0.026079273447976448, 0.08390320872422308, 0.038231403596000746, 0.062111545048537664, 0.026560068254184444, 0.10516913869651034, 4.686619117856026, 18.554031997919083, 40.35008803009987, 50.06881892681122, 45.81454060971737, 43.39891143143177, 53.4397928416729, 35.13970501720905, 18.669120222330093, 8.52181887254119, 1.7911184392869473, 0.49099020834546536, 0.08432846676441841, 1.2017028545960784, 4.272716827690601, 12.166041824966669, 5.814976645633578, 3.8455746229737997, 5.009980816394091, 4.697124604135752, 9.891935102641582, 19.40132763236761, 31.034224815666676, 42.91984833776951, 51.7522843927145, 55.574301704764366, 55.73250241577625, 51.7636875808239, 57.58846342563629, 53.5281191021204, 54.011171981692314, 56.389612555503845, 53.21757696568966, 51.343449130654335, 47.76375241577625, 44.34249959886074, 44.96439702808857, 47.26252131164074, 49.76700872182846, 50.129965245723724, 52.40118697285652, 54.325513914227486, 52.12601713836193, 51.61649867892265, 48.061690628528595, 43.471658527851105, 39.86257039010525, 40.72172708809376, 46.63322187960148, 49.40107695758343, 51.1248392611742, 51.98547787964344, 52.75851599872112, 51.20319485664368, 53.39258037507534, 52.07064650952816, 35.824899449944496, 50.75370937585831, 53.519189581274986, 49.779996424913406, 45.80734379589558, 40.80355189740658, 39.58290159702301, 38.32767695188522, 37.35335983335972, 38.32955405116081, 42.5477647036314, 50.28013698756695, 51.08336828649044, 54.6608155220747, 51.42964370548725, 50.58201938867569, 46.62798196077347, 43.118136897683144, 40.611232817173004, 47.71315813064575, 52.94545456767082, 53.13055783510208, 52.51648038625717, 50.528582856059074, 51.86345882713795, 53.87243762612343, 51.06752693653107, 50.74755750596523, 48.313784301280975, 53.13882999122143, 52.87904553115368, 57.39156939089298, 57.02862046658993, 51.38398915529251, 42.30390138924122, 30.61653982847929, 17.648477889597416, 9.748895578086376, 4.627499990165234, 6.144225653260946, 6.430021142587066, 10.122467782348394, 6.200445061549544, 6.658267294988036, 4.07418318092823, 1.4631439070217311, 1.2637884356081486, 0.28188446012791246, 1.6195549140684307, 6.490302057936788, 16.88886635005474, 33.11882145702839, 36.43703520298004, 42.06304371356964, 44.59803208708763, 38.20515252649784, 11.86571354046464, 4.105111146345735, 0.2920094324508682, 0.006067684835215914, 0.02041914689471014, 0.03552503592800349, 0.03279989934526384, 0.02815273943269858, 0.022397001994249877, 0.040415718613076024, 0.05113978222652804, 0.08352080229087733, 0.04324237357650418, 0.003396254464860249, 0.01237357959325891, 0.0034626989463504287, 0.04417533484229352, 0.06834872852778062, 0.05506566922122147, 0.0564008374203695, 0.050109985531889834, 0.029081221837259363, 0.015001229512563441, 0.026866313637583517, 0.021226716744422447, 0.034230288802064024, 0.031482490740017965, 0.05104772622871678, 0.08197726871003397, 0.035880376235581934, 0.010404940112493932, 0.18880673276726156, 0.1868519454728812, 0.12534789653727785, 0.09816606994718313, 0.13550527102779597, 0.17737601097906008, 0.10674697434296831, 0.1437833791715093, 0.18252326524816453, 0.17037892394000664, 0.13581967446953058, 0.11714069318259135, 0.17867194925202057, 0.17155044857645407, 0.13174394785892218, 0.18708426738157868, 0.19038082798942924, 0.12504624319262803, 0.18795795331243426, 0.1584023080067709, 0.07679139307583682, 0.224465592764318, 0.12328119337325916, 0.3320228587836027, 0.2132767072180286, 0.1353307772660628, 0.16690328309778124, 0.23031701159197837, 0.16035184089560062, 0.13761674053967, 0.13999124203110114, 0.147721110843122, 0.3167207236401737, 5.006817486137152, 22.644622698426247, 45.83951286971569, 57.62300357222557, 51.261324137449265, 50.441913306713104, 60.34036695957184, 42.18135416507721, 24.77662179619074, 10.934878438711166, 3.0426444578915834, 1.1436365079134703, 0.6435419584158808, 2.4047052394598722, 8.383258357644081, 20.727815553545952, 10.527833830565214, 13.274838477373123, 10.810889191925526, 3.6050199810415506, 9.254383463412523, 20.99732369184494, 32.39931486546993, 44.23843078315258, 53.77661816775799, 57.14751608669758, 57.72354617714882, 52.73454688489437, 59.97942432761192, 53.47758561372757, 53.04765768349171, 58.6988740414381, 55.596321523189545, 54.14426364004612, 48.742602691054344, 45.83442114293575, 47.45968893170357, 49.625625908374786, 51.54415436089039, 51.84476003050804, 54.307890459895134, 56.11378155648708, 54.429221749305725, 52.46067278087139, 49.86913204193115, 46.531603932380676, 41.44160605967045, 43.240627124905586, 48.792801797389984, 49.74515989422798, 52.442984730005264, 52.467596009373665, 53.3780537545681, 53.713039979338646, 54.284840896725655, 51.639422848820686, 38.8709831982851, 53.49676698446274, 55.54073430597782, 51.821113899350166, 46.63908876478672, 41.3435523211956, 41.04691743850708, 41.00915886461735, 40.72848692536354, 41.14736504852772, 45.132929384708405, 52.26973682641983, 52.69740387797356, 57.758648693561554, 52.46146313846111, 52.70988240838051, 51.15332253277302, 46.503322049975395, 42.950923070311546, 51.18081025779247, 55.190149918198586, 55.3560946136713, 53.50604608654976, 50.946495831012726, 53.03822658956051, 54.871563613414764, 54.56970401108265, 52.506467923521996, 50.79474337399006, 55.47405168414116, 56.00006505846977, 60.29474280774593, 58.443413749337196, 53.90948943793774, 41.78198039531708, 33.749112635850906, 18.19256879389286, 9.241095576435328, 3.355789454653859, 7.310911724343896, 10.964931026101112, 16.419156454503536, 15.142301470041275, 8.204110320657492, 7.09527044557035, 5.808645710349083, 3.846238162368536, 0.6499276938848197, 3.5864684265106916, 7.172106122598052, 24.120984077453613, 42.199357599020004, 43.84153068065643, 49.208484292030334, 53.613679111003876, 43.23672853410244, 15.724738966673613, 4.633882697671652, 0.44120774371549487, 0.11944993762881495, 0.14369006152264774, 0.12247162900166586, 0.1515895259217359, 0.17451642692321911, 0.12737133249174803, 0.16083486028946936, 0.11804525245679542, 0.16969502001302317, 0.15466335316887125, 0.18179005302954465, 0.2053287360467948, 0.12266116609680466, 0.23127533204387873, 0.13743694784352556, 0.1420253500691615, 0.12183125203591771, 0.16026343626435846, 0.12369344156468287, 0.13297984638484195, 0.10715004958910868, 0.12087284994777292, 0.19458127993857488, 0.11893901348230429, 0.20077566005056724, 0.1719216856872663, 0.16720140381949022, 0.22221998748136684], [0.054277326562441885, 0.06723595230141655, 0.03242997954657767, 0.04726200866571162, 0.01064604812199832, 0.07406831966363825, 0.04811019069165923, 0.04799151385668665, 0.029701119237870444, 0.09926006241585128, 0.029594589504995383, 0.023466876518796198, 0.07849966117646545, 0.09001443118904717, 0.08951527008321136, 0.02250379890028853, 0.06487529186415486, 0.009617611412977567, 0.012001665272691753, 0.04111512600502465, 0.05338785886124242, 0.019389960616535973, 0.041453207668382674, 0.04329935196437873, 0.053624310821760446, 0.013466640666592866, 0.04564455717627425, 0.018388454591331538, 0.09122629155172035, 0.09249898575944826, 0.03761353225854691, 0.03909940838639159, 0.022007272418704815, 0.6735364207997918, 9.904107749462128, 24.243669994175434, 40.002524480223656, 41.52767904102802, 34.7476876527071, 41.864755153656006, 32.8373933583498, 18.551085256040096, 8.320879954844713, 2.9204822005704045, 0.36630835966207087, 0.32394965761341155, 0.30905834573786706, 1.3453957065939903, 4.6763587184250355, 4.073031842708588, 4.747821008786559, 2.538290396332741, 2.2680187365040183, 6.233626781031489, 11.679715421050787, 22.644932381808758, 34.49097342789173, 43.48960116505623, 51.270432248711586, 54.990786015987396, 44.55597214400768, 58.01523372530937, 49.786915853619576, 51.46015606820583, 56.99445270001888, 52.70974941551685, 51.64820037782192, 46.65274143218994, 46.7442861199379, 42.662761732935905, 43.62624563276768, 45.19429989159107, 46.44478619098663, 45.15738867223263, 47.57337503135204, 48.842134550213814, 46.174506694078445, 43.75679522752762, 40.75910948216915, 39.32794667780399, 40.1643767952919, 43.336815163493156, 44.60757337510586, 47.069043293595314, 47.942263036966324, 46.95693030953407, 49.89852346479893, 50.04171498119831, 55.845166370272636, 37.06949606537819, 49.33337219059467, 50.21731875836849, 48.92674840986729, 43.719002455472946, 39.84388679265976, 38.529734909534454, 40.58054946362972, 42.31713607907295, 44.469424188137054, 47.24973499774933, 48.35362896323204, 49.65516932308674, 49.58304159343243, 51.75583340227604, 49.612212628126144, 47.396650314331055, 43.89667332172394, 38.57934504747391, 43.2661959528923, 47.66549728810787, 51.51194728910923, 52.06447184085846, 52.76058308780193, 51.7881278693676, 52.016301825642586, 49.96800273656845, 48.74191872775555, 48.750183284282684, 50.549428537487984, 52.692239955067635, 53.99578280746937, 50.96393309533596, 44.35530111193657, 32.597215846180916, 23.563008718192577, 11.887882500886917, 6.675656111910939, 4.16748289950192, 3.989070598036051, 4.250361677259207, 7.287021456286311, 4.699498526751995, 8.042746279388666, 3.5737203480675817, 1.0103726712986827, 0.5330124206375331, 0.41408301796764135, 2.426452422514558, 12.693589366972446, 18.146942742168903, 28.56773156672716, 29.797586873173714, 39.488579258322716, 39.08240005373955, 22.049667723476887, 7.877269433811307, 1.4026842825114727, 0.058965080097550526, 0.029910584853496403, 0.06029883821611293, 0.062082018703222275, 0.012659192343562609, 0.07728245735052042, 0.03786062290600967, 0.06704401806928217, 0.05716888605093118, 0.010142644714505877, 0.020712076293420978, 0.03747345930605661, 0.032061544043244794, 0.06928868824616075, 0.06780815558158793, 0.03728778137883637, 0.034955396768054925, 0.00822729236460873, 0.029699150691158138, 0.013720026581722777, 0.03602098353439942, 0.026844520471058786, 0.01550150198454503, 0.047688992199255154, 0.03929399208573159, 0.06509886385174468, 0.07595685543492436, 0.038731870881747454, 0.04582236462738365, 0.035089881348540075, 0.05129231954924762, 0.07668330668821, 0.06562912094523199, 0.0312990540987812, 0.03853332411381416, 0.06394872048986144, 0.08022404872463085, 0.04170770123891998, 0.07368200953351334, 0.065982123487629, 0.05837386299390346, 0.044362103726598434, 0.04305142269004136, 0.028171573285362683, 0.01788492223568028, 0.042658036181819625, 0.013619548135466175, 0.028476820480136666, 0.04962175626133103, 0.06279493318288587, 0.012797248509741621, 0.012142862578912172, 0.015658865122532006, 0.019134303729515523, 0.03952814338845201, 0.047467706026509404, 0.0449713587295264, 0.10544242715695873, 0.07607136882143095, 0.046965253495727666, 0.04088330133527052, 0.062210477044573054, 1.1038455180823803, 12.222599890083075, 30.671845860779285, 45.22367611527443, 48.5122362524271, 40.450072064995766, 48.37144620716572, 38.462524116039276, 23.409314565360546, 9.228872582316399, 3.0568780191242695, 0.39491925097536296, 0.17631497728871182, 0.3655940276803449, 2.4139083456248045, 9.441622216254473, 6.617001984268427, 8.457828406244516, 6.41491980291903, 4.362557781860232, 7.949405713006854, 13.979971390217543, 24.015526436269283, 36.251738145947456, 47.399344369769096, 52.89387233555317, 55.57994060218334, 48.044549748301506, 58.27138938009739, 52.509906738996506, 53.07664252817631, 57.06563428044319, 55.067842081189156, 52.831570878624916, 49.099939316511154, 47.80249893665314, 45.026949271559715, 44.465514197945595, 47.474606931209564, 49.41196337342262, 48.383715748786926, 49.961687475442886, 50.98405301570892, 48.41097928583622, 46.28441199660301, 42.21828058362007, 40.9382014721632, 41.84470362961292, 44.86465997993946, 46.150066405534744, 49.65827375650406, 50.32475419342518, 49.621183946728706, 51.395544335246086, 51.981039717793465, 55.84906116127968, 39.703780710697174, 50.37586525082588, 51.92005679011345, 51.04579210281372, 45.93877114355564, 41.041981503367424, 40.74633076786995, 42.699600756168365, 43.20981077849865, 45.804452151060104, 48.51268842816353, 49.964601919054985, 50.1566968113184, 52.166393771767616, 52.01469451189041, 51.69676937162876, 49.39342796802521, 44.35343541204929, 41.08446702361107, 44.91521246731281, 49.85966295003891, 52.369770258665085, 53.485033214092255, 52.39062733948231, 52.18010723590851, 53.490668311715126, 51.92183509469032, 50.51953934133053, 51.06007933616638, 52.09315650165081, 55.47392629086971, 55.81437662243843, 53.84031414985657, 45.633085146546364, 35.80446794629097, 24.30900938808918, 13.928725440055132, 5.614014929160476, 4.85148704610765, 8.69925795122981, 8.06839395314455, 10.332947988063097, 5.914705144241452, 6.354712508618832, 3.9556901017203927, 2.1412694128230214, 0.3702578617958352, 0.3059469658182934, 2.7867588261142373, 14.65932933613658, 20.979132167994976, 34.66660760343075, 33.23182359337807, 43.51725608110428, 45.22156722843647, 28.88697523623705, 9.396946113556623, 2.1211877278983593, 0.04141915051150136, 0.05442318826681003, 0.08193305897293612, 0.06628516464843415, 0.054676201252732426, 0.03233055031159893, 0.03149178242892958, 0.04982857055438217, 0.04938333389873151, 0.036494718660833314, 0.053017976169940084, 0.03183209424605593, 0.01702242974715773, 0.027709996393241454, 0.023298130690818653, 0.04603083019901533, 0.050497683478170075, 0.017559418120072223, 0.04981655518349726, 0.06284200761001557, 0.03057942318264395, 0.029986875779286493, 0.03226171982532833, 0.013111823573126458, 0.05827189932460897, 0.044234654706087895, 0.015685489670431707, 0.029485397317330353, 0.013517050119844498, 0.16881691088201478, 0.12447067056200467, 0.16066652635345235, 0.15064779989188537, 0.1885460311314091, 0.2145181124797091, 0.15293380769435316, 0.11076921437052079, 0.16353026643628255, 0.16770425339927897, 0.13054735347395763, 0.2049944578902796, 0.09845321430475451, 0.1654827085440047, 0.14049502671696246, 0.1550572257838212, 0.18172731186496094, 0.11263524822425097, 0.1319882777170278, 0.14199685159837827, 0.22999557259026915, 0.08990474176243879, 0.09134574022027664, 0.10519928473513573, 0.20350959850475192, 0.07863103615818545, 0.19216437212890014, 0.18641749222297221, 0.24492872675182298, 0.15019687096355483, 0.1063929773226846, 0.14043376984773204, 0.12595181178767234, 1.1568533862009645, 13.552619721740484, 34.0506112575531, 54.16933089494705, 55.37885919213295, 47.42962494492531, 55.29094710946083, 46.59879952669144, 27.392144948244095, 12.401849571615458, 4.334001839160919, 1.016402947716415, 0.5901645007543266, 1.4267601468600333, 4.836824107915163, 9.685644172132015, 10.240508448332548, 14.595659002661705, 8.031873162835836, 4.319269554689527, 10.077788829803467, 12.884062696248293, 24.39610831439495, 36.98376506567001, 48.42123493552208, 54.03927527368069, 56.7437307536602, 48.45362439751625, 59.384547248482704, 51.78884223103523, 53.23976017534733, 58.46748545765877, 57.81597621738911, 54.780144318938255, 50.64318850636482, 50.17191119492054, 45.867813751101494, 47.25603125989437, 49.45192962884903, 50.51463760435581, 49.09485138952732, 51.222752407193184, 53.05860109627247, 49.26682636141777, 48.98391254246235, 43.87804672122002, 43.15055675804615, 44.39925715327263, 47.04046502709389, 47.585021406412125, 50.950234830379486, 53.694405779242516, 52.11963728070259, 53.99868585169315, 54.19409416615963, 58.604479506611824, 42.98290975391865, 50.79146794974804, 54.61867958307266, 52.79635436832905, 47.6764141023159, 43.04935298860073, 42.05081216990948, 44.77901637554169, 45.97477801144123, 48.01552690565586, 50.58310613036156, 51.95830553770065, 52.71496653556824, 50.84428891539574, 54.88955944776535, 53.23469124734402, 51.9076656550169, 46.3747863471508, 41.958009749650955, 46.386022344231606, 51.67749300599098, 54.62007790803909, 55.04381977021694, 52.352861166000366, 52.20346838235855, 55.36935210227966, 54.089147597551346, 52.870089411735535, 52.455771043896675, 54.03256103396416, 57.181231677532196, 57.042767107486725, 54.18121665716171, 47.69515849649906, 36.11600182950497, 25.87760701775551, 14.96395519003272, 8.68110442534089, 8.716119546443224, 10.239993575960398, 10.131169315427542, 12.208002023398876, 13.611355070024729, 17.050120197236538, 9.15447162464261, 3.457764582708478, 1.0262965480796993, 0.9764987358357757, 3.867011647671461, 18.296356424689293, 26.82713806629181, 43.59094172716141, 41.09629578888416, 51.973246335983276, 53.32796484231949, 31.365743726491928, 11.774161253124475, 2.6644816249608994, 0.19759589864406735, 0.1850226108217612, 0.1508315556566231, 0.14382801193278283, 0.12100678533897735, 0.1729157182853669, 0.136155852524098, 0.12708928668871522, 0.15385405597044155, 0.07305215622182004, 0.1262975635472685, 0.10650349053321406, 0.13009118498302996, 0.18885765894083306, 0.11453720202553086, 0.13591239840025082, 0.1188158911827486, 0.09002998660434969, 0.1719647747813724, 0.1897017628652975, 0.10813420420163311, 0.1419211970642209, 0.2178024870227091, 0.10667545357136987, 0.13482872920576483, 0.18160960724344477, 0.2014935394981876, 0.15183115436229855, 0.1765747883473523], [0.027281513721391093, 0.055145490914583206, 0.04979473975254223, 0.06177697745442856, 0.02559856955485884, 0.031924179929774255, 0.06097827812482137, 0.033609140882617794, 0.0250298321043374, 0.022908269384060986, 0.09486469280091114, 0.04740944001241587, 0.10799869545735419, 0.08318757798406295, 0.047322137470473535, 0.031247693768818863, 0.030683570621476974, 0.027794803463621065, 0.03281275705376174, 0.051892620540456846, 0.04615057943738066, 0.011576074193726527, 0.07747636569547467, 0.020013724606542382, 0.013673742541868705, 0.036540256842272356, 0.0465543894097209, 0.05976029875455424, 0.03953289684432093, 0.02805135092785349, 0.05881450946617406, 0.011923009678866947, 0.012900838410132565, 0.045189115990069695, 3.532113768160343, 13.104406222701073, 31.683830358088017, 41.628001257777214, 40.9044174849987, 35.18035523593426, 30.66368769854307, 20.769759602844715, 12.589702941477299, 6.037861285731196, 0.7538920745719224, 0.5607773526571691, 0.8094428374897689, 0.7432034856174141, 4.070244692265987, 7.81834552064538, 2.982833292335272, 3.326933328062296, 3.6284770723432302, 3.576526022516191, 8.059637323021889, 18.717316836118698, 27.344113625586033, 37.56983041763306, 44.14870619773865, 56.06447920203209, 48.01665544509888, 54.47879768908024, 52.05081917345524, 47.462850362062454, 55.79910524189472, 51.3561100512743, 52.02031061053276, 48.02947595715523, 48.355107083916664, 45.6255691498518, 44.683702290058136, 42.73909583687782, 43.665843307971954, 42.902198284864426, 44.34719614684582, 44.5234002918005, 43.88118155300617, 41.85458689928055, 38.44175823032856, 39.72697466611862, 37.66474172472954, 39.840512573719025, 41.721909418702126, 41.138488724827766, 41.68036624789238, 44.02827546000481, 46.9199088960886, 49.704954251646996, 53.228850960731506, 36.27246603369713, 47.319267466664314, 51.01574331521988, 48.3463067561388, 44.50272560119629, 39.90513950586319, 43.15976746380329, 44.77894797921181, 47.85276643931866, 50.644932612776756, 52.495258525013924, 51.52783423662186, 50.531926676630974, 50.60861796140671, 53.09521213173866, 50.63758760690689, 47.60741740465164, 45.56123100221157, 42.21687085926533, 42.22520001232624, 44.97406750917435, 49.17549066245556, 51.739631071686745, 52.07212843000889, 51.41160227358341, 52.988950833678246, 49.858921989798546, 48.322136253118515, 48.56918379664421, 51.7984215170145, 54.86099258065224, 55.00651717185974, 48.54200005531311, 38.62694889307022, 29.545920677483082, 16.415605545043945, 7.421121960505843, 3.0310144694522023, 3.9782570907846093, 7.289796732366085, 8.247844073921442, 7.3525061924010515, 2.565840817987919, 5.2403985522687435, 3.0182345677167177, 1.5275920112617314, 0.3733478084905073, 0.3202900383621454, 4.288966180756688, 9.073004946112633, 14.17965542525053, 16.83524552732706, 30.619161687791348, 42.91414864361286, 39.174864292144775, 10.522506516426802, 3.5940395202487707, 0.23030338576063514, 0.02647556917509064, 0.012932245172123658, 0.03156172242597677, 0.044262941664783284, 0.06264043287956156, 0.06091348492191173, 0.028691072948276997, 0.08056790800765157, 0.02678192588064121, 0.02319541003089398, 0.0408138771308586, 0.013266770092741353, 0.010089438292197883, 0.009336124076071428, 0.012317790497036185, 0.027518837705429178, 0.03983964503277093, 0.04108933266252279, 0.05495713383425027, 0.03514158306643367, 0.026037954376079142, 0.020154604644631036, 0.0691290819668211, 0.03655900349258445, 0.0493209675187245, 0.004898083288935595, 0.03556476309313439, 0.021362622537708376, 0.05252321599982679, 0.03774049517232925, 0.004503564541664673, 0.023922699911054224, 0.09596006566425785, 0.031971128191798925, 0.010373702189099276, 0.02454764020512812, 0.03460699554125313, 0.04688399574661162, 0.016577271017013118, 0.017556158236402553, 0.03185756846505683, 0.06131938403996173, 0.07133058141334914, 0.05624025892757345, 0.04216087887471076, 0.08214886809582822, 0.053653399299946614, 0.032149644393939525, 0.062216239821282215, 0.034763466246658936, 0.022580436780117452, 0.040887590948841535, 0.045737885957350954, 0.0687674482469447, 0.023413753588101827, 0.019627132460300345, 0.035008415798074566, 0.024629905419715215, 0.060681003451463766, 0.018674140628718305, 0.014760774593014503, 0.10117488505784422, 0.2894780260976404, 5.757767865434289, 17.78830848634243, 38.740874379873276, 46.526295617222786, 44.140532836318016, 44.512935653328896, 37.4992948025465, 26.95600625127554, 13.78151848912239, 5.961357615888119, 0.7593238831032068, 0.42691668088082224, 0.13850642717443407, 2.6635528123006225, 3.8502828078344464, 9.149097763001919, 3.074694313108921, 5.061330311000347, 5.835538292303681, 3.592147221788764, 9.682893119752407, 21.416868679225445, 31.376915127038956, 38.803696408867836, 46.95377267897129, 54.37360793352127, 51.45450197160244, 55.4461345821619, 54.18685555458069, 48.048672527074814, 56.67329013347626, 54.9872712045908, 55.509720370173454, 51.274805814027786, 49.55625303089619, 47.486956268548965, 47.20935456454754, 44.52531538903713, 45.7330159842968, 44.591260850429535, 47.47108072042465, 45.895487666130066, 44.92018260061741, 43.14475826919079, 40.76751083135605, 41.14427961409092, 40.24420291185379, 41.19078911840916, 44.07774120569229, 43.7801069766283, 45.15075422823429, 47.392044961452484, 49.744228944182396, 51.914832070469856, 54.79290783405304, 39.59056958556175, 49.54553380608559, 53.14684756100178, 51.17490157485008, 46.70187659561634, 42.06396326422691, 43.67820784449577, 45.588965713977814, 49.889096170663834, 52.583489790558815, 53.63586612045765, 51.83525674045086, 52.15724766254425, 50.79940192401409, 53.53052817285061, 52.25032366812229, 50.00910893082619, 47.390468046069145, 45.01795135438442, 43.79387743771076, 47.39821583032608, 51.582380309700966, 52.26341396570206, 52.6106621325016, 52.43275187909603, 53.74369293451309, 51.68499380350113, 50.07433623075485, 50.22133134305477, 53.92042525112629, 56.131746992468834, 56.510385274887085, 50.36734990775585, 40.693650394678116, 29.72938623279333, 19.341547340154648, 9.77923410013318, 4.662422491237521, 6.407495951279998, 8.257335964590311, 8.7219949811697, 11.138976886868477, 8.46421206369996, 3.2897867588326335, 3.915552143007517, 0.6952157418709248, 0.1794519167742692, 0.6106397020630538, 4.318094467744231, 11.812869776040316, 19.90919318050146, 24.378363266587257, 36.540275663137436, 51.11326888203621, 42.19281814992428, 15.14555599540472, 4.768233513459563, 0.2219610076281242, 0.017944637293112464, 0.005868414937140187, 0.04388404187920969, 0.04769244318595156, 0.021314471996447537, 0.05209989125432912, 0.007676167933823308, 0.10348611103836447, 0.050384442874928936, 0.01923967200127663, 0.0759144862240646, 0.035439948696875945, 0.004348439442765084, 0.023239115107571706, 0.049237438797717914, 0.0459071624209173, 0.029594832558359485, 0.06157664582133293, 0.045243890199344605, 0.03244521954911761, 0.016277061149594374, 0.0309369750902988, 0.06832942526671104, 0.01202080340590328, 0.05043061559263151, 0.04361332867119927, 0.01337221165158553, 0.030178405540937092, 0.029343693495320622, 0.15191371086984873, 0.15517962077865377, 0.12057012791046873, 0.26592362439259887, 0.0935934903100133, 0.15737594745587558, 0.09006628504721448, 0.10472058464074507, 0.08772378496360034, 0.1775337173603475, 0.21748477360233665, 0.08379984981729649, 0.22206470050150529, 0.1996582528227009, 0.2218472512322478, 0.10594596693408675, 0.19899769686162472, 0.13771681173238903, 0.0844910490559414, 0.12307266471907496, 0.1477050210814923, 0.10378060265793465, 0.17169625090900809, 0.15017665486084297, 0.1454760250635445, 0.16068058263044804, 0.10576912056421861, 0.1637567550642416, 0.2190893710940145, 0.1390997742419131, 0.12434754826244898, 0.0841627451882232, 0.1608655258314684, 0.3931058576563373, 5.973261427134275, 21.125939190387726, 44.00831513106823, 55.599631145596504, 52.91494980454445, 51.270569041371346, 43.98199014365673, 33.05122308433056, 16.079931557178497, 8.608800955116749, 1.2766370899043977, 0.966335884295404, 2.06467573530972, 4.243583790957928, 8.771933801472187, 14.40048722550273, 8.959472738206387, 8.764581196010113, 7.2945683263242245, 4.762918073683977, 11.240365896373987, 22.108566462993622, 32.19153821468353, 41.01407580077648, 46.873349994421005, 57.19905272126198, 51.149625331163406, 57.529262602329254, 55.35384513437748, 47.631774097681046, 56.88153795897961, 58.42691883444786, 57.0276553183794, 53.68390694260597, 53.01796227693558, 50.488795191049576, 48.27874258160591, 45.76203502714634, 47.968246042728424, 47.55544379353523, 49.15169253945351, 46.60402424633503, 47.690059170126915, 45.621115788817406, 41.80391661822796, 43.46083290874958, 41.990467607975006, 42.573398128151894, 45.52950270473957, 46.41776584088802, 44.32981587946415, 49.71191927790642, 51.11878998577595, 54.10607568919659, 56.465809866786, 41.521291583776474, 51.48034058511257, 54.91199344396591, 52.91911818087101, 48.95189546048641, 43.09818796813488, 47.674966380000114, 48.7763524800539, 52.91910298168659, 55.56960515677929, 57.35411860048771, 55.2531049400568, 52.266841381788254, 52.50431343913078, 53.92497360706329, 54.070152416825294, 51.844737231731415, 49.190237671136856, 47.76917852461338, 45.49691565334797, 48.43844801187515, 52.412286177277565, 54.89790380001068, 52.792261987924576, 51.824970692396164, 54.68700371682644, 53.203715309500694, 53.06002601981163, 53.25566612184048, 55.78111320734024, 57.72660881280899, 58.47597800195217, 50.72576567530632, 41.52881897985935, 31.17112386971712, 21.226662285625935, 8.54597607627511, 6.13535787910223, 8.949939049780369, 16.181956082582474, 17.59389191865921, 18.828344978392124, 13.575269356369972, 9.32631740346551, 8.878000359982252, 2.9391627106815577, 0.7064384396653622, 0.8877659565769136, 6.0890578385442495, 14.062217026948929, 22.537679336965084, 29.03550736606121, 44.18894603848457, 55.12495681643486, 50.528001487255096, 18.85748751461506, 5.47030521556735, 0.42899988940916955, 0.10695568853407167, 0.1936781159020029, 0.1292345832916908, 0.17498789849923924, 0.15392246714327484, 0.15252607176080346, 0.07631217347807251, 0.1868224673671648, 0.08922444467316382, 0.09603675178368576, 0.1311821272247471, 0.11484775372082368, 0.14626455696998164, 0.1302221740479581, 0.19586040114518255, 0.1562419012770988, 0.09540581493638456, 0.0959633756428957, 0.1719709049211815, 0.18254539609188214, 0.12801551667507738, 0.14887060853652656, 0.2622076019179076, 0.11325598796247505, 0.16406369250034913, 0.1681479241233319, 0.12879275309387594, 0.08473356065223925, 0.1410873793065548], [0.006192463051775121, 0.055786042285035364, 0.019840728127746843, 0.04103621715330519, 0.05504310793185141, 0.02096631196764065, 0.06113510506111197, 0.04542673683317844, 0.03160626984026749, 0.06896637351019308, 0.010813320786837721, 0.055165985322673805, 0.05115783125802409, 0.04197458125418052, 0.15041961916722357, 0.04340230269008316, 0.12043551716487855, 0.04340258841693867, 0.04354539618361741, 0.027386946931073908, 0.023320591790252365, 0.06032745171978604, 0.03240918827941641, 0.04315262565796729, 0.033176094002556056, 0.06506136312964372, 0.028884532293886878, 0.04305706301238388, 0.022385120209946763, 0.049316199219902046, 0.04502379888435826, 0.08547891440684907, 0.036494570231297985, 0.020665560332417954, 1.0158083983696997, 8.06051317602396, 18.87416861951351, 48.101094514131546, 37.69924767315388, 32.73568041622639, 29.60002787411213, 25.169851295650005, 12.861544154584408, 6.779102236032486, 1.4375632046721876, 0.28178863401990384, 0.06262317052460276, 1.6618206398561597, 3.1163320038467646, 7.567928982898593, 4.915655627846718, 6.915043741464615, 3.9646388590335846, 1.7843572958372533, 5.77598218806088, 13.327404856681824, 21.516381539404392, 32.577080726623535, 38.34286093711853, 48.461303785443306, 43.465286269783974, 49.005286395549774, 55.86392216384411, 46.47994190454483, 59.45094108581543, 54.07274387776852, 55.15387326478958, 49.76081885397434, 53.06855656206608, 47.51698225736618, 48.337631821632385, 43.85203331708908, 44.37217600643635, 42.84492015838623, 43.6428165435791, 42.72780284285545, 44.469963759183884, 41.48493133485317, 42.76250638067722, 42.31034964323044, 41.20919533073902, 38.14187832176685, 38.90440620481968, 37.855742275714874, 40.49648657441139, 42.66507960855961, 48.740132823586464, 47.028020694851875, 55.963476821780205, 36.15045078098774, 50.47236867249012, 52.437334433197975, 50.38634888827801, 47.57574610412121, 41.72636657953262, 42.085496708750725, 46.17646358907223, 49.328041076660156, 51.579188480973244, 52.30391599237919, 53.317329213023186, 51.94263517856598, 52.554326355457306, 51.89890332520008, 52.552532851696014, 49.82619434595108, 47.363440096378326, 44.533351957798004, 45.204559341073036, 46.12272687256336, 48.669661805033684, 50.876366794109344, 50.35291828215122, 49.54578459262848, 50.454673022031784, 50.282861441373825, 49.79664333164692, 48.16064111888409, 49.9170246720314, 52.38258317112923, 49.40314024686813, 45.88605277240276, 34.57302242517471, 23.590302653610706, 12.54202215000987, 5.462216399610043, 1.9670752412639558, 5.215886542573571, 7.985115721821785, 6.038977950811386, 9.533423390239477, 5.416218442842364, 1.2679133517667651, 2.9614850878715515, 0.9580995887517929, 0.27572674211114645, 0.7668807869777083, 4.1931177489459515, 16.580410301685333, 23.811264596879482, 23.10887798666954, 31.33961632847786, 30.252595357596874, 33.25331524014473, 3.864923184737563, 1.1194810853339732, 0.04943433428707067, 0.028504511865321547, 0.03612482854805421, 0.019889067916665226, 0.01904147218738217, 0.04543416202068329, 0.0757582344522234, 0.08737715004826896, 0.031150004870141856, 0.008767412600718671, 0.037351646897150204, 0.021091232119943015, 0.03746581889572553, 0.03669624144094996, 0.03358712878252845, 0.04565194154565688, 0.039222931445692666, 0.03306563645310234, 0.032694351102691144, 0.04660733793571126, 0.024812796582409646, 0.05571135625359602, 0.013166233202355215, 0.08590008321334608, 0.027225628145970404, 0.05421444067906123, 0.03591300846892409, 0.058212601725244895, 0.0938868909724988, 0.04761839169077575, 0.007975825828907546, 0.007033046877040761, 0.045463502829079516, 0.02617925187223591, 0.03767950547626242, 0.013858959409844829, 0.0615938265400473, 0.0427835741720628, 0.039710158816888, 0.02844131984602427, 0.041323324403492734, 0.09060530690476298, 0.00780050457251491, 0.07136118758353405, 0.07429345016134903, 0.02374220402998617, 0.023902587709017098, 0.039737904007779434, 0.021741963901149575, 0.031038046327012125, 0.04713248163170647, 0.0012942476837451977, 0.03885253667249344, 0.04828437275136821, 0.013145080138201592, 0.059794430126203224, 0.03658340901893098, 0.0362609198782593, 0.03308475417725276, 0.038532318503712304, 0.03524963234667666, 0.016195799689739943, 0.03635216322436463, 0.10375536963692866, 1.949592379387468, 11.104444339871407, 25.504541136324406, 53.006562888622284, 45.56518279016018, 38.5665625333786, 33.689007461071014, 30.978246219456196, 17.74730108678341, 8.95439526066184, 2.134009189903736, 0.23396331671392545, 0.1006809264072217, 0.5476114747580141, 3.024591626599431, 3.7892723316326737, 9.624433256685734, 6.595813846215606, 5.762865291908383, 5.221237605437636, 7.493593571707606, 15.528983920812607, 22.32844166457653, 34.79752577841282, 40.04045404493809, 49.79701951146126, 47.35768720507622, 51.69969141483307, 56.90997563302517, 48.979930356144905, 57.945374473929405, 56.08540087938309, 56.24203987419605, 52.980408892035484, 54.47660140693188, 50.46280838549137, 49.27255265414715, 46.93412773311138, 46.3536024838686, 45.42969346046448, 45.095687583088875, 45.25364130735397, 46.528146117925644, 44.52436164021492, 45.188744589686394, 42.84507974982262, 41.4756940305233, 40.46035051345825, 40.277599319815636, 41.64120554924011, 41.39317385852337, 44.4048922508955, 51.52982912957668, 50.19673906266689, 56.49256803095341, 39.97108496725559, 50.987218245863914, 54.37702015042305, 52.77614705264568, 49.52049694955349, 43.52383732795715, 44.79230426251888, 47.61291950941086, 52.02151134610176, 54.291220754384995, 54.979835003614426, 53.835887387394905, 54.424787387251854, 54.53949183225632, 53.6552032828331, 53.91092576086521, 51.22169226408005, 48.756023570895195, 45.856942534446716, 46.190310046076775, 47.81566523015499, 51.70217268168926, 52.886546328663826, 51.63306578993797, 50.72565548121929, 51.59840025007725, 52.00991056859493, 51.93756625056267, 49.998594895005226, 51.45428538322449, 53.680042549967766, 52.032336965203285, 46.52752295136452, 36.590182185173035, 26.002019941806793, 13.88785008341074, 7.637554071843624, 3.507826183922589, 6.258737733587623, 7.504979660734534, 10.983843561261892, 9.312580190598965, 7.693828102201223, 2.4797151144593954, 2.0369251118972898, 0.6315454083960503, 0.3058220475213602, 0.8286336483433843, 4.511320274323225, 13.993302024900913, 21.33224342018366, 21.175993904471397, 36.0668058693409, 37.950463593006134, 37.97738514840603, 6.438380219042301, 1.429252338130027, 0.028822191889048554, 0.0592183194385143, 0.019943023908126634, 0.0455063321714988, 0.08301312132971361, 0.019004032692464534, 0.04498131092987023, 0.062357860151678324, 0.033920308560482226, 0.05538345685636159, 0.030574324628105387, 0.06927870635990985, 0.02976117753860308, 0.03127935378870461, 0.03617678630689625, 0.035251539666205645, 0.1031592395156622, 0.023590766941197217, 0.04637958394596353, 0.0411480476759607, 0.054925555450608954, 0.10117320038261823, 0.04559857370622922, 0.017765844640962314, 0.03261632540670689, 0.013218626045272686, 0.030979166185716167, 0.0397163112211274, 0.04262771202775184, 0.05759269690315705, 0.13248401752207428, 0.15605933294864371, 0.14587849174859002, 0.12130206363508478, 0.1464225453673862, 0.06712600312312134, 0.13910943700466305, 0.09128431265708059, 0.09464578892220743, 0.14763145940378308, 0.12099300365662202, 0.11863127452670597, 0.149850377056282, 0.20359335729153827, 0.20427212555659935, 0.16900405084015802, 0.24470214906614274, 0.16885571036254987, 0.07785404464812018, 0.32576967088971287, 0.10218040610197932, 0.16546074097277597, 0.11658682095003314, 0.10499255207832903, 0.17055876116501167, 0.14451846160227433, 0.1650811472791247, 0.10424438558402471, 0.12952880031662062, 0.11630016640992835, 0.16463060426758602, 0.17565553454915062, 0.09102623822400346, 0.18481936625903472, 2.2299234056845307, 13.438090067356825, 30.536753609776497, 60.94001278281212, 50.061390325427055, 46.004785001277924, 41.60752035677433, 36.66772082448006, 18.850127309560776, 9.730181582272053, 2.974661593325436, 0.7032124721445143, 0.3173080296255648, 4.135100562125444, 7.6330850366503, 14.088250380009413, 17.469847574830055, 17.557942047715187, 11.230179592967033, 3.9406619081273675, 7.523573013022542, 16.795191876590252, 22.308943010866642, 34.598819240927696, 41.517476588487625, 51.30035184323788, 48.00673417747021, 54.97507385909557, 60.477034226059914, 49.29027870297432, 58.958411514759064, 56.787204220891, 59.32258777320385, 54.776979088783264, 57.762148305773735, 52.18152076005936, 52.58968725800514, 47.70632989704609, 48.92840512096882, 46.45610198378563, 48.13443012535572, 47.05101706087589, 50.19664026796818, 45.54828129708767, 47.09186486899853, 46.50260388851166, 44.050219282507896, 42.050132006406784, 42.06954896450043, 41.898067966103554, 43.501277938485146, 46.27990923821926, 54.116775915026665, 50.822189301252365, 57.45756804943085, 43.91899712383747, 51.99518635869026, 56.81697942316532, 54.537971913814545, 51.83438278734684, 46.461311504244804, 45.88751569390297, 48.95169407129288, 53.588965237140656, 56.246234849095345, 54.5201850682497, 55.00352293252945, 54.4426616281271, 55.34759446978569, 54.11286972463131, 55.88469184935093, 52.65126675367355, 51.67198710143566, 47.740531861782074, 49.58544686436653, 49.764500856399536, 52.83115670084953, 54.40528303384781, 51.571531891822815, 50.33103905618191, 53.45404587686062, 53.04827705025673, 54.851857870817184, 52.80113071203232, 53.31309624016285, 54.982776045799255, 52.481514662504196, 49.94227051734924, 36.796845495700836, 25.53328089416027, 12.656317166984081, 8.03841546177864, 3.692232188768685, 10.652134660631418, 13.6516547575593, 15.88643454015255, 21.831985004246235, 10.90028129518032, 3.5937744844704866, 5.495947664603591, 2.4698612932115793, 0.7867213035933673, 1.3033031090162694, 6.164364097639918, 24.979962185025215, 33.50361540913582, 33.654862493276596, 43.68867628276348, 46.87861651182175, 42.77253024280071, 8.509031608700752, 2.0701989764347672, 0.17558868188643828, 0.16855528898304328, 0.09926438171532936, 0.11714644482708536, 0.14632784732384607, 0.17325611173873767, 0.16450236114906147, 0.10759946453617886, 0.18875206616939977, 0.11963514058152214, 0.24530538154067472, 0.13967882754513994, 0.10654552577761933, 0.10983591913827695, 0.1053643309569452, 0.1839027545065619, 0.13702702999580652, 0.07220149171189405, 0.15263950161170214, 0.13848874921677634, 0.13420691335340962, 0.2718679007375613, 0.09088673672522418, 0.12379539039102383, 0.15400440024677664, 0.10134605399798602, 0.0746564420114737, 0.10910992801655084, 0.20741596701554954, 0.153120546892751], [0.038219870621105656, 0.030135958404571284, 0.06368364760419354, 0.019198903974029236, 0.06275184408877976, 0.056095543841365725, 0.04492100400966592, 0.048274602377205156, 0.042021603730972856, 0.02716136001254199, 0.012834071094403043, 0.03618969225499313, 0.017716155998641625, 0.013313818544702372, 0.04077792007592507, 0.0303765070202644, 0.03736230042704847, 0.03288351341325324, 0.04839854846068192, 0.003305346708657453, 0.06642178661422804, 0.013049344943283359, 0.05097697729070205, 0.025635287311160937, 0.06486182188382372, 0.036212049453752115, 0.061764093770761974, 0.05572047353780363, 0.014515307393594412, 0.03993405363871716, 0.01467773847252829, 0.017763341747922823, 0.020412920275703073, 0.12429003923898563, 0.09460039174882695, 4.2523418460041285, 20.92475138604641, 37.92972810566425, 43.50487254559994, 39.57506261765957, 35.318105444312096, 28.693440221250057, 17.98222918063402, 8.400353640317917, 5.13830135576427, 0.7819047651719302, 0.042095851895282976, 0.6465473002754152, 1.4018189976923168, 3.963383976370096, 3.7341277906671166, 2.2838992718607187, 2.9033971298485994, 2.541053560562432, 3.6908056028187275, 8.863601982593536, 15.40802026167512, 24.96694028377533, 29.73277185112238, 39.63568456470966, 43.963093757629395, 44.03506189584732, 55.07518328726292, 50.00103056430817, 55.4889202862978, 50.54808720946312, 53.94618406891823, 51.143682450056076, 52.12266571819782, 49.8227783292532, 50.12927748262882, 48.05669769644737, 46.423537731170654, 43.03576111793518, 43.79411682486534, 43.901027888059616, 44.802407920360565, 46.40775717794895, 47.450356632471085, 44.81147803366184, 45.21553315222263, 40.602820068597794, 42.22252115607262, 39.51265476644039, 43.96685175597668, 48.055705949664116, 49.08464893698692, 47.526033371686935, 55.853111743927, 35.18893137574196, 46.6360679268837, 53.94952028989792, 47.32773721218109, 46.058529317379, 39.60771806538105, 39.56558592617512, 43.436954990029335, 48.571570068597794, 51.2374272197485, 51.158611848950386, 50.39997115731239, 50.719526410102844, 49.27918329834938, 50.19629068672657, 52.28788085281849, 49.917807430028915, 47.81454049050808, 45.258041471242905, 43.31137552857399, 45.730937495827675, 48.92326399683952, 49.646308198571205, 51.05884440243244, 49.73775029182434, 49.350463673472404, 50.25821976363659, 49.950048699975014, 48.23896251618862, 52.49584749341011, 54.412852227687836, 50.653584748506546, 39.5666840672493, 33.282303884625435, 14.587533138692379, 7.670449381694198, 9.715623613446951, 2.0244717551395297, 5.762885715812445, 3.6072566360235214, 7.532424638047814, 7.058342602103949, 7.157156299799681, 3.2162177190184593, 1.5103796473704278, 0.4189050185959786, 0.20204793865559623, 2.508833664469421, 5.864266650751233, 14.198376070708036, 24.79131370782852, 29.633863158524036, 33.66647087037563, 31.067108251154423, 23.96915752440691, 2.8135015536099672, 0.12344153437879868, 0.046071637189015746, 0.025190301130351145, 0.06071650037483778, 0.02715089201956289, 0.02446309845254291, 0.10120814069523476, 0.021423133548523765, 0.05672605395375285, 0.02072834973660065, 0.03928713464119937, 0.02644008523930097, 0.0711026530188974, 0.04962325168889947, 0.03688227188831661, 0.05170768476091325, 0.05923119570070412, 0.06399164631147869, 0.08648547445773147, 0.022040793373889755, 0.03155951824737713, 0.11382870332454331, 0.023606157228641678, 0.016124503417813685, 0.09382186399307102, 0.03240059049858246, 0.04002065114036668, 0.06137377233244479, 0.04017899576865602, 0.022078260699345265, 0.01628317273571156, 0.019480367191135883, 0.10467511325259693, 0.046852606610627845, 0.03219652957341168, 0.03840773417323362, 0.014853874235996045, 0.03456026992353145, 0.01886439018562669, 0.03557399169949349, 0.015037728335300926, 0.029861784933018498, 0.031209918452077545, 0.01922142444527708, 0.03926321893231943, 0.02667791944986675, 0.04195332614472136, 0.03647704070317559, 0.09443959803320467, 0.03452207529335283, 0.02984708484291332, 0.029692295101995114, 0.0336851182510145, 0.06805689379689284, 0.040391884540440515, 0.04705231112893671, 0.04095232849067543, 0.051601294180727564, 0.051848989678546786, 0.03964887226175051, 0.0824420757999178, 0.04746470774989575, 0.03029848503501853, 0.013911435744375922, 0.10537308829952963, 0.17246247385628521, 6.191622884944081, 23.44518084079027, 45.72259694337845, 47.66506791114807, 42.921904027462006, 41.618501767516136, 29.58773173391819, 19.584118723869324, 9.045899100601673, 4.5251434575766325, 0.35850675485562533, 0.19230441539548337, 0.6571988412179053, 1.1447890335693955, 3.2126613473519683, 6.655717631801963, 5.590322725474834, 6.0018962156027555, 6.490925224497914, 5.982711045071483, 9.4939967058599, 18.203643299639225, 28.73958494514227, 35.000282898545265, 43.541050404310226, 45.03101885318756, 50.38399301469326, 56.97210229933262, 51.25711016356945, 55.13599142432213, 51.83002822101116, 55.28323732316494, 54.99274291098118, 54.09040533006191, 51.6993722319603, 52.37239591777325, 49.73567180335522, 47.88902409374714, 44.86701585352421, 45.878251791000366, 46.412244737148285, 46.41833581030369, 48.633723333477974, 47.66077794134617, 46.77169784903526, 47.16202050447464, 42.27514833211899, 43.815334886312485, 41.929290890693665, 45.32058231532574, 49.39129628241062, 51.27983674407005, 50.80829344689846, 56.157395616173744, 37.08523482084274, 49.319062158465385, 56.48352071642876, 49.467960968613625, 48.57240602374077, 41.0409289598465, 41.38800993561745, 46.64654016494751, 50.54873317480087, 52.40774542093277, 53.6702124774456, 52.882944121956825, 52.69390046596527, 53.00104558467865, 52.879376113414764, 54.52195577323437, 52.04177185893059, 48.63849587738514, 47.805215790867805, 45.60612179338932, 48.15969116985798, 50.73969192802906, 52.96777456998825, 51.96915775537491, 50.53026996552944, 51.65404066443443, 51.21373929083347, 52.15483859181404, 49.950265288352966, 54.033218398690224, 53.967155143618584, 51.95446014404297, 42.45879627764225, 33.61597917973995, 17.684705145657063, 11.807523462921381, 9.091103374958038, 4.629068356007338, 9.289250392466784, 7.585434643551707, 7.619251878932118, 7.250240854918957, 4.051348306238651, 2.9366163723170757, 1.7029397771693766, 0.44497942726593465, 0.15601352759404108, 2.4363497039303184, 6.2159050069749355, 16.721620224416256, 25.069031305611134, 32.118855714797974, 39.654413759708405, 36.72552712261677, 28.729426190257072, 3.501380542293191, 0.301761727896519, 0.05151128651050385, 0.033712425574776717, 0.038785027209087275, 0.07825965803931467, 0.01649476274906192, 0.1034529964090325, 0.07011262059677392, 0.03431909790378995, 0.03234910771425348, 0.03482474909105804, 0.01907589856273262, 0.06173734676849563, 0.046437311902991496, 0.03543966668075882, 0.020833740272792056, 0.026713503575592767, 0.02732422246481292, 0.014683541139675071, 0.03661956645373721, 0.04037700819026213, 0.030596065844292752, 0.06189973239088431, 0.04015724713099189, 0.039190455063362606, 0.0673960855056066, 0.06757485403795727, 0.042860045068664476, 0.03660203321487643, 0.05873016067198478, 0.011813983546744566, 0.07689579098951072, 0.2564830903429538, 0.11287548884865828, 0.0983333945623599, 0.18730612500803545, 0.1381441848934628, 0.2984343533171341, 0.08563587864045985, 0.2863097976660356, 0.07883905273047276, 0.1231456252571661, 0.11232655931962654, 0.12808855884941295, 0.14600103517295793, 0.12619496905244887, 0.1366777010844089, 0.13370446453336626, 0.19691517110913992, 0.15440331946592778, 0.10983410829794593, 0.14263221906730905, 0.12882212729891762, 0.1407764491159469, 0.17185708915349096, 0.14395618083653972, 0.21789335558423772, 0.17388223204761744, 0.12746652035275474, 0.09914272886817344, 0.18964495888212696, 0.10154060801141895, 0.1166639152506832, 0.16461259976495057, 0.284303980297409, 0.372432770091109, 6.73030667938292, 29.056354947388172, 51.60269781947136, 55.8860369771719, 51.70039817690849, 48.72969478368759, 39.41657692193985, 27.550803534686565, 12.811316549777985, 6.7241134867072105, 1.2958775949664414, 0.5886072374414653, 1.7309774039313197, 5.136590972542763, 10.653282199054956, 9.110155552625656, 7.703800667077303, 8.687590677291155, 6.802152749150991, 5.970024950802326, 11.451687756925821, 21.50728102773428, 31.864180080592632, 40.61177238821983, 45.65152555704117, 49.147052988409996, 53.73634032905102, 61.494634822010994, 51.747485250234604, 55.77926270663738, 50.69943688809872, 57.263474464416504, 56.11595883965492, 56.02828994393349, 53.53057377040386, 54.549565091729164, 53.20010170340538, 50.29499799013138, 47.28016756474972, 46.55590742826462, 48.56388308107853, 48.283876106143, 51.18373990058899, 51.23184911906719, 47.860654816031456, 49.26841087639332, 44.084071666002274, 46.45947240293026, 42.69640512764454, 47.77352549135685, 53.10698390007019, 54.105175137519836, 53.35496239364147, 59.20496128499508, 40.892919301986694, 52.49671384692192, 58.43567356467247, 52.41521202027798, 50.01294292509556, 43.90575483441353, 43.65179166197777, 48.333900421857834, 53.019778579473495, 54.421238377690315, 55.859313011169434, 56.68169908225536, 55.290760919451714, 54.09054972231388, 54.51608508825302, 57.67352566123009, 53.97761978209019, 50.79148314893246, 49.4741128385067, 47.78587482869625, 49.20492768287659, 53.063107654452324, 53.8751582801342, 51.85571104288101, 51.113230884075165, 50.22583030164242, 53.616927936673164, 53.890520855784416, 51.21601916849613, 58.19429151713848, 56.78397439420223, 55.490915179252625, 43.17073367536068, 37.19284504652023, 18.661036156117916, 15.55668918415904, 15.926586035639048, 6.506433142349124, 13.380520306527615, 13.275116812437773, 20.898029319941998, 12.899463269859552, 15.84525614976883, 8.710819780826569, 3.4176275739446282, 1.184082250110805, 0.5425773980095983, 3.7775069754570723, 9.271631687879562, 21.90811961889267, 38.170752972364426, 42.28202976286411, 49.28551755845547, 44.83352445065975, 31.792348735034466, 4.817345403134823, 0.498763908399269, 0.12731305905617774, 0.18379198154434562, 0.13700293988222256, 0.2246297855162993, 0.08380101498914883, 0.2784366498235613, 0.35052264109253883, 0.07845945161534473, 0.15976926981238648, 0.22607750783208758, 0.12417986741638742, 0.16389834199799225, 0.18692182609811425, 0.115641332231462, 0.1137820073927287, 0.1486734941136092, 0.22037043672753498, 0.2798527863342315, 0.24422162328846753, 0.28313690854702145, 0.3171404229942709, 0.19203120114980265, 0.16880582319572568, 0.1363183680223301, 0.1443306091823615, 0.20629704580642283, 0.12168140499852598, 0.2113964018644765, 0.11577675191801973, 0.12605241732671857], [0.06041447224561125, 0.055976874427869916, 0.07632840424776077, 0.043084533608634956, 0.021667821492883377, 0.02909691826062044, 0.03379065165063366, 0.07949239501613192, 0.04578535372274928, 0.05420064044301398, 0.005332331056706607, 0.019126147526549175, 0.07100529808667488, 0.030521188709826674, 0.05967433949990664, 0.01091748956241645, 0.028035587711201515, 0.05518286918231752, 0.011463589653430972, 0.0610739038529573, 0.01591888583789114, 0.02524396582884947, 0.030342141872097272, 0.031355383107438684, 0.04233986262988765, 0.025788737475522794, 0.04982105630915612, 0.03398978842596989, 0.03148078751110006, 0.06154664821224287, 0.036474016451393254, 0.061004939780104905, 0.01474877313739853, 0.06691169313853607, 0.12888564029708505, 1.2695214967243373, 12.731149401515722, 32.39580385386944, 47.486834675073624, 42.61513128876686, 36.402118876576424, 30.50224006175995, 20.15522427856922, 20.45490089803934, 8.105959687381983, 0.9878486080560833, 0.47686924575828016, 0.3387024253606796, 1.5049490262754261, 0.590018683578819, 10.238877385854721, 4.652376305311918, 3.465922507457435, 8.221093509346247, 2.2638543974608183, 4.072866551578045, 7.340130256488919, 16.698126085102558, 20.007991679012775, 33.28374020755291, 39.12055000662804, 32.9776818305254, 54.8490384221077, 47.79988467693329, 51.211596205830574, 53.91078136861324, 51.508341282606125, 50.07875919342041, 54.66797053813934, 53.85055460035801, 49.939914643764496, 51.05555757880211, 47.65277557075024, 47.47027136385441, 46.176083609461784, 46.59505292773247, 45.863459184765816, 48.98492708802223, 48.43494459986687, 46.2865474820137, 43.67941997945309, 42.91194476187229, 42.214587181806564, 42.30778858065605, 49.903546795248985, 50.93854285776615, 50.4992750287056, 50.978832095861435, 68.58839437365532, 43.02332058548927, 43.08175005018711, 54.415956661105156, 48.8126215338707, 49.31057721376419, 39.896080791950226, 39.21292304992676, 41.621655598282814, 44.518114775419235, 46.030133441090584, 48.95959384739399, 45.24344265460968, 47.18484587967396, 48.15954677760601, 47.65683755278587, 47.344745099544525, 46.36471688747406, 44.4554827362299, 43.9834226667881, 45.688277184963226, 50.09952887892723, 49.78226490318775, 52.34909176826477, 53.227331042289734, 50.832281559705734, 51.256076619029045, 51.26590669155121, 50.85460916161537, 49.69495318830013, 47.96366348862648, 51.93139158189297, 48.930973783135414, 34.2255424708128, 26.871578581631184, 17.063409984111786, 13.109026774764061, 26.523530557751656, 21.337641030550003, 2.7518614986911416, 8.281201533973217, 8.694097828119993, 6.427301438525319, 4.611702337861061, 1.8787245196290314, 1.5563208446837962, 0.5563798604998738, 0.6302584649529308, 2.9597193701192737, 11.007657833397388, 15.643274188041687, 24.09488707780838, 31.96378603577614, 36.13469682633877, 23.377303183078766, 13.911932241171598, 1.5565700875595212, 0.07799898608936928, 0.01651109370868653, 0.018780288155539893, 0.05837113560119178, 0.045106811812729575, 0.011614183476922335, 0.02261405978060793, 0.030841787229292095, 0.0386396812973544, 0.027582315451581962, 0.0257463756861398, 0.052778433164348826, 0.04516311855695676, 0.02556480740167899, 0.05286477833578829, 0.028078838222427294, 0.03834864437521901, 0.0430613080970943, 0.062354305264307186, 0.0550751130504068, 0.02401093199296156, 0.02832046666298993, 0.04795426175405737, 0.0734724270296283, 0.031897028457024135, 0.04846066251047887, 0.007864128892833833, 0.03991843885160051, 0.05128214099386241, 0.025078849103010725, 0.03617254122218583, 0.04325881956901867, 0.08672999727423303, 0.029576332672149874, 0.04299115658795927, 0.041709118740982376, 0.07775359496008605, 0.022196898571564816, 0.04356540819571819, 0.06102356768678874, 0.013733326795772882, 0.06036242171830963, 0.01564367521496024, 0.06800222719903104, 0.03970042183937039, 0.11513954392285086, 0.028069533545931336, 0.01566332357469946, 0.015316412209358532, 0.024459181768179405, 0.049593313451623544, 0.028503912581072655, 0.02758558461209759, 0.032600172562524676, 0.027959265244135167, 0.019997480849269778, 0.02092247701511951, 0.11090761749073863, 0.015913846655166708, 0.07579768702271394, 0.09010929992655292, 0.0320444783574203, 0.018839043987100013, 0.015169941943895537, 0.04183176606602501, 0.0880216681980528, 2.3595247138291597, 18.179394900798798, 38.969967886805534, 53.02221804857254, 48.33718344569206, 40.62627241015434, 35.15460781753063, 21.995566226541996, 18.382342010736465, 8.378869593143463, 1.2549625779502094, 0.313187506981194, 0.14611948194215074, 2.210580068640411, 3.164798878133297, 6.103376895189285, 5.487498817965388, 8.143347781151533, 6.742557696998119, 4.235088396817446, 6.108902748674154, 10.376914478838444, 19.65292163193226, 25.540789291262627, 36.97145372629166, 43.007433637976646, 40.61595216393471, 56.168844401836395, 50.327588841319084, 53.78873571753502, 54.58587974309921, 53.19366864860058, 52.07641839981079, 58.1585468351841, 55.08713744580746, 53.544545620679855, 53.1445524841547, 50.53734138607979, 49.267970100045204, 48.81491281092167, 47.83860839903355, 47.300652265548706, 51.24203257262707, 50.60555152595043, 48.42913471162319, 46.73926658928394, 45.091382414102554, 43.45796026289463, 44.11570876836777, 52.403143867850304, 52.61829972267151, 52.53704488277435, 53.69428798556328, 62.730852887034416, 42.32545383274555, 45.87822899222374, 55.31113922595978, 51.69846408069134, 50.93047969043255, 43.421691209077835, 41.095277443528175, 45.0945932418108, 46.49636082351208, 48.08863118290901, 51.35125771164894, 49.94524195790291, 49.36458371579647, 49.916937276721, 49.71667282283306, 49.60888400673866, 48.85460928082466, 47.918578907847404, 46.30692578852177, 46.95900499820709, 52.49854534864426, 51.54937528073788, 53.21763016283512, 54.51878294348717, 51.16699039936066, 51.56930901110172, 52.85904720425606, 53.34149971604347, 50.71774050593376, 50.08331134915352, 54.47330318391323, 50.51483899354935, 38.735471069812775, 31.605269573628902, 17.350093200802803, 16.374487951397896, 26.259262338280678, 15.450088754296303, 4.967144764959812, 5.79948297701776, 2.6560520147904754, 4.4546914380043745, 3.356545614078641, 1.6021095751784742, 0.7136856601573527, 0.3498565487097949, 0.5435323936399072, 3.22053927462548, 12.354374919086695, 17.34984051436186, 26.909257359802723, 34.84453305602074, 42.94306889176369, 28.568729013204575, 17.31895387172699, 2.0807925704866648, 0.06192808985360898, 0.07723280024947599, 0.02378048771788599, 0.04594726808136329, 0.02805588359478861, 0.048125438115675934, 0.02885002613766119, 0.08737284559174441, 0.07851940230466425, 0.029533004235418048, 0.027886343668797053, 0.10872897619265132, 0.05828253059007693, 0.032312004041159526, 0.054648945879307576, 0.04456945607671514, 0.053530035802396014, 0.030423542484641075, 0.03608871564210858, 0.04304903297452256, 0.029477714233507868, 0.04944239401083905, 0.06325531707261689, 0.04259447494405322, 0.04359255966846831, 0.051113873851136304, 0.020292369517846964, 0.013458739576890366, 0.02164010042179143, 0.06109579720941838, 0.09059423406142741, 0.22427362884627655, 0.21420149743789807, 0.13842005602782592, 0.17552184406667948, 0.14725774351973087, 0.20225499785738066, 0.1486302269040607, 0.13161252834834158, 0.1400296259089373, 0.08116398617858067, 0.08897246327251196, 0.20055335713550448, 0.19691221736138687, 0.16829338506795466, 0.21640862978529185, 0.10882930713705719, 0.14330960693769157, 0.15665876562707126, 0.09558853169437498, 0.11407004974898882, 0.10889947719988413, 0.11181712688994594, 0.10927917479421012, 0.08629523974377662, 0.14873296982841566, 0.11640256794635206, 0.1950577535899356, 0.16408551164204255, 0.1948281330987811, 0.21580241387709975, 0.20089734258363023, 0.09537799181998707, 0.1458398110116832, 0.2440445320098661, 0.18921253911685199, 2.675357828848064, 19.628082364797592, 45.4032126814127, 61.36904776096344, 55.54267980158329, 49.61472049355507, 43.63074839115143, 29.458920545876026, 25.831897370517254, 11.283375788480043, 1.6809414513409138, 0.7190462818834931, 0.43262064980808645, 3.4833889827132225, 6.72747440636158, 19.22706328332424, 13.228965438902378, 10.62057165428996, 16.069107837975025, 4.768630117177963, 5.782853169366717, 10.591635257005692, 21.586666367948055, 26.522335521876812, 39.380095079541206, 45.69679252803326, 41.815559193491936, 59.58191625773907, 52.53057383000851, 52.55511291325092, 55.67773595452309, 54.14772905409336, 51.795172691345215, 59.692653715610504, 58.716961070895195, 55.53888760507107, 54.7864405810833, 52.11376279592514, 52.07495927810669, 49.382587149739265, 50.12683421373367, 49.26147244870663, 53.99590440094471, 52.65617609024048, 51.27805083990097, 47.520253881812096, 46.75810597836971, 46.18840254843235, 46.77325576543808, 55.18910497426987, 55.578477680683136, 54.07414220273495, 55.83379738032818, 63.05982023477554, 47.11141861975193, 48.061732426285744, 56.86131164431572, 54.80472519993782, 52.66206957399845, 43.56187328696251, 43.17581780254841, 47.039803862571716, 48.03310476243496, 49.8404473811388, 53.360023722052574, 50.58169640600681, 50.30626818537712, 50.590994507074356, 51.29028998315334, 51.75450347363949, 49.54177960753441, 49.584857895970345, 47.49600738286972, 50.00007301568985, 54.381002336740494, 52.94695928692818, 54.89881955087185, 54.52486641705036, 49.39981162548065, 52.88199037313461, 51.614484786987305, 54.13146212697029, 52.341978549957275, 52.46828757226467, 56.12033620476723, 52.9118187725544, 42.09491640329361, 35.10863408446312, 20.066445842385292, 19.171267077326775, 31.683102697134018, 29.859536848962307, 11.193302571773529, 18.143564723432064, 17.802067548036575, 15.85998510941863, 12.82182203605771, 4.907962940633297, 6.096242778003216, 1.0637134965509176, 0.880689489422366, 4.314573956653476, 17.27676473557949, 24.37340073287487, 38.341424614191055, 43.73649291694164, 53.48156780004501, 36.133047714829445, 19.2235104739666, 2.4688778584823012, 0.10789491352625191, 0.14374796388437971, 0.12094529840396717, 0.16695713333319873, 0.18446880538249388, 0.15912450675386935, 0.11369716507033445, 0.09905249113216996, 0.16428571339929476, 0.13971528183901682, 0.1275543906376697, 0.2044918606407009, 0.1668094311025925, 0.13739583286223933, 0.1429299687151797, 0.13455818669172004, 0.20474797580391169, 0.105413817364024, 0.12249047213117592, 0.15335332893300802, 0.09037452866323292, 0.12002304632915184, 0.15662061923649162, 0.24373400257900357, 0.11327575877658091, 0.22334368812153116, 0.1461016555549577, 0.07013839538558386, 0.17388641776051372, 0.12911836296552792, 0.14649472665041685], [0.014457761262747226, 0.06478515060734935, 0.11044165265047923, 0.03210734197637066, 0.06991141694015823, 0.012679076335189166, 0.005095082678963081, 0.04196710040559992, 0.028799953433917835, 0.03898879498592578, 0.02742219152423786, 0.04591425364196766, 0.07259693025844172, 0.03026071713975398, 0.023326510417973623, 0.03543304672348313, 0.05225464017712511, 0.01913921118102735, 0.02866464878024999, 0.051322424769750796, 0.0916472302924376, 0.039280366254388355, 0.03626969577453565, 0.02243559738417389, 0.010644052672432736, 0.05767089329310693, 0.056984339898917824, 0.06701269201585092, 0.027774034460890107, 0.050072577578248456, 0.06380989434546791, 0.03876173490425572, 0.06630733259953558, 0.1091595331672579, 0.04530785961833317, 0.3851420490536839, 8.609056491404772, 26.502453088760376, 47.86385044455528, 42.827292904257774, 40.68225860595703, 27.373761534690857, 27.32379611581564, 18.406797498464584, 9.587364345788956, 3.2657670602202415, 0.37833708920516074, 0.1414426157134585, 1.0047001694329083, 2.4723753333091736, 1.3054770673625171, 3.3228872576728463, 6.584532726556063, 6.079947352409363, 3.0038810754194856, 1.8363552493974566, 3.595479167997837, 8.772044945508242, 16.072668246924877, 19.416156336665154, 36.78864933550358, 33.49482648074627, 42.29249060153961, 51.78660795092583, 44.50945883989334, 53.58714133501053, 50.8961371332407, 53.443246856331825, 50.47666624188423, 56.45871564745903, 53.215943053364754, 53.32596234977245, 52.0528444647789, 52.267692536115646, 47.48160235583782, 47.87049628794193, 46.39775611460209, 48.73770095407963, 47.98951730132103, 48.13648961484432, 45.21528996527195, 44.756719172000885, 40.541422963142395, 47.470096573233604, 50.6964236497879, 53.632628694176674, 53.597111999988556, 51.28091208636761, 54.10019740462303, 31.171832531690598, 44.78685535490513, 53.85794520378113, 50.019816756248474, 47.58219815790653, 41.142748296260834, 39.31019023060799, 39.88518677651882, 40.69761738181114, 42.37732484936714, 45.72882100939751, 41.866734847426414, 42.89301797747612, 41.86606988310814, 43.877556547522545, 43.24810512363911, 45.40153317153454, 45.287961065769196, 46.14867568016052, 48.074689731001854, 49.99221123754978, 51.004207134246826, 54.4704457372427, 50.113664120435715, 50.48567555844784, 52.947635650634766, 49.955444410443306, 50.245258659124374, 54.3025441467762, 46.52838170528412, 45.52485175430775, 38.47781449556351, 22.38487433642149, 17.0476009324193, 14.293893445283175, 2.3680357821285725, 11.251542046666145, 27.669182382524014, 13.090078141540289, 5.599968507885933, 1.0750490007922053, 2.526117037050426, 1.2101037288084626, 1.3459070166572928, 0.26260919286869466, 0.27681942097842693, 1.1394156469032168, 6.46703353151679, 15.548350531607866, 22.212348394095898, 27.467555701732635, 38.61591808497906, 34.82098191976547, 22.793770395219326, 8.515346869826317, 0.45777734834700823, 0.04366413981188089, 0.08899716936866753, 0.045647169536096044, 0.053760595110361464, 0.01460785691961064, 0.04453136905794963, 0.016533623456780333, 0.07004705927101895, 0.014564502507710131, 0.025438709089939948, 0.05290493594657164, 0.01055192988133058, 0.0591130161046749, 0.056846986917662434, 0.011008323799615027, 0.026901048004219774, 0.037591917207464576, 0.05065299272246193, 0.1063593357685022, 0.045600072844536044, 0.07424175215419382, 0.06009061755321454, 0.01754807810357306, 0.04509935693931766, 0.03498769503494259, 0.09010817186208442, 0.02090690304612508, 0.020718944870168343, 0.09633266090531833, 0.02597877180960495, 0.0552090335986577, 0.06601110435440205, 0.04703439197328407, 0.08239765083999373, 0.061074501281837, 0.037244176492094994, 0.013872898798581446, 0.12782693695044145, 0.01426463495590724, 0.011887231667060405, 0.052920765956514515, 0.06611874545342289, 0.008885007755452534, 0.02999202628416242, 0.06758847244782373, 0.011198100237379549, 0.06864047420094721, 0.01258308695469168, 0.011207899369765073, 0.026501271604502108, 0.040840861620381474, 0.029152347415219992, 0.017573409459146205, 0.030426557459577452, 0.03502801962895319, 0.047205705632222816, 0.03185523069987539, 0.04271240220987238, 0.02255394767416874, 0.04349711205577478, 0.01879103816463612, 0.034342661092523485, 0.041125998468487523, 0.06256373933865689, 0.07787512906361371, 0.019777157613134477, 0.5870522302575409, 11.670929342508316, 32.24723182618618, 53.80846805870533, 48.117361441254616, 46.66622690856457, 34.90417465567589, 31.054994501173496, 29.19055424630642, 11.701889131218195, 3.5408129263669252, 0.184965064690914, 0.31865113880485296, 0.6675344647374004, 2.1343402471393347, 3.8747739186510444, 4.808083400130272, 8.960492983460426, 8.828339874744415, 4.536624541506171, 3.308767690323293, 5.407012011855841, 12.898120991885662, 21.65370997041464, 25.2229705452919, 39.71153609454632, 38.547202572226524, 48.80572110414505, 53.30218322575092, 48.136930391192436, 54.24878463149071, 50.88457815349102, 54.12686437368393, 53.53573389351368, 57.44651064276695, 55.23873791098595, 54.39700327813625, 53.51514279842377, 53.795316964387894, 50.918221548199654, 50.24412252008915, 48.81487861275673, 51.34096786379814, 50.71192301809788, 50.05013532936573, 47.88943827152252, 46.40191309154034, 44.067762941122055, 49.620727971196175, 51.83696284890175, 56.7002534866333, 53.809159621596336, 54.4203682243824, 56.49739757180214, 34.71211016178131, 49.40321624279022, 54.68189679086208, 53.04187439382076, 47.711239233613014, 43.58263537287712, 40.415737107396126, 43.12439516186714, 43.47363442182541, 45.32910905778408, 48.16804692149162, 45.2064174413681, 45.735577046871185, 45.12539818882942, 44.67261828482151, 46.5942207723856, 45.910132080316544, 47.93801486492157, 48.18871021270752, 50.632017105817795, 51.8232037872076, 53.13333548605442, 55.377046689391136, 51.40254355967045, 52.46449537575245, 55.06619296967983, 51.45244248211384, 51.82209424674511, 55.33335283398628, 49.82550658285618, 49.151605144143105, 43.56147810816765, 24.969746433198452, 22.723540663719177, 17.338775508105755, 4.532450940459967, 16.977830976247787, 27.544972747564316, 15.691082272678614, 5.588715886697173, 2.9466404719278216, 0.907730144681409, 1.0140058700926602, 0.3256672841962427, 0.37175133009441197, 0.257831186754629, 1.2022787611931562, 6.939683044329286, 17.907578386366367, 22.459061555564404, 29.968543499708176, 43.40600185096264, 43.39783988893032, 27.722913399338722, 9.998636227101088, 0.5112278927117586, 0.01239557870576391, 0.06955132688744925, 0.058971024700440466, 0.022981359797995538, 0.0015133715396586922, 0.030027296852495056, 0.035979504900751635, 0.011926210190722486, 0.051025131542701274, 0.021430080050777178, 0.04478413342440035, 0.03126429561234545, 0.03793784708250314, 0.07803365180734545, 0.005710503537557088, 0.02758949573035352, 0.026419167807034682, 0.02825833591487026, 0.0625620769278612, 0.030431010345637333, 0.0326172308268724, 0.06025295122526586, 0.04753471825097222, 0.02780205053568352, 0.04223552408802789, 0.06604473848710768, 0.10628642718074843, 0.011094211622548755, 0.03590883017750457, 0.042569189972709864, 0.010359520674683154, 0.1542253969819285, 0.2700815809657797, 0.22985698393313214, 0.16459176025819033, 0.15025694039650261, 0.12911138677736744, 0.1485597377177328, 0.16934929793933406, 0.12787704676156864, 0.11808180322987027, 0.18852832348784432, 0.07933900793432258, 0.15695608482928947, 0.17803319758968428, 0.10263935022521764, 0.1422073395224288, 0.16147376038134098, 0.0639602163573727, 0.07887477971962653, 0.12402849897625856, 0.16361099726054817, 0.18528001732192934, 0.21366531058447435, 0.11704771692166105, 0.14063751907087862, 0.11823130145785399, 0.1805709270411171, 0.12242163051269017, 0.1257495765457861, 0.17046455293893814, 0.1481121187680401, 0.1730246061924845, 0.15499803208513185, 0.2221191889839247, 0.1530678098788485, 0.7452894549351186, 13.195932861417532, 35.00587619841099, 62.44460664689541, 53.56237806379795, 52.35302455723286, 38.8216732442379, 36.94930471479893, 26.455854289233685, 13.959290999919176, 5.262625934556127, 0.6801859452389181, 0.9428716090042144, 1.8350855237804353, 5.676935277879238, 7.2052042465657, 10.657145641744137, 15.884321853518486, 9.863037653267384, 7.2226358111947775, 4.097307315096259, 5.265539903193712, 11.69943256303668, 20.764580480754375, 27.200583927333355, 40.80181159079075, 40.41587769985199, 51.03847749531269, 57.56584323942661, 47.91339598596096, 54.2624980956316, 51.248769611120224, 55.2089437097311, 53.6828999966383, 58.87068182229996, 56.75898313522339, 57.375123873353004, 57.23416283726692, 56.95401147007942, 51.85614041984081, 53.4120961278677, 49.66471441090107, 52.766081392765045, 53.2551721483469, 52.06651613116264, 48.48996564745903, 48.060379698872566, 44.941180273890495, 49.79895360767841, 53.42356011271477, 60.295137986540794, 57.05195501446724, 53.445484936237335, 57.65280157327652, 41.051131412386894, 48.98688778281212, 55.5585515499115, 54.30972956120968, 51.63870848715305, 44.94738154113293, 42.88756147027016, 43.322622925043106, 44.44876849651337, 47.082224786281586, 50.13925954699516, 46.4038547873497, 46.06977291405201, 46.108838617801666, 46.94067858159542, 48.04568208754063, 48.77394340932369, 49.68381978571415, 50.474576354026794, 52.330419570207596, 53.60105238854885, 55.92310778796673, 55.79723574221134, 49.677230939269066, 51.97439007461071, 53.20176221430302, 51.98876470327377, 53.02225984632969, 56.488365456461906, 51.99474178254604, 51.47742994129658, 48.61157812178135, 27.3644083365798, 22.436819449067116, 19.521862864494324, 4.563572220504284, 14.295502658933401, 35.43332666158676, 22.44049195200205, 16.0677570104599, 8.991903997957706, 8.318236246705055, 5.343089466914535, 3.5505425417795777, 1.312246760353446, 0.6689569540321827, 1.8637447734363377, 8.36121479049325, 23.186469823122025, 31.644734255969524, 40.57811759412289, 51.48492693901062, 52.18339025974274, 33.51684629917145, 11.0908249206841, 0.5797478347085416, 0.13598306570202112, 0.19297947292216122, 0.14262721699196845, 0.160020531329792, 0.09419467445695773, 0.1256487038335763, 0.08672720679896884, 0.122047595505137, 0.15797192172612995, 0.10018357614171691, 0.1371688544168137, 0.06521239018184133, 0.11945477643166669, 0.1942777563817799, 0.0921357935294509, 0.11658679868560284, 0.0796953946701251, 0.17682443198282272, 0.21349681337596849, 0.19136968039674684, 0.20990845514461398, 0.17025709297740832, 0.12175705211120658, 0.14705816516652703, 0.10739440913312137, 0.22977991931838915, 0.15363798709586263, 0.25387067114934325, 0.14527629828080535, 0.0937194624566473, 0.11784382615587674], [0.02003769412112888, 0.0478185637621209, 0.020830903413298074, 0.05279936915030703, 0.09838471407420002, 0.04360555096354801, 0.0303243414600729, 0.057163639066857286, 0.018657822656678036, 0.016045932243287098, 0.031414829136338085, 0.02509458634449402, 0.07176151688327082, 0.0317266647471115, 0.04245836506015621, 0.027476360883156303, 0.043906632854486816, 0.05025793638196774, 0.035141865082550794, 0.06246017263038084, 0.06719680401147343, 0.0937670044368133, 0.02432425560982665, 0.03833740825939458, 0.030707428813911974, 0.05042823700932786, 0.028320529745542444, 0.0335617324890336, 0.007673924328628345, 0.0775621653883718, 0.03983694361522794, 0.05312934656103607, 0.05981925867672544, 0.02541692891099956, 0.028774603524652775, 0.1935872621834278, 1.9990178709849715, 19.707955978810787, 34.72306877374649, 45.38208581507206, 31.724837757647038, 21.823957934975624, 17.01490368694067, 18.78624703735113, 15.316394828259945, 5.510598253458738, 0.4697139625204727, 0.23558311339002103, 0.9929897915571928, 2.0002820156514645, 3.8626181334257126, 3.7470777332782745, 8.874706886708736, 9.370803516358137, 4.731948785483837, 1.6902785003185272, 2.551264800131321, 4.553949711844325, 13.216362465173006, 18.361355736851692, 27.90034107863903, 26.56833965331316, 25.55917840451002, 47.56818450987339, 44.195447489619255, 48.3791483938694, 50.5518414080143, 51.805059760808945, 55.17610587179661, 52.80480891466141, 55.447627902030945, 53.85911174118519, 52.42305859923363, 50.4654910415411, 51.46036885678768, 49.43658225238323, 49.079788997769356, 46.66013203561306, 47.01742686331272, 46.89003109931946, 45.583349615335464, 45.35430170595646, 42.73133285343647, 49.02393199503422, 53.03469657897949, 51.003948748111725, 56.19805343449116, 49.66588094830513, 46.951340809464455, 28.718159794807434, 46.96688957512379, 53.77891704440117, 50.55874943733215, 49.1086408495903, 43.52975361049175, 40.08073568344116, 39.2759844660759, 40.96350431442261, 39.016112610697746, 39.80202063918114, 41.2194661796093, 42.14888870716095, 43.15509371459484, 45.390031188726425, 45.02809301018715, 45.999400690197945, 49.65554550290108, 50.152277648448944, 49.426440596580505, 50.395658388733864, 50.63263267278671, 52.206249833106995, 48.587194830179214, 52.12860479950905, 44.43237617611885, 51.89800277352333, 50.36180600523949, 50.25887332856655, 52.019885033369064, 43.37619245052338, 33.11635158956051, 22.95870054513216, 6.395292906090617, 7.471877261996269, 1.5164469718001783, 0.7208685216028243, 0.9898088872432709, 4.062933409586549, 1.0557893780060112, 0.9386856586206704, 1.1987492255866528, 0.6434613314922899, 0.36682821926660836, 0.09459492954192683, 0.3804186946945265, 2.7977380994707346, 8.484776560217142, 22.141626589000225, 22.723819948732853, 35.44997736811638, 33.39404068887234, 24.871056228876114, 14.49183052405715, 4.091668417677283, 0.14784095284994692, 0.09011113303131424, 0.02597528371552471, 0.03562563033483457, 0.018627064346219413, 0.013941406450612703, 0.0019975034592789598, 0.0852073699934408, 0.08031184479477815, 0.0585396439419128, 0.028784635505871847, 0.04702442492998671, 0.032829284682520665, 0.06855817002360709, 0.09204370784573257, 0.08524057368049398, 0.03556438830855768, 0.04569869313854724, 0.11807687536929734, 0.00697293662597076, 0.031044285933603533, 0.10577311331871897, 0.017924942549143452, 0.12782058416632935, 0.039423285343218595, 0.06248082660022192, 0.06708906643325463, 0.06019392079906538, 0.032915329284151085, 0.1336050167446956, 0.08996829928946681, 0.13378981151618063, 0.018468344933353364, 0.037580005737254396, 0.03467655333224684, 0.018409255135338753, 0.04745048448967282, 0.05362067800888326, 0.03183497377904132, 0.009467699437664123, 0.04176651644229423, 0.05459318832436111, 0.06151862471597269, 0.07522487518144771, 0.024296491865243297, 0.03042646469111787, 0.022932251886231825, 0.04109076129680034, 0.061601322231581435, 0.06906929454999045, 0.014595570664823754, 0.047058526615728624, 0.033731060902937315, 0.05511563802429009, 0.03995290790044237, 0.048467679516761564, 0.02949935897049727, 0.10105225257575512, 0.020950461548636667, 0.029135502518329304, 0.014016605491633527, 0.022400703455787152, 0.04725918479380198, 0.0654343591304496, 0.1221960547263734, 0.07690560960327275, 0.03303636243799701, 0.11704548305715434, 3.402533121407032, 23.681526258587837, 42.453852742910385, 51.34163662791252, 38.03495205938816, 24.92071196436882, 25.414417572319508, 21.944660358130932, 15.378091167658567, 5.9523924719542265, 0.6396605854388326, 0.09105747521971352, 0.40409587731119245, 1.7110544792376459, 1.9823227543383837, 3.122984734363854, 5.1875638123601675, 11.987349763512611, 3.8406975846737623, 5.154713625088334, 5.47198330052197, 7.059882469475269, 14.214472007006407, 21.054200939834118, 31.562586463987827, 30.863708965480328, 33.82872976362705, 52.45423212647438, 48.58940251171589, 51.8381217867136, 52.00361430644989, 52.967728972435, 55.177356004714966, 54.180927872657776, 57.313802763819695, 57.20405325293541, 54.33748707175255, 55.00403970479965, 53.69152553379536, 52.169232219457626, 52.178887501358986, 48.604293912649155, 49.20323297381401, 49.598217979073524, 48.33793580532074, 46.79053343832493, 44.81971979141235, 51.40943259000778, 54.701294749975204, 52.89417251944542, 56.52069412171841, 52.48398073017597, 47.01638951897621, 31.126088686287403, 48.68499778211117, 55.1526003330946, 52.68337123095989, 50.520523488521576, 45.66256396472454, 41.89207948744297, 40.727882757782936, 42.33925089240074, 42.1780901402235, 42.31372006237507, 43.01113843917847, 43.085397854447365, 44.48450177907944, 47.830674424767494, 46.84955567121506, 49.27845373749733, 51.10261805355549, 51.53118945658207, 51.39997489750385, 53.420531675219536, 52.953388541936874, 53.773289546370506, 49.014094322919846, 51.60685479640961, 48.82294937968254, 53.11846688389778, 51.0696130245924, 53.05366896092892, 56.35537639260292, 46.24799095094204, 39.29198540747166, 23.73918056488037, 11.732575334608555, 14.015948809683323, 1.8670312408357859, 0.48124450317118317, 1.61605185829103, 5.308297583833337, 1.491772283334285, 0.4275714629329741, 0.5801652779337019, 0.4445132100954652, 0.4266273620305583, 0.01737532096740324, 0.18310691986698657, 2.954967487603426, 10.530088059604168, 24.311270266771317, 24.780256301164627, 38.5118492692709, 38.6918456107378, 32.655774503946304, 17.618009224534035, 5.06052665412426, 0.15552843018667772, 0.17249460885068402, 0.07622966149938293, 0.04197519723675214, 0.04536950611509383, 0.036506793403532356, 0.04291264478524681, 0.018681786605156958, 0.09323839491116814, 0.0343880285799969, 0.02432532244711183, 0.035286851052660495, 0.025773879679036327, 0.05048416896897834, 0.0601311944774352, 0.08758095864322968, 0.04832532074942719, 0.03026218659215374, 0.06356980215059593, 0.032281846870318986, 0.017973966969293542, 0.0510757200390799, 0.046803168443148024, 0.05301298893755302, 0.0768591660016682, 0.04930630268063396, 0.031208044529194012, 0.07599135788041167, 0.10185343810007907, 0.014578365826309891, 0.03871976645314135, 0.11251853808062151, 0.13592871080618352, 0.12291491380892694, 0.1512452881434001, 0.3020758047932759, 0.23703022714471444, 0.13322861428605393, 0.11170027573825791, 0.11792359218816273, 0.1583416448556818, 0.1609268569154665, 0.1506990971392952, 0.23773550492478535, 0.15341167658334598, 0.11159178116940893, 0.12199426477309316, 0.2502059459220618, 0.16763600549893454, 0.23811673134332523, 0.17846215894678608, 0.14988383307354525, 0.1678200432797894, 0.15681838674936444, 0.23304262314923108, 0.15391476365039125, 0.12802198820281774, 0.1558923497213982, 0.11227060880628414, 0.16309897473547608, 0.15247481904225424, 0.17799456138163805, 0.13871237315470353, 0.1592061429983005, 0.21341048675822094, 0.12973355886060745, 0.1661471088300459, 0.27658398204948753, 4.926027171313763, 27.80269581824541, 48.099403604865074, 59.366771802306175, 45.0695563852787, 32.23585143685341, 26.272079050540924, 24.98869601637125, 19.86195031553507, 7.468707757070661, 0.8729922899510711, 0.5549520871136338, 1.9783353433012962, 4.783761855214834, 7.40522931329906, 13.294365629553795, 16.79674219340086, 16.622232757508755, 8.49563067778945, 5.5890896916389465, 4.648132408037782, 7.7748924773186445, 17.608044259250164, 22.573454417288303, 31.878169029951096, 34.325313717126846, 36.26641295850277, 56.501877531409264, 51.20041720569134, 50.85641786456108, 52.08442077040672, 53.08462209999561, 54.10906992852688, 53.54136519134045, 58.45355160534382, 58.66574361920357, 57.11791567504406, 55.23167409002781, 55.45643202960491, 53.823591247200966, 54.976703971624374, 50.425251200795174, 50.70389024913311, 50.34829393029213, 50.06481394171715, 48.14225770533085, 47.49218478798866, 53.974222764372826, 56.55758634209633, 55.32075271010399, 58.81045125424862, 50.66293224692345, 48.889358416199684, 36.29352070391178, 50.536558628082275, 56.64427109062672, 56.104924231767654, 52.45951384305954, 49.66974154114723, 43.52968901395798, 43.5441130399704, 43.59641723334789, 42.190500274300575, 43.07536639273167, 44.464682042598724, 45.094125866889954, 47.39109121263027, 48.27489718794823, 49.31879237294197, 49.86237220466137, 54.35547150671482, 52.421177700161934, 53.476175889372826, 54.27377209067345, 54.85774755477905, 55.076520815491676, 50.025056675076485, 50.65197743475437, 49.14078712463379, 52.044967487454414, 51.662411615252495, 52.1725532412529, 58.34177300333977, 47.46339373290539, 41.446678787469864, 29.730786457657814, 15.322179067879915, 17.17511259019375, 5.258287517353892, 2.088522780686617, 3.331328029744327, 7.804348496720195, 6.47579301148653, 3.4694615425541997, 2.839248734526336, 2.41967786103487, 0.9886877099052072, 0.39308460254687816, 0.7205029693432152, 3.5996261704713106, 12.521804384887218, 31.43744397908449, 33.46842549741268, 48.99678245186806, 47.67906256020069, 42.86120988428593, 21.983665265142918, 5.498139197006822, 0.3191377501934767, 0.19226944539695978, 0.21322867542039603, 0.1491688925307244, 0.23842141265049577, 0.15718392416602, 0.1764982580789365, 0.2566031104652211, 0.2062161813955754, 0.20877515111351386, 0.10443519175169058, 0.1629724385566078, 0.1392105472041294, 0.19379828445380554, 0.15744147909572348, 0.24646834179293364, 0.10047616044175811, 0.10938441875623539, 0.24869451764971018, 0.15491522324737161, 0.19758777954848483, 0.2847272716462612, 0.15527850453509018, 0.1941414683824405, 0.13512619683751836, 0.24528412643121555, 0.1106771657941863, 0.15127193124499172, 0.17391338740708306, 0.19237822940340266, 0.15281525702448562, 0.2739265590207651], [0.04002961257356219, 0.03319035065942444, 0.05552614216867369, 0.05402548616984859, 0.035382602945901453, 0.03633398802776355, 0.043670381273841485, 0.0671460188459605, 0.027185145845578518, 0.025995214091381058, 0.01674706698395312, 0.041874220623867586, 0.11358554605976678, 0.10299324334482662, 0.02798723493469879, 0.04487892423640005, 0.017873728793347254, 0.03374174782948103, 0.03781240928219631, 0.02147140654415125, 0.11783433408709243, 0.01712382938421797, 0.021002743997087236, 0.049790123593993485, 0.07088262849720195, 0.036889095936203375, 0.05228057081694715, 0.07826464527170174, 0.010913395690295147, 0.05734343176300172, 0.03951613914978225, 0.07231918891193345, 0.013263205000839662, 0.06666311077424325, 0.03988062642747536, 0.04139094889978878, 0.7658017636276782, 11.611865311861038, 29.114436730742455, 42.06572636961937, 37.98491254448891, 28.646567836403847, 25.651612244546413, 33.63870956003666, 17.236380502581596, 5.275265481323004, 2.1592400735244155, 0.181412759993691, 0.3448006825055927, 0.5097009683959186, 1.6141239367425442, 0.5844446201808751, 3.0248329136520624, 10.950396806001663, 2.0027369214221835, 4.214290687814355, 3.2734592724591494, 4.54674007371068, 6.957759149372578, 10.210429262369871, 12.855867259204388, 23.707936741411686, 17.483732029795647, 31.4136116579175, 41.28527104854584, 43.57684828341007, 52.858503833413124, 51.6929429769516, 55.76189383864403, 51.58470958471298, 55.10179705917835, 51.610172018408775, 57.45285630226135, 52.75348886847496, 54.772434532642365, 50.85366681218147, 52.69875280559063, 49.034639820456505, 50.137941017746925, 45.84374964237213, 48.852838575839996, 45.889149606227875, 44.50017213821411, 46.755294129252434, 53.47211770713329, 49.482916966080666, 55.22567801177502, 49.5114154368639, 55.37507839500904, 34.869562312960625, 42.63932839035988, 58.86190049350262, 49.8386424779892, 50.888507142663, 43.97777616977692, 41.46933697164059, 41.803407445549965, 39.26043190062046, 39.54407528042793, 40.698768720030785, 42.532899901270866, 47.752486020326614, 49.89870585501194, 50.19517354667187, 50.086070001125336, 49.3707811832428, 49.11457993090153, 52.46078297495842, 53.307476341724396, 54.08595956861973, 55.565064400434494, 53.28087016940117, 51.778947561979294, 51.31767511367798, 52.924593687057495, 50.33895403146744, 53.95273111760616, 47.19265826046467, 48.22160504758358, 39.139792174100876, 22.840321697294712, 16.517975851893425, 2.9000946320593357, 2.9762985929846764, 1.9010187545791268, 0.4290909360861406, 0.26819655555300415, 1.7137418850325048, 0.23223000112921, 0.15495569998165593, 0.09152099097263999, 0.1571419186075218, 0.17191088001709431, 0.2958959707757458, 0.836040994618088, 2.1796195674687624, 16.044145077466965, 22.324311286211014, 24.460649751126766, 32.68772318959236, 34.85939785838127, 23.81953865289688, 12.645076420158148, 1.2204943899996579, 0.10091139294672757, 0.1125560313812457, 0.048075153899844736, 0.05865541155799292, 0.06246945689781569, 0.06884909933432937, 0.007371654073722311, 0.11765366565668955, 0.12289290913031437, 0.02531815647671465, 0.0024973605604827753, 0.036367028442327864, 0.030313676797959488, 0.06253276209463365, 0.09170479126623832, 0.06369000038830563, 0.01108805365220178, 0.036665846782852896, 0.03696680250868667, 0.13526152004487813, 0.043062165277660824, 0.06938038059161045, 0.004249367366355727, 0.05672674044035375, 0.06295485858572647, 0.008092991465673549, 0.005478253060573479, 0.029638225933013018, 0.050411972842994146, 0.022081852694100235, 0.03146200375340413, 0.03879639320075512, 0.069404292589752, 0.040293149213539436, 0.06188403225678485, 0.03939540285500698, 0.014531411998177646, 0.05346666010154877, 0.06662615181994624, 0.07199933810625225, 0.034488908713683486, 0.06829943507909775, 0.05213963697315194, 0.04053977601870429, 0.03981640467827674, 0.06666827612207271, 0.018061748196487315, 0.02652220573509112, 0.09901783283567056, 0.04327779999584891, 0.05749960932007525, 0.06767200859030709, 0.09931835811585188, 0.05145645292941481, 0.023539582871308085, 0.11313756345771253, 0.05722531153878663, 0.013066828087175963, 0.024888799925975036, 0.05398346947913524, 0.01592586388142081, 0.04197067013592459, 0.030266988287621643, 0.04735418340715114, 0.06659012055024505, 0.06413019786123186, 0.06992778871790506, 0.04105630338017363, 1.1563512193970382, 15.125743858516216, 34.94514025747776, 47.52805486321449, 41.423321440815926, 31.50688525289297, 20.443900488317013, 24.989260286092758, 21.61339033395052, 6.9121582712978125, 1.9552388763986528, 0.2395566165796481, 0.1607508194865659, 0.7938322657719254, 1.1623128619976342, 1.842904316727072, 5.4901890736073256, 11.205525565892458, 6.314636059105396, 4.312516842037439, 8.471201788634062, 5.4817364271730185, 6.507494710385799, 13.391855098307133, 18.50667703896761, 25.697874762117863, 22.501191794872284, 37.36710749566555, 44.59235519170761, 46.52428172528744, 54.87429566681385, 54.32957209646702, 57.474252954125404, 53.77871185541153, 56.735090017318726, 54.72386173903942, 58.306879475712776, 55.60788430273533, 57.001349329948425, 53.38787242770195, 54.16570208966732, 50.81637181341648, 51.71451061964035, 48.78790766000748, 50.46782411634922, 48.24617072939873, 46.73840023577213, 50.46389892697334, 55.26832312345505, 52.664516642689705, 57.9378242790699, 51.176558285951614, 53.63658808171749, 37.94045113027096, 44.7277495265007, 58.42980667948723, 51.40428006649017, 53.08877147734165, 46.01561062037945, 42.8050184994936, 42.42142528295517, 41.52810461819172, 41.38210505247116, 41.98390156030655, 44.110571444034576, 48.414053320884705, 51.1629132181406, 50.86593635380268, 51.14896036684513, 50.76375983655453, 52.310960814356804, 55.757132694125175, 54.56454388797283, 55.909462720155716, 55.140524581074715, 54.45764422416687, 53.161894753575325, 53.22468638420105, 51.97159342467785, 53.533902391791344, 54.022886753082275, 50.78659661114216, 51.74537256360054, 42.95476086437702, 27.68676783889532, 22.024362981319427, 7.243683831766248, 6.571961101144552, 1.2580963410437107, 0.5246070341672748, 0.9203918371349573, 1.1949723470024765, 0.2599393908167258, 0.1356730260886252, 0.13151699909940362, 0.07894486072473228, 0.1388613518793136, 0.16534685099031776, 1.4720437419600785, 2.7780093206092715, 17.640526816248894, 25.62666468322277, 26.89056996256113, 36.60720907151699, 41.81940458714962, 30.352668687701225, 14.907184336334467, 1.6659361752681434, 0.02228182438557269, 0.0948005192913115, 0.029436764380079694, 0.03236414733692072, 0.03661318769445643, 0.09311929505201988, 0.06923025895957835, 0.08275669446447864, 0.020977997082809452, 0.03467095382802654, 0.01817884240153944, 0.038564783753827214, 0.01997752820898313, 0.02664797008037567, 0.07011621259152889, 0.04319187413784675, 0.004597919341904344, 0.066316535230726, 0.06796596586355008, 0.09527452901238576, 0.13047255983110517, 0.019909801667381544, 0.1395759213482961, 0.013828913561155787, 0.05057376474724151, 0.024414085164607968, 0.013402238946582656, 0.02736709448072361, 0.028173419377708342, 0.03613570843299385, 0.12636879488127306, 0.035325409335200675, 0.13924756553024054, 0.17302074702456594, 0.15586208493914455, 0.11457888103905134, 0.09229703253367916, 0.1366995499120094, 0.21427986823255196, 0.14863324002362788, 0.11523794528329745, 0.1372484423336573, 0.10631986835505813, 0.14550713589414954, 0.2124995004851371, 0.17390473396517336, 0.11241891959798522, 0.10019858978921548, 0.14530789892887697, 0.20463410066440701, 0.26753553946036845, 0.1697915734257549, 0.24932347296271473, 0.10677202182705514, 0.1558973963255994, 0.23915236874017864, 0.307944233645685, 0.12580020586028695, 0.23248624987900257, 0.1389771862886846, 0.11636661089141853, 0.3018727828748524, 0.15357773954747245, 0.19374326162505895, 0.1534006927977316, 0.13397950446233153, 0.28254713863134384, 0.14305086457170546, 1.5473307645879686, 16.890268474817276, 40.93961499631405, 55.536467134952545, 50.2445936948061, 39.19596455991268, 33.845342472195625, 44.70608688890934, 24.780427291989326, 7.372524943202734, 3.2589243398979306, 0.27036116283852607, 1.0015016910620034, 1.599428344052285, 5.895127644762397, 5.340297566726804, 12.72993441671133, 22.353263832628727, 8.66743940860033, 9.26186241209507, 6.4798312447965145, 8.582796100527048, 9.012322202324867, 16.09247088432312, 18.399304300546646, 26.75387229770422, 24.52370546758175, 40.32194294035435, 46.2608190625906, 47.42820382118225, 52.90617607533932, 53.962329402565956, 55.54977402091026, 53.280402794480324, 55.17608307301998, 53.15302222967148, 59.97538514435291, 57.647626250982285, 58.55027161538601, 56.435240507125854, 56.88661068677902, 52.39588625729084, 54.516833648085594, 50.65263479948044, 52.33242966234684, 50.97060173749924, 48.929689452052116, 51.41415573656559, 56.29255436360836, 54.39323008060455, 59.450568705797195, 51.943968906998634, 54.04480777680874, 40.888709127902985, 45.809220895171165, 57.74063766002655, 52.92156144976616, 55.666450560092926, 47.704798579216, 45.30508674681187, 45.00596679747105, 42.56128437817097, 42.82437466084957, 44.011981934309006, 47.05351732671261, 51.41360856592655, 54.227300584316254, 52.83775694668293, 53.50704923272133, 52.95213460922241, 53.369063436985016, 57.09594525396824, 56.87138870358467, 56.86187021434307, 57.497465908527374, 52.322212010622025, 51.31099507212639, 52.01402574777603, 51.97344772517681, 50.84951363503933, 54.560721293091774, 52.28970095515251, 53.03549833595753, 45.46465538442135, 29.440489634871483, 19.7452262789011, 7.839291896671057, 6.410199506208301, 4.737930614501238, 1.6609059576876462, 1.9201079802587628, 9.234684370458126, 2.029331219382584, 0.2937110880156979, 0.40134250943083316, 0.39437487081158906, 0.44710490852594376, 0.6642935948912054, 1.7087458656169474, 4.82098275795579, 24.103305526077747, 32.44775086641312, 36.11307978630066, 45.41664116084576, 49.342951476573944, 38.55415619909763, 17.12224032729864, 1.9022067845799029, 0.14052736951271072, 0.14658863801741973, 0.09598124655894935, 0.19510761107085273, 0.1648821626440622, 0.12150926384492777, 0.2002507241559215, 0.20394124643644318, 0.26531829906161875, 0.13020222511840984, 0.11066165490774438, 0.12168581335572526, 0.07343309320276603, 0.12617926520761102, 0.17876121477456763, 0.15957346156938002, 0.05819847865495831, 0.2678358420962468, 0.12609834142494947, 0.34899049205705523, 0.17367224878398702, 0.10399600359960459, 0.20436986640561372, 0.12026319047436118, 0.15376428578747436, 0.10283594514476135, 0.12070301687344909, 0.09205541151459329, 0.15534483769442886, 0.18451943469699472, 0.1650676698773168, 0.15472098835743964], [0.05676235610735603, 0.02464827357471222, 0.005689686295227148, 0.01208664582009078, 0.021884382040298078, 0.03365325785125606, 0.11205367161892354, 0.017355201343889348, 0.06639639032073319, 0.019364143154234625, 0.02211533283116296, 0.013003779858991038, 0.0477410798339406, 0.08518040034687147, 0.03668841178296134, 0.04830352758290246, 0.03034312707313802, 0.05999383036396466, 0.02222086437541293, 0.021304200672602747, 0.06196063673996832, 0.07947183010401204, 0.01648997589654755, 0.08477756258798763, 0.016245057886408176, 0.04380363017844502, 0.045544441454694606, 0.041628443577792495, 0.004958970475854585, 0.029140935039322358, 0.04574033875542227, 0.03714121092343703, 0.005081942954348051, 0.00987691038972116, 0.01941379283380229, 0.0239706649153959, 0.16100001783343032, 5.13327612541616, 25.901724323630333, 36.96787811815739, 43.474838957190514, 35.36298103630543, 40.039827078580856, 24.973540529608727, 13.442499730736017, 11.053297184407711, 2.0769360149279237, 0.5323700769804418, 0.17780117254005745, 0.5332122661639005, 0.3573368035722524, 0.9340889740269631, 3.6373035237193108, 9.293309524655342, 4.969204254448414, 4.739065803587437, 10.07742214947939, 1.0415989207103848, 1.194915825035423, 4.457309972494841, 6.506673479452729, 11.801008712500334, 15.218112152069807, 14.005740657448769, 35.84378823637962, 33.97115372121334, 46.28287307918072, 48.20004880428314, 57.72972084581852, 55.00884644687176, 52.470100075006485, 53.64835985004902, 55.52703224122524, 54.49819564819336, 55.34208096563816, 52.876590862870216, 53.10243934392929, 51.30770064890385, 50.24648979306221, 46.34341903030872, 46.173442751169205, 44.450687393546104, 44.433364123106, 45.254405066370964, 51.601288095116615, 49.72587592899799, 55.40589474141598, 50.6652919203043, 56.64164923131466, 39.753064066171646, 39.255085587501526, 56.68034255504608, 52.08667404949665, 49.877871572971344, 46.37114614248276, 43.71008813381195, 39.69768203794956, 39.36078831553459, 39.57212917506695, 42.24520593881607, 50.569255873560905, 51.535893604159355, 51.43200717866421, 49.9478068202734, 50.08351653814316, 51.89693123102188, 53.32854621112347, 53.17701034247875, 55.21967813372612, 52.72014185786247, 51.343756914138794, 52.89765313267708, 52.72194676101208, 51.7172084748745, 54.673400446772575, 51.05467602610588, 44.62579719722271, 47.273381128907204, 32.97667108476162, 29.133939184248447, 15.095655173063278, 6.917222924530506, 1.3578187837265432, 0.7378152559977025, 0.21373579977080226, 0.19157969334628433, 0.4013687517726794, 0.43958048103377223, 0.2169202218647115, 0.08597550026024692, 0.10789789695991203, 0.03828112377959769, 0.17524957977002487, 0.2984520758036524, 1.5354141290299594, 5.654116552323103, 18.696322962641716, 21.009901016950607, 27.207626849412918, 33.384495601058006, 33.2348520308733, 16.725744903087616, 5.553137445822358, 0.12263511671335436, 0.09938040166161954, 0.08685507884365506, 0.024119304107443895, 0.023623709021194372, 0.07931801257655025, 0.05978314577077981, 0.00209620075111161, 0.03451400072663091, 0.09957255111658014, 0.052088373122387566, 0.06138503071269952, 0.0591959659504937, 0.041377779489266686, 0.06291912417509593, 0.01958451834070729, 0.10042651818366721, 0.0364215095032705, 0.007059048484734376, 0.020713712729047984, 0.04233439300151076, 0.062947659753263, 0.017219770525116473, 0.03849592358164955, 0.036402005862328224, 0.029401903848338407, 0.023733455964247696, 0.036568406503647566, 0.02861655204469571, 0.04669993941206485, 0.009866587115539005, 0.04424919708981179, 0.024107654244289733, 0.08422973143751733, 0.0463900593604194, 0.03402620932320133, 0.039926680401549675, 0.047812288903514855, 0.033070412173401564, 0.017944271785381716, 0.0322844777838327, 0.07588536434923299, 0.06581272828043438, 0.028461717774916906, 0.08851265083649196, 0.05835131654748693, 0.08368586335564032, 0.030415844557865057, 0.03726019203895703, 0.07021330777206458, 0.020814594718103763, 0.05834036986925639, 0.017142141878139228, 0.027790992535301484, 0.06793055799789727, 0.015434360811923398, 0.04726492530608084, 0.022213492993614636, 0.04154191286943387, 0.040695029601920396, 0.039363772521028295, 0.009831834195210831, 0.04186644291621633, 0.03601788506784942, 0.042729931737994775, 0.032721320749260485, 0.009436765794816893, 0.009855159896687837, 0.059722215446527116, 0.27026349620427936, 6.164584010839462, 31.671051643788815, 43.724428564310074, 46.478102803230286, 37.715434804558754, 40.00113755464554, 27.554230950772762, 15.84296677261591, 12.339311577379704, 2.866814830340445, 0.21336779842386022, 0.24543139821616933, 0.4788885999005288, 0.6522874266374856, 1.320046791806817, 2.60726738255471, 9.693800434470177, 9.177375845611095, 3.1925685005262494, 2.911324454471469, 3.9378172857686877, 1.798869192134589, 6.84123745188117, 8.868226334452629, 14.913760833442211, 16.069580912590027, 21.500169709324837, 38.92983064055443, 38.3256858587265, 47.50969424843788, 50.19793599843979, 58.61415758728981, 56.56071737408638, 54.216839745640755, 55.93781299889088, 56.81012839078903, 56.68623983860016, 58.17374601960182, 55.394882932305336, 55.78975014388561, 53.93970921635628, 53.07229556143284, 48.62008586525917, 48.575738444924355, 47.4157290905714, 47.02536083757877, 48.97663593292236, 52.64154687523842, 52.48086489737034, 56.5229208022356, 51.92234426736832, 55.00743672251701, 42.080385982990265, 41.615309938788414, 56.55346356332302, 53.014006689190865, 52.0220585167408, 47.11206838488579, 45.33038578927517, 41.50583401322365, 39.968102127313614, 42.46940530836582, 45.69836564362049, 52.10280038416386, 52.15840280056, 53.215190693736076, 52.648489102721214, 53.053281381726265, 53.031310960650444, 55.716117694973946, 54.99992072582245, 57.40639619529247, 54.011506363749504, 53.47619488835335, 53.96038390696049, 53.986484706401825, 53.847773149609566, 56.3836582750082, 52.65401020646095, 49.454171508550644, 49.747975543141365, 37.91249603033066, 33.37447553873062, 17.532943189144135, 8.166868519037962, 3.7537933979183435, 1.0881679155863822, 0.9036256524268538, 0.35163363616447896, 0.2246968014515005, 0.26593235204927623, 0.10983033818774857, 0.034155205721617676, 0.12005754877463914, 0.10234835412120447, 0.06153206129965838, 0.24437693995423615, 1.3384208246134222, 3.6971963848918676, 22.67306987196207, 25.864731408655643, 31.754362173378468, 39.05954048037529, 39.917663633823395, 20.692941024899483, 7.118614017963409, 0.46767887484747916, 0.0620953142788494, 0.15101008670171723, 0.13533760502468795, 0.03249177818361204, 0.0166241283659474, 0.018188833564636298, 0.017267939620069228, 0.09144169991486706, 0.048349010103265755, 0.0663007126422599, 0.06849540659459308, 0.0215340289651067, 0.0632065579702612, 0.0652061338769272, 0.029696287856495474, 0.06815761807956733, 0.01663825700234156, 0.03470313335128594, 0.021404895269370172, 0.025084073822654318, 0.034484259158489294, 0.023663788706471678, 0.046475914714392275, 0.03738917730515823, 0.04100315818504896, 0.027382776061131153, 0.021076160955999512, 0.06169655462144874, 0.08241293166065589, 0.0511281935905572, 0.028371997686917894, 0.007817423684173264, 0.22657266876194626, 0.1632068830076605, 0.1457520594703965, 0.12089369687600993, 0.15654374758014455, 0.10089527349919081, 0.23749420302920043, 0.050296194094698876, 0.23037314764223993, 0.13983414421090856, 0.09316161973401904, 0.2293028519488871, 0.1809474334004335, 0.18629956495715305, 0.12309869925957173, 0.1199018165061716, 0.22329825384076685, 0.11787176801590249, 0.15214460785500705, 0.11511785094626248, 0.19592713506426662, 0.09928454586770386, 0.16654231731081381, 0.13677195383934304, 0.14874931192025542, 0.2009710081620142, 0.08969422415248118, 0.10536732181208208, 0.11450037665781565, 0.15062179503729567, 0.10704815271310508, 0.12439678233931772, 0.2031182640348561, 0.19463254750007764, 0.1302244301768951, 0.11365564932930283, 0.4892773611936718, 7.2391696739941835, 35.96351221203804, 50.16791380941868, 56.67270116508007, 46.401088535785675, 50.76798900961876, 34.87890221178532, 19.52534917742014, 14.955233708024025, 3.301195646636188, 0.8232869789935648, 0.5930066294968128, 1.6293661063537002, 2.8459406504407525, 3.351667863316834, 8.057077210396528, 14.594500064849854, 13.615046571940184, 12.798997610807419, 16.315839998424053, 5.144131667912006, 1.6820766404271126, 10.294857881963253, 8.795820269733667, 15.570062566548586, 17.122500613331795, 22.224317751824856, 41.31817728281021, 39.13030028343201, 45.01231625676155, 50.46809770166874, 58.89484092593193, 55.536242946982384, 53.225343748927116, 55.80390818417072, 57.03023158013821, 56.89946159720421, 60.355877727270126, 58.14309686422348, 57.800864428281784, 56.44019164144993, 55.632696971297264, 51.32946968078613, 49.06390964984894, 49.27459694445133, 48.761126697063446, 51.03517547249794, 54.81630317866802, 54.9395115673542, 59.09338027238846, 53.64709451794624, 56.444964185357094, 45.52027300000191, 44.65313673019409, 56.58487267792225, 54.867414236068726, 54.436597153544426, 49.74428214132786, 47.25276343524456, 43.09042878448963, 42.21584491431713, 43.11687916517258, 47.614671215415, 53.6816992610693, 54.781816229224205, 55.69151021540165, 54.765952080488205, 54.161256328225136, 54.7921858727932, 57.21239000558853, 55.71449138224125, 56.03907376527786, 51.64883114397526, 51.18488743901253, 54.18886564671993, 52.44932658970356, 51.70018158853054, 56.20108187198639, 52.83983923494816, 49.56903554499149, 50.18403634428978, 39.699802324175835, 33.471814915537834, 18.15844662487507, 8.604585081338882, 4.790420522913337, 4.113490646705031, 2.3379589710384607, 1.1708728526718915, 0.9258726274129003, 1.6956864413805306, 0.4655740549787879, 0.4234478826401755, 0.22156238526804373, 0.33619717229157686, 0.26653375884052366, 0.7229578157421201, 3.0684818839654326, 7.3113572504371405, 28.334346190094948, 32.50156357884407, 39.86401051282883, 47.77188017964363, 47.640650421381, 26.427129730582237, 8.12241280451417, 0.7196676079183817, 0.18487464141799137, 0.18344315729336813, 0.20387768890941516, 0.10996575787430629, 0.1679492660332471, 0.13295171898789704, 0.12671715900069103, 0.18640383670572191, 0.14965501410188153, 0.25036803097464144, 0.20633709209505469, 0.14042011433048174, 0.11378154726116918, 0.11570878603379242, 0.2118233297369443, 0.25162629783153534, 0.15168247249675915, 0.07889984946814366, 0.09443451432161964, 0.22292507230304182, 0.10784435100504197, 0.07906076934887096, 0.1881914329715073, 0.11585990956518799, 0.160831312823575, 0.1689536590129137, 0.19271786586614326, 0.1932204482727684, 0.09146466196398251, 0.09825520930462517, 0.1319916025386192, 0.12622852897038683], [0.0030894492238076054, 0.057236851935158484, 0.06227281744941138, 0.061587150921695866, 0.06787478559999727, 0.043660280643962324, 0.006842196180514293, 0.01300432812058716, 0.028173137361591216, 0.058121313850278966, 0.034578775375848636, 0.03433615987887606, 0.05408668737800326, 0.07066355392453261, 0.05514858567039482, 0.040791790816001594, 0.052905871052644216, 0.05739276974054519, 0.037162080116104335, 0.03753253426111769, 0.07623139812494628, 0.018044914431811776, 0.0798675580881536, 0.02899356491980143, 0.04605727663147263, 0.049990191764663905, 0.06698980418150313, 0.023688960500294343, 0.021037051628809422, 0.03670570382382721, 0.06165074184536934, 0.016852362896315753, 0.01289383253606502, 0.05296883486153092, 0.06126033506006934, 0.03599728304834571, 0.12141954561229795, 2.0881796116009355, 14.138009659945965, 34.734186977148056, 45.597978830337524, 35.97148418426514, 23.024003840982914, 19.161739088594913, 29.20719925314188, 11.899795811623335, 5.242589609697461, 1.0645362711511552, 0.24401119473623112, 0.2771595324156806, 0.2339789760299027, 1.0649202880449593, 2.7822615299373865, 7.591329077258706, 7.639997815713286, 0.3131207136902958, 2.540891831740737, 2.1816762071102858, 0.3647142561385408, 0.7242926128674299, 2.9473624331876636, 4.072050070390105, 7.685158392414451, 7.39916673861444, 14.47973957285285, 20.36964487284422, 32.99643762409687, 42.48441830277443, 44.723619148135185, 49.69579674303532, 54.5013152807951, 56.253386065363884, 54.988684728741646, 56.80671237409115, 56.54611475765705, 56.756277680397034, 56.75907053053379, 54.82759617269039, 52.98686094582081, 48.9883279055357, 47.61022925376892, 48.028400614857674, 47.19453155994415, 46.273164600133896, 50.874618887901306, 49.30394656956196, 53.51435624063015, 51.31642498075962, 57.3885827511549, 40.43041571974754, 38.08535635471344, 54.81090746819973, 50.495851412415504, 51.676679849624634, 46.52878448367119, 43.22436399757862, 38.17457556724548, 41.98131009936333, 39.28033143281937, 47.845972403883934, 51.183599308133125, 50.906217992305756, 52.983779311180115, 55.83781756460667, 54.279885962605476, 52.23650760948658, 55.11855036020279, 53.83860424160957, 50.17309673130512, 53.68957243859768, 50.45298591256142, 54.4606726616621, 50.894461423158646, 54.95257146656513, 48.35176706314087, 50.40635481476784, 42.37688407301903, 35.74891112744808, 28.804137781262398, 15.606410466134548, 8.274694383144379, 2.4885976128280163, 0.6460678728763014, 0.45745003153569996, 0.2942002523923293, 0.08927085116738454, 0.46991665789391845, 0.11099210358224809, 0.033376507271896116, 0.045499649131670594, 0.13681115407962352, 0.3033567516831681, 0.037942581984680146, 0.7365371589548886, 3.4291359689086676, 14.427724163979292, 25.430616103112698, 26.53087366372347, 30.247794315218925, 30.363689996302128, 29.943856224417686, 11.54860820621252, 2.162950811907649, 0.04052148578921333, 0.18125085305655375, 0.04159132135100663, 0.044090358933317475, 0.016438227794424165, 0.052312434927443974, 0.12295625885599293, 0.05868148320587352, 0.0570031570532592, 0.06432409878470935, 0.1150290307123214, 0.06483566859969869, 0.07217190228402615, 0.015070162971824175, 0.012507578067015857, 0.05623412878776435, 0.016191588001674972, 0.05377818401029799, 0.07020057251793332, 0.07955053486512043, 0.029896613923483528, 0.042909791227430105, 0.04582662084430922, 0.021809020654472988, 0.05470980941026937, 0.04264623232302256, 0.028961186872038525, 0.04879193496890366, 0.08359552171896212, 0.06136797986982856, 0.039179263476398773, 0.018219079793198034, 0.03672408311103936, 0.05905755540879909, 0.03126183910353575, 0.05219534628849942, 0.04179803545412142, 0.04140290489885956, 0.05190224990656134, 0.035821160272462294, 0.06009335607814137, 0.007345959993472206, 0.04211193052469753, 0.033588256846996956, 0.07305893203010783, 0.037114812730578706, 0.011127149064122932, 0.014149517646728782, 0.10294560488546267, 0.07809475282556377, 0.07720585286733694, 0.034589974384289235, 0.05285723440465517, 0.04945030159433372, 0.05718715772673022, 0.03993487742263824, 0.020462323191168252, 0.03211829978681635, 0.027737823220377322, 0.046967238740762696, 0.04779965012858156, 0.04114175055292435, 0.024884838712750934, 0.04290963537641801, 0.04355043165560346, 0.08521750030922703, 0.03337782087328378, 0.04968237488355953, 0.04324144589190837, 0.04592925986798946, 2.7377528557553887, 17.936120554804802, 39.496741220355034, 50.246280804276466, 38.92213225364685, 28.98467179387808, 21.27125859260559, 26.347693093121052, 14.854742400348186, 5.358545612543821, 1.3060357561334968, 0.09903115438646637, 0.11344123544404283, 0.5193432478699833, 0.648321567568928, 1.6191144939512014, 6.32256243377924, 6.55559110455215, 3.4445921145379543, 0.28578275407198817, 2.0911085419356823, 0.9199295088183135, 2.027899408712983, 4.264249932020903, 4.17693299241364, 10.429980531334877, 8.885920085012913, 19.97628428041935, 23.555836603045464, 36.83575540781021, 44.72609281539917, 47.388024777173996, 54.08563658595085, 55.873360857367516, 56.45696394145489, 54.948285296559334, 57.37106569111347, 58.06529223918915, 58.18606115877628, 59.167757481336594, 56.27669021487236, 54.61008824408054, 51.83302246034145, 50.285236313939095, 49.91332747042179, 49.21441577374935, 49.174688905477524, 53.06710124015808, 51.538492664694786, 55.71302466094494, 53.101105615496635, 56.06668308377266, 42.24047899246216, 40.288789719343185, 55.414630472660065, 53.54456081986427, 52.81470738351345, 49.61563244462013, 45.27726463973522, 41.39539293944836, 44.11578096449375, 43.07709909975529, 49.359716176986694, 53.45375329256058, 54.097533747553825, 55.18135339021683, 56.336780190467834, 55.96719682216644, 55.36995626986027, 56.01645737886429, 54.609309285879135, 51.09296277165413, 53.9590235799551, 53.229268938302994, 55.74922151863575, 52.317762449383736, 56.30899988114834, 48.89882750809193, 52.81625770032406, 44.27029587328434, 40.30737452208996, 31.52648840099573, 19.397157356142998, 10.916909202933311, 2.9716039448976517, 2.1024240972474217, 0.23005451395874843, 0.23835433734348044, 0.19709493411937729, 0.5454254639334977, 0.1429291523527354, 0.08457353877020068, 0.021361071449064184, 0.053825881841476075, 0.19023486238438636, 0.13701324089197442, 0.567069340031594, 3.008114048279822, 15.70682292804122, 28.385347053408623, 29.06485889106989, 32.63156220316887, 37.86155216395855, 34.95599627494812, 14.637439660727978, 2.8006610926240683, 0.012963208500877954, 0.05992333375615999, 0.036937042386853136, 0.05028464998758864, 0.042898258252535015, 0.014982550583226839, 0.040913929769885726, 0.07014940143562853, 0.08993524403194897, 0.1378778280923143, 0.0217268203778076, 0.0819165758730378, 0.06241870883968659, 0.06705402964144014, 0.024331901586265303, 0.04267897216777783, 0.005405408483056817, 0.04062179817992728, 0.039590487504028715, 0.02875353951822035, 0.03666204327601008, 0.02574004145571962, 0.019568436000554357, 0.010053767891804455, 0.12383082794258371, 0.09061577860848047, 0.03544780433003325, 0.0544893024925841, 0.02725185750023229, 0.09509266572422348, 0.02479697584931273, 0.03291086897661444, 0.03329733866848983, 0.1511930112610571, 0.10704990418162197, 0.17462592339143157, 0.17182539944769815, 0.15753187268273905, 0.1300385667127557, 0.13656100578373298, 0.05610235675703734, 0.09754058046382852, 0.15546096896287054, 0.12091114476788789, 0.28888899832963943, 0.13642388657899573, 0.21065679233288392, 0.11564740299945697, 0.2916212595300749, 0.16656554653309286, 0.2643871709005907, 0.11558846905245446, 0.12466353247873485, 0.17316965153440833, 0.1850941390148364, 0.13448815763695166, 0.08331185061251745, 0.13516683684429154, 0.21061768115032464, 0.19156021939124912, 0.15760087757371366, 0.09768363684997894, 0.11872445858898573, 0.2193255818565376, 0.18192414427176118, 0.1659185125026852, 0.16640279354760423, 0.1034194884414319, 0.15891217830358073, 0.22607519233133644, 3.317874614149332, 20.364910326898098, 47.26262770593166, 56.246405839920044, 47.47492231428623, 33.19597631692886, 29.934655018150806, 38.1248514354229, 17.461510822176933, 7.061013858765364, 1.5933428518474102, 0.6391343730501831, 0.838584186276421, 1.2540176161564887, 3.5588241973891854, 8.13235592097044, 16.613041050732136, 14.166608825325966, 4.233873886987567, 7.90574605576694, 6.778944069519639, 1.011446351185441, 2.8071739431470633, 6.775812562555075, 6.021003490313888, 10.879933387041092, 9.574113506823778, 22.688508443534374, 26.481254026293755, 36.577414870262146, 44.44865070283413, 49.464575350284576, 53.30864667892456, 56.19046524167061, 57.00371280312538, 55.877878814935684, 57.88173168897629, 58.12876783311367, 60.234356448054314, 61.4183235168457, 57.9351644217968, 57.026910558342934, 52.171512097120285, 52.25878581404686, 52.126818895339966, 50.95152676105499, 51.82130388915539, 54.89377722144127, 54.22529809176922, 57.51164674758911, 55.29183246195316, 56.2544272094965, 44.87941458821297, 43.47325064241886, 55.667753890156746, 55.43354585766792, 53.67248855531216, 51.93268731236458, 46.44215293228626, 43.00193913280964, 45.391136929392815, 45.07448472082615, 50.897170677781105, 56.451663225889206, 54.256182834506035, 56.34675085544586, 58.14380742609501, 56.4592894166708, 54.63696800172329, 57.30850964784622, 53.69489975273609, 49.31283429265022, 54.11410465836525, 52.45448291301727, 54.39500838518143, 51.901240199804306, 54.5892121642828, 50.466756373643875, 52.24046319723129, 46.46793834865093, 40.87476767599583, 33.16291809082031, 19.784318581223488, 10.635149572044611, 3.6826103925704956, 2.945249271579087, 1.4654298406094313, 1.0919014527462423, 0.4033168003661558, 2.327953395433724, 0.7404310593847185, 0.30658687523100525, 0.35016219480894506, 0.4398463777033612, 0.7852923427708447, 0.33514801296405494, 0.9371871734037995, 4.071630667895079, 19.918818064033985, 33.854423984885216, 38.087898418307304, 42.54345953464508, 45.742401480674744, 42.8638431429863, 17.64670718461275, 3.129123542457819, 0.22083549614762887, 0.2181776872021146, 0.1978034625062719, 0.24648122547660023, 0.151838798483368, 0.14990502881119028, 0.10012018188717775, 0.20612359105143696, 0.25776765891350806, 0.3773609868949279, 0.13912776805227622, 0.11030193592887372, 0.19152811408275738, 0.12237438539159484, 0.12108681112295017, 0.18863499979488552, 0.18932304490590468, 0.10070175107102841, 0.13229453237727284, 0.1817854368709959, 0.11254227938479744, 0.1650600554421544, 0.09677852096501738, 0.23979040794074535, 0.19019218889297917, 0.1451416133204475, 0.20232125680195168, 0.1622246505576186, 0.19797077227849513, 0.14490751025732607, 0.10811613290570676, 0.0712228957854677, 0.1279341772897169], [0.02152351829863619, 0.08565057316445746, 0.04606214140949305, 0.01562591005495051, 0.024884621634555515, 0.023780240953783505, 0.04303869485738687, 0.04090890914085321, 0.02753516866505379, 0.0037664572073481395, 0.021943351239315234, 0.05404572824772913, 0.03246133528591599, 0.07446335745044053, 0.03301555632788222, 0.06450845568906516, 0.005560203790082596, 0.08572725928388536, 0.009643910343584139, 0.0449559331900673, 0.05126074487634469, 0.03778151367441751, 0.032538937957724556, 0.03268901135015767, 0.004633669523173012, 0.017275982645514887, 0.027193712085136212, 0.053913740994175896, 0.03231008187867701, 0.07240508508402854, 0.05336695998266805, 0.02788769252219936, 0.06972838848014362, 0.020599013805622235, 0.0477907220920315, 0.057686370782903396, 0.08609589887782931, 0.5706831836141646, 6.788610275834799, 26.842339150607586, 43.58763210475445, 37.944144532084465, 27.897525429725647, 21.377886570990086, 21.568400748074055, 18.181733675301075, 8.858298417180777, 1.597996533382684, 0.46032715996261686, 0.16208392451517284, 0.41083677497226745, 0.12602185568539426, 0.7269436831120402, 7.22879053093493, 6.838060822337866, 2.3235021717846394, 0.2032776179839857, 1.2165535264648497, 0.7700140157248825, 0.1872767656459473, 1.2769787153229117, 0.5768392095342278, 2.099438407458365, 3.765585352666676, 4.687274107709527, 14.463299755007029, 20.086949542164803, 31.71579234302044, 36.61045789718628, 43.531334325671196, 51.00113309919834, 55.67642882466316, 55.4377294331789, 55.169053450226784, 56.33245222270489, 54.50468569993973, 57.11941659450531, 53.84393535554409, 54.55461502075195, 50.03061577677727, 49.635349586606026, 48.338429778814316, 50.02083130180836, 47.417488396167755, 50.95447540283203, 49.80884447693825, 54.580385237932205, 50.4768942296505, 58.99529233574867, 41.32838733494282, 38.3054481446743, 59.44975934922695, 49.36407454311848, 53.356885090470314, 49.248332753777504, 44.7943751513958, 39.36000935733318, 40.76347924768925, 40.297107473015785, 48.59752267599106, 52.49396279454231, 53.782291263341904, 51.54222026467323, 56.49019315838814, 50.12500271201134, 54.197665974497795, 54.72565144300461, 52.59596452116966, 53.263835683465004, 53.882039710879326, 51.203666031360626, 53.28763760626316, 49.18634667992592, 46.69908754527569, 48.1055972725153, 38.09528522193432, 36.57496400177479, 20.6168083101511, 15.963807888329029, 8.163653891533613, 2.049412904307246, 0.5903399444650859, 0.7788398140110075, 0.06487807491794229, 0.1373101444914937, 0.3085620270576328, 0.051016077341046184, 0.04754376503115054, 0.09369529070681892, 0.045341259974520653, 0.0340861934091663, 0.08647735536214896, 0.22298417694400996, 2.0248790457844734, 6.094893850386143, 17.91337877511978, 26.040337085723877, 29.439438991248608, 39.14989963173866, 34.277789667248726, 20.848820060491562, 6.781920259818435, 0.4309325310168788, 0.14423251210246235, 0.06284889474045485, 0.06388810186763294, 0.060182803426869214, 0.07068198145134374, 0.047997094807215035, 0.10631108132656664, 0.0485914326418424, 0.02359761139814509, 0.07051968117593788, 0.01918900372402277, 0.05635636051010806, 0.03614009081502445, 0.03540153513313271, 0.0496848165494157, 0.03276691830251366, 0.026615692222549114, 0.04509390957537107, 0.026799358929565642, 0.1141462757368572, 0.04546348798612598, 0.05403948307503015, 0.035779963654931635, 0.08247135352576151, 0.03625148718128912, 0.021507606652448885, 0.01651126625802135, 0.06145500410639215, 0.0508147846267093, 0.023481251919292845, 0.043257368670310825, 0.07194876074208878, 0.027787240978796035, 0.0777740337071009, 0.03435722945141606, 0.010966824756906135, 0.007619206244271481, 0.03942804622056428, 0.01551190411191783, 0.04279235006833915, 0.02850964381650556, 0.011989148952125106, 0.043317397285136394, 0.025696093325677793, 0.03943924522900488, 0.009088831193366786, 0.04562235211778898, 0.029047402167634573, 0.0284408708466799, 0.015611293456458952, 0.06462849807576276, 0.04628452967153862, 0.08744642953388393, 0.04256834763509687, 0.031020487112982664, 0.019675399889820255, 0.022618583170697093, 0.02245726438559359, 0.04655025935790036, 0.016939967863436323, 0.023855303625168744, 0.0409254664555192, 0.044496714472188614, 0.005152069415998994, 0.01912406394694699, 0.03300730364571791, 0.02955427047709236, 0.04995363728085067, 0.06807364406995475, 0.06647714340942912, 0.8084876637440175, 8.651788998395205, 34.09628860652447, 49.72213692963123, 43.49674478173256, 29.495567679405212, 24.15962040424347, 23.30192282795906, 17.545813098549843, 10.313957557082176, 1.6386842750944197, 0.8605587633792311, 0.028679814568022266, 0.2127629183814861, 0.2832446090178564, 0.8230248524341732, 2.5720285484567285, 2.9792631464079022, 3.9907339587807655, 0.5575137434061617, 1.0168400430120528, 0.8953363972250372, 0.6645419471897185, 0.9965252643451095, 1.3714664638973773, 2.868842496536672, 4.442189633846283, 7.9078031703829765, 15.991517901420593, 21.87081892043352, 32.03080303966999, 39.759212136268616, 45.40882118046284, 52.31791824102402, 55.465619936585426, 56.22085601091385, 56.497918143868446, 56.343916207551956, 56.724404990673065, 59.43746320903301, 56.006798297166824, 55.52509434521198, 53.49941544234753, 50.17075605690479, 50.06282664835453, 51.552992686629295, 49.70477186143398, 52.62526474893093, 50.389004945755005, 56.1268300563097, 52.109290435910225, 59.120579212903976, 42.7047760784626, 41.4117244631052, 58.228664472699165, 53.60710546374321, 53.54430243372917, 51.43387667834759, 47.082832753658295, 41.72413229942322, 42.9877544939518, 43.481735587120056, 50.20835503935814, 54.59526523947716, 55.681911930441856, 53.78329060971737, 58.822633400559425, 50.40438652038574, 55.03140963613987, 54.84341472387314, 53.53175550699234, 54.648317992687225, 54.65131603181362, 52.66428865492344, 55.041456297039986, 51.545841470360756, 49.88158397376537, 49.13368910551071, 42.078957259655, 37.71077245473862, 24.776367209851742, 20.300733670592308, 9.827877189964056, 4.3151971232146025, 1.7358721350319684, 1.209607736673206, 0.41016836708877236, 0.22553866408998147, 0.23587918578414246, 0.1502558568608947, 0.045902253114036284, 0.10747715117759071, 0.09425771990208887, 0.08222124233725481, 0.10769028856884688, 0.16440383362350985, 1.9656504364684224, 7.971478253602982, 19.34079498052597, 31.49117309600115, 33.706380128860474, 43.52163724601269, 40.62969222664833, 26.000089645385742, 8.212727308273315, 0.6198624009266496, 0.031984794841264375, 0.01817788874177495, 0.061484534162445925, 0.050274686655029655, 0.14007642574142665, 0.055569921460119076, 0.08760520460782573, 0.036360556914587505, 0.017706090620777104, 0.02341870371310506, 0.07005447332630865, 0.032408078768639825, 0.0368082649220014, 0.0696363250608556, 0.05669827165547758, 0.03448119408858474, 0.02422905105049722, 0.028606518208107445, 0.059875609949813224, 0.06967275709030218, 0.030544417932105716, 0.019220442954974715, 0.03834173498034943, 0.06046652648365125, 0.012341259061940946, 0.018274785397807136, 0.06307478222879581, 0.028995490793022327, 0.006929511246198672, 0.027229522565903608, 0.036162633550702594, 0.046628314739791676, 0.03115027204330545, 0.13711525651160628, 0.15124865749385208, 0.1262270743609406, 0.09862776001682505, 0.09621263336157426, 0.09374963818117976, 0.16514463059138507, 0.11328457549097948, 0.20270307693863288, 0.10817825066624209, 0.108127057319507, 0.17936704476596788, 0.13307614746736363, 0.1492381645948626, 0.18226340966066346, 0.14729856164194643, 0.10605889212456532, 0.18186928471550345, 0.11149125726660714, 0.1490679307607934, 0.1769589536706917, 0.12452191585907713, 0.2523663971805945, 0.11839971703011543, 0.10495547438040376, 0.0958528030605521, 0.15010805072961375, 0.13255079597001895, 0.1192509158863686, 0.06936697740457021, 0.14175707852700725, 0.155384112149477, 0.14203339494997635, 0.15055804455187172, 0.1901641208678484, 0.13808844960294664, 0.38694905990269035, 1.123430379666388, 10.732562094926834, 38.4384486079216, 56.584671288728714, 50.853720009326935, 38.32188606262207, 29.90236435085535, 34.50412452220917, 23.80266945809126, 12.081900089979172, 2.5821604672819376, 1.4215030102059245, 0.5174219759646803, 1.120128594338894, 1.6134267929010093, 3.4645664552226663, 14.669585935771465, 14.612077921628952, 7.871204484254122, 1.3659185240976512, 4.609266668558121, 2.633187691681087, 1.0049237636849284, 2.316625965759158, 1.830275219399482, 4.4520030822604895, 5.2202515583485365, 11.812020521610975, 18.044333048164845, 23.269261680543423, 34.26075518131256, 40.231481194496155, 46.212280467152596, 53.766145929694176, 56.473546251654625, 56.97608068585396, 56.382366344332695, 56.98892019689083, 57.44573548436165, 61.65154740214348, 58.88567961752415, 57.479485273361206, 55.791494250297546, 52.82912760972977, 51.60459391772747, 54.16151471436024, 53.60769063234329, 54.85017456114292, 52.271268144249916, 57.69907169044018, 54.48229730129242, 60.02175785601139, 46.245277896523476, 44.758349284529686, 59.382043182849884, 54.69089850783348, 55.632491782307625, 54.6182806044817, 49.62773099541664, 42.97530636191368, 44.112174957990646, 45.62468379735947, 52.28321470320225, 57.398561015725136, 56.27632163465023, 55.62075041234493, 58.90525236725807, 52.24846176803112, 54.44294661283493, 55.48414394259453, 52.89018273353577, 54.80248712003231, 54.13039818406105, 52.38411828875542, 55.32756194472313, 50.34473732113838, 49.1510883718729, 50.2981024235487, 43.38018983602524, 38.62199015915394, 24.56221640110016, 20.00628937035799, 11.012232787907124, 4.124767016619444, 1.3636038545519114, 2.2992369113489985, 0.6931660487316549, 0.9554296382702887, 0.8976372925098985, 0.5322792974766344, 0.17555013473611325, 0.41393812105525285, 0.2873314975295216, 0.35026039578951895, 0.42272126069292426, 0.30773147474974394, 2.6702523278072476, 9.309247769415379, 24.01487287133932, 37.49789647758007, 41.92770637571812, 50.435491651296616, 49.171276688575745, 32.820032089948654, 9.21846779063344, 0.6709183612838387, 0.19772512139752507, 0.262819369090721, 0.15089554362930357, 0.14968658506404608, 0.20271907764254138, 0.17484070092905313, 0.18941421032650396, 0.1893133673002012, 0.1715765128028579, 0.2794079727027565, 0.16295928769977763, 0.17744886019499972, 0.1643917366163805, 0.10821420029969886, 0.1721776375779882, 0.11856442186399363, 0.13272128213429824, 0.12458627490559593, 0.13240952073829249, 0.21013947087340057, 0.1510300801601261, 0.08107178175123408, 0.08469873908325098, 0.18204312538728118, 0.1256968840607442, 0.09132019549724646, 0.19411279179621488, 0.12941226828843355, 0.1535903412150219, 0.1249878213275224, 0.19579210871597752, 0.10629427168169059, 0.14816031383816153], [0.06299742817645893, 0.06493525739642791, 0.021891174546908587, 0.022078355323174037, 0.06836861808551475, 0.058670358412200585, 0.07306014173082076, 0.04193795997707639, 0.06358707934850827, 0.04243256800691597, 0.042942679501720704, 0.03006567701959284, 0.06324680463876575, 0.03414973980397917, 0.027245309902355075, 0.008777036400715588, 0.037755193407065235, 0.0013910620077695057, 0.018251710171171, 0.03794288626522757, 0.03481665968138259, 0.04151876528339926, 0.043407816847320646, 0.06000547466101125, 0.04604490502970293, 0.040738486059126444, 0.007365786468653823, 0.02455674264638219, 0.0330790359294042, 0.0406788730469998, 0.08419030855293386, 0.0511195846775081, 0.06308932090178132, 0.025602105888538063, 0.028586721418832894, 0.0564224821573589, 0.011743858940462815, 0.16695508500561118, 1.7732927645556629, 13.840722162276506, 43.53216268122196, 42.870279997587204, 34.07280206680298, 21.347163319587708, 24.661554470658302, 20.802232660353184, 13.610799349844456, 5.02823076210916, 0.9946710825897753, 0.1431733337813057, 0.16612499282928184, 0.1370006540673785, 0.1720936709898524, 0.23747668834403157, 1.6275613219477236, 4.915759647265077, 0.4144686082145199, 0.06507020210847259, 0.16188393055927008, 1.2460949225351214, 0.11377368049579673, 0.20832334645092487, 0.6899227446410805, 1.7979287425987422, 1.6387859196402133, 6.667771534994245, 12.151651997119188, 16.891628801822662, 26.366285495460033, 32.62905813753605, 41.66585482656956, 49.05249506235123, 54.901790991425514, 55.42182348668575, 56.55338376760483, 57.95037880539894, 57.5961884111166, 55.33615328371525, 54.27567198872566, 50.012939125299454, 53.43942426145077, 51.50874026119709, 53.368968442082405, 49.90443974733353, 52.24797159433365, 51.901376992464066, 54.791976884007454, 51.59469164907932, 58.29774856567383, 40.60173712670803, 36.54739648103714, 57.63434216380119, 50.46194203197956, 53.61471265554428, 45.30010521411896, 44.78148244321346, 39.666470512747765, 43.98255251348019, 41.109534278512, 48.327315375208855, 48.57503168284893, 54.91329297423363, 50.16119956970215, 50.798486173152924, 52.68713302910328, 45.94145379960537, 63.47257308661938, 51.04891553521156, 56.4051803201437, 51.69293537735939, 52.35265217721462, 45.788553804159164, 48.670056983828545, 37.70832158625126, 35.34705989062786, 28.589342907071114, 22.834268622100353, 14.110061209648848, 7.556518195196986, 2.651877701282501, 2.52932857722044, 1.0052253725007176, 0.943479398265481, 0.1484193530632183, 0.3164522146107629, 0.12809063686290756, 0.10314666011254303, 0.07220575906103477, 0.07043617471936159, 0.04811432445421815, 0.06307444084086455, 0.021439603660837747, 0.751412648241967, 3.888325891457498, 11.223697140812874, 24.7605524584651, 19.844357259571552, 30.29337666928768, 32.63494022190571, 31.519855856895447, 14.659179244190454, 2.9991448670625687, 0.03718593274243176, 0.08506250276695937, 0.06030785902112257, 0.07818870872142725, 0.010091212952829665, 0.12583670468302444, 0.08889839693438262, 0.04146465900703333, 0.046021716625546105, 0.03978510831075255, 0.05265414198220242, 0.06381641782354563, 0.07405961427139118, 0.03175920050125569, 0.03362219897098839, 0.04053261429362465, 0.009565860527800396, 0.09508941511739977, 0.046250049490481615, 0.0432278497464722, 0.06649914808804169, 0.019954215495090466, 0.10521817981498316, 0.03151653676468413, 0.03777090096264146, 0.06614593774429522, 0.04492340856813826, 0.04183918012131471, 0.013353118047234602, 0.09176325023872778, 0.03868012463499326, 0.061563635972561315, 0.0643210114503745, 0.06869433927931823, 0.014634563103754772, 0.06763855999452062, 0.020418365784280468, 0.043691391474567354, 0.027731420341297053, 0.039321529475273564, 0.05379009548050817, 0.11720772396074608, 0.0398006563045783, 0.025072409116546623, 0.08711252987268381, 0.03909384598955512, 0.01629888400202617, 0.043743044952861965, 0.02480632876540767, 0.021725256301579066, 0.00933090956095839, 0.011675199148157844, 0.026759648462757468, 0.033303257296211086, 0.04607113623933401, 0.03275902556197252, 0.05565699022554327, 0.02217082877905341, 0.03136076367809437, 0.03349125443492085, 0.01224841917064623, 0.019759743117901962, 0.00835706059660879, 0.015770569480082486, 0.07755631726467982, 0.03883797944581602, 0.09403907577507198, 0.06579974069609307, 0.024903071425796952, 0.04001171197160147, 0.03478836530121043, 0.19665378669742495, 2.6233671186491847, 16.97476454079151, 50.642162561416626, 47.06381857395172, 36.94064497947693, 21.15906771272421, 26.349384002387524, 21.086447909474373, 15.746855679899454, 5.9906507190316916, 0.9200128074735403, 0.16065953532233834, 0.09052846493432298, 0.15371766407042742, 0.09301469675847329, 0.4797136306297034, 0.9193194040562958, 1.6486734640784562, 0.9168902656529099, 0.17077773925848305, 0.49045419960748404, 1.028583669103682, 1.0279970755800605, 0.2562097425106913, 1.5801896201446652, 1.7713416879996657, 2.48514074832201, 10.570761077105999, 12.69194120541215, 18.569736555218697, 26.955058202147484, 35.81228032708168, 43.29361528158188, 50.2883293479681, 52.78496637940407, 55.624740198254585, 55.761377066373825, 57.8270298242569, 58.57519067823887, 55.35337395966053, 55.3927056491375, 52.44032487273216, 56.740637719631195, 53.72726261615753, 54.35582868754864, 52.09096781909466, 53.695682510733604, 52.99867831170559, 55.769052654504776, 53.182261660695076, 58.24795603752136, 42.97762803733349, 39.07432548701763, 57.39857621490955, 52.33718320727348, 55.00885024666786, 48.36131975054741, 46.18868753314018, 42.646407410502434, 45.18922336399555, 43.805045038461685, 50.308715254068375, 50.09108193218708, 57.738106995821, 52.88325950503349, 52.95001432299614, 52.840561196208, 49.341150373220444, 63.035554736852646, 52.692445144057274, 56.48027949035168, 53.201834410429, 53.5517842322588, 48.46451461315155, 51.34481705725193, 40.52178181707859, 37.8052581846714, 31.19881298393011, 23.792356811463833, 16.614766158163548, 8.909787554293871, 3.804588597267866, 1.9709671824239194, 2.599256937392056, 0.2712418546434492, 0.248780295078177, 0.16606738732662052, 0.18793856841512024, 0.12273600426851772, 0.015742605355626438, 0.12139726633904502, 0.07760626380331814, 0.039181823885883205, 0.09497618564637378, 0.7200086989905685, 5.355372782796621, 13.867421429604292, 28.4671338647604, 26.767030991613865, 34.19581286609173, 38.56053225696087, 38.56251195073128, 17.208723686635494, 4.181003523990512, 0.03241492137021851, 0.040347233225475065, 0.018779731544782408, 0.058252777889720164, 0.031516058079432696, 0.02191262447013287, 0.056332151652895845, 0.014781783866055775, 0.07979544359841384, 0.08518993694451638, 0.05393402389017865, 0.022075299530115444, 0.05659566602844279, 0.034657224096008576, 0.052105928625678644, 0.08842065421049483, 0.07628622057382017, 0.01639607195102144, 0.057267654774477705, 0.04745518970594276, 0.0522147386072902, 0.03756412006623577, 0.15924862353131175, 0.011655973812594311, 0.012988735597900813, 0.0653905798390042, 0.06565977906575426, 0.10472304857103154, 0.06807969999499619, 0.032972296539810486, 0.03642961375589948, 0.07777147329761647, 0.04980158606485929, 0.06759663607226685, 0.16572904220083728, 0.1340473219170235, 0.11251318719587289, 0.2008987229783088, 0.10938648192677647, 0.18508947832742706, 0.13968488347018138, 0.2170940031646751, 0.16309689672198147, 0.11333552392898127, 0.19835373532259837, 0.1376018233713694, 0.159246931434609, 0.10565661839791574, 0.07938795257359743, 0.08106061985017732, 0.15996439527953044, 0.16586675512371585, 0.13935464259702712, 0.22494421864394099, 0.1624768174951896, 0.09505126872682013, 0.2383198868483305, 0.10806455364217982, 0.09675717679783702, 0.11864523432450369, 0.09095550412894227, 0.19810324563877657, 0.24988450692035258, 0.07010849425569177, 0.27409119706135243, 0.11567189387278631, 0.18740233703283593, 0.11509906718856655, 0.13695143483346328, 0.19119797711027786, 0.14631009515142068, 0.334610371501185, 3.8688505114987493, 21.06399491429329, 56.51423066854477, 54.70458157360554, 46.003439873456955, 31.335453651845455, 36.844274550676346, 31.100920736789703, 18.756234347820282, 7.394872019067407, 1.5644602454267442, 0.5078647169284523, 0.6649085087701678, 0.7478243345394731, 0.5070287024136633, 1.2192335701547563, 6.686009131371975, 10.791676472872496, 1.970258995424956, 1.1179722100496292, 1.871333559975028, 3.434530491940677, 1.9580894359387457, 0.3855597891379148, 2.1925961086526513, 2.509303414262831, 3.60951941460371, 10.950157418847084, 15.383762363344431, 19.744244031608105, 28.588098473846912, 37.68054507672787, 45.5669154971838, 51.46614074707031, 54.60234805941582, 57.08641916513443, 58.55412840843201, 60.94014197587967, 60.28110533952713, 59.87268805503845, 58.64925630390644, 53.318176567554474, 57.382172495126724, 55.435795336961746, 58.323461785912514, 54.946339800953865, 55.844307616353035, 55.57224981486797, 56.891672015190125, 55.54103069007397, 58.26521851122379, 45.46722784638405, 42.65942931175232, 57.8922913223505, 54.37580421566963, 57.89191894233227, 49.981032237410545, 48.532880544662476, 44.370732083916664, 46.35379247367382, 46.50886595249176, 52.251098826527596, 52.82421827316284, 57.639874666929245, 56.29657454788685, 54.40146043896675, 52.5081892311573, 49.34336945414543, 61.46414905786514, 52.07236781716347, 56.95270054042339, 54.61217053234577, 54.23748403787613, 47.68795408308506, 50.940613746643066, 40.79374082386494, 38.532402366399765, 32.44157999753952, 26.26087725162506, 16.31729532033205, 9.737963564693928, 4.824706083163619, 5.734026739373803, 3.539956072345376, 2.632612972520292, 0.4288164008175954, 1.1113891820423305, 0.8276648784521967, 0.2967084740521386, 0.3300247894367203, 0.2567541226744652, 0.25582177739124745, 0.17005123605486006, 0.19134412083076313, 1.227221810258925, 5.444781985133886, 14.294175580143929, 32.555934861302376, 31.658740304410458, 42.135551422834396, 46.783146634697914, 44.23675887286663, 19.626247063279152, 4.770855372771621, 0.14151222916552797, 0.16033143183449283, 0.16636754153296351, 0.18495470430934802, 0.1316028062137775, 0.2276805171277374, 0.21278061118209735, 0.13137495203409344, 0.20505411172052845, 0.13394797802902758, 0.11588423716602847, 0.11895170420757495, 0.11614290531724691, 0.13156531291315332, 0.1173282487434335, 0.15556869911961257, 0.13486119074514136, 0.29650658019818366, 0.14289487997302786, 0.17277604609262198, 0.1448038619128056, 0.121887491986854, 0.25068008922971785, 0.16487727931234986, 0.1175934552156832, 0.15708803868619725, 0.1041657105088234, 0.26768750161863863, 0.17643815896008164, 0.15831146913114935, 0.15002304513473064, 0.14548585109878331, 0.1686632417840883, 0.15565373440040275], [0.028317707729001995, 0.055532324258820154, 0.025826128730841447, 0.0022267846497925348, 0.02443631619826192, 0.030618155869888142, 0.033979097788687795, 0.02958038850920275, 0.053020651612314396, 0.015879713428148534, 0.033062252259696834, 0.041950498562073335, 0.07519622085965239, 0.031812624001759104, 0.021290292825142387, 0.01763276643032441, 0.025721339334268123, 0.026314216993341688, 0.07690786573220976, 0.052074487539357506, 0.011485560935398098, 0.09484812064329162, 0.044077367638237774, 0.02447975039103767, 0.026238727587042376, 0.0070773224797449075, 0.022168782306835055, 0.04531709564616904, 0.06031087214068975, 0.04266065596311819, 0.012687489506788552, 0.044291377053014, 0.03651284561783541, 0.035926797572756186, 0.044405207663658075, 0.09591422320227139, 0.02761147072305903, 0.04708808264695108, 0.5959403095766902, 9.248053003102541, 30.401154085993767, 49.834120720624924, 41.87770865857601, 36.84156149625778, 24.771277382969856, 32.01515927910805, 23.62026784569025, 9.481240790337324, 3.4817650448530912, 0.45174033322837204, 0.08890391851309687, 0.1382879982702434, 0.013195264164096443, 0.05163200796232559, 0.10610757701215334, 0.892410019878298, 0.2617045445367694, 0.051155096443835646, 0.1966192026156932, 0.37265891733113676, 0.4273389925947413, 0.3602988040074706, 0.3717380901798606, 0.1192359764536377, 0.41067822254262865, 1.8800379429012537, 3.7516557751223445, 7.318895095959306, 16.379955857992172, 20.077117569744587, 29.294858649373055, 38.621480986475945, 45.76303817331791, 49.78447638452053, 54.38044756650925, 57.65162743628025, 57.25566208362579, 54.29941311478615, 54.53101068735123, 52.93513432145119, 53.916538059711456, 54.22194667160511, 54.154173508286476, 51.37539021670818, 52.56882257759571, 51.85792252421379, 54.63799774646759, 50.69511651992798, 58.753868490457535, 42.987796291708946, 34.915585443377495, 58.84494960308075, 51.35501191020012, 54.21377710998058, 48.22735793888569, 46.43109932541847, 42.52808175981045, 45.24164155125618, 41.80737063288689, 46.95639833807945, 49.260948076844215, 53.46203684806824, 54.877669885754585, 50.42143240571022, 59.62245248258114, 44.22855131328106, 55.80377519130707, 54.151213467121124, 53.821797743439674, 52.159892320632935, 47.67785422503948, 41.80973030626774, 36.61511644721031, 32.30076715350151, 26.00776143372059, 20.115713998675346, 11.94669859483838, 6.396499816328287, 2.224143915809691, 0.9289749234449118, 1.0018019936978817, 2.472796873189509, 0.7227903278544545, 0.3156915132422, 0.02634608852531528, 0.0817307346733287, 0.11563899446628056, 0.034066552470903844, 0.05065161603852175, 0.04910831994493492, 0.01931327635247726, 0.4264279024209827, 2.7191191306337714, 6.2168212328106165, 18.22785560041666, 18.05822890251875, 17.642827592790127, 30.639317706227303, 31.84362318366766, 26.069698110222816, 10.699340477585793, 0.5986449925694615, 0.0488363450858742, 0.03943762363633141, 0.026720331334217917, 0.07168932817876339, 0.037278318995959125, 0.010416208697279217, 0.043093472777400166, 0.02516691976779839, 0.04636102654330898, 0.12885945732705295, 0.023915573437989224, 0.07786873175064102, 0.030019355872354936, 0.07534919976023957, 0.09541832012473606, 0.06757298382581212, 0.01930710168380756, 0.03573278161638882, 0.07956414585351013, 0.02281746576045407, 0.0713520146382507, 0.031106381429708563, 0.09545570210320875, 0.05681023947545327, 0.04353901000285987, 0.06257054483285174, 0.08994259129394777, 0.0706367772363592, 0.018436189529893454, 0.015530812179349596, 0.04753798741148785, 0.01759429906087462, 0.0070025557397457305, 0.09284880448831245, 0.018496746924938634, 0.04755904956255108, 0.010462092905072495, 0.053710689389845356, 0.04595516453264281, 0.03420920438657049, 0.05093336869322229, 0.0341699187993072, 0.02763522687018849, 0.018022072981693782, 0.03655885135231074, 0.08279944959213026, 0.10643528716173023, 0.014116540314716985, 0.036893296492053196, 0.021490424078365322, 0.015521931454713922, 0.07153184444177896, 0.019625603636086453, 0.07950881132273935, 0.011220729247725103, 0.08337422070326284, 0.02761935789749259, 0.032467992350575514, 0.003767559528569109, 0.028188386640977114, 0.03113997845503036, 0.04978664292139001, 0.0412414432503283, 0.015005073837528471, 0.039333166350843385, 0.0696054739819374, 0.0427135265636025, 0.032340016405214556, 0.02882899181713583, 0.04461256001377478, 0.027908088595722802, 0.047580835307599045, 0.8871657075360417, 11.470032222568989, 36.04038968682289, 56.483775302767754, 46.589520424604416, 38.07845592498779, 29.474079832434654, 31.265301816165447, 24.35364369302988, 10.177032854408026, 4.087711405009031, 0.48346848227083683, 0.2524713665479794, 0.08779978830716573, 0.061514828630606644, 0.05274357819871511, 0.13557384547311813, 0.4349075927166268, 0.15559238847345114, 0.18748959875665605, 0.20733542914967984, 0.25447742140386254, 0.23296211496926844, 0.3930602304171771, 0.5412192677613348, 0.6925033405423164, 1.3258861284703016, 5.316029693931341, 5.597520964220166, 9.535950254648924, 17.026122584939003, 22.30239786207676, 32.17272162437439, 40.41278846561909, 46.157346814870834, 51.185879185795784, 55.32601922750473, 57.55976356565952, 58.94007749855518, 54.679119139909744, 56.47197313606739, 54.48869235813618, 56.05075813829899, 57.10898995399475, 55.79409331083298, 53.16978693008423, 54.295757710933685, 54.04147535562515, 55.75566217303276, 52.51843348145485, 56.895935386419296, 45.08334964513779, 38.862513452768326, 58.59319411218166, 51.87146119773388, 55.462599098682404, 51.09862446784973, 49.02898572385311, 43.895392790436745, 46.255772933363914, 43.44405300915241, 49.31751564145088, 51.153869703412056, 55.32734155654907, 57.86256171762943, 53.51370267570019, 62.30746440589428, 46.90995343029499, 58.366011902689934, 55.55762819945812, 54.788222685456276, 53.07552918791771, 47.43726633489132, 41.63222283124924, 37.42823101580143, 33.491581454873085, 25.922974683344364, 20.21171774715185, 15.056731011718512, 10.71545161306858, 4.768316159024835, 1.5867209946736693, 2.1128362510353327, 3.691215505823493, 0.5671528168022633, 0.07499778541387059, 0.10883344089961611, 0.11980730399955064, 0.163947353430558, 0.07942085940157995, 0.02944590578408679, 0.006957305140531389, 0.21320805855793878, 0.32000481616705656, 3.2580036018043756, 7.090997574850917, 17.803644463419914, 24.11795374006033, 21.664820574223995, 34.536529183387756, 38.80781538784504, 31.46431803703308, 12.021957356482744, 0.7822336256504059, 0.06718658463796601, 0.04870680320891552, 0.09169762954115868, 0.06895711150718853, 0.06777834350941703, 0.0036983584323024843, 0.01719153737212764, 0.001863944128217554, 0.07849742731195875, 0.08517335736542009, 0.02429229687550105, 0.07113649495295249, 0.02130935674358625, 0.08205316073144786, 0.03181479107297491, 0.05068935795861762, 0.022138588028610684, 0.01442916816813522, 0.010111521824001102, 0.06391349073965102, 0.02908148158894619, 0.0797636499919463, 0.04015712096588686, 0.0044049567713955184, 0.10199043856118806, 0.012674102090386441, 0.02260928406030871, 0.011970444047619822, 0.08826970137306489, 0.0319219349330524, 0.05865576407813933, 0.03925528537365608, 0.004600703323376365, 0.08360078354598954, 0.10120608494617045, 0.09937165174051188, 0.08225170007790439, 0.08724695508135483, 0.09799022547667846, 0.12277973160962574, 0.137836683425121, 0.1676984498044476, 0.10410639806650579, 0.11663463752483949, 0.0916510597744491, 0.09691442304756492, 0.16105950839119032, 0.09764215079485439, 0.10587397860945202, 0.07833316776668653, 0.11477125313831493, 0.18353168066823855, 0.09569382018526085, 0.14247795625124127, 0.0939600593119394, 0.19378725613933057, 0.1507345272693783, 0.132065654033795, 0.06403637555195019, 0.12427737819962204, 0.1316394386230968, 0.10474808121216483, 0.1490489169373177, 0.1483877227292396, 0.0918977867695503, 0.17947844113223255, 0.08223417054978199, 0.12702647130936384, 0.15996706701116636, 0.25412300135940313, 0.07932050619274378, 0.13961952994577587, 0.9478283242788166, 14.25010934472084, 41.901130601763725, 64.79978486895561, 52.09853321313858, 49.72190134227276, 35.737910717725754, 42.51252919435501, 34.02284234762192, 13.110180012881756, 5.014385255053639, 0.9567325527314097, 0.7467332587111741, 0.26719296409282833, 0.24166436051018536, 0.14819366595475003, 0.7314855081494898, 2.9140500957146287, 0.8783523179590702, 0.69107806077227, 0.6178815790917724, 1.3563325884751976, 1.3660187437199056, 1.441487562842667, 1.321916647721082, 0.42192033492028713, 3.04452036973089, 5.092518562451005, 4.909572629258037, 9.261407386511564, 18.233053721487522, 22.72366415709257, 33.660015016794205, 41.011909916996956, 47.976590394973755, 52.24955230951309, 56.76852822303772, 60.536170452833176, 62.15641871094704, 57.177234292030334, 60.11371672153473, 57.37284779548645, 58.58986169099808, 59.18132655322552, 58.079233691096306, 54.48177292943001, 54.867885410785675, 56.15429878234863, 58.21528919041157, 53.87422353029251, 57.79594749212265, 47.428017631173134, 43.29329989850521, 59.53273929655552, 56.79928757250309, 57.730549201369286, 54.26502116024494, 50.598111525177956, 46.6942124068737, 49.36407454311848, 45.41492745280266, 51.4879097789526, 53.621274903416634, 56.9436152279377, 58.50579880177975, 55.3674104064703, 63.468822687864304, 48.52145075798035, 57.676679491996765, 55.042622834444046, 55.52539832890034, 53.68188925087452, 50.16164794564247, 44.30587336421013, 38.62721487879753, 33.70864860713482, 28.719675913453102, 22.342354618012905, 14.00684829801321, 8.207850269973278, 4.46820636279881, 3.047977234236896, 3.3930198568850756, 6.3501109555363655, 1.9468244654126465, 1.1552097368985415, 0.21384836873039603, 0.43332690722309053, 0.36883614433463663, 0.15756810433231294, 0.19327179004903883, 0.2236628413083963, 0.4411736939800903, 0.6334103364497423, 3.693350753746927, 8.280711360275745, 23.98906845599413, 28.30144375562668, 28.50432626903057, 42.172500640153885, 46.10258035361767, 36.50925412774086, 13.913093078881502, 1.1283349664881825, 0.1731791064958088, 0.08986922999611124, 0.20251290901796892, 0.21157088078325614, 0.20044671051437035, 0.13969754450954497, 0.1301496068481356, 0.13304744119523093, 0.10958053127978928, 0.21362198400311172, 0.19851628050673753, 0.10676810328732245, 0.12782496283762157, 0.31057493935804814, 0.19855298713082448, 0.19765898119658232, 0.10125893328222446, 0.11950679356232285, 0.16332550789229572, 0.19674104842124507, 0.1193586312001571, 0.17741267307428643, 0.12495602772105485, 0.11669915242237039, 0.2786858333274722, 0.13485618866980076, 0.1692016253946349, 0.2277586207492277, 0.19953470007749274, 0.1762486292864196, 0.11314600909827277, 0.16069734032498673, 0.10624405796988867, 0.18523997103329748], [0.06677809913526289, 0.0033039595882655703, 0.056270802015205845, 0.04787960911926348, 0.028666201724263374, 0.0621394683548715, 0.07665254466701299, 0.03097982298641, 0.021696383046219125, 0.028293302202655468, 0.03279993274190929, 0.036236184096196666, 0.03130650526145473, 0.03995930150267668, 0.06504971141112037, 0.009061629625648493, 0.031189628134598024, 0.026547240231593605, 0.017303625791100785, 0.05635264977172483, 0.01995131555304397, 0.021737880233558826, 0.04593689285684377, 0.01922538380313199, 0.04896567916148342, 0.037168117487453856, 0.05548624802031554, 0.024951912164397072, 0.03586035680200439, 0.027044173039030284, 0.035117708175675943, 0.06572839803993702, 0.06595202939934097, 0.013618777229567058, 0.04701157464296557, 0.041568069864297286, 0.026788376999320462, 0.025911126904247794, 0.17710169835481793, 2.464915383607149, 18.189770244061947, 43.70680890977383, 50.21809011697769, 30.5004845559597, 29.290521182119846, 28.841953352093697, 24.65289283543825, 13.050820548087358, 6.617709221318364, 2.0233116298913956, 0.2273139703902416, 0.12938541738549247, 0.11763862232328393, 0.0755925128760282, 0.05173648380150553, 0.1988367547164671, 0.1694323294213973, 0.06270141515415162, 0.023043132459861226, 0.5120260873809457, 0.6523318961262703, 0.5256367789115757, 0.4340444749686867, 0.8605554979294538, 0.5208937427960336, 1.7295800289139152, 0.9813604562077671, 2.9224566696211696, 5.3811083268374205, 11.975134368985891, 17.398244217038155, 25.572981163859367, 35.0751730799675, 41.724360287189484, 47.05015450716019, 51.125717014074326, 54.455599933862686, 53.84593024849892, 55.577379539608955, 54.691605269908905, 57.63561509549618, 55.21078661084175, 58.03830988705158, 53.34757938981056, 54.54220108687878, 54.11818943917751, 56.85659609735012, 50.90567082166672, 59.39808592200279, 44.757653921842575, 36.072353571653366, 55.87225891649723, 53.37158650159836, 54.21114765107632, 51.276758909225464, 47.39103801548481, 46.004203632473946, 45.05791001021862, 44.77720387279987, 46.195584163069725, 49.26151044666767, 51.53148964047432, 54.53504607081413, 52.70384453237057, 54.580924808979034, 54.403873309493065, 48.69414769113064, 52.76001691818237, 49.39850449562073, 42.726921290159225, 37.59645938873291, 32.63181298971176, 27.53215603530407, 19.131606705486774, 13.75134240835905, 8.141013756394386, 3.38894410058856, 4.439258566126227, 2.246403358876705, 2.1019358234480023, 1.8932247790507972, 1.1426649475470185, 0.22888940147822723, 0.11068688792875037, 0.1625874123419635, 0.12844943557865918, 0.22832324670162052, 0.15780438930960372, 0.041512089665047824, 0.054409595832112245, 0.33892029023263603, 0.3797064704122022, 7.199768638238311, 19.534100107848644, 32.88152419030666, 33.32842580974102, 23.08069109916687, 28.302633091807365, 30.722747929394245, 19.088285230100155, 4.5295939687639475, 0.09398941125255078, 0.01978675358259352, 0.048652118057361804, 0.04109422712645028, 0.02415343733446207, 0.032240394211839885, 0.012374656635074643, 0.012437628793122713, 0.029344430076889694, 0.02250727586215362, 0.010442845305078663, 0.02931128576165065, 0.09591195965185761, 0.020103136703255586, 0.0010559416296018753, 0.06659102597041056, 0.07450728517142124, 0.017672606772975996, 0.051929145338363014, 0.008861532696755603, 0.03215017874026671, 0.0544082339911256, 0.03729692834895104, 0.03925488461391069, 0.034646860003704205, 0.03772488409595098, 0.0695556758728344, 0.03421211731620133, 0.07464996306225657, 0.046326294032041915, 0.07857999866246246, 0.03894415480317548, 0.029119919272488914, 0.08538363748812117, 0.015544081779808039, 0.019011858639714774, 0.021781635405204725, 0.0236875096015865, 0.01808106815587962, 0.01100687568396097, 0.12186238513095304, 0.09927340623107739, 0.008316082912642742, 0.020709718119178433, 0.01059250216712826, 0.01977745818294352, 0.03185206172929611, 0.00316696306981612, 0.026094812164956238, 0.032224363822024316, 0.03314362133096438, 0.07654865141375922, 0.019944586128985975, 0.050068848286173306, 0.08234238310251385, 0.03507598092255648, 0.04525508178630844, 0.05385949742048979, 0.013758265740761999, 0.013988987393531715, 0.014039202960702823, 0.0605179721605964, 0.005808610821986804, 0.03321741307445336, 0.10175917792366818, 0.056594233683426864, 0.018569455132819712, 0.09402947238413617, 0.04733657966426108, 0.042202413169434294, 0.04120390542084351, 0.02497487421351252, 0.016207247317652218, 0.1486601057695225, 3.2745818747207522, 23.29214595258236, 48.683983236551285, 53.55368413031101, 34.33437243103981, 29.869566410779953, 37.030407562851906, 31.06171254068613, 18.59685570001602, 7.640432417392731, 2.0950788538903, 0.295698648551479, 0.14596702996641397, 0.03777542064199224, 0.14374021586263552, 0.22232414048630744, 0.06473198314779438, 0.18696607294259593, 0.00835010667287861, 0.2953154925489798, 0.3468853753292933, 0.6288103270344436, 0.6202649418264627, 0.8864558581262827, 0.9847706544678658, 1.0003945254720747, 1.0270172031596303, 2.5915184151381254, 5.441991984844208, 9.958146549761295, 15.069105997681618, 19.823161996901035, 28.905371949076653, 37.183421552181244, 43.81556287407875, 48.17210890352726, 53.25142554938793, 56.80731274187565, 56.61908604204655, 58.63966561853886, 55.6951580196619, 58.812924921512604, 56.86771810054779, 58.201412335038185, 55.59349447488785, 56.09259769320488, 54.85180467367172, 57.8862876445055, 53.00992950797081, 58.32736037671566, 45.89560925960541, 38.40736247599125, 56.82908937335014, 55.64002297818661, 55.48279881477356, 52.51621440052986, 47.75859609246254, 46.810733154416084, 46.44854798913002, 46.40564829111099, 47.93832264840603, 51.03405453264713, 53.65037754178047, 55.09734369814396, 53.77544403076172, 57.437208741903305, 55.441453233361244, 49.38251115381718, 51.51402197778225, 50.59940345585346, 44.2309033870697, 38.60838308930397, 33.38076800107956, 30.750676430761814, 22.280089259147644, 17.431762218475342, 13.487141635268927, 7.468828400596976, 8.271778989583254, 2.822202849201858, 2.4883679626509547, 2.130635683424771, 2.10829121991992, 0.9395374066662043, 0.2718891855329275, 0.09399868809850886, 0.1305953852715902, 0.534349592635408, 0.2908639720408246, 0.15404238336486742, 0.034270453834324144, 0.5109112628269941, 0.6995745236054063, 8.101728614419699, 18.8648971170187, 32.611210495233536, 34.75354693830013, 25.947029292583466, 32.234270721673965, 37.22824014723301, 22.026905044913292, 5.558355515822768, 0.1692951360018924, 0.03470603514870163, 0.04110171168576926, 0.03560541052138433, 0.05489575079991482, 0.007305175731744384, 0.04204092925647274, 0.028239348066563252, 0.11801016371464357, 0.019928841466025915, 0.014834270405117422, 0.07189854703028686, 0.0402088783448562, 0.049692085885908455, 0.09302666017902084, 0.04972784256096929, 0.017383495724061504, 0.042428612359799445, 0.0321909486228833, 0.020498599369602744, 0.05054148503404576, 0.03766304835153278, 0.03606995043810457, 0.06833672799984924, 0.07910429631010629, 0.055962562109925784, 0.04101560029084794, 0.02383358652878087, 0.03172545875713695, 0.013891852322558407, 0.04878070256381761, 0.03141295521345455, 0.004621087337000063, 0.03347786609083414, 0.08496603841194883, 0.12343012014753185, 0.13725264288950711, 0.19951528549427167, 0.1591567011200823, 0.09892249654512852, 0.2996541472384706, 0.20476816222071648, 0.12707450310699642, 0.09528857044642791, 0.07278922814293765, 0.1715299504576251, 0.19072028633672744, 0.10241073163342662, 0.11760276174754836, 0.0727861630730331, 0.10423302330309525, 0.19375583360670134, 0.10154507574043237, 0.12191507761599496, 0.1368792832363397, 0.10139038247871213, 0.12128407397540286, 0.1918498647864908, 0.1559025319875218, 0.1609373657265678, 0.14067579904804006, 0.11693168213241734, 0.2381995995528996, 0.15536266408162192, 0.1810527144698426, 0.14166775363264605, 0.16134939127368852, 0.24533049581805244, 0.24560483812820166, 0.13803869602270424, 0.1690183297614567, 0.15832530276384205, 0.08153491900884546, 0.35908034595195204, 4.221747787669301, 28.377770259976387, 54.99855279922485, 62.47517600655556, 40.87293617427349, 39.17070351541042, 38.935754522681236, 37.40808069705963, 19.142890200018883, 8.034952897578478, 2.937222677282989, 0.4868993122363463, 0.4048513836460188, 0.6080432538874447, 0.3175780229503289, 0.4768743517342955, 0.8129546802956611, 0.5337714892812073, 0.20018940791487694, 1.2892988417297602, 1.19357235962525, 0.7516940112691373, 1.496402572374791, 1.7978554777801037, 1.6740790195763111, 2.1658443566411734, 5.100219799205661, 2.2941162111237645, 4.654240580275655, 6.498010894283652, 15.222308076918125, 19.891489930450916, 29.581063091754913, 38.449103236198425, 44.71185117959976, 49.477779641747475, 55.2314081043005, 59.410385861992836, 58.77318665385246, 61.62989616394043, 57.13135175406933, 62.02987790107727, 60.812058448791504, 61.48162432014942, 58.43747466802597, 57.66510911285877, 58.25513765215874, 60.216839388012886, 55.0328915566206, 58.86307843029499, 49.2089668661356, 43.14627058804035, 56.062256321311, 57.52058386802673, 58.81689190864563, 56.19383946061134, 50.10388724505901, 49.20154966413975, 48.8206847012043, 48.69902662932873, 51.1500509083271, 53.41537535190582, 55.53695730865002, 57.093771770596504, 56.41537517309189, 60.371441692113876, 55.38236640393734, 50.72894610464573, 53.05694438517094, 51.48681923747063, 46.96471229195595, 39.57826964557171, 33.80696453154087, 30.578631162643433, 22.397502958774567, 15.230199303478003, 9.682948216795921, 5.186563991010189, 6.544185066595674, 4.632705710828304, 3.5405975254252553, 3.747886377386749, 4.347136784344912, 1.0629802546463907, 0.22739118343451992, 0.9507149225100875, 0.39323228993453085, 0.6004418805241585, 0.9460330987349153, 0.2687306940788403, 0.33770690846722573, 0.7213775161653757, 0.7543668709695339, 9.077373761683702, 21.902655512094498, 39.1449560970068, 43.174784258008, 34.94075149297714, 40.146707743406296, 42.51051910221577, 26.482772044837475, 5.946931689977646, 0.41922654665540904, 0.18804830237058923, 0.17154758388642222, 0.14403884124476463, 0.1287606477853842, 0.06953074713237584, 0.1613429345889017, 0.08241575182182714, 0.28648690378759056, 0.11052529269363731, 0.16546103783184662, 0.2434017727500759, 0.1154321430658456, 0.08970699651399627, 0.14969890471547842, 0.18344428535783663, 0.13090156571706757, 0.18276845599757507, 0.12064253925927915, 0.11933791043702513, 0.14696584199555218, 0.10659584339009598, 0.15022623032564297, 0.14648720127297565, 0.17053640767699108, 0.12147027882747352, 0.1613102652481757, 0.159452446969226, 0.1471800555009395, 0.12119755439925939, 0.17829207354225218, 0.18922603136161342, 0.10096818950842135, 0.10680022343876772, 0.12763700651703402], [0.08174533271812834, 0.049963671117438935, 0.018710257245402317, 0.01690908338787267, 0.06008152624417562, 0.06909975229064003, 0.03900239484210033, 0.05836832286149729, 0.0731862400425598, 0.03395785381144378, 0.07202555076219141, 0.04269547753210645, 0.025423248298466206, 0.008207250666600885, 0.006394042420652113, 0.023162911384133622, 0.07680627313675359, 0.06720128658344038, 0.0688355699821841, 0.03209818016330246, 0.07577233525807969, 0.09316743075032718, 0.034787760450853966, 0.04819718153157737, 0.03263468614022713, 0.05249882902717218, 0.10654044948751107, 0.059339957442716695, 0.05854819348314777, 0.026655836845748127, 0.06153156777145341, 0.08659142346004955, 0.02049748243734939, 0.01655681371630635, 0.07421982911182567, 0.05531526832783129, 0.07892746478319168, 0.02806368727760855, 0.012331416328379419, 0.53174281376414, 7.759214518591762, 30.554502457380295, 48.6870002746582, 43.645632192492485, 26.1614802852273, 22.53182765096426, 17.415020316839218, 15.559839215129614, 13.532285112887621, 5.361853810027242, 1.6574506368488073, 0.12994909338885918, 0.14286333869677037, 0.07621753480634652, 0.05990180034132209, 0.05019007068767678, 0.0524968103854917, 0.1581192231969908, 0.09550640563247725, 0.29914601356722414, 0.5372018739581108, 0.16218827047850937, 0.1854509933036752, 1.0785316326655447, 0.1507177547318861, 2.0189670380204916, 1.0893497709184885, 0.6550473847892135, 4.3625587318092585, 6.168740512803197, 9.476894773542881, 14.662105087190866, 24.675549119710922, 29.976296983659267, 35.55739760398865, 39.933117404580116, 48.44673916697502, 52.180293425917625, 56.15345902740955, 56.81764058768749, 55.88730230927467, 57.896839678287506, 57.346621602773666, 55.24179294705391, 56.467010602355, 55.11422999203205, 55.685563534498215, 52.72044204175472, 56.54550679028034, 42.9919608682394, 35.692351162433624, 55.14543391764164, 52.75374345481396, 54.864788576960564, 51.809235736727715, 50.40034733712673, 48.36720563471317, 48.830396980047226, 48.000103533267975, 49.41764406859875, 50.46791151165962, 51.91192142665386, 54.3712292611599, 52.276276275515556, 55.36091275513172, 51.492716521024704, 49.4903227686882, 47.627468928694725, 41.99632689356804, 33.99472765624523, 26.601042598485947, 20.5209793522954, 17.374343499541283, 11.750546470284462, 6.870597051456571, 4.983010338619351, 3.3986219437792897, 5.352759948000312, 2.1596782375127077, 1.4137811120599508, 1.0732921888120472, 2.014728602953255, 0.4815795680042356, 0.015300040431611706, 0.08987672568764538, 0.074719672993524, 0.25932607997674495, 0.056788242218317464, 0.13525926391594112, 0.0779808554216288, 0.6617375195492059, 2.455610395409167, 8.46159590408206, 15.061603300273418, 37.084626853466034, 31.99326105415821, 28.658151514828205, 36.312466487288475, 23.84474840015173, 13.137278258800507, 1.5449370117858052, 0.025358514467370696, 0.06439865494030528, 0.013929494980402524, 0.03459293184278067, 0.018789294117596, 0.0239703550687409, 0.06176640556077473, 0.07610002314322628, 0.08440110817900859, 0.011131573191960342, 0.06754917572834529, 0.08921406202716753, 0.046068386582192034, 0.0729423703160137, 0.03984108851000201, 0.06497799025964923, 0.0512001893366687, 0.026270137132087257, 0.026030575572804082, 0.05950194601609837, 0.05318549374351278, 0.018322041651117615, 0.028420723392628133, 0.09426443633856252, 0.03387560158444103, 0.03412334532185923, 0.03268361593654845, 0.03805338834354188, 0.04426585088367574, 0.030061496872804128, 0.046351608689292334, 0.015452331917913398, 0.08381181323784404, 0.03396849991986528, 0.08163294187397696, 0.1024636096553877, 0.0948054991022218, 0.0410674875456607, 0.00690978774400719, 0.054117616382427514, 0.03393312174011953, 0.0839360042300541, 0.03630881808931008, 0.026635386966518126, 0.03609461571613792, 0.08653716504340991, 0.016427190203103237, 0.04298003179428633, 0.009462897742196219, 0.03683662238472607, 0.03161444459692575, 0.05226675573794637, 0.026552678318694234, 0.052251270826673135, 0.03119274515483994, 0.04720588003692683, 0.07248476205859333, 0.016756380937295035, 0.019185120436304715, 0.07536283301305957, 0.04679452984419186, 0.005207916492508957, 0.04718561198387761, 0.027249759077676572, 0.06858277221908793, 0.006937670232218807, 0.041238322519348, 0.04420172561367508, 0.028425599302863702, 0.017280409556406084, 0.0037160282727199956, 0.038747752842027694, 0.08519533977960236, 0.025810838633333333, 0.7203155918978155, 10.106890518218279, 35.19712373614311, 54.18487586081028, 46.18323862552643, 29.41890489310026, 24.626991525292397, 21.863927990198135, 17.964240945875645, 15.813683643937111, 6.726190075278282, 2.2229132568463683, 0.15390242915600538, 0.1847198442555964, 0.04296475097362418, 0.06783853168599308, 0.08852701881551184, 0.11149809244670905, 0.07666424833587371, 0.3905092313652858, 0.5903410725295544, 1.4861649717204273, 0.1537879602983594, 0.20928601588821039, 2.1405911492183805, 1.3719772989861667, 2.0704604499042034, 3.265431015752256, 2.9045332688838243, 7.070152368396521, 9.71341973170638, 10.997170396149158, 19.16305761784315, 26.1604106426239, 33.42883162200451, 38.93433719873428, 43.74823808670044, 51.76636643707752, 54.286736994981766, 58.15910920500755, 57.86497458815575, 57.458688989281654, 58.52133996784687, 58.707149997353554, 56.38515919446945, 57.99233615398407, 56.958894208073616, 56.53777040541172, 54.37420830130577, 55.99194869399071, 45.09840823709965, 39.99248541891575, 55.690332278609276, 54.16792497038841, 57.41141192615032, 54.23553094267845, 52.336472645401955, 51.21300593018532, 50.14919601380825, 48.90150636434555, 50.517555847764015, 51.16739697754383, 53.21842812001705, 54.81042489409447, 54.927405416965485, 55.68831078708172, 53.638134598731995, 52.407775819301605, 49.2905180901289, 43.39408189058304, 33.666011095047, 29.58513267338276, 23.369137421250343, 20.238757096230984, 13.299946580082178, 9.88133842125535, 8.178487345576286, 6.370683051645756, 7.96654611825943, 4.542332785204053, 3.654134483076632, 3.476699679158628, 1.7719330312684178, 1.3645889516919851, 0.2103171410271898, 0.2735643315827474, 0.3995001723524183, 0.8909690065775067, 0.210081078694202, 0.2416503636050038, 0.08907695766538382, 0.7247498945798725, 2.6945774350315332, 12.16094059869647, 19.87459033727646, 44.392326325178146, 39.3655114620924, 31.158134266734123, 41.97200819849968, 30.165918208658695, 15.191610474139452, 1.53630850603804, 0.039209917886182666, 0.07766084134345874, 0.03524620733514894, 0.051646854626596905, 0.07903873498435132, 0.023630952382518444, 0.04394607800350059, 0.04409779154229909, 0.039263426733668894, 0.056166211143136024, 0.02770663075352786, 0.02086389002215583, 0.08404466207139194, 0.01681415527855279, 0.07407580051221885, 0.026700248818087857, 0.030717616646143142, 0.03702326139318757, 0.016844880192365963, 0.039195501667563803, 0.0416467449394986, 0.03424601862207055, 0.04706085324869491, 0.03961415830417536, 0.03745363654161338, 0.04739257099572569, 0.008617840157967294, 0.02163746023143176, 0.10023786424426362, 0.020197150115564, 0.02849845594028011, 0.021811820406583138, 0.04529361038294155, 0.03869999563903548, 0.09554149437462911, 0.21089684742037207, 0.17142195312771946, 0.14286670804722235, 0.21813467232277617, 0.29614806349854916, 0.17669375461991876, 0.14984944195020944, 0.1942702310043387, 0.21590505290078, 0.1600326580228284, 0.20029296720167622, 0.11506485418067314, 0.11461819260148332, 0.11311478694551624, 0.11280218692263588, 0.13226906186901033, 0.13412986358162016, 0.18768962239846587, 0.16588339407462627, 0.17745536140864715, 0.16201771009946242, 0.2043597138253972, 0.1018563547404483, 0.09726390038849786, 0.21994500799337402, 0.19008819916052744, 0.1381555842817761, 0.15553168079350144, 0.1258848255383782, 0.12572250299854204, 0.11380869502318092, 0.21115081035532057, 0.1193970744498074, 0.11887009022757411, 0.16757504548877478, 0.10151271810173057, 0.21315852762199938, 0.18380200053798035, 0.09991598737542517, 1.2084813346154988, 12.546391915529966, 41.36551134288311, 60.01169979572296, 54.80890117585659, 37.784431502223015, 34.179697930812836, 28.852731473743916, 25.35272218286991, 17.34290398657322, 7.635422386229038, 2.015575719997287, 0.3331815591081977, 0.553914267802611, 0.20140026637818664, 0.1895314102876, 0.2687555708689615, 0.13851512514520437, 0.2822322602150962, 0.6431771779898554, 0.5393903783988208, 1.323124507907778, 0.38318741018883884, 1.6341335442848504, 3.5400603292509913, 0.9401660948060453, 6.97794746607542, 3.2834334997460246, 2.3626360343769193, 7.653820998966694, 8.04445143789053, 10.913603380322456, 18.111099265515804, 28.477043733000755, 34.53288517892361, 38.77981089055538, 46.542691737413406, 54.129296243190765, 57.6398366689682, 60.452476143836975, 59.466011077165604, 58.644259572029114, 58.97663913667202, 60.28389818966389, 57.747226506471634, 58.602173030376434, 58.57810512185097, 57.88249544799328, 55.21525137126446, 57.2326847165823, 48.398816138505936, 45.16148865222931, 55.61605006456375, 56.43370158970356, 60.105661153793335, 56.59844174981117, 55.15622153878212, 53.43328759074211, 52.961242720484734, 50.711809024214745, 52.370431423187256, 53.774558678269386, 56.14444591104984, 57.7591996639967, 58.57322618365288, 57.44301863014698, 51.44742675125599, 53.58324274420738, 48.53560499846935, 44.46656674146652, 35.59512957930565, 29.867269434034824, 23.09240397065878, 19.667459651827812, 13.418294079601765, 9.649010337889194, 6.290802313014865, 5.805751690641046, 8.747781347483397, 6.144715826958418, 3.7507471488788724, 3.1349569419398904, 2.8901726519688964, 1.7396103031933308, 0.6787132867611945, 0.11951424472499639, 0.536955005954951, 1.2634304235689342, 0.393638868117705, 0.4312537325313315, 0.2998051594477147, 1.072089672088623, 3.9274243684485555, 11.738150585442781, 23.4960563108325, 50.57810939848423, 39.58874188363552, 36.86560280621052, 51.33306808769703, 38.08747284114361, 17.88749646395445, 1.8492357269860804, 0.10362324508605525, 0.17347221029922366, 0.12256086483830586, 0.10271847058902495, 0.24716340762097389, 0.07803978194715455, 0.06655339908320457, 0.2332549070706591, 0.16167780646355823, 0.09588674889528193, 0.1339415807160549, 0.29657895443961024, 0.10541321622440591, 0.15121751697733998, 0.12659963249461725, 0.15026548993773758, 0.21738373761763796, 0.1640553804463707, 0.1197047317691613, 0.11125063072540797, 0.1099480947596021, 0.1110860075277742, 0.12552510655950755, 0.2017317689023912, 0.11543872591573745, 0.20768263551872224, 0.08814473854727112, 0.10677876794943586, 0.16843874211190268, 0.3769317880505696, 0.12645865412196144, 0.08420052050496452, 0.24141324742231518, 0.08381352759897709, 0.17733894812408835], [0.04476036614505574, 0.10386822803411633, 0.01810835692594992, 0.028744492738042027, 0.016958057713054586, 0.04323568311519921, 0.026403243173263036, 0.07104082469595596, 0.038825604133307934, 0.07285196930752136, 0.08362901484360918, 0.010819299714057706, 0.05219009930442553, 0.01887623300717678, 0.02219760175648844, 0.0022918055992704467, 0.01995472572161816, 0.09310934285167605, 0.039192380936583504, 0.04325047782913316, 0.009189421889459481, 0.02423668403935153, 0.014309017242339905, 0.05735679413191974, 0.010758457519841613, 0.015636173957318533, 0.06514057255117223, 0.0239223956305068, 0.022172198041516822, 0.017580847634235397, 0.033636247826507315, 0.07812636831658892, 0.05586407540249638, 0.03652637496998068, 0.02684904571651714, 0.04172676330199465, 0.0186096053221263, 0.0802554193069227, 0.009261103150493, 0.07841996193747036, 2.739203665405512, 18.59362967312336, 40.10791562497616, 40.947989746928215, 29.585096575319767, 22.895565032958984, 32.735026851296425, 33.54529917240143, 20.6249113753438, 10.217350590974092, 3.927244828082621, 0.8985183108597994, 0.45795421698130667, 0.08102477411739528, 0.06676195742329583, 0.04400774676469155, 0.06492889719083905, 0.08413605755777098, 0.3173579613212496, 0.45242358406540006, 0.30312763585243374, 0.2707336616003886, 0.6247085658833385, 0.9340874303597957, 2.0376587100327015, 1.1597661674022675, 2.2260357392951846, 2.9169840132817626, 2.913471101783216, 3.650947166606784, 8.109568543732166, 9.69297967851162, 11.562017686665058, 19.076384268701077, 24.94817689061165, 30.496148988604546, 36.9561443477869, 44.31894466280937, 50.26539757847786, 51.658706814050674, 53.871054500341415, 54.2297438532114, 54.958757534623146, 55.012144669890404, 56.098415181040764, 55.60662277042866, 55.755065605044365, 52.03240916132927, 55.868489518761635, 47.056241780519485, 39.231880232691765, 51.98723718523979, 52.842297703027725, 54.950071200728416, 53.352545723319054, 53.07572677731514, 50.58795087039471, 51.3790038228035, 48.896426036953926, 53.09236228466034, 48.714279010891914, 53.00421841442585, 54.14994813501835, 52.360844537615776, 56.260385289788246, 49.22616474330425, 46.5618085116148, 39.58545506000519, 30.048238523304462, 25.29203563928604, 17.92247548699379, 11.613913401961327, 9.518807474523783, 5.523101482540369, 3.7891735369339585, 6.146546378731728, 3.986261123791337, 6.796832084655762, 2.73777327965945, 3.3976651076227427, 2.5787572748959064, 1.4020868833176792, 1.5182595932856202, 0.6070912862196565, 1.1996785132214427, 0.4524244152707979, 0.7439752004574984, 0.09231004238245077, 0.037040219467598945, 0.39187715796288103, 1.7521973652765155, 6.503145843744278, 8.444937597960234, 23.719995394349098, 29.829385466873646, 16.758250258862972, 34.483499228954315, 37.70900174975395, 18.288908824324608, 5.749517558142543, 0.16712151904357597, 0.02944794669019757, 0.020565689519571606, 0.030316482116177212, 0.03985328941780608, 0.04846854411880486, 0.020161604952591006, 0.03842425809125416, 0.036740172872669064, 0.07290158187970519, 0.025568681412551086, 0.009184080281556817, 0.03819848563580308, 0.008538065776519943, 0.02976458585180808, 0.041424438313697465, 0.04482245793042239, 0.01653207051276695, 0.041393119681742974, 0.017476863467891235, 0.050732098243315704, 0.024802614316286054, 0.03431759134400636, 0.054293965513352305, 0.055122929625213146, 0.02675523082871223, 0.059147429492441006, 0.07281153710209765, 0.04936281722621061, 0.03757614285859745, 0.03939298345358111, 0.0355171320552472, 0.08540530820027925, 0.03528108456521295, 0.1689810145762749, 0.03535162199113984, 0.03584283469535876, 0.03745865345990751, 0.011600386951613473, 0.002189742203881906, 0.030730350044905208, 0.0637531942629721, 0.006744899692421313, 0.022441974288085476, 0.03093567447649548, 0.053489974670810625, 0.024900622338464018, 0.029594569095934276, 0.02432082317682216, 0.06978425735724159, 0.01532065080027678, 0.0378892326989444, 0.14073583879508078, 0.026030334374809172, 0.02367967252212111, 0.050758377692545764, 0.05908338956942316, 0.026540570179349743, 0.04640892846509814, 0.08702782113687135, 0.04414623152115382, 0.032563825880060904, 0.005668279973178869, 0.08180347998859361, 0.029591823149530683, 0.01387681733831414, 0.09346783728688024, 0.07940422045066953, 0.0350827270449372, 0.020113576865696814, 0.022424736052926164, 0.034038128214888275, 0.1341055953525938, 0.05320940945239272, 0.019124871032545343, 0.06005849740176927, 3.6113181430846453, 22.61979293078184, 46.06552094221115, 48.64905171096325, 32.014144733548164, 27.61662930250168, 34.01770502328873, 34.74750146269798, 21.370630860328674, 11.729472801089287, 4.881076058372855, 0.7063815020956099, 0.2474268403602764, 0.08543303483747877, 0.11312706206808798, 0.014943928290449549, 0.12729824578855187, 0.17347851855447516, 0.6716687022708356, 1.5081684035249054, 1.0373394680209458, 0.3662098915083334, 1.059469599276781, 2.4633489176630974, 5.02098455093801, 2.7709789853543043, 6.230316208675504, 5.107665024697781, 4.108805023133755, 6.0659498535096645, 8.800429422408342, 13.218889329582453, 17.2724424675107, 22.212078608572483, 28.098319955170155, 33.68324317038059, 40.143998488783836, 47.68162742257118, 52.665124610066414, 53.32593955099583, 55.51375575363636, 56.985116600990295, 55.070490539073944, 55.155488178133965, 57.896383702754974, 57.824069783091545, 55.4925262928009, 53.17496985197067, 54.85338158905506, 48.25390711426735, 42.37777702510357, 54.68896061182022, 56.25306688249111, 57.362132370471954, 55.42631484568119, 54.78585921227932, 53.09209629893303, 52.70995460450649, 50.278522074222565, 53.747846111655235, 51.29458375275135, 53.80411349236965, 54.01081100106239, 54.37599800527096, 56.07412688434124, 51.185278818011284, 46.91855616867542, 42.51221381127834, 33.39218258857727, 28.506919629871845, 19.073118343949318, 17.64089349657297, 13.401075303554535, 7.580269770696759, 6.069213403388858, 7.306676851585507, 5.102958977222443, 5.847037900239229, 5.832273792475462, 5.362510224804282, 3.145167944021523, 1.6809770744293928, 2.470687748864293, 1.5338197583332658, 1.966577349230647, 1.032207605894655, 0.2908676827792078, 0.14639937551692128, 0.06814943219069391, 0.43037289229687303, 1.7419225978665054, 8.243958782404661, 12.686551194638014, 24.934129044413567, 38.98892506957054, 20.553898885846138, 36.41175135970116, 43.171269446611404, 22.29119036346674, 6.345097124576569, 0.31922372058033943, 0.04114530915103387, 0.026536278710409533, 0.03255318348237779, 0.09449180070078, 0.03702874957525637, 0.032465869808220305, 0.0679765859968029, 0.03309236119093839, 0.09533450196613558, 0.045562193627119996, 0.06342049688100815, 0.049576926830923185, 0.01966146050108364, 0.036012623240821995, 0.03856119918054901, 0.026510459392738994, 0.017181796683871653, 0.017151661777461413, 0.0282109423642396, 0.055050985829439014, 0.06088998110499233, 0.0496588562236866, 0.032403384684585035, 0.0737526397278998, 0.04678200981288683, 0.050293129024794325, 0.06524533411720768, 0.014537679435306927, 0.03249890651204623, 0.009891801582853077, 0.02562540004873881, 0.039561625380883925, 0.03018250961758895, 0.07234642573166639, 0.02895354831707664, 0.1930953370174393, 0.20369019272038713, 0.060963754294789396, 0.08202043201890774, 0.10904356517130509, 0.09355623449664563, 0.059865995426662266, 0.14082495588809252, 0.10326049814466387, 0.20910021179588512, 0.19876072910847142, 0.10188843036303297, 0.08854006577166729, 0.1205351430689916, 0.11743698822101578, 0.09952230771887116, 0.17459151742514223, 0.11916516814380884, 0.12358583757304586, 0.11237899205298163, 0.12614962382940575, 0.0615481028216891, 0.11888238019309938, 0.22147546493215486, 0.14477589778834954, 0.13149572914699093, 0.16672200610628352, 0.22004583617672324, 0.107337345398264, 0.09846872519119643, 0.22522298415424302, 0.19740589399589226, 0.19110323453787714, 0.15619988087564707, 0.11187669908395037, 0.10200911099673249, 0.22215274890186265, 0.16165701148565859, 0.18153218639781699, 0.23508562211645767, 4.349477933719754, 26.20487205684185, 53.0358175188303, 53.99498865008354, 39.13548320531845, 32.58130230009556, 44.99362885951996, 43.05708937346935, 29.093112275004387, 14.646219089627266, 6.310281492769718, 0.873246401315555, 0.6226749031338841, 0.22688791825203225, 0.27106400637421757, 0.23754820169415325, 0.45643085497431457, 0.18588819249998778, 1.4729977282695472, 2.096190769225359, 1.865029816981405, 0.45504119829274714, 1.3876322214491665, 3.9675803761929274, 3.2118322793394327, 1.7423899727873504, 6.661051595583558, 8.000679686665535, 6.54416891746223, 5.8210325706750154, 10.745788235217333, 13.399183005094528, 14.757009744644165, 23.146216683089733, 27.630105279386044, 33.83118823170662, 40.623323768377304, 46.92912720143795, 53.037888407707214, 52.39944666624069, 55.026929676532745, 56.36852748692036, 56.687607765197754, 57.077763229608536, 58.76131609082222, 59.538910165429115, 57.17109762132168, 53.42082045972347, 54.66307260096073, 51.10359840095043, 46.94091796875, 53.85253809392452, 57.003013640642166, 58.93584832549095, 56.79795004427433, 56.96512587368488, 54.80920895934105, 56.08432933688164, 52.139080837368965, 56.28522075712681, 51.8647887557745, 56.81477554142475, 56.82003825902939, 58.00586722791195, 56.0052365809679, 51.73402637243271, 49.24777798354626, 42.973045483231544, 33.84492449462414, 29.373174346983433, 20.044669210910797, 12.493225168436766, 14.054009467363358, 7.674252977594733, 6.876731347292662, 9.622426964342594, 6.72738891094923, 13.626676797866821, 7.385917799547315, 6.340446174144745, 6.485165683552623, 6.35757707990706, 5.086883939802647, 1.6196515713818371, 5.404406301677227, 3.162382682785392, 1.4631511503830552, 0.4954739677486941, 0.3641115431673825, 0.6440185953397304, 2.3660838743671775, 9.275486581027508, 13.764600846916437, 32.1479507535696, 42.17338219285011, 25.42469412088394, 46.75357282161713, 48.68592493236065, 28.006093204021454, 7.519750418141484, 0.4382060532225296, 0.24959958158433437, 0.0878377491608262, 0.15077865537023172, 0.243370721291285, 0.18249604327138513, 0.11534979435964487, 0.15124896919587627, 0.10550335748121142, 0.16232923400821164, 0.16647815122269094, 0.14502107369480655, 0.12603157781995833, 0.10437976074172184, 0.10916598985204473, 0.23173752677394077, 0.11662489312584512, 0.0538540945854038, 0.14994927565567195, 0.10647668415913358, 0.09341639160993509, 0.11536771722603589, 0.09734370352816768, 0.1768805383471772, 0.16722331201890483, 0.10615053251967765, 0.17147243401268497, 0.15633220580639318, 0.13751404214417562, 0.11000362967024557, 0.14396066340850666, 0.08189708707504906, 0.16723526059649885, 0.13453868305077776, 0.24636972520966083, 0.09977175839594565], [0.019468663522275165, 0.050428875256329775, 0.04238707806507591, 0.06666434273938648, 0.06865922827273607, 0.04419641183631029, 0.06780612951843068, 0.02148716233932646, 0.01957268665137235, 0.009918838950397912, 0.0015870158972575155, 0.007229122293210821, 0.041427284450037405, 0.0988639410934411, 0.027071853292000014, 0.10482195459189825, 0.0057302827008243185, 0.042197377697448246, 0.034479394380468875, 0.03411010911804624, 0.13817400438711047, 0.09892485657474026, 0.030145990385790356, 0.018302393291378394, 0.00967170099102077, 0.04043789769639261, 0.055556332736159675, 0.061892140220152214, 0.050752985989674926, 0.020663747636717744, 0.02795840620819945, 0.06478463852545246, 0.0328174808237236, 0.026765587499539834, 0.025415157033421565, 0.07939390459796414, 0.05509174457984045, 0.043105406512040645, 0.04878813888353761, 0.025111542563536204, 0.35419354098849, 7.280940357595682, 26.750473380088806, 46.9950270652771, 36.27924107015133, 23.8126952201128, 16.886922754347324, 27.501959055662155, 39.327475503087044, 26.67308483272791, 14.401948247104883, 4.422039315104485, 0.7873577694408596, 0.23520264396211132, 0.04382974635518622, 0.010136776181752793, 0.16730750125134364, 0.4306152480421588, 0.18284924619365484, 2.2098844684660435, 1.2583297910168767, 0.5639121844433248, 0.5426740553230047, 2.9686370166018605, 7.240731865167618, 2.419331129640341, 5.349281709641218, 2.915369812399149, 3.7794833444058895, 3.1113143730908632, 0.8610741700977087, 7.20702862367034, 7.620448814705014, 9.820477087050676, 16.3663449883461, 22.959880381822586, 27.79143702238798, 29.97149784117937, 39.4125035405159, 48.24281170964241, 52.86347396671772, 54.77976433932781, 57.196776643395424, 54.23577032983303, 58.55118356645107, 53.79681408405304, 56.82720087468624, 53.00845518708229, 56.42519764602184, 49.34696786105633, 42.314411625266075, 51.01869575679302, 54.996504709124565, 57.318202927708626, 53.52295517921448, 55.2347519248724, 53.2856997102499, 54.59329694509506, 51.97737671434879, 54.49029207229614, 53.97559829056263, 54.33094762265682, 53.27582783997059, 54.52165938913822, 52.642812207341194, 42.83896587789059, 40.92600032687187, 30.608989633619785, 23.08712985366583, 15.202686879783869, 9.642451889812946, 10.38893798366189, 4.653715258464217, 1.8235366372391582, 2.4581206357106566, 2.4146599927917123, 2.3616324132308364, 3.84433351457119, 5.641641346737742, 6.098952032625675, 4.76430737413466, 1.3999164872802794, 2.1797368861734867, 1.210925909690559, 1.7426969250664115, 0.5037465097848326, 0.4266971239121631, 0.022760014253435656, 0.4543236008612439, 0.8956930437125266, 5.351277077570558, 9.798625409603119, 18.206816129386425, 32.35680654644966, 17.588562704622746, 34.24331411719322, 34.061995446681976, 27.40267988294363, 11.43043739721179, 1.3279428868554533, 0.09365231293486431, 0.05111297585244756, 0.013490070268744603, 0.017265707610931713, 0.04792498773895204, 0.03485592300421558, 0.02656998891325202, 0.06795128618250601, 0.07272743692738004, 0.03598490031436086, 0.07403872281429358, 0.05423402595624793, 0.024020130913413595, 0.07146779709728435, 0.03207911067875102, 0.024630846091895364, 0.009767922292667208, 0.04044309644086752, 0.09993332394515164, 0.013085542268527206, 0.04194531466055196, 0.09354776659165509, 0.08523947530193254, 0.03404865929041989, 0.019452560773061123, 0.04531293590844143, 0.009138415935012745, 0.02525404419429833, 0.02653085917700082, 0.03695937732118182, 0.039424146234523505, 0.08366213689441793, 0.11467022457509302, 0.022080335002101492, 0.02365092728723539, 0.005164681751921307, 0.022984432289376855, 0.04734459114843048, 0.022469467148766853, 0.0659623378305696, 0.05036069414927624, 0.009324096645286772, 0.0444983991474146, 0.036353487957967445, 0.03205521723430138, 0.0160245082952315, 0.07232409450807609, 0.043290865505696274, 0.06888352756504901, 0.09602187914424576, 0.04106605891138315, 0.03041753479919862, 0.014793474547332153, 0.01740907198836794, 0.044605862130993046, 0.04738506417197641, 0.04608299946994521, 0.04644301901862491, 0.022774196695536375, 0.025423548868275248, 0.03789644266362302, 0.015151963416428771, 0.06697201490169391, 0.052462675303104334, 0.05463245906867087, 0.022536535034305416, 0.010628797826939262, 0.0235463957869797, 0.024222915344580542, 0.04211331463011447, 0.02360512749874033, 0.05820653837872669, 0.034570993957458995, 0.04801747047167737, 0.0336707762471633, 0.03576100178179331, 0.5339164158795029, 9.039379600435495, 32.21228510141373, 51.32425256073475, 41.228475496172905, 24.178596585989, 21.454701349139214, 31.33845169097185, 44.72898826003075, 27.718826718628407, 15.855657141655684, 5.13350791297853, 0.6634414906147867, 0.16420061874669045, 0.059670584232662804, 0.02322197335161036, 0.2778047852916643, 0.30141440278384835, 1.1735645332373679, 1.609894644934684, 1.4742133067920804, 1.01060671498999, 1.054524639621377, 2.993679097853601, 10.912168957293034, 5.846029529348016, 5.598448114469647, 7.995304875075817, 3.620268562808633, 4.53816250897944, 3.617245825007558, 8.336086738854647, 11.003981530666351, 13.38422890752554, 20.01808773726225, 26.506860852241516, 30.722861923277378, 33.24944704771042, 41.75011530518532, 49.02147352695465, 53.692099303007126, 56.750961765646935, 57.25437015295029, 56.926033571362495, 58.7578696757555, 55.33781759440899, 57.875872403383255, 55.59415943920612, 55.1837320625782, 50.10923355817795, 43.05830530822277, 53.580047115683556, 56.481658816337585, 58.83828856050968, 55.67514069378376, 58.717698231339455, 54.35663804411888, 54.53381113708019, 55.01341760158539, 56.05169668793678, 54.51597109436989, 53.71414192020893, 55.460577607154846, 57.12320119142532, 51.752991154789925, 44.60132651031017, 42.76474826037884, 33.234050273895264, 25.66123142838478, 19.168094247579575, 13.777709193527699, 14.618792161345482, 6.800688877701759, 2.995474264025688, 5.376315834000707, 4.841430885717273, 6.944999434053898, 7.304758429527283, 7.152445977553725, 8.111237604171038, 3.5026890970766544, 2.321299477480352, 2.433360214345157, 1.8274890189059079, 2.0443468261510134, 0.7003007596358657, 0.14003116957610473, 0.15278441336704418, 0.193808629992418, 1.205137395299971, 5.6548442132771015, 13.192427549511194, 20.176894515752792, 35.38879305124283, 22.522307261824608, 33.72661404311657, 41.6009771078825, 32.46554911136627, 14.159817639738321, 1.4521974069066346, 0.05459551124658901, 0.09041447847266681, 0.012537335405795602, 0.02379833265877096, 0.07557938428362831, 0.021863113943254575, 0.026441710542712826, 0.026306112740712706, 0.028698759742837865, 0.03503224244923331, 0.08210770116420463, 0.06165573649923317, 0.03860432538203895, 0.09342049568658695, 0.024871320492820814, 0.018845185259124264, 0.023690361304034013, 0.0686494393448811, 0.058121083784499206, 0.05983151524560526, 0.009780630643945187, 0.06488302504294552, 0.09069825347978622, 0.05950240985839628, 0.024153741615009494, 0.028955299785593525, 0.023544757495983504, 0.025127782610070426, 0.035432167278486304, 0.05901626602280885, 0.04810941514733713, 0.006776591717425617, 0.03584802972909529, 0.047474685925408266, 0.023423906168318354, 0.05193277444050182, 0.08079715000349097, 0.1672456506639719, 0.2083931677043438, 0.1561375256278552, 0.13257516809972003, 0.09332483285106719, 0.21340318402508274, 0.20774637116119266, 0.12765302206389606, 0.14475024916464463, 0.0972139612713363, 0.1541165981325321, 0.19345302251167595, 0.3168169059790671, 0.08794676323304884, 0.1575821902952157, 0.1218204315227922, 0.19072560011409223, 0.10199072057730518, 0.1714387850370258, 0.27026601950637996, 0.2423151201219298, 0.18115590268280357, 0.08824166303384118, 0.17040204926161095, 0.10985528177116066, 0.16481471626320854, 0.14677531784400344, 0.21740622469224036, 0.07543689935118891, 0.18255363393109292, 0.11507288421853445, 0.08329670337843709, 0.1369833917124197, 0.1426399967749603, 0.16117534280056134, 0.10948416340397671, 0.08355709331226535, 0.14516552531858906, 0.153606609092094, 0.7176642247941345, 10.970615521073341, 38.81105661392212, 60.71811608970165, 47.452465519309044, 33.263327702879906, 26.093519032001495, 36.226670891046524, 48.960585594177246, 32.12241992354393, 17.95011330395937, 5.72322771884501, 1.4492139732465148, 0.4607425845460966, 0.2084090348216705, 0.10988455949700437, 0.4827516863588244, 1.2960312492214143, 2.922957530245185, 6.95166427642107, 7.1429393626749516, 1.7395506938919425, 0.780367391416803, 6.2668977957218885, 17.207893431186676, 8.476539552211761, 10.695913061499596, 7.288103448227048, 8.008186183869839, 6.2185311410576105, 2.0865915343165398, 10.243441890925169, 11.896122358739376, 13.300622943788767, 19.014335498213768, 25.580694749951363, 31.327785663306713, 32.22809225320816, 41.24488681554794, 50.22175692021847, 54.88748095929623, 58.070950135588646, 59.663216695189476, 57.80501760542393, 61.02796286344528, 56.854130029678345, 58.811621591448784, 55.5808487534523, 55.69953918457031, 52.976422905921936, 47.71298713982105, 52.57935181260109, 58.27069781720638, 60.118728652596474, 57.47065834701061, 61.1445178091526, 57.59142346680164, 56.82556316256523, 57.79726982116699, 57.51045361161232, 57.02725633978844, 55.366540253162384, 58.63672077655792, 58.223021775484085, 53.33690196275711, 45.62217593193054, 42.50208355486393, 34.73193369805813, 25.943195298314095, 16.85828559100628, 12.08467299118638, 14.861624781042337, 7.042790511623025, 4.22776049003005, 4.513585902750492, 6.651769168674946, 8.785611167550087, 11.185906268656254, 13.57523325830698, 15.45184426009655, 11.1860098131001, 5.543373394757509, 7.205286892130971, 5.778496703132987, 5.307362833991647, 1.4191011828370392, 1.1730997706763446, 0.39667205535806715, 0.8662640978582203, 1.2495701923035085, 6.868596458807588, 14.603519830852747, 27.71593887358904, 41.91721893846989, 26.40259064733982, 44.21850845217705, 48.48156429827213, 39.32670034468174, 16.22345555573702, 2.21036609262228, 0.1658038210007362, 0.16222016798565164, 0.16608519887086004, 0.14454620308242738, 0.14879005582770333, 0.1733941215206869, 0.12361988730845042, 0.1464867708273232, 0.19196399225620553, 0.15998753544408828, 0.14594003063393757, 0.1776704951771535, 0.2685750211821869, 0.16289657622110099, 0.1588856242597103, 0.16352432925486937, 0.1075879018753767, 0.2122240449534729, 0.21710053406422958, 0.09388159203808755, 0.12470301473513246, 0.2070145690231584, 0.25323429435957223, 0.1773280682391487, 0.0567187178239692, 0.1033101997745689, 0.10602825626847334, 0.12056703315465711, 0.2108353382209316, 0.18259145377669483, 0.14558734721504152, 0.12152818861068226, 0.30454896739684045, 0.10483131307410076, 0.1924221942317672, 0.18595029541756958], [0.030066638100834098, 0.02342226045584539, 0.008214438366849208, 0.06801422772696242, 0.04256777247064747, 0.03076581171626458, 0.0575529140769504, 0.03630824292486068, 0.008367009086214239, 0.04242327260726597, 0.007085198985805619, 0.06389183487044647, 0.055277311184909195, 0.09660176365287043, 0.05266937456326559, 0.007244460166475619, 0.053497203189181164, 0.05514664495422039, 0.03123040914942976, 0.019981871628260706, 0.05863125836185645, 0.012198744443594478, 0.03619850525865331, 0.03591947999666445, 0.07059227806166746, 0.04172639222815633, 0.08359869811101817, 0.026642211014404893, 0.03294237314548809, 0.016831525244924705, 0.02329834591364488, 0.03994815815531183, 0.019296242207929026, 0.028682451047643553, 0.0310083511431003, 0.0428882132837316, 0.005330578660505125, 0.014560608087776927, 0.05313212219334673, 0.049701863681548275, 0.11101365555077791, 1.9787416839972138, 13.346449434757233, 34.55665670335293, 45.03027409315109, 42.33660623431206, 23.451925478875637, 25.331502221524715, 23.55675045400858, 17.754237614572048, 14.880735855549574, 10.890395175665617, 4.729754878208041, 1.006638421677053, 0.08695148382685147, 0.1155398361152038, 0.266983708133921, 0.6286479451227933, 0.640590941766277, 0.6499294750392437, 1.1087138880975544, 1.910574291832745, 1.138146633747965, 1.1101749096997082, 12.55934827029705, 6.028105309233069, 5.230200374498963, 9.620341826230288, 0.6780758709646761, 3.6079728975892067, 2.2951283818110824, 2.9138926416635513, 5.037244828417897, 4.393870951607823, 8.542941939085722, 11.586151141673326, 18.545423559844494, 22.815680019557476, 25.817156061530113, 36.63535036146641, 45.855544209480286, 47.460133507847786, 52.70544804632664, 56.729918494820595, 56.95297792553902, 56.198376417160034, 57.496496960520744, 52.33272224664688, 58.53538781404495, 51.24860621988773, 46.91688045859337, 49.86795410513878, 52.53495119512081, 57.57699944078922, 56.470381021499634, 55.73429211974144, 52.37354725599289, 57.1763451397419, 55.76233461499214, 57.17639833688736, 53.632662892341614, 54.91015054285526, 51.36877857148647, 50.77296294271946, 46.373878195881844, 39.01159085333347, 32.1428894251585, 23.40093221515417, 15.053597129881382, 10.795877147465944, 5.993636408820748, 7.980644311755896, 3.1328634917736053, 1.3471544184722006, 3.6090092919766903, 5.764897232875228, 8.058984708040953, 3.9772368455305696, 7.305411519482732, 7.130959080532193, 1.5011275000870228, 1.6420953045599163, 1.4328306773677468, 1.5787458163686097, 0.7445021253079176, 0.36144073179457337, 0.16089087759610265, 0.3974042582558468, 0.7427880610339344, 3.711326401680708, 9.824108742177486, 11.657440066337585, 29.29138943552971, 25.42084112763405, 28.772417083382607, 35.66313073039055, 27.709572315216064, 18.349361680448055, 3.4511702740564942, 0.18546889390563592, 0.06896195773151703, 0.06442937985411845, 0.05404831092164386, 0.01377567466988694, 0.052777605669689365, 0.029163379440433346, 0.03807944514846895, 0.015522591966146138, 0.02664097904926166, 0.03193524906237144, 0.08498685565427877, 0.011661667012958787, 0.03141700733976904, 0.04726566745375749, 0.01458155520595028, 0.032823421715875156, 0.01058845189618296, 0.021875212805753108, 0.05393697392719332, 0.03612785651057493, 0.0231280805382994, 0.008491554453939898, 0.015346916334237903, 0.05524768464965746, 0.06666034998488612, 0.018347204168094322, 0.06173163594212383, 0.011016039352398366, 0.03693373982969206, 0.04122570971958339, 0.049141616400447674, 0.10452509552123956, 0.04604010704497341, 0.027282775372441392, 0.05483978173288051, 0.03674848863738589, 0.029485133854905143, 0.05635740322759375, 0.04866356568527408, 0.016976876722765155, 0.03576030787371565, 0.06300248220213689, 0.004315815094741993, 0.06321252483758144, 0.05279192169837188, 0.029123399945092387, 0.04660175327444449, 0.08032776386244223, 0.024808879898046143, 0.027407717789174058, 0.06838017332484014, 0.035727163558476605, 0.03418689171667211, 0.08296304120449349, 0.059676094679161906, 0.01974879458430223, 0.017409190731996205, 0.023917603211884852, 0.031029498641146347, 0.041095303240581416, 0.04225710945320316, 0.04201664989523124, 0.04453630433999933, 0.07384560114587657, 0.06804782475228421, 0.052921419046469964, 0.051548015399021097, 0.05205253110034391, 0.028397965434123762, 0.055165458397823386, 0.09425989439478144, 0.07041560980724171, 0.024593686757725663, 0.033651717894827016, 0.007179693866419257, 0.028390749903337564, 0.070249554264592, 2.5900474190711975, 15.775276254862547, 40.915490090847015, 48.3316395431757, 41.94203540682793, 23.440286703407764, 29.77197054773569, 31.93394623696804, 28.153739981353283, 19.364974983036518, 12.077343184500933, 5.240849303081632, 1.2304205261170864, 0.09161830879747868, 0.08778562812949531, 0.3405689267674461, 0.13385614467551932, 0.6344949407503009, 1.1681488738395274, 1.3241256354376674, 2.215798613615334, 2.7296120300889015, 4.180599320679903, 9.687125142663717, 7.902846811339259, 8.160183727741241, 7.369890259578824, 5.263211578130722, 6.172521784901619, 4.051039572805166, 4.461754309013486, 6.772836372256279, 7.025332823395729, 11.673050578683615, 15.1340901106596, 23.33761241286993, 24.943706430494785, 28.812837414443493, 39.05112773180008, 47.135570123791695, 50.09143151342869, 56.3161700963974, 58.37210297584534, 58.94491843879223, 57.88776196539402, 58.86704541742802, 53.907429948449135, 57.67587773501873, 51.989786848425865, 47.265914529562, 54.49696831405163, 54.89063858985901, 58.96009862422943, 56.98535218834877, 57.234113439917564, 54.40913982689381, 56.59696742892265, 57.293667644262314, 58.26871432363987, 55.954661294817924, 56.53208211064339, 53.747982904314995, 52.496246472001076, 49.30381737649441, 40.08219860494137, 34.151796028018, 25.18607072532177, 17.78451818972826, 12.830193936824799, 8.734739497303963, 10.098501518368721, 6.006060792133212, 3.294674246571958, 9.26000241190195, 7.311874022707343, 7.110619246959686, 6.603903137147427, 4.07305084168911, 4.939411003142595, 3.5276846308261156, 2.1499063493683934, 1.293235905468464, 1.3675212068483233, 0.9053201833739877, 0.3944733686512336, 0.1458540157182142, 0.16558543662540615, 0.8968206925783306, 3.6654013535007834, 11.939617674797773, 16.285280138254166, 28.455899767577648, 30.43611031025648, 28.39771158993244, 40.3809005767107, 34.08171258866787, 21.557003259658813, 3.6005058232694864, 0.2531691041076556, 0.0692840498231817, 0.10027565440395847, 0.025175465598294977, 0.015255681337293936, 0.1109248650027439, 0.07705484065809287, 0.02568055089795962, 0.10859734145924449, 0.030909621382306796, 0.03426885450608097, 0.03389442616025917, 0.03894614375894889, 0.06775164103601128, 0.08331908655236475, 0.037897689471719787, 0.03167491107888054, 0.05404829978942871, 0.03981506139098201, 0.04316958744311705, 0.050904614181490615, 0.0026645638808986405, 0.07100938732037321, 0.03131088393274695, 0.024797807054710574, 0.05564836646954063, 0.009365588266518898, 0.02174913119233679, 0.04049356619361788, 0.03893338995112572, 0.04187059894320555, 0.040949938775156625, 0.01240117820998421, 0.0608284607733367, 0.08126361208269373, 0.040684216510271654, 0.03128052267129533, 0.1005445048213005, 0.17190810438478366, 0.11833886834210716, 0.1734297297662124, 0.15410193329444155, 0.17417303519323468, 0.14592140272725374, 0.1568015548400581, 0.14369546435773373, 0.13232775090727955, 0.12277237692615017, 0.17932552902493626, 0.14984755689511076, 0.18136045342544094, 0.25439311342779547, 0.1708128725294955, 0.1352108016726561, 0.2304253651527688, 0.10923762194579467, 0.06217349582584575, 0.10944292967906222, 0.13246157497633249, 0.16364504699595273, 0.12125713401474059, 0.13586586574092507, 0.12305915020988323, 0.15942149941110983, 0.13497493229806423, 0.11918024116312154, 0.133994807547424, 0.10948276074486785, 0.13424731587292627, 0.10699609847506508, 0.15353613474871963, 0.18996644241269678, 0.1493378053419292, 0.11474745246232487, 0.15385286853415892, 0.10664900342817418, 0.1366148263332434, 0.2905422361800447, 3.1008053245022893, 19.87442884594202, 46.59109354019165, 56.904697716236115, 52.44913659989834, 33.231599405407906, 36.44413322210312, 37.05498844385147, 25.13508316129446, 21.517738066613674, 14.874422494322062, 6.060709459707141, 1.434041268657893, 0.48322633432690054, 0.37509900983422995, 1.2995737278833985, 1.4200581377372146, 3.0558477994054556, 1.8917705258354545, 3.9278190722689033, 5.5487605556845665, 6.412513582035899, 9.649943187832832, 22.06833802163601, 16.780805848538876, 14.002758767455816, 17.286594808101654, 5.684529645368457, 8.728783316910267, 6.101160189136863, 5.999892773106694, 8.34594625979662, 6.575804594904184, 10.83847476169467, 14.420543499290943, 22.629117630422115, 25.58645524084568, 28.783012814819813, 38.37998114526272, 48.206945434212685, 49.70436528325081, 55.7251688092947, 59.5566476136446, 60.81169746816158, 58.250669091939926, 60.64098782837391, 53.48539039492607, 60.1467901468277, 54.3672888725996, 54.129569828510284, 52.96218886971474, 56.05723679065704, 61.22445032000542, 60.96688874065876, 58.016917034983635, 55.87367244064808, 59.47820462286472, 60.23943677544594, 59.79308992624283, 57.65233799815178, 57.31328219175339, 58.431159406900406, 51.47318556904793, 51.40868782997131, 41.57102711498737, 35.60309395194054, 25.214631892740726, 17.96337079256773, 12.544415071606636, 9.680697787553072, 12.110599000006914, 6.440373212099075, 3.5120318457484245, 7.782106390222907, 11.41632305458188, 15.834598671644926, 11.433252096176147, 16.59020997583866, 15.226869732141495, 8.130838852375746, 3.9284360641613603, 5.569509342312813, 5.3576574102044106, 2.5439224066212773, 1.2539067096076906, 0.40117742610163987, 0.9368967264890671, 1.130271793808788, 5.543764298781753, 13.281316179782152, 18.873674646019936, 38.8517714291811, 34.8869463801384, 38.01528811454773, 48.102166056632996, 42.5400473177433, 25.839289873838425, 4.957622950896621, 0.3937380784191191, 0.16213390073971823, 0.2333387846010737, 0.20867784071015194, 0.17046222259523347, 0.182079104706645, 0.23097384197171777, 0.12661572225624695, 0.2409765380434692, 0.11259428909397684, 0.12481605866923928, 0.17612289462704211, 0.14791495981626213, 0.17343005631119013, 0.14730378636159003, 0.11918688338482752, 0.11817227845313028, 0.11568906717002392, 0.20149172865785658, 0.13931174646131694, 0.13170544523745775, 0.06949681614059955, 0.13063719787169248, 0.11637652598437853, 0.214524153561797, 0.09463292750297114, 0.12589944584760815, 0.43038785399403423, 0.13737586908973753, 0.2478978072758764, 0.14635365922003984, 0.1567003852687776, 0.1990689875674434, 0.17231077887117863, 0.11452749473392032, 0.15073529910296202, 0.0695446995086968], [0.03693988481245469, 0.04346702538896352, 0.04873494544881396, 0.041738541185623035, 0.04696186188084539, 0.0639255803253036, 0.03476093552308157, 0.0431645964999916, 0.03515952077577822, 0.09947691054549068, 0.08117690696963109, 0.034950865956489, 0.020575122216541786, 0.03154394798912108, 0.020925621865899302, 0.0139491535446723, 0.04756397371238563, 0.0111562598067394, 0.029463286882673856, 0.02460123254422797, 0.06176876187964808, 0.018140415850211866, 0.04472967091714963, 0.06228628000826575, 0.032857538244570605, 0.049412526277592406, 0.042149694709223695, 0.03554286602593493, 0.006216741485332022, 0.030932351510273293, 0.08738333955989219, 0.05314294270647224, 0.03375959648110438, 0.06519904636661522, 0.029713425901718438, 0.02086105687340023, 0.09138116292888299, 0.022792021227360237, 0.057962408900493756, 0.041154804930556566, 0.051422009855741635, 0.19115947448881343, 5.441899839788675, 21.732608936727047, 43.12840014696121, 44.31373134255409, 31.94804348051548, 24.53763362020254, 25.694259256124496, 25.568786188960075, 20.95093958079815, 14.675514567643404, 8.199323527514935, 2.9936285130679607, 0.7848484197165817, 0.050467099572415464, 0.10149815716431476, 0.09506279428023845, 0.503400550223887, 0.4636851407121867, 0.7018871151376516, 0.9454031044151634, 1.9214057293720543, 2.7088539814576507, 6.2237924337387085, 4.408350074663758, 4.924393258988857, 7.479015178978443, 5.29112440533936, 4.4919403642416, 5.680202627554536, 1.989602807443589, 2.774316156283021, 1.60536338808015, 5.500911148265004, 6.2884098663926125, 11.047514844685793, 13.116244487464428, 16.784227564930916, 25.564946494996548, 32.95584440231323, 40.064643546938896, 48.704718723893166, 54.06117729842663, 56.906704008579254, 56.16448983550072, 57.122087851166725, 48.88292156159878, 61.48934930562973, 51.298755928874016, 49.45126086473465, 47.91726417839527, 51.35695360600948, 56.18032358586788, 59.16062146425247, 58.5747043043375, 55.58340981602669, 57.351397946476936, 57.584599032998085, 55.26935666799545, 57.47499771416187, 53.98406803607941, 49.87296223640442, 51.025535389781, 36.250784397125244, 31.83312814682722, 22.56015133112669, 16.862896643579006, 10.080499034374952, 6.7610840778797865, 3.8924047350883484, 3.193798684515059, 2.764510069973767, 2.5834706844761968, 10.848013199865818, 5.224013831466436, 4.916132977232337, 7.877640388906002, 3.0445647798478603, 4.023592220619321, 2.754565766081214, 1.208187562879175, 0.5912856780923903, 0.9196270687971264, 1.0538876987993717, 0.836100010201335, 0.034791430371114984, 0.4928526427829638, 2.434781575575471, 7.878917595371604, 12.65421872958541, 26.428233571350574, 32.21890054643154, 18.384587690234184, 34.85176406800747, 33.62267442047596, 22.365343384444714, 8.586590196937323, 0.9540909819770604, 0.03195471930666827, 0.049302873958367854, 0.01729179966787342, 0.043363325094105676, 0.06911063217557967, 0.08605377457570285, 0.08270192396594211, 0.05055811285274103, 0.03307847189716995, 0.058554535135044716, 0.05554857729293872, 0.021354186173994094, 0.028106806057621725, 0.008245101125794463, 0.06373415817506611, 0.02780676688416861, 0.061474081012420356, 0.09132612525718287, 0.03419488464714959, 0.024525117878511082, 0.08826846940792166, 0.05104166288219858, 0.0037201622672000667, 0.07224858098197728, 0.03513324132654816, 0.03816633208771236, 0.0531687137845438, 0.037308535538613796, 0.03379107096407097, 0.074560014763847, 0.013659715023095487, 0.023488929437007755, 0.05118242232128978, 0.027775067901529837, 0.02934550619102083, 0.016151346899277996, 0.11611724927206524, 0.06798236732720397, 0.06017375664669089, 0.04591184537275694, 0.027860212649102323, 0.1281535709858872, 0.015915883850539103, 0.0290907528687967, 0.042955385069944896, 0.04123570644878782, 0.13319785968633369, 0.05171503573365044, 0.027232936445216183, 0.03682680006022565, 0.045361572556430474, 0.05044278681452852, 0.04155309703492094, 0.007996391668712022, 0.03165316615195479, 0.037465039640665054, 0.06734117399901152, 0.031948626274243, 0.031760755300638266, 0.07231388255604543, 0.042531470317044295, 0.025428469307371415, 0.03053433585591847, 0.02420077522401698, 0.0074112063703069, 0.01004271174679161, 0.026489042866160162, 0.00947901626204839, 0.03565021397662349, 0.028992668776481878, 0.0381872606521938, 0.007765287809888832, 0.026814003358595073, 0.029038399916316848, 0.03308152954559773, 0.039826175052439794, 0.03349905811774079, 0.11385744670405984, 0.3074890002608299, 7.024828400462866, 26.14716835319996, 49.91295889019966, 47.5035385787487, 36.04903422296047, 25.00952459871769, 28.82635898888111, 27.717933766543865, 24.63674370199442, 21.206337176263332, 11.115851327776909, 3.5797814978286624, 0.6440493499394506, 0.10204537975369021, 0.19740475108847022, 0.24692105187568814, 0.48922490619588643, 0.31987271388061345, 1.42817378975451, 0.7907917757984251, 2.690007467754185, 2.1083705406636, 4.795765886083245, 5.9100717678666115, 6.489791935309768, 6.621514242142439, 6.600106190890074, 10.749063659459352, 6.97261112742126, 4.477893942967057, 5.191556923091412, 4.026286276057363, 7.56225636228919, 9.215842131525278, 13.483413085341454, 17.691723369061947, 18.99460505694151, 27.77791354805231, 35.83057254552841, 41.83792099356651, 50.33424608409405, 54.07999008893967, 56.04091666638851, 57.93903261423111, 59.921500235795975, 51.64032720029354, 61.659416779875755, 53.28497774899006, 45.29963783919811, 51.045058742165565, 55.383810326457024, 58.99299345910549, 60.87366834282875, 60.048010647296906, 57.80037805438042, 58.48174229264259, 58.575281873345375, 56.77462309598923, 57.3722930252552, 55.90320065617561, 53.851922526955605, 51.46633453667164, 38.59159559011459, 34.240468069911, 26.77976030856371, 18.45753237605095, 11.541077960282564, 7.821088973432779, 6.190380351617932, 7.985115721821785, 6.900017447769642, 3.81991911213845, 8.65802826359868, 7.339931717142463, 7.028337987139821, 4.260348491370678, 2.644684687256813, 4.184871716424823, 1.8862077430821955, 2.194765554741025, 1.2169365934096277, 0.8028856362216175, 0.13716336252400652, 0.06785128178307787, 0.11529848969075829, 0.5810538365039974, 3.29749820753932, 10.366417542099953, 17.70178332924843, 24.220447540283203, 35.98241999745369, 24.15140714496374, 37.21699655056, 40.87575942277908, 26.80529873818159, 10.306053031235933, 0.8621395379304886, 0.02144689340639161, 0.053603838678100146, 0.046126537563395686, 0.04268266806320753, 0.06760573480278254, 0.015157084235397633, 0.04120979807339609, 0.023778613795002457, 0.048053316204459406, 0.020795352684217505, 0.05019866475777235, 0.03882529243128374, 0.015645135390514042, 0.006524867749249097, 0.05511676979949698, 0.0942799101176206, 0.04945391585351899, 0.050584681739564985, 0.0233109568580403, 0.08436416406766511, 0.055808625838835724, 0.028736848616972566, 0.0630494007782545, 0.014476607175311074, 0.024676554967300035, 0.04555523599265143, 0.0715041252260562, 0.04945101034536492, 0.0029321211059141206, 0.03323285716760438, 0.013220412765804213, 0.035637768160086125, 0.04567871452309191, 0.017535834522277582, 0.014365088354679756, 0.029908783290011343, 0.04575137449137401, 0.20213331532431766, 0.07456866078427993, 0.10263250762363896, 0.2152680081781, 0.18541247583925724, 0.15053059993078932, 0.1205277290137019, 0.17222799971932545, 0.15070767636643723, 0.16725945461075753, 0.09478731648414396, 0.1194453882635571, 0.11945706966798753, 0.1352510557626374, 0.1362787967082113, 0.15801382338395342, 0.08723526625544764, 0.09596212141332217, 0.09757411069585942, 0.13374100788496435, 0.19527162570739165, 0.12900821340736002, 0.1291996578220278, 0.13984184770379215, 0.10908843541983515, 0.1596820674603805, 0.08921084852772765, 0.17135306698037311, 0.0903010783076752, 0.09303820799686946, 0.10057764171506278, 0.18556369584985077, 0.1902630491531454, 0.1546787453116849, 0.07482929562684149, 0.1695267009199597, 0.1431133534060791, 0.14759893849259242, 0.18958812521304935, 0.2448414353420958, 0.2576886350288987, 0.5584853037726134, 7.987122014164925, 30.750608034431934, 56.96376174688339, 55.20275764167309, 43.65764334797859, 34.32567469775677, 35.736497193574905, 37.23746985197067, 29.914664290845394, 20.624307207763195, 11.310395188629627, 4.06095989048481, 1.5393883595243096, 0.2221400136477314, 0.6821760290767998, 0.3145985375158489, 1.4547113282606006, 4.1833095252513885, 3.4996703965589404, 5.1078488398343325, 7.734498269855976, 9.359662514179945, 16.355118490755558, 13.902875427156687, 15.037368200719357, 17.735559716820717, 12.266566380858421, 11.372981630265713, 11.669719107449055, 5.252161296084523, 5.836269278079271, 4.217178532853723, 8.700317144393921, 8.70920866727829, 15.761615987867117, 16.59822754561901, 19.635577462613583, 28.72975867241621, 35.37954814732075, 43.58016550540924, 51.579378470778465, 55.317207500338554, 57.9933051019907, 57.72101171314716, 59.978208392858505, 52.74324081838131, 61.06269679963589, 57.31104031205177, 54.985177516937256, 50.32145217061043, 57.52590738236904, 60.710322707891464, 62.95471407473087, 62.95167803764343, 60.19720584154129, 60.710683688521385, 60.954425409436226, 59.052053689956665, 58.172822669148445, 58.99632968008518, 55.43131157755852, 52.379056960344315, 42.370717003941536, 34.29569810628891, 26.75286915153265, 18.492515198886395, 11.938447337597609, 7.987947519868612, 5.764301139861345, 6.974171893671155, 6.7416338715702295, 7.253704844042659, 16.574222333729267, 14.38100852072239, 13.652974236756563, 16.113288067281246, 11.289743296802044, 11.697540264576674, 7.543124388903379, 5.141111304983497, 2.8954814421012998, 3.8619781052693725, 2.4955973122268915, 1.4940228313207626, 0.23936407378641888, 0.6634910067077726, 3.5683778347447515, 10.900668874382973, 19.66723546385765, 36.57587595283985, 43.32959175109863, 29.57536719739437, 45.2980001270771, 47.87107765674591, 31.94493144750595, 11.550119575113058, 1.2396698235534132, 0.18735142570221797, 0.16024611453758553, 0.1093307689006906, 0.12953875993844122, 0.17119875963544473, 0.19009312702110037, 0.11124979209853336, 0.18478732032235712, 0.2164228048059158, 0.10657728227670304, 0.10411732248030603, 0.13253394921775907, 0.15375386603409424, 0.10207201543380506, 0.1733859727391973, 0.2395677487947978, 0.166981817164924, 0.11496910228743218, 0.08314650011016056, 0.21787379257148132, 0.1426767627708614, 0.14962829678552225, 0.13873686402803287, 0.1224455054034479, 0.11865537206176668, 0.24644986231578514, 0.11673002576571889, 0.19815525534795597, 0.1749742281390354, 0.1919634430669248, 0.1316203802707605, 0.15144154167501256, 0.13983518321765587, 0.19799854344455525, 0.14196884294506162, 0.17847676441306248, 0.1507122628390789], [0.034954376314999536, 0.051330514179426245, 0.04287387870135717, 0.04112882605113555, 0.01920014892675681, 0.053358028235379606, 0.04849759548960719, 0.022455178950622212, 0.01699604825262213, 0.051934414586867206, 0.04080262988281902, 0.03705432027345523, 0.026820153907465283, 0.025947850226657465, 0.08618809588369913, 0.08229989514802583, 0.053348948058555834, 0.06822199196903966, 0.0241476096198312, 0.0358828401658684, 0.04729745734948665, 0.0333529181079939, 0.11817214486654848, 0.06900624168338254, 0.04667199384130072, 0.04175789639702998, 0.05094514286611229, 0.020742021952173673, 0.018905321485362947, 0.046312100457726046, 0.05838998986291699, 0.10254304914269596, 0.022562781086890027, 0.05479676685354207, 0.06893253899761476, 0.03411833953578025, 0.02135988401278155, 0.05564111939747818, 0.022380253576557152, 0.018009881350735668, 0.04343421875091735, 0.05633339846099261, 0.5649877642281353, 8.243401162326336, 25.399640165269375, 42.32024431228638, 38.83384019136429, 41.92410036921501, 20.591868348419666, 29.295842796564102, 19.6303603425622, 19.328553937375546, 20.60991358011961, 9.354751277714968, 4.004066018387675, 1.4515861147083342, 0.3446701535722241, 0.1611667190445587, 0.4184515663655475, 0.33919877372682095, 0.5003049632068723, 0.901097422465682, 2.03844859264791, 0.9757595567498356, 1.8924392899498343, 3.7426804192364216, 6.299312906339765, 2.908524479717016, 4.951897608116269, 9.754573423415422, 2.8260734165087342, 3.357257363386452, 3.6477292142808437, 1.7278379411436617, 2.3274632217362523, 2.8634097380563617, 4.565539564937353, 7.54772974178195, 11.535424813628197, 17.4167188256979, 23.37509550154209, 31.421824917197227, 40.27196042239666, 49.19086463749409, 54.86843638122082, 57.75125429034233, 58.06778870522976, 45.45214645564556, 59.286071732640266, 53.58703874051571, 48.41078169643879, 47.08337992429733, 51.50269478559494, 50.30418589711189, 57.52195939421654, 58.57231043279171, 57.508675307035446, 57.384212985634804, 59.38980236649513, 54.32336322963238, 53.923465088009834, 46.13872781395912, 46.82745985686779, 37.63634964823723, 26.321136318147182, 22.789060547947884, 15.28397211804986, 10.70641664788127, 4.5512566063553095, 3.726786347106099, 3.262326344847679, 6.928210984915495, 7.670198595151305, 3.063113009557128, 10.795281529426575, 6.597269643098116, 4.630581624805927, 2.691178754903376, 0.8996366977225989, 1.8582773418165743, 0.8134637936018407, 1.012173774652183, 0.6814744917210191, 0.29179795004893094, 0.17658859229413792, 0.1346652043866925, 0.6517940468620509, 2.6063689682632685, 5.5491220112890005, 9.934103339910507, 18.008727058768272, 38.18698950111866, 17.34904445707798, 28.322576321661472, 36.48866683244705, 26.921317912638187, 10.78863188624382, 2.109105088748038, 0.045424413910950534, 0.026752542398753576, 0.02627441004733555, 0.04486923549848143, 0.041694624596857466, 0.012227684492245317, 0.02809934190736385, 0.05623939803626854, 0.03385135561984498, 0.02181809897592757, 0.0095356495512533, 0.12667795876041055, 0.0320935009222012, 0.03682296686747577, 0.05030546722991858, 0.025995718751801178, 0.10930094940704294, 0.05361471114156302, 0.01367739112538402, 0.03793228097492829, 0.008409072161157383, 0.018263517740706448, 0.041958209476433694, 0.040762219941825606, 0.057044669083552435, 0.0313268735044403, 0.05769574781879783, 0.030161252652760595, 0.005388917961681727, 0.10869662597542629, 0.014443602940445999, 0.04114405492146034, 0.07524023021687753, 0.05160477856406942, 0.024384334319620393, 0.08003184731933288, 0.058254466275684536, 0.0163251040794421, 0.0147605983329413, 0.04733217501780018, 0.016178839759959374, 0.029126565204933286, 0.054200703525566496, 0.08328960102517158, 0.0844934610358905, 0.020770286646438763, 0.04261289876012597, 0.035025284814764746, 0.019642966180981603, 0.028173001919640228, 0.03554357106622774, 0.03415490144107025, 0.044393214557203464, 0.07414115403662436, 0.05084229604108259, 0.04399253273732029, 0.009012896498461487, 0.04341926076449454, 0.050828325111069717, 0.07082906769937836, 0.06121711237938143, 0.018293064495082945, 0.03530308182234876, 0.05179063831747044, 0.02224361120170215, 0.05698449203919154, 0.01926012188050663, 0.02793379288050346, 0.03659455236629583, 0.08751472196308896, 0.007393397145278868, 0.01277271125218249, 0.028811061529268045, 0.046644838657812215, 0.09120391579926945, 0.026214900935883634, 0.03719575506693218, 0.04730031832878012, 0.03196319463313557, 0.01833564521803055, 0.7473395636770874, 10.598960313946009, 30.222814455628395, 48.43163877725601, 41.54844872653484, 44.20287609100342, 23.43109879642725, 30.421593189239502, 24.799623861908913, 23.300822786986828, 18.065915890038013, 10.254127867519855, 5.150506300851703, 1.1994409072212875, 0.2276386006269604, 0.1635349271236919, 0.2640947053441778, 0.40147698658984154, 0.8410486509092152, 0.9344223467633128, 1.8784740893170238, 3.134313588961959, 5.143024027347565, 7.325384672731161, 4.033029489219189, 6.996751232072711, 6.855633454397321, 10.042551420629025, 9.269349910318851, 5.887439232319593, 6.029862239956856, 4.414830626919866, 4.583727763965726, 4.5223316084593534, 10.034759938716888, 10.994066912680864, 15.72533268481493, 21.868719533085823, 29.398444890975952, 33.53319302201271, 42.95351833105087, 50.85413038730621, 56.2459384649992, 58.45659904181957, 59.39660020172596, 51.21467404067516, 60.29768005013466, 55.24166755378246, 45.2197091281414, 51.253032982349396, 55.58072715997696, 51.24109782278538, 59.94646869599819, 61.20757542550564, 59.425049275159836, 59.16335351765156, 61.77311047911644, 56.92671753466129, 56.288655772805214, 50.61561718583107, 47.99066863954067, 39.88069921731949, 30.076127126812935, 24.52245343476534, 16.356476917862892, 13.062332980334759, 6.739100832492113, 4.385846732184291, 6.81190112605691, 6.146547328680754, 5.2044235076755285, 4.795091422274709, 10.594559200108051, 6.734378635883331, 5.356245785951614, 4.633652335032821, 2.2077333088964224, 1.0483072232455015, 1.248164267744869, 1.0341846873052418, 0.47571440460160375, 0.22264486702624708, 0.01574916037498042, 0.08746198494918644, 0.5443801044020802, 2.022124668583274, 7.316580070182681, 13.31774577498436, 20.467730909585953, 40.87451308965683, 24.720552004873753, 28.53970807045698, 39.92604598402977, 31.356669813394547, 13.21349361911416, 2.4307504668831825, 0.0475745827134233, 0.005583372712862911, 0.028342831283225678, 0.07266814674949273, 0.03096648844802985, 0.055750077808625065, 0.039564942780998535, 0.029084220113873016, 0.017024589396896772, 0.0192743377192528, 0.04810181555512827, 0.056432104101986624, 0.019015669568034355, 0.03603981553169433, 0.020665265328716487, 0.036097602860536426, 0.0366483840480214, 0.07192974691861309, 0.010248406324535608, 0.03113883183686994, 0.027877851644007023, 0.05044154000643175, 0.07866766114602797, 0.06486391474027187, 0.031048308374010958, 0.02088560526317451, 0.07229908413137309, 0.07572952075861394, 0.006545315773109905, 0.06284798189881258, 0.11976845999015495, 0.049806636379798874, 0.012130880604672711, 0.06169245796627365, 0.08530968247214332, 0.015327653891290538, 0.022504195949295536, 0.016548175117350183, 0.12310957914451137, 0.16330952203134075, 0.15686346479924396, 0.2628475707024336, 0.14908865152392536, 0.15775974170537665, 0.1654883340233937, 0.07382694355328567, 0.12771136971423402, 0.1015311901574023, 0.13515767874196172, 0.10637070547090843, 0.15321920800488442, 0.11782280111219734, 0.22712687496095896, 0.2599552134051919, 0.15155642613535747, 0.18595978006487712, 0.14790777582675219, 0.12066941242665052, 0.2006638332386501, 0.15132869069930166, 0.20259914657799527, 0.16319794754963368, 0.16710315831005573, 0.11188769771251827, 0.1873821803019382, 0.19521235779393464, 0.1487534976331517, 0.11579909798456356, 0.1948399332468398, 0.15856523910770193, 0.15299476770451292, 0.10096361045725644, 0.11004867061274126, 0.21586356684565544, 0.18717593746259809, 0.24432665202766657, 0.1449608409893699, 0.08142721111653373, 0.09177894666208886, 0.13551444397307932, 1.0472362744621933, 13.038067482411861, 37.067280784249306, 55.950021743774414, 50.80830104649067, 54.47089411318302, 31.13754127174616, 42.61117950081825, 30.346045643091202, 28.219035677611828, 25.477572083473206, 12.950926758348942, 5.597938941791654, 2.1319095650687814, 0.7580988644622266, 0.37758274062070996, 1.011901495512575, 1.241536473389715, 2.8313085855916142, 2.600626526400447, 7.793449256569147, 7.195921819657087, 9.859119113534689, 12.42374399676919, 16.443412452936172, 11.22655363753438, 12.713768184185028, 18.551944009959698, 10.857224855571985, 9.306201282888651, 8.411856573075056, 5.1058216486126184, 5.119518488645554, 4.423392042517662, 7.703695222735405, 11.390800774097443, 16.056114435195923, 21.500167809426785, 29.350288175046444, 34.98181588947773, 43.79726305603981, 51.96325287222862, 57.894540801644325, 58.75935539603233, 60.807745680212975, 52.57902503013611, 63.12542751431465, 56.41267351806164, 55.04167668521404, 51.52444861829281, 57.975267469882965, 54.41679261624813, 61.16416275501251, 61.84355489909649, 60.53488232195377, 61.65967896580696, 63.52243021130562, 57.98926591873169, 57.195807695388794, 53.96823428571224, 45.82427188754082, 42.102003023028374, 30.670911110937595, 23.25394280254841, 17.423140481114388, 12.960891723632812, 6.247572032734752, 6.061094664037228, 6.90874082967639, 12.10971649736166, 14.358829110860825, 8.665503412485123, 22.9083551466465, 14.192940462380648, 11.517782360315323, 9.311609342694283, 6.486202077940106, 8.759386874735355, 3.6710051028057933, 4.513329416513443, 3.3278925390914083, 0.7361532014328986, 0.4588117537787184, 0.2411247746204026, 1.0576719394885004, 4.275619396939874, 7.7676747646182775, 15.48712631687522, 27.30151031166315, 48.73181127011776, 25.906648859381676, 38.53111803531647, 46.02111652493477, 37.09786914288998, 16.406430937349796, 3.192228418774903, 0.1147300936281681, 0.11300032550934702, 0.10854779568035156, 0.22501513827592134, 0.08829343525576405, 0.18803665065206587, 0.14926185394870117, 0.17469409707700834, 0.13072440022369847, 0.11256931582465768, 0.17260996828554198, 0.20914655149681494, 0.20689560275059193, 0.21344176086131483, 0.13281508960062638, 0.11778420943301171, 0.20009723317343742, 0.13752901868429035, 0.10659162056981586, 0.08983620442450047, 0.07143896466004662, 0.1140981400385499, 0.12817544949939474, 0.2640311775030568, 0.2055214421125129, 0.0990855686541181, 0.1671042270027101, 0.08896897517843172, 0.1470387208973989, 0.2038127658306621, 0.2798384183552116, 0.11324590217554942, 0.13071167981252074, 0.2460389499901794, 0.19223848299589008, 0.1628603445715271, 0.1579218712868169, 0.08993728493805975], [0.04394765135657508, 0.032424558157799765, 0.044502659075078554, 0.07567492095404305, 0.008751193890930153, 0.056388165248790756, 0.045837185316486284, 0.03998597429017536, 0.058451595541555434, 0.04776296205818653, 0.044067051785532385, 0.03773689204535913, 0.04648451249522623, 0.036837902589468285, 0.026288956141797826, 0.07991069171112031, 0.03934855107218027, 0.06346792011754587, 0.0686073224642314, 0.07858936456614174, 0.030590974711230956, 0.06285984884016216, 0.04245302530762274, 0.048376254344475456, 0.03627180718467571, 0.011513077915878966, 0.03872727327689063, 0.02924174095824128, 0.020222887796990108, 0.041119504676316865, 0.029408327136479784, 0.014140117418719456, 0.061862027578172274, 0.01713234552880749, 0.008670429670019075, 0.04091444927325938, 0.038639673875877634, 0.09049812593730167, 0.03530691501509864, 0.030369041014637332, 0.04976006290235091, 0.07517498059314676, 0.04719865522929467, 1.967228539288044, 11.719719674438238, 29.793766178190708, 51.0552041977644, 31.823784448206425, 26.030326522886753, 23.350451923906803, 21.738753207027912, 24.236053302884102, 23.61798606812954, 18.73919226229191, 9.007756747305393, 3.935024910606444, 2.0864371675997972, 0.4432165890466422, 0.13147254445357248, 0.10999480553437024, 0.7160402275621891, 0.4336968233110383, 0.9776695480104536, 1.8133448716253042, 4.283498749136925, 3.476982288993895, 1.387752746231854, 5.128030031919479, 5.3255158849060535, 11.453846041113138, 6.980201695114374, 5.389107847586274, 3.307079868391156, 2.730932221747935, 3.381552309729159, 2.4601117288693786, 4.383517457172275, 4.051228137686849, 5.367761068046093, 12.23430896177888, 15.174556989222765, 23.08935273438692, 31.422586776316166, 38.78058984875679, 46.58372953534126, 54.67940792441368, 55.86385756731033, 43.501441329717636, 57.498366460204124, 44.47982802987099, 38.32036234438419, 45.255358815193176, 53.73018465936184, 53.545119389891624, 55.204383954405785, 58.10034155845642, 55.68065419793129, 56.64960600435734, 54.882575422525406, 47.99467362463474, 45.24247370660305, 41.1432346701622, 36.976245269179344, 23.059816919267178, 21.173617132008076, 15.08869869634509, 9.553795997053385, 5.887720892205834, 3.2793826796114445, 1.0011342982761562, 5.232916753739119, 3.9990631118416786, 3.7152786646038294, 2.5014468608424067, 5.0008936040103436, 4.396393541246653, 4.449444869533181, 2.2619727859273553, 1.1337705748155713, 0.45645288191735744, 0.5204486916773021, 0.885435197269544, 0.30044471262954175, 0.08807008591247723, 0.08858986388077028, 0.5355955695267767, 1.0609698062762618, 4.124210821464658, 13.825316838920116, 18.832137174904346, 26.267996169626713, 24.0944766998291, 19.892679266631603, 34.92780178785324, 31.083358079195023, 15.691713988780975, 3.1318522710353136, 0.33510484965518117, 0.10750924164312892, 0.08457296731648967, 0.08511673149769194, 0.008157770753314253, 0.1233401644276455, 0.07980227877851576, 0.038191787753021345, 0.1267363064107485, 0.04067695830599405, 0.06841166265076026, 0.07731310062808916, 0.08409549918724224, 0.037462286272784695, 0.04330141884565819, 0.054018766022636555, 0.033178261073771864, 0.05544924453715794, 0.062632855551783, 0.07889886983321048, 0.025692249000712764, 0.035181915081921034, 0.02018896979279816, 0.02254590464872308, 0.01959773784619756, 0.0021360037544582156, 0.047139947637333535, 0.0371770492347423, 0.017458515721955337, 0.04513138432230335, 0.011241634620091645, 0.05300216842442751, 0.03519088764733169, 0.04893078708846588, 0.03482995154627133, 0.030165740790835116, 0.008627838742540916, 0.011316836444166256, 0.06461451601353474, 0.028785620706912596, 0.03831058333162218, 0.03950882157369051, 0.035441933941910975, 0.06869005708722398, 0.01792256582120899, 0.012015273478027666, 0.014356731771840714, 0.018987391886184923, 0.06671785158687271, 0.04207956917525735, 0.04083286868990399, 0.028965431956748944, 0.019259518885519356, 0.08714332157978788, 0.06757257564458996, 0.0420367992046522, 0.0170917760260636, 0.0963969828444533, 0.08351687632966787, 0.028962199903617147, 0.008960618688433897, 0.008734310958971037, 0.034724091601674445, 0.059995281262672506, 0.07689670383115299, 0.10700838101911359, 0.00820682022094843, 0.028477896594267804, 0.05587915213254746, 0.03381069705937989, 0.07451806857716292, 0.0288734167770599, 0.03364224437973462, 0.08006141448277049, 0.03270772460382432, 0.0433047139813425, 0.07174699305323884, 0.016236599258263595, 0.04618630642653443, 0.01689091932348674, 0.016141817723109853, 0.06189549843838904, 2.440586951561272, 14.829807188361883, 35.37788763642311, 54.555678963661194, 37.086351960897446, 28.329104371368885, 27.186537981033325, 23.15876740962267, 27.287863343954086, 28.29401135444641, 19.005816355347633, 10.234015546739101, 5.182089731097221, 1.8094383249990642, 0.31927632400766015, 0.11039282675483264, 0.1109655198524706, 0.10868070690776221, 0.7589641492813826, 1.3199768518097699, 2.8503821371123195, 2.439430863596499, 3.733676327392459, 2.8825326869264245, 7.057695211842656, 3.9916349854320288, 7.032055137678981, 10.694166105240583, 7.896014777943492, 8.122575245797634, 5.471392432227731, 5.826729414984584, 5.646894089877605, 6.782581899315119, 5.809563836082816, 8.212789054960012, 14.353505596518517, 19.28005713969469, 24.89195130765438, 34.84800606966019, 39.559692442417145, 48.46305549144745, 54.02200140058994, 57.991929575800896, 47.1260554343462, 63.629101887345314, 49.55376796424389, 38.71009983122349, 49.11152869462967, 57.26868398487568, 53.403527587652206, 56.87636263668537, 60.907243341207504, 58.991864919662476, 57.091955468058586, 56.72292307019234, 49.48784910142422, 48.49704086780548, 43.4445545822382, 38.96831497550011, 26.372239775955677, 23.427792973816395, 18.252643570303917, 13.873343411833048, 7.502508368343115, 8.16479193046689, 3.958905916661024, 8.59541617333889, 8.707829341292381, 5.54670344106853, 3.7356491340324283, 7.340865042060614, 6.103970613330603, 5.9049249440431595, 2.472832971252501, 2.202130272053182, 1.757086159195751, 1.041154582053423, 0.6010088813491166, 0.23363545071333647, 0.08426783329923637, 0.017067485532606952, 0.5554103187751025, 1.4084688783623278, 5.2819697465747595, 14.160177670419216, 22.100260108709335, 27.403456941246986, 29.944697879254818, 22.285279780626297, 36.77448369562626, 36.570860221982, 19.957374595105648, 4.693830655887723, 0.42642710090149194, 0.06174501686473377, 0.037781944120069966, 0.028727725766657386, 0.041868962507578544, 0.0395959571324056, 0.06632409029407427, 0.02582659257313935, 0.0239952095944318, 0.028480985783971846, 0.0440292022540234, 0.017311783849436324, 0.045704344593104906, 0.02389507160842186, 0.019749707425944507, 0.05881484343262855, 0.0574011114804307, 0.038277639396255836, 0.02331187712115934, 0.05212453426793218, 0.02334090808290057, 0.012182775280962233, 0.02289432071847841, 0.04021681561425794, 0.025277484928665217, 0.04535371692327317, 0.024902169716369826, 0.06262930066441186, 0.07073451808537357, 0.03992114397988189, 0.01115246835979633, 0.024538085053791292, 0.06877187886857428, 0.03277636584243737, 0.06547051656525582, 0.05910213621973526, 0.0663155852816999, 0.045052590503473766, 0.030427865494857542, 0.09059816744411364, 0.13399514893535525, 0.19479172333376482, 0.15790449018822983, 0.08599071428761818, 0.11723411473212764, 0.1250505179632455, 0.18495268566766754, 0.09875940959318541, 0.14244776568375528, 0.18728017952525988, 0.11219726977287792, 0.14313607796793804, 0.1344364002579823, 0.18143361434340477, 0.24358227790798992, 0.059469057741807774, 0.1955174101749435, 0.201267926604487, 0.14454234391450882, 0.11383943477994762, 0.12018499037367292, 0.10443993407534435, 0.0786813537706621, 0.10008976867538877, 0.2986662893090397, 0.20845935243414715, 0.15782319533172995, 0.17602582171093673, 0.13329423498362303, 0.18023460055701435, 0.1676015995326452, 0.1586444559507072, 0.18747931258985773, 0.15830308286240324, 0.08912953882827424, 0.14056950865779072, 0.21302462933817878, 0.18751389667158946, 0.10925589362159371, 0.10921054097707383, 0.1504718663636595, 0.19253011734690517, 3.2256462005898356, 18.31234596669674, 40.003957003355026, 62.36958347260952, 45.99654324352741, 35.70442691445351, 36.070389077067375, 35.05490876734257, 34.319104850292206, 34.04578551650047, 25.086996741592884, 13.054894879460335, 4.913861649110913, 3.6362911155447364, 0.7817538420204073, 0.6257162243127823, 0.6602279318030924, 2.4433142552152276, 2.9464523820206523, 4.485064158216119, 6.230312408879399, 8.588893823325634, 12.457926012575626, 7.415918614715338, 11.019879877567291, 14.760651849210262, 21.148373186588287, 14.484434220939875, 14.279715456068516, 12.039944641292095, 8.064141031354666, 7.580550955608487, 7.972196415066719, 8.816500660032034, 6.988977324217558, 8.057454340159893, 16.68757025152445, 19.927485398948193, 25.189764127135277, 34.58020403981209, 40.63840515911579, 49.68436695635319, 55.30029080808163, 57.6990032941103, 50.347347781062126, 65.23980125784874, 50.89987613260746, 46.11019894480705, 49.03349608182907, 59.816831052303314, 57.56029173731804, 57.81129486858845, 61.75588600337505, 60.55184081196785, 59.04563583433628, 57.532230243086815, 51.40304133296013, 50.3913988173008, 43.19711945950985, 38.63086648285389, 27.769231013953686, 23.722670450806618, 16.570798717439175, 12.571519017219543, 7.245909562334418, 7.001864807680249, 4.459480131044984, 12.558320425450802, 9.74770624190569, 10.237481910735369, 10.977218616753817, 13.63895583897829, 12.332059666514397, 15.735336598008871, 7.961301449686289, 6.209280537441373, 6.188040627166629, 4.122837670147419, 2.3543368047103286, 1.1812597140669823, 0.7139907125383615, 0.2524269267451018, 1.1898778891190886, 1.5197234647348523, 6.663481565192342, 19.36236262321472, 25.9802034124732, 34.62107464671135, 34.92878973484039, 28.265731371939182, 45.36606967449188, 42.35961779952049, 24.276300743222237, 5.5339280515909195, 0.7208919140975922, 0.21423136146040633, 0.17872124270070344, 0.177220263867639, 0.18891029205406085, 0.18443490407662466, 0.22319990443065763, 0.14506613690173253, 0.199720949458424, 0.16177495359443128, 0.26484400732442737, 0.18640478665474802, 0.18578979856101796, 0.1277801371179521, 0.09668335536844097, 0.1352311365189962, 0.19102762453258038, 0.15833652403671294, 0.19039895123569295, 0.16418651794083416, 0.09036882896907628, 0.07701820082729682, 0.07380449358606711, 0.13377719500567764, 0.09809969225898385, 0.11827842783532105, 0.1496675712405704, 0.17172788124298677, 0.12076163911842741, 0.08582296664826572, 0.0713692547287792, 0.13611165020847693, 0.13238516345154494, 0.14283908531069756, 0.13542157161282375, 0.12700962455710396, 0.15950110217090696, 0.12083648471161723, 0.10881695037824102], [0.05527876208361704, 0.010016115029429784, 0.03673784252896439, 0.0882049415668007, 0.03488854410534259, 0.015647064974473324, 0.014332245536934352, 0.03381518334208522, 0.04077233170391992, 0.022758719205739908, 0.02541322188335471, 0.01992688405152876, 0.043496559155755676, 0.07209140152554028, 0.05656438821461052, 0.019146296835970134, 0.025367128946527373, 0.09499430147116072, 0.060955813314649276, 0.01319404333116836, 0.015379033702629386, 0.028067665189155377, 0.041687199409352615, 0.04578949119604658, 0.026909044645435642, 0.08402043837122619, 0.04496430090512149, 0.020005490478069987, 0.0057136279792757705, 0.044998573284829035, 0.03218940495571587, 0.0464966466097394, 0.03212585113942623, 0.013714620035898406, 0.05293700785841793, 0.05210309362155385, 0.01724096255202312, 0.05222811581916176, 0.049279188315267675, 0.02330018087377539, 0.03420760505832732, 0.07660711780772544, 0.07864220548071899, 0.23200044000986964, 4.106852877885103, 17.380508668720722, 34.34701435267925, 45.082696080207825, 33.21211405098438, 29.749481454491615, 21.546287834644318, 19.691489562392235, 16.38386394828558, 20.602646470069885, 21.90752875059843, 13.859762940555811, 6.056356793269515, 2.720830226317048, 0.5567088397219777, 0.4272461944492534, 0.10163874962017871, 0.29811831715051085, 0.5897578631993383, 2.895514452829957, 2.733281683176756, 4.822923503816128, 2.1642192313447595, 7.762544564902782, 2.563489694148302, 4.625178789719939, 11.235026232898235, 4.40859136171639, 6.689860224723816, 4.7342785354703665, 3.826279495842755, 2.534408192150295, 4.644275614991784, 3.272018199786544, 3.1584620056673884, 5.226741610094905, 11.071056481450796, 14.024772886186838, 21.808504164218903, 30.21469049155712, 34.65191379189491, 48.78994435071945, 43.36058288812637, 47.574104592204094, 47.24743612110615, 30.44519942253828, 37.57077656686306, 44.24015589058399, 55.36922290921211, 53.26564058661461, 53.96411910653114, 52.331491112709045, 55.165436044335365, 51.685951352119446, 47.52271994948387, 40.32019883394241, 36.17024391889572, 31.72618478536606, 21.619508005678654, 16.005052775144577, 12.81629428267479, 9.45037504658103, 3.982253526337445, 2.988269138149917, 4.239804893732071, 1.8390310183167458, 8.38416175916791, 6.372376810759306, 2.363216928206384, 3.1637558341026306, 6.62385824136436, 6.419306667521596, 4.566815821453929, 2.600835752673447, 1.1116397310979664, 0.4821577307302505, 0.4759061458753422, 0.3350947267608717, 0.06921153457369655, 0.11396597838029265, 0.24085712648229674, 1.4752204902470112, 4.721739683300257, 8.842505514621735, 19.5913003385067, 15.7887626811862, 27.889908738434315, 23.03356982767582, 26.739402674138546, 30.65881635993719, 17.669804245233536, 7.164631448686123, 0.4576448007719591, 0.047593422132194974, 0.0658504368038848, 0.08511471285601147, 0.018480568105587736, 0.024887156068871263, 0.08412969735218212, 0.017244597220269497, 0.014798454358242452, 0.04114298993954435, 0.04745305974211078, 0.02304830151842907, 0.056479590421076864, 0.048268026948790066, 0.03053791671845829, 0.04390015761600807, 0.025623038163757883, 0.10274692453094758, 0.013230671102064662, 0.05925820616539568, 0.05696636137145106, 0.012337703246885212, 0.026641923432180192, 0.11260350656812079, 0.05267806882329751, 0.010758399075712077, 0.02939868478279095, 0.06177927440148778, 0.012491203506215243, 0.021297153980412986, 0.03573895257432014, 0.037125677772564813, 0.04367932415334508, 0.044006563039147295, 0.03874114772770554, 0.10604148876154795, 0.023018793726805598, 0.02599539035145426, 0.07801532818120904, 0.03550725035893265, 0.05989748846332077, 0.07968924968736246, 0.10061002161819488, 0.04588059353409335, 0.04215973225655034, 0.021015503371017985, 0.00830242554002325, 0.10690207578591071, 0.041287738422397524, 0.02659927777131088, 0.06332769873552024, 0.029945643909741193, 0.004180440400887164, 0.025357045014970936, 0.03275070608651731, 0.07134657469578087, 0.04728753483504988, 0.04268319869879633, 0.023868079697422218, 0.04087546425580513, 0.025291977217420936, 0.02055345892586047, 0.033112332384916954, 0.008219698338507442, 0.060517174351844005, 0.0729188219702337, 0.01188073045341298, 0.06884690999868326, 0.013557694765040651, 0.08057395651121624, 0.11889018016518094, 0.04409016968565993, 0.05745743306761142, 0.0027091834226666833, 0.053512179729295895, 0.03299625306681264, 0.034043145133182406, 0.08103629224933684, 0.022973624763835687, 0.02093531802529469, 0.0787965054041706, 0.039466641610488296, 0.07281635364051908, 0.31468299392145127, 4.932707212865353, 21.709584072232246, 40.40727116167545, 49.258280619978905, 38.53769168257713, 33.21643441915512, 26.388202719390392, 23.168567083775997, 25.30638176947832, 28.113952316343784, 23.860635347664356, 13.261533491313457, 6.407194342464209, 3.0156623432412744, 0.4303013492608443, 0.38310075702611357, 0.04585890055750497, 0.20272302586818114, 0.26268129993695766, 1.8633214524015784, 2.251747059635818, 1.8660114705562592, 2.8500446677207947, 1.5212001604959369, 4.5365209970623255, 4.345306232571602, 7.842772509902716, 7.150946483016014, 9.775337409228086, 7.034254744648933, 5.122636696323752, 5.7724816258996725, 5.047975927591324, 5.6661253329366446, 6.809659721329808, 7.485487656667829, 12.995033841580153, 16.355031095445156, 24.557464756071568, 32.15845339000225, 38.28657075762749, 48.280178904533386, 48.18467102944851, 51.39010302722454, 54.102036505937576, 36.829242557287216, 40.07328428328037, 46.640764474868774, 56.50158874690533, 56.01855866611004, 54.191715493798256, 53.41874957084656, 56.13145440816879, 52.54199981689453, 47.547772005200386, 42.72419683635235, 39.683277010917664, 34.99673388898373, 26.269119009375572, 17.677694521844387, 16.0910801589489, 11.69129814952612, 6.746787820011377, 6.7988664004951715, 8.771916702389717, 5.121832564473152, 5.943951224908233, 9.804110415279865, 8.853715863078833, 5.528184184804559, 5.444310335442424, 4.380540316924453, 3.7577428109943867, 1.585483686067164, 1.6213164757937193, 1.0442360979504883, 0.614350262330845, 0.07741998473647982, 0.12432267889380455, 0.09457983425818384, 0.3695337037788704, 1.2388102384284139, 5.1583291310817, 11.083727851510048, 25.836179740726948, 18.65341756492853, 30.816433802247047, 28.33219550549984, 29.096026718616486, 35.65470278263092, 21.567097418010235, 9.367680083960295, 0.6605981150642037, 0.0162457165424712, 0.03126353491097689, 0.05234338990703691, 0.025328813717351295, 0.051744283773587085, 0.10642949098837562, 0.017039094673236832, 0.04893322504358366, 0.10258961890940554, 0.03648197227448691, 0.04441882607352454, 0.011651256536424626, 0.06017107378283981, 0.0362609421426896, 0.013001261195313418, 0.06131702029961161, 0.10088705792441033, 0.0930319813778624, 0.030200347136997152, 0.014211973084456986, 0.031775754105183296, 0.01575595473696012, 0.023655821751162875, 0.050959662985405885, 0.03413816972170025, 0.024468235969834495, 0.027605463037616573, 0.0513118009257596, 0.009265293501812266, 0.022052719687053468, 0.03006150986038847, 0.08364809546037577, 0.07316051720408723, 0.02923151416325709, 0.055038892533048056, 0.03298586299933959, 0.03765730783925392, 0.06593206562683918, 0.05074131200672127, 0.1471358531853184, 0.12659286410780624, 0.2508255501743406, 0.11292231836705469, 0.1583861737162806, 0.13773763639619574, 0.11217543578823097, 0.2641257568029687, 0.21903023676713929, 0.1976764661958441, 0.11081350574386306, 0.1065838428621646, 0.11376162059605122, 0.10726673004683107, 0.3080708143534139, 0.09938049814081751, 0.1413238572422415, 0.11967699028900824, 0.11317742420942523, 0.10406961722765118, 0.08656699195853435, 0.10436656535603106, 0.09317477059084922, 0.13593206531368196, 0.19061542087001726, 0.19254444079706445, 0.11768033844418824, 0.14419982791878283, 0.06302241628873162, 0.1386825239751488, 0.1768617916968651, 0.15954625443555415, 0.07430548037518747, 0.11725688382284716, 0.1894062545034103, 0.14273199340095744, 0.07663666270673275, 0.18518036173190922, 0.11183562121004798, 0.1108306493551936, 0.21612414973787963, 0.15646984451450408, 0.1832110431860201, 0.6587085477076471, 6.350927436724305, 25.838091038167477, 45.676338225603104, 59.3990358710289, 45.23885250091553, 42.08860494196415, 32.65368841588497, 29.865424633026123, 28.211352489888668, 30.36900781095028, 27.737118937075138, 18.458385430276394, 8.423925675451756, 3.99005189538002, 0.7979369361419231, 1.0899225901812315, 0.16439017810625955, 1.1040376452729106, 2.073165192268789, 6.653771186247468, 7.814004253596067, 11.59456579014659, 8.703594468533993, 14.959140848368406, 9.144865740090609, 13.538805563002825, 20.71659665554762, 12.4943907558918, 14.128186237066984, 13.337124735116959, 9.05034676194191, 6.625686418265104, 8.773804251104593, 5.993054565042257, 6.704436717554927, 7.030489146709442, 14.207172598689795, 16.371740698814392, 24.591144248843193, 33.4499204903841, 38.94367329776287, 48.692164197564125, 53.29518020153046, 54.922553077340126, 55.710980370640755, 40.01291312277317, 45.825658813118935, 46.89276695251465, 55.89141368865967, 59.63848002254963, 57.289476469159126, 55.84492698311806, 56.49754196405411, 54.37605120241642, 47.27567620575428, 43.0187114328146, 37.959415912628174, 32.79384009540081, 25.967143513262272, 19.60517719388008, 15.144311562180519, 11.619587447494268, 5.321399280801415, 6.077652275562286, 8.125316798686981, 8.339369762688875, 15.30889118090272, 12.249944172799587, 10.442979633808136, 10.142638999968767, 15.214943122118711, 15.672661811113358, 8.100597225129604, 6.891652196645737, 3.8344628317281604, 2.8554225666448474, 1.8512889230623841, 0.9592313342727721, 0.5401690991129726, 0.3980011824751273, 0.4281017422908917, 1.941930209286511, 7.031786302104592, 14.217793978750706, 28.07275302708149, 25.485819540917873, 38.975747376680374, 31.705633588135242, 36.0252171009779, 42.205422073602676, 26.09977349638939, 11.35540472343564, 0.9050068783108145, 0.12140012360760011, 0.21154015586944297, 0.24449568358249962, 0.16300029878038913, 0.1610065042041242, 0.18375837709754705, 0.09861030470347032, 0.23433606780599803, 0.11888123728567734, 0.117873912822688, 0.2005042863311246, 0.14196507283486426, 0.22451145749073476, 0.14983792381826788, 0.13440399809041992, 0.2003917470574379, 0.22127092903247103, 0.21661003382178023, 0.14933074009604752, 0.15347386855864897, 0.18270133616169915, 0.20597720984369516, 0.14346015901537612, 0.21666156855644658, 0.0960053589369636, 0.1816526666516438, 0.1261314857401885, 0.1090406411094591, 0.22355825785780326, 0.12692985852481797, 0.0990710077167023, 0.24288565356982872, 0.11984555429080501, 0.1971094505279325, 0.2272788668051362, 0.12728295754641294, 0.1399183928151615, 0.17543560650665313, 0.17216908803675324], [0.03689114426379092, 0.06029471929650754, 0.037182337036938407, 0.050173561612609774, 0.024824876891216263, 0.025991466245613992, 0.06433932023355737, 0.04462039338250179, 0.061737391297356226, 0.05492499883985147, 0.06455634647863917, 0.024129033663484734, 0.04049495772051159, 0.008091004365269328, 0.03442980036197696, 0.018763027655950282, 0.016856541187735274, 0.06104775056883227, 0.08239140195655636, 0.04713670816272497, 0.01730393934849417, 0.0415316378348507, 0.00889511395143927, 0.020712978002848104, 0.09072845889022574, 0.06651552728726529, 0.012452535756892757, 0.03520095116982702, 0.04272469217539765, 0.07122763810912147, 0.06672731396974996, 0.02216873035649769, 0.07515581834013574, 0.07775591788231395, 0.05053763699834235, 0.0025553508203302044, 0.022863005797262304, 0.008542358173144748, 0.05768308306869585, 0.061218433402245864, 0.08031325487536378, 0.047554967750329524, 0.04124889812374022, 0.028456747240852565, 0.5386260256636888, 4.939671764150262, 21.91400170326233, 29.641208164393902, 36.50285147130489, 35.2784887701273, 28.03524523973465, 32.24482275545597, 23.04831113666296, 18.04640583693981, 22.48033281415701, 21.59817975014448, 14.417672753334045, 7.871811501681805, 3.3647434366866946, 0.7851079339161515, 0.43312911002431065, 0.11612559843342751, 0.12061545829055831, 0.6629419955424964, 1.0986875323578715, 0.6198345555458218, 1.9776915153488517, 3.5384599026292562, 3.097646269015968, 1.8250633240677416, 5.960045736283064, 6.692721946164966, 7.764959335327148, 5.256368620321155, 4.087279178202152, 4.526093881577253, 2.136863311752677, 2.216935227625072, 2.2653949772939086, 2.2017082571983337, 4.262072648853064, 8.385419491678476, 14.406488053500652, 19.471158385276794, 25.61367128044367, 38.08844938874245, 39.002931118011475, 34.486698657274246, 42.234851494431496, 27.852845527231693, 39.15339544415474, 46.46713279187679, 57.00307823717594, 47.52682372927666, 47.45527356863022, 47.756798788905144, 52.85266354680061, 44.76840354502201, 36.19021184742451, 30.088503062725067, 27.02755831182003, 18.600286915898323, 14.190036468207836, 12.066958341747522, 7.409816142171621, 5.481335073709488, 5.734628532081842, 5.414566481485963, 10.159338153898716, 4.808068200945854, 4.147013872861862, 17.28430163115263, 6.081872899085283, 3.102400526404381, 3.385839192196727, 3.27582654543221, 2.3090090369805694, 1.6952037485316396, 1.0109004867263138, 0.4178941244026646, 0.157779497676529, 0.1374181715073064, 0.11278867241344415, 0.7326053199358284, 1.3773409486748278, 3.9895004499703646, 5.758647043257952, 14.095042515546083, 10.721354596316814, 30.815229266881943, 37.24337473511696, 25.466769263148308, 32.6559416949749, 24.038408808410168, 11.93449079990387, 1.7542119696736336, 0.059611817268887535, 0.050199956094729714, 0.040058422746369615, 0.020812551956623793, 0.04880289277934935, 0.018039793612842914, 0.013592738978331909, 0.04311394863179885, 0.04884215239144396, 0.08444154780590907, 0.08131461247103289, 0.026825413879123516, 0.041919721697922796, 0.05364226337405853, 0.05867462947207969, 0.008488237053825287, 0.05499399630934931, 0.04041225649416447, 0.020936021210218314, 0.06631571144680493, 0.02451640506478725, 0.029164720872358885, 0.06659283681074157, 0.02996945200720802, 0.03627933627285529, 0.08909722571843304, 0.07209603994851932, 0.06621968495892361, 0.05327461825800128, 0.011265056800766615, 0.0172540466155624, 0.020064472664671484, 0.024252215334854554, 0.03963863433455117, 0.030643667196272872, 0.04927960762870498, 0.05474520614370704, 0.05026940627431031, 0.027331219062034506, 0.034612672970979474, 0.06525645148940384, 0.04901955166133121, 0.07144174771383405, 0.03374538806383498, 0.05486143760208506, 0.0451270576013485, 0.0656867709767539, 0.0303686495317379, 0.06407603592379019, 0.01770290866261348, 0.03942720388295129, 0.057616093108663335, 0.07442541886121035, 0.029143469473638106, 0.02241699545265874, 0.05627797858323902, 0.016639650384604465, 0.05185817746678367, 0.04079189100593794, 0.10127033267053775, 0.04623998967872467, 0.027024001465179026, 0.016244846374320332, 0.017162818112410605, 0.05469039853778668, 0.02980337605549721, 0.03076577646424994, 0.03503458763589151, 0.042207452352158725, 0.08084099608822726, 0.054869578962097876, 0.0601276544330176, 0.06495856083347462, 0.012476754818635527, 0.0031879904327070108, 0.05060805568064097, 0.054479346581501886, 0.03432290141063277, 0.0386903848266229, 0.0367654838191811, 0.031950964039424434, 0.005135417941346532, 0.022434792153944727, 0.05475450525409542, 0.9872643300332129, 6.509230742231011, 26.782893240451813, 36.21031276881695, 42.787539437413216, 39.46001619100571, 32.26474888622761, 31.448767371475697, 26.13767646253109, 22.617499753832817, 28.458042852580547, 28.500952050089836, 16.036982461810112, 7.920134933665395, 3.1418682960793376, 0.6728598196059465, 0.14126007707091048, 0.08606637624325231, 0.3221217478858307, 0.5701728828717023, 1.0374984657391906, 1.4297613920643926, 2.006491357460618, 2.3130788560956717, 3.1073412112891674, 3.6663987999781966, 5.831418363377452, 6.115363826975226, 7.497189603745937, 6.807139506563544, 6.2308253813534975, 6.36830722913146, 4.545097136870027, 6.558829480782151, 4.9715278297662735, 4.622941184788942, 6.403643433004618, 11.014220081269741, 17.04468458890915, 22.311815656721592, 28.108860589563847, 40.83909898996353, 42.19929680228233, 41.79146468639374, 45.82901023328304, 36.954860016703606, 39.300918728113174, 47.49703712761402, 56.83103866875172, 54.204106628894806, 52.03310452401638, 53.43090131878853, 53.62232364714146, 48.029301166534424, 38.43531757593155, 32.46912091970444, 29.23535004258156, 22.70469557493925, 18.17155212163925, 15.771839339286089, 10.2692586556077, 8.44386225566268, 4.817825127393007, 6.652808887884021, 10.047998428344727, 5.002344651147723, 5.486062495037913, 11.504956148564816, 8.594865202903748, 3.650544863194227, 3.4980647452175617, 3.3915745094418526, 1.7691322253085673, 2.199542373418808, 0.3153392899548635, 0.5294128856621683, 0.2328101676539518, 0.18106144212651998, 0.06635359808569774, 0.7800908375065774, 1.5476005501113832, 4.524167384952307, 9.9104087613523, 19.99591402709484, 14.3370477296412, 25.816263109445572, 38.247482255101204, 27.395952343940735, 34.44003336131573, 30.372296534478664, 15.087259523570538, 2.4447396537289023, 0.09385202487464994, 0.032788878452265635, 0.028357778137433343, 0.10291570375557058, 0.010134286276297644, 0.0053879731149208965, 0.03917111098417081, 0.04083860549144447, 0.031000597555248532, 0.034048481174977496, 0.012163905248598894, 0.028122081312176306, 0.06252283958019689, 0.026495115489524323, 0.05311312692356296, 0.04049897273944225, 0.029912237987446133, 0.06028405834513251, 0.03440069704083726, 0.021574340571532957, 0.06335319892968982, 0.04116795207664836, 0.016170592643902637, 0.022232781411730684, 0.03970903446315788, 0.014780603851249907, 0.03485978959361091, 0.010041596669907449, 0.01644464922719635, 0.02269714135763934, 0.0632585008861497, 0.026574760922812857, 0.05229874972428661, 0.038931033632252365, 0.03641713825345505, 0.026292191905668005, 0.05155617531272583, 0.08327318471856415, 0.036847186856903136, 0.014713615746586584, 0.19370271067600697, 0.21801852621138096, 0.1505962948431261, 0.15636407362762839, 0.18573525070678443, 0.1420668509672396, 0.16360694513423368, 0.07187321010860614, 0.1495050557423383, 0.1210733040352352, 0.22140761779155582, 0.1403829624177888, 0.10947928007226437, 0.06383175059454516, 0.11209721342311241, 0.0978487943939399, 0.13921350095188245, 0.15370280627394095, 0.17466809222241864, 0.1649480059859343, 0.10461136276717298, 0.14625099051045254, 0.1154009802849032, 0.16444845154182985, 0.19144793244777247, 0.10743618462583981, 0.11410903476644307, 0.1635490873013623, 0.2048309033853002, 0.14466831606114283, 0.19222151750000194, 0.18893200729507953, 0.1597500778734684, 0.1848980487557128, 0.14233904104912654, 0.16058922425145283, 0.24015037924982607, 0.12967191607458517, 0.1281253990600817, 0.21255712083075196, 0.1817348223994486, 0.09537273741443641, 0.13031051930738613, 0.09518056569504552, 1.129278859589249, 7.860157052055001, 30.173350609838963, 44.50644180178642, 51.55554614961147, 46.281182169914246, 40.079306960105896, 44.91083510220051, 34.73514832556248, 28.631722033023834, 31.516922414302826, 29.95537530630827, 20.087318122386932, 11.093961652368307, 4.267724845558405, 1.1539470171555877, 0.7709826668724418, 0.5801481194794178, 1.083506871946156, 3.1389780761674047, 3.4338686149567366, 4.424654524773359, 9.442797303199768, 12.38828619942069, 11.771396901458502, 8.26501915231347, 15.988327972590923, 17.2777583822608, 17.51865405589342, 13.052891436964273, 12.504466865211725, 10.348757039755583, 7.9857464879751205, 5.751388482749462, 5.907211471349001, 5.140536110848188, 5.8857730217278, 10.911333002150059, 17.331609092652798, 22.720031552016735, 30.44354271143675, 44.38820354640484, 46.56587429344654, 47.02848047018051, 50.180517733097076, 39.81941990554333, 44.6038343757391, 47.036707028746605, 59.414972215890884, 56.74110509455204, 56.735424399375916, 55.76439030468464, 57.07294888794422, 46.868581250309944, 39.48617398738861, 33.21734257042408, 29.535725824534893, 23.970223367214203, 18.920942209661007, 15.045749600976706, 11.173449587076902, 9.405562151223421, 8.423713836818933, 9.894597809761763, 17.260039933025837, 12.12455565109849, 11.461103651672602, 24.657456390559673, 15.98776750266552, 10.352471340447664, 7.792722070589662, 8.46508601680398, 6.663188980892301, 7.443094756454229, 3.953063255175948, 2.16347043402493, 0.8509697404224426, 0.7031284016557038, 0.3343687579035759, 1.3457062211818993, 2.416449459269643, 5.713647482916713, 10.409414134919643, 20.803556889295578, 18.633022159337997, 39.6508951485157, 48.11291188001633, 32.38892622292042, 43.869177997112274, 35.167276337742805, 17.77627643197775, 2.4910197453573346, 0.1505560555960983, 0.09474344813497737, 0.1478764571947977, 0.14459237951086834, 0.10905645627644844, 0.09900841498165391, 0.1298346690600738, 0.1220571988960728, 0.11388082435587421, 0.21552085789153352, 0.10984794935211539, 0.193357270618435, 0.19361555285286158, 0.07901544639025815, 0.1587386493338272, 0.07929836050607264, 0.15257901657605544, 0.10719183250330389, 0.13546477945055813, 0.12328416938544251, 0.17050017602741718, 0.068939522607252, 0.12017300468869507, 0.09706468568765558, 0.0783119052357506, 0.15687188075389713, 0.32596660719718784, 0.22858338430523872, 0.13524701847927645, 0.1103718536614906, 0.2642806281801313, 0.07978517969604582, 0.12077612584107555, 0.10297605520463549, 0.14090619137277827, 0.1025911996839568, 0.08496829454088584, 0.30526172602549195, 0.07805872155586258, 0.06296271050814539], [0.05119479392305948, 0.028586329935933463, 0.07681674484047107, 0.04220194561639801, 0.08658804668812081, 0.023978453755262308, 0.039565365805174224, 0.06292557343840599, 0.02155748454242712, 0.04134917711780872, 0.07943467076984234, 0.025097746038227342, 0.0730092526646331, 0.042231609259033576, 0.03865591577778105, 0.030778003347222693, 0.01645736221689731, 0.07323555575567298, 0.05987744305457454, 0.026688118414313067, 0.04925055254716426, 0.0064659690542612225, 0.03429987256822642, 0.022112549777375534, 0.01734459790895926, 0.03605983867601026, 0.0675116824277211, 0.08470481727272272, 0.020815299758396577, 0.02072723837045487, 0.09761190827703103, 0.09131711558438838, 0.09600874313036911, 0.03237477118091192, 0.02761264331638813, 0.006497964895970654, 0.04749840867589228, 0.03769986258703284, 0.0380818014673423, 0.0582651420700131, 0.03736893893801607, 0.03340486844535917, 0.039195446006488055, 0.06695326825138181, 0.04828589786484372, 0.5870309751480818, 6.131908614188433, 27.230522520840168, 36.593955382704735, 41.49506539106369, 35.83326660096645, 27.993333488702774, 18.347184397280216, 22.76708822697401, 20.77392227947712, 21.43504310399294, 26.062983870506287, 18.731786459684372, 10.368354488164186, 5.099383369088173, 0.9494113549590111, 0.3803460829658434, 0.22828544169897214, 0.13858646037988365, 0.5296197370626032, 0.4601676278980449, 0.787809113971889, 0.606404235586524, 3.12572771217674, 2.277705129235983, 3.370053176768124, 1.9496551947668195, 7.968494463711977, 4.958400959149003, 5.462503284215927, 4.855046030133963, 4.05886335298419, 6.221745768561959, 4.812799897044897, 1.9080233224667609, 4.247429659590125, 3.5556242940947413, 7.623452553525567, 12.308717519044876, 22.031692788004875, 26.28031700849533, 27.30465654283762, 23.775894194841385, 41.5502954274416, 25.499386712908745, 25.749479793012142, 41.74728825688362, 49.87743839621544, 42.42989122867584, 34.44644741714001, 35.052488297224045, 40.87024971842766, 36.73148900270462, 29.24994695931673, 21.354181542992592, 15.270154159516096, 10.960308574140072, 8.795589432120323, 5.336721958592534, 2.7126131672412157, 3.8912771455943584, 2.4725285125896335, 7.124972501769662, 9.310614746063948, 3.540044417604804, 2.3359906766563654, 7.009432101622224, 8.366776742041111, 2.6779108168557286, 2.234967635013163, 1.6151993977837265, 1.4837918803095818, 1.428212618920952, 0.6280176539439708, 0.2069547222345136, 0.21086210006615147, 0.14066303410800174, 0.6576739344745874, 1.7424274957738817, 3.9313044352456927, 6.979544330388308, 16.007266156375408, 17.48455658555031, 18.896777406334877, 29.640714190900326, 25.426936000585556, 29.267232231795788, 30.806972309947014, 14.452939610928297, 3.7770897103473544, 0.056025908124865964, 0.0423826771293534, 0.010795698490255745, 0.04543295603070874, 0.026232092786813155, 0.005627407581414445, 0.03538570883392822, 0.03464157591224648, 0.011996227185591124, 0.02805214131512912, 0.04569606222503353, 0.056518323108321056, 0.04627173133485485, 0.021700064098695293, 0.020203571548336186, 0.04778307426022366, 0.0518812768132193, 0.01888081205834169, 0.04822237744519953, 0.03431834091315977, 0.08600301909609698, 0.08307181036798283, 0.020438236788322683, 0.0925580904004164, 0.021793973610328976, 0.04569130876916461, 0.027115417360619176, 0.051388409119681455, 0.06101338170992676, 0.016607096076768357, 0.05558018907322548, 0.031855739071033895, 0.02224677831691224, 0.046069800373516046, 0.05245904620096553, 0.014102393124630908, 0.016135568839672487, 0.010771145462058485, 0.024880764322006144, 0.0336435765348142, 0.07515824516303837, 0.09621250719646923, 0.030018643410585355, 0.06921537147718482, 0.012281909512239508, 0.03402821683266666, 0.03545434265106451, 0.04801829425559845, 0.05612279179331381, 0.04071030671184417, 0.06766263526515104, 0.05837405966303777, 0.06592863690457307, 0.053294403915060684, 0.02888328363042092, 0.03284800535766408, 0.052485088162939064, 0.03778798520215787, 0.043080058458144777, 0.03715639155416284, 0.03528460605593864, 0.031992565127438866, 0.07365615310845897, 0.04075454613484908, 0.008921827557060169, 0.04227094308589585, 0.04738268558867276, 0.045015694631729275, 0.08512921442161314, 0.03168937924783677, 0.03206054214388132, 0.05458117666421458, 0.05698159395251423, 0.04845698887947947, 0.06432356443838216, 0.04810444646864198, 0.01895738871098729, 0.03810913105553482, 0.03364313124620821, 0.0567986137320986, 0.04281271460058633, 0.02773033680568915, 0.0463106272945879, 0.033122236345661804, 0.06579910987056792, 0.0354460677044699, 1.0811924398876727, 8.609726205468178, 31.27901528030634, 41.03071130812168, 46.11002795398235, 40.16302406787872, 33.45097303390503, 22.84074917435646, 24.607188887894154, 25.25450125336647, 24.782150499522686, 29.836722873151302, 20.05497045814991, 12.619844824075699, 4.511956265196204, 0.9671134769450873, 0.30255698366090655, 0.14738753030542284, 0.1758225919911638, 0.16118696483317763, 0.30049672233872116, 1.2141424370929599, 0.9473451564554125, 3.6871338123455644, 2.5798988761380315, 3.094853893853724, 3.030508146621287, 7.135309847071767, 4.8447162844240665, 3.6328135896474123, 6.639637844637036, 6.182665340602398, 6.345634795725346, 4.941026866436005, 4.255211167037487, 4.675940265879035, 4.801454180851579, 10.264994334429502, 14.794001709669828, 24.684313349425793, 30.426078848540783, 32.29423150420189, 31.686133034527302, 44.04529854655266, 30.978073328733444, 28.32849070429802, 44.434986636042595, 51.32765717804432, 47.14791186153889, 43.66158753633499, 41.10638804733753, 46.38952575623989, 40.313381999731064, 32.891171872615814, 24.84458114951849, 17.8441920876503, 16.789074204862118, 12.025022841989994, 8.317814469337463, 6.074483720585704, 5.517660174518824, 4.810568941757083, 6.380292735993862, 8.592332638800144, 5.588915850967169, 5.407274197787046, 9.708845727145672, 4.20340427197516, 3.7466540560126305, 3.455331763252616, 2.217812743037939, 0.6723119365051389, 0.7671036687679589, 0.27430938847828656, 0.17036265606293455, 0.017553185934957583, 0.21878463041502982, 0.4457093443488702, 1.682256180793047, 5.030269352719188, 10.3927843272686, 18.817452862858772, 19.76658683270216, 17.053796499967575, 32.5996895134449, 31.36138156056404, 31.715532056987286, 35.816752687096596, 18.314829133450985, 4.827028708532453, 0.15108111023437232, 0.01416696924934513, 0.03674809529911727, 0.04622837506758515, 0.05765159374277573, 0.03188676084391773, 0.02219740879809251, 0.041776732105063275, 0.08082147760433145, 0.025788655839278363, 0.024299798133142758, 0.05820758480695076, 0.00208675483463594, 0.0888904336898122, 0.05349151833797805, 0.028456439249566756, 0.02718747804465238, 0.16177146550035104, 0.037435375998029485, 0.04051317744597327, 0.026684400254453067, 0.05195755104068667, 0.025035422331711743, 0.03228399909858126, 0.019819788431050256, 0.009223002216458553, 0.02214083116996335, 0.08022012276342139, 0.010855405198526569, 0.03245631836762186, 0.050728966380120255, 0.05174552687094547, 0.0228997235535644, 0.03645336619229056, 0.047983301992644556, 0.05283017198962625, 0.004810891605302459, 0.020953728853783105, 0.034461998438928276, 0.04014371406810824, 0.05713417209335603, 0.21416069415863603, 0.1719267322914675, 0.1853032613871619, 0.15652324946131557, 0.12784118618583307, 0.11919901007786393, 0.10681905172532424, 0.151434535800945, 0.16086956311482936, 0.3010575188091025, 0.10404203159851022, 0.10402511063148268, 0.16084054514067248, 0.10225199366686866, 0.1489124062936753, 0.1175427071575541, 0.11353824156685732, 0.18108143558492884, 0.13440972747048363, 0.18774964730255306, 0.14282433141488582, 0.17550683784065768, 0.18703826906858012, 0.1435741677414626, 0.19567959912819788, 0.15358072298113257, 0.1735975590418093, 0.252783513860777, 0.11624568534898572, 0.1204271383176092, 0.21374356263549998, 0.0955565451295115, 0.20642310701077804, 0.15924691659165546, 0.12103043758543208, 0.09685415323474444, 0.11395224864827469, 0.10888810007600114, 0.18771007598843426, 0.1901309913955629, 0.13977159600472078, 0.09723301220219582, 0.10100054714712314, 0.16240705561358482, 0.23409155983245, 1.582384833600372, 10.266849584877491, 36.25956192612648, 49.54732730984688, 52.56475679576397, 49.46101114153862, 41.16402715444565, 29.974710568785667, 33.86998414993286, 32.797959074378014, 30.32063640654087, 32.234114930033684, 23.483858965337276, 13.859914932399988, 6.288514360785484, 1.5169081720523536, 0.9364583843853325, 0.5385397584177554, 1.1926319100894034, 1.8481757026165724, 1.7967223073355854, 3.8170835142955184, 3.1934118177741766, 9.041481837630272, 8.572617396712303, 10.624835025519133, 9.31654242798686, 18.067946881055832, 13.245426155626774, 12.450036685913801, 13.822151608765125, 10.062726438045502, 12.782250959426165, 9.812279976904392, 4.468515571206808, 6.800347846001387, 5.994059611111879, 9.893683958798647, 16.03046391159296, 25.53140189498663, 32.76323653757572, 36.72743462026119, 35.18545836210251, 50.15797734260559, 35.10591723024845, 34.046712666749954, 48.823048174381256, 55.07443092763424, 51.88919484615326, 53.28834816813469, 45.27125336229801, 45.147680193185806, 41.30996212363243, 32.85101942718029, 26.07511091977358, 19.877090603113174, 18.715952709317207, 12.79619811102748, 8.536674175411463, 6.352881481871009, 7.323756460100412, 5.1564444322139025, 12.766701243817806, 16.566951423883438, 9.110917411744595, 12.595305740833282, 17.86124937236309, 20.010469146072865, 9.867716152220964, 8.74940576031804, 5.686249528080225, 6.624579727649689, 3.1025658175349236, 2.1755630476400256, 1.2306175217963755, 0.7733863941393793, 0.5537770001683384, 1.3399090385064483, 2.1364075737074018, 6.002779668197036, 11.22886011376977, 22.060856223106384, 25.92183094471693, 27.612217739224434, 40.40029093623161, 34.971100464463234, 40.00841036438942, 41.11162796616554, 22.795843183994293, 5.702966256067157, 0.34221263544168323, 0.15811794670298696, 0.14063224982237443, 0.15249353600665927, 0.18641002621734515, 0.08459564734948799, 0.11604129045736045, 0.08988864457933232, 0.2667569671757519, 0.08085075533017516, 0.1282865638495423, 0.2549966872902587, 0.12954635953065008, 0.1344354057800956, 0.14693446399178356, 0.12188970358693041, 0.06577200663741678, 0.2266119432169944, 0.12014438005280681, 0.11545633708010428, 0.25926338334102184, 0.11854635798954405, 0.13260469073429704, 0.15351882786490023, 0.10878753906581551, 0.12221756958751939, 0.08985593070974573, 0.13966251513920724, 0.16331744816852733, 0.12126585424994119, 0.13379693613387644, 0.09390134800923988, 0.2267406167811714, 0.09477154584601521, 0.1769766613142565, 0.088280343770748, 0.1188319364155177, 0.12642458954360336, 0.1593162925564684, 0.1315662034903653, 0.17098977084970102], [0.034534799415268935, 0.014023889671079814, 0.03551995221641846, 0.047220299966284074, 0.021168909006519243, 0.06916803729836829, 0.036568888899637386, 0.030992612046247814, 0.04173236280621495, 0.010049364173028152, 0.053692555011366494, 0.016812648718769196, 0.04880911568761803, 0.027847544188261963, 0.051141611620550975, 0.04344346220022999, 0.01737730621243827, 0.02179896826419281, 0.004801788700206089, 0.035208402332500555, 0.05894503839954268, 0.04511925762926694, 0.026050305568787735, 0.03396531239559408, 0.03815768606727943, 0.05409124045399949, 0.02581351964181522, 0.06465746409958228, 0.02398857850494096, 0.032874247699510306, 0.020197100020595826, 0.040543802169850096, 0.0441699839575449, 0.10263902368023992, 0.04958207362506073, 0.004413203887452255, 0.02650150352565106, 0.10532786182011478, 0.03672967890452128, 0.036653163479059, 0.08551426290068775, 0.021524913536268286, 0.021853610742255114, 0.04060922619828489, 0.02867500916181598, 0.030370376880455296, 2.141083935275674, 10.947809144854546, 26.052906811237335, 42.65643887221813, 44.416987001895905, 33.78070414066315, 19.923377819359303, 18.45556978136301, 20.199628695845604, 27.483197562396526, 20.722100660204887, 19.38208356499672, 14.345114696770906, 8.52642422541976, 5.409088125452399, 1.0901397722773254, 0.7612330431584269, 0.1875855287653394, 0.1773304134258069, 0.29786738217808306, 0.8060670155100524, 0.4426814411999658, 0.9415786690078676, 2.2104902984574437, 2.1406001737341285, 3.306777784600854, 3.5094439471140504, 2.638907809741795, 1.775525500997901, 6.4360214956104755, 4.179492155089974, 6.529559651389718, 3.0577108869329095, 4.299067938700318, 1.6567626362666488, 2.2354810824617743, 4.2656496819108725, 4.476932119578123, 15.862289685755968, 15.37910096347332, 19.718791097402573, 20.705573447048664, 27.192224375903606, 21.740601807832718, 14.007702302187681, 19.720499105751514, 27.568757571280003, 34.442381635308266, 37.110362872481346, 34.51567590236664, 25.55592767894268, 23.591262102127075, 18.147791996598244, 13.724032323807478, 7.553311642259359, 7.702240850776434, 2.9977448796853423, 2.5746038602665067, 3.382516745477915, 5.245648445561528, 5.198665391653776, 3.5853902343660593, 8.057559784501791, 2.9801620356738567, 4.11696651019156, 7.285397043451667, 3.544656657613814, 1.0089654405601323, 2.096628458239138, 1.6590717248618603, 0.6622157001402229, 0.19715838774573058, 0.12792015069862828, 0.1499016594607383, 0.27363073895685375, 0.5550467257853597, 1.7527230433188379, 5.045817643404007, 8.566133044660091, 13.69278185069561, 16.897043511271477, 16.065490432083607, 24.849917963147163, 27.034639231860638, 24.04400210827589, 31.40486642718315, 21.031557954847813, 7.378593692556024, 0.6988782109692693, 0.04020470005343668, 0.05048494080256205, 0.04971858797944151, 0.01175201792648295, 0.04882956556684803, 0.04881441462202929, 0.10441786260344088, 0.02079996142128948, 0.05459201944177039, 0.07068381455610506, 0.05843749844643753, 0.09312811176641844, 0.032073077018139884, 0.04032595956232399, 0.04665686887165066, 0.014682102300866973, 0.11565081687876955, 0.024108541110763326, 0.024983540643006563, 0.02182833504775772, 0.04811578648514114, 0.03981370697147213, 0.08442802587524056, 0.0848045248130802, 0.09975906024919823, 0.022211491050256882, 0.04826000062166713, 0.010336496470699785, 0.05889541840588208, 0.026775628757604863, 0.08296344196423888, 0.02090014393616002, 0.08095320139545947, 0.05158212450623978, 0.014286393798101926, 0.036205496289767325, 0.02728195900999708, 0.024922502707340755, 0.0476421292842133, 0.0619737430679379, 0.0734848208958283, 0.03890404914272949, 0.03443258712650277, 0.04591984201397281, 0.02588606086646905, 0.03410771569178905, 0.07970627455506474, 0.007367418729700148, 0.0034495513364163344, 0.04222228417347651, 0.016950834760791622, 0.02431234413961647, 0.06985573359997943, 0.04637002137314994, 0.053773668041685596, 0.023679748592257965, 0.030788666153966915, 0.06386072403984144, 0.11272877367446199, 0.014034253763384186, 0.0915689930843655, 0.04949434434820432, 0.014330631365737645, 0.04183325778285507, 0.05479599130921997, 0.06942612657439895, 0.02260469387692865, 0.057232458420912735, 0.0714533326390665, 0.07000889061600901, 0.02319563638593536, 0.04272990576282609, 0.046622874797321856, 0.05587981635471806, 0.07751042285235599, 0.006660254039161373, 0.03187251160852611, 0.030936075236240868, 0.03847007828881033, 0.025196338501700666, 0.02586267022707034, 0.0753887859173119, 0.021873249825148378, 0.031024229392642155, 0.04255872940120753, 0.043958215828752145, 0.014083571331866551, 2.9689296009019017, 14.563080500811338, 30.99121492356062, 48.7748933583498, 48.54970224201679, 38.08565653860569, 23.442767970263958, 22.36018516123295, 21.068605966866016, 25.752253644168377, 24.71425574272871, 23.30060999840498, 18.824539482593536, 9.18725436553359, 4.6711411233991385, 1.1651219800114632, 0.6442767439875752, 0.07868178421631455, 0.17640890349866822, 0.24627832230180502, 0.5011663888581097, 0.9435252333059907, 1.5544785372912884, 2.07246626727283, 3.142948863096535, 3.630906092002988, 4.261563951149583, 4.020348144695163, 2.79025012627244, 6.540276976302266, 7.7318046893924475, 7.4278665985912085, 3.2704621832817793, 5.1396023109555244, 4.4865513034164906, 2.317910296842456, 6.258810879662633, 7.177189774811268, 18.591705076396465, 19.54917199909687, 23.641237020492554, 24.03920866549015, 33.41476857662201, 27.219303622841835, 18.851877115666866, 21.575817950069904, 32.2273550927639, 42.946659699082375, 40.94014696776867, 40.01503340899944, 31.090539693832397, 27.59027771651745, 21.100744642317295, 16.392381191253662, 11.471133213490248, 9.412226993590593, 7.404136871919036, 5.342406928539276, 2.926917392760515, 6.43733480013907, 7.991471830755472, 4.7204862255603075, 7.081642476841807, 6.554600307717919, 7.1636582259088755, 4.972252165898681, 2.5023170141503215, 3.21030143648386, 2.5640081288293004, 1.3858187687583268, 0.8435905363876373, 0.16673713107593358, 0.2139897775487043, 0.12029321776935831, 0.39065469230990857, 0.47484080772846937, 2.301831697113812, 6.240244600921869, 11.191204134374857, 15.47368548810482, 21.77703995257616, 17.64073010534048, 26.25023402273655, 31.620949432253838, 27.735583819448948, 35.03646455705166, 24.945209249854088, 9.389507062733173, 0.9445325948763639, 0.15194351552054286, 0.04854417267779354, 0.05842697479238268, 0.08398828853387386, 0.04242637107381597, 0.01123071577239898, 0.05034863424953073, 0.04588954754581209, 0.06638254184508696, 0.13378558127442375, 0.07733760634437203, 0.07308389787795022, 0.02958490076707676, 0.06613764795474708, 0.028108104816055857, 0.02554512750066351, 0.0678795353451278, 0.03666737560706679, 0.024623470999358688, 0.023069560338626616, 0.03036106107174419, 0.05081780887849163, 0.024630246807646472, 0.04715963310445659, 0.03131659475911874, 0.06348761671688408, 0.017972224777622614, 0.07981896967976354, 0.042908930336125195, 0.02090949685225496, 0.007058580004013493, 0.06744891899870709, 0.028116075482103042, 0.01542331208838732, 0.021278414751577657, 0.034819064239854924, 0.04098979210539255, 0.017354290357616264, 0.021403277387435082, 0.014760790363652632, 0.037218999132164754, 0.13298970210598782, 0.0929115159669891, 0.15688966261222959, 0.07170264230808243, 0.26360889547504485, 0.17838782543549314, 0.06864581766421907, 0.12766123021719977, 0.1429542963160202, 0.06506623903987929, 0.16852811153512448, 0.1314284757245332, 0.09899812139337882, 0.13882265629945323, 0.1271659802296199, 0.16987654933473095, 0.10853462998056784, 0.1864539465168491, 0.12112495009205304, 0.22784865810535848, 0.1834169594803825, 0.09695937493233941, 0.13052817637799308, 0.15484308649320155, 0.12873673578724265, 0.18661806505406275, 0.1139877901005093, 0.21784777287393808, 0.15085714490851387, 0.14951655903132632, 0.0958469846227672, 0.1964907071669586, 0.11430175567511469, 0.286448787082918, 0.13704357988899574, 0.11487443392979912, 0.1479129708604887, 0.18548651249147952, 0.09917580639012158, 0.08738751042983495, 0.19151070329826325, 0.15409237443236634, 0.15451587358256802, 0.21078717283671722, 0.1672118087299168, 0.1541970914695412, 3.51780136115849, 16.044344566762447, 35.48260621726513, 56.37780278921127, 56.34889014065266, 44.84414488077164, 30.719328112900257, 30.005521215498447, 29.60369847714901, 39.25272211432457, 32.36425794661045, 26.118901669979095, 21.63525816053152, 11.696395576000214, 7.534634694457054, 1.663362169638276, 1.3262364221736789, 0.4160350444726646, 0.7776740484405309, 1.3054933352395892, 2.7543000178411603, 3.1125457445159554, 4.410109855234623, 7.634137105196714, 7.876682365313172, 10.267253313213587, 11.535636652261019, 10.41636111214757, 8.356851674616337, 13.97372167557478, 10.61300816014409, 16.210201866924763, 9.572913721203804, 7.850098991766572, 3.888888261280954, 3.785098730586469, 6.8184662237763405, 7.298866845667362, 17.309866659343243, 21.68371696025133, 25.19339293241501, 27.25840922445059, 38.303160667419434, 32.363934963941574, 24.152250699698925, 26.73246994614601, 36.485771387815475, 45.04893109202385, 45.3936105966568, 42.05915652215481, 33.45602676272392, 27.467605099081993, 21.54808133840561, 17.060856521129608, 11.826780829578638, 10.697678066790104, 6.463576667010784, 5.830098409205675, 7.668449264019728, 10.36590551957488, 12.15035056695342, 11.48198353126645, 16.05445772409439, 9.872001372277737, 13.03234688937664, 13.204387407749891, 11.343792546540499, 7.842382555827498, 7.734782304614782, 5.10952977463603, 1.8793920963071287, 1.2418491253629327, 0.37525322812143713, 0.5668036511633545, 0.550143385771662, 1.093956904951483, 2.702457499690354, 7.344253985211253, 13.536157105118036, 20.571358948946, 25.474843829870224, 25.675870142877102, 35.842872485518456, 36.323561891913414, 33.65501828491688, 43.02568405866623, 28.564691729843616, 12.068521957844496, 1.3715960131958127, 0.17042820254573599, 0.19450464576948434, 0.1494371789158322, 0.14516260125674307, 0.15701814321801066, 0.13584575353888795, 0.13157338747987524, 0.096564500418026, 0.1418870731140487, 0.22118463210063055, 0.16194900206755847, 0.17826612805947661, 0.18332837673369795, 0.20219973754137754, 0.1450691351783462, 0.06780161726055667, 0.23798826558049768, 0.1255765522364527, 0.10183256890741177, 0.10693809221265838, 0.13323781691724434, 0.2855045674368739, 0.10675506375264376, 0.17142961209174246, 0.12387277412926778, 0.12301623923121952, 0.14050927595235407, 0.1586700155166909, 0.15886549721471965, 0.1339312203344889, 0.18543799087638035, 0.14249741536332294, 0.1569291893974878, 0.1622813061112538, 0.11823701599496417, 0.12858464004239067, 0.10840144415851682, 0.10557619185419753, 0.1920805688132532, 0.11928975989576429, 0.15751655475469306], [0.03346184312249534, 0.028243112610653043, 0.04653072603105102, 0.02983531067002332, 0.03310627645987552, 0.037339987757150084, 0.016562685959797818, 0.04000304368673824, 0.037181257212068886, 0.0580462567450013, 0.017975425289478153, 0.03791682203882374, 0.05108181678224355, 0.03353096675709821, 0.03462811706413049, 0.002097317915286112, 0.05434416809293907, 0.004625899236998521, 0.04852550024224911, 0.0445932344882749, 0.03313444467494264, 0.01711214797978755, 0.0651045264385175, 0.06833494684542529, 0.012330579556874, 0.01770382707036333, 0.08917591563658789, 0.05592371438979171, 0.022928739672352094, 0.020014277506561484, 0.024898676056182012, 0.09847913752309978, 0.04431567125720903, 0.04227360739605501, 0.0702536063909065, 0.0354545875597978, 0.03738127343240194, 0.0976923867710866, 0.031069721189851407, 0.06155536473670509, 0.022177053542691283, 0.03424283109779935, 0.0574878017505398, 0.012366761111479718, 0.03839741832052823, 0.05537428762181662, 0.2317435826989822, 3.5356770269572735, 11.867510844022036, 31.332415714859962, 40.00989988446236, 48.15594457089901, 34.98006038367748, 29.138899818062782, 24.237533323466778, 20.71662325412035, 25.37211064249277, 24.984020367264748, 18.34506221115589, 15.631960295140743, 10.770767144858837, 5.639742873609066, 2.4962470773607492, 0.654173253569752, 0.22113222163170576, 0.26873476104810834, 0.2274480467895046, 0.2190982471802272, 1.8973802123218775, 0.2881667105248198, 1.2740493100136518, 1.5693465457297862, 3.040757146663964, 2.296761581674218, 1.9782743090763688, 3.5959800286218524, 6.290801838040352, 2.101030284538865, 2.340255710296333, 5.109954876825213, 3.232502220198512, 0.22529311710968614, 3.0269952351227403, 1.9852839829400182, 5.300918854773045, 7.584812426939607, 12.297547068446875, 15.526689793914557, 16.24126709997654, 19.666295014321804, 12.85496860742569, 10.232110898941755, 18.46869807690382, 26.92733108997345, 26.556782573461533, 17.89753932505846, 15.311810374259949, 15.30926926061511, 9.005573764443398, 6.281798221170902, 5.1410305593162775, 2.5402646278962493, 3.2536806212738156, 3.1877881195396185, 1.8401159788481891, 3.070538998581469, 6.65103723295033, 4.376570954918861, 5.480919471010566, 7.160209910944104, 5.614440981298685, 3.7924541858956218, 1.4743819227442145, 3.0182682909071445, 1.7987981834448874, 0.9825626760721207, 0.2316344721475616, 0.3167168941581622, 0.25470241089351475, 0.1810705111711286, 0.7152819901239127, 2.383472453802824, 3.858184008859098, 8.031671773642302, 14.034909792244434, 16.55908964574337, 18.69100134819746, 23.97609405219555, 34.52463202178478, 26.791856959462166, 31.37382209300995, 28.311904594302177, 12.291757129132748, 1.8643990508280694, 0.14240549295209348, 0.025490989683021326, 0.0419138995493995, 0.07859186560381204, 0.03517830453347415, 0.0321172051189933, 0.007668773359910119, 0.09601857658708468, 0.0447048015485052, 0.031114873454498593, 0.0609976370469667, 0.031542793949483894, 0.025366178997501265, 0.061698165081907064, 0.03129087192064617, 0.026189183663518634, 0.03223568157409318, 0.048298206384060904, 0.030002258645254187, 0.050921806032420136, 0.014588527683372376, 0.047433485597139224, 0.02315861620445503, 0.05942431736912113, 0.03938629670301452, 0.057401133744861, 0.003959978939747089, 0.0548698164493544, 0.03931140287022572, 0.03790802016737871, 0.014288725069491193, 0.06983917628531344, 0.02137807219696697, 0.013244501024018973, 0.0324021749838721, 0.09686371209681965, 0.051927768654422835, 0.07633773304405622, 0.04481256881263107, 0.016124789144669194, 0.07862313970690593, 0.060513522985274903, 0.03466492758889217, 0.032191290010814555, 0.04373759016743861, 0.06820097434683703, 0.046581756105297245, 0.03717595085618086, 0.03148325144138653, 0.0475582703074906, 0.057578510750317946, 0.054425540874945, 0.03849085471301805, 0.07228833783301525, 0.03314595538540743, 0.03498792510072235, 0.03398324639420025, 0.05016902337956708, 0.06530239785206504, 0.015774539970152546, 0.024359939925489016, 0.09543780150124803, 0.010203638121311087, 0.011443884704931406, 0.07088138168910518, 0.07872988280723803, 0.032810556585900486, 0.006303356612988864, 0.15585672663291916, 0.08598194210208021, 0.04249818128300831, 0.05206328110944014, 0.02564612266723998, 0.0332680646533845, 0.044869057383039035, 0.06702768339891918, 0.0320297393045621, 0.02753233737166738, 0.036936571123078465, 0.02718683608691208, 0.057455247442703694, 0.053780725866090506, 0.023012097699393053, 0.03846987048746087, 0.045544415479525924, 0.03851866669720039, 0.06229431746760383, 0.12702319101663306, 0.29420010396279395, 4.621005663648248, 16.201639026403427, 36.64218619465828, 46.55671678483486, 51.3366474956274, 38.39348562061787, 27.16603048145771, 25.675427466630936, 23.683737739920616, 24.948722161352634, 27.12020494043827, 24.910076335072517, 20.076615996658802, 12.649911660701036, 6.44071139395237, 1.9483046047389507, 0.9158720390405506, 0.09640268253860995, 0.18075603351462632, 0.3124268649844453, 0.33115855359937996, 0.8457801688928157, 0.43073877110145986, 1.308336176443845, 2.5252829818055034, 2.180945221334696, 3.9004422537982464, 4.573012813925743, 2.925751805305481, 7.420511618256569, 4.621857767924666, 3.8204470463097095, 5.64859782345593, 3.8635248597711325, 2.911562416702509, 3.8064333982765675, 3.9913490507751703, 10.90303709730506, 11.704631634056568, 15.111061446368694, 18.763309568166733, 21.661799736320972, 26.36007282882929, 16.587776206433773, 11.742341760545969, 22.503215186297894, 31.405993066728115, 32.63774447143078, 26.886382587254047, 19.908520616590977, 19.98823843896389, 12.821558900177479, 9.718517158180475, 7.09842000156641, 6.200646450743079, 4.860049886628985, 5.127613954246044, 5.623747631907463, 6.986259995028377, 7.640792448073626, 4.532707901671529, 6.2222767900675535, 4.723132783547044, 2.3015343630686402, 3.731550103984773, 1.660932437516749, 1.6172797861509025, 1.0487564303912222, 0.6391349073965102, 0.2728768059751019, 0.13434985099593177, 0.19881140295183286, 0.08882298730895855, 0.916424315655604, 2.1812069322913885, 4.3802553322166204, 11.298929303884506, 15.874568726867437, 19.66133438050747, 15.899597983807325, 21.90722666680813, 37.742914929986, 31.94820687174797, 34.6649394929409, 32.81326465308666, 14.720739740878344, 2.584445094689727, 0.12299854643060826, 0.010636745300871553, 0.06956611046916805, 0.05179154373763595, 0.031972423239494674, 0.04113417693588417, 0.03602341777877882, 0.07321021141251549, 0.05523296415049117, 0.005247530480119167, 0.050245572201674804, 0.04027134862553794, 0.018985152455570642, 0.05818560239276849, 0.05256118056422565, 0.04139507524087094, 0.030510819051414728, 0.0021105044879732304, 0.059104622414452024, 0.020338809408713132, 0.02321752046555048, 0.03852912726870272, 0.022373804313247092, 0.04727943800389767, 0.06406580170732923, 0.06660661107162014, 0.007875925330154132, 0.05948852427536622, 0.022385604461305775, 0.049141249037347734, 0.09125053009483963, 0.03226569402613677, 0.010399101265647914, 0.04401252248499077, 0.032759144305600785, 0.011237570433877409, 0.026773838326334953, 0.055415788519894704, 0.04699807126598898, 0.030396743532037362, 0.0474999968719203, 0.03371910861460492, 0.15433122724061832, 0.0949183278135024, 0.1139305556716863, 0.13676848058821633, 0.105789574154187, 0.1362731563858688, 0.1649614833877422, 0.11423644667956978, 0.26166806055698544, 0.1681851502507925, 0.11975107889156789, 0.09799923514947295, 0.1683701973524876, 0.0968088154331781, 0.09181274406728335, 0.1295702121569775, 0.12957888044184074, 0.12212703499244526, 0.06070241070119664, 0.12345002454821952, 0.08056788574322127, 0.10859754183911718, 0.21292537450790405, 0.14107213559327647, 0.16637527471175417, 0.12804597441572696, 0.19903400272596627, 0.19487358222249895, 0.09319873453932814, 0.12260043615242466, 0.0963014832814224, 0.17306628520600498, 0.11132227024063468, 0.18597726506413892, 0.1548079532221891, 0.15789169556228444, 0.14049783203518018, 0.1821773502160795, 0.09090460021980107, 0.13490255805663764, 0.15574359364109114, 0.10062591842142865, 0.11992521642241627, 0.16211064183153212, 0.1544438852579333, 0.16038961621234193, 0.44634996622335166, 4.778806446120143, 17.60893151164055, 41.80745802819729, 54.12604741752148, 59.730815067887306, 46.19501419365406, 39.62863974273205, 36.41604132950306, 33.941872492432594, 36.769532561302185, 35.409866720438, 26.171525046229362, 22.497194409370422, 15.589796807616949, 7.696699798107147, 3.5109002189710736, 1.7472078767605126, 0.5611319211311638, 0.4919249581871554, 0.893201861763373, 1.567258914001286, 4.22100730240345, 3.433778132312, 4.343386860564351, 5.280509199947119, 8.420550506561995, 6.456907549872994, 9.030210692435503, 10.17575517296791, 14.932523276656866, 6.993205547332764, 9.768130145967007, 12.752294316887856, 9.622019436210394, 2.032199827954173, 4.794926131144166, 4.386360654607415, 8.36535656824708, 11.107581071555614, 17.070532701909542, 21.73605155199766, 22.773238196969032, 27.89902824908495, 22.004870027303696, 18.34457963705063, 23.735977336764336, 32.26414851844311, 32.43037439882755, 26.95734567940235, 21.65493730455637, 21.994722671806812, 14.29444631561637, 9.174424353986979, 7.803494967520237, 6.121449675410986, 6.322553884238005, 8.061673063784838, 6.1425622925162315, 7.169476663693786, 13.929948024451733, 10.462178103625774, 12.72063061594963, 13.744602520018816, 11.8232536688447, 10.587038453668356, 5.83422688767314, 5.620749117806554, 4.692602371796966, 3.3177176350727677, 1.8647276144474745, 0.6836273137014359, 0.9688853693660349, 0.3795584267936647, 1.2307228473946452, 3.3279286371544003, 5.700497338548303, 12.670933082699776, 21.707549281418324, 25.11730581521988, 28.52464947849512, 35.32183304429054, 46.193106696009636, 35.74293404817581, 40.71014150977135, 37.43513144552708, 17.601727098226547, 3.3191978931427, 0.28876921569462866, 0.09963422358850949, 0.11536837773746811, 0.12718165438855067, 0.09152533995802514, 0.13522245339117944, 0.15293606382329017, 0.1127532719692681, 0.16388522082706913, 0.10835056251380593, 0.1449419162236154, 0.12641378387343138, 0.13194691040553153, 0.1459926340612583, 0.27163875522091985, 0.18508064677007496, 0.10363439956563525, 0.13049246423179284, 0.1542332340613939, 0.11280027218163013, 0.1836291395011358, 0.20138806547038257, 0.09311251182225533, 0.13714973669266328, 0.15392778092063963, 0.1409568206872791, 0.14290317718405277, 0.19698756019352004, 0.09656354304752313, 0.12636172963539138, 0.15515846956986934, 0.23822094372007996, 0.12839683215133846, 0.18277388851856813, 0.20051080238772556, 0.1356351765571162, 0.15986264683306217, 0.1500364186358638, 0.11790785865741782, 0.1053543490706943, 0.1579711795784533, 0.16845873557031155], [0.014586055403924547, 0.02546599043853348, 0.04963599807524588, 0.08596531799412332, 0.01234309958817903, 0.007633244431417552, 0.04084936292201746, 0.05783924207207747, 0.04938092562952079, 0.06639956671278924, 0.07084160999511369, 0.029013966559432447, 0.09253796335542575, 0.0561800262221368, 0.025847882934613153, 0.03407645272091031, 0.0208885515894508, 0.02694697952392744, 0.029042628302704543, 0.006721240488332114, 0.04208364727674052, 0.02727937633608235, 0.03236654076317791, 0.035570095424191095, 0.048337247062590905, 0.05560387100558728, 0.030373783338291105, 0.04372512579720933, 0.02929123478679685, 0.012174915009381948, 0.01527203363366425, 0.06380143386195414, 0.020373193110572174, 0.040934665375971235, 0.04664056388719473, 0.023919718332763296, 0.046558103858842514, 0.0467364679207094, 0.034929313987959176, 0.05923313270614017, 0.029743568229605444, 0.08236942696385086, 0.058901559677906334, 0.027708790403266903, 0.02981322249979712, 0.06228627258678898, 0.16065006551798433, 0.2045443601673469, 3.8393393950536847, 12.902674097567797, 31.160123459994793, 43.342636451125145, 38.79792831838131, 36.70672953128815, 27.65240628272295, 17.485926412045956, 21.000956296920776, 23.16790211945772, 18.290947414934635, 18.57054591178894, 16.092734970152378, 10.355540625751019, 7.845647530630231, 2.4628775054588914, 1.3879517605528235, 0.3631481167394668, 0.39583485340699553, 0.8052596775814891, 0.7524305186234415, 0.08480999444145709, 1.1946963868103921, 1.0104074631817639, 1.5624815016053617, 3.4744297759607434, 2.400581748224795, 2.1061875578016043, 5.987751949578524, 5.171550996601582, 1.854755049571395, 2.8745645144954324, 2.989668413065374, 2.843521605245769, 1.3524926570244133, 1.7382757435552776, 3.709918577224016, 2.9232002422213554, 6.958141028881073, 8.07178147137165, 11.878117974847555, 12.649216298013926, 11.018736138939857, 8.800804652273655, 8.616402447223663, 16.25043410807848, 17.23287519067526, 12.263441998511553, 9.298459198325872, 6.974313911050558, 3.0578103940933943, 4.334457814693451, 3.5907633835449815, 2.19992449041456, 4.347424618899822, 4.1941579431295395, 4.242476150393486, 6.442889627069235, 4.483491517603397, 1.9363844068720937, 4.059472745284438, 4.831169061362743, 2.895385497249663, 1.899647859390825, 1.3146073836833239, 0.8325009502004832, 0.16486356442328542, 0.4217812267597765, 0.15588368143653497, 0.15890178823610768, 0.11776231607655063, 0.9682314482051879, 3.24783178512007, 5.31548204831779, 8.697839677333832, 16.050695925951004, 23.199117444455624, 16.83066677302122, 16.643276028335094, 28.18681910634041, 27.906928025186062, 28.783647380769253, 28.732764311134815, 16.60174995660782, 4.768882803618908, 0.44947583286557347, 0.029305986827239394, 0.055025188776198775, 0.037083471834193915, 0.03925475473806728, 0.031897614753688686, 0.018121856592188124, 0.08480234289891087, 0.024126397183863446, 0.032360833647544496, 0.03188304639479611, 0.026327204577683005, 0.036893867945764214, 0.039832798720453866, 0.005289198361424496, 0.025014870407176204, 0.008705879281478701, 0.06368723217747174, 0.05523943567823153, 0.027111181552754715, 0.007085066326908418, 0.050698278573690914, 0.07526435743784532, 0.07335091519053094, 0.027950997719017323, 0.03439155378146097, 0.07703347422648221, 0.05083908254164271, 0.038854340091347694, 0.048401851017843, 0.04123055223317351, 0.027304639042995404, 0.06816141787567176, 0.06626831789617427, 0.019871417789545376, 0.037218576107989065, 0.02521030943171354, 0.06536976259667426, 0.026559619254840072, 0.03124207942164503, 0.0417942764761392, 0.05260350524622481, 0.08096139470580965, 0.02193727490521269, 0.017174627537315246, 0.027363697299733758, 0.03254581395594869, 0.053623186468030326, 0.05278986966004595, 0.027310331315675285, 0.0511567440116778, 0.0017582104646862717, 0.018874642955779564, 0.042574789476930164, 0.0467768370435806, 0.03588091800338589, 0.0560896623210283, 0.016289134036924224, 0.020137898900429718, 0.00895304228833993, 0.04399671473947819, 0.03951693324779626, 0.0012569326145239756, 0.05357947025913745, 0.09767729148734361, 0.025197449867846444, 0.027677095131366514, 0.049326515072607435, 0.08938378377933986, 0.015357422362285433, 0.057806142285699025, 0.02417354582576081, 0.052467807254288346, 0.009357197359349811, 0.04363066524092574, 0.02204820000770269, 0.03379055888217408, 0.04154494083195459, 0.03944486699765548, 0.03175041718350258, 0.02710946719162166, 0.02318597547855461, 0.039310374995693564, 0.018939033543574624, 0.07966709657921456, 0.03207308072887827, 0.023680186459387187, 0.1081667622202076, 0.08347122682607733, 0.06574413157068193, 0.4777461674530059, 5.309792328625917, 16.283916011452675, 35.75011566281319, 48.52787621319294, 43.5829621553421, 41.471221670508385, 31.074002981185913, 22.628327272832394, 26.819534674286842, 28.28430287539959, 20.007047429680824, 24.57396537065506, 20.59696387499571, 13.339085429906845, 8.386448286473751, 3.009920376352966, 0.9997093747369945, 0.2522042824421078, 0.10687078683986329, 0.2698017912916839, 0.4876684147166088, 0.42635526100639254, 0.9474583785049617, 0.29280884424224496, 1.8158137891441584, 1.5765510778874159, 3.002906902693212, 4.245531661435962, 5.285341115668416, 5.344285927712917, 3.5914988815784454, 5.058050137013197, 4.804628435522318, 4.488176666200161, 2.5351954624056816, 3.910304387100041, 3.8916179398074746, 4.875683197751641, 10.992844328284264, 11.038256641477346, 14.788593649864197, 16.686227023601532, 15.077800881117582, 9.770801402628422, 12.171083204448223, 20.41632916778326, 21.427889987826347, 15.334706045687199, 12.61742815375328, 9.507016707211733, 5.811178274452686, 5.595696587115526, 4.281588401645422, 3.0693791108205914, 6.789054851979017, 4.8670310620218515, 5.099675478413701, 10.792841110378504, 6.310463408008218, 4.449953092262149, 5.238887183368206, 3.695457740686834, 2.174933706410229, 1.6198833589442074, 0.8578519430011511, 1.002248350996524, 0.6197326141409576, 0.06542192815686576, 0.1979982911143452, 0.21929816692136228, 0.24322089651832357, 1.1303865001536906, 3.3895563427358866, 6.8364501837641, 9.519143756479025, 16.271249391138554, 25.914888717234135, 21.649480797350407, 19.994838684797287, 33.9224973320961, 34.19795975089073, 34.14355427026749, 33.34789216518402, 20.351571142673492, 5.936873629689217, 0.6966166198253632, 0.051998907219967805, 0.01850798860687064, 0.053773745967191644, 0.09997040906455368, 0.04865255221375264, 0.04520499052887317, 0.05918066657613963, 0.03527331798977684, 0.025945391862478573, 0.058601720884325914, 0.03212507930584252, 0.022566874031326734, 0.05870006287295837, 0.04335413730586879, 0.041651234932942316, 0.04692614602390677, 0.05091399492812343, 0.024815651995595545, 0.03490604394755792, 0.0598350033396855, 0.01722380595310824, 0.044952704847673886, 0.05294152011629194, 0.018778972698783036, 0.016093461235868745, 0.04231535320286639, 0.0402400188613683, 0.01630886774364626, 0.023659469406993594, 0.06177401628519874, 0.026142869937757496, 0.03547471460478846, 0.025589886427042075, 0.046595515523222275, 0.013286932389746653, 0.044594648279598914, 0.034121167118428275, 0.07242733467137441, 0.023417458760377485, 0.01026959278533468, 0.0030693124381286907, 0.04786350080394186, 0.10175510353292339, 0.11717410467099398, 0.26201559347100556, 0.17912457027705386, 0.16033879393944517, 0.09700310227344744, 0.12000138303847052, 0.23200870753498748, 0.12819664523703977, 0.16995312413200736, 0.15629722096491605, 0.09011444300995208, 0.187015900737606, 0.19302066211821511, 0.14263086835853755, 0.10368482107878663, 0.07766984359477647, 0.1098094615736045, 0.1788500350085087, 0.08412706272793002, 0.0755192554788664, 0.1654330885503441, 0.1257461032946594, 0.0694922445109114, 0.12385669921059161, 0.30441425275057554, 0.13654124981258065, 0.34909736132249236, 0.0939439027570188, 0.18292099703103304, 0.1560268268804066, 0.15768615034176037, 0.1663102477323264, 0.09880721874651499, 0.0774355475732591, 0.28232449432834983, 0.11827374488348141, 0.1882802532054484, 0.1428151287836954, 0.13199044478824362, 0.15960196004016325, 0.1296721535618417, 0.15205357602098957, 0.12266249454114586, 0.1807942392770201, 0.20067521778400987, 0.2649558044504374, 0.5154945293907076, 5.8827075362205505, 17.486296892166138, 41.822710409760475, 53.72872553765774, 52.81759902834892, 47.90326952934265, 40.057404935359955, 27.091856561601162, 32.717122212052345, 33.923470079898834, 27.240075208246708, 27.356696650385857, 24.656113162636757, 16.408015452325344, 10.540921278297901, 3.9675751514732838, 2.1366120502352715, 0.8218985691200942, 0.7673552865162492, 1.692008120007813, 1.805937287863344, 1.6869773087091744, 4.425182696431875, 4.648754149675369, 4.0372847858816385, 9.7210031747818, 6.180454334244132, 8.826860804110765, 14.95031962171197, 12.800813913345337, 6.566907372325659, 11.095005646348, 9.05072009190917, 7.448926493525505, 3.4480786649510264, 4.365811832249165, 5.598269999027252, 5.937372827902436, 9.856173321604729, 12.656301017850637, 15.639586485922337, 16.89200308173895, 15.55072445422411, 14.539321325719357, 13.193330951035023, 20.52958969026804, 22.591976523399353, 17.535893730819225, 13.087803963571787, 11.210922226309776, 4.857291234657168, 7.317483946681023, 5.927897086367011, 5.3470987267792225, 9.372908603399992, 8.514214530587196, 10.025634728372097, 17.86689966917038, 11.581428945064545, 6.836692420765758, 11.208635699003935, 12.25414864718914, 9.552612360566854, 5.566208269447088, 4.620663207024336, 2.7520301146432757, 2.1026570722460747, 0.8189770602621138, 0.9582486120052636, 0.47646376595366746, 0.5669494089670479, 1.288635777309537, 4.691404486075044, 7.6785210985690355, 13.652316872030497, 21.881131567060947, 32.99141049385071, 26.649866178631783, 27.153688743710518, 40.37300080060959, 39.660930410027504, 39.86788630485535, 38.52825678884983, 23.220058120787144, 6.944901114329696, 0.8428714249748737, 0.07509861359721981, 0.23773405031533912, 0.177728189737536, 0.2007707321899943, 0.13464314775774255, 0.21187756588915363, 0.16040809568949044, 0.1461896297405474, 0.09209755808115005, 0.14929004071746022, 0.052376471139723435, 0.12637986772460863, 0.1517742613214068, 0.08981500868685544, 0.12016914552077651, 0.18449794210027903, 0.1686799104209058, 0.09584363753674552, 0.1277387994923629, 0.20360037800855935, 0.17081040859920904, 0.16012894426239654, 0.1938699759193696, 0.14486189786111936, 0.14515967719489709, 0.16011799016268924, 0.09386185833136551, 0.12569986749440432, 0.1076452030974906, 0.20827479514991865, 0.16013731568818912, 0.12044540257193148, 0.19077793636824936, 0.14838297298410907, 0.12604659888893366, 0.16557335446123034, 0.1101527271384839, 0.16013501503039151, 0.13286701025208458, 0.12637401960091665, 0.08925119909690693, 0.22470147698186338], [0.09717721011838876, 0.016286011450574733, 0.06582913716556504, 0.013628495653392747, 0.014260442749218782, 0.07737987165455706, 0.040985305822687224, 0.14775055926293135, 0.029505804523068946, 0.03270382832852192, 0.05009403306758031, 0.1232077059103176, 0.03858217969536781, 0.08307589218020439, 0.017109511500166263, 0.014769726749364054, 0.015331501926993951, 0.05627430495223962, 0.04068120710144285, 0.02939743055321742, 0.009465031416766578, 0.025127595217782073, 0.035931076054112054, 0.02833473259670427, 0.06109592337452341, 0.03062666830373928, 0.03323291282868013, 0.059525980468606576, 0.08155799980158918, 0.06384657128364779, 0.04208103862765711, 0.006269151026572217, 0.04679709396441467, 0.012059615874022711, 0.03279019576439168, 0.03636317669588607, 0.0693128674174659, 0.0878975736850407, 0.03529119261656888, 0.010054381091322284, 0.015120015814318322, 0.04362117688287981, 0.025532958134135697, 0.041777340666158125, 0.04486683836148586, 0.022594968031626195, 0.06876886574900709, 0.04485830737394281, 0.4401226347545162, 3.8036108622327447, 12.753677442669868, 27.419036105275154, 38.4773775190115, 39.87603686749935, 34.05302032828331, 21.79798062890768, 27.452877089381218, 26.29910320043564, 31.114339716732502, 26.900272741913795, 19.218458645045757, 18.97444523870945, 13.434726297855377, 10.267381556332111, 3.8304806454107165, 1.9044555514119565, 0.8149457140825689, 0.2563659200677648, 0.15457266272278503, 0.18118334730388597, 0.376358701614663, 0.1890234398888424, 1.7914840509183705, 0.8426443277858198, 3.870618841610849, 1.9176948722451925, 2.026439574547112, 4.402572009712458, 1.771325538866222, 3.314569741487503, 2.1806968096643686, 6.158183254301548, 1.508995690383017, 2.200846653431654, 3.277552602812648, 2.38691293168813, 3.8616864709183574, 4.655699227005243, 6.569093205034733, 6.949205808341503, 4.589797938242555, 6.045409580692649, 6.363954562693834, 8.757509775459766, 10.554500799626112, 9.526361469179392, 5.502540310844779, 2.1980110555887222, 4.190427018329501, 1.5480521321296692, 1.5275441575795412, 1.8246312160044909, 4.222589917480946, 1.6361122881062329, 6.493731373921037, 9.428567066788673, 6.088294079527259, 4.201591294258833, 4.194151293486357, 1.1248918762430549, 0.4070475173648447, 1.4881842071190476, 0.7538688601925969, 0.44614201644435525, 0.19054628239246085, 0.1120154806994833, 0.0918158981949091, 0.2703255694359541, 1.6825367719866335, 2.196493037045002, 6.848909240216017, 14.066183064132929, 14.22567380592227, 19.542588852345943, 12.966530621051788, 19.895878694951534, 18.060128800570965, 23.70945855975151, 27.523946575820446, 28.10558896511793, 21.34064096957445, 8.740102909505367, 1.2993642641231418, 0.05170685726625379, 0.04721392491774168, 0.048551968939136714, 0.023465279045922216, 0.01695070488494821, 0.04280797227693256, 0.029585455522465054, 0.004311755083108437, 0.04435082679265179, 0.07090841812896542, 0.02178733509936137, 0.04180270727374591, 0.03190849092788994, 0.13529015210224316, 0.03729817886778619, 0.023536337830591947, 0.04471064225072041, 0.09217981030815281, 0.059492769360076636, 0.007523348594986601, 0.02469446299073752, 0.049140918781631626, 0.01536946741907741, 0.08962236941442825, 0.02974782259116182, 0.06305763861746527, 0.06756130984285846, 0.01865799891675124, 0.03635448243585415, 0.008220921026804717, 0.08393363677896559, 0.0015359117242041975, 0.051973202935187146, 0.039910568375489675, 0.08268596036941744, 0.08596392275649123, 0.007016805902821943, 0.021544524788623676, 0.04723024845588952, 0.16710324736777693, 0.06367561756633222, 0.01571280441567069, 0.005945781513219117, 0.024170005781343207, 0.01727818867948372, 0.030137650501274038, 0.06828540106653236, 0.01641909337195102, 0.04924669708998408, 0.01861634402303025, 0.028876049545942806, 0.03035420177184278, 0.03254772869695444, 0.07415513609885238, 0.01912617721245624, 0.09777446088264696, 0.06955174991162494, 0.04332186501414981, 0.02843702652171487, 0.005317587365425425, 0.028282622697588522, 0.002417028640593344, 0.04420848657900933, 0.05912063796131406, 0.016435153447673656, 0.046396642210311256, 0.03966368552937638, 0.054128796837176196, 0.03346029945532791, 0.03937285269785207, 0.05202833708608523, 0.06351679054205306, 0.023497028123529162, 0.049799133266787976, 0.10183644291828386, 0.0509907997911796, 0.022391055535990745, 0.03848000451398548, 0.009276960990973748, 0.08218655435484834, 0.0492565862077754, 0.04794099215359893, 0.0050555642428662395, 0.021482598131115083, 0.0171803921693936, 0.04732444183900952, 0.05917641035921406, 0.04889387637376785, 0.008252452098531649, 0.018598905407998245, 0.1309229840990156, 0.7428537856321782, 5.226010149344802, 18.26917838305235, 32.40334264934063, 43.93380492925644, 44.641186371445656, 37.967399284243584, 24.717371575534344, 30.573581233620644, 25.66482223570347, 25.662004686892033, 27.473633475601673, 21.99182152748108, 23.772766962647438, 17.005455493927002, 11.579278260469437, 4.022320713847876, 1.7022081976756454, 0.5831967433914542, 0.45533621683716774, 0.09797445483854972, 0.07448373682564124, 0.20075213396921754, 0.41896673559676856, 0.621403040131554, 0.948911503655836, 3.44140384811908, 2.3715957161039114, 4.23392565920949, 3.1705432198941708, 4.501375732943416, 4.730050312355161, 3.9240518119186163, 3.998061865568161, 3.1655431631952524, 3.170169652439654, 4.948370447382331, 4.6997141651809216, 7.6297402661293745, 8.162143472582102, 9.706102274358273, 9.559580236673355, 8.160873390734196, 8.114147298038006, 8.137933071702719, 13.207374047487974, 13.970234412699938, 12.896591573953629, 7.890847530215979, 3.537464593537152, 4.656498609110713, 2.1372309420257807, 2.999528171494603, 3.7890932662412524, 4.941129460930824, 5.252074850723147, 6.913689114153385, 7.912424197420478, 3.7954826233908534, 3.9669080497696996, 4.792668102309108, 2.673203106969595, 1.040542577393353, 1.0391892562620342, 0.6075480335857719, 0.2542002737754956, 0.07478855171939358, 0.07183288922533393, 0.023135440787882544, 0.34493587212637067, 1.4904772653244436, 2.730381488800049, 8.1967206671834, 16.49848859757185, 15.219927504658699, 24.681072123348713, 19.091389663517475, 20.51282498985529, 20.734702683985233, 29.516339264810085, 32.93615385890007, 33.01636375486851, 24.819783680140972, 10.514639988541603, 1.7690632352605462, 0.023670202717767097, 0.09436622189241461, 0.07207635819213465, 0.0634644617093727, 0.023656187258893624, 0.033354539700667374, 0.024265468236990273, 0.051884538552258164, 0.06597623825655319, 0.02467910981067689, 0.02750230451056268, 0.03474868637567852, 0.024495318793924525, 0.07731092613539658, 0.11586857042857446, 0.0561150697467383, 0.07477482940885238, 0.029515695496229455, 0.02241359827166889, 0.032365824590669945, 0.012558231501316186, 0.03584158046578523, 0.013310843460203614, 0.10355731268646196, 0.011560247894522035, 0.09053724454133771, 0.06994728493737057, 0.032371424094890244, 0.05629875871818513, 0.02743389519309858, 0.03883079545630608, 0.034467597943148576, 0.07357628317549825, 0.006199992139954702, 0.1429551572073251, 0.014821126969764009, 0.006259998490349972, 0.024088987374852877, 0.060398263740353286, 0.036725496902363375, 0.05308745603542775, 0.03709107142640278, 0.034617905112099834, 0.25335909391287714, 0.18281329656019807, 0.14821449061855674, 0.21435282134916633, 0.08937423233874142, 0.23196339199785143, 0.11092204484157264, 0.15690901782363653, 0.1367565171676688, 0.1663561273016967, 0.12095771453459747, 0.11126329918624833, 0.23173184192273766, 0.23451945249689743, 0.1620918803382665, 0.16996722493786365, 0.08981567661976442, 0.15690619766246527, 0.19740999065106735, 0.18580104951979592, 0.15224381815642118, 0.1596645824611187, 0.1765229122247547, 0.11569917522137985, 0.18005152756813914, 0.08799620511126705, 0.09284131621825509, 0.33058920758776367, 0.2376033877953887, 0.13821121567161754, 0.15638639742974192, 0.14108491537626833, 0.12617095315363258, 0.14802506484556943, 0.1579122678958811, 0.1259012270020321, 0.2569793496513739, 0.17931825597770512, 0.18726925511145964, 0.1314706593984738, 0.0848657223104965, 0.19852008030284196, 0.16701735119568184, 0.18069678044412285, 0.11270654635154642, 0.1934898181934841, 0.12925733753945678, 0.2613228134578094, 0.9146745689213276, 5.656704213470221, 20.39554998278618, 37.40372613072395, 51.797935143113136, 51.93035043776035, 48.43731187283993, 29.454972557723522, 42.999636456370354, 37.71364890038967, 41.33992351591587, 38.63357573747635, 27.123810946941376, 29.130971543490887, 17.640673108398914, 15.235766004770994, 4.834891436621547, 3.153553381562233, 0.9756764955818653, 0.8606158196926117, 0.7628184487111866, 1.1212085676379502, 1.578576487954706, 2.16642786283046, 4.370809989050031, 3.0323728965595365, 7.781119868159294, 6.248343391343951, 8.635477423667908, 11.506920643150806, 7.49446514993906, 8.977549318224192, 7.805674150586128, 11.824242565780878, 5.916796931996942, 5.333634149283171, 6.929410770535469, 6.406132774427533, 8.898140229284763, 7.3429611045867205, 10.196359567344189, 10.412787403911352, 7.011430319398642, 9.145857486873865, 7.784065660089254, 13.255778700113297, 13.668712992221117, 12.448934745043516, 7.961275801062584, 4.220210295170546, 8.440443389117718, 3.0432768864557147, 3.9925046637654305, 6.317825512960553, 10.22810971364379, 8.502490259706974, 13.022019043564796, 19.445690251886845, 14.206391740590334, 13.30689450725913, 9.505692478269339, 5.704824356362224, 2.6822886569425464, 4.6359151136130095, 2.9430786380544305, 1.9082530913874507, 1.2057553371414542, 0.6582772708497941, 0.31911916681565344, 0.5182050901930779, 3.073196243494749, 2.828589119017124, 10.219220090657473, 19.606892801821232, 19.724082313477993, 31.090102717280388, 20.553469508886337, 28.160638511180878, 29.103107638657093, 36.323029920458794, 39.338460713624954, 38.196838572621346, 27.973192669451237, 11.848093885928392, 1.9336186302825809, 0.13207163574406877, 0.2119992335792631, 0.14673209516331553, 0.15873574011493474, 0.15164713142439723, 0.09747600619448349, 0.08989742418634705, 0.19867493683705106, 0.15792429068824276, 0.2770291222259402, 0.14214529597666115, 0.16348095814464614, 0.1616949203889817, 0.2852636366151273, 0.20488450129050761, 0.15994168556062505, 0.16877043759450316, 0.2451398826087825, 0.13279717415571213, 0.14084128313697875, 0.12598056258866563, 0.17345503700198606, 0.08442922815447673, 0.21475696528796107, 0.11732677186955698, 0.2264761450351216, 0.22227799374377355, 0.17663997859926894, 0.15810727461939678, 0.13850393355824053, 0.20928620884660631, 0.11707060475600883, 0.2057376891025342, 0.13755969906924292, 0.17973271576920524, 0.20136277307756245, 0.11418003603466786, 0.11573338822927326, 0.23775773966917768, 0.22910791944013909, 0.2701588533818722, 0.12055416431394406, 0.13590717368060723], [0.03928316044039093, 0.08716058393474668, 0.02812683662341442, 0.035532138281269, 0.01984998456464382, 0.07337998511502519, 0.015509711993217934, 0.04683570048655383, 0.021561954126809724, 0.04786300727573689, 0.09489227100857534, 0.03882035343849566, 0.008564102172385901, 0.05356466812372673, 0.05171908043848816, 0.05882593854039442, 0.029360408516367897, 0.05482254164235201, 0.016285195088130422, 0.04195507390249986, 0.054434717530966736, 0.06390786526026204, 0.05799812846817076, 0.04870142263825983, 0.04952583367412444, 0.09486732742516324, 0.0805268449767027, 0.01686134473857237, 0.029233013301563915, 0.014094377002038527, 0.027241005445830524, 0.06924999266630039, 0.03293544148618821, 0.056859896576497704, 0.022288856234808918, 0.029654770260094665, 0.020018704417452682, 0.047886388638289645, 0.04176859816652723, 0.02054998196399538, 0.0015701792335676146, 0.03738312880159356, 0.08695751748746261, 0.008372748670808505, 0.0264535570750013, 0.035670726938406006, 0.09623628560802899, 0.05020630516810343, 0.03316690621431917, 0.3334050049306825, 3.267521378584206, 12.565039414912462, 22.995803654193878, 35.62265530228615, 39.701664224267006, 37.829322293400764, 30.366879925131798, 18.529587909579277, 17.209540642797947, 21.189431883394718, 28.406226933002472, 25.155374072492123, 22.457706928253174, 10.992323756217957, 8.849465791136026, 5.080116027966142, 2.237602318637073, 1.01633490761742, 0.6668827997054905, 0.2508546126773581, 0.2049062165315263, 0.13266576948808506, 0.32699062256142497, 0.453092377865687, 1.511177842039615, 2.305681365542114, 2.4214447662234306, 2.529691457748413, 2.672153888270259, 4.417941709980369, 3.2642219681292772, 1.708491041790694, 2.7913005324080586, 2.758919382467866, 1.18930886965245, 1.2739954004064202, 2.9615081241354346, 1.8221044703386724, 4.31336609646678, 3.389909011311829, 3.7787153106182814, 2.459264611825347, 6.188213042914867, 5.701529458165169, 5.9011878445744514, 5.612101731821895, 2.738320450298488, 2.2415113588795066, 3.664499376900494, 1.8965424760244787, 3.1556575186550617, 2.3334398260340095, 4.1865607257932425, 3.583938949741423, 2.162599330767989, 5.367978606373072, 3.391718426719308, 2.2884362284094095, 3.3259890787303448, 2.1978521766141057, 1.8248584913089871, 0.06752891509677283, 0.31037167995236814, 0.24292405229061842, 0.272460431442596, 0.10855102402274497, 0.7924554927740246, 0.9640632499940693, 3.297076905146241, 6.687006577849388, 10.29025062918663, 31.085366271436214, 26.99826378375292, 12.274119425565004, 13.313533701002598, 20.59302918612957, 25.980319306254387, 29.495742470026016, 24.803845435380936, 24.288296699523926, 11.335602086037397, 2.098476584069431, 0.019737024122150615, 0.056949202917166986, 0.027030716046283487, 0.025333734156447463, 0.044353565317578614, 0.016189389389182907, 0.05826880827953573, 0.022165464906720445, 0.03502679508528672, 0.1083478685177397, 0.05484419009007979, 0.041695689578773454, 0.07149395038140938, 0.017295454745180905, 0.08812657819362357, 0.047565283603034914, 0.035004560340894386, 0.015915093463263474, 0.02057068417343544, 0.0758862252405379, 0.03881378172081895, 0.04332402466388885, 0.025209743544110097, 0.025069390430871863, 0.02824680479534436, 0.031997522673918866, 0.0683534040581435, 0.06264616225962527, 0.04205872224702034, 0.010666231755749322, 0.04553077480522916, 0.05630483319691848, 0.022139127941045444, 0.08468055646517314, 0.041204172594007105, 0.018771018731058575, 0.014763122562726494, 0.01939585697982693, 0.050386817747494206, 0.029960165884403978, 0.007798147325956961, 0.04842190013732761, 0.037530140834860504, 0.0074516483164188685, 0.05789591246866621, 0.06211267682374455, 0.08145916057401337, 0.038843953734613024, 0.017117109237005934, 0.04058537357195746, 0.07941606512758881, 0.028859124868176877, 0.025064117471629288, 0.061213750450406224, 0.008254526401287876, 0.04172152002865914, 0.05336108588380739, 0.021534676488954574, 0.07782049215165898, 0.025228961458196864, 0.03281509481894318, 0.028133176419942174, 0.033575688576092944, 0.041024932797881775, 0.01097168396881898, 0.024039454583544284, 0.029972936390549876, 0.06502893869765103, 0.043470439268276095, 0.0073114881615765626, 0.025615785525587853, 0.028653798581217416, 0.02533645041694399, 0.08508309736498632, 0.043553018040256575, 0.05867192434379831, 0.054546800383832306, 0.025105930071731564, 0.06202307733474299, 0.08916273509385064, 0.05976954591460526, 0.027335666381986812, 0.04311162199883256, 0.023463867109967396, 0.019825389790639747, 0.028972925792913884, 0.02627431913424516, 0.013569136826845352, 0.058316020003985614, 0.015380894637928577, 0.04223867450491525, 0.08684577973326668, 0.041738875152077526, 0.8224520925432444, 4.837191263213754, 17.01287269592285, 28.798743970692158, 42.91031464934349, 43.48764047026634, 41.279909536242485, 34.28312838077545, 22.06959005445242, 19.74990762770176, 23.407777547836304, 27.390731424093246, 26.305488757789135, 24.92895182222128, 17.78517745435238, 12.505738846957684, 6.887362226843834, 2.886343407444656, 0.9365346771664917, 0.47018297016620636, 0.210445903649088, 0.05521778351976536, 0.1415713783353567, 0.07645070276339538, 0.23183649958809838, 0.27940090745687485, 1.3301839353516698, 1.8208925728686154, 1.7995143262669444, 2.5900258077308536, 4.453972801566124, 3.5168478498235345, 2.8234411077573895, 3.9917751029133797, 3.5306983441114426, 2.5507575273513794, 2.32726919464767, 3.4983238438144326, 4.382346644997597, 5.403867680579424, 5.103850504383445, 5.677712811157107, 5.3307239804416895, 7.445771712809801, 9.466958306729794, 7.3294680286198854, 8.163854330778122, 4.7821782901883125, 2.3796011740341783, 5.468058111146092, 2.7910148352384567, 3.5058308159932494, 3.872631546109915, 4.181854203343391, 3.7146004009991884, 5.672758352011442, 4.662782046943903, 2.1149809984490275, 2.548764059320092, 1.9219629932194948, 0.3845019615255296, 1.2907185405492783, 0.7592776918318123, 0.4649299895390868, 0.03372397710336372, 0.22397356369765475, 0.10533224049140699, 0.8298689383082092, 1.3832609122619033, 4.78385922499001, 7.8449654672294855, 11.398941837251186, 34.68942157924175, 26.86957608908415, 15.585438441485167, 15.401043836027384, 21.66257869452238, 31.581397354602814, 32.53643810749054, 32.48209722340107, 27.65461016446352, 14.503334406763315, 2.957446617074311, 0.09517272119410336, 0.02858389383618487, 0.04201368130452465, 0.02161642405553721, 0.03754787445359398, 0.04603727204084862, 0.027189311149413697, 0.04895019425021019, 0.08355698941159062, 0.047766902862349525, 0.04110751899133902, 0.05502306252310518, 0.023877334278950002, 0.03746287628018763, 0.028921609991812147, 0.03658413632365409, 0.031298107860493474, 0.11081250384449959, 0.041243409941671416, 0.12749681482091546, 0.0995777609932702, 0.0477853007032536, 0.11977923597441986, 0.048707742025726475, 0.11451391343143769, 0.02967582127894275, 0.012608306988113327, 0.047659317424404435, 0.04649571521440521, 0.021241882532194722, 0.16320542839821428, 0.12678417493589222, 0.027658092440105975, 0.026125151161977556, 0.04002829526143614, 0.05594564114289824, 0.04754607311042491, 0.030509794887620956, 0.04010042088339105, 0.02589612438896438, 0.023517272056778893, 0.06449753127526492, 0.07717256754403934, 0.016184724991035182, 0.1345053012482822, 0.35108352662064135, 0.15037948382087052, 0.09560076970956288, 0.08911757540772669, 0.13892159942770377, 0.17837145365774632, 0.16011205298127607, 0.1323283594683744, 0.14865427248878404, 0.1262627271353267, 0.14615154272178188, 0.09991665530833416, 0.10274699132423848, 0.18722039210842922, 0.1623944687889889, 0.10334665406844579, 0.13841606327332556, 0.17438871815102175, 0.1648001404828392, 0.0987347554473672, 0.2311922560329549, 0.0869182356109377, 0.14657287480076775, 0.1283158638398163, 0.2640405285637826, 0.14571559033356607, 0.1215504010906443, 0.1280168822268024, 0.13346797175472602, 0.18684710667002946, 0.2044905989896506, 0.1212852614116855, 0.12507983279647306, 0.14845580735709518, 0.1490215613739565, 0.12233039829879999, 0.19872010394465178, 0.09623094214475714, 0.13355734117794782, 0.07448952557751909, 0.11479962544399314, 0.29083470173645765, 0.09796347847441211, 0.12346151299425401, 0.09641854965593666, 0.12399821192957461, 0.19868065137416124, 0.14499086828436702, 0.9283290768507868, 5.869282381609082, 18.499693013727665, 34.37483265995979, 49.081571102142334, 52.397691160440445, 46.84596486389637, 44.70332823693752, 28.959425948560238, 27.761403433978558, 32.64296159148216, 40.0152537971735, 35.92391453683376, 31.938521191477776, 16.71343356370926, 12.673224359750748, 7.335674520581961, 4.155526841059327, 2.0515555143356323, 1.2292809435166419, 0.6185141857713461, 0.513450832804665, 0.4090060153976083, 1.3332079793326557, 1.4191717165522277, 5.000466126948595, 6.30788192152977, 5.907951956614852, 9.200255367904902, 7.496032090857625, 12.070787586271763, 9.153487477451563, 8.769696671515703, 9.703315123915672, 7.812931286171079, 3.7825222313404083, 3.6870896397158504, 6.285873502492905, 3.6239983001723886, 5.90097458101809, 5.798314539715648, 6.333774207159877, 4.06745326705277, 9.23275787383318, 9.580487664788961, 7.629417758435011, 10.327756516635418, 6.416133837774396, 4.343752590939403, 8.204445652663708, 4.855377562344074, 9.166514128446579, 7.142113381996751, 10.795852448791265, 11.2070407345891, 9.385205693542957, 14.67804143205285, 10.190298892557621, 8.331504184752703, 9.392172619700432, 5.231472356244922, 3.427851162850857, 1.8716650921851397, 1.1759395245462656, 0.757624008692801, 0.9292168042156845, 0.48885671189054847, 1.3774925842881203, 1.5187842026352882, 5.4596866853535175, 9.521342888474464, 13.550539333373308, 39.46398697793484, 33.33482086658478, 20.32018482685089, 23.91071856021881, 32.74432115256786, 36.849598065018654, 40.00048018991947, 37.13581010699272, 31.950536146759987, 15.323580242693424, 3.61408035736531, 0.19133864378090948, 0.10372141638072208, 0.12036324682412669, 0.17354765703203157, 0.11795158599852584, 0.13838931627105922, 0.14760402962565422, 0.10368067247327417, 0.10072156641399488, 0.1356790671707131, 0.12088934046914801, 0.23599938402185217, 0.15101105149369687, 0.12684023677138612, 0.21779079077532515, 0.25662489992100745, 0.1509909689775668, 0.22526224376633763, 0.10656948230462149, 0.15257244114764035, 0.11950358748435974, 0.20132432982791215, 0.2544691687216982, 0.1295545231550932, 0.11925953222089447, 0.07097170848282985, 0.14355315011925995, 0.18967382842674851, 0.09186533265165053, 0.11732435246813111, 0.19419638731051236, 0.20101290981983766, 0.1894830964738503, 0.1586515360395424, 0.10758465869002976, 0.16087195283034816, 0.14426219800952822, 0.089127067476511, 0.15628925029886886, 0.10641388362273574, 0.15419274248415604, 0.1460971136111766, 0.1529171984293498, 0.15579398546833545], [0.017376493560732342, 0.03951836930355057, 0.06282073023612611, 0.03515733886160888, 0.04228175988828298, 0.03569882836018223, 0.01986421524634352, 0.025610750053601805, 0.024059804272837937, 0.05439811109681614, 0.00829185086331563, 0.03207453162758611, 0.037861506061744876, 0.03500184779113624, 0.03178445578669198, 0.050578199079609476, 0.024238869664259255, 0.04724871309008449, 0.04763063712744042, 0.06663567357463762, 0.014971634518587962, 0.013976345835544635, 0.04043180095322896, 0.05784415508969687, 0.053340469021350145, 0.03400347733986564, 0.0193972800479969, 0.0317514970083721, 0.06964149040868506, 0.06491124149761163, 0.015073648282850627, 0.016338230816472787, 0.03984038718044758, 0.06375607379595749, 0.06207563623320311, 0.03571923742129002, 0.030040549754630774, 0.04421328085300047, 0.03843998048978392, 0.007198044395408942, 0.04204580887744669, 0.02518448825867381, 0.038547662406926975, 0.04240036621922627, 0.06227269128430635, 0.031945101072778925, 0.014376296639966313, 0.028595206022146158, 0.059498309492482804, 0.04567011674225796, 0.5292373232077807, 1.92458022153005, 11.73163203522563, 24.384957812726498, 36.482100784778595, 42.05997347831726, 40.801139026880264, 27.358214668929577, 25.20205456763506, 17.51434698700905, 20.84381192922592, 31.970834657549858, 23.969151824712753, 15.039636678993702, 8.467927314341068, 7.9697578959167, 5.650494871661067, 4.103864338248968, 1.548539218492806, 0.7421706535387784, 0.021653099138347898, 0.25277689390350133, 0.07213430508272722, 0.2004693608614616, 0.23115344170946628, 0.6471375154796988, 1.8296405347064137, 0.08011977697606198, 2.440598113462329, 1.639277043286711, 2.272982932627201, 1.853012249339372, 1.1503575160168111, 1.6449053725227714, 3.1263169180601835, 1.5295884478837252, 2.4053773283958435, 4.307641703635454, 2.5231453590095043, 3.3510268852114677, 3.0759743694216013, 3.2201082352548838, 1.847748700529337, 3.618362252600491, 2.739918027073145, 3.151885033585131, 2.586940610781312, 1.6554614435881376, 1.6929057030938566, 2.4347452400252223, 1.1760814231820405, 2.786910580471158, 2.1579479053616524, 2.291357321664691, 6.602197978645563, 2.278025262057781, 0.7165834796614945, 1.1722037312574685, 1.5455411793664098, 1.2025892757810652, 0.6847108493093401, 0.9888193965889513, 0.505743658868596, 0.0942140667757485, 0.38302633445709944, 1.0752195166423917, 1.8259502202272415, 4.132755612954497, 10.316501520574093, 14.99209837988019, 14.481653720140457, 34.69590783119202, 46.26660615205765, 23.36157962679863, 21.20740681886673, 30.81563964486122, 23.659479841589928, 24.70390509814024, 17.607495188713074, 10.587437432259321, 3.5952476179227233, 0.2622836275259033, 0.06956891578738578, 0.08332778452313505, 0.021592573284578975, 0.012146525077696424, 0.03404818431590684, 0.014827316481387243, 0.00877131258675945, 0.017964007347472943, 0.02089231613354059, 0.03367549259564839, 0.02932853327365592, 0.02345687051274581, 0.028451483558455948, 0.0470425741514191, 0.021010957716498524, 0.07070164094329812, 0.039310204301727936, 0.025891346813295968, 0.06385005195625126, 0.03678232314996421, 0.023429334978573024, 0.04444339487235993, 0.0041125139432551805, 0.020002113706141245, 0.043087620942969806, 0.05045748876000289, 0.0128889900224749, 0.03248892833653372, 0.097976607066812, 0.008057361883402336, 0.02131324745278107, 0.0016368159776902758, 0.06532034298288636, 0.02008437706535915, 0.03510417511279229, 0.047669002451584674, 0.021130211571289692, 0.03463173874479253, 0.01841543722548522, 0.03532776936481241, 0.023677844983467367, 0.052042745883227326, 0.01974192971829325, 0.02359971167607, 0.09415243883267976, 0.025633567383920308, 0.023341227206401527, 0.03574285998183768, 0.050416262456565164, 0.04366887471405789, 0.0633777937036939, 0.07839130761567503, 0.004186134992778534, 0.019333659438416362, 0.015729680853837635, 0.05816806915390771, 0.028786995535483584, 0.03310099236841779, 0.015536132450506557, 0.040668301153345965, 0.024163454472727608, 0.035328990197740495, 0.03948452736949548, 0.027881104106199928, 0.05364347678550985, 0.04732614877866581, 0.04084033840626944, 0.053980218872311525, 0.04649911425076425, 0.037806249456480145, 0.03045557728910353, 0.05053785222116858, 0.018424786430841777, 0.07114548978279345, 0.04044489614898339, 0.026517322403378785, 0.03952872968511656, 0.01883214572444558, 0.026963648160744924, 0.018618023132148664, 0.02557832376623992, 0.033673878424451686, 0.02674872590432642, 0.0927220011362806, 0.027139822886965703, 0.031723009669804014, 0.06766069083823822, 0.06236133340280503, 0.0647150918666739, 0.022253802744671702, 0.06519722068333067, 0.07057319744490087, 0.02815110856317915, 0.027443390972621273, 0.8212478540372103, 3.2606995571404696, 15.658503770828247, 29.717785455286503, 42.61505149304867, 48.4942252188921, 43.95943835377693, 29.722143821418285, 26.004394814372063, 21.09438568353653, 25.140560567378998, 33.367164731025696, 28.183642476797104, 19.67622198164463, 13.426865469664335, 9.714561570435762, 6.524665039032698, 6.113654393702745, 2.0700890198349953, 0.6515341170597821, 0.2549503475893289, 0.1427563655306585, 0.02875560639949981, 0.21966419415548444, 0.1989476612652652, 0.49508612137287855, 1.2805095571093261, 0.6231005990412086, 1.8356223637238145, 3.5033804224804044, 2.359501915052533, 3.1419682782143354, 2.490530521608889, 2.478332701139152, 1.418103261385113, 0.9330549545120448, 3.4166268026456237, 3.743653167039156, 4.750120835378766, 4.53372529707849, 5.027089398354292, 3.761027022264898, 3.472491642460227, 5.953818820416927, 4.199849087744951, 6.025513373315334, 4.072693660855293, 2.945401263423264, 1.906815581023693, 3.836511871777475, 3.6590701807290316, 3.0406091921031475, 2.644921224564314, 3.2216013176366687, 4.40988851711154, 2.921848464757204, 0.5465727648697793, 0.7699446694459766, 0.6783501687459648, 0.5161000031512231, 0.11862840983667411, 0.1182482966396492, 0.4560247517656535, 0.16308720427332446, 0.2304956762236543, 1.0600294754840434, 1.6707802028395236, 4.832759276032448, 10.642110798507929, 18.662567473948002, 16.64263766258955, 41.807043850421906, 47.89594732224941, 20.93305204063654, 21.243179999291897, 33.77441927790642, 28.661358542740345, 31.172326505184174, 23.23433395475149, 13.489945884793997, 4.77302030660212, 0.6405696866568178, 0.012636780411412474, 0.02199653725256212, 0.010825919671333395, 0.012001046507066349, 0.027060333304689266, 0.008625123409728985, 0.02749195340584265, 0.056840893885237165, 0.038702689635101706, 0.018566369653854053, 0.07364950346527621, 0.05457235994981602, 0.03744819659914356, 0.03563200167263858, 0.05481628162669949, 0.0533073247061111, 0.0207252178734052, 0.0676824951369781, 0.05386443641327787, 0.020682857939391397, 0.02874074303690577, 0.05785850451502483, 0.008798743292572908, 0.05774244375061244, 0.06194023881107569, 0.06953946736757644, 0.008163957481883699, 0.013662498076882912, 0.04314645841077436, 0.00930106687519583, 0.020370315432955977, 0.035661246001836844, 0.018215042509837076, 0.010309678964404156, 0.030580781312892213, 0.06266408512601629, 0.04399846991873346, 0.08015104365767911, 0.04404184473969508, 0.04493378379265778, 0.006263476379899657, 0.024266948821605183, 0.06674463569652289, 0.029217507981229573, 0.1461008095066063, 0.12837910966482013, 0.10873022300074808, 0.14785340608796105, 0.13617661781609058, 0.16736681369366124, 0.18619014270370826, 0.20464650937356055, 0.14500939229037613, 0.14822192693827674, 0.21251140453387052, 0.19821948080789298, 0.15393279783893377, 0.10978471094858833, 0.09346938095404766, 0.10464307473739609, 0.12510077620390803, 0.2468427107669413, 0.12211304550874047, 0.14471064816461876, 0.18379312445176765, 0.15030987036880106, 0.2626990817952901, 0.17019188788253814, 0.14472811832092702, 0.13251757744001225, 0.15526217728620395, 0.1727484678849578, 0.15425824443809688, 0.22891549539053813, 0.12448275272618048, 0.1280610400135629, 0.17435134359402582, 0.19261291134171188, 0.19710333523107693, 0.1301874712225981, 0.08587508767959662, 0.11300003607175313, 0.16160051920451224, 0.13328429020475596, 0.16898474015761167, 0.12620822380995378, 0.17392368841683492, 0.18742935120826587, 0.17799589724745601, 0.11936927359784022, 0.18909119797172025, 0.15414178662467748, 0.12897975946543738, 0.18598498339997604, 0.9001906961202621, 3.8453765586018562, 17.373593039810658, 34.10042658448219, 51.23489275574684, 55.881720408797264, 54.8717650026083, 40.35008043050766, 38.24072241783142, 29.189777188003063, 30.37853579968214, 45.35611800849438, 32.71165810525417, 25.267977230250835, 14.985537081956863, 13.680606354027987, 8.627982325851917, 6.579318456351757, 2.576330630108714, 1.3043131423182786, 0.6294091511517763, 0.7713535032235086, 1.010955108795315, 1.194200988393277, 1.8624148447997868, 2.959457659162581, 3.6769128357991576, 2.4373435880988836, 7.011152934283018, 6.852054046466947, 5.318803545087576, 6.836774116382003, 8.201098032295704, 7.44064056314528, 10.2032077498734, 4.630577825009823, 6.860985942184925, 9.578653313219547, 5.99231312982738, 5.1395500637590885, 5.924606937915087, 8.278837110847235, 3.310860190540552, 5.79189620912075, 4.979506451636553, 7.123557552695274, 4.965653344988823, 4.3996979389339685, 4.199220221489668, 5.021816706284881, 5.206510070711374, 11.654370781034231, 8.022996839135885, 8.45820838585496, 15.070500522851944, 9.526829794049263, 3.1114784767851233, 3.560534343123436, 3.4414708195254207, 2.5341232074424624, 1.7746849148534238, 1.8671168549917638, 1.4073383202776313, 0.36835769657045603, 0.757981842616573, 1.5294631733559072, 2.8013277193531394, 6.290253717452288, 14.25960598513484, 21.245383881032467, 18.350015245378017, 46.188132762908936, 51.39874376356602, 33.334167301654816, 30.810789205133915, 41.292798444628716, 37.25435994565487, 35.849328339099884, 28.280732966959476, 15.224533807486296, 5.0312231015414, 0.8224579109810293, 0.2042034175246954, 0.09538844125927426, 0.08209329607780091, 0.1038285082904622, 0.09955766363418661, 0.11730832949979231, 0.10408547692350112, 0.14531141670886427, 0.11302849743515253, 0.10568477548076771, 0.17609389149583876, 0.25532908039167523, 0.13565294357249513, 0.12262952091987245, 0.15723382617579773, 0.17805868294090033, 0.17463908909121528, 0.17571241274708882, 0.1521999720716849, 0.12711780000245199, 0.11283755768090487, 0.15847741335164756, 0.13997628033393994, 0.1715045838500373, 0.11772926081903279, 0.15118374925805256, 0.13099767384119332, 0.1306244923034683, 0.22106921329395846, 0.17030574817908928, 0.24440818437142298, 0.2124763306346722, 0.10133621311979368, 0.15583404659992084, 0.11322115897201002, 0.1464589254464954, 0.10789473541080952, 0.17156518762931228, 0.11847186120576225, 0.18726128444541246, 0.1677994561032392, 0.1416165751288645, 0.16852849745191634, 0.08635588063043542], [0.043629544597934, 0.07177975887316279, 0.11452494174591266, 0.07562730475910939, 0.01554581005621003, 0.07622700461070053, 0.056548298452980816, 0.0361227282701293, 0.02075643074931577, 0.034938319950015284, 0.06263749397476204, 0.05934386113949586, 0.03783345287956763, 0.04613785902620293, 0.012163924729975406, 0.019760318282351363, 0.001993654032048653, 0.03877490060403943, 0.045755007304251194, 0.05181974534934852, 0.018147497794416267, 0.06784703669836745, 0.08223837852710858, 0.047051906658452936, 0.06412359274690971, 0.03457466016698163, 0.03695469808008056, 0.04610439558746293, 0.03905654935806524, 0.04599074680299964, 0.02906545119913062, 0.0244438898153021, 0.10659044055500999, 0.024745558002905454, 0.07542683582869358, 0.0055823958609835245, 0.052206192776793614, 0.08096741352346726, 0.07029164145933464, 0.05377174587920308, 0.03323394441395067, 0.08004026327398606, 0.023521374278061558, 0.04941953957313672, 0.007792037595208967, 0.017532591336930636, 0.030133674445096403, 0.02617474332510028, 0.049846883048303425, 0.033114009638666175, 0.09346713224658743, 0.11921336321393028, 2.2630008682608604, 11.197850927710533, 21.85739614069462, 37.42551036179066, 46.3894497603178, 38.8037534058094, 35.151385590434074, 23.24905626475811, 17.618677988648415, 27.65842515975237, 17.65257216989994, 24.245923273265362, 27.2296504676342, 22.191895991563797, 10.783633254468441, 7.372803278267384, 4.848916009068489, 2.3134488612413406, 1.6507872194051743, 0.6900218361988664, 0.2524486865149811, 0.12222674995427951, 0.042100831706193276, 0.5297176411841065, 0.48046417941804975, 0.34929020097479224, 0.5405006906948984, 3.1051513412967324, 1.7144462722353637, 1.2137208972126245, 1.9753560656681657, 2.268903376534581, 0.5484267685096711, 0.6073974666651338, 1.146860159933567, 1.4535995316691697, 3.5170926991850138, 1.6316272225230932, 2.890890338458121, 2.131646191701293, 1.3479355140589178, 4.288903959095478, 2.3431561421602964, 2.8044815501198173, 1.1466778884641826, 1.779174730181694, 2.693316377699375, 2.5203957315534353, 2.495447457768023, 1.4120620605535805, 2.1304806042462587, 2.975452425889671, 2.227387041784823, 1.0512916068546474, 0.6138990959152579, 0.31302465009503067, 0.15667893720092252, 0.11821990949101746, 0.23419036937411875, 0.4092206445056945, 0.3180741338292137, 0.7148492289707065, 1.0868174443021417, 2.5381289049983025, 5.8178160432726145, 8.868695609271526, 10.31158933416009, 16.87749546021223, 13.685847222805023, 30.284390151500702, 49.72186714410782, 32.34870158135891, 25.160501897335052, 27.620062418282032, 30.642121955752373, 18.974644728004932, 9.873531740158796, 4.395807422697544, 0.8421602100133896, 0.019652278278954327, 0.027469464475871064, 0.028274846845306456, 0.04629009577911347, 0.01749641163769411, 0.02738642186159268, 0.060686795914079994, 0.0032237496589004877, 0.017640874393691774, 0.009771117238415172, 0.017803610680857673, 0.07991266582394019, 0.053390593675430864, 0.027355411220923997, 0.05494293654919602, 0.01712745477561839, 0.056056421526591294, 0.02048604037554469, 0.01690147451881785, 0.02970711579109775, 0.10033902639406733, 0.053720248251920566, 0.031543851509923115, 0.05716052575735375, 0.0749765154614579, 0.026264431871823035, 0.05135848201462068, 0.019999213764094748, 0.025545823264110368, 0.04067960035172291, 0.11278781152213924, 0.060879349839524366, 0.008141200451063924, 0.07804873966961168, 0.023383423867926467, 0.033379453598172404, 0.05270638546789996, 0.02367732176935533, 0.03434926249610726, 0.019016530459339265, 0.02097677996061975, 0.06438586773583665, 0.044362849585013464, 0.04371966359030921, 0.033742248779162765, 0.10378545630373992, 0.03844543898594566, 0.06855676736449823, 0.10830066792550497, 0.0145695333412732, 0.048999020145856775, 0.019239926186855882, 0.03442794128204696, 0.04584572001476772, 0.023286289724637754, 0.06635913450736552, 0.060828156492789276, 0.02254479142720811, 0.05643973338010255, 0.05873537425941322, 0.038968753287917934, 0.013272119122120785, 0.023214063912746496, 0.015011665964266285, 0.051847850481863134, 0.03679967085190583, 0.06300403329078108, 0.04766558115079533, 0.09969127990189008, 0.049374472655472346, 0.013035630054218927, 0.020831569490837865, 0.023445265178452246, 0.053689078049501404, 0.06473253975855187, 0.10272086030454375, 0.03568707274098415, 0.018237765216326807, 0.01080331292541814, 0.0812396036053542, 0.07378645197604783, 0.029974775061418768, 0.0022451597624240094, 0.045461469344445504, 0.050030839192913845, 0.040024963018368, 0.025450169705436565, 0.03338521266414318, 0.03404376853723079, 0.02495999971870333, 0.03791901879594661, 0.013541174557758495, 0.009764737551449798, 0.031058325512276497, 0.017144642915809527, 0.05832753442518879, 0.3636028751498088, 3.5442192060872912, 15.355940256267786, 27.380489073693752, 42.400651797652245, 53.42612497508526, 43.10101881623268, 39.272997826337814, 25.19461076706648, 21.649794280529022, 32.36711539328098, 19.78565040975809, 21.502835266292095, 21.00377194583416, 21.740058436989784, 12.833780944347382, 9.845947120338678, 6.1834813468158245, 3.263547266833484, 1.411706660874188, 0.7152251712977886, 0.10477394505869597, 0.1135675712430384, 0.0854567761416547, 0.27250858198385686, 0.3520376613596454, 0.6056227837689221, 0.6605048419442028, 0.8350149902980775, 1.3412279239855707, 2.3668393213301897, 1.9296384626068175, 1.9525507581420243, 1.4902103296481073, 1.1964452429674566, 2.981507400982082, 3.5419614147394896, 4.214914329349995, 3.6877180309966207, 4.568060729652643, 2.0459503401070833, 2.9608113365247846, 5.014107394963503, 2.811040710657835, 4.023223165422678, 2.8027041954919696, 4.62229996919632, 3.161169122904539, 4.879679633304477, 2.887401175685227, 1.2284731306135654, 1.3228941452689469, 1.7360704368911684, 1.5498822089284658, 1.626815611962229, 0.17782594542950392, 0.33196274482179433, 0.26853461866267025, 0.19954353163484484, 0.09187769683194347, 0.26414353866130114, 0.16149911214597523, 0.606764325639233, 1.38453574385494, 2.6172304479405284, 6.6461606696248055, 10.538637600839138, 15.865857694298029, 21.317959986627102, 16.643448919057846, 32.245605513453484, 54.57572288811207, 34.751533046364784, 27.819318026304245, 34.17054042220116, 35.21454580128193, 23.87171745300293, 13.504673894494772, 5.302253533154726, 1.0010647145099938, 0.020750308030983433, 0.007315113089134684, 0.023421828154823743, 0.04772003994730767, 0.027055672617279924, 0.019440374708210584, 0.014432500411203364, 0.020068927406100556, 0.058423560913070105, 0.043568395340116695, 0.043728695527534, 0.03590875967347529, 0.05712025311368052, 0.02754140270553762, 0.03140037581033539, 0.030675466368847992, 0.06482412820332684, 0.056486407047486864, 0.018926879020000342, 0.0703317545412574, 0.02402752827038057, 0.022604031510127243, 0.027873241051565856, 0.09181403540424071, 0.059505460085347295, 0.03671585269330535, 0.04969030102074612, 0.03994331564172171, 0.07779574152664281, 0.02661039514350705, 0.062127542041707784, 0.1505497918697074, 0.05294049595249817, 0.02721021188335726, 0.02775857923552394, 0.010959217743220506, 0.02687213393073762, 0.05394025793066248, 0.04161010139796417, 0.04999844073608983, 0.017608041780476924, 0.09318588054156862, 0.04072743176948279, 0.04011104101664387, 0.016052628270699643, 0.16581122763454914, 0.15458137553650886, 0.12073086967575364, 0.2523783902870491, 0.13221414294093847, 0.11772294514230452, 0.1358681367128156, 0.23652743693673983, 0.14924981631338596, 0.12214788192068227, 0.1857538934564218, 0.13796601007925346, 0.09224546069162898, 0.1348295752541162, 0.16546875616768375, 0.1603574663749896, 0.048607225544401444, 0.17087277868995443, 0.19338069279910997, 0.20271024608518928, 0.08099559287074953, 0.13391613989369944, 0.20574298803694546, 0.13755201041931286, 0.1365941797848791, 0.19990669417893514, 0.14612828381359577, 0.15182929899310693, 0.13588121335487813, 0.20546883868519217, 0.1888449682155624, 0.1718146531493403, 0.1758225474623032, 0.13443654868751764, 0.10352397541282699, 0.08325866831000894, 0.09125861208303832, 0.2547245565801859, 0.16550250904401764, 0.18194320262409747, 0.07759343206998892, 0.11869989350088872, 0.12216273229569197, 0.11756186941056512, 0.1341409215820022, 0.14282020507380366, 0.18144585978006944, 0.07041136472253129, 0.09119338472373784, 0.16389905445976183, 0.2635586669202894, 0.6038539193104953, 3.542860778979957, 16.123807802796364, 31.06188353151083, 51.17762602865696, 60.076813101768494, 52.63551279902458, 49.88198675215244, 35.69771267473698, 27.123567759990692, 41.447510942816734, 26.484407857060432, 33.5452763736248, 36.803909316658974, 33.4747863560915, 18.539370484650135, 12.120399624109268, 7.93315683491528, 3.419359093531966, 2.3101962357759476, 1.4072518749162555, 0.449477435904555, 0.5706138373352587, 0.5348823952954262, 0.9941965830512345, 1.9437292939983308, 3.1029241858050227, 2.790738637559116, 4.9564397893846035, 5.304043237119913, 5.156007930636406, 6.6350476909428835, 8.896239381283522, 6.083206152543426, 4.8665636871010065, 5.7470913883298635, 4.93680814281106, 8.942925576120615, 4.437722973525524, 7.99650751054287, 5.414259172976017, 6.100231138989329, 10.247459225356579, 5.562966568395495, 7.184348115697503, 5.731193516403437, 5.790520682930946, 8.982377909123898, 8.721257820725441, 6.703411722555757, 7.274015229195356, 6.140477629378438, 6.849835915490985, 6.576236821711063, 5.0986215099692345, 1.9643000839278102, 1.4565997081808746, 1.6909815813414752, 1.5087447850964963, 0.7917878567241132, 0.7176926638931036, 0.7285752205643803, 1.1320207687094808, 1.6272962861694396, 3.7980750342831016, 8.262870367616415, 14.792747776955366, 15.947603657841682, 26.66839398443699, 19.81969278305769, 40.35683646798134, 56.86322674155235, 38.62377226352692, 38.092606365680695, 39.5891522616148, 42.01110050082207, 28.290703631937504, 14.824913050979376, 6.096721552312374, 1.1727801128290594, 0.07956653556902893, 0.10801379816257395, 0.05384719632274937, 0.14822590484982356, 0.1470970833906904, 0.12734611431369558, 0.09754734885063954, 0.07842633698601276, 0.16866347927134484, 0.18395497201709077, 0.10131606381037273, 0.20517773868050426, 0.1819059468107298, 0.11260831568506546, 0.10647653572959825, 0.10715049487771466, 0.18202936596935615, 0.10757190859294496, 0.138477097498253, 0.13395121379289776, 0.1790335532859899, 0.1535897474968806, 0.11322032776661217, 0.16170538467122242, 0.14067891606828198, 0.06936384554137476, 0.18117559928214177, 0.14377686311490834, 0.13351380679523572, 0.1319067453732714, 0.28592898685019463, 0.35156066820491105, 0.21428197593195364, 0.13710835453821346, 0.1304823116515763, 0.11085682490374893, 0.22888067382154986, 0.13542807282647118, 0.12325224961386994, 0.090088037395617, 0.09347617902676575, 0.19109207263682038, 0.1213621924398467, 0.14260176132665947, 0.16981607914203778], [0.019155078298354056, 0.0813759138691239, 0.04098012563190423, 0.037122879875823855, 0.024254547533928417, 0.05020634227548726, 0.03209561233234126, 0.06703782855765894, 0.015293941833078861, 0.03145002920064144, 0.034609192298376, 0.07094890970620327, 0.03451365191722289, 0.03865867656713817, 0.08489861429552548, 0.02616205074446043, 0.05232602736214176, 0.025958258847822435, 0.07831616516341455, 0.033398137165931985, 0.04701094010670204, 0.03802851897489745, 0.02180400930228643, 0.03895878624462057, 0.05215971206780523, 0.0652309661381878, 0.04792875413841102, 0.016181778664758895, 0.04448580861208029, 0.04228141107887495, 0.043848485584021546, 0.05743111280025914, 0.06791901018004864, 0.037179546561674215, 0.019499603658914566, 0.04373669216874987, 0.032238479470834136, 0.014998692295193905, 0.042197834118269384, 0.09382835778524168, 0.05867493004188873, 0.018872143773478456, 0.015131669388210867, 0.0560829124879092, 0.025396818564331625, 0.048777882402646355, 0.037158154154894873, 0.04440770127985161, 0.03754430843400769, 0.054538848271477036, 0.0642054590571206, 0.027691602263075765, 0.2594791998853907, 1.6980093042366207, 10.103308260440826, 23.861345909535885, 31.70005738735199, 40.69528430700302, 41.88651658594608, 35.473745092749596, 26.00897166877985, 29.253953844308853, 35.401902347803116, 39.27808575332165, 28.23245655745268, 30.019379071891308, 18.900170624256134, 14.737356249243021, 10.7986044511199, 7.639757953584194, 6.292716935276985, 2.601253492757678, 1.5357850841246545, 0.49284703214652836, 0.40129076689481735, 0.3314948652405292, 0.46676947677042335, 0.10017653316026554, 0.5173586856108159, 1.6807417245581746, 0.7009130611550063, 2.0807175245136023, 1.3477216567844152, 0.9591526666190475, 1.021534453611821, 0.21035709825810045, 1.241339952684939, 1.1125630815513432, 2.0215314254164696, 3.3666321728378534, 2.26487725507468, 0.591144491918385, 1.0914148413576186, 2.2797199711203575, 1.9692774605937302, 3.0432312889024615, 2.2563203517347574, 3.9715297892689705, 1.8273441516794264, 6.179946586489677, 3.295450354926288, 0.34090868197381496, 1.1158347059972584, 0.3124562243465334, 1.590970829129219, 1.132295778952539, 0.27371926233172417, 0.17442401469452307, 0.08114420052152127, 0.12704762251814827, 0.17826351569965482, 0.3098616760689765, 0.7640120596624911, 1.7622411763295531, 2.2915188129991293, 5.718803331255913, 8.031838964670897, 16.14743683487177, 13.044426441192627, 20.7845389097929, 20.294944681227207, 22.907847873866558, 40.34007556736469, 39.018768668174744, 32.5130807608366, 30.157556757330894, 19.797984547913074, 10.927742421627045, 2.741137524135411, 0.7082741567865014, 0.047499577558483, 0.07150246281526051, 0.02527552751416806, 0.055376851742039435, 0.02607375558000058, 0.05889491374546196, 0.017051792819984257, 0.0385515512607526, 0.02534707797167357, 0.047504969261353835, 0.06228341531823389, 0.10456440708367154, 0.013005429282202385, 0.04539513247436844, 0.02158319253794616, 0.05089935235446319, 0.03858238378597889, 0.025847196448012255, 0.019070751768595073, 0.048516843089601025, 0.06922875239979476, 0.03630042810982559, 0.052485834021354094, 0.022212765688891523, 0.07398563699098304, 0.021093299001222476, 0.017783830589905847, 0.06103978361352347, 0.022983178059803322, 0.07140401692595333, 0.01589891835465096, 0.037701324617955834, 0.043672503816196695, 0.025359490391565487, 0.01599813793291105, 0.03996724990429357, 0.04206727920973208, 0.02757363788987277, 0.045716449021711014, 0.0377819812274538, 0.027026819770981092, 0.04579200336593203, 0.008507361271767877, 0.015648623484594282, 0.04887765673629474, 0.0400893665937474, 0.03813158102275338, 0.028844892331107985, 0.023641581792617217, 0.011546507957973517, 0.018887461701524444, 0.06560818495927379, 0.03704515103891026, 0.048878833040362224, 0.016636295877106022, 0.06774037523427978, 0.03320278163300827, 0.05066629200882744, 0.004904494053334929, 0.00907272287804517, 0.04344541404861957, 0.0157449820835609, 0.03792078139667865, 0.01182210078695789, 0.08465369071927853, 0.04250501275237184, 0.07225577239296399, 0.03622205360443331, 0.0590651216043625, 0.04861770838033408, 0.07702252012677491, 0.006555528188982862, 0.12516794056864455, 0.06021989225700963, 0.0571601175761316, 0.04544022536720149, 0.04149896478338633, 0.06289346812991425, 0.06819715970777906, 0.17937204684130847, 0.07687150049605407, 0.02712994861212792, 0.03354424377903342, 0.046493299523717724, 0.08897557287127711, 0.10036586987553164, 0.0674632572918199, 0.03669083489512559, 0.03232589333492797, 0.015564580826321617, 0.010328650114388438, 0.06351135802106, 0.04042778964503668, 0.029819551164109726, 0.05303854479279835, 0.025275679654441774, 0.0497039602487348, 0.014251093543862225, 0.40934508782811463, 2.983153900131583, 13.26095212250948, 30.519401840865612, 38.096740543842316, 46.733418703079224, 45.10451830923557, 38.15387427806854, 27.315544858574867, 32.50302270054817, 30.934377573430538, 31.689531952142715, 30.56893788278103, 35.77414557337761, 24.53781221061945, 19.041876420378685, 14.183061942458153, 8.564183749258518, 7.799300467595458, 2.8562207613140345, 1.1276071867905557, 0.5791884334757924, 0.24801712977932766, 0.2553023333894089, 0.11695502267684788, 0.1658280595438555, 0.26173146965447813, 0.23126094922190532, 0.34284901223145425, 1.0269295703619719, 1.0340146464295685, 1.064313983079046, 1.3621877180412412, 0.6473519071005285, 2.6169689744710922, 2.016836302354932, 3.12930878251791, 1.6544156684540212, 3.2437842898070812, 1.5152621478773654, 4.047296773642302, 3.524250090122223, 2.943735052831471, 1.7454838380217552, 1.723069790750742, 3.5450435243546963, 1.7637214343994856, 1.8426986527629197, 2.820407683029771, 1.1573347728699446, 1.1371255572885275, 1.4368291315622628, 1.4724307274445891, 0.2834393782541156, 0.341174608329311, 0.08829880098346621, 0.15106879058293998, 0.018374383471382316, 0.16876476758625358, 0.2106404650839977, 0.8848376793321222, 2.2630851762369275, 3.441020781174302, 7.12505467236042, 10.966844223439693, 17.091722264885902, 14.97361522167921, 18.87781072407961, 17.400689385831356, 24.777778834104538, 46.068610176444054, 39.57083344459534, 35.57156704366207, 34.192423447966576, 25.331253334879875, 14.534677024930716, 4.433197416365147, 0.9610484086442739, 0.03520026097248774, 0.05722956404497381, 0.032717372523620725, 0.05895253038033843, 0.08676683748490177, 0.05514696778845973, 0.059933081865892746, 0.08461726611130871, 0.12449768473743461, 0.020058552181581035, 0.025050185504369438, 0.049976224545389414, 0.030509492462442722, 0.05010152504837606, 0.055677139534964226, 0.01710599557554815, 0.056482896688976325, 0.016446352456114255, 0.017995977214013692, 0.0561639364605071, 0.05703952600015327, 0.07944394761580043, 0.015079168006195687, 0.013545627443818375, 0.04251606704201549, 0.016493669936608057, 0.007129481082301936, 0.00842989218654111, 0.046858480709488504, 0.017094809554691892, 0.007618357876708615, 0.03290141772595234, 0.0055140245785878506, 0.008483709025313146, 0.026966434925270732, 0.02721355154790217, 0.019321592117194086, 0.021981223035254516, 0.02275738890602952, 0.024530442788091023, 0.06443718724767677, 0.058944329648511484, 0.02795917804178316, 0.026125750446226448, 0.1046115779899992, 0.1342585074598901, 0.13145136355888098, 0.1459649667958729, 0.16692216333467513, 0.07660450544790365, 0.15472631697775796, 0.09123308220296167, 0.10870421814615838, 0.14626163290813565, 0.11926057864911854, 0.12100659238058142, 0.1499414534191601, 0.23448262712918222, 0.1598483679117635, 0.09356747061247006, 0.14671602024463937, 0.10662410437362269, 0.22223952080821618, 0.13166266784537584, 0.2320590548333712, 0.1351258554495871, 0.15496046456974, 0.15637735807104036, 0.17244386079255491, 0.17181777016958222, 0.1820111833512783, 0.09492783472524025, 0.20405828312505037, 0.06692464361549355, 0.20557262061629444, 0.14579373848391697, 0.07946728816023096, 0.2326033459394239, 0.2569556899834424, 0.28369702224154025, 0.1670841296436265, 0.1616264201584272, 0.25368949805852026, 0.14933750848285854, 0.1706534592085518, 0.19063091691350564, 0.12788567051757127, 0.09033973678015172, 0.19735051493626088, 0.13928826490882784, 0.09944133198587224, 0.14235964306863025, 0.16410314507083967, 0.15094713773578405, 0.12424338783603162, 0.1738287232001312, 0.2391690670629032, 0.12743539467919618, 0.5083230673335493, 3.2966119050979614, 15.161013565957546, 33.23455564677715, 43.99363651871681, 54.99101400375366, 53.919057324528694, 49.10543382167816, 34.59454447031021, 42.34949514269829, 46.54337950050831, 51.80068999528885, 39.5371862500906, 40.354613587260246, 28.873694948852062, 23.882886953651905, 18.354584500193596, 10.9352508187294, 9.119631294161081, 4.158052755519748, 2.457008957862854, 1.3140577194280922, 1.1589368619024754, 0.6330000178422779, 0.9762592299375683, 0.49417096422985196, 2.0631653163582087, 3.89003936201334, 2.971264338120818, 5.744625320658088, 4.895305819809437, 5.734181581065059, 3.1792219541966915, 3.0115721002221107, 5.431260885670781, 4.0545320603996515, 6.72268096357584, 6.6733496356755495, 7.529695434495807, 3.112554056569934, 6.63124124519527, 6.7569769732654095, 6.139860637485981, 7.084544571116567, 5.5409258510917425, 10.702049732208252, 5.4037755355238914, 12.14807828888297, 10.291718300431967, 2.3971084970980883, 5.035953847691417, 3.57487881090492, 3.270494481548667, 3.515249085612595, 1.480889548547566, 1.5346985799260437, 0.5756691691931337, 0.4831327049760148, 0.4874759609811008, 0.6930279498919845, 1.2901173415593803, 3.054857002571225, 4.069824339821935, 10.592171028256416, 13.163428455591202, 23.185740262269974, 22.297558821737766, 29.776456207036972, 30.154112242162228, 31.535454019904137, 52.225681990385056, 46.0527840256691, 43.216958194971085, 40.76711185276508, 28.04118812084198, 16.165278777480125, 4.749832050874829, 0.8572414820082486, 0.12192420603241771, 0.1650564040755853, 0.16170404880540445, 0.09436641485081054, 0.22192272765096277, 0.14891956059727818, 0.10650764656020328, 0.15622575214365497, 0.22291043715085834, 0.15848896116949618, 0.15555082820355892, 0.2740570582682267, 0.11781383596826345, 0.11393885288271122, 0.08358090883120894, 0.25322817906271666, 0.12519479147158563, 0.08647970054880716, 0.11428238562075421, 0.12699519720626995, 0.11379806746845134, 0.15332377661252394, 0.11524334069690667, 0.2039512209012173, 0.12512882938608527, 0.1315773802343756, 0.13068328524241224, 0.16163584543392062, 0.09555543190799654, 0.12442435312550515, 0.12942829867824912, 0.11862351908348501, 0.18900285271229222, 0.11901890567969531, 0.1562357266084291, 0.14079909946303815, 0.19888376235030591, 0.12732355302432552, 0.12533235596492887, 0.13055379531579092, 0.15161149349296466, 0.1831056285300292, 0.13236150378361344, 0.09733989631058648, 0.2377001490094699, 0.19402781588723883], [0.05073823580460157, 0.06442367273848504, 0.0374752107745735, 0.0352301695238566, 0.03156716236844659, 0.02745552879787283, 0.042552254162728786, 0.03652409286587499, 0.023788168946339283, 0.04854520426306408, 0.050413119461154565, 0.019604331828304566, 0.0210140172202955, 0.04629507559002377, 0.02620625677081989, 0.034511733465478756, 0.06357286722050048, 0.04652408380934503, 0.09383468088344671, 0.043854886607732624, 0.07087036821758375, 0.011463069222372724, 0.10802167234942317, 0.03940388189221267, 0.025505400335532613, 0.01923741216160124, 0.051798805652651936, 0.023222932577482425, 0.0426051692920737, 0.08058865103521384, 0.0389260463998653, 0.08540774986613542, 0.030018721336091403, 0.01487774912675377, 0.027152710281370673, 0.025826620403677225, 0.04875991871813312, 0.01076209682651097, 0.05869665641512256, 0.007075975945554092, 0.08818183850962669, 0.01970226934645325, 0.02746889673289843, 0.029813695618940983, 0.06259931789827533, 0.03372131279320456, 0.036556621198542416, 0.03823589358944446, 0.021464563942572568, 0.051220757959526964, 0.02139819182048086, 0.09742875365191139, 0.020300347605370916, 0.19221605529310182, 1.5641057956963778, 8.847048170864582, 20.055017955601215, 33.05727235972881, 44.966597110033035, 40.02384893596172, 27.02629677951336, 23.26819583773613, 25.51854718476534, 30.45291680842638, 28.062810860574245, 29.555598758161068, 17.36936006695032, 22.31275610625744, 23.74516524374485, 16.963532343506813, 10.702822990715504, 8.37681295350194, 5.025458335876465, 2.8695266973227262, 1.331720002926886, 0.5551803123671561, 0.29340176086407155, 0.18580456729978323, 0.08747212268644944, 0.3355111903510988, 0.30846726964227855, 0.4465432808501646, 0.6827420205809176, 0.5220878880936652, 0.7144303014501929, 0.8222919073887169, 2.095256019383669, 2.9273082967847586, 1.6797443968243897, 1.0228173597715795, 2.5505331018939614, 0.5834177846554667, 2.252148650586605, 2.434576624073088, 2.3596926173195243, 1.3196491193957627, 0.6274191266857088, 3.3405339857563376, 0.7252340123523027, 1.7906647198833525, 1.605546846985817, 1.0600312566384673, 0.08551194739993662, 0.7183740148320794, 1.0451081511564553, 0.1628980308305472, 0.3205136029282585, 0.2341818792046979, 0.11061244309530593, 0.45357367547694594, 0.41378425899893045, 1.9789244304411113, 2.1117846574634314, 6.253329673781991, 6.801445037126541, 8.501443415880203, 16.96046780794859, 19.353805482387543, 29.473620057106018, 31.115542352199554, 26.259953901171684, 26.414014734327793, 30.669153705239296, 39.93144549429417, 32.27553650736809, 21.05347517877817, 9.747556149959564, 2.9380750190466642, 0.4872679815161973, 0.023138756332627963, 0.06501457814010791, 0.06570266035851091, 0.07457050131051801, 0.020020912306790706, 0.021919736100244336, 0.02037392412603367, 0.013640323631989304, 0.042258990797563456, 0.11197317828191444, 0.027466768624435645, 0.0426014288677834, 0.07148354547098279, 0.03546912252204493, 0.023409690329572186, 0.007710592453804566, 0.012080007309123175, 0.011128301248390926, 0.031667834700783715, 0.028259074351808522, 0.026796972924785223, 0.018927906894532498, 0.07809136863215826, 0.047815227808314376, 0.024341005882888567, 0.038310286472551525, 0.03709111224452499, 0.03106937980192015, 0.044159111494082026, 0.05767290451331064, 0.05890831322176382, 0.03880682779708877, 0.08405656612012535, 0.004317972889111843, 0.056629556202096865, 0.08633958306745626, 0.03278712698374875, 0.012798068582924316, 0.0552065548254177, 0.015445193384948652, 0.03597013528633397, 0.04023438596050255, 0.03354219545144588, 0.12738296936731786, 0.013836694979545427, 0.040532989078201354, 0.026859715944738127, 0.054272506313282065, 0.03460774139966816, 0.05304372498358134, 0.09686763805802912, 0.06979662895901129, 0.08965805187472142, 0.03669075325888116, 0.04140295313845854, 0.03661473507236224, 0.04178436880465597, 0.07401062510325573, 0.02725443831877783, 0.06460549891926348, 0.11475810970296152, 0.012523752247943776, 0.04945431661326438, 0.036166021454846486, 0.03496068085951265, 0.10984599750372581, 0.029729341258644126, 0.20235158095601946, 0.061504709447035566, 0.060595485774683766, 0.02702443191083148, 0.026526365472818725, 0.03935766093491111, 0.07631154265254736, 0.012465659710869659, 0.022657410481770057, 0.015985439786163624, 0.0835479648958426, 0.09289182678912766, 0.06383978805388324, 0.10089853152749129, 0.01678101467405213, 0.03190760035067797, 0.038232216247706674, 0.03133357138722204, 0.05030926702602301, 0.01800207952328492, 0.048265626101056114, 0.025555302345310338, 0.005685481100954348, 0.027082927990704775, 0.05438072999822907, 0.056883608194766566, 0.044850926715298556, 0.05585478000284638, 0.0835687450307887, 0.01744239627441857, 0.02438395211356692, 0.0375352987612132, 0.032164286967599764, 0.32727721030823886, 2.5015855534002185, 12.504649255424738, 25.690254271030426, 40.59190705418587, 51.3809797167778, 45.569381564855576, 32.41400487720966, 28.492394909262657, 31.535366624593735, 37.14629374444485, 27.93868102133274, 29.560962170362473, 23.47648736089468, 24.348916746675968, 27.205177880823612, 22.477646358311176, 14.042404890060425, 9.993575848639011, 5.970760211348534, 3.569008125923574, 1.3082782295532525, 0.4338050284422934, 0.14686470211017877, 0.06383716085110791, 0.1388661758392118, 0.16013151209335774, 0.34167659701779485, 0.009310924451710889, 0.2601640537614003, 0.5003116128500551, 0.6231805728748441, 0.5505570885725319, 1.026963412296027, 0.7328691089060158, 1.091078796889633, 0.942677641287446, 2.1593139320611954, 1.4662667457014322, 2.087749522179365, 1.4563954691402614, 2.4481100728735328, 2.043146090582013, 1.6963319317437708, 2.2458550008013844, 1.9362659007310867, 1.9252208434045315, 0.4153614118695259, 0.4871974478010088, 0.30228805902879685, 0.6355114455800503, 0.13178831344703212, 0.14983589033363387, 0.24444554408546537, 0.05170896867639385, 0.10217110699159093, 0.4538352380041033, 0.5350312998052686, 1.9015319645404816, 2.929617860354483, 7.7169631607830524, 7.249920247122645, 12.868870161473751, 19.208168797194958, 22.874867543578148, 27.05763939768076, 30.77374119311571, 26.579653546214104, 27.674661688506603, 35.71631647646427, 45.92187725007534, 37.60059356689453, 27.430264502763748, 13.48434403538704, 4.53672856092453, 0.7159747404512018, 0.032176576933125034, 0.08200380791095085, 0.051804839313263074, 0.03307322862383444, 0.034048514571622945, 0.05721787892980501, 0.06521372604765929, 0.05312681583745871, 0.03763590058952104, 0.022426116447604727, 0.026049504049296957, 0.012246368987689493, 0.002834994616023323, 0.041186442686012015, 0.006633064067500527, 0.03683660012029577, 0.03142692985420581, 0.028796636033803225, 0.033477183314971626, 0.012831881758756936, 0.012372754881653236, 0.07016094925347716, 0.04993126894987654, 0.053835359067306854, 0.029620091554534156, 0.09159879031358287, 0.02958981192932697, 0.021386361986515112, 0.03708305252075661, 0.014439717797358753, 0.06358030354022048, 0.019491722050588578, 0.02312664633791428, 0.052795242809224874, 0.07905638325610198, 0.20222183869918808, 0.07293492657481693, 0.08685599168529734, 0.012313298648223281, 0.042248571044183336, 0.05966770098893903, 0.07183331967098638, 0.006242015324460226, 0.04448252831934951, 0.031714393335278146, 0.06056868311134167, 0.021436442111735232, 0.12641385808819905, 0.14403199864318594, 0.24493582168361172, 0.23118640790926293, 0.18843018187908456, 0.14222602680092677, 0.12243504112120718, 0.13823796267388389, 0.18991060322150588, 0.19053277530474588, 0.14935625513317063, 0.1178480192902498, 0.1491256253211759, 0.2482600643998012, 0.12652755511226133, 0.1702384205418639, 0.1429683229071088, 0.12148096575401723, 0.25092084193602204, 0.16183474101126194, 0.22369418962625787, 0.1182951038936153, 0.258748332853429, 0.13210430508479476, 0.08855745429173112, 0.15891651244601235, 0.16430030402261764, 0.08652059288579039, 0.13687086728168651, 0.1588994133635424, 0.18933730898424983, 0.22011356457369402, 0.18703923386055976, 0.13347279571462423, 0.08614875463536009, 0.19257431966252625, 0.17398737953044474, 0.15506580501096323, 0.14150752394925803, 0.09431141428649426, 0.15583740110741928, 0.07161898000049405, 0.14364320231834427, 0.12326412397669628, 0.16136696533067152, 0.18431785254506394, 0.1337066464475356, 0.164445141563192, 0.1707308948971331, 0.15552722790744156, 0.2046603281632997, 0.2218011044897139, 0.12551516178064048, 0.43078321090433747, 2.956607574597001, 12.727449350059032, 28.977146297693253, 44.89244408905506, 58.71766783297062, 52.85892181098461, 38.53088244795799, 36.025711074471474, 36.29382848739624, 43.84015895426273, 37.810543701052666, 40.92646770179272, 26.87214285135269, 30.30886273831129, 35.15961974859238, 23.587374910712242, 15.637243911623955, 12.205566354095936, 6.708282586187124, 4.497907944023609, 2.3855169815942645, 0.6725421210285276, 0.776903877267614, 0.5986604886129498, 0.42106520268134773, 0.723303894046694, 1.5933579322881997, 1.381512531079352, 2.2869467083364725, 2.0647688303142786, 4.132593171671033, 2.644686112180352, 6.230654390528798, 8.266058396548033, 4.010149966925383, 5.0556225422769785, 5.922446278855205, 4.488702937960625, 5.5384578835219145, 7.783681880682707, 7.722303299233317, 6.376788849011064, 6.8195064179599285, 6.274112183600664, 5.336287831887603, 5.1311776880174875, 4.982317350804806, 3.008003616705537, 1.5267826546914876, 2.316677263006568, 2.9732668306678534, 0.6965641945134848, 0.6726896006148309, 0.7353892643004656, 0.3007077000802383, 0.7842849218286574, 0.6370020937174559, 2.547404207289219, 3.4400295093655586, 9.151083156466484, 11.058208420872688, 14.344409834593534, 26.586762964725494, 27.102091312408447, 42.326966151595116, 42.06115901470184, 35.522580072283745, 36.36178784072399, 41.260203793644905, 49.59992788732052, 43.268692418932915, 30.862494930624962, 15.518611427396536, 4.39869336783886, 0.8971924195066094, 0.07013143404037692, 0.1624357173568569, 0.11204639115021564, 0.1616984826978296, 0.11720056223566644, 0.12092532720998861, 0.13612600334454328, 0.14455938362516463, 0.13152781961252913, 0.1847607662784867, 0.10765614977572113, 0.14304978103609756, 0.14223436854081228, 0.18175750243244693, 0.06198579925694503, 0.17431258864235133, 0.20196983503410593, 0.18016590736806393, 0.08268513658549637, 0.10749462875537574, 0.07664269636734389, 0.15169174934271723, 0.17293102137045935, 0.22727010946255177, 0.13265640358440578, 0.20292025903472677, 0.07465102433343418, 0.08868284014170058, 0.12028881683363579, 0.19827530515613034, 0.17769207683159038, 0.13076639093924314, 0.16918992914725095, 0.12553678796393797, 0.20010370470117778, 0.26611785928253084, 0.12005174517980777, 0.11353646041243337, 0.19642686762381345, 0.09139446963672526, 0.126990714634303, 0.19554627971956506, 0.09074069690541364, 0.1546277746092528, 0.11995205990388058, 0.19447904167464003, 0.13974959874758497], [0.036557125858962536, 0.057265016439487226, 0.0312903115991503, 0.030474286832031794, 0.03458602244791109, 0.02007373837841442, 0.05890444292163011, 0.0741542677860707, 0.08226388614275493, 0.03232952243706677, 0.014023634557815967, 0.057502266208757646, 0.039718363259453326, 0.04800607108336408, 0.08448251435765997, 0.05054340719652828, 0.020458538238017354, 0.016041640774346888, 0.04213183121464681, 0.04133673872274812, 0.037806249456480145, 0.008502158816554584, 0.02810868369124364, 0.00533458579411672, 0.0011219359521419392, 0.013398392766248435, 0.04327314301917795, 0.02338934991712449, 0.08412222392507829, 0.013746937784162583, 0.056750730364001356, 0.059227919118711725, 0.0357038378569996, 0.03791787588852458, 0.0724995530617889, 0.07429336110362783, 0.033152660689665936, 0.035492841561790556, 0.0334005899640033, 0.07183532346971333, 0.06017740430252161, 0.018231891117466148, 0.04374888194433879, 0.028465294926718343, 0.01935623000463238, 0.0193269225928816, 0.05903831894102041, 0.007842209561204072, 0.03958976762078237, 0.014578607024304802, 0.028142622104496695, 0.024403019742749166, 0.0674795919621829, 0.019810446647170465, 0.19555043574655429, 1.5336883091367781, 7.1954211965203285, 17.0163020119071, 26.51973456144333, 37.79271885752678, 44.10091996192932, 34.18236918747425, 30.143733099102974, 21.461939960718155, 23.547716438770294, 27.003708891570568, 21.57470840960741, 30.168859250843525, 17.917661145329475, 17.422264628112316, 21.55530285090208, 14.237509220838547, 12.808389756828547, 8.628061171621084, 5.890364125370979, 2.7507806941866875, 1.7554769455455244, 0.5546577216591686, 0.470409948611632, 0.4074648121604696, 0.10194461094215512, 0.5811547092162073, 0.05498139464179985, 0.39186721318401396, 0.32818078994750977, 0.2876565878977999, 0.47865031112451106, 0.24369248683797196, 0.9377446153666824, 0.3131962346378714, 1.481138791423291, 0.570362457074225, 1.22612260049209, 1.3080614036880434, 0.9849915176164359, 0.466954093426466, 0.7164488837588578, 1.180713849607855, 0.6314574787393212, 0.45316095231100917, 0.4457161424215883, 0.8579894481226802, 0.05566776620980818, 0.17379217984853312, 0.2693514263955876, 0.27478237403556705, 0.07719572997302748, 0.38447245373390615, 0.5351998563855886, 0.9234376705717295, 2.541672927327454, 2.8664153767749667, 7.419068645685911, 8.397141862660646, 12.098638191819191, 16.15272045135498, 17.352186888456345, 19.521338492631912, 17.40950871258974, 24.996162615716457, 25.790781676769257, 33.49984981119633, 35.370421037077904, 33.49539265036583, 25.474555045366287, 8.000191412866116, 3.058323129080236, 0.14312476763734594, 0.04787638448760845, 0.06320206797681749, 0.025399725927854888, 0.042840764072025195, 0.005041090971644735, 0.02457323131238809, 0.04877422732533887, 0.04368539863207843, 0.03718972882779781, 0.03998356973170303, 0.08001416936167516, 0.017542708665132523, 0.011991252013103804, 0.02264786646264838, 0.02300314183230512, 0.03871049702866003, 0.01674858467595186, 0.07119970367057249, 0.03757001642952673, 0.07120473543182015, 0.028774514466931578, 0.04846486306632869, 0.046286451834021136, 0.023016350205580238, 0.016326788754668087, 0.032152112034964375, 0.03564572769391816, 0.03946452277887147, 0.041788035014178604, 0.060690354512189515, 0.025108753943641204, 0.06726197199895978, 0.07197426093625836, 0.057820614165393636, 0.03705790113599505, 0.009843162151810247, 0.042560722067719325, 0.027923926027142443, 0.043780501146102324, 0.05761024869570974, 0.0412867031263886, 0.05575565875915345, 0.0206530236027902, 0.02698574560781708, 0.005492786167451413, 0.10594371080514975, 0.05356230067263823, 0.036233486389392056, 0.07876896430389024, 0.04572648285829928, 0.033215316507266834, 0.031433627736987546, 0.04334950259362813, 0.05481330932525452, 0.03206203386071138, 0.018213779003417585, 0.05803788902994711, 0.028396199122653343, 0.07825067805242725, 0.04754077788675204, 0.03616585447161924, 0.056249079352710396, 0.011572076800803188, 0.05419502980657853, 0.01568989802763099, 0.009162907736026682, 0.0808045121084433, 0.06358368031214923, 0.015596088705933653, 0.045526158646680415, 0.0441601133934455, 0.008200713273254223, 0.0215250211476814, 0.039678736284258775, 0.04664207044697832, 0.029517419134208467, 0.04047719812660944, 0.038812490383861586, 0.08259923299192451, 0.040075280630844645, 0.04106204389245249, 0.06287797208642587, 0.09174093385809101, 0.053996594360796735, 0.039570323351654224, 0.016008791462809313, 0.01091811111109564, 0.03713955964485649, 0.02767374062386807, 0.04458290379261598, 0.14078580017667264, 0.024374430358875543, 0.05237592937191948, 0.04345941466453951, 0.05573644826654345, 0.0670305777748581, 0.08541670758859254, 0.02451565735100303, 0.06791134379454888, 0.036844259084318765, 0.04092548129847273, 0.04585152732033748, 0.24655644956510514, 2.510362369939685, 9.654143862426281, 21.900449730455875, 33.66633787751198, 42.676687985658646, 45.27826398611069, 36.87241584062576, 33.189744651317596, 25.62678437680006, 27.572583965957165, 30.833067409694195, 21.07079464942217, 31.032940484583378, 28.596518822014332, 23.245132975280285, 24.68262054026127, 20.03050547093153, 14.61050670593977, 10.143433157354593, 6.264995047822595, 3.1400505686178803, 1.8792186118662357, 0.6697937997523695, 0.2708872564835474, 0.29660383122973144, 0.00993723122519441, 0.2670393988955766, 0.03590847394661978, 0.11444519797805697, 0.01291487335038255, 0.23150425491621718, 0.5927906942088157, 0.2308837155578658, 0.27893148420844227, 0.8417902642395347, 0.4228691558819264, 0.8419290755409747, 1.8781500379554927, 0.9323721786495298, 1.1119035794399679, 0.5138285562861711, 0.5837335239630193, 0.7464258908294141, 0.5703067069407552, 0.37606389087159187, 0.583970476873219, 0.4119793855352327, 0.05259985016891733, 0.29114022909197956, 0.19691264780703932, 0.030601702455896884, 0.15522750414675102, 0.34292530501261353, 0.5204204900655895, 1.530270273797214, 3.020821991376579, 4.560981234535575, 10.59437870979309, 12.322714067995548, 16.879636645317078, 18.796314597129822, 19.105384312570095, 20.367556884884834, 22.100111916661263, 29.21268615871668, 28.3342207968235, 36.689535453915596, 37.24387630820274, 38.21016825735569, 28.720998242497444, 10.97602928057313, 4.759261244907975, 0.3239672019844875, 0.04812759405467659, 0.03336553832923528, 0.022086880744609516, 0.02043388223682996, 0.03844114937237464, 0.014909296896803426, 0.03572237670596223, 0.04173942063061986, 0.0111624567398394, 0.06995550793362781, 0.03436452847381588, 0.03103767154243542, 0.019055385600950103, 0.0415110988978995, 0.01933065002958756, 0.008572380829718895, 0.015527307386946632, 0.11825682391645387, 0.034920567777589895, 0.09659037910751067, 0.0674905015330296, 0.07087122168741189, 0.04624081346264575, 0.017189396276080515, 0.029560161274275742, 0.037301028714864515, 0.07276432166690938, 0.03159681858960539, 0.004513042695180047, 0.042103124942514114, 0.029175873496569693, 0.05296945455484092, 0.032844316883711144, 0.05256363336229697, 0.007529796002927469, 0.03660795926407445, 0.01703163423371734, 0.03925593104213476, 0.016844253077579197, 0.039327429549302906, 0.01728605173411779, 0.021036112811998464, 0.013459692308970261, 0.027778075454989448, 0.017238088585145306, 0.006341320713545429, 0.03985354916949291, 0.043942883057752624, 0.12812660133931786, 0.12145678658271208, 0.15184008982032537, 0.13161156355636194, 0.16579193179495633, 0.13314142677700147, 0.17998222581809387, 0.1441753370454535, 0.1779900342808105, 0.11491795346955769, 0.3018620068905875, 0.08479506243020296, 0.23461177566787228, 0.12874837266281247, 0.23365075379842892, 0.1826385356253013, 0.08116046839859337, 0.10610136523609981, 0.21650089358445257, 0.2305630038608797, 0.10265352524584159, 0.11664352845400572, 0.2112002225476317, 0.06548877339810133, 0.142138690862339, 0.10954461133223958, 0.10252189793391153, 0.15116066846530885, 0.2115774413687177, 0.14902801805874333, 0.11876112068421207, 0.13633894035592675, 0.08436970791080967, 0.09668685088399798, 0.15586897206958383, 0.17494271654868498, 0.13815561396768317, 0.06713480499456637, 0.09761466906638816, 0.1673725133878179, 0.1099767342384439, 0.13182453025365248, 0.28692708641756326, 0.14215035742381588, 0.17738126538461074, 0.15313019481254742, 0.20515924436040223, 0.10789273903355934, 0.24060749768977985, 0.07176989573054016, 0.16220084246015176, 0.11360144286300056, 0.20464523287955672, 0.13963336357846856, 0.4552569257793948, 2.5999485002830625, 10.5273493565619, 23.95531676709652, 37.15897746384144, 50.658634677529335, 55.67996263504028, 47.155568450689316, 40.79091377556324, 33.954332023859024, 32.596022710204124, 37.421057000756264, 33.750533759593964, 41.634434312582016, 29.025893881917, 25.409399941563606, 32.836884185671806, 21.356269530951977, 17.72431042045355, 11.996741909533739, 8.577429838478565, 4.66872445307672, 2.6832796912640333, 1.1355734593234956, 0.7693773123901337, 0.44375654601026326, 0.3206122788833454, 0.9675666026305407, 0.5482178984675556, 1.1267270590178668, 0.8615288394503295, 0.9398726793006063, 2.0887303445488214, 1.2070097448304296, 3.197522247210145, 2.5526279769837856, 4.173194942995906, 3.0637900857254863, 5.739428149536252, 3.601917685009539, 3.5266681853681803, 2.800207491964102, 4.197819996625185, 3.9293375657871366, 3.5510291531682014, 1.3555827224627137, 1.6641362593509257, 2.3483100906014442, 1.3738880027085543, 1.3836516975425184, 0.6580023199785501, 0.6953908293507993, 0.37705436116084456, 0.737408084096387, 1.006781745236367, 1.6544130560941994, 3.70694309938699, 4.563276311382651, 11.487561631947756, 12.35694833099842, 21.222058832645416, 24.752677381038666, 25.9146436303854, 29.991574063897133, 25.761973522603512, 36.530969962477684, 34.75267678499222, 44.276713728904724, 45.9491103887558, 43.71375493705273, 32.8565177321434, 13.527895398437977, 5.026369336992502, 0.5407125886995345, 0.1971492890152149, 0.1325826786342077, 0.11417804707889445, 0.13206108240410686, 0.14845706900814548, 0.15567113034194335, 0.17633676674449816, 0.18067172553855926, 0.1959481675294228, 0.2434375145821832, 0.1585327330394648, 0.12407009635353461, 0.10465507526532747, 0.10728503883001395, 0.07012554880930111, 0.09939833194948733, 0.0965990919212345, 0.2457518278970383, 0.0845149091037456, 0.2739091927651316, 0.21169217739952728, 0.19121519493637607, 0.15828590956516564, 0.05829558125697076, 0.177458671387285, 0.16300864052027464, 0.15448094811290503, 0.10498706760699861, 0.11808345079771243, 0.13315465184859931, 0.11456670981715433, 0.19298858649563044, 0.16065034753410146, 0.15501915360800922, 0.16996140650007874, 0.1491331506986171, 0.1310688309604302, 0.11171012403792702, 0.22248005087021738, 0.12468150729546323, 0.13658524432685226, 0.1856555588892661, 0.14089301083004102, 0.10403176027466543, 0.1363522099563852, 0.11292303825030103, 0.10807747443323024, 0.18745191249763593], [0.06574386439751834, 0.026549444410193246, 0.025294504230259918, 0.05907725942961406, 0.20432515942957252, 0.0995888709439896, 0.027762475510826334, 0.03644931777671445, 0.1045103713113349, 0.04527343509835191, 0.08305756855406798, 0.05212987773120403, 0.04930208728183061, 0.04532024235231802, 0.09170619392534718, 0.05353383930923883, 0.045090517960488796, 0.04091262358997483, 0.07691265258472413, 0.05907137048779987, 0.030407903577724937, 0.01683662751020165, 0.09537323465337977, 0.01045286058797501, 0.05772340024122968, 0.01955838546564337, 0.08749031272600405, 0.03598156807129271, 0.012644212092709495, 0.01848600062658079, 0.037654825355275534, 0.058116193031310104, 0.02036132060311502, 0.027033445294364356, 0.02443398585455725, 0.030044084232940804, 0.0245647077463218, 0.07530905699240975, 0.0703005249670241, 0.04235639396938495, 0.09071058055269532, 0.05458821222418919, 0.0028500140615506098, 0.04913495562504977, 0.09254669101210311, 0.039016425143927336, 0.03359647613251582, 0.038405192317441106, 0.069472681498155, 0.06288773874985054, 0.04469628540391568, 0.03953637380618602, 0.033641895570326596, 0.06695156131172553, 0.019737749571504537, 0.07668023419682868, 1.2530854786746204, 5.3541929461061954, 14.691853690892458, 27.167734690010548, 40.70600353181362, 47.017635852098465, 47.60397098958492, 37.09487870335579, 21.847885251045227, 29.990527220070362, 28.0781639367342, 16.016934737563133, 15.495768003165722, 27.69563466310501, 26.130411252379417, 18.783834166824818, 16.851867735385895, 14.949770551174879, 10.504914410412312, 8.793188910931349, 5.098792025819421, 5.038160579279065, 2.263484629802406, 0.796498297713697, 0.8910904813092202, 0.26128006575163454, 0.27413902105763555, 0.21485246485099196, 0.2415302098961547, 0.13937723357230425, 0.11190064818947576, 0.3168915957212448, 0.08531346000381745, 0.35071372927632183, 0.2857560367556289, 0.6787831673864275, 0.3970389731694013, 0.3706342197256163, 0.7944674848113209, 0.6457211414817721, 0.45082116848789155, 0.49231755430810153, 0.37243182014208287, 0.18167013680795208, 0.16556358779780567, 0.16289858001982793, 0.31894244661089033, 0.2671061031287536, 0.27790598454885185, 0.5143802391830832, 1.4051188831217587, 0.9600839135237038, 3.7212160835042596, 4.399481350556016, 5.954088130965829, 8.004326540976763, 8.507202956825495, 10.325454790145159, 9.931281991302967, 20.901859514415264, 23.163796439766884, 28.228103891015053, 27.243143543601036, 26.846188344061375, 33.88460576534271, 31.567533798515797, 30.996604934334755, 18.67376547306776, 10.922564249485731, 2.2298687836155295, 0.3465253743343055, 0.08840788184897974, 0.022586739469261374, 0.04115849711524788, 0.024543272666051053, 0.043359766495996155, 0.011017276883649174, 0.03858252850477584, 0.06626528993365355, 0.01338459438557038, 0.026157147003686987, 0.03536698815878481, 0.055149012405308895, 0.019313304183015134, 0.056505699176341295, 0.06868760057841428, 0.021942024650343228, 0.03388766519492492, 0.07385853677988052, 0.06265818505198695, 0.05774955352535471, 0.05913427121413406, 0.050461258870200254, 0.07588512686197646, 0.030901027312211227, 0.021420164957817178, 0.061160286131780595, 0.03732040619070176, 0.10654703233740292, 0.07306381536182016, 0.07449584867572412, 0.04378867961349897, 0.006232811765585211, 0.023366896239167545, 0.04477245201996993, 0.04830180208955426, 0.016354188846889883, 0.04456789756659418, 0.020564531769196037, 0.07221377425594255, 0.042937172765959986, 0.052488060464384034, 0.018324648444831837, 0.02609993112855591, 0.0687051004206296, 0.03660215937998146, 0.023899832485767547, 0.05514284144737758, 0.08203995792428032, 0.0769658423087094, 0.04812522660358809, 0.04960505793860648, 0.017219969049619976, 0.020931733452016488, 0.06801658033509739, 0.053582264445140027, 0.03582833684049547, 0.03460526262642816, 0.02382458798820153, 0.0512379460997181, 0.0930823732051067, 0.10209940068307333, 0.019985471044492442, 0.08789953295490704, 0.07520283339545131, 0.015995219437172636, 0.0764973319019191, 0.10390688650659285, 0.029312979713722598, 0.04094717056432273, 0.026078930204676, 0.056761276282486506, 0.06440315977670252, 0.02824620922183385, 0.09793109114980325, 0.04517833258432802, 0.03485306944639888, 0.06703019185806625, 0.058687539130914956, 0.0254423493242939, 0.056450683769071475, 0.04202676165732555, 0.04315871497965418, 0.1371524084242992, 0.03589843268855475, 0.025731419555086177, 0.09245903595001437, 0.04436059716681484, 0.04674828291172162, 0.022972689657763112, 0.0834709002810996, 0.03636303197708912, 0.0255529868445592, 0.045311355133890174, 0.03908534097718075, 0.046033457401790656, 0.07760574429994449, 0.01701256103842752, 0.07368993567069992, 0.050958033971255645, 0.0695469333732035, 0.0565353331330698, 0.08634477067971602, 0.12396353879012167, 0.07459370826836675, 0.07851931324694306, 1.7303460440598428, 7.691854108124971, 18.955592550337315, 32.13813968002796, 45.97276791930199, 51.761008724570274, 52.37566374242306, 40.72738118469715, 26.562626659870148, 35.52717782557011, 26.819929853081703, 20.70929154753685, 16.826055720448494, 27.00701091438532, 31.41511257737875, 24.487280622124672, 25.602716468274593, 19.669072665274143, 15.06537364795804, 11.227284148335457, 5.506225638091564, 4.882218847051263, 2.624429874122143, 0.7763897767290473, 0.9513621346559376, 0.30624774342868477, 0.19367118424270302, 0.10848687277757563, 0.1668004659586586, 0.2096810017246753, 0.046654397519887425, 0.1016541788703762, 0.0802235514856875, 0.13149230042472482, 0.3938174288487062, 0.2865147194825113, 0.10004086114349775, 0.10975193028571084, 0.239061945467256, 0.13669490406755358, 0.19926050619687885, 0.14916052110493183, 0.2852962911128998, 0.05266120351734571, 0.23529419529950246, 0.22136699262773618, 0.0826726685045287, 0.18487042601918802, 0.18411744298646227, 0.6308116915170103, 0.9449748555198312, 1.5623862692154944, 4.070325437933207, 5.398025494068861, 9.334800448268652, 8.62939964979887, 11.355964243412018, 11.574375573545694, 11.663268003612757, 22.535665445029736, 23.667221926152706, 28.956500105559826, 29.144200533628464, 30.329678021371365, 37.22472533583641, 36.5930700302124, 36.71231523156166, 24.088315330445766, 14.14454435929656, 3.3336703665554523, 0.459721508086659, 0.050085257171303965, 0.0396263888978865, 0.04606699505529832, 0.015729597362224013, 0.017919322635862045, 0.07068368096952327, 0.07811962961568497, 0.05554574599955231, 0.030265338864410296, 0.05170009259018116, 0.029524849887820892, 0.031066233095771167, 0.03708347925567068, 0.09652262102463283, 0.013544999401347013, 0.05953550593403634, 0.04069309259648435, 0.04064624081365764, 0.07981506598298438, 0.033608532321522944, 0.0558119729248574, 0.030377238035725895, 0.09204751506331377, 0.019608083384810016, 0.013646816496475367, 0.07631902350112796, 0.0017252229281439213, 0.017582049913471565, 0.08261708906502463, 0.05242038401775062, 0.06895147118484601, 0.01932270904944744, 0.033703723893268034, 0.09553983196383342, 0.0836818854440935, 0.08116696219076402, 0.029840745046385564, 0.018272262095706537, 0.03647143748821691, 0.043229527000221424, 0.02780178521788912, 0.013847906975570368, 0.01506813876403612, 0.03519105834129732, 0.026124702162633184, 0.011764808841689955, 0.038726868806406856, 0.044276701082708314, 0.05037074653955642, 0.1515029469737783, 0.170085241261404, 0.11793865778599866, 0.1818429384729825, 0.22318032657494769, 0.2024273097049445, 0.16263102093944326, 0.11560859609744512, 0.1957745643449016, 0.17182667594170198, 0.13224988477304578, 0.1458021395956166, 0.20172461459878832, 0.1949873089324683, 0.34308237314689904, 0.20037162001244724, 0.2342041436349973, 0.19520374888088554, 0.1761716537293978, 0.11943811521632597, 0.07928790364530869, 0.09929104708135128, 0.18684821989154443, 0.13140171387931332, 0.13469456374878064, 0.20514852774795145, 0.15895271440967917, 0.10693973235902376, 0.09527878151857294, 0.09307063985033892, 0.18178950384026393, 0.19775543070863932, 0.09487182484008372, 0.3071395674487576, 0.09992314910050482, 0.1671300092129968, 0.2244716783752665, 0.11639362506684847, 0.13215644838055596, 0.10761225916212425, 0.2879762160591781, 0.20380209374707192, 0.0795019612996839, 0.08742308898945339, 0.2104520337888971, 0.11170124053023756, 0.12626245996216312, 0.07626895821886137, 0.17295273661147803, 0.17948311666259542, 0.23005773487966508, 0.11583675455767661, 0.1635097831604071, 0.22059247246943414, 0.09979452006518841, 0.24087841127766296, 2.0803503692150116, 7.666256306692958, 20.487318858504295, 35.93174211680889, 51.318598464131355, 59.14137929677963, 59.73348252475262, 48.22663597762585, 31.11646380275488, 41.028921604156494, 40.30433468520641, 24.73925080150366, 26.50018461048603, 38.282539173960686, 38.97579297423363, 26.72400400042534, 26.80492825806141, 22.944403812289238, 15.773290861397982, 12.639366276562214, 7.818052936345339, 6.39441610313952, 3.3000958431512117, 1.3815217930823565, 1.4228240330703557, 0.5441775871440768, 0.5509696633089334, 0.6009269482456148, 0.7078612851910293, 0.7477880583610386, 1.1980852112174034, 0.4638535191770643, 0.932185691781342, 1.3131498056463897, 1.3348701526410878, 2.2503857826814055, 2.110843020491302, 1.4756680349819362, 2.16852986253798, 1.9099024403840303, 0.9346629807259887, 1.6787917166948318, 1.11798788420856, 0.5815972667187452, 1.0697441291995347, 0.7721393485553563, 0.44823508069384843, 0.9784074802882969, 0.6052997417282313, 1.1577466945163906, 1.8754071788862348, 1.5740530681796372, 4.799704374745488, 7.017994467169046, 9.21942438930273, 13.798885457217693, 15.4858666844666, 19.11706868559122, 16.748264394700527, 32.885829359292984, 33.44829797744751, 39.63969334959984, 36.693384647369385, 37.038200944662094, 45.02268590033054, 42.428477704524994, 41.053430289030075, 26.52310498058796, 15.605480466037989, 3.708073776215315, 0.4571155604207888, 0.2142696562805213, 0.09957075511920266, 0.1176754328480456, 0.09963551492546685, 0.19176595757016912, 0.15664015256334096, 0.15697293158154935, 0.18415492144413292, 0.24999461194965988, 0.17376051982864738, 0.19951470661908388, 0.16060724359704182, 0.08602659712778404, 0.16649269731715322, 0.18927620054455474, 0.13223397312685847, 0.11508152281749062, 0.22977249784162268, 0.11842699095723219, 0.12473840033635497, 0.12676116835791618, 0.16163844295078889, 0.1669582465547137, 0.0885232858126983, 0.1170720742084086, 0.12628089491045102, 0.16654399456456304, 0.22069816914154217, 0.2584933309117332, 0.2184206515084952, 0.09463956972467713, 0.2215396607061848, 0.06505837227450684, 0.23097121476894245, 0.17725542682455853, 0.1423328515375033, 0.08255982495029457, 0.09539339138427749, 0.185173949575983, 0.22419702436309308, 0.14648801763541996, 0.07209060742752627, 0.09929623469361104, 0.14998740720329806, 0.13795790582662448, 0.09268683075788431, 0.14863548130961135, 0.13574817596236244, 0.37438319355715066], [0.08268659861641936, 0.08813261185423471, 0.0374578816263238, 0.0591396406525746, 0.038137829906190746, 0.03660349153506104, 0.03480531966488343, 0.015552428158116527, 0.02579077652626438, 0.04732300207251683, 0.03375742940988857, 0.035697900675586425, 0.04345451277913526, 0.03053518375963904, 0.0071021881376509555, 0.06717104406561702, 0.039410179015249014, 0.05198120699787978, 0.03732976838364266, 0.02265983359393431, 0.04992588466848247, 0.03169862640788779, 0.031825659825699404, 0.03198922917363234, 0.07582933962112293, 0.02556291306973435, 0.035923754767281935, 0.046444243562291376, 0.03962228853197303, 0.037141136708669364, 0.06101249855419155, 0.048590894584776834, 0.05405708681792021, 0.026578968900139444, 0.028288225912547205, 0.014790048608119832, 0.03096572960203048, 0.06755581052857451, 0.02123335154465167, 0.021588541567325592, 0.08202758632251061, 0.02986097413668176, 0.07179642008850351, 0.07782791362842545, 0.06863078917376697, 0.028325006751401816, 0.05161895358469337, 0.07265177497174591, 0.003762053024729539, 0.018197700374003034, 0.020454729165066965, 0.038362077248166315, 0.04472983047890011, 0.06269881021580659, 0.0594985321367858, 0.031208964792313054, 0.059811276878463104, 0.5146424844861031, 2.0770998811349273, 11.114473901689053, 22.474807910621166, 34.88847769796848, 42.03627794981003, 43.33532564342022, 35.472551956772804, 40.11310614645481, 36.689577251672745, 23.05538635700941, 26.391594037413597, 22.00623605400324, 26.810867339372635, 29.691711254417896, 26.71556655317545, 22.86242701113224, 24.232027418911457, 16.79427992552519, 18.44033259898424, 12.56151795387268, 8.913633897900581, 6.281070085242391, 3.064140141941607, 2.927497336640954, 0.9800499421544373, 1.1476597795262933, 0.4312031774315983, 0.4289195890305564, 0.25925076683051884, 0.14180350728565827, 0.1431542754289694, 0.28298984456341714, 0.06646549911238253, 0.2076873555779457, 0.4422369837993756, 0.2834061597241089, 0.24151973077096045, 0.12546341924462467, 0.2467608667211607, 0.0927814694296103, 0.2183826535474509, 0.13463499897625297, 0.32319922756869346, 0.34801602247171104, 0.7064576167613268, 0.8361012570094317, 2.1523287193849683, 2.1561249531805515, 3.811869719065726, 7.45232256129384, 6.2918824050575495, 8.77832030877471, 7.413954120129347, 15.327646024525166, 20.504341945052147, 22.918075025081635, 20.178245343267918, 18.3225180208683, 23.427323698997498, 28.14573761075735, 30.220173597335815, 33.719132244586945, 35.389218628406525, 25.409375242888927, 13.150910027325153, 6.995527222752571, 2.303173025138676, 0.2715143118984997, 0.031248703089659102, 0.06292011865298264, 0.03526323962432798, 0.04219509930408094, 0.07377698217169382, 0.053047743713250384, 0.0246149696977227, 0.04153511850745417, 0.03857133320707362, 0.059718449047068134, 0.051774363018921576, 0.08091694748145528, 0.04189434395811986, 0.03725679671333637, 0.008757147770666052, 0.020368612204038072, 0.09148291879682802, 0.01331861931248568, 0.01379490928229643, 0.051147003323421814, 0.021697269912692718, 0.013008180794713553, 0.06759650990716182, 0.034450302191544324, 0.03392220845853444, 0.008842140377964824, 0.02334184875508072, 0.03755359641218092, 0.10471993155078962, 0.04045018766191788, 0.04329565606894903, 0.07939801609609276, 0.06750697721145116, 0.047925670514814556, 0.04918149941659067, 0.055770483158994466, 0.015471241840714356, 0.02922897972894134, 0.04498449845414143, 0.05697888140275609, 0.05809181719087064, 0.02781635914288927, 0.02869716041459469, 0.023497987349401228, 0.06698624187265523, 0.06136025411251467, 0.03675019928778056, 0.05099384630739223, 0.010484705217095325, 0.030988801117928233, 0.04296241320844274, 0.04743784942547791, 0.035756448705797084, 0.03296657829196192, 0.024006566309253685, 0.06711477442877367, 0.013664317266375292, 0.04003140486020129, 0.04194916269625537, 0.011119438149762573, 0.05506788453203626, 0.052999374238424934, 0.06345993460854515, 0.028064457255823072, 0.010562541665422032, 0.05897270195418969, 0.041238326230086386, 0.07613961672177538, 0.013725203061767388, 0.009515493748040171, 0.013281878364068689, 0.01450747773560579, 0.037528582324739546, 0.06271207981626503, 0.017395281029166654, 0.01883986777102109, 0.056329361177631654, 0.06275367719354108, 0.03418243140913546, 0.031079254076757934, 0.031230457389028743, 0.03428294789046049, 0.04536850050499197, 0.010144945372303482, 0.02502972820366267, 0.04125657935219351, 0.018128662086382974, 0.04689857152698096, 0.035032665473409, 0.04799947339051869, 0.06111360133218113, 0.02292437398864422, 0.09647401035181247, 0.028800137115467805, 0.06068936003430281, 0.041259599893237464, 0.024104989934130572, 0.03242872531700414, 0.0047945958976924885, 0.04616241669282317, 0.022506945606437512, 0.023632299380551558, 0.08328318144776858, 0.043582303187577054, 0.013589875215984648, 0.015612903916917276, 0.028128625199315138, 0.880425819195807, 3.8997970009222627, 15.430141724646091, 27.143197506666183, 41.061687245965004, 47.887587770819664, 47.667207196354866, 38.22325095534325, 44.14493680000305, 39.99964043498039, 21.789111904799938, 23.86945467442274, 22.685081027448177, 29.91509936749935, 29.8924582824111, 29.46082804352045, 27.626026198267937, 26.438379026949406, 20.062615647912025, 21.233857199549675, 15.628580376505852, 9.463442545384169, 7.875791313126683, 3.4641741262748837, 3.1229030387476087, 1.19110795436427, 1.123973038047552, 0.5299547128379345, 0.48482839367352426, 0.16143657878274098, 0.1317695964826271, 0.04181723481451627, 0.04986663901945576, 0.12973857577890158, 0.06599893313250504, 0.226666520757135, 0.07312132438528351, 0.062165963026927784, 0.15102019475307316, 0.23431502049788833, 0.1810088980710134, 0.05259241755993571, 0.1291738310828805, 0.13102856202749535, 0.14021212002262473, 0.6587943399790674, 0.8241473359521478, 1.8597368197515607, 2.2201515175402164, 4.49517541565001, 7.497198153287172, 9.41670885309577, 14.274174403399229, 11.833217684179544, 18.293392583727837, 18.06888923048973, 21.098096184432507, 18.933939412236214, 19.01252679526806, 25.78298069536686, 31.283426843583584, 36.32124401628971, 38.28159302473068, 39.83171984553337, 31.760639436542988, 17.736749053001404, 9.429094288498163, 3.4202736569568515, 0.3063587687211111, 0.04961185230058618, 0.0628531101392582, 0.056734696263447404, 0.07244723165058531, 0.019901463638234418, 0.01639033514948096, 0.050754477706504986, 0.03422521251195576, 0.05361240306228865, 0.05314350673870649, 0.05163221576367505, 0.06546281307237223, 0.028723387913487386, 0.021081853228679392, 0.029975576580909546, 0.022530980058945715, 0.0195039786194684, 0.028992926672799513, 0.0115801522952097, 0.05581186531344429, 0.09900159464450553, 0.03560165896487888, 0.024092748208204284, 0.022580694676435087, 0.048868665617192164, 0.02126664243405685, 0.04291207704227418, 0.011374873320164625, 0.04423473263159394, 0.02349726746615488, 0.020151973731117323, 0.04291480072424747, 0.06353529970510863, 0.04684511091909371, 0.017759705224307254, 0.023695628697169013, 0.017470712919021025, 0.027235105371801183, 0.060547606117324904, 0.031585920150973834, 0.004357369334684336, 0.028068923129467294, 0.04627705995517317, 0.05543767074414063, 0.03179319828632288, 0.03792248462559655, 0.03391434911463875, 0.038131206238176674, 0.05078537331428379, 0.00427320514972962, 0.14523043355438858, 0.2150410891044885, 0.12601888709468767, 0.1679562867502682, 0.11949826628551818, 0.11525307025294751, 0.08216153655666858, 0.16799327539047226, 0.12174375282484107, 0.10745214822236449, 0.14165139669785276, 0.13864715321687981, 0.19831468351185322, 0.15131680149352178, 0.1644422917161137, 0.18104907794622704, 0.1216558157466352, 0.22997816180577502, 0.14213230839231983, 0.10520910334889777, 0.1109023779281415, 0.09177186657325365, 0.1378287869738415, 0.2367438917281106, 0.11932172419619747, 0.1726835299632512, 0.12361246583168395, 0.22715602652169764, 0.19214008905692026, 0.14341610512929037, 0.18122498178854585, 0.13981921219965443, 0.21436815412016585, 0.155929887550883, 0.14326800213893875, 0.1529523910721764, 0.13611378759378567, 0.20575227972585708, 0.15977010101778433, 0.12372880490147509, 0.20276894996641204, 0.10170965440920554, 0.14844393299426883, 0.17549969838000834, 0.11079694842919707, 0.10021036025136709, 0.20689879398560151, 0.2339246211340651, 0.07567380031105131, 0.15679928386816755, 0.15611996641382575, 0.135127161629498, 0.19039475067984313, 0.15780337998876348, 0.09560911144944839, 0.09438813009182923, 0.2016906687640585, 1.016150142531842, 4.073461219668388, 16.860664263367653, 29.256816990673542, 45.662370175123215, 55.50738349556923, 58.26432175934315, 45.39896070957184, 53.15333381295204, 47.78228402137756, 36.54930017888546, 37.80424743890762, 32.58582405745983, 39.18730482459068, 42.227065712213516, 36.76916018128395, 34.64496396481991, 33.47434937953949, 26.59942388534546, 26.421954408288002, 17.348472587764263, 12.60879311710596, 8.639094829559326, 4.341539209708571, 3.570132628083229, 1.509937564842403, 1.4582206774502993, 0.8434688241686672, 1.1001498601399362, 0.49392501648981124, 0.6594819249585271, 0.3051415574736893, 0.6597456545569003, 0.6298701139166951, 0.5413474515080452, 1.2378123169764876, 0.7528901158366352, 0.8713624149095267, 0.5533011944498867, 0.8656515588518232, 0.5914591625332832, 0.6732701975852251, 0.5402643315028399, 0.7537080813199282, 0.7651168503798544, 1.1524424166418612, 1.3978441734798253, 2.980333026498556, 3.086257567629218, 5.794845800846815, 10.23055488243699, 8.95656494423747, 14.109281301498413, 14.99184474349022, 22.151737846434116, 32.044493705034256, 35.500704646110535, 30.621319971978664, 27.92957480996847, 34.087195694446564, 39.245506301522255, 41.453978195786476, 45.60769870877266, 45.433044880628586, 36.09565392136574, 20.7057748362422, 10.420018415898085, 3.7909026816487312, 0.7064449705649167, 0.15551386924926192, 0.24955140135716647, 0.1955192952300422, 0.17745404038578272, 0.1499608383164741, 0.18096172716468573, 0.19795180298388004, 0.1425311088678427, 0.11257684862357564, 0.12172643109806813, 0.1450068096164614, 0.19438161252764985, 0.11301974751404487, 0.11976949899690226, 0.11716542154317722, 0.10231533597107045, 0.23046051326673478, 0.10408049711259082, 0.1727391465101391, 0.1748923395643942, 0.21092398033943027, 0.13110207917634398, 0.11345344377332367, 0.1166577405820135, 0.15753583575133234, 0.13559054379584268, 0.17975872062379494, 0.12820690171793103, 0.18105443625245243, 0.11860883940244094, 0.09258254416636191, 0.14325302559882402, 0.15740780043415725, 0.17054555093636736, 0.13559849961893633, 0.17406141618266702, 0.15038062672829255, 0.1371346859377809, 0.2702631993452087, 0.16087771189631894, 0.16682391782524064, 0.14670650591142476, 0.156438036065083, 0.1524642063304782, 0.1404910784913227, 0.15175734035437927, 0.058638282789615914, 0.11660110729280859, 0.25807268160860986, 0.14621725247707218], [0.03400223053176887, 0.04088034758751746, 0.052813225047430024, 0.04357408390205819, 0.0416944835887989, 0.05437423620605841, 0.11910043802345172, 0.04285553652152885, 0.08407624787651002, 0.05359955277526751, 0.04768060221977066, 0.006079395925553399, 0.02202596155257197, 0.04248384298989549, 0.057543852453818545, 0.008346086087840376, 0.067475807009032, 0.06720190998748876, 0.0063383729957422474, 0.023284597627935, 0.02303459776157979, 0.05564352024521213, 0.029541275471274275, 0.07383504780591466, 0.07830021640984342, 0.07894834881881252, 0.04646224064345006, 0.08360916239325888, 0.054046444420237094, 0.043518133388715796, 0.042616346036083996, 0.0594037413247861, 0.08593897175160237, 0.029138810641597956, 0.008471824457956245, 0.060273015187704004, 0.1095837596221827, 0.03484144741378259, 0.05895590344152879, 0.04413137743540574, 0.01883039982203627, 0.05633184366161004, 0.0715475928154774, 0.03296036651590839, 0.02072085590043571, 0.030823344859527424, 0.04586083014146425, 0.025725057494128123, 0.0441079700976843, 0.04892974437098019, 0.07433981212670915, 0.04214688568026759, 0.07142314949305728, 0.040008962314459495, 0.05156936698767822, 0.04288386429834645, 0.020568548643495888, 0.031978197148418985, 0.09631321663619019, 1.2053119484335184, 6.778475744649768, 18.172317780554295, 29.387005604803562, 42.33620725572109, 39.45207081735134, 38.67703400552273, 47.31532707810402, 42.447465285658836, 22.77066383510828, 32.01112009584904, 25.48672579228878, 25.426917001605034, 26.14737544208765, 30.787813737988472, 29.795643277466297, 29.65121492743492, 19.39087249338627, 13.559882082045078, 13.25033264234662, 8.072314392775297, 10.865195877850056, 6.0443047899752855, 6.81934017688036, 3.967251218855381, 3.004222819581628, 1.939409519545734, 2.252874174155295, 2.1321047795936465, 1.588108038995415, 1.3697696174494922, 1.5781086380593479, 1.3930088141933084, 0.8581827627494931, 0.7981282321270555, 0.8600097522139549, 0.7651634572539479, 0.4391053877770901, 0.6178357440512627, 1.0148713923990726, 1.235634321346879, 1.3243150315247476, 2.20327306073159, 3.705389932729304, 5.049680136144161, 6.417357372120023, 10.431215465068817, 9.631524626165628, 16.511444002389908, 17.846407368779182, 12.576138619333506, 22.696087136864662, 19.453588128089905, 20.528292059898376, 21.013774909079075, 19.911991730332375, 28.657161667943, 31.31733052432537, 36.962809190154076, 34.426456689834595, 28.588668443262577, 19.36083510518074, 9.976114835590124, 5.450037578120828, 1.2902769329957664, 0.029705594388360623, 0.06303638350800611, 0.04396577460283879, 0.029285895034263376, 0.03955216670874506, 0.06629862720728852, 0.005728674559577485, 0.0742955578607507, 0.07567247186671011, 0.04204394979751669, 0.05985553485515993, 0.05261495658487547, 0.02108268628944643, 0.04071181327162776, 0.06850483187008649, 0.07064158635330386, 0.0655731036385987, 0.03950353748223279, 0.039481306448578835, 0.05341206029697787, 0.018077466884278692, 0.03565707513189409, 0.03847958520054817, 0.05039735995524097, 0.03807416476774961, 0.037181427906034514, 0.0020425488082764787, 0.026202405024378095, 0.0256124774023192, 0.11525352296303026, 0.09741085304995067, 0.018554450762167107, 0.06073589269362856, 0.024760968699411023, 0.024561518366681412, 0.0803971101413481, 0.01645552911213599, 0.03664367141027469, 0.018752175601548515, 0.04980704085028265, 0.03162243010592647, 0.07276080388692208, 0.024328394938493147, 0.05049746825534385, 0.021899065432080533, 0.05579606870014686, 0.0490062301105354, 0.0483033420459833, 0.05668090168910567, 0.038949899026192725, 0.015733929649286438, 0.09018884331453592, 0.09283585401135497, 0.06199307972565293, 0.04778574970259797, 0.08746657142182812, 0.010138592588191386, 0.043331661363481544, 0.10878690824029036, 0.03635474218754098, 0.029150304653740022, 0.051361855075811036, 0.06953315911232494, 0.016479700861964375, 0.015789080498507246, 0.06197742040967569, 0.0060580916488106595, 0.04030273776152171, 0.054465483262902126, 0.04154721551458351, 0.034443659969838336, 0.009857008772087283, 0.011400940329622244, 0.07875996205257252, 0.0051767602053587325, 0.009738452536112163, 0.038802345225121826, 0.07586839143186808, 0.036356252458062954, 0.05364157688745763, 0.005646185309160501, 0.012090749896742636, 0.03391106511116959, 0.07308551575988531, 0.07372749576461501, 0.06439290329581127, 0.035421346765360795, 0.0259506314250757, 0.0057304422625747975, 0.015099036227184115, 0.05247488363238517, 0.05129974473675247, 0.05810811846458819, 0.07692105369642377, 0.028154336905572563, 0.03242442828195635, 0.02028734888881445, 0.034266783914063126, 0.03479924889688846, 0.06776791633456014, 0.04594898986397311, 0.02160169242415577, 0.019898960745194927, 0.06185371181345545, 0.04870296259468887, 0.0291855436807964, 0.027545712728169747, 0.0575181221938692, 0.023988400389498565, 0.054877301008673385, 0.15045335720060393, 2.181417583487928, 9.874549135565758, 22.508576698601246, 36.45345412194729, 48.89855392277241, 46.64038449525833, 43.59178528189659, 49.24458995461464, 45.10686658322811, 24.3854308873415, 32.15164415538311, 29.820716232061386, 29.30544488132, 29.218735434114933, 35.73825269937515, 33.17921921610832, 35.035294219851494, 31.132951118052006, 20.250069089233875, 19.90727048367262, 12.835175469517708, 14.041946064680815, 7.500426080077887, 8.157218936830759, 3.9359739096835256, 3.1336999218910933, 2.1100215520709753, 2.3179962672293186, 1.7002374096773565, 1.4640170289203525, 1.3714865315705538, 1.7328868014737964, 1.2468318454921246, 0.7560498837847263, 0.8967264695093036, 1.0566170210950077, 0.7335639966186136, 0.6859551044180989, 0.7434258924331516, 1.206112636718899, 1.3893561414442956, 1.4084349176846445, 2.6853194693103433, 3.4615351678803563, 5.083620389923453, 6.094752307981253, 11.402390152215958, 11.446876265108585, 18.9248389005661, 18.479286208748817, 12.384896781295538, 21.28242999315262, 22.538032718002796, 26.152389273047447, 23.75360269099474, 22.722434923052788, 29.24167100340128, 34.27937038242817, 40.386786460876465, 37.36981675028801, 35.0734593719244, 26.137995645403862, 13.404782004654408, 7.426012773066759, 1.9961725361645222, 0.12291809020098299, 0.09689035519841127, 0.055469186045229435, 0.015978957126208115, 0.05175527498067822, 0.04221258430334274, 0.040451156164635904, 0.062494675075868145, 0.06644208435318433, 0.028356527618598193, 0.04688435197749641, 0.027304535142320674, 0.05561313300859183, 0.019439951684034895, 0.07258269586600363, 0.02499851347238291, 0.07473015211871825, 0.04009654687251896, 0.03163450484862551, 0.03569957050785888, 0.06324431102257222, 0.056669802870601416, 0.021714070280722808, 0.02538132252084324, 0.020329564104031306, 0.02021474272623891, 0.07426417243550532, 0.012897310425614705, 0.017560891283210367, 0.049445908080087975, 0.018514500952733215, 0.08344083587871864, 0.03215344790078234, 0.028352928202366456, 0.08074036086327396, 0.005533550947802723, 0.07735197432339191, 0.005751189928560052, 0.003669427428576455, 0.04560261841106694, 0.06357691192533821, 0.013543634777306579, 0.05369262180465739, 0.021463181692524813, 0.02377798668021569, 0.04148308282310609, 0.016196308060898446, 0.05448889060062356, 0.04898893806966953, 0.049010482616722584, 0.03780129562073853, 0.06545663098222576, 0.15440998395206407, 0.22719645872712135, 0.07436112660798244, 0.12765845458488911, 0.10354828074923716, 0.07058261529891752, 0.2883265691343695, 0.10048792348243296, 0.11899799937964417, 0.3189025487517938, 0.11371570391929708, 0.09156147512840107, 0.14558325055986643, 0.15423636592458934, 0.17376109870383516, 0.08862334216246381, 0.1298091243370436, 0.1537733103032224, 0.11410682316636667, 0.1031303996569477, 0.06666005312581547, 0.19796761072939262, 0.1767236928571947, 0.1930591053678654, 0.1929359236964956, 0.16498585551744327, 0.18950883415527642, 0.15878994658123702, 0.11540089864865877, 0.09336053015431389, 0.1322949182940647, 0.22162374603794888, 0.2895363589050248, 0.09889126697089523, 0.18922441347967833, 0.23054691409925, 0.15800436842255294, 0.3197366336826235, 0.12207501786178909, 0.12913727288832888, 0.1296100951731205, 0.10729485744377598, 0.13159664638806134, 0.12565949466079473, 0.1795872548245825, 0.08705933272722177, 0.17627926514251158, 0.11753759376006201, 0.21624053333653137, 0.1792596559971571, 0.1212245537317358, 0.13816435646731406, 0.2475652954308316, 0.2024863549740985, 0.16751099814428017, 0.14903211471391842, 0.1522471132921055, 0.13125880592269823, 0.3271847387077287, 2.3092952091246843, 9.937885086983442, 25.15370786190033, 39.69774283468723, 54.55329269170761, 53.14204841852188, 51.87186777591705, 55.54905205965042, 56.9810014218092, 33.99585239589214, 44.34268578886986, 36.92207157611847, 39.3693720549345, 37.05954059958458, 42.53817401826382, 40.12729078531265, 41.173576042056084, 31.679783575236797, 22.881281599402428, 23.072679229080677, 13.837013561278582, 16.084789596498013, 8.28228447586298, 9.085618369281292, 5.297838170081377, 4.123761020600796, 2.7274162229150534, 3.49122344981879, 2.668529595248401, 2.244688938371837, 1.942195245064795, 2.512356787919998, 2.387046399526298, 0.9965648059733212, 1.4608446741476655, 1.7371882894076407, 1.5762918605469167, 0.7718794781249017, 1.0066784382797778, 1.6962917963974178, 1.4922263589687645, 1.8404912087135017, 3.3803078765049577, 4.65931948274374, 6.806766651570797, 8.818320762366056, 13.92930205911398, 12.496501542627811, 23.557979688048363, 27.174169644713402, 17.669561058282852, 35.48315718770027, 28.920987211167812, 31.525669544935226, 34.09181244671345, 29.923409521579742, 39.847352206707, 43.67539219558239, 46.53159633278847, 45.129961743950844, 39.75423060357571, 30.029716417193413, 16.36268388479948, 7.884855251759291, 2.326767146587372, 0.39497639634646475, 0.17691714107058942, 0.21519756352063268, 0.09905259503284469, 0.15350523171946406, 0.11523660941747949, 0.19430512678809464, 0.18310173967620358, 0.16022389463614672, 0.0912754365708679, 0.12882827228168026, 0.14568778948159888, 0.18805066240020096, 0.09526185313006863, 0.11855978344101459, 0.14307312900200486, 0.18465658358763903, 0.1847690634895116, 0.12317511078435928, 0.12472695641918108, 0.0969896545575466, 0.06449097068980336, 0.07436927538947202, 0.36273738252930343, 0.11396977075492032, 0.14289256447227672, 0.1566123665543273, 0.07613304871483706, 0.12668180308537558, 0.2801533561432734, 0.12223351834109053, 0.14532474568113685, 0.12050022502080537, 0.09742829352035187, 0.12372910918202251, 0.19657333788927644, 0.2137690776726231, 0.14340423076646402, 0.08316210747580044, 0.1683517624041997, 0.1408936342340894, 0.1767287394613959, 0.14850269624730572, 0.10438766461447813, 0.11571948780328967, 0.1075161733024288, 0.12682799133472145, 0.1407920045312494, 0.13960410811705515, 0.15402424527565017, 0.08509197345119901, 0.2204757771687582], [0.0427525449777022, 0.0655221997294575, 0.08816315865260549, 0.03976817250077147, 0.034117723553208634, 0.04824792216822971, 0.012413327167450916, 0.042553204111754894, 0.03833442853647284, 0.037977399842930026, 0.020923109696013853, 0.05242399827693589, 0.09410755374119617, 0.02003105189942289, 0.06127259162894916, 0.0036466701658355305, 0.01230214231327409, 0.03292894769401755, 0.03933508480258752, 0.03710752112965565, 0.07115730477380566, 0.019947549153584987, 0.0221271645204979, 0.04478552866203245, 0.06342528373352252, 0.08594707600423135, 0.05603883633739315, 0.02729742907831678, 0.03783393156481907, 0.04357787998742424, 0.04593623605614994, 0.06721505342284217, 0.048694212673581205, 0.0198742008433328, 0.0340600994968554, 0.025081411367864348, 0.017223123177245725, 0.03495104036119301, 0.043425854746601544, 0.04427598119946197, 0.03405251474760007, 0.03095472726272419, 0.04160749274888076, 0.041989862074842677, 0.01308580016484484, 0.03826340129307937, 0.10867585326195695, 0.0737960850528907, 0.06105442618718371, 0.04285011142201256, 0.014071361147216521, 0.0080122207509703, 0.03913677552191075, 0.0346966358483769, 0.05220304235990625, 0.006358732889566454, 0.07661464318516664, 0.022363709249475505, 0.03382119844900444, 0.06401073434972204, 0.5688201554585248, 4.902382465079427, 7.487110644578934, 21.078082658350468, 38.447001948952675, 41.822452023625374, 49.3717235326767, 42.26240001618862, 35.48306979238987, 31.565489508211613, 25.10573923587799, 22.95100785791874, 23.868746012449265, 23.40192586183548, 34.2782798409462, 23.167311251163483, 27.086686939001083, 26.23313494026661, 17.001275718212128, 21.210592947900295, 12.372875176370144, 17.64341276139021, 13.51935250684619, 12.807875834405422, 9.421551693230867, 8.163822032511234, 8.19307191297412, 6.685866164043546, 6.077813766896725, 6.9549905229359865, 5.793952373787761, 4.402384869754314, 5.4216312523931265, 5.248389048501849, 4.238054137676954, 3.6519158771261573, 4.401049241423607, 3.3960587438195944, 4.73272061906755, 5.054010953754187, 6.640070546418428, 6.458584209904075, 11.873473674058914, 11.881799027323723, 16.593489199876785, 16.49632841348648, 16.571784764528275, 14.175463300198317, 23.86416155844927, 29.540150687098503, 22.604437954723835, 27.001501210033894, 14.403851944953203, 22.49539140611887, 32.002783343195915, 35.09786166250706, 39.79029066860676, 33.67506980895996, 27.54315074533224, 12.10341738536954, 6.524937674403191, 3.530190121382475, 0.8356644585728645, 0.07834449294023216, 0.030799078485870268, 0.08430231348029338, 0.013513684480130905, 0.019430047723290045, 0.06690215654089116, 0.05860793637111783, 0.01868376257334603, 0.07177040039096028, 0.053755281332996674, 0.022558704840776045, 0.025722294849401806, 0.033000156763591804, 0.026906807070190553, 0.03942239476600662, 0.02660771042428678, 0.03243642880988773, 0.032477232089149766, 0.03598056246119086, 0.014668415242340416, 0.04001070265076123, 0.04283213660528418, 0.03925079166947398, 0.022108876146376133, 0.07236474193632603, 0.034650808229343966, 0.04744708916405216, 0.058806965535040945, 0.053033045478514396, 0.057733051871764474, 0.030720106551598292, 0.004622472370101605, 0.04146534178289585, 0.04162406861723866, 0.03845887928036973, 0.015761127506266348, 0.11131850013043731, 0.033460759586887434, 0.005702714233848383, 0.02642421626660507, 0.05008120133425109, 0.07744153670500964, 0.04870086231676396, 0.012094015346519882, 0.0540326998452656, 0.04251817474141717, 0.03348601487232372, 0.03360663242347073, 0.06608071038499475, 0.11421323230024427, 0.06735956441843882, 0.023800889357517008, 0.07679889618884772, 0.01736314603476785, 0.02916864126746077, 0.022850415261927992, 0.03110788056801539, 0.030829771858407184, 0.03856776347674895, 0.046363831861526705, 0.0749760479084216, 0.041622755015851, 0.055922753308550455, 0.0503870626562275, 0.007672196052226354, 0.03935583896236494, 0.032087296567624435, 0.06447153384215198, 0.07277412543771788, 0.06915306075825356, 0.03808860696153715, 0.0119624149374431, 0.017635094918659888, 0.03723392372194212, 0.03971404395997524, 0.030982973403297365, 0.03264236365794204, 0.06507598343887366, 0.0634631555294618, 0.038384638537536375, 0.013009431313548703, 0.0270058151363628, 0.03401952257263474, 0.00936918861043523, 0.04831930564250797, 0.06482262906502001, 0.032391313652624376, 0.054485061118612066, 0.04173422930762172, 0.022817243116151076, 0.02334491382498527, 0.07372839376330376, 0.03161940214340575, 0.02673573646461591, 0.025674405915196985, 0.018004543453571387, 0.06728198030032218, 0.008219425599236274, 0.028558263766171876, 0.03867864033963997, 0.06226781537407078, 0.016120531072374433, 0.02304702687979443, 0.06788642247556709, 0.029481360033969395, 0.04412478345329873, 0.013580418399214977, 0.0473687777412124, 0.004707932530436665, 0.07857660704758018, 0.029323347516765352, 0.06427092390367761, 0.024738997417443898, 1.0787286283448339, 6.690653432160616, 11.294127311557531, 26.365994811058044, 44.982161074876785, 46.64169542491436, 55.43047182261944, 48.26414756476879, 39.80076290667057, 36.11198544502258, 28.30411311239004, 26.341830007731915, 24.988460429012775, 25.86766865104437, 35.41439227759838, 31.092211604118347, 28.075226694345474, 29.443962648510933, 22.279764376580715, 22.772803120315075, 18.08945182710886, 17.720510624349117, 17.5928108766675, 14.350406862795353, 13.641921579837799, 11.464532017707825, 9.265885446220636, 9.287757072597742, 7.2557994816452265, 7.551194680854678, 6.296123452484608, 5.976316463202238, 5.709566501900554, 4.5664149429649115, 4.491657754406333, 4.267278369516134, 4.236924648284912, 4.024544544517994, 5.502452915534377, 6.1906814854592085, 7.479873932898045, 7.224441664293408, 11.565189566463232, 13.745771907269955, 19.19121790677309, 19.47565734386444, 21.677314303815365, 20.046255625784397, 28.467175662517548, 26.996141597628593, 25.741954296827316, 28.790722601115704, 16.759682781994343, 25.793988704681396, 33.26037526130676, 39.16209697723389, 42.75542356073856, 38.62885259091854, 33.288691341876984, 18.60523235052824, 8.46534725278616, 5.170261915773153, 1.2023763684555888, 0.29519431467633694, 0.07543269137386233, 0.030226173876144458, 0.008421737838943955, 0.04000447232101578, 0.03872830857289955, 0.0444866472389549, 0.017935282521648332, 0.00906850005776505, 0.024617383533040993, 0.03745930654986296, 0.05261356876872014, 0.019114547758363187, 0.03241656522732228, 0.029897639942646492, 0.054717973034712486, 0.02347070971154608, 0.027527682250365615, 0.01795355048670899, 0.002271518296765862, 0.0347010627592681, 0.03927074059902225, 0.023207408703456167, 0.021068244095658883, 0.09074550602235831, 0.08857352178893052, 0.014795830866205506, 0.011683568718581228, 0.008872808703017654, 0.03535822710546199, 0.05855993425939232, 0.028600185833056457, 0.034382596059003845, 0.06488861341495067, 0.012058221564075211, 0.05429846663901117, 0.008701825299795019, 0.04082618936081417, 0.046012410093680955, 0.038680633006151766, 0.04150916931394022, 0.013702374599233735, 0.04158102034125477, 0.020500491846178193, 0.06354058379656635, 0.036499735579127446, 0.06399935722583905, 0.03819667108473368, 0.0014393942592505482, 0.13301643426530063, 0.09746111129061319, 0.005094095158710843, 0.026147599273826927, 0.12259963463293388, 0.1760675452533178, 0.24223903514211997, 0.10771342131192796, 0.12738841673126444, 0.08792069158516824, 0.13116082758642733, 0.2185650437604636, 0.12716275930870324, 0.18131127872038633, 0.1154444701387547, 0.0886451241967734, 0.19299274252261966, 0.08639088773634285, 0.14896760723786429, 0.10681458399631083, 0.15579978906316683, 0.08722271653823555, 0.08671859788591973, 0.08452252353890799, 0.1512998211546801, 0.16575448302319273, 0.11295058677205816, 0.14014692977070808, 0.16328402183717117, 0.13595413678558543, 0.22382307099178433, 0.16023413627408445, 0.1313576748361811, 0.11754904509871267, 0.09886028230539523, 0.09340119242551737, 0.20103686634683982, 0.11156833672430366, 0.16000239324057475, 0.1660405215807259, 0.12216662857099436, 0.17926373780937865, 0.18945759627968073, 0.11167915421538055, 0.08720538738998584, 0.12938756961375475, 0.14651740668341517, 0.11188040240085684, 0.13791300589218736, 0.1185890834312886, 0.16776503529399633, 0.15435129491379485, 0.13578379905084148, 0.14295100118033588, 0.10851192026166245, 0.0777281986665912, 0.1181254860421177, 0.0878961784474086, 0.13223665970144793, 0.12898459826828912, 0.16145292087458074, 0.1053271938872058, 0.10395505189080723, 0.2346517180558294, 1.2352185999043286, 7.6935203187167645, 14.108690433204174, 30.29645450413227, 49.75772961974144, 54.08209137618542, 61.944412887096405, 58.79848189651966, 49.31513696908951, 44.625922590494156, 40.81151247024536, 34.65305373072624, 35.379958525300026, 34.464994221925735, 47.27245397865772, 35.563234090805054, 38.79998400807381, 38.55544053018093, 26.4099907502532, 34.185690209269524, 20.692327357828617, 25.27428489178419, 20.872378796339035, 17.085319608449936, 15.407344847917557, 12.42736330255866, 10.677696838974953, 10.190210547298193, 9.084892608225346, 10.069739911705256, 7.97276733443141, 6.240642629563808, 7.847727918997407, 7.462534988299012, 5.409709392115474, 4.4684129767119884, 6.81736190803349, 4.933868525549769, 6.8267331551760435, 7.754062945023179, 9.388549514114857, 9.388885796070099, 15.642815362662077, 17.945737838745117, 22.218982838094234, 24.33426283299923, 24.70909371972084, 24.66022454202175, 34.84274335205555, 40.05240060389042, 32.95112885534763, 40.585310608148575, 22.617950029671192, 34.614922776818275, 43.225028961896896, 44.87870782613754, 52.99776256084442, 44.10011060535908, 37.5203874707222, 21.92288752645254, 11.760771721601486, 6.377291372045875, 1.2823008047416806, 0.2956425125012174, 0.20003795041702688, 0.19497023953590542, 0.09309965782449581, 0.11184759947354905, 0.1573862336226739, 0.09921056116581894, 0.09278471261495724, 0.1242403598735109, 0.10235820984235033, 0.13239395048003644, 0.20767466485267505, 0.1195757465029601, 0.15742984222015366, 0.10699500751798041, 0.10238981791189872, 0.1659758953610435, 0.17507726792246103, 0.16201971389818937, 0.10695610413677059, 0.15254593163263053, 0.17939055600436404, 0.10555307395406999, 0.20338644651928917, 0.1821865380043164, 0.18567071354482323, 0.11080667798523791, 0.08870134188327938, 0.1680671190842986, 0.14892828825395554, 0.21223989722784609, 0.1053631360991858, 0.10487664345419034, 0.13850768882548437, 0.08804699769825675, 0.14495089621050283, 0.18988850206369534, 0.147550298133865, 0.14000068214954808, 0.0883252956555225, 0.07303217018488795, 0.14899788686307147, 0.21864860958885401, 0.096482478256803, 0.1223806565394625, 0.12812137661967427, 0.19377802382223308, 0.14185306790750474, 0.25748979882337153, 0.32669518841430545, 0.16684858681401238, 0.12040648434776813, 0.20485113433096558], [0.0298852442210773, 0.07994529805728234, 0.03629244260082487, 0.05666767661750782, 0.0651513782213442, 0.012859913604188478, 0.03889201150741428, 0.01534165636257967, 0.008092542466329178, 0.09354052323033102, 0.01496862510975916, 0.020488201880652923, 0.0674731946492102, 0.050964564870810136, 0.030035419658815954, 0.0076386055206967285, 0.022188907496456522, 0.028821800406149123, 0.06733547430485487, 0.07298968223039992, 0.0728503885329701, 0.01789603404176887, 0.03714105136168655, 0.020172525655652862, 0.09717939945403486, 0.013489416251104558, 0.04548049430013634, 0.025669116257631686, 0.05835455231135711, 0.01885424688225612, 0.03846035244350787, 0.054774272357462905, 0.05132766433234792, 0.007262728595378576, 0.033151450988953, 0.042495572633924894, 0.018973691840074025, 0.08839896865538321, 0.053614269563695416, 0.015388091615022859, 0.062138136199791916, 0.0930356104800012, 0.0409179188136477, 0.002719817471188435, 0.03194730154064018, 0.021821742921019904, 0.025506641577521805, 0.023825923854019493, 0.021747572682215832, 0.05051625943451654, 0.07941700023366138, 0.07944037788547575, 0.034121731150662526, 0.050052665756084025, 0.016598357287875842, 0.06220197945367545, 0.0661355625197757, 0.04213543805235531, 0.008999367146316217, 0.02786322576866951, 0.001826858081130922, 0.0584633994003525, 2.613771208561957, 7.042030552402139, 14.158531408756971, 31.549325175583363, 37.86232352256775, 45.679503455758095, 39.90803875029087, 41.73246905207634, 40.86627513170242, 40.08146524429321, 30.235889554023743, 24.89284235984087, 25.608547255396843, 24.325775988399982, 29.214595556259155, 26.53246007859707, 35.77049016952515, 25.145866982638836, 17.90957897901535, 17.630552351474762, 19.648354277014732, 15.50530169159174, 16.237267814576626, 16.872304938733578, 17.362102456390858, 14.451368395239115, 15.382929258048534, 13.178823329508305, 16.227424442768097, 11.024647671729326, 8.300641290843487, 12.570139691233635, 16.998648159205914, 17.53596782684326, 11.506572011858225, 11.004171520471573, 13.168051857501268, 15.22752994671464, 14.565980695188046, 13.710128869861364, 14.961481522768736, 21.77389182150364, 25.259256698191166, 26.583704128861427, 18.63912083208561, 27.65787798911333, 16.297241896390915, 17.962593734264374, 21.29597246646881, 20.8848687261343, 27.89308536797762, 31.88932903110981, 40.10182835161686, 37.361700385808945, 30.462568290531635, 20.838900692760944, 13.294489122927189, 4.204291524365544, 2.8200870752334595, 0.4441103426506743, 0.0337074717390351, 0.012901259578939062, 0.028474371392803732, 0.027103322208859026, 0.06918937404407188, 0.033362848043907434, 0.06686271139187738, 0.04388781941088382, 0.021719486103393137, 0.03567861967894714, 0.024831003320286982, 0.023177017756097484, 0.018258970230817795, 0.0039048582402756438, 0.0231103747501038, 0.052896794586558826, 0.029947734910820145, 0.03868268875521608, 0.043972825005766936, 0.027383594278944656, 0.01133225920057157, 0.05514597702131141, 0.05037092465499882, 0.05383066869399045, 0.023746044644212816, 0.026662902091629803, 0.052805974264629185, 0.06192494685819838, 0.0578503668657504, 0.020229359324730467, 0.020522312843240798, 0.03873669484164566, 0.04795545661181677, 0.019824289556709118, 0.005113792685733642, 0.11217818915611133, 0.032950547902146354, 0.014084738359088078, 0.020080506765225437, 0.03616389149101451, 0.042922025531879626, 0.036669368273578584, 0.04532631312031299, 0.038525846975971945, 0.03027497194125317, 0.0424842400389025, 0.07624293852131814, 0.0341506860422669, 0.03564131191524211, 0.07649391060112976, 0.024547554858145304, 0.08625353846582584, 0.03435404192714486, 0.03274952978244983, 0.0232437201339053, 0.03471340096439235, 0.05499348793819081, 0.05614469999272842, 0.06644127541221678, 0.032966162689263, 0.015205093768599909, 0.08809581617242657, 0.02155653459340101, 0.006959935126360506, 0.0776724707975518, 0.06994583774940111, 0.04026855815027375, 0.03506860026391223, 0.01347727657048381, 0.011402467298466945, 0.027782799224951304, 0.02220697879238287, 0.04830124547879677, 0.018049717982648872, 0.01850624455983052, 0.010269261601933977, 0.028517076425487176, 0.019214674612157978, 0.10168856257223524, 0.005332381151674781, 0.0673132024530787, 0.028870427777292207, 0.10613230537273921, 0.031186143751256168, 0.06628035553148948, 0.05387064447859302, 0.022505160741275176, 0.060366292018443346, 0.04627793197869323, 0.020762672211276367, 0.05352260690415278, 0.02734189671173226, 0.04624099899956491, 0.05918748691328801, 0.0534674727532547, 0.05996867155772634, 0.05106309239636175, 0.03815975294855889, 0.039242067723535, 0.009813849173951894, 0.02146029844880104, 0.04062281492224429, 0.022557326301466674, 0.07032993627944961, 0.09855606855126098, 0.027923378693230916, 0.05185696776607074, 0.07292546419193968, 0.03183745255228132, 0.07466727736755274, 0.05541591839573812, 0.0541590950160753, 0.03205315035302192, 0.06875767416204326, 0.0180896381061757, 0.3020475141238421, 3.716513835825026, 9.326479844748974, 20.045381672680378, 37.61410564184189, 43.53643745183945, 52.729686945676804, 43.920133262872696, 46.36156685650349, 43.4200306981802, 42.225272208452225, 33.2871600240469, 27.476840503513813, 31.330538615584373, 24.39404122531414, 29.78255867958069, 30.004702359437943, 32.65634827315807, 28.185502476990223, 25.228297859430313, 28.101870864629745, 27.13137824088335, 23.73795323073864, 24.417719654738903, 24.35838583856821, 22.694607116281986, 17.60829884558916, 19.24102943390608, 17.263305857777596, 18.803845793008804, 14.717852845788002, 11.807841695845127, 15.516773276031017, 19.37913492321968, 19.416355825960636, 12.401158008724451, 13.459481969475746, 16.755026131868362, 16.41962192952633, 18.706525415182114, 17.298277281224728, 17.52992995083332, 25.928946062922478, 31.526260413229465, 30.736822374165058, 20.22581499069929, 30.820151902735233, 20.53666491061449, 21.875735856592655, 23.095743991434574, 23.67864791303873, 29.56198051571846, 34.401108250021935, 44.78285796940327, 41.0596239566803, 35.953955724835396, 25.56016255170107, 17.33951646834612, 6.092983027920127, 4.232788570225239, 0.7117784000001848, 0.06287364536547102, 0.020852605666732416, 0.04083776686456986, 0.070752967876615, 0.04076429053384345, 0.07337461938732304, 0.026241102459607646, 0.006568527833223925, 0.02831118239555508, 0.003287191457275185, 0.05051053376519121, 0.08547210891265422, 0.03713262056407984, 0.051202742324676365, 0.0422041386627825, 0.0039022843793645734, 0.0074772398875211366, 0.05103496128867846, 0.026137821478187107, 0.04547732532955706, 0.04415564937517047, 0.05773450277047232, 0.06474143810919486, 0.035934656916651875, 0.04309842661314178, 0.018872177170123905, 0.07548631154350005, 0.02475562709150836, 0.08051891883951612, 0.023828497251088265, 0.018752567084447946, 0.005698695040337043, 0.04419347293151077, 0.02612058880913537, 0.04501747578615323, 0.04501028437516652, 0.07758715350064449, 0.025976263350457884, 0.03011799657542724, 0.05208718197536655, 0.0408974466699874, 0.02129454347596038, 0.06470475374953821, 0.09991316721425392, 0.027949498580710497, 0.022700822410115507, 0.02939547128335107, 0.05728975222154986, 0.05177574712433852, 0.021014642479713075, 0.08488094375934452, 0.08231021842220798, 0.06556831678608432, 0.01918115736771142, 0.18038108566543087, 0.17122436373028904, 0.1600043525104411, 0.15696782560553402, 0.16991764947306365, 0.1006118547229562, 0.19085991400061175, 0.2160809122142382, 0.07720139998127706, 0.23107680754037574, 0.19253618811490014, 0.13687880826182663, 0.2571560995420441, 0.12762575555825606, 0.12095913945813663, 0.1242425269447267, 0.09832182448008098, 0.10052999583422206, 0.1565962767926976, 0.14323951851110905, 0.1823802533908747, 0.13242703542346135, 0.1042783611046616, 0.11274417323875241, 0.260814264183864, 0.08559622569009662, 0.08029139120480977, 0.14118489751126617, 0.2036730936379172, 0.11557154808542691, 0.08781473516137339, 0.16573696833802387, 0.10014653555117548, 0.16470584319904447, 0.1696173765230924, 0.1498629045090638, 0.0921727302193176, 0.12265981538803317, 0.08939462655689567, 0.15137636626604944, 0.14096563740167767, 0.19827888230793178, 0.12028143988572992, 0.11597802236792631, 0.12096164049580693, 0.08298678250866942, 0.07285360203240998, 0.10970354225719348, 0.15547751885605976, 0.14613831765018404, 0.25334588368423283, 0.12340654953732155, 0.149396984197665, 0.3663708484964445, 0.09998408684623428, 0.13191821897635236, 0.177160550665576, 0.11887114407727495, 0.08712722439668141, 0.281740038190037, 0.07038536728941835, 0.31185867672320455, 3.5795941203832626, 10.499804634600878, 22.23786972463131, 41.406891122460365, 49.308472126722336, 59.00264874100685, 52.77400016784668, 55.59241533279419, 56.56382940709591, 54.55201596021652, 42.012377232313156, 39.18807238340378, 38.957534953951836, 35.507221296429634, 42.17886529862881, 43.365773409605026, 47.03871712088585, 38.06939721107483, 31.375562399625778, 29.61324166506529, 32.248041182756424, 25.158212520182133, 27.484877072274685, 25.249645113945007, 28.036945648491383, 21.980171352624893, 24.327366203069687, 19.762940928339958, 22.945287264883518, 18.60374853014946, 13.309966642409563, 17.644689492881298, 24.54891711473465, 21.999922692775726, 14.219273049384356, 14.986891709268093, 18.558517657220364, 21.12547181546688, 20.414165183901787, 21.20859805494547, 21.958056539297104, 33.20499323308468, 38.46729286015034, 36.688566505908966, 27.859430573880672, 40.72623744606972, 25.516681484878063, 27.67767872661352, 31.60278830677271, 32.38117463886738, 39.02240127325058, 42.38047108054161, 51.95065274834633, 47.49492064118385, 41.18021808564663, 28.195072263479233, 19.83812939375639, 7.759119523689151, 3.8345020171254873, 0.7053673127666116, 0.14908783516148105, 0.13468637043843046, 0.13174526888178661, 0.13077701849397272, 0.10813646033057012, 0.35975602688267827, 0.17285024601733312, 0.1665332927950658, 0.16176003642613068, 0.12566712393891066, 0.1427348135621287, 0.1317156126606278, 0.07823063264368102, 0.10961283696815372, 0.13139464863343164, 0.20172385760815814, 0.11900575482286513, 0.16927155054872856, 0.1947656145785004, 0.18198421370470896, 0.15663897997001186, 0.134299028723035, 0.1079947546531912, 0.10208919615251943, 0.1626121555455029, 0.15932231879560277, 0.18334139400394633, 0.13056157302344218, 0.27984370244666934, 0.07732744634267874, 0.10717980228946544, 0.14479986915830523, 0.09800917250686325, 0.13600319274701178, 0.11810460942797363, 0.1472964242566377, 0.1692014472791925, 0.15049162233481184, 0.101895992847858, 0.13164424774004146, 0.1340926522971131, 0.09910502776619978, 0.1627437531715259, 0.191946848644875, 0.08782845747191459, 0.11166690135723911, 0.2005289404769428, 0.11367398779839277, 0.12726429995382205, 0.09598886841558851, 0.16117396240588278, 0.18547646381193772, 0.160808335931506, 0.11716690583853051], [0.03482262654870283, 0.02544310445955489, 0.029502186553145293, 0.031334213344962336, 0.0328707076550927, 0.07650692787137814, 0.0064359570660599275, 0.03526790031173732, 0.08271415455965325, 0.042017310406663455, 0.04733886176836677, 0.08413515955908224, 0.014764617062610341, 0.048174074763664976, 0.013310478880157461, 0.029949992895126343, 0.022857246731291525, 0.01277075476536993, 0.033705204477882944, 0.011651441145659192, 0.04268759963451885, 0.018480245271348394, 0.038060769002186134, 0.0707877820241265, 0.03529514084220864, 0.05547247747017536, 0.03562752281141002, 0.05469497758895159, 0.04679945770476479, 0.04597602630383335, 0.012910608784295619, 0.030182617229002062, 0.04657371864595916, 0.025568612763890997, 0.09424240197404288, 0.022268228240136523, 0.06229534905287437, 0.03823976017883979, 0.05025749109336175, 0.08220605799579062, 0.010716977030824637, 0.057671004615258425, 0.015626681888534222, 0.02891824064136017, 0.05372008126869332, 0.03575884584279265, 0.0946096982806921, 0.02552938098233426, 0.05652032319630962, 0.07240415739943273, 0.04849331329751294, 0.039273950387723744, 0.013316311233211309, 0.021806764525535982, 0.040578757325420156, 0.07653556735021994, 0.07171928125899285, 0.05444952708785422, 0.05469303316203877, 0.023520203540101647, 0.026879625911533367, 0.022403469811251853, 0.07821411243639886, 0.9397658100351691, 4.335051057860255, 11.774719823151827, 21.29612635821104, 28.159842453897, 39.054836332798004, 38.53859223425388, 46.194417625665665, 46.735554188489914, 38.02835941314697, 30.329377837479115, 24.60008516907692, 24.920691065490246, 22.108175083994865, 25.06565898656845, 30.625925324857235, 17.29120396077633, 22.573292925953865, 18.527186438441277, 20.592024140059948, 23.042020574212074, 15.716889537870884, 19.05951127409935, 20.874573178589344, 26.965942718088627, 20.931230038404465, 18.928805887699127, 17.8338585421443, 21.184205263853073, 25.697595477104187, 12.969879191368818, 23.415342941880226, 37.919198870658875, 34.312288016080856, 20.66407397389412, 20.819004960358143, 22.549566999077797, 23.262946419417858, 15.300808064639568, 14.98435439541936, 23.273044377565384, 35.795614421367645, 24.51427437365055, 23.281664215028286, 19.233169555664062, 24.20666377991438, 25.396872013807297, 26.35725148022175, 32.0467583835125, 31.49022314697504, 43.128616735339165, 31.083137691020966, 25.00557091087103, 14.797198288142681, 7.736085634678602, 2.469597444869578, 0.6233795871958137, 0.14965406415285543, 0.007946027672005584, 0.054529641929548234, 0.029769381981168408, 0.07072921915096231, 0.0068110913798591355, 0.0386774157959735, 0.01387101652653655, 0.022397758984880056, 0.026074599772982765, 0.0714719679672271, 0.03704523638589308, 0.019238794411648996, 0.06190809639520012, 0.03069255246373359, 0.0413067336921813, 0.0385813188040629, 0.01861474655015627, 0.031066160736372694, 0.029674889883608557, 0.051170414371881634, 0.17550660035340115, 0.028341794131847564, 0.0512813468958484, 0.053516413681791164, 0.04611506396031473, 0.051711543928831816, 0.027399233185860794, 0.01165828467492247, 0.041310036249342375, 0.022757203369110357, 0.03143576883303467, 0.05009119806345552, 0.08917558909161016, 0.04850481287576258, 0.028104084231017623, 0.03140986416838132, 0.07154603430535644, 0.03596445414586924, 0.059710830901167355, 0.031303547802963294, 0.03186215864843689, 0.043738673703046516, 0.08390167990000919, 0.016779335564933717, 0.01173360617030994, 0.03588495157600846, 0.02963746894238284, 0.037951565682305954, 0.05658665264490992, 0.02037818034295924, 0.019368857647350524, 0.0671792373759672, 0.03867682949930895, 0.025784874596865848, 0.05162257526535541, 0.03574221060262062, 0.03315797075629234, 0.014460804995906074, 0.04861187881033402, 0.06070932009606622, 0.03903357246599626, 0.034826697228709236, 0.03634123881056439, 0.07771389005938545, 0.03191631687514018, 0.06420308418455534, 0.05910156847676262, 0.02972928745293757, 0.0469675912609091, 0.08684226937475614, 0.005377531097110477, 0.04745465164887719, 0.00884815919562243, 0.05784446679172106, 0.006295885041254223, 0.04327602626290172, 0.04862584602960851, 0.036938452467438765, 0.039541531732538715, 0.022422338915930595, 0.042971853326889686, 0.020582285796990618, 0.024901744836824946, 0.026945331956085283, 0.02938532426924212, 0.0822028073889669, 0.054828471402288415, 0.0591167120001046, 0.033401729160686955, 0.031706162917544134, 0.038374022115021944, 0.01974982431420358, 0.02159153242246248, 0.06247526049264707, 0.013100162577757146, 0.10537337031564675, 0.05494097356859129, 0.07548360270448029, 0.03369094782101456, 0.08888978059985675, 0.05754218633228447, 0.046380058920476586, 0.01604992870852584, 0.00964120335993357, 0.06747349892975762, 0.05710151759558357, 0.039092094521038234, 0.022062733114580624, 0.03756209400307853, 0.0055873241853987565, 0.06346983485855162, 0.06594799953745678, 0.052969766256865114, 0.1473145029740408, 0.07597253701533191, 0.019420891476329416, 0.0037735266278104973, 0.07602053170558065, 1.7782699037343264, 5.9286147728562355, 15.499855633825064, 26.997329033911228, 35.725846365094185, 44.09970782697201, 47.40668177604675, 53.0583731085062, 50.66029518842697, 42.75720186531544, 35.6305056810379, 28.4376360476017, 30.695651583373547, 25.015697367489338, 27.782615795731544, 32.617290169000626, 21.810514256358147, 24.981951378285885, 25.273593328893185, 26.404857225716114, 26.776642575860023, 21.10068954527378, 23.787855952978134, 30.167635716497898, 30.759434960782528, 28.823963217437267, 26.401274017989635, 25.30873954296112, 25.62289148569107, 31.88665397465229, 19.516261965036392, 28.60101778060198, 43.560224175453186, 34.151245057582855, 21.7832051217556, 27.317756339907646, 29.785900600254536, 29.775447361171246, 18.579619824886322, 22.20361076295376, 31.658257730305195, 42.09890618920326, 27.856584526598454, 23.489528261125088, 23.742083609104156, 24.944297298789024, 25.46819608658552, 27.595361843705177, 33.33892084658146, 34.208424389362335, 47.05572500824928, 36.415171176195145, 30.89980322867632, 19.54683132469654, 11.195717342197895, 3.980866363272071, 1.5189832169562578, 0.2658575732493773, 0.039686551099293865, 0.06226667246664874, 0.035468283895170316, 0.02169459818105679, 0.04267372147296555, 0.054828586435178295, 0.07896930706920102, 0.040509132741135545, 0.024032268738665152, 0.013581790444732178, 0.06147283420432359, 0.0854606056236662, 0.03841551559162326, 0.0334601918439148, 0.03389721292478498, 0.05661870600306429, 0.01458450988138793, 0.02468657767167315, 0.021440909840748645, 0.039671344493399374, 0.05050266699981876, 0.02742301716352813, 0.05783649241493549, 0.09398722191690467, 0.09443830669624731, 0.021606805821647868, 0.031145284810918383, 0.04173754670773633, 0.042341970329289325, 0.037975114028085954, 0.03660091999336146, 0.08673540010931902, 0.028963233344256878, 0.011843413412861992, 0.025123830673692282, 0.06496369649539702, 0.016680219887348358, 0.07811585208401084, 0.04122950209421106, 0.05262810744170565, 0.04809882469999138, 0.13487699849065393, 0.027779941956396215, 0.01832314930652501, 0.03409656863368582, 0.007626552578585688, 0.009985181386582553, 0.02835863531799987, 0.048574025568086654, 0.06483336794190109, 0.020532120324787684, 0.03105861680523958, 0.038750636085751466, 0.04532455794105772, 0.014109961175563512, 0.14769090543268248, 0.18453683063853532, 0.09770674732862972, 0.16015831846743822, 0.14298117690486833, 0.2283910196274519, 0.09760174827533774, 0.11975853005424142, 0.24099022324662656, 0.13398441747995093, 0.19338159821927547, 0.18297984934179112, 0.15017474011983722, 0.12314993713516742, 0.2365737469517626, 0.11608114378759637, 0.16456891695270315, 0.1403939610463567, 0.15253763442160562, 0.13060337078059092, 0.1375953370006755, 0.12022697366774082, 0.10500481235794723, 0.10913919089944102, 0.20489211572567, 0.15296999481506646, 0.0784830964403227, 0.14028657227754593, 0.17770448554074392, 0.07477709295926616, 0.20963771967217326, 0.13891443028114736, 0.14065518218558282, 0.07044180019875057, 0.15225294657284394, 0.10162616279558279, 0.12491979607148096, 0.09181048051686957, 0.20147933479165658, 0.1887413940858096, 0.254081025486812, 0.11545058543561026, 0.19747304351767525, 0.10417768877232447, 0.18456617515766993, 0.15036021766718477, 0.2472339413361624, 0.06306852592388168, 0.12563050637254491, 0.18053972715279087, 0.21144547266885638, 0.21010769210988656, 0.111657498346176, 0.15688577375840396, 0.08770190645009279, 0.27662969834636897, 0.1857892790576443, 0.17448259983211756, 0.3721524163847789, 0.19955516851041466, 0.21831588994245976, 0.07912811925052665, 0.2502103988081217, 1.9094842253252864, 6.767802117392421, 16.090665981173515, 29.8810987919569, 40.303950905799866, 50.35794161260128, 54.50244382023811, 59.702491387724876, 61.40166141092777, 50.923290476202965, 44.51487734913826, 39.791343212127686, 38.789348378777504, 34.149082973599434, 36.913757622241974, 45.9214972704649, 26.988631300628185, 35.18972933292389, 30.521609522402287, 30.895973034203053, 37.961646392941475, 27.66987394541502, 30.754312835633755, 33.832214176654816, 36.95976175367832, 31.11411362886429, 30.92278629541397, 28.248710185289383, 32.704157307744026, 38.97718369960785, 21.000912599265575, 32.08335041999817, 49.94355484843254, 41.09389431774616, 27.9261701926589, 29.663556665182114, 33.82221311330795, 33.16177815198898, 23.84565845131874, 26.4894387871027, 35.30794478952885, 52.64883488416672, 34.65983636677265, 32.94858679175377, 31.38078711926937, 34.266743659973145, 37.393428683280945, 35.2181252092123, 42.7858105301857, 42.77787275612354, 54.63230185210705, 41.89157411456108, 33.575720340013504, 22.28584785014391, 11.556583028286695, 3.810081440024078, 1.4869227935560048, 0.3595042903907597, 0.09408486628672108, 0.14083371323067695, 0.07171526624006219, 0.08349919095053338, 0.08582031718106009, 0.15073639748152345, 0.14907211647368968, 0.1841876798425801, 0.15033829462481663, 0.15406308928504586, 0.20060809794813395, 0.14135379547951743, 0.143194870906882, 0.19006056158104911, 0.09129451718763448, 0.1246407040162012, 0.09804520377656445, 0.12609896482899785, 0.09684178163297474, 0.12684222572715953, 0.24995809828396887, 0.1967078447341919, 0.28063601930625737, 0.23556310508865863, 0.163753341184929, 0.20669087389251217, 0.18562435900093988, 0.10616293380735442, 0.12692850781604648, 0.10291881335433573, 0.15127110003959388, 0.13942339515779167, 0.1888104435056448, 0.15191841608611867, 0.07448700969689526, 0.4339740303112194, 0.10248636390315369, 0.12368668059934862, 0.15030897979158908, 0.15870553470449522, 0.09640461212256923, 0.3781182150123641, 0.13183371804188937, 0.08959886559750885, 0.10040265071438625, 0.11226801128941588, 0.24283821549033746, 0.1787911678547971, 0.1224240796000231, 0.21998866111971438, 0.09285779189667664, 0.18109810422174633, 0.16665794391883537, 0.1262442031293176, 0.15297232515877113], [0.04833394079469144, 0.03611840897065122, 0.03814532559772488, 0.060889194428455085, 0.08204860394471325, 0.04391447735542897, 0.0013685898920812178, 0.11763888207497075, 0.029196351206337567, 0.022333262641041074, 0.03364469717780594, 0.10350156997446902, 0.10958390805171803, 0.03892440996423829, 0.039110158395487815, 0.022617713002546225, 0.03118919768894557, 0.05033422916312702, 0.03446810631430708, 0.02447878559905803, 0.033925277239177376, 0.10131653878488578, 0.08388954578549601, 0.026435073887114413, 0.03814785261056386, 0.035408025214564987, 0.019889010400220286, 0.028544938504637685, 0.006177048644531169, 0.0878295187430922, 0.07936126494314522, 0.03982479094702285, 0.03315461253805552, 0.03835983596218284, 0.015253211840899894, 0.044631811324507, 0.04480052746657748, 0.039690050325589254, 0.047952718086889945, 0.03252532325859647, 0.038576557926717214, 0.028395826193445828, 0.023481988500861917, 0.08164186248905025, 0.06350999989081174, 0.010368217717768857, 0.04811905193491839, 0.023556006599392276, 0.04229079182550777, 0.047894570816424675, 0.047185415314743295, 0.023804845004633535, 0.013653095065819798, 0.019053400355915073, 0.06608890369534492, 0.03820437086687889, 0.01748665796185378, 0.027238851362199057, 0.04951413371600211, 0.06723877988406457, 0.02577294086222537, 0.042695815209299326, 0.032385057347710244, 0.05991417565383017, 0.2275047023431398, 2.2445084480568767, 5.538645498454571, 13.75706110149622, 19.132577553391457, 25.583069622516632, 34.01856757700443, 46.46205626428127, 47.30568319559097, 40.90205781161785, 40.91293662786484, 35.41746251285076, 33.7094883620739, 36.61251358687878, 29.182783663272858, 20.657701715826988, 33.835086822509766, 24.768222346901894, 23.97702120244503, 28.180349953472614, 24.172684103250504, 26.48136042058468, 22.702947668731213, 24.273787178099155, 20.519117452204227, 24.6377145498991, 21.08866509050131, 21.542170755565166, 26.335442550480366, 27.81836997717619, 15.215632785111666, 48.59463483095169, 59.812613278627396, 27.196075469255447, 20.168375372886658, 18.327974528074265, 18.497378937900066, 35.90768560767174, 26.07247196137905, 33.58401909470558, 34.50883246958256, 32.343260273337364, 26.751715913414955, 20.799834989011288, 24.70136683434248, 34.20416101813316, 33.0283597111702, 35.082107707858086, 35.2279856801033, 26.151082143187523, 20.107538737356663, 8.93757926300168, 3.6362464679405093, 1.5429949597455561, 0.11092777422163635, 0.029066870556562208, 0.08319603846757673, 0.05658455607772339, 0.034164994649472646, 0.019780356269620825, 0.02997874926222721, 0.013206168168835575, 0.01452929966035299, 0.08067575690802187, 0.06543710507685319, 0.01321808056673035, 0.07494098143070005, 0.07491551092243753, 0.04757090537168551, 0.056977308049681596, 0.03663820920337457, 0.036120208678767085, 0.0537238921970129, 0.032110110187204555, 0.029533032065955922, 0.03293504814791959, 0.05658946909534279, 0.025374817596457433, 0.005437104682641802, 0.028736614840454422, 0.026080655698024202, 0.03801484861469362, 0.026247366185998544, 0.020635071050492115, 0.02432326855341671, 0.018514582588977646, 0.03428683674428612, 0.02208942260040203, 0.06223581396625377, 0.04701087702414952, 0.025123891900875606, 0.020491521136136726, 0.0038879966450622305, 0.060300867990008555, 0.06384842665283941, 0.023990658373804763, 0.007528442047259887, 0.027172184236405883, 0.0635785966005642, 0.08573357496061362, 0.030533523204212543, 0.07320912787690759, 0.06452853078371845, 0.028248448652448133, 0.04152400484599639, 0.0304920130292885, 0.033713215962052345, 0.05815935262944549, 0.04053541590110399, 0.02750877418293385, 0.05827952489198651, 0.050064165334333666, 0.04430370041518472, 0.07034120208118111, 0.013323510993359378, 0.07110248232493177, 0.05858414682734292, 0.06118359699030407, 0.031758469485794194, 0.035480436563375406, 0.006978394194447901, 0.017136822534666862, 0.03818129007413518, 0.06512701351311989, 0.035180367704015225, 0.041029077692655846, 0.04905049550870899, 0.05585649065324105, 0.03527290980855469, 0.015730395170976408, 0.04747598839458078, 0.038458278140751645, 0.035866067628376186, 0.03270201006671414, 0.0354112535569584, 0.07876339819631539, 0.011207557981833816, 0.006375366738211596, 0.019822345129796304, 0.0779187970329076, 0.021491876832442358, 0.07955603417940438, 0.020585239544743672, 0.017389586901117582, 0.09506405593128875, 0.049031611561076716, 0.03747338509128895, 0.1087727332196664, 0.05321497555996757, 0.057052127667702734, 0.025402130486327223, 0.02930139107775176, 0.04279125540051609, 0.033526825573062524, 0.05238399280642625, 0.006072102005418856, 0.02257197629660368, 0.021575270111497957, 0.027819798997370526, 0.019401293211558368, 0.06108769666752778, 0.06080086030124221, 0.02910261981014628, 0.022003955018590204, 0.014934430655557662, 0.016591099083598237, 0.0596111604681937, 0.04503877542447299, 0.016977027007669676, 0.03044918554223841, 0.021351239847717807, 0.05073159729363397, 0.06947560556000099, 0.04615334022673778, 0.00937907958359574, 0.05032666296756361, 0.6764640449546278, 3.2202830258756876, 8.60610119998455, 18.311367519199848, 22.994867004454136, 32.297073751688, 42.84001462161541, 53.90733875334263, 52.391018718481064, 45.269695445895195, 44.191313311457634, 37.79305703938007, 35.316338539123535, 37.65008971095085, 34.73658844828606, 24.27281253039837, 31.723032854497433, 24.092578701674938, 22.697745747864246, 33.46963383257389, 24.948929250240326, 24.310331717133522, 25.851320028305054, 30.132388807833195, 24.179295748472214, 26.23139463365078, 24.6562347561121, 30.151613876223564, 30.66284604370594, 30.655979812145233, 20.66622845828533, 63.59682261943817, 63.55771131813526, 28.26180048286915, 24.13114283233881, 26.84634603559971, 21.214810721576214, 32.15822160243988, 26.83663185685873, 35.30930511653423, 43.059414848685265, 35.36127492785454, 27.103734724223614, 23.855344131588936, 26.910659484565258, 37.35498234629631, 37.72492289543152, 40.12932747602463, 39.46816675364971, 32.59533114731312, 24.994105026125908, 11.615477968007326, 5.333829363808036, 2.2573826322332025, 0.3254809754434973, 0.06213754619238898, 0.056758003411232494, 0.0342938574613072, 0.047032822330947965, 0.17988880426855758, 0.026203002453257795, 0.0369419850903796, 0.03916410882084165, 0.05418086962890811, 0.04679985846451018, 0.08436986376182176, 0.0600964471232146, 0.02923347714386182, 0.05879505777556915, 0.035606909659691155, 0.02446129688905785, 0.0042702240352809895, 0.08945851805037819, 0.040775196393951774, 0.04688100489147473, 0.00648992511742108, 0.042590697412379086, 0.03173267614329234, 0.06768318533431739, 0.021071999362902716, 0.03567435975128319, 0.023122885504562873, 0.04350832590716891, 0.07548051537014544, 0.03934087355446536, 0.0348770556593081, 0.008440200617769733, 0.04331024298153352, 0.05414638202637434, 0.04071711220603902, 0.04013658202893566, 0.022341366893670056, 0.05765353445895016, 0.03550289766280912, 0.04164778765698429, 0.06456853254348971, 0.02185248082241742, 0.013476964868459618, 0.02408483505860204, 0.04914236596960109, 0.03530185727868229, 0.04174222965957597, 0.06052140459360089, 0.03080968563153874, 0.010721183152782032, 0.03948024888813961, 0.0391312984720571, 0.010786737984744832, 0.03763544787943829, 0.037564201702480204, 0.01429738129445468, 0.018344534291827586, 0.167439944925718, 0.16658470878610387, 0.07786739588482305, 0.20548347383737564, 0.1703299125074409, 0.12435537049896084, 0.1287570854765363, 0.17507456650491804, 0.08016571591724642, 0.11292830749880522, 0.15667161962483078, 0.2278690820094198, 0.1457590059726499, 0.10971526076900773, 0.12674916040850803, 0.15644698636606336, 0.12106773792766035, 0.16786136606242508, 0.10848040124983527, 0.16173780168173835, 0.11241221058298834, 0.16013425803976133, 0.19273129873909056, 0.1507721541565843, 0.1740352183696814, 0.1353876109351404, 0.07045879538054578, 0.13242451212136075, 0.057086808228632435, 0.21373314288211986, 0.15952832414768636, 0.17029758455464616, 0.1692014472791925, 0.20896870322758332, 0.14968318602768704, 0.13599496975075454, 0.1474460115423426, 0.25272957456763834, 0.17850109201390296, 0.09907900806865655, 0.15384699072455987, 0.12745295389322564, 0.12942320754518732, 0.13793403835734352, 0.14612242084695026, 0.14951559423934668, 0.1100471121026203, 0.06310935888905078, 0.16866249963641167, 0.17009919363772497, 0.19923332874896005, 0.05760764004662633, 0.1249925117008388, 0.11458416513050906, 0.24484044086420909, 0.08621601547929458, 0.1420896645868197, 0.1384974768734537, 0.13804757210891694, 0.15267304668668658, 0.16910568054299802, 0.2641021861927584, 0.10152593575185165, 0.18699878681218252, 0.8095151523593813, 3.3290816377848387, 9.25914365798235, 19.629338197410107, 26.68429233133793, 37.60576508939266, 47.82865673303604, 61.0857767611742, 60.47193109989166, 56.44066281616688, 53.549899533391, 48.157912865281105, 47.4005451053381, 48.05626071989536, 45.71322664618492, 31.676456853747368, 50.11239118874073, 33.608178198337555, 35.43991170823574, 41.77663788199425, 37.35061638057232, 36.817698776721954, 37.48493917286396, 37.13457517325878, 32.17471271753311, 37.606350257992744, 32.089528888463974, 33.29312950372696, 38.73273141682148, 40.867563262581825, 20.711900107562542, 64.48769241571426, 68.78456264734268, 35.6153254956007, 30.258528739213943, 29.987270794808865, 30.49179632216692, 45.794223099946976, 32.777877151966095, 47.36507020890713, 49.405971094965935, 44.496968910098076, 37.55773186683655, 34.46180619299412, 36.02385677397251, 47.26670488715172, 45.36266505718231, 45.851866006851196, 45.677299574017525, 36.52285739779472, 28.9259934425354, 13.300125170499086, 6.100395480170846, 2.2952587623149157, 0.5590037978254259, 0.1696673675905913, 0.14088128489675, 0.15786304866196588, 0.132271614857018, 0.3043298557167873, 0.10154084549867548, 0.13792842772090808, 0.12359121814370155, 0.14218701951904222, 0.1408340546186082, 0.13663798134075478, 0.19141523342113942, 0.14771508460398763, 0.1365148145123385, 0.17664220504229888, 0.10097277598106302, 0.175438248552382, 0.13771946862107143, 0.11463824543170631, 0.13876499142497778, 0.15533590223640203, 0.1824546611169353, 0.08829735379549675, 0.09325657752924599, 0.18835365161066875, 0.08663341417559423, 0.11932505643926561, 0.10856937733478844, 0.18326302320929244, 0.17068728629965335, 0.1405937917297706, 0.18882736447267234, 0.17296539765084162, 0.09836101729888469, 0.1072048200876452, 0.09843779247603379, 0.11306983506074175, 0.27081764303147793, 0.17438871815102175, 0.15525500813964754, 0.14450148126343265, 0.12255605572136119, 0.10947861213935539, 0.13931597670307383, 0.11945778955123387, 0.16403503075707704, 0.160134554898832, 0.14038734108908102, 0.17374640417983755, 0.0776400018366985, 0.19950535555835813, 0.11717210087226704, 0.21051241492386907, 0.2084608218865469, 0.08935120349633507, 0.12314319843426347, 0.08856787404511124], [0.043099176182295196, 0.020723574016301427, 0.04665722881327383, 0.027017975226044655, 0.02967589178297203, 0.011592571208893787, 0.05278089709463529, 0.022703252943756524, 0.09763575348188169, 0.032403592485934496, 0.01242505402842653, 0.048048896715044975, 0.09325973165687174, 0.03386464748473372, 0.07583342143334448, 0.03980772526119836, 0.03198397847882006, 0.009196074315696023, 0.10544547738390975, 0.02324260876775952, 0.02368418292462593, 0.008583286689827219, 0.019379769073566422, 0.03670829762995709, 0.05988828212139197, 0.01431173628589022, 0.03913165470294189, 0.07378940572380088, 0.0816388642124366, 0.04410708694194909, 0.005003822170692729, 0.04080979531863704, 0.0666378258028999, 0.01944151761563262, 0.03898606388247572, 0.018946425334434025, 0.027035719976993278, 0.07836257165763527, 0.02379690959060099, 0.03404939401661977, 0.037994472950231284, 0.042675387594499625, 0.0844824846717529, 0.08288058859761804, 0.014854788933007512, 0.02224916432169266, 0.02744804794929223, 0.05605942722468171, 0.03200714090780821, 0.022776449113734998, 0.04722958794445731, 0.01543244607091765, 0.05598128649580758, 0.048868023659451865, 0.05334879591828212, 0.045508198672905564, 0.07657730573555455, 0.0005518808995930158, 0.032483128452440724, 0.007336788439715747, 0.013440810216707177, 0.07234418444568291, 0.11987765959929675, 0.012083721758244792, 0.015193144263321301, 0.1416397004504688, 0.9230477164965123, 2.548855016939342, 9.030837658792734, 11.491512469947338, 18.512101247906685, 24.688656516373158, 39.00576576590538, 39.17615622282028, 48.74225690960884, 50.69081895053387, 41.65702410042286, 46.042980551719666, 41.25046491622925, 38.594966009259224, 34.771694764494896, 26.772683188319206, 26.988752894103527, 21.80013131350279, 25.995776876807213, 28.86622454971075, 25.580732747912407, 19.933764562010765, 29.662629514932632, 30.51332786679268, 24.22560576349497, 22.61762324720621, 25.88338080793619, 36.9359066337347, 18.76365154981613, 32.51200921833515, 76.93594604730606, 34.27375428378582, 15.644868202507496, 17.760457880795002, 24.88961063325405, 47.39095062017441, 29.222611226141453, 30.439938604831696, 44.669209867715836, 42.7002277225256, 38.42780537903309, 34.79375258088112, 39.28716726601124, 33.53960707783699, 36.133682280778885, 30.00780299305916, 21.19361735880375, 13.985721431672573, 4.96764063835144, 2.251750146970153, 0.2680092374794185, 0.03941498071071692, 0.03422745008720085, 0.029251591113279574, 0.03104814881226048, 0.02416679599264171, 0.022114651910669636, 0.03345360899402294, 0.02196706842369167, 0.017428904029657133, 0.07547923145466484, 0.05678610483300872, 0.05944956894381903, 0.013970019026601221, 0.011092846998508321, 0.024037124239839613, 0.03262694925069809, 0.023968217683432158, 0.033562574826646596, 0.07791121228365228, 0.06348589493427426, 0.07330554770305753, 0.04385867898236029, 0.0908314244588837, 0.09190540862618946, 0.02045721350441454, 0.030341488782141823, 0.0434075830708025, 0.050970323936780915, 0.030597746808780357, 0.00791997272244771, 0.01738717492116848, 0.02088526944135083, 0.02365861408179626, 0.08441444457275793, 0.018333921580051538, 0.04022027402243111, 0.04645360204449389, 0.07198610561317764, 0.050440567792975344, 0.04502495292399544, 0.06081280516809784, 0.040025178241194226, 0.022263215032580774, 0.033505837636766955, 0.040317350649274886, 0.042293200094718486, 0.11838693724712357, 0.044825092554674484, 0.043083717246190645, 0.115403592644725, 0.0379957308905432, 0.019148556675645523, 0.03732920435140841, 0.04180984302365687, 0.06759043913916685, 0.052816943207290024, 0.011449254143371945, 0.03163535460771527, 0.02982173493364826, 0.059884070433327, 0.028405333105183672, 0.03488650319923181, 0.038371187110897154, 0.024725108123675454, 0.050904877643915825, 0.04931832918373402, 0.04445840109838173, 0.03505641419906169, 0.019526604846760165, 0.01951977152202744, 0.08410464244661853, 0.0169215588903171, 0.010623663092701463, 0.05190679927181918, 0.04558806118438952, 0.051812910169246607, 0.03334748558700085, 0.02105499675963074, 0.03787539535551332, 0.024604601894679945, 0.0560313443565974, 0.030555412849935237, 0.03108265867922455, 0.053612262054230087, 0.02672373222594615, 0.02568429317761911, 0.08486169987008907, 0.0637245325197, 0.09875835574348457, 0.029549316641350742, 0.029297576438693795, 0.06211008301761467, 0.01304771778450231, 0.019004197820322588, 0.022644554628641345, 0.056098620043485425, 0.0640905078034848, 0.05746716262365226, 0.08328460637130775, 0.027249061458860524, 0.045020147517789155, 0.045782114248140715, 0.018455743265803903, 0.008983070511021651, 0.037012355533079244, 0.022651632862107363, 0.022762066291761585, 0.04418307544256095, 0.035358653840376064, 0.06081563275074586, 0.06495176276075654, 0.03588415747799445, 0.06317131337709725, 0.01486697963628103, 0.05010977401980199, 0.04707083884568419, 0.0405573241005186, 0.027138277364429086, 0.02004879108426394, 0.08853082603309304, 0.05383054995036218, 0.06227163743460551, 0.012315176281845197, 0.040673062030691653, 0.1754045847337693, 1.0301208053715527, 4.293276099488139, 11.777395829558372, 16.091889515519142, 24.082501642405987, 32.224828228354454, 45.74617847800255, 45.283450707793236, 55.116274282336235, 55.26036635041237, 46.789613887667656, 51.06770172715187, 43.85191172361374, 41.72750271856785, 38.6461416631937, 26.482462361454964, 25.805230401456356, 25.355657525360584, 27.0117112621665, 28.597746156156063, 26.982131749391556, 21.61519903689623, 28.444177396595478, 32.19411447644234, 22.509560845792294, 20.951912328600883, 26.862432472407818, 35.30495434999466, 18.53944458067417, 37.16446816921234, 84.78420451283455, 37.85281263291836, 17.388205155730247, 19.86236449331045, 24.298010878264904, 47.546974048018456, 28.327981531620026, 36.600643023848534, 48.157954663038254, 47.76693284511566, 41.71283170580864, 37.29252889752388, 41.705650091171265, 37.550310865044594, 42.01733976602554, 34.93195116519928, 26.11161556094885, 17.24219039082527, 6.960267489776015, 3.318397323600948, 0.6390126014593989, 0.0812102368217893, 0.020309412939241156, 0.03613796827266924, 0.06443811493227258, 0.03422615132876672, 0.0664033590874169, 0.033175908465636894, 0.015016305314929923, 0.08885377901606262, 0.06712428876198828, 0.009891418449115008, 0.03439195083046798, 0.030895186609996017, 0.003996449004262104, 0.10368283954448998, 0.027345169582986273, 0.06805989207350649, 0.05150251803570427, 0.07457635685568675, 0.04868161471677013, 0.04233577710692771, 0.01760830153216375, 0.036401582838152535, 0.04102101796888746, 0.08777428069151938, 0.05071906984085217, 0.08567044787923805, 0.014587801306333859, 0.00398247343582625, 0.01835132308769971, 0.10345904491259716, 0.04032444929180201, 0.06262649534619413, 0.06037643717718311, 0.031948945397743955, 0.010828683243744308, 0.04335712445026729, 0.02726969130890211, 0.03214884658518713, 0.0567868172947783, 0.042952917428920045, 0.035224421590100974, 0.03333282445964869, 0.04874894977547228, 0.02285486629261868, 0.028416905042831786, 0.03928050726244692, 0.018718621249718126, 0.03126560179225635, 0.08775770111242309, 0.03402642083528917, 0.02808942681440385, 0.07102584815584123, 0.05816831035190262, 0.04451929431525059, 0.016203375162149314, 0.017549553122080397, 0.018565978170954622, 0.04313359699153807, 0.16581671952735633, 0.15454883978236467, 0.118804692174308, 0.0752465458936058, 0.11797966144513339, 0.1371218467829749, 0.17344150022836402, 0.18179063190473244, 0.10914011858403683, 0.1185268691915553, 0.11254279888817109, 0.16374988277675584, 0.1692341166199185, 0.11526924165082164, 0.16567252023378387, 0.1349986661807634, 0.09150779558694921, 0.09140143098193221, 0.13300310529302806, 0.1041992407408543, 0.1471112880972214, 0.11211892124265432, 0.047050826833583415, 0.15468964003957808, 0.3083545819390565, 0.17471527797169983, 0.11324182036332786, 0.13121736439643428, 0.14496386895189062, 0.19696151081006974, 0.13405422389041632, 0.12358969674096443, 0.27235543238930404, 0.10989289381541312, 0.1269594850600697, 0.1684603386092931, 0.14292578300228342, 0.19917567871743813, 0.11392506377887912, 0.2756929595489055, 0.10892716672969982, 0.13706176250707358, 0.22701807611156255, 0.13249387324322015, 0.10028905016952194, 0.15418640454299748, 0.15991548774763942, 0.15062476362800226, 0.12280924682272598, 0.14140071405563504, 0.14852509426418692, 0.22059496608562768, 0.18942151305964217, 0.16119784471811727, 0.0654143730935175, 0.15264301939168945, 0.17094188748160377, 0.13907333894167095, 0.10927284427452832, 0.10161117883399129, 0.21383780054748058, 0.17479961563367397, 0.1602250523865223, 0.08937460341257975, 0.14431806688662618, 0.2666625363053754, 1.3218262838199735, 4.018640136346221, 11.851622946560383, 17.178180925548077, 25.76504945755005, 35.33599868416786, 51.57776355743408, 55.07598504424095, 63.28500375151634, 65.86194947361946, 55.451093316078186, 59.83900286257267, 57.861345782876015, 49.98051926493645, 52.3327412456274, 36.04225538671017, 39.90418195724487, 31.972411572933197, 39.57065865397453, 38.973440900444984, 37.24003091454506, 31.68394435197115, 41.92457154393196, 43.69500294327736, 34.0074797719717, 34.326461255550385, 40.51789842545986, 50.61403647065163, 26.140921488404274, 41.5843416005373, 89.46626767516136, 43.3067511767149, 23.915591798722744, 29.151062965393066, 35.14902211725712, 58.98675039410591, 36.538508757948875, 41.957409381866455, 59.817955791950226, 58.7703862041235, 48.017510399222374, 46.21534310281277, 51.965981125831604, 44.248553439974785, 47.493643909692764, 39.52682040631771, 29.552439227700233, 19.114621616899967, 7.7137551829218864, 3.620008514262736, 0.7968979887664318, 0.1429688127245754, 0.12237818518769927, 0.17018642567563802, 0.3035675216233358, 0.12598491157405078, 0.13741302100243047, 0.10741620601038449, 0.18453135358868167, 0.08235496250563301, 0.21893788391025737, 0.1127952997921966, 0.13740353635512292, 0.1356435034540482, 0.12208261003252119, 0.21398308337666094, 0.2797600772464648, 0.1932712853886187, 0.16971397446468472, 0.20215648517478257, 0.1835050227236934, 0.15299628168577328, 0.11739716457668692, 0.11766079027438536, 0.17679885757388547, 0.21045868343207985, 0.14595885149901733, 0.16181927465368062, 0.13714170665480196, 0.12932447221828625, 0.10350253476644866, 0.2540371200302616, 0.10941674670903012, 0.11236274644033983, 0.1171398397127632, 0.09073950946913101, 0.10319406850612722, 0.20838003169046715, 0.22139663400594145, 0.12110451876651496, 0.16680448839906603, 0.16358096996555105, 0.08524065531673841, 0.14819989999523386, 0.20483787957346067, 0.13059493998298422, 0.1108489952457603, 0.20536403259029612, 0.18667901022126898, 0.1520273188361898, 0.18628114485181868, 0.13346770458156243, 0.19311040261527523, 0.20397467276779935, 0.12178631499409676, 0.20306094054831192, 0.1180897664744407, 0.06349625531584024, 0.1270830081193708, 0.08053304933127947], [0.04551706733764149, 0.053467621182790026, 0.05425845745776314, 0.020534133400360588, 0.009147296659648418, 0.03054428434552392, 0.04050226416438818, 0.04507202364038676, 0.006488634244306013, 0.029686500784009695, 0.023328896422754042, 0.01797535107471049, 0.01577612816618057, 0.10542152085690759, 0.015262843990058172, 0.0331856009142939, 0.009972101961466251, 0.035835346425301395, 0.0797624551341869, 0.0486007057770621, 0.06118648765550461, 0.008486682254442712, 0.044568279772647657, 0.0332308830547845, 0.04135362629313022, 0.06541484064655378, 0.05403295217547566, 0.057401645826757886, 0.01695966817351291, 0.031170031725196168, 0.03267766020144336, 0.04630892406567, 0.03576784809411038, 0.05107765333377756, 0.05591131681285333, 0.08259681359049864, 0.004378163384899381, 0.12302599847316742, 0.021628170397889335, 0.013709124432352837, 0.03486624998913612, 0.08378738173632883, 0.032854105811566114, 0.06475651112850755, 0.011504461581353098, 0.04026404218166135, 0.12109751289244741, 0.021223390067461878, 0.04367601046396885, 0.020890047017019242, 0.027329074255248997, 0.02690276607609121, 0.04632307311112527, 0.05461055457999464, 0.016328729470842518, 0.01849939268140588, 0.012592849907377968, 0.022392949867935386, 0.03388634417206049, 0.008082763743004762, 0.052368656324688345, 0.017452682441216893, 0.021823422030138317, 0.009150549121841323, 0.03947997058276087, 0.009044598264154047, 0.055373066788888536, 0.09145180796622299, 0.522428029216826, 2.7801258070394397, 5.08035684004426, 10.425465423613787, 18.69637805968523, 24.483277536928654, 30.074704103171825, 42.39628583192825, 41.87122240662575, 48.7101524323225, 51.86169192194939, 49.533853232860565, 44.426737278699875, 41.31940081715584, 43.02059233188629, 49.491534903645515, 40.8431001752615, 31.434919014573097, 28.541408479213715, 24.694306813180447, 37.628362476825714, 29.123837426304817, 29.69793912023306, 33.9201794564724, 36.13149359822273, 40.10513037443161, 26.549846045672894, 41.36749863624573, 71.98402896523476, 51.1792029440403, 32.31812462210655, 26.330297626554966, 27.405315041542053, 44.98230166733265, 31.045320220291615, 28.560840636491776, 44.040066227316856, 44.20824520289898, 43.28807517886162, 41.23599149286747, 35.50478182733059, 28.478706143796444, 22.811076566576958, 14.360618814826012, 6.411297647282481, 2.4404442217200994, 0.33632642473094165, 0.041704035029397346, 0.07270893518580124, 0.0893837318290025, 0.04140542077948339, 0.04218469810439274, 0.0227673299741582, 0.03388135322893504, 0.03933433152269572, 0.01645987809752114, 0.004650641049011028, 0.0610186843550764, 0.011972240044997307, 0.053779657173436135, 0.08117915567709133, 0.023727305415377486, 0.027898910084331874, 0.021253283775877208, 0.019848572628689, 0.038525813579326496, 0.0233267145085847, 0.026512862095842138, 0.0636889242741745, 0.03962306036555674, 0.02459074414218776, 0.042899579275399446, 0.028222332475706935, 0.06986459484323859, 0.02954371342639206, 0.054214244009926915, 0.01587209899298614, 0.01663237919274252, 0.07857253265683539, 0.024948082682385575, 0.010558793819654966, 0.06370905131916516, 0.0068348966942721745, 0.040293909914908, 0.03769394395931158, 0.04165028498391621, 0.006077673679101281, 0.05931307314313017, 0.046447605491266586, 0.010469391927472316, 0.018572523913462646, 0.04705107545305509, 0.03818878576566931, 0.03548421780578792, 0.07125854113837704, 0.059781153104268014, 0.05065411336545367, 0.022600372722081374, 0.017519130633445457, 0.018085517331201117, 0.03610288324125577, 0.07607172505231574, 0.010608549255266553, 0.03744412591913715, 0.09260864550014958, 0.005208382654018351, 0.02029709328780882, 0.08812928703264333, 0.07700710571953095, 0.015356882449850673, 0.004134173059355817, 0.03392694336071145, 0.11827869500848465, 0.058602340577635914, 0.11711184590240009, 0.12591265607625246, 0.06362777130561881, 0.029699683182116132, 0.06635181693127379, 0.0089986407692777, 0.009843197403824888, 0.03170337986375671, 0.038591545599047095, 0.02317826270882506, 0.05212489049881697, 0.036708995248773135, 0.041374220891157165, 0.05723262540413998, 0.012603608265635557, 0.05846556647156831, 0.044738476499333046, 0.03550589593942277, 0.053812374753761105, 0.031638479049433954, 0.03773724085476715, 0.04322594984841999, 0.04232415136357304, 0.01771309649484465, 0.02387313372310018, 0.06125961146608461, 0.062016023221076466, 0.04238456589519046, 0.023910081545182038, 0.027218538780289236, 0.033270688145421445, 0.07752145858830772, 0.023428897111443803, 0.025484375291853212, 0.020101285044802353, 0.036523740345728584, 0.055394344162778, 0.03043947453988949, 0.04538457913440652, 0.04264119685103651, 0.04588050447637215, 0.07203783330623992, 0.02951978844066616, 0.008290194946312113, 0.030824320783722214, 0.09149103789241053, 0.03549224784364924, 0.03654312153230421, 0.010696889876271598, 0.08536921755876392, 0.032165548618650064, 0.02588664345239522, 0.004949867570758215, 0.015724701042927336, 0.03813259034359362, 0.03889865372912027, 0.04908241156954318, 0.05044291669037193, 0.0284259982072399, 0.05043129094701726, 0.004544309840639471, 0.19709059997694567, 1.404055415187031, 3.9226354379206896, 8.373978305608034, 14.16939027607441, 25.20865861326456, 30.36877602338791, 38.961110562086105, 50.68369433283806, 50.053380355238914, 53.381059393286705, 59.23252500593662, 54.2842785269022, 48.58732782304287, 43.568978905677795, 44.41306181252003, 49.77953664958477, 43.03113676607609, 35.96260406076908, 31.885434240102768, 27.428546994924545, 37.19422437250614, 34.32644605636597, 31.125114038586617, 31.404159665107727, 37.99719348549843, 41.80392421782017, 24.043363742530346, 37.58691810071468, 79.79928240180016, 49.15215231478214, 26.460417844355106, 23.910334780812263, 26.851401664316654, 44.74565416574478, 32.79936879873276, 31.37835144996643, 48.72110344469547, 50.144157484173775, 47.73783020675182, 45.42406976222992, 42.31552116572857, 33.79637449979782, 27.347389049828053, 18.094830438494682, 8.304453436285257, 3.52537102997303, 0.5990034202113748, 0.09569446585373953, 0.012572508567245677, 0.07725101997493766, 0.03368973069882486, 0.04449878877494484, 0.024327873579750303, 0.06166248262161389, 0.044990298338234425, 0.004177524224360241, 0.07448582968208939, 0.016159837068698835, 0.02490892140485812, 0.036005094152642414, 0.030413133863476105, 0.014431920608330984, 0.009775353046279633, 0.03931548839318566, 0.07057446651742794, 0.04384804029541556, 0.03186527937941719, 0.04058470934978686, 0.06081605577492155, 0.06161665129184257, 0.05538339006307069, 0.045073326109559275, 0.07014988383161835, 0.03594444955524523, 0.03257901393226348, 0.03706348579726182, 0.05286985462589655, 0.030964955913077574, 0.03492421172268223, 0.03012853136169724, 0.07554370924481191, 0.02489672420779243, 0.03819476747594308, 0.034569684066809714, 0.05654476954077836, 0.023995825577003416, 0.03157754872518126, 0.041846801977953874, 0.008622429413662758, 0.013532029443013016, 0.035122817862429656, 0.04298539752198849, 0.031020097485452425, 0.00921997982004541, 0.05320719414157793, 0.014846321955701569, 0.036171042083879, 0.02845850798621541, 0.0375185893062735, 0.08947731665102765, 0.03489550173981115, 0.07002897313213907, 0.020461530948523432, 0.05346445963368751, 0.05560060926654842, 0.029348458083404694, 0.018078183056786656, 0.04891006261459552, 0.16321276081725955, 0.14958197192754596, 0.17584979912498966, 0.16322758892783895, 0.20436277147382498, 0.11852318813907914, 0.11919331780518405, 0.31311878410633653, 0.13714084576349705, 0.12868395424447954, 0.12217954194056801, 0.10985583096044138, 0.09635258014895953, 0.24349706451175734, 0.09889459921396337, 0.14819771808106452, 0.14656995073892176, 0.17681083583738655, 0.1647371321450919, 0.08732356698601507, 0.1286353584146127, 0.11824265631730668, 0.11700940725859255, 0.0843610247829929, 0.15904094092547894, 0.17401479446562007, 0.13469123892718926, 0.12745161802740768, 0.09834660479100421, 0.10245169076370075, 0.08193935238523409, 0.19188410748029128, 0.18585923389764503, 0.12159126374172047, 0.11391673688194714, 0.20482030551647767, 0.08618699008366093, 0.1664953987346962, 0.13777207204839215, 0.09444546099985018, 0.11057991476263851, 0.09745782357640564, 0.13787928270176053, 0.13776065781712532, 0.10152676695724949, 0.09830898532527499, 0.21022780128987506, 0.2473083935910836, 0.12795244896551594, 0.07455785511410795, 0.10332752150134183, 0.14759159123059362, 0.13327723980182782, 0.19295285950647667, 0.20997646555770189, 0.11098639646661468, 0.11734873944078572, 0.15376415220089257, 0.11056884191930294, 0.11774446742492728, 0.15405369369545951, 0.126021069008857, 0.13108490587910637, 0.10022092101280577, 0.16732687130570412, 0.14511951216263697, 0.2427959576016292, 0.27539319125935435, 1.1265823105350137, 3.5294693475589156, 8.548897169530392, 14.927596841007471, 25.4287751019001, 34.75174203515053, 43.463032990694046, 54.36792343854904, 58.46720427274704, 62.75388725101948, 65.88005930185318, 62.66531780362129, 60.90524844825268, 53.17984119057655, 58.043842390179634, 60.71130685508251, 55.79562082886696, 43.7068735063076, 42.67189264297485, 36.31970889866352, 50.55409848690033, 44.117935448884964, 40.95124237239361, 45.8804252743721, 46.17270179092884, 56.45898923277855, 36.85180574655533, 47.63887591660023, 82.48244762420654, 61.99325546622276, 44.322094693779945, 37.36358128488064, 36.85137256979942, 58.65883179008961, 39.870774149894714, 38.52156154811382, 55.432071536779404, 61.77094839513302, 53.56613986194134, 53.780372366309166, 48.020314648747444, 41.9360127300024, 30.46991139650345, 20.40706716477871, 9.859862923622131, 3.7029426265507936, 0.8903138979803771, 0.2934437367366627, 0.12853450054535642, 0.20192355470499024, 0.07115386863006279, 0.11974411754636094, 0.13207150215748698, 0.15702948323450983, 0.12027824122924358, 0.15974314621416852, 0.1427731677540578, 0.1453660090919584, 0.07642809694516473, 0.1589168538339436, 0.13606001157313585, 0.12034973973641172, 0.09888420172501355, 0.11692258340190165, 0.12383306180709042, 0.08618753185146488, 0.11384192839614116, 0.10573059567832388, 0.14217336400179192, 0.11157259665196761, 0.1503020481322892, 0.12894462619442493, 0.1427606848301366, 0.10011416306952015, 0.1762600286747329, 0.18890895618824288, 0.12121412655687891, 0.1601637213025242, 0.1268890404026024, 0.12198704367619939, 0.09283747931476682, 0.12657465180382133, 0.20259574754163623, 0.11451011363533325, 0.14439627440879121, 0.07885816303314641, 0.2062808521441184, 0.1574750241707079, 0.1021287303592544, 0.08434354720520787, 0.19203945383196697, 0.12305989235755987, 0.14413539465749636, 0.22165767702972516, 0.10942014574538916, 0.10220315292826854, 0.09229513263562694, 0.12110730182030238, 0.14818525000009686, 0.15788201795658097, 0.29738127544987947, 0.11738801389583386, 0.11166014781338163, 0.095265400595963, 0.19724165671505034, 0.12533320201328024, 0.14382203022250906, 0.15777917113155127], [0.011737261247617425, 0.021006115202908404, 0.10861838876735419, 0.010459412824275205, 0.03824514817097224, 0.018862247234210372, 0.05839320336235687, 0.02021067019086331, 0.06728537191520445, 0.019844036251015496, 0.04741294666018803, 0.06846851858426817, 0.012895449490315514, 0.035284327750559896, 0.022678350178466644, 0.02902097985497676, 0.03987410666013602, 0.062395375716732815, 0.049347079984727316, 0.044408602989278734, 0.02022405111347325, 0.018588127568364143, 0.03252181661082432, 0.027018253531423397, 0.08188904219423421, 0.020728268100356217, 0.035743461121455766, 0.09006342035718262, 0.03861477111058775, 0.04870046155701857, 0.047985539567889646, 0.04307299692300148, 0.026023098434961867, 0.03058685950236395, 0.06441494508180767, 0.02660022957570618, 0.029131990304449573, 0.025582312810001895, 0.03589316344005056, 0.03663783070805948, 0.03113929196842946, 0.04647598892915994, 0.06889254465932027, 0.0383804936427623, 0.04326064525230322, 0.024999264896905515, 0.012998919719393598, 0.0050742524490487995, 0.023154718073783442, 0.04754728281113785, 0.0075386924982012715, 0.01062162311427528, 0.02102781189023517, 0.06618247367441654, 0.05912892032938544, 0.012955569018231472, 0.04492257365200203, 0.06556868043844588, 0.04188692990283016, 0.02558651893195929, 0.029608990880660713, 0.09984645555960014, 0.05342899981769733, 0.0509858422446996, 0.017636133925407194, 0.029577718632936012, 0.0939265290799085, 0.028522585016617086, 0.055054993426892906, 0.08636519458377734, 0.2903564024018124, 2.0711667370051146, 3.856301922351122, 9.520277995616198, 14.669389296323061, 20.509783253073692, 34.35329921543598, 35.58716520667076, 41.883370354771614, 47.301921397447586, 46.87953606247902, 58.73253643512726, 54.304067865014076, 56.980777233839035, 54.91031013429165, 48.13969664275646, 43.05070951581001, 37.459628731012344, 48.1590262055397, 43.833361119031906, 42.21944712102413, 37.73408800363541, 39.307093396782875, 44.95878092944622, 41.00352756679058, 43.90228182077408, 51.880998685956, 59.4377975910902, 40.64994513988495, 31.070645861327648, 41.44749574363232, 45.78870579600334, 37.79658704996109, 45.2704744040966, 43.807324916124344, 43.963728323578835, 35.34277372062206, 25.543736033141613, 17.552282251417637, 12.891020122915506, 5.869183586910367, 2.8418411454185843, 0.5200836737640202, 0.021258844317344483, 0.019770142462220974, 0.027565923264774028, 0.044774277703254484, 0.08802923810435459, 0.029824081975675654, 0.036260693523217924, 0.027234237059019506, 0.007186526263467385, 0.07362335760262795, 0.04666401204303838, 0.016662291454849765, 0.02565044011134887, 0.03587107341445517, 0.018333823245484382, 0.1216817983367946, 0.051019717575400136, 0.08231257845181972, 0.03978095970524009, 0.07563028819276951, 0.07290838737390004, 0.07845257932785898, 0.04877117709838785, 0.013886021824873751, 0.04055032193718944, 0.011699096303345868, 0.03993674021330662, 0.011384996214474086, 0.06379577869665809, 0.11367631814209744, 0.08507223974447697, 0.033070675635826774, 0.07712975304457359, 0.01831799694627989, 0.04495153596508317, 0.0692915974650532, 0.05299276912410278, 0.02533218121243408, 0.046176421019481495, 0.047760624293005094, 0.020025192643515766, 0.05558873490372207, 0.018685137401917018, 0.02887979739170987, 0.0478485316853039, 0.05454963167721871, 0.045619650700245984, 0.014907766217220342, 0.005155755570740439, 0.005384813421187573, 0.06530795653816313, 0.01932836792548187, 0.026479615735297557, 0.02905873661802616, 0.053879394399700686, 0.005630988907796564, 0.004192413562122965, 0.021140540411579423, 0.016054144107329194, 0.03205023742339108, 0.003170018167111266, 0.04584707072353922, 0.012718541893264046, 0.006625483956668177, 0.02395245261141099, 0.051894268108299, 0.018848606559913605, 0.07930137362563983, 0.028060904223821126, 0.017720861214911565, 0.0394436461647274, 0.048687867310945876, 0.02840480432496406, 0.0175355209648842, 0.0419425612926716, 0.06501228490378708, 0.025956768986361567, 0.09214187171892263, 0.015939354270813055, 0.009647173010307597, 0.007942777065181872, 0.057264085044153035, 0.006912376911714091, 0.05860687881067861, 0.05026761398767121, 0.06528005178552121, 0.095618625782663, 0.021838873544766102, 0.06054917575966101, 0.04241657101374585, 0.09344975856947713, 0.0442077629850246, 0.039149462536443025, 0.016917875982471742, 0.0824594049481675, 0.0067806387414748315, 0.017170048486150336, 0.023541829723399132, 0.07498559934902005, 0.007975134703883668, 0.043252537288935855, 0.025828275392996147, 0.026910345259238966, 0.017927423177752644, 0.03759225859539583, 0.01814922143239528, 0.031087473362276796, 0.030939054959162604, 0.019340730250405613, 0.055452317028539255, 0.003270322440585005, 0.03879438940202817, 0.04318417806643993, 0.08035290040425025, 0.05137855339853559, 0.012321983631409239, 0.030197547384887002, 0.04950097172695678, 0.046547535675927065, 0.0250813557067886, 0.05712144797143992, 0.014461760511039756, 0.04834310631849803, 0.029154022813600022, 0.014822958219156135, 0.003591582167246088, 0.09194083875627257, 0.014482867190963589, 0.010020630070357583, 0.07761246815789491, 0.0348021172976587, 0.028823906250181608, 0.2770689903991297, 0.6868657493032515, 3.2521656900644302, 6.1873766127973795, 12.657213918864727, 19.257148168981075, 26.71313088387251, 39.95919160544872, 42.75321967899799, 48.474010303616524, 55.37285931408405, 53.853681832551956, 63.21466952562332, 61.11885778605938, 61.644890159368515, 59.001220017671585, 52.75287330150604, 48.07045675814152, 41.7208568751812, 51.678807735443115, 47.467816695570946, 46.276200637221336, 42.03002728521824, 42.36822813749313, 49.590827375650406, 41.15941420197487, 46.46784335374832, 56.68007656931877, 65.82618579268456, 45.30882194638252, 33.84804032742977, 42.83838830888271, 50.0299584120512, 42.29049190878868, 48.19637440145016, 49.57361429929733, 49.21432077884674, 41.25139966607094, 30.425712168216705, 22.49393418431282, 16.41439910978079, 8.423220813274384, 3.75674013979733, 1.0491440095938742, 0.13883965148124844, 0.021844664152013138, 0.029422079132928047, 0.055404073718818836, 0.002719806338973285, 0.027759263866755646, 0.05917701520957053, 0.03975873980380129, 0.01855892962339567, 0.06680249352939427, 0.06064705019525718, 0.028718497160298284, 0.03459141786152031, 0.0223877900862135, 0.0306373756393441, 0.036491805731202476, 0.06329823547275737, 0.04666875065595377, 0.05491345473274123, 0.053208095851005055, 0.026931986285489984, 0.08017883708816953, 0.09103572287131101, 0.04928561902488582, 0.03859182390442584, 0.057081472186837345, 0.04141788143897429, 0.0050696237667580135, 0.047568623267579824, 0.047990853345254436, 0.0832988704496529, 0.0371955287118908, 0.09255181925254874, 0.0415544329007389, 0.08313170910696499, 0.055306013746303506, 0.058061834424734116, 0.07324265068746172, 0.04296902574424166, 0.02008073868637439, 0.036531109872157685, 0.054469245951622725, 0.009763529706106056, 0.0480313634761842, 0.0046378928072954295, 0.08703418134246022, 0.053993644323782064, 0.04673730654758401, 0.036420322066987865, 0.011268972557445522, 0.005782829075542395, 0.0167229917133227, 0.006307998746706289, 0.011264488130109385, 0.019806554082606453, 0.042310492135584354, 0.044929616633453406, 0.062161350579117425, 0.016056387248681858, 0.03268456959631294, 0.005599206897386466, 0.053255905004334636, 0.01431647026038263, 0.060963683790760115, 0.09400298513355665, 0.1757704486954026, 0.1117019381490536, 0.13506369316019118, 0.08026363488170318, 0.15359915792942047, 0.15391029592137784, 0.1943333729286678, 0.1874311620485969, 0.18006438156589866, 0.14324078016215935, 0.14917365711880848, 0.13394036359386519, 0.18422820110572502, 0.17622119950829074, 0.09378359885886312, 0.07481598891899921, 0.19423238147282973, 0.061874684906797484, 0.13252194126835093, 0.12861509778304026, 0.18817503150785342, 0.15211070654913783, 0.12677074206294492, 0.10980724255205132, 0.08560205897083506, 0.18941939051728696, 0.10926779767032713, 0.13338825025130063, 0.13915807736339048, 0.1642087526852265, 0.08998889388749376, 0.07092638552421704, 0.24443395173875615, 0.14858605427434668, 0.08151113317580894, 0.11389525912818499, 0.16783775092335418, 0.12115526682464406, 0.10777160568977706, 0.16536184237338603, 0.17168774589663371, 0.1829301699763164, 0.11690630068187602, 0.1267085352446884, 0.11606911357375793, 0.11763917151256464, 0.0736783433239907, 0.13758227520156652, 0.13927126972703263, 0.17604220833163708, 0.15029881236841902, 0.15387629071483389, 0.13449848833261058, 0.08422411337960511, 0.13691468368051574, 0.10111753188539296, 0.07785155845340341, 0.1501454401295632, 0.11427365796407685, 0.14334745646920055, 0.0902242140728049, 0.16645774216158316, 0.17303793516475707, 0.0887157024408225, 0.20725300622871146, 0.11011688140570186, 0.12794700160156935, 0.2702787547605112, 0.6444771238602698, 2.746670739725232, 5.891277026385069, 13.164865728467703, 21.339436434209347, 28.38885996490717, 42.762593775987625, 47.949946224689484, 55.948555022478104, 63.51070784032345, 64.61560115218163, 72.15161517262459, 68.59442844986916, 69.94656309485435, 70.69910511374474, 60.71503445506096, 57.9026647657156, 50.37509009242058, 63.58393371105194, 56.90865710377693, 55.032579973340034, 49.52152669429779, 54.97357673943043, 59.22529399394989, 53.044724240899086, 50.76135076582432, 64.54064637422562, 70.91013818979263, 55.216543301939964, 43.73134419322014, 51.64482995867729, 58.73179167509079, 50.60434319078922, 56.11202225089073, 56.705744192004204, 56.06992430984974, 46.943897008895874, 34.1710039973259, 25.781639367341995, 17.630132474005222, 9.543821532279253, 4.194033974781632, 1.0700089274905622, 0.2698321599746123, 0.08891962977941148, 0.12118805490899831, 0.15277559665264562, 0.14941084751626477, 0.19911246257834136, 0.11490036456962116, 0.12262704956810921, 0.2052678057225421, 0.1438878438784741, 0.3051153151318431, 0.11380079115042463, 0.08255837034084834, 0.11950527215958573, 0.11301722421194427, 0.19413122674450278, 0.21289600030286238, 0.16235209215665236, 0.06558130437042564, 0.31526973587460816, 0.1939969722297974, 0.21012038283515722, 0.4160587041405961, 0.12165919251856394, 0.15355033945525065, 0.14348505064845085, 0.1590480507002212, 0.11799427433288656, 0.1619094455963932, 0.1579168246826157, 0.1293385136523284, 0.10509692772757262, 0.16971502831438556, 0.07409287733025849, 0.17384243808919564, 0.14818784751696512, 0.1258687357767485, 0.195293637807481, 0.11187462107045576, 0.11088305982411839, 0.12633081176318228, 0.14982460968894884, 0.12002533956547268, 0.0877189238963183, 0.14194858231348917, 0.17802988761104643, 0.16175010649021715, 0.14519724471028894, 0.11378767740097828, 0.12940781540237367, 0.16264236095594242, 0.15869695547735319, 0.0707135969423689, 0.06164336118672509, 0.15287931921193376, 0.1612224246491678, 0.15545981121249497, 0.13971744891023263, 0.12303593583055772, 0.24731298006372526, 0.09250405462807976, 0.1336609004647471, 0.08310058343340643], [0.061292362443055026, 0.04415902614709921, 0.03522528990288265, 0.0982876485795714, 0.11738411762053147, 0.012003957581327995, 0.03351631676196121, 0.07957562687806785, 0.023756104455969762, 0.013974334615340922, 0.01006837150271167, 0.021070542898087297, 0.041480463041807525, 0.06332705306704156, 0.01801381844416028, 0.022021248914825264, 0.011543999498826452, 0.0417707726592198, 0.03633563930634409, 0.035216276519349776, 0.02423254099994665, 0.08545266464352608, 0.0369738120934926, 0.04955362710461486, 0.03177600272465497, 0.04360067134257406, 0.12075470745912753, 0.01647455592319602, 0.02997428338858299, 0.053236579478834756, 0.08235745612182654, 0.04578826294164173, 0.023346633752225898, 0.03133397585770581, 0.08317153275129385, 0.005328035413185717, 0.07933787244837731, 0.054905565702938475, 0.029362462410063017, 0.024863459293555934, 0.017407173945684917, 0.05027411520131864, 0.0359269942418905, 0.022252153321460355, 0.027095635414298158, 0.021917669218964875, 0.05982170034258161, 0.019022541855520103, 0.025266003904107492, 0.01884674005850684, 0.03482738000457175, 0.026855606301978696, 0.03334011234983336, 0.09496269340161234, 0.01348957302980125, 0.028770998542313464, 0.05290766333928332, 0.04259485715010669, 0.05024062207667157, 0.07737455045571551, 0.04242795184836723, 0.014033673960511805, 0.030779244589211885, 0.0213028610960464, 0.04075462777109351, 0.028430156089598313, 0.035154411089024507, 0.010193366797466297, 0.051236376457381994, 0.027259438538749237, 0.0640158774331212, 0.07349395673372783, 0.23147090279962867, 1.0852332855574787, 3.259012447670102, 6.312606493011117, 14.310257267206907, 16.930075138807297, 26.294845528900623, 30.19064348191023, 34.48539912700653, 38.94452065229416, 35.90878754854202, 44.009641259908676, 46.57378546893597, 52.133867517113686, 47.76431478559971, 48.97699311375618, 49.29338313639164, 52.37472139298916, 50.75537368655205, 45.42892590165138, 58.99134434759617, 56.66377544403076, 54.74419824779034, 47.834139838814735, 47.615035995841026, 46.58866547048092, 45.594961792230606, 43.98344546556473, 42.34446421265602, 39.61885906755924, 39.67997118830681, 41.37083865702152, 28.386405296623707, 23.31670593470335, 14.12844367325306, 9.7778994217515, 3.8203335274010897, 2.526923781260848, 0.4522783902939409, 0.06724592676619068, 0.03329638871946372, 0.030384260608116165, 0.045638987357961014, 0.04718742653494701, 0.020624233839043882, 0.037136776591069065, 0.05619174844468944, 0.05568764463532716, 0.037260403551044874, 0.06102991304942407, 0.030804112102487125, 0.005717725098293158, 0.03380077825568151, 0.024167074298020452, 0.04655670119973365, 0.03799602032813709, 0.034280428299098276, 0.01519538183856639, 0.022164227375469636, 0.03556720104825217, 0.031215736889862455, 0.08878469991032034, 0.0383956111909356, 0.021298636420397088, 0.05143910522747319, 0.052916335334884934, 0.038728668514522724, 0.0171283379313536, 0.0634792452910915, 0.021950574191578198, 0.06016791594447568, 0.04632954463886563, 0.03559458258678205, 0.024552146896894556, 0.049648547792457975, 0.04529346937488299, 0.027034085396735463, 0.03115171923127491, 0.07046307015116327, 0.06147216998215299, 0.04038165403471794, 0.09128593796049245, 0.010483465830475325, 0.04306281836761627, 0.04864023256232031, 0.036679891927633435, 0.015065280567796435, 0.03595303249312565, 0.03815362280874979, 0.021428621730592567, 0.04856819228734821, 0.04691276881203521, 0.05297854957461823, 0.09960255614714697, 0.009475431688770186, 0.016423032320744824, 0.035136154256179, 0.04149030391999986, 0.02833823182299966, 0.0364662164793117, 0.011947526527364971, 0.05961881201073993, 0.057875317870639265, 0.060563098450074904, 0.03684995506773703, 0.025257181623601355, 0.03481311221548822, 0.07337286049732938, 0.024457252184220124, 0.04451424400031101, 0.011925825201615226, 0.04114848554308992, 0.002137148053407145, 0.03357519133714959, 0.017312338604824618, 0.05096029010019265, 0.04445055288670119, 0.03511535927827936, 0.05048346021794714, 0.042321898945374414, 0.021433519905258436, 0.06054038502043113, 0.03351347433635965, 0.04398610944917891, 0.052677686617244035, 0.02045881839876529, 0.004852256133744959, 0.03148726646031719, 0.005590082655544393, 0.0506002594192978, 0.027847809506056365, 0.04285071627236903, 0.007194658346634242, 0.02637314908497501, 0.07480958418454975, 0.02582246994279558, 0.058634635133785196, 0.05322473851265386, 0.029572490202554036, 0.02446250473440159, 0.02718277282838244, 0.10338308609789237, 0.027541820163605735, 0.03561189318133984, 0.04419891658471897, 0.01669894983933773, 0.03831354821159039, 0.10067111521493644, 0.09843267165706493, 0.021930076072749216, 0.028158823188277893, 0.0107406441202329, 0.013143862088327296, 0.024739066066103987, 0.07636432419531047, 0.043732795893447474, 0.03653825304354541, 0.0435520161408931, 0.0230016408386291, 0.03984420924098231, 0.06295823535765521, 0.04949400667101145, 0.03061866980715422, 0.05822978986543603, 0.014593832183891209, 0.032321540638804436, 0.04944267973769456, 0.025434220951865427, 0.060068163875257596, 0.008064249941526214, 0.023444827311323024, 0.03460816813458223, 0.05561820187722333, 0.05831094371387735, 0.05162817476957571, 0.20636312663555145, 0.7385950454045087, 1.5172065747901797, 4.924146747216582, 8.227753601968288, 17.588933184742928, 20.592339523136616, 31.872499734163284, 37.39181376993656, 40.59259481728077, 47.31321059167385, 44.155298843979836, 49.72187094390392, 53.90163145959377, 57.79313564300537, 53.622004464268684, 54.59835447371006, 56.524303928017616, 59.141793474555016, 56.4570627361536, 51.75782069563866, 61.90502420067787, 61.19606964290142, 58.117820620536804, 48.00602361559868, 50.79886615276337, 53.231206834316254, 51.75971299409866, 47.651992812752724, 49.48497265577316, 45.104871690273285, 45.86822032928467, 46.91924013197422, 34.00647282600403, 28.47071897238493, 17.976073510944843, 12.453770935535431, 5.177483903244138, 3.7914814380928874, 0.7920423243194818, 0.11252837895881385, 0.005980187479508459, 0.04315858139307238, 0.0673973248922266, 0.004923383567074779, 0.007587934460389079, 0.008200319007301005, 0.038961843893048353, 0.015339564433816122, 0.046780161865171976, 0.03499802201986313, 0.06227274323464371, 0.03530558657075744, 0.07762313282000832, 0.024757690262049437, 0.08824410469969735, 0.031191375892376527, 0.030310123765957542, 0.007911146731203189, 0.05866203151526861, 0.0635994880576618, 0.01068676419890835, 0.009045444312505424, 0.027887011601706035, 0.058956619614036754, 0.0443088620522758, 0.059740034412243403, 0.08302482499857433, 0.0365108121332014, 0.04177196380624082, 0.04360512793937232, 0.07873298498452641, 0.032222812733380124, 0.034466551514924504, 0.03113413775281515, 0.055629018679610454, 0.004783621852766373, 0.02359606216487009, 0.018001715870923363, 0.05734426296839956, 0.04364838772744406, 0.032457320266985334, 0.027596425534284208, 0.02107292148139095, 0.01955573414306855, 0.007374875922323554, 0.01616304500203114, 0.05978002503979951, 0.03716117098520044, 0.020956940497853793, 0.044196567687322386, 0.039452685523428954, 0.031002460345916916, 0.04560361659969203, 0.03586062397516798, 0.03212037408957258, 0.01135813139626407, 0.04948569090629462, 0.04691841284511611, 0.04036908947455231, 0.016829042760946322, 0.020939566820743494, 0.04265427720383741, 0.05929552506131586, 0.05791946823592298, 0.11183127964613959, 0.13899658602895215, 0.17083899612771347, 0.1800503401318565, 0.25302094174548984, 0.11906790969078429, 0.13876096898457035, 0.26480226893909276, 0.2565429371315986, 0.12417860576533712, 0.12518218980403617, 0.17561367742018774, 0.16792189562693238, 0.29675142955966294, 0.10384736626292579, 0.08335789345437661, 0.12344893359113485, 0.17427272046916187, 0.17868474387796596, 0.15984355879481882, 0.10399816324934363, 0.26317948882933706, 0.13221384608186781, 0.126904402859509, 0.1394476040150039, 0.15238528634654358, 0.24384041171288118, 0.08213360953959636, 0.098198234627489, 0.13738385459873825, 0.15345875843195245, 0.10974705437547527, 0.0782733951928094, 0.11640306518529542, 0.14111589262029156, 0.0962906405038666, 0.19947476423112676, 0.19670535111799836, 0.11034546289010905, 0.1766417152248323, 0.10383391112554818, 0.1519695352180861, 0.150284830306191, 0.17097528412705287, 0.1653988755424507, 0.13127820566296577, 0.17915639356942847, 0.1412210549460724, 0.10003079762100242, 0.08078290818957612, 0.13521016342565417, 0.15970164531609043, 0.26167943025939167, 0.11095249516074546, 0.10613350765197538, 0.11432932646130212, 0.1650816370965913, 0.1925999386003241, 0.18644153780769557, 0.10291179263731465, 0.10607317846734077, 0.12349725482636131, 0.19450705032795668, 0.18525496241636574, 0.24326549959369004, 0.11004904910805635, 0.19379400968318805, 0.1315910802804865, 0.12590305268531665, 0.14088829077081755, 0.1913441505166702, 0.26552443800028414, 0.5983039014972746, 1.485800666268915, 4.59092790260911, 8.40031849220395, 18.777822889387608, 22.797313705086708, 33.50964568555355, 40.31609885394573, 46.25364504754543, 51.48160971701145, 52.21580632030964, 55.14607608318329, 62.07704097032547, 66.87772616744041, 62.46549412608147, 63.626548424363136, 66.83126986026764, 66.56073197722435, 67.44089394807816, 59.73711512982845, 73.50543692708015, 70.54353386163712, 68.97077545523643, 58.47740672528744, 59.16189059615135, 61.701408326625824, 58.67295183241367, 58.764697909355164, 56.563552021980286, 52.35736012458801, 51.742701306939125, 53.098498955368996, 39.79550398886204, 32.09188096225262, 19.659193195402622, 13.983015026897192, 6.391300745308399, 4.090527528896928, 0.9967620391398668, 0.20298212446505204, 0.12276733032194898, 0.14063450595131144, 0.136750758101698, 0.11192067133379169, 0.08164670129190199, 0.14435290329856798, 0.10000089649111032, 0.07937476460938342, 0.15130037034396082, 0.12580375332618132, 0.08180663411621936, 0.12111959920730442, 0.12164806772489101, 0.09828925904002972, 0.2870931493816897, 0.13803915615426376, 0.13923193590017036, 0.19766405748669058, 0.11134456435684115, 0.12879803718533367, 0.12123375636292621, 0.18355188192799687, 0.12671239441260695, 0.10638989740982652, 0.10934637626633048, 0.1852887449786067, 0.25598243752028793, 0.09249595037545078, 0.09474241654970683, 0.19657048804219812, 0.2158122102264315, 0.15185457654297352, 0.16628694429527968, 0.10380922729382291, 0.19485311378957704, 0.11763117116061039, 0.15888635156443343, 0.08896568004274741, 0.1363394598593004, 0.12843809556216002, 0.14555028436006978, 0.1682843011803925, 0.053137439681449905, 0.12082009809091687, 0.10887411801377311, 0.08591992824221961, 0.1655098859919235, 0.09345904283691198, 0.09900828881654888, 0.0896018861385528, 0.13220206077676266, 0.1489970853435807, 0.12895653024315834, 0.14998771890532225, 0.11590106907533482, 0.0898164336103946, 0.11677956412313506, 0.20481632760493085, 0.10572695915470831, 0.10035568760940805, 0.07247430519782938, 0.16247732215560973, 0.13291103445226327, 0.17854373581940308], [0.02517396645998815, 0.04908384020382073, 0.04068103269673884, 0.04241106056724675, 0.01953738639713265, 0.060397332345019095, 0.047636596573283896, 0.04901463493297342, 0.005156306615390349, 0.0834997624042444, 0.07759139116387814, 0.0399306360486662, 0.03931517669116147, 0.047669759442214854, 0.022478282007796224, 0.00989800222669146, 0.08932586657465436, 0.06850639780168422, 0.018793789677147288, 0.01220298025145894, 0.020511397706286516, 0.028982386320421938, 0.03384372263099067, 0.020271435387257952, 0.048782587618916295, 0.03163457535265479, 0.06258748806430958, 0.0006701858490032464, 0.048446231448906474, 0.044079527287976816, 0.019361339691386092, 0.026106860932486597, 0.010028916149167344, 0.025502680364297703, 0.00767016535064613, 0.027621612171060406, 0.028233019402250648, 0.008606583633081755, 0.0223021833517123, 0.026859124081966, 0.03837961790850386, 0.07479471896658652, 0.019315517638460733, 0.0323179857514333, 0.03003553098096745, 0.04564033806673251, 0.03842900041490793, 0.04696698269981425, 0.03162387729389593, 0.021910082614340354, 0.05216209436184727, 0.011634539660008159, 0.058767464724951424, 0.07658253045519814, 0.06546356264152564, 0.055312529802904464, 0.12314441555645317, 0.004377097011456499, 0.062458836764562875, 0.023112421222322155, 0.03926919322111644, 0.05731961253331974, 0.04590261676639784, 0.04380911464977544, 0.03194508622982539, 0.05174027246539481, 0.0573268150765216, 0.07588289299746975, 0.005611449550997349, 0.05596936389338225, 0.02855694645404583, 0.027601724468695465, 0.04015543257992249, 0.06719120079651475, 0.10130266804480925, 0.26960562681779265, 1.5233831433579326, 3.5984926437959075, 6.188839059323072, 8.539107944816351, 11.537987776100636, 16.597915962338448, 18.571862541139126, 26.034369505941868, 27.101832926273346, 30.927988216280937, 29.88046232610941, 33.32116059958935, 36.31276287138462, 34.70098435878754, 43.12404178082943, 37.49033868312836, 38.32792013883591, 41.10845133662224, 40.02935104072094, 53.64767208695412, 43.149568811059, 43.97166229784489, 44.86087918281555, 41.342628970742226, 33.34112852811813, 37.90194019675255, 30.216924771666527, 25.099475271999836, 14.444376770406961, 5.790731571614742, 2.8962357016280293, 1.2815991486422718, 0.11441709284554236, 0.11116923196823336, 0.016118456769618206, 0.03565599530702457, 0.06180175034387503, 0.031474846618948504, 0.06579521359526552, 0.027480084609123878, 0.043271391550661065, 0.11936755923670717, 0.02798917565087322, 0.026799978622875642, 0.06632619057199918, 0.02723986624914687, 0.06814477150328457, 0.035757814257522114, 0.025245400029234588, 0.04560037712508347, 0.01943168230354786, 0.04805981370736845, 0.033179626625496894, 0.044038831620127894, 0.049445770782767795, 0.05578279167821165, 0.018032785883406177, 0.013648933472723002, 0.0195898061429034, 0.035853317531291395, 0.08521626092260703, 0.08461492834612727, 0.05083179094071966, 0.058526726861600764, 0.08721260848687962, 0.06267294636927545, 0.03971339829149656, 0.03686505777295679, 0.042257577006239444, 0.012856983048550319, 0.03138722495350521, 0.029926839742984157, 0.022086800963734277, 0.09567242406774312, 0.02377839857217623, 0.1167014085513074, 0.07486956455977634, 0.04487996695388574, 0.03295667433121707, 0.01951262092916295, 0.06107289453211706, 0.039144033726188354, 0.014460453403444262, 0.04071508614288177, 0.026181224129686598, 0.0034076137308147736, 0.022145937145978678, 0.03136495310172904, 0.026086500110977795, 0.07512442549341358, 0.01581037085998105, 0.016417299229942728, 0.06339274797937833, 0.05783840715594124, 0.03506882661895361, 0.034204287658212706, 0.03828621862339787, 0.03298312076367438, 0.05506149464054033, 0.030317782729980536, 0.01074633639291278, 0.019658230303321034, 0.0555689640896162, 0.038474494067486376, 0.04712916794233024, 0.049251680611632764, 0.03125229137367569, 0.04936852063110564, 0.04090437090781052, 0.03289130596385803, 0.03973974453401752, 0.009602285135770217, 0.040504876524209976, 0.08422246581176296, 0.02739373201620765, 0.028634471200348344, 0.12259605748113245, 0.06009392011037562, 0.055832946018199436, 0.10388343464001082, 0.045281632119440474, 0.010027603475464275, 0.02294830082973931, 0.0905290586524643, 0.06523786069010384, 0.023339058279816527, 0.04287616451620124, 0.03352996485773474, 0.04218194473651238, 0.029434849639073946, 0.033774610128602944, 0.04078813944943249, 0.06077774611185305, 0.019479472903185524, 0.011765021281462396, 0.034483331473893486, 0.015452947900485015, 0.006153133399493527, 0.0179879416100448, 0.051844993213308044, 0.01774562111677369, 0.0705435560666956, 0.016424986024503596, 0.0915382978564594, 0.06528090525534935, 0.06367816313286312, 0.05888204861548729, 0.023329371397267096, 0.019084650339209475, 0.020404968163347803, 0.0012787434070560266, 0.0014670490008938941, 0.012772308637067908, 0.07502617998397909, 0.005562659371207701, 0.10813044151291251, 0.03896918373357039, 0.04993246009689756, 0.035759814345510677, 0.021099635087011848, 0.03568948101019487, 0.06314415819360875, 0.028023409067827743, 0.06540897767990828, 0.019438738272583578, 0.027574125851970166, 0.044496840637293644, 0.03420599088713061, 0.03393851715372875, 0.034900288592325523, 0.02039593437075382, 0.016279439732898027, 0.007607892202941002, 0.016244621874648146, 0.23362247797194868, 0.7570072542876005, 2.296142214909196, 4.957070555537939, 8.490423057228327, 11.50816697627306, 16.32214765995741, 20.355870611965656, 22.870302088558674, 31.165087893605232, 32.69359387457371, 37.34390214085579, 37.729988023638725, 40.47223247587681, 42.03413486480713, 43.181525096297264, 49.05987046658993, 42.58018456399441, 45.72977475821972, 49.54155921936035, 48.15727449953556, 60.731753557920456, 50.38876175880432, 49.52369637787342, 50.60805559158325, 47.010218650102615, 40.688212886452675, 44.26927372813225, 36.01896643638611, 29.233854822814465, 17.210025116801262, 7.517739851027727, 4.290292784571648, 1.9174064439721406, 0.1329573296243325, 0.16245128761511296, 0.07647106729564257, 0.08210129642975517, 0.03495176766591612, 0.07469347518053837, 0.022963492592680268, 0.013592251016234513, 0.044660072308033705, 0.04346824993262999, 0.07143060807720758, 0.015343409686465748, 0.06835730033344589, 0.018674825259950012, 0.049557820238987915, 0.052384708978934214, 0.02635323726281058, 0.04101261685718782, 0.01978575539396843, 0.05050264473538846, 0.08793210581643507, 0.02935663655080134, 0.11702635791152716, 0.0498931670881575, 0.013544689554692013, 0.04218169240630232, 0.035939926165156066, 0.010595705462037586, 0.056859276883187704, 0.07658850474399514, 0.028906965562782716, 0.025607696115912404, 0.08726496700546704, 0.025961989995266777, 0.02591261491033947, 0.02466023142915219, 0.06093506657634862, 0.03331779225845821, 0.043815252211061306, 0.04479876115510706, 0.0721957697533071, 0.06200540308782365, 0.03279619231761899, 0.04649147012969479, 0.04417375035700388, 0.08612297242507339, 0.043084808203275315, 0.06858725479105487, 0.048285296725225635, 0.014998430688137887, 0.021197040114202537, 0.06715262396028265, 0.015103189471119549, 0.02695022642001277, 0.02830635101418011, 0.0015132130215533834, 0.08197830029530451, 0.015647441614419222, 0.04707528802100569, 0.03496110388368834, 0.037357283508754335, 0.018534902592364233, 0.051479481771821156, 0.08949328766902909, 0.05086853096145205, 0.018334940177737735, 0.02254556140542263, 0.023571059209643863, 0.128968775679823, 0.20678031753050163, 0.1273458026116714, 0.09546353918267414, 0.103828419232741, 0.14045809744857252, 0.09814952005399391, 0.1570809882832691, 0.0787703892274294, 0.13285644206916913, 0.15946699306368828, 0.1350297176395543, 0.12800613592844456, 0.21554977196501568, 0.16089412820292637, 0.083430178638082, 0.16437233687611297, 0.13247661088826135, 0.12216981980600394, 0.3123493253951892, 0.12948565185070038, 0.09099673785385676, 0.08639513282105327, 0.10873731051106006, 0.16835798160173, 0.18002006050664932, 0.22678945009829476, 0.08825278782751411, 0.15020945778815076, 0.18767157336696982, 0.22092476167017594, 0.13406813173787668, 0.16072312253527343, 0.13501708628609776, 0.08206547296140343, 0.07804160020896234, 0.1356149307684973, 0.12343824666459113, 0.12998995603993535, 0.11339834672980942, 0.34498019318562, 0.18232292990433052, 0.1313374884193763, 0.16791463742265478, 0.0999310084444005, 0.14582430012524128, 0.12562115531181917, 0.15666133345803246, 0.14061624911846593, 0.10835437715286389, 0.08392129486310296, 0.1381718076299876, 0.12437741970643401, 0.17911622853716835, 0.07794375545927323, 0.18718280975008383, 0.281459714169614, 0.1505635809735395, 0.1762496682931669, 0.10956090147374198, 0.0826108327601105, 0.1496992609463632, 0.07670354505535215, 0.17690453940303996, 0.10941927001113072, 0.13843445369275287, 0.12173277646070346, 0.27849646692629904, 0.14754301024368033, 0.15970369364367798, 0.08673770076711662, 0.10025675932411104, 0.10764729595393874, 0.15451530955033377, 0.1799227501032874, 0.7365952839609236, 2.344514806754887, 5.207796776667237, 8.720905389636755, 12.13309284299612, 16.66505265980959, 20.892335325479507, 25.061540007591248, 33.711646646261215, 34.842207580804825, 39.62687283754349, 41.3515280932188, 43.88295225799084, 46.42960600554943, 47.39496320486069, 54.95435357093811, 50.241021886467934, 51.74587033689022, 56.16583876311779, 53.63143555819988, 64.19425696134567, 58.13379496335983, 57.769436314702034, 59.121863543987274, 53.397660702466965, 46.07930660247803, 48.669551610946655, 40.614724829792976, 32.79831625521183, 19.979966282844543, 9.618455227464437, 4.829233540222049, 2.0064353104680777, 0.4614798043621704, 0.26823333639185876, 0.1369158414308913, 0.20768137386767194, 0.1617111437371932, 0.1836691561038606, 0.1629732846049592, 0.16428390255896375, 0.11635232454864308, 0.13167703582439572, 0.09990678474423476, 0.12571469560498372, 0.1507623281213455, 0.13648830499732867, 0.21260016539599746, 0.2217129076598212, 0.13822856708429754, 0.08978972371551208, 0.1565201472840272, 0.11045771272620186, 0.16678761196089908, 0.1473107180208899, 0.15014916571089998, 0.18782779545290396, 0.0633614590333309, 0.11190192468347959, 0.12105035682907328, 0.15162072581006214, 0.1296281738905236, 0.24130783276632428, 0.162559240416158, 0.09610804991098121, 0.19262898626038805, 0.21622209838824347, 0.21240943344309926, 0.06715326962876134, 0.10520158539293334, 0.08584485258325003, 0.12555118562886491, 0.12723076972179115, 0.18295521003892645, 0.1791148036136292, 0.14267639169702306, 0.21337285987101495, 0.17269959003897384, 0.1775585496216081, 0.1823064690688625, 0.15831258235266432, 0.15694329020334408, 0.12646843562833965, 0.1172117909300141, 0.1301553807570599, 0.09489711723290384, 0.11789888609200716, 0.17502834554761648, 0.12596943037351593, 0.17452166648581624, 0.14644348877482116, 0.08875091734807938, 0.10761224431917071, 0.1509400873328559, 0.15716155583504587, 0.11383002434740774, 0.18277227063663304, 0.1239267727942206, 0.1678950892528519, 0.11411467508878559, 0.1717882475350052], [0.07487242182833143, 0.04713052978331689, 0.026016890369646717, 0.07131243590265512, 0.027545471530174837, 0.06579729160876013, 0.042022097259177826, 0.021268969067023136, 0.0694475820637308, 0.022137610249046702, 0.07303110891371034, 0.030357077594089787, 0.07865853272960521, 0.04289133030397352, 0.059215261790086515, 0.07722289999946952, 0.07785028195939958, 0.045784466856275685, 0.0514629170356784, 0.08144459963659756, 0.020776511410076637, 0.020619979477487504, 0.11088796542026103, 0.07455824103089981, 0.022166886119521223, 0.025060857587959617, 0.036749987775692716, 0.08114745854982175, 0.020076697692275047, 0.03962704569858033, 0.0546733291412238, 0.08188432213501073, 0.005648979031320778, 0.03325207879242953, 0.035877381669706665, 0.011591632392082829, 0.0333151613449445, 0.01975843137188349, 0.019952651418861933, 0.01647620720177656, 0.0287020715768449, 0.04688748384069186, 0.05762994900578633, 0.026534512398939114, 0.023149938642745838, 0.07568862100015394, 0.03896618916769512, 0.05726042254536878, 0.014733041462022811, 0.03696244239108637, 0.022454646459664218, 0.049070351669797674, 0.032963275734800845, 0.0605792327405652, 0.02623935099109076, 0.034368562046438456, 0.04125230829231441, 0.018093246799253393, 0.005910377822146984, 0.06963300023926422, 0.041816299708443694, 0.05269454079098068, 0.028655576024902984, 0.023799462578608654, 0.03307904706161935, 0.02600937797978986, 0.012801954653696157, 0.03190645373251755, 0.008517606620443985, 0.029869271347706672, 0.029558216847362928, 0.056698308762861416, 0.08320755659951828, 0.0495323719951557, 0.041453437734162435, 0.024452778889099136, 0.022922900825506076, 0.12718679005047306, 0.23902948392787948, 0.9255127154756337, 0.6239121523685753, 2.78536643832922, 3.7662709783762693, 5.687103532254696, 5.296125886961818, 8.185097090899944, 9.546937365084887, 10.693172458559275, 9.725616127252579, 12.199615873396397, 15.607224572449923, 14.169110041111708, 14.90431074053049, 15.369838960468769, 10.4716975428164, 19.269607700407505, 23.28922960907221, 22.055838592350483, 19.72191832959652, 22.261428460478783, 17.134992443025112, 14.180916957557201, 8.747168630361557, 4.756080815568566, 3.5273113008588552, 0.5594424961600453, 0.1438367841183208, 0.017598917074792553, 0.060702967311954126, 0.004708108790509868, 0.04335556222940795, 0.03111643196461955, 0.06309294258244336, 0.014787719192099757, 0.0689705740660429, 0.02234771782241296, 0.07567738488432951, 0.02078259887639433, 0.13903548941016197, 0.08680890983669087, 0.11303053834126331, 0.03430001357628498, 0.03803267500188667, 0.023013466961856466, 0.07646696321899071, 0.01258344782399945, 0.05712368183594663, 0.07528456611908041, 0.027004215808119625, 0.023957027951837517, 0.038312535180011764, 0.048611311067361385, 0.07066201025736518, 0.049559838880668394, 0.05303420693962835, 0.05250446934951469, 0.04697913536801934, 0.04302357730921358, 0.02956110936793266, 0.02234969193523284, 0.010541399733483559, 0.0209256663947599, 0.025635385645728093, 0.03069987189519452, 0.08638177416287363, 0.049272876349277794, 0.018356570071773604, 0.06391245173290372, 0.047824820067035034, 0.04290825869247783, 0.0978969523566775, 0.026065519596158992, 0.0038440997695943224, 0.03439897896896582, 0.013434121610771399, 0.0038409437865993823, 0.07188910691183992, 0.09499316598521546, 0.0140813031430298, 0.07974623920745216, 0.015170854785537813, 0.04161812030361034, 0.04621323154424317, 0.017447567188355606, 0.02468908242008183, 0.03927872981876135, 0.049805786620709114, 0.01930158381583169, 0.03164381880196743, 0.02710237225983292, 0.09329411535873078, 0.04339802049798891, 0.03281676836195402, 0.07651005231309682, 0.05576834206294734, 0.08096007368294522, 0.08989516063593328, 0.05029335166909732, 0.08279743095044978, 0.01975000985112274, 0.005422750618890859, 0.055801731286919676, 0.005902926659473451, 0.021453133012983017, 0.011552049018064281, 0.007791596017341362, 0.09531676463666372, 0.020439270228962414, 0.05421306770585943, 0.02440619056869764, 0.08413843243033625, 0.09681821102276444, 0.03503452826407738, 0.0251284523983486, 0.02059158305200981, 0.03511453920509666, 0.02210720816947287, 0.02214798361819703, 0.03351390849275049, 0.06162053643492982, 0.032321681646863, 0.00934577756197541, 0.03023000892426353, 0.04768338898429647, 0.06895040249219164, 0.03608495295338798, 0.030186866024450865, 0.055391126952599734, 0.008553779825888341, 0.041456974067841657, 0.04106876775040291, 0.05488986185810063, 0.0321604723285418, 0.04164828860666603, 0.03132378617010545, 0.023322361812461168, 0.052718515871674754, 0.016558071656618267, 0.06869216478662565, 0.03767372043512296, 0.03050804341910407, 0.05422897193056997, 0.04650888833566569, 0.05117933869769331, 0.054231803223956376, 0.030827313494228292, 0.006849851433798904, 0.04351487536041532, 0.01616088906303048, 0.05994647763145622, 0.05115432832099032, 0.08932260854635388, 0.02484371445461875, 0.01598076611116994, 0.0528333706461126, 0.040183107266784646, 0.06438133321353234, 0.06679934682324529, 0.030505108225042932, 0.10140450554899871, 0.050610512189450674, 0.07897640942246653, 0.021606863338092808, 0.01874944820883684, 0.03770802992221434, 0.015938365359033924, 0.03458048973698169, 0.024114392945193686, 0.020914296692353673, 0.020842050471401308, 0.03493969292321708, 0.008881616140570259, 0.05497965059475973, 0.1356181368464604, 0.37066512275487185, 1.2330299173481762, 1.3488124357536435, 4.4171917252242565, 5.575895374640822, 7.871934520080686, 7.792533505707979, 11.18985140696168, 12.870396729558706, 14.98346334323287, 13.620381485670805, 16.035791225731373, 20.27083497494459, 18.94095003604889, 19.3084055185318, 20.36486092954874, 14.799078237265348, 24.088142439723015, 28.227486424148083, 26.454552859067917, 23.46846979111433, 25.698475129902363, 21.44160345196724, 17.178862988948822, 10.707499589771032, 5.943025974556804, 4.145300164818764, 0.7691690360661596, 0.21208235411904752, 0.07808617359842174, 0.03183502944011707, 0.029213765701570082, 0.01251227586180903, 0.004415582470755908, 0.04372701827378478, 0.040419677970930934, 0.03540598430845421, 0.027942231099586934, 0.06774872439564206, 0.03274907336162869, 0.02162124616006622, 0.015145826782827498, 0.08464084414299577, 0.04989821740309708, 0.02873154040571535, 0.026302576407033484, 0.06751317414455116, 0.04469429644814227, 0.008856284784997115, 0.023553563078166917, 0.02912490650487598, 0.042146102714468725, 0.030358643525687512, 0.025245982615160756, 0.03853698290186003, 0.05727338415454142, 0.027692450166796334, 0.06999988094321452, 0.046260973904281855, 0.05061548828962259, 0.07795017503667623, 0.05024510093790013, 0.04740607808344066, 0.003243457854296139, 0.025015310129674617, 0.044768763546017, 0.01843341946369037, 0.029567822093667928, 0.030229994081309997, 0.05898700313991867, 0.05616844129690435, 0.03052084917726461, 0.033481510035926476, 0.02796005006530322, 0.054033030100981705, 0.02786244836897822, 0.04810197511687875, 0.040097749151755124, 0.02460183182847686, 0.06760197211406194, 0.05609501320577692, 0.05804800821351819, 0.08261473645688966, 0.06561748406966217, 0.038950336893321946, 0.018424213121761568, 0.028722976021526847, 0.030486704818031285, 0.07502759006456472, 0.008595644376327982, 0.04181193588010501, 0.027996040516882204, 0.04334716853918508, 0.04532746344921179, 0.06257001790800132, 0.03657018765807152, 0.06696109048789367, 0.0584527755563613, 0.17535940278321505, 0.17189575504744425, 0.1709467262844555, 0.15545332484180108, 0.10677290498279035, 0.24340940202819183, 0.12719358812319115, 0.09728079166961834, 0.11685789038892835, 0.08399999220273457, 0.2192473891773261, 0.1501248381100595, 0.19153795496094972, 0.09150429264991544, 0.1270555189694278, 0.1840843283571303, 0.0965559360338375, 0.08294770843349397, 0.188793181150686, 0.2745554846478626, 0.07878988544689491, 0.1915013077086769, 0.10735754665802233, 0.18445690133376047, 0.05311188753694296, 0.07950281476951204, 0.14664115238701925, 0.1595329403062351, 0.13641140365507454, 0.13175773696275428, 0.13158818590454757, 0.15213754260912538, 0.09922875862685032, 0.22503576998133212, 0.2142649659072049, 0.1027796309790574, 0.10521741540287621, 0.10587457232759334, 0.11640736964181997, 0.15308568079490215, 0.15787562064360827, 0.06993340677581728, 0.2633111161412671, 0.1347428627195768, 0.12446254404494539, 0.1398976126802154, 0.13948040694231167, 0.07808569862390868, 0.14598896785173565, 0.11474786064354703, 0.24881394405383617, 0.16228578868322074, 0.12130554430768825, 0.2658597403205931, 0.0879657844780013, 0.17026965011609718, 0.1378617383306846, 0.15869631723035127, 0.10655296209733933, 0.1303564730915241, 0.206221406115219, 0.2726949501084164, 0.07804466527886689, 0.2176194585626945, 0.09608090214896947, 0.15832567383768037, 0.10225859878119081, 0.13585090404376388, 0.2003518195124343, 0.11053168258513324, 0.10533873428357765, 0.11505729911732487, 0.14049988036276773, 0.14047939708689228, 0.18939475121442229, 0.10993392716045491, 0.18598004069644958, 0.21148845786228776, 0.5294436402618885, 1.2819929025135934, 1.7043993738479912, 4.038225235417485, 5.071242079138756, 8.632683623582125, 8.216949831694365, 11.069737002253532, 13.480588886886835, 14.864993300288916, 15.066231451928616, 17.524477243423462, 22.009634971618652, 20.71424838155508, 21.4302933588624, 22.18156434595585, 18.082520999014378, 26.28717564046383, 30.660463571548462, 30.720715038478374, 26.594748236238956, 28.616819232702255, 23.37788835167885, 19.77824840694666, 13.917378298938274, 7.625529617071152, 4.531580787152052, 1.221673870459199, 0.4132825671695173, 0.1394725253339857, 0.11685656194458716, 0.08951200463343412, 0.11490699194837362, 0.11734399711713195, 0.15219728549709544, 0.08064664245466702, 0.1340338445152156, 0.10788194078486413, 0.20547752181300893, 0.12090084375813603, 0.21433639019960538, 0.21936092292889953, 0.17925156658748165, 0.15044623258290812, 0.11846843248349614, 0.16413698700489476, 0.17629633453907445, 0.08521194904460572, 0.12989957729587331, 0.16830704058520496, 0.11534463643329218, 0.09819978571613319, 0.15234362217597663, 0.11216175800655037, 0.15536732476903126, 0.14760728023247793, 0.10175166738918051, 0.24631210486404598, 0.10717483732150868, 0.15067807951709256, 0.1314233845914714, 0.11679001356242225, 0.14296293491497636, 0.09968394006136805, 0.16324439115123823, 0.1250596166937612, 0.14191717462381348, 0.07463673056918196, 0.13406318903435022, 0.13980229123262689, 0.17798179644159973, 0.1160365629766602, 0.20216313481796533, 0.0985417896299623, 0.1439123644377105, 0.1440455502597615, 0.10784627316752449, 0.07608975181938149, 0.14025359123479575, 0.22500134917208925, 0.11747461510822177, 0.17557763872900978, 0.12477874348405749, 0.15253715944709256, 0.17247829644475132, 0.07973922591190785, 0.1636335882358253, 0.17273007746553048, 0.15170740865869448, 0.12088323259376921, 0.16185197368031368, 0.07668903606827371, 0.2146983504644595, 0.1634132445906289, 0.1409267637063749, 0.11744409057428129, 0.12187340602395125, 0.20055622182553634], [0.008255114553321619, 0.023032870412862394, 0.07513368749641813, 0.0658394604397472, 0.06185018290125299, 0.07881249868660234, 0.04356273275334388, 0.029029855941189453, 0.01294440155106713, 0.06323288936982863, 0.03683003211335745, 0.03911048494046554, 0.0244829527582624, 0.03692214748298284, 0.027790636304416694, 0.0720123182691168, 0.044773212721338496, 0.049529511015862226, 0.03135321232548449, 0.009892941707221325, 0.029598044202430174, 0.05679463953129016, 0.02905500732595101, 0.05235721240751445, 0.013482341728376923, 0.025924476285581477, 0.043899022130062804, 0.02209378271800233, 0.025725781088112853, 0.0063971436702559, 0.04031843047414441, 0.04646775108994916, 0.04993268274120055, 0.02758421906037256, 0.030104702855169307, 0.031157270495896228, 0.037739437611890025, 0.06110300346335862, 0.04473985689401161, 0.03030600113561377, 0.018059742542391177, 0.07991564925760031, 0.005974053165118676, 0.026944589808408637, 0.019355762451596092, 0.043232499301666394, 0.029031592566752806, 0.027377564329071902, 0.021937017008895054, 0.0337352466158336, 0.05293007990985643, 0.06798436370445415, 0.06277453154325485, 0.06041972665116191, 0.021880558124394156, 0.04745054757222533, 0.06864399940241128, 0.05550713205593638, 0.017591755349712912, 0.04285769617126789, 0.028451858343032654, 0.03270499350037426, 0.029117956291884184, 0.05631276304484345, 0.04903802000626456, 0.033839919124147855, 0.044694237076328136, 0.05002306148526259, 0.009704605963634094, 0.047449300764128566, 0.011630148001131602, 0.015025711109046824, 0.022222664083528798, 0.020967031850886997, 0.03925277691450901, 0.026089748862432316, 0.025940011291822884, 0.014368218362506013, 0.04901310610875953, 0.04369406320620328, 0.01771417631971417, 0.05395730877353344, 0.2535733667900786, 0.24155014398274943, 0.3179301571799442, 0.4658750700764358, 0.6497955915983766, 1.0613827966153622, 1.1910585570149124, 0.8896104607265443, 1.656991217751056, 1.5708458027802408, 1.8901970540173352, 2.7131629502400756, 1.3840385642834008, 3.7038633646443486, 4.287398289889097, 5.424545221030712, 4.545307075604796, 3.628573017194867, 2.7683939365670085, 1.5969967120327055, 1.2229035794734955, 0.2923185518011451, 0.05660692440869752, 0.06682273931801319, 0.027451712303445674, 0.053545401970040984, 0.025617167775635608, 0.03206131768820342, 0.052836235336144455, 0.026602125763020013, 0.04274173188605346, 0.008572524620831246, 0.04365252891147975, 0.0673011202889029, 0.033571098392712884, 0.006562188500538468, 0.017328294779872522, 0.07659474620595574, 0.05349916245904751, 0.08299939901917242, 0.04654055206628982, 0.02445589405397186, 0.015589422364428174, 0.046197546253097244, 0.04362604537163861, 0.03943576455640141, 0.09062368248123676, 0.03475029312539846, 0.034874654811574146, 0.046366908063646406, 0.019468138452793937, 0.038988709638942964, 0.024732509191380814, 0.038817410822957754, 0.06866990035632625, 0.04998770928068552, 0.013471754064084962, 0.08402141800615937, 0.026357855276728515, 0.03683713817736134, 0.04091092407179531, 0.019643109044409357, 0.0147849212953588, 0.016787812746770214, 0.026481461827643216, 0.011957108581555076, 0.016005375728127547, 0.010953461460303515, 0.03702775138663128, 0.023776342823111918, 0.03416156963794492, 0.03236172051401809, 0.00834608979857876, 0.0035868161876351223, 0.0668644331744872, 0.03587945597246289, 0.0392397448013071, 0.0598530635033967, 0.0055347606485156575, 0.08122015933622606, 0.0840784891624935, 0.04154965718043968, 0.02650922742759576, 0.08323066707816906, 0.11435357984737493, 0.09471098659560084, 0.004631359124687151, 0.03530375717673451, 0.02760113260592334, 0.017093529349949677, 0.07087292862706818, 0.009169203003693838, 0.07846653170417994, 0.059821789400302805, 0.0709900246874895, 0.015195060859696241, 0.013855197648808826, 0.034723609205684625, 0.01935565669555217, 0.02251804071420338, 0.021874463236599695, 0.043090166509500705, 0.052676480627269484, 0.03709035525389481, 0.044515776535263285, 0.039308779378188774, 0.0269833948550513, 0.03302177552541252, 0.016534760798094794, 0.017780973321350757, 0.05177853017812595, 0.019649593559734058, 0.014340049219754292, 0.057407668355153874, 0.062048911495367065, 0.006501307343569351, 0.07518378246459179, 0.011507329982123338, 0.044456193209043704, 0.02932223243988119, 0.013282445179356728, 0.017548506693856325, 0.027737765703932382, 0.04408512308145873, 0.006780757021260797, 0.03630883293226361, 0.05970002523099538, 0.05753046782047022, 0.02499900514521869, 0.07216724901809357, 0.011801992295659147, 0.009598233009455726, 0.06575302992132492, 0.02321372438018443, 0.02538289216317935, 0.03398952496354468, 0.016444734574179165, 0.0033607253044465324, 0.012895927247882355, 0.041219527629436925, 0.04630605937563814, 0.015619444093317725, 0.11926258986932226, 0.012905432304251008, 0.08174770759069361, 0.02656818920513615, 0.07274576055351645, 0.04121948681131471, 0.014871704333927482, 0.02570805860159453, 0.08720210709725507, 0.011376109923730837, 0.11196010163985193, 0.05872658352018334, 0.006649091210420011, 0.0664853367197793, 0.016636049113003537, 0.010920456297753844, 0.0536043136526132, 0.036931865906808525, 0.03416214109165594, 0.016624464187771082, 0.0021626259831464267, 0.043876564741367474, 0.07046286977129057, 0.06609527874388732, 0.007461381119355792, 0.03917629488569219, 0.012405311972543132, 0.03163624889566563, 0.026100430222868454, 0.07487181326723658, 0.08010175020899624, 0.022072685314924456, 0.02907454992964631, 0.06181919452501461, 0.2919235808076337, 0.3697030321927741, 0.7580616977065802, 0.9755085920915008, 1.207275374326855, 1.9740079692564905, 1.894804306793958, 1.6391867981292307, 2.8290773928165436, 2.660555960610509, 3.121658368036151, 4.197400594130158, 2.178131709806621, 5.0278617069125175, 6.508688321337104, 6.72353021800518, 5.962775414809585, 5.083318306133151, 3.2103223353624344, 2.0088897412642837, 1.4150154520757496, 0.3075081476708874, 0.06467405110015534, 0.034389735519653186, 0.02682410027773585, 0.047531719974358566, 0.06053018420061562, 0.07304825994651765, 0.02246580279461341, 0.03903118646121584, 0.06007383759424556, 0.008612899309810018, 0.019531927900970913, 0.03109023044089554, 0.0240342057441012, 0.022889400279382244, 0.01445459785827552, 0.0433166662696749, 0.04764331300975755, 0.014383398065547226, 0.03596536327677313, 0.052913318504579365, 0.058367239325889386, 0.04357601348601747, 0.04231605453242082, 0.07305902108782902, 0.07720501424046233, 0.003721283837876399, 0.047362703262479044, 0.06435764385969378, 0.05122586393554229, 0.05320614029187709, 0.045789676732965745, 0.016350266596418805, 0.049350601475453004, 0.07885843020631, 0.04749817861011252, 0.041725779956323095, 0.011986395584244747, 0.03174624260282144, 0.03284364524006378, 0.06736999159329571, 0.03784171298320871, 0.07118016292224638, 0.0408697385864798, 0.04672934330301359, 0.047789052259759046, 0.011067210434703156, 0.01750173654727405, 0.02464873370627174, 0.03407815223908983, 0.023819159177946858, 0.10687447531381622, 0.02079784815578023, 0.03772626077989116, 0.03443208617682103, 0.012354573191259988, 0.06994574127020314, 0.025567024567862973, 0.04538789282378275, 0.05300008298945613, 0.013736928995058406, 0.028104542507207952, 0.012875981101387879, 0.07718490203842521, 0.04980206475011073, 0.015429564682563068, 0.00819177039375063, 0.03810950955084991, 0.01483988567997585, 0.022007951483828947, 0.03289559557742905, 0.025391538183612283, 0.06452329122112133, 0.13803954207105562, 0.1553342695115134, 0.11591197122470476, 0.10750765344710089, 0.13269189308630303, 0.10680941864848137, 0.1566084925434552, 0.15429294726345688, 0.11589721732889302, 0.11573875395697542, 0.15219369350234047, 0.12656856619287282, 0.10637454979587346, 0.09338472416857257, 0.1081430802878458, 0.16702149237971753, 0.1265883815358393, 0.2069988354924135, 0.09750058612553403, 0.14806257298914716, 0.11406933728721924, 0.1031578442780301, 0.17288058501435444, 0.12682748667430133, 0.20323231728980318, 0.13119216106133536, 0.09117935071117245, 0.07993655555765145, 0.1124667955446057, 0.10019127221312374, 0.114132776070619, 0.21152132016140968, 0.2562114642933011, 0.1183982624206692, 0.11173244041856378, 0.1975986297475174, 0.09894716553390026, 0.10183017919189297, 0.09777493585716002, 0.17587243462912738, 0.1059717194584664, 0.24942235671915114, 0.07883139376644976, 0.18406381539534777, 0.07970056743943132, 0.1525744004175067, 0.10756147399661131, 0.17647740372922271, 0.18723186571151018, 0.07194671241450123, 0.17729433020576835, 0.17234712926438078, 0.10742048078100197, 0.19388231041375548, 0.19956380710937083, 0.1497058809036389, 0.1056133140809834, 0.096406875672983, 0.1260602692491375, 0.19951838767156005, 0.10625738694216125, 0.14545521524269134, 0.09793596706003882, 0.13630089786602184, 0.17162824049592018, 0.2803970774402842, 0.11304817177006043, 0.11175726525834762, 0.10491075256140903, 0.20661642163759097, 0.22235821990761906, 0.11675327725242823, 0.13915956165874377, 0.16915760119445622, 0.12910423247376457, 0.10614907048875466, 0.1339140915661119, 0.15767249482451007, 0.1539898689952679, 0.09469180949963629, 0.11862939689308405, 0.20330185652710497, 0.32663985388353467, 0.3155530878575519, 0.7379068073350936, 1.035596786532551, 1.099250614643097, 1.740611786954105, 1.8008176563307643, 1.9074385100975633, 2.7510929899290204, 2.8263377398252487, 3.2157045090571046, 4.732845537364483, 2.8745699767023325, 5.98098118789494, 6.825784156098962, 7.607543282210827, 6.180347939953208, 5.513918800279498, 4.230158636346459, 2.6364887645468116, 1.897059960756451, 0.4818159865681082, 0.2297840901883319, 0.1709807018050924, 0.10274144005961716, 0.11726481738151051, 0.15814543585292995, 0.14293471846031025, 0.12551707652164623, 0.14458403777098283, 0.12403699656715617, 0.07555605858215131, 0.10212952445726842, 0.17156138783320785, 0.13673302077222615, 0.10631643221131526, 0.10817511138156988, 0.15274387726094574, 0.2638345677405596, 0.1658515410963446, 0.12153689400292933, 0.11599879508139566, 0.0874166471476201, 0.1023521093884483, 0.08489770887535997, 0.18243699800223112, 0.1606139526120387, 0.07511411706218496, 0.08538201960618608, 0.09701960763777606, 0.09295718773500994, 0.13874477532226592, 0.10960322615574114, 0.16397199273342267, 0.1631227383040823, 0.12821947369957343, 0.09767938434379175, 0.15940155048156157, 0.0875790958525613, 0.092253245820757, 0.15463734831428155, 0.08808702914393507, 0.11581791884964332, 0.09620730474125594, 0.1713092951104045, 0.15168606449151412, 0.08572224236559123, 0.0955331748991739, 0.08086116766207851, 0.1734558236785233, 0.14452000526944175, 0.09362596669234335, 0.17441982898162678, 0.12317334447288886, 0.06036154227331281, 0.12233751549501903, 0.1469300259486772, 0.15582793130306527, 0.12751060392474756, 0.2157271304167807, 0.24393040454015136, 0.14780915924347937, 0.11903254635399207, 0.1708800665801391, 0.11157557266415097, 0.18499941128538921, 0.07051694265101105, 0.1642268759314902, 0.1296520562027581, 0.1319574043736793, 0.10922253408352844, 0.1778417531750165, 0.18106332718161866, 0.19621701794676483], [0.012761077159666456, 0.04734026442747563, 0.11046066647395492, 0.06790725456085056, 0.02152375764126191, 0.016519188684469555, 0.00943287323025288, 0.017858407154562883, 0.080416784476256, 0.06314037324045785, 0.009619636548450217, 0.03910169791197404, 0.006863552871436696, 0.019904962864529807, 0.03149180469335988, 0.06989175744820386, 0.03840508470602799, 0.026868538225244265, 0.01898648089991184, 0.02719522421102738, 0.018445924652041867, 0.03404395407414995, 0.020647112396545708, 0.018974606537085492, 0.01480479786550859, 0.005163942851140746, 0.0320098423253512, 0.033516669282107614, 0.07441781926900148, 0.03323567732877564, 0.020926948454871308, 0.06738030002452433, 0.013949221265647793, 0.05003476144338492, 0.03826105239568278, 0.021850983539479785, 0.058750228345161304, 0.05559303936024662, 0.021151947221369483, 0.04407763481140137, 0.009746283121785382, 0.041436924948357046, 0.09974021711968817, 0.010660532989277272, 0.012133734162489418, 0.05493841315910686, 0.027362684268155135, 0.013917082560510607, 0.04497984147747047, 0.03913831176760141, 0.04782667172548827, 0.048475520306965336, 0.0509269936446799, 0.0015541989387202193, 0.05581072982749902, 0.03302064746094402, 0.05169215532077942, 0.07533665004302748, 0.06868610144010745, 0.02405962615739554, 0.043253821204416454, 0.08816055371426046, 0.030689472550875507, 0.016785922125563957, 0.051326154061825946, 0.021086437845951878, 0.037387704142020084, 0.030055047609494068, 0.05098546746012289, 0.049485442286822945, 0.0629080661747139, 0.03882605684339069, 0.07782118234899826, 0.031987147449399345, 0.09148052908130921, 0.039279126867768355, 0.036957087795599364, 0.07173041347414255, 0.0405635655624792, 0.06406844375305809, 0.04079872618603986, 0.04441474797204137, 0.11300948361167684, 0.03838682045170572, 0.03711378485604655, 0.03908577513357159, 0.03769050039409194, 0.0036212469694874017, 0.016650205579935573, 0.05373115411202889, 0.04312906246923376, 0.09942706790752709, 0.05025887890951708, 0.1247259322553873, 0.08578400389524177, 0.044285194962867536, 0.22103703377069905, 0.2506816032109782, 0.19165822741342708, 0.06304651382379234, 0.0179817001480842, 0.017707203842292074, 0.04141837125644088, 0.04165755060967058, 0.03762140273465775, 0.04616342601366341, 0.03820236706815194, 0.008833474876155378, 0.04265077426680364, 0.09059116899152286, 0.021347679394239094, 0.04028415809443686, 0.020051832034369, 0.05760275300417561, 0.055285159396589734, 0.03958685840188991, 0.02886973201384535, 0.05002019679523073, 0.04582684348861221, 0.013748802430200158, 0.014940595119696809, 0.060543557701748796, 0.08219928218750283, 0.04724358113890048, 0.05158581298019271, 0.012818325503758388, 0.07943830729345791, 0.029122307132638525, 0.03581258475605864, 0.08820662624202669, 0.02677693308214657, 0.041274509640061297, 0.03401084686629474, 0.07704919291427359, 0.04522156639723107, 0.0589343885803828, 0.028680582690867595, 0.01471104698794079, 0.015806272349436767, 0.047631201159674674, 0.019223040471842978, 0.050515161055955105, 0.022171515265654307, 0.0117854924974381, 0.02775159191514831, 0.025909449650498573, 0.0595337878621649, 0.03566718318325002, 0.040673555558896624, 0.05173257639398798, 0.030008581743459217, 0.013254712976049632, 0.042796446723514237, 0.04517179055255838, 0.016683014073350932, 0.0437181384768337, 0.06571909150807187, 0.029015756990702357, 0.03225334468879737, 0.01886418423964642, 0.04005188442533836, 0.009160585741483374, 0.03431959885347169, 0.05361610266845673, 0.0402499562187586, 0.03383486138773151, 0.036751650186488405, 0.03040280131244799, 0.0535783533268841, 0.006473480516433483, 0.056306766491616145, 0.05909573890676256, 0.0018948777710647846, 0.03573156449419912, 0.09217621089192107, 0.0955393495678436, 0.05993219128868077, 0.07136744388844818, 0.11864180560223758, 0.0689122783660423, 0.04308251867769286, 0.008251131075667217, 0.07415448300889693, 0.0503721454879269, 0.12471399852074683, 0.06136243973742239, 0.026589405351842288, 0.01992301560676424, 0.012237881601322442, 0.025561538241163362, 0.04935113211104181, 0.062415161373792216, 0.029983473032189067, 0.03770307608647272, 0.05975654719804879, 0.012897770557174226, 0.018690586621232796, 0.04743887358927168, 0.04201524723612238, 0.021904748427914456, 0.02631999275763519, 0.021790335231344216, 0.011411962150305044, 0.06595185128389858, 0.04055559118569363, 0.023006147530395538, 0.006007634883644641, 0.01684868555457797, 0.02893468477850547, 0.04097276723769028, 0.03328197250084486, 0.03655705164419487, 0.015231382494675927, 0.036574636833393015, 0.029308669691090472, 0.03901007235981524, 0.047114907574723475, 0.009868078832369065, 0.07946071273181587, 0.005879231275685015, 0.005386716566135874, 0.012423383268469479, 0.018207194298156537, 0.042525421813479625, 0.03195670826244168, 0.01565781498356955, 0.0685827796405647, 0.030813418634352274, 0.048467037559021264, 0.03547361251548864, 0.08770010303123854, 0.013000874350836966, 0.04143658356042579, 0.09449980847421102, 0.042251702907378785, 0.04737269257020671, 0.01352374893031083, 0.04583302928949706, 0.049080129465437494, 0.026103806994797196, 0.07825029955711216, 0.03252805065130815, 0.038770774262957275, 0.06016846884449478, 0.03020888183527859, 0.04336345868068747, 0.11373896282748319, 0.06366507164784707, 0.039521011349279433, 0.029303856863407418, 0.06481071759480983, 0.030994597291282844, 0.050778586373780854, 0.05229981099546421, 0.013487797441484872, 0.03310721156594809, 0.0845951797964517, 0.0257866112224292, 0.04507933379500173, 0.055550284232595004, 0.040800306960591115, 0.06783853910746984, 0.01681120524153812, 0.0514152897085296, 0.01684510469203815, 0.02844755945261568, 0.06418345437850803, 0.09793843099032529, 0.042187896760879084, 0.11373294400982559, 0.21012810117099434, 0.11205470320419408, 0.38978097669314593, 0.2873364253900945, 0.3503993258345872, 0.05736725841416046, 0.1314085119520314, 0.0379512242943747, 0.05694416002370417, 0.040468403676641174, 0.13993918779306114, 0.010094143508467823, 0.03058061804040335, 0.01731354459479917, 0.09043883575941436, 0.1096503970620688, 0.01739220297167776, 0.10748584172688425, 0.03543812672432978, 0.010640634154697182, 0.019740790521609597, 0.04873029960435815, 0.030457386274065357, 0.01619880353246117, 0.014394280733540654, 0.012195662675367203, 0.007372351228696061, 0.0224159861318185, 0.08468889820505865, 0.040568853364675306, 0.05502599029568955, 0.02904928165662568, 0.002472408859830466, 0.027232069987803698, 0.07317605035495944, 0.04428502426890191, 0.02769966569758253, 0.02727672315813834, 0.04794319633219857, 0.05895361020520795, 0.016393611731473356, 0.043069865059806034, 0.04359166538051795, 0.03383265349839348, 0.0731563389126677, 0.010250838713545818, 0.016907736389839556, 0.0337452952953754, 0.027128701804031152, 0.027462005891720764, 0.032780685141915455, 0.047411258274223655, 0.033725988323567435, 0.05213197058765218, 0.02927185174485203, 0.041635557063273154, 0.07352882283157669, 0.013868688965885667, 0.01232676399013144, 0.09818065314902924, 0.04975969553925097, 0.05246044886007439, 0.047195879596984014, 0.03732425051566679, 0.029250286788737867, 0.012192277554277098, 0.03254746523452923, 0.048328011034755036, 0.053128960644244216, 0.02585654379799962, 0.051930087865912355, 0.0852696287620347, 0.028715190892398823, 0.048767967309686355, 0.039462704517063685, 0.0334483063488733, 0.07242587264045142, 0.017251282115466893, 0.03294149741122965, 0.04936178935167845, 0.036319197024567984, 0.0514139167353278, 0.09905176382744685, 0.13979844690766186, 0.20661112270317972, 0.23139075085055083, 0.14015485590789467, 0.14050740574020892, 0.19959899975219741, 0.10827998426975682, 0.199361749982927, 0.21964742161799222, 0.09746884446940385, 0.0938571679580491, 0.11944093537749723, 0.07597726449603215, 0.12952267017681152, 0.11510398020618595, 0.16184005478862673, 0.13177927408833057, 0.07193140190793201, 0.0828004811774008, 0.09195174090564251, 0.138405213074293, 0.08518198112142272, 0.08449527929769829, 0.0906965316971764, 0.1357208946137689, 0.08939453749917448, 0.14387556875590235, 0.18496349133783951, 0.09092909109313041, 0.1094881932658609, 0.17250973382033408, 0.14838981558568776, 0.0917636658414267, 0.19885769812390208, 0.1188273350999225, 0.1536226543248631, 0.12867441022535786, 0.19583436660468578, 0.14586927427444607, 0.1354673769674264, 0.12349027863820083, 0.17726874095387757, 0.1254757834249176, 0.1828690170077607, 0.17895883385790512, 0.14134879340417683, 0.14580029906937853, 0.17922542814631015, 0.14751696086023003, 0.14242306700907648, 0.13034152623731643, 0.1311296276981011, 0.06735551229212433, 0.14077066036406904, 0.21693672722904012, 0.16893868247279897, 0.20486220717430115, 0.1561321524786763, 0.13084523670841008, 0.1825885594007559, 0.18281982745975256, 0.1605583805940114, 0.17706435348372906, 0.159910797374323, 0.08345585694769397, 0.15883403015322983, 0.13784192298771814, 0.09691706509329379, 0.20242088270606473, 0.1711838721530512, 0.13250925054308027, 0.2290681700105779, 0.09909288623020984, 0.2106177553650923, 0.10536937013966963, 0.12356032253592275, 0.11481166307930835, 0.14931656507542357, 0.166481104970444, 0.17923915787832811, 0.16426931193564087, 0.21849467331776395, 0.127982446574606, 0.08288302284199744, 0.20150499825831503, 0.2503960841568187, 0.07988140656379983, 0.11002642844687216, 0.13788127165753394, 0.22129987279186025, 0.1377953903283924, 0.09484113703365438, 0.19089632376562804, 0.22744289628462866, 0.18296868744073436, 0.43025518767535686, 0.445003918139264, 0.4468071588780731, 0.3201674949377775, 0.319126617978327, 0.12245591773535125, 0.24678759888047352, 0.12380431100609712, 0.4459129006136209, 0.1304773095762357, 0.13608871784526855, 0.09991897823056206, 0.193552871060092, 0.22818309953436255, 0.195335776952561, 0.1725576468743384, 0.09461116773309186, 0.11612293412326835, 0.11846720051835291, 0.17279461462749168, 0.11123384334496222, 0.10208044623141177, 0.11742836446501315, 0.07184186921222135, 0.13432145642582327, 0.1822232297854498, 0.22266324260272086, 0.178923626372125, 0.16437128302641213, 0.07731683363090269, 0.10583547598798759, 0.17162898264359683, 0.2408969946554862, 0.20372295111883432, 0.15894870681222528, 0.09209401061525568, 0.133134450588841, 0.2107119932770729, 0.12464171333704144, 0.09761486202478409, 0.08550460013793781, 0.1663200292387046, 0.14588000572985038, 0.0828126523992978, 0.08014195977011696, 0.14079620508709922, 0.16057487111538649, 0.1131448958767578, 0.08028461539652199, 0.1989868763484992, 0.13709015707718208, 0.1649303428712301, 0.09532725118333474, 0.13972656248370185, 0.0981464252981823, 0.10717526776716113, 0.06791167033952661, 0.1590183944790624, 0.09756695639225654, 0.26882277976255864, 0.1772361755138263, 0.08582993541494943, 0.11696953166392632, 0.2131530357291922, 0.11098495670012198, 0.12974366691196337, 0.10138071971596219, 0.1238780804851558, 0.18034786713542417, 0.260337894433178, 0.17480601294664666, 0.07972168896230869, 0.13355811301153153, 0.12663623521802947, 0.24895909329643473, 0.14112350705545396, 0.10377015321864747, 0.12152950221206993, 0.1277280383510515, 0.17662663478404284], [0.05209019138419535, 0.051289406619616784, 0.019604884728323668, 0.04056993318954483, 0.13126037927577272, 0.07278173987288028, 0.02352046885789605, 0.0334701292013051, 0.02193806714785751, 0.047829996547079645, 0.04840546898776665, 0.050345584022579715, 0.051159890717826784, 0.016717869038984645, 0.09556709846947342, 0.028685885336017236, 0.07044407117064111, 0.03341631978400983, 0.03560571109119337, 0.07600300959893502, 0.019326352994539775, 0.03195408848114312, 0.031054295650392305, 0.07023157202638686, 0.05776837067969609, 0.027604618844634388, 0.03549253357050475, 0.0691181501315441, 0.057908024318749085, 0.02661946418811567, 0.05996761399728712, 0.025463524652877823, 0.02759249029622879, 0.03574810325517319, 0.007039418214844773, 0.04639179969672114, 0.02089742210955592, 0.03816745644144248, 0.017179618480440695, 0.029234605208330322, 0.09898661068291403, 0.03640934570285026, 0.1323147484799847, 0.0397930641338462, 0.05222134001087397, 0.05608225197647698, 0.028905102772114333, 0.07726089053903706, 0.03164932182698976, 0.071532542060595, 0.013250978117866907, 0.010006874363170937, 0.041982859911513515, 0.0399380278395256, 0.014523311456287047, 0.014110139291005908, 0.029156804012018256, 0.034901598482974805, 0.013880011356377508, 0.07470215830835514, 0.060072375563322566, 0.051257598170195706, 0.021719165124522988, 0.025335754653497133, 0.06006053830788005, 0.050728083224385045, 0.02809643639920978, 0.010989073416567408, 0.030877818498993292, 0.0038563670068469946, 0.038702322272001766, 0.05515034827112686, 0.03386814671102911, 0.025242299707315397, 0.0253302293640445, 0.06089335787692107, 0.013216419083619257, 0.009159985529549886, 0.10773875081213191, 0.025802797463256866, 0.08142898484948091, 0.05271924688713625, 0.04593982805090491, 0.07431974445353262, 0.014555941834260011, 0.01583660392498132, 0.016949944183579646, 0.01676106945524225, 0.06355266596074216, 0.03026915164809907, 0.038134260175866075, 0.10918739339103922, 0.0771937558602076, 0.019338537204021122, 0.04046295631269459, 0.044803945056628436, 0.0216905683191726, 0.014924998886272078, 0.06458224001107737, 0.030410009421757422, 0.0406514506903477, 0.038061882223701105, 0.023546115626231767, 0.08282566966954619, 0.05203998138313182, 0.048867771329241805, 0.03387583165022079, 0.08871654106769711, 0.03746069436601829, 0.04611359821865335, 0.021671239082934335, 0.05827404784213286, 0.0034156555966546875, 0.018314742628717795, 0.021761129864898976, 0.05774997283879202, 0.053584787747240625, 0.004605329686455661, 0.02403293110546656, 0.05499356957443524, 0.07842215869459324, 0.0870060762099456, 0.021042357984697446, 0.05857366770214867, 0.05429057389847003, 0.022343433774949517, 0.012521174212452024, 0.031249935054802336, 0.044277161214267835, 0.0783827506529633, 0.02188798702263739, 0.03988195116107818, 0.042573550090310164, 0.1554686576128006, 0.0036390944615050103, 0.01070429929313832, 0.06156118688522838, 0.029119470273144543, 0.01642889157665195, 0.08893851743778214, 0.07097190886270255, 0.0295812401236617, 0.068210763274692, 0.04343864195107017, 0.04287155948986765, 0.018703392379393335, 0.02816475480358349, 0.04891606658929959, 0.07172772689955309, 0.029594307488878258, 0.05901485594222322, 0.027099119797640014, 0.018662145666894503, 0.035033559761359356, 0.05609597428701818, 0.04528158016910311, 0.05222369261900894, 0.037508006280404516, 0.048631234021740966, 0.019400094643060584, 0.01417411334841745, 0.06253681422094814, 0.030394934547075536, 0.04882543551502749, 0.038180507108336315, 0.019327100708323997, 0.03284597929450683, 0.023315608268603683, 0.03301741540781222, 0.11413017855375074, 0.06256968394154683, 0.06064591099857353, 0.06474917128798552, 0.02039134418737376, 0.11525150432134978, 0.08977539284387603, 0.04956953875080217, 0.05447855619422626, 0.0215938293695217, 0.015064939179865178, 0.08743678161408752, 0.04063229585881345, 0.027725557374651544, 0.015402933640871197, 0.032578423924860545, 0.01074706462532049, 0.006117500570326229, 0.08667969450470991, 0.03380939830094576, 0.03322365082567558, 0.026445159674040042, 0.03061018891457934, 0.07915798327303492, 0.016721333013265394, 0.030813101366220508, 0.03716279999935068, 0.03464304536464624, 0.026112618143088184, 0.07620398318977095, 0.01972445399587741, 0.0060769347783207195, 0.04024560723337345, 0.05192973905650433, 0.06078294485632796, 0.029530740685004275, 0.0549362349556759, 0.05817894161737058, 0.025331830547656864, 0.03196106838004198, 0.06845156793133356, 0.007523312415287364, 0.02811865444527939, 0.08192762645194307, 0.05511353774636518, 0.015364059945568442, 0.12884097784990445, 0.047732864259160124, 0.04605970716511365, 0.03998086460342165, 0.016055834348662756, 0.04196083296847064, 0.054155751640792005, 0.019897348429367412, 0.04864649999944959, 0.02789712707453873, 0.01755896540998947, 0.043204980465816334, 0.02698961219721241, 0.030345693048730027, 0.03327015379909426, 0.0297032974413014, 0.023719349592283834, 0.025446004401601385, 0.012010417049168609, 0.03047452431928832, 0.06100117709138431, 0.037161783257033676, 0.0315425267763203, 0.04590925898810383, 0.034543682922958396, 0.053648627290385775, 0.04821455520868767, 0.05517849793250207, 0.05751691620389465, 0.05355041517759673, 0.029632793412019964, 0.038650932256132364, 0.05438071886601392, 0.05020461307140067, 0.02660802212631097, 0.09440551861189306, 0.061665473476750776, 0.01982275331101846, 0.06254714491660707, 0.04982838130672462, 0.045339334101299755, 0.030996009227237664, 0.053607957597705536, 0.04686645137553569, 0.0131894531477883, 0.0571328288060613, 0.01605799585377099, 0.02183217009587679, 0.025176550989272073, 0.09882916405331343, 0.03301033160823863, 0.03062000010686461, 0.06298155363765545, 0.01429611778803519, 0.0845149536326062, 0.029718116275034845, 0.04440939337655436, 0.011754139541153563, 0.00859779845995945, 0.07170141776441596, 0.03149688469420653, 0.02728080868109828, 0.007709819228693959, 0.02154243007680634, 0.014408607894438319, 0.07458665044396184, 0.007780509722579154, 0.04701793113781605, 0.09194886137265712, 0.0512887386867078, 0.05014544534788001, 0.016538237759959884, 0.051030456452281214, 0.030527372655342333, 0.03586309161619283, 0.05466130263812374, 0.01095327685106895, 0.04366545341326855, 0.015290639275917783, 0.03894497116561979, 0.028945223275513854, 0.09584799394360743, 0.054098569162306376, 0.008611850098532159, 0.03885808793711476, 0.040184977478929795, 0.037654736297554336, 0.024134681407304015, 0.023495657005696557, 0.03631449551903643, 0.048498411852051504, 0.012266526646271814, 0.0558267565065762, 0.0446943112910958, 0.10079288680572063, 0.07511933436035179, 0.04014611491584219, 0.06301009663729928, 0.07543075436842628, 0.04863658861722797, 0.061181400233181193, 0.050232261783094145, 0.025509834667900577, 0.034321383718634024, 0.04898635910649318, 0.05162635650776792, 0.020080436261196155, 0.036602890395442955, 0.012845517794630723, 0.005164889553270768, 0.05229780719673727, 0.02084066636598436, 0.008533311392966425, 0.050615722066140734, 0.022458086314145476, 0.024328252075065393, 0.04205882243695669, 0.034469534948584624, 0.03865259466692805, 0.06757046052371152, 0.029165316445869394, 0.035639556735986844, 0.067219031334389, 0.024597150732006412, 0.03822546641458757, 0.009208403243974317, 0.009689214748505037, 0.014438969155889936, 0.06066443871532101, 0.07664587275939994, 0.038205721575650387, 0.029953056109661702, 0.003715087832460995, 0.016526801264262758, 0.044469299537013285, 0.049831769210868515, 0.007503008182538906, 0.19112031877739355, 0.169491003616713, 0.14590911276172847, 0.15942320635076612, 0.20325412158854306, 0.11851152157760225, 0.07999740424565971, 0.10269038029946387, 0.11785590832005255, 0.16803183738375083, 0.2273872500518337, 0.2830997121054679, 0.19459734001429752, 0.12703395215794444, 0.17127864441135898, 0.14523297169944271, 0.30208948999643326, 0.1412733318284154, 0.10035093044280075, 0.11216054088436067, 0.11975490095210262, 0.08285439078463241, 0.1807555733830668, 0.15361281344667077, 0.1431904180208221, 0.11476890795165673, 0.08837792876875028, 0.19377367483684793, 0.15505743358517066, 0.15122228156542405, 0.1824993235641159, 0.06945233923033811, 0.128324294637423, 0.16606493823928759, 0.08263855939731002, 0.1941465149866417, 0.17581303312908858, 0.07437334235874005, 0.10685130546335131, 0.24249281996162608, 0.1311374202487059, 0.17832174460636452, 0.24080143572064117, 0.19540219916962087, 0.11459698944236152, 0.20846154919127002, 0.15007732581580058, 0.17500308284070343, 0.1339681347599253, 0.13779785425867885, 0.08035163875319995, 0.07625997823197395, 0.14637489948654547, 0.08883173723006621, 0.12920166162075475, 0.13114769157255068, 0.1455684521351941, 0.14843594748526812, 0.10689686590922065, 0.17484129464719445, 0.10445932639413513, 0.13712610671063885, 0.18672978796530515, 0.2021292335120961, 0.13305263622896746, 0.13285473512951285, 0.20035305147757754, 0.20935810811351985, 0.10718396573793143, 0.22693879989674315, 0.11861999388202094, 0.17707916675135493, 0.13296216842718422, 0.09763974623638205, 0.18690863071242347, 0.1489375502569601, 0.13818822393659502, 0.10683466651244089, 0.16558638657443225, 0.10490464468603022, 0.17563139990670606, 0.10292786013451405, 0.12523314566351473, 0.13207010691985488, 0.1267620292492211, 0.08921478191041388, 0.11967521655606106, 0.0949963201128412, 0.1425329048652202, 0.12798716663382947, 0.14311246282886714, 0.24797136895358562, 0.13436435256153345, 0.2332561687217094, 0.1646080132923089, 0.1678632659604773, 0.09612527515855618, 0.14670307718915865, 0.1427998999133706, 0.10166085077798925, 0.14546683727530763, 0.12876539753051475, 0.08832318795612082, 0.10783249890664592, 0.12203136473544873, 0.1740142155904323, 0.14543366327416152, 0.232033510110341, 0.13767336640739813, 0.11809031566372141, 0.0982712471159175, 0.1337228697957471, 0.12182025340734981, 0.19754154374822974, 0.09235677542164922, 0.13287137408042327, 0.19753199972910807, 0.18258939060615376, 0.10818268870934844, 0.11226896123844199, 0.21033069264376536, 0.18241660378407687, 0.08892978978110477, 0.12219818469020538, 0.15410184423672035, 0.17617621051613241, 0.1431257918011397, 0.08682069514179602, 0.13040449004620314, 0.12257138107088394, 0.15021355444332585, 0.15513066871790215, 0.1543158944696188, 0.3327184292720631, 0.1806463292450644, 0.11149009951623157, 0.16622478200588375, 0.14004077296704054, 0.17289330542553216, 0.18992495635757223, 0.1394918211735785, 0.12756555253872648, 0.14110804069787264, 0.06744685582816601, 0.18013081862591207, 0.06500872259493917, 0.11017604541848414, 0.2196738717611879, 0.17032753763487563, 0.12214031943585724, 0.1568212069105357, 0.1389736685086973, 0.20977074222173542, 0.1021748771017883, 0.11053911148337647, 0.10028433753177524, 0.22805513843195513, 0.17139915435109288, 0.16443780914414674, 0.07811355142621323, 0.13624415325466543, 0.11966170204686932, 0.14978089719079435, 0.20635698165278882, 0.16805938590550795, 0.11345197432092391, 0.15440924180438742, 0.19894012104487047, 0.12413148680934682, 0.14554274413967505, 0.10191567460424267, 0.10805629353853874, 0.13871520815882832, 0.10644792593666352, 0.16736191551899537, 0.21250338933896273], [0.03760015133593697, 0.0346644117962569, 0.032440406721434556, 0.016663861097185872, 0.05633368047710974, 0.03697623520565685, 0.020639935828512534, 0.045066004822729155, 0.01896405690786196, 0.04332566852099262, 0.044965948472963646, 0.01721826210996369, 0.04422093610628508, 0.037868723447900265, 0.043986881282762624, 0.021376621298259124, 0.030086785554885864, 0.057645448760013096, 0.03960934547649231, 0.03322150601889007, 0.013297961631906219, 0.01778199934051372, 0.06549957164679654, 0.03431533150433097, 0.036335138356662355, 0.04126959291170351, 0.0759817693324294, 0.02691861092898762, 0.034697170194704086, 0.03414620347029995, 0.025791503830987494, 0.04362515108368825, 0.03507634828565642, 0.039553728929604404, 0.02851987061148975, 0.011399945851735538, 0.06836752712843008, 0.028901902260258794, 0.03078042274864856, 0.055730581589159556, 0.008250362952821888, 0.04806031836778857, 0.0360105192521587, 0.0140716978967248, 0.0648305552022066, 0.04604271940479521, 0.00890238236024743, 0.031299269321607426, 0.09432308084797114, 0.04243584829964675, 0.040621824155095965, 0.06070354618714191, 0.049329383473377675, 0.02797780223772861, 0.10005144416936673, 0.07915618727565743, 0.027988318470306695, 0.06908115406986326, 0.06696362121147104, 0.061968959926161915, 0.036306754918769, 0.0009463826586397772, 0.049270546005573124, 0.03486157816951163, 0.008293516984849703, 0.03168157556501683, 0.0563176649302477, 0.03170548014168162, 0.04925263798213564, 0.07445505281793885, 0.04499705188209191, 0.01595798588823527, 0.02812322236422915, 0.03162425207847264, 0.03663313662400469, 0.049427640115027316, 0.04698544733400922, 0.046493930349242873, 0.10017582811997272, 0.06719529745168984, 0.07380087932688184, 0.012122675234422786, 0.016260626289295033, 0.02803953964757966, 0.06695855234283954, 0.06849569603218697, 0.040336627935175784, 0.03210836985090282, 0.0563047404284589, 0.05086699100502301, 0.08873125785612501, 0.032811358105391264, 0.029995896584296133, 0.034002920729108155, 0.035703374014701694, 0.01611810610484099, 0.08470381537335925, 0.058455625403439626, 0.04723415586340707, 0.07240473627462052, 0.025754825037438422, 0.024826316657708958, 0.03108755685389042, 0.009254907145077595, 0.03973763683461584, 0.06925726571353152, 0.018764639971777797, 0.0232916573077091, 0.03253059621783905, 0.053331826711655594, 0.021969910849293228, 0.07658840084332041, 0.007633824234289932, 0.06353290998958983, 0.037462998734554276, 0.025356783407914918, 0.03672616854601074, 0.03467841612291522, 0.0471406192809809, 0.002387810750406061, 0.017873354008770548, 0.0509998725465266, 0.015874505406827666, 0.02334154076379491, 0.05133496335474774, 0.013392804394243285, 0.04285483148123603, 0.05050627383752726, 0.031008989390102215, 0.022241518345254008, 0.006773257618988282, 0.01926029442984145, 0.024380729337281082, 0.021734366164309904, 0.008359137682418805, 0.025694842806842644, 0.042030427866848186, 0.00942728949667071, 0.07491338095860556, 0.030266990142990835, 0.05591618159087375, 0.023888926625659224, 0.025350951982545666, 0.04346250199887436, 0.020828252090723254, 0.030426524062932003, 0.006702121372654801, 0.023735190734441858, 0.04834193743590731, 0.05098996858578175, 0.018692705452849623, 0.05499738050275482, 0.07102794843376614, 0.08778345363680273, 0.03090059501118958, 0.05791043629869819, 0.04111806119908579, 0.07010532528511249, 0.06367413327097893, 0.001996650685214263, 0.020750840521941427, 0.009911724537232658, 0.040074764838209376, 0.04082342486071866, 0.06136459196568467, 0.04879530803009402, 0.033337511122226715, 0.03372917584783863, 0.040986727035488, 0.022662971023237333, 0.01394532684571459, 0.03254454117268324, 0.05820428967126645, 0.031228242078213952, 0.022146120827528648, 0.005578745885941316, 0.02222192008048296, 0.020597061957232654, 0.04324169451138005, 0.05064904449682217, 0.03808547880908009, 0.012652702262130333, 0.038061663290136494, 0.015067785316205118, 0.02338566329854075, 0.031289064791053534, 0.03124088456388563, 0.015858528822718654, 0.031027613586047664, 0.05609327658021357, 0.0674285767308902, 0.05037378563429229, 0.03177696380589623, 0.036811370810028166, 0.061067606729920954, 0.05352536398277152, 0.024007163738133386, 0.007063564453346771, 0.0621547380433185, 0.0830931322707329, 0.0588420097483322, 0.014643612666986883, 0.046810007333988324, 0.032403202858404256, 0.06997470729402266, 0.021913839736953378, 0.03439714215346612, 0.1031925693678204, 0.06563504328369163, 0.02239939356513787, 0.0557872742501786, 0.047785092901904136, 0.03250179346650839, 0.06776877722586505, 0.026311415385862347, 0.029548917736974545, 0.03464578388957307, 0.047041141806403175, 0.03334698092658073, 0.016843577723193448, 0.027434898947831243, 0.04024334739369806, 0.05937258596532047, 0.03301260629086755, 0.00834350898003322, 0.024599015378043987, 0.032473695755470544, 0.0497950996941654, 0.0161577646213118, 0.048598998837405816, 0.05551051996008027, 0.027735426083381753, 0.04494290849834215, 0.021119151715538464, 0.029977854974276852, 0.029578054454759695, 0.021835424413438886, 0.026224990433547646, 0.01828220130846603, 0.031215150593197905, 0.026347205457568634, 0.025255842047045007, 0.03556898962415289, 0.0637098379957024, 0.05208572736592032, 0.08953547876444645, 0.04760779382195324, 0.06132559210527688, 0.00786290342148277, 0.03543612292560283, 0.040043468470685184, 0.04668658075388521, 0.08239060043706559, 0.03241345562855713, 0.03409445351280738, 0.0443342472135555, 0.07356396352406591, 0.029039620749244932, 0.043990703343297355, 0.015586635599902365, 0.06436901356210001, 0.006723911756125744, 0.02167458245821763, 0.02392884489381686, 0.035772768533206545, 0.06161697041534353, 0.15170788363320753, 0.03480560168100055, 0.056116286868928, 0.08807657228317112, 0.009034008744492894, 0.021456622962432448, 0.08708994631888345, 0.052393444057088345, 0.03791590919718146, 0.060521868435898796, 0.019910872215405107, 0.052622511648223735, 0.03483407788735349, 0.021881105458305683, 0.024984223418869078, 0.044279673384153284, 0.013847686186636565, 0.05565134619246237, 0.01931779603182804, 0.03333256841870025, 0.04060537074110471, 0.07718332868535072, 0.035146766967955045, 0.06613959980313666, 0.01670700770773692, 0.07176936138421297, 0.02066948258288903, 0.008695996657479554, 0.03726307157194242, 0.003243118089812924, 0.0348244039923884, 0.012868943686044076, 0.049500452223583125, 0.064632208814146, 0.07264517727890052, 0.005796318073407747, 0.011818059792858548, 0.02200768987677293, 0.0454758113482967, 0.029821649586665444, 0.034907416920759715, 0.02375179999944521, 0.028021998987242114, 0.02081399357848568, 0.058868612031801604, 0.11753628758015111, 0.06732355541316792, 0.07763976434944198, 0.008877887776179705, 0.014358610333147226, 0.020620424766093493, 0.034548866824479774, 0.0013291345385368913, 0.03510878384986427, 0.04011712662759237, 0.049683053948683664, 0.037654057232430205, 0.0544918703235453, 0.05145179224200547, 0.013735003121837508, 0.03048392176424386, 0.0206718574554543, 0.0683384423609823, 0.034782858565449715, 0.03637802707089577, 0.04157463787123561, 0.019043474130739924, 0.05202342777920421, 0.04539276131254155, 0.012371033099043416, 0.01220361293235328, 0.03504730804706924, 0.03640150862338487, 0.023798900401743595, 0.09188678071950562, 0.07749722004518844, 0.057127132822643034, 0.01632413186598569, 0.03241209749830887, 0.02300831831234973, 0.015935667652229313, 0.0312656129244715, 0.03154051926685497, 0.060229833325138316, 0.04796954999619629, 0.0594632318825461, 0.12234424677444622, 0.10288416990078986, 0.11024386287317611, 0.18208379507996142, 0.19447466300334781, 0.13666239799931645, 0.13831180636771023, 0.07871830530348234, 0.13162147864932194, 0.12589873338583857, 0.10655295467586257, 0.07276948701473884, 0.18011827633017674, 0.12799283664207906, 0.1957972889067605, 0.17221492307726294, 0.16018644586438313, 0.24153323785867542, 0.1599740283563733, 0.11016610806109384, 0.10741216130554676, 0.09223833607393317, 0.13575209450209513, 0.16797424672404304, 0.16405802249209955, 0.08165680934325792, 0.11831623283796944, 0.23065603949362412, 0.10340284949052148, 0.10254259643261321, 0.1395900221541524, 0.14172326627885923, 0.13725657627219334, 0.13256508973427117, 0.16373077989555895, 0.12193701550131664, 0.1356045703869313, 0.12833385349949822, 0.06647722504567355, 0.25573212595190853, 0.12112351774703711, 0.17882928455946967, 0.12399208921124227, 0.08233608226873912, 0.13124421529937536, 0.12479613942559808, 0.06630951451370493, 0.10917885869275779, 0.13639336946653202, 0.12546423560706899, 0.08353831697604619, 0.2040981364552863, 0.1981199291185476, 0.10645171088981442, 0.14799392432905734, 0.1418821600964293, 0.09000969628687017, 0.19534860126441345, 0.17111886001657695, 0.1786298694787547, 0.051290579212945886, 0.08597967855166644, 0.11328062726533972, 0.11974719745921902, 0.0807850604178384, 0.13055766932666302, 0.17201359325554222, 0.17869700415758416, 0.1422215293860063, 0.19473404361633584, 0.06440214303438552, 0.12754233815940097, 0.10621715511661023, 0.13286447210703045, 0.17801908194087446, 0.14276040281401947, 0.20678202447015792, 0.09117382171098143, 0.18051943683531135, 0.19096411153441295, 0.16529700835235417, 0.11663309385767207, 0.18440389714669436, 0.15909137728158385, 0.18291707849130034, 0.13924090104410425, 0.12669873889535666, 0.10282994859153405, 0.10360872125602327, 0.24801235034829006, 0.24461387802148238, 0.09473673911998048, 0.09556494624121115, 0.14254978130338714, 0.1016183479805477, 0.24486274982336909, 0.1416234771022573, 0.14921650872565806, 0.1147378861787729, 0.10644728026818484, 0.14440786675550044, 0.1270876984926872, 0.19667416607262567, 0.05104467971250415, 0.11029818066162989, 0.17217422369867563, 0.12849752674810588, 0.20308541657868773, 0.17434126522857696, 0.13300830032676458, 0.1694997015874833, 0.17399775475496426, 0.09110310988035053, 0.20624404161935672, 0.08601357985753566, 0.18385657807812095, 0.1243929157499224, 0.13386791513767093, 0.09861457205261104, 0.07783684908645228, 0.12251298889168538, 0.11910555142094381, 0.09996806387789547, 0.24238918646005914, 0.11881909726071171, 0.11940517870243639, 0.25680449965875596, 0.14576034183846787, 0.1388853826210834, 0.14512783905956894, 0.1261752427672036, 0.13454948872094974, 0.15638050477718934, 0.08691280308994465, 0.1405910903122276, 0.1733408946893178, 0.2033191782538779, 0.13500604312866926, 0.09773407320608385, 0.1343299020663835, 0.15126774553209543, 0.08924256049795076, 0.18148262577597052, 0.1512578601250425, 0.0939352493151091, 0.1963656404404901, 0.11757496089558117, 0.15307459310861304, 0.20279548916732892, 0.13147730904165655, 0.09071924141608179, 0.11317447788314894, 0.19913842290407047, 0.20654033665778115, 0.1973576395539567, 0.0719890370965004, 0.16049225523602217, 0.12901728245196864, 0.1923490926856175, 0.07479405103367753, 0.06583623951883055, 0.07391257997369394, 0.13420341041637585, 0.09798055529245175, 0.21232948929537088, 0.1308963558403775, 0.12736508360831067, 0.12844536860939115, 0.17671658308245242, 0.09473408965277486, 0.15901683596894145, 0.0918581263977103, 0.09438950306503102, 0.09658017457695678, 0.1659040109370835, 0.09997101020417176], [0.01766497935022926, 0.12218653297168203, 0.034474036074243486, 0.023652331801713444, 0.04799099806405138, 0.05280869794660248, 0.016519197961315513, 0.046088424569461495, 0.01924036034324672, 0.05093350599054247, 0.04969368521415163, 0.03935268483473919, 0.10010288984631188, 0.02519326601031935, 0.044349012241582386, 0.015876546312938444, 0.01750404277117923, 0.017790151832741685, 0.046766057348577306, 0.03745416717720218, 0.040088650421239436, 0.0678771901584696, 0.009331983819720335, 0.04927355170366354, 0.025481809316261206, 0.08035491904593073, 0.01913022748340154, 0.05854408198501915, 0.011275491397100268, 0.03069388276344398, 0.030507889423461165, 0.04272318190487567, 0.03944403950299602, 0.04557281747111119, 0.0556935001804959, 0.034756178356474265, 0.11025337720639072, 0.023278487897187006, 0.015115252153918846, 0.022537243785336614, 0.039610328822163865, 0.006699223285977496, 0.014157819496176671, 0.05658147987560369, 0.05359892194974236, 0.009656279162300052, 0.005524364551092731, 0.09543972366373055, 0.03773037969949655, 0.08598655083915219, 0.0896392458525952, 0.049625663668848574, 0.04282930902263615, 0.07316764182178304, 0.04985572573787067, 0.04845871066208929, 0.050685220485320315, 0.02804564752295846, 0.03610102416132577, 0.07896390423411503, 0.04885637936240528, 0.04725621620309539, 0.050963726243935525, 0.06260839436436072, 0.10431089685880579, 0.05772212374722585, 0.021816909684275743, 0.059557239728746936, 0.10178244425333105, 0.015472381037398009, 0.07067379556247033, 0.03474828561593313, 0.027415000113251153, 0.07616779606905766, 0.02476431393006351, 0.07196329941507429, 0.03584929138014559, 0.0483602647727821, 0.038275264523690566, 0.038996661751298234, 0.0273887856019428, 0.06435903167584911, 0.016479860423714854, 0.03326589758216869, 0.0961815522168763, 0.023058827027853113, 0.04003963156719692, 0.05132165664690547, 0.043271944450680166, 0.052801603014813736, 0.09174513441394083, 0.06703572827973403, 0.04117387070436962, 0.0009719262800444994, 0.11873950192239136, 0.029942836736154277, 0.09137377113802359, 0.015524097598245135, 0.06219815739314072, 0.029927149589639157, 0.06544243369717151, 0.04684774554334581, 0.0683013275556732, 0.07190289601567201, 0.029041967791272327, 0.045046386148897, 0.03951707054511644, 0.040442688259645365, 0.024719104148971383, 0.04743677702208515, 0.06106734697823413, 0.03315026726340875, 0.04890686395810917, 0.11332836220390163, 0.039950020945980214, 0.04284551010641735, 0.04157675299211405, 0.049964142381213605, 0.03219710473786108, 0.017984412697842345, 0.04516626155236736, 0.041955845736083575, 0.05021928533096798, 0.06328536663204432, 0.11021094120224006, 0.02954518102342263, 0.06890786258736625, 0.011787431358243339, 0.06783179298508912, 0.02483731343090767, 0.036511817743303254, 0.05085783661343157, 0.022381886301445775, 0.044557915680343285, 0.021575474202109035, 0.025996050862886477, 0.033479673220426776, 0.03699771667015739, 0.031551013235002756, 0.02978734381031245, 0.04027433205919806, 0.019642225888674147, 0.03489914939564187, 0.03992502170149237, 0.022618529364990536, 0.006749346548531321, 0.04437361814780161, 0.027157417353009805, 0.03110956895397976, 0.03839914010313805, 0.05146781892108265, 0.03539084078511223, 0.04389978654216975, 0.0063431027956539765, 0.00997915329207899, 0.03920795119483955, 0.08641898544738069, 0.039303113080677576, 0.09475000872043893, 0.03731482895091176, 0.06830005848314613, 0.033762227394618094, 0.047474685925408266, 0.06343289816868491, 0.12226183869643137, 0.01447956277843332, 0.029804628429701552, 0.028663589364441577, 0.06708222383167595, 0.041268687491538, 0.026704813026299234, 0.05862636389792897, 0.033872718340717256, 0.03131966725050006, 0.012207759682496544, 0.02303603196196491, 0.027560685557546094, 0.01942576182045741, 0.0891405894071795, 0.07917652212199755, 0.0370276586181717, 0.04198789538349956, 0.017415018446627073, 0.03381738752068486, 0.031727280729683116, 0.03221955841581803, 0.03628320286225062, 0.03946948403608985, 0.03517358076351229, 0.0533563695353223, 0.12575030385050923, 0.03295460373919923, 0.03328384271299001, 0.004603616716849501, 0.016455846380267758, 0.05806753411889076, 0.004232567926010233, 0.03242223523557186, 0.021774071065010503, 0.02081137936329469, 0.0395935896813171, 0.017995782400248572, 0.018830626177077647, 0.06609325268073007, 0.025913538884196896, 0.03145091606711503, 0.04448006809980143, 0.04823746901820414, 0.012036263269692427, 0.024687848599569406, 0.03766502617509104, 0.0032497533538844436, 0.02950232013972709, 0.028400355149642564, 0.03493660929962061, 0.05948066864220891, 0.029022629278188106, 0.016306591205648147, 0.052844209712930024, 0.06339451429084875, 0.04623672422894742, 0.026602198122418486, 0.0067825173027813435, 0.03831557056400925, 0.020503096784523223, 0.051927423555753194, 0.041533148105372675, 0.01796362328605028, 0.047304934487328865, 0.05502584557689261, 0.03253734605095815, 0.04646514615160413, 0.05226383909757715, 0.05469127056130674, 0.053124930782360025, 0.01492649245847133, 0.06966418528463691, 0.03351345207192935, 0.11565182619960979, 0.059372467221692204, 0.031274422217393294, 0.023557806307508145, 0.01618979385966668, 0.04610543459421024, 0.0663986464496702, 0.0390773406252265, 0.04715357717941515, 0.014148901664157165, 0.006588340393136605, 0.06401724298484623, 0.058160317421425134, 0.0448394753766479, 0.05588117448496632, 0.01305983056226978, 0.028683786913461518, 0.01363512581519899, 0.0392506989010144, 0.043085587458335795, 0.01238736776940641, 0.04142721023526974, 0.09586367552401498, 0.008500412914145272, 0.04373205745650921, 0.06317531355307437, 0.03436054314079229, 0.015694790636189282, 0.06141189645859413, 0.03789636473811697, 0.03599165385821834, 0.01888813334517181, 0.01424686979589751, 0.02651549300935585, 0.04839454086322803, 0.051343561135581695, 0.04517950517765712, 0.03971704594732728, 0.06324658941593952, 0.09560930440784432, 0.01001200816972414, 0.03353929365403019, 0.061568385717691854, 0.03264114653575234, 0.02011390526604373, 0.07131812075385824, 0.044328310032142326, 0.09384234726894647, 0.04601622473273892, 0.03546717438439373, 0.03360862880072091, 0.005487279895532993, 0.033191701368195936, 0.012915570969198598, 0.04009595686511602, 0.027333560537954327, 0.01997286752157379, 0.027016652347811032, 0.02664073970663594, 0.030202458547137212, 0.10299777786713094, 0.04747400314954575, 0.12873474683146924, 0.08760550146689638, 0.00832743684441084, 0.01511668078819639, 0.017904782107507344, 0.03888318366080057, 0.03300405674963258, 0.06062722000933718, 0.02778987560304813, 0.04781053743499797, 0.03811669725109823, 0.030873044634063262, 0.06018409476382658, 0.010962834785459563, 0.010667607512004906, 0.0509571805014275, 0.06768080304027535, 0.01690207009232836, 0.04847215095651336, 0.07302240352146327, 0.03832504778984003, 0.04748682746139821, 0.03387926779396366, 0.02219510257418733, 0.01683905989921186, 0.07996160304173827, 0.025210417043126654, 0.027579608467931394, 0.017624530446482822, 0.0700153547222726, 0.0015146692544476537, 0.03274157767009456, 0.06412226430256851, 0.11836888821562752, 0.03115943014563527, 0.02770731909549795, 0.04031921715068165, 0.05009014792449307, 0.058711922392831184, 0.07202773267636076, 0.025054449142771773, 0.02963895138236694, 0.008974195352493552, 0.021482523916347418, 0.03991940735431854, 0.00779323430833756, 0.031025299940665718, 0.0645451400487218, 0.00780324680818012, 0.01247505437277141, 0.03211403243767563, 0.006348050137603423, 0.13701901480089873, 0.18349460297031328, 0.1665276227868162, 0.15760167909320444, 0.08479590847855434, 0.215936831664294, 0.07176011422416195, 0.23404412175295874, 0.09588620712747797, 0.1328840499627404, 0.085673468420282, 0.1540009121526964, 0.1694125437643379, 0.1403561412007548, 0.20349107449874282, 0.17129341315012425, 0.12480718258302659, 0.12116827667341568, 0.09191880439175293, 0.23336400277912617, 0.12931320641655475, 0.13164519768906757, 0.059705724925152026, 0.16106976487208158, 0.16217793978285044, 0.11666224541841075, 0.12882393813924864, 0.09605388797353953, 0.08804867495200597, 0.1270201036822982, 0.10538964561419562, 0.0903034902876243, 0.1291392173152417, 0.21154250105610117, 0.13951996341347694, 0.16847595339640975, 0.1329407945740968, 0.07607090126839466, 0.09376664078445174, 0.08629803021904081, 0.2313929921365343, 0.06517346453620121, 0.16012772714020684, 0.18551140412455425, 0.15718098526122048, 0.1486338782706298, 0.09713446983369067, 0.2572222100570798, 0.16495628835400566, 0.13363149657379836, 0.12817188719054684, 0.1230413831945043, 0.1297713044914417, 0.18271070206537843, 0.098468643554952, 0.15738454152597114, 0.07360951654845849, 0.0702929995895829, 0.1266622103867121, 0.1479262107750401, 0.18829595705028623, 0.08364131965208799, 0.2877295558573678, 0.1471723965369165, 0.1385208693682216, 0.11773477497627027, 0.12611125479452312, 0.19614437653217465, 0.23738022398902103, 0.12382072731270455, 0.13347347849048674, 0.11438639761763625, 0.08370541894691996, 0.14382329187355936, 0.19161111587891355, 0.14777534699533135, 0.16530575085198507, 0.18241844431031495, 0.15166587807470933, 0.12955067883012816, 0.11135932567412965, 0.17728848208207637, 0.08824576711049303, 0.13592341187177226, 0.3057865728624165, 0.11083251214586198, 0.17572960088727996, 0.15861405758187175, 0.08477579627651721, 0.15693778346758336, 0.15744578355224803, 0.10629483571392484, 0.1260918698972091, 0.0934867472096812, 0.15872312360443175, 0.0753037135291379, 0.1911741096409969, 0.17964759143069386, 0.2128892912878655, 0.1253214167081751, 0.1195521758927498, 0.18639300134964287, 0.11558054291526787, 0.19066242850385606, 0.1207097629958298, 0.20162589411484078, 0.13696509035071358, 0.13343450089450926, 0.14179583347868174, 0.13006477936869487, 0.24247048131655902, 0.19220839632907882, 0.11039092685678042, 0.1610776167945005, 0.09458545231609605, 0.12122316591558047, 0.13279555627377704, 0.16248612402705476, 0.10465807354194112, 0.13268077571410686, 0.09552646588417701, 0.17844394664280117, 0.13483609131071717, 0.10640628403052688, 0.3048174170544371, 0.17615453980397433, 0.13141253439243883, 0.06358994403854012, 0.20662145339883864, 0.08472517438349314, 0.21084603999042884, 0.11256308178417385, 0.1426383640500717, 0.11681926902383566, 0.1464362008846365, 0.11068028281442821, 0.19463982054730877, 0.17677536117844284, 0.18712639168370515, 0.11559764941921458, 0.18218886834802106, 0.07412356513668783, 0.18209989968454465, 0.19130189262796193, 0.13196346029872075, 0.09815801022341475, 0.15419535484397784, 0.09924036581651308, 0.13995091372635216, 0.18260295706568286, 0.19871734315529466, 0.1210386902675964, 0.1000031377770938, 0.11925431492272764, 0.09678707792772911, 0.10011234480771236, 0.19438363116933033, 0.2004066196968779, 0.0983136311697308, 0.1273640594445169, 0.1327862942707725, 0.10847850877325982, 0.15120271855266765, 0.25515592249576, 0.2216852255514823, 0.1258178986608982, 0.14895831554895267, 0.06927806811290793, 0.12586702883709222, 0.07055626163491979, 0.14888559991959482, 0.12466872751247138, 0.11898751283297315, 0.10164971856283955, 0.15688946965383366, 0.0649755634367466], [0.04735166010505054, 0.0633205147460103, 0.02432886805763701, 0.030528958996001165, 0.032394111549365334, 0.06000559340463951, 0.008702890281711007, 0.11287011569947936, 0.013840899246133631, 0.06521876523038372, 0.005663537649525097, 0.010166444462811342, 0.07082076306687668, 0.043697143119061366, 0.02976715924887685, 0.019278508589195553, 0.07093337655533105, 0.030909359775250778, 0.0703128075110726, 0.041120595633401535, 0.011762161229853518, 0.02558427950134501, 0.024366571014979854, 0.03311649212264456, 0.010361569002270699, 0.026437266933498904, 0.038761890755267814, 0.0468740398355294, 0.05067753925686702, 0.029776014926028438, 0.05919075607380364, 0.017257644176424947, 0.045100214119884185, 0.013362191730266204, 0.030238797808124218, 0.03542811515217181, 0.09672795102233067, 0.018988952251675073, 0.02964717994473176, 0.03641487470304128, 0.0438600482448237, 0.059316843253327534, 0.024971083694254048, 0.00708640265656868, 0.0338406612718245, 0.016601771167188417, 0.03005312173627317, 0.023670759328524582, 0.06823817078839056, 0.08079065621132031, 0.04409315311932005, 0.012944501741003478, 0.02436024420603644, 0.04070157534442842, 0.03177873011736665, 0.040201171141234227, 0.0490581952908542, 0.03799832469667308, 0.0263444019947201, 0.0840994251484517, 0.033381438843207434, 0.03817572767729871, 0.04559773136861622, 0.039365917327813804, 0.046254558037617244, 0.08780035976087674, 0.04774723965965677, 0.03773852105950937, 0.024678733170730993, 0.0808380200760439, 0.06538096160511486, 0.09358681840240024, 0.014412609925784636, 0.057369547939742915, 0.013487023752531968, 0.040131260830094106, 0.053875743033131585, 0.053690629138145596, 0.018206787972303573, 0.021616568774334155, 0.04164891201071441, 0.040068579037324525, 0.04848152799240779, 0.04797205845534336, 0.037715039507020265, 0.07032235153019428, 0.06016011968313251, 0.015668205051042605, 0.04871243239904288, 0.051914261566707864, 0.06776211273972876, 0.03376324042619672, 0.05388732795836404, 0.03157115512294695, 0.054077499589766376, 0.02306534308445407, 0.05304943952069152, 0.019323254527989775, 0.04454697642358951, 0.07281310303369537, 0.010795479556691134, 0.03236764285247773, 0.013315619180502836, 0.012321882513788296, 0.053075607647770084, 0.06326908391201869, 0.035765744105447084, 0.04973465547664091, 0.03973444188886788, 0.04287643540010322, 0.0450871745852055, 0.0294359220424667, 0.0350622326368466, 0.04232749102811795, 0.02605073786980938, 0.027651552263705526, 0.04212407206068747, 0.06374493415933102, 0.07490068281185813, 0.0567732285708189, 0.017095238144975156, 0.03702302019519266, 0.08068967959843576, 0.020236337368260138, 0.011486800322018098, 0.018375159015704412, 0.029248425853438675, 0.025086827190534677, 0.02713182067964226, 0.04401533522468526, 0.04047838556289207, 0.04338794213254005, 0.04579297929012682, 0.05446561313874554, 0.03133650287054479, 0.04158432289841585, 0.027988745205220766, 0.05393924489908386, 0.04903917033516336, 0.003882524233631557, 0.03291367429483216, 0.02191296956880251, 0.019114685055683367, 0.04621552478056401, 0.04864454072958324, 0.03790541893977206, 0.06983028535614721, 0.06885436858283356, 0.027732915768865496, 0.04767689519212581, 0.014235524213290773, 0.0360614454257302, 0.02432780122035183, 0.032568831666139886, 0.02753559539996786, 0.04286943323677406, 0.04075563709193375, 0.06583999478607439, 0.040606758557260036, 0.04241714617819525, 0.033135583871626295, 0.033290815190412104, 0.04845703340834007, 0.021166435799386818, 0.014206282667146297, 0.029071071112412028, 0.008856994463712908, 0.020606292418960948, 0.031255501162377186, 0.02169073159166146, 0.08691038368851878, 0.06164205500681419, 0.029483475154847838, 0.11076206006691791, 0.04850397053814959, 0.005138868464200641, 0.12265702491276897, 0.03139787477266509, 0.016475555967190303, 0.03914410794095602, 0.02358598751015961, 0.037691157194785774, 0.009183073743770365, 0.022399855552066583, 0.035399130574660376, 0.0948687523487024, 0.05413127932115458, 0.0356846718932502, 0.05466458293085452, 0.049047745851567015, 0.06688825611490756, 0.019595594894781243, 0.039570635053678416, 0.0207249080267502, 0.04762963893881533, 0.025408694782527164, 0.027154343006259296, 0.0962196837645024, 0.014990054623922333, 0.040712228874326684, 0.03973570725065656, 0.023708900152996648, 0.03452413104241714, 0.04350847433670424, 0.0958404314587824, 0.03356802961206995, 0.03999137712526135, 0.01440762733182055, 0.04063835920533165, 0.029100137326167896, 0.05689678873750381, 0.008954223230830394, 0.09920921787852421, 0.03026345009857323, 0.04188869621430058, 0.02663533501618076, 0.018650813071872108, 0.03355287866725121, 0.044875918538309634, 0.026261654384143185, 0.020798035548068583, 0.06736947208992206, 0.012551754407468252, 0.045621097888215445, 0.03183964188792743, 0.04942526153172366, 0.026520420869928785, 0.026161106361541897, 0.044841976414318196, 0.027625124384940136, 0.02916261688369559, 0.06524801327032037, 0.1109794870717451, 0.0331359809206333, 0.045431679536704905, 0.03746378170035314, 0.011038839984394144, 0.02981170851853676, 0.024994010491354857, 0.03814004892774392, 0.03299717704067007, 0.08966068649897352, 0.027728474015020765, 0.025779571951716207, 0.026057524810312316, 0.07985326432390139, 0.036039544647792354, 0.06816248656832613, 0.02566594357631402, 0.015605712505930569, 0.024678037407284137, 0.02270413238875335, 0.023320558393606916, 0.06885823517222889, 0.014474498548224801, 0.03977482956543099, 0.057565415554563515, 0.024667356046848, 0.06899321699165739, 0.07144551782403141, 0.07343482240685262, 0.053908839108771645, 0.05283160804538056, 0.03222641957108863, 0.07688220226555131, 0.03939930655178614, 0.027701689905370586, 0.009020698325912235, 0.023551921076432336, 0.07752791527309455, 0.07725679388386197, 0.07919889045297168, 0.00807687480119057, 0.030369914893526584, 0.02606766254757531, 0.031958411491359584, 0.03363388779689558, 0.044290931764408015, 0.07455023325746879, 0.04476656307815574, 0.04750230866193306, 0.011550421859283233, 0.030339449731400236, 0.08617972445790656, 0.02043850952759385, 0.01282041186641436, 0.04844340015552007, 0.02126663315721089, 0.025357052436447702, 0.03860832184727769, 0.11866117565659806, 0.0429161662759725, 0.01961319678230211, 0.041759978121262975, 0.0574475662142504, 0.03062367373786401, 0.038352518386091106, 0.04131542795221321, 0.046469799417536706, 0.05161208871868439, 0.042591179808368906, 0.040729546890361235, 0.017599204657017253, 0.0198872144028428, 0.09685641678515822, 0.06500731993583031, 0.034636013515410013, 0.04395282412588131, 0.016235383991443086, 0.044140279496787116, 0.029780517907056492, 0.023097227604012005, 0.05939581518759951, 0.044096143974456936, 0.015698514362156857, 0.016455185868835542, 0.05406883872637991, 0.04537394786893856, 0.03012117296748329, 0.09620612472645007, 0.09701781164039858, 0.06986369684454985, 0.06669272988801822, 0.025538763584336266, 0.01743404340231791, 0.04428922482475173, 0.04631222291209269, 0.05422326110419817, 0.036914399461238645, 0.018211320639238693, 0.013794250626233406, 0.020214327123539988, 0.04729904554551467, 0.03064163185626967, 0.06440328594180755, 0.02400996720098192, 0.007840604666853324, 0.026745918730739504, 0.026133737810596358, 0.032923912222031504, 0.06020078937581275, 0.03239443067286629, 0.019174665430909954, 0.0274866748804925, 0.03304987694718875, 0.01095981888283859, 0.0632586790015921, 0.015348546276072739, 0.04515267653914634, 0.06316602928563952, 0.03466568829026073, 0.013902777664043242, 0.32048519351519644, 0.17975742928683758, 0.1424199648317881, 0.13792675046715885, 0.0844588250038214, 0.13243757392046973, 0.18610999075463042, 0.2123705597477965, 0.1541101562906988, 0.19187129801139235, 0.10886294126976281, 0.05763947447121609, 0.11333412126987241, 0.2055468235630542, 0.16646692994982004, 0.083710280014202, 0.15334332478232682, 0.19639148202259094, 0.0989347642462235, 0.10379014667705633, 0.10183473597862758, 0.17789125442504883, 0.09074690125999041, 0.09291575363022275, 0.10073849480249919, 0.08930136827984825, 0.1540941110579297, 0.14308060985058546, 0.19586543290643021, 0.0853773440758232, 0.1464585098437965, 0.09550118091283366, 0.16972855024505407, 0.1108593110984657, 0.10045802235254087, 0.11019639510777779, 0.16332178231095895, 0.17232755140867084, 0.08334688740433194, 0.0945441889052745, 0.17013610806316137, 0.12173910698038526, 0.1399503496941179, 0.09682903153588995, 0.09089046230656095, 0.11190473000169732, 0.10032347840024158, 0.08482615099637769, 0.19062821549596265, 0.1773652498377487, 0.1843241904862225, 0.06366292684106156, 0.10764357779407874, 0.1586158387362957, 0.06496237547253259, 0.15828470728592947, 0.20778764941496775, 0.16655631421599537, 0.10715330761740915, 0.23247867997270077, 0.07858579483581707, 0.11618698888923973, 0.11367844068445265, 0.12591442238772288, 0.1199970488960389, 0.23015713813947514, 0.18008862010901794, 0.1597641786793247, 0.06746627783286385, 0.23443789046723396, 0.15769388352055103, 0.21512637671548873, 0.11991755745839328, 0.14640180976130068, 0.10256365116219968, 0.13011065893806517, 0.1349279098212719, 0.19413422502111644, 0.21532307553570718, 0.13333287119166926, 0.17037936922861263, 0.12527663551736623, 0.1412620660266839, 0.11410402526962571, 0.13557124795624986, 0.2744554728269577, 0.17680345888948068, 0.06857327272882685, 0.14083478192333132, 0.14332784892758355, 0.21162096090847626, 0.15339923818828538, 0.18228509521577507, 0.11917069714399986, 0.19876726000802591, 0.14771932968869805, 0.13520349893951789, 0.19572291086660698, 0.1627378456760198, 0.14401181222638115, 0.10809019484440796, 0.1419559889473021, 0.2187597387819551, 0.13590439804829657, 0.14048496319446713, 0.10957241218420677, 0.13940786942839622, 0.20359971007565036, 0.0640595231379848, 0.12738642777549103, 0.27710295107681304, 0.04974791023414582, 0.09843212246778421, 0.09648624836700037, 0.17426748090656474, 0.10467949934536591, 0.1186037556908559, 0.2307437761919573, 0.17716047645080835, 0.16535897768335417, 0.20025773002998903, 0.09423353330930695, 0.2236355302738957, 0.1557549336575903, 0.13283270818646997, 0.102880065824138, 0.11074235604610294, 0.0889686708978843, 0.20358366484288126, 0.1110513047024142, 0.08785861835349351, 0.15751581260701641, 0.15696963644586504, 0.17571131436852738, 0.16543856560019776, 0.07204517314676195, 0.1562915212707594, 0.23383342602755874, 0.08723579318029806, 0.11196589781320654, 0.18475052464054897, 0.13805201015202329, 0.06978775287279859, 0.26094069646205753, 0.17493502789875492, 0.19946505693951622, 0.2270678148488514, 0.1373200595844537, 0.11380008611013182, 0.14121568179689348, 0.07935836314572953, 0.14865606848616153, 0.08961400541011244, 0.09782962471945211, 0.08881308705895208, 0.23197884351247922, 0.09080599105800502, 0.1416831903043203, 0.07447216674336232, 0.1527551282197237, 0.11172636222909205, 0.1253076721332036, 0.14017283072462305, 0.13805785827571526, 0.11240145686315373, 0.10913836711551994, 0.11461565445642918, 0.12267753045307472, 0.16185418528039008, 0.1098649445339106, 0.18808483087923378, 0.13796370942145586, 0.16620320035144687, 0.2605302887968719, 0.16277198446914554, 0.08803778764558956], [0.01663881917920662, 0.036629845199058764, 0.07158038832130842, 0.010728608340286883, 0.03178890867275186, 0.018583619021228515, 0.016934607701841742, 0.06134008624940179, 0.029755514951830264, 0.02124672319041565, 0.09998662499128841, 0.02199370224843733, 0.04217034125758801, 0.022711438832629938, 0.0510093683260493, 0.015679828939028084, 0.057726283484953456, 0.0459437465906376, 0.031499393153353594, 0.00616683019870834, 0.10260691837174818, 0.056657601962797344, 0.029278284309839364, 0.05855446834175382, 0.029012703053012956, 0.019425758109719027, 0.026952647676807828, 0.008207214486901648, 0.02993774374772329, 0.06606528855627403, 0.060262677070568316, 0.022958360641496256, 0.044071170705137774, 0.018397555177216418, 0.030570181588700507, 0.020723425586766098, 0.02419254851702135, 0.06525609525851905, 0.012692103809968103, 0.05124326729855966, 0.0367784751142608, 0.07179360734880902, 0.012321775830059778, 0.044244959426578134, 0.044759694501408376, 0.02367817152844509, 0.03685810755996499, 0.07449381519109011, 0.016094507664092816, 0.019982350313512143, 0.02267562649649335, 0.04037526043248363, 0.017531524499645457, 0.04033030112623237, 0.007550077043561032, 0.013681283689948032, 0.04674519557738677, 0.0484259299992118, 0.03160805099469144, 0.035457470803521574, 0.08569151745177805, 0.07120598966139369, 0.055285882990574464, 0.03401234971533995, 0.0558826179621974, 0.028729265723086428, 0.03211582101357635, 0.0264337268890813, 0.03869349442538805, 0.0545960233284859, 0.05203655266086571, 0.018032451916951686, 0.030262173604569398, 0.03340361792652402, 0.007451175197275006, 0.016128407114592846, 0.04948620669892989, 0.03204302745871246, 0.023535610525868833, 0.02388186323514674, 0.009782083398022223, 0.00985504208074417, 0.028126317120040767, 0.027854347827087622, 0.10181746620219201, 0.07507827875087969, 0.041254345487686805, 0.028503545217972714, 0.025345799622300547, 0.02301332409842871, 0.04460368392756209, 0.027597625958151184, 0.08733123337151483, 0.07106210949132219, 0.03407632655580528, 0.038108693188405596, 0.019605845809564926, 0.017504736679256894, 0.008077475013124058, 0.01717700983135728, 0.032033097522798926, 0.02685262843442615, 0.029812725260853767, 0.01034046603308525, 0.024476666767441202, 0.07041206234134734, 0.026852621012949385, 0.07565138745121658, 0.017121150231105275, 0.07814193857484497, 0.044460553326644, 0.047021415521157905, 0.06154586895718239, 0.05076229994301684, 0.030904021878086496, 0.04265207673597615, 0.016716319805709645, 0.028624255537579302, 0.011626484574662754, 0.07086835699738003, 0.023147821666498203, 0.0056352785213675816, 0.021843268914381042, 0.037206835331744514, 0.06693795774481259, 0.02212193237937754, 0.07613498572027311, 0.05133171645866241, 0.014977424198150402, 0.10133130010217428, 0.012426583780325018, 0.04643937136279419, 0.028433796323952265, 0.038525286654476076, 0.06525532342493534, 0.0657243533350993, 0.050092177698388696, 0.0256400314901839, 0.013727588138863211, 0.022397666216420475, 0.03271703113568947, 0.024473167541145813, 0.012693756943917833, 0.047871801725705154, 0.03782714833505452, 0.028184599832457025, 0.01671732356044231, 0.022032917331671342, 0.11845311455545016, 0.048029099925770424, 0.02761226296570385, 0.01447406068109558, 0.013337638702068944, 0.011216476741537917, 0.07850124195101671, 0.0280959224619437, 0.09692110979813151, 0.09176801482681185, 0.016819290940475184, 0.03693516475323122, 0.013130637016729452, 0.018481002261978574, 0.05681291862856597, 0.04327386661316268, 0.02345612465433078, 0.030591557297157124, 0.012598236971825827, 0.022651237668469548, 0.03068165031436365, 0.04295443512091879, 0.01851611512392992, 0.08278174937004223, 0.05721352623368148, 0.014020587113918737, 0.024205604750022758, 0.033869182007038034, 0.05746849477873184, 0.04782568837981671, 0.04435297902091406, 0.02515318446967285, 0.04103408718947321, 0.0546125991968438, 0.041655951281427406, 0.13655713177286088, 0.04007762581750285, 0.01238872682733927, 0.01723141296679387, 0.03256719894125126, 0.051707677339436486, 0.028542732470668852, 0.07960847433423623, 0.026443096503498964, 0.02208051497291308, 0.01115064267651178, 0.029359157997532748, 0.038168640166986734, 0.03600064497732092, 0.02313226996193407, 0.013707860925933346, 0.01026569558234769, 0.032391209751949646, 0.06234591899556108, 0.007570073285023682, 0.04687681546784006, 0.03152064084133599, 0.020733385208586697, 0.053120121665415354, 0.018038129346678033, 0.0471256130549591, 0.01743352389894426, 0.04471156622457784, 0.03372394741745666, 0.013071223456790904, 0.055813308790675364, 0.026226010886603035, 0.05987009950331412, 0.06881273409817368, 0.08428479137364775, 0.02996690458530793, 0.019133643218083307, 0.01392070516885724, 0.050554339031805284, 0.02208946898463182, 0.044393696953193285, 0.00942670969379833, 0.06900939581100829, 0.01930845795868663, 0.011814207118732156, 0.021435067283164244, 0.015499840501433937, 0.07191604687250219, 0.02475079571013339, 0.024920704854594078, 0.07668355159694329, 0.09083445242140442, 0.008311283072544029, 0.03200859922799282, 0.07562439554021694, 0.04581270557537209, 0.06878258063807152, 0.04840546527702827, 0.013461632097460097, 0.024077730849967338, 0.011524070978339296, 0.02328943086467916, 0.0329105461423751, 0.03661617112811655, 0.0217911794243264, 0.04126181891479064, 0.05072819083579816, 0.027102348140033428, 0.018025086101260968, 0.002622193974275433, 0.05991953767079394, 0.04342234809882939, 0.03210563132597599, 0.015768912635394372, 0.019860365355270915, 0.013983202352392254, 0.06714069764711894, 0.04317367296607699, 0.03453463614278007, 0.06382772815413773, 0.06074872813769616, 0.00697515425599704, 0.015807647178007755, 0.03354957611009013, 0.11120815761387348, 0.021778399641334545, 0.0387927678093547, 0.1324450844549574, 0.07673257787246257, 0.014954495545680402, 0.047963609104044735, 0.05472494551213458, 0.058342414486105554, 0.0037803328177687945, 0.014495019859168679, 0.039137677231337875, 0.044235482200747356, 0.036419772877707146, 0.07588809545268305, 0.0894417603558395, 0.03894578381732572, 0.036743731470778584, 0.012883987947134301, 0.034965185695909895, 0.05154890226549469, 0.021924767861492, 0.02879786057746969, 0.010842004794540117, 0.04102289931324776, 0.022338069902616553, 0.05739981272199657, 0.0233945709260297, 0.01048818774506799, 0.01997205486986786, 0.032906182314036414, 0.031182574020931497, 0.04467081118491478, 0.0560637242597295, 0.048449274254380725, 0.02513944731617812, 0.05305913568008691, 0.030703883203386795, 0.013846525653207209, 0.05170047108549625, 0.04719810232927557, 0.054942895731073804, 0.06283414826611988, 0.10997337230946869, 0.027859424117195886, 0.08067864386248402, 0.013233326135377865, 0.023126789201342035, 0.036718888077302836, 0.024076025765680242, 0.044388668902684, 0.04305998336349148, 0.056377767759840935, 0.07658549904590473, 0.028987566511204932, 0.08068027658737265, 0.03524550971633289, 0.0952839468664024, 0.014190797755873064, 0.011774108879762935, 0.06470700987847522, 0.03655004205938894, 0.03604337041906547, 0.006882934521854622, 0.037792523435200565, 0.016534202331968118, 0.05682120470737573, 0.029838047339580953, 0.030013177492946852, 0.05087192257633433, 0.09943805911461823, 0.08645909110782668, 0.028292138886172324, 0.034083102364093065, 0.01860568121628603, 0.05943685224337969, 0.04890876756689977, 0.03700538676639553, 0.04909632683848031, 0.03503582331177313, 0.03322572141769342, 0.049784260627347976, 0.05796096913400106, 0.008500277472194284, 0.0160877392772818, 0.10107546695508063, 0.21237499779090285, 0.11172534548677504, 0.15104731282917783, 0.16201396967517212, 0.10955057819955982, 0.10085611036629416, 0.27764270023908466, 0.09747270363732241, 0.15046968444949016, 0.2393634058535099, 0.1500182953896001, 0.12934461410623044, 0.1343477432965301, 0.24361741117900237, 0.21084805863210931, 0.1305866873008199, 0.09832116396864876, 0.10359839798184112, 0.1185927793267183, 0.19461755611700937, 0.10553800835623406, 0.10556192035437562, 0.14558225608197972, 0.13761650305241346, 0.20736597594805062, 0.10414815129479393, 0.15693074790760875, 0.11484817674499936, 0.1279983136919327, 0.0872303383948747, 0.12278247013455257, 0.09065967664355412, 0.17649466608418152, 0.12742595456074923, 0.11684883618727326, 0.07166248469729908, 0.1467758818762377, 0.08797619680990465, 0.1540074875811115, 0.19985510007245466, 0.1698566004051827, 0.11477583218947984, 0.12299497670028359, 0.07307566003873944, 0.16592177795246243, 0.10185559774981812, 0.2606063737766817, 0.16386448522098362, 0.13539019360905513, 0.13679061143193394, 0.09655427362304181, 0.10896041494561359, 0.12355756916804239, 0.1645323884440586, 0.07957170091685839, 0.14566509460564703, 0.17542263376526535, 0.16097411687951535, 0.13869993475964293, 0.15951361478073522, 0.17748794169165194, 0.1904225960606709, 0.25006084120832384, 0.13196602812968194, 0.10994292199029587, 0.1223819181905128, 0.13292675314005464, 0.14464299398241565, 0.1040378533070907, 0.14034486055606976, 0.09885101288091391, 0.13486582174664363, 0.1362741953926161, 0.1979536286671646, 0.1349800976458937, 0.10790030893986113, 0.14459473954048008, 0.1203805091790855, 0.08094803604763001, 0.07296600771951489, 0.10471231711562723, 0.19585220783483237, 0.18446176982251927, 0.15552204771665856, 0.2192650968208909, 0.1217363536125049, 0.08069713818258606, 0.17717833252390847, 0.0959930763929151, 0.10472624722751789, 0.16884665616089478, 0.10517417045775801, 0.11697722773533314, 0.12480152741773054, 0.21208726713666692, 0.11170502548338845, 0.138883616309613, 0.10854815191123635, 0.11482580841402523, 0.11312965958495624, 0.08605822004028596, 0.14084606256801635, 0.09835895412834361, 0.11524072833708487, 0.2440202934667468, 0.1984619998256676, 0.12447025495930575, 0.10015257663326338, 0.1834654514095746, 0.08786730890278704, 0.16629414312774315, 0.15621524333255365, 0.23637266946025193, 0.09159991837805137, 0.15050176007207483, 0.10694987009628676, 0.08559016234357841, 0.08708529305295087, 0.12871276441728696, 0.09391771236550994, 0.12313349114265293, 0.08348060015123338, 0.10758698161225766, 0.14044147334061563, 0.16788432811154053, 0.17087047803215683, 0.15071079338667914, 0.06978441320825368, 0.12601192574948072, 0.12825825833715498, 0.1507906336337328, 0.1289559216820635, 0.1766994543140754, 0.2004774651140906, 0.13993384432978928, 0.1272918187896721, 0.13762876333203167, 0.1268654252635315, 0.12400202656863257, 0.15136777219595388, 0.12411072151735425, 0.21774648455902934, 0.1924040264566429, 0.15277719969162717, 0.12711052695522085, 0.22118133696494624, 0.18745201639831066, 0.3296005184529349, 0.1400877657579258, 0.11549316244781949, 0.15070429217303172, 0.11167044140165672, 0.10858765643206425, 0.14622574264649302, 0.1523267012089491, 0.18686220195377246, 0.18201161379693076, 0.07643706208909862, 0.10244330449495465, 0.15506457304582, 0.2396871751989238, 0.17770939855836332, 0.16955457598669454, 0.06306136419880204, 0.09840290411375463, 0.17307980713667348, 0.10508681967621669, 0.15391038497909904, 0.24120851856423542, 0.057377203193027526, 0.13535893434891477, 0.16279488714644685, 0.15118257666472346, 0.08210340412915684, 0.18989093630807474], [0.05329592902853619, 0.029066566276014782, 0.01602867359906668, 0.051122824152116664, 0.04431863984791562, 0.03493509902909864, 0.04709331478807144, 0.040690313253435306, 0.06756663104170002, 0.028993214255024213, 0.036647530578193255, 0.017391104593116324, 0.1330936621525325, 0.056384929484920576, 0.061712351234746166, 0.0475751133490121, 0.029023671995673794, 0.03164204135828186, 0.07796456528012641, 0.05125739779032301, 0.06036256643710658, 0.030887210377841257, 0.07856768643250689, 0.0066728051479003625, 0.009945508027158212, 0.024259284291474614, 0.040540547852288, 0.041325150086777285, 0.03441649736487307, 0.02186732006521197, 0.027460139390313998, 0.0514343666145578, 0.06478417097241618, 0.03935324144549668, 0.05557987366046291, 0.04721819597762078, 0.01623174004635075, 0.09472566627664492, 0.04641366707801353, 0.01863110162958037, 0.028302935279498342, 0.02581238601123914, 0.05235491546045523, 0.03950252073991578, 0.08673800504766405, 0.03651313134469092, 0.06990314941504039, 0.06818814261350781, 0.01973575690499274, 0.014526351478707511, 0.05291793466312811, 0.02971593065012712, 0.024097841196635272, 0.03800111146119889, 0.01626847450097557, 0.023271084974112455, 0.041927020720322616, 0.015254774061759235, 0.041466599723207764, 0.0195647085638484, 0.04902921442408115, 0.04134208218601998, 0.004098685876670061, 0.017394201204297133, 0.05875221730093472, 0.023496733119827695, 0.05232755247561727, 0.02617463942442555, 0.029366824383032508, 0.023304526148422156, 0.01687723968643695, 0.03622253600042313, 0.061504330951720476, 0.009485135269642342, 0.04461638207430951, 0.025109559173870366, 0.08806085359537974, 0.030644171856692992, 0.023658003665332217, 0.037032564214314334, 0.0009581172889738809, 0.010594784271233948, 0.01797194647224387, 0.011738410648831632, 0.052230442452128045, 0.024751459932303987, 0.03747256130736787, 0.04658437588659581, 0.011969419883826049, 0.055560314358444884, 0.028209652882651426, 0.03463072200247552, 0.019528673583408818, 0.09817845639190637, 0.05361239564081188, 0.011339898683218053, 0.060353827648214065, 0.05747447648900561, 0.03165493988490198, 0.06245212032808922, 0.015215067305689445, 0.028882031256216578, 0.04357993573648855, 0.04894550387689378, 0.02372960607317509, 0.033203059938387014, 0.026397242909297347, 0.06500996198155917, 0.028552562216646038, 0.03074909298447892, 0.009993710518756416, 0.07236866047605872, 0.05681583526893519, 0.0667851569596678, 0.02727457835135283, 0.04621395142748952, 0.0660202105063945, 0.06833333638496697, 0.037640709706465714, 0.03604511446610559, 0.08998669713037089, 0.02594078498077579, 0.07736124374787323, 0.03404592818696983, 0.025890459946822375, 0.016587217651249375, 0.09940531555912457, 0.07041503835353069, 0.030956202281231526, 0.021632098214467987, 0.08762915371335112, 0.11354484668117948, 0.06269296209211461, 0.009605932791600935, 0.033983287212322466, 0.03276339681178797, 0.04317272672778927, 0.02763551445241319, 0.028643011464737356, 0.03805168882536236, 0.05689302604878321, 0.059557295389822684, 0.04147629959334154, 0.030132080682960805, 0.02270881162985461, 0.012390629508445272, 0.0309574694983894, 0.041109600715572014, 0.018322004543733783, 0.02521002370485803, 0.04418192140292376, 0.03292366731329821, 0.04692138514656108, 0.027594596140261274, 0.04352706513600424, 0.01971875059098238, 0.008687362696946366, 0.023812199688109104, 0.04312000826757867, 0.009254164997400949, 0.07287135420483537, 0.027311247868055943, 0.015166459415922873, 0.03211195442418102, 0.023400023856083862, 0.02176657351810718, 0.03187470094417222, 0.014472876955551328, 0.016953705016931053, 0.08170886358129792, 0.04560735702398233, 0.028797717714041937, 0.036678800970548764, 0.013327803389984183, 0.04196957917883992, 0.03901522286469117, 0.009499946681899019, 0.026104393291461747, 0.09350369044113904, 0.011490241104183951, 0.023306615294131916, 0.038120259559946135, 0.004045439100082149, 0.0017223207828465092, 0.00729860123101389, 0.055072608301998116, 0.044944314868189394, 0.05112871680466924, 0.03881107288179919, 0.05696963795344345, 0.03886842605425045, 0.0246239329862874, 0.04092849441803992, 0.06310631608357653, 0.025994935786002316, 0.04503176955040544, 0.0441117327864049, 0.007761459255561931, 0.1056938964757137, 0.012103504632250406, 0.017538144456921145, 0.05846836807904765, 0.03576935836463235, 0.06587467534700409, 0.015712171734776348, 0.05483620087034069, 0.029966552065161522, 0.04318395171139855, 0.03147110990539659, 0.06314783924608491, 0.03370655518665444, 0.027638397696136963, 0.012955118163517909, 0.042609770607668906, 0.055958855082280934, 0.013460156151268166, 0.02720294625760289, 0.039552181551698595, 0.05068108301202301, 0.06504277233034372, 0.061422817161655985, 0.04465107376745436, 0.0877212913474068, 0.02990857363329269, 0.028967268772248644, 0.046726189175387844, 0.07875916053308174, 0.06886066941660829, 0.10090507726999931, 0.028502903260232415, 0.022567647720279638, 0.08300754037918523, 0.07748555348371156, 0.053293487362680025, 0.09232390570105053, 0.035518820441211574, 0.04415588315168861, 0.042342957385699265, 0.0362560291250702, 0.09901539859129116, 0.03565666323993355, 0.042470328480703756, 0.04127771571802441, 0.04232058905472513, 0.01041219089529477, 0.01607243062608177, 0.06401693870429881, 0.03449058596743271, 0.039743310553603806, 0.022158622305141762, 0.04434080037754029, 0.02000701002543792, 0.015929632136248983, 0.042717010946944356, 0.03519220495945774, 0.016027289493649732, 0.02949678928416688, 0.007454639635398053, 0.05995978062856011, 0.00812269221569295, 0.03737362188985571, 0.08713998191524297, 0.011854470485559432, 0.05180558888241649, 0.032403087825514376, 0.04002050271083135, 0.008195894879463594, 0.081133149942616, 0.028285021689953282, 0.04650994960684329, 0.03695539569889661, 0.05207148184126709, 0.023596757928316947, 0.014262472523114411, 0.0408993057499174, 0.0813540056697093, 0.04744827288959641, 0.05533445284527261, 0.0846460614411626, 0.08621004119049758, 0.06889042953844182, 0.03877976538205985, 0.04741707300127018, 0.061570304169435985, 0.051841653548763134, 0.01804070645448519, 0.03923669457435608, 0.06488177823484875, 0.05684107571141794, 0.1274766877759248, 0.01142703702498693, 0.04212697014736477, 0.03375296168087516, 0.06277459091506898, 0.04205179058772046, 0.026453462451172527, 0.024913125671446323, 0.009640840635256609, 0.06671283466857858, 0.0018655711710380274, 0.05730281402065884, 0.08861459966283292, 0.063738388416823, 0.06033122925146017, 0.03827617736533284, 0.02434388912661234, 0.048291137427440844, 0.1140495813160669, 0.01846697567088995, 0.06716700678225607, 0.055031708543538116, 0.03827283770078793, 0.025166624764096923, 0.042835669228225015, 0.04261870606569573, 0.02620916042360477, 0.013761786303803092, 0.04708683583885431, 0.01790894370060414, 0.027078061357315164, 0.035075305568170734, 0.02612289503304055, 0.02326266716409009, 0.07660395625862293, 0.030293290001282003, 0.005242183769951225, 0.06672786315903068, 0.09151123915216886, 0.04535663356364239, 0.038913017997401766, 0.017440336814615875, 0.08545256816432811, 0.008631451146356994, 0.0488233760552248, 0.01499690279160859, 0.06398561265086755, 0.03250518879212905, 0.017535008882987313, 0.03785566535952967, 0.041873233567457646, 0.016001117655832786, 0.12739451718516648, 0.007524702086811885, 0.03130379271169659, 0.026449716460774653, 0.023444010948878713, 0.05116686690598726, 0.10802121963934042, 0.018673392914934084, 0.015160435959842289, 0.0688328017713502, 0.02041884075879352, 0.11697206980898045, 0.10904499009484425, 0.13176250155083835, 0.18073937972076237, 0.10322053349227645, 0.09334316389868036, 0.1907866046531126, 0.13328568544238806, 0.18974186852574348, 0.1641562976874411, 0.16706139023881406, 0.21808220248203725, 0.2013804213493131, 0.14985770947532728, 0.15646932501113042, 0.08145021769450977, 0.1608853114885278, 0.10555916698649526, 0.09484216861892492, 0.21172321401536465, 0.1279673958197236, 0.07936196256196126, 0.17961351200938225, 0.1548254827503115, 0.20237541873939335, 0.10982529900502414, 0.1589109908672981, 0.10305958392564207, 0.09054356021806598, 0.11608252418227494, 0.15529319905908778, 0.12607103039044887, 0.22409969911677763, 0.24052933469647542, 0.10965549561660737, 0.15927173400996253, 0.11273092590272427, 0.18128479889128357, 0.15693543828092515, 0.11596459691645578, 0.15244173409882933, 0.1393748290138319, 0.1858228538185358, 0.16175338678294793, 0.19656269549159333, 0.26583910861518234, 0.14038786059245467, 0.20444743568077683, 0.11306725238682702, 0.08879586181137711, 0.15350296074757352, 0.12288675672607496, 0.158939118264243, 0.2529767691157758, 0.11300294529064558, 0.10939765867078677, 0.17155359528260306, 0.10453591603436507, 0.11818097642390057, 0.11918763295398094, 0.10662313216016628, 0.13234412268502638, 0.1386547676520422, 0.14445862965658307, 0.1538513248669915, 0.07255854638060555, 0.16294155037030578, 0.09958141978131607, 0.09636018716264516, 0.08119842925225385, 0.08313028418342583, 0.12709984002867714, 0.15095780981937423, 0.0950172783632297, 0.15203496295725927, 0.13362447585677728, 0.17432517546694726, 0.07758644103887491, 0.17472492589149624, 0.1467002570279874, 0.06416408432414755, 0.06529653488541953, 0.17065052030375227, 0.08076134879956953, 0.16935556166572496, 0.1819671443081461, 0.09256194956833497, 0.21895220736041665, 0.1056841817626264, 0.12792409892426804, 0.08118250276311301, 0.16704380133887753, 0.11890485984622501, 0.17202315211761743, 0.1769538625376299, 0.1297932572197169, 0.1869588444242254, 0.15549576084595174, 0.11044431696063839, 0.2053139969939366, 0.09552157513098791, 0.1124579417228233, 0.1481052316376008, 0.18349194608163089, 0.17011045943945646, 0.08829441489069723, 0.11867992230691016, 0.23394351621391252, 0.13110760075505823, 0.1423710721428506, 0.1708429740392603, 0.15028990659629926, 0.16684707283275202, 0.2531059621833265, 0.10727398082963191, 0.13752556027611718, 0.14673019526526332, 0.2516273071523756, 0.1663210237165913, 0.3042433806695044, 0.15479711786611006, 0.13096861133817583, 0.18090045545250177, 0.14629154145950451, 0.1788899180246517, 0.1692263240693137, 0.25604139373172075, 0.25812427571509033, 0.11571148745133542, 0.13636110088555142, 0.15880136081250384, 0.2380794903729111, 0.09766141694854014, 0.12003757758066058, 0.11443831084761769, 0.24311243905685842, 0.1945934511604719, 0.1318374733091332, 0.1235248330340255, 0.2549958857707679, 0.11759244589484297, 0.1450574240880087, 0.06090287592087407, 0.09154977145954035, 0.13879653270123526, 0.1254913685261272, 0.12003535113763064, 0.1523894869023934, 0.1297846483066678, 0.12148009744123556, 0.2505299972835928, 0.207319947949145, 0.16179355181520805, 0.17601802916033193, 0.15185806463705376, 0.15153772401390597, 0.09791901640710421, 0.13270602357806638, 0.09073733497643843, 0.13668642874108627, 0.12903138325782493, 0.12762486498104408, 0.11827028647530824, 0.14101714245043695, 0.09942256307112984, 0.24601062963483855, 0.10588768607703969, 0.08501406278810464, 0.1399416517233476, 0.1804110684315674, 0.14185768406605348, 0.18263611622387543, 0.08745309402002022, 0.10628872041706927, 0.13987439830088988, 0.09032928734086454], [0.039029357067192905, 0.032702937751309946, 0.04121902667975519, 0.016942860384006053, 0.10630331846186891, 0.046049821758060716, 0.06488203056505881, 0.041047174963750876, 0.08753861169680022, 0.01611235631571617, 0.040080961771309376, 0.028957236791029572, 0.07575835319585167, 0.0873890912043862, 0.017079226308851503, 0.042538468769635074, 0.061261696901055984, 0.05463162415253464, 0.03363296382303815, 0.11778356376453303, 0.053850061012781225, 0.027947223898081575, 0.06836751970695332, 0.024773086115601473, 0.04653139767469838, 0.11324214690830559, 0.07566971849882975, 0.005836587934027193, 0.012823806264350424, 0.008911721361073432, 0.06330357893602923, 0.04264411349140573, 0.016215325595112517, 0.02963797360280296, 0.03187385118508246, 0.08738069751416333, 0.06197123460879084, 0.051409571460681036, 0.07084205528371967, 0.029947037292004097, 0.028118823283875827, 0.06978260978939943, 0.04005985509138554, 0.05528313333343249, 0.057483408236294053, 0.048728674300946295, 0.023602090259373654, 0.03516099393891636, 0.05111156577186193, 0.012993010368518298, 0.04181145348411519, 0.014660917695437092, 0.06220542301889509, 0.07581771758850664, 0.04734133312013, 0.029332474077818915, 0.03628526232205331, 0.02871566772228107, 0.08321149740368128, 0.05291275076160673, 0.009406009339727461, 0.05715293358662166, 0.03402811664273031, 0.052074175837333314, 0.04662623301555868, 0.026635359135980252, 0.0179442754961201, 0.024354062115889974, 0.0665350235067308, 0.12314169187447987, 0.06213013955857605, 0.09158712375210598, 0.037454564226209186, 0.04029474854178261, 0.02922141724411631, 0.06655780744040385, 0.025882229529088363, 0.02062276438664412, 0.04400856312713586, 0.03573120084183756, 0.023125874504330568, 0.06741521807271056, 0.022944603078940418, 0.06954797980142757, 0.037340885755838826, 0.05076943198218942, 0.015962134493747726, 0.07907346749561839, 0.05081808347313199, 0.01635856937355129, 0.06362455038470216, 0.03574245180061553, 0.05358192676794715, 0.05530349044420291, 0.0305794788437197, 0.013765463645540876, 0.031329738194472156, 0.030576719909731764, 0.027775284979725257, 0.015941461970214732, 0.04425891180289909, 0.04297941210097633, 0.02084718427795451, 0.018502094098948874, 0.009942904016497778, 0.029669514879060443, 0.07255430129589513, 0.04101273931155447, 0.04126946674659848, 0.0366210730135208, 0.023257518514583353, 0.03428341915423516, 0.0225827281610691, 0.01920587645145133, 0.029629997370648198, 0.05873642810911406, 0.035008037302759476, 0.032735332497395575, 0.029579167676274665, 0.02980298457259778, 0.03709574695676565, 0.09931055814377032, 0.043727712181862444, 0.02377912402153015, 0.14104478002991527, 0.022176838319865055, 0.08213191002141684, 0.03865121798298787, 0.06053914563381113, 0.030700832976435777, 0.0028333308137007407, 0.05854316914337687, 0.05280958481307607, 0.011776314913731767, 0.10668807008187287, 0.03775661090912763, 0.01891157779027708, 0.08666317429742776, 0.012202407870063325, 0.015557456208625808, 0.06036503407813143, 0.09568473629769869, 0.06590309960301965, 0.028592745802598074, 0.04265578005288262, 0.050475845782784745, 0.08693045878317207, 0.009743927730596624, 0.030848412752675358, 0.029390383861027658, 0.017581500724190846, 0.10790941509185359, 0.05844802210049238, 0.021554710765485652, 0.03324547738884576, 0.04150840861257166, 0.048167636632570066, 0.02472223601216683, 0.01772406729287468, 0.05952238476311322, 0.04493866341363173, 0.027015722807846032, 0.005096339691590401, 0.07647520105820149, 0.08109101821901277, 0.027505326906975824, 0.08823166630463675, 0.04771067775436677, 0.05460136308101937, 0.05325580852513667, 0.02786186207231367, 0.0118410877075803, 0.06077126345189754, 0.04927360365400091, 0.03352480322064366, 0.04901796346530318, 0.02601533371489495, 0.04432741574419197, 0.09259876751457341, 0.03291262786660809, 0.04124105362279806, 0.04413448703417089, 0.01853175403084606, 0.02432794964988716, 0.05179831583518535, 0.0063612534086132655, 0.024921818076109048, 0.01749439299601363, 0.03885908241500147, 0.022930287050257903, 0.04394083844090346, 0.10338943888200447, 0.06028900847013574, 0.03574626643967349, 0.009759058266354259, 0.094035929068923, 0.030872174465912394, 0.026187007315456867, 0.04438312134880107, 0.056239186524180695, 0.09854699950665236, 0.09136492473771796, 0.039542392623843625, 0.007323550844375859, 0.06058593062334694, 0.04614918419974856, 0.025838290675892495, 0.024581190846220125, 0.024953902975539677, 0.048693040080252104, 0.045821923049516045, 0.03250127767387312, 0.05837892444105819, 0.058947888246621005, 0.09682270101620816, 0.03915624947694596, 0.02398544664174551, 0.04682483173382934, 0.02849813496140996, 0.05859394317667466, 0.030630538603872992, 0.03520472499076277, 0.046008747594896704, 0.0276469323944184, 0.03738531442650128, 0.04860096552874893, 0.0653077190509066, 0.009454146893403959, 0.03589747902879026, 0.021296820013958495, 0.07842545383027755, 0.04439312178874388, 0.04494263390370179, 0.07561140053439885, 0.046838836060487665, 0.020462983702600468, 0.02748386028542882, 0.0537096615153132, 0.005474104918903322, 0.05676949556800537, 0.04344408560427837, 0.0023088724447006825, 0.08746145060285926, 0.031280366820283234, 0.07647850361536257, 0.11258302329224534, 0.09669448758359067, 0.04804539006727282, 0.028379639952618163, 0.05620672869554255, 0.015813009194971528, 0.012962626842636382, 0.027958244791079778, 0.022864311977173202, 0.027824454118672293, 0.03479533777863253, 0.05761638625699561, 0.05367639474570751, 0.025115544594882522, 0.013709631875826744, 0.015059142078825971, 0.021649447771778796, 0.03193728996848222, 0.03686619696964044, 0.004659067672037054, 0.023471069653169252, 0.01381710784698953, 0.0651489439769648, 0.061952513933647424, 0.07258902638568543, 0.01558483960252488, 0.05095857944979798, 0.04979092882422265, 0.015212141388474265, 0.12648268486373127, 0.04227581899613142, 0.002958877153105277, 0.0351824531389866, 0.02877021372114541, 0.04952811206749175, 0.02926600176579086, 0.05722000889363699, 0.07270520960446447, 0.03406337236810941, 0.05980807822197676, 0.022352862761181314, 0.03902536802343093, 0.04170811313088052, 0.03804545849561691, 0.04141977391554974, 0.003131160706288938, 0.002900664248954854, 0.03312199143692851, 0.03322747288621031, 0.04033614182844758, 0.0382616461138241, 0.09125617041718215, 0.071265057194978, 0.014748120975127677, 0.07889798667747527, 0.09977555077057332, 0.03520696256600786, 0.02869550542527577, 0.0777328222466167, 0.029090459720464423, 0.05098276975331828, 0.053285717076505534, 0.09876239302684553, 0.07804956345353276, 0.02208727593824733, 0.03827762084256392, 0.027604442584561184, 0.02091686452331487, 0.06200403382536024, 0.028971593637834303, 0.032481662710779347, 0.07455945815308951, 0.06508714533993043, 0.03810686008364428, 0.04258922053850256, 0.0381352286785841, 0.029955803911434487, 0.029315349020180292, 0.0024878561998775695, 0.08070111609413289, 0.02441836921207141, 0.03404523798963055, 0.06720358724123798, 0.010163968472625129, 0.04909552160825115, 0.003303215121377434, 0.040233988911495544, 0.023515598513768055, 0.025213461703970097, 0.022620342060690746, 0.04077752302691806, 0.08014609353267588, 0.030013459509063978, 0.04067406393005513, 0.030654502552351914, 0.007867649455874925, 0.07717408894677646, 0.007059561958158156, 0.014432280549954157, 0.029188395383243915, 0.028561994913616218, 0.023018277934170328, 0.02228645909781335, 0.031214508635457605, 0.02964621515275212, 0.03533191425958648, 0.029729845919064246, 0.08847975142998621, 0.17257444909773767, 0.1748487606528215, 0.09080542702577077, 0.15616738965036348, 0.18276097514899448, 0.13487613759934902, 0.13428764417767525, 0.14655867009423673, 0.12430431816028431, 0.12402667329297401, 0.11462185881100595, 0.17939739860594273, 0.13391173153650016, 0.11826629372080788, 0.2509859431302175, 0.1247805097955279, 0.1260380048188381, 0.14256515860324726, 0.19395297771552578, 0.12735524273011833, 0.08928009832743555, 0.16645533760311082, 0.14420610648812726, 0.16631421080091968, 0.21805725147714838, 0.16590108687523752, 0.13122374686645344, 0.12952553486684337, 0.1088586516561918, 0.09845917375059798, 0.10423244442790747, 0.16134087141836062, 0.13155432912753895, 0.15142892516450956, 0.12930631928611547, 0.2194935001898557, 0.24768948642304167, 0.1857435776037164, 0.11703537500579841, 0.1511825469788164, 0.26612168876454234, 0.12780703254975379, 0.11190162782440893, 0.19912666728487238, 0.10712017814512365, 0.11780838860431686, 0.1220808140351437, 0.09664048891863786, 0.1245067389390897, 0.19316477235406637, 0.10143144550966099, 0.3572787973098457, 0.11822146057966165, 0.1358304949826561, 0.10055221573566087, 0.1819984777830541, 0.18826555868145078, 0.1233938142831903, 0.13526928290957585, 0.14959251042455435, 0.2229516115039587, 0.14560593059286475, 0.13568332709837705, 0.08474593225400895, 0.13260914362035692, 0.2308653251384385, 0.118420259677805, 0.16700501670129597, 0.2390793859376572, 0.21753111330326647, 0.14740299666300416, 0.13932949863374233, 0.11019243946066126, 0.1796884837676771, 0.16182371269678697, 0.13996363413752988, 0.08625771675724536, 0.1112744833517354, 0.08412621667957865, 0.16843430406879634, 0.16941717476584017, 0.10117477373569272, 0.18586790218250826, 0.11869243491673842, 0.167653564712964, 0.12173021605121903, 0.14273993438109756, 0.2467241304111667, 0.09606664549210109, 0.227172190498095, 0.14331330283312127, 0.17805538780521601, 0.15686149068642408, 0.16408917785156518, 0.15201675065327436, 0.09670242114225402, 0.17473834392149, 0.1838640886126086, 0.14105131092946976, 0.09808634102228098, 0.15755815955344588, 0.09296424555941485, 0.2239546983037144, 0.17556742677697912, 0.09653235058067366, 0.20940927177434787, 0.07794523975462653, 0.12970989919267595, 0.10861619201023132, 0.1128325704485178, 0.17003608139930293, 0.13073945097858086, 0.18787961220368743, 0.14987593662226573, 0.09600410470739007, 0.13507844705600291, 0.10515385045437142, 0.1788247426156886, 0.10989143920596689, 0.16193424817174673, 0.10643576213624328, 0.10930014788755216, 0.19839311367832124, 0.21791662933537737, 0.15110617998288944, 0.18865726422518492, 0.2425953550846316, 0.14398522849660367, 0.1471906978986226, 0.16014509339584038, 0.18244354374473915, 0.11340682205627672, 0.07996457163244486, 0.17563647619681433, 0.10244127101032063, 0.10148498404305428, 0.2036389845306985, 0.1613936826470308, 0.09975193563150242, 0.1479564607143402, 0.2116712785209529, 0.1892252149991691, 0.13264421751955524, 0.1063521666219458, 0.10328241376555525, 0.1692044158698991, 0.11119472474092618, 0.25880120345391333, 0.2874965808587149, 0.1130271318834275, 0.15443928394233808, 0.06994814582867548, 0.16654104081680998, 0.1754839054774493, 0.1079671319166664, 0.1335335776093416, 0.15668327134335414, 0.10080857580760494, 0.19952254369854927, 0.24447321135085076, 0.1648073541582562, 0.11325555751682259, 0.16614811815088615, 0.17216824198840186, 0.14856747089652345, 0.13145771634299308, 0.11788961666752584, 0.08484727994073182, 0.1780350974877365, 0.08814654938760214, 0.10296251100953668, 0.14503648068057373, 0.1495518852607347, 0.16216634743614122, 0.10342748879338615], [0.018418253675918095, 0.03490146489639301, 0.08507755352184176, 0.033764695035642944, 0.01328306672803592, 0.0377986684179632, 0.024806048604659736, 0.06939527549548075, 0.021486401637957897, 0.005239175288807019, 0.0399288882908877, 0.09213894023559988, 0.020710259886982385, 0.057733088979148306, 0.024532843635824975, 0.06907746559591033, 0.05021900331485085, 0.02239785546407802, 0.03746284288354218, 0.016079223132692277, 0.02709738131670747, 0.05294044029142242, 0.02608998449431965, 0.01926445973367663, 0.028775679638783913, 0.02244111896288814, 0.04367495661426801, 0.012285614684515167, 0.03254242234106641, 0.028896605181216728, 0.027918124287680257, 0.05582621102803387, 0.033214548384421505, 0.0346012476074975, 0.04672430412028916, 0.047275363613152876, 0.025729799817781895, 0.04204092554573435, 0.02867891285859514, 0.04899463405308779, 0.025562185765011236, 0.023199924144137185, 0.001779874683052185, 0.050832143460866064, 0.04220617585815489, 0.06158841628348455, 0.06963441774132662, 0.021041508225607686, 0.015538686366198817, 0.07646650308743119, 0.03240944803110324, 0.03467356618784834, 0.02826201140123885, 0.03597256953071337, 0.01086291202227585, 0.037358051631599665, 0.06595913175260648, 0.022681931041006465, 0.03970746482082177, 0.04000085435109213, 0.021151552027731668, 0.017215046755154617, 0.07534395277616568, 0.08332290119142272, 0.022979407949605957, 0.026164026712649502, 0.05042283046350349, 0.005896869806747418, 0.04027556402434129, 0.08788519466179423, 0.06845829178928398, 0.038033869859646074, 0.022781365842092782, 0.015529759257333353, 0.011931170520256273, 0.059399859892437235, 0.03505918612063397, 0.004045412661071168, 0.046962429623818025, 0.014306064422271447, 0.02111091758706607, 0.019179107184754685, 0.01638598245335743, 0.07130774552933872, 0.03319972769531887, 0.024350436724489555, 0.0931162819324527, 0.0691243915935047, 0.0093525301781483, 0.032278974758810364, 0.0037521557896980084, 0.04770697814819869, 0.040782417490845546, 0.018936708765977528, 0.020180769060971215, 0.019603777072916273, 0.026594028931867797, 0.042707440952654, 0.02084392253891565, 0.053965943661751226, 0.026327432788093574, 0.06533497813506983, 0.0049834942819870776, 0.052458051723078825, 0.03222755876777228, 0.0201624695546343, 0.0194946164265275, 0.029735504795098677, 0.04722135381598491, 0.013079009513603523, 0.026660920557333156, 0.03427925941650756, 0.047212485151248984, 0.09490760377957486, 0.05263939921860583, 0.037188749192864634, 0.02707706873479765, 0.036820951936533675, 0.05653482105117291, 0.020669306322815828, 0.08663770378916524, 0.014139057075226447, 0.027625790462479927, 0.06925814144778997, 0.04191183266812004, 0.12654211604967713, 0.024753016587055754, 0.02864921396394493, 0.03100207442912506, 0.017787615543056745, 0.03834936796920374, 0.015288797821995104, 0.03893136388796847, 0.00658452807329013, 0.07722260314039886, 0.0718858340405859, 0.021398336539277807, 0.03637619396613445, 0.02428055424388731, 0.08043573150644079, 0.0453538430883782, 0.044078744322177954, 0.030299397876660805, 0.03938919850043021, 0.024154737948265392, 0.026587126958474983, 0.04423973099619616, 0.09024792569107376, 0.05859759454324376, 0.010448945758980699, 0.04383444043924101, 0.11199853746802546, 0.058750013122335076, 0.028618861979339272, 0.0480858519586036, 0.055058696743799374, 0.046081114414846525, 0.05941826144407969, 0.025206645077560097, 0.03270147200964857, 0.060578746633837, 0.06230516766663641, 0.038898178754607216, 0.05372118335799314, 0.07745873226667754, 0.01425313073923462, 0.06998291544732638, 0.02278798579936847, 0.03173578945279587, 0.019153803659719415, 0.029713006588281132, 0.0855400376894977, 0.07667792611755431, 0.020361428214528132, 0.020727910014102235, 0.024642542339279316, 0.026331028493586928, 0.06245262498850934, 0.08588965603848919, 0.04322316308389418, 0.03229541704058647, 0.06587745097931474, 0.037248655353323556, 0.061234879394760355, 0.04579034466587473, 0.03498615507851355, 0.04035009791550692, 0.04374160518636927, 0.07855718504288234, 0.029344016329559963, 0.039013556743157096, 0.04496054563787766, 0.02852098197763553, 0.029320056091819424, 0.045397963767754845, 0.03385508491192013, 0.03925699602405075, 0.039910041450639255, 0.019707520041265525, 0.030065385726629756, 0.05400160014687572, 0.06430650988477282, 0.05015898212150205, 0.03694058985274751, 0.056670214762561955, 0.02735004363785265, 0.006634297424170654, 0.023663232095714193, 0.009490176307735965, 0.08469171094475314, 0.03184740104188677, 0.05888709893042687, 0.020680711277236696, 0.034035775606753305, 0.07337438932154328, 0.051225314746261574, 0.05890332970011514, 0.010164109480683692, 0.08016215360839851, 0.11155231375596486, 0.059639978062477894, 0.05897506569453981, 0.017040794191416353, 0.030662705139548052, 0.023016114573692903, 0.07471839649952017, 0.016085351417132188, 0.018661492576939054, 0.08464444355922751, 0.02947674202005146, 0.01780498365405947, 0.04351774376118556, 0.02389518664131174, 0.02014221448916942, 0.02980746157845715, 0.030303370222100057, 0.02048548933089478, 0.024022926954785362, 0.020333497486717533, 0.006042360437277239, 0.030240398991736583, 0.06873195132357068, 0.03008446263265796, 0.03890244239300955, 0.046664242108818144, 0.011067731793446, 0.03864692465867847, 0.05106910008180421, 0.03313201043056324, 0.0731266381626483, 0.07404293821309693, 0.02140411044820212, 0.082699957274599, 0.020626553050533403, 0.05440561049908865, 0.06161835823149886, 0.012056129635311663, 0.014701162508572452, 0.03896736918250099, 0.015058942626637872, 0.05097185647173319, 0.03317728143883869, 0.04949906811816618, 0.01654109131777659, 0.029143914762244094, 0.07401521157589741, 0.01763417836627923, 0.01812226477341028, 0.07223974200314842, 0.011803991455963114, 0.04712560934422072, 0.034448168516973965, 0.05183504843444098, 0.06291601457633078, 0.04076402336067986, 0.049559367616893724, 0.06815237109549344, 0.03391827136510983, 0.014678925908810925, 0.055611600473639555, 0.06867338845040649, 0.02522242684790399, 0.03484496148303151, 0.015448415233549895, 0.01900365976325702, 0.04801409741048701, 0.022492067400889937, 0.02177843860408757, 0.05016320494178217, 0.08370203475351445, 0.057340388957527466, 0.04337957070674747, 0.03510640155582223, 0.03378976107342169, 0.13957887509604916, 0.02433004065096611, 0.011501861281431047, 0.017506577205494978, 0.02988720720168203, 0.016817309406178538, 0.05367892918002326, 0.02895676181651652, 0.006418922457669396, 0.05044992627517786, 0.053067918997840025, 0.03171433025272563, 0.023544380856037606, 0.09355819376651198, 0.020957448869012296, 0.020585944585036486, 0.04016455728560686, 0.017773676154320128, 0.05357938491215464, 0.07017613359494135, 0.028175577172078192, 0.03910574632755015, 0.09158365050097927, 0.043223252141615376, 0.029492104476958048, 0.05449359210615512, 0.015511708370468114, 0.01386407373502152, 0.050421186606399715, 0.07319352793274447, 0.013951267737866146, 0.03485864668618888, 0.05117804364999756, 0.055119014796218835, 0.03401102869247552, 0.06291300887824036, 0.04330340409069322, 0.11035615723812953, 0.04710836183221545, 0.010064774869533721, 0.027866609962075017, 0.03179774765158072, 0.022271688503678888, 0.01327440864770324, 0.047049713612068444, 0.01905284560052678, 0.06197062604769599, 0.04567170864902437, 0.01322410495049553, 0.04411818204971496, 0.04750443120428827, 0.009160822301055305, 0.0432619996718131, 0.1539415997103788, 0.030310324145830236, 0.03659970658191014, 0.03849516659101937, 0.02542400899983477, 0.11963694400037639, 0.15449999162228778, 0.19366305030416697, 0.16341827635187656, 0.13111307780491188, 0.173910878947936, 0.13281578721944243, 0.09455561055801809, 0.1515547785675153, 0.15986046491889283, 0.1886426142300479, 0.18770728551317006, 0.12205483886646107, 0.10693802541936748, 0.11010736707248725, 0.19883883272996172, 0.1261884529958479, 0.17108727421145886, 0.07279478682903573, 0.15654977381927893, 0.11176340281963348, 0.10613327758619562, 0.13617231335956603, 0.09361923541291617, 0.1722915275604464, 0.19982989673735574, 0.17028504225891083, 0.05232013470958918, 0.16591444553341717, 0.15171322709647939, 0.17239781795069575, 0.11094116998719983, 0.1857176172779873, 0.21607914590276778, 0.1494755331077613, 0.1845974789466709, 0.1528988970676437, 0.11897817661520094, 0.1555266193463467, 0.24008563428651541, 0.13514905498595908, 0.1624954305589199, 0.19297966588055715, 0.23368697060504928, 0.11806775437435135, 0.12522643664851785, 0.13159792288206518, 0.20598252362105995, 0.10161788784898818, 0.18464901368133724, 0.14383745205122977, 0.1502008637180552, 0.15974945446942002, 0.08090171118965372, 0.12949172261869535, 0.12806472106603906, 0.11348243948305026, 0.09493217628914863, 0.15119541581952944, 0.1936065877089277, 0.18482506595319137, 0.07676309498492628, 0.15101541532203555, 0.12567562895128503, 0.0896591428318061, 0.1507103184121661, 0.09553417679853737, 0.11981589806964621, 0.11310115369269624, 0.2988731110235676, 0.1470090646762401, 0.10476390380063094, 0.09840078899287619, 0.11405902885599062, 0.12598274450283498, 0.19869766139890999, 0.15024380438262597, 0.12242223907378502, 0.16909267811570317, 0.12176038435427472, 0.12099865882191807, 0.10185001679928973, 0.06312985700787976, 0.11472132144263014, 0.1287538348697126, 0.15782611939357594, 0.23262797039933503, 0.13373890018556267, 0.10025750147178769, 0.2824726566905156, 0.10996381344739348, 0.09455333216465078, 0.17201527050929144, 0.19612954842159525, 0.1714639735291712, 0.08768764979322441, 0.10035735002020374, 0.129603786917869, 0.148237363609951, 0.1417653015232645, 0.18201863451395184, 0.10195487484452315, 0.09335299735539593, 0.11687298567267135, 0.17254455538932234, 0.08905375812901184, 0.09294789604609832, 0.09977620386052877, 0.2261964147328399, 0.08508313447237015, 0.12467206717701629, 0.10199767450103536, 0.19822785223368555, 0.24005311337532476, 0.1533151083276607, 0.22358534624800086, 0.15248191397404298, 0.12199749311548658, 0.23545791307697073, 0.16964976384770125, 0.21494170068763196, 0.06017979030730203, 0.06793698499677703, 0.15414696681546047, 0.1652935944730416, 0.15242442721500993, 0.08129844849463552, 0.19125053600873798, 0.11287573375739157, 0.09239527804311365, 0.08993501396616921, 0.15596415993059054, 0.13281378342071548, 0.13090719119645655, 0.18003275123191997, 0.19395734154386446, 0.08060929016210139, 0.11478290485683829, 0.1406649043201469, 0.14475603791652247, 0.2997609868180007, 0.19885983550921082, 0.16489731729961932, 0.10067184994113632, 0.17787843011319637, 0.17066123691620305, 0.18894981883931905, 0.24402971874224022, 0.16412919445428997, 0.17034174234140664, 0.1780526715447195, 0.19327861780766398, 0.1915420961449854, 0.22181812935741618, 0.14352016907650977, 0.20501468883594498, 0.0928745124838315, 0.12996588076930493, 0.07798020233167335, 0.14208577573299408, 0.08929302653996274, 0.06807352532632649, 0.19440116069745272, 0.12224019767018035, 0.146208836522419, 0.2660661464324221, 0.1676027721259743, 0.08141463171341456, 0.2582492830697447, 0.12506680068327114, 0.08021679052035324, 0.18925260024843737, 0.2454807807225734, 0.0604014030250255, 0.11669329687720165, 0.10584287520032376], [0.04444956583029125, 0.0818447137135081, 0.03451832373684738, 0.0474270289123524, 0.05731274766731076, 0.03787381458096206, 0.043628884086501785, 0.03466448972176295, 0.04963531158864498, 0.04705551720689982, 0.04129373868636321, 0.03316238282423001, 0.05280688339553308, 0.019696218987519387, 0.07098195012076758, 0.05266739673970733, 0.02644551219418645, 0.04634768272808287, 0.02393993072473677, 0.09355967806186527, 0.01516025877208449, 0.013092383942421293, 0.01296413896852755, 0.024569231136410963, 0.027647772876662202, 0.1455314931808971, 0.030370890817721374, 0.08356679318239912, 0.06678279693005607, 0.026858085075218696, 0.04290967248380184, 0.061745677376165986, 0.0560853689967189, 0.05171063850866631, 0.04988897766452283, 0.04259148037817795, 0.08603089416283183, 0.05830846494063735, 0.07599944729008712, 0.04902996028249618, 0.06100852806412149, 0.06808847218053415, 0.07626411941600963, 0.05598135699983686, 0.024704923562239856, 0.04387294306070544, 0.05868422915227711, 0.04042927022965159, 0.0523040189727908, 0.03425819726544432, 0.011731446520570898, 0.039766870031598955, 0.02420291075395653, 0.024873762158676982, 0.017389546082995366, 0.05155377075425349, 0.021164368918107357, 0.05347745092876721, 0.07249967922689393, 0.021320841478882357, 0.04614345853042323, 0.013701102743652882, 0.008985219028545544, 0.097458098171046, 0.057103699509752914, 0.06516867768368684, 0.0431827234569937, 0.04895723352092318, 0.018154175268136896, 0.036057471224921755, 0.04351408497313969, 0.036773317187908106, 0.04403711725899484, 0.012193693200970301, 0.02715140966756735, 0.004177322452960652, 0.06326453454676084, 0.011555520413821796, 0.028477785272116307, 0.04449166786798742, 0.03631089239206631, 0.028220913118275348, 0.08078328668489121, 0.03590934968087822, 0.013293589454406174, 0.006574692297363072, 0.05692453392839525, 0.03270275592512917, 0.03310763830086216, 0.04220292525133118, 0.03518417121085804, 0.006610567252209876, 0.010935190712189069, 0.08242647585575469, 0.10398705329862423, 0.017558926447236445, 0.05057939393736888, 0.016815839953778777, 0.013208851960371248, 0.02125934712239541, 0.014472439088422107, 0.04259440072928555, 0.05889004154596478, 0.05596607246843632, 0.027176364383194596, 0.047719082576804794, 0.02768833866866771, 0.038612522403127514, 0.025288750730396714, 0.016030911174311768, 0.023245091251737904, 0.050748796566040255, 0.06815704662585631, 0.11446703938418068, 0.06681892467895523, 0.10954163532005623, 0.018837268398783635, 0.03677323184092529, 0.06517834786791354, 0.015508832548221108, 0.026728305711003486, 0.03789158530707937, 0.05103545110614505, 0.057816999906208366, 0.031183464598143473, 0.04963974221027456, 0.03428832103963941, 0.0030693968574269093, 0.05069718761660624, 0.014461880182352616, 0.056676537860766985, 0.0056426670653308975, 0.005953141762802261, 0.044149044260848314, 0.03526513210090343, 0.03920438146451488, 0.04335990008257795, 0.05207919646636583, 0.04318231156503316, 0.02440743181068683, 0.023346182897512335, 0.03010625579918269, 0.034035419375868514, 0.036257112660678104, 0.056054966917145066, 0.06989904533838853, 0.08673160031321459, 0.03275647257396486, 0.007749645192234311, 0.035777770608547144, 0.03476665006019175, 0.09774012170964852, 0.04358923113613855, 0.028300942612986546, 0.04875897619058378, 0.0689331475587096, 0.02829988134180894, 0.010530078270676313, 0.045101798605173826, 0.06847142038168386, 0.059790255545522086, 0.024413335595454555, 0.08349479001481086, 0.07807103378581814, 0.05156370811164379, 0.013338735225261189, 0.0711284574936144, 0.053731172665720806, 0.015882563275226858, 0.09184451540932059, 0.06406407992471941, 0.01767393150657881, 0.057011688040802255, 0.00863188808580162, 0.06272990620345809, 0.022455444268416613, 0.0524502443295205, 0.07606103070429526, 0.02902853120758664, 0.03309465442725923, 0.029259663824632298, 0.04134511385927908, 0.030224025358620565, 0.02384588948189048, 0.021666737957275473, 0.029046914205537178, 0.054406014969572425, 0.02929690665041562, 0.05511939700227231, 0.01503636649431428, 0.026445245021022856, 0.02854193651728565, 0.020205794280627742, 0.00950901387113845, 0.018352911283727735, 0.04743672878248617, 0.05342685501091182, 0.036122984311077744, 0.033991936943493783, 0.04179866627964657, 0.0655690069834236, 0.036559856962412596, 0.06391876740963198, 0.06883272013510577, 0.06594206977752037, 0.06376101649948396, 0.047114632980083115, 0.05344497083569877, 0.014803440662944922, 0.026546366352704354, 0.08394709933781996, 0.06638430073508061, 0.04546923591988161, 0.0944967359828297, 0.07859861914766952, 0.03413631806324702, 0.026075486639456358, 0.06734104783390649, 0.03709285629156511, 0.07344158337218687, 0.01583147753990488, 0.05436376821307931, 0.060872269750689156, 0.026185467359027825, 0.0332259923015954, 0.013704039793083211, 0.01127093832110404, 0.046945274880272336, 0.009836698045546655, 0.051896427758038044, 0.017730820836732164, 0.01740945976052899, 0.022037776543584187, 0.01784620439138962, 0.04338191218266729, 0.07684620068175718, 0.088766183325788, 0.031439973099622875, 0.04952630122716073, 0.03951950478949584, 0.07618214178364724, 0.04584607624565251, 0.03270901594078168, 0.04368045963929035, 0.060156468316563405, 0.054038711241446435, 0.011637493407761212, 0.08958363672718406, 0.012075556278432487, 0.033551672677276656, 0.06322865912807174, 0.022265623301791493, 0.024379760834563058, 0.06363733016769402, 0.050207303356728517, 0.011504896665428532, 0.0363445339462487, 0.06655797071289271, 0.03123660608252976, 0.023806466597307008, 0.005897184755667695, 0.03276963827374857, 0.048172501410590485, 0.04290527154807933, 0.024224058252002578, 0.041734707992873155, 0.08159107732353732, 0.04075402292073704, 0.09607406696886756, 0.03433434532780666, 0.03292003821115941, 0.047838360551395454, 0.05632932035950944, 0.017877894097182434, 0.0162755286146421, 0.05347230784536805, 0.027497604860400315, 0.05051011816249229, 0.07409494792227633, 0.028833769392804243, 0.01996527164010331, 0.024491758340445813, 0.01433079834896489, 0.03681086243886966, 0.044989129455643706, 0.04404683939355891, 0.025013573504111264, 0.037184882603469305, 0.08769231790211052, 0.02322895139514003, 0.006139525657999911, 0.03265614534029737, 0.013637201973324409, 0.0203397018412943, 0.03751156858925242, 0.030812075347057544, 0.016714909725124016, 0.024081870178633835, 0.017316342491540127, 0.019715945272764657, 0.012311820846662158, 0.07351182764978148, 0.0242201137371012, 0.06390793205355294, 0.02577008359367028, 0.05551882459258195, 0.042985738909919746, 0.04551862584776245, 0.05709589211619459, 0.04521769980783574, 0.008952354874054436, 0.04141904290008824, 0.02907675225287676, 0.03884107049088925, 0.055302444015978836, 0.023754538524372038, 0.03837700183794368, 0.06448865518905222, 0.03861879726173356, 0.041784743589232676, 0.03634211825556122, 0.061703686660621315, 0.07168396245106123, 0.07035427872324362, 0.015385456063086167, 0.027221440577704925, 0.013658254847541684, 0.08372097436222248, 0.05057968337496277, 0.03955286061682273, 0.05195110548811499, 0.048479238466825336, 0.03246156906243414, 0.036802568938583136, 0.0029280012586241355, 0.06607357834582217, 0.06525793578475714, 0.01826681473175995, 0.12240501382621005, 0.03323481272673234, 0.02708832897042157, 0.04548924422124401, 0.027016643070965074, 0.03888971084961668, 0.049348764659953304, 0.0533967386581935, 0.01422610543158953, 0.025820414193731267, 0.03915642017091159, 0.02539021345000947, 0.02684919414605247, 0.02655164302268531, 0.20503926876699552, 0.1593355883960612, 0.08262619521701708, 0.131383991392795, 0.16191369068110362, 0.15991234104149044, 0.15812852972885594, 0.104377244861098, 0.09230767493136227, 0.12150814320193604, 0.2181670448044315, 0.18543637299444526, 0.2070304361404851, 0.15035224700113758, 0.11657601527986117, 0.09561423226841725, 0.09853939991444349, 0.11435172447818331, 0.13672795932507142, 0.24721954367123544, 0.09694876222056337, 0.1331240456784144, 0.08854576546582393, 0.17023074673488736, 0.17750106286257505, 0.2051055573974736, 0.13954354886664078, 0.1750266386079602, 0.11309034802252427, 0.12015525251626968, 0.1615388467325829, 0.1436470021144487, 0.09938175237039104, 0.12119141683797352, 0.169470728142187, 0.12851167208282277, 0.11471965903183445, 0.2343825262505561, 0.2268190766335465, 0.11359906056895852, 0.12476145144319162, 0.18306531506823376, 0.1349052001023665, 0.19616910489276052, 0.15196527529042214, 0.1644413120811805, 0.14292648062109947, 0.10586689109914005, 0.11942624085349962, 0.10980278966599144, 0.09844274260103703, 0.11255580873694271, 0.13782463094685227, 0.05619441646558698, 0.06186709644680377, 0.14444378670305014, 0.13197291526012123, 0.12253663371666335, 0.10691285177017562, 0.15508284472161904, 0.1520771169452928, 0.13121730502462015, 0.13921394624048844, 0.1487835546140559, 0.18185122084105387, 0.17213422193890437, 0.10505866259336472, 0.11776797866332345, 0.14287657861132175, 0.1080960949184373, 0.09003419458167627, 0.14736909535713494, 0.1401537872152403, 0.12541517964564264, 0.10500503500225022, 0.1164398534456268, 0.22419300192268565, 0.18145375623134896, 0.1617979453294538, 0.11531365176779218, 0.13087505620205775, 0.10950570795102976, 0.17105171049479395, 0.10968507020152174, 0.09267903078580275, 0.10022001559264027, 0.10135924196220003, 0.13776977139059454, 0.20743416447658092, 0.17705114325508475, 0.17243652837350965, 0.2899524662643671, 0.18204193795099854, 0.13919629796873778, 0.20017949282191694, 0.09352470806334168, 0.12022647642879747, 0.12121530657168478, 0.09385295998072252, 0.08571234211558476, 0.10434727693791501, 0.21312907920219004, 0.13560071121901274, 0.10522070311708376, 0.09346083883428946, 0.07975051397806965, 0.20991281897295266, 0.11926799270440824, 0.207562422438059, 0.12409411967382766, 0.16757148317992687, 0.2314838013262488, 0.15587020403472707, 0.17723345925332978, 0.16122644708957523, 0.24900233082007617, 0.06996530428295955, 0.1001468843605835, 0.1419980390346609, 0.13061144534731284, 0.16798904514871538, 0.15548658790066838, 0.12057477375492454, 0.15048402274260297, 0.12809048843337223, 0.2257454561186023, 0.17067512992070988, 0.1703456905670464, 0.12300763773964718, 0.15303925203625113, 0.13296099583385512, 0.11992270054179244, 0.13798362866509706, 0.12791670713340864, 0.18887532205553725, 0.11141938768560067, 0.11894562601810321, 0.15811540855793282, 0.16547041857847944, 0.12205157341668382, 0.13063172082183883, 0.10106814937898889, 0.09737229847814888, 0.09845516615314409, 0.23904208559542894, 0.4227054677903652, 0.1597313312231563, 0.16205670253839344, 0.12018352834274992, 0.07320101620280184, 0.18126878334442154, 0.13959423755295575, 0.12088656483683735, 0.11771767589380033, 0.14328003977425396, 0.24067009042482823, 0.10599911212921143, 0.08597994572483003, 0.1199515255575534, 0.16668803058564663, 0.20112896687351167, 0.0962136649468448, 0.19417468691244721, 0.18468471098458394, 0.15513703634496778, 0.10357972554629669, 0.13370329194003716, 0.10207752959104255, 0.11778203494031914, 0.12250581974512897, 0.12457291624741629, 0.06879141219542362, 0.17682539677480236, 0.12193700807983987, 0.1635100058047101, 0.05678484318195842], [0.020511727962002624, 0.01616991914488608, 0.03183534485287964, 0.04198739072307944, 0.022782987434766255, 0.04209072365483735, 0.10969240262056701, 0.012994854605494766, 0.04836369720578659, 0.016601550378254615, 0.043143794100615196, 0.04170157480984926, 0.017001684864226263, 0.06911239848705009, 0.0779239772236906, 0.029162852515582927, 0.03971647449361626, 0.03917420202924404, 0.04147731633565854, 0.038060045408201404, 0.008557658475183416, 0.05611706612398848, 0.018112538928107824, 0.0412935197527986, 0.030265465029515326, 0.030252839242166374, 0.035978369414806366, 0.0245231660301215, 0.04747606632008683, 0.07515192948631011, 0.017181856055685785, 0.01152950999312452, 0.03511413473461289, 0.03339984410558827, 0.10785006554215215, 0.0390077791234944, 0.008732334990781965, 0.04477680842683185, 0.08253864405560307, 0.050566354402690195, 0.042011744299088605, 0.011091226333519444, 0.047287078414228745, 0.017902785730257165, 0.06458611402194947, 0.050669498086790554, 0.08955550190876238, 0.03824786814220715, 0.013776288797089364, 0.01024019260512432, 0.06039469029929023, 0.0796256327885203, 0.040051134856184945, 0.07171131801442243, 0.04094121482921764, 0.09502949411398731, 0.006595920503968955, 0.017030457929649856, 0.056897193207987584, 0.02279084306792356, 0.05813065748952795, 0.04081213308381848, 0.09652446155087091, 0.04327510599978268, 0.01997821655095322, 0.0678164379496593, 0.04123687162064016, 0.03005193986609811, 0.013782834539597388, 0.04828830984479282, 0.045392008032649755, 0.028039354110660497, 0.023987470849533565, 0.06650931551121175, 0.015442196963704191, 0.07396042623440735, 0.04736061782750767, 0.03721294320712332, 0.013857972353434889, 0.07005707084317692, 0.03843914186290931, 0.0394069284084253, 0.1243528768827673, 0.046833214291837066, 0.03361275885254145, 0.03532869704940822, 0.036489052363322116, 0.04610186486388557, 0.08401563667575829, 0.04291815152100753, 0.04586917559208814, 0.02182614571211161, 0.0045822693027730566, 0.024583805061411113, 0.060938242968404666, 0.06297790969256312, 0.0634308424196206, 0.04447636107215658, 0.03498966543702409, 0.0322118846088415, 0.059143306862097234, 0.008403693445870886, 0.04962871389579959, 0.06487918071798049, 0.04753868131956551, 0.03756367848836817, 0.07968006932060234, 0.04168843137449585, 0.04490820567298215, 0.0340081788453972, 0.05961132745142095, 0.015125692316360073, 0.09298296252381988, 0.057829048673738725, 0.030747482524020597, 0.08627678995253518, 0.027830747530970257, 0.06927040172740817, 0.056391998441540636, 0.02921292521932628, 0.046721198232262395, 0.02124315531546017, 0.03787495006690733, 0.058844469967880286, 0.03219463338609785, 0.04948791734932456, 0.05193662247620523, 0.03475527664704714, 0.04236722561472561, 0.022458718995039817, 0.034798373162630014, 0.026779415566124953, 0.0023626085749128833, 0.009382800526509527, 0.012235056801728206, 0.02083117429720005, 0.0324927615292836, 0.0715736199344974, 0.08264104559202679, 0.08547258388716727, 0.020792940704268403, 0.01330482464254601, 0.07287718006409705, 0.08474212503642775, 0.10258906229864806, 0.028932142922712956, 0.08865390380378813, 0.019292835750093218, 0.03721368164406158, 0.01457507718441775, 0.0218981878424529, 0.03440304964897223, 0.059287135081831366, 0.0261132786545204, 0.043082937991130166, 0.008561024114897009, 0.06488648345111869, 0.05846250511240214, 0.008300748286274029, 0.04231142724165693, 0.04578109750582371, 0.013567445657827193, 0.04774961082148366, 0.01971211579075316, 0.020074350650247652, 0.03593634159187786, 0.036092745503992774, 0.025401028397027403, 0.046753893548157066, 0.04664907632104587, 0.013908737109886715, 0.032688948267605156, 0.12949765980010852, 0.06229877035366371, 0.011381344847904984, 0.00882262096638442, 0.036755323817487806, 0.03651661943877116, 0.09590918401954696, 0.028474742466642056, 0.028129536185588222, 0.034139472190872766, 0.08701679282239638, 0.08050708900555037, 0.03100689653365407, 0.061238838752615266, 0.007848000168451108, 0.020958604764018673, 0.023622452936251648, 0.04518921246926766, 0.12304028481594287, 0.027109520997328218, 0.012222330824442906, 0.015860295134189073, 0.020449689982342534, 0.01742420809023315, 0.024947453712229617, 0.07156644336646423, 0.010554192504059756, 0.03801371683948673, 0.023534680985903833, 0.03727644507307559, 0.04803210191312246, 0.025641424872446805, 0.018808656750479713, 0.04605946225638036, 0.043174006932531483, 0.022021992917871103, 0.03707540097821038, 0.04835470608668402, 0.04892759956419468, 0.03778948062972631, 0.044110497110523283, 0.04477359863813035, 0.026212629963993095, 0.012654711626964854, 0.02039157239778433, 0.02663718110852642, 0.017280917927564587, 0.04410189932968933, 0.05781657688203268, 0.0844145410519559, 0.09452377984416671, 0.028068843348592054, 0.03389482692000456, 0.039045480225468054, 0.0666959656518884, 0.04290601369575597, 0.02083568284433568, 0.03152881559799425, 0.0764179221005179, 0.05367381207179278, 0.02858562675100984, 0.06509698621812277, 0.028015995012538042, 0.022986729236436076, 0.040217991918325424, 0.05073567539511714, 0.03824655454081949, 0.02078422789054457, 0.039327785780187696, 0.059420825564302504, 0.04746930535475258, 0.09561409126035869, 0.03506889712298289, 0.019183894037269056, 0.019236237712902948, 0.05684277151885908, 0.026907740320893936, 0.03558507567504421, 0.06066855392418802, 0.08615403130534105, 0.039165845446405, 0.027052631667174865, 0.03778534686716739, 0.014296705940068932, 0.04564545888570137, 0.03643818556156475, 0.0397057764348574, 0.03754465724341571, 0.016634214152873028, 0.022974279709160328, 0.06420960766263306, 0.009973773649107898, 0.059158754665986635, 0.038465243196696974, 0.023172299552243203, 0.007039327301754383, 0.07000899451668374, 0.05316153350577224, 0.022693525243084878, 0.04392419948999304, 0.0262650589866098, 0.0439511876902543, 0.03954630745283794, 0.08533795829862356, 0.060527931782417, 0.030531691954820417, 0.024628296814626083, 0.07147537442506291, 0.052044226467842236, 0.030934520436858293, 0.0679877182119526, 0.043758848987636156, 0.057901300460798666, 0.03246520187531132, 0.0552927367243683, 0.017452834581490606, 0.015232874211505987, 0.0319818893331103, 0.016960295288299676, 0.03582123448722996, 0.04108546978386585, 0.022317935436149128, 0.01787340224836953, 0.019054207441513427, 0.040029159863479435, 0.05218873004196212, 0.025954904340323992, 0.011761943223973503, 0.041971764803747647, 0.047803179040784016, 0.06118377139500808, 0.07167117524659261, 0.007467367004210246, 0.05461920431116596, 0.028382393320498522, 0.006610018990613753, 0.01508527588157449, 0.010115637960552704, 0.03200960854883306, 0.03956846056098584, 0.027657745486067142, 0.01685365608864231, 0.05876200993952807, 0.02846088285878068, 0.026700174603320193, 0.03800586491706781, 0.029120410945324693, 0.03097548698860919, 0.1259270092123188, 0.04950532071234193, 0.06382509352988563, 0.026736326472018845, 0.04524502939602826, 0.04151226035901345, 0.07558400044217706, 0.04683025683334563, 0.051643711631186306, 0.02638292502524564, 0.009040965451276861, 0.021104006336827297, 0.02371421393036144, 0.05306919549184386, 0.0271015354883275, 0.026307810403523035, 0.029098280101607088, 0.032711773019400425, 0.028122860567236785, 0.04023980363854207, 0.0023676380169490585, 0.01214429956235108, 0.03790707763982937, 0.01206938068207819, 0.007680553562749992, 0.05209326387557667, 0.024905947248043958, 0.031434258562512696, 0.051847794820787385, 0.05396887514507398, 0.028260890758247115, 0.014491849960904801, 0.07048142346320674, 0.09447895412449725, 0.19282139546703547, 0.10409603026346304, 0.1322949628229253, 0.11097364636952989, 0.25680930877570063, 0.13617005723062903, 0.09223195360391401, 0.18312096130102873, 0.14143764332402498, 0.15418094233609736, 0.1080118834215682, 0.21194801054662094, 0.2625480102142319, 0.10448657063534483, 0.1024968059209641, 0.11258876009378582, 0.17937639582669362, 0.10935644721030258, 0.11079210220486857, 0.15819297783309594, 0.15422328928252682, 0.11902878366527148, 0.11386034107999876, 0.10123947417014278, 0.12388249626383185, 0.12857236491981894, 0.14611480641178787, 0.07765316753648221, 0.07218629252747633, 0.10616291154292412, 0.08489539337460883, 0.1246492238715291, 0.2288609920651652, 0.14456889795837924, 0.06438471740693785, 0.13674916990567, 0.1553508490906097, 0.11566925182705745, 0.12343135953415185, 0.14119133935309947, 0.22598834621021524, 0.1369144016643986, 0.23495351983001456, 0.19189702084986493, 0.1912025932688266, 0.23713227245025337, 0.07820267594070174, 0.10804775141878054, 0.16812733694678172, 0.1781005845987238, 0.10940349937300198, 0.14670997916255146, 0.16211700945859775, 0.27316585765220225, 0.12670820869971067, 0.151180112734437, 0.12336735671851784, 0.12478324089897797, 0.12246448211953975, 0.14576236048014835, 0.14082243258599192, 0.08507226200890727, 0.13550914503866807, 0.20598050497937948, 0.10412767544039525, 0.23842215479817241, 0.10639349682605825, 0.10733574235928245, 0.1196513045579195, 0.12967809074325487, 0.14156913704937324, 0.1193228448391892, 0.08957162135629915, 0.17695270478725433, 0.13554338773246855, 0.14442909217905253, 0.18020966439507902, 0.1122820824093651, 0.1606687973253429, 0.14442729618167505, 0.15734632092062384, 0.15146074845688418, 0.18136121041607112, 0.10321588022634387, 0.14287726138718426, 0.21469195315148681, 0.1714358016033657, 0.12257615308044478, 0.13270623137941584, 0.11241995860473253, 0.1627770607592538, 0.10702874555136077, 0.07653279171790928, 0.12440369915566407, 0.15377172210719436, 0.12352952340734191, 0.10317483203834854, 0.16010915860533714, 0.19570116593968123, 0.0804948435688857, 0.1019218641158659, 0.16821608296595514, 0.15032848343253136, 0.12633159843971953, 0.17159324081148952, 0.09588864879333414, 0.1336545031517744, 0.1324326015310362, 0.161897185316775, 0.07423073126119561, 0.2558108826633543, 0.14079031243454665, 0.1076423680933658, 0.12902403599582613, 0.14522023644531146, 0.2221597102470696, 0.13170936377719045, 0.14182664745021611, 0.14714922668645158, 0.20398060994921252, 0.14971673110267147, 0.08318787484313361, 0.08311403114930727, 0.11089906794950366, 0.15357864496763796, 0.2572727354709059, 0.17182473151478916, 0.19619797443738207, 0.12276459179702215, 0.23950647708261386, 0.16940599802182987, 0.13513764075469226, 0.10237344613415189, 0.15190303878625855, 0.09747369811520912, 0.16284694138448685, 0.19446452526608482, 0.15953173802699894, 0.17489628779003397, 0.11636213574092835, 0.20363990479381755, 0.1366676078760065, 0.17071826354367658, 0.13727069192100316, 0.21929467882728204, 0.08586171417846344, 0.15325523185310885, 0.07258303725393489, 0.12755214935168624, 0.10326751886168495, 0.16788472887128592, 0.1625652814982459, 0.12185353873064741, 0.20795639895368367, 0.12388373565045185, 0.13511797384126112, 0.12151995077147149, 0.10398300117230974, 0.15961696626618505, 0.13543188746552914, 0.09164762363070622, 0.11424573094700463, 0.11070692591601983, 0.14228096057195216, 0.20248068496584892, 0.29224133875686675, 0.3244626894593239, 0.129083467181772, 0.10325618626666255, 0.12295146458200179, 0.18040173221379519, 0.20126524002989754, 0.09061306234798394, 0.1350809703581035], [0.03627853475336451, 0.08194053982151672, 0.024006775965972338, 0.04359809237939771, 0.04702937134425156, 0.016216342337429523, 0.01881914329715073, 0.019509778503561392, 0.028395568297128193, 0.05240527018031571, 0.06396996817784384, 0.051406276324996725, 0.020837066949752625, 0.08215234134695493, 0.03631823223258834, 0.053049432099214755, 0.07671360115637071, 0.04070588722242974, 0.021078354002384003, 0.05582544290518854, 0.04377351011498831, 0.01709046799078351, 0.019278842555650044, 0.07841615471988916, 0.032315699936589226, 0.01802940540073905, 0.033218392709386535, 0.03446754599281121, 0.12189590052003041, 0.04689122055424377, 0.029853196429030504, 0.06316890881862491, 0.08895667779142968, 0.03964725066907704, 0.016375911509385332, 0.024878690019249916, 0.033897791799972765, 0.03620524024881888, 0.04437898758624215, 0.0375581828848226, 0.041027619372471236, 0.022213012452994008, 0.05721219778934028, 0.10866121810977347, 0.025249884456570726, 0.06767608298105188, 0.008334802660101559, 0.040405907420790754, 0.04470391468203161, 0.0876287381106522, 0.10848609352251515, 0.03714217571541667, 0.032289557784679346, 0.04766526573803276, 0.008389289287151769, 0.014936984571249923, 0.013245817408460425, 0.04803843614354264, 0.05537737124541309, 0.023639988030481618, 0.04391223978018388, 0.040257503860630095, 0.018563746161817107, 0.054459056264022365, 0.06018166051944718, 0.034171833540312946, 0.03690074765472673, 0.023375935597869102, 0.025382532221556176, 0.017542849673191085, 0.01594407618540572, 0.04280671062588226, 0.13809805299388245, 0.02920846120105125, 0.09717687615193427, 0.015759841735416558, 0.07083471544319764, 0.08331051474669948, 0.02367193748796126, 0.04481043513806071, 0.03215593038476072, 0.04031665674119722, 0.023849036188039463, 0.015448189806193113, 0.04681928417994641, 0.06957336125196889, 0.04045103742100764, 0.009363327499158913, 0.02952712085971143, 0.04081619634234812, 0.03445220580033492, 0.07415038635372184, 0.043433465471025556, 0.03370917125721462, 0.008012761591089657, 0.020417762789293192, 0.06286643911153078, 0.033229135297005996, 0.004316157874200144, 0.03252440299547743, 0.04076381927006878, 0.0286181031333399, 0.04537199602054898, 0.008462723872071365, 0.011056450221076375, 0.06920455838553607, 0.03494750402751379, 0.006790286661271239, 0.009957594829757, 0.022192399301275145, 0.021722924102505203, 0.03245735737436917, 0.04136571958952118, 0.04833936589420773, 0.021998105039529037, 0.037245141284074634, 0.045628912703250535, 0.07956195651786402, 0.06179889678605832, 0.01692355341219809, 0.049358880132786, 0.03430456665228121, 0.0014524051516673353, 0.05708161319489591, 0.032187249016715214, 0.05031224303820636, 0.008816425888653612, 0.020234994080965407, 0.07827967376215383, 0.059449479886097834, 0.07604652171721682, 0.06960712897125632, 0.022705035953549668, 0.01610241710295668, 0.003060800468119851, 0.034062812046613544, 0.0823270800174214, 0.08692030620295554, 0.024886007595341653, 0.02915180379204685, 0.01916250719659729, 0.04251466067216825, 0.04765846395457629, 0.05610010433883872, 0.059477963513927534, 0.09604447011952288, 0.035499324221746065, 0.061497881688410416, 0.017807132171583362, 0.07650755127542652, 0.03760189538297709, 0.0009844317582974327, 0.026749466196633875, 0.01263163547264412, 0.05931072424573358, 0.0612926778558176, 0.0352681266667787, 0.05799176084110513, 0.06764773293980397, 0.07506357680540532, 0.017122387762356084, 0.018383953465672676, 0.0067821879747498315, 0.0414223936968483, 0.03564166072465014, 0.034445930941728875, 0.04871712277235929, 0.037202898238319904, 0.058892093584290706, 0.10133963442058302, 0.034547111645224504, 0.07860227051423863, 0.03168588373227976, 0.02346474284422584, 0.029473135182342958, 0.039310879656113684, 0.033939771383302286, 0.026524239219725132, 0.04211187857436016, 0.06601424363907427, 0.014110820211499231, 0.06946879264432937, 0.010755745897768065, 0.050087439085473306, 0.06067158559744712, 0.013881993818358751, 0.06087589885282796, 0.08432579503278248, 0.04729044405394234, 0.027622612215054687, 0.03012372038938338, 0.008008900567801902, 0.009837779725785367, 0.04738636293041054, 0.03256541778682731, 0.012825957564928103, 0.02095000698318472, 0.0423020502057625, 0.050765068153850734, 0.06304200898739509, 0.0663796326261945, 0.011063924575864803, 0.03632036219642032, 0.051228654410806485, 0.02694077145861229, 0.04446727718459442, 0.04047656730108429, 0.03964509844081476, 0.09231423551682383, 0.027126889108330943, 0.04730008455226198, 0.02112136146024568, 0.03570233871869277, 0.015543086374236736, 0.03875285510730464, 0.04361593732028268, 0.01720184023724869, 0.009722922168293735, 0.045520696439780295, 0.06176449453050736, 0.07566186657641083, 0.008508080227329629, 0.029911668389104307, 0.05130418277985882, 0.10969557159114629, 0.04262819071300328, 0.06437224932597019, 0.012339274744590512, 0.05837824908667244, 0.04475244742934592, 0.004840592819164158, 0.04392244059999939, 0.0316924480284797, 0.04282426983991172, 0.042008003874798305, 0.05254474199318793, 0.040454874324495904, 0.004442489034772734, 0.04373695563117508, 0.010009470952354604, 0.06873563237604685, 0.033306077457382344, 0.02373963434365578, 0.03137489045911934, 0.07088285114150494, 0.03245758744014893, 0.010933387293334818, 0.038344610802596435, 0.053022818683530204, 0.03879362870065961, 0.05336330861609895, 0.03625973986345343, 0.041028042396646924, 0.029452740964188706, 0.05705695533833932, 0.05008860425732564, 0.053377706281025894, 0.015015604913060088, 0.0509863283514278, 0.009378881059092237, 0.029398963088169694, 0.05024487087212037, 0.05938485737715382, 0.04726211256638635, 0.036659397519542836, 0.023526042386947665, 0.020110318837396335, 0.03897758113453165, 0.038624400476692244, 0.0544243460171856, 0.03205117995094042, 0.02994282931467751, 0.06429584522265941, 0.018376216576143634, 0.04517975750786718, 0.010849758382391883, 0.04165749123785645, 0.05024123805924319, 0.023075048520695418, 0.013965483576612314, 0.033541137891006656, 0.019576338017941453, 0.04622169944923371, 0.029402543950709514, 0.053891476563876495, 0.06719071840052493, 0.01539474867968238, 0.03311065513116773, 0.052876148038194515, 0.10078487903228961, 0.07317786861676723, 0.06932892749318853, 0.008778148694545962, 0.06699380435748026, 0.045419330199365504, 0.008725312418391695, 0.023223721109388862, 0.026906421153398696, 0.01652578081120737, 0.097416181670269, 0.018078270259138662, 0.02478731308656279, 0.01997768777073361, 0.009272948755096877, 0.03387701537576504, 0.05791660354589112, 0.019739617928280495, 0.031160610160441138, 0.012018452653137501, 0.0289041806536261, 0.06111578695708886, 0.0632279169803951, 0.06155025876068976, 0.02412836387520656, 0.049813074510893784, 0.04644679283956066, 0.029241930205898825, 0.024920966461650096, 0.020018238719785586, 0.04093868410564028, 0.056477642283425666, 0.04540493253443856, 0.044886156465508975, 0.022812730858277064, 0.012233063207531814, 0.03836143157968763, 0.05282789730699733, 0.020632774103432894, 0.039269831468118355, 0.030160185815475415, 0.02383538994763512, 0.021112231188453734, 0.036588155053323135, 0.08227561207604595, 0.05956999724730849, 0.03957404522225261, 0.0683918027789332, 0.023226912344398443, 0.04157826326263603, 0.009951769898179919, 0.029962581575091463, 0.05092954292194918, 0.030625196995970327, 0.03841003854176961, 0.07347725098952651, 0.060294704453554004, 0.021103728031448554, 0.08072491677012295, 0.0021695499890483916, 0.03742441076610703, 0.049831045616883785, 0.06699360397760756, 0.18003273638896644, 0.12488537526223809, 0.1885166420834139, 0.14856335939839482, 0.09361514617921785, 0.13448697020066902, 0.10274984859279357, 0.11740573638235219, 0.26704551419243217, 0.1338606420904398, 0.17161016177851707, 0.21498562098713592, 0.09334299320471473, 0.16870552935870364, 0.12312036997172982, 0.1570126216392964, 0.21339349157642573, 0.17366236337693408, 0.11956292961258441, 0.08821962124784477, 0.05816288154164795, 0.16277645219815895, 0.1205216656671837, 0.1634899084456265, 0.1424249223782681, 0.07473457531887107, 0.11044816870708019, 0.19201533403247595, 0.18512208829633892, 0.11311336202197708, 0.09731516795000061, 0.12392263903166167, 0.19648059911560267, 0.07422666429192759, 0.10228816594462842, 0.08763609279412776, 0.10061460066935979, 0.15596249751979485, 0.15892580413492396, 0.22905212477780879, 0.1980050595011562, 0.08375897232326679, 0.1254834869178012, 0.15440971677890047, 0.12490860448451713, 0.13729849277297035, 0.16247763385763392, 0.10317691747331992, 0.2554017514921725, 0.15200506924884394, 0.2851681370520964, 0.1230452126765158, 0.15851017175009474, 0.15458467067219317, 0.14309380523627624, 0.1634056301554665, 0.10535902460105717, 0.18370256759226322, 0.19346672255778685, 0.1444665261078626, 0.10657957551302388, 0.13890267466194928, 0.1720497803762555, 0.14979983679950237, 0.14954069367377087, 0.15547315502772108, 0.08233764820033684, 0.11893929549842142, 0.1501276731141843, 0.12140175633248873, 0.09289470632211305, 0.11386082347598858, 0.17994378256844357, 0.14395843696547672, 0.19516466738423333, 0.07902832265244797, 0.09103973789024167, 0.19430052547249943, 0.11152552222483791, 0.11517357881530188, 0.09637335286242887, 0.134308943815995, 0.24135533021762967, 0.11624503968050703, 0.1761862591956742, 0.14063370443182066, 0.09019078774144873, 0.10388243274064735, 0.11088354222010821, 0.16398615291109309, 0.10523190212552436, 0.20703450310975313, 0.1041843235725537, 0.21326438756659627, 0.13087465544231236, 0.1463635594700463, 0.1815488253487274, 0.1640292865340598, 0.1449337525991723, 0.15948247426422313, 0.14908520795870572, 0.1674952794564888, 0.09617234216420911, 0.17642760562011972, 0.16228066786425188, 0.13130875246133655, 0.1555644243489951, 0.15409908344736323, 0.16430171410320327, 0.15026425797259435, 0.15793524478795007, 0.11641538483672775, 0.2370060925022699, 0.2339377868338488, 0.16327568009728566, 0.1664811494993046, 0.11586062202695757, 0.14705889247125015, 0.1398787769721821, 0.18322603456908837, 0.17618903482798487, 0.11375886722817086, 0.06408594359527342, 0.21452252083690837, 0.15402794117107987, 0.0860419670061674, 0.09253826763597317, 0.11575548196560703, 0.2001681231195107, 0.14194193267030641, 0.20780630700755864, 0.24432457401417196, 0.0870854637469165, 0.096509744762443, 0.10949522882583551, 0.17386280262144282, 0.22276004834566265, 0.21972625254420564, 0.06995811287197284, 0.19962859660154209, 0.12190246110549197, 0.12498471915023401, 0.09175889383186586, 0.10357469378504902, 0.15203616523649544, 0.14430355047807097, 0.08799257600912824, 0.14366770803462714, 0.15033434639917687, 0.129076253506355, 0.11795594240538776, 0.08917599727283232, 0.06537834924529307, 0.2087065766681917, 0.14087142917560413, 0.1487159004318528, 0.10169985063839704, 0.19693247799295932, 0.18302943964954466, 0.10080553300213069, 0.1501751408795826, 0.08471833178191446, 0.15930103400023654, 0.07874406524933875, 0.14197363721905276, 0.09603565340512432, 0.12821003358112648, 0.09284858926548623, 0.21305621514329687, 0.23238528810907155, 0.16395942075178027, 0.2140526968287304, 0.11223105975659564, 0.12529800937045366, 0.0919125480868388, 0.14935269282432273], [0.06626352362218313, 0.007877476418798324, 0.027575730746320914, 0.028077244460291695, 0.020209861249895766, 0.040377208570134826, 0.03856500639813021, 0.019176697060174774, 0.09004657360492274, 0.021769033737655263, 0.025315089551440906, 0.02430114327580668, 0.04929155620629899, 0.027484821366670076, 0.020180505598546006, 0.04076316618011333, 0.022882275661686435, 0.09417483684956096, 0.027615825274551753, 0.02660817241121549, 0.034722907876130193, 0.07092611835105345, 0.03836918331217021, 0.015347700227721361, 0.028185989503981546, 0.036111302906647325, 0.0204739099717699, 0.017321563500445336, 0.07964585631270893, 0.03492059375275858, 0.0058699868986877846, 0.056576815477455966, 0.02390606652625138, 0.01856045473687118, 0.026451616358826868, 0.06348012844682671, 0.04319803396356292, 0.034601013830979355, 0.02445346166496165, 0.03934930435207207, 0.04069471047841944, 0.05040621748776175, 0.0299689696112182, 0.02989085671288194, 0.06356860729283653, 0.08015795305254869, 0.04283408845367376, 0.021354716809582897, 0.01524071036328678, 0.027461929821583908, 0.012657370371016441, 0.02137243744073203, 0.07993910112418234, 0.03950406811782159, 0.07834398085833527, 0.05930122846621089, 0.02537374519306468, 0.03156513630528934, 0.0463380273868097, 0.09285843014367856, 0.06181087876029778, 0.0270215727869072, 0.008822331528790528, 0.01587574850418605, 0.036630579925258644, 0.014801901634200476, 0.06742252822732553, 0.00926429902392556, 0.028295183547015768, 0.03479949380562175, 0.027838699643325526, 0.03140937064017635, 0.03483689433778636, 0.05497145728440955, 0.04447305480425712, 0.03301800912595354, 0.022728658514097333, 0.021466374782903586, 0.054396752966567874, 0.04778844740940258, 0.049795277809607796, 0.006294665599853033, 0.012777510164596606, 0.050791833709809, 0.02875207192118978, 0.030053943664825056, 0.05998099863063544, 0.03963780683989171, 0.027784209305536933, 0.03110170775471488, 0.041398789689992554, 0.016486517488374375, 0.05048246945079882, 0.052470089358394034, 0.03540380239428487, 0.03321891221276019, 0.04052907053846866, 0.09075936934095807, 0.02715995735343313, 0.02587900118669495, 0.04176006717898417, 0.006265447245823452, 0.07491562224458903, 0.04928276546706911, 0.021326851019694004, 0.004057004543938092, 0.028178365791973192, 0.05842525300977286, 0.10362619141233154, 0.05789460628875531, 0.0583592909242725, 0.03657246234070044, 0.026061727221531328, 0.03427841336815618, 0.049898625584319234, 0.007346512893491308, 0.019079690937360283, 0.02661456415808061, 0.022455080616055056, 0.018795667310769204, 0.01382506181471399, 0.010828803842741763, 0.022289039916358888, 0.058096181019209325, 0.051001160172745585, 0.03443278750637546, 0.072494528722018, 0.0937309286382515, 0.05401679933129344, 0.05515634111361578, 0.047247418042388745, 0.021132053952896968, 0.10388634385890327, 0.016459536709589884, 0.04009338161267806, 0.03164964837196749, 0.015029518326628022, 0.011588304787437664, 0.027831239203806035, 0.01926113120134687, 0.0953264199779369, 0.05220558050496038, 0.04868954827543348, 0.10564213167526759, 0.023727934385533445, 0.05691354272130411, 0.060718723107129335, 0.01909733735374175, 0.05482301661686506, 0.04488754057092592, 0.011683336797432275, 0.020116139130550437, 0.0559465576952789, 0.0748039958125446, 0.05169685682631098, 0.05330819301889278, 0.06993189279455692, 0.06506795340101235, 0.037148847623029724, 0.01614821874682093, 0.004918618051306112, 0.019565688198781572, 0.018001866155827884, 0.054455705467262305, 0.020115354309382383, 0.03168796545651276, 0.02170719984860625, 0.08983067542430945, 0.09236038968083449, 0.017800237619667314, 0.041332300679641776, 0.08248630037996918, 0.02371016365941614, 0.01399216656864155, 0.04184832709142938, 0.05359524831874296, 0.012524037047114689, 0.056509543501306325, 0.019414304915699176, 0.08118737125187181, 0.0208630996348802, 0.011498559651954565, 0.06742401994415559, 0.02592473232652992, 0.08251142207882367, 0.03517452329106163, 0.006080050407035742, 0.01258603513633716, 0.1037517553777434, 0.0276574226518278, 0.03606486301578116, 0.0362579549982911, 0.03354320477228612, 0.06376249337336048, 0.013340187979338225, 0.0076717433421436, 0.043202308734180406, 0.03085763950366527, 0.05375524051487446, 0.010383582957729232, 0.012143785625085002, 0.014484091734630056, 0.028573333074746188, 0.011150343034387333, 0.031327270553447306, 0.05118186571053229, 0.07256270982907154, 0.071341899165418, 0.019783087373070884, 0.011284332231298322, 0.017909659873112105, 0.046848313286318444, 0.016929685407376382, 0.03837739146547392, 0.04851986363064498, 0.012159346606495092, 0.025106553475779947, 0.03557861899025738, 0.023723937920294702, 0.009311432822869392, 0.0996957476309035, 0.0672587139706593, 0.02733786684984807, 0.045816805941285565, 0.01356404476609896, 0.031209072403726168, 0.07405751399346627, 0.10160503385122865, 0.05212086805840954, 0.04314394995162729, 0.03226483313483186, 0.025001294670801144, 0.04708941109129228, 0.028665767567872535, 0.030750627374800388, 0.0508933075616369, 0.07527044304879382, 0.0344525434775278, 0.03324342535051983, 0.040300663458765484, 0.04342650041508023, 0.024999634115374647, 0.04162402779911645, 0.02325171863049036, 0.06222852236533072, 0.05673511928762309, 0.05308797182806302, 0.02260885918076383, 0.009476409468334168, 0.007199194260465447, 0.027491330001794267, 0.0235939136473462, 0.0251923253381392, 0.09844044194323942, 0.035834210939356126, 0.01283314897591481, 0.05888134728593286, 0.06071435556805227, 0.06252102873986587, 0.021284309259499423, 0.04242626346240286, 0.020493035117397085, 0.01650602112931665, 0.03513806528644636, 0.016481699094583746, 0.03013111218024278, 0.03420209090108983, 0.023713983864581678, 0.06589357042685151, 0.028089398983865976, 0.008668227346788626, 0.014775564668525476, 0.0482697672850918, 0.04521510600170586, 0.03574990296328906, 0.02041933057626011, 0.03820955847913865, 0.06781709103961475, 0.056074507665471174, 0.03022131280886242, 0.07346288301050663, 0.0007919187669358507, 0.03635122440755367, 0.07285568004590459, 0.03476074998616241, 0.05017303839849774, 0.02156046983145643, 0.042093636584468186, 0.018691492041398305, 0.028292439455981366, 0.03829951790976338, 0.035270453299744986, 0.06210897350683808, 0.04247502627549693, 0.04338217193435412, 0.01992066670936765, 0.020198832935420796, 0.030160473397700116, 0.0430804295319831, 0.03434762234974187, 0.022598443138122093, 0.03456178390479181, 0.05035744354245253, 0.019718296025530435, 0.056673391154618, 0.05626675731036812, 0.05231117698713206, 0.0912961499125231, 0.017924816384038422, 0.027809331004391424, 0.03196194411430042, 0.02862526485841954, 0.03988475276855752, 0.03181366671924479, 0.05114644671266433, 0.02550399582105456, 0.07885142433224246, 0.02099781428114511, 0.02899140712543158, 0.040609292991575785, 0.042864082352025434, 0.06311752993497066, 0.03479222817986738, 0.029681569212698378, 0.016053526269388385, 0.06199975163326599, 0.032605991000309587, 0.030687687685713172, 0.01912112689751666, 0.06004840790410526, 0.02341652179893572, 0.03837018521153368, 0.05398196663009003, 0.10971222538501024, 0.022909779654582962, 0.05791725292510819, 0.01443087232473772, 0.008680838291184045, 0.016703510336810723, 0.06569839300937019, 0.025350838805024978, 0.03535256822942756, 0.02075639735267032, 0.017618602541915607, 0.07534720338298939, 0.054485736472997814, 0.03618696857301984, 0.025462630364927463, 0.026851748989429325, 0.04127675463678315, 0.0035472161152938497, 0.02861694538296433, 0.11892702037584968, 0.12809906766051427, 0.08183093203115277, 0.1282752089900896, 0.07497269340092316, 0.09276346492697485, 0.1206887379521504, 0.09364911427837797, 0.18512542796088383, 0.17829137592343614, 0.05748987605329603, 0.15110604639630765, 0.21971877169562504, 0.17076611722586676, 0.2530383673729375, 0.15487044205656275, 0.07724874158157036, 0.2063261973671615, 0.10878698987653479, 0.15948547254083678, 0.1061873504659161, 0.15567685972200707, 0.10605720744933933, 0.15867337002418935, 0.17397177958628163, 0.13501711597200483, 0.14597449597204104, 0.12560586706968024, 0.2259083723765798, 0.23993390961550176, 0.13813572440994903, 0.19072209717705846, 0.10171104964683764, 0.12769204418873414, 0.07336687878705561, 0.16038525238400325, 0.10416276418254711, 0.10694149867049418, 0.22972774633672088, 0.1515803678194061, 0.13917379605118185, 0.1434200385119766, 0.1199425381491892, 0.14884770585922524, 0.2962084743194282, 0.14474889845587313, 0.14542334742145613, 0.11104648816399276, 0.1464627103996463, 0.09675552922999486, 0.10363915673224255, 0.16127924347529188, 0.20992506440961733, 0.10656397556886077, 0.18631592189194635, 0.14463267812971026, 0.22132506128400564, 0.13530205615097657, 0.10456923104356974, 0.19196660461602733, 0.17671542533207685, 0.11695243258145638, 0.1477896556025371, 0.14102995191933587, 0.14450940740061924, 0.2038602187531069, 0.14498282340355217, 0.180146329512354, 0.12876287422841415, 0.12948937743203714, 0.18371778161963448, 0.21145028178580105, 0.14654557860922068, 0.0763148748956155, 0.08210506653995253, 0.10148989706067368, 0.06030566968547646, 0.09310724257375114, 0.2262070422875695, 0.1435472723096609, 0.15553273464320228, 0.16024158743675798, 0.13063888996839523, 0.15859029401326552, 0.14703432738315314, 0.08643313078209758, 0.1985075231641531, 0.07287709842785262, 0.2023306820774451, 0.14766586537007242, 0.2569941629189998, 0.11976323527051136, 0.18480479047866538, 0.20318701659562066, 0.09719081368530169, 0.11425623975810595, 0.1008854919928126, 0.14014563843375072, 0.12367948176688515, 0.12606386124389246, 0.09279238642193377, 0.1704387113568373, 0.15147501253522933, 0.12643432652112097, 0.14797710726270452, 0.16199608391616493, 0.15795710845850408, 0.1426554928184487, 0.19725675199879333, 0.16687938594259322, 0.2676273579709232, 0.08045948023209348, 0.22175384452566504, 0.1346126158023253, 0.09448000055272132, 0.11049674227251671, 0.15842673950828612, 0.17733240238158032, 0.11290605791145936, 0.13746412529144436, 0.09577932301908731, 0.06999750607064925, 0.09454072307562456, 0.13007925124838948, 0.14176124939695, 0.1117851996968966, 0.17265345813939348, 0.19212806626455858, 0.22374600637704134, 0.19265913229901344, 0.14537319308146834, 0.13672717264853418, 0.22695196559652686, 0.09435898595256731, 0.11772895653848536, 0.09350455875392072, 0.0944867763610091, 0.15484345756703988, 0.191395893052686, 0.08505638004862703, 0.18751717696432024, 0.09955931120202877, 0.15397383860545233, 0.13786767551209778, 0.1465097625623457, 0.1669134059920907, 0.15259614534443244, 0.2167410377296619, 0.08879295259248465, 0.16091216239146888, 0.09585710009559989, 0.10330190998502076, 0.13909210043493658, 0.1379750345950015, 0.22585789149161428, 0.12142718973336741, 0.10681050218408927, 0.17097856441978365, 0.083853826217819, 0.14405102730961516, 0.06937411686521955, 0.12042042188113555, 0.12432958828867413, 0.16087098803836852, 0.12128913542255759, 0.12333505103015341, 0.09750514291226864, 0.23592827143147588, 0.21533569204621017, 0.14593010069802403, 0.16584351105848327, 0.1626249056425877, 0.08448088163277134, 0.08276598615339026, 0.17341015191050246, 0.13368804822675884], [0.03294027286756318, 0.04351773633970879, 0.029021857444604393, 0.006209913726706873, 0.04854218372202013, 0.044032393489032984, 0.04322724860685412, 0.06087408801249694, 0.07192967270384543, 0.043057567672804, 0.017508076343801804, 0.059363724722061306, 0.0044805941433878615, 0.019142443234159146, 0.05388324614614248, 0.027421057893661782, 0.029629498276335653, 0.02445437821734231, 0.04876947386946995, 0.04991413647076115, 0.027646746857499238, 0.09872785347397439, 0.03865377468173392, 0.04391519723867532, 0.054646786229568534, 0.02528594726754818, 0.031559930139337666, 0.042403731858939864, 0.01981614263058873, 0.02846655286703026, 0.01947530388861196, 0.042263191353413276, 0.0068871745042997645, 0.013668263636645861, 0.03684536859509535, 0.06616157479584217, 0.018395017032162286, 0.010137984954781132, 0.0450469613133464, 0.08179740179912187, 0.03590701933717355, 0.036342641469673254, 0.07893807749496773, 0.08633731951704249, 0.08117313685943373, 0.023043891305860598, 0.025915375699696597, 0.019815463565464597, 0.047596064177923836, 0.07575450887088664, 0.02803043906169478, 0.02604612171126064, 0.0770314184774179, 0.042153193935519084, 0.013358012511162087, 0.036265446979086846, 0.020444045949261636, 0.04680563237343449, 0.07766606606310233, 0.02250788627861766, 0.04423249505634885, 0.061636967584490776, 0.0853972855838947, 0.05641261530399788, 0.026673626125557348, 0.03430331242270768, 0.016008722814149223, 0.053660445992136374, 0.011348567895765882, 0.07294466355233453, 0.047614298746339045, 0.05828769222716801, 0.029166117965360172, 0.03453846191405319, 0.03243124490836635, 0.037225990163278766, 0.002773963406070834, 0.09268992551369593, 0.06552991806529462, 0.03841805744741578, 0.00266366982486943, 0.024505506626155693, 0.038939709338592365, 0.027892538746527862, 0.06277076143305749, 0.017732173400872853, 0.029738165394519456, 0.04702413178165443, 0.0781956478022039, 0.013675591417268151, 0.04053363103594165, 0.03676274158351589, 0.06714428222039714, 0.015053805109346285, 0.030719063834112603, 0.023128110224206466, 0.026098931084561627, 0.07696898159338161, 0.086149615526665, 0.04384360225230921, 0.012682480937655782, 0.08899150678189471, 0.03396833664737642, 0.025308968688477762, 0.02397234959062189, 0.11766024108510464, 0.07526451328885742, 0.13162769784685224, 0.014456352109846193, 0.037592971057165414, 0.006326243983494351, 0.021520289956242777, 0.08316110557643697, 0.020988802752981428, 0.029658443891094066, 0.030800900458416436, 0.10069912386825308, 0.032659154749126174, 0.032778184104245156, 0.05245539854513481, 0.03818342745944392, 0.0688614857790526, 0.032795991937746294, 0.01495624886956648, 0.024414853287453298, 0.03874070243909955, 0.01984125319722807, 0.05528348214284051, 0.10051099685369991, 0.038818145549157634, 0.0180365207415889, 0.05873486588825472, 0.018033403721346986, 0.06041407890734263, 0.05962274910416454, 0.015857131729717366, 0.061455913237296045, 0.0405338648124598, 0.07217072969069704, 0.046450414520222694, 0.0462747964047594, 0.024779518680588808, 0.074680012621684, 0.02549491935496917, 0.04446941828064155, 0.02403499798674602, 0.05703089482267387, 0.021388760978879873, 0.11650911066681147, 0.07122593116946518, 0.028503741887107026, 0.009390070790686877, 0.041780587562243454, 0.0061164666658442, 0.02298598708875943, 0.02224506581114838, 0.05185529051232152, 0.02714622205530759, 0.042337643608334474, 0.06748034153133631, 0.08470841668895446, 0.026941075739159714, 0.04056499419675674, 0.027930375290452503, 0.040382485240115784, 0.009498992094449932, 0.049861317820614204, 0.04113908995350357, 0.01047576512064552, 0.057829230499919504, 0.056002578712650575, 0.03827054446446709, 0.04171232481894549, 0.03921887560863979, 0.052151785930618644, 0.05266213120194152, 0.026776814338518307, 0.025553344930813182, 0.04364192362118047, 0.056096107873599976, 0.037096173691679724, 0.04894987141597085, 0.0493983846536139, 0.029890827026974875, 0.028916452065459453, 0.06490516330813989, 0.037664536357624456, 0.031140590726863593, 0.05762040498666465, 0.029353506542975083, 0.027438962206360884, 0.05145551040186547, 0.020897785761917476, 0.004203215521556558, 0.021858443978999276, 0.014977104146964848, 0.013918190215918003, 0.0324988916690927, 0.030937782175897155, 0.07569949346361682, 0.08888964701327495, 0.03750004674657248, 0.022984500938036945, 0.021499392933037598, 0.061963531115907244, 0.0057102243044937495, 0.0405794994730968, 0.030828072340227664, 0.02077962471958017, 0.11371201544534415, 0.046212363231461495, 0.05714474398700986, 0.08830979219055735, 0.018104395712725818, 0.030046956344449427, 0.08261271781520918, 0.011009957452188246, 0.05932748936174903, 0.04633755983377341, 0.10664007539162412, 0.09931636916007847, 0.021056759360362776, 0.022793889584136195, 0.011063831807405222, 0.05493457996635698, 0.08444125094683841, 0.06523059506434947, 0.026420409049023874, 0.03369458434463013, 0.059290163044352084, 0.006694120556858252, 0.007527745356128435, 0.02433798163110623, 0.040900007079471834, 0.03429290380154271, 0.02362052706303075, 0.010812000691657886, 0.026255422199028544, 0.06412380796973594, 0.03788245317991823, 0.03194274104316719, 0.02892085671192035, 0.018709544783632737, 0.043313931455486454, 0.08864661591360345, 0.01449402816433576, 0.05053128792496864, 0.08000698537216522, 0.031230264430632815, 0.019734133456950076, 0.02231393340480281, 0.0426489448727807, 0.009240247873094631, 0.08120224389131181, 0.043166399918845855, 0.060042032855562866, 0.04995033843442798, 0.07179524749517441, 0.022288052859948948, 0.08078229962848127, 0.026831544018932618, 0.025145308427454438, 0.04075648314028513, 0.055756033543730155, 0.06521849805722013, 0.03119222936220467, 0.04961606769938953, 0.020956081461918075, 0.06148323911475018, 0.038680139477946796, 0.004450372498467914, 0.022531000468006823, 0.05560575234994758, 0.07297112853848375, 0.024881925783120096, 0.044722397869918495, 0.04082612256752327, 0.07910868240287527, 0.0370994094555499, 0.05703832743165549, 0.030359886623045895, 0.03891352636856027, 0.018194820841017645, 0.03601349897508044, 0.048648526062606834, 0.02592108281533001, 0.024556106254749466, 0.012056417217536364, 0.01622333707928192, 0.031049972640175838, 0.01753900905896444, 0.01098616234230576, 0.05092035142297391, 0.0273722969359369, 0.008086850193649298, 0.03683523085783236, 0.06136366428108886, 0.04544420327874832, 0.050886676472146064, 0.01563309404446045, 0.057220765884267166, 0.023718249358353205, 0.060176402403158136, 0.02908914611907676, 0.013474725437845336, 0.03554920767783187, 0.017348976580251474, 0.07859997727791779, 0.04549148550722748, 0.039463554276153445, 0.04253632025211118, 0.024190971453208476, 0.04083218962477986, 0.02194480399339227, 0.07205917747342028, 0.018742557367659174, 0.020068385638296604, 0.046158290351741016, 0.01177833726615063, 0.015998273374862038, 0.0798983423737809, 0.009973823744076071, 0.044115777491242625, 0.018747186513792258, 0.01001531907604658, 0.033792855829233304, 0.011363769863237394, 0.02900516654335661, 0.029057207793812267, 0.03794461546931416, 0.07215952326077968, 0.022280451412370894, 0.02436007165670162, 0.039110065627028234, 0.04935775577905588, 0.0554859251860762, 0.05278287862893194, 0.02640952545334585, 0.027141336868226063, 0.021013968980696518, 0.0346296199131757, 0.025261346927436534, 0.014775226991332602, 0.02082715927826939, 0.023809514968888834, 0.04969944428012241, 0.03751681186258793, 0.03323918397654779, 0.009861317867034813, 0.023659256039536558, 0.02326213838387048, 0.05028145504184067, 0.08787956918240525, 0.11784316564444453, 0.12334268030826934, 0.0938560621580109, 0.1874794758623466, 0.1340137916849926, 0.17845412890892476, 0.21219937596470118, 0.24166724004317075, 0.12120266779675148, 0.12270093779079616, 0.162057637644466, 0.14117703074589372, 0.12200127064716071, 0.09238469501724467, 0.12945323484018445, 0.1454108496545814, 0.11417812129366212, 0.19309612369397655, 0.13066542916931212, 0.12276974972337484, 0.1695864586508833, 0.0746179764973931, 0.18499835743568838, 0.129532125138212, 0.0836171701666899, 0.09355314716231078, 0.21869422198506072, 0.12075235485099256, 0.15594392898492515, 0.10661899097613059, 0.15199974062852561, 0.09550544826197438, 0.17155567329609767, 0.10994042837410234, 0.16100024047773331, 0.14412855205591768, 0.10859194604563527, 0.10982653097016737, 0.19472148647764698, 0.15057391166919842, 0.10490529777598567, 0.12148968598921783, 0.22209812683286145, 0.17445686215069145, 0.11188807620783336, 0.1385555721935816, 0.19649394293082878, 0.09359775023767725, 0.16814608359709382, 0.1182531428639777, 0.10270058483001776, 0.10370170493843034, 0.14445555716520175, 0.09786906986846589, 0.2690486004576087, 0.07775966572808102, 0.13800354790873826, 0.14885646320180967, 0.0817417333018966, 0.18166249268688262, 0.13906441832659766, 0.2302092220634222, 0.16178394842427224, 0.11077518865931779, 0.07462254812708125, 0.10273479041643441, 0.1183586911065504, 0.23495846253354102, 0.12949365220265463, 0.17262307461351156, 0.1669871309422888, 0.13280260667670518, 0.12498847441747785, 0.07382344803772867, 0.20322638010839, 0.08984887288534082, 0.14510680659441277, 0.16271204862277955, 0.09506989663350396, 0.15398841438582167, 0.17858550389064476, 0.14730019436683506, 0.20786630222573876, 0.13058129930868745, 0.07160497567383572, 0.15741078386781737, 0.14427723392145708, 0.17557317099999636, 0.11064175792853348, 0.16918587702093646, 0.09730983932968229, 0.18143030436476693, 0.13434835185762495, 0.18308700062334538, 0.0515765212912811, 0.1377931935712695, 0.20857683441136032, 0.14322532864753157, 0.08052524935919791, 0.11780832923250273, 0.19975819042883813, 0.12714803509879857, 0.14962952875066549, 0.12258448739885353, 0.21712450543418527, 0.15752802835777402, 0.2875969192245975, 0.1042064989451319, 0.13472806429490447, 0.12414497905410826, 0.17303263623034582, 0.11309228502796032, 0.1345350465271622, 0.17569132091011852, 0.11578468547668308, 0.20573549234541133, 0.12258594942977652, 0.08166229381458834, 0.15455167478648946, 0.14612749713705853, 0.24887932726414874, 0.17685855593299493, 0.0714559004700277, 0.11264301851042546, 0.13092436449369416, 0.10706557834055275, 0.13238796876976267, 0.18408012780128047, 0.12891284743091092, 0.0808594458794687, 0.18692988582188264, 0.1839793738326989, 0.10866178956348449, 0.16144009656272829, 0.16680350876413286, 0.25048986193723977, 0.15892179653747007, 0.15001954219769686, 0.060212767639313824, 0.12018494584481232, 0.14063144830288365, 0.14119245257461444, 0.11611239562625997, 0.17071296460926533, 0.07288656081072986, 0.15674915921408683, 0.14336462976643816, 0.11860795624670573, 0.19736853428184986, 0.12203284160932526, 0.056797136858222075, 0.13388280262006447, 0.07961917610373348, 0.1796277760877274, 0.1336967313545756, 0.09691073457361199, 0.08038163636229001, 0.12121458668843843, 0.12265818266314454, 0.18980063177878037, 0.11759554065065458, 0.08561742142774165, 0.17557127110194415, 0.14487256994470954, 0.07686176351853646, 0.1284324997686781, 0.16881933028344065, 0.07193123863544315, 0.15192386345006526, 0.20572848647134379, 0.14535867667291313, 0.10012790022301488, 0.1014742451661732, 0.11678766837576404, 0.22531496593728662], [0.009520286166662117, 0.06469348052632995, 0.04938936013786588, 0.08236572364694439, 0.020273867776268162, 0.04342933541920502, 0.04570251148834359, 0.03144492322462611, 0.1047532020311337, 0.009027478772622999, 0.02578490984888049, 0.046720025638933294, 0.03169454459566623, 0.06296954568824731, 0.03421983194130007, 0.0206201353284996, 0.034692487242864445, 0.034165209872298874, 0.07328845604206435, 0.005894423502468271, 0.05024850368499756, 0.02786712761007948, 0.04103843246411998, 0.054320063136401586, 0.028736204803863075, 0.013588026340585202, 0.05058880808064714, 0.03355616638145875, 0.043315482544130646, 0.060097092791693285, 0.06943918837350793, 0.01804763811378507, 0.020777906647708733, 0.0319224655686412, 0.030540644111169968, 0.02269029133458389, 0.03976375672209542, 0.0768803468963597, 0.025899803586071357, 0.02069750607915921, 0.05136655287060421, 0.008002050544746453, 0.02355014548811596, 0.05206097674090415, 0.06904450681759045, 0.05595992748567369, 0.05657854468154255, 0.01812290858651977, 0.07388676807750016, 0.01625198212423129, 0.04087261811946519, 0.03424670510867145, 0.027253699881839566, 0.024095952430798206, 0.04681196289311629, 0.05201452200708445, 0.04381459912110586, 0.01227142296556849, 0.004271583093213849, 0.047731042286613956, 0.02026438498432981, 0.021125868152012117, 0.06683135565253906, 0.008845544980431441, 0.054484404317918234, 0.04185114354186226, 0.055136228911578655, 0.061367527159745805, 0.06904380177729763, 0.026570055706542917, 0.031258414092008024, 0.03686139898491092, 0.019590372030506842, 0.061715460833511315, 0.019292846882308368, 0.028512278440757655, 0.06219242430233862, 0.05271285328490194, 0.05503600186784752, 0.03709623677423224, 0.061021222500130534, 0.06347463655401953, 0.04196216141281184, 0.04231598031765316, 0.026606868086673785, 0.0238845943385968, 0.06479715113528073, 0.004403377852213453, 0.01243390692252433, 0.008886065315891756, 0.018822913407348096, 0.046889880977687426, 0.08611075667431578, 0.03217448407667689, 0.06274466752074659, 0.028850794260506518, 0.05604790538200177, 0.04215593246044591, 0.04948029178194702, 0.07819143240340054, 0.010420199596410384, 0.03099483292317018, 0.030042985854379367, 0.015260215859598247, 0.018985902024724055, 0.06524103708215989, 0.03642575458798092, 0.041436924948357046, 0.06601985427550972, 0.0644709994958248, 0.0285709619129193, 0.06738107185810804, 0.03245593987230677, 0.0018357869294050033, 0.0048780332417663885, 0.0656595044711139, 0.06679682352114469, 0.07311863781069405, 0.04148604770307429, 0.017315433360636234, 0.03910031009581871, 0.06665857625193894, 0.04762705255416222, 0.062278287077788264, 0.02382051359745674, 0.05081407958641648, 0.03536979347700253, 0.03977966094680596, 0.04547849792288616, 0.032991688858601265, 0.00954847942921333, 0.023924892957438715, 0.0621318316552788, 0.05082269592094235, 0.03226164561056066, 0.06503702810732648, 0.008313771122629987, 0.05391552214859985, 0.046575844899052754, 0.10294419480487704, 0.041480693107587285, 0.014542903227265924, 0.05569304747041315, 0.051958616022602655, 0.010103538170369575, 0.04005575472547207, 0.013096072416374227, 0.032834219964570366, 0.049280334933428094, 0.028394024629960768, 0.03695599683851469, 0.04642449872335419, 0.01834099424740998, 0.028721276503347326, 0.025419014345970936, 0.07387242978438735, 0.04275719082215801, 0.06857830449007452, 0.03474362863926217, 0.017564377521921415, 0.07128739584004506, 0.045332573135965504, 0.0506820812006481, 0.021066902663733345, 0.02070506670861505, 0.023744784848531708, 0.04388600485981442, 0.024722297239350155, 0.01131125178289949, 0.03491418530757073, 0.028785631839127745, 0.028245147950656246, 0.09776898383279331, 0.009707369536045007, 0.038448351915576495, 0.003218058545826352, 0.04493604734307155, 0.013324056471901713, 0.06764198871678673, 0.03981564397690818, 0.026551257105893455, 0.03932946303393692, 0.020791497227037326, 0.023182491095212754, 0.11365733400452882, 0.02698994430829771, 0.06313566802418791, 0.03455649239185732, 0.04840699410124216, 0.055222466471605, 0.03937119399779476, 0.03939589638321195, 0.021656650314980652, 0.02090648744342616, 0.042390799935674295, 0.03438311927311588, 0.08365153160411865, 0.016955209721345454, 0.036619080347009, 0.0721772234828677, 0.009909649306791835, 0.012479524884838611, 0.03626306468504481, 0.028134597632742953, 0.024821125334710814, 0.036357387944008224, 0.05239267222350463, 0.040392827067989856, 0.02355760592763545, 0.01488971347498591, 0.05704599752789363, 0.017445489174860995, 0.04348683331045322, 0.028030882494931575, 0.045541766012320295, 0.01662847920670174, 0.059871331468457356, 0.03519109173794277, 0.011295494132355088, 0.031900253088679165, 0.04510383208980784, 0.03913886095688213, 0.031858941438258626, 0.019447803606453817, 0.05906566708290484, 0.008768036004767055, 0.03564006881788373, 0.016583981887379196, 0.016221695077547338, 0.01944142670254223, 0.002918249206231849, 0.04736973140097689, 0.0235331614385359, 0.03868209503707476, 0.017917508084792644, 0.07251070011989214, 0.050977474529645406, 0.03272008507337887, 0.012264508004591335, 0.02435971357044764, 0.0803906905639451, 0.012403314667608356, 0.06314440310234204, 0.11323399070533924, 0.05111322447191924, 0.015600237311446108, 0.006610882201130153, 0.005949884662186378, 0.013493764308805112, 0.05432735473732464, 0.06850798599771224, 0.006761009863112122, 0.035867444312316366, 0.0073468505706841825, 0.04925506109429989, 0.03766694833757356, 0.01436330348951742, 0.03673745290143415, 0.021098622055433225, 0.07691732069361024, 0.04649768190574832, 0.030521524531650357, 0.00955850306127104, 0.013571886483987328, 0.018048174315481447, 0.03274605653132312, 0.030713065425516106, 0.06126156702521257, 0.04748233004647773, 0.0154812135224347, 0.04088703433808405, 0.03355389540956821, 0.015076492563821375, 0.04960653852322139, 0.049971831031143665, 0.07404125353787094, 0.01175256433270988, 0.05658444104483351, 0.04759077637572773, 0.016441420884802938, 0.023029482508718502, 0.013756599619227927, 0.024760016895015724, 0.05009672706364654, 0.08766499202465639, 0.0143526184183429, 0.02680043504369678, 0.011368842442607274, 0.015442448366229655, 0.05236710152530577, 0.0055258910560951335, 0.06325483467662707, 0.021173951899982058, 0.040846991760190576, 0.08136196891427971, 0.020641557421186008, 0.056449822877766564, 0.011510517506394535, 0.09247318870620802, 0.04912931159196887, 0.020030760606459808, 0.030955005568102933, 0.04089999965799507, 0.03778996302571613, 0.019731524807866663, 0.041527893699822016, 0.028651297543547116, 0.04405665058584418, 0.05259778699837625, 0.017588105838513002, 0.04373400559416041, 0.0498601674917154, 0.03701963600178715, 0.05729191929276567, 0.022785020919400267, 0.02778598303848412, 0.013989104281790787, 0.07406073491438292, 0.01652273058425635, 0.07217766877147369, 0.018527056236052886, 0.020465445777517743, 0.04459985073481221, 0.043613840753096156, 0.007174155125539983, 0.03173385244735982, 0.009683117077656789, 0.08391192153794691, 0.022469585892395116, 0.008139571436913684, 0.052606466415454634, 0.10631533383275382, 0.011875900927407201, 0.13142129173502326, 0.011631789075181587, 0.017942019367183093, 0.06781809293897822, 0.03601021868234966, 0.01489976586526609, 0.03055286913877353, 0.007035568323772168, 0.06675083262962289, 0.028258102138352115, 0.05227591755101457, 0.04937938567309175, 0.025313299120170996, 0.04126507694309112, 0.04012901583337225, 0.009789156065380666, 0.02653651619766606, 0.035581732299760915, 0.03429700416745618, 0.16039037320297211, 0.22843308455776423, 0.09591000780346803, 0.17357943579554558, 0.0919323337438982, 0.13690304680494592, 0.08831316154100932, 0.13105468562571332, 0.2735872787889093, 0.10074709629407153, 0.10772524372441694, 0.12147641638875939, 0.08732679532840848, 0.2291496578254737, 0.15417179907672107, 0.19922831183066592, 0.07756731589324772, 0.13728105230256915, 0.13390384992817417, 0.10074200516100973, 0.13412579661235213, 0.06323249603156, 0.17603713204152882, 0.11034103968995623, 0.09748826647410169, 0.09152873899438418, 0.06478471274022013, 0.16350285150110722, 0.1197879933170043, 0.1455002636066638, 0.13544472662033513, 0.13249400682980195, 0.13953335175756365, 0.10705457229050808, 0.09879089149762876, 0.08704574400326237, 0.13628075597807765, 0.09885677194688469, 0.09254657226847485, 0.11135126595036127, 0.11487422612844966, 0.0705474968708586, 0.0947595972684212, 0.23875431041233242, 0.16073238453827798, 0.14735248609213158, 0.17842042056145146, 0.07275295196450315, 0.23322949593421072, 0.0840002519544214, 0.16932931932387874, 0.10320502260583453, 0.10159605386434123, 0.10730831258115359, 0.1612986283726059, 0.19133963825879619, 0.13005513144889846, 0.10753500901046209, 0.16237028961768374, 0.16623177303699777, 0.08948553222580813, 0.0840014468121808, 0.12254987363121472, 0.1269037349266, 0.19391777022974566, 0.10798776362207718, 0.21420103730633855, 0.3100859234109521, 0.20400429930305108, 0.12927850359119475, 0.13684254692634568, 0.18045963457552716, 0.11907392108696513, 0.10998703524819575, 0.13958625204395503, 0.0762763203238137, 0.12186274136183783, 0.13224762864410877, 0.19536279112799093, 0.12557707173982635, 0.16770067624747753, 0.17325118387816474, 0.14457844197750092, 0.20107844145968556, 0.1474512807908468, 0.14571268111467361, 0.1329605802311562, 0.10011924678110518, 0.12723744905088097, 0.09405877979588695, 0.12799429125152528, 0.08242973388405517, 0.24489411298418418, 0.11292704584775493, 0.12407204078044742, 0.10094010664033704, 0.14121299522230402, 0.09721486669150181, 0.06993591523496434, 0.19535176281351596, 0.09217920174705796, 0.10555461019976065, 0.19475644163321704, 0.0983555699349381, 0.1064712813240476, 0.10281468261382543, 0.1905969117069617, 0.09654196139308624, 0.26353313704021275, 0.15569649694953114, 0.0865375212742947, 0.07502846579882316, 0.1474624130059965, 0.12341417881543748, 0.13840586616424844, 0.15269137773429975, 0.21001048560719937, 0.12170565096312203, 0.14654541533673182, 0.09555724274832755, 0.19324608205351979, 0.1439631124958396, 0.2439295733347535, 0.14188242726959288, 0.12960236199432984, 0.13287691050209105, 0.13283261912874877, 0.14499002223601565, 0.13320063531864434, 0.155812717275694, 0.1695738866692409, 0.09232854412402958, 0.1502125896513462, 0.11878962657647207, 0.1238298557291273, 0.25497151364106685, 0.13135914428858086, 0.13266854512039572, 0.12742295628413558, 0.10639665837516077, 0.17559939849888906, 0.10947325383313, 0.16003160417312756, 0.3040941496146843, 0.17038489080732688, 0.09234326091245748, 0.09776723236427642, 0.06928107381099835, 0.12294424348510802, 0.07032724970486015, 0.10079582571052015, 0.23672533803619444, 0.13906728301662952, 0.08169706343323924, 0.15082584111951292, 0.19980337237939239, 0.11501888555358164, 0.2667160896817222, 0.11884643798111938, 0.06094795397075359, 0.1467099494766444, 0.11816205907962285, 0.1853163231862709, 0.11883002909598872, 0.04603951703757048, 0.1734311250038445, 0.1615198329091072, 0.0852980678610038, 0.10044131660833955, 0.08024884387850761, 0.16822535981191322, 0.1405935690854676, 0.1840865399572067, 0.08025702976738103, 0.10786094542709179, 0.12045490948366933], [0.03442142151470762, 0.015163571533776121, 0.08133974901284091, 0.027624374815786723, 0.034122970537282526, 0.02704816208279226, 0.05776286023319699, 0.012787261985067744, 0.029238221322884783, 0.013386436767177656, 0.03960007605201099, 0.03694653445563745, 0.06155272640171461, 0.02191632222093176, 0.011934211470361333, 0.04672960305470042, 0.07716067833825946, 0.009317536987509811, 0.034912303963210434, 0.038076079508755356, 0.061981617254787125, 0.06462154415203258, 0.04353935510152951, 0.021249114761303645, 0.02698915577639127, 0.028337947951513343, 0.012245982143213041, 0.045631918401340954, 0.023129631626943592, 0.07822732266504318, 0.03309162275400013, 0.03754982630198356, 0.057768007027334534, 0.02772229563561268, 0.05592093504674267, 0.01985825951123843, 0.03547295942553319, 0.009867561184364604, 0.012551218205771875, 0.08070344643783756, 0.03476357385807205, 0.028024422099406365, 0.02951603502879152, 0.03780686172831338, 0.032557721715420485, 0.03324273515318055, 0.029000170034123585, 0.08324146532686427, 0.07754212740110233, 0.008097261597868055, 0.004663683830585796, 0.041389575926586986, 0.016550323634874076, 0.016204239764192607, 0.08378495491342619, 0.029579056354123168, 0.06500329007394612, 0.03827222913969308, 0.029671709780814126, 0.007758327392366482, 0.014939868742658291, 0.023584158116136678, 0.02368836121604545, 0.03209160473488737, 0.046604970484622754, 0.060732334095519036, 0.0043044917765655555, 0.018380691726633813, 0.0530658446950838, 0.06526501587359235, 0.016981056869553868, 0.030315489493659697, 0.05979637826385442, 0.014270693664002465, 0.04019087384222075, 0.019034835531783756, 0.016685311020410154, 0.024151771212927997, 0.0512467553926399, 0.026484009249543305, 0.02124276197719155, 0.061317228100961074, 0.06389327463693917, 0.09061267643119209, 0.08626287468359806, 0.07490519506973214, 0.0811453656933736, 0.02339533719350584, 0.043681925380951725, 0.019399576995056123, 0.023737357805657666, 0.04510113438300323, 0.09102139942115173, 0.02617306607135106, 0.0683433331141714, 0.07649709441466257, 0.03029252929991344, 0.02682022997760214, 0.04415158982737921, 0.06347125236061402, 0.023731157161819283, 0.054720244006603025, 0.06381562372553162, 0.018404870897938963, 0.027599739223660436, 0.04313318138883915, 0.05374016378482338, 0.021696622388844844, 0.03554263596015517, 0.05435224637039937, 0.011819446681329282, 0.0195120123680681, 0.02846380135451909, 0.03288170257292222, 0.05012442030420061, 0.05688944147550501, 0.02520698275475297, 0.08148224136675708, 0.007947214180603623, 0.053597938604070805, 0.02583476361905923, 0.01721954973618267, 0.04807319462997839, 0.06287711119512096, 0.0744060859142337, 0.0024015488315853872, 0.07313900234294124, 0.032977506416500546, 0.01639417947444599, 0.03159676292852964, 0.03379583555215504, 0.016012236883398145, 0.012769573822879465, 0.028750869641953614, 0.057343361258972436, 0.05203214801440481, 0.03470734503935091, 0.006683550518573611, 0.018273610949108843, 0.03152006938762497, 0.005596979990514228, 0.007836438435333548, 0.031537046015728265, 0.08039126201765612, 0.06267675358685665, 0.09769974145456217, 0.07898212395957671, 0.08298209213535301, 0.025829832047747914, 0.059705446619773284, 0.09122941599343903, 0.029281429160619155, 0.03060664330405416, 0.03754983743419871, 0.02244884286483284, 0.013891852322558407, 0.04517923058301676, 0.03006137441843748, 0.04585020629747305, 0.06706128042424098, 0.04146268118347507, 0.026196586586593185, 0.036671412890427746, 0.006418984148695017, 0.006969296855459106, 0.06074820121284574, 0.02628513964737067, 0.04607901784766, 0.06491594671388157, 0.04850552533753216, 0.08776446207775734, 0.010078781051561236, 0.010444323106639786, 0.06373864074703306, 0.015993688757589553, 0.022734154117642902, 0.044237879337742925, 0.01902929725474678, 0.03937808483897243, 0.10784011334180832, 0.023822782713978086, 0.024438075088255573, 0.014534305446431972, 0.04505440505454317, 0.05128152130055241, 0.045230910036480054, 0.0711620767833665, 0.03621976407885086, 0.019080722522630822, 0.03666590986540541, 0.0555076367163565, 0.05100426235003397, 0.03514738295052666, 0.030355511662492063, 0.02378858825977659, 0.01739072238706285, 0.04806194738193881, 0.06568067794432864, 0.04847576521569863, 0.011755224004446063, 0.023123497776396107, 0.018081808448187076, 0.02815506792103406, 0.028105132514610887, 0.038124471248011105, 0.05503572727320716, 0.03262222548073623, 0.029482660647772718, 0.0057869178453984205, 0.01610361381608527, 0.018220317324448843, 0.009045550068549346, 0.0471536328404909, 0.05312410699843895, 0.04560457025945652, 0.12090977921616286, 0.03178458566253539, 0.04444853053428233, 0.052589749539038166, 0.04432972382346634, 0.027822747179016005, 0.00701160994140082, 0.010659788058546837, 0.09186182229314, 0.009481599863647716, 0.08892113633919507, 0.054154913013917394, 0.013786825438728556, 0.018775642311084084, 0.004106899596081348, 0.03602363671234343, 0.062298510601976886, 0.025443054364586715, 0.029467704516719095, 0.04316182828915771, 0.019625022905529477, 0.02466546542564174, 0.027128280635224655, 0.042133078022743575, 0.06125073166913353, 0.04049496885272674, 0.048838404545676894, 0.027630857475742232, 0.06751065084245056, 0.00970208822764107, 0.07411046623019502, 0.0324375420314027, 0.06628127579460852, 0.07379486050922424, 0.009314739090768853, 0.03250846166338306, 0.007675338119952357, 0.03264653081714641, 0.013806868064420996, 0.05034681969846133, 0.030060658245929517, 0.12260834744665772, 0.05823934872751124, 0.07798437320161611, 0.05003296544600744, 0.048661231630831026, 0.0247007972211577, 0.06371322218910791, 0.03914947737939656, 0.01821556386857992, 0.04716300987638533, 0.013351240413612686, 0.014076066363486461, 0.060142144866404124, 0.04316026977903675, 0.00641018830719986, 0.030850522307446226, 0.05260110439849086, 0.03429138239880558, 0.037552060166490264, 0.021541550631809514, 0.044736491254298016, 0.04952221941493917, 0.03098107536061434, 0.05152756180905271, 0.05418769738753326, 0.03556609524821397, 0.04908842296572402, 0.006466059039667016, 0.0091605133820849, 0.07308789805392735, 0.0328782775613945, 0.011084478355769534, 0.039006235456326976, 0.04790674945979845, 0.06229896331205964, 0.02575249098299537, 0.06768114442820661, 0.04866007016971707, 0.025373604185006116, 0.029143218998797238, 0.016177604084077757, 0.06039023741323035, 0.022260767800617032, 0.019505754207784776, 0.040158412302844226, 0.005925199902776512, 0.017729054525261745, 0.04311300981498789, 0.04025727008411195, 0.05484450179210398, 0.05453796511574183, 0.028708489298878703, 0.06183905810758006, 0.04163832156336866, 0.05612200511677656, 0.06495743276900612, 0.03629308826930355, 0.011516391605255194, 0.022335418580041733, 0.09465614188229665, 0.04014315003587399, 0.006649898296018364, 0.07153908038162626, 0.06021884582878556, 0.024597403062216472, 0.03001625183969736, 0.05361929019272793, 0.11732757338904776, 0.023908725270302966, 0.04366455541457981, 0.05477247636008542, 0.027292304548609536, 0.04012999175756704, 0.038783891723142006, 0.04753576096845791, 0.023801668612577487, 0.005014385251342901, 0.03930072707589716, 0.09586770538589917, 0.04350196941231843, 0.09119144771830179, 0.0258771087101195, 0.03217373450752348, 0.01134187557909172, 0.0709416218160186, 0.00959899556619348, 0.003315551007290196, 0.014707402115163859, 0.022724747395841405, 0.03693669357744511, 0.05739817628636956, 0.020155842175881844, 0.01975241997570265, 0.051398483774391934, 0.040690313253435306, 0.0335352415277157, 0.1643019070615992, 0.08722136582946405, 0.1586718115140684, 0.2004910315736197, 0.063393838936463, 0.11606380721786991, 0.21801141643663868, 0.1906142185907811, 0.11540385981788859, 0.1531918375985697, 0.24726606148760766, 0.12712295050732791, 0.110084494081093, 0.12688469141721725, 0.11424475873354822, 0.12109365372452885, 0.12896334315882996, 0.06934705073945224, 0.13778305583400652, 0.10768741645733826, 0.0960746977943927, 0.21114074683282524, 0.14954946585930884, 0.17673985683359206, 0.10083161207148805, 0.12020868714898825, 0.19033313757972792, 0.1628960418747738, 0.14878101646900177, 0.18919533613370731, 0.14781094039790332, 0.1219991035759449, 0.20852595276664943, 0.17394751135725528, 0.07920974065200426, 0.09390591221745126, 0.1384343794779852, 0.19763600430451334, 0.124521856487263, 0.2567081985762343, 0.15060794656164944, 0.10922953253611922, 0.12409305098117329, 0.10037556232418865, 0.16817364696180448, 0.09608924388885498, 0.2055968888453208, 0.21734872309025377, 0.1636770780896768, 0.16327563556842506, 0.08120196929667145, 0.08554376327083446, 0.1324727071914822, 0.18304064607946202, 0.14460328908171505, 0.1899359846720472, 0.19541367277270183, 0.1182653140858747, 0.14192375005222857, 0.07813414602424018, 0.0631905127374921, 0.09947423881385475, 0.1423622851143591, 0.21009295305702835, 0.1301816082559526, 0.23753047920763493, 0.14476648735580966, 0.13690292806131765, 0.15677976538427174, 0.1671256305417046, 0.12330780678894371, 0.15341661928687245, 0.14151800307445228, 0.07500011575757526, 0.11982012088992633, 0.15525347931543365, 0.12507238163379952, 0.1889757494791411, 0.11434968357207254, 0.07774696015985683, 0.23124416184145957, 0.10284216434229165, 0.17313490418018773, 0.15925508021609858, 0.18061048351228237, 0.146278019528836, 0.13630526169436052, 0.1087780247326009, 0.1441536663332954, 0.10050539363874123, 0.14076791441766545, 0.16604363860096782, 0.14328855962958187, 0.20883409248199314, 0.1554825357743539, 0.1748392908484675, 0.22296992770861834, 0.119524998444831, 0.1074232415703591, 0.12571796105476096, 0.09812176373088732, 0.08890561060979962, 0.12371065196930431, 0.14614928659284487, 0.12716123048448935, 0.1373314144439064, 0.136844951484818, 0.11399069931940176, 0.12317371554672718, 0.30877567653078586, 0.1651122877956368, 0.1213940825255122, 0.17136620299424976, 0.0873506702191662, 0.257581498590298, 0.151150144811254, 0.11710252452758141, 0.18307865888345987, 0.12975493271369487, 0.15532897057710215, 0.10680648716515861, 0.15637973294360563, 0.10012086466304027, 0.2181994024431333, 0.18666323216166347, 0.09886638275929727, 0.10716560500441119, 0.09609141838154756, 0.13984952151076868, 0.11328365522786044, 0.13990295614348724, 0.21697551186662167, 0.10134373107575811, 0.131264787632972, 0.11286710257991217, 0.0789737599552609, 0.17672888789093122, 0.10157219381653704, 0.11344445636495948, 0.10698843208956532, 0.11151038983371109, 0.06647725473158062, 0.1527055082260631, 0.28412277752067894, 0.1132677955320105, 0.17301647225394845, 0.15269732975866646, 0.21539602865232155, 0.0871477002510801, 0.161812907026615, 0.24377666122745723, 0.26733165665064007, 0.12784891936462373, 0.1754368978436105, 0.09439656088943593, 0.0842531090893317, 0.14483236038358882, 0.1065593223029282, 0.28388594335410744, 0.19171372521668673, 0.28919651464093477, 0.17174247186630964, 0.08631585660623387, 0.0900383951375261, 0.17041972721926868, 0.14435351185966283, 0.06774046429200098, 0.15826708870008588, 0.16600282047875226, 0.13319247169420123, 0.30882718157954514, 0.14931407145923004, 0.14506031846394762, 0.1349369194940664, 0.11020875186659396, 0.11472696918644942], [0.020984795155527536, 0.04041278712975327, 0.03370205406099558, 0.04124073821003549, 0.02699031352676684, 0.014295684559328947, 0.07991181977558881, 0.024400056718150154, 0.06326449743937701, 0.03185956484230701, 0.04447835744940676, 0.041520720842527226, 0.07741857465589419, 0.0841616171237547, 0.029347484014579095, 0.02489563139533857, 0.03202924577635713, 0.03370399848790839, 0.04788979138538707, 0.07576700663776137, 0.020631041188607924, 0.009408261757926084, 0.03870764347084332, 0.03722685476532206, 0.01698421656328719, 0.00048345178186082194, 0.032844628585735336, 0.050370646349620074, 0.029864809184800833, 0.01657098502619192, 0.023268856675713323, 0.052676391569548286, 0.04369695387140382, 0.03135481907520443, 0.008718990247871261, 0.03859541960991919, 0.017265781825699378, 0.033788922446547076, 0.01870967651484534, 0.03674354593385942, 0.030606339023506735, 0.013778386291960487, 0.061056326085235924, 0.026241252744512167, 0.04284518727217801, 0.029961883956275415, 0.034375746035948396, 0.10399969207355753, 0.04428392960107885, 0.035332812258275226, 0.03372399565705564, 0.02354554602788994, 0.006899572081238148, 0.07386245531961322, 0.08487799743306823, 0.024915971807786264, 0.06429735920391977, 0.031972608776413836, 0.055710933229420334, 0.033759956422727555, 0.012926364579470828, 0.050731894152704626, 0.02063552376057487, 0.055443114397348836, 0.027013932376576122, 0.03349917686136905, 0.03484439374005888, 0.01991106146306265, 0.07339116928051226, 0.018140174652216956, 0.012468285058275796, 0.04585086309816688, 0.046886804775567725, 0.027647754322970286, 0.028099505179852713, 0.07132198734325357, 0.03607097460189834, 0.040729212923906744, 0.014011902130732778, 0.004798850259248866, 0.1331981862313114, 0.0630788566195406, 0.03402184178412426, 0.0046544023462047335, 0.008260347622126574, 0.07605164253618568, 0.013164663560019108, 0.0162584425197565, 0.05365928453102242, 0.04161426113569178, 0.0214958510332508, 0.05569663204369135, 0.09307305183028802, 0.02721447923249798, 0.07364387056441046, 0.047799527674214914, 0.051281202177051455, 0.038667997941956855, 0.018305753364984412, 0.06946605411940254, 0.04133682406973094, 0.018824301223503426, 0.014081431163504021, 0.06593565762159415, 0.02063142710539978, 0.021012690631323494, 0.055179377377498895, 0.054848257059347816, 0.038069170113885775, 0.11411618164856918, 0.040619093051645905, 0.016051129132392816, 0.05810622969875112, 0.04164108606346417, 0.04614683159161359, 0.05377224682888482, 0.026898925461864565, 0.042664934444474056, 0.03448594383371528, 0.05657015470205806, 0.08510090148774907, 0.08332313125720248, 0.023559422334074043, 0.06287973839789629, 0.003920961453331984, 0.01762668453011429, 0.025764639940462075, 0.01601815365575021, 0.05246067150437739, 0.03279242220742162, 0.06491337888292037, 0.04066510249685962, 0.05848280285135843, 0.027969026341452263, 0.047805264475755394, 0.025000296482176054, 0.015409187162731541, 0.04082533960172441, 0.005164614030945813, 0.024378721827815752, 0.018949525656353217, 0.07786930320435204, 0.08326562965521589, 0.01624330641789129, 0.048401684034615755, 0.012353649217402562, 0.0334886754717445, 0.04125043808016926, 0.03281262717791833, 0.01964757677342277, 0.02859469022951089, 0.016937745131144766, 0.04186981597740669, 0.03432199970120564, 0.014881346687616315, 0.03803461200732272, 0.01650463331316132, 0.01138721059760428, 0.014435460652748588, 0.06714126910082996, 0.0659076044394169, 0.046432847884716466, 0.048762757432996295, 0.03286740880867001, 0.03402619819098618, 0.02945442007330712, 0.04224848198646214, 0.0367876814561896, 0.026211744952888694, 0.016734530254325364, 0.009171350593533134, 0.014044923063920578, 0.018153436831198633, 0.020957226224709302, 0.05292626527079847, 0.036047188768861815, 0.047362862824229524, 0.03141137814964168, 0.0025245734923373675, 0.041412389546167105, 0.026664119213819504, 0.028846016684838105, 0.025079420556721743, 0.04650453935028054, 0.039340064613497816, 0.0504656969133066, 0.05548172463022638, 0.07303899052203633, 0.10466912412084639, 0.0016202042775148584, 0.03861237768433057, 0.08245434350101277, 0.00906891380509478, 0.002523369357732008, 0.031326854950748384, 0.03830736241070554, 0.035977623556391336, 0.038206819954211824, 0.02637551282532513, 0.03456995495071169, 0.025567980082996655, 0.027501285912876483, 0.02666971686267061, 0.030645496590295807, 0.031579507995047607, 0.06322442888631485, 0.07874085174989887, 0.058496751516941004, 0.07830783084500581, 0.012018670659017516, 0.04129492612264585, 0.06242589282919653, 0.04353113952674903, 0.046431619630311616, 0.04383889703603927, 0.009707007739052642, 0.014623247207055101, 0.09654552370193414, 0.044439635894377716, 0.047480741850449704, 0.017340718331979588, 0.05693688326573465, 0.022015191134414636, 0.05362762822187506, 0.03813559975242242, 0.024840359947120305, 0.03515294905810151, 0.04538483146461658, 0.04738621450087521, 0.01984413273021346, 0.05141818037373014, 0.013653230507770786, 0.05556644820899237, 0.016237769996223506, 0.03379358313395642, 0.057527899989509024, 0.047382878547068685, 0.020406610165082384, 0.03677927663375158, 0.0274312345936778, 0.08209014195017517, 0.029171270325605292, 0.027768844993261155, 0.008993576539069181, 0.04093422379810363, 0.009960417773982044, 0.09994551001000218, 0.04542182752629742, 0.09089842555113137, 0.03031300144357374, 0.04677314485888928, 0.062398485315497965, 0.016856324109539855, 0.034009414521278813, 0.050512682282715105, 0.014188862605806207, 0.0641409886884503, 0.05230260518146679, 0.02007858460274292, 0.01619507238501683, 0.03577774463337846, 0.025987085718952585, 0.019182354080840014, 0.09196446131682023, 0.09889956418192014, 0.04501199131482281, 0.015476697553822305, 0.00433941724622855, 0.04995311035600025, 0.033636637454037555, 0.021634666045429185, 0.030739925605303142, 0.0180025266672601, 0.01845943545049522, 0.03300100281194318, 0.06930794697836973, 0.03841486250166781, 0.01653430808801204, 0.012280886276130332, 0.038364979045582004, 0.03825169391348027, 0.011403609278204385, 0.011673382741719251, 0.036761383453267626, 0.03909567167283967, 0.029889051438658498, 0.02756211604719283, 0.031571463114232756, 0.07658063797862269, 0.01863568068074528, 0.05857379757799208, 0.06601845161640085, 0.023273554470506497, 0.02617813865072094, 0.015732276515336707, 0.024135527455655392, 0.117183351831045, 0.01057556450177799, 0.03822364815277979, 0.05267527463729493, 0.033728686030372046, 0.04168683575699106, 0.02785973952995846, 0.05584416358033195, 0.03775928264076356, 0.09493464764091186, 0.07055330788716674, 0.05888807114388328, 0.01227828597620828, 0.05342861019016709, 0.04167423780017998, 0.05216323355853092, 0.038457061018561944, 0.02820348192472011, 0.007434924946210231, 0.012348449545243056, 0.027447318789199926, 0.09716870510601439, 0.07122308132238686, 0.03263386977778282, 0.022947504876356106, 0.08635752077680081, 0.022329223502310924, 0.05115829510032199, 0.05569200846366584, 0.004913754664812586, 0.08857396707753651, 0.06068392380257137, 0.01161626705652452, 0.10916398605331779, 0.028350618267722894, 0.049827880357042886, 0.07420819223625585, 0.07872802743804641, 0.03304026242403779, 0.011701657640514895, 0.056757624915917404, 0.040478296505170874, 0.021987935760989785, 0.051899837926612236, 0.02148288014723221, 0.04765099423821084, 0.010555495900916867, 0.04489428669330664, 0.04537261942459736, 0.06747782565071248, 0.06791975232772529, 0.05738623141951393, 0.07830883274436928, 0.026444178183737677, 0.009963956890715053, 0.01578419716679491, 0.09919281641487032, 0.10276103275828063, 0.22361320647178218, 0.19595313991885632, 0.13060066936304793, 0.14683982532005757, 0.23256834625499323, 0.2360379757010378, 0.09266517488867976, 0.13196607265854254, 0.12007273311610334, 0.1473274757154286, 0.1840425602858886, 0.18943727627629414, 0.14113535173237324, 0.14837994502158836, 0.18552207620814443, 0.08103525324258953, 0.10668285278370604, 0.1652474032016471, 0.12867872952483594, 0.14442027546465397, 0.11554917233297601, 0.077807652996853, 0.1444763521431014, 0.09619678108720109, 0.1853000998380594, 0.11819283594377339, 0.12465726875234395, 0.13129260332789272, 0.2060140945832245, 0.21466669044457376, 0.12196518000564538, 0.21592314646113664, 0.15255620295647532, 0.1763238979037851, 0.12827379890950397, 0.16235995892202482, 0.0906912401842419, 0.09779107014765032, 0.11811217191279866, 0.1919428855762817, 0.12377819482935593, 0.15777550492202863, 0.13518338673748076, 0.2512804273283109, 0.10741720048827119, 0.15580407867673784, 0.25283757189754397, 0.1340745438938029, 0.13923613645602018, 0.17272264114581048, 0.13334164337720722, 0.1416995472391136, 0.24253923387732357, 0.13810921489493921, 0.17176564171677455, 0.06418363249395043, 0.18849044427042827, 0.23543201212305576, 0.19162074895575643, 0.15349007706390694, 0.11825097579276189, 0.1222591743862722, 0.18122354202205315, 0.1193588538444601, 0.11250614421442151, 0.08337018341990188, 0.16929886158322915, 0.10779086442198604, 0.1452806917950511, 0.10087911694427021, 0.15786661097081378, 0.09057343908352777, 0.09853347015450709, 0.1226115832105279, 0.0763795679085888, 0.08167522202711552, 0.08048441639402881, 0.12253423657966778, 0.1914169848896563, 0.16736595280235633, 0.12443477287888527, 0.1350431950413622, 0.13961334043415263, 0.11405720317270607, 0.10779579228255898, 0.07387712757918052, 0.18835194467101246, 0.09799660052522086, 0.1286418893141672, 0.09010751877212897, 0.14150436240015551, 0.09451177931623533, 0.17879781749797985, 0.23183752375189215, 0.10052821467979811, 0.14013379375683144, 0.07949775332235731, 0.30876187258400023, 0.14370024378877133, 0.07872243906604126, 0.1283381282701157, 0.0936749558604788, 0.13522481342079118, 0.10124229433131404, 0.24280495243147016, 0.12548978033009917, 0.15559682651655748, 0.14714040997205302, 0.07484199377358891, 0.09040002143592574, 0.20000228279968724, 0.09042665711604059, 0.13572942931205034, 0.13243847934063524, 0.15736490429844707, 0.14892324164975435, 0.13205063296481967, 0.17149275401607156, 0.2704288170207292, 0.10901825793553144, 0.16260630742181093, 0.20027315185870975, 0.17451467545470223, 0.1453191350447014, 0.08671341027365997, 0.12283516261959448, 0.11551541203516535, 0.15234454243909568, 0.11915781346033327, 0.11334019203786738, 0.17393875401467085, 0.12245027741300873, 0.1391011694795452, 0.10653526187525131, 0.14938591135432944, 0.2375069828121923, 0.09154396786470897, 0.19884610577719286, 0.1492545215296559, 0.16876637062523514, 0.3402345743961632, 0.150832639192231, 0.1448594339308329, 0.11347898849635385, 0.16367088857805356, 0.17073095426894724, 0.18424979760311544, 0.10416222241474316, 0.10936471473542042, 0.11928369654924609, 0.17400483484379947, 0.18403015157673508, 0.15142724791076034, 0.1749809816828929, 0.15112764289369807, 0.12626170297153294, 0.05934333421464544, 0.11467494463431649, 0.3534165123710409, 0.10472540860064328, 0.09679917493485846, 0.12517212628154084, 0.11419869362725876, 0.1571092937956564, 0.09265776825486682, 0.13895029085688293, 0.10378199047408998, 0.16461307473946363, 0.18193506868556142, 0.0765825824055355, 0.10477421965333633, 0.110268145945156, 0.16832348657771945, 0.1615942851640284], [0.01404020857080468, 0.03785803281061817, 0.04026693284686189, 0.09005090032587759, 0.07184167625382543, 0.036801960377488285, 0.03846900217467919, 0.08612393721705303, 0.01898834183521103, 0.028042818084941246, 0.017738464957801625, 0.08284327341243625, 0.016605036616965663, 0.02461213469359791, 0.051215113926446065, 0.012154382566222921, 0.04393751733005047, 0.04861296605668031, 0.019502750365063548, 0.02333780033950461, 0.03703691691043787, 0.02800576636218466, 0.03220088969101198, 0.045584651015815325, 0.019889112445525825, 0.05280084973492194, 0.013881231261620997, 0.06643938293564133, 0.056902391952462494, 0.03520232414302882, 0.02253812508570263, 0.03984417213359848, 0.03684005481773056, 0.05627600447041914, 0.04955491473083384, 0.06923183231265284, 0.07542825333075598, 0.038826253512525, 0.03240217127313372, 0.03691000223625451, 0.012141129664087202, 0.02910167728259694, 0.038535108978976496, 0.045072442953824066, 0.041672634761198424, 0.026321566110709682, 0.06817441288148984, 0.03509487971314229, 0.038804950163466856, 0.03185251072864048, 0.034829105497919954, 0.025348905510327313, 0.038777958252467215, 0.016296373687509913, 0.06274279730860144, 0.048484251674381085, 0.04003475194622297, 0.08216072019422427, 0.03594026384234894, 0.015771294929436408, 0.08498818409861997, 0.03206840148777701, 0.07659054565010592, 0.027522140262590256, 0.06591960496734828, 0.053019226688775234, 0.02228316767286742, 0.03360852490004618, 0.06091011186072137, 0.08821188806905411, 0.012998789843550185, 0.0877002663037274, 0.015323440347856376, 0.07143155060475692, 0.022972246224526316, 0.03889989311574027, 0.03245174673793372, 0.019304147936054505, 0.15783916634973139, 0.05214607510424685, 0.02016558100876864, 0.03210458118701354, 0.08003300506970845, 0.017413469213352073, 0.00526171848832746, 0.05124417271872517, 0.021397362470452208, 0.03841751939035021, 0.009457742598897312, 0.028800298532587476, 0.03492298346827738, 0.0313132847804809, 0.025329971467726864, 0.0318419944960624, 0.0542259105714038, 0.027348132607585285, 0.08159184915712103, 0.050989820156246424, 0.055955515417736024, 0.05441431589133572, 0.04076082099345513, 0.07390932194539346, 0.040821268921718, 0.03831853544397745, 0.059649941395036876, 0.027547618192329537, 0.04303639791032765, 0.013577937770605786, 0.024529088368581142, 0.049101395707111806, 0.037332569991122, 0.03191398653143551, 0.03431824443396181, 0.03566680839867331, 0.021009480842621997, 0.022190931704244576, 0.05669123238476459, 0.030196610423445236, 0.019462809832475614, 0.056575746784801595, 0.03274784510722384, 0.04207314217637759, 0.08347921975655481, 0.04720015807833988, 0.03364497548318468, 0.03347410340211354, 0.05395167587266769, 0.038382927887141705, 0.06171449975227006, 0.020959855282853823, 0.04718146337836515, 0.0925631592690479, 0.0855732339550741, 0.01991595963772852, 0.03689215729536954, 0.030094438952801283, 0.0012736365033561015, 0.032858443664736114, 0.03771938478166703, 0.05682761315256357, 0.0364283929229714, 0.04129120796278585, 0.04405439816764556, 0.10705575972679071, 0.03254095288866665, 0.041118473091046326, 0.010742694303189637, 0.04864383568929043, 0.019358495410415344, 0.01449863597372314, 0.04137125601118896, 0.06831355072790757, 0.10187752079218626, 0.02666326759936055, 0.05521401712030638, 0.007938944800116587, 0.014940858582122019, 0.016354123908968177, 0.018425619491608813, 0.03306703169073444, 0.01500688653322868, 0.01784221163688926, 0.058936080677085556, 0.027552653664315585, 0.03053240627195919, 0.023299956374103203, 0.005849683129781624, 0.12791035434929654, 0.0592281454737531, 0.0664975079416763, 0.004324290885051596, 0.05290104709274601, 0.03001736320584314, 0.011378956060070777, 0.056513859090046026, 0.015743761250632815, 0.05763912195106968, 0.02793010811728891, 0.09269193673389964, 0.05887469022127334, 0.06749094682163559, 0.037897618967690505, 0.04797409936145414, 0.03793319010583218, 0.024357043694180902, 0.0216176875619567, 0.06639269442530349, 0.07692325787502341, 0.011408483333070762, 0.028247647132957354, 0.0359802878665505, 0.02457890317600686, 0.0287820120138349, 0.0617117241199594, 0.03355641500093043, 0.04423563805175945, 0.05085505355964415, 0.04958911660651211, 0.06822553943493403, 0.04258917600964196, 0.07026634906651452, 0.02632802279549651, 0.015945527084113564, 0.0743575939850416, 0.05707317126507405, 0.04943479070789181, 0.01902317082567606, 0.01823461294407025, 0.030910588029655628, 0.045790571020916104, 0.10116238729096949, 0.05991873244056478, 0.03745054920727853, 0.03126693394733593, 0.027247515936323907, 0.028738646469719242, 0.003333067315907101, 0.04773955100972671, 0.013696858586627059, 0.01691281267994782, 0.056566176790511236, 0.04671333888836671, 0.0535206995846238, 0.0479861258645542, 0.029069596093904693, 0.050721459556370974, 0.04802250594366342, 0.08872416292433627, 0.05811110560898669, 0.036486169119598344, 0.04599273575877305, 0.013452567691274453, 0.048648344236426055, 0.07660549250431359, 0.031631239398848265, 0.017519321736472193, 0.05311006556439679, 0.09598215197911486, 0.04262253925844561, 0.0688688553054817, 0.02627574220241513, 0.043997026441502385, 0.07480497544747777, 0.03741400214494206, 0.06857493513962254, 0.04985462364857085, 0.03364832256920636, 0.017487155200797133, 0.05222405256063212, 0.06523097355966456, 0.025171404195134528, 0.026027994754258543, 0.04252150698448531, 0.045549651331384666, 0.05109161684231367, 0.07979559202794917, 0.004663603585868259, 0.04657172969018575, 0.06803933458286338, 0.002929766874331108, 0.04897094469924923, 0.03860348304442596, 0.0480375604092842, 0.020649223806685768, 0.022651770159427542, 0.020261141798982862, 0.02927328594523715, 0.04932732772431336, 0.01769434798916336, 0.00817340316643822, 0.03422451489313971, 0.06131697206001263, 0.08657062848214991, 0.02641524184582522, 0.05711356265237555, 0.12669072370044887, 0.05076762485259678, 0.0661753564781975, 0.052988943352829665, 0.033410349205951206, 0.10221262273262255, 0.01994091806409415, 0.07495007273973897, 0.04839613648073282, 0.02370070869801566, 0.04195701461867429, 0.09364901779918, 0.0092342568859749, 0.04654665623093024, 0.034539367334218696, 0.024110101476253476, 0.05620513307803776, 0.0646345985296648, 0.03546147469023708, 0.013610148835141445, 0.024978952314995695, 0.05141731948242523, 0.0637571573315654, 0.014719542723469203, 0.08540360868209973, 0.04072146119142417, 0.04073240044817794, 0.038881766158738174, 0.00800415360572515, 0.05488782095198985, 0.02678285356523702, 0.05551676884351764, 0.042926407913910225, 0.055654474344919436, 0.05824681844387669, 0.05518594538443722, 0.0305608657799894, 0.02221342991106212, 0.020993020007153973, 0.05436738989374135, 0.06692594979540445, 0.017518338390800636, 0.0484497232537251, 0.008364016375708161, 0.05974172650894616, 0.054986493196338415, 0.0507216747791972, 0.00652647820970742, 0.022721845598425716, 0.030478133012366015, 0.01066512131728814, 0.08367254180484451, 0.019236371299484745, 0.05777487931482028, 0.07563278180896305, 0.008560312580812024, 0.01938104000146268, 0.012202321595395915, 0.010367224167566746, 0.0675733845855575, 0.010897519296122482, 0.031265405123122036, 0.03979136461566668, 0.034499098401283845, 0.025869961827993393, 0.060506743466248736, 0.02032319833233487, 0.07621034339535981, 0.09775853439350612, 0.006703875160383177, 0.048608097567921504, 0.04623356639058329, 0.011302738421363756, 0.004219430984448991, 0.06025306625815574, 0.021129276465217117, 0.03828913897450548, 0.12275691056856886, 0.0709102809196338, 0.20799267513211817, 0.118378343177028, 0.15687627426814288, 0.14699094142997637, 0.14284411707194522, 0.10933231998933479, 0.09873040646198206, 0.2029930637218058, 0.17446288838982582, 0.19591738324379548, 0.0896849473065231, 0.14409432420507073, 0.19682796875713393, 0.1321217603981495, 0.07465181843144819, 0.2552556374575943, 0.12775423616403714, 0.1264678270672448, 0.17955756891751662, 0.2049520961008966, 0.09694986802060157, 0.16715978417778388, 0.1808522900682874, 0.17449111968744546, 0.06863869304652326, 0.13467572804074734, 0.12623258109670132, 0.2137168453191407, 0.0964059257239569, 0.08830766964820214, 0.11337802672642283, 0.11760540379327722, 0.20347004203358665, 0.16518963442649692, 0.15800509572727606, 0.18942213646369055, 0.17912131967023015, 0.12129440467106178, 0.08638990810140967, 0.11237421262194403, 0.15223893482470885, 0.2387965831439942, 0.11749161771149375, 0.08380034705623984, 0.1599746962892823, 0.15146065939916298, 0.14108417322859168, 0.12317404951318167, 0.13619536446640268, 0.17672352958470583, 0.1809540533577092, 0.12762869446305558, 0.1600400498136878, 0.10474044451257214, 0.2197362863807939, 0.12538426177343354, 0.17016815399983898, 0.08907781855668873, 0.11490014192531817, 0.12059372820658609, 0.09093921398743987, 0.21180977812036872, 0.10691638439311646, 0.1429909880971536, 0.12095306869014166, 0.1270086003933102, 0.1172751554986462, 0.18380768538918346, 0.08126350076054223, 0.20109129545744509, 0.1728967935196124, 0.16611864004516974, 0.11596959899179637, 0.07719341447227634, 0.1565859015681781, 0.13990515290061012, 0.21927008405327797, 0.24899566633393988, 0.10741699268692173, 0.08907493902370334, 0.14150036964565516, 0.08505945996148512, 0.16330319893313572, 0.18400292959995568, 0.10649260322679766, 0.1266185424174182, 0.07631324959220365, 0.14252034772653133, 0.18305182282347232, 0.10689757094951347, 0.10710110494983383, 0.10444866173202172, 0.146712695423048, 0.11016795600880869, 0.2042966164299287, 0.19521520764101297, 0.1814172277227044, 0.24621903954539448, 0.08144812483806163, 0.18006941332714632, 0.16345900541637093, 0.13285495777381584, 0.19646885833935812, 0.0954255931719672, 0.12149022775702178, 0.08682819825480692, 0.06989401357714087, 0.19809922319836915, 0.12780182267306373, 0.11396033805795014, 0.15671503526391461, 0.1256009837379679, 0.15688820800278336, 0.12316257591010071, 0.08900021959561855, 0.16399538522819057, 0.22374771331669763, 0.13090512802591547, 0.11557223086128943, 0.12322454524110071, 0.10173680959269404, 0.22446765593485907, 0.11730042562703602, 0.10187622203375213, 0.20930185331963003, 0.1813598003354855, 0.1258463377598673, 0.14359254331793636, 0.15435819688718766, 0.19855598540743813, 0.10575412918115035, 0.1853118257713504, 0.125041953579057, 0.1521680151927285, 0.12915478757349774, 0.11297075092443265, 0.12832831707783043, 0.19125291088130325, 0.17224459414137527, 0.1796090294374153, 0.21962285652989522, 0.1828061422565952, 0.174939347198233, 0.19417786330450326, 0.1769313309341669, 0.13367764331633225, 0.09627590887248516, 0.14173441333696246, 0.20054792461451143, 0.17955373943550512, 0.17866843147203326, 0.11253018979914486, 0.1787231129128486, 0.13770873716566712, 0.07893595495261252, 0.16523543978109956, 0.14252548338845372, 0.10084637338877656, 0.13024385960306972, 0.12176953503512777, 0.1341246982337907, 0.14675397367682308, 0.13935032329754904, 0.10368713657953776, 0.11494156118715182, 0.2883915218990296, 0.13426388060906902, 0.10660541709512472, 0.1392558924271725, 0.1123786432435736, 0.19519540714100003, 0.1562913876841776, 0.17303192376857623, 0.11265366832958534], [0.030690342719026376, 0.035198887999285944, 0.05191591655602679, 0.01690715380391339, 0.07453253303538077, 0.019562543348001782, 0.05929237093369011, 0.02069842263153987, 0.03277724899817258, 0.05358268004783895, 0.026582802092889324, 0.059186262369621545, 0.03545838364516385, 0.04895270642009564, 0.03011205011716811, 0.07016847463091835, 0.015671637484047096, 0.024153307458618656, 0.0060340539494063705, 0.0335449785052333, 0.0046942037261032965, 0.052979566316935234, 0.06927763024577871, 0.04373209085315466, 0.010253513228235533, 0.1067994738696143, 0.03436778279137798, 0.03633303436799906, 0.05472831857332494, 0.0292539752626908, 0.08872378442902118, 0.013711924184462987, 0.0819092063466087, 0.047479539571213536, 0.0826787318510469, 0.022420379646064248, 0.053389665990835056, 0.03168698582157958, 0.027694025375240017, 0.03592125744035002, 0.03182195650879294, 0.062340464210137725, 0.1022493961500004, 0.0760942195483949, 0.022416373903979547, 0.011468555549072335, 0.02207829966209829, 0.01348191313809366, 0.05780976025562268, 0.032038374192779884, 0.036579078587237746, 0.10600539069855586, 0.05836160642502364, 0.039840992030804045, 0.0847750021785032, 0.0763139026821591, 0.035339064852450974, 0.03550838584487792, 0.10450674220919609, 0.037545922605204396, 0.023662649509788025, 0.0050427923451934475, 0.03629850223660469, 0.0805381330428645, 0.04056250429130159, 0.016394233280152548, 0.0651168757758569, 0.07031432891380973, 0.0436159336095443, 0.053566026253974997, 0.013946033741376596, 0.06168468768009916, 0.005321972066667513, 0.027970590417680796, 0.07741946523310617, 0.039725706810713746, 0.0541050258470932, 0.008201015698432457, 0.041189941912307404, 0.010522800585022196, 0.03333007109176833, 0.033372466277796775, 0.031306486707762815, 0.09823306361795403, 0.051709143081097864, 0.020600830212060828, 0.053021638668724336, 0.01017272581520956, 0.04939713042404037, 0.06721465266309679, 0.04475072193599772, 0.08616710794740357, 0.055962643746170215, 0.025845912532531656, 0.011386064907128457, 0.04517101500823628, 0.04736770533781964, 0.010900189172389219, 0.11581746613956057, 0.02398233333224198, 0.035181480925530195, 0.07318089657928795, 0.029242718737805262, 0.022108772245701402, 0.005142054596944945, 0.011148166686325567, 0.04169216437730938, 0.0491002899070736, 0.035514541959855705, 0.024106155105982907, 0.023410861067532096, 0.11150321326567791, 0.07029069151030853, 0.06008065050991718, 0.021868266303499695, 0.04782971453096252, 0.07286540218046866, 0.03544781175151002, 0.06261040558456443, 0.037819904973730445, 0.032764320785645396, 0.05654617962136399, 0.01735838330205297, 0.03616143127146643, 0.014800460940023186, 0.02465873785695294, 0.028624808437598404, 0.01796447490050923, 0.027895421990251634, 0.07213372620753944, 0.029514270572690293, 0.05872090609045699, 0.006118652754594223, 0.005568116475842544, 0.04457653245481197, 0.1387707208050415, 0.04987422747944947, 0.04475992085644975, 0.03502303239656612, 0.01528518449049443, 0.01998524097871268, 0.06612537283217534, 0.01595002078829566, 0.018149848547182046, 0.040227725185104646, 0.058428588963579386, 0.09201204782584682, 0.03142509303870611, 0.03207768575521186, 0.05166850307432469, 0.037278122326824814, 0.021471734944498166, 0.04721253710158635, 0.0380187263363041, 0.02480088696756866, 0.01633918818697566, 0.010205314447375713, 0.026726604337454773, 0.07642691693035886, 0.014572788586519891, 0.03153965466481168, 0.01793644954886986, 0.033236649542232044, 0.030668514300487004, 0.03545193809259217, 0.048356928818975575, 0.06245828015380539, 0.042547352277324535, 0.045408290752675384, 0.043711314428946935, 0.0626686196483206, 0.02145915183064062, 0.05040998388722073, 0.050760374069795944, 0.06623657624004409, 0.026881102785409894, 0.008321725090354448, 0.04340184255852364, 0.0635847712692339, 0.025815612498263363, 0.02171940817788709, 0.026357280112279113, 0.052311069375718944, 0.028367246086418163, 0.049765462026698515, 0.012742962262564106, 0.022524610576510895, 0.030189357785275206, 0.02632793373777531, 0.11531935146194883, 0.006365492463373812, 0.02906516176153673, 0.028403422074916307, 0.03496550481941085, 0.06150873188744299, 0.02007682571274927, 0.008190143234969582, 0.010404662734799786, 0.05044835663284175, 0.025118117991951294, 0.07873646565712988, 0.09028873639181256, 0.04051640578836668, 0.02267412179207895, 0.0386284600244835, 0.027263117735856213, 0.004842534463023185, 0.03371257771505043, 0.07462714944267645, 0.046497878574882634, 0.026122739182028454, 0.019073436487815343, 0.07908942367066629, 0.04084276522917207, 0.020681752139353193, 0.04534841427812353, 0.01930398280819645, 0.04549488454358652, 0.12549325358122587, 0.02893938999477541, 0.017320390907116234, 0.06790152518078685, 0.028221165448485408, 0.06544091229443438, 0.03510429756715894, 0.033282610747846775, 0.04625602377927862, 0.06341611078823917, 0.023816079265088774, 0.011721543487510644, 0.007860099958634237, 0.06849240831797943, 0.02057229092315538, 0.017925196734722704, 0.04090985166840255, 0.05843262253620196, 0.0039046694564603968, 0.009027323849295499, 0.049400670468457974, 0.020485975437622983, 0.031165808904916048, 0.1268585678189993, 0.033829625535872765, 0.041389839389012195, 0.025292377977166325, 0.034443875192664564, 0.07240140403155237, 0.019909630973415915, 0.028016247342748102, 0.017662138779996894, 0.012959303876414197, 0.03821759222773835, 0.03345983932376839, 0.02746266825852217, 0.044600273758987896, 0.035274249385111034, 0.03539230652677361, 0.03452434255450498, 0.0070650635916535975, 0.0715352212137077, 0.09351432541734539, 0.04359432226920035, 0.10029228593339212, 0.015789937679073773, 0.0714064363273792, 0.05646328172588255, 0.02117056956194574, 0.01618861384486081, 0.032651525471010245, 0.03321038493595552, 0.03916737055988051, 0.04434746486367658, 0.049713281623553485, 0.03268646207288839, 0.0473388988757506, 0.016447508351120632, 0.0380521897750441, 0.0275338161009131, 0.0408207605505595, 0.01512494274720666, 0.04202001182420645, 0.04030107906146441, 0.04148851163336076, 0.05972390383249149, 0.06596566265216097, 0.02625594541314058, 0.044106252025812864, 0.09818143982556649, 0.06608972005778924, 0.013659671421919484, 0.03434624937654007, 0.04458240655367263, 0.04335143959906418, 0.03782196814427152, 0.0306432627257891, 0.060317666502669454, 0.02042817883193493, 0.016456289813504554, 0.035756804936681874, 0.03430455923080444, 0.06363343389239162, 0.008881482553988462, 0.08836445878841914, 0.054170739313121885, 0.08120300088194199, 0.019623896696430165, 0.0572746717807604, 0.027557423818507232, 0.06467070401413366, 0.048411610259790905, 0.04686494852649048, 0.08381864099646918, 0.027153218652529176, 0.006128916193119949, 0.01995116897887783, 0.08708898152690381, 0.03311536776891444, 0.02962927748740185, 0.0396165183337871, 0.07006923464359716, 0.0463919407047797, 0.05432965168438386, 0.05649930928484537, 0.045477317908080295, 0.036908992915414274, 0.04839590270421468, 0.0930689180677291, 0.0476970593445003, 0.01844427337346133, 0.03391158090380486, 0.08360385603737086, 0.023835658976167906, 0.014511630051856628, 0.01974708207853837, 0.006490057776318281, 0.015339497640525224, 0.04857124251429923, 0.006887007521072519, 0.027420835249358788, 0.07485414273105562, 0.05744470523495693, 0.02854499045497505, 0.022646758807240985, 0.005388649396991241, 0.01129324078647187, 0.05027646038797684, 0.04881060369370971, 0.10434591880766675, 0.037727225571870804, 0.025721545280248392, 0.03313322755275294, 0.06585971364984289, 0.08499244402628392, 0.1175356493331492, 0.14438989193877205, 0.1233959590899758, 0.16625406715320423, 0.24816788965836167, 0.1229661591059994, 0.09669986815424636, 0.13588403351604939, 0.1340350171085447, 0.10792791683343239, 0.16442866588477045, 0.09277174729504623, 0.16384547139750794, 0.06812753883423284, 0.1732960986555554, 0.06691059475997463, 0.08568549121264368, 0.08771197739406489, 0.07789422452333383, 0.06699503632262349, 0.12337168343947269, 0.09601055397070013, 0.1362791084102355, 0.11623044905718416, 0.1822050174814649, 0.20716028229799122, 0.09226211448549293, 0.12827324972022325, 0.08146338339429349, 0.2329305440071039, 0.06267708755331114, 0.21969931258354336, 0.15497328888159245, 0.11605111649259925, 0.09565823420416564, 0.23306181508814916, 0.12001540220808238, 0.09819547383813187, 0.19500145426718518, 0.0867928349180147, 0.15092911839019507, 0.2175244191312231, 0.12593423773068935, 0.09676724774180911, 0.1513213137513958, 0.1234529931389261, 0.16585033881710842, 0.16715237754397094, 0.11414139982662164, 0.19033333053812385, 0.17341319471597672, 0.13553378434153274, 0.08031374469283037, 0.33732829440850765, 0.20626649900805205, 0.10459783341502771, 0.07970332080731168, 0.108192744810367, 0.15667292580474168, 0.10097709528054111, 0.12560445698909461, 0.12558235583128408, 0.12041399488225579, 0.11534706325619482, 0.2656893728999421, 0.13379653537413105, 0.20693517406471074, 0.13951686123618856, 0.12656795763177797, 0.10217895149253309, 0.1794075215002522, 0.09419559472007677, 0.13999688235344365, 0.12194387294584885, 0.12053011130774394, 0.14080891065532342, 0.10967577851261012, 0.17248718737391755, 0.09707578079542145, 0.14837979659205303, 0.17240620421944186, 0.1479828217998147, 0.1706494961399585, 0.2184507975471206, 0.12508844170952216, 0.17563692148542032, 0.09680577262770385, 0.1710747616016306, 0.15167684701737016, 0.09434478124603629, 0.17594485339941457, 0.10531981693929993, 0.1363847457105294, 0.07351404667133465, 0.13896698917960748, 0.13849992596078664, 0.09501191263552755, 0.18238987162476406, 0.09402749084983952, 0.1961619802750647, 0.13503847498213872, 0.13964787998702377, 0.1509979006368667, 0.1680070793372579, 0.1290965883526951, 0.13849942130036652, 0.10188040032517165, 0.18399846187094226, 0.10247319078189321, 0.08807842765236273, 0.3272970108082518, 0.09425624302821234, 0.11160219350131229, 0.07676454959437251, 0.15914982883259654, 0.1590623741503805, 0.13140646362444386, 0.17573907069163397, 0.24949226703029126, 0.1575498326565139, 0.17215240455698222, 0.0883315816463437, 0.12821840500691906, 0.16495587275130674, 0.11371281696483493, 0.15425917954416946, 0.1478588386089541, 0.137710488634184, 0.15531660639680922, 0.09367195758386515, 0.12762057536747307, 0.0974964078341145, 0.09676894725998864, 0.14554467372363433, 0.252327419584617, 0.08475214403006248, 0.09940054354956374, 0.10515342743019573, 0.14601127681089565, 0.08833871368551627, 0.13879604288376868, 0.10535121720749885, 0.1712448470061645, 0.13393494591582566, 0.13842275744536892, 0.23146227904362604, 0.09845141830737703, 0.11130242521176115, 0.12479394266847521, 0.19846361770760268, 0.08700289981788956, 0.09491932971286587, 0.17680988588836044, 0.17101448436733335, 0.0820143315650057, 0.14890390128130093, 0.15659097785828635, 0.18507502129068598, 0.08535438202670775, 0.12981216714251786, 0.1390452857594937, 0.1346944153192453, 0.1679472325486131, 0.20290102256694809, 0.1671048504067585, 0.1163492669002153, 0.13446151453536004, 0.11488843083498068, 0.1504359909449704, 0.12104502820875496, 0.16164105531061068, 0.19447338650934398, 0.10383261236711405, 0.11206797280465253, 0.22639600792899728], [0.0075832389848073944, 0.07588679669424891, 0.014760234680579742, 0.03457838945905678, 0.04763503806316294, 0.009572645612934139, 0.07256802360643633, 0.07837421595468186, 0.03967563039623201, 0.03682787988509517, 0.010732975879363948, 0.029091222277202178, 0.04267304982931819, 0.08382590662222356, 0.03500650105706882, 0.0129146850304096, 0.028595011208381038, 0.08194137102691457, 0.08042786474106833, 0.06673503230558708, 0.03744771791389212, 0.04221674404107034, 0.059716820032917894, 0.07817467470886186, 0.03511509581585415, 0.017255291568289977, 0.04132121670409106, 0.053057488112244755, 0.01139281010182458, 0.04989075139747001, 0.16675078659318388, 0.09344784382847138, 0.008372102074645227, 0.028174330363981426, 0.03545995328749996, 0.0967355803004466, 0.03251884059864096, 0.040548518518335186, 0.04900699823338073, 0.044488751227618195, 0.03315300949907396, 0.0827841019781772, 0.050586414654389955, 0.0189352541565313, 0.054431800890597515, 0.007143363418435911, 0.022461657899839338, 0.025326939794467762, 0.045600592347909696, 0.02885593734390568, 0.026141769703826867, 0.011645736813079566, 0.04708583765022922, 0.03990906923718285, 0.00861751546835876, 0.022069944934628438, 0.0034008015109066037, 0.014918175766069908, 0.04561297879263293, 0.053906660905340686, 0.050829230531235225, 0.024596612674940843, 0.042514130036579445, 0.036885181107209064, 0.04896067337540444, 0.01027284617521218, 0.01783720770617947, 0.015482619892281946, 0.020134880214754958, 0.07786945163388737, 0.0260891328798607, 0.04837540087464731, 0.03928226244170219, 0.038196838067960925, 0.03588989427953493, 0.04263263617758639, 0.04052415752084926, 0.0012403263644955587, 0.04850570716371294, 0.0018473167733645823, 0.06387414206983522, 0.03949298043153249, 0.03254894952988252, 0.06245223165024072, 0.0264407643044251, 0.019107742264168337, 0.04060854342242237, 0.07428251832607202, 0.012084064073860645, 0.009328447486041114, 0.019079039702774025, 0.019265300215920433, 0.044628237883443944, 0.0560642994241789, 0.03124836912320461, 0.02905561403167667, 0.03376417182153091, 0.03035682897461811, 0.014461541577475145, 0.01101868325349642, 0.04588446383422706, 0.046676142446813174, 0.029336413026612718, 0.04013219593616668, 0.05267793152597733, 0.025697841083456296, 0.023289907694561407, 0.05352210966520943, 0.043217615530011244, 0.014901895829098066, 0.018912535160779953, 0.028973066800972447, 0.027382121115806513, 0.03574716072762385, 0.01626498269615695, 0.04281237692339346, 0.018451249561621808, 0.01885548626887612, 0.040643732354510576, 0.09893581809592433, 0.034360769495833665, 0.017823338821472134, 0.03160980617394671, 0.08595583334681578, 0.03273940317740198, 0.030241456552175805, 0.03530299276462756, 0.04222902287438046, 0.0922617434116546, 0.02400823428615695, 0.02035871752013918, 0.05023813959269319, 0.01633290776226204, 0.06551247017341666, 0.11661198717774823, 0.019338069650984835, 0.06136374220659491, 0.03133716338197701, 0.056194739299826324, 0.026927089966193307, 0.1541190769057721, 0.024523028732801322, 0.049181024442077614, 0.04096395794476848, 0.012146527860750211, 0.08627142422483303, 0.029770675173494965, 0.04373742689494975, 0.034538884938228875, 0.012298669062147383, 0.07899541582446545, 0.023030014999676496, 0.031499782780883834, 0.0737146195024252, 0.02669615587365115, 0.030230866104830056, 0.03127126437902916, 0.05313712426868733, 0.0602502423862461, 0.027407372690504417, 0.0225554171265685, 0.04967961409420241, 0.05437413230538368, 0.09170044228085317, 0.04688604036346078, 0.0248634667150327, 0.034457189321983606, 0.04908692753815558, 0.11415848406613804, 0.03483884618617594, 0.04801478760782629, 0.02786064495012397, 0.042877062514889985, 0.05375687323976308, 0.002426498213026207, 0.02289033538545482, 0.01033316237226245, 0.028211118624312803, 0.03663867675641086, 0.010152427148568677, 0.04201237141387537, 0.028659019590122625, 0.030644357393612154, 0.02659362075064564, 0.008648586408526171, 0.07954337314004079, 0.03374752544914372, 0.025102258296101354, 0.011361056385794654, 0.03868462204991374, 0.045123153904569335, 0.031211354507831857, 0.05621109623461962, 0.08470381537335925, 0.033977902930928394, 0.01489355130615877, 0.042235898872604594, 0.053289090137695894, 0.04190228493825998, 0.014436527490033768, 0.006600558926947997, 0.043283291888656095, 0.02048095851932885, 0.01875136666058097, 0.06310662036412396, 0.00736707966098038, 0.022846921601740178, 0.024174011523427907, 0.016416813123214524, 0.02831460184097523, 0.02493177955329884, 0.028730417907354422, 0.004680486053985078, 0.05025320147979073, 0.04242005539708771, 0.053770922095282, 0.02869152565835975, 0.020134212281845976, 0.05914282075536903, 0.03342833886563312, 0.09886183339403942, 0.0389564336364856, 0.025465224171057343, 0.017239786247955635, 0.04352883515821304, 0.04256955362507142, 0.061750471650157124, 0.008141476901073474, 0.0282140185663593, 0.04993925445887726, 0.03830021552857943, 0.032568267633905634, 0.048723074796725996, 0.016540089418413118, 0.07655377965420485, 0.050186359949293546, 0.029030399564362597, 0.051925931838923134, 0.03858241347188596, 0.06459825555793941, 0.02258052769320784, 0.010150940070161596, 0.020209013346175198, 0.03485852794256061, 0.039254461589735, 0.04646771769330371, 0.018735339981503785, 0.04635528603103012, 0.02209322054113727, 0.03948216362914536, 0.07725139847025275, 0.03347480102092959, 0.11039503093343228, 0.024222828142228536, 0.021175508554733824, 0.006895173000884824, 0.04934808188409079, 0.04176191141596064, 0.05327377963112667, 0.06861636182293296, 0.017921947983268183, 0.014837000580882886, 0.03416187391849235, 0.014916196087142453, 0.033611883118283004, 0.0457863667543279, 0.021912496449658647, 0.0345330813433975, 0.025221734795195516, 0.036069245397811756, 0.040287019073730335, 0.035770720205619, 0.031656554056098685, 0.02454396842949791, 0.048157985002035275, 0.040785297023830935, 0.07586831721710041, 0.05771301017375663, 0.03732694451173302, 0.0386278848600341, 0.027060288775828667, 0.02641521587065654, 0.06807900979765691, 0.03956500586355105, 0.026246989546052646, 0.01055940145306522, 0.01603703945875168, 0.02110753339366056, 0.036731775471707806, 0.030761802263441496, 0.05428479998954572, 0.02276515919220401, 0.026848800807783846, 0.012981474610569421, 0.04722410718386527, 0.05676954751834273, 0.059580019951681606, 0.04202603806334082, 0.04178776413027663, 0.0990473703132011, 0.05074359040008858, 0.018318152797291987, 0.028004120649711695, 0.08167924446752295, 0.04089571004442405, 0.03643238938821014, 0.04153517416852992, 0.021015443999203853, 0.0270565186656313, 0.07992448823642917, 0.05837872777192388, 0.05789801274659112, 0.027586315627559088, 0.06856871594209224, 0.02851992812793469, 0.0217150239404873, 0.05201632171520032, 0.06725322949932888, 0.04573213060211856, 0.03978128625021782, 0.05585247934504878, 0.024280758334498387, 0.02423037021799246, 0.06011035497067496, 0.051658283700817265, 0.05717084161005914, 0.05289639382681344, 0.019683984683069866, 0.07884166509029455, 0.0621597846475197, 0.0160944445815403, 0.027625753355096094, 0.09740176174091175, 0.04073736912687309, 0.11282914172625169, 0.018839897456928156, 0.0283187467357493, 0.07312746936804615, 0.0805627649242524, 0.007403717172564939, 0.04753913402964827, 0.07918128671008162, 0.01758609461830929, 0.04420737335749436, 0.0139847413811367, 0.05022950099373702, 0.045421890608849935, 0.05005835431802552, 0.035380057379370555, 0.04099142854101956, 0.042435313953319564, 0.011331908535794355, 0.06405727443052456, 0.1257365889614448, 0.07746012750430964, 0.0818519719177857, 0.1604974947986193, 0.133803496719338, 0.12576801149407402, 0.12293512249016203, 0.16117250779643655, 0.15916381089482456, 0.09437181768589653, 0.12135076336562634, 0.08136919743265025, 0.20965919742593542, 0.12456550961360335, 0.2883358905091882, 0.18628734920639545, 0.18400033208308741, 0.18227602617116645, 0.21739915944635868, 0.15564413100946695, 0.12610987439984456, 0.23032850003801286, 0.1910319141461514, 0.11625516999629326, 0.1430345224798657, 0.09007137618027627, 0.0872754461306613, 0.12347830779617652, 0.17969553417060524, 0.2432231674902141, 0.1661005464848131, 0.14919514971552417, 0.09931607972248457, 0.1472220610594377, 0.1124297920614481, 0.12016481879982166, 0.19752342050196603, 0.12446076289052144, 0.14670741133159027, 0.06247187629924156, 0.18759554775897413, 0.15985120291588828, 0.08255390261183493, 0.1535523432539776, 0.13919856894062832, 0.1013304985826835, 0.08366200330783613, 0.14738405705429614, 0.09891546840663068, 0.15448685560841113, 0.07834628151613288, 0.08832732914015651, 0.13386070146225393, 0.12895154301077127, 0.08852810977259651, 0.10759948680060916, 0.15820943866856396, 0.17226038704393432, 0.2433983885566704, 0.09290606860304251, 0.08104372114758007, 0.08362257300177589, 0.16542931844014674, 0.1368283570627682, 0.14293134910985827, 0.13626543805003166, 0.16556814458454028, 0.09664311612141319, 0.17943652463145554, 0.15312332252506167, 0.16418136743595824, 0.0775990798138082, 0.13079266296699643, 0.1417412410955876, 0.1150687578774523, 0.15819137479411438, 0.11172254759003408, 0.21220276015810668, 0.09554815143928863, 0.26038996351417154, 0.09227696486050263, 0.10629525131662376, 0.12003420080873184, 0.07622814751812257, 0.11491171200759709, 0.16930718848016113, 0.15539644664386287, 0.07825044798664749, 0.16987433773465455, 0.08666866619023494, 0.13151150720659643, 0.15157947724219412, 0.1576785062206909, 0.10736275653471239, 0.17363868886604905, 0.18677540036151186, 0.08548612066078931, 0.12416528421454132, 0.12775141600286588, 0.188624847214669, 0.21942237275652587, 0.10045267888926901, 0.126881871256046, 0.09498279076069593, 0.1771004218608141, 0.11014213669113815, 0.17368302476825193, 0.17222440772457048, 0.2189429453574121, 0.08268808291177265, 0.1266916439635679, 0.09619763455702923, 0.15074657974764705, 0.10796459377161227, 0.18249121931148693, 0.12533576984424144, 0.11765234463382512, 0.12580219481606036, 0.19460821989923716, 0.14816783921560273, 0.13174218154745176, 0.14077097206609324, 0.20642494753701612, 0.11281038765446283, 0.10029844575910829, 0.14259324147133157, 0.14520208351314068, 0.1929242571350187, 0.09159713532426395, 0.17762274539563805, 0.07387304576695897, 0.09756609550095163, 0.15210855432087556, 0.1987441346864216, 0.1380836998578161, 0.16486587992403656, 0.14227956533432007, 0.18958632921567187, 0.15849854971747845, 0.24400948779657483, 0.11718115507392213, 0.09991505969082937, 0.16578684066189453, 0.10874885090743192, 0.1570369492401369, 0.14045576710486785, 0.09886140294838697, 0.15836741222301498, 0.15376314288005233, 0.12354412145214155, 0.09300524179707281, 0.13790552504360676, 0.12536627211375162, 0.08560363974538632, 0.12541247822809964, 0.15866119880229235, 0.15370236098533496, 0.1497297632158734, 0.08268594552646391, 0.14236446702852845, 0.16853756649652496, 0.12615746090887114, 0.2405000347062014, 0.18356390472035855, 0.15645783656509593, 0.22533065493917093, 0.11064394726417959, 0.12772711808793247, 0.14150603965390474, 0.19371850357856601, 0.1130295661278069, 0.17883502878248692, 0.15811708581168205, 0.17874175566248596, 0.08900725515559316], [0.036000941836391576, 0.019015417237824295, 0.007513010477850912, 0.07063291064696386, 0.04823876777663827, 0.005131596808496397, 0.022992959566181526, 0.002127219277099357, 0.07080640250933357, 0.05088701786007732, 0.022129084827611223, 0.08101163068204187, 0.02136880277248565, 0.05868426254892256, 0.03139654632832389, 0.04888270705123432, 0.05209218033996876, 0.009966876314138062, 0.03095070853305515, 0.02149506806745194, 0.03149210897390731, 0.039334383473033085, 0.020777290665137116, 0.04602933848218527, 0.02749348965153331, 0.028480815090006217, 0.03308158520667348, 0.029038880456937477, 0.04030898664495908, 0.01446273365218076, 0.0314352753048297, 0.03140634267765563, 0.03998332853370812, 0.03708676325913984, 0.05384541516832542, 0.03619969269493595, 0.03849517772323452, 0.060238048899918795, 0.024566538995713927, 0.09678836184320971, 0.08505284000420943, 0.07275281837792136, 0.058372712665004656, 0.0769582501379773, 0.030556099336536136, 0.018101004097843543, 0.03151574266667012, 0.05308132960635703, 0.04281165332940873, 0.021401056510512717, 0.009770826873136684, 0.02232957416708814, 0.02510380381863797, 0.03395090730919037, 0.013479833269229857, 0.026314831120544113, 0.04330094016040675, 0.020094297724426724, 0.015967284998623654, 0.015476887729164446, 0.036246752279112116, 0.017649375695327763, 0.046340409680851735, 0.019231272744946182, 0.03130702105409, 0.020168111732346006, 0.03477860605926253, 0.05034603673266247, 0.020730973228637595, 0.0705633862526156, 0.07834796619135886, 0.03025379846803844, 0.050030954225803725, 0.034619445068528876, 0.006582766864084988, 0.06339596890029497, 0.049461630478617735, 0.030289722126326524, 0.03094002717261901, 0.10654631987563334, 0.032412049258709885, 0.012325518109719269, 0.0795913307229057, 0.05952225488726981, 0.08153189846780151, 0.0324838854430709, 0.04235606000293046, 0.03258230535720941, 0.09977007372071967, 0.06001505949825514, 0.009158106040558778, 0.03520167476381175, 0.05785329834907316, 0.026297065960534383, 0.04548439057543874, 0.05557941352890339, 0.019621460596681572, 0.06164810722111724, 0.038812694474472664, 0.05473599238030147, 0.056220217229565606, 0.0260711617738707, 0.05193641467485577, 0.031036185391712934, 0.03282174075138755, 0.016601921452092938, 0.03713389334734529, 0.030457657157967333, 0.03303939040051773, 0.031259701718227006, 0.061599199689226225, 0.13044186460319906, 0.10536560002947226, 0.03954095285735093, 0.06316534650977701, 0.04536038883088622, 0.0038614887535004527, 0.025543402007315308, 0.058414436207385734, 0.02083425049931975, 0.0179330764876795, 0.044173568530823104, 0.12709186936262995, 0.015244865462591406, 0.03985280331107788, 0.08051369411987253, 0.01711730961687863, 0.022290472261374816, 0.05153361402335577, 0.0138291983603267, 0.03656942324596457, 0.027740546902350616, 0.0244478732929565, 0.06900069041876122, 0.021707001324102748, 0.047601582045899704, 0.07958914138725959, 0.06679758051177487, 0.03459242347162217, 0.12333660954027437, 0.02906055116909556, 0.042499246264924295, 0.028738316214003135, 0.028954431472811848, 0.025691571790957823, 0.06116790056694299, 0.02796980374114355, 0.07445653711329214, 0.0195659256860381, 0.008922658762458013, 0.03190161121892743, 0.05749765747168567, 0.02129368258465547, 0.045427605145960115, 0.01655818854487734, 0.10515853340621106, 0.0602359449112555, 0.019924633488699328, 0.07951347943162546, 0.06495728433947079, 0.04906776528514456, 0.03882770812197123, 0.0884403582313098, 0.034655903073144145, 0.053176398723735474, 0.01416781251464272, 0.03574959497200325, 0.025225037352356594, 0.07883281126851216, 0.010532156284170924, 0.0451616268401267, 0.015800500295881648, 0.019248366261308547, 0.026142504430026747, 0.022665553697152063, 0.02327050424355548, 0.024761610657151323, 0.04525582764472347, 0.004159949703534949, 0.03208082132914569, 0.022315933492791373, 0.06701282560243271, 0.03170760639477521, 0.11427951350924559, 0.03769820759771392, 0.01355873284410336, 0.03807062101259362, 0.04813117491721641, 0.031296319284592755, 0.07284167571924627, 0.02564427471952513, 0.017998186958720908, 0.02944846619357122, 0.06506428719148971, 0.05293837712088134, 0.026831417853827588, 0.05892521563509945, 0.05709179175028112, 0.04826978583878372, 0.009897633008222328, 0.07175322709372267, 0.02029108931310475, 0.06808970414567739, 0.0490124270436354, 0.036786260243388824, 0.053944495593896136, 0.029696068922930863, 0.018100410379702225, 0.06376886842190288, 0.017994834306591656, 0.07682615527301095, 0.045331875517149456, 0.013077566036372446, 0.045125873875804245, 0.06382088555255905, 0.03577988572942559, 0.02323322059964994, 0.04390369023894891, 0.04937055411573965, 0.048306332901120186, 0.020303401543060318, 0.021828238568559755, 0.02154442830942571, 0.0588397313549649, 0.010285181597282644, 0.021634217046084814, 0.03654765976534691, 0.0457028194796294, 0.07742871981463395, 0.04818009358132258, 0.06229705599253066, 0.04315995807701256, 0.03032011678442359, 0.011156178170494968, 0.039843378035584465, 0.016858860399224795, 0.06057705824787263, 0.013215844846854452, 0.038563566631637514, 0.026710640740930103, 0.01971864669030765, 0.012809915115212789, 0.04138621770835016, 0.006821420220148866, 0.01644836738705635, 0.05342653959814925, 0.027766087914642412, 0.012434718646545662, 0.01881665339169558, 0.018942820352094714, 0.04853047263168264, 0.03239947356632911, 0.021554324848693796, 0.023553238388558384, 0.019653437884699088, 0.08559727211832069, 0.022034666944819037, 0.03268998727435246, 0.014617381457355805, 0.038423334117396735, 0.0968272281170357, 0.0216665988045861, 0.01509626430561184, 0.013622803380712867, 0.04459982104890514, 0.04071919393027201, 0.0036787388307857327, 0.06109652451414149, 0.03825741587206721, 0.0166550685025868, 0.06837956476374529, 0.031881042596069165, 0.06370454648276791, 0.030996628920547664, 0.027195493239560165, 0.017293959317612462, 0.07827023364370689, 0.05662654308252968, 0.058616170499590226, 0.007880559114710195, 0.0582668898277916, 0.042736518298625015, 0.041081610615947284, 0.03196091995050665, 0.040267133226734586, 0.022774449025746435, 0.03892188295139931, 0.09733126513310708, 0.027539018556126393, 0.04089207352080848, 0.07728304364718497, 0.04260119880200364, 0.027167584776179865, 0.012635208913707174, 0.04575792023388203, 0.030007548302819487, 0.07755821716273203, 0.02305035541212419, 0.03972529491875321, 0.04520153954217676, 0.025065000627364498, 0.06763359502656385, 0.07976024353411049, 0.038179015391506255, 0.041846219392027706, 0.043405842734500766, 0.06006492811138742, 0.06165704267914407, 0.04525757169176359, 0.11402166914194822, 0.06747554725734517, 0.0295769467993523, 0.028050221008015797, 0.03856196359265596, 0.03320208030345384, 0.08412284732912667, 0.023994354269234464, 0.03941379327443428, 0.046362659268197604, 0.05005883671401534, 0.04045828078233171, 0.012561203802761156, 0.013818368570355233, 0.050712164156720974, 0.019318161539558787, 0.04411466798046604, 0.0169027027732227, 0.030222754430724308, 0.08284424562589265, 0.01709783566184342, 0.0549690564366756, 0.05001905017707031, 0.05590604014287237, 0.026075861424033064, 0.02824367107677972, 0.07913349239970557, 0.024564974919485394, 0.04104415813344531, 0.016301655923598446, 0.0327424979332136, 0.024992014114104677, 0.026350238986196928, 0.044394338910933584, 0.023024458168947604, 0.018597070447867736, 0.021095317642902955, 0.07757063329336233, 0.016445157598354854, 0.010797647555591539, 0.042561330628814176, 0.042008486270788126, 0.036083761806366965, 0.14300277340225875, 0.12139440164901316, 0.11618519289186224, 0.1476952395751141, 0.1942710325238295, 0.12680121464654803, 0.0993586122058332, 0.21747144463006407, 0.11532241653185338, 0.1027153164613992, 0.13132787018548697, 0.24792050215182826, 0.17387218336807564, 0.0965024197648745, 0.13077977928332984, 0.20648310222895816, 0.10201267330558039, 0.08519067909219302, 0.12231802669703029, 0.13951212633401155, 0.15383664518594742, 0.2318324029329233, 0.15476223692530766, 0.09113022053497843, 0.11497176659759134, 0.10313868202501908, 0.30816815444268286, 0.11991154606221244, 0.23160935787018389, 0.10224672441836447, 0.0935052266868297, 0.10023280279710889, 0.16402781708166003, 0.14263754768762738, 0.11081130898674019, 0.14158398000290617, 0.11156139764352702, 0.11361779979779385, 0.11206600611330941, 0.16341661394108087, 0.15285539237083867, 0.3013401583302766, 0.17854912381153554, 0.19867938972311094, 0.07555923497420736, 0.08750165274250321, 0.1041507042828016, 0.10636447885190137, 0.13392966182436794, 0.1370954856975004, 0.15663486847188324, 0.132219337974675, 0.20579191041179, 0.11096249188994989, 0.11473358172224835, 0.1421552407555282, 0.24469877971569076, 0.11410884180804715, 0.07259364996571094, 0.12007695593638346, 0.1621884634369053, 0.1097337254032027, 0.10507444065297022, 0.1346910311258398, 0.11441211303463206, 0.06388602385413833, 0.08988382804091088, 0.22691842052154243, 0.11957061826251447, 0.1190278040303383, 0.19534324295818806, 0.12117643287638202, 0.10383248620200902, 0.14175681135384366, 0.10120078601175919, 0.12120991115807556, 0.1538570097181946, 0.10035714964033104, 0.15377212286693975, 0.19349872396560386, 0.09276437776861712, 0.15082751837326214, 0.20391064026625827, 0.21842247719177976, 0.2304186116089113, 0.05618971867079381, 0.12254141314770095, 0.13011156435823068, 0.22019597265170887, 0.18224755738629028, 0.14971279771998525, 0.11428673460613936, 0.20598512113792822, 0.06821245537139475, 0.1393132159137167, 0.125812852056697, 0.14274046872742474, 0.1437964558135718, 0.2109722644672729, 0.09828186724917032, 0.2625950030051172, 0.11741145834093913, 0.12835806235671043, 0.12072050187271088, 0.15143575292313471, 0.17692996538244188, 0.12303479292313568, 0.12900776811875403, 0.15711380605353042, 0.16395710525102913, 0.18278105766512454, 0.20548172236885875, 0.19101131212664768, 0.15205422911094502, 0.14405399590032175, 0.09687825819128193, 0.1777673899778165, 0.12654762278543785, 0.17116925184382126, 0.08746994819375686, 0.15432520100148395, 0.13668731931829825, 0.1907131914049387, 0.1716314911027439, 0.1033103110967204, 0.1922987453872338, 0.13753068109508604, 0.08611759927589446, 0.13466167176375166, 0.10703242660383694, 0.11969492057687603, 0.133483289682772, 0.10817793154274113, 0.19593227072618902, 0.09865173138678074, 0.13954215362900868, 0.1270710743847303, 0.1298681992921047, 0.10221540578640997, 0.2224318409571424, 0.1568904789746739, 0.21545424271607772, 0.13772353559033945, 0.17961762350751087, 0.07360430667176843, 0.2091466257115826, 0.1249206272768788, 0.1333531763521023, 0.11302556595182978, 0.1146125300147105, 0.10897911706706509, 0.19345174601767212, 0.2673380688065663, 0.13862200925359502, 0.15826382325030863, 0.09845650944043882, 0.13540517014916986, 0.1514234035857953, 0.13215177285019308, 0.2263639323064126, 0.1394194914610125, 0.1495771628106013, 0.11716051594703458, 0.12573724205140024, 0.08743008744204417, 0.11348595726303756, 0.1306226963060908, 0.13739317597355694, 0.14616617787396535, 0.0874101162480656, 0.14669817901449278, 0.07760318389046006, 0.04507688841840718, 0.07858160170144401, 0.0798415532335639, 0.17418008559616283], [0.04236879154632334, 0.010177342901442898, 0.03342713287565857, 0.01914989810757106, 0.0929150337469764, 0.07205004163552076, 0.029319176646822598, 0.07803903237800114, 0.04600656196998898, 0.05770036768808495, 0.0235458874158212, 0.017617060730117373, 0.07524333981564268, 0.05070333631010726, 0.05765418383816723, 0.04235013395373244, 0.043627989798551425, 0.07717596658039838, 0.03084517698880518, 0.026801475905813277, 0.0342397882923251, 0.057668559238663875, 0.014664441041531973, 0.06515330780530348, 0.04943867214024067, 0.058732728502945974, 0.02377725195401581, 0.03171568467223551, 0.030709057828062214, 0.0738009090127889, 0.052637050321209244, 0.029051894016447477, 0.016453872267447878, 0.01657619490288198, 0.044979318263358437, 0.05141633242601529, 0.03241871374484617, 0.036568510404322296, 0.05522160186956171, 0.02479905386280734, 0.04567646210489329, 0.04718915944977198, 0.09466189352679066, 0.023676497985434253, 0.05706275151169393, 0.03539702658599708, 0.008322448684339179, 0.02686661791813094, 0.013232817764219362, 0.012056813338858774, 0.04977287237124983, 0.03954655236157123, 0.0042510130788286915, 0.026463331159902737, 0.07526196772232652, 0.029558324458776042, 0.03056440025829943, 0.04997852520318702, 0.050811511755455285, 0.05895524664083496, 0.02705450930079678, 0.021315158483048435, 0.0061868306147516705, 0.01751200972648803, 0.0320514508348424, 0.03070344348088838, 0.0635240858537145, 0.014956584691390162, 0.11214497062610462, 0.015266771806636825, 0.022558283671969548, 0.010710866372392047, 0.02131002096575685, 0.02560683151386911, 0.0282821403015987, 0.03598558309022337, 0.014251533266360639, 0.049808024195954204, 0.04201531031867489, 0.03672656188427936, 0.054294644578476436, 0.021763571530755144, 0.031694492645328864, 0.03216531484213192, 0.012103500921512023, 0.019477914393064566, 0.04246522250468843, 0.023055878846207634, 0.02847256797394948, 0.05609332481981255, 0.010592507733235834, 0.022123995549918618, 0.027586209871515166, 0.052087901858612895, 0.11076157024945132, 0.04137833238928579, 0.034977612958755344, 0.05406964024587069, 0.030789794218435418, 0.02191657455114182, 0.029944933303340804, 0.03074480151553871, 0.04915362434985582, 0.03787848268984817, 0.07646175334230065, 0.051311325951246545, 0.017249332122446503, 0.02545897899835836, 0.03407337280805223, 0.023256284694070928, 0.03306982216599863, 0.036600986786652356, 0.05354772489226889, 0.019325610846863128, 0.027193118366994895, 0.02231416347058257, 0.012380434254737338, 0.07601063145557418, 0.04405389350722544, 0.027873346807609778, 0.03338283779157791, 0.06706751446472481, 0.06456367147620767, 0.04766402635141276, 0.04925181419821456, 0.08203234348911792, 0.07061797121423297, 0.009106615834753029, 0.04488752572797239, 0.05341327741916757, 0.041179225299856625, 0.060858658762299456, 0.015623566723661497, 0.0144649600952107, 0.012484793205658207, 0.03588812796806451, 0.011923463316634297, 0.04092276874871459, 0.04393226292449981, 0.023140203520597424, 0.02658230299857678, 0.027472126930661034, 0.01720770691463258, 0.04040234511194285, 0.08332975121447816, 0.016031642189773265, 0.014545984067808604, 0.024799883212835994, 0.009788441748241894, 0.05489696792210452, 0.0028255575125513133, 0.03790147813560907, 0.016938490989559796, 0.0148916634680063, 0.02852100795280421, 0.049832307267934084, 0.04262168578861747, 0.04454018206160981, 0.1015735519467853, 0.03360820577654522, 0.00873433229571674, 0.05932536681939382, 0.036618646190618165, 0.02051148305326933, 0.01715581409371225, 0.05477289938426111, 0.024542909013689496, 0.012215044789627427, 0.0780629889050033, 0.012164100062364014, 0.03219084472220857, 0.02535699120926438, 0.04868299140071031, 0.05568937755015213, 0.012503105699579464, 0.04635762750694994, 0.00866544893142418, 0.032193698280025274, 0.027000887275789864, 0.06687672314001247, 0.0852548006514553, 0.0630791015282739, 0.01791851555026369, 0.03534360308549367, 0.03451606389717199, 0.022832317990832962, 0.012467838841985213, 0.052822130819549784, 0.10079803731059656, 0.011323108519718517, 0.05496802114066668, 0.04366988032415975, 0.07139346358599141, 0.021411993911897298, 0.07202779946965165, 0.034465245335013606, 0.07904670565039851, 0.050394276331644505, 0.03070521906920476, 0.03580072894692421, 0.021417016396299005, 0.05029061314417049, 0.024356529756914824, 0.10158590870560147, 0.04361118386441376, 0.12493903253925964, 0.04278372631233651, 0.016697708597348537, 0.0209923502188758, 0.04160935553954914, 0.06002539761539083, 0.07058784001856111, 0.02670788180694217, 0.04109911045816261, 0.021287676754582208, 0.08008642485947348, 0.04618610975740012, 0.0683720171218738, 0.03805594504228793, 0.027543861069716513, 0.03047840389626799, 0.02275072256452404, 0.08066337046329863, 0.013207973443059018, 0.02357692032092018, 0.05120617846841924, 0.043515376310097054, 0.009337795763713075, 0.027188804633624386, 0.04989155291696079, 0.03415306091483217, 0.025002233487612102, 0.013543210825446295, 0.0343285825510975, 0.04665436783398036, 0.0314278835139703, 0.02622771411552094, 0.010088876115332823, 0.014253698482207255, 0.03452619421295822, 0.04525337484665215, 0.012031620208290406, 0.06898027393617667, 0.027498684685269836, 0.021555823987000622, 0.06950484617846087, 0.010469519947946537, 0.024014726222958416, 0.008656367826915812, 0.029694156037294306, 0.06136652154964395, 0.0279512018096284, 0.013463529212458525, 0.009553812687954633, 0.019959468045271933, 0.040802692965371534, 0.016997371130855754, 0.04942157305777073, 0.06839325738837942, 0.015829382828087546, 0.024335105808859225, 0.10085156100103632, 0.024528114299755543, 0.02797856850520475, 0.1249504170846194, 0.02918055088230176, 0.036637752782553434, 0.04821874092158396, 0.06860168214188889, 0.04217464942485094, 0.05664541960868519, 0.03656497778138146, 0.015173555275396211, 0.022501231069327332, 0.05866897430678364, 0.06708854692988098, 0.052910175509168766, 0.009172192003461532, 0.07213441640487872, 0.03554543756763451, 0.0458513454941567, 0.04063719403347932, 0.025224339733540546, 0.03353603191499133, 0.026739539971458726, 0.023947836452862248, 0.03688880649860948, 0.028232600088813342, 0.059343067041481845, 0.014531386950693559, 0.03171138763718773, 0.040887776485760696, 0.032245559559669346, 0.03711412624397781, 0.027192621128051542, 0.033632726335781626, 0.008620321714261081, 0.05744153997511603, 0.031173779570963234, 0.030964291690906975, 0.11776098763220944, 0.07912563305580989, 0.026152202444791328, 0.011510654803714715, 0.02523501552786911, 0.033121653759735636, 0.02878837778553134, 0.07352679676841944, 0.031080192893568892, 0.05748942705395166, 0.028474590326368343, 0.07032266323221847, 0.05298058305925224, 0.049878383506438695, 0.015085770337464055, 0.07071515545248985, 0.03841746744001284, 0.0554580612515565, 0.018297714050277136, 0.02739795298111858, 0.05573614398599602, 0.018300317133252975, 0.02711907058255747, 0.049126539670396596, 0.04814071893633809, 0.04015567748865578, 0.011223655164940283, 0.057594908503233455, 0.04596681254042778, 0.020832808877457865, 0.004160339331065188, 0.05594814589130692, 0.05248508445220068, 0.05732681878725998, 0.030693867920490447, 0.03843870399578009, 0.014923291018931195, 0.016132000964717008, 0.015135598132474115, 0.007936366764624836, 0.11275998098426498, 0.04950541719153989, 0.08333326899446547, 0.03207371897588018, 0.048110175848705694, 0.03423531314183492, 0.008714669093023986, 0.0848905545717571, 0.04761630254506599, 0.04251259750162717, 0.05243486702966038, 0.009922666577040218, 0.15140431554755196, 0.0963659981789533, 0.1814612073940225, 0.1792087298235856, 0.1902668341062963, 0.16193853778531775, 0.15588972251862288, 0.09232292606611736, 0.16288321756292135, 0.20639576629037037, 0.08229285216657445, 0.11021011741831899, 0.2781632129335776, 0.16207936772843823, 0.10990194801706821, 0.11596807758905925, 0.17481307819252834, 0.10440637415740639, 0.1461342061520554, 0.0851694165612571, 0.17823210800997913, 0.12268841033801436, 0.15618079283740371, 0.1338917380780913, 0.15180933522060513, 0.13283837819471955, 0.09389336992171593, 0.17288235132582486, 0.18095169332809746, 0.19500170659739524, 0.1324857838335447, 0.07956677305628546, 0.11532890290254727, 0.122850718034897, 0.11028212058590725, 0.15286070614820346, 0.1311549943056889, 0.1692141083185561, 0.13245204580016434, 0.23240494017954916, 0.13478241919074208, 0.18102426052791998, 0.24064886500127614, 0.12012063874863088, 0.16755352320615202, 0.13757602631812915, 0.19979988428531215, 0.12257649446837604, 0.06253461746382527, 0.0901076004083734, 0.29218419338576496, 0.10134755313629285, 0.123172958556097, 0.13289678521687165, 0.2720490738283843, 0.13494509796146303, 0.16865727491676807, 0.10671831259969622, 0.21696991607313976, 0.10085972462547943, 0.15388960484415293, 0.10525927253183909, 0.07001639372901991, 0.11239924526307732, 0.09404438213096, 0.1245240235584788, 0.1562751198071055, 0.1025875483173877, 0.16105547110782936, 0.12600662681506947, 0.15243362984620035, 0.06532800194690935, 0.1171636107028462, 0.09611196102923714, 0.16512192087247968, 0.05862455676833633, 0.161508017918095, 0.13877060206141323, 0.14552528882632032, 0.1357566809747368, 0.15477727283723652, 0.10877259963308461, 0.18227369582746178, 0.1910802279599011, 0.12479220604291186, 0.1879585173446685, 0.09478687119553797, 0.14755757118109614, 0.2820149890612811, 0.07702486531343311, 0.06685736792860553, 0.11155767206219025, 0.1348561589838937, 0.1285360738984309, 0.2280024014180526, 0.20943738432833925, 0.08761671531829052, 0.12352555291727185, 0.27026046824175864, 0.13972800225019455, 0.15645532810594887, 0.10274591521010734, 0.13862352323485538, 0.1606106129474938, 0.15615303651429713, 0.16844292782479897, 0.12070266806404106, 0.1463500375393778, 0.07124237716197968, 0.1374082118854858, 0.1154057819803711, 0.09313721049693413, 0.20226748078130186, 0.09763072172063403, 0.09814479257329367, 0.13445679447613657, 0.09568651003064588, 0.12680094747338444, 0.13733070198213682, 0.08898326152120717, 0.07160222972743213, 0.36938310717232525, 0.1526874740375206, 0.0869419843365904, 0.19735541311092675, 0.18211110611446202, 0.15743574971565977, 0.06598615334951319, 0.12348187010502443, 0.13482801674399525, 0.15532848075963557, 0.2654635818907991, 0.11887244283570908, 0.16146237583598122, 0.11776312501751818, 0.11019019075320102, 0.09284562067477964, 0.14765773143153638, 0.1254277367843315, 0.2048502882826142, 0.1687581476289779, 0.1616314667626284, 0.10570805665338412, 0.11777953390264884, 0.13674765592440963, 0.10837393274414353, 0.14967033202992752, 0.10957283520838246, 0.09363147342810407, 0.1418756737257354, 0.086148376140045, 0.0771432304463815, 0.11809162926510908, 0.11139427340822294, 0.14678189327241853, 0.20905808749375865, 0.12691911222646013, 0.24335457215784118, 0.19544387818314135, 0.13446513621602207, 0.11671940563246608, 0.10290682766935788, 0.10343738904339261, 0.17744651500834152, 0.16892162791918963, 0.1215801908983849, 0.1415423009893857, 0.09744932598550804, 0.2534268965246156, 0.0938932660210412, 0.12780160002876073, 0.18416022037854418, 0.1719932584092021, 0.1184909492440056, 0.13376855640672147, 0.08381668172660284], [0.03224579333618749, 0.0654005839896854, 0.029409004346234724, 0.018016338035522494, 0.07181507025961764, 0.04744451762235258, 0.04530654972768389, 0.072431542648701, 0.04285767019609921, 0.033608925659791566, 0.007385273411273374, 0.022008727028151043, 0.01740768046147423, 0.059408190500107594, 0.07323927391553298, 0.07232302581542172, 0.07826236687833443, 0.018315364177396987, 0.05179343992494978, 0.081325477513019, 0.03325333302200306, 0.023212319865706377, 0.061889501885161735, 0.04542287395452149, 0.02383400955295656, 0.038808037497801706, 0.04869217176747043, 0.02386603879131144, 0.007575787358291564, 0.08335353704751469, 0.005452295054055867, 0.015985024183464702, 0.03430031043535564, 0.0517442800628487, 0.06913372038980015, 0.021115457675477955, 0.045106496399967, 0.024111294478643686, 0.04900526902929414, 0.024851939306245185, 0.06533691514050588, 0.022040509502403438, 0.04284119822841603, 0.0520510727801593, 0.038105995481600985, 0.012354093578323955, 0.04297084400604945, 0.017082122540159617, 0.09910271226544864, 0.04263893701136112, 0.033706744434311986, 0.033034024672815576, 0.05314931033353787, 0.058978631714126095, 0.041589952088543214, 0.039208459565998055, 0.08814608925604261, 0.06931081908987835, 0.03583274890843313, 0.028473671918618493, 0.056867562961997464, 0.04360340244602412, 0.04821783550141845, 0.038879840285517275, 0.04326479756855406, 0.029882847084081732, 0.08070221447269432, 0.08058357474510558, 0.03306789258203935, 0.07176381011959165, 0.09550346672767773, 0.05075976179796271, 0.02138015021046158, 0.06363379754475318, 0.04650569710065611, 0.03313726854685228, 0.11333231785101816, 0.04427873827808071, 0.010416506484034471, 0.042036773229483515, 0.022094393134466372, 0.011694308523146901, 0.03691499317937996, 0.029052038735244423, 0.038237578264670447, 0.029137777200958226, 0.035396729726926424, 0.04474308152566664, 0.04379292469820939, 0.02815810701576993, 0.06283679031184874, 0.03659026275272481, 0.021645323286065832, 0.012465091040212428, 0.02559467884566402, 0.05445016904559452, 0.03815387884969823, 0.023640635554329492, 0.02040940620645415, 0.06798698348575272, 0.0736748032795731, 0.06017178253387101, 0.06319539606920443, 0.035580158946686424, 0.07517005273257382, 0.04005399583547842, 0.0625298528757412, 0.04249414399964735, 0.08680970393470488, 0.03973174418206327, 0.028618989999813493, 0.03783003528951667, 0.006324867299554171, 0.11729426580131985, 0.0408560608047992, 0.02473748714692192, 0.05233087358647026, 0.06440594283048995, 0.021778846785309725, 0.02882979704736499, 0.04593505604134407, 0.03304738333099522, 0.026933375957014505, 0.02224531814135844, 0.058838718323386274, 0.04484479286475107, 0.09353379195090383, 0.015431754018209176, 0.0682602274173405, 0.07493454701034352, 0.02189901719248155, 0.12133192765759304, 0.05506903486093506, 0.06151651330583263, 0.0672625211882405, 0.025921973392541986, 0.05362929805414751, 0.04869583426625468, 0.027419042962719686, 0.07173583115218207, 0.05026541723054834, 0.07040608063107356, 0.10551169922109693, 0.00859554511407623, 0.011079848281951854, 0.02184310749726137, 0.03567129468137864, 0.04228730373142753, 0.045657303562620655, 0.040399298595730215, 0.022963158626225777, 0.02849192689609481, 0.06293656464549713, 0.027715360265574418, 0.040135780509444885, 0.05247372217127122, 0.013138369267835515, 0.026458028514753096, 0.024483934248564765, 0.027742717684304807, 0.0316862510953797, 0.01531993370008422, 0.0144790358535829, 0.015932661954138894, 0.03159850326483138, 0.03534843446686864, 0.06635908997850493, 0.04151095046836417, 0.0684300456487108, 0.05446905670396518, 0.06956879704375751, 0.035971356119262055, 0.0463540280907182, 0.003920778699466609, 0.049283986299997196, 0.04001761946710758, 0.050279655333724804, 0.03772159638174344, 0.05582668229180854, 0.011705648539646063, 0.005917371636314783, 0.021410841727629304, 0.04268732875061687, 0.07244372129207477, 0.021692182490369305, 0.04926169589452911, 0.03923902862879913, 0.09016466414323077, 0.04307155715650879, 0.07622905293828808, 0.06557078071637079, 0.03651580678706523, 0.06654035212704912, 0.041408441320527345, 0.03938180670957081, 0.02358471287152497, 0.09239521867129952, 0.025423810475331265, 0.013043123890383868, 0.07744553688098677, 0.03037715083337389, 0.019862202170770615, 0.09690915379906073, 0.03205853463441599, 0.030184018032741733, 0.01252742958968156, 0.017974497604882345, 0.0498991636413848, 0.05932927051617298, 0.06699939272948541, 0.030311032896861434, 0.04736833616334479, 0.06592740493942983, 0.03552920308720786, 0.03043240929400781, 0.033839470124803483, 0.030134791377349757, 0.03276071023719851, 0.06011806588503532, 0.04853059879678767, 0.015848055263631977, 0.034755191300064325, 0.01671929952863138, 0.05494056909810752, 0.04978101373126265, 0.035841784556396306, 0.012634391623578267, 0.05490366580488626, 0.0683543317427393, 0.05996007748763077, 0.019922210376535077, 0.05558997429034207, 0.038711135275661945, 0.03228305657103192, 0.02537917400331935, 0.032283910040860064, 0.06488479135441594, 0.07487778013455682, 0.06609661460970528, 0.029530798201449215, 0.037844748367206194, 0.022333618871925864, 0.1192772547074128, 0.03854857895930763, 0.0242343666832312, 0.02226629680080805, 0.044774188645533286, 0.030252429205575027, 0.021185657424211968, 0.11878057979629375, 0.02260271976410877, 0.039709398115519434, 0.09941557204001583, 0.030272691692516673, 0.04083091684151441, 0.018475606848369353, 0.05971077524009161, 0.020883772158413194, 0.026034076654468663, 0.05313705747539643, 0.06612891287659295, 0.09559478799928911, 0.04030124604469165, 0.034527444731793366, 0.010890234188991599, 0.07037343355477788, 0.03890627187502105, 0.026517353944655042, 0.04339028731919825, 0.034954294678755105, 0.021206146266194992, 0.019070260095759295, 0.07760271633742377, 0.018065418116748333, 0.025703952669573482, 0.0326996277726721, 0.04889919757260941, 0.061829803526052274, 0.009810642168304184, 0.019343672865943518, 0.11723805553629063, 0.021308351133484393, 0.04939720092806965, 0.12089753377949819, 0.08365283036255278, 0.02414550934190629, 0.02267478601424955, 0.06797876048949547, 0.02861888424376957, 0.028814135876018554, 0.07131201287847944, 0.043977255627396517, 0.03401989735721145, 0.08655805650050752, 0.032403844816144556, 0.06527125733555295, 0.05883086269022897, 0.05687486940587405, 0.006694262028759113, 0.03952267376007512, 0.01545774031910696, 0.034079361939802766, 0.02661676648131106, 0.050943528694915585, 0.03510707691020798, 0.056849384054658, 0.058874282040051185, 0.07722475536866114, 0.021590497126453556, 0.05745007838413585, 0.060888552470714785, 0.03622167510911822, 0.05836578471644316, 0.08394983786274679, 0.051601513114292175, 0.04565171147987712, 0.03625082295911852, 0.027922170847887173, 0.039442228662665, 0.025009354394569527, 0.023357101745205, 0.034073621427523904, 0.03270262976002414, 0.05424872048024554, 0.1083578281395603, 0.036546668998198584, 0.016504521991009824, 0.010895827199419728, 0.04350733514002059, 0.03750310068426188, 0.007893753572716378, 0.0536992157867644, 0.00970085997323622, 0.047041383004398085, 0.047431533748749644, 0.010091660096804844, 0.016076905776571948, 0.024378899943258148, 0.041233435476897284, 0.025023132366186474, 0.053122978933970444, 0.025741559147718363, 0.06723943297402002, 0.023568838332721498, 0.13450429192744195, 0.021362301558838226, 0.038015909885871224, 0.022177849496074487, 0.009138548593909945, 0.024517432939319406, 0.011781390276155435, 0.03967835036746692, 0.12463007646147162, 0.13873938733013347, 0.1335019027465023, 0.1307772856671363, 0.16534333321033046, 0.09271132163121365, 0.13367160223424435, 0.18703742302022874, 0.15379055781522766, 0.14011046063387766, 0.14742141676833853, 0.272466724854894, 0.15382759098429233, 0.11993796651950106, 0.1567423908272758, 0.14900648093316704, 0.19627296103863046, 0.11829377544927411, 0.18944733979878947, 0.1810200748150237, 0.20587124599842355, 0.07887566287536174, 0.3195454861270264, 0.24970398691948503, 0.08950195595389232, 0.13411809311946854, 0.14057090389542282, 0.10577944383840077, 0.07451581986970268, 0.12738124758470803, 0.08865532130585052, 0.11899958015419543, 0.14893404731992632, 0.17608596535865217, 0.13634394243126735, 0.12389287148835137, 0.11554319804417901, 0.14945126487873495, 0.14937379950424656, 0.20953846484189853, 0.22509058500872925, 0.0806346493482124, 0.17083547834772617, 0.113629585102899, 0.10933871730230749, 0.1026446046307683, 0.09816542427870445, 0.16731925687054172, 0.20725471316836774, 0.16808092303108424, 0.19514657382387668, 0.11628254040260799, 0.11241357613471337, 0.22363866213709116, 0.11590233814786188, 0.1999338122550398, 0.22705274925101548, 0.14120790408924222, 0.15991658612620085, 0.13408880797214806, 0.10313989172573201, 0.1471968725672923, 0.167720491590444, 0.08594179191277362, 0.1340822028578259, 0.09115071865380742, 0.17716089205350727, 0.28335094393696636, 0.092373466322897, 0.1865132589591667, 0.09037773474119604, 0.1454165790346451, 0.1558709907112643, 0.16732899384805933, 0.12736998178297654, 0.10301469883415848, 0.21438083000248298, 0.11926152117666788, 0.12155213029473089, 0.11078288473072462, 0.1234393376216758, 0.14570675877621397, 0.10142364553757943, 0.09309873756137677, 0.1488804048858583, 0.26633625850081444, 0.19478550413623452, 0.13216887193266302, 0.20029267034260556, 0.17176933761220425, 0.15438218310009688, 0.09848535672063008, 0.11743367082090117, 0.11444476753240451, 0.12818290066206828, 0.10503488418180496, 0.1525055439560674, 0.07423148083034903, 0.0874189923342783, 0.2153948857448995, 0.15609050315106288, 0.1091285039728973, 0.09001297657960095, 0.12600705726072192, 0.19973766262410209, 0.11308631816064008, 0.14129715476883575, 0.24434970313450322, 0.21569073549471796, 0.13737074827076867, 0.07670121471164748, 0.13751050952123478, 0.1381002794369124, 0.24267230095574632, 0.25093372561968863, 0.1017210834834259, 0.11571644499781542, 0.2204737882129848, 0.08569456767872907, 0.15952722576912493, 0.18926956574432552, 0.15190956968581304, 0.10233457243884914, 0.11431276172515936, 0.14627429394749925, 0.1609269014443271, 0.1616852724691853, 0.09787483635591343, 0.07503451430238783, 0.1651872743968852, 0.15597714751493186, 0.14194067101925611, 0.17587921785889193, 0.19487938581733033, 0.22262263228185475, 0.155702063057106, 0.15229426935547963, 0.11020005389582366, 0.11588417779421434, 0.22785714827477932, 0.2979099814547226, 0.23944070795550942, 0.22042661730665714, 0.08458135358523577, 0.13578676764154807, 0.07037614239379764, 0.10065919632324949, 0.13398113718722016, 0.1481181153212674, 0.1742207701317966, 0.06731596324243583, 0.14778306533116847, 0.15853945689741522, 0.1040326508518774, 0.11507304749102332, 0.14084692345932126, 0.10811691216076724, 0.11811586038675159, 0.11723844145308249, 0.14892429549945518, 0.0834474187286105, 0.11157160959555767, 0.11030687863240018, 0.09697634042822756, 0.12602445320226252, 0.09917477480485104, 0.23612890363438055, 0.12620452791452408, 0.23214129963889718, 0.14232813147827983, 0.25118350284174085, 0.1453656528610736, 0.21825516741955653, 0.07372256048256531, 0.11819935942185111, 0.13577897509094328], [0.04673040828492958, 0.020899618866678793, 0.07246592635056004, 0.09417448804015294, 0.015607213499606587, 0.03140204193186946, 0.07034269379801117, 0.022478064929600805, 0.0327289092092542, 0.0419562613387825, 0.04033751851238776, 0.012552245152619435, 0.014421727209992241, 0.07698936096858233, 0.024194787947635632, 0.025421905011171475, 0.0126014300622046, 0.017874430122901686, 0.02514403749955818, 0.04409819230204448, 0.02683710084966151, 0.07054717032588087, 0.06292620426393114, 0.04763690085383132, 0.030298557394417003, 0.03246503860282246, 0.025081049570871983, 0.013455796961352462, 0.03908036116627045, 0.018820330733433366, 0.02690175304451259, 0.06510820749099366, 0.035192141876905225, 0.045619019874720834, 0.0442512751033064, 0.053795056737726554, 0.05621470307232812, 0.033554689507582225, 0.011310900190437678, 0.015712752465333324, 0.05990470584947616, 0.033334379259031266, 0.01678398512012791, 0.03049361977900844, 0.024408634089922998, 0.059451535635162145, 0.03321818119729869, 0.010057494400825817, 0.051357780685066245, 0.07352189859375358, 0.01871655993454624, 0.040628217757330276, 0.02063742736936547, 0.04368160625745077, 0.01945992473338265, 0.05433702492155135, 0.017907489091157913, 0.033277078036917374, 0.027166321269760374, 0.07288478707778268, 0.06222016207175329, 0.046101334228296764, 0.0066783290458261035, 0.05381605580623727, 0.04244838317390531, 0.03808660687354859, 0.035980432585347444, 0.023675570300838444, 0.01888090482680127, 0.04861741152126342, 0.04021072258183267, 0.01776523051375989, 0.007616361035616137, 0.029296168213477358, 0.033247714964090846, 0.017988017680181656, 0.06643800996243954, 0.011287551296845777, 0.04763799181091599, 0.0312588185624918, 0.030488973934552632, 0.08598203115980141, 0.020739580286317505, 0.015794013925187755, 0.07879496173700318, 0.11639378833933733, 0.017683187943475787, 0.03386038755706977, 0.03708322692546062, 0.01353959563857643, 0.02245542942546308, 0.08018529377295636, 0.04608241688401904, 0.06704494575387798, 0.03258241296862252, 0.017675831404631026, 0.05167800627532415, 0.073636449087644, 0.04592097749991808, 0.05315335874911398, 0.034655491181183606, 0.0013600496276922058, 0.03839039389276877, 0.02402195103059057, 0.03961354974308051, 0.03218992074835114, 0.07536459932452999, 0.034447674988768995, 0.017393581510987133, 0.06543843352119438, 0.07227142428746447, 0.049650221335468814, 0.027442116333986633, 0.03311644759378396, 0.03462119653704576, 0.03325180419778917, 0.017545165173942223, 0.03375303218490444, 0.051720817064051516, 0.02333952026674524, 0.035035897526540793, 0.021963220387988258, 0.021429293374239933, 0.09671554231317714, 0.060903298945049755, 0.04326989612309262, 0.04170525215158705, 0.08490499676554464, 0.022362846502801403, 0.060923244163859636, 0.08094874850939959, 0.033826938961283304, 0.027275363172520883, 0.02803169143589912, 0.043070544124930166, 0.03744488662050571, 0.0065008226283680415, 0.00982942221526173, 0.04220609422191046, 0.018890562023443636, 0.04784314369317144, 0.03144302703731228, 0.0137650601027417, 0.06577484164154157, 0.018498021563573275, 0.14941904082661495, 0.04771420295583084, 0.07012533358647488, 0.0064250683681166265, 0.012960176827618852, 0.06699919977108948, 0.049425435936427675, 0.05444058420835063, 0.08618293053586967, 0.027102138483314775, 0.09691863102489151, 0.05154905069503002, 0.048663606503396295, 0.0351677140861284, 0.05124269213411026, 0.04130509725655429, 0.07447149138897657, 0.07200581705546938, 0.054012825130485, 0.04914911951345857, 0.07833239593310282, 0.055630284041399136, 0.04384750223834999, 0.1162684173323214, 0.062307023035828024, 0.013181395279389108, 0.07431280537275597, 0.07848610955988988, 0.017539994260005187, 0.030396760230360087, 0.04417507880134508, 0.013140288647264242, 0.04630262323189527, 0.02806140146276448, 0.09560144506394863, 0.023408738525176886, 0.019551208897610195, 0.030207742638594937, 0.04470994092116598, 0.030828432281850837, 0.027976753954135347, 0.010639085849106777, 0.03679123634356074, 0.02127854277205188, 0.05833581308252178, 0.013523425168386893, 0.04974224022589624, 0.05194119039515499, 0.03154407415422611, 0.0346859897399554, 0.05878344687516801, 0.015179588936007349, 0.08362919295905158, 0.06719750905176625, 0.027117766258015763, 0.030333954127854668, 0.034339447593083605, 0.062046811217442155, 0.0060653057880699635, 0.036179172311676666, 0.05259308549284469, 0.03521740829455666, 0.04263944909325801, 0.046900059533072636, 0.02538605927838944, 0.03282787831267342, 0.014598279503843514, 0.037756707388325594, 0.02609164504974615, 0.018501656231819652, 0.037934214269625954, 0.09837534074904397, 0.034155053581343964, 0.03224626088922378, 0.08234997527324595, 0.032353946517105214, 0.01983286321774358, 0.04181181713647675, 0.018437979961163364, 0.045383068863884546, 0.019275506601843517, 0.03561726633051876, 0.04541750080534257, 0.034545219168649055, 0.12324166658800095, 0.019677112395584118, 0.038867754410603084, 0.03539216922945343, 0.06261643924517557, 0.09258534206310287, 0.0480640291061718, 0.04097578777873423, 0.033176758224726655, 0.013751478800259065, 0.015472631512238877, 0.03256477582908701, 0.04171521919488441, 0.0018597772009343316, 0.05707528267521411, 0.04354490265541244, 0.02090195477649104, 0.034119341435143724, 0.049920763849513605, 0.08538810521713458, 0.01852513407357037, 0.07012627611402422, 0.016746259898354765, 0.05736870560212992, 0.1022840321820695, 0.014041342201380758, 0.03750530115212314, 0.03145117952954024, 0.03877497110806871, 0.016261132805084344, 0.026990755104634445, 0.04756941365485545, 0.04327405957155861, 0.06330878139124252, 0.05531634815270081, 0.11877272045239806, 0.07570617279270664, 0.008711859136383282, 0.008378456714126514, 0.05722267320379615, 0.04239709334797226, 0.020847431042056996, 0.04486206635192502, 0.032861278668860905, 0.06027257732057478, 0.026908155923592858, 0.04744802427012473, 0.015825109912839253, 0.062065988313406706, 0.020836048352066427, 0.020122905661992263, 0.023022176064841915, 0.04235404507198837, 0.05219828519329894, 0.03001220156875206, 0.02366965723922476, 0.021354150921979453, 0.07236172139528207, 0.04948646645061672, 0.024572941874794196, 0.022751707765564788, 0.035033834355999716, 0.023592924735567067, 0.026250904375046957, 0.021445778329507448, 0.04395468320581131, 0.03468380782578606, 0.05111492770083714, 0.02890806023060577, 0.03950723708840087, 0.039111189980758354, 0.05908488870772999, 0.038537127620656975, 0.007166389477788471, 0.04151214532612357, 0.02110984147293493, 0.009388028029206907, 0.08534345019143075, 0.008161355326592457, 0.06350202922476456, 0.07155620915000327, 0.023786610436218325, 0.04290075186872855, 0.03707568299432751, 0.058025272519444115, 0.06559740155353211, 0.042579646833473817, 0.0218413745824364, 0.02046441048150882, 0.015434663237101631, 0.013713371372432448, 0.0187604338498204, 0.04648577043553814, 0.025335758364235517, 0.035387916723266244, 0.0535776891047135, 0.014530587286571972, 0.02951948972622631, 0.017478436820965726, 0.06681710641714744, 0.04231241429806687, 0.028425226373656187, 0.020001918892376125, 0.06752558285370469, 0.01030540883220965, 0.01739484130666824, 0.05030411652114708, 0.04778522648848593, 0.11753747501643375, 0.0132103677970008, 0.015958826370479073, 0.02958682849566685, 0.02851310036930954, 0.055329858951154165, 0.0401557405712083, 0.045069081024848856, 0.02644035983394133, 0.020530997826426756, 0.01210049800647539, 0.07529423630330712, 0.029753956441709306, 0.02682846039533615, 0.036932611765223555, 0.12636447558179498, 0.18723617016803473, 0.20160190790193155, 0.19059964281041175, 0.20621241128537804, 0.14025065232999623, 0.15842568565858528, 0.11339044285705313, 0.11768715135985985, 0.11988742626272142, 0.12579239846672863, 0.10696760000428185, 0.14163588581141084, 0.1285330904647708, 0.1708008348941803, 0.07571030655526556, 0.12866231321822852, 0.156820212432649, 0.13456350046908483, 0.12963273067725822, 0.16150408453540877, 0.2286467340309173, 0.14377303363289684, 0.10069556898088194, 0.10024339324445464, 0.09001034937682562, 0.12474506482249126, 0.11975228859228082, 0.16286488651530817, 0.11981232091784477, 0.09360145355458371, 0.09853433846728876, 0.12369752337690443, 0.12365635644528084, 0.2181123782065697, 0.12301525959628634, 0.1502397225704044, 0.09250919029000215, 0.11532910328241996, 0.10401840903796256, 0.13610764261102304, 0.18115554645191878, 0.10485470556886867, 0.12448254492483102, 0.10913582897046581, 0.1527153787901625, 0.18549498781794682, 0.17317118035862222, 0.19142845849273726, 0.2304895015549846, 0.12815067660994828, 0.10692641822970472, 0.1257461923523806, 0.22294950380455703, 0.08039516571443528, 0.14549931365763769, 0.09243940614396706, 0.07727689866442233, 0.17361578618874773, 0.17861070722574368, 0.13416605070233345, 0.08912362391129136, 0.10291373706422746, 0.1824467646656558, 0.12960114487214014, 0.1632492002681829, 0.18540600431151688, 0.10967667651129887, 0.08189729487639852, 0.09054552690940909, 0.13660431752214208, 0.13058867625659332, 0.2258564517251216, 0.15373670757981017, 0.11567932277102955, 0.101019746507518, 0.15059858065797016, 0.19937530159950256, 0.1615804960601963, 0.15111832151887938, 0.10919803578872234, 0.18594973138533533, 0.13038201781455427, 0.0908709512441419, 0.22278286196524277, 0.2043091438827105, 0.20114496757742018, 0.16514154325705022, 0.2902454958530143, 0.16705937159713358, 0.16565948812058195, 0.12209474414703436, 0.17324009619187564, 0.21844560251338407, 0.09172473277430981, 0.17265345813939348, 0.1072595089499373, 0.20927207835484296, 0.11040793688152917, 0.1426789298420772, 0.18404682021355256, 0.11805278525571339, 0.093318324215943, 0.07350288477027789, 0.10301852831616998, 0.1466860671644099, 0.14988702430855483, 0.1276019326178357, 0.10939837855403312, 0.12333499907981604, 0.21142813609912992, 0.13367096398724243, 0.15908348083030432, 0.10355709004215896, 0.09428255216334946, 0.12345440321951173, 0.07565745079773478, 0.14037603075848892, 0.17042055842466652, 0.09279552570660599, 0.20303633093135431, 0.11276884964900091, 0.11859148798976094, 0.24138678243616596, 0.15994710323866457, 0.08168438012944534, 0.13168585253879428, 0.21731356013333425, 0.09376658883411437, 0.12112066789995879, 0.2227780528482981, 0.09541347390040755, 0.18972940044477582, 0.20526317472103983, 0.18545894912676886, 0.11764495284296572, 0.10486666898941621, 0.1810752460733056, 0.14885745767969638, 0.06647273505222984, 0.13754249608609825, 0.1025120347912889, 0.09271855014958419, 0.13223953923443332, 0.10223087956546806, 0.2577845798805356, 0.17485915072029456, 0.20476121571846306, 0.1536678956472315, 0.09533243137411773, 0.13349051820114255, 0.11302637489279732, 0.13656961469678208, 0.27426696731708944, 0.20712931989692152, 0.1515255231061019, 0.14633900922490284, 0.14827239298028871, 0.12715513003058732, 0.14095710270339623, 0.09828921451116912, 0.19146270118653774, 0.12985240638954565, 0.18791287526255473, 0.21009390300605446, 0.11944532889174297, 0.1744219960528426, 0.2002364007057622, 0.14917588356183842, 0.12248898041434586, 0.10884324467042461, 0.14849454746581614, 0.18366090342169628, 0.13531488046282902, 0.09808886432438157, 0.1403397842659615], [0.061103010884835385, 0.029711865536228288, 0.04213885935314465, 0.0537152832839638, 0.08470720698824152, 0.036201607435941696, 0.028174352628411725, 0.01144631616625702, 0.007779842717354768, 0.03151128978061024, 0.056095681138685904, 0.019551954756025225, 0.0350931950379163, 0.049220365690416656, 0.028266273184271995, 0.06278791988734156, 0.03395308922335971, 0.02867476981919026, 0.04317632243328262, 0.08259703623480164, 0.012397508289723191, 0.02605711662909016, 0.06800314004067332, 0.02573007997852983, 0.055839484339230694, 0.04364495529443957, 0.029769812426820863, 0.03667450393550098, 0.05299185257172212, 0.05963780356978532, 0.029105734975019004, 0.03897500588209368, 0.034388024869258516, 0.0692742905812338, 0.056557374919066206, 0.02404092032520566, 0.027997496981697623, 0.042307497569709085, 0.024133878032444045, 0.10363884503021836, 0.023544254690932576, 0.03328427686938085, 0.024935575638664886, 0.02107370073645143, 0.013261209551274078, 0.045062973149470054, 0.030004219770489726, 0.045442396149155684, 0.015501767302339431, 0.08374415905564092, 0.0041158447947964305, 0.034658957010833547, 0.01352662382487324, 0.017138843031716533, 0.007436390687871608, 0.02776783010631334, 0.0112533967330819, 0.028406724632077385, 0.02167311671655625, 0.04570595876430161, 0.020434327525435947, 0.022662074879917782, 0.013384939484240022, 0.017939408862730488, 0.0387213917565532, 0.05452547477034386, 0.10493071633391082, 0.04973786526534241, 0.0389866872865241, 0.08042872563237324, 0.05170689808437601, 0.04814503081433941, 0.06557096625328995, 0.03645356286142487, 0.019075620257353876, 0.05399085013777949, 0.04895118130662013, 0.042320477732573636, 0.0252075078242342, 0.045158175853430294, 0.021055701799923554, 0.10381663392763585, 0.017630441652727313, 0.07603587189805694, 0.05286403618811164, 0.04743164136016276, 0.04552075581159443, 0.005415214109234512, 0.08811053296085447, 0.06288572010817006, 0.09887447959044948, 0.04916145400784444, 0.06794701141188852, 0.07237849393277429, 0.00365216345016961, 0.02916147954238113, 0.04203603108180687, 0.06417946904548444, 0.08255391745478846, 0.04322201646573376, 0.003400582809263142, 0.030342008285515476, 0.07287431537406519, 0.09890056608128361, 0.009495624599367147, 0.03658732384792529, 0.03783006497542374, 0.04294144753657747, 0.05800868180813268, 0.0782562441600021, 0.07743697991827503, 0.03548308231984265, 0.08839035232085735, 0.017802336042223033, 0.03863496494886931, 0.03557893440301996, 0.038268240095931105, 0.033695897946017794, 0.01839745498728007, 0.021511117010959424, 0.03682423965074122, 0.03996145002020057, 0.02465709956595674, 0.053769155783811584, 0.021554519662458915, 0.03490575822070241, 0.04151407862082124, 0.07018136573606171, 0.026663503231247887, 0.024472328914271202, 0.08533238476957195, 0.04681214100855868, 0.07333690344239585, 0.04298400970583316, 0.012567868288897444, 0.02114554063155083, 0.05982184877211694, 0.08964429987827316, 0.11781451874412596, 0.009592026799509767, 0.04717145180620719, 0.019787414094025735, 0.04941818515362684, 0.00763541382184485, 0.05393029088736512, 0.06027586503478233, 0.04858123924350366, 0.0351980567938881, 0.01981523906579241, 0.06590427961782552, 0.03563833961379714, 0.068322530714795, 0.039885802907519974, 0.020975523875677027, 0.08045340946409851, 0.08041570836212486, 0.02593376426375471, 0.009208324390783673, 0.0504824731615372, 0.05770875395683106, 0.02972563794173766, 0.025822635070653632, 0.013770397999905981, 0.10574275205726735, 0.03140122185868677, 0.06599733009352349, 0.014920016292307992, 0.033619768437347375, 0.03066318568016868, 0.026724416857177857, 0.03026069487532368, 0.017330812515865546, 0.0753185416397173, 0.05470670723298099, 0.03800802085606847, 0.019342394516570494, 0.03939352151064668, 0.03511564871587325, 0.04529034864390269, 0.047506702176178806, 0.047820356048760004, 0.03128361000563018, 0.027835658693220466, 0.025409075133211445, 0.005556196656471002, 0.013877984365535667, 0.06867896940093488, 0.05655882210703567, 0.07202421489637345, 0.054299234761856496, 0.03896961046848446, 0.00921734612347791, 0.04421727360750083, 0.026566098204057198, 0.02125471983163152, 0.02390131492575165, 0.04961380414897576, 0.03301301818282809, 0.06561613336089067, 0.031216341740218922, 0.008107577450573444, 0.04854237296967767, 0.07067796643241309, 0.011844025684695225, 0.0335376757720951, 0.05167776136659086, 0.034478704183129594, 0.025011462093971204, 0.03117174608632922, 0.07932889246148989, 0.02907149970269529, 0.0382022446137853, 0.016126603695738595, 0.03608736864407547, 0.046940625325078145, 0.07734547310974449, 0.027823767632071394, 0.023985131228982937, 0.030200822111510206, 0.01413016800142941, 0.06034643956809305, 0.014791195226280252, 0.0739794029504992, 0.046732753471587785, 0.028670964456978254, 0.02008090195886325, 0.020990992088627536, 0.07399360023555346, 0.028442310613172594, 0.05707804717530962, 0.06022820802172646, 0.05748815798142459, 0.017974564398173243, 0.027419469697633758, 0.07735679828329012, 0.043087847298011184, 0.03036228004930308, 0.0319609978760127, 0.036120999066042714, 0.03281361794506665, 0.031031355865707155, 0.0432856593397446, 0.04417450734763406, 0.07183403213275596, 0.033856569207273424, 0.06047599257726688, 0.0116444454761222, 0.040002720852498896, 0.020714725760626607, 0.07280619363882579, 0.06542425850057043, 0.024508597671228927, 0.05346904981706757, 0.022857679032313172, 0.06184556303196587, 0.06782302079955116, 0.034056707881973125, 0.09608968917746097, 0.009845217900874559, 0.05715704508475028, 0.04931477800710127, 0.06351685733534396, 0.008791396958258701, 0.02831748322932981, 0.04547994140011724, 0.020156094506091904, 0.04298730113077909, 0.04955965334374923, 0.033561057134647854, 0.019838653824990615, 0.06660098559223115, 0.02219597459770739, 0.030415994842769578, 0.009862461702141445, 0.06603577334317379, 0.03752482334675733, 0.03336207621032372, 0.10019302368164062, 0.024410502446698956, 0.04900376618024893, 0.061973331175977364, 0.014433082069444936, 0.030603123668697663, 0.030782215035287663, 0.06426615931559354, 0.08146810345351696, 0.023541145092167426, 0.07173563819378614, 0.01168466802482726, 0.04803704461664893, 0.028230512798472773, 0.0623650589841418, 0.018472339543222915, 0.0278155557680293, 0.05043567332904786, 0.032574442302575335, 0.054893090200494044, 0.057605613983469084, 0.019612040887295734, 0.0398122523620259, 0.05346281577658374, 0.05811340255604591, 0.008879957440512953, 0.052007857520948164, 0.035419131454546005, 0.0381178327370435, 0.10764308055513538, 0.05541520593396854, 0.0407129784434801, 0.017610591057746205, 0.0503051295527257, 0.042740603821584955, 0.05479074432514608, 0.039911982166813686, 0.019265298360551242, 0.018918620771728456, 0.07350085128564388, 0.03420963112148456, 0.06171675217046868, 0.053699349373346195, 0.01358987707135384, 0.038973057744442485, 0.04504998185439035, 0.041320834498037584, 0.03644454205641523, 0.030540963234670926, 0.0022263882965489756, 0.014339224508148618, 0.015222231813822873, 0.02665060841536615, 0.07853944771341048, 0.03526856453390792, 0.03819558383838739, 0.09916831069858745, 0.02806117325235391, 0.03866922990710009, 0.03163453824527096, 0.05316222370311152, 0.021873967853025533, 0.07072023916407488, 0.03658599540358409, 0.02091229474899592, 0.07886153980507515, 0.04769430968735833, 0.009847521341725951, 0.05588058447756339, 0.012984006261831382, 0.03425889488426037, 0.042048744071507826, 0.06563935516169295, 0.022346656551235355, 0.04148067826463375, 0.19974888389697298, 0.13196206506108865, 0.12686256057349965, 0.15954747155774385, 0.14202266349457204, 0.09143159186351113, 0.0931715867773164, 0.15406302991323173, 0.08546583034330979, 0.14202540944097564, 0.21582806250080466, 0.08813383639790118, 0.1633003490860574, 0.15028751688078046, 0.25386963214259595, 0.11425318210967816, 0.14488821441773325, 0.13624629063997418, 0.1280105739715509, 0.11228557050344534, 0.16000441188225523, 0.1413500402122736, 0.13996470283018425, 0.26380657393019646, 0.17511531041236594, 0.10333745143725537, 0.12692178395809606, 0.08316013336298056, 0.1436434843344614, 0.12518101721070707, 0.09689391008578241, 0.1792149935499765, 0.12462163082091138, 0.13911345944507048, 0.1713935734005645, 0.1116649569303263, 0.07348449435085058, 0.12836229259846732, 0.163485633675009, 0.21198222355451435, 0.18323856202187017, 0.15586141700623557, 0.10529022751143202, 0.16535041329916567, 0.08420450583798811, 0.09343320125481114, 0.14958286250475794, 0.17416225920896977, 0.18327911297092214, 0.11013308991095982, 0.0963589180901181, 0.11357937139109708, 0.09708325422252528, 0.16815258481074125, 0.138555972953327, 0.09715291220345534, 0.12370098920655437, 0.14895439700921997, 0.2094123442657292, 0.22703195427311584, 0.08505077683366835, 0.10089347750181332, 0.1515892439056188, 0.057155720351147465, 0.09270188893424347, 0.29605606687255204, 0.2318941050907597, 0.20348129299236462, 0.1864810794359073, 0.1956862339284271, 0.1533176316297613, 0.16668106924043968, 0.12318153778323904, 0.1410184783162549, 0.09151925434707664, 0.13934348069597036, 0.12349539203569293, 0.10026790638221428, 0.14298153313575312, 0.23294442216865718, 0.126175643526949, 0.22396796790417284, 0.09634680624003522, 0.11680132389301434, 0.1399738757754676, 0.12962588807567954, 0.08853769832057878, 0.13504767761332914, 0.18991413584444672, 0.16714982455596328, 0.23161694261943921, 0.12311530110309832, 0.18361371767241508, 0.12624279304873198, 0.0900456978706643, 0.07454083024640568, 0.10979656304698437, 0.12025936099234968, 0.20195699587929994, 0.0742857095610816, 0.14444249536609277, 0.17129183979704976, 0.15384403697680682, 0.21587086957879364, 0.18615777022205293, 0.13140057097189128, 0.1020336760848295, 0.17961995385121554, 0.19920276710763574, 0.16978596278931946, 0.17370358225889504, 0.11107406637165695, 0.16555732407141477, 0.0811828144651372, 0.10657107050064951, 0.15327121771406382, 0.09527647343929857, 0.0906627120275516, 0.16997911414364353, 0.12624754279386252, 0.14516142866341397, 0.12593287217896432, 0.11042069440009072, 0.2129806941957213, 0.11275028111413121, 0.12205450490000658, 0.10120240389369428, 0.15099343290785328, 0.090484418469714, 0.2056784657179378, 0.1759506421512924, 0.11564839747734368, 0.1236515176424291, 0.10701806604629382, 0.1481798174791038, 0.13678728661034256, 0.1498272072058171, 0.18919210036983714, 0.2532995736692101, 0.18293413304490969, 0.11908750981092453, 0.15754572115838528, 0.1641727882088162, 0.16446178051410243, 0.09120548915234394, 0.15896023978712037, 0.1548719560378231, 0.17953717469936237, 0.14151591021800414, 0.12859743466833606, 0.06737842239090241, 0.1523334250668995, 0.12089597526937723, 0.19299816020065919, 0.13482246547937393, 0.18929678772110492, 0.11843464992125519, 0.1670632159220986, 0.10562002309598029, 0.12603546667378396, 0.12299312875256874, 0.18505216314224526, 0.08524078148184344, 0.29648413765244186, 0.11911521418369375, 0.21012896206229925, 0.1222234993474558, 0.11503448549774475, 0.16317986883223057, 0.14021191222127527, 0.09430806720047258, 0.152820392686408, 0.13150858314475045, 0.1392463335650973, 0.11980699971900322, 0.08034432859858498], [0.07945750665385276, 0.061074241530150175, 0.060350076091708615, 0.0845256628235802, 0.03694435996294487, 0.02779806705802912, 0.058990543184336275, 0.029386613750830293, 0.03567592197214253, 0.0324702967191115, 0.01914835815114202, 0.08166434956365265, 0.08220472955144942, 0.0396517072658753, 0.04123376573261339, 0.035164348446414806, 0.026038485011667944, 0.010162063008465338, 0.0139846087222395, 0.07099179842043668, 0.0454882052144967, 0.03468446833721828, 0.024738338761380874, 0.024851776033756323, 0.061386232991935685, 0.03358467969519552, 0.018376181324128993, 0.03707582400238607, 0.02653217834449606, 0.021812033774040174, 0.06034964193531778, 0.008076130798144732, 0.062083911179797724, 0.015627177272108383, 0.01932899689563783, 0.057499520262354054, 0.016201991056732368, 0.01161552583653247, 0.05088917379907798, 0.037541421479545534, 0.05339728042599745, 0.07084831901011057, 0.017485932512499858, 0.03531398768245708, 0.05818863406602759, 0.024972208047984168, 0.08369437578949146, 0.03261507488787174, 0.02789277808915358, 0.03491493116598576, 0.01924625670653768, 0.02344916145375464, 0.08789939936832525, 0.03149822798150126, 0.05438662636152003, 0.02252944937936263, 0.10590989113552496, 0.019265005212218966, 0.045028812091914006, 0.06084185282816179, 0.042158967844443396, 0.018767768124234863, 0.03990437515312806, 0.03155875383527018, 0.07081708201440051, 0.028316110256128013, 0.03953094870666973, 0.03130284276267048, 0.053323496103985235, 0.045805365734850056, 0.03457298662397079, 0.1372730519506149, 0.02614289591292618, 0.07158613996580243, 0.047547453505103476, 0.0805954565294087, 0.06537333232699893, 0.02435528665955644, 0.039779861326678656, 0.00604050553192792, 0.02891728698159568, 0.025572377307980787, 0.05472684912092518, 0.06658658792730421, 0.01799097142793471, 0.03747847622435074, 0.07922629054519348, 0.014048480734345503, 0.018551875509729143, 0.011460083933343412, 0.056892762586358, 0.017693258887447882, 0.02550744124164339, 0.04300863787648268, 0.008334830490639433, 0.013582417559518944, 0.02235677387943724, 0.037412929741549306, 0.03667283039249014, 0.013172978397051338, 0.02993136498844251, 0.03903518292645458, 0.019221956936235074, 0.09477572413743474, 0.015999648203433026, 0.0728419354709331, 0.02826480929797981, 0.03196391451638192, 0.03412627680518199, 0.0069867823185632005, 0.06418133183615282, 0.03429017269809265, 0.06922148677404039, 0.014311170398286777, 0.048086916940519586, 0.08261961236712523, 0.02617177102365531, 0.0340372599021066, 0.01906683508423157, 0.027057785882789176, 0.06128864799393341, 0.033481725258752704, 0.051655656498041935, 0.06785078454413451, 0.041648871192592196, 0.06240737624466419, 0.006152845817268826, 0.017490873360657133, 0.05718422253266908, 0.03377557863132097, 0.03877394694427494, 0.015395682858070359, 0.04030113101180177, 0.05866226529178675, 0.03954047046136111, 0.035923216710216366, 0.047872733121039346, 0.022276800045801792, 0.027197580529900733, 0.027841289738717023, 0.042668285241234116, 0.05119063047459349, 0.04178323702944908, 0.04377370307338424, 0.04074417091032956, 0.01669516303081764, 0.04502411058638245, 0.09862927399808541, 0.059804712582263164, 0.0298896043386776, 0.027765711274696514, 0.030369848100235686, 0.08024445778573863, 0.039351849918602966, 0.03566814797522966, 0.06986613108892925, 0.08813120177364908, 0.053350439775385894, 0.03113620463409461, 0.01710402331809746, 0.01718363906547893, 0.019765081015066244, 0.014411804695555475, 0.02629229024023516, 0.017474547967140097, 0.01625603239517659, 0.04358144971774891, 0.05383183386584278, 0.02298168263223488, 0.03368267287441995, 0.04515126274782233, 0.03859529344481416, 0.017783715557015967, 0.03701162451761775, 0.04530697646259796, 0.07902787736384198, 0.05472952085256111, 0.05861432997335214, 0.1140396662231069, 0.03989313903730363, 0.04542533788480796, 0.0404737322969595, 0.05220772531174589, 0.1154358834901359, 0.02559055807068944, 0.02852859270205954, 0.044237660404178314, 0.09454052269575186, 0.05633971784845926, 0.04973297822289169, 0.042019503453047946, 0.034033723568427376, 0.08265383279649541, 0.05288451204251032, 0.039688146716798656, 0.05611563006823417, 0.013888652738387464, 0.018049385871563572, 0.009629033993405756, 0.01726985992718255, 0.07345439284108579, 0.020578734620357864, 0.04003419904620387, 0.03683516777527984, 0.05486027985170949, 0.04686636231781449, 0.04390187197714113, 0.051679995231097564, 0.08805787758319639, 0.048885571741266176, 0.07735736973700114, 0.0591607102251146, 0.02752756350673735, 0.04546167343505658, 0.0364005289884517, 0.05865613515197765, 0.0140390090746223, 0.06178874049510341, 0.05124940857058391, 0.02647267479915172, 0.06353721444611438, 0.01440055837520049, 0.041381289847777225, 0.05378885238314979, 0.026932093896903098, 0.04625744870281778, 0.049980402836808935, 0.06553254526806995, 0.04860062043007929, 0.04091295013495255, 0.04452637811482418, 0.057267127849627286, 0.029164056650188286, 0.011227945706195896, 0.03758495957299601, 0.015061132889968576, 0.02321436633792473, 0.028363231067487504, 0.025774608839128632, 0.022811667731730267, 0.09203807494486682, 0.025505036683171056, 0.01587899540027138, 0.0812556711025536, 0.030743345050723292, 0.05737964114814531, 0.03183370841725264, 0.028899232383992057, 0.06871807316201739, 0.07458523294189945, 0.05317374183505308, 0.025756275936146267, 0.015689070532971527, 0.03973404483986087, 0.011129399626952363, 0.07036357041215524, 0.003901478685293114, 0.03967363401898183, 0.009029592965816846, 0.03189091687090695, 0.03230022244679276, 0.026321855548303574, 0.05655946777551435, 0.02740553030889714, 0.03211430332157761, 0.031883910996839404, 0.07774264086037874, 0.0324556244595442, 0.07150757621275261, 0.14937869767891243, 0.03848085427307524, 0.06659631748334505, 0.025475586407992523, 0.04407767562952358, 0.034458347072359174, 0.043636643240461126, 0.02643450614414178, 0.05636487665469758, 0.057740937190828845, 0.026488482544664294, 0.05009889784560073, 0.02954736108222278, 0.05215421275352128, 0.02712462555791717, 0.07847865839721635, 0.04182768054306507, 0.0732745036657434, 0.01621116400201572, 0.022225964785320684, 0.009193374753522221, 0.04015247141069267, 0.028940200791112147, 0.0673069387266878, 0.02994065853272332, 0.04377861609100364, 0.06399736084858887, 0.015168123682087753, 0.039601883181603625, 0.021591606637230143, 0.024586239305790514, 0.06338878491078503, 0.03642993659013882, 0.037169241841183975, 0.026176559731538873, 0.04844083232455887, 0.09457815700443462, 0.0143481033774151, 0.006886565479362616, 0.04409406967170071, 0.05634381821437273, 0.02721662589465268, 0.04488043450692203, 0.05143168746144511, 0.050462097497074865, 0.02496095152309863, 0.07641481250175275, 0.0007107403348527441, 0.005288435340844444, 0.026455740844539832, 0.05930681312747765, 0.05168307514395565, 0.012391572035994614, 0.04797357243660372, 0.04758162198413629, 0.009841329974733526, 0.031039133573358413, 0.04963794621289708, 0.06844283285317943, 0.02638519599713618, 0.08932994838687591, 0.050897890323540196, 0.061494953915826045, 0.012624368919205153, 0.023982121820154134, 0.03033189281268278, 0.026128924982913304, 0.036923223597113974, 0.030965403057052754, 0.03421865563723259, 0.055225212418008596, 0.013839620896760607, 0.058230665599694476, 0.06711184294545092, 0.07867518652346916, 0.022340938303386793, 0.04376894219603855, 0.06099230100517161, 0.06567236589035019, 0.014211203106242465, 0.05149111122591421, 0.05498377693584189, 0.03867918210744392, 0.24411874677753076, 0.128708727133926, 0.15538611594820395, 0.09875823699985631, 0.10356705708545633, 0.15710708219558, 0.18449685856467113, 0.31574827269650996, 0.1161473582033068, 0.16273155226372182, 0.1163602432643529, 0.1464518898865208, 0.11145999800646678, 0.15461435657925904, 0.12735025549773127, 0.09970193714252673, 0.18795562296872959, 0.23594830941874534, 0.08016551553737372, 0.14969837036915123, 0.18615220411447808, 0.060679764064843766, 0.12403279601130635, 0.11026846506865695, 0.10735571355326101, 0.10032163045252673, 0.1572992093861103, 0.08523543059709482, 0.21527424221858382, 0.0936352732242085, 0.15276862046448514, 0.09794942961889319, 0.2709696348756552, 0.0952342155505903, 0.1756572414888069, 0.20432750461623073, 0.14451172290137038, 0.11855534539790824, 0.22523493273183703, 0.11836739649879746, 0.08527125406544656, 0.25073931261431426, 0.184169155836571, 0.18311552878003567, 0.19426767801633105, 0.13426258927211165, 0.17854358738986775, 0.11207818475668319, 0.09131825107033364, 0.1554038532776758, 0.10823710297700018, 0.10106080211699009, 0.20322114054579288, 0.2098791699972935, 0.15533193916780874, 0.11994848275207914, 0.1812165361479856, 0.1273133113863878, 0.10048457639641128, 0.16067445249063894, 0.08943419787101448, 0.14313474210212007, 0.14224619837477803, 0.06357668928103521, 0.228218678093981, 0.16323996795108542, 0.12255455658305436, 0.14056336367502809, 0.23879763699369505, 0.1055637386161834, 0.24048477614996955, 0.24172431119950488, 0.38582212349865586, 0.16585580102400854, 0.09063520061317831, 0.15676686685765162, 0.2021990399225615, 0.11258625163463876, 0.11350006549037062, 0.1323862321441993, 0.1036782976007089, 0.2805344935040921, 0.10272702013025992, 0.13235455728136003, 0.1502739652642049, 0.1502610815805383, 0.23192217311589047, 0.14708615897689015, 0.2706692134961486, 0.10513395347516052, 0.1081568693916779, 0.10257099842419848, 0.14690560929011554, 0.20841325022047386, 0.08637477571028285, 0.14308776415418833, 0.1344240509206429, 0.10821788135217503, 0.1136098439747002, 0.11208160605747253, 0.13077698880806565, 0.11507571180118248, 0.14000329450936988, 0.13265218818560243, 0.06872530168038793, 0.22374965774361044, 0.09011678819661029, 0.0857855030335486, 0.21859324537217617, 0.12523449637228623, 0.12048711869283579, 0.11362441233359277, 0.13510238874005154, 0.07878574426285923, 0.11174192506587133, 0.24140610796166584, 0.10552339546848089, 0.1370598329231143, 0.12842482596170157, 0.18328528763959184, 0.19986418396001682, 0.11653002438833937, 0.10718705307226628, 0.22254107025219128, 0.19891726289642975, 0.18634790845680982, 0.146714283619076, 0.15671035973355174, 0.11906960920896381, 0.2538769942475483, 0.11352209243341349, 0.11747549826395698, 0.17502582224551588, 0.0986642885254696, 0.12833262153435498, 0.10467187748872675, 0.1296173088485375, 0.10722651306423359, 0.0931172541459091, 0.16221562604187056, 0.19057259894907475, 0.15771025529829785, 0.09605362080037594, 0.07970171034685336, 0.09851899085333571, 0.11928589330636896, 0.14548840408679098, 0.16868301259819418, 0.16635453910566866, 0.12050065546645783, 0.18094076891429722, 0.2465082099661231, 0.1157789709395729, 0.2196255579474382, 0.153671279840637, 0.150281906244345, 0.1383857094333507, 0.18903936637798324, 0.08975369986728765, 0.09867815926554613, 0.1538984660874121, 0.08493175118928775, 0.11664748410112225, 0.13291139068314806, 0.1599495523259975, 0.08810536019154824, 0.10640824330039322, 0.1439307993859984, 0.07091275227139704, 0.17874444223707542, 0.12059496017172933, 0.20864426594926044, 0.13855248485924676, 0.17360916623147205, 0.11548382623004727, 0.15466158685740083], [0.05866972387593705, 0.11536295263795182, 0.018220779311377555, 0.08654066055896692, 0.04040829713630956, 0.03898878385371063, 0.01689776934654219, 0.05326002021320164, 0.04402584032504819, 0.054329232370946556, 0.060645840494544245, 0.08857747001457028, 0.04293771453376394, 0.026950144783768337, 0.07776431899401359, 0.02525733747461345, 0.07685864649829455, 0.01357474096948863, 0.005601307639153674, 0.010470674915268319, 0.05401613510912284, 0.00728122987311508, 0.05923740376601927, 0.06174163267132826, 0.06040464992111083, 0.06076481789932586, 0.042524286327534355, 0.04032843833556399, 0.10940870182821527, 0.0392878582351841, 0.06463077646913007, 0.044580131871043704, 0.024973779545689467, 0.039114410901675, 0.04070960538228974, 0.10017028427682817, 0.026021029698313214, 0.04244270203344058, 0.030182389018591493, 0.007829937221686123, 0.029988953792781103, 0.03775662575208116, 0.041034792229766026, 0.019236799889768008, 0.023620887004653923, 0.02635864195326576, 0.0407170936523471, 0.10206526188994758, 0.018642154063854832, 0.03426993062021211, 0.08117215722450055, 0.02240953872387763, 0.044943717439309694, 0.021781819086754695, 0.046318408712977543, 0.024565674393670633, 0.020264678132662084, 0.026487660616112407, 0.05498007361893542, 0.07358613889664412, 0.03949263162212446, 0.07006392828770913, 0.012511050390457967, 0.030041798418096732, 0.03684155766677577, 0.04065176981384866, 0.03572021334548481, 0.029889621037000325, 0.037393500315374695, 0.02748333521594759, 0.015030071226647124, 0.014604054340452421, 0.023892850731499493, 0.03738966341188643, 0.0031387598346555023, 0.048863845368032344, 0.019028532842639834, 0.02133227611921029, 0.08469755164696835, 0.042936449171975255, 0.026047264618682675, 0.04759548159199767, 0.015235538521665148, 0.06766654638340697, 0.0498825877730269, 0.023916951977298595, 0.012957624767295783, 0.014500968172797002, 0.020216047050780617, 0.06402473867638037, 0.03480218038021121, 0.034646663334569894, 0.025537329383951146, 0.06501168376416899, 0.0645368873665575, 0.009952532454917673, 0.03718476385984104, 0.02707101095438702, 0.046411525981966406, 0.017669623339315876, 0.07680380178499036, 0.03774982767936308, 0.06622457571211271, 0.034981627977686, 0.11015004056389444, 0.002375876320002135, 0.04430733322806191, 0.018298467330168933, 0.05652963343891315, 0.03233191586332396, 0.046880459412932396, 0.07481856417143717, 0.003005756766469858, 0.03915206376404967, 0.008603650294389809, 0.029752817245025653, 0.018339057241973933, 0.05327809150912799, 0.043766604430857114, 0.02278871867019916, 0.014733255757164443, 0.01484914582761121, 0.07086950732627884, 0.045815555422450416, 0.033484448940726, 0.06425040352041833, 0.021991631656419486, 0.048283920041285455, 0.04614920646417886, 0.06308569922111928, 0.048456755102961324, 0.0507377422763966, 0.05137934007507283, 0.03260023193433881, 0.020995430131733883, 0.008911332661227789, 0.010237142378173303, 0.04458914525457658, 0.007450938173860777, 0.05390310972870793, 0.012919511773361592, 0.006341406988212839, 0.05249787907814607, 0.004152027740929043, 0.031178417993942276, 0.014710258456034353, 0.037899385279160924, 0.013402301101450576, 0.024519707621948328, 0.04787703015608713, 0.03745938818610739, 0.0718673545634374, 0.08687631168868393, 0.062032662171986885, 0.045184926566435024, 0.018843363286578096, 0.020130054399487562, 0.12215856884722598, 0.06539087669807486, 0.01847059920692118, 0.04696907926700078, 0.03319372743135318, 0.055561334811500274, 0.02638124777149642, 0.044616727172979154, 0.06226354060345329, 0.016700263440725394, 0.13683806435437873, 0.015798362910572905, 0.011782054498326033, 0.042467905368539505, 0.02399869768851204, 0.05795940320240334, 0.0721885338134598, 0.06686173175694421, 0.0634409578924533, 0.01594517827470554, 0.05234377953456715, 0.034115556481992826, 0.04751501794089563, 0.023627256487088744, 0.04201176285278052, 0.02021161086304346, 0.052670250297524035, 0.03830528810794931, 0.11653195397229865, 0.05269255183520727, 0.03317910712212324, 0.023534200445283204, 0.053483892770600505, 0.0352537178696366, 0.0901695252105128, 0.0157821414177306, 0.028582318627741188, 0.03507503468426876, 0.05601244556601159, 0.025721550846355967, 0.0034542514504209976, 0.041213686927221715, 0.041385809527128004, 0.052051536622457206, 0.015036529766803142, 0.0020043312179041095, 0.07684257157961838, 0.02021124349994352, 0.010168241387873422, 0.047268546986742876, 0.0260881365466048, 0.03386044321814552, 0.03966586744354572, 0.05238044905127026, 0.04769977931573521, 0.027956656595051754, 0.023780738192726858, 0.018260745819134172, 0.013389106643444393, 0.03171916905557737, 0.04448686617251951, 0.027642544446280226, 0.03742861874343362, 0.09709196703624912, 0.022998894892225508, 0.013224030735727865, 0.02273536938446341, 0.03917994625226129, 0.04550651028694119, 0.052229054635972716, 0.03212238159903791, 0.014218345349945594, 0.025376756457262672, 0.061110677270335145, 0.03236597673094366, 0.03016906004631892, 0.01794160376448417, 0.04593059573380742, 0.022455896978499368, 0.052382679205038585, 0.03892274013196584, 0.039091293001547456, 0.00822630716356798, 0.025247485464205965, 0.021401685480668675, 0.045678911192226224, 0.008549312096874928, 0.06443830789066851, 0.032831062126206234, 0.07087111778673716, 0.0105931348480226, 0.03391195939911995, 0.09607168467482552, 0.05290368542773649, 0.023630171272088774, 0.014976541970099788, 0.05101569142425433, 0.054417607316281646, 0.019526784817571752, 0.02753917440713849, 0.009511397092865082, 0.0385914120124653, 0.05983276205370203, 0.003052268320971052, 0.03965817879361566, 0.021202281532168854, 0.017206135416927282, 0.01909937825985253, 0.033274521338171326, 0.0499631924321875, 0.05476816077134572, 0.03660604823380709, 0.07123724150005728, 0.07302609199541621, 0.027503855599206872, 0.035691336379386485, 0.02222773851826787, 0.048671454715076834, 0.014834282465017168, 0.04162004617683124, 0.03807855457125697, 0.0401141097972868, 0.02489718248398276, 0.08200003780075349, 0.04001346715085674, 0.026188098272541538, 0.012221791839692742, 0.03939481655834243, 0.07709378114668652, 0.04623622327926569, 0.05131173042173032, 0.015728454454801977, 0.04008078365586698, 0.04774126908159815, 0.019805698757409118, 0.01213795883813873, 0.05986700845824089, 0.017779500158212613, 0.006000447183396318, 0.0464141828706488, 0.023787805293977726, 0.03222224499040749, 0.020483084772422444, 0.03594676876673475, 0.06078729384171311, 0.08860973117407411, 0.03140301785606425, 0.03168125273077749, 0.0357602744770702, 0.03871643049933482, 0.00440532598986465, 0.07902516852482222, 0.04893034179985989, 0.07420453344820999, 0.02373579001869075, 0.01955026080395328, 0.056296758630196564, 0.04279531494830735, 0.043347569298930466, 0.021423246726044454, 0.035161925334250554, 0.03516343189403415, 0.0329048798448639, 0.010734975039667916, 0.04107526896405034, 0.03295021022495348, 0.03720070148119703, 0.052134159923298284, 0.02719781616178807, 0.02920051836554194, 0.040820537906256504, 0.016389260890719015, 0.030975505542301107, 0.03479654376860708, 0.03198785248969216, 0.023251252932823263, 0.029087520815664902, 0.0255496007957845, 0.024349657469429076, 0.017372927541146055, 0.08450166918919422, 0.01299845216635731, 0.006475742675320362, 0.07263400053489022, 0.06777541944757104, 0.04363025705970358, 0.0845580427267123, 0.015240745615301421, 0.0264547296683304, 0.05095958877063822, 0.05040170894062612, 0.01757459875079803, 0.05118741697515361, 0.049768950120778754, 0.04444828191481065, 0.07351919717621058, 0.15927214961266145, 0.14946744369808584, 0.1606515349703841, 0.12237808870850131, 0.12403917105984874, 0.24066813115496188, 0.1087430102052167, 0.20067150704562664, 0.32204177405219525, 0.1403483931790106, 0.15835311845876276, 0.10972830772516318, 0.11834136937977746, 0.1256707010907121, 0.1610743216588162, 0.13068159314570948, 0.10670864983694628, 0.13021267455769703, 0.1303685997845605, 0.11075684276875108, 0.09420002534170635, 0.18875640031183138, 0.0875751550483983, 0.1816732092993334, 0.13956803973997012, 0.13813280034810305, 0.13326428190339357, 0.24935974914114922, 0.09428330173250288, 0.11575561555218883, 0.09337719879113138, 0.15526434435741976, 0.10698475103708915, 0.1208452568971552, 0.09469390235608444, 0.11385105681256391, 0.1414210192160681, 0.10573751249467023, 0.11850134673295543, 0.11120317780296318, 0.1689522637752816, 0.15886968292761594, 0.10075367172248662, 0.1525851764017716, 0.0820551867946051, 0.12956305785337463, 0.1653330322005786, 0.26193184952717274, 0.14273362612584606, 0.17646843858528882, 0.11320701363729313, 0.20173592492938042, 0.08140800433466211, 0.12563911528559402, 0.10478083961061202, 0.0900271293357946, 0.0896599146653898, 0.140402659017127, 0.1545933389570564, 0.17190296872286126, 0.24277492513647303, 0.09564420761307701, 0.09404852331499569, 0.07826247077900916, 0.1281487915548496, 0.08449758737697266, 0.10544043077970855, 0.2416093525243923, 0.11429574427893385, 0.1679006256745197, 0.08973967327619903, 0.13151094317436218, 0.22529182577272877, 0.10541028474108316, 0.14985497837187722, 0.1124470766808372, 0.09741214438690804, 0.12836698297178373, 0.19355726457433775, 0.14568669110303745, 0.09844308398896828, 0.05772963057097513, 0.19754755514441058, 0.08620462351245806, 0.1825827854918316, 0.08478342555463314, 0.1511909332475625, 0.09233169083017856, 0.1543613732792437, 0.115471536264522, 0.21654983080225065, 0.072866567352321, 0.16214305884204805, 0.12614344916073605, 0.09516157413600013, 0.10144608066184446, 0.15613881696481258, 0.17171511630294845, 0.11513443794683553, 0.2485944316140376, 0.10817211310495622, 0.10831417501321994, 0.08345035021193326, 0.254919296130538, 0.14760435617063195, 0.18993136851349846, 0.07292419511941262, 0.1573764075874351, 0.29737014323472977, 0.12899804598418996, 0.11073946909164079, 0.051980464850203134, 0.07979172543855384, 0.08750126682571135, 0.11224461137317121, 0.08939199935412034, 0.2830399840604514, 0.10915087230387144, 0.16234272625297308, 0.09120879913098179, 0.10477166666532867, 0.20270071690902114, 0.09466167830396444, 0.10191853187279776, 0.18155762722017244, 0.17471714818384498, 0.2023180210380815, 0.15282609238056466, 0.09841097125899978, 0.14028418256202713, 0.12706964946119115, 0.14341533329570666, 0.12749176821671426, 0.13464810530422255, 0.11172520447871648, 0.22132838610559702, 0.12386420232360251, 0.1322615216486156, 0.17794191342545673, 0.07978297551744618, 0.1587411726359278, 0.16150959127116948, 0.09998709996580146, 0.2327267057262361, 0.11471392965177074, 0.2055466454476118, 0.12671012344071642, 0.12107948612538166, 0.2356547603267245, 0.06762615870684385, 0.2094719238812104, 0.14461234328337014, 0.11072598426835611, 0.11622071950114332, 0.09525581946945749, 0.09007867149193771, 0.16625221178401262, 0.15478279441595078, 0.1219781453255564, 0.14953941717976704, 0.18490005255443975, 0.08665977526106872, 0.13302805629791692, 0.1122067247342784, 0.09966079247533344, 0.12403990578604862, 0.23156196431955323, 0.22710045450367033, 0.09072724176803604, 0.1045164123934228, 0.1264866182464175, 0.13949876767583191, 0.199214834428858, 0.11998763104202226, 0.1594533523893915], [0.015105135753401555, 0.09642463526688516, 0.006853060294815805, 0.08896029947209172, 0.09111083563766442, 0.028157674714748282, 0.02414169841358671, 0.017445144076191355, 0.023815496679162607, 0.09596911986591294, 0.12390506497467868, 0.055160638148663566, 0.03364994045114145, 0.1283236563904211, 0.03480020255665295, 0.0548234507732559, 0.034155031316913664, 0.028416728782758582, 0.046435200492851436, 0.029858341367798857, 0.06760712261893786, 0.0483094499213621, 0.0461273093969794, 0.04825558855372947, 0.02165038287785137, 0.0377243942784844, 0.017818655869632494, 0.013260780033306219, 0.005054157409176696, 0.016431850890512578, 0.1294515872723423, 0.027343566544004716, 0.047341715326183476, 0.08449570232187398, 0.03923010801372584, 0.05335676658432931, 0.02683287802938139, 0.09838131503784098, 0.05165867703908589, 0.025965394597733393, 0.019036612975469325, 0.03583229990908876, 0.02915268880315125, 0.032592331772320904, 0.07474726604414172, 0.025818722097028513, 0.08727629960048944, 0.011560371276573278, 0.060432528698584065, 0.057067011439357884, 0.015792407175467815, 0.005643123022309737, 0.01568587373185437, 0.016899782422115095, 0.05473239296406973, 0.02457978447637288, 0.05759429623140022, 0.019550988108676393, 0.004765506955664023, 0.03546199048287235, 0.004483326174522517, 0.027148971712449566, 0.032455416658194736, 0.021448713523568586, 0.035573720815591514, 0.04012449615402147, 0.06459055206505582, 0.0844835904717911, 0.007962550662341528, 0.025709407454996835, 0.04243376286467537, 0.025727883221406955, 0.051562657972681336, 0.012332431215327233, 0.02391828969848575, 0.02398428703600075, 0.014829980791546404, 0.04319984851463232, 0.060249526213738136, 0.04054222510603722, 0.052420892388909124, 0.014496379844786134, 0.04980188292392995, 0.05537224671570584, 0.007916103349998593, 0.018679439563129563, 0.03380322363227606, 0.015779308268975, 0.06831192542449571, 0.03880345473589841, 0.07903089790488593, 0.019916777855542023, 0.0025606332883398863, 0.0621263880020706, 0.027047820694861002, 0.030579577178286854, 0.0720843140152283, 0.06669275215244852, 0.0529720483609708, 0.07552231312729418, 0.013235526603239123, 0.02893244720326038, 0.020967337986803614, 0.0030704669416081742, 0.045034433860564604, 0.05951223589363508, 0.028788774834538344, 0.07083427757606842, 0.0704913459776435, 0.009974303357012104, 0.0670950704079587, 0.019840386739815585, 0.00788591185482801, 0.029364369729592, 0.03954783627705183, 0.10291158483596519, 0.013305185511853779, 0.028172152160550468, 0.046135291195241734, 0.04228630554280244, 0.04368428541056346, 0.04722690879134461, 0.05079589696833864, 0.02562258730904432, 0.03422020672587678, 0.10740142985014245, 0.016879790819075424, 0.021682757214875892, 0.03764839093491901, 0.03392753336811438, 0.05398601133492775, 0.06091177427151706, 0.05965087650110945, 0.04206650366540998, 0.07657236303202808, 0.03620063893322367, 0.07413443017867394, 0.006501338884845609, 0.02030483945418382, 0.01740038514981279, 0.03174101046170108, 0.020674469815276098, 0.03367643141245935, 0.014685406713397242, 0.032540199608774856, 0.05967126700852532, 0.02117808751791017, 0.024755808917689137, 0.04082905034010764, 0.004436313438418438, 0.030414851935347542, 0.016526921863260213, 0.045987644625711255, 0.02240851641545305, 0.05059490111307241, 0.028445882198866457, 0.028846152126789093, 0.04065498331328854, 0.018984497510246, 0.010528219190746313, 0.019323393680679146, 0.04948679299559444, 0.1288240123540163, 0.02871951390261529, 0.04636919758922886, 0.03862704252242111, 0.020522194099612534, 0.024543788458686322, 0.07300226163351908, 0.03529147092194762, 0.03186242582160048, 0.025470925720583182, 0.07090386876370758, 0.07056910078972578, 0.04007041956356261, 0.1723431661957875, 0.03749052128114272, 0.007247028925121413, 0.02223949970357353, 0.053360458769020624, 0.00632188201052486, 0.030171004473231733, 0.03204603686754126, 0.02297310154972365, 0.04745736419863533, 0.057457818984403275, 0.0909753046289552, 0.022217669429664966, 0.06400886413757689, 0.03838490571069997, 0.04098357661860064, 0.0063569781741534825, 0.04932960611768067, 0.018359106361458544, 0.03391357357031666, 0.04118006763746962, 0.04747565071738791, 0.01358568300929619, 0.031220879973261617, 0.02473856511642225, 0.030638700372946914, 0.02969087945530191, 0.050862141069956124, 0.047222789871739224, 0.018596647423692048, 0.013976118552818662, 0.13942522084107623, 0.036544216200127266, 0.05851042558788322, 0.13068659522105008, 0.025006563919305336, 0.012860144597652834, 0.039903937285998836, 0.002293478910360136, 0.060162505687912926, 0.02822412847308442, 0.046579644695157185, 0.06242689472856, 0.02714032383664744, 0.038669834757456556, 0.004891345979558537, 0.05227056666626595, 0.051467867160681635, 0.025399019032192882, 0.023304258975258563, 0.02987740528624272, 0.014094191465119366, 0.026363143078924622, 0.043355933303246275, 0.021257684711599723, 0.054794295501778834, 0.04111614645808004, 0.04940309729136061, 0.007448237684002379, 0.09975727909477428, 0.004293148977012606, 0.0702969181293156, 0.02933518662757706, 0.062309731874847785, 0.036479779228102416, 0.03546447667758912, 0.04517481480434071, 0.020132165809627622, 0.05952113424427807, 0.025540607821312733, 0.009878634955384769, 0.016943162809184287, 0.023009657888906077, 0.036882119748042896, 0.036432760462048464, 0.038945527776377276, 0.03702173627971206, 0.002117120038747089, 0.04247806908097118, 0.04960149191902019, 0.019705692502611782, 0.033552336899447255, 0.07996753280167468, 0.031547651306027547, 0.06674848002148792, 0.04798579560883809, 0.007009448900134885, 0.019404319318709895, 0.060181244916748255, 0.07313985581276938, 0.04330143739935011, 0.07406354023260064, 0.031069877040863503, 0.058676599874161184, 0.07814660668373108, 0.029019332287134603, 0.06349983988911845, 0.01654760922974674, 0.01822786496632034, 0.03477295831544325, 0.0311257384964847, 0.04439458381966688, 0.046555925655411556, 0.022618490402237512, 0.03856315845041536, 0.025375680343131535, 0.09371489824843593, 0.016449523282062728, 0.03035127399925841, 0.07943286735098809, 0.039733555022394285, 0.017036450772138778, 0.01908352227474097, 0.02800529880914837, 0.04612293072568718, 0.019412065485084895, 0.023088943380571436, 0.020973321552446578, 0.05874868838873226, 0.06172431465529371, 0.015679370662837755, 0.03276305171311833, 0.0184601924411254, 0.02129674579919083, 0.05847377462487202, 0.006949028338567587, 0.026309185232094023, 0.05344763885659631, 0.04942864201439079, 0.03945996599213686, 0.02041920626652427, 0.04594403973896988, 0.015209165376290912, 0.0694898547953926, 0.017955884541152045, 0.06386902867234312, 0.06681418977677822, 0.03758115977689158, 0.03133108519250527, 0.08084938977845013, 0.046229380677687004, 0.015477217984880554, 0.03327980171889067, 0.041806328954407945, 0.03305800346424803, 0.0222858505367185, 0.05635673529468477, 0.02720635457080789, 0.036788130455533974, 0.028638202347792685, 0.05895259717362933, 0.01997909970668843, 0.029107035588822328, 0.022742555229342543, 0.031620808513252996, 0.0218436548311729, 0.016078041262517218, 0.06452166591770947, 0.05843935752636753, 0.01598708735400578, 0.016401446955569554, 0.026897569186985493, 0.006722605112372548, 0.09999872199841775, 0.012252226388227427, 0.025562400987837464, 0.04206556113786064, 0.06847017357358709, 0.029783334357489366, 0.050943907190230675, 0.05825010986882262, 0.021993179034325294, 0.03632971696788445, 0.010740669167716987, 0.06275820429436862, 0.026467726529517677, 0.036595086712623015, 0.1007332700828556, 0.2199404512066394, 0.09016967364004813, 0.1268409047042951, 0.1222249391139485, 0.09654418783611618, 0.20072175044333562, 0.10407051522633992, 0.1079139496141579, 0.1725321912090294, 0.18468016904080287, 0.09521873435005546, 0.1678219877067022, 0.17195088177686557, 0.11621997735346667, 0.1590634576859884, 0.10361084379837848, 0.13146634009899572, 0.08669252623803914, 0.12174154122476466, 0.12079128049663268, 0.10035689731012098, 0.19120139098959044, 0.1385984238004312, 0.1213731020106934, 0.12039504043059424, 0.1064861539634876, 0.10097038626554422, 0.15184434974798933, 0.07469263655366376, 0.25841015100013465, 0.15362232777988538, 0.12339057851932012, 0.2019510735408403, 0.10680541847250424, 0.11521931737661362, 0.1528831635368988, 0.16953651211224496, 0.11707577752531506, 0.1414837158517912, 0.1622358273016289, 0.10884722258197144, 0.09328714659204707, 0.18137275823391974, 0.1478484782273881, 0.15502224094234407, 0.20095959393074736, 0.12563061027321965, 0.17667419160716236, 0.1299385994207114, 0.09863319995929487, 0.10658949802746065, 0.159908318601083, 0.10182430880377069, 0.14220294600818306, 0.11517561972141266, 0.10543443422648124, 0.11568218003958464, 0.17442595912143588, 0.16120922926347703, 0.1764750585425645, 0.18455862009432167, 0.12305072683375329, 0.08244373078923672, 0.11214779078727588, 0.06286627583904192, 0.11846340072224848, 0.16664779133861884, 0.11568622474442236, 0.09301128287916072, 0.15723643853561953, 0.14974999416153878, 0.11713849642546847, 0.11371257205610164, 0.10629096170305274, 0.1750193804036826, 0.07648553917533718, 0.13761918962700292, 0.12442663151887245, 0.13470655685523525, 0.13451460778014734, 0.20932576531777158, 0.12447377273929305, 0.23366978246485814, 0.15963284822646528, 0.08279164219857194, 0.11475529696326703, 0.17838349129306152, 0.15526144998148084, 0.1293857439304702, 0.2811446279520169, 0.12062860172591172, 0.08173478679964319, 0.16467675101011992, 0.15082738478668034, 0.1226980063074734, 0.16097561601782218, 0.12987728317966685, 0.14723822503583506, 0.15399282274302095, 0.11596094554988667, 0.10496727452846244, 0.07895646049291827, 0.08298742075567134, 0.13219597516581416, 0.1532484931522049, 0.12163989667897113, 0.13894614967284724, 0.30864948173984885, 0.07481281994841993, 0.1590822933940217, 0.10524862271267921, 0.10328849195502698, 0.14699296007165685, 0.09568397930706851, 0.16962087946012616, 0.1806388483964838, 0.1660932882805355, 0.1589442093973048, 0.15559179475530982, 0.2564429253106937, 0.11554914264706895, 0.14778897282667458, 0.10092013544635847, 0.09213972691213712, 0.14073007972911, 0.09958326030755416, 0.16036325512686744, 0.11494109363411553, 0.12907151860417798, 0.18764013599138707, 0.11627496307482943, 0.07912106884759851, 0.11855741598992608, 0.15930202847812325, 0.11558417943888344, 0.19633588031865656, 0.2177187430788763, 0.29245555226225406, 0.17278297775192186, 0.09002392325783148, 0.08680068684043363, 0.1046809836407192, 0.12428050264134072, 0.14837713970337063, 0.14774291514186189, 0.06856614068965428, 0.12436493678251281, 0.12629217555513605, 0.11511490461998619, 0.12482383637689054, 0.11302538041491061, 0.12374997837468982, 0.14148603135254234, 0.13145486649591476, 0.20159469422651455, 0.17017656995449215, 0.13193659455282614, 0.06619805135414936, 0.11075546237407252, 0.10240212272037752, 0.09050536929862574, 0.2168292345595546, 0.1700682460796088, 0.0899389102414716, 0.16129289899254218, 0.16653394588502124, 0.20439322921447456, 0.20166631147731096, 0.12235733825946227, 0.10133856572792865, 0.1442473105271347, 0.22043605742510408, 0.09859274548944086, 0.07943717922898941, 0.2310192762524821], [0.02983451100590173, 0.034738734175334685, 0.04069324102601968, 0.020248391701898072, 0.01991103548789397, 0.028815219411626458, 0.01931077345943777, 0.0467929935985012, 0.06385241940733977, 0.012240510659466963, 0.01719985499221366, 0.043767992247012444, 0.027212406785110943, 0.05117178734508343, 0.03243482577090617, 0.04860906607063953, 0.05030144478951115, 0.08588416414568201, 0.04573394515318796, 0.04497227899264544, 0.028731915190292057, 0.022174864207045175, 0.10078736522700638, 0.02670018202479696, 0.01987995990930358, 0.029661033986485563, 0.04281933084712364, 0.025016130202857312, 0.01821077887143474, 0.09412414074176922, 0.024858844990376383, 0.04131497524213046, 0.08013759594177827, 0.05619455005216878, 0.03466039677732624, 0.04095251773833297, 0.05544838364585303, 0.00826110090201837, 0.019060680824622978, 0.052661173831438646, 0.09109243037528358, 0.10106541827553883, 0.01626918510737596, 0.03662973758764565, 0.03215444980014581, 0.034198985013063066, 0.03570480264897924, 0.03183874759997707, 0.047494560640188865, 0.02603033251943998, 0.05653919972246513, 0.01565695223689545, 0.02156313043087721, 0.016309834390995093, 0.04167785948084202, 0.07776226324494928, 0.03913474203727674, 0.021872192264709156, 0.0386651777807856, 0.044315237100818194, 0.01660379537497647, 0.038113008777145296, 0.04276928782928735, 0.013296794604684692, 0.07446889387210831, 0.04162232828093693, 0.040779330156510696, 0.021563859590969514, 0.03556970208592247, 0.02905533943703631, 0.04419644523295574, 0.007153631959226914, 0.03482034444459714, 0.008873176066117594, 0.023088600137270987, 0.02262469475681428, 0.07269671201356687, 0.04106096035684459, 0.026786221060319804, 0.04074900229170453, 0.02116788298735628, 0.03450116157182492, 0.03531996197125409, 0.040106666056090035, 0.02655152613442624, 0.07991806865902618, 0.03584922458685469, 0.020880560514342505, 0.006325837193799089, 0.038064030741225, 0.024370910723519046, 0.0602236401027767, 0.03515440737828612, 0.00878783836014918, 0.01149523668573238, 0.06191400760144461, 0.1407376496354118, 0.02821167894580867, 0.0689383054850623, 0.022487568130600266, 0.03876748654874973, 0.01856439183029579, 0.033562459793756716, 0.002415648245914781, 0.01712435816443758, 0.04101463178812992, 0.009789528066903586, 0.05925773119088262, 0.058953832849510945, 0.007663470250918181, 0.01835540861065965, 0.030053550326556433, 0.029002602423133794, 0.031342610745923594, 0.011304828494758112, 0.03610253072110936, 0.03369647682120558, 0.03719193300639745, 0.018907913436123636, 0.06893369674799033, 0.010472052526893094, 0.02663736664544558, 0.07914308094768785, 0.11398231305065565, 0.04063920525368303, 0.0546766279876465, 0.0376251542911632, 0.045997767520020716, 0.012604252078745048, 0.0677099842869211, 0.008200786560337292, 0.031000671770016197, 0.006679464067929075, 0.03142897447105497, 0.03300607168057468, 0.013659096257470082, 0.027264052841928788, 0.04012998804682866, 0.06015738857968245, 0.029870390135329217, 0.02395619489107048, 0.03085588432441, 0.026776087033795193, 0.006955093540454982, 0.03673313360195607, 0.06550090009113774, 0.02925635941210203, 0.03660435613710433, 0.021412253663584124, 0.03148410120047629, 0.03230480520869605, 0.0424265862966422, 0.030625610743300058, 0.04006797418696806, 0.02686249714315636, 0.048379111613030545, 0.06897745377500542, 0.04886194546998013, 0.030242022439779248, 0.06105942826252431, 0.01177793001261307, 0.057005951239261776, 0.05577573385380674, 0.040278974192915484, 0.04083821586391423, 0.024710049947316293, 0.033924531380762346, 0.053989421503501944, 0.037669549565180205, 0.051710052212001756, 0.039532774389954284, 0.008111884690151783, 0.062490348354913294, 0.024415870029770304, 0.024099780057440512, 0.025304218943347223, 0.028046636434737593, 0.017694155030767433, 0.00945295574638294, 0.006845390662419959, 0.019052242605539504, 0.04929169350361917, 0.025118776648014318, 0.016308337108057458, 0.04394626354041975, 0.006993011720624054, 0.038646149114356376, 0.047478344713454135, 0.07512221389333718, 0.05021144083002582, 0.07328450039494783, 0.03621648378612008, 0.05037544062361121, 0.05689525991328992, 0.051562954831751995, 0.049943759295274504, 0.06956098222872242, 0.024862557584128808, 0.022994796381681226, 0.02420721335511189, 0.043347602695575915, 0.014254132638598094, 0.029706763270951342, 0.05056882946519181, 0.01421711987859453, 0.04051115509355441, 0.016739441416575573, 0.03523873019730672, 0.0100578524870798, 0.027833810745505616, 0.05363131669582799, 0.0726447616762016, 0.031012555409688503, 0.020885950361844152, 0.06752275527105667, 0.026780599291669205, 0.057647170542622916, 0.08557462177122943, 0.0416592055989895, 0.07892594338045456, 0.03102500493696425, 0.08107089859549887, 0.014186655644152779, 0.030661734781460837, 0.05088515878014732, 0.025793960339797195, 0.08906848976039328, 0.04026100679766387, 0.01635881984839216, 0.02850662698619999, 0.03521702608850319, 0.03305598111182917, 0.012284047825232847, 0.05391224556660745, 0.008029526707105106, 0.05024729769502301, 0.03508516871079337, 0.025393490032001864, 0.10382995547843166, 0.001416182778939401, 0.01864718953584088, 0.03532363560225349, 0.02131572622602107, 0.10399742110166699, 0.033462618666817434, 0.011545670258783503, 0.05434390091977548, 0.03411184203287121, 0.01971061479707714, 0.03592300148739014, 0.04535539046628401, 0.02460459447320318, 0.04613239681930281, 0.012727591456496157, 0.0215439885869273, 0.05668516161676962, 0.016325180149578955, 0.053738839051220566, 0.037587683254969306, 0.03522790226270445, 0.06888918273034506, 0.053507040356635116, 0.014584862401534338, 0.007653093634871766, 0.05017336494347546, 0.035295137131470256, 0.02840060191374505, 0.012558922626340063, 0.05095971493574325, 0.027362292785255704, 0.025323418303742073, 0.06286512551014312, 0.06042137792974245, 0.030320200276037212, 0.0279685309578781, 0.044075163459638134, 0.029207767292973585, 0.01975825882254867, 0.0852421841409523, 0.02850233366189059, 0.06495405599707738, 0.04459867072000634, 0.046855912878527306, 0.03258210497733671, 0.009745751558511984, 0.034639813311514445, 0.021334658413252328, 0.03156706959998701, 0.03960524882131722, 0.05921499461692292, 0.034605385080794804, 0.035347016964806244, 0.03314198118459899, 0.0699089678528253, 0.003962567179769394, 0.0624865411373321, 0.031585678952978924, 0.03615456269471906, 0.04342052612628322, 0.057512144194333814, 0.010749535049399128, 0.027598037850111723, 0.07660465387743898, 0.04541190872259904, 0.04732784458610695, 0.09679540482466109, 0.046382055297726765, 0.05134487473696936, 0.010972386226058006, 0.09182332709315233, 0.06882601854158565, 0.017686432984191924, 0.06470618609455414, 0.016114081809064373, 0.03271494941145647, 0.01035915423926781, 0.007765035479678772, 0.019143007266393397, 0.028189180738991126, 0.09418631045264192, 0.025612336394260637, 0.020914239175908733, 0.03197835299943108, 0.05081423914816696, 0.09023591774166562, 0.02328530823433539, 0.08572762293624692, 0.03490696049993858, 0.07342868484556675, 0.0278902288118843, 0.01927792971400777, 0.017184579737659078, 0.05160315697139595, 0.029274328662722837, 0.03312133463623468, 0.05551882459258195, 0.06067087684641592, 0.03840894758468494, 0.04952888390107546, 0.0073862836597982096, 0.059398011944722384, 0.01118054937251145, 0.019759952774620615, 0.028542643412947655, 0.02362661081861006, 0.03921865667507518, 0.02961930302262772, 0.03803168052399997, 0.0037260456429066835, 0.08915788886952214, 0.02608827384392498, 0.03496230987366289, 0.0974992651026696, 0.0737067378940992, 0.16415698046330363, 0.11836442790809087, 0.15755403321236372, 0.21548329037614167, 0.13818292500218377, 0.12026317563140765, 0.18048228492261842, 0.08775199399678968, 0.18821555277099833, 0.1507186601520516, 0.18016520974924788, 0.21418941527372226, 0.20432382356375456, 0.12181160738691688, 0.18489307636627927, 0.13593887822935358, 0.1379444877966307, 0.12096293925424106, 0.1447105294209905, 0.1261169693316333, 0.1430713923764415, 0.1757576985983178, 0.1806215415126644, 0.14269018080085516, 0.09901112382067367, 0.14480764686595649, 0.07578416509204544, 0.2299203336588107, 0.14329399215057492, 0.15494643797865137, 0.10959204941173084, 0.15791059064213187, 0.14829985244432464, 0.2189811214338988, 0.14940206048777327, 0.09394688619067892, 0.32252598088234663, 0.17139544361270964, 0.2612016652710736, 0.1955043780617416, 0.16153847565874457, 0.18544281483627856, 0.12516382907051593, 0.1577690927661024, 0.11780775035731494, 0.17466678604250774, 0.13003105617826805, 0.08670175113365985, 0.11735354855773039, 0.09709005971672013, 0.14137698017293587, 0.08288536802865565, 0.10421769053209573, 0.2092606492806226, 0.11851175906485878, 0.16106464405311272, 0.1372584910131991, 0.13897742377594113, 0.19056247605476528, 0.18240412086015567, 0.18878369650337845, 0.11520508298417553, 0.12278311580303125, 0.10356271552154794, 0.1538489796803333, 0.26347174658440053, 0.12060120163368993, 0.11985480145085603, 0.15896148659521714, 0.14533034147461876, 0.08261487004347146, 0.2093529427656904, 0.12951357144629583, 0.1912327838363126, 0.18642693234141916, 0.11249471514020115, 0.10612293946905993, 0.1330237666843459, 0.0808639581373427, 0.16555575071834028, 0.1962689237552695, 0.14821039396338165, 0.1837736801826395, 0.1069111077231355, 0.0881876346829813, 0.09387811878696084, 0.1243181963218376, 0.12917353422380984, 0.19220904941903427, 0.22138431435450912, 0.11245420129853301, 0.16362658236175776, 0.07225883746286854, 0.10098591941641644, 0.2567020832793787, 0.12372241500997916, 0.11018247983884066, 0.10370301111834124, 0.18152464617742226, 0.14601721399230883, 0.11578079662285745, 0.08523183860233985, 0.12483257887652144, 0.15798688342329115, 0.10662624175893143, 0.16469952010083944, 0.10877743101445958, 0.1678963063750416, 0.0883376004640013, 0.12209379419800825, 0.18976781400851905, 0.11524426096002571, 0.12807886640075594, 0.05703089111193549, 0.1005235243064817, 0.09017838645377196, 0.11731300503015518, 0.15651480382075533, 0.09473595986492, 0.12225901111378334, 0.1684643907356076, 0.22263386839767918, 0.11625422746874392, 0.16954899503616616, 0.09511640702839941, 0.21010925062000751, 0.19337456265930086, 0.20858722447883338, 0.10750901899882592, 0.11132845233078115, 0.09458885877393186, 0.21988761029206216, 0.14770656474865973, 0.08965592191088945, 0.1037354207073804, 0.14963551046093926, 0.1725352488574572, 0.08105442291707732, 0.1192954447469674, 0.1760096725774929, 0.16196665033930913, 0.2140972702181898, 0.11532082833582535, 0.1374191659851931, 0.10331952857086435, 0.16559993819100782, 0.20017484697746113, 0.12464876373996958, 0.18522652331739664, 0.11478268221253529, 0.15493429644266143, 0.10498454430489801, 0.07325333761400543, 0.17447093327064067, 0.08358084203791805, 0.12292735220398754, 0.11669046187307686, 0.1704955895547755, 0.13253359298687428, 0.14653784543043002, 0.11876777032739483, 0.10273223742842674, 0.16783580649644136, 0.11551433592103422, 0.0970069837057963, 0.1311296276981011, 0.0960077486524824, 0.1256953107076697, 0.07890902241342701, 0.09513076758594252, 0.07320028147660196, 0.234590015897993, 0.19451917702099308, 0.1473938682465814], [0.003952448460040614, 0.012544611236080527, 0.020100103174627293, 0.03399290915695019, 0.028321589161350857, 0.023057754624460358, 0.06043332279659808, 0.07177314633736387, 0.040512186678824946, 0.04873556885286234, 0.0911973329493776, 0.02639507583808154, 0.049406533435103483, 0.0485548930009827, 0.03218590572942048, 0.06519649337860756, 0.02705637765757274, 0.06623716253670864, 0.02615888362925034, 0.029210832362878136, 0.0705993507290259, 0.019941398604714777, 0.14647839940153062, 0.07726093506789766, 0.02651691607752582, 0.01839995602495037, 0.03431395482039079, 0.043739979882957414, 0.017926632790477015, 0.0651491443568375, 0.01978345102543244, 0.06732056455803104, 0.05850334549904801, 0.03609103114285972, 0.05617246373731177, 0.046767215098952875, 0.023229667567647994, 0.020520542821031995, 0.012180488538433565, 0.04100129539438058, 0.05378862231737003, 0.04814721643924713, 0.040869679214665666, 0.053039068006910384, 0.005121399235576973, 0.07486410235287622, 0.028227241782587953, 0.03258728145738132, 0.04633101780200377, 0.03764154091186356, 0.02455105037370231, 0.11053750102291815, 0.08559495661756955, 0.025052465753105935, 0.023971683513082098, 0.03260225428675767, 0.05520799459191039, 0.017198070127051324, 0.0076391329093894456, 0.03611754065786954, 0.050349658413324505, 0.0198103946968331, 0.060990467900410295, 0.05413414772192482, 0.09413590378244407, 0.04361736595456023, 0.025433046503167134, 0.031720864863018505, 0.04909495386527851, 0.08007866941625252, 0.028977289621252567, 0.03911321975465398, 0.032771801634225994, 0.016155645789694972, 0.024493309429090004, 0.05054068722529337, 0.026027614403574262, 0.016662621710565872, 0.07539062644354999, 0.03475273108051624, 0.06713662325637415, 0.021749346415163018, 0.07156547857448459, 0.05190230927837547, 0.06592289268155582, 0.02878120678360574, 0.042410860187374055, 0.043081880430690944, 0.024951223822426982, 0.036545730181387626, 0.027493621382745914, 0.015124086494324729, 0.040494189597666264, 0.06504076111014001, 0.07099562048097141, 0.005491363099281443, 0.03951666978537105, 0.02921694209362613, 0.05091592451208271, 0.08317728439578786, 0.008306806066684658, 0.0140058109536767, 0.02178320133680245, 0.05781915955594741, 0.0788089215348009, 0.05845645289809909, 0.027046846626035403, 0.0275715728639625, 0.04624126246199012, 0.02055227705568541, 0.08208852406824008, 0.0188742811587872, 0.00992226767266402, 0.09425915966858156, 0.030459725894615985, 0.0399702518916456, 0.05944258904492017, 0.01659847046539653, 0.03645525124738924, 0.08407868954236619, 0.01031947809678968, 0.046987640380393714, 0.06768622071831487, 0.018186837187386118, 0.04293093872547615, 0.05817344230308663, 0.030406820042117033, 0.04848292694077827, 0.03988998490967788, 0.010390978459327016, 0.024108891775540542, 0.06638139151618816, 0.05581031051406171, 0.055362220300594345, 0.032008985144784674, 0.03442692453972995, 0.046188655323931016, 0.024635204354126472, 0.06134777118859347, 0.04059559294546489, 0.04979935591109097, 0.05664174597768579, 0.09660547439125367, 0.08735056631849147, 0.07376941226539202, 0.046377958642551675, 0.03024495206773281, 0.039359686998068355, 0.03404661096283235, 0.062100921204546466, 0.061572760678245686, 0.051163230382371694, 0.063997420220403, 0.05795679826405831, 0.012791162898793118, 0.044472327499534, 0.044939724684809335, 0.04297252497053705, 0.04261402311385609, 0.062465308292303234, 0.05848675107699819, 0.03366577788256109, 0.04720435492345132, 0.0077307626361289294, 0.03916086192475632, 0.05296123155858368, 0.03861080433125608, 0.02719864551181672, 0.04301302025851328, 0.058627083781175315, 0.03613934495660942, 0.08311994606629014, 0.07398143643513322, 0.0950735405785963, 0.03213295349269174, 0.036201629700371996, 0.01933530886162771, 0.03311241773189977, 0.024069969840638805, 0.028694729880953673, 0.054417581341112964, 0.035887456324417144, 0.04370061265944969, 0.08984526604763232, 0.05330285697709769, 0.017376829382556025, 0.05578426113061141, 0.03483831555058714, 0.03894737201335374, 0.029662347587873228, 0.022820888916612603, 0.02359484504268039, 0.011550048930075718, 0.06833841267507523, 0.0322037840669509, 0.02002158209506888, 0.018109637130692136, 0.0513066875282675, 0.018760200073302258, 0.018367552002018783, 0.02876646030927077, 0.022283713151409756, 0.03109090765065048, 0.07166910465457477, 0.0770042187650688, 0.002276824420732737, 0.057665312342578545, 0.07442827612976544, 0.03480484097963199, 0.010363355722802226, 0.013312505870999303, 0.09209027761244215, 0.08377083926461637, 0.014517413237626897, 0.025984838866861537, 0.053947720225551166, 0.08690377857419662, 0.029318831548152957, 0.03248373330279719, 0.03485157772956882, 0.06231465973542072, 0.018021007999777794, 0.07739409862551838, 0.03113061626208946, 0.05310730106430128, 0.0938054254220333, 0.01621341085410677, 0.01565795042552054, 0.05146979303390253, 0.03432121673540678, 0.018612861495057587, 0.01451634361728793, 0.0423465122730704, 0.05940986033238005, 0.07211123171146028, 0.03862664176267572, 0.008668848895467818, 0.03129601129330695, 0.07051143591525033, 0.08749502536375076, 0.0683260930236429, 0.044762403340428136, 0.018886842008214444, 0.017372205802530516, 0.03315233043394983, 0.06422849532100372, 0.03216567849449348, 0.04411310947034508, 0.021907297705183737, 0.00805604642664548, 0.04595351325406227, 0.07634375186171383, 0.012325965253694449, 0.02571261538832914, 0.01609719609405147, 0.03775504126679152, 0.04520051908912137, 0.03203245927579701, 0.06007310657878406, 0.04067840549396351, 0.11979044240433723, 0.024893317749956623, 0.06622794506256469, 0.02388755550782662, 0.031142575971898623, 0.06253153755096719, 0.02842302590579493, 0.029493785441445652, 0.027890946839761455, 0.008665664154250408, 0.04028677045425866, 0.03269820655987132, 0.03375870219315402, 0.09320001845480874, 0.004008909663753002, 0.056827765292837285, 0.058104912386625074, 0.048082085559144616, 0.020502517909335438, 0.08046925431699492, 0.013098927829560125, 0.09470761724514887, 0.031378771891468205, 0.016297062029480003, 0.06912248427397572, 0.031970207928679883, 0.018425586094963364, 0.008825461536616785, 0.006737814965163125, 0.04732006687845569, 0.03125536757579539, 0.047857585886958987, 0.04273967984772753, 0.05306360711983871, 0.07989181889570318, 0.04553801074507646, 0.047381442491314374, 0.04422330726811197, 0.03498534242680762, 0.05209690410993062, 0.03735967693501152, 0.031576108958688565, 0.029830714920535684, 0.05616068956442177, 0.028600657096831128, 0.045394004409899935, 0.021136042996658944, 0.04209593353152741, 0.033184710337081924, 0.09673484557424672, 0.028828960275859572, 0.01924491527461214, 0.05272705056995619, 0.031126729263633024, 0.08971672607003711, 0.009153558530670125, 0.05048239152529277, 0.038856347600813024, 0.07101323164533824, 0.009388872222189093, 0.02280822787724901, 0.06289634024142288, 0.03185128247423563, 0.042979493737220764, 0.043609168933471665, 0.05967360106296837, 0.05285149389237631, 0.019306463436805643, 0.08413202769588679, 0.05678838322637603, 0.03934895183192566, 0.021115459530847147, 0.035717719729291275, 0.044951064701308496, 0.03672911487228703, 0.02782563227810897, 0.050265276222489774, 0.057091398412012495, 0.007765452473904588, 0.06341784741380252, 0.02174931301851757, 0.015729252263554372, 0.004002925170425442, 0.04672227434639353, 0.009934317367878975, 0.004846179335800116, 0.061244668322615325, 0.09757491963682696, 0.03790787173784338, 0.021907501795794815, 0.02146296090359101, 0.06457579816924408, 0.10048368581919931, 0.1007874691276811, 0.0877856726583559, 0.11496787774376571, 0.17545613431138918, 0.1439490116899833, 0.17485180345829576, 0.19159091461915523, 0.08047183699090965, 0.0922113738488406, 0.1535214253817685, 0.08444142164080404, 0.12037780034006573, 0.07744765942334197, 0.08302045374875888, 0.1509508484741673, 0.09052363355294801, 0.21381963277235627, 0.09652671767980792, 0.12698784994427115, 0.27143742539919913, 0.19349593349033967, 0.218381124723237, 0.13458450324833393, 0.15829241077881306, 0.08365377289010212, 0.10163891289266758, 0.19226732285460457, 0.09297777491156012, 0.09180646549793892, 0.11416272915084846, 0.184276188374497, 0.10881366266403347, 0.12038859858876094, 0.12941771565238014, 0.174622064223513, 0.16499655728694052, 0.08892881756764837, 0.0797065936785657, 0.14968220639275387, 0.12978512328118086, 0.21870419644983485, 0.13307031418662518, 0.1859270958811976, 0.12672515935264528, 0.18920774484286085, 0.19839027867419645, 0.10184392376686446, 0.13985568133648485, 0.12027535427478142, 0.10953238073852845, 0.17236253625014797, 0.2176733681699261, 0.18507248314563185, 0.11803720757598057, 0.1934748564963229, 0.13906256295740604, 0.17506203905213624, 0.18396604486042634, 0.10114439020981081, 0.13879329693736508, 0.12159937541582622, 0.19978505617473274, 0.16956734092673287, 0.20358424371806905, 0.19098769698757678, 0.14945874572731555, 0.12112491298466921, 0.13238822109997272, 0.19289997406303883, 0.2493358519859612, 0.0847194078960456, 0.21399169228971004, 0.25652669894043356, 0.12472153874114156, 0.13202403439208865, 0.11680470066494308, 0.12265440513147041, 0.08453176327748224, 0.12837545829825103, 0.18629223253810778, 0.059169289452256635, 0.15381727513158694, 0.14802214078372344, 0.20961067581083626, 0.07598346885060892, 0.30255517282057554, 0.16245799663010985, 0.13695143483346328, 0.17293133307248354, 0.10168491120566614, 0.08150475812726654, 0.16463698673760518, 0.14514646696625277, 0.13617636548588052, 0.11611423615249805, 0.1196961896494031, 0.15906313114101067, 0.15105270082131028, 0.14371210330864415, 0.12277801724849269, 0.1674611703492701, 0.10953919365420006, 0.15464943047845736, 0.14178731362335384, 0.2736492332769558, 0.15162825118750334, 0.1608695779577829, 0.23032366123516113, 0.14081864763284102, 0.11838718957733363, 0.10407276393380016, 0.08866297284839675, 0.10486338869668543, 0.0745037748129107, 0.13732477964367718, 0.15581488434690982, 0.09953576285624877, 0.1050754202879034, 0.18137600884074345, 0.1883247375371866, 0.09430581107153557, 0.15206203650450334, 0.287506555323489, 0.15322567953262478, 0.13068482890957966, 0.08239032584242523, 0.12106028676498681, 0.1132826236425899, 0.11168925484525971, 0.11077506991568953, 0.20848017709795386, 0.11670637351926416, 0.21507024066522717, 0.10225072459434159, 0.12323368107900023, 0.24142500304151326, 0.13595731317764148, 0.12911422178149223, 0.17014431621646509, 0.1237371243769303, 0.13898621080443263, 0.2391788040404208, 0.23054528137436137, 0.13504367001587525, 0.2099116166937165, 0.05669294303515926, 0.08988169065560214, 0.11257288555498235, 0.17489284422481433, 0.1408958458341658, 0.06963009844184853, 0.1979814443620853, 0.11321372265229002, 0.1682608196279034, 0.12582871917402372, 0.13473728176904842, 0.1162436295999214, 0.10049894437543117, 0.12119270075345412, 0.13946764200227335, 0.08264853386208415, 0.09278274592361413, 0.11032909853383899, 0.04803924879524857, 0.16953795187873766, 0.11394986635423265, 0.06468821869930252, 0.11973333414061926, 0.09063371631782502, 0.14565865276381373, 0.21750216954387724, 0.2538449037820101, 0.2197995618917048, 0.11877126584295183, 0.15908983361441642], [0.054267871601041406, 0.005237714649410918, 0.02517162498406833, 0.07184604750364088, 0.02524724797694944, 0.07519815786508843, 0.05566376232309267, 0.05606242921203375, 0.02785972654237412, 0.08202882570913061, 0.0236108884200803, 0.01722397850244306, 0.03749978328414727, 0.03905713194399141, 0.03786494962696452, 0.028421766110113822, 0.0188411053022719, 0.017663185208220966, 0.025875830360746477, 0.049209174103452824, 0.050466413085814565, 0.01360500853479607, 0.021051148723927327, 0.029172400245442986, 0.008691489965713117, 0.04590684700815473, 0.01585302765306551, 0.03239573685277719, 0.051463425406836905, 0.03325490266433917, 0.049823702065623365, 0.08815662033157423, 0.030488578740914818, 0.029298448462213855, 0.037349939957493916, 0.03785945773415733, 0.025527276993670966, 0.019531185753294267, 0.025566317672200967, 0.055717200666549616, 0.02958197299449239, 0.020354502121335827, 0.06920914485817775, 0.05295526840200182, 0.012855879103881307, 0.05028641258832067, 0.06375977711286396, 0.020640902475861367, 0.04950971051584929, 0.03542824131727684, 0.04460359115910251, 0.030518962266796734, 0.03982517315307632, 0.06710465153446421, 0.06746426661266014, 0.08765322156250477, 0.015990937245078385, 0.012134794505982427, 0.031713851567474194, 0.05443256159196608, 0.023420852230628952, 0.07170903219957836, 0.1109783590072766, 0.06805756172980182, 0.03524504958477337, 0.02362414317758521, 0.036926381435478106, 0.06622722517931834, 0.04070492614118848, 0.011229919819015777, 0.021860889355593827, 0.03225082880817354, 0.012066313756804448, 0.013675123864231864, 0.04703083337517455, 0.018711858429014683, 0.0125755133376515, 0.06955789489438757, 0.03730259835720062, 0.026409965175844263, 0.034889275120804086, 0.029988109599798918, 0.04516130400588736, 0.05100841837702319, 0.051470427570166066, 0.023788434264133684, 0.0249264323792886, 0.017076092590286862, 0.0169649374220171, 0.016940702589636203, 0.010714210675359936, 0.015105979018699145, 0.04640017112251371, 0.03394075101823546, 0.037451922180480324, 0.036187788646202534, 0.07369829225353897, 0.09569006491801701, 0.060282254926278256, 0.06823534320574254, 0.067723684333032, 0.03390782934729941, 0.046599107517977245, 0.14768722438020632, 0.07390001541352831, 0.02121657715179026, 0.04847093383432366, 0.036591609750757925, 0.01557344392494997, 0.04099828969629016, 0.07116784327081405, 0.05436046565591823, 0.0431442134140525, 0.015572106203762814, 0.025730773886607494, 0.03261177604144905, 0.041264063911512494, 0.05234245480096433, 0.0385932933568256, 0.03920352057320997, 0.02309596966370009, 0.06466944236308336, 0.03415491999476217, 0.00916402374059544, 0.07340404554270208, 0.05524489046365488, 0.05812457930005621, 0.010153410494240234, 0.05663295152771752, 0.06360267929267138, 0.028482457091740798, 0.03638562666310463, 0.00999478756057215, 0.07283804661710747, 0.03585821199521888, 0.026358374780102167, 0.040436331764794886, 0.039100747962947935, 0.003451039806350309, 0.015817983439774252, 0.06219043905730359, 0.004496507181102061, 0.05354985856683925, 0.024347876315005124, 0.009242387113772565, 0.030369334162969608, 0.013048800392425619, 0.0436108424764825, 0.09591244204784743, 0.05699845925846603, 0.10719674552092329, 0.02944023577583721, 0.02892604432418011, 0.0806596819893457, 0.02228270939667709, 0.02818527333147358, 0.005187336273593246, 0.05705063224013429, 0.11061746001360007, 0.02693830567295663, 0.08422995408182032, 0.025138341516139917, 0.029932251854916103, 0.008775692185736261, 0.050310079677728936, 0.06605051981750876, 0.07457917701685801, 0.06337835031445138, 0.015347446969826706, 0.045704674848821014, 0.021105325504322536, 0.03336864050652366, 0.05048936029197648, 0.05163328074559104, 0.03774136719584931, 0.04722774370748084, 0.008851347647578223, 0.07639081886736676, 0.09838170095463283, 0.14146603789413348, 0.03157020146318246, 0.07113190848031081, 0.06751613531378098, 0.028428656951291487, 0.024723171118239406, 0.031257931696018204, 0.05199144492507912, 0.008030580556805944, 0.011389329429221107, 0.033606480283197016, 0.035630387501441874, 0.02729506162722828, 0.026253908217768185, 0.04460887525056023, 0.024328276194864884, 0.0429719164094422, 0.0682726212835405, 0.03587222374335397, 0.031873550615273416, 0.07663458469323814, 0.04112448819796555, 0.06570292011019774, 0.017114502443291713, 0.09278154364437796, 0.01826232844905462, 0.00041958994529522897, 0.02823714388796361, 0.030750059631827753, 0.04595151316607371, 0.03687333643028978, 0.016050470476329792, 0.014800729040871374, 0.04674870222515892, 0.016643175586068537, 0.025874442544591147, 0.0475136969180312, 0.03757130034500733, 0.07079173024976626, 0.0398853761726059, 0.006560503361470182, 0.055625920213060454, 0.04120052864891477, 0.03516905737342313, 0.018117704275937285, 0.09628693718696013, 0.04206738311040681, 0.007964855958562111, 0.023530176149506588, 0.01608608985407045, 0.045124541720724665, 0.04474419474718161, 0.02197071793489158, 0.02506137894670246, 0.014933568836568156, 0.044933883982594125, 0.001733949193294393, 0.03452350021689199, 0.0684982564416714, 0.023995743940758985, 0.01198804593514069, 0.04226460514473729, 0.011471719881228637, 0.025966567191062495, 0.07973501793458126, 0.03621779367676936, 0.0444142767082667, 0.022560860779776704, 0.06447572697652504, 0.011040061745006824, 0.02481808067386737, 0.0410884680604795, 0.013037105072726263, 0.018647020697244443, 0.016847164151840843, 0.03679138848383445, 0.005388501895140507, 0.08713612274732441, 0.029481758938345592, 0.08620636013802141, 0.009920622887875652, 0.05559743287449237, 0.010421499282529112, 0.10402577114291489, 0.042954706004820764, 0.03028674611414317, 0.04399744575493969, 0.08514137822203338, 0.028282440871407744, 0.005864302511326969, 0.02313621447683545, 0.028884057319373824, 0.03301752301922534, 0.0352383368590381, 0.023168640764197335, 0.00757711162805208, 0.11008643108652905, 0.05621533018711489, 0.013795370341540547, 0.06573333332198672, 0.14485504041658714, 0.022676847329421435, 0.07576175223221071, 0.015591296287311707, 0.018763133411994204, 0.02999268122948706, 0.04873664496699348, 0.07335079644690268, 0.042742956429719925, 0.04014566591649782, 0.0689097327995114, 0.06310719181783497, 0.03593697241740301, 0.016873478853085544, 0.02424578462523641, 0.03897773327480536, 0.05116085922054481, 0.016754566386225633, 0.05968710072920658, 0.059141496021766216, 0.030548950599040836, 0.016384865521104075, 0.0335964798432542, 0.05188106901186984, 0.024264234416477848, 0.018441512584104203, 0.03918229143891949, 0.035916043852921575, 0.02749587751168292, 0.03935428416298237, 0.01619141174160177, 0.04141317251196597, 0.008038510404730914, 0.032161177368834615, 0.015316229455493158, 0.03477569312963169, 0.01151210570242256, 0.022571740664716344, 0.011093944449385162, 0.019130149557895493, 0.039405073039233685, 0.02135996564902598, 0.023254247498698533, 0.011516890699567739, 0.013722972907999065, 0.06255998407141306, 0.0905390628031455, 0.03838081276626326, 0.024280847392219584, 0.060370043574948795, 0.0456543275504373, 0.030865678818372544, 0.08618352425401099, 0.039280459022847936, 0.03681071400933433, 0.03868746818625368, 0.07883692276664078, 0.01601099007530138, 0.056096456683008, 0.043284197308821604, 0.010076683556690114, 0.03595275047700852, 0.0381061476218747, 0.06697419681586325, 0.03383471295819618, 0.1309376340941526, 0.03865753365971614, 0.011686158813972725, 0.028312058129813522, 0.03582319004635792, 0.030670612723042723, 0.040170231004594825, 0.05236251876340248, 0.11195208644494414, 0.1575984136434272, 0.16345162846846506, 0.1656549610197544, 0.14265690289903432, 0.19417357369093224, 0.14389336545718834, 0.13622199272504076, 0.15925223036902025, 0.15914832969428971, 0.1277239268529229, 0.09519687067950144, 0.09354918409371749, 0.10778848954942077, 0.23289031960302964, 0.13214291160693392, 0.08755233400734141, 0.13557443919125944, 0.10294653257005848, 0.11662746837828308, 0.1504621293861419, 0.09240085157216527, 0.10281466034939513, 0.18573191104223952, 0.13211085082730278, 0.11457655069534667, 0.13610020629130304, 0.27083477179985493, 0.18049473816063255, 0.054806967673357576, 0.14165031316224486, 0.1283863084972836, 0.1837881372193806, 0.1615292878705077, 0.08362063599633984, 0.0871287086920347, 0.1480707959854044, 0.10607439558953047, 0.11146168268169276, 0.16497165081091225, 0.1289071625797078, 0.1278411119710654, 0.08024822047445923, 0.12626976269530132, 0.12728116154903546, 0.1362934912322089, 0.16527682193554938, 0.06399441452231258, 0.2728225995087996, 0.1960099142161198, 0.10341501329094172, 0.08905399561626837, 0.09590475339791737, 0.16314384498400614, 0.18257684831041843, 0.12425071283360012, 0.1274405897129327, 0.18885188503190875, 0.13802548579405993, 0.18185386288678274, 0.23193329048808664, 0.1423123385757208, 0.4239393031457439, 0.16127246024552733, 0.1497049309546128, 0.11524664325406775, 0.09119042355450802, 0.19733421737328172, 0.10662655346095562, 0.24951931089162827, 0.09262057181331329, 0.17816601233789697, 0.08165298728272319, 0.15093447669642046, 0.21669923997251317, 0.13091957021970302, 0.11212960816919804, 0.13465852505760267, 0.16585679550189525, 0.10775773494970053, 0.17153912340290844, 0.11893326925928704, 0.15264500834746286, 0.16468435060232878, 0.1269062582287006, 0.17373938346281648, 0.16189181216759607, 0.1474102251813747, 0.0836769946909044, 0.0718515542394016, 0.15144920063903555, 0.14011991559527814, 0.15602801431668922, 0.106720353505807, 0.14747839886695147, 0.16408613504609093, 0.12499077507527545, 0.2805119619006291, 0.10927409108262509, 0.22317660099361092, 0.16922673967201263, 0.12461060250643641, 0.1338119720458053, 0.209176549105905, 0.17178005422465503, 0.1007531893264968, 0.0904038360749837, 0.10816711845109239, 0.16364375565899536, 0.14272871310822666, 0.10100778308697045, 0.1347050428739749, 0.13214932376286015, 0.10663652050425299, 0.12099931191187352, 0.09408555648406036, 0.13122821459546685, 0.1375382361584343, 0.16969898308161646, 0.14353008416946977, 0.09618651718483306, 0.1422990096034482, 0.1980934344464913, 0.08936395359341986, 0.1853882521390915, 0.2376754948636517, 0.1353736882447265, 0.07656695277546532, 0.09792340249987319, 0.1485477594542317, 0.10374039309681393, 0.1322303366032429, 0.16488882713019848, 0.1727724095690064, 0.16540289798285812, 0.10090642797877081, 0.10435622723889537, 0.20623369608074427, 0.1277448405744508, 0.10633942394633777, 0.13075441267574206, 0.10396053636213765, 0.1579010911518708, 0.14872725529130548, 0.11232684875722043, 0.11633368922048248, 0.11367012863047421, 0.13238560874015093, 0.13706207420909777, 0.21343238011468202, 0.1259636416216381, 0.07098235830198973, 0.10315807434380986, 0.1504401321290061, 0.12128184753237292, 0.14129728835541755, 0.1761490330682136, 0.18801000755047426, 0.16915237647481263, 0.10278188710799441, 0.15794281469425187, 0.18438497238093987, 0.19487327052047476, 0.08831345097860321, 0.19175663619535044, 0.14243117126170546, 0.161993412184529, 0.09532886906526983, 0.3488884319085628, 0.18016276066191494, 0.25289706245530397, 0.17464704491430894, 0.15099717333214357, 0.21629551163641736, 0.10225431658909656, 0.24410743644693866], [0.02969992066937266, 0.07223141510621645, 0.0525637817918323, 0.0006152185653718334, 0.0671830445935484, 0.027349956435500644, 0.024127818396664225, 0.04148333515331615, 0.025382643543707673, 0.019686086816363968, 0.03612847620388493, 0.0290876321378164, 0.04184049001196399, 0.07170430471887812, 0.045215773934614845, 0.04654750970075838, 0.017860088119050488, 0.013738332581851864, 0.06388137800968252, 0.05999582674121484, 0.02963487699162215, 0.017121712407970335, 0.022230668146221433, 0.015037438897707034, 0.0529535020905314, 0.01678605014603818, 0.06724648337694816, 0.019012354023288935, 0.03906994141289033, 0.029352294986892957, 0.011243004810239654, 0.041064077377086505, 0.0437089321349049, 0.003802025562436029, 0.026036136114271358, 0.0966291266377084, 0.029001630209677387, 0.02961667581985239, 0.051152706728316844, 0.11635619855951518, 0.03630524835898541, 0.07731179444817826, 0.02308672250364907, 0.039720404165564105, 0.06384177700965665, 0.10211028798948973, 0.04049979652336333, 0.01331516461505089, 0.02358298923354596, 0.020870274347544182, 0.029037693020654842, 0.07003853199421428, 0.007525421042373637, 0.026897515381278936, 0.06344446082948707, 0.03301376033050474, 0.034865563502535224, 0.025643603075877763, 0.02703895759623265, 0.02129454347596038, 0.04000860237283632, 0.01576982733240584, 0.05134143117174972, 0.07313770358450711, 0.024895581300370395, 0.07680059570702724, 0.02847804131306475, 0.03492292409646325, 0.030347641186381225, 0.01807685646781465, 0.029338452077354304, 0.03459235296759289, 0.01301183772739023, 0.05168097857676912, 0.02706230185140157, 0.05805353350297082, 0.03438711573835462, 0.01399507485984941, 0.030857212768751197, 0.022056834895920474, 0.02129648048139643, 0.02076052925986005, 0.036047155372216366, 0.05786861256638076, 0.00561970687158464, 0.0806870598171372, 0.07080935625708662, 0.07954386295750737, 0.03742281514860224, 0.03995744242274668, 0.026205444119113963, 0.020570060769387055, 0.03006642287800787, 0.013010346938244766, 0.01664960444031749, 0.025902729503286537, 0.05901415832340717, 0.09578045108355582, 0.03433543628489133, 0.08426545100519434, 0.03808706329436973, 0.023376171229756437, 0.019827330506814178, 0.041751669778022915, 0.046148327019182034, 0.04506057972321287, 0.028491047451097984, 0.010403907599538798, 0.06067017551686149, 0.03938496083719656, 0.04973894880095031, 0.030609877212555148, 0.0038276540090009803, 0.07609733656863682, 0.11086498110671528, 0.03551099820469972, 0.02043383956333855, 0.07229115057270974, 0.04875388876826037, 0.016341991649824195, 0.059479262272361666, 0.0835589857888408, 0.025533702137181535, 0.06655302058788948, 0.0811156872077845, 0.020342085990705527, 0.028015674033667892, 0.05350934843590949, 0.032652260197210126, 0.045711331913480535, 0.051090648339595646, 0.006445739036280429, 0.06685727887088433, 0.046780837219557725, 0.019147885031998158, 0.04034404570120387, 0.05857196818396915, 0.07544944164692424, 0.009489417461736593, 0.038430243512266316, 0.06241788505576551, 0.04887393857643474, 0.05270851543173194, 0.07049227366223931, 0.023587562718603294, 0.017759089241735637, 0.020372491781017743, 0.03219301921490114, 0.046836850815452635, 0.0970331666758284, 0.028020000754622743, 0.03302060293208342, 0.04230495200317819, 0.0280988001395599, 0.09247632799088024, 0.03569287633581553, 0.041147977171931416, 0.009397730682394467, 0.018935224470624235, 0.047969987863325514, 0.071840132586658, 0.024698069828446023, 0.02669737114047166, 0.020746810660057236, 0.06250009275390767, 0.019523074079188518, 0.01269892785785487, 0.023442532219632994, 0.029699057922698557, 0.03079856454860419, 0.07008136875811033, 0.03064344455196988, 0.054231309695751406, 0.04499882190430071, 0.05033508634369355, 0.027511800290085375, 0.0031698256725576357, 0.05446470771858003, 0.04979280274710618, 0.04314413177780807, 0.0790816088556312, 0.04843172246182803, 0.0338327388453763, 0.02231587412097724, 0.05405915740993805, 0.027804833589470945, 0.0630096513486933, 0.026297175427316688, 0.039242093698703684, 0.09811526993871666, 0.07061543306917883, 0.04925131695927121, 0.03812822651525494, 0.03835936469840817, 0.0314193413942121, 0.04067321046022698, 0.010508574541745475, 0.03571119254047517, 0.013863365911674919, 0.017344961561320815, 0.0383236377092544, 0.016570556435908657, 0.040981335332617164, 0.0564794494130183, 0.03454708567005582, 0.012583022016769974, 0.06391685266862623, 0.023060979256115388, 0.05781439867860172, 0.022105606985860504, 0.052528307132888585, 0.06853977960417978, 0.04390295180201065, 0.008810338422335917, 0.09790719399461523, 0.052344740615808405, 0.032035988187999465, 0.06564659852301702, 0.0728538840485271, 0.04770624713273719, 0.019067781322519295, 0.06488969695055857, 0.012978628474229481, 0.02009061110584298, 0.1038270239951089, 0.0067858917554985965, 0.03950715545215644, 0.031203528560581617, 0.03400571862584911, 0.020041419702465646, 0.0370505204773508, 0.023774836263328325, 0.12713909964077175, 0.05535909585887566, 0.005228762493061367, 0.009051714532688493, 0.07010406363406219, 0.020895672496408224, 0.009115119919442805, 0.07218480081064627, 0.023791029925632756, 0.08531680708983913, 0.010271963947161566, 0.03125692979665473, 0.01630918686714722, 0.056159980813390575, 0.028922884630446788, 0.008585104023950407, 0.04153854722972028, 0.04266245196049567, 0.019640980935946573, 0.03926829151168931, 0.1121273817261681, 0.05041065924160648, 0.03999185952125117, 0.0340544999926351, 0.024230362796515692, 0.05970439648081083, 0.03779594844672829, 0.10447767228470184, 0.028153544662927743, 0.03802129045652691, 0.048839198643690906, 0.028343779376882594, 0.037892019463470206, 0.028305326850386336, 0.009609714961698046, 0.05173809426196385, 0.008393303378397832, 0.09844952583080158, 0.0143343152012676, 0.05432658661447931, 0.07343245495576411, 0.06181865646794904, 0.06411791531718336, 0.0686308708100114, 0.010319840821466642, 0.03500382190395612, 0.021578962296189275, 0.04407505584822502, 0.03795591837842949, 0.024289166867674794, 0.039750297873979434, 0.013907389184169006, 0.08538943366147578, 0.012211283028591424, 0.006117260300015914, 0.05368694808566943, 0.02320454215805512, 0.07377447371254675, 0.0562532168260077, 0.019861730906995945, 0.015472251161554595, 0.03770104260183871, 0.03897710616001859, 0.047141094255493954, 0.09595472962246276, 0.06954081807634793, 0.07305224527954124, 0.02736521313636331, 0.024621244556328747, 0.05668142119247932, 0.006460195609179209, 0.00815001623777789, 0.03708308591740206, 0.019147137318213936, 0.03219786914996803, 0.04469976236578077, 0.09617268355214037, 0.04334296056185849, 0.046852332015987486, 0.020017168171762023, 0.04852864694839809, 0.020756621852342505, 0.02017238650296349, 0.03659831876575481, 0.06275699459365569, 0.020670681151386816, 0.031163289313553832, 0.02417974275886081, 0.043591049397946335, 0.016665412185830064, 0.05208351576584391, 0.023657460042159073, 0.03792667033849284, 0.07146158532123081, 0.007009168739386951, 0.03488269598165061, 0.028882565602543764, 0.0275136538039078, 0.09827871312154457, 0.01691205568931764, 0.016258574250969104, 0.04098781428183429, 0.026453358550497796, 0.08123492807499133, 0.05823076578963082, 0.040415811381535605, 0.047008824985823594, 0.07009323569945991, 0.061898945714347064, 0.016442942287540063, 0.03172402270138264, 0.010520640007598558, 0.04623148837708868, 0.033238508622162044, 0.03080145521380473, 0.03908466191205662, 0.022390734557120595, 0.039965743344509974, 0.027174687129445374, 0.010296933505742345, 0.09857520111836493, 0.11275844473857433, 0.14553085493389517, 0.1529583430965431, 0.11611128982622176, 0.12687905109487474, 0.11926267892704345, 0.12622922658920288, 0.1344087181496434, 0.16282449883874506, 0.12108273673220538, 0.1353369519347325, 0.1559691471629776, 0.20529274188447744, 0.16431449388619512, 0.20754613971803337, 0.07704004223342054, 0.18272282875841483, 0.16219466779148206, 0.13003403961192816, 0.09336160626844503, 0.14633740618592128, 0.10604804934700951, 0.0902925584523473, 0.1167506723140832, 0.08905145747121423, 0.15256829996360466, 0.1510430232156068, 0.10812819280545227, 0.10204778431216255, 0.10676904581487179, 0.06937742684385739, 0.11324838837026618, 0.10672975651687011, 0.1850591244874522, 0.22073334694141522, 0.1447435253066942, 0.11604715342400596, 0.17120540927862749, 0.22846456646220759, 0.13892507267883047, 0.1804758727666922, 0.0962311276816763, 0.15795474842889234, 0.08899120992282405, 0.1931162062101066, 0.1308070309460163, 0.12648240284761414, 0.18419088592054322, 0.0758862475049682, 0.10643534653354436, 0.17523163463920355, 0.1345953089185059, 0.09691892788396217, 0.13683427940122783, 0.11880481833941303, 0.2997392864199355, 0.12043316455674358, 0.1220239803660661, 0.11787180512328632, 0.12998879828955978, 0.09796523736440577, 0.13895480311475694, 0.1968722156016156, 0.09486015827860683, 0.16426153422798961, 0.1515699629089795, 0.16470254806336015, 0.10840439048479311, 0.12468881002860144, 0.09123750540311448, 0.14032917155418545, 0.10787872728542425, 0.097933005890809, 0.15621117636328563, 0.11708870573784225, 0.28504624671768397, 0.12624642957234755, 0.14214255003025755, 0.18102730333339423, 0.07769734016619623, 0.20434415841009468, 0.20679204346379265, 0.2399397428962402, 0.14711857598740608, 0.15455499960808083, 0.15561797772534192, 0.16907495562918484, 0.1055242786242161, 0.1483807762269862, 0.13937499228632078, 0.18503654835512862, 0.07488434072001837, 0.19387414678931236, 0.09354325433378108, 0.184082621417474, 0.10278078872943297, 0.1766491070156917, 0.11509307805681601, 0.15578988881316036, 0.12366062379442155, 0.24488838360412046, 0.13981232506921515, 0.1310111809289083, 0.17202019836986437, 0.06452691290178336, 0.13822582113789394, 0.18192761752288789, 0.12618857173947617, 0.10234781235340051, 0.11964268822339363, 0.16899835114600137, 0.10737669406807981, 0.18889893719460815, 0.2126799017423764, 0.1337014662567526, 0.09563558385707438, 0.1565405711880885, 0.12251404274138622, 0.13022846746025607, 0.15143870667088777, 0.18109253811417148, 0.1570466862176545, 0.23388954723486677, 0.11796338614658453, 0.11941997712710872, 0.09452220649109222, 0.1067782707104925, 0.12352883321000263, 0.102017230092315, 0.11949262596317567, 0.09577797973179258, 0.11938430208829232, 0.17081726604374126, 0.1670234664925374, 0.10587879514787346, 0.1606758774141781, 0.1297219961998053, 0.10971756142680533, 0.24161531939171255, 0.16303667885949835, 0.1082190391025506, 0.1561153947841376, 0.13576656638178974, 0.06158472409879323, 0.14322270144475624, 0.09339024574728683, 0.08573441358748823, 0.09182539768517017, 0.16100089356768876, 0.15559348685201257, 0.1009341843018774, 0.16167624795343727, 0.12874826876213774, 0.2825493650743738, 0.059996220079483464, 0.16241226549027488, 0.15301520645152777, 0.12046567804645747, 0.16851663793204352, 0.1247635591425933, 0.13158101675799116, 0.06881978450110182, 0.16528752370504662, 0.24617834016680717, 0.10260077338898554, 0.09349905943963677, 0.11341349396388978, 0.19611761468695477, 0.10132697338121943, 0.19198043824872002, 0.12839134025853127, 0.08580005654948764, 0.11216626284294762, 0.18128619412891567, 0.06160954893857706], [0.032055922274594195, 0.03965724739828147, 0.02824350965966005, 0.11435764681664295, 0.0817158175050281, 0.08907217081286944, 0.04123365812120028, 0.013107972754369257, 0.002627491517159797, 0.07869713183026761, 0.030015133052074816, 0.014534205256495625, 0.016710595991753507, 0.04306490009184927, 0.022415954590542242, 0.018383582391834352, 0.06440684825065546, 0.0033760710630303947, 0.014758689158043126, 0.009624876111047342, 0.041938794893212616, 0.036149104198557325, 0.056507639892515726, 0.055852316072559915, 0.06082768151827622, 0.029626761606778018, 0.05884956110094208, 0.08821430747047998, 0.054719624313293025, 0.1107763167237863, 0.0187743769492954, 0.030931870969652664, 0.057780827628448606, 0.032565043002250604, 0.03488778711471241, 0.012681277730735019, 0.02161763004551176, 0.07946026744320989, 0.03874705893395003, 0.05079963739262894, 0.051426703939796425, 0.06147776948637329, 0.06569725752342492, 0.0041197568407369545, 0.04001639492344111, 0.022788698261138052, 0.06634451419813558, 0.04229440979543142, 0.03129019285552204, 0.05294971342664212, 0.02664891075255582, 0.026548307068878785, 0.02126650513673667, 0.0282750806218246, 0.04396704367536586, 0.02034055160038406, 0.05241822436801158, 0.04022720568173099, 0.03334049084514845, 0.05141446592460852, 0.013122766540618613, 0.020414172649907414, 0.07420831840136088, 0.03654826832644176, 0.034783879018505104, 0.08287986129289493, 0.0313114257005509, 0.022902532582520507, 0.04055735007568728, 0.034395817419863306, 0.05345481542462949, 0.06632126271142624, 0.05060178453277331, 0.032676357732270844, 0.04325842623075005, 0.030103589633654337, 0.007882198333390988, 0.06980169782764278, 0.03426743329328019, 0.012644862399611156, 0.05631360167171806, 0.023363027794403024, 0.025089728987950366, 0.04312409379053861, 0.021682256265194155, 0.018595636247482616, 0.0617663016601, 0.04793733707629144, 0.06787742764572613, 0.02396960735495668, 0.01356837148705381, 0.043845465042977594, 0.06517022877233103, 0.10716324497479945, 0.03678304303321056, 0.009997207889682613, 0.03582115285098553, 0.03639164177002385, 0.02621597519464558, 0.08263648880529217, 0.009916401922964724, 0.022643259580945596, 0.011866689019370824, 0.05481686421262566, 0.027604218084889, 0.022851270587125327, 0.06088333888328634, 0.08052167220739648, 0.07555465592304245, 0.0031094436099010636, 0.022180714186106343, 0.03155747734126635, 0.05170079763047397, 0.025813742286118213, 0.027433410941739567, 0.061650162970181555, 0.06227859135833569, 0.05393543768150266, 0.03711029676196631, 0.03107215914496919, 0.10412187184556387, 0.04842225265747402, 0.029232545748527627, 0.036351239250507206, 0.04561602901958395, 0.032453141975565813, 0.06064263441658113, 0.009834909469645936, 0.0572647344233701, 0.033568530561751686, 0.059949687420157716, 0.08827542333165184, 0.06467722749221139, 0.012828229464503238, 0.019069660811510403, 0.046777441893937066, 0.06101805352955125, 0.04501002091274131, 0.07184745016274974, 0.018565158097771928, 0.036189499296597205, 0.009690495880931849, 0.013992163785587763, 0.00863764900714159, 0.060133962688269094, 0.0627616849669721, 0.02222193121269811, 0.08403735933825374, 0.03445228001510259, 0.041802072737482376, 0.011361406122887274, 0.02200988292315742, 0.025258526766265277, 0.05822499930218328, 0.015482645867450628, 0.034310930568608455, 0.04149498316110112, 0.03389631492609624, 0.10017085573053919, 0.04139919787121471, 0.0895896258589346, 0.0849954126169905, 0.05630485917208716, 0.02060391012491891, 0.03473106036835816, 0.006197795382831828, 0.06787159436498769, 0.04492403568292502, 0.04038355764350854, 0.05392140366893727, 0.05080612005258445, 0.06545565134729259, 0.012190073375677457, 0.026105447141162585, 0.07277787328348495, 0.031966756941983476, 0.0850848265690729, 0.05469936739245895, 0.035478173012961634, 0.012172818442195421, 0.023412831469613593, 0.052386375100468285, 0.04707454958406743, 0.0846546035609208, 0.00864363350046915, 0.01809013348974986, 0.010639022766554262, 0.027765035920310766, 0.05301256591337733, 0.02945426051155664, 0.04310733238526154, 0.02358031564654084, 0.03604381941840984, 0.015135337453102693, 0.026566979504423216, 0.03856351839203853, 0.048851544270291924, 0.03106909407506464, 0.0563097202393692, 0.030854559590807185, 0.04793301777681336, 0.04385261934658047, 0.06572941478225403, 0.026003370294347405, 0.03063325486436952, 0.04236274675349705, 0.04006554365332704, 0.028113895423302893, 0.03307543651317246, 0.015250496508087963, 0.0689457418047823, 0.05383029019867536, 0.03240512502088677, 0.019804685725830495, 0.037314201836124994, 0.04513450876402203, 0.03648903009889182, 0.044959762672078796, 0.04398170109197963, 0.04808635661902372, 0.04812108170881402, 0.055535790088470094, 0.03316616035590414, 0.027412480521888938, 0.016143049688253086, 0.020989841759728733, 0.05631245134281926, 0.04559491491818335, 0.03228841858799569, 0.03757458063773811, 0.014096391005296027, 0.042886105584329925, 0.01469070100938552, 0.04714643771876581, 0.027337610808899626, 0.09650057181715965, 0.01682649348367704, 0.01143175986726419, 0.03783009837206919, 0.029220723336038645, 0.0876953087572474, 0.05108427329105325, 0.05927041078393813, 0.04136919655138627, 0.04114232571737375, 0.00279080667951348, 0.00418288021137414, 0.0500448583625257, 0.016954272759903688, 0.028510235679277685, 0.0886116830224637, 0.020599917370418552, 0.024901425713323988, 0.04038504193886183, 0.07012355243205093, 0.04080848542798776, 0.08994683637865819, 0.0677075055136811, 0.013236025697551668, 0.043220669467700645, 0.053872336575295776, 0.022233204435906373, 0.054099886474432424, 0.04742778590298258, 0.052218898345017806, 0.013258526687423, 0.032392987195635214, 0.0822316695121117, 0.026433884595462587, 0.04931987285090145, 0.03726448536326643, 0.015249963089445373, 0.013181522372178733, 0.016746762703405693, 0.046348729156306945, 0.013083780595479766, 0.022549808345502242, 0.04211292871332262, 0.017947635569726117, 0.03626588484621607, 0.10570142927463166, 0.021728287974838167, 0.08055477941525169, 0.03586348866519984, 0.01993713125557406, 0.02325333836779464, 0.020438238643691875, 0.037759405095130205, 0.03445747133810073, 0.07325638784095645, 0.04287218289391603, 0.10478600495844148, 0.0480918707762612, 0.05126990668941289, 0.015932467140373774, 0.06669270020211115, 0.11025524741853587, 0.034827131385100074, 0.029486696075764485, 0.04217426721879747, 0.10609472301439382, 0.042290684214094654, 0.05231879142229445, 0.03760738356504589, 0.03329084116558079, 0.03559655669960193, 0.07923311830381863, 0.06581781941349618, 0.049006742192432284, 0.028032912268827204, 0.01524384222648223, 0.05328417712007649, 0.009517704420431983, 0.01579567076987587, 0.05448767347843386, 0.07016379167907871, 0.0190759690667619, 0.01494145786637091, 0.011442634186096257, 0.04260407462425064, 0.0335959714720957, 0.052108960298937745, 0.009890527871903032, 0.020076428663742263, 0.031622493188478984, 0.06549039870151319, 0.04623677989002317, 0.048900949041126296, 0.016558231218368746, 0.032953360641840845, 0.05040281102992594, 0.04295152590202633, 0.045079007250024006, 0.006051806585674058, 0.08059229498030618, 0.04931878189381678, 0.056002612109296024, 0.035044369142269716, 0.05513771320693195, 0.06213154221768491, 0.05577630530751776, 0.046742037739022635, 0.05347329861251637, 0.03460408261162229, 0.04555862760753371, 0.03291317705588881, 0.05927818849158939, 0.08872941732988693, 0.022354571556206793, 0.009166805866698269, 0.006799669263273245, 0.020703170521301217, 0.09103525531827472, 0.12665866292081773, 0.09523414875729941, 0.1968863164074719, 0.08942431988543831, 0.22481033520307392, 0.13936470611952245, 0.18736220168648288, 0.07706655174843036, 0.17326052009593695, 0.11843069427413866, 0.1497096658567898, 0.10173033806495368, 0.09645066980738193, 0.11316721225739457, 0.09477432147832587, 0.15966182167176157, 0.20792131021153182, 0.08893921505659819, 0.2136624013655819, 0.1058771475800313, 0.22021028125891462, 0.2508958464022726, 0.19881782995071262, 0.12257948532351293, 0.09718670960864983, 0.10693788441130891, 0.09696451059426181, 0.11084964091423899, 0.15270317788235843, 0.1377089152811095, 0.10828425161889754, 0.13692041306057945, 0.12189236789708957, 0.16397337312810123, 0.1204348640749231, 0.13838572427630424, 0.09463584414334036, 0.11935923976125196, 0.16129107330925763, 0.20742524386150762, 0.18860212265281007, 0.14519170828862116, 0.12047500684275292, 0.24870933091733605, 0.10634424048475921, 0.11882960607181303, 0.10485882448847406, 0.06371383075020276, 0.11924596576136537, 0.17933824943611398, 0.1238473852572497, 0.06600412816624157, 0.2990069944644347, 0.10994989075697958, 0.16247229039436206, 0.16314866894390434, 0.16623425181023777, 0.07926696765935048, 0.12544109544251114, 0.18093392631271854, 0.1186003937618807, 0.15849062358029187, 0.14990556315751746, 0.11166117939865217, 0.1969815487973392, 0.09104189011850394, 0.08298387328977697, 0.1520874327979982, 0.10086178779602051, 0.09288841290981509, 0.18928990059066564, 0.12438974677934311, 0.12303942392463796, 0.16454127937322482, 0.1197493719519116, 0.0717075850116089, 0.16785723972134292, 0.11970415289397351, 0.18558869138360023, 0.1911225452204235, 0.12917963467771187, 0.17036608478520066, 0.12817067006835714, 0.15914595482172444, 0.17275866499403492, 0.12623934948351234, 0.1541294521302916, 0.15553417440969497, 0.09465642389841378, 0.15251232718583196, 0.2118845866061747, 0.1579631050117314, 0.14800717908656225, 0.1165749911160674, 0.0999844356556423, 0.08316150633618236, 0.16048440331360325, 0.1438772608526051, 0.10228952407487668, 0.12637136271223426, 0.1064709918864537, 0.09972259853384458, 0.13141335075488314, 0.19160899333655834, 0.16436919016996399, 0.1389317074790597, 0.13082454563118517, 0.15334132098359987, 0.12637934822123498, 0.12165859880042262, 0.1532908994704485, 0.21262994036078453, 0.14442720712395385, 0.15393003704957664, 0.1291642722208053, 0.1854006905341521, 0.12403082189848647, 0.14389081246918067, 0.11167350647156127, 0.25687740824650973, 0.11963069511693902, 0.12507202540291473, 0.13667620194610208, 0.18489551061065868, 0.1408565862220712, 0.1232549584528897, 0.09404930999153294, 0.2205717220203951, 0.1302122144261375, 0.15378361131297424, 0.26868640270549804, 0.1453802880132571, 0.052183275256538764, 0.05006144907383714, 0.12477026815759018, 0.18963108072057366, 0.10453875103848986, 0.13681778887985274, 0.10997346136718988, 0.20101442380109802, 0.1022653077961877, 0.14340570021886379, 0.07939832779811695, 0.09612244757590815, 0.17120380623964593, 0.08939191029639915, 0.165246230608318, 0.18900406983448192, 0.13014027063036337, 0.11522702086949721, 0.09524921435513534, 0.15127095161005855, 0.16477919707540423, 0.13314981304574758, 0.11604021434322931, 0.11406006786273792, 0.08783732613665052, 0.1332294158055447, 0.1992872977280058, 0.18283455166965723, 0.159650748828426, 0.12715049902908504, 0.15607809444190934, 0.1404888668912463, 0.13586432207375765, 0.1130718165950384, 0.11133832289488055, 0.13359376578591764, 0.2100428135599941, 0.15516109677264467, 0.18693551130127162, 0.062486689566867426, 0.09766900169779547, 0.2048970287432894, 0.14546095946570858], [0.056289919739356264, 0.03641142371634487, 0.03209630252968054, 0.030299492500489578, 0.055269277436309494, 0.0466669954766985, 0.0733994813344907, 0.029716095777985174, 0.02771126732113771, 0.02935085150966188, 0.0534060563222738, 0.016461397644889075, 0.004870576049142983, 0.0205312093385146, 0.028922739911649842, 0.023956736658874433, 0.0247862703690771, 0.06985827916651033, 0.0604319238482276, 0.025009641976794228, 0.010339345390093513, 0.02654964479006594, 0.05559051234740764, 0.04815566207980737, 0.04068185648065992, 0.07843296436476521, 0.01712476077955216, 0.04980485522537492, 0.09178216016152874, 0.0018511660846343148, 0.014242792622098932, 0.05080660615931265, 0.009514566991128959, 0.05258540055365302, 0.02773393065581331, 0.02749828763626283, 0.05589601743849926, 0.05564756123931147, 0.06676142307696864, 0.00922804696529056, 0.03155725840770174, 0.04002599460363854, 0.028484987815318163, 0.05717335377994459, 0.02273870904900832, 0.037860548691242, 0.03362843672221061, 0.02579277104814537, 0.04916067475278396, 0.03422811802010983, 0.034167551348218694, 0.01288988616579445, 0.05592278299445752, 0.02892877357226098, 0.04639415972633287, 0.010839402639248874, 0.027024409646401182, 0.0287897581802099, 0.029339507782424334, 0.01527886603071238, 0.018359115638304502, 0.010926903705694713, 0.028798702915082686, 0.06166052335174754, 0.019048251706408337, 0.027451986898086034, 0.06368214846588671, 0.07758998108329251, 0.024453099867969286, 0.09102613432332873, 0.04791569976077881, 0.04732309484097641, 0.07532399642514065, 0.03197096120857168, 0.014098733408900443, 0.0296330290439073, 0.014630413570557721, 0.03887762868544087, 0.02032922457146924, 0.009499135885562282, 0.024050907777564134, 0.0536346786248032, 0.02243060644104844, 0.038156316804816015, 0.011607550532062305, 0.05068597005447373, 0.04421245335834101, 0.011103267679573037, 0.013487077558238525, 0.017217544082086533, 0.09444293769774958, 0.043527989109861664, 0.039972652739379555, 0.05020563352445606, 0.0035398240925132995, 0.005102281047584256, 0.021102355058246758, 0.057984406157629564, 0.026223426357319113, 0.012406399218889419, 0.06789720588130876, 0.039478104081354104, 0.011360533171682619, 0.04396875803649891, 0.010469998633197974, 0.10102920889039524, 0.018284216239408124, 0.023031471464491915, 0.021278412896208465, 0.009066246711881831, 0.05754360754508525, 0.026912395442195702, 0.037836855626665056, 0.09271594521123916, 0.029444067113217898, 0.05795074604975525, 0.014912632850609953, 0.025909781761583872, 0.03925028329831548, 0.009029130051203538, 0.02520968788303435, 0.03449193296546582, 0.11949336811085232, 0.03333947781356983, 0.05179056039196439, 0.05827439665154088, 0.09689014739706181, 0.037339279006118886, 0.02928524379967712, 0.014512548459606478, 0.027625762631942052, 0.04948724941641558, 0.07556704978924245, 0.060177352352184244, 0.06208458653418347, 0.05293165326293092, 0.03452285083767492, 0.01959037945198361, 0.08073601929936558, 0.02800652335281484, 0.027428598114056513, 0.031043074377521407, 0.02456834612530656, 0.012312743892834987, 0.026286590546078514, 0.02094057243084535, 0.008780512434896082, 0.04535057763860095, 0.01755948491336312, 0.10073111043311656, 0.05839946708874777, 0.04782762909599114, 0.02082353017613059, 0.029079685591568705, 0.06996508906013332, 0.0497394163539866, 0.07998972301720642, 0.057809778809314594, 0.050215826922794804, 0.03814537383732386, 0.0074897070408042055, 0.04602867426001467, 0.057683776976773515, 0.0693883586791344, 0.03429026917729061, 0.05543669110920746, 0.029640112843480892, 0.018174890465161297, 0.017801113353925757, 0.04703530481492635, 0.025278941393480636, 0.018657199252629653, 0.022149935466586612, 0.0660565089492593, 0.047416271481779404, 0.062236908634076826, 0.07623493074788712, 0.07459891072358005, 0.01637036766624078, 0.044734906769008376, 0.029172648864914663, 0.023079471720848233, 0.028678333983407356, 0.04504547701799311, 0.01269109077838948, 0.03456663012912031, 0.04873990299529396, 0.0030369476098712767, 0.05181891414395068, 0.03404209128348157, 0.010595301919238409, 0.013892042497900547, 0.022789768809161615, 0.0379746835824335, 0.05670935192028992, 0.0067538216990215005, 0.09818769613048062, 0.11428112396970391, 0.016793710965430364, 0.025001274261740036, 0.03337192450999282, 0.05530801383429207, 0.005074102627986576, 0.025390530718141235, 0.04156658185820561, 0.07607077510328963, 0.01847065857873531, 0.05131903315486852, 0.031280047696782276, 0.04829961275390815, 0.039016963200992905, 0.10754486473160796, 0.030392773041967303, 0.11271687704720534, 0.07151943573262542, 0.053686955507146195, 0.03867904109938536, 0.0351788240368478, 0.03796456439886242, 0.04758202274388168, 0.06632806078414433, 0.08100888473563828, 0.042743060330394655, 0.01650282061746111, 0.009067804294318194, 0.009903323425533017, 0.042894321159110405, 0.021363973246479873, 0.014926087987987557, 0.04697482720075641, 0.08036503451876342, 0.02718093601288274, 0.06015360362653155, 0.043261673126835376, 0.10306555821443908, 0.022639129529125057, 0.02853172642062418, 0.010768805841507856, 0.043116034066770226, 0.05494222779816482, 0.017007299211400095, 0.01781355731509393, 0.028954758017789572, 0.03765491441299673, 0.013861547649867134, 0.016848737504915334, 0.019230324651289266, 0.02021668158704415, 0.03862026671413332, 0.0728405179688707, 0.04335417441325262, 0.012501740147854434, 0.01903306179883657, 0.09972351879696362, 0.06995340023422614, 0.05776339829026256, 0.07950060316943564, 0.12737047160044312, 0.018088580545736477, 0.050827553277486004, 0.024868671025615185, 0.07632251901668496, 0.058300093514844775, 0.07017527270363644, 0.054160193394636735, 0.0024621379998279735, 0.02449703315505758, 0.012564125081553357, 0.04128462511289399, 0.0031105967218536534, 0.03583195109968074, 0.041140366447507404, 0.01726453501760261, 0.07532477568020113, 0.038142509147292, 0.030263665321399458, 0.0257052106098854, 0.023952515693963505, 0.044998113153269514, 0.03780412320338655, 0.10771825269330293, 0.07750126475002617, 0.02428203482850222, 0.054838764990563504, 0.041694246101542376, 0.01779779038770357, 0.0644595778430812, 0.06219491049705539, 0.030658326468255837, 0.038048408532631584, 0.04035622434457764, 0.006744783268004539, 0.06386048655258492, 0.0556142239656765, 0.02494760585250333, 0.035815976370940916, 0.05125681891513523, 0.023409669920511078, 0.060824724059784785, 0.014045015832380159, 0.021103360668348614, 0.04667574539780617, 0.01036717036186019, 0.06504351447802037, 0.0708470722020138, 0.023381080536637455, 0.005489341210704879, 0.035147731759934686, 0.01429025482138968, 0.027872641767316964, 0.028861967293778434, 0.040728318635956384, 0.01744389912346378, 0.05083547941467259, 0.014387748906301567, 0.02708918800635729, 0.010165435141971102, 0.0637161907798145, 0.0420949167892104, 0.006408741583072697, 0.03731678079930134, 0.012382322092889808, 0.04568552743876353, 0.04386026717838831, 0.011564005944819655, 0.03858876625599805, 0.03836491596302949, 0.02279343687405344, 0.016149547191162128, 0.036314068784122355, 0.009278513934987132, 0.012469515168049838, 0.02327651749510551, 0.02078595895000035, 0.011856517885462381, 0.03446549395448528, 0.044960771992919035, 0.048832608372322284, 0.039041906784405, 0.05940045361057855, 0.04587459327012766, 0.037927282610326074, 0.044370460309437476, 0.059929927738267, 0.024215909470512997, 0.050990614254260436, 0.03149273237795569, 0.029749787427135743, 0.03121943649603054, 0.03374346219061408, 0.061490248699556105, 0.043242299361736514, 0.16053682862548158, 0.16290962317725644, 0.1709846648736857, 0.11816205907962285, 0.1424210928962566, 0.11968456019531004, 0.10711372146033682, 0.13849001086782664, 0.13534262194298208, 0.1646496626199223, 0.07238044578116387, 0.12043883456499316, 0.12645613081986085, 0.1521848322590813, 0.18400479981210083, 0.13777042448055, 0.12071944060153328, 0.14031428407179192, 0.15749041631352156, 0.12650876393308863, 0.22752246935851872, 0.17858189705293626, 0.17709334177197888, 0.16757197299739346, 0.15029820380732417, 0.10167718544835225, 0.07535979020758532, 0.16277891612844542, 0.13903918530559167, 0.13688599225133657, 0.11152394145028666, 0.15721604431746528, 0.1422774576349184, 0.11659542244160548, 0.1417616501566954, 0.28434349223971367, 0.20624264638172463, 0.2957745554158464, 0.25252465275116265, 0.15187658864306286, 0.21013535937527195, 0.17587881709914654, 0.21928816277068108, 0.12917344516608864, 0.15309393347706646, 0.17752414365531877, 0.196138676838018, 0.16229530301643535, 0.12364929119939916, 0.11785049064201303, 0.11720610607881099, 0.07772485900204629, 0.14663381996797398, 0.18045470671495423, 0.1421869601472281, 0.07666089382837527, 0.12917019455926493, 0.1394074983545579, 0.20924236276187003, 0.11602313752518967, 0.0789736708975397, 0.16468460293253884, 0.15542491542873904, 0.13773214450338855, 0.08026680385228246, 0.17306946159806103, 0.1774016150739044, 0.20023754361318424, 0.13216222228948027, 0.13557218306232244, 0.1653591706417501, 0.10101964260684326, 0.15288337133824825, 0.15219013119349256, 0.15290576935512945, 0.07342020951909944, 0.19012877979548648, 0.17826213530497625, 0.17549935699207708, 0.1160441551473923, 0.17163499403977767, 0.18981370842084289, 0.08330079261213541, 0.19285470305476338, 0.16365515504730865, 0.14203011465724558, 0.2333401353098452, 0.22981002082815394, 0.16872728912858292, 0.06804517528507859, 0.16695548576535657, 0.20051274681463838, 0.09209178417222574, 0.09491187112871557, 0.1649193887715228, 0.22737583582056686, 0.09734227860462852, 0.17006601963657886, 0.13003464817302302, 0.09586907835910097, 0.16960036649834365, 0.138078015006613, 0.12709417002042755, 0.13808399671688676, 0.1295245107030496, 0.13095050293486565, 0.10824525917996652, 0.10169985063839704, 0.0947496376466006, 0.06893996789585799, 0.20150766998995095, 0.1178810597048141, 0.1234929206839297, 0.2003268981934525, 0.15593103045830503, 0.1701128639979288, 0.13883635634556413, 0.13015079428441823, 0.08485997808747925, 0.11027810556697659, 0.14383950037881732, 0.14302889700047672, 0.1307055348297581, 0.0854628617526032, 0.15844561974518, 0.19421896344283596, 0.16779901081463322, 0.2788909926312044, 0.11885658313985914, 0.08164690909325145, 0.12302428411203437, 0.21835648542037234, 0.12178447446785867, 0.10222024458926171, 0.08717516713659279, 0.1046899265202228, 0.13689555111341178, 0.1260810493840836, 0.11422104711527936, 0.1561892533209175, 0.10849841317394748, 0.10208474326645955, 0.10078757302835584, 0.15308048576116562, 0.08238459646236151, 0.11846910783788189, 0.16739166079787537, 0.1407549565192312, 0.10485158112714998, 0.21326704445527866, 0.16813190857646987, 0.0918668021040503, 0.13845984998624772, 0.09334810660220683, 0.16011338884709403, 0.14580941264284775, 0.14474466821411625, 0.16869666811544448, 0.1797976833768189, 0.15050732617964968, 0.06503926939330995, 0.20564704318530858, 0.13796758343232796, 0.32601469836663455, 0.17215731757460162, 0.12166513712145388, 0.113474661775399, 0.09965766803361475, 0.1495026214979589, 0.1144339024904184, 0.09719896246679127, 0.09301320504164323, 0.1402902088011615, 0.08914891630411148, 0.1845079759368673, 0.15253837656928226], [0.06013715021254029, 0.026380359049653634, 0.01689321070443839, 0.028472183912526816, 0.05747678456827998, 0.020274413254810497, 0.014893823117745342, 0.11896380863618106, 0.02482125706592342, 0.04118399359867908, 0.05976471082249191, 0.010907011364906793, 0.030995651140983682, 0.04629550232493784, 0.03742794709978625, 0.04756024442031048, 0.01519789400845184, 0.04226157718221657, 0.0518398686836008, 0.04888414310698863, 0.03060431481571868, 0.022987796073721256, 0.07383804608252831, 0.05110027770570014, 0.0167961155239027, 0.019839191882056184, 0.05892078501346987, 0.013809714200760936, 0.046133339346852154, 0.0079277875374828, 0.02184123357437784, 0.08660766907269135, 0.012309973826631904, 0.06589515862287953, 0.05957861358183436, 0.056233850482385606, 0.026368026410636958, 0.02863336540031014, 0.051748551122727804, 0.054525912637473084, 0.010429785361338872, 0.0363885989645496, 0.021024435118306428, 0.054754497832618654, 0.015733684740553144, 0.026242479143547826, 0.12437211335054599, 0.017311856208834797, 0.026019610340881627, 0.08622905501397327, 0.04879184220044408, 0.04588307601807173, 0.03682635477161966, 0.02192326501244679, 0.08072985947364941, 0.04239206529746298, 0.03795323922531679, 0.036511966172838584, 0.025582670896255877, 0.02836545379977906, 0.0360546733281808, 0.08743765734834597, 0.024178325256798416, 0.01519359140729648, 0.09133433341048658, 0.0364871079364093, 0.03491945084533654, 0.03910612111212686, 0.03670252743177116, 0.0504081322287675, 0.07870824178098701, 0.04193130291241687, 0.061220121788210236, 0.01411935212672688, 0.06103913052356802, 0.024872342801245395, 0.059650100956787355, 0.024805425200611353, 0.029239694486022927, 0.054688710151822306, 0.01424123503966257, 0.0465194862044882, 0.03366226010257378, 0.0467655489774188, 0.07510052833822556, 0.05749617317633238, 0.08878733453457244, 0.006896192526255618, 0.07309245484066196, 0.032192989528994076, 0.04867352901783306, 0.0367307587293908, 0.050564884950290434, 0.01347210658423137, 0.02591892502096016, 0.027593861414061394, 0.04066686880833004, 0.009624681297282223, 0.03512281415169127, 0.02830957750120433, 0.021150689281057566, 0.016297865404339973, 0.07429850418702699, 0.0718971221067477, 0.035432924269116484, 0.04197656649921555, 0.023853544735175092, 0.07819356236723252, 0.09547531706630252, 0.022033036075299606, 0.07764599838992581, 0.03243417639168911, 0.04227978948620148, 0.04320387466577813, 0.04160240903729573, 0.037302991695469245, 0.03912386957381386, 0.030671176755276974, 0.03490867486107163, 0.032471150188939646, 0.03823498074780218, 0.02033156604738906, 0.03915265006071422, 0.03129860881017521, 0.08822706498904154, 0.13761867012362927, 0.019559493121050764, 0.01720824682706734, 0.05234029144048691, 0.04525603915681131, 0.027752929636335466, 0.07265117383212782, 0.05930384824750945, 0.01840447755967034, 0.0649691438593436, 0.04594071120664012, 0.012680581967288163, 0.04229017584293615, 0.06471259825048037, 0.0369853636220796, 0.015889583992247935, 0.01916511213494232, 0.036793273538933136, 0.04864792863372713, 0.02873017485399032, 0.01498877627454931, 0.02614843047922477, 0.006816936720497324, 0.0062647102004120825, 0.04542783892247826, 0.04489672835916281, 0.06377317287842743, 0.014349048688018229, 0.05130742967594415, 0.03160013227898162, 0.02904400313127553, 0.026212262600893155, 0.04362866886367556, 0.07540704275015742, 0.04887892209808342, 0.05338793678674847, 0.04664363637857605, 0.03038057027879404, 0.03754988567379769, 0.038370845722965896, 0.019912365787604358, 0.036655920557677746, 0.03998402986326255, 0.02364543168368982, 0.02500425212929258, 0.018606146913953125, 0.009068165163625963, 0.02364655603741994, 0.032425474710180424, 0.0051531821736716665, 0.03586204518796876, 0.03737206709047314, 0.039259088880498894, 0.026822901709238067, 0.07551754111773334, 0.03522379447531421, 0.0902426267566625, 0.021746761885879096, 0.04955339332809672, 0.07981119939358905, 0.02902039726905059, 0.06295588274952024, 0.039382545146509074, 0.022685786498186644, 0.016917189495870844, 0.11682438984280452, 0.04186964899417944, 0.07738356754998676, 0.03480220264464151, 0.06759532989235595, 0.07102649382431991, 0.04537017404800281, 0.026470303637324832, 0.0174735516338842, 0.01923061779962154, 0.009146031297859736, 0.005246624132269062, 0.010607560343487421, 0.022639576673100237, 0.0230902347175288, 0.044218394250492565, 0.01917568217322696, 0.045835567434551194, 0.06069598741305526, 0.07080574199790135, 0.003816243720393686, 0.03186495654517785, 0.016358986831619404, 0.028120350252720527, 0.04382575731142424, 0.017581604624865577, 0.02366337866988033, 0.06576962434337474, 0.06488321057986468, 0.01785724383807974, 0.02017993785557337, 0.025735516210261267, 0.022887144150445238, 0.021488683742063586, 0.043783495711977594, 0.027586378710111603, 0.03246624088205863, 0.022541240250575356, 0.029709108457609545, 0.02681413694517687, 0.019421513025008608, 0.03494645388855133, 0.0321839093521703, 0.014387196006282466, 0.029841939904144965, 0.05085718723421451, 0.029273003929120023, 0.01125873277487699, 0.044707733031827956, 0.018808270833687857, 0.0290377690907917, 0.0616863166942494, 0.016844297606439795, 0.08718042154214345, 0.025427771688555367, 0.009742639176693046, 0.01597611470060656, 0.020252685026207473, 0.04248500074027106, 0.03610421910707373, 0.028420046182873193, 0.04423197926371358, 0.03225207932700869, 0.012579711110447533, 0.027962449057667982, 0.0154070052485622, 0.017741990159265697, 0.035906162156607024, 0.06661294159130193, 0.04768106606206857, 0.0684002113121096, 0.037845175102120265, 0.026253618780174293, 0.07216210593469441, 0.05130650941282511, 0.020959079738531727, 0.023282161528186407, 0.037462308537214994, 0.055338041129289195, 0.03420357890718151, 0.03043770822841907, 0.01432542241673218, 0.02854791637219023, 0.04237326298607513, 0.008448528442386305, 0.01993717949517304, 0.06487903228844516, 0.10526040059630759, 0.019616933495854028, 0.02106461313815089, 0.04783275733643677, 0.027536771704035345, 0.031042024238558952, 0.027692097646649927, 0.013782698169961805, 0.04808451238204725, 0.03570982698875014, 0.02493354957550764, 0.06313968304311857, 0.01659456862398656, 0.046035876803216524, 0.011547097037691856, 0.031495307630393654, 0.03189791532349773, 0.09346933642518707, 0.019850231328746304, 0.0906367071729619, 0.04118847617064603, 0.055258653592318296, 0.016641453803458717, 0.08365950227016583, 0.03981575158832129, 0.04609257688571233, 0.0521126005332917, 0.09175323866656981, 0.03183347092999611, 0.048159647412830964, 0.10457283788127825, 0.027469876367831603, 0.03279867480159737, 0.07402484465274028, 0.1444425102090463, 0.047277690246119164, 0.031567652185913175, 0.01946497319295304, 0.06709803157718852, 0.04664558822696563, 0.037669022640329786, 0.039544904793729074, 0.05622058830340393, 0.05544184532482177, 0.038624905137112364, 0.02266996947582811, 0.06283524664468132, 0.05529166061023716, 0.026503605658945162, 0.03695986342791002, 0.03110114372248063, 0.03126420284388587, 0.022996128536760807, 0.04446951475983951, 0.017394008245901205, 0.028618808173632715, 0.03196169920556713, 0.0995060324203223, 0.046235143454396166, 0.05335406516678631, 0.05114315157698002, 0.03226494445698336, 0.019667460765049327, 0.1375852883211337, 0.036440886979107745, 0.05686044205504004, 0.02742119333561277, 0.11166905358550139, 0.053919281126582064, 0.06487876511528157, 0.017493836385256145, 0.030509323623846285, 0.006434304395952495, 0.031140535065787844, 0.03645288750703912, 0.15431723033543676, 0.12797256116755307, 0.08549311911338009, 0.14501904021017253, 0.16609460930339992, 0.12679947802098468, 0.10688047928852029, 0.14918618457159027, 0.13496578903868794, 0.22856434079585597, 0.2620877302251756, 0.11690834900946356, 0.10672314398107119, 0.07020364500931464, 0.12841079937061295, 0.14260360185289755, 0.18375684827333316, 0.13325761741725728, 0.1338566344929859, 0.13522337365429848, 0.09209332783939317, 0.11251688309130259, 0.1695673112408258, 0.15052700793603435, 0.08314926089951769, 0.07806997251464054, 0.0899963005213067, 0.06933056763955392, 0.13916662690462545, 0.1375230963458307, 0.09647888626204804, 0.1479495142120868, 0.1669979514554143, 0.14879974827636033, 0.10345413931645453, 0.13166462711524218, 0.09043636440765113, 0.10137404780834913, 0.1700944290496409, 0.11568113361136056, 0.0938360315922182, 0.183666410157457, 0.16863211611052975, 0.10630100296111777, 0.07133786930353381, 0.12416257537552156, 0.2639585064025596, 0.08853708975948393, 0.14880659087793902, 0.18176277168095112, 0.1757636951515451, 0.17567794740898535, 0.0999633215542417, 0.14254526904551312, 0.1316353419679217, 0.12432208517566323, 0.15613415627740324, 0.13415337482001632, 0.1333977942704223, 0.12983495107619092, 0.1289618737064302, 0.15265631867805496, 0.18905933015048504, 0.06687916480586864, 0.1491145376348868, 0.12899645778816193, 0.08647282083984464, 0.14881549665005878, 0.1271768898004666, 0.10766019448055886, 0.2005601255223155, 0.12499779579229653, 0.17579885810846463, 0.13815732090733945, 0.12780091725289822, 0.16004042088752612, 0.11100136558525264, 0.07508628652431071, 0.05486112590006087, 0.1400434150127694, 0.08471125169307925, 0.08056692095124163, 0.16832678171340376, 0.11468108961707912, 0.1580788503633812, 0.1481178481481038, 0.18118030449841172, 0.11118426788016222, 0.11537041864357889, 0.12154352880315855, 0.0981190919992514, 0.0777816036134027, 0.14916723011992872, 0.1152237925271038, 0.2309295951272361, 0.15667262894567102, 0.1078544590563979, 0.08895252176444046, 0.151880937628448, 0.0860269607801456, 0.15447468438651413, 0.17304323409916833, 0.14746410510269925, 0.15830210322747007, 0.1018995551567059, 0.174754107138142, 0.10159174940781668, 0.1557652049814351, 0.13849367707734928, 0.1034901557432022, 0.12098187886294909, 0.15906151325907558, 0.09938787508872338, 0.12045923620462418, 0.13955525995697826, 0.12390936943120323, 0.11218633793760091, 0.17345386440865695, 0.15204309689579532, 0.12958078033989295, 0.1912472111871466, 0.16732071147998795, 0.1243901475390885, 0.11814294135547243, 0.17332915391307324, 0.2642103022662923, 0.10332148041925393, 0.18820146680809557, 0.17210346733918414, 0.16354420396964997, 0.1445107877952978, 0.24615858419565484, 0.18435350531945005, 0.1846517893136479, 0.13519716099835932, 0.1779542924487032, 0.12842657743021846, 0.1671139194513671, 0.13358272262848914, 0.19147936982335523, 0.12329875258728862, 0.239151403948199, 0.1546331329154782, 0.18283392826560885, 0.13330866233445704, 0.15065050130942836, 0.044669701674138196, 0.1871962723089382, 0.20468630333198234, 0.17616878903936595, 0.08763661971897818, 0.13725035707466304, 0.16064835857832804, 0.09535589066217653, 0.11041508376365528, 0.13431946747004986, 0.17231943231308833, 0.17342889856081456, 0.17725944926496595, 0.10355894541135058, 0.10694106822484173, 0.15074098395416513, 0.0955059751868248, 0.09627170089515857, 0.12563314841827378, 0.09254402670194395, 0.0788276904495433, 0.0839207976241596, 0.23513604362960905, 0.1243829783925321, 0.1431920804316178, 0.10887097130762413, 0.1604048302397132, 0.11912398636923172, 0.13921630627010018, 0.16253749548923224], [0.03555224677256774, 0.01255836787095177, 0.033119104482466355, 0.0890405553218443, 0.029077496255922597, 0.026589722619974054, 0.01418180199834751, 0.0194360999375931, 0.0042612621382431826, 0.04199110517220106, 0.03635621535067912, 0.020900318340864033, 0.07279129131347872, 0.03710162105562631, 0.0044041575711162295, 0.01511234293502639, 0.023771715532348026, 0.12671292875893414, 0.0306296740018297, 0.08362272143131122, 0.030139852824504487, 0.08412085095187649, 0.03327046179038007, 0.028768807351298165, 0.012772922764270334, 0.01749675859173294, 0.07024938357062638, 0.04708271320851054, 0.03048092719836859, 0.09985796627006494, 0.027639492363960017, 0.06061387248337269, 0.04884633068286348, 0.04178459887043573, 0.042321717119193636, 0.04325756905018352, 0.044537888825288974, 0.014239228457881836, 0.012888728415418882, 0.017880970299302135, 0.007641528654858121, 0.06835529653471895, 0.060107961544417776, 0.011831226420326857, 0.004903168392047519, 0.041199055485776626, 0.00803740460469271, 0.02276719082146883, 0.023085510947566945, 0.026080336574523244, 0.024800690298434347, 0.0313610234297812, 0.035624684096546844, 0.039115461040637456, 0.06112029921496287, 0.051423479308141395, 0.04333992888859939, 0.029456479533109814, 0.0652071728836745, 0.026036791059596, 0.01849723674240522, 0.04688848202931695, 0.015431646406796062, 0.01739948715112405, 0.026191912911599502, 0.011411967716412619, 0.03611085390730295, 0.02430429925880162, 0.10360429805587046, 0.04594869300490245, 0.0762367712741252, 0.03788642366998829, 0.04726620922156144, 0.02172025979234604, 0.06271392776397988, 0.04506657256570179, 0.02813599287037505, 0.023089611313480418, 0.0097393959913461, 0.07662486998015083, 0.013526355724025052, 0.06774528825189918, 0.029926320239610504, 0.03813505427388009, 0.08044422167586163, 0.029589002988359425, 0.060164995593368076, 0.03889438266924117, 0.02970304325572215, 0.07741762470686808, 0.022364045071299188, 0.04900032261502929, 0.061074197001289576, 0.03650393984571565, 0.09559698475641198, 0.023900975393189583, 0.024145481511368416, 0.012476078536565183, 0.023523433737864252, 0.0358264703390887, 0.04375014359538909, 0.05086532859422732, 0.061518721195170656, 0.007516356172345695, 0.038873253724887036, 0.0355997293809196, 0.022870028369652573, 0.008332008474098984, 0.010213738751190249, 0.02597685521323001, 0.028969380182388704, 0.05175779457204044, 0.06166626015328802, 0.07004424653132446, 0.012730304933938896, 0.013323471102921758, 0.07996336193173192, 0.020048347651027143, 0.024347789112653118, 0.03307689112261869, 0.025236330984625965, 0.06061926047550514, 0.05287265623337589, 0.026582996906654444, 0.019854537640640046, 0.03065729859372368, 0.06880092652863823, 0.04021653359814081, 0.0387401829357259, 0.04244671334163286, 0.017983826401177794, 0.08544026335584931, 0.061386945453705266, 0.029864549433114007, 0.00788175768320798, 0.040771274143480696, 0.024635024383314885, 0.032655358663760126, 0.022229582755244337, 0.08634675963548943, 0.023634485005459283, 0.049053679322241805, 0.0565761438338086, 0.008440246074314928, 0.02951127044070745, 0.15206478245090693, 0.031006909521238413, 0.04481949676119257, 0.029300836322363466, 0.01785841457603965, 0.023733925372653175, 0.011751542951969896, 0.012990818249818403, 0.04264449940819759, 0.03864861675538123, 0.022808034918853082, 0.028393516258802265, 0.010804584780998994, 0.01838914664404001, 0.024222091560659464, 0.034734511355054565, 0.06307854491751641, 0.0534115222399123, 0.030090908185229637, 0.06678085250314325, 0.09489182571996935, 0.010575785290711792, 0.020214985779603012, 0.049647939231363125, 0.03471023199381307, 0.058671107981354, 0.025502852913632523, 0.11255849531153217, 0.051775060637737624, 0.03997357671323698, 0.056759647268336266, 0.010921884004346794, 0.004217140995024238, 0.016205328865908086, 0.060586442705243826, 0.005386179436754901, 0.050706805850495584, 0.03603082070185337, 0.07031550150713883, 0.05173984944121912, 0.020228162611601874, 0.03022014207090251, 0.03627075333497487, 0.06695185074931942, 0.09766327973920852, 0.0400782343785977, 0.029456435004249215, 0.027266381330264267, 0.05690998041245621, 0.019359107682248577, 0.044000826237606816, 0.02379236579145072, 0.0053212869715935085, 0.029692573407373857, 0.023626590409548953, 0.031238546798704192, 0.04069740076374728, 0.12544919969514012, 0.016833931658766232, 0.023530756880063564, 0.03472836266155355, 0.0342659267334966, 0.07887287982157432, 0.0235631720352103, 0.020217225210217293, 0.05481117193994578, 0.046898003784008324, 0.0075190316147200065, 0.013015902841289062, 0.011370618958608247, 0.09673691616626456, 0.020653164610848762, 0.01637175362702692, 0.03993876998720225, 0.02000339205551427, 0.011943633962800959, 0.04850848650676198, 0.04948431422235444, 0.045306902247830294, 0.021278401763993315, 0.018041020011878572, 0.03722856541571673, 0.028827080786868464, 0.05330949177732691, 0.062340902077266946, 0.050180137041024864, 0.009595716201147297, 0.018178510290454142, 0.03411745266930666, 0.0772396354295779, 0.021099061777931638, 0.022127882548375055, 0.09984145348425955, 0.012798823718185304, 0.006655546503679943, 0.04497039764828514, 0.027678369770001154, 0.08478744799504057, 0.023987882741494104, 0.023719279088254552, 0.037876400965615176, 0.040634919350850396, 0.05568025284446776, 0.02551471614424372, 0.06799174807383679, 0.021666955035470892, 0.016385396156692877, 0.05566475309024099, 0.04845723007747438, 0.02510312475351384, 0.026587690990709234, 0.008111986735457322, 0.058885228718281724, 0.011948120245506288, 0.048832036918611266, 0.03483418178802822, 0.06241927287192084, 0.029003398376516998, 0.04752286615257617, 0.03208359325071797, 0.026668633327062707, 0.027371773721824866, 0.011314798321109265, 0.05427464369859081, 0.023045954476401675, 0.037550902416114695, 0.08981476377812214, 0.030502024601446465, 0.011615534185693832, 0.02954559477075236, 0.033825035352492705, 0.04294230842788238, 0.0583146507415222, 0.029731120557698887, 0.02932164614321664, 0.015700542280683294, 0.03533847855578642, 0.016462739076814614, 0.006265944020924508, 0.05872884335985873, 0.02770759183476912, 0.021515549487958197, 0.0043208603074162966, 0.044722386737703346, 0.06562526177731343, 0.02307954964635428, 0.04302092413126957, 0.0469725488073891, 0.01262738389414153, 0.04025295078463387, 0.03236786549678072, 0.009492771969235037, 0.013218844978837296, 0.03222119856218342, 0.025709708024805877, 0.02062853644019924, 0.010896583262365311, 0.041139093664241955, 0.02276879571581958, 0.036764812175533734, 0.010364252793806372, 0.01726218240946764, 0.09563530926243402, 0.04221775336191058, 0.028224961533851456, 0.04272196478268597, 0.050910054123960435, 0.08286679207230918, 0.02632737156091025, 0.057444163467152975, 0.019582054410420824, 0.05645184523018543, 0.07025478640571237, 0.026897673087660223, 0.04612624441506341, 0.03873401939927135, 0.10172238224186003, 0.004331360769356252, 0.039137102066888474, 0.019063525105593726, 0.015038327619549818, 0.06045258523954544, 0.0037778881369376904, 0.09444307870580815, 0.03822734775894787, 0.02466124074999243, 0.012377357124933042, 0.039671793492743745, 0.02146115934010595, 0.013315660926309647, 0.04054991375596728, 0.009520888233964797, 0.015300740833481541, 0.05254873845842667, 0.04609888143022545, 0.015657210133213084, 0.03466801492322702, 0.02091808164550457, 0.07602401237818412, 0.041105997588601895, 0.028661804499279242, 0.03814668372797314, 0.04960515441780444, 0.03989164360973518, 0.021027136535849422, 0.034837677303585224, 0.03000095246534329, 0.13022986269788817, 0.168323056132067, 0.12178237418993376, 0.18952465674374253, 0.12345383918727748, 0.08718377604964189, 0.1684394694166258, 0.19283088011434302, 0.19595883961301297, 0.15002988773630932, 0.1654913619859144, 0.12432389601599425, 0.14907508506439626, 0.16402747569372877, 0.14422580308746547, 0.1832265392295085, 0.15838151302887127, 0.18096836196491495, 0.19260032451711595, 0.19179775117663667, 0.15285620873328298, 0.11797677449067123, 0.09442727838177234, 0.18424200505251065, 0.09788122624740936, 0.16242587647866458, 0.22067398997023702, 0.130560593388509, 0.15610792877851054, 0.17041300336131826, 0.21087110973894596, 0.11884283114341088, 0.11069917789427564, 0.24693864077562466, 0.10022966351243667, 0.20333872642368078, 0.15091878769453615, 0.12085768787073903, 0.06329310723231174, 0.10797843482578173, 0.1883603457827121, 0.2981798263499513, 0.15784833929501474, 0.1131199077644851, 0.13866771070752293, 0.16970766620943323, 0.11839239203254692, 0.1005260921374429, 0.1347279455512762, 0.09668512167991139, 0.1225618964235764, 0.1323629732360132, 0.2304080137400888, 0.16280357027426362, 0.15289251459762454, 0.08582776092225686, 0.10997293444233947, 0.19398825941607356, 0.11917433366761543, 0.1118828218022827, 0.09268874549889006, 0.17430727486498654, 0.13305892964126542, 0.13547966693295166, 0.13124699093168601, 0.10037047861260362, 0.15126701822737232, 0.07086011915816925, 0.18421960703562945, 0.108730638603447, 0.1961985681555234, 0.09184657857986167, 0.12162536542746238, 0.1126429665600881, 0.12588446930749342, 0.10969374590786174, 0.08202826167689636, 0.19416340626776218, 0.08569119090680033, 0.13304919266374782, 0.11597496471949853, 0.1590618843329139, 0.15154750552028418, 0.13149154343409464, 0.09357636896311305, 0.11389563762350008, 0.17356030322844163, 0.09121113689616323, 0.08309840894071385, 0.23457193718058988, 0.09021045465487987, 0.19519901397870854, 0.12648042873479426, 0.13426644844003022, 0.1735802966868505, 0.18207195040304214, 0.1266061930800788, 0.06213506741914898, 0.15896190219791606, 0.1354480069130659, 0.1752901158761233, 0.12056758234393783, 0.13980190531583503, 0.09664104552939534, 0.11914732691366225, 0.12592374376254156, 0.1513915802934207, 0.16926025506109, 0.11052135931095108, 0.14430772134801373, 0.10917317384155467, 0.15394499874673784, 0.17319414240773767, 0.15231383236823604, 0.11746441057766788, 0.12283255025977269, 0.2515871124342084, 0.13241826323792338, 0.16030682221753523, 0.08035679667955264, 0.11822577245766297, 0.16072371625341475, 0.20457268052268773, 0.09949818791938014, 0.11693732245475985, 0.21508511330466717, 0.18974744947627187, 0.15848354349145666, 0.16914458392420784, 0.16334818792529404, 0.11761232803110033, 0.1543943988508545, 0.14606113429181278, 0.14136273093754426, 0.20828846551012248, 0.1678304185043089, 0.18198786507127807, 0.11474439481389709, 0.14888439764035866, 0.12433889482053928, 0.13846088899299502, 0.1367432772531174, 0.12736998178297654, 0.10831741819856688, 0.15306170942494646, 0.23546548298327252, 0.15788718330441043, 0.08146035543177277, 0.0905006195534952, 0.12747003813274205, 0.2097431046422571, 0.08383237072848715, 0.12760124984197319, 0.12562151154270396, 0.08145998435793445, 0.09717380366055295, 0.12571873288834468, 0.10417710247565992, 0.20951585902366787, 0.12264618213521317, 0.21059473394416273, 0.09576557844411582, 0.1068974076770246, 0.12498035532189533, 0.20388116216054186, 0.21148252068087459, 0.10232082044240087, 0.16333842126186937, 0.17396480339812115, 0.16703997185686603, 0.19549930177163333, 0.18707515380810946, 0.15230626246193424, 0.16810346947750077, 0.07147592361434363, 0.13798448955640197], [0.03144484158838168, 0.03360948227054905, 0.043562703067436814, 0.04334833371103741, 0.056666748932912014, 0.023131507405196317, 0.06191079410200473, 0.028737859793181997, 0.06533661828143522, 0.0614035361650167, 0.020746933114423882, 0.024972022511065006, 0.03253521608712617, 0.10364369867602363, 0.01559540778544033, 0.0487483709002845, 0.04063255932123866, 0.0442407180526061, 0.018229900306323543, 0.03873803812894039, 0.016908975776459556, 0.010263895874231821, 0.007191664708443568, 0.02661853279278148, 0.09520538311335258, 0.053255686070770025, 0.04552676349703688, 0.0364723020902602, 0.008143074373947456, 0.03999329557700548, 0.01887172260467196, 0.053851382035645656, 0.04046968759212177, 0.02233034228993347, 0.012439711445040302, 0.029364545989665203, 0.04542336377198808, 0.04532016071607359, 0.039162212633527815, 0.0458253851684276, 0.015814191065146588, 0.03522989121847786, 0.07270198868354782, 0.0132229165865283, 0.071061797789298, 0.03849955268378835, 0.05224873639235739, 0.029043743379588705, 0.011818158127425704, 0.023383364496112335, 0.008606627234257758, 0.05719196313293651, 0.052573054927052, 0.0610659146332182, 0.05958118512353394, 0.006394913516487577, 0.04370458686025813, 0.09141138318227604, 0.015044203573779669, 0.00313182863919792, 0.02278115804074332, 0.05369600228732452, 0.03461225365754217, 0.005321189564710949, 0.007986538730619941, 0.026024981634691358, 0.032354094946640544, 0.03139775973977521, 0.035038539572269656, 0.06377214129315689, 0.062402121839113533, 0.008749211428948911, 0.03521707061736379, 0.026811036623257678, 0.015220520235743606, 0.0591582982451655, 0.024772505385044497, 0.10114303950103931, 0.041519503720337525, 0.0292220833216561, 0.07474264988559298, 0.03802665618422907, 0.008197756742447382, 0.07589895307319239, 0.025655657409515698, 0.021047627233201638, 0.04983572485798504, 0.048280810442520306, 0.026162586946156807, 0.03087256038270425, 0.04087081098987255, 0.0672960514202714, 0.008307671596412547, 0.07533335490734316, 0.03280627810454462, 0.009125182514253538, 0.028286587621551007, 0.05712882863008417, 0.02465877310896758, 0.01973137081222376, 0.016187634209927637, 0.04425193190400023, 0.02066719676804496, 0.05206390080275014, 0.05250315574812703, 0.03976478459662758, 0.04098786994291004, 0.019517988512234297, 0.012292838564462727, 0.06499625451397151, 0.039279412594623864, 0.043305062790750526, 0.10646658352925442, 0.027810184474219568, 0.03068743350013392, 0.05722912246710621, 0.0439903619553661, 0.08091480267466977, 0.08230675259255804, 0.004780762264999794, 0.04071685245435219, 0.028244478162378073, 0.05885408078029286, 0.029173331640777178, 0.04646615176170599, 0.04309298295993358, 0.08901406807126477, 0.043094355933135375, 0.005195511957936105, 0.030376436516235117, 0.031280311159207486, 0.039125019902712665, 0.011213268808205612, 0.026896506060438696, 0.020543482605717145, 0.021366340697568376, 0.04900505380646791, 0.024808265770843718, 0.02732632274273783, 0.05381402232160326, 0.006891985476613627, 0.00873298436999903, 0.02037271628068993, 0.03506178363750223, 0.06449065898777917, 0.037796894685016014, 0.027321059060341213, 0.06643352739047259, 0.0026966397354044602, 0.025478378738625906, 0.053366084248409607, 0.006046011340004043, 0.04985922496416606, 0.014024630891071865, 0.06075411612982862, 0.01020899549985188, 0.01669677163590677, 0.010969971463055117, 0.04978575605491642, 0.0741830408514943, 0.039043921715347096, 0.007211597867353703, 0.011004333828168456, 0.026297080803487916, 0.031177271375781856, 0.015666837643948384, 0.0539382838178426, 0.005224679753155215, 0.01866720154794166, 0.06971371622057632, 0.06401798513252288, 0.020999688204028644, 0.04548360389890149, 0.05171184449864086, 0.018534138180257287, 0.04234507621731609, 0.05172418641450349, 0.06601818444323726, 0.033530992732266895, 0.05353701199055649, 0.01212910594404093, 0.08571520680561662, 0.02225574902695371, 0.033460139893577434, 0.042746630060719326, 0.020168547744106036, 0.06068353046430275, 0.01988175034057349, 0.06722222256939858, 0.07879523633164354, 0.07085939185344614, 0.03493382624583319, 0.041300236189272255, 0.022482951972051524, 0.039286080791498534, 0.07446588817401789, 0.04288579759304412, 0.0179299334922689, 0.023616204052814282, 0.08267697296105325, 0.031206463754642755, 0.020724074965983164, 0.04195035384327639, 0.03717108607816044, 0.023997222670004703, 0.04547064228972886, 0.018332509644096717, 0.11181820300407708, 0.022351146544679068, 0.014318718040158274, 0.020435763581190258, 0.03046749989152886, 0.0731243375048507, 0.021204992226557806, 0.007869413911976153, 0.03381875307240989, 0.04684617219027132, 0.034655042181839235, 0.02392341979430057, 0.013688024246221175, 0.04379564838018268, 0.04483051394345239, 0.035523058104445226, 0.013642245794471819, 0.050355569619568996, 0.011340908931742888, 0.018482184132153634, 0.018489000758563634, 0.032505047784070484, 0.02763897842669394, 0.06496788962977007, 0.06177941912028473, 0.06317504637991078, 0.031162881132331677, 0.05937453781371005, 0.030035729505470954, 0.03595444628444966, 0.06348276307107881, 0.05950448787189089, 0.013038476190558868, 0.021358156664064154, 0.0630048051243648, 0.05020872828026768, 0.052939323359169066, 0.026719683810370043, 0.07693548846873455, 0.09395429282449186, 0.0289181460175314, 0.053113869071239606, 0.01722444791084854, 0.06128914523287676, 0.06638055288931355, 0.04040729894768447, 0.07368266262346879, 0.0475707532314118, 0.04370290589577053, 0.01679585206147749, 0.018511714188207407, 0.061888503696536645, 0.03949509555241093, 0.020719486637972295, 0.0009727464691877685, 0.020177947044430766, 0.008869190733094001, 0.018219393350591417, 0.013456214419420576, 0.06546995995449834, 0.036480525086517446, 0.1070228974276688, 0.012318612425588071, 0.03354443673742935, 0.022433092635765206, 0.04750945925479755, 0.03973498736741021, 0.04992509428120684, 0.060211791715119034, 0.017142874748969916, 0.06601979490369558, 0.024941613010014407, 0.03594221569073852, 0.014514215508825146, 0.036265480375732295, 0.03997153209638782, 0.04808244921150617, 0.060620514705078676, 0.04268083124770783, 0.01737893337121932, 0.04062966865603812, 0.09538322396110743, 0.032485425399499945, 0.04782770702149719, 0.05755713689723052, 0.09715764710563235, 0.007801656756782904, 0.09840258499025367, 0.02765293265838409, 0.053480438073165715, 0.06255760919884779, 0.06757425289833918, 0.016176693097804673, 0.03511005292239133, 0.06448495187214576, 0.04328551091020927, 0.053021523635834455, 0.025895690232573543, 0.05863514721568208, 0.02794464679027442, 0.012197956839372637, 0.024126627249643207, 0.017544859038025606, 0.03564050668501295, 0.06292674603173509, 0.042268237957614474, 0.07213050528662279, 0.043655612535076216, 0.005508392605406698, 0.06067254667868838, 0.048459085446665995, 0.01347194052868872, 0.05836007017933298, 0.011602936228882754, 0.06066560759791173, 0.019551268269424327, 0.057586566763347946, 0.05398816356319003, 0.09375242123496719, 0.044312643294688314, 0.04431447639944963, 0.10429730071336962, 0.056096968764904886, 0.039334361208602786, 0.049257395148742944, 0.014531230171996867, 0.03451182252319995, 0.021450064232340083, 0.024150973404175602, 0.06372950490913354, 0.0742176768835634, 0.03450399286521133, 0.0019644417079689447, 0.02955829848360736, 0.014869758979330072, 0.04391950540593825, 0.017660290832282044, 0.06965207343455404, 0.10771488334285095, 0.04305958631448448, 0.04117321761441417, 0.07831192007870413, 0.04625519999535754, 0.029391094467428047, 0.07911585897090845, 0.12907099910080433, 0.240173326455988, 0.10931256401818246, 0.14065867027966306, 0.1517255319049582, 0.1487762073520571, 0.16400372696807608, 0.07688500758376904, 0.1070834047277458, 0.10720269012381323, 0.14778527693124488, 0.06375395867507905, 0.13834021578077227, 0.24068947532214224, 0.15483424009289593, 0.16466067609144375, 0.16956302162725478, 0.09232970187440515, 0.10444320694659837, 0.16073177597718313, 0.12029741832520813, 0.09530208495561965, 0.14346351352287456, 0.2564921445446089, 0.10584891628241166, 0.19168472208548337, 0.16224835475441068, 0.08759324860875495, 0.10040081760962494, 0.1540900144027546, 0.12571805011248216, 0.28345576487481594, 0.15026050270535052, 0.09814429533435032, 0.1401980489026755, 0.10075149722979404, 0.15344627550803125, 0.1518040066002868, 0.10328481090255082, 0.15088362473761663, 0.08634975049062632, 0.10868888537515886, 0.1768718849052675, 0.07239841317641549, 0.17141432384960353, 0.1638601956074126, 0.15323051833547652, 0.13326883869012818, 0.10762092744698748, 0.05479290397488512, 0.09632528395741247, 0.19621995685156435, 0.11960776275373064, 0.09330326603958383, 0.14835330191999674, 0.17584491579327732, 0.10833301072125323, 0.16842106415424496, 0.12424840475432575, 0.1495521079050377, 0.06681145867332816, 0.10998859375831671, 0.17670944362180308, 0.1012138626538217, 0.13983571756398305, 0.17415004345821217, 0.16153317672433332, 0.16989268362522125, 0.07607074541738257, 0.1649466998060234, 0.23852541722590104, 0.1153709455684293, 0.13639323587995023, 0.07862259051762521, 0.1316285290522501, 0.09398040900123306, 0.10015363048296422, 0.27409380942117423, 0.17260833556065336, 0.14848126302240416, 0.1263172601466067, 0.15111671847989783, 0.10183329621213488, 0.1461623187060468, 0.11851592993480153, 0.09144081675913185, 0.15045372827444226, 0.1258834748296067, 0.13135617569787428, 0.08378675091080368, 0.1372973943944089, 0.24397655128268525, 0.23971604474354535, 0.19110221037408337, 0.09920609343680553, 0.06887048060889356, 0.18918663816293702, 0.12326628362643532, 0.10322632966563106, 0.16954002989223227, 0.12044050439726561, 0.25089361995924264, 0.14131694042589515, 0.18191736104199663, 0.2825026394566521, 0.21679910336388275, 0.16696587583282962, 0.12344579430646263, 0.12435678057954647, 0.10639768253895454, 0.08150418667355552, 0.12575625587487593, 0.24722346221096814, 0.09526960857328959, 0.09858263001660816, 0.1229784861789085, 0.1401516201440245, 0.2670347975799814, 0.15070650377310812, 0.14735932869371027, 0.13173952465876937, 0.10200559321674518, 0.21339426341000944, 0.09025742518133484, 0.1166217538411729, 0.12264911361853592, 0.1352865155786276, 0.09192114957841113, 0.09216067031957209, 0.09723293056595139, 0.10784065510961227, 0.11263334090472199, 0.18453694938216358, 0.12246687925653532, 0.18155428755562752, 0.1524427137337625, 0.15155341301579028, 0.1556309949955903, 0.15153241023654118, 0.11329611588735133, 0.19179372873622924, 0.14951345685403794, 0.08891937744920142, 0.18563817779067904, 0.17089821951230988, 0.11885239742696285, 0.08958342150435783, 0.23657272278796881, 0.1204410164791625, 0.21637509955326095, 0.15422858821693808, 0.13008505484322086, 0.2128143937443383, 0.14768376597203314, 0.12008760575554334, 0.13179390924051404, 0.07814151555066928, 0.10132237206562422, 0.19858979765558615, 0.19867814291501418, 0.19672108464874327, 0.16182690393179655, 0.14313448977191, 0.09097301881411113, 0.16696125967428088, 0.14072337071411312, 0.16265530401142314, 0.09918708703480661, 0.16480998136103153, 0.13800647197058424, 0.2641297347145155, 0.2403044342645444, 0.17110358661739156, 0.10983534768456593, 0.10463008715305477, 0.14595530403312296], [0.016037481036619283, 0.03324437158880755, 0.03286313403805252, 0.03476728830719367, 0.005011518242099555, 0.02871563432563562, 0.05593799702182878, 0.07445410286891274, 0.04879851039731875, 0.14283546363003552, 0.023041700114845298, 0.047018855111673474, 0.07885106810135767, 0.05569446126173716, 0.06578459346201271, 0.0603189392859349, 0.04508884441747796, 0.04564489485346712, 0.03529320012603421, 0.045981425428180955, 0.0611768397357082, 0.03669315039587673, 0.03677834523841739, 0.03612973043345846, 0.06679283076664433, 0.07142787697375752, 0.031763623701408505, 0.01624889664526563, 0.0457684179127682, 0.009446382173337042, 0.0488469244010048, 0.04279539658455178, 0.08465244391118176, 0.02865515671146568, 0.05705715200747363, 0.02621503452246543, 0.040112796195899136, 0.015810432087164372, 0.05892239176318981, 0.07816489320248365, 0.06326897258986719, 0.025165351980831474, 0.04265811410732567, 0.06285927738645114, 0.002216441430391569, 0.04418730939505622, 0.030468366348941345, 0.04601363092660904, 0.03983921087638009, 0.032499414883204736, 0.02393812916125171, 0.04658757083234377, 0.015306678014894715, 0.060599396892939694, 0.01018195720462245, 0.05683038878487423, 0.0308018819487188, 0.059021598353865556, 0.0779028185934294, 0.039462819549953565, 0.027550820559554268, 0.06007631265674718, 0.027307258824293967, 0.09108521669986658, 0.06913175369845703, 0.02992349080159329, 0.052312056432128884, 0.019842804285872262, 0.02875973459595116, 0.03311221364128869, 0.05745441252656747, 0.04994171096768696, 0.006357537567964755, 0.06695884178043343, 0.07811246046912856, 0.0671111156407278, 0.09438218548893929, 0.043577965334407054, 0.040646266788826324, 0.03248728076869156, 0.0034379712815280072, 0.050461143837310374, 0.03771490592043847, 0.0060096822835475905, 0.037850982407690026, 0.03046930145501392, 0.012784189493686426, 0.01787072680599522, 0.03347996265802067, 0.0323086012940621, 0.0838143216969911, 0.03768588794628158, 0.05569398999796249, 0.03418336280446965, 0.043022367608500645, 0.04737880786706228, 0.0698852413916029, 0.037664810952264816, 0.04008933319710195, 0.038229243946261704, 0.01977118332433747, 0.01369832340060384, 0.017025450288201682, 0.0451646362489555, 0.012434508062142413, 0.0473519569641212, 0.027311882404319476, 0.0588042529852828, 0.039734909441904165, 0.024213987308030482, 0.061134982606745325, 0.04989218374248594, 0.057219285299652256, 0.03938274552638177, 0.08724329629330896, 0.021554154154728167, 0.07626111371791922, 0.021782923031423707, 0.13648906198795885, 0.012869895490439376, 0.07125706426450051, 0.06707560387440026, 0.0241715346055571, 0.03694629325764254, 0.026003166203736328, 0.041699066350702196, 0.036006815935252234, 0.06627898997976445, 0.02399593318841653, 0.06112258131906856, 0.07203670524177141, 0.07825035150744952, 0.05896480550291017, 0.06493843378848396, 0.021671159302059095, 0.02234570845757844, 0.02757742469839286, 0.03966912176110782, 0.02677581800526241, 0.019123911806673277, 0.029469034816429485, 0.05074334920209367, 0.038015472018742, 0.055696795316180214, 0.00803279679530533, 0.06358586964779533, 0.05662382311129477, 0.04208233738609124, 0.0818432071537245, 0.05442861336632632, 0.03839026772766374, 0.038117094300105236, 0.0273664543783525, 0.04438321040652227, 0.057597650738898665, 0.039511478462372907, 0.02412772006209707, 0.04716553688922431, 0.0590000315423822, 0.0432663375249831, 0.07967353099957108, 0.023074449236446526, 0.031008711084723473, 0.04587090850691311, 0.03649968362879008, 0.0316776199179003, 0.06235288776224479, 0.06817724046413787, 0.032834127196110785, 0.02685562300030142, 0.013563774809881579, 0.02471824140229728, 0.003726541722244292, 0.059677790486603044, 0.01815436451579444, 0.055415090901078656, 0.0647673242201563, 0.04604017754900269, 0.006930776144145057, 0.029090348398312926, 0.03128254502371419, 0.038188448088476434, 0.023154617883847095, 0.046166220199665986, 0.042481642522034235, 0.030340835692186374, 0.03927541612938512, 0.07158567983424291, 0.01581225405971054, 0.05787477610283531, 0.04387614542793017, 0.01875509409728693, 0.02669010922545567, 0.054691808618372306, 0.037438704530359246, 0.03874970097967889, 0.01934728898049798, 0.05722112211515196, 0.03840686957119033, 0.038111665489850566, 0.03379576875886414, 0.028225124806340318, 0.029833972948836163, 0.013833661450917134, 0.034105997619917616, 0.016155328521563206, 0.03251388305216096, 0.022758945560781285, 0.035770979957305826, 0.051932703936472535, 0.04802445037057623, 0.02440252992528258, 0.01944787596585229, 0.03327020946017001, 0.02304960955370916, 0.05364199620089494, 0.05048888531746343, 0.03292259862064384, 0.013652675752382493, 0.026728144293883815, 0.005957092307653511, 0.026640813921403605, 0.05007516396290157, 0.019380739431653637, 0.019792599850916304, 0.03278631062130444, 0.04704565777501557, 0.037165705507504754, 0.1442549843341112, 0.036512107180897146, 0.09458852480747737, 0.04524953052168712, 0.0629364384803921, 0.04137724143220112, 0.08462287674774416, 0.030212616693461314, 0.028153835955890827, 0.06490999468951486, 0.057910376926884055, 0.03027617793122772, 0.018265762737428304, 0.0076184019417269155, 0.025483503268333152, 0.03433003344980534, 0.059614065976347774, 0.016542046832910273, 0.052292411783128045, 0.027382030202716123, 0.0735793705098331, 0.06802482559578493, 0.022971238759055268, 0.02501167731679743, 0.022867024526931345, 0.031012366162030958, 0.050394331992720254, 0.03333765584102366, 0.0590025993733434, 0.05509899536264129, 0.016170498020073865, 0.03020895048393868, 0.045648375526070595, 0.024667153811606113, 0.0592641322145937, 0.04684809064201545, 0.014841923803032842, 0.028404312652128283, 0.034277077502338216, 0.003135847368866962, 0.03269282227847725, 0.039584646801813506, 0.0798079562082421, 0.09255543351173401, 0.04989404282241594, 0.048663205743650906, 0.0826254827552475, 0.06271363832638599, 0.11380157040548511, 0.024868934488040395, 0.03125730458123144, 0.022391988786694128, 0.031908999299048446, 0.09964850250980817, 0.06839307927293703, 0.022723470901837572, 0.007462181247319677, 0.08546834622393362, 0.026249446054862347, 0.015675144131819252, 0.02240315810922766, 0.03269741246185731, 0.016369211771234404, 0.01963315313332714, 0.02986764047818724, 0.016604457741777878, 0.07707722383202054, 0.0068867389563820325, 0.00892977039256948, 0.05425167422799859, 0.029913763100921642, 0.07875870040152222, 0.030136201457935385, 0.05762729582784232, 0.03970845558797009, 0.05131024241563864, 0.050546490820124745, 0.011812830434791977, 0.028243825072422624, 0.056136373095796444, 0.033692261422402225, 0.026175975290243514, 0.023639952778466977, 0.0208454606399755, 0.06598882508114912, 0.07831180875655264, 0.03754595229111146, 0.019053346550208516, 0.03970131241658237, 0.04247815071721561, 0.017009559051075485, 0.04170179374341387, 0.07599644901347347, 0.06130747256975155, 0.014073741585889366, 0.05695088017091621, 0.036276519822422415, 0.03176994308887515, 0.003668947119876975, 0.07435834355419502, 0.04899949512036983, 0.0367283022205811, 0.08637283128337003, 0.013061428962828359, 0.007796008085279027, 0.08237166082835756, 0.045590250520035625, 0.019065532615059055, 0.04841770700295456, 0.02783752148388885, 0.05015490030928049, 0.04211839092022274, 0.028064770813216455, 0.053625045547960326, 0.03677277913084254, 0.03513286654197145, 0.03763423075724859, 0.04853496633586474, 0.05669749982189387, 0.044842766801593825, 0.0036637506946135545, 0.0566671719570877, 0.008234185061155586, 0.0942442573432345, 0.1502920885104686, 0.10903005808359012, 0.0986954067775514, 0.09356034599477425, 0.07419136032694951, 0.20000161486677825, 0.17906546563608572, 0.11567460271180607, 0.10631807977915742, 0.20726165967062116, 0.11613971408223733, 0.21167354949284345, 0.11989596838247962, 0.12417143661878072, 0.16759334685048088, 0.1861032223678194, 0.13463398965541273, 0.08896781742805615, 0.11179264343809336, 0.14262487180531025, 0.14438778423937038, 0.1656650987570174, 0.06751529668690637, 0.13449240272166207, 0.09874000985291786, 0.11229059484321624, 0.1888141394010745, 0.09121883296757005, 0.13729254074860364, 0.11649728825432248, 0.11550193463335745, 0.128957272390835, 0.11977447138633579, 0.10439228077302687, 0.152119345148094, 0.11393340551876463, 0.10815903646289371, 0.1557885529473424, 0.18595295230625197, 0.14179310237523168, 0.13680129835847765, 0.16603832482360303, 0.10154818533919752, 0.12471401336370036, 0.09130565682426095, 0.09674496846855618, 0.17629967420361936, 0.07974304797244258, 0.16363951057428494, 0.0971273600589484, 0.17335940385237336, 0.13079110445687547, 0.29203145939391106, 0.1426909674773924, 0.11016254575224593, 0.15796273393789306, 0.1556209908449091, 0.1391830580541864, 0.17763650481356308, 0.21116534160682932, 0.07845151063520461, 0.13925667910370976, 0.1024497982871253, 0.2663358428981155, 0.13448987941956148, 0.10653998193447478, 0.10805615995195694, 0.07808469672454521, 0.12453631352400407, 0.08798520648269914, 0.18893892411142588, 0.20544513448840007, 0.13325021078344434, 0.1575509161921218, 0.19372585084056482, 0.18011290318099782, 0.14855117333354428, 0.14965780457714573, 0.1687603147001937, 0.13013620366109535, 0.23532876453828067, 0.13636883406434208, 0.1518368095275946, 0.11588873458094895, 0.12105126224923879, 0.11704912700224668, 0.08622070585261099, 0.10216132548521273, 0.0841007313283626, 0.1009473722660914, 0.11635236165602691, 0.18923082563560456, 0.1056839591183234, 0.09644958627177402, 0.15117237955564633, 0.12495586444856599, 0.1424691395368427, 0.12482640420785174, 0.16896449436899275, 0.1470961928134784, 0.2018526499159634, 0.12338669708697125, 0.09501099979388528, 0.11162080656504259, 0.10880379209993407, 0.14462795807048678, 0.2002291425014846, 0.054594264438492246, 0.1305879044230096, 0.2136399588198401, 0.11618132630246691, 0.11254549288423732, 0.10047873569419608, 0.07469517469871789, 0.18059743655612692, 0.16633398161502555, 0.1801306108245626, 0.09392223946633749, 0.17761093040462583, 0.06819853268098086, 0.14739374950295314, 0.22847090440336615, 0.07284654420800507, 0.21056531521026045, 0.17626853368710726, 0.18008109473157674, 0.2120992008713074, 0.16734851233195513, 0.10044625931186602, 0.1268754739430733, 0.16332755621988326, 0.1799503283109516, 0.16797674034023657, 0.10866247976082377, 0.14507962914649397, 0.14756987598957494, 0.1321849023224786, 0.17124708829214796, 0.07176280822022818, 0.10629926633555442, 0.10988288224325515, 0.10135024713235907, 0.18394477490801364, 0.1490335990092717, 0.133994807547424, 0.1555456331698224, 0.09603186845197342, 0.09496371756540611, 0.17408255254849792, 0.16862003394635394, 0.06327171853627078, 0.1256419948185794, 0.12820895004551858, 0.13668911531567574, 0.12549417384434491, 0.104920541489264, 0.10011247839429416, 0.19129576248815283, 0.1620077356346883, 0.08279297064291313, 0.15341807389631867, 0.1460277079604566, 0.12084538306226023, 0.11634386406512931, 0.0896565972652752, 0.12820745090721175, 0.16036194894695655, 0.149913014320191, 0.09576302545610815, 0.12895614432636648, 0.16025810764404014, 0.15426428552018479, 0.06322120054392144, 0.1983513159211725, 0.116557461587945, 0.19834209844702855], [0.04974842973751947, 0.029610477031383198, 0.042199073504889384, 0.061726808271487243, 0.10486277271411382, 0.061349659954430535, 0.05447125717182644, 0.032657503470545635, 0.06605847564060241, 0.017612589290365577, 0.021698366435884964, 0.04892955141258426, 0.02878982682886999, 0.013564554992626654, 0.06597474653972313, 0.016854648711159825, 0.04830400997889228, 0.029609621706185862, 0.06427985936170444, 0.0001217976819134492, 0.016618411973468028, 0.023202347256301437, 0.015079522381711286, 0.011405644618207589, 0.052325288925203495, 0.03572540466848295, 0.0987199496012181, 0.05178615203476511, 0.015189474343060283, 0.06219186769158114, 0.03328626953589264, 0.07415108397253789, 0.04521488335740287, 0.06246115226531401, 0.06464641352067702, 0.0719155347906053, 0.03114810497208964, 0.03776731638936326, 0.05714038386940956, 0.015334505769715179, 0.03156806036713533, 0.029472816058842, 0.0485258119442733, 0.011737194454326527, 0.06398340105079114, 0.08860574584105052, 0.02091027796268463, 0.0019525893776517478, 0.1066369806358125, 0.024976300992420875, 0.001304309698753059, 0.027181757941434626, 0.046468845757772215, 0.05344636236259248, 0.025492136301181745, 0.021702190351788886, 0.034994975503650494, 0.044931865340913646, 0.04901801541564055, 0.03502145904349163, 0.09763587222550996, 0.02990184977534227, 0.023474002991861198, 0.06435440067434683, 0.03546184205333702, 0.029849188831576612, 0.08745152808842249, 0.04577196537866257, 0.013105996786180185, 0.05024359066737816, 0.039998750362428837, 0.08084777189651504, 0.05009127227822319, 0.048940813503577374, 0.012275261724425945, 0.0552095864986768, 0.0262471992027713, 0.05515820019354578, 0.04421812336659059, 0.014059726127015892, 0.05718323176552076, 0.029129374233889394, 0.02880647691199556, 0.036666696541942656, 0.06682513645500876, 0.054899851165828295, 0.03210815462807659, 0.03135018436296377, 0.023644977118237875, 0.03070974060392473, 0.049243465036852285, 0.05528259527636692, 0.048271262712660246, 0.03820262681983877, 0.043703614646801725, 0.0069954487480572425, 0.049146117526106536, 0.23914147401228547, 0.06960284677916206, 0.07134186947951093, 0.015134163932088995, 0.03406729461858049, 0.0917401174956467, 0.10022697693784721, 0.027284946154395584, 0.06088658206863329, 0.022324199162540026, 0.05368747872125823, 0.008826880894048372, 0.099458913464332, 0.043040420350735076, 0.06484886398538947, 0.044628835312323645, 0.05587904823187273, 0.024073938475339673, 0.0336193417024333, 0.029908059696026612, 0.025491585256531835, 0.035714702898985706, 0.011690344526869012, 0.08419189674896188, 0.08976371886092238, 0.016065274467109703, 0.03121338799246587, 0.024971310049295425, 0.025039980973815545, 0.018677190855669323, 0.0575615229899995, 0.05670105842000339, 0.013095654030621517, 0.007847489014238818, 0.007618253976033884, 0.08591991339926608, 0.024104262629407458, 0.026292948896298185, 0.13404451659880579, 0.0047776317933312384, 0.026990675323759206, 0.03505576110910624, 0.0709057018684689, 0.04653470023185946, 0.010154027404496446, 0.03375692103873007, 0.04494714245083742, 0.037066224322188646, 0.15078362775966525, 0.030337946882355027, 0.00927968931137002, 0.06327698036329821, 0.010124246873601805, 0.0728903160779737, 0.06530676168040372, 0.029503557670977898, 0.013111034113535425, 0.035241876903455704, 0.007027631054370431, 0.03906158854078967, 0.011237077833357034, 0.043856816191691905, 0.09748539436259307, 0.035986711154691875, 0.03403585353225935, 0.06498737100628205, 0.11751233105314896, 0.028153889761597384, 0.029564957403636072, 0.050163245759904385, 0.005200620717005222, 0.06201586365932599, 0.03682273680169601, 0.045046230297884904, 0.04700584897364024, 0.017499884888820816, 0.04643422085791826, 0.06253781612031162, 0.032017753619584255, 0.01364357145575923, 0.027122913052153308, 0.03241349273594096, 0.05864211227162741, 0.030321165068016853, 0.05952209532551933, 0.016846293983689975, 0.10244104836601764, 0.0226000127804582, 0.0439158651715843, 0.04258188069798052, 0.012008784324279986, 0.03198587837687228, 0.05421905683760997, 0.08066768234129995, 0.022774265344196465, 0.020018856557726394, 0.06154269998660311, 0.018948078468383756, 0.05615020672848914, 0.06484504934633151, 0.08023992326343432, 0.023463282668672036, 0.02169833860534709, 0.02472359970852267, 0.011975260586041259, 0.07277245560544543, 0.0176746866418398, 0.023491467582061887, 0.06917721766512841, 0.05026409249694552, 0.01105780371290166, 0.0055085442818381125, 0.048508453110116534, 0.03536210111633409, 0.06330923410132527, 0.023978691242518835, 0.014830720156169264, 0.07350080675678328, 0.03857919626170769, 0.06761015058145858, 0.040506550067220815, 0.038980701865511946, 0.05763857647252735, 0.10328652526368387, 0.056584927151561715, 0.015240961765812244, 0.015000107941887109, 0.03512062110530678, 0.04625155605026521, 0.04285522110876627, 0.017198402238136623, 0.013668971459992463, 0.03684468952997122, 0.038964278137427755, 0.026471273995412048, 0.03012992845469853, 0.06940302351722494, 0.07742748784949072, 0.020575868074956816, 0.05328932762495242, 0.031672825643909164, 0.036012211348861456, 0.0512585518299602, 0.040431188681395724, 0.025466645383858122, 0.05990105448290706, 0.012191119803901529, 0.04396068718051538, 0.0382579502183944, 0.0035062739152635913, 0.04802457282494288, 0.03936436623916961, 0.07242680032504722, 0.03662597489892505, 0.049185625757672824, 0.025709669062052853, 0.05677500972524285, 0.03620376708568074, 0.049807545510702766, 0.01463017051719362, 0.050378713494865224, 0.03722887340700254, 0.050780089222826064, 0.05574584756686818, 0.018964168230013456, 0.044035068931407295, 0.06672335832263343, 0.03434930702496786, 0.05316480266628787, 0.018474081734893844, 0.03252924550906755, 0.030403690034290776, 0.08506522644893266, 0.025036975275725126, 0.04491613552090712, 0.036172136751702055, 0.08432517905021086, 0.011528520153660793, 0.03377887747774366, 0.07754306992865168, 0.028705095828627236, 0.04905921203317121, 0.06610488213482313, 0.03285015016444959, 0.03121767018456012, 0.045019872923148796, 0.02522534163290402, 0.062073446897557005, 0.06605697650229558, 0.05339791867299937, 0.05725178023567423, 0.0319715103978524, 0.052853861343464814, 0.03336089619551785, 0.037867324499529786, 0.06793355627451092, 0.0648686644854024, 0.023221691335493233, 0.06291699421126395, 0.014672569413960446, 0.04173259287199471, 0.06261531860218383, 0.08126327069476247, 0.028039064673066605, 0.05680233931343537, 0.013799212811136385, 0.018755741621134803, 0.017899288359330967, 0.02525675303331809, 0.005540747461054707, 0.06786908590584062, 0.024681603426870424, 0.05545239124330692, 0.045829314840375446, 0.026482081520953216, 0.005572189011218143, 0.021933174539299216, 0.023717893127468415, 0.017441676391172223, 0.02653474988619564, 0.0694666404160671, 0.027107888272439595, 0.04647139132430311, 0.011409428643673891, 0.08331524964887649, 0.05733762816817034, 0.06282747635850683, 0.005187206861592131, 0.023064222441462334, 0.030121555173536763, 0.05060109804617241, 0.05263503910100553, 0.02964708532090299, 0.02033964432484936, 0.042897534658550285, 0.08610453005530871, 0.05390282400185242, 0.011330301786074415, 0.060473521225503646, 0.040754037763690576, 0.05319010990206152, 0.07140541216358542, 0.11993945081485435, 0.013866359549865592, 0.08616177190560848, 0.059374522970756516, 0.04703243641415611, 0.04832273807551246, 0.03424482747504953, 0.04856549086980522, 0.07003900696872734, 0.05869660817552358, 0.0320538628147915, 0.017746459743648302, 0.015275278674380388, 0.16621032496914268, 0.12358793785097077, 0.09262726598535664, 0.19306591828353703, 0.2287193457596004, 0.23078377795172855, 0.07514779572375119, 0.12490088614868, 0.28273819712921977, 0.1601837741327472, 0.06823360658017918, 0.13099629344651476, 0.11980935974861495, 0.22156712017022073, 0.2220427626161836, 0.0552871149557177, 0.13420427130768076, 0.17603413376491517, 0.2300176737480797, 0.1428990508429706, 0.12819948024116457, 0.18640503898495808, 0.06858774460852146, 0.11207721254322678, 0.09733788509038277, 0.11682908021612093, 0.11778492931625806, 0.16303130571031943, 0.0958539979183115, 0.2141639299225062, 0.1713922672206536, 0.11859194812132046, 0.14024752046680078, 0.14404078567167744, 0.13633557100547478, 0.09593926326488145, 0.11037030999432318, 0.13980456220451742, 0.10047817908343859, 0.09696364228148013, 0.13464768970152363, 0.12275650980882347, 0.22319519921438769, 0.1492085529025644, 0.11772921629017219, 0.21478865499375388, 0.168925175385084, 0.12279298636713065, 0.10509412983083166, 0.14567781501682475, 0.09234524244675413, 0.13741174450842664, 0.24768329691141844, 0.15504446084378287, 0.1077700471796561, 0.11794613863457926, 0.18271604552865028, 0.1846727475640364, 0.12928585085319355, 0.08889095319318585, 0.1842672232305631, 0.086882315663388, 0.10111393246916123, 0.10692455543903634, 0.12639727850910276, 0.18410138291073963, 0.16723910492146388, 0.14180291356751695, 0.12022684750263579, 0.18916780245490372, 0.1412411968340166, 0.21231000049738213, 0.12844798096921295, 0.2108221873641014, 0.13253534445539117, 0.11115216257167049, 0.11253945922362618, 0.23026446753647178, 0.15546628274023533, 0.12784865219146013, 0.14046802738448605, 0.06700369718600996, 0.17531573481392115, 0.2106779583846219, 0.09988591555156745, 0.1233492631581612, 0.1250814358354546, 0.1422379308496602, 0.1128761716245208, 0.14096703263930976, 0.09808537623030134, 0.1478635735111311, 0.08643470413517207, 0.11623602258623578, 0.1080713071860373, 0.12554556014947593, 0.10659605119144544, 0.30519199382979423, 0.18695755308726802, 0.23655989847611636, 0.14072176767513156, 0.19760700117330998, 0.15497377869905904, 0.22008625353919342, 0.10845753567991778, 0.12850220227846876, 0.14787521038670093, 0.1676274708006531, 0.14464106439845636, 0.3448602621210739, 0.06904648093041033, 0.1376308116596192, 0.10986386841977946, 0.14815770147833973, 0.15055063791805878, 0.11262744083069265, 0.15378457610495389, 0.11922459932975471, 0.16444796172436327, 0.15105562488315627, 0.12452083232346922, 0.21194973232923076, 0.08374305325560272, 0.1967012693057768, 0.2161493679159321, 0.0976989399350714, 0.10066951217595488, 0.1389240930438973, 0.14250405016355217, 0.0925059471046552, 0.11158833018271253, 0.09920282798702829, 0.1494881941471249, 0.15694818837800995, 0.13951598550193012, 0.17779557674657553, 0.0780589367786888, 0.11374255482223816, 0.13582083221990615, 0.13598475779872388, 0.15208047145279124, 0.09378468239447102, 0.19882351480191574, 0.17814873513998464, 0.11091699823737144, 0.26545268716290593, 0.13092765962937847, 0.17610226292163134, 0.11607196342083625, 0.1550572257838212, 0.13650939683429897, 0.15901958191534504, 0.1532013964606449, 0.10960003492073156, 0.1213287290011067, 0.1393984886817634, 0.10993650983436964, 0.1453131384914741, 0.17208188568474725, 0.235777348279953, 0.09306079897214659, 0.1680059512727894, 0.16465377411805093, 0.20873332367045805, 0.09957923044566996, 0.13547763344831765, 0.1293896624702029, 0.12636805273359641, 0.12265557030332275, 0.1354582782369107, 0.12445632484741509, 0.09641276832553558, 0.15656385978218168, 0.13050717359874398, 0.0945205069729127, 0.13675887719728053], [0.03804431929893326, 0.11266353889368474, 0.009354606336273719, 0.026379019473097287, 0.025952518335543573, 0.053611720286426134, 0.09310407360317186, 0.039592517277924344, 0.015865033747104462, 0.08583260714658536, 0.022847205473226495, 0.022579679789487273, 0.03507683810312301, 0.0396673109207768, 0.031020279311633203, 0.030450692102022003, 0.07894830428995192, 0.026372520114819054, 0.043551229464355856, 0.03934184947866015, 0.011944924372073729, 0.04801156297617126, 0.02826614145305939, 0.020816767355427146, 0.042560970687191, 0.018779269557853695, 0.06557573826285079, 0.017940895013452973, 0.04155033624556381, 0.01784467927791411, 0.020071506369276904, 0.03395757179532666, 0.04344929548096843, 0.049356995077687316, 0.06136548254289664, 0.023871027879067697, 0.010312857211829396, 0.035877945701940916, 0.05499535443959758, 0.06694728654110804, 0.0650732968642842, 0.008298848388221813, 0.04473498840525281, 0.03849104767141398, 0.03446985407208558, 0.07232237272546627, 0.010816941539815161, 0.018849938714993186, 0.07998880275408737, 0.019406250758038368, 0.09089399492950179, 0.019035796613025013, 0.04637796235329006, 0.01718376894132234, 0.0386539342434844, 0.012980028350284556, 0.010545174482103903, 0.062147661665221676, 0.04478828202991281, 0.013092261488054646, 0.08615995364380069, 0.05036522125010379, 0.019373807772353757, 0.05494661760167219, 0.015985348873073235, 0.05988904282276053, 0.06480620533693582, 0.06259340298129246, 0.027782710167230107, 0.02854972906789044, 0.04012488207081333, 0.014731828050571494, 0.017801213543862104, 0.022235570031625684, 0.009771655295480741, 0.018658501721802168, 0.05755079895607196, 0.0633924882276915, 0.016188884728762787, 0.01588160404935479, 0.06843809052952565, 0.04165235557593405, 0.006985336058278335, 0.01835120619944064, 0.022237143384700175, 0.05793368778540753, 0.0512882971088402, 0.04757421535032336, 0.01710337764961878, 0.02145758960978128, 0.022654347267234698, 0.028227631410118192, 0.0184778091715998, 0.01625917910132557, 0.049394095040042885, 0.048065216542454436, 0.04952001152560115, 0.02697317919228226, 0.02412240628473228, 0.06901557047967799, 0.040093081042869017, 0.024595705399406143, 0.04083197069121525, 0.006363099964801222, 0.01264297827219707, 0.08802206895779818, 0.018503198043617886, 0.03120969580777455, 0.05835273033881094, 0.024222416250267997, 0.07601991572300903, 0.019937780634791125, 0.06550459598656744, 0.0170654167959583, 0.030750727564736735, 0.05635732159134932, 0.025097235811699647, 0.005395962334659998, 0.03372470069734845, 0.036191725739627145, 0.040883275360101834, 0.10786139071569778, 0.02979571152536664, 0.03863867197651416, 0.04638572521798778, 0.012687483012996381, 0.0360360825288808, 0.06433459275285713, 0.03534926938300487, 0.03590947584598325, 0.06012235549860634, 0.05470740485179704, 0.04632863179722335, 0.05356117631890811, 0.05679656540451106, 0.03025922727829311, 0.0469552419235697, 0.022085149685153738, 0.004839952252950752, 0.04242692026309669, 0.01793001141777495, 0.018373659877397586, 0.03854584043438081, 0.01888197166408645, 0.06980173493502662, 0.020453430406632833, 0.05790637675090693, 0.0449267185467761, 0.006215533176145982, 0.09103309566853568, 0.02545118459238438, 0.04402648228278849, 0.020589555133483373, 0.049038094221032225, 0.07581520912935957, 0.04862462148594204, 0.04441260316525586, 0.04347931906522717, 0.10527813050430268, 0.009566739045112627, 0.02064854845230002, 0.010675798966985894, 0.0870150190894492, 0.05854326933331322, 0.022204713386599906, 0.015156658428168157, 0.008540525068383431, 0.026090704377566, 0.023464624100597575, 0.016151346899277996, 0.08261960494564846, 0.038717629067832604, 0.028033914168190677, 0.015453408032044536, 0.04264601710019633, 0.030230259399104398, 0.03732385717739817, 0.06363757507642731, 0.0474858997768024, 0.05744516907725483, 0.04035966790979728, 0.05782629901659675, 0.06262660666834563, 0.04086432832991704, 0.009055929931491846, 0.04651042829209473, 0.020502998449956067, 0.011621117919276003, 0.046983911088318564, 0.06136172356491443, 0.045111127401469275, 0.030230023767217062, 0.05176888967980631, 0.025444143466302194, 0.02301489374076482, 0.017476035973231774, 0.03414374696149025, 0.05736502826039214, 0.05129144752572756, 0.040152708897949196, 0.023329723917413503, 0.04737380579172168, 0.07837737750378437, 0.04456048351130448, 0.11133807056467049, 0.04161932258284651, 0.03332555141241755, 0.028850259914179333, 0.043055292990175076, 0.026962212104990613, 0.037792742368765175, 0.04891134281933773, 0.07722048801952042, 0.027518229144334327, 0.07233879645355046, 0.058291187742725015, 0.025482417877356056, 0.030910766145098023, 0.1048559597984422, 0.0442145573470043, 0.01957809134182753, 0.03152821816911455, 0.04317938750318717, 0.032939129960141145, 0.013066452374914661, 0.04537143940979149, 0.02854401453078026, 0.07000102385063656, 0.003615740465647832, 0.06395980817615055, 0.03630857689131517, 0.0068206094238121295, 0.04088621055416297, 0.047740623413119465, 0.0622509240929503, 0.09243875305401161, 0.02563254878623411, 0.039539947247249074, 0.06977515120524913, 0.06577562089660205, 0.03906966681824997, 0.10149379333597608, 0.028387169040797744, 0.014079907905397704, 0.013994963537697913, 0.05149012045876589, 0.014831365824647946, 0.07103580777766183, 0.03979529057687614, 0.022335617104545236, 0.01864440277131507, 0.09282320781494491, 0.02501811173715396, 0.0947161074145697, 0.10650380223523825, 0.048522167999180965, 0.05624634453852195, 0.039917143803904764, 0.03675041822134517, 0.039849986860645004, 0.06569244098500349, 0.01353101270069601, 0.06242222661967389, 0.1136306241096463, 0.01854400132287992, 0.025179063159157522, 0.005405972515291069, 0.02745249712461373, 0.014951430475775851, 0.0481757520174142, 0.048884963180171326, 0.016501135942235123, 0.008474272617604584, 0.08403075422393158, 0.017558479303261265, 0.04365357162896544, 0.02912794745498104, 0.03412128586205654, 0.05486609457875602, 0.021007137511332985, 0.05120351415826008, 0.02281710025272332, 0.03767444402910769, 0.029367948736762628, 0.038248996206675656, 0.07766345370328054, 0.06218813097802922, 0.013878887002647389, 0.020339421680546366, 0.043843468665727414, 0.018992577643075492, 0.08748922919039614, 0.03294432128313929, 0.0859081800444983, 0.05942521536780987, 0.011171779042342678, 0.028016022843075916, 0.04962834653269965, 0.08763325779000297, 0.0052995248825027375, 0.010079009261971805, 0.09451712277950719, 0.0550732094416162, 0.010990660684910836, 0.06619802166824229, 0.052750821560039185, 0.05019737713155337, 0.06052126358554233, 0.02444508281769231, 0.05438291191239841, 0.010220245530945249, 0.009677962862042477, 0.01456677997339284, 0.030127056343189906, 0.027140858182974625, 0.009369606068503344, 0.0338114911573939, 0.019403024271014147, 0.061306956777116284, 0.10764911421574652, 0.040451052263961174, 0.04658109930460341, 0.023225201694003772, 0.004245702548359986, 0.018165797300753184, 0.02735423120611813, 0.06563077593455091, 0.05017553943616804, 0.06127010172349401, 0.014634365506935865, 0.07578826174722053, 0.029515168571379036, 0.021352898547775112, 0.019422624391154386, 0.05621336349577177, 0.027618489584710915, 0.03920418850611895, 0.03498168363876175, 0.006322641320366529, 0.026093340857187286, 0.037153371013118885, 0.045808415961801074, 0.03995304519776255, 0.013171489463275066, 0.027364276174921542, 0.017729824503476266, 0.05191496660700068, 0.041964246847783215, 0.027199933138035703, 0.01928356447024271, 0.060786566536989994, 0.011363796766090672, 0.1222048640192952, 0.1788550816127099, 0.1668936648638919, 0.1191455012303777, 0.0981745972239878, 0.10133325195056386, 0.18858394003473222, 0.08925896196160465, 0.15497345215408131, 0.1552242535399273, 0.1323075348045677, 0.07478869272745214, 0.07880421631853096, 0.124356572778197, 0.09077190421521664, 0.10397744990768842, 0.11242379550822079, 0.1733118321863003, 0.086481771140825, 0.08139549172483385, 0.11399436552892439, 0.20405290997587144, 0.0855659312219359, 0.14160948019707575, 0.09437131302547641, 0.12805741833290085, 0.25404498679563403, 0.09401667033671401, 0.25702551123686135, 0.08385406370507553, 0.12497713440097868, 0.09234507917426527, 0.11770737488404848, 0.09912924404488876, 0.1997735380427912, 0.10987206173012964, 0.1343102054670453, 0.12159090751083568, 0.19400795601541176, 0.12228972860611975, 0.08170528642949648, 0.10762314646854065, 0.16907127457670867, 0.11755856685340405, 0.14215454313671216, 0.18394275626633316, 0.117805523914285, 0.10272113489918411, 0.15212891885312274, 0.27594374609179795, 0.1629505303571932, 0.14836980728432536, 0.13427510188193992, 0.20588359533576295, 0.16741619620006531, 0.101097605220275, 0.12521450291387737, 0.15642509300960228, 0.13261902902740985, 0.15976739960024133, 0.09920624928781763, 0.145227019675076, 0.15029306814540178, 0.16183428087970242, 0.12390498333843425, 0.30544732231646776, 0.1252599965664558, 0.13579911697888747, 0.0868202350102365, 0.1760482048848644, 0.0922695359622594, 0.17056109150871634, 0.07824080748832785, 0.2059661815292202, 0.1391794066876173, 0.15778963541379198, 0.1381228704121895, 0.15405876998556778, 0.16883666685316712, 0.15382911980850622, 0.162935568660032, 0.10093084463733248, 0.16543025354621932, 0.12097742597688921, 0.1139541485463269, 0.11989321501459926, 0.18753771961200982, 0.2189191966317594, 0.1897850912064314, 0.15539778250968084, 0.08840949230943806, 0.09927700564730912, 0.07374963402980939, 0.08758850628510118, 0.21199791255639866, 0.12497468531364575, 0.15138506423681974, 0.14721416460815817, 0.20745751244248822, 0.1157515708473511, 0.09344037782284431, 0.1552057740627788, 0.1559070442453958, 0.122690614516614, 0.1323492286610417, 0.21974586008582264, 0.11306645828881301, 0.1390159412403591, 0.12802316079614684, 0.17179814778501168, 0.1422426657518372, 0.16868149861693382, 0.22937282163184136, 0.08054739504586905, 0.05335584261047188, 0.1839477286557667, 0.10540554241742939, 0.18846659164410084, 0.14542095770593733, 0.05954331332759466, 0.11962627191678621, 0.19558724627131596, 0.21146269049495459, 0.12942335597472265, 0.08683505569933914, 0.2636251039803028, 0.08624305191915482, 0.13367357634706423, 0.14913407096173614, 0.13304448744747788, 0.19343458756338805, 0.15686840750277042, 0.1476110948715359, 0.08933445322327316, 0.22518467449117452, 0.20002279576146975, 0.12874902575276792, 0.07154998995247297, 0.10313194332411513, 0.1199305227783043, 0.09047311556059867, 0.10086854876135476, 0.14812589302891865, 0.18555998511146754, 0.1069072337122634, 0.0833159546891693, 0.09063871097168885, 0.10129626331035979, 0.11376746871974319, 0.2696674922481179, 0.10873780775000341, 0.1891029832768254, 0.13546357717132196, 0.10208919615251943, 0.20216648932546377, 0.14098974235821515, 0.11040461205993779, 0.10619016320561059, 0.18901272327639163, 0.1436823877156712, 0.1480213986360468, 0.10708494839491323, 0.16112284327391535, 0.13810442062094808, 0.1139901130227372, 0.1395099444198422, 0.18970908044138923, 0.08561387396184728, 0.1046760038298089, 0.1048722276755143, 0.15577126090647653, 0.15476965840207413, 0.11997561567113735, 0.09990305174142122, 0.17474619584390894, 0.1692225836450234], [0.0409693533583777, 0.019096782598353457, 0.02345197048271075, 0.027427462628111243, 0.02679844979866175, 0.06219747832801659, 0.05242283681582194, 0.010825858444150072, 0.011029579836758785, 0.05230751819908619, 0.03104616356722545, 0.01911090010253247, 0.014000750434206566, 0.02652600553119555, 0.037734903089585714, 0.07706815478741191, 0.028961711941519752, 0.044329775773803703, 0.04399401703267358, 0.04098469355085399, 0.04663454878027551, 0.028945624035259243, 0.048969033668981865, 0.04451832210179418, 0.027091740994364955, 0.02871718541427981, 0.04042375607241411, 0.04046379865030758, 0.017789795601856895, 0.06619519408559427, 0.05070046419859864, 0.011704402659233892, 0.0741084550099913, 0.02757003476290265, 0.027543369396880735, 0.06623060195124708, 0.043161408975720406, 0.07422135793603957, 0.03867749001074117, 0.012517501509137219, 0.025458453928877134, 0.04095375712495297, 0.005309876914907363, 0.0665670471789781, 0.04080073369550519, 0.04125364786887076, 0.06093069903727155, 0.009288081146223703, 0.023166382779891137, 0.0459643968497403, 0.009813487376959529, 0.09805105932173319, 0.02119956898241071, 0.049812272991403006, 0.076379211677704, 0.0792454750626348, 0.010752565794973634, 0.04188186845567543, 0.02493804884579731, 0.019763865748245735, 0.04889957977866288, 0.1157158958085347, 0.02332967382244533, 0.04201597083010711, 0.04308812931412831, 0.02057306275673909, 0.033327447599731386, 0.024586576982983388, 0.04377008881419897, 0.0687772742821835, 0.062316411203937605, 0.04098810371942818, 0.04183718003332615, 0.04164148682320956, 0.05658297159243375, 0.04075336612004321, 0.01209018679219298, 0.015328525914810598, 0.044406940578483045, 0.046876785781932995, 0.026811904936039355, 0.016816504175949376, 0.05691462254617363, 0.044219563133083284, 0.051706894373637624, 0.02873263136280002, 0.0360862776869908, 0.04057369216752704, 0.022117794906080235, 0.030229186995711643, 0.057219960654038005, 0.009403325548191788, 0.022903998324181885, 0.040301721019204706, 0.02478036843967857, 0.016273675100819673, 0.07296801151824184, 0.016108929448819254, 0.03700950197526254, 0.04275912040611729, 0.03996834457211662, 0.012998378879274242, 0.022141159570310265, 0.0389346775773447, 0.029949408453830983, 0.07547519417130388, 0.03459080558968708, 0.07212433061795309, 0.06029577685694676, 0.01946231073816307, 0.08164337647031061, 0.021950665104668587, 0.026393062762508634, 0.013589689679065486, 0.0577468780829804, 0.02824047056492418, 0.006606871356780175, 0.01659420126088662, 0.0968520826427266, 0.0406973079952877, 0.07917569833807647, 0.04297675892303232, 0.026504229062993545, 0.04376453383883927, 0.044675301178358495, 0.03742705281183589, 0.02379825287789572, 0.059713985028793104, 0.02343085638131015, 0.058255152762285434, 0.06336770791676827, 0.04664948079152964, 0.01441976886781049, 0.027150372516189236, 0.028911086337757297, 0.05744121714087669, 0.038601839187322184, 0.046224033503676765, 0.023989478358998895, 0.007875386345403967, 0.007719815494056093, 0.044663159642368555, 0.012799046362488298, 0.01893325777928112, 0.08039433450903744, 0.033638474269537255, 0.06709156004944816, 0.012168113225925481, 0.05510448354471009, 0.0347796302230563, 0.035763977793976665, 0.01919808390084654, 0.05111186263093259, 0.033255986199947074, 0.013801408640574664, 0.04315076657803729, 0.046755912189837545, 0.05002939942642115, 0.015391032375191571, 0.0218073137148167, 0.07177889798185788, 0.05675954707839992, 0.02076333086733939, 0.002975938200506789, 0.026143428403884172, 0.03599323834350798, 0.04295425700547639, 0.05458577797980979, 0.0254813454739633, 0.055781693299650215, 0.018766165085253306, 0.016565071964578237, 0.033197000302607194, 0.0032157386385733844, 0.05804208958579693, 0.08277373417513445, 0.03818599529040512, 0.027685611275956035, 0.012570355411298806, 0.027888148943020497, 0.03623740121838637, 0.03240767429815605, 0.048110487550729886, 0.04270387864380609, 0.04799220405402593, 0.08246175755630247, 0.030695470959472004, 0.029160242011130322, 0.018529778062656987, 0.02783523937978316, 0.05753882440330926, 0.049443451571278274, 0.04607992697856389, 0.03148869138385635, 0.042068596521858126, 0.021589671487163287, 0.007107298752089264, 0.09761644279933535, 0.02593709094071528, 0.022757626393286046, 0.05997792613925412, 0.020476509344007354, 0.012330817971815122, 0.037867380160605535, 0.011038082066079369, 0.031949565091053955, 0.013805051657982403, 0.057865643975674175, 0.031346755640697666, 0.09373162625706755, 0.0410531010129489, 0.05135179897479247, 0.026705963355198037, 0.054057335437391885, 0.005791428711745539, 0.03908246515493374, 0.09093733635381795, 0.021355648204917088, 0.05395549422246404, 0.024861316342139617, 0.03188333212165162, 0.03928110469132662, 0.07808388778357767, 0.015598124045936856, 0.014066917538002599, 0.06968097266508266, 0.018928534009319264, 0.05950537473836448, 0.04769506667798851, 0.012542619497253327, 0.036235137667972594, 0.09423193027032539, 0.022956327156862244, 0.01679588731349213, 0.005546847451114445, 0.04046646296046674, 0.08668943890370429, 0.05573387672484387, 0.023187324331956916, 0.013420298182609258, 0.01604206936463015, 0.05837914708536118, 0.050486907493905164, 0.02187231286370661, 0.021368196066759992, 0.017694054840831086, 0.038087222856120206, 0.02293263594765449, 0.055172044958453625, 0.02238494580524275, 0.03047244630579371, 0.052711769749294035, 0.01774122574715875, 0.017356266325805336, 0.09528290043817833, 0.02740808886301238, 0.030435238732025027, 0.04081006620253902, 0.0442766157357255, 0.047679503841209225, 0.0067211518944532145, 0.06718737131450325, 0.022476909034594428, 0.03599693423893768, 0.03496102224744391, 0.07969997372129001, 0.037934010179014876, 0.03311029518954456, 0.04256698950484861, 0.021641850034939125, 0.07566682412289083, 0.0783848509308882, 0.09150991070782766, 0.05339008530427236, 0.013325953586900141, 0.07953192922286689, 0.010513097931834636, 0.034046510772896, 0.03464034765784163, 0.053566645947284997, 0.062377267313422635, 0.0351509378378978, 0.0433288374915719, 0.07922021235572174, 0.05303496764099691, 0.03475539167993702, 0.011604760056798114, 0.07236664183437824, 0.060044752826797776, 0.028511289528978523, 0.05961834445770364, 0.0398049496288877, 0.0480355677427724, 0.06679334284854122, 0.03799654354224913, 0.04390892238006927, 0.053124574551475234, 0.07544965686975047, 0.007728618293185718, 0.06667183100944385, 0.03784350526984781, 0.022583926729566883, 0.02641493199917022, 0.02863511130271945, 0.08349358031409793, 0.04083289095433429, 0.025915136357070878, 0.07365416415268555, 0.011283833136985777, 0.016102702829812188, 0.04867092036874965, 0.1128710582270287, 0.03229922796890605, 0.015609447364113294, 0.0697566791495774, 0.010099091778101865, 0.015395240352518158, 0.03319320050650276, 0.04058621962030884, 0.06111950882768724, 0.06207914288097527, 0.030213444188120775, 0.033463490690337494, 0.014020339422131656, 0.02795170647004852, 0.04674081319535617, 0.007767192810206325, 0.03240060163079761, 0.008393213392992038, 0.013299447782628704, 0.03495184559142217, 0.010615467926982092, 0.05043574012233876, 0.04760517032991629, 0.017929848145286087, 0.0073603047803771915, 0.04377791105071083, 0.04791792620380875, 0.045945230885990895, 0.03898853152350057, 0.05534689866180997, 0.01565847920574015, 0.02992772660945775, 0.008409250276599778, 0.034251406614203006, 0.028139534770161845, 0.02377286771661602, 0.04248134195222519, 0.039606221034773625, 0.03727440045622643, 0.06567806558450684, 0.06623809022130445, 0.15760904119815677, 0.12970927578862756, 0.1359394719474949, 0.08380255123483948, 0.10598810607916676, 0.22509434027597308, 0.13498088432243094, 0.10514513021917082, 0.1188149189692922, 0.1453489693813026, 0.14234379079425707, 0.09613392117898911, 0.10496919669094495, 0.2450709667755291, 0.20717359642731026, 0.1352571413735859, 0.13760675123194233, 0.1832545330398716, 0.15404786041472107, 0.06334062694804743, 0.11358901188941672, 0.2179268264444545, 0.1074030106246937, 0.13243775203591213, 0.16269340587314218, 0.10417201876407489, 0.1655974445748143, 0.14170956623274833, 0.06924372151843272, 0.23764009441947564, 0.188884673116263, 0.19499513116898015, 0.11014935036655515, 0.11451786907855421, 0.1755721468362026, 0.25825741700828075, 0.14620420552091673, 0.19864392990712076, 0.09906968669383787, 0.1870788645464927, 0.1339374395320192, 0.10429779053083621, 0.09763034322531894, 0.1539041954674758, 0.16174347168998793, 0.15944980492349714, 0.16638090019114316, 0.12837965885410085, 0.11885273139341734, 0.1153910429275129, 0.09825755449128337, 0.16370723897125572, 0.09341053606476635, 0.08815039371256717, 0.14100408065132797, 0.1500517810927704, 0.09971684688935056, 0.12406009962433018, 0.14065881870919839, 0.08900265383999795, 0.1603167224675417, 0.21642936539137736, 0.17936009826371446, 0.08689051639521495, 0.1539300667354837, 0.14319853711640462, 0.11970556297455914, 0.16029476973926648, 0.20918548456393182, 0.1746781260590069, 0.15567375754471868, 0.11558989397599362, 0.13258704246254638, 0.1351406835601665, 0.12336953863268718, 0.17150922969449311, 0.059425222789286636, 0.11233173208893277, 0.12765631719958037, 0.1207360795524437, 0.11470912053482607, 0.11902014506631531, 0.2359936249558814, 0.16323413467034698, 0.1343276459374465, 0.24093514104606584, 0.09021636957186274, 0.29746311949566007, 0.12267102181795053, 0.14242143428418785, 0.15736689325422049, 0.10902186477323994, 0.17048266134224832, 0.14317425404442474, 0.10400686122011393, 0.16056602471508086, 0.2634897065581754, 0.10186209154198878, 0.09492899989709258, 0.25380942912306637, 0.09827491332544014, 0.14029819431016222, 0.17463022784795612, 0.1013031875481829, 0.2565878815948963, 0.09069452789844945, 0.12850638799136505, 0.18275693786563352, 0.08634988407720812, 0.13505834969691932, 0.22447115887189284, 0.1372864402947016, 0.12251684805960394, 0.11136299930512905, 0.15259010426234454, 0.13026520377025008, 0.16037106252042577, 0.20041021169163287, 0.15657551150070503, 0.12317486587562598, 0.17982313904212788, 0.13646733190398663, 0.13340862962650135, 0.12339858629275113, 0.1461159493192099, 0.11760202702134848, 0.131552770617418, 0.13933502021245658, 0.12081108841812238, 0.23050575458910316, 0.11989952326985076, 0.1639236492337659, 0.12022479175357148, 0.08928517461754382, 0.0872505248116795, 0.1782441753312014, 0.14611393067752942, 0.13067725900327787, 0.11552957963431254, 0.0917919936182443, 0.07659649767447263, 0.11193293161340989, 0.10157836106372997, 0.09831815827055834, 0.186549668724183, 0.11891255591763183, 0.20245086547220126, 0.12257990092621185, 0.1376151671865955, 0.14069598546484485, 0.17783732997486368, 0.12022046503261663, 0.09205478068906814, 0.11561135688680224, 0.10849805694306269, 0.09367998762172647, 0.15463001589523628, 0.14420447376323864, 0.14101429260335863, 0.09687871090136468, 0.1588773270486854, 0.15012045943876728, 0.16236271971138194, 0.13896342687075958, 0.09595053648808971, 0.11997772337053902, 0.16428764298325405, 0.10913904989138246, 0.1649251181515865, 0.10774621681775898, 0.11534492587088607, 0.08524954624590464, 0.08004948816960678, 0.12061269007972442, 0.15452187013579533, 0.2828879625303671], [0.009016896674438613, 0.06703673760057427, 0.05473645622259937, 0.036361280508572236, 0.014509014908981044, 0.05084130898467265, 0.02107081192662008, 0.04835276537050959, 0.005538158293347806, 0.11466390889836475, 0.05139790860994253, 0.057698144955793396, 0.062190075404942036, 0.005192351800360484, 0.021616362828353886, 0.033118622086476535, 0.029187779400672298, 0.013688727431144798, 0.020511766924755648, 0.021359950806072447, 0.026596496572892647, 0.028939889089087956, 0.07597542396979406, 0.1358921080827713, 0.061434980962076224, 0.048155550757655874, 0.028986098914174363, 0.01804173989512492, 0.05355728746508248, 0.007280022027771338, 0.07041886783554219, 0.015135739140532678, 0.036670229164883494, 0.024293528840644285, 0.03027256181667326, 0.0333987754129339, 0.016536402799829375, 0.025196030510414857, 0.028026214386045467, 0.045276733944774605, 0.02033522669080412, 0.0852708681486547, 0.017498287415946834, 0.016497237811563537, 0.05092091916594654, 0.04822974697162863, 0.02185654222557787, 0.03429762757150456, 0.027209838954149745, 0.04869349650107324, 0.09491625722148456, 0.03125482580799144, 0.07561750098830089, 0.02889373863581568, 0.0073851268371072365, 0.061465242033591494, 0.04066842360771261, 0.04155265916779172, 0.010926604063570267, 0.015976062750269193, 0.055515985877718776, 0.10058791303890757, 0.05177115323022008, 0.04609504452673718, 0.06621037100558169, 0.010432265989948064, 0.056336277993978, 0.03364565083757043, 0.007302242393052438, 0.028851957576989662, 0.02509334695787402, 0.012738127170450753, 0.04848531665629707, 0.05697813554434106, 0.06136209092801437, 0.03620928866439499, 0.07393094070721418, 0.04195551548036747, 0.01692944049864309, 0.015019628281152109, 0.007229621387523366, 0.0388882005790947, 0.0639182107988745, 0.020336310226412024, 0.01720547861623345, 0.012845316487073433, 0.09708645287901163, 0.07424944080412388, 0.07675690547330305, 0.015286915549950209, 0.04408964276080951, 0.014763142971787602, 0.10468906562891789, 0.029814745757903438, 0.051908008972532116, 0.077317649993347, 0.012838419152103597, 0.03157017919875216, 0.019446540100034326, 0.033854494904517196, 0.0707205879734829, 0.09168254910036922, 0.028082823555450886, 0.0320073858165415, 0.05157726714969613, 0.06355086996336468, 0.025583910282875877, 0.028684916833299212, 0.018415233134874143, 0.030170926547725685, 0.06309961449005641, 0.04011270713817794, 0.047025512176332995, 0.04902972650597803, 0.07178603744250722, 0.04210680599499028, 0.09034579270519316, 0.056924827076727524, 0.022735925995220896, 0.0924121990101412, 0.051889588867197745, 0.02012067550822394, 0.018963362999784295, 0.03827907545201015, 0.03638294008851517, 0.012197883552289568, 0.04663556181185413, 0.03880707641656045, 0.06561226677149534, 0.014966153757995926, 0.03695828636409715, 0.050780746023519896, 0.08568244840716943, 0.06380019447533414, 0.07373755186563358, 0.018461587678757496, 0.04059642044012435, 0.06806587378378026, 0.029524603123718407, 0.018016707253991626, 0.03647940444352571, 0.018865471865865402, 0.0381636232486926, 0.042459448595764115, 0.06778042152291164, 0.01627817066037096, 0.035643690498545766, 0.104263666580664, 0.04222260329697747, 0.014996782192611136, 0.01900291576021118, 0.052553655186784454, 0.020005535006930586, 0.038484728283947334, 0.046219213254516944, 0.06459162817918696, 0.06261117741814815, 0.055979961762204766, 0.0631307772709988, 0.04110229427169543, 0.0420881669560913, 0.06396828350261785, 0.05393984232796356, 0.03579591240850277, 0.014583125775970984, 0.05823122963192873, 0.04799606693268288, 0.034888310328824446, 0.05895392190723214, 0.028041443256370258, 0.039772124437149614, 0.04493573935178574, 0.04827212731470354, 0.03701365800225176, 0.0433160243119346, 0.07171372999437153, 0.04253545565006789, 0.034055019496008754, 0.028003732877550647, 0.06330783886369318, 0.043253765543340705, 0.040238326764665544, 0.028954312729183584, 0.01968355238204822, 0.08628741750726476, 0.11453543571406044, 0.07312865680432878, 0.05119361390825361, 0.04528503857727628, 0.012624168539332459, 0.028342170771793462, 0.04175017435045447, 0.04297840649087448, 0.008557785567973042, 0.037274211208568886, 0.015182404458755627, 0.010099690134666162, 0.0431821037636837, 0.026790660958795343, 0.025576733714842703, 0.0354900436650496, 0.03568755513697397, 0.016334095198544674, 0.02216640001279302, 0.04208076774375513, 0.03585375539842062, 0.027599254972301424, 0.04781696443387773, 0.05473126489960123, 0.03438226951402612, 0.058773409327841364, 0.024417452659690753, 0.004726760353150894, 0.05370867445890326, 0.054235346979112364, 0.0361073249951005, 0.040472778637195006, 0.039019579271553084, 0.06423265134799294, 0.016258277391898446, 0.02050724910077406, 0.03888808183546644, 0.032836101308930665, 0.03512802402838133, 0.05776988095021807, 0.0665892448159866, 0.056480774146621116, 0.014893277639203006, 0.007258111972987535, 0.018097836982633453, 0.05221919149335008, 0.04946084380208049, 0.06527450794237666, 0.05367325175029691, 0.02838802622136427, 0.03642753203166649, 0.062417855369858444, 0.04140033706789836, 0.04432720052136574, 0.007619456255270052, 0.03749471070477739, 0.07602778990985826, 0.060475562131614424, 0.02122747744579101, 0.028654162233578973, 0.03202020270691719, 0.010889381646848051, 0.059802523246617056, 0.052471800008788705, 0.06552099002874456, 0.0029868292176615796, 0.013809148313157493, 0.03355634820763953, 0.008123490024445346, 0.016850231077114586, 0.016351949416275602, 0.03959267312893644, 0.005598380794253899, 0.02889621926442487, 0.037140324056963436, 0.0641721959982533, 0.06001530811772682, 0.03543028964486439, 0.025914904435921926, 0.06347837697830983, 0.026027540188806597, 0.026773292847792618, 0.048780888100736775, 0.006299361539277015, 0.00859004765516147, 0.03212231109500863, 0.005742648272644146, 0.05375016051402781, 0.01969770328287268, 0.01811730722693028, 0.02405929219094105, 0.09352471548481844, 0.04119547091249842, 0.030328645916597452, 0.0473500533553306, 0.01981797016924247, 0.005315129001246532, 0.09024302009493113, 0.05210358343902044, 0.04075198943610303, 0.061709757428616285, 0.036549125507008284, 0.04953791583830025, 0.020651090308092535, 0.049626272229943424, 0.0430173098720843, 0.06032991565007251, 0.10074428355437703, 0.031259252718882635, 0.0245578911199118, 0.04054616219946183, 0.007807990987203084, 0.023402894112223294, 0.03027725590072805, 0.017682482903182972, 0.04785462100699078, 0.02836321622453397, 0.06065351059078239, 0.016733763986849226, 0.07862863159971312, 0.01919165690196678, 0.029093797529640142, 0.026496130376472138, 0.030072027948335744, 0.050091465236619115, 0.08047889481531456, 0.11540367428096943, 0.010715525204432197, 0.06891132099553943, 0.05698356435459573, 0.015259201900335029, 0.014272588923631702, 0.06852474369225092, 0.025478284114797134, 0.009178143100143643, 0.01846455441409489, 0.03878073017403949, 0.005359012193366652, 0.04565027171338443, 0.10025612107710913, 0.03817518962023314, 0.07000341356615536, 0.026515036588534713, 0.013548408642236609, 0.09263133295462467, 0.044685067841783166, 0.04118141463550273, 0.07236486810143106, 0.0347516772308154, 0.022473897770396434, 0.0070554486046603415, 0.036967292326153256, 0.018556456416263245, 0.04189436622255016, 0.008383000513276784, 0.024619322393846232, 0.026742352711153217, 0.03172138436639216, 0.011740541540348204, 0.100236231519375, 0.04302831592212897, 0.03980090121331159, 0.025363596323586535, 0.05217807280132547, 0.0845368173031602, 0.036285414462327026, 0.12466376996599138, 0.11038824028219096, 0.11052650981582701, 0.09661125572165474, 0.1573740624007769, 0.11921492172405124, 0.14864557451801375, 0.08143875151290558, 0.15119722665986046, 0.15282343549188226, 0.2218678977806121, 0.2441759515204467, 0.22010412445524707, 0.1280536036938429, 0.11196238003321923, 0.12534590758150443, 0.13380505522945896, 0.10411833180114627, 0.08600538654718548, 0.06874459009850398, 0.1437362379510887, 0.11768925163778476, 0.11818937753560022, 0.17430065490771085, 0.25278051558416337, 0.08465720849926583, 0.2432529127690941, 0.06877117382828146, 0.08648318122141063, 0.0902553768537473, 0.1102183033071924, 0.13659164163982496, 0.13657580420840532, 0.10506128979614004, 0.171456893440336, 0.15038317971630022, 0.14846615289570764, 0.16408502182457596, 0.11477007312350906, 0.10280691232765093, 0.12208332991576754, 0.10547033190960065, 0.17855362122645602, 0.18544881138950586, 0.06786872225347906, 0.0968112942064181, 0.240700859867502, 0.057547362812329084, 0.2224004184245132, 0.19780344766331837, 0.11631357701844536, 0.19320130086271092, 0.09941389478626661, 0.10943430592305958, 0.1130011938221287, 0.21333452052203938, 0.12412769443471916, 0.14231848355848342, 0.08871711994288489, 0.29239632887765765, 0.14028142177267, 0.11491837649373338, 0.151231721683871, 0.13491328951204196, 0.07392840256216004, 0.15748149569844827, 0.12539882271084934, 0.19623960892204195, 0.06531482140417211, 0.09350114487460814, 0.11905737119377591, 0.14558169204974547, 0.21218336041783914, 0.09276153534301557, 0.16893767315195873, 0.12161052247392945, 0.07998765984666534, 0.11717299887095578, 0.1379275816725567, 0.12561653915327042, 0.12080822372809052, 0.15303015330573544, 0.11922772377147339, 0.09934278219589032, 0.05939685048360843, 0.10530752697377466, 0.10832061685505323, 0.16341199778253213, 0.1393324523814954, 0.1351745254942216, 0.11473574879346415, 0.11638710158877075, 0.12991393043193966, 0.19876012054737657, 0.10901787944021635, 0.12401807180140167, 0.1711939653614536, 0.1500125214806758, 0.18261134333442897, 0.10052807367173955, 0.1839458881295286, 0.194588775630109, 0.20970996032701805, 0.15987711871275678, 0.11326565072522499, 0.11782590328948572, 0.17056097276508808, 0.16654151579132304, 0.12808879633666947, 0.08476819668430835, 0.139921777008567, 0.13490175653714687, 0.15075628703925759, 0.2929094200953841, 0.17052080773282796, 0.1366858053370379, 0.14714063261635602, 0.2123432932421565, 0.13316444819793105, 0.08024089547689073, 0.1224144316802267, 0.1648753645713441, 0.13278090627864003, 0.10890640885918401, 0.10973975906381384, 0.15770750935189426, 0.1168808524380438, 0.08938075581681915, 0.1139479070843663, 0.16010013408958912, 0.09628625441109762, 0.10336821345845237, 0.12975705525605008, 0.1514612531173043, 0.21785035554785281, 0.30891867354512215, 0.11692676169332117, 0.08831575905787759, 0.14469893707428128, 0.08547596065909602, 0.11630563603830524, 0.1084382992121391, 0.10756397503428161, 0.12141443221480586, 0.1439720331109129, 0.1757630569045432, 0.1716379329445772, 0.1341949647758156, 0.16109660093206912, 0.20846711529884487, 0.15659504482755437, 0.09219713203492574, 0.12655738944886252, 0.10596092120977119, 0.11568678135517985, 0.11455275001935661, 0.15191169222816825, 0.22278036834904924, 0.13355238363146782, 0.09377082649734803, 0.15481096634175628, 0.08055177371716127, 0.16718040104024112, 0.18383354181423783, 0.0777626343187876, 0.0926820513268467, 0.1656245329650119, 0.1317866807221435, 0.1490476107574068, 0.16911515034735203, 0.20516803138889372, 0.17066974192857742, 0.1262213004520163, 0.1465669079334475, 0.1492039961158298, 0.15794753475347534, 0.1846105110598728], [0.015010333809186704, 0.012569946302392054, 0.01975325860257726, 0.07893231842899695, 0.06281184672843665, 0.026925357051368337, 0.01402149810019182, 0.06614889149204828, 0.023160336131695658, 0.04173223664110992, 0.010786829825519817, 0.006332082366498071, 0.008323071160702966, 0.019395357885514386, 0.01816322204831522, 0.013866734334442299, 0.02914580538345035, 0.027800736934295855, 0.011077000290242722, 0.04469332052394748, 0.011184893719473621, 0.024030782587942667, 0.04803100353456102, 0.06874483500723727, 0.03567394785932265, 0.09222557113389485, 0.04991271525796037, 0.021142531222722027, 0.07133824037737213, 0.07529039939981885, 0.0440317700849846, 0.016983248060569167, 0.059418324526632205, 0.026752286357805133, 0.019576354716264177, 0.011172027661814354, 0.0579620007192716, 0.012897670367237879, 0.03003456618898781, 0.016870990802999586, 0.03552545153070241, 0.035192624272895046, 0.031540994241368026, 0.11559210557607003, 0.06737166884704493, 0.04783759613928851, 0.05472380631545093, 0.022194764896994457, 0.03201812840416096, 0.03049809307412943, 0.051743456278927624, 0.03368650235643145, 0.055694513212074526, 0.07065201352816075, 0.07491534764994867, 0.027457057622086722, 0.030627662781625986, 0.07628480307175778, 0.07485576803446747, 0.023075427016010508, 0.02387463657214539, 0.07145385214244016, 0.08104032211122103, 0.07585577492136508, 0.027964510372839868, 0.022726242823409848, 0.03207409376045689, 0.050832889319281094, 0.03741948661627248, 0.03518946272379253, 0.05360965340514667, 0.019944433988712262, 0.06906511625857092, 0.01798653152945917, 0.026218344501103275, 0.02503839277778752, 0.03884064375597518, 0.04665288724936545, 0.0404457125114277, 0.02159300373023143, 0.05136975152709056, 0.05076164314232301, 0.018043927375401836, 0.03237257813452743, 0.10277421330101788, 0.017006314010359347, 0.056828537126421, 0.008713325805729255, 0.046585622694692574, 0.027620248474704567, 0.023522003248217516, 0.07955081688123755, 0.04105508254724555, 0.03204903143341653, 0.027416436169005465, 0.022892832712386735, 0.008042108893278055, 0.02728189036133699, 0.07927179904072545, 0.04064111999468878, 0.03233806084608659, 0.10137113116797991, 0.0026724457211457775, 0.02439473737467779, 0.04112944945518393, 0.019341995612194296, 0.014280066061473917, 0.024982876420835964, 0.02576184389909031, 0.06803675190894864, 0.027018734072044026, 0.027423297324276064, 0.027646973212540615, 0.01562865229061572, 0.009913752455759095, 0.012406132973410422, 0.02517127060855273, 0.05149905591679271, 0.01601873624167638, 0.03340426730574109, 0.03875902977597434, 0.07782152373692952, 0.07560601996374317, 0.017475614804425277, 0.013107841023156652, 0.02012808770814445, 0.021533483486564364, 0.023686967833782546, 0.018209543195553124, 0.05006345658330247, 0.00645739121864608, 0.03553049813490361, 0.05922968171944376, 0.04660350474296138, 0.02036717614828376, 0.05736203369451687, 0.051902739724027924, 0.04304245754610747, 0.03195087869244162, 0.015762994007673115, 0.07328386956942268, 0.09377695663715713, 0.020179572347842623, 0.0485108502471121, 0.0285632825398352, 0.02584237248811405, 0.026958935522998217, 0.008194017245841678, 0.02802929244353436, 0.03918435089872219, 0.025196592687279917, 0.03701997367898002, 0.03739495121408254, 0.020675649830081966, 0.03038293401914416, 0.07236773279146291, 0.049110598338302225, 0.09674098313553259, 0.1735460094641894, 0.048083298970595933, 0.0585774452338228, 0.014708423495903844, 0.024796042598609347, 0.0997676988481544, 0.03607360922615044, 0.04684658408223186, 0.02726617909502238, 0.030270216630015057, 0.0655136576096993, 0.06525098186102696, 0.043792483120341785, 0.05616058195300866, 0.03851208013657015, 0.04011119315691758, 0.08979367194115184, 0.038399808036047034, 0.05881945588043891, 0.030314567375171464, 0.0718362585757859, 0.07713525235885754, 0.028174955623399, 0.09287782246246934, 0.0436073024320649, 0.022921692980162334, 0.014245418897189666, 0.0010405156263004756, 0.017414289286534768, 0.015941799647407606, 0.041553872579243034, 0.029659683277714066, 0.01186630495794816, 0.03454906720435247, 0.02387138782069087, 0.04413119931996334, 0.03664022784505505, 0.034879003796959296, 0.04472401946259197, 0.02935898915893631, 0.025707925015012734, 0.04933681608235929, 0.05791040661279112, 0.05313366957125254, 0.053061365833855234, 0.08140148827806115, 0.026010832589236088, 0.0844848521228414, 0.05385383854445536, 0.0407914791139774, 0.007447273355865036, 0.04636106365069281, 0.029866180302633438, 0.035744125343626365, 0.06715612689731643, 0.002086162971863814, 0.017965250444831327, 0.05197071674047038, 0.046322141715791076, 0.07459934859070927, 0.02204731685196748, 0.03919741640856955, 0.09770510718226433, 0.017048844638338778, 0.015221124158415478, 0.012159468133177143, 0.050769843874149956, 0.07177107574534602, 0.03610246392781846, 0.02649554593517678, 0.023971681657712907, 0.08820710863801651, 0.008143404629663564, 0.04211296953144483, 0.02846798706741538, 0.04428364016348496, 0.03270891204010695, 0.03771467585465871, 0.020286369253881276, 0.05047403865319211, 0.02826732332323445, 0.055748114828020334, 0.08965508328401484, 0.007924435813038144, 0.03740229476534296, 0.04855190956732258, 0.057980216733994894, 0.012231502842041664, 0.03435302518482786, 0.005873981044715038, 0.03903193603036925, 0.0751385411422234, 0.06711557594826445, 0.06162605801364407, 0.0578839416266419, 0.042456372393644415, 0.01215420352309593, 0.06089405178499874, 0.04897521575912833, 0.02506365919543896, 0.022874484966450837, 0.040656938872416504, 0.046526236037607305, 0.01126560691773193, 0.05430503464594949, 0.00925855109016993, 0.07226989546325058, 0.06316982166026719, 0.035495309202815406, 0.04224501986755058, 0.02858515734260436, 0.07267838838743046, 0.029428689813357778, 0.04455539979971945, 0.035967719595646486, 0.03602007440349553, 0.06930251445737667, 0.04474059533094987, 0.024062002885330003, 0.030739528556296136, 0.031697294252808206, 0.03375885804416612, 0.04542738992313389, 0.04062526400957722, 0.051862663749489, 0.08443345839623362, 0.038755923887947574, 0.06735593531630002, 0.03864678365061991, 0.05705407580535393, 0.056997490755748004, 0.04897681879810989, 0.04959926176525187, 0.024315483424288686, 0.011306558626529295, 0.04489029393880628, 0.04354315489763394, 0.044582989139598794, 0.03519528116157744, 0.01763207994372351, 0.03894558714819141, 0.016209770619752817, 0.02524169485695893, 0.027951455995207652, 0.021500242692127358, 0.06029605145158712, 0.06102548984927125, 0.1086727881920524, 0.014753687082702527, 0.013621949910884723, 0.06939139406313188, 0.05338732822565362, 0.068505737290252, 0.06010759047057945, 0.08529749640729278, 0.028823112152167596, 0.05226201712503098, 0.02382714654231677, 0.03520591984852217, 0.07869769586250186, 0.06593661499209702, 0.017767238023225218, 0.06542793213156983, 0.046407403351622634, 0.008273303665191634, 0.059003293281421065, 0.03095405005296925, 0.03185393194144126, 0.05938402988249436, 0.05662344832671806, 0.023398584089591168, 0.04764247438288294, 0.0684474193258211, 0.03786901288549416, 0.012130020641052397, 0.0739933701697737, 0.10627378840581514, 0.026313367234251928, 0.03623749769758433, 0.03026484904694371, 0.06580713248695247, 0.04194535547867417, 0.06268903613090515, 0.0211683431189158, 0.02147124512703158, 0.034509184188209474, 0.055904507607920095, 0.042569902434479445, 0.07030139327980578, 0.029324577626539394, 0.010410459835838992, 0.05261441481707152, 0.05749358308094088, 0.07368124512140639, 0.17203759431140497, 0.22939345333725214, 0.15043109277030453, 0.17900140344863757, 0.1497606810880825, 0.16544441372388974, 0.11219362582778558, 0.12253259643330239, 0.11506524751894176, 0.16865236189914867, 0.10997515346389264, 0.09731510857818648, 0.19270741642685607, 0.11341142337187193, 0.08765748891164549, 0.10628730291500688, 0.07529457769123837, 0.16460069571621716, 0.10216554830549285, 0.09174812526907772, 0.13475032872520387, 0.09394302702276036, 0.21234958665445447, 0.16211654932703823, 0.19361009064596146, 0.1666793623007834, 0.11338501033606008, 0.20701553381513804, 0.13123259326675907, 0.13434798078378662, 0.15986907383194193, 0.13229422067524865, 0.11603498962358572, 0.10377290658652782, 0.09271910676034167, 0.07438334650942124, 0.1572859100997448, 0.0695308213471435, 0.11962524775299244, 0.1038992646499537, 0.16520054399734363, 0.21850065502803773, 0.08251853927504271, 0.13236246857559308, 0.1996801164932549, 0.08991556969704106, 0.17238722008187324, 0.10559411472058855, 0.23923841334180906, 0.2436345547903329, 0.1487882004585117, 0.09674262328189798, 0.14188880973961204, 0.17250827921088785, 0.16717366233933717, 0.2346323331585154, 0.1261805565445684, 0.1971663732547313, 0.15692210930865258, 0.12240266863955185, 0.10170187670155428, 0.16085911367554218, 0.11929526663152501, 0.13236726284958422, 0.21802599221700802, 0.0814155742409639, 0.1565492691588588, 0.1399179475265555, 0.1610909606097266, 0.07180719607276842, 0.13737885252339765, 0.10851681101485156, 0.16132807679241523, 0.14858701906632632, 0.12995682656764984, 0.0920709669298958, 0.13474076986312866, 0.26197228173259646, 0.08829483791487291, 0.13341128651518375, 0.09333469599368982, 0.1663585170172155, 0.15723470191005617, 0.314981218543835, 0.12603197857970372, 0.12161839666077867, 0.15770976548083127, 0.15858995262533426, 0.20156171318376437, 0.1481133804190904, 0.09928272760589607, 0.1130050900974311, 0.12925255810841918, 0.19099971977993846, 0.10744707935373299, 0.1534211463877, 0.1026406860910356, 0.11670197258354165, 0.19358696532435715, 0.10510088337468915, 0.1918929984094575, 0.17000568303046748, 0.15775073203258216, 0.11680878989864141, 0.10064943708130158, 0.17673197522526607, 0.16133886761963367, 0.16322269075317308, 0.09693973770481534, 0.18806060717906803, 0.10770439679617994, 0.24338584626093507, 0.1134770960197784, 0.10180606681387872, 0.1757202052976936, 0.1587710960302502, 0.20780850376468152, 0.14930195960914716, 0.08402726612985134, 0.09356468013720587, 0.19925378233892843, 0.13251682044938207, 0.1890727927093394, 0.14927914598956704, 0.09705467411549762, 0.1794397900812328, 0.11797530503827147, 0.11461893474915996, 0.11370254564099014, 0.28256720630452037, 0.05974786778097041, 0.161907100409735, 0.26710467820521444, 0.1421796574140899, 0.09788865514565259, 0.195819137734361, 0.2520693006226793, 0.1291902325465344, 0.11963976416154765, 0.07096534827724099, 0.18033903557807207, 0.17463104421040043, 0.16414382960647345, 0.07163945585489273, 0.11442513030488044, 0.1689546534908004, 0.1635334873571992, 0.15132214495679364, 0.12937640771269798, 0.16804006038000807, 0.19341052713571116, 0.12799914489733055, 0.1270642169401981, 0.1617342245299369, 0.1499417651211843, 0.14444132277276367, 0.2040122402831912, 0.21865298826014623, 0.2480215232935734, 0.1272884791251272, 0.16245281643932685, 0.18440788990119472, 0.18516636482672766, 0.1898531906772405, 0.13066139188595116, 0.20893545501166955, 0.12016986540402286, 0.11679662609822117, 0.12279288988793269, 0.21962178783724084, 0.15028278197860345, 0.12373011850286275, 0.11606470521655865, 0.09991069586249068, 0.21016090409830213, 0.11879056168254465], [0.05681122653186321, 0.02654705098393606, 0.00862493416207144, 0.061049706127960235, 0.01822237863962073, 0.029497401556000113, 0.042791786036104895, 0.017780247871996835, 0.08046042275964282, 0.02540668356232345, 0.05321266005921643, 0.025261499067710247, 0.01387966347465408, 0.0201407134954934, 0.03188418559147976, 0.02660910195118049, 0.060425723204389215, 0.04105276704649441, 0.015381326938950224, 0.0359826998464996, 0.06772510925657116, 0.04617899627191946, 0.08461229372187518, 0.08403343337704428, 0.0156625183444703, 0.03832294009043835, 0.03610427476814948, 0.06171082241053227, 0.03689868448418565, 0.030452206083282363, 0.017826999464887194, 0.014685998576169368, 0.04659231686673593, 0.05411420621385332, 0.05166367169294972, 0.03271563218731899, 0.027788343068095855, 0.01610676979908021, 0.04359510894573759, 0.018432354481774382, 0.09030887085827999, 0.08248794052633457, 0.019535017090674955, 0.050159137972514145, 0.03840919249341823, 0.027239114824624266, 0.05758366867667064, 0.02507551500457339, 0.029693512224184815, 0.047285289838328026, 0.025718979304656386, 0.034924723804579116, 0.021030401985626668, 0.01805674055503914, 0.0375315583369229, 0.02472794869390782, 0.02502034003555309, 0.02444427016598638, 0.03370549762621522, 0.057432548856013454, 0.06718251766869798, 0.048459211611771025, 0.035450713548925705, 0.09896394549286924, 0.049608278859523125, 0.04122035883483477, 0.007594988574055606, 0.09923669960699044, 0.031107611539482605, 0.062031099951127544, 0.036990287771914154, 0.03665369782538619, 0.03362677431141492, 0.06603529836866073, 0.033703200679156, 0.0038993547514110105, 0.06618994710152037, 0.044630764896282926, 0.05284420600219164, 0.03778468264499679, 0.053283843153622, 0.07873869952163659, 0.012566341320052743, 0.021100000594742596, 0.03972138751123566, 0.020832087138842326, 0.02781783045065822, 0.005479712772284984, 0.02408186275715707, 0.06593747588340193, 0.07674125357880257, 0.013017325909459032, 0.02874817007977981, 0.01849791395216016, 0.005632260299535119, 0.027211751839786302, 0.043355027883080766, 0.07749812546535395, 0.03708723081217613, 0.008405532116739778, 0.04329666910052765, 0.01648232435400132, 0.01766377336025471, 0.05547243665205315, 0.03139540713164024, 0.030549418152077124, 0.09096427631448023, 0.0329049466381548, 0.02864890411728993, 0.10947087896056473, 0.07555899748695083, 0.043589212582446635, 0.055077621509553865, 0.09058922456461005, 0.04506271339778323, 0.03525720225297846, 0.027642783788905945, 0.09150309037067927, 0.062497383914887905, 0.05008296393498313, 0.04765006284287665, 0.03003401699970709, 0.024098880203382578, 0.01556451588839991, 0.020773548385477625, 0.020264051017875317, 0.06398925659595989, 0.02924335698480718, 0.06337954517221078, 0.03850950859487057, 0.023463358738808893, 0.022558888522326015, 0.04312219389248639, 0.058385403390275314, 0.01608642196515575, 0.04793700310983695, 0.014387151477421867, 0.025712839888001326, 0.050973455799976364, 0.05729617550969124, 0.04138140116992872, 0.0007335703628541523, 0.09522372158244252, 0.010212524412054336, 0.020881809177808464, 0.015380297209048877, 0.06270236510317773, 0.018727964888967108, 0.08851967155351304, 0.04446837927389424, 0.016371896490454674, 0.04245732234267052, 0.024563473925809376, 0.008297336262330646, 0.044453439841163345, 0.026218481798423454, 0.05227268178714439, 0.013593602652690606, 0.044954300465178676, 0.043075546200270765, 0.020605017780326307, 0.04827273587579839, 0.06310469820164144, 0.025514092740195338, 0.01257625270227436, 0.08074856159510091, 0.01830798908486031, 0.14354900893522426, 0.05537458819162566, 0.06735490373102948, 0.07589126442326233, 0.056205745349870995, 0.01355539781798143, 0.028710580299957655, 0.019788022655120585, 0.009454862138227327, 0.027765919076045975, 0.02874180059734499, 0.02440059291984653, 0.05229529502685182, 0.022384906842489727, 0.02433008332445752, 0.026396220600872766, 0.02829004417435499, 0.018973495170939714, 0.04460864147404209, 0.058580606782925315, 0.009317047170043224, 0.022439335953094997, 0.05116576481668744, 0.0549783518363256, 0.01673161175858695, 0.059208790262346156, 0.04313590507081244, 0.023159234042395838, 0.006131465006546932, 0.027707779227057472, 0.02902252908825176, 0.04986785243090708, 0.030854023389110807, 0.021192180902289692, 0.052682562527479604, 0.08114836396998726, 0.053111171364434995, 0.049138402901007794, 0.06543783980305307, 0.03132167847070377, 0.05110823352879379, 0.03698065840580966, 0.06587291645701043, 0.025233199121430516, 0.07527068053605035, 0.06265318297664635, 0.028833209071308374, 0.04961036058375612, 0.05102916882606223, 0.03071579096285859, 0.06944359673070721, 0.027937815320910886, 0.03667701610538643, 0.030938255295041017, 0.039064991287887096, 0.026074174893437885, 0.0630937292589806, 0.07167409188696183, 0.05554062889132183, 0.05144871975062415, 0.07558307275758125, 0.06952452793484554, 0.12323106129770167, 0.012075765007466543, 0.05183376822969876, 0.04313082135922741, 0.031757103934069164, 0.057718272000784054, 0.02714533889957238, 0.106020894163521, 0.034686865474213846, 0.030555854427802842, 0.08434987772488967, 0.022315978021651972, 0.007210645135273808, 0.01307482287302264, 0.07668769278097898, 0.0453735396877164, 0.05245673441095278, 0.030279304228315596, 0.03438296713284217, 0.012249284700374119, 0.03288162835815456, 0.07014105969574302, 0.08360370760783553, 0.0935262517305091, 0.045388482831185684, 0.09840923463343643, 0.020352207029645797, 0.05318543437169865, 0.07238223435706459, 0.004664900488933199, 0.1044545543845743, 0.08916131759178825, 0.05378259978897404, 0.012841929510614136, 0.016940144123509526, 0.059034485748270527, 0.025437107906327583, 0.026820729071914684, 0.012633042770175962, 0.03154828955302946, 0.03589693355024792, 0.006406077272913535, 0.007287101188921952, 0.039640545364818536, 0.015229778528009774, 0.028747270225721877, 0.0681191599869635, 0.08744717910303734, 0.0413034793746192, 0.043739063330576755, 0.0104340285906801, 0.0329638397670351, 0.06095402473874856, 0.07631438507814892, 0.01801361249818001, 0.050579768721945584, 0.11356377886841074, 0.05096155175124295, 0.07278280856553465, 0.02967187676404137, 0.044362196495058015, 0.025365271721966565, 0.06870082565001212, 0.019808372344414238, 0.027181735677004326, 0.010284453364874935, 0.0356170807935996, 0.027324845868861303, 0.022607651335420087, 0.013915981398895383, 0.06738985888659954, 0.012102243908884702, 0.01836494335293537, 0.08969618342234753, 0.0265149512415519, 0.06104293031967245, 0.01085756948668859, 0.06483748686150648, 0.029009819809289183, 0.07499135099351406, 0.03341257935971953, 0.05134126418852247, 0.01376728190734866, 0.06870308177894913, 0.0627937086392194, 0.014887352517689578, 0.06311058343271725, 0.06515358982142061, 0.024521060186089016, 0.03479312246781774, 0.011682876665872755, 0.011432036317273742, 0.03139126594760455, 0.03281126533693168, 0.02800261223455891, 0.05875133414519951, 0.05169002906768583, 0.025330407479486894, 0.05199706669372972, 0.02519336991099408, 0.03511328497552313, 0.04995419760234654, 0.07520174243836664, 0.07856136333430186, 0.02003829340537777, 0.057599153587943874, 0.04226382588967681, 0.02716393155424157, 0.03583180267014541, 0.006609778720303439, 0.018923335264844354, 0.008599030425102683, 0.011796028211392695, 0.019564819885999896, 0.030629391985712573, 0.018619806141941808, 0.02610028921480989, 0.05207815003814176, 0.015873026677581947, 0.06288391668931581, 0.030136880523059517, 0.03882230528688524, 0.009243905733455904, 0.13121243653586134, 0.1428638878860511, 0.07864407569286413, 0.10040938199381344, 0.08644706089398824, 0.0842422217829153, 0.1795492717064917, 0.08936427271692082, 0.15510899800574407, 0.10313853359548375, 0.16808228858280927, 0.1377221551956609, 0.0873658100317698, 0.12208697386085987, 0.13061977224424481, 0.06653825184912421, 0.16917333472520113, 0.14413843746297061, 0.10892415361013263, 0.1099380015511997, 0.1279678856371902, 0.1054573294823058, 0.16165635839570314, 0.1623962796293199, 0.12792090768925846, 0.11854733762447722, 0.1303462017676793, 0.14756344899069518, 0.16075971041573212, 0.10725849220762029, 0.1470687927212566, 0.11749797791708261, 0.23564773960970342, 0.18535271810833365, 0.13562585518229753, 0.1388004215550609, 0.16633695020573214, 0.09998315916163847, 0.21792179468320683, 0.06557489963597618, 0.17122794088209048, 0.1670921003096737, 0.1308460530708544, 0.10078921317472123, 0.09142332433839329, 0.17401163291651756, 0.1717171201016754, 0.1290732849156484, 0.14071658748434857, 0.13334450806723908, 0.18517662130761892, 0.18361870490480214, 0.18532266112742946, 0.29587489378172904, 0.06494008877780288, 0.10553348125540651, 0.12691872630966827, 0.13022876431932673, 0.1627935067517683, 0.17103665973991156, 0.24136463674949482, 0.12042998816468753, 0.12039723718771711, 0.21067032910650596, 0.10583272262010723, 0.10170031819143333, 0.08085750887403265, 0.23615793645149097, 0.16735326207708567, 0.16671560879331082, 0.12314541003433987, 0.07615856375196017, 0.060736326850019395, 0.19040962331928313, 0.14539265219355002, 0.16149777628015727, 0.18993736506672576, 0.12015741216600873, 0.252671746420674, 0.15404294739710167, 0.14335517480503768, 0.24524718231987208, 0.07196731443400495, 0.17082381178624928, 0.14082090376177803, 0.22578231117222458, 0.09443880393519066, 0.1303392552654259, 0.10946534996037371, 0.12582128285430372, 0.17512117337901145, 0.09842678642598912, 0.1473460887791589, 0.07410087026073597, 0.10195215858402662, 0.11235895406571217, 0.13243690598756075, 0.1392461999785155, 0.1176828691677656, 0.138595633325167, 0.1796495061716996, 0.13109185238135979, 0.20219292462570593, 0.16780056932475418, 0.11188619115273468, 0.1444832095876336, 0.17004721361445263, 0.1744259739643894, 0.1785310747800395, 0.2537514525465667, 0.15332296025007963, 0.12486236868426204, 0.14064437651541084, 0.14383610134245828, 0.09326783590950072, 0.15594790689647198, 0.06838499728473835, 0.11605513893300667, 0.1268120648455806, 0.17148589657153934, 0.11827326990896836, 0.13561233325162902, 0.09192188430461101, 0.14909742370946333, 0.14568731450708583, 0.07617793380632065, 0.19437499257037416, 0.13354894006624818, 0.11290426191408187, 0.1318072827416472, 0.1120862815878354, 0.09208188392221928, 0.1466433343011886, 0.13036854041274637, 0.11844729611766525, 0.12308629797189496, 0.14040363865206018, 0.2503564831567928, 0.08565116688259877, 0.10894578721490689, 0.1598240848397836, 0.14617750304751098, 0.18892467487603426, 0.07090631785104051, 0.11397760783438571, 0.10973728029057384, 0.16456041194032878, 0.06091184106480796, 0.17615442106034607, 0.17822636378696188, 0.07628069157362916, 0.13416777248494327, 0.15700515563366935, 0.16044103220338002, 0.07542844628915191, 0.13814479345455766, 0.1751617094851099, 0.12305816315347329, 0.12131573399528861, 0.2228228043531999, 0.14686400449136272, 0.1306943580857478, 0.14997666090494022, 0.10053996287751943, 0.10850103295524605, 0.17689858737867326, 0.08631575270555913, 0.13542390195652843, 0.08141486177919433, 0.15905904932878911, 0.2341581304790452, 0.1702227909117937, 0.10164602266740985, 0.15613243449479342, 0.08024073962587863, 0.13532497367123142], [0.047857801109785214, 0.04602166467520874, 0.035386265444685705, 0.014486398886219831, 0.021384666179073974, 0.022821432539785746, 0.047496464248979464, 0.03172720651491545, 0.05343970529793296, 0.0064361894510511775, 0.018188566391472705, 0.05353211752662901, 0.0259747549353051, 0.017566325659572612, 0.025012315563799348, 0.11465841700555757, 0.11627295927610248, 0.099332273384789, 0.039823410552344285, 0.0923537697235588, 0.03245789914217312, 0.02501762191968737, 0.04146648840105627, 0.07071027212077752, 0.04582971188938245, 0.03366476856172085, 0.048706146408221684, 0.10241637195576914, 0.06136510404758155, 0.03831886569969356, 0.03406019226531498, 0.014575903751392616, 0.03621140378527343, 0.04913848824799061, 0.05623366865620483, 0.0543553819443332, 0.06822881230618805, 0.06155862647574395, 0.055820229317760095, 0.049590330017963424, 0.038678911223541945, 0.0683729448064696, 0.028192084391776007, 0.020909741760988254, 0.01980753742827801, 0.14127238187938929, 0.04688002896727994, 0.0550118598039262, 0.0643963468610309, 0.0052313525884528644, 0.014183831772243138, 0.052114823265583254, 0.017235862142115366, 0.08265266762464307, 0.015548037426924566, 0.017375094612361863, 0.028863410771009512, 0.06616264348849654, 0.039246617088792846, 0.04424735285283532, 0.03617647089413367, 0.011793659832619596, 0.054811420559417456, 0.04170921150944196, 0.08135914875310846, 0.09528320471872576, 0.023645804612897336, 0.007506463807658292, 0.028822123240388464, 0.0030710131159139564, 0.035330789905856363, 0.019273781108495314, 0.068145075783832, 0.028836710152972955, 0.057493542262818664, 0.08806609315797687, 0.019190558523405343, 0.020284443380660377, 0.03295277805591468, 0.0408850305393571, 0.06612446741200984, 0.06982929087826051, 0.022349452592607122, 0.008414076091867173, 0.02041949384874897, 0.08101330793579109, 0.02069103084068047, 0.015126447451621061, 0.019545574141375255, 0.03775530101847835, 0.09257637691916898, 0.021199825023359153, 0.09789898584131151, 0.04257230699295178, 0.030208417992980685, 0.08775727066677064, 0.06200319519848563, 0.06439242089982145, 0.010057083436549874, 0.0737143745936919, 0.014936616280465387, 0.023010631957731675, 0.06713987386319786, 0.021745509511674754, 0.09033618189278059, 0.05755136298830621, 0.004441827131813625, 0.0814168136275839, 0.02737713944952702, 0.06524623211589642, 0.04477720918657724, 0.026981209230143577, 0.03345150500535965, 0.05054037923400756, 0.04424957929586526, 0.052919077570550144, 0.027711636539606843, 0.024172872326744255, 0.07975839558639564, 0.005916560376135749, 0.022337116242852062, 0.03970746853156015, 0.0175243442208739, 0.04685196836362593, 0.07098520814906806, 0.06568953176611103, 0.020260846795281395, 0.03958007517212536, 0.048910448531387374, 0.03511778610118199, 0.036213092171237804, 0.03880726937495638, 0.04720333075965755, 0.00966387968219351, 0.01494287907917169, 0.009170264274871442, 0.0326377029705327, 0.03591960616176948, 0.02513907809770899, 0.02721612123423256, 0.07633767367224209, 0.043699358429876156, 0.02732979042775696, 0.03444670277531259, 0.05625929872621782, 0.005391850372689078, 0.06385696135112084, 0.020263472142687533, 0.010891169295064174, 0.047806963993934914, 0.05858819524291903, 0.030758252942177933, 0.036044743392267264, 0.04433499307197053, 0.01157603801402729, 0.054537085670745, 0.03959207941079512, 0.035108653974020854, 0.048397542850580066, 0.016073875958682038, 0.06615633523324504, 0.06134670620667748, 0.03295017311756965, 0.047629950640839525, 0.026320029865019023, 0.01609345752513036, 0.019640676655399147, 0.06491780950454995, 0.0674446219636593, 0.038376664160750806, 0.04629712020687293, 0.02111935209541116, 0.022058430513425265, 0.014225537688616896, 0.05285297447699122, 0.060827032139059156, 0.02750398918578867, 0.05756129292421974, 0.014371008837770205, 0.024307772509928327, 0.029004810312471818, 0.011713097846950404, 0.03270321605668869, 0.06901280969032086, 0.029088346454955172, 0.04432680347235873, 0.04497997506405227, 0.03802523868216667, 0.030881204547767993, 0.02301620177604491, 0.05974630556011107, 0.03610684630984906, 0.02848060172254918, 0.045058141768095084, 0.0768838869407773, 0.06575104096555151, 0.07780458050547168, 0.02968767894344637, 0.007229044367704773, 0.08719562814803794, 0.0306116583669791, 0.010545677287154831, 0.06560702720889822, 0.0992768349533435, 0.09317332340287976, 0.03592120549001265, 0.03383410439710133, 0.0036908147330905194, 0.02770623927062843, 0.04660523023630958, 0.06811720071709715, 0.053016692254459485, 0.05794352495286148, 0.047931303415680304, 0.038496008928632364, 0.01409139078532462, 0.01604600274731638, 0.06677958343061619, 0.03660962167487014, 0.06150884692033287, 0.028464541646826547, 0.05643642711220309, 0.043277417789795436, 0.05753738463681657, 0.03528220520820469, 0.020264687409508042, 0.024686505312274676, 0.015377394483948592, 0.01137294651925913, 0.05319756848621182, 0.021840012741449755, 0.07312026311410591, 0.05796593410195783, 0.050221463534398936, 0.03350873572344426, 0.034548915064078756, 0.03365909855347127, 0.04282710113329813, 0.031743162689963356, 0.03929932812752668, 0.04423840997333173, 0.06537803754326887, 0.0467000173375709, 0.019779473113885615, 0.03028608189197257, 0.07382441282970831, 0.017263332738366444, 0.003221835613658186, 0.0791944598313421, 0.03690202043799218, 0.06035893733496778, 0.08691594237461686, 0.02965048435726203, 0.04350524228357244, 0.0390048587723868, 0.044126186112407595, 0.03126780968159437, 0.051474409192451276, 0.02327448586584069, 0.018098863001796417, 0.013947614515927853, 0.031141566651058383, 0.03833393129752949, 0.04482229094719514, 0.016589844854024705, 0.05546610613237135, 0.06441861871280707, 0.08226444275351241, 0.048149227659450844, 0.05134686369274277, 0.014093925219640369, 0.02351075043407036, 0.09106409517698921, 0.049011551309376955, 0.02859660868125502, 0.07064836958306842, 0.05275431707559619, 0.03399218185222708, 0.05942400937783532, 0.05744973699620459, 0.04789960628841072, 0.0352134823333472, 0.030556210658687633, 0.05537231350899674, 0.03602106145990547, 0.019939665689889807, 0.034913153722300194, 0.01736682894261321, 0.03372358005435672, 0.003964096931667882, 0.031790133216418326, 0.04298826592275873, 0.044926644332008436, 0.036796854401472956, 0.009784091835172148, 0.026652152082533576, 0.041868480111588724, 0.006223457921805675, 0.03738226048881188, 0.037293855857569724, 0.07978218141943216, 0.03864051621349063, 0.008644437803013716, 0.01612110067071626, 0.03759121958864853, 0.03845696453936398, 0.028358238268992864, 0.027090585099358577, 0.038457740083686076, 0.021300786793290172, 0.01346770008240128, 0.012094250050722621, 0.041250430658692494, 0.030599244091717992, 0.07316492556128651, 0.08322105626575649, 0.05620591975457501, 0.03321095267892815, 0.036411668625078164, 0.022373833999154158, 0.02672541875654133, 0.030634342110715806, 0.06482514494564384, 0.01842099034547573, 0.054925763251958415, 0.006998346834734548, 0.038052000527386554, 0.03662143295514397, 0.09354476831504144, 0.008113325384329073, 0.10799271374708042, 0.027371209689590614, 0.021329170231183525, 0.02245383566332748, 0.0090773195552174, 0.04656426368455868, 0.03310550091555342, 0.09046166422194801, 0.025884185088216327, 0.018228616390842944, 0.03160742387990467, 0.052372983045643196, 0.06816328066634014, 0.04816307613509707, 0.07296815994777717, 0.02419805525278207, 0.05676258617313579, 0.04381217229820322, 0.053125917838769965, 0.058551410693326034, 0.03011261229403317, 0.01946286178281298, 0.18325494864257053, 0.2630400541238487, 0.1284381846198812, 0.10471910034539178, 0.14750823320355266, 0.1018154995108489, 0.12062379260896705, 0.1688012812519446, 0.232364077528473, 0.11432581610279158, 0.11790285658207722, 0.1503304872312583, 0.1291592256166041, 0.08971363873570226, 0.14294963562861085, 0.1191022340208292, 0.17750826169503853, 0.2555764827411622, 0.23644394532311708, 0.1655594169278629, 0.16866189107531682, 0.19756376364966854, 0.1812461033114232, 0.1786219878704287, 0.12337823660345748, 0.17788804834708571, 0.2152164140716195, 0.23310276679694653, 0.17328002373687923, 0.15957095311023295, 0.14868882688460872, 0.128771364397835, 0.15404980484163389, 0.14570278086466715, 0.1099384023109451, 0.12277287416509353, 0.25403783249203116, 0.163438982272055, 0.08465939783491194, 0.11811778254923411, 0.10956993341096677, 0.13102166005410254, 0.17401393357431516, 0.15825692127691582, 0.09169595970888622, 0.18800702411681414, 0.13537181803258136, 0.14829624560661614, 0.12183476239442825, 0.23641189938643947, 0.11535861107404344, 0.11936505819903687, 0.10861960588954389, 0.15600373124470934, 0.08743097059777938, 0.1791183213936165, 0.16134660079842433, 0.1108740278868936, 0.08659244762384333, 0.11754874081816524, 0.13189982855692506, 0.13863983564078808, 0.11524418674525805, 0.1253423749585636, 0.14705691835843027, 0.19569068681448698, 0.12462264014175162, 0.0976589233323466, 0.10549423648626544, 0.14888269070070237, 0.06706988191581331, 0.08511834937962703, 0.16262866090983152, 0.1034352665010374, 0.14722311490913853, 0.12072950412402861, 0.06182263437949587, 0.07542675419244915, 0.11806981754489243, 0.12618826003745198, 0.1401610454195179, 0.14367122581461444, 0.09568766035954468, 0.1416180594242178, 0.11611686335527338, 0.15960543329128996, 0.11217707593459636, 0.0915131761576049, 0.10018067434430122, 0.10989304224494845, 0.2584515034686774, 0.28249337745364755, 0.20859970740275458, 0.17190961836604401, 0.13618142693303525, 0.13597626762930304, 0.15661906072637066, 0.09766684204805642, 0.1057087023218628, 0.2204528744914569, 0.10389830727945082, 0.1241174379538279, 0.13530848314985633, 0.16109768446767703, 0.14467748900642619, 0.12439668586011976, 0.10553309533861466, 0.1652033196296543, 0.186519923445303, 0.10626402174239047, 0.10604515497107059, 0.05331174790626392, 0.13668758649146184, 0.1052091404562816, 0.16478339763125405, 0.1724794096662663, 0.07641529489774257, 0.09756936837220564, 0.19228155724704266, 0.09882868907880038, 0.16809037799248472, 0.13104171288432553, 0.14093402191065252, 0.1589903561398387, 0.13812285556923598, 0.1916355176945217, 0.07466698050848208, 0.09155161198577844, 0.11113498927443288, 0.13804824004182592, 0.06396449112799019, 0.08784178644418716, 0.11916290459339507, 0.15745945391245186, 0.12262233693036251, 0.15114195150090382, 0.1130186120280996, 0.09208160190610215, 0.1325919257942587, 0.2341723203426227, 0.22931802144739777, 0.1137697916419711, 0.2080396085511893, 0.10280337228323333, 0.16466906236018986, 0.06896811013575643, 0.17716665111947805, 0.11687444770359434, 0.1192350487690419, 0.06913653312949464, 0.15686554281273857, 0.11199430722626857, 0.19969626562669873, 0.22466594295110554, 0.15706995996879414, 0.15400039264932275, 0.08639515508548357, 0.15546381880994886, 0.1656737521989271, 0.1369131400133483, 0.10668683069525287, 0.2121097393683158, 0.12108829541830346, 0.16823628422571346, 0.16934059996856377, 0.14129231596598402, 0.1636121401679702, 0.07530835195211694, 0.14925936033250764, 0.08767913735937327, 0.12592420389410108, 0.08230735373217613, 0.16069689503638074, 0.09515211917459965, 0.13318298704689369, 0.16810110944788903], [0.013760099773207912, 0.01930006612383295, 0.03567757325072307, 0.04972957176505588, 0.05520952712686267, 0.030716113797097933, 0.07719799352344126, 0.021069336908112746, 0.037196163248154335, 0.03994837337813806, 0.01730327512632357, 0.0545093330583768, 0.0321740610525012, 0.03716462568263523, 0.039532625960418954, 0.015169802791206166, 0.0746788845572155, 0.014689456984342542, 0.05104860938445199, 0.008673111606185557, 0.04249873789376579, 0.0675031180435326, 0.02631278279295657, 0.0072123288828152, 0.07409574202029034, 0.039600413729203865, 0.007556996179118869, 0.03157329992973246, 0.09610267676180229, 0.02218487577920314, 0.06743880352587439, 0.08256158384028822, 0.04721024386526551, 0.08279221365228295, 0.01909023314510705, 0.05598577648925129, 0.011101984691777034, 0.01489745964136091, 0.06315789534710348, 0.03474732824543025, 0.08612701712991111, 0.014264234196161851, 0.025504057048237883, 0.0889285652374383, 0.032248565257759765, 0.03203470056178048, 0.03161337590427138, 0.015989339772204403, 0.017346568311040755, 0.019455008005024865, 0.042393853873363696, 0.024408444842265453, 0.03919543116353452, 0.025207619146385696, 0.02984256330819335, 0.022238197234401014, 0.03746130663785152, 0.04379149977467023, 0.05159031781658996, 0.04484215452976059, 0.052795933006564155, 0.10544766671955585, 0.04619915671355557, 0.04549178607703652, 0.05531841503398027, 0.0015914468667688197, 0.03501002625853289, 0.056150789314415306, 0.014057128610147629, 0.023207052472571377, 0.13330845453310758, 0.029197802105045412, 0.011508475672599161, 0.013435882356134243, 0.01119769947763416, 0.07729222401394509, 0.047705953984404914, 0.05646511854138225, 0.054265092257992364, 0.06067777139833197, 0.03406657102459576, 0.01917703473736765, 0.01598383860255126, 0.03605986094044056, 0.03218541962269228, 0.004056110255987733, 0.0673849532904569, 0.01110820667236112, 0.031044495590322185, 0.03245639629312791, 0.03529442838043906, 0.021789255406474695, 0.04997692216420546, 0.003551726981640968, 0.0006499712537788582, 0.03545876585121732, 0.057028545925277285, 0.011526814141689101, 0.029368013674684335, 0.05739247288147453, 0.14734133903402835, 0.0711087386298459, 0.0382300194905838, 0.02862318684492493, 0.05663249881763477, 0.021987501604598947, 0.06596649385755882, 0.015411434942507185, 0.03271531677455641, 0.08592306752689183, 0.035588010869105347, 0.028805636429751758, 0.05869291599083226, 0.03685179559397511, 0.04419032993610017, 0.04133093141717836, 0.019345003165653907, 0.028748427976097446, 0.013321514616109198, 0.056540435398346744, 0.005776646057711332, 0.039935871900524944, 0.028778753985534422, 0.013007104680582415, 0.01721720826026285, 0.03837921714875847, 0.03136461542453617, 0.0157363286416512, 0.021364700551202986, 0.029415134486043826, 0.026122164017579053, 0.1253780722618103, 0.06944568958715536, 0.08144840685417876, 0.03749326351680793, 0.027765841150539927, 0.007395659304165747, 0.025120400096056983, 0.03262084508605767, 0.06711261477903463, 0.02257069052575389, 0.04106299013074022, 0.05715331950341351, 0.007093887215887662, 0.03934887019568123, 0.03754391880647745, 0.02179638930101646, 0.057665909771458246, 0.08162591373547912, 0.023292731566471048, 0.05203244487347547, 0.029457193850248586, 0.021716754999943078, 0.025719582299643662, 0.10753856389783323, 0.057313808938488364, 0.015819864784134552, 0.027360057065379806, 0.08386863206396811, 0.05843708284373861, 0.0503350306826178, 0.06418643781216815, 0.031158428246271797, 0.059426243242342025, 0.055609604096389376, 0.05592228946625255, 0.029144812760932837, 0.06161320401588455, 0.04836937092477456, 0.03077708122873446, 0.034278936582268216, 0.00979850155999884, 0.03267583822889719, 0.06847934651887044, 0.016838957853906322, 0.03439466338022612, 0.06780327967135236, 0.05485702182340901, 0.029769409811706282, 0.02187679729104275, 0.023223129246616736, 0.08352098782779649, 0.07388580328552052, 0.0619991504936479, 0.02480654769897228, 0.01024925144520239, 0.0667346092814114, 0.06969762645894662, 0.022610540145251434, 0.008571954094804823, 0.04901478336250875, 0.1008249624283053, 0.04358252583188005, 0.03230699825508054, 0.04187729682598729, 0.049071041867136955, 0.07814534503268078, 0.034192454113508575, 0.07112033839803189, 0.029408915288513526, 0.04617346356099006, 0.029993169191584457, 0.05441001514554955, 0.07187267576227896, 0.03207005276635755, 0.07570216519525275, 0.04359942824521568, 0.01534741264549666, 0.007931768232083414, 0.0809247548750136, 0.03678043438412715, 0.017497072149126325, 0.0082322341404506, 0.03594886904465966, 0.050982409811695106, 0.006630572770518484, 0.03211510484106839, 0.03156064260110725, 0.02968793127365643, 0.11303121369564906, 0.045856076685595326, 0.010243715951219201, 0.016699576954124495, 0.01151844642663491, 0.04703852944658138, 0.02213384570495691, 0.021559612650889903, 0.028007222827000078, 0.028968712249479722, 0.05670658370945603, 0.006799814909754787, 0.0022248485720410827, 0.1114022069668863, 0.03757685160962865, 0.01843403915700037, 0.027950778785452712, 0.05920189942116849, 0.03903349454049021, 0.09702679904876277, 0.07876008821767755, 0.023901068161649164, 0.012243580367794493, 0.04809557409316767, 0.04226628239848651, 0.03202744606824126, 0.02989311655255733, 0.054891542822588235, 0.015957379182509612, 0.057195206318283454, 0.044599587272387, 0.07368655889877118, 0.039229414105648175, 0.015333258033933816, 0.027522990021680016, 0.02619311519083567, 0.015197974717011675, 0.018497066048439592, 0.010136540549865458, 0.023278795888472814, 0.05435043553006835, 0.013892100014345488, 0.02953459057607688, 0.057861261593643576, 0.042330815849709325, 0.05184307476156391, 0.05312525732733775, 0.014984746412665118, 0.047037709373398684, 0.020245113264536485, 0.0388453304185532, 0.01761780473316321, 0.05043479388405103, 0.037451543685165234, 0.018145327012462076, 0.07562795784906484, 0.038706166596966796, 0.0300281280578929, 0.007182385543273995, 0.029939519336039666, 0.03135082260996569, 0.04145820603298489, 0.007189332045527408, 0.009797922684811056, 0.03690612822538242, 0.005292047280818224, 0.01386276569974143, 0.09648244114941917, 0.05416308777057566, 0.04150225991907064, 0.03918517839338165, 0.035333535852259956, 0.023871289486123715, 0.029495154703909066, 0.02742810087511316, 0.001908482613544038, 0.044313711987342685, 0.046348294999916106, 0.025021941219165456, 0.014741700470040087, 0.01924354786751792, 0.023311747245315928, 0.008818419482850004, 0.026183541485806927, 0.027958276332356036, 0.06337959712254815, 0.034690984393819235, 0.09510992807918228, 0.029300815913302358, 0.08348850402398966, 0.024865054911060724, 0.07917411756352521, 0.027962957428826485, 0.030997434150776826, 0.04463995268451981, 0.05813309544464573, 0.027056683793489356, 0.04223807336529717, 0.08005069787031971, 0.06488827944849618, 0.009787587350729154, 0.06929697803570889, 0.03070750302867964, 0.01235098954566638, 0.04181060372502543, 0.041972714752773754, 0.076833049824927, 0.03695915096614044, 0.02930778282461688, 0.024525526059733238, 0.06882927656988613, 0.07642414871952496, 0.019128626299789175, 0.03939880189136602, 0.015541086286248174, 0.02724020949244732, 0.025424944105907343, 0.021202843709033914, 0.04952688752382528, 0.03720978907949757, 0.06970020171138458, 0.016994133511616383, 0.03055970802961383, 0.017181225230160635, 0.04400049598189071, 0.021855887280253228, 0.05753313213062938, 0.02865051086700987, 0.034685511054703966, 0.018480063445167616, 0.03629086182627361, 0.027085083929705434, 0.007399236455967184, 0.14455277851084247, 0.2311190209002234, 0.11114569104393013, 0.12957414553966373, 0.1093680618214421, 0.15103034733328968, 0.19130910630337894, 0.11748062650440261, 0.09585493302438408, 0.11601433565374464, 0.15811601711902767, 0.17943906277650967, 0.08713577393791638, 0.1266224609571509, 0.11109179627965204, 0.09034397444338538, 0.15750531863886863, 0.0618722246872494, 0.10477667616214603, 0.18243517231894657, 0.14949073229217902, 0.13153359352145344, 0.12965873553184792, 0.10858613502932712, 0.14261951349908486, 0.16193426301470026, 0.147386253811419, 0.15178886678768322, 0.2285945462062955, 0.13434091553790495, 0.16840018011862412, 0.17607548623345792, 0.1561169236083515, 0.24117650231346488, 0.12169925365014933, 0.16660664667142555, 0.13602590246591717, 0.0899132616177667, 0.1251080640940927, 0.10133987932931632, 0.18212483584647998, 0.16237254574662074, 0.09356316615594551, 0.21957344433758408, 0.1307315396843478, 0.07658718372113071, 0.23119244899135083, 0.06487115810159594, 0.18117877567419782, 0.10727596978540532, 0.07589798828121275, 0.1093123784812633, 0.11086124810390174, 0.19825957162538543, 0.11811760443379171, 0.13620734272990376, 0.2748257154598832, 0.20930862170644104, 0.10791537453769706, 0.11646708284388296, 0.11250091207330115, 0.19436384551227093, 0.14132627664366737, 0.13324091909453273, 0.15127344522625208, 0.13717583060497418, 0.1194320889771916, 0.08503652759827673, 0.10217223505605944, 0.14965379697969183, 0.15203319664578885, 0.16799183562397957, 0.10676536476239562, 0.17399897187715396, 0.1467529049841687, 0.14769477944355458, 0.12693683471297845, 0.11448885110439733, 0.08076409474597313, 0.08241749586886726, 0.22576184273930266, 0.15676373499445617, 0.18290857347892597, 0.22244024206884205, 0.11740227797417901, 0.09425970143638551, 0.20189872244372964, 0.18057540961308405, 0.1242069632280618, 0.24006470572203398, 0.1071888193837367, 0.12769002554705366, 0.15627955785021186, 0.10267019388265908, 0.19951121852500364, 0.14219332777429372, 0.13672549539478496, 0.1110302351298742, 0.11482399015221745, 0.12822548509575427, 0.20506205270066857, 0.14928689401131123, 0.16044932941440493, 0.11415979766752571, 0.18217798846308142, 0.1098052758607082, 0.14974634279496968, 0.1385517872404307, 0.09590806337655522, 0.1872951560653746, 0.2247172995703295, 0.16928575525525957, 0.21166878490475938, 0.16214381583267823, 0.26012875721789896, 0.13347554166102782, 0.11131686740554869, 0.06659352700808086, 0.06644860040978529, 0.15605912514729425, 0.11216899394639768, 0.06847794385976158, 0.14534560003085062, 0.1316954114008695, 0.10165142550249584, 0.12042606220347807, 0.13785198651021346, 0.15467245189938694, 0.15600831771735102, 0.18587449245387688, 0.19679823832120746, 0.2138755758642219, 0.21559059008723125, 0.1567364833317697, 0.1610094727948308, 0.07355568115599453, 0.16193300136364996, 0.11901341378688812, 0.12345645154709928, 0.1255085418233648, 0.1508512077271007, 0.17104513506637886, 0.21098382712807506, 0.0873891579976771, 0.1739837578497827, 0.12454732699552551, 0.16531602217582986, 0.15821749839233235, 0.1252480034600012, 0.20595254085492343, 0.11219556283322163, 0.10641806933563203, 0.07239549653604627, 0.17483756906585768, 0.14767239626962692, 0.18804407212883234, 0.08352702148840763, 0.12289985563256778, 0.15915802214294672, 0.10090665804455057, 0.14574633009033278, 0.14169749891152605, 0.18364819785347208, 0.16905609023524448, 0.09993777683121152, 0.14696199767058715, 0.07080580136971548, 0.1384261713246815, 0.18408799456665292, 0.21042025502538309, 0.160602375108283, 0.0945524861162994, 0.07333385321544483, 0.16222974169068038, 0.12781942641595379, 0.10326327377697453], [0.008094751283351798, 0.05081434304884169, 0.028091614294680767, 0.03215544427803252, 0.04010462886071764, 0.09490457581705414, 0.021184440302022267, 0.04355515542556532, 0.07728955228230916, 0.04532375271082856, 0.039842071855673566, 0.031415908961207606, 0.019614740449469537, 0.02857568753825035, 0.023982366728887428, 0.05570521127083339, 0.07217769103590399, 0.04487071608309634, 0.0553193835366983, 0.07235248907818459, 0.03397221807972528, 0.10077130515128374, 0.023040017294988502, 0.026199096901109442, 0.06077479607483838, 0.016865524885361083, 0.01041369374433998, 0.04503688294789754, 0.012974785076949047, 0.03753889075596817, 0.013386036007432267, 0.0733673908689525, 0.03203681197192054, 0.034779485504259355, 0.04396854652441107, 0.027455083509266842, 0.020509627684077714, 0.015550461466773413, 0.06361365565680899, 0.04055263001646381, 0.01431733115168754, 0.024864700535545126, 0.028768185802618973, 0.06001791676681023, 0.04418740587425418, 0.04645572087611072, 0.03718292704434134, 0.02391864407400135, 0.044798319577239454, 0.031547098406008445, 0.026693521249399055, 0.01479861855841591, 0.03536834628903307, 0.032208745324169286, 0.11780771324993111, 0.04159646814514417, 0.0761166398297064, 0.04496939574892167, 0.03851902292808518, 0.044581430629477836, 0.02863842499209568, 0.029420594837574754, 0.014967772567615611, 0.016784324652689975, 0.055972903937799856, 0.051120345378876664, 0.004731298122351291, 0.034675777787924744, 0.020701309586002026, 0.03299086507468019, 0.026411375256429892, 0.019661005935631692, 0.05184261091926601, 0.02707781459321268, 0.015760146015963983, 0.02822879843733972, 0.049461871676612645, 0.014881751158100087, 0.026679696893552318, 0.053986575367162004, 0.0524526785738999, 0.019549019561964087, 0.04002289984782692, 0.011679083363560494, 0.026165718809352256, 0.012631971294467803, 0.03424592956434935, 0.015604076070303563, 0.08079996274318546, 0.036989382351748645, 0.003691635502036661, 0.03323987046314869, 0.04024996735097375, 0.05444258429633919, 0.03595099529775325, 0.024986815369629767, 0.04080273749423213, 0.05965947057120502, 0.03067293935600901, 0.07006302286754362, 0.004887175109615782, 0.05430717203125823, 0.030084386562521104, 0.06489075822173618, 0.06568163531483151, 0.07516484285588376, 0.015536873670498608, 0.020329135513748042, 0.005367457833926892, 0.08173728041583672, 0.09194111335091293, 0.060702907940139994, 0.051591816954896785, 0.0431392336031422, 0.01304048741076258, 0.005989554774714634, 0.0692196017189417, 0.0031689350953456596, 0.0782068245462142, 0.06031126918969676, 0.016681136439729016, 0.06682020859443583, 0.05005050610634498, 0.023712271358817816, 0.03617135378590319, 0.02615800975036109, 0.05924646909988951, 0.008260256709036184, 0.02982857753522694, 0.05460436877910979, 0.07798031365382485, 0.022398254368454218, 0.06818351161200553, 0.023191007239802275, 0.08954038436058909, 0.04469912782951724, 0.010908302701864159, 0.07524336950154975, 0.0063024924747878686, 0.03722334440681152, 0.029992000308993738, 0.032652512527420186, 0.019215138454455882, 0.057447766594123095, 0.032676862392690964, 0.037621213487000205, 0.03878318668284919, 0.058562772974255495, 0.04433748297742568, 0.013684525019925786, 0.023813119951228146, 0.03211610674043186, 0.06424131221137941, 0.04141900579270441, 0.04345675406511873, 0.05951792074483819, 0.03632812135037966, 0.056757925485726446, 0.02420176413579611, 0.07224882589071058, 0.018381092486379202, 0.022043236895115115, 0.08435429350356571, 0.04276472362107597, 0.08388561982428655, 0.027786725186160766, 0.024728460775804706, 0.004518972918958752, 0.03586960396205541, 0.054060088805272244, 0.0472738978714915, 0.05809013993712142, 0.05837000753672328, 0.027176555486221332, 0.05225609478657134, 0.03965945157688111, 0.05595971968432423, 0.06119511141150724, 0.044555744898389094, 0.02228473917057272, 0.0787398053216748, 0.049060941237257794, 0.04193271670374088, 0.05040254385676235, 0.0536296988138929, 0.05121733665873762, 0.054806370244477876, 0.028791309268854093, 0.028731727798003703, 0.023168742809502874, 0.07585742248920724, 0.061101804894860834, 0.07037530376692303, 0.04894946323474869, 0.02648183290148154, 0.03998830834461842, 0.033299353599431925, 0.02814895262417849, 0.051423052573227324, 0.023315448706853203, 0.03573503032384906, 0.05123101444041822, 0.018323908152524382, 0.05747373805206735, 0.05740543449064717, 0.023973446113814134, 0.03151557197270449, 0.051788615965051576, 0.03789094334933907, 0.048269596591126174, 0.009034929007611936, 0.059194477944402024, 0.0935562641825527, 0.023050628151395358, 0.04894937788776588, 0.042913186553050764, 0.1100260647945106, 0.05328333849320188, 0.05194813318667002, 0.09942942793713883, 0.012474000523070572, 0.08141913654981181, 0.03611498395912349, 0.049856475307024084, 0.03494356322335079, 0.04311197822971735, 0.02145424994523637, 0.020358242545626126, 0.033231109409825876, 0.02774915767076891, 0.1151048559404444, 0.024901047218008898, 0.02779465874482412, 0.0812050788954366, 0.05301351586240344, 0.010076786529680248, 0.024244023879873566, 0.013213336387707386, 0.012823840588680468, 0.01856497812696034, 0.013992140593472868, 0.019866564143740106, 0.02410157791018719, 0.009509493484074483, 0.015607393470418174, 0.009938214570865966, 0.04043499589897692, 0.036958419950678945, 0.04317563223594334, 0.044216086171218194, 0.01123375022871187, 0.03430198397836648, 0.06592831778107211, 0.021134393573447596, 0.05647197598591447, 0.044955217017559335, 0.03031826883670874, 0.031357783955172636, 0.013239074069133494, 0.04253152968885843, 0.0610702524863882, 0.02038654434727505, 0.030552240168617573, 0.015535859711235389, 0.07851592163206078, 0.052462756939348765, 0.01035427832903224, 0.10681523708626628, 0.040907406291808, 0.048052017446025275, 0.027923239540541545, 0.04790693870745599, 0.03814254996541422, 0.011946656359214103, 0.07522250773035921, 0.04694696326623671, 0.057356200413778424, 0.06937748621567152, 0.011626411287579685, 0.02307934184500482, 0.020646986231440678, 0.018129745621990878, 0.05340762225387152, 0.03412083686271217, 0.046798177500022575, 0.029539848692365922, 0.035005306199309416, 0.017688800435280427, 0.03735092330316547, 0.05001557321520522, 0.0627008659648709, 0.02403184014838189, 0.032296018180204555, 0.034546952083474025, 0.023576567800773773, 0.052694704063469544, 0.03503946354612708, 0.031587712437612936, 0.023335082223638892, 0.04335905774496496, 0.03114610859483946, 0.02297596995049389, 0.010716426913859323, 0.014394154568435624, 0.05566086794715375, 0.06184006000694353, 0.062248163303593174, 0.07482828630600125, 0.020695246239483822, 0.006427604193959269, 0.04059294347825926, 0.0945029329159297, 0.026624585007084534, 0.012683948534686351, 0.03375038271769881, 0.030846171466691885, 0.037248354783514515, 0.027982089995930437, 0.00831853107229108, 0.0853998088859953, 0.036483311851043254, 0.029551181287388317, 0.016984815847536083, 0.007103990628820611, 0.05999386376061011, 0.05944390635704622, 0.09306598658440635, 0.018701991575653665, 0.03666987664473709, 0.02945715303212637, 0.029792021196044516, 0.025210116473317612, 0.029249448161863256, 0.02215692093159305, 0.03794752097746823, 0.05439780310553033, 0.00702959217960597, 0.03480703402601648, 0.022870366046845447, 0.021150102984393016, 0.06740614902810194, 0.0725316435273271, 0.01903161461086711, 0.01874366687843576, 0.046443497703876346, 0.04654532407585066, 0.046701894971192814, 0.07178200015914626, 0.08761861521634273, 0.045620730525115505, 0.03373042636667378, 0.009099007893382804, 0.13287063193274662, 0.21431381406728178, 0.13179344910895452, 0.09632696863263845, 0.21919909020652995, 0.232138509163633, 0.13202458358136937, 0.16929301345953718, 0.14049916790099815, 0.09881530073471367, 0.12208068787003867, 0.07484835397917777, 0.15479977475479245, 0.12729707319522277, 0.23808835161617026, 0.22339376824675128, 0.29739703866653144, 0.18431624950608239, 0.15164034819463268, 0.2186537007219158, 0.06952316238312051, 0.13508052506949753, 0.1568638952448964, 0.20089530909899622, 0.19091150810709223, 0.14547838509315625, 0.1507050491636619, 0.13407973892753944, 0.1193292866810225, 0.07231999043142423, 0.19158043549396098, 0.16357060958398506, 0.12280877184821293, 0.1265623766812496, 0.11205208342289552, 0.10333619720768183, 0.199299558007624, 0.19145761005347595, 0.15580268343910575, 0.1517590176081285, 0.12275119603145868, 0.18195049051428214, 0.16010614548576996, 0.13811546377837658, 0.061973171614226885, 0.15148344333283603, 0.14373926591360942, 0.1526581443613395, 0.19691224704729393, 0.2099658825318329, 0.16107862611534074, 0.10741324484115466, 0.11884440449648537, 0.11119338887510821, 0.20118710672250018, 0.09549792288453318, 0.1445739742484875, 0.20113436970859766, 0.17171478975797072, 0.2049589090165682, 0.23174016881966963, 0.07692886108998209, 0.10652803335688077, 0.09138674387941137, 0.17122029676102102, 0.13779818080365658, 0.07337101254961453, 0.21631844399962574, 0.11731661186786368, 0.2001797006232664, 0.12126577261369675, 0.09079276598640718, 0.227551665448118, 0.21238289424218237, 0.08532625462976284, 0.1292418414959684, 0.12177423282992095, 0.10339723143260926, 0.19087481632595882, 0.15559048857539892, 0.12410412382450886, 0.0849100953200832, 0.07219004037324339, 0.09058198862476274, 0.13761216890998185, 0.13888008368667215, 0.10750903384177946, 0.06763306810171343, 0.1865915406960994, 0.15161713381530717, 0.11151430095196702, 0.1945990024250932, 0.08410943672060966, 0.13422478426946327, 0.16086289862869307, 0.23790150851709768, 0.20004565390991047, 0.08145724583300762, 0.13887475506635383, 0.17986639140872285, 0.08809273625956848, 0.2595364936860278, 0.1933121183537878, 0.168367006117478, 0.15620605554431677, 0.11691208943375386, 0.12126104513299651, 0.08179094511433505, 0.10089620118378662, 0.14780089171836153, 0.14209972810931504, 0.18742308748187497, 0.18402743531623855, 0.17238564672879875, 0.18150089745176956, 0.1089425959798973, 0.10783499994431622, 0.14763246872462332, 0.18061128503177315, 0.1285009999992326, 0.14089292177231982, 0.22925425611902028, 0.11466569747426547, 0.09714636646094732, 0.16299698880175129, 0.09299165307311341, 0.15875592653173953, 0.19497389090247452, 0.13320401951204985, 0.15104143501957878, 0.11838300386443734, 0.13226609327830374, 0.15867620502831414, 0.1379013096448034, 0.16504898259881884, 0.16106249182485044, 0.08258130270405672, 0.2784792787861079, 0.08024916300200857, 0.1346103151445277, 0.09815940546104684, 0.09925238860887475, 0.09490988959441893, 0.20015181071357802, 0.08584529045037925, 0.08600328626926057, 0.1321651166654192, 0.1268895747489296, 0.12373028177535161, 0.18179247243097052, 0.18353614839725196, 0.10170213645324111, 0.16068068653112277, 0.0675053073791787, 0.051020277896896005, 0.11059256838052534, 0.1840611288207583, 0.12125532317440957, 0.13550314848544076, 0.13087277038721368, 0.10397994352388196, 0.15743713011033833, 0.16367661795811728, 0.11667844650219195, 0.22312098444672301, 0.12924556707730517, 0.15033934847451746, 0.11453657120000571, 0.08433898299699649, 0.1296328494208865, 0.10459691315190867, 0.1323697267798707, 0.18154968624003232, 0.263165952055715, 0.1039325722376816, 0.1379247911972925], [0.04976019277819432, 0.06562796319485642, 0.03229491980164312, 0.035676567640621215, 0.019681077319546603, 0.036367258508107625, 0.041924092947738245, 0.031370934812002815, 0.030135637425701134, 0.04543329370790161, 0.030180704343365505, 0.025004359740705695, 0.007535026752520935, 0.01624335280212108, 0.029966954680276103, 0.045860908066970296, 0.012861237410106696, 0.031255671856342815, 0.058707825737656094, 0.010926949162239907, 0.06811136001488194, 0.05266878455586266, 0.03788856105529703, 0.046928576557547785, 0.03413293758057989, 0.03668555822514463, 0.0390046583925141, 0.03726513103174511, 0.04967686072632205, 0.026400291280879173, 0.02642646497406531, 0.03138125437544659, 0.010611323959892616, 0.03383323237358127, 0.025399343721801415, 0.0780242784821894, 0.021514041072805412, 0.08906915027182549, 0.00523266387062904, 0.05459175969008356, 0.016216680014622398, 0.04257722001057118, 0.02526521908293944, 0.007948268957989058, 0.05298787094943691, 0.036463207070482895, 0.03112584054179024, 0.09691234503407031, 0.036047040339326486, 0.02634861368278507, 0.06588686141185462, 0.0395954264968168, 0.008865099644026486, 0.0896181317511946, 0.042608631410985254, 0.07417809814796783, 0.05323415265593212, 0.05357169997296296, 0.014136142290226417, 0.034289263567188755, 0.018819147007889114, 0.0330994635442039, 0.01686183826677734, 0.02076743679936044, 0.021426527018775232, 0.05153303514816798, 0.0155156510300003, 0.04576891886244994, 0.03286698578449432, 0.058304026897531, 0.023862932903284673, 0.03536418284056708, 0.02715040962357307, 0.0302228008149541, 0.006272946648095967, 0.10701083752792329, 0.03111608686594991, 0.036439109535422176, 0.06441482633817941, 0.02732519653363852, 0.01562739249493461, 0.04198107504635118, 0.00941076372328098, 0.008144272942445241, 0.021966029416944366, 0.028681963085546158, 0.03371372433321085, 0.011246016074437648, 0.036216238877386786, 0.07823980558896437, 0.05195127618208062, 0.04210024169879034, 0.10897299434873275, 0.028493147729022894, 0.014046879550733138, 0.04931866315018851, 0.06259447167394683, 0.005627789787467918, 0.03957939610700123, 0.023623141278221738, 0.058370233891764656, 0.034912842020276, 0.02665974239789648, 0.011642165227385703, 0.029884012255934067, 0.026301897341909353, 0.042170029555563815, 0.04231008766510058, 0.03504115935356822, 0.15840693900827318, 0.08792777167400345, 0.02967911455925787, 0.01926016640936723, 0.018031830368272495, 0.03657333807495888, 0.0447390627959976, 0.02794802170683397, 0.06391926464857534, 0.05298742195009254, 0.011686643993016332, 0.07178478321293369, 0.051162922391085885, 0.04157565090281423, 0.0353113493474666, 0.04236723674694076, 0.023650873481528834, 0.07251133094541728, 0.010102513078891207, 0.011409534399717813, 0.006499448727481649, 0.032932094400166534, 0.09649381827330217, 0.06055277517589275, 0.017515182407805696, 0.030213822683435865, 0.013950717620900832, 0.023585855778947007, 0.04671777322073467, 0.07909389882115647, 0.08671803385368548, 0.01940121528605232, 0.05417510314146057, 0.04532170438324101, 0.03788171845371835, 0.028097809372411575, 0.004221720046189148, 0.026268070250807796, 0.005016207223889069, 0.054298681861837395, 0.007338924433497596, 0.09491464676102623, 0.05839660982019268, 0.08028515716432594, 0.034925881554954685, 0.06964304891880602, 0.039731410215608776, 0.02602451408165507, 0.01273553150895168, 0.08149210450937971, 0.01745106084854342, 0.04233854902849998, 0.06284994859015569, 0.017985076920012943, 0.030258429469540715, 0.05617767361400183, 0.042797522837645374, 0.052394223312148824, 0.007164965945776203, 0.03731206445081625, 0.02415007726085605, 0.09095119225094095, 0.10700035098125227, 0.04158716903475579, 0.0676640379242599, 0.05812602277728729, 0.04136073235713411, 0.05356113921152428, 0.04070388342370279, 0.029412416370178107, 0.06973381357965991, 0.043536839220905676, 0.020145181224506814, 0.10496186427189969, 0.019160221381753217, 0.046429575013462454, 0.026214284953312017, 0.004596547296387143, 0.05162865716556553, 0.05376186789362691, 0.0047995534441724885, 0.032426049874629825, 0.05229269379924517, 0.0211231500361464, 0.059754610192612745, 0.06885184528073296, 0.03134696344204713, 0.03206602290447336, 0.03644110220193397, 0.04978300639777444, 0.014303411244327435, 0.04090091992111411, 0.0576445618935395, 0.0315655444865115, 0.011900145036634058, 0.08228931212215684, 0.04526570934103802, 0.029047890129731968, 0.0578207774378825, 0.0351440098893363, 0.014487176285911119, 0.019924512889701873, 0.0630989985074848, 0.026788067152665462, 0.01739737759635318, 0.0372061080270214, 0.04571718003717251, 0.05352087027858943, 0.024804948370729107, 0.11008694316842593, 0.06716498814057559, 0.0406836079491768, 0.04796459244971629, 0.02429144711641129, 0.05240521451923996, 0.024200517327699345, 0.04368499416159466, 0.06485414065537043, 0.0596435181068955, 0.02288412917550886, 0.11668822800857015, 0.02472229167324258, 0.04941677507304121, 0.009570869096933166, 0.034469961683498695, 0.055527975273435004, 0.02415306997136213, 0.035126970178680494, 0.025996783733717166, 0.017796014799387194, 0.024499404316884466, 0.04828520766750444, 0.08504319950588979, 0.05787248657725286, 0.03004686914209742, 0.016306717370753177, 0.033960506989387795, 0.015975867936504073, 0.056532208691351116, 0.04291542041755747, 0.03230542119126767, 0.010257989306410309, 0.11365573838702403, 0.022329407183860894, 0.06532889252412133, 0.087204556184588, 0.08204977653804235, 0.038857668623677455, 0.011620969489740673, 0.035779655663645826, 0.021173580826143734, 0.049424712342442945, 0.005145822387930821, 0.046314338032971136, 0.05517139928997494, 0.04268964796210639, 0.04041213032905944, 0.011647237806755584, 0.024551890855946112, 0.035158081009285524, 0.027551770508580375, 0.054152964876266196, 0.07504185414290987, 0.0753630259714555, 0.0065053641083068214, 0.04733222696813755, 0.04470715044590179, 0.019357448982191272, 0.03327641752548516, 0.02501509490684839, 0.022938057336432394, 0.020201656807330437, 0.018896703295467887, 0.054082813367131166, 0.042848508383031, 0.021813480962009635, 0.022183493529155385, 0.06635939425905235, 0.09034203001647256, 0.03535869465849828, 0.05159755004569888, 0.052179549675202, 0.03605464364227373, 0.037380935755209066, 0.016368670003430452, 0.04740645657875575, 0.05612873639620375, 0.07258074401761405, 0.031126085450523533, 0.07229369613924064, 0.054473813870572485, 0.019870983633154538, 0.042825787531910464, 0.09959264847566374, 0.035394228689256124, 0.07354291621595621, 0.06240261165658012, 0.005498490963873337, 0.014291431125457166, 0.013014154155825963, 0.03172588178131264, 0.023330415970121976, 0.019447478916845284, 0.03352338942931965, 0.03710843397129793, 0.08305879309773445, 0.05568204513110686, 0.06705963285639882, 0.03471872587397229, 0.07511052506742999, 0.06958111669518985, 0.03675217340060044, 0.009826915611483855, 0.030104161087365355, 0.04485268931603059, 0.014214211587386671, 0.006859584700578125, 0.05726490511733573, 0.018621268172864802, 0.015661781762901228, 0.0886571840965189, 0.0867795133672189, 0.0033883932655953686, 0.051704679062822834, 0.03496686294965912, 0.0978537519404199, 0.029597014472528826, 0.023007648524071556, 0.015543589179287665, 0.03645015640358906, 0.026554157047939952, 0.04219145164825022, 0.013532899611163884, 0.05375499931687955, 0.022032106535334606, 0.030516446386172902, 0.013412515836535022, 0.04383747582323849, 0.0396188635204453, 0.02312258307938464, 0.022151950397528708, 0.02080849797494011, 0.005281246712911525, 0.13242437853477895, 0.11467406890005805, 0.0932487849786412, 0.12179004799691029, 0.15024435357190669, 0.09434153063921258, 0.20010459527838975, 0.12295976921450347, 0.08746043386054225, 0.21011037868447602, 0.06773615983547643, 0.15803455899003893, 0.11169024190166965, 0.13605590007500723, 0.09808437433093786, 0.09969754362828098, 0.09849743888480589, 0.10008400960941799, 0.13336509524378926, 0.09820149265578948, 0.19456755020655692, 0.17301711050095037, 0.1725188028649427, 0.15315198426833376, 0.10928338277153671, 0.14133847755147144, 0.10274751082761213, 0.0753668331890367, 0.24371528561459854, 0.11582059800275601, 0.09538017373415641, 0.12083006513421424, 0.11203140718862414, 0.17636326141655445, 0.11530403353390284, 0.24908634193707258, 0.08239586968556978, 0.12378975006868131, 0.10000149020925164, 0.1265595416771248, 0.08717375705600716, 0.08205425168853253, 0.24963778734672815, 0.23671376053243876, 0.23951311188284308, 0.12026480835629627, 0.07668503589229658, 0.15336929995100945, 0.13958153198473155, 0.14506209961837158, 0.18369783269008622, 0.10565247721388005, 0.08778479692409746, 0.20856363902566954, 0.11225946174818091, 0.10185818042373285, 0.15853221353609115, 0.1212431000021752, 0.2127158662187867, 0.09426075528608635, 0.15240572509355843, 0.13051257643382996, 0.09069521067431197, 0.11338863201672211, 0.10171961403102614, 0.10067913783132099, 0.15745954297017306, 0.10108696282259189, 0.05719534361560363, 0.15310966700781137, 0.07736683211987838, 0.08513161155860871, 0.2522716100793332, 0.17031055729603395, 0.08183470214135014, 0.19080542551819235, 0.11629936489043757, 0.1318993981112726, 0.1367074908921495, 0.1270982518326491, 0.10352134078857489, 0.11495359882246703, 0.08962830659584142, 0.07729964549071155, 0.2777349640382454, 0.16479890851769596, 0.14424872060772032, 0.133099302474875, 0.17168402031529695, 0.1879344866028987, 0.113488295028219, 0.11109611557913013, 0.18499256868381053, 0.09900228484184481, 0.14965516253141686, 0.14671763812657446, 0.19594426383264363, 0.12094367310055532, 0.15811692253919318, 0.13379965239437297, 0.18702440574998036, 0.10606262512737885, 0.13293699477799237, 0.18356578977545723, 0.12949452793691307, 0.1264731408446096, 0.21930726565187797, 0.14088406052906066, 0.12427576031768695, 0.23858676315285265, 0.1862168897059746, 0.22324146470054984, 0.09692222301964648, 0.18652455444680527, 0.12850310769863427, 0.140361187804956, 0.17966326558962464, 0.1501827998436056, 0.12026295298710465, 0.1231581081810873, 0.16957657324383035, 0.09784556605154648, 0.19570242759073153, 0.09827357003814541, 0.13594301941338927, 0.172379219729919, 0.13718771981075406, 0.12231134736794047, 0.169257553643547, 0.16558859817450866, 0.08898894637241028, 0.12416430457960814, 0.14334785722894594, 0.13148394384188578, 0.0703019869979471, 0.05711399680876639, 0.07597502321004868, 0.12351087323622778, 0.1383837650064379, 0.17553484649397433, 0.18677912594284862, 0.15863415494095534, 0.1131463133788202, 0.1820868972572498, 0.17675032111583278, 0.07667949204915203, 0.1579001560457982, 0.05449321361084003, 0.0929613363405224, 0.047181949485093355, 0.2091000633663498, 0.10681827247026376, 0.13184127310523763, 0.21344456617953256, 0.27761907025706023, 0.08937159771448933, 0.1444926645490341, 0.11620291537838057, 0.30876308970618993, 0.0813151616603136, 0.1159725601610262, 0.14330837497254834, 0.1134881169127766, 0.13736984285060316, 0.19961658865213394, 0.12326626878348179, 0.24671310209669173, 0.14919197332346812, 0.13618313387269154, 0.08517073016264476, 0.2839601878076792, 0.1482591827516444, 0.20365167525596917, 0.1426041658851318, 0.20527733489871025, 0.09156013184110634], [0.06284002607571892, 0.023227339079312515, 0.0574642088758992, 0.012361532681097742, 0.06387721456121653, 0.04884798196144402, 0.016563704557484016, 0.04516684413829353, 0.03670430858619511, 0.05353515662136488, 0.051288144968566485, 0.037768218098790385, 0.020904645061818883, 0.02693009009817615, 0.03351386767462827, 0.04713447058747988, 0.027125697961309925, 0.036984721664339304, 0.00943391780310776, 0.037096863889019005, 0.04487795944442041, 0.007547895129391691, 0.011159913028677693, 0.03670604150102008, 0.05286784340569284, 0.04613857148797251, 0.056788772853906266, 0.07567485416075215, 0.06989289293414913, 0.026399974012747407, 0.017397841438651085, 0.025745197526703123, 0.051183027171646245, 0.025802107265917584, 0.017907982619362883, 0.06008196040056646, 0.02565718808909878, 0.07382456125924364, 0.02144382833648706, 0.11859683887450956, 0.04475779089261778, 0.04097551318409387, 0.006337385939332307, 0.04552369471639395, 0.09494971323874779, 0.10170816269237548, 0.04426383224199526, 0.036503531664493494, 0.041954791886382736, 0.060280095276539214, 0.024779477862466592, 0.01948636559973238, 0.03782232437515631, 0.06363002743455581, 0.03372574341483414, 0.09013616567244753, 0.039976163097890094, 0.017557306709932163, 0.01064775227860082, 0.006719577613694128, 0.07032782858004794, 0.03566286017303355, 0.037465303103090264, 0.04079690421349369, 0.023592036013724282, 0.006049036055628676, 0.06473029847256839, 0.04910872441541869, 0.02125677372532664, 0.033400638203602284, 0.02215190586866811, 0.008761522731219884, 0.053074186434969306, 0.013975965484860353, 0.024520837541786022, 0.02237146098195808, 0.06729257816914469, 0.02063308023934951, 0.029417923105938826, 0.04469637817237526, 0.03741206142876763, 0.0055939088906598045, 0.029463160717568826, 0.018186616398452315, 0.025417518918402493, 0.023841139736759942, 0.026477079445612617, 0.011813374985649716, 0.02096339903800981, 0.0632213860808406, 0.006361457035382045, 0.09101359944907017, 0.036165446290397085, 0.03679991204990074, 0.07500551117118448, 0.046578668770962395, 0.02757022957666777, 0.013032335846219212, 0.042152689275098965, 0.05794591466838028, 0.020961352565791458, 0.04728177205834072, 0.113205492234556, 0.005562061014643405, 0.033789252702263184, 0.020710055796371307, 0.06058151113393251, 0.007697981973251444, 0.018914845095423516, 0.009043909922183957, 0.06920164916664362, 0.0634236287442036, 0.03060228318645386, 0.019106593790638726, 0.08127863315166906, 0.02205724307714263, 0.038801402697572485, 0.08716923737665638, 0.030084121244726703, 0.01767357713106321, 0.021326116293494124, 0.021226327116892207, 0.058191175921820104, 0.027052768964495044, 0.02805037314828951, 0.07641500546014868, 0.05285142338834703, 0.03230720234569162, 0.026278371260559652, 0.02963383241876727, 0.03135936101898551, 0.030946804836275987, 0.0275350554875331, 0.040855619226931594, 0.03607373910199385, 0.050248225379618816, 0.02620148290588986, 0.02857178755220957, 0.028137942863395438, 0.03705646508024074, 0.03490366165351588, 0.04165797363384627, 0.0388231327815447, 0.020131065575696994, 0.023352656280621886, 0.07185406269854866, 0.011937838717130944, 0.036421342520043254, 0.06957287885597907, 0.022476111225842033, 0.04392826645926107, 0.03199742248398252, 0.07078993425238878, 0.007476148930436466, 0.05949690312263556, 0.03512855837470852, 0.04481557079998311, 0.052075404091738164, 0.05539628858969081, 0.12719012971501797, 0.031715068689663894, 0.047306552369263954, 0.046600402565672994, 0.019149202344124205, 0.028867180881206878, 0.11266321234870702, 0.043787421673187055, 0.04755484529596288, 0.026869395405810792, 0.010296194141119486, 0.03758713777642697, 0.02086089731164975, 0.03192406118614599, 0.056478146943845786, 0.007317011131817708, 0.08056128062889911, 0.05803206317068543, 0.007203930090327049, 0.03281289435108192, 0.0316051158006303, 0.032946774081210606, 0.035648199045681395, 0.05271984431601595, 0.0781383688445203, 0.10290289428667165, 0.05886704981094226, 0.054019122253521346, 0.019035696423088666, 0.04869586024142336, 0.019403929691179655, 0.05906699923798442, 0.03529021669237409, 0.024900167773012072, 0.03082096627622377, 0.02635618729982525, 0.019427761908445973, 0.020846824336331338, 0.06107876863097772, 0.02514340667403303, 0.044618448955588974, 0.02748869166680379, 0.026066907412314322, 0.028868258850707207, 0.06849642333691008, 0.03950870654080063, 0.04379270947538316, 0.03033625293028308, 0.023348626418737695, 0.022788544265495148, 0.037028961087344214, 0.00901955078006722, 0.016051370330387726, 0.077670875180047, 0.019422451841819566, 0.012111963260394987, 0.06714267918141559, 0.08892082463717088, 0.01654487812629668, 0.013576342153100995, 0.013027705772401532, 0.04901960361166857, 0.037871833046665415, 0.038809195248177275, 0.06109157438913826, 0.052309072998468764, 0.0131730312750733, 0.032310074457200244, 0.028694946959149092, 0.030355018134287093, 0.066420643706806, 0.02551123732700944, 0.049638918426353484, 0.02488180332875345, 0.06262274750042707, 0.01711957131192321, 0.05190421288716607, 0.016069202283688355, 0.02856104310922092, 0.011451762602519011, 0.03601020383939613, 0.07105802025762387, 0.012288667694519972, 0.028714467298414093, 0.01863429100922076, 0.008178481311915675, 0.01922393847053172, 0.03333956316055264, 0.021676551004929934, 0.0024935591409303015, 0.03768356502405368, 0.026264754706062376, 0.03934122978535015, 0.05397796274337452, 0.010754527847893769, 0.008547053184884135, 0.04753446963150054, 0.023895392587292008, 0.05425034207291901, 0.04346514033386484, 0.048109615527209826, 0.03214960357581731, 0.019236753505538218, 0.011990493167104432, 0.02457703110849252, 0.02742865191976307, 0.05506558016350027, 0.02162009768653661, 0.030668907638755627, 0.04759655028465204, 0.0555534717568662, 0.11326472304062918, 0.05158571650099475, 0.027603800626820885, 0.007664844151804573, 0.06825451288023032, 0.04158515039307531, 0.023105808686523233, 0.08938889717683196, 0.06030941382050514, 0.0207654311452643, 0.06432843292714097, 0.048465627478435636, 0.014620564343204023, 0.017167603109555785, 0.05039477357058786, 0.013419952156255022, 0.048887968878261745, 0.05538031386095099, 0.03828089371381793, 0.03329564286104869, 0.12007009849185124, 0.014220009616110474, 0.08621067201602273, 0.031202519239741378, 0.061321521425270475, 0.03454872210568283, 0.07166331590269692, 0.034998994233319536, 0.029405286186374724, 0.056079261121340096, 0.03054087788768811, 0.03823938539426308, 0.025149369830614887, 0.011042200985684758, 0.024038380324782338, 0.01745303310599411, 0.034802941081579775, 0.056322796881431714, 0.06182043762237299, 0.027211490232730284, 0.03305095306131989, 0.031116103564272635, 0.021268661075737327, 0.009122091469180305, 0.06559150147950277, 0.0434430614404846, 0.05557496064284351, 0.017179317910631653, 0.061575695872306824, 0.013581644798250636, 0.024566238425904885, 0.016414874262409285, 0.018610952320159413, 0.026164950686506927, 0.1188603532500565, 0.032779260218376294, 0.05176596561796032, 0.051344366365810856, 0.06019386142725125, 0.013914151077187853, 0.12315606727497652, 0.0403199147694977, 0.03246496809879318, 0.007832086666894611, 0.06141948491858784, 0.04440133365278598, 0.027531411542440765, 0.027374575329304207, 0.020275075621611904, 0.0024920771647884976, 0.01033167065543239, 0.05846699881658424, 0.08599662920460105, 0.04951017806888558, 0.02045797049504472, 0.026715108469943516, 0.08344860616489314, 0.04442946476046927, 0.026851279581023846, 0.03808020213909913, 0.02735799575020792, 0.0162869929408771, 0.14422454143641517, 0.16600544768152758, 0.3095740790013224, 0.08574757928727195, 0.14285814366303384, 0.12676542828558013, 0.13931995461462066, 0.12000206581433304, 0.09622554673114792, 0.1462930257548578, 0.18953252350911498, 0.20090961770620197, 0.13395789312198758, 0.11077155955717899, 0.14667088282294571, 0.11506653143442236, 0.09837096949922852, 0.1567555862129666, 0.11255270655965433, 0.08140535486745648, 0.16400917433202267, 0.20994922873796895, 0.1869662362150848, 0.13193003396736458, 0.16269051149720326, 0.13567839923780411, 0.12129099079174921, 0.28303942002821714, 0.13813193945679814, 0.17002781387418509, 0.13987478421768174, 0.16865320794750005, 0.17497394612291828, 0.1557114883325994, 0.16556176211452112, 0.1287998480256647, 0.1500427268911153, 0.11958261136896908, 0.13855199504178017, 0.20257925702026114, 0.11690173647366464, 0.12025370582705364, 0.11210131749976426, 0.0645998066465836, 0.17270508193178102, 0.22502306441310793, 0.13066842744592577, 0.12240021955221891, 0.14198393822880462, 0.15443376236362383, 0.09566249413182959, 0.08422754210187122, 0.18097869266057387, 0.12707433983450755, 0.14110891643213108, 0.20639215945266187, 0.14970199204981327, 0.12965533649548888, 0.06413113296730444, 0.12952583172591403, 0.10124150023330003, 0.15459684189409018, 0.11174196217325516, 0.22013208857970312, 0.2405289190937765, 0.07575102819828317, 0.3348070406354964, 0.12769983673933893, 0.08683685169671662, 0.12920422945171595, 0.08796133159194142, 0.07847242435673252, 0.20320427895057946, 0.20045251410920173, 0.15838120132684708, 0.14763528888579458, 0.20599099894752726, 0.09701791554107331, 0.18955192324938253, 0.14018534333445132, 0.1604962776764296, 0.22942321345908567, 0.13491131539922208, 0.10528187092859298, 0.06450504180975258, 0.09187544070300646, 0.12789315136615187, 0.10814612309332006, 0.1455578245804645, 0.132718016684521, 0.2094060805393383, 0.1686003225040622, 0.1866176791372709, 0.14009110542247072, 0.15118324459763244, 0.1151505573943723, 0.152555609238334, 0.08448908236459829, 0.13281976513098925, 0.12856687302701175, 0.10986374225467443, 0.20164685236522928, 0.23975818388862535, 0.14812857960350811, 0.11847554225823842, 0.08980426980997436, 0.17986913735512644, 0.07347453472902998, 0.11494800302898511, 0.13822536100633442, 0.21085239277454093, 0.2404706456582062, 0.1474476294242777, 0.11192484962521121, 0.2433138430933468, 0.15938409516820684, 0.17057180812116712, 0.1416086935205385, 0.13395585963735357, 0.11789955402491614, 0.08524401724571362, 0.0769857615523506, 0.16665081930113956, 0.12891341146314517, 0.11466381984064355, 0.10481543853529729, 0.13521656073862687, 0.10777570234495215, 0.08638559622340836, 0.05669341429893393, 0.20182345382636413, 0.17676661867881194, 0.1526037894655019, 0.1372402935521677, 0.14325741911306977, 0.10676430349121802, 0.16862202290212736, 0.0801835794118233, 0.12856322166044265, 0.08580956346122548, 0.11318159507936798, 0.1191269772243686, 0.18424957495881245, 0.07832870745914988, 0.08053273762925528, 0.09768055693712085, 0.08753760237595998, 0.0891122616303619, 0.21770821942482144, 0.109276414004853, 0.0946865402511321, 0.10763634185423143, 0.12419350809068419, 0.1792463567107916, 0.1764496770920232, 0.09956044668797404, 0.11632856840151362, 0.11273288517259061, 0.1259325456339866, 0.21553893660893664, 0.19283827190520242, 0.06561204412719235, 0.13770134537480772, 0.09059778152732179, 0.07172014215029776, 0.16030679253162816, 0.15261245775036514, 0.12132499599829316, 0.17904777283547446, 0.16892397310584784, 0.1297813976998441, 0.14821741468040273, 0.12790971610229462, 0.20150813012151048, 0.22099801164586097, 0.17156355490442365], [0.032873579766601324, 0.0067466321434039855, 0.04965490057657007, 0.028224490270076785, 0.01662521932303207, 0.02189272749092197, 0.021849998338439036, 0.03756432415684685, 0.011528870818438008, 0.03818734228843823, 0.06235177454072982, 0.08314534978126176, 0.013192574806453194, 0.056421250192215666, 0.03416691681195516, 0.029384801055130083, 0.024961509989225306, 0.07186547692981549, 0.12243266624864191, 0.06425527200917713, 0.058234751122654416, 0.0025534826954753953, 0.02186092831834685, 0.02682860696950229, 0.02736789785558358, 0.015042381601233501, 0.04321691048971843, 0.047962310345610604, 0.08012632271857001, 0.031693679993622936, 0.04700662451796234, 0.05179968138691038, 0.04094135954801459, 0.02608985647384543, 0.02793906027363846, 0.034089952387148514, 0.06304114809609018, 0.02886221591325011, 0.02467830458044773, 0.057203677934012376, 0.053227996540954337, 0.02924209718912607, 0.020256379066267982, 0.01262541441974463, 0.015016568777355133, 0.05646208315738477, 0.038778808011556976, 0.05380682348913979, 0.029626026880578138, 0.10029907658463344, 0.035207634209655225, 0.01307477185036987, 0.021989086089888588, 0.018913112180598546, 0.017086560583265964, 0.017505499235994648, 0.049583331565372646, 0.12830660183681175, 0.016272940374619793, 0.009135584641626338, 0.07399949288810603, 0.013235450533102266, 0.006549405006808229, 0.026935305540973786, 0.01834182916354621, 0.05439259322884027, 0.0487910406809533, 0.04277807856851723, 0.026531528965278994, 0.03436979401158169, 0.022580867225769907, 0.013023015399085125, 0.051753167281276546, 0.031527865648968145, 0.03832991627859883, 0.019595318444771692, 0.028765284005203284, 0.059195316571276635, 0.035133304409100674, 0.021782717085443437, 0.05019010779506061, 0.052963124035159126, 0.006992317348704091, 0.008788058221398387, 0.05742529065173585, 0.03629043509135954, 0.04783399301231839, 0.009010327739815693, 0.03432669007452205, 0.08467392908642069, 0.010045888138847658, 0.025473215246165637, 0.019770877188420855, 0.044889336568303406, 0.026980071888829116, 0.06745648890500888, 0.03217434306861833, 0.056385523203061894, 0.03265515457314905, 0.05533385912713129, 0.013498368407454109, 0.022253895513131283, 0.019507346114551183, 0.033970388685702346, 0.03627547339419834, 0.04183523189567495, 0.02548315631429432, 0.02760137380391825, 0.04797426634468138, 0.03550258967152331, 0.02957333254016703, 0.07212939206510782, 0.044578447195817716, 0.029284175107022747, 0.03580765318474732, 0.04167393723037094, 0.01499763566243928, 0.02267280262458371, 0.027731837799365167, 0.02524565421481384, 0.01664111241552746, 0.08432051094132476, 0.01267872567041195, 0.036190393584547564, 0.019494510670483578, 0.05389256381022278, 0.021830613441125024, 0.028423469339031726, 0.012888254368590424, 0.01727847811707761, 0.06018599095114041, 0.03831600843113847, 0.03585430829843972, 0.027934139834542293, 0.04261139591108076, 0.029773677160847, 0.011685851750371512, 0.011994973883702187, 0.07779145933454856, 0.025880854700517375, 0.0578864649287425, 0.0425498607364716, 0.01863806483015651, 0.08420568585279398, 0.04844980488996953, 0.01240436295120162, 0.034664545382838696, 0.02812101818562951, 0.0515447388170287, 0.026279083722329233, 0.07349784558755346, 0.01935369557031663, 0.06531807201099582, 0.0139232368201192, 0.026855628566408996, 0.04253423852787819, 0.05354312728741206, 0.04699213779531419, 0.09733414466609247, 0.035640406495076604, 0.013786195540888002, 0.06766857986804098, 0.04474157125514466, 0.031823641184018925, 0.03604473968152888, 0.07074720881064422, 0.02059506186924409, 0.008867515334713971, 0.048659153617336415, 0.04350280432845466, 0.021458326191350352, 0.02177467777073616, 0.0224941120177391, 0.0647224168642424, 0.039585919585078955, 0.06571849036845379, 0.0171413292264333, 0.023640492690901738, 0.051729696861002594, 0.05525769622181542, 0.017844811009126715, 0.021083506362629123, 0.023985647021618206, 0.03769417031435296, 0.04616561534930952, 0.08583829941926524, 0.029115998877387028, 0.04701689955254551, 0.04076112156326417, 0.006920537753103417, 0.07806352325133048, 0.03561786375939846, 0.058388030593050644, 0.07907117425929755, 0.028922834535478614, 0.048465453073731624, 0.015249373082042439, 0.0419753159803804, 0.051765227181022055, 0.020428503521543462, 0.016052687642513774, 0.034031185423373245, 0.0941397035785485, 0.044368942617438734, 0.04022121283924207, 0.03255155446822755, 0.04574453560053371, 0.005445349943329347, 0.04910545154416468, 0.02921633538790047, 0.037427791248774156, 0.02812006452586502, 0.026839104648388457, 0.0201101277343696, 0.018426216920488514, 0.013662267083418556, 0.026378247639513575, 0.03906142526830081, 0.021025717178417835, 0.02575059850641992, 0.04096634766028728, 0.029430806789605413, 0.018450383104209322, 0.12891569727798924, 0.03252456255722791, 0.026908057589025702, 0.03742233275261242, 0.013713958596781595, 0.03294892630947288, 0.047219257248798385, 0.0194224666847731, 0.049132243075291626, 0.01994664558878867, 0.03775993573071901, 0.0397174170211656, 0.019093316768703517, 0.039475810845033266, 0.003381773772161978, 0.02144360012607649, 0.056386751457466744, 0.017856997073977254, 0.06438128126319498, 0.029407729707600083, 0.024440269990009256, 0.09003473634948023, 0.010423709027236328, 0.034444647026248276, 0.03207482848665677, 0.021125960920471698, 0.05306106155330781, 0.08025718561839312, 0.04927283553115558, 0.05316225338901859, 0.07098159388988279, 0.029808535837219097, 0.009464885770285036, 0.04457059898413718, 0.04393468603666406, 0.027655324229272082, 0.07143373994040303, 0.04764896446431521, 0.06318467203527689, 0.052634927778854035, 0.021256389663903974, 0.0660761387553066, 0.03477720340015367, 0.039139202344813384, 0.0679828051943332, 0.018136526996386237, 0.054854580157552846, 0.031314141961047426, 0.05481805535964668, 0.032939085431280546, 0.006788219779991778, 0.0140028674104542, 0.03364641153893899, 0.044356904982123524, 0.035374940271140076, 0.04359048907645047, 0.024553176626795903, 0.057209667065762915, 0.032154063883353956, 0.11734348503523506, 0.04139560216572136, 0.0827815786760766, 0.059159292723052204, 0.06131761401775293, 0.023585197122883983, 0.015297403024305822, 0.04135398252401501, 0.00012097405743816125, 0.021508658646780532, 0.02781622370093828, 0.06910159281687811, 0.026506570538913365, 0.031659066225984134, 0.014056661057111342, 0.06735116330673918, 0.033563869874342345, 0.020357630273792893, 0.07789090712321922, 0.015607213499606587, 0.0031186671139948885, 0.04886961185547989, 0.02123277823557146, 0.009834560660237912, 0.040444465703330934, 0.013377984632825246, 0.05650792190863285, 0.04812490748008713, 0.09848316738498397, 0.010074412584799575, 0.04129656997974962, 0.02769382128462894, 0.06571879464900121, 0.010970148650812916, 0.03985230236139614, 0.0063139670055534225, 0.08733633934753016, 0.07381531409919262, 0.033911013160832226, 0.003033920343114005, 0.027803913326351903, 0.010956694441119907, 0.039687627213425, 0.013349810851650545, 0.053762339157401584, 0.11846553810755722, 0.09796957892831415, 0.02556393537815893, 0.0702401067246683, 0.06731633431627415, 0.01730889875034336, 0.039470014671678655, 0.06377836049068719, 0.07825132372090593, 0.07201753556728363, 0.09868486828054301, 0.03347360987390857, 0.04111164162168279, 0.010639403117238544, 0.09332530782558024, 0.03144976944895461, 0.04200311683234759, 0.06963051404454745, 0.021602226770482957, 0.030001152845215984, 0.04640703227778431, 0.009801819887798047, 0.024175649814424105, 0.010684201934054727, 0.0805582749308087, 0.12095124300685711, 0.1293859220459126, 0.13438314374070615, 0.1652287010801956, 0.08437864336883649, 0.19527995260432363, 0.10089937757584266, 0.08168048385414295, 0.11855616176035255, 0.1339642607490532, 0.18027044628979638, 0.1541910058585927, 0.16514994436874986, 0.1379894619458355, 0.25782142009120435, 0.14548743929481134, 0.17108866944909096, 0.20900242641801015, 0.19360642443643883, 0.09034444199642166, 0.1403418177505955, 0.17132532550022006, 0.151938172057271, 0.09090298233786598, 0.09679753478849307, 0.08845524571370333, 0.20268281630706042, 0.12543055694550276, 0.185666557517834, 0.11165812175022438, 0.1046426517132204, 0.14774775394471362, 0.15870641043875366, 0.10156028234632686, 0.16544807993341237, 0.1504086353816092, 0.1449522320763208, 0.0690213443886023, 0.0920489251438994, 0.09955663204891607, 0.07775137593853287, 0.162858949333895, 0.10816466936375946, 0.09473203390371054, 0.11468051074189134, 0.1123315465520136, 0.1124990863900166, 0.23178505391115323, 0.11139785056002438, 0.2462173326057382, 0.2010321759735234, 0.1679748998139985, 0.0776288473571185, 0.1816145351040177, 0.24144634720869362, 0.10721253842348233, 0.10222740631434135, 0.22435084189055488, 0.09343427736894228, 0.11257189849857241, 0.1642473295214586, 0.051009776507271454, 0.07875098948716186, 0.0917242281138897, 0.10259187503834255, 0.21659115358488634, 0.11668194201774895, 0.21675942814908922, 0.21702591853681952, 0.09966054756660014, 0.1184318149171304, 0.1385693612974137, 0.10804703895701095, 0.09839023565291427, 0.14517967065330595, 0.13319826044607908, 0.12523228477220982, 0.18855474394513294, 0.12765035033226013, 0.08231248197262175, 0.17887087451526895, 0.12743399944156408, 0.13947868515970185, 0.17914426687639207, 0.20115905354032293, 0.21192405401961878, 0.1293047162471339, 0.1621285721193999, 0.18816873809555545, 0.11036797965061851, 0.12658691208343953, 0.10080628999276087, 0.09622646699426696, 0.14618620101828128, 0.06945457309484482, 0.20854272530414164, 0.1669825889985077, 0.09387820042320527, 0.14989294664701447, 0.15779871930135414, 0.1480101773631759, 0.1345464459154755, 0.11935666450881399, 0.1877278133179061, 0.17659644421655685, 0.11767064599553123, 0.2083294469048269, 0.15163635544013232, 0.1567228278145194, 0.1652538450434804, 0.07880999764893204, 0.1450935666798614, 0.15783066133735701, 0.09480061577050947, 0.22560041077667847, 0.14140063984086737, 0.1037661827285774, 0.08803409917163663, 0.09786031252588145, 0.10633037716615945, 0.14957931503886357, 0.21200462157139555, 0.10868334895349108, 0.16867339436430484, 0.23380936559988186, 0.10785725695313886, 0.13327863503945991, 0.1454682621988468, 0.132239390804898, 0.19304672634461895, 0.12125020977691747, 0.1425669842865318, 0.23270524281542748, 0.08750461391173303, 0.12345608047326095, 0.16042382922023535, 0.1040031282173004, 0.11479033375508152, 0.22576377232326195, 0.11059181881137192, 0.14452487375820056, 0.11535655532497913, 0.14442487678024918, 0.1761598832672462, 0.07228756599943154, 0.09004509673104621, 0.15379416465293616, 0.11931146771530621, 0.1394425128819421, 0.08678700905875303, 0.12899696244858205, 0.15531960467342287, 0.20601943804649636, 0.12442185950931162, 0.16425283625721931, 0.1261739365872927, 0.11781771740061231, 0.10498789881239645, 0.2264587936224416, 0.14323617884656414, 0.18102347385138273, 0.15263298555510119, 0.0770115882914979, 0.17359065706841648, 0.10054790385765955, 0.17556591279571876, 0.11859456048114225, 0.0955019898538012, 0.12902756861876696, 0.12352021687547676, 0.09764178714249283, 0.1541985312360339, 0.12818266317481175, 0.09547137626213953, 0.11620658900937997, 0.12833904853323475]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.009186859624605859, 0.05684893505531363, 0.13970538158901036, 0.007291241909115342, 0.04235754058754537, 0.05058251837908756, 0.02693137215828756, 0.0025280504542024573, 0.03006247465236811, 0.00888610427864478, 0.04653503419831395, 0.03649278536613565, 0.03770365867239889, 0.04921501109492965, 0.062301746365847066, 0.04035155252495315, 0.014539263920596568, 0.04917165482765995, 0.043800720959552564, 0.03763531429285649, 0.07889619068009779, 0.02689006050786702, 0.021399253091658466, 0.05646583471389022, 0.062379538285313174, 0.0207856157066999, 0.04880227308603935, 0.02465970079356339, 0.05785897948953789, 0.03613184184359852, 0.035160800980520435, 0.03560217846825253, 0.06565142248291522, 0.03246001055231318, 0.01951080823346274, 0.05124485549458768, 0.026946489706460852, 0.025287455682700966, 0.01630537779419683, 0.11670917141600512, 0.03307679835415911, 0.03226675900805276, 0.0610379616409773, 0.027378523554943968, 0.06773417830117978, 0.059319748761481605, 0.035760155733441934, 0.14024038100615144, 0.012150891689088894, 0.009715283613331849, 0.02534983133955393, 0.07656460758880712, 0.0073856059862009715, 0.021996322029735893, 0.04365864420833532, 0.03119146123935934, 0.1475594413932413, 0.04638365462596994, 0.05212499811023008, 0.04652302995964419, 0.03579745978640858, 0.05867574269359466, 0.02422954643407138, 0.021950223526800983, 0.07328490115469322, 0.021110312736709602, 0.017007622045639437, 0.07226149435155094, 0.05280371813569218, 0.06742142242728733, 0.07655906374566257, 0.026162273388763424, 0.06360482409945689, 0.00444097830040846, 0.021102922801219393, 0.022233929885260295, 0.02857006576959975, 0.053509645294980146, 0.04247390563250519, 0.05795476106868591, 0.025981554863392375, 0.057816907137748785, 0.02980306435347302, 0.03530125613906421, 0.044762447869288735, 0.027939637293457054, 0.015136872771108756, 0.06199290532094892, 0.03149776784994174, 0.0340218120982172, 0.05154184815182816, 0.05472377291880548, 0.08956022196798585, 0.030907049840607215, 0.055376554882968776, 0.07664357210160233, 0.004759334606205812, 0.02022501219471451, 0.03267971223976929, 0.005005394132240326, 0.01665827086981153, 0.027176440453331452, 0.032157321911654435, 0.02576045793830417, 0.019488022444420494, 0.06435732473619282, 0.010151982787647285, 0.022555630494025536, 0.013587849152827403, 0.011936497285205405, 0.032823340079630725, 0.033347047719871625, 0.04233930230839178, 0.006783032167732017, 0.06579474604222924, 0.05128615230205469, 0.01426892642484745, 0.09773998070158996, 0.04356601675681304, 0.0070546985716646304, 0.03077476201724494, 0.07381564806564711, 0.0485207430756418, 0.029107135778758675, 0.06003010283166077, 0.04072065967193339, 0.04427665284310933, 0.008447985746897757, 0.03408763688639738, 0.008936533213272924, 0.02272122033900814, 0.03539979108609259, 0.014729992162756389, 0.0368193303438602, 0.03637397494458128, 0.024661981042299885, 0.05571074769250117, 0.0679502026468981, 0.018057950255752075, 0.0913420962751843, 0.05504845510586165, 0.022642352305410895, 0.010902218946284847, 0.017342250866931863, 0.024281292680825572, 0.024703511626285035, 0.039411730103893206, 0.040163184312405065, 0.012126393394282786, 0.016784402578196023, 0.031844469558564015, 0.01993328693060903, 0.035807367457891814, 0.02855404651199933, 0.06103944222559221, 0.04317325736337807, 0.04060562678205315, 0.04671284536016174, 0.017688002626528032, 0.013373096662689932, 0.03220337959646713, 0.054991061115288176, 0.05006461804441642, 0.05493366341397632, 0.06250956997973844, 0.03367893987160642, 0.010435515669087181, 0.057447581057203934, 0.07762122550047934, 0.06139087512565311, 0.020220271726429928, 0.07090185754350387, 0.02177415826736251, 0.008929261093726382, 0.04797194342245348, 0.029574494001280982, 0.036650398978963494, 0.028465111245168373, 0.10256428198772483, 0.011571391241886886, 0.024714115061215125, 0.024267843109555542, 0.03589755324355792, 0.04837489250348881, 0.01754938613885315, 0.05290900662657805, 0.11171498510520905, 0.05681787617504597, 0.032470849619130604, 0.021982245343679097, 0.04460717573238071, 0.08325766641064547, 0.05591886074398644, 0.042084660308319144, 0.05428744574601296, 0.05005580504075624, 0.07808263355400413, 0.03677414468256757, 0.015063612590893172, 0.024913392844609916, 0.08677244812133722, 0.014436804867727915, 0.0700774353754241, 0.032334472562070005, 0.03485059438389726, 0.052460337537922896, 0.12130881717894226, 0.050826555088860914, 0.04004296752100345, 0.020005015503556933, 0.01145133122918196, 0.07539647456724197, 0.06741405290085822, 0.03450304291618522, 0.021566522045759484, 0.08247065590694547, 0.022612070824834518, 0.015000265648268396, 0.028878329794679303, 0.038055525728850625, 0.05944695287325885, 0.010126118941116147, 0.023426351544912905, 0.058105728749069385, 0.08057956714765169, 0.04698582211858593, 0.02884193858335493, 0.06685540865873918, 0.05547156462853309, 0.008122146737150615, 0.058904257384710945, 0.02143316924048122, 0.08869760145898908, 0.059601052416837774, 0.04025475420348812, 0.05581632562098093, 0.02132788074959535, 0.03161831489705946, 0.016286920581478626, 0.006235000173546723, 0.069377026084112, 0.02836500665580388, 0.032321562903234735, 0.032033349853008986, 0.11241019194130786, 0.12942512228619307, 0.016243876016233116, 0.014839636132819578, 0.051009639209951274, 0.02244531951873796, 0.011831596566480584, 0.026848240486287978, 0.04937581223202869, 0.06595038183149882, 0.02442467746732291, 0.027379621933505405, 0.030649055188405327, 0.10685401430237107, 0.016414113561040722, 0.029636819563165773, 0.036620483006117865, 0.03268123364250641, 0.014532387922372436, 0.03538982033205684, 0.04406264713907149, 0.03265320272475947, 0.02691940317163244, 0.026772018209157977, 0.09646934224292636, 0.07156967170885764, 0.031934818616718985, 0.033283586672041565, 0.039637424633838236, 0.033589540762477554, 0.053729165156255476, 0.04068043897859752, 0.02309508650796488, 0.05717772502976004, 0.012514332538557937, 0.030444805015577003, 0.04009640215372201, 0.038218330664676614, 0.01849567637691507, 0.026051513414131477, 0.005582358289757394, 0.05069492406619247, 0.025432081711187493, 0.043576763055170886, 0.042850356330745853, 0.0518721595290117, 0.034654767587198876, 0.03694794824696146, 0.06085096269089263, 0.04303131419874262, 0.03825633233645931, 0.015169455837167334, 0.08076373851508833, 0.024597416049800813, 0.04722121651866473, 0.07378703827271238, 0.04055558005347848, 0.028163877213955857, 0.029827596044924576, 0.026761323861137498, 0.07448762567946687, 0.087118021765491, 0.022784121065342333, 0.03024607456609374, 0.06424472609069198, 0.04925679029838648, 0.05371615901822224, 0.019565619550121482, 0.04298083331377711, 0.08977821300504729, 0.05942184230661951, 0.01120031090977136, 0.04181054806394968, 0.017952502203115728, 0.04389090674521867, 0.045184904302004725, 0.08050073622143827, 0.012881511956948088, 0.018720812440733425, 0.04649982300179545, 0.06341826301650144, 0.021333882868930232, 0.05645498080411926, 0.06211295141838491, 0.03095486456004437, 0.04858366977714468, 0.04144718885072507, 0.08121595135889947, 0.009408667156094452, 0.035986562725156546, 0.0321809222077718, 0.06151879540993832, 0.012740997426590184, 0.050781618047039956, 0.01078158376913052, 0.05168746123672463, 0.05648818078043405, 0.03150053606077563, 0.025197234645020217, 0.042460205586394295, 0.02283641093526967, 0.008932941218517954, 0.03506561311951373, 0.036482588257058524, 0.0374285111320205, 0.03532711256411858, 0.05710578123398591, 0.0276493443743675, 0.10747508800704964, 0.07402601724606939, 0.30058212869334966, 0.12590847036335617, 0.12231948872795328, 0.07030239517916925, 0.14950833603506908, 0.1655942088109441, 0.07899190546595491, 0.11791646014899015, 0.20328576676547527, 0.11307459964882582, 0.11691234176396392, 0.11888554916367866, 0.18293898669071496, 0.1671969360904768, 0.11073844492784701, 0.1675225459621288, 0.1961548556573689, 0.10572997969575226, 0.15729296050267294, 0.10737031159806065, 0.09400652517797425, 0.25674284202978015, 0.18671740894205868, 0.09148616198217496, 0.13920066179707646, 0.16296981135383248, 0.18301140546100214, 0.16205377847654745, 0.2290222904412076, 0.09125263779424131, 0.16845735517563298, 0.10959613864542916, 0.098122854687972, 0.20652374223573133, 0.16097166779218242, 0.11225145397474989, 0.1230988625320606, 0.18100560293532908, 0.05734539474360645, 0.10434318770421669, 0.20613228902220726, 0.0900703074876219, 0.13780822948319837, 0.09458128886763006, 0.16020358947571367, 0.18194134725490585, 0.13235883205197752, 0.09680970601039007, 0.2007036717259325, 0.14760511316126212, 0.1058761531021446, 0.095888812065823, 0.16550665022805333, 0.06877354127936997, 0.21456713875522837, 0.16531845642020926, 0.11533587166923098, 0.11343924648826942, 0.20653613610193133, 0.12692357995547354, 0.08377296922844835, 0.12293740088352934, 0.1462537216139026, 0.10554038322879933, 0.12385724097839557, 0.19739695853786543, 0.19615694851381704, 0.2019659907091409, 0.27521664917003363, 0.1321597583591938, 0.18209718342404813, 0.07355864974670112, 0.23030626529362053, 0.11151212645927444, 0.10119767641299404, 0.19509799283696339, 0.07094239364960231, 0.17224811192136258, 0.1225212193094194, 0.18124513851944357, 0.1129613553348463, 0.11327710948535241, 0.1800726936198771, 0.10348078241804615, 0.143365238327533, 0.10683714528568089, 0.15114037814782932, 0.21990257198922336, 0.12056125182425603, 0.0879419244301971, 0.23560107336379588, 0.10921468958258629, 0.12852284882683307, 0.2985716506373137, 0.1220336060214322, 0.0989492138614878, 0.16222490288782865, 0.1069084730988834, 0.09552737872581929, 0.1865543590974994, 0.09427899727597833, 0.11832574717118405, 0.11484194270451553, 0.17171642248285934, 0.0970739773765672, 0.09700034890556708, 0.09909002896165475, 0.11350445900461636, 0.10146362503292039, 0.16511132300365716, 0.12299040507059544, 0.09550136644975282, 0.18957289634272456, 0.11560043989447877, 0.2544596395455301, 0.1971277518896386, 0.17398117517586797, 0.13456741900881752, 0.14533834182657301, 0.13187898905016482, 0.1457218689029105, 0.1515738369198516, 0.11410686769522727, 0.11723730596713722, 0.11799143932876177, 0.12009780286462046, 0.18245538842165843, 0.13203598296968266, 0.1652986856061034, 0.11964256947976537, 0.21286601753672585, 0.16554979869397357, 0.11760745954234153, 0.12172436792752706, 0.12661196698900312, 0.23644859116757289, 0.18056546483421698, 0.10519127696170472, 0.1557234369101934, 0.1622762595070526, 0.13486268988344818, 0.1002003338362556, 0.20365780539577827, 0.11898996934178285, 0.18134436366381124, 0.09740344641613774, 0.10438570534461178, 0.11906499305041507, 0.16641429683659226, 0.14350995712447912, 0.13863995438441634, 0.10584737261524424, 0.15286489186109975, 0.19874348159646615, 0.13980442861793563, 0.11736731539713219, 0.11872953487909399, 0.1973954593995586, 0.10250421255477704, 0.1605128127266653, 0.14186313143000007, 0.1285525198909454, 0.18564944359241053, 0.12615507119335234, 0.09837848003371619, 0.17358075681841, 0.18283771321875975, 0.1556496971170418, 0.05083179465145804, 0.15661003621062264, 0.13664751051692292, 0.11516580852912739, 0.17196011409396306, 0.062336746050277725], [0.03292666558991186, 0.054810559668112546, 0.005121557405800559, 0.018817436357494444, 0.019492508727125823, 0.03695851642987691, 0.017159652852569707, 0.06314622878562659, 0.037927249213680625, 0.03273468311817851, 0.05422244103101548, 0.02520454851037357, 0.014358800508489367, 0.04003692643891554, 0.01519706836916157, 0.060233655385673046, 0.010683357741072541, 0.08060128981014714, 0.050351758691249415, 0.032299992381013, 0.07257304052473046, 0.04418768789037131, 0.04714949907793198, 0.020901676471112296, 0.03459578911133576, 0.056492982475901954, 0.07118173627532087, 0.025513847831462044, 0.030209312280931044, 0.0810264291067142, 0.015500031604460673, 0.011855579068651423, 0.03534905787091702, 0.05269464469165541, 0.06517541638459079, 0.028649974665313493, 0.043646981357596815, 0.08100426857708953, 0.05795710254460573, 0.0063995199343480635, 0.03825591673376039, 0.04040405205159914, 0.002213489769928856, 0.027004867042705882, 0.05414812607341446, 0.0374639227084117, 0.01976028117496753, 0.023104958927433472, 0.04655529854062479, 0.03563241356459912, 0.06131428177468479, 0.037142283326829784, 0.035726807327591814, 0.07180229047662579, 0.04314696307119448, 0.028308699911576696, 0.04189432911516633, 0.03719359541719314, 0.006288235817919485, 0.020488250120251905, 0.005203991458984092, 0.07539670463302173, 0.04132930982450489, 0.017413565692550037, 0.052193342489772476, 0.030957120688981377, 0.047151228282018565, 0.022850971872685477, 0.015657076546631288, 0.03934280313842464, 0.10007151926402003, 0.02343299005588051, 0.061521162861026824, 0.023143910548242275, 0.02652225026395172, 0.06187823979416862, 0.09093639382626861, 0.018459040256857406, 0.013321980313776294, 0.010517236332816537, 0.0545327255531447, 0.02233859497209778, 0.013715983732254244, 0.025710027148306835, 0.04770447711052839, 0.03257901764300186, 0.03492759962682612, 0.026034896727651358, 0.045467183881555684, 0.037263435224303976, 0.08233224536525086, 0.06067599024390802, 0.0722146722546313, 0.04530444202828221, 0.003839135033558705, 0.028714537802443374, 0.060173418969498016, 0.04604655259754509, 0.0625572084391024, 0.03389015138964169, 0.01773746120306896, 0.06483426594058983, 0.055969367604120634, 0.024508929782314226, 0.06183894307469018, 0.012301377901167143, 0.11994241198408417, 0.09039268901688047, 0.07028022722806782, 0.012982960761291906, 0.09096394234802574, 0.06200578900461551, 0.013171626760595245, 0.04242988143232651, 0.023535679174528923, 0.04783621945534833, 0.028196234852657653, 0.032315284333890304, 0.0813177740201354, 0.05425721807114314, 0.03601615215302445, 0.021719035248679575, 0.06721369529259391, 0.06447525200201198, 0.05992071768559981, 0.058649437269195914, 0.07630244392203167, 0.0197799851957825, 0.06651169780525379, 0.005867926047358196, 0.029200523931649514, 0.004950513239236898, 0.04494009575864766, 0.06103021732997149, 0.040697931399336085, 0.048493283611605875, 0.0036812537837249693, 0.03716106708452571, 0.006360013558150968, 0.019939780722779687, 0.059631691983668134, 0.041510163791826926, 0.029169808294682298, 0.029677789825655054, 0.026883594546234235, 0.03739764149941038, 0.05843591767188627, 0.03286387989646755, 0.038998339005047455, 0.02863882575184107, 0.04569633681967389, 0.0273416889103828, 0.012565813467517728, 0.043975578373647295, 0.03996527950221207, 0.05517423058336135, 0.0955590239027515, 0.07158880427596159, 0.024698144043213688, 0.0536997686867835, 0.021796511755383108, 0.030212479396141134, 0.06266358788707294, 0.06753274457878433, 0.017863652283267584, 0.026413544183014892, 0.027997417200822383, 0.032248624629573897, 0.04776211229909677, 0.041491836454952136, 0.005870867735211505, 0.0545351820619544, 0.05389796293457039, 0.02410926841548644, 0.018220638303318992, 0.04834859450056683, 0.014872436277073575, 0.02669230969331693, 0.07177589228376746, 0.021985269595461432, 0.021039897765149362, 0.07133616236387752, 0.02769143713521771, 0.09942269665771164, 0.03688185628561769, 0.018185159933636896, 0.0283398163082893, 0.00883974880707683, 0.006092831117712194, 0.14110260817687958, 0.06964507498196326, 0.022812066636106465, 0.02892663804232143, 0.031712244817754254, 0.036623822670662776, 0.01828824053518474, 0.016193038900382817, 0.05372163235733751, 0.03139302112685982, 0.018723482317000162, 0.033607697405386716, 0.015111826214706525, 0.033467416651546955, 0.018923626557807438, 0.03823383041890338, 0.025213183398591354, 0.03575017755792942, 0.05005065082514193, 0.07922980832518078, 0.03793276337091811, 0.026420275462442078, 0.045729303019470535, 0.028011052309011575, 0.04196194247924723, 0.04915020675980486, 0.022095164968050085, 0.027164105958945584, 0.003950942364099319, 0.017867841706902254, 0.025305107665190008, 0.02434830676065758, 0.044085126792197116, 0.014570558432751568, 0.023977475975698326, 0.0240202403801959, 0.05372186242311727, 0.10537447611568496, 0.008143908362399088, 0.012747561722790124, 0.07868809247156605, 0.058099498419323936, 0.11452846694737673, 0.022240015496208798, 0.07174103360739537, 0.011517067887325538, 0.02237336644611787, 0.04550134122837335, 0.035991093536722474, 0.09768047530087642, 0.03884883706632536, 0.03544780061929487, 0.02415981980448123, 0.027750346962420736, 0.013894825551687973, 0.06928301823791116, 0.024767468057689257, 0.012456053536880063, 0.031065257171576377, 0.02719361746130744, 0.08519481285475194, 0.04069564558449201, 0.0864122319035232, 0.07300669225514866, 0.05232399758824613, 0.05271093483315781, 0.02957622320536757, 0.031179382785921916, 0.03916833164112177, 0.027820578252431005, 0.028936033631907776, 0.03633183579950128, 0.02521861591958441, 0.048163655010284856, 0.004599789554049494, 0.026828169102373067, 0.05077339505078271, 0.06054241108358838, 0.07031116736470722, 0.05723762747948058, 0.015541987067990704, 0.05892182030947879, 0.01985201619390864, 0.019401052013563458, 0.05029096937505528, 0.06997412841883488, 0.04607252405548934, 0.05622580189083237, 0.03130978926492389, 0.032333166382159106, 0.013141397230356233, 0.07041183969704434, 0.06727418774971738, 0.07377969101071358, 0.016095216415124014, 0.06962171959457919, 0.03095477364695398, 0.011308094872219954, 0.017344571933790576, 0.019744623714359477, 0.02388000601058593, 0.008367589816771215, 0.05588685191469267, 0.058769405441125855, 0.042499624760239385, 0.007966330049384851, 0.0454745719616767, 0.013739033911406295, 0.006280094457906671, 0.0376145081827417, 0.11107993675977923, 0.037972026693751104, 0.05366647594200913, 0.061443059239536524, 0.017114803013100754, 0.03172946635459084, 0.03332735112053342, 0.048036788575700484, 0.04171211701759603, 0.03646911085525062, 0.023087989720806945, 0.09084430072107352, 0.008492606448271545, 0.014571658666682197, 0.009482179666520096, 0.028270299335417803, 0.0134230775256583, 0.03934905573260039, 0.030976982416177634, 0.019304999550513458, 0.04824982206628192, 0.019917603494832292, 0.025034724712895695, 0.015298489342967514, 0.005492451737154624, 0.036379882440087385, 0.029582748538814485, 0.025474530702922493, 0.057024334237212315, 0.01833576210628962, 0.05266352272883523, 0.07255812335642986, 0.043645549012580886, 0.03815350035438314, 0.04226090924930759, 0.03166128524753731, 0.03377515931788366, 0.035947017386206426, 0.03288999607320875, 0.013607120872620726, 0.034598935817484744, 0.003216950890418957, 0.021415893897938076, 0.030240701416914817, 0.0029139183106963173, 0.05861451179953292, 0.03363906798767857, 0.028973962944291998, 0.04570495686493814, 0.01229431172760087, 0.07300514858798124, 0.04818446483113803, 0.014885152977512917, 0.13869545218767598, 0.10942316628643312, 0.21822704002261162, 0.0470929474249715, 0.0984796421835199, 0.2011785571812652, 0.12602510629221797, 0.1479281106730923, 0.19187080819392577, 0.08429626497672871, 0.09675916575361043, 0.11335093833622523, 0.10131018600077368, 0.13729726080782712, 0.14750765432836488, 0.10349726551794447, 0.09441640591830947, 0.11662982840789482, 0.13985280180349946, 0.12821890966733918, 0.1472040417138487, 0.08067221686360426, 0.10616527899401262, 0.10858166730031371, 0.11604766550590284, 0.20024276833282784, 0.0738633236323949, 0.1299836626276374, 0.10375079800724052, 0.13974967296235263, 0.08949964045314118, 0.10341219312977046, 0.13083872065180913, 0.10763516926090233, 0.1741647973540239, 0.1145641939365305, 0.10769116430310532, 0.21773382351966575, 0.29762526392005384, 0.11609452471020631, 0.16587825841270387, 0.10523903416469693, 0.09225706788129173, 0.13567872578278184, 0.18920971895568073, 0.13200834539020434, 0.09246117333532311, 0.17497612803708762, 0.137435344804544, 0.12193534566904418, 0.1674734306288883, 0.09157321590464562, 0.16364966315450147, 0.18258615484228358, 0.1075001280696597, 0.13386859791353345, 0.10705964858061634, 0.1283183426130563, 0.053340903177740984, 0.20216107164742425, 0.14395809557754546, 0.11560330458451062, 0.19444956356892362, 0.17680497287074104, 0.1367246641893871, 0.13198688247939572, 0.12460466532502323, 0.10153722381801344, 0.0888978254806716, 0.1316430009319447, 0.18337718036491424, 0.06770544976461679, 0.18202359206043184, 0.15628148743417114, 0.11546842666575685, 0.16229169617872685, 0.16655773913953453, 0.07905118080088869, 0.13025082094827667, 0.0757139950292185, 0.19627959583885968, 0.0814441023976542, 0.09763811351149343, 0.22643755335593596, 0.2017612470081076, 0.16575066838413477, 0.2244213013909757, 0.1003800671605859, 0.1277263165684417, 0.19351549650309607, 0.2127923519583419, 0.29979500686749816, 0.15415011352160946, 0.23258399072801694, 0.13231224002083763, 0.09694822045275941, 0.1315941973007284, 0.16420229600043967, 0.24609139014501125, 0.11214022088097408, 0.13257978425826877, 0.1278073590947315, 0.21004319947678596, 0.09716139495139942, 0.13451739825541154, 0.1694952041725628, 0.2124419395113364, 0.1534184004412964, 0.1459437413723208, 0.07840036181733012, 0.20670090772910044, 0.12972523196367547, 0.1493571457103826, 0.13303285057190806, 0.10616149404086173, 0.09964751545339823, 0.15295512217562646, 0.2045776677550748, 0.11812845463282429, 0.13833763310685754, 0.09570577618433163, 0.08571543687139638, 0.17119053663918748, 0.1833690464263782, 0.14177428151015192, 0.16786788211902604, 0.1686300232540816, 0.10043477086583152, 0.26574464805889875, 0.08146514228428714, 0.10748947082902305, 0.10842007948667742, 0.10257669069687836, 0.1314089572406374, 0.24062887154286727, 0.1101474578899797, 0.15160747105255723, 0.169934036093764, 0.13291878247400746, 0.09674378845375031, 0.17345842119539157, 0.15234532911563292, 0.18304539582459256, 0.08160246929037385, 0.1380923087708652, 0.18663333845324814, 0.12908285862067714, 0.12420707455021329, 0.12736570701235905, 0.15847345028305426, 0.22262426500674337, 0.16502538230270147, 0.1264586392790079, 0.10446389802382328, 0.13467880053212866, 0.10492389599676244, 0.20371738501125947, 0.18312853120733052, 0.138263477711007, 0.20914499298669398, 0.0852348591433838, 0.14330206671729684, 0.1134054342401214, 0.148244577285368, 0.09131172759225592, 0.09301419209805317, 0.13376333168707788, 0.13902756327297539, 0.10885968324146233, 0.09492872530245222, 0.19059591722907498, 0.12225894432049245, 0.0884230513474904, 0.22036889306036755, 0.12719611142529175, 0.1379389365320094], [0.01192405796246021, 0.08234385255491361, 0.02402932983386563, 0.04641106956114527, 0.008501478823745856, 0.04234251580783166, 0.02616595444123959, 0.09844654981861822, 0.020456745951378252, 0.03693639300763607, 0.009980666345654754, 0.01404021506459685, 0.06360420811688527, 0.018439473533362616, 0.061390489208861254, 0.08247918318375014, 0.03301599048427306, 0.04775264249474276, 0.03226241002266761, 0.056080040376400575, 0.013189321416575694, 0.017358583681925666, 0.03402994232601486, 0.021397740965767298, 0.023732949448458385, 0.07132042883313261, 0.01940889280376723, 0.032036734046414495, 0.04316546481277328, 0.05288893524266314, 0.05114108840643894, 0.014655287577625131, 0.01504332227341365, 0.017038603000401054, 0.09503926819888875, 0.011642793269857066, 0.024321368655364495, 0.07454573584254831, 0.07560184167232364, 0.04377892779302783, 0.023104984902602155, 0.09299856988945976, 0.08007561176782474, 0.039841058824094944, 0.07398125089821406, 0.012067734969605226, 0.008772814508120064, 0.030627890992036555, 0.06276448286371306, 0.029951013348181732, 0.031357976913568564, 0.04564926610328257, 0.004941231754855835, 0.04078017620486207, 0.08364529756363481, 0.013929041342635173, 0.03774069184146356, 0.0774964778975118, 0.049901115489774384, 0.010985979588440387, 0.0589932817092631, 0.028046534389432054, 0.09677966387243941, 0.05160044813237619, 0.041095577835221775, 0.05657719768350944, 0.05666842247592285, 0.006119749741628766, 0.03991387835412752, 0.08205104561056942, 0.04838431777898222, 0.08219586088671349, 0.02183697735745227, 0.0038484462038468337, 0.05596600938588381, 0.024219410552177578, 0.022108106168161612, 0.053376823125290684, 0.07179765205364674, 0.023646318550163414, 0.043810613788082264, 0.046723250270588323, 0.047004865627968684, 0.014095157184783602, 0.07813681033439934, 0.04095412448805291, 0.06212203159520868, 0.06657126257778145, 0.00932715800445294, 0.02895845020248089, 0.09347170387627557, 0.023474297995562665, 0.009228818798874272, 0.031443932457477786, 0.0760708493180573, 0.013435630025924183, 0.06263823612243868, 0.04078062149346806, 0.022339962379192002, 0.024836127849994227, 0.007674525004404131, 0.04617206461261958, 0.06414693329134025, 0.008337160834344104, 0.009336761395388748, 0.02113948099577101, 0.04439866934262682, 0.04498419046285562, 0.03882591212459374, 0.021744179211964365, 0.046920624445192516, 0.0631459393480327, 0.030893208786437754, 0.05399939225753769, 0.048634870545356534, 0.015212762937153457, 0.020492691874096636, 0.03267404594225809, 0.022063332398829516, 0.073486483306624, 0.022711227320542093, 0.02032711316132918, 0.044663148510153405, 0.01670133955485653, 0.014243761124816956, 0.010207338655163767, 0.013159010250092251, 0.09720542657305487, 0.027052908117184415, 0.028099757510062773, 0.027213364155613817, 0.013124123743182281, 0.01954942588781705, 0.04378518038720358, 0.019733686312974896, 0.04993851231120061, 0.015211352856567828, 0.031279082904802635, 0.0386979547329247, 0.018759430095087737, 0.051241552937426604, 0.04643605767341796, 0.018951212186948396, 0.01608775226486614, 0.023139379736676347, 0.02342601201235084, 0.04588725802022964, 0.031305659213103354, 0.022312879555101972, 0.03973607832449488, 0.008463239664706634, 0.03328691149363294, 0.02780093731416855, 0.014918094129825477, 0.05164792702998966, 0.019079455305472948, 0.02170919437048724, 0.058049911822308786, 0.02677981447050115, 0.005320433965607663, 0.0023508907588620787, 0.021817542365170084, 0.030718930247530807, 0.06412201939383522, 0.05445554219477344, 0.0676043247221969, 0.03692890844831709, 0.08486209320835769, 0.04690606721851509, 0.005771541937065194, 0.024698622728465125, 0.05526671331608668, 0.041634859444457106, 0.03239590012526605, 0.016646212825435214, 0.04448527797649149, 0.006932085107109742, 0.02324624529137509, 0.03316666501632426, 0.04810098063899204, 0.018449193812557496, 0.008953830820246367, 0.011113217096863082, 0.07930327352369204, 0.041347585211042315, 0.030618684650107753, 0.013514742968254723, 0.0512925236398587, 0.05634331355395261, 0.05400115485826973, 0.024731818994041532, 0.012656197777687339, 0.048228537270915695, 0.04566943025565706, 0.07649012564797886, 0.02402103262284072, 0.006415176467271522, 0.035183866930310614, 0.03302241377241444, 0.032145558870979585, 0.0462381231773179, 0.07290186389582232, 0.05630310399283189, 0.009902168458211236, 0.006357957345244358, 0.04144949321926106, 0.07503884102334268, 0.04562893125694245, 0.06224532458873, 0.02527154403651366, 0.046463992111966945, 0.06288767195655964, 0.0009303616036504536, 0.069556737144012, 0.03332636406412348, 0.01803829818527447, 0.03955686079279985, 0.058284419355914, 0.05473157289088704, 0.044963124601054005, 0.055799126348574646, 0.0048813446119311266, 0.033125037953141145, 0.09234299373929389, 0.08143228740664199, 0.01723069122817833, 0.02809273308230331, 0.0745846911740955, 0.062240452389232814, 0.038548797892872244, 0.028991793042223435, 0.08176204588380642, 0.042393197072669864, 0.02582887467724504, 0.028228933879290707, 0.0321928299672436, 0.04769269551616162, 0.0028364262652758043, 0.04503515374381095, 0.1224071066826582, 0.009821645435295068, 0.04129785389523022, 0.013307976914802566, 0.03127773590676952, 0.04939970938721672, 0.04840872701606713, 0.050802791520254686, 0.11308385423035361, 0.08862755756126717, 0.018488735440769233, 0.019900381957995705, 0.031704556167824194, 0.04496090186876245, 0.021584997812169604, 0.026039954464067705, 0.032268269278574735, 0.025995484975283034, 0.047263897431548685, 0.01975939801923232, 0.07919282710645348, 0.03731678079930134, 0.050116757629439235, 0.012020282047160435, 0.01913501062517753, 0.007716880299994955, 0.04946362314512953, 0.040552351711085066, 0.03239394827687647, 0.045840042585041374, 0.049428285783506, 0.05757232866017148, 0.02205321692599682, 0.07890950480941683, 0.010793287437991239, 0.05331752552592661, 0.03938050052965991, 0.014173003837640863, 0.02526869604480453, 0.050168158777523786, 0.033278788687312044, 0.013723895026487298, 0.01587865401234012, 0.05489791787113063, 0.0819572752516251, 0.008114507254504133, 0.03359997906954959, 0.03493425298074726, 0.05015957955038175, 0.015245491649693577, 0.03921429655747488, 0.018132519398932345, 0.02295312107889913, 0.042566848496790044, 0.011292033868812723, 0.05430949495348614, 0.05603172285191249, 0.01799550595023902, 0.08556134474929422, 0.012279725742700975, 0.043543952706386335, 0.03820500169240404, 0.037594429377350025, 0.03774325225094799, 0.0010317378746549366, 0.08274728403193876, 0.04563293885439634, 0.015578178827126976, 0.03808632114669308, 0.053826304865651764, 0.03021647957211826, 0.06184098769153934, 0.03797063145611901, 0.004291625255063991, 0.018210494999948423, 0.04699098375567701, 0.024125497329805512, 0.025058258215722162, 0.04506167068029754, 0.04686606174800545, 0.037980772904120386, 0.0321264337253524, 0.013273929962451803, 0.06567283344338648, 0.017428492137696594, 0.017910956776177045, 0.07686835378990509, 0.01888685870653717, 0.037458145088749006, 0.050251208813278936, 0.03619557377533056, 0.015941083474899642, 0.04720413598988671, 0.03988667864177842, 0.02574432179244468, 0.019838013722619507, 0.043427494892966934, 0.017461155912315007, 0.04041707674332429, 0.031407782444148324, 0.015916750307951588, 0.08304323768243194, 0.030254266021074727, 0.009455825074837776, 0.028056737064616755, 0.0212408249717555, 0.03505418775603175, 0.023745551116007846, 0.02921779185271589, 0.04326558795582969, 0.014105588070378872, 0.026718030676420312, 0.046793401779723354, 0.09318605865701102, 0.16657274536555633, 0.12633768405066803, 0.10649327115970664, 0.10586666103336029, 0.1307360370992683, 0.16271074244286865, 0.1654854544904083, 0.10938412189716473, 0.10931625991361216, 0.0564868412038777, 0.19467308360617608, 0.13989927509101108, 0.13765990384854376, 0.13356991315959021, 0.15705072350101545, 0.08985490654595196, 0.10678530627046712, 0.15418144699651748, 0.08855461928760633, 0.12547725287731737, 0.18669079552637413, 0.12582488969201222, 0.12042282643960789, 0.13560742023400962, 0.16365736664738506, 0.06754393616574816, 0.17971811030292884, 0.11291216578683816, 0.11941317905439064, 0.17716841743094847, 0.16250632528681308, 0.14583044510800391, 0.14075503073399886, 0.3213148849317804, 0.10675906392862089, 0.169594444159884, 0.18233628856251016, 0.17260558961424977, 0.10759351993328892, 0.11354731061146595, 0.24544123909436166, 0.16051631566369906, 0.2302788948873058, 0.2510307094780728, 0.13482978305546567, 0.08234021603129804, 0.22478389990283176, 0.2601901476737112, 0.12427305147866718, 0.09634944828576408, 0.19209510006476194, 0.19128382875351235, 0.12179589612060227, 0.22085307020461187, 0.197584469569847, 0.11426247379858978, 0.14409571944270283, 0.13341367623070255, 0.13643231737660244, 0.12960587977431715, 0.0802345723786857, 0.1274964289041236, 0.1559826245647855, 0.12279575457796454, 0.34818021522369236, 0.12989178474526852, 0.1362775795860216, 0.18800093850586563, 0.1626942222355865, 0.14606260374421254, 0.26796268997713923, 0.22177597536938265, 0.10043500835308805, 0.13846685586031526, 0.05802179926831741, 0.11929896994843148, 0.09381565963849425, 0.14207051717676222, 0.11971299929427914, 0.09831038056290708, 0.10430913796881214, 0.13563590386183932, 0.1308083816547878, 0.126881871256046, 0.09817837475566193, 0.10636538427206688, 0.15023256826680154, 0.1521318726008758, 0.150998716999311, 0.15469107980607077, 0.12367700299364515, 0.0981091769062914, 0.08706165564944968, 0.14307425706647336, 0.11445313153672032, 0.15256819606292993, 0.20365703356219456, 0.10511768559808843, 0.13532129261875525, 0.08645451205666177, 0.10496693314053118, 0.19575075624743477, 0.1653851754963398, 0.06958448604564182, 0.06843561175628565, 0.11424863274442032, 0.22202584164915606, 0.1821804078645073, 0.13533503719372675, 0.1696516340598464, 0.07935870453366078, 0.13965981372166425, 0.1779229738167487, 0.14637136686360464, 0.10606554918922484, 0.1611892951768823, 0.13227416784502566, 0.09277369172195904, 0.16459511476568878, 0.08224594101193361, 0.1658194061019458, 0.10199984899372794, 0.12478009419282898, 0.08090403411188163, 0.12974857992958277, 0.15525635884841904, 0.23393833602312952, 0.11903722930583172, 0.18455311335856095, 0.1243083702865988, 0.28027456370182335, 0.14122020889772102, 0.11301037418888882, 0.12881007482064888, 0.2536764956312254, 0.09296932927099988, 0.11508293289807625, 0.18693386373342946, 0.13088060746667907, 0.12756120355334133, 0.07381995252217166, 0.1248217435204424, 0.13228731870185584, 0.14018599642440677, 0.16118736559292302, 0.1642548548988998, 0.11054346046876162, 0.1007270063564647, 0.23560790112242103, 0.05220780694799032, 0.17137786955572665, 0.13966138707473874, 0.0800571619765833, 0.1328309121890925, 0.11475056206109002, 0.13017789751756936, 0.12355740589555353, 0.1269392392714508, 0.088431771582691, 0.10814741443027742, 0.11960196658037603, 0.11836467281682417, 0.17346269596600905, 0.11526928617968224, 0.15307429624954239, 0.20216499018715695, 0.12863090552855283, 0.09452596175833605, 0.10861595452297479, 0.14050421450519934, 0.203206995211076, 0.18375957937678322, 0.1687434531049803, 0.1373425021301955, 0.13017144083278254], [0.03357521360157989, 0.07053355933749117, 0.023556533524242695, 0.016708835246390663, 0.03920099727110937, 0.04835943727812264, 0.009424079707969213, 0.037748113318230025, 0.047236252430593595, 0.04954709620506037, 0.011146449542138726, 0.018850972155632917, 0.05808606554637663, 0.03488046582788229, 0.01597732069058111, 0.013432655869110022, 0.05563812483160291, 0.059758777351817116, 0.057957896642619744, 0.028531032512546517, 0.05016874878492672, 0.003732996319740778, 0.04853588659898378, 0.05030112937674858, 0.05195788500714116, 0.03690802441269625, 0.04519221074588131, 0.06453169233282097, 0.03168322684359737, 0.032657904230291024, 0.008572257447667653, 0.04446786719199736, 0.03886414757289458, 0.036169153318041936, 0.03403112605155911, 0.022739818559784908, 0.043893481997656636, 0.0320308896334609, 0.029856712353648618, 0.03421503024583217, 0.03849315908155404, 0.040231899765785784, 0.008100063205347396, 0.03202413608960342, 0.03190319941495545, 0.05893535337236244, 0.018518553079047706, 0.08437763404799625, 0.03844677485176362, 0.009000177014968358, 0.03000479679030832, 0.044356459693517536, 0.015527991090493742, 0.04817315821128432, 0.009393194304720964, 0.0044797133068641415, 0.03778399986913428, 0.048318370536435395, 0.05899699615838472, 0.040527608507545665, 0.09889600187307224, 0.029983393251313828, 0.04138261829211842, 0.07441775247571059, 0.07587382395286113, 0.023254908010130748, 0.026144075927732047, 0.11956527479924262, 0.02461722953739809, 0.011105264984507812, 0.062101667062961496, 0.031023704323160928, 0.01895062032417627, 0.03774490724026691, 0.01396472751366673, 0.04127433894609567, 0.06080862687667832, 0.028199071712151635, 0.03317596041597426, 0.05155989347258583, 0.07766037379042245, 0.016500401216035243, 0.02648002020578133, 0.04034190089441836, 0.02415558585198596, 0.07476737082470208, 0.05132132639118936, 0.06791288004023954, 0.009744257058628136, 0.003714035838129348, 0.0034623508327058516, 0.06071675270504784, 0.017496706641395576, 0.01781158134690486, 0.035851102220476605, 0.03995761682745069, 0.00816708006823319, 0.05114152627356816, 0.034971831628354266, 0.0676258618477732, 0.04408720851643011, 0.047857526515144855, 0.034347503606113605, 0.02482841879100306, 0.05007894891605247, 0.022264010985963978, 0.033943730741157196, 0.026507433285587467, 0.019873100609402172, 0.06775115121854469, 0.022468376191682182, 0.05271294234262314, 0.020230376067047473, 0.043194516183575615, 0.036214253632351756, 0.03788811205595266, 0.02263156889966922, 0.007151348927436629, 0.02906537141825538, 0.0507304618076887, 0.02857319948816439, 0.02093827733915532, 0.020652121893363073, 0.04393838935357053, 0.04439879550773185, 0.06697703924146481, 0.03196132071025204, 0.03026384158147266, 0.038038734637666494, 0.013287866568134632, 0.023780571209499612, 0.0469725933362497, 0.026087661572091747, 0.04623604145308491, 0.03606772399507463, 0.016539039279450662, 0.02164941808587173, 0.07090847750077955, 0.07490433417842723, 0.05460532986035105, 0.018730144947767258, 0.02443356097501237, 0.08076854021055624, 0.04593648838636, 0.0030019205587450415, 0.10181990786804818, 0.008096797755570151, 0.02302467339177383, 0.03451667245826684, 0.006320828624666319, 0.03203811444109306, 0.08354460296686739, 0.04567980548017658, 0.04734416441351641, 0.029115390316292178, 0.04467427330382634, 0.016352643324353267, 0.024454350386804435, 0.09331174136605114, 0.023024068541417364, 0.03467528797045816, 0.04063218082592357, 0.04787120058608707, 0.003622858125709172, 0.03938509071303997, 0.030481515350402333, 0.04412803777086083, 0.02386249503615545, 0.007051800021145027, 0.04620750587491784, 0.05381063812819775, 0.06546728080138564, 0.030916475116100628, 0.075108840392204, 0.02269021155370865, 0.02462847678543767, 0.03994357539340854, 0.06823045245255344, 0.010864577216125326, 0.05036028967879247, 0.05748268093157094, 0.011483195339678787, 0.06045626258128323, 0.03145697199215647, 0.010756292303994996, 0.031279758259188384, 0.04177309187070932, 0.019899059079762083, 0.0996682139520999, 0.06321790540823713, 0.02859815791453002, 0.056144625777960755, 0.02199989918153733, 0.039852810732554644, 0.04147665953496471, 0.033667588722892106, 0.054288915198412724, 0.008905767481337534, 0.08231283078202978, 0.04229928941640537, 0.05139509587024804, 0.02203747040766757, 0.024960201953945216, 0.020628859274438582, 0.026028349129774142, 0.02308822349732509, 0.012025737760268385, 0.04599439445883036, 0.03347943944390863, 0.025208854822267313, 0.021290174081514124, 0.06155933522677515, 0.025529637023282703, 0.0726320561079774, 0.008432135327893775, 0.0360695237031905, 0.04079945349076297, 0.07192775796283968, 0.029096129728714004, 0.005040286205257871, 0.01594149536686018, 0.030856901066727005, 0.03253472998039797, 0.10734083349234425, 0.014479354049399262, 0.06428408218198456, 0.019769038517551962, 0.041915198307833634, 0.02895770434406586, 0.05016464841901325, 0.018342775401833933, 0.05292797592119314, 0.024119118570524734, 0.03882721830450464, 0.07674223321373574, 0.04043195309350267, 0.05402016868174542, 0.04404331790283322, 0.02723327968851663, 0.09523635293589905, 0.06088971393182874, 0.03649276310170535, 0.07178878338891082, 0.047235243109753355, 0.029940547210571822, 0.03499952486890834, 0.03142898189253174, 0.03734683778020553, 0.04942292005580384, 0.04522080569586251, 0.025159309043374378, 0.04118977863981854, 0.008350222633453086, 0.01405979755872977, 0.03550671972334385, 0.048416578938486055, 0.03322956203192007, 0.011699624155880883, 0.013286263529153075, 0.07852303882827982, 0.03457000319031067, 0.019940123966080137, 0.038695654075127095, 0.02456708261888707, 0.03467679453024175, 0.01925599925016286, 0.03432313147641253, 0.05062265001470223, 0.005667583282047417, 0.020766607449331786, 0.012739084540953627, 0.07019798242254183, 0.016714703779143747, 0.09343191733933054, 0.026860009093070403, 0.08771613342105411, 0.05277630691125523, 0.01696675011771731, 0.08327060946612619, 0.08042294430197217, 0.0240686432516668, 0.030858841782901436, 0.027054893362219445, 0.05771948541223537, 0.04068988280778285, 0.05875060312973801, 0.03373149134858977, 0.06058481740183197, 0.05173087316507008, 0.019579557083488908, 0.013196865347708808, 0.043085082797915675, 0.011468287448224146, 0.05531144255655818, 0.02183407556003658, 0.003041211944037059, 0.025096783101616893, 0.0064076149101310875, 0.01936017823027214, 0.02194667606090661, 0.03832186397630721, 0.09745466202730313, 0.019808550459856633, 0.034950268527609296, 0.029096621401549783, 0.023654170472582337, 0.020743174136441667, 0.04018452476884704, 0.024170671858882997, 0.052452381714829244, 0.028881170364911668, 0.044959176375414245, 0.0793421917478554, 0.06439097371185198, 0.004647078276320826, 0.07567770400783047, 0.02005319944146322, 0.02397471704171039, 0.0636256264988333, 0.08432310103671625, 0.03352718922542408, 0.040680338788661174, 0.061544232521555386, 0.03472429569228552, 0.025029375683516264, 0.07237387035274878, 0.02451212658343138, 0.05019178133807145, 0.04574550410325173, 0.014912485348759219, 0.027837352645292412, 0.033572270986041985, 0.023306190414587036, 0.027321049783495255, 0.02441568263748195, 0.03567260457202792, 0.010710443348216359, 0.016623523515590932, 0.01765495107974857, 0.08065369285759516, 0.011450121528469026, 0.07273850234923884, 0.01334691276497324, 0.02198256075644167, 0.021843235517735593, 0.019283252768218517, 0.020561015844577923, 0.05169700154510792, 0.05014707065129187, 0.022333678243739996, 0.039807424691389315, 0.052378983309608884, 0.2226974259247072, 0.11712644394719973, 0.13191772915888578, 0.16394475591368973, 0.10033806902356446, 0.16904748132219538, 0.23662623163545504, 0.11034051276510581, 0.15897358360234648, 0.12470237648813054, 0.14567897276720032, 0.10210302236373536, 0.13603500119643286, 0.17741936724632978, 0.09126710225245915, 0.1526168067357503, 0.10323613343643956, 0.12528312188806012, 0.11297437260509469, 0.12822647957364097, 0.2273580539622344, 0.21524271578527987, 0.13180893030948937, 0.15832508011953905, 0.1718920739949681, 0.18439951847540215, 0.11911691370187327, 0.18152215256122872, 0.1789321907563135, 0.11726279873983003, 0.09853502124315128, 0.175820202275645, 0.0921242160256952, 0.1196600025286898, 0.08417236342211254, 0.16216762393014506, 0.24864164704922587, 0.17417383671272546, 0.08496547437971458, 0.2263187206699513, 0.1503604551544413, 0.1256109433597885, 0.06486011494416744, 0.11600161524256691, 0.1362865892588161, 0.10144308238523081, 0.08954648481449112, 0.17160469957161695, 0.150887394847814, 0.18874601024435833, 0.103752816648921, 0.11923348283744417, 0.08804854878690094, 0.23406107240589336, 0.11008273519109935, 0.1602132522384636, 0.17642812512349337, 0.16645535244606435, 0.20695828454336151, 0.12860306014772505, 0.2041070570703596, 0.11244293549680151, 0.08773652763920836, 0.1933246458065696, 0.14409194933250546, 0.1382103399373591, 0.15575775381876156, 0.2703405905049294, 0.09472691308474168, 0.06342731721815653, 0.13097438524710014, 0.09968742073397152, 0.12430784336174838, 0.15259332518326119, 0.0716282865323592, 0.1561594635131769, 0.16976053680991754, 0.16411696386057884, 0.13931554625742137, 0.14094971091253683, 0.2667657542042434, 0.10711183640523814, 0.13045857776887715, 0.18253319518407807, 0.09879310309770517, 0.09816451143706217, 0.15378279495052993, 0.21298315812600777, 0.17431306361686438, 0.18433756398735568, 0.08508919781888835, 0.14338211476569995, 0.08976594530395232, 0.13624519226141274, 0.11818415281595662, 0.1625345862703398, 0.0798860375653021, 0.13734337786445394, 0.15086523431818932, 0.16413124278187752, 0.11983738324488513, 0.08258914720499888, 0.16633010760415345, 0.14756218733964488, 0.12120482744649053, 0.10808296632603742, 0.07761641638353467, 0.12048327436787076, 0.1449330846662633, 0.14947341056540608, 0.124682976747863, 0.15402754041133448, 0.09996680222684518, 0.09623104604543187, 0.16018531779991463, 0.1233416487229988, 0.12134990247432142, 0.17644704988924786, 0.08097266792901792, 0.08796126479865052, 0.10095373247168027, 0.0890737293229904, 0.09899017299176194, 0.12293435065657832, 0.10699220962123945, 0.22312821296509355, 0.1198858603311237, 0.10574120096862316, 0.21412242902442813, 0.11637064075330272, 0.09175333514576778, 0.13867441972251981, 0.13884009676985443, 0.1087728445418179, 0.09233788776327856, 0.13420110975857824, 0.15248774725478142, 0.14572342741303146, 0.23386651097098365, 0.10390936527983285, 0.16870775580173358, 0.14150324917864054, 0.12325949297519401, 0.0875518516113516, 0.09836259065195918, 0.1919448745320551, 0.1114824108663015, 0.09611396482796408, 0.1510405889712274, 0.1505962948431261, 0.1720280948211439, 0.14792395464610308, 0.14642463822383434, 0.1636389465420507, 0.08997626253403723, 0.19084562023635954, 0.11010946735041216, 0.1271269581047818, 0.189236658916343, 0.13315393938682973, 0.09146331125521101, 0.0854826919385232, 0.09055990230990574, 0.20137619110755622, 0.0969684513984248, 0.16033365827752277, 0.11987900288659148, 0.1580750208813697, 0.08822883130051196, 0.07935503832413815, 0.11274726799456403, 0.1778289140202105, 0.16590412968071178, 0.18958781351102516, 0.15192001912510023, 0.13649559288751334], [0.045052085843053646, 0.008018717326194746, 0.05697686647181399, 0.0046841768471495016, 0.019011559925274923, 0.060677181390929036, 0.04229453224979807, 0.02516546144761378, 0.023426102925441228, 0.04443729812919628, 0.003476776328170672, 0.0470322397450218, 0.07004112208960578, 0.04627610629540868, 0.04080421436810866, 0.014353047936310759, 0.08437517753918655, 0.06320008644252084, 0.1779428040026687, 0.006452033376262989, 0.05533568109967746, 0.024397921188210603, 0.04276565130567178, 0.02560896704380866, 0.024032858746068086, 0.09189646574668586, 0.05749304502387531, 0.011174541687068995, 0.028267824272916187, 0.025013642152771354, 0.03731643198989332, 0.03705330724187661, 0.011619257911661407, 0.03752190670638811, 0.022165106820466463, 0.04481447242142167, 0.01550554112327518, 0.027362825276213698, 0.018081489324686117, 0.0536055307748029, 0.04058187063492369, 0.09354691312182695, 0.038086499262135476, 0.017049610905814916, 0.008806299283605767, 0.04222614334139507, 0.01789416382962372, 0.022374676336767152, 0.034837243147194386, 0.054304203440551646, 0.02369914833252551, 0.0048828599847183796, 0.07740946108242497, 0.05318491857906338, 0.11802085064118728, 0.06069989482057281, 0.040468819279340096, 0.007130262192731607, 0.05558133198064752, 0.037182748928898945, 0.04243119874445256, 0.008683826363267144, 0.016278046350635123, 0.07299478078493848, 0.028631181630771607, 0.04821595415705815, 0.06576472616870888, 0.0613553114089882, 0.04181487107416615, 0.04409728688187897, 0.09192103825625964, 0.021218048459559213, 0.024714423052500933, 0.13227627554442734, 0.013672193308593705, 0.061186268721939996, 0.046231688756961375, 0.04674601565056946, 0.019171134663338307, 0.03371015831362456, 0.07254321360960603, 0.05958789784926921, 0.04100437530723866, 0.03600459320296068, 0.04997368640033528, 0.041291664383606985, 0.04359912025392987, 0.11916951712919399, 0.020320151816122234, 0.03946877899579704, 0.013928715725342045, 0.023303492707782425, 0.044991470931563526, 0.053008510076324455, 0.03212514609913342, 0.021035094214312267, 0.01942204180522822, 0.05257759316009469, 0.01965439154446358, 0.04748447114252485, 0.09265790926292539, 0.042868238379014656, 0.03165166330290958, 0.02681923178897705, 0.04184065699519124, 0.03593468660255894, 0.02021687640080927, 0.014121501571935369, 0.009401275365235051, 0.00861367114339373, 0.0603649301774567, 0.025203270161000546, 0.04868388197792228, 0.012362346260488266, 0.08809912615106441, 0.061866755058872513, 0.04605732858181, 0.010907163505180506, 0.04683077633671928, 0.03919579481589608, 0.014258549344958737, 0.07860910569434054, 0.0021756840715170256, 0.023288675729418173, 0.039540522411698475, 0.05147724790731445, 0.045256558660184965, 0.006278074888541596, 0.04640372600988485, 0.022865989230922423, 0.0921229766390752, 0.09024478640640154, 0.02589402411103947, 0.03409701392229181, 0.008382328869629418, 0.020540892510325648, 0.026986268821929116, 0.039627394507988356, 0.0653992110164836, 0.03449690164416097, 0.07395221808110364, 0.027542373063624837, 0.02610215757158585, 0.02915356082667131, 0.07049809210002422, 0.028570527756528463, 0.03136458202789072, 0.037001386590418406, 0.02541701054724399, 0.033890986305777915, 0.05959726375294849, 0.037669263838324696, 0.025072286662179977, 0.043507309164851904, 0.00706432376318844, 0.049652711240923963, 0.024622688033559825, 0.027407753041188698, 0.03114276893029455, 0.04461784781597089, 0.09676662433776073, 0.032571354968240485, 0.06950044524273835, 0.05597378338279668, 0.011284690317552304, 0.028680373034148943, 0.0054052568066254025, 0.0646320529631339, 0.04922273685224354, 0.032065848499769345, 0.0278676100060693, 0.034660448727663606, 0.02681928930542199, 0.0646806784789078, 0.03545231658790726, 0.0324636359437136, 0.03747457994904835, 0.023164809426816646, 0.038491329687531106, 0.03442367022216786, 0.028703787793347146, 0.02524332387110917, 0.03624084849434439, 0.06352604512358084, 0.0554568663937971, 0.007147428068492445, 0.016121494008984882, 0.0378660814021714, 0.06974937641643919, 0.02801420272589894, 0.059697208780562505, 0.02228265188023215, 0.05677199660567567, 0.0388782409572741, 0.039007163140922785, 0.02181294847105164, 0.07796477308147587, 0.03422317902732175, 0.029411093491944484, 0.02397439235210186, 0.025481621923972853, 0.02108811695507029, 0.032497177307959646, 0.031275156943593174, 0.03773212374653667, 0.02078192166663939, 0.016775042240624316, 0.07640306430403143, 0.01306802851104294, 0.01736796628392767, 0.017874428267532494, 0.052079916349612176, 0.03546376792655792, 0.10023184542660601, 0.061345552167040296, 0.028769362106686458, 0.03694699458719697, 0.034914048010250553, 0.06259566653170623, 0.033467093817307614, 0.07438135755364783, 0.1377139173564501, 0.016427299669885542, 0.04567978692648467, 0.06089830058044754, 0.03405243682209402, 0.0460361476871185, 0.01097419799407362, 0.05697842869267333, 0.05216958263190463, 0.044641195781878196, 0.07847496992326342, 0.04195692185021471, 0.045474312209989876, 0.06543415132910013, 0.028930593689437956, 0.04349363509390969, 0.06412852802895941, 0.028595089133887086, 0.056570674205431715, 0.04441959048563149, 0.07138735571061261, 0.05019768883357756, 0.032325050997314975, 0.033946172407013364, 0.023447576968465, 0.021472397311299574, 0.0264646447612904, 0.013606684860860696, 0.045489036419894546, 0.03899953015206847, 0.043532890995265916, 0.0781716764322482, 0.036659145189332776, 0.04565728871966712, 0.017724087701935787, 0.012729439404211007, 0.04498126269027125, 0.044178514945087954, 0.06410119473002851, 0.06418220757041126, 0.02151065502403071, 0.07391539271338843, 0.04762235104863066, 0.04597940307576209, 0.046209079227992333, 0.05317844705132302, 0.036001123662572354, 0.020284508318582084, 0.019530538229446393, 0.01373120054267929, 0.021797797526232898, 0.04413924049003981, 0.017921380240295548, 0.02767525646049762, 0.07773081844788976, 0.029642580484505743, 0.03925745615561027, 0.03988651165855117, 0.01643894396693213, 0.06874749931739643, 0.029611480786115862, 0.019793015453615226, 0.03491375857265666, 0.046821095020277426, 0.026936415051750373, 0.05036880953412037, 0.1254472552682273, 0.09110469065490179, 0.08361019397852942, 0.030493799749820028, 0.024387844678130932, 0.05007027320971247, 0.04431757115526125, 0.09317675212514587, 0.03538369761372451, 0.0096995806961786, 0.04614712102920748, 0.0639378183404915, 0.012435043336154195, 0.04594364268996287, 0.07852679409552366, 0.05323223791492637, 0.05907761937123723, 0.03517280150845181, 0.03323718388855923, 0.07388111291220412, 0.02436178230709629, 0.03438892657868564, 0.046096985242911614, 0.024180839282053057, 0.07565115738543682, 0.04483079224883113, 0.06397565302904695, 0.03593392961192876, 0.031697234880994074, 0.0638336430711206, 0.02253228252811823, 0.04692967493610922, 0.012982136049686233, 0.06928733753738925, 0.05541625607293099, 0.012272346939425915, 0.04037338279886171, 0.0006005727448155085, 0.04495923574722838, 0.015484029972867575, 0.03830829380603973, 0.03707882970047649, 0.041596264054533094, 0.007352443117270013, 0.029435606629704125, 0.01722938133752905, 0.023683550243731588, 0.1005386195902247, 0.034243922054884024, 0.11845621673273854, 0.029360369553614873, 0.009795974547159858, 0.06023859066772275, 0.02399904278718168, 0.04730939108412713, 0.030202321249817032, 0.06885574155603535, 0.02772167408693349, 0.02304619938513497, 0.026627750266925432, 0.004789791419170797, 0.006104476342443377, 0.050893114603240974, 0.03494970078463666, 0.018861237913370132, 0.13767960044788197, 0.08824669479508884, 0.13135887711541727, 0.147849784407299, 0.10785632184706628, 0.1553693730966188, 0.3109937481349334, 0.19858420186210424, 0.07079908493324183, 0.0880177496583201, 0.20379885798320174, 0.16068594093667343, 0.16661313304211944, 0.17210455087479204, 0.0928769021993503, 0.14438252983381972, 0.18114632897777483, 0.1409432096988894, 0.3538570215459913, 0.14098013896727934, 0.18381768953986466, 0.1411049533635378, 0.1842576643684879, 0.06465370883233845, 0.10317840919014998, 0.21634692762745544, 0.10358353276387788, 0.1295198648585938, 0.17781611939426512, 0.09802137341466732, 0.09379236362292431, 0.10365778463892639, 0.06664020809694193, 0.13177957094740123, 0.08608787626144476, 0.14011198945809156, 0.18398792337393388, 0.14786639367230237, 0.17209508107043803, 0.17872150987386703, 0.12991139228688553, 0.11519533858518116, 0.14520117809297517, 0.08364373905351385, 0.1838096446590498, 0.35809397231787443, 0.1183908706298098, 0.07967224708409049, 0.08060724925599061, 0.13563437503762543, 0.12155811200500466, 0.16806272557005286, 0.1105404992995318, 0.16268965060589835, 0.13737270754063502, 0.1803300852770917, 0.13516413542674854, 0.09635923721361905, 0.17691904096864164, 0.11964339326368645, 0.14605507836677134, 0.10059127496788278, 0.09994045598432422, 0.15552457101875916, 0.10149432768230326, 0.16430031886557117, 0.12130370378145017, 0.06836772008682601, 0.20329942228272557, 0.20910000399453565, 0.12784329388523474, 0.1241214900801424, 0.04530711747065652, 0.17123595607699826, 0.10906837516813539, 0.14331018581287935, 0.1367276773089543, 0.10039430897450075, 0.19144183199387044, 0.18498726974939927, 0.12919323082314804, 0.12815615365980193, 0.10140670230612159, 0.16025415941840038, 0.11481901776278391, 0.1320540320011787, 0.11785524780862033, 0.18500506645068526, 0.15197983622783795, 0.1554106513503939, 0.17254565376788378, 0.09570826237904839, 0.10929008436505683, 0.18285334284882993, 0.11700743314577267, 0.14582094561774284, 0.06796963207307272, 0.11123509757453576, 0.07226144982269034, 0.20250752102583647, 0.17667491891188547, 0.14059566194191575, 0.11701653187628835, 0.11207822928554378, 0.11921899611479603, 0.17220005043782294, 0.13648131396621466, 0.08348521630978212, 0.10733559392974712, 0.13008118083234876, 0.16325788339599967, 0.17940214835107327, 0.23528373101726174, 0.10738932542153634, 0.2266505645820871, 0.1252066361485049, 0.09159784778603353, 0.13142046052962542, 0.1584344875300303, 0.1177211565664038, 0.09012377180624753, 0.16710857598809525, 0.09031514942762442, 0.15057766693644226, 0.12665318587096408, 0.18450362695148215, 0.1705676966230385, 0.15218931483104825, 0.18318132759304717, 0.13892872404539958, 0.1366320886882022, 0.1544492584071122, 0.1549405453260988, 0.17994724097661674, 0.09120612739934586, 0.24215336161432788, 0.1331139079411514, 0.16281940770568326, 0.11999759808531962, 0.113905968319159, 0.14712592324940488, 0.14633378450525925, 0.17738987429765984, 0.09724238552735187, 0.17582490749191493, 0.14574233733583242, 0.15556595317320898, 0.12462235812563449, 0.21748455095803365, 0.17295073281275108, 0.09021563484566286, 0.16680481494404376, 0.0855978435720317, 0.07989185600308701, 0.08509135004715063, 0.10866775643080473, 0.11186305098817684, 0.14005805016495287, 0.1773805232369341, 0.14094384794589132, 0.23357652418781072, 0.1560867330408655, 0.20180967956548557, 0.21332861302653328, 0.047881534992484376, 0.18034316191915423, 0.08907942159567028, 0.2562453655991703, 0.17056642012903467, 0.1875015621772036, 0.09860401871264912, 0.1840903694392182, 0.08107752597425133, 0.15113971021492034, 0.10890738107264042, 0.09374215733259916], [0.030971336527727544, 0.02589879612060031, 0.057417653952143155, 0.07984621392097324, 0.05775281155365519, 0.026297776566934772, 0.02631654733704636, 0.0302289086903329, 0.023748341591272037, 0.06373932352289557, 0.018860816744563635, 0.09234908677171916, 0.01987133244256256, 0.029221832846815232, 0.020835311770497356, 0.013083480025670724, 0.029394361772574484, 0.03306646023702342, 0.0026709064604801824, 0.03967652839492075, 0.07052319895592518, 0.01943580307852244, 0.025291652527812403, 0.045323140438995324, 0.01736774549499387, 0.036274259982747026, 0.025800318690016866, 0.04138027310546022, 0.03250664711231366, 0.12666213617194444, 0.042173662368441, 0.0748535935417749, 0.03072858558880398, 0.0050552205357234925, 0.07077710251905955, 0.05295450027915649, 0.022928066173335537, 0.0585619083722122, 0.05902865617827047, 0.012499999811552698, 0.016604053271294106, 0.03542490165273193, 0.04022011074994225, 0.051143377932021394, 0.09678917820565403, 0.01255274424693198, 0.026197427068836987, 0.052059303197893314, 0.07135855295928195, 0.029730040732829366, 0.04013425168523099, 0.043231549352640286, 0.03774512617383152, 0.020858149509876966, 0.03279506796388887, 0.0858881272142753, 0.04400462974444963, 0.050246733662788756, 0.018442468099237885, 0.03877674855175428, 0.027571493083087262, 0.01395802592014661, 0.04987786029232666, 0.07514698678278364, 0.04615355173882563, 0.03761096071684733, 0.039976463667699136, 0.04145091814280022, 0.06890793680213392, 0.037914213389740326, 0.09109920618357137, 0.007476151713490253, 0.037690596873289905, 0.06241053037228994, 0.04956548291374929, 0.04898746861726977, 0.015404463392769685, 0.04067158886755351, 0.07531048191594891, 0.0196154788864078, 0.1380962718394585, 0.021745375925092958, 0.045999418798601255, 0.027554223306651693, 0.030809665222477634, 0.028403442483977415, 0.03227557572245132, 0.027238519251113757, 0.06349748728098348, 0.07407208235235885, 0.01850260618084576, 0.03599967276386451, 0.04515362648817245, 0.02111635752953589, 0.011579310885281302, 0.04224811833410058, 0.02845004008122487, 0.021497348316188436, 0.02909629671194125, 0.027352917604730465, 0.020510894901235588, 0.0418639047711622, 0.04305023525375873, 0.026551162482064683, 0.06544897201820277, 0.06277630527620204, 0.030754445724596735, 0.024679317612026352, 0.09191638499032706, 0.060134378290968016, 0.026756566694530193, 0.01222374647113611, 0.06824694297392853, 0.00841952994960593, 0.03689019431476481, 0.04849273813306354, 0.06762621807865798, 0.009395930046594003, 0.11486026633065194, 0.003249020714974904, 0.03830443834885955, 0.026339199539506808, 0.03372526101884432, 0.027639054496830795, 0.09822911539231427, 0.06440571276471019, 0.022780378785682842, 0.03763390792300925, 0.0734009211009834, 0.05023589088523295, 0.029333242200664245, 0.060567655236809514, 0.06370518472976983, 0.03544091719959397, 0.04963486630003899, 0.04579825596010778, 0.01016828406136483, 0.03228958747058641, 0.03157098442898132, 0.0394646934728371, 0.03236667806049809, 0.07724937982857227, 0.08191241242457181, 0.010494765028852271, 0.03516315729939379, 0.0035164251039532246, 0.04680947298766114, 0.040976711752591655, 0.018512686401663814, 0.06257234083022922, 0.07373036045464687, 0.050208000975544564, 0.03152069650241174, 0.014074516202526866, 0.06800643517635763, 0.05499099803273566, 0.07446961375535466, 0.02266026032884838, 0.06828436948126182, 0.07233981319586746, 0.02232158680271823, 0.0653450342360884, 0.05227025867498014, 0.08039814172661863, 0.03412165693589486, 0.046461101446766406, 0.02457642254739767, 0.01796608165022917, 0.006331423246592749, 0.050652892532525584, 0.03550994806573726, 0.05268311171676032, 0.07544901862274855, 0.06466619917773642, 0.035139627507305704, 0.010385970817878842, 0.027185108738194685, 0.03578550007659942, 0.02583819234132534, 0.0892398739233613, 0.07723053669906221, 0.029831527572241612, 0.03887150596710853, 0.03751423289941158, 0.06251614540815353, 0.047842319909250364, 0.08651873009512201, 0.034782101574819535, 0.05059751347289421, 0.005623329016088974, 0.039798025391064584, 0.031091547753021587, 0.031091278724488802, 0.0905998150119558, 0.02056740388070466, 0.013006438603042625, 0.020634705542761367, 0.03851895984553266, 0.029394859011517838, 0.049987312231678516, 0.0322683434933424, 0.02650940925377654, 0.014002822881593602, 0.03015405010955874, 0.03132238351099659, 0.041014847010956146, 0.018553641821199562, 0.017075947871489916, 0.04100064230442513, 0.010332618749089306, 0.03968513359723147, 0.042975912874680944, 0.019709401385625824, 0.07559156292700209, 0.015906638545857277, 0.028549057424243074, 0.02446625443553785, 0.09350709689897485, 0.03123006405076012, 0.03571944522263948, 0.04025203794299159, 0.04495871995459311, 0.055666890475549735, 0.03720318396517541, 0.00737196206500812, 0.014457355864578858, 0.05554436560487375, 0.017566937931405846, 0.025976881188398693, 0.05008138316043187, 0.03089109181019012, 0.016036382658057846, 0.05868779888260178, 0.006426417221518932, 0.04065628949319944, 0.024898210358514916, 0.05079918468254618, 0.021401548183348496, 0.08593972874223255, 0.09049449683516286, 0.01832079669839004, 0.009457908654439962, 0.15248477866407484, 0.06780793293728493, 0.022862688529130537, 0.04722242621937767, 0.03907649457687512, 0.0057139137061312795, 0.029027449527347926, 0.016687010538589675, 0.029681018168048467, 0.06006936986523215, 0.016818777003209107, 0.06917061255080625, 0.02201536739448784, 0.03075279815675458, 0.06865868650493212, 0.046630136712337844, 0.038988550077192485, 0.039386942371493205, 0.06880756132886745, 0.025311887184216175, 0.01730863343254896, 0.05741932749515399, 0.016958354572125245, 0.14077782951062545, 0.050266730831936, 0.04629536131687928, 0.029593606159323826, 0.030383653902390506, 0.06381596511346288, 0.03261838486650959, 0.03530275898810942, 0.013348004649742506, 0.01259653003216954, 0.012735166928905528, 0.028292335555306636, 0.03722898843989242, 0.04942584411764983, 0.047514917750959285, 0.007380960605587461, 0.043095146320411004, 0.044291826052358374, 0.057867250725394115, 0.017420358199160546, 0.0339143825112842, 0.03912972140824422, 0.010990441751346225, 0.04690682420914527, 0.037296093432814814, 0.012970712541573448, 0.03769311275391374, 0.047155636639217846, 0.0737465763813816, 0.008064518970058998, 0.013969326973892748, 0.0792504548735451, 0.05490352850756608, 0.02043226621026406, 0.021143679696251638, 0.12746923661325127, 0.0264101785433013, 0.05222896557825152, 0.05694660168956034, 0.027415463955549058, 0.06692442839266732, 0.039038904797052965, 0.11787248789914884, 0.06729681583237834, 0.02959067096526269, 0.028964276061742567, 0.13837629900081083, 0.02109283144818619, 0.014296818189905025, 0.04558466585876886, 0.08605932584032416, 0.03650533879408613, 0.031284018186852336, 0.03452725177339744, 0.026376902496849652, 0.054002216129447334, 0.009159475303022191, 0.03513402429234702, 0.04150034146732651, 0.03601356947910972, 0.05142493391758762, 0.05069777762400918, 0.036336411139927804, 0.03222945124434773, 0.0038801491291451384, 0.02745484045590274, 0.060331989952828735, 0.038538033040822484, 0.025415865784452762, 0.044998050070717, 0.06721713885781355, 0.01794068350136513, 0.03536647236614954, 0.021560328823397867, 0.03929448932467494, 0.02988627580634784, 0.035757368968916126, 0.12806044629542157, 0.03635534332715906, 0.04482619093323592, 0.055420252538169734, 0.03593446395825595, 0.05410923382441979, 0.061860847563366406, 0.0689285017142538, 0.02573903213487938, 0.02724815047258744, 0.13655008136993274, 0.06878537853481248, 0.17020585510181263, 0.24660684139234945, 0.1505410938989371, 0.17889633018057793, 0.15512585960095748, 0.1580061050481163, 0.13186092517571524, 0.16384980553993955, 0.18101756635587662, 0.19676677125971764, 0.12192558642709628, 0.07227875670650974, 0.14723798754857853, 0.10086428141221404, 0.11497419342049398, 0.13363684003707021, 0.13440025766612962, 0.09711583450553007, 0.09892707559629343, 0.1159761002054438, 0.1306135975755751, 0.12523057783255354, 0.10822887998074293, 0.10059756838018075, 0.13704559853067622, 0.1936572912381962, 0.11923970945645124, 0.1620794864720665, 0.23215231311041862, 0.18218647863250226, 0.1609092828584835, 0.15397051378386095, 0.14652298763394356, 0.1810211583506316, 0.060576479372684844, 0.22911700332770124, 0.18912129948148504, 0.12076494167558849, 0.13864222535630688, 0.12356030769296922, 0.1299447740893811, 0.10149907000595704, 0.15877516299951822, 0.1892988954205066, 0.12146644934546202, 0.11084207100793719, 0.15540823194896802, 0.0676667616062332, 0.1468689026660286, 0.12338550965068862, 0.06596371080377139, 0.11503372850711457, 0.1077615495887585, 0.171012970386073, 0.1414476623176597, 0.08495005255099386, 0.12814769317628816, 0.1672295163734816, 0.13440787210129201, 0.1485416738432832, 0.20862663252046332, 0.18086919619236141, 0.1544013453531079, 0.1381557623972185, 0.2248105578473769, 0.09597631869837642, 0.12425161083228886, 0.12200375684187748, 0.1925477507757023, 0.1117230299860239, 0.11063018042477779, 0.13041768543189391, 0.17772099090507254, 0.18108753603883088, 0.08487000450259075, 0.21294066275004297, 0.1705306040821597, 0.0889414489211049, 0.1749779685633257, 0.11406327394070104, 0.1264432174502872, 0.12551265332149342, 0.2095644993823953, 0.13426226272713393, 0.15835363796213642, 0.21553722966928035, 0.11903463178896345, 0.210175717365928, 0.09852517294348218, 0.1408627608907409, 0.15642896702047437, 0.15690958185587078, 0.18527559412177652, 0.20842632686253637, 0.14358130720211193, 0.09624657919630408, 0.11623387777945027, 0.12205555874970742, 0.17658559401752427, 0.17155399604234844, 0.16969289747066796, 0.191343616170343, 0.15733987907879055, 0.12305357668083161, 0.1356187157216482, 0.15325042273616418, 0.1597038420732133, 0.16101849731057882, 0.10379568309872411, 0.09133269326412119, 0.1206145306059625, 0.07243069660034962, 0.1303956436458975, 0.15893705509370193, 0.1409645241801627, 0.134054075460881, 0.22517949430039153, 0.14973752608057112, 0.18380424182396382, 0.1721517217811197, 0.15269195660948753, 0.11346424202201888, 0.2849741990212351, 0.12410987546900287, 0.16448492067866027, 0.09077933311345987, 0.20680320536484942, 0.13261312153190374, 0.1286608586087823, 0.24076312605757266, 0.14944845956051722, 0.09576793105225079, 0.10387594636995345, 0.1866038455045782, 0.1229065794905182, 0.07221997861051932, 0.09847947891103104, 0.20750492083607242, 0.11986657933448441, 0.15839317959034815, 0.10534787754295394, 0.08363712651771493, 0.13660192780662328, 0.11697480833390728, 0.09472792240558192, 0.11531903975992464, 0.07986798111232929, 0.19212720537325367, 0.2621198206907138, 0.06513691376312636, 0.05917091104493011, 0.10181857942370698, 0.1589011203031987, 0.11448981589637697, 0.19601562875322998, 0.2754997636657208, 0.1260225087753497, 0.20909225597279146, 0.11112658074125648, 0.12594649801030755, 0.1150746653729584, 0.1469123034621589, 0.09548642701702192, 0.09293588067521341, 0.18522054160712287, 0.05053366279753391, 0.13152792351320386, 0.16870349587406963, 0.1626098994165659, 0.14241422060877085, 0.2513925509992987, 0.16501577891176566, 0.23776023328537121, 0.09914965310599655], [0.02935295364295598, 0.06326786678982899, 0.0924490021134261, 0.05158967956958804, 0.01793709336197935, 0.05154855716682505, 0.04519970272667706, 0.008955655575846322, 0.011670331587083638, 0.06548574543558061, 0.009642383374739438, 0.025001328067446593, 0.04577731997414958, 0.02325896013644524, 0.030192419144441374, 0.03956074964662548, 0.01705373724689707, 0.03361464390764013, 0.02631992225360591, 0.011325472260068636, 0.04898857441730797, 0.06343928806018084, 0.03248632339818869, 0.005338480214049923, 0.0413103405298898, 0.02687946820515208, 0.03143523819744587, 0.03096257547440473, 0.01847809304308612, 0.033041653950931504, 0.029872416198486462, 0.05427462514489889, 0.014057051612326177, 0.06957027391763404, 0.011385208654246526, 0.014664449390693335, 0.05427317424619105, 0.034314500298933126, 0.0756917305989191, 0.06271538979490288, 0.0651228723290842, 0.06654453041846864, 0.06535386579344049, 0.04878525192907546, 0.08139095720252953, 0.04044585351948626, 0.01851606873970013, 0.04069092923600692, 0.052067889846512116, 0.09106353856623173, 0.06150613437057473, 0.019161523850925732, 0.09631043358240277, 0.018469571332389023, 0.028078877185180318, 0.0161629652211559, 0.03096126743912464, 0.05710736571927555, 0.06410032641724683, 0.07112731458619237, 0.09231440621078946, 0.042811248858924955, 0.036543882233672775, 0.03847512118227314, 0.06659118924289942, 0.09407848381670192, 0.07276031406945549, 0.03875822454574518, 0.033145877459901385, 0.0544615944090765, 0.05669446814863477, 0.0060420134832384065, 0.023177143921202514, 0.04698134696809575, 0.03537840239005163, 0.02516176555218408, 0.06137647374998778, 0.01174542023363756, 0.03145597751426976, 0.032256461709039286, 0.0389211779111065, 0.07351052146987058, 0.037247794462018646, 0.007357857084571151, 0.02931168652139604, 0.05658737623889465, 0.010764181333797751, 0.012237668233865406, 0.04077402008988429, 0.04196374960883986, 0.04130105626245495, 0.07727744043222629, 0.04395392621518113, 0.0444636963220546, 0.015363225029432215, 0.030434810141741764, 0.022040383337298408, 0.03378156776307151, 0.039234097057487816, 0.02514374806196429, 0.004014395062768017, 0.03473649288935121, 0.03951430233428255, 0.013109906976751518, 0.03864691352646332, 0.028842344909207895, 0.019937698998546693, 0.04305408328946214, 0.0414868863299489, 0.027651704403979238, 0.011468817156128353, 0.013782939367956715, 0.03482358020846732, 0.042668559835874476, 0.028762126166839153, 0.06910588243044913, 0.0426528634125134, 0.005624028490274213, 0.03829987042990979, 0.031703216591267847, 0.0071901233604876325, 0.03482293453998864, 0.038930874070501886, 0.02906482965045143, 0.01542625099318684, 0.0518992033903487, 0.03339653783768881, 0.09744279508595355, 0.0171537230926333, 0.0034196970545963268, 0.03877209157508332, 0.11131495266454294, 0.024926029764174018, 0.0388057813688647, 0.03709333126607817, 0.03354106367623899, 0.11375809539458714, 0.046472701214952394, 0.05532778464839794, 0.04968955516233109, 0.02765610162896337, 0.02580143747763941, 0.059912824945058674, 0.06245506665436551, 0.009741692010720726, 0.031573882515658624, 0.06364841785398312, 0.0381227457546629, 0.004617140966729494, 0.029248860009829514, 0.08850815342157148, 0.04011455508589279, 0.051572157462942414, 0.06406097032595426, 0.057854812330333516, 0.056065074968500994, 0.004485785466386005, 0.043905219063162804, 0.07635486923391, 0.01820770452468423, 0.020917801484756637, 0.04197938666038681, 0.05250258429441601, 0.025481451230007224, 0.006273147955653258, 0.02587260758446064, 0.007285356214197236, 0.060572876245714724, 0.08208962244680151, 0.04368066001916304, 0.04523843541392125, 0.040147417385014705, 0.09899993965518661, 0.0333305646199733, 0.012163371829956304, 0.013848834660166176, 0.06499901530332863, 0.01838688494899543, 0.1421717312769033, 0.007623958772455808, 0.023270578458323143, 0.06770900465198793, 0.013490829114743974, 0.018811996415024623, 0.025659991551947314, 0.06147377673187293, 0.031172369490377605, 0.06440865166950971, 0.018699360662139952, 0.02994937134644715, 0.05987845237541478, 0.0039639879287278745, 0.011697755799104925, 0.011110356117569609, 0.007163768304963014, 0.027103860265924595, 0.07322554418351501, 0.02826696709234966, 0.08824768185149878, 0.021568037882389035, 0.03444753026997205, 0.02259888657135889, 0.03766151952731889, 0.014920566409273306, 0.056319998984690756, 0.13387723651248962, 0.01158921299065696, 0.057724929065443575, 0.03612158907344565, 0.03165543712384533, 0.052736294019268826, 0.040598472478450276, 0.030900162710167933, 0.018389024189673364, 0.05283338177832775, 0.027170555222255643, 0.04329376730311196, 0.05655049521010369, 0.052918224100722, 0.026030234184872825, 0.09744531838805415, 0.04810697719221935, 0.034885338027379476, 0.007385355047517805, 0.061750026361551136, 0.08775194204645231, 0.030642670863016974, 0.03280799988715444, 0.032098955707624555, 0.005607778239209438, 0.025819137699727435, 0.020224802537995856, 0.0014589802322007017, 0.06224922457477078, 0.038546241194126196, 0.034077985255862586, 0.040465880374540575, 0.07127301301807165, 0.024337044669664465, 0.06625886293477379, 0.039914598237373866, 0.08848282392136753, 0.08958089820225723, 0.03909685168764554, 0.008857802476995857, 0.047098647119128145, 0.069439218059415, 0.04208421873045154, 0.054024090932216495, 0.03684841882204637, 0.07244268228532746, 0.03415737650357187, 0.06854667415609583, 0.007278517323356937, 0.052501704849419184, 0.022370729966496583, 0.06274718340137042, 0.05685222276952118, 0.04871382763667498, 0.029218085001048166, 0.07985281161381863, 0.05858813216036651, 0.04857405525399372, 0.1581449163495563, 0.03336400208354462, 0.011088947940152138, 0.06347172733512707, 0.05767526454292238, 0.039555335679324344, 0.0928679593198467, 0.029324117494979873, 0.041070997904171236, 0.018542205325502437, 0.0461540230026003, 0.04739117204735521, 0.030216748600651044, 0.017888616275740787, 0.04558347471174784, 0.061349025418167, 0.04421344412548933, 0.01283117022467195, 0.04209858670947142, 0.015575301149510778, 0.019200887363695074, 0.05496044010214973, 0.014291150964709232, 0.03731321106897667, 0.08693092633620836, 0.05966771954263095, 0.0447291477030376, 0.06286796793574467, 0.04663794781663455, 0.07222500295029022, 0.04025111767987255, 0.042154284892603755, 0.017476436732977163, 0.019674414688779507, 0.03358921050676145, 0.08383436710573733, 0.012355085273156874, 0.04076387864188291, 0.08366841546376236, 0.03468183371296618, 0.032099953896249644, 0.053669515036745, 0.044074822071706876, 0.030341041638166644, 0.1033138956699986, 0.04451579137821682, 0.02005778962484328, 0.045061941564199515, 0.01305243877141038, 0.05262143924483098, 0.048479847027920187, 0.07056703019770794, 0.044037169209332205, 0.06759055788279511, 0.06016280996846035, 0.14323654992040247, 0.11151246042572893, 0.021733692665293347, 0.02601216659968486, 0.03955181047786027, 0.04319885032600723, 0.0484608109400142, 0.0664557027630508, 0.08021624133107252, 0.03431887897022534, 0.023771964151819702, 0.046661054584546946, 0.05888801177206915, 0.04652148258173838, 0.06180639618833084, 0.022754366509616375, 0.012559924525703536, 0.015143326672841795, 0.018933413630293217, 0.03837898708297871, 0.06145305225800257, 0.03561443503713235, 0.024331109343620483, 0.050186233784188516, 0.02360147613217123, 0.0461074792110594, 0.01308846076426562, 0.006181873532113968, 0.035740281018661335, 0.054648266814183444, 0.1066708670987282, 0.006262043571041431, 0.09076403744984418, 0.05990891011606436, 0.17660094163147733, 0.16178065328858793, 0.15254288882715628, 0.16127968876389787, 0.10402470987173729, 0.13901019701734185, 0.09185313916532323, 0.09233475590008311, 0.14003669115481898, 0.1985119463643059, 0.15475845197215676, 0.10604972660075873, 0.1630356695386581, 0.11273199459537864, 0.20363594172522426, 0.15279671817552298, 0.08681118080858141, 0.08646527319797315, 0.09984324948163703, 0.10785641090478748, 0.19016836595255882, 0.09045440601767041, 0.13811337092192844, 0.12421853331034072, 0.08620109831099398, 0.10530763087444939, 0.2022171631688252, 0.1131731791247148, 0.1759598744683899, 0.2688186237355694, 0.17528180382214487, 0.12721092469291762, 0.14987630769610405, 0.16146829817444086, 0.10867971242987551, 0.17333550669718534, 0.16058766574133188, 0.20519666344625875, 0.2057683843304403, 0.20310411870013922, 0.12300592337851413, 0.13812708581099287, 0.14190766029059887, 0.2877068461384624, 0.23012369696516544, 0.18920765578513965, 0.10950015668640845, 0.24963805451989174, 0.15453956293640658, 0.25598389212973416, 0.08601638517575338, 0.09814568315050565, 0.2656017104163766, 0.09836152195930481, 0.06533102990943007, 0.10228899715002626, 0.15815912105608732, 0.16432905482361093, 0.12409901042701676, 0.1134881614416372, 0.22234120988287032, 0.16411616234108806, 0.12924636859679595, 0.10670239353203215, 0.07989539604750462, 0.2101077069528401, 0.24969276564661413, 0.09639396972488612, 0.13200430810684338, 0.0863284211663995, 0.17192431289004162, 0.1066448177152779, 0.0906083348672837, 0.13432770530926064, 0.1960862663690932, 0.13459502690238878, 0.22244475432671607, 0.07503475921112113, 0.09431814556592144, 0.15221485955407843, 0.15727669262560084, 0.14979568077251315, 0.0943285578978248, 0.12028679819195531, 0.169332362129353, 0.12460500671295449, 0.1882250077323988, 0.22019730851752684, 0.11194421225809492, 0.23254844185430557, 0.1821655797539279, 0.20656791486544535, 0.18041884613921866, 0.17288616596488282, 0.11837428362923674, 0.1019555279344786, 0.1291398555622436, 0.11823251858004369, 0.19597400911152363, 0.10476389637915418, 0.12334945611655712, 0.13392880093306303, 0.24779490107903257, 0.10814833469339646, 0.12958385283127427, 0.08870816964190453, 0.09470665245316923, 0.13901530299335718, 0.18236567761050537, 0.08644205881864764, 0.07787713286234066, 0.16097852523671463, 0.18336532084504142, 0.1620006703888066, 0.14678036444820464, 0.19888066017301753, 0.15244192705722526, 0.09157371314358898, 0.14991853589890525, 0.1940167578868568, 0.13929993147030473, 0.15412829437991604, 0.1339812410878949, 0.10481488934601657, 0.1514475530711934, 0.14413552824407816, 0.08934560770285316, 0.29255045810714364, 0.0728864420671016, 0.14591218525310978, 0.17644739127717912, 0.17447060672566295, 0.14352891157614067, 0.1497431070310995, 0.09665807781857438, 0.14776593656279147, 0.2171824374818243, 0.19625338318292052, 0.11420124661526643, 0.19498603243846446, 0.18091179546900094, 0.21168701205169782, 0.3332212788518518, 0.23763825389323756, 0.10986320048687048, 0.10495255774003454, 0.11520197338541038, 0.19154062669258565, 0.13633148919325322, 0.13077140785753727, 0.14549257495673373, 0.12589693738846108, 0.16249265492660925, 0.15923617029329762, 0.16688309668097645, 0.12087744384189136, 0.15950925095239654, 0.13322024286026135, 0.23380513535812497, 0.06885624621645547, 0.07287215572432615, 0.1582380261970684, 0.2003878285177052, 0.12298393354285508, 0.10723116633016616, 0.09937577066011727, 0.1650514465291053, 0.1319678538129665, 0.25292428443208337, 0.13101927033858374, 0.14447940979152918, 0.10337601343053393, 0.4342373739928007, 0.1340430323034525, 0.1138947470462881, 0.1653098178212531], [0.007864494400564581, 0.032303695697919466, 0.015709390536358114, 0.03656981287349481, 0.03627161422627978, 0.04123638922465034, 0.04455650188901927, 0.07546452950919047, 0.027249341619608458, 0.07870193352573551, 0.051317007091711275, 0.013302918250701623, 0.04874388832831755, 0.05019038981117774, 0.02253008020488778, 0.03167893723002635, 0.025969840062316507, 0.06089424103265628, 0.023577719985041767, 0.07253390707774088, 0.009443335657124408, 0.06322960165562108, 0.05301615048665553, 0.02040716863120906, 0.03841874764475506, 0.006580126673725317, 0.08794716399279423, 0.036316718251327984, 0.027244551056355704, 0.05121517700899858, 0.069812496076338, 0.02493741616490297, 0.030268674818216823, 0.10954548706649803, 0.020990472585253883, 0.015072220576257678, 0.03346739067637827, 0.057038472150452435, 0.04877173370914534, 0.07391560051473789, 0.0428585570625728, 0.0728899598470889, 0.02173719560232712, 0.028768072625098284, 0.02104081246216083, 0.060466255599749275, 0.07615128328325227, 0.02179444672947284, 0.040295420185429975, 0.03670540696475655, 0.025072240277950186, 0.016036573761084583, 0.016421668624388985, 0.06769288520445116, 0.017131423410319258, 0.02024532477662433, 0.05422926136816386, 0.0543127121636644, 0.01298037715969258, 0.00803222348622512, 0.014728620117239188, 0.04530675752903335, 0.011219148473173846, 0.007249420496009407, 0.03229909067158587, 0.05800324186566286, 0.052913192339474335, 0.03664573829155415, 0.04231189108395483, 0.05837877972226124, 0.06583212059922516, 0.07602180077810772, 0.039774558681529015, 0.01804160259780474, 0.03463440305495169, 0.014141646242933348, 0.057171361113432795, 0.048516279057366773, 0.04669598747568671, 0.04193811953882687, 0.060317106181173585, 0.03056553759961389, 0.021741355340054724, 0.03371642575075384, 0.0691071515029762, 0.0090226538850402, 0.0011862493101943983, 0.017727857812133152, 0.030300672515295446, 0.06722741018165834, 0.027936388542002533, 0.006086547909944784, 0.023640913859708235, 0.03994972037617117, 0.06232196989003569, 0.021562679576163646, 0.0709660310531035, 0.06378031233907677, 0.04673021532653365, 0.07222643529530615, 0.050176834483863786, 0.07511449555750005, 0.04996529271011241, 0.05059547627752181, 0.056486028552171774, 0.08964554668636993, 0.03845643761451356, 0.03283526639279444, 0.06980059202760458, 0.025880832436087076, 0.016840176831465214, 0.04794665474037174, 0.03357071618665941, 0.05122797163494397, 0.0671310126199387, 0.062432705744868144, 0.0668510003015399, 0.026710397687566, 0.09873036935459822, 0.0038660371910737013, 0.006265475540203624, 0.03025816044100793, 0.039935196546139196, 0.038974675626377575, 0.03224276537366677, 0.03600931326218415, 0.02866677317797439, 0.03942640236346051, 0.038111836183816195, 0.027551998718990944, 0.012118153699702816, 0.016661211629980244, 0.08761714576394297, 0.041826148008112796, 0.04490880681260023, 0.01828008989832597, 0.11530749194207601, 0.045305859530344605, 0.01753290674969321, 0.003444546709943097, 0.02976863983349176, 0.02972984962980263, 0.02551967369072372, 0.04981680009223055, 0.04990409521269612, 0.03716460712894332, 0.023500774113927037, 0.024688099074410275, 0.04815992200747132, 0.009691236173239304, 0.015211727641144535, 0.022505811975861434, 0.04840769543079659, 0.02779792048386298, 0.00950418248976348, 0.04098335397429764, 0.04532417202426586, 0.027871012753166724, 0.004227812150929822, 0.07389515434624627, 0.06019798034685664, 0.012040172532579163, 0.07113986430340447, 0.10041656598332338, 0.03807742650678847, 0.034680976532399654, 0.055024008761392906, 0.018055645887216087, 0.04570758406771347, 0.08316296094562858, 0.036269406336941756, 0.048631415847921744, 0.023623634806426708, 0.050143623375333846, 0.0331962024938548, 0.029260302071634214, 0.04363521460618358, 0.05463656685606111, 0.044619621548918076, 0.022803313004260417, 0.05006687788409181, 0.05744833433709573, 0.016638904526189435, 0.10699735270463862, 0.02915563884016592, 0.04118598997592926, 0.04829697441891767, 0.03266162981162779, 0.0363663790631108, 0.03403178656299133, 0.03752668242668733, 0.033910289566847496, 0.059236791494186036, 0.019099450619251, 0.04229010904964525, 0.04487378857447766, 0.053355742420535535, 0.013421375224424992, 0.03453368990449235, 0.03957227891078219, 0.019674696704896633, 0.022748286464775447, 0.09345131707959808, 0.023769819345034193, 0.03327436177642085, 0.046788744803052396, 0.02268155996716814, 0.035425602982286364, 0.04588667543430347, 0.10924911039182916, 0.07693312843912281, 0.020325216974015348, 0.028996611436014064, 0.040832082013366744, 0.007049243322398979, 0.023662577150389552, 0.01877503931609681, 0.010876867181650596, 0.08046568458667025, 0.07341951932176016, 0.056746874906821176, 0.08691678842296824, 0.03499263773846906, 0.09385842218762264, 0.07750813703751191, 0.030594657619076315, 0.04051325537147932, 0.020396925137902144, 0.07912852001027204, 0.027316370542393997, 0.03275995695730671, 0.00831838728117873, 0.012478279932111036, 0.017774024963728152, 0.029757557713310234, 0.02625295084726531, 0.006538637371704681, 0.016523535814485513, 0.01901069346786244, 0.07394852218567394, 0.02753732831479283, 0.04346507725131232, 0.05699948713299818, 0.044221700518392026, 0.04538079047051724, 0.044237730908207595, 0.010157920896745054, 0.0740589240740519, 0.025214368979504798, 0.04756733564136084, 0.024488865819876082, 0.029063686743029393, 0.02209421687439317, 0.04743401994346641, 0.01621443501790054, 0.08086752044619061, 0.059124912731931545, 0.07723169444943778, 0.03620057956140954, 0.009645846421335591, 0.08352021599421278, 0.052291654792497866, 0.05399686524469871, 0.04439339638338424, 0.08762044832110405, 0.03006746559549356, 0.04541349320788868, 0.04148671192524489, 0.008479995503876125, 0.019837646359519567, 0.0884021376259625, 0.01382377140544122, 0.012736654934997205, 0.0690348217904102, 0.0351918153319275, 0.028051857443642803, 0.06202787160873413, 0.062156233470886946, 0.011006791264662752, 0.04177640927082393, 0.0517312442389084, 0.04938051373756025, 0.016640889771224465, 0.045242673077154905, 0.06935165205504745, 0.06835734486230649, 0.022739690539310686, 0.026341581833548844, 0.055125029903138056, 0.02287742758198874, 0.07145362949813716, 0.025681218830868602, 0.038384408471756615, 0.027414554824645165, 0.042364668915979564, 0.014163933865347644, 0.008480219075863715, 0.03018940973561257, 0.038467918639071286, 0.05710886114684399, 0.024986240205180366, 0.01859870317275636, 0.02116769002896035, 0.025669715541880578, 0.023280482419067994, 0.029525105928769335, 0.03563634323654696, 0.12136262288549915, 0.06711337176966481, 0.07444210234098136, 0.056142354806070216, 0.03565504535799846, 0.07278170276549645, 0.027180780161870643, 0.041321020034956746, 0.03136332037684042, 0.013323668699740665, 0.03607291160733439, 0.027592679543886334, 0.042690178597695194, 0.02944644569652155, 0.0009489064825629612, 0.05243429186521098, 0.05311046632414218, 0.0651104339340236, 0.020703420996142086, 0.02356745051656617, 0.01132819594204193, 0.07053062785416842, 0.0095768591563683, 0.04817890243430156, 0.076494697277667, 0.04257362801581621, 0.03264564023993444, 0.03120269364444539, 0.05530124544748105, 0.11297522607492283, 0.012180149933556095, 0.1438561244867742, 0.040059179736999795, 0.02577601891971426, 0.06747870138497092, 0.05213506534346379, 0.07204069799627177, 0.08094162389170378, 0.03827276348602027, 0.031488513268413953, 0.06590806457097642, 0.01691391291387845, 0.02099028519296553, 0.0672474259044975, 0.007569204508399707, 0.10667836279026233, 0.10984037202433683, 0.12782330042682588, 0.130072052415926, 0.14903343573678285, 0.23009787022601813, 0.1238758466206491, 0.26812661555595696, 0.13434833701467142, 0.13365376100409776, 0.13862638792488724, 0.12862131698057055, 0.21367081732023507, 0.11179340785020031, 0.12145302389399149, 0.131304893293418, 0.1306623566779308, 0.12628338852664456, 0.1118272275198251, 0.14534059795551002, 0.11173838502145372, 0.15908017085166648, 0.16035883192671463, 0.09984646298107691, 0.12259919676580466, 0.1478143542772159, 0.1941068991436623, 0.10864463110920042, 0.08662853084388189, 0.16617422690615058, 0.2246141410432756, 0.15420825337059796, 0.1248859689803794, 0.3020492952782661, 0.15775662468513474, 0.10988179128617048, 0.12236772090545855, 0.21200563089223579, 0.11293092728010379, 0.1297354290727526, 0.12357718413113616, 0.1554210265749134, 0.17228222102858126, 0.11073932066210546, 0.13007819739868864, 0.18357160821324214, 0.11176601517945528, 0.19919451442547143, 0.16930880636209622, 0.06968627902097069, 0.10571052800514735, 0.12216528528369963, 0.16405687958467752, 0.13615655014291406, 0.11269243812421337, 0.16265445796307176, 0.13423514465102926, 0.08773155524977483, 0.13785862131044269, 0.09062642842764035, 0.10592144637485035, 0.16531217785086483, 0.11541574902366847, 0.1778783558984287, 0.13292215182445943, 0.18297398637514561, 0.10045198127045296, 0.10400516912341118, 0.10569307269179262, 0.16481958475196734, 0.21211061510257423, 0.16240856959484518, 0.13029529043706134, 0.0811033601348754, 0.1752850247430615, 0.09201334658428095, 0.08049792348174378, 0.16250878921709955, 0.06789594423025846, 0.1804567253566347, 0.12167322653112933, 0.18756271514575928, 0.14893912361003458, 0.09245487992302515, 0.18664070055820048, 0.19162463780958205, 0.10461859870702028, 0.12449994828784838, 0.13534063298720866, 0.11431474325945601, 0.14761792263016105, 0.0608420494972961, 0.10808488848851994, 0.10588137782178819, 0.1852250687079504, 0.09431784870685078, 0.20201567007461563, 0.20102003443753347, 0.13691609376110137, 0.27236341789830476, 0.13361387798795477, 0.13529212621506304, 0.11517362334416248, 0.07978995912708342, 0.13062348298262805, 0.12047676573274657, 0.09752832760568708, 0.15690330328652635, 0.190183995582629, 0.1489297131774947, 0.08636255253804848, 0.1201655832119286, 0.1146460602467414, 0.10510178879485466, 0.18681546149309725, 0.1397725014248863, 0.12751689733704552, 0.09212869117618538, 0.19576003309339285, 0.11107761383755133, 0.1201644774118904, 0.13270213472424075, 0.14021072478499264, 0.11144381918711588, 0.10705088381655514, 0.09047011728398502, 0.10259203831083141, 0.14024226606125012, 0.09590152505552396, 0.13943256810307503, 0.15165634889854118, 0.17987685569096357, 0.16335045889718458, 0.1118482080346439, 0.16894868662348017, 0.08020044100703672, 0.1810144493356347, 0.1382886216742918, 0.10524576544412412, 0.1123973008361645, 0.15189150581136346, 0.12638182699447498, 0.14083737944019958, 0.14530730521073565, 0.14875928638502955, 0.09864359002676792, 0.20968775526853278, 0.26351488020736724, 0.13070808781776577, 0.15722576645202935, 0.13809477270115167, 0.1204051187960431, 0.1390619989251718, 0.16822145611513406, 0.10715926706325263, 0.13008046837057918, 0.09176474195555784, 0.1684282481437549, 0.10995720833307132, 0.14262478274758905, 0.22159177431603894, 0.09060644981218502, 0.2513580856611952, 0.14497877127723768, 0.19150215375702828, 0.12090928939869627, 0.09705059230327606, 0.18346809345530346, 0.20154348603682593, 0.1461512755486183, 0.11600428697420284, 0.1337083088583313, 0.1250150433043018, 0.16236187366303056, 0.1921635854523629, 0.07846116597647779], [0.06114692005212419, 0.012084501940989867, 0.0033337373361064238, 0.060065614597988315, 0.0364766399434302, 0.044146910586277954, 0.043840359066962264, 0.020191073781461455, 0.022011691908119246, 0.05735741382522974, 0.026261424318363424, 0.0798586820019409, 0.05428553842648398, 0.04053303360706195, 0.06539128487929702, 0.020207393608870916, 0.06994295079493895, 0.03386321142897941, 0.03975619423727039, 0.025864054332487285, 0.03214565535017755, 0.09464545495575294, 0.024886042847356293, 0.012344560691417428, 0.03768323105759919, 0.03719421511050314, 0.046795709858997725, 0.037855928821954876, 0.09769250551471487, 0.010635229464242002, 0.049774241633713245, 0.07641930249519646, 0.03168021372403018, 0.04988854721887037, 0.024311106608365662, 0.013289834187162342, 0.03167421346006449, 0.11791951779741794, 0.0801352655980736, 0.06074731063563377, 0.0055388457076333, 0.05846106905664783, 0.039470151968998834, 0.047456195316044614, 0.01729228206386324, 0.04433679649082478, 0.03477145917713642, 0.057823608731268905, 0.01432042312444537, 0.012175147858215496, 0.026348342798883095, 0.03167652525007725, 0.0305707140796585, 0.01223174496772117, 0.08974949188996106, 0.01301746135141002, 0.0024244229825853836, 0.06172810331918299, 0.048301913411705755, 0.035732510732486844, 0.05001913181331474, 0.018730556839727797, 0.02207573183113709, 0.058412888829479925, 0.010926702398137422, 0.021827271921210922, 0.0493910596560454, 0.03816536729573272, 0.0657440721988678, 0.09254528093151748, 0.031160791986621916, 0.032863482847460546, 0.0424198364635231, 0.053541212546406314, 0.012931774836033583, 0.06241784052690491, 0.04629666007531341, 0.02595623464003438, 0.04033172233903315, 0.017658212818787433, 0.044192459899932146, 0.007080290606609196, 0.03261259240389336, 0.02730253319896292, 0.05559296143474057, 0.026383340627944563, 0.08636236700112931, 0.01392773423503968, 0.06233423759113066, 0.018279811592947226, 0.03290404121798929, 0.008187374096451094, 0.031159318823483773, 0.03162397748383228, 0.11925444108783267, 0.014697609476570506, 0.030012867646291852, 0.029587798853754066, 0.06853903745650314, 0.06241058974410407, 0.06711688212817535, 0.06205919766216539, 0.048023582057794556, 0.0488653593492927, 0.10494008965906687, 0.04460983633180149, 0.09833232586970553, 0.03642860443505924, 0.04373109266452957, 0.05058460381405894, 0.041518045400152914, 0.0258892817873857, 0.07645148943993263, 0.04695198389526922, 0.06632848380832002, 0.044327460273052566, 0.04670326794439461, 0.031338091066572815, 0.04102407932805363, 0.07818563623004593, 0.045650234606000595, 0.009709552377898945, 0.02174297878809739, 0.041965152267948724, 0.04668209447117988, 0.0505673488805769, 0.057442118850303814, 0.023780619449098594, 0.06532268816954456, 0.10703822277719155, 0.048322385555366054, 0.03481608451693319, 0.1285549541353248, 0.032975565700326115, 0.0486707756499527, 0.04320077619922813, 0.08326413793838583, 0.054716893209842965, 0.041769228992052376, 0.029234827852633316, 0.03348322439705953, 0.06865366216516122, 0.05819142454129178, 0.05750044423621148, 0.019239139510318637, 0.053088287240825593, 0.05160277105460409, 0.0857766937406268, 0.01427581169991754, 0.03308656872832216, 0.03422244801186025, 0.07018750329734758, 0.039044997829478234, 0.0479767636716133, 0.046474241171381436, 0.08655948142404668, 0.05190779374970589, 0.05244887877779547, 0.07321424869587645, 0.034948097745655105, 0.045083378499839455, 0.04174313879047986, 0.034727453530649655, 0.035920185036957264, 0.056230165719171055, 0.09834471973590553, 0.06947423258679919, 0.03139976353850216, 0.10223850884358399, 0.023460252850782126, 0.04017728511826135, 0.03869942418532446, 0.012105281148251379, 0.05545448781049345, 0.024612735833215993, 0.014730351176694967, 0.041809553586062975, 0.028264881657378282, 0.03729856849531643, 0.05788312897493597, 0.024481592772644944, 0.038205157543416135, 0.02268744705361314, 0.08748142179683782, 0.019813426370092202, 0.04395768519316334, 0.05443312933493871, 0.03639538219431415, 0.03673726365377661, 0.08040135522605851, 0.07105820579454303, 0.0710714457090944, 0.06072504249459598, 0.01648247092816746, 0.03693824837682769, 0.07119345478713512, 0.151123100949917, 0.051996450711158104, 0.011115183788206195, 0.03906999707396608, 0.026911183886113577, 0.07454560967744328, 0.03077938930800883, 0.02985458053444745, 0.042800242808880284, 0.005784670529465075, 0.022732632714905776, 0.041485535621177405, 0.04985646788554732, 0.04541514077573083, 0.035499049627105705, 0.029050023804302327, 0.014969145540817408, 0.01314428604018758, 0.03574238500732463, 0.027937058330280706, 0.011744246712623863, 0.0334756841766648, 0.03238517609133851, 0.030806926697550807, 0.037970787307131104, 0.01770692368154414, 0.08548542304197326, 0.021441985954879783, 0.027803145203506574, 0.03667466720798984, 0.03460446481767576, 0.01299466535783722, 0.020626564182748552, 0.06640843537752517, 0.0855409876385238, 0.004504718117459561, 0.012375142741802847, 0.07943591015646234, 0.016988905081234407, 0.05355389213946182, 0.042884740032604896, 0.030890470261510927, 0.0611216202378273, 0.018217955439467914, 0.0307433431953541, 0.01810764446418034, 0.024124478732119314, 0.009336208495369647, 0.020228266512276605, 0.03474383272987325, 0.053196343942545354, 0.022206574321899097, 0.03443614943535067, 0.00817019616079051, 0.038228305129450746, 0.03317191200039815, 0.01852368688560091, 0.036842915797024034, 0.01195438768263557, 0.041985969510278665, 0.05945061166130472, 0.05141789464687463, 0.04281323781469837, 0.018692395606194623, 0.03864295416860841, 0.05313115740136709, 0.0035948042477684794, 0.043983359792036936, 0.04352443422249053, 0.03236682649003342, 0.06961026825592853, 0.007833292656869162, 0.04794323715032078, 0.034652173781068996, 0.039247719178092666, 0.027275001375528518, 0.10350975586334243, 0.11379998963093385, 0.05245570653642062, 0.13253025332232937, 0.03381300142791588, 0.012438028625183506, 0.01949715086084325, 0.07143757684389129, 0.046735566211282276, 0.027598421911534388, 0.04647143214242533, 0.022096818101999816, 0.023835417778172996, 0.011626476225501392, 0.030802462679275777, 0.027661443236866035, 0.033545958140166476, 0.033282232252531685, 0.035358664972591214, 0.01145982325397199, 0.02709513260924723, 0.041433700316702016, 0.038127339648781344, 0.012117326205043355, 0.08692067727679387, 0.049843231681734324, 0.039681994312559254, 0.06964651474845596, 0.02389260767813539, 0.03537568241881672, 0.05584967402683105, 0.06755576599971391, 0.03637297675595619, 0.10223659410257824, 0.05652933286910411, 0.017424235920771025, 0.03947395918658003, 0.02356768243771512, 0.03192716707417276, 0.06518943555420265, 0.047625189763493836, 0.03506854460283648, 0.014544556361215655, 0.03688372278702445, 0.05745429007220082, 0.02674589090020163, 0.058939520531566814, 0.04094368247024249, 0.02962677459436236, 0.011060340930271195, 0.02305410882399883, 0.013412400803645141, 0.05145318376889918, 0.015537985036644386, 0.06144999832031317, 0.049333250062773004, 0.00908973104742472, 0.0445337884593755, 0.0379677333694417, 0.12548287835670635, 0.015691775661252905, 0.007996777585503878, 0.08278782755951397, 0.07002541082329117, 0.10900993846007623, 0.02153780464141164, 0.054855463313288055, 0.03446412469202187, 0.05440422268293332, 0.031340992863988504, 0.05956052744295448, 0.010259075625072, 0.09004100007587112, 0.008589260978624225, 0.021657019533449784, 0.0711248283914756, 0.02255579562188359, 0.02981718000228284, 0.026425641190144233, 0.047910990833770484, 0.15982677141437307, 0.06341950240312144, 0.10626491231960244, 0.1575954450527206, 0.1584203718812205, 0.11299005418550223, 0.1451037934748456, 0.2817792829591781, 0.11320345874992199, 0.11896376410732046, 0.17411173379514366, 0.12168847024440765, 0.19082656188402325, 0.11752297345083207, 0.20691670943051577, 0.13329239445738494, 0.17217423854162917, 0.1384912576759234, 0.14640112698543817, 0.16584564844379202, 0.22430779732530937, 0.18835676863091066, 0.09597113108611666, 0.07893058922491036, 0.09034847185830586, 0.11366894861566834, 0.20238948985934258, 0.08630913274828345, 0.16809950640890747, 0.10296562060830183, 0.10789537365781143, 0.14067830750718713, 0.09884739862172864, 0.1528876312659122, 0.10623467722325586, 0.13820668857079, 0.2514343784423545, 0.2139723370783031, 0.19751960586290807, 0.11374077366781421, 0.11722768773324788, 0.09203069057548419, 0.10499507538042963, 0.24039234907831997, 0.1996081875404343, 0.13282273372169584, 0.18601757852593437, 0.15071572124725208, 0.11052039451897144, 0.07381005969364196, 0.17587740701856092, 0.2256798799498938, 0.0738050947256852, 0.10588439836283214, 0.22071335348300636, 0.11964848439674824, 0.11535912315594032, 0.15155020693782717, 0.10215963338850997, 0.1781004955410026, 0.2060845837695524, 0.13053387607214972, 0.11937064657104202, 0.13391137530561537, 0.07792857853928581, 0.10774157839477994, 0.16930521436734125, 0.15458885638508946, 0.11582660939893685, 0.24826509616104886, 0.13819940068060532, 0.09989841331844218, 0.12400619743857533, 0.12022521477774717, 0.10698996091377921, 0.14959013555198908, 0.14608065277570859, 0.06100947430240922, 0.19658788398373872, 0.0762715408927761, 0.2049391233595088, 0.09927638966473751, 0.08551161343348213, 0.14513272239128128, 0.3034876368474215, 0.10389055925770663, 0.1840701384935528, 0.09775391081348062, 0.22644813638180494, 0.11431417922722176, 0.1215441373642534, 0.13843574502971023, 0.12778485717717558, 0.1280138542642817, 0.17570742551470175, 0.11445709460531361, 0.2501431602286175, 0.32234237354714423, 0.18804926716256887, 0.18991707474924624, 0.18057215900626034, 0.13822672655805945, 0.14423153246752918, 0.16123366076499224, 0.19353969051735476, 0.09897780138999224, 0.1551087011466734, 0.2142761426512152, 0.18999966094270349, 0.1043513067997992, 0.15294912562239915, 0.12727397755952552, 0.12785378785338253, 0.142978994990699, 0.09069634616025724, 0.12058530483045615, 0.13426529068965465, 0.10561993403825909, 0.11155191299621947, 0.1393190788803622, 0.17393594869645312, 0.1629452165798284, 0.13965401012683287, 0.21482700918568298, 0.1701851046527736, 0.09523967775749043, 0.14480628131423146, 0.12343239854089916, 0.174416993977502, 0.24035087786614895, 0.15041252423543483, 0.16863558936165646, 0.16722611733712256, 0.12880781869171187, 0.23644115484785289, 0.14175163116306067, 0.18605335004394874, 0.09686168603366241, 0.1439409371232614, 0.13609582762001082, 0.1495927627547644, 0.14773938251892105, 0.18273161578690633, 0.11270662798779085, 0.19059875223319978, 0.1962741039460525, 0.08758426120039076, 0.11514886529766954, 0.13030312751652673, 0.10194596907240339, 0.12809716776246205, 0.1120428139984142, 0.0634844700107351, 0.15482810995308682, 0.08985808293800801, 0.3280538826948032, 0.14379188418388367, 0.14359940076246858, 0.18866269674617797, 0.15975677204551175, 0.20182473032036796, 0.11094590488937683, 0.12907313648611307, 0.1033289241604507, 0.14613922307034954, 0.1932996799587272, 0.11841587358503602, 0.09741296817082912, 0.19259463966591284, 0.13192565529607236, 0.1556210353737697, 0.22842164064059034, 0.13356486655538902, 0.14505141269182786, 0.12816508911782876, 0.16157424717675894], [0.059947906265733764, 0.004943298172292998, 0.032027460911194794, 0.039734141319058836, 0.08909855416277424, 0.07188854287960567, 0.021395731600932777, 0.01161625406894018, 0.040256127176689915, 0.027165221035829745, 0.03204379929229617, 0.018810577057593036, 0.10177132688113488, 0.05567990774579812, 0.009875391770037822, 0.06784725934267044, 0.040650675146025605, 0.011277736393822124, 0.010533785298321163, 0.012322040220169583, 0.04542879258224275, 0.03895627407473512, 0.03921981813618913, 0.043154466184205376, 0.046133328214637004, 0.017035472992574796, 0.07741568027995527, 0.03025170932232868, 0.04115575116884429, 0.06421658385079354, 0.024970504819066264, 0.0323705260962015, 0.011623605041677365, 0.022603853394684847, 0.07213604912976734, 0.009918517043843167, 0.04997882577299606, 0.028260259932721965, 0.026528031594352797, 0.028997511290071998, 0.004796998600795632, 0.08169500768417493, 0.017226576019311324, 0.034235212951898575, 0.03315931033284869, 0.010842761785170296, 0.05402680348197464, 0.036414815331227146, 0.02328995593416039, 0.024866294297680724, 0.006019885422574589, 0.02658316574525088, 0.0526268569228705, 0.024899930285755545, 0.04648346235626377, 0.03368888465047348, 0.07360978372162208, 0.014660257184004877, 0.03197033409378491, 0.04727729319711216, 0.02763200223853346, 0.04632295065675862, 0.039409640958183445, 0.08752464447752573, 0.04614011515513994, 0.026939995914290193, 0.02308318616996985, 0.04332172771682963, 0.024532841780455783, 0.015356797102867858, 0.040134151495294645, 0.0555789237114368, 0.029948697847430594, 0.07511690011597238, 0.07908622501417994, 0.06610050346353091, 0.0349725329579087, 0.032115216163219884, 0.06107580004027113, 0.04270667654054705, 0.032298474689014256, 0.030640422155556735, 0.03708386517246254, 0.05241447281150613, 0.04359006605227478, 0.01772809715475887, 0.03135973209282383, 0.09075548048713244, 0.04912904812954366, 0.0419159144803416, 0.03574855967599433, 0.039322275333688594, 0.07873406109865755, 0.03495109973300714, 0.014509347020066343, 0.024559983976359945, 0.04013643731013872, 0.07695644671912305, 0.04817339198780246, 0.05323803408828098, 0.03523851126374211, 0.0330170888628345, 0.048426093271700665, 0.03410804223676678, 0.042246366865583695, 0.04032605604152195, 0.019270693774160463, 0.07766807728330605, 0.04050696938065812, 0.025268658937420696, 0.020222169769112952, 0.0060430784651543945, 0.003509040270728292, 0.005281230942273396, 0.032892560193431564, 0.004548017795968917, 0.03316218986583408, 0.036700824202853255, 0.040601181317470036, 0.027685039822245017, 0.023119716533983592, 0.04267559910658747, 0.021205676857789513, 0.02375355332333129, 0.029119739301677328, 0.01377911823510658, 0.08682980871526524, 0.018202919527539052, 0.05612043918517884, 0.09444747964153066, 0.027456191164674237, 0.022781911320635118, 0.02051004885288421, 0.0482959725195542, 0.020429416363185737, 0.038776833898737095, 0.021223636831564363, 0.007401899374599452, 0.03072412157052895, 0.05141962014022283, 0.05187816350371577, 0.09945454963599332, 0.04917966631182935, 0.02734571877226699, 0.05617391463601962, 0.0582284465781413, 0.0031452181428903714, 0.06159296193800401, 0.027370844181859866, 0.019164982259098906, 0.035582292621256784, 0.022945553027966525, 0.021334647281037178, 0.024339662595593836, 0.0487525751668727, 0.022116635300335474, 0.04099015204701573, 0.02535274612455396, 0.0124540757133218, 0.0025131172833425808, 0.030920026292733382, 0.06472209774074145, 0.041944691256503575, 0.03437331550230738, 0.019500368071021512, 0.016815324161143508, 0.02986177380080335, 0.06718982040183619, 0.05012437206460163, 0.03754274992388673, 0.024837033270159736, 0.03174500321620144, 0.05326835824234877, 0.02927532870671712, 0.04501867435465101, 0.03613722241425421, 0.020369246740301605, 0.02124979753716616, 0.02624020260554971, 0.06624574918532744, 0.04781793293659575, 0.09569226909661666, 0.017847848248493392, 0.11527557217050344, 0.023726923209324013, 0.03245511979912408, 0.022284882034000475, 0.02989468619489344, 0.012449381629267009, 0.030280886858236045, 0.027786656537500676, 0.012182483987999149, 0.015964737576723564, 0.02950494919787161, 0.07392335595795885, 0.034918823730549775, 0.04121195772313513, 0.048407936628791504, 0.02689270069822669, 0.07717498694546521, 0.05568849068367854, 0.024308078645844944, 0.06794771645218134, 0.03666317505121697, 0.016672881902195513, 0.046479128213832155, 0.02407902775303228, 0.04334059682150837, 0.08410733644268475, 0.019274929582024924, 0.04266111609467771, 0.016303006632369943, 0.032973547058645636, 0.02451002445013728, 0.0200529823632678, 0.03127084877633024, 0.013297144341777312, 0.018656204774742946, 0.02173600259993691, 0.03299441254057456, 0.03633483407611493, 0.10554748558206484, 0.04809302852663677, 0.040508902675355785, 0.024396835797233507, 0.05834921626956202, 0.02676950975001091, 0.021720237527915742, 0.0691318724420853, 0.040065710636554286, 0.03664645446406212, 0.08424772109719925, 0.0066376027643855195, 0.04160404176218435, 0.07036888418952003, 0.025252595150959678, 0.009186546067212475, 0.04035894431581255, 0.0422096491092816, 0.042092326693818904, 0.013096240327286068, 0.03739725558261853, 0.03714751546795014, 0.012712267962342594, 0.032708192156860605, 0.023608738047187217, 0.017104427788581233, 0.044350214520818554, 0.06565044284798205, 0.049449626239947975, 0.06798844551667571, 0.033975988189922646, 0.02581439166533528, 0.14149171620374545, 0.0630924676079303, 0.010228597475361312, 0.03689541161293164, 0.12442477614968084, 0.02387540469499072, 0.050655003942665644, 0.07156708161346614, 0.025502674798190128, 0.08286162672447972, 0.01840313427237561, 0.016654669598210603, 0.043502273692865856, 0.021107262509758584, 0.08049939293414354, 0.007160003760873224, 0.05589179832895752, 0.02213825035141781, 0.059002157795475796, 0.05692667131370399, 0.03206345878425054, 0.01641658862354234, 0.03937631852750201, 0.04690027475589886, 0.01691079403826734, 0.015822349123482127, 0.026241918822051957, 0.021778412628918886, 0.038113546834210865, 0.010566836845100624, 0.07246098364703357, 0.01135937078288407, 0.019880574036506005, 0.045739837805740535, 0.05114642444823403, 0.06739213727996685, 0.03031862506759353, 0.043694456544471905, 0.0511643361824099, 0.03925301440176554, 0.048157090714084916, 0.03982068315963261, 0.04833351405977737, 0.026256064156768844, 0.07257144490722567, 0.009823313412198331, 0.060422569076763466, 0.06757226394256577, 0.06165454535221215, 0.07434583094436675, 0.0359108376869699, 0.017971239576581866, 0.08921916058170609, 0.06997929376666434, 0.010910204455285566, 0.011055581908294698, 0.049528946983627975, 0.03325816440337803, 0.04514459455094766, 0.03092486695095431, 0.07193483805167489, 0.02853382298781071, 0.03510804170218762, 0.05684695723175537, 0.041247079861932434, 0.04974205468897708, 0.027089881914434955, 0.01620985411136644, 0.021363388805184513, 0.013980960138724186, 0.042205593272228725, 0.08609668555436656, 0.0705115991877392, 0.04154894100793172, 0.04911902913590893, 0.013113776349200634, 0.014433404903684277, 0.04588170304486994, 0.02705080041778274, 0.026899454242084175, 0.03664643219963182, 0.06554855339345522, 0.04734122550871689, 0.04379914760647807, 0.05708156866603531, 0.01869845338660525, 0.04121451442188118, 0.0213744579377817, 0.027085909568995703, 0.005674953272318817, 0.029992330564709846, 0.023739951611787546, 0.006390833559635212, 0.06022486835718155, 0.024115218584483955, 0.014635230108979158, 0.010636545848683454, 0.05296362127410248, 0.04047438909765333, 0.23861258989199996, 0.15936346346279606, 0.09013293733005412, 0.14679695887025446, 0.19410182285355404, 0.1393062694114633, 0.1280729885911569, 0.23429481923813, 0.14851161686237901, 0.10542277508648112, 0.11282685591140762, 0.0974274029431399, 0.1366087852511555, 0.09360498617752455, 0.09634683592594229, 0.20791960327187553, 0.16820857243146747, 0.08115447184536606, 0.18616750719957054, 0.17045064509147778, 0.15799325105035678, 0.22460483451141044, 0.0729025540931616, 0.24261191982077435, 0.12006790173472837, 0.09106772427912802, 0.11400306349969469, 0.08698408637428656, 0.1382439592271112, 0.20607935904990882, 0.21062286134110764, 0.16431752184871584, 0.23020695109153166, 0.13122649281285703, 0.16532936599105597, 0.12122405649279244, 0.13458763511152938, 0.16121479537105188, 0.10725159765570424, 0.0838910746097099, 0.16743666463298723, 0.16079867316875607, 0.105423509812681, 0.12378430270473473, 0.13055021816398948, 0.18951039266539738, 0.16170980787137523, 0.13373330439208075, 0.09576324067893438, 0.10457156880875118, 0.07461934204911813, 0.13231958728283644, 0.14778140292037278, 0.12042678208672442, 0.09596859294106252, 0.16448008187580854, 0.1262447820045054, 0.1271974918199703, 0.14756761986063793, 0.181392707163468, 0.1648160076001659, 0.11531121010193601, 0.13038553559454158, 0.14314531028503552, 0.10385804576799273, 0.0971968770318199, 0.04903485474642366, 0.09532080934150144, 0.1419460293254815, 0.09524562978185713, 0.08807732185232453, 0.12297415945795365, 0.1671407258254476, 0.12941510329255834, 0.2017477696062997, 0.13408870407147333, 0.1175291184335947, 0.30586230161134154, 0.09534259137581103, 0.10349317628424615, 0.17219831381225958, 0.21741042524809018, 0.12706181238172576, 0.21856350009329617, 0.10213209970970638, 0.08773806388489902, 0.1707409881055355, 0.1738408944220282, 0.12918399850605056, 0.09203547742799856, 0.10981574014294893, 0.17184058378916234, 0.1803681129240431, 0.1777508549275808, 0.100838573416695, 0.15465569420484826, 0.11055495633627288, 0.18858778435969725, 0.1236477104248479, 0.12690848467173055, 0.16980291344225407, 0.12112662734580226, 0.11833286436740309, 0.0664941014838405, 0.10346150884288363, 0.09708571073133498, 0.20049480168381706, 0.13240603264421225, 0.09154211249551736, 0.11917612966499291, 0.151482523069717, 0.17856215592473745, 0.08089227849268354, 0.10581125228782184, 0.12609103869181126, 0.09996042717830278, 0.13591517403256148, 0.11629589163931087, 0.1381605863571167, 0.09931006090482697, 0.11488244912470691, 0.15603457490215078, 0.12171614493126981, 0.18425408721668646, 0.11269204478594474, 0.1494482220732607, 0.16733246709918603, 0.11588146153371781, 0.0959646595583763, 0.2316140927723609, 0.14057712309295312, 0.1442853975459002, 0.09213379715220071, 0.11470805926364847, 0.166630054009147, 0.13347101456020027, 0.17177192028611898, 0.19415841903537512, 0.10878342014621012, 0.12832114793127403, 0.1521650466020219, 0.16360099310986698, 0.22097622219007462, 0.1374792354181409, 0.13271623553009704, 0.1881501844036393, 0.06768993887817487, 0.21693795919418335, 0.17316144338110462, 0.06127194967120886, 0.1898698741570115, 0.17878135666251183, 0.1477564370725304, 0.12312719773035496, 0.23220068629598245, 0.13295069482410327, 0.11688953556586057, 0.13942946592578664, 0.2245842621778138, 0.08716555632418022, 0.10414893797133118, 0.16972528479527682, 0.08792203487246297, 0.09183166141156107, 0.08395360797294416, 0.06460849719587713, 0.12441214479622431, 0.10626828909153119, 0.16973373043583706, 0.08019555767532438, 0.2246181041118689, 0.10047901028883643, 0.0890651649388019, 0.15354012750322, 0.14167375018587336, 0.13031589245656505], [0.07136757747502998, 0.015459865644515958, 0.07822849525837228, 0.034932423586724326, 0.027855396110680886, 0.05272604124911595, 0.02321242747711949, 0.005947200870650704, 0.04067776353622321, 0.05372455270844512, 0.02207875979365781, 0.027281823568046093, 0.07057115653879009, 0.1388898355071433, 0.04806280085176695, 0.007663970736757619, 0.009249507093045395, 0.038209198537515476, 0.025883990274451207, 0.00789265983257792, 0.056873886060202494, 0.03139029744488653, 0.008372027859877562, 0.07103595620719716, 0.05965479133010376, 0.028980601455259603, 0.02615242137835594, 0.035863084194716066, 0.048712491770857014, 0.05393063969677314, 0.010735774703789502, 0.054189434013096616, 0.02319386079761898, 0.007194041900220327, 0.0234910222934559, 0.014457673132710624, 0.013251172931632027, 0.034605329419719055, 0.06101557104557287, 0.021162311313673854, 0.06072650823625736, 0.09188926691422239, 0.025834973275777884, 0.0754349326598458, 0.03451301367022097, 0.018139783169317525, 0.007758285182717373, 0.027167890912096482, 0.010974642354995012, 0.03859124502923805, 0.0529373232711805, 0.005251875754765933, 0.04246891840011813, 0.031208998188958503, 0.007205705678643426, 0.016168306829058565, 0.026479593470867258, 0.013052142840024317, 0.009290517245972296, 0.1139355354825966, 0.03856720315525308, 0.04212266198010184, 0.03139124368317425, 0.017605908105906565, 0.043785826055682264, 0.0476723829342518, 0.0356555240432499, 0.019752778061956633, 0.030188331766112242, 0.026512516997172497, 0.0194264278979972, 0.055457745838793926, 0.04545571769995149, 0.02582744047685992, 0.0038871781953275786, 0.029890322366554756, 0.04371027913293801, 0.07190029849880375, 0.02308534581970889, 0.027437669014034327, 0.05645863217068836, 0.05246534703474026, 0.012543778175313491, 0.02429586289508734, 0.06104098218202125, 0.06633898519794457, 0.06863811417133547, 0.03844608836516272, 0.05023399098718073, 0.016599643058725633, 0.010846888126252452, 0.027550993108889088, 0.08075652483967133, 0.02136619597877143, 0.023913534387247637, 0.0189464309005416, 0.010949664447252871, 0.03054535303817829, 0.02241337006125832, 0.05369009479181841, 0.04069485890795477, 0.014046516826056177, 0.004829057988899876, 0.04565899565932341, 0.07301674835616723, 0.011742331043933518, 0.08175501774530858, 0.03937860805308446, 0.05726716495701112, 0.05913489461818244, 0.04277328058378771, 0.018000120253418572, 0.038635499295196496, 0.05126485266373493, 0.07196645354270004, 0.018419333500787616, 0.0429446053749416, 0.051523639558581635, 0.032589133115834557, 0.09130364560405724, 0.01746148060192354, 0.06328440184006467, 0.016884483047761023, 0.03193778349668719, 0.04339688501204364, 0.07018047515884973, 0.08464672937407158, 0.04382650316983927, 0.039085036696633324, 0.03028798550076317, 0.008178302268788684, 0.048740069978521205, 0.0786724331555888, 0.03513955329253804, 0.011052004756493261, 0.05200343061005697, 0.030322315396915656, 0.03625730190833565, 0.034597514604683965, 0.025056196900550276, 0.024477407059748657, 0.010969575341732707, 0.027595477440627292, 0.022529302805196494, 0.04818800858629402, 0.05791019510070328, 0.04915578399959486, 0.060441627429099753, 0.030753432693018112, 0.028325450184638612, 0.06961836508708075, 0.052260774027672596, 0.014892800809320761, 0.03948343641241081, 0.07757281520753168, 0.019085008425463457, 0.01681269695836818, 0.03362203198776115, 0.029437981502269395, 0.04281147150322795, 0.04104896725038998, 0.054251585170277394, 0.019331607400090434, 0.04657246812712401, 0.06507651778520085, 0.0367953404202126, 0.058280537923565134, 0.03657847373688128, 0.033503336599096656, 0.06762419201550074, 0.06639398576226085, 0.04709966015070677, 0.04474699635466095, 0.02202799318183679, 0.041024335369002074, 0.017350182570226025, 0.025508248327241745, 0.054005017736926675, 0.08170602857717313, 0.044441194404498674, 0.030340674275066704, 0.013607895489258226, 0.061738986914861016, 0.016083089722087607, 0.0025715416995808482, 0.03957046807045117, 0.07160909459344111, 0.06931991782039404, 0.06807531390222721, 0.0411775703105377, 0.06321837296127342, 0.056758611972327344, 0.047067042760318145, 0.036653990973718464, 0.03108347133093048, 0.046538010210497305, 0.009339484149677446, 0.0487575995066436, 0.021922721389273647, 0.02914310767664574, 0.059256172680761665, 0.06792243148083799, 0.01976133502466837, 0.06512125444714911, 0.036738284106832, 0.00407894428462896, 0.027496020375110675, 0.04105185049411375, 0.07625246027600951, 0.04926777408400085, 0.005132437290740199, 0.048637809450156055, 0.05687547425623052, 0.023935412900755182, 0.11242035194300115, 0.0412949149904307, 0.028093276705476455, 0.054546614846913144, 0.0679282944474835, 0.017634261857892852, 0.020258998847566545, 0.022922908246982843, 0.04482248019485269, 0.06029727970599197, 0.0520956906984793, 0.05474077181133907, 0.038715643822797574, 0.04245878066285513, 0.05337649286957458, 0.031418179933098145, 0.04700883982877713, 0.1425162807572633, 0.03845982551865745, 0.029453206661855802, 0.04672411858337, 0.05905046418774873, 0.07475642414647155, 0.04753091845486779, 0.009170861703751143, 0.10586406351649202, 0.10151116701308638, 0.010663712164387107, 0.033106699484051205, 0.03398472697881516, 0.04340629173384514, 0.016347257187590003, 0.00865332965986454, 0.0429904849443119, 0.07776899452437647, 0.0484093763952842, 0.031198823344311677, 0.03233606446883641, 0.03047730180696817, 0.0732754981436301, 0.027022554277209565, 0.017360847232339438, 0.006096869328757748, 0.06980860722251236, 0.020561923120112624, 0.028218334155099, 0.0518368147459114, 0.028338409938442055, 0.09319903881987557, 0.0882558677403722, 0.012632141988433432, 0.029796175367664546, 0.047780547247384675, 0.0062592294398200465, 0.043052513647126034, 0.01926054490468232, 0.023715657407592516, 0.029427849331113975, 0.04409350935020484, 0.03549350949469954, 0.013051874739176128, 0.05051898682722822, 0.0771357050689403, 0.06316019600490108, 0.029987508460180834, 0.016657493470120244, 0.06550788370077498, 0.020341989511507563, 0.13689697603695095, 0.03358102090714965, 0.022454863537859637, 0.07697362743783742, 0.03268827662395779, 0.0486443069530651, 0.029840038150723558, 0.0809275230858475, 0.08044383575906977, 0.0494010415422963, 0.0307650769900647, 0.00924894398849574, 0.04966193613654468, 0.02639752121467609, 0.050790957975550555, 0.052452934614848346, 0.02315131718205521, 0.04348165311967023, 0.039734004021738656, 0.07024927224847488, 0.021942354906059336, 0.03401190442673396, 0.05024012483772822, 0.007990474896359956, 0.024753133475314826, 0.06113975461630616, 0.06583221707842313, 0.07323945945245214, 0.07010515459114686, 0.05162010020285379, 0.032817521641845815, 0.0660948408767581, 0.024376747714995872, 0.006193594826982007, 0.021433532892842777, 0.021267545998853166, 0.02776700261165388, 0.06118239100032952, 0.010129842667083722, 0.07905544072855264, 0.1546765337116085, 0.060492798511404544, 0.025830954546108842, 0.016466748529637698, 0.07842326449463144, 0.02337337333301548, 0.07461955727194436, 0.0443863459804561, 0.04784125121659599, 0.013667618895851774, 0.0636575833777897, 0.04555143248580862, 0.052533001216943376, 0.03723246540175751, 0.04182480843155645, 0.03811616661550943, 0.009859223155217478, 0.03902424738043919, 0.012879274381702999, 0.028732495920849033, 0.03412981313886121, 0.0739848503144458, 0.029280857706908137, 0.028131400831625797, 0.06980781312449835, 0.055424178499379195, 0.05848381588293705, 0.031621977395843714, 0.0271278501895722, 0.029061118912068196, 0.21989400760503486, 0.136525857669767, 0.1372177471057512, 0.1166790995921474, 0.19000754255102947, 0.12006960867438465, 0.13278708094730973, 0.11909186621778645, 0.0808681661146693, 0.1645685755647719, 0.18927096098195761, 0.21311659627826884, 0.20622237090719864, 0.14141243998892605, 0.19174397515598685, 0.11470283454400487, 0.2637057605898008, 0.13061091100098565, 0.056792249815771356, 0.18738845887128264, 0.1330903818598017, 0.21528163400944322, 0.17350965907098725, 0.1673587688128464, 0.12159703022916801, 0.1361202888074331, 0.11762080335756764, 0.13030066358624026, 0.1292134469258599, 0.14304728741990402, 0.08096420002402738, 0.12910660734632984, 0.10851110389921814, 0.14405150228412822, 0.140792494348716, 0.1281872348044999, 0.08440993973636068, 0.18265539722051471, 0.19772191531956196, 0.11167343967827037, 0.2619901823345572, 0.21752578468294814, 0.18705698603298515, 0.15771003265399486, 0.06319615305983461, 0.1836174284107983, 0.08581133719417267, 0.14544479548931122, 0.14855975256068632, 0.1237877611129079, 0.13374552014283836, 0.15304633212508634, 0.11770322627853602, 0.110415410308633, 0.2491064986679703, 0.20195730758132413, 0.14653453545179218, 0.0906826980644837, 0.13671945431269705, 0.2150556945707649, 0.3820501430891454, 0.17033020936651155, 0.07570299640065059, 0.13273686723550782, 0.15398828079923987, 0.245946834620554, 0.19060523860389367, 0.20453113509574905, 0.0843238877132535, 0.16215564566664398, 0.11242897569900379, 0.1303723847377114, 0.1543043614947237, 0.08211125605157577, 0.07888761887443252, 0.13084761158097535, 0.15519281616434455, 0.12091851429431699, 0.11847477784613147, 0.06852524835267104, 0.134467585303355, 0.12911698257084936, 0.18187207519076765, 0.1212591897638049, 0.178539416519925, 0.12453316681785509, 0.14838065748335794, 0.14014942338690162, 0.15108269843040034, 0.15143127035116777, 0.1035135705024004, 0.09097403555642813, 0.31806997780222446, 0.12972465308848768, 0.1891064119990915, 0.1360610208939761, 0.09352193985250778, 0.10228992483462207, 0.15773234161315486, 0.18272640591021627, 0.15924800012726337, 0.08201442804420367, 0.0969523393723648, 0.16291269566863775, 0.1727464937721379, 0.10201063982094638, 0.24888275598641485, 0.10576842294540256, 0.21593558485619724, 0.1729232881916687, 0.11373275847290643, 0.18641323229530826, 0.158580141433049, 0.13543521228712052, 0.15159332571784034, 0.12148996058385819, 0.22564253507880494, 0.15583230997435749, 0.18838353047613055, 0.186365794215817, 0.20819082856178284, 0.12877278932137415, 0.10028913922724314, 0.09990023158024997, 0.20267471205443144, 0.10960942308884114, 0.1747166138375178, 0.09243363223504275, 0.1662993975332938, 0.06322839195490815, 0.19356934673851356, 0.123213858314557, 0.12583815929247066, 0.17248555464902893, 0.13750334037467837, 0.2013762207934633, 0.10110711955348961, 0.2966108074178919, 0.15581567102344707, 0.1524110240279697, 0.13190649304306135, 0.09678546746727079, 0.18487769906641915, 0.17114349931944162, 0.2560757996980101, 0.1949631594470702, 0.2893102710368112, 0.11630779568804428, 0.16000833042198792, 0.08553640116588213, 0.20065795542905107, 0.15450061502633616, 0.08573113329475746, 0.1487045455724001, 0.14008467842359096, 0.08750160821364261, 0.1769735146081075, 0.12455191346816719, 0.13599514786619693, 0.1392995603964664, 0.11574244985240512, 0.1199985777202528, 0.17899117665365338, 0.1010654034325853, 0.1744367796345614, 0.1273938937811181, 0.1904049626318738, 0.16142157255671918, 0.17086737585486844, 0.1340893274755217, 0.1341899181716144, 0.14495512645225972, 0.21031129290349782, 0.1219557250442449, 0.11520273779751733, 0.09997403816669248], [0.04510022154136095, 0.023447704988939222, 0.017688570369500667, 0.013308231100381818, 0.055455059264204465, 0.03535263873345684, 0.027562960240175016, 0.017183336640300695, 0.037898583759670146, 0.01899647577374708, 0.027525092154974118, 0.03909243590896949, 0.0054070676469564205, 0.018186876150139142, 0.006494555655081058, 0.09163001988781616, 0.036946831314708106, 0.009903908794512972, 0.03975380081101321, 0.017462315518059768, 0.020280174176150467, 0.036376026982907206, 0.05653967469697818, 0.051629618246806785, 0.02867269366106484, 0.02864613590645604, 0.04304603840864729, 0.058918985305354, 0.03166666952893138, 0.04197392445348669, 0.022727959039912093, 0.008692413939570542, 0.03725778376974631, 0.05685830095899291, 0.03663135918031912, 0.0175856938585639, 0.010658121937012766, 0.022029820720490534, 0.057573504964238964, 0.027809293897007592, 0.03337537920742761, 0.01124986225477187, 0.044371343465172686, 0.05096243861771654, 0.013838973372912733, 0.019762709853239357, 0.03290959990408737, 0.003989726537838578, 0.0711164643871598, 0.04350895673269406, 0.015684285535826348, 0.018566981925687287, 0.04955814307322726, 0.043359777628211305, 0.02634173953993013, 0.04148867490584962, 0.02398876033112174, 0.0326823208888527, 0.037460805688169785, 0.017323730571661144, 0.09193013698677532, 0.04496409310377203, 0.014632404381700326, 0.04724974096461665, 0.02769851536868373, 0.04074129508808255, 0.04300193257222418, 0.03020103176822886, 0.02437363626086153, 0.012975952104170574, 0.02175218513002619, 0.06564167066244408, 0.034309898983337916, 0.002327055294699676, 0.006828996156400535, 0.01712403718556743, 0.02633503423567163, 0.05345916812075302, 0.024610693071736023, 0.05620016068860423, 0.07270189962582663, 0.04933304968290031, 0.015286829275282798, 0.025298780856246594, 0.05738883635785896, 0.039917340473039076, 0.039848001615609974, 0.04577289306325838, 0.04562681613606401, 0.01640299062273698, 0.024426992968074046, 0.06048406343325041, 0.05541434133192524, 0.04014833764813375, 0.03261670390202198, 0.0503300063428469, 0.024878869990061503, 0.06353569304337725, 0.05887825624085963, 0.05685833435563836, 0.040729008833295666, 0.06486951795523055, 0.05459308442368638, 0.032032581730163656, 0.02677483094885247, 0.04657296907680575, 0.1064041318022646, 0.03518359604640864, 0.05204343608056661, 0.00900066126632737, 0.0482195721269818, 0.028498235151346307, 0.029432098126562778, 0.007157624713727273, 0.0913795227825176, 0.011313659124425612, 0.008811859825073043, 0.008403135907428805, 0.08513301421771757, 0.027275975444354117, 0.043756206941907294, 0.024388353049289435, 0.007769588091832702, 0.05888798208616208, 0.027614118334895466, 0.014559794508386403, 0.07444523420417681, 0.06876205283333547, 0.03857937808788847, 0.07758470441331156, 0.032342484046239406, 0.0563451095513301, 0.05386365344747901, 0.04827974546060432, 0.028412186838977505, 0.03938322792237159, 0.04414676957821939, 0.028391907653713133, 0.059410591347841546, 0.0272390628742869, 0.05500525840034243, 0.036609580856747925, 0.05715709332434926, 0.05025176542403642, 0.08220992458518595, 0.022970064310356975, 0.025955386736313812, 0.04110483612748794, 0.059510061400942504, 0.010928877818514593, 0.029141892409825232, 0.015584314533043653, 0.05024620673793834, 0.040273018457810394, 0.08353306257049553, 0.0393754353717668, 0.038369721369235776, 0.042634064811863936, 0.015877028708928265, 0.032294949487550184, 0.10155073832720518, 0.008619782729510916, 0.047214058504323475, 0.00944736737437779, 0.029495082344510593, 0.08528854610631242, 0.0242938795054215, 0.04928456517518498, 0.014369806558534037, 0.031138616614043713, 0.041354780332767405, 0.04856342769926414, 0.01709490046778228, 0.026727865988505073, 0.0412049258738989, 0.06182174380228389, 0.03055981193028856, 0.02323236156371422, 0.07081402436597273, 0.0235513533334597, 0.06212360494828317, 0.043880720768356696, 0.020404971874086186, 0.03911553154466674, 0.02564947531936923, 0.044528756698127836, 0.0438495134585537, 0.04827777505852282, 0.022159726249810774, 0.04191774016362615, 0.01613101576367626, 0.05706075513444375, 0.07450778983184136, 0.0038672937398587237, 0.014006250676175114, 0.03740040599950589, 0.06027408759109676, 0.05332978209480643, 0.0033669507638478535, 0.07526242043240927, 0.020875525042356458, 0.003612129453358648, 0.06522781943203881, 0.01476731291404576, 0.07574759947601706, 0.08214222587412223, 0.06829791367636062, 0.05083824762550648, 0.06651962394244038, 0.0321648324461421, 0.03767389483982697, 0.08073257573414594, 0.0327215174183948, 0.04230200938764028, 0.008840426944516366, 0.03231581125874072, 0.058331994732725434, 0.11445883865235373, 0.07541407088865526, 0.02827302858349867, 0.02136332943337038, 0.0015611903177159547, 0.035336151922820136, 0.02962977101560682, 0.0793073998647742, 0.03652146195236128, 0.015856601094128564, 0.04668476991355419, 0.06151255394797772, 0.04366875968116801, 0.005395091702666832, 0.007885537070251303, 0.04266228868800681, 0.03264103150286246, 0.07388448968413286, 0.02861657801986439, 0.033546473932801746, 0.018951288257085253, 0.012196011484775227, 0.07154320672270842, 0.02235680727608269, 0.012882807932328433, 0.032409488849225454, 0.060605653197853826, 0.024503187414666172, 0.019279712723800912, 0.025298589753219858, 0.06048655333870556, 0.010387238035036717, 0.060858462093165144, 0.059640909457812086, 0.0012570549529300479, 0.032413403678219765, 0.04248534212820232, 0.048198484000749886, 0.04663110892579425, 0.052964638016419485, 0.0928198681504, 0.011961580948991468, 0.030712662810401525, 0.060089634207542986, 0.04092545532330405, 0.04142911384406034, 0.045771935692755505, 0.013870042457710952, 0.04961230872140732, 0.03439769134274684, 0.04294554048101418, 0.0103924868744798, 0.024798070517135784, 0.05246951419394463, 0.02429970722005237, 0.027662693755701184, 0.04214733467961196, 0.047978674701880664, 0.02116833013133146, 0.0389620108762756, 0.015846673013584223, 0.04884370348008815, 0.051712586646317504, 0.07819328777259216, 0.019312046242703218, 0.0054861866192368325, 0.009315262304880889, 0.030036736970942002, 0.02911835334089119, 0.025040222171810456, 0.03549103443219792, 0.04964242136338726, 0.04189810664684046, 0.041714580947882496, 0.06314773534541018, 0.021733412504545413, 0.022342316842696164, 0.041177125021931715, 0.05261557627818547, 0.042355833647889085, 0.02209645630500745, 0.010128544836334186, 0.02679189663467696, 0.06726272156811319, 0.058994524806621484, 0.009979809165088227, 0.022798490899731405, 0.03386632102774456, 0.027004850344383158, 0.04599885847710539, 0.04054341254231986, 0.01066991280822549, 0.010815838522830745, 0.07244680862640962, 0.032285735724144615, 0.035166916277376004, 0.04794025742739905, 0.10932377044809982, 0.049322752383886836, 0.03878071904182434, 0.024303212012455333, 0.05278339442156721, 0.02294358448125422, 0.0760783079022076, 0.04488646816753317, 0.01376973192236619, 0.005023802177674952, 0.03215031974832527, 0.04161331118666567, 0.02433089968690183, 0.04379100995720364, 0.027412450835981872, 0.06329341151285917, 0.08408296431298368, 0.059860785549972206, 0.024121114947774913, 0.09583824954461306, 0.009452079084439902, 0.05979012195894029, 0.05078418587800115, 0.028347428888082504, 0.04046050351462327, 0.02492723575414857, 0.049918010481633246, 0.05825303393066861, 0.0207468403459643, 0.05314954411005601, 0.013183009450585814, 0.022451566546806134, 0.01161345431683003, 0.014177626489981776, 0.05526577078853734, 0.05305199621943757, 0.08174147355020978, 0.0809383658634033, 0.12693821510765702, 0.19715782371349633, 0.1747595248161815, 0.09838508514803834, 0.13845707435393706, 0.1369372894987464, 0.1282646259642206, 0.0765034175128676, 0.08362560096429661, 0.12114073557313532, 0.1624996608006768, 0.1854479208122939, 0.09184886439470574, 0.18185522843850777, 0.0541343518125359, 0.1713716800441034, 0.19780469447141513, 0.12072166704456322, 0.15252795681590214, 0.11094050947576761, 0.1204396880348213, 0.13419046736089513, 0.15395166323287413, 0.22518176527228206, 0.09651010841480456, 0.10179572127526626, 0.1056643515767064, 0.10660778454621322, 0.12205939565319568, 0.23820066824555397, 0.1476991581148468, 0.19088363304035738, 0.1631181369884871, 0.19101828831480816, 0.13403624907368794, 0.13879228761652485, 0.10967114751110785, 0.10729225992690772, 0.14775366144021973, 0.11911422712728381, 0.16107660747366026, 0.17819056258304045, 0.13092452776618302, 0.13190046680392697, 0.07868955450248905, 0.06018583138938993, 0.10379443629062735, 0.16249796870397404, 0.25420196587219834, 0.14488419197732583, 0.07672609892324544, 0.13080416625598446, 0.13205697090597823, 0.10875541149289347, 0.13807684241328388, 0.19636378507129848, 0.1805917517049238, 0.1544173015281558, 0.15668531967094168, 0.08950924384407699, 0.19490065576974303, 0.13087572413496673, 0.07360470743151382, 0.16954485385213047, 0.14814964175457135, 0.13576922327047214, 0.10850047634448856, 0.15768361219670624, 0.09622703102650121, 0.15700132615165785, 0.13793246500426903, 0.14122685854090378, 0.12075984312104993, 0.1526091923005879, 0.1649498168262653, 0.06469925443525426, 0.15777448075823486, 0.2824507188051939, 0.13459734240313992, 0.1321794994873926, 0.2109870035201311, 0.1984478990198113, 0.1402307627722621, 0.10231382941128686, 0.14209117856808007, 0.13643313373904675, 0.19929835572838783, 0.18110975594026968, 0.1161209971178323, 0.14225655875634402, 0.10585438591078855, 0.11163347502588294, 0.19023057277081534, 0.10164273495320231, 0.12282873562071472, 0.13781854533590376, 0.0903380372619722, 0.18557157745817676, 0.11373248387826607, 0.09255951532395557, 0.18631452665431425, 0.1408054819330573, 0.15087192849023268, 0.33892168547026813, 0.15067819826072082, 0.10048429438029416, 0.20946232049027458, 0.19354359421413392, 0.0981179416703526, 0.11713008789229207, 0.12739787169266492, 0.06320523694739677, 0.08600685599958524, 0.10173839778872207, 0.19195945031242445, 0.14308295503724366, 0.10541757263126783, 0.1200466020964086, 0.12496184615883976, 0.10370924515882507, 0.1544963996275328, 0.1582739016157575, 0.13841285719536245, 0.12328881522989832, 0.12235153466463089, 0.10524810320930555, 0.10617321255267598, 0.13490603130776435, 0.13041167403571308, 0.13618598371976987, 0.10896596621023491, 0.11864240674185567, 0.11834683158667758, 0.16285123099805787, 0.1469902734970674, 0.12296784378122538, 0.14884170930599794, 0.17087356536649168, 0.20649071666412055, 0.107555477443384, 0.1108739165647421, 0.1415099433506839, 0.0922630495915655, 0.1181513350456953, 0.11141546914586797, 0.09720449888845906, 0.1031391866854392, 0.14505031431326643, 0.22546128777321428, 0.1265033907839097, 0.15686346479924396, 0.05820027465233579, 0.11248604685533792, 0.12063310656230897, 0.2810471988050267, 0.1466278827865608, 0.11931917862966657, 0.22146557952510193, 0.12599346111528575, 0.12023648057947867, 0.23754711815854535, 0.07023976533673704, 0.12109755742130801, 0.11345072751282714, 0.28087653452530503, 0.22218307305593044, 0.24861270328983665, 0.14042205875739455, 0.06380485516274348, 0.08292702477774583, 0.13994460547110066, 0.14392149285413325, 0.12548163154860958, 0.12269897109945305, 0.11960813382756896, 0.1721235943841748], [0.04599257619702257, 0.09335583235952072, 0.03194139775587246, 0.01453769891668344, 0.03663409770524595, 0.05624287870887201, 0.019034080396522768, 0.06162089266581461, 0.05333925932063721, 0.05113165942020714, 0.02796282384224469, 0.049741112161427736, 0.057520166810718365, 0.03681413159938529, 0.059380363672971725, 0.049966791848419234, 0.015169407597568352, 0.07047320046694949, 0.019802550195890944, 0.03581149750971235, 0.04766605983604677, 0.04001387904281728, 0.04324952788010705, 0.05462842178530991, 0.04109038651222363, 0.021345879686123226, 0.03463284454483073, 0.030160423302731942, 0.015355978885054355, 0.05815026132040657, 0.06760090342140757, 0.04598770770826377, 0.018383882961643394, 0.03744515750440769, 0.021597796148853377, 0.042121270453208126, 0.043624639001791365, 0.02242008278699359, 0.049904466286534443, 0.042419339224579744, 0.010335529823350953, 0.01787828001397429, 0.021220733178779483, 0.056964546820381656, 0.05328175029717386, 0.060900222742930055, 0.07078046444803476, 0.09834586264332756, 0.06637778467847966, 0.005562851865761331, 0.04225960306939669, 0.07692117244005203, 0.07849333065678366, 0.04473114779102616, 0.055998411553446203, 0.053031219795229845, 0.026675379449443426, 0.05813518087961711, 0.05660429349518381, 0.018615696499182377, 0.0965024420293048, 0.024760994674579706, 0.05816033968585543, 0.07468007199349813, 0.07367808357230388, 0.029704564658459276, 0.055528999437228777, 0.049293649062747136, 0.009974896147468826, 0.02342097654036479, 0.00598713444560417, 0.012575000328070018, 0.011243254357395926, 0.053497893386520445, 0.027756855597544927, 0.07194974037702195, 0.014605598935304442, 0.030319369070639368, 0.03828802946372889, 0.05431383280665614, 0.044452040892792866, 0.021996002906234935, 0.015646526917407755, 0.09491906996117905, 0.12794888665666804, 0.06913360164617188, 0.0719763092638459, 0.0357005835394375, 0.035066963828285225, 0.02491170074790716, 0.04249290461302735, 0.064260170183843, 0.025823117466643453, 0.0629870974808, 0.0400502368574962, 0.023673952418903355, 0.027911485776712652, 0.038803447314421646, 0.015296576457330957, 0.024019292286538985, 0.0692682717635762, 0.05209931608987972, 0.025536108551023062, 0.040782632713671774, 0.030850154944346286, 0.035831420464091934, 0.04158696123340633, 0.07877401090809144, 0.05328012128302362, 0.0525351423129905, 0.02970497098431224, 0.005528654164663749, 0.030511024997394998, 0.027679013583110645, 0.01847016319516115, 0.07003013830399141, 0.031640820525353774, 0.02944184438092634, 0.038414992377511226, 0.06365211374941282, 0.05209687813476194, 0.0411082982463995, 0.04119704426557291, 0.030704629061801825, 0.03387499302334618, 0.11961746262386441, 0.04443762838491239, 0.01865924943558639, 0.025430538044020068, 0.05003503603802528, 0.004301817725718138, 0.03788072397583164, 0.06791497289668769, 0.021157902956474572, 0.05099477028124966, 0.03871126515150536, 0.01834543600125471, 0.07890638036769815, 0.07549244168330915, 0.022881151307956316, 0.08047470168094151, 0.04508773490670137, 0.007299720946321031, 0.062167629148461856, 0.019198670197511092, 0.044653315053437836, 0.054456050565931946, 0.011376676739018876, 0.0638287968467921, 0.02570278935309034, 0.014862508196529234, 0.05664927506586537, 0.028929743930348195, 0.05378754991397727, 0.020405426439538132, 0.018086181553371716, 0.059782633688882925, 0.06941856408957392, 0.0444322478142567, 0.019763888012676034, 0.1215105403389316, 0.02558542797487462, 0.04041167761897668, 0.06235740744159557, 0.016377555366489105, 0.0727910760906525, 0.0067110572945239255, 0.06790513201849535, 0.038711480374331586, 0.017767841018212494, 0.028558786980283912, 0.015946193161653355, 0.02057727444480406, 0.06893866913742386, 0.024281878977490123, 0.029287613106134813, 0.034574426390463486, 0.027804113706224598, 0.07383165619103238, 0.031415530465892516, 0.07745547423837706, 0.03326420919620432, 0.06440222467062995, 0.02276056900882395, 0.05080970462586265, 0.04167502818745561, 0.06444330996600911, 0.0384433053113753, 0.0056636494355188916, 0.01942170041729696, 0.04398731543915346, 0.03103036324318964, 0.0191531431482872, 0.037809897112310864, 0.029446004118653946, 0.0775109497772064, 0.025634250159782823, 0.04101256490685046, 0.0381711708905641, 0.1134339401323814, 0.006554900610353798, 0.04914790239126887, 0.01136304255851428, 0.022730189193680417, 0.04748469749756623, 0.03813667586655356, 0.061805282966815867, 0.03212419615010731, 0.041573899434297346, 0.0866700688493438, 0.04980973113561049, 0.029159214136598166, 0.022219834645511582, 0.013269121773191728, 0.06264616968110204, 0.025860408532025758, 0.05948701029410586, 0.04608462848409545, 0.013887271416024305, 0.047531890668324195, 0.02805552736390382, 0.06276350322877988, 0.03885461097524967, 0.050408518145559356, 0.0545792916091159, 0.030791809149377514, 0.04065598150191363, 0.02199348331487272, 0.05262569175101817, 0.023581423301948234, 0.009143282568402356, 0.07950637707835995, 0.02691702829906717, 0.046853422973072156, 0.06242614515940659, 0.05023756813898217, 0.06341207350487821, 0.04759544819535222, 0.048099986161105335, 0.1254821362090297, 0.06428217486245558, 0.06314264421234839, 0.03818608063738793, 0.005557232416322222, 0.04857770290982444, 0.008886756440915633, 0.03074156389629934, 0.03176733815053012, 0.03917358975741081, 0.009424730014870875, 0.03826106352789793, 0.08557728608138859, 0.025336103462905157, 0.007577253563795239, 0.01660119043663144, 0.01896139445307199, 0.030063522935961373, 0.010225406240351731, 0.02588860457763076, 0.07274259158293717, 0.04045718982524704, 0.04736900038551539, 0.0762454692448955, 0.031610719015588984, 0.033225001534447074, 0.06606355935218744, 0.03440617409069091, 0.051023469131905586, 0.009451098521822132, 0.06026227260008454, 0.024939418108260725, 0.023484957091568504, 0.0482344892952824, 0.028568035995704122, 0.022222819934540894, 0.0485277600819245, 0.06891215962241404, 0.05384582334954757, 0.03924884724256117, 0.058474260731600225, 0.020528287132037804, 0.047510475997114554, 0.04006761795608327, 0.06292728779953904, 0.03354670028784312, 0.04711975750979036, 0.0022215914714251994, 0.05298464631778188, 0.009223778688465245, 0.02586916587461019, 0.04775711764523294, 0.042397764991619624, 0.025165066253975965, 0.09942543518263847, 0.02423873607767746, 0.04986489497241564, 0.03713140344189014, 0.05255329895589966, 0.02670644946192624, 0.029716017852479126, 0.019499180634738877, 0.017060928657883778, 0.0638687689206563, 0.06411807858967222, 0.017598033919057343, 0.021538680375670083, 0.03615780588006601, 0.030341581550601404, 0.061948383881826885, 0.024922213269746862, 0.014537013357767137, 0.024932488304330036, 0.05017392526497133, 0.04391811016830616, 0.016860394789546262, 0.03357560693984851, 0.06408965433365665, 0.03805563705100212, 0.02483515563653782, 0.044779628588003106, 0.0318754134059418, 0.057569293276173994, 0.05536970857065171, 0.016135943624249194, 0.031075701044755988, 0.008551504215574823, 0.049067345971707255, 0.02499353366147261, 0.04494242981309071, 0.035715022022486664, 0.037439795487443916, 0.06491739390185103, 0.045835626806365326, 0.07742025190964341, 0.032848287373781204, 0.0430506842531031, 0.024180340187740512, 0.07490714691812173, 0.040826541880960576, 0.09468290372751653, 0.030166104443196673, 0.03487887392111588, 0.031219570082612336, 0.06193693996465299, 0.022192373326106463, 0.041569825043552555, 0.02013068151427433, 0.051839371444657445, 0.017453704749641474, 0.06182630801049527, 0.04377387376734987, 0.027465549646876752, 0.1662995311198756, 0.18873410619562492, 0.12488178326748312, 0.11032400740077719, 0.1836899362388067, 0.11901212987140752, 0.17779165820684284, 0.232425601570867, 0.10783078454551287, 0.14606714568799362, 0.12517448631115258, 0.10920677086687647, 0.14336826629005373, 0.11778145606513135, 0.12782806501490995, 0.15551392862107605, 0.07846534426789731, 0.12592295708600432, 0.11415310349548236, 0.19057516678003594, 0.12349383352557197, 0.1509581066784449, 0.12527377082733437, 0.23673056275583804, 0.1390666892984882, 0.13893501745769754, 0.10564716343651526, 0.1181318165617995, 0.08633612465928309, 0.09884261176921427, 0.22680236346786842, 0.141753590432927, 0.20103959745028988, 0.14271805586759, 0.22518749465234578, 0.13405581208644435, 0.08357375452760607, 0.10617125328280963, 0.15110686275875196, 0.13383877841988578, 0.1789157002349384, 0.0884874326584395, 0.06679649697616696, 0.16795220493804663, 0.08243507734732702, 0.1707557271583937, 0.11593700386583805, 0.15113503468455747, 0.13087202823953703, 0.10164998573600315, 0.13585633656475693, 0.22305655118543655, 0.11901736943400465, 0.1420391391729936, 0.24457840336253867, 0.11923942744033411, 0.10875872147153132, 0.19446835474809632, 0.1211264863377437, 0.1506896421778947, 0.1417607447365299, 0.1350470245233737, 0.0876050784427207, 0.1701263859285973, 0.11751874320907518, 0.08743708589463495, 0.2914951537968591, 0.11473593433038332, 0.22280632867477834, 0.10390428898972459, 0.1264618750428781, 0.1731164543889463, 0.14535891416016966, 0.24141905101714656, 0.14257805712986737, 0.17478897323599085, 0.11769443925004452, 0.08332380661158822, 0.10583466704702005, 0.18894778535468504, 0.08057501778239384, 0.13321294012712315, 0.0810527679277584, 0.2178840638953261, 0.24367329489905387, 0.14201531623257324, 0.1276875616167672, 0.09043318801559508, 0.11523608991410583, 0.21746792685007676, 0.13312768220202997, 0.14308452839031816, 0.10007656586822122, 0.1092141552362591, 0.19096289441222325, 0.07551981951110065, 0.08330985423526727, 0.07983128190971911, 0.13005677901674062, 0.11685678458889015, 0.24008162668906152, 0.26070932450238615, 0.14253140572691336, 0.18077411223202944, 0.10234357469016686, 0.1321452419506386, 0.17986900376854464, 0.20346128469100222, 0.1559839307446964, 0.13001471408642828, 0.09951139072654769, 0.29123834101483226, 0.1412816290394403, 0.10495935581275262, 0.10205888684140518, 0.13973908993648365, 0.10803736877278425, 0.11995481327176094, 0.07040625874651596, 0.1105395493505057, 0.13104536425089464, 0.15332996612414718, 0.07156743784435093, 0.12396814752719365, 0.14993462566053495, 0.21742917189840227, 0.1933127417578362, 0.0650384381879121, 0.07704039846430533, 0.13247707101982087, 0.11699587790644728, 0.06824273499660194, 0.12915524770505726, 0.1065006703720428, 0.17124521808000281, 0.0993112260766793, 0.08243000105721876, 0.1521140758995898, 0.16035774839110672, 0.14825141988694668, 0.18363080191193148, 0.10832384519744664, 0.09159643028397113, 0.1497678057057783, 0.10853178755496629, 0.14482627477264032, 0.13111600186675787, 0.11870481393998489, 0.16483040526509285, 0.12503349309554324, 0.12193917515105568, 0.17497592023573816, 0.0896429862768855, 0.13016458338825032, 0.163312119548209, 0.12306715056183748, 0.1827998785302043, 0.2396810450591147, 0.09683387033874169, 0.07078073162119836, 0.2120315912179649, 0.20783106505405158, 0.10137585864868015, 0.16320530965458602, 0.14004619064508006, 0.12521514116087928, 0.0770265499886591, 0.16751702438341454, 0.1265532779507339, 0.11091255277278833, 0.10604278009850532, 0.10925822396529838, 0.07851554313674569, 0.11004388376022689, 0.16804757091449574, 0.15207300544716418], [0.0453277046472067, 0.0158115545855253, 0.004683101196860662, 0.03147200419334695, 0.029959694620629307, 0.02645170912728645, 0.05414611856394913, 0.04365930471976753, 0.006106751488914597, 0.01837742813222576, 0.06674081363598816, 0.0247869345912477, 0.08227279933635145, 0.03990709512436297, 0.026993681021849625, 0.0497523631202057, 0.023470008381991647, 0.005031828968640184, 0.02135723269020673, 0.02780205053568352, 0.017636777738516685, 0.006153393615022651, 0.03668570665467996, 0.03254313480283599, 0.03286475191998761, 0.013153860672900919, 0.1400672973250039, 0.05711997109756339, 0.011313559862173861, 0.033847596641862765, 0.06206447433214635, 0.03283386744442396, 0.041301327146356925, 0.02788166999380337, 0.005027287952543702, 0.013225933416833868, 0.036098463751841336, 0.05331706168362871, 0.02718288786127232, 0.02949304885987658, 0.006704178513246006, 0.009650709343986819, 0.04564729941193946, 0.05336161280865781, 0.06972532341023907, 0.07522966203396209, 0.05478181628859602, 0.07496602891478688, 0.05979740984912496, 0.027214657347940374, 0.07494831384974532, 0.03633681932114996, 0.03174401987052988, 0.010676318470359547, 0.05370091530494392, 0.010682355841709068, 0.0218925883382326, 0.02542702768550953, 0.03449891657510307, 0.053470522980205715, 0.02463232296577189, 0.06919914812897332, 0.041638518232502975, 0.09079810202820227, 0.03737950341019314, 0.015192927185125882, 0.041500842417008244, 0.04138765005336609, 0.02914389991929056, 0.05079873197246343, 0.029353128047659993, 0.04009534459328279, 0.007507732880185358, 0.008398643130931305, 0.050655497470870614, 0.049894918556674384, 0.02150178450392559, 0.0072061338050843915, 0.00251390094490489, 0.09211015232722275, 0.028551432296808343, 0.05265285806672182, 0.0716703143552877, 0.0418203481240198, 0.01738345861667767, 0.06121991769759916, 0.024581111065344885, 0.050205099178128876, 0.031292530620703474, 0.026361966774857137, 0.05044182944402564, 0.0745065875526052, 0.06594991427846253, 0.04672750277677551, 0.025706540909595788, 0.019911042909370735, 0.03604062076192349, 0.02206652548920829, 0.014706854781252332, 0.05465395166538656, 0.01803149083571043, 0.028175096631457563, 0.018070019432343543, 0.02979308246722212, 0.07778475774102844, 0.01592722015629988, 0.014929085336916614, 0.02045693705440499, 0.044079790750402026, 0.022269851688179187, 0.04958360244927462, 0.05822114755574148, 0.0459129177761497, 0.014933615220797947, 0.02627383673825534, 0.08174203758244403, 0.06764904654119164, 0.05624136843835004, 0.05936894202022813, 0.10666276284609921, 0.02755756111582741, 0.0692444785090629, 0.06003889357089065, 0.0072818732223822735, 0.04411867557791993, 0.0448430822143564, 0.030390604115382303, 0.01197891195261036, 0.03260589452111162, 0.013924236864113482, 0.0320006359834224, 0.05602490251476411, 0.017511386322439648, 0.05432176636531949, 0.028657724542426877, 0.0237603013010812, 0.023058634069457185, 0.03522928265738301, 0.022785291803302243, 0.025728068758326117, 0.03407303142012097, 0.029325991417863406, 0.04495097935432568, 0.04127101041376591, 0.0705609965370968, 0.043943491618847474, 0.03178324979671743, 0.06526696030050516, 0.039204511340358295, 0.042663821222959086, 0.016299566777888685, 0.015097893319762079, 0.07144427843741141, 0.02873663710488472, 0.019721758144441992, 0.03920317547454033, 0.02844422349880915, 0.01221672853716882, 0.09942392120137811, 0.024529837937734555, 0.01904144064610591, 0.007129980640456779, 0.008908137715479825, 0.052915752748958766, 0.06514402353786863, 0.03376886961632408, 0.016106853290693834, 0.03211141265637707, 0.06593249607249163, 0.017541977649671026, 0.03317068003525492, 0.03820495716354344, 0.06926022688276134, 0.03462020576989744, 0.049780356930568814, 0.11332968322676606, 0.03674359788419679, 0.02009655570873292, 0.009357359704154078, 0.04933086776873097, 0.029427300141833257, 0.047399072209373116, 0.04346525536675472, 0.011603030852711527, 0.037873083565500565, 0.06709794994094409, 0.014398578696273034, 0.0428939018456731, 0.07187571856775321, 0.06607557472307235, 0.04228846890327986, 0.01703238936897833, 0.012889056815765798, 0.030122006028250325, 0.024740760018175934, 0.03943410214560572, 0.0268548084932263, 0.05735561040637549, 0.021496335284609813, 0.0334018961439142, 0.09162942616967484, 0.036989920408814214, 0.10660154308425263, 0.02017499144130852, 0.06349282659357414, 0.060876767165609635, 0.04925669381918851, 0.03373667896084953, 0.014416431986319367, 0.049987482925644144, 0.04500812472542748, 0.018606718367664143, 0.06704857485601678, 0.010108348214998841, 0.016565979240112938, 0.025452154950471595, 0.03321958014566917, 0.04435835588083137, 0.03500579230603762, 0.07003289167187177, 0.049940697936108336, 0.028761358043993823, 0.023381713217531797, 0.036287295806687325, 0.059525060205487534, 0.03478486978565343, 0.02627334321005037, 0.014097759340074845, 0.05559682431339752, 0.04609216870449018, 0.024934688772191294, 0.03768064096220769, 0.029664457142644096, 0.05210522729612421, 0.054745881498092785, 0.10157934069866315, 0.03030116047739284, 0.07781315231113695, 0.04030692718515638, 0.03156627921271138, 0.02314610730536515, 0.01701684137515258, 0.03179981453286018, 0.030315059048007242, 0.04078937883605249, 0.08787783997831866, 0.06518232577946037, 0.024930675608629826, 0.11359164651366882, 0.0031578543666910264, 0.042556718181003816, 0.046771300621912815, 0.022861191246192902, 0.041302577665192075, 0.012993859199923463, 0.03907122532837093, 0.014553362871083664, 0.03596313683374319, 0.04510059632593766, 0.0425956957769813, 0.046621461005997844, 0.058565092185745016, 0.03627121346653439, 0.05685308366082609, 0.011395566252758726, 0.017480401656939648, 0.028276275479584, 0.01759762944857357, 0.01832755395298591, 0.07478504136088304, 0.02319506493222434, 0.05385429867601488, 0.04068610527610872, 0.06977988610742614, 0.03501109124044888, 0.03237757278839126, 0.01415315880876733, 0.04934412252623588, 0.016331213810190093, 0.04734566726256162, 0.03906559984898195, 0.02415823717456078, 0.04084644628164824, 0.11139402849948965, 0.045935119123896584, 0.04133191476284992, 0.05908584607823286, 0.013171055306884227, 0.058537469449220225, 0.009150417390628718, 0.06657415695372038, 0.0069709318995592184, 0.09027436099131592, 0.009488508330832701, 0.048439748788950965, 0.0542599714390235, 0.0666077688219957, 0.025416810167371295, 0.10327672891435213, 0.00586196289077634, 0.04563464579405263, 0.02360582882829476, 0.047750137746334076, 0.019866723705490585, 0.04571659374050796, 0.04404629391501658, 0.06545046373503283, 0.024278062483062968, 0.03171601492795162, 0.10859043206437491, 0.055213631203514524, 0.04850603741942905, 0.024280034740513656, 0.014049868550500832, 0.0591192130377749, 0.09057729082996957, 0.009126640834438149, 0.039424101705662906, 0.08851296253851615, 0.028409928854671307, 0.10072515840874985, 0.02833559348800918, 0.024625484074931592, 0.08762962868786417, 0.03153910547553096, 0.03948844961996656, 0.03820466030447278, 0.023476580099668354, 0.056000537806539796, 0.062299438286572695, 0.06883998576086015, 0.03378705594514031, 0.0364333059405908, 0.03212897187040653, 0.022091741811891552, 0.016997695820464287, 0.08528379636118189, 0.01475813718570862, 0.02993091598909814, 0.00854876940138638, 0.07844365871278569, 0.10113819327671081, 0.03816895929048769, 0.0221646114368923, 0.024763241526670754, 0.03460424588411115, 0.028645707316172775, 0.06361091713188216, 0.014717674366693245, 0.04674891373724677, 0.04409435539855622, 0.08648047238239087, 0.14922793779987842, 0.06554903578944504, 0.12664343405049294, 0.12095785554265603, 0.17188591416925192, 0.11315413561533205, 0.07428339406033047, 0.1727861986728385, 0.13512416335288435, 0.18709507305175066, 0.16747555317124352, 0.1664250876638107, 0.15268126968294382, 0.09775186990736984, 0.15669968764996156, 0.09289181194617413, 0.11108675709692761, 0.08370230934815481, 0.24283693899633363, 0.097819999064086, 0.10660755448043346, 0.08874264982296154, 0.08977868055808358, 0.12385951937176287, 0.20127656520344317, 0.07728681375738233, 0.3167324198875576, 0.09784794834558852, 0.23580180946737528, 0.16520551638677716, 0.22232504590647295, 0.1500910852337256, 0.18082052614772692, 0.13532648765249178, 0.10025483716162853, 0.1249209835077636, 0.20019638410303742, 0.11684203811455518, 0.1591609016759321, 0.13317399221705273, 0.1041918044211343, 0.13416554604191333, 0.14912773302057758, 0.16800001409137622, 0.15421505144331604, 0.13793047604849562, 0.17823906935518607, 0.22907683829544112, 0.13651260291226208, 0.1157321414211765, 0.16556620015762746, 0.10974439006531611, 0.12902939430205151, 0.11595091171329841, 0.09965045435819775, 0.15475086722290143, 0.1129592327924911, 0.10864872776437551, 0.11452250008005649, 0.29013924999162555, 0.10899772270931862, 0.1223003413178958, 0.13064007740467787, 0.16753820527810603, 0.14833641063887626, 0.11064385078498162, 0.1283164427150041, 0.1601635431870818, 0.17067196837160736, 0.19783754192758352, 0.1619760162429884, 0.1352731420774944, 0.22240396589040756, 0.17899410071549937, 0.14989554416388273, 0.18420794047415257, 0.09777270199265331, 0.15295301447622478, 0.09690007733297534, 0.16179432364879176, 0.1129861430672463, 0.18657641572644934, 0.22876096540130675, 0.14662147063063458, 0.1501583683420904, 0.14908143784850836, 0.11480528803076595, 0.2330278098816052, 0.12726661545457318, 0.11696354253217578, 0.1557302349829115, 0.12506072991527617, 0.1025615879916586, 0.1485428464366123, 0.08145821062498726, 0.21763939264928922, 0.1304624814656563, 0.129343070439063, 0.11240428444580175, 0.1685448395437561, 0.08377793419640511, 0.1559162320336327, 0.061214830275275744, 0.11848953916341998, 0.15013093856396154, 0.16940164903644472, 0.1434039932792075, 0.20217171404510736, 0.1369446812896058, 0.1725481919129379, 0.13751098449574783, 0.14887794095557183, 0.16951219935435802, 0.10778909068903886, 0.15108896215679124, 0.15567464812193066, 0.25047665170859545, 0.16971510252915323, 0.12197160700452514, 0.22639391507254913, 0.16475402342621237, 0.21577176317805424, 0.19623442873125896, 0.0933429338329006, 0.1254460381460376, 0.1716612363816239, 0.11854158597998321, 0.08586575888330117, 0.20854493690421805, 0.13710943807382137, 0.14681954984553158, 0.12234179768711329, 0.087685660837451, 0.22514587501063943, 0.14530344604281709, 0.1302494405535981, 0.16902489034691826, 0.18140372063498944, 0.12958967126905918, 0.13070820656139404, 0.18164526001783088, 0.16270719497697428, 0.18740959523711354, 0.10992946685291827, 0.20673571445513517, 0.17884688830235973, 0.11390045416192152, 0.2305265940958634, 0.14764397201361135, 0.135786515311338, 0.12922221911139786, 0.14505951694445685, 0.2060142726986669, 0.12571111845318228, 0.1616435934556648, 0.11894503972143866, 0.11010732254362665, 0.11659162264550105, 0.18218972923932597, 0.08273984771221876, 0.15861307794693857, 0.09294557312387042, 0.1020371938648168, 0.11655973255983554, 0.17188858590088785, 0.16072916361736134, 0.07962717645568773, 0.07583201877423562, 0.14135064877336845, 0.10119316415512003, 0.13026149303186685, 0.1859586371574551, 0.23959756828844547, 0.14572219544788823, 0.14351421705214307, 0.17023617925588042], [0.0377687672880711, 0.030295531287265476, 0.05310969449055847, 0.026453230530023575, 0.03512279930873774, 0.039844435596023686, 0.08521367082721554, 0.05078309492091648, 0.02219172580225859, 0.018640860871528275, 0.011258203994657379, 0.05631957596051507, 0.06305784641881473, 0.03551339905243367, 0.008093419128272217, 0.005531017441171571, 0.05149820615770295, 0.02403560654784087, 0.01938782323122723, 0.01380920675728703, 0.0173536409783992, 0.030535497317032423, 0.006344917810565676, 0.020444552465050947, 0.01380962050461676, 0.046286314536700957, 0.010926900922640925, 0.04966762840922456, 0.051673100679181516, 0.04838864449993707, 0.05395675587351434, 0.025743295773281716, 0.020177336627966724, 0.07488552073482424, 0.01960432626219699, 0.011355649839970283, 0.04476896021515131, 0.10771405955892988, 0.03759471139346715, 0.07623741694260389, 0.07455568062141538, 0.02480496321368264, 0.040449389853165485, 0.01853041074355133, 0.01922815943544265, 0.017136048845713958, 0.027874120496562682, 0.06105605891207233, 0.11697691603330895, 0.023409391615132336, 0.022048823411751073, 0.025533748521411326, 0.03112712631264003, 0.017629573339945637, 0.06348288923618384, 0.050368249212624505, 0.033042158611351624, 0.022892211163707543, 0.061260917645995505, 0.062172182224458084, 0.04619807317794766, 0.02301370073837461, 0.02760283212410286, 0.01624004653422162, 0.07116271503036842, 0.0979033941985108, 0.03340519870107528, 0.025997342199843843, 0.08909959316952154, 0.06404200103133917, 0.019743970624404028, 0.03940239017538261, 0.07036433482426219, 0.04941044455335941, 0.017215959596796893, 0.058428436823305674, 0.029086453978379723, 0.021092026217957027, 0.01174090519270976, 0.05895546557439957, 0.05405133146268781, 0.012384164474497084, 0.01659461315284716, 0.029334617029235233, 0.06032336248608772, 0.04965272979461588, 0.051621606762637384, 0.057051014446187764, 0.03736611135536805, 0.015758082845422905, 0.05217335645284038, 0.06102566054323688, 0.06087996582209598, 0.03250916299293749, 0.020517455486697145, 0.027045071037719026, 0.017137278955488, 0.05370625505747739, 0.043087320373160765, 0.035764723652391694, 0.0292648644244764, 0.029859833084628917, 0.038427902036346495, 0.06602538327570073, 0.025093731019296683, 0.022355640248861164, 0.05445811002573464, 0.05852332411450334, 0.039985425100894645, 0.02982383706694236, 0.04028885217849165, 0.01509570862253895, 0.030235159429139458, 0.06800017144996673, 0.015392037985293427, 0.021431801833387, 0.03112783691904042, 0.012290375561860856, 0.04309772157284897, 0.028671008985838853, 0.054596628178842366, 0.06537221910548396, 0.025743893202161416, 0.04066649773449171, 0.03576559196517337, 0.006555116297022323, 0.017874337354442105, 0.014765783162147272, 0.04337537015089765, 0.01572747296449961, 0.08782522170804441, 0.03460272077063564, 0.06900726584717631, 0.043696107823052444, 0.10611297984723933, 0.02247112584882416, 0.025847587930911686, 0.06114846000855323, 0.021277600244502537, 0.040850030854926445, 0.03368658770341426, 0.04678469638747629, 0.03196461584593635, 0.02759513048658846, 0.028836157252953853, 0.02292637222126359, 0.0037313605798772187, 0.03489769107545726, 0.012696579888142878, 0.06914115670952015, 0.04549955265247263, 0.03031235948583344, 0.007294465613085777, 0.02607500795420492, 0.01674885741522303, 0.09423138850252144, 0.014141473693598527, 0.06049116207577754, 0.012029668359900825, 0.0168521755040274, 0.07938599330373108, 0.03642652642156463, 0.058082629402633756, 0.0329970805614721, 0.0291142344212858, 0.0649446678289678, 0.027302967355353758, 0.045726286189164966, 0.05832715964061208, 0.04177626826276537, 0.03667874159873463, 0.01990748060052283, 0.054386919509852305, 0.02569628442870453, 0.046437356431852095, 0.03563986101653427, 0.02948942161310697, 0.027088881870440673, 0.06291492361924611, 0.02756499558017822, 0.04897935694316402, 0.029279532973305322, 0.05118809604027774, 0.03320871139294468, 0.027269646780041512, 0.028384773759171367, 0.10355881924624555, 0.050551656167954206, 0.06869048011139967, 0.011061937475460581, 0.0034542215325927828, 0.06631476149777882, 0.02212810519267805, 0.027054281090386212, 0.03471003161394037, 0.011999118778476259, 0.03209127447917126, 0.06266783297178335, 0.03645412318292074, 0.059944121312582865, 0.007368665073954617, 0.031681790787843056, 0.04359272665169556, 0.07719748144154437, 0.08958131380495615, 0.07919770301668905, 0.023627570044482127, 0.06810068793129176, 0.06147323867480736, 0.03252099282690324, 0.031532158973277546, 0.008173313181032427, 0.036298966078902595, 0.04740462718473282, 0.025874999155348632, 0.09853231982560828, 0.024440303386654705, 0.06510790321044624, 0.057221968163503334, 0.020804898558708373, 0.08968001944595017, 0.07054598288959824, 0.068766231124755, 0.05804197455290705, 0.022923464857740328, 0.057451725951978005, 0.025259306021325756, 0.036159386654617265, 0.05471496733662207, 0.010589051180431852, 0.009359562955069123, 0.021752105349150952, 0.012840048166253837, 0.07173920050263405, 0.07666202189284377, 0.0332178917597048, 0.025076860147237312, 0.04193667235085741, 0.015772040787851438, 0.04646657849662006, 0.037277417286532, 0.050444311928004026, 0.023600635649927426, 0.05792930911411531, 0.04574941151076928, 0.03212253373931162, 0.07833564653992653, 0.05441351808258332, 0.06855328669189475, 0.043438122447696514, 0.035473686730256304, 0.039686046438873746, 0.05121823094668798, 0.06096213270211592, 0.04648377034754958, 0.020193556265439838, 0.046243874821811914, 0.012521112057584105, 0.03203422558726743, 0.008466187846352113, 0.02217243738414254, 0.06763401805073954, 0.05344029159459751, 0.022076577879488468, 0.03973663493525237, 0.002626899422466522, 0.02911034185672179, 0.06357660022331402, 0.08333529505762272, 0.020672427053796127, 0.040032429023995064, 0.020520668986137025, 0.06104650747147389, 0.013948485611763317, 0.033829625535872765, 0.05369315986172296, 0.01974259579583304, 0.01854817590356106, 0.018482675804989412, 0.019095413335890044, 0.05436411331174895, 0.00994846084722667, 0.06523355623357929, 0.0400515207729768, 0.03914854969480075, 0.04591626857290976, 0.01434482122931513, 0.015365659273811616, 0.029351682715059724, 0.03567109059076756, 0.015820697844901588, 0.026566688211460132, 0.021999938144290354, 0.026574228431854863, 0.05108133809699211, 0.03812797418504488, 0.017775741180230398, 0.03183334476489108, 0.02083373285131529, 0.029600406087411102, 0.05487599853950087, 0.04160291740845423, 0.044841089547844604, 0.04617809827323072, 0.009081457956199301, 0.08466523111565039, 0.04646866022085305, 0.019544449787645135, 0.009860954214673257, 0.04012667435745243, 0.04251848644344136, 0.02182893433200661, 0.03875999456795398, 0.019810995836451184, 0.08159027580404654, 0.011417966125009116, 0.009274003532482311, 0.06295403480180539, 0.04250097546901088, 0.018630450394994114, 0.030766954623686615, 0.01348233801763854, 0.056417450396111235, 0.05190859526919667, 0.05112112092319876, 0.027633406753011514, 0.0050540924712549895, 0.021124916347616818, 0.04837888896872755, 0.014253853405534755, 0.012587655801326036, 0.02936668894108152, 0.0800274389621336, 0.06331045122351497, 0.059882174246013165, 0.03248440123570617, 0.09538080455968156, 0.009331120145361638, 0.0354520197288366, 0.019961555335612502, 0.009786090995476115, 0.014683979006804293, 0.025240620598196983, 0.03356349880050402, 0.0333380899974145, 0.056210747425211594, 0.06714861636282876, 0.034598787387949415, 0.05403964634751901, 0.02359721991524566, 0.032363820791943, 0.008210972537199268, 0.14703134394949302, 0.08683089225087315, 0.1589731828426011, 0.12843000615248457, 0.10121706873178482, 0.13924896076787263, 0.13287680660141632, 0.11037028772989288, 0.057211515013477765, 0.10623445457895286, 0.17593921307707205, 0.1850618704338558, 0.12454229523427784, 0.11584520761971362, 0.12292171188164502, 0.14796622737776488, 0.1625096204224974, 0.0813353703415487, 0.1424085209146142, 0.1089998749375809, 0.12867443991126493, 0.17899980040965602, 0.09064815851161256, 0.18442628032062203, 0.08912551638786681, 0.08886968324077316, 0.17196183587657288, 0.14882597577525303, 0.08744464095798321, 0.16900577262276784, 0.11101672062068246, 0.11944064593990333, 0.13665941456565633, 0.18161452026106417, 0.10131462404388003, 0.075816752796527, 0.20643127063522115, 0.2545673697022721, 0.09542761181364767, 0.23869608150562271, 0.20163819892331958, 0.10955805904814042, 0.17566797294421121, 0.12785159109625965, 0.20151029719272628, 0.14036274631507695, 0.08619157655630261, 0.08448477790807374, 0.14046842814423144, 0.112045426358236, 0.2361168511561118, 0.08351861295523122, 0.16750630777096376, 0.07018773336312734, 0.08030584824155085, 0.16749878239352256, 0.1016530508059077, 0.17076210962841287, 0.20345742552308366, 0.1341229912941344, 0.14288698352174833, 0.07049538326100446, 0.059584665796137415, 0.1529778170515783, 0.12142503750510514, 0.17153894528746605, 0.07899716729298234, 0.11876008167746477, 0.18612490792293102, 0.25537761684972793, 0.17316709854640067, 0.11084305064287037, 0.1218132401118055, 0.10836417350219563, 0.14566896861651912, 0.14545472542522475, 0.09995682034059428, 0.11479339882498607, 0.16239452816080302, 0.12029437551973388, 0.16369837772799656, 0.085939142445568, 0.16318147187121212, 0.14555347559507936, 0.175426077330485, 0.13633141497848555, 0.09324877755716443, 0.17741939693223685, 0.11705542783602141, 0.09103206408326514, 0.07910870466730557, 0.11306844724458642, 0.15941844176268205, 0.11735978259821422, 0.08769948704866692, 0.16067507589468732, 0.13508959411410615, 0.13699455361347646, 0.11641686171060428, 0.14036504697287455, 0.1484377880115062, 0.10233929991954938, 0.1145283407822717, 0.15092181565705687, 0.14334135601529852, 0.06288548262091354, 0.1519584920606576, 0.12683858920354396, 0.21703596721636131, 0.1576640343409963, 0.10624773902236484, 0.10099144841660745, 0.1330734757357277, 0.1415916092810221, 0.1335955469403416, 0.13892317278077826, 0.1436558336718008, 0.07690163911320269, 0.22284149163169786, 0.11793511032010429, 0.11792635297751985, 0.1685323566198349, 0.15572569303913042, 0.19545137387467548, 0.17946897132787853, 0.10438425815664232, 0.20617131114704534, 0.18640625610714778, 0.14926905278116465, 0.174297567573376, 0.17498737899586558, 0.14926066651241854, 0.1519405617727898, 0.1665289734955877, 0.21830817160662264, 0.06502995543996803, 0.08413650284637697, 0.12410767871188, 0.17501409631222486, 0.0928853775258176, 0.1079448229575064, 0.17761907918611541, 0.17065388965420425, 0.08955116776633076, 0.07654138578800485, 0.09507898052106611, 0.11314235773170367, 0.10604409369989298, 0.13866558816516772, 0.15489396813791245, 0.12796571856597438, 0.15804190625203773, 0.08106572582619265, 0.08813847482088022, 0.11281489991233684, 0.20361965900519863, 0.14498751377686858, 0.21989458648022264, 0.1055960294615943, 0.1592780274222605, 0.28904398845043033, 0.09571621820214204, 0.1262246846454218, 0.12056698862579651, 0.12794624461093917, 0.09233424381818622, 0.08913120866054669, 0.09393014333909377, 0.2278979663969949, 0.13939317490439862, 0.12711515795672312, 0.0691143429139629, 0.13242423010524362, 0.10628362186253071, 0.09210925432853401, 0.08834292908431962], [0.028057928211637773, 0.053913384763291106, 0.034097503739758395, 0.06441647390602157, 0.04828892582736444, 0.06506355246528983, 0.03731501448783092, 0.03324852390505839, 0.061630919080926105, 0.01950153695361223, 0.01855001271906076, 0.007506810761697125, 0.03859396128973458, 0.022709403492626734, 0.026517875303397886, 0.020861192315351218, 0.037129878328414634, 0.05446155359095428, 0.03135271879727952, 0.04724686143163126, 0.027430882073531393, 0.029323900416784454, 0.06522415322251618, 0.035828414766001515, 0.046507140577887185, 0.06905080765136518, 0.02925645218056161, 0.022518254081660416, 0.0017851118104772468, 0.03209862916264683, 0.046571336351917125, 0.08353471755981445, 0.07137949636671692, 0.04147173538513016, 0.043571323112701066, 0.04181024007266387, 0.027161092839378398, 0.03846286090265494, 0.035460777071421035, 0.049370442793588154, 0.04221329676511232, 0.02085423839162104, 0.08731111374800093, 0.05096404907817487, 0.06003934999171179, 0.06970458780415356, 0.0252955265386845, 0.032507044161320664, 0.11408644379116595, 0.00827912952445331, 0.055704187107039616, 0.030231539603846613, 0.04056658610352315, 0.07608877960592508, 0.03218775738787372, 0.0708371125801932, 0.026031787128886208, 0.045941100834170356, 0.026750466240628157, 0.04049843468237668, 0.05370363898691721, 0.12445761618437245, 0.041952276005758904, 0.02516798474971438, 0.02849999404133996, 0.10499071155209094, 0.010604702147247735, 0.023605290771229193, 0.03169392490235623, 0.01944041738170199, 0.05377495566790458, 0.010778861014841823, 0.01118034806495416, 0.030336534946400207, 0.04205233977700118, 0.04393061164591927, 0.011450009278632933, 0.009945136953319889, 0.06396020151441917, 0.0563140803569695, 0.06885534079628997, 0.018335780659981538, 0.018827475760190282, 0.027788044353656005, 0.00554397580344812, 0.029241711272334214, 0.050423401917214505, 0.06412256858311594, 0.02530742873204872, 0.021788036428915802, 0.0639228566433303, 0.013411734726105351, 0.020441702617972624, 0.09782756154891104, 0.06089217044063844, 0.01761382125550881, 0.036635218348237686, 0.0641199413803406, 0.04497196729062125, 0.05979858244245406, 0.019762169940804597, 0.03335934510687366, 0.034788573102559894, 0.05325228703441098, 0.014771990299777826, 0.03644709875516128, 0.022151605298859067, 0.05525497253984213, 0.0415209249331383, 0.014574888864444802, 0.05376592373067979, 0.024372606530960184, 0.04721972109109629, 0.03945169104554225, 0.019222025584895164, 0.12134626595070586, 0.026205169524473604, 0.003401006993044575, 0.04386237487778999, 0.05599651536613237, 0.030435979024332482, 0.014572772815881763, 0.0035759270258495235, 0.02102207137795631, 0.040195352703449316, 0.08426001848420128, 0.0800569838611409, 0.029003489289607387, 0.048407914364361204, 0.05882065444893669, 0.03153934296278749, 0.048794224494486116, 0.010594479990686523, 0.05180777450732421, 0.054894181157578714, 0.035489683723426424, 0.033952818339457735, 0.06386445704265498, 0.032160798873519525, 0.019617106045188848, 0.019483987016428728, 0.007818791091267485, 0.06054029967344832, 0.046544459473807365, 0.024177612795028836, 0.00785978732892545, 0.028582225859281607, 0.007679368909521145, 0.041427492251386866, 0.02332851421670057, 0.021435627604660112, 0.03629379702033475, 0.057328956172568724, 0.03918353082553949, 0.007381739396805642, 0.021651802235282958, 0.030867606546962634, 0.020031638196087442, 0.021236019565549213, 0.026533523487159982, 0.05678087269188836, 0.06645866393228061, 0.03855556627968326, 0.0344474746088963, 0.016588282633165363, 0.06083932952606119, 0.05646569741657004, 0.07547907560365275, 0.011060935576097108, 0.027404888351156842, 0.10681701081921346, 0.003002537469001254, 0.08868035394698381, 0.05804445703688543, 0.11188233198481612, 0.06895289610838518, 0.025153748501907103, 0.09452887097722851, 0.0346110291138757, 0.06347003523842432, 0.03040446557861287, 0.06258863839320838, 0.04254288454831112, 0.05465615955472458, 0.035034153479500674, 0.011857657082146034, 0.03393231279915199, 0.007880655593908159, 0.009796463436941849, 0.02296513644978404, 0.021842801361344755, 0.03524846717482433, 0.05377234330808278, 0.048517507311771624, 0.07284922336111777, 0.06864048162242398, 0.02759215818514349, 0.04394657524244394, 0.06053212491679005, 0.012864159616583493, 0.04502868221607059, 0.02221151331468718, 0.03375923653948121, 0.043647912752931006, 0.024524603941245005, 0.022215014396351762, 0.061909079740871675, 0.03561775243724696, 0.06670568778645247, 0.11229624258703552, 0.024017069554247428, 0.04388340734294616, 0.013828707615175517, 0.04005925766250584, 0.03099302022746997, 0.052061919268453494, 0.025101833416556474, 0.048929395561572164, 0.04961892496794462, 0.02383977232966572, 0.08952908887295052, 0.0406943431153195, 0.0464929507143097, 0.03116442108876072, 0.07492095828638412, 0.011799171206803294, 0.0179662300797645, 0.02680735371541232, 0.07253553238115273, 0.028053777750756126, 0.012486034447647398, 0.05397836350311991, 0.026270385751558933, 0.031629116856493056, 0.050855669542215765, 0.01989621108805295, 0.042430564208189026, 0.10591509359073825, 0.010014794934249949, 0.016916985405259766, 0.014777307787881, 0.03932932944735512, 0.01313581627982785, 0.09208240342559293, 0.03560146600648295, 0.03362171286426019, 0.058587445673765615, 0.05027109837101307, 0.05410964571638033, 0.04238983143295627, 0.004618293150997488, 0.019015040597878397, 0.017832899538916536, 0.015333176397689385, 0.043082192132715136, 0.069693069672212, 0.044407489767763764, 0.010369834672019351, 0.017042130057234317, 0.004757414762934786, 0.01615426539501641, 0.05358340735256206, 0.029217379960755352, 0.025500218289380427, 0.041366773439222015, 0.04505196709942538, 0.03275758579547983, 0.047349392843898386, 0.024882577017706353, 0.02369189569435548, 0.07014457747573033, 0.04343643035099376, 0.016545466278330423, 0.05172074284928385, 0.009379140810779063, 0.051203673720010556, 0.032029928552219644, 0.03689618344651535, 0.03923725489585195, 0.08112630734103732, 0.06308089752565138, 0.036611911200452596, 0.03579091775463894, 0.011846431170852156, 0.025622956527513452, 0.03063291162106907, 0.014930335855751764, 0.019924216030631214, 0.06669526061159559, 0.03565461120160762, 0.03897567010426428, 0.01739649444061797, 0.056339276270591654, 0.037098734101164155, 0.065088080446003, 0.012461441529012518, 0.033313502644887194, 0.004110224881515023, 0.014957901075831614, 0.020774477925442625, 0.03471794290817343, 0.11628159787505865, 0.024551890855946112, 0.0542296509956941, 0.06468084175139666, 0.0671894641709514, 0.053346023996709846, 0.038569800672121346, 0.02815275984175969, 0.02747286722296849, 0.05351103682187386, 0.043095101791550405, 0.045587760614580475, 0.07387013654806651, 0.0517021186533384, 0.07674435575609095, 0.023207828016893473, 0.013310093891050201, 0.006037147313691094, 0.036257643296266906, 0.03565783583326265, 0.043361614443711005, 0.01161213514933479, 0.03634076383605134, 0.01289087786062737, 0.020726453549286816, 0.0679072471393738, 0.036469047772698104, 0.014764263614779338, 0.018140206193493214, 0.016526725194125902, 0.009570101901772432, 0.04785167839145288, 0.05547644053876866, 0.02933083764219191, 0.025961342471418902, 0.03277710799011402, 0.09196161146974191, 0.06032246077666059, 0.04055500859976746, 0.08589626115281135, 0.07919935800600797, 0.025779718525882345, 0.0555052470008377, 0.04206670404528268, 0.015150548697420163, 0.06481518532382324, 0.02788955345749855, 0.03546352301782463, 0.07412164297420532, 0.024631050182506442, 0.034951930938404985, 0.10319714841898531, 0.24210089177358896, 0.10992023453582078, 0.11888373832334764, 0.08975360338808969, 0.1488059526309371, 0.16839583113323897, 0.08363809130969457, 0.203746699844487, 0.07582372898468748, 0.08161998397554271, 0.1130567213112954, 0.09273788309656084, 0.08927133356337436, 0.07663931217393838, 0.15797475673025474, 0.18793810828356072, 0.08695657495991327, 0.10048068012110889, 0.23443388286978006, 0.08120363170746714, 0.14898481022100896, 0.26432824437506497, 0.09589753972250037, 0.15444603748619556, 0.2233158575836569, 0.08069493400398642, 0.08386452056583948, 0.05266925953037571, 0.1085771105135791, 0.17528162570670247, 0.13439590868074447, 0.15932555455947295, 0.2016886352794245, 0.08947871931013651, 0.12657230661716312, 0.12895954336272553, 0.19329245144035667, 0.16758657846366987, 0.12278050344320945, 0.14270316838519648, 0.13357816584175453, 0.20037254027556628, 0.10792854023748077, 0.17139323201263323, 0.11073744302848354, 0.18221432401333004, 0.10877468506805599, 0.3951339394552633, 0.1216445276804734, 0.25817732443101704, 0.10634624428348616, 0.1202439762710128, 0.22021448181476444, 0.08469125081319362, 0.18643417570274323, 0.08317240106407553, 0.155054212664254, 0.11210192606085911, 0.1010155607946217, 0.2269669866655022, 0.18309439241420478, 0.12429050679202192, 0.1447642015409656, 0.0903567839122843, 0.23211450810777023, 0.09488553972914815, 0.17487188597442582, 0.16161601524800062, 0.16411322343628854, 0.16045370808569714, 0.20582532190019265, 0.11083329882239923, 0.14775529416510835, 0.18614794418681413, 0.19448413280770183, 0.07618742587510496, 0.0816103583201766, 0.17904952430399135, 0.19952862930949777, 0.0819451262941584, 0.1325797545723617, 0.15017787198303267, 0.07250917129567824, 0.0610342880099779, 0.1263269377523102, 0.15394712128909305, 0.13961711054435, 0.18833220354281366, 0.16545861843042076, 0.126113674195949, 0.11467196862213314, 0.12829343613702804, 0.21205577038927004, 0.12537828006315976, 0.14547562430379912, 0.17364005441777408, 0.23828934004995972, 0.12406399589963257, 0.1467553837574087, 0.09993172832764685, 0.18014046654570848, 0.12104306151741184, 0.14425581553950906, 0.17387864005286247, 0.07684565891395323, 0.09757905339938588, 0.11981038391240872, 0.13808114686980844, 0.09527090733172372, 0.16137095808517188, 0.08838231486151926, 0.19556345301680267, 0.10586313583189622, 0.14286715333582833, 0.1879781248862855, 0.11744760093279183, 0.1754345526569523, 0.12095985934138298, 0.10791945634991862, 0.149648008227814, 0.1376198130310513, 0.11687257006997243, 0.10931506505585276, 0.13924544298788533, 0.24404108844464645, 0.1348331375629641, 0.16118732106406242, 0.17402560013579205, 0.12688106973655522, 0.10618639309541322, 0.12373409641440958, 0.13276996702188626, 0.14697329315822572, 0.15275088313501328, 0.15341617399826646, 0.08468647138215601, 0.2528679108945653, 0.2220693018171005, 0.195737115573138, 0.1220286262105219, 0.10691245101043023, 0.10628650881699286, 0.13353328075027093, 0.12962838169187307, 0.11499623520649038, 0.13773512793704867, 0.15814435231732205, 0.12836172856623307, 0.06509988801553845, 0.11003705600160174, 0.16140730847837403, 0.14979428553488106, 0.19453952671028674, 0.06665076885838062, 0.06804173914133571, 0.14027226367034018, 0.1518009341089055, 0.07121565242414363, 0.09943307188223116, 0.16087469877675176, 0.21491968858754262, 0.17282980727031827, 0.07977948000188917, 0.19681092904647812, 0.14037441287655383, 0.10659649648005143, 0.150232553423848, 0.09304697276093066, 0.08551803301088512, 0.23447605170076713, 0.1092032456654124, 0.18768597103189677, 0.24196032900363207, 0.18776739947497845, 0.09984520875150338], [0.030835621837468352, 0.06851178579381667, 0.05186658599996008, 0.05761843087384477, 0.06075533325201832, 0.015120059415494325, 0.022913685206731316, 0.052632059378083795, 0.0022858262082081637, 0.059689130503102206, 0.028765630959242117, 0.012945277285325574, 0.0411392829118995, 0.044537168942042626, 0.021809428835695144, 0.04358789898105897, 0.02348273807001533, 0.09494294485193677, 0.014048125431145309, 0.04741626777104102, 0.029847068144590594, 0.050756496348185465, 0.0311043145484291, 0.03201142309990246, 0.04912664728180971, 0.023793278633092996, 0.030350626475410536, 0.014838278002571315, 0.0031288377840610337, 0.016724440756661352, 0.1069261807424482, 0.04350251118012238, 0.007296447147382423, 0.10210900407400914, 0.0402004252828192, 0.006172709863676573, 0.0793074221292045, 0.038710990556865, 0.045169319200795144, 0.11696556859533302, 0.014516764786094427, 0.026327412379032467, 0.018050538055831566, 0.028669873499893583, 0.03899086557794362, 0.034590601499076, 0.07655013570911251, 0.015138733706407947, 0.056333264874410816, 0.017329511902062222, 0.0023728481255602674, 0.05329644111043308, 0.017076372751034796, 0.07594358583446592, 0.027978716934740078, 0.06491453663329594, 0.02316833648364991, 0.0163178662842256, 0.0713853890192695, 0.03729273521457799, 0.020741906919283792, 0.03778102014621254, 0.027502336051838938, 0.03903713477484416, 0.02376404358074069, 0.014688020000903634, 0.006080148741602898, 0.045901496123406105, 0.09287027482059784, 0.014293148269644007, 0.028089157785871066, 0.061168215979705565, 0.013589640511781909, 0.04668420588131994, 0.020797373181267176, 0.03405795097933151, 0.06831081220298074, 0.03657101886346936, 0.017216664637089707, 0.03422667083214037, 0.04736278860946186, 0.06292153615504503, 0.07433463193592615, 0.03049118553462904, 0.0233032106916653, 0.0339238782908069, 0.0127391346359218, 0.03144402151519898, 0.02302233191585401, 0.06749175576260313, 0.021260684843582567, 0.06827777178841643, 0.0712042604573071, 0.052397459076019004, 0.016521700854355004, 0.09267264831578359, 0.016114809113787487, 0.04805401011253707, 0.014523291974910535, 0.06882663452415727, 0.00886338342752424, 0.006813388790760655, 0.03889109495503362, 0.040535675652790815, 0.08327307339641266, 0.060512940399348736, 0.016886434896150604, 0.060096127999713644, 0.023940600513014942, 0.017152687796624377, 0.017054314266715664, 0.050041797003359534, 0.0410097670101095, 0.016438947677670512, 0.013663538938999409, 0.03464893059572205, 0.04899650426523294, 0.026173184814979322, 0.06238618050701916, 0.05014304078940768, 0.04107556211238261, 0.005760429203292006, 0.04538872773991898, 0.07391142222331837, 0.05958587549685035, 0.011168696346430806, 0.09089369807043113, 0.050645215014810674, 0.016559650575800333, 0.024899266063584946, 0.06593027705093846, 0.11728489989764057, 0.07823138221283443, 0.053474059313884936, 0.04090045978955459, 0.025096107747231144, 0.028507426650321577, 0.04829279983823653, 0.026715358944784384, 0.029471533998730592, 0.024013232650759164, 0.042603009642334655, 0.0855990829586517, 0.05285142338834703, 0.0590213014947949, 0.011565317690838128, 0.03863200006890111, 0.010344545989937615, 0.02201940838858718, 0.023355309458565898, 0.08691355265909806, 0.10881693553528748, 0.0035555972817746806, 0.034761273200274445, 0.01106952686313889, 0.009135240470641293, 0.01076395126801799, 0.03527217879309319, 0.13103573117405176, 0.01623410193133168, 0.04899922423646785, 0.019289013689558487, 0.029099181811034214, 0.0508344812260475, 0.01961686670256313, 0.014475265743385535, 0.01800548783648992, 0.034878625301644206, 0.0497907395765651, 0.025430410023545846, 0.055216284381458536, 0.08067433940595947, 0.017373385817336384, 0.05666896795446519, 0.052128226452623494, 0.0519464114040602, 0.03458000734099187, 0.028507185452326667, 0.044120300881331787, 0.06259876870899461, 0.04155446258664597, 0.0159222143702209, 0.0035333168489160016, 0.032491173333255574, 0.06676341203274205, 0.0039426757666660706, 0.024749092481215484, 0.041025404061656445, 0.028507196584541816, 0.03509217458486091, 0.009082904216484167, 0.05042118289566133, 0.060722786365658976, 0.05611754109850153, 0.0406689802184701, 0.04723351761640515, 0.05995819243253209, 0.057712639099918306, 0.05488697119290009, 0.0097759801610664, 0.03136085273581557, 0.013512597233784618, 0.011905713927262696, 0.026745083814603277, 0.03072128656640416, 0.047568979498464614, 0.06818357840529643, 0.05581834055192303, 0.039959397981874645, 0.07348352955887094, 0.014772045960853575, 0.01375007243041182, 0.043892643370782025, 0.01489243344622082, 0.04106285654415842, 0.052436867117648944, 0.0390153267653659, 0.07036750379484147, 0.019943951592722442, 0.0861213768075686, 0.059580235174507834, 0.06085173452447634, 0.018915865548478905, 0.004834445517190034, 0.017840428627096117, 0.04034441306430381, 0.02836180428857915, 0.017056475771823898, 0.0407284707762301, 0.05663036885380279, 0.0533619022462517, 0.08229241429944523, 0.01085322050130344, 0.019179023693141062, 0.05683750227035489, 0.024255597672890872, 0.026841535182029475, 0.05767527938587591, 0.027847087767440826, 0.013161919468984706, 0.012439038873708341, 0.010251694966427749, 0.016001961848814972, 0.01094303614081582, 0.047907870102790184, 0.025723818107508123, 0.023118707213143352, 0.07484644665964879, 0.003565529536899703, 0.033390240714652464, 0.015250706164806616, 0.007182246854426921, 0.05981197449727915, 0.023518973430327605, 0.022587876810575835, 0.024816039767756592, 0.04080724233062938, 0.006019514348736266, 0.023348303584498353, 0.0416355904599186, 0.018938232024083845, 0.020346858000266366, 0.018416639504721388, 0.05736106890253723, 0.02598731949547073, 0.044307088319328614, 0.05366744073398877, 0.0470372195559321, 0.07205565969343297, 0.034811479490599595, 0.0626822974300012, 0.10065774913528003, 0.049003862659446895, 0.06042378619895317, 0.13919344812165946, 0.058990394754800946, 0.008980232723843073, 0.04203723707178142, 0.06284573319135234, 0.01601805903192144, 0.0714383932063356, 0.04596506478264928, 0.022398527107725386, 0.02900015333580086, 0.015395872105727904, 0.03274880247772671, 0.03282894329458941, 0.026106699515366927, 0.018613399552123155, 0.010064579128084006, 0.013192998758313479, 0.05398635272285901, 0.033031646089511923, 0.04939138249028474, 0.002614462650853966, 0.02957138069177745, 0.024664663906150963, 0.038501081508002244, 0.030465384770650417, 0.03734084122697823, 0.00787840688644792, 0.030939752577978652, 0.05681367932993453, 0.03432692385104019, 0.03853716843877919, 0.02351862462091958, 0.03379545705683995, 0.0830820000555832, 0.036366238055052236, 0.022478630817204248, 0.05828685731103178, 0.10471109999343753, 0.03778913182031829, 0.04032800788991153, 0.006940986704648822, 0.02471973311912734, 0.0073804063140414655, 0.03949519574234728, 0.035024227254325524, 0.042658359016058967, 0.0563760274235392, 0.025447384796279948, 0.1063879307184834, 0.007191039912868291, 0.0257178252650192, 0.028201593158883043, 0.0633418292272836, 0.037493742202059366, 0.012146836779720616, 0.016964358546829317, 0.015399191361211706, 0.02757254507741891, 0.029180549026932567, 0.0919308271841146, 0.0339028087182669, 0.012678602288360707, 0.0819338159635663, 0.05945901277300436, 0.020081267466594, 0.04116928052098956, 0.0866988419147674, 0.04103514474991243, 0.051893778290832415, 0.01093857676096377, 0.04241129063302651, 0.05266951928206254, 0.03007060116942739, 0.041003518126672134, 0.02692764286621241, 0.02817512631736463, 0.017823708039941266, 0.03932916617486626, 0.13101227930746973, 0.20974582090275362, 0.0998904871812556, 0.29777642455883324, 0.10634368387400173, 0.10537274691159837, 0.12378218758385628, 0.2083062325255014, 0.11753959755878896, 0.12260192044777796, 0.17936673306394368, 0.1441496142069809, 0.13907470449339598, 0.08342349188751541, 0.1466213518870063, 0.1661731136846356, 0.12572700041346252, 0.15050861751660705, 0.1318847926449962, 0.0992110138759017, 0.10522630633204244, 0.23474607471143827, 0.1234865011065267, 0.10147031920496374, 0.06525473712827079, 0.1028355814923998, 0.09047696730704047, 0.0979501569236163, 0.06438485841499642, 0.20511468581389636, 0.18344812968280166, 0.17363810999086127, 0.16996813035802916, 0.23121567821362987, 0.10058488507638685, 0.13674410845851526, 0.15097679395694286, 0.1394165080273524, 0.1304252998670563, 0.21595381200313568, 0.13474658830091357, 0.11529161740327254, 0.09407878809724934, 0.17028692731400952, 0.20804363099159673, 0.10883934839512222, 0.09949781684554182, 0.08976770419394597, 0.13501244044164196, 0.1041654433356598, 0.15848087175982073, 0.12373084580758587, 0.14592331746825948, 0.132697963854298, 0.1655727013712749, 0.18026176316197962, 0.1035369184683077, 0.1542336496640928, 0.21333570795832202, 0.14311301201814786, 0.1487932025338523, 0.11278220088570379, 0.1271944638574496, 0.15150360006373376, 0.12391839394695126, 0.0722380647493992, 0.1130182335327845, 0.17469316197093576, 0.1372881917632185, 0.0773959762591403, 0.10280521280947141, 0.14559300238033757, 0.07905298421974294, 0.10418792298878543, 0.11288542620604858, 0.12536547059426084, 0.15468760655494407, 0.09649285348132253, 0.10442561804666184, 0.1816825455171056, 0.15846248134039342, 0.15547192306257784, 0.12824829871533439, 0.11980350420344621, 0.11609872526605614, 0.17561713582836092, 0.1173855054366868, 0.29297855857294053, 0.09066321668797173, 0.17736735753715038, 0.1072902709711343, 0.22173319797730073, 0.11731004386092536, 0.13663422607351094, 0.1938391916337423, 0.13776456151390448, 0.162275769689586, 0.12471197987906635, 0.21876431041164324, 0.16968161682598293, 0.13056237454293296, 0.15766192664159462, 0.15520287968683988, 0.08911274402635172, 0.26481871493160725, 0.11030878595192917, 0.17973488284042105, 0.14755362295545638, 0.0816163548734039, 0.14013429841725156, 0.15602869709255174, 0.14449506910750642, 0.15153120795730501, 0.13946845836471766, 0.09713674822705798, 0.21223646850557998, 0.11294396681478247, 0.15127423190278932, 0.1502475596498698, 0.09872589420410804, 0.12015092579531483, 0.13184266834286973, 0.08661092710099183, 0.14730344497365877, 0.1912146754330024, 0.12752611481118947, 0.2130575806950219, 0.09269066766137257, 0.17840554792201146, 0.10019663051934913, 0.1219470938667655, 0.2063654866651632, 0.10862258932320401, 0.1108233243576251, 0.13859183352906257, 0.16524620092241094, 0.0798587265308015, 0.18546458944911137, 0.11652457702439278, 0.06288379052421078, 0.1313672782271169, 0.138647687563207, 0.15544047084404156, 0.13053818052867427, 0.17912308598170057, 0.1760848966659978, 0.12892647326225415, 0.06997346790740266, 0.11678436581860296, 0.09223624321748503, 0.2594177203718573, 0.19019808154553175, 0.04696454845543485, 0.14989094284828752, 0.06066115471185185, 0.06714149916660972, 0.1154530345229432, 0.17920495971338823, 0.20388558536069468, 0.13729764672461897, 0.20006665668915957, 0.14015798777109012, 0.12729351088637486, 0.15510674187680706, 0.20283471909351647, 0.1126429888245184, 0.12135434051742777, 0.12154151016147807, 0.12436394230462611, 0.17823549220338464, 0.08216293179430068, 0.22181388427270576, 0.08880632609361783, 0.11476129351649433, 0.13043367129284889, 0.11811644668341614], [0.020654587679018732, 0.023596503742737696, 0.0748661655234173, 0.015983144694473594, 0.02728097009821795, 0.03989266406279057, 0.04285386297851801, 0.059462218850967474, 0.02769120706943795, 0.08266615986940451, 0.052507259824778885, 0.024291747686220333, 0.025261153969040606, 0.029323610979190562, 0.055828148033469915, 0.028175365659990348, 0.011731934482668294, 0.020806336469831876, 0.022962917428230867, 0.04400208046718035, 0.026669397739169654, 0.024506979789293837, 0.027745628758566454, 0.024473024677718058, 0.016636242071399465, 0.08888025884516537, 0.010464490042068064, 0.046146916938596405, 0.043219923609285615, 0.026951827603625134, 0.08058495513978414, 0.055770802282495424, 0.057099235491477884, 0.036076370015507564, 0.031274848952307366, 0.03080151273024967, 0.05648876336636022, 0.02091994072543457, 0.02958160563139245, 0.008998221455840394, 0.014379969343281118, 0.07171962264692411, 0.017685718667053152, 0.026615243223204743, 0.026129084544663783, 0.05368249891034793, 0.05643681302899495, 0.012412160140229389, 0.03911601394065656, 0.027687531583069358, 0.05797199744847603, 0.0018908320225818898, 0.07571441805339418, 0.026722834227257408, 0.03699108929140493, 0.028646846512856428, 0.010870914229599293, 0.04802172668860294, 0.03179522063874174, 0.05800428829388693, 0.01796587384887971, 0.018155260659113992, 0.03627695026807487, 0.058727793220896274, 0.04104867039131932, 0.039737985644023865, 0.04725118073110934, 0.024118359724525362, 0.023463898651243653, 0.03154513171466533, 0.004889072688456508, 0.017653130962571595, 0.02978551998239709, 0.0360782216739608, 0.06602215493330732, 0.0025421589134566602, 0.019868976123689208, 0.026688047910283785, 0.04345045694208238, 0.012530468684417428, 0.04550700010440778, 0.011777837244153488, 0.05242786486633122, 0.035717741993721575, 0.038574127393076196, 0.015506377894780599, 0.009298358963860665, 0.04603611429047305, 0.008228948281612247, 0.034500567853683606, 0.04787554957147222, 0.05829287983942777, 0.05170795935555361, 0.056576481511001475, 0.02041034502326511, 0.04486872712732293, 0.06679012192762457, 0.021386935295595322, 0.03006535604072269, 0.02410381548543228, 0.054257266310742125, 0.058226431647199206, 0.09239680686732754, 0.038299696025205776, 0.02793303588987328, 0.01641100210690638, 0.07643178541911766, 0.06787543868995272, 0.02024316883762367, 0.039759741703164764, 0.006456942219301709, 0.020389820929267444, 0.007828567031538114, 0.0833146707736887, 0.005221136461841525, 0.06212759770278353, 0.03195248915289994, 0.051738487600232475, 0.05154599675734062, 0.040142059078789316, 0.04527533128566574, 0.03482329077087343, 0.04780372451932635, 0.009353894802188734, 0.07314810107345693, 0.012640228615055094, 0.03987827010860201, 0.006889335081723402, 0.06680545469862409, 0.05555272589845117, 0.11428554716985673, 0.005945382145000622, 0.11741185167920776, 0.052632059378083795, 0.06411712121916935, 0.029852906991436612, 0.01727472284983378, 0.033107296912930906, 0.03892354165145662, 0.03819023295363877, 0.030039631346880924, 0.02666382977622561, 0.016216650328715332, 0.006889836031405139, 0.014122866195975803, 0.023029729272820987, 0.009509286610409617, 0.040415833645965904, 0.06682389706838876, 0.012920218669023598, 0.039144334295997396, 0.0712500064400956, 0.029942894252599217, 0.060749162294087, 0.055351767150568776, 0.015173900374065852, 0.019750471838051453, 0.04921357503917534, 0.011032759939553216, 0.02410622746538138, 0.0077981937101867516, 0.04691230868047569, 0.041943303440348245, 0.025132671507890336, 0.11612144240643829, 0.0334435269178357, 0.037707844385295175, 0.020756269332196098, 0.03765061737794895, 0.007796371737640584, 0.05448022231576033, 0.014276395213528303, 0.08060333813773468, 0.06065094275982119, 0.024269730020023417, 0.049864338361658156, 0.014858490394544788, 0.004200820239930181, 0.04773959924932569, 0.05646856581734028, 0.07928429680760019, 0.06724968203343451, 0.04511760263994802, 0.031304408694268204, 0.0229954439055291, 0.091972921800334, 0.05800020277092699, 0.07850021778722294, 0.09449086559470743, 0.06111796144978143, 0.11098000657511875, 0.003915953348041512, 0.047074686881387606, 0.013788030501018511, 0.07912986329756677, 0.006936211448191898, 0.020004102661914658, 0.027059934400313068, 0.00806115240266081, 0.0510947524162475, 0.050450471753720194, 0.029438222700264305, 0.040666271379450336, 0.053557268911390565, 0.05625927275104914, 0.005128890288688126, 0.05508253823791165, 0.01789888945495477, 0.036173583939671516, 0.03911614010576159, 0.05898296585655771, 0.08050930060562678, 0.02214525251474697, 0.013396216418186668, 0.008363855886273086, 0.0465574878762709, 0.09223633969668299, 0.06649367103818804, 0.05115966065204702, 0.03256432311900426, 0.0491356792190345, 0.03417994150368031, 0.06677572426269762, 0.029176472780818585, 0.024136336396622937, 0.0691736108274199, 0.01688436430413276, 0.019289791089249775, 0.05165432063222397, 0.08877274391124956, 0.022236776021600235, 0.08251476174336858, 0.040861990564735606, 0.03594327325117774, 0.012716864639514824, 0.06451615918194875, 0.0332506241829833, 0.053778499423060566, 0.06454977105022408, 0.05846951840794645, 0.03251350826758426, 0.006729770084348274, 0.01681276931776665, 0.01350220345557318, 0.030554607619706076, 0.08604528440628201, 0.07384425043710507, 0.03768455208046362, 0.07743553273030557, 0.0032392183356932946, 0.03553848735464271, 0.09145717369392514, 0.019516301981639117, 0.013744480347668286, 0.035769692331086844, 0.013506159102689708, 0.04669631030992605, 0.05203926521062385, 0.028416407803888433, 0.03874442802043632, 0.01459097677070531, 0.038828576434752904, 0.06624280285905115, 0.007986212185642216, 0.02249643122922862, 0.02957404314656742, 0.08419333651545458, 0.048007789155235514, 0.06163078549434431, 0.06872931669931859, 0.03384018629731145, 0.06016449464368634, 0.02766626905213343, 0.02844446098606568, 0.028014588642690796, 0.05183448069146834, 0.045792292803525925, 0.035359997127670795, 0.03608233317208942, 0.025975083335652016, 0.02332015021238476, 0.021239965935819782, 0.05377459943701979, 0.009171350593533134, 0.025496759881207254, 0.04285400398657657, 0.017019750594045036, 0.024582474761700723, 0.028443585251807235, 0.033374533159076236, 0.03299295793112833, 0.01763945689162938, 0.027783107216237113, 0.04233897947415244, 0.06125290245108772, 0.018680152024899144, 0.012093985660612816, 0.00728223919395532, 0.02955392723379191, 0.07096304761944339, 0.10097464619320817, 0.04211626837786753, 0.014808692285441794, 0.008113462681649253, 0.042402722538099624, 0.01244182099981117, 0.0868340241140686, 0.03188272356055677, 0.049087142760981806, 0.02170331841625739, 0.05029403073422145, 0.051830740267178044, 0.06897923492942937, 0.024279043973365333, 0.018866119389713276, 0.005959382760920562, 0.006384680691553513, 0.018694082136789802, 0.020407623196661007, 0.03979323853855021, 0.016582031894358806, 0.020109530305489898, 0.022229152309591882, 0.000895230419928339, 0.050668511030380614, 0.042438219461473636, 0.036411163964658044, 0.02039085993601475, 0.05036744769313373, 0.05690244761353824, 0.07488764327717945, 0.016828094667289406, 0.010167586442548782, 0.08903385372832417, 0.021567486837739125, 0.06165417427837383, 0.06740197815815918, 0.06138036260381341, 0.04178384559054393, 0.02943812622106634, 0.05424333990958985, 0.027802297299786005, 0.02534246366849402, 0.0341989107982954, 0.02274873731948901, 0.006126000480435323, 0.0005680622120962653, 0.0350232364871772, 0.027079373103333637, 0.018182183921453543, 0.012586550928972429, 0.07070584149914794, 0.15751688129967079, 0.07025179555057548, 0.14173427975038067, 0.13054966897470877, 0.22370021586539224, 0.1707011050893925, 0.07503411354264244, 0.1313281522016041, 0.1530723221367225, 0.14254188485210761, 0.13141479052137583, 0.1352216221857816, 0.1443732381449081, 0.10979289683746174, 0.11986146593699232, 0.14857588685117662, 0.11743516253773123, 0.1478263919125311, 0.08309765937156044, 0.19524774339515716, 0.09783221481484361, 0.1300981908570975, 0.1637699652928859, 0.06149477951112203, 0.08834568987367675, 0.16988109127851203, 0.11782505724113435, 0.14280950330430642, 0.15233194077154621, 0.10150127418455668, 0.13860531093087047, 0.131596720602829, 0.16671078483341262, 0.09709751830087043, 0.1415828222525306, 0.21582567278528586, 0.16215790179558098, 0.11702776799211279, 0.1377575407968834, 0.11302481638267636, 0.17293491022428498, 0.22210965980775654, 0.11521920605446212, 0.13316394353751093, 0.12992632429813966, 0.16850822197739035, 0.13180309702875093, 0.15105615922948346, 0.08180615172022954, 0.13395906571531668, 0.14723145664902404, 0.12466212239814922, 0.17455715598771349, 0.2543309808243066, 0.09972847634344362, 0.13478259730618447, 0.12824016477679834, 0.1342508039670065, 0.09247034628060646, 0.10893803177168593, 0.1903206398128532, 0.11622647114563733, 0.1300170592730865, 0.1644422026583925, 0.18575324036646634, 0.11786575661972165, 0.142329111113213, 0.118797255854588, 0.1000635560194496, 0.2071199391502887, 0.176915820047725, 0.12537841364974156, 0.16561478114454076, 0.14798763091675937, 0.179771144175902, 0.17309470946202055, 0.11959898314671591, 0.10106210829690099, 0.09175965824397281, 0.07680625087232329, 0.134147600911092, 0.12870127597125247, 0.20393668964970857, 0.11008443470927887, 0.17508412536699325, 0.0842715217731893, 0.14458135119639337, 0.06382750550983474, 0.10204799953498878, 0.1250803968287073, 0.20775150682311505, 0.1322092892951332, 0.1363487367052585, 0.18223213555756956, 0.1631261670263484, 0.11531380019732751, 0.11740966976503842, 0.14364866452524439, 0.12506932398537174, 0.11905852152267471, 0.1450067205587402, 0.1733460748801008, 0.13979439478134736, 0.10695381832192652, 0.08669568036566488, 0.11382042095647193, 0.10336160092265345, 0.18825976992957294, 0.13677055860171095, 0.1225148887897376, 0.1291765770292841, 0.11331046902341768, 0.1728848449420184, 0.10857564106117934, 0.0915282937057782, 0.10012902828748338, 0.1433195814024657, 0.14234165340894833, 0.16766788816312328, 0.09247756737750024, 0.12809828098397702, 0.17578446044353768, 0.09228639013599604, 0.13032818242209032, 0.16472340241307393, 0.12877428845968097, 0.169076380552724, 0.14639864821219817, 0.1523589252610691, 0.21940871723927557, 0.2798159758094698, 0.12986851099412888, 0.20439613843336701, 0.15523007197771221, 0.2373309453832917, 0.10455726020154543, 0.1676003378815949, 0.12636095780180767, 0.22241591446800157, 0.12653899902943522, 0.132444906339515, 0.14255916205001995, 0.1940627710428089, 0.1278030694811605, 0.051560015926952474, 0.09617106567020528, 0.11274037344264798, 0.10364090077928267, 0.17164860502816737, 0.14908125973306596, 0.10003957722801715, 0.23501925927121192, 0.12149669928476214, 0.12305834869039245, 0.1776814492768608, 0.11198546824743971, 0.18443785782437772, 0.18443785782437772, 0.06402197046554647, 0.1050221043988131, 0.12783109297743067, 0.17034043616149575, 0.15124160709092394, 0.1424444408621639, 0.21146408573258668, 0.10257718051434495, 0.11298665514914319, 0.08922527587856166, 0.15027132321847603, 0.11912650224985555, 0.10059554973850027, 0.16161966661456972, 0.15117285453015938, 0.08714835334103554, 0.06992298702243716, 0.1755769262672402], [0.05162040077266283, 0.009486051822023, 0.08405061409575865, 0.017857893217296805, 0.046191946748876944, 0.056770697847241536, 0.035225824249209836, 0.015767988661536947, 0.07373780419584364, 0.03699983179103583, 0.05534788200748153, 0.04176944050414022, 0.03036774040083401, 0.036317441845312715, 0.08646997099276632, 0.08840126189170405, 0.06508172766189091, 0.045250788461999036, 0.08255298977019265, 0.020854796857747715, 0.02192395149904769, 0.01961864785698708, 0.005749977908635628, 0.02066563454718562, 0.03551723224518355, 0.02956860505946679, 0.030778650871070568, 0.02638315323565621, 0.042354523757239804, 0.01867071376182139, 0.08194356778403744, 0.04316468184697442, 0.06694905285257846, 0.03567168430890888, 0.03716623985383194, 0.055345191722153686, 0.06810071761719882, 0.016720919265935663, 0.0843361034640111, 0.020991162782593165, 0.035999884275952354, 0.03264985563873779, 0.028077207352907863, 0.012467379638110287, 0.07032371708191931, 0.058527324290480465, 0.028766397226718254, 0.08655700265080668, 0.035539340824470855, 0.027178154814464506, 0.05121578185935505, 0.0788089215348009, 0.04211540006508585, 0.01771975170413498, 0.020823652630497236, 0.007444125722031458, 0.06371050592861138, 0.018882815857068636, 0.029804802834405564, 0.03185707493685186, 0.021288554344209842, 0.04590353702951688, 0.06266919110203162, 0.08135394629789516, 0.01703843972791219, 0.01124193890063907, 0.02656392000062624, 0.033235859154956415, 0.059758432253147475, 0.03884784258843865, 0.04897990613244474, 0.03753285709535703, 0.08966160676209256, 0.061328772208071314, 0.05888755535124801, 0.045163133399910294, 0.024102138231683057, 0.04096110809769016, 0.03812430426478386, 0.06039089792466257, 0.04211971194308717, 0.06403216015314683, 0.03397563938051462, 0.035964884591521695, 0.035120784377795644, 0.03995704166300129, 0.012555184057418955, 0.055760464165359735, 0.01341801607850357, 0.09392930471221916, 0.040259500237880275, 0.031238595038303174, 0.05456545055494644, 0.030241729291446973, 0.06306983952526934, 0.013647482574015157, 0.03126165727735497, 0.008561492595617892, 0.031748005203553475, 0.09029768669279292, 0.027001826092600822, 0.028295693773543462, 0.006273941125982674, 0.008671677405800438, 0.0899203862354625, 0.057768867918639444, 0.019551591103663668, 0.07133962819352746, 0.06746376195224002, 0.039643068666919135, 0.0286196968954755, 0.008379317605431424, 0.040904860725277103, 0.03744617795746308, 0.003959728001063922, 0.057377889679628424, 0.017526542833365966, 0.027433607610873878, 0.049047894281102344, 0.010153569128306117, 0.04984764746041037, 0.07020337041467428, 0.03522514889482409, 0.06339893749100156, 0.03316266112960875, 0.04154413931246381, 0.08130676797009073, 0.04998289645300247, 0.08933465360314585, 0.013782776095467852, 0.03935721193556674, 0.030271268624346703, 0.038120994286146015, 0.03789143687754404, 0.026900257616944145, 0.0316757831024006, 0.02430179822113132, 0.0604900859616464, 0.039770588191458955, 0.03863324687699787, 0.031757712495164014, 0.04216510169499088, 0.036188178273732774, 0.06056689082470257, 0.04282749447156675, 0.045079189076204784, 0.04533501109108329, 0.062223319910117425, 0.08022464244277216, 0.0179480159204104, 0.030245425186876673, 0.018789093737723306, 0.039266617968678474, 0.041177284583682194, 0.021972417453071102, 0.045694852524320595, 0.029221161203167867, 0.0728467816952616, 0.03753755860088859, 0.00647941259558138, 0.028288470821280498, 0.02014809229876846, 0.03937602537916973, 0.007111268314474728, 0.0815102129126899, 0.0371491853002226, 0.027335484555806033, 0.015774311759741977, 0.036412726185517386, 0.015502580881729955, 0.025635320707806386, 0.05367125908378512, 0.04591164499288425, 0.07790759060299024, 0.04764353194332216, 0.03293137822765857, 0.017503912895335816, 0.04590258336975239, 0.07011028283159249, 0.03314375862828456, 0.030028680957912002, 0.023722861806163564, 0.020289165295253042, 0.04656051954953, 0.07644918136065826, 0.03028385544894263, 0.014546981328749098, 0.0491897261235863, 0.04061840285430662, 0.015060326732054818, 0.08870149773429148, 0.04492710817430634, 0.026429246172483545, 0.044734676703228615, 0.04849849719903432, 0.0326265484909527, 0.0311972908093594, 0.03513842151733115, 0.021461304058902897, 0.023615046302438714, 0.01903487449453678, 0.015556489561276976, 0.03916749672498554, 0.05173688456125092, 0.032035724725574255, 0.05110541336762253, 0.0954280051519163, 0.0021053488808320253, 0.05859953897015657, 0.03730653173988685, 0.03555859955667984, 0.08040044238441624, 0.024844113358994946, 0.015620063786627725, 0.05041695636464283, 0.051928388347732835, 0.022918618633411825, 0.02706624822167214, 0.00615921669123054, 0.011550726139830658, 0.008259009900939418, 0.07976215085363947, 0.060259567471803166, 0.1315519690979272, 0.021685813007934485, 0.0248448759157327, 0.023175700443971436, 0.050639363180380315, 0.04053838078107219, 0.017261197208426893, 0.04957658544299193, 0.03815954514720943, 0.06577029227628373, 0.04321964530390687, 0.09609879532945342, 0.09325235470896587, 0.01835042508901097, 0.04357716010417789, 0.0628965554642491, 0.06593681537196971, 0.04191900552541483, 0.03957645720220171, 0.05774368313723244, 0.016624603340460453, 0.09253984841052443, 0.017462302530475426, 0.032749700476415455, 0.04183619668765459, 0.07903859397629276, 0.0191255000027013, 0.03799642850935925, 0.057314565929118544, 0.03449086798354983, 0.013056918560323538, 0.02880235613702098, 0.0576180709322216, 0.019629952621471602, 0.07643105811439455, 0.056902781579992734, 0.04856349449255504, 0.06207035214174539, 0.020612788066500798, 0.07724506052909419, 0.08798139184364118, 0.012464905503293267, 0.04256309322954621, 0.026504412744543515, 0.022213121919776313, 0.030201913068594877, 0.031708515525679104, 0.013719583148485981, 0.1000858649786096, 0.05135265244462062, 0.027534626897249836, 0.030840815015835688, 0.05131117381097283, 0.07102313931682147, 0.055364298314088956, 0.05627280210319441, 0.06769474799511954, 0.04627405425708275, 0.04551989120955113, 0.06905932008521631, 0.06361471692798659, 0.01020288484141929, 0.08489764950354584, 0.02169635336031206, 0.03042478743736865, 0.027152782640769146, 0.01882934411696624, 0.03231070899346378, 0.017263941299461294, 0.017516791012894828, 0.029276668283273466, 0.015941222627589013, 0.030832790544081945, 0.018900900140579324, 0.06460829681600444, 0.04929008675389923, 0.032594146323390305, 0.05575621165917255, 0.030133513027976733, 0.014160306618578034, 0.02755408415396232, 0.09092179578146897, 0.04104767591343261, 0.02190467421314679, 0.013836460275342688, 0.017876125930342823, 0.051479693283909, 0.025288888027716894, 0.07822137064067647, 0.07619834286742844, 0.07733320540864952, 0.012518755738710752, 0.04525814685621299, 0.02417267194687156, 0.021507012934307568, 0.057040605825022794, 0.050570658859214745, 0.03295311573310755, 0.0332296436681645, 0.08735111550777219, 0.09301002122811042, 0.027873593571712263, 0.02498607507732231, 0.03459462765022181, 0.026339136456954293, 0.03566679726645816, 0.03770284602069296, 0.02874869700463023, 0.03778749538469128, 0.0254712095920695, 0.023888087998784613, 0.030738658388145268, 0.016995859004964586, 0.044273661987972446, 0.039704062073724344, 0.0436234144581249, 0.026675680019252468, 0.0335574169002939, 0.0988763126952108, 0.05840450256073382, 0.01836514929891564, 0.028089031620766036, 0.034343510851613246, 0.041217520119971596, 0.10791997585329227, 0.034169332502642646, 0.036025132139911875, 0.04378445679321885, 0.050523102036095224, 0.10697527381125838, 0.07264385625603609, 0.15501749119721353, 0.10646368173183873, 0.08663854241603985, 0.21676251548342407, 0.18315857334528118, 0.1724942377768457, 0.22022129473043606, 0.09618922602385283, 0.21051547257229686, 0.12461864738725126, 0.10960129657178186, 0.13293374417116866, 0.13337898824829608, 0.15109360800124705, 0.11500700376927853, 0.17521912202937528, 0.20014732814161107, 0.11902896920219064, 0.10829882739926688, 0.08852119295625016, 0.08372894502826966, 0.10824113283888437, 0.14046176365809515, 0.1507720205700025, 0.14322188508231193, 0.12607592856511474, 0.11359831842128187, 0.15841859072679654, 0.2524089073995128, 0.11648795945802703, 0.18874629226047546, 0.1187787986418698, 0.09104140030103736, 0.10393217889941297, 0.13491340825567022, 0.15257603314239532, 0.15444048622157425, 0.20103333372389898, 0.10502220829948783, 0.12125085544539616, 0.10227051767287776, 0.1036510310950689, 0.12689707044046372, 0.1259755456703715, 0.12002605944871902, 0.17525052971905097, 0.14577546680811793, 0.10437821707455441, 0.18779623933369294, 0.13562540989369154, 0.23442954872734845, 0.09215229147230275, 0.1323891562060453, 0.19481680792523548, 0.14384301815880463, 0.11009771173121408, 0.1313988195033744, 0.1400616718456149, 0.09801813022932038, 0.10854720196221024, 0.15708435763372108, 0.15283545828424394, 0.12305139476666227, 0.08239640403189696, 0.15323701954912394, 0.08124939995468594, 0.18288470600964502, 0.1100609902641736, 0.15746594028314576, 0.1304209657246247, 0.18468287045834586, 0.1326604705536738, 0.12022138529573567, 0.2629890537355095, 0.14091392455156893, 0.13788014359306544, 0.18399530032183975, 0.1736903571872972, 0.20082250441191718, 0.23289759265026078, 0.1416185195557773, 0.17564064706675708, 0.15719217684818432, 0.0894062189036049, 0.11995104316156358, 0.23798649926902726, 0.11085100646596402, 0.25783287885133177, 0.11165224394062534, 0.07952300118631683, 0.2442029508529231, 0.10528680621064268, 0.17644532810663804, 0.11667507715173997, 0.1115236000623554, 0.16115606180392206, 0.116444454761222, 0.24856844160240144, 0.16818722826428711, 0.11351894572726451, 0.13548115122830495, 0.14222197467461228, 0.17143698903964832, 0.14406020025489852, 0.14821236807620153, 0.21082822844618931, 0.2726410998729989, 0.16583438264206052, 0.1179582579061389, 0.06706277214107104, 0.11518937913933769, 0.3091763472184539, 0.06750321452273056, 0.1517462229821831, 0.11053638780140318, 0.13554528763052076, 0.1448228460503742, 0.17067866254365072, 0.1450480433413759, 0.15456488501513377, 0.12696417543338612, 0.1434289591270499, 0.13380483258515596, 0.2339272780227475, 0.15102095174370334, 0.06966071203351021, 0.22387396747944877, 0.14329084544442594, 0.10443816034239717, 0.12424340267898515, 0.22105520154582337, 0.08472253975924104, 0.10905310919042677, 0.1762945088557899, 0.17516037361929193, 0.246251946373377, 0.1481940964004025, 0.2425195966497995, 0.08534355409210548, 0.13215808110544458, 0.19003458641236648, 0.23286913870833814, 0.1639851732761599, 0.22834264644188806, 0.16236231895163655, 0.12999225669773296, 0.202187328832224, 0.09139112997218035, 0.12207963402033783, 0.09085201163543388, 0.07670199396670796, 0.08399897546041757, 0.2063258262933232, 0.08964371358160861, 0.12027179196593352, 0.2671526506310329, 0.1403482150635682, 0.08037897947360761, 0.18212391558336094, 0.22819708159659058, 0.14787311753025278, 0.17351384478388354, 0.2284813389996998, 0.1304003785480745, 0.15877035388257354, 0.08827599478536285, 0.1528545908513479, 0.1525520914583467, 0.1424778820364736, 0.14134646306047216, 0.12811448948923498, 0.1653784664813429, 0.19651313486974686, 0.10352405704907142], [0.015927659878798295, 0.05344647739548236, 0.039418145970557816, 0.04474171597394161, 0.02333375006855931, 0.05098701854876708, 0.06860659515950829, 0.013445784461509902, 0.06985507308854721, 0.030501429027935956, 0.05166015020222403, 0.012950594773428747, 0.027866264863405377, 0.03201713763701264, 0.053013638316770084, 0.004130114439249155, 0.018312916945433244, 0.017072936607291922, 0.05966956006886903, 0.10373211072874255, 0.046148857654770836, 0.055000033680698834, 0.03673723025713116, 0.025076255296880845, 0.04256673717463855, 0.015158024907577783, 0.010663616612873739, 0.0972586905118078, 0.07004074359429069, 0.01578882260218961, 0.026467980715096928, 0.01871229258540552, 0.04484785422391724, 0.040967520253616385, 0.03861333134409506, 0.02002099579840433, 0.03698329674080014, 0.049185959724127315, 0.10281102382577956, 0.06395555566996336, 0.015524768314207904, 0.0633343038498424, 0.014342315553221852, 0.02261287791043287, 0.04354706601588987, 0.031219521843013354, 0.028587229789991397, 0.027211005981371272, 0.023936826692079194, 0.02575386024545878, 0.0474622178444406, 0.04656733617594, 0.01012340268061962, 0.031699049432063475, 0.011873761686729267, 0.046061859393375926, 0.010273228381265653, 0.04823793286050204, 0.013536858041334199, 0.020692014186352026, 0.015259225092449924, 0.02372952258156147, 0.008735457577131456, 0.02608121601952007, 0.08928886309149675, 0.050954234175151214, 0.036860771870124154, 0.04373200921691023, 0.061355719590210356, 0.0744914477400016, 0.026489631018193904, 0.06270750818657689, 0.052909566948073916, 0.02287122879351955, 0.057088607936748303, 0.018272807574248873, 0.03917214256944135, 0.02835599698300939, 0.06490779793239199, 0.02981348410685314, 0.052642156297224574, 0.009441242800676264, 0.03750716394279152, 0.008082281347014941, 0.036160488743917085, 0.03161786218697671, 0.032117913870024495, 0.01387077996696462, 0.0013997025780554395, 0.032503830661880784, 0.012749991328746546, 0.021212380306678824, 0.11028926004655659, 0.0138849707582267, 0.04614553283317946, 0.05733509373385459, 0.05379486749006901, 0.053745195546071045, 0.023220939910970628, 0.03321366151794791, 0.011014698848157423, 0.09625382997910492, 0.05690494494047016, 0.0160709852934815, 0.056196680016000755, 0.03867490362608805, 0.017747647179930937, 0.03575602197088301, 0.02457926868373761, 0.014821561126154847, 0.04212069899949711, 0.01539697048428934, 0.025248977181036025, 0.03551879446604289, 0.021465447098307777, 0.01320946237683529, 0.06513705477118492, 0.04817176297365222, 0.05818435558467172, 0.052170721828588285, 0.06532785351737402, 0.026473133075342048, 0.04174267865892034, 0.04061696308781393, 0.048192676695180126, 0.012726311251753941, 0.0114641147229122, 0.02265036750031868, 0.05469629119033925, 0.03041331012354931, 0.04337593789387029, 0.029493592483049724, 0.019758344169531483, 0.016813372312753927, 0.046617423722636886, 0.046242316311690956, 0.02658773180883145, 0.07357384893111885, 0.021916773075645324, 0.03674301158753224, 0.0799320952501148, 0.044830384067608975, 0.01329267197434092, 0.02087161577946972, 0.0358388196764281, 0.009898029129544739, 0.027849496036651544, 0.0149356616930163, 0.017998435578192584, 0.06043769033567514, 0.049380083291907795, 0.033931552097783424, 0.028239422281330917, 0.024853236209310126, 0.022784616448916495, 0.037143088557058945, 0.09380735500599258, 0.014713362488691928, 0.03657115245005116, 0.10096899844938889, 0.019873605269822292, 0.06638867940637283, 0.055125601356849074, 0.06688637105980888, 0.02051488951110514, 0.02043565225903876, 0.08628415205748752, 0.023706885222054552, 0.019288965449959505, 0.05540023310459219, 0.0718713844253216, 0.040165136160794646, 0.06311675810138695, 0.054470496470457874, 0.026116625740542077, 0.03382956616405863, 0.04687483022280503, 0.03365176984516438, 0.05132807251357008, 0.06100612350564916, 0.02487626319634728, 0.05107985380163882, 0.009864146377367433, 0.06896486695040949, 0.00986655928500113, 0.06655696881352924, 0.035762014813371934, 0.021824357136210892, 0.03746245325601194, 0.018290919688297436, 0.06202358941663988, 0.056602449258207344, 0.045105390599928796, 0.035813371432595886, 0.03611123982409481, 0.024467790681228507, 0.017888662659970578, 0.08450804423773661, 0.06198364331794437, 0.02903554264776176, 0.034160794093622826, 0.03838105025351979, 0.034523106878623366, 0.04523856900050305, 0.043931168256676756, 0.036910325070493855, 0.03705008261022158, 0.05134488957992289, 0.05520256578165572, 0.04394433766719885, 0.015081116143846884, 0.01017568049064721, 0.02801690970954951, 0.03752532800717745, 0.016429526112915482, 0.07037426476017572, 0.059651247574947774, 0.07884116042987444, 0.027384649984014686, 0.012200780711282277, 0.03285607621364761, 0.02254708466352895, 0.0649483414599672, 0.038286875424091704, 0.060830909860669635, 0.004641110945158289, 0.04020847758511081, 0.10019342444138601, 0.011723073239409132, 0.05819614831125364, 0.04019005747977644, 0.03723715206433553, 0.12005569340544753, 0.012176823256595526, 0.09545669658109546, 0.030890138150425628, 0.019340995568200015, 0.02405979499599198, 0.031826190461288206, 0.024499185383319855, 0.06470211912528612, 0.06700261365040205, 0.02158127408620203, 0.018021436590061057, 0.04995468370907474, 0.04899692728940863, 0.028100366071157623, 0.0539935478445841, 0.04533541185082868, 0.09841217353823595, 0.030483706541417632, 0.05242822480795439, 0.046495859933202155, 0.0496377198578557, 0.02363669846090488, 0.038740546588087454, 0.01951609974639723, 0.012048575499647995, 0.0469317826355109, 0.07624823003425263, 0.07692142477026209, 0.009528909922664752, 0.026923653822450433, 0.027475490715005435, 0.029577573914139066, 0.054342323855962604, 0.019899459839507472, 0.00541557961696526, 0.05731278106395621, 0.010075928421429126, 0.020055153145221993, 0.04068712943990249, 0.028269314134377055, 0.06321101085632108, 0.015576032164972275, 0.03568900232494343, 0.006374737768055638, 0.09965796489268541, 0.037385559335234575, 0.008353544671990676, 0.05164815338503104, 0.05189179675653577, 0.06220723756996449, 0.018057636698358692, 0.055998619354795665, 0.024039350682869554, 0.04507940429903101, 0.018689013268158305, 0.0021347460460674483, 0.019121330988127738, 0.039426176008419134, 0.03422386180318426, 0.05938843823969364, 0.06478785202489235, 0.019506635508150794, 0.0129600775653671, 0.007629444171470823, 0.0409038439829601, 0.012018779198115226, 0.07163253161706962, 0.05264715466182679, 0.03234361211070791, 0.08426111686276272, 0.06444412632845342, 0.03044040593522368, 0.018474757089279592, 0.05025333877711091, 0.055101848920457996, 0.019264513539383188, 0.03771153285924811, 0.0476766094652703, 0.09035086157382466, 0.010604853359836852, 0.09186617127852514, 0.01951224243384786, 0.03244510451622773, 0.031175768526736647, 0.053315889090299606, 0.030685717283631675, 0.01420191327270004, 0.023336625890806317, 0.073599267489044, 0.04400239216920454, 0.029805261110595893, 0.03236330871004611, 0.05395970591052901, 0.06707866152282804, 0.02971018271637149, 0.01479728176491335, 0.01969086253666319, 0.05867887826752849, 0.011843935699289432, 0.0447072803217452, 0.006597876990781515, 0.023123369755921885, 0.05978452987619676, 0.006654996850556927, 0.017378354496031534, 0.10252200183458626, 0.0707147250068374, 0.034318147954763845, 0.03598559051170014, 0.0834957770712208, 0.02676704210898606, 0.02987634030432673, 0.039137436033342965, 0.02421174602204701, 0.06656660931184888, 0.006184869489516132, 0.01845979168138001, 0.03274356662586797, 0.01887099901068723, 0.1164283649995923, 0.15376455296063796, 0.15306018060073256, 0.1344355393666774, 0.11281578306807205, 0.14531968423398212, 0.12200659184600227, 0.07459002721589059, 0.11571690512937494, 0.15863894921494648, 0.11283066312898882, 0.052029123762622476, 0.08427629378275014, 0.11741951806470752, 0.095763856661506, 0.10749608336482197, 0.07023657410172746, 0.13918626413214952, 0.11501536035211757, 0.1644096223753877, 0.12665174610447139, 0.1974837898160331, 0.1915652066236362, 0.15140718023758382, 0.11532991222338751, 0.1506823839736171, 0.09542950429022312, 0.22287401254288852, 0.09762677349499427, 0.0738471002841834, 0.08912676319596358, 0.09757947642356157, 0.14028306934051216, 0.17134371591964737, 0.08572165606892668, 0.14066131232539192, 0.15195886313449591, 0.12616831110790372, 0.2560925722355023, 0.168414770741947, 0.12978570215636864, 0.2187128647346981, 0.09269523929106072, 0.07147393465857022, 0.10204074133071117, 0.1724195628776215, 0.14647746429545805, 0.09807983238715678, 0.11117372938315384, 0.09107325327931903, 0.176714371482376, 0.15221147536067292, 0.0702599591750186, 0.13480742956744507, 0.07053180786897428, 0.09859682730166242, 0.1410634524654597, 0.07933646978926845, 0.17108763044234365, 0.10377340382547118, 0.07260646685608663, 0.1161138947645668, 0.1324657310033217, 0.1094312037457712, 0.20112034311750904, 0.19399441924178973, 0.12885852222098038, 0.15209414181299508, 0.2382272222894244, 0.20878343348158523, 0.23102510953322053, 0.174493835947942, 0.1637267871410586, 0.1587754747015424, 0.13334530958672985, 0.11644778700429015, 0.2068605288513936, 0.1562218484468758, 0.15817650215467438, 0.14999329985585064, 0.15856618905672804, 0.06557756394613534, 0.09306817592005245, 0.21056981262518093, 0.1614938280545175, 0.08022026377147995, 0.12345438095508143, 0.129209884617012, 0.2720567327924073, 0.11937880277400836, 0.06664009677479044, 0.10121119834366255, 0.27057225932367146, 0.12340476096142083, 0.11636556446319446, 0.10334263904951513, 0.13829504867317155, 0.1483742898562923, 0.09883611797704361, 0.08712042632396333, 0.09281000500777736, 0.24139019631547853, 0.09034867965965532, 0.0806051935069263, 0.1281718723475933, 0.16705672955140471, 0.10372069649747573, 0.16843246354255825, 0.1561601462890394, 0.07202405904536135, 0.19657844386529177, 0.11197984276805073, 0.217265454120934, 0.09204419024172239, 0.13602106366306543, 0.12866615754319355, 0.28304072620812804, 0.10953217293717898, 0.13092921813949943, 0.23130270245019346, 0.15995544497855008, 0.14354593644384295, 0.12229514628415927, 0.15858285769354552, 0.1208972888707649, 0.1304466588771902, 0.1552920858375728, 0.19363517523743212, 0.12597803928656504, 0.09369192135636695, 0.14050927595235407, 0.1778826751979068, 0.12777816300513223, 0.17897717974847183, 0.21287916839355603, 0.24053362431004643, 0.0932550709694624, 0.17912028066348284, 0.2248602668987587, 0.08285061325295828, 0.12944660003995523, 0.10659503444912843, 0.11192123536602594, 0.0977345927094575, 0.14616432250477374, 0.1263972488231957, 0.1092143333517015, 0.1317440962884575, 0.0911302502208855, 0.13548239803640172, 0.2197115431772545, 0.14069852360989898, 0.1485049820621498, 0.11572414849069901, 0.2031966793583706, 0.11911410838365555, 0.17937626224011183, 0.18610972358146682, 0.12459458695957437, 0.1374316934379749, 0.1167447425541468, 0.14740341226570308, 0.1558867539279163, 0.24464227259159088, 0.12950813892530277, 0.09121580500504933, 0.2008788037346676, 0.17324212967650965, 0.12376093989587389, 0.10000088164815679, 0.1750908640678972, 0.19578004139475524, 0.08041720750043169, 0.13647319487063214, 0.2825567271793261, 0.09949153827619739], [0.058445513641345315, 0.041553679620847106, 0.03620630151999649, 0.1007159186701756, 0.03291732195066288, 0.06443160629714839, 0.06827867720858194, 0.054067447199486196, 0.039439145039068535, 0.07206020163721405, 0.07802939930115826, 0.018811276531778276, 0.049835372337838635, 0.02553384500060929, 0.036216146108927205, 0.019614380507846363, 0.013746655768045457, 0.056994852420757525, 0.07448094635037705, 0.015889300120761618, 0.019166819074598607, 0.016884646320249885, 0.026782608656503726, 0.025191922723024618, 0.03613405715441331, 0.011520512380229775, 0.014158688736642944, 0.012293067702557892, 0.027241456300544087, 0.05618195951683447, 0.05857583477336448, 0.002841041032297653, 0.03336673318699468, 0.015592721210850868, 0.0335686159087345, 0.08268951525678858, 0.07457497646100819, 0.04165582140558399, 0.02851773693691939, 0.017238936488865875, 0.022238681485760026, 0.017779247828002553, 0.04523813113337383, 0.03252529728342779, 0.0466993753798306, 0.021253771737974603, 0.05627581151202321, 0.019905604822270107, 0.025842320537776686, 0.03391484264284372, 0.07693202263908461, 0.09392543812282383, 0.014495662744593574, 0.0950177681806963, 0.023721026846033055, 0.04031040414702147, 0.034098457399522886, 0.005858241484020255, 0.0759790456504561, 0.042131564041483216, 0.0470780970499618, 0.06223326097824611, 0.014416436624742346, 0.025159531687677372, 0.03198139209416695, 0.04107608903723303, 0.09965137462131679, 0.004269666032996611, 0.047796291910344735, 0.06447423525969498, 0.03676284548419062, 0.06472721113823354, 0.09166277828626335, 0.08038226718781516, 0.026581514466670342, 0.027097052916360553, 0.04011927143437788, 0.03597561604692601, 0.022927190439077094, 0.05587490333709866, 0.046341122142621316, 0.08877688509528525, 0.022795206896262243, 0.01437266104403534, 0.008918496241676621, 0.016323478776030242, 0.008662823584018042, 0.07630027685081586, 0.06324914240394719, 0.010327785512345145, 0.0110632835458091, 0.08412689945544116, 0.025561508555256296, 0.012176211912446888, 0.04248327524692286, 0.062045056038186885, 0.07851652277167886, 0.04010712247691117, 0.04586144983477425, 0.0611934601329267, 0.02248752545710886, 0.03773874370381236, 0.022779645914852154, 0.05862880927452352, 0.019613862859841902, 0.06051081043551676, 0.0849301481503062, 0.03658620691567194, 0.020430770782695618, 0.012615928844752489, 0.04022416287625674, 0.00745047943382815, 0.06944996435777284, 0.05097051689517684, 0.07739020235021599, 0.09793204852030613, 0.03057892965443898, 0.07047319304547273, 0.014438155576499412, 0.027203146637475584, 0.042681918494054116, 0.014385476079041837, 0.064930900989566, 0.11111294748843648, 0.03353335276187863, 0.04101260572497267, 0.1080800051568076, 0.015223653026623651, 0.026491501230339054, 0.02070967915642541, 0.031056464576977305, 0.01685447059571743, 0.03676576212455984, 0.03893509318004362, 0.08624720052466728, 0.030272610056272242, 0.050662937501329, 0.06517665577121079, 0.0179361526897992, 0.06190058957145084, 0.025895476865116507, 0.02010047981457319, 0.030105183395789936, 0.015268593779182993, 0.039479413972003385, 0.041438553962507285, 0.03081006227148464, 0.018900627401308157, 0.04101907354197465, 0.03171828961058054, 0.02801625661959406, 0.026945472964143846, 0.04422816462465562, 0.0287386334821349, 0.08231257845181972, 0.06031319877365604, 0.011665900037769461, 0.014201903068169486, 0.013809438678435981, 0.04131615525693633, 0.020023435608891305, 0.022970043901295867, 0.11768731463234872, 0.012618686851055827, 0.04052675503771752, 0.02541552996262908, 0.02819789355271496, 0.07477773120626807, 0.04608964540238958, 0.016728092123230454, 0.0778596627060324, 0.04996104762540199, 0.04006127630418632, 0.07042004785034806, 0.02497744204447372, 0.1002112879359629, 0.02380985635682009, 0.023150862616603263, 0.03121385925624054, 0.021052497577329632, 0.03857721843814943, 0.018761597166303545, 0.0238339780116803, 0.019939847516070586, 0.027816587353299838, 0.004888465055046254, 0.026233950011373963, 0.03292509223683737, 0.066976111556869, 0.015273827775672544, 0.04547953692963347, 0.06596451232326217, 0.05011660177842714, 0.06693242874462157, 0.022671854530926794, 0.034560826534288935, 0.025249066238757223, 0.018055584660032764, 0.02091211292281514, 0.021864963746338617, 0.05664730095304549, 0.02793968924379442, 0.018651282480277587, 0.008294579183711903, 0.0828201332478784, 0.06013971804350149, 0.018331255414523184, 0.03433645673794672, 0.008913959864003118, 0.07078208232996985, 0.03798999408900272, 0.09090298975934274, 0.011368402720108861, 0.04340423227404244, 0.07895971852121875, 0.04438095427758526, 0.01374929781377432, 0.022801190461905207, 0.012176734198874328, 0.0048347122265113285, 0.016633798550174106, 0.03788062749663368, 0.06137753873190377, 0.05609560321317986, 0.05070885788882151, 0.02197586843976751, 0.026992066850652918, 0.03680911839182954, 0.0172966069294489, 0.05716435523936525, 0.04935865006700624, 0.058966753640561365, 0.050877325411420316, 0.013030170630372595, 0.07313509122468531, 0.035377244639676064, 0.0639281926851254, 0.05408527729741763, 0.017620433791307732, 0.030703829397680238, 0.018793392628140282, 0.0656955580052454, 0.0227456629727385, 0.06348605820676312, 0.050143794069299474, 0.0498880759550957, 0.007877741736592725, 0.050364208218525164, 0.03875969770888332, 0.11646735001704656, 0.081916664930759, 0.05536933007533662, 0.009399468235642416, 0.033095270409830846, 0.047306370543083176, 0.06649226095760241, 0.040807420446071774, 0.015383748195745284, 0.00681101299051079, 0.006890069344080985, 0.023048245857353322, 0.03605170102673583, 0.0574886218237225, 0.04986475396435708, 0.07092087136697955, 0.03573457019228954, 0.0377652940369444, 0.014781628942728275, 0.0685204763431102, 0.046136359887896106, 0.13703744974918664, 0.06670991802820936, 0.035933499166276306, 0.031115700949158054, 0.02771523595583858, 0.048169517976930365, 0.07077969261445105, 0.046351953787961975, 0.04622712454875, 0.010526133755774936, 0.039261660422198474, 0.03005189348186832, 0.13959518750198185, 0.011712376108334865, 0.061442751248250715, 0.06947933856281452, 0.0474300160567509, 0.04667164132115431, 0.07063713346724398, 0.013505805654858705, 0.054885460922378115, 0.11251441173953936, 0.058546820509945974, 0.04015336569864303, 0.03704470946104266, 0.0533546440419741, 0.05441847562906332, 0.013353837002796354, 0.07058710529236123, 0.02796387027046876, 0.09139632500591688, 0.03491367693641223, 0.08642683736979961, 0.013039296263741562, 0.0787658547051251, 0.0065686994548741495, 0.052229603825253434, 0.0756664530490525, 0.040664215630386025, 0.05759914987720549, 0.08201515534892678, 0.02661356225871714, 0.02152942950488068, 0.03801166109042242, 0.02351318282308057, 0.03275952651165426, 0.02455400041071698, 0.054778242847532965, 0.03551761445123702, 0.010226796839560848, 0.044433817456592806, 0.0703304706257768, 0.03338221809826791, 0.07622788034495898, 0.03555879622581415, 0.013192227852414362, 0.03408276468690019, 0.037340006310842, 0.003957657872888376, 0.025987751796492375, 0.05925780540565029, 0.021832253587490413, 0.04774750683282036, 0.027622647467069328, 0.021614845136355143, 0.06633075478021055, 0.008270721918961499, 0.0569009076571092, 0.020050748498761095, 0.04232638893881813, 0.06745893799234182, 0.01913630752824247, 0.01849445739935618, 0.039677266831859015, 0.040289772441610694, 0.0645789819827769, 0.03507166533381678, 0.027234784392931033, 0.03534282383043319, 0.057777328402153216, 0.020823079321417026, 0.06694889700156637, 0.09585677355062217, 0.12115706282202154, 0.15018412086647004, 0.21391588932601735, 0.11238941922783852, 0.2013948338571936, 0.08906371775083244, 0.2480446337722242, 0.1154875592328608, 0.1743772890768014, 0.2128951987833716, 0.08843126692227088, 0.13315837742993608, 0.17540574248414487, 0.11348675878252834, 0.15611898677889258, 0.18750705407001078, 0.20339253213023767, 0.20839162403717637, 0.11035420538973995, 0.10249762970488518, 0.12286289667827077, 0.15594312746543437, 0.19830141391139477, 0.08150696230586618, 0.13424087403109297, 0.07700179194216616, 0.07980132882948965, 0.23898983839899302, 0.14071967481868342, 0.13711749779758975, 0.12183607599581592, 0.17692687804810703, 0.25366672896780074, 0.07659211158170365, 0.18609119957545772, 0.1472258905414492, 0.15641001256881282, 0.09784590743947774, 0.08743451806367375, 0.0665334724180866, 0.07294270428246818, 0.08258439003839158, 0.08254650339949876, 0.1212269879761152, 0.10815023459144868, 0.08896163533790968, 0.21503988682525232, 0.14788122178288177, 0.12900073255877942, 0.15426063415361568, 0.08324158407049254, 0.08215280147851445, 0.09917431467329152, 0.11857101955683902, 0.20735269150463864, 0.10791876615257934, 0.09899729018798098, 0.21030942269135267, 0.14514795126160607, 0.15996038768207654, 0.13162225048290566, 0.0849211162130814, 0.07635220492375083, 0.0812113426218275, 0.12201096309581771, 0.18591311381896958, 0.13148989586625248, 0.08838529087370262, 0.18162838357966393, 0.0704012269852683, 0.1145282962534111, 0.17864854191429913, 0.18563655990874395, 0.18657217064173892, 0.13035650277743116, 0.0846410371013917, 0.12837890186347067, 0.10411683266283944, 0.17935994983417913, 0.10645444941474125, 0.12611220474354923, 0.12489254440879449, 0.10148563713300973, 0.11744858798920177, 0.125699496420566, 0.15630919922841713, 0.1605722142267041, 0.20186672103591263, 0.10921190652879886, 0.23740330478176475, 0.07902643759734929, 0.15560901258140802, 0.11494184320326895, 0.19811743550235406, 0.17447088874178007, 0.14312503481050953, 0.11311662005027756, 0.11000087630236521, 0.11518097060616128, 0.1745284051867202, 0.1225222360517364, 0.11945220117922872, 0.1560271979542449, 0.11817506892839447, 0.16495971707627177, 0.2266876571229659, 0.09752640544320457, 0.17682320001767948, 0.1925053444574587, 0.1513896358665079, 0.16766350949183106, 0.16941094072535634, 0.1486559200566262, 0.19593673845520243, 0.2580654085613787, 0.14865301083773375, 0.16349556361092255, 0.1342222758103162, 0.22956488945055753, 0.14135802572127432, 0.118369667470688, 0.1863967566168867, 0.1181340949551668, 0.17025268462020904, 0.07211317613837309, 0.2520504203857854, 0.11196404986549169, 0.17606534849619493, 0.10087738031870686, 0.12586854281835258, 0.1482529635541141, 0.09037297757458873, 0.14185637788614258, 0.1926471688784659, 0.15948544285492972, 0.19897152873454615, 0.16789342684205621, 0.11721716407919303, 0.20851631968980655, 0.09085212295758538, 0.10552181469392963, 0.14117308252025396, 0.1531569121289067, 0.11120691822725348, 0.2017072038142942, 0.09274875556002371, 0.11589227462536655, 0.17601433326490223, 0.08114032651064917, 0.1282451074803248, 0.10434404117404483, 0.15166952944127843, 0.10337733445339836, 0.16815069975564256, 0.16402940527768806, 0.10482629615580663, 0.15385807841084898, 0.1520345325116068, 0.21512020204681903, 0.0970824304386042, 0.14702942920848727, 0.16813726688269526, 0.14416543679544702, 0.1255004820995964, 0.19129013700876385, 0.11978193739196286, 0.12385753041598946, 0.1871658442541957, 0.13350200664717704, 0.23511201288783923, 0.09483652087510563, 0.07842785096727312, 0.21535734791541472, 0.11785573020461015, 0.28777640021871775], [0.08620945489383303, 0.0522574974456802, 0.015533682435489027, 0.07347741426201537, 0.015137517511902843, 0.03547601336322259, 0.05972928069240879, 0.07391364866634831, 0.0833469616190996, 0.05802893872896675, 0.06317725797998719, 0.04321285094192717, 0.03379873734957073, 0.05015413960791193, 0.04172831067990046, 0.045275182856130414, 0.04149084568780381, 0.04860725523030851, 0.032469291109009646, 0.026467309071449563, 0.01050063448928995, 0.0123655699644587, 0.036641530314227566, 0.02023353019467322, 0.03512882183713373, 0.041333413901156746, 0.06348885610350408, 0.02533828723244369, 0.0072712414930720115, 0.019602049724198878, 0.061718362630927004, 0.09831148636294529, 0.007717603893979685, 0.034972173016285524, 0.027170750036020763, 0.02960303143481724, 0.024727288182475604, 0.04898521619907115, 0.028820976622228045, 0.08323227753862739, 0.029795449918310624, 0.01887989365059184, 0.007205936672107782, 0.05058355367509648, 0.032876414770726115, 0.05806779387057759, 0.058767145601450466, 0.025451075125602074, 0.025034049358509947, 0.01861241806182079, 0.028298443430685438, 0.10612217505695298, 0.028490661534306128, 0.03996018094767351, 0.04064795146405231, 0.04164108235272579, 0.023427796877513174, 0.03413634774915408, 0.06008273223415017, 0.07322030462091789, 0.08468889820505865, 0.06565501447767019, 0.029410442257358227, 0.024967844219645485, 0.021602853885269724, 0.06745859660441056, 0.016387939867854584, 0.01771656417986378, 0.028196984421811067, 0.04831273021409288, 0.031623617542209104, 0.021050859286333434, 0.023064213164616376, 0.00902990652321023, 0.022387830904335715, 0.03679661691421643, 0.03974860948801506, 0.05965479875158053, 0.053534637117991224, 0.030090735635894816, 0.026717722685134504, 0.056644451105967164, 0.11630477514700033, 0.04200398143439088, 0.035516274874680676, 0.08220497446018271, 0.012707373498415109, 0.026795757657964714, 0.05710270503186621, 0.07304587023099884, 0.061903925525257364, 0.16329415957443416, 0.030952159431762993, 0.05356037108867895, 0.01504981142716133, 0.02716455124755157, 0.03955739884986542, 0.018586318583402317, 0.026261875173076987, 0.06336323276627809, 0.026797536957019474, 0.02174930374167161, 0.00792257766079274, 0.078540130489273, 0.04941851912008133, 0.03272402216680348, 0.04075384851603303, 0.027910515418625437, 0.041762512555578724, 0.046805821621092036, 0.0662757913232781, 0.043922811673837714, 0.05626769983791746, 0.040783942604321055, 0.06823918753070757, 0.0056906408826762345, 0.05048286649980582, 0.018805166801030282, 0.0774985336465761, 0.025599415603210218, 0.03999931810540147, 0.06627496753935702, 0.040626759437145665, 0.020749499090015888, 0.03863076439301949, 0.03137022606097162, 0.026609120504872408, 0.0126748414550093, 0.019033742719329894, 0.022349051832861733, 0.05769348055764567, 0.039953223313204944, 0.06672482777503319, 0.03296504575700965, 0.08358009246876463, 0.0477857868099818, 0.03411874029552564, 0.03402938942599576, 0.048975735262501985, 0.04858307605900336, 0.013333822207641788, 0.06196055510372389, 0.07746276212856174, 0.041401658090762794, 0.005801544184578233, 0.10006590862758458, 0.03581520082661882, 0.038071281524025835, 0.060548893743543886, 0.04167227110883687, 0.007720749208601774, 0.03965488736866973, 0.02967841694044182, 0.05318840667314362, 0.045534778691944666, 0.06594704958843067, 0.03894990644766949, 0.045788266652380116, 0.03098096960457042, 0.05378305620979518, 0.06093870681070257, 0.03359496586199384, 0.03331035222799983, 0.05961616996501107, 0.04266816649760585, 0.034400786098558456, 0.03718463769473601, 0.06690582275041379, 0.012823027009289945, 0.04037713435536716, 0.07139425768400542, 0.04411050824273843, 0.052314642816782, 0.06790311337681487, 0.06245054697501473, 0.03391224512597546, 0.06674661723081954, 0.06024459464242682, 0.022434113088820595, 0.05030434287618846, 0.033467646717326716, 0.023592987818119582, 0.03225151158403605, 0.039561647645314224, 0.018259844109707046, 0.11582505831029266, 0.00951478592469357, 0.04131330169911962, 0.05645732228003908, 0.0253262013575295, 0.03703738817421254, 0.023324434259848204, 0.023432112466252875, 0.01665343948843656, 0.044032245059497654, 0.061915781334391795, 0.0397794754098868, 0.01940760888828663, 0.0308849876455497, 0.0389955633727368, 0.056863982099457644, 0.05601390017545782, 0.007968662248458713, 0.026026824016298633, 0.03766824709600769, 0.010413523978058947, 0.040902381952037103, 0.04885355920123402, 0.06965325344935991, 0.022514853189932182, 0.028902278900204692, 0.024511243427696172, 0.040477287184330635, 0.11255645440542139, 0.019715136331797112, 0.10082541513838805, 0.03669465695566032, 0.04692762660852168, 0.03041196869162377, 0.0419430028705392, 0.045641558899660595, 0.05096108048746828, 0.007964149990584701, 0.026798121398314834, 0.03543913233443163, 0.012786281422449974, 0.02372081533394521, 0.08061319385888055, 0.01705444599792827, 0.0219545576692326, 0.02896390313253505, 0.02269962013087934, 0.01272438816158683, 0.041674126478028484, 0.008446682350040646, 0.07351124135311693, 0.05804044943943154, 0.02181363681302173, 0.013645269118569558, 0.024547029788664076, 0.04393845243612304, 0.04315973914344795, 0.04234701322275214, 0.02911010065872688, 0.013761633235844783, 0.06123066028521862, 0.030367011240741704, 0.058306520513724536, 0.05862351776158903, 0.03004722351761302, 0.0328671008173842, 0.03590190965041984, 0.09278931393055245, 0.009489645672147162, 0.025179274671245366, 0.0340823193982942, 0.025383300344401505, 0.038917871643207036, 0.03112403897830518, 0.03812279399426188, 0.015984784840838984, 0.10724888881668448, 0.02310151536221383, 0.05915856541832909, 0.03281510224041995, 0.0712564482819289, 0.038954214614932425, 0.13642167497891933, 0.038999704556772485, 0.02213537081843242, 0.019776601002376992, 0.008572198075853521, 0.033270962740061805, 0.03312883774924558, 0.02905550085415598, 0.05988920238451101, 0.04098579192941543, 0.017072042319341563, 0.023340618645306677, 0.03699341592437122, 0.08407643341342919, 0.03533392176905181, 0.02101258116454119, 0.04211187857436016, 0.033228675165446475, 0.05240524420514703, 0.03679879882838577, 0.03959813904657494, 0.06987759727053344, 0.027907665571547113, 0.01375820358589408, 0.01967740183317801, 0.008932067339628702, 0.019513372353685554, 0.03711850120453164, 0.03864973368763458, 0.09982193500036374, 0.07354341345489956, 0.04255318555806298, 0.045005230349488556, 0.013372167122724932, 0.052571307169273496, 0.09675990790128708, 0.010181756824749755, 0.027031940589949954, 0.052456307676038705, 0.03917408328561578, 0.024307195490109734, 0.04471342530450784, 0.018245830506202765, 0.04484453682380263, 0.03682616552396212, 0.038506625351146795, 0.086005846678745, 0.020851357003266457, 0.027476778341224417, 0.04336666846938897, 0.029331340447242837, 0.03984613511420321, 0.038866919494466856, 0.0162302019452909, 0.05234781310718972, 0.01231022708452656, 0.026745979957922827, 0.012152247963967966, 0.03809080371866003, 0.037361829163273796, 0.028186538693262264, 0.03430027332797181, 0.05327284823579248, 0.012297605935600586, 0.06275738051044755, 0.017696335089567583, 0.009870755202427972, 0.09570741633069701, 0.026169203192694113, 0.01581256390636554, 0.06550939026055858, 0.011695756638800958, 0.015247510291374056, 0.024220494087785482, 0.06216277921339497, 0.056141928071156144, 0.04351455623691436, 0.023248325160238892, 0.03265587074565701, 0.026989530560967978, 0.03737040839041583, 0.010657551410986343, 0.04425218794494867, 0.04924271546769887, 0.05065490746346768, 0.27976577694062144, 0.17993707355344668, 0.08254324537119828, 0.16417324834037572, 0.15959893207764253, 0.13468924997141585, 0.16961117216851562, 0.17969688487937674, 0.22905421763425693, 0.17583396169357002, 0.12887891643913463, 0.16424244618974626, 0.13785623159492388, 0.15916753647616133, 0.11923147161724046, 0.0662683104746975, 0.15390327520435676, 0.197237441316247, 0.135662799293641, 0.1778996258508414, 0.08008419841644354, 0.10034854072728194, 0.1444763076142408, 0.1217893800640013, 0.17718657036311924, 0.15716499940026551, 0.2090522987418808, 0.08914596255635843, 0.13646936538862064, 0.06821073358878493, 0.17124541103839874, 0.23574466409627348, 0.1704726868774742, 0.1390789050492458, 0.17019469320075586, 0.14278121263487265, 0.09583385603036731, 0.19928893045289442, 0.1521629685885273, 0.18015879759332165, 0.1652938171173446, 0.1502546842675656, 0.09425230222404934, 0.10035345374490134, 0.18208223656984046, 0.2168434244231321, 0.12230833424837328, 0.13991637417348102, 0.09633416004362516, 0.05602670593361836, 0.11828847651486285, 0.15074830153025687, 0.10472773152287118, 0.14229678316041827, 0.1228346282732673, 0.09748580996529199, 0.12173069844720885, 0.08637980747153051, 0.11453905739472248, 0.19669438217533752, 0.1545724697643891, 0.1403599706827663, 0.12894999934360385, 0.12119105318561196, 0.10023765644291416, 0.14572336804121733, 0.0718079975922592, 0.05717333893699106, 0.08354989447980188, 0.11125203338451684, 0.17434447130654007, 0.10467143220012076, 0.09991545302909799, 0.09253010401153006, 0.15193539642496035, 0.1105470301990863, 0.2023535847547464, 0.17157050140667707, 0.17821649322286248, 0.1778429702972062, 0.1262140422477387, 0.17578210041392595, 0.2573042915901169, 0.07828279820387252, 0.08303071022965014, 0.2675073378486559, 0.11061725963372737, 0.15997178707038984, 0.12794637819752097, 0.20627501886337996, 0.1449765745201148, 0.3378956811502576, 0.10984095832100138, 0.1531473087379709, 0.0898855052946601, 0.12679183389991522, 0.1213071918755304, 0.13234906538855284, 0.14884359436109662, 0.1772224309388548, 0.14713531883899122, 0.16431265335995704, 0.11896482537849806, 0.13834156648954377, 0.15803338639670983, 0.08823087220662273, 0.13270266907056794, 0.12626842682948336, 0.1571427794988267, 0.16610020509688184, 0.18312746251467615, 0.10800400181324221, 0.1293821816216223, 0.22069163824198768, 0.13793691789032891, 0.10824826487805694, 0.1312075086752884, 0.09409228776348755, 0.26054156944155693, 0.11736105167074129, 0.13697518355911598, 0.18122440291335806, 0.13029386551352218, 0.1292309764539823, 0.14169861213304102, 0.13095384259941056, 0.21127862302819267, 0.08981724255136214, 0.12339892768068239, 0.13200310582760721, 0.16762675833888352, 0.14754597883438691, 0.13957517920061946, 0.0968531661783345, 0.15601824765326455, 0.08863426657626405, 0.11013986571924761, 0.20207241468597203, 0.1105417386861518, 0.16090517136035487, 0.09181368659483269, 0.1859852802590467, 0.15556982718408108, 0.2191768554621376, 0.13289147143950686, 0.2650228649144992, 0.11287438304862007, 0.10036819279775955, 0.15808647964149714, 0.14053636434255168, 0.09528022128506564, 0.132693006307818, 0.19183148921001703, 0.1527773926500231, 0.11811585296527483, 0.10421256971312687, 0.10184050988755189, 0.19700506003573537, 0.20912259496981278, 0.10580828369711526, 0.12315516927628778, 0.11815160964033566, 0.14592907653423026, 0.16519623954081908, 0.12673884455580264, 0.14174594631185755, 0.11297700722934678, 0.12215573384310119, 0.06070668918255251, 0.18632833060109988, 0.14965268375817686, 0.14968049945309758, 0.1657102955505252, 0.1867357548326254, 0.19206729921279475, 0.11043049074942246], [0.006224588305485668, 0.0429892010288313, 0.04380029422463849, 0.0318258379411418, 0.013112154756527161, 0.0398940073500853, 0.04913878510706127, 0.020274754642741755, 0.029365820628299844, 0.07841157566872425, 0.017599084058019798, 0.03011231357959332, 0.03494643162412103, 0.05598151285084896, 0.04473954519198742, 0.026079212220793124, 0.040577940962975845, 0.034017414873233065, 0.04361595958471298, 0.03486469518975355, 0.02081129958241945, 0.0947449695377145, 0.028782164154108614, 0.022640411589236464, 0.004224913600410218, 0.0539494382974226, 0.024908127306844108, 0.022634294437011704, 0.052657811902463436, 0.05450631622807123, 0.04245245385391172, 0.04758267583383713, 0.06813421074184589, 0.01660837442614138, 0.026947912774630822, 0.032860395513125695, 0.027864264775416814, 0.06278121087234467, 0.05280271994706709, 0.06617466628085822, 0.05277406562527176, 0.034841707165469415, 0.04329128852987196, 0.11985421515419148, 0.031352069418062456, 0.07625859783729538, 0.020328346981841605, 0.01958390977961244, 0.046459045697702095, 0.10131558883585967, 0.020899242226732895, 0.009784942521946505, 0.059207836602581665, 0.01065408187059802, 0.044102593237766996, 0.052703346373164095, 0.051280022162245587, 0.04697803327871952, 0.05664137119310908, 0.04337898441008292, 0.027733374045055825, 0.08575262589147314, 0.030683822951687034, 0.01171810734376777, 0.026314593633287586, 0.027699190723069478, 0.031751033166074194, 0.011978299680777127, 0.030522383567586076, 0.08258116911747493, 0.06893241283250973, 0.10493799680261873, 0.02879978830605978, 0.055614825105294585, 0.030550427472917363, 0.08628343217424117, 0.014188341247063363, 0.04271915204299148, 0.07516510260757059, 0.027290285906929057, 0.08131361799314618, 0.015956065581121948, 0.06551272992510349, 0.016750978102209046, 0.03457447834080085, 0.09701948147267103, 0.00816374040368828, 0.0393165199784562, 0.06978235745918937, 0.06657713296590373, 0.05910405467147939, 0.051995337489643134, 0.02329535134776961, 0.0636665262572933, 0.011184124668943696, 0.030486417235806584, 0.03670237900223583, 0.05380944327043835, 0.006268359711611993, 0.0776152363687288, 0.04085357089934405, 0.023745783037156798, 0.00514441277118749, 0.04288377152988687, 0.023459657277271617, 0.04586766903230455, 0.07613737543579191, 0.07370129795162939, 0.016112844277813565, 0.07385421748040244, 0.030228630384954158, 0.03504584230540786, 0.07371415937086567, 0.043133786239195615, 0.044018266708008014, 0.02132854497176595, 0.013701741918339394, 0.024579170349170454, 0.012932785084558418, 0.041270008514402434, 0.04737876333820168, 0.02340000901313033, 0.05802312400192022, 0.11091797787230462, 0.01630058352020569, 0.01358090265057399, 0.07191479264292866, 0.06653792530414648, 0.015925212646834552, 0.020429805990715977, 0.07790235104039311, 0.10743927938165143, 0.02167295344406739, 0.014590226273867302, 0.02278542724525323, 0.03019998719537398, 0.035418166662566364, 0.06168714789964724, 0.038534763880306855, 0.03169060008076485, 0.00926830940443324, 0.023303828529606108, 0.01854893474956043, 0.10101222855155356, 0.03835805480775889, 0.043644435791065916, 0.05265385996608529, 0.04416360148752574, 0.03825856249022763, 0.06936567864613608, 0.03315003719762899, 0.053583340559271164, 0.015898155797913205, 0.010198164782195818, 0.027220416413911153, 0.013312424234754872, 0.039830260575399734, 0.078895834449213, 0.028739935951307416, 0.04434862632479053, 0.05039792769821361, 0.06018570151354652, 0.018705488946579862, 0.031758332188474014, 0.020641256851376966, 0.029476116760633886, 0.058712864920380525, 0.0063957196744013345, 0.013477096599672223, 0.054297294045682065, 0.06651796153164469, 0.029556905101344455, 0.015117983257368905, 0.018228985609312076, 0.04690683534136042, 0.07268657427630387, 0.031151600487646647, 0.0406687575741671, 0.040402682789135724, 0.05829984860611148, 0.028901458827021997, 0.05346997008018661, 0.017776472195691895, 0.040240404778160155, 0.02273532114486443, 0.03053659569559386, 0.03969219142163638, 0.07761814558762126, 0.043795822784886695, 0.021500982984434813, 0.03712372221343685, 0.04952576317009516, 0.05937487178016454, 0.029266213277878705, 0.07941156029119156, 0.018402512723696418, 0.058264195831725374, 0.044614248399739154, 0.031347891126642935, 0.04686220629082527, 0.02050881874311017, 0.09658105031121522, 0.032267753485939465, 0.022376207016350236, 0.017563065775902942, 0.05603657278697938, 0.02834635648468975, 0.07244405525852926, 0.013875437871320173, 0.05167458497453481, 0.07563443679828197, 0.024509334252798, 0.0019004473574568692, 0.028623309299291577, 0.05456673075968865, 0.02947639877675101, 0.0492756853782339, 0.019970282992289867, 0.020403422640811186, 0.030050205095903948, 0.03754518416826613, 0.013434075226541609, 0.03469695868261624, 0.060274955903878435, 0.026169088159804232, 0.04900716521660797, 0.03710828925250098, 0.0394218233122956, 0.03187933936715126, 0.014143651897029486, 0.05402680348197464, 0.05746664683101699, 0.016594858061580453, 0.04083610816451255, 0.07715075582382269, 0.0324591199751012, 0.06039728410542011, 0.027000234185834415, 0.00553946308173181, 0.027139390585944057, 0.044845820739283226, 0.08383702399441972, 0.005937328915024409, 0.04617636906914413, 0.04887204238912091, 0.06056371443264652, 0.04551963887934107, 0.07982789029483683, 0.01494212858233368, 0.0787691721052397, 0.020197823614580557, 0.035923825271311216, 0.09257480356609449, 0.02777657260594424, 0.05072441701486241, 0.022103896335465834, 0.04083022664417513, 0.05123444316268433, 0.02991050136188278, 0.013901218226237688, 0.02571217937656911, 0.047774717677384615, 0.057637036516098306, 0.006589102022189763, 0.04671572860388551, 0.06045527923561167, 0.027356038335710764, 0.020193326199660078, 0.019036407029489055, 0.037947342862025835, 0.03063486161408946, 0.05410134850535542, 0.03261710466176737, 0.05887720239115879, 0.01605234810995171, 0.08590303696109913, 0.029666453519894276, 0.08327471354277804, 0.04834983017644845, 0.03752827433345374, 0.06188236613525078, 0.06239680064027198, 0.07988978541106917, 0.02013895646086894, 0.013240243879408808, 0.1416336593683809, 0.05870550281542819, 0.05626889469567686, 0.02506706936401315, 0.0498925473948475, 0.016629388337605633, 0.03302400938991923, 0.057142729056067765, 0.0233204730466241, 0.03375708431121893, 0.024461833090754226, 0.00895278531970689, 0.032100436292239465, 0.041916322661563754, 0.05913112450798508, 0.03484519154881127, 0.03562966019671876, 0.04841471243707929, 0.015093511865416076, 0.06152112575364299, 0.04158638977969531, 0.03857452073134482, 0.034877716170740314, 0.03234448784496635, 0.055266063936869614, 0.012312835733609973, 0.03899274692230392, 0.052503174301818945, 0.009149897887255065, 0.04873234051046893, 0.07106351957190782, 0.04343215929111466, 0.0327442011621315, 0.08193856570869684, 0.040048967784969136, 0.03583305318898056, 0.03034842786291847, 0.04047998860187363, 0.0379344925750047, 0.02809507270285394, 0.059093252712045796, 0.03540904195688199, 0.06074906952562742, 0.044426781896618195, 0.009663117125455756, 0.031687494192738086, 0.026104938770004082, 0.037406272676889785, 0.08396343400818296, 0.009285658034059452, 0.022075308806961402, 0.0375414956943132, 0.03161745029501617, 0.03356023706146516, 0.0631592608988285, 0.05330670130206272, 0.032218474880210124, 0.020830571302212775, 0.018188714821008034, 0.02384057570452569, 0.007044228723316337, 0.004692749116657069, 0.08585876785218716, 0.04449816908163484, 0.049561204432393424, 0.02029964998655487, 0.054001091775717214, 0.07344559839111753, 0.1338299023336731, 0.08644032219308428, 0.1232772674120497, 0.05827546163345687, 0.1138053776230663, 0.1017854202655144, 0.11700669099809602, 0.11302911341772415, 0.18797353841364384, 0.0877225752628874, 0.2210441287024878, 0.21567896503256634, 0.1116040933993645, 0.08699402373167686, 0.20426102302735671, 0.15210362646030262, 0.15447290323209018, 0.20857345021795481, 0.10486368555575609, 0.17381463723722845, 0.1917467507882975, 0.18632702442118898, 0.09712903731269762, 0.10083047658554278, 0.185550055175554, 0.11582462044316344, 0.08616100749350153, 0.15754413296235725, 0.11638306430540979, 0.08699249490746297, 0.21555213199462742, 0.13984109071316198, 0.1307558672851883, 0.14988635637564585, 0.08792926339083351, 0.10254235152387992, 0.18907991732703522, 0.14141828811261803, 0.16913189319893718, 0.15943751495797187, 0.13687016966287047, 0.19417596340645105, 0.20657110610045493, 0.11491204597405158, 0.22958887566346675, 0.1427246758248657, 0.11121459203423001, 0.17582616914296523, 0.15176170418271795, 0.12698911159532145, 0.07118238936527632, 0.2162229295936413, 0.10967180802254006, 0.11423802003264427, 0.15365949453553185, 0.17959396383957937, 0.24096696433844045, 0.24572945956606418, 0.2117203938541934, 0.12646194925764576, 0.1224567044118885, 0.13823077868437394, 0.09331591965747066, 0.18101820460287854, 0.13002546038478613, 0.09977544686989859, 0.10992708455887623, 0.1069397917308379, 0.16645517433062196, 0.19529512210283428, 0.26447106327395886, 0.10583795476122759, 0.16045808675698936, 0.11027218322851695, 0.1652285674936138, 0.14096301019890234, 0.16908712685108185, 0.26654028974007815, 0.07219080478535034, 0.22158318024594337, 0.0850933909532614, 0.13762545335339382, 0.09662916374509223, 0.1470974099356681, 0.19779676833422855, 0.11714974738424644, 0.09910790729918517, 0.09319926888565533, 0.1873149862512946, 0.1405568327754736, 0.07961760275065899, 0.17010492301778868, 0.2980087761534378, 0.08930792144383304, 0.18118788924766704, 0.08729074921575375, 0.15974454145180061, 0.08789562925812788, 0.1390074213850312, 0.09000499849207699, 0.20254056144040078, 0.10895401021116413, 0.21847597119631246, 0.17149495077319443, 0.16580429597524926, 0.15467438148334622, 0.15762812923640013, 0.10779139134683646, 0.19934837648179382, 0.13636026968015358, 0.22234371834201738, 0.1631006965180859, 0.13155410648323596, 0.12123612381401472, 0.1534689258551225, 0.14575303910532966, 0.06722795937093906, 0.04428705033205915, 0.07548672714619897, 0.10193690002779476, 0.1039436376595404, 0.193067476793658, 0.19119180244160816, 0.15337038348661736, 0.11355469498084858, 0.10702588828280568, 0.13063967664493248, 0.1884596748277545, 0.08484385121846572, 0.1318476555752568, 0.2654924662783742, 0.11304153696983121, 0.119097410060931, 0.1288931953604333, 0.09652676220866852, 0.10858536319574341, 0.22195533761987463, 0.08355226935236715, 0.21162470133276656, 0.1459868749952875, 0.09084396675461903, 0.14114232792053372, 0.2270514430711046, 0.13735240238020197, 0.1630994348670356, 0.10221596239716746, 0.1417227170895785, 0.07283610961167142, 0.19271899393061176, 0.17470766353653744, 0.19424464175244793, 0.08045314229093492, 0.05169131669390481, 0.1825419079978019, 0.11392660002456978, 0.1411725630168803, 0.1297121701645665, 0.0969809565867763, 0.13605815620394424, 0.08430713001871482, 0.15415827714605257, 0.12033955004881136, 0.13801128108752891, 0.13078163465252146, 0.14154552191030234, 0.15171597304288298, 0.06888310454087332, 0.1027847889054101, 0.10470001230714843, 0.1163652008108329, 0.17805936571676284, 0.149551336071454, 0.1145070485654287, 0.10878835542825982, 0.15217634208966047], [0.021519080255529843, 0.04878119609202258, 0.0411318688566098, 0.019636722863651812, 0.04077758239873219, 0.07685566306463443, 0.07440027489792556, 0.02216736294940347, 0.026813706499524415, 0.035149739269400015, 0.015571082039969042, 0.046619661297881976, 0.029802923345414456, 0.04380253179988358, 0.0099920982029289, 0.010612638488964876, 0.02031099927989999, 0.06672763309325092, 0.04101510676264297, 0.04426030704053119, 0.050219225959153846, 0.05192787626583595, 0.012604560070030857, 0.04819621673959773, 0.06865750649012625, 0.05796532554086298, 0.019758587222895585, 0.010906974257522961, 0.05284093684167601, 0.02468777067406336, 0.053986749771866016, 0.008355339741683565, 0.048657673032721505, 0.05313240792020224, 0.05064263605163433, 0.06190192172653042, 0.043371963693061844, 0.010568183843133738, 0.016806553830974735, 0.07895340284449048, 0.013344698381843045, 0.02510157552023884, 0.00949823324845056, 0.054591462831012905, 0.0384928139828844, 0.10472098540049046, 0.023921798201627098, 0.04994037139113061, 0.02324205586774042, 0.022570777728105895, 0.05854545124748256, 0.016424551868112758, 0.036067326946067624, 0.03759972831176128, 0.09697114539449103, 0.0586035836749943, 0.052727492147823796, 0.023791256280674133, 0.0988762459019199, 0.035813119102385826, 0.05700905341655016, 0.008392893341806484, 0.04708047192252707, 0.04026735587103758, 0.03069580863666488, 0.028455058854888193, 0.02507088956917869, 0.033166661305585876, 0.04641548162908293, 0.08305632174597122, 0.02913128711952595, 0.01859862524725031, 0.04222405048494693, 0.029610803576360922, 0.030882518149155658, 0.0369946590217296, 0.024797714286250994, 0.03734301200893242, 0.026776942358992528, 0.02445769376208773, 0.03958996428991668, 0.0395898715214571, 0.024923742093960755, 0.06657444639131427, 0.03136049650493078, 0.06173643392685335, 0.05492270560353063, 0.0474660027975915, 0.020168711016594898, 0.05083556105091702, 0.042854798084590584, 0.06629347670241259, 0.0706961564719677, 0.058343906202935614, 0.019180461604264565, 0.06945270288269967, 0.07396565837552771, 0.06558637323905714, 0.01576366750668967, 0.0631596839230042, 0.010594897448754637, 0.04932689727866091, 0.020338477297627833, 0.04494424436416011, 0.03562525555025786, 0.049106798542197794, 0.09111747785937041, 0.007571568248749827, 0.024563182632846292, 0.02978168493427802, 0.035899575595976785, 0.027986400018562563, 0.04675523312471341, 0.031111088501347695, 0.07396660090307705, 0.05592405948846135, 0.006369534385157749, 0.07075714616803452, 0.014639019700553035, 0.0448939861234976, 0.018919043795904145, 0.02731751159444684, 0.02109683719027089, 0.017508297132735606, 0.057180140720447525, 0.05104554431454744, 0.0448616952780867, 0.02163673663744703, 0.032158687463379465, 0.04310270509449765, 0.017587016736797523, 0.048183793187490664, 0.032034451942308806, 0.09600944074918516, 0.03740563814062625, 0.013347600179258734, 0.08522623538738117, 0.01954972089151852, 0.00944978213738068, 0.016373434591514524, 0.006364917762766709, 0.016044733674789313, 0.03555419862095732, 0.03384183015441522, 0.021784227355965413, 0.06582844696822576, 0.014991158568591345, 0.011348420393915148, 0.052827422332484275, 0.04149697211687453, 0.03067494686547434, 0.025336637809232343, 0.1158125011716038, 0.05413713115558494, 0.056610301180626266, 0.04712637746706605, 0.046907551513868384, 0.028153442617622204, 0.030827441514702514, 0.0618225379002979, 0.04135483599384315, 0.06840641566668637, 0.023666605156904552, 0.036498002664302476, 0.00952342174059595, 0.08462591213174164, 0.0140280095183698, 0.06157583688036539, 0.014935464096197393, 0.04023856054118369, 0.06963420993997715, 0.010231180149276042, 0.023133253307605628, 0.019732177897822112, 0.023109239264158532, 0.06805170618463308, 0.05406071592005901, 0.006684021318505984, 0.03330607003590558, 0.016677486928529106, 0.03011339154909365, 0.029078685547574423, 0.031079333857633173, 0.01381041274726158, 0.04508244339376688, 0.03320004681881983, 0.0283742760802852, 0.07023671510978602, 0.01566737199027557, 0.027076237529399805, 0.026341088305343874, 0.06758655770681798, 0.03676471569633577, 0.03485141074634157, 0.06504423436126672, 0.04335029298090376, 0.061770773099851795, 0.011514858142618323, 0.10214034497039393, 0.012644589660339989, 0.049644933533272706, 0.023220136536110658, 0.02274225280416431, 0.013682613989658421, 0.055318774975603446, 0.05099454392620828, 0.055435243921238, 0.11381754142348655, 0.004094466303286026, 0.03735114965820685, 0.029040954759693705, 0.09354809313663282, 0.017607286645215936, 0.023232179737533443, 0.05572564259637147, 0.08949222639785148, 0.024620745462016203, 0.048543111406615935, 0.019844578018819448, 0.05057591697550379, 0.029891409612901043, 0.042561145091895014, 0.02350647195271449, 0.02221969549282221, 0.03171313539496623, 0.02917140576755628, 0.07260480444529094, 0.015154779866861645, 0.022741525499441195, 0.0630055769579485, 0.02927212819486158, 0.04662681189074647, 0.03617229260271415, 0.029298322297108825, 0.1242466235999018, 0.054754798402427696, 0.024481924883730244, 0.06768576800823212, 0.031373918245662935, 0.03524031468259636, 0.025975320822908543, 0.045065923186484724, 0.009597674543329049, 0.017506755320937373, 0.05422416652436368, 0.04665473890781868, 0.018044727039523423, 0.013229304622655036, 0.03581130826205481, 0.02837058389559388, 0.015368007243523607, 0.02352352279558545, 0.05154433805728331, 0.0461253167304676, 0.01860461437900085, 0.02694018516194774, 0.055847829789854586, 0.01691766632575309, 0.05204260116443038, 0.026329282591177616, 0.06180822558235377, 0.011140529059048276, 0.02189559403632302, 0.07094192609656602, 0.07411788770696148, 0.08504290264681913, 0.03373392559296917, 0.049021143568097614, 0.06203427634318359, 0.03955179934564512, 0.02941441831353586, 0.061840316047891974, 0.07238730322569609, 0.032214678794844076, 0.04530148456979077, 0.02533345399569953, 0.0407629732217174, 0.0781049944635015, 0.014983308501541615, 0.015109650794329355, 0.10748874352429993, 0.040259396337205544, 0.04237609427946154, 0.026832870607904624, 0.06007559277350083, 0.015447410551132634, 0.03887783648679033, 0.09139331930782646, 0.07170768149080686, 0.00936773678404279, 0.054095871455501765, 0.07130512574804015, 0.04291140168788843, 0.07494824705645442, 0.026103784730366897, 0.0031880015649221605, 0.015503015038120793, 0.024558768709539436, 0.09768069052370265, 0.02999518226715736, 0.0790306604176294, 0.016442619453300722, 0.01777249799488345, 0.03645960765425116, 0.02085794541926589, 0.016317042500304524, 0.03403120397706516, 0.0443318352336064, 0.07333792760618962, 0.061132585469749756, 0.02168009476008592, 0.029915546110714786, 0.040250824531540275, 0.05069820435892325, 0.12726205866783857, 0.002383587234362494, 0.03650891965662595, 0.04455879141460173, 0.023483125842176378, 0.025403095278306864, 0.04369976290035993, 0.037506662993109785, 0.008616226914455183, 0.06508138627395965, 0.03817470722424332, 0.02556735296820989, 0.01881924534245627, 0.027100190345663577, 0.0283414323348552, 0.05170619304408319, 0.004514112779361312, 0.0721401309419889, 0.053327132627600804, 0.04715824899903964, 0.02808869023283478, 0.023786944402672816, 0.0335470157006057, 0.03805144762736745, 0.058156818195129745, 0.011849490674649132, 0.04756951755553018, 0.03487793139356654, 0.008160618745023385, 0.02329300987184979, 0.023607569164596498, 0.03881421958794817, 0.06222619573236443, 0.03677686465380248, 0.004486480302148266, 0.005543055540329078, 0.05923392680415418, 0.027306670672260225, 0.2488921961048618, 0.13180351263144985, 0.12084847039659508, 0.11785343696828932, 0.13175601518014446, 0.1755720577784814, 0.216316083970014, 0.18020454357611015, 0.09860349920927547, 0.18310101237148046, 0.07343134915572591, 0.12886257434729487, 0.14423273474676535, 0.07586519277538173, 0.10472772410139441, 0.11447578188381158, 0.06432493741158396, 0.11209194417460822, 0.14555360918166116, 0.10338407315430231, 0.12563990196213126, 0.07520441417000256, 0.20293734327424318, 0.1119092051521875, 0.19248147698817775, 0.11725764081347734, 0.13415094057563692, 0.06791961131966673, 0.10758358257589862, 0.10107209760462865, 0.1218887759023346, 0.17349355446640402, 0.16091829253127798, 0.09116369881667197, 0.11171379766892642, 0.23774754256010056, 0.09566210079356097, 0.12307855737162754, 0.1648583248606883, 0.15584464446874335, 0.08824524018564261, 0.1587770480546169, 0.15481423179153353, 0.11077447619754821, 0.15434978093253449, 0.2720689633861184, 0.12886949116364121, 0.06507551588583738, 0.0807750562671572, 0.10601851929095574, 0.2024663466727361, 0.06662123880232684, 0.11788068120949902, 0.0988389529811684, 0.24742130393860862, 0.2156405514688231, 0.21607727569062263, 0.12341486901277676, 0.15736773930257186, 0.14033493062015623, 0.1686146459542215, 0.1377217099070549, 0.119916867261054, 0.1720030399155803, 0.13271037256345153, 0.1295733143342659, 0.07901969147496857, 0.07164214985095896, 0.11873694151290692, 0.1714817702304572, 0.13544656714657322, 0.12278071124455892, 0.12340531757217832, 0.14667178824311122, 0.12882907380117103, 0.08341403692611493, 0.10696001525502652, 0.10853124578716233, 0.1431016274727881, 0.12145664557465352, 0.13525049173040316, 0.09161034555290826, 0.10246683799778111, 0.17120693810284138, 0.13717725552851334, 0.11798159845056944, 0.10888752862229012, 0.11635675517027266, 0.15498725610086694, 0.18431608623359352, 0.09764999529579654, 0.1027052455174271, 0.20236951124388725, 0.15146555757382885, 0.16732265590690076, 0.15532859950326383, 0.18690627068281174, 0.1291450357530266, 0.17586136178579181, 0.11894760013092309, 0.08515848472598009, 0.3074208414182067, 0.17348861176287755, 0.15241477929521352, 0.2908297738758847, 0.16042541741626337, 0.2413479977985844, 0.12347519819741137, 0.16763901861850172, 0.12201686316984706, 0.09035420123836957, 0.17188566183904186, 0.16492269875016063, 0.12489687855122611, 0.1490950636798516, 0.14869408129015937, 0.111065071541816, 0.21240973030216992, 0.09328512795036659, 0.11095516689238138, 0.17864625609945506, 0.06353542587021366, 0.131840530957561, 0.13389858067966998, 0.15894882555585355, 0.1355956943007186, 0.13652061810716987, 0.08823130265227519, 0.18078224617056549, 0.06837765744421631, 0.09423653900739737, 0.12167978711659089, 0.14143320528091863, 0.144139283511322, 0.0872440829698462, 0.15031776682008058, 0.20443103421712294, 0.10876001280848868, 0.16552005341509357, 0.10424625579616986, 0.14393333753105253, 0.12989743991056457, 0.13287879555718973, 0.1749488021596335, 0.1236317765142303, 0.17996707116253674, 0.04439541131432634, 0.16913607891183347, 0.18282436940353364, 0.10902708207140677, 0.11477941676275805, 0.17425289028324187, 0.23004397546174005, 0.11502870416734368, 0.14056009822525084, 0.23317668470554054, 0.214766850695014, 0.1387465267907828, 0.10943897403194569, 0.18457847996614873, 0.16555428126594052, 0.24992366263177246, 0.21848239819519222, 0.11068073552451096, 0.18282690754858777, 0.21734001027652994, 0.08699438738403842, 0.10562862458755262, 0.12299055350013077, 0.1573900631046854, 0.21290915115969256, 0.07146524410927668, 0.09406583762029186, 0.09622352808946744, 0.09080716365133412, 0.14118697552476078], [0.05242370141786523, 0.04010427262983285, 0.04120306308323052, 0.0746985811565537, 0.08591387973865494, 0.048408960792585276, 0.038285751070361584, 0.02526005559047917, 0.06904772031703033, 0.03630891085776966, 0.052659199718618765, 0.03575283073587343, 0.04967078253685031, 0.030530174262821674, 0.038757979637011886, 0.034619456200744025, 0.04116428957786411, 0.03177045517077204, 0.040599181229481474, 0.09349848056444898, 0.03206091692845803, 0.03238846009480767, 0.02538289216317935, 0.02548683922213968, 0.017730692816257942, 0.017563841320225038, 0.010762443780549802, 0.013189044038881548, 0.07030468841549009, 0.019661145088321064, 0.019315235622343607, 0.028086291240470018, 0.02752476189925801, 0.038749474624637514, 0.030667044848087244, 0.00968076632489101, 0.029083574445394333, 0.10115005279658362, 0.035936389831476845, 0.159132462576963, 0.024322541248693597, 0.0436933062155731, 0.02886995094740996, 0.022445263857662212, 0.05468255032610614, 0.0722948538896162, 0.04604133158863988, 0.03403120397706516, 0.027734327704820316, 0.007406800796161406, 0.03463970570010133, 0.06897723113070242, 0.03753903176402673, 0.013746974891546415, 0.032488935758010484, 0.03098862485785503, 0.016025345066736918, 0.07744001530227251, 0.07220188505016267, 0.07608909872942604, 0.04901250867987983, 0.03399469031137414, 0.05236771750787739, 0.018651484715519473, 0.03551532492565457, 0.0712552979530301, 0.09727399359690025, 0.018901326875493396, 0.020587460421666037, 0.019614339689724147, 0.042665828732424416, 0.01888890332338633, 0.02415813141851686, 0.025694030155136716, 0.011139644047943875, 0.020799634876311757, 0.09669034639955498, 0.05297201125358697, 0.02944657000625739, 0.034357659897068515, 0.07932137450552545, 0.06500936084194109, 0.11461047426564619, 0.08184898106264882, 0.01497734720032895, 0.036418748713913374, 0.04970590096490923, 0.02528050546970917, 0.064602463535266, 0.02815507905324921, 0.05851638503372669, 0.04493540167459287, 0.027790122367150616, 0.022496332894661464, 0.0176144650686183, 0.02468358496116707, 0.024908136583690066, 0.020250738743925467, 0.06898447449202649, 0.04791407074662857, 0.011186921638000058, 0.025161982630379498, 0.030652689856651705, 0.04015542144770734, 0.023444806902261917, 0.03374450490809977, 0.031201814199448563, 0.01172618747659726, 0.026767815797938965, 0.027536721609067172, 0.020751547417603433, 0.0796033238293603, 0.12467528809793293, 0.006095377611927688, 0.02621145365992561, 0.05451221630210057, 0.0926077994517982, 0.02884356574213598, 0.02547555857745465, 0.04566042800433934, 0.04024397079774644, 0.04989839551853947, 0.010374406301707495, 0.03932044222892728, 0.03758521932468284, 0.01988693795283325, 0.01169220175142982, 0.03392401187738869, 0.04739080097351689, 0.036036505553056486, 0.04189026956737507, 0.09809541748836637, 0.01590593165019527, 0.07602036101161502, 0.06729131651809439, 0.04176901376922615, 0.05441853129013907, 0.09242379877832718, 0.03777971025556326, 0.024938822534750216, 0.05376059139962308, 0.015255911403073696, 0.06989738292759284, 0.02668466928298585, 0.036539143620757386, 0.04019356783828698, 0.04456194554222748, 0.022048840110073797, 0.11615135837928392, 0.017102078891184647, 0.009709993028081954, 0.017249680931854527, 0.04064703862241004, 0.034883478947449476, 0.012321679350861814, 0.049938790616579354, 0.010580115722405026, 0.02081720893329475, 0.030224452093534637, 0.03689792749355547, 0.013164267438696697, 0.033516658149892464, 0.08321808025357313, 0.017556002385390457, 0.03646449469670188, 0.017063438972400036, 0.07199555315310135, 0.061458095151465386, 0.02440678799757734, 0.026812613687070552, 0.11175068240845576, 0.039748564959154464, 0.04777001617185306, 0.05388949502957985, 0.006135335770522943, 0.016399073938373476, 0.028210569435032085, 0.012688449660345213, 0.030888917317497544, 0.03874722962791566, 0.022755997379135806, 0.04486791818635538, 0.05535154450626578, 0.0016904919243643235, 0.04770382773131132, 0.017415671536582522, 0.05766143091022968, 0.0796878915571142, 0.12587875477038324, 0.013720386523345951, 0.017074693641916383, 0.021479557181010023, 0.033113686804426834, 0.06043664390745107, 0.043461373934405856, 0.042135144904023036, 0.03909415769157931, 0.04030541320389602, 0.032839600535226054, 0.03405533490877133, 0.03150274766085204, 0.06922030675923452, 0.027419961370469537, 0.0368102130596526, 0.10682125590392388, 0.036173869666527025, 0.04469086401513778, 0.04617935250280425, 0.04093953386473004, 0.016758974743424915, 0.09282135244575329, 0.03993806123617105, 0.04909722112643067, 0.05736934384913184, 0.080089586408576, 0.061682019659201615, 0.028057195340807084, 0.07391810897388496, 0.0543622430996038, 0.026534113494562916, 0.0385230676329229, 0.009175647628580919, 0.0416585859056795, 0.012406533733155811, 0.05934030625212472, 0.02730399151914753, 0.014486261588899652, 0.0762185589701403, 0.03836752090137452, 0.01819798239012016, 0.013161060433048988, 0.017991333224927075, 0.045947067701490596, 0.01501822469435865, 0.04668423927796539, 0.014332655573525699, 0.04148322383116465, 0.01959949302545283, 0.02966721607663203, 0.00895037519512698, 0.04597803752403706, 0.09258206919184886, 0.018815831463143695, 0.027071942349721212, 0.036250322009436786, 0.10020284229540266, 0.05544057254155632, 0.02250817200547317, 0.03816790173004847, 0.041271296140621416, 0.057581182481953874, 0.040629672366776504, 0.10291727710864507, 0.012855430104536936, 0.0345021412067581, 0.06746382132405415, 0.021962389182590414, 0.01084816554794088, 0.012129741407989059, 0.045868092056480236, 0.05891587941732723, 0.05773886288807262, 0.05130171884957235, 0.03937511624826584, 0.030707096702826675, 0.016125779911817517, 0.018408323740004562, 0.053928246270515956, 0.03026996615517419, 0.029921511122665834, 0.0147982001726632, 0.042128625136683695, 0.029149484580557328, 0.010138378293049755, 0.017076511903724167, 0.038447042024927214, 0.015711976921011228, 0.017026431778504048, 0.012476788215280976, 0.03671417915029451, 0.06210855790413916, 0.02322182677744422, 0.07755120386718772, 0.02078243560390547, 0.014051192356419051, 0.01835785213188501, 0.04003154957899824, 0.07586634310428053, 0.08034637692617252, 0.03808207606198266, 0.00965518634984619, 0.07245460117701441, 0.15466549055418, 0.030740983165742364, 0.017341877937724348, 0.05555528259719722, 0.034137564871343784, 0.07668092439416796, 0.026222246342513245, 0.012109721046726918, 0.014964199126552558, 0.025768079794943333, 0.03205854205589276, 0.07810028924723156, 0.05501316969457548, 0.032931753012235276, 0.016525268729310483, 0.060864911356475204, 0.03184295186656527, 0.03179464918503072, 0.04499156741076149, 0.012690151961578522, 0.03572533416445367, 0.0887353990401607, 0.061098168371245265, 0.032844190718606114, 0.0432800153066637, 0.019164592631568667, 0.07345094185438938, 0.024972397295641713, 0.04160812728514429, 0.08971266652224585, 0.042738689080579206, 0.035615355300251395, 0.07086883197189309, 0.021514950203709304, 0.012356154893495841, 0.029233816676423885, 0.052114262944087386, 0.004302155402911012, 0.06508126010885462, 0.029026599768258166, 0.05132548983965535, 0.04216095680021681, 0.03265305429522414, 0.036906514142174274, 0.009133351704804227, 0.039307276529143564, 0.018978771840920672, 0.07316283270483837, 0.06630922507611103, 0.07325705577386543, 0.029868766687286552, 0.05936433328315616, 0.0488095869513927, 0.058884082100121304, 0.03571572706277948, 0.03612782311392948, 0.04481383046368137, 0.03266367442847695, 0.050378932428429835, 0.015962204997777008, 0.18970513221574947, 0.09373529246659018, 0.10839782247785479, 0.18618325557326898, 0.1840220918529667, 0.1676030392991379, 0.1457631916855462, 0.09528435504762456, 0.1300725867622532, 0.10248959966702387, 0.11567186418687925, 0.2341854860424064, 0.1584517053561285, 0.1178649254143238, 0.1271950575755909, 0.13271687377709895, 0.16779921861598268, 0.1465469441609457, 0.1509194407844916, 0.22557731514098123, 0.09514440083876252, 0.09811000811168924, 0.1283397906809114, 0.12975739664398134, 0.08604852017015219, 0.10339014392229728, 0.14942401321604848, 0.10578964836895466, 0.10599049579468556, 0.1659329843823798, 0.1132006682746578, 0.14729165966855362, 0.12498069670982659, 0.09262694686185569, 0.1257102278759703, 0.12178190663689747, 0.13620324607472867, 0.17332645249553025, 0.13615557050798088, 0.2546703501138836, 0.13032058282988146, 0.20205258450005203, 0.1061326393391937, 0.15743438416393474, 0.23479673371184617, 0.14949836157029495, 0.14782326004933566, 0.1982955212588422, 0.10824532597325742, 0.09273272517020814, 0.10824366356246173, 0.17705795617075637, 0.12104419700335711, 0.08505963807692751, 0.103182476159418, 0.1008596207248047, 0.08828208039631136, 0.14836410759016871, 0.14973105455283076, 0.1392230746569112, 0.17531006480567157, 0.164440406661015, 0.06883869442390278, 0.09911086104693823, 0.13525604299502447, 0.14263321354519576, 0.18238991615362465, 0.07129432007786818, 0.10802878212416545, 0.12611885438673198, 0.1443020810256712, 0.08529675425961614, 0.14818927244050428, 0.2381813427200541, 0.06350455252686515, 0.07997259424882941, 0.24204122310038656, 0.11153246872709133, 0.1245850429404527, 0.23635448684217408, 0.12259337832801975, 0.10075022815726697, 0.18407074705464765, 0.18835323600796983, 0.19799474364845082, 0.11336532115819864, 0.13051895890384912, 0.11793474666774273, 0.19446234335191548, 0.10716205753851682, 0.1789542325423099, 0.14138048310996965, 0.12750341993523762, 0.09789997289772145, 0.13981345313368365, 0.15168171550612897, 0.09136776716331951, 0.09848932721070014, 0.18797341967001557, 0.15800843539182097, 0.1365329377586022, 0.12946179922437295, 0.0991663291642908, 0.10723674728069454, 0.21576098719378933, 0.12899602734250948, 0.16674109414452687, 0.11435231819632463, 0.10855520231416449, 0.07558293917099945, 0.24415377614786848, 0.22158021165523678, 0.17187550925882533, 0.05952180959866382, 0.10665607609553263, 0.18676925537874922, 0.22066498029744253, 0.1021770887018647, 0.23749721614876762, 0.096843585051829, 0.1725351152708754, 0.13453705032588914, 0.09273278454202227, 0.11441284033935517, 0.12496855517383665, 0.11594685958698392, 0.06318525833194144, 0.11416483685025014, 0.16679583495715633, 0.10869378354982473, 0.1829036753042601, 0.23874316335422918, 0.08408743946347386, 0.1742739079054445, 0.27106985449790955, 0.1451224065385759, 0.12343574562692083, 0.25921282824128866, 0.16287978884065524, 0.13229089585365728, 0.14604743424570188, 0.21399396326160058, 0.25710952235385776, 0.1752978193690069, 0.12800908967619762, 0.19703861995367333, 0.12115591991459951, 0.13470709120156243, 0.17546693998156115, 0.0880771956872195, 0.07204794135759585, 0.11906759056728333, 0.1300676737446338, 0.16624551761196926, 0.15882061212323606, 0.18835234543075785, 0.16396725783124566, 0.07813174146576785, 0.11500292195705697, 0.12599356501596048, 0.10999987440300174, 0.11600470257690176, 0.09550763759762049, 0.14463439991232008, 0.08974631549790502, 0.15409728744998574, 0.14239128824556246, 0.12107233924325556, 0.13905337516916916, 0.1686720733414404, 0.19337649224326015, 0.1711467350833118, 0.1662390906130895, 0.15057987853651866, 0.1871801825473085, 0.12612387130502611], [0.02636162724229507, 0.04242622264428064, 0.0436401461774949, 0.03512341158057097, 0.0984819873701781, 0.016529302301933058, 0.00880882629644475, 0.02105273691995535, 0.018814755349012557, 0.011139738671772648, 0.033536903938511387, 0.06641151529038325, 0.04092328454134986, 0.04055016608617734, 0.11414554843213409, 0.013533420969906729, 0.015516522125835763, 0.013743427425652044, 0.04317130551498849, 0.053638300305465236, 0.07133682287530974, 0.019988218846265227, 0.06613531761104241, 0.043144539959030226, 0.09835004835622385, 0.0395890737127047, 0.009546232577122282, 0.03547777967469301, 0.047095214686123654, 0.019364048530405853, 0.02630834474985022, 0.060422695241868496, 0.01955128311237786, 0.024482659609930124, 0.022238631390791852, 0.06440572018618695, 0.027442142309155315, 0.008806636033114046, 0.0802902334544342, 0.039478898179368116, 0.05288929147354793, 0.039028863538987935, 0.06312610174063593, 0.05754540725320112, 0.03086961034568958, 0.056571397799416445, 0.03790921502513811, 0.014749848323845072, 0.0207063172274502, 0.036538360654958524, 0.041055861802306026, 0.039159837760962546, 0.011965216544922441, 0.06263734554522671, 0.040740278345765546, 0.005102442464703927, 0.06367338370182551, 0.023886850467533804, 0.026974973334290553, 0.03381614442332648, 0.05029493615438696, 0.009942302876879694, 0.07948550046421587, 0.01193971635075286, 0.01698025535006309, 0.011081976390414638, 0.026803850778378546, 0.021150286665942986, 0.03571106637537014, 0.0336417397193145, 0.06962957893847488, 0.04173982139036525, 0.011097400074504549, 0.14425663190195337, 0.015164533542701975, 0.013512419118342223, 0.07385096687357873, 0.04392057780933101, 0.04584458081808407, 0.039640946124563925, 0.02135319355147658, 0.024054236309893895, 0.07353865628829226, 0.05243714913376607, 0.010668032391549787, 0.01595645891939057, 0.05181692147743888, 0.021313904253474902, 0.017867394562927075, 0.03221049308194779, 0.0643197720637545, 0.00432677104981849, 0.053202128983684815, 0.011617452637437964, 0.02484877590177348, 0.047722722811158746, 0.01661900940234773, 0.03507791421725415, 0.0775853129744064, 0.035246927218395285, 0.06877029809402302, 0.012606457185029285, 0.017567028844496235, 0.011292338149360148, 0.04998585020075552, 0.009250455186702311, 0.045062895223964006, 0.08236589434091002, 0.021862976645934395, 0.04184426383289974, 0.02030039770033909, 0.017257321342185605, 0.0508835705841193, 0.044283220850047655, 0.019302676628285553, 0.039431571422028355, 0.07283012047992088, 0.05285900071612559, 0.04273987280612346, 0.018980415698024444, 0.0114960511928075, 0.020651930790336337, 0.022355091059580445, 0.056287463230546564, 0.06610628479393199, 0.020241910897311755, 0.04155494498263579, 0.012359568772808416, 0.017233912149094976, 0.027775548442150466, 0.03534090908942744, 0.0702621930395253, 0.10315083098248579, 0.028802352426282596, 0.04870406097325031, 0.062317828706, 0.034714773937594146, 0.014272876505856402, 0.014755702941329218, 0.07118746565538459, 0.03059838134504389, 0.05533560317417141, 0.046916687351767905, 0.09868011111393571, 0.01396941510392935, 0.0193309505993966, 0.03858093659800943, 0.057212249739677645, 0.005144958713572123, 0.04678590608818922, 0.06360193714499474, 0.06455624257796444, 0.04833527666050941, 0.04796806941158138, 0.046390797797357664, 0.05139777131262235, 0.027242157630098518, 0.06319765961961821, 0.029232176530058496, 0.024442166177323088, 0.008136543474392965, 0.01887903461465612, 0.055959200180950575, 0.03555268092895858, 0.00882388911122689, 0.03392866514332127, 0.0319417873834027, 0.010304692659701686, 0.02648252124345163, 0.02896235018852167, 0.006034017769707134, 0.02296738701261347, 0.022856554678583052, 0.04802041679795366, 0.007632018032381893, 0.00721397552297276, 0.09122992807533592, 0.010298515207978198, 0.09631562861613929, 0.07429183227941394, 0.07560894402558915, 0.018528624023019802, 0.03246966218284797, 0.029076381179038435, 0.027433512987045106, 0.01286552145757014, 0.08832260165945627, 0.03826411375484895, 0.008074718862189911, 0.030915065035515, 0.07548781810328364, 0.022419745109800715, 0.026531091098149773, 0.030946574770496227, 0.04435518691025209, 0.0594532722607255, 0.10410672461148351, 0.03369026133441366, 0.0351273226988269, 0.08899175911210477, 0.08020226669032127, 0.031645295675843954, 0.046074297788436525, 0.04393455987155903, 0.0545506966591347, 0.012557670252135722, 0.05127244112372864, 0.05872405650734436, 0.02230562320619356, 0.05604827274510171, 0.04789449660165701, 0.06693679257296026, 0.021922407831880264, 0.039295550595852546, 0.022863202466396615, 0.04776325891725719, 0.05964180745650083, 0.0261523415974807, 0.0026536663699516794, 0.01788771271094447, 0.033199768513441086, 0.047618970565963537, 0.04508092941250652, 0.035822815261781216, 0.021110719062562566, 0.0602081922988873, 0.08184582693502307, 0.02358606543566566, 0.02474602370057255, 0.02158330571546685, 0.0588607118697837, 0.05256541080598254, 0.05490127608936746, 0.030715850334672723, 0.1211822587356437, 0.020774229305970948, 0.05752705765189603, 0.07019306198344566, 0.09167377691483125, 0.04265912342816591, 0.0651587477477733, 0.07025322789559141, 0.016338535097020213, 0.04703359416453168, 0.004579526139423251, 0.09460724919335917, 0.09713265899335966, 0.05282945581711829, 0.06158713236800395, 0.07278406279510818, 0.038079129735706374, 0.00666112884573522, 0.04621134648914449, 0.04925318717141636, 0.00448329463324626, 0.031174054165603593, 0.03951040234824177, 0.056706639370531775, 0.0292356720456155, 0.04059293605678249, 0.01567917955981102, 0.01793911200365983, 0.030122462449071463, 0.05201123429287691, 0.0634743322734721, 0.025808189166127704, 0.025710993795655668, 0.07348315848503262, 0.043468431758810766, 0.02933818490419071, 0.039191872565425, 0.040405232066405006, 0.04364033913589083, 0.034023337211692706, 0.011904268594662426, 0.03867687031743117, 0.0523243797942996, 0.038647614856017753, 0.027866398449987173, 0.009197841554851038, 0.06615436112042516, 0.01906690187752247, 0.058479184881434776, 0.04287595671485178, 0.061914323014207184, 0.034880918537965044, 0.08802363488939591, 0.03470828756690025, 0.033469516929471865, 0.009368529954372207, 0.028275438708078582, 0.05783455169876106, 0.05041351279942319, 0.02176442685595248, 0.06363981636241078, 0.03422374677029438, 0.010682066404115176, 0.019805581869150046, 0.007108475056156749, 0.04072198069479782, 0.05055217938206624, 0.04228590849379543, 0.020735105135827325, 0.04490858416829724, 0.02734282439632807, 0.036062785002286546, 0.05736367384088226, 0.05948969686869532, 0.06842042741482146, 0.01768211182934465, 0.01740495121339336, 0.07388452679151669, 0.031908346209093, 0.0678910683200229, 0.025597805142751895, 0.05225476263149176, 0.018109258635377046, 0.025503600627416745, 0.03191614247043617, 0.0176705695776036, 0.03203232197847683, 0.037967484749970026, 0.06221126743184868, 0.007084658145686262, 0.027312834208714776, 0.03175692952936515, 0.023077015212038532, 0.016978587373159826, 0.047910671710269526, 0.07128136217943393, 0.008508559840265661, 0.02998457697685808, 0.031844309996813536, 0.052606959943659604, 0.023126028499973472, 0.04017049075628165, 0.05786946974694729, 0.0188689692367916, 0.03566202154615894, 0.011857917761517456, 0.03849289190839045, 0.036869484683847986, 0.01699576067039743, 0.029212806475698017, 0.010331536141165998, 0.030467857977782842, 0.053769088990520686, 0.08768085172050633, 0.0266153415577719, 0.06511113155283965, 0.015398965006170329, 0.08999571422464214, 0.12517727678641677, 0.15155651519307867, 0.16498873505042866, 0.14423882035771385, 0.34664242586586624, 0.09279326215619221, 0.11438252360676415, 0.14887347322655842, 0.11482438349048607, 0.07882195364800282, 0.09098808441194706, 0.25274400191847235, 0.09794600831810385, 0.13796028069918975, 0.22279178258031607, 0.06855552797787823, 0.1301476772641763, 0.10561190400039777, 0.12939916196046397, 0.09628094063373283, 0.2083054161630571, 0.06615596415940672, 0.14754753734450787, 0.125957288837526, 0.2117982303025201, 0.08335610487847589, 0.08892607904272154, 0.1451480551622808, 0.16881279938388616, 0.09076547721633688, 0.15880133112659678, 0.12469517765566707, 0.1058784760243725, 0.19668388820718974, 0.11924937964067794, 0.13986522535560653, 0.12927133444463834, 0.09017426011268981, 0.1219124800991267, 0.09964898490579799, 0.1833749984507449, 0.13414406828815117, 0.19247936928877607, 0.21489381731953472, 0.10914587022853084, 0.15696491638664156, 0.13918375567300245, 0.10121918385266326, 0.10032341160695069, 0.1632757394690998, 0.18068753328407183, 0.12234584981342778, 0.10550660808803514, 0.1818600672413595, 0.1643376934225671, 0.1434545632218942, 0.18537299358285964, 0.1508104192907922, 0.21937293087830767, 0.12238480514497496, 0.17653187736868858, 0.13527878239983693, 0.17046189605025575, 0.11153864339576103, 0.11157287124660797, 0.15838050370803103, 0.20811124064493924, 0.12608539836946875, 0.1442906222655438, 0.1302406980539672, 0.1198941575421486, 0.1576704761828296, 0.07712506267125718, 0.2593966730637476, 0.12756167852785438, 0.10468917695106938, 0.1300153523334302, 0.22554158815182745, 0.08861678899847902, 0.12438108591595665, 0.15416736103361472, 0.0809111661510542, 0.15356919000623748, 0.15444847173057497, 0.08174505812348798, 0.10989541711751372, 0.09553199488436803, 0.22039387375116348, 0.12135041455621831, 0.0953734276117757, 0.11259702761890367, 0.12964985944563523, 0.14329945435747504, 0.13098832278046757, 0.10315119463484734, 0.15414245455758646, 0.11588117209612392, 0.09450590892811306, 0.10847505036508664, 0.09965548611944541, 0.14833218039711937, 0.11257344216573983, 0.07929159211926162, 0.07597655203426257, 0.14643004105892032, 0.1495012262603268, 0.10643464891472831, 0.16614604013739154, 0.13487244170391932, 0.10390584007836878, 0.14387515315320343, 0.11272664371063001, 0.13624268380226567, 0.1399805847904645, 0.09988701393012889, 0.13365770922973752, 0.21579628373729065, 0.15346524480264634, 0.1169652865792159, 0.10681429455871694, 0.09296498028561473, 0.10111295283422805, 0.1810593789559789, 0.07824301166692749, 0.13651904475409538, 0.08805109435343184, 0.20113707112614065, 0.14047101081814617, 0.18597422225866467, 0.07021175668342039, 0.22144778282381594, 0.21283545589540154, 0.23698231409071013, 0.14007731631863862, 0.1394451252417639, 0.19644665328087285, 0.08102462568785995, 0.06743815043591894, 0.09387062309542671, 0.24565067316871136, 0.07526478788349777, 0.10812598120537587, 0.1746504142647609, 0.301009071408771, 0.1404740833095275, 0.11488352523883805, 0.16770499554695562, 0.10708684829296544, 0.13055266725132242, 0.13362501020310447, 0.17880918720038608, 0.17994448018725961, 0.15958365867845714, 0.17887063702801242, 0.17524839233374223, 0.11954738904023543, 0.14002662763232365, 0.12478074728278443, 0.1301091894856654, 0.13221746776252985, 0.12123974549467675, 0.1515800561173819, 0.17328076588455588, 0.11856353870825842, 0.14459882135270163, 0.24032315122894943, 0.12152330527896993, 0.1535977330058813, 0.09122016141191125, 0.13954489957541227, 0.09874668176053092, 0.15712088614236563, 0.09471440789639018, 0.11620754637988284, 0.08939360981457867, 0.15860878833336756], [0.06130957655841485, 0.07879415279603563, 0.0464594204822788, 0.04617549704562407, 0.05673953506629914, 0.00557573508558562, 0.06337708866340108, 0.05745626047428232, 0.015109596060938202, 0.020974729777663015, 0.050176890144939534, 0.03564736784028355, 0.02531537156755803, 0.05107540462631732, 0.025685013060865458, 0.04675162628700491, 0.006604839263673057, 0.06982828897889704, 0.05886333907255903, 0.03397286003746558, 0.006706691146973753, 0.05078193345980253, 0.024970942686195485, 0.039935148306540214, 0.03835650742985308, 0.037143982845009305, 0.03462393877271097, 0.03682311900774948, 0.08195177593734115, 0.024053893066593446, 0.06577228123205714, 0.045631517641595565, 0.005690385769412387, 0.03212626303138677, 0.006519594326164224, 0.044359016392263584, 0.017948162494576536, 0.04802367853699252, 0.0656386798073072, 0.010224288380413782, 0.029303990449989215, 0.06627834431128576, 0.03718228508660104, 0.0414950091362698, 0.062145687552401796, 0.009041062858159421, 0.02936096327175619, 0.010305848554708064, 0.07123653645976447, 0.03589127467421349, 0.03392418257135432, 0.01767015397490468, 0.05895763635635376, 0.052050434533157386, 0.03364130556292366, 0.01719781408610288, 0.05213462376559619, 0.09548924717819318, 0.008176265073416289, 0.009780899672477972, 0.027578729022934567, 0.010889214663620805, 0.02791911505482858, 0.050175595097243786, 0.0064634271984687075, 0.025457834235567134, 0.03434557773289271, 0.04693783113907557, 0.01436587317584781, 0.0357242654717993, 0.03133953454380389, 0.03318763068818953, 0.04319495776144322, 0.03765479566936847, 0.05921725074585993, 0.11342868572683074, 0.028444952658901457, 0.024877760479284916, 0.016113237616082188, 0.01503683775808895, 0.025542331459291745, 0.026744798087747768, 0.03501197439618409, 0.06558900786330923, 0.020973605423932895, 0.10706610526540317, 0.01711384378722869, 0.041275645126006566, 0.06590722594410181, 0.06655142497038469, 0.04456505143025424, 0.038148316452861764, 0.04550166035187431, 0.020742773376696277, 0.04115695715881884, 0.037110530538484454, 0.019846867544401903, 0.0613088121463079, 0.05503431719262153, 0.031192214519251138, 0.006963996993363253, 0.04976215204806067, 0.027835309883812442, 0.02852506935596466, 0.020791350652871188, 0.005460687352751847, 0.020983119757147506, 0.02906453093601158, 0.055003373345243745, 0.033439931212342344, 0.03467569244094193, 0.047489810895058326, 0.06063224805984646, 0.03027089755050838, 0.09779026120668277, 0.025690681213745847, 0.026629613057593815, 0.07578963472042233, 0.0512304429867072, 0.011060585839004489, 0.06743811332853511, 0.017104244107031263, 0.013215904218668584, 0.02795602020341903, 0.016970909855444916, 0.03659313115349505, 0.03427738178288564, 0.025477094823145308, 0.02336217246920569, 0.05586330727965105, 0.03128759533865377, 0.06795979861635715, 0.019649478526844177, 0.014949802389310207, 0.09233376884367317, 0.022466392802016344, 0.03070731007028371, 0.07052993765682913, 0.052937865038984455, 0.030986487472546287, 0.030231866148824338, 0.04392765047668945, 0.03480002444121055, 0.041246289474656805, 0.01806749241950456, 0.0733671682246495, 0.07495825862861238, 0.0450576519506285, 0.038235099491430447, 0.06360515806591138, 0.04912004958896432, 0.061551401668111794, 0.05091038437967654, 0.020358654437586665, 0.05137640859175008, 0.048126347246579826, 0.06305874441750348, 0.031411901363753714, 0.044361439504427835, 0.03611150328652002, 0.044210497799213044, 0.059846313670277596, 0.009462949692533584, 0.033446347079006955, 0.02972226302517811, 0.028908351523568854, 0.04123565449845046, 0.061777281734975986, 0.11627660322119482, 0.024769900446699467, 0.12720708036795259, 0.022681389273202512, 0.04740855314594228, 0.07269493085914291, 0.037205814878689125, 0.027201356206205674, 0.046198926647775806, 0.14628407545387745, 0.056075071697705425, 0.05447379902761895, 0.005793239088234259, 0.04095188691280782, 0.02967945038108155, 0.037904699056525715, 0.044506458871182986, 0.07072519671055488, 0.0418340481701307, 0.05308085834258236, 0.08602765097748488, 0.02101973175740568, 0.03473232201940846, 0.0688614635146223, 0.017659698969509918, 0.03691780591907445, 0.07110564387403429, 0.08591376099502668, 0.060813168820459396, 0.032152698331628926, 0.009564227802911773, 0.06690475405775942, 0.07171241639298387, 0.06264317882596515, 0.049381218777853064, 0.044038879859726876, 0.05496120822499506, 0.004099370507901767, 0.04968967390595935, 0.08927199407480657, 0.07356952963164076, 0.032000802966649644, 0.08649268071167171, 0.05363566197047476, 0.03576608178263996, 0.019760778413910884, 0.04828720404475462, 0.04066984482051339, 0.030132520405459218, 0.061053721146890894, 0.05249449117400218, 0.009586123014742043, 0.028615982446353883, 0.017800079913286027, 0.0344445097289281, 0.03094795702054398, 0.019963911654485855, 0.04108470166102052, 0.022656952205579728, 0.039348313584923744, 0.08070013645919971, 0.0295967992497026, 0.04612930577422958, 0.02138273288437631, 0.02042816769971978, 0.05060799630882684, 0.04394709845655598, 0.08168133732397109, 0.01617484143935144, 0.03436662504100241, 0.014897139590175357, 0.02548647185903974, 0.07349054285441525, 0.020614211134670768, 0.03649317499366589, 0.02095404426654568, 0.006810686445533065, 0.06015465747623239, 0.018661859940038994, 0.026624286292644683, 0.03704700640810188, 0.06404574887710623, 0.02997145023982739, 0.010451381858729292, 0.08455779039650224, 0.05749811760324519, 0.047082650125958025, 0.06870717843412422, 0.051833300676662475, 0.007575511372124311, 0.04118377837585285, 0.032258929350064136, 0.0356890320108505, 0.03633819600509014, 0.013657696381415008, 0.020237496974004898, 0.06699277277220972, 0.10724794628913514, 0.05573195085162297, 0.06065000023227185, 0.06394496522261761, 0.09633364054025151, 0.018864972771552857, 0.008274896499642637, 0.04889596180873923, 0.06325051537714899, 0.06841815644293092, 0.04397996817715466, 0.06702874467009678, 0.0693001618492417, 0.035770141330431215, 0.11904085098649375, 0.025457552219450008, 0.03473864882835187, 0.021720415643358137, 0.05999872482789215, 0.023851553924032487, 0.08443463841103949, 0.014420028619497316, 0.03598750525270589, 0.028340202225081157, 0.026723233131633606, 0.04720348661066964, 0.025216658505087253, 0.016274942317977548, 0.008338053266925272, 0.03542108701367397, 0.03761294596188236, 0.07932095890282653, 0.02483078253135318, 0.034358246193733066, 0.06678367266431451, 0.05742983630625531, 0.023469776460842695, 0.09597179159754887, 0.05615336085611489, 0.03387449949514121, 0.024027793588174973, 0.02155310216039652, 0.03529571971739642, 0.038615565208601765, 0.04703043261542916, 0.03809344576438889, 0.09101137300604023, 0.09845869877608493, 0.07008833010331728, 0.03745538429939188, 0.04692614602390677, 0.020055032546224538, 0.047957605129340664, 0.07152279766160063, 0.05051607760833576, 0.010709010075515835, 0.06836245825979859, 0.018706121627474204, 0.0723308628948871, 0.010309754106856417, 0.06551924598170444, 0.028226419854036067, 0.0042240610582666704, 0.059173029876546934, 0.02448362069117138, 0.116757002833765, 0.03326404963445384, 0.03426669856708031, 0.008545979853806784, 0.03147686897136737, 0.006272360351431416, 0.011119969713035971, 0.05593944420979824, 0.015402949411509326, 0.06901447210111655, 0.0461613702645991, 0.026252119641867466, 0.017878157559607644, 0.040314745710929856, 0.050706082256510854, 0.05809691945614759, 0.02913956021075137, 0.06595647486392409, 0.09251373223378323, 0.0006441972868742596, 0.06902345208800398, 0.0380694076011423, 0.11840035527711734, 0.21821014874149114, 0.08462947444058955, 0.1442024254356511, 0.09914556387229823, 0.11115496788988821, 0.21086520224343985, 0.14214523660484701, 0.07087551130098291, 0.1384433446219191, 0.15208064956823364, 0.1578958664322272, 0.1877455209614709, 0.1386851808638312, 0.10609760996885598, 0.14747915585758165, 0.09900085991830565, 0.14634000370278955, 0.23253143182955682, 0.18311992229428142, 0.2326074574375525, 0.1918642476084642, 0.13981152354972437, 0.12750080757541582, 0.12413019547238946, 0.15567451453534886, 0.24785519315628335, 0.15342724684160203, 0.1772107495344244, 0.10259550414048135, 0.15667855128413066, 0.16503844410181046, 0.18527592066675425, 0.17892870266223326, 0.20720066997455433, 0.19001901615411043, 0.14746786036994308, 0.16168363974429667, 0.08789192594122142, 0.09696890410850756, 0.12010909835225902, 0.1257994191837497, 0.18224261468276381, 0.17303924134466797, 0.09936686488799751, 0.1182098533899989, 0.1262193263391964, 0.20845924853347242, 0.11957049209740944, 0.24498167156707495, 0.10034601000370458, 0.20339760842034593, 0.143524325103499, 0.08763949925196357, 0.1352281085564755, 0.09816099365707487, 0.15854537923587486, 0.15644446306396276, 0.08200007490813732, 0.23115210584364831, 0.09620064767659642, 0.08339172054547817, 0.1689273424562998, 0.11463117276434787, 0.1344367119600065, 0.09761346678715199, 0.09349754545837641, 0.08516707879607566, 0.11979574876022525, 0.10022681366535835, 0.09408056183019653, 0.08526521298335865, 0.19824075076030567, 0.05998927357723005, 0.12445377928088419, 0.16512048110598698, 0.1370284252334386, 0.16408194933319464, 0.23074665572494268, 0.24460987042402849, 0.10102165382704698, 0.15509247779846191, 0.10495983820874244, 0.1394422457087785, 0.11582749997614883, 0.18933484505396336, 0.06518162073916756, 0.11129086255095899, 0.20250661560567096, 0.2916903980076313, 0.1700048815109767, 0.13542982429498807, 0.2091851580189541, 0.18567345949122682, 0.14215580478776246, 0.11797088183811866, 0.15480906644370407, 0.1387055157101713, 0.1669188088271767, 0.1922023404040374, 0.11677868096739985, 0.1739678462035954, 0.172507225361187, 0.20592761953594163, 0.1123231602832675, 0.12376209022477269, 0.11000557409715839, 0.21421387646114454, 0.18699596665101126, 0.09934746514772996, 0.09562959472532384, 0.10406416986370459, 0.1285134383942932, 0.10112030009622686, 0.2617487171664834, 0.07720699577475898, 0.07970625229063444, 0.12146365887019783, 0.1153662106662523, 0.14343556424137205, 0.14166572014801204, 0.09210894262650982, 0.12685836001764983, 0.09373151493491605, 0.18106754258042201, 0.11209492018679157, 0.20514018600806594, 0.08527615224011242, 0.08966962195700034, 0.14147969341138378, 0.11912205678527243, 0.12569493963383138, 0.14840865129372105, 0.11296997909084894, 0.10498094488866627, 0.21835553547134623, 0.18058603716781363, 0.16883757227333263, 0.09599952565622516, 0.1790846575750038, 0.14637853601016104, 0.1521911405143328, 0.17017919715726748, 0.10683114131097682, 0.10490385800949298, 0.10501899480004795, 0.1874460792168975, 0.26759799860883504, 0.06211410916876048, 0.21888667572056875, 0.13890605885535479, 0.13415297406027094, 0.2767864696215838, 0.15111983550013974, 0.20144524052739143, 0.12990837916731834, 0.17065757070668042, 0.07723141243332066, 0.171875806117896, 0.15402476477902383, 0.12123939668526873, 0.2075050544226542, 0.1435154044884257, 0.12755594914779067, 0.1410710223717615, 0.14394113008165732, 0.19136234797770157, 0.17483664880273864, 0.20936211571097374, 0.10313117149053141, 0.17274155106861144, 0.14241154887713492, 0.17208638309966773, 0.1693074853392318, 0.1691377116367221, 0.13812316727126017], [0.04265326788299717, 0.03427780480706133, 0.04860082452069037, 0.046672071766806766, 0.0105462153442204, 0.019705618287844118, 0.05144722803379409, 0.03794638549152296, 0.032438625567010604, 0.02516226093575824, 0.04459124924323987, 0.047615801595384255, 0.0467463384848088, 0.030720967442903202, 0.023511023173341528, 0.041682390292407945, 0.04091990034794435, 0.03965178519138135, 0.00983299843937857, 0.003994367743871408, 0.029555966284533497, 0.051080788907711394, 0.043949102255282924, 0.05114137784403283, 0.04128408705582842, 0.05658793656039052, 0.07020547811407596, 0.0675352530379314, 0.055578192695975304, 0.028285953085287474, 0.06128950146376155, 0.017156222274934407, 0.023540326874353923, 0.010641542357916478, 0.03203503823897336, 0.0571307693462586, 0.02614457131130621, 0.02887943002860993, 0.010211034550593467, 0.021042088956164662, 0.04093194911547471, 0.012784041064151097, 0.015380907625512918, 0.031798497220734134, 0.06558615801623091, 0.018172715972468723, 0.018450581628712825, 0.031473815033677965, 0.05507982939889189, 0.04727533021650743, 0.007274578838405432, 0.038079808800830506, 0.012357757932477398, 0.03787897621805314, 0.04226410048431717, 0.08620967753813602, 0.011074450085288845, 0.0010653202889443492, 0.07400373797281645, 0.012813092434953433, 0.14435523364227265, 0.00561807136364223, 0.03895281937730033, 0.040385813772445545, 0.030799841042608023, 0.05628970451653004, 0.044517153219203465, 0.057834971012198366, 0.07976661116117612, 0.025407271714357194, 0.06609588730498217, 0.04525794276560191, 0.012084542759112082, 0.030239194857131224, 0.06802035044529475, 0.06079573948227335, 0.0085701664465887, 0.021587216833722778, 0.056464662120561115, 0.022132977392175235, 0.05500904706423171, 0.036308216949691996, 0.013057462183496682, 0.031061659610713832, 0.08877115571522154, 0.021992034271534067, 0.0317736278520897, 0.0904323419672437, 0.025559846144460607, 0.015706280937592965, 0.061637116014026105, 0.035169064794899896, 0.04502275987761095, 0.02060660412098514, 0.018927650853584055, 0.06483437726274133, 0.011536230140336556, 0.09365692909341305, 0.055165547455544583, 0.07281760787009262, 0.035986618386232294, 0.029832319814886432, 0.034089217660948634, 0.06148521322757006, 0.03487943424261175, 0.025741416284290608, 0.036363863182486966, 0.004857067569901119, 0.03513917479722295, 0.04115781433938537, 0.06810592749388888, 0.007687617880947073, 0.0638264516601339, 0.005963477096884162, 0.03360751928994432, 0.014687647999380715, 0.019648682573460974, 0.05028206360293552, 0.013910735342506086, 0.11578969497350045, 0.019033145290450193, 0.05423077163868584, 0.026051040294987615, 0.03863870537315961, 0.03880040821968578, 0.04874939135333989, 0.030587889232265297, 0.08553117644623853, 0.03281807083112653, 0.01933004146849271, 0.025268362078350037, 0.08130241156322882, 0.043341346390661784, 0.022858667944092304, 0.003936731627618428, 0.07439510212861933, 0.029103295164532028, 0.052239118158468045, 0.02860760359908454, 0.012365739730739733, 0.02285500358993886, 0.051211625832365826, 0.05212013333220966, 0.09718529210658744, 0.06897512343130074, 0.038631150309811346, 0.022874711321492214, 0.0859958202636335, 0.03959984969696961, 0.017281073778576683, 0.025876667132251896, 0.03032244712812826, 0.026311068431823514, 0.048278650792781264, 0.06639336235821247, 0.01598822469532024, 0.04937466932460666, 0.06675760843791068, 0.033315109394607134, 0.01618443555344129, 0.04257544256688561, 0.06586040384718217, 0.04174684210738633, 0.02306976071849931, 0.008508473565598251, 0.05350515901227482, 0.07826663422747515, 0.05502507745404728, 0.06548244287841953, 0.019824677328870166, 0.02399972185230581, 0.06017276959028095, 0.004851019530178746, 0.031505693987128325, 0.04380666927318089, 0.04130572808207944, 0.021310501506377477, 0.027316723062540404, 0.01665333373239264, 0.013807723389618332, 0.025370323892275337, 0.011557408251974266, 0.0912765646353364, 0.01103418208003859, 0.035263373210909776, 0.03795761047513224, 0.05907329265028238, 0.030795460515946615, 0.02094672297971556, 0.0017122223562182626, 0.004314510306357988, 0.06157440824608784, 0.02877257931686472, 0.021933170828560833, 0.03506271132209804, 0.020638535024772864, 0.09890593923046254, 0.024640109950269107, 0.07787193040712737, 0.07688611338380724, 0.06721818528603762, 0.06211669184267521, 0.03440694592427462, 0.05192317104956601, 0.017868424292828422, 0.059326198024791665, 0.033139060833491385, 0.04161842087341938, 0.05565819621551782, 0.05048898921813816, 0.05749123047280591, 0.09949431390850805, 0.0764970869931858, 0.024914331661420874, 0.018259909047628753, 0.07302584708668292, 0.04294169986678753, 0.06644544628215954, 0.03200933766493108, 0.03736778860911727, 0.029839475973858498, 0.0383689421141753, 0.012490859335230198, 0.024633432476548478, 0.061379382968880236, 0.040507756057195365, 0.05058657792687882, 0.031355475875898264, 0.03677674219943583, 0.05799476282845717, 0.06954004624276422, 0.07696281434618868, 0.06503589262138121, 0.00661550392578647, 0.09779489220818505, 0.0908191641792655, 0.056642406489118, 0.035264701655250974, 0.07192900477093644, 0.020863635836576577, 0.02168125251046149, 0.057295919468742795, 0.03587845407309942, 0.04559655877528712, 0.04889186515356414, 0.01130686940086889, 0.12772809772286564, 0.019948267181462143, 0.05122173017298337, 0.026056858732772525, 0.03393891420273576, 0.032706711572245695, 0.0449101204139879, 0.0624578126007691, 0.02904622957430547, 0.037799284400534816, 0.03462295171630103, 0.01908594167616684, 0.03185040673997719, 0.025041725020855665, 0.05832809103594627, 0.05314912850735709, 0.03740157488209661, 0.054249358727247454, 0.012196586649224628, 0.0821073968836572, 0.06742055411450565, 0.024090866863843985, 0.050379036329104565, 0.05134207312949002, 0.02016501883190358, 0.057472450425848365, 0.053477191177080385, 0.05540039266634267, 0.01589532821526518, 0.024568383232690394, 0.005485921765284729, 0.01984611983061768, 0.044058042112737894, 0.08746111663640477, 0.029419123529805802, 0.022864302700327244, 0.06348087801598012, 0.08298219603602774, 0.05957994202617556, 0.023953528725542128, 0.01707270468614297, 0.08168730419129133, 0.02920546663517598, 0.01668323115154635, 0.04442161283805035, 0.06257113855099306, 0.04814855601580348, 0.030993096297606826, 0.0330127510096645, 0.03931626764824614, 0.022732218967576046, 0.037861101591261104, 0.01767994290275965, 0.04752065826323815, 0.029610866658913437, 0.0358836157101905, 0.06104695647081826, 0.03484911379928235, 0.01388123497235938, 0.0182386520828004, 0.04946263237798121, 0.11179984227055684, 0.10897777377977036, 0.0021299267245922238, 0.03130169243377168, 0.07718353648670018, 0.004646960460377159, 0.017998205512412824, 0.040824716197676025, 0.04821217662538402, 0.025654380915511865, 0.03873555935570039, 0.025296209314547013, 0.05128762175445445, 0.06159982680401299, 0.02186696197895799, 0.029635546779900324, 0.014766747026442317, 0.07073206899804063, 0.011997373803751543, 0.018030271858151536, 0.022591492925130296, 0.07886348423198797, 0.032880433500395156, 0.046570430931751616, 0.05826386186527088, 0.02188125017710263, 0.050852856802521273, 0.04249118283041753, 0.04397643184347544, 0.0435366573947249, 0.058945454002241604, 0.011859198893944267, 0.03319410592666827, 0.010826060679391958, 0.024263301165774465, 0.05972204846329987, 0.027442403916211333, 0.06200279814947862, 0.01678701493801782, 0.031606874690623954, 0.006598395566470572, 0.014253173412726028, 0.003960727117373608, 0.02550559329392854, 0.07050693850032985, 0.10580574555206113, 0.1590014883549884, 0.15239003609167412, 0.11214276644750498, 0.07666680132388137, 0.07758891981211491, 0.1446109332027845, 0.12383893219521269, 0.11046063678804785, 0.10344188645831309, 0.1252036527148448, 0.14216647687135264, 0.06989110435824841, 0.12214106900501065, 0.09421799273695797, 0.1307865179842338, 0.15899354737484828, 0.1707358969724737, 0.11201134693692438, 0.10751658148365095, 0.16898825793759897, 0.13764186966000125, 0.1865368740982376, 0.16846832411829382, 0.1582573665655218, 0.19921317201806232, 0.18955400126287714, 0.19097888027317822, 0.13217304280260578, 0.0901052552217152, 0.21810699021443725, 0.1718344833352603, 0.227591103175655, 0.1537397355423309, 0.1265883370069787, 0.1381048807525076, 0.12542353622848168, 0.11381887728930451, 0.10417014113045298, 0.16002876916900277, 0.08824319927953184, 0.09377325332025066, 0.14714781660586596, 0.18830501125194132, 0.1051843749883119, 0.13791723613394424, 0.07702758157392964, 0.06448094427469186, 0.16723871900467202, 0.12096998965716921, 0.06366112342220731, 0.1609529062989168, 0.10790190455736592, 0.15673410845920444, 0.1785345925600268, 0.28210164222400635, 0.1772233215160668, 0.04506128476350568, 0.1771683877450414, 0.18766005523502827, 0.28018235927447677, 0.14919455599738285, 0.24308125401148573, 0.07669506972888485, 0.09984482283471152, 0.22570049681235105, 0.10611065692501143, 0.1948010001797229, 0.17411876935511827, 0.1085834855621215, 0.16979313193587586, 0.11561719758901745, 0.11688624043017626, 0.11915401366422884, 0.17977495881495997, 0.14467171509750187, 0.16454322380013764, 0.12342967485892586, 0.18404497968731448, 0.09512342032394372, 0.1198472834948916, 0.07516562953242101, 0.10334023449104279, 0.08712599985301495, 0.1638470299076289, 0.14359548222273588, 0.12706544890534133, 0.2888241346227005, 0.15985699166776612, 0.17366950283758342, 0.1071739022154361, 0.08028840034967288, 0.17913942807354033, 0.1047768394346349, 0.09240514118573628, 0.09403197342180647, 0.15344240149715915, 0.2137520824908279, 0.11862129264045507, 0.16462702711578459, 0.16066915355622768, 0.17306537978583947, 0.13749998586717993, 0.1868451919290237, 0.12310487392824143, 0.14711922907736152, 0.16048250341555104, 0.16802901722257957, 0.09593179725925438, 0.12124825792852789, 0.1383679424179718, 0.1666534910327755, 0.15847974369535223, 0.2170827818918042, 0.11781606983277015, 0.14829234190983698, 0.13917281641624868, 0.1789541880134493, 0.08275093539850786, 0.3522627695929259, 0.07516381127061322, 0.155562361178454, 0.07536004995927215, 0.10629079100908712, 0.17399861564626917, 0.09438279405003414, 0.1749334842315875, 0.09870210837107152, 0.15936381969368085, 0.10215541798970662, 0.17709169420413673, 0.20671894191764295, 0.19913895725039765, 0.06939233659068123, 0.07531975134043023, 0.1154977414989844, 0.1971939069335349, 0.16091055935248733, 0.13454957777867094, 0.10661472362698987, 0.11030724228476174, 0.16180008271476254, 0.10513634319067933, 0.1783409810741432, 0.14398439729120582, 0.12630635057576, 0.1565177575685084, 0.14446814398979768, 0.10923793364781886, 0.06475775793660432, 0.06400329803000204, 0.14956892497139052, 0.15201986767351627, 0.12772180431056768, 0.14703873574035242, 0.13863134547136724, 0.14285400247899815, 0.1555762393400073, 0.13763434428256005, 0.28014376759529114, 0.13675397902261466, 0.1677196752279997, 0.19803847098955885, 0.1512834642198868, 0.06583925263839774, 0.0949245247466024, 0.14068822260014713, 0.1045201528177131, 0.15135019813897088, 0.1290842390153557, 0.09086279504117556, 0.12075466293026693, 0.2656754798954353, 0.11779007982113399, 0.18322319956496358, 0.18041700561298057], [0.06264874493354, 0.044767587241949514, 0.08655703233671375, 0.02795170461467933, 0.033302578231086954, 0.03914040462404955, 0.01558277457661461, 0.018273828027304262, 0.023800013623258565, 0.03112414287897991, 0.035265518017695285, 0.04459996576770209, 0.01913324431370711, 0.015742750074423384, 0.01410000897521968, 0.029882565067964606, 0.04921125582768582, 0.03698375316162128, 0.053076984331710264, 0.01888354316179175, 0.004133776474191109, 0.04599382671585772, 0.021202454081503674, 0.048573684180155396, 0.011900145036634058, 0.008646193909953581, 0.039662130729993805, 0.05792451112938579, 0.05108787641802337, 0.02288026258611353, 0.07021971992799081, 0.07880538891186006, 0.03215393400751054, 0.04421668731083628, 0.05050229221524205, 0.0367313116294099, 0.019703644175024237, 0.031481733749387786, 0.06873946185805835, 0.020829771638091188, 0.03061764749872964, 0.03499113488942385, 0.04849286058743019, 0.021548313452512957, 0.04318673847592436, 0.05167759067262523, 0.03311563494207803, 0.011804373662016587, 0.06167513252876233, 0.0163796370907221, 0.038136200892040506, 0.016049956539063714, 0.01880484211142175, 0.019211104881833307, 0.002677327661331219, 0.043222539679845795, 0.0520022728596814, 0.029715192213188857, 0.0172860498787486, 0.003041559593839338, 0.02520283971534809, 0.049146369856316596, 0.06868081734864973, 0.033094650716520846, 0.084038717468502, 0.04613421879184898, 0.0360130425542593, 0.047418419999303296, 0.04714368435088545, 0.04369596681499388, 0.07227140944451094, 0.012869604197476292, 0.06991556554567069, 0.018580579926492646, 0.02269724525831407, 0.06906049267854542, 0.06686038104817271, 0.043708961820811965, 0.027870741869264748, 0.06836107786512002, 0.0716927791654598, 0.040755310546956025, 0.10083302957355045, 0.0770240044221282, 0.0465277425973909, 0.005188197164898156, 0.02304731260664994, 0.04172809545707423, 0.01367063201541896, 0.03845773266220931, 0.031819084397284314, 0.007125123283913126, 0.04713998845545575, 0.023123714854591526, 0.01671978006925201, 0.03515602154948283, 0.05551293565076776, 0.059068383343401365, 0.01978448261070298, 0.021037938495283015, 0.03604240933782421, 0.060458978841779754, 0.03834206523606554, 0.034352861912338994, 0.039743343950249255, 0.04410430388816167, 0.009570428446750157, 0.008409190904785646, 0.03259391254687216, 0.0842322621610947, 0.08176206814823672, 0.028084510086046066, 0.02327663252799539, 0.0912455577054061, 0.019384201550565194, 0.03017482096765889, 0.008695296255609719, 0.021128079752088524, 0.03298433046438731, 0.01840590062784031, 0.0475497949810233, 0.033883216019603424, 0.05268718239676673, 0.022189772098499816, 0.06446627201512456, 0.020157372855464928, 0.03578662814106792, 0.052403540976229124, 0.02651181937835645, 0.018448052760504652, 0.03173550001520198, 0.026188140946032945, 0.0736214428616222, 0.02716215225518681, 0.017998101611738093, 0.037349238627939485, 0.05981015623547137, 0.06114513518696185, 0.05076300127257127, 0.024257586628664285, 0.12047986791003495, 0.03221670485800132, 0.015761606191517785, 0.032189134071813896, 0.04588876086927485, 0.055069383670343086, 0.03138764055620413, 0.03829168083029799, 0.022034516659914516, 0.026615419483277947, 0.06925593726919033, 0.0429756790981628, 0.01516226813691901, 0.04932032185024582, 0.014117545924818842, 0.028105806013627443, 0.0369773298734799, 0.004572088428176357, 0.0435534113785252, 0.011521380693011452, 0.041317747163702734, 0.0029194178569014184, 0.024964469303085934, 0.011055016948375851, 0.04359989208751358, 0.02596815538709052, 0.020048043370479718, 0.046800838099443354, 0.023622862972842995, 0.0408671930199489, 0.08792095875833184, 0.01774981054040836, 0.07879237906308845, 0.03145635600958485, 0.08997330878628418, 0.029405887325992808, 0.018901597759395372, 0.06132475347840227, 0.05488205446454231, 0.041689080753712915, 0.010649614141584607, 0.10163897968595847, 0.04111892580112908, 0.013751241313002538, 0.05381793343985919, 0.050708713170024566, 0.017546107701491565, 0.02886323451093631, 0.017625153850531206, 0.08596325482358225, 0.020786916320503224, 0.01444145349523751, 0.007848025215935195, 0.03260125609813258, 0.05067573212727439, 0.02730191536102211, 0.017604167769604828, 0.023419111894327216, 0.02745517256698804, 0.06288847347605042, 0.027604462993622292, 0.0377293518249644, 0.03770241928577889, 0.02253913440654287, 0.02316311361937551, 0.018521273050282616, 0.033093203528551385, 0.043036598290200345, 0.0350542434171075, 0.06047329858120065, 0.06340546096907929, 0.10930725766229443, 0.053168205413385294, 0.07204881709185429, 0.07083669697749428, 0.02480204657331342, 0.02966063879284775, 0.05499037462868728, 0.06872935380670242, 0.02674688908882672, 0.09309049230068922, 0.03195840406988282, 0.056012208078755066, 0.047019233606988564, 0.020816181058762595, 0.03811313123151194, 0.04184218210866675, 0.0114523405500222, 0.02858684387319954, 0.01676336269156309, 0.007303412203327753, 0.05602571145573165, 0.013796294315397972, 0.05634776644001249, 0.042459378091734834, 0.027451495225250255, 0.008252989227912622, 0.04554457133053802, 0.05147896968992427, 0.021623867796733975, 0.04374954245577101, 0.015081709861988202, 0.005218132155277999, 0.03769838571315631, 0.06349217350361869, 0.026881308731390163, 0.050218513497384265, 0.031230932363541797, 0.047740359950694256, 0.011537930586200673, 0.0031390149479193497, 0.046389272683882155, 0.07981741116964258, 0.032516283899894916, 0.11131507882964797, 0.012075144386471948, 0.041974228734034114, 0.014219615350157255, 0.0621584562031785, 0.08380042869248427, 0.037240517704049125, 0.03338096386869438, 0.040416271513095126, 0.04612869721313473, 0.022533894843945745, 0.05213572585489601, 0.0255499551713001, 0.013113356108078733, 0.023084570275386795, 0.02390895719145192, 0.008069793784670765, 0.023797698122507427, 0.03716627696121577, 0.023225305594678503, 0.018036331493931357, 0.02266377254272811, 0.03187296802934725, 0.06595548780751415, 0.023926097092044074, 0.06591878860490397, 0.050152688709204085, 0.0460094786103582, 0.05435539307654835, 0.011392414908186765, 0.11393238877644762, 0.0136941052187467, 0.03430362783547025, 0.017780938069336116, 0.013075332171865739, 0.0737453592591919, 0.08284924027975649, 0.043702145194401965, 0.023203230412036646, 0.03875137823342811, 0.02865578939236002, 0.017352800496155396, 0.03201327475835569, 0.0276713657513028, 0.06253561194171198, 0.04989992805349175, 0.03860385411826428, 0.02989726886880817, 0.03082758623349946, 0.02963656352221733, 0.023533768144261558, 0.06076543759263586, 0.07393918596790172, 0.0103258921080851, 0.030915430543245748, 0.06583888156455941, 0.03682403556013014, 0.0014411935035241186, 0.04748422252305318, 0.040785237652016804, 0.027951897573075257, 0.04843813461775426, 0.07461800618330017, 0.028044825594406575, 0.057788939302554354, 0.05543928862607572, 0.02607272399473004, 0.06552421094966121, 0.007601613633596571, 0.002255531508126296, 0.028210959062562324, 0.06899261585203931, 0.040594464880996384, 0.06533198727993295, 0.08986807966721244, 0.03815248732280452, 0.07606650775414892, 0.01744247605529381, 0.021243776864139363, 0.045079972042003646, 0.03232761511753779, 0.02153310128051089, 0.02184818935347721, 0.035161524574505165, 0.03914548833563458, 0.07602252808283083, 0.033487658729427494, 0.015895944197836798, 0.03375786356627941, 0.09361853037262335, 0.05889546293474268, 0.04720744596852455, 0.024253592018794734, 0.0371824928879505, 0.043449677687021904, 0.049213742022402585, 0.05866454368515406, 0.020094008286832832, 0.09044713297043927, 0.15450934268301353, 0.12786929873982444, 0.09101240459131077, 0.06196171285409946, 0.24174005957320333, 0.08804796249023639, 0.07054854329908267, 0.1565504417521879, 0.1356930343899876, 0.12441671642591245, 0.10816031295689754, 0.18320011877221987, 0.12859056238085032, 0.09110595230595209, 0.07713143029832281, 0.14502191974315792, 0.12158959390944801, 0.2222130261361599, 0.10673280674382113, 0.09834933589445427, 0.1277605741051957, 0.1347851799800992, 0.158989139017649, 0.23773036926286295, 0.15459648566320539, 0.08410767783061601, 0.23627218266483396, 0.1389128272421658, 0.20881835895124823, 0.1605148907401599, 0.13625326682813466, 0.06302485053311102, 0.1111120346467942, 0.19233914790675044, 0.28919678181409836, 0.15549206495052204, 0.19567700161132962, 0.1642189794802107, 0.2211609872756526, 0.07681750183110125, 0.1329802768304944, 0.12248728089616634, 0.09217733153491281, 0.18342059600399807, 0.2625239052576944, 0.21752631902927533, 0.11932013600016944, 0.2137576782843098, 0.12976772733964026, 0.15758621273562312, 0.12110583236790262, 0.11756869716919027, 0.11327194413752295, 0.09457349631702527, 0.10351414195611142, 0.09509757874184288, 0.16336041851900518, 0.1584395341342315, 0.08854037005221471, 0.12343371214228682, 0.12344337490503676, 0.10375015233876184, 0.14133834396488965, 0.11839457394671626, 0.1239859071210958, 0.11450413934653625, 0.08174486516509205, 0.10813744738698006, 0.14391622360562906, 0.17947096028365195, 0.11461158748716116, 0.15320224250899628, 0.09064493759069592, 0.1486923298216425, 0.12734069663565606, 0.1366964922635816, 0.09604095976101235, 0.22057377034798265, 0.09334535323432647, 0.17615568271139637, 0.12657187617151067, 0.19723096978850663, 0.2364595452672802, 0.19444355217274278, 0.22949814068851992, 0.1708512267214246, 0.17164502787636593, 0.08471448745694943, 0.10920334214461036, 0.12795623391866684, 0.14178041164996102, 0.17301835730904713, 0.19436503294855356, 0.0830368923197966, 0.10527829377679154, 0.14583081618184224, 0.09822369029279798, 0.08499017305439338, 0.09345027807285078, 0.10594970735837705, 0.19342597865033895, 0.188865288218949, 0.17018513433868065, 0.10902526380959898, 0.17683146754279733, 0.1558492606272921, 0.10472845140611753, 0.10773551504826173, 0.142448092228733, 0.13180643669329584, 0.08595818595495075, 0.15408066334202886, 0.18572687928099185, 0.11963983095483854, 0.12663470639381558, 0.103342579677701, 0.14440374041441828, 0.18170636845752597, 0.122496030817274, 0.17516669671749696, 0.0936057728540618, 0.1932468093582429, 0.1514353373204358, 0.07197233135229908, 0.1050767487322446, 0.16273150773486122, 0.22808172216173261, 0.13742606795858592, 0.10320324145141058, 0.1881120676989667, 0.0709229419589974, 0.12407186266500503, 0.13324062223546207, 0.1368591858772561, 0.09642722536227666, 0.1972803968237713, 0.13282403990160674, 0.13730103091802448, 0.18317599897272885, 0.19246132025728002, 0.11338466894812882, 0.0845730712171644, 0.1675912836799398, 0.12492530280724168, 0.15797962521901354, 0.10960297382553108, 0.1712720244540833, 0.08691529670613818, 0.14699727937113494, 0.26794891571626067, 0.13240101572591811, 0.1947080239187926, 0.14140386076178402, 0.19190007849829271, 0.12602608592715114, 0.1314081557211466, 0.11291359813185409, 0.09030659246491268, 0.12306973323575221, 0.0867882558668498, 0.15976340684574097, 0.0894109315413516, 0.12716457014903426, 0.08708091438165866, 0.13521981134545058, 0.135838792193681, 0.13875981123419479, 0.13498119602445513, 0.11575580851058476, 0.13586270419182256, 0.14438742800848559, 0.16507228603586555, 0.17915790755068883, 0.2079742995556444, 0.16850866726599634], [0.02640800033987034, 0.05183273664442822, 0.09086983802262694, 0.030278949852799997, 0.02062852530798409, 0.052958660016884096, 0.05602006000117399, 0.03661759976239409, 0.08340848566149361, 0.034405973710818216, 0.025513597356621176, 0.04489229402679484, 0.024387321464018896, 0.02934408126748167, 0.06102156388806179, 0.01899748509458732, 0.08609002848970704, 0.058051102969329804, 0.03778683858399745, 0.004094812329640263, 0.04013561352621764, 0.013711775754927658, 0.024197693455789704, 0.02481035677192267, 0.055323387423413806, 0.0692418884136714, 0.013997251207911177, 0.03908426115231123, 0.10546825389610603, 0.022190124618646223, 0.0412037310161395, 0.03512825409416109, 0.06978837627684698, 0.0285109407195705, 0.01851183478720486, 0.08921573185943998, 0.02925988275819691, 0.014290308627096238, 0.06241907991352491, 0.02322281197848497, 0.05216181234573014, 0.06531074701342732, 0.04662339801143389, 0.031221150857163593, 0.08128104513161816, 0.0386936168797547, 0.06996139316470362, 0.0036488585737970425, 0.03479380895441864, 0.028580823200172745, 0.11656710208626464, 0.017756779307092074, 0.03469273586233612, 0.041808176902122796, 0.05644441262120381, 0.050566250502015464, 0.01514470428446657, 0.052340332258609124, 0.06187851438880898, 0.04897317856375594, 0.06604680907912552, 0.061638689367100596, 0.018313410473638214, 0.013787228981527733, 0.02706319428398274, 0.009012899281515274, 0.07392918181722052, 0.06796085246605799, 0.025590170298528392, 0.041640069321147166, 0.016562277778575663, 0.02658537920069648, 0.06339274797937833, 0.0023104265483198105, 0.03155845326546114, 0.048189359295065515, 0.03253673006838653, 0.06856881984276697, 0.02851809131243499, 0.02778255246084882, 0.04104589104827028, 0.08341743596247397, 0.021401375634013675, 0.05878094212675933, 0.0227442027971847, 0.01051978746545501, 0.07841580591048114, 0.05696644671843387, 0.03525753621943295, 0.011034705294150626, 0.055819138360675424, 0.050596044020494446, 0.05711120262276381, 0.060540641061379574, 0.057810365105979145, 0.03151612858346198, 0.014585473745682975, 0.012147488014306873, 0.030323426763061434, 0.04018623541924171, 0.027159812634636182, 0.03165967849781737, 0.037300345939002, 0.0659486823133193, 0.02829016106261406, 0.01978514683287358, 0.027055136415583547, 0.04109175948542543, 0.03502680621750187, 0.06670384726021439, 0.024880471173673868, 0.014082478519412689, 0.03337424001074396, 0.0075836258292838465, 0.05644574477628339, 0.018592424603411928, 0.03460676918621175, 0.08691050243214704, 0.013813148489134619, 0.0213964125214261, 0.07065064055495895, 0.06687457833322696, 0.010889850127568934, 0.021717242962040473, 0.048897939632297494, 0.06315157967037521, 0.10974334363709204, 0.0327834422205342, 0.04270839832315687, 0.05386872602684889, 0.05167597650142852, 0.04167075712757651, 0.09415698077646084, 0.010081070577143691, 0.050985437774215825, 0.1100411600782536, 0.01585349891684018, 0.01764302847732324, 0.04796927540155593, 0.046163314691511914, 0.03466179572569672, 0.03157850238494575, 0.07750292716082186, 0.0014630712053076422, 0.051056082811555825, 0.021752272332378197, 0.004939226100759697, 0.037660692032659426, 0.10549240338150412, 0.015108039406186435, 0.023186992220871616, 0.06599641725188121, 0.03826224725344218, 0.025495088193565607, 0.03492397052468732, 0.031954121877788566, 0.04357088895631023, 0.03165780828567222, 0.05551382993871812, 0.05568071297602728, 0.04906589507299941, 0.06471339976997115, 0.03459004117758013, 0.020370614147395827, 0.043685758573701605, 0.041820340702543035, 0.04407213178637903, 0.03730336648004595, 0.026221250009257346, 0.06586903502466157, 0.07372706531896256, 0.04016782644612249, 0.020208720197842922, 0.018299471084901597, 0.03475749195786193, 0.07118443769286387, 0.04076429795532022, 0.030870031514496077, 0.06013445250573568, 0.0449508420570055, 0.04754965768370312, 0.038400524208555, 0.041780954925343394, 0.027636380909825675, 0.07931458385428414, 0.0031765258745508618, 0.05012374866055325, 0.039724671514704823, 0.04004365029686596, 0.022631288738921285, 0.017930204376170877, 0.03481478946923744, 0.11391900785383768, 0.06155639261123724, 0.01361991457088152, 0.03453633937169798, 0.026705627533374354, 0.013746751319558825, 0.023205584875540808, 0.008707046308700228, 0.011596403473959072, 0.04333132368628867, 0.02958552046038676, 0.028744607770931907, 0.03778993333980907, 0.027353592959116213, 0.05093901643704157, 0.0746083063131664, 0.01532829306597705, 0.03402701455343049, 0.057190204242942855, 0.013222713423601817, 0.01757186579197878, 0.10566499724518508, 0.06639996005105786, 0.07134739105822518, 0.05557983284234069, 0.03478229453321546, 0.013700240924663376, 0.05684751384251285, 0.022781369552831165, 0.04974157229298726, 0.04745778351207264, 0.039064586817403324, 0.01378363976982655, 0.03407762531423941, 0.04126085783354938, 0.03623778342443984, 0.09205557478708215, 0.0451089083799161, 0.039641187322558835, 0.07872105124988593, 0.036598300212062895, 0.02543914881243836, 0.04668115565436892, 0.042672519193729386, 0.0669416091113817, 0.06810120743466541, 0.039407689109793864, 0.02980645225761691, 0.0448145763220964, 0.07550673544756137, 0.07119699483155273, 0.08793142304057255, 0.023917248836369254, 0.051700593539862894, 0.04432432098838035, 0.0765802817477379, 0.06882189962198026, 0.032061933670775034, 0.013350486206036294, 0.05009883105230983, 0.018071269951178692, 0.015096457264007768, 0.05083237723738421, 0.0917489490529988, 0.017681488425296266, 0.006042567774784402, 0.012038589902658714, 0.005126142023073044, 0.04001472509116866, 0.020761948617291637, 0.0844627435435541, 0.03095385338383494, 0.03665071439172607, 0.04474133747862652, 0.026283562583557796, 0.050513268579379655, 0.013997325422678841, 0.04240385060256813, 0.030491756988340057, 0.02186929232266266, 0.041271915833931416, 0.059493318549357355, 0.011413340689614415, 0.08285089526907541, 0.04233825959090609, 0.02178697886847658, 0.06556654305313714, 0.04608273971825838, 0.051592024756246246, 0.04640592276700772, 0.038491582017741166, 0.052266291895648465, 0.05795036384370178, 0.02742413224041229, 0.09124497883021832, 0.052309703823993914, 0.023968560926732607, 0.0015843729238440574, 0.05478692226461135, 0.03404079623578582, 0.00940675983656547, 0.03576260853151325, 0.03141645072901156, 0.01221251684910385, 0.004206809835523018, 0.02828608667186927, 0.03627253077866044, 0.03844389160803985, 0.06004926879541017, 0.0407004509906983, 0.039620655807084404, 0.032161429699044675, 0.027472772599139716, 0.11156196167576127, 0.006030940639902838, 0.06950192953809164, 0.055143847057479434, 0.05718125765270088, 0.05966064316453412, 0.048192929025390185, 0.019516858592396602, 0.07272108414326794, 0.06193241657456383, 0.04343419648648705, 0.019745261961361393, 0.013954568439658033, 0.07563972831121646, 0.028433621919248253, 0.0021362848428907455, 0.0366632566874614, 0.049077157163992524, 0.051533933146856725, 0.01985174159926828, 0.021429178341350053, 0.0213933585837367, 0.0482418810861418, 0.02999753487529233, 0.03645220844191499, 0.06056634163542185, 0.0706304689811077, 0.0720211498264689, 0.060159496279084124, 0.06755422975402325, 0.026725196112238336, 0.009578913977748016, 0.0833621014317032, 0.024491437361575663, 0.010074713154608617, 0.05282757818349637, 0.06314494487014599, 0.03359082467795815, 0.010155726922675967, 0.050013888539979234, 0.06995981239015236, 0.04487534337386023, 0.01567662100569578, 0.03343691067129839, 0.050062970476574264, 0.023317111117648892, 0.051786779149551876, 0.12696917750872672, 0.11892353228176944, 0.22336225665640086, 0.11492991689010523, 0.1606609157170169, 0.1681629303493537, 0.15174025611486286, 0.14897021959768608, 0.22550219495315105, 0.14899914851412177, 0.10827023244928569, 0.16602265066467226, 0.14366941497428343, 0.15062327933264896, 0.20314429857535288, 0.09949178318493068, 0.21030937816249207, 0.09884283441351727, 0.085114727698965, 0.13317792559973896, 0.12017958753858693, 0.14466980035649613, 0.1427030941704288, 0.09039875978487544, 0.20527372806100175, 0.22363591619068757, 0.16374085826100782, 0.08171918685548007, 0.2022902201861143, 0.07411195052554831, 0.151945385732688, 0.2127460271003656, 0.21865922230063006, 0.10626694580423646, 0.10965009278152138, 0.1720794811262749, 0.0777689425740391, 0.19868209114065394, 0.23440909513738006, 0.0948031761799939, 0.09447946620639414, 0.12168401735834777, 0.11593951974646188, 0.1332472570356913, 0.19423744291998446, 0.15663387399399653, 0.2436172479065135, 0.08331881195772439, 0.15934496914269403, 0.1252951446804218, 0.2337669295957312, 0.09392448075232096, 0.12310223930398934, 0.12749228772008792, 0.15864605898968875, 0.15348639601143077, 0.08656684352899902, 0.15343950712122023, 0.1316739188041538, 0.24515064375009388, 0.1642327240551822, 0.11704057003953494, 0.07544467705884017, 0.23547441844129935, 0.10175642455578782, 0.21183225035201758, 0.20155092235654593, 0.1842867862433195, 0.09286559929023497, 0.18165259243687615, 0.1449642251827754, 0.1884805440204218, 0.16118666797410697, 0.11991769846645184, 0.11384752418962307, 0.15236147824907675, 0.09651632761233486, 0.14782937534619123, 0.19380103040020913, 0.20554927265038714, 0.10167440981604159, 0.13793816469842568, 0.1382176871993579, 0.137933800870087, 0.11460570225608535, 0.12212427420308813, 0.17238383588846773, 0.09174375401926227, 0.15005451219622046, 0.1847598608583212, 0.09574369993060827, 0.09588468572474085, 0.11318769553327002, 0.14081912260735407, 0.19250902550993487, 0.1028117659734562, 0.1433569856453687, 0.09639467476517893, 0.16646476287860423, 0.15888218069449067, 0.17021802632370964, 0.05963482384686358, 0.1558215488330461, 0.18319336522836238, 0.10245081502944231, 0.09847277731751092, 0.22429480974096805, 0.11207103787455708, 0.10174825350986794, 0.12219930533319712, 0.12974375596968457, 0.10017582069849595, 0.12471800611820072, 0.1093194808345288, 0.2027768167317845, 0.16917845554417, 0.19419686228502542, 0.21956829383270815, 0.11351146487868391, 0.13985571102239192, 0.1466826829710044, 0.22372663632268086, 0.118401668878505, 0.17123221565270796, 0.1951086352346465, 0.13851902884198353, 0.16742118343245238, 0.1224737886514049, 0.15839386236621067, 0.25261231523472816, 0.14683972141938284, 0.14305257151136175, 0.12133718948462047, 0.20245298801455647, 0.07403855954180472, 0.2037310108426027, 0.07884505670517683, 0.21050659648608416, 0.13899416662752628, 0.11727450240869075, 0.11849458576762117, 0.06557103304658085, 0.2697604685090482, 0.11403289783629589, 0.11743617185857147, 0.16566481674090028, 0.129092714341823, 0.15180768765276298, 0.16244321304839104, 0.11457852480816655, 0.17225462797796354, 0.19975928880739957, 0.0891135900747031, 0.0641711347270757, 0.13457081804517657, 0.1231409794127103, 0.09897584954160266, 0.18021833267994225, 0.1482764896354638, 0.11850831549963914, 0.09997178945923224, 0.179210941423662, 0.08477425260934979, 0.16646241769194603, 0.1496588732698001, 0.17260214604903013, 0.15443502401467413, 0.15358818898675963, 0.14351654739584774, 0.11239271436352283, 0.18008430080953985, 0.14992203883593902, 0.10844634409295395, 0.09195749255013652, 0.15291865303879604, 0.1466667713248171], [0.044246840770938434, 0.06475835165474564, 0.008282533199235331, 0.01152370268755476, 0.05084225151222199, 0.016062257636804134, 0.04038055194541812, 0.05055250963778235, 0.03648016514489427, 0.022486629313789308, 0.06741353339748457, 0.020959573266736697, 0.019206767028663307, 0.029745484825980384, 0.032540106840315275, 0.09280161873903126, 0.020329827566456515, 0.08878455148078501, 0.024491908625350334, 0.017569390729477163, 0.07481494249077514, 0.04711872592451982, 0.05243928651907481, 0.021487889644049574, 0.054380700312322006, 0.07669487677048892, 0.058320428361184895, 0.045609405351569876, 0.06305462549789809, 0.028333966329228133, 0.0036590148647519527, 0.06273225139011629, 0.02853702535503544, 0.024745153532421682, 0.05735332459153142, 0.05303958008880727, 0.0628644204698503, 0.013191056186769856, 0.04410412206198089, 0.04369799658888951, 0.041289345172117464, 0.02419820739305578, 0.040273088961839676, 0.03148851697915234, 0.025793891691137105, 0.0370040212146705, 0.033057008986361325, 0.019236512307543308, 0.052140631451038644, 0.0507539210957475, 0.02409968543361174, 0.018689608841668814, 0.02829956963978475, 0.021349367780203465, 0.02402742251433665, 0.07778512139339, 0.0654315463907551, 0.08185747865354642, 0.04692318485467695, 0.056434363941662014, 0.02936856100859586, 0.05343537857697811, 0.07014078510110267, 0.007331520582738449, 0.01753232045302866, 0.06436531024519354, 0.04375884156615939, 0.030082353077887092, 0.023259000954567455, 0.08718892655451782, 0.032469450670760125, 0.059100585131091066, 0.004978660581400618, 0.034375285904388875, 0.047053491143742576, 0.04408850356412586, 0.03448896808549762, 0.06797635593102314, 0.01725619142234791, 0.019267738171038218, 0.03883913719619159, 0.01374731906253146, 0.02714693451707717, 0.0774254543648567, 0.03407502037589438, 0.028087679056625348, 0.012190934266982367, 0.019771673141804058, 0.03724720074387733, 0.044329308220767416, 0.04082276806002483, 0.06668358662864193, 0.028452732221921906, 0.010497550865693484, 0.023462210265279282, 0.02180834715545643, 0.029461027042998467, 0.026484376612643246, 0.03172146600263659, 0.041439496490056626, 0.04567544907331467, 0.034278131352039054, 0.04249700126820244, 0.025883290800265968, 0.06457917494117282, 0.05936970643233508, 0.03788575573707931, 0.027108751019113697, 0.07994217361556366, 0.05666287492203992, 0.00716232390004734, 0.029316555010154843, 0.008894202037481591, 0.034005399502348155, 0.0561273745552171, 0.09261097584385425, 0.004633357357306522, 0.012755721636494854, 0.04133928428927902, 0.033612595580052584, 0.060678498703055084, 0.03440391425101552, 0.0195572722441284, 0.03639535992988385, 0.014346039279189426, 0.047873775838525034, 0.04982231053872965, 0.021524818912439514, 0.02091417794872541, 0.010683025629987242, 0.049537529921508394, 0.028138688721810468, 0.05392967119405512, 0.011065443195548141, 0.030564222142857034, 0.06902544846525416, 0.06392849696567282, 0.03313128312584013, 0.006125563540990697, 0.015219035012705717, 0.01751334002619842, 0.04113546456210315, 0.03296261151263025, 0.0295645084042917, 0.01882817523437552, 0.09308409498771653, 0.025959449994843453, 0.09064440324436873, 0.03761966981983278, 0.031169545618467964, 0.06489314051577821, 0.03403268456168007, 0.061837481043767184, 0.04786183839314617, 0.06740416749380529, 0.015913464449113235, 0.004024389008918661, 0.04253327373589855, 0.03261841455241665, 0.03662564093247056, 0.01233853816302144, 0.04536438900686335, 0.11135444976389408, 0.022472478412964847, 0.04767108417581767, 0.006158840978969238, 0.017305258515989408, 0.023687884386163205, 0.07133336446713656, 0.025046038754226174, 0.051090752240270376, 0.025315050588687882, 0.05906797516217921, 0.04489870618272107, 0.040769711922621354, 0.012618611708603567, 0.00954309236476547, 0.04685314095695503, 0.008076221711235121, 0.015107330655155238, 0.03159433610562701, 0.023363667896774132, 0.04983691600500606, 0.02866260416340083, 0.04753300760057755, 0.054506839442183264, 0.04181923119176645, 0.05691676735295914, 0.040291920959134586, 0.08886095558409579, 0.0018392220295027073, 0.02759637172857765, 0.049662066012388095, 0.02567247262049932, 0.019424552119744476, 0.05057347530964762, 0.0693286677415017, 0.02635308883327525, 0.031582042429363355, 0.027286718031973578, 0.0162258863565512, 0.044196797753102146, 0.0681686686584726, 0.012216231298225466, 0.0664891216729302, 0.023935648532642517, 0.047055680479388684, 0.006950766355657834, 0.022841743266326375, 0.012693767148448387, 0.04265008035872597, 0.006543798544953461, 0.032871538860490546, 0.022139667853480205, 0.0494339075521566, 0.024110342674248386, 0.06664979664492421, 0.0684103935782332, 0.03514285584969912, 0.02249674293125281, 0.018572291992313694, 0.02052868418104481, 0.05825558320793789, 0.02977625797939254, 0.05116669250128325, 0.03282994519395288, 0.01379036548314616, 0.022646278266620357, 0.029772359848720953, 0.060975365195190534, 0.016777762211859226, 0.055080478778108954, 0.06696171389194205, 0.03945718293834943, 0.012305199034017278, 0.011415902954468038, 0.01675281677307794, 0.0412192010844592, 0.0550118375394959, 0.034106524544768035, 0.01937212309712777, 0.03383983377716504, 0.020580493510351516, 0.02832824622601038, 0.028333658337942325, 0.07261471211677417, 0.026499974701437168, 0.049509428499732167, 0.029250132793094963, 0.02104113529640017, 0.038118675074656494, 0.015664551829104312, 0.020567073624988552, 0.07879818265791982, 0.0346496282145381, 0.03751367257791571, 0.03425312097533606, 0.06638958482653834, 0.024877012765500695, 0.022300433738564607, 0.08444290593615733, 0.031148880516411737, 0.029138810641597956, 0.017008273280225694, 0.02622089934448013, 0.009069880452443613, 0.03858073250739835, 0.009902903184411116, 0.037487452500499785, 0.043444148686830886, 0.1272310665808618, 0.014048442699277075, 0.04283511632820591, 0.06829334946814924, 0.037062309493194334, 0.04348184236732777, 0.048703508073231205, 0.041540870151948184, 0.027899218075617682, 0.05651208906783722, 0.04070697075803764, 0.03832000118563883, 0.019937598808610346, 0.04066793007950764, 0.03557956522854511, 0.03954444837290794, 0.02217458219092805, 0.020989442855352536, 0.017846668233687524, 0.025119401907431893, 0.037454920457093976, 0.03962365037295967, 0.01657299253565725, 0.03156624581606593, 0.037020537711214274, 0.04721220313513186, 0.01975230308744358, 0.0437081565905828, 0.06815964414272457, 0.03908715552825015, 0.09391458792379126, 0.013254299228719901, 0.042730907662189566, 0.02818550154188415, 0.008010729961824836, 0.030470889651041944, 0.06093176401918754, 0.02355412896577036, 0.014226931998564396, 0.03712522877322044, 0.004666165850721882, 0.043759272011811845, 0.021118704571563285, 0.04341305269917939, 0.05375656524847727, 0.012492361256590812, 0.01953486123966286, 0.056219104008050635, 0.061418983968906105, 0.03281191471614875, 0.06133388931630179, 0.06262941940804012, 0.07934734967420809, 0.04626307789294515, 0.03143722715321928, 0.01787921883078525, 0.0634668959537521, 0.08384100190596655, 0.0958826596615836, 0.019709826265170705, 0.01799767487682402, 0.040680717283976264, 0.022604435980611015, 0.046727246735827066, 0.06875455714180134, 0.023509210477641318, 0.019582733475544956, 0.010193021698796656, 0.05114713319926523, 0.028990013743168674, 0.035300231975270435, 0.015896411750873085, 0.034315027223783545, 0.04646791065169964, 0.08813834865577519, 0.031396501799463294, 0.05246103886747733, 0.04564496164675802, 0.04732414126920048, 0.020006520207971334, 0.0603699322527973, 0.02868531573767541, 0.10552683161222376, 0.3322717157425359, 0.09925379868946038, 0.08209645762690343, 0.12577789690112695, 0.06297436222666875, 0.14425672095967457, 0.07830901828128844, 0.17402024182956666, 0.10825490709976293, 0.12885461852420121, 0.13090742868371308, 0.13873116433387622, 0.2037436273531057, 0.09482762252446264, 0.12612348538823426, 0.11677212780341506, 0.14404025132535025, 0.13167776312911883, 0.10134504467714578, 0.1736712988349609, 0.1137124681554269, 0.09721128211822361, 0.12761854188283905, 0.20038159447722137, 0.15365069266408682, 0.19137612223858014, 0.1458331465255469, 0.14105801994446665, 0.09382668053149246, 0.12126091896789148, 0.09888976041111164, 0.12914843478938565, 0.24961294024251401, 0.10442394821438938, 0.10085354995680973, 0.24980248475912958, 0.15074904367793351, 0.14959887805161998, 0.09988337740651332, 0.1960361417150125, 0.24470784876029938, 0.18175097153289244, 0.12273267944692634, 0.09224278153851628, 0.10935579412034713, 0.0907932038535364, 0.2281649169162847, 0.11141745810164139, 0.14448251196881756, 0.1346243714215234, 0.14087243849644437, 0.07473389996448532, 0.16443389060441405, 0.1498915217234753, 0.13511343189748004, 0.20636686705984175, 0.17793124134186655, 0.10888018878176808, 0.11178496963111684, 0.1491864220588468, 0.18360228859819472, 0.1849069248419255, 0.10101293359184638, 0.09550335540552624, 0.11624359991401434, 0.12745846062898636, 0.11235544370720163, 0.10648010545992292, 0.1981947969761677, 0.12664199428400025, 0.11741980750230141, 0.1743460149737075, 0.09163263966911472, 0.12247188133187592, 0.06994410854531452, 0.10659976935130544, 0.29397553007584065, 0.11729526770068333, 0.16860814474057406, 0.11383987264707685, 0.20364927069749683, 0.15889559872448444, 0.1856133752153255, 0.1610352550051175, 0.1188133901450783, 0.12516262679127976, 0.13407587975962088, 0.13088525331113487, 0.1623704528901726, 0.09357793489471078, 0.15145587996812537, 0.0849272686173208, 0.11739346868125722, 0.1934063117369078, 0.07873289592680521, 0.12761616701027378, 0.16020801267586648, 0.07934943510917947, 0.1678977016126737, 0.138348201289773, 0.1757591828936711, 0.09790269657969475, 0.15216552157653496, 0.15989306004485115, 0.12771047913702205, 0.22408527176594362, 0.15230983961373568, 0.17541929410072044, 0.12122223080950789, 0.12159409874584526, 0.12905501323984936, 0.11037711548851803, 0.17131014115875587, 0.10049566408270039, 0.1339547464158386, 0.12025216215988621, 0.12054190403432585, 0.08940987769165076, 0.14795102819334716, 0.1721018791431561, 0.11891575457411818, 0.15185237978585064, 0.18857277813367546, 0.11930262873647735, 0.12181197103927843, 0.08446246152743697, 0.16595127090113238, 0.0928980608296115, 0.08043783920584247, 0.1508969982387498, 0.12185190600575879, 0.21606170543236658, 0.09335750219179317, 0.0894582954060752, 0.1860773510998115, 0.12580997252371162, 0.1714031767915003, 0.08420546320849098, 0.11784700996940956, 0.06799365539336577, 0.10772851659567095, 0.18517136690206826, 0.13604573265183717, 0.12561297684442252, 0.15763587725814432, 0.2513085101963952, 0.1652337476843968, 0.10678182559786364, 0.1366323113325052, 0.16156909667188302, 0.08751735658734106, 0.28034527553245425, 0.11138538990053348, 0.12216275456012227, 0.19160500058205798, 0.08890095734386705, 0.10153496768907644, 0.16877969959750772, 0.11294280164293014, 0.1309870759723708, 0.2196559266303666, 0.17831059754826128, 0.0751337171823252, 0.0910424986795988, 0.12368767507723533, 0.1546135253738612, 0.17722507298458368, 0.19572448421968147, 0.14694163313833997, 0.2223992013023235, 0.10366356596932746, 0.1791996756219305, 0.1177856714639347, 0.21525040443520993, 0.22396315878722817], [0.010705995100579457, 0.029053862563159782, 0.012999825139559107, 0.0583289259520825, 0.007419424728141166, 0.029583004579762928, 0.037549410699284635, 0.02142573292076122, 0.014264276869653258, 0.04529701684077736, 0.03388526434719097, 0.0773551878228318, 0.024465250680805184, 0.026596518837322947, 0.01930872142111184, 0.02020415227889316, 0.024882640100258868, 0.027769180815084837, 0.04300027387216687, 0.051177494460716844, 0.020186463189020287, 0.004133204092795495, 0.015727326390333474, 0.0088162514839496, 0.035712543249246664, 0.04377609278890304, 0.01191442395793274, 0.019076779863098636, 0.021855243467143737, 0.031230468521243893, 0.019971177280240227, 0.027399350074119866, 0.01251785774002201, 0.018326895296922885, 0.049286097710137255, 0.017228273682121653, 0.019942819817515556, 0.011277594458078966, 0.03629008628195152, 0.01879509029095061, 0.015589719223498832, 0.02165047193557257, 0.007293625594684272, 0.022110234276624396, 0.06025047245202586, 0.02130997643689625, 0.05239155529125128, 0.07647079270100221, 0.013595238160633016, 0.002274965804645035, 0.06040148095053155, 0.04806290475244168, 0.08931854899856262, 0.06318404120975174, 0.06007439049426466, 0.06291597746894695, 0.013184282233851263, 0.06438918513595127, 0.012716914734482998, 0.035853499357472174, 0.022769285533286165, 0.036352189199533314, 0.06479277246398851, 0.019585358822951093, 0.01715686794341309, 0.029497874675143976, 0.020739628525916487, 0.03939262722269632, 0.03709928329044487, 0.05217701524088625, 0.0770329027727712, 0.020242402570147533, 0.030478984626824968, 0.01956581065314822, 0.04601127831847407, 0.02741107044130331, 0.040902945984271355, 0.06723889862769283, 0.05189538875129074, 0.039981339577934705, 0.07227192152640782, 0.03933779364160728, 0.09335985479992814, 0.03574736481823493, 0.0746190822974313, 0.06153591304610018, 0.041249525238526985, 0.05462862587592099, 0.01985665276151849, 0.05465212969284039, 0.012935648846905679, 0.0528641994606005, 0.03830030829703901, 0.01037227169945254, 0.01701190609310288, 0.01231948259373894, 0.0053597084206558065, 0.0645802881626878, 0.0604486555675976, 0.04585055139614269, 0.018284941688762046, 0.03767618065467104, 0.07869290158851072, 0.034091640773112886, 0.08820282644592226, 0.0419263156800298, 0.024830155416566413, 0.03330794024805073, 0.018985291608260013, 0.03609419640270062, 0.07205999383586459, 0.06624855450354517, 0.016423366287199315, 0.029999583202879876, 0.03754159217351116, 0.06548938938067295, 0.04309250056394376, 0.02583575067546917, 0.027111213094030973, 0.07395900131086819, 0.03473364675301127, 0.013662794008268975, 0.041102186660282314, 0.03512541537929792, 0.10219531584880315, 0.052574004876078106, 0.05475673911860213, 0.021485151119122747, 0.06851273574284278, 0.04398951219627634, 0.04095382762898225, 0.02581679065770004, 0.01923646777868271, 0.0677493552211672, 0.07879144395701587, 0.014102798522799276, 0.021583057095995173, 0.03087720808252925, 0.038865093811182305, 0.03977823973400518, 0.01980449462280376, 0.05645999401167501, 0.031095586891751736, 0.0735792591876816, 0.027694318523572292, 0.06646141730016097, 0.021861716850253288, 0.05109377649205271, 0.0428604384069331, 0.04436402588908095, 0.014464868254435714, 0.029959785533719696, 0.015112932942429325, 0.022917151036381256, 0.026973114254360553, 0.06588922886294313, 0.009277187346015126, 0.04318072707974352, 0.05775728299340699, 0.06248693447560072, 0.06423240643925965, 0.019867610571964178, 0.05693952531146351, 0.01708170137135312, 0.053644794097635895, 0.021063943349872716, 0.02694712980883196, 0.028421562019502744, 0.04826382268220186, 0.039973272432689555, 0.01812100312235998, 0.04206296362099238, 0.06127884793386329, 0.06462847581133246, 0.11232203964027576, 0.11568835470825434, 0.002475492483426933, 0.030859377984597813, 0.03142960158584174, 0.025944273074856028, 0.05735634142183699, 0.04567790929286275, 0.03224973414035048, 0.02261388537590392, 0.03518861667544115, 0.03691464808071032, 0.012896331718366127, 0.04947575354890432, 0.009826645655266475, 0.025750997410796117, 0.027410484144638758, 0.040023133624345064, 0.012616666354006156, 0.01944757725141244, 0.012266071153135272, 0.09358503724797629, 0.0183005768849398, 0.01892266362119699, 0.022470545118267182, 0.07417460263241082, 0.002004487764679652, 0.04939323785947636, 0.024463567860948388, 0.02409882639767602, 0.012004382460872876, 0.012426714583853027, 0.05567832326050848, 0.02678232478501741, 0.02467681471898686, 0.05656744215229992, 0.03124113689409569, 0.01587051821843488, 0.12692567281192169, 0.08193150046281517, 0.042009944590972736, 0.01872612065199064, 0.03103138555161422, 0.0425982858723728, 0.042579977089189924, 0.050059137283824384, 0.014461468290392077, 0.0369928667350905, 0.05504399108758662, 0.03520200501952786, 0.01851079021434998, 0.015691423141106497, 0.035617065950646065, 0.008840388909447938, 0.025110785572906025, 0.0508537362475181, 0.05635974099277519, 0.01966304684174247, 0.02400369234237587, 0.030954972171457484, 0.040214745022240095, 0.028153594757895917, 0.032523018890060484, 0.06350148003548384, 0.015816231971257366, 0.01975407310965238, 0.05014477741497103, 0.005218770402279915, 0.01928161633259151, 0.06375291966833174, 0.008287985201604897, 0.0570763253926998, 0.0843054527649656, 0.045308371700230055, 0.038220200876821764, 0.050954360340256244, 0.015664345883124042, 0.03553358175850008, 0.022254038376559038, 0.04034755977045279, 0.024378675443585962, 0.017767349345376715, 0.0648167660983745, 0.07945627468870953, 0.01399634764311486, 0.025894120590237435, 0.06474649955634959, 0.02659922025486594, 0.0624690116092097, 0.026596576353767887, 0.009642129189160187, 0.05656115616147872, 0.010107477119163377, 0.08654501696582884, 0.02942021077615209, 0.03454232479271013, 0.01745363053487381, 0.012374157540762099, 0.030505596187140327, 0.036240406916476786, 0.03564297061529942, 0.03339006630994845, 0.016760308753873687, 0.0417566978285322, 0.01988188763789367, 0.05824465879413765, 0.07020851349807344, 0.021049911192676518, 0.006572603151653311, 0.025394692311238032, 0.044411623530322686, 0.03781231280299835, 0.02725261449086247, 0.026359026014688425, 0.03241922582674306, 0.07094586690072902, 0.0343403121951269, 0.0363712252874393, 0.060526733213919215, 0.004537934328254778, 0.008875490639184136, 0.015010623246780597, 0.022461038206529338, 0.009868256020126864, 0.044906628609169275, 0.053996089700376615, 0.11919092066818848, 0.036006036680191755, 0.06796168367145583, 0.05880211559997406, 0.04419083830725867, 0.04889876341621857, 0.006649980859947391, 0.018246774889121298, 0.023990760419110302, 0.08700073274667375, 0.05998083906888496, 0.011373966044629924, 0.033692595388856716, 0.06394535113940947, 0.04527387296548113, 0.03956093147280626, 0.04234319487295579, 0.04543186878436245, 0.0445560751541052, 0.043074043351225555, 0.0336852073087357, 0.026616187606123276, 0.021309570111043286, 0.02967352804262191, 0.05457460123579949, 0.09703708521556109, 0.02169799536204664, 0.025531128740112763, 0.04952834584400989, 0.004031855014545727, 0.05882669924176298, 0.0243020245761727, 0.027552046958589926, 0.028763519549102057, 0.03777373225602787, 0.0236103132556309, 0.07337875314988196, 0.04252899525454268, 0.034498627137509175, 0.023237497225636616, 0.01275054608413484, 0.08708576802746393, 0.016392199795518536, 0.030461748247034848, 0.045739459310425445, 0.047980774979805574, 0.030284178283181973, 0.05525807471713051, 0.043591290595941246, 0.09851956230704673, 0.05519614620425273, 0.0314718372101197, 0.0759851535258349, 0.10979397295159288, 0.0950731175544206, 0.1622008127742447, 0.14486497035250068, 0.0740228705399204, 0.11986190380412154, 0.14770657959161326, 0.17109753069235012, 0.19509300560457632, 0.07453497470123693, 0.10723809056798927, 0.11208535390323959, 0.10789446081616916, 0.1237345120171085, 0.12828451552195475, 0.13111203879816458, 0.07204646448371932, 0.18177007441408932, 0.1739915504003875, 0.08896763189113699, 0.12071311008185148, 0.07667866826523095, 0.22303157049464062, 0.06539216061355546, 0.1265437636175193, 0.06437954463763162, 0.06393773670424707, 0.1369160195463337, 0.07305317296413705, 0.12787303916411474, 0.09269054149626754, 0.13619662611745298, 0.10819065937539563, 0.1857534926966764, 0.1988169690594077, 0.19686868297867477, 0.16615614818874747, 0.13004290085518733, 0.04938802056130953, 0.19694356567924842, 0.22561369522009045, 0.15451674931682646, 0.18832824047422037, 0.19774407584918663, 0.10411950439447537, 0.19589028001064435, 0.11337486517732032, 0.10736112380982377, 0.08773988956818357, 0.2081938268383965, 0.14622914168285206, 0.1277245205710642, 0.11726115117198788, 0.16403057787101716, 0.1724667931557633, 0.09639332405640744, 0.12393333337968215, 0.08576959880883805, 0.17598803155124187, 0.15188677090918645, 0.16008937294827774, 0.15262128930771723, 0.15607646171702072, 0.11567903333343565, 0.10698774189222604, 0.12584969226736575, 0.13316385447978973, 0.09038353091455065, 0.09857398399617523, 0.22130724973976612, 0.11444565068813972, 0.09238075421308167, 0.10736781798186712, 0.10594345847493969, 0.07841208775062114, 0.1894627170986496, 0.1461072513484396, 0.16624790732748806, 0.11798136096331291, 0.2003894018707797, 0.2766469755442813, 0.18638290814124048, 0.13565989007474855, 0.17492398474132642, 0.13078252522973344, 0.16815583541756496, 0.13610608410090208, 0.14306514349300414, 0.12043691240251064, 0.08993445735541172, 0.13398707436863333, 0.08433253373368643, 0.17936613934580237, 0.13849559181835502, 0.13625763065647334, 0.10078671213705093, 0.1958771439967677, 0.1892157451948151, 0.136012751609087, 0.05597517862042878, 0.14638488879427314, 0.16024482320062816, 0.12196460855193436, 0.18803245009621605, 0.111079721536953, 0.10267266523442231, 0.12471570546040311, 0.09878217126242816, 0.17010210285661742, 0.15244589012581855, 0.12841986841522157, 0.13594549818662927, 0.10083524117362686, 0.12281767762033269, 0.16930512530962005, 0.14068414078792557, 0.09189435062580742, 0.09397066460223868, 0.2269505406729877, 0.17130490159615874, 0.1314187832758762, 0.11267905720160343, 0.19681884034071118, 0.13268856826471165, 0.13934523216448724, 0.17117835057433695, 0.12710580689599738, 0.16209600667934865, 0.1099257412715815, 0.13136738212779164, 0.09569287023623474, 0.13657595263794065, 0.15822019980987534, 0.13246458809589967, 0.08602679750765674, 0.1772263049497269, 0.13662995130289346, 0.0928149996616412, 0.11901066041900776, 0.13579402584582567, 0.16412236669566482, 0.11819941137218848, 0.1829495103447698, 0.09636770511860959, 0.06834257612354122, 0.1402729464462027, 0.12827140919398516, 0.12362118606688455, 0.17790220852475613, 0.08651852229377255, 0.08770681204623543, 0.13294892851263285, 0.09102509531658143, 0.1595326731330715, 0.11471227466245182, 0.10541936862864532, 0.1295612470130436, 0.16302183590596542, 0.17072820832254365, 0.17866788228275254, 0.1936030254000798, 0.15506898140301928, 0.08206009239074774, 0.22789740236476064, 0.1749565204954706, 0.11807936898549087, 0.06884044589241967, 0.17964545404538512, 0.14545040612574667, 0.17527908756164834, 0.17004840105073527, 0.16651847952743992, 0.14601415634388104, 0.18356975284405053, 0.20359795860713348], [0.06386566674336791, 0.059139362347195856, 0.04495494613365736, 0.02380403791903518, 0.057770556304603815, 0.02915750719694188, 0.004503381787799299, 0.1312294020317495, 0.023787783029547427, 0.012153810184827307, 0.05621204989438411, 0.018868677943828516, 0.020274953167245258, 0.022482291460619308, 0.06254799096495844, 0.015708037972217426, 0.021205289085628465, 0.04585095957736485, 0.038009070995030925, 0.05520365302800201, 0.019690556400746573, 0.0033269951563852374, 0.02615094079374103, 0.06477142829680815, 0.030028569635760505, 0.006039276813680772, 0.01945719362993259, 0.05337668953870889, 0.016548345811315812, 0.08158610493410379, 0.01802730326744495, 0.011799744515883503, 0.020310090148996096, 0.03678346605738625, 0.02850633940397529, 0.07405893149552867, 0.03611025647842325, 0.0535374535684241, 0.034166553159593605, 0.00888495766048436, 0.025281589005317073, 0.07248784939292818, 0.07077299102093093, 0.05780193430837244, 0.018597482339828275, 0.014707233276567422, 0.014352742728078738, 0.0562382773932768, 0.040592731966171414, 0.05779743689345196, 0.06376235978677869, 0.013456444485200336, 0.08353486598934978, 0.0237569152523065, 0.049398295595892705, 0.021008089315728284, 0.01567891609738581, 0.03152318640786689, 0.0159755302593112, 0.026592498252284713, 0.020133542493567802, 0.01984886206628289, 0.023380670500046108, 0.04058281316247303, 0.0403813534649089, 0.008827625824778806, 0.0201252211627434, 0.03594181493099313, 0.05557731696171686, 0.05248387475148775, 0.023190400534076616, 0.003370386211827281, 0.018593033164506778, 0.04171893364400603, 0.03134905258775689, 0.03432241530390456, 0.017149932573374826, 0.025412553950445727, 0.021972157701384276, 0.04462150660401676, 0.06309309843345545, 0.025359251048939768, 0.03481084495433606, 0.018989458767464384, 0.01611341387615539, 0.04449778687558137, 0.030046919237065595, 0.0570390324719483, 0.02499748003174318, 0.026051277782244142, 0.030864958935126197, 0.005215870460233418, 0.05888086117920466, 0.009722302474983735, 0.07211672360426746, 0.035778438541456126, 0.004800226943189045, 0.02927837151219137, 0.01684348866547225, 0.018047395060420968, 0.01014546580336173, 0.03695820472785272, 0.027834591855935287, 0.03988719814515207, 0.07834487143554725, 0.13748205557931215, 0.018826447885658126, 0.04339802049798891, 0.03176229525706731, 0.02214118925621733, 0.06465910424594767, 0.1434426591731608, 0.01566758906847099, 0.034885634886450134, 0.046133112991810776, 0.013260113028081832, 0.019021476873604115, 0.028195613303978462, 0.013518989908334333, 0.06639587081735954, 0.024586089020885993, 0.0267990583597566, 0.045629740197909996, 0.03800247701292392, 0.07469332675100304, 0.03121575544355437, 0.041017188486875966, 0.0436760438606143, 0.013227469662524527, 0.10988082649419084, 0.06406528220395558, 0.046930112803238444, 0.07350926724029705, 0.03886596954544075, 0.023796063542249613, 0.04888035815383773, 0.035044001779169776, 0.07000270852586254, 0.008582608552387683, 0.031713669741293415, 0.03966442767705303, 0.021541055248235352, 0.06526722747366875, 0.07791547221131623, 0.03608365419495385, 0.07275662559550256, 0.01951943941094214, 0.08641019099741243, 0.05818524987262208, 0.05658101974404417, 0.07645942299859598, 0.013702899668714963, 0.0345256450236775, 0.052700708038173616, 0.030744207797397394, 0.02577437877334887, 0.010587695833237376, 0.02720072166994214, 0.056719823624007404, 0.02778799240331864, 0.041388473837287165, 0.04385768450447358, 0.0562075153720798, 0.05023782046919223, 0.04655295706470497, 0.03423536509217229, 0.024113029248837847, 0.03367671342857648, 0.08694638527231291, 0.02147812112525571, 0.14314446423668414, 0.105315683176741, 0.04138636984862387, 0.037491445255000144, 0.06278311077039689, 0.032680869990144856, 0.039001849363557994, 0.07932053587865084, 0.03901048796251416, 0.034362595179118216, 0.0049319669687974965, 0.04225907614454627, 0.01577553259267006, 0.055023515233187936, 0.07521950203226879, 0.08385228255065158, 0.008031905290408758, 0.0642628938658163, 0.05532126117032021, 0.027434190196800046, 0.009267984714824706, 0.007331132810577401, 0.008258474626927637, 0.0150554396896041, 0.023922291729832068, 0.08568641147576272, 0.025941527128452435, 0.011232042361370986, 0.00632219185717986, 0.05824470332299825, 0.037788404515595175, 0.01848919000622118, 0.0211705565743614, 0.06640771549427882, 0.05550501693505794, 0.0403346983512165, 0.009322225505457027, 0.06218801223440096, 0.05650476407026872, 0.03374276828253642, 0.00862930077346391, 0.026347587663622107, 0.04460412179469131, 0.02569904892880004, 0.08589903678512201, 0.031609112265869044, 0.09755403560120612, 0.0102192825943348, 0.028742559443344362, 0.04770605046360288, 0.017073344788514078, 0.04026066169899423, 0.0224394676843076, 0.15443662705365568, 0.019557867817638908, 0.04314799094572663, 0.04845815034059342, 0.026520845749473665, 0.06205103774846066, 0.035353251005290076, 0.05274257258861326, 0.05355104600312188, 0.046581711576436646, 0.03748875125893392, 0.042066425739903934, 0.01796565677068429, 0.004151765670030727, 0.03052126292459434, 0.040085091823129915, 0.017846317568910308, 0.010406305664218962, 0.016139168255904224, 0.033481702994322404, 0.050051322468789294, 0.02396445685008075, 0.03759700462978799, 0.01612005609786138, 0.0018656830729923968, 0.006647667678407743, 0.08459212214802392, 0.09835001124884002, 0.02632951636769576, 0.040260865789605305, 0.014085133552725893, 0.017883716245705727, 0.024682933726580814, 0.016093474223453086, 0.047487183692283, 0.04529257879767101, 0.016181756400328595, 0.028690553444903344, 0.04698011129221413, 0.018699752145039383, 0.03445156755333301, 0.04259672365151346, 0.06685439191642217, 0.014384164333023364, 0.06268336612265557, 0.027090019211755134, 0.07443734517437406, 0.07701662005274557, 0.011857127374241827, 0.004835910795009113, 0.024728525713726413, 0.014492664467979921, 0.020088076671527233, 0.03753166594833601, 0.01749707957060309, 0.04321954140323214, 0.03711713194206823, 0.027688149421010166, 0.10762075675302185, 0.06977049051783979, 0.022518378391396254, 0.03419894419494085, 0.011472081678221002, 0.09628965344745666, 0.04523246854660101, 0.09725248615723103, 0.024933371460065246, 0.06480745214503258, 0.05881455399503466, 0.06705959574901499, 0.047992723557399586, 0.01965258070413256, 0.06602873036172241, 0.031012557265057694, 0.022505570777866524, 0.057473047854728065, 0.04707562198746018, 0.02297093076776946, 0.027140774691361003, 0.04616973426891491, 0.05729414944653399, 0.049929921951843426, 0.024662023715791292, 0.028068678220734, 0.0541962766146753, 0.06106342843850143, 0.03930389975721482, 0.07284923078259453, 0.06410987043636851, 0.04114709772693459, 0.03687299875309691, 0.0421128211019095, 0.04726665822090581, 0.05622126736852806, 0.014721363768330775, 0.05964726966340095, 0.013051517580606742, 0.06001013534842059, 0.045215773934614845, 0.024194324105337728, 0.03271101231803186, 0.02183880304073682, 0.02478221638739342, 0.03288294195954222, 0.05116409869515337, 0.0571272738307016, 0.06776891823392361, 0.09528616588795558, 0.034317424360779114, 0.04714028902526479, 0.03400615278223995, 0.05396220694819931, 0.03583863413950894, 0.025395347256562673, 0.11232976539758965, 0.024064464960247278, 0.017103110476455186, 0.061863842129241675, 0.03323309094412252, 0.04101129583432339, 0.0424729519727407, 0.022183725450304337, 0.018047790254058782, 0.05422045578598045, 0.06433057031244971, 0.06856825581053272, 0.03338451875606552, 0.04671784001402557, 0.04938034304359462, 0.1441028737463057, 0.11380941490642726, 0.10011953621869907, 0.13488110998878255, 0.14360244356794283, 0.12064475085935555, 0.098891274392372, 0.23826799588277936, 0.11320768157020211, 0.226106540649198, 0.1392356466385536, 0.13791263481834903, 0.14135345409158617, 0.0839059027202893, 0.22634077729890123, 0.0839867968170438, 0.04448898500413634, 0.14790382760111243, 0.19201159360818565, 0.25881607609335333, 0.15292353637050837, 0.1095387854729779, 0.08092603136901744, 0.13672499073436484, 0.1206725591327995, 0.15370712557341903, 0.1661098381737247, 0.10702213301556185, 0.12448189925635234, 0.1433225054643117, 0.06432416557800025, 0.09153768929536454, 0.13095022091874853, 0.19905193301383406, 0.1363880408462137, 0.18331170809688047, 0.18602338212076575, 0.14935816987417638, 0.21336239558877423, 0.10168722670641728, 0.1686528665595688, 0.1357574824942276, 0.1569886354263872, 0.13034045754466206, 0.08174178525223397, 0.1787425423390232, 0.049023507308447734, 0.22591922257561237, 0.12862342467997223, 0.14392938930541277, 0.24397854023845866, 0.11980331124505028, 0.19319297396577895, 0.07593367074150592, 0.14310842554550618, 0.15431889274623245, 0.09771886660018936, 0.19083350838627666, 0.25421143567655236, 0.11149197714985348, 0.08038315034355037, 0.10590151970973238, 0.12011795959551819, 0.12944833666551858, 0.12720513594103977, 0.18184443761128932, 0.08591199468355626, 0.2030232988181524, 0.12441983344615437, 0.10500923555810004, 0.1701473887078464, 0.11952104279771447, 0.09695426895632409, 0.15096034796442837, 0.2344483695924282, 0.13275292731123045, 0.1456929399864748, 0.10707887020544149, 0.111800027807476, 0.12222659410326742, 0.11197403917321935, 0.12508229672675952, 0.17932278307853267, 0.08210805739508942, 0.10591291909804568, 0.16716193640604615, 0.1973195228492841, 0.16777938843006268, 0.1359648979268968, 0.12847834965214133, 0.12019101661280729, 0.1740792574128136, 0.09615420407499187, 0.11637245901511051, 0.3434306778945029, 0.11584395339014009, 0.06628501621889882, 0.05981137335766107, 0.11388042359612882, 0.19047521433094516, 0.09436555395950563, 0.12517338793259114, 0.1463599526323378, 0.1974523375974968, 0.13447586767142639, 0.25253753643482924, 0.19784877804340795, 0.19081706239376217, 0.17934332572622225, 0.09819003389566205, 0.14519852120429277, 0.2321049789316021, 0.13189458899432793, 0.1281779579585418, 0.09699494607048109, 0.2950543159386143, 0.18261968507431448, 0.21329586947103962, 0.08424775820458308, 0.1169243422918953, 0.11959850075072609, 0.13582446874352172, 0.14430084906052798, 0.17324181797448546, 0.13728746445849538, 0.1061474006564822, 0.12373768840916455, 0.11908188433153555, 0.106684188649524, 0.16282403870718554, 0.1624124584486708, 0.11973501881584525, 0.2812223753426224, 0.1115944009507075, 0.11583522573346272, 0.1626341528026387, 0.11763929767766967, 0.10691547897295095, 0.0950088030367624, 0.06215222958417144, 0.14760211488464847, 0.11285467160632834, 0.13471593760186806, 0.12745472020469606, 0.13957954302895814, 0.20672639308031648, 0.07351570908213034, 0.2820087847067043, 0.10997287507052533, 0.15480274334549904, 0.12945951340952888, 0.1144216644752305, 0.11341675941366702, 0.11037416916224174, 0.1058412721613422, 0.08368845345103182, 0.151016068411991, 0.11811348551418632, 0.17354161594994366, 0.1884532775147818, 0.11883805171237327, 0.1857647584984079, 0.13238327839644626, 0.12810540560167283, 0.19529682904249057, 0.08190620806999505, 0.09686857316410169, 0.09614253009203821, 0.19543391856132075, 0.09645233963965438, 0.22848914639325812, 0.19610710587585345, 0.14448815229116008, 0.13430558930849656, 0.17478869121987373, 0.1576304150512442], [0.03543900988006499, 0.029054435872239992, 0.0444817787501961, 0.03033319899259368, 0.01670971654675668, 0.0314657070703106, 0.03798430181632284, 0.015566710790153593, 0.010101493553520413, 0.02467807451466797, 0.07424645737046376, 0.0393016473390162, 0.03977115222369321, 0.08890696131857112, 0.05433421960333362, 0.02573822876001941, 0.013135589924786473, 0.007553750674560433, 0.0688642317254562, 0.06238739762920886, 0.08049882148043253, 0.06579007051186636, 0.03368740035512019, 0.02777437213808298, 0.05150134915311355, 0.03034292112715775, 0.06471864675404504, 0.025999720783147495, 0.0572288367402507, 0.021745529920735862, 0.04511022569204215, 0.03328469247207977, 0.04643745662178844, 0.08309250144520774, 0.06447109597502276, 0.05650724284350872, 0.048472800335730426, 0.01790542035450926, 0.021767772086604964, 0.04901939209958073, 0.012975082863704301, 0.051390624430496246, 0.02956581643957179, 0.047717145571368746, 0.024627771745144855, 0.016800883822725154, 0.020627358280762564, 0.026970950893883128, 0.08968465786892921, 0.017367558102705516, 0.06502231131889857, 0.02892833941587014, 0.021086289416416548, 0.020215366130287293, 0.07234885997604579, 0.0228210447676247, 0.06477348404587246, 0.05876520859601442, 0.04219221977109555, 0.06936273974133655, 0.027848119352711365, 0.011176130810781615, 0.00684249999721942, 0.020040881645400077, 0.03294347152404953, 0.06985384112340398, 0.01663808445300674, 0.03595403439248912, 0.038710010921931826, 0.03083120049268473, 0.03492073105007876, 0.07949880717205815, 0.06126092135673389, 0.013947100578661775, 0.07447771058650687, 0.05958452107734047, 0.06090932889492251, 0.01675786894338671, 0.03539872239343822, 0.029958371742395684, 0.06913206540048122, 0.03719810767506715, 0.044261130824452266, 0.010121952709596371, 0.045940340132801794, 0.023554457366117276, 0.05677609326085076, 0.026979958711308427, 0.03969167191826273, 0.03162919107126072, 0.0036918463183610584, 0.07131170117645524, 0.06997247342951596, 0.05375075423216913, 0.04286459072318394, 0.04918907303363085, 0.052476382770692, 0.06090043796575628, 0.045471625635400414, 0.015063602386362618, 0.015128536597330822, 0.025867132389976177, 0.032046270644059405, 0.05444309637823608, 0.026661295341909863, 0.09303619677666575, 0.023310264805331826, 0.021662171893694904, 0.04179780538834166, 0.013562027052103076, 0.05223920350545086, 0.03676927248307038, 0.01668098986556288, 0.04518188005022239, 0.038126274666865356, 0.008558147364965407, 0.04562861955491826, 0.029600153757201042, 0.021169176179682836, 0.07682755051064305, 0.02635589786223136, 0.004703235199485789, 0.02991274079249706, 0.004562722060654778, 0.06709505556500517, 0.04907930197077803, 0.02229067264124751, 0.04127847270865459, 0.10649147516232915, 0.023041677850415, 0.030751120903005358, 0.03830397079582326, 0.009836017125053331, 0.12129056034609675, 0.01693487116426695, 0.04918048267427366, 0.049963259225478396, 0.06311770805041306, 0.015891467191977426, 0.034922783088404685, 0.065401645260863, 0.02939550282462733, 0.06469451211160049, 0.05966301803709939, 0.04518219175224658, 0.08025637667742558, 0.057028052397072315, 0.027313214559399057, 0.009933539968187688, 0.03338117909152061, 0.026988588033418637, 0.024494856806995813, 0.014547238297382137, 0.030061459765420295, 0.07554795432952233, 0.031956968014128506, 0.03609810381021816, 0.07303728358238004, 0.05204346576647367, 0.04136570845730603, 0.06438596421503462, 0.0012822944677282067, 0.06703632199787535, 0.042901943015749566, 0.0055363242609018926, 0.07184569869423285, 0.05615576170384884, 0.03745066424016841, 0.024651080748299137, 0.021869988086109515, 0.034322485807933845, 0.02428374733426608, 0.015847559880057815, 0.04221000534016639, 0.05083239208033774, 0.022112583174020983, 0.05496085941558704, 0.005532155710170628, 0.04417975062096957, 0.07479209176381119, 0.04064693843247369, 0.04284247843315825, 0.025380431943631265, 0.061527934958576225, 0.026561960730759893, 0.033078868946176954, 0.04089245201612357, 0.0563560636510374, 0.03918137117580045, 0.03952712293539662, 0.0329066943959333, 0.049917494688997976, 0.07030246197246015, 0.033393502453691326, 0.0663499318761751, 0.07397374778520316, 0.03680829831864685, 0.03933979372959584, 0.017529275792185217, 0.053462893702089787, 0.03501817504002247, 0.014212151199899381, 0.04354444994532969, 0.02447389855660731, 0.07609401174704544, 0.00940022893701098, 0.030762728092668112, 0.017576188802195247, 0.02329499326151563, 0.028300771919020917, 0.0178137632610742, 0.04413039408973418, 0.02381869162491057, 0.0763570585695561, 0.062200610191212036, 0.025018187807290815, 0.03766315225220751, 0.02231632126495242, 0.04283756541553885, 0.05089673628390301, 0.031817663184483536, 0.07094169603078626, 0.06478811177657917, 0.0923698372207582, 0.13795017264783382, 0.012712358875432983, 0.051542070796131156, 0.03233799034205731, 0.04659858801460359, 0.0052126936043350725, 0.05913116161536891, 0.026868285895034205, 0.013755546697211685, 0.057921394109143876, 0.026148903598368634, 0.011577073310036212, 0.0421626192110125, 0.05220220744377002, 0.0528579802630702, 0.022465478105004877, 0.06465445840149187, 0.004294428254070226, 0.018621605850057676, 0.03328140846861061, 0.09421883878530934, 0.06363870314089581, 0.03721616041730158, 0.04006649360235315, 0.06564656141563319, 0.010042600424640113, 0.017850529256975278, 0.03664557130832691, 0.01935900749231223, 0.026556212797004264, 0.03807320368650835, 0.040315584337804466, 0.0677696974889841, 0.014796225132158725, 0.04168942214164417, 0.03329429586301558, 0.0901884499762673, 0.012153569914516993, 0.05082920084532816, 0.1139580670860596, 0.014310725109680789, 0.044508110149763525, 0.003979355951742036, 0.021844113107363228, 0.05491501324286219, 0.10334759659599513, 0.043970390761387534, 0.034464165510144085, 0.044721707672579214, 0.02911677071097074, 0.04821956841624342, 0.04394601492094807, 0.04899087878584396, 0.023689802837907337, 0.03971884565544315, 0.027420536534918938, 0.05138854270626325, 0.05118932058394421, 0.009423412702744827, 0.02041946045210352, 0.03028859220648883, 0.03207505484169815, 0.03760098996281158, 0.019922954379580915, 0.02834455492120469, 0.025256630578951444, 0.014683949320897227, 0.021139783420949243, 0.02695823790418217, 0.07285979154403321, 0.01795940232113935, 0.01744295845128363, 0.03479562721622642, 0.03389724632143043, 0.024707014563318808, 0.005679826863342896, 0.03388726072444115, 0.033244490332435817, 0.05347071222786326, 0.039019890973577276, 0.04161418692092411, 0.06748102430719882, 0.02953475199319655, 0.04903370441752486, 0.034367367188679054, 0.030265051282185595, 0.01271684144739993, 0.04585672606481239, 0.12813596724299714, 0.10264237076626159, 0.013759916091657942, 0.03363950214406941, 0.06535557273309678, 0.0371911908587208, 0.06880412518512458, 0.0930551957571879, 0.013694774079340277, 0.06559792105690576, 0.043406403055996634, 0.04070828064868692, 0.01803062994440552, 0.0244169554207474, 0.0465469308255706, 0.0498378140036948, 0.05010375891288277, 0.07232402771478519, 0.06206823331012856, 0.048408352231490426, 0.028730740741593763, 0.050138780861743726, 0.02407693118584575, 0.02700263874430675, 0.05951043247478083, 0.08112872674246319, 0.014823969395365566, 0.0978597262292169, 0.02316856654942967, 0.05066903795523103, 0.06073199270758778, 0.06524890384753235, 0.04712137539172545, 0.011169480239914265, 0.039501125502283685, 0.01398643904394703, 0.06701938618789427, 0.03307425278762821, 0.10550127946771681, 0.012796268874808447, 0.09196890678140335, 0.11978016365901567, 0.17393376678228378, 0.15601645165588707, 0.1028677610156592, 0.10139342528418638, 0.12665996910072863, 0.1533194721559994, 0.08130446731229313, 0.16057228844147176, 0.14337653381517157, 0.13171547907404602, 0.11750689111067913, 0.2630462287925184, 0.13671224063728005, 0.14818302355706692, 0.07695354492170736, 0.0740676888381131, 0.19328807276906446, 0.21118285629199818, 0.11823586566606537, 0.17317588557489216, 0.13136720401234925, 0.12334211627603509, 0.15575472585624084, 0.12481166515499353, 0.2142744357115589, 0.08147847867803648, 0.15824347356101498, 0.08826239121844992, 0.13941526121925563, 0.20547753665596247, 0.18006919068284333, 0.15115419693756849, 0.15354704431956634, 0.1371913414914161, 0.15127194608794525, 0.1386296088458039, 0.1132889318978414, 0.12279282309464179, 0.12403037660988048, 0.11902145866770297, 0.14515704999212176, 0.2109093451872468, 0.0833819761464838, 0.18103619426256046, 0.15374231821624562, 0.11271955620031804, 0.2917470090324059, 0.12321943184360862, 0.12405234418110922, 0.15563596738502383, 0.11966866339207627, 0.10146717992029153, 0.11818120648968033, 0.1402443737606518, 0.10269328951835632, 0.183529409696348, 0.09548382950015366, 0.18062597955577075, 0.08659898594487458, 0.13186292897444218, 0.12714050972135738, 0.10820888652233407, 0.16233992093475536, 0.23797743022441864, 0.08960335559095256, 0.09487632967648096, 0.20082225208170712, 0.12432080126018263, 0.14425933331949636, 0.11582603794522583, 0.20789273752598092, 0.10480288139660843, 0.19009483396075666, 0.09683855329058133, 0.23625808185897768, 0.1339184702374041, 0.13008392677875236, 0.12205644190544263, 0.32467129232827574, 0.15805980685399845, 0.14111786673311144, 0.13343322440050542, 0.15000740066170692, 0.1290089258691296, 0.11824006622191519, 0.20276133553124964, 0.14645183051470667, 0.15211729682050645, 0.10096115394844674, 0.12386174581479281, 0.09499339605099522, 0.16377058869693428, 0.1504549157107249, 0.12054874663590454, 0.08945378314820118, 0.1169394598400686, 0.1346027452382259, 0.16855064313858747, 0.11309255220112391, 0.09787774557480589, 0.12881457223556936, 0.1369808238814585, 0.13039549521636218, 0.237376602308359, 0.1023322792025283, 0.14685297617688775, 0.09341631739516743, 0.1466777254245244, 0.13935737370047718, 0.071538961637998, 0.09717353648738936, 0.15223008842440322, 0.09950871899491176, 0.12515930196968839, 0.1004952187940944, 0.12667475268244743, 0.09442647686228156, 0.15703130891779438, 0.14674879348604009, 0.12881564092822373, 0.08128848887281492, 0.07477200924768113, 0.0898140438948758, 0.16937368491198868, 0.18501670332625508, 0.1448192392126657, 0.22889940562890843, 0.12691281881416216, 0.08998740959214047, 0.24815846438286826, 0.09596914955182001, 0.19204494572477415, 0.06741136632626876, 0.09678522998001426, 0.20200165832648054, 0.16038727102568373, 0.0781121858744882, 0.11338495096424595, 0.16662972746416926, 0.12433224517735653, 0.14966289571020752, 0.19316515827085823, 0.07281339989276603, 0.21017499006120488, 0.1303329470101744, 0.15707450191257522, 0.070687280385755, 0.11618972741416655, 0.11331662884913385, 0.18530159897636622, 0.09476280334638432, 0.15801366011146456, 0.1532873371616006, 0.14414670498808846, 0.13462834933307022, 0.14539058902300894, 0.1253462044405751, 0.11747517171897925, 0.11729819918400608, 0.19482338335365057, 0.12406340218149126, 0.13734492153162137, 0.08806146957795136, 0.24551500857342035, 0.19227057346142828, 0.20200291997753084, 0.11435478954808787, 0.13004705688217655, 0.15973582863807678, 0.1087779134104494, 0.1437409728532657, 0.14295796252554283, 0.1633944534114562, 0.14322148432256654], [0.045940789132146165, 0.041343592456541955, 0.00549413038243074, 0.0939157308312133, 0.09240302606485784, 0.016395982893300243, 0.055331799667328596, 0.04484283359488472, 0.04524863252299838, 0.053338702709879726, 0.058607494793250225, 0.01124352802435169, 0.08899656822904944, 0.014987505346653052, 0.031448407607967965, 0.06183598190546036, 0.022129235112515744, 0.057505821096128784, 0.019161913478455972, 0.03879890908137895, 0.04717640935268719, 0.03636493558587972, 0.03582363162422553, 0.059061726278741844, 0.029508956795325503, 0.02352013674681075, 0.08574707462685183, 0.04597166618623305, 0.025921624583133962, 0.08001322683412582, 0.07039466639980674, 0.024201897722377907, 0.04725081707874779, 0.05817865217977669, 0.0422721713403007, 0.05829967791214585, 0.06302807145402767, 0.04082243780430872, 0.10430953130708076, 0.03391738820937462, 0.014557234098901972, 0.015350909088738263, 0.007943881009850884, 0.03541969177604187, 0.10820114592206664, 0.024148051197698805, 0.06832325801951811, 0.014121582280495204, 0.03315267553261947, 0.02216325701738242, 0.031806761035113595, 0.015128284267120762, 0.022932014398975298, 0.010297238713974366, 0.008496778245898895, 0.04084562249772716, 0.027295401159790345, 0.046154512820066884, 0.0389556803565938, 0.0342603940225672, 0.014018339334143093, 0.01830198882089462, 0.043848311179317534, 0.015254882600856945, 0.023356675010290928, 0.053241136265569367, 0.02845059112587478, 0.059529939826461487, 0.015521490804530913, 0.0512708343740087, 0.012450744397938251, 0.03868536419759039, 0.041657509791548364, 0.07530425529694185, 0.04161020158790052, 0.017401884288119618, 0.014472082857537316, 0.004671260694522061, 0.06914094890817069, 0.07077998205204494, 0.05731304452638142, 0.029280972739798017, 0.05584625272604171, 0.041710254226927646, 0.023802551768312696, 0.05492955933732446, 0.036916406970703974, 0.03171821168507449, 0.03244822524720803, 0.028430803613446187, 0.028130719911132473, 0.04402645630761981, 0.020353743275336456, 0.03221344311896246, 0.0633786768594291, 0.04879017607891001, 0.025889153766911477, 0.022355196815624367, 0.0472464977792697, 0.02234800540463766, 0.07409043566440232, 0.03553673959686421, 0.035842541547026485, 0.08292381127830595, 0.018662730108189862, 0.037750235860585235, 0.04593187593854964, 0.06876865052618086, 0.04486894977162592, 0.04872954261372797, 0.0616819120477885, 0.038758977825636975, 0.035228885608376004, 0.03148612355289515, 0.02000855740334373, 0.013455283024086384, 0.045965840326971374, 0.00810913224995602, 0.06434648938011378, 0.00607461974141188, 0.12386282192892395, 0.02331344861886464, 0.07028347783489153, 0.05791094838059507, 0.0365949345723493, 0.060619627838605084, 0.06203905948495958, 0.07948860264150426, 0.019675032526720315, 0.06984506893786602, 0.025226933539670426, 0.04887491821136791, 0.007706241613050224, 0.0359968637349084, 0.02350559807382524, 0.011079505966336, 0.025031064069480635, 0.036321356674307026, 0.03603821249271277, 0.05452924488054123, 0.060878856311319396, 0.016707599570509046, 0.038066988199716434, 0.07091134961228818, 0.08721231162780896, 0.03684371360577643, 0.008807292833807878, 0.03939628972148057, 0.022241251172090415, 0.00919098689337261, 0.020876443450106308, 0.03021791377250338, 0.006509917648145347, 0.04994636794435792, 0.047475190585828386, 0.01698123312962707, 0.032412427754024975, 0.058368638274259865, 0.035270991356810555, 0.02294084039021982, 0.07614583591930568, 0.04645215485652443, 0.0332904181414051, 0.039102388109313324, 0.025680994331196416, 0.01741516316542402, 0.059972994567942806, 0.06152601279609371, 0.04576934559736401, 0.04444349506229628, 0.03245682302804198, 0.04519835201790556, 0.024737147614359856, 0.027267169862170704, 0.022651911167486105, 0.04469031482585706, 0.03235070333175827, 0.003956106784244184, 0.0514443262363784, 0.05875418399227783, 0.023940186765685212, 0.017710226238705218, 0.02863160836568568, 0.009046358081832295, 0.06902164124767296, 0.04027939721709117, 0.02953210994746769, 0.016676212289894465, 0.011791096640081378, 0.015880956525506917, 0.020479387021623552, 0.11438532150350511, 0.013945055961812614, 0.11483881084132008, 0.06807279802160338, 0.010386004214524291, 0.040097956953104585, 0.02173584118281724, 0.03282092067820486, 0.0480628342484124, 0.03444595691689756, 0.025450455432292074, 0.0958693603752181, 0.0879582591005601, 0.02460583385982318, 0.060922887932974845, 0.05353784319595434, 0.0059764159777842, 0.03892330045346171, 0.03613612774643116, 0.017600870778551325, 0.04152227193117142, 0.06745876729837619, 0.02722538323723711, 0.041289931468782015, 0.04249491212249268, 0.01757516092766309, 0.007257335500980844, 0.030663078068755567, 0.036553589525283314, 0.03163661625876557, 0.016804453553049825, 0.08994669537059963, 0.0623612295021303, 0.019437829141679686, 0.06408385816030204, 0.04979387886123732, 0.020084278730791993, 0.06110778289439622, 0.1400027156341821, 0.08241023024311289, 0.043513806667760946, 0.015775330357428174, 0.04635478137061, 0.08166799350874498, 0.04758670198498294, 0.011921064324269537, 0.031116066456888802, 0.0396505124081159, 0.04650983086321503, 0.010415274518891238, 0.04431167479197029, 0.046626062321593054, 0.03577829382265918, 0.04391464433865622, 0.0436264238669537, 0.0034286930440430297, 0.038590617914451286, 0.036130353837506846, 0.01155460107838735, 0.04326369547925424, 0.041703415336087346, 0.0192529583000578, 0.02572965509898495, 0.060062790726078674, 0.009360547228425276, 0.013695219367946265, 0.027350407290214207, 0.027977247482340317, 0.02041633601038484, 0.043119017500430346, 0.0420452745311195, 0.017266755894524977, 0.029367518291110173, 0.029180411729612388, 0.03711721728905104, 0.012512805569713237, 0.08157177406246774, 0.028494077268987894, 0.0036643307294070837, 0.011215087070013396, 0.047711542356410064, 0.033820307871792465, 0.03944214331568219, 0.015348643682955299, 0.061021485962555744, 0.026018921998911537, 0.06185727041156497, 0.04265628471330274, 0.09829668793827295, 0.013400747229752596, 0.09443705988815054, 0.03693661194120068, 0.014579191465600161, 0.03567030391423032, 0.037501649785554036, 0.03543690589140169, 0.05199216480832547, 0.04132433743507136, 0.040036985810729675, 0.04091430084372405, 0.013596918197436025, 0.04145694438193459, 0.04422738536959514, 0.024291174377140123, 0.05110731326567475, 0.04172134191321675, 0.03014579928276362, 0.06433405840652995, 0.027118432335555553, 0.02578696745331399, 0.021788132908113766, 0.019784007636189926, 0.011636227118287934, 0.006515084851344, 0.009226956008205889, 0.0039286264473048504, 0.017879938714031596, 0.027072322700405493, 0.024743641406530514, 0.03215108416043222, 0.04971076574292965, 0.11150015561725013, 0.06791438660002314, 0.01996522340050433, 0.044338373554637656, 0.0488265413150657, 0.008095364482869627, 0.026339713476772886, 0.031892345505184494, 0.05323818993929308, 0.02547613188653486, 0.04112223949050531, 0.05109042198455427, 0.03611487634771038, 0.011394012381060747, 0.04962971950590145, 0.015206989955913741, 0.035883912569261156, 0.033017430250765756, 0.08219064358854666, 0.020366986900626216, 0.023315450562222395, 0.018167678645113483, 0.032742538751335815, 0.017177045083371922, 0.039891658452688716, 0.012644161070056725, 0.03197277575964108, 0.05560744815738872, 0.06212115957168862, 0.05147868396306876, 0.03819765814114362, 0.04625220914022066, 0.03366311728314031, 0.014051376965653617, 0.03225804248359054, 0.0323347397352336, 0.0903367533464916, 0.011899837973032845, 0.029354911057453137, 0.06697427845210768, 0.07550010806880891, 0.13467975048115477, 0.16257801675237715, 0.19624465552624315, 0.1625568061717786, 0.10975599725497887, 0.13642854726640508, 0.1268703828100115, 0.2004239265806973, 0.18775659380480647, 0.19769162085140124, 0.07880447607021779, 0.23825303418561816, 0.0940940466534812, 0.11580942868022248, 0.22581205645110458, 0.0747406089794822, 0.2856934885494411, 0.17299701314186677, 0.15494872379349545, 0.1544298289809376, 0.17113361391238868, 0.12458985205739737, 0.17368376691592857, 0.11581564787775278, 0.09222855456755497, 0.20278122508898377, 0.2028810142655857, 0.08916644583223388, 0.18512373586418107, 0.1442353322636336, 0.09015579547849484, 0.13529951800592244, 0.23149901535362005, 0.12482744321459904, 0.1427791643072851, 0.11517471430124715, 0.1288984200800769, 0.157578494399786, 0.1284174490137957, 0.058278322612750344, 0.07823083302355371, 0.1503013208275661, 0.1453562275855802, 0.23692173999734223, 0.2038784310570918, 0.14348776690894738, 0.14474821568001062, 0.16341887007001787, 0.21227069635642692, 0.18664317933144048, 0.10763356622192077, 0.1757449930300936, 0.19044554326683283, 0.19875456928275526, 0.15529777068877593, 0.1018750345974695, 0.18531697627622634, 0.1560273315408267, 0.1842623547418043, 0.060131817881483585, 0.08839692774927244, 0.17387923377100378, 0.12303968367632478, 0.09205954527715221, 0.16535887378267944, 0.10338868189137429, 0.1331493677571416, 0.14523834484862164, 0.10964024448185228, 0.09942893811967224, 0.1718530073412694, 0.11945650563575327, 0.16835508722579107, 0.19807399017736316, 0.14312482700916007, 0.07735826031421311, 0.06498843969893642, 0.20161128864856437, 0.1368009569705464, 0.10675248107872903, 0.20088500808924437, 0.12214760732604191, 0.23673777643125504, 0.08833539628540166, 0.14148640242638066, 0.18092234880896285, 0.17135970178060234, 0.13987822778290138, 0.12153746545664035, 0.10000546812079847, 0.16872194566531107, 0.14936707564629614, 0.09942726086592302, 0.18153194891056046, 0.15523427253356203, 0.0896710691449698, 0.07668282429222018, 0.2508310420671478, 0.17235086968867108, 0.25587283715140074, 0.1774991926504299, 0.15473583131097257, 0.17619154328713194, 0.16314967826474458, 0.15808008232852444, 0.12544899189379066, 0.12985492969164625, 0.10881042690016329, 0.14579638052964583, 0.13271354895550758, 0.1043426978867501, 0.16186371445655823, 0.1404399742023088, 0.14108803239651024, 0.10450794448843226, 0.10390706462203525, 0.15067606087541208, 0.1914671837585047, 0.11588826702791266, 0.20675253152148798, 0.11246722599025816, 0.13030042609898373, 0.0736823731858749, 0.10324411152396351, 0.14673895260784775, 0.11669187195366248, 0.24391760991420597, 0.12672762328293175, 0.19239102402934805, 0.06057388927729335, 0.09249764247215353, 0.14102913555689156, 0.13446800090605393, 0.18814169423421845, 0.1274480705615133, 0.1544275728520006, 0.12265961500816047, 0.08499861869495362, 0.12374493177048862, 0.13702340831514448, 0.1576439815107733, 0.10573640669463202, 0.14890787919284776, 0.14774944604141638, 0.18519392819143832, 0.12104650508263148, 0.10777860414236784, 0.09427694152691402, 0.1298677094746381, 0.07242091509397142, 0.21783279633382335, 0.13594851130619645, 0.12678809347562492, 0.14047063974430785, 0.1715442887507379, 0.08341100154211745, 0.06515971253975295, 0.12796530296327546, 0.2207030524732545, 0.12113845717976801, 0.14809530170168728, 0.08730561443371698, 0.22422662121243775, 0.1299383767764084, 0.10571836508461274, 0.2025413332739845, 0.08494877605699003, 0.07344633311731741, 0.10726336811785586, 0.11685765290167183, 0.17641298531088978, 0.17389044020092115, 0.09096462512388825, 0.09595468509360217, 0.1070152161992155], [0.040173181041609496, 0.019635314638435375, 0.0134141142370936, 0.00989782318356447, 0.0741702907544095, 0.04968438981450163, 0.03127579519059509, 0.03929578066163231, 0.042283915827283636, 0.06641815751208924, 0.011692364096234087, 0.042354067336418666, 0.006575839843208087, 0.029603244802274276, 0.02060469865682535, 0.02923931784607703, 0.034218733562738635, 0.06818937457865104, 0.03190598246874288, 0.03825376450549811, 0.04503916876274161, 0.007279931114680949, 0.04784737393492833, 0.044082247259211726, 0.012703132124443073, 0.042800072114914656, 0.02048522586846957, 0.0281468263710849, 0.013606574466393795, 0.026909230182354804, 0.053968741558492184, 0.09328748797997832, 0.05434586390038021, 0.057121225327136926, 0.06155207331175916, 0.02329738112166524, 0.022137897831271403, 0.011825794827018399, 0.029349767974053975, 0.017703591438475996, 0.02945461674244143, 0.03340631192259025, 0.04487493890337646, 0.031089744334167335, 0.04223593226925004, 0.029123926869942807, 0.018186477245762944, 0.023088871021172963, 0.07086123980116099, 0.020147992108832113, 0.055123823913163505, 0.07162416019127704, 0.019187714242434595, 0.01066931537934579, 0.024870359411579557, 0.01665583848080132, 0.03178063743689563, 0.03383587070857175, 0.03005945596669335, 0.03984663235314656, 0.05645208642818034, 0.04942093481076881, 0.05411389451182913, 0.028847256071458105, 0.03751050360733643, 0.044923119130544364, 0.03876868140650913, 0.06410645655705594, 0.035144573921570554, 0.014265147965488723, 0.04602769833581988, 0.02619154183776118, 0.03660476431832649, 0.018334055166633334, 0.04283451889932621, 0.036697462273878045, 0.026282072722096927, 0.041359337119502015, 0.033807398212957196, 0.027418814752309117, 0.02898470553191146, 0.033235584560316056, 0.050023759104078636, 0.028723087343678344, 0.04032338802062441, 0.06001284047670197, 0.013904244333389215, 0.0077017279636493186, 0.05124488889123313, 0.05060916890215594, 0.009307751770393224, 0.04038678227516357, 0.007802511154295644, 0.03243462539103348, 0.03364420364960097, 0.028090005689591635, 0.017332222596451174, 0.07545827320427634, 0.05971759557723999, 0.06746535014826804, 0.014765061423531733, 0.05898225339478813, 0.013812948109261924, 0.03480369436147157, 0.03578243871743325, 0.029858031521143857, 0.04100595608178992, 0.01973193298908882, 0.024044135680014733, 0.05182202374271583, 0.03300060205219779, 0.08376989673706703, 0.018575268004497048, 0.02766929701465415, 0.09642939985496923, 0.019150981643178966, 0.06667900757747702, 0.03208935602742713, 0.03192533396941144, 0.0301493448932888, 0.0450890559295658, 0.037596232796204276, 0.048080304404720664, 0.019722012330021244, 0.03226202039513737, 0.0567181649239501, 0.03477229409327265, 0.02860695978597505, 0.0032273669330606936, 0.05245643013040535, 0.07824485961464234, 0.06946472567506135, 0.012388761151669314, 0.028990522114327177, 0.012293572362978011, 0.03345724551763851, 0.04584540089126676, 0.02771929921436822, 0.05243442174105439, 0.04262283611751627, 0.02340349896257976, 0.014442069477809127, 0.022630372186540626, 0.008717868677194929, 0.06543366893311031, 0.041010472050402313, 0.043247063949820586, 0.021276769039104693, 0.05633695705910213, 0.020348737489257473, 0.014033616444066865, 0.014284273111115908, 0.03398649329028558, 0.07198310733656399, 0.02134000929800095, 0.05089171194413211, 0.04375049982627388, 0.029801869495713618, 0.07856422802433372, 0.040030733216553926, 0.07603352671139874, 0.07647123056813143, 0.02804726354952436, 0.0403093799832277, 0.05214657976466697, 0.0164719491294818, 0.08302401605760679, 0.019445597572484985, 0.06295581595622934, 0.022867252737341914, 0.034907680383184925, 0.05198334809392691, 0.061551895196316764, 0.14464100502664223, 0.054410731318057515, 0.023806774588592816, 0.03159645122650545, 0.054901995972613804, 0.030736819717276376, 0.04844623515964486, 0.06666975299594924, 0.08089814145932905, 0.052935798157704994, 0.023148411673901137, 0.05295871196722146, 0.051691828775801696, 0.004086040144102299, 0.06671157301752828, 0.01917712936119642, 0.0252360137164942, 0.051398884534137323, 0.02054768687230535, 0.03384865791304037, 0.033999284205492586, 0.03469682138529606, 0.039672791681368835, 0.09391904080985114, 0.053005125882918946, 0.04891930235316977, 0.07156748237321153, 0.049698178918333724, 0.021437653667817358, 0.012623943111975677, 0.019385348168725614, 0.003735939631042129, 0.020423477326403372, 0.022499618753499817, 0.03660791473521385, 0.04614570723788347, 0.060231944735278375, 0.055312633703579195, 0.05399589674198069, 0.026170769124291837, 0.02074822816211963, 0.020744218709296547, 0.11155750878970139, 0.02038540886132978, 0.023919599589135032, 0.030704584532941226, 0.0360594304947881, 0.054878358569112606, 0.05871694673260208, 0.027762764948420227, 0.07224091459647752, 0.0269072616356425, 0.01563736324897036, 0.056637348752701655, 0.01656912780163111, 0.030594141826441046, 0.014223477301129606, 0.0077204885292303516, 0.031372656594612636, 0.025590897603251506, 0.05203817425353918, 0.024855243718775455, 0.026921037751890253, 0.0778630246350076, 0.009604820497770561, 0.05526515480596572, 0.027193764035473578, 0.038884385940036736, 0.03364917232829612, 0.053014558579889126, 0.011043569320463575, 0.06089188471378293, 0.031038933193485718, 0.0357466189598199, 0.02127139403455658, 0.04566249859635718, 0.0910783295694273, 0.034964944497914985, 0.007864273611630779, 0.04498515525483526, 0.060296058873063885, 0.02765244098554831, 0.007454532487827237, 0.020726186376123223, 0.03863372185151093, 0.018316559035156388, 0.012384688616293715, 0.06188758714415599, 0.03403393136977684, 0.013338047810975695, 0.010232808235741686, 0.017903232874232344, 0.052969469397794455, 0.04873394354945049, 0.04326618909544777, 0.02446582955599297, 0.010930783282674383, 0.06341090833302587, 0.06403882463928312, 0.05338753973774146, 0.07840121528715827, 0.013793640209769364, 0.03857753756165039, 0.007055346559354803, 0.11228713643504307, 0.01672247592068743, 0.02828536122251535, 0.021604058019875083, 0.03329685627250001, 0.020335601475380827, 0.011781401408370584, 0.041665209573693573, 0.061141591431805864, 0.07805348199326545, 0.028076288945158012, 0.04093387498869561, 0.0069656450250477064, 0.0662383202870842, 0.015916193697194103, 0.019254926846770104, 0.03763782275200356, 0.06087657420721371, 0.07495462952647358, 0.020738934617838822, 0.06294325881754048, 0.038604180663242005, 0.012069047643308295, 0.05242209466814529, 0.05158380918146577, 0.03872646433592308, 0.05798293299449142, 0.020773949145223014, 0.010864861087611644, 0.033548366409377195, 0.023030567899695598, 0.017535725055495277, 0.05636511414195411, 0.035555738577386364, 0.0357744828943396, 0.036216799198882654, 0.025036010483745486, 0.01808128523407504, 0.011151064773002872, 0.02168586310290266, 0.03119770270131994, 0.015438916670973413, 0.05741985070926603, 0.0616831959632691, 0.04914155702863354, 0.05091924933367409, 0.044235344903427176, 0.05759726482210681, 0.06025642447639257, 0.0016434697954537114, 0.04352944000856951, 0.050678863990469836, 0.05821194492455106, 0.0558348125196062, 0.04564845345157664, 0.06705645646434277, 0.020254250957805198, 0.02751038278802298, 0.007611692926730029, 0.03254843002650887, 0.017768097059160937, 0.021500845687114634, 0.01148680217738729, 0.032227324991254136, 0.09236994112143293, 0.021257397129375022, 0.01463357419197564, 0.012251911903149448, 0.05364173273846973, 0.012728162910207175, 0.04327757364080753, 0.03532488983182702, 0.06616777915041894, 0.02560368851845851, 0.02737375340075232, 0.13937439856817946, 0.10225011603324674, 0.10899141445406713, 0.15630349953426048, 0.08423491904977709, 0.2623007562942803, 0.09508430914138444, 0.17575073725311086, 0.16054626874392852, 0.2233642604551278, 0.11051041263272054, 0.2286483222269453, 0.19711207773070782, 0.10295510437572375, 0.08394572636461817, 0.1517240921384655, 0.11736626896890812, 0.19675353134516627, 0.10706433895393275, 0.15524341579293832, 0.14258133742259815, 0.09759012624272145, 0.14625305368099362, 0.19856046797940508, 0.07505309768021107, 0.16170085757039487, 0.10261037677992135, 0.12182095844764262, 0.09671517866081558, 0.14847387123154476, 0.15267714334186167, 0.13072000670945272, 0.0644732110959012, 0.1505537994671613, 0.14521434379275888, 0.18429401476169005, 0.08089368857326917, 0.11265241410001181, 0.14157502970192581, 0.2827388502191752, 0.11056594754336402, 0.1215083064744249, 0.18676101753953844, 0.12674598401645198, 0.16960709035629407, 0.1326293300371617, 0.1483421103330329, 0.20737652928801253, 0.09544931221171282, 0.07097124092979357, 0.1501571957487613, 0.14259877789299935, 0.14634959225077182, 0.0501049463491654, 0.11698504255036823, 0.08288795812404715, 0.15471847989829257, 0.15537485014647245, 0.13066571118542925, 0.1324515708256513, 0.23255415639141575, 0.10770542095997371, 0.11396462767152116, 0.1791785837849602, 0.17589670285815373, 0.13501294510206208, 0.22315366863040254, 0.19503807183355093, 0.1822159715811722, 0.09576368596754037, 0.134133173560258, 0.11115292698377743, 0.10771696135634556, 0.16940188652370125, 0.11085019010351971, 0.17644468985963613, 0.14631692291004583, 0.12905919895274565, 0.19938511279178783, 0.16758243727963418, 0.11496098319184966, 0.1422217520303093, 0.12255234498297796, 0.09676544432295486, 0.14960557222366333, 0.15906672313576564, 0.07296933254110627, 0.0628520266036503, 0.15429783059516922, 0.16609647951554507, 0.15703518292866647, 0.13728755351621658, 0.14643997099483386, 0.10515006550122052, 0.12846421916037798, 0.19355529046151787, 0.08720984027604572, 0.17868564929813147, 0.16563155368203297, 0.12129673501476645, 0.1637733494862914, 0.13137088506482542, 0.14026922086486593, 0.07887216735980473, 0.09900818491587415, 0.11062534162192605, 0.11280984588665888, 0.11370198160875589, 0.15158560738200322, 0.1774469602969475, 0.16088853240944445, 0.16557614493649453, 0.09746554933371954, 0.12164539599325508, 0.1994672982254997, 0.10810174266225658, 0.2573970006778836, 0.09554183576256037, 0.11624691731412895, 0.1630145777016878, 0.08729815584956668, 0.12493739981437102, 0.1017944076738786, 0.07105019059963524, 0.10400473125628196, 0.12252375745447353, 0.13431131868856028, 0.13601715996628627, 0.10572464365395717, 0.09651229775045067, 0.14008341677254066, 0.09869125817203894, 0.13797635561786592, 0.15114637470105663, 0.13025974156334996, 0.1554231342743151, 0.16227907966822386, 0.14837512106169015, 0.14358313288539648, 0.1438391738338396, 0.1909674215130508, 0.116498987772502, 0.10348533178330399, 0.20448056515306234, 0.11948992454563268, 0.1162610700703226, 0.1518680836306885, 0.18392639933153987, 0.18113359372364357, 0.05520549355424009, 0.04653356474591419, 0.15171803621342406, 0.11175207022461109, 0.1705213717650622, 0.1747427522786893, 0.11648747706203721, 0.1623845536960289, 0.1001404202543199, 0.11095475128968246, 0.104146718949778, 0.1578348025213927, 0.09559655431075953, 0.09969997787266038, 0.09565788539475761, 0.1565927144838497, 0.1970245488337241, 0.12460663943784311, 0.1075445901369676, 0.10976645411574282, 0.10927104827715084, 0.13139991788193583, 0.1425315986853093, 0.107395596569404, 0.2209372297511436, 0.23661306593567133, 0.18104174552718177], [0.018389610486337915, 0.03723905567312613, 0.009627612780604977, 0.04748960680444725, 0.03159219500957988, 0.020729611387650948, 0.028259480677661486, 0.027684019369189627, 0.022932218489586376, 0.03386240990948863, 0.01970160326891346, 0.053687701365561225, 0.12159216916188598, 0.0391392208985053, 0.06466653314419091, 0.012139414375269553, 0.036737293339683674, 0.027118564066768158, 0.01700362001429312, 0.05402977949415799, 0.05338715382094961, 0.04178512950602453, 0.03608381375670433, 0.017888120892166626, 0.006017435407557059, 0.024802044717944227, 0.08468713189358823, 0.037962731294101104, 0.04669161993660964, 0.04905150482954923, 0.03047675076231826, 0.02631130406371085, 0.02774711490928894, 0.02766402962151915, 0.02987280211527832, 0.07860000696382485, 0.02683106533368118, 0.025594088838261086, 0.02573692072473932, 0.033714559249347076, 0.032456392582389526, 0.022767767841287423, 0.026785234003909864, 0.046100154213490896, 0.05033840374380816, 0.012489827749959659, 0.0460893967829179, 0.05053627886809409, 0.04341755382483825, 0.03859140088025015, 0.06202449483680539, 0.029381982749328017, 0.03020252534042811, 0.04057697988173459, 0.04242828210408334, 0.024665305863891263, 0.039752594821038656, 0.027693908486980945, 0.05384754513215739, 0.05648934966302477, 0.04087251050805207, 0.023603719273523893, 0.04190409948932938, 0.0422240133775631, 0.034723483040579595, 0.027028649165004026, 0.026720134665083606, 0.054603938333457336, 0.05811807066493202, 0.058456404658500105, 0.07613354595378041, 0.06759171563317068, 0.03998757732915692, 0.07027783751254901, 0.04077369725564495, 0.010184604816458886, 0.034075573275913484, 0.03480780957033858, 0.021862505382159725, 0.05601190379820764, 0.03558614436769858, 0.027565038253669627, 0.05959357898973394, 0.05527623507077806, 0.032169277910725214, 0.042931536154355854, 0.0516959217202384, 0.004847980435442878, 0.040607708506286144, 0.05126823685714044, 0.02872161232517101, 0.058981455586035736, 0.019891075426130556, 0.03609374369261786, 0.025078149628825486, 0.056042446885840036, 0.0543034835573053, 0.06258413355681114, 0.024572563379479107, 0.07537049197708257, 0.053243741203914396, 0.049782750356826, 0.02108390341163613, 0.060368596386979334, 0.03751295640540775, 0.02457155776937725, 0.05686047545168549, 0.012178185097582173, 0.056824919156497344, 0.053337967983679846, 0.043958560927421786, 0.019610261588240974, 0.015664271668356378, 0.07986251890542917, 0.034411298620398156, 0.03111497178906575, 0.05166406132047996, 0.08736975083593279, 0.04387292450701352, 0.05573452610406093, 0.015429261329700239, 0.054972563084447756, 0.024649435035826173, 0.011047742045775522, 0.039859182070358656, 0.0133463682141155, 0.04358793237770442, 0.019049854745389894, 0.14652902871603146, 0.03920446310075931, 0.02328133774426533, 0.08174601549399085, 0.03792606177739799, 0.030801336470176466, 0.008069049781624926, 0.026064118792419322, 0.032756023574620485, 0.06275482752243988, 0.03122383372101467, 0.06884699905640446, 0.03187691625498701, 0.020982923088013195, 0.04363596788607538, 0.012646956183743896, 0.04358146456070244, 0.06218800481292419, 0.029740733225480653, 0.05970272293779999, 0.06240836330107413, 0.03448001036304049, 0.0650546838005539, 0.017916801189130638, 0.022996219449851196, 0.011346619758114684, 0.021764350785815623, 0.022583676254726015, 0.02486523302650312, 0.02040374918578891, 0.0410635912703583, 0.024304559010488447, 0.007743507167106145, 0.016739376478653867, 0.035289478255435824, 0.052107182855252177, 0.02459310973790707, 0.034508460594224744, 0.04801937779120635, 0.06578633750905283, 0.023314886529988144, 0.01779132628143998, 0.06631234209635295, 0.022573258356715087, 0.023659870166738983, 0.034895791177405044, 0.044943376051378436, 0.031271713378373533, 0.049126354133477435, 0.0052835816950391745, 0.014178094043018064, 0.017411637963959947, 0.022750579701096285, 0.02041510961134918, 0.02816868818626972, 0.02499570258805761, 0.025442113692406565, 0.05055358946265187, 0.042088619666174054, 0.04734691035992, 0.06572659462108277, 0.020486995890678372, 0.027348468429408967, 0.07235392142320052, 0.054791174770798534, 0.04590180040395353, 0.036550869554048404, 0.0641708007606212, 0.013466457912727492, 0.037824116661795415, 0.021657295983459335, 0.03005196213052841, 0.034856624333770014, 0.06372577932779677, 0.024909715502872132, 0.045624404156114906, 0.029022046692261938, 0.035503788240021095, 0.052589667902793735, 0.020242539867467713, 0.04381672166346107, 0.039389892408507876, 0.025532360705255996, 0.04547998592897784, 0.02359282454563072, 0.03614013905462343, 0.076458532421384, 0.011559164358914131, 0.08719176898011938, 0.04474376059079077, 0.054041282783146016, 0.007138914243114414, 0.04857086772972252, 0.031138056292547844, 0.03220562830392737, 0.05319113777659368, 0.024911140426411293, 0.07593117712531239, 0.05678354071278591, 0.06710551242576912, 0.012521992430265527, 0.00499470349495823, 0.033032863211701624, 0.006852776887171785, 0.019192866602679715, 0.010379929735790938, 0.013797627398162149, 0.014247912513383199, 0.044913285673828796, 0.012721279490506276, 0.037203117171884514, 0.05613851419184357, 0.016590041523159016, 0.025074490840779617, 0.07523119085817598, 0.05035830443375744, 0.034591915100463666, 0.025468326348345727, 0.04746622173115611, 0.02811607177136466, 0.0214965820487123, 0.08890247874660417, 0.012703223037533462, 0.015587333218718413, 0.00736635374778416, 0.09231807242031209, 0.028034390998072922, 0.04485135716095101, 0.10627957715769298, 0.029414115888357628, 0.014906861724739429, 0.03750337527890224, 0.028469803473853972, 0.07444467759341933, 0.05706952360924333, 0.05775394332886208, 0.038079040677985176, 0.032671767548890784, 0.022437259794969577, 0.06675747485132888, 0.03806552616879344, 0.019916596029361244, 0.016862257580214646, 0.043631867520161904, 0.027129866975883488, 0.08383488660911098, 0.05431086050521117, 0.0305821561414632, 0.033483116785646416, 0.024363693337363657, 0.034189975340268575, 0.02331413510546554, 0.057097699245787226, 0.029545982542913407, 0.034886095018009655, 0.013868385613022838, 0.023512787629442755, 0.032232865123660304, 0.03136069317406509, 0.01672072074143216, 0.013549278810387477, 0.05097276560263708, 0.019452451306278817, 0.029368666764639784, 0.12299467984121293, 0.05971682745439466, 0.016258967589237727, 0.038075092452345416, 0.05361820665712003, 0.02252765894809272, 0.07802202977472916, 0.09916543116560206, 0.09739509725477546, 0.037444326299009845, 0.03230359550798312, 0.01531592795799952, 0.03414766921196133, 0.027756243325711694, 0.016979876854748, 0.053022176725789905, 0.020349551996332593, 0.026588631662889384, 0.012220760254422203, 0.018125906863133423, 0.016032009552873205, 0.010709348680393305, 0.01483512294726097, 0.033824207857833244, 0.06976755903451703, 0.02330206592887407, 0.039234063660842367, 0.04026655064080842, 0.04842007445404306, 0.03523375780787319, 0.032516157734789886, 0.08670074181281962, 0.07304792598006316, 0.023559952969662845, 0.08488618332194164, 0.020201254192215856, 0.06027559044014197, 0.050334923071204685, 0.014252537021093303, 0.04289234333555214, 0.01759149003191851, 0.04123184728086926, 0.006033278405084275, 0.009364901779918, 0.04971367496182211, 0.031734486983623356, 0.03624835531809367, 0.09176982566714287, 0.02796552340441849, 0.02966097275930224, 0.036227289456292056, 0.04059968588990159, 0.024522355233784765, 0.06382317136740312, 0.06204870740475599, 0.029284893134899903, 0.08802068114164285, 0.04054558332427405, 0.027999699304928072, 0.018934695690404624, 0.1419547272962518, 0.11247885544435121, 0.07945611883769743, 0.16453557967906818, 0.16959281143499538, 0.06005643052048981, 0.06517274465295486, 0.08677824429469183, 0.12450108377379365, 0.08056833845330402, 0.16057142755016685, 0.11699251597747207, 0.2459717114106752, 0.16611734870821238, 0.1808286749292165, 0.1197668792156037, 0.14076561375986785, 0.1436023396672681, 0.13260908424854279, 0.10871641905396245, 0.14964279835112393, 0.13742584531428292, 0.15640812751371413, 0.06853580169263296, 0.07155676576076075, 0.23949317779624835, 0.17487204924691468, 0.19707130413735285, 0.16914562293095514, 0.10655435733497143, 0.11543142318259925, 0.14408670976990834, 0.09842677158303559, 0.13964896352263168, 0.08174490969395265, 0.17693343863356858, 0.05127009964780882, 0.10237988055450842, 0.21749798383098096, 0.11870543734403327, 0.11657746246783063, 0.11715534317772835, 0.1417216780828312, 0.09493386096437462, 0.18398686952423304, 0.06890643766382709, 0.13980462157633156, 0.15644955419702455, 0.12433330644853413, 0.15830429998459294, 0.2353013792890124, 0.1655681148986332, 0.19732733024284244, 0.09185031900415197, 0.15002274827565998, 0.10880451198318042, 0.07781327105476521, 0.07715180967352353, 0.17415973590686917, 0.15048927714815363, 0.11413473534048535, 0.10392169977421872, 0.15560997737338766, 0.1352759325527586, 0.13459873764077201, 0.12657595798373222, 0.23387771740090102, 0.11611008012550883, 0.15559758350718766, 0.17977264331420884, 0.2408465137705207, 0.19565191701985896, 0.11382531170966104, 0.24622307682875544, 0.1459471255657263, 0.17112579167587683, 0.1248414401197806, 0.2275496764923446, 0.14337255590362474, 0.1533775229472667, 0.24837604723870754, 0.09968943195417523, 0.19265801907749847, 0.10304121577064507, 0.10494381524040364, 0.14650928758783266, 0.1671522291144356, 0.1426547803566791, 0.13549029448768124, 0.22937864006962627, 0.12419913357007317, 0.16658166598062962, 0.1265417004469782, 0.15486921009141952, 0.13378868345171213, 0.12137225596234202, 0.14268467406509444, 0.13746443699346855, 0.11697773981723003, 0.1667662529507652, 0.17753334628650919, 0.0952196100843139, 0.13232571742264554, 0.12992921867407858, 0.15829646290512756, 0.20212835777783766, 0.1511688469327055, 0.12716452562017366, 0.16983157518552616, 0.13362186349695548, 0.24337863258551806, 0.14623395079979673, 0.13331056223250926, 0.15537945146206766, 0.07979018919286318, 0.1799826414207928, 0.3346316859824583, 0.1575510943075642, 0.08197772884159349, 0.18405581504339352, 0.13375255570281297, 0.16650800040224567, 0.16569068800890818, 0.2005763043416664, 0.17909034242620692, 0.0838777085300535, 0.08103576532448642, 0.18989418691489846, 0.22891064174473286, 0.167113414790947, 0.12724794301902875, 0.1691231655422598, 0.14301161980256438, 0.10633245517965406, 0.1264282112242654, 0.09462140194955282, 0.12187930609798059, 0.1646203626296483, 0.1291317364666611, 0.1960126156336628, 0.12499234842834994, 0.10388741997303441, 0.15406298538437113, 0.07925934580271132, 0.11198923093616031, 0.19931395567255095, 0.1633347847382538, 0.17389999906299636, 0.12351295867119916, 0.14637158950790763, 0.16182205028599128, 0.11098018469056115, 0.2127848711097613, 0.14296617067884654, 0.13603467465145513, 0.11619004653766751, 0.11131122708320618, 0.11338256124872714, 0.09190965371089987, 0.12043606635415927, 0.08029448596062139, 0.13285675377119333, 0.11075973714469001, 0.13944537757197395, 0.10070036325487308, 0.09823932734434493, 0.08472331159282476, 0.18680012872209772, 0.09019802368129604, 0.15269165975041687, 0.16690151678631082, 0.07091202496667393, 0.14792190631851554, 0.11449207944679074, 0.14063833543332294, 0.13407510792603716], [0.03223491716198623, 0.04647957350243814, 0.02649142887094058, 0.03337311194627546, 0.008056290407694178, 0.0072966688640008215, 0.03344796125020366, 0.041480611471342854, 0.03806346299825236, 0.037146164759178646, 0.046718674930161797, 0.02348186419112608, 0.042623103290679865, 0.059432725902297534, 0.03409007484151516, 0.007596948307764251, 0.011726747798093129, 0.024804900131130125, 0.07514110155170783, 0.04025832764455117, 0.01682495538261719, 0.02686459742108127, 0.025900994733092375, 0.039053061263985, 0.02578203217126429, 0.14852583641186357, 0.02211566494224826, 0.05901696735236328, 0.008087717578746378, 0.04726383805973455, 0.057184571342077106, 0.019502024915709626, 0.05101024406030774, 0.07931747823022306, 0.014834942048764788, 0.06349240356939845, 0.027162458391103428, 0.01886113215732621, 0.058331846303190105, 0.012070982793375151, 0.01102638489101082, 0.03232479495636653, 0.0421427222318016, 0.02319143954082392, 0.04065409644681495, 0.04527589902863838, 0.05669839782058261, 0.02908686587034026, 0.05613800210994668, 0.020952602644683793, 0.06884086891659535, 0.060600866345339455, 0.015206986245175358, 0.024663103540660813, 0.03979991786764003, 0.04047538728627842, 0.06766299149603583, 0.060203932371223345, 0.02093902319757035, 0.04551836238533724, 0.0713567940692883, 0.07700261572608724, 0.05365819357393775, 0.04349324546637945, 0.03381988484761678, 0.036859784813714214, 0.022778373131586704, 0.10151398717425764, 0.014552064112649532, 0.010055233633465832, 0.02699034692341229, 0.03586281331081409, 0.016548611129110213, 0.025821803865255788, 0.03288391417299863, 0.03884882964484859, 0.034050533213303424, 0.019584308683988638, 0.02410939643596066, 0.021151273722352926, 0.06802668838645332, 0.07497517959563993, 0.021244971721898764, 0.04885098765953444, 0.0181373322266154, 0.029143194878997747, 0.0767573581833858, 0.011715397577063413, 0.04192283500742633, 0.02357735447731102, 0.009787900908122538, 0.057786827892414294, 0.007319579890463501, 0.017031756688083988, 0.018775781463773455, 0.02535777231969405, 0.08833087660605088, 0.003933923062504618, 0.023121857630030718, 0.037794289746670984, 0.04706025210907683, 0.03108844186499482, 0.021987601794535294, 0.04893824196187779, 0.10719270823756233, 0.037802865263074636, 0.051405426565906964, 0.002041854204435367, 0.00956719639361836, 0.033050548590836115, 0.008166644984157756, 0.04005595139460638, 0.00955757352130604, 0.020254351147741545, 0.0050026180360873695, 0.06707167049171403, 0.05657418085320387, 0.08479939657263458, 0.008022934580367291, 0.08929110437748022, 0.016821816097944975, 0.023392201619572006, 0.04301496097468771, 0.06537527675391175, 0.0626662521972321, 0.01377728141960688, 0.0416101830342086, 0.05746636481489986, 0.02380599718890153, 0.01927553072164301, 0.04855928280449007, 0.03179489038302563, 0.0231602823259891, 0.06547536278958432, 0.03335995366796851, 0.040007745192269795, 0.04253622377291322, 0.021045261637482326, 0.028151021360827144, 0.02552515630668495, 0.05143912749190349, 0.02200580853241263, 0.020267448198865168, 0.04095272182894405, 0.044631028358708136, 0.006915814446983859, 0.0717172997246962, 0.014121906970103737, 0.04792585605173372, 0.033516613621031865, 0.013247107817733195, 0.00951499372604303, 0.05611971559119411, 0.04844324059376959, 0.03370407270267606, 0.024051633226918057, 0.015330485184676945, 0.0552108481497271, 0.05850946079590358, 0.010195079303230159, 0.021027279399277177, 0.035402548164711334, 0.03436590144701768, 0.05879168842511717, 0.04614605975802988, 0.044023970112903044, 0.030932846893847454, 0.059510554929147474, 0.04167522114585154, 0.015358119981101481, 0.06803792450227775, 0.007919146155472845, 0.05703129558241926, 0.056049653139780276, 0.03607287821068894, 0.08320118155097589, 0.04466452890483197, 0.04601028012984898, 0.06418841192498803, 0.008620672379038297, 0.021211794010014273, 0.03174167468387168, 0.02925229986431077, 0.008752128069318132, 0.014549750467267586, 0.020941002876497805, 0.026497948638279922, 0.02384091894782614, 0.029754060342384037, 0.021177760972932447, 0.037076232183608226, 0.02111497899022652, 0.03243932318582665, 0.027219297626288608, 0.047693548985989764, 0.043395615939516574, 0.09055977614480071, 0.018825505358108785, 0.037216279160929844, 0.058067066565854475, 0.04473701075767167, 0.1364326587645337, 0.013500695040420396, 0.027034144768549595, 0.01836454259318998, 0.044032671794411726, 0.03425340670219157, 0.05374472057155799, 0.06023441979777999, 0.033806685751187615, 0.029347688105190173, 0.047609593530069105, 0.03226752713089809, 0.050392587945680134, 0.06886825416586362, 0.04078210949955974, 0.0391255208523944, 0.061426008396665566, 0.010177243639191147, 0.09135749583947472, 0.05249555244517978, 0.03760154657356907, 0.02280714805237949, 0.027419992911745794, 0.07651649415493011, 0.04798925401701126, 0.07553740841103718, 0.11210217839106917, 0.0612560491572367, 0.01854526111856103, 0.04016958533611614, 0.05530877082492225, 0.0356908465619199, 0.07146365591324866, 0.0493947778159054, 0.03101010817772476, 0.02210535094491206, 0.057304031142848544, 0.053366874635685235, 0.03561521058145445, 0.05891031330975238, 0.033935155224753544, 0.02613409589685034, 0.04224586591590196, 0.04741453485621605, 0.01326685729509336, 0.0738892394292634, 0.013918348849983886, 0.030747399032406975, 0.03123960064840503, 0.07550746275228448, 0.03199000842869282, 0.04357537523901556, 0.08443454193184152, 0.019379739387659356, 0.05761110958701465, 0.05012441659346223, 0.06509076702059247, 0.022511986644531135, 0.039163644978543743, 0.040642559761181474, 0.06174284979351796, 0.0520312425942393, 0.02850118704373017, 0.0067894791118305875, 0.05422359135991428, 0.045883502752985805, 0.019293602017569356, 0.037140220156288706, 0.05312955065164715, 0.06780275274650194, 0.06674183037830517, 0.026586954409140162, 0.011063526599173201, 0.025956707759178244, 0.015212952184811002, 0.05830140711623244, 0.1050716575991828, 0.04349299313616939, 0.015473073090106482, 0.03222047867893707, 0.014393787205335684, 0.059382682884461246, 0.033700948260957375, 0.04126518455450423, 0.05404274481406901, 0.016541046788915992, 0.05506905712536536, 0.019417837538640015, 0.02457247432175791, 0.06637037062318996, 0.019728648985619657, 0.1078235634486191, 0.008929028244892834, 0.012411487568897428, 0.05318414303474128, 0.041734351761988364, 0.03787628222198691, 0.02130079607013613, 0.0764589331811294, 0.06671896480838768, 0.03948100587876979, 0.04647414469218347, 0.00516526758474356, 0.07933956454508007, 0.05158723048225511, 0.028132497354818042, 0.03730419397470541, 0.04103806881175842, 0.04481680647586472, 0.020837912998104002, 0.04808436024177354, 0.056149928423110396, 0.09127449404331855, 0.02381691232585581, 0.012198244421597337, 0.09191337929223664, 0.019799223518930376, 0.015804044051037636, 0.005457096749523771, 0.03456343518337235, 0.037813088347320445, 0.005861607123733847, 0.022867438274261076, 0.004791547062268364, 0.06222176882147323, 0.033021604831446894, 0.012583966399688506, 0.07122474373318255, 0.047594995485269465, 0.024927820195443928, 0.08072154741967097, 0.023848900746088475, 0.04434087088156957, 0.02108614284225041, 0.03524253370414954, 0.027458632830530405, 0.02530641755583929, 0.020000957811134867, 0.06805175813497044, 0.005605823143923772, 0.03934027241484728, 0.05812318035168573, 0.02191567840782227, 0.03739659507118631, 0.020620654831873253, 0.048024888237705454, 0.033758947101887316, 0.06231543156900443, 0.13842875399859622, 0.07875490060541779, 0.05774887446023058, 0.1540531890350394, 0.2501007984392345, 0.13042941136518493, 0.10562952258624136, 0.12073394958861172, 0.07862038633902557, 0.18265029124449939, 0.08123740684823133, 0.1430287040420808, 0.0959211474400945, 0.1289787353016436, 0.12760852288920432, 0.12214879476232454, 0.14891467726556584, 0.17871597345219925, 0.08654382210806943, 0.19274643855169415, 0.11467422475107014, 0.2144433485227637, 0.14729599381098524, 0.21382211154559627, 0.10130175520316698, 0.11876844568178058, 0.20051810512086377, 0.15566253627184778, 0.3349347197217867, 0.17155674198875204, 0.1619190935161896, 0.0782401321339421, 0.1138192780490499, 0.13127540034474805, 0.18472264957381412, 0.09410813261638395, 0.19333537726197392, 0.06982889753999189, 0.1799898550962098, 0.1583881923579611, 0.1344683422939852, 0.17865139176137745, 0.1434299536049366, 0.09745770483277738, 0.13864847423974425, 0.1841522942413576, 0.16633953287964687, 0.1558494832715951, 0.1356513553764671, 0.1418070399085991, 0.10123684696736746, 0.09446481621125713, 0.16128057934110984, 0.2157415874535218, 0.14297397807240486, 0.16027902136556804, 0.0834871458937414, 0.2120157834724523, 0.1624304332653992, 0.14011807506904006, 0.17777611763449386, 0.14548179897246882, 0.16914750798605382, 0.17823893576860428, 0.14671631710371003, 0.11672667867969722, 0.08029176970012486, 0.2462193660903722, 0.09777183367987163, 0.09344483070890419, 0.1461875220411457, 0.1315093698212877, 0.12650868971832097, 0.31040299858432263, 0.0746971636544913, 0.09423653900739737, 0.20910981518682092, 0.16388789255870506, 0.08749996064580046, 0.16403341287514195, 0.12888031167676672, 0.27515905851032585, 0.070359065575758, 0.13275064149638638, 0.13821448112139478, 0.10277938607032411, 0.12895737629150972, 0.20109561475692317, 0.1305913776741363, 0.1459610927850008, 0.10060992513899691, 0.09346103921416216, 0.10551001454587094, 0.10935804282780737, 0.16521131998160854, 0.07244317952427082, 0.12609801487997174, 0.09573526913300157, 0.21757393522420898, 0.1349158276570961, 0.1208501921792049, 0.1144589128671214, 0.08869942714227363, 0.17492402927018702, 0.1690475852228701, 0.1182245479139965, 0.1248427462996915, 0.20258624805137515, 0.16682621848303825, 0.20290952757932246, 0.14291120722191408, 0.12680666201049462, 0.1671563702984713, 0.0812544985092245, 0.128862633719109, 0.14101816661423072, 0.08199611183954403, 0.11227658309508115, 0.14903302013408393, 0.25676623452454805, 0.1546888830489479, 0.08903097419533879, 0.15381954610347748, 0.11296560784103349, 0.10316567393601872, 0.11134939573821612, 0.16605445911409333, 0.16859169874805957, 0.12009938363917172, 0.17830072698416188, 0.09697973204310983, 0.12415014440193772, 0.16721872554626316, 0.12506671162554994, 0.08177312614861876, 0.18045501841697842, 0.09512224773061462, 0.07215147095848806, 0.16291910782456398, 0.15377127681858838, 0.11457887361757457, 0.13769870332907885, 0.09301444442826323, 0.18625598604558036, 0.1022862883110065, 0.09460777611820959, 0.11772623285651207, 0.1497197590651922, 0.08567473749280907, 0.1404579490190372, 0.10329759068554267, 0.15920403529889882, 0.1666040046256967, 0.16019875067286193, 0.18685912946239114, 0.17096063413191587, 0.08354938239790499, 0.13018040597671643, 0.1643814949784428, 0.15322499675676227, 0.11177914377185516, 0.08713527669897303, 0.11863589068525471, 0.14982928521931171, 0.12633228121558204, 0.06382479667081498, 0.1772795763099566, 0.12166042448370717, 0.15371561574283987, 0.12564781325636432, 0.19871039665304124, 0.1340995097416453, 0.06065495777875185, 0.1096616851282306, 0.16000000352505594, 0.14088328869547695, 0.23341291031101719, 0.14687289542052895, 0.15911796101136133], [0.08647869864944369, 0.026281712780473754, 0.06292133577517234, 0.0393710529897362, 0.052780062178499065, 0.06924104236532003, 0.0673527515027672, 0.025768241212063003, 0.03674547180708032, 0.04966847445757594, 0.01716097758617252, 0.03183414999512024, 0.03835012495983392, 0.0708103136275895, 0.02621832965814974, 0.02367193748796126, 0.007351173117058352, 0.026255995508108754, 0.04675089156080503, 0.029800630109093618, 0.07388426703982987, 0.02757381043920759, 0.03720549946592655, 0.04392694914713502, 0.017868073628051206, 0.03868763516948093, 0.03765153021959122, 0.03230592585168779, 0.051485426374711096, 0.05244122352451086, 0.08100012739305384, 0.08036680083023384, 0.032627724795020185, 0.019855305763485376, 0.02893311142543098, 0.07449193013599142, 0.0491810058883857, 0.04630476803868078, 0.0012532102800832945, 0.01470103912652121, 0.06014822305587586, 0.0554978552099783, 0.06160003460536245, 0.05174058045668062, 0.03675200270663481, 0.025062200875254348, 0.012683776913036127, 0.049002656669472344, 0.021181388219702058, 0.01972955997189274, 0.043816075994982384, 0.056520286088925786, 0.029868698038626462, 0.026104389580723364, 0.026812398464244325, 0.05838548131578136, 0.02343105305044446, 0.02779019658191828, 0.08371735268156044, 0.022187627291714307, 0.0066832434549723985, 0.05157152292667888, 0.0033673619600449456, 0.08425022955634631, 0.03806236090895254, 0.03070019472943386, 0.09357627990539186, 0.037427917413879186, 0.029353367390285712, 0.028764885100827087, 0.024026429891819134, 0.04062821033585351, 0.03984835413575638, 0.02634183972986648, 0.04876623810559977, 0.03708644784637727, 0.018151212243537884, 0.05561192701861728, 0.05216754543653224, 0.022295507733360864, 0.04146888182731345, 0.03488091111648828, 0.03891693282639608, 0.022594279689656105, 0.004358064634288894, 0.0028456785275920993, 0.0695817920495756, 0.05921236370340921, 0.05518244986888021, 0.019345897453604266, 0.03168112656567246, 0.059714916424127296, 0.04669894122343976, 0.014336772637761896, 0.011981734896835405, 0.019178533875674475, 0.021031364922237117, 0.060263285631663166, 0.046219788418966345, 0.01864529520389624, 0.048645312563166954, 0.02978364791488275, 0.039916397945489734, 0.0654653437959496, 0.0714609916030895, 0.05771857628133148, 0.029669321920664515, 0.07529080015956424, 0.010443980791023932, 0.04634983866708353, 0.03124176771962084, 0.015590201619488653, 0.040161681463359855, 0.0477195241546724, 0.03367565957887564, 0.05291556350130122, 0.04356723387900274, 0.027459955708764028, 0.03240699152229354, 0.01714177822577767, 0.016516127325303387, 0.019269972035544924, 0.008200458159990376, 0.044331831522868015, 0.06955532706342638, 0.026888526117545553, 0.017333658652205486, 0.048785867911647074, 0.018401611014269292, 0.04070289265655447, 0.051258848689030856, 0.01438889923520037, 0.06251267215702683, 0.022525232125190087, 0.05914351095270831, 0.01170029765489744, 0.033209256871487014, 0.03536719596013427, 0.04497714377066586, 0.005126450014358852, 0.0515944033395499, 0.014958949359424878, 0.024772010001470335, 0.05737210092775058, 0.050345940253464505, 0.016684862021065783, 0.05995111234369688, 0.07321856799535453, 0.009409271078766324, 0.008874935883795843, 0.02120665092661511, 0.026924308767775074, 0.03438117113546468, 0.0821867398917675, 0.03565960956620984, 0.06482234704890288, 0.03541899786796421, 0.02060741862806026, 0.04780194707564078, 0.08162979516782798, 0.010286216893291567, 0.020818991943087894, 0.03767195412365254, 0.016092834121081978, 0.06202410892001353, 0.048918022148427553, 0.06391195449396037, 0.06860430934466422, 0.028476924380811397, 0.07220123938168399, 0.017781062379071955, 0.04717398995126132, 0.04814801424799953, 0.03249378569307737, 0.07081749019562267, 0.05468163377372548, 0.050234580994583666, 0.039598773582838476, 0.05144025926711038, 0.06221548654139042, 0.06659445469267666, 0.06040577056410257, 0.03693676037073601, 0.01106723826524103, 0.038539858724107035, 0.031095965387066826, 0.038677096672472544, 0.0277851462669787, 0.026724930794443935, 0.04318443410738837, 0.04256439198798034, 0.017942665035661776, 0.09480719119892456, 0.03767416943446733, 0.03986575378803536, 0.037337097091949545, 0.09609818676835857, 0.04028922696306836, 0.04329103248892352, 0.03381790702405851, 0.039914379303809255, 0.04079459613421932, 0.052476297423709184, 0.09763047681190073, 0.057932236886699684, 0.0386185004026629, 0.03407726908335462, 0.046755396397202276, 0.03726524235389661, 0.02637056455569109, 0.018749694972939324, 0.07601804551086389, 0.01844808430178091, 0.01427969591532019, 0.023356302081083413, 0.06903737477841787, 0.05688394216122106, 0.09736216816236265, 0.044514399851323105, 0.0070997381226334255, 0.049084330021287315, 0.07220405954285525, 0.03510866139549762, 0.03818683391727973, 0.038505029733642004, 0.01576648766786093, 0.02061968818452442, 0.03822667982603889, 0.052623981100623496, 0.006760683781976695, 0.016366042800655123, 0.015286649304471212, 0.02874014746339526, 0.011850243954540929, 0.03182328124239575, 0.02017526603594888, 0.01231540820299415, 0.05179358093300834, 0.03617107548052445, 0.03211770235793665, 0.037255950664984994, 0.01566117691254476, 0.08041205699555576, 0.07163273941841908, 0.050699417770374566, 0.023704994600848295, 0.04935999706503935, 0.03022213844815269, 0.043954300999757834, 0.0473407356912503, 0.01765250570315402, 0.057848452124744654, 0.04481792340811808, 0.08454958224319853, 0.03213934709492605, 0.03259610188251827, 0.0279468639564584, 0.03923862044757698, 0.034711501066340134, 0.03990425269876141, 0.042111284856218845, 0.05948207501205616, 0.08969540416728705, 0.033564111072337255, 0.0613609999709297, 0.007425132307616877, 0.026950647588819265, 0.04524017946096137, 0.033736237382981926, 0.05856156327354256, 0.02094057428621454, 0.0477361445518909, 0.020742196356877685, 0.017950344408745877, 0.033098149942816235, 0.022643283700745087, 0.030385279205802362, 0.011104277000413276, 0.18294182169483975, 0.05215911092818715, 0.05197837199375499, 0.033090116194216534, 0.02255276580399368, 0.024086794328468386, 0.030598028824897483, 0.01065139715137775, 0.03275158924225252, 0.06041022345016245, 0.030182793489075266, 0.05596174203674309, 0.042169042499153875, 0.07198784966021776, 0.07399170033750124, 0.06490567539003678, 0.020623890595743433, 0.006990175788814668, 0.04989592045603786, 0.03379714544280432, 0.03023715951712802, 0.008679928232595557, 0.04975297910277732, 0.01531806812636205, 0.052393410660442896, 0.05603051686193794, 0.05952124185569119, 0.05627973376249429, 0.08437181561021134, 0.013500460336217657, 0.018756374302029144, 0.027487665647640824, 0.05225616157986224, 0.04572158468363341, 0.07897083589341491, 0.04099957732250914, 0.04185708072327543, 0.01963248705578735, 0.027885232302651275, 0.06014896520355251, 0.043486068898346275, 0.09664359109592624, 0.04507625017140526, 0.020099303510505706, 0.03202631800377276, 0.06588064221432433, 0.0026122190456590033, 0.010218545085081132, 0.008820643142826157, 0.013984129109303467, 0.04369117996247951, 0.0202141694171587, 0.02044676035438897, 0.03237573226215318, 0.02395073082880117, 0.03097721990343416, 0.03077538356592413, 0.03399668668862432, 0.02549925720813917, 0.04687155735155102, 0.06379278042004444, 0.030437127497862093, 0.051829330186592415, 0.04854303719184827, 0.03011565324413823, 0.017882185566122644, 0.021814352985529695, 0.03981310954259243, 0.0517808864969993, 0.03268308530095965, 0.006662703126494307, 0.013203450052969856, 0.01512132199422922, 0.013227523468231084, 0.21158042480237782, 0.06702993952785619, 0.0898722505371552, 0.10283621231792495, 0.16663864807924256, 0.16133141645696014, 0.2048007573466748, 0.09560586084262468, 0.13182595517719164, 0.13872239214833826, 0.10021421941928566, 0.12151670016464777, 0.14980860898504034, 0.16407491377322003, 0.10678380713216029, 0.08538581940229051, 0.20595913112629205, 0.1573924528202042, 0.1183112159196753, 0.18197489232989028, 0.23374215670628473, 0.09758007756317966, 0.08502743628923781, 0.15363694808911532, 0.08273061539512128, 0.09723495662910864, 0.16813150781672448, 0.1292727148393169, 0.1361299812560901, 0.1384733570739627, 0.18154325924115255, 0.18073062237817794, 0.12455728661734611, 0.12550965504487976, 0.11270011935266666, 0.1694200691417791, 0.2490964054595679, 0.23598516447236761, 0.089956217125291, 0.15593339048791677, 0.16678326297551394, 0.14624909061240032, 0.18617093592183664, 0.09232838085154071, 0.13451451872242615, 0.14153312804410234, 0.11932220659218729, 0.11914731207070872, 0.13617465854622424, 0.08766865823417902, 0.16214559698710218, 0.20722899032989517, 0.11554411830729805, 0.11049644541344605, 0.09565470900270157, 0.1402351859724149, 0.12479619879741222, 0.09785412301425822, 0.20368664525449276, 0.09376381320180371, 0.11805166461272165, 0.1367525986279361, 0.15658097370760515, 0.1914578178548254, 0.13136226130882278, 0.09779204236110672, 0.19243455841206014, 0.1359456911450252, 0.19659177283756435, 0.07494579054764472, 0.14743756590178236, 0.091091717913514, 0.10887160213314928, 0.17943995335372165, 0.08851069898810238, 0.2050278100068681, 0.07185273425420746, 0.14932303660316393, 0.1563816625275649, 0.1915234830812551, 0.121391737338854, 0.1092442567460239, 0.18059019319480285, 0.12515550217358395, 0.17444369645090774, 0.10436686963657849, 0.17745536140864715, 0.20121101872064173, 0.09665150981163606, 0.09522579217446037, 0.1261531564523466, 0.13401113479631022, 0.08166820131009445, 0.11253065735218115, 0.12159951642388478, 0.17415958747733384, 0.13501325680408627, 0.11810925527242944, 0.08497892951709218, 0.07044749247143045, 0.056516772019676864, 0.09873354574665427, 0.19301169697428122, 0.1886004305561073, 0.12183129656477831, 0.1732478293706663, 0.114014017599402, 0.16765855194535106, 0.09240886676707305, 0.12834063672926277, 0.20846071798587218, 0.15002129366621375, 0.15060874808114022, 0.197028779075481, 0.16056972061051056, 0.1770780238439329, 0.18332704086788, 0.2071631618309766, 0.06319305088254623, 0.10875872147153132, 0.18661269190488383, 0.1493435792508535, 0.0976331188576296, 0.12303407303988934, 0.17373221431626007, 0.09228059396264143, 0.11678383889375255, 0.21176792099140584, 0.2588996716076508, 0.1654728379799053, 0.23338611877989024, 0.08893397549400106, 0.15171190607361495, 0.05691521997505333, 0.11182949849171564, 0.08141676167724654, 0.12682843662332743, 0.11234112767851911, 0.2004048236995004, 0.12723709281999618, 0.16115809528855607, 0.13906455191317946, 0.17863461922388524, 0.15275028941687196, 0.1162143073452171, 0.11132239640573971, 0.08249516162322834, 0.1848189061274752, 0.10107843554578722, 0.1154738591867499, 0.0668397122353781, 0.06522061317809857, 0.11335939139826223, 0.16887511010281742, 0.06531830949825235, 0.08245257718954235, 0.10334747785236686, 0.20732918026624247, 0.14778719167225063, 0.21588215022347867, 0.09076888367417268, 0.11585706713958643, 0.1496412992128171, 0.09781763903447427, 0.10981930245179683, 0.1553165024961345, 0.09316475159721449, 0.08730845685931854, 0.16210636706091464, 0.2653271157760173, 0.12810979911591858, 0.1016381559020374, 0.0897979541332461, 0.1027300555142574, 0.1281931868288666, 0.11475329316454008], [0.017139373667305335, 0.04265016570570879, 0.08412918527028523, 0.037405549082905054, 0.03556205796485301, 0.03175327816279605, 0.060736519808415323, 0.04422144447744358, 0.05200164574489463, 0.02481123807228869, 0.03331749168864917, 0.016303980701195542, 0.06128049179096706, 0.04322330038121436, 0.04127232030441519, 0.03217239493096713, 0.016230025685217697, 0.03482686421193648, 0.024284838291350752, 0.0231396116578253, 0.03513343799568247, 0.047266710171243176, 0.0700686928757932, 0.03948981517169159, 0.033027512326953, 0.03788353300478775, 0.050558665752760135, 0.046843849268043414, 0.03869242573273368, 0.044061864173272625, 0.051406161292106844, 0.027932592456636485, 0.06301610061200336, 0.08269058394944295, 0.030109764302324038, 0.04907774717139546, 0.06282142785494216, 0.008213306591642322, 0.07150963196181692, 0.03977291482442524, 0.04770756815560162, 0.041791411786107346, 0.07439746957970783, 0.06046941714885179, 0.046193531234166585, 0.018722441454883665, 0.04300853768654633, 0.007538217523688218, 0.04889110445219558, 0.04057566256960854, 0.017606702203920577, 0.0455005990806967, 0.009013346425490454, 0.03760281564609613, 0.028247168447705917, 0.07279358454979956, 0.09065454840310849, 0.03117936423223, 0.012562345782498596, 0.03321324962598737, 0.0423068519012304, 0.007282521210072446, 0.01758998532750411, 0.042411743343109265, 0.037005379344918765, 0.04435136113897897, 0.04357477409939747, 0.040749722174950875, 0.029762663689325564, 0.034496734660933726, 0.02403395155852195, 0.17121165816206485, 0.008377901031053625, 0.03197781494236551, 0.02600265412183944, 0.0715562239929568, 0.1051325656590052, 0.032435987232020125, 0.051888690868509, 0.01493019299232401, 0.031041348884173203, 0.009290234302170575, 0.05980710600852035, 0.050632145794224925, 0.022946736753510777, 0.06566318552359007, 0.026360552983533125, 0.08268658377346583, 0.055473650063504465, 0.014649196400569053, 0.06286534815444611, 0.05094284220831469, 0.03300980097264983, 0.07471879725926556, 0.03442108383751474, 0.04740795942780096, 0.037864363330299966, 0.04400398407597095, 0.09324949001893401, 0.001981158120543114, 0.03934848056815099, 0.06145134902908467, 0.03261245510657318, 0.05067912003141828, 0.02055281696812017, 0.040978856559377164, 0.015300220402423292, 0.07768031529849395, 0.030880495796736795, 0.021717428498959634, 0.054427841532742605, 0.042916043821605854, 0.05449056043289602, 0.016703890687495004, 0.009390894574607955, 0.02281274755659979, 0.008386942245124374, 0.07094350687111728, 0.08247493809903972, 0.05132413542014547, 0.007145482713895035, 0.03472747950581834, 0.07757984334602952, 0.01126584347730386, 0.09024431143188849, 0.02527338085201336, 0.05088509569759481, 0.022580930308322422, 0.07329572166781873, 0.0668992027931381, 0.025024672322615515, 0.06823614472523332, 0.030067207699175924, 0.023031482596707065, 0.02546919095038902, 0.08012051170226187, 0.07747639538138174, 0.07326315622776747, 0.034790250356309116, 0.059275071471347474, 0.030919959499442484, 0.05929684608418029, 0.03706732270075008, 0.0580470100248931, 0.01574657955643488, 0.047924650061759166, 0.01661180314840749, 0.02858046140318038, 0.0063396170207852265, 0.057317608734592795, 0.07472998142475262, 0.02671152204129612, 0.040300652326550335, 0.019163336546625942, 0.13183563278289512, 0.0190586399185122, 0.029224960999272298, 0.02136862836778164, 0.10257433066726662, 0.09608673542970791, 0.04218880960252136, 0.027299278881400824, 0.005807494353575748, 0.10731186746852472, 0.010867530036193784, 0.042343291352153756, 0.03326446152641438, 0.04627029898983892, 0.006935543979125214, 0.021802500887133647, 0.02735690664849244, 0.07245010376209393, 0.012727820594591321, 0.019750028404814657, 0.05151709010533523, 0.11021946105756797, 0.07043370336759835, 0.02360354486881988, 0.03744247092981823, 0.07612049899762496, 0.04777273614308797, 0.020813184637518134, 0.07703293245867826, 0.04906939801003318, 0.07190552321844734, 0.008247629994002637, 0.061332249169936404, 0.01453985207263031, 0.03715262144396547, 0.06444797065341845, 0.06982178776524961, 0.05164763759239577, 0.002800088163894543, 0.05790645467641298, 0.04055953941133339, 0.03611035295762122, 0.08888103810022585, 0.02730704360146774, 0.015021076396806166, 0.03311414322524797, 0.034849314179155044, 0.06718839547829702, 0.10241620868328027, 0.027452630711195525, 0.02483518903318327, 0.04274911625543609, 0.039223595667863265, 0.024103145697154105, 0.019312751282996032, 0.02744385852565756, 0.032142909403773956, 0.029031486810708884, 0.04241827795340214, 0.060883283222210594, 0.0925593520514667, 0.05417103246145416, 0.015264099147316301, 0.02678494271094678, 0.07978949157404713, 0.016533927737327758, 0.02196920209826203, 0.03868697094731033, 0.018012287764577195, 0.023257436878338922, 0.036202431219862774, 0.01095580200853874, 0.0068268263021309394, 0.035066047275904566, 0.029440345242619514, 0.04435550974449143, 0.02145219419617206, 0.02019482162722852, 0.05586802362813614, 0.035771989278146066, 0.03938479014323093, 0.053851129705435596, 0.07037097704596817, 0.02848354990419466, 0.07128028606530279, 0.05672587954904884, 0.03246327971282881, 0.04252695805917028, 0.014906621454429114, 0.0443235788407037, 0.05248931469395757, 0.021498240748769604, 0.05291170804412104, 0.15467629622435197, 0.05142206551681738, 0.03752869364689104, 0.11427572855609469, 0.03830549219856039, 0.05638915972667746, 0.014732839226780925, 0.042953982410836034, 0.041975980202551, 0.014792927213420626, 0.022949100493860897, 0.07926660400698893, 0.023920649728097487, 0.04693982751632575, 0.06758740375516936, 0.020084553325432353, 0.08722313956241123, 0.05075979519460816, 0.05338493479939643, 0.03039644110685913, 0.03989187738625333, 0.021767811049357988, 0.02629077440360561, 0.025777699884201866, 0.023456399248971138, 0.08598985339631326, 0.03211246650607791, 0.06902728157001548, 0.022214845557755325, 0.015815795959497336, 0.03476047539152205, 0.009717010034364648, 0.028500986663857475, 0.06957178047741763, 0.017731106563587673, 0.020295147005526815, 0.010274276664858917, 0.050431569252396, 0.016404957314080093, 0.017977766765397973, 0.05470641037391033, 0.028598540120583493, 0.04001720757514704, 0.07474429003195837, 0.03231649403460324, 0.08289799196063541, 0.05063273580162786, 0.027024118353438098, 0.02825783310981933, 0.053250361161190085, 0.06830952828750014, 0.0354900214006193, 0.027682752152031753, 0.04433865557075478, 0.04739251533464994, 0.01941122129210271, 0.0339083636936266, 0.011236882091907319, 0.08349158393684775, 0.06221570176421665, 0.006626882441196358, 0.05086171062430367, 0.03329365761601366, 0.044954048134968616, 0.0832852371968329, 0.01522981470770901, 0.01866333681391552, 0.01290843521928764, 0.05069260856544133, 0.03888599268975668, 0.03931816012482159, 0.04324326044297777, 0.029461806298058946, 0.017404107020411175, 0.03209973125194665, 0.032806905219331384, 0.05404506402555853, 0.06958534693694673, 0.018324613192817196, 0.025186419698002283, 0.013347912808967521, 0.017883770051412284, 0.053333043833845295, 0.061011114448774606, 0.01126079965615645, 0.04398812809085939, 0.01887673952296609, 0.05015870381612331, 0.0407172717677895, 0.005886507569812238, 0.06290202509262599, 0.025452017653151415, 0.031948014002409764, 0.046035646737436764, 0.06508330843644217, 0.010189456606894964, 0.05163820860616397, 0.025462311241426505, 0.03244717139750719, 0.01727622569887899, 0.04111010166525375, 0.03464742774667684, 0.014982284337747842, 0.08401568120461889, 0.07804489534464665, 0.09720168614876457, 0.13689347309991717, 0.1958908440428786, 0.16386720148148015, 0.16814626171253622, 0.1311346297734417, 0.22429164819186553, 0.16632776241749525, 0.20590244588674977, 0.10937180966720916, 0.14261739095672965, 0.15187943849014118, 0.14295414788648486, 0.1568609118112363, 0.13630690926220268, 0.11925889397389255, 0.06503835655166768, 0.1765631217858754, 0.15868430928094313, 0.1055316926795058, 0.17532036581542343, 0.16410516371252015, 0.1253021357115358, 0.20722854504128918, 0.11536432561115362, 0.09740226640133187, 0.16886994475498796, 0.1518390656565316, 0.07828526955563575, 0.12126466681365855, 0.1304978522239253, 0.13278951519168913, 0.1603316396358423, 0.1747937229811214, 0.11448290650150739, 0.21647668472724035, 0.11515791207784787, 0.12989926559384912, 0.23546769458334893, 0.08943159293266945, 0.13001967163290828, 0.09512027361779474, 0.25112047966104, 0.12684170622378588, 0.1233689597574994, 0.11429638252593577, 0.09648411098169163, 0.12357707280898467, 0.10800565680256113, 0.17539278458571061, 0.09947114405804314, 0.07513084507081658, 0.1170668717531953, 0.1346932427259162, 0.13825167756294832, 0.17875934456242248, 0.16604865551926196, 0.12939650507178158, 0.089263622649014, 0.12968778319191188, 0.20320111740147695, 0.14337878994410858, 0.1805755283567123, 0.1475584617583081, 0.09264433538191952, 0.1608125216444023, 0.21403274789918214, 0.1930619403719902, 0.08829734637401998, 0.08590107769123279, 0.10151663664146326, 0.34137436479795724, 0.1276134655927308, 0.08893580117728561, 0.13418061163974926, 0.21273562218993902, 0.1568171102553606, 0.17046799650415778, 0.12885225849458948, 0.1308845408493653, 0.09847579785855487, 0.07725279370788485, 0.15601063321810216, 0.06353389704599977, 0.11817728052847087, 0.1400061443564482, 0.09312393347499892, 0.15108756691915914, 0.13532148557715118, 0.13856651145033538, 0.16786121763288975, 0.13916589959990233, 0.14851409563561901, 0.17302845051744953, 0.1352241454878822, 0.1356811451842077, 0.15731942548882216, 0.14803336205659434, 0.19052459683734924, 0.09628284053178504, 0.11179967157659121, 0.16064236202510074, 0.15220920438878238, 0.16801427816972136, 0.13892231188947335, 0.14302254421636462, 0.0905896550102625, 0.13542566826799884, 0.12734525342239067, 0.07643945922609419, 0.17775938962586224, 0.11578424760955386, 0.15425114950630814, 0.1503512673662044, 0.10441791455377825, 0.18728883296716958, 0.15622183360392228, 0.1380651313229464, 0.27168378874193877, 0.15347343811299652, 0.13925234496127814, 0.10356376937124878, 0.10264199969242327, 0.19200909999199212, 0.17570508032804355, 0.1135428057750687, 0.10246961363009177, 0.146665153442882, 0.1454661544994451, 0.1430683644139208, 0.10445298845297657, 0.15780698682647198, 0.20780841470696032, 0.08320583481690846, 0.08725965322810225, 0.15973278583260253, 0.126931446720846, 0.13109311403241009, 0.11549311791895889, 0.2580903744092211, 0.20306980179157108, 0.2203140186611563, 0.09690573991974816, 0.1039187831338495, 0.14738131110789254, 0.1750039288890548, 0.16119336214615032, 0.16487975808558986, 0.1339548800024204, 0.0899986011791043, 0.13062195415841416, 0.11069138534367085, 0.1260170465684496, 0.12617951753782108, 0.15095015085535124, 0.1075545942876488, 0.11309563953545876, 0.12434397853212431, 0.15195985761238262, 0.20159462001174688, 0.09748659664182924, 0.1572933018906042, 0.10766521882032976, 0.19271606986876577, 0.15824332513147965, 0.18098124564858153, 0.11576576813240536, 0.12140962309786119, 0.08596591171226464, 0.0733960303477943, 0.07468565294402651, 0.16698818479198962, 0.13825966307194903, 0.10561686896835454, 0.18323142256122082, 0.21901202446315438], [0.016259650365100242, 0.010153172079299111, 0.04523912561126053, 0.0012727483613161894, 0.06048016715794802, 0.021615303412545472, 0.08009475917788222, 0.02879416468203999, 0.07897158546256833, 0.02859499079931993, 0.019127030682284385, 0.02838890752173029, 0.010221122192888288, 0.035383890572120436, 0.07183793582953513, 0.04509240672632586, 0.02693460977752693, 0.0456581792968791, 0.06625219102716073, 0.021511155973712448, 0.0328726335283136, 0.03599269657570403, 0.055832667712820694, 0.05889154810574837, 0.010621617548167706, 0.04436655290191993, 0.06558920082170516, 0.03613317028793972, 0.01946103795489762, 0.03036494250409305, 0.03057704645470949, 0.0033866983858388267, 0.015315080054278951, 0.028935697810084093, 0.07714156061410904, 0.02315066409209976, 0.01309418828896014, 0.058369476901134476, 0.007077974642015761, 0.07051625245367177, 0.057820669826469384, 0.08081709893303923, 0.018489733629394323, 0.04730490851216018, 0.11436805172706954, 0.05325871032255236, 0.015709043582319282, 0.02595016201667022, 0.057110334309982136, 0.030103313183644786, 0.04283398455299903, 0.03644857191829942, 0.03585523598303553, 0.02305200669070473, 0.050551147796795703, 0.031965584348654374, 0.04363671745522879, 0.04406627624121029, 0.0024942261461546877, 0.01282744557101978, 0.01718864299618872, 0.07708520934102125, 0.0440560271817958, 0.09036266914336011, 0.06270868077990599, 0.07229238253785297, 0.021371392867877148, 0.02405834038654575, 0.0354037949728081, 0.04587458955938928, 0.05564494516875129, 0.07294005481526256, 0.06549275873112492, 0.03198420112312306, 0.02610280324006453, 0.02867512605007505, 0.06225074968824629, 0.07805865476257168, 0.053011434138170443, 0.037127996984054334, 0.031249255989678204, 0.020714929851237684, 0.018038932721538004, 0.03684248906210996, 0.02551885732827941, 0.12353524536592886, 0.03968305558373686, 0.013621551934193121, 0.03233624629501719, 0.03917476977221668, 0.05204030792810954, 0.05627204882330261, 0.025574911742296536, 0.0347442409110954, 0.048962907239911146, 0.04862980538746342, 0.013315111737028928, 0.02077372464555083, 0.043421012233011425, 0.050932029116665944, 0.026461171510163695, 0.049314970965497196, 0.07363705022726208, 0.07679281057789922, 0.022072898682381492, 0.1017397633404471, 0.03971537611505482, 0.03605605372285936, 0.04134830509428866, 0.05628418664855417, 0.02509332654881291, 0.02222949555289233, 0.0996077734453138, 0.042431974288774654, 0.05424036760814488, 0.06650056559010409, 0.051070862682536244, 0.1068753658910282, 0.02026549820584478, 0.05841779442562256, 0.006135182702564634, 0.04375270400487352, 0.027218700197408907, 0.07320943957893178, 0.041785741777857766, 0.08948776609031484, 0.10522706332267262, 0.06178550102049485, 0.008103257223410765, 0.039432191115338355, 0.013040984649705933, 0.022215411445358768, 0.038626099994871765, 0.04523783798504155, 0.02411020908766659, 0.05511997216672171, 0.03065866414544871, 0.05322243785485625, 0.05247611188679002, 0.01475880975704058, 0.025170517328660935, 0.056534984323661774, 0.009590959962224588, 0.07657116817426868, 0.030378503397514578, 0.06186000522575341, 0.059627391237881966, 0.025749229243956506, 0.030554804288840387, 0.09098348309635185, 0.09862747800070792, 0.04741182230645791, 0.02458912811562186, 0.059432072812342085, 0.08922905341023579, 0.07008199958363548, 0.05221759216510691, 0.06203887394804042, 0.04545980322291143, 0.030844334651192185, 0.05019401891331654, 0.05406576623499859, 0.035600196933955885, 0.0608967383595882, 0.07422921727993526, 0.030738847635802813, 0.01975968374608783, 0.013711977062484948, 0.03279434436990414, 0.059980419755447656, 0.04932183583150618, 0.05439430016849656, 0.04210121762298513, 0.08609671524027362, 0.028476336228777654, 0.024182694651244674, 0.010507159822736867, 0.015809296601219103, 0.0354919027449796, 0.02296181904966943, 0.022811838425695896, 0.04921550462313462, 0.0446850604203064, 0.011627035619312664, 0.034675228598644026, 0.07966984252561815, 0.053930725043755956, 0.04905731955659576, 0.016538271156605333, 0.030150209495332092, 0.034168308338848874, 0.024688525809324346, 0.057815185355138965, 0.04469653402338736, 0.0471233346615918, 0.0035496962800607434, 0.07719124740106054, 0.035226533000241034, 0.06663802618277259, 0.048329098281101324, 0.014781792215217138, 0.05182000881177373, 0.014556948372046463, 0.04583385307341814, 0.010652363798726583, 0.05976565706077963, 0.08558083354728296, 0.024852544156601653, 0.08673433883814141, 0.030279278253146913, 0.07279624143848196, 0.034056971344398335, 0.029094018318573944, 0.0367977969290223, 0.05268265900667757, 0.010350584288971731, 0.04693739698268473, 0.06642453256063163, 0.02277950490679359, 0.06722769219777547, 0.006068856964702718, 0.021414801085484214, 0.038017208644305356, 0.06712343529216014, 0.0012648842630369472, 0.05739488115068525, 0.041673198793432675, 0.06151411616883706, 0.056346679193666205, 0.0369055567716714, 0.050372987825539894, 0.023980691330507398, 0.04442727913556155, 0.023136106865422335, 0.01064300717189326, 0.04686927895818371, 0.028084853329346515, 0.04069041715411004, 0.02877334558434086, 0.10024343777331524, 0.11121678879135288, 0.03662752598756924, 0.020134529549977742, 0.03845922808977775, 0.037355528329499066, 0.04879561973211821, 0.0774714452563785, 0.07652015294297598, 0.05490268988069147, 0.012983594369870843, 0.04536339452897664, 0.024034406123973895, 0.04065383298438974, 0.05193071126996074, 0.05973598228592891, 0.01740615534799872, 0.0328917549632024, 0.02820091223838972, 0.05101052978716325, 0.01257719337445451, 0.02553044781961944, 0.08400440055993386, 0.053217758613754995, 0.01782435370841995, 0.038035420948290266, 0.0635906342358794, 0.04622928048775066, 0.046047261348576285, 0.029327792981348466, 0.029647346927959006, 0.020735060606966726, 0.041002783400472254, 0.005722378828068031, 0.03755316596652847, 0.09362403710838407, 0.02993103102198802, 0.0019592663875300786, 0.054235291318036616, 0.02026267618930433, 0.02734031222644262, 0.011635313348961063, 0.07216880010673776, 0.00861592448927695, 0.03961947208154015, 0.10632287405314855, 0.04855129729548935, 0.05126535732415505, 0.055105036444729194, 0.046234661058406346, 0.006343766553982277, 0.048053037899080664, 0.0372884827083908, 0.03682558664877433, 0.060485421563498676, 0.0200998360014637, 0.10362925648223609, 0.027164592065673787, 0.024532303723390214, 0.01632065304875141, 0.018487603665562347, 0.04289356787921861, 0.04503581425524317, 0.004563402981148101, 0.005209765831750701, 0.02506157376046758, 0.07949197199195623, 0.018279210453329142, 0.043941380208707415, 0.07377597285085358, 0.04074510230566375, 0.027985014057776425, 0.02151567936380161, 0.05401199763582554, 0.04237426859617699, 0.04962733721185941, 0.07215671794256195, 0.043589398119365796, 0.05241002363618463, 0.015754182859382126, 0.038623654618277214, 0.029029926445218734, 0.06056766265828628, 0.031661203611292876, 0.06325991096673533, 0.06330400196020491, 0.06830456331954338, 0.18405854614684358, 0.04108077941054944, 0.022360085713444278, 0.033157169236801565, 0.03708678181283176, 0.04868685056862887, 0.02683577054995112, 0.03627348814916331, 0.04002409099484794, 0.08059233208769001, 0.02345860528293997, 0.045888953827670775, 0.02089122517645592, 0.021387148663052358, 0.08425166190136224, 0.035030676517635584, 0.02895652432925999, 0.026624757556419354, 0.08880503475666046, 0.032318130470230244, 0.09371005944558419, 0.02626369157951558, 0.026332147281209473, 0.0239446823252365, 0.018216098214907106, 0.04632216026948299, 0.08057855040533468, 0.2267209201818332, 0.09959660412278026, 0.10402453175629489, 0.14053851657081395, 0.12149994247010909, 0.181204320397228, 0.12975880672456697, 0.18063800234813243, 0.18121217231964692, 0.10985543020069599, 0.13422806456219405, 0.2099982401705347, 0.10942163746221922, 0.2288882140419446, 0.14456929871812463, 0.1253600826021284, 0.1457096976810135, 0.10938867868389934, 0.12585362565005198, 0.21742185432231054, 0.13816777034662664, 0.15515076607698575, 0.12389463037834503, 0.08783236116869375, 0.15463163377717137, 0.09119312497205101, 0.19943900755606592, 0.09645655503845774, 0.14056749001611024, 0.1295887806918472, 0.21511686238227412, 0.13586864137323573, 0.12446615088265389, 0.23910810705274343, 0.13142905459972098, 0.07644250203156844, 0.19725654419744387, 0.1383821025956422, 0.18975113052874804, 0.09932618035236374, 0.1841086262720637, 0.04934553631755989, 0.19399376615183428, 0.19059467042097822, 0.111878109164536, 0.19034472992643714, 0.12889650533907115, 0.10961158273858018, 0.1770563976606354, 0.1336254258058034, 0.10363698966102675, 0.14975726720876992, 0.1147752013639547, 0.12984974950086325, 0.08268574514659122, 0.16975923063000664, 0.13949458196293563, 0.09794624580536038, 0.11292599941953085, 0.13288980902871117, 0.1530414042645134, 0.12081103646778502, 0.17323119041975588, 0.15529256081208587, 0.21850797260412946, 0.11212391589651816, 0.1036511201527901, 0.1058388601813931, 0.10336494800867513, 0.1811875033308752, 0.19376787124201655, 0.13279582344694063, 0.07643312128493562, 0.1259141106856987, 0.08397944213356823, 0.19522877410054207, 0.17225391551619396, 0.12555097782751545, 0.10832244253833778, 0.1272230810718611, 0.09869470173725858, 0.2174976424430497, 0.07154305087169632, 0.131870053592138, 0.14186368061928079, 0.13713438907871023, 0.2469195082085207, 0.10367010429035872, 0.1501284894766286, 0.15521702502155676, 0.11901967751327902, 0.11910379253095016, 0.1377802505157888, 0.1682344585424289, 0.1004096565884538, 0.15444924356415868, 0.15413052082294598, 0.1853149279486388, 0.15364030259661376, 0.1088658430671785, 0.08749705884838477, 0.15642396494513378, 0.2106412369175814, 0.06095071104937233, 0.2007516144658439, 0.09660880663432181, 0.15434608503710479, 0.1925677590770647, 0.15461521747056395, 0.19512566010234877, 0.14865130389807746, 0.35096959210932255, 0.10069447802379727, 0.0982662673050072, 0.10319107022951357, 0.12051431098370813, 0.20057479036040604, 0.14655786857474595, 0.22010534157743677, 0.16462147585116327, 0.113567838416202, 0.12887161370599642, 0.24726650677621365, 0.1002508369856514, 0.17742448806529865, 0.12506886385381222, 0.28101400996092707, 0.06849617100670002, 0.23482205579057336, 0.09179715896607377, 0.1368652714882046, 0.14492670219624415, 0.17358685727231205, 0.11983169839368202, 0.13603690109448507, 0.058934507324011065, 0.10297643369995058, 0.1761139146401547, 0.17418269795598462, 0.16017457150155678, 0.21943127852864563, 0.17259223095607013, 0.21941713319392875, 0.0836444144078996, 0.24250583723187447, 0.12814610498026013, 0.16460599465062842, 0.10221480464679189, 0.21979062643367797, 0.32290239818394184, 0.0998454685031902, 0.08512819025781937, 0.1181810135312844, 0.18134402227587998, 0.154073286394123, 0.15425831865286455, 0.15750753023894504, 0.11379512856365182, 0.13686564256204292, 0.2047363092424348, 0.15869391267187893, 0.10521406831685454, 0.19641757593490183, 0.2341749772313051, 0.09707252276712097, 0.09982930452679284, 0.1406074027181603, 0.19721801189007238, 0.13459424022585154, 0.17844372399849817, 0.1626302787917666, 0.14451247989200056, 0.12248857965460047, 0.09797993930988014, 0.16272105829557404], [0.044608604366658255, 0.028515931662695948, 0.020394008497532923, 0.031770599889568985, 0.041501384184812196, 0.04854459570196923, 0.020345791162981186, 0.037515557633014396, 0.012123578799219104, 0.013681231739610666, 0.0023216408635562402, 0.06709282912197523, 0.019856380022247322, 0.03782880332437344, 0.018816853771568276, 0.07891404675319791, 0.05854666465893388, 0.054181789892027155, 0.01526721338450443, 0.019685892002598848, 0.04329086179495789, 0.011957243095821468, 0.03376293614564929, 0.12681301479460672, 0.029274111584527418, 0.047073788882698864, 0.08298272296087816, 0.036561300439643674, 0.021197728456172626, 0.025537190231261775, 0.01159154797278461, 0.0432094593270449, 0.06823251562309451, 0.022838509357825387, 0.02993026289914269, 0.03814708448771853, 0.07610895860125311, 0.01431088652680046, 0.06332215489237569, 0.02119398061040556, 0.036923156803823076, 0.048602256865706295, 0.06402222279575653, 0.054720934203942306, 0.03569942207832355, 0.00707702979525493, 0.05701884605514351, 0.04514967826253269, 0.043235278644715436, 0.0557630839466583, 0.04109119174245279, 0.01175655059341807, 0.016890039878489915, 0.04808808953384869, 0.01790811620594468, 0.0313523254590109, 0.04255993910192046, 0.04028726398246363, 0.021993214286339935, 0.01394950977555709, 0.02092982056637993, 0.03712666111823637, 0.03658652232843451, 0.025881255460262764, 0.03469035727903247, 0.06550111531396396, 0.05928975857386831, 0.032956217910395935, 0.06564571536728181, 0.015720808478363324, 0.037582425138680264, 0.03677984437672421, 0.024460064923914615, 0.0634333211928606, 0.043806160902022384, 0.026871454865613487, 0.04053822121932171, 0.014588856083719293, 0.03270940556831192, 0.048760634890641086, 0.04022956571134273, 0.029107597765687387, 0.014612168797611957, 0.052902635288774036, 0.019909942675440107, 0.019761618896154687, 0.07579077762784436, 0.050295893524889834, 0.05107563469209708, 0.03329891202156432, 0.019524124218150973, 0.07990623882506043, 0.026825810928130522, 0.05503402775502764, 0.035652514634421095, 0.04215788430883549, 0.08023024565773085, 0.016134581783262547, 0.03363827388966456, 0.00905194738152204, 0.04321413485740777, 0.024756096499913838, 0.013465653610182926, 0.022011999899405055, 0.023876202503743116, 0.027752706992032472, 0.02498965408449294, 0.02456561131111812, 0.010691551979107317, 0.03049736205866793, 0.0015253455126185145, 0.018391445446468424, 0.04675105483329389, 0.06269155943300575, 0.04215038119582459, 0.04234490181261208, 0.0772618998598773, 0.02619092399982037, 0.041040621799766086, 0.05820549195050262, 0.08712166571058333, 0.053582869295496494, 0.05617189599433914, 0.03481436644506175, 0.024092095118248835, 0.06867795265861787, 0.08903704496333376, 0.033064526942325756, 0.04687645923695527, 0.01269713928195415, 0.058403259463375434, 0.013968814891995862, 0.05393499610363506, 0.00904154339878005, 0.03751141644897871, 0.02404611906968057, 0.07691701641306281, 0.027476490758999716, 0.036623143605538644, 0.060483551351353526, 0.030977064052422065, 0.0710752751911059, 0.03901967946148943, 0.010400187584309606, 0.04775113964569755, 0.06403835708624683, 0.017435024892620277, 0.013957434057374485, 0.06343473127344623, 0.022303621262835804, 0.015403079287352739, 0.03373114996065851, 0.07996471264050342, 0.009899714732455323, 0.05249055779131595, 0.05752260847657453, 0.031054262253746856, 0.04877456871327013, 0.04385654530778993, 0.06400811456842348, 0.04470218176720664, 0.10706563771236688, 0.012471612662920961, 0.035371437334106304, 0.014485508309007855, 0.0636613460665103, 0.043119199326611124, 0.05680443216988351, 0.03639029848272912, 0.039051851563272066, 0.027757126481446903, 0.022799858306825627, 0.03715301107149571, 0.042342738452134654, 0.014404476914933184, 0.04016478735138662, 0.022481918531411793, 0.056713248195592314, 0.021369975365814753, 0.03193684467987623, 0.06621719876420684, 0.03811112001130823, 0.03381836344487965, 0.0340732466429472, 0.02387791686487617, 0.007685795908400905, 0.014785239491175162, 0.05120992260344792, 0.026735489700513426, 0.0057010787259059725, 0.024181338376365602, 0.016310706414515153, 0.024289233660965692, 0.034890202805399895, 0.051214768827776425, 0.0507513977936469, 0.0595219023671234, 0.04460291580471676, 0.02764640546956798, 0.12770654575433582, 0.029681470878131222, 0.06721771031152457, 0.1363375154323876, 0.03747960057808086, 0.07857308926759288, 0.04147448875301052, 0.02685652842046693, 0.02490327551640803, 0.059117005148436874, 0.09179576372844167, 0.04930343056912534, 0.072248113428941, 0.08647346650832333, 0.10412329676910304, 0.01871664157079067, 0.05267167151032481, 0.042838526496780105, 0.035665940085891634, 0.024390317885263357, 0.01138950568929431, 0.060787234469898976, 0.04355526303697843, 0.05688012381142471, 0.06818630950874649, 0.057020638341782615, 0.12295714201172814, 0.030656508206448052, 0.007732816065981751, 0.01081454718587338, 0.011849439651996363, 0.06611589560634457, 0.04021680448204279, 0.013307312692631967, 0.017956493102246895, 0.03838437136437278, 0.04918607104627881, 0.03590909735066816, 0.020377313885546755, 0.04291481185646262, 0.06805892728152685, 0.020917604815622326, 0.07787973780068569, 0.05709161363483872, 0.05346475278201979, 0.03793018440774176, 0.027484277743496932, 0.04975585121428594, 0.030516591104969848, 0.012621699042938417, 0.08483859681291506, 0.05508539921720512, 0.016746363799029496, 0.02332736945390934, 0.08892821642803028, 0.05379886024456937, 0.04364530410384759, 0.010467570882610744, 0.04703192433225922, 0.039059503105818294, 0.019986934930784628, 0.018486750195734203, 0.02656066197232576, 0.06604225229239091, 0.03983543334470596, 0.027035065031668637, 0.022576126757485326, 0.032829318079166114, 0.06253771221963689, 0.0454765423637582, 0.07299276956473477, 0.022105133866716642, 0.05390082020312548, 0.059229811595287174, 0.009318571355834138, 0.016847991646500304, 0.03257587093685288, 0.01021624813802191, 0.03140872126095928, 0.02005068541620858, 0.030910573186702095, 0.02307109287357889, 0.0076519289268617285, 0.020510906033450738, 0.03454302983300295, 0.07304414844838902, 0.036127129205851816, 0.010066366776300129, 0.04432423935213592, 0.04757936956593767, 0.05185081907256972, 0.030263457520049997, 0.009949532322934829, 0.03333062770252582, 0.028684723874903284, 0.0344827525987057, 0.018481427141523454, 0.0335308368812548, 0.031357334955828264, 0.05362727570172865, 0.03412123391171917, 0.038889788775122724, 0.04873828511335887, 0.037903081174590625, 0.02528528119000839, 0.015986842445272487, 0.04537293112662155, 0.03293688867415767, 0.015379229444079101, 0.020310900945332833, 0.006507801599582308, 0.036702705547213554, 0.0719788993592374, 0.023569396798848175, 0.05588605781667866, 0.022859016753500327, 0.04973298193363007, 0.027731787704396993, 0.09912367793731391, 0.04883028545009438, 0.05767183582065627, 0.01992675974179292, 0.008089674065558938, 0.04218368136207573, 0.0673130688664969, 0.040484619603375904, 0.007716800055277417, 0.060374277527444065, 0.022486234120151494, 0.0339038922538748, 0.058457814739085734, 0.04618084421963431, 0.0300944352420629, 0.06544057090650313, 0.04310241565690376, 0.03406777701457031, 0.042129612193093635, 0.028387942729750648, 0.09716240427223966, 0.09427415847312659, 0.03928551675926428, 0.015053876541060163, 0.07687386794714257, 0.011069576030422468, 0.021183323369768914, 0.062133108149282634, 0.058705810806714, 0.0331757303501945, 0.04472436456126161, 0.03942223891499452, 0.06276504689594731, 0.02808909284794936, 0.031071363191585988, 0.11398539296351373, 0.13809751864755526, 0.10016096290200949, 0.07581448924611323, 0.23604864778462797, 0.10285210169968195, 0.10388324168161489, 0.08539311471395195, 0.11917013311176561, 0.09836479483055882, 0.13343222992261872, 0.17631968250498176, 0.08908800082281232, 0.08064598936471157, 0.11053736743633635, 0.15584041422698647, 0.22932747640879825, 0.09127482800977305, 0.1524766001966782, 0.09425745272892527, 0.17983813042519614, 0.11338077267282642, 0.11107842277851887, 0.3900767373852432, 0.13204576447606087, 0.17795200663385913, 0.303491466329433, 0.12426851695636287, 0.1956056070048362, 0.17445902922190726, 0.14483653125353158, 0.15658529300708324, 0.23137148469686508, 0.13845845474861562, 0.1952090923441574, 0.20670139754656702, 0.1562408177414909, 0.21507623721845448, 0.12925398303195834, 0.06570740268216468, 0.1519458755501546, 0.13113578752381727, 0.1716972008580342, 0.1066096918657422, 0.13632117334054783, 0.10736529467976652, 0.11789012132794596, 0.18817632284481078, 0.11253510281676427, 0.18980977503815666, 0.21888718038098887, 0.12541399220936, 0.0737465095880907, 0.14565810357453302, 0.09321156627265736, 0.1299225096590817, 0.15253594232490286, 0.15260580810718238, 0.16682559507898986, 0.13713517575524747, 0.11239292958634906, 0.15848263807129115, 0.14163029001792893, 0.13077649899059907, 0.13125129538821056, 0.13662490469869226, 0.21837446023710072, 0.08431548660155386, 0.18485797278117388, 0.12925074726808816, 0.15002769097918645, 0.1067933437298052, 0.09087740050745197, 0.14637580490671098, 0.12972910597454756, 0.18866760976379737, 0.15205265575787053, 0.14812218229053542, 0.13566885521868244, 0.10507369850529358, 0.11913235037354752, 0.24200724757974967, 0.08178135656635277, 0.15182178845861927, 0.19390176952583715, 0.17933064984390512, 0.20953185972757638, 0.22310336586087942, 0.2754821302369237, 0.13849496841430664, 0.14835190668236464, 0.13160400849301368, 0.0847748017986305, 0.2508031076285988, 0.1051350221678149, 0.21868748328415677, 0.1747052144492045, 0.0637261726660654, 0.06823817078839056, 0.12228713851072825, 0.07079550035996363, 0.1430614772834815, 0.08331188771990128, 0.10455990966875106, 0.07667396304896101, 0.13307463348610327, 0.21843386173713952, 0.11480444198241457, 0.15336049807956442, 0.06616792757995427, 0.05651650113577489, 0.17729343962855637, 0.25405246764421463, 0.22600759752094746, 0.09345139129436575, 0.14639453671406955, 0.21635541779687628, 0.09986946955905296, 0.19397133844904602, 0.13475619169184938, 0.1803008298156783, 0.07068595936289057, 0.2118700701976195, 0.15953274734783918, 0.1804991762037389, 0.15423848846694455, 0.16517165960976854, 0.1660819334210828, 0.15283961431123316, 0.1132045868143905, 0.14325050229672343, 0.11486926858196966, 0.12470377172576264, 0.11410123479436152, 0.13506517745554447, 0.14050414029043168, 0.12823200115235522, 0.08110246955766343, 0.10003255651099607, 0.1609978952910751, 0.09446335418033414, 0.2567273163003847, 0.14228251908207312, 0.14303480449598283, 0.07804572655004449, 0.11861749284435064, 0.1574862009147182, 0.186908645555377, 0.11039906821679324, 0.14618545887060463, 0.18346692086197436, 0.13515490310965106, 0.1469349834951572, 0.17005135479848832, 0.1755682282964699, 0.08950729199568741, 0.12218346790177748, 0.1369250292191282, 0.11561765772057697, 0.1028144673909992, 0.11303099847282283, 0.1887289111618884, 0.1547258420032449, 0.1361732484656386, 0.05558564385864884, 0.17199061636347324, 0.07417488464852795, 0.09547675683279522, 0.2582123241154477, 0.11071502274717204, 0.06535964712384157, 0.1795888430206105, 0.13404414552496746, 0.16670927085215226, 0.12218282965477556, 0.1133335052873008], [0.02091346548695583, 0.05655654000292998, 0.06189399187860545, 0.08530890321708284, 0.03960940855904482, 0.033690884738462046, 0.026843613195524085, 0.01858728523075115, 0.09228269424056634, 0.017851538577815518, 0.008707569522812264, 0.01718075025564758, 0.025593754871806595, 0.042718914555734955, 0.046325240182341076, 0.021245086754788645, 0.022175871672516223, 0.05297803378198296, 0.007465727785529452, 0.021583010711765382, 0.02041795389231993, 0.014473582923528738, 0.09431309154024348, 0.02376854285103036, 0.04030835581943393, 0.022752854383725207, 0.08224798933952115, 0.037560186683549546, 0.053000591360614635, 0.031478245655307546, 0.009261631003028015, 0.04643782398488838, 0.058537194854579866, 0.023048566836223472, 0.029176196330809034, 0.031202767859213054, 0.04010088101495057, 0.030021992351976223, 0.031753675211803056, 0.02350233819015557, 0.022959449743211735, 0.035952835823991336, 0.06708108834573068, 0.026164475711993873, 0.019747731457755435, 0.022261461708694696, 0.01771272913174471, 0.03587573410186451, 0.019186589888704475, 0.0193598108671722, 0.048687396047171205, 0.04229687743645627, 0.06665168912149966, 0.06022550289344508, 0.007676049654037342, 0.017782006761990488, 0.05455522004922386, 0.02716775175940711, 0.029754527895420324, 0.03301443939562887, 0.012731516490021022, 0.04930593531753402, 0.04814660787815228, 0.014423253251152346, 0.011142126531922258, 0.050724287139019, 0.006859691848148941, 0.0016019503436837113, 0.02663037746970076, 0.028248001508472953, 0.0241469899265212, 0.07804704757290892, 0.13147257413947955, 0.0258387099893298, 0.04340808402048424, 0.034650188536033966, 0.07122730414266698, 0.047800251268199645, 0.026046086459246, 0.05173793470021337, 0.03342235344462097, 0.038058234567870386, 0.05281570010993164, 0.02988246673339745, 0.04321562286349945, 0.057898810555343516, 0.029598183355119545, 0.05907531129196286, 0.03455752768786624, 0.07309220993192866, 0.022759171915822662, 0.02751468724454753, 0.0424346645741025, 0.036406080253073014, 0.07835108321160078, 0.015966884238878265, 0.01887080419692211, 0.02440340194880264, 0.032984894496621564, 0.06367814086843282, 0.025505932826490607, 0.031314750522142276, 0.03687335869472008, 0.06360488347127102, 0.024287007217935752, 0.054388685821322724, 0.030118805516394787, 0.02181003183068242, 0.04138480762776453, 0.07906968996394426, 0.16393939760746434, 0.027019604240194894, 0.016839158233779017, 0.05811358438222669, 0.028638076182687655, 0.07143968454329297, 0.08782759658060968, 0.010292224578734022, 0.03771336596400943, 0.09342739765997976, 0.018921496593975462, 0.023980285004654434, 0.028588660279638134, 0.026034035836346447, 0.018369852659816388, 0.007020969351287931, 0.06185284350067377, 0.014969361691328231, 0.03256172189139761, 0.00716523868504737, 0.0903591290989425, 0.06309340271400288, 0.05590354652667884, 0.03168056995491497, 0.025956028694054112, 0.05947846446360927, 0.07075067464029416, 0.007523670037699048, 0.11828135189716704, 0.10386061359895393, 0.009898603366309544, 0.06295192710240372, 0.023161870522017125, 0.06365669280057773, 0.024623296594654676, 0.04174199217231944, 0.027261215982434805, 0.044346292270347476, 0.06024795657140203, 0.03083249739574967, 0.08019091925234534, 0.056567635110695846, 0.04687144602939952, 0.05131303289090283, 0.03211918294255156, 0.03426979332289193, 0.008892674140952295, 0.053875950834481046, 0.019067128232563846, 0.05524007021449506, 0.014128215225355234, 0.007369407685473561, 0.0444507050269749, 0.029642157460330054, 0.028309397530392744, 0.09831426199525595, 0.07322169243707322, 0.0715489657886792, 0.03554180475475732, 0.046826085963402875, 0.03206010798749048, 0.042360253137303516, 0.03326871032186318, 0.0679652756662108, 0.04637166151951533, 0.05678423462086357, 0.03762770356843248, 0.07303190301172435, 0.11288789755781181, 0.03025790811079787, 0.05950214639597107, 0.043636550472001545, 0.03708570569870062, 0.01587304152053548, 0.054815227776998654, 0.0210738621535711, 0.02893616350775119, 0.012483564951253356, 0.038573782294406556, 0.11861576364026405, 0.060873839393025264, 0.05520435435755644, 0.02563710371759953, 0.02476336212566821, 0.018386653027846478, 0.03490742434223648, 0.06160960088891443, 0.06381920829880983, 0.008316642306454014, 0.04005650800536387, 0.031677475199103355, 0.03662032715510577, 0.04455367430637125, 0.022459520514530595, 0.02509543795895297, 0.038048753631301224, 0.029944007474114187, 0.017349852314509917, 0.024094841064652428, 0.042643371343729086, 0.05910196552576963, 0.07530933900852688, 0.06785715959267691, 0.010650188378349412, 0.07359160110354424, 0.0287855093847611, 0.043529091199161485, 0.020252401154721156, 0.09638936840929091, 0.027014804400096182, 0.05088616439024918, 0.03644869437266607, 0.018934339459519833, 0.025109475682256743, 0.03084351457800949, 0.03281431185314432, 0.024604752179584466, 0.03403970527870115, 0.020477425896388013, 0.1452401705319062, 0.02003307054110337, 0.012141062870796304, 0.022355254332069308, 0.046278807712951675, 0.05934762753895484, 0.04871148616075516, 0.06191192958795, 0.044876701504108496, 0.05872362235095352, 0.060021386307198554, 0.049593417352298275, 0.03539813980751205, 0.041404893854632974, 0.026567760614852887, 0.074756631947821, 0.04569421427731868, 0.034182939780293964, 0.03813387425907422, 0.07422438589856029, 0.08076528218225576, 0.005800378085041302, 0.02059555539744906, 0.05568444597884081, 0.0507048985309666, 0.04375925345811993, 0.01794850944861537, 0.028575822980201337, 0.031231065950123593, 0.018940261797979474, 0.010234248929918977, 0.012601899470610078, 0.012664130408666097, 0.10205231883446686, 0.00878491058756481, 0.03583850426366553, 0.050763761973939836, 0.01870832209533546, 0.020153022014710587, 0.0652393746713642, 0.12833032087655738, 0.05306437895342242, 0.01551488940094714, 0.062191589386202395, 0.00898814772881451, 0.04815283449715935, 0.07588541629957035, 0.03723331887158565, 0.021869952834094875, 0.057885117930709384, 0.01204814969241852, 0.024710634388611652, 0.0409396080794977, 0.02995659986481769, 0.01924989508552244, 0.06732895824825391, 0.07878598917159252, 0.08257440073066391, 0.040649287329870276, 0.03231887261790689, 0.040974819276016206, 0.01852265344496118, 0.11216883809538558, 0.04942277904774528, 0.0387487027910538, 0.03557704192644451, 0.03609156919992529, 0.01795966578356456, 0.01431674671039218, 0.028255740253371187, 0.014496308413072256, 0.02958303983177757, 0.04729144224256743, 0.06513709930004552, 0.01866388785856543, 0.0617896941548679, 0.012934901133121457, 0.060022132165613584, 0.03835640352917835, 0.04855934588704258, 0.07492183402064256, 0.03408363671042025, 0.019135285219817888, 0.06257012180867605, 0.03802056686254218, 0.08459806675091386, 0.1220104584353976, 0.016193883093365002, 0.029336695042729843, 0.013016294324188493, 0.07100234433892183, 0.048177184362430125, 0.05177628147066571, 0.03046790250664344, 0.016497200704179704, 0.03423916488827672, 0.022657568188151345, 0.01248507336640614, 0.02860484837583499, 0.02242597172880778, 0.04437823430635035, 0.021644031949108467, 0.06332360950182192, 0.007956868594192201, 0.023118827812140808, 0.016628221310384106, 0.04662396204366814, 0.05775038473075256, 0.04301745830161963, 0.03838064207229763, 0.07043808946036734, 0.022177138889674097, 0.0595851110847434, 0.04020789128844626, 0.06030060823832173, 0.01838323543779552, 0.025709923247632105, 0.02020390922552906, 0.044581130059668794, 0.028181280576973222, 0.02497447159839794, 0.02406100098596653, 0.060684903437504545, 0.08043018024181947, 0.211563830380328, 0.17292688018642366, 0.2256683915038593, 0.09320974801084958, 0.12962665990926325, 0.12252262939000502, 0.2097487894934602, 0.16375911509385332, 0.055557319792569615, 0.1377788107492961, 0.12082362329238094, 0.10235131529043429, 0.15409273066325113, 0.1063807838363573, 0.13232429249910638, 0.08558616958907805, 0.20107351359911263, 0.14070964098209515, 0.09337354742456228, 0.12918623979203403, 0.18250307883135974, 0.10656575672328472, 0.10046678711660206, 0.12255606314283796, 0.10111954310559668, 0.19110525317955762, 0.08361148531548679, 0.1313417631899938, 0.11248112641624175, 0.1054882473545149, 0.15999210707377642, 0.11608310305746272, 0.10339383981772698, 0.12909195735119283, 0.1317792889312841, 0.1249331547296606, 0.10979841841617599, 0.16305095778079703, 0.10920141998212785, 0.11978721406194381, 0.05764257293776609, 0.18933258892502636, 0.14609061239752918, 0.11784612681367435, 0.09149149060249329, 0.1533016754547134, 0.13342611462576315, 0.09147197954007424, 0.10010151687311009, 0.16595262160990387, 0.23516633809776977, 0.1315351075027138, 0.24947864119894803, 0.0989604796632193, 0.09800267871469259, 0.13929988694144413, 0.11397394162486307, 0.12329214747296646, 0.15533041034359485, 0.12053313927026466, 0.12471239548176527, 0.1979526341892779, 0.10570341080892831, 0.11528214759891853, 0.07604038415593095, 0.10035413652076386, 0.2917422592872754, 0.18075380707159638, 0.12833986489567906, 0.14800925710005686, 0.15097719471668825, 0.32372205576393753, 0.1618304365547374, 0.11676170805003494, 0.09847514476859942, 0.14848482533125207, 0.2379974682116881, 0.11101842756033875, 0.09486832190304995, 0.11478740969323553, 0.1124534962582402, 0.22875750699313357, 0.1060048044018913, 0.09739672255818732, 0.14529418403981254, 0.20451707881875336, 0.11737720080418512, 0.14123181608738378, 0.13141180708771572, 0.1229896851873491, 0.14272871310822666, 0.1605713681783527, 0.2604810398770496, 0.1900024217320606, 0.0989296731131617, 0.2231833100086078, 0.06280913788941689, 0.19456346839433536, 0.16343107097782195, 0.12003711744910106, 0.18630992533871904, 0.1287573971785605, 0.1809056950150989, 0.13481476198649034, 0.1752399021643214, 0.1691046860651113, 0.135781335120555, 0.2093647577567026, 0.1893881757860072, 0.2531750709749758, 0.10073268378619105, 0.09384351986227557, 0.15284895052900538, 0.13403486867900938, 0.1886193107930012, 0.1464708591811359, 0.09017721386044286, 0.14136215206235647, 0.25920508021954447, 0.15380638040369377, 0.16698431078111753, 0.1407583407126367, 0.09037238385644741, 0.19837648957036436, 0.19238012930145487, 0.18580630392534658, 0.121325033105677, 0.1389664548332803, 0.08851439488353208, 0.19829345808830112, 0.11071166081819683, 0.11284848951618187, 0.11748075266950764, 0.13013071176828817, 0.10762120204162784, 0.17375438968883827, 0.08192866545869038, 0.17707840976072475, 0.2610445080790669, 0.18400404282147065, 0.11679271497996524, 0.0954763857589569, 0.1908094182726927, 0.16067360644228756, 0.1614229826373048, 0.10698928555939347, 0.1884695008629933, 0.08187546089175157, 0.11502672263304703, 0.09521052619675174, 0.15859951148740947, 0.2005466926493682, 0.08186392049537972, 0.10565033240709454, 0.15487960015889257, 0.11214899306651205, 0.10288317542290315, 0.08773665380431339, 0.1319173283991404, 0.1093529442732688, 0.13261122163385153, 0.1606583924149163, 0.13732900988543406, 0.20303021563449875, 0.15576933132251725, 0.09686592369689606, 0.13353225658647716, 0.07071347077726386, 0.09094259818084538, 0.11498617910547182, 0.09251904601114802, 0.16051429702201858, 0.3328009264077991, 0.1550377072999254, 0.14231548528186977], [0.03723752684891224, 0.025434126328036655, 0.04603940571541898, 0.053719710194855, 0.03562621663149912, 0.02792432307614945, 0.045408717487589456, 0.0031652818734073662, 0.07851889764424413, 0.11585939006181434, 0.041913717723218724, 0.012616760050150333, 0.04006253424449824, 0.02004299491090933, 0.04094623545825016, 0.017986477723752614, 0.06886003116960637, 0.07440927714924328, 0.01288285060581984, 0.024587449006503448, 0.05520806138520129, 0.008013027836568654, 0.036831130491918884, 0.03885922342306003, 0.08213428489398211, 0.08099254264379852, 0.017915845673996955, 0.056895059533417225, 0.008693933486938477, 0.021119244483998045, 0.03422049245273229, 0.05349351842596661, 0.0464748460217379, 0.04576103725412395, 0.036532542217173614, 0.02695551793294726, 0.08979331571026705, 0.06982557271840051, 0.011803265078924596, 0.022401889036700595, 0.012743931692966726, 0.03732497039891314, 0.01220977461343864, 0.10629942960804328, 0.035965389251941815, 0.03898961134837009, 0.042934167067869566, 0.017379805394739378, 0.01900487688544672, 0.04765544341353234, 0.03423245216254145, 0.030862020030326676, 0.03640475923020858, 0.04070227667398285, 0.04490953782806173, 0.030686680220242124, 0.041776205180212855, 0.01392235366438399, 0.051898297970183194, 0.02416905768768629, 0.06897877479786985, 0.12774521164828911, 0.045628062944160774, 0.045349397623795085, 0.05383356678066775, 0.12645342940231785, 0.01587440707226051, 0.016764989850344136, 0.03312792119686492, 0.010353961060900474, 0.02198829570261296, 0.037368207922554575, 0.0302679716332932, 0.02591239412140567, 0.023083672276698053, 0.02923697637015721, 0.033740449071046896, 0.06819797607022338, 0.023899086627352517, 0.021422849677037448, 0.07366515535977669, 0.03186812551575713, 0.029741942926193587, 0.06272722705034539, 0.04686593187216204, 0.047098131326492876, 0.01003361579932971, 0.023294074853765778, 0.04262193811882753, 0.03148816445900593, 0.05623073717288207, 0.09534142620395869, 0.03205582579539623, 0.036836685467278585, 0.056474336015526205, 0.023331857591983862, 0.019612476899055764, 0.06012653379002586, 0.07458645006408915, 0.005296386525515118, 0.07665052602533251, 0.033808852822403423, 0.02486887326085707, 0.04643367909011431, 0.0712660071440041, 0.043287262378726155, 0.030051819267100655, 0.024019650372792967, 0.06816780034569092, 0.019826373136311304, 0.018050992621283513, 0.06682175226160325, 0.02198036771005718, 0.012559265869640512, 0.005220234288572101, 0.03584649348340463, 0.03485697685391642, 0.034018079095403664, 0.04931737552396953, 0.03204993685358204, 0.017378092888975516, 0.016255841292149853, 0.04792018233274575, 0.1259014496463351, 0.030288521702459548, 0.04519175803579856, 0.02800462159939343, 0.03748450988496188, 0.09939202369423583, 0.034787975673680194, 0.05266892556392122, 0.07880885474151, 0.02337569068913581, 0.00665542776005168, 0.05948050908045843, 0.03839080578472931, 0.012733012845274061, 0.015055064905027393, 0.037107651005499065, 0.03762676104088314, 0.019799592737399507, 0.005383236821216997, 0.026718000990513247, 0.020419490138010588, 0.0357031513703987, 0.09338461284642108, 0.02513591283786809, 0.025619012012612075, 0.0031156653585640015, 0.002750725138866983, 0.018855504822568037, 0.07795246827299707, 0.03285947896074504, 0.10543470139964484, 0.03427704039495438, 0.029792368150083348, 0.018564638594398275, 0.04104406907572411, 0.035711704622372054, 0.025277045206166804, 0.07756894861813635, 0.031131655268836766, 0.07338605588302016, 0.043414644605945796, 0.02505286094674375, 0.09453735372517258, 0.04718604242953006, 0.05929829698288813, 0.026493913210288156, 0.057127592954202555, 0.02329226215806557, 0.023368005749944132, 0.025513037035125308, 0.0565997589728795, 0.07485017966246232, 0.03766524139791727, 0.0190480828678119, 0.06771019208827056, 0.04035069163364824, 0.024135026505973656, 0.04243775190843735, 0.024865075320121832, 0.029243102799227927, 0.03819505320279859, 0.0888161818147637, 0.06685595042654313, 0.02248122833407251, 0.06285194496740587, 0.06080116087105125, 0.008130622991302516, 0.017976252784137614, 0.043858148346771486, 0.04933870484819636, 0.055205141034093685, 0.04006536182714626, 0.012907468571938807, 0.010291600247001043, 0.060841214581159875, 0.005502595504367491, 0.03304724974441342, 0.029536842994275503, 0.14185076724970713, 0.009686961402621819, 0.03093419574724976, 0.04827099553949665, 0.02841982539393939, 0.034669629094423726, 0.053944677420076914, 0.05559610071941279, 0.04713514594186563, 0.028042669655405916, 0.051552282748161815, 0.0058511934003036, 0.08030011144001037, 0.03924682117940392, 0.03807240216701757, 0.029028469980403315, 0.026090537394338753, 0.02064876738586463, 0.037558316471404396, 0.04190690851828549, 0.044139901001472026, 0.052630497157224454, 0.027591087637119927, 0.023635639045096468, 0.04755536479933653, 0.051878126396331936, 0.03950840968172997, 0.04486038538743742, 0.06122489008703269, 0.029538329144997988, 0.01673338920227252, 0.04132451183977537, 0.021329283408704214, 0.028299554796831217, 0.024382423289353028, 0.006699093410134083, 0.04207798840070609, 0.009477001331106294, 0.01950564474100247, 0.006937581638339907, 0.011199685650353786, 0.0720209939754568, 0.03083063831581967, 0.035870576175511815, 0.03168808420014102, 0.047380960095324554, 0.014448117981373798, 0.02204552642069757, 0.05602496188657824, 0.04242302769853268, 0.015075392329890747, 0.03201427294698078, 0.06884556671138853, 0.01220594142068876, 0.007979954953043489, 0.047610131587134674, 0.08645904657896608, 0.02333689306396991, 0.060285216095508076, 0.05117906410305295, 0.014416811409319052, 0.035210168643970974, 0.07363325785263442, 0.031180095247691497, 0.008848110028338851, 0.058425843017175794, 0.013857358226232463, 0.0647793841199018, 0.01121651384892175, 0.018800738034769893, 0.05093660445709247, 0.037050639220979065, 0.03962140537623782, 0.0635744999453891, 0.04134825685468968, 0.06979291822062805, 0.0195169699145481, 0.04518717156315688, 0.061903157402412035, 0.06322580185951665, 0.024975061605800875, 0.05332092085154727, 0.006993186125328066, 0.027877922148036305, 0.03542543599905912, 0.08044553527724929, 0.030713141495652962, 0.015183304312813561, 0.08234068358433433, 0.04442543489858508, 0.04395487245346885, 0.0813576125074178, 0.06102092935179826, 0.020742886554216966, 0.0293001424142858, 0.029664401481568348, 0.012345052364253206, 0.03516871227475349, 0.08941911743022501, 0.025384665896126535, 0.05968872603261843, 0.020493628835538402, 0.02208254845754709, 0.019283354813524056, 0.002141810364264529, 0.05717784748412669, 0.06720291188685223, 0.013451542599796085, 0.09695537475636229, 0.031928955650073476, 0.030813457597105298, 0.022312308101390954, 0.0245870389699121, 0.0732606700330507, 0.08023713278817013, 0.04146713778027333, 0.021303707144397777, 0.06897543513332494, 0.022967425975366496, 0.021284641370584723, 0.04432843248650897, 0.016535063223273028, 0.039732649602228776, 0.0135165408210014, 0.022242572194954846, 0.027116768069390673, 0.08097825630102307, 0.050079279171768576, 0.0659733364591375, 0.009910948992910562, 0.01252436451977701, 0.03833934897556901, 0.018108731710526627, 0.03780727362027392, 0.02383916376857087, 0.020953008970536757, 0.03883418336044997, 0.0493799942341866, 0.08536288703908212, 0.024220232480729464, 0.029615015264425892, 0.024402949238719884, 0.13241771404864267, 0.02607095582789043, 0.029148939102014992, 0.021843144604645204, 0.05432099824247416, 0.0502748981671175, 0.031071719422470778, 0.07957622801768593, 0.050487252592574805, 0.12017010289127938, 0.2147888924810104, 0.11772100813686848, 0.11840143139124848, 0.10869659628951922, 0.15246959432261065, 0.11277295372565277, 0.14218292286386713, 0.2115315172704868, 0.12864030111813918, 0.09577075121342205, 0.1995055633597076, 0.08992216738988645, 0.09740625915583223, 0.13902299164328724, 0.1341721511562355, 0.15393575158668682, 0.20390863646753132, 0.1901717798318714, 0.09132064820732921, 0.1011085147911217, 0.12393694763886742, 0.121639837307157, 0.1510976007557474, 0.1976668628049083, 0.2914258075179532, 0.19869065552484244, 0.1158608372497838, 0.0893079511297401, 0.09052141453139484, 0.1261518502724357, 0.11978906943113543, 0.15046751737827435, 0.12986226211069152, 0.11950344647630118, 0.16944358038017526, 0.16610295104328543, 0.09575717733241618, 0.10974149568937719, 0.11522040833369829, 0.11383969453163445, 0.11422387469792739, 0.11225648573599756, 0.24820618447847664, 0.13299069658387452, 0.08363674802239984, 0.12323920265771449, 0.0961727429239545, 0.1303486805409193, 0.13395413785474375, 0.13499459921149537, 0.11789830721681938, 0.2678253629710525, 0.1618961017811671, 0.24586601473856717, 0.1787317663547583, 0.10834489250555634, 0.10960481435176916, 0.08418557365075685, 0.11927288345759735, 0.163298137485981, 0.14425860601477325, 0.11136442422866821, 0.0662718059902545, 0.14816892275121063, 0.2155550115276128, 0.13246151560451835, 0.12263082709978335, 0.1660882862051949, 0.1396417201613076, 0.13108340674079955, 0.1474610177683644, 0.0743070685712155, 0.1200468915340025, 0.1174397935392335, 0.1024995073385071, 0.11014275267370977, 0.13941995159257203, 0.12682411732384935, 0.1151144148025196, 0.2345505336415954, 0.30840012012049556, 0.0872838991926983, 0.1216397705138661, 0.1467182021588087, 0.07997081309440546, 0.055909142320160754, 0.118218684947351, 0.1623408411978744, 0.06208624894497916, 0.15633400180377066, 0.1686379939201288, 0.1886244909837842, 0.14678352599730715, 0.16754822427174076, 0.14820080541539937, 0.09160843823337927, 0.16600814909907058, 0.14850713429041207, 0.22631401545368135, 0.18317374284379184, 0.07192812161520123, 0.16318933863658458, 0.20107495336560532, 0.18976083782035857, 0.12496203911723569, 0.15091874316567555, 0.08611687197117135, 0.11966590260271914, 0.07470786542398855, 0.2734100539237261, 0.1129652961390093, 0.05532567694899626, 0.14660929940873757, 0.10142930070287548, 0.1707248538150452, 0.18050901708193123, 0.1428781371214427, 0.07107098557753488, 0.14047519653104246, 0.19330469687702134, 0.06816526220063679, 0.10617870444548316, 0.19774530781432986, 0.12402619089698419, 0.24016704788664356, 0.12411857343977317, 0.05969198406091891, 0.2869985403958708, 0.08854292304022238, 0.21156028291443363, 0.24539832811569795, 0.15029876783955842, 0.1672628684900701, 0.18839145661331713, 0.09696631401311606, 0.13821590604493394, 0.15062682679854333, 0.17431741260224953, 0.21922807849477977, 0.1735592939076014, 0.07160997774917632, 0.2361936040688306, 0.09606123523553833, 0.10355034391977824, 0.11930426146136597, 0.06689898757031187, 0.09779475120012648, 0.09292351649492048, 0.10553575222729705, 0.08882124326191843, 0.23167573555838317, 0.12766342697432265, 0.16011551138944924, 0.14225967577658594, 0.17862777662230656, 0.1286129603977315, 0.20840625918935984, 0.11808028182713315, 0.10699070306145586, 0.19557770225219429, 0.1513621912454255, 0.24376422283239663, 0.15691823529778048, 0.11517806138726883, 0.26101633615326136, 0.19608850765507668, 0.24337370472494513, 0.13780266337562352, 0.20403131347848102, 0.10626916482578963, 0.09500186395598575, 0.1248561791726388, 0.15437632013345137, 0.2494510036194697, 0.10341006316593848], [0.05263640094199218, 0.009752319565450307, 0.012832306638301816, 0.027787116669060197, 0.048219137970590964, 0.06801046503824182, 0.013057640298939077, 0.019167056561855134, 0.03116612060694024, 0.0589071888680337, 0.05437732354039326, 0.10104795554070733, 0.037266199724399485, 0.047567283691023476, 0.023724574311927427, 0.011434370371716795, 0.056673532162676565, 0.048426186040160246, 0.07030535634839907, 0.032029412759584375, 0.03880076816130895, 0.026061486023536418, 0.05578236494329758, 0.0222656882397132, 0.08172673449735157, 0.06528483121655881, 0.05342633921827655, 0.03655417211120948, 0.08126218715915456, 0.03335783854709007, 0.010151247133762809, 0.08469266089377925, 0.02196378442022251, 0.10311287755030207, 0.05480484513100237, 0.045583378232549876, 0.060368540725903586, 0.08636543949251063, 0.10025652925833128, 0.06453452733694576, 0.020597110196831636, 0.015021710005385103, 0.05816504119138699, 0.05706490745069459, 0.054292106433422305, 0.03089563560934039, 0.03906426398316398, 0.027787491453636903, 0.05019285003072582, 0.0504558931424981, 0.039306508406298235, 0.045438002634909935, 0.05142241432622541, 0.0269604662025813, 0.05018494244723115, 0.0351149065681966, 0.04002412439149339, 0.06225217832252383, 0.038027479968150146, 0.013241699416539632, 0.04777142625243869, 0.02463622295181267, 0.026015649127657525, 0.0029640956108778482, 0.06258268636884168, 0.048889816825976595, 0.06617604667553678, 0.041695979016367346, 0.021560545901593287, 0.06429909582948312, 0.029663295681530144, 0.006295558496276499, 0.04981426194717642, 0.03124872164335102, 0.006894331127114128, 0.014817443134234054, 0.01172568745460012, 0.050407750022714026, 0.016469594665977638, 0.08274919135146774, 0.01003424848022405, 0.014562566429958679, 0.031068183088791557, 0.013965357411507284, 0.045075919915689155, 0.03193262185959611, 0.0738630119303707, 0.04192984459223226, 0.057959477417171, 0.04100943675439339, 0.03645224183856044, 0.009770234082679963, 0.010456241998326732, 0.010184221682720818, 0.010977879046549788, 0.03543640865245834, 0.07903348800027743, 0.037385021278169006, 0.027771806162490975, 0.03064679905946832, 0.044971054448978975, 0.011976327423326438, 0.022748824521841016, 0.043236332494416274, 0.03412023943383247, 0.05070793762570247, 0.03269335662480444, 0.07243525338708423, 0.051252674020361155, 0.04744651399960276, 0.036338774880277924, 0.09495773585513234, 0.0358177278394578, 0.029829009836248588, 0.09475834303884767, 0.007725162668066332, 0.01652785882470198, 0.008913663932617055, 0.035586585945566185, 0.03921569550584536, 0.008518337635905482, 0.017599655511730816, 0.025695191616250668, 0.025735928102221806, 0.06634481105720624, 0.048115834724740125, 0.01782151870429516, 0.05591115725110285, 0.02187266723922221, 0.037283035344444215, 0.027222000899200793, 0.03331148029246833, 0.0549126643454656, 0.047605979270883836, 0.031876463544904254, 0.07447251555277035, 0.08478921430651098, 0.007446357267326675, 0.020182418484182563, 0.024513586758985184, 0.08540570896002464, 0.027309641118336003, 0.04592391269397922, 0.016029176404117607, 0.021262666377879214, 0.02170930012653116, 0.02581880929938052, 0.016797369753476232, 0.020417640334926546, 0.056135100312530994, 0.08170149405486882, 0.04945121814671438, 0.09437194385100156, 0.041891720466082916, 0.046703846819582395, 0.03622228738095146, 0.04558101820293814, 0.02743401022598846, 0.020728802446683403, 0.03139904736599419, 0.01279179094126448, 0.12062623427482322, 0.05359694783692248, 0.024427041207673028, 0.019729402265511453, 0.061564452335005626, 0.09994383275625296, 0.029662572087545414, 0.03559179953299463, 0.029286253120517358, 0.028683632917818613, 0.036754852553713135, 0.03138684274745174, 0.04162109631579369, 0.036582358879968524, 0.03049016508157365, 0.05132450278324541, 0.035416871614870615, 0.0655184370407369, 0.01888751365186181, 0.04666038294089958, 0.09180466207908466, 0.031255419526132755, 0.02111583060468547, 0.028725337906507775, 0.07295515752048232, 0.02103504040860571, 0.07816064069629647, 0.03739332591067068, 0.06436990413931198, 0.017278884442930575, 0.044685639295494184, 0.05737449806474615, 0.03921574003470596, 0.05726083072659094, 0.03393224600586109, 0.011268146918155253, 0.025707665263325907, 0.0459643968497403, 0.059776863490696996, 0.0587707227532519, 0.06086819164920598, 0.028581658116308972, 0.05284617640427314, 0.05332564833224751, 0.029845138560631312, 0.015746564713481348, 0.0018116374440069194, 0.030185520881786942, 0.06897849278175272, 0.021791437320644036, 0.02032661963312421, 0.037399496868602, 0.01109986957089859, 0.0643978311563842, 0.021052286065241788, 0.03744260822713841, 0.01415945314874989, 0.013342686233954737, 0.05860986224433873, 0.09960634110029787, 0.007513820810345351, 0.021998776683176402, 0.042473426947253756, 0.029397955622698646, 0.0019106779791400186, 0.03089904577791458, 0.04725965605757665, 0.01747477061144309, 0.011699142687575659, 0.048649583623046055, 0.0470545041753212, 0.02301455049746437, 0.056444074944010936, 0.10021206719102338, 0.02744240206084214, 0.011104755685664713, 0.03670889876957517, 0.021130447203177027, 0.025968416994146537, 0.033760806181817316, 0.05030635780713055, 0.08054645993979648, 0.06238727146410383, 0.006384185771821649, 0.0465480588900391, 0.04790191065694671, 0.014030407583049964, 0.03542544713127427, 0.024635733134346083, 0.08204338664654642, 0.029830518251401372, 0.05414865299826488, 0.03055857068829937, 0.07275465890415944, 0.013104159042995889, 0.04372945251816418, 0.03484555520117283, 0.05453875179227907, 0.028179438195365947, 0.04232744649925735, 0.02986776664329227, 0.016097652514872607, 0.02047378566203406, 0.0925618308247067, 0.03874732610711362, 0.036037262543686666, 0.026993005667463876, 0.03563957528967876, 0.02776538472971879, 0.0270940991686075, 0.08374283803277649, 0.020847301166213583, 0.007442040750902379, 0.01621770232304698, 0.03391922131413594, 0.03443711051659193, 0.04392788054246921, 0.04341080770245753, 0.06186489597894251, 0.10377891798270866, 0.01686171210167231, 0.026856981130549684, 0.024656160749145783, 0.013197553689678898, 0.05235288197582122, 0.01183154647151241, 0.011450127094576601, 0.09173287413432263, 0.03639184586063493, 0.036703199075418524, 0.0648427932173945, 0.014552752454619622, 0.06368988906615414, 0.03411823192436714, 0.06136404648714233, 0.019133904825139325, 0.0677895276749041, 0.0393425916263368, 0.03698481814353727, 0.030682806209370028, 0.02535260882723378, 0.05545191997953225, 0.06752863308065571, 0.06346518901409581, 0.04576105951855425, 0.018095282139256597, 0.05247478715318721, 0.05037857990828343, 0.030688964179717004, 0.07714639199548401, 0.006418655748348101, 0.06661632578470744, 0.054159907667781226, 0.05747570103267208, 0.04786842495377641, 0.026533254458627198, 0.029705906090384815, 0.044895978790009394, 0.04085408669197932, 0.024600605429441202, 0.012167403547209688, 0.04795795393874869, 0.0327126635966124, 0.02430581509543117, 0.028651319807977416, 0.05150117845914792, 0.04100751830264926, 0.05441944413178135, 0.046582902723457664, 0.052143043430987746, 0.04825959986192174, 0.020003996905870736, 0.04915594727208372, 0.02668015702511184, 0.013996278066770174, 0.04515494751103688, 0.06265034055104479, 0.008072770724538714, 0.017208821991516743, 0.018800741745508276, 0.026944292949337978, 0.05905876139877364, 0.0570254660124192, 0.029500637319870293, 0.0179036633198848, 0.03315609683340881, 0.0494096281909151, 0.0347795634297654, 0.026616987270244863, 0.027128351139253937, 0.0313837739668088, 0.1687507113092579, 0.08571623096941039, 0.18878282076912, 0.10408949194243178, 0.11817245656857267, 0.1488366923877038, 0.07565684223663993, 0.0812147936085239, 0.09856780190602876, 0.2377630237606354, 0.18811978603480384, 0.19171568448655307, 0.10894854800426401, 0.13178034278098494, 0.181863451434765, 0.14104509173193946, 0.1650872774189338, 0.10231061591184698, 0.14639774279203266, 0.1129576817038469, 0.08134020914440043, 0.0947437524155248, 0.16479196201544255, 0.11870892543811351, 0.15676484821597114, 0.2092486116453074, 0.13825835689203814, 0.12297529494389892, 0.18023574346443638, 0.1063196308678016, 0.1177573659515474, 0.13310267182532698, 0.12141100349253975, 0.13336766307475045, 0.12814773770514876, 0.07801460087648593, 0.12565863376948982, 0.1324184561963193, 0.2854897838551551, 0.16999420942738652, 0.06836671076598577, 0.09085020821657963, 0.16163455409696326, 0.18543898535426706, 0.17877975362353027, 0.12800315249478444, 0.054671184334438294, 0.12697912228759378, 0.13449587597278878, 0.15203202405245975, 0.1719013656838797, 0.1812801678897813, 0.1469144705333747, 0.10197826733929105, 0.15518866013735533, 0.20735764905111864, 0.08390785456867889, 0.1362096137017943, 0.16271151427645236, 0.09089418788789771, 0.14273487293394282, 0.09894779635942541, 0.1336113695288077, 0.128944655880332, 0.11668551174807362, 0.1773823786061257, 0.1771785254823044, 0.14781865873374045, 0.14133703778497875, 0.17239888664335012, 0.09877925462205894, 0.11290567941614427, 0.11382870332454331, 0.0877895244047977, 0.16364135110052302, 0.15310297283576801, 0.0943519503925927, 0.18681074143387377, 0.14050764322746545, 0.23576695821247995, 0.26994048384949565, 0.11439140711445361, 0.11892101640114561, 0.15136743080802262, 0.15702318982221186, 0.08511478707077913, 0.11881884493050165, 0.11997229827102274, 0.14578725211322308, 0.11217908715480007, 0.21596590901026502, 0.13962965284008533, 0.1057015109108761, 0.19725563877727836, 0.07992943093995564, 0.13210155913839117, 0.1817824089084752, 0.1782677459414117, 0.09142063776380382, 0.08451523564872332, 0.16674329090164974, 0.206729777273722, 0.09235278266714886, 0.1520166319096461, 0.1395418419269845, 0.13456076936563477, 0.10540515650063753, 0.10749034656328149, 0.18684522161493078, 0.3087770420825109, 0.14641568792285398, 0.14655485545517877, 0.22689119854476303, 0.14542732533300295, 0.28891132213175297, 0.13688553211977705, 0.08936676633311436, 0.11519717911141925, 0.1385785936145112, 0.14075169106945395, 0.1558016295894049, 0.21857150044525042, 0.0767636664386373, 0.12066013558069244, 0.18788305576890707, 0.09141896793153137, 0.09614318318199366, 0.13341618468984962, 0.11900289755431004, 0.10293008657754399, 0.15309583337511867, 0.08403834639466368, 0.11384146826458164, 0.15059504803502932, 0.12713868403807282, 0.16734410397475585, 0.21319651074009016, 0.15065519168274477, 0.14837339927908033, 0.08418210782110691, 0.15538648702204227, 0.1445488748140633, 0.12298800793359987, 0.1339356880635023, 0.11403584416257218, 0.08971080373157747, 0.13991689367685467, 0.07229339928016998, 0.1915581413777545, 0.12407487578457221, 0.22215129429241642, 0.15239137195749208, 0.19858687359374017, 0.11780377244576812, 0.2189498918596655, 0.09740901252371259, 0.18159491271944717, 0.20404232695000246, 0.12315660162130371, 0.10135222124517895, 0.13670729793375358, 0.26767512259539217, 0.10263066709740087, 0.11282837731414475, 0.0944138084014412, 0.13435145403491333, 0.24845268140779808, 0.2124761970480904, 0.11857142031658441, 0.11345644947141409, 0.13901159225497395, 0.10682158244890161, 0.1717505612759851, 0.14209370187018067, 0.11078515570261516, 0.16187008208362386], [0.07050081578199752, 0.04470129861147143, 0.032179526970139705, 0.03108034132310422, 0.07673819593037479, 0.061512694956036285, 0.04511858227488119, 0.03222904306312557, 0.032314905838575214, 0.003386179346307472, 0.03806576365604997, 0.09176906125503592, 0.04122312333493028, 0.026486937022127677, 0.020433900790521875, 0.04318980354582891, 0.058954797641490586, 0.05928968435910065, 0.008742586833250243, 0.042606063580024056, 0.08799804563750513, 0.051586640474852175, 0.06898626306792721, 0.029403358457784634, 0.07595128190587275, 0.028641670032811817, 0.009414059786649887, 0.029815016641805414, 0.029551890038419515, 0.0376920811686432, 0.08439419878413901, 0.05190273230255116, 0.04335315024945885, 0.015005655495770043, 0.058246317494194955, 0.01120851071391371, 0.040479294693795964, 0.022449672214861494, 0.037093019564053975, 0.036481007482507266, 0.032604050284135155, 0.03668385870696511, 0.0030577820143662393, 0.04837133761611767, 0.0223809289309429, 0.04113172413781285, 0.030918161646695808, 0.07685912889428437, 0.03732277735252865, 0.09791107542696409, 0.07761815300909802, 0.05098971625557169, 0.01928473520820262, 0.025657837468315847, 0.0022173507932166103, 0.024254708951048087, 0.01823797672841465, 0.04587904244544916, 0.029027377167949453, 0.06105159118305892, 0.013765087005594978, 0.04631031559256371, 0.02694732462259708, 0.03535500247380696, 0.025634424564486835, 0.06327188180875964, 0.03731636519660242, 0.04891720578598324, 0.005074539103588904, 0.09097371643292718, 0.06141299112641718, 0.03678817127365619, 0.02722387853282271, 0.035519258308340795, 0.05222152925853152, 0.049396918911952525, 0.046611330690211616, 0.03985091083450243, 0.03318311100883875, 0.03326721489429474, 0.07868274158681743, 0.005746910519519588, 0.02271378401928814, 0.03565068152965978, 0.08450382883893326, 0.020320964467828162, 0.010960929321299773, 0.072450133448001, 0.06226676152436994, 0.029613735059683677, 0.09427084107301198, 0.005320533227859414, 0.054395795596065, 0.05534303949389141, 0.054681949186488055, 0.02593611687188968, 0.043874008042621426, 0.017896304925670847, 0.032145421573659405, 0.026882609345193487, 0.0651078883674927, 0.06246429154998623, 0.01486553894210374, 0.02969667377328733, 0.029840639290341642, 0.07761784130707383, 0.024292964808410034, 0.017066912223526742, 0.03958107336075045, 0.048037304368335754, 0.04606567032169551, 0.04324080022342969, 0.05289580010867212, 0.06506149671622552, 0.037886842983425595, 0.04445145088538993, 0.028509994481282774, 0.07124634023057297, 0.03775497818423901, 0.01785476692020893, 0.07294501236174256, 0.08037788851652294, 0.03791024661040865, 0.02974651455588173, 0.05279506469378248, 0.02953218045149697, 0.03630978288128972, 0.08829522383166477, 0.0348702167684678, 0.02098619967000559, 0.031838317154324614, 0.023714729722996708, 0.053718960625701584, 0.050488595879869536, 0.00698777401339612, 0.02385642426816048, 0.03917255817214027, 0.011244953875575447, 0.00912834035261767, 0.05834644063725136, 0.0404153920680983, 0.005597054205281893, 0.03135636645311024, 0.007831351013010135, 0.0469820445869118, 0.0047378689123434015, 0.04988533000869211, 0.05267953827569727, 0.04183255645330064, 0.03907617174263578, 0.027157818112755194, 0.02461448915710207, 0.08336857295944355, 0.002214858336628822, 0.04938275502354372, 0.04288997959520202, 0.024784389024716802, 0.013104150693834526, 0.018267150553583633, 0.06543915340444073, 0.023473644905607216, 0.11515743710333481, 0.023056055106280837, 0.019092262919002678, 0.032217970219790004, 0.0454598106443882, 0.029411251198325772, 0.05002145473554265, 0.04873915342614055, 0.02245228457468329, 0.052022834061062895, 0.08656285077449866, 0.004977533444616711, 0.03481087464024313, 0.05325347447069362, 0.031116552563617006, 0.0680369374458678, 0.04538364773907233, 0.05190177864278667, 0.02216402514022775, 0.03712984864250757, 0.01894314875244163, 0.07019968194072135, 0.05232987539784517, 0.017563342225912493, 0.058214104574290104, 0.04020066648081411, 0.0831278796249535, 0.060326034217723645, 0.037554390510194935, 0.03805376312811859, 0.057383400126127526, 0.0475694693159312, 0.03344072159961797, 0.04472781183721963, 0.03892984619596973, 0.020926139513903763, 0.10221067088423297, 0.048832163083716296, 0.018684317328734323, 0.04795570894202683, 0.027341616550984327, 0.03543389277183451, 0.024870459601515904, 0.02308013408764964, 0.00991829718259396, 0.029762492995359935, 0.021074381656944752, 0.013358431824599393, 0.019309975650685374, 0.15680680924560875, 0.03373215928149875, 0.0541007547872141, 0.06965692708035931, 0.003440916216277401, 0.008496731861669105, 0.013449985945044318, 0.02230597016023239, 0.017227854368684348, 0.02677910386410076, 0.020380249079607893, 0.03860085584165063, 0.04238448425894603, 0.04288475487555843, 0.027520351686689537, 0.021881224201933946, 0.030140288836264517, 0.02325803059648024, 0.002602155755084823, 0.007126454511308111, 0.009281905549869407, 0.044173167771077715, 0.10297883825842291, 0.07292152338777669, 0.04172448119788896, 0.05102820032334421, 0.036801752576138824, 0.03964180330513045, 0.0030662960716654197, 0.0012484817557378847, 0.03518191879265942, 0.03878621835610829, 0.01693679703748785, 0.03704470946104266, 0.016339789326593745, 0.03667825920274481, 0.08159129254636355, 0.03266176339820959, 0.029096281868987717, 0.02825969033438014, 0.02303020239196485, 0.038332606563926674, 0.08458971758955158, 0.07482172572053969, 0.02504960106307408, 0.011351424236636376, 0.020470414456212893, 0.0026225502051602234, 0.020473594559007324, 0.04529260848357808, 0.08143374943756498, 0.04748179198941216, 0.024441475979983807, 0.09006808104459196, 0.02853500485798577, 0.04320528474636376, 0.05918094488151837, 0.039167262948467396, 0.0562029994034674, 0.015731723615317605, 0.014314399668364786, 0.05487265145347919, 0.02432484005112201, 0.0462585507921176, 0.029274061489559244, 0.006405202930181986, 0.08288273340440355, 0.08542746872990392, 0.028000176134810317, 0.0331082283082651, 0.028695718792732805, 0.037035117202322, 0.030459863191936165, 0.024729136130190454, 0.019786911288974807, 0.0338425203517545, 0.010540653875068529, 0.055869470816105604, 0.028151622500445228, 0.047616272859158926, 0.025332338918815367, 0.045989711506990716, 0.02321573003428057, 0.03668435965664685, 0.11947814666200429, 0.03498827762086876, 0.03907424586941488, 0.028494155194493942, 0.0634196656756103, 0.03366116914548911, 0.07753567813779227, 0.0666079246730078, 0.07669983431696892, 0.00745521340832056, 0.0848566235799808, 0.0704358407529071, 0.02025557383603882, 0.045094488450558856, 0.05153839345439337, 0.039134612161433324, 0.017699685886327643, 0.035549716048990376, 0.02925217184383655, 0.04208536534861196, 0.06115285723353736, 0.06260372625547461, 0.03518387435178738, 0.008102920473902486, 0.0325167514529312, 0.05347408528905362, 0.021917402045801282, 0.029313436134543736, 0.017680076489341445, 0.06128723791334778, 0.019365959560673218, 0.06912226162967272, 0.04091794849955477, 0.020114886756346095, 0.04312549644964747, 0.04909516537736636, 0.0593138635304058, 0.01119694248700398, 0.03409224562346935, 0.0488079282513354, 0.030018366960575804, 0.017829964344855398, 0.031120326384552754, 0.06549485900904983, 0.03142901528917719, 0.05287183987093158, 0.030303847051982302, 0.0029663401437574066, 0.06117853925388772, 0.04164357596891932, 0.042389111549709924, 0.07472005148883909, 0.09973634310881607, 0.09022342739626765, 0.023163486548583023, 0.017661316851445008, 0.07204450521385297, 0.028373418899718672, 0.12760717218043283, 0.1820228499127552, 0.1637536528869532, 0.1009155044448562, 0.22915914247278124, 0.10455281473696232, 0.1182927364425268, 0.19820955087197945, 0.14084218855714425, 0.11780699336668476, 0.13414636894594878, 0.19647837267257273, 0.11740319081582129, 0.28213236713781953, 0.09464773334912024, 0.17616620636545122, 0.12073429839801975, 0.14840243209619075, 0.23506803321652114, 0.17075191251933575, 0.25853696919512004, 0.24357574700843543, 0.14614572428399697, 0.09159349137917161, 0.15228468080749735, 0.11993681619060226, 0.13657697680173442, 0.14253229630412534, 0.07763809451716952, 0.11253440519794822, 0.1349201172706671, 0.09138449517195113, 0.14177920937072486, 0.07880550765548833, 0.30393274733796716, 0.06681826416752301, 0.18665141717065126, 0.13534901925595477, 0.09760524379089475, 0.08850134050589986, 0.10993858042638749, 0.059497589609236456, 0.07755599814117886, 0.18092215585056692, 0.05931736646743957, 0.12250066181877628, 0.16625331016257405, 0.13570897572208196, 0.14708042959682643, 0.17693283007247373, 0.1319104412687011, 0.1034564696601592, 0.11918056770809926, 0.1177213124174159, 0.07322221194044687, 0.11481624955195002, 0.13585593580501154, 0.11393328677513637, 0.1611089799553156, 0.16665997740346938, 0.08595529157901183, 0.12875150452600792, 0.11267190289800055, 0.13975734676932916, 0.08814352884655818, 0.11676656169584021, 0.10090043884702027, 0.12223052006447688, 0.14473813731456175, 0.19978088530479, 0.27093347744084895, 0.11800908760051243, 0.09018758166348562, 0.11735239080735482, 0.14091551274759695, 0.11524222005391493, 0.1266687858151272, 0.15725205332273617, 0.08569823388825171, 0.10648262134054676, 0.16660106572089717, 0.14133254037005827, 0.12333365579252131, 0.08479862473905087, 0.1829806953901425, 0.10848697667825036, 0.11520126834511757, 0.12026454860460944, 0.12566590681672096, 0.10268899248330854, 0.1544177022879012, 0.07257305536768399, 0.18258006923133507, 0.08790761494310573, 0.11558602738659829, 0.09597078227670863, 0.15312943782191724, 0.13803477748297155, 0.09579665958881378, 0.11528953938977793, 0.19183175638318062, 0.17970337125007063, 0.1433111060759984, 0.11359438503859565, 0.10962120839394629, 0.1603430390241556, 0.09988707330194302, 0.10593533937935717, 0.11500689244712703, 0.14334141538711265, 0.10733664035797119, 0.11543393906322308, 0.19551640085410327, 0.11433524137828499, 0.1346080144867301, 0.1797094865469262, 0.11777099178289063, 0.1585924462415278, 0.15036452212370932, 0.12228788807988167, 0.1374865381512791, 0.15348448127042502, 0.17905250773765147, 0.10573095933068544, 0.16501681791851297, 0.15189723519142717, 0.14363453403348103, 0.24573679198510945, 0.20590594882378355, 0.1773195483838208, 0.07738478467217647, 0.11327345811878331, 0.08820156479487196, 0.11064750957302749, 0.11795128171797842, 0.13526040682336316, 0.2436510898405686, 0.20211157039739192, 0.12460144440410659, 0.15463933727005497, 0.10188336149440147, 0.09122110393946059, 0.061480860531446524, 0.16143249697051942, 0.11566312910872512, 0.11258882688707672, 0.11723958436050452, 0.13889419933548197, 0.1972043712157756, 0.10906276453169994, 0.18856206152122468, 0.06397442106390372, 0.14303670439403504, 0.11404055680031888, 0.15902207553153858, 0.1627706189174205, 0.13541294785682112, 0.1688509903033264, 0.13810029427986592, 0.1977140040253289, 0.11323241735226475, 0.18224205065052956, 0.09467872543609701, 0.1666906726313755, 0.07916576840216294, 0.12385980880935676, 0.15010628441814333, 0.15030589245725423, 0.20121024688705802, 0.14063308102777228, 0.2492721757153049, 0.13521618966478854, 0.08055962563958019, 0.09963737771613523, 0.14605547912651673, 0.13892434537410736], [0.035788639361271635, 0.0466033006523503, 0.08638792656711303, 0.043490911411936395, 0.05330773288733326, 0.029431428338284604, 0.046769408145337366, 0.07356769652687944, 0.07506762151024304, 0.009174618826364167, 0.0471752107841894, 0.024196741651394404, 0.03833266222500242, 0.004376664246592554, 0.035952535254182294, 0.029802407552779187, 0.034837243147194386, 0.05027316525229253, 0.043362037467886694, 0.04884070891421288, 0.028065917431376874, 0.007291172332770657, 0.051072595597361214, 0.030544746332452632, 0.016516426039743237, 0.008667132678965572, 0.027982190185866784, 0.01962312300747726, 0.012220362277730601, 0.03442791901761666, 0.03774149707169272, 0.05304495323798619, 0.05221424507908523, 0.03351738916535396, 0.03113566286629066, 0.039580045486218296, 0.06118110708484892, 0.03153819634462707, 0.036903382278978825, 0.042128899731324054, 0.03716733452165499, 0.016068011136667337, 0.09147556411335245, 0.01750838247971842, 0.02664632807864109, 0.027687858128047083, 0.08820265575195663, 0.045271512935869396, 0.054383524184231646, 0.014952306210034294, 0.06634991703322157, 0.04361679821158759, 0.04340167928603478, 0.026959163733408786, 0.036526519688777626, 0.05422575843113009, 0.03390813733858522, 0.049785017617978156, 0.06201766707818024, 0.007767530487399199, 0.054810110668768175, 0.025886007060762495, 0.019111091205559205, 0.022714455662935507, 0.02349272366700461, 0.02135073704266688, 0.023455612572433893, 0.09736607928061858, 0.05165817237866577, 0.028952659595233854, 0.045309084161999635, 0.05501705854840111, 0.06524947530124336, 0.0273293395730434, 0.05323516197677236, 0.04027578666864429, 0.041843028157018125, 0.05925391655182466, 0.037535191149800085, 0.038329151866491884, 0.033657525200396776, 0.026216750738967676, 0.012878889392595738, 0.043995545856887475, 0.011649559801298892, 0.03513240269967355, 0.029663304958376102, 0.07014040660578758, 0.04952337345457636, 0.023395335338136647, 0.008678281592437997, 0.03175279947754461, 0.023094895404938143, 0.04791175153513905, 0.01983681144338334, 0.04186901816865429, 0.0714720792893786, 0.04265967261744663, 0.04917919875879306, 0.05037550370616373, 0.01013904529827414, 0.05280277931888122, 0.026623384583217558, 0.04607210103131365, 0.060353300723363645, 0.027541959316295106, 0.025804257638810668, 0.013310644008015515, 0.0596596523973858, 0.06881509412778541, 0.015239088770613307, 0.003680867171169666, 0.012476915308070602, 0.08674854354467243, 0.025257571251131594, 0.0697453688189853, 0.04031899450637866, 0.026909888838417828, 0.07800247418344952, 0.019510333258949686, 0.05875551243661903, 0.05465946211188566, 0.05555064788495656, 0.04411479414557107, 0.03146722105157096, 0.05624260040349327, 0.02078172314213589, 0.027360973617760465, 0.02746923069935292, 0.0267659270321019, 0.03738630890438799, 0.061831952043576166, 0.03577357005269732, 0.05520699269254692, 0.08612554767751135, 0.07202419263194315, 0.004102131761101191, 0.005110391794005409, 0.01674041363003198, 0.028086215170333162, 0.041797066951403394, 0.04908001072180923, 0.025896244987961836, 0.03959762325393967, 0.02915121935075149, 0.04459368348761927, 0.03296362825494725, 0.028550220740726218, 0.040320230182260275, 0.022191041171026882, 0.03515540185617283, 0.059796471032314, 0.0271396466268925, 0.02644330801558681, 0.01392422387652914, 0.08076677389908582, 0.055352754206978716, 0.03253951683291234, 0.03392525868548546, 0.022130016222945414, 0.02067064961011056, 0.025323019399365876, 0.042783444296219386, 0.014712399552081479, 0.024936525587690994, 0.03913086802640464, 0.03356951019668486, 0.03544273546140175, 0.015057478740345687, 0.04382277387776412, 0.020006028535135556, 0.02691462002985645, 0.06483978751930408, 0.09125767697696574, 0.05554258073971141, 0.04454410802281927, 0.03813709889072925, 0.012869047586718807, 0.04226651246426627, 0.01368960780382622, 0.027161000070918817, 0.09088149716262706, 0.019950348905695137, 0.057426121857133694, 0.02984373404615326, 0.011538835078681586, 0.021782461044494994, 0.043447718417155556, 0.03774125958443619, 0.08405879998463206, 0.04549904799205251, 0.021952414717816282, 0.0841602886794135, 0.022214376149349846, 0.05019587428250816, 0.00862316599523183, 0.07407646844512783, 0.07827818946680054, 0.030483437512884848, 0.02451592452416662, 0.033565406120033, 0.0520728956325911, 0.0014043949227016128, 0.05005570485081989, 0.09612980968086049, 0.04611715681676287, 0.00826158329800819, 0.0324723339144839, 0.026114562570001, 0.06973216601181775, 0.04793545573193114, 0.03807990528002847, 0.06524541575345211, 0.03670367404993158, 0.0235951530339662, 0.013368597392400261, 0.030391745167435147, 0.01828232932894025, 0.01317758156801574, 0.023980340665730182, 0.0413337775535183, 0.03421164976316504, 0.05648546080919914, 0.02255928557133302, 0.032129791943589225, 0.011363172434357693, 0.045540608261944726, 0.0160557582785259, 0.054526176099898294, 0.04051736315886956, 0.018461656327417586, 0.028295764277572744, 0.035340200338396244, 0.05044090547016822, 0.03503753767290618, 0.025852799662970938, 0.034850553565775044, 0.03083000934566371, 0.05387114913901314, 0.04387890992802568, 0.10792537868837826, 0.040816396722220816, 0.03461815002083313, 0.06380997598171234, 0.02440138330712216, 0.025335173922940157, 0.00892415790076484, 0.016778472818259615, 0.008291351769003086, 0.037846447885385714, 0.08818148970021866, 0.051983014127472416, 0.023976980592124164, 0.04946800552716013, 0.029245720725157298, 0.009388268299517222, 0.014108590057730908, 0.025989165587816387, 0.030193777274689637, 0.0913830850913655, 0.01175849594801548, 0.03618794449721463, 0.019270691918791272, 0.04550675890641287, 0.022268165157584008, 0.0385764503153041, 0.012967261554877041, 0.025011454672494438, 0.013228314783191308, 0.02077247412671568, 0.0272782148749684, 0.01465275592636317, 0.048911264893831685, 0.01700853117654333, 0.06584420276340097, 0.08874149949406274, 0.030153573279676493, 0.05225972017797176, 0.029054729020572267, 0.054659228335367516, 0.022069115584599786, 0.02191138508351287, 0.04510274484346155, 0.013765063813480083, 0.06077519683458377, 0.022148551361169666, 0.035645983734866604, 0.017508157980046235, 0.04691492475103587, 0.04695967254519928, 0.028897597803734243, 0.07205243135103956, 0.029705180641030893, 0.055520527821499854, 0.01571011041960446, 0.05045413796324283, 0.04146576480707154, 0.026998050416295882, 0.025953039694286417, 0.07834381758584641, 0.037783320804010145, 0.02434571666526608, 0.013762825310550397, 0.05007670391933061, 0.011941106949961977, 0.03556209507223684, 0.017430349362257402, 0.05132364931341726, 0.029006023723923136, 0.029305307762115262, 0.09267996589187533, 0.07680871480260976, 0.04193531422060914, 0.014069622666283976, 0.04528573248535395, 0.04520312031672802, 0.032570082184975035, 0.07107134180841967, 0.06704607381834649, 0.07022541220067069, 0.013622751430375502, 0.09439397079404444, 0.03501497638353612, 0.013964992831461132, 0.02174688248487655, 0.026698085457610432, 0.04458739007532131, 0.14156376390019432, 0.030277331970864907, 0.0414899402676383, 0.047034358576638624, 0.014821439599472797, 0.020452701246540528, 0.07267553111887537, 0.022408082259062212, 0.04183404074865393, 0.03931019688025117, 0.0606511171645252, 0.064908369386103, 0.03541961013979744, 0.055134588765213266, 0.02057075467746472, 0.02969074215798173, 0.04821714901481755, 0.036979489523218945, 0.05067310492449906, 0.07678303649299778, 0.028686024488706607, 0.07353447057539597, 0.04416283707541879, 0.01197630052047316, 0.03925872522813734, 0.19237077824072912, 0.09691016311990097, 0.15420494339196011, 0.2571191405877471, 0.12675407342612743, 0.16400786815211177, 0.1053109705389943, 0.10668018105207011, 0.16169074951903895, 0.07009151391685009, 0.19882217893609777, 0.09414046056917869, 0.07317033581784926, 0.2260131190996617, 0.14202509773895144, 0.09219824525644071, 0.18161986372433603, 0.14631131227361038, 0.1745503579149954, 0.09676582281826995, 0.2772463340079412, 0.1778324763290584, 0.11422757801483385, 0.12543812685180455, 0.08740306584513746, 0.12031677353661507, 0.1389956212369725, 0.06405270280083641, 0.12938566971570253, 0.1626628145459108, 0.14353608072269708, 0.08708964203833602, 0.11282788007520139, 0.1688537807785906, 0.10412537478259765, 0.08665779372677207, 0.17446168611058965, 0.12157610166468658, 0.14606738317525014, 0.06449377600802109, 0.12902584683615714, 0.16469417663756758, 0.2194382992456667, 0.10403082516859286, 0.14092284516664222, 0.09613608825020492, 0.16085759969428182, 0.10822148818988353, 0.16025297198211774, 0.06274600338656455, 0.13310923241078854, 0.10980943188769743, 0.10421827682876028, 0.1365741269546561, 0.12940569286001846, 0.20455825317185372, 0.0946333356841933, 0.12194307142635807, 0.1779193224501796, 0.12658578401897103, 0.1735599321546033, 0.18719241314101964, 0.13914387265685946, 0.0929438736056909, 0.1969761459622532, 0.10274304309859872, 0.16744053864385933, 0.25569834338966757, 0.1317735595512204, 0.12069066011463292, 0.06771233689505607, 0.1633378423866816, 0.1723338002921082, 0.09988276884541847, 0.19628385576652363, 0.1273858785862103, 0.2420342617551796, 0.14996043755672872, 0.13001349696423858, 0.150309172749985, 0.12597995402757078, 0.1644730314728804, 0.09933282999554649, 0.18190331960795447, 0.12241324424394406, 0.12662931840168312, 0.12091052136383951, 0.21398075303295627, 0.1286578900180757, 0.10449685680214316, 0.13292124640429392, 0.14577601599739864, 0.15753601386677474, 0.18343724979786202, 0.12396547579555772, 0.09173412836389616, 0.2500488481018692, 0.12344510410912335, 0.18311785912374035, 0.15336794924223796, 0.08237814719905145, 0.10502257195184939, 0.11217852312256582, 0.09315144488937221, 0.11269327675108798, 0.16540782584343106, 0.1299088096129708, 0.09773796205990948, 0.11956805785303004, 0.21829312085174024, 0.08824716234812513, 0.15531436511082575, 0.22915991430636495, 0.1907134585781023, 0.1282621917198412, 0.1752009245683439, 0.16340116242645308, 0.1591217311215587, 0.10656360449502245, 0.11361402226611972, 0.14068869757466018, 0.13959281262941658, 0.14293390209786594, 0.18815957999322563, 0.18282481469213963, 0.16735559242079034, 0.10991566290613264, 0.0758789225073997, 0.09239313323632814, 0.09135661268373951, 0.07911882014013827, 0.1606715432717465, 0.08611768833361566, 0.09819700266234577, 0.166681440314278, 0.2372614506748505, 0.17637688724789768, 0.08847248580423184, 0.1107725985639263, 0.11622992955381051, 0.1877497512032278, 0.10628677599015646, 0.1573714945698157, 0.2352129598148167, 0.10509314277442172, 0.18040749127976596, 0.1918837067205459, 0.10812089749379084, 0.1577707106480375, 0.15250797820044681, 0.10473302303580567, 0.20694305567303672, 0.17381067416863516, 0.15055194409796968, 0.10001709015341476, 0.16572059656027704, 0.12956319143995643, 0.2025599018088542, 0.1218415678886231, 0.13175628235330805, 0.1027571661688853, 0.1702074136119336, 0.11202014880836941, 0.11573772237170488, 0.21153971058083698, 0.1753662305418402, 0.06462509903940372, 0.12741970567731187, 0.11499119602376595, 0.15317849378334358, 0.18149892333894968, 0.2124650203040801, 0.18097557564033195, 0.2692538785049692, 0.13155193941202015, 0.08630679498310201], [0.028151603946753312, 0.06259746995056048, 0.03263625949330162, 0.025709830479172524, 0.026431472615513485, 0.06472451714216731, 0.051109743799315766, 0.05805609762319364, 0.02627048408612609, 0.07483175955712795, 0.024096304950944614, 0.014676787595817586, 0.05044646044552792, 0.07068103150231764, 0.02583099721960025, 0.0698926554468926, 0.048763837257865816, 0.028748825025104452, 0.06503807453555055, 0.037110474877408706, 0.02675653886399232, 0.05323228244378697, 0.045661043986910954, 0.06338839157251641, 0.04479003349842969, 0.0539866421604529, 0.016627310324111022, 0.07132669998100027, 0.0227860098311794, 0.041951452221837826, 0.05245992564596236, 0.008149539407895645, 0.020328820100985467, 0.06081784435082227, 0.02732604629272828, 0.011236381142225582, 0.022172248136484995, 0.03815663221757859, 0.0494374030677136, 0.022759149651392363, 0.020534231734927744, 0.0673120743886102, 0.0490166090457933, 0.09859417041298002, 0.02944131374533754, 0.011726739448931767, 0.036266960960347205, 0.050025926175294444, 0.0196842648438178, 0.04104461084352806, 0.0688724398787599, 0.09961847521481104, 0.012968415594514227, 0.041669710699352436, 0.05448422620247584, 0.03455117119301576, 0.04767190053826198, 0.06196268506755587, 0.012499243748607114, 0.012497830884967698, 0.03133417252684012, 0.02298839721333934, 0.016795063529571053, 0.011121535644633695, 0.06658533369773068, 0.06269393430557102, 0.014304388096206822, 0.013763512724835891, 0.027494023997860495, 0.04879700383753516, 0.03648119673016481, 0.036803337061428465, 0.03886443329975009, 0.06293953323620372, 0.019133838031848427, 0.035988214003737085, 0.01540091685455991, 0.03271976223913953, 0.02951536709588254, 0.010537940397625789, 0.05056032074207906, 0.10525327597861178, 0.011366989856469445, 0.03369491831108462, 0.11851267190650105, 0.05062964846729301, 0.05909471103223041, 0.03177611775754485, 0.049045935011236, 0.015464755470020464, 0.00818872944364557, 0.03292155590315815, 0.061406419408740476, 0.003532205714691372, 0.04051246498420369, 0.03513326359097846, 0.043739419561461546, 0.04817354783881456, 0.04252019338309765, 0.02669641748070717, 0.003458950636741065, 0.0223576681673876, 0.025549077581672464, 0.056104163886629976, 0.00683064836266567, 0.024890000349842012, 0.05129625293193385, 0.0617489057185594, 0.06624278059462085, 0.006621308448302443, 0.053503964154515415, 0.014743481624464039, 0.019689491418830585, 0.022499963852169458, 0.0481842273438815, 0.020089100835321005, 0.00806635114713572, 0.008198521154554328, 0.05214837576204445, 0.04953400472004432, 0.021408374086604454, 0.006574487742909696, 0.01786096385330893, 0.04008758543932345, 0.0318698584305821, 0.0561337496037595, 0.026332859742979053, 0.04260401154169813, 0.0066709316888591275, 0.024368726953980513, 0.04627744958270341, 0.07498124294215813, 0.04020246989966836, 0.04958108656865079, 0.03394764928088989, 0.02898703773098532, 0.041441570792812854, 0.07444788367138244, 0.06106602224463131, 0.029855599132133648, 0.07451814279193059, 0.038915930927032605, 0.04557511070743203, 0.03860772441839799, 0.02603565557365073, 0.04416297066200059, 0.021562254696618766, 0.01877328599221073, 0.0024989520034068846, 0.05768489390902687, 0.02293882174853934, 0.06023722511599772, 0.027568825062189717, 0.01218599805724807, 0.05583022233622614, 0.03319440649647731, 0.018940124500659294, 0.03571030938473996, 0.04363873980764765, 0.057951814742409624, 0.020672657119575888, 0.03355606990226079, 0.021350666538637597, 0.07141237350879237, 0.01479889315305627, 0.02518778153898893, 0.05360771268897224, 0.028801626976928674, 0.05296293478750158, 0.029206077051640023, 0.08138099758070894, 0.08741629833821207, 0.0645341414201539, 0.03104361614532536, 0.053135487833060324, 0.0222941496031126, 0.06518638532725163, 0.03614821362134535, 0.029223101919342298, 0.03572527850337792, 0.03866709623252973, 0.08489334504702128, 0.01007666871373658, 0.014193997340044007, 0.08791050931904465, 0.08185351558495313, 0.03688394914206583, 0.018561503020464443, 0.039760146173648536, 0.06531522958539426, 0.02239270124846371, 0.04704677099653054, 0.016023313437472098, 0.11021200247341767, 0.03649898600997403, 0.016807635511213448, 0.031214081900543533, 0.036306587935541756, 0.022736267383152153, 0.035255454495199956, 0.028613572321773972, 0.0392725440178765, 0.08475977330817841, 0.0702562187507283, 0.048012483239290304, 0.055490107188234106, 0.011677002567012096, 0.05216494049818721, 0.06146790263301227, 0.06628290851949714, 0.027543530814000405, 0.06698786717606708, 0.06439304430386983, 0.030322265301947482, 0.1021051597490441, 0.03409258701140061, 0.03536237942171283, 0.009147868113359436, 0.06263977978960611, 0.02672835580597166, 0.042883292844635434, 0.011288613495707978, 0.07442920381436124, 0.0531104626134038, 0.021816612825205084, 0.013616424621432088, 0.029676658050448168, 0.006772415745217586, 0.04019685184175614, 0.031509182081208564, 0.01993136105738813, 0.03058228230656823, 0.0217220836202614, 0.026765646871353965, 0.03252218768466264, 0.07915839887573384, 0.06954998360015452, 0.010614173806970939, 0.018134126148652285, 0.03713233112648595, 0.028466929506976157, 0.0885408153408207, 0.057536553431418724, 0.029262704774737358, 0.04471044187084772, 0.01801993745175423, 0.02604420697025489, 0.06923995140823536, 0.012142667765147053, 0.030347639331012033, 0.03790355614910368, 0.03164579291478731, 0.00640251078948495, 0.0007092037992606492, 0.04576865540002473, 0.02357704648602521, 0.032311324976035394, 0.06199120951350778, 0.014504316186503274, 0.03627621554187499, 0.01925120312080253, 0.02294430621986976, 0.046895332052372396, 0.020175802237645257, 0.015014857199275866, 0.038728531217202544, 0.012811934684577864, 0.03924699929484632, 0.0420974846201716, 0.0043924269994022325, 0.04299836284189951, 0.04148758765950333, 0.031208252330543473, 0.02122374629834667, 0.04367183588328771, 0.007579885404993547, 0.044343653935357, 0.1157480753317941, 0.023901416971057188, 0.10590370904537849, 0.07503152344725095, 0.013707552934647538, 0.051390576190897264, 0.0628126334049739, 0.014453201692958828, 0.08005321375094354, 0.0776983865944203, 0.00549081715689681, 0.036474454318522476, 0.042697236422100104, 0.028624806582229212, 0.042236347871948965, 0.02779991500574397, 0.030585464264731854, 0.05037637572968379, 0.08335571896168403, 0.11087489619967528, 0.028369153405947145, 0.06676835473626852, 0.011284937081654789, 0.03964396666560788, 0.011765928556997096, 0.04301148401282262, 0.0162713892859756, 0.045369802974164486, 0.019093728660664055, 0.029441462174872868, 0.07111462386092171, 0.02199885460868245, 0.0484042852622224, 0.06290262623224407, 0.027085100628028158, 0.015084749884408666, 0.05308779000188224, 0.0372762669576332, 0.048314526211470366, 0.026593440779834054, 0.0530031666130526, 0.022776775658712722, 0.06494972185464576, 0.04220890696160495, 0.09235031131538562, 0.03250668050895911, 0.0344549999863375, 0.10304655923391692, 0.08268288787803613, 0.023760434887662996, 0.04855010243772995, 0.044561095783137716, 0.04135868031880818, 0.03149136682623066, 0.055404797312803566, 0.07785054171108641, 0.07803131404216401, 0.03798505509621464, 0.08077506368863396, 0.07808540176483802, 0.07744056449155323, 0.026931502034130972, 0.007309375359909609, 0.03903373202774674, 0.0941150939615909, 0.0290035746365902, 0.03779521372052841, 0.04719061776995659, 0.012876136024715379, 0.04076249824720435, 0.04768357452121563, 0.029735792377323378, 0.004079096424902673, 0.03975500680098776, 0.013503611680789618, 0.11396348476409912, 0.15462989715160802, 0.07731036210316233, 0.17422253644326702, 0.1471075922017917, 0.1818839940824546, 0.2180602794396691, 0.16986835602438077, 0.13906719395890832, 0.23117637407267466, 0.09643718498409726, 0.1153351369430311, 0.09589087523636408, 0.18268496438395232, 0.151189582538791, 0.19987669656984508, 0.09911365894367918, 0.27315635816194117, 0.14034241146873683, 0.06834537402028218, 0.11696097470121458, 0.16554090776480734, 0.20366571669001132, 0.10508638923056424, 0.13948886742582545, 0.1378099957946688, 0.16529035870917141, 0.14445949054788798, 0.11174631858011708, 0.10297611457644962, 0.1211847820377443, 0.24614673951873556, 0.1383233690285124, 0.14484623854514211, 0.18417809129459783, 0.22444938425906003, 0.12465259322198108, 0.08631504766526632, 0.2277646618313156, 0.07724781389697455, 0.11208203650312498, 0.14148686255794019, 0.13928298081737012, 0.19536446838174015, 0.14388579555088654, 0.218956868047826, 0.17128385428804904, 0.14225586113752797, 0.16426717455033213, 0.11906393920071423, 0.1274098054273054, 0.10117153055034578, 0.1183078317262698, 0.1316759522887878, 0.08553231935366057, 0.1485704246442765, 0.1318037649616599, 0.13131384359439835, 0.09399957125424407, 0.09471340599702671, 0.14032087434316054, 0.07769416377414018, 0.12327553820796311, 0.13788720883894712, 0.12321912756306119, 0.2968296519247815, 0.15097078256076202, 0.11008948873495683, 0.08959844257333316, 0.10712153627537191, 0.10792391665745527, 0.1583603915059939, 0.1262263470562175, 0.12395155310514383, 0.10062926550745033, 0.14696898870170116, 0.17107347026467323, 0.10000972062698565, 0.08994383068056777, 0.09123580588493496, 0.1830811524996534, 0.22914707515155897, 0.18984082649694756, 0.1689623124548234, 0.17395349306752905, 0.1080430239380803, 0.14268327882746235, 0.1279093004995957, 0.10550288250669837, 0.07102134331944399, 0.12090928939869627, 0.19792737148236483, 0.11364168953150511, 0.07779409395880066, 0.11343104575644247, 0.1516312049352564, 0.17862474865978584, 0.1687390892766416, 0.22584677411941811, 0.12317548927967437, 0.1476207873201929, 0.2850269805639982, 0.0749441355583258, 0.21580195374554023, 0.10716497417888604, 0.12734341289615259, 0.11599900288274512, 0.16037122579291463, 0.15220363828120753, 0.11865539432619698, 0.17666982777882367, 0.07997370004886761, 0.10492984059965238, 0.09460310800932348, 0.15129302308196202, 0.11108142105513252, 0.16163375257747248, 0.10968728180159815, 0.15031163668027148, 0.17447335267206654, 0.22452722070738673, 0.10337974643334746, 0.11901578123797663, 0.19397481170017272, 0.14372126141097397, 0.10462997583090328, 0.15684035432059318, 0.1458264226675965, 0.11434542364440858, 0.1320399608812295, 0.24929639941547066, 0.18359602487180382, 0.22548346314579248, 0.1610598646220751, 0.14831086591584608, 0.16728114016586915, 0.07337798873777501, 0.1660572792752646, 0.10617694555548951, 0.10625358714605682, 0.1341328618582338, 0.19685449311509728, 0.1947098199161701, 0.12316670967265964, 0.11825560679426417, 0.23019201908027753, 0.10287060344126076, 0.1884886037441902, 0.22858993004774675, 0.20596052636392415, 0.1281746628228575, 0.1586820383090526, 0.08154332754202187, 0.08753954680287279, 0.1261626262567006, 0.1364760150318034, 0.10491090841242112, 0.22426694951718673, 0.20249690831406042, 0.148469923005905, 0.14548466366250068, 0.14304667885880917, 0.13507478084648028, 0.18508803856093436, 0.08399156882660463, 0.22171734570292756, 0.16332115890691057, 0.10160359408473596, 0.22305143036646768, 0.08488090665196069, 0.20994017453631386, 0.3188248904189095, 0.22118089167634025, 0.2604225289542228, 0.16678839863743633, 0.06848169912700541], [0.025721882957441267, 0.062299646087922156, 0.05193621800572146, 0.053637023811461404, 0.010661780725058634, 0.0451441863697255, 0.03234910771425348, 0.030244632944231853, 0.07105686992872506, 0.014863321775919758, 0.02253298385767266, 0.028440351343306247, 0.023453721951227635, 0.05462835499201901, 0.016933392435021233, 0.03368812023836654, 0.031564679884468205, 0.03843199127004482, 0.04466074395168107, 0.03521718565025367, 0.02068174657324562, 0.06800009723519906, 0.09009395973407663, 0.0744112215761561, 0.021286758346832357, 0.015751474020362366, 0.055507491997559555, 0.008125937256409088, 0.08507113394443877, 0.029005027390667237, 0.006506203662866028, 0.025004556409840006, 0.005960355902061565, 0.023585315866512246, 0.026729255660029594, 0.0417894079873804, 0.068365686602192, 0.013961429594928632, 0.0380533846328035, 0.034814028767868876, 0.012287948738958221, 0.03721706954820547, 0.015615814991178922, 0.06676182383671403, 0.028426647586456966, 0.003420732582526398, 0.026535549550317228, 0.0814577579149045, 0.057637633944978006, 0.04010869211924728, 0.02157960982003715, 0.06676980934571475, 0.0409868160932092, 0.008578575907449704, 0.013423523741948884, 0.03618610026023816, 0.04624701039574575, 0.016111387812998146, 0.033514157112222165, 0.042063431174028665, 0.0095680285267008, 0.02808064906275831, 0.03215597120288294, 0.013024849431531038, 0.06469868298154324, 0.02764142565865768, 0.025639231826062314, 0.026723327755462378, 0.029770563851343468, 0.0313839075533906, 0.007897352061263518, 0.007475265774701256, 0.01518167344329413, 0.04257078187947627, 0.02951932645373745, 0.07465503935236484, 0.02586644775874447, 0.05529667752853129, 0.038775824577896856, 0.07147941912990063, 0.04235536980559118, 0.015246665170707274, 0.028080810479877982, 0.06873627062304877, 0.015526441857218742, 0.03043269316549413, 0.0984547208645381, 0.055354728319798596, 0.007959757404023549, 0.03457255988905672, 0.05686785611032974, 0.023091446273610927, 0.034057535376632586, 0.008246741272159852, 0.008618171341367997, 0.018540917699283455, 0.04247555691108573, 0.016315101784130093, 0.012757846034219256, 0.03385904055903666, 0.042825858035939746, 0.019296099344501272, 0.014487454591289861, 0.10420339676784351, 0.022298170188150834, 0.0643543858313933, 0.07184313828474842, 0.022916920970601495, 0.0330665307410527, 0.024238309342763387, 0.04094132986210752, 0.0738460167485755, 0.025517753383610398, 0.0384959347138647, 0.031965024027158506, 0.01878945553471567, 0.020111144476686604, 0.03743653003766667, 0.02941475970146712, 0.024817546327540185, 0.06696303491480649, 0.10378870691056363, 0.024608123385405634, 0.03966089505411219, 0.0242653958775918, 0.05114861378388014, 0.034314199729124084, 0.02093492468702607, 0.036907593967043795, 0.04079205056768842, 0.021849553049833048, 0.07239143698825501, 0.05039547490014229, 0.009656766196712852, 0.0311533593776403, 0.10622638001223095, 0.06641630214289762, 0.08215276437113062, 0.070294394827215, 0.0244656236100127, 0.05575983705057297, 0.03938260822906159, 0.020636317858588882, 0.08710875976248644, 0.059000491673941724, 0.031928413882269524, 0.02805435662594391, 0.045827867652405985, 0.023192166845547035, 0.030881547791068442, 0.12070061231497675, 0.038320914027281106, 0.03303353856608737, 0.04824064912099857, 0.0395786279841559, 0.011604326828091871, 0.08788175851805136, 0.03848846128676087, 0.028792444754799362, 0.01572322602442, 0.07183994704973884, 0.03131770055915695, 0.036418299714569, 0.04008008232631255, 0.05100186150230002, 0.09253434167476371, 0.06783873948734254, 0.039983450988074765, 0.01543933320135693, 0.08168931541149504, 0.013121526226314018, 0.06720486373524182, 0.02062010007648496, 0.08845218064379878, 0.030702280164405238, 0.06430060981074348, 0.010910635828622617, 0.04556154795864131, 0.03091777572990395, 0.0977431348292157, 0.046537412781617604, 0.014866272740619024, 0.08192854671506211, 0.044394557844498195, 0.02728766241489211, 0.027044070993724745, 0.009961647883756086, 0.019910549381165765, 0.002672070936569071, 0.027084349203505553, 0.018003689983743243, 0.037876939022680745, 0.045065719095873646, 0.08005915093235672, 0.009927146365953377, 0.028996075234317686, 0.07618350733537227, 0.07553104820544831, 0.02542299967899453, 0.07339976335060783, 0.00726505383681797, 0.03902354234014638, 0.00455547777164611, 0.0032606179320282536, 0.09444935727515258, 0.02248086097097257, 0.031310331032727845, 0.017687366234895308, 0.06030497948813718, 0.005810790416944656, 0.03134147154923994, 0.053479176422115415, 0.06011062956531532, 0.03214749216567725, 0.04440483658981975, 0.01934116069605807, 0.030474325794784818, 0.023582228532177396, 0.05541977756365668, 0.08484392543323338, 0.021245934658509213, 0.05155565209861379, 0.0260788856758154, 0.053503526287386194, 0.027274192434560973, 0.010684772460081149, 0.04818768204131629, 0.010720269383455161, 0.041469067364232615, 0.03999483924417291, 0.04528934303380083, 0.02477503239788348, 0.014957243347453186, 0.07982268041814677, 0.06582280664588325, 0.035287448481540196, 0.062104925091261975, 0.05086809309432283, 0.05079054237285163, 0.02385433512245072, 0.04738010662549641, 0.046297420776681975, 0.0877076803590171, 0.012450621015887009, 0.0001678264055726686, 0.01961708378075855, 0.00964250675679068, 0.03522350132698193, 0.016607112775091082, 0.06613380362978205, 0.024636688649479765, 0.03010176951647736, 0.02328744190890575, 0.06943469095858745, 0.013252814933366608, 0.06283548413193785, 0.0013815862894261954, 0.06805323500884697, 0.029984478642290924, 0.047417087844223715, 0.02789239959383849, 0.008752558514970588, 0.07426317053614184, 0.08949400755227543, 0.02032948988926364, 0.01384778266583453, 0.011868736419273773, 0.05856047602719627, 0.04405144813063089, 0.015641671416233294, 0.03671181169920601, 0.05822977873322088, 0.0633291904523503, 0.007047891685942886, 0.013358505111682462, 0.017226620548171923, 0.010787455084937392, 0.06752112996764481, 0.00608600660598313, 0.08557041379390284, 0.02495264503522776, 0.09607118743588217, 0.02652684230270097, 0.047024443483678624, 0.012490378794609569, 0.004313673071010271, 0.018803322564053815, 0.049401394062442705, 0.082660296902759, 0.04433742360561155, 0.026267174107488245, 0.08404919659369625, 0.055526735886815004, 0.0527031459932914, 0.04057056030433159, 0.01632884821447078, 0.07935039990115911, 0.05341629424947314, 0.030075790637056343, 0.02018127743212972, 0.01974974453332834, 0.027169670211151242, 0.04264831404725555, 0.07695670647080988, 0.07986455981153995, 0.02757725214905804, 0.04202842777885962, 0.07468349329428747, 0.04015534352220129, 0.0344103375391569, 0.06878875530674122, 0.06920798710780218, 0.03712146979523823, 0.06601100045372732, 0.01401856568918447, 0.001483219703004579, 0.01644047093577683, 0.026684086697059684, 0.018921166338259354, 0.03436957878875546, 0.08015058352611959, 0.08223092736443505, 0.03418705498916097, 0.055277634019148536, 0.030354183218150865, 0.054081481212051585, 0.06977909943088889, 0.007637136068296968, 0.03362969837326091, 0.038839983244542964, 0.054282755372696556, 0.035801849589915946, 0.03934079191822093, 0.042018434760393575, 0.021268451419018675, 0.07970167323946953, 0.006506768158942577, 0.03977177562774159, 0.0648712545807939, 0.052814809532719664, 0.01088366525436868, 0.020138299660175107, 0.10463220227393322, 0.012159759426140226, 0.08361074316781014, 0.06836115207988769, 0.026451783342054114, 0.08233011540141888, 0.020049792983627412, 0.0753221039485652, 0.03335772722493857, 0.03414655599044636, 0.14727350673638284, 0.16760406346293166, 0.11347550040227361, 0.16205851337872446, 0.18733437114860862, 0.06328277653665282, 0.17650193913141266, 0.15682482859119773, 0.11856446639285423, 0.11035497722332366, 0.06278599030338228, 0.13479129527695477, 0.13978773029521108, 0.10701894178055227, 0.11836776015115902, 0.07812591560650617, 0.13072656729491428, 0.11178589731571265, 0.15991225198376924, 0.1530423542135395, 0.15914680087007582, 0.12160350917838514, 0.12045493916957639, 0.17199716210598126, 0.1822566264308989, 0.11391951993573457, 0.16488591791130602, 0.11968061196967028, 0.161284705682192, 0.15182683506282046, 0.07678155219764449, 0.18588736129458994, 0.27529395127203315, 0.13672445638803765, 0.18023035547230393, 0.134941030992195, 0.2216087991837412, 0.14966550807002932, 0.09935316484188661, 0.16317899309797212, 0.11889297064044513, 0.09102411568164825, 0.13465436903061345, 0.16381100605940446, 0.18473424192052335, 0.12450918802642263, 0.11635010552708991, 0.18479270831448957, 0.11850668277475052, 0.15578536171233281, 0.14569359307643026, 0.10872132465010509, 0.1514037069864571, 0.14192550152074546, 0.1106991185224615, 0.12448087509255856, 0.10520868774619885, 0.13374820671742782, 0.1741514980676584, 0.09877165502985008, 0.16051661252276972, 0.10755575203802437, 0.08081707666860893, 0.07372244916041382, 0.08675254372064956, 0.19965504674473777, 0.10931459750281647, 0.14299642061814666, 0.0966770842205733, 0.0721873612201307, 0.12663452827837318, 0.10649477771949023, 0.07467063929652795, 0.10653650126187131, 0.15117778239073232, 0.15289631439372897, 0.08727577267563902, 0.12723437655949965, 0.20401501591550186, 0.14428345311898738, 0.10535676847212017, 0.11837443205877207, 0.11778853615396656, 0.14622817689087242, 0.1428520432091318, 0.10269508551573381, 0.23558339540613815, 0.240222456632182, 0.09567540007992648, 0.1599309392622672, 0.12112970725866035, 0.17375636380165815, 0.10629613447235897, 0.18134685728000477, 0.09123637733864598, 0.19025415822397918, 0.14584114687750116, 0.13358885276829824, 0.08655004130559973, 0.1034638391865883, 0.10749265464255586, 0.2466152870329097, 0.09336177696241066, 0.18972088058944792, 0.10534845641814172, 0.18728510738583282, 0.13647341751493514, 0.1277222199132666, 0.12113519915146753, 0.09754934522788972, 0.0941037613665685, 0.1701785737532191, 0.10985139291733503, 0.13767525146249682, 0.1128947401593905, 0.15001197229139507, 0.15725671401014552, 0.15109645784832537, 0.12703883548965678, 0.0937323016114533, 0.1894367122440599, 0.13934790389612317, 0.11291270755464211, 0.13394175883149728, 0.11844342952826992, 0.26384397817309946, 0.1435238352860324, 0.1500529536860995, 0.11809143630671315, 0.12496352341258898, 0.13368510932195932, 0.14788160769967362, 0.2028013372910209, 0.09440779700526036, 0.15811754594324157, 0.16630812518997118, 0.21441066433908418, 0.22774319892050698, 0.15348166110925376, 0.1872499889577739, 0.13984253047965467, 0.13863811385817826, 0.10084532696055248, 0.12861379160312936, 0.2008875907631591, 0.1472238718997687, 0.07163961170590483, 0.14141393912723288, 0.11397484704502858, 0.19262586924014613, 0.21054444601759315, 0.09757972133229487, 0.08262886694865301, 0.07640579540748149, 0.12386879621772096, 0.14686603797599673, 0.12398321312502958, 0.16195976320886984, 0.11193118756636977, 0.19805712858214974, 0.15755520580569282, 0.13450347556499764, 0.12358766325633042, 0.25179111398756504, 0.16462466708617285, 0.20911698433337733, 0.2571452938718721, 0.15312032424844801, 0.16600233066128567, 0.2372509121778421, 0.12171060108812526, 0.2227512316312641, 0.12210700442665257, 0.3451944957487285, 0.10878314555156976, 0.21894131263252348], [0.012635603179660393, 0.04766172198287677, 0.04811078069906216, 0.09068275001482107, 0.042884406066150405, 0.0569573888060404, 0.021791479994135443, 0.06469741390901618, 0.014286773221101612, 0.05233230964222457, 0.09843472740612924, 0.017830485703598242, 0.01868161591119133, 0.05240440557827242, 0.05036649032263085, 0.07262616345542483, 0.04322115928516723, 0.029116640835127328, 0.022679142421111465, 0.04171906351984944, 0.04916439291264396, 0.016956035360635724, 0.05408875054854434, 0.034505547664593905, 0.06142266131064389, 0.016233933092735242, 0.06631582276895642, 0.02696118608582765, 0.029011270707997028, 0.019905508343072142, 0.08459014061372727, 0.07506374749937095, 0.028288923531363253, 0.05334798326657619, 0.029973646996950265, 0.027914257698284928, 0.020466189780563582, 0.02819172259478364, 0.04118675809877459, 0.011835629211418564, 0.034604869288159534, 0.013751017741014948, 0.02946253360278206, 0.054479068276123144, 0.03538668104738463, 0.03607084843679331, 0.026237983583996538, 0.010681479179766029, 0.027508082130225375, 0.004834011824641493, 0.02428695712296758, 0.06030324657331221, 0.08234660592279397, 0.04266740208549891, 0.061012799124000594, 0.05503741565917153, 0.02137371207936667, 0.02917645422712667, 0.010615642331686104, 0.055805230513215065, 0.10399472710560076, 0.02335890145332087, 0.04246419091941789, 0.026191781180386897, 0.06975576630793512, 0.06329550436930731, 0.014594960248359712, 0.02398721295321593, 0.018703540808928665, 0.08320818742504343, 0.03038673567061778, 0.045841846003895625, 0.015704709439887665, 0.0657576831872575, 0.015034769949124893, 0.05447262643428985, 0.10253639949951321, 0.03150171978631988, 0.05053270542703103, 0.04503781063249335, 0.0232610715465853, 0.043788594266516156, 0.03519184130709618, 0.007463371466656099, 0.027245677265455015, 0.041452231744187884, 0.05457659761304967, 0.0033865450859593693, 0.02788472022075439, 0.049778267784859054, 0.033820753160398453, 0.002140354131370259, 0.032516432329430245, 0.03983299538958818, 0.02838014275766909, 0.04934554373903666, 0.01658401157328626, 0.037198471327428706, 0.01845673774369061, 0.03332951448101085, 0.027215579466428608, 0.07862525482778437, 0.02146745831851149, 0.0338685697352048, 0.05597783550911117, 0.023014956823317334, 0.044386501831468195, 0.07865239516831934, 0.024323661891685333, 0.0029830479752490646, 0.022033112145436462, 0.03478556369373109, 0.034340894781053066, 0.03909607243258506, 0.014204530270944815, 0.07269906462170184, 0.014661202494608006, 0.07570307061541826, 0.04581964836688712, 0.08224369972595014, 0.008548203513782937, 0.03014294201420853, 0.014598609759559622, 0.02379001132794656, 0.13490571960574016, 0.045784696922055446, 0.024833567440509796, 0.03032722099305829, 0.06247888959478587, 0.07336261143791489, 0.05051202548202127, 0.06143317383248359, 0.06233116509974934, 0.04331508920586202, 0.022030369909771252, 0.043755004662671126, 0.02804061947244918, 0.0324046760215424, 0.0032941365680017043, 0.004244930714776274, 0.07894501657574438, 0.02203436266427161, 0.05821072409162298, 0.05240348160441499, 0.037597780174110085, 0.056476837053196505, 0.0447129243548261, 0.04450251435628161, 0.016802343998278957, 0.03744583656953182, 0.07302922385861166, 0.0438998199388152, 0.04025286543765105, 0.055195363238453865, 0.060028893130947836, 0.02114003204042092, 0.02167047467082739, 0.07615167662152089, 0.012673927685682429, 0.011741192774934461, 0.1019107319007162, 0.0760420317237731, 0.08147856773575768, 0.035807185631711036, 0.03587261337088421, 0.11522805245476775, 0.012528313673101366, 0.04963751576724462, 0.059413756607682444, 0.03560761841072235, 0.021087597451696638, 0.05924014600168448, 0.03416975923755672, 0.04700741861597635, 0.046693404801771976, 0.052157433674437925, 0.025745060229382943, 0.018409991716907825, 0.039080320348148234, 0.033681359273032285, 0.07566124317236245, 0.06949327609618194, 0.009093012267840095, 0.056207433735835366, 0.026414870771986898, 0.09256191246095113, 0.04157491246587597, 0.02858495881810086, 0.017557507089804858, 0.053891086936346255, 0.024905264472181443, 0.00949882882196107, 0.0029371466052907635, 0.03444207177381031, 0.03091295548074413, 0.04452171742741484, 0.0035931179490944487, 0.08106072375085205, 0.04988659537048079, 0.01948876273672795, 0.03208622416423168, 0.02862036482838448, 0.026106833101948723, 0.026804088265635073, 0.03108068271103548, 0.04352427466074005, 0.02565904531365959, 0.0824274925980717, 0.020198771708237473, 0.021775935711048078, 0.03345558310684282, 0.0395358246169053, 0.02416598148556659, 0.061954833145136945, 0.045687416204600595, 0.007013527465460356, 0.08715289528481662, 0.03368000114278402, 0.02928572805103613, 0.027847774254041724, 0.01413046486050007, 0.022829475565231405, 0.0380532955750823, 0.0034468144349375507, 0.009411083774466533, 0.02007652699830942, 0.018480304643162526, 0.04180404313956387, 0.0017610189138395071, 0.12223127705510706, 0.06280958317802288, 0.06969899201067165, 0.025243574345950037, 0.034750508348224685, 0.04837819877138827, 0.03858663258142769, 0.02734776153374696, 0.016728118098399136, 0.04390491478261538, 0.09436171705601737, 0.06506122212158516, 0.04046334965096321, 0.045442307091434486, 0.058347431404399686, 0.05222725863859523, 0.06282663773163222, 0.0318642589263618, 0.06087041809223592, 0.06026029477652628, 0.0898893570411019, 0.02672062077181181, 0.025109167690970935, 0.03267655069066677, 0.09583396735251881, 0.009313015452789841, 0.036242425558157265, 0.04914718621876091, 0.02550770284869941, 0.07977366898558103, 0.03299578922451474, 0.018682463814911898, 0.03442426765104756, 0.07948000857140869, 0.019047743335249834, 0.024236609824583866, 0.026493059740460012, 0.08004896124475636, 0.013603962106571998, 0.09183025133097544, 0.024289168723043986, 0.07815617296728306, 0.07150675242883153, 0.01387165848427685, 0.017532708225189708, 0.01877173675893573, 0.038992520567262545, 0.05428488162579015, 0.062332085362868384, 0.02810100617352873, 0.04096087061043363, 0.014259577219490893, 0.050272219014004804, 0.042483616634854116, 0.032041416998254135, 0.04086754554009531, 0.022505997512780596, 0.029299966154212598, 0.018607890960993245, 0.033739539940143004, 0.01777553708961932, 0.03211038107110653, 0.07390804545138963, 0.04444237070856616, 0.05739024643844459, 0.012527340531960363, 0.023763717035762966, 0.035130940668750554, 0.024253389783552848, 0.04313215351430699, 0.022602829230891075, 0.03675723484775517, 0.04867972224019468, 0.040998686745297164, 0.05076385474239942, 0.03861018834868446, 0.0758015684550628, 0.027344679765519686, 0.021187145430303644, 0.030268324153439607, 0.02495101602107752, 0.05845015948580112, 0.034071535992552526, 0.061177374082035385, 0.03604424615332391, 0.04854573489865288, 0.014979845454945462, 0.06768662147806026, 0.03778034108108841, 0.04011894117866177, 0.01670347322942689, 0.06592841426027007, 0.023865183466114104, 0.07908931976999156, 0.05192194279516116, 0.0158505952640553, 0.018850589949579444, 0.09032916117575951, 0.07378438138402998, 0.048178813376580365, 0.015887197987467516, 0.008516536072420422, 0.02226145243184874, 0.03273055306635797, 0.030677464601467364, 0.03594884678022936, 0.03558730582881253, 0.02074167314276565, 0.024723241622268688, 0.07552539304015227, 0.006387071334756911, 0.031091731434571557, 0.06509982122224756, 0.031749244590173475, 0.014046949127077824, 0.012378910068946425, 0.05394248066295404, 0.03169054813042749, 0.00793137953223777, 0.05940868773905095, 0.05599362099019345, 0.07849998029996641, 0.057414967377553694, 0.1383551477920264, 0.11766116134822369, 0.1295369936269708, 0.19668724271468818, 0.1759967443649657, 0.1716688508167863, 0.09258134188712575, 0.1378201780607924, 0.11296220880467445, 0.14141387975541875, 0.1978549823979847, 0.08353896264452487, 0.10847624522284605, 0.1901841736980714, 0.13375096750678495, 0.12347703130217269, 0.12143873755121604, 0.18818233424099162, 0.1515130847110413, 0.11333845541230403, 0.10427522181998938, 0.13440505194012076, 0.13204760500229895, 0.10321505644242279, 0.17179998831124976, 0.0773400034813676, 0.14456386619713157, 0.07757478932035156, 0.11739772860892117, 0.09595242896466516, 0.17744773213053122, 0.2050775635871105, 0.0856440348434262, 0.11745086638256907, 0.16055449174018577, 0.13840245228493586, 0.10987808796926402, 0.19872347329510376, 0.10031475074356422, 0.09498244195128791, 0.1777686516288668, 0.11610032830503769, 0.10729628236731514, 0.16721228370442986, 0.09493421719525941, 0.09257349738618359, 0.11685551551636308, 0.12917769025079906, 0.13798649335512891, 0.07307934109121561, 0.06194269903062377, 0.1296313205966726, 0.19309527764562517, 0.2711399726103991, 0.160798198194243, 0.21930459392024204, 0.09987740311771631, 0.15511331730522215, 0.09232786134816706, 0.12226777587784454, 0.14298626803793013, 0.13972592423669994, 0.16727713256841525, 0.20274235139368102, 0.17629962967475876, 0.1802662605769001, 0.14093283447436988, 0.14728931448189542, 0.10380062580225058, 0.18034011911367998, 0.13452023325953633, 0.1584113176795654, 0.1483065020875074, 0.16071826888946816, 0.12435844299034216, 0.06082234547648113, 0.2448812738293782, 0.11131498235045001, 0.11918346950551495, 0.13102358963806182, 0.15904898580629379, 0.13520839711418375, 0.14654571219580248, 0.19535588915459812, 0.11693488821038045, 0.10910824334132485, 0.171315380721353, 0.1112138424650766, 0.14283884782344103, 0.1270413736347109, 0.16982030938379467, 0.10108688860782422, 0.16246886167209595, 0.09697466317447834, 0.25024661561474204, 0.11603137536440045, 0.25840807298664004, 0.13442826631944627, 0.17224072013050318, 0.09964721859432757, 0.23567546624690294, 0.1462892853305675, 0.11149981422931887, 0.15375253016827628, 0.11861252787639387, 0.1912350399652496, 0.10587737764581107, 0.12623670743778348, 0.12909219483844936, 0.1042458476149477, 0.13916315365349874, 0.11378988900105469, 0.14245873462641612, 0.08300879460875876, 0.11269633439951576, 0.1905579786398448, 0.10026487099821679, 0.20271613873774186, 0.1750178070506081, 0.14530623651808128, 0.1424818451050669, 0.09239411287126131, 0.14181674720020965, 0.120690021867631, 0.22918820497579873, 0.15453496162081137, 0.134214973077178, 0.09415181542863138, 0.12350552235147916, 0.23664908978389576, 0.09341823955764994, 0.11475209830678068, 0.2351938866195269, 0.08598560089012608, 0.12114570054109208, 0.16167701978702098, 0.2285709755960852, 0.11875371405039914, 0.13724523625569418, 0.13554794451920316, 0.14647480740677565, 0.16262201126664877, 0.11953330307733268, 0.1647747738752514, 0.13197183172451332, 0.16844022640725598, 0.19253180944360793, 0.12764769344357774, 0.13393319444730878, 0.15931745030684397, 0.1692467776592821, 0.1642789301695302, 0.11631951419985853, 0.13446760014630854, 0.11265559791354463, 0.08669653383549303, 0.06673632364254445, 0.12461002363124862, 0.11049773675040342, 0.14601247909013182, 0.14170969981933013, 0.1681295337039046, 0.20147940900642425, 0.11343692356604151, 0.167154886003118, 0.1776228196104057, 0.11242623717407696, 0.08715305855730549, 0.16716575104510412, 0.12190801979159005, 0.21211310871876776, 0.1394830786739476, 0.14792330155614763, 0.1860127694089897, 0.3461942874127999, 0.14659803360700607], [0.07307234263862483, 0.008290045589092188, 0.05002213751140516, 0.013724158488912508, 0.053475628956221044, 0.06936489196959883, 0.03028174032806419, 0.030084329046076164, 0.008513324428349733, 0.04948320100083947, 0.13169581216061488, 0.02980513123475248, 0.04293217811209615, 0.03786011824558955, 0.002539123529459175, 0.054299245894071646, 0.03463301523879636, 0.05651234139804728, 0.024049599742284045, 0.15535340207861736, 0.014975342473917408, 0.16886786674149334, 0.033696840473567136, 0.021061373663542327, 0.02969877405121224, 0.026544958127487916, 0.056221753475256264, 0.061668052439927123, 0.03593708745029289, 0.043867065251106396, 0.061960454913787544, 0.011622105903370539, 0.048591744343866594, 0.020624616045097355, 0.03162239670928102, 0.016770103247836232, 0.004539730325632263, 0.03970795834902674, 0.03288088249973953, 0.0647150918666739, 0.07748128613457084, 0.007291361580428202, 0.013171710252208868, 0.06606125127291307, 0.037602188531309366, 0.04783588919963222, 0.008614390098955482, 0.06623833513003774, 0.04041398198751267, 0.05552579335926566, 0.012227523075125646, 0.01964042803592747, 0.058387399767525494, 0.04300725748180412, 0.047239822160918266, 0.028465422947192565, 0.010661520973371807, 0.017171402905660216, 0.033304541211691685, 0.042427087246323936, 0.027765334634750616, 0.06806547302403487, 0.05431110170320608, 0.027505061589181423, 0.07169994089053944, 0.07845735133741982, 0.022255392796068918, 0.00694814889357076, 0.0661938582197763, 0.048745888416306116, 0.0022858357169752708, 0.03004504160344368, 0.04989410961570684, 0.06436927331378683, 0.09113474763580598, 0.02321724772627931, 0.02852375018846942, 0.026249607471982017, 0.048570366780040786, 0.036807170254178345, 0.06450239976402372, 0.06831397375208326, 0.056284112433786504, 0.015507691496168263, 0.021185974692343734, 0.06199074567120988, 0.06344617519062012, 0.0748521092464216, 0.11377738381270319, 0.006599948510483955, 0.03719169551914092, 0.030797354847891256, 0.012121228046453325, 0.020812887778447475, 0.02396125448285602, 0.016523493140994105, 0.13010798720642924, 0.046266551144071855, 0.028013302871841006, 0.013855731067451416, 0.046197156625567004, 0.005222837835390237, 0.057341283245477825, 0.026897754723904654, 0.024505809051333927, 0.013734382500842912, 0.024560696438129526, 0.0610467931983294, 0.04471272026421502, 0.015400368592963787, 0.0340732021140866, 0.029102599401085172, 0.04226981502142735, 0.07631045169546269, 0.03331201463879552, 0.034361938378424384, 0.040113137583830394, 0.009106562029046472, 0.005612435679722694, 0.02774345612124307, 0.03026316251634853, 0.0658863790158648, 0.011285918571957154, 0.059538956920732744, 0.0643792180926539, 0.07577620926895179, 0.03278841460996773, 0.036116753981332295, 0.029989964968990535, 0.07284296705620363, 0.028053178466507234, 0.032649102358845994, 0.01766833200235851, 0.003982207190347253, 0.022575469956791494, 0.024710272591619287, 0.05717886422644369, 0.03537082877301145, 0.04749103914946318, 0.03889998217346147, 0.013772596612398047, 0.10790790853207, 0.06804708260460757, 0.05776755802799016, 0.06813397325458936, 0.029926355491625145, 0.044461369689088315, 0.021880511740164366, 0.11421668328694068, 0.06721486788592301, 0.027933017336181365, 0.06911743024829775, 0.00391103615584143, 0.03344520417158492, 0.034524802686064504, 0.044135941643617116, 0.040347003159695305, 0.011307753484288696, 0.0481509865494445, 0.07088735597790219, 0.047712666710140184, 0.0443974781956058, 0.00951276078922092, 0.03989739154349081, 0.05187782953726128, 0.09047595798620023, 0.014997307262092363, 0.013563588345277822, 0.02555157490860438, 0.011566049633984221, 0.04694016890425701, 0.07216744939796627, 0.03061871619138401, 0.028882441292807925, 0.034929013418150134, 0.04485410681809299, 0.030690697094541974, 0.012017161316180136, 0.008644708686915692, 0.038956359421717934, 0.018247090301883873, 0.026772333621920552, 0.06810462873545475, 0.07160338005633093, 0.06070609546441119, 0.011495781236590119, 0.09023651145980693, 0.04662229221139569, 0.0547830371215241, 0.041570203538867645, 0.032247429771814495, 0.02556252158683492, 0.0897380405513104, 0.02782910923997406, 0.01624547534447629, 0.0549740585120162, 0.052944073104299605, 0.06234975589904934, 0.057241156391683035, 0.0032027287898017676, 0.09809701310587116, 0.0430476303154137, 0.03749256589799188, 0.07813146687112749, 0.03038399157958338, 0.012418420155881904, 0.03996089340944309, 0.10640033200616017, 0.046008691933820955, 0.013973512686789036, 0.0936765737424139, 0.033792970862123184, 0.05933875887421891, 0.05124118186358828, 0.041657602560007945, 0.0368312158389017, 0.030823550805507693, 0.04250330210197717, 0.05375814973376691, 0.027560557537071873, 0.028348130217636935, 0.007988021170604043, 0.06056285354134161, 0.0475075890426524, 0.03547990221704822, 0.03633826279838104, 0.045930703345220536, 0.05552739639824722, 0.04222805437166244, 0.08094991368125193, 0.05645602723234333, 0.02816852676915005, 0.04417191354150418, 0.043721678521251306, 0.07987298318766989, 0.03695988198160194, 0.04336755533586256, 0.1399509730981663, 0.05727632677007932, 0.05488851114932913, 0.0378283914324129, 0.03455640333413612, 0.0245784077924327, 0.018524907718528993, 0.048699801045586355, 0.0788314531382639, 0.022517344950756524, 0.029907376920164097, 0.03888287566951476, 0.03239455683797132, 0.014769605222682003, 0.01641001505049644, 0.025751904686330818, 0.018772484472719952, 0.0752429613203276, 0.01967005828191759, 0.028081558193662204, 0.012762592068611411, 0.10109628419741057, 0.010894611932599219, 0.0345539728004951, 0.010800479776662542, 0.062353065877687186, 0.016481272359669674, 0.036058777404832654, 0.018736199017439503, 0.07064831021125428, 0.007500472356696264, 0.039475168887292966, 0.06062114924134221, 0.08478505827952176, 0.05332744804036338, 0.044914306126884185, 0.04068139263836201, 0.09251203271560371, 0.026612122492224444, 0.03376352244231384, 0.0689307578431908, 0.02978966116643278, 0.0541386451368453, 0.027879014960490167, 0.04301752880564891, 0.06192854627443012, 0.06339113009744324, 0.023391192298731767, 0.011408260688767768, 0.008430624129687203, 0.022000168210070115, 0.04702853271737695, 0.009011273978103418, 0.05460630578454584, 0.043337698734831065, 0.08210702580981888, 0.029071959834254812, 0.04940516417264007, 0.030668965155200567, 0.08371885924134403, 0.024074155553535093, 0.025334608035336714, 0.036138235445832834, 0.02037436941463966, 0.024324493097083177, 0.00917360022867797, 0.04088214358489495, 0.04116470146982465, 0.05255220799881499, 0.07685397838940844, 0.036838867381447926, 0.045354262401815504, 0.013350767294468824, 0.027173818816663697, 0.03833593880699482, 0.019537521839083638, 0.07814652504748665, 0.022265144616540056, 0.06097930599935353, 0.0384438136825338, 0.0802531409135554, 0.11621547251706943, 0.0343384085863363, 0.002733973706199322, 0.05859353128471412, 0.03826400985417422, 0.0075705348081100965, 0.026911545683105942, 0.055872064622235484, 0.03766752721276134, 0.045487874958780594, 0.044153029593871906, 0.04725398604932707, 0.03100012443610467, 0.043481660541146994, 0.08324232621816918, 0.05954451560683083, 0.041998845772468485, 0.03543876126059331, 0.053434684668900445, 0.011091333944932558, 0.06044707479304634, 0.03356635235832073, 0.05708868586225435, 0.04663630395953078, 0.02889785941079026, 0.05919933530094568, 0.022913158281880897, 0.013459911242534872, 0.02506446442566812, 0.08172687550541013, 0.0441211617726367, 0.03185711946571246, 0.028459413406380918, 0.012943888541485649, 0.1573617130634375, 0.11551753457752056, 0.11337346251821145, 0.14564156852429733, 0.13644180202390999, 0.1900178287178278, 0.17191699531394988, 0.09037839525262825, 0.15736711589852348, 0.11623406331636943, 0.2014513112953864, 0.17291604483034462, 0.10360980479163118, 0.11779177191783674, 0.15781724330736324, 0.19916564488084987, 0.16525308805285022, 0.08444353676168248, 0.12166909276857041, 0.2206694331835024, 0.09062496639671735, 0.2562429313547909, 0.19854084559483454, 0.15477875713258982, 0.16545144928386435, 0.10073405675939284, 0.08564430201658979, 0.11288328139926307, 0.09048981388332322, 0.11104454373707995, 0.10658681145287119, 0.24954890774097294, 0.14246667560655624, 0.1903014478739351, 0.23800423659849912, 0.0879581477784086, 0.13240708649391308, 0.1325482875108719, 0.13710403523873538, 0.1625827664975077, 0.19502943323459476, 0.08123589286697097, 0.09820723687880673, 0.18346199300140142, 0.12583738745888695, 0.1100099750328809, 0.13444814103422686, 0.13138725684257224, 0.16867854486918077, 0.13423711876384914, 0.07283150829607621, 0.22548975655809045, 0.16249379783403128, 0.11046238825656474, 0.10233056484139524, 0.136208574695047, 0.1502789673395455, 0.15166648663580418, 0.18252664944157004, 0.12349767042906024, 0.09662941607530229, 0.23249291436513886, 0.14723043248523027, 0.13547551090596244, 0.22474694094853476, 0.21189978579059243, 0.04880341970419977, 0.06518306792713702, 0.2568249235628173, 0.27436463395133615, 0.0781183382787276, 0.11981414660112932, 0.15253083634888753, 0.1495723833795637, 0.16143249697051942, 0.15511456411331892, 0.11159711721120402, 0.07660662799025886, 0.195967864128761, 0.11669123370666057, 0.14923899580026045, 0.10566873766947538, 0.17637669428950176, 0.125051868672017, 0.10616787651088089, 0.1961659878725186, 0.12511984939919785, 0.1323992939433083, 0.20821034704567865, 0.1154492050409317, 0.13596121687442064, 0.15126666199648753, 0.16600850532995537, 0.17394538881490007, 0.19853428500937298, 0.14620656555052847, 0.20953594153979793, 0.11732499071513303, 0.1642407986219041, 0.14393128920346498, 0.25893339479807764, 0.13190505327656865, 0.14971775526646525, 0.1519052652292885, 0.12268199818208814, 0.13075579307042062, 0.13833546603564173, 0.12204900558572263, 0.1479691217537038, 0.05737492479966022, 0.17845862632384524, 0.1091731886845082, 0.14562899654265493, 0.11080650729127228, 0.12757859949488193, 0.147178482147865, 0.19510247540893033, 0.15491103753447533, 0.16017374029615894, 0.14651970734121278, 0.2017476805485785, 0.20255169365555048, 0.115109412727179, 0.20560745702823624, 0.12932478392031044, 0.14104951493209228, 0.06886647301143967, 0.15456157503649592, 0.13791975943604484, 0.15053071867441759, 0.14358788263052702, 0.13678039947990328, 0.13292179559357464, 0.16738750477088615, 0.23794701701262966, 0.11835061653982848, 0.1092549436725676, 0.1536037740879692, 0.18450451752869412, 0.16597448528045788, 0.08590648794779554, 0.22320257616229355, 0.21606074064038694, 0.15918758930638433, 0.17657973105087876, 0.1526753621874377, 0.09305604922701605, 0.10849972677533515, 0.19741926749702543, 0.1595246876240708, 0.1949801397859119, 0.17281009582802653, 0.11455316562205553, 0.14058384695090353, 0.16001527692424133, 0.0634969084057957, 0.14993982069427148, 0.14916043204721063, 0.2283063405775465, 0.1885613490594551, 0.10293200131854974, 0.07294276365428232, 0.1488930213963613, 0.24534738709917292, 0.1185656018787995, 0.19763165531912819, 0.07301920486497693, 0.12993552692933008, 0.0998020454426296, 0.17495554086053744, 0.1540135286631994, 0.17497514840215445, 0.13044235442066565, 0.16928992612520233, 0.18974780570715666, 0.18088187207467854], [0.011742721599148354, 0.022599732619710267, 0.0657612454961054, 0.003282851980657142, 0.07748551637632772, 0.04885697679128498, 0.09243516105925664, 0.01760737199219875, 0.01816494197555585, 0.06983416678849608, 0.012261117317393655, 0.02118022119248053, 0.04735334849101491, 0.03670580772450194, 0.0752045180706773, 0.06960117694688961, 0.021273511010804214, 0.03125164199445862, 0.020126868730585556, 0.03929317943402566, 0.05970508667815011, 0.061745755301672034, 0.007392760289803846, 0.0480046721349936, 0.019255902770964894, 0.0547638266289141, 0.02711560475290753, 0.02502114155504387, 0.03142563480651006, 0.04005832626717165, 0.027623560308711603, 0.02868141575163463, 0.07059081603074446, 0.016429782153863925, 0.025314633130619768, 0.07380392213235609, 0.05174977566639427, 0.023868320895417128, 0.02804950298013864, 0.015800741493876558, 0.006734811122441897, 0.05254960306046996, 0.014505886756523978, 0.04193906577711459, 0.06995760821155272, 0.08019647793844342, 0.04417736090545077, 0.06892225283081643, 0.05385468088206835, 0.0803697991068475, 0.13140575116267428, 0.06973486000788398, 0.05668827492627315, 0.03895360976457596, 0.06557546366821043, 0.022744277011952363, 0.014418137998291058, 0.00926740398426773, 0.030785293092776556, 0.11975720903137699, 0.010785274098452646, 0.06607916671782732, 0.034260757674928755, 0.007611612218170194, 0.0626214561634697, 0.048112012664205395, 0.051214423729106784, 0.04741134733194485, 0.01913227952172747, 0.0036204303751219413, 0.003681395951389277, 0.0260620871631545, 0.024786320464045275, 0.015597213059663773, 0.023440775185008533, 0.045941293792566285, 0.07136871296097524, 0.028389811086526606, 0.05997975553327706, 0.061641212669201195, 0.05952044404693879, 0.022906705307832453, 0.10239348412142135, 0.029084114357829094, 0.058488513677730225, 0.05153820420673583, 0.03657316367025487, 0.015607590139552485, 0.04367935754999053, 0.08232166976085864, 0.04754464818688575, 0.09283633640734479, 0.06116567412391305, 0.041769893214222975, 0.01756141078658402, 0.03287527557404246, 0.11132608487969264, 0.02732636727159843, 0.10136753175174817, 0.01957567936187843, 0.030304227402666584, 0.06409458961570635, 0.012442467595974449, 0.015693083696532995, 0.0239728783708415, 0.02909610189817613, 0.028900609067932237, 0.03615917143179104, 0.06346773458062671, 0.04715131362900138, 0.026483018482394982, 0.025906800183292944, 0.0393134437763365, 0.002512438682060747, 0.047975657871575095, 0.07956351502798498, 0.06726511870510876, 0.05418348569946829, 0.01933279854711145, 0.0666437778272666, 0.007546674760305905, 0.03615094843553379, 0.03207782676327042, 0.08337966806720942, 0.07750795892206952, 0.028785652248188853, 0.06343260873109102, 0.015643797669326887, 0.02175406647438649, 0.03156148493872024, 0.027368168739485554, 0.01552307157908217, 0.08258770743850619, 0.01804146344511537, 0.03754589663003571, 0.009718594519654289, 0.05462371656903997, 0.06087479676352814, 0.011126623066957109, 0.02286942908540368, 0.0309286760239047, 0.038069745278335176, 0.02728793700953247, 0.11539427126990631, 0.03445442111114971, 0.036297704427852295, 0.03407528012758121, 0.040549368277424946, 0.03672848775750026, 0.01852820842032088, 0.013141808194632176, 0.01543778860650491, 0.013347560288821114, 0.03714492166182026, 0.06021876048180275, 0.04417831456521526, 0.040073536583804525, 0.07338139519561082, 0.028119661910750438, 0.04771813633851707, 0.04821819173230324, 0.027132835566590074, 0.020343609248811845, 0.031065871298778802, 0.03633985099440906, 0.01633175186725566, 0.05294429945934098, 0.026704575539042708, 0.08154431459843181, 0.029053018370177597, 0.01821699806896504, 0.023022248424240388, 0.06682309554889798, 0.07012391608441249, 0.016071992758952547, 0.050523205936769955, 0.0509758158295881, 0.03126280760625377, 0.036414284695638344, 0.0225105116260238, 0.04313170080422424, 0.08373967648367397, 0.03615047346102074, 0.02639713344251504, 0.010141208658751566, 0.045263961583259515, 0.011722817198460689, 0.004489880730034201, 0.03020182401087368, 0.038858459010953084, 0.0588613315630937, 0.012309458033996634, 0.05246450840786565, 0.010522643806325505, 0.03169950214214623, 0.08018557578907348, 0.0672325532650575, 0.05903096425754484, 0.05563200953474734, 0.025142449303530157, 0.07615602560690604, 0.03568674990674481, 0.029056324638077058, 0.04975356911018025, 0.06694365001749247, 0.019843780210067052, 0.04657256831706036, 0.026477660176169593, 0.03498232559650205, 0.023314305799431168, 0.034118354378733784, 0.017166194884339347, 0.06681090206257068, 0.052788552347919904, 0.042814566259039566, 0.025531557330396026, 0.044374464196152985, 0.03331595544295851, 0.03803482723014895, 0.053110380977159366, 0.05757390572398435, 0.02288107709318865, 0.13441282964777201, 0.03117476291663479, 0.07050771033391356, 0.041018954798346385, 0.05373114669055212, 0.06385554384905845, 0.046446354972431436, 0.04131307534407824, 0.02587264469184447, 0.018864709309127647, 0.0517698210751405, 0.036907133835484274, 0.0965360835834872, 0.08751761633902788, 0.019618766600615345, 0.019806713644356932, 0.022427689800679218, 0.025737234282132704, 0.06402866463758983, 0.0023336462618317455, 0.034129130362998694, 0.026096320580109023, 0.01481719822550076, 0.017444240511395037, 0.010049537650047569, 0.03374788168002851, 0.02277344527101377, 0.0578827022400219, 0.031985726236598566, 0.0445846923685167, 0.03943754200008698, 0.04367248526250478, 0.033515960531076416, 0.06379960817866959, 0.03266912179242354, 0.03749207979126368, 0.06688336536171846, 0.07917167589766905, 0.08560741727706045, 0.09576457654475234, 0.052377781030372716, 0.03313512002932839, 0.04556101732305251, 0.06954759388463572, 0.02040094943367876, 0.02140897708159173, 0.029021445552643854, 0.008560132610000437, 0.01888132970634615, 0.03046110814466374, 0.06271865524468012, 0.054897416921448894, 0.006886765859235311, 0.05245933563855942, 0.08016593114007264, 0.01519042429208639, 0.020101433474337682, 0.013016358334425604, 0.02257555530377431, 0.06535981039633043, 0.01991872413782403, 0.020997749343223404, 0.055612105134059675, 0.04773332067998126, 0.04216919835016597, 0.0073458676888549235, 0.03619070899731014, 0.035291830863570794, 0.09251173585653305, 0.05969599536911119, 0.03959782363381237, 0.06821650749770924, 0.03663737799797673, 0.04733572248369455, 0.035527418222045526, 0.07380919138086028, 0.07478593193809502, 0.05344557939679362, 0.024879788397811353, 0.01264037333385204, 0.02984277110954281, 0.025246151453757193, 0.027624413778539747, 0.03388568737136666, 0.053136107526370324, 0.012439549100236036, 0.02422107667371165, 0.024231431489170063, 0.042081572973984294, 0.015880687496974133, 0.045551050279755145, 0.06779573202948086, 0.0630257633747533, 0.05001494238968007, 0.015683792007621378, 0.05037027527578175, 0.03462310014583636, 0.02798154266201891, 0.021465350619109813, 0.04675474701798521, 0.038889788775122724, 0.05565996252698824, 0.05474484620208386, 0.01339481746981619, 0.009215422105626203, 0.033627598095336, 0.032940391611191444, 0.03921407391317189, 0.015463433519471437, 0.01775230972270947, 0.026824244996532798, 0.05206965986872092, 0.055933276962605305, 0.023051190328260418, 0.03332625645271037, 0.052520755780278705, 0.04263775328581687, 0.03411498502828181, 0.09844927350059152, 0.040343307264265604, 0.04512813000474125, 0.0804524817795027, 0.01843956815719139, 0.018663305272639263, 0.05297574054566212, 0.0453847609605873, 0.015528503172390629, 0.0811247191450093, 0.048392262469860725, 0.01862529432401061, 0.1427415819489397, 0.09536241414025426, 0.1619067441788502, 0.14311013248516247, 0.26603340287692845, 0.23162406723713502, 0.1601244616904296, 0.09065845952136442, 0.12912432983284816, 0.19563884037779644, 0.13153721520211548, 0.12612520717084408, 0.11039087490644306, 0.13620612560771406, 0.20640486502088606, 0.1793405946227722, 0.12817374255973846, 0.14570324099622667, 0.10062121320515871, 0.10398784739663824, 0.20312694716267288, 0.13466821750625968, 0.14348460535984486, 0.136887313274201, 0.17558825144078583, 0.0873532157856971, 0.16200727550312877, 0.10115754848811775, 0.24035559792537242, 0.13827371934894472, 0.08344029411091469, 0.10866226453799754, 0.25404124637134373, 0.1158841629512608, 0.099801206815755, 0.1161198467889335, 0.13813011377351359, 0.10750706715043634, 0.10491913883015513, 0.11137101450003684, 0.1070782468013931, 0.10768783206003718, 0.12906529940664768, 0.14547946862876415, 0.1383740280289203, 0.1709585264325142, 0.3016912832390517, 0.1863796278485097, 0.18161656858865172, 0.13484375027474016, 0.1839367300271988, 0.1355007736128755, 0.17705160338664427, 0.10130548078450374, 0.1572699539246969, 0.16916370164835826, 0.12721220118692145, 0.1635855861240998, 0.13435587723506615, 0.17813752871006727, 0.10082025721203536, 0.10792569039040245, 0.08615588667453267, 0.10825550823938102, 0.19722675438970327, 0.13298186502652243, 0.12305656011449173, 0.08746702413191088, 0.10706946719437838, 0.07087392310495488, 0.14191499270964414, 0.09261818209779449, 0.08407670058659278, 0.1332591165555641, 0.17089274246245623, 0.1826753164641559, 0.13003834406845272, 0.11434171290602535, 0.10549522354267538, 0.18034846085356548, 0.17464746051700786, 0.11898036595084704, 0.13217984087532386, 0.16669692151481286, 0.10391704650828615, 0.20411532459547743, 0.1231047254987061, 0.11210565164219588, 0.1707166456617415, 0.1342104162904434, 0.17159741168143228, 0.19047669862629846, 0.10064848713227548, 0.13755724998191, 0.06754349829861894, 0.15691640961449593, 0.1943211571779102, 0.09667351449024864, 0.2202844960265793, 0.1015105213446077, 0.2970171481138095, 0.1491865556454286, 0.06686051463475451, 0.08719586563529447, 0.11432842104113661, 0.11182170594111085, 0.07526168570620939, 0.11571482711588033, 0.1830265749595128, 0.11044879953260534, 0.13273299322463572, 0.09589686436811462, 0.1027241480187513, 0.05501322535565123, 0.1910516998032108, 0.11245394154684618, 0.15474362386157736, 0.1549630769295618, 0.07491431606467813, 0.12656625069212168, 0.08417815959546715, 0.15482009475817904, 0.14094249723711982, 0.2146527825971134, 0.11918410775251687, 0.08385497654671781, 0.15578708349494264, 0.09583381150150672, 0.06776141512091272, 0.10942831679130904, 0.1539628696627915, 0.1492946271901019, 0.1957843013224192, 0.10360493630287237, 0.15095736453076825, 0.06967919151065871, 0.07999331501196139, 0.09667871694546193, 0.10206484628724866, 0.14877595502184704, 0.17059178673662245, 0.21684435952920467, 0.10037437488790601, 0.17802080372348428, 0.12970808835234493, 0.18321056821150705, 0.21928452624706551, 0.17485419317381456, 0.13705071934964508, 0.08592107857111841, 0.10358172934502363, 0.06781628952012397, 0.13124014833010733, 0.1417673795367591, 0.09386051504407078, 0.13064200698863715, 0.08165063467458822, 0.17617076315218583, 0.11711668470525183, 0.106562728760764, 0.16416217549704015, 0.16565093857934698, 0.0902329343080055, 0.13423168624285609, 0.09654245863202959, 0.15675389411626384, 0.19776234752498567, 0.14143776206765324, 0.25003753777127713, 0.14214660215657204, 0.19053194409934804, 0.140822239627596, 0.16491293208673596, 0.1667187554994598, 0.11546413705218583, 0.12076110477210023], [0.07879370008595288, 0.05603540761512704, 0.02355453158088494, 0.033380730092176236, 0.03563104801287409, 0.06406598724424839, 0.04838045861106366, 0.022140827459224965, 0.07749322729068808, 0.03592219996789936, 0.038047076377552, 0.04915151665045414, 0.09540196318994276, 0.025779134084586985, 0.02285416681843344, 0.025522935429762583, 0.05208891489019152, 0.04535658903478179, 0.0562847989203874, 0.07105176395270973, 0.024975176638690755, 0.06839650057372637, 0.014387817554961657, 0.017592196927580517, 0.074724630540004, 0.029651324839505833, 0.0009714327518395294, 0.04187121492577717, 0.008106250861601438, 0.024027223989833146, 0.050745468033710495, 0.046183133745216765, 0.04074470896739513, 0.010590478887024801, 0.03861583238176536, 0.01518584524092148, 0.03146228948025964, 0.06586788469576277, 0.021942792773188557, 0.0284851789183449, 0.024619476389489137, 0.009606725961930351, 0.01811547041143058, 0.007085793631631532, 0.023502199037466198, 0.04461484953935724, 0.018912804189312737, 0.0428405636921525, 0.06200561088917311, 0.05163273155631032, 0.03638305883214343, 0.055133520072558895, 0.025462789926677942, 0.09003024635603651, 0.05204792236327194, 0.026936934555124026, 0.011307965924061136, 0.019665805775730405, 0.02005363545322325, 0.006596534167329082, 0.04408744971442502, 0.00926859049286577, 0.07150512712541968, 0.0426026014611125, 0.04082716528500896, 0.011851975013996707, 0.04730619984911755, 0.04825627132959198, 0.06356360521749593, 0.07427789474604651, 0.04722747653431725, 0.0192729870104813, 0.005578921682172222, 0.00796030381025048, 0.040618380589876324, 0.043402020673966035, 0.02639816502778558, 0.01906794830574654, 0.03816500735410955, 0.061751391913276166, 0.021978987315378617, 0.04078933801793028, 0.0429255952622043, 0.050376223589410074, 0.023297193729376886, 0.03915089117072057, 0.1394353437353857, 0.037153897937969305, 0.026467887946637347, 0.011195621464139549, 0.059793409673147835, 0.06646089779678732, 0.034032940602628514, 0.04378641977382358, 0.06739681281032972, 0.041778980812523514, 0.056412069825455546, 0.010815836667461554, 0.022589884320041165, 0.031057505439093802, 0.06872694182675332, 0.07428655560943298, 0.05605042497336399, 0.017150598650914617, 0.07273781215189956, 0.041443099617026746, 0.01343679055935354, 0.0979216065024957, 0.06620013678912073, 0.053533204772975296, 0.052914821353624575, 0.0522935955086723, 0.05366310659155715, 0.04538880937616341, 0.016921824208111502, 0.012930476077599451, 0.03415766594116576, 0.0371584806998726, 0.056882450444391, 0.03719255641044583, 0.06481238742708229, 0.021990922905388288, 0.021974786759528797, 0.0565451591683086, 0.04549500699795317, 0.04931963165290654, 0.007797288290021243, 0.04351229268650059, 0.07430818179273047, 0.0746690362575464, 0.027832834821310826, 0.028109171653341036, 0.05062223441200331, 0.048004026466514915, 0.03338451875606552, 0.024297649615618866, 0.0470433719601715, 0.06657550766249187, 0.05387677461840212, 0.03554165261448361, 0.033959267602767795, 0.048413562108180486, 0.040086939770844765, 0.03398302746063564, 0.07604905244079418, 0.04333922013756819, 0.012480296718422323, 0.044003420043736696, 0.04995397124730516, 0.04195937464828603, 0.013837865717505338, 0.03430645912885666, 0.03156833496177569, 0.07876104558818042, 0.03445548238232732, 0.01673025548370788, 0.07000644152867608, 0.030895082709321287, 0.02399031141976593, 0.024035061069298536, 0.03957090593758039, 0.061683455714955926, 0.024672536237630993, 0.05232418312516529, 0.025035340695467312, 0.03296834089269396, 0.022629936174780596, 0.04180762771284208, 0.01631099214137066, 0.01619359180040192, 0.022539434976351913, 0.017778880464902613, 0.015382368728751317, 0.02323453049029922, 0.035830125416396186, 0.01751522322592791, 0.055357926976284944, 0.055247866475838237, 0.017233064245374408, 0.011295083168079145, 0.01715666199743282, 0.05271159534459002, 0.017701077413221356, 0.02547870528360363, 0.028115470631746575, 0.046573985819122754, 0.03148707350192126, 0.03835310097201727, 0.1463663499453105, 0.04943611544149462, 0.023730082903057337, 0.03905523204593919, 0.06690258698654361, 0.019874609024554957, 0.024122183640429284, 0.05168231815332547, 0.015630633824912366, 0.003219183595319919, 0.03868687817885075, 0.03603978955652565, 0.08459527627564967, 0.04037983206217177, 0.0355474970274372, 0.026120826296391897, 0.04803292940778192, 0.01509232906755642, 0.022073015570640564, 0.06388450987287797, 0.05962203664239496, 0.019487254321575165, 0.027803321463579778, 0.037176459227339365, 0.018179063190473244, 0.00923043946386315, 0.03525851214362774, 0.037860229567741044, 0.012321068934397772, 0.025174029542540666, 0.03344077726069372, 0.03295094124041498, 0.05410287361883093, 0.03592052271415014, 0.020168664632365108, 0.01830242483265465, 0.018520723861001898, 0.02579614596470492, 0.052603920848923735, 0.04908338378299959, 0.04643856984330341, 0.0582155443407828, 0.002471827433510043, 0.03382259739737492, 0.020056969551660586, 0.050989111405215226, 0.04637470432498958, 0.042849543679039925, 0.04113787283131387, 0.03435481747146696, 0.06627721624681726, 0.03150181997625623, 0.013640755005326355, 0.040365007662330754, 0.048598768771626055, 0.03630706291005481, 0.05728328811528627, 0.06345701054669917, 0.030513372039422393, 0.05985256997519173, 0.04069647678988986, 0.0195243394409772, 0.02929206228145631, 0.07753307319944724, 0.054275077854981646, 0.04211049075820483, 0.019986413572041783, 0.049202839873032644, 0.08023024565773085, 0.03401836111152079, 0.006449123229685938, 0.07206106252851896, 0.030712510670127813, 0.025571065561962314, 0.12229385494720191, 0.0249710502976086, 0.02263786045659799, 0.019301850988995284, 0.04180350879323669, 0.01798378743842477, 0.0709747958171647, 0.05905071280722041, 0.037771097631775774, 0.02820370085828472, 0.05560236815654207, 0.052795127776334994, 0.03977689644671045, 0.04282532740035094, 0.07400298840366304, 0.06820634749601595, 0.056381222457275726, 0.09272747076465748, 0.05654299209709279, 0.0755701816524379, 0.033120091538876295, 0.050478658522479236, 0.020151344760961365, 0.022663481249765027, 0.014595688480767421, 0.04600030566507485, 0.0012901758441330458, 0.03448309769737534, 0.07352679676841944, 0.028542945838125888, 0.01980651511985343, 0.05706055475457106, 0.05666205113811884, 0.03412905614823103, 0.035907516576116905, 0.03715805767569691, 0.03234653988329228, 0.0625657505588606, 0.0483344157692045, 0.03869966167258099, 0.019047724781557918, 0.03593523950257804, 0.022312872133625206, 0.06219849135959521, 0.013453250467136968, 0.046481310128001496, 0.05408385979535524, 0.0253069018071983, 0.028819139806728344, 0.0208800966720446, 0.05101701244711876, 0.08130613714456558, 0.05118216256960295, 0.023991650996322278, 0.027757104217016604, 0.042288539407309145, 0.050384268470224924, 0.025083947657549288, 0.01979685421247268, 0.044994049894739874, 0.0062847356639395, 0.06348151626298204, 0.05639257731672842, 0.021782223557238467, 0.021460689931700472, 0.04637145742890425, 0.034649130975594744, 0.06722077538142912, 0.03515230338962283, 0.008876758784026606, 0.015093966430868022, 0.032710336963646114, 0.044314572878647596, 0.04846707095566671, 0.02743958746577846, 0.13323426945134997, 0.030022155624465086, 0.06122665268776473, 0.0645083369454369, 0.06768272520275787, 0.022558233577001374, 0.011350531804055208, 0.038398045435315, 0.02695052513445262, 0.010606924879539292, 0.026395934874017257, 0.04158386647759471, 0.048097897015395574, 0.022286282837740146, 0.03906584104697686, 0.20067452016519383, 0.25143301289062947, 0.11863087376696058, 0.10336312974686734, 0.10228557584923692, 0.18971598241478205, 0.07312005531275645, 0.1253067221841775, 0.11175261199241504, 0.20298672578064725, 0.09868043765891343, 0.09852192233665846, 0.21228034427622333, 0.08540016511688009, 0.08594150247517973, 0.11748910183086991, 0.14023898576851934, 0.1592779383645393, 0.1729762033210136, 0.13427291996777058, 0.07266169006470591, 0.14710217452375218, 0.19190752966096625, 0.0995752376911696, 0.18983456277055666, 0.15236006816849113, 0.13037593220360577, 0.06913139004609548, 0.13218484295066446, 0.09489405958447605, 0.05567520624026656, 0.2062311430927366, 0.18401563516817987, 0.10098632017616183, 0.10663654276868328, 0.107672202429967, 0.08278954192064703, 0.21263543225359172, 0.20271271001547575, 0.09137545581324957, 0.0801686399790924, 0.1793287499458529, 0.10797773720696568, 0.11777266903663985, 0.11097179100033827, 0.15818612038856372, 0.09947527039912529, 0.13459640729706734, 0.27667016023769975, 0.1175083605630789, 0.09227217058651149, 0.139803463825956, 0.10462260630447417, 0.16051791870268062, 0.26294710754882544, 0.08640043175546452, 0.11281712635536678, 0.11244963709032163, 0.11489393014926463, 0.07978690147865564, 0.15557034668745473, 0.12243585748365149, 0.10970029907184653, 0.1329677939065732, 0.14591792947612703, 0.0951652997173369, 0.10315384410205297, 0.1385613312595524, 0.18277359165949747, 0.1858116770745255, 0.13814632227877155, 0.21571911522187293, 0.0976365253154654, 0.10953932724078186, 0.1244821070577018, 0.19647215347504243, 0.12235511181643233, 0.19440884934738278, 0.11008248286088929, 0.15044562402181327, 0.18260084936628118, 0.17007091781124473, 0.1444663479924202, 0.21445571270305663, 0.1317932561505586, 0.09962102078134194, 0.2240968492696993, 0.11285101281828247, 0.10304137162165716, 0.13032810820732266, 0.1335657126037404, 0.1481502503156662, 0.19896015903213993, 0.14841918979072943, 0.1307108040782623, 0.1178650367364753, 0.1367747740005143, 0.18234783638035879, 0.2017905915272422, 0.10575904219876975, 0.15776563435792923, 0.11009587862645276, 0.12360750086372718, 0.20453411852940917, 0.25266301876399666, 0.19783531548455358, 0.08112342780805193, 0.13798863074043766, 0.1860413866234012, 0.07175875609391369, 0.1863526730448939, 0.1165625749854371, 0.090507744171191, 0.1529685253626667, 0.06488335158792324, 0.0984807257191278, 0.08869790573953651, 0.0969663511204999, 0.24135203508194536, 0.12390741758281365, 0.15653549489798024, 0.08442028527497314, 0.2557828591670841, 0.14785438572289422, 0.09291930109611712, 0.2044859086163342, 0.15617680008290336, 0.14130470983218402, 0.14396887156181037, 0.12643305002711713, 0.09043911035405472, 0.33176643191836774, 0.23046616843203083, 0.13719270704314113, 0.1172774338920135, 0.16285167628666386, 0.116476678813342, 0.17263563175220042, 0.14392627228517085, 0.1451865429407917, 0.060883502155775204, 0.165362955594901, 0.12309521116549149, 0.17243189737200737, 0.14225502993213013, 0.20304229779867455, 0.11405824960093014, 0.1721457252278924, 0.2427160579827614, 0.16901644470635802, 0.106298962055007, 0.13207697920734063, 0.11138006128021516, 0.1592972342041321, 0.20971252815797925, 0.1365726871881634, 0.19577349565224722, 0.158820582437329, 0.14187818218488246, 0.13446503231534734, 0.12260511168278754, 0.284537875559181, 0.1252443075645715, 0.2175533480476588, 0.19024833978619426, 0.16611521132290363, 0.07932415013783611, 0.14970420364988968, 0.1064017866156064, 0.09015216637635604, 0.13106955826515332, 0.0984446944494266, 0.11074925801949576, 0.1223424804629758, 0.14689404662931338, 0.10339254848076962], [0.0036455270264923456, 0.03198477628757246, 0.06020103057380766, 0.06590706267161295, 0.032246624541585334, 0.02774750639218837, 0.05982904389384203, 0.05009964370401576, 0.07656057772692293, 0.027598909873631783, 0.013510231638065306, 0.04302857938455418, 0.03616165391576942, 0.03712644589541014, 0.04746247017465066, 0.034466518118279055, 0.020454888726817444, 0.028002114995615557, 0.052450444709393196, 0.07403064824757166, 0.02128058553353185, 0.031697947342763655, 0.014464403484453214, 0.07906133338110521, 0.059615694990498014, 0.02478328508004779, 0.04149510932620615, 0.09536192432278767, 0.05169620744709391, 0.06118735967902467, 0.015434468423336511, 0.009618156891519902, 0.059887306197197177, 0.06242483155801892, 0.0556992110068677, 0.07120129186660051, 0.05181940025067888, 0.036965488907299004, 0.025460821379965637, 0.02469440732966177, 0.005853857246620464, 0.033998148719547316, 0.03176893376803491, 0.07044971891446039, 0.013767947984888451, 0.002470985559739347, 0.02608986760606058, 0.0955639591848012, 0.02649331021530088, 0.04339449900726322, 0.04833706894714851, 0.07037918519927189, 0.02903182448790176, 0.045246840236359276, 0.04558050241030287, 0.013576441415352747, 0.027094264296465553, 0.04036190177430399, 0.06286589734372683, 0.0476456470642006, 0.03660667905933224, 0.057490365870762616, 0.027210998559894506, 0.032716949499445036, 0.03692821082950104, 0.029610139354190324, 0.055557319792569615, 0.02620836632559076, 0.0597159554308746, 0.05513671501830686, 0.09942467819200829, 0.05412478552898392, 0.04950973278027959, 0.045750981153105386, 0.030757134154555388, 0.08634833298856393, 0.090304707409814, 0.30969362414907664, 0.7846748165320605, 1.447871932759881, 0.6429735920391977, 0.5590446456335485, 1.6071295808069408, 0.9678190515842289, 0.46277577232103795, 0.7776372379157692, 0.25755074399057776, 0.10362323024310172, 0.13950519467471167, 0.023485875499318354, 0.04016906212200411, 0.055214069070643745, 0.017442537282477133, 0.08211525622755289, 0.03714260987180751, 0.057398536227992736, 0.08583756469306536, 0.07296754396520555, 0.08867801618180238, 0.04934022625093348, 0.052001007497892715, 0.022886570841365028, 0.015916238226054702, 0.02676368018001085, 0.03161428503517527, 0.01920428083394654, 0.09088062884984538, 0.12213681649882346, 0.03685799994855188, 0.058063578471774235, 0.029123175445420202, 0.07371842672000639, 0.05644672812195495, 0.01729544732370414, 0.015329628004110418, 0.03250607936934102, 0.05112917693622876, 0.05976355307211634, 0.025897861014527734, 0.02246760621346766, 0.062270828493637964, 0.026996983579010703, 0.02765247623756295, 0.023405018509947695, 0.02410626271739602, 0.046968912283773534, 0.03688948185299523, 0.0475968248792924, 0.0424706513149431, 0.0438539848983055, 0.07453651836840436, 0.04410157649544999, 0.04685189043811988, 0.03795994081883691, 0.016876542067620903, 0.05526800836378243, 0.021125821767782327, 0.0494412770785857, 0.009716913555166684, 0.03953986561100464, 0.027386291985749267, 0.024831973678374197, 0.08401410043006763, 0.026618723895808216, 0.02781264283839846, 0.077803489548387, 0.021593372948700562, 0.019018057428183965, 0.010826387224369682, 0.049671751039568335, 0.057735085356398486, 0.05893424015084747, 0.05630420237139333, 0.04023969602712896, 0.04034118101117201, 0.029846079232811462, 0.030492450896417722, 0.05102937291667331, 0.08092087344266474, 0.017907895417010877, 0.04506354089244269, 0.05093441883218475, 0.04632318072253838, 0.05102447474200744, 0.026287147156836, 0.11522087588673458, 0.031977863181964494, 0.0282385409809649, 0.009194991707772715, 0.03343899981700815, 0.04809893602214288, 0.11128640966489911, 0.07331760760280304, 0.046773204230703413, 0.04978504359314684, 0.0311084316126653, 0.042113960298593156, 0.07827692781575024, 0.07251952425576746, 0.04311041600885801, 0.044582944610738195, 0.04936599732900504, 0.015269210689439205, 0.026686279743444175, 0.07505218483856879, 0.02121631183399586, 0.12349674274446443, 0.0029495664466594462, 0.01674217066465644, 0.018896170804509893, 0.016813619076856412, 0.028176575360703282, 0.02498221590940375, 0.07221358129754663, 0.022079993614170235, 0.06425556886824779, 0.0038520646376127843, 0.044005575982737355, 0.041157350497087464, 0.045357386843534186, 0.018634812367963605, 0.053594012642861344, 0.08377359263249673, 0.11847845889860764, 0.028400657574820798, 0.05089625759865157, 0.032918301585596055, 0.05536921504244674, 0.06941883868421428, 0.06328460964141414, 0.00038316774350732885, 0.051345420215511695, 0.04590788601490203, 0.04677410594013054, 0.0229371482055285, 0.0075590264168567955, 0.04052258045703638, 0.05239287631411571, 0.03647750825621188, 0.00742672514206788, 0.06060749743483029, 0.021227954275673255, 0.04373451396531891, 0.05240092119493056, 0.04502317919104826, 0.04204925615340471, 0.035431399155640975, 0.04438395997567568, 0.008049219595704926, 0.03134500788291916, 0.032659087955835275, 0.027538059330254328, 0.04587353570968844, 0.009345901871711249, 0.06000306268106215, 0.05325039084709715, 0.04735861402878072, 0.05562226513575297, 0.012391967229632428, 0.01671179084951291, 0.02722571349295322, 0.012553350952657638, 0.019657462180475704, 0.024716957486816682, 0.058877013143501244, 0.01458099117371603, 0.014321656017273199, 0.054841484961798415, 0.025760888383956626, 0.0731056131189689, 0.04284399241441861, 0.10161975063965656, 0.1461905796895735, 0.5385329900309443, 1.2333225016482174, 2.0939750131219625, 1.1833694321103394, 1.0097470111213624, 2.4169291835278273, 1.7071077972650528, 0.572094451636076, 1.2064972473308444, 0.5739000078756362, 0.08117920020595193, 0.0996759619738441, 0.025907453273248393, 0.00814803099274286, 0.02203406209446257, 0.03328460341435857, 0.0383055775455432, 0.027936561091337353, 0.022422088441089727, 0.06654007011093199, 0.04076221252034884, 0.06732168520102277, 0.03254744668083731, 0.011751191359508084, 0.040434676775475964, 0.018147744558518752, 0.04200979616143741, 0.045864956482546404, 0.0369868479174329, 0.020408170530572534, 0.08751253262744285, 0.029018907407589722, 0.01914581072924193, 0.07785230802255683, 0.052251845991122536, 0.08677747246110812, 0.010310999059583992, 0.037378523775259964, 0.02394211263890611, 0.02114444967446616, 0.06907421498908661, 0.026436927400936838, 0.028186390263726935, 0.03319565701531246, 0.018513660470489413, 0.03304845573438797, 0.00611758220657066, 0.039940428687259555, 0.02410745571978623, 0.030022853243281133, 0.017856575905170757, 0.020738159073516726, 0.04174329835223034, 0.008391789397137472, 0.023094769239833113, 0.05185979163798038, 0.07849795423680916, 0.043589591077761725, 0.02045951045147376, 0.0659710580657702, 0.043213693279540166, 0.06817718109232374, 0.01225942985911388, 0.08322765395860188, 0.00813978480437072, 0.0696682596753817, 0.01922642837598687, 0.05218284481088631, 0.031473251001443714, 0.02669448047527112, 0.024355255118280184, 0.03125530820398126, 0.008396289595111739, 0.03894709741871338, 0.021181267620704602, 0.06949763992452063, 0.08840228605549783, 0.03303111545392312, 0.04002957917691674, 0.05574545793933794, 0.07210016628960148, 0.05978184701234568, 0.049392799992347136, 0.03417751839151606, 0.040149621563614346, 0.05781422427389771, 0.005543178458538023, 0.01097221274903859, 0.06224863827810623, 0.016070933343144134, 0.0491642519045854, 0.053646664309781045, 0.0755665080214385, 0.02338807342312066, 0.04708687665697653, 0.05657902707753237, 0.02181767409638269, 0.04213993175653741, 0.04430017892445903, 0.11693668420775793, 0.15294550394173712, 0.20570182852679864, 0.1717588139581494, 0.12473540205974132, 0.18720881460467353, 0.16466275410493836, 0.09986272343667224, 0.13178449880797416, 0.11034909199224785, 0.20639802241930738, 0.14318632136564702, 0.10486303988727741, 0.12184709688881412, 0.12242451004567556, 0.09775410377187654, 0.12345994706265628, 0.18878950009820983, 0.09750492768944241, 0.1860227290308103, 0.08345688111148775, 0.11268567715887912, 0.14732596173416823, 0.14433338481467217, 0.1603313724626787, 0.12389221097691916, 0.16978211846435443, 0.3035039344104007, 0.19085746491327882, 0.13277767051476985, 0.15689844964072108, 0.09250268907635473, 0.12775998038705438, 0.07996496497071348, 0.11511384334880859, 0.14843943557934836, 0.13851824216544628, 0.16819061245769262, 0.10960071769659407, 0.11544783948920667, 0.11086216836702079, 0.1411391663714312, 0.20790087146451697, 0.14026178454514593, 0.1677313121035695, 0.11553149437531829, 0.19786023680353537, 0.16367146745324135, 0.1427193175186403, 0.14384447276825085, 0.21113773371325806, 0.21013022371334955, 0.0983323332911823, 0.10401170002296567, 0.12688657647231594, 0.08105058601358905, 0.09936342874425463, 0.11581912855035625, 0.13058043841738254, 0.15829913463676348, 0.13524967536795884, 0.13179859961383045, 0.16165802080649883, 0.13185709569370374, 0.09426458476809785, 0.12727463064948097, 0.1849773694993928, 0.12991143681574613, 0.17293124401476234, 0.1502529624849558, 0.19438796531176195, 0.1869400532450527, 0.08941464227973484, 0.16908982826862484, 0.11265599125181325, 0.18774814816424623, 0.36116215924266726, 0.7510871719568968, 2.002445524558425, 2.8699192637577653, 1.9329948700033128, 1.504773166961968, 2.814718675799668, 1.8537194863893092, 0.9789838024880737, 1.5946884546428919, 0.8576984074898064, 0.3176889888709411, 0.28181080939248204, 0.12174571209470741, 0.07624649340868928, 0.117971824365668, 0.11032722832169384, 0.17841316235717386, 0.09645883343182504, 0.19777938723564148, 0.18028224643785506, 0.19047656503971666, 0.16027360368752852, 0.1392214122461155, 0.1223970134742558, 0.12033883016556501, 0.06792238695197739, 0.17986576800467446, 0.14299349655630067, 0.15516229905188084, 0.17061106773326173, 0.2047830942319706, 0.11167037460836582, 0.14625191077357158, 0.14772308495594189, 0.14752950315596536, 0.13539056468289346, 0.18988655763678253, 0.09183709393255413, 0.15379250224214047, 0.13194413477322087, 0.2276133676059544, 0.09341796496300958, 0.07124828465748578, 0.11659659503493458, 0.13419411872746423, 0.12587835401063785, 0.21392892143921927, 0.11579828162211925, 0.10982270890963264, 0.15396595699712634, 0.1328772073611617, 0.09237462407327257, 0.11844985652714968, 0.11657521376037039, 0.10898756270762533, 0.1179682843212504, 0.19115681760013103, 0.14686636452097446, 0.1637749228393659, 0.12105195244657807, 0.15141095034778118, 0.10137668243260123, 0.13157024077372625, 0.16854733315994963, 0.14580421760911122, 0.2207703801104799, 0.15243603440467268, 0.1739627995993942, 0.15483312687138095, 0.16002447955543175, 0.10852659252122976, 0.14393317425856367, 0.16639462992316112, 0.19532614387571812, 0.3610612271586433, 0.14805810526013374, 0.21964967774692923, 0.1549291459377855, 0.14746149274287745, 0.09716763641336001, 0.17838683095760643, 0.2183496576617472, 0.13419334689388052, 0.14659481268608943, 0.13478029664838687, 0.16587558668106794, 0.08598741915193386, 0.06872579891933128, 0.15598295110976323, 0.14331361453514546, 0.10959923340124078, 0.13133732514688745, 0.18119357409887016, 0.11275299737462774, 0.2130723197478801, 0.1264371318393387, 0.13859845348633826, 0.11972904452704825, 0.1531825607526116], [0.07850320864235982, 0.02168374056054745, 0.035309193408465944, 0.06834938161773607, 0.033983918037847616, 0.006933784161446965, 0.08161758683854714, 0.06139326484117191, 0.05073010557680391, 0.05094276799354702, 0.041324864359921776, 0.05935554625466466, 0.05324872843630146, 0.050322737006354146, 0.032195063831750304, 0.012678270177275408, 0.030189428289304487, 0.03368591977050528, 0.09246948538930155, 0.049287084766547196, 0.036644799474743195, 0.050220532139064744, 0.024542126047890633, 0.03062608200707473, 0.05278045551676769, 0.0541589614294935, 0.013941189372417284, 0.04788306381669827, 0.01556156585138524, 0.055503016847069375, 0.03022502725798404, 0.11734605286619626, 0.01762957890605321, 0.025004474773595575, 0.008223312597692711, 0.04200417439278681, 0.11503581394208595, 0.05269398789096158, 0.07790659612510353, 0.04358127902378328, 0.016518556003575213, 0.07754056146950461, 0.03143581336189527, 0.04835105472011492, 0.04592103687173221, 0.0055238093318621395, 0.018211081296612974, 0.11192877558642067, 0.026943417215079535, 0.039001700934022665, 0.023219396243803203, 0.17300646810326725, 0.02214641026512254, 0.014984364206611644, 0.051374345421209, 0.04422127007273957, 0.022836095522507094, 0.0579682421812322, 0.07881465091486461, 0.08655669837025926, 0.01932194092660211, 0.008603801506978925, 0.11831713083665818, 0.041031819928321056, 0.002438402725601918, 0.04425179460668005, 0.05503667351149488, 0.04177203059953172, 0.028465217001212295, 0.04418059666932095, 0.03896197376889177, 0.05562404257943854, 0.05080906266812235, 0.21249604207696393, 1.4669813448563218, 2.495253193192184, 4.953885851427913, 8.723356258124113, 10.32494181767106, 12.195015270262957, 12.22531484439969, 13.719124887138605, 17.10797969251871, 15.23936441168189, 11.085688546299934, 12.184232398867607, 8.24710976332426, 3.7913828808814287, 1.5716511220671237, 1.3116436614654958, 1.0231572040356696, 0.9454254875890911, 0.24491890071658418, 0.3951996343676001, 0.5318936181720346, 0.3671328560449183, 0.34897063218522817, 0.7157026987988502, 1.3043239479884505, 2.2930971533060074, 0.8039194776210934, 1.0100049222819507, 0.5670399509835988, 0.27074194396845996, 0.14343551971251145, 0.03008926061738748, 0.07258462544996291, 0.009899279648379888, 0.08891133256838657, 0.0366297709842911, 0.05301948272972368, 0.01831557568948483, 0.03463523797108792, 0.04416131567268167, 0.03495820208627265, 0.009423273550055455, 0.038076721466495655, 0.010236922516924096, 0.04672289032896515, 0.02797179826302454, 0.0562050143344095, 0.027112385687360074, 0.03773909622395877, 0.0921390664007049, 0.019310862517158967, 0.020194300268485676, 0.06263809511438012, 0.09159807785181329, 0.0024545611358917085, 0.015967216349963564, 0.06558078486705199, 0.05285223604005296, 0.018487685301806778, 0.13603672297904268, 0.030478808366751764, 0.039561762678204104, 0.02665527837962145, 0.045361138400039636, 0.06145587241917383, 0.07199547151685692, 0.0861099328903947, 0.018929829057015013, 0.026486950009712018, 0.053783156399731524, 0.07209223273093812, 0.045511746138799936, 0.008256714809249388, 0.07266497035743669, 0.040405862891930155, 0.034363671293249354, 0.014059696441108827, 0.029291368373378646, 0.017766204582585488, 0.06303679168922827, 0.020833142843912356, 0.038423608712037094, 0.04013646699604578, 0.05042713863076642, 0.004993649181415094, 0.02369111458392581, 0.02400434728770051, 0.10360863961977884, 0.0285115604128805, 0.050896547036245465, 0.045380326628219336, 0.039109056306187995, 0.04191895728581585, 0.03709000644448679, 0.03149733740428928, 0.04925710200041067, 0.02240034351416398, 0.04922376843751408, 0.023786497258697636, 0.02754406516032759, 0.016994766192510724, 0.020265277416910976, 0.10444519590237178, 0.027554343905649148, 0.009514954763290007, 0.03664020558062475, 0.033482289290986955, 0.02095740619552089, 0.06211256179085467, 0.0218715187656926, 0.027020927118428517, 0.023868422940722667, 0.035174790464225225, 0.03879844523908105, 0.021979423327138647, 0.09668880273238756, 0.08638716215500608, 0.025908382813213393, 0.034495172440074384, 0.04846402443945408, 0.060648122598649934, 0.03158763451210689, 0.06234688378754072, 0.03894950197718572, 0.03923785603547003, 0.04903860630292911, 0.04292796642403118, 0.016843037810758688, 0.02101153659168631, 0.006700311460008379, 0.036137719653197564, 0.047030080095282756, 0.03442880217335187, 0.0969240561244078, 0.06681804152322002, 0.017525281182315666, 0.026310621287848335, 0.04957899742294103, 0.06561219997820444, 0.030874174553900957, 0.07866512300097384, 0.02969386103359284, 0.027793343288067263, 0.017748239042703062, 0.046229517975007184, 0.07376426176051609, 0.056421795670758, 0.04439334443304688, 0.06110471782449167, 0.040272216938319616, 0.05339035618817434, 0.03546336716681253, 0.08694597709109075, 0.0999867363134399, 0.001728688641833287, 0.04125836792809423, 0.011429632686486002, 0.01510123947809916, 0.03307175174995791, 0.10859105546842329, 0.05082492236397229, 0.08448510445305146, 0.018412954741506837, 0.06545174765051343, 0.04595334998157341, 0.028587010856426787, 0.017831383702286985, 0.024164378446585033, 0.0010276228977090796, 0.011553116783034056, 0.024052720473264344, 0.03969819168560207, 0.04123948769120034, 0.013189807523303898, 0.06875428996863775, 0.6086540117394179, 2.3092052014544606, 4.020182378590107, 7.031879872083664, 12.082975432276726, 14.296285416930914, 17.69945975393057, 15.231578629463911, 18.254522569477558, 23.09298723936081, 20.903155244886875, 16.30479969084263, 15.49623442813754, 12.633093763142824, 6.043787067756057, 2.4826053343713284, 1.7899185349233449, 1.2356453645043075, 1.1670421832241118, 0.4003454785561189, 0.6459670001640916, 0.5595189076848328, 0.3396846726536751, 0.27481488010380417, 1.0011253925040364, 1.4228305639699101, 2.3356807557865977, 1.5089914156123996, 1.3782209577038884, 0.9192318900022656, 0.44038752210326493, 0.39516757358796895, 0.06619272273383103, 0.11758319131331518, 0.01465266315790359, 0.12936071871081367, 0.10117850673850626, 0.03815383432083763, 0.04074113181559369, 0.031393989629577845, 0.05467475777550135, 0.012993212603760185, 0.044472524168668315, 0.03214282405679114, 0.04767929232912138, 0.01564728947414551, 0.009022001722769346, 0.04885403788648546, 0.038020603969926015, 0.03808655863394961, 0.03343676224176306, 0.047773994083399884, 0.0224540527415229, 0.04048303882882465, 0.07137010819860734, 0.04127115513256285, 0.03266386738687288, 0.04879554551735055, 0.05612206077785231, 0.01016624779367703, 0.03786959176068194, 0.07879633471020497, 0.0510197695257375, 0.033563836477696896, 0.0607932273123879, 0.049542016204213724, 0.043763884459622204, 0.03093617171543883, 0.13017988647334278, 0.030180403773556463, 0.01862820725364145, 0.029934712074464187, 0.08389043636270799, 0.0038967924865573877, 0.06912492593983188, 0.0807736387650948, 0.06649738919804804, 0.019988081548945047, 0.02213368243246805, 0.06407631793990731, 0.032715799170546234, 0.02056191755400505, 0.018968630392919295, 0.0061052718319842825, 0.0522364278731402, 0.03426206385483965, 0.06888581337989308, 0.01585026315297, 0.0903892528731376, 0.064115161949303, 0.025493572356936056, 0.03743994762771763, 0.05266658037726302, 0.0719257615855895, 0.04798199581273366, 0.036206149379722774, 0.035523815095075406, 0.03607387639931403, 0.024144722665369045, 0.07039094081846997, 0.10606509647914208, 0.015816966697457246, 0.09546288609271869, 0.14729056128999218, 0.17338843666948378, 0.059627962691592984, 0.12005514421616681, 0.1861766356159933, 0.1592686615185812, 0.207389130955562, 0.13192826765589416, 0.14933312981156632, 0.07350068059167825, 0.13412468339083716, 0.1379448440275155, 0.10114662407431751, 0.18130376818589866, 0.14120110601652414, 0.11535730489413254, 0.13161120732547715, 0.19599836639827117, 0.17863499029772356, 0.1069258913048543, 0.16089435084722936, 0.13902425329433754, 0.1297264193999581, 0.23325910762650892, 0.17373659298755229, 0.16478459991049021, 0.09675089080701582, 0.16653390135616064, 0.11819305116659962, 0.15786178701091558, 0.08987945679109544, 0.25534481392242014, 0.1473461333080195, 0.1250578652252443, 0.10601786620100029, 0.11677967544528656, 0.14900478883646429, 0.14647295203758404, 0.21954295691102743, 0.182870501303114, 0.08578931025112979, 0.17333835654426366, 0.11599029749049805, 0.14462874474702403, 0.23999622033443302, 0.0897840982361231, 0.10467749554663897, 0.19206731405574828, 0.11994401502306573, 0.0872333069855813, 0.28267603483982384, 0.27578465931583196, 0.10220480049611069, 0.1057125763327349, 0.18765635933959857, 0.1752158417366445, 0.12101488959160633, 0.1574124611215666, 0.1375600998289883, 0.1546662178589031, 0.15968203777447343, 0.1291689625941217, 0.29645908274687827, 0.11983781369053759, 0.18383904854999855, 0.12724061059998348, 0.16040410293499008, 0.12005028314888477, 0.07614147951244377, 0.09396952169481665, 0.1848774912650697, 0.2489494750625454, 0.18554290087195113, 0.8022372960112989, 2.7255804464221, 4.868455985561013, 8.121014479547739, 14.074061941355467, 16.97511412203312, 20.873628929257393, 19.49748907238245, 21.940180398523808, 28.194078616797924, 25.792514383792877, 19.476500898599625, 18.44001341611147, 15.195491965860128, 8.004539329558611, 3.3854919858276844, 2.6334600895643234, 1.4823657693341374, 1.6603567684069276, 0.7060786464717239, 1.3109556608833373, 0.9624833066482097, 0.6698985316324979, 0.7207639084663242, 1.782219079323113, 2.416357076726854, 3.4677131613716483, 2.9420073330402374, 2.179915001615882, 1.6539967409335077, 0.9753335639834404, 0.723382739815861, 0.14046436117496341, 0.32000864564906806, 0.12356167324469425, 0.2255824359599501, 0.30678449431434274, 0.11732938422937877, 0.0975638245290611, 0.08461982652079314, 0.12632232159376144, 0.10807433514855802, 0.1497380604268983, 0.18110950361005962, 0.1416023407364264, 0.0554662508511683, 0.10983099869918078, 0.17893895914312452, 0.09270311347790994, 0.12837691290769726, 0.15042767889099196, 0.061817365130991675, 0.0686620113265235, 0.21838467218913138, 0.1307344637461938, 0.17350247508147731, 0.1525291590951383, 0.16532607085537165, 0.10858050212846138, 0.21573477453785017, 0.2227375761140138, 0.15889191767200828, 0.14800827746512368, 0.11656189963105135, 0.11135598600958474, 0.15207912074401975, 0.1918706894502975, 0.20869753730949014, 0.25575367792043835, 0.1587231978191994, 0.13746724231168628, 0.2458315939293243, 0.19339240388944745, 0.08696450851857662, 0.1173632632708177, 0.13435137982014567, 0.17351929214783013, 0.060417348067858256, 0.12599945766851306, 0.11914122645976022, 0.1315464178333059, 0.09365622405312024, 0.15814746933756396, 0.17096110910642892, 0.19614627643022686, 0.10646187089150771, 0.11179127046489157, 0.08373045900953002, 0.2295383799355477, 0.20434230304090306, 0.11948821018449962, 0.10156078700674698, 0.12842314870795235, 0.14913885039277375, 0.1212369253335055, 0.12047816097037867, 0.09211248267092742, 0.10294193125446327, 0.0719616592687089, 0.1760742542683147, 0.22283147263806313, 0.07495384284993634, 0.22473727818578482], [0.006554700694323401, 0.06521172967040911, 0.02586449776572408, 0.0442327065684367, 0.032540095708100125, 0.03626726524089463, 0.046869393991073593, 0.06280956833506934, 0.06478923241957091, 0.038182893113116734, 0.08711860806215554, 0.02912611249485053, 0.03714617218065541, 0.070844905130798, 0.011009769132215297, 0.04624158529622946, 0.0906194002891425, 0.004253964971212554, 0.05984060655464418, 0.044207180399098434, 0.05146994146343786, 0.05963751413219143, 0.0338450213894248, 0.05786077548691537, 0.04528562487394083, 0.041974184205173515, 0.10547045065322891, 0.05297246767440811, 0.0537729592906544, 0.02496145618351875, 0.022094764208304696, 0.035539340824470855, 0.030925330793252215, 0.04351298659457825, 0.027296492116875015, 0.012064385100529762, 0.038695379480486736, 0.039047098107403144, 0.04305841001041699, 0.03346092657011468, 0.015098471267265268, 0.11018989389413036, 0.031100841297302395, 0.05126600670337211, 0.0908586909645237, 0.021919749087828677, 0.13794616505037993, 0.017163831143989228, 0.01966795800399268, 0.022131287150841672, 0.042946089670294896, 0.0038511181674039108, 0.053877579848631285, 0.07512914555263706, 0.006428360256904853, 0.12404297085595317, 0.007261424270836869, 0.03504225402139127, 0.05784375804068986, 0.03777695317694452, 0.018860360323742498, 0.03993091806478333, 0.01113974702093401, 0.017804139461077284, 0.03402608686883468, 0.1404154536430724, 0.056776308483676985, 0.06852107006125152, 0.050250600252184086, 0.043862300663022324, 1.2253065942786634, 1.7229231423698366, 4.071042174473405, 14.556523952633142, 17.652796357870102, 25.2949158847332, 31.92165769636631, 34.42484937608242, 42.28575736284256, 48.363656625151634, 42.57830746471882, 48.61568570137024, 55.50377368927002, 46.42852686345577, 56.515427604317665, 42.37252190709114, 40.20565778017044, 32.214606776833534, 23.020555526018143, 16.278391107916832, 13.185405526310205, 9.862728919833899, 6.95569870993495, 6.26690729521215, 7.763317348435521, 8.33558326587081, 7.851896770298481, 7.803813200443983, 7.725249091163278, 12.016121819615364, 11.245059594511986, 13.002547938376665, 13.532425705343485, 8.343152459710836, 3.901068507693708, 2.6120570255443454, 0.30616129806730896, 0.0925434181408491, 0.037045347708044574, 0.061714496041531675, 0.09947771948645823, 0.1076745253521949, 0.04734970454592258, 0.028478885506046936, 0.084141363913659, 0.02143991536286194, 0.027166456711711362, 0.016524836428288836, 0.02019895167904906, 0.010598779808788095, 0.06042367487680167, 0.02356008655624464, 0.056108694698195904, 0.07575376672320999, 0.06534688960528001, 0.055173043147078715, 0.026023488062492106, 0.03697802378155757, 0.04314884812629316, 0.02825623934768373, 0.06391815142706037, 0.05489861548994668, 0.004924915638184757, 0.01652256731176749, 0.01768784120940836, 0.02837705356796505, 0.031074793769221287, 0.027049833770433906, 0.029683675056730863, 0.02842691661498975, 0.025498830473225098, 0.04517172375926748, 0.0971981386828702, 0.03551092398993205, 0.04236427557771094, 0.01489418862547609, 0.017939920944627374, 0.0308480936291744, 0.016172045397979673, 0.01639533536945237, 0.02688115659111645, 0.03660835631308146, 0.0855735011282377, 0.04017854305857327, 0.03537937460350804, 0.01890062183520058, 0.05843392129463609, 0.05645180070132483, 0.03651529099442996, 0.04754391346068587, 0.010720694263000041, 0.02184907250921242, 0.014533213561662706, 0.019219431778765284, 0.007351155954893329, 0.02640312257426558, 0.02414095441054087, 0.027417649580456782, 0.03787361420108937, 0.015937140815367457, 0.10084462934173644, 0.050894101659650914, 0.039757415070198476, 0.015838939834793564, 0.05668358084221836, 0.07641320204129443, 0.05053172950283624, 0.02869454434403451, 0.02754088505753316, 0.05654574175423477, 0.04140502373047639, 0.019662547747429926, 0.046710043752682395, 0.030761718771827873, 0.036199952446622774, 0.021891584583499935, 0.046743599959881976, 0.10510521751712076, 0.021293183490342926, 0.041029901476576924, 0.021145410755707417, 0.006840251753601478, 0.05663460280629806, 0.03328516744659282, 0.007077290474626352, 0.02746977988863364, 0.008570204481657129, 0.059955906617688015, 0.036450045081437565, 0.08800482886726968, 0.017192210871144198, 0.036263829097151756, 0.09410314538399689, 0.03532464492309373, 0.05094018531963229, 0.0407542975153774, 0.0484154620062327, 0.0492242508335039, 0.048779982680571266, 0.037823842067155056, 0.041707408090587705, 0.021084964682813734, 0.0591650480782846, 0.034910849353764206, 0.04748973296955228, 0.027595204701356124, 0.07842779901693575, 0.10103739477926865, 0.016998504761431832, 0.027591462421696633, 0.036775369226234034, 0.028921871598868165, 0.044912035154993646, 0.04014989244751632, 0.044494636458694004, 0.073174157878384, 0.09139369038166478, 0.04473376386158634, 0.03355375069077127, 0.06406908200006001, 0.02125850664015161, 0.03819142410065979, 0.03816730801190715, 0.04322816515923478, 0.0234463598462753, 0.0891546456841752, 0.013684835794265382, 0.006750604952685535, 0.032358892931370065, 0.009268310332117835, 0.032848435803316534, 0.0567528900137404, 0.03269701912358869, 0.054402378445956856, 0.03609416671679355, 0.18459759769029915, 1.6333317873068154, 2.7964725298807025, 7.114160181954503, 20.037225410342216, 24.386000856757164, 35.27812398970127, 44.34296317398548, 45.15252873301506, 54.48076218366623, 59.36505809426308, 55.024535804986954, 56.90141089260578, 66.64135605096817, 56.22376285493374, 66.40310883522034, 52.7022410184145, 47.41290584206581, 41.42041839659214, 30.342034958302975, 21.46888218820095, 16.269113905727863, 12.583685964345932, 8.506028819829226, 7.447013296186924, 9.65755132958293, 10.132239907979965, 10.669458881020546, 10.139791052788496, 10.745122320950031, 16.013378128409386, 12.890122421085835, 15.45734066516161, 16.64721831679344, 10.82749905064702, 5.260699912905693, 3.1022330978885293, 0.2755558106582612, 0.007541535387645126, 0.04639817474526353, 0.06294460210483521, 0.09715580657939427, 0.0514479998673778, 0.06852403865195811, 0.04216995534079615, 0.07046625396469608, 0.023519086607848294, 0.015030162139737513, 0.029831726096745115, 0.04442965400812682, 0.02105182964442065, 0.008778740557318088, 0.02211686165537685, 0.10346700815716758, 0.04679372832470108, 0.05172486176888924, 0.012282054231036454, 0.03940560367482249, 0.03715315579029266, 0.042134877730859444, 0.009362380333186593, 0.0411021235777298, 0.006949136877665296, 0.04581170367600862, 0.06386644599842839, 0.022332667067530565, 0.023471967651857994, 0.019134559770463966, 0.017209823890880216, 0.1275883661583066, 0.04124391831282992, 0.0445996095368173, 0.029767014530079905, 0.04514794534770772, 0.023874386097304523, 0.015537021172349341, 0.014652581521659158, 0.022253149654716253, 0.014858881877444219, 0.03919635513739195, 0.06900496518937871, 0.039630904866498895, 0.040393342860625125, 0.09639710900955833, 0.01666154003032716, 0.012098152819817187, 0.02177809536078712, 0.11247242102399468, 0.01864797064627055, 0.08718803597730584, 0.055254519829759374, 0.0643641673377715, 0.02887306982302107, 0.01283769277506508, 0.1503926346777007, 0.0029874846268285182, 0.019022554843104444, 0.07229628623463213, 0.09318662268924527, 0.02155359568860149, 0.009431159796804423, 0.0788598699728027, 0.05172774130187463, 0.008007473788893549, 0.04720377233752515, 0.03650526829005685, 0.06269291014177725, 0.1325160189298913, 0.23052748467307538, 0.11224501955439337, 0.13986762991407886, 0.21284924499923363, 0.16912689112359658, 0.1274491540971212, 0.20110447600018233, 0.19435686932411045, 0.21313173609087244, 0.13453961815685034, 0.19702140212757513, 0.15790989302331582, 0.15433936117915437, 0.121610092028277, 0.11229168580030091, 0.18841539829736575, 0.15145227313041687, 0.11577871860936284, 0.10379596511484124, 0.1764607202494517, 0.19263884198153391, 0.10343963032937609, 0.18644891475560144, 0.11707265308359638, 0.1420506276190281, 0.16430319839855656, 0.11242666019825265, 0.20674742554547265, 0.14219401055015624, 0.17606960842385888, 0.08482812510919757, 0.15920035424642265, 0.13899576966650784, 0.11361600380041637, 0.11726481738151051, 0.16535928938537836, 0.11156670399941504, 0.0912209703528788, 0.11153500687214546, 0.15292366995709017, 0.24319262069184333, 0.14494167873635888, 0.13595855998573825, 0.14323352195788175, 0.12122325497330166, 0.19277487765066326, 0.12170021844212897, 0.14843502722214907, 0.10563667688984424, 0.15010628441814333, 0.13435448199743405, 0.13489288045093417, 0.1607277535367757, 0.09072275177459233, 0.23053778568282723, 0.0717049058584962, 0.17901605344377458, 0.16418485553003848, 0.19739179319003597, 0.09213557830662467, 0.21745866484707221, 0.1389813274727203, 0.14595080661820248, 0.10703304258640856, 0.2158783801132813, 0.1307074198848568, 0.1533448981354013, 0.16140054009156302, 0.2395155164413154, 2.0647286949679255, 4.044214189052582, 9.18453086167574, 23.2930389046669, 28.462707102298737, 40.88806316256523, 48.45032997429371, 52.15185955166817, 61.66388913989067, 67.38801598548889, 63.79937455058098, 67.10532635450363, 77.00713902711868, 66.75490915775299, 75.86507230997086, 63.558581471443176, 55.55559150874615, 48.63473027944565, 37.11611196398735, 25.10007183998823, 20.380113311111927, 14.968137815594673, 11.933096274733543, 9.707815032452345, 13.30244304612279, 14.204370249062777, 13.784214444458485, 13.493021819740534, 14.86509209498763, 20.238863490521908, 16.781706400215626, 19.430707655847073, 19.62893921881914, 14.103514160960913, 7.150391712784767, 4.09880680963397, 0.7102808053605258, 0.21016191341914237, 0.1084344474656973, 0.19312380580231547, 0.19102603633655235, 0.2787876263028011, 0.12633801059564576, 0.1114010121091269, 0.10206777777057141, 0.1434289145981893, 0.16020727052818984, 0.13038445205893368, 0.12086093847756274, 0.06122991442680359, 0.2098300843499601, 0.07396243745461106, 0.2875941287493333, 0.16923946008319035, 0.08680223050760105, 0.09283515639253892, 0.11290938273305073, 0.11498727748403326, 0.0979094798094593, 0.11051362613216043, 0.13270749303046614, 0.0860355251643341, 0.10744088242063299, 0.1561334586585872, 0.1969234980060719, 0.17464515985921025, 0.12526753678685054, 0.14559546631062403, 0.141379963606596, 0.12958793464349583, 0.19610358809586614, 0.15270638396032155, 0.24147644871845841, 0.19568929157685488, 0.1485468095052056, 0.18044183787424117, 0.08051767203141935, 0.09339149997686036, 0.12832125183194876, 0.18117833038559183, 0.10523628079681657, 0.10154556555789895, 0.22075552231399342, 0.0875654848641716, 0.1300243174773641, 0.06523990901769139, 0.1450273671071045, 0.16282038734061643, 0.13924057449912652, 0.1110934883763548, 0.10095241144881584, 0.08577787375543267, 0.10745827836217359, 0.15806351759238169, 0.19412818393902853, 0.09258750171284191, 0.3175236680544913, 0.09676051646238193, 0.058674948595580645, 0.11040472338208929, 0.2175008930498734, 0.13053681497694924, 0.14567544014425948, 0.14094141370151192, 0.12386296293698251, 0.1546091615455225], [0.04025089132483117, 0.031260388204827905, 0.03233373041439336, 0.05063485834398307, 0.05702427486539818, 0.028197375904710498, 0.03120533197943587, 0.032842205473571084, 0.11864725296618417, 0.0770524880499579, 0.02754228586127283, 0.04381233928143047, 0.07144813760532998, 0.04414702932990622, 0.01877965547464555, 0.04682961487560533, 0.06557081040227786, 0.06822542811278254, 0.1493786383070983, 0.009300826604885515, 0.02163576256862143, 0.07084013312123716, 0.025478067036601715, 0.027669957526086364, 0.01262232894077897, 0.043907849976676516, 0.05686270560545381, 0.012102696618967457, 0.029842938092770055, 0.017593926131667104, 0.042368008580524474, 0.03760858584428206, 0.011732857528841123, 0.02599861127237091, 0.03559624499757774, 0.03186919049767312, 0.07887910644058138, 0.041366201985511, 0.05436743813334033, 0.05314727684890386, 0.06395171134499833, 0.01290863652684493, 0.01985137423616834, 0.04183748060313519, 0.051247189549030736, 0.08946035857661627, 0.014903853243595222, 0.02804694257065421, 0.023298366322705988, 0.03828017754130997, 0.03960499649110716, 0.01146763157521491, 0.061429392590071075, 0.07366856923908927, 0.059051454954897054, 0.04695067400461994, 0.06758571165846661, 0.019753954366024118, 0.03293656583991833, 0.023818491245037876, 0.02033531760389451, 0.010908633885264862, 0.03398588472919073, 0.014362386009452166, 0.041574611896066926, 0.09204600108205341, 0.5120989959686995, 1.1820256104692817, 3.7526883697137237, 10.787055920809507, 16.110991090536118, 26.93925105035305, 39.77669879794121, 49.367152377963066, 57.325593531131744, 70.76008424162865, 72.37387284636497, 73.13007786870003, 65.01377418637276, 63.24074752628803, 63.88027980923653, 66.18873193860054, 69.36856850981712, 68.70317101478577, 72.55035817623138, 66.32960557937622, 63.52260880172253, 69.18582871556282, 55.167940109968185, 54.419642463326454, 51.45530752837658, 44.14859980344772, 38.53424146771431, 31.18819635361433, 34.88297559320927, 36.70526280999184, 40.64254693686962, 36.35813243687153, 40.048084035515785, 45.84756463766098, 43.64934839308262, 40.68964160978794, 36.4605787396431, 29.970196411013603, 25.932690761983395, 12.524850871413946, 5.040205819532275, 2.4315652856603265, 0.21427376777864993, 0.224360593711026, 0.09338781892438419, 0.047366684884764254, 0.035890636427211575, 0.0537853308924241, 0.06256051099626347, 0.09552622839692049, 0.05864642786036711, 0.03968919685576111, 0.03265145867771935, 0.062011822665226646, 0.020900926901958883, 0.006272697564781993, 0.03924545191694051, 0.05417985288659111, 0.026203011730103754, 0.008341190696228296, 0.013710537295992253, 0.023084225176717155, 0.028917461386299692, 0.06178524126880802, 0.013770818241027882, 0.021363117921282537, 0.11291261107544415, 0.06606900671613403, 0.007428447388519999, 0.03525553984218277, 0.06840643793111667, 0.02278091498737922, 0.031234349953592755, 0.047309053406934254, 0.04849960299907252, 0.021665504136763047, 0.01608666316315066, 0.010261692623316776, 0.10293243918567896, 0.00785907672252506, 0.03903121985786129, 0.03919969480193686, 0.032290901071974076, 0.015562295011477545, 0.011500588498165598, 0.04722457844763994, 0.04511031474976335, 0.013343698337848764, 0.016771470654930454, 0.02755146437266376, 0.034084193321177736, 0.03866307750286069, 0.01269538874112186, 0.038279131113085896, 0.03480292623862624, 0.10242168573313393, 0.06742703306372277, 0.07289796019904315, 0.013965917733003153, 0.0717968653771095, 0.04535059619229287, 0.08665356348501518, 0.013374590234889183, 0.032852740259841084, 0.011482944864837918, 0.044147300213808194, 0.013221078843344003, 0.02309280440385919, 0.07229206341435201, 0.037115235754754394, 0.04034217548905872, 0.040129090048139915, 0.015226172617985867, 0.03512318893626798, 0.028545250206661876, 0.03309920379251707, 0.03799017962592188, 0.06979801677516662, 0.06069839568226598, 0.006590923067051335, 0.018581036347313784, 0.03314918001706246, 0.016377601750718895, 0.02358899135288084, 0.07089368649758399, 0.02136494731530547, 0.015346026684710523, 0.010019771034421865, 0.03846264567982871, 0.015574106291751377, 0.050495572068030015, 0.013728924004681176, 0.03971088241087273, 0.006757159508197219, 0.04074296863109339, 0.014038048921065638, 0.019645426400529686, 0.05919502342294436, 0.03514212483423762, 0.032748023222666234, 0.02747748338151723, 0.016711657262931112, 0.016582915050094016, 0.07464148773578927, 0.04008680989500135, 0.02416333201836096, 0.01342641719020321, 0.05583138008660171, 0.08743241778574884, 0.03096403379458934, 0.12771041976520792, 0.042937848120345734, 0.040711082256166264, 0.05244717554887757, 0.008869203720678343, 0.05589986176346429, 0.03415672341361642, 0.04896639904472977, 0.04646013294404838, 0.026894426191574894, 0.02285725044202991, 0.01438191005945555, 0.057257279549958184, 0.02554881040850887, 0.10749247652711347, 0.09687534155091271, 0.010087871432915563, 0.022557255797437392, 0.03320076299132779, 0.07652544445591047, 0.03900082519976422, 0.01186786068501533, 0.0846473676210735, 0.04899359875707887, 0.07383644304354675, 0.19974661292508245, 0.9263061010278761, 2.5031795678660274, 7.347654327750206, 16.870243549346924, 22.854696325957775, 34.650397673249245, 47.691845074296, 56.79382346570492, 69.96183827519417, 83.65834012627602, 85.26995524764061, 84.97622340917587, 78.82846489548683, 74.05708372592926, 77.92781442403793, 79.9093396961689, 81.0890319943428, 83.22413742542267, 81.76099553704262, 78.32546308636665, 76.43108233809471, 81.37010291218758, 69.38079625368118, 66.77411332726479, 60.52276477217674, 50.222304090857506, 44.23860177397728, 34.83841918408871, 40.132523104548454, 42.58072033524513, 48.53602297604084, 43.618509247899055, 49.47979353368282, 54.76651445031166, 51.66348695755005, 50.13117358088493, 47.29476258158684, 36.6896266490221, 32.003349512815475, 17.30087824165821, 8.068056721240282, 4.5170703157782555, 0.4641826171427965, 0.3420575859490782, 0.10730270194471814, 0.06451693843700923, 0.061969167727511376, 0.011823165768873878, 0.03899544091837015, 0.046765471051912755, 0.11551820251042955, 0.08869104087352753, 0.025608707292121835, 0.02786002525681397, 0.020945652431691997, 0.03785277469432913, 0.02527931432268815, 0.01128160391090205, 0.043545021399040706, 0.04898017330560833, 0.010912639627349563, 0.014747538389201509, 0.04440785342012532, 0.04548259086732287, 0.02981856967380736, 0.024278389028040692, 0.04057956255564932, 0.030891572350810748, 0.0248587967507774, 0.03098309585766401, 0.012757887780026067, 0.04490018676733598, 0.0547993717918871, 0.009117585705098463, 0.0609840037941467, 0.06626519345445558, 0.011341256813466316, 0.04166857892414555, 0.0364185000944417, 0.025493859939160757, 0.025111830145760905, 0.041802955893217586, 0.014008631114847958, 0.040813194354996085, 0.025927712049451657, 0.02130973523890134, 0.0037878850980632706, 0.028839901387982536, 0.08331550940056331, 0.02960273457574658, 0.020383512674015947, 0.014850679290248081, 0.018380628644081298, 0.042995286639779806, 0.03376594184373971, 0.012179282548459014, 0.015195110954664415, 0.04393349117890466, 0.03893803950631991, 0.0536204479431035, 0.033058949702535756, 0.01664952465944225, 0.04589233059959952, 0.04082660125277471, 0.03949979705794249, 0.05357649795769248, 0.03355707180162426, 0.038724686892237514, 0.055660096113570035, 0.055030342991813086, 0.13610872614663094, 0.09336303861346096, 0.08192692883312702, 0.13600711128674448, 0.1252618816215545, 0.11223289286135696, 0.13732482417253777, 0.15711506770458072, 0.18770071008475497, 0.1746484698378481, 0.10220965414191596, 0.23570818011648953, 0.12765297753503546, 0.1969295390881598, 0.12425125460140407, 0.16037800902267918, 0.08799215298495255, 0.17756689136149362, 0.1904565715813078, 0.13301210012286901, 0.162216947064735, 0.1557177520589903, 0.06747165098204277, 0.09663543489295989, 0.2126283966936171, 0.09723456329084001, 0.18185077555244789, 0.10868082565139048, 0.1904203399317339, 0.0836122348846402, 0.25745776772964746, 0.08844638447044417, 0.18740483064902946, 0.13404030120000243, 0.17447069578338414, 0.09889871813356876, 0.1252836562343873, 0.09649876097682863, 0.25919537292793393, 0.12038335902616382, 0.1511606090934947, 0.10840962262591347, 0.11911004141438752, 0.1332113816170022, 0.1832147390814498, 0.24770361691480502, 0.13028862595092505, 0.13201644964283332, 0.09221414205967449, 0.0919791409978643, 0.09440980080398731, 0.13303690269822255, 0.1365144582814537, 0.11697738358634524, 0.19905913184629753, 0.1702018771902658, 0.11085254271165468, 0.23384734871797264, 0.21413455571746454, 0.14732217678101733, 0.07724816270638257, 0.15069758315803483, 0.21836724656168371, 0.12978006183402613, 0.2295595608302392, 0.2757078025024384, 1.3417106168344617, 2.8215941693633795, 7.900945013388991, 18.628236316144466, 25.095039010047913, 39.83094848692417, 54.26794320344925, 65.76952323317528, 79.4228745996952, 92.69847303628922, 96.07298076152802, 95.67266464233398, 91.4601118862629, 88.07478234171867, 92.00710773468018, 94.11936119198799, 94.49030488729477, 96.73062667250633, 94.09429013729095, 89.16360631585121, 87.81560584902763, 93.79644691944122, 80.52438989281654, 78.33722725510597, 70.9872816503048, 60.30184842646122, 54.05700892210007, 43.59091892838478, 48.57284300029278, 53.91630247235298, 57.407916113734245, 52.993692979216576, 62.01416194438934, 65.14495834708214, 60.56384436786175, 58.540715128183365, 57.349099069833755, 44.332308545708656, 38.48974585533142, 21.51083003729582, 10.835064444690943, 5.218803361058235, 0.7733834849204868, 0.47638880903832614, 0.2373392425943166, 0.13958837458631024, 0.10720395919634029, 0.18964886257890612, 0.09336318704299629, 0.11370296124368906, 0.35794382099993527, 0.216400362260174, 0.13132130960002542, 0.14053070917725563, 0.12737568147713318, 0.11163069939357229, 0.09941614349372685, 0.0890104538120795, 0.13395287620369345, 0.10893694081460126, 0.11090891624917276, 0.12295236258069053, 0.11660907795885578, 0.14157185330986977, 0.1280184110510163, 0.04925336528685875, 0.1573143046698533, 0.13882149854907766, 0.08846093798638321, 0.14459052414167672, 0.1219497062265873, 0.1643570337910205, 0.10772508045192808, 0.08946815112722106, 0.1479332908638753, 0.1951930471113883, 0.13495810038875788, 0.10018200278864242, 0.12554817250929773, 0.06659178296104074, 0.12606625095941126, 0.24686733522685245, 0.09225990288541652, 0.09543979045702145, 0.07919039286207408, 0.16672813624609262, 0.15688276063883677, 0.1029570636455901, 0.2509155875304714, 0.13181893446017057, 0.19394647650187835, 0.09724130941322073, 0.15299629652872682, 0.11660396456136368, 0.26800312218256295, 0.17862431821413338, 0.16106741968542337, 0.2891937835374847, 0.12219995842315257, 0.22116600419394672, 0.11639482734608464, 0.09971184481400996, 0.09732644859468564, 0.1665649825008586, 0.05549552486627363, 0.24180829263059422, 0.07485012771212496, 0.1067363319452852, 0.18463008891558275, 0.1518684992333874], [0.009487678053119453, 0.012294600237510167, 0.056593706758576445, 0.03779929182201158, 0.05736848295782693, 0.03461532985966187, 0.05909471474296879, 0.06390128983184695, 0.04522689130681101, 0.06426843770896085, 0.04739863805298228, 0.040936305522336625, 0.04687591746915132, 0.055564284848514944, 0.08337412422406487, 0.007209485065686749, 0.013124049528414616, 0.01791305148799438, 0.06042866581992712, 0.018532587091613095, 0.04324445158999879, 0.018331290666537825, 0.003998261236120015, 0.10240700605208986, 0.025785947000258602, 0.014380056545633124, 0.02614380318846088, 0.030582265608245507, 0.007673866812183405, 0.07239475438836962, 0.03418136271648109, 0.054830757217132486, 0.04957678582286462, 0.04225971439154819, 0.015329932284657843, 0.013133285556250485, 0.03229501628084108, 0.020646004741138313, 0.02584885514806956, 0.021931270930508617, 0.027504217396199238, 0.013255586854938883, 0.018024943237833213, 0.025206893697031774, 0.09058506111614406, 0.03681091438920703, 0.07207249902421609, 0.0326446086546639, 0.00651327215564379, 0.12691336800344288, 0.01521042517197202, 0.08248163227108307, 0.08739284647163004, 0.033704584784572944, 0.004791879173353664, 0.044375877987477, 0.08815256820525974, 0.02395209452515701, 0.02421628982119728, 0.024761523454799317, 0.10524473385885358, 0.06565104398760013, 0.1960781472735107, 1.6673544491641223, 1.9204694358631968, 5.9029153268784285, 15.476221852004528, 22.450721003115177, 39.34593491256237, 50.421265214681625, 56.66505977511406, 62.842517495155334, 66.44753605127335, 68.55152115225792, 75.04359439015388, 76.83611780405045, 69.49062556028366, 62.559451684355736, 68.50387170910835, 65.45839592814445, 54.908873811364174, 59.69371385872364, 54.71314251422882, 59.358659237623215, 66.12723603844643, 70.4179809987545, 70.51739886403084, 61.36370524764061, 64.98123273253441, 69.30010378360748, 65.68281948566437, 63.73799264431, 61.96204774081707, 62.87779480218887, 55.11599309742451, 54.30209197103977, 69.11320701241493, 64.18205201625824, 67.56412133574486, 62.77760937809944, 66.02270364761353, 70.57126477360725, 68.29797595739365, 65.61603426933289, 59.628349766135216, 48.645840883255005, 36.99191942811012, 28.12016688287258, 7.4715804029256105, 2.7895830245688558, 1.0220990795642138, 0.2226495128707029, 0.035595684676081873, 0.04318794817663729, 0.07591637127916329, 0.06202341501193587, 0.09075102760107256, 0.059041064887424, 0.030055214592721313, 0.07801270097843371, 0.028508391442301217, 0.0816006658715196, 0.08177243595127948, 0.04611859287251718, 0.11633619767962955, 0.020325821824371815, 0.1043825586384628, 0.027678815058607142, 0.07371158411842771, 0.032105119244079106, 0.041577743759262376, 0.032219268978224136, 0.07208634749986231, 0.021980900201015174, 0.06931139796506613, 0.029231989137770142, 0.02492458443157375, 0.017366971806040965, 0.0398011646757368, 0.03160615851811599, 0.04241940601787064, 0.02208995880209841, 0.017958422686206177, 0.08029684599023312, 0.031290040715248324, 0.03665278127300553, 0.015139741171878995, 0.024220943087129854, 0.048538302289671265, 0.07859615521738306, 0.030071072433202062, 0.058350344334030524, 0.047026302563608624, 0.06290324221481569, 0.043430960722616874, 0.026651322732504923, 0.05115453612233978, 0.00560767155548092, 0.017931488291651476, 0.08710047739441507, 0.037214331023278646, 0.012989474962523673, 0.03349224149133079, 0.024046363978413865, 0.02659341294929618, 0.02991846646182239, 0.011263314609095687, 0.07377444402663969, 0.007619318494107574, 0.0998754141619429, 0.031329059129348025, 0.040449916778015904, 0.015204674455162603, 0.07122034279746003, 0.037032783147878945, 0.0263732399980654, 0.043678288857336156, 0.025486937556706835, 0.13505818642443046, 0.014851164469291689, 0.030265257228165865, 0.05174492944206577, 0.01626158737053629, 0.08787500497419387, 0.03393843551748432, 0.050909170968225226, 0.07364828634308651, 0.06129175759269856, 0.027202389646845404, 0.03192892225342803, 0.05266339285299182, 0.026584742809063755, 0.05904242301767226, 0.07960096379974857, 0.04297281069739256, 0.037435776757774875, 0.02710306431254139, 0.03409587843634654, 0.011201068828086136, 0.04380816470074933, 0.024778231054369826, 0.018035914035863243, 0.02211303959484212, 0.08485332102281973, 0.04583825029840227, 0.040676654025446624, 0.06471092099673115, 0.04072359486599453, 0.06328788251266815, 0.03284212383732665, 0.016653808706905693, 0.010058738425868796, 0.028174912949907593, 0.04517648834735155, 0.006231665147424792, 0.0750977304414846, 0.03357236004376318, 0.0245328603341477, 0.023821855029382277, 0.11835783021524549, 0.124663146561943, 0.05059284907474648, 0.033859085087897256, 0.019420457319938578, 0.02854660833691014, 0.07021151919616386, 0.04989500761439558, 0.013618308748846175, 0.0398495452827774, 0.09428404388017952, 0.017069392852135934, 0.011870471189467935, 0.035389534605201334, 0.020103183087485377, 0.016375258419429883, 0.035608598045655526, 0.057744057921809144, 0.05301474411680829, 0.5233871808741242, 3.109912723302841, 3.147266856394708, 9.061943739652634, 20.64983993768692, 31.43205016851425, 51.79184406995773, 62.20414415001869, 67.59782552719116, 73.36403131484985, 78.58368203043938, 80.59716358780861, 86.46063655614853, 85.98810911178589, 78.18483263254166, 72.16443568468094, 78.21431145071983, 77.38355442881584, 64.73408639431, 67.1389165520668, 64.15473908185959, 70.10512098670006, 76.06000944972038, 82.16081008315086, 82.39321321249008, 73.15918430685997, 74.55069243907928, 80.53955867886543, 73.23159322142601, 73.524169921875, 71.26386120915413, 72.91266113519669, 66.78079336881638, 62.19548441469669, 79.44461703300476, 72.62512296438217, 78.18819165229797, 72.85658374428749, 74.79392498731613, 82.3781356215477, 79.67296198010445, 77.31233105063438, 69.84098196029663, 59.25197996199131, 44.55200515687466, 36.80328994989395, 11.77621504291892, 4.247117601335049, 1.7046832898631692, 0.11857524237711914, 0.0352525007474469, 0.04145700375374872, 0.11621867117355578, 0.052056609201827087, 0.05906132180825807, 0.027296098778606392, 0.04047769536555279, 0.11798585095675662, 0.027508679559105076, 0.035625741656986065, 0.04325428875745274, 0.06946698180399835, 0.06575803941814229, 0.022496366291306913, 0.04097363183973357, 0.04297023173421621, 0.0257531700481195, 0.010028066390077583, 0.0661119251162745, 0.034803319576894864, 0.0526726919633802, 0.029877355191274546, 0.06812189851189032, 0.05464159119583201, 0.025637944199843332, 0.007901333683548728, 0.019661018923216034, 0.02520902366086375, 0.015467977318621706, 0.07905019374447875, 0.024875693598005455, 0.04606508031429257, 0.06548642821144313, 0.11415414992370643, 0.03515767282806337, 0.02903988421167014, 0.04129963504965417, 0.03143247369735036, 0.024565043568145484, 0.04807775512745138, 0.04846581672609318, 0.03145303860947024, 0.010339099553675624, 0.04967252287315205, 0.018324186457903124, 0.08934573386795819, 0.034318927209824324, 0.05529615802515764, 0.025543643205310218, 0.046667860078741796, 0.04878134452155791, 0.09594056944479235, 0.016526122199138626, 0.0473700393922627, 0.020514817151706666, 0.012477029413275886, 0.02472574637067737, 0.061827818281017244, 0.016082779875432607, 0.015649031665816437, 0.06798649366828613, 0.02909511669713538, 0.0639451878669206, 0.0340341614355566, 0.08762230369029567, 0.11939692602027208, 0.2684831729857251, 0.13609740097308531, 0.11760053530451842, 0.18520465964684263, 0.11775007806136273, 0.13594374671811238, 0.08011743921088055, 0.26288464840035886, 0.1644806904369034, 0.1777489550295286, 0.1259701873641461, 0.1613826394896023, 0.17323190288152546, 0.125208476674743, 0.1078322391549591, 0.10843823984032497, 0.16653335216687992, 0.07985969874425791, 0.12484066828619689, 0.08232613006839529, 0.1295830067829229, 0.202247042034287, 0.11353885012795217, 0.10224598969216458, 0.158274807035923, 0.11207091913092881, 0.11138355679577217, 0.16987028560834005, 0.10021085749031045, 0.1353838705108501, 0.3202669130405411, 0.1343145247665234, 0.17139787785708904, 0.11945138481678441, 0.144099177850876, 0.1598955091321841, 0.1713995699537918, 0.13069904845906422, 0.14270189189119264, 0.1552588227787055, 0.290536952088587, 0.1843143199221231, 0.3267192339990288, 0.1656545008881949, 0.1536208434845321, 0.08922733162762597, 0.12495454342570156, 0.3303229546872899, 0.14831531880190596, 0.2152141579426825, 0.21071678755106404, 0.291074623237364, 0.19451914733508602, 0.07230246090330184, 0.18085907329805195, 0.09145718853687868, 0.08684293730766512, 0.16078825341537595, 0.1877311381394975, 0.1834649170632474, 0.6500907882582396, 3.76521036028862, 3.9300355408340693, 9.824578016996384, 22.652345784008503, 35.89803792536259, 59.535068571567535, 72.88404867053032, 80.41950032114983, 85.30899435281754, 87.78117209672928, 93.73737528920174, 98.5511165857315, 100.5240847170353, 90.04763647913933, 85.4195000231266, 90.7701601088047, 90.03854736685753, 77.77081444859505, 82.42909848690033, 80.02055212855339, 82.65941932797432, 90.53350120782852, 95.31640335917473, 93.68695959448814, 85.7763996720314, 88.576879799366, 92.83732518553734, 86.25970333814621, 88.24157819151878, 81.8310409784317, 83.83450627326965, 78.96673187613487, 76.63666650652885, 90.49233421683311, 84.55626234412193, 88.53437528014183, 84.94702577590942, 86.41947716474533, 91.15680456161499, 92.18786403536797, 88.59524801373482, 78.94448027014732, 69.16492983698845, 52.325248047709465, 44.529297575354576, 15.905451569706202, 5.623640762642026, 2.2982805501669645, 0.2807270659832284, 0.13728249206906185, 0.1918515271972865, 0.2591219003079459, 0.09061501419637352, 0.25251185812521726, 0.2096290365443565, 0.09404673473909497, 0.2673310035606846, 0.10340100896428339, 0.12820497213397175, 0.15063499042298645, 0.12146085355198011, 0.2928564010653645, 0.06642459193244576, 0.19006289192475379, 0.16108281182823703, 0.13430940394755453, 0.08678674188558944, 0.2100882478407584, 0.13123600714607164, 0.13378090574406087, 0.12454710435122252, 0.18048037018161267, 0.1492417714325711, 0.12241879550856538, 0.06975696116569452, 0.1740314334165305, 0.1464237624895759, 0.1139045730815269, 0.17008378665195778, 0.19175812049070373, 0.12279920556466095, 0.14919338340405375, 0.20228693989338353, 0.10545836106757633, 0.1286403159610927, 0.1292360675870441, 0.19063813058892265, 0.14500706194667146, 0.2579559269361198, 0.12756482523400337, 0.16550531436223537, 0.08196534981834702, 0.07047857361612841, 0.174845821748022, 0.1463574738590978, 0.12604095856659114, 0.145517704077065, 0.1589248244999908, 0.10178718657698482, 0.11236896563787013, 0.20670757221523672, 0.15885486965999007, 0.1596698517096229, 0.09028931526700035, 0.18808144668582827, 0.13742045732215047, 0.2599386189831421, 0.12170619273092598, 0.13985893194330856, 0.11790857854066417, 0.10727438901085407, 0.20536128664389253, 0.12632294499780983], [0.06962632833165117, 0.02772311941953376, 0.023323606765188742, 0.03746941460121889, 0.045757107582176104, 0.03003928439284209, 0.04171129323367495, 0.029130190596333705, 0.026987274432030972, 0.0597996808210155, 0.05727666815801058, 0.042698798642959446, 0.009703899995656684, 0.09048596213688143, 0.014224778842617525, 0.08864219271345064, 0.018619904476508964, 0.021135011411388405, 0.03826590233074967, 0.050154317723354325, 0.06286154835834168, 0.0658714173187036, 0.030230992269935086, 0.03150078839098569, 0.03783206135267392, 0.034114498921553604, 0.023684900952503085, 0.02582101347798016, 0.02093906958180014, 0.06092187119065784, 0.0584788249398116, 0.021017386570747476, 0.03603487282816786, 0.006208087579580024, 0.03232236071198713, 0.0705508365354035, 0.0424030379508622, 0.06920381623785943, 0.024551206224714406, 0.06249149126233533, 0.005764824572906946, 0.049143705546157435, 0.052905102929798886, 0.030776298262935597, 0.052647540578618646, 0.08025567905860953, 0.07044515470624901, 0.03048198104806943, 0.023687743378104642, 0.042828336809179746, 0.010544263495830819, 0.06062171327357646, 0.04773737280629575, 0.07453547936165705, 0.051369588254601695, 0.025939944498531986, 0.0713357690256089, 0.018903288000728935, 0.07168801457737572, 0.1264512920170091, 0.7947836397215724, 7.427445771172643, 11.656856797635555, 18.88938870280981, 25.04256572574377, 39.39273700118065, 50.64021706581116, 66.82071402668953, 66.88413262367249, 63.60150396823883, 69.05044957995415, 67.469232827425, 70.62544226646423, 65.72257295250893, 55.12499861419201, 53.2154680788517, 41.85824990272522, 50.129228085279465, 43.53784337639809, 42.0196158438921, 36.98441103100777, 43.95551696419716, 39.455049857497215, 38.487408980727196, 39.80495028197765, 37.485398948192596, 41.11239932477474, 42.06688150763512, 59.38937298953533, 61.4076878875494, 57.70341485738754, 62.919060587882996, 54.84251417219639, 61.469442173838615, 55.939621701836586, 49.75907474756241, 57.53969304263592, 62.448976412415504, 59.94678407907486, 62.98337213695049, 64.87201899290085, 61.384186148643494, 62.56684988737106, 62.73568622767925, 68.58282387256622, 66.33510768413544, 60.407345965504646, 57.76267647743225, 43.95588554441929, 23.718080297112465, 14.750713482499123, 7.054391764104366, 1.4271642314270139, 0.21103883511386812, 0.0224893975246232, 0.08671556992339902, 0.02826023210218409, 0.028980004026379902, 0.05964999334537424, 0.0749999302206561, 0.006640065766987391, 0.04645532382710371, 0.06215333538420964, 0.02792854775179876, 0.03142875182675198, 0.04834518062125426, 0.027428152825450525, 0.027374412056815345, 0.025384220607520547, 0.050716502009890974, 0.0241014869970968, 0.03514318239467684, 0.03231647548091132, 0.03813435665506404, 0.023423481288773473, 0.02914808563218685, 0.03799040227022488, 0.03586651662772056, 0.048274669170496054, 0.05070436418463942, 0.0613564394734567, 0.018892628904723097, 0.10575311243883334, 0.01930531310790684, 0.021532806276809424, 0.014530635526170954, 0.0222724380728323, 0.03872857203532476, 0.06442334619350731, 0.020208709065627772, 0.0231339230958838, 0.051762321672867984, 0.022431550823966973, 0.01513047360276687, 0.03241383041313384, 0.050209299733978696, 0.025537305264151655, 0.05545634689042345, 0.05324896592355799, 0.08853379462379962, 0.0023588069234392606, 0.046494917405652814, 0.03889837542374153, 0.009294583287555724, 0.08352461692993529, 0.016802709506009705, 0.034061101396218874, 0.05556753916607704, 0.04283527217921801, 0.06724424951244146, 0.07730082550551742, 0.0405182611575583, 0.04870841366937384, 0.029100339561409783, 0.05935926812526304, 0.039796982673578896, 0.010182719761360204, 0.027265884091320913, 0.04256996922777034, 0.018873856279242318, 0.03588515937735792, 0.04611397300323006, 0.015985109530447517, 0.00492982819196186, 0.01632338415220147, 0.04156364295340609, 0.06515834698802792, 0.0243924107417115, 0.02160647742130095, 0.07156236155424267, 0.07792309406795539, 0.15622336242813617, 0.03957731809350662, 0.07918410687125288, 0.021652959985658526, 0.02056244447885547, 0.02700465924135642, 0.019913512405764777, 0.03562158934073523, 0.020159077939752024, 0.03367729230376426, 0.040966867163660936, 0.04327254559029825, 0.0809870581724681, 0.04178848030278459, 0.08069385788985528, 0.015878253252594732, 0.07318086689338088, 0.07534365591709502, 0.05662288429448381, 0.045252647541929036, 0.06242584830033593, 0.056468792172381654, 0.04638412960048299, 0.03601634511142038, 0.03001049091835739, 0.09576917043887079, 0.0030543762522938778, 0.0695199117762968, 0.04942102015775163, 0.0561931065749377, 0.019722795295820106, 0.04392225877381861, 0.018759888371278066, 0.057469938255962916, 0.0453580028261058, 0.005410778849181952, 0.04417006188305095, 0.05045811216405127, 0.023790981686033774, 0.028877715667476878, 0.06957150588277727, 0.030787510258960538, 0.08294615734484978, 0.0503168814611854, 0.18451143434504047, 1.4454056276008487, 10.915764514356852, 15.62866872176528, 25.339118912816048, 33.95487919449806, 50.84762513637543, 60.591282695531845, 77.7549161016941, 75.40754646062851, 72.06581577658653, 77.47850373387337, 77.49871864914894, 80.0033238530159, 73.07344570755959, 66.05839133262634, 61.06297418475151, 52.63419046998024, 60.47988027334213, 56.49947226047516, 54.23665188252926, 49.66800883412361, 55.836221650242805, 48.56436565518379, 50.537500977516174, 50.03507673740387, 50.30148424208164, 53.20620037615299, 53.82324166595936, 68.60974162817001, 69.41735029220581, 70.39043247699738, 68.42464596033096, 63.36097687482834, 70.70496439933777, 64.89670246839523, 58.73187147080898, 67.37562105059624, 70.93210861086845, 68.75552460551262, 72.45272621512413, 75.64649283885956, 70.08425250649452, 71.58882737159729, 71.33883118629456, 79.39698278903961, 73.77556443214417, 68.03342655301094, 64.59135845303535, 51.33438661694527, 31.64982408285141, 18.054142221808434, 8.943921122699976, 2.2213387163355947, 0.29916278610471636, 0.05224047999945469, 0.08280868190922774, 0.11054359405534342, 0.0745002347684931, 0.0790493625390809, 0.05286415864247829, 0.022176413440320175, 0.07493491066270508, 0.040757388560450636, 0.03825665517069865, 0.05326570135366637, 0.06857599641080014, 0.056104219547705725, 0.011349169963068562, 0.04085815366124734, 0.05681317466951441, 0.04516163797234185, 0.02580429289082531, 0.04177367816737387, 0.05005594975955319, 0.03185290035617072, 0.026893392750935163, 0.06135711111710407, 0.05055422028817702, 0.03737740684300661, 0.08808904036413878, 0.040702981714275666, 0.008450321656710003, 0.03791093680774793, 0.027696557954186574, 0.0236741416665609, 0.01166222640677006, 0.07084814831614494, 0.07699362089624628, 0.012770727862516651, 0.022929648803255986, 0.05686105061613489, 0.07159424421843141, 0.03656471431895625, 0.03378549372428097, 0.05391665021306835, 0.1084742414241191, 0.014127214253676357, 0.031735540833324194, 0.030917792428226676, 0.037963970680721104, 0.028564779822772834, 0.037563307414529845, 0.017282020016864408, 0.07163109927205369, 0.09503504537860863, 0.053108818756300025, 0.08739857585169375, 0.0454288037144579, 0.04689499437517952, 0.013959501866338542, 0.0796876911772415, 0.041450762291788124, 0.0303181445269729, 0.08868436896591447, 0.05360723029298242, 0.04358486730779987, 0.2282852487405762, 0.10955395497148857, 0.1999712610268034, 0.14542361459461972, 0.13301474216859788, 0.13343227445147932, 0.07554153475211933, 0.12699276296189055, 0.0787666042742785, 0.18342595431022346, 0.20752017939230427, 0.11859110207296908, 0.07074711233144626, 0.16726116155041382, 0.186998326680623, 0.2322955772979185, 0.12797455012332648, 0.15243573754560202, 0.1399817573837936, 0.09251530558685772, 0.2167293563252315, 0.09865973173873499, 0.12685953261097893, 0.15927905158605427, 0.16686574526829645, 0.10900691049755551, 0.135553733271081, 0.16308380523696542, 0.11347254665452056, 0.17482057388406247, 0.15582917811116204, 0.27409882633946836, 0.1740851649083197, 0.1469884329708293, 0.10129344314918853, 0.16990616102702916, 0.15369131782790646, 0.17139107978437096, 0.17686970299109817, 0.16239009011769667, 0.12567009252961725, 0.07374882508884184, 0.10398298632935621, 0.12445980552001856, 0.13125867233611643, 0.1707535600871779, 0.10647100672940724, 0.13120220974087715, 0.10839791895705275, 0.11778314074035734, 0.1430887883179821, 0.14413416269235313, 0.14854945155093446, 0.18510939757106826, 0.1334076203056611, 0.13550877396482974, 0.2196410985197872, 0.16843512043124065, 0.24180617008823901, 0.5919388274196535, 2.078683921135962, 12.39163001999259, 17.742699533700943, 28.8549467548728, 39.75089818239212, 59.348745569586754, 70.68740174174309, 89.69281151890755, 88.01645547151566, 81.49285912513733, 88.66831809282303, 86.06645330786705, 90.65042093396187, 86.85450822114944, 77.59853169322014, 73.2997539639473, 62.287162095308304, 72.04124629497528, 66.3047245144844, 63.0241971462965, 57.44285523891449, 65.97658932209015, 58.52395422756672, 59.677116349339485, 60.98005123436451, 58.14405061304569, 63.790787011384964, 62.4411678314209, 80.29372707009315, 80.1411272585392, 79.3838582932949, 81.74936056137085, 74.11279633641243, 82.48191565275192, 75.70770755410194, 68.26720520853996, 79.2567627131939, 82.02963352203369, 81.8773452937603, 82.93882593512535, 87.08244279026985, 82.73189663887024, 84.59644138813019, 81.9149100780487, 89.51960921287537, 81.83895975351334, 79.11275804042816, 73.61788049340248, 59.60256814956665, 36.972825452685356, 23.34012597799301, 10.923621542751789, 2.934325570240617, 0.5854044249281287, 0.1808978134067729, 0.30569704016670585, 0.17596576712094247, 0.09560019825585186, 0.19822532893158495, 0.2393991031567566, 0.18400107423076406, 0.15379901829874143, 0.14473484217887744, 0.11723320189048536, 0.18062740447930992, 0.14021538547240198, 0.19693284906679764, 0.1228506289771758, 0.17982989258598536, 0.2605558780487627, 0.11701539639034308, 0.13971437641885132, 0.08786048856563866, 0.10943539688014425, 0.11917216659639962, 0.06898406631080434, 0.13630986300995573, 0.08798359602224082, 0.10934252451988868, 0.18370537291048095, 0.1346477639162913, 0.10038068314315751, 0.17897101992275566, 0.11821694090031087, 0.07391678052954376, 0.061660274732275866, 0.11295722899376415, 0.1799281529383734, 0.13543733482947573, 0.08133773037116043, 0.19526543619576842, 0.1742774702142924, 0.10168175707804039, 0.12329087097896263, 0.11849909802549519, 0.22780393628636375, 0.13152542989701033, 0.11145537442644127, 0.10959021630696952, 0.2095173581619747, 0.10020703542977571, 0.1433843412087299, 0.12928319396451116, 0.14357387088239193, 0.1752623892389238, 0.1377944106934592, 0.1256519989692606, 0.1469418706255965, 0.08553363295504823, 0.10647647635778412, 0.12161425547674298, 0.11379697651136667, 0.1146684805280529, 0.23721720383036882, 0.21317360806278884, 0.23278061533346772], [0.0262443215251551, 0.09521326472167857, 0.05913385932217352, 0.01145571546658175, 0.07786620102706365, 0.018282429518876597, 0.006394682059180923, 0.08170000975951552, 0.033589128870517015, 0.03627656064054463, 0.015593717544106767, 0.04876097627857234, 0.01627597946935566, 0.0176631777867442, 0.12078737679985352, 0.061230519277160056, 0.04476714566408191, 0.06619810330448672, 0.06423011320293881, 0.08816148139885627, 0.03044189765205374, 0.07660603427211754, 0.02262295256514335, 0.019777933157456573, 0.036926051179762, 0.03725702306837775, 0.06368836024194025, 0.03550836358044762, 0.028543598928081337, 0.03329934988869354, 0.027079185711045284, 0.023997280186449643, 0.034510939367464744, 0.05153964397322852, 0.08722189275431447, 0.016789410219644196, 0.04261723661329597, 0.03647587924206164, 0.02780440314381849, 0.07934231791296043, 0.025148262175207492, 0.05802769934234675, 0.049174207815667614, 0.029140417391317897, 0.04079423248185776, 0.04889491909125354, 0.0802939070854336, 0.036246247618691996, 0.015194984789559385, 0.03411895551835187, 0.051672295448952354, 0.03118187640211545, 0.012260287039680406, 0.014134511420706986, 0.05902483040699735, 0.1012712751980871, 0.07155837622121908, 0.5992592533584684, 3.4295582212507725, 6.815775968134403, 22.94858928769827, 38.32984283566475, 51.8461811542511, 55.57369373738766, 72.7322468161583, 67.11820006370544, 69.9806472659111, 70.94584867358208, 62.363063022494316, 56.77512466907501, 57.1514792740345, 53.473945409059525, 50.45378766953945, 37.4336913228035, 31.71255111694336, 29.334118142724037, 33.12275804579258, 30.629286244511604, 26.980305947363377, 28.928717896342278, 21.163230389356613, 22.78226461261511, 16.67904730886221, 15.535596515983343, 18.87083999812603, 20.056782960891724, 22.55155809223652, 18.79375733435154, 32.11868852376938, 22.508316412568092, 25.14406207948923, 36.09629228711128, 40.14063946902752, 64.79329481720924, 64.1400870680809, 40.56270182132721, 41.848796010017395, 57.04560935497284, 46.30171626806259, 52.284833416342735, 51.33097060024738, 51.70843094587326, 46.19079641997814, 51.28367833793163, 53.29740688204765, 59.91027183830738, 65.84125578403473, 66.39868587255478, 66.0130825638771, 58.060192912817, 38.39950829744339, 29.50778592377901, 18.613650798797607, 10.651122014969587, 2.962344316765666, 1.546018528752029, 0.6817078229505569, 0.12833009823225439, 0.05809912734548561, 0.04446730687050149, 0.04787328973179683, 0.032448162164655514, 0.04413240159919951, 0.014641157085861778, 0.046803398508927785, 0.05864164100785274, 0.007550719928985927, 0.013986867634230293, 0.043318603275110945, 0.005386043994803913, 0.09137522574746981, 0.06335451995255426, 0.01225430161866825, 0.0360768264363287, 0.06797615555115044, 0.047063242964213714, 0.018849387670343276, 0.03930133934773039, 0.03735515725566074, 0.016193137234949972, 0.06402954779332504, 0.03128545424260665, 0.03709832963068038, 0.027167506850673817, 0.017849425312306266, 0.03412623598705977, 0.037750614355900325, 0.009728960467327852, 0.14945464907214046, 0.011695060875354102, 0.06502100513898768, 0.04648286121664569, 0.013097646697133314, 0.010803575460158754, 0.020063431802554987, 0.014296075114543783, 0.025249780555895995, 0.014661808272649068, 0.03537189004418906, 0.08002133850823157, 0.025255940381612163, 0.04838918255700264, 0.06825745178502984, 0.0353884362266399, 0.012145654909545556, 0.052269620427978225, 0.05197503603994846, 0.048890206453506835, 0.09815824771067128, 0.044117592042312026, 0.06127857333922293, 0.04682184458943084, 0.045849913149140775, 0.030334328912431374, 0.016561017982894555, 0.035774924472207204, 0.02570890836068429, 0.029367466340772808, 0.02862623707187595, 0.008351469441549852, 0.032918026990955696, 0.025536937901051715, 0.003637807994891773, 0.04002319670689758, 0.05909852196054999, 0.03903778415406123, 0.04973072951543145, 0.06187976119690575, 0.03261011363065336, 0.05646038363920525, 0.029945948190288618, 0.0036663899572886294, 0.05568002648942638, 0.03281213364971336, 0.02838573112967424, 0.0408926895033801, 0.0423887627403019, 0.057760307245189324, 0.04487452701141592, 0.043968427780782804, 0.017834519276220817, 0.10183597536524758, 0.05536885881156195, 0.05662304385623429, 0.07995510924956761, 0.10189297230681404, 0.05924155608227011, 0.03257732554629911, 0.015452659390575718, 0.07176096027251333, 0.05096354812849313, 0.005811036253362545, 0.051918840617872775, 0.0255198109880439, 0.02880459556763526, 0.06346186419250444, 0.05519018304767087, 0.005265904665066046, 0.02047061669145478, 0.029446712869685143, 0.01799388621293474, 0.019425379614403937, 0.0687340516014956, 0.059400260652182624, 0.025170940352836624, 0.0848244440567214, 0.025385996195836924, 0.026302390870114323, 0.028836333513027057, 0.04731396271381527, 0.04123765087570064, 0.20460186176933348, 0.0616795000678394, 1.0341699630953372, 5.271278545260429, 10.897309854626656, 29.455582424998283, 46.86876364052296, 60.54467059671879, 66.13515481352806, 84.70479637384415, 79.77251663804054, 80.37100732326508, 80.75249925255775, 71.1304047703743, 68.76992583274841, 67.56754875183105, 63.64305093884468, 60.49932762980461, 47.34666779637337, 43.40687580406666, 44.110981822013855, 44.76126752793789, 44.28941264748573, 41.394002214074135, 41.01581230759621, 33.69261346757412, 36.80702894926071, 28.87763913720846, 24.163254909217358, 28.290515542030334, 29.588345400989056, 28.80618017166853, 29.476506002247334, 45.986211597919464, 32.97740824520588, 33.18514309823513, 43.87879528105259, 46.52384854853153, 70.75158789753914, 69.42211523652077, 44.49578337371349, 47.958358973264694, 66.87328800559044, 53.24667580425739, 60.262801721692085, 59.37689445912838, 60.94216726720333, 57.23539017140865, 58.788898810744286, 62.26218603551388, 67.83810943365097, 75.3429651260376, 78.0021308362484, 77.18090370297432, 66.36651679873466, 48.548710495233536, 36.17628179490566, 24.08282272517681, 14.793400391936302, 4.829288637265563, 2.152587343007326, 1.0468500014394522, 0.14165301457978785, 0.08195825488655828, 0.07163434245740063, 0.0582706970453728, 0.039511396826128475, 0.047169281024252996, 0.03860888216877356, 0.1021919168124441, 0.0570390547363786, 0.05614489295112435, 0.035353020939510316, 0.05131176752911415, 0.0121232698802487, 0.07131278471206315, 0.102231866621878, 0.06126194180978928, 0.023733444832032546, 0.04776410867634695, 0.06807244921219535, 0.04592792771290988, 0.031268844977603294, 0.032183152361540124, 0.02888152845116565, 0.08218475835747086, 0.01897125202958705, 0.02954755775135709, 0.026783055800478905, 0.03630357110523619, 0.041384124851902016, 0.014586508114007302, 0.03812749549979344, 0.07579903773148544, 0.009731071877467912, 0.044506815102067776, 0.007528982423536945, 0.011762292961066123, 0.005412982100096997, 0.019809919722320046, 0.01036314235534519, 0.06215250788955018, 0.019871224831149448, 0.01511436157670687, 0.04134709910431411, 0.014683168210467556, 0.03259391254687216, 0.06334361038170755, 0.014467707896983484, 0.02581524142442504, 0.03868716390570626, 0.05430310877272859, 0.028120198112446815, 0.03257554068113677, 0.07438612956320867, 0.05882955279957969, 0.019332846786710434, 0.006104266685724724, 0.04895730773569085, 0.06935865050763823, 0.046273905827547424, 0.13099854957545176, 0.15456127817742527, 0.16765401000157, 0.13011623988859355, 0.1682505928329192, 0.10688802693039179, 0.12588758632773533, 0.18589922081446275, 0.10868083307286724, 0.1498667339910753, 0.27967235539108515, 0.17001755739329383, 0.11842883148347028, 0.10150314439670183, 0.20613142813090235, 0.13928755244705826, 0.3488404891686514, 0.22987277683569118, 0.1378726033726707, 0.15388700732728466, 0.0966808023804333, 0.10077085986267775, 0.2319296688074246, 0.11557525882381015, 0.11498624589876272, 0.21075707132695243, 0.14430893847020343, 0.12983820168301463, 0.12966447975486517, 0.20528284163447097, 0.20803481427719817, 0.06851985293906182, 0.1504131476394832, 0.16953075304627419, 0.15349135355791077, 0.10162749123992398, 0.16138897743076086, 0.13123320182785392, 0.1035545815830119, 0.1425412911339663, 0.12218499672599137, 0.06749693595338613, 0.10067164213978685, 0.11000539598171599, 0.28084346442483366, 0.13922576123150066, 0.21587322960840538, 0.2064162792521529, 0.07690888247452676, 0.16071868449216709, 0.09735416038893163, 0.11343682708684355, 0.13347960863029584, 0.16600145492702723, 0.16353397717466578, 0.30698784277774394, 0.24394365929765627, 1.4183198497630656, 7.4057019129395485, 15.068596825003624, 33.648893013596535, 55.424654334783554, 70.05118668079376, 76.62287324666977, 94.71413567662239, 91.31886586546898, 90.64914420247078, 92.81248971819878, 81.19632303714752, 77.5802394747734, 78.84684830904007, 72.88220956921577, 69.76937100291252, 58.050317242741585, 51.97094365954399, 49.023552015423775, 50.19056059420109, 47.540123015642166, 43.33572842180729, 43.86071965098381, 33.85537773370743, 38.25162023305893, 32.10744872689247, 29.0062565356493, 35.232959613204, 34.12038691341877, 37.98345722258091, 34.18122544884682, 50.144054889678955, 39.3600245565176, 41.50532104074955, 55.9516404569149, 58.78375768661499, 83.43745797872543, 82.64788314700127, 57.76511214673519, 62.895623445510864, 76.58964022994041, 63.54674890637398, 70.15251204371452, 72.09731608629227, 72.67859369516373, 67.98289686441422, 70.39520502090454, 74.8186768591404, 81.18450567126274, 86.48475766181946, 87.91361778974533, 86.81071937084198, 75.88187500834465, 55.24642489850521, 44.14221614599228, 30.154463723301888, 18.2408395037055, 6.819590488448739, 2.9749470530077815, 1.3144748657941818, 0.23806766053894535, 0.16744071675930172, 0.15102261415449902, 0.15661209938116372, 0.10173376678721979, 0.1584176259348169, 0.08146350955939852, 0.14854557754006237, 0.1362022664397955, 0.20357713394332677, 0.125979375152383, 0.11353849389706738, 0.10163577360799536, 0.24053602886851877, 0.14376641367562115, 0.2093110856367275, 0.14622923074057326, 0.12623375369003043, 0.18335340195335448, 0.13673224893864244, 0.17562458699103445, 0.1385882860631682, 0.09585413892637007, 0.17587877257028595, 0.09004633611766621, 0.08198139505111612, 0.15961319615598768, 0.09033864582306705, 0.1799228391610086, 0.15385445673018694, 0.1286978620919399, 0.2626541076460853, 0.09749755816301331, 0.08260617207270116, 0.15470878744963557, 0.09782105291378684, 0.1129230234073475, 0.19661357713630423, 0.09493020959780551, 0.09595725292456336, 0.13565165223553777, 0.10470347813679837, 0.12390277173835784, 0.060346884856699035, 0.23108411027351394, 0.21239177032839507, 0.1370813700486906, 0.11720068840077147, 0.19750350125832483, 0.18642092094523832, 0.09771780532901175, 0.17455976834753528, 0.15301581501262262, 0.19978211726993322, 0.07230254996102303, 0.34600898798089474, 0.10242520351312123, 0.1427929979399778, 0.10746077197836712], [0.010042183894256596, 0.011282857212790987, 0.022117195621831343, 0.03919045135262422, 0.018940254376502708, 0.01859270105342148, 0.012543057364382548, 0.018350079990341328, 0.08067347851465456, 0.0502041863364866, 0.01848424359195633, 0.029543971322709695, 0.06655059376498684, 0.018112045399902854, 0.0385224924684735, 0.03366156619449612, 0.06054593628505245, 0.023948187117639463, 0.018892411826527677, 0.024659364971739706, 0.019892724849341903, 0.0581144898023922, 0.027949118230026215, 0.06094111507991329, 0.061761971228406765, 0.036038398029631935, 0.017928078123077285, 0.04604952860972844, 0.029706883869948797, 0.016374412371078506, 0.010100037088704994, 0.02253557580843335, 0.063808016711846, 0.013113238292135065, 0.07436830317601562, 0.046688228321727365, 0.0417622528038919, 0.027282465525786392, 0.04476283378608059, 0.05907790138735436, 0.024771896823949646, 0.009342476860183524, 0.01684625502093695, 0.03826234744337853, 0.021367316621763166, 0.016849390594870783, 0.014171978746162495, 0.07953246356919408, 0.1457910073804669, 0.03509146212309133, 0.01453724713428528, 0.03477873593510594, 0.06742208293871954, 0.09247710724594072, 0.15140970353968441, 0.8886597398668528, 4.4080346915870905, 14.50657183304429, 32.6817537099123, 44.29840296506882, 60.3131528198719, 62.2244768589735, 71.1521016061306, 67.83587515354156, 67.017323076725, 56.93774834275246, 57.40053690969944, 57.06697940826416, 61.15898363292217, 43.40649962425232, 37.532493621110916, 32.021922916173935, 20.179605670273304, 19.569440111517906, 19.13200568407774, 11.431846171617508, 15.987077839672565, 17.29192592203617, 14.417554959654808, 14.49269212782383, 11.00092364475131, 10.210654400289059, 13.249601181596518, 24.208390787243843, 15.978594794869423, 21.382347531616688, 27.900430373847485, 22.084071077406406, 12.674100212752819, 25.178989805281162, 36.91108636558056, 44.187635108828545, 44.17103759944439, 35.8279924839735, 36.49547226727009, 40.02449870109558, 30.14938909560442, 40.80312252044678, 34.259189665317535, 34.574310556054115, 43.15790556371212, 34.70835596323013, 32.89702355861664, 34.21763889491558, 36.5891220420599, 39.92659315466881, 48.205744698643684, 67.87606179714203, 61.246641129255295, 59.07350733876228, 63.11859168112278, 57.70118057727814, 50.66437616944313, 41.9087415933609, 28.808703236281872, 18.98290928453207, 9.960303883999586, 2.1384293027222157, 0.24433723505353555, 0.03820799996901769, 0.030243627334129997, 0.022709626136929728, 0.06644323468208313, 0.052653036182164215, 0.031888067023828626, 0.033638752574916, 0.07123344170395285, 0.06429298053262755, 0.1393252980778925, 0.024439433218503837, 0.028743173570546787, 0.060629487270489335, 0.020627332305593882, 0.03433515055803582, 0.0374625942640705, 0.047861485872999765, 0.03781253544730134, 0.07094980028341524, 0.040610235519125126, 0.05307404542691074, 0.06962549712625332, 0.020698999651358463, 0.03574129776097834, 0.12120524304918945, 0.05604628750006668, 0.025822488496487495, 0.044756124771083705, 0.021250951576803345, 0.014378750365722226, 0.03166983478877228, 0.04717209376394749, 0.029357527128013317, 0.022576620285690296, 0.10731027185101993, 0.017454864355386235, 0.018749487171589863, 0.04176098373136483, 0.023161710960266646, 0.030195584404282272, 0.005540198271773988, 0.043608686537481844, 0.020920256138197146, 0.06000102177495137, 0.03928511971025728, 0.09533571908832528, 0.02886481899622595, 0.0891853631765116, 0.0016960509583441308, 0.012948903604410589, 0.016114373102027457, 0.04118674696655944, 0.03093159266427392, 0.03680555608298164, 0.06411926602595486, 0.029040528024779633, 0.019076547941949684, 0.02819775811076397, 0.03578022340661846, 0.06000707398925442, 0.03457871229329612, 0.03512231691274792, 0.056078893758240156, 0.044874096565763466, 0.040111371272359975, 0.09376351634273306, 0.03180548083037138, 0.043575096933636814, 0.019255034458183218, 0.007193031651695492, 0.020198851489112712, 0.03481503066723235, 0.046934268830227666, 0.05076765453850385, 0.024973786967166234, 0.003655615596471762, 0.06879970940644853, 0.05623827368253842, 0.004220381861159694, 0.02729283703956753, 0.06634547899011523, 0.07895614879089408, 0.029084092093398795, 0.0333461237460142, 0.054360732829081826, 0.050806153449229896, 0.05319421397871338, 0.029198303054727148, 0.053492958104470745, 0.009908862630254589, 0.025291550482506864, 0.09572398106683977, 0.0362466891965596, 0.009200637596222805, 0.010417885023343842, 0.048399550360045396, 0.03229716108762659, 0.02814900828525424, 0.057607491617091, 0.06913657765835524, 0.007822941552149132, 0.022701586822222453, 0.02100893536407966, 0.04074537690030411, 0.018529373592173215, 0.06988029868807644, 0.05173782708880026, 0.15181665279669687, 0.057456245631328784, 0.09754822458489798, 0.16915464744670317, 0.30488973192404956, 2.133438983000815, 7.460846928879619, 20.88380668312311, 38.778116181492805, 55.85866704583168, 71.57981425523758, 71.35640144348145, 80.40835171937943, 78.12041088938713, 73.28735902905464, 63.40547628700733, 64.61978852748871, 66.30553767085075, 68.77842217683792, 51.45665265619755, 46.45004130899906, 43.4870021045208, 32.59726144373417, 31.485131420195103, 29.28959783166647, 26.36116337031126, 29.153770320117474, 30.596682094037533, 25.5764826759696, 25.139785408973694, 18.808787427842617, 24.029984660446644, 19.61467858403921, 25.913235805928707, 29.720481410622597, 28.373987562954426, 37.85502031445503, 21.664054915308952, 16.683937646448612, 25.80548118799925, 36.8962861597538, 47.03058175742626, 50.19000202417374, 45.76271139085293, 49.77911867201328, 46.44549295306206, 39.291571229696274, 51.378479450941086, 42.15241111814976, 45.14290004968643, 55.05636669695377, 42.953940108418465, 41.72463767230511, 43.52628439664841, 47.24052809178829, 49.38236676156521, 56.79025165736675, 75.27158975601196, 68.53567600250244, 66.483254134655, 71.45006641745567, 67.27904543280602, 58.91183361411095, 48.473729118704796, 33.743435740470886, 23.77364281564951, 13.70032824575901, 3.4329051291570067, 0.5302255076821893, 0.27224408055189997, 0.07597631454700604, 0.08927743401727639, 0.11719449888914824, 0.07580884892377071, 0.05512388699571602, 0.035014096938539296, 0.01855912629252998, 0.005488402857736219, 0.031201231613522395, 0.0777104910230264, 0.030153734696796164, 0.021772430918645114, 0.021166973856452387, 0.015222255933622364, 0.01962900823855307, 0.017473189836891834, 0.058532983166514896, 0.06567128977621906, 0.052682803725474514, 0.06402839004294947, 0.028794361351174302, 0.005865486700713518, 0.05188600429391954, 0.09132303050137125, 0.049026895212591626, 0.03598394294385798, 0.07226694171549752, 0.06452464192989282, 0.0222048915020423, 0.0480765342945233, 0.031167582637863234, 0.07624225574545562, 0.03531389120325912, 0.052890987280989066, 0.03692216603667475, 0.035557378723751754, 0.035712888347916305, 0.06657597521552816, 0.08436290983809158, 0.009727155193104409, 0.027148383560415823, 0.0622204477986088, 0.05294157577736769, 0.02415467857645126, 0.02414338679955108, 0.03964926931075752, 0.013770370169368107, 0.00756744005229848, 0.05299675445712637, 0.0359503644722281, 0.043149575431016274, 0.03655069143860601, 0.007400491149383015, 0.013732449206145247, 0.041186661619576626, 0.0724215384980198, 0.12201215053210035, 0.1618271562620066, 0.1401830426766537, 0.12750018417136744, 0.14528824685839936, 0.12363127927528694, 0.09957410220522434, 0.1381320582004264, 0.2043223095824942, 0.0958493298094254, 0.15922868944471702, 0.20840035169385374, 0.08657526690512896, 0.10666971676982939, 0.11254265045863576, 0.15037774719530717, 0.19229046301916242, 0.11786114788264968, 0.08333997800946236, 0.10714925549109466, 0.088894062791951, 0.17123907309724018, 0.12336176092503592, 0.14902681577950716, 0.18585688871098682, 0.13207099749706686, 0.10659529420081526, 0.18591378175187856, 0.14175537158735096, 0.16529392101801932, 0.09363250501337461, 0.12971735035534948, 0.13743613148108125, 0.09575611606123857, 0.22359929862432182, 0.19223729555960745, 0.12921650457428768, 0.08255293039837852, 0.11851339921122417, 0.09020765675813891, 0.18084194452967495, 0.1889260404277593, 0.23937664576806128, 0.13460933550959453, 0.07202546912594698, 0.11697848938638344, 0.07858543118345551, 0.15774103958392516, 0.24408241122728214, 0.10698265818064101, 0.23643999709747732, 0.10911621400737204, 0.22378076857421547, 0.4557830194244161, 0.7571517652831972, 2.765463818795979, 8.363755904138088, 24.72097758203745, 45.96629686653614, 64.68200638890266, 83.93672078847885, 79.9968110024929, 90.52677556872368, 86.20997160673141, 84.39018845558167, 72.78571754693985, 76.21865093708038, 73.95575076341629, 78.75285655260086, 58.00506927073002, 53.140653893351555, 48.881435841321945, 34.93769645690918, 33.52440029382706, 35.92445030808449, 25.59775583446026, 29.81164611876011, 30.203631184995174, 25.662819743156433, 24.8841218277812, 20.884099267423153, 21.816003061830997, 23.829815201461315, 38.14481556415558, 27.677733823657036, 32.93771177530289, 42.39571966230869, 35.14320082962513, 26.103183813393116, 41.21754348278046, 51.20629169046879, 60.053831934928894, 61.02841503918171, 54.018349796533585, 56.127590015530586, 58.8106944411993, 46.78350381553173, 59.28991712629795, 51.758899837732315, 51.962895691394806, 60.125040113925934, 51.9825254380703, 48.18395286798477, 51.6878816485405, 54.946176409721375, 59.343619644641876, 67.75905847549438, 84.73853096365929, 80.85450857877731, 76.60805404186249, 82.34377026557922, 79.06515419483185, 70.53496152162552, 59.54962559044361, 41.015819907188416, 29.441946856677532, 17.351035550236702, 5.282333577051759, 1.0024802573025227, 0.6355848885141313, 0.29531109903473407, 0.384571990580298, 0.2574209572048858, 0.12962628883542493, 0.1687327810213901, 0.1372060360154137, 0.1882483556983061, 0.25556867534760386, 0.20211112510878593, 0.1547981717158109, 0.12960311898496002, 0.17641445476328954, 0.10249760001897812, 0.17101393517805263, 0.0919222405354958, 0.18772202456602827, 0.15096845221705735, 0.17587903974344954, 0.11853914431412704, 0.11068754101870582, 0.20767690613865852, 0.12592030019732192, 0.1451243954943493, 0.2502795372856781, 0.14150180941214785, 0.11837679950986058, 0.2585628553060815, 0.1284105915692635, 0.16202845639782026, 0.08798597831628285, 0.17947845597518608, 0.1974516102927737, 0.11984972516074777, 0.17136032518465072, 0.08799416420515627, 0.11295643489575014, 0.13377102033700794, 0.1609718904364854, 0.19387313746847212, 0.07107376863132231, 0.17408112762495875, 0.11834561446448788, 0.2097686642082408, 0.21193931257585064, 0.10166436113649979, 0.17465839977376163, 0.32707169477362186, 0.16178075718926266, 0.13417696027318016, 0.06023604510119185, 0.12816473288694397, 0.1678577740676701, 0.15658276970498264, 0.10623343783663586, 0.10174783048569225, 0.11334293056279421], [0.02311310399818467, 0.023169800369942095, 0.02436265433061635, 0.03388941666344181, 0.026178537555097137, 0.03796220807998907, 0.011630843764578458, 0.010961481293634279, 0.05885055928956717, 0.05585022321611177, 0.007966387565829791, 0.04289845492166933, 0.013922728448960697, 0.0967614738328848, 0.04930772389343474, 0.029540574141719844, 0.06289651835686527, 0.04944171494571492, 0.023581150562677067, 0.03495413882774301, 0.05204286462685559, 0.054753054355387576, 0.017468345467932522, 0.049251394884777255, 0.04339183469710406, 0.06437388205085881, 0.05782160864328034, 0.08118729703710414, 0.029980059152876493, 0.08185387181583792, 0.05845521722221747, 0.02959033885417739, 0.06494625602499582, 0.053667629981646314, 0.03252926035202108, 0.06517652960610576, 0.019277731189504266, 0.049537748855073005, 0.023132999122026376, 0.03244911953515839, 0.018696790975809563, 0.02968025375594152, 0.0605285292112967, 0.052228824570192955, 0.08631492892163806, 0.016653890343150124, 0.021051443727628794, 0.07616661605425179, 0.01462708503822796, 0.0037532492979153176, 0.0798004753596615, 0.413422595593147, 2.155707450583577, 2.713863062672317, 13.063847199082375, 22.15023312717676, 31.11930415034294, 51.232305094599724, 64.32034939527512, 70.76671868562698, 65.0835232436657, 63.88328164815903, 66.77213743329048, 56.05304941534996, 54.95008260011673, 44.70637187361717, 39.97771941125393, 37.53087870776653, 33.57018023729324, 38.34658853709698, 24.579902552068233, 19.603148102760315, 11.897564381361008, 9.328657127916813, 12.660609986633062, 18.292216546833515, 23.509942665696144, 31.02971065789461, 19.987755864858627, 23.230425864458084, 35.710487589240074, 32.375186160206795, 26.40200737863779, 24.889878518879414, 23.855032548308372, 32.51823328435421, 21.2977222725749, 23.44311185181141, 27.27066356688738, 39.3599409610033, 38.90201233327389, 23.21909487247467, 19.82567746192217, 24.709285609424114, 14.846666883677244, 13.968075178563595, 15.466493424028158, 17.168474346399307, 19.172555208206177, 18.255772702395916, 23.236876018345356, 21.309300251305103, 25.552576258778572, 24.242657348513603, 21.675522699952126, 21.44505936652422, 34.36931915581226, 42.769042029976845, 41.10766097903252, 52.457769736647606, 48.97334150969982, 59.792314767837524, 63.07095743715763, 55.93703784048557, 44.2790088057518, 40.82602769136429, 34.95099954307079, 25.489218458533287, 11.87981078401208, 5.091867372393608, 1.0907902498729527, 0.03811093818512745, 0.013442846484394977, 0.0338704510795651, 0.008274899282696424, 0.06299532789853401, 0.026945589852402918, 0.03705835755681619, 0.02782837451377418, 0.04267991469532717, 0.04988406093616504, 0.02040560641034972, 0.057125344246742316, 0.08089500217465684, 0.0021284598233251018, 0.03243203529564198, 0.10825921897776425, 0.04038911261886824, 0.027276237051410135, 0.05554278854106087, 0.04289595388399903, 0.04561337955237832, 0.020794835036213044, 0.05248518464213703, 0.03413598409679253, 0.02205199980380712, 0.031101255044632126, 0.03146587034279946, 0.016413735065725632, 0.016776535812823568, 0.07429018471157178, 0.03873652414768003, 0.01433063693184522, 0.06818645793828182, 0.03495136690617073, 0.002661511334736133, 0.041485249894321896, 0.011847529549413593, 0.057082173516391777, 0.017159413509943988, 0.023620226493221708, 0.04573616046400275, 0.030520856598741375, 0.06628696064581163, 0.06889376920298673, 0.03570092492736876, 0.03313635941594839, 0.03993025384261273, 0.014393616511370055, 0.020236428281350527, 0.03964174393331632, 0.029160408994357567, 0.050269454513909295, 0.06503953656647354, 0.007050259137031389, 0.01458068132706103, 0.05664269963745028, 0.024874984846974257, 0.0120913111459231, 0.0696426333161071, 0.03522793194861151, 0.03592985151044559, 0.0919569210964255, 0.002578126636763045, 0.05508344736881554, 0.059316260667401366, 0.047424097429029644, 0.02395230232650647, 0.057225916389143094, 0.07754538542940281, 0.03667199176561553, 0.047843882130109705, 0.02333549226023024, 0.02720224863878684, 0.04043485489091836, 0.06360686500556767, 0.01814036204450531, 0.028610796689463314, 0.12545310339191929, 0.055617830803385004, 0.0639118802791927, 0.021232577855698764, 0.026302127407689113, 0.06894226113217883, 0.05438085245259572, 0.0374527236999711, 0.0288269397788099, 0.02753084565483732, 0.04978384873538744, 0.060327158571453765, 0.01759725095325848, 0.029829777959093917, 0.029128123715054244, 0.04441943092388101, 0.046359998668776825, 0.019180153612978756, 0.04769321130879689, 0.046046125862631015, 0.0698467981419526, 0.04701466939877719, 0.031442303443327546, 0.06954875905648805, 0.07780025378451683, 0.017891391908051446, 0.025697091514302883, 0.03567621512047481, 0.06131369176728185, 0.7953889947384596, 2.87441560998559, 4.005975415930152, 18.959648832678795, 28.791108280420303, 40.17948858439922, 60.06491594016552, 73.95383566617966, 79.16657835245132, 73.72076377272606, 73.41519936919212, 76.67249858379364, 66.26165762543678, 68.74703586101532, 57.04618312418461, 53.95467661321163, 48.06981839239597, 44.69308398663998, 42.898972257971764, 37.41875432431698, 34.50636640191078, 21.183278113603592, 22.362782321870327, 23.886101581156254, 29.20726004987955, 26.163439080119133, 36.10356889665127, 23.35462599992752, 26.48306082934141, 31.59049216657877, 27.209277860820293, 26.26786507666111, 33.75160530209541, 33.29730927944183, 32.03792005777359, 28.611657209694386, 36.260800659656525, 32.010740116238594, 53.35789583623409, 50.21059311926365, 37.67041102051735, 33.90972621738911, 34.11846801638603, 23.243668153882027, 24.252837002277374, 19.326068870723248, 27.78004713356495, 28.48812773823738, 30.11328913271427, 33.69610548019409, 33.218505308032036, 35.84836319088936, 35.949547961354256, 32.160197496414185, 31.22668068856001, 46.0340890288353, 50.89445762336254, 48.37979435920715, 60.82472316920757, 56.314570382237434, 68.43037605285645, 71.31707355380058, 65.16337975859642, 53.900252133607864, 48.814711421728134, 43.39014530181885, 33.385004773736, 17.137361615896225, 8.419115133583546, 2.0042777387425303, 0.1912977811298333, 0.16316701483447105, 0.026278836958226748, 0.03331098305352498, 0.10266436060192063, 0.0022005886921760975, 0.0669809800456278, 0.03431756536883768, 0.019479701113596093, 0.05527674344193656, 0.02085458534565987, 0.035882810479961336, 0.08226490288507193, 0.011537999234860763, 0.03519764490192756, 0.08990007365355268, 0.030213433055905625, 0.04548946315480862, 0.029416329343803227, 0.044625714581343345, 0.04933352465741336, 0.0966600445099175, 0.07078970418660901, 0.06777820250135846, 0.02554868238803465, 0.02901333944464568, 0.004107029008082463, 0.04536220709269401, 0.03673707069538068, 0.017837686391430907, 0.004358898622740526, 0.06190179927216377, 0.034426353086018935, 0.04352333584392909, 0.016801184392534196, 0.058096147622563876, 0.016795824230939616, 0.00856402053614147, 0.041666463803267106, 0.04462222277652472, 0.06231450388440862, 0.018406633498671, 0.009112457464652834, 0.04415243587573059, 0.04426907922606915, 0.02897965707234107, 0.060435912891989574, 0.030191591649781913, 0.045832643372705206, 0.05257771190372296, 0.09787251343368553, 0.04796027686097659, 0.050847888123826124, 0.01219057061462081, 0.038241571019170806, 0.11213537465664558, 0.1264468688168563, 0.1317517107236199, 0.1368490036111325, 0.18158838181989267, 0.13749020436080173, 0.17017517471686006, 0.10418815305456519, 0.12970065203262493, 0.17044878972228616, 0.13163388735847548, 0.1437857688870281, 0.2112054027384147, 0.32256754115223885, 0.135240962554235, 0.1693202502792701, 0.1707809601793997, 0.17764502466889098, 0.16553928988287225, 0.14811461238423362, 0.11130269238492474, 0.18423042754875496, 0.20083191484445706, 0.15889712754869834, 0.12935411359649152, 0.09077593407710083, 0.15552615921478719, 0.16416845406638458, 0.18485963519196957, 0.1735709753120318, 0.12837811518693343, 0.10085161295137368, 0.17638724762946367, 0.1639199978671968, 0.11931316723348573, 0.09934735382557847, 0.08509399209287949, 0.1267263913177885, 0.1742864353582263, 0.11877153301611543, 0.16590736544458196, 0.08403698826441541, 0.16481624508742243, 0.13400448515312746, 0.2287849664571695, 0.20111372316023335, 0.17252686258871108, 0.13062633282970637, 0.16334919724613428, 0.19180802250048146, 0.229559471772518, 1.19545622728765, 3.666854538023472, 5.387473935261369, 21.96463018655777, 34.668108522892, 50.38220711052418, 72.14482873678207, 86.6418944299221, 87.94729918241501, 85.40986374020576, 85.1942253112793, 84.86837759613991, 75.13228163123131, 73.5760447382927, 62.846951857209206, 58.4980396181345, 54.150905683636665, 49.614982679486275, 55.37439063191414, 39.72570173442364, 31.615399830043316, 20.99050495773554, 21.644256077706814, 24.92091905325651, 28.38380243629217, 34.598731845617294, 42.31455601751804, 28.958627991378307, 34.93259713053703, 48.74718904495239, 46.08717978000641, 44.37223680317402, 39.882523119449615, 36.99298717081547, 47.93656334280968, 34.35594767332077, 43.248686492443085, 45.21389544010162, 57.729511857032776, 55.74626907706261, 39.57760468125343, 34.395267963409424, 38.60102288424969, 26.878336519002914, 26.954594627022743, 25.610359758138657, 30.680917873978615, 31.283402144908905, 30.834389738738537, 35.99963687360287, 34.82004337012768, 38.854271695017815, 38.904607594013214, 36.24241344630718, 38.90085719525814, 50.800621658563614, 62.67610162496567, 59.515765607357025, 71.17707386612892, 64.86941993236542, 77.96075105667114, 79.31161656975746, 75.17041638493538, 64.1381111741066, 59.180414602160454, 50.15490710735321, 41.399173736572266, 22.17375196516514, 10.249769501388073, 2.9885125625878572, 0.45715712069068104, 0.17458173591876402, 0.19477281341096386, 0.1930481512681581, 0.16324001247994602, 0.10331353201763704, 0.1540113615919836, 0.17472660314524546, 0.09973513340810314, 0.21260433626594022, 0.10023329261457548, 0.12310426536714658, 0.31130527204368263, 0.11034180410206318, 0.14689904870465398, 0.2784442197298631, 0.14327003562357277, 0.18300763535080478, 0.16531389963347465, 0.14835110516287386, 0.17763928044587374, 0.17450180661398917, 0.22852585301734507, 0.24410846061073244, 0.222276390704792, 0.15468236699234694, 0.10769082291517407, 0.09837715158937499, 0.16388986667152494, 0.18746078858384863, 0.09894406335661188, 0.12008857054752298, 0.17308408190729097, 0.13774088700301945, 0.1850211710552685, 0.11302254541078582, 0.11553617732715793, 0.10423490835819393, 0.0863950808707159, 0.1334493883769028, 0.153547118534334, 0.14965173380915076, 0.210170091886539, 0.22769875911762938, 0.1053342071827501, 0.11994971471722238, 0.21463031036546454, 0.1433898924733512, 0.09340827251435257, 0.13107151753501967, 0.21363877138355747, 0.12250184925505891, 0.15334558091126382, 0.0782178677036427, 0.12718362850137055], [0.021519659130717628, 0.07582035221275873, 0.043010007138946094, 0.005743774481743458, 0.020806726097362116, 0.032963836056296714, 0.053379895616672, 0.01668829074333189, 0.02813609862641897, 0.0029365327100094873, 0.02735940768616274, 0.009382460993947461, 0.01139952282755985, 0.030083484853093978, 0.04682605627749581, 0.06861766800284386, 0.03297451556136366, 0.03445230227953289, 0.09063709308975376, 0.07084071199642494, 0.017833300298661925, 0.030076939110585954, 0.037667427022824995, 0.08415933873038739, 0.01661768095800653, 0.03939454196370207, 0.04431204215507023, 0.026610101995174773, 0.006823739895480685, 0.06700983474729583, 0.04624077264452353, 0.030647043968201615, 0.02177770387788769, 0.017023696964315604, 0.0241483183708624, 0.07818525773473084, 0.112406087864656, 0.03738822364539374, 0.03166561567923054, 0.019709963562490884, 0.06364224318531342, 0.015016227389423875, 0.049614141826168634, 0.013010280144953867, 0.032727781144785695, 0.05346064499462955, 0.004859681321249809, 0.06277632754063234, 0.11734891755622812, 1.0126286814920604, 3.1960645504295826, 11.925273444503546, 16.657297275960445, 26.79507538676262, 49.948764368891716, 64.28032234311104, 68.08318108320236, 67.23218634724617, 64.44490671157837, 56.37381300330162, 54.22807194292545, 47.86522217094898, 39.151145964860916, 42.75570094585419, 28.105649761855602, 24.56107646226883, 22.09771804511547, 22.64015033841133, 24.725185856223106, 32.347333654761314, 18.60195502638817, 8.597373068332672, 19.112353138625622, 16.326536424458027, 21.91811118274927, 29.398908466100693, 48.42724621295929, 45.534385442733765, 37.013943046331406, 33.52880425751209, 34.271090626716614, 45.43276749551296, 29.28243901580572, 29.272838830947876, 42.82569319009781, 42.28547617793083, 36.12712763249874, 33.10676850378513, 25.352710783481598, 19.27480772137642, 22.17551127076149, 28.50843194872141, 27.80222464352846, 22.80255362391472, 33.52873586118221, 28.579999208450317, 27.86085929721594, 19.68696590512991, 19.900808930397034, 18.651000894606113, 19.133791588246822, 18.938972242176533, 21.749713718891144, 16.529173851013184, 23.931423649191856, 17.628762647509575, 21.53328873217106, 33.43207284808159, 37.71527141332626, 36.110427528619766, 41.70054316520691, 44.82975125312805, 50.7275477796793, 61.5996839851141, 61.564874053001404, 59.916115924715996, 56.02216087281704, 52.41654194891453, 48.95520508289337, 32.99692399799824, 14.8926567658782, 6.754485256969929, 3.0171824991703033, 0.3364588238764554, 0.04741375560115557, 0.06448083295254037, 0.0739067021640949, 0.04450790605915245, 0.00815858804344316, 0.02397508254944114, 0.09857436991296709, 0.04733100984594785, 0.08599277745815925, 0.0489975766686257, 0.03539041405019816, 0.04697205527918413, 0.049919765660888515, 0.01202152699988801, 0.04840196605073288, 0.008797572554612998, 0.0810910998552572, 0.04701859535998665, 0.05181744469155092, 0.09194776299409568, 0.0440286938828649, 0.048011444232543, 0.03394978295546025, 0.10489932348718867, 0.014700296978844563, 0.06358663405990228, 0.02093524752126541, 0.059421641926746815, 0.059813228726852685, 0.03024310226464877, 0.027086622030765284, 0.028964858647668734, 0.02964577914099209, 0.03915845736628398, 0.015770864483783953, 0.03723463989445008, 0.06604750669794157, 0.008709977792022983, 0.023902689754322637, 0.08184492893633433, 0.024754784753895365, 0.05439907959953416, 0.024534199910704046, 0.03852596943033859, 0.05837789285578765, 0.05493731106980704, 0.013698475540877553, 0.01037434971294715, 0.020677967186202295, 0.019778907226282172, 0.04444064892595634, 0.06336326987366192, 0.04194596775050741, 0.0071213698720384855, 0.04687052576628048, 0.034334668162046, 0.021318965700629633, 0.033799008233472705, 0.05374996013415512, 0.06549352314323187, 0.05551805646973662, 0.035595009321696125, 0.012811188826162834, 0.04681975915445946, 0.01881048799987184, 0.04029003961477429, 0.006025138900440652, 0.03621210882556625, 0.04528253753960598, 0.015841270178498235, 0.03175022422510665, 0.04559861452435143, 0.051623421313706785, 0.056860954136936925, 0.04746698614326306, 0.04782825621077791, 0.040547104727011174, 0.05016946866817307, 0.07445351657224819, 0.04364685890323017, 0.0244637645300827, 0.060069881947129034, 0.03293580513854977, 0.06871460733236745, 0.06527097531943582, 0.04080390266608447, 0.03232361494156066, 0.03763328451896086, 0.0867124083742965, 0.014580551451217616, 0.05795657190901693, 0.01668283966864692, 0.046781364144408144, 0.11163182745804079, 0.016911233760765754, 0.06341617758153006, 0.05057571659563109, 0.024091288032650482, 0.05431063786090817, 0.02874963953217957, 0.18003300356213003, 1.2475795741192997, 4.279403518885374, 13.379211276769638, 22.7144705504179, 37.849730998277664, 60.0632668286562, 73.19114059209824, 79.59711804986, 77.60865435004234, 75.75873121619225, 65.94540819525719, 65.71274667978287, 54.85963225364685, 48.42398598790169, 51.20350643992424, 40.394940823316574, 38.555022552609444, 36.23898983001709, 30.07003605365753, 31.21939267963171, 46.03945054113865, 27.224458046257496, 16.8429534137249, 24.80087209492922, 23.997196219861507, 28.144086599349976, 30.729623660445213, 49.71386477351189, 42.18110337853432, 27.67383713275194, 28.49262099713087, 30.59929635375738, 32.53142237663269, 27.987586297094822, 28.575226664543152, 32.054749354720116, 41.53530903160572, 37.33420506119728, 37.669445872306824, 36.52953743934631, 27.848414964973927, 30.74632376432419, 28.599224276840687, 28.905852623283863, 31.929276287555695, 34.42965231835842, 30.464156605303288, 32.31935195624828, 25.90830747038126, 25.254771038889885, 23.388305492699146, 30.91910809278488, 27.12753664702177, 28.203452713787556, 26.342380978167057, 31.958690509200096, 30.639249309897423, 30.51829420030117, 39.85367126762867, 45.42690820991993, 44.432980343699455, 49.227376878261566, 56.15176811814308, 55.56765966117382, 69.65587109327316, 69.7828982770443, 71.49615794420242, 66.89583599567413, 62.48519226908684, 56.52398094534874, 43.067166432738304, 20.512247420847416, 10.822453871369362, 4.255436304956675, 0.5186845769640058, 0.06891382203320973, 0.15777255117427558, 0.10432925017084926, 0.0865425233496353, 0.06477074552094564, 0.03531234382535331, 0.04405979358125478, 0.021277756095514633, 0.039418053202098235, 0.04239070345647633, 0.05347726539184805, 0.046623390589957125, 0.09090309366001748, 0.009268766752938973, 0.047808010422158986, 0.037960541958454996, 0.07577042793855071, 0.050259068157174625, 0.00922617675314541, 0.025529549820930697, 0.07333588670007885, 0.07224918954307213, 0.01873841989436187, 0.0410456201643683, 0.04435216265846975, 0.033580913295736536, 0.03402807211386971, 0.04333546487032436, 0.02683432150661247, 0.0007383521710835339, 0.06852470658486709, 0.0214679870987311, 0.06203637291037012, 0.035717478531296365, 0.012930541943205753, 0.10524007317144424, 0.0708460109308362, 0.012597251770785078, 0.0388447107252432, 0.04053456614201423, 0.029374392433965113, 0.039343114840448834, 0.00813079275758355, 0.04399572026159149, 0.05322337667166721, 0.0903616301366128, 0.03225317399483174, 0.0060807160207332345, 0.039558115022373386, 0.010226089016214246, 0.0833420708659105, 0.025602393470762763, 0.12808530824258924, 0.16938137356191874, 0.12861662660725415, 0.1610526509466581, 0.11719330403138883, 0.13044518942479044, 0.15830541320610791, 0.10907643489190377, 0.12691580224782228, 0.09623771795304492, 0.13517391693312675, 0.10669329480151646, 0.05010981112718582, 0.1031096640508622, 0.08716109601664357, 0.15540765307378024, 0.06908834548084997, 0.11694730434101075, 0.19611320632975549, 0.19697961921337992, 0.12716163124423474, 0.10678506136173382, 0.18785691732773557, 0.2722659887513146, 0.18718696577707306, 0.19221117196138948, 0.13675348920514807, 0.142542285611853, 0.06636549471295439, 0.1693329558474943, 0.15247112314682454, 0.17363879276672378, 0.2745428978232667, 0.12012534396490082, 0.08521797528374009, 0.11459073313744739, 0.207344290392939, 0.1595564663875848, 0.10827199133927934, 0.2096310255001299, 0.11176690575666726, 0.2985180972609669, 0.10819882299983874, 0.19455766479950398, 0.17025972018018365, 0.07459229818778113, 0.2700990659650415, 0.1526617957279086, 0.3700814978219569, 2.5993374455720186, 6.764906672760844, 16.96048490703106, 27.37429540604353, 47.65513524413109, 71.86687365174294, 85.6281316280365, 86.195547580719, 86.18341863155365, 83.39971840381622, 76.39619261026382, 72.3342789709568, 61.5538964420557, 56.63892097771168, 58.708248138427734, 44.711091220378876, 37.69855611026287, 35.38476526737213, 36.58267378807068, 38.85856546461582, 48.43732327222824, 27.633929774165154, 16.592563949525356, 29.697960019111633, 28.859949186444283, 34.46089044213295, 40.316839814186096, 62.06641674041748, 63.10970775783062, 52.31381066143513, 50.741162449121475, 52.955679818987846, 64.6146360039711, 42.266511395573616, 45.44332712888718, 59.758751168847084, 60.91815635561943, 54.72226582467556, 50.09496912360191, 41.531163454055786, 32.53617212176323, 37.064210548996925, 40.95854938030243, 41.10575348138809, 37.235174775123596, 47.05322094261646, 43.73174697160721, 43.28928731381893, 29.310054033994675, 32.25117601454258, 28.60503986477852, 32.546784952282906, 31.684863902628422, 35.100339129567146, 28.403169997036457, 38.59530799090862, 30.887193605303764, 32.24697723984718, 50.134578198194504, 53.599426075816154, 51.24349169433117, 58.87368746101856, 63.558030501008034, 68.67183789610863, 82.85626396536827, 80.66846296191216, 81.5513227880001, 76.76630035042763, 71.55412763357162, 64.73766580224037, 49.98917140066624, 25.353531539440155, 12.974361050873995, 5.384857775643468, 0.6772876507602632, 0.24119842535583302, 0.20576972019625828, 0.17679352895356715, 0.21519989386433735, 0.16031837003538385, 0.13882933562854305, 0.17128750565461814, 0.12551713589346036, 0.1896416489034891, 0.13443809235468507, 0.21988805558066815, 0.12274646112928167, 0.15848578477744013, 0.0745104170346167, 0.1226956165919546, 0.08994222764158621, 0.20627390564186499, 0.13045851839706302, 0.09873307819361798, 0.1290190636063926, 0.19393255381146446, 0.1804648296092637, 0.10130313559784554, 0.15209013421554118, 0.1561086263973266, 0.11834289078251459, 0.08747904692427255, 0.21505940530914813, 0.08602045214502141, 0.12050772813381627, 0.17494095023721457, 0.12877624772954732, 0.22898369876202196, 0.11105517129180953, 0.06589499535039067, 0.15047640830744058, 0.13368013693252578, 0.10437730423291214, 0.1795297977514565, 0.14473564369836822, 0.24809388269204646, 0.17968747444683686, 0.19125932303722948, 0.12506491562817246, 0.1910452134325169, 0.17093727132305503, 0.1640899051562883, 0.15402215241920203, 0.07226525704027154, 0.10377745595178567, 0.20493507123319432, 0.19401404162636027], [0.0410885571182007, 0.04938295540341642, 0.05533957366424147, 0.05385842130635865, 0.04085224987647962, 0.03119978071481455, 0.03439555024669971, 0.040981532001751475, 0.017042690378730185, 0.03267629836045671, 0.035115266509819776, 0.030699088929395657, 0.03545577128534205, 0.0664755329489708, 0.039122103262343444, 0.07411684870021418, 0.09678474016254768, 0.03786361005040817, 0.06430582710891031, 0.021691514557460323, 0.04733584122732282, 0.03829044144367799, 0.030010299815330654, 0.06442696045269258, 0.03652005187177565, 0.047537824138998985, 0.009346597635158105, 0.13509613985661417, 0.01582542718097102, 0.07258439538418315, 0.06535507549415343, 0.0193390511412872, 0.045241845582495444, 0.0484576456801733, 0.018790800677379593, 0.07098248446709476, 0.047958592185750604, 0.08503602293785661, 0.033864547294797376, 0.02489323611371219, 0.03963888295402285, 0.15111545682884753, 0.08047672032262199, 0.061684097672696225, 0.012415410747053102, 0.11066083854530007, 0.053652241549571045, 0.7793759414926171, 4.075916362926364, 9.918486177921295, 16.437479071319103, 31.33832059800625, 50.02387493848801, 71.7558816075325, 71.47332116961479, 73.42371091246605, 66.09344825148582, 56.6927944868803, 49.57159660756588, 51.12473286688328, 35.23548647761345, 34.29278366267681, 32.66968175768852, 32.71060176193714, 25.51212552934885, 13.337328974157572, 18.24269000440836, 25.441567115485668, 20.50025336444378, 7.822299683466554, 24.062225930392742, 36.71815171837807, 36.75464116036892, 34.78688634932041, 35.876006707549095, 50.06915330886841, 37.85742558538914, 36.1536768078804, 28.689767718315125, 29.08717129379511, 18.91676053404808, 12.517803199589252, 19.735859781503677, 26.603700555860996, 38.53198058903217, 25.945233888924122, 24.199560061097145, 35.67745216190815, 24.63018525391817, 31.74132887274027, 28.505221121013165, 36.676448956131935, 40.39034686982632, 27.430473491549492, 34.331005811691284, 32.03425705432892, 31.307329460978508, 40.9378556907177, 38.023191690444946, 47.56694957613945, 25.107654333114624, 35.80458573997021, 39.3068578094244, 37.16291785240173, 46.899238005280495, 28.319131806492805, 41.41773574054241, 30.22320583462715, 22.439676895737648, 27.36645072698593, 20.80144040286541, 30.481791459023952, 36.098180785775185, 30.57403340935707, 43.35798762738705, 45.30822157859802, 54.853563979268074, 55.05865037441254, 59.501478374004364, 57.729580253362656, 47.423929050564766, 30.7729584351182, 15.918552316725254, 5.8063150104135275, 0.7084036467131227, 0.11686357524013147, 0.015870911556703504, 0.023519743408542126, 0.037672889229725115, 0.06544681236846372, 0.057479014722048305, 0.043336986273061484, 0.01913293446705211, 0.03337290043418761, 0.045440229077939875, 0.007707655404374236, 0.04239278146997094, 0.0304604754637694, 0.027041879802709445, 0.05679944122675806, 0.021389039284258615, 0.020913389416818973, 0.10685009576263838, 0.035841984936269, 0.028481635163188912, 0.016557418566662818, 0.07059613722958602, 0.03440711661824025, 0.028051388035237323, 0.08505053934641182, 0.04270160025043879, 0.04061519677634351, 0.047547223439323716, 0.12728426372632384, 0.028844452608609572, 0.018102176691172644, 0.023071306241035927, 0.02744519068073714, 0.05889106942049693, 0.05229727285041008, 0.04602715285727754, 0.057115726012852974, 0.024267421940749045, 0.02230430403869832, 0.04432290719705634, 0.0054397230724134715, 0.04990788016584702, 0.03098005305218976, 0.06812996565713547, 0.06400759506504983, 0.008946694142650813, 0.07368942358880304, 0.07839604251785204, 0.03523191357089672, 0.06655105389654636, 0.01776748293195851, 0.01765865625202423, 0.07185284557635896, 0.10368162984377705, 0.08276239415863529, 0.01815408806578489, 0.028083682591386605, 0.0502872029755963, 0.029253175598569214, 0.018034010427072644, 0.016605441087449435, 0.023166664796008263, 0.026191937031398993, 0.021268507080094423, 0.0460064914659597, 0.011914637325389776, 0.04673284252930898, 0.07196111750090495, 0.007831306484149536, 0.04372154493466951, 0.023963070889294613, 0.056000111071625724, 0.00496667350489588, 0.010224720681435429, 0.04033934048493393, 0.05493859869602602, 0.02110328645358095, 0.0558800501312362, 0.018834006659744773, 0.02214095733506838, 0.028439314191928133, 0.05843168000865262, 0.04047484922921285, 0.0290020921966061, 0.05359727067116182, 0.055836352476035245, 0.06274257466429844, 0.03180774067004677, 0.02562889741966501, 0.035452813826850615, 0.035591417326941155, 0.03301991644548252, 0.06609694857615978, 0.07371127241640352, 0.11542370484676212, 0.01806244395993417, 0.04696028110629413, 0.04236128843331244, 0.9306582331191748, 4.914311924949288, 12.213142197579145, 20.530716329813004, 36.60829961299896, 60.565094500780106, 82.9718841612339, 81.3920809328556, 80.90968921780586, 72.96464994549751, 65.56650772690773, 57.971528470516205, 59.320988059043884, 43.355388566851616, 48.50812867283821, 43.14684435725212, 45.08941791951656, 36.72631748020649, 24.94258739054203, 21.843954361975193, 31.0627593845129, 36.04861244559288, 20.09427934885025, 26.580992974340916, 26.147008761763573, 35.17048716545105, 33.07976335287094, 30.276965349912643, 30.38995798677206, 33.58297035098076, 30.20228985697031, 25.7993084192276, 23.461204580962658, 13.753853123635054, 13.397489245980978, 13.967970684170723, 20.8737201243639, 26.5817928314209, 21.93202033638954, 22.474796511232853, 30.82494344562292, 22.48543594032526, 26.801536940038204, 27.104669474065304, 30.49619648605585, 33.727708384394646, 28.242398723959923, 33.41935873031616, 37.49398648738861, 32.788288593292236, 35.25270335376263, 35.755541771650314, 37.81596980988979, 27.24369451403618, 35.886604338884354, 38.92445772886276, 31.187331900000572, 41.1025046557188, 27.863806039094925, 37.162731662392616, 43.43190886080265, 39.03878599405289, 36.73294812440872, 30.23043494671583, 37.50635102391243, 44.0673753619194, 40.841356068849564, 51.71904377639294, 53.430316150188446, 63.99846866726875, 64.67113137245178, 69.1189295053482, 65.11468157172203, 59.099938720464706, 40.08623778820038, 22.775007002055645, 10.254642739892006, 1.6961020440794528, 0.5903158395085484, 0.009927143582899589, 0.0614755987044191, 0.07461501532816328, 0.06406176442396827, 0.0941039172175806, 0.02938957306469092, 0.05122314396430738, 0.11814374287496321, 0.04980710393283516, 0.005067153806521674, 0.006923869532329263, 0.0178620548103936, 0.02958842225780245, 0.08501807038555853, 0.02954716812382685, 0.041242927545681596, 0.009887861706374679, 0.045954329616506584, 0.04684216830355581, 0.057884383204509504, 0.030639008364232723, 0.01856370163295651, 0.05952537561825011, 0.018947959724755492, 0.06968731060624123, 0.03584025573218241, 0.046131884737405926, 0.03055937591852853, 0.01998752308281837, 0.04009419426438399, 0.021783128977403976, 0.0423138243786525, 0.06969024208956398, 0.015331713439081796, 0.044734680413967, 0.06797617781558074, 0.024989770972752012, 0.023326935297518503, 0.05217055484536104, 0.049347321182722226, 0.05515707583981566, 0.06891557350172661, 0.021237739492789842, 0.0432168065890437, 0.02263862857944332, 0.08277967135654762, 0.028460994180932175, 0.04711531575594563, 0.018684354436118156, 0.03941037197364494, 0.0884826309629716, 0.20078521891264245, 0.19883286586264148, 0.14542091317707673, 0.1249914281652309, 0.19179062655894086, 0.17937560915015638, 0.2718580747023225, 0.09812670643441379, 0.08911986122257076, 0.09766329458216205, 0.2287476067431271, 0.12735461932606995, 0.14866429148241878, 0.11106118268799037, 0.14964318426791579, 0.14942134148441255, 0.11435161315603182, 0.11299046978820115, 0.09767859766725451, 0.1281898026354611, 0.12894504179712385, 0.16402225097408518, 0.14180426427628845, 0.10321284484234639, 0.16428921633632854, 0.15128757571801543, 0.23494881461374462, 0.07128525103325956, 0.16652664315188304, 0.15419918432598934, 0.10058161962660961, 0.1715846615843475, 0.12897631590021774, 0.1370462664635852, 0.18882913078414276, 0.1956190398777835, 0.17558511957759038, 0.14755910000531003, 0.19527968543116003, 0.12670338473981246, 0.1368580578127876, 0.15620920225046575, 0.1764609428937547, 0.13769298879196867, 0.2869681123411283, 0.2172410226194188, 1.8675622623413801, 7.638365803286433, 17.028362564742565, 26.443358659744263, 48.04887771606445, 72.55231887102127, 95.8523266017437, 89.9634861946106, 90.79298168420792, 84.79208528995514, 74.42453160881996, 68.39185371994972, 69.96494650840759, 50.69663263857365, 52.883647084236145, 46.34660705924034, 48.5830644518137, 40.379528850317, 24.675011448562145, 26.623679883778095, 42.56832920014858, 33.89525279402733, 18.230209574103355, 39.67794969677925, 47.60552890598774, 50.49950301647186, 48.00807550549507, 52.53104120492935, 65.15356868505478, 50.19813358783722, 50.50933688879013, 41.45844295620918, 39.376363679766655, 26.882024221122265, 18.907872810959816, 27.8228822350502, 34.585508555173874, 48.167389556765556, 33.58524642884731, 33.63391041755676, 46.253056079149246, 34.7786445915699, 42.927512526512146, 38.81584815680981, 48.40330369770527, 54.04699265956879, 39.040077924728394, 48.965130150318146, 49.246816635131836, 46.0147100687027, 56.43492512404919, 55.383863523602486, 62.70164765417576, 39.40554991364479, 52.17900149524212, 54.359343498945236, 51.8022783100605, 60.832588747143745, 40.529768988490105, 55.41432648897171, 48.04551489651203, 41.240532249212265, 43.254929557442665, 34.28382374346256, 43.98933134973049, 53.1115398555994, 50.72828494012356, 62.63562619686127, 66.97336703538895, 75.77353522181511, 74.32554692029953, 79.44908559322357, 74.73718643188477, 67.78216883540154, 47.69410215318203, 26.90268751233816, 11.394695565104485, 2.278482662513852, 0.5559566582087427, 0.11397716996725649, 0.2328287807176821, 0.2214224755880423, 0.221879564342089, 0.17961688135983422, 0.17884495871840045, 0.14495664043352008, 0.2592441171873361, 0.1269884139765054, 0.11791817451012321, 0.12383604524075054, 0.08975588178145699, 0.09180840250337496, 0.10952901138807647, 0.10331474913982674, 0.18139621010050178, 0.24734306673053652, 0.07924953461042605, 0.1557747638435103, 0.1236032038286794, 0.14002974465256557, 0.10358676852774806, 0.13174152845749632, 0.22759445768315345, 0.1347642662585713, 0.13462961098412052, 0.11518859246280044, 0.179044863616582, 0.09742507259943523, 0.11479446751764044, 0.09506930291536264, 0.12855333625338972, 0.2800799725810066, 0.155563251755666, 0.15951613808283582, 0.1731892887619324, 0.09715284541016445, 0.10167348213144578, 0.17902230232721195, 0.17728784383507445, 0.237327249487862, 0.13948886742582545, 0.2947317191865295, 0.18589907238492742, 0.1531907540629618, 0.29214322683401406, 0.16516747389687225, 0.10064306945423596, 0.19376056850887835, 0.1011198028572835], [0.07676377033931203, 0.0184586654722807, 0.05273894719721284, 0.01720732841931749, 0.02285346363350982, 0.007551747803518083, 0.11562309766304679, 0.02132397890818538, 0.03492134332191199, 0.010433795741846552, 0.036057482357136905, 0.04745322672533803, 0.06465268466854468, 0.050448557012714446, 0.04892499462584965, 0.06213542365003377, 0.04175312067673076, 0.012793738151231082, 0.056313675886485726, 0.042117734119528905, 0.045724850133410655, 0.053058245102874935, 0.03443486551987007, 0.05307738509145565, 0.005435298944576061, 0.11884516148711555, 0.049504860580782406, 0.05653814958350267, 0.05720051638490986, 0.023710586683591828, 0.018061779737763572, 0.02399062126642093, 0.04172746463154908, 0.06454079106333666, 0.11133008505566977, 0.03733674457180314, 0.0073908497233787784, 0.0413878244580701, 0.046027765129110776, 0.045004195053479634, 0.028994776475883555, 0.0476538366638124, 0.020071940525667742, 0.0256614331738092, 0.045773141682730056, 0.09816819991101511, 0.6589092244394124, 5.886257020756602, 15.27149073779583, 33.59159968793392, 41.37111984193325, 59.25310090184212, 69.12302568554878, 74.72262561321259, 70.20629435777664, 61.98430694639683, 52.99976885318756, 46.196955889463425, 47.836085334420204, 43.083117976784706, 26.814454346895218, 16.654363833367825, 14.83828168362379, 13.522997461259365, 18.13273910433054, 20.681733526289463, 50.01674272119999, 17.702947966754436, 15.30048318207264, 34.618532583117485, 41.51785656809807, 38.23284164071083, 38.02428223192692, 37.743724286556244, 29.158041290938854, 30.728820003569126, 17.47952565550804, 13.097096364945173, 6.842497559264302, 7.455484941601753, 6.8537007831037045, 6.238102465867996, 7.970212921500206, 6.957750599831343, 9.438874963670969, 12.173679415136576, 13.749578353017569, 9.213788341730833, 10.71773149073124, 9.40604092553258, 12.279535084962845, 10.112663358449936, 12.825703527778387, 24.165739975869656, 22.415785677731037, 22.970307022333145, 28.339344821870327, 28.90727374702692, 31.173246055841446, 42.09072142839432, 46.71252362430096, 41.40287473797798, 45.47072745859623, 76.49875670671463, 81.15792989730835, 70.70181056857109, 58.74802440404892, 21.14738143980503, 22.00566228479147, 12.123113628476858, 29.415543973445892, 33.908909261226654, 22.717031612992287, 33.235045820474625, 32.66399346292019, 30.853757299482822, 41.06207862496376, 47.20139779150486, 48.4228802472353, 58.35894428193569, 60.207020714879036, 58.90067361295223, 48.99766020476818, 38.75573918223381, 21.32280472666025, 9.450797773897648, 1.5967924729920924, 0.16008891281671822, 0.1104874728480354, 0.04877808649325743, 0.005054887960795895, 0.0855062402843032, 0.059469885236467235, 0.06319843145320192, 0.03803693121881224, 0.061561157199321315, 0.03897027469065506, 0.162603858334478, 0.019416438590269536, 0.032535642822040245, 0.06411407099221833, 0.02876146936614532, 0.0370313322491711, 0.02995395967445802, 0.03766704481677152, 0.047791048637009226, 0.0010008756635215832, 0.06502544318209402, 0.034959022159455344, 0.08058819090365432, 0.04009226096968632, 0.0519767541118199, 0.015764533964102156, 0.06441424746299163, 0.02198338454036275, 0.025679745667730458, 0.04707705804321449, 0.02555622260842938, 0.049992715066764504, 0.048996311306837015, 0.04534938278084155, 0.06492356114904396, 0.038846491879667155, 0.04038400664285291, 0.0484261526435148, 0.026973852691298816, 0.023137424177548382, 0.00956964640863589, 0.03242708517063875, 0.016100207358249463, 0.035155364748789, 0.03419112566916738, 0.061363326603895985, 0.0386911381065147, 0.02504564356058836, 0.04701616111560725, 0.028565661123138852, 0.018642686554812826, 0.04848120144743007, 0.06901775239384733, 0.019541857836884446, 0.03159218387736473, 0.038716449053026736, 0.037780808634124696, 0.058365758741274476, 0.03740892214409541, 0.03208891073882114, 0.039271723944693804, 0.004738352236017818, 0.01551759638459771, 0.011073443547502393, 0.05659957343596034, 0.03113755905360449, 0.05970709789835382, 0.05167041039385367, 0.03929429265554063, 0.05847863940289244, 0.05006084051274229, 0.041062526288442314, 0.0457964154338697, 0.004087937259100727, 0.0400961832201574, 0.015932402202452067, 0.01765033677656902, 0.03584744714316912, 0.02031132211413933, 0.009911200395436026, 0.03487104797386564, 0.04777981623192318, 0.03167957918776665, 0.06996045805863105, 0.03137368075840641, 0.053257764084264636, 0.0617433507431997, 0.017802660731831565, 0.04453686095075682, 0.005424103646873846, 0.03334188608278055, 0.014148634490993572, 0.03042171309061814, 0.08220240662922151, 0.12740039499476552, 1.0423736041411757, 7.101319245994091, 18.902458101511, 38.80435757339001, 46.80416330695152, 68.44480007886887, 78.38344797492027, 80.65772473812103, 78.07943388819695, 73.69971290230751, 69.42869648337364, 60.80944038927555, 57.05088347196579, 53.798242807388306, 34.81544181704521, 24.661588668823242, 25.345645062625408, 24.382109865546227, 23.28760899603367, 18.274612091481686, 42.37292468547821, 27.879620790481567, 20.14381729066372, 35.34243933856487, 40.53904049098492, 30.73166035115719, 26.790553629398346, 24.43940319120884, 22.302435860037804, 26.058919988572598, 15.131447352468967, 10.397473275661469, 6.359753413125873, 5.157691715285182, 4.5349773298949, 3.5297265462577343, 5.781360799446702, 5.721093183383346, 7.438933979719877, 8.694934733211994, 8.318516481667757, 7.425430929288268, 8.077370021492243, 7.284358749166131, 7.937271539121866, 9.554918836802244, 11.048870421946049, 18.435016684234142, 21.526323705911636, 23.76823950558901, 25.0508663803339, 27.919235564768314, 32.44890600442886, 39.11679580807686, 32.715879678726196, 37.89597071707249, 41.37354791164398, 65.35935044288635, 74.07560393214226, 61.605847254395485, 65.15185117721558, 25.949001386761665, 28.714834973216057, 23.13191045075655, 31.958321928977966, 44.07283566892147, 33.2110121101141, 44.05074745416641, 44.20935094356537, 41.1849944293499, 51.479459032416344, 54.858769699931145, 56.71848490834236, 64.06735897064209, 68.01446557044983, 69.23929944634438, 61.65866062045097, 50.62572464346886, 31.84197597205639, 14.572167713195086, 3.71990111656487, 0.3475733462255448, 0.02313804201548919, 0.04573639795125928, 0.037930644539301284, 0.0551272118173074, 0.044760644450434484, 0.08052263699937612, 0.03212613686628174, 0.049319687313982286, 0.059603475529002026, 0.019301335196360014, 0.08920517851947807, 0.061019422792014666, 0.10089620860526338, 0.03212458577763755, 0.018752854666672647, 0.024791439427644946, 0.02096368476486532, 0.08028727228520438, 0.034780943824443966, 0.08095579891232774, 0.0318219861947, 0.03964850489865057, 0.014516850133077241, 0.12962642242200673, 0.02146675884432625, 0.07722170514171012, 0.05022022785851732, 0.04724457561678719, 0.08134459523716941, 0.0274557347438531, 0.025783722412597854, 0.013043954168097116, 0.02543654201872414, 0.03456506419752259, 0.09988254620111547, 0.05107977587613277, 0.03153910547553096, 0.06839247071184218, 0.010524052031541942, 0.011796823237091303, 0.015347050848504296, 0.04731837107101455, 0.059420803299872205, 0.006774541998311179, 0.044361038744682446, 0.044224223820492625, 0.01969144697795855, 0.07638471099198796, 0.1593823585426435, 0.117522943764925, 0.226750799047295, 0.1265995582798496, 0.1455858480767347, 0.062214095014496706, 0.2464751695515588, 0.18890349398134276, 0.13948984706075862, 0.12844296405091882, 0.13866450462955981, 0.17733013140968978, 0.1473342441022396, 0.12113895441871136, 0.1827809982933104, 0.19761427422054112, 0.09060127704287879, 0.22219163744011894, 0.17893379379529506, 0.16071691818069667, 0.13327404856681824, 0.21413034031866118, 0.07962449730257504, 0.1316692284308374, 0.138610505964607, 0.18873605062253773, 0.11947022794629447, 0.15444211894646287, 0.1609521493082866, 0.13250754360342398, 0.09717255685245618, 0.11425848104408942, 0.1873561309184879, 0.21774523775093257, 0.2127289428608492, 0.09882467405986972, 0.08028239637496881, 0.15910724439891055, 0.17449714592657983, 0.17340739112114534, 0.08272297869552858, 0.1696553744841367, 0.17656898475252092, 0.07635403060703538, 0.11651292530586943, 0.5578802456147969, 2.133893771097064, 9.737645331770182, 25.515077970921993, 48.57638821005821, 59.0849295258522, 77.56902247667313, 88.22861328721046, 91.52156218886375, 87.04303130507469, 81.90300911664963, 71.00732177495956, 63.47391061484814, 63.98304149508476, 59.93153169751167, 40.74843965470791, 27.793010137975216, 27.565698735415936, 25.045979842543602, 30.05085278302431, 29.129092544317245, 63.309136256575584, 30.491176955401897, 24.314070716500282, 47.69332319498062, 56.9542470574379, 53.97901810705662, 52.92314596474171, 50.551427230238914, 40.77541060745716, 40.22724062204361, 23.031191155314445, 17.255409881472588, 9.696447942405939, 9.244518242776394, 8.793263956904411, 9.138587526977062, 10.51214162260294, 9.217227157205343, 12.6855100505054, 15.80972995609045, 18.316670134663582, 12.335345540195704, 14.770317580550909, 13.094357661902905, 16.7677079513669, 14.623179025948048, 17.496738731861115, 32.245468720793724, 32.856536731123924, 32.965818867087364, 39.82088662683964, 41.96127377450466, 45.66208139061928, 56.44228532910347, 62.49311864376068, 53.2601460814476, 57.79908612370491, 88.88179823756218, 91.53295397758484, 83.71846050024033, 73.81347879767418, 32.66367428004742, 35.891441479325294, 23.586620651185513, 42.077118158340454, 48.818374425172806, 36.22327007353306, 51.08030945062637, 51.08757846057415, 49.017137959599495, 61.38079673051834, 64.5452669262886, 67.53385975956917, 75.96506014466286, 77.93599158525467, 80.45790866017342, 70.9733060002327, 61.648800149559975, 38.42194229364395, 16.986498311161995, 4.387154811993241, 0.48868868965655565, 0.18314233515411615, 0.06392987736035138, 0.19293500343337655, 0.20666719938162714, 0.19355724973138422, 0.13389816507697105, 0.10529205319471657, 0.17244503338588402, 0.11266634421190247, 0.24170713790226728, 0.16594861401244998, 0.11974775406997651, 0.24792158568743616, 0.09942222910467535, 0.07069371480611153, 0.16191213217098266, 0.16243052232312039, 0.14674860052764416, 0.16079484368674457, 0.13809293217491359, 0.18493577954359353, 0.22289384272880852, 0.21639659214997664, 0.28786887181922793, 0.21419226512080058, 0.20643320021918043, 0.1365913447807543, 0.06655644931015559, 0.13580218947026879, 0.10255049288389273, 0.10398855985840783, 0.15531424636719748, 0.11150616701343097, 0.18833532056305557, 0.1575595696340315, 0.12688157439697534, 0.171629739634227, 0.14956200815504417, 0.10108490707352757, 0.0871080621436704, 0.08470273183775134, 0.17802570189815015, 0.16097794636152685, 0.1331685745390132, 0.169886716757901, 0.12193241418572143, 0.07630504143889993, 0.12949673953698948], [0.03145415925246198, 0.020932750194333494, 0.002710299427235441, 0.02055841832770966, 0.010784539372252766, 0.08777652197750285, 0.056727467745076865, 0.0017813032013691554, 0.023954970347404014, 0.01278496318263933, 0.039700321649434045, 0.07749690092168748, 0.017157415277324617, 0.06887946801725775, 0.021244630333967507, 0.05332715860276949, 0.029730857095273677, 0.04687416600063443, 0.03876010960084386, 0.055225004616659135, 0.029998447716934606, 0.09454758052015677, 0.021642427054757718, 0.005773416323791025, 0.07606645580381155, 0.03624988785304595, 0.03585815262340475, 0.05119111287058331, 0.06572089492692612, 0.14385936025064439, 0.0503227036097087, 0.034366736363153905, 0.12316413442022167, 0.10923101683147252, 0.044988231456954964, 0.08484957317705266, 0.01296409258429776, 0.011703910986398114, 0.03315947360533755, 0.0908836122835055, 0.023976128977665212, 0.05023462181270588, 0.049951759647228755, 0.04009130730992183, 0.06532431347295642, 1.9991359021514654, 9.446819387376308, 23.19151785224676, 44.15628679096699, 60.927249267697334, 67.64799043536186, 74.42211493849754, 72.25537240505219, 64.97671097517014, 51.98301561176777, 47.112349569797516, 34.77196455001831, 33.97638984024525, 32.70314276218414, 22.899528220295906, 17.815545424818993, 17.588855288922787, 29.138466641306877, 20.63424937427044, 35.48581704497337, 39.95058886706829, 60.353449657559395, 23.719429224729538, 45.89863009750843, 34.974368289113045, 27.503659464418888, 22.6645203307271, 21.190284937620163, 18.844406716525555, 5.923298383131623, 3.5862746369093657, 2.3322797007858753, 1.170531464740634, 0.670112210791558, 0.6527899496722966, 0.5865890707354993, 0.5336204473860562, 0.6352430849801749, 1.0267619043588638, 0.8794900600332767, 1.1025210516527295, 1.3307615043595433, 2.132168901152909, 1.6291892970912158, 2.470295182429254, 2.4821263225749135, 2.208757591433823, 4.594871141016483, 6.867433246225119, 8.160995934158564, 11.19399318471551, 11.686058230698109, 13.352463562041521, 13.623885847628117, 17.563189566135406, 27.074734680354595, 34.50964942574501, 33.96137684583664, 28.83534550666809, 26.684691309928894, 38.70528928935528, 22.50032164156437, 35.3061056882143, 37.73042120039463, 19.560643583536148, 31.5506437048316, 8.343309201300144, 13.518925029784441, 16.122242286801338, 20.324799679219723, 30.27211681008339, 31.099093034863472, 33.54243032634258, 39.63910058140755, 44.45112816989422, 55.908090993762016, 54.146190136671066, 60.97479231655598, 60.272825583815575, 53.70799005031586, 34.87501502037048, 24.366023428738117, 8.39728245511651, 1.0134262824431062, 0.16045732976635918, 0.044954838522244245, 0.017207938835781533, 0.0710305014217738, 0.02948619698145194, 0.10997832243447192, 0.0765296895406209, 0.029422465049719904, 0.027334798069205135, 0.015525057751801796, 0.03166075090121012, 0.020010214248031843, 0.02161838703614194, 0.04995305840566289, 0.07699114954448305, 0.0237221456336556, 0.009361647462355904, 0.05071353341918439, 0.04102181577763986, 0.048768022970762104, 0.04623124346835539, 0.04172396169451531, 0.012561682488012593, 0.053670568886445835, 0.004904963461740408, 0.060040366734028794, 0.04844005678023677, 0.11252054187934846, 0.041684742900542915, 0.055196305766003206, 0.010279172984155593, 0.09619506672606803, 0.031757267206558026, 0.04322766049881466, 0.024790613788354676, 0.08270600577816367, 0.03870836706482805, 0.018887797523348127, 0.018816792544384953, 0.04756769187224563, 0.015152045052673202, 0.02646878594532609, 0.07003442049608566, 0.061911053853691556, 0.04175075693638064, 0.05215660989051685, 0.06867292831884697, 0.05699535337043926, 0.05055891437223181, 0.011445976633694954, 0.027707185508916155, 0.055371849666698836, 0.057400521473027766, 0.13501235138392076, 0.010123457414010772, 0.042556844346108846, 0.03948044184653554, 0.0669736773124896, 0.0419703806983307, 0.023867252202762756, 0.02496469194738893, 0.05562269187066704, 0.0029272649089762126, 0.1064906884857919, 0.011482839108793996, 0.031160832804744132, 0.06776698864996433, 0.015845183152123354, 0.058868441337835975, 0.07206941168988124, 0.04718277326901443, 0.06257821863982826, 0.03766179783269763, 0.022929988335818052, 0.034353010341874324, 0.06278384549659677, 0.08516094865626656, 0.021999936288921162, 0.04297217987186741, 0.04261297297489364, 0.02877912877011113, 0.10154808885999955, 0.02715146718401229, 0.05961541668511927, 0.04274263730621897, 0.035602163625299, 0.02243165101390332, 0.016001173316908535, 0.047841792984399945, 0.05080401235318277, 0.050701080181170255, 0.03993059894128237, 2.5504794297739863, 10.937686488032341, 27.583020105957985, 49.847636595368385, 69.44833382964134, 77.18790292739868, 83.34728121757507, 81.70399099588394, 76.30197286605835, 62.33222387731075, 54.7368798404932, 40.95752343535423, 42.99459032714367, 44.58877578377724, 35.2220693975687, 29.353736490011215, 24.173523858189583, 26.160617731511593, 19.593699909746647, 32.947443053126335, 34.37773570418358, 65.84627151489258, 28.141709826886654, 34.083886072039604, 30.65457008779049, 25.630869157612324, 20.120328851044178, 18.50062396377325, 13.298575803637505, 7.127745877951384, 4.031950822100043, 2.5536779081448913, 1.1816258006729186, 0.632188405143097, 0.5181423341855407, 0.3888991568237543, 0.596938052913174, 0.39429801399819553, 0.9566288895439357, 0.7788799493573606, 0.7429801288526505, 1.149348788894713, 0.8961724711116403, 1.0833810037001967, 1.3003304810263216, 1.675434596836567, 1.3360213721171021, 2.982237911783159, 4.662677077576518, 6.473521683365107, 8.642807230353355, 9.661258030682802, 9.236751459538937, 12.916803639382124, 17.44586706161499, 21.22207783162594, 25.513715744018555, 27.19128392636776, 32.41367429494858, 33.541411980986595, 41.13435834646225, 31.409019604325294, 40.797863602638245, 45.52178151905537, 23.889234513044357, 43.14964860677719, 17.629433311522007, 22.778597809374332, 28.41590691357851, 29.46782346814871, 37.10651367902756, 40.17027407884598, 45.07226563990116, 48.06497745215893, 55.252808555960655, 63.66274148225784, 61.10700622200966, 68.39105576276779, 69.73647996783257, 61.68858401477337, 45.90848296880722, 31.928995102643967, 12.456478290259838, 2.576627489179373, 0.24529070185963064, 0.03192231713910587, 0.030376618342415895, 0.046405685279751197, 0.00911641125640017, 0.060367646437953226, 0.07650257888599299, 0.0634237623307854, 0.0447600655752467, 0.0323124307760736, 0.016784257859399077, 0.017650765366852283, 0.040234953703475185, 0.05127625947352499, 0.05604217600193806, 0.04348802445747424, 0.014330597969092196, 0.031104585432331078, 0.039515033349744044, 0.029812834727636073, 0.02213005889643682, 0.004526643479039194, 0.03429637334193103, 0.052768425302929245, 0.02268538017233368, 0.05760431151429657, 0.07469678515917622, 0.029490716660802718, 0.02170872310671257, 0.03172129159793258, 0.02912444822868565, 0.086097783932928, 0.01895788223919226, 0.03300758937257342, 0.045244450520840473, 0.06306834780843928, 0.010051158315036446, 0.006259458114072913, 0.013624219955090666, 0.009978625439543976, 0.041470169453532435, 0.07877185867982917, 0.07607956213178113, 0.03348941019794438, 0.07526789748226292, 0.05569475069933105, 0.03319939372886438, 0.14434338896535337, 0.12741825106786564, 0.11389459861675277, 0.10513733024708927, 0.2571408112999052, 0.24133550003170967, 0.1504322950495407, 0.07110225225915201, 0.12992087693419307, 0.10285544136422686, 0.15064244158565998, 0.172197378706187, 0.0841587598551996, 0.14138107682811096, 0.13548465416533872, 0.3015880356542766, 0.24667516350746155, 0.11756073392461985, 0.16073480393970385, 0.17059767938917503, 0.08670669383718632, 0.2487221107003279, 0.1720105652930215, 0.1318898392491974, 0.2756858349312097, 0.14507677929941565, 0.13804472226183861, 0.17095756164053455, 0.09091767686186358, 0.21300488820997998, 0.19147116167005152, 0.1759366155602038, 0.20694537117378786, 0.17404188285581768, 0.2534552465658635, 0.1475598569959402, 0.2077957833535038, 0.16475353360874578, 0.15317227458581328, 0.1492647928535007, 0.11059528464102186, 0.15428604529006407, 0.11014316827640869, 0.14951008750358596, 0.24438694410491735, 3.907285686582327, 14.995981771498919, 35.360758155584335, 59.288815185427666, 77.70352005958557, 85.32214164733887, 92.87342324852943, 89.40950632095337, 86.11438393592834, 67.45741546154022, 62.54798389971256, 48.833208829164505, 47.307974472641945, 48.81773605942726, 36.880486607551575, 29.04696375131607, 31.234069392085075, 40.877579525113106, 35.91105982661247, 48.80127154290676, 56.91414400935173, 72.0483747124672, 37.111715599894524, 62.60627657175064, 47.36112602055073, 39.12852957844734, 30.806706324219704, 28.849070370197296, 22.761151045560837, 9.073858950287104, 4.948370447382331, 3.286882289685309, 1.8568393564783037, 1.402738548349589, 1.2844682321883738, 1.1369494604878128, 1.283543931785971, 1.2438808288425207, 1.5397208416834474, 1.4434528886340559, 1.6968551161698997, 2.2371955029666424, 3.0084303813055158, 2.6040917029604316, 3.2082825573161244, 3.2253861520439386, 2.961259474977851, 5.96810937859118, 8.197491075843573, 11.113613247871399, 14.838347230106592, 16.593589894473553, 17.786706872284412, 17.92455017566681, 23.756619729101658, 34.252448827028275, 42.63386428356171, 41.69934242963791, 34.555041790008545, 34.414924308657646, 49.77070212364197, 36.25768102705479, 56.163809671998024, 53.249309062957764, 32.575047835707664, 47.406408190727234, 15.387194529175758, 24.685599580407143, 28.08053880929947, 34.113463684916496, 43.64724710583687, 45.9896732121706, 50.752284452319145, 56.52118809521198, 63.72311644256115, 76.85472160577774, 71.15337833762169, 77.8821636736393, 79.07700195908546, 74.16754379868507, 53.47508914768696, 38.76196704804897, 15.483475662767887, 3.3688080310821533, 0.48015506006777287, 0.18946098047308624, 0.14103925845120102, 0.21061444538645446, 0.06628171366173774, 0.11765266375732608, 0.2084961926448159, 0.17041313694790006, 0.1564375017187558, 0.17092579771997407, 0.11170771947945468, 0.09587834036210552, 0.12123697728384286, 0.22462236403953284, 0.15942503203405067, 0.2568237658124417, 0.06547456127009355, 0.1659960372489877, 0.10252773121464998, 0.11790596618084237, 0.1489322364795953, 0.1977925084065646, 0.12712719559203833, 0.15367450076155365, 0.10973559561534785, 0.15074938506586477, 0.1602716592606157, 0.1713600431685336, 0.10400034516351297, 0.08523089607479051, 0.04699475386587437, 0.2228046811069362, 0.16713704477297142, 0.13686691905604675, 0.16934775427216664, 0.1625170122133568, 0.14196692820405588, 0.12096484657377005, 0.09563548737787642, 0.1437584578525275, 0.15465425443835557, 0.18249317858135328, 0.27620302280411124, 0.2031511114910245, 0.11664772900985554, 0.21264959243126214, 0.2577258017845452], [0.07546472988906316, 0.0703995645744726, 0.030089162282820325, 0.0538386690459447, 0.05103546965983696, 0.0411429342784686, 0.05195334677409846, 0.058233764066244476, 0.011410934275772888, 0.061793082059011795, 0.007084544504323276, 0.039362956158583984, 0.02336738234589575, 0.022578674179385416, 0.08978789061075076, 0.06868504016892985, 0.04264945695467759, 0.01604567249160027, 0.06147283049358521, 0.029054968363197986, 0.008917955401557265, 0.041012104775290936, 0.04659149308281485, 0.03646231649327092, 0.05299551507050637, 0.03562943384167738, 0.02488774978701258, 0.039402330803568475, 0.02907938131102128, 0.029937669532955624, 0.042236715235048905, 0.029993428943271283, 0.03722476933035068, 0.052886486155330203, 0.02777862835500855, 0.06767707745893858, 0.04806651530088857, 0.04276769592252094, 0.010137274348380743, 0.09209041862050071, 0.05186700902413577, 0.009513863806205336, 0.060427111020544544, 0.2186629775678739, 2.359682167880237, 10.456401463598013, 27.492292374372482, 50.81739395856857, 60.01389987766743, 70.04115521907806, 72.5197622179985, 70.26294931769371, 63.63722965121269, 62.66658693552017, 48.54302600026131, 44.922135695815086, 45.451610684394836, 23.30990619957447, 18.787529468536377, 17.625055946409702, 19.480918161571026, 19.484913647174835, 28.645312003791332, 38.31300213932991, 30.71417558938265, 26.744897179305553, 21.80313315242529, 30.023064874112606, 24.97627068310976, 24.873716086149216, 11.160513181239367, 9.329793266952038, 2.906689178198576, 1.1501453211531043, 0.6907249172218144, 0.6429351784754544, 0.3857722511747852, 0.0403341454511974, 0.11167571807163768, 0.06740905824699439, 0.023824920099286828, 0.04660032835090533, 0.11071886707213707, 0.04971679569280241, 0.17030448652803898, 0.1450599473901093, 0.0647151141311042, 0.06202730757649988, 0.028374674984661397, 0.02308671137143392, 0.14200836973031983, 0.03135717910481617, 0.5672741134185344, 0.6239518721122295, 1.58312211278826, 1.6178711294196546, 2.5448531191796064, 3.0117333540692925, 4.420845229178667, 4.925314709544182, 3.719071098603308, 9.038289058953524, 8.708585500717163, 13.359079007059336, 15.824736300855875, 19.224735908210278, 34.26119975745678, 32.32754051685333, 26.85394562780857, 43.02442632615566, 18.772961050271988, 31.65377777069807, 30.012968815863132, 20.821113847196102, 22.80257072299719, 18.70415434241295, 18.479569293558598, 23.50862793624401, 27.685080729424953, 31.63268130272627, 39.61973302066326, 43.75507012009621, 51.91235080361366, 56.23820587992668, 59.647652730345726, 60.35162575542927, 49.0490448474884, 29.78435978293419, 18.06257776916027, 6.6988904401659966, 1.3241970003582537, 0.0799988662765827, 0.039619394156034105, 0.08269214988104068, 0.042192327382508665, 0.058439743443159387, 0.05792665222543292, 0.07980510636116378, 0.02532843893277459, 0.09278599653043784, 0.022057857204345055, 0.0254730018787086, 0.09566182619892061, 0.03360813898325432, 0.022026497754268348, 0.02904840963310562, 0.022233447489270475, 0.047257848927984014, 0.06573171544005163, 0.050374101047054864, 0.009390180257469183, 0.021037994156358764, 0.018401542365609203, 0.04180079995421693, 0.041473234523436986, 0.015867950387473684, 0.015716149646323174, 0.04473804605368059, 0.047049346248968504, 0.012240118248882936, 0.06934497272595763, 0.06576596555532888, 0.027787495164375287, 0.058482569074840285, 0.07982456547324546, 0.05755125166615471, 0.01551629484310979, 0.05461046923301183, 0.014845471268927213, 0.07679443588131107, 0.03588160820072517, 0.0034176264625784825, 0.05481711654283572, 0.02336779794859467, 0.05717612570151687, 0.042960825012414716, 0.02496429118764354, 0.0779488762782421, 0.024827791676216293, 0.05649891223583836, 0.03515860422339756, 0.0339193177933339, 0.028664197925536428, 0.019809758305200376, 0.04346309200627729, 0.05739187174185645, 0.05382391143939458, 0.03575497925339732, 0.014862771658954443, 0.004194210023342748, 0.025873500017041806, 0.05877340561710298, 0.031226665014401078, 0.01728068971715402, 0.029487364008673467, 0.02380463349254569, 0.031070337172423024, 0.07658961796551012, 0.06622662403970025, 0.008135596308420645, 0.023317296654568054, 0.0260733307004557, 0.021716335686505772, 0.043661178642651066, 0.0372378459724132, 0.021274037935654633, 0.01131645702116657, 0.04533344887022395, 0.011100106130470522, 0.0072790897047525505, 0.039052181818988174, 0.020013626271975227, 0.07922554097604007, 0.06960801954846829, 0.032048782813944854, 0.08926807553507388, 0.07180222368333489, 0.03383538089110516, 0.04317804421589244, 0.17951437592273578, 2.3771517304703593, 12.55203366279602, 32.42239862680435, 60.16528755426407, 70.00630348920822, 80.13232693076134, 80.16776382923126, 82.01698020100594, 72.91345149278641, 69.79829505085945, 54.091598466038704, 56.65982365608215, 52.750525027513504, 34.41954106092453, 28.985046073794365, 27.437265627086163, 28.13645090907812, 20.10336086153984, 37.74684011936188, 48.33316706120968, 42.52638705074787, 35.41945360600948, 29.24436315894127, 25.353164859116077, 22.692437432706356, 13.65086629986763, 9.017552621662617, 7.201717458665371, 3.745217020623386, 1.3608043547719717, 0.443185418844223, 0.416495829122141, 0.36944817868061364, 0.04873666723142378, 0.016489688314322848, 0.05265465035336092, 0.0890723340853583, 0.027075931393483188, 0.08197875300538726, 0.09818619699217379, 0.0967219247831963, 0.1789875846588984, 0.11058824165957049, 0.062386173085542396, 0.08001955735380761, 0.012042199523421004, 0.03518436416925397, 0.07927721671876498, 0.18584410892799497, 0.5583862715866417, 1.130783697590232, 1.1931934487074614, 1.425155564211309, 2.2195836855098605, 2.7956111636012793, 3.786100926809013, 3.9942231215536594, 7.211508108302951, 9.190589636564255, 13.487183433026075, 12.156066410243511, 19.38146609812975, 25.353601835668087, 34.146366119384766, 29.47837360203266, 35.69583937525749, 24.956648536026478, 27.669210880994797, 31.856035217642784, 22.483955919742584, 31.521071791648865, 29.607790857553482, 29.66410953551531, 33.02437372505665, 37.84543342888355, 41.34259857237339, 50.26912897825241, 55.37330009043217, 61.16499111056328, 64.49843063950539, 68.24711188673973, 66.97063878178596, 62.14873932301998, 39.00573156774044, 22.90550719946623, 9.070383086800575, 2.4044696521013975, 0.1248290907824412, 0.03156020102323964, 0.1533329050289467, 0.03369911515619606, 0.1040082861436531, 0.029491824316210113, 0.0353467386594275, 0.05419881104899105, 0.11254136654315516, 0.022843348160677124, 0.05676628577930387, 0.06990618479903787, 0.04928981215925887, 0.012436222423275467, 0.057954846415668726, 0.03863240453938488, 0.10448750574141741, 0.02383421735430602, 0.05533825264137704, 0.028719573274429422, 0.06335195212159306, 0.0438447117630858, 0.0038660466998408083, 0.035294780900585465, 0.029817577051289845, 0.017410812324669678, 0.10308060896932147, 0.03781899213208817, 0.06027771298249718, 0.04257995853549801, 0.0958405873097945, 0.016226164661929943, 0.038972334150457755, 0.04256934211298358, 0.07733120903139934, 0.04961880993505474, 0.05139144450367894, 0.02768164635199355, 0.026822942527360283, 0.07387967314571142, 0.014860812389088096, 0.018828939646482468, 0.0652033879305236, 0.029520365460484754, 0.025384651053173002, 0.18340869195526466, 0.20546487561659887, 0.1021190156461671, 0.17186624725582078, 0.13530339201679453, 0.15873240045038983, 0.1446606422541663, 0.12757034681271762, 0.2081478136824444, 0.15717394970124587, 0.1366300997324288, 0.1565875342930667, 0.12191896646982059, 0.08534433334716596, 0.18235641560750082, 0.10786366168758832, 0.19664584571728483, 0.18546475272160023, 0.12456571741495281, 0.08142716658767313, 0.10766554536530748, 0.12209400199935772, 0.15049650566652417, 0.15538553707301617, 0.1288415418821387, 0.15230071119731292, 0.08295363819343038, 0.13127571204677224, 0.09376396163133904, 0.24979147128760815, 0.09086174119147472, 0.1874423387926072, 0.11766870899009518, 0.12615285959327593, 0.08707276560016908, 0.19946830754633993, 0.1920725090894848, 0.1783531077671796, 0.15813362086191773, 0.16520667413715273, 0.1743278026697226, 0.26734323415439576, 0.1679148749099113, 0.3918007167521864, 4.235519198700786, 17.05702632665634, 40.80014728009701, 68.40988755226135, 78.93275409936905, 88.68871539831161, 90.04327431321144, 87.92837619781494, 80.46357795596123, 81.1023236811161, 61.75458267331123, 61.069563031196594, 59.92549382150173, 38.28296855092049, 29.33204535394907, 28.69616847485304, 31.860425882041454, 29.432249777019024, 39.70519803464413, 52.891330271959305, 47.34877668321133, 38.711247369647026, 32.05798298120499, 42.09757246077061, 33.4518925845623, 31.021590493619442, 14.454397782683372, 11.325557325035334, 4.860021388158202, 2.1995547227561474, 1.0149002471007407, 1.1208319128490984, 0.8751856035087258, 0.2925611747195944, 0.20620825525838882, 0.20803905936190858, 0.1468645833665505, 0.22055521665606648, 0.23699406970990822, 0.327281781937927, 0.5186988855712116, 0.6112394167575985, 0.35850360814947635, 0.2604383515426889, 0.35178942780476063, 0.20032505766721442, 0.27362569235265255, 0.2847986068809405, 0.7550163986161351, 1.0680373082868755, 2.5153246661648154, 2.4343293998390436, 3.673707232810557, 4.462813502177596, 6.5031648427248, 6.897938959300518, 5.789363645017147, 10.81140311434865, 10.564563609659672, 17.048833966255188, 21.470928378403187, 25.40910355746746, 41.6233579069376, 42.377336248755455, 38.08384783565998, 57.37127847969532, 31.68890878558159, 44.26800459623337, 40.60646407306194, 30.919934548437595, 36.43635503947735, 31.12301465123892, 30.49598939716816, 36.75146073102951, 42.18239150941372, 47.179328575730324, 54.94361154735088, 63.43767575919628, 71.33928716182709, 73.8507091999054, 76.87404736876488, 78.5066145658493, 76.81059077382088, 49.93812873959541, 29.308503717184067, 11.682615615427494, 2.819670047610998, 0.3707776026567444, 0.11996327375527471, 0.4273563588503748, 0.1828245772048831, 0.25600894703529775, 0.20331902982434258, 0.12578665424371138, 0.1517879168386571, 0.17461082810768858, 0.08643804379971698, 0.11554095675819553, 0.1268976493156515, 0.24892204528441653, 0.09253595213522203, 0.12277726025786251, 0.12638135201996192, 0.1706343563273549, 0.12678585218964145, 0.3710512473480776, 0.12052369915181771, 0.10430363865452819, 0.1236293867987115, 0.1989971922012046, 0.16267802857328206, 0.12199447999591939, 0.08020447829039767, 0.1674773046397604, 0.17738732130965218, 0.19102928694337606, 0.07869305743952282, 0.2577429008670151, 0.09850015514530241, 0.2417818721733056, 0.15432413230882958, 0.17394559661624953, 0.15086615458130836, 0.16503491147886962, 0.06679732076008804, 0.16197604592889547, 0.07370845225523226, 0.1424448861507699, 0.09865829939371906, 0.09461742403800599, 0.14472687151283026, 0.11075667949626222], [0.007870943663874641, 0.018315373454242945, 0.06053883393178694, 0.03043970646103844, 0.07913362598628737, 0.03264994840719737, 0.005843738990733982, 0.012213810041430406, 0.05367724079405889, 0.02887433147407137, 0.07897336661699228, 0.029468177635862958, 0.018286079030076507, 0.00975504788584658, 0.03179438201186713, 0.030477051332127303, 0.03687647942570038, 0.050141040701419115, 0.04114428869797848, 0.02150988504581619, 0.05028874293202534, 0.023982272105058655, 0.0767412461573258, 0.031731010021758266, 0.02028652510489337, 0.017900999009725638, 0.06313499266980216, 0.06070298586564604, 0.04927779307763558, 0.015417206068377709, 0.0688243264448829, 0.03815731128270272, 0.06117012700997293, 0.02362958312005503, 0.042325446411268786, 0.05723887799831573, 0.05109224766783882, 0.019106373001704924, 0.016194231902773026, 0.05635236404486932, 0.013751191218034364, 0.010634585651132511, 0.176067634311039, 2.6748795295134187, 11.200232449918985, 27.422421723604202, 49.49056215584278, 67.99723729491234, 71.1527855694294, 62.5559900701046, 64.53066051006317, 59.391649067401886, 51.139555871486664, 46.310809180140495, 35.73016673326492, 24.462870731949806, 19.471409171819687, 15.134050212800503, 15.222377423197031, 28.345601186156273, 35.008737444877625, 27.073258459568024, 28.099845573306084, 25.702449716627598, 31.65195006877184, 25.704590901732445, 21.670554466545582, 13.504396509379148, 9.640192911028862, 5.1663334015756845, 3.0978132225573063, 0.41313769994303584, 0.383364605368115, 0.22922112664673477, 0.15907705383142456, 0.04832487175008282, 0.07060783347696997, 0.039004476566333324, 0.01663263152295258, 0.17704924335703254, 0.04063424770720303, 0.013949145195510937, 0.054505692824022844, 0.08726605796255171, 0.044650569107034244, 0.023983969767868984, 0.04772481566760689, 0.06677551646134816, 0.07686309938435443, 0.1642875836114399, 0.04631526942830533, 0.02778333357127849, 0.006251385402720189, 0.10143793188035488, 0.070692460576538, 0.042029600372188725, 0.07587559768580832, 0.01820328317990061, 0.20212886243825778, 0.5546932853758335, 0.650052671553567, 0.6094678211957216, 0.6701090047135949, 2.53274483140558, 4.953853553161025, 6.8911221250891685, 14.698449186980724, 21.104175858199596, 32.02759601175785, 27.870586775243282, 39.19863201677799, 45.470225885510445, 34.65434946119785, 34.56918083131313, 23.764215521514416, 20.707536041736603, 21.522592306137085, 19.88573893904686, 21.586058400571346, 22.443609684705734, 22.750808000564575, 33.09580609202385, 41.831696927547455, 45.66627636551857, 44.37957800924778, 56.77047751843929, 47.54559092223644, 51.48187190294266, 44.82408955693245, 33.95078681409359, 12.229630462825298, 3.697160999290645, 0.3017255407758057, 0.05533522096811794, 0.03253375776694156, 0.038431056163972244, 0.043261268656351604, 0.05501089872268494, 0.023770656116539612, 0.05380740978580434, 0.03577640134608373, 0.05295149458106607, 0.042836151624214835, 0.05565173581999261, 0.0351188251079293, 0.033934101375052705, 0.08440495250397362, 0.008682128700456815, 0.035651560974656604, 0.02851443252438912, 0.029131374321877956, 0.041722841051523574, 0.023464592559321318, 0.0347147182765184, 0.02551003319240408, 0.0591036761761643, 0.04530581500148401, 0.04412316186062526, 0.03138887994282413, 0.054937296226853505, 0.02896418700402137, 0.02484110023942776, 0.008469486692774808, 0.05673441795806866, 0.03380148329597432, 0.024675512249814346, 0.03805448672210332, 0.04551001693471335, 0.022353732929332182, 0.011180242308910238, 0.06998861514148302, 0.09150507190497592, 0.039811050082789734, 0.009315493298345245, 0.03849872147839051, 0.04144173035456333, 0.03993710386566818, 0.04204109623969998, 0.042552896120469086, 0.030220099397411104, 0.04325046298617963, 0.007688113728363533, 0.002458311764712562, 0.03352485517098103, 0.04475651068787556, 0.07882564954343252, 0.04269220466085244, 0.05831171554746106, 0.03524287880281918, 0.044713903989759274, 0.021361099279602058, 0.06020884538884275, 0.017219471810676623, 0.04566658411931712, 0.02249765020678751, 0.04354122531367466, 0.050462568760849535, 0.026234848010062706, 0.013846577603544574, 0.06803767217206769, 0.05324099896824919, 0.04195940804493148, 0.01709463329461869, 0.07308688131161034, 0.024574016133556142, 0.005147103520357632, 0.06849170327768661, 0.035281043747090735, 0.03693956939969212, 0.02533729832066456, 0.057761617135838605, 0.032868863418116234, 0.07123483694158494, 0.006170116521388991, 0.03139705098874401, 0.040744820289546624, 0.012344736951490631, 0.05578710355621297, 0.23649941344046965, 3.0955062713474035, 13.020406030118465, 32.693103700876236, 59.10450227558613, 76.88144937157631, 80.68260580301285, 73.03211912512779, 75.95726296305656, 70.6956472992897, 61.53509505093098, 60.40883928537369, 47.65063248574734, 35.84944613277912, 31.53089426457882, 20.76702754944563, 20.571689531207085, 30.493278242647648, 24.62925810366869, 27.728901877999306, 31.61079067736864, 26.671179234981537, 28.78038715571165, 19.314861372113228, 16.29562508314848, 11.722168643027544, 7.4011896550655365, 4.629769893363118, 2.1736854733899236, 0.25442312587983906, 0.22831466747447848, 0.3494515735656023, 0.1506880539818667, 0.05453022080473602, 0.07460561973857693, 0.08555089531000704, 0.04728113752207719, 0.07102670162566938, 0.10841422394150868, 0.09326126048108563, 0.042954958335030824, 0.01578693940246012, 0.16586568643106148, 0.12013865809421986, 0.1689663645811379, 0.29861223127227277, 0.187193704477977, 0.23004882910754532, 0.200376013526693, 0.0924627466883976, 0.16690950229531154, 0.07057292285026051, 0.09937947397702374, 0.1348795514786616, 0.1035121307359077, 0.113376972876722, 0.13935059047071263, 0.3539876395370811, 0.5106693820562214, 0.7267356442753226, 0.8676945429760963, 1.8306503305211663, 4.0189531445503235, 6.550892181694508, 12.201617415994406, 18.333803415298462, 23.445562720298767, 27.913750559091568, 33.92700009047985, 39.57152880728245, 35.39901830255985, 36.796818897128105, 36.30224123597145, 27.728293910622597, 31.40052706003189, 32.51427389681339, 37.3310512304306, 36.32189758121967, 37.421057000756264, 46.18181370198727, 52.84436099231243, 59.55328479409218, 54.383559599518776, 66.51342451572418, 55.89345797896385, 61.713655069470406, 55.29869109392166, 43.092951849102974, 16.251482851803303, 4.701290605589747, 0.5383448407519609, 0.06121062229794916, 0.042009621756733395, 0.04760116644320078, 0.008857428620103747, 0.08407655215705745, 0.025699724283185787, 0.03767561291169841, 0.01972472673514858, 0.05399053101427853, 0.061616424936801195, 0.024820314538374078, 0.06205478188348934, 0.07081833624397404, 0.01823451089876471, 0.05127773263666313, 0.0218351999137667, 0.03697264692164026, 0.05618244562356267, 0.03989202210505027, 0.0267640902166022, 0.02349669415707467, 0.0255529868445592, 0.00450151806944632, 0.07839791272999719, 0.07098104470060207, 0.05370815866626799, 0.009826564019022044, 0.0412453395256307, 0.03432149504078552, 0.061263730385689996, 0.05131190853717271, 0.08773153298534453, 0.03475214107311331, 0.030265910318121314, 0.035423721637926064, 0.05203889413678553, 0.06660131213720888, 0.03312580978672486, 0.060113698345958255, 0.059198941962677054, 0.015305010037991451, 0.05024716410844121, 0.023139917793741915, 0.12437894110917114, 0.10905722068855539, 0.10821337651577778, 0.10329029537388124, 0.13503344322089106, 0.11327404441544786, 0.09976514586014673, 0.1662851037690416, 0.23404069303069264, 0.25466604565735906, 0.1839669799664989, 0.13992440421134233, 0.1285494919284247, 0.1292417524382472, 0.08677604011609219, 0.12406856010784395, 0.11918409290956333, 0.18327685684198514, 0.1574827276635915, 0.19201331539079547, 0.16134734294610098, 0.07086213037837297, 0.14379399188328534, 0.2691193122882396, 0.10781430886709131, 0.1581794855883345, 0.13982213626150042, 0.10812769556650892, 0.11238617604249157, 0.13841417821822688, 0.15518557280302048, 0.08162052574334666, 0.1642872125376016, 0.25396896118763834, 0.12141321509261616, 0.117600008379668, 0.13376263406826183, 0.19763257558224723, 0.16706180584151298, 0.09040191391250119, 0.11194934049854055, 0.14283089200034738, 0.6593799835536629, 4.728784980252385, 16.98237743228674, 40.450208857655525, 69.35364291071892, 88.14510896801949, 92.61569827795029, 78.67255166172981, 80.29661491513252, 74.69908207654953, 67.03530371189117, 63.8434673845768, 49.416063353419304, 36.15447476506233, 32.349263951182365, 26.366902962327003, 25.160355605185032, 39.14431393146515, 49.621354937553406, 42.414551451802254, 38.64156670868397, 37.574382573366165, 43.345706686377525, 36.57841041684151, 29.7823553904891, 19.056910313665867, 13.79459548741579, 7.509149461984634, 4.325339728966355, 0.6449477642308921, 0.6897202867548913, 0.6002141302451491, 0.3718609601492062, 0.2743400540202856, 0.14170379232382402, 0.22163796558743343, 0.27739422919694334, 0.3263114090077579, 0.1620378965162672, 0.21742525335866958, 0.3899175318656489, 0.3249379014596343, 0.3237044223351404, 0.36404148442670703, 0.44312539394013584, 0.4364225536119193, 0.5317653156816959, 0.3857151058036834, 0.255355560220778, 0.17089550325181335, 0.16490649024490267, 0.12575126864248887, 0.1993180820136331, 0.3389168466674164, 0.2685794443823397, 0.22617618378717452, 0.39492794894613326, 0.8285173389595002, 1.0712659475393593, 1.0834985598921776, 1.232582728844136, 3.397602173499763, 5.8000752702355385, 8.908130843192339, 17.385070323944092, 27.19677273184061, 42.426574006676674, 37.71938279271126, 52.472296357154846, 58.5329407453537, 48.51599045097828, 51.30104720592499, 38.516811802983284, 32.16264456510544, 32.62980669736862, 31.873609274625778, 34.198708310723305, 34.18803468346596, 37.72444412112236, 49.983509704470634, 57.93543040752411, 64.44876730442047, 63.32210496068001, 75.86650863289833, 65.68982630968094, 76.80369794368744, 68.00967022776604, 55.27974151074886, 22.19847723841667, 5.77656545676291, 0.8884997328277677, 0.16887233447050676, 0.1954238401958719, 0.07811696530552581, 0.13810038333758712, 0.2044745982857421, 0.11593922288739122, 0.11900057463208213, 0.12052671969286166, 0.2194094890728593, 0.1528122735908255, 0.1087876058591064, 0.20634445420000702, 0.1478637516265735, 0.15260312153259292, 0.21688105131033808, 0.09269607791793533, 0.11673594068270177, 0.13323918246896937, 0.13288952701259404, 0.1769106843858026, 0.11988077661953866, 0.09449348537600599, 0.18011662876233459, 0.14249336323700845, 0.1433279231423512, 0.14996199606684968, 0.13370793778449297, 0.06400628888513893, 0.08789438245003112, 0.12381712047499605, 0.10007097749621607, 0.16387045208830386, 0.1311672545853071, 0.1470096583943814, 0.09356744834803976, 0.14089776057517156, 0.13680146163096651, 0.1565802760887891, 0.1118892859085463, 0.1090628610108979, 0.07409324098262005, 0.1308709298609756, 0.16724404762499034], [0.10710009562899359, 0.03428163799981121, 0.04488748490985017, 0.046506428116117604, 0.09041925790370442, 0.08095360215520486, 0.009967845744540682, 0.060279271492618136, 0.05793670832645148, 0.024723913265916053, 0.03282403398770839, 0.07455928003764711, 0.06458196541643701, 0.07158282256568782, 0.03586505088605918, 0.022677383531117812, 0.031211321111186408, 0.04789244456333108, 0.051028805173700675, 0.042885920047410764, 0.08275144005892798, 0.0710949495260138, 0.017962749407161027, 0.010319689608877525, 0.04251503174600657, 0.03223506559152156, 0.03690415411256254, 0.0767005022498779, 0.0231805114162853, 0.0391002692776965, 0.04386570712085813, 0.02846895185939502, 0.011049953645851929, 0.03476855366898235, 0.039892367203719914, 0.050850404004449956, 0.01580868618475506, 0.014383777488546912, 0.02041230985923903, 0.0583277533587534, 0.018343806987104472, 0.3940791101194918, 3.2244343031197786, 13.99599228054285, 34.62846525013447, 51.50175243616104, 68.10114651918411, 78.41024413704872, 70.09628266096115, 62.53910757601261, 51.23113855719566, 48.51074293255806, 33.78226965665817, 28.105264082551003, 24.406582452356815, 21.435985453426838, 28.70362937450409, 31.371489018201828, 30.794472880661488, 42.694900408387184, 44.111023619771004, 27.885191291570663, 42.22034007310867, 32.768392860889435, 21.982325837016106, 16.824254617094994, 8.55025939643383, 3.670250605791807, 2.7067446196451783, 0.4041473229881376, 0.040344431617995724, 0.21857822430320084, 0.02530800204112893, 0.031221280733007006, 0.06372650663251989, 0.10703316875151359, 0.19474240019917488, 0.031087013230717275, 0.04908202936348971, 0.04584570888255257, 0.29448885878082365, 0.030247388167481404, 0.12366796363494359, 0.035375741790630855, 0.04844434268306941, 0.05611482112726662, 0.10127439963980578, 0.058574365320964716, 0.06022002955432981, 0.17670735076535493, 0.07084707962349057, 0.06905293761519715, 0.23018863488687202, 0.10867419827263802, 0.28589695575647056, 0.06063638182240538, 0.022481658779724967, 0.027570203601499088, 0.05592102410446387, 0.027045128554163966, 0.029091469041304663, 0.06553909843205474, 0.012383399134705542, 0.2801076992182061, 0.10850566395674832, 1.4893743745051324, 2.0667031640186906, 3.2503360882401466, 6.927666189149022, 9.575364589691162, 15.250563360750675, 26.995670422911644, 29.983216412365437, 34.36684548854828, 32.81315825879574, 31.351521089673042, 26.501733027398586, 18.949716165661812, 16.426847241818905, 14.008353967219591, 13.419296275824308, 20.246278792619705, 24.698695577681065, 22.37805750221014, 37.96110302209854, 37.812223210930824, 45.073675364255905, 47.52627655863762, 43.22462238371372, 37.76504874229431, 34.67978149652481, 14.34346653521061, 5.116338059306145, 1.352027419488877, 0.03907285434252117, 0.043485230271471664, 0.04748978863062803, 0.025476996488578152, 0.04522211187577341, 0.023533948115073144, 0.054690142496838234, 0.022023625642759725, 0.08496601614751853, 0.07805579749401659, 0.04478605929762125, 0.09561166443745606, 0.026541236256889533, 0.020010722619190346, 0.06936185658560134, 0.01618233527551638, 0.0226840480172541, 0.033463227227912284, 0.023429464854416437, 0.03756518504815176, 0.01438090073861531, 0.06748618965502828, 0.06702244383632205, 0.041247102126362734, 0.025459808348387014, 0.05362104166124482, 0.03773505894059781, 0.07430489407852292, 0.03451918833889067, 0.0640732899773866, 0.02229581386927748, 0.09301529047661461, 0.028423586227290798, 0.05320438140188344, 0.015365418075816706, 0.07021690718829632, 0.02237804754258832, 0.022745516398572363, 0.014739359921804862, 0.05422065616585314, 0.021996527975716162, 0.014832441938779084, 0.054172976888366975, 0.023281035319087096, 0.02716896702622762, 0.026020239311037585, 0.10051470017060637, 0.06755937283742242, 0.042781147349160165, 0.09129310710704885, 0.04099883146409411, 0.010770390326797497, 0.09119050519075245, 0.06417244832846336, 0.05782539359643124, 0.07633080138475634, 0.03916526657121722, 0.015648768203391228, 0.033559647054062225, 0.05110130558023229, 0.03504160093143582, 0.016069410085037816, 0.017151687752630096, 0.04006729141110554, 0.02463541030010674, 0.05634969973471016, 0.03075876687944401, 0.04356609839305747, 0.04576887804432772, 0.10327322597731836, 0.009468333973927656, 0.03032175693078898, 0.023105608306650538, 0.01195866801936063, 0.01650431233429117, 0.031107361064641736, 0.034980941491085105, 0.041578029486117885, 0.046158887780620717, 0.02614434310089564, 0.013133638076396892, 0.04792416024429258, 0.022351541738316882, 0.3496350918430835, 3.9961201697587967, 16.092337891459465, 42.2701022028923, 61.11714027822018, 79.79881882667542, 87.64205396175385, 79.67748373746872, 67.47863352298737, 61.78435027599335, 58.609514236450195, 48.75339791178703, 39.81943890452385, 33.43656040728092, 28.387613631784916, 34.458450973033905, 41.78720511496067, 34.482325091958046, 37.289230674505234, 38.22457328438759, 34.422075524926186, 33.71700055897236, 24.720517806708813, 16.930187232792377, 13.093286119401455, 6.7060193326324224, 2.919524176977575, 1.6735643846914172, 0.4412143933586776, 0.13649443513713777, 0.2243150703725405, 0.10150138550670817, 0.22427487565437332, 0.08405402797507122, 0.1440918305888772, 0.4668291157577187, 0.23374064272502437, 0.17396222072420642, 0.33463996835052967, 0.5047538713552058, 0.1254176881047897, 0.10967980837449431, 0.08751797256991267, 0.09251518684322946, 0.23492184496717528, 0.18274549394845963, 0.2553918067133054, 0.3475384949706495, 0.4598425969015807, 0.5105023097712547, 0.4872278164839372, 0.654297637520358, 0.6559583265334368, 0.7491760526318103, 0.3676120162708685, 0.5571264016907662, 0.42341760301496834, 0.3497308288933709, 0.28219200612511486, 0.2565989544382319, 0.08613514364697039, 0.2524510317016393, 0.23116258496884257, 0.29454380739480257, 0.6424797372892499, 1.3611133256927133, 3.7192124035209417, 6.183803854510188, 8.057508487254381, 15.047916434705257, 22.588735297322273, 26.410262435674667, 31.919241026043892, 29.800024442374706, 33.99614118039608, 27.631478905677795, 21.62867311388254, 22.787259444594383, 22.310077250003815, 20.363578498363495, 31.368553675711155, 38.11692886054516, 32.997402772307396, 48.62364627420902, 48.69501404464245, 53.196564093232155, 56.68487951159477, 54.11004267632961, 47.667815163731575, 44.452651888132095, 19.916834570467472, 6.644550506025553, 1.5285908826626837, 0.0387159703677753, 0.05323385208612308, 0.03215526987332851, 0.021856456878595054, 0.04167821571172681, 0.010024325038102688, 0.03546256564732175, 0.02540601748478366, 0.024091557061183266, 0.09815309720579535, 0.038864392481627874, 0.023354622971965, 0.02299565170687856, 0.051347175394766964, 0.07964993070345372, 0.0163026837981306, 0.04577789884933736, 0.03703247886733152, 0.04879078835074324, 0.1089154407964088, 0.036007446760777384, 0.0610695214709267, 0.05341919975762721, 0.014211556554073468, 0.015065537536429474, 0.08451176981907338, 0.03410394558159169, 0.05486078080139123, 0.1285715337144211, 0.04555499479465652, 0.037851691158721223, 0.08884868046152405, 0.0076508157053467585, 0.04213330066704657, 0.06103370171331335, 0.05956100612820592, 0.044504232428153045, 0.01674781284236815, 0.07349794206675142, 0.017817030566220637, 0.05236884557234589, 0.06289136043051258, 0.25710100249852985, 0.09927496474119835, 0.09535125966067426, 0.13063710881397128, 0.175879247544799, 0.16349560813978314, 0.18907714169472456, 0.16828873922349885, 0.11176910251379013, 0.10097089092596434, 0.120812721143011, 0.29029608063865453, 0.273853947292082, 0.16521359095349908, 0.15436414891155437, 0.1651281103841029, 0.17123022669693455, 0.1423290220554918, 0.11264617263805121, 0.09138763445662335, 0.10974890232319012, 0.18894771113991737, 0.10209672152996063, 0.0774851230380591, 0.12039127774187364, 0.07111707294825464, 0.15561799256829545, 0.19302081054775044, 0.15113386209122837, 0.10948515788186342, 0.0920822549960576, 0.10906284616794437, 0.11582649807678536, 0.09919755131704733, 0.10098629791173153, 0.16514235961949453, 0.17808348551625386, 0.16439139522844926, 0.10232354412437417, 0.16436151636298746, 0.12222894671140239, 0.8699878386687487, 6.364251896739006, 22.01667409390211, 52.40454979240894, 74.33542639017105, 90.47557711601257, 98.66668358445168, 87.39051505923271, 78.21920558810234, 66.83763831853867, 63.050491735339165, 47.96132281422615, 41.60905547440052, 37.783196568489075, 31.473327353596687, 39.41381447017193, 46.00832641124725, 41.33286349475384, 56.937033981084824, 61.62747569382191, 38.090273290872574, 54.45610150694847, 42.13106766343117, 27.180760391056538, 20.873218551278114, 10.405889824032784, 4.801844609901309, 3.5786603204905987, 0.6566015013959259, 0.24227569723734632, 0.38781018869485706, 0.1613729025120847, 0.17976195638766512, 0.29299957619514316, 0.19631472910987213, 0.5642387294210494, 0.1867796602891758, 0.28020551428198814, 0.26138738030567765, 0.6727413728367537, 0.45471901714336127, 0.5016157741192728, 0.30868828122038394, 0.2730431064264849, 0.3740071918582544, 0.283599563408643, 0.4075733438367024, 0.44723591243382543, 0.41547932429239154, 0.45215572812594473, 0.5096634454093874, 0.6254559382796288, 0.6500527902971953, 0.6527650135103613, 0.576515217544511, 0.5423847958445549, 0.47785659902729094, 0.40089276793878525, 0.2941360417753458, 0.22424021735787392, 0.3752837155479938, 0.3795723197981715, 0.4724171315319836, 0.5608190316706896, 1.8306701607070863, 2.5052680307999253, 4.524863222613931, 8.199420422315598, 11.930794548243284, 21.118210405111313, 34.088347032666206, 40.01757927238941, 46.025091111660004, 44.28213983774185, 43.3745813369751, 38.649040907621384, 27.916790395975113, 24.213993586599827, 24.006131440401077, 23.188109435141087, 33.51544797420502, 39.12598371505737, 36.43504410982132, 53.58944021165371, 56.84582367539406, 63.191973343491554, 68.07710140943527, 67.31777295470238, 61.27890519797802, 56.87832333147526, 30.269804634153843, 9.74691778421402, 2.8123506903648376, 0.17239663051441312, 0.15179784677457064, 0.1726981799583882, 0.06657559672021307, 0.19187548372428864, 0.12644870934309438, 0.10831001156475395, 0.0995826962753199, 0.1392860829946585, 0.1689514919416979, 0.14875775756081566, 0.15597809746395797, 0.11004158310242929, 0.2369443903444335, 0.1228356895444449, 0.06586022573173977, 0.15819127089343965, 0.20807735418202356, 0.1000673632370308, 0.15213325299555436, 0.13075787108391523, 0.2097314826096408, 0.13617853255709633, 0.14918844070052728, 0.2353336033411324, 0.1181429710413795, 0.13296255434397608, 0.164969053294044, 0.2283574448665604, 0.21188537328271195, 0.18242565798573196, 0.27126607834361494, 0.11128503669169731, 0.1270922552794218, 0.15298774698749185, 0.1330954284640029, 0.1246730171260424, 0.10894048085901886, 0.11281004626653157, 0.15065384097397327, 0.20996846520574763, 0.12697499594651163], [0.015539971209364012, 0.037196037083049305, 0.046287965815281495, 0.046107152666081674, 0.05090437669423409, 0.022948388032091316, 0.07184644826338626, 0.08522957505192608, 0.007689514068260905, 0.026216787846351508, 0.022706446034135297, 0.05182695902476553, 0.018508645407564472, 0.02830537694535451, 0.04323170520365238, 0.03973867584136315, 0.04019356783828698, 0.08667733447509818, 0.022995308463578112, 0.048076656748889945, 0.041305379272671416, 0.07881833938881755, 0.03521016122249421, 0.0988116419466678, 0.025014276689034887, 0.030698766095156316, 0.04780669311003294, 0.048112918084370904, 0.027703317064151634, 0.03025471687578829, 0.043310306064086035, 0.08755221526371315, 0.06975935830269009, 0.017583126027602702, 0.016114734899019822, 0.0768168710055761, 0.008070765998127172, 0.029654807367478497, 0.10530808358453214, 0.07833460011170246, 0.3785711625823751, 4.21692774631083, 17.360187359154224, 36.04249857366085, 57.758375108242035, 75.89053094387054, 72.91581496596336, 69.1808357834816, 64.30673852562904, 52.305603101849556, 44.80322487652302, 32.21619889140129, 25.409365743398666, 21.276825293898582, 20.345979742705822, 22.297710813581944, 39.16730649769306, 32.301105335354805, 42.103857323527336, 43.46486449241638, 23.892690427601337, 26.295050717890263, 17.98417277634144, 6.6889663226902485, 4.02212074957788, 1.273062787950039, 0.5495655792765319, 0.3023555944673717, 0.12579903326695785, 0.10058552332338877, 0.07154681356041692, 0.039908100734464824, 0.08375958088436164, 0.2159991572261788, 0.21128018153831363, 0.29568493366241455, 0.3754353808471933, 0.21481924632098526, 0.20930744911311194, 0.3089761157752946, 0.07304199622012675, 0.05388175442931242, 0.08152126349159516, 0.052789357578149065, 0.05116990228998475, 0.058979722671210766, 0.02579163741756929, 0.13183925446355715, 0.22838509728899226, 0.785004508215934, 0.8176123397424817, 0.488676666864194, 0.4448599711759016, 0.7150659360922873, 0.6751309102401137, 0.13934425252955407, 0.36692659836262465, 0.28488092590123415, 0.28071777429431677, 0.3017646074295044, 0.15280788007657975, 0.031948429605108686, 0.0956003466853872, 0.11045897437725216, 0.048215594215434976, 0.08899590771761723, 0.20894335146294907, 0.3490410471567884, 0.4854550037998706, 2.3046278720721602, 4.573048437014222, 11.664258800446987, 20.741135738790035, 30.449267104268074, 45.848358795046806, 39.368004128336906, 46.11236482858658, 51.98008596897125, 44.81175921857357, 43.767845034599304, 53.90969842672348, 35.28560198843479, 18.512447029352188, 27.96378817409277, 21.36740293353796, 23.925701156258583, 35.79421229660511, 42.469253316521645, 46.924210265278816, 44.028009474277496, 39.96272921562195, 31.932988688349724, 18.90154805034399, 5.104211485013366, 0.2199422472040169, 0.07390275393845513, 0.05758914572652429, 0.02318631872185506, 0.0031870467455519247, 0.05166727853065822, 0.049304710773867555, 0.03185838482750114, 0.03759719016670715, 0.03128804804873653, 0.07409921527141705, 0.017059384990716353, 0.03604502911912277, 0.017640636906435248, 0.004402751201268984, 0.04301184766518418, 0.024531285125704017, 0.019283813089714386, 0.0662024448683951, 0.026664915167202707, 0.013776342602795921, 0.04926768502627965, 0.038767883597756736, 0.01132974517531693, 0.08705036016181111, 0.028782811677956488, 0.05025057056627702, 0.0247404353285674, 0.026993133687938098, 0.06252315870369785, 0.05481118678289931, 0.07185727619798854, 0.031324331648647785, 0.023309884454647545, 0.008026239920582157, 0.09806662215851247, 0.011172829181305133, 0.008038582764129387, 0.038066335109760985, 0.10842226140084676, 0.04706947329395916, 0.031737481549498625, 0.06414117422536947, 0.050706460751825944, 0.02514038798835827, 0.024639351104269736, 0.03164192632539198, 0.0403669891966274, 0.042612431207089685, 0.007777510518280906, 0.01845365040935576, 0.05897241993807256, 0.022584114121855237, 0.02146682934835553, 0.017961458070203662, 0.04932022908178624, 0.02891360407375032, 0.027397765588830225, 0.057896268699551, 0.06440721932449378, 0.036932645161869004, 0.03037509693967877, 0.0510147674503969, 0.15513675432885066, 0.023990600857359823, 0.04098283076018561, 0.020058427871845197, 0.05459842046548147, 0.03764321074413601, 0.14146706205792725, 0.06171982837258838, 0.011628882639342919, 0.036638394740293734, 0.03604761921451427, 0.029146783163014334, 0.027189045831619296, 0.01542085557957762, 0.04331095173256472, 0.027873632534465287, 0.05032634384406265, 0.028421239185263403, 0.0964690231194254, 0.38643599837087095, 5.485842106863856, 22.402930967509747, 44.298547357320786, 68.57566505670547, 87.05801010131836, 84.96536359190941, 81.13150611519814, 75.18614754080772, 65.0986160337925, 55.30296206474304, 44.966331124305725, 32.11388938128948, 32.75348626077175, 29.51899152249098, 23.62643301486969, 31.715076081454754, 26.775179654359818, 33.091196939349174, 37.17231094837189, 31.622583344578743, 20.822394378483295, 12.944100424647331, 5.596027644351125, 3.6318325297906995, 0.7411282032262534, 0.49162557581439614, 0.3158264060039073, 0.19166432786732912, 0.4521394008770585, 0.46009243349544704, 0.14778814162127674, 0.7484945829492062, 0.6883860239759088, 1.2173728574998677, 0.8827314642257988, 0.6887288962025195, 0.8982236485462636, 0.7871367875486612, 0.9459347790107131, 0.7093744352459908, 0.1627885046764277, 0.04102770843019243, 0.045660275864065625, 0.15490973135456443, 0.10300004883902147, 0.19498180219670758, 0.5549142672680318, 0.7412044960074127, 1.470973149407655, 2.242925358004868, 1.9882402243092656, 2.6025891210883856, 2.4901051819324493, 1.2090358673594892, 1.2431054329499602, 0.9310510370414704, 0.7228602678515017, 0.6419510906562209, 1.0510030598379672, 0.6940683221910149, 0.5254153814166784, 0.3048208903055638, 0.22196526755578816, 0.12765238381689414, 0.18273391644470394, 0.1548951110453345, 0.18437536899000406, 0.494519803323783, 1.7854914162307978, 3.527300376445055, 9.478989411145449, 15.718714389950037, 24.724902771413326, 33.0423391610384, 31.547491773962975, 38.032014816999435, 34.3750112503767, 30.877403430640697, 33.8934288918972, 40.73398143053055, 41.48252226412296, 27.646647691726685, 33.04217576980591, 34.25328478217125, 35.893440172076225, 46.73396207392216, 52.928340286016464, 58.07886131107807, 52.76122145354748, 50.02183824777603, 41.44167445600033, 22.879628688097, 6.634514769539237, 0.297636158647947, 0.09461038105655462, 0.01687231368123321, 0.03985460672993213, 0.06587879426660948, 0.02421113931632135, 0.033620161775616, 0.03366637531144079, 0.05791953131847549, 0.0869080533448141, 0.06202715543622617, 0.04313636520237196, 0.05019683165301103, 0.048271136547555216, 0.0316794789978303, 0.007228164922707947, 0.012964856996404706, 0.038620934647042304, 0.05138700274983421, 0.02143875761248637, 0.029110178584232926, 0.04789123857335653, 0.044130546230007894, 0.0010772467180686363, 0.07874406524933875, 0.06504969656816684, 0.03014045396412257, 0.03979035529482644, 0.05593362577201333, 0.035857035691151395, 0.04034900324768387, 0.08819280003081076, 0.03261507117713336, 0.03337012109113857, 0.02054402808425948, 0.024119704867189284, 0.006511219189633266, 0.09279309146222658, 0.04358882666565478, 0.038538585940841585, 0.009650353113102028, 0.008606047431385377, 0.21093204006319866, 0.19357957353349775, 0.10968720758683048, 0.11413846834329888, 0.11754464416299015, 0.14710640476550907, 0.26154682331252843, 0.2322162565542385, 0.10112890900927596, 0.12652620440348983, 0.1173879174166359, 0.10515477813896723, 0.13302280189236626, 0.10895605111727491, 0.09777515850146301, 0.09314565613749437, 0.09751507284818217, 0.2378115156898275, 0.14875861845212057, 0.10387641392298974, 0.11566582310479134, 0.33348575059790164, 0.156621019996237, 0.22857177711557597, 0.07642328782822005, 0.19478985312161967, 0.10375963698606938, 0.2772190823452547, 0.12489149055909365, 0.13408349419478327, 0.1734170241979882, 0.24273447808809578, 0.1910825286176987, 0.07746155984932557, 0.1612259869580157, 0.12175540454336442, 0.13876586715923622, 0.07126371390768327, 0.2587483625393361, 0.1461595282307826, 1.4927659300155938, 8.36974723264575, 29.8036627471447, 53.82074140012264, 83.37907031178474, 100.17872884869576, 92.99822375178337, 87.69513711333275, 80.4243640601635, 66.93349957466125, 57.91513569653034, 44.93864580988884, 36.726587265729904, 35.07446251809597, 32.340174838900566, 34.155713617801666, 50.6163277477026, 46.27729117870331, 57.013972252607346, 56.87377877533436, 32.91987173259258, 34.835827723145485, 21.526065319776535, 9.231502991169691, 5.404041046276689, 1.6510837222449481, 0.9882402839139104, 0.7018620008602738, 0.5655237135943025, 0.6247711437754333, 0.5334780737757683, 0.17129874177044258, 0.4912523942766711, 0.772465537302196, 1.1006931122392416, 0.942677641287446, 0.387088168063201, 0.4674912302289158, 0.8437187201343477, 0.9856266179122031, 1.1675895913504064, 0.9131917578633875, 0.5525416508316994, 0.2643907628953457, 0.3487248922465369, 0.20441948639927432, 0.38518705288879573, 0.8349438034929335, 0.5094114714302123, 2.152760708704591, 2.7181777311488986, 3.2737886672839522, 2.9771991446614265, 2.449573469348252, 1.9981947401538491, 0.8775738347321749, 1.1326156742870808, 0.6546751235146075, 0.44611019315198064, 0.8305747504346073, 0.5871795827988535, 0.31931441102642566, 0.41501105879433453, 0.3854726906865835, 0.1287658279761672, 0.27428445231635123, 0.4122098669176921, 0.8956838410813361, 0.9358785592485219, 3.3119452698156238, 5.949018253013492, 14.68220790848136, 25.012009665369987, 38.47404129803181, 58.236423656344414, 53.08880187571049, 64.51100796461105, 69.77220565080643, 61.14976912736893, 58.54488730430603, 66.26590579748154, 48.43288891017437, 30.381748527288437, 39.127682223916054, 36.763015910983086, 39.04859706759453, 53.880645185709, 61.230005621910095, 70.81980183720589, 66.92057266831398, 65.29580265283585, 54.48848336935043, 28.458263240754604, 9.767514578998089, 1.1709537170827389, 0.35133817233145237, 0.14461145270615816, 0.20943071984220296, 0.16953579965047538, 0.18437189573887736, 0.11141903887619264, 0.12018071560305543, 0.15624932275386527, 0.10403421678347513, 0.11928709558560513, 0.11396197820431553, 0.20936600456479937, 0.16214693285292014, 0.07357590468018316, 0.07403655574307777, 0.1484063803218305, 0.14063990878639743, 0.12922733993036672, 0.046754798968322575, 0.1060470993979834, 0.21574013284407556, 0.12090199408703484, 0.09276514218072407, 0.1854223315604031, 0.15189840778475627, 0.07125206961063668, 0.08909759679227136, 0.13705539488000795, 0.13780141656752676, 0.2519865659996867, 0.14945807779440656, 0.07291974223335274, 0.09948222432285547, 0.09226589943864383, 0.1738920432399027, 0.10195587674388662, 0.27289877354633063, 0.195342545339372, 0.2076767577091232, 0.16153354779817164, 0.15966240054694936], [0.06330556047032587, 0.07740411019767635, 0.04273602105968166, 0.031026914111862425, 0.03065617423999356, 0.0440231611719355, 0.03242666585720144, 0.028252912670723163, 0.045740732093690895, 0.029140074148017447, 0.02272697012813296, 0.10879356530494988, 0.016422807821072638, 0.1010208968364168, 0.022874405185575597, 0.07362424817983992, 0.037884776102146134, 0.016527270672668237, 0.03205667184374761, 0.06761889308108948, 0.028196709827170707, 0.041325138954562135, 0.06652993979514576, 0.05221780367719475, 0.07930678388220258, 0.07670919279917143, 0.07944949888042174, 0.03395456609723624, 0.09588242959580384, 0.05255310228676535, 0.01872025582997594, 0.04778241374879144, 0.05586669889453333, 0.03691990248626098, 0.004227693407301558, 0.024183180757972877, 0.038677374977851287, 0.0674012879608199, 0.00553128090359678, 0.6140302482526749, 4.05127041041851, 23.739507347345352, 44.373631328344345, 68.82418692111969, 75.21634072065353, 68.18674832582474, 65.50363630056381, 56.24815754592419, 41.46616794168949, 46.63492038846016, 33.63148994743824, 19.26372181624174, 22.072595693171024, 25.88406667113304, 31.111600063741207, 47.84377992153168, 60.298037230968475, 66.01860746741295, 48.50003510713577, 18.771311938762665, 13.022468369454145, 10.807989947497845, 4.188522370532155, 1.10676673008129, 0.5069842922966927, 0.3054179926402867, 0.21245958778308704, 0.13073588866973296, 0.29856274486519396, 0.27454369934275746, 0.3460057225311175, 0.4044358106330037, 0.7684788387268782, 0.9308230492752045, 0.33792328904382885, 0.7642615400254726, 1.0563095938414335, 1.729961670935154, 0.9882495459169149, 0.8385112776886672, 0.943797156214714, 0.02688527551072184, 0.11725152551662177, 0.017601260406081565, 0.03970715682953596, 0.11681460833642632, 0.2241718358709477, 0.37072773033287376, 1.1432004813104868, 0.8565175614785403, 0.557400758843869, 1.003768506925553, 0.8582023554481566, 1.649858288001269, 1.6343984613195062, 1.282396037131548, 1.7301154439337552, 0.9349481435492635, 0.7995307131204754, 0.928497277200222, 0.7021043566055596, 0.4108403075952083, 0.8016715419944376, 0.16590245242696255, 0.05908903731324244, 0.02648959020007169, 0.07536010190960951, 0.02720805223361822, 0.11825473106000572, 0.25145061663351953, 0.858044367050752, 1.0330676659941673, 3.4034932823851705, 8.964700307697058, 20.109163150191307, 33.96664336323738, 51.28670297563076, 68.42457756400108, 82.39317521452904, 84.73296046257019, 97.52690434455872, 62.63537161052227, 36.16784244775772, 30.181413777172565, 20.06478913128376, 20.929003357887268, 25.677722543478012, 35.56545317173004, 40.073645263910294, 46.492226645350456, 49.863911122083664, 29.790401458740234, 25.748273357748985, 17.49743789434433, 6.394368605688214, 0.26370858075097203, 0.019621464307419956, 0.02615049550513504, 0.020421597837412264, 0.02485255157807842, 0.029300327951204963, 0.06265213654842228, 0.03950737438572105, 0.06903923014760949, 0.02457882339513162, 0.06410791858797893, 0.039713082878733985, 0.04711289264378138, 0.029796854432788678, 0.08557485183700919, 0.03445384223596193, 0.04715464587206952, 0.08527046738890931, 0.03712203753821086, 0.03168362389260437, 0.010685511824704008, 0.07815543081960641, 0.013194487692089751, 0.03799951955443248, 0.06428652384784073, 0.0480392413737718, 0.01984348891710397, 0.026491996613913216, 0.05782598731457256, 0.07607486433698796, 0.033660701592452824, 0.017292090960836504, 0.021965810483379755, 0.13483370159519836, 0.013645572471432388, 0.028752812213497236, 0.03734844452992547, 0.03482359505142085, 0.026557290766504593, 0.04934326534566935, 0.017749656544765458, 0.08439776851446368, 0.04532292892690748, 0.027092644559161272, 0.0962880281440448, 0.011268476246186765, 0.019139066462230403, 0.022142879497550894, 0.04347689595306292, 0.04006022616522387, 0.016726203357393388, 0.04550138946797233, 0.11216285638511181, 0.025687315574032255, 0.08131574795697816, 0.09882821410428733, 0.03295018796052318, 0.017996036585827824, 0.029992911295266822, 0.06579017441254109, 0.053927637709421106, 0.04548642406007275, 0.06488689163234085, 0.04471761843888089, 0.0833543979388196, 0.020060747083334718, 0.05099511909065768, 0.017387892949045636, 0.01571453918586485, 0.08494405599776655, 0.07003438338870183, 0.08103766522253864, 0.09106457757297903, 0.01007863633276429, 0.05188225273741409, 0.037188956994214095, 0.03925124809029512, 0.09680096351075917, 0.04391134178149514, 0.003982802300015464, 0.9205495880451053, 6.111693698912859, 31.118414998054504, 51.77687667310238, 78.68568375706673, 86.370999366045, 79.21490415930748, 75.15850782394409, 67.09968745708466, 55.430084243416786, 54.70735162496567, 41.54761657118797, 28.051063790917397, 28.974302150309086, 23.24976872652769, 20.977984629571438, 38.10315079987049, 60.28028838336468, 52.857124507427216, 38.213884457945824, 21.80843196809292, 12.516467571258545, 8.299620095640421, 3.965735575184226, 0.8931800129357725, 0.6672450865153223, 0.308960530674085, 0.3093186020851135, 0.5086791794747114, 0.7883955293800682, 0.8585629204753786, 1.3338622567243874, 1.5474677947349846, 2.8933086711913347, 2.2499936912208796, 2.294031665660441, 2.0702034886926413, 3.6591922491788864, 2.902511302381754, 2.8417271515354514, 2.5378909427672625, 1.7663805792108178, 0.2567560225725174, 0.08412095485255122, 0.15740508417366073, 0.04974573945219163, 0.16753970441641286, 0.338783705374226, 1.0575061733834445, 3.947350261732936, 3.331767381168902, 4.76876026019454, 4.252784997224808, 3.0804403172805905, 5.688746944069862, 3.578747953288257, 3.3997029857710004, 3.8739127898588777, 2.248374978080392, 2.948371754027903, 2.7247703773900867, 2.9336936166509986, 1.1153600877150893, 2.2408019844442606, 1.3485907413996756, 0.3953048412222415, 0.47045103390701115, 0.09941446623997763, 0.12032366066705436, 0.14142487838398665, 0.31183136568870395, 0.5325696850195527, 1.0027777100913227, 2.913637342862785, 8.125769924372435, 17.52521440386772, 28.296809904277325, 45.31345009803772, 63.58966000378132, 71.51758879423141, 73.70549619197845, 95.49443140625954, 63.87635841965675, 40.341029316186905, 40.74677154421806, 27.419184297323227, 28.060211800038815, 34.01963531970978, 44.457067251205444, 48.786592930555344, 57.51282848417759, 60.20062945783138, 39.176201820373535, 34.649968296289444, 21.484966725111008, 7.5165272410959005, 0.6081967300269753, 0.13414616114459932, 0.08704253050382249, 0.006692934975944809, 0.010146044678549515, 0.03976880332629662, 0.030337588796101045, 0.02041877025476424, 0.05392498082073871, 0.06180075586598832, 0.036751557418028824, 0.024484711648256052, 0.024511174779036082, 0.023250751983141527, 0.07780086976708844, 0.03881970034854021, 0.02883243352698628, 0.11759547385736369, 0.05318594274285715, 0.016402999899582937, 0.06081503532186616, 0.061335473801591434, 0.03725064430909697, 0.018924359428638127, 0.07110207414370961, 0.03255555093346629, 0.013805334601784125, 0.030176689324434847, 0.04434623660927173, 0.05545808722672518, 0.036483059520833194, 0.03850147855700925, 0.02936400236649206, 0.03491530595056247, 0.038263913374976255, 0.034315383454668336, 0.04354937780590262, 0.0413617973390501, 0.03439513093326241, 0.030952927554608323, 0.05311172797519248, 0.2794973866548389, 0.12401726286043413, 0.06920981279108673, 0.21369382389821112, 0.10146364729735069, 0.12869853002484888, 0.13822579145198688, 0.13263244705740362, 0.1327837709686719, 0.14982230903115124, 0.08019345739739947, 0.2483008973649703, 0.15653144277166575, 0.24853595037711784, 0.12192387206596322, 0.16640484187519178, 0.09140000605839305, 0.12377320759696886, 0.1580180090968497, 0.16634290223009884, 0.19421617296757177, 0.12390816715196706, 0.14288860140368342, 0.1448801695369184, 0.16504444065503776, 0.1604056911310181, 0.17020616680383682, 0.09075893889530562, 0.1714643742889166, 0.2037519245641306, 0.16320369177265093, 0.2384339549462311, 0.11424566415371373, 0.14415791141800582, 0.15514969738433138, 0.10336862163967453, 0.16365275048883632, 0.15690719214035198, 0.16217808821238577, 1.7598798405379057, 9.922804646193981, 40.06444215774536, 64.78266298770905, 91.45930632948875, 99.01574805378914, 87.97257542610168, 83.01349192857742, 73.25651228427887, 53.514816015958786, 57.98053398728371, 43.49126547574997, 29.02780707925558, 32.72040903568268, 38.92668440937996, 46.09495036303997, 64.70535233616829, 72.81742304563522, 77.33175560832024, 57.78042532503605, 25.473449304699898, 18.45499601215124, 13.465801980346441, 5.58214888907969, 1.616980789694935, 0.8299075893592089, 0.5636925681028515, 0.40862606547307223, 0.4107299057068303, 0.530994669534266, 0.5959976627491415, 0.8596655144356191, 1.649393169209361, 2.719858903437853, 4.824217334389687, 1.969054697547108, 1.5546465595252812, 4.060737127438188, 3.2714095199480653, 3.4800489619374275, 4.448655461892486, 2.8188716154545546, 0.9374507842585444, 0.3038468660088256, 0.2695000043604523, 0.3774055157555267, 0.7000902865547687, 0.6090061459690332, 2.7635026490315795, 4.33934910222888, 3.4908888302743435, 5.886804666370153, 5.7947702798992395, 7.825635904446244, 7.249941620975733, 4.274563528597355, 4.904683716595173, 4.663946684449911, 4.437890639528632, 3.7368558067828417, 2.9069860372692347, 2.1766901621595025, 1.5650533698499203, 1.6774116782471538, 0.8785749028902501, 0.37048831349238753, 0.41694571904372424, 0.21921893523540348, 0.16408427967689931, 0.1740556868026033, 0.5366076808422804, 1.4269431307911873, 1.8753258395008743, 4.9885015189647675, 11.453585755079985, 25.564059242606163, 41.29704661667347, 61.759275421500206, 78.58607590198517, 91.80056601762772, 92.33148112893105, 105.45125752687454, 71.45810678601265, 48.48046615719795, 43.93841028213501, 31.172026321291924, 33.60410861670971, 39.90699760615826, 51.09591521322727, 58.089284151792526, 68.70279103517532, 72.65058919787407, 51.632826402783394, 50.016206949949265, 30.41187521070242, 11.857208646833897, 1.1398953711614013, 0.2470968963461928, 0.16088974953163415, 0.11929488813620992, 0.1599381974665448, 0.17850999778602272, 0.08182011151802726, 0.162003549921792, 0.13135941146174446, 0.1272905126097612, 0.11382222437532619, 0.12077275649062358, 0.2019338557147421, 0.07629534156876616, 0.24913196917623281, 0.11499083979288116, 0.10881807102123275, 0.2345091663300991, 0.15438871399965137, 0.1514447625959292, 0.1628887391416356, 0.12017068176646717, 0.14347575895953923, 0.15185013849986717, 0.14365440874826163, 0.08111178351100534, 0.14012849482242018, 0.11968392936978489, 0.14154774835333228, 0.17159376031486318, 0.17799402703531086, 0.18536160903749987, 0.196974468708504, 0.15748265344882384, 0.11745208350475878, 0.19333362579345703, 0.17358353245072067, 0.11844309556181543, 0.1758969551883638, 0.0999971189594362, 0.09700893555418588], [0.04006716524600051, 0.012830294490413507, 0.053740891089546494, 0.03940231224987656, 0.02507803830667399, 0.016445801411464345, 0.08777076291153207, 0.04312774144636933, 0.0027895550010725856, 0.1050232769921422, 0.022799928810854908, 0.007345813419306069, 0.03838456061203033, 0.04011180171801243, 0.01537094336526934, 0.048391316231573, 0.0662387210468296, 0.04232513841998298, 0.01133677424149937, 0.02770635430351831, 0.09269260466680862, 0.11099734314484522, 0.01848702293500537, 0.026315072318539023, 0.1000946520071011, 0.1185864710714668, 0.048988047492457554, 0.04721028097264934, 0.09635358946979977, 0.005053305794717744, 0.028136503096902743, 0.07072578300721943, 0.05458408217236865, 0.04231801751302555, 0.016059650843089912, 0.03664740070234984, 0.03969737903389614, 0.1514757695258595, 1.500566911417991, 8.451782930642366, 33.55980299413204, 55.295761451125145, 71.93713188171387, 82.66286194324493, 70.1514632999897, 63.191426172852516, 50.87807670235634, 44.05896261334419, 26.625849567353725, 34.00741517543793, 29.812438376247883, 29.448636397719383, 28.67986924946308, 46.08587644994259, 55.11799558997154, 43.453917279839516, 27.136272378265858, 19.90842942148447, 14.766010511666536, 7.118028849363327, 5.627830987796187, 1.3948887633159757, 0.26519548846408725, 0.10734909359598532, 0.04249142402841244, 0.09686955279903486, 0.27032515383325517, 0.554893605876714, 1.04750522878021, 0.5153468123171479, 1.6122673801146448, 0.7120176090393215, 2.9912258544936776, 0.8605239714961499, 2.9884964134544134, 2.5340685853734612, 2.5131685193628073, 3.089266293682158, 1.1323897051624954, 1.126461667008698, 0.7305786630604416, 0.06393870891770348, 0.08750844339374453, 0.10911251811194234, 0.1093195030989591, 0.0333598015276948, 0.16180162638192996, 0.5157976818736643, 2.0447498420253396, 3.0563583970069885, 4.303577346727252, 3.4822590183466673, 3.5832806350663304, 4.353944119066, 1.8864724226295948, 3.1770608201622963, 1.2472010194323957, 0.8755230135284364, 1.8868003925308585, 2.934496086090803, 2.787318821065128, 1.9103764649480581, 2.3445848654955626, 1.518661540467292, 0.8588891685940325, 0.5836312856990844, 0.06902081004227512, 0.11367549435817637, 0.12468189321225509, 0.058840510610025376, 0.024121999958879314, 0.1678996905684471, 0.7313474686816335, 1.4648759015835822, 5.539458654820919, 9.994161017239094, 23.199562020599842, 40.181472077965736, 63.95073562860489, 56.19355447590351, 55.639437809586525, 57.30560660362244, 29.281933642923832, 24.685884565114975, 18.566031754016876, 20.840232521295547, 20.90273156762123, 45.626937076449394, 41.45120054483414, 45.886170566082, 52.279430106282234, 56.22283950448036, 44.24289934337139, 23.738640993833542, 13.401804864406586, 2.6677166763693094, 0.13066346989944577, 0.03354414729983546, 0.05406381438660901, 0.07929821949801408, 0.028685722063528374, 0.032974337445921265, 0.010150225753022823, 0.03236781725718174, 0.01900275434309151, 0.0703081171377562, 0.021565592505794484, 0.1488806720590219, 0.01505374202679377, 0.07343710822169669, 0.048119634520844556, 0.038866815593792126, 0.02066207780444529, 0.0613875577255385, 0.021878400330024306, 0.05460588647110853, 0.04890168747806456, 0.03890472820785362, 0.03426820141612552, 0.035655568572110496, 0.051927527456427924, 0.04851889141718857, 0.006609724914596882, 0.024096880115394015, 0.0311862476519309, 0.03547233602148481, 0.010651622578734532, 0.07834199932403862, 0.06743423189618625, 0.07415427520754747, 0.005082728239358403, 0.03442199667915702, 0.08325503178639337, 0.027211126580368727, 0.06949009228264913, 0.038385384395951405, 0.021559120978054125, 0.04693154514825437, 0.03247712076699827, 0.05515119060873985, 0.01892158750706585, 0.032832015785970725, 0.036655872318078764, 0.04647021873097401, 0.04349992479546927, 0.06048225630365778, 0.05985497082292568, 0.04942476429278031, 0.0864110593101941, 0.029215055183158256, 0.0338760283193551, 0.031046369513205718, 0.07208970942883752, 0.05369160877307877, 0.023592577781528234, 0.053924101375741884, 0.0732557124865707, 0.13752113707596436, 0.0455446640989976, 0.03938931353332009, 0.01669487730396213, 0.09676162226242013, 0.036791343954973854, 0.05580980585364159, 0.05350754872779362, 0.02752231837803265, 0.0687586389540229, 0.03794681222643703, 0.03358210073201917, 0.05733524958486669, 0.03820500169240404, 0.058542723854770884, 0.061238137423060834, 0.0419387318106601, 1.6089996742084622, 10.036616139113903, 37.55646273493767, 63.693314641714096, 81.5199364721775, 93.66930574178696, 79.95334133505821, 74.87832605838776, 60.6892566382885, 55.18001586198807, 34.47891287505627, 46.539165526628494, 39.09672528505325, 28.092401772737503, 26.79242692887783, 41.31469666957855, 55.788560807704926, 48.264227360486984, 31.719474345445633, 25.237903743982315, 17.72591583430767, 7.220757286995649, 4.674886297434568, 1.264268159866333, 0.10840338858542964, 0.09102671319851652, 0.17110943474108353, 0.4683103534625843, 0.8630637789610773, 1.6188837750814855, 2.499629370868206, 3.3075892785564065, 3.8872443744912744, 3.2486226176843047, 4.804268879815936, 5.084058316424489, 6.173400962725282, 4.186679469421506, 7.137412559241056, 7.2374592907726765, 6.811735359951854, 4.6044091042131186, 1.5148661378771067, 0.5057957873214036, 0.06712296773912385, 0.03731983102625236, 0.021892959412070923, 0.04266571741027292, 0.2704998850822449, 1.6917847632430494, 4.794693868607283, 6.66692323051393, 6.36497100815177, 3.738679471425712, 6.491859974339604, 8.022492416203022, 5.855616889894009, 8.068195413798094, 5.072281323373318, 4.7707124054431915, 5.287231989204884, 4.376684473827481, 5.556232379749417, 5.270005138590932, 4.325148314237595, 4.01974587701261, 1.69357422972098, 2.064949795603752, 0.830824290169403, 0.5810796632431448, 0.3279261145507917, 0.17225698800757527, 0.11063824014854617, 0.2323610198800452, 0.7016371004283428, 1.970727201551199, 5.87766045704484, 12.273209374397993, 26.704723834991455, 45.0781287252903, 70.91751739382744, 70.26163458824158, 67.84839168190956, 64.08137261867523, 32.93290123343468, 30.21639660000801, 25.060476064682007, 28.344957120716572, 29.462300464510918, 51.034134328365326, 51.285061463713646, 55.861277505755424, 61.76783636212349, 62.12610013782978, 51.88873887062073, 32.59537294507027, 16.21221385896206, 2.516045202501118, 0.20230299996910617, 0.04632813455828, 0.06086291868996341, 0.030860914230288472, 0.019572586461436003, 0.051734873341047205, 0.04625460256647784, 0.043816072284244, 0.04641591207473539, 0.045402357282000594, 0.06604349910048768, 0.07288972978130914, 0.053107453204574995, 0.012523316236183746, 0.015088096970430342, 0.01717989864118863, 0.007025190316198859, 0.03332332125864923, 0.03744016285054386, 0.02724727659369819, 0.031966857131919824, 0.08983653839095496, 0.07402646995615214, 0.021023659573984332, 0.06320668413536623, 0.027490593420225196, 0.031420751474797726, 0.07143212205846794, 0.024805482717056293, 0.018173283715441357, 0.07708667137194425, 0.03921498304407578, 0.04121434372791555, 0.06518234804389067, 0.028601757330761757, 0.0761463628441561, 0.060412961975089274, 0.059070082861580886, 0.051073170761810616, 0.009938593066181056, 0.12423459338606335, 0.14719568513100967, 0.13929197564721107, 0.18258216208778322, 0.15430657309480011, 0.15745148324640468, 0.14268341241404414, 0.135177405027207, 0.12492494657635689, 0.20034264656715095, 0.13863063300959766, 0.0918800568615552, 0.1638490188634023, 0.1082439381571021, 0.06865373637992889, 0.09825286411796696, 0.23543064657133073, 0.1873777571017854, 0.18400745670078322, 0.1347344319219701, 0.17213270795764402, 0.2877520874608308, 0.12010249323793687, 0.1226524607045576, 0.16034058993682265, 0.15763801464345306, 0.16991408716421574, 0.20181836269330233, 0.28391699481289834, 0.07691844133660197, 0.15276618622010574, 0.15886474022408947, 0.09736956737469882, 0.19325516594108194, 0.17282709100982174, 0.2074817064567469, 0.17533753911266103, 0.2199020524858497, 3.291358924470842, 15.29699306935072, 48.69836166501045, 80.15078634023666, 94.11394268274307, 101.50659799575806, 89.46411699056625, 83.30634221434593, 69.85919818282127, 57.91794374585152, 36.67059347033501, 44.2832113802433, 39.41139779984951, 40.13847358524799, 42.25859262049198, 62.94695109128952, 70.82613229751587, 57.31204345822334, 37.07400642335415, 27.59028721600771, 20.65117746591568, 10.186952222138643, 7.386453570798039, 2.244146279990673, 0.6181615765672177, 0.1882617291994393, 0.2744012663606554, 0.37417239393107593, 0.767766673816368, 1.5469962637871504, 2.894521043635905, 2.3419095715507865, 4.897498777136207, 3.220846583135426, 7.336619719862938, 6.6517753433436155, 9.39897520467639, 7.721232231706381, 10.805691070854664, 10.260334834456444, 5.6817063968628645, 6.498840199783444, 3.4208965860307217, 0.8477430010680109, 0.24099580419715494, 0.6427524914033711, 0.4353342088870704, 0.6100147543475032, 0.3087059740209952, 3.020308306440711, 8.557662349194288, 7.726925276219845, 12.675468139350414, 9.44424407556653, 9.93559380993247, 13.680863790214062, 11.159646827727556, 9.853903893381357, 6.272581340745091, 6.4813122153282166, 8.399800769984722, 8.494827020913363, 8.516985531896353, 6.470219185575843, 6.664794869720936, 3.9467534562572837, 1.9172140792943537, 1.5818848041817546, 0.7174069667235017, 0.5484880995936692, 0.44804918754380196, 0.3451771888649091, 0.22155664104502648, 0.44509647879749537, 1.1700212233699858, 2.275485573336482, 6.921724257990718, 13.20561284199357, 26.377625986933708, 46.187498196959496, 71.17642030119896, 63.46430093050003, 67.37806051969528, 66.07847705483437, 38.47045049071312, 38.07385057210922, 30.148520842194557, 35.54293558001518, 35.47463804483414, 61.14171355962753, 57.16937631368637, 66.84460714459419, 74.95094776153564, 78.35460752248764, 67.79273226857185, 45.58159410953522, 22.695800252258778, 5.6443567760288715, 0.4434984567342326, 0.1398872522986494, 0.13093472487526014, 0.12388745381031185, 0.10492992965737358, 0.12289958103792742, 0.1829575255396776, 0.15290269686374813, 0.11056386210839264, 0.20791795570403337, 0.15976345137460157, 0.15296512632630765, 0.14972957025747746, 0.12278713824343868, 0.18800834513967857, 0.09451954218093306, 0.26900454657152295, 0.16800761368358508, 0.14208653272362426, 0.14164847263600677, 0.1921783690340817, 0.1684531249338761, 0.1969109705532901, 0.11666096150293015, 0.18555038172053173, 0.20328389655333012, 0.09608656473574229, 0.21584097587037832, 0.12155201897257939, 0.17431576503440738, 0.15059901110362262, 0.1596512831747532, 0.1181972814083565, 0.1186707938904874, 0.08961717438069172, 0.14509603061014786, 0.1689041726058349, 0.15444660151842982, 0.21572799130808562, 0.09793643461307511], [0.05986680065689143, 0.03398550994461402, 0.011709825903380988, 0.06793236141675152, 0.028874101408291608, 0.03098751163634006, 0.018549020096543245, 0.03828778084425721, 0.021584582209470682, 0.02404160681180656, 0.06044045112503227, 0.04110693640541285, 0.01721770178846782, 0.06576761312317103, 0.03524370629747864, 0.0883920444175601, 0.015913909737719223, 0.02689176002604654, 0.052769044996239245, 0.046373045624932274, 0.0407902397273574, 0.03413006546907127, 0.050250299682375044, 0.11574872100027278, 0.06672807096038014, 0.03197473502950743, 0.04630503521184437, 0.0013439031613415864, 0.05514317912457045, 0.046630322249257006, 0.026036290109914262, 0.021978710865369067, 0.012164905292593176, 0.06184345162182581, 0.03972768463427201, 0.12141832106863149, 0.08222041113185696, 0.9834859671536833, 9.267815742641687, 34.56379272043705, 60.47157011926174, 75.82560762763023, 75.02844840288162, 68.40740248560905, 65.18046364188194, 54.74631853401661, 42.00853183865547, 31.249848045408726, 31.354021355509758, 40.074838399887085, 48.321638479828835, 67.39664912223816, 73.73613774776459, 54.56797510385513, 31.321673691272736, 27.134836055338383, 23.668445460498333, 14.100695662200451, 4.4835451897233725, 2.1663753781467676, 0.36204816482495517, 0.12362906767521054, 0.27770628745201975, 0.09064887097338215, 0.5374125845264643, 0.18737219099421054, 1.184703754261136, 1.516246295068413, 1.105231731198728, 4.208869328722358, 3.74890994746238, 3.3929666597396135, 4.024744983762503, 3.067330070771277, 5.037898868322372, 4.196236906573176, 7.408391693606973, 4.919487722218037, 6.808679373934865, 1.180224388372153, 0.6564042088575661, 0.36585279973223805, 0.0411628757865401, 0.04856309373280965, 0.0436953211465152, 0.21656848839484155, 0.44154827075544745, 0.2060975119820796, 4.982664082199335, 6.4659154415130615, 4.061075309291482, 4.070487404242158, 3.336470816284418, 6.547465715557337, 4.4901720341295, 4.884054148569703, 5.45529174618423, 2.7276366110891104, 3.8794201193377376, 2.563537904061377, 4.57276820205152, 1.9308440666645765, 4.400691585615277, 5.735540958121419, 1.784409424290061, 1.9621784915216267, 0.7686982175800949, 0.5649931076914072, 0.6874509179033339, 0.26160456240177155, 0.06148555090476293, 0.04359999227744993, 0.14525750710163265, 0.10754010756500065, 0.4406906745862216, 1.909300172701478, 4.8613546416163445, 11.170824877917767, 21.21831603348255, 28.214358128607273, 29.96065702289343, 33.467338755726814, 44.97323915362358, 55.13129107654095, 45.42922988533974, 23.512439131736755, 24.16161149740219, 36.576727107167244, 36.05554327368736, 44.36389625072479, 48.30718405544758, 54.57448035478592, 47.61326149106026, 37.05137103796005, 24.06525056809187, 9.567356519401073, 1.6405300260521472, 0.10702361731091514, 0.023454733127437066, 0.04398468452563975, 0.0363600930722896, 0.007597199710289715, 0.02186667810747167, 0.041689552017487586, 0.06611357268411666, 0.055415985189029016, 0.018493143797968514, 0.009187945015582955, 0.07066142396070063, 0.040221390954684466, 0.044989496818743646, 0.04313961951993406, 0.033205045183422044, 0.046846958866808563, 0.030324497311084997, 0.027761594210460316, 0.03454436569882091, 0.03747347785974853, 0.07240106264362112, 0.049439503345638514, 0.06099198930314742, 0.09699531714431942, 0.04260040841472801, 0.10044519804068841, 0.06794083674321882, 0.0413078840210801, 0.03536406409693882, 0.06164133141282946, 0.023252067439898383, 0.05697788692486938, 0.008322783578478266, 0.01978021526156226, 0.013949626663816161, 0.04060404600750189, 0.08394335891352966, 0.05179504667466972, 0.07236253775772639, 0.03176127480401192, 0.01857257400843082, 0.06369083159370348, 0.01939279376529157, 0.032482382594025694, 0.00980446842731908, 0.005676730716004386, 0.025333251760457642, 0.02454546200169716, 0.14046211988897994, 0.0041704125942487735, 0.022216224097064696, 0.04765466044773348, 0.09097092595766298, 0.03628888771345373, 0.04427636711625382, 0.021455647038237657, 0.02230219262855826, 0.026764719186758157, 0.04547150689177215, 0.005382118033594452, 0.0514996125275502, 0.052462263411143795, 0.028698804271698464, 0.017954320464923512, 0.042085257737198845, 0.02647299948876025, 0.03788073510804679, 0.0106424227305979, 0.06869141521747224, 0.04344800043327268, 0.026145545380131807, 0.02963113471196266, 0.07420038484269753, 0.052455918048508465, 0.1491443274426274, 1.6763372858986259, 10.335011277347803, 40.5352520942688, 69.8281842470169, 86.08928248286247, 86.46947488188744, 78.99178013205528, 74.78884845972061, 63.982828706502914, 55.87076559662819, 45.47583058476448, 34.67081397771835, 36.89041547477245, 37.259922847151756, 47.54398360848427, 54.75211322307587, 57.090427950024605, 33.290826827287674, 24.558587595820427, 18.16385943442583, 9.142747353762388, 4.233258794993162, 2.180623901076615, 0.2150404657004401, 0.26377362257335335, 0.7457577798049897, 0.8508051617536694, 1.0921705258078873, 1.5837455168366432, 2.333752359263599, 4.129282124340534, 6.547444816678762, 5.4148186929523945, 7.039004489779472, 6.960677867755294, 7.9299417324364185, 7.088988432660699, 9.863351136446, 9.935838896781206, 6.152110230177641, 6.906216340139508, 6.404654653742909, 3.277822625823319, 0.4437498963670805, 0.24467642622767016, 0.048968836999847554, 0.10378999082604423, 0.09779444691957906, 0.1472144020954147, 0.23784507560776547, 0.840121025685221, 3.602087963372469, 6.307868622243404, 7.542042871937156, 4.522263687103987, 6.670933440327644, 9.876216296106577, 8.78722133114934, 8.763772789388895, 10.201774276793003, 7.730299020186067, 8.860328458249569, 8.081076722592115, 8.665414117276669, 8.746271878480911, 6.895587360486388, 7.417320739477873, 3.296101544983685, 3.6080790543928742, 2.5315367337316275, 1.3029642147012055, 1.31270190468058, 0.5917808983940631, 0.38906082627363503, 0.11030683410353959, 0.1542930511641316, 0.16567621612921357, 0.744159787427634, 1.726289049256593, 6.18008385412395, 14.728874154388905, 26.836565360426903, 30.31434204429388, 39.111373499035835, 34.84121583402157, 34.97286356985569, 47.344737499952316, 40.65759412944317, 28.152341656386852, 28.831034637987614, 45.84864757955074, 44.313811138272285, 51.42147034406662, 55.84416322410107, 66.38806164264679, 57.073165476322174, 44.06425192952156, 27.16714382171631, 10.27764480561018, 2.0637352857738733, 0.0058291154346079566, 0.10257040470605716, 0.04935302087687887, 0.02619620438053971, 0.024295799812534824, 0.03736567719897721, 0.006218258249646169, 0.0657427660189569, 0.009271816052205395, 0.03585538812330924, 0.02028993156272918, 0.032916327472776175, 0.027411352457420435, 0.05869680484465789, 0.056438026440446265, 0.053041205392219126, 0.028196238563396037, 0.08846147975418717, 0.012217694256833056, 0.018793192248267587, 0.02381895508733578, 0.0478305160504533, 0.010547748806857271, 0.06451895707868971, 0.012518188923422713, 0.0408536265604198, 0.08383958440390415, 0.009723257062432822, 0.0323116552317515, 0.009052570785570424, 0.007380128472505021, 0.07040812895866111, 0.06648289505392313, 0.04954462485329714, 0.04466700767807197, 0.04726008279249072, 0.07947713645990007, 0.05286625149892643, 0.016369304539693985, 0.157843945780769, 0.08281547256046906, 0.10291608225088567, 0.1540408396977, 0.10768397289211862, 0.34785503579769284, 0.1299455013941042, 0.13647873129229993, 0.08088227434200235, 0.12709805887425318, 0.2707366895629093, 0.13703091884963214, 0.08293388222227804, 0.16876313486136496, 0.19514709332725033, 0.1558305585058406, 0.16976338665699586, 0.194418408209458, 0.17076053627533838, 0.12908069154946133, 0.13890784000977874, 0.06285520299570635, 0.16760479076765478, 0.25117522047366947, 0.14332729973830283, 0.16912390768993646, 0.12691828102106228, 0.09755909704836085, 0.3520516731077805, 0.08324514637934044, 0.17514723760541528, 0.1853635534644127, 0.06560741312569007, 0.18444349814672023, 0.14077400002861395, 0.2618426433764398, 0.5436969129368663, 2.832241910509765, 15.943298488855362, 50.88958628475666, 79.75067541003227, 96.7738227546215, 95.63655897974968, 86.42890825867653, 82.56560996174812, 69.15371283888817, 55.796338990330696, 44.22933027148247, 40.79450838267803, 52.748921513557434, 61.110733821988106, 81.96464940905571, 91.66375055909157, 70.31959667801857, 43.92301730811596, 37.010648623108864, 29.50708106160164, 17.631523199379444, 5.917531717568636, 3.155059525743127, 0.40172590292058885, 0.4212108120555058, 0.5277984472922981, 0.6803917873185128, 1.1893406929448247, 1.7173009878024459, 1.8900132388807833, 4.698968455195427, 7.226819386705756, 7.117286464199424, 9.317153245210648, 10.553799737244844, 14.439554829150438, 10.096667166799307, 15.835199039429426, 13.32100884988904, 15.311481691896915, 13.99453030899167, 15.460492596030235, 6.643575383350253, 3.047597254626453, 1.2306121783331037, 0.357411433942616, 0.3016766480868682, 0.229577268473804, 0.8528521831613034, 0.9983704215846956, 0.8397686539683491, 11.398446913808584, 16.826633289456367, 14.814014285802841, 17.742367051541805, 13.043342549353838, 18.92650131136179, 15.284363497048616, 16.61335453391075, 15.098747257143259, 11.738905794918537, 13.800098542124033, 10.321945678442717, 15.059661604464054, 10.678353253751993, 12.852355297654867, 13.632489535957575, 5.33981641754508, 4.898243537172675, 2.837366173043847, 1.2475221022032201, 1.435347804799676, 0.6739543983712792, 0.5824739509262145, 0.2759056293871254, 0.19613860262325034, 0.2778297511395067, 1.052344269119203, 2.966997167095542, 6.980735566467047, 15.736007262021303, 28.209418393671513, 37.1858686208725, 44.062944799661636, 46.48695632815361, 58.31159882247448, 67.56318658590317, 57.185544446110725, 35.45482970774174, 36.97993867099285, 51.427219435572624, 50.5358062684536, 60.62687538564205, 64.40079867839813, 75.65509557723999, 65.99599108099937, 56.6183602809906, 37.73875415325165, 14.189262259751558, 2.7222221391275525, 0.14769908390007913, 0.28464471513871104, 0.1241524970100727, 0.04833099817915354, 0.09241112289601006, 0.126167761918623, 0.08727517153602093, 0.13527703093132004, 0.15500402863835916, 0.1607814256567508, 0.13390941603574902, 0.13256134930998087, 0.1449817101820372, 0.21399593737442046, 0.12944119720486924, 0.17244228743948042, 0.0983360737154726, 0.20877887669485062, 0.09517313679680228, 0.10133569361642003, 0.10981323910527863, 0.17604155524168164, 0.09096956782741472, 0.15860656189033762, 0.14454700460191816, 0.1332469453336671, 0.13659434305736795, 0.1469799131155014, 0.13575164921348915, 0.13972430635476485, 0.1565939761349, 0.13259983708849177, 0.1847474669921212, 0.15429924067575485, 0.08008451011846773, 0.11857353543746285, 0.22418045962695032, 0.22321893309708685, 0.10620695058605634], [0.03461133710516151, 0.005020354901716928, 0.018779753809212707, 0.08956290854257531, 0.027074473073298577, 0.04014496458694339, 0.052896115521434695, 0.0572121718141716, 0.03293353787739761, 0.015694681169406977, 0.008495009151374688, 0.01193145439174259, 0.04618072918674443, 0.01502628070738865, 0.028459064596972894, 0.015259143456205493, 0.10249667233438231, 0.01705166851024842, 0.011645343474810943, 0.027897509280592203, 0.041615682348492555, 0.017482911971455906, 0.040966867163660936, 0.09069072068086825, 0.07112024934031069, 0.04797711990249809, 0.00890576191522996, 0.026260810191161, 0.004633102707884973, 0.0205771111723152, 0.015905280415609013, 0.02005481732339831, 0.02989109420013847, 0.038871658107382245, 0.03873977475450374, 0.042762248558574356, 0.5524180980864912, 8.903343100100756, 40.09053535759449, 59.77021135389805, 73.03145796060562, 70.28593048453331, 65.61634585261345, 58.34027208387852, 54.43391069769859, 48.684617802500725, 27.587412670254707, 28.645560890436172, 39.42743293941021, 90.10630533099174, 109.20743957161903, 108.60728457570076, 81.1635459959507, 48.179317116737366, 31.322437450289726, 14.63878383859992, 6.0986110009253025, 2.3756049759685993, 0.5967211676761508, 0.29137804289348423, 0.1347593977698125, 0.1401910133427009, 0.4676062037469819, 0.39770723262336105, 1.3045426737517118, 2.463400927372277, 2.8310915222391486, 3.327576918527484, 3.9799161767587066, 5.351774375885725, 3.710082918405533, 5.9434624761343, 5.8874838799238205, 6.283005606383085, 7.4159167148172855, 6.375283654779196, 4.63357443921268, 6.83685296215117, 7.541303811594844, 5.17555883154273, 0.5844320927280933, 0.10429143032524735, 0.08592464087996632, 0.0945499850786291, 0.038256016923696734, 0.18011342268437147, 0.5360140814445913, 0.7704458269290626, 1.270561097189784, 6.359078949317336, 3.7704479042440653, 2.2799966437742114, 6.931654075160623, 5.421998407691717, 2.925680559128523, 8.770459480583668, 4.284486221149564, 5.277726799249649, 4.831312028691173, 3.6699456721544266, 5.770544679835439, 9.850722514092922, 3.444514931179583, 4.2648745235055685, 2.547710328362882, 5.073551880195737, 2.2340141236782074, 1.5254828869365156, 0.6259822100400925, 0.5616917973384261, 0.1146742989658378, 0.03084182619204512, 0.13804332702420652, 0.05138613443705253, 0.09976559857022949, 0.19028329494176432, 1.1760599305853248, 3.6864443868398666, 11.423400174826384, 31.574341133236885, 36.39113366603851, 69.99037474393845, 97.37059593200684, 79.89284098148346, 50.84061071276665, 25.08151363581419, 23.527902401983738, 20.978841483592987, 29.45588830858469, 35.74731521308422, 44.21425648033619, 50.81031113862991, 47.524395659565926, 51.46199516952038, 46.63352966308594, 21.98092371225357, 2.967541250400245, 0.34601914056111127, 0.08449682296486571, 0.04914329736493528, 0.01954598232259741, 0.05052333952335175, 0.036377529831952415, 0.05376681801863015, 0.0699461049225647, 0.04495054890867323, 0.015898879391897935, 0.033488360058981925, 0.05111709106131457, 0.09052304725628346, 0.02544667604524875, 0.04541557493212167, 0.02004487996600801, 0.04329714778577909, 0.03732547505933326, 0.059312587036401965, 0.017052731636795215, 0.023051533571560867, 0.07002813450526446, 0.03102346498053521, 0.034364339226158336, 0.02486116049112752, 0.035399334665271454, 0.04673328410717659, 0.023847947086323984, 0.057609183713793755, 0.09504768415354192, 0.04985059749742504, 0.01814384086173959, 0.045989262507646345, 0.029591984566650353, 0.05811067145259585, 0.043512188785825856, 0.03540602141583804, 0.031928885146044195, 0.08951573021477088, 0.05491767755302135, 0.06653785108937882, 0.029005613687331788, 0.04951980372425169, 0.03650477476185188, 0.033322111557936296, 0.009779822630662238, 0.07276194679434411, 0.022388508114090655, 0.0855210906593129, 0.055143884164863266, 0.10054037848021835, 0.0478973983990727, 0.04090805567102507, 0.045254606811795384, 0.060376596738933586, 0.002601075930215302, 0.0309649280825397, 0.06737617368344218, 0.038501289309351705, 0.011673003318719566, 0.012555066241475288, 0.0485667339671636, 0.030388733903237153, 0.050441866551409476, 0.04378615260065999, 0.012276779416424688, 0.02408151951385662, 0.025669446513347793, 0.007127564022084698, 0.04576156788971275, 0.06800831280997954, 0.015510764915234176, 0.02807550412398996, 0.021908342278038617, 0.0014538672985509038, 0.8393325086217374, 10.345857795327902, 45.14445796608925, 69.03458163142204, 79.82414066791534, 80.17325833439827, 77.07025364041328, 67.51379683613777, 68.8828557729721, 61.08633153140545, 39.37671706080437, 28.264517337083817, 34.18597139418125, 77.504942715168, 90.19845798611641, 98.52250412106514, 77.43200942873955, 49.12101298570633, 30.28319511562586, 15.567331463098526, 6.751655358821154, 3.511285660788417, 1.084334752522409, 0.3364022425375879, 0.4307716037146747, 0.5092978337779641, 0.8609130349941552, 1.8993506440892816, 2.0655853115022182, 3.9356452273204923, 5.050584012642503, 7.784696901217103, 8.024578504264355, 9.794324040412903, 7.454037219285965, 9.521166197955608, 9.81070876121521, 9.036229569464922, 12.238553334027529, 7.333544259890914, 8.10892827808857, 3.0399629892781377, 2.548339907079935, 2.346908440813422, 0.2297900422126986, 0.12817792827263474, 0.06920959014678374, 0.05302436606143601, 0.10968441711156629, 0.12782818375853822, 0.8097553113475442, 1.688940734602511, 3.090566536411643, 4.902954809367657, 5.967053985223174, 6.8757030274719, 7.7809911500662565, 8.652979284524918, 11.364284846931696, 12.079265881329775, 10.882877279073, 12.467746585607529, 8.065484259277582, 6.567973690107465, 6.752165956422687, 6.5828033443540335, 6.535560479387641, 7.09133718162775, 3.6819095676764846, 6.449774382635951, 5.642123920843005, 3.263203860260546, 3.9431932847946882, 1.4059700374491513, 0.8700539194978774, 0.36493565363343805, 0.5024928145576268, 0.42851918551605195, 0.2311015359009616, 0.23110506852390245, 1.3479548692703247, 3.6275606090202928, 10.973737053573132, 26.545677669346333, 32.91208975017071, 52.9256272315979, 83.39590340852737, 79.91528257727623, 59.045244455337524, 28.14279466867447, 30.69165799766779, 27.67758373171091, 36.06199532747269, 44.34954062104225, 52.77273863554001, 58.471737429499626, 57.81677797436714, 59.90752078592777, 54.62998017668724, 25.756308026611805, 3.844870235770941, 0.4523704759776592, 0.10434023395646363, 0.025709949222800788, 0.04638106081984006, 0.03223537729354575, 0.036377014039317146, 0.05412301550677512, 0.04137891868595034, 0.045423831325024366, 0.06644249995588325, 0.03990221179265063, 0.06688893889077008, 0.01038117097778013, 0.06841942551545799, 0.044451740322983824, 0.029034605686319992, 0.019526348805811722, 0.013567612641054438, 0.04537861226708628, 0.024053362431004643, 0.018818564421962947, 0.07652981570572592, 0.04686508953454904, 0.009314469134551473, 0.020024535842821933, 0.02839557571860496, 0.02242095481051365, 0.014104010078881402, 0.059688429173547775, 0.022181075983098708, 0.05549450812395662, 0.027726763364626095, 0.05031184227846097, 0.04545266005152371, 0.06674629810731858, 0.024346866994164884, 0.03449853807978798, 0.02856915849406505, 0.032972971894196235, 0.13971908163512126, 0.1512902177637443, 0.10685818517231382, 0.27421008911915123, 0.07344354264205322, 0.11884519859449938, 0.13655923947226256, 0.2525194577174261, 0.1342425958137028, 0.12487936386605725, 0.1286709518171847, 0.282026210334152, 0.11323902988806367, 0.16920025984290987, 0.13428328034933656, 0.14617425244068727, 0.12439769518096, 0.11110719584394246, 0.11639912438113242, 0.13962347817141563, 0.1545973465545103, 0.1334146855515428, 0.1917795091867447, 0.25619463238399476, 0.19713878020411357, 0.24989697500132024, 0.17049686604877934, 0.11136607179651037, 0.09026954445289448, 0.15922916441923007, 0.11040302386390977, 0.12994857388548553, 0.11754983177524991, 0.14831607579253614, 0.13013881602091715, 0.29892598162405193, 1.3260144903324544, 15.419621039181948, 59.14702959358692, 84.78783711791039, 93.6388997733593, 91.58932015299797, 83.54968875646591, 74.92305725812912, 68.86358320713043, 61.17061100900173, 39.49641823768616, 37.7084431797266, 53.48080024123192, 104.71224278211594, 114.21361774206161, 115.48129811882973, 89.61603283882141, 57.67633371055126, 40.0875411182642, 17.988014370203018, 8.411750178784132, 3.698293576017022, 1.1955925449728966, 0.4877926502376795, 0.5354389466810971, 0.5629226344171911, 0.7223469985183328, 1.1507726437412202, 2.518102554604411, 4.336219020187855, 8.309147134423256, 12.090908456593752, 11.86175225302577, 15.910975523293018, 11.677729077637196, 15.128455962985754, 14.11369001492858, 16.41853518784046, 17.712681144475937, 15.848745312541723, 15.875106398016214, 18.24628461152315, 20.746744237840176, 17.096295319497585, 3.5796648915857077, 0.7207386754453182, 0.2604203321970999, 0.23760640091495588, 0.12168176865088753, 0.44818025082349777, 1.0434338659979403, 2.140923156403005, 9.31964686140418, 19.494236446917057, 13.542860895395279, 8.318524081259966, 18.80781278014183, 19.40322943031788, 13.59790189191699, 20.559171102941036, 16.64125833660364, 16.005953326821327, 16.201578229665756, 12.60272579267621, 19.08064763993025, 21.91570021212101, 14.946362134069204, 12.881267946213484, 8.23197327554226, 10.986121539026499, 7.916298089548945, 6.075294977054, 3.6020003305748105, 1.9632014678791165, 0.8404809376224875, 0.24912897089961916, 0.49621688725892454, 0.40765331767033786, 0.3424526460003108, 0.6570714886765927, 1.7825916968286037, 5.23722667247057, 15.733176413923502, 40.39074584841728, 46.79669290781021, 79.85012367367744, 100.40122970938683, 88.292016685009, 62.9423875361681, 36.916691064834595, 37.13514894247055, 35.92812851071358, 45.59463880956173, 52.56887577474117, 62.99879550933838, 70.15349239110947, 68.21457043290138, 69.30051416158676, 65.98650678992271, 35.13839788734913, 6.602724250406027, 0.8866971451789141, 0.27618037245702, 0.25995090894866735, 0.1285132157499902, 0.12158908182755113, 0.08524343094904907, 0.15551266697002575, 0.1638766861287877, 0.17700665892334655, 0.15400689386297017, 0.10588269884465262, 0.09329748470918275, 0.15709078463260084, 0.1306720045977272, 0.16195268312003464, 0.10005097661633044, 0.10456203963258304, 0.0769122815108858, 0.15924322069622576, 0.15690564847318456, 0.1638047571759671, 0.1521116416552104, 0.13869159301975742, 0.10250102131976746, 0.11089937965152785, 0.0997874622407835, 0.11490661345305853, 0.057016118662431836, 0.1676597393816337, 0.12553255772218108, 0.19783617637585849, 0.1807709358399734, 0.13137089990777895, 0.0721763403271325, 0.12231216373038478, 0.106462561088847, 0.12068753567291424, 0.10807624988956377, 0.18748725356999785], [0.04787638448760845, 0.018273041350767016, 0.02364705884247087, 0.061422943326761015, 0.032988649763865396, 0.021844361726834904, 0.06761662953067571, 0.06457011331804097, 0.01988896958209807, 0.02017700080614304, 0.03223221945518162, 0.030089401625446044, 0.04347441717982292, 0.06765179248759523, 0.0241612428726512, 0.028102982141717803, 0.005271871996228583, 0.013849146362190368, 0.0239177479306818, 0.020987453899579123, 0.03857758209051099, 0.033276265385211445, 0.05242776467639487, 0.023055819474393502, 0.01543076603411464, 0.04484501179831568, 0.044601398112718016, 0.11560864062630571, 0.016709562551113777, 0.022696278610965237, 0.01156352447651443, 0.012648549945879495, 0.03526708766003139, 0.0525141395337414, 0.031842758908169344, 0.7759099337272346, 7.417347813025117, 29.677011743187904, 51.33421182632446, 62.60896682739258, 72.9051299393177, 62.01608084142208, 49.66536797583103, 46.37010879814625, 32.97928914427757, 32.52269044518471, 31.252264715731144, 65.84465280175209, 81.78997278213501, 69.02933791279793, 53.984151631593704, 45.589421689510345, 39.216616451740265, 21.979667879641056, 7.77915014885366, 2.732651154510677, 1.063457247801125, 0.2847802609903738, 0.029641519213328138, 0.12826008402043954, 0.5560619244351983, 0.3694069746416062, 1.6453617042861879, 2.195248603820801, 1.7650426947511733, 4.06815005466342, 4.090106226503849, 4.953666888177395, 8.095430452376604, 7.374392542988062, 6.835110280662775, 8.293148092925549, 8.298010881990194, 5.437032775953412, 8.730774410068989, 8.507892619818449, 3.120160773396492, 3.2416238682344556, 0.6858643249142915, 0.5567612056620419, 0.10776235852972604, 0.050879047194030136, 0.11736056927475147, 0.0901349782361649, 0.1515873588505201, 0.06964778382098302, 0.18653305945917964, 1.8614014866761863, 1.408119653351605, 1.7878167727030814, 4.207233991473913, 4.307260774075985, 2.887003622017801, 7.073148982599378, 11.792239733040333, 6.891239443793893, 12.461190037429333, 9.805193357169628, 8.424776829779148, 7.455032765865326, 4.65067969635129, 4.937581876292825, 4.978784965351224, 5.237818965688348, 1.747716455720365, 2.3632052913308144, 2.916889493353665, 2.54915876314044, 2.606130768544972, 1.690552441868931, 0.43919533607549965, 0.17066591244656593, 0.06201196367328521, 0.10670317278709263, 0.06436187410145067, 0.041826593296718784, 0.09038212825544178, 0.5950475949794054, 3.485923446714878, 10.950666591525078, 28.6831446737051, 57.54701904952526, 58.33133116364479, 32.84542992711067, 28.198763765394688, 24.171863347291946, 20.252024084329605, 20.278647355735302, 28.718944452703, 31.854302510619164, 36.03082560002804, 40.43660178780556, 49.155617728829384, 48.64939369261265, 49.44369167089462, 36.73715449869633, 14.803261812776327, 3.784681702964008, 0.06765915459254757, 0.020198708625684958, 0.04675536671129521, 0.04640725863282569, 0.04301396278606262, 0.033352532191202044, 0.04991084133507684, 0.014072590329305967, 0.03709701602929272, 0.10268955651554279, 0.03657325272797607, 0.02390474921412533, 0.07572788803372532, 0.029066095012240112, 0.03333403044962324, 0.04136957504670136, 0.02630932995089097, 0.026316706898796838, 0.019594991899793968, 0.09091913889278658, 0.027288141100143548, 0.0674261647509411, 0.07356554429861717, 0.026364579134678934, 0.009995025975513272, 0.01657151380641153, 0.049278063961537555, 0.015606862834829371, 0.01641823248064611, 0.03393276550923474, 0.07675540633499622, 0.024164380301954225, 0.03608523496950511, 0.03837277530692518, 0.05078289825178217, 0.05179977786610834, 0.05076125722553115, 0.03391198537428863, 0.02280795142723946, 0.0403173469385365, 0.039938465706654824, 0.02686347306735115, 0.008402886360272532, 0.017970699664147105, 0.05382247909437865, 0.04100256446690764, 0.05384681782743428, 0.06727539745043032, 0.04245277668815106, 0.04329472467361484, 0.14764716324862093, 0.038763601405662484, 0.009411691407876788, 0.016462130515719764, 0.12580381269799545, 0.044185342703713104, 0.008711247792234644, 0.014582090479962062, 0.09530108305625618, 0.03226628774427809, 0.01641470913455123, 0.05164932968909852, 0.02423601610644255, 0.026961813200614415, 0.06205747959029395, 0.07582240054034628, 0.04945328502799384, 0.05294685244734865, 0.021543964467127807, 0.0036638330266214325, 0.021418895885290112, 0.04183882017969154, 0.01777021218003938, 1.1703598801977932, 7.606316898018122, 33.23192238807678, 61.363408863544464, 72.17816054821014, 84.58472281694412, 72.73721694946289, 62.46132954955101, 58.49630691111088, 43.91497313976288, 42.671645656228065, 28.51640772074461, 49.59371902048588, 71.46977216005325, 75.95793172717094, 75.20063996315002, 67.86647871136665, 52.12760925292969, 28.70034445077181, 11.858544275164604, 4.063507178798318, 1.3958305190317333, 0.3106426529120654, 0.1252370048314333, 0.21916527795838192, 0.9985144576057792, 1.940640415996313, 2.804475612938404, 4.879128662869334, 5.422265343368053, 7.494201064109802, 9.421521294862032, 8.466246854513884, 9.554744996130466, 6.363363694399595, 8.494522087275982, 9.287988860160112, 10.61234699562192, 9.442888498306274, 10.902535524219275, 11.470452100038528, 3.67281261831522, 2.168741226196289, 0.6242842948995531, 0.2962199627654627, 0.07649321298231371, 0.028803337627323344, 0.10092605036334135, 0.13119723735144362, 0.1500112153007649, 0.17370767891407013, 0.6717002287041396, 1.658835425041616, 2.7039923798292875, 4.576713340356946, 4.1625455394387245, 4.242350282147527, 6.310614449903369, 7.661347920075059, 8.836020212620497, 9.172044731676579, 5.733766928315163, 12.292560786008835, 8.444632664322853, 9.519312847405672, 10.633125230669975, 8.806621190160513, 11.75102999433875, 8.664323575794697, 8.209016807377338, 8.947090152651072, 5.723926881328225, 7.366726454347372, 5.5950292479246855, 5.090468097478151, 3.8750152057036757, 2.412140965461731, 1.0438210889697075, 0.2573665726231411, 0.37018352828454226, 0.0682777792098932, 0.08505801277351566, 0.6911767367273569, 3.122091069817543, 12.250519841909409, 27.09867149591446, 58.220852091908455, 68.04698422551155, 43.324458226561546, 32.87173591554165, 27.834726199507713, 26.377449296414852, 26.707383692264557, 35.51135927438736, 38.70889529585838, 45.01877970993519, 49.41699430346489, 57.99477182328701, 57.79364861547947, 59.42430451512337, 43.32940176129341, 17.792881540954113, 4.70254453830421, 0.08975724733318202, 0.011925314975087531, 0.04336051977588795, 0.02285858259710949, 0.05852467111253645, 0.024217488389695063, 0.019968787564721424, 0.049492982507217675, 0.07390403043245897, 0.009449929639231414, 0.026045988124678843, 0.010987317309627542, 0.04238959023496136, 0.09666686484706588, 0.07337264527450316, 0.030729576355952304, 0.011080261101596989, 0.013355201626836788, 0.014928760647308081, 0.058245378677384, 0.012480261466407683, 0.030408328457269818, 0.018828537031367887, 0.02622173426061636, 0.02922009622125188, 0.04909302057058085, 0.032838294355315156, 0.0316392879904015, 0.049455685875727795, 0.016225721228693146, 0.08846404758514836, 0.021088467619847506, 0.008122586459649028, 0.04536543172434904, 0.06516402441775426, 0.04140077864576597, 0.05352269596187398, 0.007597673293275875, 0.2324087845045142, 0.14482038212008774, 0.08984672807855532, 0.27352559147402644, 0.19046503206482157, 0.10307827120414004, 0.17193707783007994, 0.17520926630822942, 0.1523918320890516, 0.13949624437373132, 0.13094527821522206, 0.10399411854450591, 0.2630745491478592, 0.2513344556791708, 0.11413866872317158, 0.09036863601068035, 0.22519280842971057, 0.07812638315954246, 0.10140594531549141, 0.1255019663949497, 0.1867600082186982, 0.09497569582890719, 0.08775816124398261, 0.13292693125549704, 0.09814946068217978, 0.15691915556089953, 0.17594659002497792, 0.21438474854221568, 0.13537947699660435, 0.19868443632731214, 0.15785001654876396, 0.08514290704624727, 0.12798404961358756, 0.14907680684700608, 0.13861139654181898, 2.113535413518548, 12.731051556766033, 46.62499912083149, 75.51607623696327, 85.34331411123276, 94.66805934906006, 78.82412552833557, 66.19304090738297, 61.806951463222504, 46.482381373643875, 44.76495333015919, 40.89548036456108, 79.46473315358162, 93.47676247358322, 81.57595306634903, 62.940233051776886, 56.37834995985031, 48.67474973201752, 28.390805460512638, 9.966539349406958, 4.475681036710739, 1.2223570025525987, 0.5874874850269407, 0.3289289044914767, 0.3540895809419453, 0.6796434649731964, 1.433365736156702, 4.2566522397100925, 6.2075060326606035, 8.665253575891256, 14.071509428322315, 14.160486403852701, 16.38579424470663, 19.90334529429674, 13.898879941552877, 17.204452715814114, 22.154701687395573, 20.636318363249302, 18.509994260966778, 22.5229874253273, 21.716676391661167, 18.634031005203724, 11.904005035758018, 4.422864345833659, 2.1884517185389996, 0.43811640178319067, 0.20846340456046164, 0.44941191910766065, 0.39367098826915026, 0.3907398018054664, 0.98083715303801, 2.128772595897317, 6.150292027741671, 8.190441504120827, 8.046288639307022, 13.72024867683649, 13.860633093863726, 11.807566210627556, 18.512393832206726, 23.633949011564255, 18.879537731409073, 26.386599205434322, 23.446432873606682, 18.32833930850029, 16.999586708843708, 15.927480887621641, 16.677854172885418, 14.29782623425126, 16.37344680726528, 9.601173754781485, 11.107758712023497, 10.319444462656975, 9.530922174453735, 9.037527199834585, 4.438820164650679, 4.037915552034974, 2.105063055641949, 1.002307366579771, 0.39330291270744056, 0.35107640200294554, 0.21996538736857474, 0.38401600322686136, 0.8765680762007833, 4.6403480507433414, 14.15037989616394, 36.980611234903336, 62.60309614241123, 68.24766665697098, 43.53008799254894, 41.81170620024204, 37.94366575777531, 32.53697767853737, 32.60648734867573, 42.66491241753101, 46.39396391808987, 51.004609912633896, 56.06698326766491, 68.45457315444946, 68.78841564059258, 70.54833680391312, 52.933211624622345, 25.29362205415964, 7.112355278804898, 0.5483049375470728, 0.13938134507043287, 0.15001421357737854, 0.15661117911804467, 0.1724954103701748, 0.1459934504237026, 0.13352066423976794, 0.2232020121300593, 0.1449154067086056, 0.2725130645558238, 0.0735408604668919, 0.09557479454088025, 0.17733966058585793, 0.1802612585015595, 0.15548272873274982, 0.15757947403471917, 0.06924460467416793, 0.10950642783427611, 0.09870512891211547, 0.17042737134033814, 0.2742067049257457, 0.14651690202299505, 0.09552607254590839, 0.09178382999380119, 0.10481173521839082, 0.12462666258215904, 0.1568294150638394, 0.17863530199974775, 0.09896691408357583, 0.07251569477375597, 0.13232712750323117, 0.13045120082097128, 0.10327735231840052, 0.13365741237066686, 0.11321351485094056, 0.14880089118378237, 0.1627221269882284, 0.06427576270652935], [0.02486574881913839, 0.09928928076988086, 0.06567745702341199, 0.06801209776313044, 0.04108892448130064, 0.03048524278710829, 0.019385691412026063, 0.06030207769072149, 0.0889734503289219, 0.03128205891698599, 0.00773091524024494, 0.04610711184795946, 0.05277435135212727, 0.036472584106377326, 0.006255457010411192, 0.018358405031904113, 0.02032741002039984, 0.09162556700175628, 0.027240168674325105, 0.015218935750453966, 0.04709958222520072, 0.030494643942802213, 0.016101747314678505, 0.049242307286476716, 0.03852755391562823, 0.044480980941443704, 0.02648057125043124, 0.023896442726254463, 0.008656758382130647, 0.022638021873717662, 0.019733916378754657, 0.05732690784498118, 0.01381957548801438, 0.043579861521720886, 0.12588711135322228, 5.412890296429396, 21.839016526937485, 26.339907310903072, 48.00052151083946, 68.08131158351898, 56.65955767035484, 50.980333015322685, 46.90117210149765, 34.32570889592171, 31.206009797751904, 53.26341390609741, 70.80616816878319, 66.83434009552002, 59.0964163094759, 39.60733808577061, 27.58289661258459, 28.56422245502472, 15.566547755151987, 7.8938783425837755, 3.606741763651371, 0.9746779210399836, 0.201436483184807, 0.044902301888214424, 0.3283217386342585, 0.12038706234307028, 1.3622478023171425, 1.8542107287794352, 1.881400526035577, 4.2353325337171555, 1.8874300899915397, 4.229924473911524, 5.176685471087694, 6.420357786118984, 6.8730023223906755, 4.932950874790549, 4.994896100834012, 6.0227504465729, 8.548482991755009, 7.840182473883033, 12.347140107303858, 6.05288615450263, 4.1205064952373505, 0.13418794405879453, 0.12610956269782037, 0.1838337050867267, 0.046714381605852395, 0.023457130264432635, 0.07505462650442496, 0.022785353030485567, 0.11897691496415064, 0.06518293434055522, 2.5054136104881763, 2.444848660379648, 4.078262262046337, 3.2631791615858674, 2.60369794908911, 6.340369703248143, 4.54368551261723, 2.029074258171022, 9.760185722261667, 9.470243230462074, 4.817173462361097, 11.321954168379307, 5.284704649820924, 5.089660165831447, 3.594981632195413, 2.8589939000084996, 5.51275416277349, 4.63255419395864, 4.2680649273097515, 8.496014457195997, 5.676712514832616, 4.204846294596791, 6.332918303087354, 3.59372912440449, 2.2982665384188294, 2.5982445292174816, 0.8921807259321213, 0.487650009454228, 0.19998191826744005, 0.09897463241941296, 0.17286746384343132, 0.12349716576864012, 0.33151914831250906, 1.880526216700673, 8.872147724032402, 16.514500938355923, 30.049921832978725, 33.12985606491566, 46.334493309259415, 34.637998938560486, 34.39858518540859, 25.845669731497765, 21.801396645605564, 25.639859475195408, 27.80812192708254, 37.26589992642403, 43.42081345617771, 51.57519109547138, 58.38589243590832, 45.20642124116421, 37.41972707211971, 12.599969040602446, 1.6604683874174953, 0.049739631576812826, 0.039177508297143504, 0.006813814597990131, 0.04241545779223088, 0.01850265070970636, 0.028676751353486907, 0.0181435068952851, 0.010687626017897855, 0.005182862050787662, 0.06928897768375464, 0.08890533601515926, 0.04821901551622432, 0.028723647665174212, 0.02394003648078069, 0.05025649290473666, 0.02447087987093255, 0.04377201468741987, 0.019832965263049118, 0.02961516183859203, 0.03752792552404571, 0.04699703596998006, 0.07492893637390807, 0.018497463097446598, 0.0640557159204036, 0.017774590851331595, 0.020303171477280557, 0.029715949203819036, 0.09559446887578815, 0.07619296971824951, 0.02711275861656759, 0.060690595710184425, 0.0183018608004204, 0.030112066815490834, 0.04204547862173058, 0.05822033119329717, 0.07930578198283911, 0.018679886707104743, 0.02977700569317676, 0.0633022801775951, 0.05223918124102056, 0.043960256734862924, 0.006191515885802801, 0.05799269594717771, 0.013405747449724004, 0.011831073352368549, 0.04196579793642741, 0.0694204491446726, 0.022798361023887992, 0.07959267401020043, 0.038335671633831225, 0.032022607265389524, 0.06650950104813091, 0.06498270289739594, 0.03225540785933845, 0.012700855586444959, 0.033336754131596535, 0.01138595358497696, 0.02959946170449257, 0.03949715872295201, 0.03579689575417433, 0.04583302557875868, 0.038653882293147035, 0.011422022889746586, 0.030307407505461015, 0.014000706833030563, 0.010286827309755608, 0.06597500629140995, 0.02615177942061564, 0.03382794828212354, 0.049731827893992886, 0.07595111863338389, 0.15449642931343988, 5.666693402454257, 25.95870416611433, 39.985269606113434, 57.525223419070244, 78.46567556262016, 66.58248201012611, 61.175733134150505, 56.69955812394619, 45.48246882855892, 35.914278253912926, 52.693045511841774, 58.14848877489567, 65.39323702454567, 69.40946951508522, 51.62084564566612, 30.80890640616417, 30.50627924501896, 19.14085540920496, 9.62928369641304, 3.608597726561129, 1.2098814407363534, 0.33553853107150644, 0.5084769590757787, 0.9686412918381393, 0.9133274818304926, 2.0829076319932938, 3.726075072772801, 4.153568521142006, 8.378280624747276, 6.953702392056584, 7.88475408218801, 8.180637080222368, 11.816616374999285, 9.935748651623726, 10.474503692239523, 7.940251054242253, 7.999154068529606, 10.328100398182869, 12.068378515541553, 7.261823108419776, 9.882706347852945, 6.9954597763717175, 1.1878036754205823, 0.32811696524731815, 0.14175097807310522, 0.09402066309121437, 0.21490646351594478, 0.14931715879356489, 0.07556333162938245, 0.10350581505917944, 0.2942111768061295, 0.9175545768812299, 2.7585736010223627, 3.093587374314666, 2.356059062294662, 1.3533828780055046, 4.4396119471639395, 5.2626249846071005, 6.594028891995549, 5.531531805172563, 6.452438989654183, 6.31485597230494, 11.501884013414383, 8.52444738149643, 6.015445338562131, 8.313452303409576, 8.205657787621021, 9.58013903349638, 8.782768920063972, 11.329402718693018, 11.079349536448717, 8.889411147683859, 8.907747063785791, 7.1466669626533985, 9.108533039689064, 5.801781853660941, 3.3645536843687296, 4.5353929325938225, 2.3500515846535563, 1.26938660396263, 0.40791102102957666, 0.31473972368985415, 0.12967908522114158, 0.37447999930009246, 2.106888620182872, 10.775668881833553, 21.4353109896183, 35.48949904739857, 34.26275007426739, 41.73126071691513, 38.0984428524971, 36.44286409020424, 31.044731251895428, 28.708618506789207, 34.477419555187225, 34.12202462553978, 43.01349051296711, 52.25987255573273, 60.376301631331444, 67.33714431524277, 52.04095870256424, 43.52558143436909, 15.54589681327343, 1.9572267634794116, 0.11143827534397133, 0.11687113030347973, 0.034987895414815284, 0.04844256895012222, 0.07527561581810005, 0.044199491749168374, 0.0392582242784556, 0.11206466282601468, 0.06276959626120515, 0.06082879102905281, 0.034602034284034744, 0.06414544157451019, 0.0054941410508035915, 0.03007507446454838, 0.050281952280784026, 0.03309758962132037, 0.02338819958822569, 0.06547225319081917, 0.016099175772978924, 0.04572158468363341, 0.07687258403166197, 0.0547317361633759, 0.030736053449800238, 0.07029381595202722, 0.02107092510414077, 0.024159639833669644, 0.022969195997575298, 0.13313856208696961, 0.02559324278990971, 0.03049399827432353, 0.020294813039072324, 0.023522769515693653, 0.01816533531382447, 0.05004061327781528, 0.026450497571204323, 0.041363478303537704, 0.04224529446219094, 0.13529484247555956, 0.1529645622940734, 0.1505855337018147, 0.10024633214925416, 0.17150262458017096, 0.12065255825291388, 0.09173021724564023, 0.20093600847758353, 0.3185342950746417, 0.10445226856973022, 0.13976154732517898, 0.13510087475879118, 0.11783321344410069, 0.1987704067141749, 0.2300406209542416, 0.13146608776878566, 0.18731577292783186, 0.1942710325238295, 0.1405402531963773, 0.10913306818110868, 0.09626712184399366, 0.10791950087877922, 0.07224924891488627, 0.1662240398582071, 0.14744715444976464, 0.11066019287682138, 0.13627863343572244, 0.12256873902515508, 0.13659334857948124, 0.14317515946459025, 0.15810549346497282, 0.16034848638810217, 0.0777614171965979, 0.21605266607366502, 0.9016064764000475, 8.797406684607267, 35.23332819342613, 49.54421907663345, 73.52978602051735, 89.46649566292763, 76.2893195450306, 69.46663364768028, 63.4092228859663, 48.29470172524452, 46.2735141813755, 67.32547134160995, 83.98468181490898, 79.04028072953224, 73.2353550195694, 53.360316306352615, 41.699277833104134, 38.66422489285469, 23.871096186339855, 10.76162863522768, 4.9082764238119125, 1.3700365531258285, 0.5241619236767292, 0.3885838034329936, 1.1784201976843178, 0.8580202027224004, 3.36957274004817, 5.905142957344651, 9.47106208652258, 16.583583131432533, 13.480525240302086, 14.909053836017847, 16.466163732111454, 15.686105489730835, 16.506585963070393, 17.416175454854965, 15.767455324530602, 18.983716741204262, 21.882670484483242, 19.16443694382906, 21.83568600565195, 17.529318183660507, 10.7668980024755, 2.057649912312627, 1.500119366683066, 0.2773229236481711, 0.4596743668662384, 0.18512183596612886, 0.29416035453323275, 0.21317055041436106, 0.577942575328052, 0.8833577181212604, 4.17681329883635, 4.763691807165742, 6.123949941247702, 6.938939709216356, 7.342226793989539, 17.07192152738571, 15.063354056328535, 11.495756842195988, 19.435835480690002, 18.214381523430347, 15.902501977980137, 25.04607103765011, 16.176801659166813, 14.240859691053629, 13.802832495421171, 11.456624642014503, 16.05786044150591, 18.330489993095398, 15.34165682271123, 21.762422136962414, 15.419012121856213, 14.0504015609622, 16.37313712388277, 13.702610023319721, 8.59357612207532, 6.566544491797686, 5.146837122738361, 1.8919917452149093, 1.2373042129911482, 0.43446337280329317, 0.571687932824716, 0.25644598295912147, 0.7254924578592181, 2.5008391309529543, 11.113427057862282, 21.108256839215755, 39.67319995164871, 45.95429711043835, 62.693421095609665, 47.19670504331589, 45.999400690197945, 38.96296486258507, 35.077741742134094, 40.18911346793175, 41.2492223829031, 53.09359721839428, 60.70247232913971, 67.81458109617233, 75.70135429501534, 64.25965905189514, 54.70309965312481, 22.202715910971165, 3.3671933552250266, 0.2123160712653771, 0.21630293311318383, 0.13972184242447838, 0.16390456119552255, 0.19975384144345298, 0.1372292949235998, 0.11827479131170548, 0.19559972919523716, 0.18802158505422994, 0.18549801578046754, 0.15420630894368514, 0.1671375791192986, 0.07927129438030533, 0.11199354281416163, 0.17256174352951348, 0.07734925064141862, 0.13420035276794806, 0.18866142025217414, 0.2142656486830674, 0.1247136274469085, 0.22516858472954482, 0.17270425072638318, 0.08862054426572286, 0.2171977999387309, 0.054651023892802186, 0.11217846375075169, 0.19032173819141462, 0.2551186369964853, 0.13963251753011718, 0.15099695068784058, 0.16915298503590748, 0.10462282894877717, 0.1261003452236764, 0.1034813464502804, 0.15184593794401735, 0.18252580339321867, 0.14992683310993016], [0.017193980893353, 0.02689959896088112, 0.037451866519404575, 0.06759608688298613, 0.03108342494670069, 0.02070407965220511, 0.017759003894752823, 0.02996025865286356, 0.05845584804774262, 0.026316677212889772, 0.008296771302411798, 0.018905293654825073, 0.029928789736004546, 0.01582905628310982, 0.04071404713613447, 0.0434684020729037, 0.12171945490990765, 0.06547015291289426, 0.03166521491948515, 0.051371733061387204, 0.03573990623408463, 0.014936714615032542, 0.08381556850508787, 0.05107172728457954, 0.061157681193435565, 0.031136783509282395, 0.03083414867433021, 0.13907345768529922, 0.05847581924172118, 0.022064974400564097, 0.030576443459722213, 0.01539511604278232, 0.04251139151165262, 0.41810379596427083, 3.9112759474664927, 18.48778635263443, 28.03655046969652, 38.31029288470745, 70.76826140284538, 65.00457867980003, 68.3625116944313, 51.68465942144394, 35.55837795138359, 29.169214591383934, 33.71062830090523, 50.374504923820496, 65.40875539183617, 70.53233206272125, 59.289757534861565, 30.533542782068253, 31.905823945999146, 27.876147776842117, 9.841263871639967, 3.270513005554676, 0.33743041392881423, 0.09201491993735544, 0.13670418091351166, 0.27232254040427506, 0.5663439352065325, 0.582960027968511, 1.5157828386873007, 4.2009534034878016, 1.3306209119036794, 6.644418938085437, 5.587672367691994, 6.224810779094696, 6.485678181052208, 6.9616710394620895, 5.80163698643446, 4.489971119910479, 5.259880581870675, 3.6479828506708145, 6.213742922991514, 6.323308618739247, 2.1888592466712, 9.856930430978537, 0.6233628443442285, 0.3325219976250082, 0.1353837814531289, 0.11134538814076222, 0.10299024506821297, 0.19094846706138924, 0.11167123549967073, 0.052612114159273915, 0.033277964903390966, 1.3507331139408052, 7.799714170396328, 14.01575691998005, 8.455558028072119, 7.795573817566037, 1.6624528309330344, 0.8290252648293972, 2.9849450290203094, 5.5881378427147865, 2.227331707254052, 4.526069657877088, 2.569315731525421, 7.824678355827928, 4.848767817020416, 5.174627406522632, 9.27084133028984, 6.7689458560198545, 11.267900168895721, 6.706484332680702, 12.232721596956253, 8.70966274291277, 4.763255305588245, 7.726249862462282, 3.8878874899819493, 7.90769012644887, 5.589022245258093, 4.136174954473972, 2.165658879093826, 1.4940062072128057, 0.6382138724438846, 0.35810394678264856, 0.06550968711962923, 0.019091845460934564, 0.1355908703408204, 0.1795828464673832, 0.8077139302622527, 6.802301416173577, 17.041344568133354, 39.176775589585304, 49.43602368235588, 38.5227394849062, 34.32499833405018, 24.297473207116127, 21.338792368769646, 20.71950349956751, 28.048018254339695, 29.099114052951336, 34.575306102633476, 41.32814794778824, 50.023650750517845, 57.43486046791077, 47.95014761388302, 31.798272617161274, 5.764578999951482, 0.40914800309110433, 0.044957272766623646, 0.040094535652315244, 0.026985727054125164, 0.02863356021407526, 0.03582578014174942, 0.0067221881181467324, 0.07573785507702269, 0.02891273019486107, 0.06445896928198636, 0.03818480785412248, 0.009365275636810111, 0.06646814857958816, 0.05083850737719331, 0.0018208539904662757, 0.051228357551735826, 0.014116340862528887, 0.05644267599564046, 0.03006252289196709, 0.009640841562941205, 0.022250192196224816, 0.059214044667896815, 0.03594960748159792, 0.026329121174057946, 0.006590671200683573, 0.013477206066454528, 0.03996370614913758, 0.07308630985789932, 0.04462978526134975, 0.00373798656710278, 0.06351556599838659, 0.10755588562460616, 0.01607609498023521, 0.01982298523216741, 0.09002059101476334, 0.05451382676255889, 0.03170753589074593, 0.027270307291473728, 0.049913590992218815, 0.027934006247960497, 0.027676490281010047, 0.023031619894027244, 0.048633022597641684, 0.011921416844415944, 0.02857852439774433, 0.033916486499947496, 0.05346716476196889, 0.04845895557082258, 0.10068175761261955, 0.025264070609409828, 0.0306326611462282, 0.025904208232532255, 0.04369951057014987, 0.0773450946144294, 0.017306416266364977, 0.03887293831212446, 0.046794641166343354, 0.09593269525794312, 0.06568592492840253, 0.03437270694121253, 0.025276418091380037, 0.055849525597295724, 0.022885580074216705, 0.04390449175843969, 0.06313925259746611, 0.05922666117839981, 0.04432460671523586, 0.025869967394100968, 0.046923103218432516, 0.012530790590972174, 0.5571991321630776, 3.850220823660493, 19.382815025746822, 34.341280460357666, 43.89097362756729, 80.97290262579918, 75.71225970983505, 77.42206916213036, 62.10249960422516, 46.214028373360634, 37.458788976073265, 42.37027242779732, 57.22320802509785, 75.54257601499557, 81.42754822969437, 63.3949888497591, 32.67802990972996, 28.47269296646118, 24.41781274974346, 8.701743967831135, 3.47457701805979, 0.49217862426303327, 0.2592354192165658, 0.41452765348367393, 0.5949024902656674, 0.7289480755571276, 3.7488764617592096, 5.95379744656384, 6.775946980342269, 6.135526970028877, 4.969605132937431, 10.627007558941841, 8.732878547161818, 10.451413281261921, 15.910387504845858, 11.56754544004798, 10.676346011459827, 9.48340192437172, 6.916978787630796, 7.845142632722855, 9.331319835036993, 7.193664265796542, 7.560265744104981, 6.032683588564396, 1.171963750384748, 0.7557584275491536, 0.2483649892383255, 0.5422706238459796, 0.8363151142839342, 0.20434527163160965, 0.1254302600864321, 0.09655727189965546, 0.8650271454825997, 6.567694405093789, 10.628376435488462, 8.020802456885576, 5.176771441474557, 1.6545004514046013, 0.8673867594916373, 4.182514892891049, 3.503289702348411, 3.8147946121171117, 5.978336054831743, 4.07484719529748, 7.048985604196787, 4.5451840572059155, 11.75439566373825, 12.483612634241581, 9.973150994628668, 11.103344298899174, 6.728694615885615, 11.882711928337812, 11.675357054919004, 8.134460058063269, 12.620135508477688, 7.295436579734087, 10.504469834268093, 9.364634547382593, 7.227339958772063, 5.931766228750348, 3.4149822033941746, 2.7260034112259746, 1.8297248426824808, 0.8541122905444354, 0.1707006004289724, 0.33927845070138574, 0.30859931255690753, 1.325807876419276, 6.973911607638001, 18.186019845306873, 33.17741431295872, 47.3039884865284, 37.0688197016716, 30.1491155102849, 24.64638188481331, 29.149957224726677, 27.716130763292313, 32.108128890395164, 37.03873671591282, 41.927250400185585, 48.500859662890434, 59.33942086994648, 66.69662788510323, 54.3192670494318, 35.517161563038826, 6.911458158865571, 0.5924491875339299, 0.022170574593474157, 0.021358280973799992, 0.08953779426519759, 0.016336854132532608, 0.016363235627068207, 0.03674419902381487, 0.08293465405586176, 0.047761485184310004, 0.002679512590475497, 0.024394013780693058, 0.035769510504906066, 0.11561492661712691, 0.08756430484936573, 0.03527078726619948, 0.08141319194692187, 0.012765837109327549, 0.008699815934960498, 0.05192227676161565, 0.023347806345555, 0.05815472162794322, 0.04296722974686418, 0.02588942279544426, 0.06261459871893749, 0.024455391248920932, 0.0271235123364022, 0.02980832061439287, 0.07469438060070388, 0.03094159681495512, 0.027839523427246604, 0.04948464818880893, 0.03127909774775617, 0.04749993378936779, 0.04639030426915269, 0.07356237532803789, 0.08552695362595841, 0.03798337042098865, 0.07934766879770905, 0.05725338327465579, 0.1831056285300292, 0.17233431979548186, 0.09443303002626635, 0.13547996379202232, 0.16322104318533093, 0.1531192407128401, 0.18230992747703567, 0.08668562426464632, 0.273120675701648, 0.1657399072428234, 0.13579631166066974, 0.1549990859348327, 0.10530005354667082, 0.10857836474315263, 0.2536978101124987, 0.16893341322429478, 0.10039911809144542, 0.17986616876441985, 0.19222838978748769, 0.1559702306985855, 0.20540581550449133, 0.17373268929077312, 0.11822990622022189, 0.09446565483813174, 0.15091296925675124, 0.18046249926555902, 0.1706707660923712, 0.08041967885219492, 0.23090391681762412, 0.18738323415163904, 0.1812488492578268, 0.8271812950260937, 6.150711430236697, 31.363857127726078, 47.40060970187187, 62.218526378273964, 95.9065192937851, 83.41789662837982, 87.65352174639702, 67.84684896469116, 51.48502953350544, 44.180559888482094, 48.65711107850075, 63.104395642876625, 77.06662863492966, 82.66869083046913, 72.74212628602982, 45.70553205907345, 41.69865846633911, 34.32280585169792, 12.76574844494462, 4.024962522089481, 0.6112573470454663, 0.29701990890316665, 0.5231145455036312, 1.1835477850399911, 1.4175463537685573, 3.9160563284531236, 8.818603847175837, 11.47472022101283, 9.931362736970186, 16.895046718418598, 13.667808640748262, 18.593112900853157, 16.837848387658596, 20.945321582257748, 19.42249819636345, 15.616146493703127, 15.427419170737267, 17.981989793479443, 17.07852177321911, 19.785637110471725, 13.845242019742727, 17.179843336343765, 8.685092311352491, 0.7631045021116734, 0.4262112843571231, 0.2013866405468434, 0.46746650186832994, 0.863627870567143, 0.5530477955471724, 0.20957008033292368, 0.29951702803373337, 1.1037742719054222, 6.824499825015664, 12.11757542565465, 7.870418876409531, 8.918879516422749, 5.384353827685118, 6.207884112372994, 10.70767343044281, 12.637353334575891, 9.575293343514204, 12.34004208818078, 9.191727675497532, 16.04091715067625, 15.37561560049653, 17.435221932828426, 22.295721620321274, 16.770808584988117, 22.44247544556856, 17.61150397360325, 21.65439773350954, 18.257547207176685, 14.075680654495955, 16.94888412952423, 12.37947067245841, 20.72089232504368, 11.889603808522224, 11.502765566110611, 10.447607785463333, 4.760224018245935, 2.6753288554027677, 1.3056912808679044, 0.7329418393783271, 0.6030875479336828, 0.5679330218117684, 0.5912922089919448, 1.5929698781110346, 9.28228821605444, 22.539584934711456, 47.86132737994194, 63.42745430767536, 52.471471801400185, 49.80998441576958, 37.61798903346062, 32.578479051589966, 31.568139865994453, 40.21573483943939, 42.56012164056301, 48.57138007879257, 57.44300723075867, 67.32656568288803, 76.52193546295166, 65.69540441036224, 43.46063531935215, 11.5999766997993, 1.4461811422370374, 0.19863153604092076, 0.13356479234062135, 0.1328795080189593, 0.10304939423804171, 0.14291352272266522, 0.15798563661519438, 0.20891025167657062, 0.14018418558407575, 0.17359334364300594, 0.1762911246623844, 0.2536872122436762, 0.2067927856114693, 0.2579954091925174, 0.10185066246776842, 0.17288986186031252, 0.12085840775398538, 0.1545269464259036, 0.11283529413049109, 0.10621905501466244, 0.2016388371703215, 0.15161903371335939, 0.1617303950479254, 0.16984043642878532, 0.1142330328002572, 0.12673379795160145, 0.16252464149147272, 0.12544406403321773, 0.1757390410057269, 0.25056449230760336, 0.253540652920492, 0.12396684876875952, 0.11312469461699948, 0.187230663432274, 0.2619002934079617, 0.14230052358470857, 0.09882384285447188], [0.03767175003304146, 0.07684465701458976, 0.037992855068296194, 0.06843425362603739, 0.04722829289676156, 0.041969879748648964, 0.009663559631007956, 0.07969219601363875, 0.1024624147976283, 0.03146312810713425, 0.05897249786357861, 0.03652583691291511, 0.034393427704344504, 0.04057857549923938, 0.04138930504268501, 0.0420634905458428, 0.05883633602934424, 0.03992344092694111, 0.033730244540493004, 0.07492599746910855, 0.0633477812516503, 0.12006653618300334, 0.10907431234954856, 0.043714550192817114, 0.04293313919333741, 0.10122319145011716, 0.016624855670670513, 0.12726149463560432, 0.06509743892820552, 0.08442851569270715, 0.032118028902914375, 0.013982775617478183, 0.03238655648601707, 0.8075460267718881, 13.23647478595376, 27.356635853648186, 44.19646583497524, 68.7664832174778, 63.265985772013664, 60.44591009616852, 52.63696052134037, 37.35546492040157, 33.93950141966343, 30.4547331109643, 20.94075232744217, 33.968995437026024, 28.264010064303875, 37.093408182263374, 48.642994835972786, 45.917739272117615, 19.22944575548172, 5.021356455981731, 1.5993758593685925, 0.4515827901195735, 0.06390247726812959, 0.3547799267107621, 0.2578385191736743, 0.5751431349199265, 0.517268143594265, 2.606946062296629, 2.975132055580616, 3.5756568191573024, 3.72036540415138, 2.217630590312183, 5.171267436817288, 4.713211040943861, 5.655553350225091, 13.162866085767746, 8.419070485979319, 7.198004582896829, 5.352154355496168, 2.967547425068915, 4.84212719835341, 8.296326622366905, 4.317479375749826, 4.908038936555386, 7.763757174834609, 2.332242652773857, 0.6298691045958549, 0.5008390720468014, 0.6327130144927651, 0.6879293359816074, 0.2558160776970908, 0.2776186843402684, 1.6517124697566032, 12.470144256949425, 20.648576505482197, 23.879138454794884, 21.012891456484795, 14.305630065500736, 4.959151893854141, 1.1348880711011589, 1.8964249198324978, 3.546457285992801, 4.523719009011984, 5.5597063433378935, 2.9409384028986096, 6.993619725108147, 5.1213860884308815, 4.539892366155982, 5.011878339573741, 6.444732528179884, 5.982465008273721, 3.247621371410787, 8.686944711953402, 8.661653269082308, 7.4696952290833, 9.244446996599436, 5.679480666294694, 5.332342218607664, 7.256092540919781, 2.621765029616654, 7.5915974378585815, 4.085106644779444, 3.0246942210942507, 1.1703266319818795, 0.3061458613956347, 0.35624103737063706, 0.0489820175425848, 0.08077167949522845, 0.2833415335044265, 1.2147667910903692, 6.784978145733476, 18.086332194507122, 28.39420437812805, 44.12422031164169, 29.401089549064636, 21.279861330986023, 20.586330145597458, 21.864435262978077, 20.071182288229465, 27.765072137117386, 29.042878970503807, 28.272920586168766, 36.42433628439903, 48.55773501098156, 56.05253644287586, 47.42311209440231, 17.056148573756218, 3.4131010668352246, 0.29133482021279633, 0.09809376992052421, 0.08545306540327147, 0.049211196455871686, 0.01610762697964674, 0.050814884816645645, 0.07858803612180054, 0.09748710130224936, 0.02114357950631529, 0.04879563828581013, 0.024313247704412788, 0.053408037856570445, 0.06318991159787402, 0.0654079312516842, 0.02461503834638279, 0.022909989311301615, 0.08818321148282848, 0.041734960323083214, 0.18835350318113342, 0.08096993682556786, 0.07258153811562806, 0.09579813646269031, 0.0530063541373238, 0.05159238098713104, 0.039437044761143625, 0.02741678683378268, 0.006594972874154337, 0.017915871649165638, 0.011341369063302409, 0.04880198364844546, 0.015248054842231795, 0.0037756795518362196, 0.027247018697380554, 0.019474940236250404, 0.07891147150075994, 0.06558106688316911, 0.06889387310366146, 0.018928411554952618, 0.031229934174916707, 0.034970707274624147, 0.032529364252695814, 0.05700314592104405, 0.07108812176738866, 0.03534107607265469, 0.08046230039326474, 0.01060621056240052, 0.062031148190726526, 0.027364335546735674, 0.09219359199050814, 0.03650332015240565, 0.01440520143660251, 0.03578923307941295, 0.036109696156927384, 0.04135654293349944, 0.05471969852806069, 0.04596058221068233, 0.013844840977981221, 0.04857552470639348, 0.044903211019118316, 0.06417923897970468, 0.04732377019536216, 0.05932875472353771, 0.05443140384159051, 0.034221190071548335, 0.11314568255329505, 0.0407928966160398, 0.08210795349441469, 0.014000126102473587, 0.04048080867505632, 1.0519275977276266, 13.49591726437211, 37.59098008275032, 50.52130624651909, 76.59910932183266, 76.31739243865013, 69.62703824043274, 65.35678938031197, 48.04594807326794, 38.818257227540016, 35.650462210178375, 28.97684421390295, 39.03032384812832, 44.01650749146938, 54.758679270744324, 61.22982323169708, 43.81460152566433, 20.29367744922638, 5.592529457062483, 2.0924729062244296, 0.6361483270302415, 0.23431542125763372, 0.47179307439364493, 0.7197099400218576, 2.319335932843387, 3.3917060773819685, 5.796864917501807, 9.21643489971757, 8.785082995891571, 8.882598113268614, 8.340710140764713, 12.04758983105421, 8.533988669514656, 11.468502804636955, 12.671547699719667, 8.205058369785547, 13.747256677597761, 7.350261462852359, 8.578332290053368, 5.8696899097412825, 8.638062234967947, 4.9848271161317825, 6.381762782111764, 3.7411878118291497, 4.798534037545323, 2.626172793097794, 2.0668734423816204, 1.4898071950301528, 1.8480507843196392, 0.21770867955638096, 0.3269450250081718, 1.1785742081701756, 11.694413982331753, 19.096747376024723, 23.43511138111353, 18.85667245835066, 12.939794305711985, 4.374040765687823, 1.3788461429066956, 2.489812122657895, 4.153141044080257, 3.188690096139908, 6.079941177740693, 6.930696526542306, 6.860571764409542, 5.9232119377702475, 11.043214425444603, 11.317877937108278, 10.078015867620707, 7.562996847555041, 8.18101231008768, 15.016581416130066, 9.543644841760397, 9.98573686927557, 9.851358029991388, 11.898730918765068, 11.009750571101904, 12.298735454678535, 9.336966332048178, 7.49588817358017, 9.296849984675646, 6.154748238623142, 4.774860357865691, 2.822790155187249, 1.284876591525972, 0.9549989551305771, 0.47852378978859633, 0.20963878836482763, 1.3715350977145135, 5.945430770516396, 17.92276617139578, 34.81072247028351, 41.44798971712589, 34.3601730465889, 27.939307987689972, 23.412143513560295, 25.124567225575447, 27.2770282253623, 32.46452696621418, 32.94816501438618, 35.76323635876179, 44.73478674888611, 58.15589837729931, 63.61326813697815, 52.7779595553875, 21.037367843091488, 4.127258732914925, 0.2272539454861544, 0.10071686119772494, 0.017319956750725396, 0.032260751322610304, 0.01546776395116467, 0.015605903608957306, 0.054691715849912725, 0.0449068660964258, 0.0840573305322323, 0.09279779667849652, 0.04055087854794692, 0.04789663027622737, 0.004812592051166575, 0.11712499675923027, 0.02409939785138704, 0.023391283211822156, 0.008016355441213818, 0.1022342563373968, 0.0343818539113272, 0.07809312010067515, 0.03554346345481463, 0.0072929892030515475, 0.04172278910118621, 0.02687823067390127, 0.04557656902761664, 0.033854216599138454, 0.030055889947107062, 0.024376432302233297, 0.016597579888184555, 0.04028566094348207, 0.03039698287466308, 0.04737921233754605, 0.08537072411854751, 0.00305340635804896, 0.09148129349341616, 0.03751026240934152, 0.1383617232204415, 0.1922302896855399, 0.11153378232847899, 0.14629632089054212, 0.10877003922360018, 0.2109833076247014, 0.1369781224639155, 0.10545744822593406, 0.33872753963805735, 0.1696404127869755, 0.15589864313369617, 0.1979123058845289, 0.2474605932366103, 0.12142366453190334, 0.1475241596926935, 0.17502418952062726, 0.17387807602062821, 0.2290080560487695, 0.15489821322262287, 0.19396707852138206, 0.16720083978725597, 0.2394956417265348, 0.17904474487295374, 0.2030781880603172, 0.16464099433505908, 0.19532235892256722, 0.19198676134692505, 0.22087518620537594, 0.3801801387453452, 0.2083275024779141, 0.19597932288888842, 0.1398448905092664, 0.19615040277130902, 2.0315866358578205, 18.832365162670612, 43.68666239082813, 64.21579420566559, 88.66055130958557, 81.77688628435135, 77.87289217114449, 71.92480534315109, 54.74830962717533, 45.22837646305561, 43.083364963531494, 34.573846980929375, 48.22950102388859, 41.71070761978626, 50.867175087332726, 61.346868351101875, 52.844638377428055, 24.590380489826202, 6.85307951644063, 2.0399514120072126, 0.9777509467676282, 0.3801622678292915, 0.8853754692245275, 0.6647434551268816, 2.5742459669709206, 4.246567105874419, 9.83036795631051, 11.304979529231787, 15.393928717821836, 15.09667256847024, 12.895464934408665, 17.068366818130016, 17.106064595282078, 17.060273252427578, 25.61092782765627, 21.691877022385597, 21.11037142574787, 18.25571570545435, 14.703553263098001, 13.869957793504, 18.22895374149084, 15.105513744056225, 14.016483630985022, 16.866857931017876, 9.290556572377682, 3.0785204702988267, 2.45125915389508, 3.4926253370940685, 2.886214926838875, 0.871134070912376, 0.8136696356814355, 2.793928566388786, 11.985558159649372, 15.902114398777485, 19.30546447634697, 15.75707333162427, 12.922330442816019, 6.74524842761457, 5.431197239086032, 8.197391331195831, 11.046803332865238, 9.252820797264576, 12.964340038597584, 10.120990611612797, 14.655812624841928, 14.154020100831985, 11.85328345745802, 12.151399310678244, 16.71874187886715, 13.187030889093876, 10.481280628591776, 18.799352534115314, 14.93098245933652, 17.809081971645355, 20.183240175247192, 17.63314951211214, 15.304902344942093, 22.2144515812397, 13.971926271915436, 17.155765928328037, 12.578429896384478, 10.416179671883583, 4.703788971528411, 1.8912715651094913, 1.07706930488348, 0.981142264790833, 0.47716479864902794, 0.47585443302523345, 1.953707083594054, 8.389151841402054, 22.806296423077583, 38.424225971102715, 57.89201773703098, 45.62648110091686, 38.19138586521149, 32.873122841119766, 33.356711491942406, 32.27673724293709, 41.25163145363331, 42.311983555555344, 43.13117779791355, 52.31360547244549, 66.09477818012238, 73.82424741983414, 65.10199785232544, 31.22437421232462, 6.759115783497691, 0.5465503816958517, 0.1555400967481546, 0.13817201543133706, 0.08161144927726127, 0.13359752105316147, 0.18014540924923494, 0.15256941318511963, 0.1711382597568445, 0.21773422427941114, 0.15448759775608778, 0.1520930285914801, 0.2025438565760851, 0.18262047175085172, 0.1467936488916166, 0.17020713159581646, 0.08600272223702632, 0.24615459144115448, 0.15011504176072776, 0.22689458273816854, 0.16582339885644615, 0.16257098119240254, 0.15214794751955196, 0.16732986958231777, 0.15306818095268682, 0.09448696189792827, 0.22047867154469714, 0.10455315612489358, 0.054402612222475, 0.06715248295222409, 0.1452933528344147, 0.21886203641770408, 0.11574037926038727, 0.26390878250822425, 0.10224475030554458, 0.17439367569750175, 0.08984168889583088], [0.04296721861464903, 0.12148175985203125, 0.019977496667706873, 0.07406677599647082, 0.00501160358908237, 0.018896656911238097, 0.024829710127960425, 0.09953977045370266, 0.10325421215384267, 0.05478157509060111, 0.014079726079216925, 0.04055094534123782, 0.006793327147534001, 0.05311093758791685, 0.1322904060361907, 0.031004273041617125, 0.08190358086721972, 0.028436885513656307, 0.058009379426948726, 0.09648920211475343, 0.06259422676521353, 0.038409919798141345, 0.01236798472746159, 0.06578371772775427, 0.06011037352436688, 0.08968813854153268, 0.09865001702564768, 0.08074554105405696, 0.17217121057910845, 0.0836952069948893, 0.12482092715799809, 0.10661176245776005, 0.24337992392247543, 3.838090212084353, 14.578591268509626, 21.21644463390112, 49.693893045187, 60.614666640758514, 52.64402434229851, 53.71913105249405, 38.33181872963905, 31.07515811920166, 35.24758882820606, 35.54942563176155, 29.845659993588924, 20.178819112479687, 27.26916264742613, 26.6650178655982, 27.83513467758894, 13.275038916617632, 6.386941904202104, 1.462384897749871, 0.49368224514182657, 0.18429769581416622, 0.12428189787897281, 0.35280225158203393, 0.49554292811080813, 0.6197634874843061, 1.6674812673591077, 5.410141618922353, 9.021907187998295, 5.384765155613422, 5.779880778864026, 3.962452788837254, 12.5031378865242, 4.159879507496953, 12.185797914862633, 14.395113363862038, 5.258817113935947, 8.076468519866467, 6.8282316997647285, 3.828841745853424, 3.888233033940196, 4.029603498056531, 2.746428265236318, 4.610609421506524, 1.9621996278874576, 3.2752639381214976, 5.151217337697744, 4.595029782503843, 4.585869899019599, 3.2123086787760258, 1.0580078652128577, 3.4593939827755094, 14.284894578158855, 31.40743888914585, 48.710505813360214, 47.690693736076355, 45.76229341328144, 35.38342773914337, 12.889248467981815, 3.565097185783088, 0.7952696573920548, 3.05225414223969, 5.893051531165838, 9.009208269417286, 8.22438033297658, 5.527121191844344, 4.412684692069888, 19.692088030278683, 13.176014330238104, 6.768879359588027, 6.863278644159436, 4.261469431221485, 12.105441726744175, 8.446856494992971, 4.2985848896205425, 7.854627873748541, 6.1781929805874825, 11.86485668644309, 13.922318033874035, 9.225539211183786, 1.8343550129793584, 3.3367918990552425, 3.4794937167316675, 5.745861204341054, 1.4356800494715571, 0.2922057453542948, 0.25607894640415907, 0.1857541161007248, 0.21099590929225087, 0.05195966987230349, 1.0297105461359024, 3.9685759227722883, 12.463986687362194, 24.16368428617716, 23.47298014909029, 31.081689968705177, 28.506277464330196, 23.70257332921028, 20.35123486071825, 21.658062636852264, 29.15387101471424, 35.53232654929161, 42.7497922629118, 50.742971152067184, 59.14698779582977, 58.867231607437134, 37.221864089369774, 6.355755552649498, 1.461801272816956, 0.04797887879249174, 0.052887291385559365, 0.024680215610715095, 0.06450364657212049, 0.034115062953787856, 0.07634169611264952, 0.2530914457747713, 0.09211006326950155, 0.016531424844288267, 0.09537076330161653, 0.06905214351718314, 0.043077772643300705, 0.006546412296302151, 0.021309601652319543, 0.0682317660539411, 0.02993680307554314, 0.029916509047325235, 0.14075416984269395, 0.1251167175360024, 0.07723858900135383, 0.08524789125658572, 0.02839255888829939, 0.06094873322581407, 0.016343288552889135, 0.030432346211455297, 0.01599547733349027, 0.08956508303526789, 0.03057046174944844, 0.1302047781064175, 0.04170206833805423, 0.05369273312680889, 0.020837695919908583, 0.09787925955606624, 0.09062527809874155, 0.06558211331139319, 0.03755311030545272, 0.048922419373411685, 0.04485037752601784, 0.08386320696445182, 0.01589909090398578, 0.05595553026068956, 0.04112732320209034, 0.0539092918188544, 0.05902724609768484, 0.046967227608547546, 0.03702663445437793, 0.02866129798348993, 0.006808043935961905, 0.037746862799394876, 0.12922116526169702, 0.02549425513279857, 0.07125311603886075, 0.08511197433108464, 0.10156060146982782, 0.01612048283277545, 0.018501556041883305, 0.030025623309484217, 0.013124288871040335, 0.04126242005440872, 0.045136820554034784, 0.01649227284360677, 0.04364409811387304, 0.10618972533848137, 0.08880214038072154, 0.0919719941157382, 0.09286308340961114, 0.004656119490391575, 0.19945854088291526, 3.6139663634821773, 17.21396930515766, 28.127027414739132, 59.71080534160137, 74.06484290957451, 65.8270825445652, 63.34839954972267, 49.414794221520424, 40.613771080970764, 41.886467188596725, 40.88489793241024, 34.31921884417534, 28.855663016438484, 30.094865821301937, 34.515337720513344, 34.44941125810146, 20.452938303351402, 7.830008044838905, 1.5530154970474541, 0.5867700953967869, 0.2447778481291607, 0.581598988501355, 0.5703234497923404, 3.27600774820894, 3.4446707228198647, 6.5060588624328375, 7.943850411102176, 8.787108287215233, 10.893095880746841, 12.324132341891527, 10.143702942878008, 12.302017528563738, 13.249179404228926, 12.76735670864582, 13.672024514526129, 6.594153335317969, 11.543487031012774, 9.956781473010778, 5.562230832874775, 4.808594947680831, 5.409105224534869, 4.151260619983077, 4.0804514195770025, 2.5127541041001678, 5.619912687689066, 5.217804964631796, 5.2735004760324955, 3.924171505495906, 3.897148543037474, 1.3904107036069036, 3.7012312933802605, 13.489723596721888, 31.097314730286598, 44.746866300702095, 45.99711701273918, 44.12280298769474, 33.24503928422928, 11.388773582875729, 3.555580833926797, 3.095209412276745, 4.612343553453684, 6.350441537797451, 8.71912993490696, 7.411731239408255, 7.953993491828442, 7.681426517665386, 9.009608197957277, 7.26793460547924, 9.339578691869974, 7.563705509528518, 8.162550050765276, 11.65814682841301, 12.884398028254509, 10.791480783373117, 14.096734374761581, 12.624363731592894, 12.23774017766118, 14.393812883645296, 10.964490249752998, 11.304411459714174, 8.082352504134178, 8.242588955909014, 6.911179348826408, 5.2810706198215485, 2.1859255665913224, 1.7979644844308496, 0.6589674088172615, 0.295985740958713, 0.15129611041629687, 1.265379125252366, 4.444821467623115, 12.765172775834799, 27.616900987923145, 30.66986996680498, 35.34186936914921, 31.528224907815456, 25.193005353212357, 24.729582220315933, 31.6826144233346, 38.811877369880676, 40.99657014012337, 48.091815412044525, 57.48176135122776, 67.00047478079796, 65.21449461579323, 40.63166432082653, 8.849847670644522, 1.5108612715266645, 0.08069366493145935, 0.013780160024907673, 0.05748084782680962, 0.014067182855797, 0.056172682670876384, 0.06108456480433233, 0.07691119055380113, 0.07242170177050866, 0.017876942292787135, 0.08638068320578896, 0.025648972514318302, 0.06952005278435536, 0.01014157973258989, 0.04406990534334909, 0.03722181558259763, 0.037460219391505234, 0.018257504489156418, 0.0769063072220888, 0.06221492250915617, 0.010102440719492733, 0.06745860402588733, 0.0643780454993248, 0.07370785111561418, 0.0705201413074974, 0.03303855919511989, 0.011094507553934818, 0.06071821473597083, 0.0314279280428309, 0.03250095855037216, 0.014315348689706298, 0.01904547978483606, 0.04377114637463819, 0.019650313442980405, 0.061069580842740834, 0.03454204277659301, 0.1421046708128415, 0.11404983364627697, 0.2071327337762341, 0.16780304809799418, 0.19455180183285847, 0.10699584614485502, 0.16278538765618578, 0.22439263964770362, 0.1451838415232487, 0.1600341423181817, 0.1248836237937212, 0.10279154987074435, 0.14564499724656343, 0.20102855429286137, 0.23716470430372283, 0.09981819457607344, 0.207235669658985, 0.14367285853950307, 0.23493015702115372, 0.2773948526009917, 0.1408637553686276, 0.08442128717433661, 0.16067535791080445, 0.2827984595205635, 0.17974377376958728, 0.2389482336002402, 0.16835513175465167, 0.2425122493878007, 0.24340306408703327, 0.3176463599083945, 0.2976754924748093, 0.1378144635236822, 0.42243773059453815, 5.49594291485846, 21.261704005301, 38.642087280750275, 71.32085055112839, 81.33434683084488, 73.23685213923454, 73.92184138298035, 57.04612232744694, 47.204000651836395, 48.16167466342449, 49.30977165699005, 43.013855293393135, 36.51258274912834, 38.30289468169212, 41.63932465016842, 38.05708587169647, 19.896108582615852, 7.585200956091285, 2.068751254118979, 0.8089568791911006, 0.483968363259919, 0.6337881193030626, 0.34216991742141545, 4.28189143538475, 5.467180833220482, 6.590802865102887, 13.011583853513002, 19.386700317263603, 16.436187140643597, 17.869886308908463, 14.116434417665005, 24.515767693519592, 18.599124178290367, 26.493956744670868, 26.93100169301033, 18.540314733982086, 25.129691250622272, 17.515319734811783, 14.48683189228177, 10.292078331112862, 12.12805526331067, 8.720273673534393, 14.258120264858007, 6.152717247605324, 10.723224096000195, 13.091884944587946, 10.22617181763053, 10.361151974648237, 8.083469644188881, 2.8876123018562794, 5.5110494792461395, 17.458983957767487, 28.193692937493324, 44.107337817549706, 42.90823616087437, 42.720917612314224, 32.74864912033081, 13.829068187624216, 5.15027261339128, 8.905964009463787, 9.362656753510237, 12.02323978766799, 15.31666936352849, 13.70861180126667, 10.577877145260572, 10.431001726537943, 28.535040020942688, 22.222902327775955, 14.391559604555368, 15.945154689252377, 13.506478797644377, 21.338362991809845, 20.33058486878872, 12.990769520401955, 20.314435735344887, 19.087282083928585, 21.214371845126152, 24.83470167964697, 21.123801805078983, 17.10991758853197, 11.742394957691431, 12.423611003905535, 15.31365042552352, 7.4412889033555984, 1.5080653340555727, 1.5643071848899126, 0.8021813677623868, 0.3140405018348247, 0.2679167955648154, 1.6674406570382416, 5.242947265505791, 16.951260901987553, 31.096119694411755, 35.91547138988972, 45.886748135089874, 41.33958913385868, 35.338787734508514, 31.144434101879597, 35.925263464450836, 42.83829711377621, 48.16338837146759, 56.164197251200676, 66.56460016965866, 78.04275825619698, 76.23549923300743, 51.95255644619465, 14.910412263125181, 3.0275222193449736, 0.14893616986228153, 0.16525926272151992, 0.12420225801179186, 0.18963428679853678, 0.1243914759834297, 0.18032445979770273, 0.44560381094925106, 0.21997792966431007, 0.1126901968382299, 0.22931693791178986, 0.15185825759544969, 0.17019151680869982, 0.12010276783257723, 0.1595302388886921, 0.15790729550644755, 0.09155090694548562, 0.09112758591072634, 0.23435874783899635, 0.3134279331425205, 0.14522213634336367, 0.2851851173909381, 0.20937538531143218, 0.11762172362068668, 0.18424213863909245, 0.11331570858601481, 0.10965030800434761, 0.1538300994434394, 0.1505051739513874, 0.16933807666646317, 0.13604432257125154, 0.12970421434147283, 0.19101940153632313, 0.11824197354144417, 0.20204727072268724, 0.2296947652939707], [0.044402005296433344, 0.08784158606431447, 0.055337432568194345, 0.020071172402822413, 0.08841378192300908, 0.13474756793584675, 0.024080736548057757, 0.06783597869798541, 0.05309077714628074, 0.005218536161919474, 0.03577652380045038, 0.011061171207984444, 0.026638025301508605, 0.05551172966079321, 0.18456244957633317, 0.11166284180944785, 0.03348490907228552, 0.009261597606382566, 0.06179385760333389, 0.055499287554994226, 0.034059164390782826, 0.012214363869134104, 0.05286504921969026, 0.09828698806813918, 0.053171879044384696, 0.16367143776733428, 0.0661381303507369, 0.16136649035615847, 0.21522067399928346, 0.23104415304260328, 0.16065607691416517, 0.1437128454563208, 0.42490780586376786, 5.7548548467457294, 20.472450256347656, 40.44037118554115, 51.649944484233856, 58.902201130986214, 48.22146065533161, 50.63066057860851, 40.63274726271629, 34.106859639286995, 28.0490517988801, 23.278578780591488, 25.65268948674202, 31.680946312844753, 45.72681091725826, 35.56007266044617, 25.920696705579758, 7.607686724513769, 1.564616987016052, 0.0949630347895436, 0.16941981681156904, 0.32138025329913944, 0.5751448567025363, 1.1249418673105538, 2.4825250636786222, 2.758066803216934, 6.994489403441548, 6.025816407054663, 9.662968888878822, 10.483574755489826, 9.422636535018682, 10.242111962288618, 9.052103217691183, 6.768039604648948, 7.740083495154977, 6.6772885993123055, 5.954968258738518, 12.293263748288155, 3.6399899795651436, 5.600215969607234, 4.469448896124959, 7.090093223378062, 3.161152023822069, 4.386796681210399, 5.345206903293729, 9.875958859920502, 11.625769715756178, 10.37068946287036, 9.261994455009699, 8.650099989026785, 6.147445505484939, 10.843830574303865, 31.119051463901997, 57.93647915124893, 68.1229117512703, 61.742183938622475, 60.254757553339005, 58.42563830316067, 26.932135932147503, 12.736218329519033, 8.788877092301846, 11.165840495377779, 13.204554598778486, 16.36240839958191, 16.739788949489594, 17.195975370705128, 16.58045969903469, 20.080520287156105, 15.905540864914656, 12.004511542618275, 4.623265117406845, 7.405480574816465, 11.611858662217855, 7.2665073070675135, 11.213805321604013, 9.240697547793388, 11.518112942576408, 11.705239601433277, 11.33425410836935, 6.681954273954034, 6.750410925596952, 9.720671642571688, 3.815688039176166, 4.040181180462241, 4.078153967857361, 2.9491452500224113, 2.5106385676190257, 0.7745892670936882, 0.2663238497916609, 0.09688391335657798, 0.2831901650642976, 1.2859316286630929, 6.880788104608655, 14.632137045264244, 30.82966849207878, 48.47187101840973, 37.461388036608696, 28.522776179015636, 28.13563395291567, 15.70094084367156, 16.815458089113235, 20.33769428730011, 29.460385367274284, 53.24760675430298, 58.6962977796793, 56.39014072716236, 51.11710287630558, 22.28569395840168, 4.956046510487795, 0.7792135595809668, 0.013528205527109094, 0.02821883881551912, 0.12029500634525903, 0.13278029771754518, 0.11459363493486308, 0.23803588177543133, 0.17689781554508954, 0.032770369289210066, 0.11392308224458247, 0.03618252681917511, 0.030965601581556257, 0.03363174670084845, 0.055029675058904104, 0.029903384165663738, 0.05801369872642681, 0.08926881768275052, 0.22608985716942698, 0.1032755637424998, 0.1276102298288606, 0.05416357016656548, 0.03640086666564457, 0.07219013685244136, 0.12979616643860936, 0.03443803820118774, 0.022328559280140325, 0.07616088667418808, 0.04807070472452324, 0.02202779465733329, 0.15491887461394072, 0.026534694225119893, 0.04961308055499103, 0.24266983702545986, 0.07919989235233516, 0.05726095689169597, 0.057728981191758066, 0.047899149867589585, 0.05054993809608277, 0.039821195241529495, 0.08578830835176632, 0.12308967474382371, 0.030898682125553023, 0.08933696910389699, 0.05253284536593128, 0.02078407760564005, 0.007370532039203681, 0.02088872599415481, 0.049037864155252464, 0.05365280187106691, 0.15028664114652202, 0.04209274971799459, 0.024486581860401202, 0.06316352824796923, 0.06369666487444192, 0.02497005210898351, 0.08502755503286608, 0.04794286978722084, 0.04771970969159156, 0.030897539218130987, 0.011138861082145013, 0.07438831889885478, 0.057989812703453936, 0.02281146549648838, 0.09169100958388299, 0.1351994022843428, 0.047272721567424014, 0.12505706370575354, 0.5814694985747337, 6.052874280139804, 22.718821316957474, 45.724694430828094, 63.66977110505104, 71.43745869398117, 59.991139099001884, 60.417540818452835, 45.95603361725807, 41.12699054181576, 37.32929952442646, 33.74513044953346, 35.50966076552868, 35.15671670436859, 38.350471928715706, 34.64774541556835, 23.596880100667477, 9.249204341322184, 1.9175034575164318, 0.09537788791931234, 0.5223763163667172, 0.7471591327339411, 1.5429476997815073, 3.82523977663368, 4.994331356137991, 4.955351622775197, 8.903401046991348, 10.431603994220495, 10.572230648249388, 10.110620968043804, 8.37027445435524, 12.191943135112524, 18.87240931391716, 13.407044783234596, 15.233505126088858, 18.090527169406414, 9.352590143680573, 6.400180868804455, 7.298210905864835, 6.490497747436166, 5.785831259563565, 5.781807275488973, 3.825844181701541, 5.436123674735427, 5.357475019991398, 7.594053531065583, 8.055289406329393, 10.251750145107508, 9.639389254152775, 8.718477319926023, 6.4676429238170385, 12.596655618399382, 34.285309463739395, 57.99005247652531, 67.99773126840591, 64.00045216083527, 63.269211798906326, 58.43541517853737, 29.60182137787342, 13.255812898278236, 8.557781092822552, 12.020771820098162, 15.048234667629004, 14.36612281948328, 15.147190857678652, 16.190000250935555, 15.803444143384695, 12.869088649749756, 10.481675807386637, 10.484760291874409, 6.738224979490042, 6.157462717965245, 10.617070142179728, 13.397586140781641, 8.87276329100132, 10.649391207844019, 15.406036768108606, 12.714629787951708, 16.036083810031414, 13.925751149654388, 12.360809873789549, 14.812151435762644, 10.524556506425142, 10.074569452553988, 9.507521130144596, 5.902294060215354, 2.4575409293174744, 1.7590213241055608, 1.0276932106353343, 0.2226154482923448, 0.4326594196027145, 1.2707284069620073, 6.065575098618865, 14.613076318055391, 25.85228707641363, 41.38982243835926, 33.96179102361202, 29.52962715178728, 27.47658211737871, 24.61710635572672, 26.669461727142334, 30.31104002147913, 37.22791336476803, 58.32917667925358, 66.02331161499023, 64.27065566182137, 55.68147875368595, 23.654091730713844, 5.07211365737021, 0.5574847699608654, 0.038960263118497096, 0.05386450320656877, 0.08400687933317386, 0.1072036029654555, 0.08852638798998669, 0.06307654854026623, 0.08244297379860654, 0.006246619886951521, 0.04460247051611077, 0.02775020224362379, 0.03919675218639895, 0.05656921959598549, 0.011127227917313576, 0.019867031696776394, 0.036172389081912115, 0.10239034483674914, 0.1329360596719198, 0.09420001792022958, 0.04342437045124825, 0.1145120061119087, 0.06927076537976973, 0.058585252627381124, 0.0410629715770483, 0.05398086825152859, 0.07147418698878027, 0.05654122578562237, 0.04429884305864107, 0.010394617765996372, 0.057511420600349084, 0.025819974471232854, 0.0694690301315859, 0.07676450506551191, 0.012480870027502533, 0.06690120659186505, 0.13070618791971356, 0.20122028072364628, 0.26901941921096295, 0.14961720909923315, 0.21602409338811412, 0.23275440267752856, 0.14954302401747555, 0.29139959486201406, 0.23659406695514917, 0.19733585009817034, 0.14360183500684798, 0.10836345361894928, 0.20430506207048893, 0.2397324313642457, 0.3712435229681432, 0.17712905391817912, 0.13678145332960412, 0.16700194420991465, 0.2334913404774852, 0.18510953115765005, 0.152173878159374, 0.16670507029630244, 0.13124810415320098, 0.16962886496912688, 0.3325002081692219, 0.2604143356438726, 0.12742475228151307, 0.23437506024492905, 0.4510682146064937, 0.2962473628576845, 0.3568324993830174, 0.30119419272523373, 0.9274152852594852, 8.763690143823624, 28.978856205940247, 59.5906063914299, 70.88917091488838, 80.5555634200573, 67.01609954237938, 71.08256533741951, 56.646395176649094, 50.57488717138767, 39.33606304228306, 34.50272999703884, 39.89182122051716, 45.87949812412262, 60.648454427719116, 48.10297541320324, 33.58526162803173, 10.393631681799889, 2.670856495387852, 0.2915017440682277, 0.6193376134615391, 0.9038846916519105, 2.1277511632069945, 3.7219741428270936, 5.804879162460566, 10.16335928812623, 15.871558338403702, 17.716606333851814, 22.524900622665882, 25.70601962506771, 20.22437296807766, 26.222326420247555, 24.063599556684494, 19.842501059174538, 20.492718368768692, 23.970561549067497, 12.958773337304592, 23.928583301603794, 11.23648440465331, 13.012723792344332, 12.540994305163622, 15.930979549884796, 7.082061879336834, 8.233138862997293, 9.831281807273626, 15.874124150723219, 17.216484770178795, 16.473556235432625, 16.269809268414974, 13.984391503036022, 8.01551504060626, 18.39640125632286, 42.989304810762405, 59.694542214274406, 66.19861900806427, 62.2529449313879, 62.4671546369791, 58.01209509372711, 32.205483466386795, 18.27238731086254, 12.27623401209712, 18.667398914694786, 20.853892788290977, 20.125238187611103, 20.64642582088709, 20.676050931215286, 22.269981801509857, 25.962815545499325, 22.326441071927547, 19.0284688398242, 11.516289990395308, 14.492479339241982, 20.82444056868553, 18.44554591923952, 23.0649371445179, 16.73015456646681, 23.412417098879814, 25.704617500305176, 21.351371593773365, 20.85127852857113, 15.392205510288477, 23.400027863681316, 15.449641328305006, 14.705949034541845, 12.44562417268753, 9.33976773172617, 5.603076741099358, 2.5011628260836005, 1.350874537602067, 0.2308441887726076, 0.6202739069703966, 1.7285099113360047, 8.44442842528224, 18.94538439810276, 39.425859823822975, 62.57516764104366, 52.79006950557232, 43.925517573952675, 41.355149298906326, 26.520906798541546, 28.33207581192255, 32.07011952996254, 42.78154335916042, 68.34497183561325, 75.34454584121704, 75.80046817660332, 68.29362899065018, 36.57893478870392, 8.62038653343916, 1.082332853693515, 0.11746596166631207, 0.18840404343791306, 0.27184522070456296, 0.26635225920472294, 0.2197262377012521, 0.42774886591359973, 0.28363667079247534, 0.09986095712520182, 0.20614638982806355, 0.11269068665569648, 0.327758596977219, 0.12818447401514277, 0.07133645180147141, 0.07908765735919587, 0.17825759336119518, 0.2571131440345198, 0.35057880682870746, 0.19222126516979188, 0.2262924931710586, 0.21288682735757902, 0.2335767468321137, 0.17739303584676236, 0.3205067157978192, 0.10390537994680926, 0.20714101614430547, 0.295532793388702, 0.1690073756617494, 0.14896796346874908, 0.25113535230048, 0.25347581889946014, 0.15543766552582383, 0.31916523934341967, 0.14129142538877204, 0.16661534464219585], [0.052465866538113914, 0.049224829708691686, 0.15161735645961016, 0.08669851536978967, 0.14045751857338473, 0.05590572844084818, 0.007707962931817747, 0.017531823214085307, 0.029835742971044965, 0.02765331486443756, 0.041294603288406506, 0.08607321884483099, 0.023327864837483503, 0.06667146735708229, 0.04651300725527108, 0.07652898450032808, 0.035988707531942055, 0.07161755507695489, 0.033315959153696895, 0.09390773790073581, 0.048761195212136954, 0.017906698703882284, 0.05526833490876015, 0.12370757205644622, 0.04631349569535814, 0.03188105001754593, 0.02058277004834963, 0.16344251489499584, 0.2368741386453621, 0.1752592870616354, 0.14122455788310617, 0.2190716189215891, 1.607891321182251, 14.01700895279646, 31.45464565604925, 34.346672371029854, 51.528484001755714, 47.372734397649765, 41.760283559560776, 36.511515006423, 37.77935117483139, 33.87332797050476, 31.539886482059956, 36.770201325416565, 31.86117634177208, 33.2709576934576, 33.58747310936451, 28.13965793699026, 11.590751744806767, 3.487358819693327, 0.6225999165326357, 0.4544044949579984, 0.1958761049900204, 0.8377741766162217, 0.811624217312783, 2.553038354963064, 3.2922212406992912, 3.3668278623372316, 6.698204101994634, 7.591889072209597, 5.394756719470024, 7.8941429033875465, 7.434166660532355, 9.190823324024677, 13.950022347271442, 15.399237982928753, 10.124476924538612, 13.092739898711443, 5.66759442910552, 4.97436722740531, 11.548860892653465, 7.205182397738099, 9.127087444067001, 12.576941326260567, 11.7481573484838, 13.477874882519245, 13.558032531291246, 19.615991413593292, 19.72852997481823, 24.318430982530117, 22.469252608716488, 20.604472272098064, 18.256963938474655, 28.12982026487589, 42.95936621725559, 58.826379999518394, 64.10570651292801, 63.11326816678047, 58.7734754383564, 67.18043312430382, 38.99037279188633, 25.78323908150196, 21.48147091269493, 24.056661128997803, 27.566454894840717, 27.749994546175003, 25.171787291765213, 30.781435780227184, 27.09581784904003, 18.46174255013466, 11.743887327611446, 19.464812725782394, 11.707434933632612, 7.219545627012849, 6.770519921556115, 11.716481298208237, 5.859153075143695, 13.743044603616, 10.965027920901775, 10.373072884976864, 15.255113616585732, 14.26136339083314, 8.909447472542524, 5.2659654803574085, 5.600651046261191, 3.294842387549579, 5.775254527106881, 2.9567493544891477, 3.020628201775253, 1.1789545440115035, 1.906368511263281, 0.4804842174053192, 0.026469941840332467, 0.19932528084609658, 0.5201045726425946, 6.44429175183177, 17.30435125529766, 40.56917667388916, 43.543022498488426, 33.856608867645264, 32.758463993668556, 24.883232675492764, 26.239873878657818, 22.071643844246864, 30.81723365932703, 48.64321522414684, 55.15175297856331, 62.20794014632702, 55.624071434140205, 36.66772462427616, 14.372181594371796, 1.4761102362535894, 0.03851656641927548, 0.042920622872770764, 0.07967990604811348, 0.1793391103274189, 0.2470720195560716, 0.3154880757210776, 0.24427363299764693, 0.0487867250922136, 0.09937170369084924, 0.029193740701884963, 0.04036137484945357, 0.050909215497085825, 0.01265947992578731, 0.1318606431595981, 0.032019865029724315, 0.04493001368246041, 0.07397060850053094, 0.09889790177112445, 0.05771795658802148, 0.03344950491737109, 0.04598290972353425, 0.01246870715476689, 0.03899587507476099, 0.04603232562658377, 0.03806906992394943, 0.05342122582078446, 0.060344235389493406, 0.020473609401960857, 0.02498867816029815, 0.06132813767180778, 0.02731239077547798, 0.12221581069752574, 0.052350833648233674, 0.04147111940255854, 0.029537763257394545, 0.027327179923304357, 0.04651885166822467, 0.08643484514323063, 0.09200388420140371, 0.059291999859851785, 0.01190235756439506, 0.04340137500548735, 0.01846677900175564, 0.08844202806358226, 0.023487059224862605, 0.014206782689143438, 0.03556578354618978, 0.05160404754860792, 0.03470530042250175, 0.09554526448482648, 0.06126568594481796, 0.05577528114372399, 0.020085852083866484, 0.06514037217129953, 0.03773370823182631, 0.07895341768744402, 0.06465456972364336, 0.043862794191227295, 0.07812198222381994, 0.06506002726382576, 0.056498240592190996, 0.06273788429098204, 0.09057244460564107, 0.14912103884853423, 0.113723778486019, 0.05773738601419609, 1.590450257062912, 13.718989044427872, 35.454552322626114, 46.94736622273922, 63.80964919924736, 60.69710701704025, 53.022582828998566, 48.36830757558346, 48.72214838862419, 41.16921007633209, 34.300375655293465, 32.659752890467644, 30.825940892100334, 33.47980588674545, 41.03978522121906, 26.829733327031136, 12.732586674392223, 3.8829468050971627, 0.6336892652325332, 0.2648536255583167, 0.9272819955367595, 1.3934721518307924, 3.9970515947788954, 4.886431870982051, 9.1866834461689, 7.342886058613658, 11.093647219240665, 11.51474917307496, 10.118744932115078, 12.202175986021757, 13.678557313978672, 14.325553346425295, 12.900382820516825, 14.537620916962624, 14.268041532486677, 11.317321266978979, 7.237540986388922, 7.620202302932739, 6.84077862650156, 6.645844811573625, 10.265444610267878, 11.488489732146263, 11.771907024085522, 13.318825867027044, 14.16650528088212, 18.39214738458395, 19.043941609561443, 23.294885605573654, 22.754058726131916, 21.57404724508524, 19.52811162918806, 30.95560133457184, 50.7425569742918, 67.74179220199585, 70.48861160874367, 70.91662064194679, 65.76582223176956, 69.78422060608864, 44.35174070298672, 26.11238691955805, 22.538828775286674, 23.24233252555132, 28.349383883178234, 26.349720284342766, 26.284386590123177, 27.48384352773428, 24.860621988773346, 20.152946300804615, 15.759237315505743, 13.668855484575033, 11.786781325936317, 7.911861352622509, 6.211703857406974, 10.227878876030445, 15.322225615382195, 15.965470299124718, 20.08658666163683, 11.676079016178846, 16.468456909060478, 15.66418256610632, 13.171275984495878, 12.053407318890095, 10.429803840816021, 7.979750409722328, 7.0713407546281815, 7.406066218391061, 4.584286333993077, 5.665279878303409, 1.8043056316673756, 1.2596604321151972, 0.3281949501251802, 0.2548044116701931, 0.6669228756800294, 5.674343816936016, 15.38951525464654, 39.92379270493984, 42.9729200899601, 38.44921723008156, 37.96867601573467, 24.348415173590183, 24.56989958882332, 21.41798011958599, 35.84880776703358, 58.428689539432526, 62.018185928463936, 66.44302949309349, 61.839948892593384, 41.64327263832092, 16.037755720317364, 1.9056565244682133, 0.0694727482914459, 0.07186059359810315, 0.026590023189783096, 0.10866514407098293, 0.046670257215737365, 0.12318325214437209, 0.036885849040118046, 0.18530262314016, 0.057646985005703755, 0.05976382024527993, 0.012737334927805932, 0.018245162573293783, 0.02293016830662964, 0.08860007583280094, 0.02667171323992079, 0.09851981463725679, 0.08296868152683601, 0.0943491821817588, 0.040125843152054586, 0.05838933677296154, 0.06405072868801653, 0.052131061456748284, 0.050724123866530135, 0.04725430888356641, 0.015749054618936498, 0.028237628139322624, 0.03879630043229554, 0.029305495154403616, 0.029932485631434247, 0.04756082329549827, 0.0312971282255603, 0.032397384420619346, 0.06787749443901703, 0.04261946305632591, 0.17272185446927324, 0.1403905323240906, 0.32477302593179047, 0.30803064932115376, 0.361625348450616, 0.206689894257579, 0.13752514467341825, 0.09412563245859928, 0.20118073909543455, 0.15561705746222287, 0.26809461414813995, 0.20016062742797658, 0.18629609170602635, 0.17824279493652284, 0.40157005190849304, 0.18043186340946704, 0.17528251628391445, 0.27915510814636946, 0.1492036844138056, 0.3488193528028205, 0.17532343830680475, 0.13186052441596985, 0.1515524779097177, 0.23187065322417766, 0.1193887104454916, 0.17922079714480788, 0.17166316596558318, 0.38717363378964365, 0.43289420544169843, 0.4880394885549322, 0.22541318176081404, 0.3273478033952415, 2.559551205486059, 20.137426033616066, 44.26536373794079, 53.77582021057606, 72.10620000958443, 69.51527863740921, 63.160674422979355, 52.290681302547455, 55.68287707865238, 47.6107232272625, 44.326639249920845, 50.16393542289734, 45.01505210995674, 47.957827001810074, 46.796172335743904, 36.781365126371384, 14.71795354038477, 4.304078444838524, 0.9681020770221949, 1.021226670127362, 1.27451989101246, 2.2268871311098337, 4.332992043346167, 10.169148277491331, 14.457566812634468, 12.796474546194077, 22.083117328584194, 20.619424469769, 20.114425867795944, 18.967444114387035, 23.317456394433975, 22.129509039223194, 20.226392559707165, 25.074856393039227, 23.431119695305824, 25.384161695837975, 16.679358892142773, 12.124580349773169, 18.666319772601128, 12.048404887318611, 15.53509684279561, 17.215654514729977, 17.12122768163681, 17.874554358422756, 18.066157177090645, 24.162633642554283, 26.30128998309374, 30.879966393113136, 28.18118780851364, 29.02791917324066, 23.859341517090797, 40.584273263812065, 57.97589063644409, 70.19527494907379, 73.04724231362343, 72.85426586866379, 66.75971210002899, 72.47181639075279, 48.76116469502449, 29.921921901404858, 26.445769630372524, 28.089747615158558, 34.03600864112377, 34.206288903951645, 30.25680363178253, 35.508722215890884, 31.794508919119835, 23.14975429326296, 16.442943178117275, 24.21399548649788, 17.931380309164524, 12.478645350784063, 10.336490347981453, 20.004957541823387, 13.262613583356142, 21.5387262403965, 18.189466260373592, 20.669946558773518, 27.54796888679266, 26.32266003638506, 19.826224632561207, 15.614115502685308, 15.186694487929344, 14.54175889492035, 14.18789243325591, 9.209180139005184, 9.340353850275278, 6.065665343776345, 3.547509592026472, 1.6565000941045582, 0.6723577121738344, 0.35025962395593524, 1.0821720748208463, 7.651428552344441, 20.61841942369938, 50.09392037987709, 54.866179302334785, 46.464039757847786, 46.18583768606186, 36.663594245910645, 37.17458702623844, 34.27457123994827, 44.1517536342144, 64.07669886946678, 70.39848044514656, 79.17243763804436, 72.78203174471855, 51.74021624028683, 24.521138705313206, 3.2086922228336334, 0.26528603048063815, 0.22974367282586172, 0.28214320249389857, 0.4492622130783275, 0.45881371304858476, 0.5991703737527132, 0.47102070646360517, 0.2738979714922607, 0.3020753595046699, 0.2008751968969591, 0.10038314707344398, 0.12464900122722611, 0.08778714953223243, 0.4611928900703788, 0.12508799642091617, 0.25820246839430183, 0.2702841575955972, 0.35442725813481957, 0.12544354452984408, 0.15771116071846336, 0.1660050469217822, 0.14466620836174116, 0.3039548039669171, 0.14232779009034857, 0.06594382124603726, 0.2151264064013958, 0.13577738689491525, 0.09039763172040693, 0.11795136335422285, 0.17743437347235158, 0.11189088894752786, 0.24531207571271807, 0.2354746707715094, 0.24000154895475134], [0.016413850098615512, 0.04328204879129771, 0.06647873160545714, 0.04196321155177429, 0.10921245571807958, 0.022529514317284338, 0.0671832449734211, 0.013918710646976251, 0.027907973562832922, 0.02670697824214585, 0.018080192421621177, 0.056490414644940756, 0.042308232295908965, 0.017456302266509738, 0.07131495178327896, 0.02037483882304514, 0.09857816970907152, 0.13150015234714374, 0.03699097054777667, 0.013751424066867912, 0.021780999013572, 0.030352928988577332, 0.07677569665247574, 0.053405306753120385, 0.07105047261575237, 0.09038321921252646, 0.1015598296362441, 0.15379398653749377, 0.30897000047843903, 0.24935206049121916, 0.08455868839519098, 0.32052250870037824, 4.826066410169005, 20.941734574735165, 34.65420126914978, 58.53195659816265, 54.61397923529148, 51.70482113957405, 40.37697158753872, 36.28720164299011, 25.96849624067545, 26.236843541264534, 41.670304387807846, 45.27215391397476, 43.150594756007195, 32.61487349867821, 30.239776745438576, 16.745838224887848, 3.2146935258060694, 0.5212005169596523, 0.1237456664966885, 0.14942410227376968, 0.7996507035568357, 1.3468265673145652, 2.916789036244154, 6.296976031735539, 5.760431047528982, 2.8729398641735315, 5.753077492117882, 9.948266129940748, 8.603769075125456, 6.653188392519951, 6.515571651980281, 8.66116214543581, 18.48487190902233, 12.692227140069008, 17.178652100265026, 16.75289824604988, 13.676730562001467, 11.105269845575094, 13.059637974947691, 20.35071238875389, 21.343422420322895, 25.270429998636246, 24.58644200116396, 30.098029151558876, 29.691221080720425, 34.71420384943485, 33.82598251104355, 35.51350995898247, 39.06067281961441, 38.205954283475876, 37.951964512467384, 45.257277712225914, 38.42289224267006, 52.03555539250374, 55.57457908987999, 57.227467596530914, 50.52504524588585, 64.96035665273666, 47.63553589582443, 44.450250416994095, 41.91343434154987, 38.383735343813896, 39.164437651634216, 38.818257227540016, 40.73773182928562, 33.71821649372578, 38.15127141773701, 31.947591304779053, 28.766293711960316, 20.904922150075436, 19.932943806052208, 10.111949946731329, 11.348659135401249, 11.842386592179537, 9.475484099239111, 11.722398530691862, 22.713583298027515, 7.738936906680465, 17.368229627609253, 11.449983548372984, 12.62463066726923, 15.57635122910142, 8.98274838924408, 7.728363024070859, 8.699506837874651, 4.759375238791108, 0.9882952028419822, 3.1736975256353617, 0.9486850001849234, 0.7912601600401103, 0.4465384123614058, 0.21177514950977638, 0.10055763341370039, 0.5587563361041248, 3.4804505528882146, 17.031442299485207, 37.52532720565796, 40.197917595505714, 27.348169907927513, 45.02021223306656, 30.346965193748474, 25.516366101801395, 16.670359075069427, 32.725303173065186, 53.80159042775631, 52.792828157544136, 60.564228147268295, 45.04016496241093, 27.41516411304474, 6.262307642027736, 0.18634648353327066, 0.013154902462702012, 0.17608687077881768, 0.0797472039994318, 0.1502206493751146, 0.18249427695991471, 0.18465609377017245, 0.06990592504735105, 0.07672347914194688, 0.056614809727761894, 0.05758293023973238, 0.046903261900297366, 0.04626046182238497, 0.03331961423100438, 0.08244160082540475, 0.007260049442265881, 0.06696600350551307, 0.12028050477965735, 0.01379481651383685, 0.0402221145486692, 0.013103594083077041, 0.016054674742917996, 0.046240260562626645, 0.05660676113620866, 0.0384730060613947, 0.06641573811066337, 0.06929769049747847, 0.056168953378801234, 0.05930208193603903, 0.0669972256582696, 0.09073688968783244, 0.15509608463617042, 0.09055904141860083, 0.09243027030606754, 0.08500781390466727, 0.08360782652744092, 0.036927320252289064, 0.03833953080174979, 0.051754265659837984, 0.014413028311537346, 0.051113450826960616, 0.03563799080438912, 0.022656178516626824, 0.08029741002246737, 0.05584650134551339, 0.055399023403879255, 0.018504387335269712, 0.07376806155662052, 0.06620090120122768, 0.03634219989180565, 0.009761287492437987, 0.057811192600638606, 0.029571378836408257, 0.00875443243785412, 0.05143815898918547, 0.04309441530494951, 0.12012110630166717, 0.0554048121557571, 0.06396861746907234, 0.04186163751001004, 0.013605814692709828, 0.11155453277751803, 0.15159586386289448, 0.17916255339514464, 0.034407602724968456, 0.29129887057933956, 4.81778047978878, 24.37051858752966, 41.93427622318268, 61.352682039141655, 63.409526869654655, 61.26545011997223, 50.74837066233158, 40.62112748622894, 33.9920412003994, 30.72443313896656, 39.37359742820263, 43.80940720438957, 41.829398050904274, 34.49233755469322, 28.98086439818144, 18.6348669603467, 4.436601083725691, 0.8376552548725158, 0.043988076140522026, 0.3640597709454596, 2.1753151109442115, 4.459628323093057, 6.926749013364315, 7.225318467244506, 10.279945582151413, 12.460191641002893, 7.3046159371733665, 14.467603974044323, 12.334871515631676, 13.334307186305523, 10.190424285829067, 11.260200832039118, 11.122731808573008, 10.243651829659939, 13.859364911913872, 10.127748548984528, 9.944122452288866, 8.618455287069082, 14.379006028175354, 20.69602455943823, 23.34121271967888, 24.54316232353449, 25.21715685725212, 28.261171616613865, 28.662509880959988, 31.496202126145363, 35.31294912099838, 35.81796482205391, 41.764003559947014, 39.75178353488445, 42.24350742995739, 51.37923181056976, 47.99794904887676, 62.15234912931919, 63.262934535741806, 65.4709580540657, 58.8366736471653, 71.36074841022491, 55.00210180878639, 44.48193311691284, 43.99265997111797, 39.24641825258732, 40.725378692150116, 39.56448018550873, 40.099791660904884, 33.611187636852264, 37.907579094171524, 31.51510041207075, 27.83692628145218, 19.4145680218935, 18.48113290965557, 11.92808909341693, 9.870298113673925, 8.892091903835535, 13.161452561616898, 12.533037532120943, 23.80093865096569, 15.079270452260971, 20.224352069199085, 22.804968394339085, 13.356270957738161, 13.11794774606824, 11.129636038094759, 9.503908473998308, 9.785435367375612, 11.094179190695286, 4.922854341566563, 4.064668016508222, 3.763874969445169, 2.290035467594862, 1.1932075791992247, 0.7072152011096478, 0.1908871062914841, 0.8570919244084507, 4.63603338226676, 19.547684378921986, 34.55737866461277, 40.44043578207493, 31.53605628758669, 41.30006745457649, 34.83734764158726, 34.5631505548954, 25.023747235536575, 38.79941783845425, 62.8057012706995, 59.886401519179344, 68.29200267791748, 49.960672929883, 30.89719656854868, 7.2933699656277895, 0.21594753343379125, 0.033360154047841206, 0.10018453351221979, 0.13286708446685225, 0.13406091806245968, 0.08490366832120344, 0.0801217436674051, 0.08185769387637265, 0.04883832290943246, 0.07637785354745574, 0.03393266903003678, 0.018198444377048872, 0.02844791568350047, 0.06293476122664288, 0.08656935198814608, 0.00642504332063254, 0.04487627105845604, 0.06463641679147258, 0.04639713944925461, 0.04242163988237735, 0.02519090412533842, 0.025603254362067673, 0.036707158433273435, 0.004569678303596447, 0.03493977455946151, 0.029502279321604874, 0.09644353034673259, 0.03552925132680684, 0.05422785128757823, 0.052075266794417985, 0.027056526087108068, 0.08431510810623877, 0.04510462247708347, 0.0453221274074167, 0.22375163185643032, 0.15963963145622984, 0.12397555416100658, 0.22788362810388207, 0.20172943855868652, 0.08953556782216765, 0.19428062107181177, 0.10018700486398302, 0.05921821553783957, 0.2091553236823529, 0.12784148304490373, 0.1769163692370057, 0.2430584403919056, 0.17680118791759014, 0.12693661206867546, 0.15362443547928706, 0.20852809015195817, 0.28261402097996324, 0.20043612748850137, 0.18591606756672263, 0.14064488117583096, 0.1639088656520471, 0.21330571034923196, 0.15478061250178143, 0.17802935326471925, 0.2201034119934775, 0.2019016761914827, 0.2688824781216681, 0.49882238963618875, 0.4641308746067807, 0.31367898685857654, 0.4504207649733871, 7.195339500904083, 29.74139928817749, 48.83719481527805, 77.16607689857483, 73.41643050312996, 74.23312827944756, 58.93457539379597, 52.13124565780163, 42.06291452050209, 39.44634452462196, 56.46115131676197, 60.36524422466755, 58.933811634778976, 46.70973837375641, 40.65849468111992, 21.06651607900858, 4.115554885938764, 0.6841976393479854, 0.14550957013852894, 0.4634006606647745, 1.8840304599143565, 6.583677297458053, 11.353318635374308, 8.931525237858295, 19.669110663235188, 16.797321662306786, 18.44846796244383, 23.611372523009777, 19.227754846215248, 23.407648354768753, 19.60573386400938, 23.055844232439995, 36.87676660716534, 26.823165379464626, 26.143117770552635, 24.18462686240673, 22.77274612337351, 17.36345138400793, 17.369312569499016, 26.380658224225044, 31.0654591396451, 27.892876379191875, 27.286689206957817, 33.39744910597801, 33.70826482772827, 38.09508003294468, 39.59675945341587, 43.21024015545845, 48.026094138622284, 45.620986595749855, 46.219355687499046, 61.23636268079281, 53.234630450606346, 66.4055635035038, 66.27345219254494, 66.51183620095253, 61.608746498823166, 77.07539856433868, 60.911506712436676, 51.45208530128002, 46.90625622868538, 45.51431491971016, 43.1400541216135, 42.46198810636997, 45.19005551934242, 39.15028341114521, 44.69111189246178, 37.4450109153986, 32.92615659534931, 23.945133313536644, 24.737443998456, 15.027070753276348, 17.14912388473749, 18.399473391473293, 18.855779506266117, 25.186340510845184, 34.7727245092392, 18.051269575953484, 36.89005449414253, 25.39144590497017, 28.638649061322212, 28.214470222592354, 18.773061744868755, 16.691831722855568, 18.042951822280884, 15.10888321325183, 7.115000411868095, 9.09324361011386, 4.766766792163253, 2.34111066441983, 1.2405530386604369, 0.7276138721499592, 0.27273324492853135, 1.1888588313013315, 4.512979360297322, 22.45681967586279, 47.169810086488724, 54.520736038684845, 41.16148889064789, 57.26775303483009, 45.00668875873089, 37.88554787635803, 26.42947420477867, 46.08570545911789, 70.09337201714516, 68.19955363869667, 79.70831528306007, 66.03591933846474, 38.01590368151665, 11.306651439517736, 0.6838168285321444, 0.12812314293114468, 0.31664680573157966, 0.31173230381682515, 0.3142770688282326, 0.3859243617625907, 0.44910081080161035, 0.14621916721807793, 0.2944219170603901, 0.23655005759792402, 0.11351873792591505, 0.11135488020954654, 0.08428691391600296, 0.1734731750912033, 0.18440316984197125, 0.09049712403793819, 0.2983186376513913, 0.3129027003888041, 0.18474884738679975, 0.19880751409800723, 0.12254636327270418, 0.08063052300713025, 0.11122023977804929, 0.1510837671230547, 0.17737485322868451, 0.17084962368244305, 0.18633287254488096, 0.14916899643139914, 0.08000740097486414, 0.17274101672228426, 0.23938642727443948, 0.25884442613460124, 0.19999646436190233, 0.25205742625985295], [0.07853596704080701, 0.14340779307531193, 0.017121805176429916, 0.07363909855484962, 0.025024028509506024, 0.07132500788429752, 0.02205134300311329, 0.03796518038143404, 0.061865723473601975, 0.06895101105328649, 0.020720163847727235, 0.0528022969228914, 0.019815183404716663, 0.02766954006801825, 0.043588329426711425, 0.019003169945790432, 0.05016254814108834, 0.08533590254955925, 0.0072014953821053496, 0.05076431858469732, 0.002573794813542918, 0.03936344597605057, 0.06706012267386541, 0.08073669465375133, 0.061019248387310654, 0.026196221078862436, 0.11794078032835387, 0.16935486404690892, 0.30593431962188333, 0.18782693456159905, 0.15965143160428852, 0.49310972273815423, 7.82015897333622, 19.442773908376694, 44.93104241788387, 51.950770542025566, 47.631986886262894, 44.87735889852047, 41.32206067442894, 30.613471493124962, 32.50578135251999, 33.10601234436035, 21.468346416950226, 32.36260883510113, 41.553491055965424, 33.8310020416975, 22.35089845955372, 4.953699661418796, 0.9105217480100691, 0.14763184532057494, 0.24994764884468168, 0.2582983241882175, 2.5394412595778704, 3.2338696718215942, 4.109882265329361, 5.934279793873429, 8.269992135465145, 9.306992590427399, 5.252360785380006, 9.884401056915522, 6.128738159313798, 11.080545522272587, 9.65265054255724, 11.705337446182966, 4.812649805098772, 11.07571218162775, 18.2375355809927, 18.2381359487772, 15.043889600783587, 23.530216477811337, 29.76224686950445, 31.834708862006664, 33.865914568305016, 39.51602518558502, 45.34198276698589, 41.75586059689522, 47.200390845537186, 51.39329865574837, 52.99347639083862, 53.93834888935089, 58.55851337313652, 54.4022735953331, 52.88692630827427, 47.24211260676384, 34.175366163253784, 48.376100957393646, 49.32546481490135, 56.2959323823452, 45.47411687672138, 56.645418629050255, 48.35541486740112, 58.64162631332874, 56.87201946973801, 49.83860448002815, 51.937383860349655, 48.94169680774212, 48.62083442509174, 50.739471539855, 44.69505228102207, 34.61093299090862, 35.81250071525574, 30.357494428753853, 30.346136838197708, 27.378553077578545, 17.454498298466206, 14.090858940035105, 29.241125732660294, 14.920351579785347, 30.967126116156578, 15.659543965011835, 14.783521872013807, 18.54070421308279, 10.4744409956038, 8.78251813352108, 7.619959115982056, 5.030762376263738, 3.3757827943190932, 6.783926552161574, 4.494550824165344, 5.910083642229438, 2.1113443560898304, 1.6427326016128063, 0.4750160139519721, 0.3058271831832826, 0.27736777905374765, 0.24809775670291856, 1.3910920545458794, 7.2930878307670355, 20.532528832554817, 38.163875341415405, 47.47833073139191, 37.32560612261295, 25.06078764796257, 16.40832133591175, 36.57654091715813, 55.07063873112202, 55.788355618715286, 46.36467508971691, 56.915124356746674, 54.78072948753834, 42.01161727309227, 17.46719341725111, 1.416088656987995, 0.03967994969571009, 0.03831495087069925, 0.039983532624319196, 0.15352347370935604, 0.15119495568796992, 0.15140107978368178, 0.05212289783230517, 0.0372841225907905, 0.010404184977232944, 0.06999347620876506, 0.029396209720289335, 0.010577226912573678, 0.03351512561494019, 0.058820242556976154, 0.04172292639850639, 0.00528043777194398, 0.122316319757374, 0.06186452490510419, 0.03866941544401925, 0.030908773478586227, 0.05897331422602292, 0.021819729845447, 0.01218643870743108, 0.005578382697422057, 0.08968879163148813, 0.04377351011498831, 0.023548165809188504, 0.054813999522593804, 0.051115513997501694, 0.030303629973786883, 0.07206602007499896, 0.09672362430137582, 0.07441984533215873, 0.04367356137663592, 0.034457727379049174, 0.03775533812586218, 0.024773763325356413, 0.016448868336738087, 0.06719220269587822, 0.028932510285812896, 0.02987943691550754, 0.06943927000975236, 0.03227640321711078, 0.027176831936230883, 0.07380783325061202, 0.05693634520866908, 0.01739371695293812, 0.01723894205497345, 0.021947689092485234, 0.08510717263561673, 0.025743674268596806, 0.060099434267613105, 0.06195297777594533, 0.04114233313885052, 0.02413429549051216, 0.10557731249718927, 0.009937066097336356, 0.09443177579669282, 0.03280519085819833, 0.044091735617257655, 0.05539468183997087, 0.11870407179230824, 0.1379772907239385, 0.027744276194425765, 0.3961565002100542, 8.793829176574945, 26.242229752242565, 50.968052074313164, 64.39661130309105, 61.97867564857006, 56.79262273013592, 50.66907271742821, 39.85303670167923, 36.60316228866577, 33.69720742106438, 32.00789026916027, 32.75094799697399, 37.670939192175865, 38.892140462994576, 23.826760165393353, 6.407252289354801, 1.1356318811886013, 0.1291655338718556, 0.3891172294970602, 1.397500648163259, 3.8063631020486355, 6.0464906226843596, 8.658695127815008, 8.892817664891481, 11.106538977473974, 11.013630162924528, 9.887045715004206, 15.284200105816126, 17.891890928149223, 19.23556722700596, 14.737413246184587, 10.593985430896282, 9.741535373032093, 3.9343449845910072, 9.18656375259161, 13.63806763663888, 13.735479209572077, 20.83887219429016, 25.30912522226572, 31.64795458316803, 34.746809899806976, 40.73783062398434, 45.18229253590107, 42.85597376525402, 48.62845681607723, 52.56693407893181, 52.97706887125969, 57.34152227640152, 59.284483417868614, 57.56245382130146, 58.264378756284714, 53.34777317941189, 43.203822299838066, 54.60761457681656, 58.11195753514767, 62.482205629348755, 55.04057854413986, 62.97907076776028, 56.16501420736313, 59.438074976205826, 59.07186582684517, 51.362451910972595, 53.007163256406784, 49.91558454930782, 49.29573141038418, 50.29131218791008, 46.93906746804714, 42.207074984908104, 38.40439863502979, 33.20076785981655, 27.93335560709238, 25.62975961714983, 16.28223080188036, 15.05778830498457, 18.596318028867245, 19.179594330489635, 18.946769423782825, 12.421752903610468, 17.351174242794514, 16.042672656476498, 12.701185159385204, 13.402367234230042, 12.320248950272799, 12.42714861407876, 8.844760693609715, 8.199348226189613, 9.29323447868228, 5.581429302692413, 7.014366136863828, 5.585809042677283, 1.8794779479503632, 1.2386131240054965, 0.47123266384005547, 0.31028772820718586, 1.411269921809435, 7.20211073756218, 21.064401492476463, 34.86616529524326, 41.242941319942474, 39.9878990650177, 33.17552961409092, 18.539661169052124, 29.4432919844985, 53.19624111056328, 59.70161743462086, 50.801317021250725, 61.00074112415314, 63.43449912965298, 47.342541217803955, 19.755033552646637, 1.00985589902848, 0.05229195907304529, 0.058677679699030705, 0.09457071326323785, 0.00801798631073325, 0.08160220211721025, 0.053062423394294456, 0.05003265003324486, 0.02065358577965526, 0.05567993001022842, 0.00786257594882045, 0.08591387231717817, 0.021333877302822657, 0.09999192392569967, 0.02257114880194422, 0.007722310501776519, 0.06398689656634815, 0.028467508382163942, 0.036874453362543136, 0.005255039623079938, 0.03420069937419612, 0.038830591365695, 0.04069745271408465, 0.06072724667319562, 0.017820422181102913, 0.04787410609424114, 0.03563478843716439, 0.032557551021454856, 0.08140070902300067, 0.12363611065666191, 0.007360654981312109, 0.06127760112576652, 0.01206651691973093, 0.02349377937207464, 0.20621064497390762, 0.250498084933497, 0.10485692459042184, 0.14232534100301564, 0.07139971989090554, 0.2330501188407652, 0.13397125178016722, 0.14851483778329566, 0.20914526015985757, 0.18321316572837532, 0.08064085370278917, 0.18941921240184456, 0.14433068339712918, 0.10454145245603286, 0.12347392170340754, 0.15332235168898478, 0.16447453061118722, 0.22110520745627582, 0.12004559277556837, 0.16413909470429644, 0.15128650702536106, 0.11767812684411183, 0.25901791057549417, 0.14093893492827192, 0.2415572092286311, 0.14675293467007577, 0.20343688287539408, 0.2629848680226132, 0.5606285075191408, 0.4189994197804481, 0.24566480366047472, 1.1042517400346696, 12.31073996052146, 32.858372032642365, 62.277206629514694, 71.25769793987274, 69.38214138150215, 64.08030107617378, 62.99382537603378, 50.36861144006252, 46.65032096207142, 47.66007497906685, 33.66837456822395, 45.62002904713154, 56.18970148265362, 46.22453100979328, 29.647472128272057, 7.253259317949414, 1.5613276697695255, 0.39027845312375575, 0.5367377051152289, 1.7674358538351953, 5.611874694004655, 7.657315386459231, 15.807734113186598, 16.175029054284096, 19.869200326502323, 21.19424432516098, 17.290584594011307, 23.91426756978035, 19.9018082767725, 24.849695675075054, 25.61736848205328, 23.792744390666485, 13.237050455063581, 24.412886314094067, 27.180426008999348, 27.705407738685608, 20.477920062839985, 27.883162200450897, 33.39950479567051, 36.65827073156834, 41.2559100240469, 46.14845149219036, 47.71922640502453, 45.193745121359825, 50.05282938480377, 55.90360723435879, 57.57987588644028, 61.28669857978821, 63.67275394499302, 63.78365099430084, 61.65101543068886, 59.493848383426666, 51.18410848081112, 60.37444353103638, 62.96470753848553, 67.43726134300232, 58.00775572657585, 68.0953024327755, 61.75167962908745, 63.605676144361496, 61.57274343073368, 51.639833226799965, 56.42840087413788, 52.041923850774765, 53.89577217400074, 56.056887209415436, 48.86951208114624, 42.137455120682716, 40.527101531624794, 35.32922364771366, 33.91432777047157, 32.133629322052, 24.038534201681614, 17.46013529598713, 35.948776602745056, 29.393754042685032, 43.941613510251045, 28.801607117056847, 27.894880771636963, 32.284264639019966, 22.57465325295925, 21.8668120354414, 21.740746200084686, 19.865429028868675, 11.679660324007273, 16.471603140234947, 11.630743648856878, 10.995368342846632, 9.352431502193213, 6.581241628155112, 1.5381321706809103, 0.9067747334484011, 0.564252563053742, 0.5136874888557941, 2.163256458006799, 8.820736482739449, 25.714683160185814, 47.092944011092186, 63.14900524914265, 50.67735247313976, 36.664187014102936, 25.466983951628208, 48.26517730951309, 67.06378698348999, 68.60200524330139, 60.71905463933945, 74.67949032783508, 76.50866657495499, 60.30622199177742, 24.58209503442049, 3.063460453413427, 0.156656168110203, 0.24250231945188716, 0.2586762554710731, 0.363462342065759, 0.3449716733302921, 0.37878038885537535, 0.194566689315252, 0.27844442753121257, 0.16973928170045838, 0.16907287761569023, 0.2900016854982823, 0.07025918734143488, 0.15238237712765113, 0.12122062777052633, 0.0852979120099917, 0.1886528410250321, 0.26885754195973277, 0.21444211655762047, 0.1598261034814641, 0.08320065462612547, 0.18912830535555258, 0.11286701352219097, 0.18929742596810684, 0.13139301590854302, 0.17768219142453745, 0.10760839999420568, 0.22664404852548614, 0.14143816282739863, 0.23948304005898535, 0.11317792144836858, 0.3051885205786675, 0.21911452990025282, 0.25268388795666397], [0.03443777473876253, 0.21882537432247773, 0.024639868752274197, 0.04498568960116245, 0.025519137489027344, 0.04253255756339058, 0.03125234703475144, 0.04620056308340281, 0.04178319621132687, 0.026245770568493754, 0.05631819927657489, 0.02552367757743923, 0.020514921052381396, 0.07104181917384267, 0.04781073781487066, 0.05472604389069602, 0.04141641198657453, 0.04431502558873035, 0.049164923548232764, 0.021954887924948707, 0.04550167890556622, 0.04277381121937651, 0.0812647253042087, 0.048943177243927494, 0.04609031333529856, 0.04438759649929125, 0.15289840725017712, 0.17985362646868452, 0.16590362502029166, 0.12393516648444347, 0.12522933102445677, 1.3095997273921967, 13.099257498979568, 35.22014670073986, 54.71302852034569, 50.556735545396805, 45.386831760406494, 31.98585145175457, 32.46009260416031, 27.86636710166931, 37.86276429891586, 33.64421546459198, 31.14494327455759, 39.45664957165718, 45.07409334182739, 31.041600219905376, 9.141234084963799, 3.20485632866621, 0.23565069335745648, 0.08121604041662067, 0.16914081381401047, 1.7262402456253767, 4.859516015276313, 4.671145873144269, 8.315602038055658, 7.586949812248349, 7.521573845297098, 9.110800568014383, 4.526804443448782, 8.251420632004738, 15.890811905264854, 14.377920236438513, 9.22288790345192, 5.660172952339053, 10.140632707625628, 5.732039920985699, 19.27900079637766, 25.982488989830017, 31.052505634725094, 30.541484355926514, 39.10872504115105, 43.66258308291435, 49.69021484255791, 50.49202501773834, 52.091024816036224, 55.662608966231346, 62.0406237244606, 61.39706365764141, 64.79324162006378, 63.996051996946335, 65.35509467124939, 60.43919585645199, 56.79095461964607, 49.86569702625275, 34.55437682569027, 40.71588680148125, 48.98940324783325, 53.117098957300186, 46.005145981907845, 47.12062552571297, 49.29874464869499, 67.30988457798958, 67.45330408215523, 62.69261933863163, 61.80775701999664, 60.6688479334116, 61.739953458309174, 56.72749802470207, 56.85701407492161, 49.09947194159031, 44.077042043209076, 41.00966423749924, 42.018327713012695, 34.97949421405792, 25.48140037804842, 26.296768225729465, 29.526568315923214, 19.490744434297085, 23.35108269006014, 13.473272379487753, 14.69163615256548, 20.52861124277115, 9.750490542501211, 11.135383229702711, 10.09033290669322, 7.8015869949012995, 8.838485330343246, 7.39926790818572, 3.259088206104934, 2.413385398685932, 4.902167301625013, 5.165365878492594, 2.907842416316271, 1.890121295582503, 0.304456822341308, 0.17802021000534296, 0.12240059062605724, 3.050666064955294, 6.846945695579052, 24.61899295449257, 46.61133125424385, 42.75166556239128, 36.30510248243809, 60.235883966088295, 75.49735084176064, 72.37902536988258, 59.270959943532944, 48.04667763411999, 52.12466061115265, 54.324776753783226, 48.62481661140919, 25.02639189362526, 4.651747914031148, 0.04531870239588898, 0.1237876720551867, 0.058897244089166634, 0.16750341339502484, 0.07891144181485288, 0.1802312015206553, 0.015981810684024822, 0.03783492233196739, 0.10345156406401657, 0.059277494583511725, 0.017763020769052673, 0.05461599081172608, 0.08749642060138285, 0.025623225556046236, 0.023285395436687395, 0.034719787145149894, 0.04037563892779872, 0.06838124201749451, 0.01985997943847906, 0.04528387340542395, 0.08164054888766259, 0.015238536798278801, 0.04577734223857988, 0.039260547200683504, 0.040876885468605906, 0.058364207652630284, 0.12197751450003125, 0.041253414092352614, 0.07164510359871201, 0.05886824095796328, 0.05387946490372997, 0.06700855083181523, 0.12473538721678779, 0.03274603055615444, 0.04294047161238268, 0.03714996455528308, 0.07505153174861334, 0.055203797746798955, 0.030979071561887395, 0.016445122346340213, 0.029006331715208944, 0.015897881203272846, 0.03712905083375517, 0.022137901542009786, 0.03746171852981206, 0.021737503593612928, 0.10750944202300161, 0.05066451456514187, 0.03648993922979571, 0.03561444245860912, 0.01216593131175614, 0.0815646123373881, 0.07533918076660484, 0.015416784899571212, 0.07644554483704269, 0.0943383839330636, 0.03293073626991827, 0.031905796931823716, 0.01797270346287405, 0.07458813473931514, 0.09424764153664, 0.12594262399943545, 0.041660838323878124, 0.15944192331517115, 1.8021225300617516, 15.61928702518344, 38.08577813208103, 63.58488366007805, 60.526119992136955, 54.69960384070873, 43.12818355858326, 42.43496775627136, 36.5868915617466, 48.76884788274765, 32.3804222792387, 21.116889975965023, 37.47102431952953, 45.701584070920944, 29.903610683977604, 9.908416718244553, 2.904129778034985, 0.34393890062347054, 0.19528559292666614, 0.8293394604697824, 3.145878268405795, 7.0818908885121346, 11.072626747190952, 10.657047796994448, 10.832698121666908, 11.699160877615213, 12.327906489372253, 15.453161839395761, 17.04494297504425, 19.531022273004055, 18.79782121628523, 11.644193977117538, 9.079420901834965, 8.39789517223835, 8.983110319823027, 14.840062838047743, 22.842424884438515, 29.970711283385754, 31.552972979843616, 37.25717179477215, 43.851668536663055, 48.03131505846977, 51.408782824873924, 53.98913696408272, 57.3954413831234, 61.9170543551445, 63.02683800458908, 64.95097875595093, 64.70333844423294, 65.43210133910179, 63.552885577082634, 60.883661806583405, 58.94520342350006, 41.63308538496494, 49.30455073714256, 55.555735900998116, 58.965410739183426, 53.948076367378235, 57.27554261684418, 57.27781489491463, 67.17517420649529, 67.34610423445702, 62.97289229929447, 61.941069066524506, 61.72356113791466, 61.76919288933277, 60.065941885113716, 58.64273585379124, 52.83966064453125, 45.47640435397625, 46.17728054523468, 40.026501193642616, 36.34963609278202, 26.305530555546284, 20.019780546426773, 19.248133152723312, 19.045771211385727, 13.61918929964304, 15.433913972228765, 16.713741347193718, 17.221603095531464, 11.9382250495255, 15.481991842389107, 14.59372490644455, 19.014479890465736, 10.70515701547265, 10.963590648025274, 9.205394592136145, 7.8302293829619884, 7.758968006819487, 6.759690977632999, 5.153654906898737, 3.689068383537233, 0.9486556705087423, 0.08992105416837148, 0.41506903537083417, 2.834194293245673, 7.630997998639941, 25.30626017600298, 41.708522737026215, 37.65907242894173, 30.02815470099449, 42.200831919908524, 72.09765806794167, 80.00242710113525, 66.40763059258461, 52.4800631403923, 58.997815400362015, 63.21933567523956, 55.80732420086861, 28.26827723532915, 5.882525146007538, 0.16057647415436804, 0.09918895724695176, 0.09192391036776826, 0.04908179187623318, 0.053962707897881046, 0.08888122363714501, 0.10698399404645897, 0.012630744895432144, 0.07891343819210306, 0.012183683484181529, 0.062242953426903114, 0.10090394178405404, 0.06952614581678063, 0.06612846758798696, 0.04969073517713696, 0.019750139726966154, 0.04948237350618001, 0.026147597418457735, 0.02241125865111826, 0.043291192050674, 0.014979804636823246, 0.013953830930404365, 0.007773887909934274, 0.032143080097739585, 0.022594815891352482, 0.041929462386178784, 0.1104216517705936, 0.0778868624183815, 0.037211299350019544, 0.07092257830663584, 0.0160613132538856, 0.05533284980629105, 0.02415592723991722, 0.2168504154542461, 0.336893099010922, 0.15278750070137903, 0.17078493809094653, 0.18722561682807282, 0.1311918642022647, 0.1518528547603637, 0.09566984139382839, 0.16781940503278747, 0.102142408140935, 0.13480610854458064, 0.11856662604259327, 0.14627778204157948, 0.1993710416718386, 0.13086058432236314, 0.12221997414599173, 0.16024798474973068, 0.2877540764166042, 0.26041029836051166, 0.14777159172808751, 0.1764455359079875, 0.2675567945698276, 0.1545250168419443, 0.15940155048156157, 0.10831923646037467, 0.22989475924987346, 0.2931955922394991, 0.31439869198948145, 0.3515963506652042, 0.3057052631629631, 0.2874659450026229, 2.9337202152237296, 20.960815250873566, 49.55432653427124, 71.09032452106476, 71.77120238542557, 63.52404512465, 49.956694543361664, 48.08491878211498, 42.42519088089466, 56.973960399627686, 49.81132194399834, 45.18827721476555, 57.43896044790745, 61.6864675283432, 39.68658663332462, 12.48252684250474, 3.6051591485738754, 0.5859094415791333, 0.28530344541650265, 1.1009937711060047, 2.089601685293019, 11.464324928820133, 13.045961558818817, 13.951094839721918, 20.235335379838943, 17.570469975471497, 19.474745392799377, 16.01651296019554, 21.87200255692005, 26.574318632483482, 29.25761304795742, 22.25892249494791, 15.662838388234377, 17.93318711221218, 11.58112021163106, 24.006720408797264, 27.985623702406883, 34.547822177410126, 34.02444966137409, 41.612384095788, 47.62768171727657, 52.00092785060406, 54.2997170984745, 57.06481732428074, 58.20853695273399, 63.061218559741974, 62.29420691728592, 64.9410916864872, 65.23373678326607, 63.997184336185455, 64.12489548325539, 65.57783111929893, 61.906802505254745, 50.26755966246128, 54.10775139927864, 61.04780539870262, 61.52554236352444, 57.91446693241596, 61.62664733827114, 64.96215775609016, 70.4648856818676, 70.8234952390194, 63.88760581612587, 63.60189154744148, 64.64089259505272, 65.69481924176216, 61.321253925561905, 63.4005593508482, 57.677998021245, 50.67092701792717, 46.7107605189085, 45.655416548252106, 39.35422606766224, 30.75724057853222, 32.296382188797, 44.140601232647896, 31.99420340359211, 33.083642944693565, 22.882700823247433, 29.035889245569706, 35.585307106375694, 22.22797315567732, 21.577712148427963, 18.18217635154724, 18.19010842591524, 17.963701374828815, 15.750935710966587, 13.362613767385483, 9.636314269155264, 15.05881329998374, 11.573456972837448, 7.1618252992630005, 4.008252443745732, 0.8322392986156046, 0.3492132847895846, 0.5146891507320106, 3.778516771271825, 8.86971490457654, 31.97997696697712, 55.76552264392376, 56.1245995759964, 51.13245405256748, 75.39517432451248, 84.09622102975845, 79.11921009421349, 71.03559985756874, 62.60271996259689, 68.61589729785919, 75.93529254198074, 66.21521651744843, 36.72610469162464, 8.354508150368929, 0.679460777901113, 0.287302850629203, 0.2098301288788207, 0.252984962426126, 0.30569920723792166, 0.2982077607885003, 0.24457933846861124, 0.19609339098678902, 0.1991840501432307, 0.11064740567235276, 0.11689870851114392, 0.17819675209466368, 0.23642775166081265, 0.20283534249756485, 0.13404739613179117, 0.11733417850336991, 0.14008819620357826, 0.16647216951241717, 0.09585517793311737, 0.1494160425500013, 0.14277693786425516, 0.15327568544307724, 0.09387281985254958, 0.13416507106740028, 0.26680434588342905, 0.18976239633047953, 0.2838399005122483, 0.21676373260561377, 0.15453116182470694, 0.2302416242309846, 0.10816996087669395, 0.18273203138960525, 0.23120625293813646], [0.05069070866738912, 0.06233223379240371, 0.03263565093220677, 0.016809147637104616, 0.055506449280073866, 0.01980675817321753, 0.013427984977170127, 0.01879158920928603, 0.045084068697178736, 0.07523933221818879, 0.027210547705180943, 0.009000503559946083, 0.006469741019827779, 0.04778255104611162, 0.0980481575243175, 0.04351663796114735, 0.08248819285654463, 0.05255051961285062, 0.0333615047566127, 0.04859205975662917, 0.008522453772457084, 0.05202710883168038, 0.028427441684470978, 0.11503183603053913, 0.10784707468701527, 0.14300600916612893, 0.02492800758773228, 0.14747430221177638, 0.04679650395701174, 0.14907995355315506, 0.3506224451120943, 2.7681118017062545, 17.767054326832294, 45.44418968260288, 54.0809590369463, 53.20062607526779, 45.86887389421463, 36.97438336908817, 29.246793128550053, 23.78166038542986, 29.87049736082554, 25.19541062414646, 49.01861608028412, 46.68339058756828, 29.9268901348114, 19.536005705595016, 4.815257415175438, 0.7310967415105551, 0.041150786200887524, 0.23340672079939395, 1.6603185329586267, 4.629325792193413, 2.1290468936786056, 10.184019729495049, 9.561786968261003, 5.4450745694339275, 8.316411394625902, 9.577114395797253, 12.6515949703753, 17.193458005785942, 22.614822797477245, 20.54759882390499, 13.344391845166683, 12.406329531222582, 15.62260139733553, 14.014924764633179, 24.823771566152573, 34.2681609839201, 38.72230477631092, 48.05010885000229, 50.229417309165, 56.380170062184334, 58.26640024781227, 65.87384283542633, 61.15974739193916, 62.45021514594555, 67.05006211996078, 66.12063959240913, 67.46221840381622, 65.06653815507889, 66.29764169454575, 62.61281222105026, 59.138457253575325, 52.44834624230862, 37.63455994427204, 33.58958579599857, 46.694060415029526, 51.660078540444374, 43.2318039983511, 42.82037727534771, 41.853496357798576, 65.53705930709839, 65.94774886965752, 62.32354514300823, 64.50261801481247, 63.04264895617962, 64.40880104899406, 64.75576803088188, 59.83387313783169, 60.486184135079384, 58.45335781574249, 55.77191390097141, 46.64037309587002, 52.31128379702568, 38.29980164766312, 40.11776849627495, 27.161689214408398, 48.362224102020264, 18.919173404574394, 12.8514395467937, 17.51120075583458, 11.299781408160925, 8.167061358690262, 12.294264044612646, 12.729392945766449, 16.643371023237705, 7.355306167155504, 5.99464145489037, 9.134502746164799, 4.433162743225694, 7.0831243973225355, 7.575741363689303, 2.3774051293730736, 3.610281036235392, 1.2967186560854316, 0.1262741710525006, 0.043717785956687294, 0.18140814383514225, 4.826546609401703, 9.77781392633915, 28.141635730862617, 37.8403303027153, 61.90297231078148, 59.96262922883034, 53.8271364569664, 31.821947246789932, 27.52907820045948, 27.608756124973297, 44.81125004589558, 55.538036450743675, 54.69299219548702, 35.376656502485275, 5.919191278517246, 0.6779065425507724, 0.018324093689443544, 0.020528530185401905, 0.04742450932099018, 0.10182476893533021, 0.030544952278432902, 0.04925535795337055, 0.03823599006864242, 0.010638247222232167, 0.05883091835130472, 0.0332766513020033, 0.010844841654034099, 0.022620570271101315, 0.09121247276198119, 0.03850293687719386, 0.026912191351584624, 0.042583031026879326, 0.031002976138552185, 0.058886709302896634, 0.08214519446482882, 0.05282762271235697, 0.0424290650698822, 0.06931272640940733, 0.06636223668465391, 0.019386218336876482, 0.06089179194532335, 0.016705198722775094, 0.020960886868124362, 0.014806782182859024, 0.08619574742624536, 0.041613856665208004, 0.12265543671674095, 0.034417425049468875, 0.055640117498114705, 0.021513540123123676, 0.059250031408737414, 0.04282956135284621, 0.015908280547591858, 0.028538980914163403, 0.04443554666067939, 0.039176142745418474, 0.053717012488050386, 0.043816732795676216, 0.06962487372220494, 0.032389847910963, 0.07998356319149025, 0.023465358826797456, 0.04274648534192238, 0.02057374924333999, 0.039051447092788294, 0.0784137353184633, 0.05800364633614663, 0.01955914245627355, 0.044073879544157535, 0.029605228191940114, 0.048036410080385394, 0.009217429615091532, 0.06927060210728087, 0.05084648546471726, 0.017274132842430845, 0.07214228317025118, 0.0783403220702894, 0.012776404364558402, 0.475106555968523, 3.553119753487408, 21.052713319659233, 53.461124897003174, 64.91489589214325, 64.14515599608421, 55.72438985109329, 42.89342075586319, 36.22595652937889, 27.76573710143566, 33.724535554647446, 34.94900085031986, 48.05165536701679, 43.712235018610954, 33.95263731479645, 20.591070391237736, 5.870441319420934, 0.4749440256273374, 0.2214195960550569, 0.9879912191536278, 4.368230402469635, 7.080564759671688, 9.14331542328, 11.745029166340828, 11.904827691614628, 13.448179475963116, 14.451858568936586, 9.80975691229105, 20.117857083678246, 23.226073198020458, 24.24345150589943, 18.62059112638235, 9.259189255535603, 11.263077277690172, 18.306325189769268, 16.107096299529076, 23.332554884254932, 33.43094430863857, 39.2343956977129, 45.90488836169243, 49.608173444867134, 55.36134213209152, 61.42778120934963, 63.83409708738327, 61.0803734511137, 64.38311442732811, 67.03383699059486, 66.14433512091637, 67.44277104735374, 66.85754925012589, 67.60215729475021, 65.94496741890907, 62.20114231109619, 59.64535005390644, 45.54092489182949, 41.466635316610336, 55.60652017593384, 57.09798574447632, 51.835921704769135, 51.550633013248444, 48.91791008412838, 67.16896533966064, 67.98693984746933, 62.16872625052929, 66.70764729380608, 65.69424167275429, 66.96172446012497, 66.40868693590164, 64.39683929085732, 62.295046672225, 61.86633847653866, 58.03238980472088, 50.90334914624691, 49.02872733771801, 38.624714612960815, 35.09717769920826, 29.3605400249362, 29.31660298258066, 20.244648680090904, 16.621197313070297, 17.14189287275076, 11.36955801397562, 16.755394712090492, 16.760129258036613, 18.72723240405321, 21.177637316286564, 12.283349130302668, 11.745458543300629, 13.121776040643454, 9.73893441259861, 6.284343134611845, 5.85950693115592, 8.340348210185766, 4.775464050471783, 2.306935298256576, 0.40773750690277666, 0.1149556842574384, 0.22983804432442412, 4.131837962195277, 10.881048627197742, 29.120544902980328, 37.04345226287842, 47.301594614982605, 58.161700665950775, 61.661594063043594, 45.808593928813934, 35.3804486989975, 34.27690051496029, 49.1168712079525, 65.15375107526779, 62.364332154393196, 41.903266087174416, 7.464650049805641, 0.6745348172262311, 0.021426976018119603, 0.0516823107318487, 0.06748201878508553, 0.04929022405121941, 0.05294293019687757, 0.10291908052749932, 0.04158790747169405, 0.012913893715449376, 0.050221541459904984, 0.00972611896941089, 0.06852320744656026, 0.062363886390812695, 0.08010247751371935, 0.048816051057656296, 0.08486948499921709, 0.044360370811773464, 0.036698438198072836, 0.022151571902213618, 0.10086270063766278, 0.05405384363257326, 0.02471995205269195, 0.051140876894351095, 0.015318610821850598, 0.021512573475774843, 0.06088893838750664, 0.0855001992022153, 0.1371990449842997, 0.023236576962517574, 0.04914544217172079, 0.020883863071503583, 0.09658721755840816, 0.043672756146406755, 0.26497797982301563, 0.177986427443102, 0.07137643871828914, 0.13240239612059668, 0.14384321111720055, 0.18977587373228744, 0.21408457949291915, 0.09916133451042697, 0.11200809633010067, 0.1644975520321168, 0.1347741813515313, 0.11862755636684597, 0.15767006058013067, 0.11670436229906045, 0.2788133342983201, 0.14267513004597276, 0.18488126137526706, 0.21535656123887748, 0.13905147527111694, 0.20204088825266808, 0.07792896445607767, 0.14407597831450403, 0.249343421892263, 0.21423272701213136, 0.2770908095408231, 0.21367733337683603, 0.1489835188840516, 0.2502729173284024, 0.2118288810015656, 0.20978169632144272, 0.7627988560125232, 5.814267983660102, 28.417343236505985, 61.40610717236996, 73.97139072418213, 73.97294864058495, 64.28796753287315, 54.64468538761139, 42.827756479382515, 34.88210543990135, 41.84506841003895, 39.43880952894688, 64.97562423348427, 64.82408076524734, 43.54303389787674, 24.60147589445114, 6.4188977144658566, 1.114776344038546, 0.28006521868519485, 0.5917837482411414, 5.434558158740401, 9.545586537569761, 11.063273549079895, 24.616846069693565, 20.298731178045273, 18.440788574516773, 24.187102429568768, 24.311317764222622, 23.472746461629868, 28.50213758647442, 37.40874946117401, 35.69968096911907, 26.55577752739191, 22.827504985034466, 23.66137593984604, 19.437036216259003, 26.381963454186916, 38.71243670582771, 43.1211007386446, 51.0030709952116, 50.64243234694004, 59.19378988444805, 62.89321057498455, 67.3289367556572, 62.95397311449051, 64.96704429388046, 67.01240614056587, 66.97854235768318, 69.84264627099037, 68.46802443265915, 66.3514544069767, 66.75930932164192, 66.35139361023903, 62.15557515621185, 53.221878334879875, 47.28929087519646, 59.80537086725235, 62.130245715379715, 54.545047134160995, 54.43259596824646, 55.97978934645653, 69.66060563921928, 67.13922053575516, 61.986157447099686, 68.42065617442131, 67.83260732889175, 68.28214600682259, 70.86533859372139, 64.76114094257355, 66.26348912715912, 63.247001990675926, 60.79014502465725, 50.23441404104233, 55.612375661730766, 42.91805103421211, 47.47361518442631, 40.157639756798744, 54.60764117538929, 24.940558299422264, 25.21838989108801, 34.32747580111027, 20.43769922107458, 16.021522991359234, 22.10177432745695, 27.13387280702591, 27.50785443931818, 19.80594702064991, 16.842778623104095, 24.874631837010384, 13.141224347054958, 17.13408049196005, 16.344834342598915, 9.624329712241888, 6.911581652238965, 2.5002349633723497, 0.695203630020842, 0.19737510971026495, 0.43678222806192935, 5.85229491814971, 12.734917849302292, 34.42876696586609, 48.38002994656563, 73.43173608183861, 67.42966935038567, 58.39756540954113, 42.33993485569954, 39.27126131951809, 41.68730087578297, 58.68568494915962, 73.19624751806259, 73.51435884833336, 50.359153747558594, 11.62451958283782, 1.6880243900232017, 0.14780368219362572, 0.2683851501205936, 0.240569484885782, 0.26888372492976487, 0.20343622978543863, 0.26318097312469035, 0.11104573117336258, 0.1933848042972386, 0.15238242165651172, 0.09889813183690421, 0.18962015630677342, 0.14574263419490308, 0.1749927076161839, 0.19874140358297154, 0.11096686313976534, 0.11534240256878547, 0.1295153674436733, 0.11807198461610824, 0.22869377135066316, 0.19132368208374828, 0.14022255461895838, 0.1626200816826895, 0.22645385091891512, 0.09796791651751846, 0.17345662519801408, 0.1580307146650739, 0.2849256922490895, 0.1382345042657107, 0.09783956207684241, 0.21925167879089713, 0.32420424395240843, 0.26456935331225395], [0.04508030600845814, 0.04185239034995902, 0.04200783318083268, 0.05070657949545421, 0.011441058049967978, 0.12494304013671353, 0.04821429174626246, 0.04147059618844651, 0.019701124583662022, 0.05703455361071974, 0.04508689627982676, 0.0656374404206872, 0.056974209583131596, 0.007959753693285165, 0.037183116291998886, 0.06055178069800604, 0.029880064030294307, 0.022219788261281792, 0.056006378508755006, 0.05445412469271105, 0.017373135342495516, 0.040918208251241595, 0.0606197577144485, 0.043293670823914, 0.04084502506884746, 0.04428268279298209, 0.04931489675072953, 0.1590270033921115, 0.1301277580205351, 0.054055591390351765, 1.2557355989702046, 6.333639789372683, 32.93459214270115, 52.636998519301414, 48.50802227854729, 53.074514642357826, 44.559129774570465, 36.14254340529442, 30.626842975616455, 25.850111693143845, 27.975111566483974, 27.074402198195457, 36.9848670065403, 38.70279662311077, 23.122927732765675, 9.848610777407885, 1.1746762110851705, 0.35942624614108354, 0.35183238331228495, 0.583051519934088, 1.8278078455477953, 7.24789590574801, 10.35042230039835, 7.749249078333378, 10.802826024591923, 12.95104930177331, 12.110555302351713, 7.709306096658111, 26.968564577400684, 22.224332951009274, 20.04674769937992, 15.590986143797636, 7.821033876389265, 14.567821696400642, 25.982770174741745, 32.00815625488758, 34.14635471999645, 42.753402069211006, 50.48373386263847, 52.906191274523735, 60.18679820001125, 67.36363649368286, 63.26881282031536, 64.32084336876869, 65.82835167646408, 65.43217733502388, 66.50390222668648, 68.19112569093704, 66.42470687627792, 66.32160320878029, 63.603616654872894, 67.09961906075478, 59.67894405126572, 60.15687860548496, 44.2196673899889, 32.591443955898285, 39.82999473810196, 46.26059867441654, 39.099814519286156, 48.96550253033638, 42.73112006485462, 69.06579315662384, 59.73214879631996, 60.84894686937332, 63.407520577311516, 65.1993790268898, 62.890668511390686, 66.39410331845284, 66.2022516131401, 67.62302577495575, 63.87879028916359, 67.5803692638874, 61.774307414889336, 59.97810959815979, 50.24954482913017, 43.4748275578022, 34.175031781196594, 35.15901558101177, 34.87979516386986, 33.73387925326824, 22.657783292233944, 20.484024435281754, 23.548284508287907, 21.632320918142796, 16.201473735272884, 26.131178811192513, 10.559311341494322, 15.015099495649338, 9.518241304904222, 10.412635412067175, 4.790593413636088, 1.347548884805292, 9.072485323995352, 3.7646126048639417, 2.0615504030138254, 0.35044340940658003, 0.032134634457179345, 0.03050446441193344, 0.527143576182425, 4.943679124116898, 9.973042700439692, 35.64749836921692, 41.92732259631157, 40.383142456412315, 37.81532384455204, 27.0858433842659, 25.312767326831818, 33.84465090930462, 54.83110338449478, 47.75697737932205, 53.97798076272011, 43.92623953521252, 18.126323148608208, 3.4196756640449166, 0.11225581038161181, 0.04954562304192223, 0.1357228241977282, 0.015278437440429116, 0.032545854774070904, 0.04605176247423515, 0.10238969916827045, 0.06261024973355234, 0.055262965470319614, 0.008856178101268597, 0.02499804035323905, 0.0372780592442723, 0.03957286891818512, 0.051075935261906125, 0.08588298413087614, 0.047020840356708504, 0.04516071770922281, 0.03732865516212769, 0.04319056053645909, 0.059773891189252026, 0.023704961204202846, 0.05255103169474751, 0.06693346775136888, 0.011859704482048983, 0.032765753130661324, 0.06940915365703404, 0.059091827788506635, 0.07190164920757525, 0.03411789053643588, 0.03030476174899377, 0.06236817600438371, 0.11983540171058849, 0.06011658530042041, 0.037549214030150324, 0.035938419605372474, 0.03976591266109608, 0.03266316605731845, 0.060961824710830115, 0.038597549573751166, 0.04399797267979011, 0.049369756306987256, 0.07845403393730521, 0.044276793851167895, 0.07126317213987932, 0.10671543306671083, 0.03942679199099075, 0.1032901469443459, 0.029016395237704273, 0.0709427276160568, 0.07744164060568437, 0.017518436725367792, 0.0515317697863793, 0.04469345782126766, 0.06183893565321341, 0.0487593917932827, 0.05426658026408404, 0.06966555825783871, 0.03085960248427, 0.026711618520494085, 0.04097573211765848, 0.1427396375220269, 0.12601061956956983, 1.4792266627773643, 6.99700154364109, 36.03916995227337, 60.9704415500164, 56.7922655493021, 62.105626836419106, 51.707055419683456, 44.44512069225311, 34.08382907509804, 28.883179239928722, 32.331822887063026, 31.72041479498148, 40.20778566598892, 43.53370539844036, 22.404300794005394, 10.034145321696997, 1.420634756796062, 0.41439976659603417, 1.0990671557374299, 2.4004575423896313, 5.697054248303175, 8.056995514780283, 9.309301916509867, 11.63669602945447, 10.934303719550371, 9.134026821702719, 11.364626828581095, 14.153532776981592, 17.54457626491785, 21.9095616415143, 20.453456975519657, 10.42578935623169, 7.25285273976624, 8.244269415736198, 16.29718489944935, 29.904674626886845, 33.64959217607975, 43.93997959792614, 48.863641396164894, 55.15032425522804, 62.52690263092518, 67.71369650959969, 64.41216006875038, 67.92109698057175, 68.17108556628227, 67.5325146317482, 67.65558242797852, 68.97224217653275, 66.48777589201927, 67.40763813257217, 64.53436151146889, 65.83507731556892, 63.26098144054413, 66.3503448665142, 51.23236209154129, 39.63089682161808, 48.611308336257935, 53.28823037445545, 47.68545001745224, 54.96803663671017, 49.42340835928917, 71.56798169016838, 61.44604682922363, 62.05238789319992, 63.69673065841198, 65.19051790237427, 65.49723744392395, 67.61775925755501, 68.22081729769707, 69.27230447530746, 67.187280356884, 70.39275035262108, 61.76117531955242, 59.99306559562683, 50.15435993671417, 44.91326317191124, 34.04438339173794, 31.630948595702648, 24.127071350812912, 20.292723700404167, 14.300632383674383, 13.309385273605585, 17.434938848018646, 17.659121118485928, 17.41289433091879, 15.331732705235481, 14.498141035437584, 13.791362810879946, 11.92136250436306, 12.197222951799631, 10.759907327592373, 10.416062828153372, 7.7339643985033035, 9.635835494846106, 5.137127218768001, 1.1727697821334004, 0.37501387065276504, 0.220694265444763, 0.797122532967478, 5.553834708407521, 11.623857468366623, 31.679069213569164, 45.03237538039684, 52.75751285254955, 49.16886381804943, 29.687200896441936, 29.887334257364273, 38.67637664079666, 58.44225861132145, 54.24820326268673, 61.04365602135658, 51.19176886975765, 21.638683676719666, 4.155127387493849, 0.13138053298462182, 0.06279364926740527, 0.0384612318885047, 0.04696870077168569, 0.044947413334739394, 0.06091593029850628, 0.07623148718266748, 0.030037599717616104, 0.055622228028369136, 0.002096949856422725, 0.01981354882445885, 0.031889432575553656, 0.021899288076383527, 0.04528761754045263, 0.023369434384221677, 0.008380548642890062, 0.055156025700853206, 0.0945689766376745, 0.05004036094760522, 0.04982403232133947, 0.03138513580779545, 0.05685150288627483, 0.014716989735461539, 0.034989902924280614, 0.0504105442087166, 0.06635039200773463, 0.06433598056901246, 0.08527883139322512, 0.02826991712936433, 0.04321619802794885, 0.03950604223064147, 0.11226407048525289, 0.3119752532802522, 0.12304106407100335, 0.12831430532969534, 0.0949272484285757, 0.12738999008433893, 0.26744882692582905, 0.25027469848282635, 0.11512100507388823, 0.10523954624659382, 0.2432133859838359, 0.22148897201986983, 0.15261582710081711, 0.17271777265705168, 0.22900608193594962, 0.243204643484205, 0.17274155106861144, 0.2028578592580743, 0.16700626350939274, 0.18874914210755378, 0.1715332010644488, 0.1037626204197295, 0.16285091929603368, 0.19797360728261992, 0.1396826421841979, 0.13728473335504532, 0.09645400947192684, 0.24224656051956117, 0.20870809064945206, 0.23881142609752715, 0.2712491573765874, 2.313821241259575, 10.33081155270338, 46.21852733194828, 70.0545684993267, 64.98387739062309, 70.73129698634148, 61.317351534962654, 52.77020417153835, 45.96127733588219, 41.792114451527596, 43.67496281862259, 38.42289984226227, 51.855293065309525, 51.37229338288307, 29.586209915578365, 11.796107925474644, 1.9332483876496553, 0.6237435364164412, 1.171681140549481, 3.163933949545026, 4.6954925917088985, 15.710318740457296, 17.482236810028553, 23.407486863434315, 24.05629064887762, 25.89762434363365, 21.821953542530537, 16.34813256561756, 38.30014742910862, 33.19782681763172, 31.60656340420246, 25.211405865848064, 14.80332925915718, 20.8741058036685, 30.150103457272053, 36.9382169097662, 37.07133136689663, 46.01879104971886, 51.346279978752136, 56.55934564769268, 63.60774323344231, 70.42060285806656, 65.86382657289505, 68.67286384105682, 70.19833758473396, 68.16607743501663, 69.24083456397057, 68.93474578857422, 67.29048281908035, 67.46205881237984, 65.53943797945976, 65.178282558918, 66.09822079539299, 68.93162995576859, 57.322945073246956, 47.14848943054676, 53.744502291083336, 58.038184493780136, 49.37396541237831, 59.63731728494167, 55.474142879247665, 71.72227621078491, 59.907942563295364, 61.314068511128426, 64.29266408085823, 66.08278602361679, 67.34379395842552, 67.11756929755211, 68.91486525535583, 70.17404168844223, 67.61675611138344, 70.98174154758453, 66.08160048723221, 63.52354735136032, 54.21622797846794, 47.10375063121319, 38.46606932580471, 36.91070258617401, 39.879521280527115, 42.73524284362793, 32.927976697683334, 29.099499732255936, 32.988731637597084, 33.34087774157524, 24.638626500964165, 38.53616036474705, 22.821902185678482, 24.592293687164783, 15.656954403966665, 19.4138365611434, 14.917154051363468, 15.406867023557425, 18.13438631594181, 9.235574472695589, 7.63970903120935, 1.2539011286571622, 0.37084950192365795, 0.3190183237893507, 0.9564011392649263, 6.643854668363929, 13.367023430764675, 45.48633702099323, 53.43157388269901, 52.071585059165955, 48.407065495848656, 40.19249148666859, 37.263498455286026, 47.463013753294945, 67.85460814833641, 64.55131620168686, 71.39608651399612, 59.908748120069504, 29.294301979243755, 5.935448706150055, 0.4686312284320593, 0.19580006453907117, 0.27258520130999386, 0.23469247680623084, 0.23876321618445218, 0.13897669647121802, 0.14749705645954236, 0.13314359384821728, 0.14174714859109372, 0.05690962047083303, 0.18055124528473243, 0.11269700233242474, 0.07798722304869443, 0.1533196502714418, 0.16179948899662122, 0.10910498531302437, 0.13161405717255548, 0.15160548209678382, 0.11883387342095375, 0.18233591748867184, 0.17445505131036043, 0.15605474647600204, 0.19426338840276003, 0.11398085101973265, 0.15942236030241475, 0.23394893389195204, 0.15095821057911962, 0.23070200812071562, 0.13672160654095933, 0.08913102312362753, 0.3575016197282821, 0.27759695425629616], [0.042178052171948366, 0.030820810425211675, 0.011709758182405494, 0.0391193461837247, 0.06914155746926554, 0.059725380706368014, 0.02620785238832468, 0.05400416426709853, 0.01600761886948021, 0.0027956494250247488, 0.012149085487180855, 0.04522713992628269, 0.04425756851560436, 0.046514680798281915, 0.060924620847799815, 0.051238213272881694, 0.02837889223883394, 0.02691530651645735, 0.019105287610727828, 0.056076081018545665, 0.005010962095184368, 0.05805813481856603, 0.03530865906213876, 0.0741108892543707, 0.07638846625923179, 0.050630379482754506, 0.03533295697707217, 0.04259132452716585, 0.13256917154649273, 0.043921115866396576, 1.408683923073113, 9.646394178271294, 35.985281243920326, 53.25682885944843, 60.87177224457264, 47.63973467051983, 41.45920671522617, 32.34288029372692, 31.232165694236755, 20.10509356856346, 21.888917349278927, 36.61925442516804, 48.75483423471451, 31.85448870062828, 14.506891015917063, 3.457095343619585, 1.1440416611731052, 0.26914537651464343, 0.521614991594106, 3.3075018832460046, 8.228960987180471, 5.3962585888803005, 9.827704299241304, 9.224599711596966, 7.512289043515921, 5.785765238106251, 9.291915949434042, 8.790185172110796, 17.96359308063984, 26.272903606295586, 23.334228694438934, 16.322622634470463, 14.939041826874018, 20.504330545663834, 38.5634732991457, 43.44576671719551, 47.64893017709255, 56.91332705318928, 58.52637469768524, 66.59777238965034, 63.40843252837658, 62.58524090051651, 59.39074471592903, 60.442193895578384, 59.56978730857372, 63.78792956471443, 64.4410689175129, 65.73671579360962, 64.10280346870422, 64.78470727801323, 64.56176564097404, 68.55370223522186, 62.26016454398632, 63.725316524505615, 50.27442209422588, 35.342595130205154, 36.272549629211426, 41.149694323539734, 45.93451917171478, 64.28555086255074, 44.57644544541836, 67.55820125341415, 58.41939143836498, 62.01306380331516, 59.6315947920084, 61.39568813145161, 62.31742367148399, 66.05813294649124, 62.89270140230656, 63.98085281252861, 66.21574088931084, 64.3194830417633, 65.04431694746017, 66.09037801623344, 60.46403132379055, 60.72747878730297, 50.427808463573456, 46.0295444726944, 48.753409311175346, 38.153156116604805, 29.472083039581776, 15.844356548041105, 29.628725834190845, 17.931859083473682, 21.036980263888836, 16.774933263659477, 8.94054215401411, 10.015901550650597, 15.662092678248882, 9.941081665456295, 3.3868264267221093, 6.785007119178772, 7.7017525769770145, 7.765617650002241, 3.258270062506199, 1.5992938075214624, 0.8960743888746947, 0.06909131407155655, 0.2895627496764064, 1.2379983882419765, 6.359580522403121, 13.901807684451342, 21.626788415014744, 19.31097988039255, 21.82073950767517, 26.633730344474316, 24.595751501619816, 28.613346219062805, 31.039643324911594, 48.75089764595032, 48.26167389750481, 49.729649126529694, 24.950838647782803, 5.694925412535667, 0.38796639593783766, 0.029824597768310923, 0.023332399359787814, 0.11798610328696668, 0.10784775746287778, 0.03698957159940619, 0.10296228836523369, 0.048810266016516834, 0.08450281209661625, 0.018577464761619922, 0.06184994170325808, 0.014862410789646674, 0.03554123701178469, 0.015387237217510119, 0.02082268227241002, 0.059290612043696456, 0.08810922678094357, 0.04358527177828364, 0.047081640805117786, 0.08243446878623217, 0.03780463528528344, 0.0202734169215546, 0.013503142272384139, 0.02917628167779185, 0.05479900442878716, 0.04505870951106772, 0.15465302247321233, 0.047425819211639464, 0.06219947841600515, 0.01459648350646603, 0.07085001110681333, 0.122498732234817, 0.0486089621699648, 0.012055544266331708, 0.08203230638173409, 0.03258302895119414, 0.024799345155770425, 0.018348048361076508, 0.009507164995739004, 0.007176939107012004, 0.02514122475986369, 0.03574110480258241, 0.016665376933815423, 0.07396815941319801, 0.05977826614980586, 0.058583111531334, 0.05829918438394088, 0.01852633635280654, 0.02614258606627118, 0.05122036091051996, 0.03548207299900241, 0.04317140570492484, 0.02100840658386005, 0.05439563603431452, 0.03578468371415511, 0.027447636057331692, 0.04930811352096498, 0.08090962248388678, 0.07615910551976413, 0.048314960367861204, 0.01728012939565815, 0.12567377358209342, 1.8331112922169268, 11.998582910746336, 43.07343229651451, 63.235313817858696, 67.67822921276093, 57.44104653596878, 48.358633294701576, 38.72208818793297, 35.27039900422096, 25.660061091184616, 30.693652890622616, 35.50212197005749, 46.69296607375145, 35.91914959251881, 14.793492536991835, 4.061759747564793, 0.7717759336810559, 0.3731388197047636, 1.8662850558757782, 6.69320167042315, 7.2417606599628925, 10.361987929791212, 12.639002446085215, 11.90575959160924, 12.507333811372519, 13.848147913813591, 12.72191209718585, 14.568859040737152, 17.687760181725025, 15.143714994192123, 11.437680758535862, 5.6293960288167, 7.296453025192022, 20.632197484374046, 29.295876994729042, 39.80906926095486, 44.91012454032898, 55.030368492007256, 59.98663634061813, 66.99886366724968, 66.75203651189804, 64.54610288143158, 63.32661531865597, 62.58367918431759, 61.833569034934044, 65.40095061063766, 65.58147132396698, 67.60412558913231, 65.64587786793709, 66.48820146918297, 64.49868142604828, 67.09238424897194, 63.996659964323044, 68.25024291872978, 55.84591493010521, 42.576749548316, 44.55368846654892, 48.810691237449646, 53.04168060421944, 66.88662528991699, 52.196989730000496, 68.19740295410156, 60.34265823662281, 62.62581892311573, 59.61888827383518, 60.73632851243019, 62.89405792951584, 65.51193505525589, 65.0923539698124, 67.35584691166878, 67.61520579457283, 66.080901324749, 68.17017361521721, 68.0186377465725, 58.54755096137524, 58.446738570928574, 47.75723196566105, 42.34475679695606, 39.62684243917465, 29.274356849491596, 22.981035746634007, 18.129152096807957, 16.734714321792126, 15.403737891465425, 16.782563254237175, 17.33690980821848, 17.626900747418404, 12.819422464817762, 11.628584414720535, 11.519772503525019, 13.775347620248795, 10.638214107602835, 9.214478954672813, 8.606069851666689, 6.350782569497824, 4.089122079312801, 1.2044148403219879, 0.03448025898251217, 0.3597417479613796, 1.3748491136357188, 6.047445321455598, 16.465322077274323, 28.460543118417263, 29.719535261392593, 29.372095204889774, 31.20044119656086, 28.439159765839577, 33.302104622125626, 37.06185467541218, 54.42256070673466, 55.895844250917435, 56.02810375392437, 29.642266407608986, 7.025649156421423, 0.39621275500394404, 0.024462063156533986, 0.012382521545077907, 0.019269860713393427, 0.058042197197210044, 0.032771055775810964, 0.04946013134031091, 0.04849525030294899, 0.02594783167296555, 0.13023563660681248, 0.007697404489590554, 0.06254546024138108, 0.02205033553764224, 0.02812574752169894, 0.04808696889085695, 0.048291608691215515, 0.06786667392589152, 0.06085053595597856, 0.025938499165931717, 0.016624113522993866, 0.056118416832759976, 0.03288575098849833, 0.10014968967880122, 0.05340606745448895, 0.02091912436299026, 0.029057506508252118, 0.06035649937984999, 0.02414777103695087, 0.015015167045930866, 0.014609783720516134, 0.09802685046452098, 0.03401360765565187, 0.23699236277025193, 0.10962597298203036, 0.22804321954026818, 0.1960057285032235, 0.20427522773388773, 0.14841114490991458, 0.17062248196452856, 0.10245587647659704, 0.1641992828808725, 0.1645705199916847, 0.09533637959975749, 0.1438733423128724, 0.17051766102667898, 0.12930208904435858, 0.21036723599536344, 0.27395879791583866, 0.17995620612055063, 0.11882194710779004, 0.21144722413737327, 0.21529592777369544, 0.08900550368707627, 0.14917859982233495, 0.12619839777471498, 0.15902765648206696, 0.24621718417620286, 0.2138333031325601, 0.24070326442597434, 0.09965035787899978, 0.20402568799909204, 0.25922770088072866, 2.616758798249066, 17.52868741750717, 49.865146055817604, 71.86311185359955, 78.36732164025307, 65.81798583269119, 57.60338522493839, 48.92747417092323, 46.98737807571888, 32.11990065872669, 34.174594804644585, 49.69438321888447, 62.68528953194618, 40.54053381085396, 18.42655833810568, 4.3827318493276834, 1.562785841524601, 0.666797423036769, 1.9712714035995305, 4.591663163155317, 13.547892775386572, 15.991134122014046, 23.69487304240465, 18.881874606013298, 19.11398135125637, 20.354428589344025, 23.070910423994064, 21.48636694997549, 25.911157317459583, 40.248717069625854, 37.499632984399796, 25.335617400705814, 21.351825669407845, 24.918823465704918, 41.4455958455801, 47.27519743144512, 50.235439985990524, 59.93025116622448, 61.966615095734596, 71.48191630840302, 68.0996721982956, 67.0595084130764, 63.72362561523914, 65.00654697418213, 65.54066151380539, 66.532301902771, 66.01141825318336, 67.45357766747475, 66.97082877159119, 68.14052760601044, 67.05494105815887, 68.72859925031662, 67.19595149159431, 70.48639252781868, 61.35604105889797, 49.38805125653744, 48.470788076519966, 53.7422414124012, 55.886188969016075, 67.13444799184799, 57.12855890393257, 70.49045071005821, 59.302141070365906, 61.87883980572224, 64.08866062760353, 63.30410532653332, 63.10606375336647, 69.58068072795868, 65.89361697435379, 67.40835249423981, 69.0201424062252, 67.99295872449875, 68.41362655162811, 71.01657047867775, 63.93396332859993, 64.21096846461296, 55.96556290984154, 48.6081925034523, 52.45454750955105, 41.12074367702007, 33.7055441737175, 24.889527037739754, 41.09006032347679, 26.66409071534872, 28.54893207550049, 27.43843786418438, 21.29261914640665, 21.710389629006386, 24.830960780382156, 21.214088760316372, 14.256443604826927, 13.352379966527224, 19.184488467872143, 16.569271199405193, 10.206308383494616, 4.638151293620467, 1.8712189723737538, 0.2010387068730779, 0.6090295384638011, 1.715443718712777, 8.59726382419467, 17.790601663291454, 29.0974098443985, 29.377652406692505, 35.45469291508198, 39.318542182445526, 33.9896435290575, 41.84954456984997, 45.46448439359665, 64.51338663697243, 65.30790120363235, 64.35207769274712, 38.871929347515106, 9.804415348917246, 0.9104374994058162, 0.20728672941913828, 0.16488602181198075, 0.18677611282328144, 0.2977759495843202, 0.1792740388191305, 0.1589558314299211, 0.12140672872192226, 0.14385854388820007, 0.29549351893365383, 0.19216441665776074, 0.1071527881140355, 0.17102061450714245, 0.10998604077030905, 0.20400499692186713, 0.17669492721324787, 0.21799283305881545, 0.10877546432311647, 0.10408769594505429, 0.11662015080219135, 0.11714343170751818, 0.15109535946976393, 0.22764100518543273, 0.17629688372835517, 0.11159264206071384, 0.1606879150494933, 0.28635533584747463, 0.13375746872043237, 0.24042167875450104, 0.14398430823348463, 0.3541736217448488, 0.2728023240342736], [0.07624537276569754, 0.01858183601143537, 0.04671534268709365, 0.12921224464662373, 0.06643971690209582, 0.027979251281067263, 0.02581027460109908, 0.0737550739722792, 0.023580853703606408, 0.04059117716678884, 0.013048794826318044, 0.022013575107848737, 0.047300344303948805, 0.020861724806309212, 0.051050346010015346, 0.08681082457769662, 0.05501678024302237, 0.10897480518906377, 0.08466431827400811, 0.08911751603591256, 0.05670177088177297, 0.03804001484240871, 0.02468870206939755, 0.0770411999837961, 0.0517523806047393, 0.01096416322980076, 0.09731160564115271, 0.05755977152148262, 0.0715353993291501, 0.28471913770772517, 5.027595721185207, 20.917174592614174, 39.94102858006954, 57.99980655312538, 54.002109467983246, 44.733977392315865, 37.01967313885689, 35.38452208042145, 23.05706776678562, 22.117427587509155, 20.012004263699055, 33.21814052760601, 25.133088268339634, 22.853085212409496, 4.952599620446563, 1.2948321760632098, 0.1179221598431468, 0.4129731806460768, 3.145997249521315, 7.159835631027818, 7.025815397500992, 6.804014649242163, 6.629343247041106, 11.423852350562811, 8.923026993870735, 9.21277854591608, 6.392006557434797, 23.537409491837025, 11.918960083276033, 14.309377614408731, 11.601108089089394, 8.628942724317312, 13.12461068853736, 23.965929597616196, 32.22677752375603, 47.22920089960098, 58.19206103682518, 61.58986151218414, 64.42222192883492, 60.056172609329224, 58.222789987921715, 60.84809951484203, 60.51364146173, 60.02787932753563, 58.03434669971466, 60.846556797623634, 63.34347881376743, 66.84268444776535, 65.57772472500801, 65.4419656097889, 62.93932870030403, 69.20038193464279, 61.658550426363945, 65.63890904188156, 59.01861168444157, 40.20239755511284, 34.946371391415596, 38.08015823364258, 47.666321843862534, 47.14362949132919, 47.232366129755974, 66.69219732284546, 57.907900884747505, 53.584960252046585, 55.443683713674545, 57.84550443291664, 60.52117645740509, 60.843478962779045, 61.88645459711552, 67.12557926774025, 64.70146894454956, 63.601446971297264, 60.91220587491989, 67.7950881421566, 65.78037545084953, 62.09341049194336, 58.042736649513245, 48.79810631275177, 44.114530831575394, 39.99885767698288, 33.869919553399086, 35.28753228485584, 25.935196727514267, 25.108256600797176, 20.65297856926918, 9.59558330476284, 18.496231399476528, 12.07561332732439, 8.26897094026208, 8.814223632216454, 13.300057724118233, 12.32515163719654, 5.173120312392712, 11.211964320391417, 5.5118412617594, 1.6158706555142999, 0.9227703313808888, 0.23182162694865838, 0.08652258926304057, 0.3979610768146813, 1.882815237622708, 7.036243937909603, 24.548825919628143, 48.03281217813492, 49.00442764163017, 27.191920392215252, 24.33491639792919, 19.960372634232044, 31.922839432954788, 37.46896103024483, 47.636447846889496, 48.129015415906906, 38.03067348897457, 10.683526676148176, 1.572058650199324, 0.06914875630172901, 0.0399010020919377, 0.0379801272356417, 0.0334235186164733, 0.10000434747780673, 0.03376946704520378, 0.03045971847313922, 0.042629207455320284, 0.05750842232373543, 0.021962263017485384, 0.10090969342854805, 0.028028980741510168, 0.036169876912026666, 0.06205363155459054, 0.044008603945258074, 0.04636750178178772, 0.04777563794050366, 0.06859682107460685, 0.029819517767464276, 0.03333014901727438, 0.01727379330986878, 0.05308862862875685, 0.0922419577545952, 0.023461540477001108, 0.04157514253165573, 0.04787616555404384, 0.02717382067203289, 0.026240094994136598, 0.1350203072070144, 0.03357768124260474, 0.0665321662381757, 0.06431212052120827, 0.03562672129191924, 0.058765227149706334, 0.01912510851980187, 0.0561535352608189, 0.012953341647516936, 0.08640326675958931, 0.011926643419428729, 0.043114323416375555, 0.04361111707112286, 0.01990661970921792, 0.029590999365609605, 0.0010163726346945623, 0.0447091839305358, 0.02283604357216973, 0.0933839671779424, 0.023720980461803265, 0.09728769364301115, 0.07568899949546903, 0.026730537720141, 0.04945639091602061, 0.06799450886319391, 0.030053622685954906, 0.006707169368382893, 0.040334401492145844, 0.014116775018919725, 0.04458615439943969, 0.030723976851732004, 0.07677611967665143, 0.48199885175563395, 4.701725207269192, 23.39033268392086, 45.146445259451866, 66.57324850559235, 65.87093979120255, 53.540111258625984, 42.864724695682526, 39.11113031208515, 29.835839420557022, 18.98221582174301, 16.468379013240337, 33.48962835967541, 29.862192906439304, 26.43480721861124, 6.225297627970576, 1.6192137636244297, 0.10096165118739009, 1.6076345974579453, 2.9856323171406984, 11.287920344620943, 11.993940509855747, 9.538180734962225, 13.200972341001034, 18.084479793906212, 14.475511349737644, 17.06708438694477, 10.841497499495745, 14.21768568456173, 16.612159498035908, 16.70203797519207, 11.336818970739841, 9.249586220830679, 15.776511188596487, 26.092660278081894, 34.0364608168602, 47.898873165249825, 55.6701173633337, 63.03656168282032, 66.27809554338455, 64.6349649131298, 62.085533514618874, 64.30268034338951, 63.161825761199, 63.29710990190506, 61.34298495948315, 63.00279289484024, 63.70787926018238, 68.42707023024559, 67.11787328124046, 66.44060522317886, 64.41901490092278, 66.5104378759861, 62.58251264691353, 67.81167805194855, 64.00593146681786, 46.21487192809582, 42.495475709438324, 44.993959441781044, 52.892789393663406, 56.09165534377098, 53.02144668996334, 69.17934626340866, 58.522175922989845, 56.80892385542393, 59.26619119942188, 58.04800696671009, 59.761848002672195, 62.434879168868065, 64.84027549624443, 69.07235160470009, 66.26627817749977, 64.68921080231667, 64.43047508597374, 70.15828013420105, 67.42548957467079, 63.07057365775108, 58.49631071090698, 49.343475848436356, 44.38552089035511, 38.91234777867794, 31.659973338246346, 26.683997847139835, 20.961362421512604, 13.68948457762599, 21.91832397133112, 16.72515783458948, 16.442126221954823, 14.199338369071484, 14.53735588118434, 14.664231073111296, 15.298190955072641, 9.627631735056639, 8.185064792633057, 11.011512726545334, 6.468314062803984, 6.318155145272613, 3.823989643715322, 1.368624335154891, 0.25934068544302136, 0.4717934603104368, 2.155951587483287, 7.672008723020554, 25.605682209134102, 40.041848570108414, 42.98217639327049, 29.576742723584175, 30.917428582906723, 25.816491097211838, 38.964625373482704, 44.60319980978966, 53.778647258877754, 55.560212060809135, 44.56495486199856, 12.923200596123934, 1.817306277807802, 0.07924705583718605, 0.021194303444644902, 0.06793191612814553, 0.015101759909157408, 0.04295028280466795, 0.022753346056560986, 0.04866517243499402, 0.03187255613738671, 0.03989654178440105, 0.052447550333454274, 0.040348242546315305, 0.06270969010074623, 0.025215476634912193, 0.035705945556401275, 0.0797028532542754, 0.06013487552991137, 0.03760336483537685, 0.1076265900337603, 0.008405211137869628, 0.030801401408098172, 0.05935018794843927, 0.012629182674572803, 0.03610133586334996, 0.043152009675395675, 0.025637478502176236, 0.02878102495742496, 0.0190037302672863, 0.017094616596295964, 0.078087754372973, 0.06452675705077127, 0.08417243021540344, 0.14877130917739123, 0.17603876476641744, 0.11114452587207779, 0.24705802265089005, 0.15172193991020322, 0.10343349276809022, 0.1624075454310514, 0.19060271530179307, 0.17319374164799228, 0.10869028061279096, 0.126889307575766, 0.1701019989559427, 0.11480692075565457, 0.16539945441763848, 0.11348508895025589, 0.13922069978434592, 0.12766454019583762, 0.23587817646330222, 0.1528387237340212, 0.20355939661385491, 0.12750434019835666, 0.1761249577975832, 0.14743814477697015, 0.14113959681708366, 0.2324190261424519, 0.11870097703649662, 0.26957015215884894, 0.09183938716887496, 0.21989520988427103, 1.017912772949785, 8.122406154870987, 30.404541604220867, 55.491713136434555, 76.92213758826256, 69.73510444164276, 60.508659929037094, 50.025581046938896, 48.2924522459507, 35.75819782912731, 34.75310616195202, 31.193046793341637, 45.51064811646938, 35.501099824905396, 29.761771894991398, 6.696416772902012, 2.103090723976493, 0.3192592249251902, 1.434336465317756, 5.522042289376259, 16.68861709535122, 17.353317327797413, 14.300578236579895, 18.40658091008663, 28.141204454004765, 20.170643851161003, 18.02065271884203, 19.872435852885246, 39.1657979786396, 23.204857036471367, 22.483340352773666, 20.216383896768093, 12.52748318016529, 16.909465044736862, 28.126088865101337, 35.713481828570366, 48.638723865151405, 60.892750918865204, 67.66750618815422, 71.81063666939735, 65.36313503980637, 64.90323811769485, 65.75422525405884, 66.8573060631752, 64.25484851002693, 64.4993805885315, 63.41081500053406, 66.61157324910164, 68.76761555671692, 69.10710453987122, 66.59857034683228, 65.63973739743233, 66.66949734091759, 64.88072052598, 71.74787163734436, 66.73898041248322, 53.947331607341766, 47.17709809541702, 49.575426802039146, 52.9133614897728, 59.24909971654415, 60.67986734211445, 70.14147743582726, 58.65318909287453, 58.12394969165325, 59.23658698797226, 61.32393658161163, 63.241940662264824, 64.61438521742821, 65.92831671237946, 69.72389504313469, 68.83792698383331, 67.34390795230865, 67.67255991697311, 72.24421620368958, 71.84344410896301, 65.71293666958809, 61.90518759191036, 51.86508134007454, 44.58012364804745, 43.05349476635456, 39.770881310105324, 39.88758824765682, 34.85056333243847, 34.108197167515755, 30.321206375956535, 19.143781252205372, 33.24972823262215, 22.213269844651222, 19.826756604015827, 17.121379673480988, 24.476485401391983, 23.109064176678658, 13.681844137609005, 22.28270161896944, 12.735951393842697, 7.20675646327436, 2.755843922495842, 1.4347095577977598, 0.3548130561830476, 0.8500756009016186, 3.056015227921307, 9.64837197214365, 32.83791013062, 60.26970215141773, 63.78665283322334, 40.22781439125538, 36.66043661534786, 31.935906931757927, 46.89801827073097, 52.081076949834824, 65.40738746523857, 63.268258050084114, 54.0775316208601, 17.65640616416931, 2.5036091823130846, 0.19733706722036004, 0.09904784528771415, 0.2234026146470569, 0.1347391222952865, 0.1413781676092185, 0.07677394518395886, 0.1449796766974032, 0.13404273544438183, 0.30127238540444523, 0.15721377334557474, 0.13535724225221202, 0.1946024311473593, 0.13229043572209775, 0.1809184005833231, 0.2620642486726865, 0.15017236524727196, 0.10132969706319273, 0.1761585770873353, 0.10802918288391083, 0.1239935660851188, 0.10940336578642018, 0.12872680585132912, 0.13206707895733416, 0.12959262501681224, 0.14642303518485278, 0.18799265613779426, 0.22475508973002434, 0.11945875434321351, 0.1794108166359365, 0.28179261193145066, 0.20351077109808102], [0.0034287667949683964, 0.031249040766851977, 0.020900496456306428, 0.04530015983618796, 0.009588383782102028, 0.05194949873839505, 0.056447963797836564, 0.035039630529354326, 0.024732754100114107, 0.06966532077058218, 0.041072511885431595, 0.028704312862828374, 0.009381280979141593, 0.04467981343623251, 0.02237511977000395, 0.05395836262323428, 0.10930112010100856, 0.05707885982701555, 0.03757811697141733, 0.11619001685176045, 0.06354854704113677, 0.02581635464594001, 0.053083570892340504, 0.010299348268745234, 0.0679974551894702, 0.0304078015324194, 0.017327137029496953, 0.036995787086198106, 0.06890848599141464, 1.0183439310640097, 8.911045286804438, 26.829803623259068, 52.71680563688278, 59.126442298293114, 55.459658056497574, 48.180122673511505, 33.741144463419914, 27.805376574397087, 21.54688060283661, 32.65171252191067, 49.61459510028362, 46.171744242310524, 34.26371902227402, 13.520331904292107, 3.291475768201053, 0.7946286792866886, 0.3312817501137033, 0.9699618397280574, 2.845461876131594, 12.634533885866404, 7.899876795709133, 10.08925661444664, 13.354899231344461, 11.273981742560863, 19.005210287868977, 22.909137904644012, 11.261676102876663, 5.86390377022326, 16.327013298869133, 11.774268597364426, 9.212562907487154, 13.85873794555664, 17.584318332374096, 38.72253276407719, 48.38529646396637, 56.46292582154274, 58.89623925089836, 62.459695637226105, 60.387218445539474, 62.50973895192146, 59.78782340884209, 58.90531696379185, 58.17207030951977, 56.93293020129204, 57.156996577978134, 59.95591878890991, 61.75891824066639, 63.66726703941822, 64.12843689322472, 64.76413518190384, 61.51078015565872, 64.0394076704979, 66.81289404630661, 59.32487905025482, 60.46204783022404, 48.28652076423168, 37.30079725384712, 33.71628239750862, 39.310642406344414, 31.134706623852253, 48.34774307906628, 66.06954753398895, 56.34604409337044, 58.70512470602989, 57.55930379033089, 61.10136352479458, 53.329366967082024, 59.8520627617836, 55.17605647444725, 64.16540890932083, 66.10157981514931, 61.031945049762726, 59.418635219335556, 60.96168301999569, 63.21067973971367, 64.40285056829453, 60.257398411631584, 61.20979830622673, 59.39008355140686, 52.493081241846085, 40.84520526230335, 37.087320908904076, 26.004011034965515, 24.587528742849827, 28.544398918747902, 26.454980336129665, 15.907599404454231, 9.431553706526756, 10.710231643170118, 13.631271701306105, 16.480373069643974, 11.691684778779745, 6.03459108620882, 4.578917697072029, 4.1777124255895615, 7.751270094886422, 3.393796202726662, 0.5133975169155747, 0.45973329339176416, 0.03983287293522153, 1.0848544933833182, 3.9197644544765353, 16.944924741983414, 32.83972643315792, 30.419565998017788, 31.57857220619917, 25.292803198099136, 25.22699072957039, 22.57269635796547, 39.47602093219757, 47.07784362137318, 51.50769151747227, 44.79732759296894, 15.226181019097567, 1.6424653097055852, 0.08983204097603448, 0.007700277064941474, 0.041941121526178904, 0.039113004531827755, 0.04306905611883849, 0.02498148118320387, 0.021904670502408408, 0.08536195935448632, 0.027121851780975703, 0.01621979146875674, 0.08968630543677136, 0.16776568838395178, 0.030251978350861464, 0.021919416976743378, 0.015959290212776978, 0.041483665409032255, 0.04729530141048599, 0.014816719540249323, 0.08935446152463555, 0.031090167358343024, 0.037463581320480444, 0.03048386424779892, 0.03329746483359486, 0.0328842963790521, 0.01159691277280217, 0.012949320134794107, 0.0363390680286102, 0.06584752016351558, 0.0612468428153079, 0.050336140193394385, 0.06785829507862218, 0.04657903984480072, 0.043687524885172024, 0.011212456156499684, 0.1566957839531824, 0.020310884247010108, 0.062037953684921376, 0.04154439164267387, 0.01398962378516444, 0.026008580171037465, 0.032091931279865094, 0.03223975596483797, 0.03404652561584953, 0.06789420760469511, 0.04128625412704423, 0.027310936166031752, 0.025699883844936267, 0.05874594244232867, 0.050650610428419895, 0.07373910295427777, 0.031177935597952455, 0.07200615102192387, 0.017518776257929858, 0.03583566183806397, 0.03564068851119373, 0.03189088718499988, 0.036047040339326486, 0.043785495799966156, 0.012781407367583597, 0.03978234752139542, 0.978504850063473, 10.524975433945656, 31.650984920561314, 62.09861621260643, 65.11858016252518, 62.19692073762417, 50.756999999284744, 41.61622188985348, 37.01623432338238, 30.15510018914938, 24.974241591989994, 31.66238810867071, 39.00073103606701, 30.84770232439041, 14.200587552040815, 3.549397378228605, 0.44473754649516195, 0.3152202197816223, 1.832843169104308, 6.5764581598341465, 11.345990728586912, 9.617823511362076, 13.135123774409294, 14.106336459517479, 15.841087773442268, 10.804497934877872, 15.244142655283213, 14.826143234968185, 13.474174831062555, 17.192395962774754, 17.208459600806236, 11.358666848391294, 14.908968340605497, 19.896532259881496, 36.635365560650826, 47.72548846900463, 55.7466034591198, 61.068715676665306, 65.07884949445724, 63.452418968081474, 64.88490030169487, 62.711116746068, 61.70494593679905, 60.955094173550606, 60.048455223441124, 60.57642549276352, 62.45708517730236, 63.26950438320637, 65.51435932517052, 66.42165943980217, 64.55207616090775, 62.64580965042114, 64.29596230387688, 67.48823180794716, 62.32637599110603, 65.60271978378296, 54.28886868059635, 44.76124092936516, 41.44783392548561, 46.81766398251057, 37.321224957704544, 53.95256392657757, 67.35307306051254, 57.966520339250565, 58.60099509358406, 58.324894309043884, 61.550632417201996, 58.120719864964485, 60.72294943034649, 57.5300719588995, 64.68490183353424, 67.99106642603874, 63.13405305147171, 61.318639665842056, 63.39357912540436, 66.22421443462372, 63.425786197185516, 63.28336983919144, 59.52068634331226, 57.72843651473522, 50.46864867210388, 42.511366456747055, 37.58168578147888, 29.809064157307148, 25.257609486579895, 22.267536632716656, 17.662102058529854, 25.407237857580185, 16.504729762673378, 9.504067115485668, 12.466609496623278, 21.053425781428814, 14.587166458368301, 13.834099117666483, 10.928106252104044, 6.801475435495377, 8.093961831182241, 6.063251048326492, 2.4002195801585913, 0.8198711997829378, 0.20439805317437276, 0.6056884489953518, 4.729939643293619, 15.77127791941166, 34.142566323280334, 33.54606293141842, 34.14960354566574, 25.483676455914974, 29.048495069146156, 29.43727880716324, 45.480139553546906, 53.968348279595375, 57.72458352148533, 50.627548545598984, 18.45073454082012, 2.338994415476918, 0.006113816270953976, 0.026113970707228873, 0.02366837146837497, 0.022423246191465296, 0.026676976922317408, 0.028592998132808134, 0.021290394870447926, 0.033390782482456416, 0.04544945768429898, 0.0758677234989591, 0.0989741351804696, 0.06227867299458012, 0.04633351883967407, 0.03661293907498475, 0.0567955152655486, 0.03253823291743174, 0.043335713489796035, 0.08018399501452222, 0.05439060056232847, 0.042349325012764893, 0.016681962079019286, 0.03542463076882996, 0.04258798486262094, 0.028302412065386306, 0.007804012147971662, 0.06845995420007966, 0.0230973834550241, 0.025781145304790698, 0.011715030213963473, 0.03482052627077792, 0.03900253213942051, 0.13958328345324844, 0.2567084657493979, 0.10953332326607779, 0.24470867996569723, 0.1136780770320911, 0.1476254776935093, 0.10614147831802256, 0.07051112421322614, 0.191118270449806, 0.11409408049075864, 0.20672376587754115, 0.14586363395210356, 0.10976390112773515, 0.11680755793349817, 0.08614519974798895, 0.09419514200999402, 0.18324904114706442, 0.17399877891875803, 0.22573944472242147, 0.14886099030263722, 0.26122309849597514, 0.1333015674026683, 0.08859814624884166, 0.20457337814150378, 0.13376548391534016, 0.1534582834574394, 0.13110883272020146, 0.05749246614868753, 0.15332983253756538, 1.842084035743028, 13.61212357878685, 38.66289496421814, 72.14203208684921, 74.5871476829052, 72.62232631444931, 62.40877076983452, 48.29755537211895, 41.57641522586346, 34.39861558377743, 46.216148659586906, 61.968363001942635, 59.278266951441765, 44.01159815490246, 17.26735644042492, 4.789887126535177, 1.2236211472190917, 0.6737922539468855, 2.633772622793913, 8.982417806982994, 25.72999633848667, 19.8794711753726, 20.12203685939312, 24.09728094935417, 19.993835538625717, 30.29540006071329, 35.497258231043816, 22.20981203019619, 16.46798763424158, 27.444118559360504, 23.081105276942253, 16.88410710543394, 20.329509526491165, 20.45853540301323, 44.2152102291584, 50.71378871798515, 60.44437877833843, 63.906878381967545, 66.63025304675102, 66.32750809192657, 69.15736824274063, 64.91171166300774, 64.03790295124054, 62.9500213265419, 62.13353633880615, 62.229743376374245, 64.70737382769585, 64.47016775608063, 65.68201392889023, 67.49389350414276, 64.93666872382164, 62.55149491131306, 63.450336679816246, 69.21824097633362, 64.17116940021515, 67.72077932953835, 59.63657632470131, 49.41620014607906, 47.189139649271965, 50.546248108148575, 43.37756037712097, 57.099836245179176, 66.71454772353172, 57.159964218735695, 57.91840352118015, 55.62247931957245, 62.35273137688637, 58.6195532977581, 62.391120716929436, 57.00099594891071, 66.78229048848152, 70.06891652941704, 66.13796666264534, 62.91086062788963, 67.93001130223274, 69.48934122920036, 68.2441708445549, 62.963917180895805, 61.95820614695549, 62.415112629532814, 54.31608282029629, 44.75013792514801, 43.96660476922989, 33.057659938931465, 31.821403875947, 35.52972748875618, 40.42193457484245, 26.959483064711094, 16.713796444237232, 20.539533756673336, 21.5744424238801, 28.79143126308918, 20.165098048746586, 18.72516341507435, 16.801607832312584, 12.674637883901596, 14.625658392906189, 7.408584533259273, 1.2532132468186319, 0.7532716391142458, 0.37351173406932503, 1.3423233339563012, 5.457264315336943, 19.329627379775047, 42.18149855732918, 42.542836368083954, 45.71744441986084, 35.9711080044508, 37.61908337473869, 33.75282883644104, 54.622376784682274, 61.21370069682598, 68.39400440454483, 57.97887347638607, 25.606284476816654, 3.5121358651667833, 0.38653330877423286, 0.11307229156955145, 0.09541037172311917, 0.16232445457717404, 0.17221091547980905, 0.12771548121236265, 0.10850295511772856, 0.208351117616985, 0.1478823201614432, 0.20211657247273251, 0.22392976214177907, 0.21360668091801926, 0.18226070824312046, 0.10187219217186794, 0.1481715647969395, 0.0920088862767443, 0.1281629962613806, 0.18126965907867998, 0.19256389990914613, 0.11662460368825123, 0.08219108145567589, 0.10037556974566542, 0.16966923780273646, 0.13800846092635766, 0.13897064054617658, 0.13847113063093275, 0.1582685878383927, 0.13987509591970593, 0.09182285211863928, 0.20356022781925276, 0.1595836883643642], [0.06780735406209715, 0.02431632390653249, 0.0430909197893925, 0.023641466759727336, 0.04197350514004938, 0.05877303825400304, 0.0337113012210466, 0.04494260050705634, 0.04655726152122952, 0.04724452366644982, 0.027096960147900973, 0.0516042961680796, 0.045577077398775145, 0.027423425344750285, 0.027701012695615645, 0.02036799993220484, 0.021119483826623764, 0.04106247433810495, 0.027783324294432532, 0.088786458800314, 0.01243461289050174, 0.09149380610324442, 0.04917860132991336, 0.013182809998397715, 0.050555051493574865, 0.07101309805875644, 0.06669117137789726, 0.02751806030573789, 0.15189065976301208, 2.3623593617230654, 9.519386943429708, 41.72066688537598, 55.345033407211304, 54.63268183171749, 46.597701385617256, 45.187597051262856, 33.828216791152954, 22.11204517632723, 23.697386607527733, 47.996220141649246, 29.003587178885937, 26.651232205331326, 15.756613556295633, 9.483056142926216, 1.8659669416956604, 0.09383543045260012, 0.14448598521994427, 2.5604762183502316, 2.633566721342504, 7.683399561792612, 9.702917095273733, 8.961523678153753, 14.35790291056037, 17.331673689186573, 9.852098040282726, 13.723106123507023, 9.29362965747714, 9.693248514086008, 13.01417626440525, 21.916999742388725, 14.812320526689291, 18.401937559247017, 28.15279383212328, 40.31788855791092, 50.139012560248375, 67.40735694766045, 65.6295919418335, 63.32778185606003, 58.02745006978512, 59.79541540145874, 57.95517414808273, 59.13257896900177, 53.13381426036358, 56.57089322805405, 57.310056164860725, 62.17279203236103, 59.3412409722805, 62.98129744827747, 61.939362958073616, 66.47624731063843, 61.681052818894386, 63.202152997255325, 66.10179260373116, 60.44524133205414, 61.608092933893204, 52.65514254570007, 38.43345187604427, 26.903540566563606, 28.48926767706871, 35.485406666994095, 55.66837705671787, 65.00504225492477, 59.68762278556824, 60.59834651648998, 56.323541700839996, 58.87359246611595, 60.210733115673065, 56.8609544634819, 61.2908935546875, 61.52380205690861, 65.4173581302166, 60.98898455500603, 57.17833623290062, 58.1690988689661, 61.09953582286835, 62.464798763394356, 61.96791462600231, 60.36872483789921, 58.450230583548546, 57.5415663421154, 54.66794013977051, 48.728231862187386, 40.1282749325037, 29.56610519438982, 37.33427345752716, 25.794912055134773, 25.54065629839897, 21.743934229016304, 9.593190383166075, 14.734021928161383, 16.541238203644753, 8.442024104297161, 10.0174262188375, 10.108457934111357, 5.17341242171824, 5.929448353126645, 10.86107974871993, 5.13559352606535, 0.7641121011693031, 0.0994476031337399, 0.12500777025707066, 1.4275015820749104, 7.4225174356251955, 23.910004198551178, 32.6962461322546, 35.952830985188484, 40.017856657505035, 28.997703194618225, 34.42095458507538, 31.32939487695694, 36.06746323406696, 46.41984432935715, 50.93742571771145, 30.35861536860466, 5.53298095241189, 0.20754468510858715, 0.035470154107315466, 0.0714372428774368, 0.08068881870713085, 0.07758607738651335, 0.03311363856482785, 0.04209815255308058, 0.022490364171972033, 0.034255525533808395, 0.08532698935596272, 0.02151978900656104, 0.0573439661093289, 0.010936791895801434, 0.02966321033454733, 0.032139328541234136, 0.09713752748211846, 0.027261286486464087, 0.07839519646950066, 0.06195573485456407, 0.033031705461326055, 0.03324470184452366, 0.023078497652022634, 0.03130141041765455, 0.06481069533037953, 0.023718813390587457, 0.04785282872035168, 0.08757601593970321, 0.03337532725709025, 0.03291780063591432, 0.057902458211174235, 0.02486579705873737, 0.022854767958051525, 0.023900771302578505, 0.024224492408393417, 0.03489335322228726, 0.029275586603034753, 0.01840589877247112, 0.0370969306823099, 0.0465219872421585, 0.08612113932031207, 0.025987816734414082, 0.04395229720103089, 0.04099283120012842, 0.029026633164903615, 0.012860296737926546, 0.02446382204652764, 0.03026271722774254, 0.03690380530315451, 0.021021112152084243, 0.014588612102670595, 0.06118519631854724, 0.04045416557346471, 0.04003700065368321, 0.04732291301479563, 0.05917506707191933, 0.02274436606967356, 0.06574997227289714, 0.04937925950798672, 0.016264027181023266, 0.1276564656291157, 2.604929320514202, 11.763063948601484, 47.788827270269394, 62.67766714096069, 64.30673852562904, 55.506007969379425, 57.0968534052372, 36.53044939041138, 24.366397708654404, 19.35765277594328, 46.81849613785744, 43.72097074985504, 30.32397072762251, 21.602891497313976, 9.967081770300865, 2.398025435395539, 0.12587235745741054, 0.7240874832496047, 4.083931557834148, 7.317649237811565, 8.517122324556112, 11.385840140283108, 17.09223333746195, 15.739916302263737, 16.517728865146637, 13.177858181297779, 13.26700234785676, 13.813518472015858, 13.22861585766077, 16.46619603037834, 16.41535095870495, 11.644428614526987, 20.234807208180428, 32.91128799319267, 40.34671761095524, 54.67665307223797, 66.042660176754, 67.5471742451191, 64.50106009840965, 63.286721259355545, 62.923665940761566, 62.84163974225521, 61.13276124000549, 57.85413756966591, 58.437220081686974, 60.863690078258514, 64.61367085576057, 61.27740427851677, 62.750026658177376, 63.04104544222355, 67.51632750034332, 63.45505602657795, 63.176770359277725, 65.17328202724457, 61.57186947762966, 65.46180814504623, 57.6406080275774, 45.67766435444355, 35.64634323120117, 33.599757850170135, 39.10685554146767, 59.84353221952915, 65.65349265933037, 59.807665944099426, 60.4113395512104, 58.87572415173054, 58.84305350482464, 58.23192089796066, 57.589702159166336, 62.5141467154026, 62.435855716466904, 66.97910472750664, 63.1944166123867, 60.80058306455612, 61.39852657914162, 64.71509501338005, 64.39560815691948, 62.87478916347027, 61.029053404927254, 59.65513452887535, 56.638472601771355, 52.389502599835396, 45.60151644051075, 37.532090842723846, 27.934619039297104, 28.560890033841133, 23.94914209842682, 21.882159411907196, 9.122009966522455, 14.949794299900532, 19.741895757615566, 19.222334437072277, 18.37148029357195, 11.643882393836975, 12.810262106359005, 10.988573357462883, 9.411652274429798, 9.515110272914171, 4.34109415858984, 1.4782947627827525, 0.16814032453112304, 0.19170395855326205, 1.4566558739170432, 7.785167125985026, 23.30776121467352, 29.31889235973358, 31.239837482571602, 43.98516297340393, 34.72765512764454, 36.65291681885719, 38.47191721200943, 42.313184291124344, 52.110354378819466, 57.155746445059776, 35.820396691560745, 6.618581749498844, 0.3245826798956841, 0.040890322052291594, 0.027994572919851635, 0.022511183269671164, 0.05474333593156189, 0.01830211313063046, 0.02704959628317738, 0.05751043725467753, 0.024911795371735934, 0.06201999742188491, 0.01222389675604063, 0.003747204273167881, 0.02539401510148309, 0.029072065590298735, 0.045544025851995684, 0.02998227260832209, 0.027665011111821514, 0.04373569398012478, 0.04530412290478125, 0.030271452305896673, 0.03986236588389147, 0.04394420779135544, 0.035492945462465286, 0.067351868347032, 0.02506155891751405, 0.04015598176920321, 0.08455025759758428, 0.03617277128796559, 0.05697780528862495, 0.013780672106804559, 0.004999157772545004, 0.1904796969029121, 0.09833654868998565, 0.14005775330588222, 0.0793257234909106, 0.11429833437432535, 0.17709788371575996, 0.11622833393630572, 0.18664383242139593, 0.2127353401738219, 0.11299671125016175, 0.16335155727574602, 0.13773204060271382, 0.09577690361766145, 0.1930889842333272, 0.2066429756814614, 0.12575934320921078, 0.10495426467969082, 0.08752156456466764, 0.07771742268232629, 0.1618597365450114, 0.27009128825739026, 0.17007191228913143, 0.21604745619697496, 0.18064221774693578, 0.2011630017659627, 0.17331938724964857, 0.11966697871685028, 0.23373115807771683, 0.3524380055023357, 4.137715296819806, 17.28704698383808, 57.420048862695694, 74.99072402715683, 70.9804268181324, 62.76027850806713, 59.817963391542435, 44.684705436229706, 33.54594513773918, 36.6365434974432, 60.33703073859215, 38.38319577276707, 37.246733754873276, 21.652222350239754, 11.757042221724987, 2.8719759033992887, 0.6475293694529682, 0.8318393700756133, 6.382686132565141, 11.201580427587032, 17.844876050949097, 22.498792223632336, 24.07863724976778, 23.27740464359522, 27.865726836025715, 18.07504490017891, 29.82888389378786, 23.738903179764748, 19.922606460750103, 21.63723975419998, 27.552781328558922, 18.297175280749798, 21.597022712230682, 34.49483402073383, 42.58029095828533, 53.96335154771805, 70.26238694787025, 69.19405907392502, 66.0876801609993, 62.75346167385578, 64.06519308686256, 63.520788699388504, 62.85515941679478, 58.77980209887028, 59.99469190835953, 63.55747953057289, 66.69310927391052, 63.1691137701273, 66.50972351431847, 64.09697458148003, 67.93758809566498, 63.779152035713196, 65.01659363508224, 65.68124637007713, 62.78447560966015, 65.7258939743042, 62.18505397439003, 50.06629206240177, 39.61688697338104, 40.06926029920578, 44.233133867383, 61.88474088907242, 67.34944805502892, 60.32523237168789, 62.00862184166908, 58.3877619355917, 61.1253060400486, 61.42220690846443, 58.6926955729723, 63.15902531147003, 64.0461029112339, 68.2067808508873, 67.26481139659882, 62.69180238246918, 62.32144005596638, 67.66876012086868, 67.00194150209427, 65.80670043826103, 62.40643009543419, 60.022422820329666, 59.49479453265667, 56.67488984763622, 51.79402515292168, 43.321532383561134, 35.148984119296074, 44.16861332952976, 29.45898324251175, 30.942427441477776, 31.329812854528427, 20.359436720609665, 24.549428187310696, 25.025677531957626, 18.635170944035053, 19.113270789384842, 21.453555710613728, 14.313903171569109, 16.228418089449406, 19.220248349010944, 9.142260029911995, 1.5341383474878967, 0.6664153654128313, 0.4070897604105994, 2.0424675894901156, 10.695194900035858, 31.119914017617702, 43.78950387239456, 48.601945638656616, 54.244126081466675, 41.63252681493759, 44.814935848116875, 43.64912040531635, 51.21200658380985, 60.99873103201389, 67.50647842884064, 42.633879482746124, 11.712584607303143, 0.5966008210089058, 0.06611261531361379, 0.21466732869157568, 0.16408813884481788, 0.10450228190165944, 0.11968099788646214, 0.15593968390021473, 0.17151161941001192, 0.10896791063714772, 0.25051568867638707, 0.09043766316608526, 0.18547854182543233, 0.13707255333429202, 0.16092053381726146, 0.154831791005563, 0.1809265196789056, 0.15920028003165498, 0.14364002592628822, 0.18090928700985387, 0.1057408373162616, 0.12714925222098827, 0.09822010571951978, 0.1279702308238484, 0.16374293627450243, 0.057256752625107765, 0.1318326048203744, 0.17297546117333695, 0.1184389172703959, 0.12026979558868334, 0.1557980227516964, 0.15068328939378262], [0.011725829390343279, 0.05198968603508547, 0.0744815326470416, 0.01675168128713267, 0.02419974363874644, 0.013525697067962028, 0.06243000432732515, 0.06533238061820157, 0.010988886024279054, 0.03165981950587593, 0.04990127134078648, 0.04315593192586675, 0.050972539247595705, 0.02609349485283019, 0.03857488067296799, 0.037369217243394814, 0.02848045143764466, 0.03565966893802397, 0.04472158892895095, 0.09545445529511198, 0.09383344891830347, 0.062080768184387125, 0.022287203100859188, 0.004592763270920841, 0.06325464171823114, 0.04200958464934956, 0.028473629245127086, 0.08147625965648331, 0.4082612553611398, 2.6430362882092595, 17.168119065463543, 42.30960488319397, 51.04326903820038, 46.70327492058277, 41.81437365710735, 29.409139417111874, 42.38264836370945, 53.72984267771244, 58.47601220011711, 28.700745329260826, 28.016324155032635, 27.67718095332384, 15.76538348570466, 5.566467605531216, 0.34008026705123484, 0.28548966511152685, 1.2604060233570635, 2.7659034077078104, 7.67892150208354, 5.370501196011901, 4.573583733290434, 13.38542204350233, 10.134759172797203, 15.940667130053043, 4.712496204301715, 7.265426265075803, 10.390625093132257, 13.854238037019968, 15.929543226957321, 17.314810194075108, 19.827978238463402, 28.4098082408309, 44.2567154020071, 52.71547570824623, 65.16822829842567, 68.84583815932274, 64.05687153339386, 60.31265504658222, 59.429096058011055, 60.98073899745941, 63.16590294241905, 59.484732672572136, 54.31225262582302, 51.31794489920139, 59.19013448059559, 61.395729929208755, 62.95314095914364, 59.04645659029484, 62.66170419752598, 60.68639159202576, 60.97219705581665, 57.93016389012337, 64.53657299280167, 65.91076925396919, 57.83546917140484, 57.054687067866325, 43.0718819797039, 31.60330317914486, 33.257761001586914, 42.49375060200691, 53.610684871673584, 56.88406102359295, 61.866156086325645, 61.738247349858284, 63.024706318974495, 61.84617675840855, 61.380868926644325, 59.17777754366398, 58.47765751183033, 61.273395493626595, 63.30075390636921, 60.84488868713379, 56.21111333370209, 56.50789260864258, 57.344554513692856, 62.01623663306236, 64.07314226031303, 62.47752048075199, 65.46918734908104, 58.207765594124794, 58.66007812321186, 50.59005595743656, 50.2066945284605, 41.82287760078907, 37.67764963209629, 32.26734794676304, 46.91590391099453, 19.246181957423687, 9.12556467577815, 16.09553921967745, 22.426913380622864, 19.603875763714314, 13.107320666313171, 9.968773629516363, 8.28585248440504, 6.53821368701756, 2.911948333494365, 5.15396174043417, 2.7164559485390782, 0.3167102742008865, 0.10921871944447048, 0.8140952128451318, 4.5052168518304825, 18.455814868211746, 32.60286994278431, 45.81151217222214, 33.78021776676178, 18.79986170679331, 13.523416388779879, 24.57349419593811, 43.31744760274887, 47.67234832048416, 51.69442109763622, 32.27387219667435, 11.060853078961372, 1.431878472212702, 0.038020971333025955, 0.02928466121375095, 0.049116498412331566, 0.08258804882643744, 0.041666129836812615, 0.007132710816222243, 0.022177482132974546, 0.045861984181101434, 0.04026818336569704, 0.061554581770906225, 0.09437046697712503, 0.05061525822384283, 0.03702338013681583, 0.07031827713944949, 0.05471143471368123, 0.03727899806108326, 0.0007761831489005999, 0.04475734931475017, 0.03546093292243313, 0.02530087742343312, 0.023641900916118175, 0.012604896819539135, 0.05105771924718283, 0.014791547746426659, 0.02849867487384472, 0.06842646849690937, 0.04386072359920945, 0.045668699240195565, 0.07122745257220231, 0.05755803489591926, 0.05854921393620316, 0.09465539231314324, 0.022420568893721793, 0.03139150714559946, 0.014137101516098483, 0.023210206600197125, 0.023208705606521107, 0.03360568247444462, 0.06583900772966444, 0.01316449472142267, 0.05881655037228484, 0.04312388598918915, 0.02136469498509541, 0.017580233507032972, 0.06421158919692971, 0.033534102331032045, 0.019042683743464295, 0.06690839058137499, 0.025139979807136115, 0.05847071697644424, 0.06525619915919378, 0.07624921709066257, 0.013331975187611533, 0.02850165830750484, 0.022382691531674936, 0.08539327056496404, 0.004334608129283879, 0.03329249615489971, 0.4846204142086208, 3.227989487349987, 19.98678881675005, 49.73816066980362, 61.773338466882706, 57.237658649683, 48.25414650142193, 35.69048926234245, 43.65440212190151, 42.5198096036911, 43.2034233212471, 40.8914677798748, 28.830479867756367, 28.972457349300385, 12.795843780040741, 5.363158090040088, 0.6874025298748165, 0.7448993227444589, 0.9095895511563867, 3.912332053296268, 8.333304338157177, 12.101942114531994, 12.39059742540121, 14.917743019759655, 19.027005918323994, 14.190393649041653, 17.361488789319992, 10.997219793498516, 10.868427604436874, 18.449571803212166, 16.63850538432598, 15.166691411286592, 16.613227240741253, 30.545248053967953, 41.76876850426197, 54.67829838395119, 65.02709627151489, 69.04405072331429, 65.99956288933754, 64.1659864783287, 61.40483804047108, 63.39452527463436, 64.71080884337425, 62.04458691179752, 56.28347285091877, 53.95037904381752, 60.67042484879494, 62.42887169122696, 64.05849784612656, 61.63933485746384, 65.73397234082222, 62.04145587980747, 62.085130736231804, 59.36682119965553, 64.7041667997837, 65.1661080121994, 62.28499621152878, 60.9195888787508, 49.25109900534153, 38.772583678364754, 36.50633588433266, 49.34309966862202, 55.26357717812061, 58.35593104362488, 62.31589235365391, 61.884702891111374, 64.55430284142494, 64.60543289780617, 61.33780583739281, 60.490052327513695, 60.027772933244705, 63.12468655407429, 64.56917524337769, 63.54161158204079, 59.90251265466213, 58.6417593061924, 60.207054913043976, 62.79550261795521, 65.80825835466385, 63.44687506556511, 61.868059784173965, 59.893913716077805, 57.48760163784027, 53.53891812264919, 50.349490866065025, 41.78823105990887, 30.42315110564232, 23.79334855824709, 17.84460436552763, 14.70757344737649, 14.704065285623074, 22.091134898364544, 13.5529332049191, 17.92847726494074, 18.435995131731033, 11.449929401278496, 12.408170532435179, 10.633230675011873, 10.503514185547829, 3.6980242654681206, 2.984332786872983, 0.5845026858150959, 0.11486794013762847, 0.9837851417250931, 4.442970966920257, 21.616376973688602, 35.84346905350685, 44.068929478526115, 36.69988229870796, 21.826177015900612, 22.39868089556694, 30.704548805952072, 47.60590508580208, 52.635060623288155, 57.812613397836685, 37.4878004193306, 14.085420481860638, 1.601534381043166, 0.019779517642746214, 0.013699542378162732, 0.006267758571993909, 0.044835764638264664, 0.0856710787047632, 0.01365397543850122, 0.04018829858978279, 0.0734802418446634, 0.029082956607453525, 0.045154183098929934, 0.06258054156205617, 0.055064941916498356, 0.03625081924838014, 0.018855191265174653, 0.04940306389471516, 0.030767138305236585, 0.045481700290110894, 0.052244958860683255, 0.02137413881428074, 0.00792898053987301, 0.10368914779974148, 0.039143989197327755, 0.04892067161563318, 0.011320408957544714, 0.07440901739755645, 0.06473812070908025, 0.03781462830374949, 0.0693186635908205, 0.051688533640117384, 0.0851454229268711, 0.13494204031303525, 0.2925233548739925, 0.22699910681694746, 0.07310662243980914, 0.08613282814621925, 0.09805454741581343, 0.09313417511293665, 0.12482392543461174, 0.1665477646747604, 0.10248547332594171, 0.18440615327563137, 0.13962000492028892, 0.17532055877381936, 0.16807307110866532, 0.2786779368761927, 0.13197753141866997, 0.1033832122629974, 0.16369220305932686, 0.24480826134094968, 0.18187419773312286, 0.18612762418342754, 0.13997209462104365, 0.09178043095744215, 0.12920427398057655, 0.12443486935808323, 0.15426946571096778, 0.11052027577534318, 0.1803020914667286, 0.8404490549582988, 4.0760360565036535, 26.91928882151842, 57.61732667684555, 70.17181500792503, 65.09463384747505, 57.60111674666405, 42.20118150115013, 55.32780133187771, 65.79212442040443, 73.20798128843307, 39.90070894360542, 39.07849006354809, 38.897551372647285, 20.187256559729576, 7.879314674064517, 0.8580907364375889, 0.7077478850260377, 2.6111085014417768, 8.645046260207891, 17.06681840121746, 15.129436310380697, 14.729569517076015, 24.696852676570415, 22.90629755705595, 30.837936848402023, 17.392248138785362, 17.513383738696575, 21.401922181248665, 22.300231978297234, 25.902945958077908, 23.399402797222137, 21.90113179385662, 32.71089814603329, 45.392295867204666, 53.618489652872086, 67.73156315088272, 70.36008730530739, 67.32338905334473, 65.7542784512043, 62.53630332648754, 66.16692870855331, 66.84095174074173, 63.78962427377701, 59.84903432428837, 56.52031794190407, 63.40874791145325, 65.07815033197403, 65.21631851792336, 63.3325581997633, 65.84035903215408, 62.01252803206444, 63.397701904177666, 59.86784711480141, 63.466482013463974, 69.48675736784935, 65.76523706316948, 64.08115983009338, 53.88768620789051, 44.40384350717068, 43.74287277460098, 52.94628672301769, 58.587365224957466, 57.242396995425224, 63.27748015522957, 64.38512831926346, 66.56957790255547, 66.66848659515381, 64.41708460450172, 62.71665684878826, 60.88731341063976, 64.61582913994789, 66.16276413202286, 65.8714185655117, 62.46264047920704, 60.97662001848221, 63.64367790520191, 66.674315482378, 69.8352138698101, 64.32558551430702, 66.2106491625309, 57.86584094166756, 60.15152469277382, 53.10580976307392, 54.870047494769096, 48.286326974630356, 42.26070910692215, 40.457360073924065, 60.97902528941631, 28.19177784025669, 19.444840997457504, 24.060375429689884, 33.68361175060272, 33.37045915424824, 22.999977730214596, 20.96992716193199, 18.116736263036728, 19.20976471155882, 13.524368237704039, 11.10491931438446, 5.120718749240041, 0.6309890351258218, 0.37671588244847953, 1.489682870451361, 5.062694912776351, 22.648669481277466, 38.779050931334496, 60.58372490108013, 44.04712624847889, 29.96228713542223, 23.62971603870392, 38.0136352032423, 57.52763628959656, 60.212500020861626, 67.90113285183907, 46.61081448197365, 17.80598323792219, 3.0179298715665936, 0.13700274692382663, 0.15010272210929543, 0.15133149601751938, 0.19010060786968097, 0.18126824899809435, 0.13573615317000076, 0.10905475675826892, 0.2264519955497235, 0.1695811003446579, 0.15511646401137114, 0.21555999875999987, 0.16670236887875944, 0.08249828606494702, 0.12806905520847067, 0.12419440608937293, 0.13389501837082207, 0.09823894142755307, 0.14285354234743863, 0.12158065845142119, 0.23051255266182125, 0.21530643658479676, 0.1884644542587921, 0.13602674851426855, 0.07814707423676737, 0.14766913081984967, 0.15816810104297474, 0.14744103915290907, 0.17950732551980764, 0.12498106778366491, 0.2060784536297433], [0.0345006791758351, 0.03195050390786491, 0.0391013082844438, 0.007691306818742305, 0.016350108890037518, 0.04312332566769328, 0.027795964924735017, 0.037894739434705116, 0.03886774698912632, 0.16753835370764136, 0.1535257149953395, 0.028964194425498135, 0.02316794871148886, 0.03524559135257732, 0.0488685023447033, 0.07805587170878425, 0.0342119020933751, 0.04015435646579135, 0.06779147210181691, 0.012876187975052744, 0.0594816223019734, 0.02991198194649769, 0.06448169384384528, 0.07612784625962377, 0.07588506006868556, 0.039535620526294224, 0.043390843929955736, 0.09230957482941449, 0.09086722566280514, 6.295747747644782, 25.481113493442535, 41.965993121266365, 42.661731988191605, 42.803281992673874, 38.13644461333752, 37.844183295965195, 24.622600860893726, 44.71141040325165, 25.175628885626793, 35.94545178115368, 42.57531702518463, 17.707475423812866, 9.183506816625595, 1.5060217562131584, 0.48383922956418246, 0.34746632853057235, 0.564847884234041, 2.2659986699, 6.051340587437153, 7.544557861983776, 12.521636243909597, 16.956837102770805, 16.905971132218838, 12.647427543997765, 19.392595700919628, 8.037845492362976, 11.798169314861298, 16.72612678259611, 26.20121855288744, 25.784082636237144, 23.56829233467579, 42.58797034621239, 60.86275152862072, 58.52056100964546, 66.21346861124039, 61.319923996925354, 63.196673691272736, 58.45033697783947, 59.8698990046978, 60.296528711915016, 60.73229692876339, 59.09793242812157, 54.694082736968994, 46.388165429234505, 57.62231580913067, 61.029277592897415, 65.88306874036789, 61.23347483575344, 63.14727634191513, 62.37571254372597, 64.48647648096085, 58.54865290224552, 60.409093871712685, 49.41963516175747, 48.30515496432781, 63.47231090068817, 46.41625352203846, 32.70732253789902, 32.888086438179016, 53.14091607928276, 55.129007399082184, 59.227733463048935, 59.23398032784462, 62.65312425792217, 60.255965888500214, 61.05073504149914, 57.39609494805336, 61.90025545656681, 62.48733915388584, 63.238289058208466, 61.002033054828644, 58.64905871450901, 54.32506553828716, 55.28076745569706, 58.82030792534351, 60.47219708561897, 59.393860548734665, 62.09476701915264, 59.8018978536129, 62.34671249985695, 60.209608376026154, 60.81149987876415, 54.58394184708595, 47.6072084158659, 37.938201650977135, 37.41270124912262, 17.91777513921261, 11.42883388325572, 22.68358390778303, 34.56817388534546, 13.751285411417484, 19.5425508543849, 15.359891094267368, 10.958287082612514, 12.546843141317368, 8.496156949549913, 9.956253301352262, 1.448193727992475, 1.9942705007269979, 0.5781324463896453, 0.0533738322701538, 0.16316502587869763, 1.7034927662461996, 4.8098602797836065, 17.760554775595665, 41.5486691147089, 51.80952452123165, 44.41213846206665, 31.43597535789013, 28.69439586997032, 34.19243864715099, 43.31972748041153, 52.2409001737833, 45.67071832716465, 14.67460261657834, 4.623439908027649, 0.048214618291240185, 0.04936360019200947, 0.013252095977804856, 0.02501250110071851, 0.07339700998272747, 0.07135229665436782, 0.036919679841957986, 0.02278256812132895, 0.056842971898731776, 0.06778600247344002, 0.019071892820647918, 0.06649130358709954, 0.022560417346539907, 0.0863420766836498, 0.021271759542287327, 0.103424156550318, 0.012888930650660768, 0.0892165704863146, 0.018298806862731, 0.005224067017479683, 0.04841296839003917, 0.0600346113787964, 0.04506204175413586, 0.05068277139798738, 0.052264707410358824, 0.11855144170112908, 0.03627613761636894, 0.11767335483455099, 0.039982660600799136, 0.0692979725135956, 0.026456963532837108, 0.07715232175542042, 0.051083163780276664, 0.007526534727730905, 0.08478045696392655, 0.026828657064470463, 0.04468601408007089, 0.05314341025950853, 0.051877310033887625, 0.04464644276595209, 0.1195507361262571, 0.047285564432968386, 0.022376886081474368, 0.0727201416157186, 0.024027531981118955, 0.051414606932667084, 0.04709512933914084, 0.15855066332733259, 0.02694721144507639, 0.03492742522212211, 0.06488920713309199, 0.05153184029040858, 0.042797797432285734, 0.009761891415109858, 0.07656543879420497, 0.018262491721543483, 0.06623112145462073, 0.07315301409107633, 0.2449341889587231, 7.19400292262435, 29.124538488686085, 51.03173665702343, 52.55801975727081, 51.421466544270515, 43.526299595832825, 36.63423702120781, 29.515514709055424, 53.423309326171875, 40.57570092380047, 35.174659341573715, 36.46132729947567, 20.48210173845291, 9.766070656478405, 2.0474151615053415, 0.5389003234449774, 0.9315576567314565, 2.3336405027657747, 9.961740206927061, 14.067779928445816, 15.299232099205256, 14.813968688249588, 15.21397702395916, 16.545039899647236, 13.10424568131566, 19.189302809536457, 10.032949335873127, 9.613251406699419, 19.34491205960512, 18.568646013736725, 23.2584360614419, 26.02147299796343, 42.03367508947849, 58.29149790108204, 61.115388572216034, 66.15824237465858, 65.17514392733574, 64.64544475078583, 62.36701861023903, 62.21643649041653, 63.64226818084717, 62.357583716511726, 62.97144457697868, 56.41570955514908, 49.33884769678116, 58.86404737830162, 64.13750320672989, 66.06671288609505, 63.16732406616211, 64.02735471725464, 64.57406178116798, 64.01595532894135, 59.28660750389099, 60.76988451182842, 52.98667095601559, 53.280136808753014, 65.7797446846962, 49.665352776646614, 43.304733484983444, 37.0470354706049, 58.22359174489975, 56.43078334629536, 60.59300780296326, 61.28188803792, 64.16094034910202, 62.30060577392578, 63.19454200565815, 61.119815334677696, 64.69985783100128, 64.69486489892006, 66.67060688138008, 62.877308428287506, 61.32060796022415, 57.254024371504784, 57.286740615963936, 59.30841453373432, 61.605383679270744, 60.34919388592243, 63.632259517908096, 60.13360485434532, 61.752063408493996, 59.947559237480164, 59.51995298266411, 54.504127129912376, 46.081901863217354, 38.85607659816742, 33.858694955706596, 21.53668574988842, 12.372669037431479, 16.20884533971548, 15.37793917581439, 11.583317443728447, 18.854345083236694, 19.431395418941975, 10.49854215234518, 13.089926149696112, 11.400955729186535, 7.4556815810501575, 7.06843676045537, 4.295540302991867, 1.188262382056564, 0.19082236132817343, 0.1975752372527495, 1.876317705027759, 6.014168132096529, 22.160859256982803, 41.45450636744499, 44.273225516080856, 41.98590785264969, 29.095692336559296, 31.890218183398247, 42.07385033369064, 49.639369770884514, 58.95034834742546, 51.82206764817238, 18.452467247843742, 5.172762656584382, 0.20795587945031002, 0.038643644365947694, 0.022438990854425356, 0.047100528463488445, 0.016283376826322637, 0.07275178679265082, 0.037306271988200024, 0.061036072875140235, 0.0038903392805877957, 0.04896440637821797, 0.00871939100761665, 0.02183342061471194, 0.07659607465029694, 0.04534123399935197, 0.03381239286682103, 0.023337843012996018, 0.03562122568837367, 0.03081025894061895, 0.00856823871799861, 0.01979744978598319, 0.05892203553230502, 0.005675687998518697, 0.039143655230873264, 0.03470906311122235, 0.02514501342375297, 0.04865955808782019, 0.039195275312522426, 0.04326188092818484, 0.0807848155091051, 0.06375980679877102, 0.09977322784834541, 0.1717393400031142, 0.14805795683059841, 0.11839968734420836, 0.14850869280053303, 0.10362075889133848, 0.10964171393425204, 0.13137544185156003, 0.172279623511713, 0.2319421072024852, 0.26626821840181947, 0.16052113962359726, 0.10718123463448137, 0.26664422010071576, 0.1173406203452032, 0.18208192486781627, 0.1007776430924423, 0.26570124726276845, 0.1398950003203936, 0.11031333531718701, 0.20955295156454667, 0.15510552475461736, 0.231327282381244, 0.24302241654368117, 0.20198061101837084, 0.18513169168727472, 0.14425450935959816, 0.20366221375297755, 0.551087100757286, 10.905586760491133, 34.787026941776276, 59.90130811929703, 62.76894964277744, 59.797520488500595, 51.076597049832344, 51.12186402082443, 36.29599817097187, 55.80991566181183, 34.33905377984047, 47.57043398916721, 54.28642921149731, 24.700025506317616, 12.092715259641409, 2.2535911481827497, 1.0938863712362945, 0.6690036796499044, 2.345611760392785, 10.383879505097866, 18.90176083892584, 21.800695583224297, 24.600052870810032, 29.257417358458042, 28.723110929131508, 24.364716298878193, 33.191690146923065, 17.523156814277172, 19.507465437054634, 25.75323399156332, 32.72157557308674, 28.12535360455513, 28.499753214418888, 43.680506721138954, 62.331015542149544, 62.40144856274128, 69.88410964608192, 65.41920483112335, 66.58810570836067, 61.15270636975765, 64.28622722625732, 64.15730774402618, 63.0006156116724, 64.28539887070656, 58.09232398867607, 51.091211065649986, 61.3113858550787, 65.8241719007492, 70.06196290254593, 65.67327439785004, 64.95075836777687, 65.78373447060585, 64.72583323717117, 60.34817934036255, 62.65987269580364, 58.600869700312614, 57.64590114355087, 65.20982086658478, 56.451344043016434, 46.45464666187763, 45.222566574811935, 59.47137638926506, 58.92455153167248, 61.583876833319664, 63.2715904712677, 65.59524178504944, 66.28812700510025, 64.69285100698471, 63.49704757332802, 67.0813724398613, 68.24072062969208, 67.19528272747993, 66.53234750032425, 63.308657482266426, 58.884828463196754, 59.89042170345783, 63.447901010513306, 64.77069362998009, 64.01159316301346, 64.18402791023254, 62.1518399566412, 64.26371723413467, 61.19308300316334, 60.784969702363014, 55.92953324317932, 49.075852409005165, 43.07430624961853, 45.500958636403084, 28.88737991452217, 18.070477545261383, 32.208758890628815, 46.07405908405781, 25.824470669031143, 26.786970421671867, 21.15636795759201, 19.27765566855669, 26.686072535812855, 16.012509874999523, 18.01442865282297, 10.413049589842558, 5.915933903306723, 2.2282526828348637, 0.2965205622604117, 0.4119383596116677, 2.60474621783942, 7.098671263083816, 24.708179868757725, 49.06385265290737, 67.93815046548843, 56.007862240076065, 44.83175754547119, 40.841314271092415, 46.379118114709854, 56.79282411932945, 66.17683097720146, 61.073526218533516, 24.579568170011044, 6.579883201047778, 0.38013457087799907, 0.12269271479453892, 0.10302384209353477, 0.11188920427230187, 0.13112576853018254, 0.12940784508828074, 0.3366170497611165, 0.2305827895179391, 0.23406493157381192, 0.10773706613690592, 0.10418483565445058, 0.17018075566738844, 0.17679872398730367, 0.12669928808463737, 0.15334936586441472, 0.1305462105665356, 0.0796554225962609, 0.1879390879184939, 0.1100819930434227, 0.14174838055623695, 0.19349510228494182, 0.12542447133455426, 0.12858849921030924, 0.14981502114096656, 0.1569609681610018, 0.21158137475140393, 0.14228021842427552, 0.2112487144768238, 0.15949402208207175, 0.13858377380529419], [0.013965994730824605, 0.018000983000092674, 0.06813044805312529, 0.02930488102720119, 0.031827084749238566, 0.05617758826701902, 0.023543404931842815, 0.04064829656272195, 0.013770174427918391, 0.018353061568632256, 0.042849154051509686, 0.08097920625004917, 0.05210827381233685, 0.06349474133457989, 0.05923221615375951, 0.03658206944237463, 0.01807194345019525, 0.03910526764229871, 0.003979502989750472, 0.001213895702676382, 0.05858527118107304, 0.032910063746385276, 0.04887913732090965, 0.019398582517169416, 0.0355959221633384, 0.021141653633094393, 0.05873073954717256, 0.0480634539417224, 1.2392672826536, 10.73625074699521, 33.3956404030323, 46.1688069999218, 51.488361954689026, 49.70563821494579, 39.618296697735786, 27.543906904757023, 27.30696301907301, 16.879917830228806, 26.196447908878326, 40.6417565792799, 32.79160961508751, 18.19588791579008, 4.602981805801392, 0.35039947426412255, 0.2652824384858832, 2.4706981983035803, 2.3534391028806567, 6.883158702403307, 7.13767284527421, 15.184296816587448, 12.794609796255827, 10.965586490929127, 19.473660551011562, 8.031705021858215, 22.571064345538616, 11.353966500610113, 8.669738285243511, 37.800732627511024, 30.757531262934208, 36.39076508581638, 35.850958451628685, 56.49996243417263, 58.45554269850254, 67.57132574915886, 61.527700647711754, 63.27420853078365, 58.06302756071091, 59.93311621248722, 59.94680307805538, 63.61981898546219, 63.644863441586494, 61.26991108059883, 56.44481599330902, 47.38312304019928, 48.349791169166565, 58.84342588484287, 58.76359976828098, 59.76161241531372, 58.24710488319397, 64.45208072662354, 64.46429327130318, 62.763489335775375, 62.351177260279655, 56.67124964296818, 61.63382135331631, 54.349061250686646, 54.323473423719406, 35.81901356577873, 33.84347677230835, 43.27474929392338, 53.76092121005058, 59.58028234541416, 60.33473566174507, 62.44781367480755, 60.03825657069683, 57.99158379435539, 57.04340547323227, 57.114678248763084, 58.60507607460022, 59.32560481131077, 59.0739481151104, 54.95990887284279, 53.45272354781628, 54.74198676645756, 56.25815860927105, 56.14665359258652, 58.42864014208317, 61.925752088427544, 59.5647107809782, 62.340287044644356, 59.59580451250076, 64.04579132795334, 63.78618165850639, 59.57029648125172, 47.75797672569752, 36.78318902850151, 22.68158331513405, 24.01722874492407, 21.598611027002335, 21.90605442970991, 5.663257911801338, 15.6561697460711, 30.150112956762314, 9.642902165651321, 10.231710020452738, 10.222023390233517, 8.000188563019037, 3.1585873989388347, 4.265719028189778, 0.9271866444032639, 0.7405807950999588, 0.05559169607295189, 0.5295965226832777, 6.72358768992126, 14.864095598459244, 30.580401867628098, 27.784551791846752, 20.447295606136322, 29.659680873155594, 29.703287333250046, 34.10090535879135, 47.611099407076836, 46.55387833714485, 48.46165716648102, 29.143324680626392, 8.36030948907137, 0.651745421346277, 0.050323735194979236, 0.08015448722289875, 0.04062600986799225, 0.07339123607380316, 0.03554243186954409, 0.025383897773281205, 0.0361358531517908, 0.09050438966369256, 0.014421670621231897, 0.00968477670539869, 0.024591293331468478, 0.017766432792996056, 0.1560167336720042, 0.06305016519036144, 0.03878490475472063, 0.03543929189618211, 0.05413356142526027, 0.1294775475980714, 0.045757074185530655, 0.050288078709854744, 0.011704804346663877, 0.07827909488696605, 0.03984858420153614, 0.08102098174276762, 0.08275359228719026, 0.010771758661576314, 0.031483834027312696, 0.060948684986215085, 0.037642283059540205, 0.0642625376349315, 0.06128524895757437, 0.029713548356085084, 0.025208064434991684, 0.0372568783495808, 0.0929261436976958, 0.049409598505008034, 0.06353885459247977, 0.1039161262451671, 0.05466552174766548, 0.06828007244621404, 0.012397604768921155, 0.05760467887739651, 0.028447834047256038, 0.06352464246447198, 0.021194171713432297, 0.0638079499185551, 0.055833966471254826, 0.023970071197254583, 0.020147795439697802, 0.02656942859175615, 0.02550224249716848, 0.02819107878167415, 0.04750523643451743, 0.0380935979046626, 0.01564643043820979, 0.006154819466246408, 0.03647440978966188, 1.394814548548311, 12.186551224440336, 38.17849315702915, 54.79719400405884, 58.63772392272949, 54.74173218011856, 42.58099392056465, 33.76973792910576, 28.759169094264507, 23.446854650974274, 23.506310060620308, 40.13980731368065, 31.68269421905279, 16.415311060845852, 4.526159903034568, 0.4835820308653638, 0.33717015758156776, 1.613925516139716, 5.678378250449896, 10.721733625978231, 11.322891768068075, 12.350659668445587, 16.530283391475677, 11.945323068648577, 16.042351573705673, 9.328071009367704, 11.848570760339499, 8.44500694423914, 11.819898448884487, 19.343099556863308, 22.966687716543674, 33.44921752810478, 38.62935036420822, 52.96368218958378, 58.862584456801414, 67.79741361737251, 65.37916257977486, 64.8800365626812, 61.46121561527252, 62.012843415141106, 60.97448453307152, 65.36143273115158, 66.31636708974838, 62.888179644942284, 58.9298864454031, 49.56707485020161, 51.20526574552059, 60.80505542457104, 61.6964115947485, 61.51893071830273, 60.83762727677822, 65.8155919611454, 64.16156351566315, 62.894449308514595, 62.729891538619995, 59.031405597925186, 61.71817682683468, 56.73633635044098, 53.51852461695671, 41.55444860458374, 38.12509462237358, 46.9529215246439, 55.89370496571064, 59.72362205386162, 63.298546224832535, 63.34929250180721, 61.26579590141773, 60.266377329826355, 58.58909033238888, 59.93469312787056, 61.88514366745949, 61.83036960661411, 61.391097977757454, 57.236651703715324, 55.076357424259186, 56.72682926058769, 58.732722625136375, 58.53739030659199, 60.95247611403465, 63.21673661470413, 61.646083295345306, 62.23349377512932, 61.38740837574005, 66.20554983615875, 65.60385212302208, 60.82592770457268, 48.724800646305084, 36.69821418821812, 24.42150615155697, 19.567226730287075, 10.745555497705936, 15.864045191556215, 8.88672849163413, 14.99156640842557, 21.606203019618988, 14.036049731075764, 9.85666824504733, 13.506371453404427, 10.340405087918043, 6.112055629491806, 4.9778117425739765, 2.1576491463929415, 0.762750111753121, 0.2700700331479311, 0.6091451947577298, 5.399391520768404, 15.536145586520433, 35.62375344336033, 34.92079496383667, 24.660937003791332, 33.05846929550171, 31.508992239832878, 37.84675195813179, 52.83117949962616, 51.41623042523861, 55.47483064234257, 31.842865124344826, 9.864292535930872, 0.850195650709793, 0.011139725684188306, 0.04701251345977653, 0.04635239536582958, 0.08178926786058582, 0.032998115857481025, 0.02134010206646053, 0.023774012479407247, 0.04486397738219239, 0.07114883686881512, 0.035086690113530494, 0.013155886736058164, 0.03657653302070685, 0.06918524028151296, 0.032992779815685935, 0.012312778217165032, 0.02502521594578866, 0.06727183514158241, 0.05771504365839064, 0.08132076487527229, 0.022436120598285925, 0.03351696614117827, 0.04587392533721868, 0.0102284230706573, 0.06618747574975714, 0.09216807695338503, 0.07785262714605778, 0.013855266297468916, 0.040100008991430514, 0.06324077097815461, 0.10383587039541453, 0.1303532818565145, 0.14732600626302883, 0.16627930017421022, 0.1645809249021113, 0.1660744080436416, 0.15109856554772705, 0.17557419516379014, 0.2664477290818468, 0.1601301465416327, 0.23747756407829002, 0.142902153020259, 0.15864738001255319, 0.1269495254382491, 0.18273805762873963, 0.10674062898033299, 0.1341712605790235, 0.1398665166925639, 0.12286517507163808, 0.07221596359158866, 0.14307220873888582, 0.1525928798946552, 0.11370587788405828, 0.22758078732294962, 0.13587316847406328, 0.1349521632073447, 0.09548914327751845, 0.17320171231403947, 1.9450494856573641, 15.588767062872648, 45.332954451441765, 65.72543799877167, 68.06472167372704, 64.75926384329796, 53.33355814218521, 41.17315426468849, 38.20532351732254, 28.113239854574203, 37.56314277648926, 52.99685440957546, 39.99786213040352, 23.301499150693417, 6.267802147194743, 0.8338691736571491, 0.5598643328994513, 6.255444260314107, 7.070368006825447, 12.545857094228268, 16.844689920544624, 26.857346445322037, 22.115294001996517, 22.593916319310665, 36.32383167743683, 19.802211821079254, 32.6578301936388, 20.927242152392864, 16.310396790504456, 46.22545816004276, 35.344263240695, 38.891874477267265, 40.21141067147255, 56.50065019726753, 61.92625746130943, 71.12684056162834, 66.82187676429749, 67.53772035241127, 62.218157798051834, 64.90820825099945, 64.29982289671898, 66.98300331830978, 68.70934948325157, 66.56276106834412, 60.976274237036705, 52.6643418520689, 53.52612800896168, 63.88459637761116, 63.6343190073967, 64.07752722501755, 63.76450002193451, 67.47970506548882, 65.76587542891502, 64.45718005299568, 64.74099442362785, 59.500543624162674, 60.96476465463638, 57.66971446573734, 56.94538973271847, 48.409645557403564, 45.73950223624706, 53.772062212228775, 57.15819351375103, 60.81143908202648, 64.32747021317482, 66.62674203515053, 64.07360583543777, 63.070068284869194, 61.546456441283226, 62.848733961582184, 64.48535934090614, 64.22169908881187, 64.43182781338692, 57.574548572301865, 56.30516968667507, 59.185749515891075, 60.840743109583855, 61.58077619969845, 63.587813302874565, 67.34469071030617, 64.73215609788895, 66.98435604572296, 64.42364305257797, 71.14951014518738, 69.32870864868164, 65.4637460410595, 51.74629591405392, 39.37998108565807, 25.40424171835184, 31.862525269389153, 32.11966127157211, 31.336010321974754, 17.70189542323351, 26.973605006933212, 43.463203981518745, 22.255761064589024, 19.860772378742695, 24.172944389283657, 20.71795128285885, 11.548767797648907, 9.262705016881227, 2.578057162463665, 1.4839891134761274, 0.3133340069325641, 0.7893908978439867, 8.099222648888826, 19.831874929368496, 40.79708084464073, 38.83674703538418, 33.26254494488239, 41.59774728119373, 41.820567324757576, 48.0914506316185, 61.427070647478104, 59.53647069633007, 63.33218201994896, 39.34845797717571, 12.746810261160135, 1.305915943812579, 0.12816868111258373, 0.13850546238245443, 0.15312790899770334, 0.18477114150300622, 0.24191344011342153, 0.09243621490895748, 0.13726698118261993, 0.15428947401233017, 0.1659922077669762, 0.16279505041893572, 0.0757621529919561, 0.07412675637169741, 0.2695827092975378, 0.301990220323205, 0.06403799343388528, 0.12918114865897223, 0.10623846959788352, 0.29352935089264065, 0.12744133186060935, 0.11372254652087577, 0.10911680772551335, 0.19215319538488984, 0.13630946225021034, 0.1564641299773939, 0.1706143925548531, 0.10739504738012329, 0.07686390832532197, 0.19627533591119573, 0.1383431101567112], [0.038417148316511884, 0.0591359670215752, 0.03169912735756952, 0.02768287275102921, 0.02285945462062955, 0.022889342762937304, 0.11022170234355144, 0.037969904151395895, 0.10376089863711968, 0.04791172927070875, 0.030707336045452394, 0.15454199718078598, 0.023971371811057907, 0.031989028793759644, 0.024800976025289856, 0.06709249515552074, 0.07108913850970566, 0.0689731418970041, 0.08081448657321744, 0.03302668483229354, 0.07171062781708315, 0.0305924033455085, 0.040204577599070035, 0.04189303406747058, 0.03611233078117948, 0.04448495885299053, 0.04291263365303166, 0.03324168501421809, 1.0083083133213222, 17.045290656387806, 38.78490261733532, 45.558593943715096, 49.67800609767437, 49.222102761268616, 31.88058950006962, 23.489355370402336, 23.097436800599098, 29.748227521777153, 53.31935830414295, 34.53720934689045, 26.590279676020145, 8.681276366114616, 1.2218287121504545, 0.1876040527713485, 0.2074140968034044, 1.1645212559960783, 5.859141675755382, 16.228518784046173, 14.550903104245663, 12.098095770925283, 12.019570134580135, 9.163382146507502, 11.08065476641059, 8.00148144364357, 10.359036438167095, 8.03541362285614, 18.84801272302866, 27.12883237749338, 33.74805249273777, 49.47664350271225, 55.476878732442856, 57.85347260534763, 65.60636758804321, 57.83077262341976, 60.34888230264187, 59.647052362561226, 59.262136816978455, 57.44030177593231, 60.79406261444092, 60.98174974322319, 60.66881373524666, 59.36012975871563, 58.27839620411396, 46.57108761370182, 46.28133036196232, 50.78642562031746, 56.34871914982796, 59.5129157602787, 59.84535612165928, 61.59314073622227, 63.09172332286835, 63.638080805540085, 59.03321050107479, 62.74876892566681, 59.92000311613083, 57.49506823718548, 54.26113396883011, 51.56153082847595, 32.39764675498009, 40.68999499082565, 53.22510056197643, 59.18858416378498, 61.11145578324795, 59.985051825642586, 58.1384839117527, 55.654667392373085, 53.309722021222115, 56.545191407203674, 56.154325380921364, 54.94581542909145, 52.68280506134033, 54.614059031009674, 53.510039672255516, 56.00844740867615, 55.45002557337284, 55.106713995337486, 56.125135347247124, 54.517304822802544, 52.381253242492676, 57.79267206788063, 60.22063538432121, 58.99392060935497, 57.772833332419395, 58.51327300071716, 55.245554745197296, 50.2399617433548, 40.366943925619125, 21.060901880264282, 21.015832498669624, 13.963485974818468, 11.364019811153412, 18.18400975316763, 15.452628917992115, 10.17146235331893, 8.766900021582842, 8.312325663864613, 4.991214573383331, 6.262637274339795, 4.466153997927904, 1.935470080934465, 0.5905303498730063, 0.14695479883812368, 0.17808642442105338, 2.6015463145449758, 10.160054415464401, 18.78035545349121, 40.02890266478062, 46.23926281929016, 39.98302772641182, 27.44969855993986, 24.51497543603182, 42.30761379003525, 46.09868176281452, 50.27850307524204, 37.22652263939381, 12.42413442581892, 1.1442532623186707, 0.030860220322210807, 0.023956809018272907, 0.06774774476070888, 0.027556145469134208, 0.018098067048413213, 0.04903476939944085, 0.06745363163645379, 0.022025905891496222, 0.06219489936484024, 0.013306757009559078, 0.04638399230316281, 0.011793195062637096, 0.08399842627113685, 0.061902905072201975, 0.1351065596099943, 0.010614458606141852, 0.02402516267466126, 0.019342465020599775, 0.0401846880413359, 0.05462238070322201, 0.006321143573586596, 0.05858806165633723, 0.021040530446043704, 0.048155472832149826, 0.0383589602279244, 0.060387383855413646, 0.06612799261347391, 0.022961366339586675, 0.05421052213932853, 0.008313221933349269, 0.058948726873495616, 0.01961085530638229, 0.037886683421675116, 0.02124798298609676, 0.04122452228330076, 0.07214550409116782, 0.07563727922388352, 0.1278886094223708, 0.008183883219317067, 0.08741106619709171, 0.04209991515381262, 0.03547756445186678, 0.026567966560833156, 0.04219686561555136, 0.0467756867146818, 0.036601432075258344, 0.028678480557573494, 0.06554657928063534, 0.025295038576587103, 0.03622539326897822, 0.029536490474129096, 0.031163211388047785, 0.04384806255984586, 0.013962187513243407, 0.013952206554677105, 0.06398369048838504, 0.050093587778974324, 1.4536179369315505, 21.663912422955036, 43.5084443539381, 54.73076596856117, 56.49270862340927, 55.29607683420181, 38.90247590839863, 29.72450539469719, 30.13603661209345, 32.74622865021229, 48.23409117758274, 32.757605239748955, 25.131680443882942, 10.509270876646042, 1.5041795675642788, 0.5613377632107586, 0.9445216704625636, 2.7837712364271283, 7.804832495748997, 10.430988427251577, 13.89886474236846, 14.188978224992752, 9.37406849116087, 13.350247330963612, 15.297851823270321, 11.456620842218399, 8.80051301792264, 8.752450346946716, 18.544264622032642, 21.605539955198765, 31.197494454681873, 45.926091223955154, 53.30326236784458, 59.187026247382164, 67.54121616482735, 58.703034818172455, 63.09488855302334, 62.66084164381027, 60.206332951784134, 60.049743354320526, 62.81165175139904, 64.65924561023712, 61.566477566957474, 62.11833335459232, 60.63036359846592, 49.16890561580658, 48.281284645199776, 52.95895904302597, 57.89689667522907, 61.49540238082409, 61.51511192321777, 63.632692694664, 63.98577734827995, 64.84566360712051, 59.86217021942139, 63.1293299049139, 59.14891429245472, 56.66875697672367, 54.831217378377914, 50.82080617547035, 38.46541576087475, 45.07826551795006, 55.57057410478592, 59.98958498239517, 62.51598961651325, 62.23346337676048, 60.774147883057594, 56.68657422065735, 55.90504355728626, 58.25816988945007, 58.23968008160591, 57.31036774814129, 55.38886785507202, 55.13227142393589, 55.75212836265564, 56.924266666173935, 58.92907328903675, 57.07373924553394, 58.64643685519695, 58.82846988737583, 57.765484526753426, 58.51601265370846, 62.83281281590462, 60.42640954256058, 60.593847557902336, 59.61017534136772, 58.08183655142784, 49.079401418566704, 41.57924987375736, 25.457849241793156, 17.24080916494131, 15.89677283540368, 7.167671760544181, 9.891661517322063, 19.4958608597517, 14.25690907984972, 14.985236898064613, 15.902489628642797, 12.472055554389954, 9.399237390607595, 7.840256569907069, 4.487365884706378, 1.0758121660910547, 0.43638770235702395, 0.3106833522906527, 2.707904032431543, 11.076553836464882, 23.242431320250034, 35.54147265851498, 35.31431324779987, 36.936867982149124, 33.312367871403694, 33.66447977721691, 48.56553219258785, 52.32317715883255, 56.88730224967003, 42.59344585239887, 15.713591314852238, 1.3820775132626295, 0.03119535009318497, 0.08064430468948558, 0.04032377393741626, 0.02731576569203753, 0.061702425009571016, 0.04267195887223352, 0.04164729412877932, 0.030588020963477902, 0.009328080122941174, 0.06265378411626443, 0.02601721691462444, 0.03420002401981037, 0.06404443527571857, 0.08965080851339735, 0.026706464304879773, 0.04760801275551785, 0.03654359279607888, 0.07954072367283516, 0.038047825946705416, 0.1315688158501871, 0.030975041700003203, 0.010542315358179621, 0.07487749069696292, 0.024385493925365154, 0.035417157341726124, 0.018356614600634202, 0.02248379616503371, 0.02543477570725372, 0.013588722104032058, 0.147446634946391, 0.12413833683240227, 0.17627027031267062, 0.20370179991004989, 0.10131549235666171, 0.08968294350779615, 0.22751380107365549, 0.15942964819259942, 0.23813948559109122, 0.09240779807441868, 0.23986266343854368, 0.19764403434237465, 0.10542709438595921, 0.22526472253957763, 0.20554896094836295, 0.2412611071486026, 0.14244870078982785, 0.1714863270171918, 0.3321965807117522, 0.12954165431438014, 0.0904817615810316, 0.15150823106523603, 0.12759344244841486, 0.12408614158630371, 0.1735369404195808, 0.19946381013141945, 0.14187938446411863, 0.22794651769800112, 2.522724294103682, 26.354882307350636, 52.10287258028984, 62.438093796372414, 64.42004844546318, 62.50206336379051, 45.61298802495003, 37.80151158571243, 33.126253858208656, 42.43041940033436, 69.07489746809006, 44.364439621567726, 35.9154561907053, 11.25910934060812, 1.8422083603218198, 0.5529426480643451, 1.0864114598371089, 4.266529334709048, 12.379231285303831, 25.562780611217022, 25.563956648111343, 19.8935342207551, 25.90238928794861, 22.071524150669575, 23.62072192132473, 22.086683437228203, 20.86233403533697, 15.130510702729225, 28.20410057902336, 31.90045103430748, 36.66532315313816, 54.1420179605484, 56.573078110814095, 62.24501475691795, 69.30872932076454, 61.28321036696434, 64.68004569411278, 64.53665658831596, 62.513204365968704, 61.280307322740555, 64.05738070607185, 64.91771534085274, 63.06300446391106, 63.94189730286598, 63.3977285027504, 51.81084305047989, 51.507664918899536, 55.40973633527756, 60.97777895629406, 64.32747781276703, 64.1578321158886, 66.54174819588661, 67.53169387578964, 66.60132899880409, 61.15644916892052, 61.838295981287956, 59.55981284379959, 57.244764268398285, 55.76730094850063, 54.123429358005524, 42.922538593411446, 51.28901705145836, 56.47689387202263, 63.29448044300079, 63.50484095513821, 65.8261401951313, 62.927473336458206, 60.22901393473148, 58.36490236222744, 62.86954164505005, 60.2829634398222, 58.4830342233181, 56.9877764582634, 58.8895858079195, 57.98092536628246, 60.558824837207794, 59.76585678756237, 58.362557888031006, 60.2566422522068, 60.351872742176056, 59.7774575650692, 63.23760889470577, 66.09404861927032, 64.8744660615921, 63.630295023322105, 64.1203661262989, 60.598870888352394, 57.45055742561817, 49.34930093586445, 28.32921266555786, 24.790036976337433, 19.872538447380066, 17.470446042716503, 28.14899403601885, 25.852074287831783, 17.513549029827118, 19.86299715936184, 17.377121150493622, 11.727876886725426, 17.18043990433216, 12.661018464714289, 6.959029706194997, 1.7003130493685603, 0.6889556965325028, 0.32247744442429394, 3.785617402754724, 12.422253526747227, 28.729445189237595, 48.57819311320782, 56.10696092247963, 51.53291456401348, 39.82940576970577, 38.107098788022995, 55.30077338218689, 59.32457126677036, 66.06406062841415, 50.0825247913599, 19.19907968491316, 2.0938244462013245, 0.12867161975009367, 0.22687680087983608, 0.13689486833754927, 0.09124806616455317, 0.18342098192078993, 0.14850731240585446, 0.10822716561960988, 0.10060865606646985, 0.08983943276689388, 0.12952357559697703, 0.0823640389717184, 0.14903906121617183, 0.17336125922156498, 0.12494934839196503, 0.2262493595480919, 0.16209093038924038, 0.1492677762871608, 0.20392301928950474, 0.1597810848033987, 0.39389974786899984, 0.09351422151667066, 0.10330277829780243, 0.15530580072663724, 0.1056999598222319, 0.22837495955172926, 0.16541299119126052, 0.2406425864319317, 0.14124716370133683, 0.13520446373149753], [0.039363727992167696, 0.08734030983760022, 0.02292803463205928, 0.06269213088671677, 0.08160476252669469, 0.020385483076097444, 0.02272165449539898, 0.06272865939536132, 0.034653149705263786, 0.0458546220761491, 0.12285329328733496, 0.04503483090957161, 0.019095680509053636, 0.07278216289705597, 0.0233366963948356, 0.08557067354558967, 0.04668099609261844, 0.02297710358106997, 0.07431685749907047, 0.08530985316610895, 0.04728390573291108, 0.10962660380755551, 0.02398169322987087, 0.0198751303832978, 0.023527508128609043, 0.048817646675161086, 0.039082732328097336, 0.14991969364928082, 4.978032605722547, 20.1709421351552, 41.629304587841034, 52.320445105433464, 47.192046493291855, 43.046252354979515, 25.122585631906986, 17.799236699938774, 24.035403169691563, 34.321050345897675, 40.77466204762459, 38.02595034241676, 18.599823340773582, 5.0192247703671455, 0.5674570379778743, 0.18231515219667926, 0.8538713597226888, 1.5853725420311093, 7.137211645022035, 7.047640476375818, 9.48543956503272, 10.066513884812593, 10.869832579046488, 8.19780645892024, 10.865678451955318, 5.504479156807065, 3.870335756801069, 10.538959633558989, 26.51831913739443, 32.73864425718784, 42.70243160426617, 51.91826328635216, 57.63068675994873, 62.92734794318676, 61.819935366511345, 61.64947651326656, 57.80067443847656, 56.12195111811161, 57.790008410811424, 61.07709422707558, 62.84898854792118, 60.76155535876751, 62.242005318403244, 60.88577829301357, 60.07731847465038, 46.82208314538002, 44.10024739801884, 46.64668835699558, 50.38663387298584, 53.59154909849167, 56.94652207195759, 57.70103998482227, 60.14733351767063, 60.35316467285156, 57.26935274899006, 54.80828180909157, 57.608617544174194, 55.9498355537653, 54.08960737287998, 45.26697479188442, 36.09736382961273, 42.43991129100323, 47.910253554582596, 61.73526830971241, 59.81352522969246, 61.77292428910732, 56.7281249910593, 54.271686002612114, 47.60744780302048, 46.890285685658455, 47.13665686547756, 46.648500859737396, 49.07369792461395, 52.38392069935799, 52.42580585181713, 55.39587087929249, 54.75778631865978, 59.85561557114124, 59.27740819752216, 59.19807605445385, 57.14325651526451, 51.96913495659828, 50.01979775726795, 49.735284224152565, 46.76750287413597, 43.874015137553215, 36.05537988245487, 30.348268523812294, 32.38261096179485, 28.281502425670624, 13.098181206732988, 19.823152497410774, 8.91116688027978, 6.572496397420764, 16.710188537836075, 15.483419615775347, 8.661458529531956, 15.581541750580072, 12.84615308046341, 2.9575879219919443, 3.7670632358640432, 2.8823961317539215, 0.7169353170320392, 0.20576687034917995, 0.0799719114729669, 0.8341686450876296, 5.830356795340776, 17.270740158855915, 31.78430076688528, 56.41121059656143, 41.88256859779358, 23.79833009094, 22.565809227526188, 42.65802338719368, 44.140806421637535, 47.530114352703094, 32.56473898887634, 15.224004685878754, 2.6721961610019207, 0.05130798257596325, 0.06778611379559152, 0.10092995406012051, 0.03968969780544285, 0.008034027832763968, 0.008150674893840915, 0.022874726164445747, 0.0810328932129778, 0.03546344509231858, 0.007324999423872214, 0.050683854933595285, 0.03519436460919678, 0.0849756492243614, 0.055607618851354346, 0.0234076290144003, 0.017845864858827554, 0.10016503729275428, 0.026512971562624443, 0.09024903149111196, 0.08277464701677673, 0.07382818293990567, 0.04245617201377172, 0.04010807242593728, 0.0933145169983618, 0.07446150950272568, 0.06103218773205299, 0.08020027773454785, 0.11312689879559912, 0.0444966736540664, 0.04324401372286957, 0.03551486479409505, 0.03802365419687703, 0.05026398488553241, 0.04441802084329538, 0.0434838053479325, 0.06360601153573953, 0.03871657892887015, 0.043907011349801905, 0.02296989732712973, 0.06320996442809701, 0.09733815226354636, 0.028203125693835318, 0.05882066187041346, 0.049653345777187496, 0.024028704574448057, 0.04570618511934299, 0.04267483469448052, 0.07938513241242617, 0.06829106365330517, 0.06481475487817079, 0.06156095681944862, 0.02771003721136367, 0.023307164483412635, 0.08677868216182105, 0.02591768748970935, 0.05889023821509909, 0.1832041412126273, 6.297622947022319, 24.866572469472885, 48.4596698731184, 58.83293464779854, 52.71396718919277, 47.928363382816315, 28.94436925649643, 20.862748213112354, 21.793517768383026, 31.297757774591446, 41.99992150068283, 36.9423358887434, 19.546268954873085, 5.021450500935316, 0.4019878513645381, 0.32478347537107766, 2.738100537098944, 4.787162197753787, 9.513256922364235, 9.86647266894579, 11.17719903588295, 13.468629028648138, 10.754285529255867, 11.85563363134861, 15.728325974196196, 10.608467403799295, 9.026624634861946, 14.050222970545292, 24.064519107341766, 30.67631632089615, 44.79644224047661, 51.96838639676571, 56.56277306377888, 61.69746793806553, 62.11674503982067, 61.24795585870743, 59.94328826665878, 57.77901940047741, 59.49970006942749, 63.14109027385712, 64.5314508676529, 62.102495804429054, 63.1367015093565, 62.43937812745571, 61.122900769114494, 48.424764946103096, 46.1394839733839, 49.64318476617336, 52.141584903001785, 56.22681029140949, 60.246644988656044, 61.36040702462196, 62.54410810768604, 61.45238108932972, 57.47746378183365, 56.36930264532566, 57.77511700987816, 55.262695625424385, 56.100550666451454, 47.25805655121803, 41.14980071783066, 46.46522529423237, 50.92195674777031, 63.024938106536865, 62.95592240989208, 63.500851169228554, 58.235386312007904, 57.284407541155815, 50.4535748809576, 50.289799869060516, 49.28508058190346, 48.91447886824608, 51.90002426505089, 54.32399779558182, 55.300279408693314, 57.053718119859695, 56.94606989622116, 62.315341383218765, 62.20121070742607, 61.78101785480976, 59.9875482916832, 57.87639297544956, 54.982046484947205, 56.22931055724621, 52.496178075671196, 46.18052177131176, 40.51086500287056, 35.79924322664738, 31.91527023911476, 29.647331535816193, 16.837745793163776, 17.263811230659485, 9.026755727827549, 8.445155136287212, 7.943501779809594, 12.587389815598726, 10.657280534505844, 12.067206278443336, 12.823644038289785, 5.737309763208032, 8.96056517958641, 4.174199514091015, 1.0929809510707855, 0.64167216187343, 0.06627978407777846, 1.17925496539101, 6.354664536193013, 18.887838385999203, 37.0527845621109, 58.52636709809303, 49.19553078711033, 30.924794487655163, 26.517038606107235, 48.11030521988869, 50.039746686816216, 53.543652668595314, 40.14132343232632, 17.853784672915936, 3.7496884306892753, 0.015407260361826047, 0.027023693473893218, 0.03476371486613061, 0.05573961723712273, 0.0212913522409508, 0.048536855101701804, 0.07027041603578255, 0.04206626246741507, 0.03382947339559905, 0.026785811023728456, 0.03425554037676193, 0.04528263030806556, 0.04716158495284617, 0.041503666288917884, 0.043465333292260766, 0.04516641369264107, 0.08070212541497312, 0.08793941597105004, 0.03124803515675012, 0.054891383260837756, 0.08177504831110127, 0.04775965950102545, 0.028760547247657087, 0.07675793705857359, 0.02530166781070875, 0.013357865009311354, 0.09882331592962146, 0.16174942371435463, 0.02799358215270331, 0.10971995114232413, 0.19368498818948865, 0.07476745246094652, 0.20094890700420365, 0.2724746213061735, 0.12478923745220527, 0.142611691262573, 0.15581745217787102, 0.1260823110351339, 0.20881779491901398, 0.19145340949762613, 0.1865912735229358, 0.14793737267609686, 0.22624288802035153, 0.19787208148045465, 0.163984312384855, 0.17640124453464523, 0.14598522742744535, 0.16065733856521547, 0.19383478327654302, 0.22700065048411489, 0.1627304538851604, 0.10403938213130459, 0.12425165536114946, 0.18643626855919138, 0.09979673908674158, 0.1582580344984308, 0.45573282055556774, 8.701022956520319, 31.638741977512836, 55.643047615885735, 67.7088251709938, 58.870963007211685, 55.53352229297161, 35.18096700310707, 27.86069020628929, 34.97173123061657, 46.512779742479324, 53.478079587221146, 46.96074530482292, 22.941650860011578, 6.605454403907061, 0.9338768979068846, 0.5127650289796293, 2.4220090359449387, 5.237918235361576, 18.9524919167161, 16.818953901529312, 22.359429001808167, 22.529870755970478, 19.735464602708817, 14.457502216100693, 21.74333196133375, 15.449723973870277, 11.146887112408876, 17.164286971092224, 31.821075193583965, 37.40372993052006, 44.78152044117451, 55.0741383433342, 60.473390221595764, 65.25341972708702, 65.0010372698307, 64.53727215528488, 61.88461549580097, 62.04929865896702, 61.97869844734669, 65.82686215639114, 66.8833726644516, 61.95507891476154, 65.42895510792732, 64.96805503964424, 63.75582128763199, 51.998910158872604, 49.228946194052696, 50.39668433368206, 53.26044626533985, 56.64119325578213, 62.2110939770937, 62.9536197334528, 65.11563152074814, 62.9376719892025, 57.5036595761776, 55.60458607971668, 56.985982954502106, 54.97499406337738, 56.0418476164341, 49.972114115953445, 45.727867260575294, 55.156913101673126, 55.166480988264084, 65.065778195858, 63.979226499795914, 67.95327365398407, 60.241800248622894, 59.6727579832077, 52.88856782019138, 50.94054535031319, 51.16497650742531, 50.556469559669495, 52.16829366981983, 57.06656523048878, 56.595143526792526, 58.32390636205673, 57.84733213484287, 63.96531164646149, 63.25910434126854, 63.06395061314106, 61.96457840502262, 58.39311204850674, 57.128501906991005, 58.416237607598305, 57.1475350856781, 52.010237351059914, 43.200064301490784, 39.193027317523956, 37.438216879963875, 34.90945637226105, 21.25718604773283, 29.48485605418682, 18.164332509040833, 13.835415747016668, 25.68895474076271, 23.82767591625452, 18.380320519208908, 22.54983488470316, 24.490704238414764, 9.92231922224164, 9.566249828785658, 7.487116819247603, 2.398788956925273, 0.5812084407079965, 0.17650906374910846, 1.4632878242991865, 7.500215666368604, 22.588290721178055, 43.54095920920372, 65.23125931620598, 52.24691145122051, 35.626812279224396, 34.24026668071747, 56.15724362432957, 54.829100891947746, 60.72771057486534, 47.45618551969528, 21.67732760310173, 4.748072745278478, 0.10869148289202712, 0.1615676865912974, 0.14537907089106739, 0.24319726653629914, 0.10055511011159979, 0.1379085233202204, 0.10867420569411479, 0.1285752741387114, 0.10105818233569153, 0.10673001626855694, 0.15535025537246838, 0.13277856109198183, 0.21526714728679508, 0.1635971339419484, 0.11248358292505145, 0.21250316669465974, 0.197690834174864, 0.13942366233095527, 0.18775206670397893, 0.18220282072434202, 0.1592946663731709, 0.20802155951969326, 0.11175129839102738, 0.20250891626346856, 0.12252279266249388, 0.09469810291193426, 0.2285056814434938, 0.24624375306302682, 0.15301127306884155], [0.046910720484447666, 0.030001277154951822, 0.009565095188008854, 0.02018715338635957, 0.07466836832463741, 0.044542686810018495, 0.022595092341362033, 0.028014312192681246, 0.07961885698023252, 0.06758548901416361, 0.05155572260264307, 0.03858733020024374, 0.017316635639872402, 0.0006588373094018607, 0.07929997838800773, 0.05506192879693117, 0.009591355155862402, 0.0935808070062194, 0.06834451312897727, 0.0553346532251453, 0.038297502978821285, 0.05753843106504064, 0.04149476793827489, 0.05161352106370032, 0.03611865759012289, 0.018596665977383964, 0.01563355417601997, 0.26360411604400724, 8.212859351187944, 30.81760223954916, 49.82250854372978, 55.97150579094887, 51.36850118637085, 42.166816145181656, 33.87724556028843, 30.1143853738904, 38.19696396589279, 44.831677749753, 35.2994180470705, 22.01620861887932, 10.572569780051708, 2.342360084876418, 0.15762069291668013, 0.8174335118383169, 4.949517985805869, 3.5214042803272605, 6.366550773382187, 7.401603357866406, 8.141710069030523, 13.260028772056103, 6.58451515249908, 15.925729181617498, 17.07825008779764, 10.140134934335947, 12.340043988078833, 23.296954594552517, 34.46861542761326, 39.2871368676424, 52.003222927451134, 55.40823921561241, 63.02438333630562, 57.59352095425129, 59.114643931388855, 57.09141209721565, 57.584272250533104, 56.11015275120735, 61.86377741396427, 60.154461935162544, 61.31408751010895, 57.478121146559715, 58.53883422911167, 60.42279213666916, 57.157057374715805, 47.84257158637047, 45.34673631191254, 46.81673303246498, 49.082695841789246, 51.771059185266495, 54.54600848257542, 58.853692933917046, 59.58533227443695, 60.01554898917675, 56.10042527318001, 56.05767376720905, 57.50538848340511, 53.21465492248535, 53.580354899168015, 39.01953622698784, 27.185114957392216, 35.42617164552212, 47.77023106813431, 59.298341274261475, 60.50253085792065, 57.828469946980476, 56.23473286628723, 52.277579605579376, 47.28197626769543, 45.3473898768425, 47.142447754740715, 50.380463004112244, 52.742104679346085, 54.79308642446995, 58.97120542824268, 56.103278920054436, 56.617455929517746, 53.691343143582344, 56.094930768013, 56.991504058241844, 59.66134339570999, 60.75472332537174, 56.28462418913841, 48.87920916080475, 47.52446785569191, 42.31706388294697, 41.94567561149597, 30.218953862786293, 25.65106127411127, 17.889704145491123, 15.004961639642715, 11.978024113923311, 7.27486970834434, 5.257818242534995, 8.966621104627848, 11.833085641264915, 12.742964867502451, 17.01517917215824, 13.476516455411911, 7.998794987797737, 11.607512645423412, 2.5152657693251967, 1.2677724030800164, 0.5796695232857019, 0.12900327070383355, 0.2718849404482171, 3.346684668213129, 9.87590091302991, 22.888248525559902, 30.124680921435356, 32.46571630239487, 23.394039385020733, 28.63218940794468, 34.79644663631916, 40.50456874072552, 49.79360729455948, 40.7582051306963, 24.22817252576351, 4.716048063710332, 0.1858243826427497, 0.06276722138863988, 0.09600624209269881, 0.009987715820898302, 0.06262693321332335, 0.03837989250314422, 0.025204863923136145, 0.027816886067739688, 0.03395077001187019, 0.04851507306739222, 0.04602829947543796, 0.04451421802514233, 0.06055217032553628, 0.03338822949444875, 0.08853498206008226, 0.11307509688776918, 0.05765893729403615, 0.01738184815621935, 0.011879941921506543, 0.05698709697753657, 0.026555166368780192, 0.0834240484982729, 0.007135141349863261, 0.07417898130370304, 0.044563081028172746, 0.06029412557836622, 0.01704810249066213, 0.03682836228108499, 0.006850749432487646, 0.06656413796008565, 0.03805808984907344, 0.011522364966367604, 0.007236007104438613, 0.0416228218091419, 0.014633219816460041, 0.012209593714942457, 0.02976789211970754, 0.02121394623827655, 0.05111142476380337, 0.0426516240258934, 0.08482143093715422, 0.05882908153580502, 0.02363919949857518, 0.009146962693193927, 0.09559202720993198, 0.035408299809205346, 0.02587023271189537, 0.018309788792976178, 0.08930105657782406, 0.03606970181863289, 0.052093226768192835, 0.02606979807751486, 0.03658058514702134, 0.06518165042507462, 0.10558564681559801, 0.027999612102576066, 0.4390603245701641, 9.899635389447212, 34.69170145690441, 56.104958429932594, 61.78570680320263, 55.874629989266396, 47.63970427215099, 31.95118971168995, 26.390476897358894, 31.60726446658373, 36.69271968305111, 38.78237195312977, 25.11589229106903, 12.17174056917429, 2.611441696062684, 0.26266826782375574, 1.4709008345380425, 3.7785381451249123, 6.853131288662553, 7.770968237891793, 12.41228761151433, 10.046659000217915, 17.061111107468605, 9.379864130169153, 15.731432307511568, 17.556441128253937, 7.182667655870318, 9.02299202978611, 21.040724962949753, 30.734540596604347, 39.506122916936874, 49.79282073676586, 54.81949880719185, 65.22678315639496, 59.05174970626831, 62.47187778353691, 59.944583997130394, 58.52118417620659, 58.26374039053917, 61.55294269323349, 61.672339886426926, 61.72263018786907, 58.84221754968166, 58.384003937244415, 63.68433192372322, 58.99278827011585, 50.246417596936226, 46.119170263409615, 49.54010009765625, 49.60690051317215, 54.523179307579994, 56.76798865199089, 60.7029777020216, 62.71022379398346, 61.727444529533386, 56.424445286393166, 55.83173789083958, 56.77038632333279, 52.89400152862072, 54.501440674066544, 40.66975347697735, 33.10238353908062, 40.98761782050133, 51.17875076830387, 61.34077347815037, 61.783354729413986, 60.766628086566925, 58.256163597106934, 54.48297366499901, 49.37996909022331, 47.21406631171703, 49.27781157195568, 51.32904410362244, 53.44771921634674, 56.127856001257896, 59.891839027404785, 57.77442164719105, 58.52457359433174, 55.67732937633991, 57.46539942920208, 59.41307611763477, 61.67181931436062, 61.15688234567642, 57.01847121119499, 52.91479401290417, 53.021648079156876, 49.708092883229256, 44.99767184257507, 32.24650986492634, 27.21304725855589, 17.409007139503956, 16.39813408255577, 12.021399736404419, 9.660759307444096, 7.591322902590036, 5.742871714755893, 10.132701583206654, 9.474729839712381, 12.032246254384518, 11.068920996040106, 11.362503692507744, 8.99135397747159, 3.9724464900791645, 2.5389555981382728, 0.5220676423050463, 0.2376836584880948, 0.33883871336001903, 3.677261467091739, 10.252132024616003, 26.148579977452755, 35.70609502494335, 35.250248685479164, 28.39053377509117, 34.29343342781067, 41.5599051117897, 46.27257563173771, 56.66559934616089, 47.49931700527668, 27.97239851206541, 5.926513485610485, 0.22675136307952926, 0.05632848173263483, 0.1404971195734106, 0.04000199354777578, 0.026865092804655433, 0.031583478485117666, 0.01666292784648249, 0.07418704844894819, 0.0382770493888529, 0.03944046235119458, 0.043101265328004956, 0.02256009822303895, 0.0074512461651465856, 0.03597386457840912, 0.05731421340897214, 0.10035709768999368, 0.010047684136225143, 0.021809708996443078, 0.02443794521241216, 0.08870123798260465, 0.09237941092578694, 0.049323724597343244, 0.07839135214453563, 0.014214854472811567, 0.03364188443811145, 0.10865960764931515, 0.05076357272628229, 0.004115292358619627, 0.038801369300927036, 0.20912495499942452, 0.28528717753943056, 0.10041732297395356, 0.10410256116301753, 0.16957845829892904, 0.11459057728643529, 0.14182635059114546, 0.10010145750129595, 0.21849407959962264, 0.14310737169580534, 0.15187145298114046, 0.1714982310659252, 0.15746702381875366, 0.12709448172245175, 0.1107685241731815, 0.15880306775216013, 0.13276158075314015, 0.26022879872471094, 0.13358638883801177, 0.16713038028683513, 0.15893362637143582, 0.20404796727234498, 0.15554656827589497, 0.20342545380117372, 0.2761205256683752, 0.2158639082335867, 0.10635480866767466, 0.683979329187423, 12.573782745748758, 41.28366373479366, 63.96334335207939, 71.0696992278099, 65.17788738012314, 55.6915558129549, 44.01526875793934, 43.15144971013069, 50.89451842010021, 59.164079278707504, 46.59545570611954, 29.721079878509045, 14.464850071817636, 2.9250322189182043, 0.48279651207849383, 2.3223881190642715, 9.628410693258047, 7.826365465298295, 13.976131696254015, 13.753374349325895, 18.986583687365055, 27.855231799185276, 19.22833241522312, 29.485448822379112, 26.557890214025974, 16.856324896216393, 18.709954731166363, 27.453714944422245, 38.40777285397053, 41.268145367503166, 54.35411497950554, 57.5539992749691, 66.55213683843613, 60.27466468513012, 63.55407491326332, 62.54688575863838, 63.33611100912094, 60.79674907028675, 64.99565675854683, 62.416776940226555, 63.077512085437775, 58.99112015962601, 59.520036578178406, 65.8259730041027, 60.348312333226204, 52.732388600707054, 49.39166106283665, 51.01975969970226, 51.827740743756294, 56.124124601483345, 58.64151231944561, 63.466105833649635, 64.60627645254135, 64.7566419839859, 56.449493542313576, 55.63901983201504, 57.13683865964413, 51.95178508758545, 55.32451070845127, 43.08116488158703, 38.08320187032223, 47.267799228429794, 54.887788742780685, 62.00413428246975, 63.90885427594185, 63.1251235306263, 61.523327082395554, 56.660484820604324, 51.848468631505966, 50.48567935824394, 51.65067404508591, 53.319206312298775, 57.15330317616463, 57.640646025538445, 63.04068066179752, 56.592707857489586, 60.23136980831623, 58.22454169392586, 59.071854427456856, 62.12034344673157, 64.14356008172035, 63.105569779872894, 60.42887181043625, 54.89662706851959, 57.89030782878399, 54.963446483016014, 53.736458122730255, 40.98996989428997, 34.692108035087585, 23.300539702177048, 19.935197085142136, 18.73692188411951, 12.244088687002659, 10.116562899202108, 17.458467185497284, 18.635283038020134, 22.657887786626816, 29.48708463460207, 21.618255972862244, 17.13655035942793, 21.742666997015476, 8.408678993582726, 2.409248133189976, 1.4128333004191518, 0.4175872908672318, 0.6577403715346009, 4.725842513144016, 11.91161697730422, 30.222968347370625, 41.77054300904274, 44.489300921559334, 36.870728731155396, 40.80936178565025, 49.57134962081909, 53.92261013388634, 65.23773416876793, 56.67883023619652, 34.19545188546181, 8.491304609924555, 0.37406694958917797, 0.20921166753396392, 0.19985253224149346, 0.08707553381100297, 0.16782318998593837, 0.08634336059913039, 0.14376743783941492, 0.09075677924556658, 0.23580911220051348, 0.1252417397336103, 0.1377490654704161, 0.1639513610280119, 0.1110093436727766, 0.27373535209335387, 0.09867874556221068, 0.17478509922511876, 0.1508002815535292, 0.16359187953639776, 0.13462443079333752, 0.12860363902291283, 0.21746963378973305, 0.2260035602375865, 0.1105097372783348, 0.20896002009976655, 0.07914241301477887, 0.18212473194580525, 0.12976208701729774, 0.1805446104845032, 0.15202568611130118], [0.05458619358250871, 0.04268008910003118, 0.03882116980093997, 0.05084781761979684, 0.027196159317099955, 0.05059879367763642, 0.02203399159043329, 0.04896980550256558, 0.02528251668991288, 0.05402982402301859, 0.02775454009679379, 0.05888434185180813, 0.04865621100179851, 0.013431935985863674, 0.060126311145722866, 0.0408208273438504, 0.03859740485495422, 0.022779788778279908, 0.0667605918715708, 0.037048642843728885, 0.011680614043143578, 0.0517202901392011, 0.02679455908946693, 0.009784331177797867, 0.031198578435578384, 0.019944654777646065, 0.04251324317010585, 0.5378574575297534, 10.969436634331942, 27.00809955596924, 50.62695577740669, 54.52976815402508, 44.03903268277645, 31.767606362700462, 31.83123204857111, 24.339337460696697, 28.766345009207726, 36.72338403761387, 28.009549118578434, 19.182552471756935, 5.1667119562625885, 0.8434791548643261, 0.42804970289580524, 1.4189425413496792, 3.859453140757978, 6.073258286342025, 5.422293841838837, 13.131092190742493, 7.683094153180718, 11.505074892193079, 7.614548206329346, 10.115092378109694, 18.444212190806866, 8.875439297407866, 16.33646909147501, 39.19011287391186, 47.09223724901676, 49.95966978371143, 59.66937616467476, 59.114567935466766, 61.71204395592213, 59.87095534801483, 59.51331093907356, 58.54874409735203, 58.96892935037613, 58.686270117759705, 62.64468111097813, 61.169284880161285, 58.50505404174328, 56.665014177560806, 58.85761812329292, 60.134053230285645, 53.606896474957466, 42.58955866098404, 42.62043200433254, 47.40806870162487, 54.18502405285835, 55.206090062856674, 57.19045378267765, 58.12952399253845, 60.79612970352173, 57.58233815431595, 55.709566846489906, 54.0511230379343, 55.33773019909859, 53.33540104329586, 48.93880516290665, 30.735781230032444, 30.959309935569763, 37.846045196056366, 48.80686104297638, 60.80869562923908, 58.54644142091274, 54.6127936989069, 53.64979237318039, 47.212010622024536, 42.863094583153725, 43.78426395356655, 42.888640612363815, 46.964495703577995, 49.46136832237244, 55.11896073818207, 54.23782221972942, 57.071159183979034, 55.28355270624161, 55.382662788033485, 53.67978036403656, 58.26392278075218, 58.67010198533535, 59.68051336705685, 59.33687120676041, 61.58705726265907, 54.39555175602436, 48.19406792521477, 40.948350727558136, 44.4961329549551, 40.94723738729954, 35.36718741059303, 23.954856991767883, 19.980011880397797, 15.046963635832071, 12.295574974268675, 6.562126753851771, 6.838814606890082, 6.052308585494757, 6.53381067328155, 7.8151066694408655, 4.888316569849849, 7.519291592761874, 4.336746716871858, 2.6853308686986566, 0.9202852647285908, 0.29043976042885333, 0.18183841137215495, 1.1031924281269312, 6.345842834562063, 17.06454422324896, 35.46255849301815, 40.70072181522846, 18.630755580961704, 19.160962030291557, 25.782481022179127, 36.89964517951012, 47.58241854608059, 48.65965694189072, 26.896919421851635, 9.760901033878326, 0.8952725131530315, 0.02863035970221972, 0.07383476578979753, 0.022367527599271853, 0.06475775051512755, 0.010516280817682855, 0.01589133360539563, 0.05019926589739043, 0.02187606442021206, 0.02129074182448676, 0.06984201128943823, 0.012241707372595556, 0.024859911827661563, 0.0531679382402217, 0.045674688371946104, 0.05050200648838654, 0.0440758351032855, 0.033161414321511984, 0.05357797483156901, 0.022196636964508798, 0.07110874605132267, 0.053110436638235115, 0.059163207552046515, 0.07327234401600435, 0.09398136637173593, 0.06661945022642612, 0.06474951267591678, 0.10725346044637263, 0.01343654472293565, 0.04217393696308136, 0.029990011353220325, 0.05252199145616032, 0.04298980216844939, 0.03907386737409979, 0.08311385303386487, 0.056468231850885786, 0.03640441413153894, 0.06474433990661055, 0.07279186276718974, 0.033536903938511387, 0.022053465545468498, 0.004004782858828548, 0.08465528633678332, 0.03571032051695511, 0.0016986964828902273, 0.04095359756320249, 0.008603359001426725, 0.031209031585603952, 0.03826818814559374, 0.027282708579150494, 0.02917460813478101, 0.03274000060628168, 0.021156773036636878, 0.0053626426870323485, 0.06976086486247368, 0.057307671377202496, 0.6003848242107779, 13.656535595655441, 34.186522364616394, 59.95674714446068, 61.926242262125015, 49.912267327308655, 36.62947587668896, 36.41580194234848, 29.024138376116753, 30.59188675135374, 36.49024374783039, 27.873178236186504, 17.676053009927273, 6.599376630038023, 0.97359913517721, 0.382223479100503, 0.6672817782964557, 3.7825614167377353, 10.349969174712896, 8.80230462178588, 15.919421520084143, 12.201644964516163, 12.62272696942091, 9.221093449741602, 14.024296961724758, 15.832360591739416, 7.901522582396865, 15.225633848458529, 29.557090178132057, 43.34862492978573, 49.560573399066925, 59.788499772548676, 59.800890907645226, 62.35465407371521, 60.62402933835983, 61.93101480603218, 59.801593869924545, 60.5752095580101, 59.7855207324028, 62.779155895113945, 60.844755694270134, 60.878475084900856, 57.20179617404938, 61.33896477520466, 61.016156896948814, 55.54636560380459, 44.8016631603241, 44.3452962487936, 48.96671086549759, 54.986043870449066, 57.59898506104946, 60.04729628562927, 61.27879500389099, 61.56759090721607, 57.901030853390694, 56.057058200240135, 53.41846078634262, 56.08594425022602, 54.003044217824936, 51.8975467979908, 36.29575118422508, 36.26562260091305, 43.26371468603611, 51.32989525794983, 61.7359484732151, 61.17912255227566, 56.90274462103844, 55.74388660490513, 48.865510895848274, 46.67925260961056, 45.6656152009964, 46.976320669054985, 48.27349126338959, 51.45284906029701, 55.90818218886852, 57.68795348703861, 58.631784841418266, 57.23339907824993, 57.04893037676811, 55.87496817111969, 59.33901809155941, 59.86702635884285, 60.526119992136955, 62.21000723540783, 60.95770463347435, 55.170922949910164, 51.014626175165176, 48.618117570877075, 51.04801878333092, 45.799463018774986, 35.91145880520344, 24.682289958000183, 19.217421300709248, 15.475507490336895, 10.711504574865103, 6.4683648850768805, 7.73050325922668, 9.959698766469955, 10.16192676499486, 12.662966810166836, 14.890036806464195, 10.542926620692015, 8.14486674964428, 4.314206326380372, 2.3277973663061857, 0.13936507719336078, 0.2579932421213016, 1.4524250384420156, 8.185526467859745, 21.162022054195404, 37.338145449757576, 42.2973695397377, 19.085308089852333, 20.004353374242783, 29.44379735738039, 43.293938264250755, 53.84919427335262, 53.80203120410442, 31.55332636088133, 11.634344905614853, 1.5011219191364944, 0.055942538965609856, 0.10817809481523, 0.055086137654143386, 0.01900558749184711, 0.01780264217813965, 0.052247185303713195, 0.052220115467207506, 0.03988077114627231, 0.059318071507732384, 0.01901194584206678, 0.004897886155958986, 0.06611011427594349, 0.011686404650390614, 0.03757892220164649, 0.0332958172657527, 0.07988469427800737, 0.039750078940414824, 0.055123764541349374, 0.1199884177185595, 0.012617086595128058, 0.016976455553958658, 0.05831702932482585, 0.10196799601544626, 0.10703264924813993, 0.027394919452490285, 0.048754827585071325, 0.02062462346657412, 0.04818839821382426, 0.22442375047830865, 0.1296326713054441, 0.19508260069414973, 0.2091230996302329, 0.12875905958935618, 0.24710339755984023, 0.12261343115824275, 0.14529458479955792, 0.19640712649561465, 0.148991133319214, 0.16223049868131056, 0.1607306775986217, 0.16535198665224016, 0.11829589057015255, 0.14146562229143456, 0.11470319077488966, 0.16990118863759562, 0.08542853000108153, 0.1525246468372643, 0.2834158076439053, 0.1260911871213466, 0.15267513954313472, 0.13433432526653633, 0.21489690465386957, 0.12063335889251903, 0.13720529386773705, 0.1541344542056322, 1.2093713181093335, 16.891089230775833, 40.48147737979889, 68.48585307598114, 67.62323096394539, 56.51471324265003, 43.91795597970486, 45.66675513982773, 36.02875091135502, 42.808856293559074, 50.27004472911358, 36.099620908498764, 25.46874325722456, 6.841707201674581, 1.3186919270083308, 0.8308430516626686, 2.6065361592918634, 7.6967373210936785, 12.066872846335173, 12.311852350831032, 27.639006301760674, 14.501312915235758, 22.20109909772873, 14.244738332927227, 22.252814322710037, 28.13213624060154, 16.245868653059006, 20.582646243274212, 41.456429064273834, 51.853184178471565, 53.64148981869221, 61.51605047285557, 60.46481788158417, 63.670417070388794, 63.416206911206245, 63.38798202574253, 62.46338903903961, 61.93464741110802, 62.797816693782806, 65.816959887743, 63.087554946541786, 60.299401357769966, 57.64432802796364, 62.02078878879547, 65.7884994149208, 56.84760197997093, 46.82218573987484, 46.813639998435974, 51.31836287677288, 58.63548204302788, 59.6561186760664, 61.84166640043259, 64.93949577212334, 62.85394348204136, 60.45840762555599, 56.08664721250534, 54.67645548284054, 56.10883042216301, 56.444082632660866, 55.07828392088413, 42.14693561196327, 40.369721576571465, 47.38945730030537, 54.07794579863548, 64.77570176124573, 63.26372489333153, 59.898519068956375, 58.742712289094925, 53.80945220589638, 49.72363784909248, 48.37859742343426, 48.25871005654335, 49.77787993848324, 53.327429071068764, 59.323260337114334, 57.24037930369377, 59.792375564575195, 59.24251466989517, 60.67758746445179, 57.222444266080856, 63.25079418718815, 62.02652268111706, 64.47080612182617, 63.71310397982597, 64.68753889203072, 57.50811293721199, 53.61461766064167, 50.809763967990875, 59.337357580661774, 50.606258288025856, 43.368182480335236, 30.912764333188534, 25.848468281328678, 18.132917694747448, 16.74728974699974, 12.639313079416752, 14.736989568918943, 10.831770021468401, 12.974456995725632, 14.090636651962996, 13.736790139228106, 18.429400585591793, 12.740887328982353, 7.979152891784906, 2.1780407521873713, 0.5079575150739402, 0.5809876963030547, 1.6907148831523955, 8.817181773483753, 22.532146833837032, 46.22666269540787, 54.09267760813236, 28.773944601416588, 30.532300248742104, 36.9499696791172, 51.469469368457794, 60.30115306377411, 63.770541697740555, 39.171193689107895, 15.525313317775726, 1.9775912957265973, 0.1619852930889465, 0.17481920833233744, 0.16162324376637116, 0.15318934398237616, 0.12685788504313678, 0.11690093495417386, 0.12912075268104672, 0.12458051583962515, 0.16695331869414076, 0.15428794518811628, 0.1211958697240334, 0.2114930740208365, 0.1811812841333449, 0.1177549985004589, 0.1470880737178959, 0.13522077613743022, 0.11131884893984534, 0.15394965943414718, 0.29793331457767636, 0.150239989743568, 0.21216016088146716, 0.17135159752797335, 0.16097004991024733, 0.16087208641692996, 0.11537341692019254, 0.20226489810738713, 0.18591728468891233, 0.09380664996569976], [0.02975178009364754, 0.046696651697857305, 0.04065491280925926, 0.02060283957689535, 0.020939256974088494, 0.02417948857328156, 0.0330983132153051, 0.05020826072723139, 0.04465432808501646, 0.03601718744903337, 0.04498288799368311, 0.059966715998598374, 0.04673555136832874, 0.052431657240958884, 0.029357143066590652, 0.05272225258522667, 0.06878226893604733, 0.07484734465833753, 0.048391149248345755, 0.08214963250793517, 0.07722402064246126, 0.09766364339157008, 0.022099309862824157, 0.030796920691500418, 0.0513298388250405, 0.037878994771745056, 0.05718984430131968, 1.7026843596249819, 15.009923223406076, 38.30936573445797, 51.57519489526749, 47.71155461668968, 43.68959583342075, 28.653223179280758, 20.240672193467617, 25.01884739845991, 35.470279678702354, 33.42500522732735, 30.93299064785242, 12.347928564995527, 2.960355360992253, 0.18112336692865938, 0.08411016402533278, 0.41083876392804086, 2.4142396403476596, 9.638712890446186, 8.817872386425734, 12.752611599862576, 12.061719372868538, 15.423913858830929, 5.385345099493861, 14.384062606841326, 13.69646955281496, 9.868150278925896, 16.77926693111658, 27.884780913591385, 37.10160054266453, 54.833045080304146, 58.7324870377779, 62.21945732831955, 62.607481107115746, 59.90101173520088, 57.069392278790474, 56.65638484060764, 55.94223976135254, 61.17234751582146, 60.69828115403652, 58.46130318939686, 57.529057413339615, 60.20151861011982, 58.13578985631466, 57.03174389898777, 46.62441775202751, 39.995080679655075, 44.81721952557564, 52.51130126416683, 57.53725737333298, 57.84349054098129, 59.55976344645023, 64.27493423223495, 58.10710899531841, 56.995467245578766, 58.478390872478485, 56.936365216970444, 52.57671855390072, 49.70129504799843, 37.9315710067749, 34.93257813155651, 32.69748866558075, 33.93991939723492, 60.06419777870178, 57.43738353252411, 58.261525109410286, 52.395795062184334, 46.91633328795433, 45.054235607385635, 49.29433308541775, 46.86155162751675, 48.36313985288143, 47.620120123028755, 49.36678759753704, 48.089945912361145, 48.077057003974915, 47.09142409265041, 47.240676283836365, 48.26494552195072, 49.11658242344856, 50.57411201298237, 54.334302842617035, 57.47175648808479, 60.89736387133598, 57.39032305777073, 57.17669852077961, 55.33356562256813, 51.90002426505089, 46.81412637233734, 42.51287877559662, 40.7277649641037, 41.994753777980804, 27.535136975347996, 22.223099917173386, 13.749593552201986, 7.6798624265939, 7.725748289376497, 6.746026435866952, 8.807671833783388, 13.390736058354378, 23.060500882565975, 5.683783460408449, 3.8132440578192472, 3.1953874742612243, 2.0008493727073073, 0.06209625680639874, 0.4130318103125319, 0.3506907820701599, 3.3718692418187857, 10.1649191044271, 26.481736600399017, 22.635368295013905, 28.60990170389414, 30.40240801870823, 22.415115013718605, 28.14164523035288, 44.139829874038696, 46.76999174058437, 37.897213250398636, 16.875920444726944, 0.912568710045889, 0.05544229061342776, 0.026953731212415732, 0.10775897433632053, 0.01299650031796773, 0.02500578837498324, 0.04032305034343153, 0.05371463019400835, 0.03871401851938572, 0.06323683759546839, 0.02817260301526403, 0.04694288145401515, 0.020773166179424152, 0.07910102343885228, 0.010060504737339215, 0.03688297321787104, 0.052496517237159424, 0.03230570691812318, 0.12719087186269462, 0.012450726771930931, 0.010655218284227885, 0.03375819382199552, 0.05787916961708106, 0.03230542119126767, 0.04332797288952861, 0.08420999030931853, 0.038091041205916554, 0.058443851230549626, 0.02582839413662441, 0.025704494437377434, 0.021743023316957988, 0.04978983044566121, 0.08165117644239217, 0.08547671022824943, 0.01061576478605275, 0.029954939309391193, 0.03656519671494607, 0.019094873423455283, 0.01447869075491326, 0.04348859591118526, 0.08470257598673925, 0.053394842470879667, 0.06831070830230601, 0.037633262254530564, 0.10724819119786844, 0.06101030179706868, 0.025044354079000186, 0.02357174569624476, 0.07052742919768207, 0.017922580664162524, 0.027857197674165946, 0.04671760252676904, 0.020948517121723853, 0.022057500973460265, 0.026108154124813154, 0.021474662717082538, 2.163241021335125, 17.513132952153683, 44.39900256693363, 58.29007297754288, 55.999441891908646, 45.69203898310661, 33.5881494730711, 27.26917214691639, 26.54999613761902, 36.94112375378609, 37.01918676495552, 28.895574174821377, 14.316709320992231, 3.528183354064822, 0.38905862951651216, 0.4643235955154523, 2.3707588110119104, 5.2564916387200356, 11.784690488129854, 12.559811845421791, 14.069208651781082, 11.82281669229269, 9.927582889795303, 10.452088695019484, 7.5083220563828945, 11.813630685210228, 11.736775059252977, 18.26288592070341, 28.30333225429058, 41.63360595703125, 56.322914734482765, 62.59070120751858, 62.96682022511959, 65.58410078287125, 60.53256444633007, 61.5434318035841, 57.19748340547085, 60.29286950826645, 62.47737228870392, 63.89467343688011, 58.382100239396095, 59.72449600696564, 59.74509470164776, 60.61262995004654, 58.255848214030266, 49.13382589817047, 41.561637818813324, 47.06778936088085, 54.098229110240936, 59.987460896372795, 59.55582685768604, 61.61039561033249, 64.39101800322533, 61.39566533267498, 58.53251896798611, 58.68588633835316, 57.22156271338463, 52.644510716199875, 51.828443706035614, 44.06503848731518, 39.33757156133652, 37.187016159296036, 36.00101999938488, 60.185411274433136, 60.62886267900467, 60.78224904835224, 55.43530896306038, 49.76946339011192, 47.21215881407261, 50.19929252564907, 48.28850045800209, 50.498184487223625, 49.994760900735855, 51.30630612373352, 49.84952889382839, 49.469727873802185, 49.89499345421791, 50.88273145258427, 51.587266847491264, 51.64395220577717, 53.57729226350784, 58.04582588374615, 58.66136245429516, 60.9993351995945, 58.409960344433784, 56.9206378608942, 53.592434450984, 51.23545132577419, 48.211524188518524, 47.635786682367325, 46.449342146515846, 42.93464854359627, 31.241898871958256, 26.32940087467432, 15.451765414327383, 9.942207355052233, 8.445379324257374, 12.51825062558055, 14.413134846836329, 14.646894503384829, 11.950827073305845, 8.874834179878235, 10.450442433357239, 6.398788718506694, 2.951520597562194, 0.9885331650730222, 0.21872600074857473, 0.5737465317361057, 4.334093984216452, 11.72402959316969, 28.1161106005311, 29.097628332674503, 29.195968955755234, 33.46731975674629, 29.69677448272705, 34.732583463191986, 50.51884777843952, 52.65065498650074, 44.70102556049824, 21.324451938271523, 1.6579801146872342, 0.09685172641184181, 0.03629492508480325, 0.006240776865524822, 0.01415078393620206, 0.03725005801243242, 0.030737350352865178, 0.011997825586149702, 0.009875845407805173, 0.04498766742472071, 0.03938392554118764, 0.028387733073031995, 0.017793825463741086, 0.07473893914720975, 0.006687688919555512, 0.026932264590868726, 0.04785785677086096, 0.01928869642142672, 0.061597385138156824, 0.0706440354406368, 0.027981000894214958, 0.032443141535623, 0.05351838408387266, 0.021248424563964363, 0.06376642675604671, 0.024553952171118, 0.01976958770683268, 0.016650504294375423, 0.08288624376291409, 0.15988703380571678, 0.15825935552129522, 0.10878429588046856, 0.18151863478124142, 0.1338320248760283, 0.20670916041126475, 0.08541541625163518, 0.1729150503524579, 0.1415182405617088, 0.15457883739145473, 0.17774365609511733, 0.23555641091661528, 0.16430643416242674, 0.1673782872967422, 0.16638352739391848, 0.20057836751220748, 0.1558124352595769, 0.13370252010645345, 0.115933827473782, 0.21086110558826476, 0.17751330829923972, 0.20076944085303694, 0.12491792585933581, 0.07664245888008736, 0.08478902876959182, 0.1252397062489763, 0.10412520408863202, 2.643891954794526, 22.586936093866825, 54.09872688353062, 67.25382998585701, 62.43205212056637, 56.901946663856506, 40.68243719637394, 30.784903094172478, 36.567698791623116, 49.64100368320942, 43.93966801464558, 38.215704560279846, 15.580722894519567, 4.588962458074093, 0.45844765612855554, 0.5139064521063119, 2.756228889338672, 8.006974048912525, 18.84469360113144, 19.33471340686083, 25.747456401586533, 23.843002393841743, 24.437436796724796, 15.738514177501202, 23.18272702395916, 20.326222702860832, 14.591092597693205, 19.25055932253599, 35.314032062888145, 45.426528230309486, 62.65827298164368, 65.28037548065186, 64.53533425927162, 65.43053582310677, 64.03895929455757, 62.080141603946686, 60.024600103497505, 61.06609381735325, 64.9743703007698, 64.45014283061028, 59.45162124931812, 58.98957744240761, 61.71874299645424, 62.68945790827274, 60.82453317940235, 50.357345044612885, 43.12966167926788, 48.207940980792046, 57.44133532047272, 61.50991380214691, 62.87405960261822, 65.04310861229897, 68.67227107286453, 63.72534692287445, 57.726183235645294, 59.56463858485222, 55.69456145167351, 53.26217137277126, 53.86591337621212, 51.60370096564293, 41.65469482541084, 43.922268748283386, 42.10677556693554, 61.752295196056366, 63.46572205424309, 63.11382293701172, 58.65394525229931, 52.37102799117565, 51.693968921899796, 54.82497811317444, 51.94572441279888, 53.596682623028755, 52.27456636726856, 53.66800479590893, 51.657327488064766, 51.54375158250332, 50.363021939992905, 50.98199352622032, 52.24945351481438, 52.17947646975517, 55.127723067998886, 60.1688289642334, 62.13860526680946, 66.35931998491287, 60.3841558098793, 58.82713995873928, 56.095192953944206, 53.488589823246, 52.80395396053791, 51.33033603429794, 46.6939540207386, 45.28898701071739, 30.588862113654613, 25.317986346781254, 17.841933108866215, 13.179708682000637, 13.468973860144615, 17.229272983968258, 17.26478587836027, 22.864121720194817, 33.11210721731186, 17.163747400045395, 13.160074185580015, 9.110016860067844, 6.108131390064955, 1.5910495561547577, 0.729648603592068, 0.9085537504870445, 4.434885000810027, 14.390148930251598, 34.497064501047134, 35.408829376101494, 42.14466713368893, 42.25307151675224, 34.568075090646744, 40.232054963707924, 58.92498090863228, 59.46508392691612, 52.20116950571537, 26.330366022884846, 2.692031334154308, 0.2215724636334926, 0.2089230908313766, 0.1933479937724769, 0.13324871164513752, 0.15095812152139843, 0.1031438770587556, 0.14706570538692176, 0.12480759818572551, 0.14610863174311817, 0.23194563982542604, 0.12363406975055113, 0.04598948515194934, 0.16278308699838817, 0.09581172518664971, 0.08471412380458787, 0.09375661436934024, 0.08188975465600379, 0.2792021899949759, 0.22869570093462244, 0.14840611314866692, 0.1445607640198432, 0.28752974001690745, 0.10404022817965597, 0.23675238189753145, 0.1456426817458123, 0.20507397159235552, 0.13981421012431383, 0.14285327517427504], [0.10524785830057226, 0.04454502086446155, 0.12385994239593856, 0.09019771197927184, 0.04267146905476693, 0.13951410044683143, 0.18917145382147282, 0.031042415721458383, 0.046247537320596166, 0.042681963022914715, 0.04513781132118311, 0.1561111051705666, 0.0623747959616594, 0.05946701312495861, 0.07962579606100917, 0.09923623947543092, 0.021622639542329125, 0.042452275738469325, 0.08374496799660847, 0.04456307731743436, 0.05596969785983674, 0.027826923615066335, 0.04311026757932268, 0.01245137336809421, 0.025125463398580905, 0.023628887356608175, 0.03210888935427647, 3.0521904956549406, 17.092759609222412, 37.87322513759136, 47.92163394391537, 44.265945106744766, 34.41324859857559, 23.14268097281456, 25.032253079116344, 37.89763122797012, 38.50451946258545, 29.090870395302773, 14.221947155892849, 5.613240245729685, 0.365386315388605, 0.06637107566348277, 0.12410674360580742, 1.669829897582531, 4.168169712647796, 13.171660713851452, 8.02224162966013, 11.130484342575073, 13.066937383264303, 4.936978658661246, 7.836359404027462, 6.227983133867383, 11.359735541045666, 9.937123227864504, 20.14060266315937, 22.589962631464005, 31.523055285215378, 36.08341097831726, 51.19902268052101, 54.31781932711601, 60.81981383264065, 63.434863910079, 58.24251852929592, 53.514857813715935, 57.13826358318329, 58.8005755841732, 58.33258129656315, 55.92000335454941, 57.598517686128616, 60.04323050379753, 57.15132348239422, 53.19935694336891, 41.52892157435417, 41.58544734120369, 50.221198350191116, 59.564832374453545, 56.766662523150444, 59.02410238981247, 62.81163275241852, 62.07135267555714, 54.48903813958168, 48.037105947732925, 53.12308743596077, 55.00557862222195, 48.41495007276535, 41.09650477766991, 48.099491000175476, 49.430521577596664, 31.072171479463577, 45.162556394934654, 65.73194324970245, 54.261061772704124, 57.63091094791889, 44.43465605378151, 50.156214237213135, 50.08042350411415, 56.38669811189175, 56.29569299519062, 56.6286501288414, 54.96159978210926, 56.04514963924885, 51.550386026501656, 50.60881555080414, 44.008318930864334, 41.13424055278301, 41.08357027173042, 43.14530923962593, 47.17445343732834, 52.136671766638756, 54.49959397315979, 57.412958443164825, 53.032865077257156, 53.648846223950386, 52.51388892531395, 50.17163001000881, 49.05416317284107, 51.8490955978632, 48.66681955754757, 44.77281130850315, 38.758083656430244, 40.29788263142109, 20.590192638337612, 12.706499174237251, 5.251868236809969, 10.45649265870452, 15.795412324368954, 14.789944477379322, 10.461923517286777, 6.602085409685969, 10.466541219502687, 4.326431220397353, 3.7422738410532475, 0.31616966414730996, 0.12656105565838516, 0.31587292382027954, 1.7595909372903407, 7.877250434830785, 19.67350322753191, 31.914354488253593, 30.275713317096233, 16.70309241861105, 12.720597367733717, 18.13333187252283, 34.23946112394333, 47.840382903814316, 39.453309550881386, 21.933538354933262, 2.540096011944115, 0.17313580960035324, 0.10437100339913741, 0.08006090982235037, 0.06099860183894634, 0.024125951895257458, 0.07439690554747358, 0.040831154328770936, 0.053989584775990807, 0.02731066899286816, 0.04699325101682916, 0.0028576732574947528, 0.11589479792746715, 0.02639571037434507, 0.009665235029387986, 0.011760929264710285, 0.055366591550409794, 0.04373668103653472, 0.08742316320422105, 0.11185013019712642, 0.09565778891555965, 0.07515023738960735, 0.11015758820576593, 0.02980548746563727, 0.03127194715489168, 0.08504989367793314, 0.049063616679632105, 0.005707762229576474, 0.03217438017600216, 0.1109097697190009, 0.04868401556450408, 0.02623528773256112, 0.029540023097069934, 0.09497616338194348, 0.130597774987109, 0.10326996794901788, 0.06676841410808265, 0.027946572663495317, 0.030131815365166403, 0.031108646835491527, 0.0858301432162989, 0.07812269468558952, 0.019378307042643428, 0.05283871039864607, 0.035383957365411334, 0.059904275403823704, 0.06610370954149403, 0.07604843645822257, 0.03419193089939654, 0.03401769688935019, 0.07439387758495286, 0.06522899944684468, 0.017424363941245247, 0.04991709763999097, 0.031245552672771737, 0.020420746222953312, 3.477453226223588, 21.88558492809534, 43.755548894405365, 53.13347987830639, 48.431110605597496, 42.89864927530289, 27.1650368347764, 26.130511946976185, 39.05607886612415, 38.20307023823261, 31.52323577553034, 17.412734739482403, 6.162531645968556, 0.9988214098848403, 0.188599836837966, 0.565869138808921, 1.8277375493198633, 5.102826459333301, 9.167984649538994, 11.50225069373846, 8.7453618273139, 10.61972999945283, 14.163106363266706, 10.76444523409009, 5.445804605260491, 7.5289179012179375, 10.415099579840899, 19.120186418294907, 23.778673745691776, 31.28913603723049, 40.891520977020264, 52.87652626633644, 56.65834553539753, 60.56461952626705, 63.27496089041233, 59.464160576462746, 57.4485207349062, 58.03921803832054, 59.547227919101715, 59.070163518190384, 55.82766830921173, 56.72891914844513, 61.08035445213318, 58.56992416083813, 54.847621098160744, 43.1908193975687, 43.15078854560852, 51.5192960947752, 59.67943802475929, 58.37830804288387, 62.08090916275978, 64.28352177143097, 63.298683017492294, 54.98320162296295, 49.14246283471584, 54.13368500769138, 56.230526491999626, 49.62184891104698, 43.66367742419243, 51.6926883906126, 57.018209025263786, 35.06528601050377, 45.14052137732506, 66.85316428542137, 56.95694871246815, 58.96074838936329, 47.25279003381729, 50.74141703546047, 52.66192898154259, 58.20591889321804, 58.035011664032936, 59.07516784965992, 56.93777494132519, 58.09358932077885, 53.42451386153698, 52.98186041414738, 46.652091667056084, 43.32729287445545, 42.4356859177351, 46.61482706665993, 49.300454556941986, 54.4658175855875, 56.04241378605366, 59.02385540306568, 55.42986385524273, 55.58569349348545, 55.130071341991425, 51.21920719742775, 50.784613117575645, 51.89638026058674, 48.230697959661484, 45.92949204146862, 36.70845463871956, 34.61076579988003, 16.22357714921236, 11.412453912198544, 6.710788551717997, 15.016798954457045, 11.91840436309576, 14.497647061944008, 15.962905436754227, 7.949244221672416, 8.213677257299423, 8.02927790209651, 5.958932396024466, 1.011339481920004, 0.2845421800157055, 0.24387979006860405, 2.456380329094827, 8.610280975699425, 22.158195599913597, 31.376717537641525, 34.68547359108925, 23.937543220818043, 16.675948575139046, 21.866553649306297, 40.638538151979446, 56.08806073665619, 47.0496529340744, 26.448361091315746, 2.879168917424977, 0.3015617636265233, 0.06593700833036564, 0.04212403866404202, 0.06513550368254073, 0.058156083468929864, 0.041860231140162796, 0.058400149864610285, 0.0430469215643825, 0.04288762698706705, 0.041639423652668484, 0.002656562369338644, 0.09734080173075199, 0.045872897462686524, 0.019533798113116063, 0.02333806194656063, 0.044109806913184, 0.03336256973852869, 0.08633441029815003, 0.029146386114007328, 0.05670547419867944, 0.01123609819842386, 0.045129224672564305, 0.04059205290104728, 0.017033615768013988, 0.11897388700162992, 0.034920612306450494, 0.01121355267969193, 0.04672658622439485, 0.22789358772570267, 0.1258111302740872, 0.16865522658918053, 0.19256283121649176, 0.29303027142304927, 0.3388939885189757, 0.20120010914979503, 0.1768670164165087, 0.12913756974739954, 0.1033498601464089, 0.1816275969031267, 0.2219897139002569, 0.14516172552248463, 0.2539891772903502, 0.18527258100220934, 0.19530704099452123, 0.13399099290836602, 0.12979141669347882, 0.24758500687312335, 0.1370546972611919, 0.12414820739650168, 0.1958688913146034, 0.24159024964319542, 0.09181056957459077, 0.2675293054198846, 0.16614614403806627, 0.1456949140992947, 5.515416394919157, 27.616203725337982, 53.01078826189041, 60.34043535590172, 55.23019216954708, 47.65811808407307, 33.18169288337231, 38.11314046382904, 52.576809749007225, 47.835785150527954, 38.584497570991516, 19.390570409595966, 7.405262086540461, 1.0631936369463801, 0.3984648466575891, 0.9958127432037145, 2.4570690421387553, 9.283765386790037, 21.426987536251545, 18.489272072911263, 24.36068471521139, 24.28214482963085, 14.850300438702106, 14.68668406829238, 15.821700263768435, 19.68124721199274, 15.990286767482758, 25.79629898071289, 27.528515830636024, 36.63747064769268, 44.502132833004, 58.85136365890503, 61.81858643889427, 64.93871301412582, 65.80219388008118, 62.97292649745941, 57.80214495956898, 60.97792714834213, 60.637845396995544, 59.186178892850876, 55.713416039943695, 57.40218982100487, 62.68210530281067, 60.63601389527321, 55.9981157630682, 44.670950174331665, 44.83282528817654, 54.33466762304306, 61.735811680555344, 60.88414438068867, 64.78663757443428, 66.32994756102562, 63.52480888366699, 56.02651543915272, 48.39790798723698, 54.540768563747406, 54.82745558023453, 50.643131509423256, 46.346386671066284, 58.78922559320927, 54.34275358915329, 42.57693573832512, 50.72135031223297, 67.4724930524826, 60.41244529187679, 61.16930387914181, 48.69244538247585, 55.18555976450443, 56.04440487921238, 61.24620795249939, 62.00097285211086, 61.29848554730415, 59.273832589387894, 60.50745539367199, 55.646212846040726, 56.02601386606693, 49.33975964784622, 45.442304983735085, 45.27056559920311, 47.882769629359245, 51.74124218523502, 58.31672474741936, 60.027009174227715, 63.21400076150894, 58.10822993516922, 58.16290520131588, 56.74331657588482, 51.57711759209633, 51.97902962565422, 55.407220870256424, 52.570464089512825, 50.24064190685749, 41.33429601788521, 44.01105098426342, 23.63217070698738, 17.464866042137146, 13.342093918472528, 18.203495107591152, 24.747370965778828, 24.29008260369301, 17.331719286739826, 15.996837615966797, 17.723303474485874, 10.44285899028182, 9.77207813411951, 2.1310907090082765, 0.5401212454307824, 0.5588717549107969, 2.4212937243282795, 10.20322009921074, 25.608693547546864, 43.23037147521973, 44.081552401185036, 28.855938501656055, 23.92082791775465, 29.973568730056286, 47.414049580693245, 63.291995376348495, 58.263109624385834, 32.82586097717285, 5.194736402481794, 0.5121236352715641, 0.17781450151233003, 0.1613810216076672, 0.1688946582726203, 0.12747800879878923, 0.1604267829679884, 0.17558605468366295, 0.11262919229920954, 0.09453526086872444, 0.15485399606404826, 0.1101808990642894, 0.30371434811968356, 0.15996635454939678, 0.1584150581038557, 0.19413809903198853, 0.15004882734501734, 0.1214039976184722, 0.1782397521310486, 0.15060303354403004, 0.20769461378222331, 0.21747377497376874, 0.17475958418799564, 0.11264841392403468, 0.20263126672944054, 0.4061150236520916, 0.12950822798302397, 0.15397683688206598, 0.17374785878928378], [0.03678162924188655, 0.03375187443452887, 0.04199996641546022, 0.045463042697519995, 0.012963038734596921, 0.0780555971141439, 0.0554072241357062, 0.02243542483483907, 0.05905819736653939, 0.010598687040328514, 0.030686207101098262, 0.05510528135346249, 0.02642829993419582, 0.05745837188442238, 0.07723289672867395, 0.07193385099526495, 0.05934864057053346, 0.017815397841332015, 0.015715711779193953, 0.066088710736949, 0.02898797840316547, 0.049047159554902464, 0.07777836042805575, 0.031981087813619524, 0.011276049863226945, 0.031224676058627665, 0.055038755235727876, 6.179674901068211, 25.16964800655842, 47.81580202281475, 52.88975715637207, 39.25440542399883, 28.050566017627716, 17.896916158497334, 24.768988005816936, 24.354033172130585, 34.67199191451073, 29.549938961863518, 11.46156057715416, 2.837001155130565, 0.4069113777950406, 0.14170451962854713, 1.1941154929809272, 4.332257257774472, 5.314307436347008, 7.862384207546711, 13.475287221372128, 5.896194912493229, 4.7742989379912615, 10.32353114336729, 10.442537907510996, 2.38960437476635, 9.729945994913578, 19.93158917874098, 27.804837003350258, 35.04688359797001, 47.04189755022526, 57.34594523906708, 58.878353610634804, 58.94322752952576, 59.02849115431309, 57.44087174534798, 61.774315014481544, 56.297026723623276, 58.280330300331116, 59.40342843532562, 58.455288112163544, 57.42961674928665, 60.58727391064167, 58.89116272330284, 58.12421187758446, 48.41242700815201, 42.62670926749706, 46.90723657608032, 56.96103349328041, 58.71481418609619, 59.17700618505478, 60.9529434889555, 58.117642030119896, 58.21915738284588, 58.97084824740887, 54.79554869234562, 57.65117906033993, 58.40781345963478, 53.29877480864525, 41.20166413486004, 54.39092360436916, 43.12275744974613, 30.94033945351839, 59.11209426820278, 56.7494760453701, 57.103058472275734, 49.115469083189964, 47.22727820277214, 53.64549480378628, 54.123729541897774, 55.38048930466175, 55.888788029551506, 57.61194236576557, 57.428032234311104, 57.23058342933655, 57.32533894479275, 56.83195821940899, 53.760039657354355, 50.71699194610119, 45.42521730065346, 41.539412811398506, 42.626557275652885, 48.82885046303272, 48.5864120721817, 54.30697090923786, 54.097731336951256, 55.950375124812126, 54.65988077223301, 55.11435158550739, 47.810299918055534, 53.657505959272385, 49.35811646282673, 46.5562342107296, 41.59760668873787, 34.88373175263405, 24.076686054468155, 14.151397291570902, 12.116615027189255, 19.046671763062477, 9.146521501243114, 10.707142408937216, 13.037910740822554, 4.401500942185521, 6.3822116330266, 6.957326922565699, 2.616387843154371, 1.0203265934251249, 0.10760711607872508, 0.09270413764170371, 0.5541674885898829, 3.8513697870075703, 14.599695336073637, 28.24477169662714, 34.63631182909012, 33.81831452250481, 32.8750379383564, 30.51323477178812, 32.79569059610367, 45.576893761754036, 49.0467269718647, 24.90099672228098, 4.553942587226629, 0.283335447893478, 0.04465564539714251, 0.03211352777725551, 0.07808647787896916, 0.07161636764067225, 0.0471399995876709, 0.041551557078491896, 0.029943044537503738, 0.022675990148854908, 0.02966467978694709, 0.08514335233485326, 0.027733370334317442, 0.06343749206280336, 0.06938303748029284, 0.07397161039989442, 0.03960947164159734, 0.0547863359679468, 0.028134230269643012, 0.046197019328246824, 0.05253767303656787, 0.03170006617438048, 0.03357712834258564, 0.03581485572794918, 0.01920578368299175, 0.05175465157662984, 0.014618228433391778, 0.079649381514173, 0.014832417818979593, 0.05990634599584155, 0.017750823571986984, 0.01753323700540932, 0.061064326437190175, 0.033380577951902524, 0.029912492173025385, 0.030522324195771944, 0.03023927092726808, 0.004425772158356267, 0.013520100346795516, 0.011032784059352707, 0.007422966627927963, 0.007762206041661557, 0.026320480719732586, 0.02488672933395719, 0.05435066559584811, 0.034200194713776, 0.05375911823648494, 0.05718765496567357, 0.07660921066417359, 0.09302661565016024, 0.11230158605030738, 0.1079100978677161, 0.04074535463587381, 0.026156319509027526, 0.048272168132825755, 0.08671881310874596, 7.043634541332722, 29.174180924892426, 53.12690623104572, 59.319718927145004, 43.37947927415371, 32.371249571442604, 20.449396893382072, 27.51722853630781, 30.674665309488773, 37.41521291434765, 30.896586701273918, 12.781626842916012, 2.8706701984629035, 0.5379932408686727, 0.1520983868977055, 0.8202632912434638, 3.9955383259803057, 8.607564121484756, 9.45838026702404, 11.360370106995106, 13.626487758010626, 13.336901497095823, 14.081147611141205, 9.169591013342142, 4.896073853597045, 9.365046825259924, 19.691901840269566, 28.25953770428896, 39.464944526553154, 49.12208452820778, 57.60812357068062, 59.47977013885975, 61.32201388478279, 61.603677570819855, 61.118356212973595, 62.90040358901024, 56.79102301597595, 59.36073012650013, 59.851166009902954, 58.05991552770138, 57.807578667998314, 59.742450043559074, 61.114446222782135, 58.5693883895874, 51.079530492424965, 44.843920692801476, 48.77044379711151, 58.45789857208729, 61.08988434076309, 61.42632208764553, 61.344029903411865, 58.91009710729122, 59.063449278473854, 58.67474913597107, 57.38586589694023, 58.41578163206577, 59.4629180431366, 53.82218152284622, 45.537231490015984, 56.70483224093914, 49.64074149727821, 35.441621616482735, 59.82784666121006, 59.316967874765396, 59.32077147066593, 50.54765023291111, 48.833303824067116, 55.71175552904606, 57.153987139463425, 57.1218104660511, 59.09355506300926, 60.551966205239296, 59.70859006047249, 59.421481266617775, 60.10971933603287, 58.14053200185299, 56.5601360052824, 52.08622187376022, 46.66456259787083, 43.22402961552143, 46.660470217466354, 52.09857881069183, 52.031797394156456, 55.300708785653114, 56.2852967530489, 56.234812662005424, 57.89976552128792, 53.34633305668831, 50.416488870978355, 54.29043039679527, 52.45922885835171, 45.98474107682705, 42.46639586985111, 30.511097386479378, 25.294334515929222, 16.63242571055889, 8.175323065370321, 11.587908547371626, 12.545677553862333, 18.62370315939188, 12.82939787954092, 9.894607309252024, 10.591284725815058, 7.7183909341692924, 4.470530888065696, 1.475918940268457, 0.501303062774241, 0.17201627983013168, 0.6713695276994258, 4.550123792141676, 15.922104176133871, 30.271983817219734, 36.120029613375664, 31.851832643151283, 31.57637022435665, 34.05374228954315, 35.83935387432575, 51.549827456474304, 57.13223710656166, 30.39338920265436, 6.948760282248259, 0.4852604423649609, 0.04429001150128897, 0.030547809546987992, 0.02223310795670841, 0.025937530663213693, 0.030322556594910566, 0.07749527561827563, 0.008377811045647832, 0.04445453821972478, 0.09099780654651113, 0.015030677932372782, 0.0016097815091598022, 0.04444831902219448, 0.02548401906096842, 0.07704106639721431, 0.03192458811099641, 0.028015456955472473, 0.018643065050127916, 0.03816740449110512, 0.05279006632918026, 0.03490959512419067, 0.027071374606748577, 0.05350668783648871, 0.027869795630977023, 0.07733336868113838, 0.020181585423415527, 0.01932174611283699, 0.03919578739441931, 0.19295456644613296, 0.12510413071140647, 0.07008549509919249, 0.15637479024007916, 0.0851555161352735, 0.20091052312636748, 0.16988208575639874, 0.10272183251800016, 0.11329179658787325, 0.11919913624296896, 0.14184515661327168, 0.1236267744388897, 0.10126973895239644, 0.09600975987268612, 0.1952597958734259, 0.09940501127857715, 0.2006536806584336, 0.09138926718151197, 0.10945513800834306, 0.1437004515901208, 0.3079189412528649, 0.25427668530028313, 0.20776931836735457, 0.12872187799075618, 0.1379173103487119, 0.13887430977774784, 0.25255065760575235, 9.694245010614395, 35.245662331581116, 61.81964658200741, 66.9235061109066, 52.78353005647659, 39.29111525416374, 28.889321610331535, 33.905162662267685, 38.1898545473814, 46.72506295144558, 37.19430036842823, 13.658455442637205, 3.8516060868278146, 0.615147091448307, 0.3763111447915435, 1.7905627191066742, 8.244653195142746, 13.931827023625374, 17.90783677250147, 24.69898246228695, 15.908254869282246, 16.306264512240887, 19.583522155880928, 19.487651400268078, 8.193507939577103, 14.637825340032578, 27.73322604596615, 32.46330343186855, 42.505225986242294, 54.709673300385475, 60.55507443845272, 61.986191645264626, 63.496375009417534, 64.7869947552681, 63.84017676115036, 64.98081475496292, 59.71267484128475, 62.63922080397606, 60.74607118964195, 59.096104726195335, 57.28248864412308, 60.93229919672012, 62.891037091612816, 61.79471231997013, 52.114674746990204, 47.24145524203777, 50.29864959418774, 60.99764049053192, 64.75388333201408, 62.23513528704643, 61.37134663760662, 58.24606753885746, 59.94737684726715, 60.51211014389992, 59.20987822115421, 60.84322817623615, 61.34164363145828, 55.39307802915573, 49.361353889107704, 59.89946901798248, 48.94299253821373, 42.151027992367744, 60.37828132510185, 62.380298897624016, 61.6196671128273, 54.26508955657482, 51.67732201516628, 57.735865116119385, 57.86212854087353, 59.68171030282974, 61.0413533449173, 61.27426564693451, 60.715657621622086, 61.701769307255745, 61.90395645797253, 62.00313113629818, 59.32313874363899, 56.836388781666756, 49.5318241417408, 45.45016296207905, 47.817477732896805, 53.982103541493416, 53.54503199458122, 60.51140338182449, 58.43196116387844, 59.7778033465147, 60.70238873362541, 56.84008978307247, 50.70033743977547, 56.056887209415436, 52.761373445391655, 48.21164198219776, 46.29513122141361, 39.51884463429451, 28.852231800556183, 19.53671246767044, 17.008989304304123, 30.469949394464493, 21.967139951884747, 20.318607911467552, 25.003270134329796, 14.132447708398104, 14.065783135592937, 16.345753893256187, 6.685519432649016, 2.7534970734268427, 0.48243939061649144, 0.28790989774279296, 1.1698608007282019, 5.232020476832986, 18.501779101788998, 36.29064045846462, 48.56693811714649, 46.5567471832037, 45.79600900411606, 41.523856446146965, 46.07187420129776, 58.55735443532467, 67.90602698922157, 37.82198868691921, 9.950968734920025, 0.7942621177062392, 0.11043161881389096, 0.1382037199800834, 0.2235532260965556, 0.14238926960388198, 0.15647572232410312, 0.15848863462451845, 0.13458996545523405, 0.15926803811453283, 0.1690421675448306, 0.1278051474946551, 0.11030195077182725, 0.1599537380388938, 0.11514603029354475, 0.15728350554127246, 0.14702288346597925, 0.12503778270911425, 0.08850344820530154, 0.25221416784916073, 0.15159504750045016, 0.17739834962412715, 0.1797067851293832, 0.1277902748552151, 0.07674501626752317, 0.21170339867239818, 0.1487120709498413, 0.161230395315215, 0.08137703451211564], [0.04135926290473435, 0.06888875970616937, 0.012262647996976739, 0.055393720758729614, 0.06211182706465479, 0.0608874206955079, 0.035199693229515105, 0.05031001288443804, 0.07538895661127754, 0.037603943710564636, 0.05910543506615795, 0.054586000624112785, 0.03642184346972499, 0.1391349223558791, 0.010970014136546524, 0.06069315983040724, 0.07170856464654207, 0.07584961509564891, 0.05342677337466739, 0.06022916910296772, 0.01068907042281353, 0.023083503438101616, 0.024521713276044466, 0.045107683836249635, 0.0360631709190784, 0.07405965880025178, 0.8437077957205474, 5.8392316941171885, 29.207659028470516, 45.63994757831097, 40.66935829818249, 37.23726466298103, 27.37341195344925, 18.730716817080975, 23.49393032491207, 29.871728494763374, 28.76671738922596, 17.746845111250877, 6.305279536172748, 1.0099282138980925, 0.2913546800846234, 0.19105230836430565, 0.8815775136463344, 0.9870627033524215, 6.512798750773072, 6.256227493286133, 7.523805750533938, 7.68917097710073, 9.387855101376772, 18.61595157533884, 7.1584159322083, 4.226568778976798, 13.574185464531183, 26.979791074991226, 35.392691642045975, 42.60266035795212, 51.45435757935047, 56.87507450580597, 59.374025613069534, 61.12412430346012, 58.487582579255104, 60.91891631484032, 55.92750795185566, 55.07124289870262, 58.269345089793205, 60.280261784791946, 58.540141358971596, 58.94852064549923, 57.27009370923042, 58.1582048535347, 53.4126091003418, 44.038504511117935, 41.01678505539894, 52.36588306725025, 56.860167905688286, 65.79454109072685, 59.866893365979195, 54.64411921799183, 60.56369997560978, 55.999415293335915, 57.28822633624077, 55.27286387979984, 57.707275450229645, 59.18859176337719, 59.03065703809261, 40.94974145293236, 57.82863333821297, 39.906834214925766, 33.20617116987705, 59.273551404476166, 54.79288883507252, 55.30724823474884, 46.384548023343086, 50.947601571679115, 55.47666594386101, 55.369834676384926, 54.24828305840492, 54.74721148610115, 56.29638075828552, 56.2177287787199, 54.216668754816055, 56.55932664871216, 56.434408351778984, 56.55843369662762, 56.19484260678291, 56.73975616693497, 50.279430225491524, 43.09786878526211, 45.380847081542015, 46.53747841715813, 47.93557919561863, 50.42417585849762, 53.64993676543236, 55.734151527285576, 54.132263883948326, 55.45589245855808, 54.846937134861946, 54.580324441194534, 50.83443984389305, 43.88758800923824, 34.622700959444046, 26.559972502291203, 16.24499659985304, 7.108810069039464, 13.633315041661263, 8.212598115205765, 20.920666605234146, 16.44367653876543, 8.330620732158422, 6.635178783908486, 8.716981150209904, 5.462646251544356, 0.6938522087875754, 0.6041050620842725, 0.025364926623296924, 0.3829737607156858, 2.0286724297329783, 10.330966394394636, 26.757558099925518, 39.27297882735729, 33.717030957341194, 25.72708759456873, 21.696353182196617, 25.715916194021702, 37.465374022722244, 45.79825468361378, 36.283903419971466, 9.690701700747013, 0.689681873191148, 0.04442506753548514, 0.04199543931463268, 0.014783105816604802, 0.03894559828040656, 0.062229861941887066, 0.079809485032456, 0.03514498952426948, 0.010632785943016643, 0.033256216265726835, 0.021645440174324904, 0.020550508888845798, 0.021269538665364962, 0.021361058461479843, 0.028769178425136488, 0.02065816668618936, 0.013821477241435787, 0.0732880255964119, 0.07836769247660413, 0.03381234833796043, 0.05113039776915684, 0.0483399039512733, 0.058808412723010406, 0.04634724486095365, 0.0208357663359493, 0.04571737670630682, 0.0787753467739094, 0.05293843649269547, 0.05103686489746906, 0.045598915094160475, 0.04685911524575204, 0.026377028661954682, 0.05368201651435811, 0.012282120096642757, 0.05310610620654188, 0.0195789392455481, 0.04396547774376813, 0.0357038155925693, 0.03253533854149282, 0.03191082869307138, 0.02305843368958449, 0.058712256359285675, 0.06892197823617607, 0.04110596048121806, 0.030523188797815237, 0.07041659686365165, 0.018180720035161357, 0.03333041619043797, 0.030812147706456017, 0.05130222350999247, 0.02962131238746224, 0.0033951270961551927, 0.03000162039825227, 0.06044016539817676, 0.7941062073223293, 7.47638002038002, 35.76395832002163, 54.06042493879795, 47.89087079465389, 44.840086698532104, 32.43623748421669, 21.813008822500706, 30.05878295749426, 32.17393755912781, 32.01131008565426, 20.73491547256708, 7.2941365744918585, 1.1084831692278385, 0.2716848277486861, 0.39272279071155936, 1.2676593591459095, 4.7287526819854975, 9.861473087221384, 11.016945485025644, 11.76353607326746, 10.439670011401176, 9.888493437319994, 10.996971856802702, 6.6602883115410805, 5.545271392911673, 14.42265048623085, 28.463752046227455, 39.1841471940279, 48.017631992697716, 56.598589941859245, 59.895749017596245, 62.8794477134943, 62.89687357842922, 61.21715471148491, 62.56729446351528, 57.70936153829098, 56.35813884437084, 59.921732023358345, 61.00069172680378, 58.63638639450073, 57.14996315538883, 59.35974217951298, 60.41140414774418, 55.83272963762283, 46.571296602487564, 43.674951419234276, 53.94261226058006, 61.08389586210251, 63.26800346374512, 61.11174076795578, 55.37494920194149, 60.7907035946846, 58.13846491277218, 59.521271511912346, 58.62242594361305, 59.401707127690315, 59.58471670746803, 59.4489423930645, 44.37972620129585, 59.615160673856735, 44.14445802569389, 38.02921436727047, 59.553615376353264, 56.64575681090355, 56.94504015147686, 49.08926568925381, 52.770052179694176, 59.12542775273323, 58.197680935263634, 56.52544006705284, 54.79157030582428, 58.42294804751873, 55.94682991504669, 56.35539159178734, 57.137393429875374, 59.82234075665474, 58.41828569769859, 58.502599373459816, 58.68185095489025, 51.8464395403862, 44.177816435694695, 47.43343994021416, 49.157985001802444, 52.1342208981514, 53.68142567574978, 57.49158762395382, 58.523205667734146, 57.043941244482994, 55.47250136733055, 55.387249141931534, 52.72872179746628, 52.576167583465576, 45.84863618016243, 33.52090448141098, 25.798825845122337, 15.918170437216759, 7.6514817494899035, 11.965632978826761, 11.393149048089981, 14.54236876219511, 18.415656723082066, 15.243804473429918, 8.400070555508137, 7.651195339858532, 5.182644976302981, 2.2087077191099524, 0.8691098482813686, 0.12541617412352934, 0.37078834895510226, 2.367643928155303, 10.900141652673483, 27.92428359389305, 41.811649203300476, 43.246646001935005, 31.67781338095665, 28.579678125679493, 32.332826033234596, 43.57186295092106, 52.177625969052315, 44.04039680957794, 13.319588676095009, 0.8278014929965138, 0.061830998383811675, 0.013952273347968003, 0.01969068071048241, 0.04128604632569477, 0.04199042981781531, 0.08771663808147423, 0.036691562199848704, 0.0517572936223587, 0.10197388866799884, 0.04698758843005635, 0.049214005484827794, 0.04742736287880689, 0.03530604670231696, 0.028692722371488344, 0.032592194475000724, 0.034049008099827915, 0.034684223428484984, 0.04871898185228929, 0.05937416302913334, 0.023104884712665807, 0.043096445078845136, 0.05755594203947112, 0.03811889771895949, 0.018649364028533455, 0.028359661337162834, 0.03390991478227079, 0.006966971614019712, 0.12592586630489677, 0.11137650639284402, 0.12011329148663208, 0.08693987663718872, 0.20160646468866616, 0.1263516809558496, 0.16495893039973453, 0.20355823886347935, 0.1400923077017069, 0.10944637324428186, 0.08350180331035517, 0.1558365995879285, 0.07961562863783911, 0.24180838168831542, 0.1767499203560874, 0.08333997058798559, 0.18068952223984525, 0.203952883312013, 0.11720770911779255, 0.15591924515319988, 0.09911138797178864, 0.11698313523083925, 0.1073338276182767, 0.17205804790137336, 0.10955096411635168, 0.15651533816708252, 1.4287634706124663, 11.080357432365417, 45.272526293992996, 59.38662953674793, 55.21203674376011, 49.61767293512821, 38.44545163214207, 29.512968845665455, 34.932650327682495, 42.26188704371452, 41.04182571172714, 23.750621750950813, 9.156371522694826, 1.1464951420202851, 0.6712355848867446, 0.6700510578230023, 2.9641026724129915, 5.361585924401879, 16.527315750718117, 18.37300781160593, 16.76606073975563, 16.84905968606472, 16.923718079924583, 29.119230173528194, 14.249321836978197, 7.591490568593144, 18.578721173107624, 29.395118169486523, 40.40536366403103, 49.92895983159542, 55.36916211247444, 59.188663959503174, 61.27868860960007, 60.0394307076931, 61.963989436626434, 66.78007140755653, 61.958399936556816, 59.14824552834034, 60.659823417663574, 63.05631682276726, 59.1004478931427, 58.05003225803375, 58.81359748542309, 62.400270625948906, 58.23923550546169, 49.15510855615139, 44.35964047908783, 56.85119278728962, 62.5504195690155, 66.51006549596786, 62.934415563941, 53.86404387652874, 61.01681426167488, 60.59706598520279, 62.60532662272453, 60.89186556637287, 62.72225774824619, 63.433511182665825, 63.17266657948494, 47.89160415530205, 61.232046112418175, 48.57672639191151, 44.19078513979912, 60.599995627999306, 58.860870748758316, 60.078880190849304, 51.89265266060829, 55.328055918216705, 62.87991128861904, 59.34302307665348, 58.041357323527336, 55.20493872463703, 58.54548007249832, 56.306777000427246, 56.310968175530434, 58.04899871349335, 60.805199816823006, 60.07249653339386, 62.06469163298607, 62.95213781297207, 54.944211915135384, 47.61742226779461, 51.355274096131325, 51.368307396769524, 53.07222716510296, 55.37483900785446, 60.86203336715698, 60.61865262687206, 57.66294322907925, 56.270314157009125, 57.02204681932926, 53.91209989786148, 56.896782740950584, 48.56576777994633, 41.296100467443466, 30.578196085989475, 20.703430362045765, 12.900932841002941, 26.32106602191925, 20.778770819306374, 34.650526866316795, 32.87808537483215, 14.962856099009514, 16.783315613865852, 15.929878558963537, 10.699547566473484, 3.057119306176901, 1.4579147938638926, 0.3612877306295559, 0.7495690346695483, 2.6579160522669554, 12.45916759595275, 33.47065597772598, 51.59343011677265, 48.12734730541706, 35.791533440351486, 31.63410622626543, 38.29776495695114, 51.69032871723175, 60.894236639142036, 51.52365066111088, 18.496888764202595, 1.424124869517982, 0.139410927076824, 0.15851545584155247, 0.1115906159975566, 0.13908816705225036, 0.1458796940278262, 0.29950963624287397, 0.10569578153081238, 0.18500653590308502, 0.18309670791495591, 0.08207525446778163, 0.146496374218259, 0.14794673857977614, 0.13881061866413802, 0.1356465314165689, 0.10886838121223263, 0.09634285801439546, 0.10391885734861717, 0.14395496371435001, 0.12444522231817245, 0.1631641946732998, 0.1534110977081582, 0.18435543490340933, 0.1755912200314924, 0.16303995915222913, 0.1208502367080655, 0.15395396389067173, 0.1966231656842865], [0.020693721126008313, 0.022830429224995896, 0.06429213448427618, 0.05001259720302187, 0.029300224050530232, 0.07782531611155719, 0.13769834709819406, 0.022040320254745893, 0.09892796617350541, 0.015504825878451811, 0.004749427862407174, 0.020626226505555678, 0.044616649247473106, 0.019557862251531333, 0.07754602367640473, 0.06737840012647212, 0.02467652713676216, 0.0583939937496325, 0.08328704803716391, 0.0472646247362718, 0.020234157309459988, 0.06958054524147883, 0.008225208785006544, 0.046499129093717784, 0.020606056787073612, 0.03146194067085162, 1.6672544670291245, 8.340517301112413, 38.892835825681686, 52.69663631916046, 51.63896307349205, 27.103613130748272, 20.349515452980995, 16.38929955661297, 20.84404181689024, 28.669214621186256, 27.779385969042778, 15.433533042669296, 4.3934933468699455, 0.5503120610956103, 0.07169951044488698, 0.20789537957170978, 0.7618917734362185, 4.501680666580796, 8.796934559941292, 9.968389850109816, 7.246760716661811, 14.97580200433731, 10.346842892467976, 8.055126965045929, 6.16710945032537, 10.166591014713049, 18.33759941160679, 34.980303570628166, 46.15019179880619, 55.17348401248455, 56.64928302168846, 60.55679194629192, 57.30566740036011, 60.46697236597538, 60.29491379857063, 58.464122638106346, 56.78584389388561, 53.9074869453907, 55.05303427577019, 59.68076795339584, 57.45959334075451, 57.25817754864693, 56.86688594520092, 57.19251327216625, 49.940830394625664, 41.763068810105324, 42.4576411396265, 55.64780116081238, 55.95878787338734, 55.22627837955952, 47.550420463085175, 56.59792497754097, 62.21205152571201, 54.29450377821922, 51.657335087656975, 51.60105250775814, 51.46623194217682, 53.931706845760345, 59.63319830596447, 42.730660289525986, 46.07871003448963, 37.34728775918484, 36.861312836408615, 62.44161620736122, 55.803668797016144, 53.000380620360374, 47.54669666290283, 52.88790285587311, 56.445397362113, 55.78441523015499, 55.117345824837685, 56.19076922535896, 56.20663717389107, 59.18212071061134, 57.623144164681435, 54.4467768073082, 54.075753316283226, 52.93298363685608, 56.720331609249115, 58.16195525228977, 53.67671772837639, 45.006472170352936, 39.37336564064026, 43.39659735560417, 46.0918877273798, 51.924050375819206, 51.58022202551365, 55.65419241786003, 55.37554956972599, 57.09686100482941, 52.155674546957016, 53.50133053958416, 49.47822041809559, 49.251627177000046, 38.77396680414677, 32.61029474437237, 25.389481410384178, 9.976905193179846, 5.576441120356321, 11.514522135257721, 14.050752092152834, 7.528178840875626, 13.622570168226957, 9.978118278086185, 4.105683965608478, 3.5783204762265086, 1.6194510133937001, 0.6758262729272246, 0.08977184537798166, 0.00581225012865616, 0.8875573240220547, 5.388127025216818, 19.475060775876045, 27.838909775018692, 25.552697852253914, 23.37551347911358, 17.5486059486866, 26.604996286332607, 40.917435586452484, 47.30974517762661, 38.68912495672703, 11.835762597620487, 2.4378662975504994, 0.04224848198646214, 0.04213880740280729, 0.014382516765181208, 0.007764396768834558, 0.05548223671212327, 0.08292292070109397, 0.02217058943642769, 0.028264319480513223, 0.03753352131752763, 0.011448986970208352, 0.029332405429158825, 0.056349020669586025, 0.032361189878429286, 0.019599123806983698, 0.026629191888787318, 0.09230529263732024, 0.030720520298928022, 0.03232456489058677, 0.06817844274337403, 0.11260827115620486, 0.02150512231310131, 0.04131433328439016, 0.04345298766565975, 0.03876314869557973, 0.04710321132733952, 0.04103600193047896, 0.02908496040618047, 0.03204103108146228, 0.06877207924844697, 0.07269980676937848, 0.019261055131210014, 0.016240718177868985, 0.0439902283687843, 0.04966504202457145, 0.016086498035292607, 0.030682481519761495, 0.08223848242778331, 0.0767452092259191, 0.025902345441863872, 0.04749055304273497, 0.011409808994358173, 0.06783242381061427, 0.14505734987324104, 0.026622258374118246, 0.05635437155433465, 0.025656757643446326, 0.052266774291638285, 0.03278452204540372, 0.023871486155258026, 0.0815783791767899, 0.03251297392125707, 0.04141715413425118, 0.03844155013212003, 1.8847374594770372, 11.56737444922328, 46.47627130150795, 58.10690760612488, 55.74646286666393, 32.62108996510506, 23.194350600242615, 19.72459528595209, 25.19547712057829, 34.124654084444046, 33.24164226651192, 17.49760128557682, 5.0439362693578005, 0.6703622848726809, 0.05959423950116616, 0.5762926919851452, 1.3202429562807083, 6.666715191677213, 9.325503297150135, 11.248402465134859, 11.437992341816425, 10.247510522603989, 11.993236597627401, 9.101878646761179, 7.531576808542013, 12.782948222011328, 18.879991807043552, 33.99939760565758, 46.08952425420284, 53.071383610367775, 56.97477735579014, 58.90869878232479, 59.02030259370804, 61.36171795427799, 63.66343304514885, 61.13936148583889, 58.70485112071037, 56.702556163072586, 57.93518342077732, 58.88000652194023, 57.8028479218483, 57.082820758223534, 57.144708037376404, 59.6957353502512, 53.7512469291687, 43.733099699020386, 44.28090490400791, 58.00538085401058, 58.56328971683979, 57.74483263492584, 51.61051020026207, 57.666268050670624, 64.40991058945656, 56.764846220612526, 55.53838223218918, 53.97262305021286, 52.67764113843441, 56.684085354208946, 60.87505146861076, 44.97662477195263, 51.016871854662895, 41.88020512461662, 40.80889821052551, 62.723382487893105, 58.38162146508694, 55.37673510611057, 49.409341514110565, 54.75364074110985, 58.31214979290962, 57.02767811715603, 56.07185460627079, 56.530151814222336, 57.11875922977924, 59.85819183290005, 58.48630964756012, 53.83873723447323, 55.455447882413864, 53.54122839868069, 59.026671051979065, 59.38859023153782, 55.97974754869938, 48.01049217581749, 42.342967092990875, 44.82450753450394, 49.501197785139084, 53.11988040804863, 53.779456615448, 55.965372920036316, 59.11726199090481, 57.41215668618679, 52.48287878930569, 53.36286976933479, 51.80807299911976, 50.286471247673035, 43.7168175727129, 33.23188439011574, 24.923350922763348, 12.6406829059124, 5.366288647055626, 14.045331683009863, 20.733667239546776, 14.838826954364777, 13.2737678848207, 10.405870825052261, 9.41673830151558, 5.175289046019316, 3.375577605329454, 1.8135995767079294, 0.10268125188304111, 0.1785206253407523, 0.9518461336847395, 6.3306749984622, 21.88337154686451, 33.86875681579113, 29.420364014804363, 26.287008449435234, 20.273238345980644, 32.987549901008606, 50.16181133687496, 54.48034420609474, 46.53012581169605, 15.752526875585318, 2.6267363503575325, 0.043656336129060946, 0.040744694124441594, 0.032320828177034855, 0.025879901040752884, 0.07519695558585227, 0.029295416788954753, 0.08427961118286476, 0.0305570808268385, 0.04471860549529083, 0.0616837711277185, 0.017266227114305366, 0.045877157390350476, 0.011001265047525521, 0.017053043338819407, 0.13101129967253655, 0.03467165144684259, 0.06680376260192133, 0.014096582108322764, 0.02914819138823077, 0.08091760057141073, 0.04866034476435743, 0.06931580632226542, 0.03440378808591049, 0.039234772411873564, 0.03438031024415977, 0.07465591508662328, 0.03166997208609246, 0.10730400070315227, 0.16186736582312733, 0.12717922014417127, 0.08285260963020846, 0.1310767570976168, 0.13511690514860675, 0.21183282922720537, 0.10433959570946172, 0.10988142021233216, 0.17532532336190343, 0.2454815525561571, 0.10989709437126294, 0.12330497178481892, 0.07604528975207359, 0.2682499011280015, 0.23113466537324712, 0.14940223860321566, 0.11981316696619615, 0.21124292572494596, 0.12331723206443712, 0.1763770802062936, 0.179966967261862, 0.17522652866318822, 0.15277092112228274, 0.13687448896234855, 0.14298692112788558, 2.5923586450517178, 15.764211248606443, 55.12169659137726, 65.47536581754684, 66.56897753477097, 37.106639072299004, 30.08785519748926, 24.68753557652235, 29.94654268026352, 41.86293125152588, 39.852500930428505, 19.469142593443394, 6.498831175267696, 0.9215440065599978, 0.3772648045560345, 0.7590822398196906, 2.802911759354174, 8.818537350744009, 19.452214501798153, 22.411524206399918, 16.391330547630787, 27.772496938705444, 19.200878888368607, 15.825107730925083, 11.64762994274497, 13.53990275412798, 21.504685766994953, 39.94362384080887, 50.26590295135975, 59.24274265766144, 59.426857978105545, 62.746192663908005, 59.54969018697739, 61.73488073050976, 63.26703831553459, 62.42892108857632, 60.47550670802593, 59.34421241283417, 60.39562739431858, 61.52811862528324, 57.666963413357735, 56.5419577807188, 59.378338381648064, 62.696020156145096, 54.31711636483669, 45.58828555047512, 46.273301392793655, 60.12956567108631, 61.05136580765247, 59.36248563230038, 53.441643342375755, 60.243791341781616, 67.33226537704468, 60.33147543668747, 57.41003639996052, 58.08336406946182, 54.20283369719982, 59.05394598841667, 63.855307549238205, 47.818670868873596, 53.15162770450115, 48.31250756978989, 44.449752643704414, 64.55750986933708, 61.23045399785042, 57.59843789041042, 51.69766612350941, 56.834021508693695, 61.172860488295555, 59.129710122942924, 57.926075309515, 58.089284151792526, 58.62610414624214, 61.93006865680218, 59.72334086894989, 53.97381618618965, 56.44597493112087, 56.32187359035015, 60.121198520064354, 63.10871221125126, 57.30392709374428, 50.78547187149525, 43.57074961066246, 47.84725673496723, 50.697179809212685, 56.27445213496685, 55.468002408742905, 60.50112873315811, 61.527126878499985, 60.46247720718384, 53.82579892873764, 55.67545227706432, 52.637188509106636, 52.441107630729675, 41.48696802556515, 36.953093111515045, 29.904133155941963, 15.2433817461133, 11.539630237966776, 22.112854532897472, 26.446938067674637, 16.653679870069027, 21.677869074046612, 19.935692958533764, 13.388421032577753, 11.884344890713692, 4.645095895975828, 1.5206799446605146, 0.4248284554341808, 0.24896428833017126, 1.7771748499944806, 7.166383154690266, 26.142825186252594, 37.730083018541336, 37.392398938536644, 36.014136895537376, 29.745225682854652, 40.292692109942436, 54.25483390688896, 59.98931139707565, 53.00687447190285, 20.545489937067032, 3.6599571956321597, 0.11386183279682882, 0.13497882115188986, 0.08987375709693879, 0.09138818364590406, 0.19405757600907236, 0.10771512083010748, 0.13725755590712652, 0.14689122646814212, 0.1413115079049021, 0.17736971756676212, 0.06936488454812206, 0.2383731136796996, 0.11432628365582787, 0.2060264884494245, 0.21896889084018767, 0.1512552477652207, 0.15745443699415773, 0.08478857605950907, 0.21123615733813494, 0.18549915868788958, 0.2918117243098095, 0.1579646486788988, 0.16137392667587847, 0.08441243335255422, 0.13006443798076361, 0.1538327118032612, 0.11399725248338655], [0.008069631439866498, 0.03059308055526344, 0.05569369313889183, 0.04257887128915172, 0.030875191296217963, 0.02379257359280018, 0.019486269120534416, 0.039416216386598535, 0.01347895846265601, 0.04319964071328286, 0.05166757538972888, 0.013375421440287028, 0.06677166471490636, 0.03430306009249762, 0.031111858479562216, 0.06715713621815667, 0.0741480485885404, 0.03139248306979425, 0.06376878678565845, 0.08197463408578187, 0.042430530811543576, 0.03688312535814475, 0.038473874374176376, 0.10479967531864531, 0.06428574459278025, 0.03735264879651368, 1.9207842252217233, 14.412574376910925, 37.251449301838875, 55.36905571818352, 41.96283169090748, 34.50087569653988, 24.52982883900404, 20.731746442615986, 39.108098074793816, 35.33144272863865, 25.12999713420868, 8.750112522393465, 2.251908313483, 0.1988391889608465, 0.23329232615651563, 0.3719476133119315, 0.6562292401213199, 3.7716505397111177, 5.6684688571840525, 4.592903796583414, 13.37174752727151, 4.266615780070424, 9.42693030461669, 6.348772952333093, 4.104468505829573, 11.02318475022912, 21.54768615961075, 38.12085025012493, 49.772431030869484, 55.25369770824909, 58.21131460368633, 56.87474772334099, 59.65281665325165, 56.65985405445099, 58.03002253174782, 54.87572818994522, 52.76198521256447, 53.82798761129379, 58.4847517311573, 56.91938012838364, 54.67495076358318, 54.773832857608795, 57.83761605620384, 56.81633725762367, 52.349737733602524, 39.53899495303631, 45.00810608267784, 51.18902541697025, 60.906266793608665, 52.57028549909592, 55.48046953976154, 57.422286942601204, 55.76690576970577, 52.29540824890137, 48.93055960536003, 43.0710232257843, 51.36833779513836, 48.82825009524822, 59.54864144325256, 47.46324174106121, 42.49926410615444, 34.35673423111439, 29.097105860710144, 60.718271881341934, 53.62163208425045, 55.9939131885767, 48.205478712916374, 51.3552512973547, 48.501384034752846, 51.86846695840359, 52.300876155495644, 55.60084328055382, 53.21921467781067, 55.33715642988682, 55.9028472751379, 58.09838846325874, 52.57718972861767, 54.88409534096718, 51.44870348274708, 56.62054896354675, 55.8044857531786, 50.80286733806133, 40.49268677830696, 42.5114044547081, 46.223968639969826, 45.2330008149147, 50.40404833853245, 51.59782648086548, 53.53225328028202, 57.32833318412304, 56.55777633190155, 51.505236849188805, 48.45146991312504, 50.12070134282112, 36.62163309752941, 33.49692776799202, 22.696636207401752, 20.561346486210823, 12.590487599372864, 7.663474380970001, 11.071012783795595, 19.00233954191208, 24.409443698823452, 5.116632068529725, 7.413586489856243, 3.9816386718302965, 3.063042713329196, 2.473506722599268, 0.15881476399954408, 0.055725750207784586, 0.5726043961476535, 3.7887173239141703, 13.118284977972507, 28.039548508822918, 36.0972536355257, 29.64527204632759, 26.458403952419758, 25.523825101554394, 35.12633353471756, 45.762870982289314, 41.578239127993584, 19.368926770985126, 2.983543141745031, 0.07205493981018662, 0.05796681725769304, 0.11057068244554102, 0.042500841882429086, 0.05169569165445864, 0.05259538986138068, 0.01795579919416923, 0.015910527399682906, 0.040552604041295126, 0.027753052090702113, 0.013208472537371563, 0.05111837497679517, 0.035926864366047084, 0.024201250198530033, 0.02753744334768271, 0.03846600389806554, 0.039089638012228534, 0.054902500633033924, 0.025028908130479977, 0.037672325197490864, 0.08662280888529494, 0.030787165160290897, 0.06100601589423604, 0.017049549678631593, 0.07498496110201813, 0.03261311190726701, 0.03140901812002994, 0.05014135611418169, 0.021695421964977868, 0.047869898116914555, 0.07107765748514794, 0.042796595153049566, 0.15410007792524993, 0.04190571366052609, 0.036277436374803074, 0.05431187724752817, 0.026867033520829864, 0.04322868837334681, 0.07936856025480665, 0.055685503539280035, 0.031119630621105898, 0.038864622547407635, 0.07833359079086222, 0.05364927295886446, 0.03483123175101355, 0.015977541479514912, 0.037325185621739365, 0.06906901995535009, 0.04588082359987311, 0.06899008512846194, 0.055030699222697876, 0.006486044148914516, 0.025729326698638033, 2.1776396362110972, 18.26099932193756, 45.83096332848072, 61.426565274596214, 50.594079941511154, 36.36346735060215, 27.473466284573078, 21.86091475188732, 33.182616233825684, 37.37286798655987, 27.526190355420113, 10.650195814669132, 2.3608342185616493, 0.2986484480788931, 0.04658191195630934, 0.7407544576562941, 2.704839971847832, 9.700075797736645, 9.784948993474245, 13.314531147480011, 10.713494718074799, 9.518357198685408, 10.572011210024357, 9.196799453347921, 8.693370167165995, 12.009946200996637, 21.038876362144947, 38.2689169049263, 51.146752685308456, 57.782161831855774, 60.6318911164999, 58.96617449820042, 60.246208012104034, 59.256889298558235, 59.172362834215164, 57.19548851251602, 55.03468506038189, 55.79833388328552, 59.08354640007019, 58.82188104093075, 54.34024952352047, 54.9018631875515, 59.48970280587673, 58.516362234950066, 54.91488888859749, 42.679389640688896, 46.08426533639431, 54.85811613500118, 62.7306704968214, 54.52277272939682, 55.9328580647707, 57.90536642074585, 59.035874158144, 54.492944329977036, 52.642572820186615, 46.56090795993805, 52.60952599346638, 50.11629357933998, 62.11573049426079, 48.94127123057842, 46.542870327830315, 37.78160825371742, 33.45168739557266, 61.154887452721596, 55.89722737669945, 58.44460308551788, 51.090591698884964, 52.42736376821995, 51.94972559809685, 55.42007178068161, 55.592882707715034, 56.0391915589571, 57.14928299188614, 56.601128205657005, 58.11663508415222, 58.60297478735447, 54.74629193544388, 55.31909219920635, 52.165630012750626, 59.14630763232708, 58.28078247606754, 51.91481687128544, 42.80298940837383, 44.234763979911804, 47.775151804089546, 49.000905230641365, 53.57174456119537, 54.877335503697395, 56.82027384638786, 58.80119875073433, 55.78311949968338, 52.08976708352566, 49.59827497601509, 50.94856671988964, 38.612255081534386, 37.34169065952301, 24.651823192834854, 21.768938787281513, 13.810200300067663, 6.901451395824552, 15.16871765255928, 18.42665333300829, 7.576562594622374, 12.676722072064877, 13.294084444642067, 7.619648007676005, 4.251003367826343, 2.395005547441542, 0.37950905913021415, 0.08885031318641268, 0.6055087898857892, 4.15311967022717, 15.63393048942089, 30.53871050477028, 37.04893536865711, 31.065234951674938, 27.128743082284927, 30.62690757215023, 39.837339743971825, 51.65885120630264, 49.34417501091957, 24.49562307447195, 3.7102938070893288, 0.07213953722384758, 0.015953425390762277, 0.047035553434398025, 0.03351501429278869, 0.040288039526785724, 0.06179721582157072, 0.014029779540578602, 0.01377101119942381, 0.014056047857593512, 0.03002543035108829, 0.026366391830379143, 0.05642294228891842, 0.057963774452218786, 0.06543211784446612, 0.066319014003966, 0.022099992638686672, 0.0732468586647883, 0.056746173577266745, 0.0023730028169666184, 0.017522488851682283, 0.049382402503397316, 0.011806474867626093, 0.03018491974216886, 0.015920433215796947, 0.05363635216781404, 0.04615773003024515, 0.01728573075524764, 0.1103112127748318, 0.18702756729908288, 0.09588214757968672, 0.15507193515077233, 0.113044371973956, 0.23187574435723945, 0.17367613763781264, 0.1982256257906556, 0.17154494184069335, 0.09786196751520038, 0.16094972990686074, 0.18666177755221725, 0.19592487893532962, 0.10045762901427224, 0.18075852713081986, 0.19910336384782568, 0.22284855687757954, 0.09672534608398564, 0.25756051065400243, 0.12038595654303208, 0.21194783243117854, 0.1349652695353143, 0.17844798392616212, 0.20316996204201132, 0.13850215240381658, 0.1351149458787404, 3.070018426515162, 22.20950234681368, 52.95873485505581, 68.36328685283661, 55.39216607809067, 45.43610371649265, 35.54735854268074, 32.10487626492977, 50.51627531647682, 47.25097753107548, 31.692341901361942, 11.856444887816906, 3.0241254391148686, 0.5873613199219108, 0.42825575277674943, 1.1787209752947092, 3.879559524357319, 13.457116596400738, 14.706667196005583, 16.172661781311035, 29.629394598305225, 12.311065793037415, 18.176666647195816, 14.939965177327394, 10.75414588674903, 17.433348633348942, 30.436551086604595, 42.679929211735725, 54.7733236849308, 59.62521493434906, 62.51408211886883, 59.63063724339008, 63.11661198735237, 60.83111822605133, 62.61692740023136, 56.94667026400566, 58.01829256117344, 58.416374400258064, 62.210011035203934, 60.275132060050964, 53.463245183229446, 54.8523024469614, 60.36519482731819, 61.160271763801575, 58.464901596307755, 44.311341270804405, 48.6893979460001, 56.39362134039402, 63.34033638238907, 56.77564524114132, 54.647151455283165, 60.88319443166256, 60.778890028595924, 58.02375286817551, 54.33573916554451, 48.40972155332565, 56.32908560335636, 54.757136553525925, 64.26244050264359, 52.80277222394943, 50.35385683178902, 42.977677434682846, 37.54437558352947, 64.55020666122437, 58.182983323931694, 62.36517570912838, 53.66808079183102, 54.90891180932522, 55.623976439237595, 56.08806453645229, 58.68504658341408, 59.34799320995808, 58.11372444033623, 59.36789274215698, 60.423381105065346, 61.631898656487465, 56.92028447985649, 55.21808601915836, 51.94692514836788, 61.186649948358536, 60.372357442975044, 53.60192634165287, 45.744194984436035, 46.85645990073681, 50.81212744116783, 51.478072106838226, 56.21028497815132, 57.263425067067146, 58.01446236670017, 61.58925734460354, 58.15484203398228, 55.43363705277443, 51.416116431355476, 53.434233739972115, 41.23290225863457, 38.06908182799816, 27.192936837673187, 27.21966840326786, 19.11812122911215, 15.84276158362627, 19.377996884286404, 30.04194226115942, 37.26936914026737, 16.24228924512863, 16.707291193306446, 10.961997583508492, 5.864196829497814, 4.009406631812453, 0.37220979924313724, 0.3212236304534599, 0.7743018481414765, 4.698016131296754, 17.52894390374422, 36.946215480566025, 48.07123191654682, 44.837385043501854, 38.56494002044201, 35.58352120220661, 45.73320597410202, 58.02831642329693, 56.06887936592102, 31.728876940906048, 5.684935273602605, 0.33091783057898283, 0.1496300334110856, 0.338494386523962, 0.1364514054148458, 0.171287446282804, 0.20073740975931287, 0.10959385283058509, 0.10008377954363823, 0.13632348884129897, 0.13764132047072053, 0.09246610119589604, 0.1923832908505574, 0.0906433271302376, 0.11276041142991744, 0.16792670474387705, 0.1692261014250107, 0.11906869636732154, 0.09306281761382706, 0.1662092117476277, 0.14148419082630426, 0.184789294435177, 0.1455404286389239, 0.23211248946608976, 0.0967568502528593, 0.13705946184927598, 0.14254973677452654, 0.10523993958486244], [0.03715120394190308, 0.04218128051434178, 0.03925858793081716, 0.08464642509352416, 0.03828945067652967, 0.04439250951691065, 0.023204030076158233, 0.05509948889084626, 0.039763370805303566, 0.06456361210439354, 0.04622520980774425, 0.062221082334872335, 0.037737496895715594, 0.02353413921809988, 0.03226518936571665, 0.018506925480323844, 0.014593574287573574, 0.032917752396315336, 0.06938806182006374, 0.03990218952822033, 0.14249974570702761, 0.06506983845611103, 0.06100537022575736, 0.07172901081503369, 0.023072512231010478, 0.03416223386011552, 1.8504871660843492, 20.18821220844984, 38.94141621887684, 47.662028074264526, 42.63178959488869, 30.425772964954376, 21.125278025865555, 30.365994572639465, 35.90392380952835, 36.40019237995148, 18.800614066421986, 7.711375560611486, 1.1517008626833558, 0.1889297808520496, 0.05430531295132823, 1.086956849321723, 1.5912061790004373, 8.718508668243885, 8.532476350665092, 12.326602209359407, 5.7297818921506405, 9.56230279058218, 10.800192765891552, 7.197674000635743, 9.184309523552656, 17.54237998276949, 24.663159884512424, 42.38987177610397, 52.202237248420715, 57.84407950937748, 57.80952416360378, 56.73388548195362, 55.784453228116035, 52.720119059085846, 52.91748806834221, 48.470924869179726, 53.05613502860069, 52.77392037212849, 55.390756353735924, 56.674867048859596, 55.538576021790504, 55.23233525454998, 55.89532367885113, 54.39024344086647, 53.40388856828213, 41.76568306982517, 40.49408510327339, 52.95393951237202, 58.027575463056564, 57.56922885775566, 58.61871734261513, 57.03208968043327, 56.48002490401268, 48.10123510658741, 41.219317987561226, 38.60823109745979, 46.43888130784035, 52.98360072076321, 56.14923745393753, 48.15157860517502, 35.002349987626076, 30.45509409159422, 33.13225753605366, 65.34783706068993, 52.93001979589462, 56.057392582297325, 52.286805510520935, 52.87247568368912, 48.33624869585037, 48.17030020058155, 47.776702120900154, 49.56500016152859, 50.3318902105093, 52.247762605547905, 51.237932592630386, 56.02561108767986, 57.593209370970726, 55.003811717033386, 56.103886887431145, 54.863880425691605, 55.80260865390301, 50.32766863703728, 44.825012907385826, 45.42224586009979, 44.37092587351799, 45.09059965610504, 45.719488710165024, 49.885246977210045, 51.345713809132576, 56.111604273319244, 55.109628438949585, 53.42742830514908, 53.79876337945461, 52.68731161952019, 48.71278949081898, 37.62408770620823, 36.96541965007782, 15.041541326791048, 12.186510376632214, 8.10913061723113, 22.635807171463966, 18.815450370311737, 3.387546013109386, 11.952873263508081, 10.53663320839405, 5.288342954590917, 4.407886499539018, 2.80938898678869, 0.27398177480790764, 0.03364380288985558, 0.04891410360869486, 2.2190626384690404, 9.802841283380985, 24.39169105142355, 30.687415525317192, 25.132358707487583, 22.035559080541134, 28.961817920207977, 39.06740985810757, 42.950698882341385, 47.04010784626007, 28.113017566502094, 7.911958247423172, 0.26091347448527813, 0.08240951778134331, 0.04229770493111573, 0.03981306872447021, 0.0193960406613769, 0.017986948987527285, 0.01975441635295283, 0.024189394389395602, 0.030683947261422873, 0.026969214268319774, 0.0455974493524991, 0.062149461373337545, 0.10085016576340422, 0.05361063675081823, 0.05211874551605433, 0.06165555467305239, 0.025515705056022853, 0.02836610503436532, 0.012376546328596305, 0.12183993516373448, 0.05012432753574103, 0.03577521019906271, 0.020049702070537023, 0.041667588156997226, 0.02444625355565222, 0.009773993060662178, 0.029940593594801612, 0.03978727167122997, 0.05334353038051631, 0.047721906448714435, 0.04645968394470401, 0.034000853847828694, 0.06219961942406371, 0.016163007894647308, 0.03616763191530481, 0.014972841436247109, 0.03271566929470282, 0.012276675515749957, 0.045575722979265265, 0.048101915745064616, 0.043748611060436815, 0.054136403850861825, 0.033293720698566176, 0.0288883116809302, 0.08607566793216392, 0.019400384080654476, 0.07440233064698987, 0.0704752784804441, 0.02659976944414666, 0.030943069978093263, 0.02832404938089894, 0.024859780096448958, 0.07973433515871875, 2.4468502029776573, 24.34734933078289, 44.19201247394085, 54.97002772986889, 47.71687053143978, 35.725485384464264, 24.619699716567993, 32.30599567294121, 40.267849043011665, 38.55439178645611, 22.07166664302349, 8.1319141946733, 1.6868989379145205, 0.07867009539040737, 0.271435109898448, 0.7375422050245106, 3.0279860319569707, 8.082494996488094, 8.722450956702232, 9.276680666953325, 11.61257017403841, 7.066410044208169, 9.8739212192595, 6.361768255010247, 9.10536590963602, 17.192682847380638, 27.85695880651474, 42.19937279820442, 54.07459817826748, 58.03578682243824, 59.96266342699528, 58.58075737953186, 57.61597014963627, 55.093034729361534, 55.41249118745327, 50.806822925806046, 54.7485376149416, 55.00801429152489, 59.0309040248394, 58.210596442222595, 55.305287539958954, 55.118246376514435, 56.3250046223402, 57.25259564816952, 55.75510360300541, 43.058814480900764, 43.12772378325462, 54.40799608826637, 61.56287916004658, 57.67694927752018, 58.74762922525406, 57.83117160201073, 58.82925644516945, 49.944793581962585, 42.74474613368511, 40.2948883920908, 48.362987861037254, 53.64539220929146, 58.354452922940254, 50.406601801514626, 39.96918126940727, 35.11869214475155, 35.49080237746239, 65.83269864320755, 56.40222407877445, 57.53416433930397, 54.74089242517948, 55.35981461405754, 48.384889885783195, 50.45290231704712, 50.172051787376404, 52.2184319794178, 51.817853674292564, 55.92203624546528, 54.18087847530842, 59.336612820625305, 57.249103635549545, 56.37485794723034, 56.77894726395607, 56.67117364704609, 57.938470244407654, 54.351667910814285, 47.311508283019066, 47.276721149683, 45.213553458452225, 47.45547495782375, 48.73760215938091, 52.409542724490166, 53.339075446128845, 57.12965704500675, 56.51774927973747, 55.46335145831108, 53.562647849321365, 54.39011424779892, 48.50342832505703, 41.208477169275284, 35.46665087342262, 24.08657882362604, 21.14987600594759, 8.59284371137619, 15.187938921153545, 17.136812545359135, 9.730796199291945, 15.758191421627998, 18.813362382352352, 8.807394448667765, 6.132739344611764, 4.122487613931298, 0.5747032491490245, 0.09071619861060753, 0.13596365111880004, 2.6210333313792944, 10.032202675938606, 25.550873950123787, 36.176122203469276, 33.871188685297966, 27.375294752418995, 30.387233532965183, 42.076004818081856, 48.18369448184967, 53.05152967572212, 33.24002355337143, 8.816993683576584, 0.4583637637551874, 0.06620767700951546, 0.05303075595293194, 0.025637142680352554, 0.03692818485433236, 0.022200418206921313, 0.010583329221844906, 0.033611679027671926, 0.01763479805958923, 0.03115364510449581, 0.011512523160490673, 0.03272918380389456, 0.09481671295361593, 0.03666182063170709, 0.03416755876969546, 0.05293791327858344, 0.03517745848512277, 0.02989474742207676, 0.018031657818937674, 0.026805708002939355, 0.018303643810213543, 0.027888150798389688, 0.08506724509061314, 0.044107354115112685, 0.04472257227462251, 0.017743608041200787, 0.05158163468877319, 0.18107097130268812, 0.16939456894760951, 0.12025359450490214, 0.1369527113274671, 0.08624477370176464, 0.269328152644448, 0.09459066961426288, 0.12543014134280384, 0.13900653080781922, 0.16399528132751584, 0.19386270287213847, 0.09571497139404528, 0.11940077776671387, 0.17855987010989338, 0.19109752000076696, 0.14312784012872726, 0.11542164909769781, 0.24120124551700428, 0.12782760488335043, 0.11815511257736944, 0.1942801906261593, 0.1843251404352486, 0.1128066546516493, 0.1332168438239023, 0.09361308300867677, 0.14311129023553804, 3.7619957327842712, 29.577521681785583, 52.80958905816078, 61.39462038874626, 55.68758882582188, 42.0842769742012, 30.839698053896427, 42.62968070805073, 49.56872396171093, 46.7538920044899, 25.104004628956318, 10.07185259833932, 1.8474827148020267, 0.2651700476417318, 0.35433368815574795, 2.5494807958602905, 3.3195781102404, 16.783059127628803, 18.905298449099064, 25.61981175094843, 15.00622982159257, 17.691474482417107, 22.00510561466217, 16.372667849063873, 15.581156071275473, 22.492482662200928, 28.88538122177124, 46.64017170667648, 55.56379146873951, 61.95715360343456, 61.12965300679207, 61.361531764268875, 61.379041224718094, 57.10553593933582, 58.13380256295204, 52.45647020637989, 57.655746415257454, 57.27712333202362, 60.0914803147316, 59.521571695804596, 55.501224026083946, 56.87705799937248, 57.07025483250618, 59.047680124640465, 58.70557688176632, 46.22253231704235, 44.797168001532555, 57.10196413099766, 64.14727628231049, 58.79454530775547, 59.73564840853214, 60.82544133067131, 61.317651718854904, 53.397257924079895, 45.86926907300949, 44.0072625875473, 50.33219799399376, 57.136458680033684, 62.17935048043728, 53.15530590713024, 42.902901247143745, 39.382169768214226, 42.10035391151905, 63.69723603129387, 58.3002982288599, 60.24555824697018, 57.361695393919945, 58.66610839962959, 51.90310209989548, 52.23342977464199, 53.38625751435757, 55.04703439772129, 53.365468829870224, 57.539077475667, 55.6390730291605, 61.67002581059933, 60.42316071689129, 57.84802369773388, 56.528453305363655, 57.683823108673096, 61.17155335843563, 55.45665621757507, 49.634388238191605, 49.44038964807987, 48.36014561355114, 50.12533329427242, 51.032496616244316, 54.475149884819984, 55.7751589268446, 60.30865766108036, 59.240922555327415, 57.408318892121315, 54.644913375377655, 54.66259002685547, 50.30035950243473, 42.678386494517326, 41.88041031360626, 19.939861334860325, 19.542832039296627, 16.101204715669155, 31.52219083160162, 31.16267692297697, 13.323437869548798, 20.491622127592564, 18.866601325571537, 14.57592286169529, 9.889540281146765, 5.217670071870089, 1.0893921623937786, 0.09303130602347665, 0.32384712249040604, 2.7378663746640086, 13.114199247211218, 31.977974474430084, 41.90636672079563, 38.62180016934872, 33.663146048784256, 40.8246635645628, 52.15496778488159, 54.65739190578461, 60.4215382039547, 39.91601452231407, 12.205725945532322, 0.864009156357497, 0.26845120126381516, 0.09611582761863247, 0.0990857467695605, 0.16791201021987945, 0.08135050273267552, 0.12466669402783737, 0.13923169841291383, 0.11944231577217579, 0.10884563438594341, 0.07290897367056459, 0.1287798397243023, 0.21772822772618383, 0.16307359328493476, 0.07605976905324496, 0.13879184232791886, 0.12986539397388697, 0.10178065567743033, 0.08363647342775948, 0.22946379409404472, 0.190258136135526, 0.13123489392455667, 0.20469837065320462, 0.13348173117265105, 0.14509105822071433, 0.0944722154235933, 0.15238129359204322], [0.007486518588848412, 0.04998966855055187, 0.0786588221671991, 0.002080837134599278, 0.044554460982908495, 0.044652832657448016, 0.019667045162350405, 0.009745026109158061, 0.03610464213124942, 0.02413793386949692, 0.01937482080393238, 0.021204188851697836, 0.029962696607981343, 0.058682603848865256, 0.03583096033253241, 0.038772106418036856, 0.08874069055309519, 0.005913212362429476, 0.042529299535090104, 0.008899260701582534, 0.05822635372169316, 0.014414831730391597, 0.03475153622275684, 0.06514590117149055, 0.06367311652866192, 0.0516389322001487, 3.3013383764773607, 21.768230125308037, 43.21571946144104, 47.1244253218174, 38.72407928109169, 22.434161491692066, 22.786833867430687, 26.04561310261488, 32.36489251255989, 33.47422018647194, 13.786073494702578, 5.234503643587232, 0.5359183147083968, 0.17340477876132354, 0.19205134303774685, 0.5948704888578504, 4.773323340341449, 7.742895819246769, 7.551295850425959, 10.105492193251848, 4.72523027099669, 5.608843406662345, 6.50765810161829, 6.16931950673461, 9.203326553106308, 15.78942384570837, 27.175339981913567, 40.350908786058426, 53.92067223787308, 57.72127389907837, 58.11820060014725, 53.90128567814827, 53.21640282869339, 49.095865935087204, 48.428872525691986, 51.952947825193405, 55.50837904214859, 57.16321684420109, 58.37285153567791, 54.268642365932465, 52.560113444924355, 55.09288653731346, 54.82770636677742, 54.42592352628708, 54.49717350304127, 48.899948447942734, 38.54738496243954, 43.92523258924484, 55.660473480820656, 56.59158691763878, 55.672701224684715, 53.514196649193764, 50.99357530474663, 41.37876883149147, 40.984699577093124, 41.66239321231842, 44.21310514211655, 51.20917193591595, 53.97842913866043, 54.45332385599613, 36.3410409539938, 22.516218088567257, 37.50095151364803, 50.04113361239433, 54.50127728283405, 58.3844181150198, 54.18451488018036, 55.25037668645382, 51.152649968862534, 52.87241488695145, 49.57446165382862, 48.47225859761238, 47.18993000686169, 45.83247184753418, 47.37763613462448, 51.40345171093941, 54.874128475785255, 54.09312218427658, 52.166477367281914, 54.3639450520277, 57.184180319309235, 54.27730210125446, 48.18948917090893, 44.77042503654957, 41.224728897213936, 43.018939420580864, 42.664528638124466, 48.24319168925285, 49.718709513545036, 55.29149428009987, 55.238616317510605, 56.565094739198685, 51.68498620390892, 57.59299278259277, 51.87061384320259, 43.1511153280735, 35.4204111546278, 36.93664379417896, 28.935755118727684, 6.416956493631005, 8.825665768235922, 10.499737188220024, 6.010286640375853, 15.056222788989544, 23.091602213680744, 7.443673275411129, 4.775334382429719, 2.7600643085315824, 0.8851274137850851, 0.16702897322829813, 0.07039523785351776, 0.9569635684601963, 7.589655267074704, 21.796673499047756, 29.319555424153805, 23.242545314133167, 22.88629163056612, 26.297093108296394, 29.2747026309371, 40.327771827578545, 47.1980007737875, 28.265938460826874, 10.992508996278048, 0.7650727964937687, 0.02033756631135475, 0.034031426621368155, 0.022411219688365236, 0.1144983728590887, 0.020755588411702774, 0.03039539838937344, 0.028432957697077654, 0.010003017978306161, 0.016505830026289914, 0.011610839173954446, 0.05918249225942418, 0.07032346475170925, 0.08671456802403554, 0.022745711212337483, 0.03809347916103434, 0.046455706033157185, 0.12816599453799427, 0.0795760795881506, 0.03719585896760691, 0.00792386343164253, 0.055530261088279076, 0.013686226393474499, 0.03348129852383863, 0.04003636240668129, 0.03332351792778354, 0.054121141583891585, 0.0455484935810091, 0.08257976645836607, 0.029976459736644756, 0.09122675168327987, 0.03215219738194719, 0.022971429862082005, 0.03738660576345865, 0.03610249732446391, 0.034137794937123545, 0.007848698714951752, 0.05321436699887272, 0.028195218110340647, 0.02750735297013307, 0.06349791030515917, 0.02707347859541187, 0.016859183233464137, 0.06663099062279798, 0.03282370373199228, 0.05208378664974589, 0.06403049032087438, 0.023534547399322037, 0.010703171228669817, 0.045028214663034305, 0.043293036287650466, 0.022260829027800355, 0.08416251512244344, 5.028165215626359, 26.93486038595438, 51.61660887300968, 52.97453060746193, 46.39469347894192, 27.776596918702126, 29.35765027999878, 32.606415152549744, 36.86763949692249, 36.239483803510666, 15.89685833081603, 5.3752214927226305, 1.046855344902724, 0.1360776153160259, 0.20527732005575672, 1.3855363964103162, 5.925517464056611, 10.852807592600584, 10.660356469452381, 13.259131070226431, 12.210140358656645, 13.58281860128045, 11.047322005033493, 6.798940021544695, 8.022233080118895, 19.25753954797983, 30.510510317981243, 44.70663405954838, 56.20907664299011, 60.77583499252796, 59.2609778791666, 56.9923248142004, 53.940598368644714, 52.47124761343002, 50.52963539958, 53.35804782807827, 57.6696764677763, 60.22653266787529, 58.42720381915569, 55.22106885910034, 53.64425987005234, 53.846279829740524, 55.17458975315094, 57.30646915733814, 56.363621950149536, 51.073253229260445, 40.49193821847439, 47.14069604873657, 57.51461818814278, 58.43256913125515, 57.18916565179825, 56.36792331933975, 53.33537444472313, 44.892729073762894, 42.49655865132809, 43.5048421472311, 45.70341557264328, 54.200306832790375, 54.62501384317875, 56.53605289757252, 37.86662869155407, 26.779080145061016, 39.32337172329426, 50.81408813595772, 55.82569241523743, 60.08055970072746, 56.08802653849125, 57.68699213862419, 54.61627051234245, 55.58435596525669, 50.95887936651707, 50.7729135453701, 48.23286384344101, 48.46556715667248, 49.56743203103542, 55.381127670407295, 56.10747389495373, 55.46571113169193, 51.985147297382355, 55.07937066257, 58.804736360907555, 56.85044042766094, 50.63923291862011, 47.69562587141991, 43.02789933979511, 46.87326639890671, 46.33331537246704, 52.3586368560791, 52.93669603765011, 58.01242187619209, 57.73893915116787, 58.044366762042046, 55.3849920630455, 57.14181259274483, 52.91008986532688, 43.50533612072468, 33.465222269296646, 31.021628491580486, 21.901040598750114, 12.647869270294905, 7.831292375922203, 13.993309624493122, 13.000668939203024, 14.495349135249853, 17.07353264093399, 9.605738259851933, 6.101687885820866, 4.615739146247506, 1.3096351129934192, 0.38589351810514927, 0.13186172669520602, 1.1774996970780194, 8.117957543581724, 22.601299323141575, 32.96698920428753, 30.311509296298027, 27.546087987720966, 32.93637424707413, 36.76589995622635, 45.012798830866814, 53.6730395257473, 33.24378155171871, 13.68714390322566, 1.021942812949419, 0.02921645784226712, 0.009367436214233749, 0.059011189732700586, 0.09978585178032517, 0.09831192423007451, 0.015688517632952426, 0.040272766127600335, 0.03239791505620815, 0.05331776301318314, 0.03888325045409147, 0.0706016513868235, 0.02069033136649523, 0.0518248847220093, 0.05596130416961387, 0.032022711166064255, 0.032368681859225035, 0.022105443713371642, 0.033624863281147555, 0.09105242119403556, 0.06743491467204876, 0.04774154367623851, 0.03443070578214247, 0.03318660281365737, 0.03499283811834175, 0.055839050182839856, 0.005467662613227731, 0.08801803909591399, 0.11541335930814967, 0.12197229720186442, 0.14080902939895168, 0.12987150927074254, 0.1378820138052106, 0.1033930160338059, 0.1485105333267711, 0.10399426697404124, 0.08359900981304236, 0.11694967921357602, 0.1298110539210029, 0.13200830086134374, 0.15924158797133714, 0.1346967605059035, 0.07984105599462055, 0.12128234477131628, 0.17281042237300426, 0.2433012711117044, 0.1951745231053792, 0.17266381852095947, 0.0815571314888075, 0.14417030528420582, 0.13293303170939907, 0.09555636701406911, 0.16499629011377692, 7.010850375518203, 31.74983661621809, 58.18351149559021, 60.535304099321365, 52.449098601937294, 32.60269895195961, 32.21441298723221, 35.44584318995476, 42.419510185718536, 44.15846407413483, 19.43541180342436, 6.4002625644207, 1.14251509308815, 0.3717318264534697, 0.31470911751966923, 2.80021651647985, 11.39413034543395, 18.639381118118763, 16.7983191087842, 21.145960316061974, 14.504931271076202, 16.758991219103336, 17.19107363373041, 14.279346875846386, 15.941423289477825, 19.652636647224426, 30.079987719655037, 43.390057906508446, 57.02257499098778, 61.78847685456276, 61.67216509580612, 58.52339565753937, 55.48689119517803, 53.36863785982132, 52.641896456480026, 54.82682481408119, 59.867349341511726, 61.32993645966053, 60.31398117542267, 55.099638774991035, 53.965673223137856, 53.88315685093403, 55.640209168195724, 57.86422222852707, 58.90489138662815, 53.424004688858986, 42.303589805960655, 50.080005526542664, 60.44467516243458, 61.798223331570625, 59.49323281645775, 59.729526937007904, 55.633168146014214, 47.57992587983608, 44.8324491083622, 46.429336220026016, 48.64375479519367, 57.13232070207596, 57.52543620765209, 59.20224443078041, 42.02779300510883, 30.375300273299217, 45.525201335549355, 57.253655791282654, 56.5001068264246, 61.14080920815468, 58.36017541587353, 59.67612460255623, 57.25736819207668, 57.7432557195425, 54.2886520922184, 53.212823420763016, 50.519117563962936, 50.09146571159363, 51.92614406347275, 56.295335814356804, 58.31191040575504, 56.33776433765888, 51.905431374907494, 55.70042073726654, 62.326273396611214, 59.33637723326683, 53.35995152592659, 49.81760300695896, 45.057853013277054, 49.572166576981544, 48.3621709048748, 53.827037662267685, 54.863641038537025, 62.13147684931755, 60.058908462524414, 62.50931717455387, 55.890022963285446, 62.90127754211426, 54.5289321988821, 49.124489799141884, 38.17694664001465, 38.478924036026, 36.46939806640148, 11.462278738617897, 18.011645302176476, 25.02456609159708, 14.213382415473461, 24.25713837146759, 35.37549376487732, 15.147049315273762, 12.918694987893105, 9.217773377895355, 2.256342200562358, 0.5883350176736712, 0.2516200934769586, 1.3369169365614653, 9.787947032600641, 27.773978859186172, 40.46326495707035, 36.66639469563961, 35.854792445898056, 38.858386874198914, 41.96128897368908, 52.92647458612919, 62.249346524477005, 39.74408134818077, 16.490775011479855, 1.8047895119525492, 0.1247881242306903, 0.08794320092420094, 0.23303306428715587, 0.21482807787833735, 0.10923564783297479, 0.13287480280268937, 0.11408057340304367, 0.09062937475391664, 0.14699506777105853, 0.1161807548487559, 0.11085997903137468, 0.11084630867117085, 0.13833380362484604, 0.20754003926413134, 0.13957221060991287, 0.09276074866647832, 0.24084122967906296, 0.13483558665029705, 0.10330846314900555, 0.18127988587366417, 0.17801709298510104, 0.15321592771215364, 0.16055244341259822, 0.1658761061844416, 0.11075231566792354, 0.14097555249463767], [0.08120772094116546, 0.09502788365352899, 0.08078281913185492, 0.06408989924238995, 0.020829393142776098, 0.042378257639938965, 0.016284545708913356, 0.027824318676721305, 0.049117244270746596, 0.0426825641625328, 0.05655857348756399, 0.025146178595605306, 0.009188441326841712, 0.0895657212822698, 0.02670671477972064, 0.030763911818212364, 0.020074779240530916, 0.1233874614990782, 0.025003135197039228, 0.06899123545736074, 0.026618517949827947, 0.06528071229695342, 0.04723196652776096, 0.01819712149881525, 0.013456596625474049, 0.22236219781916589, 4.170033512637019, 22.635824270546436, 51.696712374687195, 46.36012673377991, 31.83415789157152, 26.122093498706818, 20.57010691612959, 21.45467285066843, 41.65463402867317, 27.761137448251247, 15.624311305582523, 3.6500668013468385, 0.5138567578978837, 0.04586186172673479, 0.5761440249625593, 1.0955706308595836, 4.014747245237231, 7.219587899744511, 6.52864390052855, 3.887955886311829, 14.114279933273792, 6.664286646991968, 6.2609306909143925, 2.23504648078233, 8.048221785575151, 25.82692913711071, 31.059193275868893, 42.12969593703747, 52.31891758739948, 56.37923151254654, 58.32322999835014, 54.36888858675957, 52.844611778855324, 49.20118108391762, 48.59262093901634, 48.571467474102974, 57.641702368855476, 58.846720308065414, 56.067940816283226, 54.56384852528572, 56.3104248046875, 53.89840543270111, 54.159789606928825, 55.71739062666893, 54.00628164410591, 54.60865192115307, 47.634810134768486, 39.6333172917366, 41.81790366768837, 53.3000173419714, 53.20582799613476, 47.928697764873505, 41.606957986950874, 39.076738357543945, 37.236124724149704, 38.82351614534855, 41.41357496380806, 43.939546421170235, 46.00814402103424, 56.07893742620945, 47.26135477423668, 23.276724480092525, 28.468581587076187, 50.36763109266758, 50.22416599094868, 55.35607561469078, 56.20808109641075, 55.89090831577778, 51.84334650635719, 54.35183510184288, 50.63038319349289, 53.771461844444275, 51.44509747624397, 47.845801413059235, 41.25201143324375, 48.717888817191124, 55.63989378511906, 57.31696039438248, 53.5522136092186, 53.005244359374046, 54.90590997040272, 56.23130165040493, 52.44137741625309, 47.74193778634071, 43.93769972026348, 44.08981695771217, 44.67307806015015, 47.546305283904076, 47.39296831190586, 50.79797700047493, 53.56210067868233, 54.55352447926998, 54.88732136785984, 57.05099366605282, 54.275485798716545, 46.946298480033875, 36.45962879061699, 32.9469832777977, 26.181928887963295, 17.195416800677776, 11.583396289497614, 10.741976089775562, 13.17600293084979, 14.839447271078825, 22.288521006703377, 10.123919304460287, 4.240590976551175, 3.997073918581009, 1.1505086766555905, 0.20598080183845013, 0.14706160873174667, 0.5652887793257833, 4.617325561121106, 14.776556845754385, 34.39812161028385, 37.11671993136406, 35.747026428580284, 19.468713216483593, 26.442399211227894, 35.99462874233723, 42.50042304396629, 38.08075860142708, 11.078577227890491, 1.6816666186787188, 0.0156802018682356, 0.024575954994361382, 0.015730228187749162, 0.02753756765741855, 0.07009801513049752, 0.09015436313347891, 0.026879110118898097, 0.011560105958778877, 0.03876480368489865, 0.044664996457868256, 0.033336787528241985, 0.06810503691667691, 0.04691853901022114, 0.11232348682824522, 0.04291347970138304, 0.09332483285106719, 0.010192411282332614, 0.011933860805584118, 0.03564836231817026, 0.03256056043028366, 0.025553361629135907, 0.059318164276191965, 0.04870948978350498, 0.058619669725885615, 0.057625800400273874, 0.028098006041545887, 0.0788571240263991, 0.03557169475243427, 0.05991662845190149, 0.04037350896396674, 0.07157200947403908, 0.01806419913918944, 0.027441925230959896, 0.03934510750696063, 0.0510805662634084, 0.025956574172596447, 0.06312121098744683, 0.06245634314836934, 0.05894961745070759, 0.03477690654108301, 0.026308806736778934, 0.05265159270493314, 0.05084971751784906, 0.07562982063973323, 0.10806788588524796, 0.06804542019381188, 0.023467874707421288, 0.06682417908450589, 0.047269222341128625, 0.03399574416107498, 0.023421726109518204, 0.5092505738139153, 5.526196891441941, 28.66842806339264, 59.438675343990326, 51.99417941272259, 38.53546120226383, 28.11684776097536, 22.891130670905113, 21.240569539368153, 42.7888123691082, 32.52226486802101, 16.9030224904418, 4.448509169742465, 0.3414641349809244, 0.1933952685794793, 0.7201370608527213, 1.535570276901126, 5.465833330526948, 9.674688410013914, 7.784335445612669, 12.490882594138384, 11.975311059504747, 9.855561554431915, 9.786810893565416, 11.154210269451141, 9.498204980045557, 16.98951154947281, 34.79396536946297, 41.3602714240551, 55.163976922631264, 57.30003610253334, 59.66397665441036, 56.20412930846214, 55.72546899318695, 50.63053898513317, 50.58166980743408, 51.489577889442444, 60.691114738583565, 60.56167848408222, 56.63469560444355, 55.164835676550865, 57.30287455022335, 53.91076996922493, 53.95648151636124, 55.69356590509415, 54.49503041803837, 56.650666147470474, 48.484216555953026, 41.035738438367844, 45.96272885799408, 55.91786026954651, 56.74086570739746, 51.16000637412071, 43.21829952299595, 41.64628207683563, 40.13396702706814, 41.2034310400486, 43.987309858202934, 46.44821360707283, 48.76512788236141, 57.55311772227287, 48.98051172494888, 27.308804020285606, 33.806326165795326, 53.03561992943287, 51.67835555970669, 55.78310050070286, 56.43960267305374, 57.270686477422714, 54.40608859062195, 56.90403655171394, 54.029669389128685, 55.17377279698849, 51.954577937722206, 48.17462436854839, 43.65432232618332, 50.48287510871887, 56.81331641972065, 57.03248865902424, 54.10326763987541, 53.86048346757889, 56.68775975704193, 57.556035965681076, 55.156681314110756, 48.4502387791872, 45.005708411335945, 45.90763181447983, 46.51986636221409, 49.72495637834072, 50.04961855709553, 53.87952044606209, 54.39709447324276, 57.74919480085373, 57.72282041609287, 60.80383948981762, 55.4937232285738, 49.45452108979225, 36.84907749295235, 33.20080205798149, 22.536239214241505, 14.716966543346643, 11.762525327503681, 10.265413261950016, 13.965208232402802, 10.982869863510132, 14.20911144465208, 6.671119155362248, 6.208735266700387, 5.278369914740324, 1.3406819407828152, 0.21615195058984682, 0.16164783854037523, 0.6410643132403493, 5.9135006088763475, 16.968283988535404, 36.59353740513325, 33.42696592211723, 39.430062398314476, 25.742028392851353, 33.07624854147434, 42.266116216778755, 47.41957068443298, 45.80563388764858, 14.02957297861576, 2.2943033510819077, 0.012353793008514913, 0.029890196201449726, 0.04780874514835887, 0.042157498392043635, 0.038968248627497815, 0.04321460241044406, 0.057138840202242136, 0.04663784020522144, 0.01301276726735523, 0.03701818881381769, 0.041948973448597826, 0.06874838247313164, 0.03964771080063656, 0.08159629462170415, 0.06853237297036685, 0.08660100458655506, 0.011742410824808758, 0.009410338843736099, 0.08669604401802644, 0.051343308805371635, 0.015061506746860687, 0.027674735101754777, 0.004314802527005668, 0.03409179662412498, 0.03606373866205104, 0.029832360633008648, 0.1211886783130467, 0.27175963623449206, 0.1371514584752731, 0.1859519281424582, 0.12325093601248227, 0.11912946341908537, 0.09535099990898743, 0.18348706274991855, 0.14570384955732152, 0.1916133423219435, 0.155511197517626, 0.20532428316073492, 0.10019861947512254, 0.1494810843723826, 0.10332965888665058, 0.13476339052431285, 0.17785350879421458, 0.15685387625126168, 0.16271776315988973, 0.1919571793405339, 0.099118082143832, 0.09229827934177592, 0.14020875067217276, 0.13409422565018758, 0.15185704047325999, 0.726000324357301, 8.455876260995865, 37.04753324389458, 66.12149834632874, 58.92067573964596, 43.871176689863205, 36.90706618130207, 29.85378585755825, 30.3134585916996, 53.75399798154831, 37.28579945862293, 19.90020666271448, 5.189118403941393, 0.7978935353457928, 0.3845947002992034, 1.2002121470868587, 1.981067277956754, 7.476405669003725, 12.09096260368824, 15.738249141722918, 16.954874508082867, 26.877150982618332, 17.588082030415535, 14.558307006955147, 11.335668582469225, 14.697786122560501, 30.038841627538204, 38.16549025475979, 43.673511296510696, 56.67549401521683, 57.627741917967796, 62.51889266073704, 59.09109279513359, 59.4277623295784, 51.16261683404446, 52.44137741625309, 52.2096848487854, 61.72924563288689, 61.40343211591244, 57.77315631508827, 55.79104967415333, 58.29036556184292, 53.02233584225178, 52.48524986207485, 56.15690544247627, 55.764188915491104, 58.27159836888313, 51.684758216142654, 44.65664014220238, 47.56867088377476, 57.63153411448002, 58.849646151065826, 52.2523033618927, 46.3894459605217, 42.747671976685524, 42.027238234877586, 43.75190868973732, 47.03834854066372, 48.183705881237984, 51.86961829662323, 61.39883816242218, 52.48390473425388, 31.94950260221958, 37.34707497060299, 56.41678489744663, 53.240322545170784, 55.44140003621578, 57.0656418800354, 57.84589201211929, 57.29641489684582, 57.887355387210846, 55.23427315056324, 59.81500335037708, 56.004552617669106, 50.853488221764565, 46.16285651922226, 52.49559670686722, 61.190662533044815, 60.5049779266119, 53.37425395846367, 52.9733906686306, 59.56903874874115, 58.783419504761696, 58.20506773889065, 52.84062959253788, 48.936035111546516, 48.9111502468586, 49.458537474274635, 51.89370900392532, 52.91007846593857, 55.137651935219765, 56.965137273073196, 59.8291651904583, 60.036166682839394, 60.34608565270901, 61.26513473689556, 50.081335455179214, 41.7338939756155, 37.41124592721462, 28.10792963951826, 22.68123183399439, 21.778842955827713, 19.206390492618084, 22.14216995984316, 25.55201578885317, 33.03733862936497, 18.381509855389595, 13.651422020047903, 9.069967959076166, 3.2342304149642587, 0.6224826571997255, 0.5250792775768787, 0.9305150283034891, 6.4317467249929905, 19.33015175163746, 44.153695330023766, 50.36687113344669, 48.24642911553383, 33.38353805243969, 38.50296534597874, 47.75292679667473, 55.18283911049366, 55.310124680399895, 17.769489996135235, 3.418814060278237, 0.18804781255312264, 0.14992741198511794, 0.11075900241849013, 0.3513152844971046, 0.21130467241164297, 0.24040981923462823, 0.23939849459566176, 0.14845294266706333, 0.13934239716036245, 0.12295651860767975, 0.07885051891207695, 0.34977152827195823, 0.21407030057162046, 0.18638307141372934, 0.15017349331174046, 0.16120539978146553, 0.10079142477479763, 0.08325728791533038, 0.14081008324865252, 0.13339740835363045, 0.0928658813063521, 0.1496337293065153, 0.1428246876457706, 0.09078925562789664, 0.1704474538564682, 0.10060916814836673], [0.10032079924712889, 0.006496161477116402, 0.06831778096966445, 0.06233273845282383, 0.033515993927721865, 0.00545584205610794, 0.05908361963520292, 0.08831039333017543, 0.014263027278502705, 0.06614049038034864, 0.045001638354733586, 0.033263674849877134, 0.028749552329827566, 0.03525104242726229, 0.022499418373627122, 0.005309923762979452, 0.011233410696149804, 0.02146458991774125, 0.033255963935516775, 0.016968509007710963, 0.02103480106597999, 0.047796477447263896, 0.016441439438494854, 0.05566155072301626, 0.008694865809957264, 0.207525686128065, 6.771658910438418, 30.81921335309744, 48.24971213936806, 42.41148881614208, 36.569404900074005, 29.42493326961994, 27.130428291857243, 41.66499227285385, 43.88207830488682, 31.14736944437027, 12.931945826858282, 2.513813772238791, 0.15222428482957184, 0.1699812663719058, 0.43159503140486777, 0.8637472079135478, 3.9182920334860682, 10.951437000185251, 7.289160741493106, 14.224940445274115, 8.751247711479664, 11.569271497428417, 9.197275377810001, 9.151512533426285, 6.816493654623628, 16.633375659585, 37.769775688648224, 46.43611125648022, 53.763581067323685, 56.43806375563145, 59.061682373285294, 55.24400442838669, 54.90008108317852, 52.82017149031162, 49.509678930044174, 49.35122363269329, 52.48534485697746, 55.53578697144985, 56.524011343717575, 55.48679240047932, 55.51366835832596, 55.74854515492916, 55.34786805510521, 57.203483283519745, 55.30062898993492, 53.176926746964455, 54.01367224752903, 49.09593053162098, 41.361931934952736, 39.14625182747841, 37.9898826777935, 40.141331031918526, 39.32489164173603, 37.72295840084553, 40.55319473147392, 41.47386632859707, 39.59757640957832, 39.62273485958576, 43.42839404940605, 48.121484220027924, 54.522366151213646, 28.086776174604893, 38.80380280315876, 58.95697519183159, 52.481883242726326, 55.11002741754055, 54.19784836471081, 54.35986027121544, 54.737867787480354, 54.24970418214798, 55.18296830356121, 55.00036150217056, 52.81059980392456, 48.85148964822292, 40.52372731268406, 46.17158465087414, 52.95644737780094, 55.87141536176205, 53.097476810216904, 54.05690252780914, 53.78853812813759, 56.16528779268265, 54.61840219795704, 50.53444594144821, 46.41186095774174, 44.24051307141781, 43.73943775892258, 44.05524641275406, 44.31049391627312, 45.9609467536211, 50.58153681457043, 51.288918256759644, 52.393241599202156, 54.90798465907574, 56.566800847649574, 48.02194096148014, 35.421505495905876, 31.98681280016899, 24.606060348451138, 15.25826744735241, 8.504307512193918, 9.720437955111265, 12.708441819995642, 6.639561848714948, 6.071773041039705, 3.3224528934806585, 4.535323111340404, 4.056264292448759, 0.6002887012436986, 0.28281389619223773, 0.039660902475588955, 0.4762250615749508, 3.2958723697811365, 13.124796878546476, 24.338832087814808, 32.63823464512825, 25.88492352515459, 20.11848594993353, 25.520422384142876, 43.44638228416443, 44.75622899830341, 40.731724351644516, 14.336698148399591, 1.7937673721462488, 0.006966008213566965, 0.05319272226188332, 0.011904000493814237, 0.030158983536239248, 0.07232131887576543, 0.021735162117693108, 0.004253386096024769, 0.03709733144205529, 0.01353503421341884, 0.03173291734128725, 0.027935791113122832, 0.04407959037052933, 0.048914994185906835, 0.03289713553385809, 0.10132120689377189, 0.022964889685681555, 0.003182354284945177, 0.02784758686175337, 0.03884879253746476, 0.05457315033709165, 0.059455840091686696, 0.030248386356106494, 0.07639094503247179, 0.031830917941988446, 0.04645366883778479, 0.033130719093605876, 0.11670972060528584, 0.015309543632611167, 0.018925229596788995, 0.018800934703904204, 0.12461232428904623, 0.009874607876554364, 0.038406394596677274, 0.05917403548664879, 0.03173029013851192, 0.054661811009282246, 0.03433309480897151, 0.014080753026064485, 0.04657944431528449, 0.02919683731306577, 0.03499090482364409, 0.0624913428328, 0.02367423257965129, 0.042954557575285435, 0.014627598047809443, 0.015340479130827589, 0.06139662305940874, 0.036207722732797265, 0.0605848322447855, 0.061768546656821854, 0.07213536635390483, 0.3393689333461225, 8.898594304919243, 36.64944760501385, 55.171215534210205, 48.9746106415987, 40.851201340556145, 33.443989008665085, 27.337368987500668, 37.82619886100292, 42.31309689581394, 31.234453171491623, 14.080846477299929, 3.0835855985060334, 0.1580969587666914, 0.2500631270231679, 0.7818146981298923, 3.018718804232776, 5.184196243062615, 8.376022595912218, 11.115286108106375, 11.159254498779774, 12.24958224222064, 13.2499935105443, 9.487713743001223, 8.047725912183523, 14.38365887850523, 19.657019712030888, 35.3955452889204, 44.53099228441715, 54.45052720606327, 58.04104574024677, 60.857173427939415, 57.78002254664898, 57.18801811337471, 53.7632504850626, 50.579484924674034, 51.31494306027889, 56.338110119104385, 58.30496817827225, 57.99907699227333, 56.42459727823734, 56.63346827030182, 57.88562647998333, 55.61149790883064, 57.6942877471447, 55.73493808507919, 54.15447749197483, 55.694181472063065, 50.48186436295509, 43.402756825089455, 41.417686343193054, 41.815430000424385, 41.455479115247726, 41.886193603277206, 40.29121778905392, 42.09428183734417, 43.538424745202065, 41.60194605588913, 43.23527701199055, 46.033462062478065, 51.33480839431286, 55.648029148578644, 30.82594659179449, 40.21182104945183, 59.06092241406441, 51.93186655640602, 56.470175832509995, 56.08340598642826, 55.436806082725525, 56.24596506357193, 55.326649993658066, 57.656099796295166, 58.04742559790611, 55.735325664281845, 51.38455532491207, 42.5005978345871, 47.11972497403622, 55.12890860438347, 57.666268050670624, 53.645946979522705, 55.363120436668396, 56.08878269791603, 57.27346032857895, 56.415166184306145, 53.36996018886566, 48.35055872797966, 46.30023054778576, 46.65667422115803, 47.297855615615845, 47.286038249731064, 48.50019849836826, 51.784958839416504, 52.19771549105644, 55.36351181566715, 56.91838838160038, 56.94188632071018, 48.95624242722988, 38.65782983601093, 29.994021132588387, 18.681684248149395, 15.427875146269798, 9.312909822911024, 16.686582304537296, 14.19393315911293, 15.16593525186181, 12.185018006712198, 8.885537255555391, 7.295380057767034, 5.365852145478129, 2.0948273548856378, 0.44245478929951787, 0.09882268510409631, 0.5438677850179374, 4.525038488209248, 12.74340184405446, 26.98712658137083, 36.686267629265785, 31.332339718937874, 25.314908511936665, 30.010312758386135, 48.54794293642044, 50.82313545048237, 46.97130113840103, 18.753112815320492, 2.4307198310270905, 0.025624106856412254, 0.011115835022792453, 0.014604698153561912, 0.012999572809349047, 0.06041699554771185, 0.019908966751245316, 0.022754422170692123, 0.05222021936788224, 0.03450364776654169, 0.05676651584508363, 0.061306901116040535, 0.05649369122693315, 0.01896965641208226, 0.041526238710503094, 0.05365366276237182, 0.03947276432882063, 0.05698560897144489, 0.0058158745923719835, 0.012795700204151217, 0.017774340376490727, 0.0708312941424083, 0.021821115806233138, 0.043573260118137114, 0.018807203996402677, 0.022934122098376974, 0.043230091032455675, 0.25497498689219356, 0.12956549209775403, 0.119971400272334, 0.08961748608271591, 0.17986928578466177, 0.09634889909648336, 0.12615079642273486, 0.21949317364487797, 0.16648199554765597, 0.12518223433289677, 0.14729765622178093, 0.16421761392848566, 0.18368704186286777, 0.09877871285425499, 0.1018761181330774, 0.07953828200697899, 0.10893276252318174, 0.16063235787441954, 0.20863395009655505, 0.13039083452895284, 0.11555341741768643, 0.11643925972748548, 0.10902699301368557, 0.18235562893096358, 0.11020524892956018, 0.5651585175655782, 12.46740935370326, 43.09120014309883, 63.69274087250233, 53.82013343274593, 47.63954468071461, 40.32890036702156, 40.354757979512215, 53.14344294369221, 54.96095761656761, 37.33479402959347, 16.66998479515314, 3.4297854965552688, 0.5696583073586226, 0.31537316157482564, 1.0615455941297114, 3.9568685134872794, 11.198121663182974, 21.419425942003727, 19.7784972935915, 25.891065895557404, 17.996734902262688, 23.58761429786682, 17.061627879738808, 19.71121620386839, 13.25082566589117, 20.361194126307964, 40.996277555823326, 49.477874636650085, 54.15546923875809, 58.807533010840416, 60.91342180967331, 60.2465233951807, 60.31744658946991, 56.50039181113243, 52.78557054698467, 53.244623914361, 57.73711904883385, 59.96513709425926, 60.670679435133934, 59.68718200922012, 59.110699743032455, 60.20567178726196, 55.3709252178669, 57.62374073266983, 57.24124565720558, 55.8508812636137, 59.14055094122887, 53.859134539961815, 45.88618956506252, 43.49001154303551, 42.028153985738754, 44.46919620037079, 43.33326615393162, 42.15448960661888, 43.772940561175346, 45.53358368575573, 43.89320030808449, 44.56506505608559, 46.77931644022465, 53.30972582101822, 59.30761277675629, 35.226693749427795, 42.102519795298576, 56.81945689022541, 54.212302789092064, 57.5697760283947, 58.370104283094406, 55.83854332566261, 57.077257856726646, 56.456705555319786, 59.27254445850849, 59.66882139444351, 57.426189333200455, 53.33555303514004, 45.357197150588036, 50.666044279932976, 57.355486527085304, 59.34571713209152, 53.53260666131973, 55.31227916479111, 54.910298734903336, 58.52843798696995, 57.11103044450283, 56.035783141851425, 50.139270946383476, 48.49502697587013, 49.18668106198311, 48.79489168524742, 48.84129099547863, 50.30191361904144, 54.64973531663418, 54.773061498999596, 57.115039229393005, 58.65864560008049, 61.50348074734211, 50.811796858906746, 41.837981790304184, 34.57370638847351, 27.59437009692192, 21.576538011431694, 11.963970568031073, 20.858709029853344, 24.11123190075159, 20.212553702294827, 15.066742524504662, 13.380579203367233, 11.43605349585414, 9.337732940912247, 3.2452752348035574, 0.7130708056502044, 0.3258731559617445, 0.745221592951566, 5.007933676242828, 17.062439136207104, 32.887132689356804, 43.22929993271828, 37.5668665766716, 30.03168661147356, 36.52991361916065, 54.42707486450672, 57.609073519706726, 54.35543730854988, 24.336970187723637, 4.018167536705732, 0.26780654210597277, 0.12870391801698133, 0.14072387537453324, 0.1296770220506005, 0.14401780877960846, 0.09626301034586504, 0.14566641562851146, 0.157186180294957, 0.11748051518225111, 0.1012551409075968, 0.19217295135604218, 0.13471773359924555, 0.09982711519114673, 0.12014630963676609, 0.11266473375144415, 0.12781259865732864, 0.1239214590168558, 0.08086855945293792, 0.07497906102798879, 0.17214907973539084, 0.29257871909067035, 0.09677764523075894, 0.15785926370881498, 0.19638379337266088, 0.07920566626125947, 0.14829473162535578], [0.04763538687257096, 0.021766536410723347, 0.04305304799345322, 0.04107623375602998, 0.041314225672977045, 0.01226132419105852, 0.012625339277292369, 0.04062082225573249, 0.05196420068386942, 0.02143012643500697, 0.06635911966441199, 0.06159548524010461, 0.01032249492709525, 0.1181640406139195, 0.024304878133989405, 0.04868687283305917, 0.047635390583309345, 0.033732793817762285, 0.055381178462994285, 0.08407192115555517, 0.02107078966218978, 0.03795890181208961, 0.06828783531091176, 0.021858006111870054, 0.04215666718664579, 0.7738966948818415, 11.194704696536064, 36.05103671550751, 47.34613962471485, 42.17956066131592, 25.70119198411703, 21.257068254053593, 38.364447578787804, 48.55407200753689, 48.077186197042465, 32.67937123775482, 9.204771425575018, 1.8063692771829665, 0.14338205539388582, 0.47921131539624184, 3.0493805464357138, 4.076628349721432, 1.931233664508909, 5.3487378638237715, 5.638188282027841, 7.657795110717416, 10.950892679393291, 6.078783189877868, 8.881307132542133, 11.476086247712374, 20.724866911768913, 22.1751768887043, 36.98948755860329, 43.70722308754921, 55.8625428378582, 53.900955095887184, 56.008872985839844, 55.48311799764633, 54.538272097706795, 54.182109609246254, 53.31393599510193, 49.75293047726154, 49.13656175136566, 49.086647629737854, 49.7332589328289, 48.54458771646023, 50.66928170621395, 53.62809173762798, 54.197863563895226, 54.73316363990307, 55.87848298251629, 52.57596239447594, 54.88614723086357, 52.647007182240486, 48.91402669250965, 40.12037895619869, 37.86053001880646, 35.87341904640198, 38.30443359911442, 46.25101558864117, 50.79644948244095, 47.338726222515106, 44.76461514830589, 39.17101889848709, 43.20955999195576, 45.01209206879139, 56.78511433303356, 29.53413560986519, 44.99824561178684, 54.397998824715614, 55.058433786034584, 53.81603725254536, 48.625428378582, 53.35699148476124, 52.395582273602486, 54.02331233024597, 54.86502796411514, 56.009423956274986, 53.45252975821495, 53.888461366295815, 41.780270487070084, 44.88314978778362, 53.251839727163315, 54.382495656609535, 54.158493876457214, 51.55803881585598, 50.7345812022686, 52.22284734249115, 56.06361284852028, 54.149438962340355, 51.26777999103069, 49.5163057744503, 48.229987397789955, 46.59853354096413, 44.32976648211479, 46.63875438272953, 46.71849690377712, 50.494472086429596, 52.51317836344242, 57.80056804418564, 55.11351563036442, 52.25282393395901, 40.12815333902836, 35.582434460520744, 15.07093844935298, 16.700901836156845, 15.419895574450493, 14.71646687015891, 10.337789878249168, 11.388535145670176, 12.286657802760601, 3.9427173603326082, 3.8560891337692738, 5.285420911386609, 1.1952701560221612, 0.3937981923809275, 0.09667300982982852, 0.18488043016986921, 1.8704819306731224, 9.699883908033371, 26.885666325688362, 33.19679707288742, 38.168248906731606, 27.004917226731777, 28.03172092884779, 39.95665334165096, 38.96811358630657, 42.605848386883736, 21.285205744206905, 2.4363898392766714, 0.25987541768699884, 0.012662673016166082, 0.03501110608340241, 0.044966015266254544, 0.0325037378934212, 0.03216502911527641, 0.07111068305675872, 0.043325097067281604, 0.038833259386592545, 0.05533295370696578, 0.05530001348233782, 0.038382170896511525, 0.03222429702873342, 0.03364428899658378, 0.017475531312811654, 0.053017289683339186, 0.034594174940139055, 0.09910001084790565, 0.018951529455080163, 0.025508444996376056, 0.029682482054340653, 0.014264100609580055, 0.028108689257351216, 0.02784606174827786, 0.0722257154120598, 0.007384457976513659, 0.05896149181353394, 0.04342045562225394, 0.050137036814703606, 0.028157674714748282, 0.028150678117526695, 0.04027801311167423, 0.030433481697400566, 0.03166689959471114, 0.04003796915640123, 0.06673350348137319, 0.03125838440610096, 0.01997363749978831, 0.03653124345873948, 0.06134647243015934, 0.030095531765255146, 0.07395278211333789, 0.01301408643485047, 0.027608472446445376, 0.036220665788277984, 0.032828215989866294, 0.032103122866828926, 0.01891055919259088, 0.039808088913559914, 0.08820520131848752, 0.01699208703939803, 1.0410309699364007, 14.389095436781645, 40.09786516427994, 54.369367361068726, 44.69825930893421, 31.121114753186703, 25.40759313851595, 36.92911259829998, 46.59711241722107, 48.348085060715675, 33.388181403279305, 11.31218109279871, 1.7378970701247454, 0.09914625406963751, 0.3549400228075683, 2.1700925286859274, 7.696545906364918, 10.511963982135057, 9.347276128828526, 9.298119116574526, 10.751405283808708, 9.648222830146551, 13.943712785840034, 7.853542556986213, 8.555959090590477, 13.35419436916709, 25.2241712808609, 37.73582451045513, 47.08447426557541, 54.22060914337635, 55.37206135690212, 55.51033213734627, 57.18782812356949, 56.89864844083786, 56.825232580304146, 54.46047507226467, 52.23746135830879, 51.334436014294624, 51.12404130399227, 51.29455715417862, 52.10248500108719, 53.60248491168022, 54.49352569878101, 56.208065897226334, 56.665219366550446, 57.25556328892708, 53.448965549468994, 56.42951041460037, 55.728045254945755, 50.840701907873154, 41.87323249876499, 39.23085808753967, 38.08906115591526, 38.60085569322109, 46.27472631633282, 51.703650802373886, 48.35354916751385, 47.005845084786415, 42.83407934010029, 46.09015882015228, 46.13475322723389, 57.86812461912632, 33.17818187177181, 44.49599616229534, 55.365856289863586, 57.3498248308897, 56.44530616700649, 52.25289233028889, 55.92549405992031, 54.19577367603779, 55.60712434351444, 55.525747910141945, 57.55630575120449, 55.05580812692642, 55.363135635852814, 42.94363886117935, 47.45532676577568, 55.56865520775318, 55.23614265024662, 54.187710508704185, 52.684419974684715, 51.60879269242287, 53.67782346904278, 56.38971894979477, 55.72375528514385, 52.994825318455696, 51.37315973639488, 48.48426595330238, 47.928553372621536, 47.16518573462963, 48.42681683599949, 48.86908270418644, 53.20665255188942, 55.4205771535635, 59.38629515469074, 57.13031440973282, 53.72855454683304, 40.723509192466736, 37.810653895139694, 19.173032082617283, 11.136831901967525, 6.063079107552767, 13.516051433980465, 17.892261408269405, 11.313833054155111, 11.363363396376371, 8.639069180935621, 8.348247036337852, 5.363869601860642, 3.005784535780549, 0.3580465936101973, 0.0706698399153538, 0.35077327920589596, 2.112423023208976, 11.113172471523285, 26.607430055737495, 35.62613591551781, 33.89391906559467, 26.160834319889545, 30.468953847885132, 46.30053833127022, 47.17327170073986, 46.85046002268791, 25.298633985221386, 3.800939368084073, 0.32625450112391263, 0.01596924426849, 0.030462362374237273, 0.018030984319921117, 0.0067572012540040305, 0.05044431934948079, 0.029070226919429842, 0.01038650701957522, 0.016960859320533928, 0.024427473508694675, 0.04254950079484843, 0.0803062118939124, 0.0915245087526273, 0.014388258205144666, 0.03325240162666887, 0.03443402318225708, 0.021481535004568286, 0.031358151318272576, 0.03741900422028266, 0.02535393912694417, 0.05710092758818064, 0.04729923479317222, 0.14597462955862284, 0.033754620380932465, 0.06574362691026181, 0.06524301861645654, 0.07980652386322618, 0.1743728361907415, 0.16501045029144734, 0.15259673906257376, 0.11801993037806824, 0.15969854313880205, 0.10656733749783598, 0.13499462889740244, 0.13572902855230495, 0.15082196710864082, 0.16848015395225957, 0.10680043866159394, 0.07401188675430603, 0.1974760863231495, 0.09317834774265066, 0.2341600155341439, 0.1494361399090849, 0.08192315872292966, 0.12826918275095522, 0.13556632009567693, 0.17204921634402126, 0.16735038254410028, 0.1866614806931466, 0.1371377584291622, 0.0993822496093344, 1.9030262343585491, 17.92516954243183, 49.221578389406204, 61.818324252963066, 53.00616770982742, 36.35350048542023, 31.45921491086483, 49.464316964149475, 59.835301861166954, 53.3115953207016, 36.5935830026865, 11.609171256422997, 2.7347557665780187, 0.2048018408822827, 1.192742104176432, 4.7689758986234665, 9.106933325529099, 8.609666358679533, 18.027463853359222, 14.512118585407734, 16.495002284646034, 16.989120170474052, 14.847090560942888, 18.478129170835018, 21.036248803138733, 26.233904398977757, 26.654900908470154, 38.409535959362984, 44.790959134697914, 56.26627117395401, 55.31092643737793, 56.47124357521534, 58.788830414414406, 58.35354097187519, 59.473207890987396, 58.4508765488863, 54.40944001078606, 53.558034896850586, 53.15693981945515, 54.03430134057999, 53.09748061001301, 54.92858715355396, 57.205284386873245, 58.46349947154522, 58.120043501257896, 58.158562034368515, 53.52138966321945, 58.5065283626318, 57.79117874801159, 53.62073913216591, 44.11086402833462, 41.718375608325005, 38.83434176445007, 41.56806707382202, 50.7326091080904, 56.24697960913181, 52.26064391434193, 50.48016205430031, 44.78807508945465, 48.496444299817085, 49.2912932485342, 59.795385003089905, 38.22814129292965, 47.326882258057594, 57.13064879179001, 61.2384145706892, 58.828378692269325, 54.7583144903183, 58.72848205268383, 56.81083135306835, 57.46578700840473, 57.84125246107578, 58.43113660812378, 56.40070416033268, 58.335784524679184, 46.71353816986084, 47.966197952628136, 58.80955070257187, 56.70605577528477, 54.77231293916702, 52.5840749591589, 50.9811157733202, 53.65531347692013, 60.120495557785034, 57.45823681354523, 56.469875648617744, 54.65747930109501, 52.19171181321144, 50.24395152926445, 49.063898250460625, 51.07674904167652, 51.6849672049284, 54.9085546284914, 56.90217465162277, 62.31515519320965, 59.87352021038532, 56.07943519949913, 42.65464536845684, 41.78858444094658, 20.680568888783455, 21.67221687734127, 25.574730969965458, 25.317011699080467, 19.918103702366352, 18.55600979179144, 22.91684579104185, 14.075053688138723, 14.475060123950243, 12.488353829830885, 4.450907316058874, 1.514861744362861, 0.21064549684524536, 0.6196360161993653, 2.672918834723532, 13.398405946791172, 34.796758219599724, 44.914304316043854, 49.34510216116905, 39.84104074537754, 38.6830148845911, 51.46193817257881, 51.7433662712574, 55.48933446407318, 30.841704346239567, 5.243678251281381, 0.5070567852817476, 0.1291052417946048, 0.17824965238105506, 0.21391772985225543, 0.11085901423939504, 0.119370075117331, 0.11879321857122704, 0.07662867719773203, 0.11819543346064165, 0.10299251604010351, 0.10055418984848075, 0.23036767059238628, 0.2116305791423656, 0.14710070507135242, 0.18162216438213363, 0.1275800689472817, 0.07814653246896341, 0.2017684606835246, 0.12974170764209703, 0.18695630627917126, 0.22302904719254002, 0.12366844603093341, 0.20840818877331913, 0.1343920940416865, 0.2147601416800171, 0.14089065080042928], [0.032462463350384496, 0.07133711231290363, 0.09243028514902107, 0.0496309032314457, 0.03713327365403529, 0.05173360797925852, 0.0839132945111487, 0.03769419628952164, 0.07281005280674435, 0.12411216870532371, 0.027163243212271482, 0.04626773115887772, 0.02689261906198226, 0.056073602245305665, 0.03993477352196351, 0.004056302750541363, 0.1004703865328338, 0.01828635919082444, 0.11981349351117387, 0.03690111501782667, 0.02410623859759653, 0.05359343747841194, 0.04314298144890927, 0.06327886541839689, 0.03836677875369787, 0.9724654897581786, 12.942856941372156, 38.9151406288147, 47.652285397052765, 38.53833764791489, 26.77599661052227, 39.54008549451828, 59.122361317276955, 61.10801316797733, 50.42943477630615, 19.90920078009367, 6.313657611608505, 0.8001044823322445, 0.13064438186120242, 0.6255026045255363, 1.0779952676966786, 8.028991017490625, 10.580602549016476, 6.5070544090121984, 8.062233533710241, 8.537234645336866, 8.47293259575963, 15.277603659778833, 3.2916453341022134, 3.714245595037937, 18.787044994533062, 32.75375224649906, 43.10460962355137, 49.614948481321335, 52.043124586343765, 55.22988438606262, 54.32195730507374, 52.53085881471634, 54.43240977823734, 56.068575382232666, 53.17263297736645, 53.19718345999718, 51.76464132964611, 51.3299560546875, 49.35391008853912, 45.179989859461784, 44.62420508265495, 43.82989950478077, 50.35002663731575, 52.49835155904293, 55.136109218001366, 52.97521837055683, 53.41574773192406, 52.608606442809105, 49.96782414615154, 40.45197956264019, 39.299136623740196, 36.35530538856983, 44.42858777940273, 49.998659491539, 55.88158741593361, 54.94626000523567, 48.651285991072655, 42.459951415658, 42.4574663490057, 45.96007660031319, 57.26365305483341, 37.5279338657856, 47.02895924448967, 59.08524490892887, 49.281432777643204, 49.54054467380047, 46.856661289930344, 46.70495443046093, 47.6188737899065, 52.528290152549744, 52.57231839001179, 52.80582346022129, 54.36307869851589, 54.99616652727127, 40.35894155502319, 44.108511954545975, 52.97362245619297, 53.782804235816, 56.38714648783207, 53.399188220500946, 52.95397751033306, 53.06846156716347, 54.31593082845211, 55.53796045482159, 52.29919284582138, 51.43291912972927, 51.86706863343716, 53.01787868142128, 51.91859006881714, 52.600588873028755, 53.977634981274605, 53.66366162896156, 53.19140397012234, 52.582323253154755, 54.903713688254356, 51.02654233574867, 40.76706625521183, 29.806299805641174, 18.800131492316723, 12.783484943211079, 1.9812737731263041, 13.377840500324965, 17.24466785788536, 14.737429395318031, 9.541986230760813, 6.281645279377699, 6.269854987040162, 2.9557568952441216, 3.2244734885171056, 0.7054416462779045, 0.09336833012639545, 0.08228905237047002, 1.9268807605840266, 7.290702508762479, 23.532061278820038, 49.56954851746559, 63.442360907793045, 58.867592588067055, 40.27023911476135, 34.21776048839092, 37.117753475904465, 41.859910413622856, 22.852201759815216, 4.216808527708054, 0.16068325436208397, 0.04955749369401019, 0.015843413129914552, 0.05298293195664883, 0.0867697095964104, 0.018608167411002796, 0.07853070521377958, 0.04240077811118681, 0.04866651201155037, 0.014385004815267166, 0.00990328724583378, 0.04446572609595023, 0.020737500417453703, 0.02870635005820077, 0.08252904808614403, 0.03918408001482021, 0.0788895039295312, 0.06434208844439127, 0.11578972465940751, 0.04020151995064225, 0.039957483240868896, 0.07000243393122219, 0.07749945390969515, 0.004740437207146897, 0.03476926984149031, 0.07706188363954425, 0.01889820799988229, 0.03488523041596636, 0.031246235448634252, 0.024220529339800123, 0.06044791341992095, 0.07027494313661009, 0.0632029288681224, 0.04356159355666023, 0.039941393479239196, 0.0651215884136036, 0.016400561944465153, 0.06886924122227356, 0.02805187599733472, 0.047778951629879884, 0.04575152292090934, 0.03353337131557055, 0.05428790958831087, 0.07548879031674005, 0.03004473175678868, 0.044517865680973046, 0.03473817014310043, 0.06660747196292505, 0.06181527227454353, 0.06640853185672313, 0.09280055746785365, 1.376897559966892, 17.358175367116928, 45.07301039993763, 53.3561897277832, 44.628932029008865, 29.836014211177826, 38.53225037455559, 58.151889592409134, 62.89816550910473, 51.945435628294945, 24.992552809417248, 7.032740525901318, 1.2022639182396233, 0.14935621060431004, 0.6872704869601876, 2.0966317830607295, 4.775952324271202, 8.306644018739462, 8.695310913026333, 11.822968684136868, 14.71460497006774, 15.302272886037827, 13.674827814102173, 7.973825577646494, 9.458785895258188, 18.438622690737247, 34.00059454143047, 44.45905074477196, 50.14839805662632, 53.973390609025955, 55.50253875553608, 55.70639781653881, 54.382564052939415, 55.09259395301342, 57.802186757326126, 55.003777518868446, 54.71864461898804, 53.511745780706406, 52.69428424537182, 50.372833013534546, 47.3409491032362, 45.23216865956783, 47.69822873175144, 54.038716703653336, 54.13279965519905, 57.2040456533432, 54.53070290386677, 55.64620904624462, 53.74401971697807, 52.6651968061924, 43.50476235151291, 41.448745876550674, 38.17139893770218, 46.42499305307865, 54.0123575180769, 57.922796085476875, 56.583402156829834, 51.48152992129326, 44.590428695082664, 44.81351852416992, 48.9384213835001, 58.370206877589226, 39.99566964805126, 48.91685754060745, 59.194299057126045, 51.60107530653477, 52.130934074521065, 49.263562336564064, 50.30203901231289, 50.88446795940399, 55.190594494342804, 54.72962602972984, 54.0211920440197, 55.56042864918709, 56.77721455693245, 43.027120381593704, 44.59971159696579, 55.51390774548054, 58.08079160749912, 58.01685243844986, 53.07728849351406, 52.64584444463253, 52.292265817523, 55.34647352993488, 57.78306618332863, 54.01461839675903, 53.91809977591038, 54.08923499286175, 53.79845179617405, 53.154108971357346, 55.362417474389076, 55.09211517870426, 54.88139748573303, 55.39194568991661, 55.53804785013199, 56.106022372841835, 53.827714025974274, 44.1000460088253, 30.899681635200977, 17.346777878701687, 17.19706781208515, 10.434261951595545, 11.982345432043076, 16.91719003021717, 17.052688859403133, 11.400837935507298, 11.9430498406291, 9.968343302607536, 5.433435793966055, 4.162698481231928, 1.189717585220933, 0.15922024380415678, 0.35233719216194004, 1.9178110035136342, 7.346270252019167, 24.621620513498783, 49.65076915919781, 59.32243198156357, 55.57003453373909, 42.17090092599392, 38.10028575360775, 41.958678513765335, 49.26020711660385, 27.01857179403305, 5.653242599219084, 0.2533736696932465, 0.03983133668953087, 0.0129560940877127, 0.015591428018524311, 0.06099811573221814, 0.05921894284256268, 0.021440195523609873, 0.040242115428554825, 0.06188139763253275, 0.020439594918570947, 0.008814390548650408, 0.019453197164693847, 0.052719046507263556, 0.0061384309901768574, 0.015161106675805058, 0.03214958131138701, 0.04749352534417994, 0.03594105794036295, 0.0665619560459163, 0.05920686438912526, 0.02147454026271589, 0.06652472249697894, 0.04224283424264286, 0.03627118749136571, 0.030966996819188353, 0.07609193373355083, 0.11989216858637519, 0.19242873997427523, 0.17263180227018893, 0.1431988933472894, 0.1470212804269977, 0.1519639097386971, 0.22252009715884924, 0.12664190522627905, 0.11632609704975039, 0.20275651157135144, 0.13021202146774158, 0.0979207233467605, 0.15038381796330214, 0.12367631279630587, 0.16146657639183104, 0.15014247153885663, 0.2018582753953524, 0.14776923169847578, 0.16567707702051848, 0.21068926871521398, 0.06539552254253067, 0.22168403811519966, 0.13211799028795213, 0.1472728091175668, 0.18131764634745196, 2.2295168275013566, 21.590747348964214, 53.30006293952465, 63.09850595891476, 51.517293602228165, 39.32571239769459, 51.31976120173931, 67.31176927685738, 67.25534990429878, 55.720362067222595, 26.30802132189274, 8.740942664444447, 1.4569033356383443, 0.398601817432791, 1.1013033357448876, 2.8217357117682695, 13.106816243380308, 16.671573109924793, 13.726712130010128, 19.83909074217081, 21.038532480597496, 20.033243224024773, 27.715817280113697, 12.074946463108063, 9.991393815726042, 24.341070167720318, 40.12258663773537, 49.31486338376999, 52.5167615711689, 54.33034725487232, 56.416264325380325, 55.97385786473751, 52.47602395713329, 57.26200394332409, 59.44012686610222, 58.57964403927326, 58.35944205522537, 55.784023851156235, 54.78454828262329, 52.59679667651653, 49.95420567691326, 48.077246993780136, 48.69010850787163, 55.24046301841736, 56.006954088807106, 60.77873423695564, 56.62572808563709, 56.836156994104385, 56.468728110194206, 54.80794742703438, 44.48888674378395, 42.34305828809738, 39.787501618266106, 49.83579263091087, 56.086487621068954, 59.96198706328869, 58.232297077775, 55.10690778493881, 49.59956310689449, 46.889016553759575, 51.31942681968212, 60.176405757665634, 44.43611137568951, 50.426151752471924, 60.83070784807205, 53.669433519244194, 55.55772699415684, 53.02171267569065, 51.394180208444595, 52.85117022693157, 57.960577458143234, 58.484831526875496, 56.24333180487156, 58.129938170313835, 58.95084232091904, 45.758619010448456, 48.37723329663277, 57.37831190228462, 59.93582546710968, 60.01157820224762, 55.61913549900055, 53.136519715189934, 54.00160789489746, 56.46463192999363, 58.84471781551838, 56.648257076740265, 57.104190811514854, 56.4628916233778, 58.25811669230461, 55.86821973323822, 57.367870062589645, 57.920394614338875, 57.50249303877354, 58.98393474519253, 56.004697009921074, 59.04165744781494, 54.77150738239288, 45.11327683925629, 33.64515781402588, 24.11029525101185, 19.326574243605137, 9.998794868588448, 24.488139376044273, 24.107540398836136, 23.778244368731976, 19.796990901231766, 20.857612788677216, 15.550147835165262, 8.933995105326176, 8.424830976873636, 2.0717697171494365, 0.31564362987410277, 0.7438352017197758, 2.810926716774702, 8.8641064055264, 29.018026404082775, 58.85758772492409, 72.9782684147358, 66.171465665102, 52.4261250346899, 44.77816142141819, 50.86118280887604, 57.94846370816231, 33.47883313894272, 7.252643276005983, 0.41037527786102146, 0.15097756579052657, 0.21263716887915507, 0.1482083011069335, 0.15695531299570575, 0.13424378324998543, 0.14167740155244246, 0.13246607239125296, 0.15403009339934215, 0.10700792088755406, 0.09277497563743964, 0.11580280872294679, 0.18871984211727977, 0.12799638410797343, 0.12187192172859795, 0.11326340201776475, 0.13951515429653227, 0.16208137152716517, 0.1777278631925583, 0.14285524928709492, 0.1477947467355989, 0.15828148636501282, 0.19258324027759954, 0.0988886842969805, 0.11494752805447206, 0.1963035375229083], [0.0441619056800846, 0.021986470019328408, 0.018255907016282436, 0.03191997195244767, 0.001791024524209206, 0.020712187615572475, 0.021753461624030024, 0.043916811409872025, 0.030858671088935807, 0.03589439540519379, 0.015638736222172156, 0.044430051057133824, 0.03610276078688912, 0.043406874319771305, 0.019930863818444777, 0.04835221618122887, 0.040055186982499436, 0.07353733526542783, 0.06632769713178277, 0.02979076511110179, 0.03261455909523647, 0.031044966854096856, 0.05459706604597159, 0.039992965321289375, 0.04009253556432668, 1.9042104645632207, 15.14923419803381, 37.4095968157053, 47.060546949505806, 39.24328722059727, 28.18716488778591, 28.620892614126205, 29.131672605872154, 23.036102391779423, 24.208546578884125, 13.010159879922867, 6.0194251500070095, 0.7184071443043649, 0.1344960689311847, 0.22457832499640062, 1.6014273930341005, 3.310619853436947, 12.555623520165682, 8.138801325112581, 6.561785722151399, 10.17151365056634, 11.28969294950366, 13.397047519683838, 6.526379222050309, 13.076264932751656, 21.618924736976624, 40.21467089653015, 47.78764933347702, 52.177249789237976, 53.605102971196175, 56.38291731476784, 53.845611065626144, 55.51640801131725, 54.7130361199379, 54.50817011296749, 55.559543296694756, 56.329887360334396, 54.79049876332283, 53.58587220311165, 51.68921537697315, 50.77564939856529, 43.797840625047684, 37.52680912613869, 40.242895781993866, 46.898842826485634, 52.87999168038368, 52.986952140927315, 52.72717148065567, 52.372677102684975, 48.80166292190552, 41.42376221716404, 38.14679145812988, 40.18267281353474, 48.16635221242905, 57.96682432293892, 52.1138121932745, 46.2468434125185, 51.238935738801956, 43.92422944307327, 43.79960373044014, 44.769083708524704, 57.40070030093193, 36.80094167590141, 47.47973285615444, 56.02487772703171, 48.294276148080826, 48.39490234851837, 40.45807063579559, 40.85694283246994, 40.423583686351776, 45.54828129708767, 49.57720510661602, 52.68820837140083, 53.512824922800064, 49.429313242435455, 38.61856274306774, 37.735543325543404, 45.86784414947033, 51.90217114984989, 53.15373659133911, 55.33201530575752, 51.970354691147804, 50.87197043001652, 52.35337033867836, 51.792531833052635, 53.75799156725407, 54.714757427573204, 55.47149822115898, 57.65183262526989, 52.7724726498127, 54.999669939279556, 54.31680478155613, 55.13942264020443, 54.35779318213463, 58.79627041518688, 55.6894089281559, 54.93947356939316, 40.33972218632698, 36.42424888908863, 21.774598583579063, 14.690606407821178, 7.320413114503026, 7.9034937266260386, 18.273873031139374, 9.671596325933933, 9.15532847866416, 7.5099787674844265, 8.23157524690032, 3.7970925495028496, 2.5325441546738148, 0.5935284483712167, 0.05640909381327219, 0.15091621986357495, 0.5802376521751285, 6.993528055027127, 20.215869024395943, 46.479911506175995, 59.40386161208153, 37.46630497276783, 24.55811832100153, 26.09104346483946, 48.062632977962494, 46.28640688955784, 26.212635040283203, 4.693541396409273, 0.07817609963240102, 0.03577549592591822, 0.03587402345146984, 0.055030354124028236, 0.06032927740307059, 0.05178597020858433, 0.024301664634549525, 0.01863293658971088, 0.10012172555434518, 0.026689756705309264, 0.02389860979747027, 0.035664003080455586, 0.004685786379923229, 0.038324160923366435, 0.01949102628714172, 0.0772386186872609, 0.046705865461262874, 0.012991166131541831, 0.0284938323602546, 0.020155511920165736, 0.026641583899618126, 0.027281732654955704, 0.026379192022432107, 0.025568223136360757, 0.016954094644461293, 0.011253708435106091, 0.03180811916536186, 0.049261951935477555, 0.05203337626880966, 0.03857979740132578, 0.0429143739893334, 0.0356753319647396, 0.038937071003601886, 0.03437662177020684, 0.048491814159206115, 0.025258521200157702, 0.04134551090828609, 0.044802316042478196, 0.06111321541538928, 0.025670581999293063, 0.030279486054496374, 0.023562893729831558, 0.015207595733954804, 0.03391247148101684, 0.08366133537492715, 0.05482930260768626, 0.026843041741813067, 0.016482463506690692, 0.016289475424855482, 0.03365536183991935, 0.10520361887756735, 2.4772445345297456, 18.35282139480114, 43.785973861813545, 52.72936016321182, 45.193813517689705, 33.16452160477638, 37.99924157559872, 42.989031225442886, 38.59205536544323, 35.4421915858984, 17.293719425797462, 6.5538963954895735, 0.6577312282752246, 0.13652873720275238, 0.3743634821148589, 0.9804268938023597, 5.242629982531071, 11.659102477133274, 8.259751684963703, 11.57674664631486, 14.07030014321208, 14.19660346582532, 11.951168105006218, 8.68910489603877, 13.63718893378973, 23.57594322413206, 37.01284110546112, 48.91717292368412, 51.407205909490585, 54.96109440922737, 55.52334263920784, 55.060861855745316, 55.456219241023064, 55.81045143306255, 54.37565602362156, 56.77356295287609, 55.72354629635811, 57.58142240345478, 55.461778342723846, 53.939055651426315, 51.53888404369354, 44.76133972406387, 39.60331790149212, 43.55602540075779, 48.7985622882843, 56.788993924856186, 54.99556615948677, 54.47655200958252, 55.39560869336128, 51.053007915616035, 44.76388178765774, 40.05224481225014, 40.91852992773056, 51.3316697627306, 58.97607296705246, 54.31754194200039, 50.28972767293453, 52.83190906047821, 46.29399128258228, 44.80450160801411, 47.112881541252136, 58.98016154766083, 40.80072104930878, 48.98483969271183, 58.70769336819649, 51.334789395332336, 51.85420632362366, 43.22407901287079, 43.20083186030388, 44.04500976204872, 47.476408034563065, 51.87719129025936, 55.243453457951546, 55.92960923910141, 51.67309284210205, 40.4214634001255, 39.96274061501026, 48.02789904177189, 53.485306799411774, 56.33393794298172, 56.04608438909054, 55.046179443597794, 50.707857236266136, 52.949049174785614, 53.333637937903404, 56.43254645168781, 56.53707504272461, 57.66251765191555, 59.25793044269085, 58.00560504198074, 57.445416301488876, 57.527317106723785, 58.03864046931267, 57.64125399291515, 59.857314079999924, 58.248172625899315, 54.57058176398277, 46.116624400019646, 36.10899120569229, 24.910906590521336, 15.390237215906382, 9.736645985394716, 8.799450974911451, 13.389633167535067, 18.946638330817223, 7.251826319843531, 10.096257738769054, 11.306939274072647, 8.954913932830095, 4.440625067800283, 1.7705806600861251, 0.035036532062804326, 0.24013130605453625, 0.8554726769216359, 8.110020719468594, 22.353400625288486, 51.14016003906727, 65.03537982702255, 45.10357975959778, 32.23265960812569, 29.53518245369196, 52.605106830596924, 55.039928779006004, 30.42815163731575, 7.165352459996939, 0.13513039739336818, 0.05808511188661214, 0.039093701270758174, 0.09652410531998612, 0.019473322354315314, 0.03662520677607972, 0.016927267861319706, 0.023005952716630418, 0.025448106534895487, 0.03352498133608606, 0.03518525845720433, 0.07711975631536916, 0.032009538044803776, 0.11747140160878189, 0.008192550576495705, 0.027594713028520346, 0.023874104081187397, 0.06102591287344694, 0.04942725790897384, 0.038419181801145896, 0.01067418665115838, 0.01879668405308621, 0.07175889710197225, 0.012833674045396037, 0.02176683883590158, 0.01318586300840252, 0.1447086888947524, 0.1142370181332808, 0.0864944099157583, 0.20589057152392343, 0.10263071904773824, 0.10959995328448713, 0.12864830147009343, 0.14391312142834067, 0.18696130835451186, 0.09484380134381354, 0.10745974039309658, 0.09976686022127979, 0.16087270982097834, 0.23818898684112355, 0.12189331042463891, 0.13729956146562472, 0.10571386766969226, 0.15136861824430525, 0.22131394391180947, 0.14617220411309972, 0.13297006487846375, 0.16717410762794316, 0.09711623526527546, 0.09647474507801235, 0.18592319218441844, 3.8660476868972182, 23.328597396612167, 52.32365973293781, 60.49761772155762, 52.65367202460766, 40.193338841199875, 39.32127043604851, 41.49801403284073, 32.883310094475746, 33.559821993112564, 20.18081210553646, 7.855289513245225, 0.9851343068294227, 0.35706817579921335, 0.6186377385165542, 2.3956892732530832, 9.36570418998599, 22.960207164287567, 18.236460238695145, 15.135137904435396, 20.525351017713547, 21.64327573031187, 19.671278446912766, 15.817565135657787, 20.103096775710583, 26.9497137889266, 45.64548388123512, 50.539875850081444, 54.8108846694231, 54.41926248371601, 55.295221880078316, 55.08370243012905, 56.48039348423481, 55.946001559495926, 54.46149721741676, 56.36642999947071, 58.902288526296616, 59.856379330158234, 58.969921097159386, 56.85977652668953, 55.61434015631676, 47.65817888081074, 40.92967852950096, 44.99066881835461, 51.056959703564644, 58.21476861834526, 57.92053900659084, 57.06436514854431, 57.196845039725304, 53.32449562847614, 46.02145850658417, 42.597545832395554, 44.32538531720638, 53.49209323525429, 62.77893550693989, 56.69442839920521, 52.747808173298836, 55.39508432149887, 49.86234560608864, 46.3385096937418, 49.82697710394859, 61.07832536101341, 44.07078757882118, 50.38552053272724, 60.51554515957832, 54.74881500005722, 53.78759577870369, 43.89617174863815, 44.28701117634773, 45.82038849592209, 49.18069638311863, 54.04932953417301, 57.94448912143707, 59.66895058751106, 53.91269266605377, 42.5446754693985, 40.680727288126945, 48.7195835262537, 55.867847353219986, 58.33436340093613, 59.256820902228355, 54.542208686470985, 49.841100946068764, 52.379486337304115, 53.43798793852329, 58.00098828971386, 58.8558816164732, 59.9372997879982, 61.27505600452423, 58.301449567079544, 59.899829998612404, 60.86745947599411, 59.61240582168102, 59.40903693437576, 63.58616419136524, 59.08772997558117, 57.70021542906761, 46.4414119720459, 42.919073179364204, 28.03266517817974, 19.391180276870728, 16.648567244410515, 16.80070538073778, 28.73282700777054, 17.12838649749756, 15.980925969779491, 19.271374605596066, 18.135625049471855, 13.706316724419594, 6.293631736189127, 2.403748403303325, 0.5243983422406018, 0.37448243354447186, 1.1555391317233443, 9.224169384688139, 24.487643502652645, 51.503127962350845, 68.4982480108738, 47.03719340264797, 36.65932707488537, 40.01299291849136, 61.90669611096382, 61.10134072601795, 37.17053644359112, 9.09412706270814, 0.293074770597741, 0.14719613041961566, 0.1326814288040623, 0.17625643667997792, 0.1743420519051142, 0.08249168095062487, 0.09616968527552672, 0.12996761739486828, 0.15970921522239223, 0.1254883108776994, 0.15258131723385304, 0.1325663216994144, 0.16807777632493526, 0.20862137811491266, 0.16652656893711537, 0.20790456735994667, 0.10189489446929656, 0.16341325943358243, 0.16404549503931776, 0.11137023524497636, 0.11594320079893805, 0.06055425947124604, 0.1302757125813514, 0.09327364692580886, 0.09239424645784311, 0.2007077683811076], [0.016500748170074075, 0.03961107839131728, 0.0685687901568599, 0.0482573511544615, 0.03749324496311601, 0.008097409099718789, 0.03328865182993468, 0.0176452289451845, 0.15731733263237402, 0.0855000656156335, 0.03441454922722187, 0.06780792551580817, 0.0026105431834366755, 0.06035530081135221, 0.011973158452747157, 0.01433508332411293, 0.03320242540212348, 0.03390873105672654, 0.12207858759211376, 0.04089242604095489, 0.007333198300329968, 0.041400418704142794, 0.04684985695348587, 0.018869180748879444, 0.0356040449696593, 1.8811948620714247, 17.041891738772392, 41.308104023337364, 46.08217164874077, 41.820343136787415, 27.839810326695442, 22.762900851666927, 22.432168498635292, 23.264084458351135, 29.28591962903738, 15.554096773266792, 4.371207067742944, 0.4615138244116679, 0.0253248729131883, 0.2420361913391389, 1.7252913652919233, 3.5713122272863984, 7.309558521956205, 6.08872345648706, 12.772600427269936, 15.838767047971487, 18.21049053221941, 7.844993015751243, 7.915604626759887, 21.80014081299305, 35.47976016998291, 40.877826511859894, 54.848711639642715, 57.754704505205154, 58.97896081209183, 58.219651356339455, 56.35939657688141, 55.768049508333206, 56.20523504912853, 54.27708551287651, 51.97503224015236, 56.542071774601936, 57.86349266767502, 57.63421297073364, 55.49108996987343, 51.10913850367069, 49.90779496729374, 40.443133637309074, 37.24547602236271, 37.45203673839569, 41.55472978949547, 44.96481120586395, 44.686384946107864, 42.02455937862396, 40.52780829370022, 37.95951850712299, 40.13560853898525, 45.856608152389526, 52.21073359251022, 49.841959699988365, 48.105973452329636, 50.0039754062891, 51.29038877785206, 42.7009192854166, 42.928515672683716, 43.8030843436718, 55.8061158657074, 40.78139528632164, 49.200956895947456, 54.94101248681545, 49.82584856450558, 46.32345490157604, 41.18658274412155, 37.46171481907368, 37.60723181068897, 37.38929070532322, 40.02976901829243, 42.04020693898201, 41.48044377565384, 39.430609568953514, 38.27932454645634, 38.30571413040161, 38.33339184522629, 44.03040334582329, 50.93073807656765, 53.70591156184673, 54.69111129641533, 51.11642271280289, 51.523270681500435, 53.553034365177155, 52.36848592758179, 54.30072784423828, 53.1171103566885, 54.92735221982002, 54.18045289814472, 54.84585799276829, 54.8314605653286, 57.941772267222404, 56.11704558134079, 55.57817369699478, 54.80564475059509, 50.996641740202904, 45.450254157185555, 34.003330394625664, 19.521281495690346, 19.281073585152626, 17.60076954960823, 7.499292315915227, 9.59060462191701, 30.16310825943947, 8.668607845902443, 8.841261081397533, 11.07332305982709, 6.699543055146933, 4.438577927649021, 1.3729438721202314, 0.28601715399418026, 0.04805216958629899, 0.830263226525858, 3.810123475268483, 12.333394344896078, 26.23592209070921, 31.550959087908268, 20.61347208917141, 21.335706934332848, 35.04340298473835, 43.129141107201576, 45.4698421061039, 23.77361051738262, 5.389703465625644, 0.42789601895492524, 0.008706541648280108, 0.08463745994959027, 0.04036131547763944, 0.047642504068790004, 0.00965545630606357, 0.049703733893693425, 0.013342489564820426, 0.05097304761875421, 0.010129935435543302, 0.0658580957679078, 0.03799647674895823, 0.055204888703883626, 0.07450637975125574, 0.035295422858325765, 0.04495117973419838, 0.03831187837931793, 0.0862217448593583, 0.03214561453205533, 0.044802119373343885, 0.03073806281463476, 0.04004569120297674, 0.01604947970918147, 0.019093635892204475, 0.030060153585509397, 0.033743707099347375, 0.055249851720873266, 0.025846923708741087, 0.023652745549043175, 0.07302605488803238, 0.03634124994277954, 0.009185603539663134, 0.06822495313826948, 0.02954763753223233, 0.13044547144090757, 0.02845768420229433, 0.050489319473854266, 0.0504699679731857, 0.01605128312803572, 0.01615807632333599, 0.014607910725317197, 0.019009446659765672, 0.03620618277636822, 0.02545969888160471, 0.010927667190117063, 0.08500643350998871, 0.025491379310551565, 0.013865999608242419, 0.010435799540573498, 0.09660658019129187, 0.024917662049119826, 2.8404675191268325, 21.025451682507992, 47.59483627974987, 53.34653064608574, 46.84097193181515, 35.71400240063667, 28.034616373479366, 27.309018708765507, 26.20957810431719, 29.424389898777008, 16.994132101535797, 5.043621361255646, 0.5319179606158286, 0.0750297868216876, 0.2571755734970793, 3.469457267783582, 6.220815293490887, 9.124780017882586, 11.927183791995049, 12.8913146071136, 11.704828273504972, 14.615157656371593, 12.219599951058626, 12.040314171463251, 15.20591290667653, 29.917626231908798, 42.05651566386223, 52.4130005389452, 57.576247081160545, 60.41861616075039, 58.34717631340027, 55.604802668094635, 56.444211825728416, 56.69880576431751, 54.59895484149456, 52.34283730387688, 56.120112016797066, 57.0770488679409, 58.45589227974415, 58.07772517204285, 53.55030991137028, 53.60786162316799, 42.40434139966965, 40.30018150806427, 38.71644929051399, 43.89660872519016, 48.31913061439991, 48.03900584578514, 44.83933813869953, 41.28690876066685, 40.66919490695, 41.27240113914013, 47.58065164089203, 55.28857983648777, 53.33795450627804, 50.004845559597015, 52.86358796060085, 53.82078319787979, 45.63756890594959, 44.954734146595, 47.41073615849018, 57.18730375170708, 43.705023005604744, 51.76613464951515, 56.413657665252686, 52.261156886816025, 47.94496089220047, 42.64220483601093, 40.10706827044487, 38.39247867465019, 40.265823751688, 42.011374086141586, 46.36177584528923, 45.61587207019329, 41.561588421463966, 38.863319009542465, 39.584037736058235, 39.89589840173721, 47.041407376527786, 53.865704387426376, 55.774144381284714, 55.790977478027344, 51.16037495434284, 51.36592112481594, 54.106356874108315, 52.61046074330807, 57.009374499320984, 55.19663617014885, 56.79134599864483, 56.358845606446266, 57.38460436463356, 58.20205830037594, 58.12276415526867, 58.87295410037041, 56.58016853034496, 57.27148063480854, 53.93117867410183, 46.61700814962387, 37.1060387045145, 25.518756173551083, 18.188275024294853, 15.916189793497324, 12.852526288479567, 15.160667784512043, 20.123849362134933, 15.44076880440116, 14.627499394118786, 9.193485081195831, 6.992532508447766, 5.033870134502649, 2.6903501618653536, 0.4986077011562884, 0.14355166582390666, 0.7452418387401849, 5.216922936961055, 15.955020859837532, 33.13088580965996, 41.40188679099083, 28.13118439167738, 26.41786202788353, 40.994373857975006, 48.804189786314964, 51.52768984436989, 28.59962895512581, 6.273910794407129, 0.5216923530679196, 0.0370481752906926, 0.02343460979318479, 0.02587121049145935, 0.02104711515130475, 0.026965783690684475, 0.021762784854217898, 0.06315488964901306, 0.09212172240950167, 0.020844321443291847, 0.0024474601741530932, 0.016183810294023715, 0.04767773381900042, 0.024279433600895572, 0.05748191280872561, 0.019506581702444237, 0.06026238392223604, 0.0171951980155427, 0.06087018802645616, 0.04139667085837573, 0.049149809710797854, 0.11860483180498704, 0.027768353320425376, 0.01669347835559165, 0.02444461155391764, 0.014048174598428886, 0.11638421463430859, 0.1299943495541811, 0.09462327216169797, 0.14301574614364654, 0.06764883131836541, 0.14624996634665877, 0.11789674870669842, 0.10721188533352688, 0.3276535385521129, 0.2662146056536585, 0.18485049193259329, 0.14863671327475458, 0.14225779072148725, 0.08432140151853673, 0.1486997661413625, 0.12328610639087856, 0.1337070917361416, 0.06976983742788434, 0.16590736544458196, 0.12570255406899378, 0.14683612942462787, 0.19811275997199118, 0.2844012313289568, 0.1287100333138369, 0.23133289301767945, 3.791338470764458, 24.55877758562565, 54.20866258442402, 59.64072950184345, 55.407889634370804, 40.10162316262722, 33.217038586735725, 31.730094775557518, 33.31555590033531, 38.608584478497505, 19.89924531430006, 6.082380646839738, 0.6892681703902781, 0.2531737054232508, 0.652746845735237, 3.9593837410211563, 8.545857332646847, 15.515826176851988, 14.383423291146755, 19.122859574854374, 25.772882737219334, 31.45546641200781, 18.508411645889282, 15.145726036280394, 27.81334474682808, 40.01659132540226, 43.447032049298286, 57.42030344903469, 58.52543234825134, 61.5466046333313, 59.88800883293152, 58.47691275179386, 55.47161601483822, 56.16719909012318, 54.969176575541496, 51.52148477733135, 56.8906232714653, 56.51747569441795, 60.00111736357212, 59.01436731219292, 54.77762505412102, 54.72736895084381, 45.650640204548836, 41.5641038864851, 40.516032725572586, 46.16697169840336, 49.52632583677769, 50.08591040968895, 46.3626080006361, 43.033184856176376, 42.86913625895977, 43.954209834337234, 50.97568966448307, 57.5372763723135, 55.22653676569462, 52.691210210323334, 56.32549859583378, 54.565360844135284, 48.900043442845345, 48.63439969718456, 50.71465887129307, 59.50546815991402, 47.3028751462698, 54.41984385251999, 59.57140602171421, 55.31788006424904, 49.38734069466591, 44.8611793667078, 41.906602308154106, 40.879627615213394, 41.071730107069016, 43.28211709856987, 46.71877048909664, 46.83577001094818, 43.759356290102005, 40.604381784796715, 42.27066457271576, 42.3233525454998, 48.27034503221512, 55.71650147438049, 58.65251652896404, 57.66475573182106, 52.37685687839985, 50.820395797491074, 54.791137129068375, 52.42007575929165, 56.44027903676033, 54.762342274188995, 56.400331780314445, 56.470305025577545, 57.96316511929035, 57.78086610138416, 59.88454341888428, 59.81043219566345, 57.50713258981705, 57.73299627006054, 55.040365755558014, 51.27047784626484, 38.78981955349445, 22.54087496548891, 28.39442666620016, 23.96336853504181, 19.229362159967422, 20.917476676404476, 44.441666677594185, 23.291216902434826, 17.809289060533047, 21.06692835688591, 13.65835189819336, 11.621926221996546, 4.1266141925007105, 0.6001382530666888, 0.26611082372255623, 1.2715279078111053, 5.658689131960273, 17.761557921767235, 35.678478106856346, 45.545344054698944, 32.522884234786034, 32.94050842523575, 46.97670444846153, 54.914440512657166, 61.27580836415291, 35.794774666428566, 9.89915756508708, 1.0128548881039023, 0.259418937494047, 0.13124169199727476, 0.10262320109177381, 0.13457650289637968, 0.09635659516789019, 0.14628613862441853, 0.18808129825629294, 0.17542008077725768, 0.08412707014940679, 0.19232737744459882, 0.14367158204549924, 0.14481839316431433, 0.07979361049365252, 0.15562507265713066, 0.1443583655054681, 0.1449129279353656, 0.18274227302754298, 0.15231954690534621, 0.08267128068837337, 0.12031925973133184, 0.22345496574416757, 0.09298259144998156, 0.09524784138193354, 0.06869091055705212, 0.14375366357853636], [0.03417357387661468, 0.007313973892451031, 0.034362457881798036, 0.010064671896543587, 0.06794915621867403, 0.03409567434573546, 0.03299178533779923, 0.0733697805844713, 0.05803062340419274, 0.08174249771400355, 0.004061200925207231, 0.023578937107231468, 0.048168816647375934, 0.03851134541037027, 0.03006263606948778, 0.032738271402195096, 0.03888475330313668, 0.08424776562605985, 0.06760424308595248, 0.024426553245575633, 0.06329445051960647, 0.07192131612100638, 0.040640392689965665, 0.07013229493168183, 0.008177227082342142, 1.3973792921751738, 15.431150570511818, 37.24982678890228, 42.189592123031616, 34.4963463395834, 23.096407055854797, 24.31652918457985, 27.07251749932766, 38.569917753338814, 35.368072763085365, 13.697033822536469, 4.146753111854196, 0.4188606084790081, 0.04927802314341534, 0.3301296994322911, 2.965654651634395, 5.012425510212779, 8.32734340801835, 7.730153677985072, 11.096961591392756, 9.772477112710476, 10.964750535786152, 10.943151544779539, 16.275681853294373, 20.170337967574596, 32.225728780031204, 48.72060187160969, 57.72883169353008, 54.37062129378319, 53.64800646901131, 52.779981046915054, 53.37206527590752, 54.50568504631519, 58.957974538207054, 55.06015509366989, 55.24235911667347, 52.39337459206581, 54.735819697380066, 53.252542689442635, 56.14704877138138, 53.22055600583553, 51.74419082701206, 44.13269765675068, 35.37253752350807, 35.36730520427227, 35.83341859281063, 35.23818053305149, 37.042601108551025, 36.05040594935417, 38.048642724752426, 41.24027766287327, 47.0807808637619, 50.709494948387146, 54.31812711060047, 46.422295197844505, 59.64211642742157, 52.440146282315254, 48.06234419345856, 40.51547035574913, 41.14439740777016, 43.96915443241596, 54.45205092430115, 41.137553974986076, 48.95062632858753, 50.57264529168606, 45.23290582001209, 42.959943786263466, 38.138192519545555, 37.85913549363613, 36.324264854192734, 38.579333648085594, 36.60826541483402, 37.46676854789257, 37.329732701182365, 36.838305070996284, 41.89907871186733, 46.5991947054863, 37.742550149559975, 39.197887256741524, 45.99749319255352, 51.57171808183193, 52.79073067009449, 51.08271472156048, 52.7771881967783, 51.901582181453705, 50.15717178583145, 50.641433000564575, 51.68739527463913, 50.92582494020462, 55.88332012295723, 51.697046756744385, 52.8186971694231, 53.76450061798096, 56.694690585136414, 50.35038761794567, 55.64834453165531, 48.397288620471954, 49.398785680532455, 36.89283974468708, 35.02107158303261, 19.848842918872833, 14.770721308887005, 9.750157110393047, 12.562759537249804, 17.857977747917175, 7.620154805481434, 10.703440457582474, 6.817914778366685, 7.789343101903796, 2.8030354902148247, 2.954343371093273, 0.3292403096565977, 0.1393279104377143, 0.1733441898250021, 3.8212889386340976, 10.807255636900663, 25.544176809489727, 27.84527063369751, 22.155725732445717, 29.671899117529392, 36.65967285633087, 50.94915188848972, 47.65542782843113, 27.003706991672516, 10.2222665771842, 0.5235156614799052, 0.05235249234829098, 0.07065387631882913, 0.0691937527153641, 0.05143602531461511, 0.01394012810123968, 0.030177763583196793, 0.031129851849982515, 0.13678877090569586, 0.08708397203008644, 0.020733075361931697, 0.039935126042109914, 0.02956343043479137, 0.05999202694511041, 0.044315055274637416, 0.04210487270029262, 0.03604622768762056, 0.01901805186207639, 0.05902983248233795, 0.037245645944494754, 0.04353710639406927, 0.03756981604965404, 0.033291998915956356, 0.039459639447159134, 0.03694897241075523, 0.07508990078349598, 0.12193918999400921, 0.04919378196063917, 0.0280646947430796, 0.025769152198336087, 0.02380490808718605, 0.012461873830034165, 0.024040788593993057, 0.060675400236505084, 0.03765215733437799, 0.018461205472704023, 0.05407452357758302, 0.02214390737208305, 0.08925351459765807, 0.046926706345402636, 0.03431871940847486, 0.07427613585605286, 0.03831017886113841, 0.027607103183981963, 0.03369648053194396, 0.0008553867144200922, 0.06359690538374707, 0.06925998939550482, 0.008307225380121963, 0.02672849495866103, 0.020080818467249628, 1.636924494523555, 19.153917208313942, 41.653136909008026, 48.9728931337595, 41.04870714247227, 28.63341674208641, 28.054048530757427, 30.666598342359066, 36.79078862071037, 35.153281688690186, 16.147201247513294, 4.000712698325515, 0.43487989576533437, 0.0701718291384168, 0.6471550895366818, 3.0189365800470114, 6.5433120634406805, 12.763074338436127, 11.686716545373201, 14.3531702645123, 11.227971911430359, 12.84170351922512, 14.29167341440916, 13.035699259489775, 19.051514603197575, 31.126347072422504, 49.023791402578354, 56.97122074663639, 57.8117698431015, 56.24545209109783, 55.43613351881504, 54.857124388217926, 55.89078292250633, 58.873261883854866, 54.87882122397423, 54.73658725619316, 53.740995079278946, 55.252371579408646, 53.75093534588814, 56.01776070892811, 55.29046453535557, 53.162939697504044, 45.31393647193909, 37.10247069597244, 36.94710083305836, 39.32380110025406, 37.60549910366535, 38.61919730901718, 38.305588737130165, 39.09195274114609, 42.83662900328636, 48.81945736706257, 53.41407962143421, 56.05379797518253, 49.67324875295162, 60.4057652503252, 54.98345620930195, 51.83353163301945, 44.008953496813774, 43.95597293972969, 45.51827810704708, 57.11489483714104, 43.881698325276375, 51.92067235708237, 53.097632601857185, 48.67905490100384, 45.124782621860504, 40.726321041584015, 40.42391046881676, 38.47749911248684, 40.37729077041149, 37.91846551001072, 38.82225461304188, 39.28671509027481, 38.654334023594856, 43.62899288535118, 49.370803982019424, 39.07799988985062, 41.2801793217659, 48.91243077814579, 52.97351226210594, 54.54259626567364, 53.08866508305073, 52.154884189367294, 51.88836649060249, 50.64612574875355, 50.62828570604324, 50.69278724491596, 51.632526218891144, 55.323150381445885, 51.76234245300293, 53.06554712355137, 54.9666079133749, 56.632187739014626, 52.677705734968185, 55.85021249949932, 51.04871794581413, 46.77998900413513, 38.33874575793743, 32.99214385449886, 20.481548868119717, 15.502363499253988, 11.06542993336916, 17.89121836423874, 18.769940212368965, 12.371249813586473, 16.89887311309576, 12.895214147865772, 10.225536301732063, 4.371401807293296, 3.322519389912486, 0.7993103843182325, 0.14688874769490212, 0.40748485014773905, 3.193645505234599, 12.379752807319164, 24.858754388988018, 32.791974395513535, 24.894105792045593, 32.435564920306206, 43.01687993109226, 55.71960210800171, 54.094566106796265, 32.640005350112915, 12.00375348329544, 0.7895934151019901, 0.012406993864715332, 0.021938866811979096, 0.07094775937730446, 0.025196475799020845, 0.02412886853562668, 0.06886089948238805, 0.0734639294387307, 0.01565035454405006, 0.05533080518944189, 0.051100058772135526, 0.017457996218581684, 0.007231423414850724, 0.06102770516008604, 0.05149699645699002, 0.05308524072461296, 0.0632985620177351, 0.024484132773068268, 0.02894145316531649, 0.0413399744866183, 0.055768531310604885, 0.06690982292639092, 0.01663556857238291, 0.047044125240063295, 0.03680275818624068, 0.036363265753607266, 0.1454220263985917, 0.11496652703499421, 0.11952091663260944, 0.0808988613425754, 0.13427024823613465, 0.09207357186824083, 0.0805059757840354, 0.12305931348237209, 0.11843770756968297, 0.17560808162670583, 0.14916527085006237, 0.06580637549632229, 0.18411730939988047, 0.2509301929967478, 0.16944340226473287, 0.13134709181031212, 0.10444828323670663, 0.17627648951020092, 0.08984925138065591, 0.14916979795088992, 0.2336110785836354, 0.10663640176062472, 0.1038939508725889, 0.21979215525789186, 0.08679745107656345, 2.588417544029653, 22.318679988384247, 49.087874963879585, 55.63474506139755, 47.037683576345444, 34.237124249339104, 34.200680404901505, 37.1184678375721, 48.69961179792881, 43.09712402522564, 18.204036578536034, 5.872244797646999, 0.5969504022505134, 0.3435577929485589, 0.9317897411528975, 5.143848108127713, 11.07748193666339, 16.877765245735645, 16.470784284174442, 23.933456540107727, 25.756480917334557, 20.57323794811964, 15.309324357658625, 20.223770700395107, 26.070081889629364, 36.7260666936636, 53.425110429525375, 61.695165261626244, 59.84311804175377, 59.839230850338936, 56.25600412487984, 56.94866135716438, 57.76313625276089, 62.09325090050697, 55.67304700613022, 54.87688712775707, 52.563578858971596, 54.69069331884384, 51.792839616537094, 56.84410996735096, 57.32025481760502, 55.99282264709473, 48.864629343152046, 40.36368750035763, 38.46637710928917, 40.499780997633934, 39.32073086500168, 39.803175777196884, 41.08730547130108, 42.32537783682346, 45.03626637160778, 51.411191895604134, 55.12500621378422, 56.45438767969608, 51.50699995458126, 59.72483418881893, 56.231898218393326, 54.116646721959114, 46.12372241914272, 46.11510828137398, 49.12928134202957, 60.08124366402626, 46.706820130348206, 54.10264827311039, 56.62562549114227, 51.49901658296585, 48.23669023811817, 42.58940286934376, 43.46494808793068, 40.656655579805374, 42.338654324412346, 40.495399832725525, 40.71435168385506, 41.59983716905117, 40.65670117735863, 45.86329199373722, 51.57758876681328, 42.197419703006744, 42.636820524930954, 52.39884249866009, 56.03451780974865, 55.55063657462597, 53.24697218835354, 52.54061669111252, 51.14563174545765, 50.17717391252518, 49.829302579164505, 52.04035073518753, 51.147505044937134, 56.05640463531017, 50.9703965485096, 53.89092743396759, 53.804056495428085, 56.23402610421181, 50.66947929561138, 58.132081255316734, 50.35506896674633, 53.973519802093506, 40.4020806401968, 41.39662407338619, 22.911693267524242, 23.084356002509594, 17.857297584414482, 25.659316331148148, 26.864908039569855, 11.988703440874815, 19.74267851561308, 19.191673882305622, 20.387435518205166, 7.578198406845331, 6.6977884992957115, 1.2820479995571077, 0.48498635238502175, 0.6034161115530878, 5.079980185255408, 14.755642767995596, 33.36269237101078, 41.42583690583706, 32.8145831823349, 40.14582999050617, 48.12605917453766, 61.079811081290245, 62.83274441957474, 38.58917511999607, 13.885020185261965, 1.1194126890040934, 0.18522687954828143, 0.14282749296398833, 0.16778256482211873, 0.20298743824241683, 0.08647602691780776, 0.16584072058321908, 0.18718373001320288, 0.2025150167173706, 0.14300136332167313, 0.20786155248060822, 0.21235249587334692, 0.17293044249527156, 0.2261823436128907, 0.09879123288556002, 0.12217201656312682, 0.17675409122603014, 0.1657772669568658, 0.1302922921604477, 0.1563077891478315, 0.09376156449434347, 0.10014448722358793, 0.16398934414610267, 0.16639480803860351, 0.1371453728643246, 0.15260551124811172], [0.03566949126252439, 0.014978768413129728, 0.01919060119689675, 0.04878113300947007, 0.019151935302943457, 0.075891115993727, 0.013763365222985158, 0.025654126729932614, 0.048938794861896895, 0.07320503864320926, 0.045349995052674785, 0.0172642938196077, 0.020133857906330377, 0.06484021054347977, 0.028781490655092057, 0.006148484308141633, 0.01738246784952935, 0.05765879999671597, 0.011381495132809505, 0.037472809926839545, 0.02585834350611549, 0.020682813410530798, 0.10281552124070004, 0.035126005386700854, 0.024576326068199705, 1.962448989506811, 13.575674034655094, 37.0583588629961, 45.89253522455692, 42.20147408545017, 33.44359003007412, 20.16805239021778, 28.93110416829586, 40.96033528447151, 26.144423000514507, 11.183362305164337, 2.7242825785651803, 0.9503892087377608, 0.2091810168349184, 0.11514014506246895, 3.5678874235600233, 7.181245582178235, 8.035244531929493, 13.260901775211096, 9.275045804679394, 4.0730565413832664, 12.238962762057781, 19.636899791657925, 17.59536813944578, 19.93062023073435, 37.36075043678284, 51.75370171666145, 51.333269476890564, 52.91464202105999, 47.24617838859558, 47.723622769117355, 48.71770262718201, 50.904443487524986, 52.235447466373444, 55.38275018334389, 55.265910252928734, 54.868295788764954, 57.33452685177326, 53.58266517519951, 54.94639299809933, 52.275390923023224, 49.56622749567032, 42.95983739197254, 37.02666476368904, 34.48329024016857, 36.1659387499094, 39.17535446584225, 42.41660714149475, 40.499746799468994, 44.18388091027737, 50.26350907981396, 52.46495135128498, 51.39057420194149, 50.817652344703674, 57.10962451994419, 52.87776879966259, 51.15783289074898, 47.82646805047989, 38.926885798573494, 40.27676336467266, 46.000403836369514, 53.59499171376228, 42.78678707778454, 50.704418420791626, 54.264629781246185, 43.854335993528366, 39.31348845362663, 39.05810035765171, 37.98705942928791, 35.928307101130486, 36.624783128499985, 39.169084802269936, 39.782964661717415, 39.052298069000244, 37.19749599695206, 37.23622351884842, 38.41328635811806, 38.083182871341705, 38.09800587594509, 43.195607140660286, 50.698517337441444, 53.5393550992012, 56.65262684226036, 50.409147664904594, 52.36794635653496, 52.4201213568449, 54.78533864021301, 52.184735387563705, 53.15401017665863, 52.66887120902538, 53.5962038487196, 51.56416028738022, 52.28569597005844, 51.0734736174345, 53.44782181084156, 53.16351726651192, 54.69068951904774, 46.91054239869118, 43.205475211143494, 36.230102106928825, 25.00480145215988, 24.697468243539333, 17.811774127185345, 20.821381732821465, 14.089629705995321, 22.202776707708836, 21.001879647374153, 7.524882992729545, 6.239793375134468, 3.7564658420160413, 2.367197689600289, 0.622644207905978, 0.15971913031535223, 0.2212870930088684, 2.288815970532596, 11.213836669921875, 24.55615572631359, 37.391730174422264, 39.196671321988106, 32.969747856259346, 46.21707580983639, 48.947396501898766, 44.70507234334946, 25.00922631472349, 4.9871098436415195, 0.588787371525541, 0.04870779397606384, 0.06280115980189294, 0.01611381463590078, 0.01576800350449048, 0.030866699271427933, 0.004457590812307899, 0.04049505419970956, 0.037482506086234935, 0.06654611861449666, 0.03478078797343187, 0.08262022834969684, 0.021244687850412447, 0.012943651054229122, 0.017989052976190578, 0.06313153426162899, 0.03926031342416536, 0.03617988848418463, 0.01220463987920084, 0.0545747979049338, 0.038646698303637095, 0.07820801198249683, 0.08232923224568367, 0.024505209767085034, 0.0322118623444112, 0.0698087333876174, 0.01024051822241745, 0.02914336928370176, 0.09360186915728264, 0.026392591498733964, 0.03757160833629314, 0.03780032340728212, 0.03647508143330924, 0.0445387905347161, 0.03310349340608809, 0.024844432482495904, 0.10001478207414038, 0.04279551903891843, 0.02913571774115553, 0.05537237288081087, 0.033989068542723544, 0.006963644009374548, 0.04750190790218767, 0.03677188484289218, 0.013745095402555307, 0.07170967786805704, 0.0023442675546903047, 0.0423646392300725, 0.0456729183497373, 0.0702152299345471, 0.03352269923198037, 2.646080874837935, 16.92962296307087, 43.0312355607748, 52.09458142518997, 47.68879383802414, 35.94785325229168, 24.59278766065836, 27.205658555030823, 40.56705258786678, 30.349600352346897, 12.115600481629372, 3.0411976855248213, 0.9102821233682334, 0.06173047819174826, 0.38419684977270663, 5.863259704783559, 5.303833298385143, 11.638778317719698, 9.244036618620157, 13.811208195984364, 14.512091986835003, 15.001371782273054, 16.52775652706623, 13.967484310269356, 21.03806510567665, 38.68608891963959, 53.274452313780785, 54.483494237065315, 54.75176364183426, 50.47323502600193, 50.814369320869446, 52.350999265909195, 53.0085501819849, 54.03672181069851, 58.038431480526924, 56.84035576879978, 53.788690119981766, 56.099349930882454, 53.43926087021828, 55.214442014694214, 54.71334770321846, 52.57038429379463, 45.54902605712414, 38.26628364622593, 36.14031292498112, 37.39479660987854, 39.84456695616245, 42.24414199590683, 42.47290872037411, 45.94501420855522, 51.59127563238144, 55.68313926458359, 52.79513843357563, 51.19687579572201, 56.61543443799019, 54.69146467745304, 53.26985076069832, 50.108382403850555, 41.2192115932703, 43.21913927793503, 46.80470667779446, 55.12822464108467, 46.36851668357849, 51.560539081692696, 56.34998828172684, 44.69707377254963, 42.40967631340027, 40.52061527967453, 39.38484862446785, 37.38733761012554, 39.09164875745773, 40.41770540177822, 40.19555412232876, 40.444163382053375, 39.61378253996372, 39.67184342443943, 40.64694330096245, 39.372495487332344, 40.51233932375908, 44.28617142140865, 51.738430336117744, 54.71022427082062, 55.58098554611206, 51.478953659534454, 52.65531733632088, 52.562678307294846, 53.84813033044338, 51.0784437507391, 53.70360508561134, 52.26058691740036, 52.424719110131264, 52.35140584409237, 51.140388026833534, 52.714981734752655, 52.79087506234646, 52.369470074772835, 54.41601745784283, 47.736724466085434, 42.53683649003506, 35.41267856955528, 23.6068906635046, 15.407681129872799, 15.003129187971354, 6.720503205433488, 7.531180679798126, 18.75654973089695, 17.017187364399433, 12.978880908340216, 12.148175183683634, 5.497208721935749, 3.823948558419943, 0.8807678602170199, 0.17053787712939084, 0.24836767581291497, 2.4339950177818537, 12.284076791256666, 27.112200669944286, 43.384962379932404, 41.011678129434586, 35.62181554734707, 50.32402463257313, 55.68025141954422, 51.844171062111855, 29.872040078043938, 7.360502863302827, 0.5993932555429637, 0.02690479770535603, 0.0360253473627381, 0.01343606696536881, 0.08236973124439828, 0.025655978388385847, 0.049390169078833424, 0.02404869803285692, 0.0651640392607078, 0.04911554846330546, 0.05716529405617621, 0.010523656837904127, 0.022878945273987483, 0.028577964076248463, 0.04245408286806196, 0.06775002315407619, 0.05898422750760801, 0.0763235506019555, 0.02408387397736078, 0.05878491261682939, 0.04722914265585132, 0.06500700823380612, 0.02656243941601133, 0.048134239987120964, 0.03822455728368368, 0.05887974053621292, 0.0877658870012965, 0.12700239603873342, 0.1842728041810915, 0.13041516212979332, 0.2018794562900439, 0.2646313968580216, 0.12588515208335593, 0.10287194672855549, 0.12528660998214036, 0.2799226966453716, 0.22440285159973428, 0.10804323916090652, 0.1337704117759131, 0.19176557165337726, 0.15467208082554862, 0.12600198097061366, 0.14280073111876845, 0.13571817835327238, 0.09613386922865175, 0.11231325261178426, 0.12283479154575616, 0.1123639264551457, 0.17761858936864883, 0.13042472099186853, 0.135036114952527, 3.4127863962203264, 20.770206078886986, 50.1273699849844, 60.45790985226631, 54.989095106720924, 44.688828215003014, 31.48429736495018, 38.27941194176674, 50.974150747060776, 34.79175768792629, 15.993792079389095, 4.089506333693862, 1.4812420983798802, 0.7793362811207771, 0.5820093071088195, 6.797696063295007, 13.425749279558659, 19.815634600818157, 23.106499314308167, 23.479200415313244, 20.06960727274418, 21.723242439329624, 29.42160464823246, 22.06822782754898, 23.025837242603302, 40.68687915802002, 55.60353733599186, 54.737267419695854, 59.7707699239254, 51.92527391016483, 53.181558698415756, 54.17060762643814, 55.923027992248535, 56.72519154846668, 60.149438604712486, 58.09849105775356, 54.85098771750927, 55.82648277282715, 55.15508159995079, 55.209889858961105, 56.24874271452427, 54.870784655213356, 49.31925594806671, 40.29696308076382, 38.89733478426933, 40.35975471138954, 43.15414376556873, 45.696328952908516, 45.56352607905865, 49.33183327317238, 55.36030858755112, 56.69358104467392, 55.112459287047386, 53.31498473882675, 56.693087071180344, 56.56708963215351, 56.108260452747345, 52.473968267440796, 43.37045855820179, 45.87981730699539, 50.650761500000954, 57.09322080016136, 49.17947664856911, 54.94675397872925, 58.93868297338486, 47.35118195414543, 44.700869768857956, 42.69123740494251, 42.16470345854759, 40.84778532385826, 40.45962855219841, 43.24545666575432, 42.157966420054436, 42.02262908220291, 41.381284296512604, 40.50665482878685, 42.3470214754343, 41.08594514429569, 42.76914082467556, 47.0075473934412, 53.410386219620705, 56.227893233299255, 57.33166940510273, 52.303870394825935, 53.48461523652077, 53.45427766442299, 56.38860180974007, 51.5126920491457, 54.5144397765398, 52.80868470668793, 54.76008899509907, 52.88747727870941, 53.44375982880592, 52.650521993637085, 54.136740043759346, 52.79520682990551, 56.58592142164707, 46.42433188855648, 48.84797103703022, 37.23287969827652, 28.99005800485611, 31.2488828971982, 27.653500624001026, 32.77080953121185, 24.327330105006695, 35.604404881596565, 32.34344646334648, 15.011802222579718, 9.783300831913948, 10.93268595635891, 5.687014712020755, 1.3738508359529078, 0.43707270466256887, 0.5365690297912806, 2.617874275892973, 15.523202531039715, 32.67347775399685, 50.75080253183842, 52.51310616731644, 44.949764013290405, 56.90856970846653, 58.98102790117264, 58.09048868715763, 35.935158133506775, 9.49614454060793, 1.1008075810968876, 0.1527700453880243, 0.1290964102372527, 0.07025727260042913, 0.10581036913208663, 0.08622700668638572, 0.12935890787048265, 0.2087632322218269, 0.1589865711866878, 0.15679481613915414, 0.11238064704230055, 0.1755220370250754, 0.09762173431226984, 0.1923358379281126, 0.12260407267604023, 0.10719365076511167, 0.13359900534851477, 0.17406422150088474, 0.18455302430083975, 0.20266206585802138, 0.17077293014153838, 0.16048999910708517, 0.12890832033008337, 0.22172688972204924, 0.0696128880372271, 0.14960025844629854], [0.0473674715613015, 0.042453218266018666, 0.05578005686402321, 0.12123676206101663, 0.021100631420267746, 0.014193360020726686, 0.0673443429695908, 0.030020389312994666, 0.05897383744013496, 0.03538936762197409, 0.04274788429029286, 0.09346253835246898, 0.047833369608270004, 0.029780566146655474, 0.06085524488298688, 0.04360091996204574, 0.06756149537977763, 0.03899302151694428, 0.040705286082811654, 0.028697960078716278, 0.04535167972790077, 0.03389009943930432, 0.07572465226985514, 0.0700005266116932, 0.03716013568919152, 0.8973849622998387, 8.958225455135107, 29.46172669529915, 45.71042999625206, 39.3052276968956, 31.4938747510314, 23.409590050578117, 25.205903761088848, 28.11694085597992, 25.341039709746838, 12.47665710747242, 2.67992518376559, 0.6785757222678512, 2.44999619666487, 4.1900242399424314, 4.142437968403101, 3.8844714732840657, 12.51185841858387, 6.723225759342313, 12.251850720494986, 10.388730894774199, 12.077630069106817, 17.595047056674957, 16.273909248411655, 26.609453447163105, 40.106642693281174, 51.79338298738003, 52.105752825737, 45.55704742670059, 44.30051565170288, 41.46424904465675, 43.616107776761055, 44.898956939578056, 47.58682630956173, 49.0253759175539, 53.64284634590149, 53.29801864922047, 55.684294402599335, 51.75488345324993, 53.70434984564781, 52.345459163188934, 48.27683508396149, 40.9083616733551, 35.82686774432659, 38.20533871650696, 46.743058785796165, 50.16489677131176, 52.680954560637474, 53.74965101480484, 52.65761241316795, 50.8528308570385, 52.14674882590771, 52.86775253713131, 56.455409824848175, 51.66333496570587, 52.21679426729679, 47.61365666985512, 43.61310213804245, 38.55075538158417, 41.928219348192215, 45.686981454491615, 54.57659684121609, 42.05652706325054, 47.61419624090195, 53.009967505931854, 44.270067885518074, 38.98186504840851, 38.39280925691128, 40.64239874482155, 41.00439012050629, 45.746999233961105, 49.17949564754963, 49.626602455973625, 47.31306619942188, 44.98164430260658, 40.37577845156193, 38.06399770081043, 37.89353884756565, 35.874908566474915, 43.26110802590847, 50.843361765146255, 53.54838341474533, 49.01089869439602, 48.57131168246269, 52.96783536672592, 53.471543937921524, 52.49887973070145, 53.39142523705959, 51.727669313549995, 53.410978987812996, 51.51491492986679, 48.51554587483406, 49.31263290345669, 54.66569446027279, 49.38149280846119, 52.97944754362106, 50.03946170210838, 49.24834035336971, 43.47361162304878, 38.76161366701126, 29.615265056490898, 13.211891055107117, 9.936569407582283, 5.757197421044111, 12.469636984169483, 12.704338990151882, 13.520522844046354, 16.847877949476242, 17.4851493537426, 3.3668684726580977, 2.7388334227725863, 0.9876975661609322, 0.14518164476612583, 0.25091282674111426, 1.5759502351284027, 9.278198685497046, 21.257372237741947, 27.694718912243843, 27.587279677391052, 26.454594656825066, 37.96396806836128, 45.02049341797829, 38.895081505179405, 29.69645719975233, 7.010284680873156, 0.48644770053215325, 0.044521457675728016, 0.00848361532916897, 0.06106991109845694, 0.05700298264855519, 0.021616615158563945, 0.021659579942934215, 0.053261434004525654, 0.039555981347803026, 0.0290981001307955, 0.029634895545314066, 0.07454986218363047, 0.0711782556027174, 0.05232101786532439, 0.043372446089051664, 0.03517808188917115, 0.034542796056484804, 0.0222105355351232, 0.045297228352865204, 0.029842212643416133, 0.03447546470852103, 0.04464393059606664, 0.0494723285373766, 0.04433870752109215, 0.006049646472092718, 0.01792741761164507, 0.060335043890518136, 0.04520791830145754, 0.12051920173689723, 0.052633436062023975, 0.057309920084662735, 0.009235445249942131, 0.062416400760412216, 0.0392738279333571, 0.07698052198975347, 0.08112241848721169, 0.03457381040789187, 0.02243938419269398, 0.0559500754752662, 0.06304231326794252, 0.05139088047144469, 0.05504568318428937, 0.032219521308434196, 0.012799821906810394, 0.07714710445725359, 0.03521112601447385, 0.05500310617208015, 0.09332750458270311, 0.013358957821765216, 0.04922470725432504, 0.06832898739958182, 1.6840898199006915, 12.377148997038603, 35.54905325174332, 52.82253496348858, 45.87737023830414, 35.455418676137924, 26.137433275580406, 26.084344424307346, 32.9185988008976, 29.13647934794426, 14.20052295550704, 3.2070435862988234, 0.7456009194720536, 1.7753712530247867, 1.2600112007930875, 1.718061303254217, 5.947814667597413, 10.948695447295904, 11.959860138595104, 13.197138346731663, 14.923890139907598, 15.884006470441818, 12.619880922138691, 16.447151452302933, 29.418948590755463, 44.16529230773449, 54.54717501997948, 53.11223901808262, 47.70168274641037, 47.46552921831608, 44.579762667417526, 45.88752709329128, 48.88547882437706, 51.60842031240463, 52.61529788374901, 56.74399293959141, 54.885113686323166, 55.62378264963627, 53.57549495995045, 54.45241950452328, 54.65103104710579, 51.01444758474827, 44.631743878126144, 38.69912602007389, 38.89324240386486, 47.76872634887695, 52.1737539768219, 53.676713928580284, 54.06374216079712, 54.34479407966137, 54.835229963064194, 52.12629072368145, 52.5245663523674, 56.0178367048502, 51.88006013631821, 54.80540156364441, 49.07513044774532, 46.313244849443436, 40.087487921118736, 43.791985139250755, 47.009147107601166, 55.90514995157719, 45.12182638049126, 50.979706048965454, 55.1089558750391, 46.28855377435684, 40.30628018081188, 39.9526559561491, 42.162115797400475, 43.04624855518341, 46.85644090175629, 50.96940100193024, 50.997002720832825, 47.97685258090496, 45.310676246881485, 41.07466734945774, 39.462657049298286, 38.852960765361786, 37.69882209599018, 46.5602657943964, 52.81799040734768, 53.996801152825356, 50.63015520572662, 51.087684854865074, 52.816151306033134, 53.72311323881149, 53.05037073791027, 55.64017117023468, 54.96844321489334, 53.806663155555725, 50.78410014510155, 49.79257375001907, 51.63449451327324, 56.1246033757925, 50.449664890766144, 52.59455479681492, 51.70791417360306, 50.29586814343929, 43.8224633038044, 35.031806007027626, 25.921585857868195, 15.012268647551537, 9.822878558188677, 7.132219662889838, 10.182081833481789, 13.91813825815916, 17.56410151720047, 18.11741452664137, 11.520180981606245, 6.579634789377451, 5.528603112325072, 1.1737477546557784, 0.1528819018858485, 0.22012187662767246, 2.0000471407547593, 10.325230602174997, 25.953291356563568, 35.09601876139641, 33.17006930708885, 33.53201888501644, 42.86845229566097, 51.07730761170387, 44.48559992015362, 32.73678615689278, 9.650573953986168, 0.6209293124265969, 0.05002835299819708, 0.017487847253505606, 0.027714070783986244, 0.020056392531841993, 0.02602710788778495, 0.03949858735722955, 0.07454851147485897, 0.04223279669531621, 0.051217856162111275, 0.06433152768295258, 0.11805014320998453, 0.03401536283490714, 0.03286271101387683, 0.049406455509597436, 0.015005068271420896, 0.01454637462302344, 0.04746098959003575, 0.05809641850646585, 0.03930675331503153, 0.010141908132936805, 0.10638751511578448, 0.02735364490945358, 0.05497329781064764, 0.03715076236403547, 0.01586485748703126, 0.2166559430770576, 0.1518084149574861, 0.2211741975042969, 0.20023738034069538, 0.19153495668433607, 0.10428893670905381, 0.14341441303258762, 0.1432901032967493, 0.15418212977238, 0.12417677266057581, 0.13249802927020937, 0.24870955356163904, 0.20130237709963694, 0.1559479662682861, 0.16261286800727248, 0.1402136340038851, 0.21399118762928993, 0.111633727356093, 0.18780900427373126, 0.06627124195802025, 0.20908192527713254, 0.22951388906221837, 0.20984746544854715, 0.24663542892085388, 0.21121611935086548, 2.490751384757459, 14.462246261537075, 43.46412733197212, 58.947547897696495, 51.65524899959564, 41.45074836909771, 35.79319015145302, 36.70311972498894, 39.03962954878807, 33.606548085808754, 16.150334179401398, 4.178614877164364, 0.928748776204884, 3.774167667143047, 6.864496478810906, 8.529691100120544, 10.708189252763987, 23.055441454052925, 14.428049996495247, 19.179575331509113, 19.388262033462524, 21.056837998330593, 25.323836132884026, 21.993037462234497, 30.454284735023975, 43.83293554186821, 57.364575639367104, 56.775949224829674, 50.69637045264244, 48.92690800130367, 46.1228446662426, 48.15198138356209, 49.79266494512558, 52.48265080153942, 53.29137660562992, 57.160739377141, 54.67248469591141, 55.68819299340248, 53.05952824652195, 55.518562495708466, 57.45684988796711, 53.51477041840553, 45.457861348986626, 40.57610370218754, 42.84102916717529, 51.805789321660995, 55.09876862168312, 57.12221324443817, 58.227239549160004, 58.15537020564079, 55.71169473230839, 53.78604166209698, 54.23803120851517, 57.05700494349003, 54.768091365695, 57.60647065937519, 53.0974730104208, 48.250738084316254, 42.233829349279404, 45.26053413748741, 49.74215425550938, 57.55737729370594, 49.19735848903656, 53.80966119468212, 57.42397405207157, 48.672595247626305, 42.094243839383125, 41.760420352220535, 44.52219195663929, 44.910797104239464, 48.81333589553833, 53.68687458336353, 54.08926539123058, 51.34707413613796, 48.368698954582214, 45.10469309985638, 42.53527857363224, 42.16666795313358, 39.02359440922737, 48.27472619712353, 54.355311915278435, 57.565569654107094, 52.88001827895641, 53.610213696956635, 53.99155743420124, 56.27061814069748, 55.47857724130154, 57.72720918059349, 56.31086938083172, 53.49170185625553, 51.563377529382706, 50.238331630825996, 50.685826018452644, 55.65026342868805, 50.44980548322201, 52.89653979241848, 53.587703704833984, 51.959893852472305, 48.501623421907425, 43.811664283275604, 37.92687825858593, 20.71098815649748, 16.526747681200504, 16.47372342646122, 26.105239503085613, 21.031911335885525, 26.818569526076317, 27.295689024031162, 28.7629783898592, 9.802948627620935, 5.423389133065939, 2.7295749820768833, 0.20802904036827385, 0.5072581744752824, 2.5076179672032595, 12.430266346782446, 29.871249720454216, 39.0543157607317, 38.383245170116425, 37.79296584427357, 50.937687903642654, 59.107656106352806, 51.1945541203022, 38.77771720290184, 11.921035721898079, 1.2000597990117967, 0.14071520708967, 0.07481186257791705, 0.18131006159819663, 0.0891134564881213, 0.15174105763435364, 0.15213519742246717, 0.13980607618577778, 0.12653807876631618, 0.1774672357714735, 0.14889555954141542, 0.1378257738542743, 0.1711035124026239, 0.11313889190205373, 0.18742243439191952, 0.09304337334469892, 0.12131251307437196, 0.13030183617956936, 0.12064185648341663, 0.10556062159594148, 0.08744790640776046, 0.23691436304943636, 0.1326021080603823, 0.09627221297705546, 0.13056449708528817, 0.13729078928008676], [0.07572699003503658, 0.068151050072629, 0.021208903344813734, 0.06410338406567462, 0.03332185180624947, 0.018514847906772047, 0.08942054235376418, 0.06094027645303868, 0.028034038477926515, 0.017565308917255607, 0.020260011879145168, 0.06702474449411966, 0.05190257645153906, 0.07318178715649992, 0.056339461807510816, 0.03381575479579624, 0.04485668949200772, 0.03657099659903906, 0.004972383867425378, 0.05133451435540337, 0.05294848888297565, 0.021229906124062836, 0.025467407940595876, 0.030835326833766885, 0.027721097067114897, 0.6055692897643894, 8.647165596485138, 29.81426987797022, 40.12079693377018, 39.4011839479208, 27.343650050461292, 17.776325829327106, 17.741185314953327, 26.52676608413458, 21.02789495140314, 11.552480198442936, 2.0486992551013827, 0.6021250120829791, 3.2358811888843775, 23.34039956331253, 22.563259564340115, 3.2853673584759235, 5.156061127781868, 10.90077431872487, 10.830262452363968, 14.419142324477434, 15.508416574448347, 12.989830020815134, 15.351371951401234, 28.037696108222008, 48.42124253511429, 50.88039457798004, 47.657757103443146, 44.4282191991806, 44.82339799404144, 44.49463203549385, 43.51105481386185, 41.414866894483566, 42.47955076396465, 47.88169428706169, 51.49368926882744, 54.40271817147732, 54.144826009869576, 54.75750133395195, 56.00289590656757, 53.79997171461582, 49.94504056870937, 41.4052078127861, 35.53284332156181, 41.234726160764694, 53.06431218981743, 53.6322221159935, 53.41826319694519, 51.09404571354389, 53.551636040210724, 52.68182851374149, 55.69346711039543, 53.68005394935608, 54.57522511482239, 53.5451003909111, 48.81900139153004, 41.967501640319824, 40.585276409983635, 36.902806609869, 42.35504664480686, 45.64173348248005, 54.88683119416237, 43.68965283036232, 46.89286954700947, 54.6711889654398, 45.417746901512146, 38.673522993922234, 36.026003658771515, 41.08089901506901, 45.06413787603378, 51.29781737923622, 53.7975512444973, 53.68369795382023, 54.18722793459892, 52.2668793797493, 50.70689208805561, 46.44142337143421, 43.276170417666435, 40.46121686697006, 36.300470530986786, 42.45207063853741, 51.02525420486927, 53.674939423799515, 55.38946442306042, 52.03615576028824, 49.384551644325256, 45.265983045101166, 47.973854541778564, 54.42441500723362, 53.80682274699211, 49.99648980796337, 54.60994005203247, 53.476517871022224, 55.21053962409496, 52.71032318472862, 51.84375688433647, 52.196286767721176, 51.6698744148016, 41.89051777124405, 38.52200612425804, 22.973344959318638, 12.730823568999767, 11.899234391748905, 2.3892923165112734, 3.890612656250596, 12.890335209667683, 14.244459047913551, 14.240442663431168, 10.692830476909876, 3.711714930832386, 6.949507892131805, 0.8489074604585767, 0.11640523225651123, 0.07316121482290328, 1.4656895329244435, 6.442910050973296, 19.463646188378334, 32.67449609935284, 27.445277497172356, 20.1762143522501, 28.984153121709824, 40.05493126809597, 44.246015176177025, 28.196829669177532, 7.099890997633338, 0.5287373531609774, 0.03544623097695876, 0.02279250733408844, 0.039812623435864225, 0.04866245246375911, 0.07017248222837225, 0.016617237524769735, 0.026176138562732376, 0.03147771873045713, 0.024513208263670094, 0.028026451873301994, 0.04464152232685592, 0.022179994302859996, 0.04036717473354656, 0.04215817745716777, 0.006801977342547616, 0.030525938454957213, 0.010703469943109667, 0.03411870689888019, 0.014295539840532001, 0.09429310550331138, 0.04394642310217023, 0.003712753778017941, 0.06352776690619066, 0.03251366040785797, 0.06557119631906971, 0.012756146516039735, 0.05890205691684969, 0.0842132706020493, 0.041253128365497105, 0.11963828728767112, 0.05761781118053477, 0.041342260301462375, 0.015746056342322845, 0.01850999797170516, 0.039027497987262905, 0.03770896131754853, 0.06121916070696898, 0.11028284789063036, 0.05242092578555457, 0.06007983043673448, 0.04792443483893294, 0.03971109392296057, 0.049367080864612944, 0.016950805074884556, 0.018276388436788693, 0.052154301811242476, 0.007016435756668216, 0.07656992136617191, 0.023048099283187184, 0.040294191931025125, 0.8797760540619493, 10.978893376886845, 36.806747764348984, 47.15171925723553, 44.51018460094929, 34.380623549222946, 24.874086566269398, 25.50451833754778, 28.47282785922289, 24.120738990604877, 13.090840000659227, 2.551630293019116, 0.8564652549102902, 4.453135896474123, 20.307522006332874, 13.459884747862816, 1.3875168026424944, 10.35460302606225, 10.933833494782448, 14.678158275783062, 18.092879243195057, 14.913739934563637, 13.788460716605186, 17.399272061884403, 29.01963371783495, 50.890954211354256, 53.563590198755264, 51.288732066750526, 46.026421040296555, 46.13261394202709, 45.30524633824825, 44.912822395563126, 43.46098490059376, 45.59350647032261, 49.96446892619133, 53.84632542729378, 53.60292188823223, 54.52305771410465, 53.783491998910904, 56.29845164716244, 55.98543584346771, 52.34181135892868, 42.616180032491684, 37.37000674009323, 43.237925469875336, 55.37633992731571, 53.937227949500084, 53.590842336416245, 52.682360485196114, 53.053744956851006, 52.358279675245285, 56.192254945635796, 53.998514860868454, 56.20861306786537, 55.33135034143925, 51.697886511683464, 44.218960627913475, 42.30005979537964, 38.765063881874084, 43.384525403380394, 49.03743267059326, 56.70211158692837, 46.330454126000404, 50.588190257549286, 57.37527206540108, 47.52962797880173, 41.0868114978075, 39.338358119130135, 43.21121670305729, 47.27936580777168, 54.89858776330948, 55.368782132864, 55.19992679357529, 56.995113864541054, 54.99150037765503, 52.51694776117802, 47.58631333708763, 45.90708464384079, 42.06784665584564, 39.33818332850933, 46.67813926935196, 52.869891822338104, 55.094691440463066, 58.22550684213638, 53.856151700019836, 52.57175602018833, 48.485090509057045, 52.2307813167572, 55.08321225643158, 54.14661571383476, 48.84788364171982, 53.53644825518131, 53.02040934562683, 55.179430693387985, 53.8887045532465, 53.758177757263184, 53.70401166379452, 51.615582928061485, 42.08654545247555, 40.41208550333977, 25.981755629181862, 16.67285744100809, 14.254238773137331, 9.122561886906624, 10.862931199371815, 14.690501913428307, 11.626098398119211, 11.47304356098175, 15.959179736673832, 6.7433257307857275, 5.452795755118132, 1.5215489105321467, 0.17010928684612736, 0.15184516611043364, 1.6754449275322258, 7.574709244072437, 23.529676906764507, 33.616024777293205, 29.020044095814228, 25.274896658957005, 36.899250000715256, 46.986903101205826, 48.68225812911987, 35.24708345532417, 8.129799608141184, 0.8561308728531003, 0.04431261360878125, 0.07092930958606303, 0.05836048207129352, 0.012512401099229464, 0.03187818903825246, 0.03133223552140407, 0.013673522680619499, 0.006146338573671528, 0.03341321389598306, 0.07197194543550722, 0.022093764164310414, 0.036929149646312, 0.05924030556343496, 0.026939502386085223, 0.0338567732978845, 0.030020491358300205, 0.025110978531301953, 0.00734196445591806, 0.023256499916897155, 0.014454313986789202, 0.06116131400631275, 0.041224589076591656, 0.030522472625307273, 0.0502109806984663, 0.038833122089272365, 0.09630074113374576, 0.17397926043486223, 0.19599808438215405, 0.1956562660052441, 0.2947425248567015, 0.21910684125032276, 0.1492078701267019, 0.13716600456973538, 0.10192547837505117, 0.15779377659782767, 0.13790696481009945, 0.18469624395947903, 0.1571249234257266, 0.12148603462264873, 0.15278534847311676, 0.19992541114334017, 0.22846481879241765, 0.08320138935232535, 0.11561999548575841, 0.21950754162389785, 0.11856193566927686, 0.07267764623975381, 0.20301206270232797, 0.1941652616369538, 0.11665972953778692, 1.4875169866718352, 14.18992342427373, 43.37143890559673, 55.88837765157223, 53.06431218981743, 39.71130430698395, 29.171198084950447, 28.386207707226276, 37.951500937342644, 30.425478480756283, 15.72566706687212, 2.7741171419620514, 1.2245182553306222, 4.817884024232626, 30.010054372251034, 29.967703744769096, 10.117604043334723, 19.13514431566, 22.1348724514246, 21.7841911688447, 26.52045652270317, 22.562927082180977, 18.844499811530113, 19.82813213020563, 31.147546134889126, 53.583485931158066, 55.34197077155113, 53.338072299957275, 49.10841666162014, 49.718546122312546, 47.96641834080219, 47.222376465797424, 47.109047546982765, 47.47521869838238, 51.18328392505646, 56.693584844470024, 56.260753870010376, 54.63931247591972, 53.154948726296425, 56.90117530524731, 58.05929236114025, 54.732551872730255, 44.88237462937832, 39.55984063446522, 45.4970296472311, 57.79575750231743, 55.75697310268879, 54.82113651931286, 52.05152593553066, 55.313932076096535, 53.4071259945631, 57.6562137901783, 54.54279765486717, 59.31208893656731, 57.85330541431904, 54.1962106525898, 47.01078861951828, 43.933793529868126, 41.16357497870922, 45.57925343513489, 51.95487432181835, 59.382077381014824, 49.916067123413086, 53.07665012776852, 58.06339234113693, 49.51689854264259, 44.06955644488335, 41.52849979698658, 45.79083368182182, 49.965133890509605, 56.17259860038757, 58.15271034836769, 56.908394917845726, 58.70420515537262, 58.04528251290321, 54.872722551226616, 50.57712905108929, 48.40575836598873, 45.44866964221001, 41.92234106361866, 47.19117633998394, 54.8018791526556, 58.67255285382271, 59.53689247369766, 58.83711062371731, 54.73540931940079, 50.02480208873749, 53.99758391082287, 57.99755707383156, 56.94131255149841, 49.73350211977959, 54.47102330625057, 54.737635999917984, 56.591746509075165, 53.51356968283653, 53.82702626287937, 54.890361204743385, 54.38582807779312, 44.03014495968819, 44.205395355820656, 28.339025638997555, 17.765762396156788, 16.724164187908173, 8.344792071729898, 9.892307482659817, 26.69512365013361, 21.87899798154831, 24.286759681999683, 24.26399890333414, 14.44495813921094, 12.748762406408787, 3.094764123670757, 0.8811119792517275, 0.2353037244756706, 2.0758219622075558, 8.625805992633104, 26.950213462114334, 44.458689764142036, 39.334824308753014, 33.212057054042816, 43.00231531262398, 52.884144857525826, 57.472307458519936, 40.89035823941231, 12.117913607507944, 1.0852842265740037, 0.19091152295004576, 0.1421035872772336, 0.16759040794568136, 0.1789988504606299, 0.14802693505771458, 0.0795142661081627, 0.11974867433309555, 0.192367572162766, 0.12411961244652048, 0.08746833773329854, 0.14596990949939936, 0.08555172651540488, 0.1593796571251005, 0.1205414290598128, 0.1573988056043163, 0.10353869220125489, 0.08073247925494798, 0.08401698738452978, 0.12155942560639232, 0.2080252702580765, 0.12731927825370803, 0.12189358501927927, 0.14733939460711554, 0.13516851409804076, 0.11233541314140894], [0.013884060699638212, 0.023574204060423654, 0.007105454051270499, 0.034192546881968156, 0.015671203327656258, 0.08100328894215636, 0.039073733787517995, 0.06040565553121269, 0.030925178652978502, 0.020155571291979868, 0.02913103478931589, 0.07416008622385561, 0.011713819585565943, 0.07904714351752773, 0.03318383460282348, 0.0075441050739755156, 0.036680352059192955, 0.03798683625063859, 0.00804375646112021, 0.09288693603593856, 0.09036166724399664, 0.035284131081425585, 0.016976681909000035, 0.036254622755222954, 0.025131465517915785, 0.1452789403265342, 6.009737094864249, 25.879351124167442, 36.34170971810818, 40.41802078485489, 26.784882433712482, 11.906759887933731, 11.601071041077375, 19.02888871729374, 18.605486936867237, 11.036693975329399, 2.0751914335414767, 0.9313629765529186, 0.9038138017058372, 8.639095779508352, 25.0873102247715, 10.95949161797762, 8.633908107876778, 7.637761160731316, 12.275346759706736, 21.26126702874899, 11.858190894126892, 11.233197581022978, 20.000393986701965, 32.939357087016106, 47.283526584506035, 49.05109293758869, 47.26825900375843, 45.252151787281036, 49.080894738435745, 50.086643770337105, 50.13335086405277, 46.040252298116684, 40.96691653132439, 42.30728320777416, 48.142443895339966, 50.79256609082222, 55.20426996052265, 54.62963819503784, 55.96360981464386, 49.46484133601189, 51.61627449095249, 40.785103887319565, 35.29665179550648, 41.672318279743195, 54.34441789984703, 51.28686636686325, 53.72959949076176, 51.377879083156586, 54.673734828829765, 55.00807888805866, 53.826729878783226, 52.09870420396328, 53.270774111151695, 46.571399196982384, 46.829994320869446, 37.67735704779625, 37.66919128596783, 37.03523710370064, 43.589782789349556, 45.52133694291115, 53.334059715270996, 42.18763902783394, 46.470795795321465, 53.482787534594536, 44.855084493756294, 38.702842220664024, 38.019787073135376, 42.86128968000412, 50.54573513567448, 50.02837389707565, 50.393541902303696, 52.634965628385544, 54.4227696955204, 53.44750642776489, 52.385805398225784, 53.84718798100948, 53.09170491993427, 51.0802448540926, 44.30151119828224, 36.49780534207821, 40.90770050883293, 45.2622402459383, 46.02871231734753, 45.10632321238518, 40.60836777091026, 42.026071697473526, 45.82051008939743, 50.05634419620037, 53.43532048165798, 52.16789089143276, 51.4130499958992, 52.61574245989323, 53.4500864893198, 51.98746897280216, 53.550993874669075, 50.32940894365311, 49.5793329924345, 49.31263290345669, 35.043072402477264, 27.2195316106081, 22.245727702975273, 11.597411837428808, 10.340396538376808, 13.255756851285696, 10.775020066648722, 10.533011052757502, 13.431378677487373, 9.681231658905745, 7.562177516520023, 5.308318957686424, 1.5310543379746377, 0.2013138507027179, 0.09894415241433308, 1.4030488254502416, 6.044544652104378, 19.686755016446114, 32.85702310502529, 20.74538581073284, 25.825392119586468, 32.491053342819214, 47.22975566983223, 40.476055070757866, 24.46747038513422, 8.067392706871033, 0.43039408803451806, 0.04894059457001276, 0.0253435082413489, 0.04610359035723377, 0.05080551891296636, 0.018112778270733543, 0.06990925729041919, 0.025071709642361384, 0.013120214480295544, 0.06195169757120311, 0.047123022959567606, 0.014525177957693813, 0.020094882165722083, 0.044004418232361786, 0.022705173250869848, 0.05340294672350865, 0.027290348989481572, 0.06343824905343354, 0.05909819541557226, 0.03218980571546126, 0.04564893584756646, 0.03374179235834163, 0.015562975931970868, 0.010440766363899456, 0.037910472965450026, 0.061553594714496285, 0.028540494895423763, 0.03172413031279575, 0.003265181676397333, 0.023822348557587247, 0.014645519986515865, 0.039615861533093266, 0.049325709842378274, 0.00842210612972849, 0.011966960591962561, 0.017714252389851026, 0.08322098947246559, 0.08091106967185624, 0.02115067072736565, 0.024586126128269825, 0.048607192147755995, 0.024504534412699286, 0.02298526535014389, 0.049574551958357915, 0.017679660886642523, 0.04683872844907455, 0.06450536093325354, 0.09334485599538311, 0.037420566441142, 0.045238828752189875, 0.03061597210034961, 0.20899743918562308, 8.484236039221287, 32.030704244971275, 45.25936760008335, 47.18427591025829, 32.085516303777695, 18.41199181973934, 18.0805679038167, 28.395002335309982, 23.347476683557034, 11.67113833129406, 2.758443458005786, 1.0546236718073487, 2.0070378156378865, 15.62824409455061, 34.60762716829777, 9.009552150964737, 8.864752370864153, 9.633242134004831, 16.73190627247095, 13.080736342817545, 13.338061384856701, 16.249075680971146, 19.727129749953747, 32.61196285486221, 50.417233631014824, 53.293059915304184, 49.501600563526154, 48.94794747233391, 50.25590568780899, 51.99771322309971, 51.36591352522373, 47.1646461635828, 43.04490342736244, 45.38662277162075, 50.682455599308014, 52.26162426173687, 57.15141087770462, 54.44532908499241, 56.117471158504486, 53.087521344423294, 52.13846907019615, 43.055444061756134, 36.94124534726143, 43.94652284681797, 55.993833392858505, 54.18698474764824, 54.00103412568569, 51.12232759594917, 55.143895000219345, 56.32858783006668, 54.68766488134861, 54.392682909965515, 55.41567921638489, 49.71620924770832, 49.06753845512867, 41.63171745836735, 39.74345438182354, 38.56098063290119, 44.87457364797592, 48.15438665449619, 56.12364962697029, 46.93820871412754, 48.953407779335976, 55.8453943580389, 47.38587409257889, 41.89489133656025, 39.7820071130991, 45.54035112261772, 51.98599465191364, 54.047505632042885, 52.0132277905941, 53.47933351993561, 55.87299607694149, 54.045560136437416, 53.4535177052021, 56.26598618924618, 54.50454130768776, 52.54088267683983, 45.01624144613743, 38.373152911663055, 42.995726466178894, 48.901912942528725, 47.85998225212097, 48.867380395531654, 44.07951571047306, 45.27558133006096, 48.563484102487564, 54.11990314722061, 53.221638947725296, 50.779141411185265, 52.439177334308624, 54.41029496490955, 52.458309307694435, 54.955531507730484, 53.071410208940506, 52.49655045568943, 52.126047536730766, 51.78019389510155, 35.988058894872665, 29.793215207755566, 21.45855814218521, 20.07156416773796, 15.168191380798817, 15.766651667654514, 14.257065821439028, 14.745756648480892, 6.3023527432233095, 15.342564024031162, 9.631712716072798, 4.277977645397186, 2.494775843806565, 0.19941485807066783, 0.45858759549446404, 1.2967566540464759, 7.358133690431714, 20.09787205606699, 38.20106014609337, 27.423668056726456, 30.100918896496296, 37.57153272628784, 52.034404054284096, 47.779833152890205, 28.76808911561966, 10.257749073207378, 0.3301796311279759, 0.010313809943909291, 0.03225071377528366, 0.04043442815600429, 0.06062107873731293, 0.08714917712495662, 0.07118172143236734, 0.03136703853670042, 0.02380271689617075, 0.02002374174480792, 0.04752877364808228, 0.040283542111865245, 0.04104432140593417, 0.04949180620315019, 0.023706419524387456, 0.07842447419534437, 0.047972707834560424, 0.025075635603570845, 0.054221368627622724, 0.0725045774015598, 0.01913602180138696, 0.09431633472559042, 0.060875193812535144, 0.05506937624886632, 0.025580830370017793, 0.06183350313222036, 0.1031054338091053, 0.10229356135823764, 0.07902907222160138, 0.18097958323778585, 0.08219865878345445, 0.2009331586305052, 0.15887334913713858, 0.1303616532823071, 0.10274165528244339, 0.1132835067983251, 0.12787480547558516, 0.23675337637541816, 0.14097984210820869, 0.14995208097388968, 0.14267069200286642, 0.14200454024830833, 0.07985605479916558, 0.13478111301083118, 0.10168678141781129, 0.21515290107345209, 0.21023915614932775, 0.22751013486413285, 0.0959060521563515, 0.0804216974938754, 0.14212411508196965, 0.7442005758639425, 11.69889584183693, 39.700942263007164, 51.84536799788475, 53.59395816922188, 37.959484308958054, 20.74344791471958, 19.737493693828583, 30.89095540344715, 26.019187420606613, 14.345068149268627, 3.4623072389513254, 1.2371164793148637, 1.5385113190859556, 14.106957726180553, 34.58687648177147, 16.680107451975346, 18.216593004763126, 17.469520792365074, 22.3766515776515, 28.330757282674313, 21.856670379638672, 17.75032952427864, 26.58965650945902, 34.265269339084625, 53.09641666710377, 56.74301639199257, 53.91869634389877, 51.1837512999773, 53.61620597541332, 55.422450453042984, 54.65538941323757, 49.83677297830582, 46.911465749144554, 46.244780123233795, 52.974629402160645, 53.68756614625454, 58.921762481331825, 54.404078498482704, 57.3715178668499, 54.04810979962349, 56.837365329265594, 45.717816799879074, 39.24909330904484, 44.93925757706165, 58.53367030620575, 53.65758575499058, 54.438371658325195, 52.05941051244736, 56.47260770201683, 57.132651284337044, 57.17428185045719, 56.47793121635914, 57.35259868204594, 50.386637672781944, 52.756589502096176, 42.680666372179985, 41.83151073753834, 41.54347479343414, 48.38563844561577, 50.847537741065025, 58.75672973692417, 50.7747982442379, 52.41922080516815, 57.88445994257927, 50.40754035115242, 42.39525608718395, 41.86881713569164, 47.8754398226738, 55.93545712530613, 55.836692824959755, 52.357747703790665, 53.906795382499695, 57.36717090010643, 53.91656465828419, 54.85258363187313, 57.31361277401447, 58.13963145017624, 56.117984130978584, 49.269273430109024, 39.89989958703518, 45.09062245488167, 49.12949413061142, 49.59849536418915, 49.48503725230694, 45.45536868274212, 46.485314816236496, 51.60254582762718, 55.32519847154617, 55.53640253841877, 50.90821288526058, 52.314099445939064, 53.65590624511242, 52.412947341799736, 54.254503324627876, 54.280657321214676, 52.97891557216644, 51.082642525434494, 52.59596072137356, 37.182847782969475, 30.194091796875, 23.25421068817377, 16.34176030755043, 19.822723120450974, 19.94519244879484, 14.672068152576685, 16.100509352982044, 21.858319491147995, 15.45442907139659, 12.08870742470026, 11.511122267693281, 3.6610688734799623, 0.5894243123475462, 0.5423887737561017, 2.3342681815847754, 8.529059384018183, 26.16283491253853, 44.979949593544006, 32.05677844583988, 38.646468445658684, 44.150967076420784, 57.408147901296616, 56.643454134464264, 35.83787575364113, 13.483498580753803, 0.8076634048484266, 0.14448585163336247, 0.11978164795436896, 0.2110943922889419, 0.16533824207726866, 0.1787256807438098, 0.1992705845623277, 0.07739797263639048, 0.09944453064235859, 0.16794036026112735, 0.10174969327636063, 0.12517214112449437, 0.11289164540357888, 0.20422746310941875, 0.10081517350045033, 0.10442886865348555, 0.08846560609526932, 0.21005495509598404, 0.12063435337040573, 0.17808510339818895, 0.10836974703124724, 0.18784738815156743, 0.09311428555520251, 0.12180633071693592, 0.15330440655816346, 0.21634841192280874], [0.012540490461105946, 0.053657577591366135, 0.02711923199967714, 0.020179646562610287, 0.025958353471651208, 0.02107696247549029, 0.07870646804803982, 0.013884125637559919, 0.01744330169458408, 0.06665124383289367, 0.023064383858582005, 0.0156782537305844, 0.010644658450473798, 0.07244624459417537, 0.07889158936450258, 0.030528829120157752, 0.054324193188222125, 0.05012564855860546, 0.03620826450060122, 0.01922992760228226, 0.04659578640712425, 0.03787211135204416, 0.09179715896607377, 0.03931791150534991, 0.026147404460061807, 0.20911786006763577, 5.111507568508387, 24.724161811172962, 35.464363396167755, 39.34970051050186, 31.72207150608301, 21.091053262352943, 18.65048222243786, 21.124899946153164, 24.358477033674717, 9.383869115263224, 2.619146495126188, 0.02905915036535589, 0.14417796424822882, 0.2281257018330507, 0.8884461200796068, 1.190803258214146, 2.8406577464193106, 8.517620097845793, 14.157644156366587, 13.05925514549017, 16.47135615348816, 20.30558981001377, 16.755210421979427, 27.706272192299366, 46.66324406862259, 48.6216551810503, 47.607565596699715, 50.680741891264915, 51.6497240960598, 54.49981816112995, 51.406605541706085, 50.23399606347084, 42.93067015707493, 39.796358942985535, 42.28937476873398, 47.579671293497086, 53.508204370737076, 53.64087425172329, 54.25766475498676, 50.62854789197445, 50.40896527469158, 40.18982023000717, 34.63553287088871, 42.09552437067032, 51.71842820942402, 51.65183678269386, 50.76915554702282, 52.71813176572323, 51.40575438737869, 48.45485933125019, 48.22152145206928, 48.651491180062294, 48.86753998696804, 44.713200107216835, 39.79849822819233, 36.54876060783863, 38.647995963692665, 36.47349804639816, 45.24983391165733, 44.22943666577339, 54.61308628320694, 43.65393854677677, 43.086340203881264, 55.07689319550991, 43.583779111504555, 39.153931215405464, 36.66245050728321, 43.178086280822754, 47.03903630375862, 53.51420044898987, 50.07478080689907, 53.75635005533695, 51.718329414725304, 52.34231673181057, 52.11426816880703, 50.79662807285786, 53.847051188349724, 54.80112299323082, 51.072645261883736, 46.21304802596569, 36.11124448478222, 36.14228881895542, 36.902559623122215, 37.71995656192303, 36.46464452147484, 43.793391063809395, 48.92157308757305, 53.7604234367609, 49.11302201449871, 49.42914605140686, 52.63605237007141, 51.25339396297932, 50.74528522789478, 51.614108607172966, 51.81310772895813, 56.83537803590298, 50.275410041213036, 44.59645517170429, 42.5918385386467, 24.566320180892944, 18.477278016507626, 24.559940323233604, 17.40817118436098, 16.52362994849682, 19.564327485859394, 13.05023442953825, 2.3971260711550713, 21.445477344095707, 3.4814753104001284, 2.5889395410194993, 1.750681484118104, 0.21208633203059435, 0.332768865628168, 0.7818466401658952, 5.646811919286847, 18.368208669126034, 29.76419236510992, 26.531494930386543, 25.72042655199766, 33.94503012299538, 42.68114134669304, 42.24336303770542, 29.732616059482098, 5.773849077522755, 0.753325370606035, 0.0445096649491461, 0.037425527698360384, 0.04813621038920246, 0.01080594012819347, 0.023396917968057096, 0.08836896362481639, 0.007648894006706541, 0.08033436897676438, 0.03289284592028707, 0.026495427191548515, 0.022468652641691733, 0.02383336759521626, 0.0351068282907363, 0.013332891739992192, 0.00846396418637596, 0.03505000946461223, 0.016386255192628596, 0.0376207941735629, 0.05866590181540232, 0.09336024071672, 0.016084555463748984, 0.04445304279215634, 0.05873880298167933, 0.023057058861013502, 0.03485277258732822, 0.008754307200433686, 0.07025129831163213, 0.034354594827163965, 0.021832108868693467, 0.041305238264612854, 0.053267471375875175, 0.03293266585387755, 0.040045167988864705, 0.02542548958444968, 0.045904550061095506, 0.048876792134251446, 0.005123333921801532, 0.050768775181495585, 0.03232572635170072, 0.031857872745604254, 0.030265678396972362, 0.04499207949265838, 0.03706826893903781, 0.026029835280496627, 0.08867878059390932, 0.04519137954048347, 0.028270310467632953, 0.06835276581114158, 0.018542411271482706, 0.034261262335348874, 0.2620767167536542, 6.418907688930631, 30.706188417971134, 41.54828153550625, 44.99560475349426, 34.89773020148277, 18.589596189558506, 17.55855191498995, 22.022147700190544, 24.35739789158106, 11.585824359208345, 2.700811238028109, 0.26644452300388366, 0.18742581858532503, 0.564472476253286, 3.3348345290869474, 3.0381858721375465, 5.90986467897892, 8.113781567662954, 14.531794879585505, 14.168428927659988, 11.599003002047539, 14.603141751140356, 21.111429668962955, 31.086301021277905, 48.17045219242573, 51.82228423655033, 48.95369656383991, 50.48228994011879, 53.151768296957016, 54.79638084769249, 53.59084993600845, 51.873969063162804, 45.354297906160355, 41.60610303282738, 46.22258171439171, 50.270409509539604, 55.17582468688488, 54.1961270570755, 54.3871808052063, 52.752360329031944, 51.82969383895397, 41.698327884078026, 36.56334422528744, 44.582950696349144, 53.126549050211906, 52.2887472063303, 51.5229856967926, 55.11426419019699, 53.85451778769493, 52.29947783052921, 52.5118712335825, 51.63931265473366, 51.341545432806015, 47.77166359126568, 41.946595162153244, 38.67731899023056, 40.263475477695465, 36.95644453167915, 46.90556466579437, 47.12113469839096, 56.10925979912281, 46.26209579408169, 47.036509439349174, 56.84433035552502, 46.13736368715763, 41.219215393066406, 38.547255769371986, 45.107033774256706, 50.24726115167141, 55.04635043442249, 52.98980578780174, 55.35505346953869, 52.201028913259506, 53.041129633784294, 52.27416358888149, 52.00774468481541, 54.9139579385519, 57.31171287596226, 53.52252200245857, 46.44389323890209, 37.99334429204464, 38.330671191215515, 39.163818284869194, 39.936742410063744, 39.067090675234795, 44.727833122015, 50.983171463012695, 55.56497320532799, 51.43478102982044, 50.059916004538536, 52.939428091049194, 52.35447607934475, 52.60224938392639, 52.78818100690842, 50.8877319842577, 54.93105702102184, 50.4037519544363, 47.43546903133392, 43.682239428162575, 30.370951406657696, 26.174606680870056, 26.236657351255417, 17.930988930165768, 17.788905054330826, 14.922790098935366, 16.858695968985558, 5.57383731007576, 17.23441030830145, 12.869116198271513, 4.665720714256167, 2.1997819980606437, 0.22548217180883512, 0.2530236728489399, 1.2430097255855799, 6.4942666701972485, 21.249179877340794, 33.71978580951691, 28.115360140800476, 31.20984759181738, 40.8686576038599, 49.58783693611622, 47.78502367436886, 34.42665047943592, 7.879718877375126, 0.6603201956022531, 0.013168509740353329, 0.03568472384358756, 0.065147571003763, 0.03543524719134439, 0.034002438333118334, 0.08139121695421636, 0.021190015686443076, 0.07893133879406378, 0.05837625270942226, 0.03039460614672862, 0.058119176464970224, 0.020252883550710976, 0.05174836187507026, 0.003526421369315358, 0.0561732318601571, 0.11220609390875325, 0.01534070455818437, 0.03927554229449015, 0.01644588861381635, 0.05110465266625397, 0.017187973207910545, 0.04059805316501297, 0.02769122933386825, 0.020577061077347025, 0.016389938100473955, 0.13160567090380937, 0.18293717585038394, 0.13051161164185032, 0.147498689184431, 0.11002328174072318, 0.1535902076284401, 0.17983939207624644, 0.09386748381075449, 0.0823517118988093, 0.14649266347987577, 0.1336494565475732, 0.08632615019450895, 0.15529251628322527, 0.1696206271299161, 0.23979774035979062, 0.08475668597384356, 0.14700468600494787, 0.12327595381066203, 0.13599505880847573, 0.1681824043043889, 0.14898403838742524, 0.16679806140018627, 0.26955700130201876, 0.09603210593922995, 0.1611110579688102, 0.7341425155755132, 9.268700145184994, 37.77075983583927, 49.43644925951958, 52.72401005029678, 42.152536511421204, 30.985973104834557, 29.063253477215767, 30.22274225950241, 32.021827921271324, 13.529140781611204, 3.3730963384732604, 0.5455088813323528, 0.3668320190627128, 0.6848378456197679, 1.5538641577586532, 2.1441745944321156, 5.37440026178956, 13.782669827342033, 22.53730695694685, 21.895568892359734, 26.291932985186577, 30.547780618071556, 22.209359854459763, 31.897574588656425, 51.54997564852238, 52.94216014444828, 52.788488790392876, 55.06412208080292, 55.20552769303322, 57.00584828853607, 55.69302253425121, 55.17306223511696, 48.688417598605156, 43.400948122143745, 48.34159500896931, 51.650294065475464, 57.80846782028675, 55.08361503481865, 56.070889458060265, 56.248628720641136, 55.599794536828995, 45.608021691441536, 38.87399643659592, 47.291715145111084, 56.82226113975048, 53.390441089868546, 52.3391705006361, 56.56274266541004, 56.432641446590424, 53.982901498675346, 54.22005817294121, 53.12689483165741, 53.59392397105694, 49.82306331396103, 43.05776193737984, 41.54186747968197, 41.65634013712406, 41.29880212247372, 48.931171372532845, 50.17423667013645, 59.11683641374111, 50.17970837652683, 49.34863597154617, 59.856896102428436, 48.59491981565952, 42.007049918174744, 41.08686089515686, 46.76198557019234, 52.682147696614265, 58.04722800850868, 55.02702087163925, 57.18024753034115, 53.945503905415535, 53.62588785588741, 52.573610320687294, 51.53540343046188, 55.08916273713112, 58.884581476449966, 55.337718799710274, 51.650381460785866, 41.076206266880035, 40.994081273674965, 40.854864344000816, 41.67193450033665, 41.31845846772194, 47.245916202664375, 55.31310752034187, 58.089865520596504, 50.40698178112507, 49.46731500327587, 53.68594363331795, 51.6889151930809, 54.07192312180996, 53.862368166446686, 52.3192747682333, 56.7393533885479, 52.68326483666897, 48.12252536416054, 46.69769302010536, 30.038672536611557, 22.77973774820566, 30.06573088467121, 24.50160775333643, 21.923166811466217, 29.048153087496758, 27.273646406829357, 11.097443215548992, 31.95699580013752, 13.200784251093864, 5.616270108148456, 4.812638880684972, 0.4946882708463818, 0.6100049579981714, 1.3996740127913654, 7.764858165755868, 25.656143501400948, 40.194547176361084, 38.678318336606026, 37.3272742331028, 46.57924957573414, 53.379087299108505, 54.36419203877449, 41.71867199242115, 10.082827359437943, 0.9991025947965682, 0.15630461275577545, 0.14239624579204246, 0.15289494884200394, 0.1661868582596071, 0.1618877748842351, 0.2030409619328566, 0.0681412908306811, 0.2231649641180411, 0.1102344821265433, 0.15488969336729497, 0.15812033641850576, 0.09458373053348623, 0.14437435136642307, 0.14379317552084103, 0.17021698731696233, 0.17421805387130007, 0.0760433601681143, 0.14155392302200198, 0.17520715860882774, 0.19995288545032963, 0.11308133092825301, 0.15970909647876397, 0.13917370699346066, 0.09065155012649484, 0.1609540788922459], [0.041899832140188664, 0.07464323920430616, 0.023783142751199193, 0.08574608014896512, 0.18509597954107448, 0.02751780612015864, 0.04068944494065363, 0.0451522646471858, 0.06857822285383008, 0.007119526098904316, 0.07004701474215835, 0.025284054790972732, 0.0880881943157874, 0.008802873344393447, 0.0649521486775484, 0.022689324687235057, 0.03835779134533368, 0.016714273333491292, 0.03311618413135875, 0.018981944522238337, 0.022669654063065536, 0.02165058882383164, 0.11012547547579743, 0.051147452322766185, 0.05418352651759051, 0.1697818809770979, 5.268207835033536, 18.27191423624754, 40.92032343149185, 42.19997316598892, 34.86325845122337, 31.93758264183998, 28.404944501817226, 35.757985040545464, 18.558183275163174, 8.362778406590223, 2.1145965065807104, 0.20739827421493828, 0.21332671312848106, 0.743089847965166, 2.812518593855202, 6.3025555573403835, 9.486100729554892, 6.844175644218922, 18.428545631468296, 7.0165320206433535, 7.221002373844385, 12.413667887449265, 19.10050917416811, 32.600096091628075, 44.3200846016407, 49.457078352570534, 49.16718050837517, 50.87349034845829, 51.8994352966547, 55.033541321754456, 50.399423986673355, 51.54921568930149, 47.99990214407444, 40.7519468665123, 39.81370881199837, 42.28846661746502, 49.498575925827026, 52.092096358537674, 54.372908771038055, 53.152273669838905, 47.771849781274796, 39.768935814499855, 36.307173371315, 44.447738751769066, 51.23545132577419, 53.604692593216896, 52.43946231901646, 51.856554597616196, 47.67389863729477, 46.15402579307556, 46.32388427853584, 43.094118386507034, 41.62075124680996, 37.14117921888828, 38.27797941863537, 36.64668895304203, 38.10851231217384, 40.02386413514614, 47.075810730457306, 44.81281936168671, 56.65286622941494, 43.98034103214741, 43.16909596323967, 54.82067294418812, 44.16181929409504, 39.69353266060352, 36.04196660220623, 42.02748902142048, 44.5035919547081, 49.98838484287262, 51.0448307543993, 49.81015160679817, 50.44109635055065, 52.3378823697567, 52.69989274442196, 55.290179550647736, 50.39916180074215, 53.21303240954876, 54.1574527323246, 51.44607402384281, 43.90336476266384, 40.52241638302803, 39.28329907357693, 38.34894061088562, 40.0396902859211, 47.17849642038345, 50.09353660047054, 55.111634731292725, 49.461820498108864, 52.514819875359535, 48.86335261166096, 52.182968482375145, 51.658900603652, 54.99879978597164, 54.919790625572205, 53.51194716989994, 54.788796454668045, 47.89111018180847, 37.51593790948391, 30.016512125730515, 26.23125024139881, 31.79439302533865, 16.245000399649143, 21.320192366838455, 12.763858996331692, 15.363720338791609, 4.910825612023473, 13.883565813302994, 13.044776022434235, 4.017319707199931, 2.750028809532523, 0.2133963562664576, 0.27692925883457065, 0.6367834866978228, 5.128152100369334, 13.945755176246166, 32.48131066560745, 34.038326516747475, 30.585812777280807, 24.089238680899143, 38.363497629761696, 46.85383044183254, 28.967741802334785, 9.11237558349967, 0.2135587381781079, 0.07575274255941622, 0.01718936844554264, 0.07323102865484543, 0.04128628752368968, 0.01776509321643971, 0.03096172571531497, 0.05687563752871938, 0.04031470860354602, 0.05949743375822436, 0.02824576207785867, 0.04729004700493533, 0.02494116772140842, 0.04258581036992837, 0.04485405115701724, 0.025797917842282914, 0.06419203360565007, 0.051167764904676005, 0.03313628149044234, 0.030689157138112932, 0.0333101147407433, 0.08697371114976704, 0.04868672440352384, 0.049917401920538396, 0.0363136606029002, 0.04219997892505489, 0.08790713996859267, 0.015662538753531408, 0.0748498753819149, 0.03643601477961056, 0.056301007425645366, 0.022982174305070657, 0.08312798352562822, 0.0412794671865413, 0.0359927039971808, 0.03772089505218901, 0.05530108217499219, 0.08226528138038702, 0.012903291208203882, 0.007766426542730187, 0.06434650422306731, 0.04375790274934843, 0.019206316173949745, 0.01357891740553896, 0.02365706484852126, 0.04049903582199477, 0.024398563145950902, 0.027690010356309358, 0.018806636253430042, 0.020122670030104928, 0.03769384748011362, 0.2873969846405089, 7.2256348002702, 24.237884804606438, 46.11757054924965, 47.375702038407326, 38.55037920176983, 34.44190666079521, 26.40711810439825, 33.84203664958477, 24.993031583726406, 10.168870892375708, 2.602791697718203, 0.22590132197365165, 0.3387969749746844, 0.7648351311217993, 3.692048848606646, 7.338055092841387, 9.145768191665411, 12.03699504956603, 10.561497174203396, 15.473961923271418, 16.809824891388416, 14.612535797059536, 21.704961620271206, 35.91866321861744, 46.269623190164566, 52.58744917809963, 51.69563703238964, 52.69118741154671, 53.51591795682907, 54.92485195398331, 52.78560094535351, 54.20552775263786, 48.853248953819275, 42.97292768955231, 42.53290370106697, 44.57529790699482, 52.03277014195919, 54.80380564928055, 56.84876091778278, 54.674806371331215, 49.1673780977726, 41.55738964676857, 37.118285447359085, 47.23268151283264, 53.92833262681961, 53.64151641726494, 51.97322353720665, 54.77140098810196, 51.028791815042496, 50.07486820220947, 48.19303438067436, 46.638784781098366, 44.84585098922253, 39.68251705169678, 40.45868240296841, 39.048714861273766, 39.251585975289345, 42.15277589857578, 48.84221434593201, 49.14489470422268, 58.78551319241524, 45.73503367602825, 47.19382479786873, 56.68200686573982, 46.851132586598396, 42.1335831284523, 37.93460324406624, 43.93059030175209, 46.776922568678856, 51.82259202003479, 53.12037818133831, 53.083645552396774, 52.80319780111313, 55.88343791663647, 55.62148757278919, 54.543785601854324, 50.92214293777943, 53.98300789296627, 55.31254895031452, 52.9231421649456, 45.84000684320927, 42.29012332856655, 40.0850560516119, 40.73093019425869, 41.53754711151123, 49.08712260425091, 53.93155485391617, 56.889133751392365, 49.44971814751625, 50.933736115694046, 50.16409881412983, 52.224720641970634, 52.03930579125881, 57.17345729470253, 54.69135828316212, 55.16037091612816, 54.86523695290089, 48.1946986913681, 41.22833490371704, 32.52966687083244, 28.6329360678792, 28.744990155100822, 19.47466179728508, 16.976181864738464, 19.065020978450775, 10.303166136145592, 8.50580558180809, 12.535788584500551, 11.133031155914068, 4.739862810820341, 2.81243191100657, 0.5775681766681373, 0.06256157226744108, 0.8267962688114494, 5.492288935929537, 19.06133897602558, 37.70997069776058, 38.94008629024029, 34.78737652301788, 30.247872211039066, 42.10855387151241, 54.02720332145691, 34.92915831506252, 10.74498362839222, 0.399865546496585, 0.027162296973983757, 0.06388639492797665, 0.05658746900735423, 0.01855134487414034, 0.04801836475962773, 0.025223543780157343, 0.014955371279938845, 0.08186096674762666, 0.022900948097230867, 0.05036162554461043, 0.02658688390511088, 0.03598401715862565, 0.036677620955742896, 0.025112130715569947, 0.056603495686431415, 0.07828368878108449, 0.06296830630162731, 0.020588375118677504, 0.09614195121685043, 0.03447123817750253, 0.07048958708764985, 0.035143520071869716, 0.01612187992577674, 0.039636311412323266, 0.028403084397723433, 0.17378006799845025, 0.13700596784474328, 0.12685355090070516, 0.26242341846227646, 0.2490683225914836, 0.11378306124242954, 0.13457491470035166, 0.2526599611155689, 0.1364017408923246, 0.07827459747204557, 0.18856682610930875, 0.12402880325680599, 0.16935069317696616, 0.06737657444318756, 0.10541501964326017, 0.09142717608483508, 0.09916875598719344, 0.1873524350230582, 0.10906922121648677, 0.09684423814178444, 0.09869183704722673, 0.054821851445012726, 0.1587655150797218, 0.1323918576235883, 0.0919523420452606, 0.5082960531581193, 8.572214618325233, 28.382501006126404, 54.1164643317461, 54.5749781280756, 45.604324489831924, 42.24310465157032, 39.84507232904434, 47.024642676115036, 26.385322473943233, 12.104683667421341, 3.2211622036993504, 0.52807422936894, 0.6389522203244269, 1.9272259483113885, 8.686747122555971, 10.776023212820292, 17.440528348088264, 15.971709564328194, 26.94030549377203, 14.90860641002655, 12.94316852465272, 15.289133191108704, 24.181077852845192, 36.08026474714279, 48.31838205456734, 55.436901077628136, 53.93743693828583, 54.482061713933945, 56.124132201075554, 54.88250322639942, 54.131560921669006, 55.90732343494892, 52.82228037714958, 45.25852784514427, 45.15103921294212, 46.85796841979027, 53.54177936911583, 57.440674155950546, 58.805405125021935, 56.60750426352024, 52.21274748444557, 43.607216253876686, 39.540176689624786, 50.061698108911514, 55.744338780641556, 54.93268333375454, 52.9451809823513, 57.111041843891144, 52.76792049407959, 51.84741988778114, 50.440609976649284, 47.273046746850014, 46.03017523884773, 40.993446707725525, 42.737906500697136, 41.35381177067757, 41.40920139849186, 44.56143245100975, 51.782808154821396, 53.008485585451126, 61.463172510266304, 48.82129646837711, 49.77686159312725, 59.90912429988384, 49.7959403693676, 45.34923657774925, 40.73661848902702, 46.07225798070431, 48.679567873477936, 54.33647632598877, 56.06858678162098, 54.67670626938343, 54.58405964076519, 58.324749916791916, 58.06617759168148, 56.202879175543785, 53.430384546518326, 54.88517448306084, 56.895642802119255, 56.09140455722809, 48.23669023811817, 44.7845184803009, 44.3536140024662, 43.33212621510029, 44.99925635755062, 52.20538727939129, 55.18569655716419, 57.64546416699886, 50.27856767177582, 53.06442618370056, 48.56622375547886, 53.203149139881134, 52.60905481874943, 57.16268867254257, 55.96264846622944, 57.27812647819519, 56.629691272974014, 50.78259162604809, 45.0298523157835, 35.927440747618675, 36.80179663002491, 37.12105169892311, 23.107861541211605, 28.10211595147848, 21.963539645075798, 32.822665348649025, 19.630715623497963, 23.576271906495094, 20.68431928753853, 6.568199777975678, 4.505907939746976, 0.6583222153130919, 0.4769312299322337, 1.0797447175718844, 6.481316965073347, 20.453542470932007, 43.012551963329315, 46.381443589925766, 40.91240845620632, 33.63099217414856, 50.001060962677, 58.393967002630234, 41.403083726763725, 13.787831850349903, 0.6905250123236328, 0.14061743655474856, 0.2200187774724327, 0.22375123109668493, 0.09694965279777534, 0.1547693318570964, 0.11918337302631699, 0.12201141580590047, 0.13023719511693344, 0.16923476970987394, 0.09293644470744766, 0.1392969480366446, 0.0949690536072012, 0.14824172743828967, 0.0884232739917934, 0.21608224808005616, 0.14218805852578953, 0.12471364228986204, 0.10565456264885142, 0.19904736138414592, 0.12372223689453676, 0.1562110279337503, 0.164021939272061, 0.2251528066699393, 0.1019192740204744, 0.10765610524686053], [0.06062861895770766, 0.032558181846980006, 0.046243403558037244, 0.017868908544187434, 0.008459644886897877, 0.04635125987988431, 0.03400509893253911, 0.017463491822127253, 0.03755262048798613, 0.036331535229692236, 0.027313453902024776, 0.01718767078273231, 0.02718867104704259, 0.03736591097549535, 0.02636107434227597, 0.034201623348053545, 0.023613220619154163, 0.032789969409350306, 0.003922294072253862, 0.01854186393757118, 0.05643619704642333, 0.01041385330609046, 0.057774411761783995, 0.05543005630897824, 0.018567688821349293, 0.11690561048453674, 3.0176116386428475, 18.611308224499226, 39.70082826912403, 39.863847121596336, 31.680724024772644, 15.477096755057573, 19.31432370096445, 23.244207724928856, 16.941890604794025, 8.719998188316822, 1.7076480807736516, 0.13182941358536482, 0.20045681856572628, 0.3967108251526952, 2.36458960454911, 5.935860984027386, 7.407019967213273, 8.191210012882948, 7.557826275005937, 21.184488348662853, 22.718728221952915, 13.271927833557129, 18.549856022000313, 29.473711252212524, 40.256366059184074, 50.43200723826885, 51.741542369127274, 53.291414603590965, 54.914748296141624, 50.986207500100136, 53.210482746362686, 52.962169870734215, 49.89792689681053, 45.93441277742386, 40.78254282474518, 39.83393132686615, 40.06017878651619, 44.66743156313896, 47.843802720308304, 47.045461758971214, 43.231484815478325, 38.20838615298271, 39.6010722219944, 48.22725534439087, 51.51687182486057, 51.39028161764145, 52.21317306160927, 47.8739845007658, 45.754454433918, 42.87509813904762, 40.01329690217972, 39.046055004000664, 36.25069320201874, 37.15949043631554, 38.448651060462, 37.033219411969185, 38.82861167192459, 41.75809107720852, 48.06050889194012, 45.46601191163063, 55.98095968365669, 43.44130575656891, 43.87116149067879, 53.28664965927601, 44.86068919301033, 41.25516526401043, 36.71114109456539, 38.16416412591934, 40.90168543159962, 43.17996717989445, 46.30838871002197, 47.777036502957344, 47.76126354932785, 48.592571541666985, 49.97958451509476, 52.87615388631821, 52.37854018807411, 50.12262783944607, 51.2362302839756, 55.02359725534916, 49.05623026192188, 49.72081460058689, 49.74079392850399, 46.819883063435555, 43.674848824739456, 46.98729828000069, 52.6339852809906, 52.494376972317696, 48.9871309697628, 50.501030534505844, 50.9541030228138, 54.7656062990427, 52.980230301618576, 52.6974418759346, 50.0284156948328, 53.66988189518452, 52.148359939455986, 52.945541962981224, 41.50640018284321, 38.644249364733696, 32.66937777400017, 27.31656890362501, 24.803955629467964, 18.8246363773942, 19.192008264362812, 8.520806226879358, 4.8224542289972305, 10.26555385440588, 12.729350198060274, 7.539684623479843, 1.0152767831459641, 0.503030545078218, 0.08893298101611435, 0.7801636273507029, 5.427225027233362, 14.382551237940788, 26.762402839958668, 29.195524379611015, 27.791773304343224, 31.884761676192284, 42.0707231014967, 41.942582577466965, 31.964382603764534, 6.882376419380307, 0.3087028570007533, 0.04242421142407693, 0.043787377144326456, 0.04711499292170629, 0.06207347287272569, 0.009139940120803658, 0.06039161409717053, 0.06550524165504612, 0.06014715807395987, 0.06307402523816563, 0.0418209455528995, 0.0012880771896561782, 0.046923240515752696, 0.05799106693302747, 0.08660819599754177, 0.05809551308630034, 0.08129115318297409, 0.011392520664230688, 0.02224907155323308, 0.0240335860507912, 0.03813996729149949, 0.010116439480043482, 0.06415874828235246, 0.02183009393775137, 0.06105228509113658, 0.03764826848055236, 0.013112712294969242, 0.09649030791479163, 0.06759469164535403, 0.05061108364316169, 0.04806753575394396, 0.03834743096376769, 0.07104828328010626, 0.0453023417503573, 0.051835182021022774, 0.07344233294134028, 0.026863742095883936, 0.03144438145682216, 0.006702082873744075, 0.024254532690974884, 0.07244170265039429, 0.053212307539070025, 0.0217483983215061, 0.020421827903192025, 0.0377509297686629, 0.021996040013618767, 0.021570002718362957, 0.012521782773546875, 0.04835882500628941, 0.020673981853178702, 0.022311484317469876, 0.17452292813686654, 4.198621278628707, 22.835712544620037, 46.14901766180992, 47.10030421614647, 37.099875435233116, 22.66405675560236, 25.55034387856722, 32.651264145970345, 18.88142053037882, 9.65769287198782, 1.8259799061343074, 0.35292141081299633, 0.16947430529398844, 1.0466811480000615, 2.191191609017551, 9.167836457490921, 10.610206760466099, 12.638396378606558, 11.242141351103783, 13.887500502169132, 17.439964078366756, 15.844195056706667, 20.916557125747204, 31.732169464230537, 42.92115546762943, 53.79408203065395, 54.77881819009781, 54.09421272575855, 53.846314027905464, 50.135642141103745, 53.00036542117596, 53.28982248902321, 52.807886749506, 47.855148911476135, 43.307735323905945, 41.38053573668003, 42.59816139936447, 46.357938051223755, 51.90057523548603, 50.303999707102776, 44.75333735346794, 40.021295472979546, 41.00291199982166, 48.72752510011196, 54.005118906497955, 51.2358883023262, 53.51609654724598, 50.16403801739216, 49.02833595871925, 45.55146172642708, 42.59947992861271, 40.74776329100132, 38.71401362121105, 38.241524174809456, 40.56412674486637, 37.560954093933105, 40.82640387117863, 43.76405283808708, 49.54217478632927, 47.436593770980835, 57.24121145904064, 45.280258879065514, 46.25746764242649, 55.97351588308811, 47.2179839015007, 42.50627093017101, 38.47012370824814, 39.69274990260601, 43.502144291996956, 47.46946580708027, 49.70241218805313, 50.248568281531334, 50.52983678877354, 50.77906921505928, 52.20946066081524, 55.27674727141857, 53.6743276566267, 49.338897094130516, 53.1091345846653, 55.26993043720722, 53.21488291025162, 51.17739424109459, 50.657863318920135, 48.26274923980236, 45.01670882105827, 49.48799729347229, 54.836115315556526, 53.12265045940876, 49.160052090883255, 50.270033329725266, 50.49811229109764, 54.59913343191147, 54.747386276721954, 54.92571070790291, 53.07584077119827, 55.75233355164528, 54.50281240046024, 53.32890719175339, 43.27147386968136, 38.256651163101196, 31.586578376591206, 21.80599819868803, 15.820718966424465, 15.56611267849803, 13.981339316815138, 16.58414740115404, 10.405233409255743, 13.023965489119291, 11.825712136924267, 7.597791580483317, 3.285638331435621, 0.7175250572618097, 0.10198452364420518, 0.9234802995342761, 5.543315447866917, 16.942901350557804, 30.102036036551, 32.78417341411114, 32.74943567812443, 31.984388530254364, 47.257801964879036, 48.114222809672356, 35.55960528552532, 8.977187387645245, 0.32624283456243575, 0.05474603734910488, 0.04606532893376425, 0.056090782964020036, 0.0029903590575486305, 0.008947809219534975, 0.06833398947492242, 0.08517391397617757, 0.04379214173241053, 0.039715112652629614, 0.003903622100551729, 0.03159796891850419, 0.08762070807279088, 0.054546006285818294, 0.02724666803260334, 0.03244968727813102, 0.021206817909842357, 0.020365790187497623, 0.03195353187038563, 0.023678165962337516, 0.048680486652301624, 0.07152629317715764, 0.03534352515998762, 0.019201349350623786, 0.041093522086157463, 0.0053855820078752, 0.15381237695692107, 0.15780360263306648, 0.17852895223768428, 0.07303171747480519, 0.14223724807379767, 0.17233277612831444, 0.19599042541813105, 0.1499359169974923, 0.22010868124198169, 0.155706352670677, 0.1535003335447982, 0.07383659889455885, 0.1445677550509572, 0.15907942870398983, 0.1679036091081798, 0.17922146507771686, 0.2210152888437733, 0.1289712099242024, 0.142763119074516, 0.13713400316191837, 0.23382077983114868, 0.10220463722362183, 0.13262691063573584, 0.11195694009074941, 0.12232551496708766, 0.27526996505912393, 5.264213299378753, 29.987631775438786, 52.9669576138258, 52.9317183047533, 43.78048315644264, 24.708189368247986, 28.83978746831417, 34.53282058238983, 24.729169942438602, 12.696702349931002, 2.411972349509597, 0.5275398236699402, 0.531617954839021, 1.5912343212403357, 5.05782357417047, 14.028326645493507, 13.181733973324299, 17.711951583623886, 16.655613966286182, 33.58808107674122, 31.406764425337315, 18.534062169492245, 19.482305087149143, 31.757799088954926, 43.64459864795208, 55.74619308114052, 56.407577991485596, 54.627084732055664, 53.82139876484871, 51.06739394366741, 53.6019491404295, 58.05805742740631, 54.971087872982025, 50.175714790821075, 44.90110382437706, 44.620827063918114, 42.10582561790943, 47.11834564805031, 53.08652199804783, 51.47587962448597, 47.78758093714714, 42.29021072387695, 43.35872478783131, 52.21601530909538, 54.63951386511326, 51.928431540727615, 55.51664359867573, 53.14136825501919, 50.76001323759556, 47.23520837724209, 43.7041262537241, 42.15827040374279, 40.123528987169266, 41.59230597317219, 43.34790296852589, 40.55860184133053, 42.253029718995094, 46.27242363989353, 52.21056640148163, 50.07993333041668, 57.011099606752396, 48.10612164437771, 50.79111076891422, 57.53653161227703, 51.55173875391483, 45.461034178733826, 41.175042763352394, 40.66264405846596, 46.09176993370056, 48.92051674425602, 52.36499771475792, 52.94565595686436, 53.542812913656235, 53.83824326097965, 53.45846123993397, 55.53819604218006, 55.31524680554867, 49.958522245287895, 53.978569731116295, 58.155525997281075, 54.26252469420433, 55.15581116080284, 54.52175438404083, 51.413087993860245, 49.41578596830368, 51.62012368440628, 57.56288319826126, 53.46830651164055, 49.85006846487522, 50.32030463218689, 50.90536303818226, 55.60465447604656, 55.65128557384014, 57.95073218643665, 55.19657537341118, 58.49192574620247, 57.309926971793175, 56.762247160077095, 47.56802871823311, 44.659554585814476, 34.89474356174469, 36.444953978061676, 32.56938613951206, 27.4279922246933, 32.04715736210346, 21.280995570123196, 11.793907843530178, 22.9130706936121, 23.546327613294125, 16.406858414411545, 3.5734849981963634, 1.6350643755868077, 0.5177124822512269, 1.216043047606945, 7.212116550654173, 19.28314447402954, 36.73852242529392, 43.139062374830246, 40.14779828488827, 42.663061916828156, 55.15027105808258, 55.93621328473091, 42.4125337600708, 11.71143801882863, 0.6775294721592218, 0.14283884782344103, 0.13118744100211188, 0.1365840865764767, 0.1114804219105281, 0.15487989701796323, 0.18647515709744766, 0.1863044482888654, 0.16605932760285214, 0.1625699718715623, 0.14095652382820845, 0.16425844689365476, 0.23744189646095037, 0.13854982797056437, 0.17710410291329026, 0.15590668801451102, 0.15570615971228108, 0.1451691469992511, 0.08572090649977326, 0.15403027151478454, 0.13754776533460245, 0.2069641771959141, 0.19892214622814208, 0.138034985284321, 0.1550295585184358, 0.07193937999545597], [0.03626747304224409, 0.07571247362648137, 0.042044083384098485, 0.06061246611352544, 0.04300879001675639, 0.03708647382154595, 0.08273830404505134, 0.04287283598387148, 0.06774770023184828, 0.05138677639479283, 0.07535992379416712, 0.04162653625826351, 0.10106544053996913, 0.014235461130738258, 0.06439859556849115, 0.0013388745310294325, 0.05280998186208308, 0.037783606530865654, 0.007176979925134219, 0.039994457038119435, 0.08600309331086464, 0.08942886925069615, 0.06980917867622338, 0.07359618015470915, 0.09157170192338526, 0.08412976414547302, 2.607631213031709, 17.590836882591248, 40.937202125787735, 44.13010619580746, 35.412063002586365, 20.275491625070572, 17.06801913678646, 21.063176058232784, 20.475818775594234, 8.149273563176394, 2.372415284626186, 0.17779783287551254, 0.16673122358042747, 0.9975613025017083, 1.0322834830731153, 9.513348117470741, 11.682966146618128, 13.514313027262688, 8.10723926872015, 10.277389269322157, 18.15407495945692, 16.91893793642521, 22.617131173610687, 32.20877029001713, 41.10588647425175, 48.00803750753403, 50.640464052557945, 51.39042221009731, 52.79242157936096, 51.17730684578419, 49.78417620062828, 55.05385123193264, 50.16236990690231, 49.115195497870445, 47.722129449248314, 44.561360254883766, 43.192947283387184, 41.57544627785683, 40.61704270541668, 41.15845665335655, 41.84667952358723, 43.106733709573746, 47.12773494422436, 50.833216309547424, 53.05602863430977, 49.93495590984821, 52.191331833601, 48.03489446640015, 46.507068648934364, 38.87898936867714, 39.411067217588425, 36.09188452363014, 37.87169001996517, 36.106935515999794, 36.41946114599705, 38.74726563692093, 41.60296440124512, 44.5800818502903, 49.66753765940666, 48.4881379455328, 55.20261324942112, 41.47778391838074, 42.35783189535141, 52.752797305583954, 45.185187980532646, 42.799706384539604, 36.383032500743866, 37.36899979412556, 36.84370078146458, 40.84177404642105, 41.01457357406616, 44.009280279278755, 45.25508902966976, 47.34299719333649, 45.88418327271938, 51.38229064643383, 52.863838747143745, 52.53221534192562, 51.31702534854412, 52.47691310942173, 53.38167496025562, 53.2685474306345, 51.347359120845795, 49.30351719260216, 47.931733801960945, 50.498142689466476, 52.97077640891075, 50.90234600007534, 51.35783515870571, 50.479242503643036, 52.85640634596348, 54.095234870910645, 52.51668177545071, 51.3542253524065, 48.77705544233322, 49.45228300988674, 52.27393560111523, 54.255377277731895, 48.19156385958195, 37.91498489677906, 39.48662616312504, 33.12290623784065, 20.732485502958298, 16.56433716416359, 14.45433508604765, 8.340116422623396, 6.407277463003993, 10.055944751948118, 5.05281544290483, 2.0462189381942153, 2.6495591131970286, 0.977857222314924, 0.013286603061715141, 0.7234460301697254, 5.0505906622856855, 19.494768418371677, 34.01691846549511, 35.706801787018776, 37.440850138664246, 44.765097722411156, 47.3926567286253, 48.72036628425121, 25.34106820821762, 6.839660061523318, 0.5318993772380054, 0.015058163371577393, 0.05135149469424505, 0.045023164348094724, 0.0417560558707919, 0.04662958381231874, 0.042487505488679744, 0.06586832998436876, 0.06812955747591332, 0.07688435449381359, 0.020075085376447532, 0.003573683188733412, 0.050232135617989115, 0.02022354459768394, 0.028397117530403193, 0.03567863823263906, 0.06371463226969354, 0.09199500811519101, 0.09044944847119041, 0.04507174533500802, 0.023042501634336077, 0.07523669017245993, 0.031629484219592996, 0.09397309884661809, 0.027559158588701393, 0.09936909875250421, 0.025205114397977013, 0.027195480251975823, 0.019857849474647082, 0.06301920278929174, 0.019846793329634238, 0.02722134224313777, 0.06206065598235, 0.0184822583469213, 0.049193062077392824, 0.011123493986815447, 0.029303439405339304, 0.020599396011675708, 0.02574964855739381, 0.056997709689312615, 0.04885613816441037, 0.004449959678822779, 0.020530598922050558, 0.11206452923943289, 0.06380636172252707, 0.04490460625675041, 0.04197515641862992, 0.039427278097718954, 0.042770876025315374, 0.05700840032659471, 0.05396149819716811, 0.024581053548899945, 4.066554140299559, 22.15821649879217, 45.830837935209274, 49.724899381399155, 38.48869331181049, 19.88880157470703, 19.851350784301758, 27.43640497326851, 25.390389561653137, 10.665993466973305, 2.360470863059163, 0.3908065950963646, 0.22474342316854745, 1.3364459993317723, 3.1606943858787417, 7.907292572781444, 10.243102759122849, 12.64463184401393, 10.416674595326185, 14.924496207386255, 22.559845447540283, 17.483355849981308, 20.428853295743465, 28.5113824903965, 43.83914440870285, 50.737431049346924, 53.02521988749504, 51.73277243971825, 53.39468166232109, 51.18318513035774, 53.13915677368641, 55.68197272717953, 51.82804472744465, 51.88490107655525, 48.73125270009041, 45.39175249636173, 45.57858467102051, 42.685906291007996, 42.975842133164406, 42.57253557443619, 44.50677238404751, 43.54658670723438, 47.835914343595505, 52.689804285764694, 54.95628386735916, 51.812400966882706, 53.67386408150196, 49.73384790122509, 47.454961985349655, 40.895020589232445, 40.53908608853817, 37.3992233723402, 38.3454903960228, 37.58349448442459, 39.46505472064018, 40.485573559999466, 43.087506741285324, 47.635125517845154, 51.08086422085762, 52.288211435079575, 56.96593143045902, 43.108113035559654, 46.29496403038502, 54.66509789228439, 47.89831839501858, 44.309144988656044, 37.7156475931406, 40.44130213558674, 37.970598712563515, 42.28352688252926, 44.159953594207764, 46.40292763710022, 47.59797491133213, 49.757262244820595, 48.5668621212244, 52.47437484562397, 54.56485167145729, 53.76618392765522, 50.160580202937126, 52.14153550565243, 53.36070388555527, 53.119268640875816, 51.57773695886135, 51.37140043079853, 49.78476516902447, 52.941365987062454, 53.260149881243706, 50.57377003133297, 50.16240790486336, 50.57592831552029, 53.336639776825905, 56.49576745927334, 53.857059851288795, 52.539602145552635, 51.788868829607964, 51.420368403196335, 54.63447153568268, 55.02944894134998, 50.711611434817314, 40.92489078640938, 31.675970479846, 21.4122861251235, 13.493620287626982, 21.879353262484074, 14.450377598404884, 15.322970375418663, 12.787237241864204, 11.135360430926085, 9.6072543784976, 3.227474852465093, 2.6529197953641415, 0.23942252533743158, 0.08440501929726452, 0.6934836285654455, 6.246456792578101, 20.428040139377117, 36.82496018707752, 39.23891365528107, 37.92840577661991, 46.990984082221985, 52.68074557185173, 54.62425388395786, 31.470468007028103, 9.121296554803848, 0.5627484375145286, 0.02363236060773488, 0.03602369237341918, 0.032407195612904616, 0.014233954570954666, 0.058547981971059926, 0.0348757494793972, 0.10683879285352305, 0.0322608626447618, 0.05084648175397888, 0.013932599013060099, 0.04323007618950214, 0.06233047490241006, 0.0402548247075174, 0.03494918128126301, 0.13517626211978495, 0.013975452475278871, 0.05409375262388494, 0.014749409529031254, 0.07382747047813609, 0.030130340346659068, 0.05041262964368798, 0.03953689330955967, 0.02640944567247061, 0.038348284433595836, 0.026600071869324893, 0.08351111726369709, 0.15595037082675844, 0.18764760199701414, 0.16883243661141023, 0.14032557955943048, 0.13612959533929825, 0.1821432262659073, 0.20485819957684726, 0.13470404839608818, 0.2156982311862521, 0.1355499483179301, 0.1531195524148643, 0.15516897838097066, 0.14729479153174907, 0.2243007320794277, 0.16490156238432974, 0.17872725409688428, 0.2619885199237615, 0.1625415327725932, 0.12285498538403772, 0.1524891721783206, 0.1504495128756389, 0.1179308800783474, 0.16728917020373046, 0.20072457060450688, 0.1581482560141012, 5.822846973314881, 26.70813985168934, 54.17813882231712, 56.46388716995716, 46.23765550553799, 28.348682820796967, 26.920381262898445, 32.433942407369614, 28.692229986190796, 11.892625596374273, 3.705671592615545, 0.5776308733038604, 0.49058440199587494, 2.150785527192056, 4.135539438575506, 19.038097523152828, 21.584743671119213, 24.37774769961834, 17.993396781384945, 23.716491982340813, 27.992303743958473, 21.539174616336823, 27.395429871976376, 36.9108621776104, 45.987138748168945, 53.28677885234356, 55.41281037032604, 51.6972329467535, 52.86293439567089, 50.59743516147137, 51.249138191342354, 56.59037098288536, 56.915272548794746, 54.92001101374626, 51.22897267341614, 50.7057711482048, 49.209050461649895, 45.58319382369518, 45.64996384084225, 43.87445971369743, 47.26309888064861, 46.86894603073597, 51.77862077951431, 55.76026372611523, 53.450200483202934, 51.83918572962284, 56.25286169350147, 53.14372792840004, 49.767339304089546, 44.11706529557705, 43.33363853394985, 39.75085258483887, 41.0883504152298, 39.446868896484375, 41.06177844107151, 42.32114866375923, 45.56483320891857, 50.52618518471718, 53.357272669672966, 54.02992017567158, 58.57072971761227, 45.39916589856148, 50.146619752049446, 58.09224799275398, 50.07109500467777, 46.198730394244194, 40.12198247015476, 41.98373056948185, 40.20034186542034, 44.90643873810768, 46.282090321183205, 47.848940044641495, 49.78432059288025, 52.80186787247658, 50.81558905541897, 56.249571070075035, 56.16637073457241, 54.954391568899155, 52.458575293421745, 52.87252128124237, 53.8155584782362, 54.60163749754429, 53.70838522911072, 53.4913294762373, 52.26538226008415, 56.21258765459061, 54.897615015506744, 50.669661685824394, 50.17699912190437, 50.373482778668404, 54.58764664828777, 58.21655832231045, 55.61099633574486, 55.96883453428745, 53.42686593532562, 54.92985248565674, 57.40953482687473, 59.17146988213062, 51.33385844528675, 43.913221433758736, 41.038527488708496, 37.66263283789158, 28.386221006512642, 24.251524172723293, 21.796464510262012, 18.74289896339178, 20.39787355810404, 20.429463163018227, 13.978818152099848, 7.60776462033391, 5.449658548459411, 2.4282969860360026, 0.31993630109354854, 0.999427477363497, 6.814305922016501, 26.163682267069817, 44.323861598968506, 48.43643791973591, 49.23868127167225, 56.12872615456581, 58.3737862855196, 63.67537200450897, 36.43100492656231, 11.38967888429761, 1.0365048190578818, 0.13458604691550136, 0.2749265288002789, 0.11132177300169133, 0.16731011361116543, 0.12039733366691507, 0.11981658084550872, 0.20910393737722188, 0.1494988810736686, 0.22184696921613067, 0.0876457110280171, 0.14758642588276416, 0.13759552995907143, 0.08383502019569278, 0.12676707585342228, 0.22485496796434745, 0.14165878848871216, 0.28848144051153213, 0.1818172007915564, 0.1359744419460185, 0.09323463222244754, 0.13752038008533418, 0.1231111673405394, 0.20894988236250356, 0.2015468553872779, 0.14265106961829588], [0.03851460714940913, 0.0759408695739694, 0.03101809368672548, 0.05385409829614218, 0.023629714851267636, 0.02692438669328112, 0.042111262591788545, 0.027608871350821573, 0.008680971877765842, 0.08405909684370272, 0.017304829925706144, 0.03006058217579266, 0.02446802260237746, 0.0447464100579964, 0.038850221171742305, 0.014119433762971312, 0.020783624895557296, 0.029146278502594214, 0.05711156627512537, 0.0631358906684909, 0.007946357000037096, 0.028146306867711246, 0.0205900579385343, 0.055450354047934525, 0.0161409438442206, 0.08359446786926128, 1.044478453695774, 16.733146905899048, 38.910508677363396, 44.7394984960556, 34.59148943424225, 25.41128844022751, 18.802819848060608, 21.81599736213684, 17.674998566508293, 9.661932494491339, 2.0860415138304234, 0.34575431258417666, 0.05598622177785728, 1.324737521354109, 4.167380779981613, 5.536450641229749, 8.447688650339842, 9.27881520241499, 8.597165029495955, 9.557047672569752, 15.729810744524002, 15.294410157948732, 18.38491827249527, 20.936496555805206, 35.82263857126236, 45.41507184505463, 52.22218617796898, 51.279563158750534, 50.82121655344963, 50.873288959264755, 52.31064923107624, 50.21026633679867, 54.30895820260048, 50.71481466293335, 53.64850424230099, 52.63102903962135, 50.60731463134289, 51.03584423661232, 51.699018850922585, 48.19456189870834, 50.48362746834755, 45.979387164115906, 51.17238610982895, 52.369812056422234, 52.623870223760605, 53.561906889081, 53.28071057796478, 47.3617871850729, 42.95014791190624, 37.32377462089062, 37.002855241298676, 36.00793182849884, 35.814222022891045, 35.60068488121033, 36.61058709025383, 35.99644884467125, 43.92512999475002, 47.62357793748379, 53.161446377635, 49.81050878763199, 54.97965261340141, 41.21484562754631, 43.4449003636837, 55.99676303565502, 48.231917694211006, 42.5134639441967, 37.411967888474464, 37.985167130827904, 37.98290625214577, 36.51329331099987, 38.986705988645554, 38.88656236231327, 39.94022682309151, 43.49236361682415, 47.50761575996876, 45.778925120830536, 49.19686831533909, 50.9081444889307, 51.83199271559715, 51.483182832598686, 53.15462954342365, 51.707165613770485, 52.09116540849209, 51.47518806159496, 49.162092581391335, 51.12194761633873, 50.445078536868095, 50.68967521190643, 49.93212506175041, 52.880645245313644, 53.212496638298035, 49.140775725245476, 44.400720074772835, 45.63192620873451, 46.3860185444355, 49.76814866065979, 50.252326279878616, 54.32229928672314, 47.441035732626915, 45.723649486899376, 30.88671673089266, 20.477030910551548, 12.102451287209988, 23.065269626677036, 12.600637804716825, 21.218732111155987, 9.072833005338907, 8.326292764395475, 9.502378106117249, 2.9322247579693794, 3.486250704154372, 0.38272086647339165, 0.0637669165735133, 0.8556602918542922, 4.583324510604143, 16.62815473973751, 31.068025901913643, 30.422488041222095, 37.8528506308794, 39.54874522984028, 48.997561410069466, 43.498534485697746, 29.200555309653282, 5.830862643197179, 0.6930390524212271, 0.018636714121385012, 0.03603578938054852, 0.01432993096386781, 0.025516543682897463, 0.05635385947243776, 0.045014614806859754, 0.025445329047215637, 0.07859897537855431, 0.01977803334739292, 0.04975223324436229, 0.11013105642632581, 0.037996484170434996, 0.1257466821698472, 0.054914219144848175, 0.03855702088912949, 0.05039607232902199, 0.04061775347508956, 0.02822077582095517, 0.046757140444242395, 0.08034429149120115, 0.010049346547020832, 0.04535022140771616, 0.04300485292333178, 0.051730075356317684, 0.0992765677801799, 0.02393920898612123, 0.057508288737153634, 0.021953520517854486, 0.04198418464511633, 0.05498039274243638, 0.027256967186986003, 0.047320679150288925, 0.0171729781141039, 0.0373560070147505, 0.045273164214449935, 0.021629808688885532, 0.03889829007675871, 0.006625215855819988, 0.03501855724607594, 0.019502518443914596, 0.018584672870929353, 0.028500277912826277, 0.038066505803726614, 0.0211330206002458, 0.033653094578767195, 0.01844046430051094, 0.02777523302938789, 0.046172495058272034, 0.01881644559034612, 0.0380918946757447, 0.12174817602499388, 2.3484494956210256, 19.084428437054157, 45.55550470948219, 49.53881196677685, 38.40233914554119, 28.720838651061058, 22.555823363363743, 24.272088669240475, 21.66265469044447, 12.68672313541174, 2.901548291556537, 0.38562192174140364, 0.03535615651344415, 1.1380348959937692, 3.071235786192119, 5.014789458364248, 9.189628288149834, 15.590127389878035, 9.904140047729015, 11.387516800314188, 17.790738455951214, 10.606407914310694, 19.678746946156025, 27.57516212761402, 40.14939799904823, 48.180818036198616, 52.73050770163536, 53.645517602562904, 51.0275074839592, 51.062602400779724, 50.682182013988495, 52.09968455135822, 54.4713880866766, 52.02980250120163, 55.43188914656639, 52.64885388314724, 52.06762567162514, 53.37704300880432, 51.46378107368946, 50.4274170845747, 50.27902364730835, 47.90403328835964, 53.45629155635834, 53.09031419456005, 51.517928168177605, 53.63947592675686, 55.20867012441158, 50.01387767493725, 46.14418052136898, 40.30930481851101, 39.60522159934044, 37.73808538913727, 37.11737349629402, 37.84994378685951, 38.742341101169586, 38.46342086791992, 46.23975299298763, 49.80707757174969, 54.805458560585976, 53.4122709184885, 53.829043954610825, 44.68167319893837, 45.54960362613201, 56.83397211134434, 50.27146965265274, 44.00446593761444, 38.84764865040779, 40.1442264765501, 38.87495018541813, 39.562743678689, 40.535179898142815, 41.15555360913277, 42.74972766637802, 46.61020651459694, 49.45540264248848, 50.2824092656374, 50.53144030272961, 54.58909437060356, 52.40601271390915, 51.46945796906948, 52.82900981605053, 52.08270326256752, 52.697582468390465, 54.036657214164734, 50.41077017784119, 54.36888858675957, 50.871016681194305, 51.30545116961002, 50.612147971987724, 53.68008054792881, 53.66165153682232, 51.32608786225319, 46.75023280084133, 47.58019186556339, 48.707769960165024, 52.26896546781063, 51.69225141406059, 58.23143072426319, 48.946066573262215, 45.016435235738754, 33.34886111319065, 24.249263294041157, 16.64866603910923, 19.311907030642033, 9.107651486992836, 14.280840195715427, 15.710634123533964, 10.14519626274705, 9.139094799757004, 6.036900887265801, 3.9725072868168354, 0.91738156741485, 0.10388387250714004, 0.9334121947176754, 4.919395577162504, 22.046238407492638, 36.189550682902336, 36.967395544052124, 41.75813287496567, 46.46424874663353, 54.24913801252842, 52.0970094949007, 32.28996813297272, 8.40367941185832, 0.7189767574891448, 0.005866927858733106, 0.0076653928772429936, 0.010569778532953933, 0.05089351165224798, 0.01564514281199081, 0.0322969384433236, 0.062423673807643354, 0.05302022858813871, 0.0191333129623672, 0.018320581475563813, 0.04629473049135413, 0.021221193310339004, 0.07133961335057393, 0.0585861877334537, 0.05623068893328309, 0.06795446999603882, 0.11180846602655947, 0.061083202963345684, 0.03522084443829954, 0.0371150131104514, 0.03704745540744625, 0.06924910208908841, 0.008109560840239283, 0.01704438247543294, 0.13579460472101346, 0.12841066578403115, 0.23095614917110652, 0.16189942660275847, 0.12302475166507065, 0.26754919497761875, 0.10099656181409955, 0.16626913275104016, 0.11531685042427853, 0.13632789719849825, 0.2778698271140456, 0.12144630745751783, 0.18279723648447543, 0.1952757520484738, 0.21151977649424225, 0.17100780503824353, 0.16546002851100639, 0.09824336462770589, 0.10418619378469884, 0.08814625252853148, 0.16093935468234122, 0.08428629793343134, 0.11402420728700235, 0.13304677326232195, 0.1294131885515526, 0.15207661228487268, 0.19264587754150853, 3.4697206411510706, 24.288545586168766, 52.64274001121521, 57.08871804177761, 46.407092213630676, 35.665403008461, 29.528732299804688, 32.126728892326355, 27.23014824092388, 14.178982861340046, 3.264195369556546, 0.6851464009378105, 0.27889271441381425, 3.039409168995917, 7.153458623215556, 9.423012714833021, 16.021916270256042, 18.11274077743292, 17.00686901807785, 19.00955345481634, 22.28842981159687, 23.51724587380886, 22.771910168230534, 22.937140502035618, 39.51434947550297, 49.6059163659811, 54.500600919127464, 53.488103449344635, 50.35497397184372, 51.1731992661953, 51.72735013067722, 50.95553554594517, 57.46337413787842, 54.03529308736324, 57.18219302594662, 55.30804619193077, 53.331023678183556, 56.63597233593464, 55.20409896969795, 53.74658077955246, 54.82761897146702, 50.70107840001583, 57.392557337880135, 55.27931593358517, 52.441939786076546, 55.55449716746807, 57.24951781332493, 52.411051243543625, 47.25672282278538, 40.8692541718483, 40.613771080970764, 40.60403600335121, 39.26069028675556, 40.15041634440422, 41.072767451405525, 41.30363926291466, 48.63672137260437, 51.999366134405136, 57.37456530332565, 54.81883004307747, 55.14354541897774, 47.74781987071037, 49.643127769231796, 58.368903547525406, 51.133913174271584, 45.65072380006313, 42.11540870368481, 41.57255843281746, 41.302411928772926, 40.97863130271435, 42.34165996313095, 43.34026537835598, 44.09034512937069, 48.32830712199211, 51.726932153105736, 50.98903454840183, 52.27281466126442, 58.02344128489494, 53.30440990626812, 52.376321107149124, 54.01394583284855, 52.84917153418064, 54.04539294540882, 54.48854796588421, 53.028157129883766, 54.968025237321854, 50.777640491724014, 52.01339118182659, 51.28772512078285, 55.23600585758686, 55.62771163880825, 54.59574021399021, 47.83388525247574, 50.13501897454262, 51.63125328719616, 55.33528693020344, 54.79371719062328, 61.01230390369892, 52.1235016733408, 48.40709209442139, 35.39282463490963, 23.834490850567818, 16.45764458924532, 27.630365565419197, 22.92305275797844, 36.19639791548252, 18.60782191157341, 15.23052703589201, 18.039554804563522, 7.64471716247499, 7.793429782614112, 1.3118097838014364, 0.20586361672030762, 1.687799133360386, 6.274720150977373, 22.5677927210927, 43.10801424086094, 42.801302298903465, 50.34069433808327, 50.866635516285896, 60.0106168538332, 58.716018721461296, 41.851866245269775, 10.380482487380505, 1.0999507270753384, 0.13767345546511933, 0.1431910414248705, 0.12814047950087115, 0.0986520505102817, 0.13270563766127452, 0.13362713274545968, 0.06967955516302027, 0.13746083015576005, 0.23447890154784545, 0.18592133681522682, 0.24104858573991805, 0.1681057404493913, 0.3030198463238776, 0.22406174568459392, 0.21623939042910933, 0.20021673379233107, 0.21857016457943246, 0.14912424492649734, 0.18814999144524336, 0.22992653801338747, 0.1717465982073918, 0.11716101318597794, 0.1521021273219958, 0.1908320834627375, 0.22317155438940972], [0.03796695040364284, 0.01218374285599566, 0.10019784022006206, 0.03717492669238709, 0.07641182164661586, 0.03873011941323057, 0.023032675599097274, 0.029873748353566043, 0.06855875632027164, 0.01792887593182968, 0.06953174161026254, 0.034538194740889594, 0.03920265968190506, 0.009045910937857116, 0.03752442258701194, 0.029364757501753047, 0.06095820674090646, 0.07508780792704783, 0.01361307568004122, 0.058389340483699925, 0.056723990783211775, 0.007271613958437229, 0.05231610484770499, 0.02371057926211506, 0.0660264742327854, 0.05080612005258445, 1.401006553787738, 16.675399504601955, 36.68672740459442, 43.78761537373066, 36.79654151201248, 26.338364593684673, 15.06642809137702, 26.784884333610535, 29.332605823874474, 13.856697455048561, 3.067128206603229, 0.3108190168859437, 0.13622242317069322, 1.495772993657738, 3.1743855262175202, 4.528617421165109, 8.808617983013391, 16.30247611552477, 7.053541084751487, 10.678482446819544, 27.28213705122471, 10.044767651706934, 17.775691263377666, 29.26212340593338, 39.30056914687157, 47.11172640323639, 49.328390657901764, 51.17478758096695, 50.56500390172005, 51.46096922457218, 52.39967465400696, 51.28829888999462, 51.971616223454475, 55.343517288565636, 52.92899765074253, 54.81504924595356, 52.677808329463005, 53.07945817708969, 52.69781805574894, 52.236803993582726, 52.87702023983002, 53.9779731631279, 51.96918435394764, 53.178393468260765, 52.726274728775024, 56.113450974226, 48.70413355529308, 49.724154621362686, 43.22341404855251, 36.250818595290184, 36.682163849473, 34.9179907143116, 36.0805307328701, 34.85627442598343, 37.698130533099174, 35.95281578600407, 39.51548181474209, 44.512532874941826, 50.27898944914341, 49.50855039060116, 52.634194269776344, 39.07922722399235, 40.719865188002586, 55.11066198348999, 46.980686634778976, 47.00616426765919, 38.36125575006008, 37.297309041023254, 37.237481251358986, 37.06685520708561, 37.813321352005005, 40.33909521996975, 37.84336254000664, 39.52441893517971, 41.38482190668583, 47.04962633550167, 45.778203159570694, 50.16936533153057, 50.72196587920189, 52.39399395883083, 49.88395504653454, 49.728303998708725, 46.44244931638241, 50.39135701954365, 50.641698986291885, 52.52011679112911, 50.95943793654442, 50.95628410577774, 49.53320726752281, 52.43714824318886, 48.68787802755833, 47.359100729227066, 44.987230002880096, 48.32199566066265, 45.73571003973484, 45.323470160365105, 48.952636420726776, 51.645692512393, 51.70564949512482, 45.558894127607346, 35.80896310508251, 25.362725146114826, 16.705936565995216, 30.87503805756569, 10.614681020379066, 9.426645319908857, 14.668748080730438, 10.21172309294343, 6.927028773352504, 3.8817239832133055, 2.549072317779064, 0.43581835634540766, 0.20881875971099362, 0.7108154485467821, 5.376626942306757, 16.520025841891766, 32.882280349731445, 37.42391064763069, 31.72356102615595, 34.50181424617767, 44.668548703193665, 43.935199454426765, 29.61488127708435, 6.360636865720153, 0.5809092661365867, 0.041842983628157526, 0.006363357861118857, 0.08035396167542785, 0.028950275445822626, 0.04870681063039228, 0.0754016696009785, 0.1304158300627023, 0.0945811033307109, 0.017458055590395816, 0.015909009707684163, 0.039518773774034344, 0.07785786670865491, 0.04676281416323036, 0.054322816504281946, 0.07120589318219572, 0.022606844249821734, 0.09063841411261819, 0.03084458141529467, 0.05175935679289978, 0.06331650714855641, 0.01563808869832428, 0.01963541111763334, 0.13138918642653152, 0.027518526003404986, 0.034258854066138156, 0.008418245106440736, 0.022490596093120985, 0.05427970885648392, 0.04105913838429842, 0.02107440392137505, 0.018682300542423036, 0.004375500002424815, 0.033318864661850967, 0.03158070656354539, 0.08356345351785421, 0.09214479578076862, 0.02605608318845043, 0.05277147552988026, 0.016286818536173087, 0.008036675444600405, 0.04016709171992261, 0.04303966707084328, 0.030792738689342514, 0.013678740906470921, 0.029449570138240233, 0.037664569754269905, 0.06162559046060778, 0.0554691266734153, 0.04490309227549005, 0.0042773361292347545, 0.02772532174276421, 2.0258705550804734, 20.891529768705368, 42.042380422353745, 49.41806584596634, 42.915463373064995, 31.127975285053253, 20.63690923154354, 29.985368996858597, 32.27530471980572, 15.973330177366734, 3.420890411362052, 0.32516600796952844, 0.1578967718523927, 0.2885986404726282, 3.6820171494036913, 4.817314529791474, 7.232034131884575, 11.845933701843023, 10.545801166445017, 9.504421446472406, 13.411845825612545, 9.96738575398922, 16.62547018378973, 31.67934089899063, 39.46227326989174, 46.95430085062981, 51.50225020945072, 52.49106355011463, 50.74207440018654, 51.199729442596436, 51.65340609848499, 50.92250391840935, 52.39534668624401, 54.65570479631424, 53.21240544319153, 56.11145228147507, 53.54051783680916, 53.95961634814739, 54.469499588012695, 54.321611523628235, 53.88941891491413, 53.939656019210815, 52.87034019827843, 54.01028282940388, 51.80858597159386, 56.665356159210205, 50.909827798604965, 51.99785001575947, 44.39898356795311, 38.565870970487595, 37.2634756565094, 37.23896697163582, 36.209856793284416, 38.19252200424671, 39.129973500967026, 39.59788419306278, 42.64153987169266, 47.78383433818817, 53.032469898462296, 53.82889576256275, 53.18813234567642, 41.421683728694916, 43.226203098893166, 55.66753730177879, 48.67658123373985, 47.682786360383034, 40.20530819892883, 38.983164578676224, 37.668906301259995, 39.21306364238262, 38.55731002986431, 40.62573663890362, 39.323557913303375, 42.0320525765419, 43.802077397704124, 49.36696998775005, 47.57494054734707, 51.91684976220131, 53.44260089099407, 52.63197898864746, 49.49345000088215, 50.94026416540146, 48.047034814953804, 51.304448023438454, 53.00636529922485, 52.896535992622375, 52.160792872309685, 50.79110696911812, 49.72336046397686, 54.37953941524029, 51.97480045258999, 48.53493623435497, 47.02162563800812, 49.77678939700127, 48.9749526232481, 47.706797271966934, 50.80194778740406, 54.62279096245766, 51.481081545352936, 49.31579053401947, 34.89558331668377, 24.89092156291008, 18.54390174150467, 18.47538571804762, 14.474619347602129, 12.330651842057705, 14.993421658873558, 9.643279295414686, 10.082355234771967, 4.6205454133450985, 1.0221071541309357, 0.5646970798261464, 0.1460983307333663, 0.824873453238979, 5.711068846285343, 18.831194825470448, 37.24859945476055, 42.21734583377838, 41.52856819331646, 41.313602328300476, 50.184530317783356, 48.601592257618904, 35.115918293595314, 8.22977889329195, 0.6784490228164941, 0.01178664097096771, 0.07449540338711813, 0.027298635068291333, 0.02671159068995621, 0.032843214794411324, 0.045062331191729754, 0.06172617002448533, 0.082142010651296, 0.04923612890706863, 0.0452379827038385, 0.04816353255591821, 0.04595437414536718, 0.03700264081999194, 0.059506643810891546, 0.05993338614644017, 0.03512094393954612, 0.06776151160011068, 0.04910454241326079, 0.047043538943398744, 0.041317209106637165, 0.009166407890006667, 0.0676365487743169, 0.01477147172408877, 0.022708557444275357, 0.13620048528537154, 0.13086184597341344, 0.1481863038497977, 0.19226410193368793, 0.10705896580475383, 0.15984485013177618, 0.09083719836780801, 0.16772596864029765, 0.1703003453440033, 0.10943051354843192, 0.09923514109686948, 0.16995861602481455, 0.0959869685175363, 0.20946600154275075, 0.08673214208101854, 0.14925851428415626, 0.15516032493906096, 0.09855114069068804, 0.09213520723278634, 0.14193324954248965, 0.20972631726181135, 0.08328891824930906, 0.11615056428126991, 0.13744341937126592, 0.13473935978254303, 0.17141224583610892, 0.14627528842538595, 3.029532073996961, 24.524644017219543, 49.714978113770485, 56.67526222765446, 49.058023765683174, 35.965522304177284, 25.253855288028717, 38.13499689102173, 39.88758064806461, 18.25213249772787, 4.808586873114109, 0.5142504523973912, 0.49690945947077125, 2.09136170335114, 7.0819255616515875, 12.022529225796461, 15.662299767136574, 26.67131792753935, 18.182677924633026, 21.437999345362186, 40.09545609354973, 20.91767806559801, 23.196847066283226, 35.109272450208664, 42.72996872663498, 49.63983714580536, 51.51393838226795, 54.366228729486465, 50.42195677757263, 51.566926538944244, 51.95985205471516, 52.18866057693958, 52.633628100156784, 55.82764931023121, 55.295324474573135, 56.39598861336708, 54.63164068758488, 53.54091301560402, 55.00843606889248, 54.80277210474014, 55.331802517175674, 56.02985925972462, 53.46069552004337, 54.28580604493618, 52.62625269591808, 58.51293481886387, 52.37301908433437, 54.98078495264053, 47.254009768366814, 40.54875276982784, 39.95622016489506, 38.672512248158455, 38.569446578621864, 38.122252374887466, 41.4564860612154, 41.41195245087147, 44.57334481179714, 49.27580527961254, 55.41819088160992, 55.11451877653599, 53.927109092473984, 44.372225403785706, 47.669126093387604, 59.67389792203903, 53.340754956007004, 50.98635949194431, 43.38355265557766, 41.582228913903236, 40.356388092041016, 40.67079842090607, 41.417978927493095, 43.59960526227951, 41.51535630226135, 43.86858142912388, 45.493739023804665, 51.4956309646368, 49.191822186112404, 54.86706845462322, 56.27008996903896, 54.756836369633675, 51.33939474821091, 51.43413506448269, 47.12843410670757, 52.37336866557598, 52.839930430054665, 54.458746165037155, 52.160124108195305, 51.798113733530045, 51.230120211839676, 56.74229063093662, 54.54348161816597, 51.10347680747509, 50.434085726737976, 53.07359129190445, 51.929392889142036, 49.34641309082508, 53.60849618911743, 58.03188443183899, 56.555181071162224, 52.208658903837204, 42.82150961458683, 27.77607824653387, 24.2563746124506, 38.814328238368034, 20.561057701706886, 18.874362409114838, 25.041435286402702, 20.257495790719986, 14.650497660040855, 8.776114527136087, 6.013094214722514, 2.0331730507314205, 0.3391332569299266, 1.1651802831329405, 7.214540345594287, 23.00310306251049, 42.44007088243961, 50.47498673200607, 43.383488059043884, 47.04575054347515, 57.153120785951614, 58.862850442528725, 40.72988525032997, 11.667389832437038, 1.2568270904012024, 0.17187316407216713, 0.18398778978735209, 0.29533677734434605, 0.16228507622145116, 0.08300948480609804, 0.14016186178196222, 0.2832954906625673, 0.12771215639077127, 0.0919980657636188, 0.20363727759104222, 0.18030179460765794, 0.1323709439020604, 0.15342524304287508, 0.16434541175840423, 0.20931871491484344, 0.21627211914164945, 0.11691942185279913, 0.1551339341676794, 0.09936879447195679, 0.1797827216796577, 0.05232728159171529, 0.13871356059098616, 0.19722779339645058, 0.13852765259798616, 0.22811145259765908], [0.026457303065399174, 0.037572443252429366, 0.03641483017418068, 0.04108412278583273, 0.02420217788312584, 0.08655054596601985, 0.026343340723542497, 0.05832217982970178, 0.026969344144163188, 0.03720912485732697, 0.024106385171762668, 0.031150980794336647, 0.013922827711212449, 0.04275655257515609, 0.038718066934961826, 0.06900742911966518, 0.01584577501489548, 0.018918518726422917, 0.016416078397014644, 0.033506928593851626, 0.07955395616590977, 0.03645057571702637, 0.023413443741446827, 0.034434902627253905, 0.06408721266780049, 0.03655343367427122, 1.0267767473123968, 13.823726624250412, 37.19217248260975, 46.72363042831421, 35.16357533633709, 25.998307541012764, 27.761468030512333, 28.141812421381474, 22.737869694828987, 12.327669002115726, 3.5222696838900447, 0.350294208037667, 0.23416289506712928, 0.4036194778745994, 1.440294070634991, 1.945602830965072, 3.8119853753596544, 12.464504409581423, 7.561138272285461, 8.238458577543497, 7.073381720110774, 4.382752273231745, 14.778018817305565, 30.24954792112112, 35.55396258831024, 42.99820013344288, 49.99845430254936, 53.197540640830994, 51.73886351287365, 52.19391189515591, 51.644446179270744, 55.10519787669182, 54.86326865851879, 52.60481424629688, 50.50914689898491, 49.615925028920174, 52.570095509290695, 52.561082392930984, 52.57297195494175, 53.25951911509037, 52.90225088596344, 53.20755310356617, 52.646851390600204, 52.411575615406036, 50.730975195765495, 51.3718032091856, 48.2688707113266, 44.6428506821394, 37.282379642128944, 36.156902834773064, 36.37436516582966, 32.78674587607384, 35.025433748960495, 35.60956500470638, 37.59367413818836, 37.27888382971287, 40.581529811024666, 42.76828967034817, 47.94527247548103, 46.346550062298775, 54.96725767850876, 42.52979926764965, 39.312264919281006, 56.152018904685974, 47.58295811712742, 45.60426369309425, 41.39512315392494, 38.65725986659527, 35.872609689831734, 36.078836023807526, 37.42956854403019, 38.41026172041893, 38.554235994815826, 37.37285278737545, 38.61751779913902, 42.66933158040047, 46.14447310566902, 46.296179965138435, 49.462747648358345, 51.73437975347042, 52.12958134710789, 48.162354826927185, 49.68131572008133, 47.71386869251728, 48.21815103292465, 51.96836359798908, 49.201238080859184, 52.34280310571194, 51.39994449913502, 50.90165063738823, 47.04576574265957, 49.80547405779362, 50.96014469861984, 51.603396981954575, 46.268000677227974, 48.29953886568546, 43.79346325993538, 52.64979623258114, 47.85588227212429, 45.057108253240585, 36.11642360687256, 28.84836930781603, 22.70043220371008, 11.840877123177052, 8.914682641625404, 11.224853228777647, 13.775011338293552, 10.052904915064573, 9.882591404020786, 5.568822054192424, 0.8389157778583467, 0.4474841756746173, 0.26776548649650067, 1.0119936405681074, 4.834538530558348, 20.434486493468285, 30.977102480828762, 27.514781467616558, 28.968307971954346, 32.06028185784817, 42.13265597820282, 50.0439378619194, 23.766561895608902, 10.161769073456526, 1.1048578075133264, 0.0067821879747498315, 0.051259742976981215, 0.07025107566732913, 0.026852331575355493, 0.02913876796810655, 0.04353485397587065, 0.041263054590672255, 0.049156982568092644, 0.028779627864423674, 0.026646090591384564, 0.03638291411334649, 0.013408628838078585, 0.017346616550639737, 0.0322229945595609, 0.01695695005764719, 0.07276457399711944, 0.04507221659878269, 0.025561452894180547, 0.03907003047061153, 0.06568234035512432, 0.016309183156408835, 0.01346054485111381, 0.02416925250145141, 0.018493646603019442, 0.016022923809941858, 0.014396984934137436, 0.019163433025823906, 0.03375853892066516, 0.02162893480999628, 0.05876391354831867, 0.049755250074667856, 0.011020798374374863, 0.052466107736108825, 0.013896482396376086, 0.022615874331677333, 0.029428400375763886, 0.029997538586030714, 0.011696956134983338, 0.026070005878864322, 0.051579779319581576, 0.037185617329669185, 0.010058413736260263, 0.03228316789318342, 0.03218059195205569, 0.030345000996021554, 0.030368925981747452, 0.012671068561758148, 0.02281322067574365, 0.05684080853825435, 0.016233396891038865, 0.0702783273300156, 1.3607253902591765, 16.795562356710434, 41.840314865112305, 52.443319112062454, 40.24305917322636, 33.818348720669746, 26.022592037916183, 30.28166189789772, 29.22488920390606, 14.645216893404722, 4.377330439165235, 0.5364913120865822, 0.15100224962225184, 0.3399392293067649, 1.7589207482524216, 4.295793464407325, 9.163992013782263, 8.288629185408354, 11.603148579597473, 12.240111250430346, 10.96274234354496, 12.206815537065268, 20.19974458962679, 31.917211934924126, 40.56428633630276, 44.74554017186165, 50.66879913210869, 52.54853926599026, 51.444823890924454, 53.68100389838219, 51.21674872934818, 54.83195833861828, 56.19790144264698, 54.89252708852291, 53.16206194460392, 52.175980657339096, 54.321877509355545, 54.622566774487495, 53.038488775491714, 53.871354684233665, 53.77335034310818, 55.201701298356056, 55.484774708747864, 53.957997635006905, 53.0053735524416, 53.17093826830387, 50.917640179395676, 48.99622768163681, 40.58083064854145, 38.75169239938259, 38.60593602061272, 35.330127999186516, 36.7822390794754, 36.98746606707573, 39.65568669140339, 38.54963444173336, 42.453662753105164, 46.218333542346954, 49.73703972995281, 50.099943056702614, 55.18168397247791, 42.983103543519974, 42.946454510092735, 57.18369014561176, 49.31099519133568, 47.70101398229599, 43.26026827096939, 41.273658871650696, 38.67351159453392, 39.5102608948946, 38.65178436040878, 40.98200172185898, 40.345342084765434, 39.95345391333103, 40.84680877625942, 45.181764364242554, 46.837590113282204, 49.77385975420475, 51.08336068689823, 54.33929957449436, 52.61433273553848, 48.711064383387566, 50.11095866560936, 48.688691183924675, 49.484398886561394, 53.23057606816292, 50.47378979623318, 52.176493629813194, 52.678366899490356, 53.579249158501625, 49.40116435289383, 50.388260185718536, 51.776565089821815, 52.783419862389565, 47.506757006049156, 50.41928552091122, 46.380121260881424, 56.26282475888729, 51.21775567531586, 48.788781613111496, 38.41936223208904, 28.503676503896713, 20.166167691349983, 19.309482760727406, 9.23479076474905, 15.978655591607094, 14.680463802069426, 7.500327760353684, 10.240606293082237, 3.646425409242511, 2.413995978422463, 0.853276988491416, 0.2476067518000491, 0.992575257550925, 5.324478540569544, 21.465808153152466, 34.81027789413929, 36.296533942222595, 33.59099552035332, 38.01609367132187, 49.48704354465008, 56.45038269460201, 29.73834615200758, 12.5419613532722, 1.3022008119150996, 0.09158101587672718, 0.026786488233483396, 0.017540545304655097, 0.045683275020564906, 0.03666960576083511, 0.18063457362586632, 0.03423783273319714, 0.0414664141862886, 0.055742355762049556, 0.09493636200204492, 0.058353123677079566, 0.036485861128312536, 0.057622761305538006, 0.015153832700889325, 0.03195558390871156, 0.07068158811307512, 0.06374328659148887, 0.026331575827498455, 0.05623130491585471, 0.03870732805808075, 0.019378449906071182, 0.010994432650477393, 0.01685181927314261, 0.038658264675177634, 0.0710632152913604, 0.10173938484513201, 0.13228109950432554, 0.1288158042007126, 0.1276065784622915, 0.17489412071881816, 0.20003873709356412, 0.11954839836107567, 0.2116417113575153, 0.1546469665481709, 0.12660328386118636, 0.10310219062375836, 0.08755531001952477, 0.11783372552599758, 0.14430454495595768, 0.13366162776947021, 0.09232482596416958, 0.1381572912214324, 0.10113041556905955, 0.1010491132910829, 0.17638286895817146, 0.20567764935549349, 0.10223472389043309, 0.09459351203986444, 0.11888375316630118, 0.10830002967850305, 0.2663280355045572, 1.9772328087128699, 18.666439466178417, 49.38203617930412, 60.08503206074238, 45.466015711426735, 37.967786863446236, 35.197230130434036, 39.761518612504005, 33.92819322645664, 17.47010786086321, 4.6307070180773735, 0.9035470441449434, 0.4223609628388658, 0.9168535738717765, 3.792342091910541, 6.135985320433974, 11.369577012956142, 25.831545889377594, 19.0371722728014, 13.889711033552885, 16.842050962150097, 9.51170090585947, 19.716668911278248, 34.39763143658638, 40.99603436887264, 48.345178216695786, 53.956052139401436, 53.33682216703892, 52.04199604690075, 52.424042746424675, 53.218268528580666, 56.07547201216221, 58.34562599658966, 57.45232433080673, 54.86719384789467, 53.948581740260124, 56.01265758275986, 55.195097252726555, 54.67096857726574, 55.98030611872673, 57.56791412830353, 56.00530117750168, 57.1380165964365, 56.81329362094402, 54.375447034835815, 55.034107491374016, 52.978334203362465, 50.83426125347614, 42.26293198764324, 39.94306527078152, 40.0155121833086, 36.7609678208828, 38.53385768830776, 38.685195967555046, 40.37813052535057, 41.3111362606287, 44.877833873033524, 48.6070791631937, 53.587464317679405, 53.461759462952614, 58.402645736932755, 46.58021852374077, 46.60274751484394, 60.07212795317173, 52.834888100624084, 50.73142357170582, 46.6463615745306, 42.179788649082184, 40.80929338932037, 41.511636301875114, 41.14215932786465, 41.013760417699814, 41.95646323263645, 41.109298691153526, 43.09766359627247, 46.800872683525085, 50.15956565737724, 51.56550921499729, 54.532029032707214, 56.80177643895149, 53.67678612470627, 50.26624493300915, 50.53929068148136, 49.75365623831749, 49.53043341636658, 54.6609029173851, 51.676261872053146, 55.42389817535877, 55.0412967056036, 56.08117550611496, 52.22787447273731, 54.80141557753086, 55.42419835925102, 56.55783332884312, 50.46757712960243, 53.98488499224186, 49.183025658130646, 58.705170303583145, 55.79386532306671, 51.89122013747692, 43.84974204003811, 31.229908615350723, 24.988838508725166, 17.608591429889202, 15.042450428009033, 26.24408595263958, 23.62487319856882, 15.814673490822315, 19.18031819164753, 12.038563415408134, 4.677867712453008, 1.8441035086289048, 0.7565954513847828, 1.6666586115024984, 6.895244428887963, 26.82607412338257, 41.398512572050095, 40.47340281307697, 41.93276010453701, 46.57205656170845, 56.063643246889114, 63.84679600596428, 36.113246977329254, 15.584298502653837, 1.9278136105276644, 0.1571592700202018, 0.24728657444939017, 0.14020346658071503, 0.1533989710151218, 0.14072549325646833, 0.27019886998459697, 0.11519303050590679, 0.13252415286842734, 0.09363207456772216, 0.1270095948711969, 0.1287346874596551, 0.15893748553935438, 0.12603843526449054, 0.0937742403766606, 0.1451842422829941, 0.19286473689135164, 0.14584451622795314, 0.22410643781768158, 0.160567894927226, 0.09925776917953044, 0.06184190424392, 0.13274292316054925, 0.1465125530376099, 0.14020337752299383, 0.1860708647291176], [0.059218475289526395, 0.037896539142820984, 0.04953701041813474, 0.11161656890180893, 0.02557684318162501, 0.06561939138919115, 0.03977547894464806, 0.09306531865149736, 0.04822339418751653, 0.05917812100960873, 0.0258160243902239, 0.041939080620068125, 0.03952539373131003, 0.061878417909611017, 0.022006719518685713, 0.01957563668838702, 0.04201569623546675, 0.05328900850145146, 0.03927333440515213, 0.08954296703450382, 0.03254940966144204, 0.03460385625658091, 0.016068844197434373, 0.05479429179104045, 0.05894808120501693, 0.051607962377602234, 0.811533615924418, 10.029630213975906, 36.690717190504074, 43.825522139668465, 40.82374021410942, 26.29510961472988, 23.48389506340027, 23.675161600112915, 18.010110184550285, 13.83812215179205, 6.006419397890568, 0.680444153258577, 0.16252241504844278, 0.21843071503099054, 1.2911770096980035, 3.905077767558396, 9.039936270564795, 4.484117059037089, 7.4951989855617285, 12.01914170756936, 8.86282017454505, 14.687476325780153, 16.787993162870407, 28.554377183318138, 35.952230617403984, 41.68082222342491, 51.7231285572052, 52.45936185121536, 52.91689150035381, 51.71299830079079, 53.00140656530857, 53.37716840207577, 48.10963645577431, 47.76461876928806, 46.007650047540665, 46.415881142020226, 45.84394723176956, 47.52123802900314, 48.43722827732563, 48.71079079806805, 48.63062649965286, 47.051731422543526, 47.23338447511196, 46.52308478951454, 47.04633951187134, 48.25956501066685, 45.5279827862978, 40.6019689142704, 36.7052286118269, 35.09805545210838, 36.03780582547188, 35.73234781622887, 35.97897358238697, 33.47173132002354, 36.48172840476036, 35.56152418255806, 37.461866810917854, 38.24578754603863, 46.75598569214344, 46.61642678081989, 53.25340524315834, 39.450034126639366, 32.74717099964619, 55.628357604146004, 49.37616169452667, 47.33019948005676, 44.1057875007391, 43.40711519122124, 40.10517217218876, 38.411124274134636, 37.11605116724968, 38.380201533436775, 36.658456921577454, 37.28529408574104, 37.757848128676414, 38.44121865928173, 40.859047919511795, 46.60628132522106, 47.22024857997894, 49.06938135623932, 51.10081695020199, 52.93565109372139, 50.55871903896332, 53.38254891335964, 50.90453088283539, 50.707735642790794, 51.10759578645229, 49.34143155813217, 50.47469034790993, 52.08079196512699, 51.905321180820465, 52.35047869384289, 53.31886813044548, 55.01029796898365, 50.63523933291435, 46.46641843020916, 46.578645408153534, 51.11621752381325, 47.94219084084034, 47.054972648620605, 35.60296855866909, 28.20118423551321, 18.288684636354446, 21.07926059514284, 13.48301600664854, 13.157734461128712, 13.020961750298738, 5.218888856470585, 6.5707912389189005, 2.2098307963460684, 0.9287724655587226, 0.295433197170496, 0.24166152550606057, 1.0933527373708785, 6.921418374404311, 18.11455138027668, 33.081078082323074, 29.927538000047207, 31.788195557892323, 36.53752081096172, 45.93157812952995, 46.616848558187485, 32.472977712750435, 7.679830603301525, 0.30856609402690083, 0.028705244258162566, 0.05121037902426906, 0.016645374198560603, 0.09733507235068828, 0.024115370724757668, 0.05904710225877352, 0.03358135487360414, 0.07063242082949728, 0.09735875428305008, 0.05402876646257937, 0.021589051793853287, 0.03633750580775086, 0.0453718809876591, 0.010125736735062674, 0.030474943632725626, 0.04133741407713387, 0.013671925207745517, 0.022333136475936044, 0.026132010461878963, 0.04558350810839329, 0.05543020473851357, 0.04056911311636213, 0.056004185462370515, 0.05568332904658746, 0.047396534064318985, 0.019540709363354836, 0.023509355196438264, 0.01144886358815711, 0.03974511768319644, 0.051273168428451754, 0.0699250353500247, 0.05747360075474717, 0.04877726642007474, 0.08428940753219649, 0.022341994008456822, 0.020249814770068042, 0.03425978546147235, 0.029091044161759783, 0.08380131926969625, 0.06183676116052084, 0.07329894258873537, 0.0878664331685286, 0.0560952395608183, 0.03564527498383541, 0.04224000294925645, 0.01962945538252825, 0.08961868094047531, 0.03579114410968032, 0.07158582826377824, 0.08497395712765865, 0.014581005088984966, 0.852869579102844, 12.691012155264616, 43.7782184779644, 51.86502434313297, 46.80263198912144, 29.145340472459793, 29.484681263566017, 31.046957932412624, 25.771623104810715, 16.736884005367756, 6.156587339937687, 1.0576923633925617, 0.14412913093110546, 0.2824654133291915, 2.0386701682582498, 3.4729592548683286, 6.812140513211489, 7.738454807549715, 10.788985267281532, 13.457918353378773, 11.025233790278435, 15.01119615510106, 19.89873804152012, 26.31859615445137, 38.477324321866035, 43.92017886042595, 52.195686399936676, 51.07156991958618, 52.09438383579254, 52.72853180766106, 54.248431250452995, 55.28192639350891, 50.76816760003567, 50.40474370121956, 49.204042330384254, 49.72393423318863, 49.04437869787216, 49.953282326459885, 52.36427575349808, 52.711706310510635, 52.10045590996742, 50.00553712248802, 51.42988309264183, 49.23341475427151, 49.949714317917824, 50.37629462778568, 47.447081208229065, 42.93607346713543, 39.005564376711845, 36.76627233624458, 37.721712067723274, 37.146240547299385, 38.04023377597332, 36.158456951379776, 37.56381914019585, 38.53708751499653, 39.76844944059849, 41.03344336152077, 49.36690539121628, 49.26510505378246, 55.23934967815876, 40.33633276820183, 35.47012768685818, 57.06887550652027, 50.77395848929882, 50.30348293483257, 46.305432468652725, 44.77417543530464, 41.13807454705238, 38.51795174181461, 38.20902071893215, 39.9675739556551, 37.34342336654663, 39.43980127573013, 38.77850756049156, 40.06703361868858, 43.796666488051414, 48.32058973610401, 50.441666319966316, 52.21796080470085, 52.19861604273319, 54.042736887931824, 51.58216372132301, 53.17754991352558, 52.23247982561588, 52.57942020893097, 51.419270262122154, 51.596519351005554, 52.257220298051834, 54.527484476566315, 54.48440618813038, 54.02958199381828, 55.3795013576746, 56.25159256160259, 52.01754815876484, 48.82202222943306, 49.97569352388382, 54.74041745066643, 51.759937182068825, 49.788314178586006, 37.81147085130215, 30.166786462068558, 20.455776751041412, 18.885480612516403, 12.246518656611443, 17.744905315339565, 12.867397740483284, 11.5393509529531, 12.180515248328447, 3.5934151662513614, 1.162286619655788, 0.45287507702596486, 0.28080718824639916, 1.494800839573145, 7.668223176151514, 20.515104867517948, 40.28340920805931, 33.27033832669258, 36.06720484793186, 43.144275695085526, 50.45293651521206, 53.13685789704323, 36.521907448768616, 9.967616591602564, 0.692276005866006, 0.024882823781808838, 0.004772991051140707, 0.02606696307339007, 0.0411429565428989, 0.019679830511449836, 0.07961797382449731, 0.018742212268989533, 0.034655717536224984, 0.04649881739169359, 0.04980316312867217, 0.04729878208308946, 0.04033740347949788, 0.06095777629525401, 0.011776490246120375, 0.018145564499718603, 0.04230260681651998, 0.04192064196104184, 0.04358016580226831, 0.03165382666338701, 0.031683189736213535, 0.05112836057378445, 0.048136169571080245, 0.03327751961478498, 0.03844785467663314, 0.0612127374188276, 0.12175936019048095, 0.12074666999978945, 0.12415987395797856, 0.1452486013295129, 0.1702412703889422, 0.11932477442314848, 0.16212294664001092, 0.17957456409931183, 0.16182892257347703, 0.16558557021198794, 0.09016891664941795, 0.09641766650020145, 0.1754843062371947, 0.1765110230189748, 0.13752998347627, 0.09270612659747712, 0.19391484616789967, 0.11661636584904045, 0.13564960390795022, 0.14664357178844512, 0.06085693326895125, 0.2694550302112475, 0.10305450021405704, 0.2036887381109409, 0.15012847463367507, 0.1396061564446427, 1.2832855456508696, 14.884879533201456, 49.149359464645386, 58.63652318716049, 53.620537742972374, 38.01937289535999, 35.626690685749054, 34.28288519382477, 30.65440859645605, 19.922241680324078, 8.206830974668264, 1.4563187607564032, 0.3679629333782941, 1.2712644156999886, 3.99608644656837, 12.311479020863771, 19.5937018096447, 12.190310172736645, 18.473094440996647, 23.267511874437332, 17.083225920796394, 19.37915962189436, 19.517493098974228, 30.98194532096386, 41.32958047091961, 44.9773733317852, 52.39852711558342, 51.98546268045902, 53.34367699921131, 51.71278931200504, 54.52512480318546, 58.16979803144932, 53.27289819717407, 51.688360422849655, 52.00828045606613, 51.62326231598854, 49.5908235758543, 52.43326485157013, 54.19996105134487, 54.59212280809879, 54.700318202376366, 53.3270300924778, 53.985010385513306, 51.74455940723419, 51.867349818348885, 52.59173534810543, 49.83162045478821, 44.438452050089836, 40.562937408685684, 38.404683619737625, 40.3907610476017, 39.53152075409889, 39.75706525146961, 38.66267077624798, 39.57587577402592, 41.26432277262211, 42.127970829606056, 44.60929848253727, 52.08153672516346, 52.3570067435503, 56.49798274040222, 44.031292498111725, 38.75376708805561, 59.265112057328224, 53.88119995594025, 53.472471088171005, 48.2954540848732, 47.87952080368996, 44.43586438894272, 41.136832013726234, 40.49830287694931, 42.37363904714584, 39.207964316010475, 40.873745530843735, 41.576669812202454, 41.65777266025543, 45.171029940247536, 51.67715482413769, 52.0278038084507, 54.889855831861496, 55.5071859061718, 56.23659856617451, 53.91153372824192, 56.677713096141815, 54.276815727353096, 52.4677138030529, 51.9953877478838, 51.820084154605865, 53.6699540913105, 56.18817016482353, 56.04479245841503, 57.33836464583874, 57.51276768743992, 58.89628104865551, 53.571592569351196, 51.26231588423252, 52.5164195895195, 57.055124044418335, 52.40258149802685, 55.38607880473137, 39.958207458257675, 31.695343740284443, 23.036909848451614, 25.956386290490627, 24.892872758209705, 22.387940771877766, 25.23922987282276, 13.704495672136545, 14.377427212893963, 5.954121854156256, 2.338700881227851, 0.9377101203426719, 0.5856585956644267, 1.7703049373812973, 9.027594532817602, 24.77918665856123, 44.69394274055958, 41.50934882462025, 44.00227725505829, 50.62650740146637, 57.977874130010605, 59.3232299387455, 42.67506167292595, 12.99052918329835, 0.799504411406815, 0.1488778370548971, 0.10013405262725428, 0.14620736707001925, 0.15497184911509976, 0.11308047745842487, 0.20972216123482212, 0.13210749631980434, 0.15242113207932562, 0.2422270123497583, 0.15884945198195055, 0.2735169528750703, 0.0984661425172817, 0.1790998864453286, 0.10177699688938446, 0.05925575336732436, 0.1181252633978147, 0.18547309446148574, 0.14457657176535577, 0.08866044954629615, 0.13615056843264028, 0.20505041582509875, 0.22123852686490864, 0.1613010626169853, 0.07336068927543238, 0.26345868478529155], [0.014653579710284248, 0.051716798334382474, 0.07276939053554088, 0.03828073415206745, 0.03803525025432464, 0.0288471243402455, 0.03521875900332816, 0.03993773469119333, 0.048791745721246116, 0.0493372131313663, 0.03294605790870264, 0.05308729647367727, 0.02768385053059319, 0.00651464883958397, 0.07070811989251524, 0.09986386634409428, 0.0488263631996233, 0.06559392088092864, 0.07107388737495057, 0.0721821142360568, 0.04137455856835004, 0.04468573948543053, 0.04097556142369285, 0.04933896831062157, 0.06224455646588467, 0.057106694075628184, 0.18296128080692142, 8.073127549141645, 30.96555110067129, 43.90651099383831, 37.79730901122093, 29.478025920689106, 18.03661186248064, 24.07859545201063, 31.040978953242302, 19.282815791666508, 6.902126809582114, 1.0555816954001784, 0.2761369419749826, 0.15971473680110648, 1.475453821476549, 1.4511648123152554, 4.818028416484594, 3.847098578698933, 9.353378601372242, 12.63241644948721, 12.679770458489656, 18.52348543703556, 21.614448577165604, 22.78186183422804, 33.341557905077934, 40.19835077226162, 47.26794362068176, 51.512756645679474, 54.755122661590576, 53.14271338284016, 50.69718740880489, 47.554022669792175, 45.86514249444008, 42.31005325913429, 40.3879301995039, 40.266982689499855, 41.19078911840916, 40.608094185590744, 41.168989688158035, 40.6926092505455, 42.410770654678345, 41.23787239193916, 42.52029597759247, 40.51014684140682, 41.1476956307888, 39.45261798799038, 36.736801117658615, 32.40346424281597, 35.835086703300476, 34.74138379096985, 35.82443207502365, 34.81615237891674, 35.383815318346024, 35.17809055745602, 36.959970742464066, 34.96355026960373, 39.764022678136826, 40.88538810610771, 45.56512579321861, 44.68963377177715, 54.276591539382935, 38.764284923672676, 37.71520681679249, 54.34450149536133, 48.872380927205086, 51.72548063099384, 44.856612011790276, 44.83482018113136, 41.24144420027733, 37.15020753443241, 36.463922560214996, 37.462459579110146, 36.09585151076317, 37.91036814451218, 39.31202173233032, 38.23800936341286, 37.33418986201286, 40.055759623646736, 44.333695471286774, 47.12183006107807, 48.73061813414097, 48.331491351127625, 48.72336432337761, 47.949965223670006, 47.649876326322556, 50.63806638121605, 52.118816524744034, 51.46565817296505, 51.59419767558575, 50.03461316227913, 51.32986105978489, 53.6245921254158, 52.04673819243908, 54.33081082999706, 54.1066874563694, 50.30184902250767, 47.18154765665531, 51.92971207201481, 50.29383145272732, 47.07431361079216, 33.9230976998806, 29.948045499622822, 20.00800497829914, 23.145169839262962, 6.172223500907421, 18.13711266964674, 7.44783072732389, 7.515053870156407, 11.405192501842976, 2.6654971204698086, 1.814146984834224, 0.41290858411230147, 0.24076235422398895, 1.314150933176279, 5.84915011189878, 19.923244826495647, 31.839751191437244, 34.59894463419914, 26.62492621690035, 31.16936646401882, 45.59317968785763, 44.81522083282471, 31.81504301726818, 6.842930736020207, 0.478565557859838, 0.06260445356019773, 0.03766774243558757, 0.021575863829639275, 0.01780217276973417, 0.07235714976559393, 0.03015987040271284, 0.0429800837446237, 0.05987210701277945, 0.04874233352893498, 0.04670657050155569, 0.06629167328355834, 0.10231503169052303, 0.023450831286027096, 0.02515256477636285, 0.02657467372046085, 0.026425687574374024, 0.05499387756572105, 0.05762835338828154, 0.07597691568662412, 0.04027381626656279, 0.06044661466148682, 0.06852262114989571, 0.01392117643263191, 0.03936061839340255, 0.06589252399862744, 0.04191230393189471, 0.03238481243897695, 0.028870184723928105, 0.05533276817004662, 0.033335974876536056, 0.02567784391430905, 0.031770128625794314, 0.11227992275962606, 0.08470109169138595, 0.017053100855264347, 0.06357277816277929, 0.060367301339283586, 0.07314860573387705, 0.04910727722744923, 0.05922103569901083, 0.06885693641379476, 0.02110853343765484, 0.021031053220212925, 0.04176509894023184, 0.10375580008258112, 0.030430047409026884, 0.051962208017357625, 0.018568768646218814, 0.028614216134883463, 0.03689272503834218, 0.09589169902028516, 0.2875540527747944, 10.29829764738679, 37.430868074297905, 50.31513690948486, 42.96532429754734, 33.595091700553894, 22.93763067573309, 26.812402456998825, 30.802969224750996, 20.765817314386368, 8.421473857015371, 1.2541280477307737, 0.16618164838291705, 0.1226039019820746, 1.4457069989293814, 2.8886876441538334, 8.806362804025412, 8.59312679618597, 12.135251127183437, 8.074958100914955, 10.302417576313019, 15.348518304526806, 21.10585156828165, 23.936361484229565, 33.05382214486599, 42.683934196829796, 49.80620361864567, 52.85911560058594, 56.315307542681694, 52.87551932036877, 52.654758766293526, 51.798318922519684, 47.50351957976818, 44.96752806007862, 42.661226615309715, 43.08999940752983, 44.221225306391716, 42.98021949827671, 43.13425563275814, 43.52217301726341, 45.07731556892395, 43.81039135158062, 45.54318957030773, 44.4305332750082, 44.44596044719219, 41.91059969365597, 38.665239438414574, 36.07559859752655, 36.23183101415634, 36.10189698636532, 37.78300657868385, 36.17460988461971, 37.22676582634449, 36.19179256260395, 37.993716672062874, 37.6753431558609, 40.63332483172417, 43.699733689427376, 47.70944572985172, 47.706721276044846, 56.52153767645359, 42.05986328423023, 39.32851664721966, 56.91493056714535, 49.96342398226261, 53.47602769732475, 48.197065964341164, 47.918837293982506, 43.07012267410755, 39.55301620066166, 39.79115702211857, 38.962885066866875, 37.109762504696846, 40.10449580848217, 40.156894996762276, 40.1261318475008, 40.8683118224144, 42.08304204046726, 48.06394390761852, 49.07352313399315, 50.7252337038517, 51.20148114860058, 51.16840772330761, 50.40204964578152, 51.47535905241966, 51.98513589799404, 54.5457348972559, 50.79267628490925, 52.40998350083828, 49.095858335494995, 52.129132971167564, 52.78588593006134, 53.48602116107941, 55.01682601869106, 55.984390899538994, 50.814110934734344, 49.605790972709656, 52.53825701773167, 50.42499281466007, 49.06682029366493, 38.205232322216034, 29.822988510131836, 21.730798333883286, 20.74208188802004, 6.5479482896626, 16.43895909190178, 10.061831586062908, 12.520916182547808, 11.45139517262578, 3.739915592595935, 2.5001311814412475, 0.3168470965465531, 0.26574752759188414, 1.5810838784091175, 7.5523346196860075, 22.409489415585995, 37.91950285434723, 38.200440779328346, 33.08042071759701, 37.09804393351078, 53.394685462117195, 51.592438369989395, 37.31576845049858, 8.515558708459139, 0.5989970080554485, 0.03757908176339697, 0.05750781376264058, 0.002259196558043186, 0.043549941838136874, 0.04798717600351665, 0.022964843301451765, 0.04340315987064969, 0.06232486426597461, 0.039128541393438354, 0.044260715221753344, 0.040772008869680576, 0.2174431094317697, 0.020072003608220257, 0.03783544554607943, 0.02592898854345549, 0.021378207638917957, 0.043728368982556276, 0.04665791158913635, 0.04262444286723621, 0.03768809212488122, 0.024202756758313626, 0.02700631979678292, 0.03933955624233931, 0.013371723689488135, 0.04306554947106633, 0.08959447950473987, 0.14781932666664943, 0.15459393267519772, 0.12830461288103834, 0.08454302165773697, 0.10064542206237093, 0.1269817049615085, 0.22361779294442385, 0.12638901098398492, 0.10900319233769551, 0.1730678288731724, 0.20892059721518308, 0.17840724001871422, 0.10101922700414434, 0.1377386605599895, 0.25729642482474446, 0.1558245619526133, 0.1564344292273745, 0.17994442081544548, 0.19457314600003883, 0.20390535617480054, 0.21761472366051748, 0.16791949106846005, 0.12717167992377654, 0.1123381219804287, 0.15083127364050597, 0.5300080880988389, 12.391060050576925, 44.36008885502815, 57.65766151249409, 51.89023979008198, 40.67797623574734, 27.935544289648533, 35.38535423576832, 42.279647290706635, 27.05922581255436, 9.744279775768518, 1.9370866566896439, 0.4828336788341403, 0.49834159668534994, 3.0371632520109415, 5.099589033052325, 11.169558595865965, 14.122694581747055, 18.36981788277626, 24.09198023378849, 21.256733871996403, 23.203475810587406, 27.282391637563705, 26.481880992650986, 36.35059744119644, 44.24289554357529, 49.62271526455879, 52.74916850030422, 55.23333840072155, 54.77979853749275, 54.67174373567104, 54.50571544468403, 50.606668666005135, 47.32979290187359, 44.30573657155037, 45.1187789440155, 46.46280862390995, 44.70105595886707, 44.44200485944748, 46.39586381614208, 46.18811376392841, 44.53820049762726, 46.31403520703316, 44.9942634254694, 45.62217593193054, 43.66027660667896, 39.87918309867382, 36.94879554212093, 38.91827546060085, 37.91843891143799, 39.56752382218838, 38.25780250132084, 38.966494873166084, 39.15982089936733, 39.70632277429104, 39.84691523015499, 42.233821749687195, 45.97054123878479, 49.96542647480965, 51.58420421183109, 57.88237385451794, 43.70092682540417, 43.797567039728165, 57.6419797539711, 53.618223667144775, 55.70437252521515, 51.94689854979515, 50.27104027569294, 46.50708764791489, 40.71578800678253, 41.51589207351208, 40.31886890530586, 39.03110660612583, 41.57617203891277, 40.881763100624084, 41.651533395051956, 42.51648098230362, 43.83728630840778, 49.85741727054119, 52.919558957219124, 53.38373064994812, 54.14825722575188, 53.236283361911774, 53.24473790824413, 52.87904553115368, 54.14055123925209, 56.31074398756027, 53.12458835542202, 53.556336387991905, 50.38024261593819, 51.243746280670166, 54.69046913087368, 53.820931389927864, 56.79677210748196, 58.18185858428478, 55.94731628894806, 52.43629328906536, 55.88113144040108, 55.90352363884449, 52.56416782736778, 39.64504346251488, 31.909863129258156, 22.84877434372902, 29.106939733028412, 10.530417691916227, 33.10342088341713, 19.243343509733677, 13.74108200892806, 21.40042506158352, 7.951247664168477, 6.110850619152188, 1.5648631425574422, 0.6030082271900028, 2.1664601610973477, 8.468230348080397, 26.691373251378536, 43.40160168707371, 46.79648391902447, 38.597994446754456, 43.78616765141487, 58.2095704972744, 60.025303065776825, 42.79037028551102, 11.513523738831282, 0.9399769362062216, 0.15286763780750334, 0.16226199542870745, 0.13202732952777296, 0.10905713163083419, 0.1405159107525833, 0.0866948788461741, 0.12580075504956767, 0.17669045948423445, 0.13465635798638687, 0.10996829601936042, 0.1636983035132289, 0.4274189070565626, 0.07893412926932797, 0.17270960903260857, 0.1051598099002149, 0.16518391988938674, 0.15115450863959268, 0.21616826299577951, 0.17990505730267614, 0.15107365907169878, 0.13190447440138087, 0.1147909794235602, 0.11643001998891123, 0.18328435253351927, 0.1886130470666103], [0.03324915473058354, 0.0051093769070575945, 0.014108940722508123, 0.018319817063456867, 0.03511960807372816, 0.060777697872254066, 0.029598778928630054, 0.055934401316335425, 0.07300635828869417, 0.014126345013210084, 0.0684551005542744, 0.020973720456822775, 0.031267423764802516, 0.02271096942422446, 0.07495425845263526, 0.01954531810042681, 0.02760161685728235, 0.10644569949363358, 0.03455671503616031, 0.0618461975682294, 0.015075191950018052, 0.0322441977186827, 0.03464248504315037, 0.025025117611221503, 0.06608891111682169, 0.0458303649793379, 0.23497700138250366, 6.404409566894174, 29.855537563562393, 47.40870326757431, 47.07006923854351, 31.299547478556633, 24.331266693770885, 29.7676919773221, 31.948750242590904, 19.58056591451168, 9.029521029442549, 1.9083211314864457, 0.11657732145977207, 0.3399574861396104, 1.0575264785438776, 1.8926512473262846, 6.623707199469209, 7.369225770235062, 11.256351638585329, 5.574101870879531, 4.630000730976462, 7.794324159622192, 15.699746757745743, 21.400368064641953, 27.72168606519699, 39.43293124437332, 47.97271080315113, 52.08743780851364, 53.074256256222725, 50.17805926501751, 50.327718034386635, 43.54568235576153, 43.11637759208679, 39.861658439040184, 37.367213889956474, 36.75006240606308, 36.50792419910431, 36.76979474723339, 34.44434233009815, 33.48802484571934, 36.534906551241875, 35.243739634752274, 34.50505927205086, 33.887797594070435, 35.68918973207474, 34.41391356289387, 35.94115421175957, 41.20431259274483, 46.92633055150509, 35.82058668136597, 35.611221715807915, 34.48488995432854, 38.180735036730766, 37.826981619000435, 43.22423480451107, 41.21102683246136, 42.19517022371292, 43.61659795045853, 50.717417523264885, 48.38331297039986, 53.0500515550375, 36.77635699510574, 32.05406539142132, 47.86182515323162, 46.994491294026375, 54.81439188122749, 49.80796292424202, 47.25104592740536, 40.87762512266636, 38.03521044552326, 34.94305796921253, 35.09890280663967, 36.31098076701164, 42.16605618596077, 41.86148352921009, 39.16798286139965, 37.15925104916096, 38.167253360152245, 39.25562135875225, 41.52411103248596, 43.59825253486633, 44.096979573369026, 46.15580789744854, 43.19095999002457, 45.299117267131805, 45.24512216448784, 51.82213604450226, 55.01356199383736, 52.77798995375633, 51.570220962166786, 51.56601078808308, 51.777302250266075, 54.904621839523315, 54.510282799601555, 54.58352006971836, 53.32649812102318, 48.27885277569294, 50.779107213020325, 46.11297659575939, 42.615974843502045, 36.48292154073715, 24.02348130941391, 21.014563366770744, 14.89785298705101, 5.660507334396243, 13.297635354101658, 8.688745815306902, 14.449158813804388, 13.840148393064737, 3.82644668687135, 0.25941454397980124, 0.20610870356904343, 0.31151939649134874, 0.9375267208088189, 7.574662221595645, 19.665466658771038, 37.072467505931854, 43.208667039871216, 33.790040239691734, 39.93930347263813, 43.55246879160404, 44.26968030631542, 32.902723252773285, 6.001302497461438, 0.17329833994153887, 0.04077579011209309, 0.030990168525022455, 0.03459200044744648, 0.06732965586706996, 0.02100853274896508, 0.0641609079320915, 0.04037324179080315, 0.04109441637410782, 0.01703755657217698, 0.01132237750425702, 0.03324297635117546, 0.02774085118289804, 0.014742303465027362, 0.019054743643209804, 0.012641611792787444, 0.051060123805655167, 0.07622232165886089, 0.05008268934034277, 0.021738841314800084, 0.016395021812058985, 0.07198952691396698, 0.006765119042029255, 0.08569884987082332, 0.04867811920121312, 0.02295759622938931, 0.08072699478361756, 0.07073514891089872, 0.03228012879844755, 0.00812235361081548, 0.040185185280279256, 0.0408677681843983, 0.015796368388691917, 0.06695282296277583, 0.08237546804593876, 0.010385125697212061, 0.0023879707759988378, 0.02367122688156087, 0.007017860216365079, 0.015487714736082125, 0.009935510370269185, 0.07523510939790867, 0.05720770779589657, 0.02119480810506502, 0.06729294924298301, 0.04632440897694323, 0.05210767267271876, 0.05155623839527834, 0.03082262868701946, 0.06192286884470377, 0.05378308218496386, 0.017438787581340875, 0.43881419871468097, 7.96337328851223, 35.973764061927795, 52.788135409355164, 51.5445077419281, 37.20306649804115, 27.07908734679222, 35.09512960910797, 43.81351478397846, 24.612145721912384, 10.090726185590029, 1.7310055461712182, 0.27791536529548466, 0.08906326504074968, 1.5454872697591782, 2.9721375787630677, 6.182017475366592, 6.578016076236963, 10.846559777855873, 5.559285990893841, 6.259347600862384, 14.711031261831522, 18.375291489064693, 24.62027918547392, 29.342728480696678, 40.28476193547249, 47.61570855975151, 53.356182128190994, 53.031896129250526, 53.27857129275799, 52.57348872721195, 46.73819124698639, 46.360176131129265, 41.85178644955158, 38.57227362692356, 39.85703028738499, 38.458682522177696, 38.282067999243736, 37.24514164030552, 36.19452081620693, 37.69914507865906, 38.270592615008354, 37.859207689762115, 35.20464353263378, 36.74625501036644, 35.8392208814621, 37.317873537540436, 43.076806515455246, 46.366795375943184, 37.40047350525856, 36.65651522576809, 35.4468197375536, 38.83047737181187, 40.65770052373409, 43.462242633104324, 43.73859420418739, 42.99272082746029, 46.169171780347824, 51.37382470071316, 52.507041692733765, 54.002751633524895, 40.566171035170555, 36.27550967037678, 50.43587163090706, 49.68142591416836, 55.98686456680298, 50.43120928108692, 48.488324135541916, 42.92536184191704, 40.06454095244408, 36.37536071240902, 36.83284476399422, 37.835873141884804, 43.38295228779316, 44.28606502711773, 40.09914189577103, 39.0771297365427, 39.767674282193184, 42.688512951135635, 44.04095157980919, 46.032550111413, 48.05802382528782, 48.31990957260132, 46.663498654961586, 47.68002770841122, 47.74794526398182, 53.29834923148155, 57.060405761003494, 54.18116346001625, 50.98585791885853, 50.52365832030773, 52.201139107346535, 53.771686032414436, 54.707496017217636, 55.64530469477177, 55.097879469394684, 49.75888475775719, 52.617885544896126, 53.05939145386219, 45.59341907501221, 38.27981472015381, 30.15202235430479, 24.72558293491602, 16.079998053610325, 12.528988849371672, 15.81562913954258, 10.143476855009794, 16.57661620527506, 11.667130496352911, 4.011428123340011, 1.2575755314901471, 0.22255165327806026, 0.2152736485004425, 1.1236082576215267, 8.51411858573556, 22.539157457649708, 40.14609597623348, 45.08116476237774, 36.74429811537266, 44.842849150300026, 49.778537303209305, 51.617330834269524, 38.30513656139374, 8.086195047944784, 0.5256554810330272, 0.051887948720832355, 0.04676109609135892, 0.09530716866720468, 0.032836027094163, 0.006385325896189897, 0.011765970302803908, 0.07557236356660724, 0.11564249740331434, 0.030563671098207124, 0.048913398568402044, 0.016262192220892757, 0.05262432248855475, 0.014793827995163156, 0.046409974893322214, 0.04826911048439797, 0.0443118491966743, 0.024351948850380722, 0.05300580494804308, 0.046823651719023474, 0.028866730026493315, 0.05805918495752849, 0.0319894592394121, 0.04025112510134932, 0.023490751409553923, 0.039912037827889435, 0.13588343979790807, 0.16987135430099443, 0.12374300218652934, 0.0857851913315244, 0.20179354527499527, 0.20565747778164223, 0.10992067240295, 0.15721074538305402, 0.12612786405952647, 0.09363976321765222, 0.14540973643306643, 0.08699096608324908, 0.16346712451195344, 0.06791801570216194, 0.15238739404594526, 0.1434780893032439, 0.12001025912468322, 0.16496638156240806, 0.15434204775374383, 0.16020805720472708, 0.1462359249126166, 0.10092314114444889, 0.11815657460829243, 0.19877373153576627, 0.12169848181656562, 0.2241768824751489, 0.6511316949035972, 9.806731324642897, 40.35029321908951, 60.93672215938568, 59.241788908839226, 44.10994827747345, 34.199240282177925, 43.01480524241924, 42.2658122330904, 27.346370704472065, 12.321097254753113, 2.570212483406067, 0.5039381620008498, 0.6573513674084097, 3.375182901509106, 6.726688798516989, 13.2379244081676, 15.541183166205883, 16.486944817006588, 12.491604555398226, 8.399788420647383, 13.096554894000292, 20.92205163091421, 24.37100876122713, 31.691365353763103, 41.54127471148968, 50.43494448065758, 53.45815725624561, 53.90181764960289, 55.30716083943844, 54.71566937863827, 48.19131687283516, 48.494814187288284, 44.02930900454521, 41.620884239673615, 41.359838247299194, 40.05687676370144, 40.61230055987835, 38.47641997039318, 37.56911225616932, 38.73226784169674, 39.56872455775738, 38.38216982781887, 36.972422674298286, 38.3684753626585, 38.13140228390694, 38.946576341986656, 45.53845502436161, 49.49248865246773, 38.764250725507736, 39.12791781127453, 37.952933460474014, 41.72690235078335, 43.074249252676964, 47.43119426071644, 45.93147173523903, 46.35142520070076, 49.911590963602066, 55.53453303873539, 55.60823008418083, 52.96197608113289, 42.301686108112335, 40.32751344144344, 52.486940771341324, 51.52721107006073, 57.29004263877869, 54.11084443330765, 51.81159920990467, 45.19138544797897, 42.00209878385067, 38.27802501618862, 37.89700046181679, 39.94045481085777, 44.29602429270744, 45.93788959085941, 42.102819979190826, 41.57180607318878, 42.604089081287384, 44.22165088355541, 45.859898775815964, 48.25774110853672, 50.269242972135544, 51.45443357527256, 48.854183703660965, 49.83304537832737, 51.021074429154396, 55.65512336790562, 59.749183282256126, 56.04291915893555, 51.886215806007385, 52.54614159464836, 51.67515613138676, 54.75357614457607, 54.73432257771492, 55.00807888805866, 58.61169911921024, 53.0468825250864, 55.78611373901367, 50.8979382365942, 49.68108773231506, 40.661785304546356, 31.455162428319454, 23.81547287106514, 19.587815925478935, 11.737254783511162, 24.90362048149109, 18.068689741194248, 20.25912970304489, 19.994724690914154, 6.544317584484816, 2.5287353340536356, 0.3879862854955718, 1.0457080439664423, 1.374910029117018, 10.790641978383064, 26.60295769572258, 48.12793627381325, 53.65970604121685, 47.41311863064766, 51.42841637134552, 56.78148552775383, 59.38103623688221, 44.813503324985504, 9.709751978516579, 0.8532496774569154, 0.17167138896184042, 0.10375999321695417, 0.16542183759156615, 0.13232176919700578, 0.12314352497924119, 0.17043143830960616, 0.2275810544961132, 0.2705542102921754, 0.07610967106302269, 0.1279189484193921, 0.14345781382871792, 0.15129309729672968, 0.08888622571248561, 0.11333574657328427, 0.21111745823873207, 0.13655162503710017, 0.2081224916037172, 0.13689121697098017, 0.1290674219490029, 0.15694597677793354, 0.10851727856788784, 0.10366656424594112, 0.1887721783714369, 0.16195686883293092, 0.15806454175617546], [0.06720328296069056, 0.1169220193696674, 0.040360603015869856, 0.04079531972820405, 0.049988481114269234, 0.037134550148039125, 0.08643809575005434, 0.03191728908859659, 0.047282510495278984, 0.03645170007075649, 0.08887023243005387, 0.08686158747877926, 0.07028036081464961, 0.06820347538450733, 0.005565152059716638, 0.12579466943861917, 0.09580410333001055, 0.026324389982619323, 0.07157192041631788, 0.018914865504484624, 0.08729606299311854, 0.03467890222964343, 0.042095232201972976, 0.011827712351077935, 0.010538151909713633, 0.06880820699734613, 0.1573641473078169, 4.249003250151873, 22.195340506732464, 44.76741559803486, 44.230888187885284, 31.02531809359789, 18.911875896155834, 16.727525107562542, 29.576740823686123, 22.21894484013319, 13.015942219644785, 2.2462057694792747, 0.5041850300040096, 0.025503023607598152, 0.7738615467678756, 1.296433552633971, 5.251213246956468, 5.237898761406541, 12.869545575231314, 3.510652044788003, 4.30239038541913, 14.940545596182346, 12.581885810941458, 19.619228839874268, 25.32913114875555, 37.131174355745316, 43.120188787579536, 49.328117072582245, 53.641600012779236, 52.54098527133465, 45.9626604616642, 44.02185000479221, 40.39098143577576, 37.25340999662876, 37.900549471378326, 38.591390401124954, 43.53186249732971, 45.438919365406036, 43.809859380126, 40.244902074337006, 38.412040024995804, 35.47464944422245, 36.43011577427387, 37.42799922823906, 34.398338198661804, 36.08110450208187, 36.44108958542347, 45.15948995947838, 42.27351061999798, 34.2314587533474, 36.32951237261295, 38.76975283026695, 44.4077230989933, 45.73637880384922, 48.73698279261589, 44.18453447520733, 50.7931512594223, 45.95570683479309, 51.20226390659809, 48.142143711447716, 54.51286666095257, 41.45770579576492, 28.24247281998396, 52.20294401049614, 48.63370053470135, 51.90486140549183, 46.59909971058369, 45.381842628121376, 38.63562002778053, 37.26713106036186, 36.659091487526894, 38.8716671615839, 39.840204790234566, 38.326871395111084, 36.03091299533844, 36.07782147824764, 38.0836920440197, 37.56748214364052, 37.134879156947136, 35.66949538886547, 37.40332335233688, 37.83357426524162, 38.794124722480774, 40.244499295949936, 43.97403337061405, 44.06661160290241, 47.62020371854305, 48.83478954434395, 49.4607375562191, 52.29678377509117, 54.34682697057724, 53.09470675885677, 53.089622631669044, 51.689800545573235, 53.97699661552906, 55.91504842042923, 53.11773732304573, 48.49709786474705, 49.66970354318619, 40.15942566096783, 31.20816808193922, 27.46108654886484, 19.512990340590477, 12.57215928286314, 10.260976050049067, 10.855572894215584, 5.964996870607138, 18.688860163092613, 10.092782825231552, 3.67836507037282, 1.8441010150127113, 0.35008643637411296, 0.04247758668498136, 1.302957208827138, 7.920355321839452, 19.501319266855717, 31.57657351344824, 34.07733142375946, 29.467760771512985, 30.809115394949913, 42.817029654979706, 43.81568066775799, 32.450931295752525, 6.170069016516209, 0.2969246468273923, 0.016992424716590904, 0.007641357960892492, 0.04889190226094797, 0.050136725112679414, 0.03412487043533474, 0.06115349919127766, 0.03485453147732187, 0.07776976635796018, 0.03601344702474307, 0.06035525999322999, 0.04038083025079686, 0.034055423966492526, 0.07674194377614185, 0.03994386854174081, 0.0646507328201551, 0.05970170990622137, 0.0372866458928911, 0.035028646743739955, 0.011864006155519746, 0.031583545278408565, 0.008660645380587084, 0.019941153695981484, 0.02917496251029661, 0.10547427271376364, 0.008655853889649734, 0.04476484129554592, 0.04094935618923046, 0.024480147440044675, 0.06011060359014664, 0.01461486835978576, 0.045127673583920114, 0.04414682152855676, 0.07971350307343528, 0.07905382284661755, 0.08241711737355217, 0.07247960413224064, 0.029642918161698617, 0.0028521885542431846, 0.013562830426963046, 0.05502951178641524, 0.07202955093816854, 0.033959668362513185, 0.03487303321890067, 0.07843637082260102, 0.028883127779408824, 0.08355953497812152, 0.004638334385163034, 0.03758208746148739, 0.07313795591471717, 0.07310088563826866, 0.06621559572522528, 0.2017187071032822, 5.200752429664135, 27.52803325653076, 51.76402196288109, 51.92269764840603, 34.93653751909733, 25.484747998416424, 23.798894360661507, 34.168541729450226, 25.702823996543884, 13.605173751711845, 2.6669761911034584, 0.31779324577655643, 0.05028136969485786, 0.614905507536605, 1.9360743672586977, 5.592099130153656, 5.074571650475264, 9.625842031091452, 8.477870430797338, 6.97469056583941, 12.411651145666838, 17.632106468081474, 24.238908849656582, 27.868078909814358, 40.83420865237713, 44.76559169590473, 51.60508029162884, 54.768395349383354, 54.31632600724697, 48.9132135361433, 46.626606434583664, 42.307097017765045, 38.771743923425674, 39.87374559044838, 40.83001367747784, 43.78020577132702, 46.6734579205513, 43.86544659733772, 40.32174535095692, 38.95747035741806, 37.25334160029888, 37.878886833786964, 38.22348274290562, 35.25551900267601, 37.948578894138336, 38.25083747506142, 47.0754649490118, 44.00109551846981, 35.94031825661659, 38.24848160147667, 40.15752196311951, 45.637192726135254, 47.33891241252422, 48.68718646466732, 47.053000554442406, 52.5137597322464, 48.22352774441242, 55.08071959018707, 51.98178827762604, 56.214593946933746, 42.52128392457962, 32.20283500850201, 53.15918169915676, 49.478748589754105, 53.56483273208141, 50.30951701104641, 48.70691120624542, 42.554509341716766, 39.23326715826988, 38.488180339336395, 40.08678495883942, 42.18951612710953, 39.48255658149719, 37.74383828043938, 37.96366028487682, 38.554946556687355, 38.69782269001007, 39.70287635922432, 37.26946033537388, 38.91433887183666, 40.69721080362797, 41.161306500434875, 42.362030670046806, 46.43779456615448, 46.58929243683815, 51.35438494384289, 50.81352196633816, 52.505472376942635, 52.77197107672691, 55.7284252345562, 53.096295073628426, 53.38775463402271, 51.748351603746414, 55.352032631635666, 55.59890538454056, 55.308194383978844, 50.18716737627983, 51.88774712383747, 43.10595855116844, 39.93094392120838, 26.342234686017036, 24.836362190544605, 16.492505818605423, 12.557385675609112, 13.970037773251534, 9.215109720826149, 14.180226344615221, 6.896057585254312, 5.498404232785106, 1.036906884983182, 0.4080580553272739, 0.2790813980391249, 1.2794389645569026, 8.627300262451172, 22.845804803073406, 37.26642429828644, 38.837062418460846, 36.971221938729286, 40.79176872968674, 50.2004324644804, 49.437296614050865, 36.84023916721344, 7.90153730660677, 0.47001788683701307, 0.024300078293890692, 0.029397198632068466, 0.035983404886792414, 0.03038679133169353, 0.04646314606361557, 0.09579395074979402, 0.00919682759558782, 0.05838507684529759, 0.010522120592213469, 0.028799678839277476, 0.04722395504359156, 0.034564726520329714, 0.018675359606277198, 0.01714147765596863, 0.015740629387437366, 0.036282338260207325, 0.03547286665707361, 0.016184157248062547, 0.05187491660763044, 0.03219089667254593, 0.0725033602793701, 0.030093216264504008, 0.06728555745212361, 0.08366813344764523, 0.01845812555984594, 0.1569745791493915, 0.23826225165976211, 0.14155196375213563, 0.1174549333518371, 0.16048539779148996, 0.1364049469702877, 0.20448984199902043, 0.14629434677772224, 0.1879704065504484, 0.13049644214333966, 0.14305594086181372, 0.10533088236115873, 0.19415407004998997, 0.2051576116355136, 0.1723228461924009, 0.23516816378105432, 0.21322459360817447, 0.13610759808216244, 0.22224692744202912, 0.12650567659875378, 0.17749505146639422, 0.10384387816884555, 0.11144024945679121, 0.15094465896254405, 0.16311135375872254, 0.34320168080739677, 0.5091885896399617, 6.838647415861487, 30.840767696499825, 58.56358230113983, 57.87122145295143, 42.73354813456535, 30.5182771012187, 26.99478507041931, 40.98739743232727, 29.23647478222847, 17.078082896769047, 2.9569201078265905, 0.8850771852303296, 0.3127354203024879, 2.2702095564454794, 5.0446591805666685, 12.713119369000196, 9.845970869064331, 21.728432960808277, 12.055196072906256, 9.750169459730387, 19.42062109708786, 14.91453219205141, 23.358725979924202, 27.321907617151737, 40.4145971685648, 44.96100381016731, 52.14306302368641, 56.48932300508022, 56.36721655726433, 51.62465684115887, 48.506897538900375, 44.65822845697403, 41.44704356789589, 41.605742052197456, 44.56726133823395, 49.10308934748173, 50.827360823750496, 47.89570793509483, 44.6238137036562, 41.32264964282513, 39.552685618400574, 39.613064378499985, 41.897725984454155, 38.19575943052769, 39.84821476042271, 39.81145553290844, 47.778940200805664, 44.52417925000191, 36.886866465210915, 40.7039250433445, 43.16109359264374, 47.41299323737621, 49.73032929003239, 51.43171079456806, 48.904751390218735, 55.33914752304554, 51.6166240721941, 57.86854639649391, 53.532188683748245, 55.05086839199066, 44.2070596665144, 37.04289749264717, 53.702286556363106, 51.419030874967575, 55.75861841440201, 52.559668868780136, 50.40549226105213, 43.20405788719654, 40.7426031678915, 41.096375584602356, 41.42056658864021, 43.24022814631462, 41.98131009936333, 39.46282044053078, 38.09121184051037, 42.092047557234764, 41.02862522006035, 41.78187780082226, 39.45075608789921, 40.62907665967941, 42.121290788054466, 43.13416823744774, 43.55670176446438, 48.41707415878773, 49.95205499231815, 53.874835297465324, 55.51973283290863, 55.78732207417488, 56.00390665233135, 57.63461194932461, 54.18031610548496, 53.56447175145149, 52.8944157063961, 56.824297830462456, 58.12254376709461, 59.63122621178627, 53.46862189471722, 55.99002979695797, 43.404257744550705, 36.894146874547005, 28.652670308947563, 23.57700526714325, 18.10203105211258, 14.810680914670229, 17.684277668595314, 14.058654718101025, 26.14779531955719, 17.952452078461647, 9.884217716753483, 4.736780701205134, 1.3016170682385564, 0.3578797588124871, 2.1478782081976533, 10.321999825537205, 26.98922596871853, 42.963963970541954, 44.75873306393623, 41.9493842124939, 44.24903601408005, 56.015640422701836, 57.983980402350426, 42.88913458585739, 11.874576564878225, 0.5876810371410102, 0.11490245000459254, 0.1665450187283568, 0.13919956341851503, 0.16270222258754075, 0.10810513427713886, 0.1764456249657087, 0.11854739699629135, 0.20198593963868916, 0.05501880630617961, 0.12114289522287436, 0.14956634229747579, 0.13602616963908076, 0.19686087558511645, 0.12786649342160672, 0.09058689422090538, 0.14394638448720798, 0.17437712580431253, 0.14882792020216584, 0.1404373173136264, 0.1576475438196212, 0.13472502148943022, 0.1364730909699574, 0.13735023530898616, 0.27611022465862334, 0.134671289997641], [0.04538317647529766, 0.02143765737855574, 0.032630674832034856, 0.0564411620143801, 0.0674444661126472, 0.05686888769560028, 0.03443862449785229, 0.020698472726508044, 0.06752349741873331, 0.03685034840600565, 0.019189818231097888, 0.02351973598706536, 0.03226541943149641, 0.028192394238431007, 0.021155106915102806, 0.03026147413038416, 0.07262821178301238, 0.10136247030459344, 0.02841935227479553, 0.03229137233574875, 0.06977426804951392, 0.028228449627931695, 0.03734209545655176, 0.06511127998237498, 0.028488190182542894, 0.0448846684594173, 0.07144372182665393, 3.1756142852827907, 21.816041059792042, 36.03847078979015, 45.218098014593124, 28.947046212852, 19.478265903890133, 24.60760686546564, 43.7946791946888, 29.49876330792904, 15.449685025960207, 3.377309599891305, 0.6591332342941314, 0.13116522110067308, 0.7255887589417398, 1.451006883289665, 3.6058675730600953, 3.5123914014548063, 5.775913316756487, 4.121385673061013, 5.8706944808363914, 7.693981043994427, 14.137124307453632, 17.05069586634636, 22.55143079906702, 38.81768345832825, 42.981063053011894, 49.65825475752354, 52.7457182854414, 48.9647463709116, 47.809699550271034, 43.43704618513584, 40.18096290528774, 37.50112630426884, 38.69905762374401, 43.63977670669556, 49.51769270002842, 52.149560675024986, 50.223254039883614, 49.7408015280962, 44.3096199631691, 40.505594685673714, 37.261036187410355, 35.117556005716324, 35.159669145941734, 36.577148884534836, 36.20777070522308, 35.20993284881115, 36.430058777332306, 35.71901433169842, 36.97744980454445, 44.291206151247025, 52.31244653463364, 49.807795733213425, 50.356642082333565, 51.74735225737095, 50.48437222838402, 45.01349799335003, 52.462861463427544, 51.529608741402626, 48.864370957016945, 34.13715921342373, 25.759670846164227, 53.00118997693062, 48.886375576257706, 53.18836033344269, 44.466046169400215, 44.2114332318306, 36.651381701231, 37.726856991648674, 35.683414041996, 39.40483175218105, 36.689869835972786, 39.76007468998432, 36.58338814973831, 38.73303920030594, 36.68972164392471, 38.36306445300579, 38.20498153567314, 37.08169721066952, 34.986793622374535, 34.85579565167427, 34.15964640676975, 35.9795967489481, 37.15086489915848, 38.85460987687111, 43.162412121891975, 46.821083799004555, 45.63886843621731, 45.335751101374626, 49.52305421233177, 52.90336802601814, 53.32536198198795, 54.881777465343475, 52.7446923404932, 54.054846838116646, 57.316135838627815, 49.452560395002365, 46.616084799170494, 37.402817979454994, 34.97268497943878, 21.934260316193104, 22.26675197482109, 9.823803808540106, 17.09099270403385, 14.824039097875357, 9.868787694722414, 17.05232597887516, 5.8009482733905315, 2.3196128429844975, 0.5446663359180093, 0.10954197670798749, 0.3309719479875639, 1.0410692053847015, 8.628303408622742, 22.150339521467686, 30.392836332321167, 37.17423364520073, 24.283826239407063, 29.884400814771652, 41.724318489432335, 41.13253824412823, 29.273927472531796, 7.364749610424042, 0.26554667274467647, 0.0345099745754851, 0.11823073742561974, 0.029758372220385354, 0.018754678494588006, 0.07956237212056294, 0.07503185741370544, 0.03851154207950458, 0.08449953922536224, 0.03042371874471428, 0.031134542223298922, 0.0497312935476657, 0.05378670015488751, 0.01621196737687569, 0.01621868937945692, 0.026019358010671567, 0.04048647126182914, 0.046383580411202274, 0.023532844170404132, 0.05160540938959457, 0.033157974467030726, 0.06208747348864563, 0.0680844571616035, 0.11181626599864103, 0.07253927280544303, 0.08072172553511336, 0.018703772730077617, 0.029063616239000112, 0.022707143652951345, 0.015081494639161974, 0.05296652678225655, 0.01788632489478914, 0.014914281346136704, 0.032258858846034855, 0.027900978820980527, 0.02058133399259532, 0.03847303203656338, 0.005981759904898354, 0.052568653991329484, 0.05389257123169955, 0.033372752004652284, 0.06295387152931653, 0.04868568910751492, 0.07597258154419251, 0.01829232420277549, 0.034106134917237796, 0.04694386851042509, 0.06812430307036266, 0.07162876150687225, 0.04048978124046698, 0.057391637965338305, 0.010334753351344261, 0.046766057348577306, 4.163697827607393, 23.906922563910484, 43.944562152028084, 49.41973775625229, 35.95579482614994, 23.190630599856377, 28.574337512254715, 48.20309244096279, 33.153479397296906, 16.09278056770563, 4.140122942626476, 0.5471192230470479, 0.15550879295915365, 0.3149288526037708, 1.7097247880883515, 3.5567160230129957, 6.722152791917324, 9.259360246360302, 9.183470718562603, 8.148946780711412, 7.1952625550329685, 14.584524650126696, 21.425480917096138, 25.36753758788109, 37.595125660300255, 44.36122119426727, 51.199273467063904, 54.04694706201553, 50.37299260497093, 51.6399472206831, 45.54306037724018, 41.73256404697895, 39.88264091312885, 40.24893365800381, 44.97753672301769, 52.20416374504566, 52.414326667785645, 52.12838061153889, 50.919414684176445, 47.040883004665375, 41.95157289505005, 39.14202645421028, 37.565171867609024, 37.2075654566288, 37.61370666325092, 36.270653530955315, 36.17247819900513, 37.55879960954189, 36.90948285162449, 38.13126549124718, 44.8865582048893, 53.94614987075329, 52.01592944562435, 53.81920248270035, 53.71590122580528, 53.39452587068081, 46.52824491262436, 54.93877060711384, 51.294389963150024, 53.40084493160248, 37.47139669954777, 28.26559267938137, 53.83232317864895, 50.69835014641285, 54.397364258766174, 47.569362446665764, 46.02660723030567, 38.784496039152145, 39.14026714861393, 38.16544085741043, 42.30881832540035, 38.04243005812168, 40.27022771537304, 39.130820855498314, 39.98305432498455, 39.1708555072546, 38.46896477043629, 39.636148139834404, 38.681491166353226, 37.32951611280441, 36.875717863440514, 37.69209645688534, 38.683307468891144, 40.96968658268452, 41.667663529515266, 46.5859904140234, 49.00956876575947, 48.10291841626167, 48.38509127497673, 52.39118970930576, 53.08345176279545, 54.75985340774059, 54.65530201792717, 54.99865159392357, 55.500562861561775, 59.068244621157646, 50.880671963095665, 51.253846138715744, 42.88395166397095, 41.14389203488827, 23.172321282327175, 23.948727920651436, 17.430496886372566, 13.034904152154922, 12.121107336133718, 11.060832180082798, 10.708820018917322, 7.089702794328332, 4.337319061160088, 1.04869777103886, 0.4209198901662603, 0.14235553157050163, 1.7128457268700004, 9.04204610735178, 24.950000792741776, 35.43135456740856, 40.19959330558777, 29.136371053755283, 32.82356210052967, 48.23554269969463, 48.86729300022125, 34.20443080365658, 9.479494784027338, 0.27658033068291843, 0.03168401352013461, 0.08104445587377995, 0.00776949114879244, 0.006547376624439494, 0.12071447563357651, 0.014109409203229006, 0.019163292017765343, 0.061114028067095205, 0.0280640973141999, 0.052662309317383915, 0.09199892665492371, 0.04596622253302485, 0.04564297269098461, 0.02539715809689369, 0.013737038461840712, 0.033794588744058274, 0.04434339418367017, 0.08703271189006045, 0.08620214473921806, 0.02723653771681711, 0.036438523238757625, 0.02944273681350751, 0.01997143517655786, 0.03720669432368595, 0.02765270444797352, 0.09743086135131307, 0.09190822136588395, 0.10469392669619992, 0.18010655039688572, 0.12526669073849916, 0.20586389873642474, 0.13730955077335238, 0.12060416280291975, 0.11088094470323995, 0.14242867764551193, 0.11946432787226513, 0.12837738788221031, 0.11302320592221804, 0.1545511998119764, 0.11212262455956079, 0.1360187481623143, 0.18201639322796836, 0.22126779716927558, 0.08449161308817565, 0.17172661959193647, 0.19470613886369392, 0.12328271477599628, 0.15739021153422073, 0.13780925364699215, 0.13549957133363932, 0.18234794028103352, 0.2919158327858895, 4.978721318766475, 29.501115381717682, 49.86381612718105, 58.14899794757366, 41.93127818405628, 30.2059243619442, 34.08159859478474, 54.26233850419521, 37.670639008283615, 20.392373353242874, 4.740512575954199, 1.0054255742579699, 0.3253777278587222, 1.4788485830649734, 3.0422096187248826, 10.489408392459154, 14.528325665742159, 16.4712193608284, 10.778782814741135, 11.62253513932228, 13.439676482230425, 21.604648903012276, 23.589892275631428, 27.517967596650124, 42.10799530148506, 45.007106736302376, 52.3453413695097, 56.22832641005516, 54.642109125852585, 54.28508788347244, 48.30816440284252, 43.905606642365456, 41.620473861694336, 42.43866875767708, 48.302540704607964, 54.25517588853836, 55.81119239330292, 54.59735132753849, 55.048649311065674, 48.36411640048027, 45.68770341575146, 40.83198197185993, 39.44501839578152, 38.40516239404678, 39.74401295185089, 38.70812773704529, 38.313708901405334, 40.217923521995544, 38.65418963134289, 40.385775715112686, 48.52743163704872, 57.261468172073364, 54.98640105128288, 54.84401509165764, 57.26920835673809, 55.44043108820915, 47.54173032939434, 55.79787030816078, 51.44387014210224, 51.3138373196125, 42.428633496165276, 34.15930062532425, 53.14277037978172, 55.16151465475559, 55.673396587371826, 49.677306935191154, 49.573006331920624, 40.83379827439785, 41.58379822969437, 39.8687868565321, 43.210012167692184, 38.77697244286537, 43.8983566313982, 39.952222779393196, 41.98922127485275, 40.03371320664883, 41.986975595355034, 42.286851704120636, 40.27305856347084, 39.584330320358276, 38.67516070604324, 38.300136029720306, 40.539485067129135, 42.297920510172844, 41.95663422346115, 48.46754305064678, 50.877765119075775, 49.92339313030243, 50.40972523391247, 54.8215164989233, 53.845345079898834, 56.51281334459782, 54.80457700788975, 55.3985383361578, 56.08466751873493, 62.56067141890526, 53.65377075970173, 53.155248910188675, 43.71247060596943, 40.18599383533001, 26.531494930386543, 29.616302400827408, 15.887292344123125, 24.370900467038155, 25.149294398725033, 15.874658972024918, 26.965933218598366, 13.88619052246213, 7.585217105224729, 1.881597046740353, 0.3086485911626369, 0.726980137405917, 1.9490017485804856, 10.597982816398144, 29.01681426912546, 43.61327312886715, 51.75409309566021, 35.52933990955353, 40.998147055506706, 56.30717597901821, 56.64853826165199, 39.275338500738144, 12.240904457867146, 0.6022980809211731, 0.13830321229761466, 0.252916002064012, 0.12693745811702684, 0.10747098393039778, 0.21664659201633185, 0.1412084384355694, 0.09074069690541364, 0.22206618479685858, 0.08291821548482403, 0.11612662259722129, 0.16571231419220567, 0.10786110127810389, 0.1301306375535205, 0.15336370415752754, 0.14465917280176654, 0.12347505718935281, 0.1569870620733127, 0.27858976973220706, 0.18336109060328454, 0.10990521346684545, 0.20150991127593443, 0.1796995714539662, 0.16242096346104518, 0.20386682386742905, 0.13182444119593129], [0.058892999004456215, 0.11283429223112762, 0.07443995011271909, 0.026303379781893454, 0.03238977740693372, 0.011646907551039476, 0.044414558724383824, 0.07009661247138865, 0.0617140915710479, 0.042677625169744715, 0.0761983725533355, 0.03327668469864875, 0.04387371489428915, 0.05100641828903463, 0.05064217220933642, 0.05203725027968176, 0.02551217799918959, 0.03566022925951984, 0.0243685525492765, 0.06657195277512074, 0.043861039011972025, 0.027497768132889178, 0.05087068318971433, 0.014390104297490325, 0.04061203893797938, 0.040045442583505064, 0.09697184301330708, 1.8162569403648376, 19.297975078225136, 35.471651405096054, 51.315535828471184, 34.770304039120674, 25.615563578903675, 16.356883496046066, 21.966024711728096, 36.10317371785641, 18.57823859900236, 5.309835076332092, 0.522330243838951, 0.3259956697002053, 0.21440199605422094, 1.9009437086060643, 2.1485111117362976, 3.7278716638684273, 6.898439582437277, 11.04677863419056, 6.577135948464274, 6.504743183031678, 11.092221345752478, 14.48192160576582, 18.979193083941936, 29.624857641756535, 39.249176904559135, 47.60424077510834, 53.2904988527298, 53.4651792794466, 46.693973019719124, 44.94759812951088, 39.68138091266155, 37.85123571753502, 37.75230422616005, 45.32131567597389, 50.63005641102791, 54.53701436519623, 52.8880662471056, 49.82171058654785, 50.93610718846321, 49.27275404334068, 44.131930097937584, 38.14134635031223, 35.973935052752495, 37.55619674921036, 36.69173553586006, 36.46059013903141, 39.33262422680855, 35.25804586708546, 39.958283454179764, 47.24358692765236, 47.89185494184494, 51.596990525722504, 49.907851964235306, 51.39820039272308, 52.9166255146265, 41.381447687745094, 42.357372120022774, 45.01723699271679, 39.04252499341965, 37.45593152940273, 25.806070156395435, 47.156415805220604, 51.317492723464966, 48.805261328816414, 44.94387052953243, 39.740885719656944, 34.92341682314873, 34.88448031246662, 34.87509861588478, 35.91929018497467, 36.13536559045315, 36.01705513894558, 35.9839741140604, 37.26057641208172, 38.0779467523098, 36.43358498811722, 40.08610099554062, 39.50436361134052, 36.34070657193661, 36.25442460179329, 35.65663307905197, 35.14579989016056, 36.54030226171017, 37.74907819926739, 37.582966312766075, 40.263543874025345, 44.48988229036331, 45.18717907369137, 47.65013091266155, 51.344459876418114, 54.206986874341965, 50.72992265224457, 54.233965426683426, 50.40771134197712, 57.11608797311783, 54.08049926161766, 45.95701016485691, 37.974561899900436, 38.36119495332241, 18.04150030016899, 18.86728908866644, 19.487153626978397, 9.477924518287182, 7.77101288549602, 10.581266563385725, 8.497386183589697, 3.9560641441494226, 4.686722187325358, 1.0773033485747874, 1.1034572264179587, 0.2254832850303501, 2.340084007009864, 8.396657388657331, 22.156120911240578, 34.11476321518421, 34.46801885962486, 32.45986841619015, 36.56728081405163, 50.6636656075716, 49.52789515256882, 25.01928437501192, 6.470741657540202, 0.31046064861584455, 0.026356732778367586, 0.052229180801077746, 0.002123985368598369, 0.0816823985951487, 0.0016376331518586085, 0.09409803940798156, 0.018455459394317586, 0.06126897736976389, 0.03550682733475696, 0.05742996989283711, 0.02379899688094156, 0.04276855310308747, 0.05237692756054457, 0.02539352157327812, 0.02394236496911617, 0.0645243153849151, 0.04371678034658544, 0.024525420303689316, 0.007711565131103271, 0.05288028551149182, 0.023032673743728083, 0.06705285704811104, 0.044707443594234064, 0.04207939848129172, 0.06178612071380485, 0.006440417837438872, 0.07583952188724652, 0.007951434217829956, 0.01867111823230516, 0.028108594633522443, 0.043636505943140946, 0.05315851296472829, 0.007537406263509183, 0.01903579290228663, 0.04393396244267933, 0.021612520358758047, 0.01905039094708627, 0.029599676927318797, 0.03225925589504186, 0.026044143887702376, 0.056871592823881656, 0.04207542056974489, 0.06466176113463007, 0.02100317444273969, 0.013943568883405533, 0.045117725094314665, 0.06416401010937989, 0.039214942225953564, 0.04097987330169417, 0.04730591412226204, 0.06021644869178999, 0.03217413155653048, 2.490011374466121, 22.297182641923428, 41.8612327426672, 54.907266497612, 38.97573597729206, 27.906947024166584, 21.245427578687668, 28.12664743512869, 40.08035570383072, 21.38839490711689, 6.203560894355178, 0.949377987999469, 0.29109789698850363, 0.4097052075667307, 1.3886745530180633, 3.1767133763059974, 5.154945412650704, 6.257593045011163, 9.024066422134638, 5.130244363099337, 7.146698785945773, 10.231619775295258, 17.450062036514282, 22.301786094903946, 32.207550555467606, 41.43947817385197, 49.552160650491714, 55.85102565586567, 54.85006056725979, 49.110187366604805, 46.20718874037266, 42.37702086567879, 40.40667079389095, 41.3757061958313, 46.77725315093994, 53.78824934363365, 55.62743045389652, 54.55125980079174, 52.658360973000526, 53.143192157149315, 51.43118642270565, 46.113793551921844, 38.99356082081795, 39.05547849833965, 39.37743902206421, 38.79591442644596, 37.792243883013725, 40.11773809790611, 36.752870455384254, 41.86006620526314, 49.12163995206356, 51.62763588130474, 54.446165040135384, 51.07800677418709, 52.160656079649925, 52.81237430870533, 42.07409732043743, 45.2880484610796, 47.725594863295555, 41.769406870007515, 40.873616337776184, 29.355298206210136, 49.71875511109829, 52.78255730867386, 49.230762496590614, 47.524198070168495, 42.56555154919624, 38.36790159344673, 37.33841523528099, 36.70139841735363, 38.398413956165314, 37.960206270217896, 37.8918669372797, 38.156062960624695, 39.43519592285156, 39.09121558070183, 38.10538128018379, 41.65353588759899, 42.155640944838524, 38.42243626713753, 37.13092736899853, 37.59186163544655, 37.29895435273647, 39.08153370022774, 39.56244729459286, 39.72613871097565, 42.74744398891926, 46.98827862739563, 48.10408495366573, 49.37623769044876, 54.968523010611534, 54.39353786408901, 52.86312438547611, 54.28729176521301, 53.89842823147774, 56.6414288431406, 53.94580788910389, 46.03802561759949, 38.788542822003365, 37.84398950636387, 23.55753891170025, 19.885231666266918, 15.23965984582901, 11.804390531033278, 17.605884075164795, 13.44225749373436, 8.992611709982157, 3.706816043704748, 3.2856594678014517, 0.8618942135944963, 0.3271670755930245, 0.22498408681713045, 2.196523197926581, 10.41465975344181, 25.183963738381863, 40.943752974271774, 44.27946478128433, 37.70953372120857, 43.335819616913795, 53.87418553233147, 55.214810594916344, 30.693685188889503, 7.890446651726961, 0.3554396069375798, 0.05547735338041093, 0.012663716661336366, 0.044300605659373105, 0.020189940150885377, 0.03776344237849116, 0.0636778588523157, 0.04007760355307255, 0.07491154043236747, 0.03240928846935276, 0.025845877280517016, 0.022682057206111494, 0.04283478236175142, 0.01253635113243945, 0.0347189893363975, 0.0389565004297765, 0.030349637563631404, 0.04442317134817131, 0.04779493006935809, 0.08699812038685195, 0.02807946348184487, 0.06877792737213895, 0.026448131975485012, 0.005270062547424459, 0.021091428789077327, 0.05026086415455211, 0.16878980764886364, 0.22986535535892472, 0.16229246801231056, 0.12222550314618275, 0.17778437031665817, 0.10324523958843201, 0.21317978273145854, 0.13966779923066497, 0.13403837161604315, 0.13583404244855046, 0.19132348912535235, 0.12813811947125942, 0.18469569477019832, 0.14138199709123, 0.15398557938169688, 0.18468426569597796, 0.1614074272220023, 0.13459006935590878, 0.10246522011584602, 0.1974874411826022, 0.12984333734493703, 0.17418977804481983, 0.12617545056855306, 0.1492866119951941, 0.12792375753633678, 0.14581643335986882, 0.25054181227460504, 3.323308560065925, 26.201780922710896, 50.20949497818947, 64.2474465072155, 48.04161250591278, 37.43793569505215, 26.569810174405575, 30.09088173508644, 43.95039103925228, 24.112219847738743, 7.930857483297586, 1.195102371275425, 0.9090270032174885, 1.0231080441735685, 5.014213314279914, 6.737588988617063, 10.508510917425156, 15.258745271712542, 20.530239455401897, 16.365450136363506, 11.326767560094595, 19.009787142276764, 20.6039460003376, 23.555253334343433, 33.09145152568817, 43.90026792883873, 53.85040260851383, 55.326118022203445, 56.932174041867256, 52.718754932284355, 49.25408944487572, 45.04412055015564, 41.130847334861755, 42.52338521182537, 48.555854111909866, 55.58924250304699, 56.49387516081333, 57.39052064716816, 54.371639639139175, 55.09481303393841, 54.98328521847725, 48.0638375133276, 42.56335146725178, 41.78254276514053, 41.17631949484348, 40.937965884804726, 39.8840506374836, 42.817576825618744, 40.44376440346241, 44.25492949783802, 51.09209641814232, 52.77514390647411, 54.8073660582304, 52.3876179009676, 51.63623481988907, 53.537797182798386, 41.07449255883694, 43.7201613932848, 48.99087376892567, 45.9793795645237, 42.634350657463074, 33.45603056252003, 50.80604016780853, 56.48455426096916, 51.62538640201092, 50.62431871891022, 43.671725392341614, 39.88812781870365, 38.187054097652435, 39.03233014047146, 40.31128071248531, 39.76842664182186, 39.288014620542526, 39.98922899365425, 40.58682672679424, 41.90786384046078, 40.96346631646156, 44.241736605763435, 44.06259521842003, 41.23389780521393, 39.59145113825798, 39.71809074282646, 37.94199384748936, 41.50923863053322, 41.74655109643936, 40.99098823964596, 43.56342740356922, 47.96148620545864, 50.449547097086906, 52.8933859616518, 56.52239263057709, 57.06929348409176, 53.291148617863655, 55.62619172036648, 54.906920716166496, 57.52626836299896, 57.438006699085236, 48.63545224070549, 45.40475159883499, 39.899253621697426, 21.687366664409637, 27.099689841270447, 28.385573141276836, 17.151002883911133, 18.052306920289993, 17.166175469756126, 18.773935697972775, 11.343112383037806, 9.30942066013813, 3.19815372582525, 2.0735824573785067, 0.3543124033603817, 2.7389205805957317, 11.825606692582369, 29.091746248304844, 44.758862257003784, 47.118041664361954, 46.07359930872917, 50.18176406621933, 63.06558072566986, 65.38368433713913, 36.893470510840416, 9.746002983301878, 0.663312238175422, 0.13509708980564028, 0.10660014784662053, 0.11879739686264656, 0.14449426758801565, 0.1095081347739324, 0.1871762194787152, 0.141417367849499, 0.15905627369647846, 0.14960152009734884, 0.11245113622862846, 0.16881444695172831, 0.12646604591282085, 0.1618359432904981, 0.12288571771932766, 0.16628029465209693, 0.10269520425936207, 0.19957299489760771, 0.13125533267157152, 0.17298546532401815, 0.11573384093935601, 0.20201767387334257, 0.2342090566526167, 0.10918685162323527, 0.19898352184100077, 0.15322076651500538], [0.025466398619755637, 0.060118934197817, 0.06287845448241569, 0.0581306686217431, 0.0473055912880227, 0.07976385037181899, 0.034970362175954506, 0.039505437380285, 0.056179120801971294, 0.08070822586887516, 0.013899284003855428, 0.050271428626729175, 0.08001260343007743, 0.02672883634659229, 0.043762084751506336, 0.03559029668394942, 0.037295933871064335, 0.06430595327401534, 0.03800144913839176, 0.03637240159150679, 0.027009679870388936, 0.08653977740323171, 0.0748759915586561, 0.055618428232264705, 0.03583776211598888, 0.06747846389771439, 0.014859498787700431, 1.2939919461496174, 11.415158417075872, 37.30526581406593, 49.85041804611683, 44.30241174995899, 35.8627188205719, 33.73492419719696, 38.73310759663582, 41.982594430446625, 22.832870297133923, 8.945976812392473, 1.2534189107827842, 0.46926166804041713, 0.1571037425310351, 0.871851519914344, 2.7802407508715987, 3.466562060639262, 4.016504650935531, 6.819944819435477, 4.101930242031813, 4.5827279426157475, 3.679516646079719, 11.147000156342983, 19.971076659858227, 22.3631452023983, 32.60523721575737, 46.59387119114399, 48.43089401721954, 51.7324760556221, 48.68572734296322, 44.49245475232601, 43.13728027045727, 38.412195816636086, 36.58086508512497, 40.97312539815903, 47.4760090559721, 51.81395888328552, 53.370545357465744, 52.2938921302557, 52.5801345705986, 50.65694376826286, 46.21229566633701, 43.767107874155045, 39.48826387524605, 35.50255134701729, 37.22832374274731, 36.685598865151405, 36.26583158969879, 34.748284220695496, 36.675753593444824, 48.073713183403015, 50.47028638422489, 51.662119030952454, 51.24392867088318, 50.466885566711426, 52.33308702707291, 55.015883669257164, 49.39068831503391, 44.36172276735306, 54.75915424525738, 45.569845139980316, 31.511536203324795, 48.49612511694431, 50.78536167740822, 46.3165582716465, 40.91661863029003, 35.153950452804565, 35.995852276682854, 36.27774775028229, 38.40691789984703, 36.500039622187614, 36.82342886924744, 37.72884428501129, 36.45986817777157, 35.651294365525246, 37.038656920194626, 38.686335906386375, 40.01289412379265, 40.058408081531525, 40.90719893574715, 38.106027245521545, 36.025061309337616, 35.755207389593124, 35.03850884735584, 36.990300714969635, 38.07508930563927, 39.70315754413605, 40.87939202785492, 43.99557061493397, 46.67369730770588, 49.179586842656136, 56.666127517819405, 52.9964592307806, 55.57920344173908, 54.34545524418354, 52.44724430143833, 48.19276839494705, 45.29115669429302, 32.31983833014965, 33.92060123383999, 22.022953256964684, 15.502160210162401, 12.342988830059767, 8.877684976905584, 16.0154927149415, 13.520706184208393, 3.900072961114347, 3.464785893447697, 1.9063870352692902, 0.31357122701592743, 0.34378174343146384, 0.2273631896241568, 2.39513355307281, 10.521423574537039, 25.18470659852028, 33.20273995399475, 29.130464270710945, 32.06308230757713, 41.996418088674545, 51.7649757117033, 49.86198082566261, 25.55360220372677, 6.848284173756838, 0.2538929058937356, 0.05577260941208806, 0.04269148477760609, 0.03271145760663785, 0.04606382979545742, 0.06180623662658036, 0.030943567217036616, 0.05349045335606206, 0.03066604294872377, 0.0353301405266393, 0.041063928947551176, 0.01674595747317653, 0.03388969496882055, 0.08132770395604894, 0.03291315850219689, 0.12059541288181208, 0.05661926632456016, 0.01764480592100881, 0.03117123771517072, 0.06994953364483081, 0.047247187976608984, 0.043686686258297414, 0.02516742257284932, 0.0381730077060638, 0.022388495126506314, 0.14014497050084174, 0.03029128805792425, 0.03895229245244991, 0.04729424756078515, 0.05742320521676447, 0.05176922735699918, 0.02669777190021705, 0.04199072296614759, 0.028149436875537504, 0.006108079005571199, 0.05813147756271064, 0.022693669961881824, 0.011155536212754669, 0.024001378696993925, 0.010921993471129099, 0.02156763155653607, 0.018154969366150908, 0.05804034553875681, 0.02244875009637326, 0.0373201538604917, 0.09397899892064743, 0.0338605805154657, 0.0670170558441896, 0.024504901775799226, 0.04132496083911974, 0.03805773732892703, 0.05152567675395403, 0.0209064336377196, 1.5684383944608271, 13.73960293829441, 43.50053697824478, 55.43476179242134, 47.14988395571709, 37.792844250798225, 32.32259318232536, 36.42950400710106, 44.12274979054928, 27.1992065012455, 9.121041968464851, 1.4944118354469538, 0.2356282211258076, 0.23917832906590775, 0.8155930449720472, 3.2790718087926507, 5.472427876666188, 6.177731305360794, 9.481493476778269, 4.796101218089461, 7.193227289244533, 7.717615300789475, 13.960958160459995, 23.23840543627739, 26.9064075127244, 38.56013707816601, 48.61356541514397, 50.28115153312683, 55.456185042858124, 51.783416122198105, 46.7183069139719, 44.87022288143635, 41.275877952575684, 39.69260171055794, 43.168054819107056, 50.26918597519398, 54.241880401968956, 54.91877228021622, 52.787383049726486, 54.21358332037926, 52.41721831262112, 48.77718463540077, 45.37375286221504, 41.11177235841751, 36.45673334598541, 38.75952757894993, 38.22341814637184, 37.389210909605026, 36.52856469154358, 39.693551659584045, 47.99765266478062, 52.62930393218994, 54.18419189751148, 52.09439143538475, 50.88751159608364, 52.9855652153492, 53.400936126708984, 49.25839841365814, 44.88050512969494, 53.01477424800396, 47.710965648293495, 33.399269208312035, 51.200534999370575, 53.301362469792366, 47.87470646202564, 44.23405721783638, 36.81158110499382, 37.56808631122112, 39.03602734208107, 39.49275903403759, 38.5338918864727, 39.615834429860115, 39.005298390984535, 37.91009075939655, 37.474824115633965, 39.08528029918671, 41.20475336909294, 41.45037218928337, 43.06687764823437, 41.42984189093113, 39.88822661340237, 39.090406224131584, 37.24788889288902, 38.03434409201145, 38.20174030959606, 38.616936430335045, 41.70852653682232, 43.52015532553196, 47.43996039032936, 49.149933233857155, 51.09475627541542, 57.339717373251915, 52.93487973511219, 55.03672935068607, 53.95907297730446, 53.658372312784195, 52.29498267173767, 47.108154594898224, 35.82014590501785, 31.897331401705742, 21.807400323450565, 14.277430828660727, 11.937954314053059, 12.295692767947912, 13.129283487796783, 9.37065152451396, 5.4815782606601715, 4.472049381583929, 2.271320284344256, 1.791444153059274, 0.4355969588505104, 0.165833699866198, 2.8111720411106944, 10.907196924090385, 28.82482387125492, 37.360731437802315, 31.863549314439297, 37.609918266534805, 45.62531836330891, 57.78189204633236, 58.903189077973366, 30.69374218583107, 8.064182829111814, 0.3528954950161278, 0.04829759040148929, 0.07522898667957634, 0.025944486442313064, 0.03226227272534743, 0.02678709864994744, 0.022060740448068827, 0.020913198313792236, 0.04988666587451007, 0.033036455206456594, 0.03835371695458889, 0.043724513525376096, 0.01898292415717151, 0.14228024811018258, 0.005925747700530337, 0.023171844986791257, 0.023709677552687936, 0.037151890428503975, 0.01346028788248077, 0.052666405972559005, 0.06900298365508206, 0.05213621196162421, 0.05742478228057735, 0.06450332002714276, 0.03557961346814409, 0.09682277523097582, 0.0951450019783806, 0.18492574570700526, 0.13713851541979238, 0.26134460291359574, 0.13110038707964122, 0.18841351324226707, 0.12147854635259137, 0.09542365616653115, 0.13119980518240482, 0.1609211869072169, 0.07549095738795586, 0.11099176219431683, 0.21337088575819507, 0.08483899015118368, 0.12083972047548741, 0.15974451176589355, 0.14448769215960056, 0.1958223883411847, 0.15262698900187388, 0.10432839670102112, 0.1349566160934046, 0.1823127327952534, 0.11896777170477435, 0.15525662602158263, 0.21569063159404323, 0.21136144670890644, 0.13248550181742758, 1.8294600443914533, 16.629729755222797, 50.439846217632294, 62.90969409048557, 56.736906319856644, 47.06799075007439, 44.234026819467545, 48.46456401050091, 50.87752193212509, 28.029978722333908, 11.868703979998827, 2.0063595520332456, 0.6649675837252289, 0.7165872794575989, 3.1384776905179024, 7.4296914506703615, 12.358613591641188, 12.257302477955818, 12.976999059319496, 7.807037327438593, 7.4310926254838705, 7.571070464327931, 15.805816166102886, 23.082959577441216, 27.90925160050392, 38.872742503881454, 51.971677020192146, 54.62290495634079, 56.917989403009415, 54.17756885290146, 49.232255816459656, 48.60782012343407, 44.878058061003685, 41.774544194340706, 43.89331430196762, 50.42972356081009, 55.60452148318291, 55.31966596841812, 52.99181967973709, 56.11600063741207, 56.49751916527748, 51.07950769364834, 48.27594593167305, 43.47240708768368, 38.81026245653629, 40.341922268271446, 40.6199761480093, 40.090805143117905, 39.12391282618046, 41.37307673692703, 52.01419293880463, 54.77078162133694, 55.99078595638275, 52.11733840405941, 53.532257080078125, 53.55471387505531, 54.387306198477745, 51.186601147055626, 47.40467928349972, 54.34314876794815, 46.097089648246765, 37.24343553185463, 51.49426683783531, 57.2428909689188, 51.198521107435226, 46.3876486569643, 38.705346286296844, 40.064426958560944, 41.05254873633385, 43.09653505682945, 39.093305468559265, 41.206026300787926, 40.969762578606606, 38.67568127810955, 39.61534805595875, 41.11719086766243, 43.35291489958763, 44.37645457684994, 44.4287283718586, 44.11520719528198, 43.347215205430984, 41.26059517264366, 38.09272035956383, 39.89922322332859, 39.68826234340668, 41.72062128782272, 43.306234404444695, 45.9209842979908, 49.757235646247864, 52.57514163851738, 53.13767485320568, 58.701807484030724, 53.002953082323074, 56.00831441581249, 53.35662670433521, 55.484827905893326, 52.27890193462372, 50.71587860584259, 36.89503222703934, 40.668301954865456, 24.94810089468956, 25.94698179513216, 17.71349050104618, 16.891298219561577, 25.782847702503204, 21.210007779300213, 12.000904586166143, 8.237044103443623, 4.579487191513181, 1.444620257243514, 0.7984095951542258, 0.5113548296503723, 3.120792252011597, 14.546533338725567, 33.74446928501129, 42.154732793569565, 40.83213396370411, 44.808145612478256, 54.24822226166725, 64.91396114230156, 63.59420455992222, 36.44863598048687, 10.883640088140965, 0.6580669165123254, 0.1186064793728292, 0.11340032826410607, 0.07074772089254111, 0.12774156028172, 0.22401893860660493, 0.1046665562898852, 0.1778964643017389, 0.11054612477892078, 0.08687614841619506, 0.12390967371175066, 0.08066884751315229, 0.09784819325432181, 0.2642758487490937, 0.07305067192646675, 0.1782156026456505, 0.22828036540886387, 0.18052567087579519, 0.23460203869035468, 0.1235016409191303, 0.06624191970331594, 0.17844814719865099, 0.24657969363033772, 0.16482602659380063, 0.16383263224270195, 0.21220372495008633], [0.06281974317971617, 0.05968497818685137, 0.031145952743827365, 0.046095333964331076, 0.024124677256622817, 0.04107108325115405, 0.033034058069461025, 0.004666375507440534, 0.045497712126234546, 0.034947411259054206, 0.025513285654596984, 0.05124037663335912, 0.08188943553250283, 0.012377148395898985, 0.04202125121082645, 0.06275686842855066, 0.04151628279942088, 0.08502513563144021, 0.017802898219088092, 0.08119969832478091, 0.042284936280339025, 0.02659033860254567, 0.07892191351857036, 0.041399665424251, 0.004559948283713311, 0.010576588665571762, 0.03285725622845348, 0.4345632065087557, 9.821010958403349, 31.48994956165552, 45.47592557966709, 40.6482770293951, 30.208544321358204, 18.850503489375114, 22.82987415790558, 26.35046124458313, 21.608112417161465, 9.57491621375084, 2.719831829890609, 0.5137849180027843, 0.2526345202932134, 0.4663088405504823, 2.8463738271966577, 3.7561810947954655, 3.9357380848377943, 6.630004411563277, 1.9118852214887738, 5.771209644153714, 6.2982456386089325, 9.052788130939007, 15.503075961023569, 27.501656971871853, 35.96035838127136, 47.7846322953701, 51.839824095368385, 48.22369113564491, 46.51005148887634, 42.79931120574474, 42.89398692548275, 39.23613600432873, 37.29119136929512, 38.826677575707436, 44.944455698132515, 49.89706054329872, 55.118519961833954, 52.914843410253525, 52.157844230532646, 51.694664284586906, 50.93994498252869, 47.53937065601349, 45.538785606622696, 39.9225577712059, 37.81028911471367, 37.37588122487068, 35.382470190525055, 35.04074692726135, 36.55009053647518, 43.92680570483208, 49.323982894420624, 50.95150776207447, 51.414881497621536, 53.85835558176041, 54.669600650668144, 52.14886151254177, 56.143366768956184, 53.24020095169544, 51.67153872549534, 47.8356559574604, 35.581252723932266, 50.70831701159477, 47.52678573131561, 45.20270884037018, 41.3211715221405, 36.423215344548225, 36.5679419785738, 38.46690148115158, 38.8558030128479, 37.23983712494373, 36.96406312286854, 34.80319507420063, 36.215009316802025, 37.44905009865761, 36.895423606038094, 43.343176022171974, 45.525638312101364, 48.5467080026865, 46.07983097434044, 44.349457025527954, 40.545298755168915, 38.06945040822029, 36.021622493863106, 36.39690935611725, 37.288603708148, 37.97922804951668, 41.4299026876688, 45.01082293689251, 45.83928108215332, 51.97749450802803, 53.795370161533356, 55.866422429680824, 53.94805356860161, 55.1640073210001, 53.15029017627239, 49.44002866744995, 39.94683086872101, 30.655757524073124, 26.345850192010403, 24.55004185438156, 10.748099461197853, 4.674612712115049, 10.206877402961254, 18.261956870555878, 9.70720611512661, 3.373934431001544, 2.0439758710563183, 1.37932859826833, 1.6319823847152293, 0.07076361027429812, 0.4584041959606111, 2.5792236998677254, 11.75294129177928, 24.317931309342384, 33.87375354766846, 30.306149683892727, 31.143651343882084, 41.68228514492512, 44.24904361367226, 44.1532127559185, 25.48169106245041, 5.16613201238215, 0.3791509580332786, 0.04756318332511, 0.024812429219309706, 0.005887228844585479, 0.08161142701283097, 0.047802373810554855, 0.03853566558973398, 0.018959288609039504, 0.018627316676429473, 0.04309441530494951, 0.01338769749054336, 0.04666008608182892, 0.04592577177390922, 0.038750817911932245, 0.018970788187289145, 0.01953719158336753, 0.015891732509771828, 0.07708508317591622, 0.026304060702386778, 0.024812104529701173, 0.014688742667203769, 0.02910448074544547, 0.011533637261891272, 0.052984902358730324, 0.02276781051477883, 0.09404231153894216, 0.057958126708399504, 0.029224524987512268, 0.05355634493753314, 0.036040027043782175, 0.04733200803457294, 0.01990774406294804, 0.03826477797701955, 0.029657642371603288, 0.08039412670768797, 0.008130367878038669, 0.06597638668608852, 0.05067746504209936, 0.05792150172055699, 0.03835736832115799, 0.012833249165851157, 0.0385968111368129, 0.10153115305001847, 0.07375312954536639, 0.044900858410983346, 0.060034815469407476, 0.05302979487169068, 0.034894633427029476, 0.11062855512136593, 0.0807378301396966, 0.04015019672806375, 0.05036558861320373, 0.09290278831031173, 0.6985709618311375, 11.396830100566149, 36.44204333424568, 53.769523948431015, 48.41915264725685, 38.37029166519642, 27.477049492299557, 27.2194879129529, 32.63821184635162, 25.163471437990665, 10.90696893632412, 3.075376613996923, 0.6252972374204546, 0.26560809288639575, 0.8565170865040272, 3.2210788456723094, 5.075476001948118, 5.571105731651187, 8.768734373152256, 4.997249124571681, 5.92707728035748, 7.27169212885201, 10.707614533603191, 18.709441758692265, 29.949170239269733, 37.20540717244148, 51.23431138694286, 51.76730498671532, 49.293018355965614, 50.054983869194984, 45.24219252169132, 45.02600312232971, 40.77500022947788, 38.82093608379364, 41.8885038793087, 46.62891671061516, 51.87778025865555, 56.605030596256256, 52.67114728689194, 52.3510904610157, 53.73485840857029, 52.363097816705704, 49.56178933382034, 46.43452674150467, 41.3225394487381, 38.848560601472855, 38.77514474093914, 36.935557052493095, 36.70775927603245, 38.607725724577904, 46.91561512649059, 52.38514043390751, 52.51835748553276, 53.84089931845665, 54.29822377860546, 57.39918038249016, 53.88962410390377, 55.73266960680485, 55.77061057090759, 52.48322457075119, 47.60471574962139, 37.728813886642456, 51.47124007344246, 49.60450664162636, 46.277082189917564, 43.188668712973595, 38.31174060702324, 38.42972807586193, 39.15491156280041, 40.55958218872547, 39.0024371445179, 38.05732525885105, 37.22692921757698, 38.724922835826874, 39.72192853689194, 40.56566186249256, 44.27700251340866, 48.381390273571014, 50.91910310089588, 48.894134759902954, 45.21090880036354, 42.126295119524, 39.22565996646881, 38.7549602240324, 39.27133351564407, 39.42919224500656, 40.292870700359344, 43.69511693716049, 47.18924984335899, 50.22450037300587, 53.46582144498825, 56.2034073472023, 54.59730572998524, 56.30281001329422, 56.026865020394325, 55.117611810564995, 49.357941672205925, 42.48686537146568, 31.932175531983376, 31.53311714529991, 21.003502160310745, 14.86067958176136, 16.06320485472679, 8.545687291771173, 14.16503855958581, 11.055477317422628, 7.500050850212574, 4.487041477113962, 1.4988733897916973, 1.8609122629277408, 0.11183772148797289, 0.3336141421459615, 2.6050088787451386, 12.348971609026194, 28.785989955067635, 39.317048862576485, 36.35223135352135, 36.54584236443043, 48.85699175298214, 52.67291039228439, 51.57782055437565, 29.635107591748238, 6.320792203769088, 0.44184667349327356, 0.06440884462790564, 0.017398939817212522, 0.019954658928327262, 0.1095797965535894, 0.03994003534899093, 0.04378810815978795, 0.04470515777938999, 0.05560190802498255, 0.058174377409159206, 0.1024068205151707, 0.014032470753591042, 0.04572065328829922, 0.02584484940598486, 0.03873842033499386, 0.013874523174308706, 0.035471426890580915, 0.06788934653741308, 0.03847870946628973, 0.0478640017536236, 0.04950690890836995, 0.016271521017188206, 0.019340385151735973, 0.0125811128418718, 0.04116700583836064, 0.08618740568635985, 0.251096137217246, 0.11132359868497588, 0.14392082492122427, 0.1608314018812962, 0.10925506241619587, 0.17945280735148117, 0.08930882686399855, 0.08100302176899277, 0.19631547125754878, 0.09799050007131882, 0.17639051307924092, 0.1014867280900944, 0.16614365042187274, 0.15538531442871317, 0.10078821127535775, 0.15345537423854694, 0.18587219179607928, 0.24576668569352478, 0.148338993312791, 0.16696507431333885, 0.11797399143688381, 0.13339046185137704, 0.16083101596450433, 0.2087089218548499, 0.11179363791598007, 0.13478181062964723, 0.22977524378802627, 0.8631504024378955, 13.880107998847961, 42.935598492622375, 60.2183099091053, 54.46106784045696, 43.15759778022766, 29.83321376144886, 33.02511088550091, 36.28823518753052, 28.938082493841648, 12.997605353593826, 4.123339243233204, 0.921906471485272, 0.6856083730235696, 1.0507108317688107, 7.359276479110122, 10.831860266625881, 11.637379992753267, 17.009730264544487, 6.058711241930723, 9.08239709213376, 11.308130510151386, 11.713735945522785, 21.76287431269884, 32.04467609524727, 39.19759467244148, 49.93236064910889, 53.71773652732372, 53.55467967689037, 52.35967040061951, 47.499791979789734, 47.65244118869305, 43.54544676840305, 41.57874070107937, 43.799960911273956, 49.29826207458973, 54.55214895308018, 59.60174739360809, 53.58432948589325, 54.19129751622677, 55.34882180392742, 54.78553242981434, 52.388936430215836, 49.31323327124119, 42.4863637983799, 41.26458115875721, 41.03392593562603, 37.97909885644913, 38.32451552152634, 40.079709738492966, 49.77812312543392, 54.16149951517582, 54.616247713565826, 55.179293900728226, 57.59175784885883, 59.93174448609352, 55.4608815908432, 59.144829511642456, 55.68673387169838, 53.43631602823734, 49.742674827575684, 41.71094320714474, 53.057784140110016, 52.72326149046421, 48.08082640171051, 45.641722083091736, 39.728452786803246, 40.89056342840195, 42.3913536965847, 43.19846838712692, 41.40347510576248, 40.87569862604141, 38.95070672035217, 39.77436192333698, 41.80389381945133, 41.37015089392662, 47.221175730228424, 50.68694695830345, 53.65162007510662, 51.053881868720055, 48.63933943212032, 44.868102595210075, 43.24553266167641, 39.78148654103279, 41.09162963926792, 40.60382321476936, 41.68529458343983, 44.809114560484886, 49.912841096520424, 50.45063003897667, 56.11983463168144, 57.55521520972252, 58.261327520012856, 55.63009791076183, 56.77251800894737, 54.58904877305031, 52.96861432492733, 42.49524772167206, 36.16338528692722, 29.348074793815613, 30.566454716026783, 16.584698371589184, 15.40886476635933, 21.617733500897884, 35.12368127703667, 21.51650883257389, 14.403693303465843, 6.735635418444872, 3.3576945774257183, 3.445735378190875, 0.18927391472971067, 0.6876454793382436, 3.9380113128572702, 14.975295681506395, 31.69481936842203, 46.12899653613567, 42.136090993881226, 45.2791341394186, 57.34352856874466, 58.349368795752525, 59.12586472928524, 34.42381963133812, 8.480592984706163, 0.5467181070707738, 0.28850254719145596, 0.1032120878517162, 0.09988489138777368, 0.21161733922781423, 0.1374581881100312, 0.13660430267918855, 0.14222528465325013, 0.1271695425384678, 0.15902378247119486, 0.1993901890818961, 0.10598452892736532, 0.15565432811854407, 0.12227962055476382, 0.14539614028763026, 0.08263415104011074, 0.13783444213913754, 0.1856983214383945, 0.1070786698255688, 0.11796674807555974, 0.17769494152162224, 0.1439389184815809, 0.12725867447443306, 0.1567321937181987, 0.14755783835425973, 0.3230515995528549], [0.015242405243043322, 0.07241782775963657, 0.04399219134938903, 0.01224388650371111, 0.01875615165772615, 0.009988134206651011, 0.046043888287385926, 0.025338910636492074, 0.029003587624174543, 0.012310884812904987, 0.04699761855590623, 0.10407527239294723, 0.04265128634870052, 0.03575120172172319, 0.017351063870592043, 0.04109175948542543, 0.03633888620242942, 0.04273744598322082, 0.03780583385378122, 0.060819272985099815, 0.0570467137004016, 0.028756951542163733, 0.04996896634111181, 0.03991247940575704, 0.017390646316925995, 0.014109760795690818, 0.021103668659634423, 0.11505164395202883, 5.7319150026887655, 27.764093689620495, 44.64203752577305, 45.63274696469307, 32.065707966685295, 22.676934264600277, 26.063428446650505, 30.494936853647232, 28.118293583393097, 14.501833487302065, 4.034066358581185, 1.3050259603187442, 0.21767731639556587, 0.5289399297907948, 1.865693237632513, 4.072126066312194, 4.684910159558058, 6.794807743281126, 4.619711833074689, 4.4250525534152985, 2.843988505192101, 7.0112617034465075, 12.560621201992035, 25.868377313017845, 34.85566645860672, 42.39402115345001, 49.50087480247021, 52.78557054698467, 50.11692054569721, 45.346846505999565, 43.27952943742275, 38.07394556701183, 38.05317208170891, 37.489514127373695, 41.18294633924961, 48.61722081899643, 49.370161816477776, 51.94335713982582, 52.95571781694889, 50.25839075446129, 48.96588250994682, 49.748781099915504, 46.26407168805599, 41.939048767089844, 37.46715232729912, 36.133716478943825, 35.3909969329834, 35.474387258291245, 36.27817712724209, 39.199790954589844, 44.54546570777893, 47.48956672847271, 47.91836991906166, 49.39735695719719, 50.267400071024895, 51.51412837207317, 49.42623160779476, 47.86731965839863, 52.245516926050186, 51.5857545286417, 34.0271133184433, 47.54985809326172, 50.7857758551836, 44.515720903873444, 42.428428307175636, 41.3913993537426, 41.95696860551834, 45.44677734375, 48.06873545050621, 47.85165309906006, 44.86013822257519, 39.35617536306381, 36.51572898030281, 35.38873225450516, 38.32617223262787, 47.68057867884636, 51.06265939772129, 50.77498063445091, 50.900746285915375, 48.4908813983202, 44.86270688474178, 42.070669904351234, 36.68588384985924, 37.657286524772644, 39.8268599063158, 39.059612676501274, 42.29004733264446, 46.59298963844776, 48.970548659563065, 50.48527278006077, 52.093331292271614, 53.599023297429085, 58.77909153699875, 55.62656410038471, 53.39291475713253, 43.916040882468224, 37.04104699194431, 27.78722494840622, 23.963835909962654, 13.758537322282791, 7.013071356341243, 16.730975322425365, 5.075917728245258, 5.124923698604107, 5.14296418055892, 4.803896499797702, 3.7221118854358792, 0.5314777779858559, 1.8339135241694748, 0.6810341309756041, 0.35756176337599754, 4.501909604296088, 12.552173305302858, 31.602947898209095, 37.2334648668766, 31.603582464158535, 25.00313524156809, 36.154793947935104, 49.18752081692219, 46.127541214227676, 19.06337946653366, 4.68671933747828, 0.15493505343329161, 0.09534112192341127, 0.08002821821719408, 0.0424625953019131, 0.052028927093488164, 0.02246790492790751, 0.029820929703419097, 0.0171701894942089, 0.02968059514387278, 0.04758996001328342, 0.06401998893124983, 0.020735504040203523, 0.009423187275388045, 0.05941268420428969, 0.02896841167967068, 0.025822041352512315, 0.017105876831919886, 0.0765345135005191, 0.010244071254419396, 0.02655281004990684, 0.040480467287125066, 0.03026001952093793, 0.028645718448387925, 0.04905713773041498, 0.035673469174071215, 0.050329264195170254, 0.007769315816403832, 0.03402396432647947, 0.03377863256901037, 0.03541417019732762, 0.03764122549910098, 0.025169402251776773, 0.025556161381246056, 0.012584854193846695, 0.05836876815010328, 0.07687094388529658, 0.021378048077167477, 0.06010712662828155, 0.03558520555088762, 0.04028422859846614, 0.06975142474402674, 0.049385007441742346, 0.05734285288781393, 0.058128943128394894, 0.05065636578365229, 0.039707390606054105, 0.03646154837042559, 0.01487309029471362, 0.01681762110820273, 0.04338226099207532, 0.015359905773948412, 0.03390306104847696, 0.12504355661803856, 0.21018012572312728, 8.056258354336023, 31.508236080408096, 52.02170893549919, 51.542231664061546, 37.38708682358265, 22.66024176031351, 28.39313853532076, 35.18489599227905, 28.51573895663023, 15.671400278806686, 4.2449920903891325, 0.9499853616580367, 0.21991643530782312, 0.6593038095161319, 2.0899006817489862, 5.194609584286809, 4.970613503828645, 6.7713340278714895, 5.1678366959095, 9.519936963915825, 5.7408155500888824, 8.026430904865265, 14.249088149517775, 25.880382768809795, 37.068960294127464, 44.388062953948975, 50.75481131672859, 55.20968846976757, 52.12701268494129, 47.41580128669739, 46.06883056461811, 40.65786011517048, 39.231135472655296, 38.951968252658844, 45.124474838376045, 50.09300082921982, 52.760377898812294, 53.43536227941513, 53.45092624425888, 51.78480684757233, 50.70097580552101, 51.487598195672035, 48.02123799920082, 43.64736869931221, 38.50067026913166, 37.24003851413727, 36.976306065917015, 36.68037034571171, 38.87051582336426, 40.89945115149021, 46.670186296105385, 51.19623363018036, 50.73630630970001, 51.02385587990284, 52.19831205904484, 54.45190653204918, 52.0844853669405, 50.893500074744225, 53.89960236847401, 51.958898305892944, 36.1834330111742, 49.40484255552292, 52.961364313960075, 46.634848192334175, 43.5693284869194, 43.410329818725586, 43.32185536623001, 47.14117482304573, 48.94907221198082, 49.97591011226177, 45.29118329286575, 40.114318281412125, 38.21418844163418, 36.83631397783756, 39.390084743499756, 48.59157979488373, 53.18773716688156, 53.34104374051094, 53.46099570393562, 50.32964073121548, 46.87830872833729, 43.51599454879761, 38.973801881074905, 38.4445358812809, 40.73761023581028, 41.391319558024406, 44.455456137657166, 49.30309161543846, 51.157247722148895, 53.17737892270088, 54.192692041397095, 54.51931111514568, 57.99118861556053, 54.811675027012825, 53.14400531351566, 46.566907837986946, 39.71276342868805, 30.35398531705141, 24.71225894987583, 18.07464212179184, 18.94113052636385, 15.575611218810081, 10.525930132716894, 11.603435464203358, 10.015032347291708, 4.4539780262857676, 5.858635352924466, 2.7004224713891745, 0.7589009776711464, 0.38675901072565466, 0.37721953354775906, 4.366804528981447, 14.223758708685637, 32.312303334474564, 39.489719197154045, 34.0163104981184, 32.99333319067955, 43.26266974210739, 55.92992082238197, 52.47967176139355, 23.160272128880024, 5.893259570002556, 0.1808203777181916, 0.07897590476204641, 0.03920971750630997, 0.012622880913113477, 0.04757410773891024, 0.03051966730708955, 0.030634223367087543, 0.029684721484954935, 0.018442479231453035, 0.09918189200107008, 0.07001059013418853, 0.023178108713182155, 0.03674785781186074, 0.03524529078276828, 0.03365829703398049, 0.02839378714270424, 0.015582961968902964, 0.008836108572722878, 0.03876980204950087, 0.02690982204512693, 0.03562510712072253, 0.051321482242201455, 0.01842374556872528, 0.03948723620851524, 0.04526477052422706, 0.03012328623299254, 0.12120294239139184, 0.10389618473709561, 0.16914142237510532, 0.11015789248631336, 0.08033662510570139, 0.12145699438406155, 0.13034189731115475, 0.10893579790717922, 0.07405083466437645, 0.16646690026391298, 0.1572856429265812, 0.18508370441850275, 0.10350726966862567, 0.17518438951810822, 0.1634058082709089, 0.14473614835878834, 0.19843857764499262, 0.21948803798295557, 0.2344217264908366, 0.13047368789557368, 0.14759062643861398, 0.13840784027706832, 0.14272630854975432, 0.15191844577202573, 0.10398965823696926, 0.12489229207858443, 0.194482633669395, 0.3895293886307627, 9.69658948481083, 37.06763036549091, 59.38532620668411, 59.96447592973709, 45.216999873518944, 32.98982597887516, 36.8440655618906, 41.840744242072105, 36.145438849925995, 19.075876995921135, 5.854238988831639, 1.6733264224603772, 0.6651147664524615, 2.3183838464319706, 6.421966049820185, 11.93056371062994, 14.141785707324743, 11.693381387740374, 11.321117263287306, 9.83176153153181, 6.271069021895528, 9.26454696804285, 16.52463499456644, 29.649064242839813, 39.028769731521606, 46.50414280593395, 50.43267600238323, 55.445021241903305, 55.84941454231739, 50.9647386521101, 48.64904411137104, 43.21430593729019, 41.688019037246704, 41.07706122100353, 46.019733399152756, 53.24218824505806, 53.97769957780838, 55.20985186100006, 55.17616666853428, 52.68133454024792, 51.27295911312103, 54.00521770119667, 50.7647667825222, 45.6641598790884, 39.803468361496925, 38.27324487268925, 38.85381571948528, 38.829516023397446, 41.75673075020313, 44.150161519646645, 48.96573431789875, 54.67286467552185, 51.66954763233662, 53.85570332407951, 54.46411907672882, 58.26227746903896, 53.421971797943115, 52.90863834321499, 55.74676305055618, 51.79196946322918, 39.47265811264515, 50.39092004299164, 54.69790533185005, 49.984900429844856, 46.80376432836056, 47.588331028819084, 47.053479328751564, 51.242218762636185, 52.25900240242481, 53.119986802339554, 48.40391546487808, 42.336218655109406, 38.869862258434296, 39.20865207910538, 41.473896726965904, 51.855483055114746, 56.71007215976715, 55.61511531472206, 57.35871635377407, 53.13984453678131, 49.7708997130394, 46.6780898720026, 41.151126846671104, 41.042806059122086, 43.31666864454746, 43.44423919916153, 46.70369289815426, 51.153250336647034, 54.597689509391785, 55.90661287307739, 56.600801423192024, 56.042026206851006, 58.69126684963703, 55.174224972724915, 54.52557697892189, 44.31027352809906, 40.80669812858105, 32.54434548318386, 29.148102924227715, 17.772560231387615, 17.422435618937016, 26.64938360452652, 14.181181993335485, 14.37483575195074, 14.617873560637236, 14.05009662732482, 8.361908253282309, 2.957874806597829, 2.9230401758104563, 0.9584134281612933, 0.8317512623034418, 6.303806165233254, 17.325039245188236, 40.85790038108826, 47.35671065747738, 43.533416613936424, 37.91851490736008, 53.44438299536705, 64.55499440431595, 58.68597373366356, 26.56743910163641, 7.353838970884681, 0.34985500504262745, 0.13879967940738425, 0.20784191525308415, 0.14657550200354308, 0.13755526102613658, 0.1326407739543356, 0.0830335526552517, 0.08808541126199998, 0.11352491259458475, 0.17091701069148257, 0.17065059451851994, 0.12308451681747101, 0.12472864851588383, 0.14628664328483865, 0.11825076799141243, 0.13840295694535598, 0.10219878909992985, 0.2210601294063963, 0.08853440318489447, 0.08054772901232354, 0.2699515566928312, 0.1855527120642364, 0.14866332669043913, 0.23451329267118126, 0.1295973005471751, 0.13404083554632962], [0.058229355709045194, 0.05905881705984939, 0.035860167554346845, 0.051816042032442056, 0.013974318844702793, 0.04884133973973803, 0.023016186933091376, 0.07511146759497933, 0.04805284122994635, 0.0820553871744778, 0.04915979159704875, 0.07644579716725275, 0.032790414697956294, 0.0919086518115364, 0.061112376788514666, 0.03674307095934637, 0.09617812349461019, 0.029742664664809126, 0.06857535074232146, 0.06770271866116673, 0.04154333037149627, 0.04742996039567515, 0.060034882262698375, 0.0556082051480189, 0.013589215632237028, 0.06934041593922302, 0.081013152084779, 0.038450719366665, 3.8196934992447495, 20.935018435120583, 42.5071144849062, 46.568389758467674, 39.51791748404503, 29.889693930745125, 25.135560035705566, 25.52635006606579, 24.204883575439453, 18.819858133792877, 7.14588325470686, 1.5689795091748238, 0.5820020043756813, 0.32069629000034183, 0.7611251052003354, 1.8934673722833395, 3.0911367433145642, 3.112254347652197, 3.744896175339818, 6.350747896358371, 5.1131277065724134, 4.981955895200372, 10.65666876733303, 22.600681856274605, 32.24466696381569, 43.138040229678154, 49.3283374607563, 50.287576988339424, 51.848518028855324, 48.0433414131403, 44.7893176227808, 43.281615525484085, 38.00663597881794, 36.621104925870895, 39.179332852363586, 44.19692561030388, 47.94749915599823, 51.36507377028465, 51.76329620182514, 50.32775603234768, 51.245699375867844, 49.42439630627632, 47.69071273505688, 44.406594559550285, 40.92836380004883, 37.38973528146744, 34.90957796573639, 36.26138962805271, 35.460650995373726, 38.21418844163418, 39.400974959135056, 42.38306254148483, 44.21197660267353, 47.74249255657196, 47.67262950539589, 46.78833715617657, 48.31395909190178, 46.821991950273514, 50.415588319301605, 54.09635201096535, 30.116978734731674, 45.550542175769806, 52.253466099500656, 49.24012899398804, 46.63476079702377, 43.8647398352623, 48.902239724993706, 47.30591878294945, 45.3304997831583, 48.02523538470268, 48.51740397512913, 43.18029396235943, 38.22002112865448, 36.4243932813406, 39.023161232471466, 48.24277751147747, 53.34450535476208, 53.42249996960163, 53.53434696793556, 50.234626829624176, 49.88146238029003, 48.63028831779957, 45.11837616562843, 38.31185080111027, 37.55360908806324, 38.79306837916374, 43.61832305788994, 46.060045436024666, 49.38137121498585, 48.47830027341843, 51.92193768918514, 49.36893068253994, 50.977904945611954, 57.163676619529724, 57.5997070223093, 44.38420236110687, 32.56937853991985, 25.197755098342896, 24.32770248502493, 21.59110262989998, 22.953810207545757, 16.240765526890755, 7.846783194690943, 11.458346899598837, 8.50802656263113, 3.8293936662375927, 5.532390084117651, 4.38819975592196, 0.8459582843352109, 0.4282386240083724, 0.5445655225776136, 3.7151812948286533, 13.035396225750446, 33.5870361328125, 37.777044698596, 39.725675135850906, 26.29841733723879, 42.624421790242195, 54.01676908135414, 40.0079657882452, 18.194115310907364, 3.3975577633827925, 0.0954958597139921, 0.011862395695061423, 0.043477359795360826, 0.038227214172366075, 0.05689379046089016, 0.015059380493767094, 0.04227319921483286, 0.05602147008175962, 0.013157482353562955, 0.06225860532140359, 0.010654304514901014, 0.0115535054828797, 0.053730081708636135, 0.05396715336246416, 0.0836890100617893, 0.023150884881033562, 0.020626441728381906, 0.026338680036133155, 0.04264135641278699, 0.07237103534862399, 0.05703054972400423, 0.022015398935764097, 0.03961120826716069, 0.035779436730081216, 0.027183696802239865, 0.02380324382102117, 0.051486639786162414, 0.051438173832139, 0.04987018277461175, 0.08829560232697986, 0.012580524689838057, 0.017100425757234916, 0.0411715069640195, 0.04402531711093616, 0.0147100487993157, 0.06447387902881019, 0.02696971336263232, 0.01191165110867587, 0.05184755733353086, 0.039182925975183025, 0.000609658777648292, 0.012317545588302892, 0.07275143056176603, 0.04886464317678474, 0.07165875169448555, 0.07198569001047872, 0.04424632868904155, 0.00888275348188472, 0.05333078770490829, 0.05792564661533106, 0.004467234093681327, 0.02354265165195102, 0.02590399672044441, 0.05740318578318693, 5.018829591572285, 25.359808802604675, 48.36877875030041, 51.94965340197086, 44.153592735528946, 34.38166469335556, 31.699591912329197, 32.78593271970749, 32.191352024674416, 22.267536632716656, 7.713492522016168, 1.5157017367891967, 0.32223633548710495, 0.27280437236186117, 1.6468275943771005, 3.772182511165738, 3.9367205696180463, 7.763215703889728, 6.99514914304018, 7.084385929629207, 5.2981421537697315, 6.546894796192646, 14.345678016543388, 23.500192388892174, 35.00103905797005, 45.20908109843731, 49.57742929458618, 52.39715538918972, 54.60650883615017, 50.13032242655754, 46.89828425645828, 44.118904396891594, 39.31893356144428, 38.70077133178711, 41.13121211528778, 46.84488192200661, 49.684484750032425, 53.32362927496433, 53.34669403731823, 51.06178164482117, 52.32486046850681, 50.12198947370052, 49.767483696341515, 45.75904078781605, 41.80483236908913, 38.382002636790276, 37.109264731407166, 37.74262994527817, 37.42535836994648, 39.54409047961235, 42.33943708240986, 44.018061608076096, 47.09161788225174, 49.79795426130295, 51.644480377435684, 48.99083957076073, 51.0107883810997, 49.02938090264797, 53.279255256056786, 54.16295103728771, 33.131208792328835, 47.52435006201267, 52.029095739126205, 50.45995473861694, 49.532340914011, 45.93408219516277, 52.46568851172924, 49.991751462221146, 48.260917738080025, 51.38831712305546, 50.382951870560646, 44.7395820915699, 38.76707777380943, 38.11819039285183, 41.000229343771935, 49.703092351555824, 56.10955238342285, 55.634456276893616, 54.00452233850956, 53.09199370443821, 51.02653093636036, 50.572892278432846, 45.67595824599266, 39.886474907398224, 39.9219574034214, 41.064544692635536, 46.6623967140913, 48.316254168748856, 51.140524819493294, 50.60080178081989, 54.388240948319435, 51.59221038222313, 52.28921838104725, 57.83607333898544, 54.94690217077732, 46.090846583247185, 34.8898646235466, 25.37231583148241, 19.780362993478775, 18.45415435731411, 15.687767900526524, 10.242588836699724, 9.339729733765125, 12.165204919874668, 10.817550234496593, 5.046388087794185, 6.172557882964611, 3.2924535032361746, 0.133141886908561, 0.25266441400162876, 0.7450317218899727, 3.560513206757605, 16.07108563184738, 37.63986825942993, 43.74815449118614, 42.21987269818783, 30.67931056022644, 48.22163164615631, 61.951024532318115, 47.42957554757595, 21.970270983874798, 3.9545145398005843, 0.1556670040008612, 0.017222149108420126, 0.010503693993086927, 0.08892883983207867, 0.024564598279539496, 0.014005665307195159, 0.0041331094689667225, 0.041453415469732136, 0.01864402242063079, 0.02751266674749786, 0.024217629397753626, 0.0584993861411931, 0.022599296607950237, 0.031905247742543, 0.037092722704983316, 0.01196683906528051, 0.004939726122756838, 0.015416797887155553, 0.0682724876969587, 0.1336856436682865, 0.05226522320299409, 0.03274714748840779, 0.03943770527257584, 0.020075718057341874, 0.058910179723170586, 0.006366174775394029, 0.2030121666030027, 0.1308553892886266, 0.19529826880898327, 0.18188437999924645, 0.10562654657405801, 0.09450297002331354, 0.1893318022484891, 0.16785327665274963, 0.08148330263793468, 0.20559246564516798, 0.17908157024066895, 0.1554006471997127, 0.1384654309367761, 0.18729585368419066, 0.1184463313256856, 0.1551524136448279, 0.279675888014026, 0.17704357334878296, 0.22341843723552302, 0.1265841067652218, 0.14738050958840176, 0.08834856940666214, 0.12359829823253676, 0.10906385548878461, 0.12947220413479954, 0.13700337032787502, 0.11516482889419422, 0.2680407342268154, 6.889918064698577, 30.09944837540388, 56.494315937161446, 59.411259815096855, 53.24774734675884, 41.26665584743023, 36.821327582001686, 35.83070553839207, 33.66343483328819, 25.616110749542713, 9.868953935801983, 2.497098231688142, 0.8519297826569527, 1.0088002681732178, 3.091271398589015, 6.347937472164631, 8.22760920971632, 10.588938351720572, 10.440991390496492, 13.382529448717833, 8.933757618069649, 8.677903097122908, 15.981537736952305, 26.155159324407578, 36.092830672860146, 45.80258645117283, 51.19584985077381, 53.867718279361725, 55.817997828125954, 53.44466418027878, 48.761176094412804, 47.81802490353584, 42.12235853075981, 40.73710486292839, 42.36367978155613, 48.872722908854485, 51.28818869590759, 56.80912524461746, 55.15921197831631, 50.952773094177246, 53.22684466838837, 54.6059350669384, 52.620423808693886, 47.928724363446236, 44.24109444022179, 40.995323807001114, 38.71930293738842, 39.52427074313164, 40.38823038339615, 42.96821974217892, 43.46064291894436, 45.195352435112, 49.52516309916973, 52.554223760962486, 52.12860479950905, 50.95523536205292, 52.977391853928566, 51.426216289401054, 55.89942745864391, 55.702601820230484, 38.3242267370224, 48.83553810417652, 54.35771718621254, 53.361851423978806, 51.896205469965935, 47.66941487789154, 54.78383392095566, 52.12855540215969, 49.948000609874725, 53.43060493469238, 52.583258002996445, 48.42299044132233, 41.69389732182026, 39.952872544527054, 42.868763878941536, 51.98651522397995, 58.61794978380203, 57.30584979057312, 55.663353726267815, 54.19203467667103, 53.60694207251072, 53.260347470641136, 48.83964568376541, 42.2692396491766, 41.016652062535286, 43.27478729188442, 48.42897891998291, 51.423814818263054, 54.066542610526085, 53.31085056066513, 56.75645247101784, 56.35747767984867, 55.48139289021492, 61.76084093749523, 59.209973216056824, 49.030456244945526, 35.9287478774786, 27.466626651585102, 27.741747088730335, 23.511454984545708, 32.67999440431595, 24.548679627478123, 16.137958243489265, 25.470840744674206, 18.928547501564026, 11.347276009619236, 11.918175425380468, 8.01705775782466, 1.2874593841843307, 0.7949679892044514, 0.9177090029697865, 4.441684260964394, 18.0597735196352, 42.45963603258133, 50.94777636229992, 51.316823959350586, 39.25534017384052, 56.89749710261822, 67.63116493821144, 54.18829947710037, 26.76845021545887, 5.620338264852762, 0.3678169084014371, 0.10110730509040877, 0.1222310469893273, 0.1496059581404552, 0.0881145108724013, 0.12454043986508623, 0.20858652686001733, 0.16144288703799248, 0.08433823342784308, 0.16103436442790553, 0.10324767383281142, 0.12085182490409352, 0.14376375678693876, 0.1465537867625244, 0.15476400323677808, 0.11428410740336403, 0.0877523428061977, 0.10017987282481045, 0.16414111334597692, 0.17259738146094605, 0.20221124083036557, 0.11958396949921735, 0.1358626299770549, 0.1096593622060027, 0.15062264108564705, 0.10482447047252208], [0.057185480472981, 0.04512141727900598, 0.008901608671294525, 0.04779355338541791, 0.01813945476897061, 0.02501981125533348, 0.006915636331541464, 0.0018906324544332165, 0.01811534424632555, 0.014159119182295399, 0.07155324798077345, 0.03722246125107631, 0.0220425986481132, 0.0074285934988438385, 0.01857539602497127, 0.05740029882872477, 0.05848819826496765, 0.047329870649264194, 0.03163600398693234, 0.03937555411539506, 0.04629460061551072, 0.021209567566984333, 0.0117540207975253, 0.018647054093889892, 0.07025403683655895, 0.08967258312623017, 0.05052642314694822, 0.021595094731310382, 1.7139327060431242, 16.071319319307804, 39.53442379832268, 50.46624340116978, 37.057264521718025, 26.335921324789524, 24.918907061219215, 30.685764513909817, 30.802984423935413, 21.011477932333946, 8.629730232059956, 2.0292255375534296, 0.2893646853044629, 0.1834161431179382, 1.6224072547629476, 3.629728155210614, 1.7141568940132856, 7.436276497319341, 5.142245069146156, 6.47676195949316, 3.527724528685212, 3.848983277566731, 12.0881412550807, 18.992344178259373, 31.70521941035986, 42.73286797106266, 49.94187153875828, 52.56110139191151, 52.16364651918411, 49.50905956327915, 46.621761694550514, 44.515276327729225, 40.88498532772064, 38.06355692446232, 38.56624715030193, 39.51553501188755, 46.23946040868759, 48.2343153655529, 53.37749898433685, 48.62387426197529, 49.389996752142906, 49.9056176841259, 47.472437247633934, 45.62442921102047, 42.83138148486614, 39.10331793129444, 38.40856321156025, 36.34170211851597, 38.023104295134544, 36.871758475899696, 35.43187513947487, 35.90256728231907, 37.28150948882103, 40.539956241846085, 40.641213208436966, 42.29911744594574, 44.57180969417095, 46.760036274790764, 47.83055663108826, 56.302042454481125, 33.73923696577549, 43.11163164675236, 49.96919587254524, 49.98621515929699, 50.648774206638336, 50.226582661271095, 49.64091628789902, 51.10089294612408, 57.06472232937813, 51.961539164185524, 50.10169096291065, 46.464054957032204, 39.48366232216358, 35.51547445356846, 36.743652150034904, 46.98602914810181, 52.37728625535965, 52.44836524128914, 54.64046761393547, 53.90013433992863, 51.105289310216904, 48.204946741461754, 48.65732006728649, 44.50811371207237, 36.52239382266998, 40.76521955430508, 45.9732922911644, 50.38074418902397, 48.580404594540596, 47.28335939347744, 46.80381752550602, 51.48440636694431, 53.58417369425297, 44.73529972136021, 40.89144118130207, 41.31529703736305, 24.335030391812325, 21.162337437272072, 14.46615720167756, 14.251499120146036, 10.63452260568738, 5.876796953380108, 8.561073616147041, 9.707585144788027, 7.69140905700624, 1.6020084056071937, 8.600144069641829, 3.632152662612498, 0.09143522096564993, 0.42875029030255973, 0.5119161307811737, 5.526456227526069, 11.347901076078415, 26.38443522155285, 33.20630796253681, 28.760385029017925, 31.638939566910267, 42.409501522779465, 45.4340860247612, 37.601934894919395, 19.627373702824116, 2.913937526755035, 0.21228752826573327, 0.03130203753244132, 0.05389040416048374, 0.020654784348153044, 0.00804288443760015, 0.014831600528850686, 0.023072723743098322, 0.050296698755118996, 0.02818133623804897, 0.015182486095000058, 0.05601879092864692, 0.05506990688445512, 0.08227026119129732, 0.11098934279289097, 0.01795378055248875, 0.012927533462061547, 0.008521899944753386, 0.04829367928323336, 0.10243752316455357, 0.06696925411233678, 0.0412068962759804, 0.02076287073577987, 0.013381870703597087, 0.0213402857480105, 0.017511108017060906, 0.010103753393195802, 0.03391596699657384, 0.0647460542677436, 0.01624346783501096, 0.012962003438587999, 0.04895845806458965, 0.02676025887922151, 0.031516826202278025, 0.01623613541596569, 0.04119716671993956, 0.021743522411270533, 0.08729002191103064, 0.03131216042675078, 0.03295240327133797, 0.06912247685249895, 0.07768863477394916, 0.05278087854094338, 0.06219314418558497, 0.00881708361703204, 0.051709246981772594, 0.03906699137587566, 0.019090793466602918, 0.013698096117877867, 0.03412215046409983, 0.05138562235515565, 0.06941119456314482, 0.024820722719596233, 0.0626808576635085, 0.026525586217758246, 2.320900736376643, 20.373362973332405, 46.02050855755806, 56.15297645330429, 44.68534380197525, 30.5212789401412, 27.23946724087, 30.71153473109007, 34.085683375597, 24.531059972941875, 9.638679642230272, 2.5673878099769354, 0.3192146960645914, 0.3176711773267016, 1.1280128150247037, 3.394495127722621, 4.476448595523834, 7.323894202709198, 7.675368217751384, 6.154862232506275, 6.074642362073064, 7.060374543070793, 12.441827226430178, 20.726677514612675, 34.45190392434597, 43.414805978536606, 51.587491035461426, 53.71436610817909, 53.84901948273182, 53.2290181517601, 49.49309282004833, 46.38154998421669, 42.426976785063744, 39.76779207587242, 39.59859475493431, 42.293850928545, 49.34984430670738, 50.79174153506756, 55.3443456441164, 50.568818897008896, 49.71927188336849, 50.57528994977474, 49.550044164061546, 47.22244866192341, 44.298247173428535, 41.050394251942635, 39.1482999175787, 37.981618121266365, 39.586670994758606, 37.66474172472954, 36.90817952156067, 37.42427922785282, 39.56797979772091, 44.2638324201107, 43.36255118250847, 45.486090034246445, 47.43712954223156, 49.815000146627426, 51.65996454656124, 57.707412242889404, 35.80816514790058, 43.74149724841118, 50.62860868871212, 52.40062840282917, 54.46097284555435, 52.979481741786, 51.88666418194771, 54.75400552153587, 56.03082820773125, 53.02970364689827, 51.550917997956276, 49.35265235602856, 39.13104124367237, 38.83859373629093, 40.25237627327442, 50.07169917225838, 54.57272104918957, 53.47342483699322, 54.994395822286606, 55.66497623920441, 52.798083275556564, 50.85311584174633, 49.286562502384186, 45.145559906959534, 39.06867139041424, 42.65489615499973, 48.259656205773354, 53.908706679940224, 50.80437585711479, 50.59431932866573, 49.40563291311264, 54.7168131172657, 55.47038868069649, 51.990079432725906, 47.1877147257328, 42.80927047133446, 28.064492270350456, 22.304347157478333, 16.95523738861084, 16.077262200415134, 12.114448193460703, 9.29128898307681, 12.376583777368069, 6.973249493166804, 8.410880025476217, 8.969108071178198, 3.444036631844938, 2.726122629828751, 0.06329774565529078, 0.23753098386805505, 0.5957525165285915, 5.695263594388962, 14.252097588032484, 32.80965864658356, 41.5845961868763, 34.7997410595417, 34.30199816823006, 52.30520412325859, 53.327885046601295, 42.31565035879612, 21.63907315582037, 3.590053771622479, 0.19130380736896768, 0.03280893128248863, 0.06754781017662026, 0.034183937968919054, 0.06084818705858197, 0.016914989028009586, 0.08380895596928895, 0.04806687153177336, 0.05845249725098256, 0.014691642609250266, 0.05296756207826547, 0.050800516837625764, 0.07379212198429741, 0.04778146751050372, 0.022168309187691193, 0.06100843529566191, 0.03201141196768731, 0.02666876320290612, 0.04466601320018526, 0.045749029304715805, 0.04582846879202407, 0.03051970441447338, 0.012880602826044196, 0.030238217077567242, 0.05804169624752831, 0.04610777978086844, 0.21394662908278406, 0.3054273733869195, 0.15860728919506073, 0.11828693284769543, 0.19184002390829846, 0.1447807069052942, 0.07174188707722351, 0.15012316085631028, 0.1645611837739125, 0.1224391080904752, 0.18516548909246922, 0.08900594155420549, 0.10145052612642758, 0.10985655084368773, 0.1705060835229233, 0.1562136402935721, 0.2207203148282133, 0.2022360879345797, 0.1456195118953474, 0.16630748694296926, 0.06579056032933295, 0.1331178264808841, 0.115113353531342, 0.13653412519488484, 0.16898922272957861, 0.14697350095957518, 0.17297283397056162, 0.11993662323220633, 2.8451051702722907, 23.01465254276991, 52.339482083916664, 64.41434875130653, 51.54600486159325, 36.27083972096443, 36.739932149648666, 41.32024057209492, 40.2582773566246, 29.2064867913723, 12.287602052092552, 3.3913030615076423, 0.6511433911509812, 0.7262020697817206, 4.097453132271767, 8.060501776635647, 11.454976480454206, 17.827628776431084, 10.578884091228247, 13.547864276915789, 8.456396833062172, 8.367752339690924, 15.460634138435125, 23.081040680408478, 36.09549432992935, 46.336963176727295, 52.18768782913685, 54.92117755115032, 55.26432193815708, 55.83063594996929, 52.219438925385475, 49.239502027630806, 45.640665739774704, 42.86921985447407, 41.145518347620964, 44.100201800465584, 50.736496299505234, 53.580886870622635, 57.94686779379845, 52.083041444420815, 50.65847888588905, 52.58042715489864, 52.221813797950745, 49.09379504621029, 47.22995325922966, 43.48422825336456, 41.74858018755913, 41.14392623305321, 41.90561816096306, 40.5109827965498, 38.72673913836479, 39.942951276898384, 40.79258568584919, 44.568306282162666, 44.47814851999283, 48.859123438596725, 48.99248108267784, 51.777233853936195, 52.68858075141907, 59.742647632956505, 39.96261142194271, 44.687851667404175, 51.377244517207146, 54.6113383769989, 57.24341154098511, 56.38226754963398, 54.573165625333786, 55.41304595768452, 59.06414084136486, 56.966755986213684, 54.35390219092369, 52.337031215429306, 42.368368729949, 40.648166835308075, 41.712398529052734, 51.89749740064144, 57.02228240668774, 55.73755994439125, 56.24192588031292, 56.758998334407806, 56.042455583810806, 52.34426222741604, 52.04007335007191, 49.269805401563644, 42.306272462010384, 45.79762011766434, 50.91724120080471, 56.05964966118336, 53.69165472686291, 51.96841299533844, 49.83385853469372, 56.603734865784645, 58.109795451164246, 55.334374979138374, 47.73339584469795, 44.3264302611351, 32.03996814787388, 24.18014120310545, 15.4612554050982, 20.131464153528214, 15.916822459548712, 15.139216035604477, 17.38831914961338, 20.97755905240774, 19.682674035429955, 12.060219403356314, 14.39854172989726, 6.654089894145727, 0.9811653604265302, 0.5830935551784933, 1.1511323181912303, 6.959356488659978, 17.109216526150703, 34.286707788705826, 46.904082745313644, 41.461805775761604, 43.82519915699959, 58.15583758056164, 59.09399963915348, 50.93258857727051, 25.473534800112247, 4.17538695037365, 0.4053946357453242, 0.09743924762005918, 0.19423287129029632, 0.11436912041972391, 0.19808561220997944, 0.09634548521717079, 0.13547795999329537, 0.17365332401823252, 0.1662296208087355, 0.11905184219358489, 0.13796982471831143, 0.24672105791978538, 0.4376861045602709, 0.1571303411037661, 0.088902738498291, 0.18757037410978228, 0.2061197318835184, 0.07929318031528965, 0.19774328917264938, 0.16802990779979154, 0.17639403085922822, 0.15405020560137928, 0.15884732943959534, 0.14841167925624177, 0.0930627656634897, 0.07735920284176245], [0.05227166504482739, 0.017984657606575638, 0.04501854818954598, 0.0259465588897001, 0.03411131510802079, 0.11857422563480213, 0.02966762796859257, 0.011735672123904806, 0.047483268863288686, 0.040619300852995366, 0.03585869068047032, 0.027515865403984208, 0.03991129568021279, 0.10575628140941262, 0.006964041522223852, 0.16289167804643512, 0.03703180351294577, 0.00729681079974398, 0.04253986400726717, 0.07119592613889836, 0.006734135304213851, 0.011249580238654744, 0.06713533191941679, 0.01683969072473701, 0.06790536950575188, 0.04058211554365698, 0.0798737327568233, 0.02600107891339576, 0.6142023077700287, 7.46073673479259, 28.441223055124283, 51.08765445649624, 40.99869042634964, 37.81242460012436, 28.582670465111732, 28.067138828337193, 32.79798187315464, 29.642625488340855, 13.22525778785348, 4.003014424815774, 0.991124922875315, 0.37029660190455616, 0.8750968426465988, 2.585652954876423, 2.4495399836450815, 4.672576496377587, 8.037959486246109, 2.9348779655992985, 4.784732228145003, 4.150363868102431, 9.945174045860767, 17.299930192530155, 31.860203593969345, 43.3687524497509, 49.86957661807537, 50.743039548397064, 51.100839748978615, 50.78576825559139, 47.77406886219978, 46.54768846929073, 43.593571186065674, 39.02186170220375, 40.18664740025997, 40.01450903713703, 46.11825451254845, 48.01509752869606, 48.86588707566261, 53.01168501377106, 50.17981477081776, 50.19774980843067, 50.24232141673565, 49.49081294238567, 46.99894845485687, 44.91441071033478, 42.151586562395096, 39.7627155482769, 36.17851607501507, 35.63405469059944, 36.49291880428791, 35.38503885269165, 36.10654793679714, 37.77014046907425, 38.40913698077202, 40.677999034523964, 43.57998311519623, 48.419198244810104, 48.05194795131683, 53.46430912613869, 33.5202357172966, 46.00147917866707, 50.49924463033676, 48.89705300331116, 53.172321394085884, 52.39920347929001, 52.16179981827736, 50.608374774456024, 50.518217012286186, 53.341948091983795, 50.66027618944645, 46.0331504791975, 37.862680703401566, 35.6511689722538, 35.947309881448746, 42.74068035185337, 51.00982703268528, 51.42030380666256, 50.1365464925766, 52.181691750884056, 52.478649616241455, 48.20536471903324, 49.16851043701172, 44.54855494201183, 41.96803741157055, 39.669814333319664, 46.672792956233025, 49.3083543330431, 49.21631567180157, 45.52651606500149, 47.09925167262554, 48.13674800097942, 56.40253946185112, 54.15931083261967, 35.924233719706535, 30.619081892073154, 22.03486941754818, 13.25257832184434, 12.744393590837717, 10.91725118458271, 11.96433724835515, 7.809445923194289, 8.394838236272335, 5.033597499132156, 5.7970881555229425, 7.354375692084432, 0.6716293981298804, 0.8173809677828103, 0.10161519385292195, 0.11289858448435552, 1.5175349009223282, 4.657030580565333, 19.34244979172945, 27.981662414968014, 35.0969573110342, 31.526921577751637, 35.10152846574783, 47.247629910707474, 45.17533130943775, 36.889507323503494, 16.32988214492798, 2.163953483104706, 0.08919088475522585, 0.05112958140671253, 0.03427393450692762, 0.04308939096517861, 0.03400064233574085, 0.08814329135930166, 0.04406953426951077, 0.02912754483986646, 0.08738877208088525, 0.0061535313761851285, 0.11138294081320055, 0.038833051585243084, 0.07152085323468782, 0.025024523893080186, 0.08391594397835433, 0.028481855952122714, 0.047098565482883714, 0.058675612817751244, 0.026477775209059473, 0.024105852680804674, 0.037503712956095114, 0.07292452166439034, 0.03952278508222662, 0.0735233977320604, 0.018162641317758244, 0.04325909787439741, 0.06394667958375067, 0.044257516565267, 0.02024318924668478, 0.023402450678986497, 0.1304836623603478, 0.02793655738059897, 0.04334178054705262, 0.045407006837194785, 0.049879656289704144, 0.03068846508540446, 0.04122466329135932, 0.03324234923638869, 0.018304680961591657, 0.050054617604473606, 0.07965171927935444, 0.061359964674920775, 0.04085508859134279, 0.0353071673453087, 0.05308743377099745, 0.05511580871825572, 0.02907005065935664, 0.02847602267138427, 0.029390944182523526, 0.0336796078045154, 0.09020263241836801, 0.04252343285770621, 0.035487078785081394, 0.06856584383058362, 1.0495913168415427, 9.467983301728964, 35.61720259487629, 58.23626786470413, 46.21444635093212, 41.18406727910042, 31.394950859248638, 32.53315128386021, 36.03946253657341, 30.019848346710205, 14.47627890855074, 4.051661314442754, 0.9808389935642481, 0.4785351891769096, 0.9622537752147764, 2.912905882112682, 4.187284586951137, 5.073850164189935, 7.651792857795954, 5.422256318852305, 6.7031908594071865, 4.282305613160133, 13.227709606289864, 21.01262167096138, 31.827576644718647, 44.0570817142725, 51.0054686665535, 51.603552773594856, 52.28074863553047, 53.54173757135868, 50.44870734214783, 48.0429158359766, 43.711000084877014, 41.362908482551575, 41.446029022336006, 41.29480853676796, 46.80479787290096, 51.03363275527954, 51.42826057970524, 52.27779999375343, 50.96008390188217, 50.76187513768673, 51.72597460448742, 51.73955887556076, 48.46968613564968, 45.61402916908264, 42.75526776909828, 42.25448504090309, 38.55673626065254, 38.86684902012348, 37.80596874654293, 37.42366746068001, 38.79018433392048, 38.830724358558655, 39.35887701809406, 42.356053590774536, 46.318321377038956, 51.205413937568665, 50.13701006770134, 54.52336169779301, 36.705346405506134, 47.1145648509264, 51.96755804121494, 50.17886862158775, 53.73751826584339, 53.795316964387894, 54.958730936050415, 52.00627416372299, 51.936278119683266, 54.167643785476685, 53.598628118634224, 49.401358142495155, 39.81538072228432, 36.90459631383419, 38.36603209376335, 44.97383192181587, 52.94361166656017, 54.40970979630947, 52.180669605731964, 53.73173117637634, 55.34592255949974, 51.917951703071594, 50.923898443579674, 47.92921833693981, 44.36932235956192, 40.965818390250206, 49.34707045555115, 49.83879826962948, 51.38135589659214, 46.9976831227541, 49.04723234474659, 51.918886452913284, 57.86550275981426, 54.48170833289623, 38.90851378440857, 36.03377804160118, 25.180724412202835, 17.890707291662693, 16.647484302520752, 11.458123661577702, 6.518627163022757, 9.19689729809761, 12.536067869514227, 10.640801768749952, 9.357956405729055, 6.513527361676097, 2.596596130169928, 0.7263078109826893, 0.23954906151629984, 0.05937231137068011, 1.2682764697819948, 5.371904745697975, 21.009112559258938, 30.240094028413296, 38.62617373466492, 35.47543980181217, 41.98912248015404, 55.315501391887665, 54.57867152988911, 43.26923578977585, 19.261031560599804, 2.4051403161138296, 0.07510756389820017, 0.09857053300947882, 0.07513684904552065, 0.0366780847980408, 0.08423897117609158, 0.017837910891103093, 0.003452123341958213, 0.0305121753262938, 0.059232980565866455, 0.0540407558582956, 0.05676739900081884, 0.07529154230724089, 0.050112649842048995, 0.013652800989802927, 0.06679804806481116, 0.010144906409550458, 0.006111292968853377, 0.03157514787744731, 0.07197121813078411, 0.043027302890550345, 0.0612833601917373, 0.03650327562354505, 0.021961724960419815, 0.05393735984398518, 0.07944239652715623, 0.048872773404582404, 0.15848504262976348, 0.09038074043928646, 0.1487415490555577, 0.11285871631116606, 0.21016218059230596, 0.17556002014316618, 0.10967957830871455, 0.19850298122037202, 0.14424245688132942, 0.1767092803493142, 0.09336766219348647, 0.1405408320715651, 0.180319175706245, 0.11818224549642764, 0.11948308194405399, 0.24585835577454418, 0.2565090951975435, 0.057684556231833994, 0.2091656395350583, 0.13214383187005296, 0.1636526465881616, 0.09098283742787316, 0.13551350886700675, 0.14382995635969564, 0.16207690379815176, 0.1280974200926721, 0.09961585543351248, 0.07226755027659237, 1.164282700046897, 11.46439902484417, 40.238298028707504, 66.2608976662159, 54.593247547745705, 49.669152572751045, 40.50945907831192, 39.226298332214355, 42.002695351839066, 36.28212511539459, 18.36119804531336, 5.3173453733325005, 1.6877595917321742, 1.0860844398848712, 2.0991790713742375, 6.201824862509966, 8.438673634082079, 12.93723039329052, 17.307259999215603, 8.78293041139841, 9.772801995277405, 8.102908451110125, 14.085455629974604, 20.79266857355833, 35.147338807582855, 45.40573574602604, 53.154709339141846, 52.04556405544281, 53.663046061992645, 54.810664281249046, 52.40081839263439, 51.26017279922962, 47.6549718528986, 43.03177893161774, 43.47955450415611, 42.428333312273026, 49.03498940169811, 54.035654067993164, 53.56709361076355, 55.07229544222355, 51.79697759449482, 50.78710198402405, 55.002626180648804, 55.00395230948925, 51.54209107160568, 48.17356422543526, 46.483943089842796, 46.19531437754631, 39.35966357588768, 40.03842115402222, 40.027443543076515, 39.34932433068752, 40.3801292181015, 41.13256864249706, 41.9286373257637, 44.96709108352661, 48.143086060881615, 52.30004779994488, 53.6904463917017, 56.058369129896164, 38.80520112812519, 48.835986480116844, 52.3099272698164, 50.72589486837387, 54.55151438713074, 55.37885159254074, 55.13237401843071, 50.82157373428345, 52.429043278098106, 56.14558964967728, 54.81003351509571, 50.99288374185562, 40.91588146984577, 38.71558293700218, 40.11786349117756, 47.18631260097027, 56.10707871615887, 56.495987847447395, 53.78756918013096, 53.81826773285866, 56.111794263124466, 54.076429679989815, 53.70211936533451, 48.63471508026123, 46.14092789590359, 42.5264972448349, 51.21392548084259, 52.25100003182888, 54.21861805021763, 50.05674697458744, 51.69670857489109, 53.88566471636295, 60.54258070886135, 57.292786091566086, 41.685636565089226, 36.01716533303261, 25.794038102030754, 17.75640729814768, 15.466701462864876, 13.215270973742008, 16.740237325429916, 12.760943602770567, 16.02952156215906, 15.069903954863548, 19.189929775893688, 19.521976858377457, 6.116993939504027, 2.518887687474489, 0.5192912381608039, 0.24811170907923952, 2.139664711430669, 7.342839986085892, 26.023253202438354, 37.82115653157234, 45.78323408961296, 45.03625877201557, 50.988247990608215, 64.78181943297386, 64.5292241871357, 49.42745514214039, 21.286653466522694, 3.0604334408417344, 0.23908792063593864, 0.17052377632353455, 0.13583521504187956, 0.15292546595446765, 0.12818990653613582, 0.1514274557121098, 0.14700664527481422, 0.1564173004589975, 0.2253715621191077, 0.23459976771846414, 0.2145031062536873, 0.2105188716086559, 0.1823889958905056, 0.1141525171988178, 0.2462470778846182, 0.13472505117533728, 0.16443443979369476, 0.11370961830834858, 0.19022371532628313, 0.13717829453526065, 0.09696098539279774, 0.1934968537534587, 0.12774770526448265, 0.1208723675517831, 0.18801177386194468, 0.14178596291458234], [0.04117357384529896, 0.1312237320234999, 0.03434399695834145, 0.005993209852022119, 0.026404887030366808, 0.06606446477235295, 0.08309458688017912, 0.01820175992179429, 0.04826998250791803, 0.06092804957006592, 0.02333916403586045, 0.02914048047387041, 0.06475111571489833, 0.04975992560503073, 0.021041395048086997, 0.047107059363042936, 0.030983435390226077, 0.04142100959143136, 0.007572247777716257, 0.02715213326155208, 0.028828720933233853, 0.03431088975048624, 0.0463955698069185, 0.04915088582492899, 0.07893476009485312, 0.054010353778721765, 0.04296305516618304, 0.09824498250964098, 0.4258529160870239, 5.013776337727904, 26.066010408103466, 50.421060025691986, 49.771747067570686, 40.09240485727787, 32.36314840614796, 23.888744339346886, 38.93440179526806, 35.859903171658516, 17.536761984229088, 6.349771823734045, 0.5696070101112127, 0.27773995127063245, 0.7448156678583473, 1.5521540120244026, 1.942923974711448, 3.4361544298008084, 6.42818964086473, 4.32778537273407, 4.746796488761902, 3.1591115333139896, 10.000174194574356, 16.861420422792435, 28.24357096105814, 40.658449083566666, 46.74110189080238, 51.113238483667374, 52.80319020152092, 53.31778518855572, 51.004910096526146, 48.68672288954258, 44.42254610359669, 39.23400051891804, 37.87148103117943, 42.28998273611069, 46.06620490550995, 48.72540481388569, 50.429575368762016, 53.48238095641136, 49.06504958868027, 52.95370012521744, 50.049660354852676, 51.142120733857155, 50.55805027484894, 47.765580117702484, 46.91455878317356, 43.859059140086174, 40.28527490794659, 38.00956182181835, 35.12617014348507, 34.657051116228104, 37.37344175577164, 40.417374819517136, 35.25372549891472, 39.126698076725006, 41.13477252423763, 49.58270341157913, 48.231701105833054, 55.05049221217632, 29.225723259150982, 33.33178482949734, 39.61281359195709, 47.33498342335224, 54.72274459898472, 48.88550162315369, 51.77709326148033, 49.98257875442505, 44.34192202985287, 50.777005925774574, 50.18709518015385, 46.603256687521935, 40.11557221412659, 35.52469655871391, 36.92641854286194, 39.77596163749695, 46.54796965420246, 49.25504319369793, 53.10113601386547, 50.16798980534077, 51.20856776833534, 50.768756568431854, 48.30802761018276, 46.76515460014343, 44.78818528354168, 43.5657224804163, 44.61715266108513, 45.76842248439789, 48.30044321715832, 46.16156458854675, 46.76232375204563, 47.48901575803757, 48.640319779515266, 54.96693089604378, 44.905276000499725, 31.60187065601349, 24.98860862106085, 14.324708841741085, 10.468404069542885, 6.166290594264865, 5.794777404516935, 7.861373936757445, 16.14710245281458, 4.865744831040502, 6.229584747925401, 5.5409173015505075, 2.1809670701622963, 1.1320079443976283, 0.21179131348617375, 0.1692764784093015, 1.2321623764000833, 7.931246487423778, 19.457234032452106, 38.555588722229004, 47.68071927130222, 32.33387477695942, 37.83280290663242, 39.985330402851105, 38.15487362444401, 35.606547966599464, 10.538272820413113, 1.6847952757962048, 0.030793035548413172, 0.03845209976134356, 0.035256645642220974, 0.007499867042497499, 0.04349645154434256, 0.018125979222531896, 0.009430151403648779, 0.04718839132692665, 0.011334756527503487, 0.045313614973565564, 0.024981592505355366, 0.031826899212319404, 0.015305741981137544, 0.06989941641222686, 0.06133221206255257, 0.07301808422198519, 0.042848074226640165, 0.04375655575131532, 0.03828842280199751, 0.030312511626107153, 0.0584349157725228, 0.05874894071894232, 0.023990682493604254, 0.039581099335919134, 0.05610662781691644, 0.05156663588422816, 0.04445614125870634, 0.0406799120537471, 0.03588314444641583, 0.024404576397500932, 0.06697550299577415, 0.049202680311282165, 0.04701317026047036, 0.031662580295233056, 0.05833250310388394, 0.09441121088457294, 0.028305955820542295, 0.031506269151577726, 0.03051088027859805, 0.05060241535829846, 0.07063986457069404, 0.015875180761213414, 0.05975866602966562, 0.04775736255396623, 0.04269424556696322, 0.07130531870643608, 0.05131522593728732, 0.03123758200672455, 0.03247628585086204, 0.02760823495918885, 0.0367654170258902, 0.03278257390775252, 0.06375077486154623, 0.08224534729379229, 0.4807452455861494, 6.524647939950228, 30.627597235143185, 56.634733602404594, 55.089649111032486, 46.13898999989033, 37.37343415617943, 28.303250558674335, 39.07581880688667, 37.79344081878662, 20.606567859649658, 6.844450179487467, 0.8966318308375776, 0.14161114260787144, 0.48749261477496475, 1.4767425460740924, 3.752475343644619, 7.094690501689911, 6.090669427067041, 7.212921632453799, 6.801593704149127, 6.233229702338576, 11.507650204002857, 17.695709355175495, 29.561288952827454, 43.2108823210001, 48.3855776488781, 52.09643192589283, 51.967352852225304, 55.11912792921066, 52.90121354162693, 51.37054167687893, 45.00648736953735, 41.89032778143883, 39.56364423036575, 43.3979082852602, 47.0492235571146, 51.06351435184479, 51.4488060772419, 55.46992130577564, 49.30495731532574, 52.44668573141098, 51.79007336497307, 53.923921063542366, 52.01368756592274, 48.85554023087025, 47.2960165143013, 45.19993498921394, 39.56220790743828, 39.20990601181984, 37.092131450772285, 36.94269686937332, 37.98386760056019, 41.40584997832775, 38.415710628032684, 41.18450805544853, 44.58824001252651, 51.36547274887562, 49.37244929373264, 55.58776818215847, 33.121861293911934, 37.812652587890625, 40.53308241069317, 49.65108074247837, 55.60190722346306, 49.32142183184624, 52.48130947351456, 49.8823781311512, 45.31528539955616, 51.698323488235474, 52.50645272433758, 48.875485360622406, 41.626082360744476, 37.90440246462822, 37.743492498993874, 42.92470447719097, 49.510647878050804, 51.62263534963131, 54.29698504507542, 52.69508980214596, 52.5737851113081, 52.56857939064503, 50.19395761191845, 49.65841434895992, 46.12714223563671, 44.859397262334824, 46.81551709771156, 49.15437899529934, 50.641740784049034, 49.355901181697845, 49.69124458730221, 49.46941249072552, 51.393724232912064, 57.028137892484665, 44.261202961206436, 33.72700162231922, 23.334376886487007, 18.45648743212223, 16.114152520895004, 9.94215415790677, 5.091055165976286, 12.282822858542204, 9.320153184235096, 6.867171535268426, 10.530636180192232, 4.936824766919017, 3.3161487942561507, 1.0234997794032097, 0.3015309199690819, 0.1439068280160427, 1.7224899656139314, 8.422820884734392, 22.811281755566597, 35.715624913573265, 46.49802513420582, 37.9182793200016, 44.602375254034996, 50.71649797260761, 46.93034313619137, 42.64624021947384, 13.56668371707201, 2.1278399834409356, 0.04929358598019462, 0.03540559468092397, 0.03554114424332511, 0.08012547667021863, 0.04013169869722333, 0.09361689022625796, 0.039046274323482066, 0.028929252257512417, 0.032323937775800005, 0.02847200394171523, 0.05472287492011674, 0.023476236856367905, 0.05370074090023991, 0.028406854507920798, 0.024213705291913357, 0.014192134549375623, 0.0335648754844442, 0.03769766211917158, 0.07144265313399956, 0.030276736397354398, 0.03905163634044584, 0.04395021918753628, 0.021635706907545682, 0.12916755251353607, 0.05010706518078223, 0.030342889585881494, 0.1156600566173438, 0.1590243910322897, 0.09033866808749735, 0.1253919949522242, 0.191351720422972, 0.32938669086433947, 0.1792694820323959, 0.14493621652945876, 0.16867910890141502, 0.18592774897115305, 0.12931834207847714, 0.10552309860941023, 0.07933678891276941, 0.13888976129237562, 0.1763721226598136, 0.14173855452099815, 0.18742991524050012, 0.074174120236421, 0.06199655668751802, 0.1150687578774523, 0.14305136923212558, 0.15653292706701905, 0.10481006538611837, 0.17529256496345624, 0.11913828013348393, 0.24593911628471687, 0.14888494682963938, 0.17197844514157623, 0.6240612349938601, 7.96560044400394, 37.0169410854578, 63.97845134139061, 65.20042777061462, 52.033298313617706, 45.12664832174778, 33.94483633339405, 50.69379799067974, 45.10592043399811, 22.487829811871052, 8.676636815071106, 1.4891248941421509, 0.7713118242099881, 1.5952638862654567, 4.792679976671934, 7.712134569883347, 8.77056397497654, 15.227557495236397, 12.00395867228508, 11.906928978860378, 6.666388884186745, 15.57865770533681, 21.290265172719955, 30.43186593800783, 44.13159191608429, 48.651122599840164, 53.53191129863262, 53.40675741434097, 56.12524174153805, 55.59238873422146, 53.68300639092922, 48.446708768606186, 42.62127935886383, 40.351387560367584, 46.26623377203941, 49.23406071960926, 52.99382597208023, 55.27700185775757, 56.5350079536438, 49.91751864552498, 51.564517468214035, 52.494555562734604, 55.86889989674091, 54.95146192610264, 52.18312427401543, 50.39312392473221, 46.795925348997116, 42.07960322499275, 42.85793825984001, 38.38698796927929, 39.12406861782074, 41.296666637063026, 42.85113662481308, 40.393458902835846, 43.04204598069191, 45.20648963749409, 54.35182370245457, 52.572975754737854, 56.78764879703522, 38.08767803013325, 40.62266640365124, 47.199224308133125, 52.1931367367506, 53.45476023852825, 50.09026877582073, 52.240277007222176, 51.24908119440079, 45.77921390533447, 53.17952960729599, 53.96356053650379, 50.6475430727005, 42.411165833473206, 39.37495015561581, 40.04605494439602, 44.99364025890827, 50.167226046323776, 54.183576330542564, 58.49309228360653, 55.26076152920723, 53.948410749435425, 55.52679285407066, 53.07551018893719, 51.67567290365696, 49.47369486093521, 47.44854412972927, 50.54633930325508, 51.01388521492481, 53.19066300988197, 51.101835295557976, 52.88744308054447, 52.19393089413643, 54.027670696377754, 57.421215400099754, 47.119671776890755, 33.908403888344765, 25.898735783994198, 16.34477734565735, 13.57153795659542, 12.306189704686403, 13.55560066178441, 15.523300375789404, 25.95401331782341, 15.917924400418997, 13.175887987017632, 17.697423063218594, 7.528858529403806, 3.627360644750297, 0.6866482109762728, 0.6613831885624677, 1.9207427836954594, 10.486472100019455, 27.41833694279194, 50.64924918115139, 58.08782882988453, 44.912700802087784, 52.429256066679955, 56.70495383441448, 54.85164888203144, 48.29581506550312, 16.046212166547775, 2.689449372701347, 0.10950161129585467, 0.18421706889057532, 0.10142472907318734, 0.22222708241315559, 0.08678761761984788, 0.18642345909029245, 0.08697881712578237, 0.15134651708649471, 0.09938665796653368, 0.22871360153658316, 0.16061171132605523, 0.1116762227320578, 0.10312330472515896, 0.178863913170062, 0.20308206207118928, 0.11364774545654655, 0.09836640529101714, 0.09043163692695089, 0.17238313826965168, 0.14845205208985135, 0.15238878928357735, 0.2328565964126028, 0.07491053111152723, 0.14450256479904056, 0.12200924873468466, 0.12044947696267627], [0.06396388256689534, 0.04283132395357825, 0.03314545814646408, 0.0903406718862243, 0.044703153980663046, 0.05537553442991339, 0.04389417219499592, 0.039108711207518354, 0.050375225400784984, 0.0488059133203933, 0.009428744106116937, 0.031150706199696288, 0.0337477740686154, 0.01322882129898062, 0.036198037705617025, 0.011769597549573518, 0.019185307828593068, 0.04665338077757042, 0.04549019045953173, 0.021278620697557926, 0.01799807378120022, 0.03274119917477947, 0.024163795860658865, 0.01546939945910708, 0.05675066728144884, 0.0415650344802998, 0.017169608763651922, 0.10347890478442423, 0.1735869760159403, 2.329517723992467, 15.808577667921782, 39.88287650048733, 49.11183647811413, 51.565984189510345, 30.420599542558193, 29.24752838909626, 33.90424691140652, 30.613748878240585, 21.150548569858074, 9.298356603831053, 2.4462277488783, 0.2913960919249803, 0.5022799666039646, 0.7788869552314281, 3.180128918029368, 5.3467106726020575, 2.765141073614359, 3.9763533929362893, 3.872923655435443, 2.5693200062960386, 9.882596153765917, 15.653140358626842, 25.941852070391178, 43.128821924328804, 46.20852246880531, 52.49002620577812, 51.537128537893295, 52.00231097638607, 50.968344658613205, 48.97130101919174, 46.05849511921406, 41.049964874982834, 40.512935891747475, 45.18809862434864, 45.93672685325146, 49.168001264333725, 51.09554283320904, 50.51637411117554, 51.300359442830086, 48.3017997443676, 48.33053760230541, 50.90725153684616, 49.409170523285866, 51.417051181197166, 46.57108761370182, 49.78137195110321, 44.21633116900921, 41.00463330745697, 35.675012692809105, 37.08389349281788, 39.64072309434414, 42.86833070218563, 37.36527979373932, 38.99582929909229, 41.29010058939457, 48.80008600652218, 46.035897731781006, 56.7416712641716, 36.02469652891159, 31.276277527213097, 49.5447738468647, 44.292175099253654, 47.79087156057358, 49.87300023436546, 49.527978748083115, 51.97127424180508, 52.12478220462799, 52.356539368629456, 50.63565731048584, 46.387770250439644, 40.266621708869934, 35.3501833230257, 37.09671400487423, 38.520406410098076, 44.121461659669876, 47.89864897727966, 51.3736879080534, 51.68701149523258, 50.644442439079285, 51.39093138277531, 51.4355143904686, 48.647376000881195, 46.949839890003204, 44.97615359723568, 44.382944628596306, 46.844220757484436, 44.20444540679455, 44.19255204498768, 46.16304650902748, 47.11894601583481, 51.168027743697166, 54.20552395284176, 40.18468290567398, 33.43639701604843, 21.41969572752714, 15.19184036180377, 13.987793270498514, 6.982093993574381, 2.6528200507164, 8.85722877457738, 6.326454849913716, 6.585487425327301, 10.26560040190816, 2.5650599598884583, 2.4168968852609396, 0.6041782081592828, 0.40236943401396275, 0.4386386362602934, 2.364315544255078, 6.1851641815155745, 23.204845637083054, 36.36154465377331, 41.06490187346935, 38.63489046692848, 49.93119031190872, 40.005978494882584, 38.17665785551071, 27.73784849792719, 8.610320873558521, 0.6835624203085899, 0.0402089006092865, 0.03651408500445541, 0.025660173378128093, 0.03313222936412785, 0.03448327581281774, 0.07925132318632677, 0.029820489980920684, 0.06006992276525125, 0.060127272226964124, 0.04742199715110473, 0.04331945674493909, 0.039977116757654585, 0.025975022108468693, 0.020686364587163553, 0.017170115279441234, 0.04632788222806994, 0.026486762617423665, 0.04644167944206856, 0.03888453808031045, 0.03662489136331715, 0.001607417420927959, 0.05528114066692069, 0.056493579904781654, 0.08390128656174056, 0.058940054877894, 0.03227312663511839, 0.011643411107797874, 0.013155487831681967, 0.032595912634860724, 0.0422500404965831, 0.019261925299360882, 0.018195843149442226, 0.043541370032471605, 0.03161411063047126, 0.07369942773948424, 0.01613500851817662, 0.03725962800672278, 0.041562481492292136, 0.032811154014780186, 0.025028010131791234, 0.07805551547789946, 0.045696514935116284, 0.03313574714411516, 0.034424839104758576, 0.011485749255371047, 0.04695671879744623, 0.009572764356562402, 0.05571947534917854, 0.026258203397446778, 0.024893184163374826, 0.03295227710623294, 0.02318597362318542, 0.07357624606811441, 0.0648142427962739, 0.2425241534365341, 3.2313838927075267, 22.055773995816708, 44.976149797439575, 54.15078029036522, 57.245706617832184, 36.35213255882263, 36.056865602731705, 42.09727607667446, 39.662568122148514, 22.9023951664567, 9.869782291352749, 2.1346128825098276, 0.26499501953367144, 0.5496859853155911, 1.309682847931981, 3.8979104021564126, 8.426518086344004, 7.07679963670671, 8.794683180749416, 6.815833915024996, 6.694694040343165, 11.14668857306242, 17.024598866701126, 28.04157380014658, 43.282953053712845, 48.48352499306202, 54.12286698818207, 52.306108474731445, 51.38452872633934, 52.44462624192238, 51.73778437077999, 47.28825733065605, 42.57941700518131, 41.77765242755413, 46.19515098631382, 48.64024378359318, 52.57210560142994, 51.639840826392174, 50.97011536359787, 50.900548696517944, 49.43190090358257, 48.84073622524738, 51.58306047320366, 49.92112845182419, 53.73071663081646, 50.46574182808399, 51.67305864393711, 45.31610235571861, 43.39618317782879, 37.499845772981644, 38.0801772326231, 41.50721713900566, 45.573865324258804, 39.724842980504036, 41.69339954853058, 42.67048291862011, 51.39687806367874, 49.66179616749287, 55.69545820355415, 37.38376200199127, 35.015314891934395, 51.9470277428627, 45.61311721801758, 49.278613328933716, 50.49045950174332, 50.288070961833, 53.45817245543003, 52.241211757063866, 52.90199629962444, 52.617087587714195, 49.03324529528618, 42.79469445347786, 37.28248983621597, 37.43739612400532, 39.81833316385746, 45.69621115922928, 50.819426849484444, 54.154910668730736, 52.73991979658604, 52.20996603369713, 53.221038579940796, 54.073325246572495, 50.20039066672325, 49.63814623653889, 47.1348025649786, 47.38019339740276, 47.84453608095646, 46.86608478426933, 47.28067293763161, 47.69084192812443, 49.56929013133049, 54.02164041996002, 56.04546122252941, 42.0666079223156, 34.95198369026184, 20.15169806778431, 16.24306060373783, 16.022379845380783, 6.1953794583678246, 5.801118314266205, 10.851900391280651, 10.848687663674355, 9.829346761107445, 11.674768086522818, 4.9948733020573854, 1.5987803600728512, 0.6090189109090716, 0.4263150366023183, 0.44443920312915, 2.2477430244907737, 7.999884579330683, 25.08577700704336, 42.49796077609062, 46.984653621912, 41.32788956165314, 53.94562549889088, 46.386132538318634, 44.03712898492813, 34.29538272321224, 10.43373093008995, 0.9704309364315122, 0.007030952165223425, 0.034278361417818815, 0.0036994370975662605, 0.01801800786779495, 0.024502547312295064, 0.032893925745156594, 0.011769659704441437, 0.043545982480281964, 0.0769831937213894, 0.03138676853268407, 0.014832769411441404, 0.0342906254081754, 0.03171378848492168, 0.020852447960351128, 0.03543167003954295, 0.03224480999051593, 0.06857702799607068, 0.02640853839693591, 0.03096226562774973, 0.06320613494608551, 0.05289912864100188, 0.07452705598552711, 0.025246505829272792, 0.08768584637437016, 0.05360791677958332, 0.008146145937644178, 0.1524245904874988, 0.13747329823672771, 0.09538165060803294, 0.18177832709625363, 0.13114960631355643, 0.12187633008579724, 0.17429381230613217, 0.15321156388381496, 0.12787755142198876, 0.08905189533834346, 0.12901164212962613, 0.14599155052565038, 0.09184144291793928, 0.17021351406583562, 0.23200845520477742, 0.10035295650595799, 0.16506752144778147, 0.08726259213290177, 0.08799888426437974, 0.08315959901665337, 0.09663832926889881, 0.10611469420837238, 0.06791037158109248, 0.1536698400741443, 0.17609070026082918, 0.148102841922082, 0.1371134159853682, 0.20421674649696797, 0.31943262030836195, 4.243146339431405, 24.385959059000015, 51.93720147013664, 59.786064103245735, 65.16223981976509, 41.70373499393463, 40.85041478276253, 45.72422705590725, 42.14967906475067, 26.911841221153736, 12.600304372608662, 3.3294628048315644, 0.8193721203133464, 1.1221358366310596, 2.7592608891427517, 8.337447065860033, 14.619873203337193, 10.954160504043102, 14.106459952890873, 12.571780253201723, 7.685017324984074, 13.084123861044645, 17.244842648506165, 29.537449032068253, 45.81853039562702, 50.81112429499626, 55.14294885098934, 54.83747184276581, 52.93970927596092, 54.572067484259605, 53.4689486771822, 49.490695148706436, 44.148482009768486, 45.45125350356102, 48.34110863506794, 50.87558023631573, 54.53392893075943, 55.4378966242075, 52.19203479588032, 51.55230492353439, 50.87769292294979, 49.161792397499084, 51.13249585032463, 51.846982911229134, 54.71873961389065, 52.344326823949814, 54.90081064403057, 47.55596436560154, 44.016929268836975, 40.0601901859045, 40.15373736619949, 43.88737142086029, 48.090656474232674, 41.88532344996929, 42.061622589826584, 45.071213096380234, 51.80654168128967, 51.383597776293755, 56.31802819669247, 40.977745950222015, 39.319587126374245, 50.950044840574265, 48.27766343951225, 48.47315154969692, 51.91575922071934, 49.94765482842922, 53.618489652872086, 51.949577406048775, 55.44496424496174, 53.79742585122585, 52.02647387981415, 43.837613090872765, 38.107790350914, 40.0981729477644, 43.219994232058525, 47.23618872463703, 52.05774240195751, 56.08719818294048, 53.81773576140404, 53.08065131306648, 52.93657444417477, 55.27322106063366, 54.13419418036938, 51.60988323390484, 51.1544206738472, 48.64076815545559, 51.771059185266495, 49.06258352100849, 48.87961953878403, 49.66052323579788, 52.860836908221245, 56.45668275654316, 59.316675290465355, 45.13167545199394, 36.023028418421745, 24.41456202417612, 18.106965087354183, 21.173341646790504, 13.045245297253132, 6.4114235155284405, 19.792649634182453, 15.415581855922937, 18.150126971304417, 22.130624279379845, 8.814265429973602, 6.979002859443426, 1.6527234530076385, 0.7828719913959503, 0.9340863616671413, 3.5230799904093146, 9.257106017321348, 30.237428471446037, 50.28785437345505, 51.012498289346695, 53.53268265724182, 62.71490894258022, 52.60978437960148, 53.7188308686018, 38.7413227558136, 13.132807798683643, 1.1957215005531907, 0.1391781895654276, 0.13493181351805106, 0.07772990560624748, 0.1681132212979719, 0.09179674336337484, 0.15384124650154263, 0.11305982348858379, 0.2168640709714964, 0.1346849009860307, 0.1280093123205006, 0.1157379375945311, 0.18233075214084238, 0.07842487495508976, 0.140031288319733, 0.2287854117457755, 0.1105493308568839, 0.1366305598639883, 0.07377857778919861, 0.17318292113486677, 0.249065354000777, 0.09758602958754636, 0.1916219957638532, 0.18779059901135042, 0.17917049437528476, 0.09513387718470767, 0.25303798145614564], [0.05840423909830861, 0.03705078393977601, 0.004768205590153229, 0.030113115099084098, 0.07858538665459491, 0.06402674247510731, 0.009992094492190517, 0.018028570484602824, 0.004709184440798708, 0.09241400985047221, 0.034314830554649234, 0.022604220757784788, 0.0445437926100567, 0.05104541814944241, 0.06857175132608972, 0.06744164595147595, 0.010448285247548483, 0.14621309645008296, 0.059652475829352625, 0.04760194198752288, 0.08819109309115447, 0.014429983602894936, 0.05854240102053154, 0.06663389984169044, 0.021919198043178767, 0.0706884084502235, 0.0588482734747231, 0.08076464393525384, 0.10804628196638077, 1.20934899430722, 9.47020998224616, 38.87268930673599, 49.092377722263336, 43.34037557244301, 35.5745954811573, 24.281506463885307, 28.47470685839653, 28.68489257991314, 22.014656402170658, 11.63378443568945, 2.532110740430653, 0.6667140650097281, 0.39526645734440535, 0.8102194801904261, 2.2982810251414776, 8.192323353141546, 3.5482382029294968, 6.068455344066024, 5.509734274819493, 9.401912447065115, 5.37503007799387, 14.569600000977516, 23.392454870045185, 35.59478759765625, 44.74567696452141, 52.55026437342167, 52.28873200714588, 51.92442275583744, 52.09748446941376, 49.76152181625366, 45.29685638844967, 41.87672071158886, 41.11128218472004, 44.606251046061516, 50.034506767988205, 48.091085851192474, 49.43116374313831, 47.867171466350555, 43.24182786047459, 50.5469586700201, 48.385497853159904, 50.30064828693867, 47.966368943452835, 51.031972244381905, 48.02992433309555, 50.42819604277611, 46.02471113204956, 46.520455330610275, 41.484718546271324, 40.597435757517815, 36.426266580820084, 38.46898376941681, 37.435412630438805, 40.72942927479744, 40.605506524443626, 47.15265020728111, 47.03422576189041, 57.5116391479969, 38.312139585614204, 38.90574753284454, 53.859442323446274, 47.097583562135696, 50.4055492579937, 49.28097680211067, 50.853659212589264, 50.18404774367809, 47.43477366864681, 51.7057178914547, 49.738894030451775, 48.45755338668823, 38.51158328354359, 34.31141026318073, 37.688707038760185, 36.42744451761246, 40.49318455159664, 46.3754703104496, 49.71502751111984, 49.54008109867573, 53.57908196747303, 51.12257458269596, 50.66766299307346, 51.627639681100845, 46.72815978527069, 45.67390255630016, 45.12360468506813, 45.828972235322, 43.829922303557396, 44.51625667512417, 45.05973771214485, 48.031539246439934, 49.88282650709152, 51.35044075548649, 41.437547877430916, 33.76628391444683, 16.917047537863255, 16.482875235378742, 16.327161490917206, 4.1925981268286705, 3.5819704178720713, 8.708392661064863, 8.283603955060244, 4.374166633933783, 12.196981664747, 4.103288669139147, 1.3979486678726971, 0.4656640626490116, 0.05948625701421406, 0.5953006376512349, 2.4645235296338797, 11.55551528558135, 23.111043870449066, 28.540458530187607, 36.990103125572205, 55.43794982135296, 42.78036542236805, 42.995889857411385, 46.840618550777435, 25.22219728678465, 7.992253638803959, 0.14241723372833803, 0.03219482263375539, 0.07631052591023035, 0.019433294619375374, 0.09771912635187618, 0.0430487138510216, 0.02953424547740724, 0.05916632086155005, 0.011612024754867889, 0.06624552654102445, 0.04177642040303908, 0.03641744995547924, 0.09596696763765067, 0.0261659080570098, 0.03457056722254492, 0.0181818610872142, 0.08350161035195924, 0.05539291181776207, 0.02727454495470738, 0.07173024278017692, 0.07388420766801573, 0.05946246747043915, 0.034642945174709894, 0.03455058489635121, 0.03563416874385439, 0.0822486424294766, 0.0709476183692459, 0.048905732182902284, 0.02658004501427058, 0.022576564624614548, 0.01949809524376178, 0.05762150336522609, 0.022486994821520057, 0.018015109781117644, 0.04488149206736125, 0.028416493150871247, 0.018870548155973665, 0.008316619114339119, 0.07580871533718891, 0.055290955569944344, 0.03206656838301569, 0.029413481352094095, 0.017376901741954498, 0.0757511320989579, 0.0791150945588015, 0.049710320454323664, 0.028271394003240857, 0.023205686920846347, 0.022380598675226793, 0.002853135256373207, 0.038679393619531766, 0.03584397018130403, 0.020853499954682775, 0.04106028129172046, 0.054319361806847155, 0.15267460519680753, 1.6220940090715885, 12.47853135690093, 43.95067222416401, 55.432690903544426, 50.585093423724174, 38.156834319233894, 29.72780741751194, 33.070248663425446, 34.625212624669075, 26.815780475735664, 15.206224489957094, 2.811930337920785, 0.7046479044947773, 0.2512819116236642, 0.617568630259484, 2.07075540907681, 3.84212345816195, 6.040809452533722, 6.846125889569521, 6.3438184931874275, 8.154801316559315, 9.381001219153404, 14.711888115853071, 24.208865761756897, 39.092507511377335, 46.834170296788216, 53.89225356280804, 54.283974543213844, 53.42096485197544, 54.97776411473751, 51.0364256054163, 47.65318974852562, 42.99433954060078, 44.87407207489014, 47.636284455657005, 52.74703301489353, 49.73701313138008, 52.54549562931061, 48.61844815313816, 47.73874595761299, 50.64092002809048, 47.82331421971321, 51.32468953728676, 48.50339412689209, 51.12309895455837, 50.70168636739254, 52.27551631629467, 48.676900416612625, 48.59552018344402, 43.07508520781994, 41.20635308325291, 39.153794422745705, 39.39708396792412, 39.31636109948158, 42.906640246510506, 43.67384187877178, 49.20452490448952, 48.927097991108894, 58.39562751352787, 41.01042799651623, 42.22235396504402, 54.581962153315544, 47.907456904649734, 50.92787683010101, 50.23354388773441, 52.185765132308006, 50.179282799363136, 47.374679893255234, 52.861505672335625, 52.000513672828674, 50.079731941223145, 40.282288268208504, 36.585964411497116, 39.56492476165295, 38.667238131165504, 43.196773678064346, 49.247964173555374, 51.35341219604015, 51.98486231267452, 53.61838325858116, 50.95035262405872, 54.06705178320408, 54.046578481793404, 49.634661823511124, 47.51903034746647, 47.93595917522907, 47.126815393567085, 45.16954801976681, 46.94187931716442, 49.018209502100945, 49.863371551036835, 53.347925171256065, 54.20239292085171, 42.93239526450634, 34.85965244472027, 19.07185111194849, 14.702044744044542, 10.894989129155874, 4.302907157689333, 7.689672550186515, 11.162990648299456, 6.822336316108704, 8.691695407032967, 7.868842910975218, 5.287365457043052, 2.5217952439561486, 0.19464290788164362, 0.3163964347913861, 0.507824047235772, 2.641525869257748, 11.073106471449137, 27.674961872398853, 35.74184350669384, 40.373167991638184, 58.8807512819767, 49.87197428941727, 50.14707952737808, 52.28149339556694, 29.4092059135437, 9.370139501988888, 0.2507953596068546, 0.03073017007409362, 0.07520839208154939, 0.07758634455967695, 0.0400781007920159, 0.032371435227105394, 0.02105514704453526, 0.014824171630607452, 0.03246751366532408, 0.07558183337096125, 0.044985329659539275, 0.03499849699437618, 0.054947567550698295, 0.08144508203258738, 0.054848450017743744, 0.015674966016376857, 0.037535098381340504, 0.05561204947298393, 0.01817721153202001, 0.03121113928500563, 0.08089329523500055, 0.06253731888136826, 0.06569632983882912, 0.03943746036384255, 0.04602185763360467, 0.04938600191962905, 0.07771397911710665, 0.1319624509778805, 0.14540421485435218, 0.10589432829874568, 0.09729572368087247, 0.25816904206294566, 0.1990457286592573, 0.09274226918932982, 0.12743358383886516, 0.12288233352592215, 0.16146301408298314, 0.12235948306624778, 0.1679660237277858, 0.20465890323976055, 0.14690170559333637, 0.15973704576026648, 0.1470182227785699, 0.1233516974025406, 0.1878866329207085, 0.16913070576265454, 0.16491604910697788, 0.1639493423863314, 0.12115847290260717, 0.08999936559121124, 0.14485143357887864, 0.14107909693848342, 0.13498272484866902, 0.16194006660953164, 0.19638239813502878, 0.2617299556732178, 1.869445180054754, 16.2590691447258, 49.862839579582214, 63.03858697414398, 56.057058200240135, 46.94216810166836, 33.93659457564354, 37.95221909880638, 40.518475994467735, 30.02941433340311, 16.607491448521614, 3.4935748111456633, 1.0200430336408317, 0.8000246272422373, 2.7165195951238275, 5.4996538907289505, 16.04022178798914, 11.313283033668995, 14.64966170489788, 10.205444879829884, 17.182981967926025, 9.583449605852365, 17.309627272188663, 26.68209034949541, 39.40188691020012, 48.37122581899166, 58.43088962137699, 55.66652275621891, 56.424513682723045, 57.02406831085682, 55.76815590262413, 49.71305161714554, 44.91572543978691, 46.09901234507561, 50.53091213107109, 54.55364987254143, 53.19877937436104, 53.77229019999504, 52.62311026453972, 47.700375616550446, 50.66917531192303, 48.02627272903919, 51.238266974687576, 49.37871515750885, 52.30103574693203, 52.37173095345497, 54.65003550052643, 48.859294429421425, 51.422401294112206, 46.51128642261028, 43.41324046254158, 40.176463946700096, 41.57526768743992, 40.517507046461105, 44.634050354361534, 44.55760985612869, 50.59125669300556, 51.37626796960831, 60.24856008589268, 42.27559290826321, 44.47569765150547, 52.68590189516544, 49.8094866424799, 51.49320289492607, 50.93213640153408, 54.015401154756546, 52.2930371761322, 49.26914803683758, 54.87458825111389, 53.48343349993229, 52.279901280999184, 43.27120788395405, 39.254055842757225, 41.370017901062965, 41.49728067219257, 44.156902357935905, 53.602120131254196, 53.89658913016319, 54.993373677134514, 55.70401534438133, 52.00577639043331, 54.22635443508625, 57.23539397120476, 52.18659728765488, 49.95625376701355, 50.77953279018402, 49.980200082063675, 48.29977445304394, 48.44267338514328, 50.22458016872406, 52.995030507445335, 55.343817472457886, 56.881150379776955, 45.97811043262482, 38.15624535083771, 20.155999436974525, 23.11468407511711, 22.683922089636326, 10.324494391679764, 11.742062475532293, 17.626944445073605, 17.46768359094858, 13.492136467248201, 17.68791027367115, 11.857260894030333, 6.271278960630298, 2.9578030854463577, 0.6089648231863976, 1.081422446295619, 3.312137397006154, 15.561650767922401, 31.64167732000351, 39.876853823661804, 50.24914965033531, 66.31996169686317, 53.81316460669041, 59.15579192340374, 58.52155275642872, 33.44046659767628, 10.779500026255846, 0.5769834236707538, 0.1386577807716094, 0.16671272926032543, 0.24203910055803135, 0.18146013870136812, 0.15033537056297064, 0.17441374337067828, 0.203211284824647, 0.21877882682019845, 0.1537595211993903, 0.2441356677445583, 0.16430232266429812, 0.13871954230125993, 0.17316537676379085, 0.15735368302557617, 0.09812312928261235, 0.20505559601588175, 0.17807585623813793, 0.13584796513896435, 0.12608229619218037, 0.17063420789781958, 0.12282828291063197, 0.21399813413154334, 0.09550572285661474, 0.1355079427594319, 0.19104285340290517, 0.20119764521950856], [0.02371691349253524, 0.09319008109741844, 0.04349047354480717, 0.030534801553585567, 0.05406565120210871, 0.07057054797769524, 0.026690877348301, 0.023148957152443472, 0.038506302516907454, 0.10959476567222737, 0.030927249244996347, 0.06607519622775726, 0.06023624177032616, 0.006508843389383401, 0.03482632615487091, 0.06100039783632383, 0.048901141999522224, 0.08122713552438654, 0.03158969397190958, 0.1629108699853532, 0.04838490036490839, 0.08182732519344427, 0.030615523101005238, 0.026971633669745643, 0.03945418466173578, 0.03061808351048967, 0.030841800216876436, 0.03018699775566347, 0.13335225608898327, 0.6637837097514421, 7.507318435236812, 30.65926853567362, 48.25776770710945, 54.24357511103153, 38.72560299932957, 29.649066142737865, 25.551567412912846, 26.147498935461044, 20.833436585962772, 13.17998606711626, 5.179171012714505, 0.7541764655616134, 0.3306033677654341, 0.3675361390924081, 2.1458474546670914, 2.2907035192474723, 5.409603947773576, 6.225499017164111, 4.978612549602985, 5.294753210619092, 9.318320732563734, 10.35400265827775, 19.063168577849865, 31.782522462308407, 42.76661776006222, 51.45731762051582, 51.69950142502785, 50.9587387740612, 51.0482581704855, 45.616913214325905, 44.62173521518707, 43.98738965392113, 44.875588193535805, 48.99783119559288, 49.27754558622837, 52.21607230603695, 48.1416991353035, 50.74091926217079, 45.78079082071781, 49.64815489947796, 48.784373849630356, 51.16392396390438, 49.19700510799885, 48.69901143014431, 49.448923990130424, 50.77930860221386, 48.236572444438934, 48.301537558436394, 47.34641321003437, 47.22477413713932, 44.85255382955074, 45.66366970539093, 41.8526566028595, 39.10454146564007, 37.78480768203735, 48.23880672454834, 46.884232610464096, 57.34840750694275, 37.422953099012375, 38.979623168706894, 48.73882569372654, 50.09923629462719, 52.96282343566418, 49.795241206884384, 51.931870356202126, 52.16678515076637, 53.09906892478466, 49.428857266902924, 48.21520619094372, 45.06591998040676, 36.257232651114464, 35.04993863403797, 34.98567648231983, 36.88473477959633, 38.841572776436806, 44.637694358825684, 47.52175100147724, 50.6827025860548, 51.79923087358475, 51.860943362116814, 51.579576060175896, 52.06697590649128, 49.80103589594364, 46.69727124273777, 43.74771751463413, 45.08059859275818, 43.35845500230789, 45.00771850347519, 46.25151336193085, 47.75353856384754, 49.46720860898495, 50.53217366337776, 42.06522099673748, 32.797575294971466, 19.249767065048218, 11.120071951299906, 5.967998709529638, 2.9379831114783883, 7.47756983153522, 7.692146692425013, 5.771553525701165, 9.125229343771935, 7.197589930146933, 4.526639152318239, 0.8170873741619289, 0.26145521260332316, 0.2724868815857917, 0.44732452486641705, 3.677853047847748, 10.964059922844172, 27.485496439039707, 39.146301224827766, 42.92863726615906, 49.62748780846596, 33.50684143602848, 49.116669818758965, 36.30730256438255, 22.03254584223032, 4.61532449349761, 0.0944099566549994, 0.04020213593321387, 0.04848306794883683, 0.04660095917643048, 0.023454877846234012, 0.0778122765768785, 0.03004100432008272, 0.021275177132338285, 0.037324851655284874, 0.03639198315795511, 0.019354012838448398, 0.034202528768219054, 0.01403738655426423, 0.03150368276692461, 0.022231944640225265, 0.014383091001946013, 0.0677185486711096, 0.09420490125194192, 0.04907044072751887, 0.036691781133413315, 0.022025045000191312, 0.04290284101443831, 0.023686080967308953, 0.03728213363501709, 0.06394946263753809, 0.03969105222495273, 0.03791054718021769, 0.04960710255545564, 0.02598027651401935, 0.035988317904411815, 0.05059090835857205, 0.02510387061192887, 0.04033316952700261, 0.047087321945582516, 0.04516673281614203, 0.04122622551221866, 0.06350630399538204, 0.035613462823675945, 0.04892744371318258, 0.02898086120694643, 0.02306505550222937, 0.038608106624451466, 0.0557928960188292, 0.10680065388442017, 0.01953179616975831, 0.008629682051832788, 0.017410717700840905, 0.04691611589805689, 0.03351392333570402, 0.12151553499279544, 0.021512243220058735, 0.021779190028610174, 0.044840584887424484, 0.03867547507979907, 0.0447333297051955, 0.06494391083833762, 0.9890276135411114, 9.66959573328495, 36.24284662306309, 53.90524506568909, 58.39432418346405, 43.88387940824032, 32.593640238046646, 32.13967479765415, 29.197743460536003, 23.91045067459345, 14.786920789629221, 5.350044518709183, 0.8983647159766406, 0.2314054750604555, 0.32602556340862066, 1.8787470809184015, 3.6090879002586007, 7.76502488180995, 8.085973709821701, 6.855039736256003, 5.607404708862305, 7.045692130923271, 12.777846995741129, 26.29743129014969, 34.906667321920395, 44.50655199587345, 54.41451273858547, 54.83175314962864, 53.113907128572464, 52.74598427116871, 48.61359961330891, 46.38731427490711, 45.34216895699501, 46.03592813014984, 49.32506203651428, 50.82455277442932, 53.70907299220562, 49.33855891227722, 52.967170402407646, 46.79645732045174, 51.18036948144436, 49.36164267361164, 49.27981026470661, 49.687794372439384, 48.83797377347946, 50.644742622971535, 52.13323675096035, 51.14630050957203, 51.388647705316544, 48.91851045191288, 47.80296631157398, 45.63377670943737, 46.40941768884659, 42.68612287938595, 39.76851783692837, 40.28720140457153, 50.814015939831734, 49.513315334916115, 58.18263754248619, 39.226898699998856, 40.62920585274696, 49.85694229602814, 49.39943164587021, 53.28321844339371, 51.63838930428028, 54.412799030542374, 52.6152028888464, 55.607477724552155, 52.951709032058716, 50.42236715555191, 48.13684679567814, 38.65566395223141, 36.689980030059814, 37.36683391034603, 38.02885718643665, 41.913016363978386, 45.94861641526222, 50.110327899456024, 51.58274509012699, 53.936593383550644, 51.882169023156166, 53.89502741396427, 53.72194670140743, 53.06221090257168, 48.432858511805534, 46.74045592546463, 44.81510303914547, 46.18314363062382, 46.610761284828186, 47.708100602030754, 50.36715991795063, 53.332349807024, 53.29306371510029, 44.653379917144775, 32.32285916805267, 22.38364700227976, 11.676621437072754, 9.80537574738264, 5.1843558344990015, 8.277792166918516, 10.460627786815166, 11.36816443875432, 9.563174843788147, 8.389683812856674, 6.658506207168102, 2.208365499973297, 0.5466463265474886, 0.16643337003188208, 0.7109186367597431, 3.717534081079066, 12.965878956019878, 29.20331586152315, 40.86346708238125, 45.01892030239105, 54.761707708239555, 40.50673462450504, 55.80413997173309, 43.953096494078636, 25.98942741751671, 5.9753679390996695, 0.18090801051585004, 0.02350444960029563, 0.03542081612977199, 0.041457074257778004, 0.03140717759379186, 0.06018117070198059, 0.013553218686865875, 0.032256138874799944, 0.04480729956412688, 0.07249502596096136, 0.02408001666481141, 0.07656731642782688, 0.03997274179710075, 0.030449675359704997, 0.05328990278940182, 0.040082520281430334, 0.017540081462357193, 0.05203850450925529, 0.009007773824123433, 0.024067010526778176, 0.0601877646840876, 0.06426110528991558, 0.09453342034248635, 0.03813290204561781, 0.06520392969832756, 0.029959156563563738, 0.023530319012934342, 0.11942420736886561, 0.14563751639798284, 0.1659737282898277, 0.12606589472852647, 0.16110093507450074, 0.11843493935884908, 0.12455618823878467, 0.1885586031130515, 0.12058272215654142, 0.1960006373701617, 0.1249096731771715, 0.23420264449669048, 0.14302336057880893, 0.07698658533627167, 0.06726770137902349, 0.20393379527376965, 0.1665985127328895, 0.13020782091189176, 0.10521811302169226, 0.1559867212199606, 0.13079546828521416, 0.18465881003066897, 0.28373947308864444, 0.1161411390057765, 0.10020697605796158, 0.137016209482681, 0.06882722824229859, 0.10087529488373548, 0.21759651135653257, 1.1338185472413898, 11.296181101351976, 39.216943234205246, 59.89736773073673, 65.37668511271477, 49.2913768440485, 41.470013335347176, 35.17768777906895, 36.930719912052155, 29.024303667247295, 18.83225116878748, 7.346195206046104, 1.1971156694926322, 0.7439836312551051, 1.1424882570281625, 4.925474775955081, 5.813075322657824, 11.42467500641942, 15.400227829813957, 14.200496356934309, 10.368617624044418, 12.270004246383905, 12.851516492664814, 21.476234793663025, 36.073227524757385, 46.402923837304115, 55.053117871284485, 55.7402577996254, 54.54023279249668, 55.53965136408806, 50.303570330142975, 49.39465530216694, 48.4600954502821, 49.4841481000185, 53.48191738128662, 52.412491366267204, 54.90978956222534, 51.72989219427109, 53.20986717939377, 48.99620868265629, 50.38447178900242, 49.74405035376549, 49.519885182380676, 50.333394929766655, 49.2281786352396, 51.48107774555683, 54.70105916261673, 53.214932307600975, 54.02979098260403, 51.873019114136696, 50.978197529911995, 48.464750200510025, 49.940180629491806, 46.41976833343506, 41.58118776977062, 42.052301689982414, 53.01877163350582, 52.50283531844616, 60.11642597615719, 42.231883853673935, 43.65426912903786, 49.14453752338886, 50.43723575770855, 56.08190506696701, 53.64337831735611, 57.436300590634346, 55.31958617269993, 56.56446777284145, 54.134817346930504, 52.62912914156914, 49.78797599673271, 39.63575676083565, 38.79006654024124, 39.23908084630966, 39.905606880784035, 43.27409952878952, 48.68823900818825, 51.94038189947605, 53.32745186984539, 55.33284746110439, 53.25204871594906, 54.7085827589035, 55.84210753440857, 55.738908872008324, 50.583284720778465, 48.88573341071606, 47.85042196512222, 48.037010952830315, 50.52267797291279, 50.6819274276495, 53.50107975304127, 56.83801129460335, 55.68319246172905, 47.85933628678322, 37.029514610767365, 23.286336064338684, 14.27333939820528, 11.446668226271868, 8.668591696768999, 14.326278157532215, 18.225843608379364, 14.885326009243727, 20.051563940942287, 20.488981269299984, 10.77515210956335, 3.784096771851182, 1.0559879173524678, 0.6687891692854464, 1.09027347760275, 5.132731329649687, 14.874592535197735, 35.75220175087452, 51.25378534197807, 55.905123353004456, 60.71120046079159, 46.85630030930042, 65.37793904542923, 50.46536564826965, 30.043344385921955, 6.453698147088289, 0.28870827052742243, 0.14619224210036919, 0.11566591216251254, 0.1279444040847011, 0.09763373484020121, 0.1648671564180404, 0.08572621285566129, 0.15302678395528346, 0.10255239278194495, 0.12049035445670597, 0.08648864342831075, 0.1368141226703301, 0.15421790129039437, 0.09310524619650096, 0.11320437901304103, 0.10597617976600304, 0.1811756586539559, 0.10119980637682602, 0.09252136893337592, 0.16116980637889355, 0.18287259415956214, 0.11133977750432678, 0.1401139932568185, 0.18216897879028693, 0.16230128472670913, 0.25411192851606756, 0.10236101516056806], [0.11188294796738774, 0.04323075154388789, 0.016840759417391382, 0.03196487559762318, 0.0840511781279929, 0.04572629361064173, 0.03020547537744278, 0.008416127202508505, 0.0566851430630777, 0.06220383111212868, 0.04826040138141252, 0.0566300571517786, 0.07860288649681024, 0.05041096723289229, 0.07467636867659166, 0.02733869248913834, 0.04144668047956657, 0.02346438846871024, 0.03452276549069211, 0.037011899112258106, 0.03675536463561002, 0.024990012170746922, 0.07489268245990388, 0.10318700326024555, 0.03345975768752396, 0.018598758833832107, 0.04973441798938438, 0.02528083758079447, 0.05680606860551052, 0.18148695991840214, 3.7742265639826655, 20.38177952170372, 46.27442613244057, 50.28588987886906, 37.91789934039116, 22.35976718366146, 20.74198879301548, 24.57346759736538, 25.708067715168, 18.265247493982315, 5.566842360422015, 1.6690890560857952, 0.14012044994160533, 0.22031856060493737, 0.8724095555953681, 1.8665322801098228, 6.247348794713616, 4.404472857713699, 5.134804593399167, 4.528406532481313, 4.508352633565664, 5.750204371288419, 17.559824846684933, 26.677285507321358, 37.72606283426285, 45.329679027199745, 52.40549974143505, 50.697001218795776, 49.22275632619858, 47.17853061854839, 46.52872748672962, 47.8653247654438, 47.841298654675484, 49.22072343528271, 51.110863611102104, 53.9894675463438, 49.86885465681553, 48.488529324531555, 53.22053320705891, 50.738700181245804, 51.18194259703159, 50.98973371088505, 50.57077959179878, 49.1761290282011, 48.73043194413185, 51.05363868176937, 50.2921899408102, 50.146661549806595, 49.93626683950424, 48.46273630857468, 50.298657193779945, 49.93852771818638, 47.5080793350935, 43.821517154574394, 36.83354392647743, 46.50252029299736, 46.74089290201664, 56.43334820866585, 38.853663727641106, 38.66202101111412, 50.395711585879326, 49.80405293405056, 50.06515592336655, 47.04249791800976, 50.13488598167896, 50.469594821333885, 51.916606575250626, 48.2144196331501, 48.12798947095871, 39.27979566156864, 37.57940210402012, 35.15366546809673, 37.06422194838524, 37.19874992966652, 39.59556631743908, 42.99079433083534, 48.51048454642296, 47.40938723087311, 52.93470114469528, 51.05205036699772, 50.68474307656288, 52.64448031783104, 51.224382519721985, 47.78564304113388, 46.24926008284092, 44.835576340556145, 44.12204682826996, 44.996600300073624, 48.50587919354439, 47.25361458957195, 47.83172316849232, 49.87051896750927, 45.313841477036476, 31.015613414347172, 25.019915141165257, 8.954383861273527, 6.720726918429136, 2.576062506996095, 5.6115103885531425, 9.359153341501951, 5.569390598684549, 6.395519468933344, 3.2692115753889084, 5.529331723228097, 2.210505260154605, 0.12227179831825197, 0.10446983520523645, 0.38553832622710615, 4.668494090437889, 13.85002501308918, 29.892912358045578, 39.220313653349876, 50.976799204945564, 40.7181590795517, 36.825210973620415, 45.28340511023998, 39.01884846389294, 20.615370087325573, 2.7993912482634187, 0.07508462411351502, 0.038269145516096614, 0.08606981238699518, 0.044618426691158675, 0.03337835893034935, 0.01187882498925319, 0.06703322724206373, 0.07291800560778938, 0.006483468432634254, 0.030403803211811464, 0.024855241863406263, 0.004008495916423271, 0.04254327417584136, 0.018889966449933127, 0.0251774304342689, 0.020792675386474002, 0.06782040843972936, 0.028648978332057595, 0.033626629592617974, 0.044019279739586636, 0.028510662414191756, 0.02238439476059284, 0.053323084212024696, 0.05050534615293145, 0.05457900959299877, 0.024397186462010723, 0.01698683077847818, 0.007654859482499887, 0.025425804997212254, 0.035815939263557084, 0.03154421145154629, 0.05709037424821872, 0.036087710032006726, 0.057401816520723514, 0.04854918588534929, 0.0506381275044987, 0.03149213865981437, 0.010797121558425715, 0.018678573105717078, 0.048171618254855275, 0.05529739741177764, 0.03709941687702667, 0.06006680203427095, 0.050303548778174445, 0.019769455975620076, 0.07902005512733012, 0.04864772825385444, 0.019593520592025016, 0.039088424600777216, 0.0856204419687856, 0.08872338366927579, 0.08939128689235076, 0.02209823560406221, 0.05638987218844704, 0.022665559263259638, 0.14412224380066618, 0.17523280723253265, 5.087130451574922, 25.644738413393497, 54.27781127393246, 55.32644100487232, 45.36896891891956, 28.14440008252859, 22.328513860702515, 27.646127119660378, 28.928636200726032, 18.000318109989166, 6.0350774601101875, 1.548238203395158, 0.3133694815915078, 0.23670439462875947, 1.3590500364080071, 3.22702101431787, 5.9274164121598005, 5.911355149000883, 7.331826752051711, 8.3125289529562, 6.0233911871910095, 8.79734018817544, 19.154048301279545, 29.03625402599573, 39.98179279267788, 49.471958354115486, 53.720669969916344, 53.672009781003, 51.03207863867283, 49.5088429749012, 47.63650864362717, 48.028222024440765, 50.40028274059296, 51.20326705276966, 53.85981850326061, 54.53603781759739, 49.60769847035408, 49.56898234784603, 52.629151940345764, 50.68058229982853, 52.37891636788845, 50.83591416478157, 50.7326965034008, 50.42943857610226, 48.48460033535957, 51.511255726218224, 52.732312604784966, 53.26976716518402, 52.590109035372734, 49.39063511788845, 51.72541983425617, 52.26600542664528, 49.96165327727795, 45.67621283233166, 39.51512463390827, 47.83981293439865, 48.47653716802597, 57.9922791570425, 41.97455786168575, 42.16441087424755, 53.32378886640072, 52.270367592573166, 51.89273625612259, 50.707359462976456, 52.388412058353424, 51.77943013608456, 53.52608621120453, 49.94859717786312, 49.69352066516876, 41.087028086185455, 39.19735908508301, 37.74035386741161, 38.77019360661507, 38.484072759747505, 40.04231974482536, 45.171459317207336, 50.36263436079025, 50.12680761516094, 55.65890796482563, 52.42559306323528, 52.47638113796711, 53.72382000088692, 53.23516622185707, 48.854552283883095, 48.27284149825573, 46.93974383175373, 47.02028051018715, 47.929537519812584, 50.67343108355999, 50.482730716466904, 52.095801159739494, 51.81118503212929, 48.07634264230728, 31.664079017937183, 26.012043803930283, 12.137084528803825, 8.855223432183266, 8.372489735484123, 10.093022212386131, 7.378091169521213, 9.808984603732824, 6.2337331753224134, 5.697209564968944, 6.059219464659691, 2.0428748801350594, 0.49530493619386107, 0.1961223199032247, 0.4028539377031848, 4.895802643150091, 13.967877589166164, 33.74940522015095, 43.48827123641968, 52.667681872844696, 47.683337330818176, 42.20234423875809, 54.23815280199051, 45.57852767407894, 23.337625712156296, 3.452807036228478, 0.14077040803385898, 0.03224506974220276, 0.03523968014633283, 0.017899214144563302, 0.025230527389794588, 0.010793753135658335, 0.07818058220436797, 0.04251607446349226, 0.05282800491841044, 0.02306697209860431, 0.07692938059335575, 0.027658400431391783, 0.030424872784351464, 0.02123592308635125, 0.05346057077986188, 0.030232894023356494, 0.026147812641283963, 0.09890029890812002, 0.011775777784350794, 0.05565786224906333, 0.04028852563351393, 0.044415215525077656, 0.07625584446941502, 0.01585421137860976, 0.008734075327083701, 0.0352303253748687, 0.055763870623195544, 0.22552312351763248, 0.17266812297748402, 0.15466390235815197, 0.08627661925856955, 0.12625508301425725, 0.1675795577466488, 0.09711760823847726, 0.1406508480431512, 0.15072085690917447, 0.1559392237686552, 0.2200866542989388, 0.15537148079602048, 0.14509528846247122, 0.19299173320177943, 0.13240598811535165, 0.20344981108792126, 0.08556672531994991, 0.07540853446698748, 0.15998891583876684, 0.10626054849126376, 0.12028729543089867, 0.200960113434121, 0.16027489502448589, 0.2284512820187956, 0.12504698534030467, 0.10803014767589048, 0.11263007545494474, 0.1315499801421538, 0.3035220131278038, 0.5100012710317969, 5.588888777419925, 29.70626637339592, 59.73768889904022, 62.631062641739845, 51.47234961390495, 33.52118946611881, 31.478635668754578, 36.07180640101433, 35.648797899484634, 24.433669298887253, 8.751582093536854, 3.028302127495408, 0.5939429823774844, 0.8770048152655363, 3.001574124209583, 7.9667893052101135, 14.42968675866723, 13.607798460870981, 12.932941373437643, 12.570541519671679, 8.81229618564248, 8.408055827021599, 20.577332228422165, 30.122843720018864, 41.12689554691315, 52.2198037058115, 58.12458425760269, 56.16887480020523, 53.85453298687935, 52.235542461276054, 50.74702933430672, 50.96365191042423, 52.00764209032059, 53.5163739323616, 57.661845088005066, 55.914805233478546, 50.724458545446396, 48.65660570561886, 53.96368972957134, 53.85193392634392, 53.477521017193794, 53.245836049318314, 51.671998500823975, 50.51802322268486, 48.606326803565025, 52.34179615974426, 54.55787144601345, 54.52999994158745, 55.542307421565056, 51.89372420310974, 54.923590421676636, 54.5545694231987, 53.04812505841255, 48.17275486886501, 41.31310075521469, 49.78793039917946, 50.79969070851803, 59.33896489441395, 45.102367624640465, 44.94901165366173, 52.72228114306927, 52.92343094944954, 53.93464408814907, 52.449767366051674, 54.343813732266426, 54.407483115792274, 56.1275178194046, 53.32225754857063, 52.70436130464077, 42.824317663908005, 42.140430361032486, 39.30905029177666, 40.52827946841717, 40.78268721699715, 42.02877715229988, 47.70611710846424, 54.93780165910721, 52.57469706237316, 58.018459752202034, 53.506642654538155, 52.887693867087364, 53.585997596383095, 58.05917076766491, 51.185981780290604, 49.92374651134014, 49.14967484772205, 48.22493366897106, 49.946970865130424, 52.502702325582504, 52.38694913685322, 53.93016792833805, 55.46496257185936, 50.1433215290308, 36.235813200473785, 29.853954948484898, 12.876561898738146, 12.685658242553473, 9.224991090595722, 13.311822842806578, 21.065965108573437, 14.05116531997919, 12.3639409057796, 11.353253088891506, 8.893570024520159, 6.1866451520472765, 1.3047732738777995, 0.3315219091018662, 0.7850343722384423, 6.540623232722282, 18.625793047249317, 39.82420764863491, 51.56032629311085, 62.1936871111393, 52.02707424759865, 50.599243864417076, 61.92170910537243, 51.536767557263374, 26.949288211762905, 4.243410900235176, 0.1919907541014254, 0.18595090397866443, 0.14452279574470595, 0.20703629910713062, 0.11531285766977817, 0.12735280848573893, 0.10822472395375371, 0.20439741492737085, 0.12834084453061223, 0.08352725155418739, 0.09641949960496277, 0.10327950454666279, 0.09157566499197856, 0.10233810506178997, 0.15589533315505832, 0.13011643284698948, 0.20886699930997565, 0.20601899275789037, 0.08801961987046525, 0.17726241785567254, 0.14512513764202595, 0.13065719133010134, 0.23134392133215442, 0.1705475102062337, 0.15901673206826672, 0.27761999052017927, 0.10473787668161094], [0.031236873255693354, 0.09412327985046431, 0.05979434848995879, 0.017720209980325308, 0.030796733299212065, 0.03246485677664168, 0.05411927508248482, 0.03547593914845493, 0.05432591868157033, 0.013366814382607117, 0.07028385633020662, 0.02168570354115218, 0.05113355931825936, 0.039777141355443746, 0.026582141581457108, 0.051205243362346664, 0.03814240524661727, 0.03508022229652852, 0.04425607308803592, 0.005413921844592551, 0.0947634044860024, 0.06808551101130433, 0.09975768727599643, 0.033508119740872644, 0.1280745619442314, 0.09598252305295318, 0.042219742317683995, 0.09523179614916444, 0.03107208864093991, 0.033100547079811804, 1.909420459996909, 11.149750258773565, 31.760441847145557, 53.0184980481863, 42.54403330385685, 24.58778902888298, 21.878310218453407, 25.26253592222929, 26.83485545217991, 17.406580969691277, 7.528699412941933, 2.5308544328436255, 0.4517965583363548, 0.3321364667499438, 0.5395415390376002, 1.504071510862559, 4.617174994200468, 3.3525396790355444, 4.377668621018529, 5.506189065054059, 3.4844161150977015, 8.590787071734667, 17.0937779545784, 21.333871632814407, 31.117670238018036, 44.12247620522976, 49.3368224054575, 51.83637008070946, 47.84552022814751, 48.45204748213291, 46.657255589962006, 49.24139812588692, 49.31389443576336, 51.266134679317474, 53.58304135501385, 50.24292938411236, 48.86893071234226, 53.26371029019356, 49.982464760541916, 51.62332311272621, 49.513642117381096, 52.64673359692097, 52.62366883456707, 52.57991038262844, 49.30078513920307, 51.27726808190346, 50.313225612044334, 52.748587131500244, 52.51597501337528, 53.14943142235279, 50.99150821566582, 55.6893215328455, 48.72033968567848, 45.01619204878807, 36.952158361673355, 46.53787359595299, 45.111190751194954, 54.79714460670948, 40.44631406664848, 37.355518117547035, 53.09935010969639, 46.28064639866352, 49.7512661665678, 45.04689060151577, 46.81360960006714, 45.24129956960678, 44.97207261621952, 42.38122344017029, 38.01836974918842, 35.871032774448395, 37.44718819856644, 36.052279248833656, 37.202887907624245, 37.38211669027805, 39.64835308492184, 44.6609491109848, 47.172640934586525, 48.80934990942478, 53.832456171512604, 53.10172498226166, 50.779365599155426, 52.26496808230877, 51.37423127889633, 48.11965651810169, 50.0976137816906, 46.20911903679371, 47.55306512117386, 47.2547697275877, 50.51646150648594, 46.087365970015526, 51.64645627140999, 47.70347245037556, 46.318218782544136, 28.59919387847185, 23.860610648989677, 13.899734895676374, 9.674749206751585, 7.362064579501748, 9.188881628215313, 3.799744094721973, 13.90711884945631, 4.769452773034573, 3.628377802670002, 5.682257367298007, 1.2735561677254736, 0.5474437493830919, 0.0818123783392366, 1.0343724209815264, 4.336060853675008, 13.055568393319845, 27.523156218230724, 34.4562166929245, 44.5381511002779, 42.619474455714226, 41.46218195557594, 52.34927035868168, 35.982381999492645, 13.141329791396856, 2.0391558296978474, 0.02390585872490192, 0.0886239878309425, 0.04461536904273089, 0.02264421695144847, 0.04908682734821923, 0.017275704340136144, 0.033932631922652945, 0.03875353046169039, 0.019128273779642768, 0.004742234132208978, 0.029342878988245502, 0.04909722112643067, 0.010422580035083229, 0.03294867026852444, 0.05506546513061039, 0.05848054672242142, 0.06538675777846947, 0.03512859177135397, 0.05661228271492291, 0.03855222661513835, 0.06553158789756708, 0.09488498311839066, 0.041620754927862436, 0.06957349483855069, 0.018047840349026956, 0.04945735570800025, 0.09303380706114694, 0.0524713139020605, 0.04576297797029838, 0.007990483245521318, 0.06416533855372109, 0.020762245476362295, 0.0377824450697517, 0.005718404627259588, 0.011788931424234761, 0.12496215786086395, 0.017641655504121445, 0.033910059501067735, 0.053792589096701704, 0.023870910990808625, 0.02224485986516811, 0.04766290199768264, 0.06456202390836552, 0.0175664833659539, 0.030667493847431615, 0.031585140895913355, 0.024479724415868986, 0.05142550537129864, 0.033939804779947735, 0.07286414795089513, 0.033442179919802584, 0.046614748280262575, 0.04969631612766534, 0.06363747117575258, 0.011640098346106242, 0.05336459253157955, 0.03995281884272117, 2.804568470455706, 14.761128723621368, 39.482275396585464, 58.10379937291145, 45.34864000976086, 28.853890411555767, 27.043082378804684, 31.486073769629, 32.01876908540726, 20.552437864243984, 8.51944399997592, 2.8747461922466755, 0.5075253476388752, 0.22592818771954626, 1.2111405981704593, 4.0130482614040375, 4.112906428053975, 6.9382106233388186, 7.474684836342931, 7.881750343367457, 5.724140619859099, 6.069592433050275, 14.350302368402481, 22.239013463258743, 37.47641623020172, 45.28216637670994, 52.416959926486015, 53.627871349453926, 50.84501467645168, 49.91609372198582, 49.38091143965721, 50.64729988574982, 50.63467316329479, 53.37191328406334, 55.372946709394455, 51.401836797595024, 50.228486359119415, 52.0779687166214, 50.58515802025795, 52.8240966796875, 51.66637860238552, 52.80605524778366, 53.34711581468582, 51.49763345718384, 49.57227677106857, 51.79994523525238, 50.47806076705456, 54.19382818043232, 52.81854897737503, 53.48705470561981, 52.9888254404068, 55.43156996369362, 50.888218358159065, 47.39954575896263, 40.052457600831985, 47.8242451697588, 47.66702480614185, 55.570133328437805, 42.52137131989002, 40.79930752515793, 53.76301869750023, 50.07199175655842, 51.10966667532921, 47.65489965677261, 49.837817922234535, 47.877229526638985, 50.03057777881622, 45.66955178976059, 41.00128188729286, 37.688106670975685, 37.81723894178867, 37.878613248467445, 38.42475414276123, 38.7498115003109, 41.72303795814514, 46.519493982195854, 49.96695019304752, 50.12618824839592, 53.98300029337406, 53.78780476748943, 51.4264252781868, 52.659113332629204, 53.062533885240555, 49.28848139941692, 52.215426340699196, 48.65281730890274, 48.55531074106693, 49.33774955570698, 52.11765378713608, 50.317154601216316, 53.83192799985409, 50.34774295985699, 48.33975590765476, 30.999264791607857, 21.719047464430332, 13.722235970199108, 7.330983197316527, 7.027186648920178, 10.803915616124868, 7.330105919390917, 9.104690495878458, 6.402256032451987, 5.265463432297111, 4.673330755904317, 1.8367239483632147, 0.5226383835542947, 0.05843484526849352, 0.9092458477243781, 5.247205886989832, 16.181530505418777, 33.56172189116478, 38.91333572566509, 52.955189645290375, 47.63940788805485, 46.41027644276619, 56.37111134827137, 42.57217079401016, 17.219279520213604, 2.6287796907126904, 0.04637927595467772, 0.020791886854567565, 0.033815109127317555, 0.03766494082810823, 0.00827802094136132, 0.02044750435743481, 0.019645990432763938, 0.033278744158451445, 0.02637488014443079, 0.029991593983140774, 0.01913346324727172, 0.03272901310992893, 0.060777660764870234, 0.03435847997025121, 0.09673065986135043, 0.013548117349273525, 0.12375122518278658, 0.028070659755030647, 0.030227429961087182, 0.015912722301436588, 0.10048116993857548, 0.008116744829749223, 0.030402012780541554, 0.028485390430432744, 0.04668581263103988, 0.05007594692870043, 0.00906041528651258, 0.23567795986309648, 0.18317807698622346, 0.179094439081382, 0.134351750893984, 0.14938408567104489, 0.13461746944813058, 0.13228138152044266, 0.11670538646285422, 0.24663404852617532, 0.08879382090526633, 0.11394992572604679, 0.07888036067015491, 0.17535998165840283, 0.11810630152467638, 0.1427143154432997, 0.15050239831907675, 0.13749439007369801, 0.17886326008010656, 0.3064972534775734, 0.13041692844126374, 0.18239494791487232, 0.22683758579660207, 0.16714128985768184, 0.14734444121131673, 0.22791358118411154, 0.24653869739267975, 0.1594639354152605, 0.2388530902680941, 0.10439334204420447, 0.17450652667321265, 3.1438287533819675, 17.792919538915157, 43.16292129456997, 64.87968698143959, 54.99066062271595, 37.679222747683525, 33.8196824491024, 36.41717366874218, 37.86947853863239, 24.39916905015707, 11.156765632331371, 3.5259144008159637, 0.7598134037107229, 0.6255334778688848, 2.5927870720624924, 6.522910483181477, 12.899412922561169, 15.683658421039581, 13.35016943514347, 9.782601669430733, 5.979368174448609, 11.547047439962626, 19.55886907875538, 25.759988129138947, 39.87799376249313, 48.44263918697834, 54.007083401083946, 56.40331842005253, 51.77648149430752, 52.45626501739025, 52.083144038915634, 54.21401269733906, 53.22870656847954, 56.985922157764435, 54.83002424240112, 51.342856362462044, 50.489908531308174, 55.13996221125126, 53.641368225216866, 55.54618701338768, 53.81937727332115, 55.199907794594765, 54.35256466269493, 53.31621967256069, 50.14613337814808, 51.76709219813347, 50.69026418030262, 55.18703028559685, 56.38267792761326, 56.61029331386089, 55.488669499754906, 58.74883376061916, 52.09865860641003, 49.09043602645397, 41.99649788439274, 50.740132704377174, 50.90619519352913, 56.913855224847794, 46.67228378355503, 41.751939207315445, 56.020511761307716, 52.38752290606499, 53.057730942964554, 49.411685988307, 50.53977705538273, 49.3559467792511, 50.86264953017235, 47.050941064953804, 41.79320499300957, 39.54005889594555, 39.38783906400204, 39.59807798266411, 40.349449664354324, 41.43646113574505, 43.868003860116005, 49.068306013941765, 51.97792388498783, 53.84124889969826, 57.31127209961414, 54.659105613827705, 52.004074081778526, 53.153010830283165, 55.94068184494972, 53.020257353782654, 56.133650690317154, 51.043953001499176, 52.594482600688934, 51.80580832064152, 56.06159135699272, 50.56091912090778, 57.11617536842823, 54.023950695991516, 52.16922461986542, 33.72371479868889, 28.26664712280035, 18.61750189214945, 15.100246276706457, 15.745903830975294, 18.265897259116173, 11.351797766983509, 22.433781512081623, 12.462552264332771, 11.84867050498724, 15.037505943328142, 3.6043668910861015, 1.4360899524763227, 0.3369675512658432, 1.6990318056195974, 6.066829031333327, 19.218498542904854, 35.847443640232086, 46.799029782414436, 56.64677515625954, 55.1832190901041, 54.59398850798607, 66.18294104933739, 49.10867504775524, 19.737195409834385, 3.1764880008995533, 0.14454330870648846, 0.22276807838352397, 0.155376453185454, 0.13681406329851598, 0.15000471408711746, 0.08688077199622057, 0.17478072055382654, 0.09714851126773283, 0.1353282984928228, 0.07434195693349466, 0.14960085216443986, 0.13551105977967381, 0.12997144687687978, 0.08796742462436669, 0.22558592405403033, 0.20555374037940055, 0.16929828270804137, 0.17789180361432955, 0.17683507438050583, 0.2918910450534895, 0.19226997974328697, 0.17063324310583994, 0.20288289932068437, 0.13005933200474828, 0.07645804260391742, 0.1571408350719139, 0.184355063829571], [0.033226367086172104, 0.04230967577314004, 0.04295957820431795, 0.04047632981382776, 0.03354465196025558, 0.05956182620138861, 0.025513276377751026, 0.10674917852156796, 0.06211306645127479, 0.03234207957575563, 0.055296543941949494, 0.08159804609022103, 0.03421868532313965, 0.05640395072987303, 0.0314867766428506, 0.06543829251313582, 0.038487036363221705, 0.038667905173497275, 0.03213022238924168, 0.04965405823895708, 0.09169216733425856, 0.03286989500338677, 0.005036905722590745, 0.0235715601593256, 0.053759288930450566, 0.025905599759425968, 0.06302537745796144, 0.009266869637940545, 0.056748592978692614, 0.05665424374456052, 0.3442231728695333, 6.150724729523063, 25.653569139540195, 46.04270696640015, 47.92182773351669, 32.75154836475849, 20.577235333621502, 23.53007398545742, 26.30235582590103, 23.627620451152325, 10.48195794224739, 3.6635548900812864, 1.0066779633052647, 0.34423513629008085, 1.0166422161273658, 3.8063937379047275, 2.1088044298812747, 6.031853333115578, 6.639300612732768, 9.882305469363928, 4.678251491859555, 1.7111772601492703, 4.7789608128368855, 14.24650713801384, 26.049699783325195, 39.80452090501785, 47.27095685899258, 51.88141666352749, 52.11134232580662, 49.37505975365639, 51.5476805716753, 51.68046064674854, 51.38694919645786, 53.15364919602871, 51.63355216383934, 49.830412119627, 48.82611840963364, 50.67703329026699, 48.83683383464813, 47.26235792040825, 46.717546954751015, 48.849072977900505, 50.814840495586395, 51.61382742226124, 49.59282226860523, 48.742329105734825, 50.184461921453476, 51.431680396199226, 51.63514047861099, 54.34367313981056, 52.7637293189764, 52.34300069510937, 47.8543471544981, 44.381717294454575, 38.59140560030937, 44.987967163324356, 47.32461757957935, 54.53360974788666, 42.38941200077534, 41.61382041871548, 53.989725932478905, 47.10596211254597, 47.12965004146099, 41.35629303753376, 39.734540060162544, 38.22751812636852, 39.45464327931404, 36.7582281678915, 37.52593897283077, 36.40505991876125, 37.56120108067989, 38.03947001695633, 38.415573835372925, 40.47914810478687, 45.15831962227821, 47.95960150659084, 47.8174739331007, 48.959050476551056, 51.95465013384819, 51.74418702721596, 48.57163846492767, 52.80286341905594, 52.1923653781414, 52.621734738349915, 51.1816918104887, 48.80846455693245, 50.96932880580425, 50.05710795521736, 50.78439652919769, 50.255738496780396, 50.80426566302776, 46.50544993579388, 42.36045755445957, 27.244207486510277, 16.97864033281803, 13.924057390540838, 4.564255233854055, 7.152864430099726, 8.243077229708433, 4.881382416933775, 5.327743515372276, 4.838164485991001, 3.7643276201561093, 4.663268895819783, 0.6410844996571541, 0.3672141954302788, 0.0721029048145283, 0.9895105438772589, 6.272075492888689, 16.94951679557562, 25.432365909218788, 38.166698589921, 49.85137939453125, 39.55583184957504, 39.96878609061241, 49.259473755955696, 35.43582692742348, 11.395730059593916, 1.6940582287497818, 0.059012633209931664, 0.04432341185747646, 0.024481182736053597, 0.0838158282567747, 0.04404252380481921, 0.0794375799887348, 0.024617717499495484, 0.03009845211636275, 0.040553910221206024, 0.026725804673333187, 0.09451025791349821, 0.05975124455289915, 0.05046868034696672, 0.016189597190532368, 0.03530169400619343, 0.039264013030333444, 0.018472038973413873, 0.018231738977192435, 0.024823811909300275, 0.026715351523307618, 0.027206070699321572, 0.03473438147921115, 0.006541493712575175, 0.03530385365593247, 0.06091038274462335, 0.041878706906572916, 0.04777069152623881, 0.040126934109139256, 0.020929724087181967, 0.02240873349364847, 0.016517583790118806, 0.05966408672975376, 0.027645793197734747, 0.04432265857758466, 0.01952226142748259, 0.027784793746832293, 0.04878704421571456, 0.06076987192500383, 0.012683070945058716, 0.001202280859615712, 0.017151415013358928, 0.06496133646578528, 0.02308911964064464, 0.08764133977820165, 0.08618393985670991, 0.05525320622837171, 0.05673570929502603, 0.01836011382692959, 0.08075253208517097, 0.02376101376285078, 0.02173703418520745, 0.013192762198741548, 0.021398073076852597, 0.09997749657486565, 0.007279323945112992, 0.04315186495659873, 0.05459585263452027, 0.7077076903078705, 7.90708833374083, 30.441186837852, 55.4680822044611, 51.11778683960438, 38.472487181425095, 23.164824284613132, 30.07560085505247, 30.740377083420753, 26.086261421442032, 11.336596682667732, 3.966020797379315, 0.526245814980939, 0.3114138334058225, 0.34092643414624035, 1.8839713255874813, 3.3317234460264444, 9.885761383920908, 9.239118732511997, 7.027741419151425, 8.95017558708787, 4.59023111499846, 8.347797710448503, 18.633253946900368, 30.1121548935771, 41.71173736453056, 51.49829462170601, 54.25868310034275, 54.463849291205406, 51.99741683900356, 53.30582343041897, 53.92510659992695, 54.26484256982803, 53.93219321966171, 52.349122166633606, 49.42405052483082, 49.49213907122612, 53.342179879546165, 51.23862035572529, 48.60142506659031, 49.7559779137373, 52.06009827554226, 52.9406364262104, 52.6380168646574, 49.7605262696743, 48.36672306060791, 49.613774344325066, 51.2898264080286, 53.03465098142624, 54.467405900359154, 54.87003609538078, 53.65892328321934, 50.05683436989784, 46.2998353689909, 40.026835575699806, 47.72972524166107, 48.17256487905979, 55.834549739956856, 44.15735073387623, 43.85276287794113, 55.45259803533554, 48.981207087635994, 49.930369555950165, 43.59970025718212, 42.99814313650131, 40.476921424269676, 41.21674172580242, 38.980979695916176, 39.13751609623432, 38.67563188076019, 38.99499714374542, 40.323424860835075, 39.173002392053604, 41.36154815554619, 47.453856244683266, 49.605103209614754, 49.55148808658123, 51.775140166282654, 52.987579107284546, 50.06175510585308, 48.89282763004303, 53.57085160911083, 53.91195930540562, 53.297623470425606, 51.93555235862732, 50.822918862104416, 53.210129365324974, 52.93328382074833, 53.562355265021324, 53.003048077225685, 52.54323095083237, 50.61129681766033, 43.49074870347977, 30.327168256044388, 21.803444735705853, 13.389488775283098, 5.442472184076905, 6.4390969555824995, 9.708281457424164, 9.636102430522442, 9.785248227417469, 7.0127250999212265, 7.628295868635178, 3.903880356810987, 1.5684028901159763, 0.4142394330119714, 0.09673393273260444, 0.8260480652097613, 7.020409237593412, 16.660299114882946, 29.82744377106428, 39.362403228878975, 51.793261393904686, 44.87171620130539, 44.940416514873505, 57.008371353149414, 39.97072398662567, 12.947247605770826, 2.1646198723465204, 0.0671544051147066, 0.0229236040104297, 0.040100149999489076, 0.017422029886802193, 0.03819229612417985, 0.04867869436566252, 0.06313430247246288, 0.02245369651063811, 0.04258499029674567, 0.022329258754325565, 0.014134899192868033, 0.03209142290870659, 0.118611347861588, 0.044662517684628256, 0.004919746115774615, 0.0322249204327818, 0.07116250722901896, 0.051583059612312354, 0.06757015624316409, 0.025248609817936085, 0.006535011980304262, 0.05115159721754026, 0.05149106669705361, 0.03757189406314865, 0.09389038648805581, 0.027797974289569538, 0.005900800406379858, 0.17792634316720068, 0.10145750973606482, 0.08959911050624214, 0.11514609708683565, 0.10853096377104521, 0.07532135437941179, 0.1355402113404125, 0.150240435032174, 0.22357385780196637, 0.16094247170258313, 0.13690368505194783, 0.16795049799839035, 0.11393060762202367, 0.11873947223648429, 0.0917674953234382, 0.20567095518345013, 0.15747131343232468, 0.16196034208405763, 0.13862358260666952, 0.12273072759853676, 0.17874751472845674, 0.11424728203564882, 0.1074415206676349, 0.11042754442314617, 0.1031612730002962, 0.08552972925826907, 0.19685474544530734, 0.09799939100048505, 0.16874115244718269, 0.23270568810403347, 0.8342457097023726, 10.086983386427164, 37.34849989414215, 60.84488108754158, 59.24111254513264, 47.20975734293461, 30.58228086680174, 34.427794218063354, 37.88832172751427, 33.152020275592804, 14.362216629087925, 4.655644604936242, 1.246450797189027, 0.6880588852800429, 1.977651498746127, 5.8115763030946255, 6.507931686937809, 8.515094183385372, 13.371052164584398, 19.14874568581581, 11.922481544315815, 5.165404351428151, 6.4744640327990055, 18.88680674135685, 30.01658622175455, 44.04256649315357, 53.314703553915024, 55.56280352175236, 56.03562355041504, 54.88521248102188, 55.64443454146385, 56.131670996546745, 55.89506909251213, 55.75114041566849, 52.31330148875713, 50.44213369488716, 49.798516631126404, 54.97448489069939, 52.44797006249428, 51.33928835391998, 51.63731776177883, 53.690461590886116, 54.56887185573578, 53.67682032287121, 50.0750657916069, 48.845326378941536, 50.131021589040756, 50.74459746479988, 54.01005484163761, 55.78751966357231, 56.36421851813793, 55.505305007100105, 53.18093553185463, 47.93285474181175, 43.2401217520237, 48.00953462719917, 51.44802711904049, 56.520306542515755, 46.10560119152069, 46.93722456693649, 56.846078261733055, 52.38078586757183, 52.01709218323231, 44.20642890036106, 44.93229255080223, 40.96123203635216, 43.02639842033386, 41.37222558259964, 40.2935166656971, 40.78635782003403, 40.486379116773605, 41.9175723195076, 42.844031006097794, 43.823884427547455, 51.098525673151016, 52.50768005847931, 51.902285143733025, 56.01402550935745, 56.48983597755432, 51.337643042206764, 51.151244044303894, 53.24091911315918, 54.92534212768078, 56.343528628349304, 55.943265706300735, 52.98395790159702, 56.76991514861584, 56.01096287369728, 55.26814453303814, 55.36276325583458, 54.52805444598198, 52.21842437982559, 44.82817813754082, 30.929103456437588, 22.286883294582367, 16.548072136938572, 8.886073026806116, 14.436174910515547, 14.359609019011259, 13.621879555284977, 15.53491635248065, 11.589553859084845, 9.924010131508112, 11.237848531454802, 5.188971161842346, 1.2766811437904835, 0.3528628108324483, 1.2723258649930358, 8.76768372952938, 23.673746176064014, 34.719899743795395, 51.106216460466385, 61.15150943398476, 49.770151153206825, 55.21364405751228, 62.06196717917919, 47.74431645870209, 15.622248966246843, 2.695360668003559, 0.1639029136276804, 0.12847244215663522, 0.15739243797725067, 0.3734422690467909, 0.07972010076628067, 0.12411778676323593, 0.092229697474977, 0.10624176473356783, 0.12629456527065486, 0.2182662847917527, 0.20789386559044942, 0.15124800440389663, 0.23917582060676068, 0.08612958496087231, 0.13314093695953488, 0.09898128948407248, 0.1286956504918635, 0.1316684714402072, 0.21426671737572178, 0.11336938812746666, 0.19259544118540362, 0.15358949516667053, 0.18417518207570538, 0.15699638344813138, 0.2453270077239722, 0.13765758834779263, 0.25360245897900313], [0.011652006105578039, 0.05835659321746789, 0.0429961957706837, 0.08560464906622656, 0.07290564142749645, 0.06765700978576206, 0.0657612454961054, 0.019232356280554086, 0.07136782238376327, 0.06813941319705918, 0.14321906492114067, 0.03761188097996637, 0.02558165415393887, 0.04842633075895719, 0.026570361842459533, 0.09645239158999175, 0.025479143150732853, 0.031729310503578745, 0.051564758250606246, 0.02138697796908673, 0.043143345101270825, 0.008982047274912475, 0.037364994423114695, 0.04559734545182437, 0.09222871784004383, 0.014513028072542511, 0.021587938572338317, 0.03880003343510907, 0.036930051355739124, 0.057796308828983456, 0.058518440782791004, 4.598019747063518, 17.498125657439232, 44.39950414001942, 50.67894458770752, 41.075032129883766, 32.162306383252144, 18.6064425855875, 25.29689557850361, 23.33412230014801, 13.94978865981102, 5.848986720666289, 1.2451030570082366, 0.43362780357711017, 0.20085174503037706, 1.345911172684282, 2.2053085640072823, 10.756587255746126, 6.181016229093075, 3.4455211646854877, 6.430956842377782, 2.895094812847674, 7.962255673483014, 8.352458160370588, 20.853022634983063, 28.672902323305607, 41.38653561472893, 46.222296729683876, 53.3139131963253, 51.68940156698227, 52.208077535033226, 51.9790106266737, 54.650324285030365, 52.78200253844261, 51.92612886428833, 50.693201422691345, 50.877001360058784, 51.279065385460854, 47.847670912742615, 48.380155339837074, 48.38116228580475, 47.58916698396206, 50.13878837227821, 50.645001009106636, 51.629345789551735, 51.76633223891258, 53.31572949886322, 50.944326147437096, 51.917404532432556, 50.79900674521923, 52.047661542892456, 48.98548945784569, 43.61933760344982, 39.31108318269253, 39.76230517029762, 48.47746051847935, 45.786889493465424, 56.93466670811176, 41.780699864029884, 38.00952762365341, 55.38947582244873, 44.49837103486061, 44.5499836653471, 38.95909287035465, 38.00826609134674, 38.332848474383354, 39.11280982196331, 37.29113817214966, 39.04554583132267, 36.01596839725971, 37.70008742809296, 39.307496175169945, 43.183652982115746, 47.40518845617771, 45.717869997024536, 46.21368259191513, 49.94951672852039, 52.050465792417526, 49.19848322868347, 48.57480749487877, 52.74421736598015, 46.06713205575943, 52.38113544881344, 51.89893752336502, 52.627567425370216, 51.25091649591923, 51.820787116885185, 52.58557587862015, 52.540631890296936, 51.5222979336977, 50.618425235152245, 46.90629042685032, 36.97579689323902, 27.24700603634119, 13.606609124690294, 6.797801507636905, 3.461905410513282, 1.973109554965049, 7.8268717881292105, 7.292008213698864, 5.977454977110028, 6.008587181568146, 4.690755670890212, 1.4993886183947325, 1.34702522540465, 0.4862030589720234, 0.11058744756155647, 1.8718859553337097, 6.489822333678603, 21.76970824599266, 35.532425343990326, 51.94292016327381, 54.0745297819376, 45.647930949926376, 52.70414851605892, 43.85482996702194, 26.693951413035393, 7.004051115363836, 0.6058915005996823, 0.02114652768796077, 0.05459618660097476, 0.0558113309671171, 0.021191531523072626, 0.03624222517828457, 0.029465281404554844, 0.023559312867291737, 0.028881669459224213, 0.04825978910957929, 0.027281432085146662, 0.013241465640021488, 0.046760765835642815, 0.027183822967344895, 0.01767481651768321, 0.04183629687759094, 0.03663980482087936, 0.0054698612257197965, 0.11928608626476489, 0.027459124503366183, 0.02371494865656132, 0.049944553393288516, 0.03723142268427182, 0.10124939668457955, 0.007571483365609311, 0.009866370965028182, 0.006371735780703602, 0.037482116458704695, 0.037811032598256133, 0.06351417818223126, 0.026909291409538127, 0.0675910477002617, 0.05136100160598289, 0.0311545319709694, 0.024037127950577997, 0.025601773777452763, 0.14147837238851935, 0.027571097889449447, 0.04638289763533976, 0.043239122969680466, 0.03239011508412659, 0.010477398773218738, 0.02122636607964523, 0.02497533063433366, 0.04435840040969197, 0.0692566942598205, 0.05164599002455361, 0.030387544611585326, 0.025064527508220635, 0.06498671049484983, 0.03901842894265428, 0.11654532747343183, 0.06836871456471272, 0.03132177866064012, 0.02334990476811072, 0.02285297010530485, 0.033365924246027134, 0.02597367696580477, 0.10209125932306051, 6.0857966635376215, 23.952396623790264, 50.89935936033726, 56.18800677359104, 43.622058257460594, 35.148205161094666, 24.846933223307133, 31.737413182854652, 28.489351272583008, 16.16745226085186, 6.845294209197164, 1.377953547053039, 0.5271023721434176, 0.13320691388798878, 1.6488620289601386, 3.2734196120873094, 7.905367501080036, 8.670267406851053, 6.133525427430868, 5.7164745312184095, 4.543347330763936, 9.111949056386948, 14.478013515472412, 25.1990869268775, 32.262894585728645, 44.005070105195045, 50.52992798388004, 56.243886575102806, 53.49374994635582, 53.8801322132349, 54.77132499217987, 54.937695264816284, 52.16173902153969, 52.33604706823826, 49.95143562555313, 51.032830998301506, 53.45438025891781, 50.672370940446854, 50.519752129912376, 50.90269558131695, 49.95114304125309, 52.172910422086716, 53.20263236761093, 52.97695107758045, 53.21719318628311, 55.10065712034702, 51.46608754992485, 53.47866855561733, 53.07744048535824, 52.6827746629715, 52.35678255558014, 48.23027238249779, 40.78756235539913, 41.36765442788601, 50.3936330974102, 48.992948457598686, 58.231502920389175, 43.44844937324524, 40.70983752608299, 55.74327863752842, 47.73364283144474, 46.030255034565926, 41.30618892610073, 39.555824249982834, 38.80622707307339, 40.5417687445879, 39.6883687376976, 40.053589940071106, 37.920589596033096, 38.628161028027534, 40.09308882057667, 43.1530000269413, 48.742929473519325, 50.53605705499649, 48.93962971866131, 51.631610468029976, 54.64239791035652, 50.797680616378784, 49.243780598044395, 51.78763009607792, 47.589368373155594, 53.97363759577274, 52.94390045106411, 54.600432962179184, 53.92740547657013, 52.760602086782455, 55.84428861737251, 53.79933714866638, 54.43809047341347, 54.24941919744015, 51.01761281490326, 40.456717908382416, 29.339027479290962, 17.425331063568592, 9.990843795239925, 5.413535786792636, 7.09953049197793, 8.026244714856148, 7.255240911617875, 8.743396382778883, 7.686093142256141, 6.9597583170980215, 2.0428216829895973, 1.1816500243730843, 0.5377799773123115, 0.09296696924138814, 2.061286554671824, 7.335300240665674, 23.90159334987402, 33.088822066783905, 48.786148354411125, 58.662027418613434, 48.87969933450222, 57.41406038403511, 49.30303081870079, 31.765987649559975, 9.79388041421771, 0.9567254281137139, 0.024306967279699165, 0.024069749051705003, 0.0075968819783156505, 0.05227891211688984, 0.05177053353691008, 0.057531655256752856, 0.037292501438059844, 0.019033206517633516, 0.03899168565112632, 0.04134388560487423, 0.021134664457349572, 0.04300671942473855, 0.014938263848307543, 0.04971347087121103, 0.05441639761556871, 0.028011041176796425, 0.020785239066754002, 0.08806143989204429, 0.023353643337031826, 0.010365578455093782, 0.034519629916758277, 0.03229036672564689, 0.009479958789597731, 0.03719505373737775, 0.023968432906258386, 0.04139113814744633, 0.03712325466040056, 0.08486091319355182, 0.17722033808240667, 0.22586485283682123, 0.09781087806914002, 0.2075138859800063, 0.19936115626478568, 0.15414613561006263, 0.13546457164920866, 0.24463571200612932, 0.1383230127976276, 0.27341415057890117, 0.15096530551090837, 0.07346945843892172, 0.21355682343710214, 0.0886771256045904, 0.1450403398484923, 0.09537920152070001, 0.1286771264858544, 0.12644609698327258, 0.13936225703218952, 0.12530737527413294, 0.15147137601161376, 0.13043876242591068, 0.22688358410960063, 0.1892486965516582, 0.2146784757496789, 0.12523598066763952, 0.22340254043228924, 0.14580565737560391, 0.09314734081272036, 0.2516372222453356, 7.482949867844582, 28.67317020893097, 59.78009082376957, 63.32973875105381, 54.14722368121147, 42.432216703891754, 30.75235214084387, 37.67490237951279, 32.89475508034229, 19.522102251648903, 8.375654965639114, 1.9583868887275457, 0.9708615008275956, 1.1598625872284174, 5.05870227701962, 5.5278379283845425, 18.28801777213812, 20.42188636958599, 10.909090172499418, 14.987488277256489, 7.633055113255978, 10.791755318641663, 11.37806860730052, 26.22080460190773, 31.71456690877676, 44.046351090073586, 50.11104226112366, 56.89479544758797, 53.55507865548134, 55.765477046370506, 55.951925441622734, 56.35995514690876, 53.4530883282423, 53.57570394873619, 51.450869366526604, 52.90932610630989, 54.345056265592575, 53.01281355321407, 53.20368871092796, 52.716809436678886, 51.35363258421421, 53.85900914669037, 53.793063685297966, 54.500893503427505, 54.49775107204914, 56.48035168647766, 52.13251858949661, 56.89081706106663, 54.95081976056099, 54.976232796907425, 53.97228866815567, 50.11724732816219, 41.99789620935917, 43.498781472444534, 53.32323409616947, 50.916466042399406, 61.555921733379364, 46.03111758828163, 41.76224045455456, 57.39322990179062, 48.8584128767252, 48.05578954517841, 43.0528450012207, 41.66511006653309, 41.76531828939915, 41.968854367733, 42.51839987933636, 43.132503926754, 39.96130429208279, 41.35202206671238, 42.46078357100487, 47.375812232494354, 52.73410990834236, 51.8203691393137, 50.308415070176125, 55.042056664824486, 55.861646085977554, 52.62017302215099, 49.359811171889305, 53.45491223037243, 48.776956647634506, 53.283704817295074, 56.23494565486908, 55.96208229660988, 56.704904437065125, 55.315056815743446, 58.37187498807907, 57.52712331712246, 56.1001592874527, 55.63531883060932, 51.821079701185226, 41.12017750740051, 31.657778955996037, 16.777993999421597, 9.237003196030855, 6.990164760500193, 8.330814521759748, 15.150034055113792, 16.782114878296852, 15.264876242727041, 17.514428682625294, 14.203913323581219, 5.765397856011987, 3.2010406209155917, 0.9569249174091965, 0.5100649176165462, 2.7226714650169015, 9.144392665475607, 27.247482910752296, 46.493032202124596, 60.45630633831024, 66.26162722706795, 57.95387841761112, 65.61864852905273, 57.457351461052895, 36.546845510602, 10.668010208755732, 1.0377300158143044, 0.08430469577433541, 0.18925173935713246, 0.15772594430018216, 0.16953047103015706, 0.27475714101456106, 0.24091902159852907, 0.1619479779037647, 0.08889745440683328, 0.1827969989972189, 0.15243584144627675, 0.127112619811669, 0.10718812176492065, 0.12729368900181726, 0.12489156477386132, 0.12012403036351316, 0.09895050519844517, 0.14464740233961493, 0.21647448797011748, 0.10377324055298232, 0.0870151304116007, 0.14100034022703767, 0.06827548597357236, 0.11921753408387303, 0.13490796089172363, 0.2001863651094027, 0.13278636848554015, 0.09127535493462346], [0.03465673798928037, 0.03242669554310851, 0.01712718018097803, 0.039952284496393986, 0.0839059027202893, 0.02949782086943742, 0.016149304137798026, 0.021201596900937147, 0.03152224016957916, 0.04410561377881095, 0.020372287690406665, 0.043212234959355555, 0.016104441310744733, 0.09831872972426936, 0.05517845340364147, 0.052430796349653974, 0.05881141471036244, 0.134978212590795, 0.072158877592301, 0.02657886314409552, 0.00979342434220598, 0.04834100604057312, 0.03040723007870838, 0.04830729027162306, 0.021405292318377178, 0.02469394534273306, 0.01633864641917171, 0.11855149365146644, 0.03352912623086013, 0.10115662822499871, 0.02151222652173601, 2.218160661868751, 12.656980231404305, 36.574618220329285, 48.52344565093517, 43.829998299479485, 31.723817512392998, 25.186416506767273, 21.196303814649582, 23.426328152418137, 16.136729009449482, 8.493978716433048, 1.976049409713596, 0.8450214564800262, 0.18681229994399473, 0.7288150826934725, 3.8861288968473673, 9.649293422698975, 7.10692442022264, 4.408227056264877, 4.088715501129627, 2.9674673918634653, 3.668979099020362, 7.51104936003685, 15.030491519719362, 21.143971122801304, 33.55015151202679, 42.75730066001415, 51.60926766693592, 53.44653747975826, 52.79294595122337, 54.564384296536446, 56.26970238983631, 50.965247824788094, 48.78506541252136, 47.414091378450394, 51.678705140948296, 48.56603756546974, 47.88757637143135, 45.584181770682335, 44.58810701966286, 46.89902901649475, 48.06768290698528, 50.24723455309868, 51.07694283127785, 51.28208242356777, 49.56736743450165, 50.99915340542793, 50.39563179016113, 49.20810051262379, 47.66232065856457, 44.400746673345566, 39.08217206597328, 38.829052448272705, 39.76053066551685, 49.22890819609165, 48.769117668271065, 53.449584916234016, 43.877222165465355, 42.08934970200062, 54.98782217502594, 46.82002365589142, 43.49569983780384, 41.44960083067417, 44.59361672401428, 47.18455709517002, 46.05174668133259, 45.79103507101536, 46.70843504369259, 45.896901190280914, 46.2997517734766, 44.90297332406044, 49.25916597247124, 48.67845453321934, 47.92227990925312, 50.9948406368494, 52.34821021556854, 50.18239863216877, 51.40974037349224, 46.60329848527908, 48.84841561317444, 54.15118306875229, 46.67616717517376, 54.40025210380554, 56.09340324997902, 57.93128103017807, 55.408945977687836, 55.88574819266796, 54.92091916501522, 56.5587642788887, 54.553699269890785, 43.790681809186935, 30.757852345705032, 21.90756104886532, 15.684577021747828, 9.891531374305487, 1.7836368782445788, 5.7702169474214315, 6.697381921112537, 5.282976217567921, 7.054128153249621, 5.72306907735765, 7.0713060814887285, 2.1577351167798042, 0.529476769734174, 0.24655726592754945, 0.16184569511096925, 2.128772595897317, 9.303633570671082, 20.6511090695858, 42.99986444413662, 45.46545334160328, 38.835173919796944, 41.16523168981075, 45.87323606014252, 46.68294221162796, 25.96505932509899, 5.202740672975779, 0.3119602025253698, 0.06873696824186482, 0.009084956254810095, 0.028498780629888643, 0.08493534318404272, 0.07607398118125275, 0.06843017181381583, 0.06823635994805954, 0.03174096593284048, 0.03381021837412845, 0.015413345045089955, 0.0930143850564491, 0.01704666829027701, 0.03737271275895182, 0.033063539885915816, 0.12013543717330322, 0.08385415276279673, 0.11741444919607602, 0.04880672968283761, 0.11213187914108858, 0.016452276649943087, 0.024955698972917162, 0.04232941319060046, 0.04621384752681479, 0.042777072958415374, 0.0017818511150835548, 0.0544471633475041, 0.028810900112148374, 0.049050625384552404, 0.037841386438230984, 0.041223935986636207, 0.01887513277324615, 0.05389583297073841, 0.05778864615422208, 0.03215992313926108, 0.045017460943199694, 0.022355092914949637, 0.027820047616842203, 0.02621260213345522, 0.07298596407053992, 0.029968106864544097, 0.048401569001725875, 0.051053811839665286, 0.03476887279248331, 0.0431169023795519, 0.08706302862265147, 0.09294907606090419, 0.016340945221600123, 0.06080246334022377, 0.030395767607842572, 0.03266004532633815, 0.04542930095340125, 0.021570104763668496, 0.02297722046932904, 0.01243823364347918, 0.06345885849441402, 0.027398118108976632, 0.052685787159134634, 0.00442169034613471, 3.373349974863231, 16.12358171492815, 45.078588500618935, 53.98052282631397, 51.47931084036827, 36.44921354949474, 25.002521574497223, 24.428613670170307, 28.258536458015442, 20.60055088251829, 9.486487358808517, 2.361744032241404, 0.48000357288401574, 0.42062291235197335, 1.1329311761073768, 2.5634120358154178, 4.668191531673074, 6.351128350943327, 7.151321237906814, 6.612172443419695, 3.6664897575974464, 5.02258806489408, 11.978732775896788, 18.807047121226788, 25.564294829964638, 36.531927511096, 45.342199355363846, 53.70722249150276, 53.264557644724846, 52.48467609286308, 54.27931599318981, 55.28761848807335, 52.599764317274094, 48.86468254029751, 48.28394070267677, 53.13124559819698, 51.33302628993988, 50.67939296364784, 48.139939829707146, 46.29456505179405, 49.33555327355862, 50.42211636900902, 53.55854406952858, 52.27906532585621, 52.90623687207699, 51.18930280208588, 52.617695555090904, 53.05155627429485, 51.4410924911499, 49.710741341114044, 46.93964123725891, 41.47400312125683, 40.67525938153267, 41.58623389899731, 51.811276227235794, 49.88198675215244, 55.66709652543068, 46.0942891985178, 45.078744292259216, 57.40623280405998, 48.62112320959568, 46.034138426184654, 42.53855399787426, 45.49683205783367, 47.911564484238625, 47.71000050008297, 46.48899681866169, 47.02373832464218, 45.85414968430996, 45.754150450229645, 46.23708553612232, 51.67564630508423, 50.8789848536253, 51.060432717204094, 53.37991185486317, 54.267673417925835, 52.19491884112358, 50.27553163468838, 48.609765619039536, 51.958195343613625, 53.975860476493835, 48.572626411914825, 55.16959302127361, 56.46030396223068, 57.40963362157345, 56.186741441488266, 57.21268638968468, 58.108362928032875, 59.138130471110344, 56.967778131365776, 47.25167289376259, 33.92864540219307, 26.7237551137805, 18.199997395277023, 10.735553484410048, 5.681998981162906, 5.957877477630973, 6.861823322251439, 7.570509994402528, 7.777900490909815, 2.877597464248538, 6.306786630302668, 1.0664339130744338, 0.5523730942513794, 0.42560658243019134, 0.2225770941004157, 2.4068613862618804, 9.061969388276339, 23.418627865612507, 41.12997718155384, 51.08275651931763, 44.76843014359474, 46.33261241018772, 55.490717589855194, 52.956561371684074, 29.95925299823284, 6.2158166617155075, 0.5296281678602099, 0.0505593596608378, 0.053261218781699426, 0.024019980628509074, 0.04029905299830716, 0.026933203407679684, 0.004307578647058108, 0.0037630433280355646, 0.04490941537369508, 0.03421636611165013, 0.030523917957907543, 0.044877829568577, 0.06182007025927305, 0.019463487042230554, 0.04559888540825341, 0.029098517588863615, 0.05007880419725552, 0.09242413274478167, 0.036420667165657505, 0.07229858689242974, 0.11360683827660978, 0.028609536893782206, 0.03080285787291359, 0.03172612669004593, 0.03762534724955913, 0.008734134698897833, 0.041808303067227826, 0.027910144344787113, 0.17445181554649025, 0.16327891586115584, 0.18455761077348143, 0.12918393913423643, 0.21908756025368348, 0.14233565685572103, 0.1672620521276258, 0.1194197619042825, 0.09661190881161019, 0.12321214395342395, 0.10987148285494186, 0.2070665342034772, 0.06834639818407595, 0.1762723334832117, 0.19744827062822878, 0.13852285832399502, 0.12405072629917413, 0.20617073227185756, 0.2215809834888205, 0.08748919208301231, 0.144760787661653, 0.1005223739775829, 0.19054131000302732, 0.19654826814075932, 0.19347552442923188, 0.13291165785631165, 0.1047431310871616, 0.20100333611480892, 0.11676097332383506, 0.16952049656538293, 0.12231122120283544, 3.6800179816782475, 20.16035970300436, 50.56756116449833, 60.5442526191473, 58.54877829551697, 45.19536003470421, 36.87211565673351, 30.12139219790697, 34.99786622822285, 22.078340984880924, 11.709289234131575, 2.5859118159860373, 1.1154251592233777, 0.7100396370515227, 2.416748693212867, 7.159433802589774, 20.272278897464275, 19.851757362484932, 11.017818488180637, 11.709352880716324, 7.133559565991163, 6.815027883276343, 14.56164512783289, 21.14437960088253, 24.889468140900135, 39.35506962239742, 46.12416319549084, 52.73326635360718, 53.388005420565605, 53.155609890818596, 56.11312419176102, 56.92171320319176, 53.39722752571106, 49.75918114185333, 48.50200340151787, 55.58473974466324, 53.50787378847599, 53.09588849544525, 49.17725756764412, 47.46840186417103, 51.680985018610954, 51.32743678987026, 54.00918088853359, 54.68385748565197, 53.86643774807453, 51.57771036028862, 53.821850940585136, 54.684051275253296, 51.7611151188612, 51.65896899998188, 49.06815022230148, 43.37922468781471, 41.84890240430832, 45.27114316821098, 54.81101766228676, 53.51681850850582, 56.83225080370903, 46.87329679727554, 47.81478747725487, 59.326535761356354, 51.572227254509926, 47.220936343073845, 46.00036583840847, 48.12376409769058, 53.20276916027069, 51.19970664381981, 51.05206936597824, 49.76431846618652, 49.650047197937965, 49.25254672765732, 49.27222587168217, 53.460190147161484, 52.77182288467884, 53.940366581082344, 56.1073637008667, 55.70815712213516, 53.46201404929161, 51.50828808546066, 49.68393757939339, 50.640764236450195, 55.32036893069744, 51.69298857450485, 53.55912923812866, 58.2384717464447, 60.03760300576687, 58.55633229017258, 58.31802427768707, 60.27142345905304, 59.600041285157204, 59.01646099984646, 47.839121371507645, 34.770022854208946, 24.24394927918911, 21.764046549797058, 13.982569500803947, 6.3445319049060345, 11.654827706515789, 15.967254303395748, 13.756683021783829, 18.198663666844368, 15.849814005196095, 14.769544322043657, 5.995637001469731, 2.134228628128767, 1.103053498081863, 0.505981205496937, 2.863581678830087, 12.449312824755907, 28.306605778634548, 54.95672084391117, 54.988760724663734, 48.43096241354942, 56.20727553963661, 59.03508760035038, 60.51217474043369, 33.42186659574509, 8.160653002560139, 0.6532483594492078, 0.1695611365721561, 0.18277249328093603, 0.1636619382770732, 0.17433774744858965, 0.12096008940716274, 0.12450592257664539, 0.11015056006726809, 0.12722103274427354, 0.12213606692967005, 0.08284519557491876, 0.18305783421965316, 0.15842025313759223, 0.11086362297646701, 0.1360175310401246, 0.23695532960118726, 0.1179384277202189, 0.15442571748280898, 0.17629893205594271, 0.17508155753603205, 0.22544599953107536, 0.10626985502312891, 0.11040596276870929, 0.08220423973398283, 0.1460244573536329, 0.0931270356522873, 0.15951453504385427, 0.30389474937692285], [0.06362065410939977, 0.06624902205658145, 0.01995536582398927, 0.05901541626371909, 0.0402430505346274, 0.0466844804759603, 0.018919058638857678, 0.04891345051873941, 0.08021899469895288, 0.05755704412877094, 0.028829431539634243, 0.06772651191568002, 0.013518688410840696, 0.10100134866661392, 0.030624584724137094, 0.006230461012819433, 0.027098214377474505, 0.028458227825467475, 0.05748258816311136, 0.06680309466901235, 0.012966007325303508, 0.0194534513502731, 0.06922481159563176, 0.08171363559085876, 0.054327955876942724, 0.025716545060276985, 0.016947960793913808, 0.09084361794521101, 0.057843001050059684, 0.045398991642287, 0.05830318455991801, 0.6388723058626056, 9.346153289079666, 30.280964635312557, 47.42294870316982, 44.93959575891495, 39.04073528945446, 21.363283954560757, 18.74748531728983, 23.770270496606827, 20.289680063724518, 12.904650941491127, 3.857395788654685, 1.0396104399114847, 0.09206551956594922, 0.8278284478001297, 1.5405876701697707, 2.5638877227902412, 1.6033674264326692, 6.16338137537241, 4.59418480284512, 2.530732126906514, 3.364885929040611, 5.966561436653137, 6.966695319861174, 16.56217698007822, 26.630437821149826, 39.59013640880585, 46.08658701181412, 53.041232228279114, 51.84895500540733, 54.56561163067818, 52.88037545979023, 50.02444110810757, 48.58894653618336, 52.001551017165184, 51.687657460570335, 51.34895123541355, 47.00838714838028, 46.53267167508602, 41.497409865260124, 45.19505985081196, 48.56770947575569, 50.94342179596424, 50.319742262363434, 49.81710143387318, 49.45325195789337, 50.70965453982353, 46.06370843946934, 42.799330204725266, 39.75453078746796, 38.300770595669746, 36.603766456246376, 39.40812237560749, 41.971198841929436, 49.68134991824627, 46.865032240748405, 54.7829295694828, 43.944212570786476, 40.6659384816885, 51.67471915483475, 44.26876835525036, 43.23082745075226, 45.084231197834015, 51.645749509334564, 53.62015016376972, 51.93589814007282, 50.79034321010113, 51.71714007854462, 49.94898475706577, 50.51751784980297, 51.43379308283329, 47.380144000053406, 49.87156391143799, 53.05146127939224, 49.56575632095337, 49.78629648685455, 51.39620549976826, 49.19271133840084, 53.548789992928505, 47.39313170313835, 41.77214652299881, 49.66181896626949, 43.650845512747765, 54.16111573576927, 50.94585746526718, 57.15549185872078, 60.941741690039635, 58.700830936431885, 52.277963384985924, 48.17072957754135, 43.46191205084324, 27.395353876054287, 21.30852699279785, 10.429945383220911, 6.543321562930942, 3.8946513645350933, 4.364506127312779, 3.376014344394207, 4.7440174128860235, 6.5790581703186035, 3.445990439504385, 3.2116748252883554, 0.5965869280043989, 0.36314918543212116, 0.210277569713071, 0.40268036420457065, 1.9298579008318484, 11.439593005925417, 27.675068266689777, 39.1880039870739, 24.090600907802582, 42.981150448322296, 37.99293391406536, 45.853579714894295, 39.9315594881773, 19.189335107803345, 4.219533456489444, 0.11373092536814511, 0.022136916340969037, 0.01063352809069329, 0.07065835146931931, 0.026610114982759114, 0.008642092616355512, 0.006312235482255346, 0.004515697264650953, 0.034901702383649535, 0.051228309312136844, 0.02611435662402073, 0.01095679555874085, 0.029151636808819603, 0.044396543089533225, 0.037753356591565534, 0.03645214907010086, 0.018021915275312494, 0.02985717248520814, 0.033370573801221326, 0.12711592979030684, 0.10450952526298352, 0.03721065368154086, 0.025412563227291685, 0.04470189232961275, 0.055569494725205004, 0.02692658901651157, 0.06142885824374389, 0.0940670027921442, 0.10248642327496782, 0.020185038265481126, 0.02135468712367583, 0.018929456127807498, 0.05899968644371256, 0.05439336506242398, 0.017567704198881984, 0.06875463135656901, 0.0962448499922175, 0.04626342299161479, 0.05486448782903608, 0.08700016129296273, 0.039265263549168594, 0.032120221949298866, 0.03212206618627533, 0.016279001865768805, 0.005242196293693269, 0.06608177165617235, 0.028732061764458194, 0.02856617320503574, 0.06957224060897715, 0.0626932960585691, 0.026471990167920012, 0.009324423190264497, 0.07695235006394796, 0.06617534163524397, 0.006276696349232225, 0.10411376017145813, 0.0280875343378284, 0.04894382662314456, 0.026728071934485342, 0.9211219323333353, 12.580693624913692, 35.709416046738625, 54.31256040930748, 49.039647951722145, 41.78167261183262, 28.29257123172283, 20.52173551172018, 25.28290282934904, 22.307795472443104, 12.575354911386967, 4.188476772978902, 0.8091930008959025, 0.2845496905501932, 1.0027721291407943, 2.116039954125881, 3.2468405133113265, 5.512174218893051, 8.981061279773712, 7.263692133128643, 4.549871580675244, 4.218934988602996, 7.361585330218077, 10.829491093754768, 19.80692356824875, 28.25850795954466, 41.57691299915314, 48.257900699973106, 53.81219565868378, 54.406935945153236, 54.9887303262949, 54.65307913720608, 52.997268587350845, 49.83986221253872, 52.17994004487991, 52.941202595829964, 52.70514786243439, 48.2434918731451, 48.184674829244614, 43.395005241036415, 47.6724661141634, 49.87520411610603, 53.13893258571625, 51.99122317135334, 51.406312957406044, 52.09327429533005, 52.21638008952141, 49.696131125092506, 45.11390000581741, 42.16413348913193, 41.383351385593414, 39.1182055324316, 40.88634565472603, 43.529008850455284, 52.28121981024742, 50.18690899014473, 56.616631373763084, 46.31633788347244, 42.35503524541855, 53.9375015348196, 47.32402861118317, 46.83391571044922, 47.32064679265022, 53.92538398504257, 54.54814396798611, 53.43054413795471, 52.33358100056648, 52.136276587843895, 51.009720638394356, 52.67546385526657, 52.53208614885807, 49.75233390927315, 52.21258409321308, 54.605562686920166, 51.27893999218941, 52.5139307230711, 51.72172263264656, 50.78591264784336, 54.28577944636345, 47.057108134031296, 46.8009714782238, 50.44024519622326, 46.020831540226936, 55.68419560790062, 52.168099880218506, 57.758040726184845, 60.3583437949419, 57.58348189294338, 53.585970997810364, 52.20169387757778, 45.47028288245201, 31.336962170898914, 22.592671886086464, 13.067247066646814, 8.746381122618914, 5.154697000980377, 9.325752183794975, 7.526804264634848, 7.853079931810498, 6.850100951269269, 3.9839610597118735, 5.2202781569212675, 1.6308284341357648, 0.3761250735260546, 0.285799348494038, 0.4919123713625595, 2.3741444293409586, 13.328378554433584, 30.791676230728626, 45.14142192900181, 33.08720715343952, 47.56587043404579, 43.97923909127712, 49.225541576743126, 46.80229760706425, 24.23386462032795, 5.380838541314006, 0.1430196053115651, 0.012507523333624704, 0.10702240761020221, 0.054881304895388894, 0.018318590664421208, 0.029088305636832956, 0.02101102265442023, 0.020545350962493103, 0.030572395044146106, 0.01793999701476423, 0.0501168095797766, 0.024013644542719703, 0.07205511050415225, 0.03343167481943965, 0.053547776842606254, 0.016057209177233744, 0.02344043936318485, 0.005257178399915574, 0.02601572519779438, 0.019145907208439894, 0.08617855928605422, 0.03812417809967883, 0.031327808610512875, 0.03413655926124193, 0.11880068457685411, 0.03061032621189952, 0.056618093731231056, 0.022305298516585026, 0.1977687596809119, 0.11993091611657292, 0.119857154058991, 0.14044626761460677, 0.10934809062746353, 0.09698366542579606, 0.17028449306963012, 0.17996153474086896, 0.21773288841359317, 0.1592335430905223, 0.12265957790077664, 0.12817504873964936, 0.13388557825237513, 0.13123713521054015, 0.14494981267489493, 0.11404728807974607, 0.1420772261917591, 0.15800042019691318, 0.16386162053095177, 0.10793840338010341, 0.11436865286668763, 0.22426899784477428, 0.23755262489430606, 0.21712493587983772, 0.1765001579769887, 0.15444004093296826, 0.15393852721899748, 0.1400250245933421, 0.23056380538037047, 0.13436862733215094, 0.1306046175886877, 1.0172829567454755, 14.086630716919899, 42.17326819896698, 60.367451906204224, 58.54024015367031, 51.387636959552765, 34.36335727572441, 28.446364179253578, 33.123054429888725, 27.399467155337334, 16.989034675061703, 5.752602042630315, 1.7678736615926027, 0.44498880801256746, 2.347645601257682, 3.4474680852144957, 8.459488917142153, 9.228704441338778, 16.492070741951466, 11.710359826683998, 6.370586631819606, 8.6750029027462, 8.378413617610931, 9.98502155765891, 21.448382288217545, 32.735729813575745, 47.15314418077469, 54.8383229970932, 56.8979112803936, 55.59959314763546, 58.611144348978996, 56.958765015006065, 54.26491856575012, 49.97988469898701, 51.48727901279926, 55.17727620899677, 55.89565426111221, 50.135129168629646, 50.5906867235899, 45.09549379348755, 47.97737315297127, 52.23439872264862, 56.309562250971794, 53.77650797367096, 53.32236014306545, 53.99328634142876, 54.283108189702034, 49.87275704741478, 45.258565843105316, 43.42484124004841, 43.00018362700939, 40.62988981604576, 42.681901305913925, 46.99755012989044, 53.66914853453636, 53.065604120492935, 56.849954053759575, 48.17159593105316, 44.968576803803444, 54.877780079841614, 49.52443353831768, 48.00656698644161, 50.05972221493721, 56.83674216270447, 58.793819546699524, 56.82943895459175, 54.4629867374897, 55.817880034446716, 53.537591993808746, 54.7376473993063, 55.7538078725338, 53.460585325956345, 54.5306459069252, 56.21721960604191, 52.118972316384315, 53.49823370575905, 53.00156995654106, 51.73704341053963, 56.71985663473606, 49.554269537329674, 47.454954385757446, 54.445161893963814, 49.10953380167484, 55.47200359404087, 52.34841160476208, 59.06998872756958, 62.90269486606121, 58.823678344488144, 55.654135420918465, 52.54390351474285, 46.67508043348789, 32.10958041250706, 26.19776263833046, 15.983449034392834, 10.292373765259981, 10.303748454898596, 14.444439467042685, 11.426650900393724, 13.686609081923962, 13.764792736619711, 11.587976943701506, 7.6680246368050575, 2.978352620266378, 1.3308486621826887, 1.0012118378654122, 0.9076262440066785, 3.405591007322073, 15.36433020606637, 34.01089958846569, 47.9222647100687, 36.21942088007927, 53.66867356002331, 50.051469057798386, 60.36503903567791, 53.40269923210144, 27.468070574104786, 6.054464969784021, 0.2849468879867345, 0.10493809328181669, 0.2066888107219711, 0.11839113038149662, 0.09212193021085113, 0.11336139519698918, 0.07989109901245683, 0.13027074019191787, 0.11103195691248402, 0.13580529164755717, 0.10775302231195383, 0.09299008714151569, 0.2387849462684244, 0.13449595018755645, 0.10410139599116519, 0.10944182387902401, 0.13362925528781489, 0.04751750784635078, 0.1240939786657691, 0.1647695343126543, 0.1731761675910093, 0.1348533685086295, 0.09886182597256266, 0.16023220669012517, 0.12711416347883642, 0.15847987728193402, 0.22013427049387246, 0.1254486505058594], [0.1437264564447105, 0.02084923631628044, 0.03048099399165949, 0.029956249200040475, 0.04692194546805695, 0.012100068488507532, 0.018525024606788065, 0.019058120415138546, 0.03202184285328258, 0.052590057530323975, 0.0731303563225083, 0.017144765370176174, 0.05741979504819028, 0.034714555004029535, 0.015595083095831797, 0.023753800087433774, 0.046028588913031854, 0.057078922909568064, 0.06933954020496458, 0.10978725651511922, 0.027569042140385136, 0.01617226989765186, 0.036980246513849124, 0.025601705128792673, 0.055651271977694705, 0.030534894322045147, 0.056495197786716744, 0.005271667441775207, 0.01441244294255739, 0.0473339858581312, 0.048577710331301205, 0.3391488123452291, 3.8643190171569586, 22.485574632883072, 47.1349773555994, 49.17430132627487, 40.2782566845417, 21.184290759265423, 22.416462041437626, 26.740096136927605, 29.577360190451145, 18.744992651045322, 8.383950870484114, 1.291378636378795, 0.5917160643730313, 0.7479411782696843, 2.376360660418868, 1.4719382976181805, 5.521125588566065, 8.670972269028425, 6.277797035872936, 2.2626909473910928, 1.9127455190755427, 4.914095811545849, 8.669026773422956, 14.217850025743246, 22.303456105291843, 33.24304819107056, 42.75836080312729, 45.80070175230503, 46.39289237558842, 50.22469036281109, 51.5034319460392, 49.99320298433304, 48.94624516367912, 52.63293273746967, 54.01692487299442, 50.662039294838905, 48.11147175729275, 45.24422161281109, 39.96833011507988, 42.543094754219055, 40.74237897992134, 42.049182057380676, 42.76600979268551, 43.0433265119791, 42.009185403585434, 39.47552315890789, 37.33669772744179, 37.83191755414009, 35.36089114844799, 38.80103275179863, 37.82966047525406, 43.00474338233471, 42.83718757331371, 48.05048502981663, 47.72527948021889, 53.90089429914951, 45.160078927874565, 40.20217336714268, 52.28878140449524, 45.34853361546993, 45.50052925944328, 44.296453669667244, 51.28448389470577, 50.82156993448734, 52.29486487805843, 51.498883590102196, 54.443653374910355, 53.25733423233032, 53.134969398379326, 51.741124391555786, 53.10873940587044, 50.0796939432621, 50.04928417503834, 51.5646580606699, 53.75464394688606, 52.24468857049942, 52.32362933456898, 50.26619553565979, 54.89621289074421, 41.06714755296707, 48.03944282233715, 50.68185143172741, 48.10173287987709, 52.886698320508, 47.48040921986103, 54.84514743089676, 53.37195508182049, 58.84330429136753, 50.8587471395731, 38.03116366267204, 24.88672848790884, 18.258704245090485, 9.790735132992268, 7.2607287671417, 2.8634686348959804, 4.694021120667458, 5.638322224840522, 5.451781684532762, 2.4245615489780903, 0.17728800710756332, 4.512386592105031, 1.3223032769747078, 0.13391694141319022, 0.17894161603180692, 0.377976197632961, 4.9719681311398745, 10.230661276727915, 30.9184792265296, 40.23833982646465, 29.097269251942635, 37.29678466916084, 47.639001309871674, 45.2087277173996, 36.18409417569637, 15.079018715769053, 2.319038361310959, 0.14260008407291025, 0.035373916107346304, 0.06332599921734072, 0.07942194293718785, 0.04611565396771766, 0.06206405501870904, 0.02495251701475354, 0.06806441175285727, 0.0891568795486819, 0.093141886027297, 0.04183941760857124, 0.033595210770727135, 0.03131546669465024, 0.009100973657041322, 0.02128071540937526, 0.06977902521612123, 0.06877069885376841, 0.08090679490123875, 0.027446546955616213, 0.01742456432111794, 0.04181191361567471, 0.013711017836612882, 0.03204690889106132, 0.037706961229559965, 0.018944690564239863, 0.02504703323211288, 0.017424599573132582, 0.055317350052064285, 0.05275373077893164, 0.020819489182031248, 0.06029981414030772, 0.024738676438573748, 0.04245078031090088, 0.03183718908985611, 0.004557923148240661, 0.005537480619750568, 0.02206410608778242, 0.031372886660392396, 0.06253979765460826, 0.05837706907186657, 0.04809678008314222, 0.013507944895536639, 0.02998478477820754, 0.05023395016905852, 0.04364586071460508, 0.056390425088466145, 0.10485995255294256, 0.03784230299061164, 0.011025344028894324, 0.02122999147104565, 0.031522896970272996, 0.028910431392432656, 0.04330498486524448, 0.05984798350255005, 0.09822431369684637, 0.036600203820853494, 0.04645470042305533, 0.03542271602782421, 0.045976764740771614, 0.47476202133111656, 5.271245297044516, 27.335222102701664, 52.200512140989304, 55.71580611169338, 46.01241119205952, 23.87625250965357, 21.126007586717606, 27.14361358433962, 30.751373693346977, 18.09403818100691, 7.391984649002552, 1.4915331336669624, 0.23495878907851875, 0.5863752134609967, 1.2713904026895761, 2.626558472402394, 5.055916076526046, 7.8109287936240435, 5.8125367015600204, 7.424248717725277, 4.415623359382153, 6.046684887260199, 11.372476257383823, 17.110856138169765, 28.17230388522148, 38.4123820066452, 47.18511566519737, 50.80706611275673, 50.86051404476166, 51.4667297154665, 55.322740003466606, 53.02991643548012, 49.60397846996784, 52.94722147285938, 53.879433050751686, 52.58841812610626, 49.8912962526083, 46.73599496483803, 41.04817517101765, 43.873654156923294, 42.78904415667057, 45.91783046722412, 46.01825147867203, 46.5125023573637, 44.143774062395096, 42.56221532821655, 41.389997228980064, 39.25210654735565, 36.083980947732925, 40.73485158383846, 40.11804588139057, 43.79524156451225, 46.25491037964821, 50.58268055319786, 50.05359314382076, 55.358857065439224, 46.08833871781826, 42.718398347496986, 53.404648527503014, 46.8119452893734, 46.98329709470272, 46.446108520030975, 54.12558004260063, 53.19233871996403, 53.28459396958351, 53.69889333844185, 55.81834740936756, 54.72464829683304, 55.72924219071865, 53.97167690098286, 55.30626408755779, 53.08643840253353, 51.93698488175869, 50.99416807293892, 54.00484152138233, 53.44978630542755, 51.61680266261101, 51.81610196828842, 55.08839897811413, 42.10148625075817, 52.14327201247215, 49.65357720851898, 49.098005220294, 53.67892161011696, 50.817789137363434, 56.48292414844036, 56.37127473950386, 57.6900851726532, 50.99287994205952, 40.81076771020889, 26.85067780315876, 20.362668447196484, 11.172143407166004, 7.718260791152716, 5.3407801408320665, 5.748637905344367, 8.465601839125156, 5.649621393531561, 5.501533839851618, 3.839370980858803, 2.995935226790607, 0.5672919249627739, 0.3833728877361864, 0.27822691889014095, 0.7075173442717642, 4.74308218806982, 13.523493334650993, 31.673287823796272, 43.980348631739616, 32.08700582385063, 43.39054428040981, 51.14591673016548, 50.47237627208233, 42.63269394636154, 18.621852658689022, 3.2374968146905303, 0.07437260763254017, 0.034218618529848754, 0.08187370200175792, 0.0759494562225882, 0.01971245903405361, 0.017648527791607194, 0.015416310852742754, 0.012840035178669496, 0.09215470345225185, 0.04652193529182114, 0.030644325852335896, 0.03857506992062554, 0.024044699712248985, 0.048376517806900665, 0.023273667648027185, 0.08254484841017984, 0.022723461624991614, 0.07519788327044807, 0.08086999179795384, 0.06315690086921677, 0.06662116458755918, 0.04540160771284718, 0.013477071552188136, 0.03968756784161087, 0.05047904072853271, 0.024280099678435363, 0.027985900924250018, 0.08268126999610104, 0.31694096338469535, 0.10902427675318904, 0.09143927309196442, 0.10580128524452448, 0.10330227363738231, 0.09754889251780696, 0.10187395106186159, 0.1273073148331605, 0.10266983023029752, 0.1282673719106242, 0.11057450450607575, 0.13601333048427477, 0.14012500672833994, 0.11820168234407902, 0.09458078420720994, 0.14632501231972128, 0.12586967088282108, 0.1796051554265432, 0.14730179740581661, 0.20282330486224964, 0.05571713387325872, 0.11364500693161972, 0.1242909520806279, 0.18975675600813702, 0.18575896974653006, 0.16667642339598387, 0.21146865736227483, 0.12469976412830874, 0.17326325119938701, 0.14888745528878644, 0.08395073586143553, 0.6021310086362064, 6.884122900664806, 31.275983043015003, 58.330138027668, 63.147907108068466, 53.8511473685503, 32.691249400377274, 34.251411482691765, 38.56400907039642, 39.56391021609306, 22.297361232340336, 10.215940866619349, 1.8253237288445234, 1.026471694931388, 1.2076266179792583, 6.595209203660488, 4.847176652401686, 12.53198403865099, 15.887083355337381, 15.106863621622324, 9.827990233898163, 4.364160345867276, 8.686247449368238, 14.272095914930105, 19.152188301086426, 27.792377471923828, 42.75869898498058, 48.17430518567562, 52.37208433449268, 52.17964366078377, 52.75136858224869, 57.0000422000885, 54.11962576210499, 49.436061680316925, 53.48693311214447, 58.068746253848076, 55.4715134203434, 51.40785187482834, 49.72129337489605, 43.35582174360752, 47.336427345871925, 44.432372376322746, 46.915273144841194, 46.2751404941082, 47.78245501220226, 45.29368735849857, 42.46153213083744, 41.75997577607632, 41.03445030748844, 37.79732421040535, 44.56995539367199, 42.540659084916115, 46.89978517591953, 46.58112287521362, 52.30419337749481, 52.99778535962105, 57.30858564376831, 47.7559020370245, 45.798665061593056, 55.225385427474976, 49.55211125314236, 49.27409917116165, 49.00138400495052, 54.922724068164825, 55.28415687382221, 54.90843303501606, 55.79234920442104, 57.12689459323883, 56.49944946169853, 57.96555519104004, 56.1114788800478, 57.25025497376919, 53.19098599255085, 51.22592143714428, 52.83135809004307, 56.427447125315666, 56.100972443819046, 54.183078557252884, 53.935856223106384, 55.79856567084789, 45.614443346858025, 50.85706762969494, 51.988285928964615, 50.15428014099598, 53.34071695804596, 50.70363946259022, 56.90495230257511, 58.11718225479126, 62.121395990252495, 54.79279384016991, 43.46970923244953, 28.20865273475647, 23.166319504380226, 15.217617228627205, 12.448250781744719, 10.091502293944359, 9.825527016073465, 11.889616157859564, 11.844933405518532, 11.26093229278922, 6.797841880470514, 10.163271892815828, 5.116088697686791, 0.5459824309218675, 0.6298588332720101, 0.6989835959393531, 7.314150100573897, 14.383782371878624, 40.478806123137474, 48.86275224387646, 41.619786098599434, 49.085165709257126, 61.083215698599815, 58.746348693966866, 50.734189823269844, 22.663897164165974, 4.287789193913341, 0.2676449320279062, 0.08832343286485411, 0.2356968104140833, 0.20181313797365874, 0.14124000939773396, 0.13702348252991214, 0.12876048451289535, 0.16771298105595633, 0.23009552503935993, 0.21846388903213665, 0.0745660113170743, 0.17235639126738533, 0.17108289554016665, 0.1172788068652153, 0.11600305500905961, 0.17395453207427636, 0.1622164572472684, 0.15798076812643558, 0.19205318356398493, 0.17547695897519588, 0.2803221205249429, 0.16160011844476685, 0.12144345018896274, 0.11754026549169794, 0.10673147087800317, 0.14665844442788512, 0.08921144224586897, 0.17539784603286535], [0.029528315717470832, 0.015866438261582516, 0.023966861408553086, 0.04816230801225174, 0.03789400099776685, 0.07993219172931276, 0.04442250712600071, 0.01257314959730138, 0.08738941032788716, 0.057063363783527166, 0.03216188611986581, 0.060660356903099455, 0.02461799023876665, 0.04862169000261929, 0.024040087264438625, 0.03109067758487072, 0.057468479935778305, 0.08192578592570499, 0.09884532060823403, 0.036008949609822594, 0.050986643764190376, 0.036643779021687806, 0.0913087664230261, 0.06311729244771414, 0.07947517719003372, 0.0310572178568691, 0.11113117463537492, 0.03670064979814924, 0.040967542518046685, 0.02764017328445334, 0.03959183821280021, 0.08378310696571134, 1.8784306291490793, 15.78048387542367, 43.87696757912636, 47.73719564080238, 42.53466300666332, 33.15221406519413, 31.587112247943878, 32.81219311058521, 31.456948332488537, 23.868941701948643, 8.887914028018713, 3.0030453577637672, 0.5217311822343618, 0.283072697930038, 0.7302698702551425, 2.2598631866276264, 2.318956428207457, 4.151171324774623, 3.8734278408810496, 6.18975481018424, 4.3746767565608025, 3.840098879300058, 6.727035529911518, 13.499332331120968, 25.510721504688263, 35.188980773091316, 45.59450961649418, 53.066348880529404, 58.00051711499691, 57.044575810432434, 46.88525475561619, 50.50464414060116, 52.413692101836205, 53.43587525188923, 54.81533043086529, 50.53494371473789, 45.879433527588844, 44.6891625970602, 41.03246681392193, 41.75263836979866, 39.224326238036156, 37.94987842440605, 36.65281802415848, 39.93711479008198, 37.07765802741051, 36.12300105392933, 36.507422626018524, 39.39688637852669, 38.86360019445419, 41.585135757923126, 44.69086490571499, 45.83758257329464, 46.592358872294426, 50.20452104508877, 47.00950428843498, 53.904918283224106, 44.5417495071888, 37.07594811916351, 55.009891390800476, 45.97963035106659, 46.62190608680248, 45.32391473650932, 49.96931366622448, 50.2107223123312, 53.936920166015625, 51.28224581480026, 51.6071891784668, 51.24728009104729, 53.687288761138916, 51.2923950701952, 50.67287251353264, 50.083231553435326, 48.769854828715324, 50.652330815792084, 46.359602361917496, 47.82621346414089, 49.80446711182594, 52.05716863274574, 50.883913189172745, 53.777841702103615, 48.14025901257992, 52.114693745970726, 54.307643473148346, 54.5952158421278, 52.84286767244339, 52.15883977711201, 44.191537499427795, 44.82943207025528, 47.20929376780987, 38.60972061753273, 23.775776401162148, 15.242809876799583, 9.457510113716125, 5.917094266042113, 2.524053272791207, 4.72941099666059, 8.247389998286963, 5.431901151314378, 4.305616887286305, 3.870646390132606, 2.663729740306735, 0.769959274912253, 0.9255132498219609, 0.2668563852785155, 0.9789763216394931, 5.085250502452254, 14.938142225146294, 35.58238126337528, 35.44908441603184, 30.801785588264465, 37.64196574687958, 41.381105706095695, 46.488890424370766, 28.000974878668785, 9.649917539209127, 1.015644057188183, 0.057728762258193456, 0.013775953902950278, 0.04460025520529598, 0.03947443787183147, 0.019402849866310135, 0.018363310628046747, 0.03831029389402829, 0.039009044485283084, 0.018497633791412227, 0.02847291307261912, 0.07261547652888112, 0.030619016761193052, 0.06277663182117976, 0.03612187480030116, 0.0425679654290434, 0.018934962863568217, 0.06910866548423655, 0.04400437370350119, 0.10805261990753934, 0.024918736307881773, 0.07988635668880306, 0.04009155964013189, 0.05578659889579285, 0.04522077229921706, 0.01932252722326666, 0.08261915965704247, 0.04970431647961959, 0.016439825267298147, 0.10284229050739668, 0.0648687312786933, 0.0693843510816805, 0.01951165613718331, 0.058251482842024416, 0.027670855524775106, 0.02323015552974539, 0.03768414389924146, 0.02789643687719945, 0.04829074037843384, 0.025327711628051475, 0.013044741772318957, 0.03245907915697899, 0.009581665490259184, 0.030759768778807484, 0.007654993069081684, 0.08051266995607875, 0.024849939218256623, 0.05270821857266128, 0.01306818992816261, 0.02636698369315127, 0.015159022168518277, 0.08290763988043182, 0.04212959363940172, 0.047088320134207606, 0.012758604880218627, 0.047838397658779286, 0.03210304865206126, 0.06038902771251742, 0.043931246182182804, 0.024263655541290063, 0.16130067670019343, 2.6856683380901814, 19.164949916303158, 49.5488016307354, 56.45882584154606, 46.90835751593113, 35.39714500308037, 35.66284954547882, 34.79513570666313, 36.24066174030304, 24.742980301380157, 10.885709077119827, 2.5697643449530005, 0.6783869792707264, 0.35928298195358366, 0.8322441077325493, 2.5897797709330916, 4.5838564820587635, 6.755524976179004, 4.7004275768995285, 7.991805262863636, 4.828394735231996, 6.7875848058611155, 9.112276788800955, 15.625191908329725, 27.558365128934383, 37.22293183207512, 48.91002170741558, 53.403527587652206, 57.907042130827904, 57.94354297220707, 50.445515513420105, 52.447616681456566, 53.32118220627308, 54.61983472108841, 55.50115562975407, 54.352678656578064, 48.872278332710266, 46.38430863618851, 41.96608051657677, 42.61315539479256, 41.46886959671974, 39.906610026955605, 38.47710393369198, 40.81524387001991, 39.46608826518059, 38.54399934411049, 38.425821885466576, 40.88766038417816, 40.50637364387512, 43.56946527957916, 45.794489085674286, 47.03515291213989, 48.61626327037811, 52.004442662000656, 49.0270022302866, 54.4348606467247, 44.707093834877014, 40.66329002380371, 56.81264765560627, 48.40716429054737, 46.87136270105839, 48.174069598317146, 52.35663816332817, 53.84588845074177, 54.5550823956728, 52.26475529372692, 51.70661464333534, 52.755457162857056, 53.06805118918419, 53.32095041871071, 52.457914128899574, 51.180787459015846, 51.69801950454712, 53.726099878549576, 49.858758598566055, 50.395153015851974, 51.77128717303276, 52.539567947387695, 53.17107506096363, 54.220954924821854, 49.14330638945103, 53.24687719345093, 54.103913605213165, 54.61075700819492, 53.67757648229599, 54.94755573570728, 50.85297904908657, 51.40671193599701, 50.14447286725044, 38.54499489068985, 25.604663863778114, 19.299580492079258, 10.152359828352928, 7.318316102027893, 5.73897834867239, 9.60570976138115, 10.766381230205297, 6.85345902107656, 4.338109418749809, 5.025260271504521, 4.427792206406593, 1.6465965192764997, 0.41428375407122076, 0.2808560512494296, 0.7175168045796454, 6.356754899024963, 14.29955419152975, 35.05887195467949, 45.98999239504337, 32.31281630694866, 40.60177892446518, 47.8242489695549, 52.36197307705879, 33.77424828708172, 13.003739174455404, 1.4348081150092185, 0.05820940677949693, 0.004627592725228169, 0.04317431121307891, 0.04833376638998743, 0.020276324285077862, 0.07270671616424806, 0.03309263207484037, 0.025273158207710367, 0.023794031912984792, 0.022499338592751883, 0.04379120291559957, 0.017064880594261922, 0.02899984163377667, 0.073330097948201, 0.008629744206700707, 0.04845014998863917, 0.05076486777397804, 0.09460312285227701, 0.03851780580589548, 0.03889981147949584, 0.0469118411274394, 0.03432164347032085, 0.06472940047387965, 0.059334688194212504, 0.038026192341931164, 0.059298152264091186, 0.06222028452611994, 0.06379091020789929, 0.2045784841175191, 0.12103586268494837, 0.18939280678750947, 0.1380722559406422, 0.11232542383368127, 0.25918839673977345, 0.08131522103212774, 0.15116675407625735, 0.14419123384868726, 0.1696220223675482, 0.09423661322216503, 0.21841385343577713, 0.10404992804978974, 0.1683097123168409, 0.1192075150902383, 0.08964634078438394, 0.24198280123528093, 0.1844286997220479, 0.14465558080701157, 0.07969871207023971, 0.14432311349082738, 0.10380936830188148, 0.20352795923827216, 0.13547637179726735, 0.15626968728611246, 0.09186749230138958, 0.23347682406893, 0.08599891501944512, 0.21093204006319866, 0.1647068525198847, 0.13724133255891502, 0.2132744956179522, 3.360392195172608, 21.640357486903667, 55.92655040323734, 62.029976695775986, 55.22735372185707, 43.52235920727253, 42.669270783662796, 43.57050262391567, 41.11977472901344, 29.5895404368639, 11.79618202149868, 3.8840679824352264, 0.8010677306447178, 0.9269381733611226, 1.5057776193134487, 7.255186764523387, 9.188553895801306, 10.970814060419798, 10.17445469275117, 14.559710081666708, 11.433569379150867, 7.118830131366849, 10.098698157817125, 18.932421393692493, 31.669233441352844, 39.09755364060402, 49.55800473690033, 53.40450033545494, 60.2092169970274, 58.99585850536823, 53.07917699217796, 51.232236698269844, 53.5601893812418, 53.78684721887112, 57.08812527358532, 55.13843089342117, 50.44620327651501, 49.66835081577301, 44.76963847875595, 44.83441360294819, 43.358937576413155, 41.582270711660385, 39.54577758908272, 42.803076803684235, 41.21159300208092, 40.22309124469757, 40.281953886151314, 44.63325619697571, 42.89326876401901, 46.25405542552471, 50.22374041378498, 50.03280445933342, 51.334736198186874, 54.303775280714035, 51.82044893503189, 56.3236290961504, 47.90846385061741, 42.99769476056099, 59.030212461948395, 51.320201978087425, 50.87627559900284, 49.884707406163216, 54.317811727523804, 55.360650569200516, 57.40035451948643, 52.477646470069885, 52.17740938067436, 52.15390004217625, 54.15536664426327, 53.77939581871033, 53.02418254315853, 52.05739662051201, 53.76379765570164, 55.01218266785145, 50.64519479870796, 52.026128098368645, 53.692897260189056, 55.563658475875854, 55.634832456707954, 55.63927821815014, 48.70379537343979, 52.20704399049282, 53.9382728934288, 54.724739491939545, 53.26423466205597, 56.848890110850334, 50.57125836610794, 53.6419115960598, 53.913433626294136, 42.66736328601837, 28.580582477152348, 19.390988387167454, 11.698942389339209, 12.739613447338343, 9.158748295158148, 13.204801585525274, 17.469150312244892, 15.13703590258956, 13.121583200991154, 11.199791673570871, 10.417110621929169, 2.641520882025361, 2.603853503242135, 1.0004396480508149, 1.6400790377520025, 6.74090763553977, 19.21216808259487, 44.29497554898262, 46.37205809354782, 40.86105801165104, 51.407000720500946, 55.39129212498665, 59.3739952147007, 40.294044837355614, 15.188250504434109, 1.9007145334035158, 0.10518799666897394, 0.1015770919912029, 0.14633785147452727, 0.09583744060364552, 0.12516794056864455, 0.26717408385593444, 0.14935582468751818, 0.18503650382626802, 0.07645958627108485, 0.1242786472721491, 0.20251697598723695, 0.16329775156918913, 0.11795030950452201, 0.10450634887092747, 0.13872647396055982, 0.07636233523953706, 0.1087443386495579, 0.16948661010246724, 0.220821350812912, 0.11387893187929876, 0.1765900172176771, 0.08165460516465828, 0.17141914780950174, 0.14228483458282426, 0.14177695324178785, 0.2679578511742875, 0.22215320903342217, 0.11782861212850548], [0.061443552767741494, 0.0429832267400343, 0.0430742325988831, 0.041837243115878664, 0.0132956860215927, 0.07650449362699874, 0.027022648901038337, 0.03549560235114768, 0.06071009564038832, 0.037439999578054994, 0.004382635752335773, 0.024049221246968955, 0.03657852197648026, 0.02751459447608795, 0.10340546927182004, 0.03702043752127793, 0.024704186980670784, 0.03454012061411049, 0.04332721218816005, 0.05222752210102044, 0.04580935477861203, 0.01748774891893845, 0.030000182487128768, 0.08414713782258332, 0.024823190360621084, 0.045874541319790296, 0.05532093833608087, 0.07870269051636569, 0.0676502933492884, 0.04900654181255959, 0.10099137420183979, 0.07511318195611238, 1.0161301936022937, 8.778741136193275, 29.62630156427622, 42.252653539180756, 46.20746232569218, 32.52656243741512, 32.64788992702961, 34.03025954961777, 30.563867054879665, 31.64644606411457, 11.191956494003534, 4.35525837354362, 0.9409523557405919, 0.3144344635074958, 0.23547771357698366, 1.386906341649592, 3.2191468868404627, 4.909956883639097, 2.6528012892231345, 6.383678829297423, 3.661441490985453, 5.559937655925751, 7.100749751552939, 13.13840489834547, 23.36535282433033, 38.24647530913353, 48.64810936152935, 59.37799260020256, 57.29328006505966, 48.62244173884392, 47.02640578150749, 54.49604116380215, 50.44175751507282, 55.20860552787781, 52.08679184317589, 47.77729108929634, 47.447442188858986, 43.93723614513874, 39.727259650826454, 40.3435979783535, 40.80271974205971, 40.8973802626133, 37.99452982842922, 38.77037599682808, 37.87610538303852, 37.39237233996391, 38.86941768229008, 45.75821243226528, 46.115233674645424, 49.280463829636574, 47.782781794667244, 48.493598252534866, 45.65891236066818, 48.0598059296608, 49.59182672202587, 53.7476447224617, 43.113318756222725, 37.90500283241272, 51.45123794674873, 47.50128909945488, 45.49588970839977, 42.52779297530651, 46.19785264134407, 50.87473668158054, 51.99274688959122, 53.038754761219025, 52.259123995900154, 52.47690550982952, 51.86782859265804, 54.67014782130718, 50.20024247467518, 51.96161516010761, 50.585693791508675, 48.43747526407242, 46.351147815585136, 44.50255461037159, 45.7118359208107, 48.42349961400032, 53.92447963356972, 50.32620571553707, 50.44420078396797, 52.18187794089317, 52.907931581139565, 52.51614220440388, 56.8383152782917, 56.12369142472744, 55.59844180941582, 48.4980022162199, 34.23084698617458, 25.42212165892124, 21.417022570967674, 13.767786975950003, 7.541324235498905, 7.497837468981743, 5.006285039708018, 5.7350612338632345, 7.229585163295269, 4.541988428682089, 2.621586676687002, 1.836159797385335, 2.976395725272596, 0.7881037169136107, 0.09338462768937461, 0.03396493390027899, 1.7164370091632009, 6.674960274249315, 18.42061545699835, 21.471656039357185, 19.590673372149467, 22.323581725358963, 36.276554614305496, 41.7214572429657, 43.69719162583351, 25.89412473142147, 7.33071768656373, 0.45546641922555864, 0.029331590922083706, 0.02502712140994845, 0.026030306544271298, 0.01834446935390588, 0.025729809094627853, 0.01975923474674346, 0.03782787192903925, 0.03308230508991983, 0.041803954081842676, 0.006507469488497009, 0.06771411804948002, 0.026972609593940433, 0.02173896191379754, 0.048333380473195575, 0.06138976932561491, 0.0571729530201992, 0.10262343857903033, 0.03836917217995506, 0.10744385843281634, 0.030421213996305596, 0.037674210252589546, 0.05144319075043313, 0.048141449951799586, 0.055006954207783565, 0.006219241595317726, 0.013644802493217867, 0.04160542957833968, 0.03674677798699122, 0.011849118673126213, 0.07861211881390773, 0.05112998958793469, 0.03721490989846643, 0.019511160753609147, 0.033989150178967975, 0.06214349821675569, 0.07980751834111288, 0.0164233254690771, 0.07037718882202171, 0.09834426702582277, 0.0334185833344236, 0.034084686849382706, 0.008222508295148145, 0.01979466116608819, 0.0040425744100502925, 0.018077034583257046, 0.0539792948984541, 0.01042061427142471, 0.0740973450592719, 0.05334557128662709, 0.08763149890000932, 0.07352476328378543, 0.03558086769771762, 0.04698641583672725, 0.03792862218688242, 0.0402190160821192, 0.11508518160553649, 0.030838963357382454, 0.006883822779855109, 0.11112915599369444, 0.0639503457932733, 1.4936871430836618, 11.990252807736397, 37.62871965765953, 49.92348812520504, 51.85320697724819, 37.941811457276344, 34.96133118867874, 36.356490924954414, 31.770205423235893, 32.84185811877251, 11.416808478534222, 4.68027108348906, 0.7858547125943005, 0.21468451683176681, 0.6492962152697146, 1.3139655743725598, 2.9400423634797335, 5.929449778050184, 7.545659327879548, 5.868885302916169, 5.648476704955101, 5.691998619586229, 9.040878619998693, 15.068148449063301, 26.21468313038349, 39.21576909720898, 48.69779169559479, 57.15038873255253, 59.759609922766685, 52.987054735422134, 50.241116881370544, 54.82275903224945, 52.896706983447075, 55.09242296218872, 54.931737184524536, 51.02710850536823, 48.96738722920418, 44.556454718112946, 41.77603371441364, 42.42881968617439, 43.226776868104935, 42.82410107553005, 39.90244925022125, 40.40349796414375, 38.36406759917736, 38.74116696417332, 41.00141867995262, 46.616548374295235, 47.43396811187267, 50.429043397307396, 50.189538449048996, 50.71557082235813, 49.209179654717445, 51.00666180253029, 51.4554139226675, 55.60704454779625, 44.54388119280338, 40.40005914866924, 53.573735654354095, 49.17220003902912, 46.72792799770832, 46.191210597753525, 50.27321755886078, 53.35441902279854, 52.82655894756317, 53.90653319656849, 52.8046303242445, 53.355547562241554, 52.86801092326641, 53.79027843475342, 52.88144700229168, 52.261225283145905, 54.25763435661793, 49.87348660826683, 49.166990518569946, 48.26828934252262, 47.59376473724842, 51.35342739522457, 54.14258413016796, 52.06020846962929, 50.01472882926464, 52.827060520648956, 52.84804679453373, 52.51725174486637, 56.70692212879658, 55.77692583203316, 55.623744651675224, 50.51744185388088, 42.09110900759697, 31.21598806232214, 22.850322760641575, 12.978309988975525, 9.48224013671279, 5.85512101650238, 6.944068958982825, 6.237314958125353, 11.745672281831503, 7.8994132205843925, 5.8088447246700525, 5.9458796214312315, 2.5616978527978063, 1.07135274913162, 0.3614359226776287, 0.2694515569601208, 1.8245344399474561, 8.22136614471674, 18.334369584918022, 27.8040599450469, 25.11657055467367, 27.000942640006542, 43.335055857896805, 47.0203261077404, 51.292041689157486, 30.202362053096294, 8.41256333515048, 0.7299072272144258, 0.0342547499894863, 0.040572857251390815, 0.007226717270896188, 0.0402814715198474, 0.0336962949950248, 0.028266768567846157, 0.0315302664967021, 0.06530864673550241, 0.021989794840919785, 0.045145885887905024, 0.041612272179918364, 0.03585631951864343, 0.05780052793852519, 0.018661583490029443, 0.02302156379300868, 0.04165983642451465, 0.024718152344576083, 0.039608124643564224, 0.07518044280004688, 0.040615215330035426, 0.058854462986346334, 0.036325234395917505, 0.0900356937199831, 0.0484644623065833, 0.04182171367574483, 0.024229848859249614, 0.03842071062535979, 0.07900657030404545, 0.1248711853986606, 0.12774207978509367, 0.1899226408568211, 0.14603606454329565, 0.11628458873019554, 0.10632054370944388, 0.16388194053433836, 0.15318100224249065, 0.1090095451218076, 0.16804865445010364, 0.13531657255953178, 0.11120231691165827, 0.13781354326056316, 0.1287509553367272, 0.27647105685900897, 0.10891680634813383, 0.14589829224860296, 0.18111425335519016, 0.07810279770637862, 0.12026699027046561, 0.1259522867621854, 0.18675824190722778, 0.17584074492333457, 0.21085280837723985, 0.2005393008585088, 0.0995729592978023, 0.11862060244311579, 0.23222888790769503, 0.13471056445268914, 0.1310924460995011, 0.3082223905948922, 0.22859516961034387, 1.7227248405106366, 13.954400662332773, 41.31147064268589, 57.68109105527401, 58.08921955525875, 44.84350651502609, 43.6412700265646, 43.128221556544304, 39.710745736956596, 39.25183676183224, 14.798254631459713, 5.4161405470222235, 1.526363727170974, 0.7722878374624997, 1.580329262651503, 5.228033065795898, 7.005553459748626, 13.391173034906387, 10.080979708582163, 13.255915492773056, 8.202330116182566, 9.787726644426584, 12.550868075340986, 18.665050640702248, 27.782359309494495, 42.29440949857235, 50.97106531262398, 60.93937061727047, 61.75873205065727, 55.98831228911877, 51.6414899379015, 55.53075984120369, 50.1086749881506, 56.1003340780735, 56.253249272704124, 51.812864542007446, 51.03661559522152, 46.247721165418625, 43.796153515577316, 44.472365230321884, 44.705509319901466, 45.81574134528637, 42.16624237596989, 41.01950190961361, 40.63191890716553, 40.73812320828438, 42.805041298270226, 48.13228704035282, 50.70116959512234, 52.74925969541073, 52.925555035471916, 52.17900149524212, 50.608811751008034, 51.92468114197254, 53.34754899144173, 55.03411129117012, 46.806591376662254, 43.96029710769653, 55.176824033260345, 52.171185314655304, 48.67150850594044, 47.82477714121342, 52.030133083462715, 56.15179851651192, 55.73407173156738, 56.862105801701546, 55.052175521850586, 54.835590943694115, 52.983840107917786, 55.49917213618755, 54.18424889445305, 54.65449646115303, 56.13559998571873, 52.68761560320854, 50.812970995903015, 50.08171163499355, 49.24649365246296, 54.15416970849037, 56.23151823878288, 52.79712192714214, 50.39379268884659, 54.186509773135185, 53.63403461873531, 53.43958005309105, 58.979542180895805, 56.28090798854828, 56.61320775747299, 53.14273618161678, 45.25852404534817, 32.7103927731514, 27.059693187475204, 17.746835611760616, 10.809339825063944, 12.609758265316486, 10.40710860863328, 12.690413687378168, 17.391554675996304, 12.53209613263607, 12.810454946011305, 8.86754522100091, 6.959226820617914, 2.751850811764598, 1.0718671465292573, 0.48286695673596114, 2.5240242993459105, 9.712679721415043, 24.102289080619812, 30.232950411736965, 31.236332170665264, 33.5952664911747, 51.38650842010975, 55.04461772739887, 54.50195364654064, 36.00769244134426, 10.859038308262825, 0.8397485269233584, 0.10459932513185777, 0.08271727157989517, 0.13556164456531405, 0.08491581727867015, 0.18700746993999928, 0.1316563002183102, 0.11062414676416665, 0.0970530191261787, 0.17253486294066533, 0.1387597667053342, 0.13726989040151238, 0.0981658992532175, 0.12326185300480574, 0.15963286306941882, 0.16127520619193092, 0.18023618875304237, 0.17084727849578485, 0.18846384569769725, 0.21804338815854862, 0.15057630138471723, 0.12468708824599162, 0.17789129895390943, 0.23202409967780113, 0.13779265922494233, 0.19949604902649298, 0.10842582370969467, 0.08499006173224188, 0.1544359145918861], [0.06153964604891371, 0.05811596296553034, 0.04890944292128552, 0.06368985938024707, 0.10021310619777068, 0.01541792966236244, 0.009555894412187627, 0.016500737037858926, 0.0704119807051029, 0.10062396657303907, 0.04599214575137012, 0.09592545189661905, 0.04244804920745082, 0.034501072514103726, 0.04953852068865672, 0.0929698784602806, 0.03838267926767003, 0.07211978867417201, 0.02625701410579495, 0.0834686664165929, 0.05169106436369475, 0.08543026662664488, 0.03809282978181727, 0.06804887860198505, 0.028788648669433314, 0.04101254635315854, 0.09002878432511352, 0.07501435015001334, 0.1070511584111955, 0.10964035580400378, 0.03160391723213252, 0.08397988742217422, 0.1472518508671783, 6.080590467900038, 19.808187000453472, 42.35340893268585, 48.8422067463398, 36.63267910480499, 45.52719242870808, 35.87054640054703, 35.50285913050175, 26.197378858923912, 12.515352331101894, 6.016143076121807, 1.0157639882527292, 0.5309972818940878, 0.24568105669459328, 1.2937791575677693, 1.998168141581118, 3.2145298970863223, 4.721781006082892, 4.965709866955876, 3.8222804479300976, 4.844391876831651, 7.341434061527252, 12.735377624630928, 24.608057141304016, 37.743006125092506, 49.282857701182365, 48.75507742166519, 47.89674907922745, 48.709555864334106, 53.12494173645973, 55.90486876666546, 52.91726008057594, 53.778107687830925, 51.681851372122765, 51.43705330789089, 48.28581400215626, 45.0180159509182, 41.1865409463644, 41.98484770953655, 40.11585719883442, 38.96674565970898, 40.04960015416145, 37.872833758592606, 37.693825364112854, 43.946534246206284, 48.42198729515076, 50.223983600735664, 48.72053347527981, 49.56356763839722, 49.377689212560654, 50.97584925591946, 50.71759231388569, 53.51376347243786, 49.260887280106544, 52.26995341479778, 42.092579528689384, 34.636600613594055, 55.48425793647766, 47.36811384558678, 46.32039226591587, 42.8593859821558, 42.46823117136955, 44.82462912797928, 47.87464566528797, 49.98689912259579, 50.754514932632446, 50.506426244974136, 50.554052889347076, 50.41985169053078, 49.998963475227356, 49.916580095887184, 45.60814328491688, 45.9302482008934, 44.61168475449085, 42.22875662147999, 45.87273448705673, 48.29122871160507, 50.470366179943085, 51.562750563025475, 49.632218554615974, 51.642732471227646, 52.48584643006325, 54.719792157411575, 54.428879767656326, 54.63853731751442, 55.743651017546654, 52.04592123627663, 44.712523743510246, 27.593629136681557, 15.955064557492733, 12.904121819883585, 7.821545898914337, 3.0681617511436343, 5.783167602494359, 8.389583118259907, 10.717218518257141, 4.934757202863693, 2.8403791738674045, 5.140397418290377, 3.059130823239684, 1.339987290557474, 0.17698267271043733, 0.4051036841701716, 1.8347384361550212, 10.491216145455837, 23.270266726613045, 26.693009063601494, 39.526687413454056, 34.65487003326416, 41.1438350379467, 41.772484704852104, 36.901735067367554, 16.290083080530167, 4.565901970490813, 0.07470662603736855, 0.03169984353007749, 0.0484980593319051, 0.04943067178828642, 0.03736575883522164, 0.04616561534930952, 0.053954948743921705, 0.06864359122118913, 0.01968100681551732, 0.04403733619255945, 0.028839591541327536, 0.022777280319132842, 0.010226609447272494, 0.03046178535441868, 0.05685183314199094, 0.009164982966467505, 0.024012783651414793, 0.08086446279776283, 0.03135520870273467, 0.034329083500779234, 0.06329367868602276, 0.021374396710598376, 0.04832575490581803, 0.01693198792054318, 0.027034434206143487, 0.04595857099047862, 0.032459947469760664, 0.052001144795212895, 0.10152007278520614, 0.047925818944349885, 0.05221793726377655, 0.03789601963944733, 0.06200130643264856, 0.012186682688479777, 0.07033203655737452, 0.026438497043272946, 0.09670013532740995, 0.03343477328598965, 0.06955284086870961, 0.028667224032687955, 0.04991881571186241, 0.028318429467617534, 0.05893382825888693, 0.059215818400844, 0.07126854528905824, 0.01654789681197144, 0.013131501618772745, 0.01406077997671673, 0.04764074146805797, 0.029881724585720804, 0.08281706817797385, 0.06186495906149503, 0.033878006142913364, 0.012328721404628595, 0.03699456625327002, 0.09661192365456372, 0.0369781499466626, 0.08708947876584716, 0.031173953975667246, 0.050667616742430255, 0.0625693573965691, 0.4123940382851288, 8.199589513242245, 24.39462449401617, 48.1206900626421, 55.03173641860485, 39.605544582009315, 46.96477688848972, 39.38595436513424, 36.6500099748373, 36.333733946084976, 15.185242015868425, 6.701195491477847, 0.9691297437530011, 0.6136980629526079, 0.11822854066849686, 1.219338895753026, 4.421464120969176, 6.374043021351099, 6.237663114443421, 6.52722705155611, 5.774119812995195, 6.355771226808429, 7.372932946309447, 14.31576032191515, 24.209044352173805, 40.49680195748806, 51.13731399178505, 54.71954517066479, 53.82571153342724, 51.81382209062576, 53.2520867139101, 55.442843958735466, 53.20155322551727, 56.87521129846573, 54.007767364382744, 53.33606220781803, 50.205417796969414, 47.53868289291859, 43.12181130051613, 42.651681527495384, 40.262643322348595, 40.436909571290016, 40.15224404633045, 40.038394555449486, 40.39439745247364, 44.78776350617409, 48.1790055334568, 52.934222370386124, 51.960691809654236, 51.217694878578186, 51.851014494895935, 52.6406729221344, 51.58103518188, 54.39664609730244, 51.03418752551079, 51.91575162112713, 44.15840707719326, 38.93141135573387, 55.93098856508732, 49.83047291636467, 47.64573834836483, 44.869105741381645, 45.85433967411518, 47.66639783978462, 50.92587813735008, 52.72207595407963, 53.58443967998028, 52.978497594594955, 52.67911545932293, 53.10376547276974, 52.621810734272, 51.646893247962, 47.42432422935963, 48.15215617418289, 46.458131074905396, 43.8368721306324, 48.11333745718002, 50.564711317420006, 53.60319547355175, 50.967212319374084, 51.01934552192688, 51.69221721589565, 52.56783463060856, 55.38875386118889, 55.64232565462589, 55.39131112396717, 55.23311421275139, 54.30938757956028, 44.056314155459404, 29.70608588308096, 19.366411305963993, 13.524469882249832, 5.816641906276345, 4.934498341754079, 7.250266503542662, 7.350661866366863, 8.988147899508476, 6.76307232119143, 4.783454546704888, 5.061893155798316, 2.5101431692019105, 0.710177676519379, 0.23213800450321287, 0.2502203139010817, 2.364116767421365, 11.137735303491354, 24.333639666438103, 32.5016737729311, 35.48123449087143, 33.983309268951416, 45.38239359855652, 48.55544753372669, 43.202868551015854, 21.068440675735474, 6.50143688544631, 0.3658116847509518, 0.11312044211081229, 0.05234251788351685, 0.025050374752026983, 0.03704263886902481, 0.015858417500567157, 0.01764137534337351, 0.06299498651060276, 0.04111525217012968, 0.06905745729454793, 0.0666934423497878, 0.02590693191450555, 0.038441397991846316, 0.07034904658212326, 0.11647384380921721, 0.07050712403724901, 0.046197639021556824, 0.08200284311897121, 0.007020705888862722, 0.030407634549192153, 0.02752947639237391, 0.09734252351336181, 0.03713963014888577, 0.04544811439700425, 0.019166841339028906, 0.06216795569343958, 0.05103577394038439, 0.02888212588004535, 0.03417535132030025, 0.13540588261093944, 0.11890937952557579, 0.26377196016255766, 0.14397788123460487, 0.17001221393002197, 0.20627222838811576, 0.1590054514235817, 0.17445658013457432, 0.11832217001938261, 0.15745390264783055, 0.17155589594040066, 0.1985492170206271, 0.08418984842137434, 0.11438197441748343, 0.1175813507870771, 0.14942502253688872, 0.10745673469500616, 0.13130768376868218, 0.17283589288126677, 0.17625572421820834, 0.19601353589678183, 0.24366936151636764, 0.1957506820326671, 0.08116499549942091, 0.05682487833837513, 0.1383998547680676, 0.18684326234506443, 0.17251719982596114, 0.18417375715216622, 0.18139632884413004, 0.11435496766353026, 0.19757295143790543, 0.4726055479841307, 9.34409474954009, 29.83906164765358, 55.298934280872345, 63.0172473192215, 49.963066801428795, 58.05960774421692, 45.129524767398834, 45.493241250514984, 35.48552826046944, 16.038853861391544, 7.477522334083915, 1.3525211554951966, 0.7595256878994405, 0.8233720588032156, 4.077723640948534, 8.554897047579288, 11.604300867766142, 13.532586246728897, 11.811864729970694, 12.080246228724718, 11.99575301259756, 11.360586695373058, 16.95719998329878, 29.96111109852791, 47.817667722702026, 53.739672750234604, 57.85125732421875, 57.46250778436661, 54.73573990166187, 54.37484286725521, 56.341807320714, 53.157779574394226, 59.09133978188038, 55.753127709031105, 56.417670249938965, 52.48521946370602, 49.78800259530544, 44.469294995069504, 44.433512315154076, 42.26628340780735, 42.32689395546913, 43.18674981594086, 41.88160724937916, 41.034317314624786, 47.24685475230217, 51.74778923392296, 54.39356826245785, 53.23722571134567, 54.144628420472145, 55.49061879515648, 54.370507299900055, 53.49338136613369, 54.964134246110916, 51.91126026213169, 50.260917618870735, 46.06424421072006, 40.97811833024025, 59.13813427090645, 50.7897162437439, 49.56534594297409, 47.569860219955444, 47.335295006632805, 48.55084978044033, 52.511175870895386, 55.4186050593853, 54.67386022210121, 55.18229193985462, 55.4144024848938, 55.337601006031036, 54.933880269527435, 54.50834110379219, 50.42889140546322, 50.66509053111076, 48.95639821887016, 45.80343380570412, 49.98483203351498, 52.67289899289608, 55.243616849184036, 51.4429771900177, 49.607436284422874, 51.20386362075806, 52.67301678657532, 56.53501935303211, 55.67567266523838, 57.454676404595375, 58.92270103096962, 55.526572465896606, 48.190275728702545, 34.047810807824135, 22.81952541321516, 17.512836568057537, 12.03968245536089, 7.193116145208478, 11.640676315873861, 18.072886615991592, 19.09986700862646, 12.632952220737934, 11.764957197010517, 13.853996749967337, 8.552147895097733, 3.5472970409318805, 0.6224130734335631, 1.0641849087551236, 2.764501520432532, 13.331870567053556, 30.081864818930626, 39.83790211379528, 53.195663541555405, 46.05974145233631, 55.08112616837025, 56.21262565255165, 48.46647150814533, 23.298976086080074, 7.132925949990749, 0.43161391164176166, 0.17824419017415494, 0.1644508115714416, 0.11901448990101926, 0.10210271808318794, 0.10155021882383153, 0.09711084727314301, 0.1731272303732112, 0.1483778521651402, 0.17412583460099995, 0.16872390493517742, 0.16338664601789787, 0.13200059736846015, 0.15978264331351966, 0.23761024523992091, 0.21967988315736875, 0.1075555442366749, 0.24704427807591856, 0.12085225534974597, 0.10055249033030123, 0.13034167466685176, 0.11540267238160595, 0.14121292100753635, 0.14696870668558404, 0.12764653569320217, 0.1781571510946378, 0.18388951459201053, 0.18123713816748932, 0.278770467848517], [0.03334708853799384, 0.12200832847156562, 0.017577828948560636, 0.045939033952890895, 0.02091011469019577, 0.01738572958856821, 0.04725149614387192, 0.040839577704900876, 0.01798610664991429, 0.04864230315433815, 0.023544670293631498, 0.030461961614491884, 0.06296823208685964, 0.014225445847841911, 0.07778854269417934, 0.016698868203093298, 0.047735138941789046, 0.021650243725162, 0.02420403696305584, 0.04525377931713592, 0.030093845234659966, 0.0626749056391418, 0.06294829800026491, 0.08682626124937087, 0.01612311931239674, 0.06189313098730054, 0.08101407234789804, 0.007235125804072595, 0.054254327405942604, 0.01115607798055862, 0.02867419651011005, 0.18494478921638802, 0.1419578294735402, 3.3692908426746726, 20.03457125276327, 38.4923031181097, 47.137998193502426, 43.404120951890945, 37.571878507733345, 28.894249945878983, 22.020131908357143, 25.939215011894703, 19.577448181807995, 10.731013678014278, 2.0200309809297323, 0.4196084855357185, 0.1324945263331756, 0.47297050652559847, 2.8283440321683884, 4.304125467315316, 5.925703654065728, 3.789047193713486, 4.101183107122779, 3.945812056772411, 5.050388323143125, 11.702593993395567, 20.754683911800385, 29.318571276962757, 34.279358983039856, 38.59750047326088, 57.1683693677187, 45.05772762000561, 56.963985934853554, 54.073815420269966, 55.291543677449226, 55.7358880341053, 52.62902274727821, 48.5331617295742, 47.964533641934395, 43.62049654126167, 41.93420022726059, 40.907582715153694, 40.46688616275787, 38.88337813317776, 40.94661422073841, 39.41759146749973, 43.71992200613022, 50.67779324948788, 50.69260485470295, 53.71893346309662, 51.996664479374886, 51.926588639616966, 50.85176311433315, 54.10386420786381, 49.92368571460247, 47.333794087171555, 45.50361469388008, 57.80822083353996, 41.44475609064102, 35.30540652573109, 53.97303722798824, 47.29066640138626, 49.03166078031063, 42.667245492339134, 40.30922122299671, 38.15083064138889, 41.155424416065216, 44.29044619202614, 46.04836866259575, 47.904208078980446, 50.83042345941067, 48.79119448363781, 46.950535252690315, 46.276018247008324, 42.72622212767601, 41.35758496820927, 39.69905376434326, 42.9240433126688, 47.63581708073616, 48.25138404965401, 52.99925208091736, 51.90919317305088, 52.02220670878887, 49.84504133462906, 50.336928740143776, 53.7812577188015, 54.46656234562397, 54.43312793970108, 55.544108524918556, 51.769748255610466, 43.19859378039837, 33.6248555034399, 18.7093448638916, 8.17617516964674, 5.0675206538289785, 1.8895770935341716, 4.39260134473443, 1.9842927111312747, 7.82431785017252, 5.9006682224571705, 3.3536656061187387, 4.481457676738501, 0.37235766474623233, 0.42739189288113266, 0.15657119220122695, 0.6828466337174177, 3.1283635832369328, 13.446968290954828, 21.45030878484249, 23.016126863658428, 28.53610396385193, 36.082738414406776, 37.92696185410023, 43.50207209587097, 36.025110706686974, 11.314435321837664, 2.9322135960683227, 0.051133117740391754, 0.04440073993464466, 0.09021789097459987, 0.017940826364792883, 0.04398601296998095, 0.09639494193834253, 0.04974616247636732, 0.033021719864336774, 0.031167942579486407, 0.024433347607555334, 0.00884353561559692, 0.033655046427156776, 0.06809087673900649, 0.03090082507696934, 0.099698337726295, 0.038235362953855656, 0.04645909393730108, 0.01610946565051563, 0.05834776537085418, 0.03626269732194487, 0.015197946886473801, 0.04058778926264495, 0.02658095971128205, 0.04956423239491414, 0.037509464600589126, 0.01990590724744834, 0.01815883966628462, 0.08470627930364572, 0.09075262321857736, 0.03476128804322798, 0.06145726394606754, 0.007565195055576623, 0.020897602080367506, 0.03587951905501541, 0.04678759076341521, 0.06166500963445287, 0.04224103453452699, 0.021456893846334424, 0.0632437840977218, 0.034565750684123486, 0.04006774783192668, 0.08018039559829049, 0.037217307035462, 0.019558188796509057, 0.033078330889111385, 0.017833092497312464, 0.007489112394978292, 0.019786380653386004, 0.06311512537649833, 0.04707091306045186, 0.024983965522551443, 0.06277895474340767, 0.06715208961395547, 0.059921675056102686, 0.018999147505383007, 0.0699483387870714, 0.008231719275499927, 0.042509035192779265, 0.03426233844948001, 0.033807157014962286, 0.05897822353290394, 0.12253679698915221, 4.774652794003487, 23.7984174862504, 44.761202931404114, 53.61726991832256, 47.43877865374088, 45.85552521049976, 32.70465508103371, 28.620315045118332, 24.929358400404453, 18.485723063349724, 9.236426576972008, 1.9465816346928477, 0.200147298455704, 0.2221591759007424, 1.3410094357095659, 3.9018624275922775, 5.896097542718053, 8.36899297311902, 4.8164082784205675, 3.320073508657515, 2.786360322497785, 4.4327998626977205, 11.877808291465044, 22.03788075596094, 35.38166843354702, 42.15063661336899, 46.961767449975014, 55.99377639591694, 49.461546912789345, 57.97374755144119, 54.72349315881729, 54.773825258016586, 55.15925757586956, 54.679419323801994, 51.6184251755476, 49.35514122247696, 44.9798583984375, 44.156431183218956, 43.24335537850857, 42.312371134757996, 42.4486318230629, 42.078508883714676, 41.29949368536472, 44.8300514370203, 52.15962253510952, 54.272373765707016, 55.06887562572956, 53.876336216926575, 53.55091027915478, 53.20180021226406, 55.35295218229294, 49.47030544281006, 48.7171820551157, 46.906750202178955, 56.66424281895161, 45.33688344061375, 37.177554666996, 55.48134349286556, 49.11282442510128, 48.927458971738815, 45.48709698021412, 41.68766185641289, 41.6405975818634, 44.42837879061699, 47.10243210196495, 48.439257368445396, 51.00421853363514, 52.57409669458866, 51.75790049135685, 49.67742472887039, 48.401798978447914, 44.906039759516716, 44.624600261449814, 41.644826754927635, 45.246258303523064, 48.70787255465984, 51.216672733426094, 54.17832501232624, 51.321281120181084, 51.595698595047, 50.577034056186676, 52.131492644548416, 54.88884128630161, 56.13332010805607, 56.02763257920742, 56.09085738658905, 52.66918659210205, 44.73620027303696, 34.56583321094513, 22.002149373292923, 12.46267195791006, 7.335432758554816, 3.1900200247764587, 7.05543290823698, 7.4204460717737675, 9.002263192087412, 8.529933337122202, 3.7912805238738656, 4.368435591459274, 2.3719585966318846, 0.7406406418886036, 0.28057174931745976, 0.7857010583393276, 4.027875065803528, 12.783634085208178, 27.561634853482246, 27.856540828943253, 36.39894224703312, 39.55105550587177, 43.87917906045914, 49.45731393992901, 41.41874648630619, 13.911010790616274, 3.326326785609126, 0.028602855709323194, 0.08998575460282154, 0.05625534678983968, 0.04118336277315393, 0.029419383281492628, 0.062139694709912874, 0.023841542351874523, 0.024558690784033388, 0.033299698698101565, 0.04435323877260089, 0.0023427092764904955, 0.014780516648897901, 0.01963544636964798, 0.019321623658470344, 0.07291666232049465, 0.013066303017694736, 0.009790590265765786, 0.008607707059127279, 0.05437316380266566, 0.03271361725637689, 0.0177384259950486, 0.023606199902133085, 0.02843733451300068, 0.047883876468404196, 0.0068037223172723316, 0.06223820739251096, 0.0389985727815656, 0.029164032530388795, 0.11193633064976893, 0.20388941484270617, 0.168191681150347, 0.17518440436106175, 0.15027776506030932, 0.10387717833509669, 0.12521144526544958, 0.11251457501202822, 0.15623523679096252, 0.10385143323219381, 0.18035767832770944, 0.08658417267724872, 0.15853807650273666, 0.14021189737832174, 0.17097860894864425, 0.22298386524198577, 0.1571430021431297, 0.1484063803218305, 0.15422288852278143, 0.1477584705571644, 0.2213402307825163, 0.2129802043782547, 0.2370281342882663, 0.11029019515262917, 0.16443473665276542, 0.12386777205392718, 0.11022324601071887, 0.12591369508299977, 0.15005712455604225, 0.2526864706305787, 0.12238866431289352, 0.08508574683219194, 0.26621380413416773, 0.2627665875479579, 5.082252938300371, 26.134988106787205, 49.52662982046604, 60.22061638534069, 54.47906747460365, 49.44086082279682, 39.14999462664127, 35.202219262719154, 35.62286429107189, 24.602492339909077, 13.384605087339878, 2.3875914327800274, 0.8194913389161229, 0.5808849236927927, 1.9762500864453614, 6.440799264237285, 9.192899912595749, 13.12145495787263, 9.642357844859362, 9.401378575712442, 7.174117639660835, 10.055557172745466, 15.095577277243137, 26.599676571786404, 38.06950740516186, 47.650586888194084, 48.41935783624649, 60.2779059112072, 47.72476650774479, 58.628551214933395, 55.339253917336464, 55.065767392516136, 58.48743058741093, 55.7412875443697, 53.60679388046265, 51.5806970000267, 46.19577795267105, 45.12439504265785, 44.149792939424515, 43.23150761425495, 43.087825924158096, 44.248595237731934, 42.80876509845257, 47.60537311434746, 55.57589761912823, 55.09915620088577, 57.42870479822159, 57.04932935535908, 55.068389251828194, 53.343714997172356, 57.74039827287197, 50.323868840932846, 49.14704158902168, 48.77483256161213, 57.8038814663887, 48.44263918697834, 40.40204644203186, 55.50656273961067, 50.74459366500378, 52.85969316959381, 47.79976308345795, 44.10904012620449, 42.03514561057091, 45.002269595861435, 48.37815664708614, 49.34146195650101, 52.259492576122284, 55.10450631380081, 54.459468126297, 51.834139600396156, 49.24307383596897, 47.06127271056175, 45.90030960738659, 43.68960343301296, 47.23721846938133, 51.37061767280102, 52.10520565509796, 57.08834946155548, 51.68307110667229, 52.48209983110428, 52.96037256717682, 51.358044147491455, 55.625975131988525, 58.30032102763653, 57.04846300184727, 58.99538353085518, 56.20947182178497, 46.57649852335453, 37.106167897582054, 23.287947177886963, 12.276536095887423, 7.910735188052058, 5.556360147893429, 11.27114424481988, 8.910103887319565, 18.362410180270672, 15.580864436924458, 8.864310644567013, 8.559255413711071, 3.8368248799815774, 1.9652543077245355, 0.7839698356110603, 1.1282226350158453, 4.706873456016183, 16.724456772208214, 30.698410235345364, 34.36402224004269, 42.26419351994991, 48.615374118089676, 49.40667025744915, 58.863177224993706, 47.70870856940746, 17.628967836499214, 4.369710423052311, 0.15714790031779557, 0.17928589833900332, 0.13442555005894974, 0.23450585635146126, 0.12341648689471185, 0.1374594052322209, 0.1348430081270635, 0.12210653687361628, 0.11033823437173851, 0.0891025469172746, 0.1324223302071914, 0.16094235295895487, 0.12083663314115256, 0.12347211086307652, 0.1696031866595149, 0.05300612036080565, 0.0665806359029375, 0.08219670693506487, 0.1551393370027654, 0.16876764711923897, 0.07395642605843022, 0.1051907945657149, 0.07057779133901931, 0.22466910450020805, 0.12175747513538226, 0.1689367974177003, 0.10340863824239932, 0.20917009242111817, 0.20066326920641586], [0.06435529867303558, 0.07011077264905907, 0.06698083161609247, 0.023224836186273023, 0.0548018283006968, 0.049209715871256776, 0.07535405340604484, 0.1171758932468947, 0.052389818665687926, 0.017009273324219976, 0.058664265379775316, 0.029123830390744843, 0.0593404658138752, 0.024918350391089916, 0.029251212617964484, 0.052867208869429305, 0.03598329356464092, 0.059267256656312384, 0.1250729605089873, 0.07129923309548758, 0.016591705789323896, 0.07805444678524509, 0.018028524100373033, 0.06675984972389415, 0.043470747259561904, 0.04077375662745908, 0.07017335054115392, 0.07175940918386914, 0.016446627050754614, 0.04099973688425962, 0.08374630386242643, 0.029113943128322717, 0.10057556370156817, 1.5413342113606632, 15.647448264062405, 37.321878522634506, 52.85154640674591, 49.37908373773098, 41.864994540810585, 40.23784965276718, 49.651616513729095, 63.202684968709946, 39.770246744155884, 15.336929876357317, 4.195389077067375, 0.4137400566833094, 0.3641626622993499, 1.0357123240828514, 3.3079079864546657, 3.9914198219776154, 4.674405148252845, 7.361890263855457, 3.179216729477048, 2.9097432643175125, 5.156040703877807, 12.611928898841143, 16.379269994795322, 29.115432277321815, 37.973471358418465, 38.362091705203056, 59.338121339678764, 49.819776490330696, 54.0295097976923, 56.329533979296684, 50.786448419094086, 54.29948531091213, 50.15662081539631, 50.48725247383118, 43.14269118010998, 45.56000366806984, 41.93293869495392, 44.34501126408577, 43.13873179256916, 42.273465022444725, 44.76517751812935, 43.706045150756836, 44.84408788383007, 50.58487303555012, 52.92800970375538, 55.63547842204571, 51.272746324539185, 51.268467754125595, 49.63286451995373, 52.91423924267292, 51.28503866493702, 53.701815381646156, 37.45602272450924, 43.28130014240742, 32.39141508936882, 32.94525817036629, 55.24680107831955, 47.833421677351, 48.94668594002724, 44.42953012883663, 42.2935925424099, 38.03704954683781, 37.27459765970707, 37.27253437042236, 40.029723420739174, 40.11246778070927, 42.74865232408047, 40.94730578362942, 39.30871590971947, 38.76537926495075, 38.591143414378166, 37.631698697805405, 38.84220354259014, 42.88234055042267, 48.67138311266899, 51.35598845779896, 54.654697850346565, 50.30786789953709, 48.098092675209045, 53.42982977628708, 52.98382110893726, 53.06705184280872, 55.97138039767742, 53.32095421850681, 53.45121502876282, 52.96041816473007, 42.94857859611511, 31.964124217629433, 20.14865443110466, 12.512604128569365, 5.094248419627547, 2.7177559537813067, 5.396636193618178, 7.406720733270049, 6.259903321042657, 5.25663080625236, 3.9101208094507456, 3.5374225582927465, 1.5224257134832442, 0.3393600572599098, 0.21039050974650308, 0.7538182160351425, 4.510464845225215, 17.50699818134308, 22.166013680398464, 25.38350623100996, 30.725905559957027, 32.93707720935345, 45.22462606430054, 37.36364208161831, 32.02607989311218, 9.739452134817839, 2.7664104430004954, 0.08586983327404596, 0.06741933699231595, 0.04439407915924676, 0.09646144579164684, 0.05013695146772079, 0.08564510353608057, 0.07317814321140759, 0.06269740013522096, 0.013410576048045186, 0.02944341402326245, 0.03998622662038542, 0.05615631089312956, 0.03136027757136617, 0.0629278740962036, 0.03495526689221151, 0.03174485478666611, 0.05718776257708669, 0.041302373574581, 0.041637026515672915, 0.06616577535169199, 0.02790188795188442, 0.03839188189886045, 0.027199543510505464, 0.024829136818880215, 0.00659430818814144, 0.06264835901674815, 0.03508209621941205, 0.07100249276845716, 0.04747227023472078, 0.023033677498460747, 0.0407747473946074, 0.06060457708372269, 0.021003135479986668, 0.0218733778456226, 0.027705107495421544, 0.035582763885031454, 0.08860898902639747, 0.12387523063807748, 0.04675783435232006, 0.03622710020863451, 0.01983405807550298, 0.0874039415793959, 0.0407010706840083, 0.029164594707253855, 0.030896633797965478, 0.0966141872049775, 0.08044782109209336, 0.057768994083744474, 0.02635636912600603, 0.020079055866517592, 0.06681641621980816, 0.03161615153658204, 0.033569205916137435, 0.015204633637040388, 0.0538968088949332, 0.015787303054821678, 0.056748871284071356, 0.015232468813337618, 0.02423142777843168, 0.060776766476919875, 0.03079390386119485, 0.16683004796504974, 2.6676126569509506, 18.671477995812893, 42.33500272035599, 58.90617571771145, 55.25236018002033, 42.40270368754864, 40.10575354099274, 39.83567923307419, 53.08408632874489, 34.562880769371986, 15.92506231740117, 3.635422387160361, 0.6492949090898037, 0.14494788309093565, 0.7932733988855034, 4.197578709572554, 6.348265679553151, 8.73999746516347, 7.319266526028514, 4.518070612102747, 3.2689769379794598, 5.753957144916058, 13.047785460948944, 23.495948016643524, 34.03422273695469, 40.49755811691284, 44.13688123226166, 59.86038811504841, 52.410116493701935, 56.51086404919624, 55.98587282001972, 53.15201908349991, 56.06995850801468, 52.93135352432728, 51.032485216856, 46.430973932147026, 45.86799994111061, 44.77809302508831, 45.44682294130325, 44.662134647369385, 43.47793199121952, 46.198027431964874, 43.80760230123997, 47.47748717665672, 52.30777658522129, 54.15656358003616, 56.06025002896786, 54.22352738678455, 53.44315946102142, 52.9031628370285, 55.17886072397232, 52.36294962465763, 54.647075459361076, 42.99315020442009, 46.451158449053764, 35.36211848258972, 37.25805714726448, 55.36451496183872, 50.77657274901867, 50.45148879289627, 47.517723217606544, 44.96331788599491, 39.371157959103584, 39.84840475022793, 39.49522890150547, 42.36034736037254, 43.0524118244648, 46.590804755687714, 44.432474970817566, 43.57714846730232, 41.05483241379261, 39.82318550348282, 40.854837745428085, 40.75081832706928, 45.39880491793156, 50.69536730647087, 53.76226633787155, 55.0762852281332, 50.89276671409607, 49.09666769206524, 54.64679427444935, 53.36134225130081, 53.09969589114189, 57.287641167640686, 54.85664561390877, 55.64582146704197, 54.76074256002903, 43.63971970975399, 33.31775598227978, 22.564101219177246, 12.463803347200155, 3.818599870428443, 4.318976970389485, 6.222434006631374, 9.936364218592644, 9.55467564985156, 7.45155880227685, 4.401802076026797, 4.380139438435435, 2.093026489019394, 0.520385104464367, 0.30231231241486967, 0.9084155329037458, 4.643514230847359, 18.820714987814426, 27.47043214738369, 27.042064033448696, 31.813475601375103, 38.15618075430393, 47.654257491230965, 43.75405557453632, 38.17104175686836, 11.815812718123198, 3.6808985844254494, 0.06313015386695042, 0.037914443455520086, 0.060561617865459993, 0.014890876791469054, 0.051072962960461155, 0.04244473922881298, 0.04736571267130785, 0.017756356282916386, 0.03605570120271295, 0.03260589081037324, 0.01947118125826819, 0.06356390207656659, 0.024879101911210455, 0.03855570357700344, 0.02463057891873177, 0.058504143307800405, 0.06323674111627042, 0.05227374676906038, 0.0368529496336123, 0.06026331160683185, 0.022002771293045953, 0.015362116446340224, 0.03670199679618236, 0.014425337758439127, 0.10373939119745046, 0.0518788203044096, 0.018934022191388067, 0.0492923948331736, 0.033325187760055996, 0.21780376351671293, 0.29971639858558774, 0.17068788001779467, 0.074943779327441, 0.14509030123008415, 0.10842549716471694, 0.09608416759874672, 0.23243176139658317, 0.25103632011450827, 0.12720366648864, 0.11557022706256248, 0.1111231891263742, 0.25712439499329776, 0.10811930929776281, 0.15971822489518672, 0.13679871568456292, 0.14894019230268896, 0.13581446459284052, 0.14531337597873062, 0.19270505639724433, 0.12563993164803833, 0.12662712164456025, 0.18285608879523352, 0.2737821073969826, 0.14837863884167746, 0.11457455431809649, 0.19800701877102256, 0.17536039726110175, 0.11030173554900102, 0.18812305148458108, 0.25775367685128003, 0.20374739746330306, 0.26869551627896726, 2.9393479507416487, 20.49126874655485, 46.99337035417557, 65.50093844532967, 61.089261174201965, 52.63135202229023, 52.43188552558422, 57.48792842030525, 71.06012374162674, 44.61334526538849, 18.316645435988903, 5.487335901707411, 0.9627488174010068, 0.6405671336688101, 1.6476116585545242, 8.254677057266235, 8.973414190113544, 13.659011162817478, 15.056451726704836, 8.884460963308811, 6.563627673313022, 7.266380013898015, 18.253445327281952, 28.940884843468666, 41.74934394657612, 45.57604640722275, 46.26479744911194, 65.60726433992386, 56.75454117357731, 56.86837926506996, 56.88377223908901, 51.10573768615723, 56.7739125341177, 54.31610181927681, 54.00334820151329, 48.64486053586006, 49.20148126780987, 46.02513670921326, 48.86623665690422, 47.37328536808491, 45.27524694800377, 48.01087975502014, 46.127917394042015, 49.3080123513937, 54.93234895169735, 56.23016931116581, 56.87847152352333, 55.87177634239197, 54.617722034454346, 54.90190878510475, 55.66653795540333, 55.63160263001919, 54.73119914531708, 46.77451349794865, 43.92709068953991, 39.09940794110298, 40.99766068160534, 55.50964817404747, 52.457838132977486, 52.26488448679447, 49.59010921418667, 47.910766527056694, 41.91342294216156, 41.06079429388046, 40.094715133309364, 43.4676231443882, 43.687255159020424, 47.357170432806015, 44.79208007454872, 43.15183728933334, 42.747193202376366, 42.06591255962849, 41.64424918591976, 42.6707299053669, 46.407502591609955, 51.72673836350441, 56.221023201942444, 57.85253405570984, 52.024722173810005, 49.26243759691715, 53.749312832951546, 54.05293174088001, 55.27790620923042, 59.18847776949406, 58.23683403432369, 59.05024118721485, 58.79143327474594, 46.64892643690109, 37.357551008462906, 23.38083129376173, 15.803297851234674, 7.765802890062332, 8.528664205223322, 12.275130171328783, 15.792048554867506, 14.747633747756481, 14.735072571784258, 9.724971111863852, 9.76995499804616, 6.057350439950824, 1.4111556904390454, 0.8813585503958166, 1.6377175832167268, 5.73452546261251, 23.639213629066944, 32.17749036848545, 34.61017303168774, 45.50867982208729, 44.1221684217453, 56.366707384586334, 50.80948658287525, 42.24025100469589, 14.1671521961689, 3.599945828318596, 0.2678516646847129, 0.12529043946415186, 0.1394649999565445, 0.23551409365609288, 0.09311994814197533, 0.17022868356434628, 0.15978037234162912, 0.13259753643069416, 0.1185793687182013, 0.2019576489692554, 0.08686286397278309, 0.1592466197325848, 0.14965070964535698, 0.15402672404889017, 0.14778750337427482, 0.15372462541563436, 0.14422620384721085, 0.21321647451259196, 0.14108583563938737, 0.1217411553079728, 0.13842210435541347, 0.1746661774814129, 0.1404215392540209, 0.1198053002008237, 0.1299861414008774, 0.18507839064113796, 0.0855098916508723, 0.12770647153956816, 0.16956692532403395], [0.029035490697424393, 0.0727375820861198, 0.03325592682813294, 0.03350429768033791, 0.0663007571711205, 0.04171875181782525, 0.0064181014568021055, 0.06383727217325941, 0.0437014512863243, 0.057518778994563036, 0.039840750832809135, 0.03364792180946097, 0.06157335810712539, 0.03090891634201398, 0.033915740641532466, 0.028480831788328942, 0.013510950593627058, 0.051819081127177924, 0.036653957577073015, 0.0840263013378717, 0.06406861444702372, 0.026423878589412197, 0.03487037633021828, 0.07086122495820746, 0.03130365912511479, 0.019197046749468427, 0.012941889381181682, 0.0609536165575264, 0.04929606104269624, 0.051970976492157206, 0.08070720912655815, 0.05233212410530541, 0.12043077484122477, 0.941590602742508, 8.72189523652196, 31.976560950279236, 46.04022569954395, 46.52218043804169, 47.179913744330406, 50.22165812551975, 84.31216344237328, 78.38571265339851, 53.52105528116226, 23.65751914680004, 6.102882921695709, 1.3148605450987816, 0.1726002906798385, 0.7860349654220045, 3.0034906463697553, 5.8230516873300076, 11.424311175942421, 3.2045307336375117, 1.5651881438679993, 1.2958335410803556, 6.962810028344393, 15.122942458838224, 23.536356948316097, 30.872788578271866, 43.298114240169525, 38.807272017002106, 56.63128338754177, 51.71933636069298, 54.37292017042637, 57.315030097961426, 58.2182340323925, 55.54021753370762, 50.24474188685417, 50.01599036157131, 43.957409262657166, 44.559000581502914, 45.46649448573589, 48.783876076340675, 47.434116303920746, 50.04729688167572, 47.399386167526245, 48.590572848916054, 47.4926483631134, 51.28775171935558, 52.66711190342903, 52.5375122576952, 48.57654020190239, 50.54947793483734, 47.7593332529068, 50.50063535571098, 48.30922834575176, 52.916602715849876, 47.90744550526142, 41.14281289279461, 40.926490500569344, 30.168834552168846, 53.704395443201065, 49.52174328267574, 49.5346549898386, 47.73588091135025, 45.93852035701275, 44.67446118593216, 44.45384502410889, 38.226875960826874, 37.95568071305752, 36.39704614877701, 38.8047831505537, 38.35980802774429, 40.53766496479511, 41.67770639061928, 41.08782984316349, 39.57485742866993, 40.92251971364021, 45.92785432934761, 47.64446161687374, 51.711007207632065, 52.94675409793854, 51.60022035241127, 52.80845291912556, 51.53742112219334, 50.75089372694492, 52.48675458133221, 52.36347019672394, 53.75061996281147, 53.37464913725853, 50.234892815351486, 41.298482939600945, 30.476236157119274, 20.17850372940302, 10.973599310964346, 4.0311590395867825, 3.0827902536839247, 6.722990646958351, 7.211149027571082, 6.997085139155388, 7.5577811524271965, 1.8799796397797763, 2.7739613503217697, 1.6343060787767172, 0.6601470673922449, 0.18016466055996716, 1.4391491445712745, 6.752843270078301, 18.199721910059452, 23.877289853990078, 24.79437254369259, 32.165300622582436, 36.414099633693695, 48.82381573319435, 34.95616726577282, 20.183810144662857, 5.1604370679706335, 0.10349187752581201, 0.16855729278177023, 0.04438853902684059, 0.020904071752738673, 0.0700058181246277, 0.04433197624166496, 0.061806221783626825, 0.05375300665036775, 0.011070134496549144, 0.03408744763873983, 0.008250814735220047, 0.007227467303891899, 0.011037261065212078, 0.06052367185475305, 0.021651792958437, 0.0635761623561848, 0.05337030335795134, 0.07111686514690518, 0.0493662941880757, 0.03101005066127982, 0.02209451558883302, 0.018108857875631656, 0.08900735163479112, 0.026678329486458097, 0.031132534713833593, 0.051673868802026846, 0.03338322741910815, 0.035216436081100255, 0.01115193957957672, 0.029100100218784064, 0.01730871692416258, 0.055385538580594584, 0.03754882811335847, 0.028858625773864333, 0.03404913055419456, 0.09357396440464072, 0.011899524415639462, 0.05792998446850106, 0.018706722767092288, 0.0343273431644775, 0.08627465256722644, 0.03630332248576451, 0.012678194107138552, 0.028687742560578045, 0.06426448948332109, 0.05579851407674141, 0.04575086983095389, 0.0088986484297493, 0.034446884601493366, 0.031562683507218026, 0.049763109418563545, 0.03578371892217547, 0.04229619094985537, 0.031616504056728445, 0.08338928630109876, 0.04208214442769531, 0.07706543110543862, 0.03461301435891073, 0.034478132729418576, 0.026497822473174892, 0.04782813004567288, 0.05468990500958171, 0.03532301961968187, 0.9600165858864784, 11.367852855473757, 37.35972449183464, 53.96694615483284, 54.55240733921528, 51.67167171835899, 52.99642123281956, 83.40863272547722, 79.42390814423561, 51.252596005797386, 23.72050266712904, 6.5852803364396095, 1.0932617797516286, 0.21883966808672994, 0.5589180055540055, 2.953708805143833, 3.901392202824354, 4.825831772759557, 4.248580047860742, 2.2103067208081484, 1.4516983274370432, 7.80867456458509, 16.983866952359676, 27.51028060913086, 34.44066412746906, 44.199349880218506, 45.007817298173904, 57.11859963834286, 55.28134882450104, 56.21104873716831, 56.846036463975906, 57.68601939082146, 56.4237917214632, 53.451340422034264, 52.49582089483738, 46.202195808291435, 46.65220946073532, 47.055082842707634, 50.57715184986591, 49.882203340530396, 51.36476218700409, 48.92235964536667, 50.34148849546909, 49.25727367401123, 53.98308388888836, 54.15478527545929, 55.69817125797272, 52.0152872800827, 52.21614830195904, 51.086305528879166, 51.05638973414898, 51.791023313999176, 54.81222219765186, 49.20660339295864, 44.82429854571819, 42.4205931276083, 33.618065267801285, 54.592039212584496, 50.883502811193466, 50.47508552670479, 50.428975000977516, 47.102299109101295, 46.31106376647949, 45.83556488156319, 40.22139273583889, 39.17082130908966, 39.35910500586033, 41.04475535452366, 40.27625039219856, 41.706106066703796, 42.11804196238518, 42.5368744879961, 41.92382298409939, 42.1462744474411, 48.07933308184147, 48.8184580206871, 52.935673892498016, 55.574275106191635, 53.36383871734142, 51.574522331357, 50.70373445749283, 52.34499178826809, 54.58676889538765, 55.60881145298481, 55.99225267767906, 55.98380573093891, 52.37565614283085, 43.76341067254543, 32.06801824271679, 21.72275796532631, 12.890429254621267, 5.5974003206938505, 5.089185666292906, 8.736603297293186, 11.602617558091879, 10.34307824447751, 8.115412630140781, 5.179816028103232, 3.8323684316128492, 1.150232597719878, 0.5625772685743868, 0.2094458744977601, 1.8025827803649008, 6.612029476091266, 21.918468363583088, 31.98815792798996, 28.57246421277523, 36.715586856007576, 42.06908918917179, 54.877772480249405, 39.40850615501404, 25.245499536395073, 6.8937834072858095, 0.4920841340208426, 0.10488739717402495, 0.0842470457428135, 0.02640073471411597, 0.03531922724505421, 0.04290066281100735, 0.04716034556622617, 0.019951497379224747, 0.0091190384591755, 0.023155846138251945, 0.031450162787223235, 0.04938150450470857, 0.04881356857367791, 0.020355832421046216, 0.02464515284373192, 0.041706810661708005, 0.029023835268162657, 0.03096546799497446, 0.06855610685306601, 0.03006302755238721, 0.03837899450445548, 0.03733873352757655, 0.007181905930337962, 0.01448758539481787, 0.025991340080508962, 0.04587336130498443, 0.04157296061748639, 0.041970684978878126, 0.036932693401467986, 0.03887357655912638, 0.1500277651939541, 0.2026749643846415, 0.15593932766932994, 0.21757495938800275, 0.12148080248152837, 0.20340924529591575, 0.055812069404055364, 0.1580107508925721, 0.09855741183855571, 0.1527866249671206, 0.1704971183789894, 0.14227500854758546, 0.13229629868874326, 0.11152498787851073, 0.1404961696243845, 0.11122872252599336, 0.1363431112258695, 0.13137009838828817, 0.16560706280870363, 0.12471373134758323, 0.20908152451738715, 0.13481442059855908, 0.2586404245812446, 0.2102121865027584, 0.2058024043799378, 0.09628726373193786, 0.1070068521948997, 0.17370125191519037, 0.2935032866662368, 0.12372302357107401, 0.21630996867315844, 0.20407906325999647, 0.1900222519179806, 1.3892356166616082, 13.016628082841635, 41.40720270574093, 58.30925814807415, 59.8394588381052, 59.39137548208237, 61.135215908288956, 90.038091391325, 81.94444209337234, 56.51177600026131, 27.53772083669901, 7.372428998351097, 1.9909229991026223, 0.5658146948553622, 1.2695851433090866, 6.444940567016602, 9.80959827080369, 16.91673595458269, 7.407540064305067, 5.017404668033123, 2.67837842926383, 10.56403448805213, 20.122443437576294, 30.594909489154816, 36.21823534369469, 46.50387302041054, 46.38585515320301, 61.497507467865944, 56.43791936337948, 54.87334571778774, 57.314000353217125, 60.069749280810356, 58.11136096715927, 54.97654438018799, 54.262186512351036, 48.512779623270035, 48.092476576566696, 49.72284369170666, 52.37593732774258, 51.87167398631573, 54.15964901447296, 50.78394055366516, 51.40569359064102, 51.67043298482895, 56.74693398177624, 56.07764169573784, 56.58871427178383, 53.50739121437073, 53.963932916522026, 52.01925806701183, 53.076418340206146, 53.799956515431404, 55.88381789624691, 52.6260969042778, 45.758919194340706, 44.132298678159714, 38.34640234708786, 54.66600984334946, 52.82477304339409, 54.20355185866356, 52.89792291820049, 50.39831064641476, 49.29813288152218, 47.954353988170624, 41.18891961872578, 41.51932708919048, 41.239133924245834, 43.242709413170815, 43.02573345601559, 44.91256780922413, 45.18837980926037, 44.55747306346893, 43.66161793470383, 45.61114512383938, 50.61557538807392, 51.288276091217995, 55.7520105689764, 56.301381289958954, 54.62252877652645, 51.94842986762524, 52.33934909105301, 52.093494683504105, 54.92600329220295, 56.151471734046936, 57.661252319812775, 57.107861414551735, 55.58117173612118, 46.56770199537277, 36.061752140522, 25.31400416046381, 14.146229568868876, 7.064393777400255, 8.523139301687479, 13.59020920470357, 14.111374039202929, 14.086756110191345, 15.563946794718504, 9.22088161110878, 7.93160461820662, 4.414356127381325, 1.3344531250186265, 0.6474725506268442, 2.6539789885282516, 8.457060847431421, 22.98547960817814, 35.85341311991215, 35.19400030374527, 45.1050578802824, 50.29178336262703, 59.365502670407295, 45.347112491726875, 26.65122840553522, 7.980071492493153, 0.8203737821895629, 0.30524441914167255, 0.16019633127143607, 0.07625685379025526, 0.1952915746369399, 0.1613883243408054, 0.1918778140679933, 0.16191777249332517, 0.1346368988743052, 0.06681209692033008, 0.15364886698080227, 0.16443672560853884, 0.15643592836568132, 0.19227036566007882, 0.08429717781837098, 0.21644517313688993, 0.18819984892616048, 0.08608728254330344, 0.11439009351306595, 0.14258397946832702, 0.1384477232932113, 0.11539068669662811, 0.10705758541007526, 0.12882852461189032, 0.17602499050553888, 0.16132739401655272, 0.11561358332983218, 0.15682052413467318, 0.09215202429913916, 0.13645661529153585], [0.030280923965619877, 0.037010978849139065, 0.008326667793880915, 0.03791241739236284, 0.018062748240481596, 0.013935459992353572, 0.0167477571812924, 0.1095169440668542, 0.03353366817464121, 0.04425683378940448, 0.05212825242779218, 0.04150000007939525, 0.06147805892396718, 0.04184066070592962, 0.02146551945770625, 0.0610851919191191, 0.015170351052802289, 0.04877814957580995, 0.06166316910821479, 0.061423781953635626, 0.02120198838383658, 0.030484710296150297, 0.03131498058792204, 0.05610164058452938, 0.054408827709266916, 0.041198929320671596, 0.03381219619768672, 0.05782454383734148, 0.04548476907075383, 0.04737410636153072, 0.07949715218273923, 0.019561123990570195, 0.03595388596295379, 0.06154572794912383, 6.228512255474925, 27.032287158071995, 48.99691164493561, 48.59503000974655, 41.56946539878845, 49.18731562793255, 47.133427038788795, 53.592746034264565, 37.41171330213547, 19.645979404449463, 6.02843351662159, 2.5501626217737794, 0.057827130221994594, 0.4957789013860747, 3.3770642755553126, 4.666810305789113, 2.9526583990082145, 11.25251004472375, 19.610943384468555, 5.807320531457663, 8.518541548401117, 6.069532111287117, 16.287852600216866, 24.241808094084263, 41.74361765384674, 36.09501175582409, 52.01452352106571, 53.45071345567703, 51.60133749246597, 58.77643547952175, 53.88680845499039, 54.00533549487591, 49.70004491508007, 51.12616539001465, 45.21994091570377, 48.210874423384666, 49.285703748464584, 52.01508589088917, 50.35198353230953, 50.464810878038406, 50.09199768304825, 48.77942271530628, 50.45735947787762, 51.06194883584976, 51.05835422873497, 51.381557285785675, 48.50868344306946, 48.483186811208725, 44.56082068383694, 47.31216944754124, 47.55086123943329, 50.304744467139244, 47.18812510371208, 52.04013034701347, 47.75831110775471, 28.689416237175465, 49.11779835820198, 52.423674166202545, 49.88375745713711, 49.652824848890305, 48.36209870874882, 48.47478546202183, 47.8479178994894, 45.133924931287766, 37.32097037136555, 37.47222885489464, 37.988830134272575, 41.15384370088577, 46.851113587617874, 48.84748846292496, 46.951511800289154, 44.62398089468479, 40.6487900018692, 44.26819458603859, 49.735918790102005, 50.299086570739746, 51.00770674645901, 53.34287904202938, 51.33495658636093, 48.71256150305271, 56.33438251912594, 54.25245143473148, 54.84680414199829, 52.93263405561447, 53.023156598210335, 49.620017409324646, 42.86087550222874, 28.755496591329575, 18.712445497512817, 8.93289316445589, 3.734141564927995, 2.34769974835217, 5.774287478998303, 12.274893634021282, 9.490264356136322, 4.478866690769792, 4.221008727326989, 2.5240665720775723, 0.8434882387518883, 0.11085824240581132, 0.551981715252623, 0.891561834141612, 10.680039413273335, 20.071583166718483, 20.662495158612728, 27.44527369737625, 28.13853319734335, 36.93082630634308, 36.67409308254719, 37.09365896880627, 13.658318649977446, 2.05465329810977, 0.08986602391814813, 0.09973218708182685, 0.025535138192935847, 0.06935647601494566, 0.03282920675701462, 0.07186754752183333, 0.02948636953078676, 0.02980690867843805, 0.04848714605032001, 0.03166763432091102, 0.0455842354131164, 0.05197684688027948, 0.0437559842976043, 0.054523218641406856, 0.058856266405200586, 0.04825522119062953, 0.02313814406079473, 0.06976566655794159, 0.010784403930301778, 0.06384944339515641, 0.029386786300165113, 0.0654438511992339, 0.0637112332333345, 0.05507558802491985, 0.057130494751618244, 0.029058293184789363, 0.03882045733917039, 0.03529336339852307, 0.03952734186896123, 0.03097775981586892, 0.05181860244192649, 0.01004043891953188, 0.01463985739974305, 0.037351624632719904, 0.05041205818997696, 0.02308451832504943, 0.013751922233495861, 0.06588462754734792, 0.03639883318101056, 0.0690116074110847, 0.051620378508232534, 0.020595837413566187, 0.025598792199161835, 0.03239904312067665, 0.09922017197823152, 0.021472317530424334, 0.01319242544923327, 0.0304746616166085, 0.038769122984376736, 0.08000917470781133, 0.06354405704769306, 0.028056278788426425, 0.06175213406095281, 0.04808297242561821, 0.11283410669420846, 0.03701650784933008, 0.017628333953325637, 0.0859759010199923, 0.03765276589547284, 0.016559231262363028, 0.021130502864252776, 0.009903239006234799, 0.0803957816970069, 0.2208607440115884, 8.541622459888458, 32.26802431046963, 54.13218028843403, 53.9625383913517, 48.50131943821907, 53.96268278360367, 56.66310667991638, 67.77054145932198, 53.60305868089199, 27.664913311600685, 7.218410912901163, 1.9654306420125067, 0.12693181779468432, 0.2393957634922117, 1.3785435841418803, 2.7124462136998773, 3.6741387471556664, 5.6529761385172606, 7.100899368524551, 5.10330380871892, 10.51335945725441, 10.707842521369457, 17.476683408021927, 27.151044085621834, 42.31768324971199, 41.197989732027054, 56.21573768556118, 55.32653599977493, 52.27874234318733, 58.20844955742359, 54.277853071689606, 56.49077072739601, 51.96782782673836, 52.71880432963371, 46.842453852295876, 49.55027595162392, 52.76739992201328, 53.67499642074108, 51.81981436908245, 51.610514000058174, 52.05729402601719, 51.48097515106201, 52.2589948028326, 53.93560163676739, 52.45441451668739, 55.22957660257816, 51.416663601994514, 49.8515921831131, 46.645464822649956, 49.801586866378784, 49.77020435035229, 51.56776249408722, 49.87785257399082, 52.47126281261444, 48.00028592348099, 32.034906819462776, 50.46059310436249, 53.02152268588543, 52.153178080916405, 52.2406379878521, 49.83286298811436, 51.60030014812946, 50.03615967929363, 45.56720048189163, 38.89075733721256, 39.312580302357674, 40.4224893450737, 42.941507175564766, 48.72363790869713, 49.926828145980835, 47.592294216156006, 46.80303476750851, 43.198145404458046, 46.345239132642746, 52.07339756190777, 53.97144511342049, 52.97242172062397, 52.77313381433487, 52.664790228009224, 52.698053643107414, 56.01357713341713, 56.99620060622692, 55.27493476867676, 54.084952622652054, 54.734094589948654, 50.97440913319588, 43.47211070358753, 31.16623543202877, 21.296567134559155, 10.675386562943459, 4.22127328813076, 3.3168633934110403, 7.25596334785223, 8.616671282798052, 9.651882033795118, 4.581374265253544, 4.215295733883977, 3.9701687498018146, 1.3812482077628374, 0.41672755731269717, 0.3124951128847897, 1.417165424209088, 9.455253034830093, 21.425925493240356, 22.917601950466633, 28.98800991475582, 32.99049474298954, 42.16219939291477, 43.541065603494644, 42.735546827316284, 15.413856748491526, 2.9362751031294465, 0.0636217524879612, 0.09805263267480768, 0.0022360232287610415, 0.0467018318886403, 0.03480149018287193, 0.04212565654597711, 0.04850020784942899, 0.018363770759606268, 0.06000196801323909, 0.0405611313180998, 0.020372083599795587, 0.02503597152099246, 0.10966126210405491, 0.04959729136317037, 0.030556431447621435, 0.028609147266251966, 0.04332695985794999, 0.02648128371220082, 0.01991241588257253, 0.02496338391210884, 0.020927310251863673, 0.02341642160899937, 0.01586685757501982, 0.03119756540399976, 0.036626520377467386, 0.01917794386827154, 0.017630912916501984, 0.018200596605311148, 0.07490796328056604, 0.05616477508738171, 0.23369277419988066, 0.10817716713063419, 0.11592403854592703, 0.08183193393051624, 0.16581893112743273, 0.12400952968164347, 0.0974816687812563, 0.18469188013114035, 0.15946539002470672, 0.1594115694751963, 0.11830390576506034, 0.10303545670467429, 0.13946173450676724, 0.09320753641077317, 0.21274648723192513, 0.1280724987736903, 0.12295346838072874, 0.09426899312529713, 0.14700538362376392, 0.1462996457121335, 0.10153150928090326, 0.1107511727605015, 0.11041417834348977, 0.11447033451986499, 0.17537265754071996, 0.148668670153711, 0.09886695421300828, 0.22841960715595633, 0.10460469828103669, 0.17080010758945718, 0.1520583702949807, 0.09840305254328996, 0.3005307127023116, 0.4987813637126237, 10.216506086289883, 35.16399331390858, 60.958711579442024, 64.6695126593113, 54.84802387654781, 59.40350063145161, 55.774566158652306, 63.57973873615265, 44.40604358911514, 24.018389582633972, 7.778667574748397, 3.187203425914049, 0.27528890466783196, 1.0889386804774404, 5.08462306112051, 11.484844777733088, 7.962882164865732, 18.474325574934483, 26.73481822013855, 9.774698093533516, 10.74096154421568, 8.062405474483967, 17.957555204629898, 27.768167071044445, 44.15114186704159, 42.348617389798164, 62.66034007072449, 59.906141459941864, 53.13489720225334, 57.59216442704201, 55.844615399837494, 57.986731454730034, 53.72692823410034, 54.273084327578545, 48.99530433118343, 51.13018557429314, 55.284107476472855, 55.37724047899246, 55.557510405778885, 53.257680013775826, 54.16185289621353, 53.45373049378395, 54.55832362174988, 55.31329371035099, 54.343247562646866, 55.509807765483856, 54.42306607961655, 51.89856514334679, 47.71728850901127, 51.75223499536514, 52.16250658035278, 53.60981471836567, 52.61873669922352, 53.98430362343788, 47.80483581125736, 36.770201325416565, 50.28855353593826, 53.492211028933525, 54.124364107847214, 54.396824687719345, 52.44403727352619, 52.66204297542572, 52.239737436175346, 48.714332208037376, 40.04101261496544, 41.873612478375435, 43.027747347950935, 44.93986554443836, 51.698752865195274, 52.825806587934494, 50.67430503666401, 49.37477096915245, 44.71658952534199, 46.65921248495579, 54.52583156526089, 55.61202988028526, 53.71935524046421, 53.03429760038853, 53.39850805699825, 50.651646852493286, 57.7284175157547, 57.950914576649666, 56.993407756090164, 56.32232576608658, 55.362854450941086, 53.146589174866676, 46.82324208319187, 32.30815015733242, 22.875010035932064, 13.035103641450405, 7.3509459011256695, 6.1137607879936695, 13.26122285798192, 24.567220732569695, 20.890490524470806, 12.75629360228777, 9.371724016964436, 9.780390188097954, 3.8776237657293677, 0.9830700082238764, 1.10401033423841, 1.264447937719524, 13.631974663585424, 26.83212149888277, 29.663264080882072, 37.779955342411995, 38.90654169023037, 51.123041957616806, 50.12143090367317, 46.43565148115158, 18.237866163253784, 3.157546492293477, 0.2883173665031791, 0.19177646638127044, 0.10825366771314293, 0.13175273488741368, 0.1433646891382523, 0.20348721533082426, 0.1111639775626827, 0.07987739896634594, 0.1790635212091729, 0.1680795129504986, 0.09787165996385738, 0.15599849168211222, 0.25021844368893653, 0.1648380048573017, 0.14854531036689878, 0.07692999657592736, 0.12974083190783858, 0.11685150049743243, 0.10816630208864808, 0.16501793114002794, 0.07300521538127214, 0.1395171432523057, 0.11205055459868163, 0.12397321639582515, 0.25577508145943284, 0.10224501005723141, 0.09693170766695403, 0.09029438413563184, 0.17584510875167325, 0.14176297117955983], [0.03297595903859474, 0.05586384533671662, 0.10117363824974746, 0.11619804688962176, 0.08997183191240765, 0.06035017628164496, 0.03194081516994629, 0.01806215637770947, 0.04359896440291777, 0.027116324636153877, 0.1202577208459843, 0.06126016436610371, 0.005142465561220888, 0.02918654372479068, 0.04746624770632479, 0.024817893281579018, 0.0994665278994944, 0.03458932871581055, 0.022753151242795866, 0.04235509521095082, 0.022750063908461016, 0.013742070223088376, 0.010425865893921582, 0.028175755287520587, 0.01831819176004501, 0.020542759011732414, 0.007466001452485216, 0.01445406443963293, 0.0243875422529527, 0.018810564070008695, 0.02487870486220345, 0.035876142283086665, 0.05840595345944166, 0.12095925078028813, 2.51042767893523, 17.19180889427662, 41.9264030456543, 53.667016848921776, 50.30983619391918, 35.45593164861202, 25.3153682872653, 21.324453838169575, 18.504535853862762, 17.26358324289322, 11.064611077308655, 1.814390409272164, 0.9805277665145695, 0.17206895747222006, 1.03964974405244, 0.9010176861193031, 9.060614760965109, 19.574307650327682, 14.82443142682314, 4.541484005749226, 3.065872136503458, 5.059739146381617, 9.455255884677172, 17.104329988360405, 32.0012292265892, 33.18917468190193, 42.98059567809105, 51.852344423532486, 48.036779165267944, 58.641371726989746, 52.66346409916878, 55.27009002864361, 51.03996321558952, 52.750920206308365, 46.88087359070778, 50.69562949240208, 52.75096960365772, 54.90825444459915, 51.770527213811874, 54.14397485554218, 50.54882436990738, 51.906977891922, 49.98366169631481, 50.29305249452591, 50.53202927112579, 48.41118447482586, 46.0296318680048, 46.765447184443474, 42.4921128898859, 44.72779892385006, 44.060208946466446, 50.40044613182545, 48.290176168084145, 51.507611721754074, 51.87964215874672, 31.185671389102936, 48.52129116654396, 51.57353438436985, 49.21911612153053, 52.239984422922134, 52.45014734566212, 52.06263653934002, 50.71666516363621, 47.94108510017395, 41.17823839187622, 36.271614879369736, 38.428325951099396, 47.64668069779873, 50.77887162566185, 52.10914604365826, 49.676638171076775, 45.699045807123184, 41.72494925558567, 44.00947406888008, 49.02035638689995, 51.32023237645626, 54.52295511960983, 48.50584879517555, 51.883453354239464, 50.48791363835335, 50.663882195949554, 53.194196820259094, 55.228987634181976, 53.47716383635998, 54.32789258658886, 48.17533493041992, 37.82680682837963, 27.863825038075447, 17.41237185895443, 9.311271160840988, 4.51186696998775, 4.026272026821971, 6.840826598927379, 4.281864836812019, 7.339992513880134, 4.025526316836476, 2.190040508285165, 1.3458186713978648, 0.9274937747977674, 0.23940751911140978, 0.37254240014590323, 3.0019809398800135, 10.93373280018568, 20.110405683517456, 30.146411955356598, 31.680782921612263, 31.493561267852783, 48.31360191106796, 42.07244820892811, 22.43297215551138, 6.727930381894112, 0.49041148158721626, 0.07084447468514554, 0.03711356592248194, 0.06853212064015679, 0.017131091299233958, 0.010800996496982407, 0.04559120046906173, 0.021242652510409243, 0.06411220078007318, 0.056639322865521535, 0.03275640949141234, 0.0113526803215791, 0.0429422379238531, 0.04515285836532712, 0.015635626623407006, 0.040274510174640454, 0.01810168872907525, 0.024253233932540752, 0.050423253487679176, 0.03650503080280032, 0.03392233091290109, 0.03630834682553541, 0.05730113305617124, 0.01902596872241702, 0.029552261112257838, 0.014471614376816433, 0.011163609851791989, 0.016619254311081022, 0.038205042510526255, 0.07368188336840831, 0.02211344035458751, 0.034348776389379054, 0.05104102463519666, 0.04580176631861832, 0.14494338567601517, 0.04422852085554041, 0.02853447793313535, 0.03674661471450236, 0.027702333718480077, 0.023653812386328354, 0.04677187207562383, 0.03613286971813068, 0.016355018196918536, 0.0458936850191094, 0.04930205759592354, 0.05823443570989184, 0.02265733255626401, 0.036674143993877806, 0.020379618254082743, 0.052388037511263974, 0.01625376142328605, 0.03255847499531228, 0.034529073745943606, 0.053950703659211285, 0.02210445480159251, 0.041079258007812314, 0.06314163489150815, 0.025440711033297703, 0.02882947606849484, 0.057191146770492196, 0.032811072378535755, 0.07969621103256941, 0.06749629770638421, 0.021502118470380083, 0.032393825822509825, 3.525285297073424, 21.66236210614443, 48.86816315352917, 60.35331666469574, 55.317275896668434, 43.58291655778885, 32.553901970386505, 28.727072216570377, 22.758892066776752, 16.820593513548374, 10.152623914182186, 2.2586230281740427, 0.32395633694250137, 0.18202764418674633, 1.2295602285303175, 1.3195350067690015, 5.627093352377415, 23.363202139735222, 23.772149495780468, 7.219943655654788, 5.92119662091136, 7.4983100686222315, 12.1402782574296, 19.584542401134968, 34.41772095859051, 37.248071283102036, 47.40154445171356, 54.99835900962353, 52.317865043878555, 58.087798431515694, 54.324879348278046, 56.50867536664009, 53.75755459070206, 53.49028453230858, 49.4593620300293, 52.95830927789211, 54.13278825581074, 55.69758228957653, 54.06959384679794, 55.4217778891325, 51.95939987897873, 53.93863007426262, 51.36750563979149, 53.70455123484135, 53.504499569535255, 50.743503123521805, 47.27894023060799, 48.12328912317753, 45.303232446312904, 47.48390883207321, 47.809821143746376, 51.72648377716541, 51.18725471198559, 53.61887723207474, 52.74376519024372, 35.44936180114746, 49.53289568424225, 51.173780634999275, 50.1069650799036, 53.49854148924351, 53.24780434370041, 52.992936819791794, 53.60763743519783, 50.10754644870758, 42.961520701646805, 37.100791186094284, 40.03790818154812, 49.061052203178406, 52.93499752879143, 52.431950122117996, 51.46520219743252, 48.84224474430084, 44.3601268529892, 46.37024939060211, 52.039548978209496, 54.047171249985695, 53.82824219763279, 51.08188256621361, 52.98507884144783, 51.48515872657299, 53.006847873330116, 54.96671050786972, 57.633297219872475, 55.510689318180084, 55.633719116449356, 49.872179478406906, 39.342089518904686, 31.301736161112785, 19.205484241247177, 11.755239218473434, 4.8602441512048244, 4.24463870935142, 8.280246835201979, 4.769650837406516, 7.034762017428875, 4.609067654237151, 5.031354669481516, 2.96140861697495, 0.5994480557274073, 0.33015068736858666, 0.5929635849315673, 2.431373158469796, 11.989915575832129, 24.84191369265318, 30.274060405790806, 31.17242529988289, 33.22268508374691, 51.713708862662315, 45.72405606508255, 28.59814703464508, 8.94966071471572, 0.7218180550262332, 0.08517052978277206, 0.03359430163982324, 0.03304825535451528, 0.05621655102004297, 0.022786095178162213, 0.05982059083180502, 0.025178489850077312, 0.05034847839851864, 0.011119713672087528, 0.006860138528281823, 0.04427664913237095, 0.0779213425994385, 0.050723711974569596, 0.016156901874637697, 0.029863029885746073, 0.032988304665195756, 0.015442601434187964, 0.0779932715522591, 0.068008743255632, 0.03985691109846812, 0.02500145052181324, 0.04326673086325172, 0.028466838593885768, 0.08051998011069372, 0.03130594493995886, 0.02496026318112854, 0.042187726066913456, 0.016789477012935095, 0.0648192003427539, 0.035713623074116185, 0.11470989236840978, 0.12873253523139283, 0.14039249159395695, 0.22734640224371105, 0.15517654828727245, 0.2006031255587004, 0.07624989244504832, 0.1674946560524404, 0.08565022435504943, 0.10233162611257285, 0.2048895924235694, 0.1307936871307902, 0.1575855744886212, 0.1638136777910404, 0.14992129668826237, 0.12065922273905016, 0.20949871541233733, 0.12929183256346732, 0.1538395247189328, 0.10896342064370401, 0.1665411447174847, 0.11766375144361518, 0.14479010249488056, 0.04852045363804791, 0.122712923475774, 0.15572573756799102, 0.13671056338353083, 0.13995981949847192, 0.16582820797339082, 0.0791076805035118, 0.09517391605186276, 0.2005073439795524, 0.1602932409150526, 0.23408771550748497, 4.408869221806526, 24.683483093976974, 53.23906101286411, 66.70288234949112, 65.36399379372597, 49.58834990859032, 38.003835529088974, 32.39018015563488, 24.58499237895012, 23.01652394235134, 14.063960183411837, 2.3472656216472387, 1.6720676212571561, 0.42881090892478824, 2.199201579205692, 3.868448445573449, 15.385057143867016, 28.42094164341688, 18.029928021132946, 6.263084225356579, 4.674910996109247, 9.60885789245367, 11.819261033087969, 19.471821449697018, 35.31383067369461, 39.84869733452797, 51.51356600224972, 58.467105478048325, 52.537801042199135, 59.43953409790993, 55.932246297597885, 59.52049635350704, 55.97405165433884, 56.42817668616772, 52.446963116526604, 55.457754358649254, 56.10861383378506, 57.07738324999809, 54.809429347515106, 56.50764562189579, 53.04431386291981, 55.991526916623116, 53.35346147418022, 55.45941486954689, 55.33321604132652, 52.29804150760174, 49.42186564207077, 50.78304000198841, 47.64927975833416, 48.69918242096901, 49.086598232388496, 54.435191228985786, 53.803627118468285, 53.13636772334576, 54.06613603234291, 39.28907096385956, 48.137367367744446, 52.18274049460888, 48.4913981705904, 54.7069488465786, 54.784449487924576, 54.4109333306551, 55.141090750694275, 51.4196540415287, 45.777219012379646, 38.936837464571, 42.33214147388935, 52.1695552021265, 55.890767723321915, 55.5636090785265, 54.80047322809696, 49.49669882655144, 46.39957241714001, 48.96772921085358, 54.88292120397091, 55.939260721206665, 55.91719150543213, 51.61238729953766, 54.746854305267334, 51.53269797563553, 53.64215098321438, 54.487377628684044, 59.941034987568855, 56.13255254924297, 58.703069016337395, 52.15391904115677, 42.26358935236931, 31.793393678963184, 21.80013321340084, 12.829962149262428, 7.490128632634878, 7.904563369229436, 17.005425095558167, 13.936991896480322, 15.681026112288237, 10.67108804360032, 8.590713925659657, 4.25878725014627, 1.2549879890866578, 0.912429898744449, 0.6439692573621869, 4.573249351233244, 12.823478747159243, 31.17739923298359, 43.039006143808365, 42.14585267007351, 44.31878887116909, 60.30823968350887, 53.46041053533554, 30.9746915102005, 10.024561285972595, 0.9261863480787724, 0.20203541120281443, 0.14513987669488415, 0.1638171510421671, 0.13408671511569992, 0.13817584491334856, 0.09385449622641318, 0.10280078218784183, 0.14260183554142714, 0.19846792216412723, 0.13863820291589946, 0.17026852205162868, 0.1582167562446557, 0.15053298964630812, 0.12801508622942492, 0.09919700212776661, 0.1626460420084186, 0.09134172520134598, 0.17383019265253097, 0.19882195629179478, 0.16764597996370867, 0.11300047393888235, 0.1621005337801762, 0.18094862083671615, 0.18438198894727975, 0.19156275753630325, 0.12348784439382143, 0.14099734195042402, 0.18425528949592263, 0.18709971889620647, 0.18127158866263926], [0.040331225100089796, 0.0075748921426566085, 0.031645674171159044, 0.025587170166545548, 0.05182268796488643, 0.01586484635481611, 0.10602401118376292, 0.006808274001741665, 0.06572220110683702, 0.021948149224044755, 0.06136560870800167, 0.05942731935647316, 0.062479171610902995, 0.022442521621997003, 0.013941053930466296, 0.11150418547913432, 0.057403894534218125, 0.04665131389629096, 0.03483171785774175, 0.02432925954053644, 0.007949859009386273, 0.03344980919791851, 0.024012475660128985, 0.0361021893331781, 0.03370530095708091, 0.021780108436360024, 0.026241597843181808, 0.0547906960855471, 0.010079423009301536, 0.043064851852250285, 0.06280080357100815, 0.04191916137642693, 0.08527080877684057, 0.03420024295337498, 1.2032297789119184, 10.40700601413846, 22.778470516204834, 47.30428487062454, 51.65510080754757, 45.818568393588066, 33.2736137509346, 26.987145580351353, 39.57490682601929, 29.994499906897545, 11.372279617935419, 3.6507631139829755, 0.8376469428185374, 0.33756049757357687, 1.0391875938512385, 0.9828254557214677, 4.013218302279711, 1.8399219517596066, 1.995056583546102, 2.3188065737485886, 5.366448238492012, 3.3941308222711086, 6.82170270010829, 13.08102797716856, 26.068124994635582, 28.90309777110815, 37.108227387070656, 49.55414034426212, 44.41373437643051, 57.395832762122154, 52.646741196513176, 55.89088931679726, 50.79296886920929, 52.2571025043726, 49.93954226374626, 55.515602454543114, 53.3765110373497, 55.547057166695595, 51.822390630841255, 51.34423948824406, 49.07695434987545, 51.43447704613209, 51.92685082554817, 51.94039709866047, 49.696039929986, 48.591895177960396, 44.80322107672691, 42.1445569396019, 42.196887731552124, 42.580351755023, 46.07022508978844, 49.33217905461788, 47.31353357434273, 52.75264531373978, 51.66635200381279, 29.952576756477356, 47.67045222222805, 52.3465421050787, 52.50174477696419, 51.88029192388058, 51.33000545203686, 50.917803570628166, 50.995262414216995, 50.093916580080986, 39.64871786534786, 37.976283207535744, 42.71511912345886, 50.14774449169636, 49.77360516786575, 51.10398218035698, 48.354704305529594, 47.664566338062286, 44.308879002928734, 43.1796669960022, 48.164224326610565, 51.946875751018524, 54.12303417921066, 49.27728720009327, 49.601151421666145, 51.622236371040344, 49.712800830602646, 55.33215589821339, 53.48890520632267, 53.224948570132256, 49.76348631083965, 43.92739847302437, 31.762229651212692, 22.299905195832253, 13.566796761006117, 7.323964023962617, 1.1774048209190369, 2.1246512420475483, 4.510389324277639, 3.8487374782562256, 4.087847722694278, 2.0500809559598565, 4.54248477704823, 3.356991852633655, 0.19180940289516002, 0.2525270276237279, 0.69040383445099, 3.401976926252246, 11.227782871574163, 21.29103273153305, 17.62663286179304, 31.719928421080112, 37.441123723983765, 40.99199518561363, 43.75038877129555, 11.508470010012388, 3.288725190795958, 0.14521855919156224, 0.008493462701153476, 0.008990749884105753, 0.040949846006697044, 0.06476089722127654, 0.056206079316325486, 0.04494933549722191, 0.07428610289935023, 0.04848940960073378, 0.05301927121763583, 0.049703893455443904, 0.03199283230060246, 0.03456489350355696, 0.03248214881750755, 0.07810907627572306, 0.0938810947991442, 0.04553815917461179, 0.03853202906611841, 0.07056366084725596, 0.05115156753163319, 0.03291798617283348, 0.05409988276369404, 0.04756683840241749, 0.040727561645326205, 0.06483457764261402, 0.014973833131080028, 0.03779303551709745, 0.08052380959270522, 0.04248318618920166, 0.02604384888400091, 0.036459511175053194, 0.04641900311980862, 0.013538649400288705, 0.08975147342425771, 0.08489509651553817, 0.08962894484284334, 0.049711192477843724, 0.051432600303087384, 0.020906452191411518, 0.05563507460465189, 0.054938732282607816, 0.08952683274401352, 0.019885564979631454, 0.03111483634711476, 0.0311298110318603, 0.040405209801974706, 0.02681605354155181, 0.022968607845541555, 0.06285376322921365, 0.03725920869328547, 0.032291301831719466, 0.009853234023466939, 0.02388459804933518, 0.026560211117612198, 0.03411735247937031, 0.044528986763907596, 0.043205039837630466, 0.0024387209214182803, 0.08247185076470487, 0.011744704061129596, 0.04255102961906232, 0.024977514403872192, 0.02645082597155124, 0.028574949101312086, 0.011004546267940896, 1.4177433494478464, 13.067945279181004, 30.42512319982052, 55.716220289468765, 57.875906601548195, 48.44130925834179, 34.67750541865826, 28.106208331882954, 35.51921725273132, 32.4082025885582, 12.374260202050209, 3.7404428143054247, 0.8804964122828096, 0.20825925457756966, 0.5196737707592547, 2.598843234591186, 5.918970890343189, 3.8236654736101627, 4.55336406826973, 4.680302906781435, 3.1935452856123447, 4.481036849319935, 6.688592042773962, 14.364710245281458, 27.72984802722931, 33.327487260103226, 40.163514241576195, 52.936821430921555, 47.099323868751526, 56.62673503160477, 55.523012056946754, 57.179198786616325, 52.608940824866295, 54.07130755484104, 51.2410332262516, 55.709984824061394, 56.4481408149004, 55.04649482667446, 51.766412034630775, 52.34988212585449, 51.02010168135166, 54.26772281527519, 52.72809483110905, 53.05566385388374, 53.41551974415779, 49.81335483491421, 47.19857834279537, 44.617912620306015, 43.89951936900616, 46.05379097163677, 47.994084656238556, 51.75410449504852, 49.86684836447239, 54.84520822763443, 51.961941942572594, 32.733894512057304, 48.05681549012661, 52.56293669342995, 53.084485307335854, 54.450523406267166, 52.98682674765587, 54.17123459279537, 52.30856694281101, 51.63970023393631, 40.83311051130295, 40.04833102226257, 43.76172736287117, 52.727133482694626, 51.15169622004032, 53.23260895907879, 50.65219022333622, 50.881633311510086, 46.72476276755333, 45.709791630506516, 51.183238327503204, 53.32287311553955, 53.48555378615856, 49.6858374774456, 51.62709251046181, 51.95837013423443, 52.197134122252464, 56.90668500959873, 55.331658124923706, 53.34136292338371, 52.2690224647522, 45.85412308573723, 35.631664618849754, 25.081692226231098, 14.120767135173082, 7.32829911634326, 2.581313350237906, 4.923463733866811, 8.246346954256296, 4.655955238267779, 7.674135183915496, 4.1451657470315695, 2.329616043716669, 2.4214860890060663, 0.5369795265141875, 0.3801869665039703, 0.6403296464122832, 4.358682939782739, 14.701199289411306, 26.351802572607994, 24.206705577671528, 34.569439217448235, 40.73911115527153, 48.79709176719189, 49.90051455795765, 14.372091349214315, 4.573028013110161, 0.20235961099388078, 0.10287639961461537, 0.024246181674243417, 0.06482984274043702, 0.08657369355205446, 0.018582424163469113, 0.013904601491958601, 0.14494163420749828, 0.04008991578302812, 0.03252278140280396, 0.028470721881603822, 0.06507751226308756, 0.03989614844613243, 0.021647301109624095, 0.031107160684769042, 0.004795669228769839, 0.025603052126825787, 0.10967578593408689, 0.025271536615036894, 0.10681364146876149, 0.050984818080905825, 0.03530514870362822, 0.012702177536993986, 0.014267608185036806, 0.0583010397531325, 0.027583256123762112, 0.03779941798711661, 0.032859018829185516, 0.0033103302303061355, 0.027177692827535793, 0.019555726721591782, 0.1794578242697753, 0.13359061907976866, 0.1798995357239619, 0.2971843391424045, 0.1389211689820513, 0.16127661627251655, 0.20989867363823578, 0.11854927462991327, 0.21017953200498596, 0.20229198649758473, 0.19499581394484267, 0.18146281043300405, 0.13534097437513992, 0.15227791242068633, 0.10378381615737453, 0.2128432781319134, 0.13098434486892074, 0.1293423876632005, 0.0825824159255717, 0.1154978082922753, 0.12012818639050238, 0.09711788283311762, 0.09441223504836671, 0.1734766038134694, 0.1480200033984147, 0.09291541966376826, 0.19960735633503646, 0.19478394562611356, 0.16099350177682936, 0.08982426326838322, 0.1759063804638572, 0.06153244721645024, 0.20061991293914616, 0.16075396619271487, 1.8356411252170801, 15.954431891441345, 36.67476184666157, 62.93565429747105, 68.39514434337616, 57.48861238360405, 43.99690814316273, 40.153026804327965, 50.18503189086914, 38.81813183426857, 15.339568834751844, 5.670411977916956, 1.227299349848181, 0.7273511518724263, 1.5102993766777217, 4.22067909501493, 9.850441329181194, 5.263338396325707, 5.83501392044127, 5.532906381413341, 8.334940150380135, 5.935764564201236, 8.355563543736935, 15.836294330656528, 29.697146862745285, 34.695983827114105, 45.78938215970993, 60.4519859701395, 47.87555381655693, 57.64864079654217, 55.85025429725647, 59.736909940838814, 56.10359810292721, 56.81476794183254, 54.79117892682552, 59.94860798120499, 58.4560214728117, 57.121194899082184, 52.32660077512264, 51.53174042701721, 50.09946808218956, 55.34518159925938, 54.25398275256157, 55.33084496855736, 55.06355211138725, 52.09877260029316, 47.86915875971317, 46.88739784061909, 47.37088389694691, 47.24846586585045, 50.85988327860832, 53.73450882732868, 51.57065033912659, 54.50887307524681, 52.58443593978882, 36.342933252453804, 47.81691536307335, 51.981400698423386, 56.17178164422512, 56.04985758662224, 54.816014394164085, 54.991127997636795, 55.30458077788353, 54.8692761361599, 43.65814872086048, 42.12841160595417, 46.295742988586426, 53.880512192845345, 52.86383114755154, 55.73182225227356, 49.923423528671265, 51.50881625711918, 47.084272876381874, 47.16032959520817, 51.867273822426796, 57.03299783170223, 54.330487847328186, 50.58089844882488, 50.69569408893585, 54.249905571341515, 52.28888779878616, 57.566701993346214, 56.76335670053959, 56.18993707001209, 53.95240433514118, 48.3015413582325, 36.63692727684975, 26.220971792936325, 16.28910843282938, 11.137647908180952, 3.6911157611757517, 7.823658585548401, 13.015681933611631, 7.198898009955883, 12.70492510870099, 8.351822644472122, 10.08374311029911, 7.4071116372942924, 1.0178954363800585, 0.6792108225636184, 1.030699205584824, 5.035726809874177, 16.029618456959724, 30.651102773845196, 30.452669821679592, 42.64806792140007, 48.97177219390869, 54.96496260166168, 55.41721433401108, 18.124366253614426, 5.143925528973341, 0.2992870513116941, 0.1562388287857175, 0.16663274058373645, 0.1475202411529608, 0.11162410912220366, 0.15152089210459962, 0.13726482895435765, 0.19972736161435023, 0.11996873596217483, 0.20342073374195024, 0.2031546292710118, 0.08926491398597136, 0.10669909097487107, 0.1672865281580016, 0.1544232090236619, 0.14806285500526428, 0.13932415517047048, 0.14340032706968486, 0.21402814658358693, 0.17822710593463853, 0.1478389638941735, 0.10535302804782987, 0.1269744022283703, 0.049685740523273125, 0.19416564755374566, 0.1875332518829964, 0.11988010868662968, 0.27944038971327245, 0.15487462776945904, 0.12534178124042228, 0.22222184285055846], [0.0675254715315532, 0.03418977496039588, 0.022193800105014816, 0.03747382666915655, 0.041135330975521356, 0.0408738983242074, 0.1039521797792986, 0.057279154352727346, 0.014509705106320325, 0.04010959753941279, 0.018659759662114084, 0.0866008190496359, 0.050226499006384984, 0.04801004157343414, 0.06641058760578744, 0.014131738571450114, 0.017920036953000817, 0.029312033475434873, 0.07392195329884999, 0.067720982915489, 0.03524067833495792, 0.03559264187060762, 0.04068378977535758, 0.043127785975229926, 0.05088686943054199, 0.03981146939622704, 0.007016694580670446, 0.03756975296710152, 0.10830738436197862, 0.02691210414923262, 0.05801294173579663, 0.006289497932812083, 0.0982033702894114, 0.03586881357477978, 0.08479265787173063, 4.021770693361759, 12.253334540873766, 33.43496449291706, 49.753515645861626, 45.08168913424015, 37.53010734915733, 25.339348800480366, 19.9393692612648, 15.773232914507389, 13.63060388714075, 5.1641295198351145, 2.108170813880861, 0.3861906740348786, 0.3977655357448384, 0.8581041544675827, 0.31442879349924624, 2.392129576765001, 3.0674542766064405, 3.5695930570364, 3.4378883242607117, 1.5277854446321726, 2.8990264143794775, 7.098304582759738, 20.599728226661682, 22.872637063264847, 28.814680315554142, 41.56316913664341, 42.65410579741001, 54.502675607800484, 54.67010982334614, 53.326623514294624, 51.8785098195076, 50.767916813492775, 52.19230458140373, 57.176926508545876, 55.181600376963615, 52.94163577258587, 51.927831172943115, 53.49855288863182, 53.535403311252594, 52.336069867014885, 53.5591596364975, 51.47114887833595, 51.098841056227684, 48.18805284798145, 44.58646930754185, 44.63047854602337, 43.9155089110136, 42.94387064874172, 44.031987860798836, 48.340580463409424, 51.111456379294395, 53.04488003253937, 51.672127693891525, 32.81695045530796, 50.9711717069149, 51.50770291686058, 50.794260799884796, 49.11926127970219, 49.48573641479015, 48.97061325609684, 48.43230754137039, 42.367775961756706, 36.67061626911163, 37.449829056859016, 43.12996186316013, 50.060284584760666, 50.82212470471859, 51.225256472826004, 52.19314053654671, 51.31473407149315, 45.67217744886875, 46.117524951696396, 46.61302976310253, 51.08356587588787, 52.47570477426052, 54.60777796804905, 48.93504336476326, 53.15579988062382, 53.02249923348427, 54.788120090961456, 54.50976222753525, 53.7126599997282, 45.29165826737881, 36.78247466683388, 27.429903522133827, 18.469668924808502, 8.821374848484993, 4.376380490139127, 3.176643317565322, 3.2664543483406305, 5.427854843437672, 3.900890154764056, 5.880238143727183, 3.6352779949083924, 1.9688111543655396, 1.7799026286229491, 0.6264821800868958, 0.208425035525579, 1.1123882909305394, 3.804340660572052, 17.83892747014761, 28.02125059068203, 29.636997990310192, 29.790555350482464, 40.11849045753479, 37.42373205721378, 32.95677915215492, 10.220536720007658, 0.9715644037351012, 0.04007151052064728, 0.07681762799620628, 0.03306621903902851, 0.032942744219326414, 0.04277683918189723, 0.026171574354521, 0.020804880005016457, 0.03392915867152624, 0.008458295105810976, 0.05191223550355062, 0.042594860860845074, 0.03679708075651433, 0.03564290011127014, 0.04203324802801944, 0.04477985865378287, 0.05895674948988017, 0.03170699783368036, 0.07987282733665779, 0.03303828831121791, 0.03951972001232207, 0.04113722716283519, 0.11866863424074836, 0.06283267139224336, 0.09033370311954059, 0.08224004835938103, 0.01644678290176671, 0.03986969459219836, 0.0328086715308018, 0.04236668755766004, 0.04146984290855471, 0.10962627726257779, 0.04574066158966161, 0.07998881017556414, 0.045012974660494365, 0.012109374092688086, 0.02694011836865684, 0.022647421174042393, 0.00822133199108066, 0.003373223999005859, 0.023042099019221496, 0.03017150542291347, 0.057716557639651, 0.04034734454762656, 0.09693680622149259, 0.04158201852987986, 0.03614958288380876, 0.10878319008043036, 0.018295634181413334, 0.02662030095962109, 0.08465699327643961, 0.039238249373738654, 0.028955472334928345, 0.030541419655492064, 0.042594564001774415, 0.06140522084024269, 0.042002048139693215, 0.015509155382460449, 0.009898479984258302, 0.026795310513989534, 0.04235464250086807, 0.03473484903224744, 0.028647039471252356, 0.009858894754870562, 0.06431021320167929, 0.028900675861223135, 0.09599144366802648, 5.830500712618232, 16.547245681285858, 41.564502865076065, 58.734436333179474, 50.63206270337105, 42.823922485113144, 30.604359582066536, 28.754311054944992, 23.11402291059494, 16.534679755568504, 6.0047598369419575, 1.9874094938859344, 0.2900386741384864, 0.2973751601530239, 1.707684772554785, 0.8883114054333419, 3.8772931834682822, 7.223594784736633, 5.3092556074261665, 3.8536282908171415, 3.380856472067535, 4.0518351551145315, 11.016425862908363, 21.945161931216717, 28.779458105564117, 34.90867741405964, 46.82273671030998, 46.91960871219635, 54.169547483325005, 55.29483050107956, 55.45998103916645, 54.70284506678581, 52.34848380088806, 53.47630888223648, 57.34624542295933, 54.94110748171806, 53.731210604310036, 53.49262520670891, 52.35890284180641, 53.63439939916134, 54.06428933143616, 55.167940109968185, 54.09568704664707, 53.54446962475777, 49.79864202439785, 46.210589557886124, 46.40640065073967, 45.39236806333065, 44.65277574956417, 47.390099465847015, 50.9806028008461, 52.98956640064716, 54.873193725943565, 52.408239394426346, 35.468212589621544, 51.65398746728897, 52.643575966358185, 54.12888966500759, 51.202636286616325, 51.7076063901186, 51.78047887980938, 50.24538405239582, 46.57267212867737, 38.173154443502426, 39.1069695353508, 45.69886341691017, 52.55179189145565, 54.44346718490124, 52.11973987519741, 53.22186693549156, 51.958556324243546, 48.22019912302494, 47.24389851093292, 49.34510216116905, 51.853989735245705, 55.35136766731739, 54.886382818222046, 51.13584727048874, 54.65365290641785, 55.57149365544319, 55.683333054184914, 56.79643772542477, 56.09626069664955, 47.85652443766594, 38.6061792075634, 30.4443596675992, 21.14192683249712, 11.705783922225237, 6.028633480891585, 4.980313908308744, 6.467265319079161, 8.454899713397026, 7.084231087937951, 7.161002168431878, 4.03482916764915, 3.6339882016181946, 1.9573499006219208, 0.30707226949743927, 0.2166946089710109, 1.2441190285608172, 4.815636919811368, 17.397461459040642, 31.2421952560544, 29.012754186987877, 36.024339348077774, 46.04759730398655, 41.98572926223278, 38.17635767161846, 12.508314158767462, 1.6230197343975306, 0.07347687249421142, 0.11878176723257639, 0.01707668630842818, 0.016071935242507607, 0.05259323392238002, 0.04904406479909085, 0.04261263158696238, 0.09789141593500972, 0.02252281457913341, 0.047594869320164435, 0.02750584826571867, 0.09199920867104083, 0.0760669307783246, 0.013859754435543437, 0.015400831507577095, 0.04942251187458169, 0.051648220178321935, 0.09855232070549391, 0.021023581648478284, 0.04695023613749072, 0.037493144773179665, 0.05430446319223847, 0.03871490538585931, 0.02230662139481865, 0.014414999641303439, 0.053967743369867094, 0.05364172160625458, 0.01067034232619335, 0.08149473171215504, 0.06383686399203725, 0.039327281119767576, 0.1784411710104905, 0.24683380499482155, 0.10392518786829896, 0.1359045910066925, 0.10477545903995633, 0.14496594696538523, 0.17955572839127854, 0.13548843911848962, 0.15513203426962718, 0.1278795997495763, 0.1375557211576961, 0.1956603626604192, 0.17661685327766463, 0.1272929913830012, 0.2237346812034957, 0.19373622606508434, 0.0895274561480619, 0.1038955464900937, 0.16536026902031153, 0.14464637817582116, 0.15042800543596968, 0.1383348723175004, 0.09710997896036133, 0.1296760275727138, 0.16601845010882244, 0.11150585531140678, 0.18943568808026612, 0.12793644826160744, 0.1891416046419181, 0.11987446836428717, 0.17374659713823348, 0.06004401067912113, 0.16303330950904638, 0.11978734022704884, 0.28905004437547177, 6.371682398021221, 21.393032558262348, 50.47768838703632, 66.21775478124619, 59.54059347510338, 50.839314982295036, 37.87018150091171, 30.560506135225296, 24.21710941940546, 19.2911259457469, 8.168039806187153, 2.8149262396618724, 0.6904741306789219, 0.6417064787819982, 2.0684980927035213, 1.6890283674001694, 8.949722461402416, 7.875527227297425, 9.476384650915861, 7.324752481654286, 3.6497450061142445, 5.048701213672757, 9.599004071205854, 22.583753764629364, 29.974761866033077, 38.365940898656845, 51.460741236805916, 48.4836807847023, 54.59623798727989, 58.753507509827614, 55.80932289361954, 55.4045420140028, 53.7365835160017, 56.04628197848797, 59.68156211078167, 56.34758681058884, 53.962971568107605, 53.1707938760519, 53.16551215946674, 54.02336172759533, 53.000202029943466, 56.27417854964733, 55.111756324768066, 55.99090754985809, 51.54687501490116, 49.20626901090145, 48.914064690470695, 47.377434745430946, 47.291570752859116, 48.229284435510635, 52.75550656020641, 54.594113901257515, 55.69462224841118, 52.40859657526016, 39.84355241060257, 53.754731342196465, 53.068571761250496, 56.14250421524048, 52.689564898610115, 55.65282069146633, 53.34557309746742, 52.777632772922516, 45.9369320422411, 39.352816343307495, 41.440899297595024, 48.852150812745094, 53.60846199095249, 56.02222166955471, 51.981374099850655, 54.19410176575184, 55.51993042230606, 51.31336994469166, 50.80179579555988, 52.15432181954384, 54.04619850218296, 55.99146232008934, 54.519774690270424, 52.221859395504, 55.32041072845459, 56.48960039019585, 58.00580643117428, 59.35789167881012, 57.347674146294594, 48.207872584462166, 40.60525953769684, 31.11537706106901, 21.246273033320904, 12.17401759698987, 7.182935066521168, 6.499728402122855, 9.489511996507645, 13.341511599719524, 13.479280807077885, 16.2280286103487, 11.425513811409473, 7.8052713721990585, 4.8414902575314045, 1.8419221881777048, 0.4431886546080932, 2.0155733451247215, 5.307533349841833, 24.169672764837742, 37.128704488277435, 41.74879677593708, 42.993944361805916, 52.57213979959488, 51.738654524087906, 43.25352743268013, 17.075871415436268, 1.7545692692510784, 0.20467102993279696, 0.16741497907787561, 0.13395536981988698, 0.11658282819553278, 0.11690758459735662, 0.14782988000661135, 0.12609624856850132, 0.21552479127421975, 0.1767706559621729, 0.1483253823244013, 0.13440549722872674, 0.15436829009559005, 0.14701072708703578, 0.11147240671562031, 0.23618293198524043, 0.16465855354908854, 0.22336889145663008, 0.18819535151124, 0.08751865534577519, 0.12699957587756217, 0.20910558494506404, 0.22147357987705618, 0.14578643575077876, 0.1879851901321672, 0.22182414075359702, 0.10232790053123608, 0.1325929054291919, 0.2588280395139009, 0.20475156779866666, 0.20289989450247958, 0.11388384489691816], [0.036165205092402175, 0.06869855467812158, 0.03903352793713566, 0.0676726691017393, 0.02792899489577394, 0.034265474023413844, 0.04047750240715686, 0.05847337386512663, 0.045378500944934785, 0.04301053035305813, 0.039978159475140274, 0.06593522717594169, 0.04154803558776621, 0.05784708286228124, 0.0388144125463441, 0.026617117146088276, 0.024999814086186234, 0.028577138436958194, 0.010838507423613919, 0.014632754118792946, 0.02769761922536418, 0.02324535100342473, 0.021058787278889213, 0.05829111723869573, 0.06647802656516433, 0.05468186383950524, 0.03477695106994361, 0.06306054041488096, 0.07592896552523598, 0.01363486884656595, 0.05629380488244351, 0.043582165890256874, 0.04683358907641377, 0.10085032161441632, 0.01262102554392186, 0.6273436057381332, 9.478514436632395, 22.227137200534344, 50.73359705507755, 47.05200120806694, 45.00477746129036, 29.447941035032272, 36.468140333890915, 30.655639730393887, 14.714389331638813, 6.048093661665916, 2.4762751115486026, 0.2630192443029955, 0.3148489975137636, 1.2277484382502735, 0.640280427178368, 2.8369422582909465, 8.241993337869644, 4.4018918462097645, 1.4243722124956548, 2.3039650451391935, 1.6163018136285245, 6.293504917994142, 13.248250354081392, 19.075939692556858, 19.333594366908073, 37.919335663318634, 37.029172629117966, 53.7756834179163, 54.43424507975578, 59.193493500351906, 52.00990676879883, 55.12133561074734, 51.63937725126743, 55.547699332237244, 55.68287707865238, 56.4449717849493, 50.46890325844288, 51.746216118335724, 53.164672404527664, 52.84145414829254, 52.98540562391281, 53.19009304046631, 48.95192965865135, 46.155272126197815, 45.24235211312771, 43.881964311003685, 42.56940454244614, 43.201299235224724, 45.78619793057442, 50.80616936087608, 47.92767561972141, 51.55118778347969, 52.69508980214596, 35.30023120343685, 50.54328426718712, 52.86335617303848, 49.52558487653732, 47.512380704283714, 44.182524383068085, 39.69703987240791, 36.81003458797932, 38.64714480936527, 38.47755990922451, 41.07573129236698, 47.96769507229328, 50.47181770205498, 50.35880796611309, 51.1224377900362, 51.33020304143429, 52.30352841317654, 48.049041107296944, 45.840793401002884, 47.8881311416626, 50.65040051937103, 51.71296410262585, 53.703494891524315, 51.00463651120663, 53.75744819641113, 52.29549944400787, 53.712849989533424, 54.76276785135269, 47.76769280433655, 40.35184733569622, 28.22474867105484, 22.5352056697011, 13.056157361716032, 7.489599036052823, 2.7387153916060925, 1.7130034184083343, 4.692493127658963, 6.464623510837555, 4.6214711386710405, 5.756581854075193, 1.639483894687146, 2.297979653812945, 0.7237947208341211, 0.16750936541939154, 0.20250544301234186, 2.1105148131027818, 7.048946181312203, 22.75845129042864, 25.587591379880905, 26.91830277442932, 29.26221650093794, 37.54657566547394, 42.32211381196976, 25.55546410381794, 4.772279346361756, 0.1870158116798848, 0.05265433865133673, 0.11612771355430596, 0.09391193103510886, 0.09660995696322061, 0.016607532088528387, 0.029406213870970532, 0.017191095794260036, 0.034609563372214325, 0.008504486377205467, 0.036530156212393194, 0.028980386232433375, 0.04739774376503192, 0.03158960120345, 0.05930218583671376, 0.11031201429432258, 0.09148438082775101, 0.018461667459632736, 0.04703212471213192, 0.04483063268708065, 0.11674018576741219, 0.06251586339203641, 0.04118796037801076, 0.013547187809308525, 0.057955718439188786, 0.01542844867799431, 0.02046932164375903, 0.01634486561670201, 0.016740947976359166, 0.015095022135938052, 0.045070227643009275, 0.07478824743884616, 0.040166872786358, 0.03510634589474648, 0.016742458246881142, 0.04467699698579963, 0.040185608304454945, 0.037941709961160086, 0.04089742069481872, 0.09372902874019928, 0.036014059296576306, 0.025142835220322013, 0.046725294887437485, 0.06729110871674493, 0.024139193665178027, 0.02437584971630713, 0.03432994068134576, 0.017934273200808093, 0.05532320930797141, 0.027733797069231514, 0.0065385422840336105, 0.041070296574616805, 0.04676292548538186, 0.002365456566622015, 0.0279651449091034, 0.0556408039847156, 0.02932568713731598, 0.028963116455997806, 0.052777045348193496, 0.03735497914021835, 0.038806096781627275, 0.04874974758422468, 0.021828145800100174, 0.01758363996486878, 0.06022322450007778, 0.04904383844404947, 0.04613550270732958, 0.9433513332623988, 11.047544293105602, 29.365688748657703, 56.81170530617237, 53.89622814953327, 49.84382539987564, 31.848346330225468, 27.50351507216692, 28.261901177465916, 18.89354757964611, 9.377271719276905, 3.1313333613798022, 0.3147657582303509, 0.14371115335961804, 0.5684163083788007, 2.070161453448236, 2.700572800822556, 4.246227974072099, 7.150110052898526, 3.623042651452124, 3.0992609448730946, 2.9758521169424057, 6.436978569254279, 13.971138764172792, 21.485325805842876, 26.63760993629694, 37.4933785200119, 41.96964092552662, 54.31580923497677, 55.67205145955086, 59.81186851859093, 53.69798518717289, 54.98679623007774, 55.229398012161255, 56.691510155797005, 56.35944217443466, 55.43397143483162, 49.557408168911934, 51.44507847726345, 53.38584713637829, 54.53199863433838, 54.014063626527786, 54.209920316934586, 51.889422833919525, 49.87198568880558, 47.21324175596237, 46.013231948018074, 45.49623169004917, 44.846895933151245, 47.35699564218521, 51.79806053638458, 52.66596056520939, 54.5137520134449, 53.112622797489166, 38.556591868400574, 51.667556539177895, 54.07586731016636, 51.75784349441528, 50.17986796796322, 48.55237729847431, 44.149390161037445, 39.91414502263069, 39.99592803418636, 40.11079587042332, 41.887436136603355, 49.444713816046715, 51.98909908533096, 53.16032163798809, 51.50830328464508, 52.660298869013786, 52.592449709773064, 49.80890527367592, 47.5804578512907, 50.12276463210583, 52.74739779531956, 53.5352399200201, 53.25473137199879, 50.82798399031162, 54.101797118783, 53.3315746486187, 55.065904185175896, 56.45893603563309, 48.52558873593807, 44.648766964673996, 31.94908082485199, 25.940951518714428, 15.218564327806234, 7.113641509786248, 4.486449183896184, 5.584257775917649, 8.26766001060605, 10.600614175200462, 7.310852352529764, 6.979810791090131, 4.760288139805198, 1.7146292561665177, 1.0881201806478202, 0.23744333622744307, 0.24601963930763304, 2.3679407872259617, 7.36459381878376, 24.426658675074577, 30.95790971070528, 30.988819152116776, 31.73477042466402, 43.14668856561184, 48.482054471969604, 29.97720893472433, 6.196422502398491, 0.2511886088177562, 0.046772825735388324, 0.1194904292060528, 0.005345530153135769, 0.09660728523158468, 0.06449579464970157, 0.03576716531824786, 0.054713438512408175, 0.018950158337247558, 0.13127243175404146, 0.03962396949646063, 0.04331765703682322, 0.017450237064622343, 0.057799429559963755, 0.040128551991074346, 0.10640384978614748, 0.05705735238734633, 0.029182888647483196, 0.08072260126937181, 0.02362814891966991, 0.06653799951891415, 0.017722364063956775, 0.014061769816180458, 0.02460652220179327, 0.03977632128226105, 0.06745157588738948, 0.02540437548304908, 0.03200030201696791, 0.023099947575246915, 0.03039739476662362, 0.014428331396629801, 0.03171436736010946, 0.15483651106478646, 0.13756857515545562, 0.09633750712964684, 0.2409407071536407, 0.11161953749251552, 0.14128511713352054, 0.18112928926711902, 0.13794456201139838, 0.13143326999852434, 0.12443316983990371, 0.17682551551843062, 0.14194099756423384, 0.1282833726145327, 0.12912841164506972, 0.18394477490801364, 0.16083873430034146, 0.11460631823865697, 0.11890566136571579, 0.14875107823172584, 0.09241005420335568, 0.2203858585562557, 0.11868729183333926, 0.08734748640563339, 0.09212181146722287, 0.07126286043785512, 0.13905453291954473, 0.09765521259396337, 0.1473825579159893, 0.1992434071144089, 0.1290059127495624, 0.18522640457376838, 0.1783513859845698, 0.1800342058413662, 0.22046845959266648, 0.2020993546466343, 1.2153554032556713, 14.330414235591888, 36.09482556581497, 68.17337304353714, 60.258333161473274, 58.87228153645992, 42.1528746932745, 47.24865585565567, 42.283412888646126, 20.896553099155426, 10.39041230455041, 3.4601876651868224, 0.8050920115783811, 0.7459138089325279, 2.8369959304109216, 4.304905375465751, 6.152797993272543, 16.743740737438202, 14.795446582138538, 5.791779365390539, 6.3895542640239, 3.0452895909547806, 7.398929726332426, 14.584732688963413, 23.186127841472626, 30.394010469317436, 47.474394142627716, 43.45233656466007, 55.29747515916824, 55.53747408092022, 62.819091752171516, 54.90228496491909, 56.76584556698799, 56.63170516490936, 58.97486463189125, 57.44445875287056, 56.709080412983894, 49.743362590670586, 51.480823159217834, 53.47321964800358, 54.552635326981544, 54.31074410676956, 55.655738934874535, 52.58887030184269, 50.512608513236046, 49.74716618657112, 47.86528296768665, 45.892322435975075, 46.855323761701584, 49.94708485901356, 56.35486342012882, 53.37352819740772, 54.72537025809288, 53.974762335419655, 43.02581325173378, 52.87364602088928, 55.656578689813614, 54.09788332879543, 52.4260338395834, 49.42226082086563, 43.79494518041611, 40.46647198498249, 41.26487374305725, 42.39241003990173, 45.0297649204731, 52.91235834360123, 55.42952187359333, 55.165941417217255, 51.06154605746269, 53.61551821231842, 54.85750436782837, 52.14150510728359, 49.65367220342159, 51.46874360740185, 54.30703550577164, 55.329625234007835, 53.35335128009319, 50.96060447394848, 53.3444369584322, 54.470510333776474, 56.39269419014454, 58.14204052090645, 51.482187286019325, 44.48330104351044, 33.2694111764431, 26.253517046570778, 17.456599585711956, 10.588219240307808, 4.713725438341498, 4.904982475563884, 9.594758749008179, 14.712860863655806, 9.563710615038872, 14.204853773117065, 8.978492617607117, 3.2020770153030753, 2.131749498657882, 0.6979089661035687, 0.6951972772367299, 3.1082875980064273, 9.60890918970108, 29.23025071620941, 37.34587803483009, 36.803122758865356, 40.358660370111465, 50.441115349531174, 54.99059982597828, 33.07341389358044, 7.572113508358598, 0.4501410049851984, 0.13204205373767763, 0.19970178720541298, 0.15485785523196682, 0.19513890001690015, 0.11958850402152166, 0.11014599585905671, 0.12482377700507641, 0.12510105822002515, 0.2374944553594105, 0.15867443871684372, 0.12228623309056275, 0.10326613104552962, 0.11379554416635074, 0.1190886007680092, 0.2890890516573563, 0.2134173590457067, 0.09905456914566457, 0.15846674126805738, 0.1219595767906867, 0.2745655184844509, 0.14142824773443863, 0.07845227504731156, 0.1219520736776758, 0.18906605400843546, 0.11036949363187887, 0.12033295977744274, 0.14851604006253183, 0.11110079853096977, 0.08720490499399602, 0.1535730788600631, 0.14485122577752918], [0.02624729382660007, 0.05586717386904638, 0.03455035483057145, 0.08947547612478957, 0.021850547527719755, 0.09565894666593522, 0.049413799060857855, 0.014640422359661898, 0.036471181447268464, 0.11035060597350821, 0.09235695353709161, 0.02153368572180625, 0.018779340061882976, 0.05262851562292781, 0.04738281175377779, 0.04029228461149614, 0.05254570678516757, 0.018553934969531838, 0.06210017163539305, 0.0634048153006006, 0.026597923351801, 0.009957621732610278, 0.037344344164012, 0.07276598407770507, 0.03464643697952852, 0.011413022493798053, 0.05174142279429361, 0.05472390279464889, 0.04084162232175004, 0.011639597396424506, 0.0196997349121375, 0.052287751095718704, 0.020527300075627863, 0.03860057011479512, 0.017463818367104977, 0.09461843335884623, 2.905882908962667, 10.25898590683937, 36.52553625404835, 53.93199943006039, 38.77624288201332, 31.115361861884594, 31.28645148128271, 21.634851582348347, 21.83773409575224, 11.422871053218842, 5.779231013730168, 1.132713994011283, 0.05416370746388566, 0.4706622491357848, 1.2529402552172542, 1.6859924490563571, 3.4009001590311527, 3.7030863063409925, 2.917510522529483, 2.381475898437202, 1.8321949476376176, 5.217277742922306, 10.21007303148508, 14.752841368317604, 15.121924113482237, 30.737481638789177, 32.6156410574913, 48.859321027994156, 55.360848158597946, 56.57310090959072, 53.84604424238205, 51.77685767412186, 54.309493973851204, 53.983653858304024, 52.1879044175148, 51.86421878635883, 54.06001456081867, 52.353932708501816, 53.24070632457733, 54.31331656873226, 55.06790287792683, 53.18456433713436, 50.15108071267605, 46.15162432193756, 41.28406651318073, 42.407571226358414, 41.30332387983799, 42.68568970263004, 42.67964042723179, 49.03823062777519, 49.14514169096947, 49.78518694639206, 53.94371420145035, 33.22433039546013, 50.766613483428955, 51.713511273264885, 47.6322490721941, 46.55423931777477, 43.809581995010376, 41.062424406409264, 42.37368084490299, 43.494058325886726, 43.641558811068535, 47.22816355526447, 48.52281868457794, 50.54874077439308, 51.56838186085224, 50.36186300218105, 50.791661739349365, 51.94755211472511, 49.29498665034771, 46.57102681696415, 46.706356555223465, 50.99984496831894, 53.35776664316654, 55.090093687176704, 50.35898655653, 54.90954637527466, 53.926466926932335, 51.71255372464657, 53.828511983156204, 45.25882802903652, 37.55656152963638, 25.536406226456165, 18.672587536275387, 10.344221983104944, 3.6612213402986526, 3.4855593787506223, 8.738696034997702, 9.78915061801672, 8.653318416327238, 4.242390654981136, 4.111908506602049, 3.0573860043659806, 1.4264086657203734, 1.3306546350941062, 0.016927060059970245, 0.30345299339387566, 1.9970448268577456, 9.620481468737125, 22.49352190643549, 23.19038551300764, 19.21275705099106, 30.00431288033724, 44.060106351971626, 32.178504914045334, 16.448080502450466, 2.9615589464083314, 0.020085534815734718, 0.07366568228462711, 0.12219173542689532, 0.009463330043217866, 0.0665311272314284, 0.09383496289956383, 0.007599154341733083, 0.04024395966553129, 0.056531095469836146, 0.08058770108618774, 0.018268601452291477, 0.030851151277602185, 0.03368902194779366, 0.10723008279455826, 0.01353579120404902, 0.026049170082842465, 0.05456060804135632, 0.04204130404104944, 0.017286170477746055, 0.04861152629018761, 0.008993269475467969, 0.06794651417294517, 0.012926798735861667, 0.0431622067844728, 0.0984313506342005, 0.036970171859138645, 0.03554724469722714, 0.10404470333014615, 0.019614786833699327, 0.04858281259657815, 0.011709606042131782, 0.11718234251020476, 0.051459499445627443, 0.053864967048866674, 0.05277956122881733, 0.043069946696050465, 0.0543195065256441, 0.04258438173565082, 0.06964946849620901, 0.03856873569020536, 0.021592007396975532, 0.09310706445830874, 0.046426970075117424, 0.08787522761849687, 0.0152258776142844, 0.08277767497929744, 0.05533356226806063, 0.03771140669414308, 0.01751835323375417, 0.02075364398478996, 0.05328493411070667, 0.02438627132505644, 0.021554796112468466, 0.02735060581471771, 0.021095102420076728, 0.06251764454646036, 0.036917086035828106, 0.017438464747101534, 0.02654724765307037, 0.03763712142244913, 0.035852182045346126, 0.0015104724093362165, 0.03360780501679983, 0.009750098688527942, 0.011855222837766632, 0.034036350771202706, 0.029380246123764664, 0.08934139972552657, 4.603400258347392, 15.681323446333408, 47.29683727025986, 58.68651330471039, 46.86472825706005, 34.75993439555168, 38.969291523098946, 26.112341322004795, 23.028343208134174, 11.783289313316345, 5.372299449518323, 0.9498798579443246, 0.0908316248387564, 0.436599540989846, 1.056310662534088, 2.230370594188571, 5.634046504274011, 5.087247295305133, 3.362446934916079, 3.3285024063661695, 3.1751260114833713, 5.937231760472059, 9.7737623937428, 19.28041622042656, 21.425684206187725, 34.03182126581669, 37.33536779880524, 50.17149321734905, 54.92079757153988, 58.78566138446331, 56.150441989302635, 54.816219583153725, 56.25712126493454, 56.16744227707386, 53.62626023590565, 55.2531049400568, 55.11806398630142, 53.368368074297905, 54.18733432888985, 53.68793472647667, 56.15574270486832, 54.69274140894413, 53.497895523905754, 49.64103028178215, 44.56223800778389, 44.74083982408047, 43.71559403836727, 45.23644722998142, 46.398310884833336, 49.49110172688961, 52.44474783539772, 53.80125604569912, 54.08820904791355, 35.514330714941025, 52.05459237098694, 54.59320954978466, 50.834048464894295, 49.047631323337555, 45.25041148066521, 43.04907560348511, 43.400989919900894, 44.45262908935547, 44.371488243341446, 49.52536828815937, 49.97545413672924, 51.79630123078823, 54.759306237101555, 51.6229697316885, 51.77181534469128, 53.50225009024143, 50.751159712672234, 48.5936164855957, 49.59766320884228, 51.48491933941841, 55.840568616986275, 54.1819804161787, 52.12412863969803, 55.23948647081852, 54.74215775728226, 53.687630742788315, 54.60832893848419, 47.89039582014084, 39.94265869259834, 27.430957965552807, 20.11957459151745, 11.293077617883682, 4.681356875225902, 5.540961949154735, 6.46605983376503, 7.601609900593758, 8.559489101171494, 9.523464124649763, 5.129033178091049, 3.9128181897103786, 2.3778107576072216, 0.5910695646889508, 0.018706258924794383, 0.35000085190404207, 2.5959216663613915, 10.789353847503662, 26.10825464129448, 27.49747909605503, 20.54170724004507, 31.25108677893877, 50.351025983691216, 39.70253437757492, 20.941512286663055, 3.386458083987236, 0.11523139211931266, 0.02784609328955412, 0.09280157421017066, 0.02616040874272585, 0.045900130571681075, 0.08839785543386824, 0.025856341562757734, 0.05290606030030176, 0.020440797197807115, 0.037759679689770564, 0.04817362205358222, 0.003075729696320195, 0.054965709350653924, 0.0702077490859665, 0.02747242007899331, 0.033235217197216116, 0.054927633464103565, 0.0021861228424313595, 0.03245257794333156, 0.05687575256160926, 0.06302976355073042, 0.05180218242458068, 0.03624256656621583, 0.05288505752105266, 0.03710375473019667, 0.02861060929717496, 0.04994807117327582, 0.04126378560613375, 0.013976223381177988, 0.0974719763325993, 0.034818515050574206, 0.027244335833529476, 0.1197789391153492, 0.1674764437484555, 0.12353822879958898, 0.19965985586168244, 0.1559367004665546, 0.14048796147108078, 0.254538010340184, 0.12753746967064217, 0.0662797321274411, 0.26661005162168294, 0.12127522757509723, 0.20190737588563934, 0.08059602056164294, 0.15589251299388707, 0.12328650715062395, 0.08465680031804368, 0.1623840193497017, 0.12479351222282276, 0.12110333133023232, 0.22525920096086338, 0.16816521616419777, 0.1297566099674441, 0.0724092559539713, 0.2298942842753604, 0.10124170061317272, 0.08488587161991745, 0.1755715679610148, 0.13845612440491095, 0.1325490593444556, 0.13421666517388076, 0.15788633725605905, 0.13528897950891405, 0.10464775768923573, 0.2484747677226551, 0.12112141004763544, 0.25450401997659355, 5.146214906126261, 18.23075294494629, 51.82096190750599, 67.53955945372581, 52.40302987396717, 42.512601390480995, 44.56109046936035, 30.866904594004154, 29.055182710289955, 15.303651262074709, 7.695086309686303, 1.8370830290950835, 0.3081514115910977, 1.5058694081380963, 2.3964207340031862, 6.199373044073582, 13.292183596640825, 8.514544162899256, 8.532475400716066, 4.8840308748185635, 4.172308640554547, 7.09159841760993, 12.117359787225723, 22.13977038860321, 22.302872836589813, 39.06436622142792, 40.114626064896584, 51.801579147577286, 56.75186611711979, 59.265112057328224, 57.50063493847847, 56.14267900586128, 57.817792519927025, 57.291380167007446, 56.5544743090868, 55.721570402383804, 54.72879387438297, 53.93339015543461, 54.649853110313416, 55.366403460502625, 58.99157993495464, 56.93791173398495, 55.495322942733765, 50.86566276848316, 46.62073954939842, 47.811192870140076, 46.24496251344681, 47.54277907311916, 47.07805261015892, 54.15972501039505, 54.6562709659338, 55.39534270763397, 54.15129706263542, 39.14946645498276, 54.14572276175022, 56.191327795386314, 52.220415472984314, 50.46761132776737, 47.92417220771313, 44.126709178090096, 45.92884987592697, 47.59192183613777, 47.907259315252304, 52.18665808439255, 51.68203376233578, 53.71070310473442, 54.690541326999664, 51.9113552570343, 52.24481776356697, 55.943068116903305, 53.7295500934124, 50.525007247924805, 51.059448570013046, 54.19370278716087, 57.976365610957146, 56.300697326660156, 51.52712367475033, 56.52233563363552, 55.630785673856735, 54.84028749167919, 56.12169273197651, 48.773232847452164, 40.93866124749184, 29.042690880596638, 23.32184135913849, 13.418922945857048, 5.700557185336947, 6.18180563673377, 13.543525859713554, 16.43168818205595, 18.41098677366972, 11.57336862757802, 11.087153367698193, 11.469894479960203, 4.956603180617094, 2.430377611890435, 0.09433628365513869, 0.9116024931427091, 3.2711508963257074, 14.592662863433361, 29.07238818705082, 35.82383930683136, 29.510774463415146, 40.396734327077866, 58.08775283396244, 45.47645755112171, 24.070102907717228, 4.40368914976716, 0.17894357530167326, 0.13521476474124938, 0.3534131875494495, 0.09154155588475987, 0.17983082769205794, 0.16419337538536638, 0.08157115065841936, 0.1739942963467911, 0.13926191866630688, 0.14754900679690763, 0.14343394635943696, 0.20060922601260245, 0.21300865832017735, 0.2813174593029544, 0.10398400307167321, 0.09219083120115101, 0.1533119022496976, 0.0951600972621236, 0.07849606918171048, 0.12828951759729534, 0.08335795282619074, 0.15121515694772825, 0.09437291606445797, 0.15326890221331269, 0.22141174413263798, 0.09252895368263125, 0.2704547328175977, 0.24380780174396932, 0.09964903685613535, 0.20934184023644775, 0.09940432108123787, 0.2267011345247738], [0.010170044806727674, 0.056792442774167284, 0.01790357240679441, 0.0229096163820941, 0.007740017681499012, 0.05656042885675561, 0.049542168344487436, 0.020683427537733223, 0.022042401978978887, 0.04885579677647911, 0.047823443383094855, 0.051374627437326126, 0.013606301727122627, 0.0042177620798611315, 0.030156675456964877, 0.0719999466673471, 0.0586443498468725, 0.021260553112369962, 0.09054098496562801, 0.04913060663966462, 0.022363733369274996, 0.02817669967043912, 0.0579824505985016, 0.044383002605172805, 0.035622598661575466, 0.0606314650940476, 0.05162956258573104, 0.012466681091609644, 0.03391968144569546, 0.18016333953710273, 0.05220332808676176, 0.05258707038592547, 0.01270808596018469, 0.04762590222526342, 0.07114827283658087, 0.059804861011798494, 1.324952447321266, 6.196521772071719, 20.134441293776035, 51.57673381268978, 39.546727538108826, 30.531306602060795, 16.840987019240856, 22.91665770113468, 26.932025738060474, 21.32547788321972, 7.849159017205238, 1.4752962486818433, 0.2901833038777113, 0.16988974472042173, 0.8537448383867741, 1.267240906599909, 3.5425869561731815, 4.954743180423975, 2.0520860608667135, 2.332404381595552, 1.674330874811858, 2.0262158615514636, 3.8283138116821647, 12.26338405162096, 11.138643454760313, 23.989210948348045, 31.500421799719334, 41.08591854572296, 52.02602930366993, 52.125781551003456, 55.53207077085972, 53.83900322020054, 54.287413358688354, 55.219605937600136, 54.46911200881004, 51.38851851224899, 51.45418278872967, 52.80110031366348, 53.49466189742088, 52.94962674379349, 52.939857468008995, 50.727502182126045, 50.94535209238529, 46.42054349184036, 42.94911816716194, 42.087958976626396, 43.9820509403944, 43.36239919066429, 45.02867057919502, 47.07500897347927, 50.762464106082916, 49.61665078997612, 55.09427346289158, 34.968212619423866, 47.80313350260258, 52.50147119164467, 49.726358503103256, 48.87936495244503, 46.226978078484535, 48.87718006968498, 47.38951809704304, 49.56485956907272, 50.38026161491871, 49.56273928284645, 47.87502944469452, 52.42610223591328, 50.83058305084705, 52.250000685453415, 47.310410141944885, 50.742792561650276, 51.96424841880798, 49.16020788252354, 48.28521363437176, 49.72329206764698, 51.94865025579929, 54.28071051836014, 53.24935846030712, 49.96865630149841, 58.23956988751888, 48.32003876566887, 51.56365491449833, 40.105324164032936, 32.88709469139576, 20.38204550743103, 12.805310022085905, 5.7063214760273695, 2.0282311784103513, 2.5422963313758373, 4.097835011780262, 5.447954339906573, 9.28445030003786, 9.871625192463398, 4.346957243978977, 2.858986775390804, 1.295504264999181, 0.13814204750815406, 0.08346427290234715, 0.7187088718637824, 3.3671332709491253, 11.938852965831757, 29.877209700644016, 24.908780604600906, 30.94846721738577, 40.26061803102493, 49.259910732507706, 29.326250664889812, 10.999601315706968, 1.6883047437295318, 0.045659941897611134, 0.039533887611469254, 0.0578293863509316, 0.037141184948268346, 0.060369561178958975, 0.0870952452532947, 0.026183788249909412, 0.04990893401554786, 0.013159322879801039, 0.030378687079064548, 0.027621725348581094, 0.04295925908081699, 0.04632683951058425, 0.05098313340567984, 0.12092761302483268, 0.06812575025833212, 0.04024971873150207, 0.093576116632903, 0.02742463690083241, 0.025244134667445906, 0.01712938250420848, 0.007654783412363031, 0.040836627667886205, 0.050858493414125405, 0.04174736903223675, 0.02361085502343485, 0.020770115952473134, 0.004946741273670341, 0.045819960068911314, 0.012814796591555933, 0.03320268515381031, 0.04081767321622465, 0.017268175251956563, 0.04423795726324897, 0.008899228232621681, 0.05968655525066424, 0.00784539708547527, 0.007372232948910096, 0.033174657946801744, 0.027439535515441094, 0.04410401816130616, 0.020948908604623284, 0.06853123006294481, 0.09688221383839846, 0.024728505304665305, 0.0446689483942464, 0.060513055432238616, 0.04558997221465688, 0.03559398144716397, 0.0335475463361945, 0.07332140739890747, 0.029961010077386163, 0.06747827836079523, 0.04281962028471753, 0.09565382584696636, 0.05195677549636457, 0.0267358496421366, 0.034099926851922646, 0.031237864022841677, 0.01581110558618093, 0.047130010279943235, 0.07747738243779168, 0.021472087464644574, 0.009020156558108283, 0.043008597058360465, 0.04629842638678383, 0.05293409863952547, 0.0387759692966938, 1.8498832359910011, 8.91496192663908, 26.2961545586586, 60.1638588309288, 42.058290168643, 37.19168230891228, 20.912090465426445, 27.235397659242153, 28.272301219403744, 21.315005645155907, 9.68640223145485, 1.49411806371063, 0.1978507373132743, 0.07084821510943584, 0.5228788394015282, 2.0549128716811538, 3.6998617043718696, 8.558677844703197, 5.820252187550068, 4.338148841634393, 4.908869666978717, 3.443639315664768, 8.299370259046555, 12.535390555858612, 15.876768808811903, 25.89645590633154, 34.85280141234398, 44.50203783810139, 52.22329951822758, 54.19317841529846, 58.058540001511574, 55.84776163101196, 56.45526543259621, 55.1102402061224, 57.20810003578663, 54.855794459581375, 53.01743030548096, 53.424415066838264, 56.005582362413406, 54.84850265085697, 54.249377399683, 52.43468597531319, 52.573302537202835, 48.29421915113926, 46.57343968749046, 44.72029432654381, 46.31041780114174, 45.03009930253029, 47.040480226278305, 48.39551031589508, 52.05559551715851, 51.479124650359154, 55.91573618352413, 39.03499759733677, 51.322877034544945, 54.39948834478855, 51.2615255266428, 51.219176799058914, 48.16660679876804, 50.92067241668701, 49.908554926514626, 52.48962342739105, 52.51838028430939, 52.59930454194546, 51.270466446876526, 53.53452555835247, 51.85403533279896, 52.273453027009964, 50.08796609938145, 52.35116645693779, 53.594281151890755, 51.8966918438673, 49.934845715761185, 51.76279462873936, 53.978174552321434, 54.934644028544426, 52.12678089737892, 52.44341030716896, 58.40189717710018, 50.80717630684376, 52.31327868998051, 43.45697611570358, 34.04682666063309, 23.31604477018118, 15.569527745246887, 7.068063905462623, 3.5417289147153497, 5.417587794363499, 9.701945297420025, 7.280843462795019, 6.490500597283244, 5.473658535629511, 4.79691912420094, 3.0149133084341884, 1.6970416624099016, 0.37088266108185053, 0.08286662879982032, 0.706149892648682, 3.5053062066435814, 12.60885676369071, 33.9495100826025, 27.273893393576145, 31.95715919137001, 42.619843035936356, 54.94127467274666, 35.209739059209824, 13.016026765108109, 2.2612774232402444, 0.01926381592056714, 0.03038882110558916, 0.06220276241947431, 0.015655660899938084, 0.05029188592743594, 0.09687205383670516, 0.01877560149296187, 0.06349973598844372, 0.06187427672557533, 0.05599956559308339, 0.0222985319851432, 0.034295597797608934, 0.08367815244127996, 0.046780414195382036, 0.04834572238905821, 0.02049383292614948, 0.013968914154247614, 0.05132451762619894, 0.023615877507836558, 0.010855695563805057, 0.04472013431950472, 0.015365386534540448, 0.06054907928046305, 0.029339747125050053, 0.023845087962399703, 0.05467609364131931, 0.019343565254530404, 0.06456015369622037, 0.0334440798178548, 0.027132173199788667, 0.10037887972430326, 0.019452369670034386, 0.1414400478824973, 0.09626479892176576, 0.10361039108829573, 0.17985381942708045, 0.08792832086328417, 0.13603728701127693, 0.1152333291247487, 0.1659739954629913, 0.15712571010226384, 0.0987460212490987, 0.12060836335876957, 0.13741866132477298, 0.11878058721777052, 0.14929155469872057, 0.10725241401814856, 0.13551978743635118, 0.15244697366142645, 0.1657710922881961, 0.16944018134381622, 0.22163968737004325, 0.1417730940738693, 0.14628177479607984, 0.210683865880128, 0.16501361184054986, 0.10508825944270939, 0.17121701646829024, 0.16039665177231655, 0.11648730636807159, 0.18897609086707234, 0.22888616571435705, 0.09976107889087871, 0.11629151296801865, 0.22645300487056375, 0.11872006507473998, 0.14864349650451913, 0.15449262951733544, 2.1536755096167326, 11.592628844082355, 34.7305353730917, 67.71357491612434, 51.84743128716946, 43.460604920983315, 27.009467482566833, 35.2567121386528, 35.921885445714, 26.534593664109707, 10.401814542710781, 2.102449983358383, 0.5798094032797962, 0.4437774745747447, 2.6192089542746544, 3.546525682322681, 5.153052639216185, 12.798992861062288, 8.957283105701208, 6.395380776375532, 4.867208227515221, 4.035663697868586, 5.291571831330657, 14.327484592795372, 17.990106157958508, 29.896375872194767, 37.526695132255554, 45.33969908952713, 54.696852788329124, 56.1062503606081, 59.226354137063026, 56.921599209308624, 57.015841752290726, 57.91974864900112, 58.068016692996025, 56.737765073776245, 54.67234030365944, 55.49771301448345, 55.667966678738594, 55.84425821900368, 54.93270233273506, 54.807259663939476, 55.14058917760849, 51.1690878868103, 47.82735340297222, 46.59772798418999, 47.56765253841877, 47.862805500626564, 48.76861609518528, 51.298729330301285, 56.118310913443565, 53.9109143614769, 57.01135419309139, 42.59160295128822, 51.79772615432739, 55.35927124321461, 54.03145909309387, 53.311754912137985, 50.06162591278553, 53.99007551372051, 51.54085993766785, 53.456238359212875, 55.298573300242424, 54.594277292490005, 52.00659714639187, 56.24118112027645, 53.56063015758991, 53.2754972577095, 51.99294447898865, 53.04989196360111, 55.248476788401604, 53.21576826274395, 52.573541924357414, 54.767521396279335, 56.31172813475132, 54.98944088816643, 54.071755930781364, 51.572842821478844, 60.83900660276413, 53.813772574067116, 52.940697222948074, 44.92259167134762, 37.65181861817837, 24.204805679619312, 15.855905078351498, 8.098664078861475, 4.026628257706761, 6.905133873224258, 11.581190507858992, 13.676126394420862, 18.228366672992706, 19.32817965745926, 10.673383120447397, 5.505826184526086, 3.63991707097739, 0.5068463715724647, 0.5708409938961267, 1.13654620712623, 4.964693421497941, 16.065598726272583, 39.97562192380428, 34.56901744008064, 43.50051797926426, 51.09613940119743, 61.202384904026985, 42.14813254773617, 15.975304171442986, 2.4654468800872564, 0.1285494028707035, 0.12068883443134837, 0.12298146961256862, 0.15027107088826597, 0.11679805102176033, 0.1789821224519983, 0.15599399426719174, 0.1221404604439158, 0.14903710194630548, 0.20570527209201828, 0.10901978675974533, 0.1135811822314281, 0.17265884613152593, 0.11963614248088561, 0.16674465645337477, 0.16282819473417476, 0.1351810563937761, 0.24986521108075976, 0.21471166459377855, 0.12261369833140634, 0.13023436011280864, 0.09810896168346517, 0.13639111333759502, 0.1924115518340841, 0.09651020489400253, 0.13043511105934158, 0.10191461333306506, 0.17124545556725934, 0.10203182071563788, 0.08781351803918369, 0.28562639839947224, 0.12226692982949317], [0.05455729806271847, 0.014509716238535475, 0.058917705100611784, 0.018165524561482016, 0.06182457880640868, 0.032435207976959646, 0.03074235428357497, 0.041740630331332795, 0.048969356503221206, 0.01308022756347782, 0.03578126983484253, 0.04009495867649093, 0.052929360026610084, 0.052684080219478346, 0.13644794700667262, 0.014553121673088754, 0.012602971874002833, 0.046496891518472694, 0.06278203465626575, 0.06855182466097176, 0.029769289212708827, 0.03962092669098638, 0.026119423637283035, 0.011360238167981151, 0.027961029700236395, 0.09145215677563101, 0.044778515366488136, 0.038223221417865716, 0.015760402056912426, 0.058611810381989926, 0.050128691364079714, 0.06878197949845344, 0.07577601631055586, 0.0061843903404223965, 0.004445378772288677, 0.04814960244402755, 0.46197125455364585, 4.87430339679122, 18.30848917365074, 42.716939225792885, 50.87584622204304, 34.25202324986458, 22.303507402539253, 21.638522185385227, 18.21446891874075, 14.370256997644901, 11.668735910207033, 2.590100378729403, 0.3934767236933112, 0.27432993112597615, 0.194564655830618, 1.6792229935526848, 4.5343883614987135, 4.897298812866211, 4.122135182842612, 3.4101472003385425, 3.2099290564656258, 2.945298431441188, 3.7587419198825955, 5.490641724318266, 10.92387992888689, 19.97901253402233, 27.498769126832485, 32.77111731469631, 40.980584397912025, 45.3149738162756, 52.04060152173042, 52.431665137410164, 54.32931371033192, 52.39897169172764, 54.10609848797321, 51.77832059562206, 54.79986146092415, 54.396703094244, 54.80209194123745, 51.42645187675953, 50.63055418431759, 49.3170140683651, 49.49762977659702, 46.34570270776749, 46.47906795144081, 45.01761697232723, 44.7489295899868, 44.568553268909454, 44.959290102124214, 47.22521871328354, 50.41377581655979, 50.16912214457989, 55.929749831557274, 34.41510669887066, 48.02082762122154, 51.89625106751919, 49.44340668618679, 48.876100927591324, 48.01484674215317, 50.365199223160744, 50.99409967660904, 48.6086218804121, 50.865305587649345, 50.5930045992136, 51.10595427453518, 50.29264971613884, 51.57282382249832, 48.16394694149494, 47.52278834581375, 48.29473212361336, 51.25313937664032, 52.075882628560066, 50.04065863788128, 49.166329354047775, 53.72896872460842, 49.849840477108955, 56.668133810162544, 45.38942702114582, 55.4685115814209, 51.8708798289299, 46.75761200487614, 40.145248621702194, 28.919744677841663, 19.051307514309883, 9.69431720674038, 3.5480565251782537, 1.833365997299552, 7.717806715518236, 6.123513439670205, 5.124183213338256, 3.6044060764834285, 4.73047636449337, 2.760839704424143, 3.465648447163403, 1.1216291575692594, 0.33666398318018764, 0.20513502066023648, 0.8342721895314753, 5.130608668550849, 15.940057262778282, 33.91708642244339, 24.89701833575964, 33.16970832645893, 37.22748018801212, 38.83896991610527, 22.662859819829464, 6.063038734719157, 0.3703874407801777, 0.020091431179025676, 0.028405234770616516, 0.02239437664684374, 0.03207445741281845, 0.032586435409029946, 0.047607055385014974, 0.04771511579747312, 0.021793878986500204, 0.03757422440685332, 0.06047664937796071, 0.0658258049224969, 0.04374179072328843, 0.017345636915706564, 0.027161992693436332, 0.0710383830300998, 0.12147730696597137, 0.025948364163923543, 0.03035158199054422, 0.016966625807981472, 0.045712938663200475, 0.059832175757037476, 0.01586372200108599, 0.03678447537822649, 0.11920965989702381, 0.028927986895723734, 0.01737591839628294, 0.0354968825558899, 0.05409133322245907, 0.07381408955552615, 0.047886559332255274, 0.022660726026515476, 0.06014510974637233, 0.05173387144168373, 0.047785504793864675, 0.021635239354509395, 0.032269957664539106, 0.022440746033680625, 0.025039587635546923, 0.03850742315989919, 0.037664224655600265, 0.03879740623233374, 0.06530202677822672, 0.04250055244483519, 0.04491061394219287, 0.03607651473430451, 0.014445818251260789, 0.08073697666986845, 0.04250902034982573, 0.007779604766255943, 0.046968593160272576, 0.05855289869941771, 0.048037697706604376, 0.02626410347147612, 0.042091306240763515, 0.09151604084763676, 0.02904791424953146, 0.02065389562631026, 0.0628126111405436, 0.030810720927547663, 0.08918269886635244, 0.047807791488594376, 0.042018824387923814, 0.04382494465971831, 0.008112509949569358, 0.026808912225533277, 0.04663175088353455, 0.043206294067204, 0.06770835898350924, 0.3109555126866326, 6.49723288603127, 22.707925401628017, 49.723527655005455, 57.75564305484295, 40.556059777736664, 25.729133784770966, 26.45387079566717, 24.49338309466839, 19.522505030035973, 11.168172620236874, 2.8867176873609424, 0.3718412487069145, 0.18454969947924837, 0.39141705608926713, 1.468342978041619, 3.9092599181458354, 4.405693542212248, 6.913250712677836, 7.060403516516089, 5.793883027508855, 4.163087960332632, 7.318765427917242, 9.07524112612009, 13.194720726460218, 22.706559374928474, 30.685498528182507, 38.243135288357735, 46.22936055064201, 47.70249590277672, 55.43926075100899, 54.27798606455326, 56.7673958837986, 54.43097725510597, 55.50919599831104, 53.65271061658859, 55.72478123009205, 53.722155690193176, 56.65650263428688, 52.558331340551376, 53.42179700732231, 50.904656276106834, 52.30431877076626, 47.02738992869854, 48.694831654429436, 47.56792612373829, 47.76195131242275, 46.937714740633965, 46.98738567531109, 48.27452480792999, 51.762612238526344, 52.06949897110462, 58.092498779296875, 37.55924418568611, 50.46209402382374, 54.42947633564472, 51.79587945342064, 49.764276668429375, 49.88337367773056, 51.4624397456646, 53.3819979429245, 52.13969260454178, 52.461679726839066, 51.54895730316639, 52.93012998998165, 50.753219202160835, 50.883878991007805, 50.808323845267296, 50.04840262234211, 48.05300809442997, 53.16581234335899, 53.40800754725933, 52.651954516768456, 50.628878474235535, 54.47492189705372, 52.05060638487339, 56.207731515169144, 46.89595118165016, 56.736993715167046, 52.74348400533199, 49.00657832622528, 42.302001491189, 32.358961030840874, 21.056228131055832, 11.716705486178398, 5.508779101073742, 4.763255305588245, 4.795846631750464, 7.108213501051068, 8.619994204491377, 8.256104830652475, 5.5029673129320145, 4.042063029482961, 2.7897582901641726, 1.0870453133247793, 0.6906713044736534, 0.2851074590580538, 0.9698810940608382, 5.311971511691809, 14.855813942849636, 39.300542548298836, 25.82602098584175, 34.600095972418785, 43.920946419239044, 45.3870103508234, 28.12201738357544, 7.494733985513449, 0.4368103703018278, 0.051335679527255706, 0.02261962588818278, 0.034608208952704445, 0.03841666220978368, 0.020564555888995528, 0.06665345543297008, 0.033676642924547195, 0.03203001760994084, 0.013847034952050308, 0.02771317092992831, 0.03825088497251272, 0.06518701615277678, 0.025525735181872733, 0.06604687587241642, 0.008248623544204747, 0.0742300484853331, 0.04751959699206054, 0.023246564414876048, 0.02944481482700212, 0.018025023018708453, 0.04938404636050109, 0.008981361715996172, 0.04186014579317998, 0.04482005337195005, 0.02851564779120963, 0.03253847040468827, 0.05356572939490434, 0.028324739578238223, 0.005800563158118166, 0.07593457616167143, 0.009410999355168315, 0.019443968558334745, 0.15666192717617378, 0.12512670684373006, 0.10934361547697335, 0.14537864044541493, 0.1005161770444829, 0.17273378820391372, 0.0993509087129496, 0.11704872624250129, 0.1749146485235542, 0.09426189819350839, 0.16913493600441143, 0.12043117560097016, 0.1520424141199328, 0.1422335224924609, 0.17805246374337003, 0.0892324821325019, 0.18494147923775017, 0.17082477657822892, 0.1652447017841041, 0.18787741544656456, 0.1908937856205739, 0.09551780502079055, 0.11072838140535168, 0.2343982004094869, 0.17518338019726798, 0.1078444326412864, 0.09531722476822324, 0.19754868320887908, 0.17113601847086102, 0.07865608364227228, 0.12674052180955186, 0.17516455933218822, 0.18777149613015354, 0.11985048957285471, 0.18101686873706058, 0.28674514149315655, 0.5792006640695035, 7.204829016700387, 27.921808026731014, 59.13933500647545, 64.35497313737869, 47.55350969731808, 32.62319505214691, 33.645891174674034, 26.300319135189056, 22.146076150238514, 16.681317687034607, 3.56217039283365, 0.7823556941002607, 0.7476121396757662, 0.622488297522068, 4.440826456993818, 9.73564188927412, 11.732524987310171, 9.261958356946707, 9.255651645362377, 8.248407393693924, 7.079833773896098, 8.609160035848618, 8.438603337854147, 14.50205197557807, 26.577288173139095, 34.55046683549881, 42.215856313705444, 47.838350012898445, 50.18772214651108, 55.29330678284168, 55.650559812784195, 57.71835945546627, 56.687676161527634, 56.58951222896576, 55.884251073002815, 57.051556035876274, 55.86877830326557, 58.5417752712965, 54.92552071809769, 54.66333478689194, 52.56281889975071, 56.35041385889053, 50.69654904305935, 51.24293312430382, 49.50952313840389, 48.58216390013695, 48.31218458712101, 48.138704895973206, 51.27020426094532, 54.85690779983997, 54.84843425452709, 57.89929434657097, 41.75011530518532, 51.89736820757389, 54.86538514494896, 54.13723781704903, 52.82627396285534, 51.54026336967945, 54.88881088793278, 54.835461750626564, 53.96603040397167, 54.66794773936272, 55.16348674893379, 53.43106471002102, 51.09451688826084, 50.25768019258976, 53.48069004714489, 50.479405894875526, 49.429476633667946, 54.25826132297516, 55.58935649693012, 54.05202358961105, 52.570540085434914, 56.806415989995, 51.80460378527641, 57.90862664580345, 49.09470319747925, 57.089132219552994, 56.084488928318024, 51.40830025076866, 43.41397002339363, 33.24532046914101, 23.09441026300192, 12.331455498933792, 5.329713709652424, 4.985305415466428, 12.784095760434866, 14.858250562101603, 12.124901432543993, 12.040008287876844, 14.386349134147167, 9.719546902924776, 8.370471093803644, 3.372871200554073, 2.062284001149237, 0.4392230330267921, 1.2802137667313218, 7.152868704870343, 22.548976130783558, 43.110446110367775, 34.84634555876255, 44.5756246894598, 48.749985694885254, 50.9081444889307, 32.12744705379009, 8.867928050458431, 0.5779067147523165, 0.15335640142438933, 0.0888707593549043, 0.09516046091448516, 0.13016352953854948, 0.09017365897307172, 0.1764026694581844, 0.12708919763099402, 0.08491700471495278, 0.1828228702652268, 0.18887892889324576, 0.21812587045133114, 0.13738706067670137, 0.1376817823620513, 0.1290006731869653, 0.15199050831142813, 0.2185820389422588, 0.11189024327904917, 0.19430098560405895, 0.08887989519280382, 0.08520021568983793, 0.15476318687433377, 0.11934600726817735, 0.11900421857717447, 0.21701152087189257, 0.10259243164910004, 0.14038438734132797, 0.13788806973025203, 0.10104230779688805, 0.17682355624856427, 0.21000629989430308, 0.16255037917289883, 0.20241901249391958], [0.023334544166573323, 0.06872496029245667, 0.052059236404602416, 0.04284256006940268, 0.024005876111914404, 0.04416396885062568, 0.040538488392485306, 0.049408886043238454, 0.014944424601708306, 0.04083418971276842, 0.06891109092975967, 0.04536617758276407, 0.02108532833517529, 0.07494597608456388, 0.0699409692606423, 0.03033595236047404, 0.0637369263859, 0.009938805505953496, 0.04764004013850354, 0.04597104649292305, 0.03147886905935593, 0.02400904879323207, 0.04073918367794249, 0.057497765083098784, 0.04311824566684663, 0.07716481952229515, 0.0633465641294606, 0.04848136471991893, 0.06178032825118862, 0.08753325339057483, 0.011640501888905419, 0.017769887490430847, 0.051284322908031754, 0.05124499279190786, 0.031045885261846706, 0.013082295372441877, 0.04012990269984584, 1.4870564988814294, 13.59461696818471, 33.692849054932594, 42.15899236500263, 37.662484645843506, 13.751901928335428, 13.222318645566702, 19.479329846799374, 24.250693917274475, 13.509548082947731, 4.809506423771381, 1.2866502651013434, 0.30252296361140907, 0.5694637459237128, 1.002461020834744, 2.829115390777588, 4.63181228376925, 7.486854158341885, 4.518465315923095, 7.231965260580182, 0.8138266741298139, 5.745068471878767, 4.834948908537626, 6.477058343589306, 15.636320561170578, 23.159236684441566, 24.73650734871626, 35.31202957034111, 39.54638555645943, 47.984778955578804, 52.91858620941639, 54.68931019306183, 53.5646503418684, 53.10256853699684, 52.14336320757866, 53.718082308769226, 52.24825657904148, 52.931547313928604, 52.311758771538734, 51.29319302737713, 49.76794347167015, 51.99109397828579, 48.78648653626442, 52.13652357459068, 46.58771172165871, 47.88518629968166, 44.71137620508671, 48.66349473595619, 48.32902908325195, 50.53911969065666, 49.38120022416115, 58.268786519765854, 32.59465478360653, 45.81522077322006, 51.53006851673126, 49.57815885543823, 49.417222291231155, 47.82833755016327, 50.509751066565514, 51.98148429393768, 51.77985951304436, 51.38831712305546, 49.79651413857937, 51.38296701014042, 49.889552146196365, 49.06601473689079, 50.68831868469715, 50.08856646716595, 48.37559178471565, 51.08013466000557, 48.78129221498966, 51.32097713649273, 50.44927731156349, 52.858127653598785, 47.93869122862816, 49.72514256834984, 51.030034348368645, 44.70728002488613, 46.98391266167164, 41.746288910508156, 38.09370070695877, 24.71309870481491, 14.92879567667842, 7.634858591482043, 3.1469699973240495, 2.2890035854652524, 2.511825291439891, 8.06111829355359, 6.916822521016002, 4.700967622920871, 3.486619284376502, 2.627856102772057, 1.6274455469101667, 1.3590043201111257, 0.2524538815487176, 0.17096919851610437, 1.9188381358981133, 7.308144997805357, 16.702298261225224, 33.26476402580738, 38.997315019369125, 31.60497508943081, 41.08563356101513, 33.892478942871094, 14.369628131389618, 2.999697499908507, 0.08846916840411723, 0.08853153849486262, 0.05020419375796337, 0.04955074386089109, 0.03340555864269845, 0.028368279527057894, 0.048269206963595934, 0.04301573280827142, 0.03856491734040901, 0.05513593947398476, 0.02337813606573036, 0.029623874652315862, 0.01464975486669573, 0.021593549208773766, 0.020442416935111396, 0.1047726537217386, 0.017358056757075246, 0.029409267808659934, 0.04350528310169466, 0.05398816356319003, 0.018221319223812316, 0.06088051130063832, 0.035653238228405826, 0.05546069216507021, 0.026017508207587525, 0.03155092788801994, 0.046685096458531916, 0.06520067909150384, 0.06296688879956491, 0.06565673626028001, 0.08079606646788307, 0.08001755355508067, 0.05903022210986819, 0.02276186776725808, 0.04129107437620405, 0.032305658678524196, 0.05290518456604332, 0.016936596657615155, 0.021873140358366072, 0.06709736364427954, 0.05476471720612608, 0.05680777183442842, 0.07773240664391778, 0.034313936266698875, 0.05155544058652595, 0.02393636284978129, 0.008020056902751094, 0.03287776547949761, 0.01746464957250282, 0.01945651827554684, 0.029781746161461342, 0.031196225827443413, 0.03807445049460512, 0.045939653646200895, 0.007942713054944761, 0.052283929035183974, 0.06711280773743056, 0.0764787188381888, 0.07042479017400183, 0.011894785802724073, 0.02379151603236096, 0.02876758651837008, 0.032709030783735216, 0.06265547621296719, 0.09869314322713763, 0.033895784290507436, 0.03064326087041991, 0.06853124490589835, 0.02481206556694815, 0.11711325598298572, 2.3290137760341167, 17.490005493164062, 40.918138548731804, 49.954844042658806, 42.60429047048092, 19.317019656300545, 19.748687893152237, 27.19460304826498, 26.62496231496334, 17.25433263927698, 4.8257496021687984, 0.973368416307494, 0.25516990455798805, 0.19118892290862277, 0.8573847461957484, 2.5523102190345526, 4.225707650184631, 6.230106744915247, 9.008705746382475, 5.556728728115559, 4.6541147120296955, 5.98624580539763, 5.127895139157772, 10.499889180064201, 16.848214231431484, 27.05104675143957, 30.05705215036869, 38.88436608016491, 43.610594272613525, 50.914706736803055, 55.21551355719566, 56.58945523202419, 55.65138056874275, 54.70021940767765, 54.77960094809532, 55.843646451830864, 53.37593726813793, 55.38145825266838, 53.36697734892368, 54.491185024380684, 50.94748757779598, 53.79538916051388, 51.453605219721794, 52.941221594810486, 48.25084447860718, 50.07334068417549, 48.23541350662708, 50.394355058670044, 50.82642987370491, 53.12100134789944, 52.02499955892563, 58.44455748796463, 35.183516666293144, 47.9873476177454, 53.82154315710068, 51.91285237669945, 50.32119758427143, 51.4909116178751, 52.71155811846256, 52.67378434538841, 53.82601171731949, 53.96362893283367, 51.055048406124115, 52.088383957743645, 50.6818438321352, 50.889187306165695, 50.95727205276489, 50.36450766026974, 50.60247749090195, 53.30378673970699, 52.3782704025507, 51.97128564119339, 51.98956646025181, 53.98558035492897, 50.58100864291191, 52.01701998710632, 51.103685796260834, 47.51649208366871, 50.541042387485504, 43.772321194410324, 38.35263021290302, 27.286841198801994, 17.85639513283968, 8.664011042565107, 5.112787624821067, 6.539182160049677, 9.520011059939861, 6.0517248418182135, 9.736285954713821, 6.7365136463195086, 5.513495123013854, 4.165333164855838, 2.3934039333835244, 0.9848400007467717, 0.31241000338923186, 0.3014418325619772, 2.165321884676814, 7.9374586790800095, 20.467157140374184, 38.10316599905491, 36.22977912425995, 33.96935261785984, 47.04852819442749, 39.59603749215603, 18.544585704803467, 3.7549015134572983, 0.05744056776165962, 0.10981493120198138, 0.07054185654851608, 0.020585228412528522, 0.0709885181277059, 0.010293711657141102, 0.04704157225205563, 0.04150773696892429, 0.05347283477021847, 0.046809135310468264, 0.016446584377263207, 0.019380689336685464, 0.05574558410444297, 0.05530706388526596, 0.05445869261166081, 0.11226222253753804, 0.03366758130141534, 0.008169287029886618, 0.05224944885412697, 0.05842825870786328, 0.053277835468179546, 0.03613528169807978, 0.015914603645796888, 0.02318989958439488, 0.04076420889759902, 0.03824109233391937, 0.020188767557556275, 0.026459896871529054, 0.06765453843399882, 0.009489657732046908, 0.02094040173687972, 0.06462949255364947, 0.010197756600973662, 0.17430862557375804, 0.15951100242091343, 0.15427708014613017, 0.1886508965981193, 0.16962464957032353, 0.1524126122239977, 0.24410660524154082, 0.1487140599056147, 0.2519908407703042, 0.13407314865617082, 0.16470836650114506, 0.3360763209639117, 0.16117691615363583, 0.21541982190683484, 0.13320378202479333, 0.09324624683358707, 0.13149569946108386, 0.18436301965266466, 0.22549444693140686, 0.14771940390346572, 0.09515671306871809, 0.13836734869983047, 0.1473719155183062, 0.21881094697164372, 0.2240181074012071, 0.18687413568841293, 0.15808928495971486, 0.15356371295638382, 0.09669011633377522, 0.16686020884662867, 0.1408093114150688, 0.19088786328211427, 0.16053865430876613, 0.1338850290630944, 0.15454233856871724, 0.11670272215269506, 0.180210777616594, 2.7595843467861414, 20.555308610200882, 49.01513546705246, 57.10093818604946, 50.80201618373394, 23.254968747496605, 22.17800583690405, 29.873047024011612, 34.66357156634331, 18.676548823714256, 5.889577567577362, 1.9989454373717308, 0.5188327096402645, 1.285074893385172, 2.8014808986335993, 5.575519669800997, 10.428364668041468, 17.137517407536507, 13.368497751653194, 12.752404510974884, 4.202393051236868, 9.609784092754126, 7.174329003319144, 11.234242524951696, 22.275132425129414, 29.799319580197334, 31.412277929484844, 41.43409386277199, 44.77003365755081, 50.7768577337265, 56.337182968854904, 57.22188949584961, 57.685004845261574, 57.2536101937294, 56.35962076485157, 58.253309950232506, 55.29541566967964, 56.60304710268974, 56.25476539134979, 56.514234468340874, 54.462785348296165, 55.075422674417496, 52.6555947214365, 57.038530334830284, 50.746409967541695, 50.60736782848835, 49.46661964058876, 50.5781701952219, 54.235876724123955, 54.52206216752529, 53.28147813677788, 56.95086903870106, 39.33774635195732, 49.78810898959637, 53.36440488696098, 53.811507895588875, 52.40652568638325, 53.71041812002659, 53.86962577700615, 53.57783943414688, 54.42158795893192, 54.39784683287144, 51.8099121004343, 52.32362173497677, 51.99925974011421, 52.30297364294529, 52.32014112174511, 49.9149651825428, 50.48480540513992, 52.586430832743645, 51.193512976169586, 53.718998059630394, 54.92778159677982, 54.841765612363815, 52.04297259449959, 51.65557958185673, 52.71592788398266, 50.72821654379368, 55.12782946228981, 46.408342346549034, 43.68932604789734, 30.30735231935978, 19.634369127452374, 11.004757639020681, 5.608550822362304, 5.273258714005351, 9.304471425712109, 15.382825713604689, 13.5521399974823, 12.2707281075418, 8.550353441387415, 6.724889595061541, 3.6624337127432227, 2.4222581600770354, 0.7188169879373163, 0.7813363987952471, 2.8972970321774483, 9.791567288339138, 23.479696288704872, 43.39334473013878, 46.847708970308304, 43.57530936598778, 55.669365003705025, 46.997766718268394, 21.771623343229294, 4.475311981514096, 0.25146780477371067, 0.2569389471318573, 0.17992329929256812, 0.12799868476577103, 0.27014454477466643, 0.2173496433533728, 0.16821145196445286, 0.08976132914540358, 0.13632497313665226, 0.15922477090498433, 0.1349029885022901, 0.14385979069629684, 0.11180812463862821, 0.1181033551984001, 0.11855636956170201, 0.22034291789168492, 0.10448026238009334, 0.18365051335422322, 0.12328598022577353, 0.23197539994725958, 0.12197800431749783, 0.13989005761686713, 0.14582419622456655, 0.12153873452916741, 0.1094213554461021, 0.13609472924144939, 0.1852473776671104, 0.22579626354854554, 0.15341411082772538, 0.11218803003430367, 0.23500400071498007, 0.22152639110572636, 0.14688442839542404], [0.03472465192317031, 0.03566631115972996, 0.01667080203333171, 0.01783726522262441, 0.02813943829096388, 0.04016157014120836, 0.03765899993595667, 0.042551634469418786, 0.0581076954404125, 0.006053726428945083, 0.06231624793144874, 0.07796940408297814, 0.04300445216358639, 0.01729535826598294, 0.0852225320704747, 0.0203495724053937, 0.051274237121106125, 0.053625227374141105, 0.018908898637164384, 0.05796847595775034, 0.039538537166663446, 0.06467280429205857, 0.04818340727069881, 0.04416613963257987, 0.005589680040429812, 0.03963099021348171, 0.018903597847383935, 0.07651206353330053, 0.06774355162633583, 0.041077744026551954, 0.09567697343300097, 0.026785913069033995, 0.08621001150459051, 0.05828574037877843, 0.03642174327978864, 0.06976932534598745, 0.01479015529184835, 0.9253265848383307, 7.195748928934336, 29.536609277129173, 43.14378932118416, 38.683505058288574, 22.422936893999577, 13.042881824076176, 28.97245354950428, 16.88100267201662, 9.865304231643677, 7.730484260246158, 1.4879424450919032, 0.9305485140066594, 0.14984148612711579, 0.7217732293065637, 2.5459298864006996, 1.955998835619539, 5.231037279590964, 8.718549516052008, 2.15404836460948, 4.71624992787838, 2.9341355804353952, 1.5363019751384854, 4.205106105655432, 7.012910814955831, 15.128099732100964, 18.767270855605602, 31.122418083250523, 34.769764468073845, 40.74838265776634, 46.07743710279465, 54.09308418631554, 52.10543364286423, 54.96658131480217, 51.58086039125919, 53.679879158735275, 52.85620495676994, 54.38774697482586, 50.61590977013111, 52.62760542333126, 52.38669455051422, 54.13872353732586, 50.788051933050156, 53.11137266457081, 50.0864689797163, 48.807157427072525, 46.6384731978178, 49.70614738762379, 51.21699571609497, 51.89696542918682, 57.22577288746834, 68.83446916937828, 38.57296518981457, 42.91857920587063, 55.827903896570206, 47.005586698651314, 49.84228268265724, 46.37570969760418, 47.230591624975204, 49.513744711875916, 51.745015382766724, 51.621001437306404, 51.66723735630512, 50.209578573703766, 51.77763283252716, 50.83856642246246, 51.53594680130482, 51.62634015083313, 48.42824175953865, 51.96943514049053, 50.79274848103523, 53.33412431180477, 49.47347067296505, 52.216600477695465, 50.8540353924036, 48.422971442341805, 42.2021808475256, 40.7988553494215, 36.68614983558655, 36.09333984553814, 33.619729578495026, 25.52058957517147, 15.207766257226467, 7.203162806108594, 5.508595760911703, 6.727937031537294, 4.519876465201378, 0.8766714425291866, 11.157118063420057, 6.668014246970415, 6.361575415357947, 2.329174792394042, 1.8946430529467762, 0.36878270970191807, 0.3276842931518331, 0.5532742396462709, 3.129947385750711, 9.442251082509756, 14.043578077107668, 31.781027242541313, 32.8404787927866, 30.232179053127766, 39.13191519677639, 28.051398172974586, 11.264997124671936, 0.5060900934040546, 0.024329435800609645, 0.06573564140126109, 0.09926562852342613, 0.04936504737997893, 0.054438008955912665, 0.09384881137521006, 0.033674371952656657, 0.06891250843182206, 0.00673774075039546, 0.01498681978773675, 0.053573277036775835, 0.03371409540704917, 0.05892240660614334, 0.0719280845078174, 0.03483111671812367, 0.06627789160120301, 0.12514552770880982, 0.04924418120936025, 0.008175186176231364, 0.029159041587263346, 0.02883020708395634, 0.058721529494505376, 0.0575368243153207, 0.09220059786457568, 0.0736315360700246, 0.01956723557668738, 0.036123778409091756, 0.0607423901965376, 0.07305341787287034, 0.020004928301204927, 0.1191049577028025, 0.06882713918457739, 0.04736640657938551, 0.09093856831896119, 0.015771333892189432, 0.032495247724000365, 0.07151659330702387, 0.0279683101689443, 0.08291204081615433, 0.06442876387154683, 0.039831674366723746, 0.06732518071657978, 0.03785691216762643, 0.0259015865958645, 0.06154804344987497, 0.02389156124991132, 0.06391519767930731, 0.04601397602527868, 0.04351386603957508, 0.04172778375505004, 0.052636237669503316, 0.03880272000969853, 0.018063833631458692, 0.028620849079743493, 0.05715087412681896, 0.04942843792377971, 0.024866077219485305, 0.036857398808933794, 0.048554562745266594, 0.10307565884431824, 0.023569216828036588, 0.013845237099303631, 0.01619088481675135, 0.06748206331394613, 0.04239278146997094, 0.03743154651601799, 0.049651382796582766, 0.045437015578499995, 0.03127697520540096, 0.010053100886580069, 1.1584703181870282, 9.656294547021389, 33.94360139966011, 50.15666641294956, 44.08480502665043, 24.446670301258564, 14.557087272405624, 22.6611328125, 22.66707569360733, 13.564437087625265, 7.536809127777815, 1.636991584673524, 0.568106328137219, 0.3219385858392343, 0.5306251393631101, 2.1921698190271854, 4.377233544364572, 5.790829891338944, 7.970018181949854, 8.830450661480427, 7.7832206804305315, 3.8296978874132037, 4.33796645142138, 5.762554183602333, 10.958458073437214, 18.36969628930092, 23.844395019114017, 33.96382011473179, 37.581970766186714, 43.97971786558628, 49.29492965340614, 56.623706594109535, 54.7343073785305, 55.48158288002014, 54.63591165840626, 56.327014714479446, 55.966923236846924, 56.48824006319046, 54.379398822784424, 55.6605988740921, 54.027457907795906, 57.05489605665207, 53.16722206771374, 54.05600197613239, 52.73645058274269, 50.153109803795815, 48.40676911175251, 52.44669333100319, 52.236040234565735, 54.63657282292843, 57.88035996258259, 64.09067451953888, 41.593768894672394, 47.031923085451126, 58.159170001745224, 48.12993876636028, 52.60800987482071, 48.05890157818794, 50.281155332922935, 51.272909715771675, 54.85972344875336, 53.01164321601391, 53.81297081708908, 52.06063784658909, 53.08324657380581, 50.95490477979183, 53.95740866661072, 52.12797403335571, 49.555960446596146, 51.057723462581635, 51.76957346498966, 53.39170642197132, 51.48716501891613, 53.99869345128536, 52.436905056238174, 50.59139348566532, 46.07205659151077, 45.80672822892666, 44.20417942106724, 40.478874519467354, 39.63763386011124, 26.347618997097015, 16.562268175184727, 7.902617398649454, 6.220105681568384, 6.795451333746314, 6.266716355457902, 4.884638367220759, 4.671889683231711, 5.620289342477918, 4.09553756006062, 3.1491472804918885, 0.7435895211528987, 0.27205720776692033, 0.061685589389526285, 0.5661312653683126, 2.903442014940083, 12.433649115264416, 17.72792212665081, 32.79085725545883, 37.530829310417175, 33.94429676234722, 46.891049444675446, 35.376683101058006, 13.430229239165783, 0.5940459331031889, 0.06764871257473715, 0.03807368237175979, 0.09345584418042563, 0.01972298268810846, 0.04912245785817504, 0.06649678805842996, 0.04910432347969618, 0.07897844290710054, 0.025010120662045665, 0.019704620099219028, 0.057917627709684893, 0.06559445522725582, 0.05252782102616038, 0.10921607739874162, 0.02949878566141706, 0.06606477647437714, 0.009512104916211683, 0.05443194189865608, 0.02535073675971944, 0.0361345024430193, 0.02738250703259837, 0.03185695990396198, 0.03514535317663103, 0.050201265985378996, 0.03299112111562863, 0.04158211871981621, 0.03598202449211385, 0.026088327649631537, 0.052588521284633316, 0.03981516158091836, 0.07093518739566207, 0.07003790116868913, 0.03580992415663786, 0.2726994623662904, 0.14224455080693588, 0.167960932594724, 0.11313536670058966, 0.10968394213705324, 0.1548609128803946, 0.1684174276306294, 0.09430397796677426, 0.12476961506763473, 0.14811296481639147, 0.13713768421439454, 0.19434438640018925, 0.15535510901827365, 0.1067398719897028, 0.15902157087111846, 0.12823971948819235, 0.11820134837762453, 0.1817555580055341, 0.2847921650391072, 0.1603813486872241, 0.2001434244448319, 0.13551729382015765, 0.12446272216038778, 0.1730148246861063, 0.1106039974547457, 0.12097586746676825, 0.2051809596014209, 0.15246583905536681, 0.18671981350053102, 0.06422281789127737, 0.1371589838527143, 0.09366164915263653, 0.13508359756087884, 0.14176789904013276, 0.0942925711569842, 0.14781292935367674, 0.10618434476782568, 1.4527874439954758, 11.204074993729591, 39.52624283730984, 58.55787880718708, 53.960870280861855, 31.407115906476974, 24.488519355654716, 39.772519022226334, 28.406758904457092, 15.108371190726757, 10.644559767097235, 2.0018489565700293, 1.198273419868201, 0.6055384164210409, 2.3544092383235693, 5.709760766476393, 6.960211442783475, 11.383187882602215, 19.450046718120575, 12.364544123411179, 12.623609472066164, 6.423038067296147, 4.405943853780627, 7.605933118611574, 9.65688731521368, 18.19241300225258, 22.796135768294334, 33.886699452996254, 39.53282028436661, 44.69788692891598, 50.714921057224274, 57.456477507948875, 55.12621074914932, 58.384706899523735, 56.08522228896618, 58.674410954117775, 58.36693525314331, 58.455470502376556, 55.55319003760815, 57.67705947160721, 56.21218107640743, 58.45673583447933, 54.87166240811348, 57.14952617883682, 53.7852019071579, 52.218245789408684, 50.300861075520515, 53.480754643678665, 53.886052295565605, 54.58350867033005, 58.33429880440235, 66.5214116871357, 43.99730332195759, 47.82917730510235, 58.80473256111145, 50.753226801753044, 52.85576418042183, 51.25134967267513, 51.287462934851646, 53.11339795589447, 55.34431904554367, 55.088224187493324, 54.58188235759735, 54.52638253569603, 54.75071109831333, 52.432824075222015, 54.42148916423321, 53.061196357011795, 49.25648331642151, 52.42745116353035, 52.72393025457859, 55.68200692534447, 52.09558077156544, 54.81414869427681, 53.27141247689724, 52.30364240705967, 47.67558954656124, 48.59813444316387, 48.39591309428215, 44.85119730234146, 42.167013734579086, 28.18502940237522, 17.033870369195938, 9.567896090447903, 9.322506207972765, 12.279332745820284, 9.738790020346642, 8.854167088866234, 21.47973820567131, 14.018893651664257, 14.30088697001338, 7.737802667543292, 4.895605528727174, 0.796769626904279, 0.525443583028391, 0.7656112394761294, 4.1497259773314, 14.812501017004251, 22.327888794243336, 42.014991492033005, 42.98502244055271, 41.85653239488602, 52.593901231884956, 42.14574247598648, 16.357352770864964, 0.9570086316671222, 0.1217812164395582, 0.20034475426655263, 0.27065437054261565, 0.09267483022995293, 0.14050265599507838, 0.16272898443276063, 0.10145716834813356, 0.24708365643164143, 0.09117969952058047, 0.13674566696863621, 0.16978921339614317, 0.17913372837938368, 0.13785228336928412, 0.28093287837691605, 0.12603245355421677, 0.1561537489760667, 0.24648768216138706, 0.1934861222980544, 0.06750574524630792, 0.09143462724750862, 0.09280535174184479, 0.10827028439962305, 0.09806729751289822, 0.2060118829831481, 0.20241432212060317, 0.1388302113628015, 0.13485379895428196, 0.12500448996433988, 0.19360305508598685, 0.14007979509187862, 0.3289949259487912, 0.1660180790349841, 0.10457395852426998], [0.1363052913802676, 0.07324685124331154, 0.020884931764157955, 0.02042361276835436, 0.045333712332649156, 0.03798182304308284, 0.01929708454554202, 0.09188029434881173, 0.11194064252777025, 0.047911647634464316, 0.07707786950049922, 0.009824534245126415, 0.033618863017181866, 0.09313970411312766, 0.029901473135396373, 0.13767755212029442, 0.046313187704072334, 0.026125403492187615, 0.02640325801621657, 0.01877505230368115, 0.11209171410882846, 0.041983056580647826, 0.05648416205076501, 0.08965523171355017, 0.02794584350340301, 0.04009104013675824, 0.01540393554023467, 0.029712642935919575, 0.02657680553966202, 0.06368163638398983, 0.07906653583631851, 0.07649663428310305, 0.035076982821919955, 0.055753395208739676, 0.04411392583278939, 0.018833214417099953, 0.0891938162385486, 0.30035235977265984, 4.814077578485012, 23.597736954689026, 32.89309076964855, 43.96268717944622, 40.54963432252407, 34.868954345583916, 32.79857084155083, 21.603182181715965, 28.143685720860958, 11.01874753832817, 3.6833297414705157, 0.8569073374383152, 0.3572268469724804, 0.48437075573019683, 1.5304648946039379, 4.9015165865421295, 3.686488321982324, 7.973984219133854, 6.234201975166798, 6.115711983293295, 2.7955639036372304, 3.2317503355443478, 3.8928257999941707, 2.7912278613075614, 9.51753169298172, 14.041093960404396, 20.642975606024265, 28.24045892804861, 32.99134209752083, 40.62159106135368, 45.779533088207245, 50.296016335487366, 53.753401413559914, 52.56393603980541, 54.60571467876434, 51.96308568120003, 54.72166545689106, 54.366741701960564, 57.097047194838524, 54.71978835761547, 52.697590067982674, 56.94906033575535, 54.388035759329796, 51.0970513522625, 49.381815791130066, 48.118938356637955, 51.85635320842266, 53.19791302084923, 52.21815839409828, 51.849616169929504, 44.387633576989174, 32.351133450865746, 50.31036056578159, 54.516088888049126, 50.547878220677376, 48.29522989690304, 47.660261169075966, 47.61310949921608, 49.38928619027138, 50.167910009622574, 50.93171462416649, 49.6066839247942, 52.190507277846336, 52.54369832575321, 51.50605000555515, 51.92497752606869, 53.278818279504776, 52.51489207148552, 51.89902491867542, 49.458434879779816, 50.07426403462887, 52.94619932770729, 50.42248114943504, 48.06648597121239, 47.96447664499283, 43.91420938074589, 39.01841148734093, 34.6732534468174, 27.59497806429863, 30.279024839401245, 25.70559784770012, 14.822647422552109, 3.0767473904415965, 3.842019201256335, 7.251796396449208, 7.861827062442899, 4.673606716096401, 6.80994613096118, 4.912545019760728, 2.6012667920440435, 2.275158315896988, 0.6755802361294627, 0.24947703815996647, 0.2205337240593508, 0.9091463999357074, 4.275995101779699, 14.07700963318348, 24.18635006994009, 38.67577247321606, 37.28082552552223, 34.20443080365658, 41.75516523420811, 23.66358172148466, 5.3232725802809, 0.03523167237290181, 0.046386359754251316, 0.014455494929279666, 0.017940976649697404, 0.03265718805778306, 0.05829343273944687, 0.039866881852503866, 0.00799060013378039, 0.06957878635148518, 0.03332955158839468, 0.0663193479704205, 0.03319684816233348, 0.006952722378628096, 0.027698578451236244, 0.04649604175938293, 0.01550489916553488, 0.009752991209097672, 0.03662186340079643, 0.04475438443478197, 0.06825006741564721, 0.09761883993633091, 0.05530367969186045, 0.028210476666572504, 0.04903748194919899, 0.02710546144953696, 0.024755699450906832, 0.05320699005096685, 0.025346842339786235, 0.10947475297143683, 0.03958250941650476, 0.07538595833466388, 0.056835568975657225, 0.025322284673165996, 0.04078626923728734, 0.09095685483771376, 0.004958428244208335, 0.026438693712407257, 0.04399770179588813, 0.05954502397798933, 0.01751236224663444, 0.04603544635756407, 0.09103201213292778, 0.05865298844582867, 0.04392283393826801, 0.04744279583974276, 0.030682401738886256, 0.09692528066807427, 0.07402508956147358, 0.015697299095336348, 0.08552661223802716, 0.027939487008552533, 0.05475429745274596, 0.04697271950135473, 0.054036451401771046, 0.04205858123896178, 0.03732786848559044, 0.016656391380820423, 0.025119220081251115, 0.030621669939137064, 0.0243512011365965, 0.055614008742850274, 0.051582933447207324, 0.03321099720778875, 0.0035356302623767988, 0.011602446411416167, 0.04516403510933742, 0.030862628591421526, 0.017939516474143602, 0.04536092688795179, 0.1138987769081723, 0.04703741993580479, 0.35625329765025526, 5.75576632283628, 26.90905027091503, 41.4132671803236, 49.067378863692284, 44.06945385038853, 30.377982929348946, 33.647528886795044, 22.97748863697052, 22.163701504468918, 12.499807365238667, 3.284429758787155, 0.6879717274568975, 0.0413406832376495, 0.38235460175201297, 0.8293166023213416, 4.000144628807902, 3.182065626606345, 9.374292679131031, 4.295112825930119, 7.77050418779254, 5.572632299736142, 5.489469487220049, 5.820769434794784, 5.618776073679328, 13.198794107884169, 17.30536960065365, 25.67560415714979, 32.41804786026478, 35.956569984555244, 41.34109765291214, 49.54104624688625, 53.9947796612978, 54.924585968256, 54.51273746788502, 55.09840004146099, 53.952518329024315, 56.782089695334435, 56.51664353907108, 59.6198458224535, 56.780854761600494, 54.38938468694687, 57.438451275229454, 56.928750425577164, 53.83186340332031, 50.77437646687031, 50.03628887236118, 53.51411685347557, 54.579845666885376, 52.65347063541412, 56.254947781562805, 46.335017681121826, 37.27917641401291, 51.6035907715559, 57.07000024616718, 52.1753004938364, 50.217827931046486, 51.41016595065594, 50.65325416624546, 53.10641013085842, 53.41684587299824, 52.72515378892422, 51.777199655771255, 54.983171224594116, 54.77782264351845, 53.511274605989456, 53.39289575815201, 54.867258444428444, 52.38860584795475, 53.56273904442787, 51.579788848757744, 51.89695402979851, 53.63381803035736, 52.752284333109856, 51.165573075413704, 51.74003764986992, 47.02733293175697, 43.13208594918251, 39.80797491967678, 34.115982949733734, 34.94546324014664, 28.54973953217268, 17.771279700100422, 6.048365347087383, 6.912511652335525, 6.737763779237866, 3.2910756021738052, 9.991916287690401, 7.0294081047177315, 3.1828431598842144, 2.6941596949473023, 2.3983629047870636, 0.3062025614781305, 0.22740115789929405, 0.1743007736513391, 0.9229638241231441, 5.632131407037377, 16.825747936964035, 20.832955911755562, 38.51879149675369, 39.197879657149315, 37.26009763777256, 47.03426755964756, 29.02243796736002, 7.072533890604973, 0.17372179456287995, 0.043900881209992804, 0.03504328189592343, 0.02447650349495234, 0.051909845788031816, 0.020396136605995707, 0.026907680949079804, 0.035089261655230075, 0.05011288732930552, 0.06353220494929701, 0.04087834007805213, 0.020248703403922264, 0.019739207891689148, 0.015769756828376558, 0.025399540390935726, 0.03305588834336959, 0.02379842357186135, 0.019899029393855017, 0.02176553080062149, 0.01495776934461901, 0.1434396905824542, 0.01677536693023285, 0.03395567931875121, 0.017194292595377192, 0.029585121556010563, 0.06487793390988372, 0.02832666545145912, 0.03680420166347176, 0.05016077440814115, 0.02347022917092545, 0.0638871816045139, 0.06749297288479283, 0.05798328922537621, 0.00820140903670108, 0.23693462368100882, 0.1494819749495946, 0.09470109376707114, 0.11405871715396643, 0.15096714603714645, 0.07840918595320545, 0.16597491572611034, 0.13275724661070853, 0.17526065261336043, 0.15686892700614408, 0.18635377142345533, 0.15437738882610574, 0.17936808377271518, 0.17098019714467227, 0.3105611650971696, 0.2219299116404727, 0.11118414913653396, 0.20566938183037564, 0.09034002621774562, 0.11862187893711962, 0.20076043118024245, 0.1572425093036145, 0.23288237862288952, 0.2414954180130735, 0.05986937590932939, 0.13205662951804698, 0.14634631195804104, 0.15906633721897379, 0.16505604784470052, 0.13024179643252864, 0.20328367390902713, 0.16870057181222364, 0.10357378836488351, 0.12943195004481822, 0.13413026434136555, 0.19512536324327812, 0.12217402036185376, 0.4966147377854213, 7.079982440918684, 31.474037915468216, 47.308042868971825, 58.593254908919334, 50.83264634013176, 45.56155778467655, 46.577497869729996, 33.779605999588966, 35.50871081650257, 15.67572159692645, 4.910828461870551, 1.1224881489761174, 0.6170525110792369, 0.6699056562501937, 2.4560086615383625, 10.436062105000019, 8.948686067014933, 12.794466353952885, 13.580548223108053, 14.581197928637266, 6.812637336552143, 5.20764478482306, 5.068583646789193, 5.302045019343495, 12.738502006977797, 19.54956527799368, 24.98800255358219, 32.56764963269234, 36.147179156541824, 44.546765238046646, 49.26166243851185, 54.57145191729069, 56.39601521193981, 56.88467659056187, 58.53361330926418, 55.81720747053623, 59.497158005833626, 57.49754570424557, 60.0459473580122, 58.19201543927193, 54.932044968008995, 60.099152103066444, 57.26268030703068, 55.470369681715965, 53.47471296787262, 52.114074379205704, 56.86929501593113, 58.71891796588898, 52.62495316565037, 55.79262658953667, 47.750247940421104, 42.2514908015728, 52.98987798392773, 57.03175529837608, 53.840587735176086, 53.23655694723129, 52.557841166853905, 52.3051243275404, 53.82731504738331, 54.528624415397644, 54.63768996298313, 52.754795998334885, 55.00468946993351, 57.38574430346489, 53.87609302997589, 53.58227759599686, 55.02722226083279, 53.758162558078766, 52.730142921209335, 50.91219127178192, 51.712002754211426, 54.714647233486176, 53.86900261044502, 49.76880602538586, 52.498020976781845, 47.61470541357994, 48.11893455684185, 45.79222820699215, 38.775353729724884, 39.991512671113014, 34.6619338542223, 21.80408500134945, 7.476325398311019, 7.441886896267533, 13.942524399608374, 14.287904966622591, 14.129060190171003, 14.5922458358109, 10.73361748829484, 7.473202915862203, 5.634153848513961, 1.8043783027678728, 0.9489630383905023, 0.7346596440766007, 1.5504702273756266, 6.6885340958833694, 21.092350892722607, 32.908270955085754, 49.17677119374275, 48.134665712714195, 44.77965474128723, 52.8772634267807, 33.31245146691799, 8.598011434078217, 0.366155180381611, 0.11656952890916727, 0.1401935366448015, 0.0749439574428834, 0.15204539755359292, 0.15820753877051175, 0.1363313852925785, 0.17472341191023588, 0.16832955734571442, 0.13654957670951262, 0.10208924068138003, 0.1512652519159019, 0.07078705471940339, 0.09889505192404613, 0.1435405484517105, 0.1992309687193483, 0.14970599964726716, 0.12849602760979906, 0.08641257329145446, 0.16107417322928086, 0.21685421525035053, 0.10432784009026363, 0.1794197372510098, 0.11829816896351986, 0.11122772804810666, 0.18499966361559927, 0.1002225092088338, 0.19926081789890304, 0.21799954207381234, 0.15876612364081666, 0.2994341152952984, 0.28936263697687536, 0.0909357555792667, 0.10353234683861956], [0.06528433397761546, 0.043211993761360645, 0.0967268378008157, 0.06653788819676265, 0.09332397938123904, 0.014224861406546552, 0.06704058934701607, 0.022327045298879966, 0.02858686428226065, 0.043251962124486454, 0.04965172789525241, 0.04101203056052327, 0.014768472519790521, 0.032598083416814916, 0.04858282001805492, 0.05713689206459094, 0.08534265609341674, 0.033422832129872404, 0.021977345313644037, 0.07016717587248422, 0.032546233269385993, 0.07405884243780747, 0.06790536208427511, 0.026086615143867675, 0.07763407949823886, 0.05385337470215745, 0.025994340212491807, 0.05845892424986232, 0.03039081748283934, 0.020154960875515826, 0.02076620854495559, 0.04287257252144627, 0.014540309421136044, 0.019251694793638308, 0.01138065093982732, 0.02816193093167385, 0.01838533571572043, 0.12896586646093056, 1.8066049832850695, 10.782986339181662, 26.158525943756104, 44.525892958045006, 41.410869508981705, 22.468437552452087, 16.25936932861805, 28.570845499634743, 24.047017246484756, 11.179742999374866, 5.347229344770312, 1.5233303024433553, 0.23674971016589552, 0.22109665791504085, 1.4761008555069566, 2.921380139887333, 3.5218927916139364, 7.1444811299443245, 3.613446978852153, 5.796278798952699, 6.9237210508435965, 6.1997591983526945, 4.164064507931471, 2.4785799253731966, 4.465285269543529, 8.23627844452858, 13.118129186332226, 20.27220480144024, 24.284641295671463, 31.010149307549, 36.473646238446236, 41.626990512013435, 47.92657747864723, 49.935411885380745, 53.826764076948166, 54.97308276593685, 55.28796806931496, 54.317511543631554, 55.078766494989395, 55.38080848753452, 54.97785530984402, 53.510906025767326, 54.88092631101608, 50.94011217355728, 50.698809921741486, 49.57276314496994, 53.0583731085062, 53.966486379504204, 50.94821713864803, 50.90536303818226, 48.685457557439804, 33.66949550807476, 46.14272139966488, 56.35217696428299, 53.29138420522213, 51.16345278918743, 46.89866803586483, 45.14240987598896, 48.05702447891235, 49.349916502833366, 47.93900281190872, 49.44891259074211, 49.917780831456184, 49.6246113628149, 51.10576048493385, 51.373642310500145, 52.47777946293354, 54.04000863432884, 52.9906265437603, 53.050632923841476, 51.63951024413109, 50.23424685001373, 51.76513910293579, 49.46222327649593, 47.2036624699831, 42.419662177562714, 36.90741576254368, 40.49515664577484, 28.418234288692474, 24.564287289977074, 14.168949499726295, 14.653101470321417, 4.545913143083453, 2.544685690663755, 4.095258750021458, 6.811987096443772, 9.203055817633867, 2.305600857362151, 3.0113773606717587, 1.4534950372762978, 1.5760370367206633, 0.20885576319415122, 0.26235487370286137, 0.2766212378628552, 1.9105064892210066, 7.337194913998246, 18.628443405032158, 24.878146648406982, 31.045037135481834, 36.49883508682251, 35.72259373962879, 39.613691344857216, 14.16888015344739, 2.2933861752972007, 0.06239642956643365, 0.09072333064978011, 0.05440686843940057, 0.032066238127299584, 0.0872379973588977, 0.044977652141824365, 0.022729280062776525, 0.034273173805559054, 0.12028909884975292, 0.037018140574218705, 0.018414559635857586, 0.05760155814641621, 0.04137447693210561, 0.018469183560227975, 0.055893249227665365, 0.043192267476115376, 0.043166399918845855, 0.04903719622234348, 0.03710633369337302, 0.04316020669648424, 0.03498096746625379, 0.025080752711801324, 0.0039052576084941393, 0.014872183946863515, 0.014785440798732452, 0.02231775546533754, 0.05846400425070897, 0.022718470681866165, 0.050190490001114085, 0.054404167021857575, 0.023415646064677276, 0.05344145305571146, 0.026894298171100672, 0.03410368582990486, 0.04035186422697734, 0.07713382743531838, 0.09502382410573773, 0.012324926246947143, 0.09723717565066181, 0.02398146130872192, 0.05376117398554925, 0.02509385161829414, 0.018111551871697884, 0.0771693020942621, 0.03441497596213594, 0.019063606741838157, 0.0356920859485399, 0.05495827674167231, 0.06688492387183942, 0.02414445178146707, 0.03077358200243907, 0.02600593626993941, 0.046904419650672935, 0.032891150112845935, 0.06965691965888254, 0.04911863579764031, 0.02527096887206426, 0.013784503444185248, 0.09814501521759667, 0.03328824364871252, 0.04860860964981839, 0.07294109382200986, 0.02836413092154544, 0.008230465045926394, 0.058277131465729326, 0.054351552462321706, 0.006941065557839465, 0.03958932233217638, 0.03430202108575031, 0.0510774900612887, 0.02807283053698484, 0.07555968026281334, 2.6969387708231807, 13.378642257303, 32.362434044480324, 50.39237916469574, 46.64256937801838, 31.889591217041016, 25.71869194507599, 32.56069980561733, 29.64915543794632, 14.580152984708548, 6.200291644781828, 1.5965334931388497, 0.32953927642665803, 0.17095771007006988, 1.1249621724709868, 2.478629322722554, 0.541154908714816, 6.816770089790225, 3.4631120832636952, 8.667354863137007, 8.602800127118826, 6.145048784092069, 5.305581204593182, 7.2660052590072155, 7.090617595240474, 9.021550007164478, 16.094224490225315, 22.775763161480427, 27.294628880918026, 33.47132094204426, 39.26649637520313, 44.158574268221855, 51.127423122525215, 53.093095645308495, 56.58326916396618, 56.93608783185482, 57.00253866612911, 57.19065897166729, 56.46912328898907, 56.69241450726986, 56.836061999201775, 57.02780731022358, 57.41547770798206, 53.72716002166271, 52.98460006713867, 51.50271378457546, 53.338570073246956, 56.49184986948967, 53.721597120165825, 50.814403519034386, 47.76078097522259, 35.556219667196274, 49.41844202578068, 57.91133590042591, 55.137754529714584, 53.33550363779068, 50.34236624836922, 48.08895416557789, 50.17080545425415, 51.708966717123985, 51.48344121873379, 51.4318285882473, 52.63663373887539, 52.28118181228638, 53.3565317094326, 54.28862929344177, 54.56754952669144, 55.13170525431633, 55.81226013600826, 53.42656195163727, 52.27058798074722, 53.11849348247051, 53.99464666843414, 50.0817496329546, 50.47268785536289, 46.08512029051781, 42.08401098847389, 43.60089719295502, 34.82963405549526, 28.982942886650562, 21.973512209951878, 17.446292638778687, 5.381506830453873, 3.669148189947009, 5.422674296423793, 8.457782808691263, 6.98006110265851, 1.5792091540060937, 2.249907008372247, 0.9267061483114958, 1.1358275706879795, 0.20781136845471337, 0.23491749598179013, 0.31743656960316, 2.017764877527952, 7.8612779919058084, 19.896232075989246, 27.78766192495823, 32.80392475426197, 41.75800368189812, 39.688501730561256, 45.56183136999607, 17.808608897030354, 2.9693354666233063, 0.014964794700063067, 0.05711620098736603, 0.053293795353965834, 0.06561597750987858, 0.04680991085479036, 0.07042047087452374, 0.0355525213672081, 0.04952597839292139, 0.017853126773843542, 0.020929035745211877, 0.01622659696295159, 0.05710001845727675, 0.018935029656859115, 0.04856100829783827, 0.023489202176278923, 0.021323377768567298, 0.023239397123688832, 0.0879943571635522, 0.018287956663698424, 0.09529573217150755, 0.05755009762651753, 0.008455474016955122, 0.02595046258647926, 0.05004672486393247, 0.036301823347457685, 0.011804351397586288, 0.028087380342185497, 0.03106378029769985, 0.03289965141448192, 0.020892308712063823, 0.06526025870698504, 0.07314865768421441, 0.04814969150174875, 0.03570652443158906, 0.13334453775314614, 0.2057060884544626, 0.43696592445485294, 0.24675439519342035, 0.173946027061902, 0.14027198165422305, 0.16498413373483345, 0.17153137538116425, 0.06446511426474899, 0.12907665426610038, 0.1316306070657447, 0.15023654617834836, 0.1451751435524784, 0.168570488167461, 0.12983799388166517, 0.09524226043140516, 0.16538424039026722, 0.13305719301570207, 0.173400251660496, 0.16038465866586193, 0.1996849849820137, 0.22239498590352014, 0.11417918998631649, 0.16993080032989383, 0.23700894234934822, 0.1845724685699679, 0.15869320021010935, 0.16151791816810146, 0.10093530494486913, 0.10789123989525251, 0.2837678825017065, 0.18511466681957245, 0.13094778667436913, 0.15869238384766504, 0.10198481308179908, 0.13812613586196676, 0.11395230059861206, 0.2435430182958953, 3.0072714434936643, 15.736978109925985, 39.82303351163864, 57.61173717677593, 54.91213783621788, 32.39168867468834, 27.496555745601654, 39.51336532831192, 33.54692168533802, 18.006842359900475, 7.4131841864436865, 2.271966962143779, 0.6019511120393872, 0.5818781547714025, 2.522744480520487, 5.349968047812581, 9.584411904215813, 17.940152138471603, 14.260793421417475, 14.246027413755655, 12.344270311295986, 9.73582997918129, 6.415448924526572, 5.914351288229227, 6.70714502222836, 10.705812480300665, 17.332963719964027, 23.386808373034, 29.002610631287098, 35.533341094851494, 41.9423545897007, 46.83948241174221, 52.53138318657875, 52.916910499334335, 58.177162036299706, 58.17491635680199, 57.42656551301479, 57.74923659861088, 57.02297016978264, 57.471304312348366, 56.2136135995388, 56.1336924880743, 57.61254273355007, 55.37942536175251, 55.02007104456425, 54.47162747383118, 55.056891068816185, 57.56281100213528, 52.909405902028084, 51.42274707555771, 48.914767652750015, 39.96519908308983, 51.02818384766579, 59.09322068095207, 57.79296085238457, 54.50744055211544, 51.438995003700256, 49.213963598012924, 53.149237632751465, 53.16809222102165, 51.365985721349716, 54.91947904229164, 53.824841380119324, 53.520998284220695, 54.23205032944679, 55.081715136766434, 56.47890396416187, 56.74548625946045, 55.998404547572136, 55.09261675179005, 53.67800585925579, 53.509370908141136, 53.92715469002724, 51.03718176484108, 50.084097906947136, 47.0478518307209, 43.55346813797951, 45.0851621478796, 37.179013788700104, 29.615620337426662, 22.44000557810068, 18.106334321200848, 5.703229866921902, 5.059387190267444, 8.99760939180851, 14.003931004554033, 15.551550909876823, 7.631126241758466, 7.902588425204158, 4.2206947691738605, 3.585136360488832, 0.882247049594298, 0.7112982007674873, 0.5419720429927111, 2.6491475477814674, 10.712906699627638, 26.236843541264534, 35.50482362508774, 39.676357582211494, 48.781079426407814, 49.15162794291973, 50.23169718682766, 21.501336246728897, 3.35570870898664, 0.1912196329794824, 0.14213440124876797, 0.14899089583195746, 0.11631680536083877, 0.11980251714703627, 0.20160506945103407, 0.17944738967344165, 0.15383698657387868, 0.1518492924515158, 0.08960492894402705, 0.13627569453092292, 0.14614841085858643, 0.12281756629818119, 0.1550607435638085, 0.12990591523703188, 0.17666199069935828, 0.1666603484773077, 0.17901134822750464, 0.12973456818144768, 0.16538484895136207, 0.12279298636713065, 0.08657838392537087, 0.1059269456891343, 0.21167757193325087, 0.08393385200179182, 0.15148439328186214, 0.15060019853990525, 0.08591775374952704, 0.14267765334807336, 0.11657128779916093, 0.21876867423998192, 0.23603393841767684, 0.14949598669772968, 0.17571207135915756], [0.03334380453452468, 0.02289675125211943, 0.04500442882999778, 0.06743069185176864, 0.0845347392896656, 0.06143486221844796, 0.06925474983290769, 0.015467665616597515, 0.062478229083353654, 0.03306172162410803, 0.05229648246313445, 0.010915859620581614, 0.004855772986047668, 0.03876361624861602, 0.01697917923593195, 0.014257446327974321, 0.025744616796146147, 0.06289911587373354, 0.05476328486111015, 0.07219309060019441, 0.029798299765388947, 0.034979405245394446, 0.05584495767834596, 0.02224794719950296, 0.0018905910565081285, 0.06710595771437511, 0.020435071528481785, 0.05589521591900848, 0.009686226676421938, 0.0984438335581217, 0.01687942902208306, 0.022723361435055267, 0.02118982458341634, 0.04700476914877072, 0.04058985614392441, 0.038396572272176854, 0.04354909950052388, 0.07060084244585596, 0.20451914198929444, 7.754531744867563, 26.915927901864052, 40.80231316387653, 44.754120111465454, 27.465515211224556, 20.71823626756668, 27.342882491648197, 29.18310284614563, 21.020023673772812, 7.961019789800048, 2.8268578369170427, 0.44389761344064027, 0.1193800124747213, 0.411783013259992, 1.1847986304201186, 0.7476465159561485, 4.358925651758909, 0.18908251484390348, 7.007285691797733, 9.684828165918589, 6.221573352813721, 3.0194089422002435, 5.318793570622802, 2.6364350924268365, 3.5806048661470413, 6.193893263116479, 9.451392441987991, 13.13671113923192, 18.701973259449005, 23.910026997327805, 31.889899000525475, 35.95628499984741, 41.43166959285736, 48.08307588100433, 48.254940658807755, 49.46815475821495, 51.916401386260986, 54.872224777936935, 55.580594167113304, 57.57004201412201, 54.89544913172722, 54.289453849196434, 51.251839846372604, 51.20395101606846, 50.32660849392414, 53.008287996053696, 52.766586765646935, 52.97675348818302, 50.53627364337444, 58.261369317770004, 35.57302616536617, 41.74194574356079, 58.09856705367565, 52.35822647809982, 52.3310237377882, 47.54564791917801, 46.89874783158302, 44.23744663596153, 46.20598420500755, 46.853344067931175, 48.97326171398163, 48.26062135398388, 50.94725579023361, 50.50937108695507, 51.101181730628014, 52.43612229824066, 53.67511421442032, 54.95247267186642, 53.18449214100838, 52.138681858778, 52.13863246142864, 48.08660589158535, 45.88958278298378, 40.18473610281944, 39.37564171850681, 25.606278777122498, 29.865367636084557, 20.147732980549335, 17.855445183813572, 8.424308504909277, 5.102601321414113, 2.321972753852606, 5.702233845368028, 3.677592999301851, 1.9678191700950265, 1.6420250083319843, 1.2786848237738013, 0.5213841539807618, 1.0983093339018524, 1.0857221530750394, 0.24167883238987997, 0.5493955384008586, 0.6217924004886299, 4.093374526128173, 11.31222479045391, 26.237111426889896, 21.820680610835552, 31.96845218539238, 40.81771373748779, 37.79366120696068, 28.541117794811726, 8.529252223670483, 0.8694475551601499, 0.05752964774728753, 0.105839943717001, 0.05090992053737864, 0.017750274382706266, 0.08315263767144643, 0.04686539752583485, 0.055850308563094586, 0.049994781948043965, 0.05679063935531303, 0.1118869407218881, 0.0514711288997205, 0.021646900349878706, 0.10445119987707585, 0.026327998675697017, 0.06178986113809515, 0.0690377013233956, 0.048883345298236236, 0.052181349383317865, 0.03334981593070552, 0.006707865131829749, 0.026339091928093694, 0.08475998853100464, 0.12592230399604887, 0.026506262547627557, 0.028951848798897117, 0.04255292580637615, 0.02470532061124686, 0.07458429041435011, 0.04696726842666976, 0.0409346950618783, 0.013133697448211024, 0.027526847334229387, 0.03295564645668492, 0.01607428970601177, 0.017052154616976622, 0.06832644925452769, 0.01985643568332307, 0.01959117169462843, 0.02861385619326029, 0.04733872818178497, 0.0408920698100701, 0.08898142841644585, 0.07426208700053394, 0.04770192041178234, 0.05741474844398908, 0.03548330867488403, 0.020601110372808762, 0.07002981918049045, 0.05344008750398643, 0.07890265478636138, 0.05304715741658583, 0.0605348152021179, 0.0367641108459793, 0.09831695599132217, 0.029436699442157988, 0.015975190726749133, 0.07219591818284243, 0.022523361913044937, 0.01031108347888221, 0.03708436983288266, 0.004328964560045279, 0.02220528112957254, 0.042054295336129144, 0.04693811686593108, 0.060690792379318736, 0.013364638962229947, 0.01592630174855003, 0.02855199261830421, 0.048900696710916236, 0.06311685458058491, 0.0365658980445005, 0.05318924530001823, 0.47915488248690963, 9.369196202605963, 30.723114609718323, 47.30972997844219, 50.40568225085735, 28.71289137750864, 19.84779417514801, 29.162184968590736, 28.686644285917282, 20.89745555073023, 8.998709432780743, 2.2490720031782985, 0.3782866825349629, 0.10271147213643417, 0.24512411939213052, 0.7427231676410884, 0.299743561190553, 5.61732217669487, 4.8832557164132595, 7.702107382938266, 3.5482683638110757, 5.732303531840444, 6.128641739487648, 9.03639106079936, 3.523086877539754, 3.3794925827533007, 8.478479348123074, 13.407194875180721, 17.69364606589079, 21.869473792612553, 29.085666574537754, 33.862414956092834, 41.58812999725342, 44.865906313061714, 51.521674767136574, 53.035908713936806, 54.90869902074337, 53.45482863485813, 57.06429675221443, 56.824195235967636, 59.41898100078106, 56.3538982719183, 56.42673276364803, 53.54373626410961, 53.84629882872105, 54.15763132274151, 55.14436237514019, 54.01048041880131, 54.35794897377491, 50.87832748889923, 55.94318971037865, 39.99217003583908, 44.47252482175827, 58.27480919659138, 55.32271720468998, 54.88063372671604, 50.10928675532341, 47.31897488236427, 48.78465883433819, 50.10240152478218, 48.931593149900436, 53.366791158914566, 50.40511608123779, 54.83594432473183, 53.13594974577427, 53.94815996289253, 53.7296374887228, 54.74306210875511, 55.946035757660866, 55.26491090655327, 54.15035851299763, 54.73234288394451, 51.34901583194733, 48.71576853096485, 42.512996569275856, 41.81577958166599, 31.367197148501873, 34.94478687644005, 24.8172340169549, 22.270796857774258, 10.333314668387175, 9.432356413453817, 4.993134895339608, 3.388124769553542, 8.203991577029228, 7.986261360347271, 3.6709402687847614, 1.4575465698726475, 0.6999711866956204, 0.8142453047912568, 0.30629577522631735, 0.08563634619349614, 0.37947400007396936, 0.8084158238489181, 5.329859526827931, 12.953861150890589, 28.052332922816277, 24.491245709359646, 35.52999347448349, 44.14967134594917, 43.246611803770065, 34.62949499487877, 10.751137398183346, 0.8152622252237052, 0.09861052734777331, 0.01798584318748908, 0.038765794452046975, 0.04147461862885393, 0.07701736220042221, 0.02236149022792233, 0.027206475169805344, 0.01426917875505751, 0.03431555785937235, 0.07484951172955334, 0.01560584052640479, 0.09187677656882443, 0.0797276409866754, 0.03474095690762624, 0.04865495677222498, 0.033433930948376656, 0.03664436902909074, 0.010625811610225355, 0.015403911420435179, 0.039803120234864764, 0.06233505395357497, 0.0747108859650325, 0.05915677313168999, 0.044709807334584184, 0.03732407611096278, 0.03574258538719732, 0.041546770225977525, 0.05611315500573255, 0.013462583901855396, 0.04057069389091339, 0.04230693353747483, 0.013333597707969602, 0.03994180166046135, 0.008189477157429792, 0.10516794383875094, 0.11168015611474402, 0.16424937784904614, 0.2075945129035972, 0.13414476590696722, 0.08540196111425757, 0.13125190394930542, 0.14379491214640439, 0.19163225224474445, 0.05649713479215279, 0.15451299404958263, 0.1414995829691179, 0.09071970154764131, 0.12144891981733963, 0.1193887772387825, 0.21112492424435914, 0.10797654234920628, 0.16366930038202554, 0.22121504531241953, 0.17138036317192018, 0.10793065535835922, 0.09665053759817965, 0.12421840714523569, 0.12093219949747436, 0.116195338050602, 0.12643962545553222, 0.12462459941161796, 0.09431518439669162, 0.1507011306239292, 0.16124839981785044, 0.11604768034885637, 0.09592102127498947, 0.14115473662968725, 0.20969761098967865, 0.10250367820844986, 0.18729061412159353, 0.18960457120556384, 0.1972754838061519, 0.6761645735241473, 11.541101709008217, 37.7056997269392, 54.40131224691868, 59.2909886687994, 38.25484246015549, 29.911717548966408, 39.78658206760883, 38.6210972070694, 26.61420129239559, 10.794264134019613, 3.422390380874276, 0.8028656872920692, 0.4806323500815779, 1.0727501241490245, 3.155218642205, 2.3046554205939174, 12.590592093765736, 7.29038380086422, 17.258827798068523, 19.08381476998329, 12.996817845851183, 8.783952556550503, 9.633139539510012, 5.805341312661767, 5.489507485181093, 10.186942722648382, 14.000987112522125, 18.175659701228142, 23.029614239931107, 29.212689958512783, 35.26556186378002, 42.29666657745838, 46.67580999433994, 51.434705033898354, 54.89098057150841, 53.29748287796974, 54.99343827366829, 57.70819120109081, 57.29701526463032, 61.1279620975256, 57.58745647966862, 56.654275953769684, 53.60359065234661, 55.55952429771423, 56.77846468985081, 57.23090261220932, 55.30194751918316, 54.1403042525053, 51.03512227535248, 56.3411233574152, 43.36275637149811, 48.514675721526146, 58.60169805586338, 59.10080127418041, 56.51379369199276, 52.9954294860363, 49.67555522918701, 50.16689546406269, 50.27185343205929, 49.975089356303215, 53.99712793529034, 52.255119010806084, 55.74104815721512, 56.875268295407295, 55.166773572564125, 54.80744585394859, 55.02746544778347, 56.9317826628685, 54.161735102534294, 53.17661516368389, 54.39984172582626, 51.50875546038151, 46.98650412261486, 43.650100752711296, 42.10878185927868, 34.01428900659084, 33.620842918753624, 25.39355669170618, 23.005827516317368, 10.803237352520227, 6.324186371639371, 4.830314582213759, 10.65851166844368, 10.645365323871374, 9.384269043803215, 7.800945304334164, 4.56343780271709, 2.2155981743708253, 3.563582254573703, 2.6484773587435484, 0.607412843964994, 0.982254120754078, 1.578654027543962, 5.92618765309453, 16.427757292985916, 33.949282094836235, 31.13532219082117, 43.18647623062134, 51.42572231590748, 52.70675517618656, 40.622415617108345, 12.469697780907154, 1.1799980630166829, 0.1401975442422554, 0.15013828582596034, 0.14036537351785228, 0.21363348729209974, 0.16676221566740423, 0.15029766946099699, 0.08309348850161768, 0.12044563263771124, 0.19463524891762063, 0.2520954539068043, 0.14800567994825542, 0.126740358537063, 0.19040233542909846, 0.1083204461610876, 0.20512995921308175, 0.17050627648131922, 0.1885389955714345, 0.14942935667932034, 0.18595621775602922, 0.14356434170622379, 0.16594656568486243, 0.13026190863456577, 0.166527533729095, 0.11069036117987707, 0.0996077957097441, 0.17450332059524953, 0.17392852721968666, 0.20597530994564295, 0.10666891525033861, 0.15635430696420372, 0.11904931147000752, 0.09440576352062635, 0.13643963495269418, 0.1499845425132662], [0.0622408754134085, 0.016602800897089764, 0.028531902680697385, 0.06495154011645354, 0.03707691495947074, 0.025758992196642794, 0.044725563129759394, 0.010758952903415775, 0.03814837211393751, 0.023772298118274193, 0.014674683607154293, 0.01586353831953602, 0.0700066122226417, 0.11203919231775217, 0.08639931111247279, 0.06163986567116808, 0.012669795778492698, 0.03988675285654608, 0.07232740448671393, 0.04637246674974449, 0.016510455461684614, 0.02254651320981793, 0.0801120289543178, 0.061700988953816704, 0.040371905924985185, 0.02422580600978108, 0.06690947411698289, 0.015224258804664714, 0.01606687936146045, 0.03851697088975925, 0.05005275481380522, 0.052404208909138106, 0.03150240998365916, 0.04746479680761695, 0.039667143937549554, 0.020994827136746608, 0.0685021972458344, 0.022236751901800744, 0.06428431224776432, 2.5334779545664787, 20.095284394919872, 31.121414937078953, 42.57767669856548, 39.001886174082756, 28.81278231739998, 28.168260902166367, 29.33821812272072, 22.327826097607613, 14.017435479909182, 6.060169413685799, 1.4844510261900723, 0.12475296127377078, 0.601133918389678, 0.702513309661299, 0.21576872037258, 2.9708584723994136, 3.155288938432932, 8.835066463798285, 3.5855628876015544, 3.852998474612832, 4.3008229695260525, 7.62670042924583, 0.7634020736441016, 0.47327597450930625, 1.2590025924146175, 3.443786557763815, 5.193868149071932, 9.15405459702015, 13.747423868626356, 19.069326147437096, 27.481732740998268, 32.54523083567619, 38.483574986457825, 43.60006123781204, 49.86309036612511, 53.52257139980793, 55.052878484129906, 54.41978305578232, 55.266966596245766, 55.27847617864609, 55.83383917808533, 51.86790458858013, 51.876370534300804, 52.889126390218735, 55.97334109246731, 51.20042860507965, 54.932687133550644, 50.30944101512432, 55.286406353116035, 34.46216717362404, 35.50961136817932, 55.82696534693241, 53.65642301738262, 52.72200755774975, 48.95045913755894, 47.77407646179199, 45.02143196761608, 46.434386149048805, 44.90478202700615, 47.41596467792988, 50.229250118136406, 52.310010865330696, 51.303764060139656, 53.23211118578911, 54.806427508592606, 52.576912343502045, 53.77408750355244, 52.02808119356632, 47.309106811881065, 45.71207910776138, 40.529271215200424, 34.79676961898804, 28.801187239587307, 26.47416740655899, 22.411923184990883, 18.403468877077103, 11.523342411965132, 7.471563303843141, 4.687561942264438, 4.878552043810487, 2.3081585951149464, 2.5256643863394856, 6.148190265521407, 7.83541657961905, 1.5583796217106283, 0.3506974910851568, 0.6007321493234485, 0.19126264785882086, 0.14460891456110403, 0.03806413464189973, 0.2940014161868021, 1.900990018621087, 7.492739567533135, 16.519613564014435, 24.48163792490959, 23.411814831197262, 38.38623180985451, 44.30324390530586, 31.31704553961754, 18.764932081103325, 3.7717802077531815, 0.1155668577121105, 0.018873976878239773, 0.046071499891695566, 0.03904820390744135, 0.05706567186280154, 0.027876725434907712, 0.04425831437401939, 0.020573606379912235, 0.04804402822628617, 0.10390407376689836, 0.04421556295710616, 0.009715889391372912, 0.01747407113725785, 0.07853636037907563, 0.044696496916003525, 0.02228761870355811, 0.012066233975929208, 0.020856381343037356, 0.031868763762759045, 0.016944276030699257, 0.0026812909618456615, 0.022003531994414516, 0.017682705547485966, 0.031308048928622156, 0.06533278137794696, 0.04781742827617563, 0.03319236187962815, 0.07106452147127129, 0.061235087196109816, 0.04912958247587085, 0.010660079351509921, 0.06481397562311031, 0.027423609026300255, 0.04367539819213562, 0.026782057611853816, 0.0967639526061248, 0.10102696760441177, 0.020150955133431125, 0.017320940096396953, 0.025458849122514948, 0.030076226648816373, 0.08513163382303901, 0.023412005830323324, 0.04478525406739209, 0.019773302155954298, 0.014645994033344323, 0.033973323879763484, 0.026609567648847587, 0.07730936762527563, 0.06990079680690542, 0.037611161096720025, 0.027394366552471183, 0.11220802349271253, 0.042021258632303216, 0.10724171224865131, 0.028997166191402357, 0.050670967539190315, 0.032395799935329705, 0.019342580053489655, 0.040022068642429076, 0.04771679305122234, 0.06033385274349712, 0.03977271815529093, 0.07801157291396521, 0.03475058627373073, 0.008994981053547235, 0.032895591866690665, 0.031730768823763356, 0.07162778929341584, 0.025560942667652853, 0.021973970397084486, 0.04641742605599575, 0.019390559900784865, 0.014483411741821328, 4.136675577610731, 23.5541532933712, 37.85625524818897, 46.55770853161812, 43.27354095876217, 30.176646932959557, 33.35124358534813, 34.28438611328602, 26.8114373087883, 14.410080760717392, 5.9865607134997845, 1.4477821625769138, 0.24494818586390465, 0.20074226340511814, 0.11474422411993146, 0.4002738167764619, 2.0436775870621204, 4.098996799439192, 3.1015854701399803, 2.689919122494757, 3.4342160588130355, 3.452720590867102, 4.232646077871323, 2.4675277434289455, 1.0106000653468072, 2.8374690050259233, 5.095915580168366, 7.646641759201884, 11.187855564057827, 15.805933959782124, 21.58154234290123, 28.89260273426771, 35.02534635365009, 43.70977655053139, 46.16346828639507, 53.6953367292881, 55.43866038322449, 56.876545026898384, 56.83158203959465, 59.45913724601269, 59.19584937393665, 57.60151572525501, 54.12607401609421, 55.19462987780571, 54.96358707547188, 56.992944180965424, 54.971095472574234, 55.42525850236416, 50.452624931931496, 55.49228310585022, 37.756442204117775, 39.24972787499428, 56.87189407646656, 54.652604162693024, 54.173525869846344, 50.820027217268944, 49.453495144844055, 47.65426509082317, 48.776698261499405, 48.97412046790123, 49.75761562585831, 53.114507496356964, 53.43172587454319, 53.54122839868069, 55.46587072312832, 56.35489001870155, 54.26374062895775, 55.230864733457565, 54.49403487145901, 49.96973164379597, 49.77627642452717, 42.788181602954865, 37.53130428493023, 33.22506755590439, 30.28918169438839, 24.563327841460705, 22.756490595638752, 15.357852503657341, 9.673541821539402, 8.18042429164052, 4.8596010357141495, 0.8143153041601181, 5.1502137165516615, 9.608944337815046, 5.412717880681157, 2.4362473469227552, 0.10628042320604436, 0.39924686250742525, 0.11650993445073254, 0.16938588581979275, 0.05622254015179351, 0.3319826046936214, 2.6722930558025837, 9.259763024747372, 18.70779074728489, 30.3475446626544, 24.41586345434189, 42.50731207430363, 50.15416234731674, 37.09961324930191, 22.36498050391674, 4.880256727337837, 0.09591160342097282, 0.004882161438217736, 0.019519628658599686, 0.019578842766350135, 0.05718294603866525, 0.059872812053072266, 0.0922582256316673, 0.050346296484349295, 0.08819132315693423, 0.05510456889169291, 0.01631119808735093, 0.04224716096359771, 0.03909046179614961, 0.1464446762111038, 0.014289808605099097, 0.02496199609595351, 0.03869616615702398, 0.006261068110688939, 0.03637544439698104, 0.0498893153417157, 0.0040188465573010035, 0.018036594956356566, 0.020150302043475676, 0.08130607777275145, 0.024980963535199407, 0.012260051407793071, 0.02520536487281788, 0.0487489015358733, 0.04924610708258115, 0.0120005038115778, 0.02104142102325568, 0.05158676292921882, 0.02239592588011874, 0.04691784139140509, 0.02851483328413451, 0.19899541104678065, 0.10899663917371072, 0.08775366382906213, 0.15958992240484804, 0.185726048075594, 0.1010950151248835, 0.21988989610690624, 0.15604446030920371, 0.19315136916702613, 0.10371765369200148, 0.15987977560143918, 0.10250682491459884, 0.1628005423117429, 0.13790127995889634, 0.15592395036946982, 0.2321865112753585, 0.07960490460391156, 0.2298696746584028, 0.1435764683992602, 0.12923208967549726, 0.090085113333771, 0.15189423691481352, 0.13142319163307548, 0.1500483523705043, 0.14043016301002353, 0.16747445479268208, 0.09748690092237666, 0.13482697773724794, 0.167259217123501, 0.17461726994952187, 0.13629887922434136, 0.1735484882374294, 0.18200732418335974, 0.1159314600226935, 0.09534463970339857, 0.1408952966448851, 0.13866349530871958, 0.17141364107374102, 0.1547704153927043, 4.661030815914273, 26.14041231572628, 43.962390795350075, 55.63143543899059, 53.24898228049278, 40.87229020893574, 40.11049568653107, 41.733502596616745, 29.046133495867252, 18.207304403185844, 7.830355726182461, 2.223032950423658, 0.4982693411875516, 1.1543191596865654, 2.4515336891636252, 1.4464632770977914, 7.24948232062161, 8.113197349011898, 17.590700089931488, 11.582592632621527, 7.941652229055762, 10.720440745353699, 12.83824285492301, 3.4942081896588206, 0.7366692612413317, 3.3084948174655437, 5.240004798397422, 7.960533415898681, 12.052761353552341, 17.42869958281517, 21.807358525693417, 29.536193199455738, 34.39307168126106, 43.53142932057381, 46.50962971150875, 52.3308489471674, 56.40614926815033, 57.937664687633514, 57.69556447863579, 58.77275727689266, 58.383969739079475, 59.0030325204134, 56.423578932881355, 56.58788211643696, 57.284836918115616, 59.3449267745018, 56.69789381325245, 55.47112584114075, 52.39237904548645, 55.169741213321686, 41.52314208447933, 42.56391763687134, 58.34057226777077, 57.480066642165184, 56.555739641189575, 53.33579242229462, 51.237769201397896, 49.19570937752724, 49.525904059410095, 49.45562683045864, 51.83964930474758, 55.668532848358154, 55.98725974559784, 55.98159044981003, 56.15050658583641, 58.5679292678833, 55.30229330062866, 57.15519167482853, 55.24825260043144, 50.66233567893505, 49.3671827763319, 43.463606759905815, 38.045838475227356, 33.492808789014816, 31.977400705218315, 25.237035490572453, 23.906954862177372, 16.786285154521465, 11.30135927349329, 8.863512687385082, 9.799579158425331, 6.290731066837907, 8.152072113007307, 14.261357691138983, 12.924995999783278, 9.086145590990782, 1.0153656033799052, 0.8474567101802677, 0.8653466845862567, 0.9826902661006898, 0.1284044614294544, 0.4028867109445855, 2.58400313090533, 10.489264950156212, 23.706065341830254, 35.416375771164894, 35.05868576467037, 51.8859726190567, 55.63079707324505, 44.79667402803898, 25.58455914258957, 6.078777015209198, 0.23817653360310942, 0.13629738008603454, 0.16248527797870338, 0.12339975888608024, 0.1666310039581731, 0.07663502256036736, 0.17019044811604545, 0.10353756413678639, 0.17942080594366416, 0.2729664871003479, 0.16657461557770148, 0.1435333347762935, 0.11909015185665339, 0.36406817205715925, 0.1764688838738948, 0.10140358528587967, 0.1156526870909147, 0.1025439248769544, 0.14192366099450737, 0.1394101107143797, 0.08420063182711601, 0.08932962926337495, 0.19822918809950352, 0.2162510866764933, 0.15716419788077474, 0.10879090099479072, 0.11184989270986989, 0.25316218729130924, 0.11148719029733911, 0.10886158313951455, 0.15930870780721307, 0.15789594064699486, 0.10548111531534232, 0.07268747227499261, 0.16783648927230388], [0.03470506293524522, 0.03074685355386464, 0.019593301658460405, 0.035288940198370256, 0.03186953559634276, 0.016866901569301262, 0.04727546009235084, 0.06643050684942864, 0.040053097836789675, 0.01293958594033029, 0.05853687573107891, 0.07786116184433922, 0.05812564799271058, 0.04139370226766914, 0.03260841782321222, 0.027689617018040735, 0.09517122205579653, 0.008269101253972622, 0.0361320904630702, 0.015639489502063952, 0.043686055432772264, 0.01270502274564933, 0.06721710917190649, 0.046195757677196525, 0.02986760337080341, 0.14212258625775576, 0.07280632722540759, 0.08096347271930426, 0.027772422145062592, 0.02830222281772876, 0.05360570517950691, 0.027442418759164866, 0.04741083896078635, 0.01672354275797261, 0.0434503641736228, 0.07646731202839874, 0.09421894268598408, 0.02608064085507067, 0.05512183495739009, 0.9373705135658383, 6.648001670837402, 29.876430742442608, 44.506836980581284, 39.35206018388271, 26.119289249181747, 15.246471930295229, 14.6791129745543, 22.472056858241558, 15.053914412856102, 9.301763121038675, 2.5062590651214123, 0.6696313584689051, 0.09289895882830024, 0.17829940596129745, 0.2824129583314061, 2.0387786999344826, 3.4117979742586613, 1.1493245651945472, 1.570098667871207, 1.6505610127933323, 2.7825545892119408, 2.608048478141427, 1.963036770466715, 0.44339500134810805, 0.5518753209616989, 1.3934858073480427, 1.9069789722561836, 3.0279729701578617, 7.784958612173796, 10.591995287686586, 17.550019472837448, 22.825979366898537, 35.055216550827026, 37.499762177467346, 38.509618788957596, 41.4208971709013, 48.092115595936775, 50.803957879543304, 55.60010612010956, 54.36155878007412, 55.24772822856903, 53.677880465984344, 52.993905767798424, 50.79275228083134, 54.621537029743195, 56.13045126199722, 56.321645602583885, 53.52355554699898, 54.963644072413445, 40.05150385200977, 40.049961134791374, 55.641607493162155, 53.98511677980423, 53.64983797073364, 51.14257290959358, 49.449482560157776, 47.09939606487751, 46.94555751979351, 46.21807515621185, 51.40173800289631, 50.810542926192284, 53.57138358056545, 53.44346724450588, 54.85828712582588, 52.34777323901653, 51.03652819991112, 47.71549880504608, 42.15200453996658, 37.64471299946308, 33.07602055370808, 26.128469556570053, 23.261998370289803, 19.61659748107195, 15.218888260424137, 13.581688161939383, 10.167918093502522, 3.789512668736279, 1.733344083186239, 1.2314116791822016, 2.630168991163373, 0.7531030231621116, 4.714626464992762, 7.729679178446531, 1.1711676931008697, 0.8247032342478633, 0.13185032730689272, 0.28786207374650985, 0.05637938193103764, 0.0733623442647513, 0.11468414726550691, 1.0711831832304597, 3.6604915419593453, 9.510468821972609, 23.834488950669765, 22.677148953080177, 24.67259667813778, 39.69928175210953, 34.882648810744286, 29.919569827616215, 11.037743669003248, 1.0400047875009477, 0.036758214482688345, 0.05665776894602459, 0.05717185835237615, 0.012388371524139075, 0.05513771320693195, 0.08609027339844033, 0.0329376345325727, 0.00961498142714845, 0.039753225646563806, 0.026530246905167587, 0.04518253685091622, 0.09213620913214982, 0.01379067996822414, 0.04274367631296627, 0.05654929293086752, 0.027897590916836634, 0.04682828643126413, 0.03378651788807474, 0.061832913124817424, 0.06166165883769281, 0.037653207473340444, 0.012159760353824822, 0.022761756445106585, 0.05089549318654463, 0.053084042156115174, 0.02345864053495461, 0.0076331154832587345, 0.01694352275080746, 0.018807387677952647, 0.031047733209561557, 0.07721604997641407, 0.02208713678555796, 0.04020862601464614, 0.009964844684873242, 0.04413847978867125, 0.056352026367676444, 0.03833830625808332, 0.005661225859512342, 0.05212708725593984, 0.06970971604459919, 0.046657944985781796, 0.08501366944983602, 0.06525224351207726, 0.03925656186765991, 0.04279753025912214, 0.0204556067546946, 0.025803843891480938, 0.03360049486218486, 0.05264797844574787, 0.03717515675816685, 0.040765730300336145, 0.09502612476353534, 0.007254551983351121, 0.03124184935586527, 0.0359293839574093, 0.032228642303380184, 0.022271040979831014, 0.045970167047926225, 0.0169188147992827, 0.01392767857396393, 0.046620280991191976, 0.037313916109269485, 0.04650943381420802, 0.06085538960178383, 0.0208305434716749, 0.08501392178004608, 0.010015207753895083, 0.03533355069521349, 0.01193434505694313, 0.03495581608149223, 0.02394508308498189, 0.07384806507616304, 0.01674223745794734, 0.05809403250168543, 1.280296768527478, 9.564331881701946, 35.22841885685921, 48.888457864522934, 43.587894290685654, 30.77095404267311, 19.741251692175865, 18.626598604023457, 23.833178021013737, 20.450949110090733, 9.510531518608332, 2.8753817081451416, 0.45511624426580966, 0.07501915184548125, 0.10593528000754304, 0.24318934039911255, 1.1383534851484, 2.315787160769105, 1.7549921153113246, 0.5823430954478681, 2.762727728113532, 0.8378993917722255, 1.2852370971813798, 1.8066356191411614, 0.678179474780336, 0.7446689007338136, 2.0173901226371527, 2.474850188009441, 4.914031689986587, 9.890504479408264, 11.87198605388403, 20.628825165331364, 25.758939385414124, 35.86241103708744, 40.305759608745575, 42.60068826377392, 45.09501501917839, 51.84320591390133, 54.70602549612522, 58.84108141064644, 58.04712161421776, 58.54763835668564, 55.62816761434078, 55.55384360253811, 55.02692207694054, 57.688040882349014, 57.42311529815197, 56.718652099370956, 54.65268775820732, 52.76593700051308, 43.641292825341225, 42.06450283527374, 56.88504137098789, 56.3188299536705, 54.419368878006935, 52.767392322421074, 50.551890805363655, 50.16599491238594, 49.25262272357941, 48.56998175382614, 53.685563653707504, 53.596511632204056, 54.66627962887287, 55.34222915768623, 57.933359518647194, 56.80620700120926, 54.0461491048336, 51.12589180469513, 46.186673641204834, 40.06724260747433, 37.537148371338844, 28.77520613372326, 27.023959904909134, 21.781426817178726, 18.29112410545349, 16.041126139461994, 12.715451493859291, 5.3366906102746725, 2.0457534631714225, 1.993469693697989, 1.567288243677467, 0.17894491116749123, 2.160006444901228, 7.254906054586172, 0.6255787191912532, 0.18769949296256527, 0.19109689659671858, 0.1334079765365459, 0.02768062589893816, 0.02175847112084739, 0.10121742496266961, 0.9619973483495414, 4.5438736025244, 10.724294688552618, 27.786776572465897, 23.632782474160194, 25.295402258634567, 44.20964352786541, 40.07494859397411, 34.60390716791153, 13.489018734544516, 1.1859572120010853, 0.024034758644120302, 0.030365029706445057, 0.00924903675695532, 0.029356252489378676, 0.04193359985947609, 0.05304828919179272, 0.011639400727290194, 0.042074240554939024, 0.0274906806225772, 0.046658631472382694, 0.054770268470747396, 0.04339529310527723, 0.02874167257687077, 0.009688756472314708, 0.03906025638571009, 0.048309041740139946, 0.044147300213808194, 0.028796519145544153, 0.01781253500666935, 0.07480464890250005, 0.04752884415211156, 0.06316643004538491, 0.03311556814878713, 0.057364096865057945, 0.02089971905661514, 0.054926991506363265, 0.03599680436309427, 0.08413209448917769, 0.036369507215567864, 0.05613600944343489, 0.08812104177195579, 0.034471360631869175, 0.01880770123534603, 0.03452155950071756, 0.009012422451633029, 0.10195225506322458, 0.14685343630844727, 0.14165075845085084, 0.1543614623369649, 0.24249225592939183, 0.08818603164399974, 0.1497245384962298, 0.2381589001743123, 0.10611830104608089, 0.19563977548386902, 0.17723055003443733, 0.11686306315823458, 0.1354758077650331, 0.26107452053111047, 0.27760565222706646, 0.1146311876073014, 0.20817865733988583, 0.0836435535165947, 0.2700379426823929, 0.08943921478930861, 0.11268655289313756, 0.16209611058002338, 0.2877039072336629, 0.16505088249687105, 0.07929205967229791, 0.19074954179814085, 0.1630539115285501, 0.1278608530992642, 0.15758063178509474, 0.1391190552385524, 0.18526870699133724, 0.09072092609130777, 0.18921354843769222, 0.19647160428576171, 0.12033615101245232, 0.13075175578705966, 0.2182112619630061, 0.14859323826385662, 0.17683359008515254, 1.7107992991805077, 11.402401551604271, 40.30332013964653, 57.739132940769196, 52.30866573750973, 36.98391705751419, 26.371987089514732, 22.280457839369774, 31.97968438267708, 22.502092346549034, 11.838223915547132, 3.4796578204259276, 0.7371755840722471, 0.3501649555983022, 0.44368681381456554, 0.5436484655365348, 3.720894050784409, 6.244675163179636, 3.0612556217238307, 3.024020232260227, 11.965255849063396, 9.709296002984047, 10.425919499248266, 5.365078411996365, 1.7339990730397403, 1.4970219391398132, 2.896663178689778, 3.795147528871894, 5.106868967413902, 9.349112380295992, 13.527714908123016, 21.152651757001877, 27.084399461746216, 36.160410046577454, 38.499541729688644, 40.9870820492506, 44.697928726673126, 51.805496737360954, 55.62538996338844, 58.71905095875263, 58.29117111861706, 59.52851392328739, 58.47429469227791, 57.94222444295883, 56.306313425302505, 58.9557858556509, 59.249950870871544, 57.3857557028532, 54.301947578787804, 52.00633116066456, 46.6023675352335, 46.28536954522133, 57.667263597249985, 57.86696568131447, 56.92905440926552, 54.42789562046528, 54.041726142168045, 51.27112381160259, 51.90850540995598, 50.07914297282696, 55.88661454617977, 55.890338346362114, 56.25746704638004, 56.58852808177471, 57.5244140625, 55.670060366392136, 54.64189633727074, 49.59028020501137, 46.49391755461693, 39.107292518019676, 39.01523865759373, 28.99246897548437, 26.5061616897583, 21.753384321928024, 18.611944690346718, 15.072257928550243, 14.721759986132383, 4.883037703111768, 3.35672824177891, 2.633835794404149, 7.690926482900977, 3.5091024404391646, 13.250781018286943, 14.21602612361312, 6.444486016407609, 3.1244533555582166, 0.36543595022521913, 0.8882461558096111, 0.4345829476369545, 0.10374382181908004, 0.6636193091981113, 1.432054687757045, 5.327308438718319, 14.988142792135477, 33.841261491179466, 35.35264939069748, 34.615488946437836, 54.50471609830856, 45.978425815701485, 42.74989865720272, 15.0712775811553, 2.014340073801577, 0.1526682820986025, 0.17667671490926296, 0.18973667349200696, 0.08244509634096175, 0.1210695190820843, 0.13793881778838113, 0.21523113828152418, 0.09828045716858469, 0.08777159411692992, 0.22607345570577309, 0.18688703421503305, 0.16481093131005764, 0.1195645029656589, 0.10166468768147752, 0.10647550414432772, 0.13872590992832556, 0.11907082633115351, 0.26190878357738256, 0.25713039154652506, 0.1998288874165155, 0.18405731418170035, 0.13361226010601968, 0.11345906925271265, 0.1577733675367199, 0.12715572374872863, 0.09577334873029031, 0.10844569842447527, 0.20945810509147123, 0.07519000908359885, 0.10261065137456171, 0.17721006675856188, 0.10240595962386578, 0.15011035138741136, 0.1112407750042621, 0.13832785160047933], [0.07758329433272593, 0.025104367850872222, 0.03594352187064942, 0.02465877310896758, 0.053538102947641164, 0.017727091544657014, 0.028538305559777655, 0.020693852857220918, 0.05747651739511639, 0.043039663360104896, 0.04523518480709754, 0.04231373161019292, 0.03786013308854308, 0.04717108444310725, 0.04062915286340285, 0.02222709470515838, 0.053503986418945715, 0.03889546249411069, 0.011593471990636317, 0.10988446301780641, 0.011194660382898292, 0.039787742935004644, 0.04026743379654363, 0.10969650669721887, 0.046987814785097726, 0.02175531513785245, 0.02658698595041642, 0.03300522192148492, 0.005959424506727373, 0.02955126663437113, 0.0375842100038426, 0.03194560202246066, 0.007800700313964626, 0.07590120178065263, 0.012424797987478087, 0.02071057529974496, 0.08752623267355375, 0.027840508628287353, 0.0842049288621638, 0.3731638746103272, 4.637656845152378, 18.895088396966457, 44.4878114014864, 45.349814146757126, 32.70041070878506, 20.242855176329613, 25.512932986021042, 27.217299230396748, 22.63634104281664, 14.018629565834999, 4.811386372894049, 1.310621991287917, 0.3269173577427864, 0.10524094148422591, 0.35972120531369, 0.8532084140460938, 0.7203313848003745, 0.6002326542511582, 0.15408814419060946, 2.397722164168954, 0.6430090963840485, 0.6581464153714478, 1.8294713250361383, 0.7352914195507765, 0.1590393527294509, 0.11029441055143252, 0.20814631454413757, 0.6568779365625232, 1.4648292353376746, 2.512494530528784, 6.419732719659805, 14.721809383481741, 19.429577216506004, 22.637110501527786, 26.78780447691679, 31.27362336963415, 34.985456094145775, 46.34630687534809, 44.95131812989712, 53.61948139965534, 54.43200699985027, 54.66617323458195, 55.969058722257614, 55.54742954671383, 54.82548728585243, 54.03926007449627, 55.61176769435406, 52.179993242025375, 55.049549862742424, 42.56081320345402, 42.50616833567619, 54.412764832377434, 52.60962478816509, 54.62165102362633, 52.738171890378, 49.8736348003149, 48.69195140898228, 48.27214613556862, 49.31707866489887, 52.60438486933708, 52.332167476415634, 57.087828889489174, 51.84615075588226, 53.28230269253254, 46.698468178510666, 43.1673214584589, 41.1139914393425, 35.81817381083965, 25.688968040049076, 21.99018381536007, 20.272106006741524, 14.211160484701395, 11.708090398460627, 8.25004605576396, 6.711217928677797, 3.5693558072671294, 3.212226745672524, 1.3247775379568338, 2.0283128740265965, 1.0730783315375447, 0.299594389507547, 2.1946107130497694, 4.846307449042797, 0.9577311866451055, 0.10861731265322305, 0.07002855752944015, 0.05856297335412819, 0.04768071354192216, 0.13263082917546853, 0.3482000750955194, 1.259383165743202, 6.022979384288192, 12.208949122577906, 25.77137041836977, 28.6723817512393, 29.844597950577736, 43.60876277089119, 31.640242896974087, 23.072607032954693, 4.570623217150569, 0.20350520499050617, 0.06955768709303811, 0.04069315196829848, 0.007833534782548668, 0.015916611155262217, 0.035625511591206305, 0.08098998223431408, 0.07970988881425001, 0.00808500595667283, 0.007338238410738995, 0.031290018450818025, 0.07721258414676413, 0.0374906140496023, 0.0441316297656158, 0.039419544918928295, 0.09008021515910514, 0.05594432012003381, 0.0254981662510545, 0.10922602959908545, 0.02193925087340176, 0.05741060354921501, 0.030080647993599996, 0.05277252566884272, 0.0285890443410608, 0.018733193319349084, 0.03408595592190977, 0.06864434079034254, 0.07326782433665358, 0.08198911338695325, 0.037619962968165055, 0.03986664807598572, 0.025015373212227132, 0.01926953045767732, 0.036999490403104573, 0.07314209709875286, 0.05136783678608481, 0.017791174141166266, 0.037610838262480684, 0.05764238740084693, 0.08153332339134067, 0.03947199249523692, 0.03658956884464715, 0.0712487893179059, 0.045897366071585566, 0.020699229717138223, 0.001147787622812757, 0.023280259774765, 0.026280610691173933, 0.048453244744450785, 0.08027571704587899, 0.07204613051726483, 0.04235292813973501, 0.02575144641014049, 0.036643593484768644, 0.04082768478838261, 0.055303534973063506, 0.023014409489405807, 0.028829318362113554, 0.04137211319175549, 0.0054464529603137635, 0.058444033056730404, 0.07090576124028303, 0.051356470794416964, 0.07358751929132268, 0.03245479325414635, 0.04817249398911372, 0.02351825725781964, 0.07480199201381765, 0.02005779890168924, 0.06223363205208443, 0.04975734664185438, 0.06046918708307203, 0.04379333659016993, 0.06087791007303167, 0.07287288302904926, 0.5953006376512349, 5.808067666366696, 24.3883054330945, 50.340812131762505, 50.58841444551945, 35.67666180431843, 21.568503342568874, 23.653998635709286, 27.437628507614136, 25.25663673877716, 17.231146283447742, 4.6802459098398685, 1.1919306102208793, 0.21076078206533566, 0.0719842131366022, 0.2922015596413985, 0.5856622767169029, 0.5169311491772532, 0.6285066402051598, 0.1700910003273748, 1.1783434893004596, 0.18654180195881054, 0.1285133048077114, 0.2869745244970545, 0.2157675032503903, 0.3419563570059836, 0.5868143867701292, 0.39902576187159866, 0.6866245216224343, 2.7176687959581614, 3.7956764129921794, 8.098275549709797, 16.02245584130287, 23.382560200989246, 26.062890775501728, 29.934491626918316, 32.9726243019104, 38.95893707871437, 49.589068070054054, 51.47682957351208, 57.54471257328987, 57.05531023442745, 58.188386633992195, 57.80050344765186, 56.846275851130486, 57.517525032162666, 56.55293919146061, 56.89638376235962, 53.61665815114975, 55.76093249022961, 44.45816159248352, 45.79197362065315, 56.41258992254734, 56.81046277284622, 57.5834970921278, 54.554231241345406, 51.62985496222973, 48.964442387223244, 51.48391619324684, 52.33263485133648, 54.806256517767906, 55.40454961359501, 57.99617774784565, 54.677207842469215, 55.39875112473965, 51.003990545868874, 46.85770243406296, 43.849669843912125, 37.9131305962801, 28.684491701424122, 24.263966605067253, 20.53702589124441, 15.743459612131119, 13.44380971044302, 10.383440628647804, 8.119485061615705, 4.285129336640239, 3.317601028829813, 1.9701289711520076, 1.0029853926971555, 1.11235884251073, 0.6538414838723838, 2.4372538179159164, 2.276876773685217, 0.5914792895782739, 0.005825182051921729, 0.016995307960314676, 0.04539882094832137, 0.0180901464773342, 0.2997878228779882, 0.4085609642788768, 1.1587828514166176, 7.154142111539841, 14.036795441061258, 30.358043499290943, 30.702322125434875, 33.255488723516464, 49.15062479674816, 37.34764114022255, 26.680902913212776, 6.093923952430487, 0.18476003897376359, 0.07624875695910305, 0.04266506803105585, 0.0046972298332548235, 0.036018200480611995, 0.026663451280910522, 0.0572394160553813, 0.09493746038060635, 0.017373842238157522, 0.02300247761013452, 0.04739984775369521, 0.05563348640862387, 0.04875796315900516, 0.103012902836781, 0.0635139703808818, 0.03075991349760443, 0.058391748752910644, 0.049098445670097135, 0.05360206494515296, 0.06502206641016528, 0.035105785573250614, 0.013317336324689677, 0.05035362519265618, 0.04557643915177323, 0.050598051529959776, 0.029659006067959126, 0.04572291683871299, 0.03714832811965607, 0.08172004774678499, 0.03196377721906174, 0.052125621514278464, 0.045729258490609936, 0.05930521379923448, 0.00965355733569595, 0.03362200972333085, 0.13779680040897802, 0.13977925496874377, 0.09154363389825448, 0.11441689246566966, 0.12230721360538155, 0.18684197100810707, 0.10869073332287371, 0.13498532236553729, 0.16811893583508208, 0.10051288933027536, 0.13811354903737083, 0.17032605333952233, 0.10453230919665657, 0.1882030995329842, 0.2796599466819316, 0.1808775230892934, 0.13929574575740844, 0.16645789059111848, 0.19172730651916936, 0.13614765921374783, 0.25776991504244506, 0.09739422152051702, 0.30383080593310297, 0.1271516122506, 0.16661145578837022, 0.18968907214002684, 0.19994270318420604, 0.2283066077507101, 0.13037857424933463, 0.1876169809838757, 0.15432999527547508, 0.08537951114703901, 0.11968210368650034, 0.14538635878125206, 0.13020804355619475, 0.1248503607348539, 0.21287674899213016, 0.1940945498063229, 0.25978906138334423, 0.26012267160695046, 0.7592728233430535, 6.585780009627342, 28.055479153990746, 55.81402704119682, 58.654465824365616, 45.42458653450012, 32.12969273328781, 37.36268073320389, 37.18782551586628, 31.363828629255295, 18.383145667612553, 6.906775860115886, 1.573542826808989, 0.678846042137593, 0.49368948850315064, 0.8258279738947749, 1.4599976758472621, 6.118226498365402, 2.9877020185813308, 0.9470652777235955, 4.972521001473069, 1.7296239640563726, 3.031778703443706, 4.6265291422605515, 1.7772513208910823, 1.3228719402104616, 0.7173825649078935, 0.6873258214909583, 1.5410683443769813, 2.57653059437871, 3.6677660141140223, 7.695059711113572, 15.453671962022781, 20.5791637301445, 25.12841261923313, 29.75620899349451, 33.91008339822292, 39.74281221628189, 51.452666670084, 53.48714590072632, 60.177598893642426, 58.47649097442627, 59.62059438228607, 61.00518688559532, 58.64910811185837, 58.98120269179344, 55.803497806191444, 56.970350593328476, 54.1046317666769, 56.464696526527405, 48.03936682641506, 49.932075664401054, 55.41108526289463, 57.94243723154068, 57.24506825208664, 57.19312123954296, 52.484771087765694, 50.545742735266685, 52.18502417206764, 54.94693636894226, 56.58628240227699, 57.22267225384712, 59.24113914370537, 54.55935336649418, 55.85965499281883, 50.056613981723785, 44.907411485910416, 41.71203374862671, 36.88146315515041, 28.14010251313448, 24.221982657909393, 21.945274025201797, 16.79674219340086, 15.354993157088757, 10.556706581264734, 9.554073382169008, 5.635415855795145, 4.957374539226294, 2.9493922367691994, 5.595779232680798, 4.373049018904567, 1.8558856076560915, 10.124759059399366, 13.873285464942455, 4.650812689214945, 0.1551747671328485, 0.2501642075367272, 0.15795669285580516, 0.2943109511397779, 0.7740244036540389, 0.37923476134892553, 2.0780244190245867, 9.803363755345345, 17.673533745110035, 35.87461598217487, 39.880680218338966, 41.570145562291145, 55.98566763103008, 45.97426503896713, 30.46371202915907, 8.145087137818336, 0.44672813499346375, 0.20412841608049348, 0.1250283425906673, 0.05588585372606758, 0.07130720376153477, 0.11524740024469793, 0.20466682937694713, 0.27468616201076657, 0.11072326058638282, 0.25011807563714683, 0.1601663781912066, 0.14216275129001588, 0.17054476425983012, 0.19966683204984292, 0.16666257492033765, 0.19591321237385273, 0.14388710173079744, 0.10149451321922243, 0.1723292435053736, 0.1201011128432583, 0.20862810197286308, 0.10071778888232075, 0.15742302930448204, 0.1387181322206743, 0.14123563072644174, 0.146997531701345, 0.34763194620609283, 0.11795743412221782, 0.37470709648914635, 0.13258080842206255, 0.10169410641537979, 0.14509332919260487, 0.13276275334646925, 0.10680147024686448, 0.13238361978437752, 0.20690495381131768], [0.025246071672881953, 0.033579510636627674, 0.023669686925131828, 0.044958475045859814, 0.036924062223988585, 0.1324631631723605, 0.09663966513471678, 0.022708598262397572, 0.007252807008626405, 0.039004914433462545, 0.004196605768811423, 0.03740277716133278, 0.07504009525291622, 0.02345047876588069, 0.1220501188072376, 0.04088577639777213, 0.04559108543617185, 0.055613010554225184, 0.024625508194731083, 0.07361244803178124, 0.02346068144106539, 0.03114266502961982, 0.002633905992297514, 0.13420946634141728, 0.08946844056481495, 0.03846346946374979, 0.02686605388589669, 0.03778640442760661, 0.028623869620787445, 0.032454915708513, 0.035823160360450856, 0.013106299211358419, 0.04588535441143904, 0.03871653811074793, 0.029980109247844666, 0.04965533473296091, 0.018746704117802437, 0.044345683709252626, 0.031436277204193175, 0.02732569377258187, 1.8305486859753728, 10.772800035774708, 36.69741243124008, 47.44626045227051, 35.23094952106476, 33.309727013111115, 27.543019652366638, 26.27136278897524, 25.473814085125923, 16.92899029701948, 9.942899867892265, 3.6064137937501073, 0.5925798055250198, 0.22642462514340878, 0.14378861873410642, 0.5833226710092276, 0.2556643827119842, 1.0574257839471102, 0.13772221456747502, 0.13620404759421945, 0.014803628055233276, 0.04524482901615556, 0.07460063992766663, 0.12103823013603687, 0.30994488566648215, 0.23083114181645215, 0.4569224832812324, 0.45729236968327314, 0.9455577679909766, 1.1543683195486665, 1.9624353339895606, 6.033393200486898, 9.831159263849258, 15.72183022275567, 18.81949905306101, 21.748446486890316, 26.76281701773405, 36.22781842947006, 45.399960055947304, 51.896076276898384, 53.65600124001503, 56.4766126871109, 56.46507270634174, 57.58314751088619, 56.0178405046463, 56.494897305965424, 55.526545867323875, 51.822459027171135, 55.79319655895233, 48.6513239890337, 42.30825215578079, 53.00611451268196, 53.3844868093729, 54.79687862098217, 51.54610365629196, 54.564213305711746, 49.427006766200066, 50.62976382672787, 49.129832312464714, 54.97410111129284, 52.898276299238205, 60.038028582930565, 48.29698160290718, 45.55528052151203, 38.643048629164696, 32.79378689825535, 27.61010505259037, 21.53762809932232, 17.3166910931468, 11.024791114032269, 8.247993215918541, 6.95266742259264, 5.10001128539443, 2.7049905387684703, 2.6468337094411254, 0.22939815855352208, 0.6688273453619331, 0.1349573433981277, 0.5180408083833754, 0.8158986316993833, 0.9647391980979592, 0.253185520414263, 0.6930500955786556, 0.04488728452997748, 0.11462643786217086, 0.0794252529158257, 0.04646458211936988, 0.09861105427262373, 0.2207313579856418, 0.8061922306660563, 4.350945604965091, 15.523385871201754, 20.971036702394485, 29.682690538465977, 28.504331968724728, 38.52182373404503, 48.54621022939682, 33.01166720688343, 13.0501270852983, 2.008066847920418, 0.040922030311776325, 0.023550403384433594, 0.042946687099174596, 0.08545911390683614, 0.04704041450168006, 0.022900211515661795, 0.026448792486917228, 0.04036873324366752, 0.03631507068348583, 0.017271459255425725, 0.0294715098789311, 0.020114126054977532, 0.038541283647646196, 0.04677693352277856, 0.08150104738888331, 0.052542916309903376, 0.05143641494214535, 0.0316715343069518, 0.006844831732450984, 0.05422024056315422, 0.05114470637636259, 0.033185767897521146, 0.06447506646509282, 0.035854924281011336, 0.04887498500465881, 0.019307214861328248, 0.04978347395081073, 0.01812125545257004, 0.03269793567596935, 0.007720021440036362, 0.034537107494543307, 0.009827401718212059, 0.033365809213137254, 0.020545469706121366, 0.041044417885132134, 0.04240121597831603, 0.06378950754879043, 0.05907055783609394, 0.013623521408590022, 0.06054055200365838, 0.02684667084395187, 0.017936123003892135, 0.013142857405910036, 0.07163973044953309, 0.034740674891509116, 0.012795151942555094, 0.03827228480076883, 0.022940033304621466, 0.039299253912759013, 0.044117796132923104, 0.06864788825623691, 0.029302123948582448, 0.03023756027687341, 0.026580683261272497, 0.030149730810080655, 0.07355467925663106, 0.04660760139813647, 0.015571521762467455, 0.03866732629830949, 0.044014574523316696, 0.05973887295112945, 0.07365129204117693, 0.07048754618153907, 0.03612842054280918, 0.06860317385871895, 0.011746604886866407, 0.002884677924157586, 0.02995338636537781, 0.011409803428250598, 0.056964442919706926, 0.013347570493351668, 0.027039386186515912, 0.007361023735938943, 0.053203208808554336, 0.052962044210289605, 0.03203916458005551, 2.6107482332736254, 13.417783007025719, 42.95205540955067, 52.59590372443199, 38.35730396211147, 34.423774033784866, 32.509121373295784, 30.78883968293667, 31.53797708451748, 19.41342618316412, 11.754834540188313, 4.079636363312602, 0.5542778014205396, 0.20592965302057564, 0.12699816579697654, 0.17583473352715373, 0.09346300590550527, 0.5604150658473372, 0.06451613691751845, 0.08644940608064644, 0.015136142683331855, 0.08599067718023434, 0.07606815532199107, 0.12342419038759544, 0.45007438980974257, 0.5503613397013396, 0.49681152566336095, 0.46182080637663603, 0.7413941295817494, 2.0481219235807657, 2.4687990127131343, 7.909096051007509, 11.314447671175003, 16.70675352215767, 20.90684674680233, 23.416302390396595, 29.533911421895027, 38.595953956246376, 49.39751274883747, 53.76210294663906, 57.036250457167625, 58.10183487832546, 60.037667602300644, 59.45558823645115, 57.90976658463478, 57.95167453587055, 58.50186601281166, 53.347700983285904, 57.31144309043884, 49.29862305521965, 46.099232733249664, 55.42000338435173, 56.483741104602814, 57.271758019924164, 55.24898216128349, 56.1234862357378, 51.32452614605427, 51.57663881778717, 51.661340072751045, 56.943577229976654, 55.20012058317661, 60.908333882689476, 50.41499175131321, 49.3828721344471, 43.507589399814606, 34.80120778083801, 28.542461022734642, 22.577212415635586, 20.691820085048676, 13.717818707227707, 9.26704628393054, 7.926366124302149, 6.675107516348362, 4.350825911387801, 3.028640546835959, 0.8187925920356065, 0.5042894650250673, 0.41639264090918005, 1.3268257468007505, 0.5544508702587336, 0.9847121138591319, 0.4937888472341001, 0.2019780728733167, 0.09099204748054035, 0.10184101454797201, 0.08457831820123829, 0.15793888131156564, 0.04983019956853241, 0.22523515537614003, 0.755988493328914, 4.761532573029399, 14.328598883002996, 24.06108219176531, 30.815841034054756, 33.336610570549965, 40.44191010296345, 53.35586674511433, 37.72686459124088, 16.39422219246626, 2.549401237629354, 0.06192755179654341, 0.06697447883198038, 0.007046759910736, 0.023307277660933323, 0.0070400096137746004, 0.008302218666358385, 0.03609282342949882, 0.05743230023654178, 0.046831581566948444, 0.10041038389317691, 0.0061039016418362735, 0.04920836887322366, 0.020180344181426335, 0.07228089409181848, 0.020827266889682505, 0.06819491842179559, 0.06649160786764696, 0.03472776894341223, 0.05831381211464759, 0.0453588674281491, 0.041389427497051656, 0.037924840944469906, 0.09432170787476934, 0.049169112971867435, 0.05258202007098589, 0.01961823225428816, 0.0896467044367455, 0.010220492295047734, 0.07968035133671947, 0.04535909007245209, 0.04487525802687742, 0.01936947177455295, 0.009582709135429468, 0.046354892692761496, 0.011816916885436513, 0.07613105975906365, 0.16103993053548038, 0.11356654707924463, 0.1306056120665744, 0.1316804051748477, 0.16887733654584736, 0.2617505280068144, 0.18955667299451306, 0.20797860401216894, 0.11658444607746787, 0.06748575178789906, 0.22511608520289883, 0.1778068722342141, 0.1858338524471037, 0.12405776185914874, 0.1763938824296929, 0.16852052678586915, 0.12212214423925616, 0.23981667996849865, 0.08816929621389136, 0.16974211670458317, 0.17849895462859422, 0.1091024768538773, 0.14818976225797087, 0.23029569711070508, 0.19683562772115692, 0.1506701682228595, 0.12067998803104274, 0.08625475558801554, 0.1876213151263073, 0.09900446675601415, 0.08525186174665578, 0.12420481842127629, 0.08182753299479373, 0.1254006929229945, 0.08884064300218597, 0.1447644835570827, 0.09071827662410215, 0.14126110123470426, 0.15025128523120657, 0.10894117847783491, 2.955829566344619, 17.22856432199478, 48.76856669783592, 60.29868319630623, 47.76333823800087, 44.979949593544006, 39.346428886055946, 35.80649323761463, 36.0130425542593, 21.34151492267847, 13.217594549059868, 4.285615235567093, 1.2104498664848506, 0.3919648501323536, 1.098488043062389, 1.626117993146181, 2.480679787695408, 4.240102702751756, 0.6221093272324651, 0.46527464292012155, 0.42573678481858224, 0.3690780251054093, 0.4744078387739137, 0.6273068545851856, 1.296251518651843, 0.9954959945753217, 1.9010584149509668, 1.355358890723437, 2.268084045499563, 2.4923807848244905, 3.754458837211132, 7.67300664447248, 12.852110210806131, 18.836734928190708, 22.01421182602644, 25.256093367934227, 30.471269823610783, 41.12756051123142, 50.11739172041416, 57.726004645228386, 59.3682537227869, 60.22076077759266, 60.75637623667717, 62.11953788995743, 58.77164013683796, 58.83948549628258, 59.442216753959656, 54.046707674860954, 58.627050295472145, 53.09981368482113, 50.55765509605408, 56.17740534245968, 57.515321150422096, 59.59542453289032, 55.937357023358345, 57.80046924948692, 53.537375405430794, 53.474606573581696, 53.0684881657362, 57.65546903014183, 55.16973741352558, 61.34148024022579, 50.704718604683876, 48.693931102752686, 43.135733753442764, 33.966388776898384, 28.443430736660957, 22.829264290630817, 19.40316293388605, 12.783530540764332, 9.373811054974794, 8.920723367482424, 5.5666157975792885, 3.752472731284797, 4.142039939761162, 1.0897279693745077, 1.5446111792698503, 0.5265409522689879, 1.7808536463417113, 1.313073334749788, 2.5185552053153515, 1.1676109652034938, 1.7039772402495146, 0.13900900958105922, 0.28671094332821667, 0.31698175182100385, 0.4126211057882756, 0.28128076752182096, 0.6526561849750578, 1.0700688930228353, 6.646676016971469, 18.887771889567375, 28.806613348424435, 40.26040904223919, 40.43543145060539, 48.16666379570961, 60.67205876111984, 43.17874364554882, 20.61542898416519, 3.328353026881814, 0.14384586800588295, 0.13258239661809057, 0.13175938453059644, 0.1415267158881761, 0.24705731018912047, 0.09852482413407415, 0.10872695755097084, 0.11545368761289865, 0.2108939382014796, 0.22131149482447654, 0.16510036890394986, 0.15195915999356657, 0.16021158982766792, 0.20260379242245108, 0.23339679086348042, 0.1838420468266122, 0.1664225198328495, 0.16115453297970816, 0.13626625441247597, 0.14826862287009135, 0.15345519612310454, 0.09649756611906923, 0.21208091435255483, 0.13138801383320242, 0.1602500627632253, 0.07684689830057323, 0.20826106541790068, 0.09732957303640433, 0.13476711610564962, 0.12926394265377894, 0.15444814518559724, 0.05486887021106668, 0.0824854765960481, 0.13360170676605776, 0.1430219950270839, 0.24301199679030105], [0.08849306555930525, 0.017328816138615366, 0.024823750682116952, 0.06861432833829895, 0.016700975902494974, 0.04272311140084639, 0.01831976325775031, 0.032783679707790725, 0.038826019736006856, 0.03394078441488091, 0.03861345750920009, 0.0521298406238202, 0.057912328775273636, 0.06221884847036563, 0.03928671903850045, 0.04738205476314761, 0.025012760852405336, 0.03725704904354643, 0.012919360560772475, 0.06045700472895987, 0.061571532423840836, 0.0457411514071282, 0.05628710699966177, 0.010583070397842675, 0.039916145615279675, 0.0690104125533253, 0.07720302528468892, 0.035551033361116424, 0.010193132093263557, 0.03921762137906626, 0.0307926310779294, 0.02402847821940668, 0.03491223345918115, 0.0323024488898227, 0.008242144594987622, 0.03829546578344889, 0.025890448814607225, 0.05370786180719733, 0.01422207556970534, 0.09272763403714634, 0.6938570772763342, 6.959153674542904, 25.18356665968895, 44.06062692403793, 41.12638257443905, 29.9749955534935, 14.100314732640982, 16.001442968845367, 25.562987700104713, 31.372611857950687, 9.440802410244942, 6.299029346555471, 2.6755563681945205, 0.7618962856940925, 0.050214921502629295, 0.19976749696070328, 0.20230081805493683, 0.06900285748997703, 0.08263449984951876, 0.07924735269625671, 0.06616186423343606, 0.08572612379794009, 0.05954550266324077, 0.06698417128063738, 0.015932242640701588, 0.4456981527619064, 0.19987677078461275, 0.34045870299451053, 0.4235711682122201, 0.665548121323809, 0.3783092141384259, 2.1760686580091715, 4.300743173807859, 6.178705953061581, 11.856394540518522, 15.639906618744135, 20.523701906204224, 25.54868906736374, 36.37967348098755, 44.16939988732338, 49.25747126340866, 54.41068634390831, 56.883947029709816, 58.6829224973917, 55.52054598927498, 55.616129860281944, 54.23579312860966, 51.0758712887764, 52.674000933766365, 48.16053092479706, 40.76046220958233, 51.88218042254448, 54.67211611568928, 55.22544242441654, 53.39581400156021, 53.75529371201992, 51.505062058568, 52.702590599656105, 51.311420649290085, 54.42102178931236, 54.451241567730904, 55.317895263433456, 46.694824174046516, 34.98243525624275, 28.897863551974297, 20.584525242447853, 19.95033547282219, 14.633082244545221, 10.513074472546577, 6.351334014907479, 3.971957741305232, 1.9168621231801808, 2.5851808302104473, 1.0963628883473575, 0.1268694328609854, 0.15721795905847102, 0.5444054561667144, 0.2666444575879723, 0.3732492809649557, 0.06191437496454455, 0.3847028163727373, 0.18224595434730873, 0.02576594240963459, 0.011899605124199297, 0.04928794194711372, 0.0814753097074572, 0.015117062066565268, 0.023888041614554822, 0.40385120606515557, 4.140107743442059, 10.876789055764675, 23.372595235705376, 29.707949683070183, 25.477055311203003, 30.21587982773781, 40.267275273799896, 39.20004554092884, 23.972311355173588, 6.63512178696692, 0.40028943156357855, 0.09273830612073652, 0.02748955441347789, 0.0435056282003643, 0.031226245700963773, 0.020542217243928462, 0.039207357476698235, 0.026993406427209266, 0.04240574678988196, 0.008818459373287624, 0.06757285023923032, 0.037346978788264096, 0.05799500402645208, 0.025341012769786175, 0.07551054266514257, 0.036677001262432896, 0.04688717956014443, 0.05740650318330154, 0.034082297133863904, 0.07986109398189001, 0.05309300730004907, 0.04946653236402199, 0.026570940717647318, 0.020386479409353342, 0.06534175394335762, 0.027681586980179418, 0.039139844302553684, 0.046737952216062695, 0.0593998450494837, 0.005325117381289601, 0.022448379022534937, 0.037220928716124035, 0.024435334707959555, 0.04697946933447383, 0.09412606290425174, 0.016495345334988087, 0.027914022066397592, 0.027837951929541305, 0.0660835973394569, 0.04235117667121813, 0.059517612753552385, 0.02080254223983502, 0.08127775741741061, 0.0165961531092762, 0.07337023329455405, 0.03288779560534749, 0.023754156318318564, 0.06892295787110925, 0.024246669636340812, 0.02951315364043694, 0.06177047253004275, 0.033786696003517136, 0.05125201721966732, 0.0214450807106914, 0.02660915761225624, 0.07896961877122521, 0.02523486895370297, 0.018897564186772797, 0.04843244605581276, 0.06566272539203055, 0.03569636814063415, 0.024548384208173957, 0.028411151542968582, 0.03652102037449367, 0.05721365239878651, 0.041842304563033395, 0.04254354877048172, 0.027051577817474026, 0.050266816178918816, 0.04549340395897161, 0.036808650838793255, 0.031609275538357906, 0.036030742776347324, 0.03973469421907794, 0.04008335519756656, 0.06518808484543115, 0.024427534735877998, 1.0829502018168569, 9.298665337264538, 31.026798114180565, 49.34406101703644, 46.690519005060196, 34.94670957326889, 19.930709525942802, 20.341231897473335, 27.89710745215416, 33.64455744624138, 12.126791831105947, 7.712223865091801, 3.1871549785137177, 0.5743142450228333, 0.14958557876525447, 0.03096698383160401, 0.04363989384728484, 0.06736313414876349, 0.11790139455115423, 0.04394220028189011, 0.09913970832712948, 0.09860377380391583, 0.017506170879642013, 0.1730569638311863, 0.7906217942945659, 0.6052093778271228, 0.33528489468153566, 0.26400089787784964, 0.3671135602053255, 1.0868322872556746, 0.6305153074208647, 3.291680244728923, 6.20254254899919, 8.295372873544693, 11.486623082309961, 17.668326124548912, 21.99399311095476, 27.212724275887012, 37.941264286637306, 46.608971580863, 50.74826806783676, 56.349110528826714, 58.37008148431778, 58.98990422487259, 58.53957898914814, 56.52827471494675, 56.49391695857048, 52.1788115054369, 53.679354786872864, 47.69438333809376, 45.33066317439079, 54.142800718545914, 57.68576480448246, 59.41372588276863, 57.84132465720177, 56.930141150951385, 53.69038179516792, 55.599023178219795, 52.9503221064806, 55.456948801875114, 55.89469291269779, 55.761738047003746, 48.518251329660416, 36.243264600634575, 32.18350924551487, 22.598966248333454, 20.124801211059093, 15.333789344877005, 15.330588016659021, 8.111037164926529, 4.640836324542761, 3.136078594252467, 2.9996424028649926, 2.48295942787081, 1.732303889002651, 0.45031846733763814, 0.6862802838440984, 0.958716640016064, 0.7337155134882778, 0.1590918077272363, 0.14990204537753016, 0.08163720922311768, 0.0521923628548393, 0.07548969573690556, 0.039965676551219076, 0.1401509076822549, 0.08147421875037253, 0.031633328544558026, 0.6341940443962812, 4.766352139413357, 12.385331857949495, 23.160891495645046, 31.43223635852337, 32.46114134788513, 32.123958840966225, 44.989920258522034, 43.03319625556469, 28.369836285710335, 7.940870421007276, 0.4962796135805547, 0.05728620104491711, 0.026858511810132768, 0.023432941816281527, 0.026710985839599743, 0.03563133745046798, 0.043495868958416395, 0.055821698770159855, 0.03290703949460294, 0.08077574646449648, 0.07892327164881863, 0.05112849787110463, 0.06601617322303355, 0.06785524485167116, 0.005361968724173494, 0.07134569896152243, 0.04827200114959851, 0.0546382070024265, 0.028198600448376965, 0.03518970392178744, 0.050689799536485225, 0.03342204916407354, 0.04016273531306069, 0.029511383618228137, 0.03456847436609678, 0.011284203283139504, 0.02300750380527461, 0.022026002370694187, 0.020783923609997146, 0.051588202695711516, 0.05241217957518529, 0.013955624144728063, 0.08869115961715579, 0.03738108789548278, 0.060349846025928855, 0.04909384806524031, 0.0741467646730598, 0.12454621377401054, 0.13099819334456697, 0.10828558006323874, 0.19889838265953586, 0.15348795452155173, 0.1861254867981188, 0.14292141917394474, 0.16654543433105573, 0.14950121141737327, 0.11206494484213181, 0.13366746105020866, 0.1433956070104614, 0.2244445009273477, 0.1943342635058798, 0.17365237406920642, 0.11542380874743685, 0.10373567303759046, 0.136005092645064, 0.1157283787324559, 0.19378969038370997, 0.13807561044814065, 0.19737218564841896, 0.15265838184859604, 0.11191195852006786, 0.1485196320572868, 0.19415306072914973, 0.13259352883324027, 0.19724728219443932, 0.11610814312007278, 0.11194016013178043, 0.16924756433581933, 0.12303061463171616, 0.17835891136201099, 0.1598415698390454, 0.12809424370061606, 0.18352752464124933, 0.10193622467340901, 0.17436375230317935, 0.19333698030095547, 0.16544252866879106, 1.5874095889739692, 10.820231940597296, 35.86787894368172, 56.5157163888216, 54.83881317079067, 40.462694987654686, 26.393558531999588, 27.106592170894146, 35.496331080794334, 38.31472724676132, 13.27314281836152, 8.963028397411108, 4.296876881271601, 0.9312283806502819, 0.3225366084370762, 0.6642500753514469, 0.5125534278340638, 0.14506092702504247, 0.12154741765698418, 0.18292942782863975, 0.22067036828957498, 0.2927125431597233, 0.2053251292090863, 0.2712585381232202, 0.8160259248688817, 1.4656876330263913, 0.9990014252252877, 0.6444811017718166, 1.0573064466007054, 1.371455539483577, 0.7281337911263108, 3.6444697016850114, 5.7839033380150795, 8.937196433544159, 13.631645031273365, 19.2422928661108, 22.780769392848015, 28.41003242880106, 41.05897419154644, 48.442000821232796, 52.411290630698204, 59.20846089720726, 60.311826691031456, 60.63086897134781, 59.109894186258316, 57.717489302158356, 58.67008678615093, 53.07623215019703, 55.00846266746521, 51.48500673472881, 49.25402104854584, 56.74306958913803, 58.88641677796841, 61.4635144919157, 58.568138256669044, 57.540916576981544, 56.99324056506157, 57.3092620074749, 55.42072154581547, 56.9148013740778, 59.856174141168594, 56.71539947390556, 50.233897268772125, 37.653129547834396, 33.91259886324406, 25.1114921271801, 22.05834075808525, 16.564764641225338, 12.825309298932552, 8.238239139318466, 6.028005089610815, 2.8800010727718472, 4.228835357353091, 2.905211295001209, 1.4298988971859217, 0.8920796751044691, 1.3194370432756841, 1.3698922796174884, 1.9003881071694195, 0.936277894070372, 1.0076864529401064, 0.6547351484186947, 0.21240224945358932, 0.26045355072710663, 0.17109327076468617, 0.2796868421137333, 0.14652493206085637, 0.11100140269263647, 0.7080529374070466, 4.5535835064947605, 12.258390169590712, 27.66956616193056, 39.339498057961464, 34.87284153699875, 40.91738618910313, 49.72880557179451, 50.18258102238178, 35.14311723411083, 10.23022335022688, 0.9299035579897463, 0.14931196375982836, 0.16301098570693284, 0.1294040898210369, 0.12111996285966597, 0.14450296555878595, 0.17797235632315278, 0.16152473108377308, 0.18149012146750465, 0.1059243110648822, 0.11235670535825193, 0.17083506274502724, 0.16591624153079465, 0.13176028995076194, 0.1986292502260767, 0.13428917300188914, 0.1426958804950118, 0.13929917447967455, 0.11207747971639037, 0.13279557111673057, 0.09324751590611413, 0.13720673363422975, 0.08489963103784248, 0.13096953160129488, 0.14487334177829325, 0.14293516374891624, 0.15660237724659964, 0.11775154009228572, 0.1155808917246759, 0.20944473159033805, 0.15963575744535774, 0.09277944336645305, 0.11452281920355745, 0.10600612542475574, 0.1708408514969051, 0.1825541682774201, 0.1292154358816333], [0.021203151700319722, 0.04268326178134885, 0.08543719828594476, 0.025056950180442072, 0.049139081966131926, 0.03533114984747954, 0.022717748943250626, 0.0537897578033153, 0.07466972645488568, 0.0830547335499432, 0.019151081833115313, 0.06932874937774613, 0.12054578546667472, 0.012916863233840559, 0.04845602408749983, 0.01376227797663887, 0.02636884462845046, 0.0537190237082541, 0.027850009973917622, 0.02879644864151487, 0.06995862495386973, 0.056498481790185906, 0.06559527158970013, 0.005458954901769175, 0.029123411077307537, 0.06495822686702013, 0.07005320425378159, 0.030705710742040537, 0.03255448224081192, 0.040565502567915246, 0.06657754114712588, 0.03569489126675762, 0.04697614822362084, 0.11328801905619912, 0.05169546158867888, 0.03235730102460366, 0.04744260659208521, 0.060301784542389214, 0.02443329936795635, 0.06609202813706361, 0.17292457952862605, 2.533230730332434, 15.602059699594975, 34.616020917892456, 38.954164534807205, 34.301876574754715, 28.560823537409306, 21.086922883987427, 27.91242443025112, 22.077820412814617, 20.175539888441563, 12.283339630812407, 5.1004639361053705, 1.6924485401250422, 0.18272725195856765, 0.04648217473004479, 0.061234248569235206, 0.032442002338939346, 0.022629190316365566, 0.02604055745905498, 0.08800056151812896, 0.12163223771494813, 0.13382322300458327, 0.09936664966517128, 0.3674564918037504, 0.6255648261867464, 0.5777911772020161, 0.3581392136402428, 0.2957021218026057, 0.5824090575333685, 0.2261292058392428, 0.9226683899760246, 1.8424543971195817, 1.854020026512444, 3.707581702619791, 8.830211274325848, 13.788009490817785, 19.199148081243038, 27.70765531808138, 34.566027000546455, 41.65595255792141, 47.17222295701504, 49.90945927798748, 54.00109872221947, 57.111334428191185, 57.694610729813576, 56.24680481851101, 49.50557895004749, 55.19130505621433, 47.64177516102791, 43.5238753259182, 49.532249718904495, 52.84738563001156, 55.149374306201935, 55.193288549780846, 57.60135993361473, 53.81036035716534, 55.35224922001362, 54.031907469034195, 53.66787940263748, 53.004419803619385, 49.49522830545902, 40.19668646156788, 29.706500060856342, 25.232903212308884, 18.048073947429657, 13.228467665612698, 6.960433255881071, 9.341448191553354, 4.487057626247406, 1.4899381692521274, 0.9612286614719778, 1.5040455060079694, 1.8248829524964094, 0.8324994659051299, 0.06587333948118612, 0.24820942024234682, 0.6702210986986756, 0.3770053794141859, 0.07803756292560138, 0.09209881231072359, 0.08945868132286705, 0.09540089449728839, 0.0394001340464456, 0.06784538913052529, 0.04467914179258514, 0.10849897720618173, 0.3071753092808649, 1.039560092613101, 4.737279899418354, 16.8011936545372, 33.83477903902531, 36.188665330410004, 17.122143432497978, 26.820585317909718, 41.08514338731766, 31.60897057503462, 15.063177365809679, 2.397075961343944, 0.051080124685540795, 0.017885597590066027, 0.03780001170525793, 0.04437895790033508, 0.031964712325134315, 0.03736803351785056, 0.04998609139875043, 0.0472738310782006, 0.037512629860430025, 0.016027925885282457, 0.05497304548043758, 0.03340267539897468, 0.08147353597451001, 0.07665927594644018, 0.043058918381575495, 0.01911393177579157, 0.03606060679885559, 0.0301836933431332, 0.008650631025375333, 0.08444111736025661, 0.10206535094766878, 0.11435159089160152, 0.044132464681752026, 0.06082156251068227, 0.04685442858317401, 0.02358810819714563, 0.03515876749588642, 0.07846110660466366, 0.04801116221642587, 0.031055371764523443, 0.02903983597207116, 0.02421134340693243, 0.05071217157819774, 0.014897345536155626, 0.02261942736367928, 0.05800074082799256, 0.054971483259578235, 0.01819887853343971, 0.0511035617091693, 0.0200933292217087, 0.024538200086681172, 0.028273605603317264, 0.03086816315772012, 0.04708664659119677, 0.05310937536705751, 0.08019074855837971, 0.02428553405479761, 0.01658704139117617, 0.04251271253451705, 0.004506575342020369, 0.06118456178228371, 0.04053369782923255, 0.05330322434019763, 0.01429351934348233, 0.03295922731922474, 0.026731482103059534, 0.0417827026831219, 0.029952588556625415, 0.021914459430263378, 0.05771408628788777, 0.04941982901073061, 0.056757580387056805, 0.038615669109276496, 0.022841605969006196, 0.018458175654814113, 0.012253783042979194, 0.011760544275603024, 0.06379697355441749, 0.019244577597419266, 0.02068013982352568, 0.09526606852887198, 0.07948670274345204, 0.03694371429446619, 0.043165423994651064, 0.1263934193411842, 0.023634856079297606, 0.05574830778641626, 0.3080365271307528, 3.445481266826391, 19.239712804555893, 39.10623997449875, 46.98890179395676, 39.17091630399227, 30.334308072924614, 23.67516729980707, 32.788037806749344, 29.28613431751728, 20.322381108999252, 15.493634417653084, 6.098885061219335, 2.2260884614661336, 0.3820175479631871, 0.1283754879841581, 0.05690082602086477, 0.06937255835509859, 0.09237682083039545, 0.014023342337168287, 0.054016517315176316, 0.1036063909123186, 0.10059335298137739, 0.06698788944049738, 0.4102112929103896, 1.4979874435812235, 0.6005131860729307, 0.6410845590289682, 0.3288020862964913, 1.2177780107595026, 1.7418154911138117, 1.982622581999749, 4.384345812723041, 4.937803214415908, 4.392110696062446, 12.580929212272167, 16.305745840072632, 21.30825150758028, 29.082201160490513, 35.40828600525856, 42.717076018452644, 50.5120575428009, 52.329629212617874, 55.797908306121826, 58.24303910136223, 58.20292845368385, 57.032545655965805, 52.786592692136765, 54.72994141280651, 47.25225426256657, 46.289302334189415, 52.50744067132473, 55.18152818083763, 57.348335310816765, 58.591890782117844, 58.62119480967522, 55.84800481796265, 56.60371966660023, 56.134380251169205, 55.715483129024506, 54.736701250076294, 49.93527889251709, 43.775847405195236, 30.18191535025835, 25.873687528073788, 17.457188554108143, 12.743687778711319, 12.66683405265212, 9.909584205597639, 7.296455875039101, 1.3511083438061178, 0.03908281396434177, 1.2757803546264768, 1.3274649437516928, 0.8599782851524651, 0.44578525121323764, 0.7967835792806, 1.7991104791872203, 1.005787504836917, 0.055635089447605424, 0.03210234732250683, 0.08188482679543085, 0.08121217382722534, 0.09264414242352359, 0.032166754608624615, 0.056274898670380935, 0.049541719345143065, 0.46815856941975653, 2.150635435245931, 7.420229958370328, 21.881042271852493, 38.047073408961296, 38.875751942396164, 20.132776983082294, 30.998903810977936, 46.08076952397823, 38.41998539865017, 17.972790487110615, 3.2853975193575025, 0.052807614410994574, 0.061491280284826644, 0.04594324935169425, 0.031787079278728925, 0.06003597693052143, 0.04741212658700533, 0.03532122362230439, 0.00871069118147716, 0.03187717971741222, 0.03965386320487596, 0.025329884265374858, 0.026705813070293516, 0.03554302929842379, 0.03846830455586314, 0.012715732864307938, 0.04183636738162022, 0.01988408996112412, 0.04188623970549088, 0.042015128492494114, 0.05735790735343471, 0.00532202355316258, 0.04417805481352843, 0.021817568340338767, 0.03282605634012725, 0.0399562215898186, 0.03603428653150331, 0.054109549237182364, 0.03349631959281396, 0.04191239298961591, 0.022730309792677872, 0.027485222126415465, 0.05847394160809927, 0.016687583847669885, 0.03266954481659923, 0.03969606172177009, 0.03514616211759858, 0.02552740872488357, 0.08548118537873961, 0.2196771965827793, 0.13234225247288123, 0.08778872288530692, 0.13365203922148794, 0.18477500067092478, 0.09053892179508694, 0.17276961909374222, 0.16873157874215394, 0.17994635039940476, 0.131451140914578, 0.197514173341915, 0.15960198972607031, 0.15293932927306741, 0.19985018705483526, 0.14608871249947697, 0.19309962663101032, 0.13793755613733083, 0.051793169041047804, 0.12030432772007771, 0.23933556047268212, 0.17905368033098057, 0.13005829299800098, 0.16695426864316687, 0.1234531044610776, 0.08809390885289758, 0.13942047109594569, 0.08870609162840992, 0.11853081741719507, 0.07160014429246075, 0.15081656427355483, 0.11334244074532762, 0.1531392044853419, 0.17815566679928452, 0.2669646794674918, 0.1973969436949119, 0.16652291757054627, 0.21391228248830885, 0.10255120534566231, 0.16358289954951033, 0.4672440653666854, 3.9534520218148828, 22.39830281585455, 45.38544863462448, 53.62977884709835, 46.350330859422684, 43.72551150619984, 32.97591872513294, 39.08216826617718, 32.52663843333721, 25.406200513243675, 16.477842405438423, 7.006404139101505, 2.5867586955428123, 0.5064644920639694, 0.35046478325966746, 0.25500188232399523, 0.10546144098043442, 0.2335273940116167, 0.11465886971564032, 0.2539895928930491, 0.36757986643351614, 0.31928430951666087, 0.27776907314546406, 0.9750094532500952, 3.104013539850712, 1.2589156720787287, 0.8586328604724258, 0.3901237895479426, 3.290231809951365, 1.858183890581131, 1.9881409546360373, 4.031246434897184, 3.2087786681950092, 5.21843240596354, 11.706772819161415, 16.92267693579197, 21.547201685607433, 30.94078592956066, 35.91118901968002, 44.183930307626724, 50.24590842425823, 52.40543894469738, 56.914808973670006, 60.534171760082245, 58.33993010222912, 60.1924978941679, 54.7124395519495, 57.243236750364304, 54.37649957835674, 52.74740159511566, 55.11318124830723, 57.26018764078617, 60.27013532817364, 59.804698303341866, 62.25856103003025, 57.52473704516888, 59.935494884848595, 58.90263430774212, 57.342350631952286, 55.241078585386276, 50.86347408592701, 44.15018051862717, 31.73900529742241, 26.877240277826786, 20.826158076524734, 15.277053639292717, 8.128241691738367, 13.65640640258789, 11.434240993112326, 2.7578411903232336, 2.086711465381086, 3.1948954006657004, 3.399231336079538, 3.209724579937756, 1.2085461686365306, 0.6791113154031336, 2.105354215018451, 1.7345736734569073, 0.6941820785868913, 0.29574973799753934, 0.2165187051286921, 0.32235279330052435, 0.20747009926708415, 0.18464533262886107, 0.20572692796122283, 0.23932546726427972, 0.6491609662771225, 1.6266183787956834, 7.8072719648480415, 23.599218875169754, 36.95839762687683, 43.21489490568638, 28.33610739558935, 37.41949148476124, 52.06946097314358, 44.76426176726818, 22.038255035877228, 4.412138471379876, 0.29160609003156424, 0.153998477908317, 0.18760473554721102, 0.15975812275428325, 0.1456362844328396, 0.1514940708875656, 0.16933681501541287, 0.09872210925095715, 0.16004273638827726, 0.12929959542816505, 0.1899235908058472, 0.08030338431126438, 0.14714866265421733, 0.3720827732468024, 0.08396774588618428, 0.09138825043919496, 0.11880406877025962, 0.13822861161315814, 0.12530606909422204, 0.1852059509838, 0.17711131658870727, 0.16119521751534194, 0.18265846971189603, 0.1290862131281756, 0.1716923323692754, 0.17701703414786607, 0.1587686172570102, 0.20107893127715215, 0.12686207075603306, 0.10318255779566243, 0.163614752527792, 0.19509613746777177, 0.14903171395417303, 0.15188136807410046, 0.16678538551786914, 0.2007720828987658, 0.16994591045659035], [0.09784387395484373, 0.06708991990308277, 0.03159930849506054, 0.09039697120897472, 0.06303446876700036, 0.07867732390877791, 0.013216509996709647, 0.045297848046175204, 0.018302764365216717, 0.05302992845827248, 0.04440552678715903, 0.027778407566074748, 0.05835147981997579, 0.06796227738959715, 0.023571701167384163, 0.014246375340007944, 0.040668531219125725, 0.014171164239087375, 0.008006129573914222, 0.06836124855908565, 0.022301797434920445, 0.018365763426118065, 0.06604732858249918, 0.027868431934621185, 0.024135917083185632, 0.047667696271673776, 0.01563381578307599, 0.04742329219880048, 0.07725700168521143, 0.005482883598233457, 0.024485643043590244, 0.021919815881119575, 0.06520826384075917, 0.01986049708648352, 0.06348841081489809, 0.0428654404822737, 0.04439965639903676, 0.10781591190607287, 0.029444041138049215, 0.01725489451928297, 0.1323770295130089, 0.5742044665385038, 8.513412773609161, 26.04817036539316, 41.90113440155983, 51.148869171738625, 30.60577690601349, 19.850953705608845, 19.678564555943012, 30.00138893723488, 19.701806008815765, 11.176916901022196, 10.27780819684267, 4.641209179535508, 1.3097722618840635, 0.17138527618953958, 0.06857742875581607, 0.05755622034484986, 0.11698528003762476, 0.05369104474084452, 0.07783617373206653, 0.04166928767517675, 0.08357918704859912, 0.05012106950744055, 0.30378716764971614, 0.6996302143670619, 0.731331497663632, 0.7160875468980521, 0.4557600722182542, 1.0576680209487677, 1.3597633293829858, 1.4891288126818836, 2.6809786772355437, 2.726321881636977, 0.30865515174809843, 3.5538269905373454, 7.786987703293562, 11.692924462258816, 18.306779265403748, 24.628112465143204, 29.112848415970802, 37.550808638334274, 42.18844458460808, 48.33828918635845, 49.767552092671394, 55.15621013939381, 54.81630697846413, 47.67788842320442, 53.689507842063904, 46.28691226243973, 39.3241772800684, 47.3542407900095, 54.278632029891014, 53.175684213638306, 54.504932686686516, 57.920728996396065, 55.06909221410751, 56.06966212391853, 54.0313109010458, 52.0205993950367, 49.86067749559879, 43.33169303834438, 33.03829997777939, 22.21631918102503, 18.31455174833536, 12.120619062334299, 5.242238603532314, 7.284273253753781, 7.414845172315836, 1.1259851488284767, 0.6250327953603119, 0.5824842222500592, 0.21798566391225904, 1.1566424975171685, 1.2682150793261826, 0.12023337840219028, 0.08223903161706403, 2.037375862710178, 0.1604971830965951, 0.08448822147329338, 0.06305068469373509, 0.07765621034195647, 0.13653592119226232, 0.020283766170905437, 0.035080574816674925, 0.0262161477439804, 0.46614883351139724, 0.8538748626597226, 2.2590509802103043, 6.11080882139504, 12.523110564798117, 17.600868344306946, 23.806182369589806, 34.62038308382034, 36.893785893917084, 37.15083830058575, 24.89713802933693, 8.388030901551247, 1.2356838374398649, 0.10523524179006927, 0.08111037343041971, 0.016603934527665842, 0.03164953333907761, 0.06036985432729125, 0.09992583567509428, 0.027299542343826033, 0.06559553876286373, 0.016509479537489824, 0.06400248166755773, 0.06394841620931402, 0.0506579354259884, 0.049908830114873126, 0.010803774912346853, 0.03263678641815204, 0.02487317586201243, 0.059361487146816216, 0.031987388647394255, 0.011384883964637993, 0.028380398798617534, 0.19069009576924145, 0.022780041108489968, 0.03868176478135865, 0.016222917765844613, 0.04861968620389234, 0.012930807261000155, 0.02849489734217059, 0.009292673184972955, 0.062267110333777964, 0.04099223377124872, 0.005543611687244265, 0.011740586069208803, 0.051513943399186246, 0.026992547391273547, 0.00515046591317514, 0.043210019648540765, 0.104584445070941, 0.00879404642546433, 0.027183641141164117, 0.08345489215571433, 0.018132281911675818, 0.04618207247403916, 0.06538203029776923, 0.06785168254282326, 0.0628842951846309, 0.003985060284321662, 0.08290801095427014, 0.0935226671572309, 0.031097251157916617, 0.06515790169942193, 0.04762736425618641, 0.06638649749220349, 0.036250986231607385, 0.03585959981137421, 0.028712372586596757, 0.039105282485252246, 0.01269621438041213, 0.04623244945832994, 0.008418898196396185, 0.009942670239979634, 0.0414182116946904, 0.05587817991909105, 0.058126293661189266, 0.04803375690244138, 0.04970138499629684, 0.11210776676307432, 0.022966182878008112, 0.050859524999395944, 0.011884199993801303, 0.015676637704018503, 0.05491418203746434, 0.06313317440799437, 0.07837377066607587, 0.013181260765122715, 0.0042516276698734146, 0.07158969485317357, 0.017409066422260366, 0.048559843125985935, 0.8503925276454538, 10.140698254108429, 30.781188793480396, 46.76413245499134, 55.116950646042824, 36.41671009361744, 24.345901608467102, 20.03795877099037, 32.37173214554787, 26.27842850983143, 16.036760173738003, 12.23253445699811, 4.696486238390207, 1.399132066871971, 0.04084567444806453, 0.03813602277659811, 0.13595572498161346, 0.1342509820824489, 0.06634777222643606, 0.02547516894992441, 0.012158838235336589, 0.17148279439425096, 0.25660794926807284, 0.5778043577447534, 1.3253358704969287, 1.329519683495164, 1.1736391042359173, 1.3142783450894058, 2.4640651792287827, 5.08329170756042, 3.5698267444968224, 5.317704929038882, 4.0337946731597185, 2.461788388900459, 7.752778613939881, 10.058090686798096, 14.270575996488333, 20.047944635152817, 27.26436920464039, 30.93911401927471, 39.059415087103844, 44.323173835873604, 49.24251526594162, 50.17924100160599, 56.04608818888664, 56.035946533083916, 52.38226018846035, 52.900377586483955, 45.72193957865238, 43.01661394536495, 50.79068139195442, 57.22300663590431, 56.51219017803669, 59.84125234186649, 60.13652689754963, 58.00414212048054, 58.12644235789776, 54.88693378865719, 53.54085221886635, 51.821414083242416, 44.471054300665855, 33.26555818319321, 22.67004333436489, 20.22940579801798, 13.921717666089535, 8.916686084121466, 11.36234600096941, 8.574636038392782, 2.276314403861761, 0.4373382747871801, 0.2135781230754219, 1.3779240986332297, 1.6154793952591717, 1.8325656652450562, 0.4403270222246647, 1.4937357092276216, 2.489581285044551, 0.4482975695282221, 0.12259595358045772, 0.03700464832945727, 0.10814898036187515, 0.1121124868222978, 0.03248637534852605, 0.09036949690198526, 0.1278885203646496, 0.15591814677463844, 1.2676432100124657, 3.103301078081131, 5.825449358671904, 17.68384449183941, 25.55551540106535, 29.07608348876238, 36.40265844762325, 41.30202054977417, 41.924541145563126, 30.148423947393894, 9.876344539225101, 1.019728125538677, 0.05786429697764106, 0.06519791830214672, 0.03488357542664744, 0.07149843295337632, 0.024891417851904407, 0.04891145414148923, 0.03457602942944504, 0.0227506650480791, 0.03600901269237511, 0.0330089883209439, 0.05713006430596579, 0.04623777436790988, 0.027505200741870794, 0.02678372558875708, 0.04048257127578836, 0.015339907677116571, 0.04575437276798766, 0.032327381341019645, 0.05922073883994017, 0.021634170661855023, 0.03475824152701534, 0.03060051501961425, 0.0449148775805952, 0.07957785332109779, 0.0338897506298963, 0.02322797732631443, 0.029193332520662807, 0.060523337888298556, 0.0661743397358805, 0.036484347147052176, 0.018056100452668034, 0.03208464338968042, 0.04098313504073303, 0.018359896748734172, 0.05568265369220171, 0.056820477402652614, 0.04687378750531934, 0.15336604934418574, 0.13991385087138042, 0.14225725637516007, 0.09921341101289727, 0.13937570474809036, 0.32673606590833515, 0.20516660646535456, 0.1281068750540726, 0.14400666172150522, 0.22452028904808685, 0.2864490542560816, 0.1074117753887549, 0.10924542191787623, 0.1258026104187593, 0.14489884197246283, 0.14518778974888846, 0.13687156490050256, 0.13404693600023165, 0.13389032799750566, 0.2016443884349428, 0.08555793829145841, 0.10772898414870724, 0.16800047422293574, 0.07195886137196794, 0.12712314346572384, 0.19192777544958517, 0.08573525221436284, 0.15828798757866025, 0.16378584725316614, 0.07915111098554917, 0.11157435554196127, 0.06797161360736936, 0.1062133107916452, 0.19704711012309417, 0.1257262285798788, 0.2191019876045175, 0.134271762217395, 0.21287668962031603, 0.132300914847292, 0.2062471883255057, 0.2164727810304612, 1.1715128808282316, 12.194705586880445, 33.85160453617573, 56.558072715997696, 63.51787805557251, 45.51957003772259, 33.6224502325058, 29.198450222611427, 42.423066794872284, 25.782712809741497, 18.50124903023243, 15.664789583534002, 6.635930193588138, 2.361543830484152, 0.2825069735990837, 0.18044137774268165, 0.4185618495102972, 0.3543874790193513, 0.1859433637582697, 0.27707712433766574, 0.14728147740243003, 0.2695133036468178, 0.18596764683024958, 1.3762020785361528, 2.01793325599283, 1.219989729579538, 1.112281302921474, 0.7325543195474893, 1.8969947705045342, 3.461023145355284, 4.242422478273511, 4.9417041800916195, 5.867079924792051, 1.5643851994536817, 6.444071363657713, 9.798942692577839, 13.85078877210617, 20.252143777906895, 27.999808341264725, 31.505046151578426, 39.52099531888962, 44.64337505400181, 49.84331622719765, 50.48545517027378, 57.12690219283104, 58.10827553272247, 54.17496219277382, 55.326718389987946, 51.63191445171833, 49.28802542388439, 53.84449392557144, 59.536064118146896, 58.98256681859493, 60.26602774858475, 60.59419333934784, 59.67128366231918, 60.93696154654026, 57.6612713187933, 55.280790254473686, 55.84903456270695, 46.47608891129494, 35.02702206373215, 24.789028130471706, 21.00687637925148, 14.288965109735727, 7.16989416629076, 10.635236967355013, 14.229569546878338, 3.128340309485793, 1.2357155419886112, 1.3950307806953788, 0.9670855721924454, 2.4520281376317143, 2.3862600792199373, 0.2736491145333275, 2.659085439518094, 5.891556311398745, 2.5414197659119964, 0.33939167275093496, 0.18503732018871233, 0.3234041196992621, 0.31057841260917485, 0.3271140862489119, 0.18801860162056983, 0.14896150678396225, 0.578120572026819, 1.2634893204085529, 4.467680091038346, 8.13571684062481, 20.956559479236603, 28.57309877872467, 33.219550251960754, 45.795826613903046, 48.12908761203289, 48.187505677342415, 36.15277625620365, 12.303875628858805, 1.5694225416518748, 0.20613432250684127, 0.15868652088101953, 0.16780840640421957, 0.09045118509675376, 0.13469931349391118, 0.17270281095989048, 0.08171281922841445, 0.1387502672150731, 0.09488421128480695, 0.13972810615086928, 0.17973917245399207, 0.22960017115110531, 0.130198692495469, 0.05734592166845687, 0.09967286721803248, 0.21159376861760393, 0.13663084188010544, 0.09733310565934516, 0.1140571957512293, 0.13482175301760435, 0.2776296978117898, 0.163822969479952, 0.0777006872522179, 0.11371482818503864, 0.10208507723291405, 0.07253711315570399, 0.10284244635840878, 0.1572896505240351, 0.17439627321437, 0.1360433132504113, 0.07582257865578867, 0.10566723110969178, 0.0738976479624398, 0.13644497841596603, 0.1416812013485469, 0.11708132136845961, 0.15978454321157187], [0.01744951161526842, 0.06100276528741233, 0.020809854249819182, 0.01612695436051581, 0.03524245948938187, 0.1006627141032368, 0.05341319949366152, 0.025666531728347763, 0.007564549850940239, 0.047706551413284615, 0.10749382723588496, 0.028155600411992054, 0.038576628430746496, 0.01185562174214283, 0.027238274342380464, 0.022355894434440415, 0.03585950704291463, 0.016357509957742877, 0.027913532248931006, 0.07553901145001873, 0.01688917342107743, 0.014383233865373768, 0.02713013229367789, 0.06760174204828218, 0.0578758410847513, 0.0726916134590283, 0.040459501615259796, 0.08306867850478739, 0.032176614040508866, 0.026640823198249564, 0.04130748326133471, 0.03611711763369385, 0.04689696477726102, 0.04339035782322753, 0.023854374085203744, 0.09179056869470514, 0.022295645030681044, 0.09209176932927221, 0.01929675243445672, 0.05821958533488214, 0.08938724218751304, 0.07111861661542207, 2.8306341217830777, 17.681798301637173, 32.21454218029976, 37.969219386577606, 33.818200528621674, 23.796682879328728, 28.273836337029934, 26.624475941061974, 28.946683332324028, 26.162359938025475, 14.236253388226032, 10.00169601291418, 3.7682824954390526, 1.027050451375544, 0.29466047300957143, 0.1067326360498555, 0.022528031877300236, 0.1352649339241907, 0.00931382810449577, 0.1975211495300755, 0.06305180533672683, 0.11013378752977587, 0.3215153538621962, 2.4158395919948816, 1.6509669972583652, 1.8219660152681172, 1.4606581279076636, 1.2287463597021997, 3.63865340128541, 3.4779659612104297, 4.132383232936263, 1.7069915472529829, 0.8187716931570321, 2.876658677123487, 4.031778881326318, 5.5947209894657135, 7.863289508968592, 14.291299134492874, 16.98309939354658, 22.97153625637293, 29.925881288945675, 37.00026378035545, 43.345011323690414, 48.249761536717415, 50.96005730330944, 44.96781684458256, 48.54532107710838, 42.88918778300285, 39.29934561252594, 44.72403332591057, 54.37653757631779, 48.8617604970932, 56.37727461755276, 57.99488961696625, 56.823765859007835, 55.32888427376747, 53.86138781905174, 48.84926676750183, 45.221077054739, 33.99577260017395, 25.889186896383762, 17.077161446213722, 14.028500486165285, 6.809877259656787, 3.324013422243297, 10.598736125975847, 2.9410987067967653, 1.557553878519684, 0.09391998333740048, 0.5960282986052334, 0.6008304690476507, 0.3541290631983429, 1.3719159085303545, 1.5819879923947155, 0.4865643958328292, 0.732059811707586, 1.0226239264011383, 0.07428778757457621, 0.10500587362912484, 0.07528249552706257, 0.09766978837433271, 0.11978109876508825, 0.04441715624125209, 0.08311203477205709, 0.9683002007659525, 2.927149892784655, 8.402313385158777, 14.171583708375692, 19.860071316361427, 22.586801201105118, 27.19305083155632, 27.349112257361412, 41.54384717345238, 40.617597475647926, 19.93762895464897, 5.224546752870083, 0.4842502606334165, 0.0790657194738742, 0.1260362088214606, 0.02993510541273281, 0.07522931322455406, 0.02080550340906484, 0.06295724830124527, 0.04233064886648208, 0.03315750691399444, 0.016334980209649075, 0.023823137089493684, 0.030233860670705326, 0.05700231842638459, 0.045950819257996045, 0.012248237344465451, 0.030245141315390356, 0.01281671597098466, 0.032824419904500246, 0.03482685307972133, 0.027276303844701033, 0.02696273531910265, 0.06559763161931187, 0.01267154817469418, 0.044424121297197416, 0.021054785247542895, 0.030630412438767962, 0.02697541862289654, 0.05203729109780397, 0.016489133558934554, 0.021873786026844755, 0.09235820034518838, 0.021530911944864783, 0.040929637325461954, 0.024815149190544616, 0.028806471345887985, 0.018497416713216808, 0.07707221433520317, 0.04471982261748053, 0.027837838752020616, 0.04055779907503165, 0.012776631647284376, 0.08958781501860358, 0.002965026078527444, 0.030609302048105747, 0.021926942354184575, 0.021798079542350024, 0.029742085789621342, 0.006643725018875557, 0.03845919840387069, 0.08088046350167133, 0.02672240192623576, 0.0600630282133352, 0.04943278319842648, 0.02586530114058405, 0.010049806678580353, 0.022258292738115415, 0.010300074645783752, 0.05964015617792029, 0.04171143053099513, 0.0048347558276873315, 0.07036486917058937, 0.029188909320509993, 0.03094486783083994, 0.06585871175047942, 0.005548046019612229, 0.03511723691190127, 0.037660565867554396, 0.013008096375415334, 0.09735965228173882, 0.027560184607864358, 0.0633392391318921, 0.05325282509147655, 0.060444510672823526, 0.04287954870960675, 0.029901280177000444, 0.11294838259345852, 0.10030016754171811, 0.037352118160924874, 0.03326437246869318, 0.02806696757033933, 3.5888048261404037, 20.131773836910725, 37.95320704579353, 44.773293882608414, 38.02959814667702, 28.660777173936367, 28.534240163862705, 30.465811416506767, 29.29077386856079, 25.11439137160778, 19.63813092559576, 13.580827508121729, 5.155805591493845, 0.9886883036233485, 0.08086133835604414, 0.12087988550774753, 0.05724245886085555, 0.08346788716153242, 0.09162769696558826, 0.17813156184274703, 0.2967755642021075, 0.5463628261350095, 0.7803121162578464, 0.25583308772183955, 1.6182924318127334, 2.379107913002372, 2.6135781314224005, 4.186452906578779, 7.351011922582984, 6.279428573325276, 6.928793778643012, 3.787873056717217, 4.284796379506588, 6.8719350546598434, 9.020232427865267, 9.501074776053429, 10.8307184278965, 17.897394932806492, 20.821879506111145, 27.018431201577187, 31.89684122800827, 39.071395844221115, 43.111544251441956, 51.530216708779335, 52.06358648836613, 50.04705749452114, 50.38852617144585, 44.310448318719864, 40.24806350469589, 48.57746735215187, 57.52188339829445, 51.701085940003395, 59.06974174082279, 61.22680239379406, 58.770735785365105, 57.36862622201443, 53.77143144607544, 52.349988520145416, 45.476898327469826, 37.68565960228443, 27.4409419298172, 19.96058352291584, 15.564001891762018, 11.033789981156588, 6.981196291744709, 11.716924924403429, 5.124750807881355, 0.9625434502959251, 0.386697857757099, 1.3237765291705728, 1.5625084564089775, 2.995412042364478, 1.576483512762934, 2.3547262838110328, 5.191672816872597, 4.086913922801614, 1.2200245214626193, 0.05996224455884658, 0.08830171762383543, 0.2184463298181072, 0.0976281390467193, 0.03838240838376805, 0.10923216716037132, 0.12004144417005591, 1.2444568541832268, 3.861770066432655, 10.180468820035458, 16.740286722779274, 19.512895345687866, 22.04366024583578, 31.00066501647234, 34.06311258673668, 47.137663811445236, 44.63034175336361, 23.113230653107166, 5.889108767732978, 0.3694816050119698, 0.01839612468756968, 0.049201693254872225, 0.09552874427754432, 0.02083900024445029, 0.015651096691726707, 0.05974035353574436, 0.014926402473065536, 0.0024695796537343995, 0.028927036946697626, 0.011418891026551137, 0.046830342180328444, 0.04362854640930891, 0.03555831754056271, 0.014485150222753873, 0.019592455610109027, 0.038019331186660565, 0.03209392394637689, 0.02642797895532567, 0.035322771000210196, 0.09624127284041606, 0.05016338676796295, 0.0404538353177486, 0.0243868112374912, 0.011776324190577725, 0.029272510400915053, 0.012342180252744583, 0.05437477426312398, 0.023874297039583325, 0.061843600051361136, 0.0359621386451181, 0.01803745955839986, 0.011153871018905193, 0.03145015907648485, 0.07553971649031155, 0.07604148995596915, 0.15381512290332466, 0.013301968301675515, 0.10260340059176087, 0.18812952301232144, 0.18573945126263425, 0.2461404461064376, 0.11512764729559422, 0.17424126825062558, 0.12320036606979556, 0.12234616893692873, 0.07228726171888411, 0.19561829773010686, 0.18636180146131665, 0.1846528283203952, 0.09026944055221975, 0.2069182976265438, 0.20030225889058784, 0.12480249220971018, 0.11218245650525205, 0.12226307808305137, 0.10282502073096111, 0.19616641831817105, 0.16397217084886506, 0.12393608674756251, 0.13811598328175023, 0.1167418852855917, 0.16214881790801883, 0.16358196444343776, 0.12472609552787617, 0.10183589372900315, 0.08686597357154824, 0.0773564717383124, 0.14451907016336918, 0.09478654465056024, 0.145916118635796, 0.19760939088882878, 0.22939176124054939, 0.2309167114435695, 0.15940968442009762, 0.21208979043876752, 0.16600209317402914, 0.16473962576128542, 0.12214264235808514, 0.2362524563795887, 3.9939766097813845, 22.161864303052425, 44.11944776773453, 53.184302151203156, 45.11610008776188, 36.53563991189003, 41.11593693494797, 40.554619655013084, 38.57811011373997, 34.44205105304718, 20.299059860408306, 13.229008186608553, 5.47363668680191, 1.2873925315216184, 0.5210780922789127, 0.38294864643830806, 0.16292756830807775, 0.29114129778463393, 0.25455792958382517, 0.31310616759583354, 0.3729233890771866, 0.7305096730124205, 0.6476592749822885, 5.92651586048305, 7.057856228202581, 2.571835471317172, 4.437876865267754, 7.026783870533109, 10.436460133641958, 7.467601066455245, 8.411166910082102, 6.329310871660709, 2.7217678260058165, 6.559128239750862, 8.165259305387735, 8.463893830776215, 8.991477470844984, 15.950943678617477, 19.80592042207718, 25.605478920042515, 31.89136952161789, 40.0389189273119, 45.878730565309525, 51.97136163711548, 53.9224923402071, 52.55987785756588, 53.18212866783142, 50.748784840106964, 45.022541508078575, 51.7134390771389, 60.63829377293587, 55.85020869970322, 60.00390641391277, 62.51829229295254, 62.286151349544525, 60.15692040324211, 56.8144753575325, 53.675300404429436, 48.132522627711296, 38.638675063848495, 28.401961661875248, 21.72541782259941, 16.32220845669508, 7.998562250286341, 5.220184111967683, 15.251860991120338, 7.250350099056959, 3.4628570219501853, 0.50896066124551, 0.9698366839438677, 1.8473835638724267, 4.706753762438893, 3.3075641049072146, 1.4300544513389468, 9.585949871689081, 8.329471293836832, 3.918986921198666, 0.3666804131353274, 0.15337442076997831, 0.6600082560908049, 0.27236421941779554, 0.2721878851298243, 0.19254123471910134, 0.2261955983703956, 1.6368692787364125, 3.97912273183465, 13.133920188993216, 21.97091694921255, 29.65906910598278, 33.07179898023605, 38.28570440411568, 39.063180685043335, 50.615108013153076, 48.97841423749924, 27.418525032699108, 7.306578056886792, 0.5907384480815381, 0.18785935157211497, 0.23609518044395372, 0.15710003179265186, 0.1923776208423078, 0.0772952965053264, 0.11054730479372665, 0.11589133951929398, 0.18651904771104455, 0.10816429086844437, 0.09415917753358372, 0.13003773550735787, 0.171910286298953, 0.133793136337772, 0.0805754036991857, 0.15597659832565114, 0.05979023699183017, 0.20364158204756677, 0.16832038440043107, 0.05707011361664627, 0.1202363618358504, 0.11694767541484907, 0.21969511202769354, 0.2354009309783578, 0.11986430836259387, 0.20505969267105684, 0.10546443925704807, 0.12645135138882324, 0.13179966830648482, 0.09062874392839149, 0.13214012113166973, 0.07497975864680484, 0.1144202915020287, 0.08360027146409266, 0.14592089806683362, 0.12861198076279834, 0.25998222758062184, 0.06294501028605737], [0.025282050992245786, 0.05321861579432152, 0.036550594959408045, 0.028326999417913612, 0.05849278844834771, 0.05516633784282021, 0.01943269347975729, 0.03214487609511707, 0.024175866892619524, 0.03422617359319702, 0.03435254649957642, 0.03239705416490324, 0.08467416657367721, 0.05053101333032828, 0.02787389970762888, 0.035102104520774446, 0.027377651531423908, 0.02432115714327665, 0.031472163755097426, 0.0471239320904715, 0.04521148803178221, 0.0737554524675943, 0.016711835378373507, 0.04766663128975779, 0.04681343605625443, 0.03304612167994492, 0.06542095594340935, 0.04793461710505653, 0.012401739459164673, 0.033871649648062885, 0.06277392298216, 0.07811507282895036, 0.030766257004870567, 0.03596315538743511, 0.03758527869649697, 0.07990051686647348, 0.050987341383006424, 0.035436516263871454, 0.036910302806063555, 0.06858922148239799, 0.07061843134579249, 0.02427649469609605, 0.39208890753798187, 7.35662279650569, 23.243915140628815, 39.62668664753437, 37.434033304452896, 33.43845650553703, 17.22049355506897, 20.566139928996563, 24.5700553804636, 27.642139233648777, 17.996731102466583, 9.562082402408123, 10.072102434933186, 3.745331489481032, 1.0663862968795002, 0.04582066510920413, 0.04996662486519199, 0.10228459621430375, 0.14888953330228105, 0.18281090684467927, 1.0881581786088645, 1.2479318864643574, 0.39076257089618593, 0.26663982658647, 2.2688950644806027, 3.746867082081735, 1.6381343733519316, 4.282267140224576, 11.69323604553938, 5.128690246492624, 5.69557280279696, 1.693530057091266, 3.754017110913992, 4.633248606696725, 3.554538027383387, 3.481415226124227, 3.4801437193527818, 5.080496957525611, 8.56541583314538, 13.071519937366247, 18.711672239005566, 25.919074192643166, 31.04585599154234, 36.94232068955898, 43.84931646287441, 39.4516908377409, 42.548171281814575, 36.719675436615944, 33.2405099272728, 37.600973546504974, 49.830700904130936, 45.10904386639595, 54.732149094343185, 53.62283281981945, 53.08729335665703, 49.42971982061863, 47.58883640170097, 41.87923617660999, 34.36347886919975, 27.021142356097698, 19.41700369119644, 10.891772601753473, 9.802087023854256, 6.623468287289143, 6.549707120284438, 5.558422012254596, 1.88839559443295, 0.21319045481504872, 0.09066009966772981, 0.602568875765428, 0.2803004201268777, 2.618608111515641, 1.3258685544133186, 4.576084949076176, 4.0235798712819815, 2.335945791564882, 0.6427283864468336, 0.009750038389029214, 0.022894368958077393, 0.21497518639080226, 0.07684159936616197, 0.0482686614850536, 0.12922695401357487, 0.7426760857924819, 2.4978769524022937, 5.9686527494341135, 6.314248004928231, 12.639460321515799, 21.921758987009525, 31.55574683099985, 30.808507427573204, 31.48492243140936, 34.459222331643105, 24.31934293359518, 8.922550119459629, 1.7695155297406018, 0.04259797788108699, 0.04837226901145186, 0.02248580552986823, 0.03497893769235816, 0.045546734691015445, 0.03398818909772672, 0.012522533270384884, 0.03012251625477802, 0.03991455741925165, 0.01622300682356581, 0.029248446262499783, 0.11495716113131493, 0.05431212957773823, 0.0283562381810043, 0.054443805129267275, 0.0062067823273537215, 0.07995015170308761, 0.03905810044670943, 0.016814084774523508, 0.010674642144294921, 0.011163154358655447, 0.04105558720766567, 0.03280576602264773, 0.022246724511205684, 0.04946552675392013, 0.08312324862345122, 0.03499865284538828, 0.06553918748977594, 0.020871057313343044, 0.05642445998091716, 0.035117570878355764, 0.010116147259395802, 0.017224522125616204, 0.051968130355817266, 0.04922827327391133, 0.0473104152479209, 0.015278107184713008, 0.03258862103393767, 0.056265465973410755, 0.015792026824783534, 0.04040774052555207, 0.01553432346554473, 0.03327340069517959, 0.03986003925092518, 0.05417709951871075, 0.08937130085541867, 0.05005909646570217, 0.008718256449355977, 0.05773354168923106, 0.03836565068922937, 0.03360416478244588, 0.10650446274667047, 0.029177541473472957, 0.009120373397308867, 0.021315043450158555, 0.05876993978745304, 0.033810600580181926, 0.0446589665079955, 0.06359746199450456, 0.07366617952357046, 0.017359500234306324, 0.05174535246624146, 0.07057149792672135, 0.005243237155809766, 0.06792449465137906, 0.03067969661060488, 0.0291502211621264, 0.015653024420316797, 0.05296805931720883, 0.06245847311220132, 0.011744157654902665, 0.047719483336550184, 0.02413937920209719, 0.04885371134150773, 0.015374863760371227, 0.04960764061252121, 0.03843594320642296, 0.05961988812487107, 0.043582440484897234, 0.08091863957815804, 0.5478721763938665, 8.75972505658865, 27.406758964061737, 43.42827245593071, 44.49780486524105, 39.16950657963753, 24.640323109924793, 25.002774260938168, 25.176575034856796, 34.82019156217575, 21.665154956281185, 10.170474406331778, 9.704223275184631, 3.737426963634789, 0.8722826186567545, 0.11614794449997135, 0.0874361211026553, 0.054488226378452964, 0.07143196620745584, 0.0746031483868137, 0.3439301432808861, 0.40203407232183963, 1.3907881896011531, 0.6776836607605219, 1.8453409359790385, 3.018013942055404, 3.6728434916585684, 4.529044423252344, 8.464794382452965, 9.92646099999547, 11.329515762627125, 4.058609241619706, 5.236157979816198, 5.5896093137562275, 5.811968157067895, 5.891319299116731, 5.581147642806172, 8.06505773216486, 12.759938556700945, 16.47463157773018, 19.368687383830547, 26.354669518768787, 33.60565893352032, 38.41640219092369, 44.81705993413925, 44.603241607546806, 44.60948087275028, 38.494294211268425, 35.449768379330635, 43.61973658204079, 54.05248336493969, 49.277112409472466, 56.2406225502491, 56.151479333639145, 55.05914814770222, 50.61313971877098, 48.36853936314583, 44.64457578957081, 36.13915778696537, 29.417251981794834, 20.685527622699738, 14.917612876743078, 11.117772124707699, 9.221578873693943, 5.786787383258343, 7.96520859003067, 5.128223346546292, 0.597823642892763, 0.6204640748910606, 3.0700222263112664, 5.11128100566566, 5.122479479759932, 2.1508465614169836, 5.208713002502918, 3.7757070595398545, 0.29344073846004903, 0.9174683096352965, 0.31860776769462973, 0.489687115768902, 0.2797289070440456, 0.06744317477568984, 0.013555338446167298, 0.0866680131002795, 0.5481206474360079, 2.8948440263047814, 7.1713437885046005, 12.931456603109837, 20.68282786756754, 29.106120876967907, 36.28099277615547, 35.15565276145935, 38.21102701127529, 39.669240564107895, 30.146185867488384, 10.4427345469594, 1.8705270532518625, 0.06677222874714062, 0.048055746738100424, 0.03296371360193007, 0.028317993455857504, 0.0444767766748555, 0.06358068203553557, 0.03560109864338301, 0.0334670084703248, 0.03996421452029608, 0.06135628362244461, 0.05057129339547828, 0.03293977933935821, 0.017671732894086745, 0.05338944334653206, 0.04720085940789431, 0.054730181363993324, 0.06133831622719299, 0.0739930807321798, 0.042509940612944774, 0.01890716201160103, 0.05471562784805428, 0.06713823371683247, 0.04901927706669085, 0.033591410974622704, 0.04368553592939861, 0.11070639156969264, 0.051420002346276306, 0.019023508502868935, 0.04231547565723304, 0.06579797438462265, 0.038588632669416256, 0.05155046448635403, 0.010712196672102436, 0.05377247689466458, 0.005592835559582454, 0.020280205717426725, 0.06083493972255383, 0.02904190285335062, 0.14786467188969254, 0.09278010387788527, 0.10748205677373335, 0.11100358460680582, 0.1354530535172671, 0.1444795136922039, 0.12909504468552768, 0.1543302327627316, 0.09857681157882325, 0.13169702928280458, 0.1202069282589946, 0.13356117065995932, 0.14855841669486836, 0.2206656482303515, 0.14002676121890545, 0.09742383321281523, 0.12948056071763858, 0.22387987497495487, 0.12669991148868576, 0.1908709274721332, 0.12547450693091378, 0.21059799939393997, 0.166391423845198, 0.20384740928420797, 0.1653017580974847, 0.18954126600874588, 0.2112214034423232, 0.10169686720473692, 0.08949396302341484, 0.10528129947488196, 0.19049430236918852, 0.11806919414084405, 0.15541584638413042, 0.1129814526939299, 0.09697709741885774, 0.1407214708160609, 0.17624383501242846, 0.10717980971094221, 0.08519097595126368, 0.152996608230751, 0.14182026498019695, 0.24353043147129938, 0.8397815376520157, 10.689828637987375, 30.801221318542957, 51.42747402191162, 49.97757442295551, 48.01517732441425, 29.967084378004074, 34.54212248325348, 36.60923056304455, 42.223007529973984, 27.252755127847195, 13.710416704416275, 13.284400664269924, 4.505126131698489, 1.2140255933627486, 0.19265629729488865, 0.25512632564641535, 0.18582554039312527, 0.6215724279172719, 0.8707206649705768, 2.1571934083476663, 3.63979808986187, 3.294905796647072, 1.2208984745666385, 7.763493089005351, 9.095120709389448, 8.774103485047817, 10.664939973503351, 19.19163778424263, 11.737434323877096, 11.781844440847635, 5.71191905066371, 9.377169124782085, 8.25814912095666, 6.760724047198892, 5.769087458029389, 5.687213251367211, 6.84194041416049, 11.908835526555777, 15.983958207070827, 21.74754973500967, 27.874620258808136, 33.5221242159605, 38.930180221796036, 47.6728954911232, 46.523723155260086, 47.02069848775864, 42.64095850288868, 38.738602101802826, 46.05128310620785, 56.78874313831329, 51.14277429878712, 58.43399405479431, 57.18525566160679, 56.76292732357979, 52.153812646865845, 50.79093597829342, 45.7304435223341, 37.719895765185356, 29.830776192247868, 21.798696890473366, 14.236999098211527, 13.35871897637844, 8.638825044035912, 9.783496521413326, 11.546854600310326, 5.83065127953887, 0.9217587544117123, 0.529775113100186, 1.2727772095240653, 8.453847169876099, 11.895239856094122, 10.425925198942423, 13.425337951630354, 10.132166761904955, 8.920198045670986, 1.8623731657862663, 0.2891687583178282, 1.1479256465099752, 1.437917179428041, 0.5563526088371873, 0.22695722000207752, 0.4509541019797325, 1.646965336985886, 3.433337830938399, 8.334749210625887, 11.577778290957212, 23.10909267514944, 33.25983189046383, 42.881762981414795, 40.604716166853905, 42.96256944537163, 47.200561836361885, 35.05707085132599, 13.012861534953117, 2.6751215290278196, 0.20925304968841374, 0.12956981139723212, 0.05908593884669244, 0.11059936645324342, 0.11896397933014669, 0.13732730294577777, 0.055642399602220394, 0.17689371888991445, 0.23701640835497528, 0.16055633226642385, 0.1373101890203543, 0.3475852502742782, 0.1303811717662029, 0.12670041614910588, 0.16021809104131535, 0.11815208461484872, 0.16197574906982481, 0.1382827735505998, 0.10095904624904506, 0.11761396817746572, 0.08655698780785315, 0.15395243506645784, 0.14371324621606618, 0.11287902889307588, 0.17350560694467276, 0.1478474837495014, 0.21605205751257017, 0.14293353102402762, 0.10003306859289296, 0.10810476320330054, 0.2967175282537937, 0.19512848026352003, 0.11468783573945984, 0.170041291275993, 0.07263080187840387, 0.08860366040607914, 0.14811956993071362, 0.1769353830604814], [0.012649018426600378, 0.037093041828484274, 0.014908164193911944, 0.07508897309890017, 0.037654457992175594, 0.023365667984762695, 0.015776168984302785, 0.0769791861239355, 0.034005870766122825, 0.11593738978262991, 0.09233051081537269, 0.050756210621329956, 0.05202015861868858, 0.10099961946252733, 0.08397764613619074, 0.1038843252172228, 0.06087589143135119, 0.0636456125357654, 0.047041531433933415, 0.03655659522337373, 0.0837089960987214, 0.03560332508641295, 0.016414287965744734, 0.05071668383607175, 0.018479198843124323, 0.09113882202655077, 0.0039055948218447156, 0.04965330495906528, 0.036985400729463436, 0.011095391637354624, 0.03708147916768212, 0.06926548870978877, 0.023409875866491348, 0.0454665827419376, 0.0509231196338078, 0.1377957168733701, 0.022170617266965564, 0.10040290304459631, 0.04163407276791986, 0.07687048375373706, 0.012103126136935316, 0.034482652408769354, 0.14221728430129588, 1.7392853018827736, 11.005653440952301, 29.23953741788864, 38.80596108734608, 40.097340792417526, 24.385223798453808, 18.033423833549023, 23.293147198855877, 29.38590556383133, 26.101177521049976, 26.20023250579834, 18.02409913390875, 8.568297028541565, 3.621679712086916, 1.022857257630676, 0.22951023769564927, 0.09481542161665857, 0.10170583977014758, 0.014001653999002883, 0.07472905374015681, 0.20578260387992486, 0.9948968142271042, 0.5679103417787701, 0.945648547494784, 1.2903345236554742, 3.276729709468782, 1.8653557682409883, 2.1659939736127853, 9.465774670243263, 13.3429916203022, 3.218845990486443, 7.852264875546098, 5.549439769238234, 5.698980744928122, 4.073856873437762, 2.114031524397433, 3.8151425309479237, 3.1204274715855718, 7.779400460422039, 10.476784519851208, 15.058211032301188, 21.652366742491722, 24.691023789346218, 33.12555089592934, 34.14350867271423, 34.39157836139202, 30.027007162570953, 25.027085356414318, 34.270049482584, 47.934598848223686, 41.34636037051678, 44.55097921192646, 45.418115481734276, 44.84767109155655, 39.8477815836668, 37.396506518125534, 33.2466010004282, 26.29463654011488, 19.371601827442646, 13.62758969888091, 10.817206352949142, 4.380374075844884, 6.75304988399148, 3.6247960198670626, 4.786871038377285, 3.564728843048215, 0.3304096672218293, 1.209633385296911, 7.888993229717016, 3.5314483288675547, 1.4981312421150506, 1.4956343010999262, 3.521379344165325, 3.083001379854977, 0.6985913263633847, 0.8443991211242974, 0.6888519146014005, 0.09658378141466528, 0.0726039064466022, 0.05222668347414583, 0.14655427657999098, 0.31183831219095737, 2.7493277471512556, 6.518821902573109, 9.388919044286013, 17.000829242169857, 19.63868949562311, 18.646612130105495, 23.80625456571579, 33.64111103117466, 31.527915224432945, 29.54883322119713, 13.300005476921797, 2.9180890414863825, 0.18816878262441605, 0.07823933061445132, 0.07991771242814139, 0.03958251683798153, 0.0686146029329393, 0.04009574906376656, 0.022420227505790535, 0.046435222757281736, 0.013199950826674467, 0.05315535141562577, 0.06006658310070634, 0.044313767648418434, 0.023490547318942845, 0.03516320182825439, 0.006532036431963206, 0.04355932629550807, 0.032569473623880185, 0.03970851124904584, 0.09526584588456899, 0.06670956921880133, 0.024054766945482697, 0.04311575576139148, 0.07037819814286195, 0.02136192862963071, 0.09445005489396863, 0.041351544568897225, 0.0412060762027977, 0.02533617396693444, 0.07699876397964545, 0.018758077530947048, 0.01516246758910711, 0.01618072852579644, 0.0522612378699705, 0.013292263793118764, 0.055858947162050754, 0.05292282541631721, 0.05222066094574984, 0.05811827846628148, 0.017992123612202704, 0.09119173715589568, 0.032948529260465875, 0.04405398256494664, 0.09482460198341869, 0.06717188269249164, 0.031449335292563774, 0.03358395981194917, 0.06730157299898565, 0.0749973401252646, 0.012662038479902549, 0.014232157645892585, 0.026654792272893246, 0.054663417759002186, 0.039972675003809854, 0.042294576778658666, 0.05511272880539764, 0.015968717343639582, 0.07115449203411117, 0.06741909208358265, 0.08785964993876405, 0.051261464759591036, 0.03167044334986713, 0.021795728789584246, 0.017850579351943452, 0.018710483600443695, 0.014785579023737228, 0.03270049979619216, 0.01147396766100428, 0.023182708173408173, 0.04178096234682016, 0.10155174022656865, 0.0625013692479115, 0.034920638281619176, 0.02730829412030289, 0.07515189237892628, 0.006930410636414308, 0.01912263160193106, 0.05422796260972973, 0.03632288549852092, 0.0863899674732238, 0.009500439282419393, 0.02182527183322236, 0.08987100372905843, 1.9334140350110829, 15.103818085044622, 33.890510648489, 45.3843504935503, 44.15380172431469, 28.825925812125206, 20.931395329535007, 27.979646623134613, 37.729953825473785, 31.51785336434841, 29.806144014000893, 23.201452419161797, 10.445425752550364, 4.505732199177146, 1.0790836717933416, 0.24914966197684407, 0.01449017270715558, 0.08303462134790607, 0.05343518561858218, 0.2951077208854258, 0.43616054579615593, 0.346359281684272, 0.9215860418044031, 1.4452127879485488, 2.2880381997674704, 2.699669636785984, 4.78362743742764, 5.577468490228057, 6.859948122873902, 7.983772493898869, 7.040128754451871, 6.609362969174981, 5.696964478120208, 7.191434260457754, 2.6693311147391796, 4.298237208276987, 4.435256905853748, 7.8648127522319555, 9.758760798722506, 14.32481523603201, 17.304706536233425, 22.670552507042885, 27.72844210267067, 34.4009068608284, 39.677653312683105, 35.98786510527134, 33.8905144482851, 27.778857797384262, 40.18991142511368, 51.96077540516853, 43.90944063663483, 48.736454620957375, 48.453533202409744, 45.78373186290264, 42.07431010901928, 40.0149954110384, 34.851418286561966, 28.006305992603302, 20.701627358794212, 16.084225326776505, 11.284061651676893, 6.946982927620411, 5.946523686870933, 3.574053542688489, 6.735109621658921, 7.035259315744042, 1.5219035977497697, 2.462060786783695, 7.416680948808789, 4.6333953738212585, 1.2950353464111686, 2.203877465799451, 3.2742192316800356, 2.739910427480936, 0.5750939750578254, 0.662900316528976, 0.3802863846067339, 0.16530849679838866, 0.02954612540634116, 0.037168599883443676, 0.049033997565857135, 0.6067122565582395, 2.713445322588086, 6.94624244235456, 10.871152058243752, 17.992101050913334, 23.06742411106825, 22.124611102044582, 26.87914777547121, 37.61428043246269, 38.64650644361973, 36.1055675894022, 16.79653510451317, 3.511426728218794, 0.15382803627289832, 0.028476106162997894, 0.0611483115790179, 0.010842034480447182, 0.02727358016272774, 0.039642575138714164, 0.05331232307071332, 0.024760612468526233, 0.0218408439468476, 0.06022582201694604, 0.0396641679253662, 0.03783317828492727, 0.069643716851715, 0.04208231141092256, 0.025601664310670458, 0.012849004961026367, 0.007863034225010779, 0.06921290754689835, 0.02627618749102112, 0.024309767031809315, 0.007354948793363292, 0.07620696662343107, 0.026858419041673187, 0.051795696053886786, 0.03938681991712656, 0.07843652667361312, 0.04756503869430162, 0.04124668281292543, 0.10930494958302006, 0.051343824598006904, 0.07570707079139538, 0.041822062485152856, 0.06466749051469378, 0.028953381333849393, 0.050154777854913846, 0.11641827179118991, 0.04674893229093868, 0.05267933047434781, 0.03362547555298079, 0.20061477727722377, 0.1286701057688333, 0.10717742741690017, 0.17843861802248284, 0.1505602413089946, 0.121302278857911, 0.137549368373584, 0.28330614790320396, 0.17075249139452353, 0.17523479618830606, 0.2210399429895915, 0.08227559723309241, 0.18099191773217171, 0.3261410415871069, 0.1341911352938041, 0.1275886333314702, 0.10286969802109525, 0.125962023739703, 0.1678864803398028, 0.1576608876348473, 0.22101114765973762, 0.20477225887589157, 0.20910859806463122, 0.08067609087447636, 0.12473175069317222, 0.2320174648775719, 0.09407205681782216, 0.16866714548086748, 0.11571667506359518, 0.14720644627232105, 0.17515750892926008, 0.08108646885375492, 0.22756373276934028, 0.1709473496885039, 0.1805090467678383, 0.22584759048186243, 0.1167012972291559, 0.18190052913269028, 0.14541369950165972, 0.1798138621961698, 0.0719368270074483, 0.16059924324508756, 0.25944045977666974, 2.371132615953684, 16.963192261755466, 39.74954925477505, 51.77687667310238, 52.8941535204649, 38.930643796920776, 27.152203023433685, 36.97430357336998, 41.440059542655945, 37.03343980014324, 33.02342377603054, 24.2081817984581, 11.730464547872543, 5.50957515835762, 1.5240073786117136, 0.7892723323311657, 0.218267546442803, 0.18920995644293725, 0.3221371251856908, 0.7181980961468071, 0.6882210297044367, 3.9593094075098634, 2.3858865117654204, 3.3156244223937392, 6.930555934086442, 7.9756200313568115, 9.95182178914547, 10.889692213386297, 19.765902869403362, 25.364721938967705, 10.000469628721476, 16.197349056601524, 11.528604179620743, 9.602621477097273, 7.329571098089218, 4.547263020649552, 5.454064412042499, 7.584097590297461, 11.60427426919341, 13.76399477943778, 16.13512359559536, 24.16988555341959, 27.46494334191084, 37.875808998942375, 40.03741040825844, 40.90041249990463, 36.613927111029625, 34.238583371043205, 41.85319237411022, 57.85842753946781, 47.49328292906284, 48.979527577757835, 48.51923547685146, 48.7000335752964, 43.112991973757744, 41.3326583057642, 36.21587947010994, 28.402326442301273, 20.63864953815937, 16.88811019062996, 12.648464888334274, 8.922931049019098, 11.006735432893038, 5.859770067036152, 9.787425510585308, 10.387466512620449, 0.685733410064131, 2.818478336557746, 16.80118415504694, 12.296982798725367, 11.97236716747284, 4.961931444704533, 11.068154387176037, 12.787095699459314, 4.305781703442335, 3.9008326828479767, 1.5316541120409966, 0.7457017921842635, 0.21892841410590336, 0.15392070083180442, 0.5030667025130242, 0.6874442682601511, 3.47587488591671, 9.424439538270235, 15.3088322840631, 25.535366982221603, 30.780178047716618, 30.793965607881546, 32.777500972151756, 44.63660381734371, 44.29111875593662, 41.12992778420448, 20.083710215985775, 4.516114667057991, 0.4060318734264001, 0.1466512307524681, 0.21214693580986932, 0.1407093441230245, 0.1446208037668839, 0.1908515574177727, 0.14411532698431984, 0.1412620660266839, 0.14221830846508965, 0.15722733980510384, 0.21045618981588632, 0.08974599637440406, 0.18002025346504524, 0.12093197685317136, 0.17354504467220977, 0.23947205627337098, 0.09366609461721964, 0.1656388267292641, 0.26408143574371934, 0.09484599810093641, 0.16296118759782985, 0.23537522298283875, 0.13005305343540385, 0.1144873297016602, 0.20547977794194594, 0.19584445981308818, 0.1356766329263337, 0.07181967157521285, 0.18949669261928648, 0.10685864530387335, 0.24533143092412502, 0.12732911913190037, 0.2208185158087872, 0.10325051625841297, 0.1771832158556208, 0.2159922700957395, 0.11878792705829255, 0.14550140651408583, 0.166676482767798], [0.03577371477149427, 0.03718704967468511, 0.07623376557603478, 0.05140213885169942, 0.029285809687280562, 0.01858167273894651, 0.10006505515775643, 0.0265074258641107, 0.017628152127144858, 0.06684786843834445, 0.07273109571542591, 0.057846411218633875, 0.024651676321809646, 0.0669959862716496, 0.10261243252898566, 0.022444024471042212, 0.023080612772901077, 0.022183907276485115, 0.03535062380251475, 0.01965223560546292, 0.021878296429349575, 0.016612120416539256, 0.010922400724666659, 0.05862057885678951, 0.04670724585594144, 0.04272700025467202, 0.034782502334564924, 0.01308631595748011, 0.047605244544683956, 0.12532667111372575, 0.00378111068130238, 0.04361236387921963, 0.030437448476732243, 0.013140970495442161, 0.06917291320860386, 0.047669748309999704, 0.03910370171070099, 0.1306143990950659, 0.0643482779560145, 0.04205351237033028, 0.03123096947092563, 0.025832453684415668, 0.03097657423495548, 0.20279550401028246, 5.059618502855301, 19.86847646534443, 31.662217117846012, 46.46375097334385, 36.15300044417381, 24.778614789247513, 12.010330930352211, 20.7864673063159, 18.200538866221905, 14.620521068572998, 14.916584081947803, 12.659241110086441, 9.979726541787386, 4.089637426659465, 1.29518021363765, 0.2722660778090358, 0.055079090961953625, 0.1090146139904391, 0.0194729271606775, 0.17319155973382294, 0.14921682042768225, 0.1887426557368599, 1.8944997293874621, 1.7763044591993093, 1.977553297765553, 2.836136226542294, 3.8367303600534797, 7.637597769498825, 6.611349787563086, 3.498857240192592, 3.356366786174476, 2.652920032851398, 4.8621127009391785, 1.702696590218693, 1.6806758218444884, 2.144169844686985, 3.7713363440707326, 2.94218426104635, 4.995697857812047, 9.362994935363531, 13.474289774894714, 18.214715905487537, 21.010334193706512, 20.305016040802002, 25.006028786301613, 19.775843136012554, 18.639289923012257, 27.260753698647022, 40.99259935319424, 33.165802136063576, 38.55476416647434, 37.918556705117226, 35.970085859298706, 31.258963756263256, 26.259560622274876, 22.962494641542435, 19.221621975302696, 12.866743225604296, 7.883007125928998, 5.158099243417382, 1.8061277526430786, 3.463251725770533, 1.6789478645659983, 4.467806434258819, 5.913065057247877, 3.418133184313774, 2.4067730410024524, 5.2531687170267105, 3.766719354316592, 1.1701690591871738, 1.9263822748325765, 0.5647372745443135, 0.543635938083753, 0.3546995669603348, 0.25675050099380314, 0.30706089979503304, 0.08359417101019062, 0.10274468324496411, 0.10482352052349597, 0.7069914287421852, 2.186411703005433, 5.0534438341856, 9.566226080060005, 15.301891956478357, 21.607692539691925, 26.333476155996323, 31.918454468250275, 40.93443967401981, 35.191355645656586, 34.27932098507881, 17.553739473223686, 6.342025939375162, 0.7294464425649494, 0.027702663974196184, 0.04018087711301632, 0.06464795718784444, 0.02928467049059691, 0.059333278113626875, 0.0789626945334021, 0.0649095197150018, 0.10369678449933417, 0.035844560188706964, 0.052921018286724575, 0.0156179004261503, 0.015104139420145657, 0.02520196583645884, 0.05650027407682501, 0.007900213968241587, 0.05109771358547732, 0.04383041799883358, 0.07493916316889226, 0.045575448384624906, 0.0471201694017509, 0.02246790307253832, 0.0934719858923927, 0.05491377756698057, 0.011735633161151782, 0.038224308664212, 0.0620711239753291, 0.035672311423695646, 0.0038992680129013024, 0.03148304364003707, 0.04170824300672393, 0.013545063411584124, 0.0059869507640542, 0.06573419421329163, 0.06860084351501428, 0.046784132355242036, 0.03468188566330355, 0.04913071796181612, 0.012718302550638327, 0.01633291889447719, 0.010787725968839368, 0.04222524534270633, 0.03025665759196272, 0.038211057617445476, 0.03447118622716516, 0.05973040133540053, 0.02670073306944687, 0.02089365942083532, 0.041710254226927646, 0.006420669287763303, 0.1080194310634397, 0.06916525424458086, 0.01795910175133031, 0.034416898124618456, 0.033480830970802344, 0.01620064962480683, 0.010751676145446254, 0.0157811450844747, 0.032363965510739945, 0.04115190313314088, 0.08821776587865315, 0.14626185555243865, 0.0904892869584728, 0.029748915403615683, 0.08856028187437914, 0.009915708942571655, 0.037628282443620265, 0.02956636562885251, 0.07666235585929826, 0.03131632758595515, 0.024226340356108267, 0.10903318994678557, 0.007523018803112791, 0.014687127568322467, 0.05374641637899913, 0.025973283627536148, 0.03976998334110249, 0.13160341477487236, 0.021233529660094064, 0.04222299292450771, 0.04072697905940004, 0.0693473921273835, 0.023589711236127187, 0.38679371355101466, 6.38803007081151, 22.844037897884846, 38.125827983021736, 52.23972983658314, 42.15538635849953, 29.91826269775629, 20.575419031083584, 27.473525181412697, 26.601411178708076, 25.802080370485783, 21.875811852514744, 15.038644932210445, 9.692807737737894, 4.1820313688367605, 1.1344944359734654, 0.3023848053999245, 0.025811382256506477, 0.048036788575700484, 0.029579125002783258, 0.06383633706718683, 0.35414913087151945, 0.47698404116090387, 0.40699126257095486, 0.8809114212635905, 3.327795169316232, 3.5149698005989194, 3.6995057109743357, 5.223702723160386, 7.522395551204681, 7.905154237523675, 7.892061565071344, 6.314540589228272, 5.069220587611198, 3.9305986231192946, 3.643428795039654, 4.408854972571135, 5.3667612466961145, 5.018419688567519, 7.401536861434579, 11.99880139902234, 16.812192164361477, 19.607082791626453, 23.958968371152878, 26.68158307671547, 28.169410340487957, 23.521520644426346, 21.84847991913557, 32.55148530006409, 45.40581934154034, 37.79466435313225, 41.85837149620056, 39.10106845200062, 39.00717929005623, 32.73480646312237, 29.49485331773758, 26.290458664298058, 21.951993964612484, 14.952593799680471, 11.37206207960844, 6.378892036154866, 3.29438213724643, 4.63126321323216, 3.260420272126794, 5.610240306705236, 8.899983130395412, 5.47288385219872, 3.3010241808369756, 4.754761336371303, 3.5908165806904435, 2.5144756492227316, 1.3048254023306072, 1.68078649090603, 0.6582431914284825, 0.44777376169804484, 0.766222650418058, 0.39912788139190525, 0.044432084541767836, 0.1257460142369382, 0.10516303082113154, 0.876757234800607, 2.302320683375001, 5.180639158934355, 12.109243422746658, 20.63895732164383, 29.243107326328754, 30.728156939148903, 34.44782294332981, 41.56672194600105, 39.88361746072769, 38.714986369013786, 22.39257652312517, 7.830443121492863, 0.5922321835532784, 0.011209509830223396, 0.050888869518530555, 0.033753529423847795, 0.016401584252889734, 0.03710515367856715, 0.04207313475490082, 0.0037532254100369755, 0.07109391794074327, 0.06413022012566216, 0.0521758092509117, 0.03941121802199632, 0.02311669599293964, 0.04777443937200587, 0.010874534982576733, 0.07307506632059813, 0.046802136857877485, 0.01549187911223271, 0.03173276149027515, 0.02581957927759504, 0.030892123395460658, 0.04680133533838671, 0.019310736352053937, 0.02760839823167771, 0.037638932262780145, 0.017259456872125156, 0.10636673498083837, 0.03190483956132084, 0.023201831463666167, 0.025274679610447492, 0.012948965759278508, 0.013077682924631517, 0.057303953217342496, 0.06000535962812137, 0.013397004950093105, 0.039037435344653204, 0.035308722144691274, 0.06265928343054838, 0.031045198775245808, 0.054583555247518234, 0.1455858035478741, 0.1547138488967903, 0.1782530514174141, 0.1317286299308762, 0.10370114090619609, 0.14749488938832656, 0.16635939275147393, 0.09101937335799448, 0.11762016511056572, 0.16580684896325693, 0.15745556505862623, 0.14039704838069156, 0.13068779750028625, 0.16081587615190074, 0.19536166306352243, 0.10113673866726458, 0.057088552275672555, 0.07906355982413515, 0.14013150794198737, 0.07418300374411047, 0.19600792526034638, 0.2292940649203956, 0.1770988930366002, 0.11347514417138882, 0.1965729965013452, 0.11488316158647649, 0.17812507547205314, 0.09532067575491965, 0.17203248833538964, 0.19965369603596628, 0.16682179528288543, 0.16024442244088277, 0.198949828336481, 0.12854459375375882, 0.10985036875354126, 0.11426031414885074, 0.16179025667952374, 0.2669438102748245, 0.1314944971818477, 0.17578128405148163, 0.12619965942576528, 0.10810496358317323, 0.15867323643760756, 0.6298211915418506, 7.5044092163443565, 27.051118947565556, 42.52653904259205, 61.00194185972214, 47.70263269543648, 38.53780187666416, 23.31149261444807, 36.432099267840385, 29.26383711397648, 23.715861216187477, 23.889249712228775, 17.764831446111202, 13.510320391505957, 5.582675160840154, 1.9343255111016333, 0.5057048297021538, 0.11993396634352393, 0.2242685525561683, 0.19065184547798708, 0.796537067508325, 0.7950039091520011, 2.515103565528989, 5.401250096037984, 5.146379247307777, 8.869416620582342, 10.83259742707014, 13.925943989306688, 19.102963842451572, 18.293951153755188, 11.800188906490803, 8.322252631187439, 8.842466566711664, 11.03314496576786, 5.49765519797802, 4.3207581248134375, 4.924315363168716, 7.728242380544543, 3.6586355790495872, 10.029986444860697, 12.005609683692455, 15.4995222017169, 19.961799457669258, 25.846929363906384, 25.746713541448116, 32.68708102405071, 25.95005013048649, 28.571960739791393, 35.56146718561649, 46.97788618505001, 40.6272641569376, 42.558685317635536, 39.20254960656166, 38.95936265587807, 33.94345700740814, 30.944982804358006, 25.659287832677364, 22.254260145127773, 16.05784524232149, 11.551376357674599, 6.856437111273408, 2.860558941029012, 5.764643121510744, 4.7818429581820965, 9.068684577941895, 14.226621855050325, 9.76887110620737, 9.322674348950386, 14.646366331726313, 10.289749056100845, 5.18623910844326, 4.8388019017875195, 7.127764401957393, 5.198550447821617, 1.476792418397963, 1.522994376718998, 1.1926691955886781, 0.7131831371225417, 0.34626799752004445, 0.3143449901835993, 1.4730001031421125, 3.2488515553995967, 7.445800211280584, 15.171502903103828, 23.3126762509346, 33.77612538635731, 36.836488768458366, 42.08070136606693, 50.09448654949665, 45.160508304834366, 43.63186173141003, 25.785933136940002, 9.594097584486008, 1.0904908971861005, 0.10408961810753681, 0.10700697093852796, 0.13066977815469727, 0.17164719494758174, 0.22572678368305787, 0.1557659322861582, 0.16012131498428062, 0.2595007815398276, 0.12832088075811043, 0.3207527525955811, 0.10639480300596915, 0.19630381953902543, 0.10844134201761335, 0.24815288343233988, 0.22234974458115175, 0.11865148320794106, 0.1527599076507613, 0.14834326808340847, 0.11718203822965734, 0.13954620575532317, 0.17919302597874776, 0.13433965388685465, 0.2417612701538019, 0.21366747765569016, 0.07020576013019308, 0.12896071595605463, 0.0908674111997243, 0.08355077021406032, 0.0915703883219976, 0.12480482255341485, 0.06270135578233749, 0.17674946022452787, 0.11098001399659552, 0.1067824118945282, 0.12177257041912526, 0.12181896207039244, 0.16402092995122075, 0.10128796609933488, 0.14909133809851483], [0.11698238566168584, 0.009429678284504917, 0.024041610522544943, 0.030262490872701164, 0.017635484546190128, 0.10123837579158135, 0.03965402647736482, 0.08108694382826798, 0.03372217368450947, 0.024485724679834675, 0.058290430752094835, 0.024322953140654135, 0.026086989928444382, 0.022553910566784907, 0.05519720376469195, 0.032906939304666594, 0.005597103372565471, 0.047139661910478026, 0.05344036952010356, 0.012715987977571785, 0.11151772225275636, 0.023886676062829792, 0.06415579453459941, 0.056906592508312315, 0.01086937891159323, 0.08974108335678466, 0.006866857747809263, 0.029614740669785533, 0.013505178540071938, 0.021783594675071072, 0.07216384256025776, 0.04018698127765674, 0.010328476637369022, 0.0026244756145388237, 0.04260668698407244, 0.013345289316930575, 0.022271053967415355, 0.06467373197665438, 0.02791471968521364, 0.1122646864678245, 0.04060201252286788, 0.042062444117618725, 0.02069740032311529, 0.01307329590417794, 0.6866713659837842, 7.440247759222984, 20.66737599670887, 35.30967749655247, 45.43667368590832, 30.846248902380466, 22.832881696522236, 18.124757632613182, 10.797729548066854, 21.32858231663704, 25.622859187424183, 22.995691560208797, 16.401377208530903, 11.194902285933495, 5.387560855597258, 1.919410836417228, 0.4644858289975673, 0.07774874131428078, 0.0714039130252786, 0.19175074354279786, 0.31035662919748574, 0.38904087734408677, 0.5750754510518163, 0.25497786642517895, 1.4122135774232447, 1.445209225639701, 2.6671151211485267, 2.0399053394794464, 4.329419760033488, 8.264201246201992, 7.0512298587709665, 4.3031935673207045, 5.155004784464836, 2.76898053009063, 3.94916205201298, 2.0250070514157414, 2.262045219540596, 3.152285674586892, 2.712797694839537, 4.993647867813706, 7.86618685349822, 12.550205010920763, 13.703686315566301, 12.380546014755964, 15.503546185791492, 13.25744491070509, 13.086610827594995, 22.965916357934475, 32.42189325392246, 25.564427822828293, 31.00121408700943, 27.476756907999516, 25.949316769838333, 23.39440416544676, 17.970622703433037, 14.707253314554691, 10.073407664895058, 7.327436087653041, 5.313191721215844, 1.9647631840780377, 1.3222696725279093, 1.5150558901950717, 1.7734803794883192, 4.463180657476187, 8.060714565217495, 4.570245137438178, 2.556128539144993, 4.737170180305839, 1.866834838874638, 1.2419692939147353, 1.5556206135079265, 1.2166778510436416, 0.553956184303388, 0.3995122842025012, 0.1644707753439434, 0.2622737124329433, 0.15438702190294862, 0.09974092215998098, 0.4172347707208246, 2.387876892462373, 5.041955150663853, 8.94748818129301, 14.00628687813878, 18.12997855246067, 17.862622998654842, 22.48147275298834, 27.356242574751377, 35.286874920129776, 38.2184936106205, 17.515186741948128, 7.089850986376405, 1.6771727660670877, 0.05884182421141304, 0.1159671573259402, 0.015053701208671555, 0.03368436126038432, 0.015596029334119521, 0.019013786368304864, 0.05961008806480095, 0.011788950905611273, 0.04328876151703298, 0.034719924442470074, 0.008315748018503655, 0.015338479970523622, 0.02577591316367034, 0.040151755238184705, 0.02269288328534458, 0.06457370531279594, 0.04412557384057436, 0.08822629315545782, 0.0362609644071199, 0.06566280702827498, 0.07474139565601945, 0.09063660327228718, 0.05699896762962453, 0.03156470585963689, 0.07199961270089261, 0.05579744538408704, 0.015875041608524043, 0.02941065191407688, 0.0326526424032636, 0.008332027955475496, 0.011561897317733383, 0.02222582192189293, 0.09287474254961126, 0.06284654213231988, 0.03656060653156601, 0.00901326757229981, 0.023315085054491647, 0.05935305263847113, 0.04253625345882028, 0.04505540324316826, 0.08346024304046296, 0.06310360724455677, 0.033035275191650726, 0.04934491662424989, 0.03837652315269224, 0.03528794943122193, 0.0061998780347494176, 0.06349888251861557, 0.04527815886831377, 0.032507136929780245, 0.03880696138367057, 0.034085866864188574, 0.03327758640807588, 0.042916700622299686, 0.013110637992213015, 0.06720815144944936, 0.0062738024371356005, 0.08955640732892789, 0.0921045416907873, 0.008609796204837039, 0.047228333714883775, 0.08572320715757087, 0.04428267166076694, 0.021928035166638438, 0.0348620049044257, 0.10164994862861931, 0.08929521587560885, 0.0684626036672853, 0.028915147740917746, 0.05634089044178836, 0.050526694030850194, 0.05541174381505698, 0.039335563487838954, 0.01363637169561116, 0.06906851529492997, 0.024028394727793057, 0.055584838628419675, 0.02330640192667488, 0.08656532212626189, 0.09093163665966131, 0.025847942306427285, 0.05142906025866978, 0.057475125868222676, 0.05102937662741169, 0.9674165106844157, 9.23302385956049, 24.3375401571393, 41.67395979166031, 50.531250312924385, 35.85074946284294, 25.962847843766212, 24.422017224133015, 15.788470096886158, 21.866031177341938, 26.4668869972229, 24.803645946085453, 19.214571453630924, 11.750817205756903, 4.991746544837952, 1.8551812204532325, 0.20872429915471002, 0.028712953317153733, 0.015481835071113892, 0.17034245480317622, 0.4469122173031792, 0.2630293375113979, 0.40492824045941234, 0.7986770651768893, 1.6893575247377157, 2.155151255428791, 2.4349976889789104, 3.610706850886345, 4.869155623018742, 5.107464585453272, 8.00868870690465, 7.088380940258503, 5.085801472887397, 3.9409020077437162, 4.6332101337611675, 4.32226711884141, 3.104463340714574, 4.394095139577985, 3.848434444516897, 6.441119872033596, 10.951597541570663, 15.445642992854118, 16.740784496068954, 16.25684056431055, 21.070321574807167, 15.268470849841833, 16.487163305282593, 26.885704323649406, 37.03761197626591, 29.38611075282097, 35.64724758267403, 30.187022276222706, 29.151703231036663, 25.624027624726295, 19.70006190240383, 17.395278476178646, 12.921758573502302, 8.834752980619669, 6.372321238741279, 2.9223317513242364, 3.315677857026458, 4.032209683209658, 3.6350616440176964, 5.212559346109629, 7.680963892489672, 5.65349243581295, 5.0419974233955145, 5.043180109933019, 3.398304423317313, 1.590457025449723, 1.4888501213863492, 0.7664106809534132, 0.6461610272526741, 0.3149589541135356, 0.0760297491797246, 0.23933502612635493, 0.09489483141805977, 0.06345491026877426, 0.6374805117957294, 2.390575222671032, 6.389113012701273, 13.062669262290001, 20.370165444910526, 25.14849454164505, 20.272748172283173, 27.99803003668785, 31.05420984327793, 40.454077050089836, 43.5442840307951, 23.048392832279205, 9.18285135179758, 1.8596267444081604, 0.013922795242251595, 0.028653210429183673, 0.1036860010935925, 0.06577688996912912, 0.03144150563457515, 0.011232594333705492, 0.026212164266326, 0.01619170117919566, 0.05614256631815806, 0.04669941248721443, 0.04430597880855203, 0.02880542306229472, 0.0322961183701409, 0.033347207281622104, 0.026707358592830133, 0.05041583201091271, 0.029747089720331132, 0.07651009684195742, 0.08090953342616558, 0.0483225970674539, 0.04136271389143076, 0.02887455040763598, 0.02440006413962692, 0.03735200683877338, 0.03348669764818624, 0.0317662583256606, 0.03408099466469139, 0.010384635879745474, 0.026186411741946358, 0.04751203079649713, 0.010580685320746852, 0.05973490246105939, 0.08543101619579829, 0.008019111592147965, 0.018543748992669862, 0.022665685428364668, 0.01242688435013406, 0.10507357976166531, 0.041639549817773513, 0.019717449977179058, 0.2622543869074434, 0.15286425361409783, 0.09589267123374157, 0.15997926791897044, 0.20544844446703792, 0.2106066676788032, 0.13129468134138733, 0.23006583913229406, 0.15745142387459055, 0.18667979689780623, 0.1203504744626116, 0.1393143439781852, 0.0892759051930625, 0.11100095740403049, 0.0792314633144997, 0.2351579666719772, 0.08081591891823336, 0.16888630168978125, 0.20659757108660415, 0.07823796506272629, 0.16106510418467224, 0.1934440722106956, 0.25656297511886805, 0.20117600419325754, 0.09992200619308278, 0.2144875211524777, 0.2514797978801653, 0.12288454512599856, 0.10948000737698749, 0.18161644984502345, 0.1379087459645234, 0.1346027007093653, 0.15092974179424345, 0.13137486297637224, 0.1832338864915073, 0.10989907590555958, 0.24817176366923377, 0.15505314397159964, 0.18418471125187352, 0.3287430707132444, 0.14186532818712294, 0.12283966003451496, 0.13155171676771715, 0.10977363068377599, 1.6123399324715137, 10.826175771653652, 29.0237070992589, 47.89386123418808, 59.38028767704964, 42.93629005551338, 36.38445362448692, 30.171382315456867, 19.4264442846179, 30.012081563472748, 34.934253841638565, 33.14191281795502, 23.63982729613781, 15.00015014782548, 7.019407516345382, 2.8697164496406913, 0.7838765031192452, 0.1777353440411389, 0.8880236896220595, 0.6344587239436805, 0.6985445413738489, 1.9458514801226556, 2.270259903743863, 2.537060212343931, 4.831887222826481, 6.345516052097082, 8.8111543469131, 9.407141916453838, 10.8638621494174, 15.875150095671415, 16.29496581852436, 12.018723729997873, 13.436830434948206, 6.0703120194375515, 7.593471212312579, 6.254768371582031, 4.554328741505742, 7.239500256255269, 5.213223360478878, 7.494570594280958, 11.638298593461514, 15.735366996377707, 17.508039325475693, 17.181659638881683, 24.225953444838524, 20.99063605070114, 21.887498125433922, 30.46003382652998, 39.62106674909592, 32.5224282592535, 36.202625781297684, 29.42934673279524, 30.078830681741238, 26.22944913804531, 20.02621740102768, 16.80829167366028, 12.730713374912739, 9.331294186413288, 6.583791766315699, 4.375570183619857, 3.2711193105205894, 3.802211587317288, 5.435690972954035, 10.751517377793789, 15.449508335441351, 12.38681947812438, 9.237035494297743, 11.487651877105236, 8.291308041661978, 4.526586905121803, 3.9126170380041003, 4.966510199010372, 2.959309467114508, 1.475534567143768, 0.61565768904984, 0.7810397772118449, 0.581324037630111, 0.3830580390058458, 0.6131201377138495, 3.1115461606532335, 6.916570784524083, 13.62621322274208, 21.782462261617184, 29.091413766145706, 27.863319665193558, 35.2638291567564, 37.771930173039436, 46.33965343236923, 51.14073000848293, 27.01002225279808, 11.43706139177084, 2.521385340951383, 0.11196589039172977, 0.21813084284076467, 0.1132302577025257, 0.10279744252329692, 0.13044087012531236, 0.05351900377718266, 0.16127743263496086, 0.13497448700945824, 0.18870410858653486, 0.15981891949195415, 0.16931824648054317, 0.08905012902687304, 0.13992262305691838, 0.12082855857443064, 0.09417216511792503, 0.16803305450594053, 0.0867052392277401, 0.24942894699051976, 0.19581146392738447, 0.15674397902330384, 0.17687103885691613, 0.3607251530047506, 0.11920137752895243, 0.13717575639020652, 0.10665530426194891, 0.12478062853915617, 0.17734687426127493, 0.08240926545113325, 0.18205357482656837, 0.10831487263203599, 0.11337634205119684, 0.14794339891523123, 0.16915721527766436, 0.08307967713335529, 0.0991008420533035, 0.0979529919277411, 0.1044656420708634, 0.25002352602314204, 0.12764806451741606, 0.12822150718420744], [0.05904132092837244, 0.011732098682841752, 0.06776352282031439, 0.06494366592960432, 0.08070302341366187, 0.054284198849927634, 0.037570239073829725, 0.04676348209613934, 0.026250065748172347, 0.01841331468313001, 0.05266750064038206, 0.08063452318310738, 0.05468893650686368, 0.022030028521839995, 0.04773355074576102, 0.05802200706966687, 0.025041864173545036, 0.023152680878411047, 0.02868138049961999, 0.08159224249538966, 0.036642239065258764, 0.01944895393535262, 0.08598296626587398, 0.03566398081602529, 0.056781837483868, 0.03026681388291763, 0.05392039063735865, 0.015255797297868412, 0.07798590202583, 0.021798036868858617, 0.10579860609141178, 0.03707381649292074, 0.04119980505493004, 0.0419872014754219, 0.027835462024086155, 0.047934149552020244, 0.10526685728109442, 0.08184659876860678, 0.057994206217699684, 0.018035787870758213, 0.14067121257539839, 0.044474175447248854, 0.06564367446117103, 0.05867246611160226, 0.09759382213815115, 1.476938829291612, 8.246513195335865, 21.620399057865143, 36.58247619867325, 36.594616547226906, 32.36315980553627, 20.652277506887913, 23.512625321745872, 21.60559505224228, 28.038480766117573, 24.54313762485981, 27.28099901229143, 18.27569503337145, 10.659279227256775, 7.5858773197978735, 3.130388637073338, 1.053866681177169, 0.3116795519599691, 0.09443977614864707, 0.0024217074178523035, 0.14112806384218857, 0.2916750800795853, 0.346359726972878, 1.8297301861457527, 1.0581108159385622, 0.8569488383363932, 1.5126528753899038, 3.733556396327913, 2.9757687589153647, 8.49370228126645, 6.239372072741389, 3.043873691931367, 2.842552657239139, 2.7054534014314413, 3.117649583145976, 1.9085751241073012, 1.9649439118802547, 1.0749878478236496, 2.358815101906657, 5.837360769510269, 6.439789943397045, 9.906533919274807, 8.36551520973444, 9.536914452910423, 7.202477417886257, 9.456979092210531, 19.848588332533836, 25.5987361818552, 19.344342090189457, 25.71824736893177, 22.55509190261364, 18.076515421271324, 15.112456921488047, 12.516489420086145, 6.736478973180056, 5.978182163089514, 2.250225003808737, 1.9591620471328497, 0.908770338864997, 1.6793606174178421, 4.634035639464855, 2.7760267769917846, 2.9921888653188944, 6.160282166674733, 4.305930370464921, 1.632151713129133, 2.411922477185726, 2.043589004315436, 1.0671760607510805, 0.7714975986164063, 0.17898332473123446, 0.09986422999645583, 0.14755993121070787, 0.1522826324799098, 0.051239063031971455, 0.08806083875242621, 0.8486818475648761, 2.1958663081750274, 4.267837414517999, 8.291648123413324, 8.458880949765444, 11.57835965976119, 19.366086423397064, 24.545913375914097, 28.243572860956192, 35.33968448638916, 37.80074402689934, 25.338197462260723, 10.82818491384387, 2.568665728904307, 0.19142025033943355, 0.06744881509803236, 0.030746816446480807, 0.015811983175808564, 0.005826867190990015, 0.014650051725766389, 0.02112257672706619, 0.02083882955048466, 0.02215275748312706, 0.03979396955401171, 0.08455301096546464, 0.08894115206203423, 0.03257619377109222, 0.014402551041712286, 0.05889131061849184, 0.030852307172608562, 0.031190756199066527, 0.036763973548659123, 0.023754061694489792, 0.07714096689596772, 0.05243606188741978, 0.03380534988536965, 0.1056010092725046, 0.057606831105658785, 0.05444128924864344, 0.015420089312101481, 0.044177954623592086, 0.04112529713893309, 0.05885126432985999, 0.048424371489090845, 0.06109457266575191, 0.02728882016526768, 0.05082190553366672, 0.02915299679443706, 0.040396096228505485, 0.05287437801598571, 0.005197019445404294, 0.02213045965618221, 0.034270008545718156, 0.08326771509018727, 0.010754889644886134, 0.12990830495255068, 0.033702406581141986, 0.07483682100428268, 0.01744978620990878, 0.03246762869821396, 0.048995116449077614, 0.04556327345198952, 0.0340694171609357, 0.024419155888608657, 0.0350865342625184, 0.08903370529878885, 0.05596405753749423, 0.03510570393700618, 0.025230527389794588, 0.04823057446628809, 0.03327766804432031, 0.020035315537825227, 0.03770221890590619, 0.052838910778518766, 0.12312291553826071, 0.11030660403775983, 0.0498880091618048, 0.03681335234432481, 0.03769356546399649, 0.0730883507640101, 0.01638175963307731, 0.037423037792905234, 0.020602780205081217, 0.0771145464386791, 0.021218259971647058, 0.011297794790152693, 0.03336162721097935, 0.053442050484591164, 0.06334836012683809, 0.06117559292761143, 0.019542570298654027, 0.03985988339991309, 0.05218288933974691, 0.07758241859846748, 0.027105890039820224, 0.053105835322639905, 0.06951198563911021, 0.044827014717157, 0.020415161561686546, 0.10967583788442425, 2.083776122890413, 10.868523549288511, 28.199060149490833, 43.54121759533882, 40.429670959711075, 38.13587844371796, 23.986697383224964, 22.829820960760117, 22.46113434433937, 28.989299945533276, 33.18470612168312, 30.64577355980873, 23.511652573943138, 11.590286269783974, 7.577984668314457, 3.153347955085337, 0.40185732243116945, 0.11401777286664583, 0.11721410643076524, 0.08333030782523565, 0.21023302600951865, 0.27811583422590047, 0.39843652630224824, 1.3351049087941647, 2.0283088367432356, 2.438749987632036, 2.4635462695732713, 4.2787019815295935, 5.1466020103544, 5.656364606693387, 5.108522353693843, 5.912320297211409, 5.237987106665969, 7.108547408133745, 5.663376180455089, 2.7680369932204485, 3.677450269460678, 2.0332438219338655, 3.3704376686364412, 5.177248315885663, 9.537989795207977, 11.830478981137276, 10.334048978984356, 12.471335493028164, 8.962234240025282, 12.872807700186968, 23.37807074189186, 29.448235519230366, 22.83947814255953, 27.83778503537178, 25.148302651941776, 20.73360074311495, 18.024473413825035, 12.3875005915761, 10.460965018719435, 7.535620266571641, 4.455807628110051, 5.304261725395918, 3.0149349197745323, 4.014861714094877, 3.7429908150807023, 3.301258818246424, 6.638786690309644, 5.889347679913044, 4.365646066144109, 4.921508263796568, 2.927976348437369, 0.9165729233063757, 1.2916899821721017, 0.6545770412776619, 0.3650260472204536, 0.2875276026315987, 0.20332250307546929, 0.039366344062727876, 0.11159197412780486, 0.0853786057268735, 1.0042390879243612, 2.7073870226740837, 5.878695901483297, 11.049737725406885, 13.176213819533587, 16.18426825851202, 22.73469876497984, 27.48415131121874, 29.05735619366169, 39.282311126589775, 41.49428263306618, 30.63939180225134, 13.9518946968019, 3.49475322291255, 0.33580790099222213, 0.06645218498306349, 0.024266518375952728, 0.041369768005097285, 0.013869480280845892, 0.04964928622939624, 0.02969653462059796, 0.057229853482567705, 0.04420880941324867, 0.019285364178358577, 0.014438838352361927, 0.07648413651622832, 0.02973441940412158, 0.06274630024563521, 0.0289911807703902, 0.03451852411672007, 0.04361008919659071, 0.04105336447537411, 0.04561761721561197, 0.06820067748776637, 0.021857957872271072, 0.02223146966571221, 0.05107359007524792, 0.06710904504870996, 0.08273692365037277, 0.05000325727451127, 0.03275310322351288, 0.0606480186979752, 0.12422576182871126, 0.0399584999831859, 0.01804300340154441, 0.015695874171797186, 0.06199864583322778, 0.07996261978405528, 0.026266428249073215, 0.012051245375914732, 0.022566849911527243, 0.0223031128916773, 0.004867943280260079, 0.0331129632104421, 0.05074263674032409, 0.1884953276021406, 0.07819482401828282, 0.17233210819540545, 0.26634347217623144, 0.13341768382815644, 0.14136877201963216, 0.19869570212904364, 0.0950809768983163, 0.09864018356893212, 0.1662130412296392, 0.19464170560240746, 0.19233438331866637, 0.16844022640725598, 0.144148753315676, 0.18116537248715758, 0.19583073008107021, 0.09906164923449978, 0.11954913308727555, 0.12907511059893295, 0.21643361047608778, 0.176702422904782, 0.14694874291308224, 0.13768872886430472, 0.14053296530619264, 0.13722723175305873, 0.12319662564550526, 0.09489494274021126, 0.1580107954214327, 0.17242026049643755, 0.1309401573962532, 0.19550414057448506, 0.11834461998660117, 0.08590861791162752, 0.13543378736358136, 0.23058151302393526, 0.11584391628275625, 0.18800577730871737, 0.14979045605286956, 0.216608356568031, 0.12677485356107354, 0.27573594474233687, 0.1446356764063239, 0.20336626010248438, 0.11949251464102417, 0.14279807423008606, 2.36447608564049, 13.5325463488698, 32.545078843832016, 48.70914168655872, 50.17586678266525, 44.950390979647636, 32.881216406822205, 36.51604436337948, 34.53549183905125, 39.48699094355106, 38.851760029792786, 37.53234542906284, 26.455897986888885, 14.613233059644699, 9.237007945775986, 4.189644735306501, 1.4473777217790484, 0.5854539410211146, 0.516257279086858, 0.3151652414817363, 0.6268789025489241, 1.758531981613487, 1.712443067226559, 5.395299140363932, 6.740900985896587, 5.084914695471525, 8.278133198618889, 12.078732959926128, 13.837765920907259, 18.819820135831833, 15.820627771317959, 6.450640261173248, 11.28011366352439, 10.15877578407526, 7.0026162173599005, 5.986466193571687, 5.385603960603476, 2.4329118384048343, 3.519749944098294, 7.6045875158160925, 9.954569041728973, 13.539271038025618, 11.38917351141572, 15.832551531493664, 13.97231575101614, 16.824786588549614, 25.4941600933671, 30.427830554544926, 25.306136682629585, 29.102621264755726, 25.061281621456146, 21.516451835632324, 17.650923058390617, 14.237796105444431, 9.13241570815444, 8.315676134079695, 4.17775422334671, 5.226585818454623, 2.03707757871598, 4.601036785170436, 8.472904097288847, 8.93154613673687, 10.361371412873268, 13.903459645807743, 11.970362775027752, 9.424650426954031, 8.64652058109641, 9.689707104116678, 4.818501966074109, 4.957299018278718, 1.5271349670365453, 1.1183591955341399, 0.6125692266505212, 0.8286725368816406, 0.3970244567608461, 0.41874349757563323, 1.4718608767725527, 3.627075422555208, 6.567751402035356, 13.25568750500679, 15.123424082994461, 18.880166597664356, 31.105936467647552, 32.202249839901924, 37.77408465743065, 45.66273495554924, 48.58592949807644, 34.958333149552345, 17.208252511918545, 3.9989733416587114, 0.5270652647595853, 0.1807429123437032, 0.1518456856138073, 0.1051944014034234, 0.13166807068046182, 0.13607010478153825, 0.1904214679962024, 0.16073756472906098, 0.08902784233214334, 0.17657484771916643, 0.17342889856081456, 0.27848497848026454, 0.10780617492855527, 0.10873826788156293, 0.1412777995574288, 0.10900558947469108, 0.11526445479830727, 0.14115420228336006, 0.1311467564664781, 0.13022741361055523, 0.11576969409361482, 0.09092407417483628, 0.17775762331439182, 0.1530337453004904, 0.16554279281990603, 0.16377729771193117, 0.10974644581438042, 0.16082745365565643, 0.17651578760705888, 0.15121874894248322, 0.14861290517728776, 0.05692369530152064, 0.2809093671385199, 0.1557644925196655, 0.07546029926743358, 0.1656153006479144, 0.07657839669263922, 0.12134039556258358, 0.14803955156821758, 0.12027195523842238, 0.17714633111609146], [0.043019740405725315, 0.04686376480094623, 0.05307778214046266, 0.008722365164430812, 0.05999605309625622, 0.0698396067309659, 0.06583056951058097, 0.030863135107210837, 0.06113294170063455, 0.06911503311130218, 0.03934216860216111, 0.028358709532767534, 0.02826260511938017, 0.05986266318359412, 0.019929463014705107, 0.07903181074652821, 0.061210985950310715, 0.030618584460171405, 0.03466325033514295, 0.06913663703016937, 0.012700866718660109, 0.06113405492214952, 0.031716330340714194, 0.0499617971945554, 0.018439584855514113, 0.05163717331015505, 0.015151197148952633, 0.08804949873592705, 0.05339620431186631, 0.057076811499428004, 0.07677762623643503, 0.038114073759061284, 0.06691470625810325, 0.019658022501971573, 0.05793200311018154, 0.06780110517865978, 0.09572033712174743, 0.11027346714399755, 0.060574965391424485, 0.08490308944601566, 0.034452907129889354, 0.06646089037531056, 0.09098272610572167, 0.028336818031675648, 0.017845490074250847, 0.1795597211457789, 2.94694350566715, 8.838071152567863, 27.301700301468372, 39.631064012646675, 33.88098455965519, 28.93310096114874, 23.843819350004196, 24.399560429155827, 23.389597423374653, 22.510516494512558, 26.866967529058456, 25.751360692083836, 21.275354772806168, 13.442802764475346, 8.857702799141407, 4.071413604542613, 1.483240791130811, 0.5658188508823514, 0.029448616478475742, 0.2424387470819056, 0.10962721236865036, 0.22843661718070507, 0.7992372382432222, 0.12348150645266287, 1.0569560341536999, 1.3912725448608398, 1.9457455608062446, 2.5968675781041384, 3.5996577562764287, 4.195858351886272, 5.863379398360848, 1.8681347253732383, 4.416408492252231, 4.882771717384458, 1.8216027785092592, 1.3301248010247946, 1.7278486280702055, 1.334485779516399, 1.6044973907992244, 4.34010811150074, 4.2518051248043776, 4.7327191941440105, 5.5437457747757435, 5.641538752242923, 8.067825883626938, 14.446370713412762, 17.01648060232401, 17.8699604049325, 19.814688451588154, 18.760748505592346, 12.098102420568466, 8.340668343007565, 4.955671280622482, 3.0414610588923097, 1.5300475107505918, 1.9242627010680735, 2.4246413446962833, 2.023817477747798, 3.1668020831421018, 1.7909792717546225, 2.795882374048233, 5.140148531645536, 3.954139784909785, 3.2043948909267783, 4.184194402769208, 1.2560425512492657, 0.4287436109734699, 0.5956290231551975, 0.6698472343850881, 0.11012911942088977, 0.20059842034243047, 0.00979987360551604, 0.11025243467884138, 0.2947724185651168, 0.9804192942101508, 1.802846984937787, 6.268947785720229, 6.954376380890608, 10.873165000230074, 21.16434372961521, 24.231107868254185, 19.553967341780663, 20.13614170253277, 31.21298622339964, 32.647680938243866, 25.368685126304626, 14.166011307388544, 5.414703274145722, 0.6855284585617483, 0.013199931345297955, 0.0202060688752681, 0.03680072470160667, 0.01715098271233728, 0.038582376364502124, 0.019610695744631812, 0.038082183673395775, 0.06226852783584036, 0.06711790629196912, 0.009713947747513885, 0.10425218555610627, 0.04400898986204993, 0.1002185238758102, 0.07669881757465191, 0.05079984890471678, 0.05233268442680128, 0.02428320742183132, 0.01979548680537846, 0.01527800699477666, 0.04832414444535971, 0.022123730232124217, 0.08593926861067303, 0.03548720866092481, 0.003961336142310756, 0.012034034043608699, 0.06430760084185749, 0.016557529888814315, 0.002782043075058027, 0.010518838444113499, 0.04299143860407639, 0.05430629629699979, 0.030399478346225806, 0.06088539092161227, 0.04877223836956546, 0.020640965558413882, 0.026568263419903815, 0.04378295394417364, 0.040147691979655065, 0.03087165310716955, 0.030422622221522033, 0.039467409733333625, 0.04488621583732311, 0.022510715716634877, 0.06338832477922551, 0.016604559787083417, 0.1391891436651349, 0.0354712970147375, 0.040529423058615066, 0.028369385327096097, 0.022580058284802362, 0.020660446934925858, 0.02532950762542896, 0.059869561446248554, 0.027328760697855614, 0.04901016720396001, 0.0053427104558068095, 0.01484961059759371, 0.009799522940738825, 0.03613296248659026, 0.025159913893730845, 0.055013666933518834, 0.10453138893353753, 0.09852095012320206, 0.025216255889972672, 0.033926550022442825, 0.038377833043341525, 0.12329023273196071, 0.022438951891672332, 0.01616142526472686, 0.03257226409914438, 0.037651407765224576, 0.03898440518241841, 0.042797730638994835, 0.029217943992989603, 0.061284488256205805, 0.05253802926745266, 0.024590337816334795, 0.02887980666855583, 0.0722155554103665, 0.07201137574156746, 0.06906163558596745, 0.08770941698458046, 0.09445827789022587, 0.020748992574226577, 0.022891053413331974, 0.030093455607129727, 0.36723509430885315, 3.599515976384282, 11.51480806991458, 33.1760273873806, 43.68292339146137, 40.43075390160084, 35.284249261021614, 30.571968220174313, 27.32613679021597, 31.368612572550774, 29.049743302166462, 33.63671846687794, 27.387987971305847, 24.172790497541428, 14.34359097853303, 8.077689204365015, 3.686400926671922, 1.4947249623946846, 0.24848368833772838, 0.20492552721407264, 0.05850527137226891, 0.20552919013425708, 0.2850591007154435, 0.5859041574876755, 0.8972565410658717, 0.416879371041432, 2.0814409106969833, 1.1897165165282786, 3.380469367839396, 3.4692316548898816, 2.420064015313983, 5.6595412362366915, 5.6655691377818584, 5.8956662658602, 5.721384817734361, 4.337755087763071, 3.2701814733445644, 3.2748051127418876, 2.7765770349651575, 2.369211344048381, 5.80457660369575, 7.712592920288444, 8.082080818712711, 9.003131445497274, 5.829711779952049, 10.486254561692476, 18.319105803966522, 21.31456296890974, 19.343551732599735, 25.072597414255142, 21.186623834073544, 15.852655302733183, 9.246541634202003, 7.209425820037723, 5.871601207181811, 3.8651445228606462, 3.2447926606982946, 5.211415607482195, 3.821908780373633, 5.132788326591253, 5.6930345389992, 4.699954502284527, 4.948918092995882, 4.362138854339719, 2.3927035834640265, 1.5635490068234503, 1.067641417030245, 0.9216074156574905, 0.8943781955167651, 0.2496271301060915, 0.1523248161538504, 0.15577771759126335, 0.048071825367514975, 0.08846256328979507, 0.5112431512679905, 0.6456171220634133, 1.7114166473038495, 6.688055321574211, 9.736074116081, 13.060718066990376, 20.91683641076088, 21.590825244784355, 21.39412309974432, 22.56549384444952, 36.322319358587265, 37.343058586120605, 32.146708220243454, 17.865898422896862, 7.21281903795898, 0.8197836263570935, 0.08495328831486404, 0.056927135156001896, 0.029429125825117808, 0.01360067068162607, 0.04438155912794173, 0.08521431649569422, 0.008807454250927549, 0.03658051464299206, 0.07885307932156138, 0.011545304751052754, 0.044984594933339395, 0.06406688524293713, 0.038230887803365476, 0.055113162961788476, 0.021762849792139605, 0.04075533652212471, 0.045904008293291554, 0.004953746683895588, 0.028433716543077026, 0.030505030299536884, 0.04048600370879285, 0.05894472298678011, 0.05614400979538914, 0.044505323385237716, 0.010420914841233753, 0.02898437527619535, 0.02729550877120346, 0.03150748256302904, 0.053630426118616015, 0.030755360421608202, 0.01318431377512752, 0.08535821893019602, 0.029338760068640113, 0.09882411002763547, 0.09398757814778946, 0.008165011331584537, 0.03634611101006158, 0.025391243179910816, 0.02732679215114331, 0.016389435295423027, 0.08585778079577722, 0.1157242152839899, 0.06585215858649462, 0.15700655087130144, 0.0838827328698244, 0.19008377596037462, 0.13217776286182925, 0.19695560331456363, 0.08376017460250296, 0.14472583250608295, 0.226150713278912, 0.13794086611596867, 0.1791284146020189, 0.09136174834566191, 0.17871002142783254, 0.11407485886593349, 0.14005992037709802, 0.14455917582381517, 0.12438854450010695, 0.08086328278295696, 0.1376399103901349, 0.17324888322036713, 0.20063767995452508, 0.09165556461084634, 0.11141857874463312, 0.09894183691358194, 0.19763232325203717, 0.13673523237230256, 0.16658193315379322, 0.1236066548153758, 0.3018501028418541, 0.17586002591997385, 0.14602245355490595, 0.1549297248129733, 0.17979680764256045, 0.14541718759573996, 0.14703208609716967, 0.14204142498783767, 0.2510373591212556, 0.25473999325186014, 0.20028671831823885, 0.20825141749810427, 0.1546936624799855, 0.24540640268241987, 0.06983207393204793, 0.18627311481395736, 0.4176033806288615, 4.572440469637513, 14.43297928199172, 37.35081396996975, 52.83124029636383, 46.41703628003597, 43.22979010641575, 37.96179078519344, 36.44370764493942, 37.6579324901104, 33.89170378446579, 38.958477303385735, 38.85941281914711, 30.24717304855585, 19.061129987239838, 11.83941325172782, 5.966149158775806, 2.5625497195869684, 0.9563352365512401, 0.5362148175481707, 0.7732603477779776, 0.8077087055426091, 1.2380215432494879, 2.6895479299128056, 3.7039526598528028, 5.076479148119688, 5.573084000498056, 6.498793652281165, 10.251079481095076, 11.81861411780119, 11.925468184053898, 13.401189297437668, 11.086005829274654, 11.110259927809238, 15.431031826883554, 6.543122073635459, 4.912292333319783, 3.350279275327921, 2.52571330871433, 2.23786236718297, 7.002269960939884, 8.471552319824696, 8.967725895345211, 10.09944861754775, 11.925300993025303, 11.934023424983025, 19.65010978281498, 22.31733676046133, 21.507843397557735, 25.41225738823414, 21.421800814568996, 15.859657377004623, 10.39337519556284, 5.5055582989007235, 6.3971201330423355, 2.3156111827120185, 4.718010658398271, 4.578447947278619, 6.0612081829458475, 8.405404519289732, 8.101771362125874, 9.61868891492486, 10.877021793276072, 13.084985464811325, 9.387164488434792, 10.669507328420877, 5.750457057729363, 3.27863696962595, 3.406218448653817, 2.8596897376701236, 1.0978158353827894, 0.9415358025580645, 0.5004554707556963, 0.35969143034890294, 0.9510240121744573, 1.8099444103427231, 3.026074734516442, 8.124238606542349, 11.786111611872911, 15.699026696383953, 32.97964632511139, 34.836986660957336, 29.195714369416237, 31.169461458921432, 41.80635988712311, 43.67035746574402, 37.608109563589096, 20.86700588464737, 8.372484035789967, 1.045438377186656, 0.11944519530516118, 0.14797510346397758, 0.09283062187023461, 0.11545931309228763, 0.11776655373978429, 0.1504149436368607, 0.13768270262517035, 0.33668250718619674, 0.18917016248451546, 0.13125205237884074, 0.18796484044287354, 0.15321010927436873, 0.14087699528317899, 0.32233530830126256, 0.12011720260488801, 0.13552266696933657, 0.15931353176711127, 0.06927074311533943, 0.14548907201969996, 0.10774096241220832, 0.11012209870386869, 0.09617510295356624, 0.08158851691405289, 0.130372206622269, 0.061324115231400356, 0.14538189105223864, 0.16838521842146292, 0.12623057729797438, 0.1198768506583292, 0.13238439161796123, 0.23443557496648282, 0.26711206999607384, 0.16447450092528015, 0.17965321691008285, 0.29396309168078005, 0.09894877599435858, 0.13893564086174592, 0.1426618010737002, 0.10368433126132004, 0.08378046491998248, 0.132409758225549], [0.008765157399466261, 0.01434510231774766, 0.03598260707804002, 0.0998206585063599, 0.026490987293072976, 0.020201094630465377, 0.050233111542183906, 0.03278302290709689, 0.012674251447606366, 0.14424661290831864, 0.043309170578140765, 0.009072916764125694, 0.0433895674359519, 0.018047183548333123, 0.025126702785200905, 0.016566389276704285, 0.05444949369120877, 0.05544543360883836, 0.026416620385134593, 0.05752246746851597, 0.03812129485595506, 0.034645093692233786, 0.008271321203210391, 0.06139857490779832, 0.034271236800123006, 0.06513398970128037, 0.06204940131283365, 0.016581592171860393, 0.00682505117765686, 0.021798318884975743, 0.06665928871370852, 0.03349112084833905, 0.03358073146955576, 0.08313858139445074, 0.013853281052433886, 0.046062698020250537, 0.0545773434714647, 0.0366502653923817, 0.06372166040819138, 0.015212260132102529, 0.047820333784329705, 0.006315402597465436, 0.12106507361750118, 0.07174916754593141, 0.01770454695360968, 0.021076288976473734, 0.8176250453107059, 2.887494508177042, 12.186011653393507, 28.172642067074776, 32.87902772426605, 32.166558355093, 26.181043535470963, 18.693940490484238, 14.310609698295593, 22.962384447455406, 25.149349495768547, 27.61459831148386, 19.680314362049103, 20.03518871963024, 17.507028579711914, 9.576301239430904, 4.84259077347815, 1.1261021113023162, 0.3576938953483477, 0.06780091964174062, 0.25078217906411737, 0.106509657780407, 0.1576651624054648, 0.648075055796653, 0.2225041261408478, 1.0572515870444477, 1.3120681699365377, 1.5076820296235383, 1.2353646545670927, 1.5042350208386779, 5.97942897118628, 5.8522493205964565, 5.537271397188306, 4.049671171233058, 2.2533800220116973, 2.2707341657951474, 1.4613819890655577, 1.511251819320023, 0.1626150796073489, 1.8461229815147817, 2.416182761080563, 2.243929454125464, 3.018693393096328, 2.519460031762719, 7.08099746145308, 10.706272255629301, 14.290607571601868, 18.258367963135242, 23.59350398182869, 14.219814520329237, 8.925374317914248, 4.7092934511601925, 2.31522882822901, 1.8600282166153193, 2.7952998178079724, 1.258180767763406, 5.915567222982645, 4.566990612074733, 4.289203193038702, 3.8970815716311336, 1.8419221881777048, 2.8747362177819014, 2.3443884635344148, 1.176896479446441, 1.6494709462858737, 0.6606428220402449, 0.2479663965641521, 0.6709031027276069, 0.10478931493707933, 0.11870242422446609, 0.06797235575504601, 0.2160375114181079, 0.3456244367407635, 0.6204788584727794, 1.8858097144402564, 5.605116756632924, 7.6765471044927835, 15.006322916597128, 19.190775230526924, 19.03503678739071, 18.528881147503853, 17.890897281467915, 28.04972056299448, 29.84217558056116, 27.61338047683239, 17.843971699476242, 6.170535441488028, 1.3021308719180524, 0.040776031310088, 0.053618388483300805, 0.006142145439298474, 0.00747525835322449, 0.06104591375333257, 0.08991110196802765, 0.05943031392234843, 0.022614928093389608, 0.035531077010091394, 0.040887064023991115, 0.04990298941265792, 0.03994569422502536, 0.04019205014628824, 0.01415197693859227, 0.06493676395621151, 0.07043891324428841, 0.06874482016428374, 0.013752416689385427, 0.005338761302482453, 0.035236162366345525, 0.06422552673029713, 0.03193734934029635, 0.04273550155630801, 0.04192052692815196, 0.04767718091898132, 0.13369472755584866, 0.05001732839446049, 0.028398740978445858, 0.052909644873579964, 0.03403259921469726, 0.04738982876006048, 0.027746810628741514, 0.018017672045971267, 0.024124111369019374, 0.057177053386112675, 0.03661829738121014, 0.04361175531812478, 0.06523639123770408, 0.03531296351866331, 0.0005763192427821195, 0.03430951677728444, 0.05929134305915795, 0.067948013311252, 0.03703579255670775, 0.046090420946711674, 0.04165431113506202, 0.01676981381024234, 0.07952499014209025, 0.013248170016595395, 0.025197830218530726, 0.06481419084593654, 0.032208800985245034, 0.03928853358956985, 0.046629988282802515, 0.06569274526555091, 0.011963693286816124, 0.024534862277505454, 0.02898620838095667, 0.058092945255339146, 0.06689696150715463, 0.10027282682131045, 0.047840954357525334, 0.07445992872817442, 0.013414565091807162, 0.04926392233755905, 0.019858127780025825, 0.0875307152455207, 0.04968289809767157, 0.05108545330585912, 0.007990032390807755, 0.041906593105522916, 0.046399681305047125, 0.049832229342428036, 0.014851219202682842, 0.019635956596175674, 0.037898787850281224, 0.0313323839509394, 0.03424715410801582, 0.05361908610211685, 0.06882846762891859, 0.13388054649112746, 0.03855080169159919, 0.049214372847927734, 0.061365497385850176, 0.020931497820129152, 0.014612324648624053, 0.024269177120004315, 0.06232347644981928, 1.116955408360809, 3.707391950301826, 17.47234784066677, 34.32743400335312, 39.20765273272991, 38.44654977321625, 32.12454400956631, 25.80426525324583, 20.2272380143404, 26.123368330299854, 32.343697249889374, 40.722418650984764, 29.260453395545483, 24.961240589618683, 18.908967152237892, 9.506095256656408, 3.128420580178499, 1.114683486521244, 0.4865274962503463, 0.1700682906084694, 0.0814878816890996, 0.18625883589265868, 0.10975227909511887, 0.7319680228829384, 0.34781398018822074, 1.4584667142480612, 1.2301721144467592, 1.0229786136187613, 1.4937637327238917, 2.9192612785845995, 4.2381705064326525, 3.8013658951967955, 3.292460865341127, 5.178417228162289, 5.357376700267196, 2.7272820426151156, 4.470204580575228, 3.2682485645636916, 1.8464292213320732, 2.981194155290723, 4.045223034918308, 4.372722236439586, 5.90939492918551, 3.9395806286484003, 8.912300169467926, 14.967127069830894, 17.18576341867447, 19.72838368266821, 22.302623949944973, 17.60672003030777, 10.234467722475529, 6.405866788700223, 3.4249806543812156, 3.953306917101145, 3.3875075401738286, 4.1890372429043055, 5.104051418602467, 3.7243884382769465, 5.053254794329405, 3.6572132678702474, 4.548904532566667, 4.401701856404543, 2.021878156810999, 1.1321192071773112, 0.7876761804800481, 1.1364761483855546, 0.32846147019881755, 0.46985743450932205, 0.1501977615407668, 0.1275792228989303, 0.06318862768239342, 0.009343353522126563, 0.18803573038894683, 0.6804355443455279, 1.794274882413447, 6.433933982625604, 10.178831107914448, 18.318446539342403, 21.1089389026165, 23.024596609175205, 23.82034420967102, 21.723937802016735, 32.12324447929859, 34.97626818716526, 33.491486459970474, 22.69155018031597, 7.683715419843793, 1.7080880259163678, 0.12722321465844288, 0.008326681709149852, 0.05983585680951364, 0.0196709191732225, 0.00557392702830839, 0.0731664321210701, 0.054835885457578115, 0.001163878660008777, 0.02738435683568241, 0.0515436552814208, 0.013047604606981622, 0.0478594635205809, 0.1438246128964238, 0.012738223649648717, 0.08114472744637169, 0.0013952182666798763, 0.0533705556881614, 0.034472002589609474, 0.01994461395952385, 0.03412271449633408, 0.018091402562276926, 0.042053987344843335, 0.03063527536141919, 0.043590051209321246, 0.05691892700269818, 0.0581894504284719, 0.037742580607300624, 0.11422653158660978, 0.023155502894951496, 0.017771570310287643, 0.08060266278334893, 0.0404148169036489, 0.05592400011664722, 0.03814428288023919, 0.018785295796988066, 0.01174569018985494, 0.04797137196874246, 0.007227449677884579, 0.03213298688933719, 0.056659301480976865, 0.027783760306192562, 0.07861971098463982, 0.18173462944105268, 0.08409139511059038, 0.1621562393847853, 0.12323133589234203, 0.11133839710964821, 0.17140206356998533, 0.20099244138691574, 0.1171189482556656, 0.10420683291158639, 0.2299638235126622, 0.14447924651904032, 0.15370988636277616, 0.14769642701139674, 0.08970263268565759, 0.14654697384685278, 0.13755873427726328, 0.12114499550079927, 0.13890801812522113, 0.22726761584635824, 0.15948361717164516, 0.1440704715787433, 0.09646218051784672, 0.27893002959899604, 0.157625591091346, 0.1559318319777958, 0.19803535396931693, 0.10487604973604903, 0.1524784555658698, 0.14012180065037683, 0.17061779159121215, 0.206707468314562, 0.1469251129310578, 0.163171274762135, 0.18794146279105917, 0.13701604621019214, 0.18540410441346467, 0.18944310955703259, 0.09705752396257594, 0.24165024486137554, 0.10688894719351083, 0.12173843162599951, 0.16839645453728735, 0.21868599898880348, 0.0782485629315488, 0.11153540763189085, 0.10544726595981047, 1.0086366394534707, 4.542428255081177, 20.87723683565855, 37.101117968559265, 47.25602746009827, 46.68539687991142, 41.63721576333046, 31.958473920822144, 26.66695386171341, 35.10886587202549, 40.45425944030285, 40.39364889264107, 31.21875811368227, 28.08826569467783, 25.37302639335394, 14.124332293868065, 5.997614320367575, 2.583608189597726, 0.9584063629154116, 0.3997085674200207, 0.8214836195111275, 0.4787709843367338, 0.6410385458730161, 2.068660771474242, 2.6780791953206062, 5.239369282498956, 5.4105885699391365, 8.150232061743736, 7.091422202065587, 6.785432221367955, 13.576212655752897, 10.924637988209724, 12.71109502762556, 11.507102083414793, 11.767527759075165, 8.952437415719032, 4.783377125859261, 5.065822144970298, 2.061688620597124, 2.4275325145572424, 5.02337652258575, 5.658065965399146, 7.240351410582662, 4.598079118877649, 10.793218240141869, 16.010744869709015, 15.751778315752745, 20.198087878525257, 24.19444553554058, 16.794722601771355, 10.674647502601147, 7.363481903448701, 3.719597370363772, 5.223872764036059, 6.847585961222649, 4.078992772847414, 11.103649232536554, 9.93787083774805, 11.318370960652828, 11.899451930075884, 7.459847582504153, 8.994817491620779, 7.69835508428514, 7.137253442779183, 4.708858849480748, 4.314296096563339, 1.5122648212127388, 1.7828943743370473, 1.031812783330679, 0.7265215495135635, 0.22945232049096376, 0.4502644983585924, 0.7465991971548647, 1.2029105960391462, 3.3037973195314407, 7.9168538097292185, 11.832895651459694, 23.745129145681858, 29.12216741591692, 29.263953007757664, 31.195465363562107, 26.896594539284706, 38.72750669717789, 40.839410573244095, 38.48580166697502, 25.571715831756592, 9.626224860548973, 2.001306298188865, 0.17226755619049072, 0.1352001741179265, 0.19916675810236484, 0.12898336630314589, 0.1164571603294462, 0.12044005168718286, 0.12506711238529533, 0.11163510775077157, 0.1549518556566909, 0.20665421179728583, 0.13353941089008003, 0.10757572323200293, 0.21345978020690382, 0.11076583017711528, 0.11888857712619938, 0.1834893337218091, 0.12695865385467187, 0.13093445770209655, 0.1669384608976543, 0.09606812978745438, 0.12347460447927006, 0.07444636226864532, 0.26832456118427217, 0.19306266767671332, 0.14529706357279792, 0.27885715069714934, 0.0732533450354822, 0.23656662233406678, 0.09641490571084432, 0.15079364675329998, 0.18324243603274226, 0.08789006315055303, 0.12144979555159807, 0.09282605024054646, 0.10530618368647993, 0.19660793681396171, 0.1640870256233029, 0.17698173760436475, 0.1875097703305073, 0.14016313827596605, 0.09673328706412576, 0.1404626393923536], [0.04622445652785245, 0.032831396092660725, 0.018602668096718844, 0.05185575064388104, 0.038358919409802184, 0.04564211551041808, 0.08893647653167136, 0.04259156201442238, 0.01570524378621485, 0.014388717409019591, 0.012096000591554912, 0.05590936867520213, 0.04926910994981881, 0.0827980469330214, 0.024812186165945604, 0.15669872285798192, 0.01984482292755274, 0.06567497825017199, 0.03934771986678243, 0.03314983310701791, 0.026740241301013157, 0.04328516952227801, 0.13961970806121826, 0.05113215294841211, 0.020953875427949242, 0.062408296507783234, 0.021032784279668704, 0.04274225881090388, 0.047077507042558864, 0.03484675005893223, 0.04818172259547282, 0.01129946183937136, 0.02854368241969496, 0.06826825745520182, 0.049474265542812645, 0.0761241874715779, 0.05646889978379477, 0.02082448198052589, 0.049100315882242285, 0.06048896160791628, 0.06832155850133859, 0.08354058794793673, 0.05166668110177852, 0.09297896976931952, 0.029621180656249635, 0.006957907207834069, 0.02968801105453167, 0.36040018138010055, 3.2701885979622602, 14.713887758553028, 27.043905034661293, 38.01002159714699, 34.48592349886894, 29.68400526791811, 23.17457266151905, 19.555724747478962, 20.791220851242542, 9.487562701106071, 25.285120010375977, 27.437662705779076, 13.119848594069481, 13.155473582446575, 10.041308887302876, 7.114325948059559, 3.3296074345707893, 1.5669950656592846, 0.265530226752162, 0.29640680586453527, 0.3094823198625818, 0.11628697844571434, 0.06199473842571024, 0.6737369787879288, 0.49685614358168095, 0.5170466273557395, 0.6337058893404901, 0.8740893623325974, 1.6757255187258124, 1.9138212176039815, 2.5860863691195846, 2.1606592973694205, 3.697312753647566, 2.4582075560465455, 6.049661077558994, 2.7694296184927225, 1.1282595642842352, 2.1327324584126472, 2.371922261081636, 1.965357733424753, 2.4555436614900827, 1.7970631015487015, 3.39266671333462, 6.7704614996910095, 9.091691393405199, 16.026350632309914, 15.2884017303586, 9.749736282974482, 5.591278849169612, 2.3466597916558385, 1.652465898077935, 1.1873541120439768, 1.5351913659833372, 3.070092760026455, 4.989719353616238, 2.140344399958849, 3.1048069847747684, 3.5012157261371613, 5.111900847405195, 3.4818391408771276, 0.19483648968162015, 0.4952401912305504, 0.13778474793070927, 0.5729900754522532, 0.6705146923195571, 0.2673555538058281, 0.19598175713326782, 0.09765457434696145, 0.19372362439753488, 0.35448953916784376, 1.5250337985344231, 2.95926695689559, 5.198787460103631, 8.051376566290855, 13.426223304122686, 14.501337613910437, 21.394670270383358, 16.59851063042879, 17.032829225063324, 26.28278497606516, 29.367233365774155, 29.848405346274376, 20.860090255737305, 9.90954715758562, 1.9519459968432784, 0.20897263661026955, 0.01737379585392773, 0.08953311873483472, 0.07511120042181574, 0.07720240188064054, 0.032622284852550365, 0.044410829432308674, 0.02906816931499634, 0.01403499869411462, 0.044490884902188554, 0.07221393010695465, 0.04823677139938809, 0.073584394849604, 0.08571517711970955, 0.02267396223032847, 0.05753723620728124, 0.15545051952358335, 0.05133700426085852, 0.057224320771638304, 0.03656337103166152, 0.02192219631979242, 0.02790440383250825, 0.02991329183714697, 0.025531924693495966, 0.13310149923199788, 0.00557912345357181, 0.08495350353769027, 0.04183205179288052, 0.00848166533614858, 0.028114676533732563, 0.025574245664756745, 0.027943218155996874, 0.047894121817080304, 0.049091766341007315, 0.02722918117797235, 0.027157267068105284, 0.07371859741397202, 0.06704671948682517, 0.07569693305413239, 0.006429659015338984, 0.04275460072676651, 0.03735019599844236, 0.048996838231687434, 0.04261636458977591, 0.014255857204261702, 0.01558715695864521, 0.050722724918159656, 0.014996864756540162, 0.03667200289783068, 0.05462361266836524, 0.01429728203220293, 0.0604554721940076, 0.04847474476264324, 0.03479481085378211, 0.06705428939312696, 0.05987643002299592, 0.07411774669890292, 0.034473312480258755, 0.019367091335880104, 0.025425062849535607, 0.05295525726978667, 0.017804406634240877, 0.026746057883428875, 0.057863235706463456, 0.07070488412864506, 0.06979294048505835, 0.044969403170398436, 0.022556411604455207, 0.06752566448994912, 0.039033064094837755, 0.013283814441820141, 0.007803966691426467, 0.06868891417980194, 0.0393040593189653, 0.021222712857706938, 0.032557732847635634, 0.047263300002668984, 0.11127994555863552, 0.09711793478345498, 0.014453554213105235, 0.006048857940186281, 0.06341316446196288, 0.020025548874400556, 0.07882548627094366, 0.03703975191456266, 0.02828185086400481, 0.032833704171935096, 0.05859602490090765, 0.13434732769383118, 0.0477467238670215, 0.4226228519110009, 4.9037727154791355, 19.586947672069073, 32.476382330060005, 44.567679315805435, 39.49931748211384, 34.17175255715847, 25.393682084977627, 24.57105092704296, 29.64126516133547, 17.950402088463306, 26.925003714859486, 36.06742903590202, 20.005472414195538, 18.122443556785583, 13.224423732608557, 6.794525133445859, 1.8158716172911227, 0.9717490500770509, 0.12638267304282635, 0.026893856593233068, 0.1639365329174325, 0.34790998441167176, 0.1932565463357605, 0.5542276916094124, 0.705000632442534, 0.9521961305290461, 0.5315708729904145, 2.002611765637994, 2.472335435450077, 4.480649745091796, 3.307471484877169, 5.393133731558919, 4.9118453823029995, 3.8083083601668477, 5.463191997259855, 3.046795497648418, 2.956759328953922, 2.0117861358448863, 2.7348859095945954, 2.343356581404805, 4.388088136911392, 3.2094001723453403, 6.231673210859299, 9.830499049276114, 11.768479607999325, 18.613151125609875, 18.950498923659325, 12.738291118294, 6.296182824298739, 5.872441912069917, 2.837250754237175, 3.143309368751943, 2.9320304933935404, 4.205978633835912, 4.241777937859297, 4.004725283011794, 5.146792000159621, 4.5079047325998545, 2.132231597788632, 2.7719322592020035, 1.3279903843067586, 1.9232010142877698, 0.7489069201983511, 0.111627753067296, 0.4060271236812696, 0.3184802073519677, 0.07842722756322473, 0.05762990076618735, 0.23494263994507492, 0.64397246344015, 1.9863960170187056, 3.7210830906406045, 6.303667472675443, 10.467149186879396, 16.86513092368841, 17.618676088750362, 26.14084169268608, 20.785555355250835, 20.147751979529858, 29.045498929917812, 32.90684603154659, 35.42252004146576, 24.766381345689297, 13.134460709989071, 2.921348079107702, 0.21414225921034813, 0.06890136137371883, 0.0366780847980408, 0.04333273747761268, 0.0297991513798479, 0.04147102292336058, 0.08521519965142943, 0.01647078952373704, 0.026162844842474442, 0.01364265490337857, 0.0321388498559827, 0.04414577881107107, 0.01691788711468689, 0.05698410612239968, 0.02587236824183492, 0.021746097663708497, 0.038672220762236975, 0.06301263478235342, 0.04511356164584868, 0.01678313721640734, 0.0440812787564937, 0.013334866780496668, 0.027510625841387082, 0.03546864383679349, 0.06075668025005143, 0.031031680555315688, 0.02995508402818814, 0.06186042453919072, 0.044722282837028615, 0.017465799901401624, 0.010536217687331373, 0.0330345070688054, 0.07475885839085095, 0.015536265109403757, 0.0198308445760631, 0.032570798357483, 0.04105359454115387, 0.09089749044505879, 0.024974623738671653, 0.02897016685892595, 0.039203502019518055, 0.04168630141066387, 0.06808813821407966, 0.1468961691716686, 0.10288511984981596, 0.14662389003206044, 0.17455320776207373, 0.1929320051567629, 0.14130218653008342, 0.12913519487483427, 0.2208999145659618, 0.10471581263118424, 0.1377026515547186, 0.061231469226186164, 0.1617963719763793, 0.26565671840216964, 0.2118503735982813, 0.17386085819453, 0.3727129753679037, 0.10453665818204172, 0.16325310396496207, 0.09547542838845402, 0.09609086177079007, 0.1661873926059343, 0.1371144104632549, 0.20458226907067, 0.13638165837619454, 0.12821902841096744, 0.1922466911491938, 0.06807944024330936, 0.1293645185069181, 0.11534926743479446, 0.20403162518050522, 0.13525020971428603, 0.07395004358841106, 0.07790086674503982, 0.20076849090401083, 0.1564068955485709, 0.14717192156240344, 0.18870122905354947, 0.07204870576970279, 0.11637106377747841, 0.1575637553469278, 0.17335852811811492, 0.17395203845808282, 0.14439480495639145, 0.15155227010836825, 0.17311495525063947, 0.2112621918786317, 0.15141098003368825, 0.9069368185009807, 6.397362370043993, 20.862356834113598, 37.981344535946846, 51.18118643760681, 48.193980529904366, 44.749944135546684, 37.271044850349426, 32.35750950872898, 35.10688617825508, 17.681353725492954, 34.695288464426994, 39.642193615436554, 21.08683928847313, 19.887817427515984, 13.997532147914171, 10.077878125011921, 4.564420999959111, 2.4582400918006897, 0.6049028411507607, 0.7331692334264517, 0.9163496852852404, 1.9961775233969092, 0.6111857446376234, 2.3719251109287143, 1.7870120471343398, 5.208111209794879, 5.04172146320343, 5.700918165966868, 9.26783949136734, 9.27080238237977, 10.958904549479485, 9.584561996161938, 12.135362271219492, 8.166042063385248, 11.799902971833944, 8.470049500465393, 3.965246113948524, 5.04412435926497, 3.5062174452468753, 5.450819861143827, 5.459543718025088, 4.0758769400417805, 6.177289579063654, 9.106836430728436, 11.781028434634209, 20.32076619565487, 19.31902974843979, 13.552630171179771, 7.2351333405822515, 5.861894153058529, 3.279806594364345, 4.201540471985936, 5.8747493382543325, 8.875731881707907, 13.744303286075592, 5.079344669356942, 9.49018171057105, 10.250356569886208, 13.173140734434128, 9.674278981983662, 7.824717303737998, 3.521401430480182, 1.834856467321515, 2.3616046272218227, 2.6618474163115025, 1.0963619383983314, 0.45829038019292057, 0.43582951824646443, 0.5707952775992453, 0.9078092873096466, 2.2188873728737235, 4.516131291165948, 7.529233284294605, 13.567711561918259, 20.3222519159317, 22.502607218921185, 32.90005959570408, 27.06074383109808, 27.320841774344444, 38.45887251198292, 39.57149460911751, 41.88702575862408, 28.322656117379665, 15.081619676202536, 3.5114027420058846, 0.5068223259877414, 0.15321569022489712, 0.15679208503570408, 0.1528149304795079, 0.18875736510381103, 0.11218634535907768, 0.19953763898229226, 0.07043808946036734, 0.1376545158564113, 0.13928136293543503, 0.2709947491530329, 0.1739224564516917, 0.12474331335397437, 0.2807727229082957, 0.1268715554033406, 0.17580310319317505, 0.22418375476263463, 0.14170530630508438, 0.12482063029892743, 0.08453286165604368, 0.11820378262200393, 0.16100950248073786, 0.1931125993723981, 0.13028173882048577, 0.2124831880792044, 0.21204270859016106, 0.16986091970466077, 0.1993543581920676, 0.1883980617276393, 0.12015405023703352, 0.10225591220660135, 0.16092219622805715, 0.09736952284583822, 0.15461918053915724, 0.1570974788046442, 0.25568620185367763, 0.14497957279672846, 0.19305863039335236, 0.17980909760808572, 0.07500885083572939, 0.10014878425863571, 0.18839665164705366, 0.18312615633476526], [0.0791248538007494, 0.03017025490407832, 0.08941546606365591, 0.05297965166391805, 0.02928914564108709, 0.021593851633952, 0.012560200048028491, 0.03894598048646003, 0.06943316213437356, 0.09037142648594454, 0.06837520093540661, 0.06465805039624684, 0.04266385833034292, 0.023026872004265897, 0.017868928953248542, 0.008601038862252608, 0.01958941651537316, 0.020956541593477596, 0.04843682472710498, 0.006323300440271851, 0.014784667109779548, 0.06073443808418233, 0.01369340110613848, 0.05185438509215601, 0.006788270802644547, 0.1194978209969122, 0.024195663681894075, 0.02535124142013956, 0.03866653591103386, 0.020303924757172354, 0.0841588934417814, 0.042224759235978127, 0.06581144436495379, 0.07666479752515443, 0.022803123756602872, 0.006759190673619742, 0.07001966660027392, 0.05115441366797313, 0.05522313811525237, 0.04008637202787213, 0.02201486458943691, 0.020722355038742535, 0.017517739106551744, 0.028228288210812025, 0.05883015022845939, 0.005210938425079803, 0.09172143021714874, 0.0514727653353475, 0.48610067227855325, 4.9873297568410635, 15.157379060983658, 26.65264192968607, 39.63609494268894, 37.45413802564144, 25.327318646013737, 19.41478841006756, 16.179180331528187, 28.864066265523434, 35.901662930846214, 20.761092267930508, 14.984678328037262, 13.978486619889736, 10.000715665519238, 12.647664081305265, 6.087357429787517, 2.9010612051934004, 1.5319861192256212, 0.7711259904317558, 0.195072359056212, 0.2434202522272244, 0.1788085192674771, 0.23974550800630823, 1.018273278605193, 0.6845860497560352, 0.29809231229592115, 2.5179792987182736, 0.5280680547002703, 2.2304081171751022, 0.8066224388312548, 4.763135612010956, 3.697906471788883, 0.8793627668637782, 3.3192881383001804, 1.9659808999858797, 3.312095361761749, 1.1259763617999852, 1.3406960712745786, 0.7892987527884543, 1.5699209086596966, 2.7587533788755536, 3.0230999691411853, 5.020420756191015, 7.1523509826511145, 4.653755156323314, 7.005811370909214, 1.2299668067134917, 2.221926497295499, 3.177541019394994, 1.3218123908154666, 3.018082338385284, 1.8987070536240935, 3.7738449219614267, 2.1998503943905234, 3.5332662938162684, 4.002422131597996, 1.5368907060474157, 2.2311816131696105, 1.4344236231409013, 0.8811675512697548, 0.9376423771027476, 0.14191557158483192, 0.11060588993132114, 0.03750466290512122, 0.12795476446626708, 0.051238250380265526, 0.1494973967783153, 0.39424466842319816, 0.6491308053955436, 2.412687661126256, 9.270692188292742, 10.154914241284132, 16.368339881300926, 13.944210559129715, 22.904414758086205, 17.6454209536314, 15.86302874609828, 24.820575937628746, 28.393873795866966, 38.230402171611786, 22.090965807437897, 13.807570841163397, 2.995702251791954, 0.18411293072858825, 0.03826575761195272, 0.02383064762398135, 0.054888570521143265, 0.07365893616224639, 0.05993605045659933, 0.01588119030202506, 0.023795961496944074, 0.060879027005285025, 0.04452895707800053, 0.02738090028287843, 0.051576001787907444, 0.038652390576316975, 0.06891139521030709, 0.05793076372356154, 0.03838229335087817, 0.036897344907629304, 0.021013033874623943, 0.061544243653770536, 0.04876784485531971, 0.021721512166550383, 0.02643380852532573, 0.05968836980173364, 0.022668600213364698, 0.03969306344515644, 0.040690198220545426, 0.023641832267458085, 0.03261735699197743, 0.02064064272417454, 0.048105875102919526, 0.0662871239183005, 0.061373022763291374, 0.019158668437739834, 0.006430280100175878, 0.033769433648558334, 0.04819782348931767, 0.04314639161748346, 0.025259463727707043, 0.04717135161627084, 0.05690361649612896, 0.032152880157809705, 0.07545019121607766, 0.024425397350569256, 0.022504088337882422, 0.018688488198677078, 0.03388583951164037, 0.02410688055533683, 0.06762416975107044, 0.027393861892051063, 0.04513333617069293, 0.07683006639126688, 0.0046428795758401975, 0.04089413669134956, 0.013844508866895922, 0.02905264358560089, 0.007991308884811588, 0.06267385921091773, 0.0327398633089615, 0.028463244743761607, 0.04938152676913887, 0.05350438346795272, 0.02750515992374858, 0.032787293966975994, 0.03919380957086105, 0.019039668768527918, 0.06691132206469774, 0.060600098222494125, 0.06505542594823055, 0.06512022286187857, 0.11845504413940944, 0.038610218034591526, 0.01283843863348011, 0.028059180585842114, 0.015397670886159176, 0.0481217273772927, 0.06510467486805283, 0.09583324746927246, 0.029239707473607268, 0.037288831517798826, 0.039373605977743864, 0.08407383589656092, 0.012142277209932217, 0.029310634527064394, 0.021607631460938137, 0.026425609648867976, 0.02604067063657567, 0.04656460507248994, 0.029841895375284366, 0.10228895262116566, 0.058865984829026274, 0.04649293587135617, 0.10577365508652292, 0.9597844420932233, 7.01135384850204, 18.859604001045227, 34.89571250975132, 46.10499322414398, 44.51481655240059, 31.531849913299084, 24.05414756387472, 19.71521358937025, 22.194628044962883, 35.39328061044216, 28.49364124238491, 20.735538639128208, 18.135520555078983, 14.84261155128479, 15.225417260080576, 9.338282011449337, 4.393554143607616, 1.6934369620867074, 0.6969873374328017, 0.07684501324547455, 0.10305215502739884, 0.10810302657773718, 0.23848779033869505, 0.32807148643769324, 0.4907870973693207, 0.8529940817970783, 1.525516016408801, 1.1534720426425338, 1.2672217888757586, 1.9045666954480112, 3.097772137261927, 3.6246088799089193, 2.5161102740094066, 5.827314108610153, 3.183919214643538, 4.037244888022542, 2.5379332154989243, 3.1129181245341897, 1.3695066003128886, 4.676701175048947, 3.071418651379645, 4.66219212859869, 5.802658181637526, 9.194192793220282, 7.342713642865419, 10.302625615149736, 2.5949752796441317, 4.00465308688581, 3.4565127873793244, 4.0113298036158085, 3.4698702581226826, 4.082547007128596, 5.913654025644064, 4.481922201812267, 3.9409079449251294, 2.721618921495974, 2.3996773967519403, 1.5096421306952834, 1.8673434178344905, 0.6988763704430312, 0.46892078476957977, 0.576163677033037, 0.02377673616138054, 0.1628002306097187, 0.25570140103809536, 0.06307757270406, 0.24400835973210633, 0.5398265237454325, 1.2879748502746224, 2.683051466010511, 10.943592321127653, 13.605890963226557, 17.349641025066376, 20.5326846241951, 23.266219943761826, 21.303317472338676, 20.055196546018124, 28.06938450783491, 32.954362481832504, 43.02125729620457, 27.53850169479847, 16.561941392719746, 4.590166043490171, 0.31754700117744505, 0.07310847780900076, 0.03456379141425714, 0.10381925370893441, 0.07347436403506435, 0.04197367583401501, 0.02677876804227708, 0.0017645848174652201, 0.05880954078747891, 0.013853782002115622, 0.05494086966791656, 0.022811305934737902, 0.05935723464062903, 0.009246498611901188, 0.03647565288702026, 0.035609789192676544, 0.02471611700457288, 0.02205035965744173, 0.06055587364244275, 0.009906924697133945, 0.023069064955052454, 0.014522496949211927, 0.06531045015435666, 0.04216406639898196, 0.02564772014011396, 0.03478530765278265, 0.08360536259715445, 0.02461799951561261, 0.09014616240165196, 0.01471714002036606, 0.03406990697840229, 0.018804940445988905, 0.028089193037885707, 0.0350685186276678, 0.026113992971659172, 0.0449304589710664, 0.0842196456505917, 0.05454687088786159, 0.04782116498972755, 0.0396722462028265, 0.045217781444080174, 0.057088151515927166, 0.04000973414804321, 0.07044117679470219, 0.19577171449782327, 0.1803454477339983, 0.16730395378544927, 0.12273103187908418, 0.0870817010581959, 0.1769133858033456, 0.1558775661396794, 0.1333871073438786, 0.16419294493971393, 0.1653396521578543, 0.2518282807432115, 0.10774520749691874, 0.1361311093205586, 0.13215373212005943, 0.0918492503114976, 0.11499610904138535, 0.15724436467280611, 0.1575170742580667, 0.40607672883197665, 0.13523704401450232, 0.1081780280219391, 0.09858193239779212, 0.12829361425247043, 0.1402172853704542, 0.2738355123437941, 0.26308948115911335, 0.07431115038343705, 0.10341116896597669, 0.10120898674358614, 0.06071524243452586, 0.18217260047094896, 0.1758267034892924, 0.28451718448195606, 0.22477011079899967, 0.14229862368665636, 0.16033644875278696, 0.16915478103328496, 0.18174932396505028, 0.11774102385970764, 0.18957527121528983, 0.0865403562784195, 0.11222938992432319, 0.14652353682322428, 0.12670985626755282, 0.21586923685390502, 0.15000361570855603, 0.13740326918195933, 0.12115215722587891, 1.1697753053158522, 7.95576942153275, 21.41730945557356, 38.90805780887604, 52.22132362425327, 54.23832759261131, 38.309225142002106, 32.370048835873604, 26.952244453132153, 37.77728408575058, 47.072550505399704, 34.526547119021416, 25.870921276509762, 25.499797090888023, 17.82596256583929, 18.381690345704556, 9.501459505409002, 4.750100886449218, 2.526801712810993, 1.639562740456313, 0.5072766391094774, 0.6311191187705845, 0.6784306769259274, 1.147738981526345, 1.9370769197121263, 2.102906433865428, 1.8500315467827022, 5.332163628190756, 4.164642076939344, 8.25571820139885, 4.846865069121122, 9.835776966065168, 9.575712271034718, 7.6090385019779205, 9.597202017903328, 8.309211730957031, 7.105295732617378, 3.779689958319068, 4.857082245871425, 2.187645211815834, 5.234420048072934, 5.965117989107966, 5.3315257374197245, 8.631079159677029, 11.285826656967402, 6.57569820061326, 10.712133441120386, 3.7343030562624335, 5.987432291731238, 6.083977511152625, 5.704412553459406, 9.099551271647215, 9.735095668584108, 12.972388956695795, 8.788791596889496, 9.455733709037304, 10.621194820851088, 6.678374391049147, 6.65024402551353, 5.259266439825296, 2.185681192204356, 3.8709252001717687, 1.635200574528426, 1.1575830657966435, 0.7052508252672851, 0.7465940911788493, 0.6410522607620806, 0.6272561510559171, 0.7498913048766553, 1.5065590711310506, 3.2038785936310887, 13.541242182254791, 15.42779440060258, 23.822886273264885, 26.3540805503726, 33.40872310101986, 28.39219618588686, 25.601120553910732, 35.13208642601967, 39.00619134306908, 49.443908259272575, 31.906074732542038, 19.21220228075981, 5.2568264957517385, 0.5350687040481716, 0.15326535474741831, 0.12162919490947388, 0.221276777156163, 0.15609765745466575, 0.15947891195537522, 0.10342172972741537, 0.12317017550230958, 0.11276187346084043, 0.1982595122535713, 0.17405188700649887, 0.12792825495125726, 0.13121423253323883, 0.1016306527890265, 0.16520211735041812, 0.15193162631476298, 0.1020656552282162, 0.19552239740733057, 0.12710024078842252, 0.15853099641390145, 0.08107046072836965, 0.12799291085684672, 0.18379036366241053, 0.077177599305287, 0.12353448837529868, 0.19571612763684243, 0.22950238577323034, 0.09523214495857246, 0.19252423953730613, 0.12841851770645007, 0.13626993546495214, 0.1950344946817495, 0.08470001557725482, 0.12868607678683475, 0.16581763979047537, 0.1325950279715471, 0.14497952826786786, 0.10333170721423812, 0.22087825869675726, 0.1761582653853111, 0.1908275266760029, 0.17929784691659734, 0.14858603943139315, 0.15109475090866908], [0.030604112580476794, 0.015601578743371647, 0.04880374624917749, 0.0813228428887669, 0.04650413116905838, 0.01747837373841321, 0.007357492968367296, 0.04930851428071037, 0.024726000556256622, 0.10809427665662952, 0.027689950984495226, 0.039763266904628836, 0.030044455306779128, 0.04428074578754604, 0.1299053363618441, 0.042815356646315195, 0.05486345253302716, 0.026518723207118455, 0.11155170519487001, 0.07057722730678506, 0.06912222452228889, 0.04124244143895339, 0.047422011994058266, 0.0229372372632497, 0.030149164922477212, 0.05224122214713134, 0.04336946636612993, 0.005861048657607171, 0.01590284431586042, 0.02886832935473649, 0.029087424336466938, 0.04049997092806734, 0.02864540303562535, 0.04204592391033657, 0.027291291517030913, 0.04243844210577663, 0.029701109961024486, 0.03846692416118458, 0.07284427323611453, 0.00407070690926048, 0.01726861868519336, 0.09215876300004311, 0.027762490353779867, 0.02524076717236312, 0.01287401348236017, 0.05159310458111577, 0.023417926313413773, 0.020592850269167684, 0.029298732333700173, 0.8906923339236528, 7.079156935214996, 15.892390720546246, 29.535961411893368, 32.02614448964596, 35.24602331221104, 28.392287380993366, 26.334997974336147, 23.885174430906773, 19.15503814816475, 14.763520695269108, 20.096373036503792, 19.70463115721941, 21.014306880533695, 13.734894040971994, 6.600091466680169, 5.9940258879214525, 4.039217932149768, 2.8810842521488667, 1.0801062919199467, 0.7794557372108102, 0.10642592867952771, 0.15775289910379797, 0.15143977536354214, 0.15619198442436755, 0.5187223374377936, 1.0481308889575303, 0.7570003671571612, 1.6287036356516182, 1.4713632222265005, 1.6358721884898841, 2.221315442584455, 2.0737717347219586, 5.308184064924717, 1.2660374399274588, 2.526392759755254, 1.4292719308286905, 1.1605368135496974, 0.36567521863617003, 1.783339900430292, 0.9937521850224584, 2.253136122599244, 1.566055566072464, 2.8747939271852374, 1.4404359692707658, 3.0534992879256606, 1.750315991230309, 1.5799682820215821, 0.9527719777543098, 3.562961700372398, 2.119607962667942, 1.8496265122666955, 4.056030604988337, 2.3975407239049673, 2.2006440768018365, 2.650153781287372, 2.396445907652378, 0.6577305751852691, 1.1716547794640064, 0.20959520945325494, 0.4002591816242784, 0.5217975005507469, 0.05355750639864709, 0.24348570965230465, 0.2624211920192465, 0.3233140823431313, 0.6413757184054703, 2.3345925891771913, 3.882190645672381, 6.109256604686379, 16.481199525296688, 27.840800173580647, 14.683770574629307, 19.37422938644886, 17.793138027191162, 22.79835294932127, 27.42393784224987, 32.27433197200298, 30.729013793170452, 25.289767161011696, 16.04107864201069, 4.235128294676542, 0.9961170237511396, 0.011671680440485943, 0.07918066330603324, 0.059289888449711725, 0.059603854024317116, 0.042760549040394835, 0.05634998917230405, 0.041874094458762556, 0.05425453149655368, 0.0120143365165859, 0.03919654067431111, 0.03895606627338566, 0.06420511766918935, 0.03048197177122347, 0.004545581696220324, 0.038134571877890266, 0.02469304177793674, 0.0903294728777837, 0.01921629620483145, 0.02589297953818459, 0.12208153391839005, 0.06763861936633475, 0.010880829322559293, 0.05136151739861816, 0.04313486235332675, 0.035908629797631875, 0.032283817272400483, 0.04054259989061393, 0.0303113056361326, 0.07214848752482794, 0.07566643820609897, 0.029211244254838675, 0.025808434074860997, 0.08973243733635172, 0.04819917419808917, 0.013231143293523928, 0.014599947480746778, 0.03988200311141554, 0.024709005374461412, 0.02660653040948091, 0.03537529650202487, 0.011925422586500645, 0.09352018096251413, 0.04006297211162746, 0.04252228623954579, 0.02613852651847992, 0.055338386227958836, 0.05883946047106292, 0.023675594420637935, 0.04176504698989447, 0.04739943957247306, 0.0631804640579503, 0.06119701502029784, 0.08100992374238558, 0.01305811341808294, 0.09077847964363173, 0.022357497473421972, 0.045788886345690116, 0.016245916922343895, 0.012966217909706756, 0.07675560671486892, 0.07091565406881273, 0.04558160078886431, 0.04360563259979244, 0.028879953242721967, 0.06432043257518671, 0.03373039668076672, 0.01700038610579213, 0.030575931377825327, 0.04669119320169557, 0.05292770503729116, 0.0474144346662797, 0.07904971134848893, 0.035707793504116125, 0.01869273699412588, 0.014602605297113769, 0.044363792112562805, 0.08013732134713791, 0.020795044692931697, 0.05393295890826266, 0.02537724813009845, 0.011025567600881914, 0.046033294129301794, 0.021197047535679303, 0.017909581947606057, 0.0473227868496906, 0.08685599168529734, 0.023859363172960002, 0.029200583303463645, 0.012852320505771786, 0.012000145725323819, 0.02306038553797407, 0.09572383263730444, 0.032454715328640305, 1.5266962093301117, 9.05559903010726, 19.59572710096836, 35.58613546192646, 39.19970355927944, 38.15254054963589, 32.4710588157177, 27.07790181040764, 26.802581883966923, 24.68193657696247, 18.207158111035824, 21.78029827773571, 20.265357568860054, 21.591072231531143, 18.131431974470615, 8.158108089119196, 6.657060859724879, 4.649652326479554, 2.887781630270183, 0.8720013150013983, 0.25404287909623235, 0.11683259057463147, 0.1872465602355078, 0.0527138143661432, 0.3081143042072654, 0.37706724484451115, 0.402785986661911, 0.5644838162697852, 1.3731625978834927, 2.1700127329677343, 1.9448172231204808, 2.3265548329800367, 1.3362304796464741, 2.56731228902936, 2.662403848953545, 3.031606050208211, 1.8736570165492594, 5.002526566386223, 2.198135261423886, 5.32772071659565, 3.4282192680984735, 3.3220999874174595, 3.2746695075184107, 3.879865170456469, 3.8370300689712167, 2.7778528165072203, 2.1604655077680945, 2.3092849971726537, 3.756713541224599, 2.6194060686975718, 2.006185711361468, 3.7379026506096125, 1.9764870987273753, 2.8485983703285456, 1.984180142171681, 1.6905656224116683, 1.8895335146225989, 1.0433551389724016, 0.6823072407860309, 0.4594974685460329, 0.19000194675754756, 0.12616725725820288, 0.11000391910783947, 0.12749409856041893, 0.3163772280095145, 0.35039739625062793, 0.718534734332934, 2.7906403178349137, 5.210651373490691, 6.838027099147439, 20.047667250037193, 31.041410230100155, 16.38117179274559, 21.983089596033096, 22.463256530463696, 24.45011291652918, 28.515385575592518, 34.78080667555332, 35.153247490525246, 31.070883348584175, 19.935134388506413, 6.3974730391055346, 1.298424289561808, 0.025000018176797312, 0.05111813748953864, 0.04761441748996731, 0.013004352240386652, 0.00611468736678944, 0.08357957296539098, 0.011538436174305389, 0.008820709936117055, 0.08182574441889301, 0.019410328859521542, 0.021948102839814965, 0.03410955992876552, 0.0572522960283095, 0.02321049789316021, 0.03613431690610014, 0.043601984943961725, 0.025618739273340907, 0.022204255110409576, 0.053937278207740746, 0.014845647529000416, 0.11361943994415924, 0.03266269850428216, 0.0393512673326768, 0.03597678121877834, 0.014776687166886404, 0.023693370712862816, 0.03035714809811907, 0.051595820841612294, 0.06246386110433377, 0.06869565288070589, 0.04493506399739999, 0.03056498841033317, 0.04602583925588988, 0.03655362663266715, 0.019481703056953847, 0.04777452842972707, 0.009096535613934975, 0.006015101816956303, 0.02387444175838027, 0.029517485927499365, 0.025100655257119797, 0.1380676991539076, 0.06359031511237845, 0.09893647118587978, 0.13971280306577682, 0.14199719298630953, 0.12422356507158838, 0.16463968815514818, 0.1784087688429281, 0.12950687727425247, 0.1774757556268014, 0.24730483128223568, 0.18783986277412623, 0.21407539170468226, 0.2488561425707303, 0.13939277414465323, 0.13461190334055573, 0.13701802032301202, 0.2718891261611134, 0.14399958163267002, 0.1380591792985797, 0.16447473841253668, 0.1321863420889713, 0.19163652701536193, 0.16557731752982363, 0.10299999688868411, 0.10876120766624808, 0.16083732421975583, 0.11215302292839624, 0.14183418767061085, 0.1358213962521404, 0.15683474368415773, 0.14744020794751123, 0.10659087100066245, 0.150653722230345, 0.20128603500779718, 0.12838421564083546, 0.12015883708954789, 0.1361008148523979, 0.15895531192654744, 0.1416649780003354, 0.13243270543171093, 0.19703902071341872, 0.12886833341326565, 0.14645325543824583, 0.23547535354737192, 0.11721225848305039, 0.11446405595052056, 0.238819693622645, 0.14058746863156557, 0.1306254422524944, 0.15425885299919173, 0.10930183256277815, 1.5724535915069282, 10.336064770817757, 23.110348507761955, 39.80390153825283, 46.964898481965065, 49.77125309407711, 40.409733429551125, 38.652008548378944, 35.98775111138821, 30.453059300780296, 24.989547170698643, 33.09093475341797, 31.93018063902855, 32.571498826146126, 22.371852435171604, 12.613977938890457, 10.467410422861576, 6.286094365641475, 3.921359656378627, 1.9210802530869842, 1.1259909672662616, 0.353981732041575, 0.6070839241147041, 0.5443432938773185, 0.9603545896243304, 1.2791229877620935, 2.790584983304143, 2.1247103763744235, 4.512882940471172, 4.808853333815932, 5.210457108914852, 6.099863508716226, 6.546112988144159, 12.29905178770423, 7.0646431390196085, 6.648897472769022, 5.81119442358613, 5.575322555378079, 3.012495213188231, 9.056491032242775, 4.561322266235948, 4.781110547482967, 3.3416404388844967, 6.0429914854466915, 4.974475996568799, 5.057181408628821, 4.029116649180651, 3.1889071594923735, 5.635950202122331, 7.2798859141767025, 5.831418363377452, 7.58896560408175, 9.077983628958464, 6.433498430997133, 6.50638896971941, 6.118375165387988, 5.8774015959352255, 4.180606920272112, 4.995963843539357, 1.6506783314980567, 1.7404863936826587, 2.2460813261568546, 0.5536252458114177, 0.8545341866556555, 1.3444670126773417, 0.7512487226631492, 1.3172446796670556, 3.682001712732017, 6.672934032976627, 8.602351751178503, 23.24169985949993, 37.48298227787018, 20.455539263784885, 30.728983394801617, 28.38019832968712, 33.807637095451355, 38.191188275814056, 42.59481757879257, 43.196188509464264, 33.3105743676424, 22.721207588911057, 7.46231222525239, 1.9100718875415623, 0.0932422540790867, 0.1573466623085551, 0.20286373706767336, 0.1510165582294576, 0.11993243751931004, 0.23181747092166916, 0.1181826982065104, 0.08206945087295026, 0.18839194643078372, 0.13595345400972292, 0.2368071227101609, 0.10506877064472064, 0.07859963588998653, 0.09203352557960898, 0.16510217974428087, 0.170001630904153, 0.20413467980688438, 0.09043357393238693, 0.15370889188488945, 0.20474429475143552, 0.2568188082659617, 0.20488531765295193, 0.18878261296777055, 0.17084482940845191, 0.11011779424734414, 0.13091810076730326, 0.06266345430049114, 0.13219686574302614, 0.15766581549542025, 0.22298404335742816, 0.11891628892044537, 0.13795486302115023, 0.1699422294041142, 0.060327674364089034, 0.20411731355125085, 0.12982617889065295, 0.08977842080639675, 0.07608984829857945, 0.08697820856468752, 0.07857804681407288, 0.11354939604643732, 0.27696369448676705, 0.1309706745087169, 0.1570243327296339], [0.034546480819699354, 0.03481825529888738, 0.009727031811053166, 0.015896506374701858, 0.01496269813287654, 0.08550674494472332, 0.014741024187969742, 0.027333228426869027, 0.04115198476938531, 0.06982385093579069, 0.05846512118296232, 0.02229153167718323, 0.02102052585541969, 0.041109808516921476, 0.03121221910987515, 0.009861265916697448, 0.045484776492230594, 0.05186471207707655, 0.05495094432262704, 0.0015206123498501256, 0.050478658522479236, 0.02514378516934812, 0.04940526436257642, 0.044708786881528795, 0.02295497830345994, 0.06678028104943223, 0.008326160350407008, 0.02660678088432178, 0.04217222631268669, 0.04635583893104922, 0.04573109530610964, 0.012388528302835766, 0.034476937871659175, 0.03007640661962796, 0.06350973271764815, 0.020471952557272743, 0.029666230875591282, 0.023195643807412125, 0.020599522176780738, 0.15303472493542358, 0.01712488694465719, 0.06821403614594601, 0.029161666934669483, 0.04016445338493213, 0.020424367903615348, 0.14592299092328176, 0.05567620442889165, 0.024905073369154707, 0.018078706270898692, 0.10457485652295873, 0.6044191983528435, 5.909163616597652, 14.076147079467773, 28.886840343475342, 36.75130873918533, 45.48551246523857, 35.47967277467251, 28.67577876895666, 21.061931625008583, 22.835456058382988, 21.182122975587845, 19.30510349571705, 17.918810583651066, 23.48461702466011, 13.747750651091337, 7.27009336464107, 9.009488504379988, 7.673954218626022, 4.182532941922545, 1.6725082788616419, 1.0762829845771194, 0.6007085193414241, 0.09619823569664732, 0.13587195135187358, 0.18722500826697797, 0.2821236097952351, 0.5374883429612964, 0.5506096326280385, 0.8662753191310912, 1.0310418996959925, 1.2618368840776384, 0.9404287557117641, 2.1409770660102367, 1.5138461301103234, 1.8639809545129538, 2.3791879462078214, 4.16265525855124, 1.7441251734271646, 2.171301576308906, 2.1534631960093975, 2.244023261591792, 1.2233938719145954, 1.924088504165411, 2.649678331799805, 1.8318275548517704, 1.1178830335848033, 0.7230381458066404, 2.0178536977618933, 1.8840783135965466, 1.5116845211014152, 2.5669976184144616, 0.6020409415941685, 2.4554353673011065, 1.997920204885304, 0.5903238547034562, 0.6290422333404422, 0.028696807894448284, 0.36250173579901457, 0.10890203760936856, 0.10903745729592629, 0.0637283620017115, 0.18697868945309892, 0.3018172999145463, 0.24934520304668695, 1.5125115704722703, 2.1955649368464947, 4.38353693112731, 10.870776828378439, 11.042350921779871, 17.772056758403778, 46.38041764497757, 35.31067304313183, 18.41436669230461, 20.14963287860155, 28.508867025375366, 32.86154866218567, 35.92057451605797, 29.795717373490334, 16.87650751322508, 7.360665779560804, 1.4705114741809666, 0.20037923444760963, 0.03429979093198199, 0.03896579954016488, 0.03285524500824977, 0.03374819709279109, 0.007460729884769535, 0.029204542661318555, 0.01620205228391569, 0.08360440522665158, 0.04767427541082725, 0.037673969054594636, 0.09684866134193726, 0.022205468521860894, 0.018083647119055968, 0.03551486850483343, 0.02233503822935745, 0.03953765772166662, 0.04532431674306281, 0.03827888249361422, 0.07028062056633644, 0.016198193115997128, 0.06081470877688844, 0.06563352930243127, 0.04023779612907674, 0.0456338108779164, 0.08484759164275602, 0.054147947957972065, 0.005623001543426653, 0.029594352017738856, 0.04194912558887154, 0.05889573752938304, 0.045812182361260056, 0.007462515677616466, 0.020178069498797413, 0.03328169048472773, 0.07020059478236362, 0.018491733717382886, 0.003630941969277046, 0.026865565923799295, 0.01577520975843072, 0.04047684560646303, 0.012035094387101708, 0.07626357022672892, 0.038490260994876735, 0.028186032177472953, 0.032368648462579586, 0.10693550953874364, 0.07233841795823537, 0.04643608735932503, 0.03834562383417506, 0.06992453811108135, 0.0438824017328443, 0.031013512780191377, 0.024204513792938087, 0.039033706052578054, 0.038901195584912784, 0.02737681661528768, 0.04121323050640058, 0.024889041123969946, 0.04235449407133274, 0.08078383587417193, 0.0226415767610888, 0.06767468774341978, 0.03117917869531084, 0.009693214924482163, 0.02748062452155864, 0.0045401538136502495, 0.043743801943492144, 0.0682926295849029, 0.00838092992125894, 0.014465270869550295, 0.030639123397122603, 0.023225479999382515, 0.03172446427925024, 0.04161209406447597, 0.04871936034760438, 0.06646953639574349, 0.07897568953922018, 0.04092170005606022, 0.009305587482231203, 0.00892127836777945, 0.037001338350819424, 0.03564855898730457, 0.04767108417581767, 0.04476702320971526, 0.05184187619306613, 0.03403137838176917, 0.03383279079571366, 0.06522453171783127, 0.05238841229584068, 0.03937907189538237, 0.05452643214084674, 0.04106241496629082, 0.03995286337158177, 0.07284754610736854, 1.200294317677617, 8.55411333963275, 18.510229848325253, 34.25082631409168, 44.368383809924126, 48.0566368997097, 39.67526324093342, 31.184751838445663, 23.644746132194996, 19.495334587991238, 22.112326361238956, 23.11457198113203, 23.510611429810524, 25.05745142698288, 17.640125937759876, 11.978897117078304, 12.696098182350397, 9.529972225427628, 3.8733254838734865, 1.7548839398659766, 0.7704927306622267, 0.2427982582594268, 0.09785482063307427, 0.12761690915795043, 0.21770830848254263, 0.388566852780059, 0.217627355013974, 0.874344720505178, 0.853850282728672, 1.1547144572250545, 0.8827762899454683, 2.0128916390240192, 2.2487732442095876, 2.722086296416819, 3.666144688613713, 1.8130011088214815, 4.233158575370908, 3.990481747314334, 2.8290517441928387, 2.5005142483860254, 2.1211430802941322, 4.265624508261681, 2.296893624588847, 1.6822001338005066, 2.4860557867214084, 1.737242080271244, 2.7419851161539555, 2.1342003671452403, 2.939800126478076, 2.326575256884098, 2.903309022076428, 2.0604769606143236, 2.3103615269064903, 2.0090379333123565, 1.4908482204191387, 1.247777994722128, 0.7114773255307227, 0.4587897565215826, 0.11888568275026046, 0.043168051197426394, 0.03291947788966354, 0.07392409068415873, 0.1194245413353201, 0.37914003361947834, 1.1539271869696677, 3.188866311684251, 5.189210074022412, 12.93677631765604, 11.353305336087942, 19.9667239934206, 50.341610088944435, 32.358782440423965, 19.171050488948822, 22.15524885803461, 28.224040009081364, 38.61325062811375, 41.37521222233772, 34.75054509937763, 20.660325475037098, 10.508232582360506, 1.9475801498629153, 0.210279380553402, 0.020932243678544182, 0.047296088087023236, 0.06578613712918013, 0.03470403877145145, 0.05342377509805374, 0.013713309217564529, 0.039163830515462905, 0.017172169173136353, 0.01861886918050004, 0.00202508862457762, 0.06218407885171473, 0.03256656440498773, 0.04216652290779166, 0.04359890132036526, 0.015109658215806121, 0.016554221765545662, 0.04340015417255927, 0.046392864678637125, 0.04035545251099393, 0.01776955909008393, 0.04083258296304848, 0.0298577346620732, 0.01577591108798515, 0.03976697764301207, 0.055683173195575364, 0.050163141859229654, 0.06504500619485043, 0.01145827402069699, 0.08316918014315888, 0.03823022358119488, 0.013143904761818703, 0.03532939837896265, 0.019649452551675495, 0.017872188836918212, 0.05270400317385793, 0.03610217077948619, 0.021150550128368195, 0.017339926089334767, 0.03316666501632426, 0.026236501144012436, 0.0462934985262109, 0.02199511232902296, 0.04548394899757113, 0.031274459324777126, 0.14375384169397876, 0.19722144061233848, 0.12064011985785328, 0.13248784700408578, 0.15312917064875364, 0.17413196474080905, 0.22245043917791918, 0.08415746109676547, 0.060119127156212926, 0.14028400444658473, 0.15853092219913378, 0.09498098734184168, 0.13408848142717034, 0.14605791337089613, 0.12619211920537055, 0.10216957816737704, 0.1478189110639505, 0.1565035677049309, 0.1990843054954894, 0.07210601441329345, 0.1497219706652686, 0.10334980819607154, 0.17357523523969576, 0.23796509573003277, 0.11018653196515515, 0.12642359506571665, 0.15025987930130213, 0.10734260722529143, 0.19290432304842398, 0.1487882449873723, 0.1392534581827931, 0.27020611334592104, 0.1292545470641926, 0.09833047792199068, 0.14760254533030093, 0.0791959218622651, 0.1385122159263119, 0.14498120552161708, 0.13315294490894303, 0.31167367415037006, 0.17646726599195972, 0.10410273185698316, 0.09070063577382825, 0.1605285462574102, 0.12248924016603269, 0.1705994308576919, 0.3110144688980654, 0.09997792702051811, 0.11594707480981015, 0.3067157417535782, 1.2925986084155738, 9.545360449701548, 21.251908130943775, 39.36292380094528, 49.32612977921963, 59.40399460494518, 49.150636196136475, 42.40889735519886, 30.99420726299286, 32.89609640836716, 31.939961314201355, 31.549199782311916, 29.439070411026478, 36.52835190296173, 25.328644774854183, 15.943547375500202, 15.290575213730335, 11.861539464443922, 6.282851239666343, 2.6987161254510283, 1.3833954487927258, 0.8348911406937987, 0.514871422201395, 0.7234333839733154, 0.9131478820927441, 1.08122818171978, 1.6146085294894874, 2.2493831114843488, 3.8457838492468, 4.890202218666673, 5.37823710590601, 3.1490959832444787, 6.423997990787029, 6.456699036061764, 6.135892225429416, 7.413189886137843, 9.245990663766861, 6.16777203977108, 6.526602935045958, 6.513605257496238, 7.51256262883544, 4.950945759192109, 4.9382492154836655, 5.863119587302208, 4.599488843232393, 2.925895960070193, 5.144410477951169, 6.703702881932259, 7.481144014745951, 4.879136737436056, 7.140138437971473, 4.71145648509264, 8.131730854511261, 6.340259984135628, 3.9203472482040524, 2.799064703285694, 1.8072876404039562, 1.0859944322146475, 0.7718855934217572, 0.24316513154190034, 0.7764379272703081, 0.3655638371128589, 0.5293880682438612, 0.6828223506454378, 2.163740932010114, 3.8653010269626975, 6.698118131607771, 15.291743651032448, 16.499634236097336, 25.36901380866766, 56.46785415709019, 41.77125357091427, 27.047112062573433, 30.91026596724987, 38.913552314043045, 44.582118541002274, 47.67344646155834, 39.810961559414864, 23.650124743580818, 10.704367607831955, 2.5881791068241, 0.35542137979064137, 0.2254329525749199, 0.11733039355021901, 0.21190420899074525, 0.13617445074487478, 0.12444512583897449, 0.17277278064284474, 0.21928482310613617, 0.14082612848142162, 0.22079482645494863, 0.06970957503654063, 0.22436106868553907, 0.20761775696882978, 0.13896022079279646, 0.15143112192163244, 0.12072594923665747, 0.1861602786812, 0.1640472761937417, 0.20146995404502377, 0.21900632476899773, 0.08864473085850477, 0.15145672601647675, 0.1852068564039655, 0.12369550473522395, 0.20749524323036894, 0.15713256754679605, 0.1132576577947475, 0.1290983843500726, 0.11471410034573637, 0.18566345534054562, 0.1643980003427714, 0.1561227420461364, 0.14373985963175073, 0.1576351499534212, 0.1218590974167455, 0.137075477396138, 0.059565614865277894, 0.08755783332162537, 0.09591880967491306, 0.10785723468870856, 0.08846727592754178, 0.14210581372026354, 0.13133877975633368, 0.08097778874798678, 0.10844019911019132], [0.03542469014064409, 0.06861320769530721, 0.03473196207778528, 0.017060049212886952, 0.0621461291302694, 0.05504599859705195, 0.017968643915082794, 0.014283296259236522, 0.06989002082264051, 0.05107261044031475, 0.015078509350132663, 0.042289630364393815, 0.04708685810328461, 0.031959090556483716, 0.034587655172799714, 0.008381474472116679, 0.05072991632914636, 0.02457060410961276, 0.04084746673470363, 0.04103511877474375, 0.06745003964169882, 0.048362068191636354, 0.05809559843328316, 0.18832818110240623, 0.015476004573429236, 0.01579310293891467, 0.04256061074556783, 0.061077258360455744, 0.09579118253896013, 0.03221463426598348, 0.0300844756202423, 0.0227289312533685, 0.10686962908948772, 0.03244456645916216, 0.008272931663668714, 0.012335459177847952, 0.08707999411853962, 0.03151376855385024, 0.06479210453107953, 0.08629483898403123, 0.02679070548765594, 0.03547044354490936, 0.05850980589457322, 0.05126257427036762, 0.10132986033568159, 0.09774021076736972, 0.018852567773137707, 0.033870042898342945, 0.10664016444934532, 0.006420448962671799, 0.041785341018112376, 1.0408764844760299, 5.004255948588252, 15.68684360012412, 30.33419217914343, 50.635721907019615, 47.74993255734444, 35.13795331120491, 25.370417833328247, 27.690731026232243, 27.30573568493128, 22.00243815779686, 22.819933891296387, 24.273038618266582, 11.80070947855711, 12.5730674341321, 14.622984286397696, 12.188930846750736, 10.487439148128033, 4.3163608107715845, 3.024725094437599, 1.5331693994812667, 0.48354082682635635, 0.2096835695556365, 0.22559986158739775, 0.15470237529370934, 0.3972486744169146, 0.540111567825079, 0.45482888468541205, 1.0487375501543283, 0.4982790781650692, 1.4217103365808725, 0.4479158384492621, 1.3753029517829418, 3.2250660192221403, 0.24839587742462754, 4.635178428143263, 3.2167197670787573, 2.479315185919404, 1.4280393719673157, 1.2493730778805912, 3.981544626876712, 1.4287189417518675, 0.38910360366571695, 1.2133545731194317, 1.8545274180360138, 2.605434455908835, 1.3298360165208578, 0.9814506419934332, 1.1204096605069935, 2.463071057572961, 1.121061088051647, 1.3192261545918882, 1.0162102268077433, 0.1720306181232445, 0.5330043460708112, 0.2848358923802152, 0.37712344026658684, 0.08626679322333075, 0.11139762791572139, 0.09630840009776875, 0.317796214367263, 0.5175008811056614, 1.7560945311561227, 2.252897210419178, 5.626207999885082, 8.623764552175999, 12.838145960122347, 18.95539116114378, 22.30970297008753, 44.779890328645706, 45.962048694491386, 27.932010479271412, 26.077430695295334, 34.21809867024422, 32.47916378080845, 30.940609239041805, 18.293726965785027, 8.562615383416414, 2.1112187253311276, 0.21898469858570024, 0.022154553480504546, 0.04939370170177426, 0.03387652926903684, 0.02191193798353197, 0.07407467986922711, 0.038678566124872304, 0.017428334431315307, 0.05556054071348626, 0.059809521699207835, 0.05592700581473764, 0.04021113818453159, 0.016481443053635303, 0.06682378574623726, 0.015794954597367905, 0.02989251726830844, 0.011229764895688277, 0.0475551495765103, 0.014531670822179876, 0.058011409200844355, 0.07471375065506436, 0.03620097289967816, 0.024313106696354225, 0.012005915923509747, 0.022338706294249278, 0.02621464489493519, 0.0827535403368529, 0.0062145284937287215, 0.01121755192798446, 0.015690436084696557, 0.027020021698263008, 0.01685106413788162, 0.04419228920596652, 0.05724480404751375, 0.055445626567234285, 0.09083714641747065, 0.04109261295525357, 0.03104719700786518, 0.009696473880467238, 0.023393372357531916, 0.018789244022627827, 0.016827359941089526, 0.004715390650744666, 0.010378071583545534, 0.043001286903745495, 0.015575149009237066, 0.09395587359904312, 0.13730039267102256, 0.0251293819383136, 0.03881375945638865, 0.004853635136896628, 0.01767110763466917, 0.03174391225911677, 0.05901987286051735, 0.04605248606821988, 0.02419845786789665, 0.02499195845302893, 0.03061879782762844, 0.016554867434024345, 0.04959037454682402, 0.04117329553992022, 0.06056652346160263, 0.02313452794624027, 0.025573657512723003, 0.03902116746758111, 0.022252105081861373, 0.08270754202385433, 0.05169474541617092, 0.014301728424470639, 0.14392005308764055, 0.03818396551650949, 0.05678067231201567, 0.02912543528509559, 0.04132786634727381, 0.03552946654963307, 0.02925593824329553, 0.02417915646219626, 0.02891494550567586, 0.08946734218625352, 0.02553855207224842, 0.039878552124719135, 0.04099536934518255, 0.03400262758077588, 0.052306100697023794, 0.001573888000621082, 0.023601509528816678, 0.008263009149231948, 0.025485076621407643, 0.018975714192492887, 0.011162139471707633, 0.13009882910409942, 0.03302497789263725, 0.06584354967344552, 0.0332790855463827, 0.09429459722014144, 0.051527324321796186, 0.0545018522097962, 1.5611413610167801, 7.3330730851739645, 20.09739328175783, 36.18952788412571, 56.63860559463501, 53.10247354209423, 41.65425404906273, 29.859818033874035, 29.211261235177517, 29.015153758227825, 25.64778584986925, 23.83010968565941, 33.43980923295021, 16.365157552063465, 15.874030105769634, 16.20219949632883, 14.66265320777893, 11.426189225167036, 5.605795020237565, 2.939638872630894, 1.2840091693215072, 0.6042776559479535, 0.3061552718281746, 0.10527203005040064, 0.12086792208719999, 0.3311955719254911, 0.17512987134978175, 0.2857290819520131, 0.5576609855052084, 0.5049056257121265, 1.2414680770598352, 1.5609504212625325, 2.2817913349717855, 2.281742412596941, 1.7173075187020004, 3.643555138260126, 3.577963770367205, 2.941620466299355, 2.2970907390117645, 1.6173659940250218, 3.132211114279926, 4.1017260029911995, 3.1293156696483493, 1.9838866079226136, 1.9842046033591032, 1.5606993972323835, 3.2191264629364014, 0.9894240985158831, 2.8057426074519753, 1.2438532803207636, 1.1061274143867195, 2.0739405881613493, 1.498763314448297, 0.6094262015540153, 0.6860621517989784, 0.4155073477886617, 0.21065674780402333, 0.057228658624808304, 0.18468447349732742, 0.1451773551525548, 0.19316207093652338, 0.7187346392311156, 1.8053846550174057, 3.189883232116699, 6.755110323429108, 12.04825384542346, 16.33918784558773, 21.563468612730503, 23.43017164617777, 48.92877750098705, 47.08637036383152, 25.317670963704586, 28.188386522233486, 37.160843163728714, 36.60255812108517, 35.05474537611008, 23.14350552856922, 11.580782979726791, 3.4168127551674843, 0.395026981132105, 0.022138510103104636, 0.04973254406650085, 0.059548679055296816, 0.03443471337959636, 0.06475827001850121, 0.05860139433934819, 0.07728689539362676, 0.016329755490005482, 0.06213067019416485, 0.02434423608065117, 0.014242706347431522, 0.09245781882782467, 0.07083282296662219, 0.03485207496851217, 0.025993891213147435, 0.04949157242663205, 0.0050828845542127965, 0.04466673679416999, 0.12902719754492864, 0.08017162341275252, 0.025702726270537823, 0.0341418322204845, 0.030149658450682182, 0.07225518609629944, 0.009990299422497628, 0.06319515116047114, 0.03896341353538446, 0.03749078474356793, 0.01592375247128075, 0.004498456710280152, 0.03174804602167569, 0.038449821367976256, 0.047118729635258205, 0.011627349176706048, 0.07863969702157192, 0.06324071160634048, 0.022117440530564636, 0.051261520420666784, 0.07417410539346747, 0.02443681900331285, 0.05119074550748337, 0.014456225944741163, 0.03867737868858967, 0.020374143059598282, 0.04109297660761513, 0.18546136852819473, 0.26033082918729633, 0.10925482492893934, 0.18055471853585914, 0.12952841439982876, 0.14663628389826044, 0.12514083733549342, 0.13080415141303092, 0.14123902976280078, 0.11619012817391194, 0.15198403678368777, 0.11848604364786297, 0.16488404769916087, 0.11990154191153124, 0.10099539664224721, 0.10055797480163164, 0.07812627925886773, 0.15158989699557424, 0.1391098229214549, 0.1998836430720985, 0.21369680733187124, 0.12453938601538539, 0.17688104300759733, 0.34008914313744754, 0.142956240742933, 0.10942968976451084, 0.11061450626584701, 0.1205155800562352, 0.22007394873071462, 0.04096263321116567, 0.16826092352857813, 0.06690052381600253, 0.17564368987223133, 0.06375523516908288, 0.09926529455697164, 0.11431737046223134, 0.1918499983730726, 0.1511526681133546, 0.10737885371781886, 0.12575886823469773, 0.07471648917999119, 0.19981560297310352, 0.14813831658102572, 0.15091221226612106, 0.20563938422128558, 0.15662959922337905, 0.13401021453319117, 0.13303195999469608, 0.30404721619561315, 0.099811916006729, 0.16832795430673286, 1.504876355174929, 8.161551654338837, 22.507425360381603, 44.56485986709595, 62.075038477778435, 61.45806938409805, 49.09435361623764, 38.90695586800575, 38.079470470547676, 38.28776769340038, 31.762676127254963, 33.605632334947586, 39.135384410619736, 21.52854658663273, 24.033225886523724, 22.08169810473919, 19.168384931981564, 14.973365385085344, 7.328715668991208, 4.470619233325124, 2.6106413640081882, 1.018435601145029, 0.6506982806604356, 0.6375624448992312, 0.6335239741019905, 0.9441994596272707, 1.6439928277395666, 1.485167525243014, 2.7039562817662954, 2.6352222450077534, 3.7532079918310046, 4.455897398293018, 4.7147580329328775, 8.391182832419872, 3.9959667529910803, 12.552498187869787, 10.98366117104888, 8.08794105425477, 6.137954089790583, 5.620283167809248, 10.420714728534222, 5.781518965959549, 5.439414298161864, 4.614307573065162, 6.1653354205191135, 5.821679960936308, 5.29504057019949, 4.867219626903534, 6.176657387986779, 6.993121476843953, 4.1227892227470875, 4.615496909245849, 3.770207092165947, 3.113440596498549, 2.129347315058112, 1.4618513826280832, 1.1849206988699734, 0.5548494926188141, 0.5015749856829643, 0.2760119049344212, 0.6240576726850122, 1.340541229583323, 2.652860898524523, 3.4118335973471403, 8.401849810034037, 12.968330774456263, 21.582556888461113, 27.885098196566105, 29.639880135655403, 54.260453805327415, 52.172686234116554, 37.73294806480408, 35.11552311480045, 44.36833441257477, 42.581476494669914, 39.99902866780758, 25.261758863925934, 12.592478692531586, 3.7885038228705525, 0.5390482186339796, 0.09153621242148802, 0.12440062666428275, 0.10504805730306543, 0.09568887748173438, 0.17756698041921481, 0.16078927757916972, 0.1651926920749247, 0.14181955251842737, 0.1665686783962883, 0.15204873721813783, 0.15102636942174286, 0.14787215273827314, 0.1579158747335896, 0.12142622494138777, 0.12338404019828886, 0.12131275798310526, 0.1642189794802107, 0.09295459021814167, 0.15166736237006262, 0.15666465827962384, 0.13439144095173106, 0.11453773637185805, 0.10838775895535946, 0.13140536524588242, 0.08445016414043494, 0.2044278578250669, 0.11749892786610872, 0.1485646507353522, 0.12722550047328696, 0.09685940021881834, 0.12555364955915138, 0.14899647678248584, 0.14982502529164776, 0.1410986451082863, 0.22794455842813477, 0.19158522976795211, 0.10933958561508916, 0.1408692917902954, 0.10968573071295395, 0.06146708255982958, 0.11719518908648752, 0.07970177714014426, 0.12965987843926996, 0.19106749270576984, 0.07098162357578985], [0.020916608482366428, 0.07930075022159144, 0.04086796114279423, 0.06743507052306086, 0.019934674746764358, 0.07181717053754255, 0.036724049714393914, 0.01743294131301809, 0.05030563050240744, 0.06704202911350876, 0.040392871596850455, 0.021980705387250055, 0.05449941054394003, 0.06947897491045296, 0.03912402542482596, 0.026372186148364563, 0.032134404391399585, 0.010224281886621611, 0.052716705031343736, 0.04929403126880061, 0.040142964498954825, 0.03529325207637157, 0.016966430994216353, 0.05375905515393242, 0.005910194604439312, 0.02794697898934828, 0.05756974969699513, 0.0623823213391006, 0.024304360485984944, 0.035799333709292114, 0.00824843058580882, 0.053215981170069426, 0.016303216289088596, 0.03315880567242857, 0.04560993969789706, 0.015009407979960088, 0.04513016720011365, 0.06870579803944565, 0.005261100186544354, 0.018789023233694024, 0.032029987924033776, 0.032584565196884796, 0.08175324401236139, 0.022141024128359277, 0.03393706625502091, 0.0553304489585571, 0.03563005353498738, 0.06849021156085655, 0.09221896601957269, 0.0459878561377991, 0.024143932278093416, 0.04193558510451112, 1.3600647007115185, 5.506945224478841, 11.703122165054083, 29.4176072627306, 31.49889998137951, 41.89890772104263, 37.85682141780853, 32.489115446805954, 32.34788462519646, 21.069472320377827, 21.46486960351467, 25.05330964922905, 26.381763964891434, 24.63286031037569, 24.533985815942287, 17.94637620449066, 12.928518410772085, 9.051002226769924, 8.130185287445784, 4.587250174954534, 2.18671758659184, 0.7434777833987027, 0.6466623034793884, 0.24506194225978106, 0.24688698729733005, 0.11517851409735158, 0.12216621296829544, 0.18807868589647114, 0.31992098316550255, 0.9486807254143059, 0.8915691368747503, 1.8193377438001335, 1.4907970419153571, 1.0947389504872262, 0.833815501537174, 1.345972919370979, 1.8030009954236448, 0.7658771064598113, 1.4520599017851055, 2.4157700082287192, 3.4161333041265607, 1.4530166191980243, 1.2074587144888937, 0.7235503464471549, 1.0886900313198566, 0.9251571970526129, 0.8422448742203414, 2.338634147308767, 0.5168837704695761, 0.6355509872082621, 0.9793377772439271, 0.6945081485901028, 0.32980321382638067, 0.438518556766212, 0.05825583924888633, 0.12372535391477868, 0.2087746316101402, 0.12178195858723484, 0.5319868912920356, 0.8569455135148019, 1.2938977824524045, 3.2016894361004233, 6.17388591170311, 11.80956395342946, 11.15155041217804, 21.655746661126614, 17.394617311656475, 14.912965726107359, 29.536064006388187, 41.60094290971756, 34.27273973822594, 31.19004875421524, 31.592479459941387, 30.439841710031033, 15.640983860939741, 7.905857199802995, 2.4236536351963878, 0.33436739235185087, 0.023019502477836795, 0.07851486036088318, 0.030709404782101046, 0.04480599338421598, 0.04642635780328419, 0.026473107100173365, 0.012444714448065497, 0.06003101196256466, 0.04268704302376136, 0.04911001946311444, 0.04169248350081034, 0.01020457137201447, 0.07294421084225178, 0.025277137974626385, 0.04053042866871692, 0.02674975748959696, 0.014756401487829862, 0.023286649666260928, 0.039686610471108, 0.09109535443712957, 0.05464198453410063, 0.042123738094232976, 0.019800694826699328, 0.04498245754803065, 0.05013162655814085, 0.04799186637683306, 0.09951033687684685, 0.025729332264745608, 0.05714083286875393, 0.0567081830376992, 0.01230812866197084, 0.03898870592820458, 0.049069045489886776, 0.04829922312637791, 0.013877785841032164, 0.04493150539929047, 0.022989206154306885, 0.047229732663254254, 0.06225489829375874, 0.0311064834750141, 0.03275935581768863, 0.03415610372030642, 0.02578943138360046, 0.04925909095618408, 0.020048577716806903, 0.036304290988482535, 0.004020631422463339, 0.0863343731907662, 0.04953124764142558, 0.011160887097503291, 0.022885337020852603, 0.09827220448642038, 0.07784804809489287, 0.06107457178586628, 0.023211076768347993, 0.09928936982760206, 0.015542856308456976, 0.019419596428633668, 0.09488322422839701, 0.07716202904703096, 0.04688724635343533, 0.012913988339278148, 0.0410673539590789, 0.02586486141808564, 0.03477776001091115, 0.030093168024905026, 0.09731216967338696, 0.03386269192560576, 0.025068438626476564, 0.09794604542548768, 0.01847520052251639, 0.06707512147841044, 0.02550274530221941, 0.013278261321829632, 0.01750586845446378, 0.03442840512434486, 0.08954704884672537, 0.05116565720527433, 0.01978969248739304, 0.024712805170565844, 0.027216278940613847, 0.13642799807712436, 0.014564419016096508, 0.03357076442625839, 0.012511854693002533, 0.028482026646088343, 0.02133156365744071, 0.007360398940363666, 0.05378467409173027, 0.021530021367652807, 0.07785834910464473, 0.031773698356118985, 0.013984887027618242, 0.04240748341544531, 0.0427023720840225, 0.01042498088281718, 0.053084376122569665, 0.12307145501836203, 1.9088736455887556, 7.512745019048452, 18.173130936920643, 37.58819103240967, 40.026801377534866, 46.47573933005333, 39.78988789021969, 36.51805065572262, 36.321658194065094, 21.842335648834705, 23.27351365238428, 25.929947309195995, 23.875587545335293, 25.61632353812456, 26.769996732473373, 25.64449902623892, 16.462092250585556, 11.214259397238493, 9.214903581887484, 5.8958918787539005, 1.8364123650826514, 0.8502034877892584, 0.6373919290490448, 0.19920845195883885, 0.029089563577144872, 0.1614858870743774, 0.09751439749379642, 0.22840687190182507, 0.17784837313229218, 0.6681259861215949, 0.38093327020760626, 0.6526041752658784, 1.42236354527995, 1.3923052581958473, 1.8490792228840292, 1.5710024256259203, 1.1987179960124195, 2.0528080221265554, 1.1246078414842486, 1.8062372342683375, 2.031772588379681, 2.111733122728765, 1.8833964876830578, 1.4972694008611143, 1.987157401163131, 1.4172931923530996, 0.9592588234227151, 1.5501718246378005, 0.643133302219212, 0.43203669833019376, 0.6439155852422118, 0.08001442911336198, 0.3464245906798169, 0.74798250105232, 0.22992710204562172, 0.14816544950008392, 0.06894859165186062, 0.20109227509237826, 0.457664571586065, 1.2507442105561495, 1.9834660179913044, 4.185684872791171, 7.550970017910004, 14.266225229948759, 12.82802615314722, 23.355798237025738, 22.5322038307786, 18.09297613799572, 34.17627431452274, 44.589022770524025, 37.51312606036663, 34.34016332030296, 38.75986196100712, 35.771896094083786, 20.425705164670944, 10.787231661379337, 3.6409786390140653, 0.5766641220543534, 0.020067710283910856, 0.07771774180582725, 0.016755288124841172, 0.026400489805382676, 0.03709493059432134, 0.02883070061216131, 0.013065792791167041, 0.012707704681815812, 0.04576061051920988, 0.08803371325484477, 0.027274103376839776, 0.033002464842866175, 0.04261927380866837, 0.03285121885710396, 0.014752148981642677, 0.02653294832271058, 0.05424356997536961, 0.03290796717919875, 0.07940271389088593, 0.09386734280269593, 0.005930817960688728, 0.034770947095239535, 0.009319117762061069, 0.04059839826368261, 0.034055457363137975, 0.022826954118499998, 0.03701789566548541, 0.054732166609028354, 0.005150659335413366, 0.03596209040551912, 0.049272831820417196, 0.07733892736723647, 0.03234626528865192, 0.021492318410309963, 0.03745243797311559, 0.05638839160383213, 0.015382472629426047, 0.03860815857478883, 0.058768819144461304, 0.015947042920743115, 0.013288574391481234, 0.019960481076850556, 0.009533390639262507, 0.041501636515022255, 0.09167014781269245, 0.024497938575223088, 0.09602294783690013, 0.2193412114866078, 0.08556392742320895, 0.20076164830243215, 0.09294325762311928, 0.16145395988132805, 0.17587743670446798, 0.13721740571781993, 0.12782178644556552, 0.23585016780998558, 0.13314473675563931, 0.10867311473703012, 0.19931125425500795, 0.2253191961790435, 0.10158854332985356, 0.13889954279875383, 0.21114944480359554, 0.0890405553218443, 0.16839292191434652, 0.14539147960022092, 0.15165777382208034, 0.07980630864039995, 0.15270841744495556, 0.1668674818938598, 0.06916720609297045, 0.16898233559913933, 0.11763686343329027, 0.07873197566368617, 0.16326950542861596, 0.14523678633850068, 0.18918913177913055, 0.2119334792951122, 0.08765554448473267, 0.10901671426836401, 0.1397414054372348, 0.1597950520226732, 0.1461558768642135, 0.14049131597857922, 0.19812381797237322, 0.08529653903678991, 0.10172940295888111, 0.08093224314507097, 0.1759681271505542, 0.06704911662382074, 0.2015280196792446, 0.0940729548165109, 0.1276072463952005, 0.15740052738692611, 0.2117957515292801, 0.16406878363341093, 0.10735623305663466, 0.37627106881700456, 2.16310802847147, 8.57670882716775, 20.96992526203394, 40.33358171582222, 45.51920905709267, 54.285475462675095, 52.49933570623398, 41.85178264975548, 47.360841035842896, 28.99006560444832, 32.20179386436939, 37.57719822227955, 37.40594521164894, 39.329876974225044, 35.08877255022526, 27.13131934404373, 19.36328787356615, 14.13824524730444, 10.998268537223339, 7.16762188822031, 3.093566237948835, 1.3592745806090534, 1.1411046562716365, 0.806791945360601, 0.8904257544782013, 0.7633771374821663, 0.7773590215947479, 0.8586066181305796, 1.6610029712319374, 3.1055994797497988, 2.7644435735419393, 4.1968282498419285, 5.013420581817627, 3.9050487941130996, 5.3343903087079525, 5.36351622082293, 6.097072558477521, 7.2645162139087915, 2.576195737347007, 7.364222863689065, 7.2999887354671955, 6.571714589372277, 5.9440552443265915, 2.984552700072527, 5.426637958735228, 4.369815867394209, 2.5693461298942566, 6.847515664994717, 2.1735638799145818, 2.9482259368523955, 4.399511273950338, 2.0729744900017977, 1.3886048505082726, 1.8076988495886326, 0.6755068525671959, 0.49585305678192526, 0.38858104264363647, 0.5014683539047837, 0.8366926002781838, 1.452278271317482, 2.2855873312801123, 4.571344703435898, 9.742396026849747, 17.19244346022606, 17.460277788341045, 31.956213042140007, 28.697032928466797, 22.110686749219894, 40.56421793997288, 50.74972718954086, 42.65456937253475, 44.6361668407917, 43.54547716677189, 40.593886747956276, 21.808825246989727, 11.816017907112837, 3.9623235957697034, 0.6379870127420872, 0.1285075902706012, 0.30609910609200597, 0.20372551894979551, 0.13843635359080508, 0.09650984124164097, 0.16400685883127153, 0.14793309790547937, 0.09901553959934972, 0.11722639639629051, 0.18376757972873747, 0.1344332832377404, 0.1702204457251355, 0.1920756112667732, 0.13656639377586544, 0.11150436359457672, 0.10776153474580497, 0.15717240603407845, 0.14777763281017542, 0.19071029702899978, 0.28895760246086866, 0.08997597309644334, 0.17341613362077624, 0.1954606655635871, 0.15007910697022453, 0.1633828759077005, 0.24363724136492237, 0.14618140674429014, 0.14301481103757396, 0.13440793147310615, 0.1701189941377379, 0.2192466173437424, 0.13144309603376314, 0.12932099896715954, 0.08913701225537807, 0.058632178624975495, 0.22385582939023152, 0.11632707668468356, 0.09736191583215259, 0.15578086429741234, 0.129110733687412, 0.12313519066083245, 0.08872529098880477, 0.1283778331708163, 0.22990792494965717, 0.19825412426143885, 0.12689096998656169], [0.07914449102827348, 0.0491054033045657, 0.0487533507111948, 0.06561030008015223, 0.036699414122267626, 0.026270205780747347, 0.05113401202834211, 0.03992937068687752, 0.030573062977055088, 0.03320935335068498, 0.05297393712680787, 0.05305213351675775, 0.03238692013837863, 0.05052314285421744, 0.026022847960121, 0.09389973012730479, 0.05358704016543925, 0.02237287106254371, 0.0232114960817853, 0.030747115160920657, 0.03374981868546456, 0.029159284640627448, 0.037314524670364335, 0.010693571548472391, 0.1137798180570826, 0.030794022604823112, 0.014173784020385938, 0.07615016264026053, 0.046085485664661974, 0.07542688777903095, 0.05568685053731315, 0.0448096855689073, 0.019186454446753487, 0.057259999521193095, 0.074567228439264, 0.021036389262008015, 0.05403932351327967, 0.05453273297462147, 0.02636073109897552, 0.0274479440486175, 0.031542508222628385, 0.036204234638717026, 0.015396968628920149, 0.11264430242590606, 0.05022082528739702, 0.011581732142076362, 0.03914287968655117, 0.05506538349436596, 0.020048885708092712, 0.09261376631911844, 0.05288290529279038, 0.07299806107766926, 0.1354644083767198, 0.3138234978541732, 2.5015580048784614, 11.94758489727974, 22.934341952204704, 32.60962218046188, 41.62466123700142, 41.51165150105953, 37.685473412275314, 26.018495857715607, 25.575686618685722, 24.842607155442238, 16.371930688619614, 28.528263084590435, 22.215587720274925, 21.023223102092743, 22.91875708848238, 13.153253551572561, 9.46014242246747, 7.024121638387442, 4.595741294324398, 3.037181538529694, 1.2083333800546825, 0.9158114797901362, 0.41306116967462003, 0.20644862204790115, 0.13834174460498616, 0.1459925004746765, 0.18701524764765054, 0.5481896374840289, 0.30585045693442225, 0.6419636181090027, 0.5027121340390295, 0.5577461246866733, 0.8726126071996987, 0.8543607615865767, 0.3808404423762113, 0.6890509289223701, 0.88980324100703, 1.1855229665525258, 1.337190878111869, 2.7608449291437864, 1.0327911120839417, 0.9366430307272822, 1.3312757830135524, 1.0381617676466703, 0.05134619575983379, 0.8527749998029321, 0.6408218387514353, 0.4161904501961544, 0.24182466440834105, 0.32218563195783645, 0.22397007560357451, 0.28148524404969066, 0.13364271784666926, 0.37446485948748887, 0.4339760192669928, 0.6410878244787455, 1.3465477572754025, 1.9963188283145428, 4.437345368787646, 5.730981677770615, 10.804648976773024, 14.550035800784826, 16.69077727943659, 12.610823158174753, 16.051433086395264, 18.48574586212635, 22.314418517053127, 33.19478318095207, 37.92298346757889, 35.26736296713352, 26.155748292803764, 18.920493833720684, 6.956319026648998, 1.9855810794979334, 0.3730178496334702, 0.08209306601202115, 0.07266633590916172, 0.048460243197041564, 0.019528937045834027, 0.06394515075953677, 0.06231917199329473, 0.014318604862637585, 0.06999587334576063, 0.044512678068713285, 0.056297426563105546, 0.06054567653336562, 0.08769990265136585, 0.018360839276283514, 0.04965061096299905, 0.069364854862215, 0.03975616826210171, 0.05192202814214397, 0.030282243133115117, 0.08068644383456558, 0.04931459989165887, 0.011374009645805927, 0.06962713727261871, 0.05752933233452495, 0.031765093153808266, 0.030821738109807484, 0.03738044964848086, 0.05715762024919968, 0.04412814167153556, 0.042667836241889745, 0.02621303628984606, 0.010186470390181057, 0.09187725896481425, 0.015618028446624521, 0.007419456269417424, 0.047566330031258985, 0.021328860384528525, 0.0272895678790519, 0.05000214776373468, 0.05570291803451255, 0.04634386808902491, 0.03329525323351845, 0.035384209695621394, 0.026131106897082645, 0.008318571890413295, 0.04236598251736723, 0.06337909246212803, 0.096119560621446, 0.07166336785303429, 0.06106643042585347, 0.0441308542212937, 0.07028153340797871, 0.0424240629945416, 0.08884750786819495, 0.04789699392858893, 0.0649087478814181, 0.023751482731313445, 0.04523862837231718, 0.032858399135875516, 0.012371275224722922, 0.022492889329441823, 0.008072600030573085, 0.04587284922308754, 0.05746101393015124, 0.023412625523633324, 0.015815705046406947, 0.06183984849485569, 0.05809007314383052, 0.038394520233850926, 0.04914772056508809, 0.07577297350508161, 0.03281162898929324, 0.056868802348617464, 0.007317512545341742, 0.057439079755567946, 0.09851755108684301, 0.06030756216205191, 0.021364431522670202, 0.05443418318463955, 0.06902670269482769, 0.03281727673311252, 0.02266442377731437, 0.04486172867473215, 0.020874421097687446, 0.08100340768578462, 0.028047840569342952, 0.050064313763868995, 0.04502375435549766, 0.03926235804101452, 0.009680029743321938, 0.02987997497257311, 0.030661410091852304, 0.07731094097835012, 0.00971239294813131, 0.08009256984223612, 0.002684276018953824, 0.14831609063548967, 0.023149912667577155, 0.053411499975482, 0.020132763238507323, 0.12663212371990085, 0.5625916959252208, 4.4935662019997835, 18.312473259866238, 28.601038679480553, 41.9384104013443, 46.36514626443386, 47.39954195916653, 40.114515870809555, 28.988585583865643, 27.157157957553864, 27.172790318727493, 19.85304929316044, 34.17544975876808, 29.528002738952637, 22.74957686662674, 22.186372987926006, 16.810037679970264, 13.605213649570942, 9.566411320120096, 6.110775573179126, 4.1809118539094925, 1.6576472762972116, 0.5262720573227853, 0.30069722095504403, 0.1195993393776007, 0.07088835787726566, 0.07248318870551884, 0.11844904758618213, 0.3951798932394013, 0.021735872724093497, 0.4801210103323683, 0.4769573832163587, 0.4233626544009894, 0.3598655085079372, 1.0011591156944633, 0.819143004482612, 1.0033062379807234, 1.89178655622527, 1.0869391565211117, 1.170646883547306, 1.088541008066386, 1.0301320860162377, 0.7427047623787075, 0.8337197348009795, 1.1922654672525823, 1.255851136520505, 0.395765655557625, 0.19438714894931763, 0.4866261128336191, 0.373155236011371, 0.2337709817220457, 0.1172674965346232, 0.120666696166154, 0.1467296460759826, 0.27005216223187745, 0.5971703154500574, 0.7443305407650769, 1.9495353824459016, 2.299280846491456, 5.56855084374547, 8.764414004981518, 13.259385656565428, 18.672826923429966, 21.374385058879852, 20.259606577455997, 19.558608792722225, 19.962612614035606, 26.67501512914896, 39.51140083372593, 41.53668835759163, 39.79644253849983, 30.890366435050964, 23.66535432636738, 9.412276390939951, 3.3187312306836247, 0.5857832171022892, 0.15870595030719414, 0.00854565980262123, 0.04286066847271286, 0.026358920258644503, 0.030506076727760956, 0.042354330798843876, 0.037620400835294276, 0.048498126125195995, 0.02933353534899652, 0.044976861754548736, 0.03922905045328662, 0.03867033570713829, 0.04035639503854327, 0.0917971292801667, 0.04323728986491915, 0.028733774270222057, 0.013541479765990516, 0.0871897280740086, 0.03936845176212955, 0.010158532240893692, 0.04415301475091837, 0.03457531696767546, 0.04601338230713736, 0.07290427587577142, 0.0386447501659859, 0.03296723880339414, 0.03893077759130392, 0.017356520511384588, 0.04899635212495923, 0.03930364371626638, 0.012750834594044136, 0.013412760745268315, 0.043390773425926454, 0.022353610474965535, 0.06391745380824432, 0.06323576890281402, 0.033167095461976714, 0.009826736568356864, 0.024162749432434794, 0.01462567774069612, 0.0623673151130788, 0.045495359518099576, 0.01710792515950743, 0.023472253378713503, 0.020239547156961635, 0.044110764283686876, 0.04952750721713528, 0.21717844472732395, 0.17010170209687203, 0.19238465640228242, 0.23897034960100427, 0.15291645628167316, 0.1841363380663097, 0.20628500817110762, 0.08755010756431147, 0.09795153731829487, 0.10376329577411525, 0.15027182787889615, 0.16959098575171083, 0.15580588951706886, 0.1359540328849107, 0.14229586289729923, 0.21299279120285064, 0.12636456463951617, 0.08928249546443112, 0.10666135276551358, 0.2320312985102646, 0.13155838125385344, 0.2672122896183282, 0.212830928794574, 0.12260327115654945, 0.13842240121448413, 0.08481766824843362, 0.09215387966833077, 0.2647241059457883, 0.13979041686980054, 0.1611483286251314, 0.17744327924447134, 0.18179253180278465, 0.14359105902258307, 0.09631178429117426, 0.15428055339725688, 0.1515157861285843, 0.1490572141483426, 0.12629772681975737, 0.09604938313714229, 0.1798208086984232, 0.11161778602399863, 0.10681613508495502, 0.09551040580845438, 0.28139401925727725, 0.2073158512939699, 0.14536499977111816, 0.17906205175677314, 0.16432578937383369, 0.22736704879207537, 0.12086661590728909, 0.10256060093524866, 0.14305089425761253, 0.25765310099814087, 1.0916666965931654, 6.324257617816329, 19.098360389471054, 33.01244996488094, 46.7588659375906, 54.885995239019394, 55.6030547618866, 49.66439142823219, 36.84572607278824, 39.14122849702835, 35.27808599174023, 24.850639924407005, 42.143534794449806, 31.30264811217785, 30.92294968664646, 32.500495836138725, 21.728182174265385, 14.310902282595634, 11.324709970504045, 7.348183924332261, 4.80465835891664, 1.9911435060203075, 1.4836823986843228, 0.7420485850889236, 0.6502578605432063, 0.38373671821318567, 0.6952210853341967, 0.37536104733590037, 1.333458290901035, 1.3787186122499406, 1.5370812895707786, 2.114215577021241, 3.1887394934892654, 3.6419927095994353, 2.4498109566047788, 3.061523982323706, 2.7210696134716272, 4.345432100817561, 4.0293793100863695, 5.508540663868189, 4.835645221173763, 4.083760092034936, 3.340021250769496, 3.1405044067651033, 5.379598382860422, 4.205853715538979, 2.4454012932255864, 2.561106509529054, 1.1812452273443341, 1.5781636163592339, 1.3365431316196918, 0.6292350729927421, 1.070071030408144, 0.5123368394561112, 0.8896234631538391, 0.8034930098801851, 1.040174828376621, 2.2689152508974075, 3.3853544807061553, 7.6731624361127615, 11.083086635917425, 16.620106771588326, 24.11766305565834, 26.617339923977852, 22.700842581689358, 27.606149464845657, 28.293515481054783, 33.055516853928566, 44.742329344153404, 47.56018973886967, 48.17840896546841, 37.8948649764061, 26.20005961507559, 10.85466854274273, 3.720118417404592, 1.0081551340408623, 0.19550347264157608, 0.1293567704851739, 0.0981101491197478, 0.17485457909060642, 0.16680644766893238, 0.10071655691717751, 0.1422574938624166, 0.1394396778778173, 0.18521831516409293, 0.12339770313701592, 0.14523068588459864, 0.20504784799413756, 0.09762341156601906, 0.1392570650205016, 0.18182570580393076, 0.1345334286452271, 0.20684265793533996, 0.23991056164959446, 0.18650323996553198, 0.09486237730016, 0.13501456298399717, 0.19014673976926133, 0.11301875303615816, 0.200937804474961, 0.12652467557927594, 0.18912331812316552, 0.1588105337577872, 0.1635467421147041, 0.21012775978306308, 0.15326695778639987, 0.07163159651099704, 0.16418199084000662, 0.1076658051169943, 0.09161281690467149, 0.19939971825806424, 0.15146975812967867, 0.08789074592641555, 0.08161126374034211, 0.17727113066939637, 0.14799108932493255, 0.12103655288228765, 0.10999510981491767, 0.06761536045814864, 0.11032037829863839, 0.09489230811595917, 0.17834807600593194, 0.1973452011588961], [0.07835209995391779, 0.0457225383433979, 0.07451612415025011, 0.05055268033174798, 0.028464445167628583, 0.0549058254546253, 0.0420087571546901, 0.027053127050749026, 0.0033595592049096012, 0.1045746858289931, 0.0379307298862841, 0.025857384280243423, 0.02898208018450532, 0.03694581828312948, 0.03384227544302121, 0.03711112425662577, 0.05523796622583177, 0.04627369431545958, 0.05726128343667369, 0.0491281983704539, 0.06286048708716407, 0.01626393812330207, 0.039296170289162546, 0.02847792813554406, 0.019294323756184895, 0.056369355515926145, 0.08960059480159543, 0.04503616306465119, 0.026138764005736448, 0.041626940728747286, 0.01651314574701246, 0.07251861883560196, 0.021418541509774514, 0.06965678607230075, 0.015877705918683205, 0.06044864443538245, 0.03610841966292355, 0.024703981034690514, 0.02034366119914921, 0.024636286034365185, 0.07179313237429596, 0.04338789760367945, 0.060538496254594065, 0.05784340180980507, 0.02506142162019387, 0.010014629806391895, 0.07047763108857907, 0.03373866420588456, 0.023493361914006528, 0.053730745930806734, 0.016007310878194403, 0.04452728353498969, 0.07274941192008555, 0.05981738475384191, 0.7759845640975982, 2.9888141714036465, 10.115953031927347, 21.445044167339802, 28.023511469364166, 40.938813239336014, 41.88325256109238, 39.98027667403221, 33.67449603974819, 26.28856446594, 21.715156473219395, 20.233568474650383, 27.38263215869665, 28.561750687658787, 17.862691394984722, 18.478041775524616, 24.221273995935917, 23.438322208821774, 8.02718611434102, 6.590225771069527, 6.757225384935737, 1.990179663989693, 1.3819706439971924, 0.8479619643185288, 0.4682469740509987, 0.17886049929074943, 0.19354252552147955, 0.17660024401266128, 0.08565774973249063, 0.012940656488353852, 0.22773687582230195, 0.2478702735970728, 0.3612786467419937, 0.6135388871189207, 0.17439173127058893, 0.4005943355150521, 0.9425890585407615, 0.5979923182167113, 0.7549032359384, 0.4832721990533173, 0.32242193177808076, 0.770180553663522, 0.6492386839818209, 0.44698922254610807, 0.2015646520885639, 0.18262634956045076, 0.07817365054506809, 0.6049992609769106, 0.1366834601503797, 0.02860705255443463, 0.2908325643511489, 0.4128485592082143, 0.3000241523841396, 0.4580374265788123, 2.013271381147206, 1.811043145135045, 3.1218808935955167, 6.011622743681073, 6.639730939641595, 10.636441502720118, 14.388031493872404, 20.88643044233322, 14.468331634998322, 13.773466721177101, 17.530207335948944, 21.95600274950266, 24.524917602539062, 33.38013343513012, 36.89118683338165, 27.835558354854584, 24.33493159711361, 9.156255628913641, 2.3592447163537145, 0.24938584305346012, 0.017256749888474587, 0.032122815755428746, 0.05852490859979298, 0.011643425023066811, 0.0290816782580805, 0.011833090138679836, 0.028783991692762356, 0.055501788592664525, 0.01056260196492076, 0.02085895659547532, 0.06384312029695138, 0.07334840673138388, 0.030953536115703173, 0.023410848079947755, 0.06211047264514491, 0.01924907130160136, 0.024696227446838748, 0.022681220434606075, 0.03510244961944409, 0.04909801522444468, 0.04393241506477352, 0.06759055046131834, 0.020779973528988194, 0.028155520631116815, 0.05006983905332163, 0.016949291093624197, 0.07425530377076939, 0.04044523382617626, 0.12346233677817509, 0.06964713073102757, 0.005191377731534885, 0.04800671675184276, 0.04165699770965148, 0.01765837052516872, 0.037641366507159546, 0.06465652157203294, 0.04336700985732023, 0.020110758559894748, 0.04712076311989222, 0.052264618352637626, 0.00987000099485158, 0.014573511252820026, 0.02549852248193929, 0.04192601882095914, 0.0700735836289823, 0.021495004984899424, 0.03982628266385291, 0.0714224370312877, 0.0632214751385618, 0.03066473491344368, 0.07015636278083548, 0.01885293884697603, 0.008754038171900902, 0.10847113182535395, 0.0391168006171938, 0.03091125596256461, 0.008943602169892984, 0.08129529436700977, 0.04536077845841646, 0.04734725174785126, 0.05162451598152984, 0.028547166803036816, 0.014398834737221478, 0.0033888522375491448, 0.043189833231735975, 0.03793864118051715, 0.04605270871252287, 0.008069446830631932, 0.037127941322978586, 0.04446239756362047, 0.07506957335863262, 0.00445995640802721, 0.04226830475090537, 0.02909727449150523, 0.09537531266687438, 0.03553872855263762, 0.0271501814131625, 0.02882290064007975, 0.02912192307121586, 0.06404765619663522, 0.018383931201242376, 0.0358071930531878, 0.029116767000232358, 0.08663529923069291, 0.10171098285354674, 0.013436812823783839, 0.013273080203362042, 0.051085713057545945, 0.0667403609259054, 0.020794248739548493, 0.03101494141446892, 0.13303997518960387, 0.05367689569538925, 0.04960243444656953, 0.054432695178547874, 0.03869170213874895, 0.052582413409254514, 0.04173637040366884, 0.06341956177493557, 0.06334388497634791, 0.05382882816775236, 0.0858584041998256, 1.0607167636044323, 4.583258964121342, 15.160423647612333, 26.244739517569542, 33.987158462405205, 46.13143980503082, 47.13542953133583, 44.56476867198944, 35.43609671294689, 28.452318459749222, 20.622823387384415, 24.256346113979816, 28.16744014620781, 28.13920386135578, 25.644789710640907, 22.93680801987648, 22.8084547072649, 20.955045260488987, 10.513484850525856, 8.371694628149271, 7.556920973584056, 3.4464138792827725, 1.284425009507686, 0.8625049714464694, 0.34635663963854313, 0.25158862641546875, 0.09642482080380432, 0.05571996145590674, 0.05237202567514032, 0.07807792833773419, 0.08016820953343995, 0.28142358642071486, 0.2503964997595176, 0.14339545858092606, 0.39036961854435503, 0.2418551518348977, 0.40563966322224587, 0.6554265925660729, 0.6955549924168736, 0.531389017123729, 0.772317226510495, 0.2008342748740688, 0.5456691852305084, 0.3023340424988419, 0.38606504327617586, 0.11481571520562284, 0.04414192335389089, 0.13896364951506257, 0.1958523562643677, 0.24805961031233892, 0.18393769481917843, 0.18532807880546898, 0.29017962282523513, 0.7368972490075976, 1.9212033902294934, 2.9040829930454493, 3.2993332715705037, 7.027095928788185, 9.835021756589413, 12.857430875301361, 17.014780193567276, 23.859881088137627, 16.705222204327583, 14.909069035202265, 18.745019249618053, 24.977175034582615, 28.405199088156223, 37.25312501192093, 42.82647214829922, 34.053324311971664, 27.413507401943207, 11.596858017146587, 3.612367124296725, 0.4246639955090359, 0.15367107203928754, 0.014172463925206102, 0.0153055082046194, 0.07032759109279141, 0.017455439519835636, 0.020742183369293343, 0.026075289970322046, 0.03564318212738726, 0.021065453620394692, 0.031296627275878564, 0.06978841338423081, 0.023164334452303592, 0.044439461489673704, 0.043931019827141427, 0.03089081721554976, 0.02799556739773834, 0.026941378164337948, 0.07107881523552351, 0.03502108796965331, 0.06601211367524229, 0.032763541530584916, 0.09787217946723104, 0.043257839934085496, 0.060224920307518914, 0.040700914832996204, 0.11059075011871755, 0.05225297405559104, 0.015357335159933427, 0.07426077339914627, 0.046168858534656465, 0.0217927954508923, 0.03772164091060404, 0.02059413232927909, 0.01830762357712956, 0.041065428085858, 0.060897124276380055, 0.08309504701173864, 0.034888629452325404, 0.02476390203810297, 0.06835117019363679, 0.02802090617478825, 0.01166722384368768, 0.03704846101754811, 0.028997643021284603, 0.023088084344635718, 0.028300278390815947, 0.011218915624340298, 0.09581523554516025, 0.174610338290222, 0.15185764903435484, 0.1597782052704133, 0.1066655755857937, 0.07939332572277635, 0.20777383062522858, 0.1583109941566363, 0.1691522280452773, 0.1038604874338489, 0.13795156788546592, 0.15972340508596972, 0.08712142080185004, 0.10153703085961752, 0.1304939336841926, 0.13507629482774064, 0.14867190591758117, 0.13059963035630062, 0.1490089003345929, 0.16279893927276134, 0.17014773009577766, 0.18271105829626322, 0.1060742100526113, 0.16818169184261933, 0.14460653968853876, 0.11625191938946955, 0.17384576291078702, 0.16187634581001475, 0.16538379510166124, 0.08090582268778235, 0.10559749149251729, 0.15737643727334216, 0.14395750185940415, 0.12950796080986038, 0.17788595549063757, 0.15941660123644397, 0.12367053888738155, 0.18859936186345294, 0.06673631622106768, 0.1153872134455014, 0.19365962158190086, 0.17537411215016618, 0.08256804794655181, 0.14021709241205826, 0.19771222287090495, 0.16084389964817092, 0.09942515316652134, 0.17866860958747566, 0.18204118096036837, 0.13983047800138593, 0.16733176948036999, 0.18012207612628117, 0.1651596071314998, 0.2495287510100752, 0.2741019136738032, 1.2533644074574113, 4.999904707074165, 15.269266907125711, 29.984833225607872, 38.56199137866497, 52.660633251070976, 56.26169241964817, 54.53860267996788, 47.27355971932411, 37.788170501589775, 30.502409152686596, 28.904422000050545, 39.68503251671791, 40.90753711760044, 29.33665830641985, 29.87779676914215, 33.830044493079185, 32.47206576168537, 13.003470338881016, 10.573460832238197, 9.447684790939093, 3.3904390828683972, 2.1891620429232717, 1.4171543810516596, 0.7726650265976787, 0.621037072269246, 0.47840400715358555, 0.5971180088818073, 0.577561705140397, 0.6579083937685937, 1.36003655847162, 0.6257149775046855, 1.3970772083848715, 2.7299920096993446, 0.862513817846775, 2.5009037274867296, 2.769775874912739, 2.29627117048949, 2.633644617162645, 1.7230259743519127, 2.19841122161597, 2.3971334332600236, 2.307088952511549, 1.9301940640434623, 1.6010996606200933, 0.6915074377320707, 0.5950129812117666, 1.588611868210137, 0.8241008478216827, 0.4953120608115569, 1.1380351334810257, 0.7490494719240814, 0.5764218256808817, 0.6880274182185531, 2.7729589166119695, 2.887189337052405, 5.499015050008893, 10.028663165867329, 11.993260346353054, 18.768995963037014, 22.68008429557085, 31.400762647390366, 23.273236267268658, 23.811864964663982, 29.698518589138985, 34.089692160487175, 36.32508181035519, 45.82210600376129, 47.67444580793381, 40.36879062652588, 30.699766762554646, 12.653072141110897, 4.170037787407637, 0.38875892059877515, 0.2984455449040979, 0.15440744580700994, 0.2801574527984485, 0.12243538250913844, 0.05374298394599464, 0.12262414777069353, 0.15724853554274887, 0.15718444366939366, 0.14446109358686954, 0.12122564468882047, 0.18227345834020525, 0.21610933647025377, 0.21318484417861328, 0.16640340210869908, 0.1890741434181109, 0.10422295235912316, 0.11359572832589038, 0.17407254839781672, 0.1861353128333576, 0.22021393262548372, 0.08429337802226655, 0.16290923726046458, 0.12862738774856552, 0.18716753635089844, 0.13395376678090543, 0.25705724547151476, 0.13516333390725777, 0.09616264229407534, 0.30477161169983447, 0.14733853371581063, 0.1144388155080378, 0.19892888492904603, 0.12851284467615187, 0.08204647398088127, 0.13079767988529056, 0.17310033494140953, 0.2525015571154654, 0.2882838808000088, 0.12024894123896956, 0.13232982892077416, 0.12950632808497176, 0.12755796778947115, 0.07888872467447072, 0.0944323324074503, 0.2116261114133522, 0.06012598460074514, 0.1070685098238755, 0.1932583868619986], [0.05142921239894349, 0.03252540860557929, 0.023778324357408565, 0.046477142968797125, 0.036074488671147265, 0.05688737830496393, 0.07502727094106376, 0.03295097834779881, 0.017368960761814378, 0.018777677651087288, 0.02368184144870611, 0.031488342574448325, 0.01430506994438474, 0.03681550457258709, 0.05759306426625699, 0.00763800762797473, 0.025215894092980307, 0.049478280561743304, 0.022644729033345357, 0.07899390926468186, 0.0452112913626479, 0.0019211101403016073, 0.02403103677352192, 0.027970681330771185, 0.010789855004986748, 0.06273982871789485, 0.07642089069122449, 0.022982575064816047, 0.021874429839954246, 0.019675310832099058, 0.03368517391209025, 0.030125421762932092, 0.029679934632440563, 0.03938404057407752, 0.04831245190871414, 0.08408254871028475, 0.08107534406008199, 0.04648968897527084, 0.04088050714926794, 0.012062675377819687, 0.003400882219466439, 0.02365435972023988, 0.03488387599645648, 0.03471746793366037, 0.007162865204008995, 0.06423995408113115, 0.02384078350587515, 0.08759819131228141, 0.03518622695992235, 0.024189394389395602, 0.057486785008222796, 0.07720325535046868, 0.01494473352067871, 0.052633803425123915, 0.04674398216593545, 0.3729625151026994, 1.666689484845847, 9.508333336561918, 18.083898425102234, 29.880183041095734, 42.45954103767872, 39.27278883755207, 40.1676332205534, 31.579938232898712, 24.97967530041933, 25.95801830291748, 33.09820756316185, 16.2430777028203, 13.122799135744572, 15.03425806760788, 25.42884159833193, 20.44756729155779, 15.216332897543907, 16.124315075576305, 8.121741190552711, 4.6785621251910925, 3.7669235933572054, 2.622776487842202, 1.6689047659747303, 1.119825798086822, 0.5598855880089104, 0.43711960839573294, 0.12830867985030636, 0.37551482033450156, 0.1682011954835616, 0.09467368625337258, 0.16592097643297166, 0.07672302643186413, 0.30829167750198394, 0.1295456915977411, 0.39437472238205373, 0.41658156202174723, 0.08325194445205852, 0.5863864347338676, 0.13597459037555382, 0.34030038805212826, 0.060977547109359875, 0.19514516374329105, 0.36721125652547926, 0.11949904554057866, 0.09899613243760541, 0.11837171579827555, 0.14519904070766643, 0.2905707940226421, 0.38163056247867644, 0.7786936406046152, 2.2021647077053785, 2.2094387048855424, 4.728736532852054, 5.25491519831121, 5.651943543925881, 7.849188940599561, 10.989460609853268, 21.122810058295727, 24.19333789497614, 24.302266649901867, 24.573615789413452, 27.010941803455353, 27.16283105313778, 28.969113528728485, 31.859464533627033, 30.60215190052986, 31.138971894979477, 18.18937126547098, 8.398831821978092, 2.807289124466479, 0.28171391459181905, 0.12750667054206133, 0.10878343498916365, 0.045112882580724545, 0.04113585047889501, 0.060583295999094844, 0.027675757410179358, 0.02424634494673228, 0.008404384570894763, 0.03256499476265162, 0.03589406514947768, 0.03147748866467737, 0.11368327948730439, 0.0531028259138111, 0.04474937864870299, 0.024484954701620154, 0.018871813517762348, 0.034680542376008816, 0.008241983177867951, 0.05978910892736167, 0.04503962889430113, 0.02184128181397682, 0.08846662283758633, 0.026632518565747887, 0.050519910801085643, 0.012837587946705753, 0.1255713275168091, 0.0639439930091612, 0.024938970964285545, 0.02908311060309643, 0.03262466343585402, 0.08135300377034582, 0.015011611230875133, 0.036711759748868644, 0.06819319663918577, 0.008742682384763611, 0.05957969340670388, 0.06839487527031451, 0.052268496074248105, 0.054656233769492246, 0.03259724107920192, 0.11958472648984753, 0.05871676119568292, 0.045316739415284246, 0.03137630053970497, 0.02555375682277372, 0.043330652042641304, 0.08866825693985447, 0.042722473153844476, 0.10504546720767394, 0.05416817148216069, 0.03467579263087828, 0.007831142283976078, 0.0805702235084027, 0.023808986188669223, 0.028321457430138253, 0.03357461617270019, 0.025144631217699498, 0.054185036788112484, 0.07604628422996029, 0.03697813881444745, 0.052158480102662, 0.053694221132900566, 0.04157161733019166, 0.04890419222647324, 0.0460094340814976, 0.007166284185586846, 0.04510403246968053, 0.020579324627760798, 0.03891813881637063, 0.0219139677574276, 0.05041413620347157, 0.026419162240927108, 0.029266220699355472, 0.03330626670503989, 0.053626021472155116, 0.10124925567652099, 0.024648793078085873, 0.04392834067402873, 0.0068422119511524215, 0.10812060063472018, 0.029336618972592987, 0.02758377006102819, 0.020464365952648222, 0.01735209545586258, 0.03139353691949509, 0.026797160317073576, 0.03163377012242563, 0.05587072875641752, 0.044676585093839094, 0.055281582244788297, 0.053510791913140565, 0.03768934264371637, 0.09046926381415688, 0.05432455684058368, 0.03150352320517413, 0.10544846823904663, 0.07953450447530486, 0.017917864315677434, 0.05020539974793792, 0.039283524092752486, 0.03630407947639469, 0.04370299124275334, 0.04010035037936177, 0.04459699346625712, 0.6831493705976754, 2.909444742836058, 14.021885991096497, 22.396534010767937, 36.6616715490818, 48.35206724703312, 46.02348379790783, 44.413897767663, 37.4342954903841, 26.53682604432106, 27.199024111032486, 36.16522058844566, 23.426548540592194, 18.873306065797806, 21.654608622193336, 28.693970292806625, 31.3114807382226, 20.46042200177908, 19.38963945955038, 13.192859776318073, 6.627288032323122, 5.667132753878832, 3.25349158141762, 2.7458903566002846, 1.276436175685376, 0.8973182877525687, 0.20788905647350475, 0.15752758306916803, 0.16136652004206553, 0.1882227070746012, 0.05677603759977501, 0.09326950574177317, 0.12135670054703951, 0.0767786504002288, 0.11734997882740572, 0.4184165666811168, 0.22460455249529332, 0.20045039156684652, 0.5116810777690262, 0.11810213065473363, 0.07908060695626773, 0.16419114894233644, 0.2401535407989286, 0.09194418584229425, 0.08372570184292272, 0.05053416003647726, 0.09429677171283402, 0.05906196376599837, 0.36862712586298585, 0.40643462212756276, 0.6987543613649905, 2.0991363236680627, 2.3421489587053657, 5.81139818765223, 6.013654209673405, 9.35136565938592, 12.489434871822596, 14.353046771138906, 19.3872132897377, 23.78159388899803, 24.189661592245102, 24.02484353631735, 26.54484361410141, 29.529435262084007, 31.424127593636513, 35.12847661972046, 37.08414047956467, 38.17344702780247, 22.585231885313988, 12.268573623150587, 3.8071833830326796, 0.6129377475008368, 0.02945889707916649, 0.03438629937591031, 0.06701675898511894, 0.028431762839318253, 0.04589857206156012, 0.021340313578548376, 0.02907659269112628, 0.04275441890058573, 0.05574744689511135, 0.04291762459615711, 0.034146333346143365, 0.09566396358422935, 0.025958637343137525, 0.04080466336745303, 0.025191709355567582, 0.010252416705043288, 0.04060560080688447, 0.029908152464486193, 0.06801256531616673, 0.02478033689840231, 0.03263371763750911, 0.02880088668462122, 0.015224803355522454, 0.031090764787222724, 0.028158138557046186, 0.05030849148170091, 0.02463408742187312, 0.029502051111194305, 0.012129939932492562, 0.09549839043756947, 0.04364867716503795, 0.0604846423084382, 0.04531040518486407, 0.010412182546133408, 0.03286714905698318, 0.08551418868592009, 0.03458474966464564, 0.06054528690583538, 0.030420143448282033, 0.06574184575583786, 0.046330160621437244, 0.040283519847434945, 0.050409538598614745, 0.07338227835134603, 0.0466031893301988, 0.025325184615212493, 0.044903185043949634, 0.03968001648900099, 0.025797756425163243, 0.1000774787098635, 0.13747481221798807, 0.09960469353245571, 0.22336850553983822, 0.13447769335471094, 0.1113809370144736, 0.13330606481758878, 0.11335251911077648, 0.27314288076013327, 0.15218827582430094, 0.12651422613998875, 0.14580585033399984, 0.28087175509426743, 0.13037894532317296, 0.1540210540406406, 0.12849178252508864, 0.1308538010925986, 0.13267167698359117, 0.11242770662647672, 0.20665548829128966, 0.18433199787978083, 0.16476153396070004, 0.09245830864529125, 0.10647373041138053, 0.12332846075878479, 0.14370298973517492, 0.18362354370765388, 0.10983984509948641, 0.1272953365696594, 0.06363042077282444, 0.12930027820402756, 0.11466512602055445, 0.08221347947255708, 0.1615263638086617, 0.11803715562564321, 0.1207333558704704, 0.1554660897818394, 0.12578157795360312, 0.1145184924826026, 0.1218641440209467, 0.12147792294854298, 0.17951430170796812, 0.09236199271981604, 0.17610410344786942, 0.14707553142216057, 0.13001802406506613, 0.20190327923046425, 0.1661722527933307, 0.1387719824560918, 0.15434366563567892, 0.06855408078990877, 0.12168700821348466, 0.25248629855923355, 0.12493168527726084, 0.1413575655897148, 0.9902182559017092, 3.4894052473828197, 14.208095949143171, 25.30423678457737, 39.42095808684826, 54.042660892009735, 53.24534587562084, 51.93745605647564, 45.8338587731123, 35.768962651491165, 38.16188804805279, 43.367281928658485, 28.123710192739964, 22.84336533397436, 26.47731553763151, 36.228327602148056, 33.075161799788475, 23.81604664027691, 22.99104630947113, 13.914163671433926, 9.14560005068779, 6.826240131631494, 3.959773457609117, 3.232376351952553, 1.7521603172644973, 1.1814512475393713, 0.78570123645477, 0.6253469316288829, 0.7923824654426426, 0.5449159943964332, 0.4064898379147053, 0.5267071933485568, 0.47655971080530435, 0.9417079214472324, 0.5125784233678132, 1.6598470020107925, 1.5507666114717722, 0.7354855653829873, 1.8737932154908776, 0.9487617085687816, 0.7607403164729476, 0.8774745056871325, 0.9477203863207251, 1.0960689978674054, 0.7013262889813632, 0.5300155095756054, 0.48229324689600617, 0.4783030750695616, 0.869815363548696, 0.8609279966913164, 1.1252117715775967, 3.3700740756466985, 3.4257819363847375, 7.166583593934774, 8.606813661754131, 11.190164890140295, 14.397576581686735, 19.709494896233082, 30.758619904518127, 34.17462520301342, 35.63658535480499, 34.2583005130291, 39.69881437718868, 38.69659535586834, 40.17777867615223, 44.86317805945873, 42.75121718645096, 41.418845281004906, 25.514240115880966, 12.407787702977657, 4.083646573126316, 0.6235145987011492, 0.16533500631339848, 0.1713648225995712, 0.2285891433712095, 0.08937469989177771, 0.2174327935790643, 0.10055429374915548, 0.12468800850911066, 0.1461264878162183, 0.12746945925755426, 0.07940108858747408, 0.12349273514701054, 0.3096408722922206, 0.11717814195435494, 0.1620482123689726, 0.13701402756851166, 0.13560636638430879, 0.12854919506935403, 0.06895732673001476, 0.17966353276278824, 0.13002149731619284, 0.09165128241875209, 0.14569250954082236, 0.14158423233311623, 0.16206811676966026, 0.13730652281083167, 0.13814172096317634, 0.14821906224824488, 0.08943167456891388, 0.16118162136990577, 0.14683026645798236, 0.1402203578618355, 0.16530269320355728, 0.18949425837490708, 0.14196545875165612, 0.12874954525614157, 0.14358369691763073, 0.15738635236630216, 0.1390294631710276, 0.13316192489583045, 0.10842979419976473, 0.15381619159597903, 0.1453924147062935, 0.12357581857941113, 0.30521998764015734, 0.18441740423440933, 0.16938878019573167, 0.13639736222103238, 0.1439984535682015, 0.11945767822908238], [0.016064328228821978, 0.08558538291254081, 0.02441421504045138, 0.12362316017970443, 0.05897387454751879, 0.01862551140220603, 0.028339877535472624, 0.05038829091063235, 0.01923843261465663, 0.0031530691376246978, 0.041497918355162255, 0.07079340750351548, 0.029404469823930413, 0.0871212723723147, 0.02928872447228059, 0.008819262748147594, 0.05876016941328999, 0.07992221726453863, 0.05058863367594313, 0.022290939814411104, 0.05508590016688686, 0.027371957403374836, 0.037154424862819724, 0.07166465918999165, 0.00620356697254465, 0.02881615266232984, 0.02828809603670379, 0.08602316840551794, 0.040753291905275546, 0.025796084737521596, 0.041243131636292674, 0.040669403242645785, 0.015905616237432696, 0.043617707342491485, 0.062237238889792934, 0.040681006721570157, 0.059903852379648015, 0.0059263075581839075, 0.08099510305328295, 0.015340234222094296, 0.03288718333351426, 0.040407755368505605, 0.06343042681692168, 0.009726653315738076, 0.06928083632374182, 0.038980082172201946, 0.08122505008941516, 0.05685197786078788, 0.033260932614211924, 0.07097330410033464, 0.05023545672884211, 0.08304701521410607, 0.018510051777411718, 0.07477386461687274, 0.01567510702443542, 0.04069145245011896, 0.18184434855356812, 1.818838189356029, 7.943879384547472, 17.482082918286324, 27.755766436457634, 36.06769122183323, 38.53027828037739, 41.285879015922546, 42.762798964977264, 42.717376202344894, 31.831408739089966, 19.22749076038599, 19.991764649748802, 19.24094583839178, 21.778126694262028, 18.23797445744276, 19.671861715614796, 18.751742988824844, 12.365360129624605, 12.075550630688667, 5.843341648578644, 5.6995174661278725, 5.107651725411415, 2.944807782769203, 1.8092409730888903, 1.4482307760044932, 0.8766067866235971, 0.8092916174791753, 0.3283226885832846, 0.26833554496988654, 0.25780898169614375, 0.10122472027433105, 0.015485353778785793, 0.1784344026236795, 0.13484156836057082, 0.1277268212288618, 0.26207728078588843, 0.08024378243135288, 0.2058901113923639, 0.036313575255917385, 0.27191349829081446, 0.057514303844072856, 0.0702822681341786, 0.18694002355914563, 0.5033863603603095, 0.40360769256949425, 1.2422541598789394, 1.2887967936694622, 2.170352339744568, 2.7461829409003258, 4.595553204417229, 6.064831763505936, 6.905119149014354, 8.758144341409206, 13.134426511824131, 15.133041366934776, 17.73027040064335, 24.606206640601158, 19.2717469856143, 22.7007057890296, 18.507746681571007, 25.63234157860279, 27.428510896861553, 33.71448129415512, 35.95206342637539, 29.61694836616516, 19.537905603647232, 10.948871187865734, 3.109259158372879, 0.6278448819648474, 0.008185564183804672, 0.02262458157929359, 0.04326501650211867, 0.09035604176460765, 0.01086878148271353, 0.02945965406979667, 0.017608236594242044, 0.04836142994463444, 0.02360166166909039, 0.03980823734309524, 0.09634602698497474, 0.029917481260781642, 0.005429198954516323, 0.04221553805109579, 0.03174198267515749, 0.04052338939800393, 0.027836749650305137, 0.013557207730627852, 0.051590106304502115, 0.016605186901870184, 0.06537353270687163, 0.01808965294912923, 0.038138022864586674, 0.04688480468757916, 0.015818308129382785, 0.03950955629989039, 0.071145853435155, 0.031950355478329584, 0.011317157423036406, 0.05341859119653236, 0.04122348327655345, 0.0679976110404823, 0.016254420079349075, 0.035525603670976125, 0.02998234125698218, 0.0459258645423688, 0.03302039884147234, 0.014454205447691493, 0.05397345048550051, 0.007395148149953457, 0.066811495780712, 0.06502760283183306, 0.02378660487011075, 0.028484522117651068, 0.005283111822791398, 0.03817003540461883, 0.05451728145999368, 0.04946016473695636, 0.04649809008697048, 0.013311389866430545, 0.02389669320109533, 0.05780317740573082, 0.03683756120153703, 0.040137595060514286, 0.027982188330497593, 0.024593825910415035, 0.02862211815227056, 0.06400844853487797, 0.023159655211202335, 0.03899455776263494, 0.03773472497414332, 0.06086494475312065, 0.025256829103454947, 0.08925159985665232, 0.02492295541742351, 0.03808256587944925, 0.04148867490584962, 0.0536445714533329, 0.020340158262115438, 0.06226204146514647, 0.026921410681097768, 0.028549886774271727, 0.04205857381748501, 0.02228009147074772, 0.014096450377110159, 0.07507084985263646, 0.03737683167855721, 0.07088664351613261, 0.05286659659759607, 0.014035967196832644, 0.024444769260298926, 0.02210207992902724, 0.027248788719589356, 0.06039844927727245, 0.030889893241692334, 0.016652884733048268, 0.02196618341258727, 0.05011655724956654, 0.013493932219716953, 0.01024547576889745, 0.053666988023906015, 0.07243670057505369, 0.027790040730906185, 0.017053111987479497, 0.03812174385529943, 0.026746401126729324, 0.07295574381714687, 0.04425221020937897, 0.05160575448826421, 0.024952394560386892, 0.053756097695440985, 0.0697451907035429, 0.02198257188865682, 0.10326768213417381, 0.020930802056682296, 0.0359821469464805, 0.3010485536651686, 2.7914114389568567, 10.920044034719467, 23.100693225860596, 34.312603399157524, 41.024806424975395, 45.05011662840843, 44.09593842923641, 45.95539145171642, 46.155861094594, 35.79119525849819, 20.124476328492165, 22.42593113332987, 19.224194437265396, 26.435103602707386, 23.94464123994112, 22.922927364706993, 25.6791265681386, 15.841538049280643, 15.506154745817184, 10.514692235738039, 9.950143229216337, 7.419763058423996, 3.1812189845368266, 2.465500789694488, 1.8619005661457777, 1.1381839192472398, 0.79647894250229, 0.5177517863921821, 0.20417346444446594, 0.20756960642756894, 0.05795122844574507, 0.11738632922060788, 0.04435865645064041, 0.08756225652177818, 0.12410948213073425, 0.10818582057254389, 0.06448875908972695, 0.22075734799727798, 0.0885814701905474, 0.07797016107360832, 0.17694942449452356, 0.10958082071738318, 0.21239433815935627, 0.4322613909607753, 0.4722443298669532, 1.2966759083792567, 1.3716395921073854, 1.9445887603797019, 3.3067067759111524, 6.032570069655776, 7.547529777511954, 8.892433885484934, 11.427449807524681, 17.467506900429726, 15.526253767311573, 21.04686163365841, 27.464314475655556, 23.271066583693027, 24.696860276162624, 24.098002910614014, 29.965076185762882, 32.07739993929863, 39.409159719944, 41.06213562190533, 33.6685835570097, 24.3577341735363, 13.144908249378204, 3.8650032179430127, 0.7793017267249525, 0.020909558079438284, 0.0727697393449489, 0.03506027707771864, 0.0650351207877975, 0.053411986082210205, 0.05557234828302171, 0.028928851497767027, 0.06995077303145081, 0.019597079190134536, 0.02540374465752393, 0.07307112551643513, 0.027723928360501304, 0.04778148235345725, 0.052141711275908165, 0.018829832079063635, 0.00428973092311935, 0.03681870693981182, 0.07651584848645143, 0.03220516075089108, 0.057159839270752855, 0.04436890179931652, 0.03402866954274941, 0.03803342828177847, 0.06379302532877773, 0.032672903034836054, 0.0078414952440653, 0.06092280258599203, 0.0030415862647714675, 0.035463404274196364, 0.041925469631678425, 0.03977085536462255, 0.044129421876277775, 0.049625285173533484, 0.06535137959872372, 0.09781232525710948, 0.038179738985490985, 0.018394211801933125, 0.03460509193246253, 0.040402890590485185, 0.027676256504491903, 0.07431723599438556, 0.0632226699963212, 0.02348297741264105, 0.03387379816558678, 0.025671238799986895, 0.07618658724823035, 0.024564217928855214, 0.034085729566868395, 0.07100975839421153, 0.035644206291181035, 0.10691800227505155, 0.24210608680732548, 0.12115204590372741, 0.1512638566782698, 0.10693090822314844, 0.10282946619554423, 0.1743992418050766, 0.19425587786827236, 0.19576886465074494, 0.13960456824861467, 0.14170155103784055, 0.22097515349742025, 0.12792249588528648, 0.1633522697375156, 0.10686558438464999, 0.09068395229405724, 0.21200282557401806, 0.17463635798776522, 0.19309720722958446, 0.15545313188340515, 0.1083674315304961, 0.14761663129320368, 0.15265416644979268, 0.17888985865283757, 0.09870871348539367, 0.15784085844643414, 0.19267884374130517, 0.14972275734180585, 0.17084849561797455, 0.10250368562992662, 0.20028904866194353, 0.17469862417783588, 0.08552238941774704, 0.1634087471757084, 0.13902352598961443, 0.19177557580405846, 0.12266123289009556, 0.1413534689345397, 0.2500247134594247, 0.10031361525761895, 0.09593720009434037, 0.1455483547761105, 0.1628271260415204, 0.0898038393643219, 0.15844170120544732, 0.11965042140218429, 0.13264129345770925, 0.15716068010078743, 0.22442104906076565, 0.175966004608199, 0.14518330717692152, 0.2181932277744636, 0.11666697289911099, 0.12880324706202373, 0.08991933238576166, 0.14106756396358833, 0.4242950590560213, 2.8122257720679045, 11.186482887715101, 24.55996122211218, 37.71102324128151, 48.01888972520828, 53.552760779857635, 56.04757010936737, 55.50932519137859, 57.126522213220596, 43.43320079147816, 30.434597991406918, 31.793676763772964, 29.690295830368996, 34.68704670667648, 30.030590370297432, 30.779583379626274, 31.222278624773026, 20.605999790132046, 21.33903745561838, 12.169210854917765, 11.41276739537716, 8.354911878705025, 4.322103252634406, 3.185039204545319, 2.4149696761742234, 1.312290458008647, 1.0310010518878698, 0.5106434365734458, 0.9415429271757603, 0.5372335785068572, 0.6693967210594565, 0.4729762952774763, 0.3506207827012986, 0.3533134132158011, 0.601393491961062, 1.0810114745981991, 0.34788181248586625, 0.8014832739718258, 0.29340879642404616, 0.4926297313068062, 0.38948367233388126, 0.5063261557370424, 0.47601081838365644, 0.9210394648835063, 0.7536175986751914, 1.7265131184831262, 1.605690170545131, 3.2483502198010683, 4.002383658662438, 6.818912224844098, 8.726031314581633, 10.427713952958584, 15.46441588550806, 21.86867393553257, 22.925836108624935, 25.843057371675968, 35.70506528019905, 28.815216086804867, 35.06030447781086, 30.119665190577507, 38.153224512934685, 39.43397618830204, 45.59788763523102, 46.912658885121346, 38.79650719463825, 27.07809180021286, 14.761410858482122, 4.789631590247154, 0.9068678878247738, 0.06459559124778025, 0.19149985309923068, 0.17992842011153698, 0.2493220183532685, 0.11838716731290333, 0.2240163559326902, 0.09871865084278397, 0.180642084160354, 0.12783072190359235, 0.15985255362465978, 0.12568735488457605, 0.09499142193817534, 0.11168542536324821, 0.22194812394445762, 0.16640614805510268, 0.11096755333710462, 0.13489313278114423, 0.16960461158305407, 0.14802611869527027, 0.18111588608007878, 0.20368771394714713, 0.10294492953107692, 0.16699600702850148, 0.11399057315429673, 0.12620483961654827, 0.1531739073107019, 0.16318270383635536, 0.12888657540315762, 0.11375823640264571, 0.16003697732230648, 0.12261687472346239, 0.14101111621130258, 0.11229033509152941, 0.12920498644234613, 0.28055367060005665, 0.14720251288963482, 0.10689215327147394, 0.11296197131741792, 0.17109827284002677, 0.11023913539247587, 0.22661522350972518, 0.1523916094447486, 0.09044332575285807, 0.16069028992205858, 0.08896257044398226, 0.22570621134946123, 0.17393991176504642, 0.12869658559793606, 0.25704394618514925, 0.08560053756809793], [0.04425883758813143, 0.03791071045270655, 0.04219480244501028, 0.09759402251802385, 0.03362701550940983, 0.01277946572372457, 0.005323937830326031, 0.03433749203395564, 0.05636770052660722, 0.014500320648949128, 0.03420995024498552, 0.05099256610265002, 0.022660228787572123, 0.014040534188097809, 0.05897478367842268, 0.06435031144064851, 0.03117329346423503, 0.060515660370583646, 0.005873985683138017, 0.07134489744203165, 0.05121429014252499, 0.051047603774350137, 0.05337199916539248, 0.05804063126561232, 0.01894220622489229, 0.01792138209566474, 0.030914454619050957, 0.0332692817755742, 0.008489706506225048, 0.02852423072909005, 0.03747770439076703, 0.04388276538520586, 0.04676391996326856, 0.03572245463146828, 0.07771426113322377, 0.037586570033454336, 0.046823985685477965, 0.01148451357948943, 0.04900717263808474, 0.08896657804143615, 0.015556202906736871, 0.010739939079940086, 0.04699732169683557, 0.092254485207377, 0.046576260501751676, 0.03981128385930788, 0.07886418927228078, 0.032715398410800844, 0.022281933852354996, 0.026549468529992737, 0.020060687711520586, 0.06064137276553083, 0.039068304977263324, 0.05003047554055229, 0.07058582137688063, 0.05965514756098855, 0.03055496941669844, 0.12544263910967857, 1.4621246117167175, 5.674429787322879, 13.255754001438618, 20.17106182873249, 33.62813472747803, 45.84927074611187, 40.22895433008671, 43.578041419386864, 38.32374036312103, 29.438295252621174, 25.424525029957294, 27.46617827564478, 21.0156387090683, 26.563696302473545, 27.264792881906033, 25.830603539943695, 22.19801176339388, 12.800116650760174, 12.085152715444565, 10.241011921316385, 9.38956405967474, 7.410556152462959, 8.679120931774378, 4.0480272844433784, 3.8847305718809366, 2.1438573114573956, 1.6472401097416878, 1.3231914793141186, 0.9281275095418096, 0.7570266688708216, 1.0875115008093417, 0.6145353836473078, 0.6555846403352916, 0.436212852364406, 0.6632643251214176, 0.8481958892662078, 0.347241279669106, 0.7141206180676818, 0.3206617949763313, 0.7326889154501259, 0.9693064342718571, 0.5195410747546703, 1.707413918338716, 2.5033550709486008, 2.9127258667722344, 5.081879133358598, 6.454630047082901, 8.111069463193417, 5.835191085934639, 9.42617129534483, 13.571559805423021, 14.659483227878809, 19.83036831021309, 26.742233522236347, 21.836472563445568, 17.837175764143467, 18.5413558781147, 23.6375892162323, 26.092679277062416, 31.647616401314735, 34.04699765145779, 29.288359098136425, 28.049160093069077, 16.481925286352634, 9.38925152644515, 2.8725477727130055, 0.4793132864870131, 0.02893500575737562, 0.0168776051941677, 0.011457910368335433, 0.023168713123595808, 0.03838070515485015, 0.03895701993315015, 0.01166954769360018, 0.05511184564966243, 0.025296051608165726, 0.06269758567214012, 0.04796709348738659, 0.024242417130153626, 0.031100349624466617, 0.07626664271811023, 0.039834175404394045, 0.046218719726311974, 0.03506695640680846, 0.08496961556375027, 0.07900991739006713, 0.0030102901291684248, 0.03193037315213587, 0.067059150460409, 0.06640382664045319, 0.04113460367079824, 0.03742256281839218, 0.004184676208751625, 0.07266742686624639, 0.061053068056935444, 0.03413141246710438, 0.033338416542392224, 0.05534604519198183, 0.04200201845378615, 0.03738166305993218, 0.07076287554809824, 0.07635393412783742, 0.07704445801209658, 0.02638073197886115, 0.02800085519993445, 0.0031087084198588855, 0.0375085183623014, 0.06293897662544623, 0.02081790840747999, 0.026027816638816148, 0.06799664624850266, 0.0321766511478927, 0.02277770334330853, 0.06367336143739522, 0.025124888234131504, 0.043875291958102025, 0.019633500087365974, 0.01002524530122173, 0.04469503488508053, 0.03373347288288642, 0.018071147496812046, 0.03062709318328416, 0.0033464373382230406, 0.011546798323252006, 0.08813578824629076, 0.09047231404110789, 0.019604994195105974, 0.02950268935819622, 0.04023250461614225, 0.02889347517339047, 0.049129612161777914, 0.061177708048489876, 0.039612555265193805, 0.053275516256690025, 0.02823530707246391, 0.02104554179823026, 0.031688191811554134, 0.09841317543759942, 0.012988255057280185, 0.05925313729676418, 0.005771866162831429, 0.04073466028785333, 0.04572073492454365, 0.03743362824025098, 0.01609493439900689, 0.04097447046660818, 0.022819334117230028, 0.016275819907605182, 0.01830988341680495, 0.03262901242123917, 0.032641703146509826, 0.039483647924498655, 0.024985939635371324, 0.02801453483698424, 0.011346192095516017, 0.012916936520923628, 0.05466188522404991, 0.08086495261522941, 0.03184411703841761, 0.014271471991378348, 0.07030251392279752, 0.0733500171918422, 0.060900649477844127, 0.01204739919558051, 0.08535372151527554, 0.023004043541732244, 0.04367010296846274, 0.024405463263974525, 0.009315965489804512, 0.026759407264762558, 0.007222577478387393, 0.02089019544655457, 0.0539743596164044, 0.01638450372411171, 0.06423460319638252, 0.32115104841068387, 2.3162312619388103, 7.977535128593445, 17.039387673139572, 26.82769473642111, 38.75752128660679, 50.418160781264305, 47.225480899214745, 48.4466365724802, 41.220792308449745, 30.09215086698532, 24.561545737087727, 27.356018386781216, 24.933340586721897, 25.88193118572235, 28.958928175270557, 28.253971002995968, 26.038072407245636, 17.718692421913147, 14.352884329855442, 16.82681567966938, 12.269924450665712, 8.84233832359314, 10.27039099484682, 6.01216041482985, 4.381549637764692, 2.7885775035247207, 2.1605825889855623, 1.6763737401925027, 1.2491002050228417, 1.07516287593171, 0.8391791512258351, 0.4176551825366914, 0.7358714821748435, 0.30593987088650465, 0.706610024208203, 0.5030764394905418, 0.3075996693223715, 0.5694513372145593, 0.35727568028960377, 0.8221026894170791, 0.8471852028742433, 0.8289177424740046, 1.8306435621343553, 2.337901499122381, 3.700782679952681, 4.761300310492516, 7.210094109177589, 8.841908946633339, 9.405626747757196, 10.089064724743366, 17.116189152002335, 18.80768358707428, 25.65936002880335, 27.918859384953976, 19.68011487275362, 21.509061232209206, 19.103790298104286, 28.06976068764925, 27.497475296258926, 35.480622723698616, 37.7725875377655, 36.522978991270065, 33.365029245615005, 21.815098710358143, 11.662199310958385, 4.242977723479271, 0.8629711589310318, 0.07918464863905683, 0.07023070371360518, 0.028666654434346128, 0.05313895737344865, 0.026034518232336268, 0.05760910578828771, 0.02568084775703028, 0.03889069790602662, 0.016314543318003416, 0.06404731480870396, 0.027729410976462532, 0.03454435085586738, 0.019713759647856932, 0.05850791712873615, 0.06135076946520712, 0.029026011616224423, 0.03271867870353162, 0.029157702010707, 0.008277153556264238, 0.024744262955209706, 0.02025774276262382, 0.04809646838111803, 0.08268877310911193, 0.04770083316543605, 0.015066928135638591, 0.008099927763396408, 0.05990837576973718, 0.046420810249401256, 0.034187656128779054, 0.04050857613037806, 0.016144801156769972, 0.028204700902279, 0.028563529303937685, 0.04309411844587885, 0.05999888810038101, 0.0321052305662306, 0.09274492607801221, 0.024201699197874404, 0.025366750451212283, 0.12352984995231964, 0.05997661253786646, 0.07808730166289024, 0.028132595689385198, 0.0989260662754532, 0.024440659617539495, 0.004836216467083432, 0.051988728664582595, 0.014151824798318557, 0.016965330760285724, 0.05315025286108721, 0.04940185048326384, 0.11961262382101268, 0.16518127784365788, 0.07928651582915336, 0.24582246551290154, 0.12259464740054682, 0.12576207431266084, 0.17843290348537266, 0.23347342503257096, 0.14726332447025925, 0.06154549788334407, 0.10548515259870328, 0.11450218749814667, 0.1450475089950487, 0.18510200578020886, 0.15522006782703102, 0.18883490469306707, 0.12324688388616778, 0.16349684010492638, 0.08608075906522572, 0.25642695429269224, 0.18989874370163307, 0.1856684871017933, 0.12360007938696072, 0.14839232404483482, 0.18682387744775042, 0.07899181640823372, 0.09906331164529547, 0.11086166370660067, 0.08636831902549602, 0.10491309032659046, 0.08684022846864536, 0.17884210887132213, 0.10053130943560973, 0.2815774187911302, 0.14245275291614234, 0.14719460159540176, 0.10889958852203563, 0.12187179556349292, 0.13819638756103814, 0.17946578009286895, 0.08628643045085482, 0.13805548340315, 0.11338515134411864, 0.11832682328531519, 0.15420090610859916, 0.15413178247399628, 0.16352378006558865, 0.10966455723973922, 0.21004915150115266, 0.14544351899530739, 0.10712002229411155, 0.13902487669838592, 0.08977160789072514, 0.16062794951722026, 0.12408277223585173, 0.14873547828756273, 0.16687837662175298, 0.4331449029268697, 2.2446015430614352, 8.341058772057295, 19.033036194741726, 29.867056645452976, 43.13956014811993, 59.63510200381279, 54.4836500287056, 57.42709368467331, 51.73397697508335, 40.702310130000114, 37.54850596189499, 41.55070200562477, 30.783385075628757, 37.27899022400379, 37.71009989082813, 39.561303555965424, 34.7716111689806, 24.274427443742752, 22.833392769098282, 20.55684182792902, 16.103537790477276, 12.16164831072092, 13.551348689943552, 6.278635365888476, 5.875876452773809, 3.5068959463387728, 2.741243443451822, 1.770825746934861, 1.503731191623956, 1.460668221116066, 1.3764818385243416, 1.12821479793638, 1.065216672141105, 1.1064116866327822, 0.9128861117642373, 0.9982501342892647, 0.7927335903514177, 1.01992144016549, 0.8746585599146783, 0.9938787657301873, 1.3485308946110308, 0.8898069220595062, 2.728629782795906, 3.500365521758795, 4.1749542485922575, 7.295870231464505, 8.351137731224298, 11.87987158074975, 10.470271669328213, 15.785729493945837, 20.89791152626276, 22.32569821178913, 32.72517018020153, 36.391228660941124, 32.90100194513798, 28.561287112534046, 27.648332901299, 35.18128238618374, 36.65762476623058, 43.45970816910267, 45.38514845073223, 41.01156033575535, 36.60426802933216, 23.42700831592083, 12.476227730512619, 4.30939388461411, 0.8934572199359536, 0.11317106400383636, 0.19438021729001775, 0.08491867454722524, 0.15895372373051941, 0.2313025391777046, 0.1548114264733158, 0.08640981250209734, 0.15533317113295197, 0.1581637520575896, 0.2405696184723638, 0.10256678302539513, 0.14191671449225396, 0.12074527476215735, 0.16877889807801694, 0.12158675890532322, 0.10368251299951226, 0.22997461433988065, 0.18626032018801197, 0.26202915993053466, 0.14747180859558284, 0.13862845109542832, 0.2546449686633423, 0.1549732591956854, 0.17800357105443254, 0.12959866609890014, 0.13979660638142377, 0.11207687857677229, 0.17161133437184617, 0.12466203334042802, 0.13582771935034543, 0.18258263706229627, 0.08849816411384381, 0.1302815310191363, 0.15147777332458645, 0.14474889845587313, 0.11651886990875937, 0.3105339134344831, 0.12045231196680106, 0.10539610972045921, 0.15764810785185546, 0.15533907862845808, 0.1641086518066004, 0.12393694763886742, 0.2131336063030176, 0.11063278536312282, 0.07671323750400916, 0.14741988794412464, 0.12935901177115738, 0.0971411268983502, 0.08906655275495723, 0.10335588638554327], [0.031067645031725988, 0.08130444504786283, 0.02673244318430079, 0.018765708664432168, 0.03301455813925713, 0.06243658717721701, 0.031191008529276587, 0.02331361003598431, 0.04933688287565019, 0.046394712626351975, 0.02217878460214706, 0.04802804978680797, 0.00407189527322771, 0.02277248233440332, 0.013078974261588883, 0.010172113543376327, 0.0202854341478087, 0.03751176525838673, 0.04219736285449471, 0.014522766905429307, 0.03752085656742565, 0.030080761171120685, 0.03430557968385983, 0.0165682669103262, 0.026963714954035822, 0.046309265453601256, 0.04906487461994402, 0.08357328697456978, 0.08228029502788559, 0.14351742313010618, 0.04554244878818281, 0.034527763855294324, 0.05196555139264092, 0.052997711827629246, 0.017477531400800217, 0.0354547434108099, 0.04206994723062962, 0.13139153161318973, 0.009733649912959663, 0.04918543651001528, 0.06771840766305104, 0.05179868319828529, 0.024098976682580542, 0.06058238315745257, 0.02507243880245369, 0.04257427739503328, 0.04187611681118142, 0.05035311682149768, 0.03575663795345463, 0.04663356172386557, 0.04052754542499315, 0.040590000862721354, 0.05889076513994951, 0.03966853917518165, 0.09217364306095988, 0.058146673036389984, 0.06456063609221019, 0.04784925527928863, 0.06327552575385198, 1.0221310216002166, 3.861933695152402, 10.168117582798004, 22.989532090723515, 31.302952095866203, 34.624141082167625, 44.79387737810612, 39.73332032561302, 39.473725855350494, 35.0709743052721, 28.52824218571186, 25.85413947701454, 26.21438294649124, 24.93745196610689, 23.18126030266285, 22.805335074663162, 21.59138761460781, 17.932527847588062, 16.721559427678585, 16.073012128472328, 12.729793824255466, 11.345839686691761, 10.244577080011368, 7.868962129577994, 7.084990097209811, 4.98252491466701, 3.15593252889812, 3.463292336091399, 3.077603057026863, 2.6239978848025203, 4.241759413853288, 2.448186781257391, 2.956444420851767, 2.3749407241120934, 2.2080334927886724, 2.049286561086774, 2.5433172890916467, 2.662207684479654, 2.4475106550380588, 2.813545251265168, 5.253341607749462, 3.514612619765103, 8.571242820471525, 8.760392870754004, 11.05454446747899, 15.064066518098116, 17.48864896595478, 18.132110238075256, 23.231379613280296, 20.37158466875553, 25.461056269705296, 18.165782131254673, 16.107276789844036, 24.56082757562399, 24.75148994475603, 31.50132045149803, 30.668631233274937, 36.71858489513397, 34.37813088297844, 27.85869911313057, 17.165848687291145, 14.976243730634451, 7.236659908667207, 1.9914394151419401, 0.6808439630549401, 0.06420245335903019, 0.046091511903796345, 0.025830783852143213, 0.03153092329739593, 0.032918312717811204, 0.04700092111306731, 0.03069273428991437, 0.02810703055729391, 0.06104604362917598, 0.0036192522156852647, 0.0794707317254506, 0.02778355064947391, 0.03150008706143126, 0.06535137959872372, 0.01670154364546761, 0.019609471200965345, 0.049230807708227076, 0.01959535184141714, 0.010836243873200146, 0.014467853543465026, 0.027007971075363457, 0.01981516670639394, 0.029975999605085235, 0.032175901578739285, 0.011476223789941287, 0.015484102332266048, 0.0270974852173822, 0.022010326356394216, 0.027414944452175405, 0.041028866180568, 0.06874568847706541, 0.021194099354033824, 0.036798954679397866, 0.011602441772993188, 0.014890560451021884, 0.026023109567177016, 0.03905847894202452, 0.05046003432653379, 0.03939494643418584, 0.0804697663988918, 0.02050371462246403, 0.024323598809132818, 0.04514956322964281, 0.04490574916417245, 0.04246512602549046, 0.03365143958944827, 0.03077201050473377, 0.0371002740575932, 0.03865507344016805, 0.06127797591034323, 0.02862530753191095, 0.037501991173485294, 0.05376571221859194, 0.035020015566260554, 0.025125611828116234, 0.026081943324243184, 0.030680128911626525, 0.058764941422850825, 0.08979077756521292, 0.05408004144555889, 0.049722725452738814, 0.04029425130283926, 0.016406873910455033, 0.036854370846413076, 0.07131592399673536, 0.02067498931864975, 0.015336771175498143, 0.022379889924195595, 0.007040451655484503, 0.03431285273109097, 0.033938071865122765, 0.016409146737714764, 0.02341529539990006, 0.04811501465155743, 0.05036058653786313, 0.03330199564516079, 0.02649645321071148, 0.05468068011396099, 0.024918363378674258, 0.007860292917030165, 0.0707233339198865, 0.07703234616201371, 0.0337544571084436, 0.0466019722080091, 0.047612165071768686, 0.03806482483923901, 0.045111609797459096, 0.0443045909923967, 0.0010501292217668379, 0.02583839828730561, 0.016979134707071353, 0.04824700561584905, 0.06080331309931353, 0.008874957220541546, 0.05940235350863077, 0.012289466430956963, 0.028680718132818583, 0.06719279641401954, 0.0585173349827528, 0.045909448235761374, 0.04832327613257803, 0.0701384102285374, 0.09327560619567521, 0.05893655936233699, 0.02254552615340799, 0.06272849612287246, 0.04589903590385802, 0.037752517964690924, 0.051383737300056964, 0.07806903740856797, 0.21794144675368443, 1.6691405908204615, 5.782233802601695, 13.619732670485973, 28.15794825553894, 37.74313911795616, 41.77917614579201, 51.726502776145935, 44.766313657164574, 43.215818256139755, 38.112141117453575, 32.324694469571114, 27.712207473814487, 28.091655112802982, 26.847501173615456, 27.539198957383633, 25.093748979270458, 25.460260212421417, 21.55496846884489, 20.744422562420368, 21.30846619606018, 20.484516508877277, 16.84368297457695, 14.614486992359161, 10.572174601256847, 8.839530274271965, 6.193940760567784, 4.4223651476204395, 3.173408741131425, 3.966616652905941, 3.2591658644378185, 3.4944858122617006, 2.404231452383101, 3.400225695222616, 2.3220843728631735, 2.3802421521395445, 2.9982523899525404, 2.459779721684754, 3.3074743347242475, 3.089987304992974, 3.2231046119704843, 4.809080371633172, 4.920198284089565, 9.929721225053072, 12.166389506310225, 13.011956233531237, 16.10682461410761, 18.035914599895477, 19.791302606463432, 26.45626086741686, 22.712399661540985, 25.169944390654564, 20.445222817361355, 20.05761131644249, 25.83734057843685, 24.93025705218315, 30.561862662434578, 33.34850013256073, 40.763365253806114, 40.68242199718952, 33.719956800341606, 23.954473212361336, 19.82549697160721, 9.213680997490883, 3.0717753572389483, 0.7923436362762004, 0.03180594838340767, 0.02673887760465732, 0.03720047512615565, 0.009889661414490547, 0.020320302101026755, 0.04905605048406869, 0.0772052220418118, 0.0492702194605954, 0.025136545518762432, 0.016034967011364643, 0.026578994875308126, 0.04885907706920989, 0.03317518116091378, 0.03755732570425607, 0.06803150492487475, 0.042275010055163875, 0.030727246012247633, 0.01536285859401687, 0.014918980068614474, 0.06959092788747512, 0.054170190123841166, 0.007323006757360417, 0.047474155289819464, 0.010881231009989278, 0.018627261015353724, 0.07112127350410447, 0.08212387256207876, 0.030689079212606885, 0.030007214336364996, 0.10057119245175272, 0.017392961817677133, 0.029890439254813828, 0.0269933990057325, 0.004751096766995033, 0.01728023144096369, 0.03388654826267157, 0.07726011128397658, 0.011041857742384309, 0.016907504468690604, 0.07565876439912245, 0.015954054360918235, 0.021088512148708105, 0.06892605262692086, 0.03723253961652517, 0.02919184265920194, 0.05659824870235752, 0.06303762289462611, 0.020125547707721125, 0.034115990638383664, 0.024417417407676112, 0.05179798186873086, 0.06373062555212528, 0.1398324075853452, 0.12382928427541628, 0.15496355190407485, 0.08797860136837699, 0.13338983844732866, 0.2655416855122894, 0.17331545386696234, 0.08717475895537063, 0.17207547352882102, 0.15126676589716226, 0.09715466367197223, 0.1166667279903777, 0.11098996619693935, 0.0997192959766835, 0.1462975231697783, 0.11468957978649996, 0.09642807141062804, 0.11536330886883661, 0.12243108547409065, 0.14858693000860512, 0.14698310435051098, 0.17649156390689313, 0.13734640582697466, 0.1789686005213298, 0.1599151166738011, 0.11948428422329016, 0.19295455160317943, 0.1342221422237344, 0.21007285569794476, 0.24345789395738393, 0.16433457640232518, 0.11296251308522187, 0.16196670971112326, 0.23352457385044545, 0.08631318487459794, 0.11091782202129252, 0.23078924015862867, 0.18655876745469868, 0.10683215063181706, 0.245607242686674, 0.166332601220347, 0.21639962011249736, 0.18510620633605868, 0.23149833257775754, 0.14146587462164462, 0.1761904449085705, 0.1696037210058421, 0.11051612716983072, 0.1734146344824694, 0.18706641130847856, 0.12712531053693965, 0.21723505575209856, 0.1393104699673131, 0.17344605701509863, 0.19454497407423332, 0.28976874018553644, 0.19609373237472028, 0.22249346890021116, 0.2740364265628159, 1.6398423817008734, 5.928038628771901, 15.386173333972692, 30.231149308383465, 43.311516121029854, 47.83953174948692, 58.201112151145935, 53.990189507603645, 52.53649391233921, 47.44409076869488, 41.35756976902485, 39.71077613532543, 37.770531848073006, 35.547430738806725, 34.967851638793945, 35.75482740998268, 35.7586994022131, 33.02964024245739, 29.206921868026257, 27.882635928690434, 22.677346542477608, 19.397085160017014, 17.433075048029423, 11.97757763788104, 11.385354716330767, 8.845412358641624, 6.3357895240187645, 5.14882299117744, 4.957150826230645, 4.058460099622607, 5.817504934966564, 3.5489105293527246, 4.056848986074328, 3.6794681986793876, 3.457874064333737, 3.511038674041629, 3.605185984633863, 3.7334846751764417, 3.7572452751919627, 3.78365789540112, 7.247909205034375, 4.66335391625762, 11.866210363805294, 13.048496022820473, 15.379781126976013, 20.864727906882763, 23.54177925735712, 27.041070386767387, 31.047184020280838, 31.980368345975876, 34.74086321890354, 29.018263891339302, 27.233026586472988, 34.4343488663435, 34.85624022781849, 42.43881694972515, 41.032387018203735, 48.111391961574554, 47.228756323456764, 37.80488580465317, 27.944261021912098, 20.199472904205322, 10.114086382091045, 3.190810144878924, 1.0814617504365742, 0.15673523652367294, 0.12261046256753616, 0.16819874639622867, 0.1511948072584346, 0.15411809727083892, 0.10833994980202988, 0.10514723049709573, 0.16322248295182362, 0.11459649220341817, 0.18641921400558203, 0.16610210499493405, 0.11990802086074837, 0.08610798846348189, 0.12028326556901447, 0.09394388791406527, 0.12115263962186873, 0.12925039103720337, 0.14914615312591195, 0.16359121160348877, 0.18396763305645436, 0.09752096550073475, 0.12985868495889008, 0.11208629643078893, 0.14893603627569973, 0.09319651551777497, 0.15463623509276658, 0.17694145382847637, 0.07047745297313668, 0.1433418903616257, 0.1425208375439979, 0.15424582088598981, 0.09748719778144732, 0.1511722756549716, 0.13654837443027645, 0.15278773818863556, 0.15458136069355533, 0.13140940252924338, 0.14860141673125327, 0.18297386763151735, 0.18347299162996933, 0.08656132937176153, 0.09938273200532421, 0.1632634791894816, 0.19086463405983523, 0.09645357160479762, 0.1736091068596579, 0.18713612866122276, 0.09297542230342515, 0.19714094727532938, 0.14530257030855864, 0.14805293991230428, 0.12032248065224849], [0.024777149374131113, 0.028106930367357563, 0.012978290797036607, 0.018063197239825968, 0.013147458721505245, 0.026601840036164504, 0.012910972436657175, 0.04480765579501167, 0.07861105012125336, 0.03322315729747061, 0.017903795051097404, 0.015720188785053324, 0.040279033564729616, 0.053115761547815055, 0.04505411932768766, 0.033303405725746416, 0.10199752607150003, 0.019285147100163158, 0.029069093288853765, 0.03113405611657072, 0.08869267359841615, 0.022893532186571974, 0.021512931562028825, 0.03067116191232344, 0.02234368796052877, 0.03121984096651431, 0.0323153065983206, 0.0759331883455161, 0.013269699720694916, 0.006677913906969479, 0.02383763865509536, 0.025870846839097794, 0.0724440478370525, 0.04594973572238814, 0.03538753080647439, 0.008943284901761217, 0.04035524842038285, 0.03521314465615433, 0.010088876115332823, 0.033172798866871744, 0.06023411922797095, 0.034304366272408515, 0.02846895185939502, 0.01942146849614801, 0.051209340017521754, 0.06671183276921511, 0.025609386357245967, 0.046379955019801855, 0.05443240574095398, 0.06885738912387751, 0.04530673897534143, 0.054683006746927276, 0.023721602010482457, 0.026370872546976898, 0.06851781945442781, 0.01606251738849096, 0.06059019797248766, 0.02913157284638146, 0.015587706147925928, 0.04795599466888234, 0.26817271776963025, 2.575315609574318, 7.054074956104159, 16.20499424636364, 26.34728841483593, 36.28735363483429, 42.12851420044899, 43.24465490877628, 40.3876756131649, 36.93918205797672, 39.18559871613979, 31.279304064810276, 27.003456205129623, 24.13970947265625, 20.13992439955473, 18.757797963917255, 22.523074820637703, 26.408959105610847, 22.98190400004387, 12.06602169200778, 21.626782715320587, 16.432894617319107, 11.308817323297262, 8.108089473098516, 9.438259396702051, 12.14811248704791, 8.623715154826641, 8.13824275508523, 8.283092882484198, 8.766628336161375, 11.162617318332195, 9.417689200490713, 8.795081209391356, 7.766817435622215, 7.051702458411455, 7.572180954739451, 5.650645438581705, 9.362988285720348, 7.74117736145854, 8.353384360671043, 11.231363229453564, 10.130269713699818, 13.93939146772027, 18.50918300449848, 22.997920140624046, 20.751492083072662, 21.39467976987362, 15.739268437027931, 26.60948384553194, 27.334792725741863, 24.741236194968224, 20.780017152428627, 20.790419094264507, 27.650274597108364, 33.96413929760456, 35.983480140566826, 34.314039722085, 18.524543680250645, 16.367616020143032, 8.601719085127115, 2.9989919252693653, 1.3981943484395742, 0.07465902468538843, 0.03761204796319362, 0.030835833349556196, 0.0789861983503215, 0.011926419847441139, 0.036201570328557864, 0.11581899496377446, 0.055286298593273386, 0.020082790724700317, 0.05393760475271847, 0.011830164221464656, 0.019305051500850823, 0.0032139535414899, 0.037390643046819605, 0.026717140099208336, 0.028243272172403522, 0.06773619694286026, 0.0655383562843781, 0.033292054577032104, 0.022586476006836165, 0.028327967920631636, 0.013915060208091745, 0.03373677172930911, 0.030941262848500628, 0.03563836929970421, 0.052382849899004214, 0.05524710948520806, 0.025360349427501205, 0.052635113315773197, 0.0834139330254402, 0.05314685382472817, 0.05977071850793436, 0.0483361857914133, 0.017570118034200277, 0.046343163048732094, 0.07756027291179635, 0.07326888560783118, 0.05881312536075711, 0.04216448200168088, 0.020835129944316577, 0.05592912835709285, 0.05509181137313135, 0.038292957324301824, 0.03180502069881186, 0.038885796020622365, 0.039815744166844524, 0.031043441740621347, 0.03478826882201247, 0.02889751431212062, 0.08375497956876643, 0.1038505946053192, 0.008577626886108192, 0.0670009438181296, 0.017994107001868542, 0.05046482117904816, 0.03677142842207104, 0.021650258568115532, 0.03751399170141667, 0.031762395447003655, 0.06791746651288122, 0.03253321970987599, 0.03697013475175481, 0.07422470502206124, 0.06943117317860015, 0.0378457205806626, 0.01938954501383705, 0.06260073540033773, 0.060835258846054785, 0.05376509252528194, 0.053490928330575116, 0.01033545097016031, 0.03725385038706008, 0.004083240391992149, 0.05942898918874562, 0.05962038536381442, 0.01396802728777402, 0.009667667418398196, 0.07022225065156817, 0.05923205659200903, 0.035877277769031934, 0.05169437805307098, 0.025321702087239828, 0.060330372070893645, 0.022733994555892423, 0.025269269353884738, 0.04050791190820746, 0.08136341610224918, 0.08566850345232524, 0.037667827782570384, 0.031498476600972936, 0.032030525981099345, 0.061454399256035686, 0.009743678183440352, 0.042678578829509206, 0.1004193045082502, 0.022662182491330896, 0.011604983628785703, 0.012376614977256395, 0.015755511303723324, 0.011752043901651632, 0.032033739480539225, 0.031288033205782995, 0.03321536103612743, 0.07402751638437621, 0.05228165435255505, 0.0422065951715922, 0.058074321059393696, 0.019823196744255256, 0.07499023035052232, 0.013656127666763496, 0.04221284776576795, 0.02570295077021001, 0.01586567384947557, 0.06896963895997033, 0.8441840764135122, 4.085975373163819, 10.045584607869387, 21.4527615532279, 33.52563142776489, 42.92630799114704, 47.34910346567631, 48.779836893081665, 44.091602861881256, 40.42886160314083, 43.053308576345444, 35.00899963080883, 30.754880905151367, 28.090038299560547, 25.38738202303648, 22.335304096341133, 28.501216135919094, 27.4852342531085, 28.863536193966866, 19.449702836573124, 26.186663433909416, 22.618654891848564, 17.480019629001617, 16.232214085757732, 14.305215887725353, 15.986084192991257, 14.241724144667387, 9.764727428555489, 10.576672609895468, 10.955641474574804, 12.610341534018517, 12.076883409172297, 10.854029227048159, 7.229516766965389, 8.212974295020103, 9.263269286602736, 8.435881733894348, 10.81144206225872, 10.371077042073011, 12.06504799425602, 12.69535532221198, 14.412717819213867, 16.1618684604764, 22.643646150827408, 26.186104863882065, 25.637437105178833, 27.537033073604107, 22.763364426791668, 28.058057315647602, 31.813809983432293, 24.527469165623188, 21.44119307398796, 25.027991607785225, 31.053096503019333, 37.139020934700966, 40.98846897482872, 40.19197091460228, 24.317796416580677, 19.990959092974663, 11.656920444220304, 5.215895567089319, 2.169794007204473, 0.1317967739305459, 0.03099442103120964, 0.023225672957778443, 0.02632867774082115, 0.02481179097230779, 0.0329593015339924, 0.05774357181508094, 0.11266650748439133, 0.01466966019506799, 0.016935010316956323, 0.02828454857080942, 0.0324375197669724, 0.09695783126517199, 0.023708037406322546, 0.0352711806044681, 0.06844335977802984, 0.023975524127308745, 0.06914467448950745, 0.04438120289705694, 0.011157877688674489, 0.005198517192184227, 0.030548809590982273, 0.05846695428772364, 0.0630181934684515, 0.033677318278932944, 0.06708114029606804, 0.05374371125071775, 0.015868538539507426, 0.03183112945407629, 0.08733702212339267, 0.12227219165652059, 0.05312111243256368, 0.012235493741172832, 0.05160529806744307, 0.04618355305865407, 0.04795886678039096, 0.014324286930786911, 0.06328089148155414, 0.009770798114914214, 0.021696896983485203, 0.0497795405681245, 0.028972753243579064, 0.03398571032448672, 0.025907009840011597, 0.04018344494397752, 0.00881784060766222, 0.042913097495329566, 0.10329830314731225, 0.03899606061168015, 0.04896238402579911, 0.05897653514693957, 0.02543096477893414, 0.07246322493301705, 0.04994499126041774, 0.1716878794832155, 0.10565048825810663, 0.15256671176757663, 0.2085300939506851, 0.09908375781378709, 0.14560155192157254, 0.1485578081337735, 0.11088222861872055, 0.21327387221390381, 0.1407459023175761, 0.13794221682474017, 0.08382702726521529, 0.2271319364081137, 0.18991842545801774, 0.1321278905379586, 0.12387668524752371, 0.1727179656154476, 0.10158658405998722, 0.07616096088895574, 0.13645458180690184, 0.16561755677685142, 0.22290758730378002, 0.17243099195184186, 0.0961543525045272, 0.12530964624602348, 0.11671182830468751, 0.14110165822785348, 0.10386427980847657, 0.08199888747185469, 0.1007283570652362, 0.08045763228437863, 0.18181331193773076, 0.2427585533587262, 0.1892252149991691, 0.20695487066404894, 0.1059171864471864, 0.1342509375535883, 0.12075352744432166, 0.1232772006187588, 0.08981981038232334, 0.16848082188516855, 0.12220726857776754, 0.1685492182150483, 0.15123224118724465, 0.12824828387238085, 0.16139546380145475, 0.10174682116485201, 0.13671376946149394, 0.15766683965921402, 0.12857025722041726, 0.08126600179821253, 0.12260262548807077, 0.1429550236207433, 0.09786188587895595, 0.2701735182199627, 0.07747816169285215, 0.1218516610970255, 0.15024540742160752, 0.12026684184093028, 0.15690563363023102, 0.961160680744797, 3.979052435606718, 10.112895146012306, 22.518866546452045, 36.28733083605766, 47.987902387976646, 54.10560831427574, 56.033476665616035, 52.917518466711044, 50.53200267255306, 53.584831058979034, 45.172074884176254, 37.785126864910126, 38.749587312340736, 31.19061302393675, 30.005756802856922, 37.28262662887573, 39.59439978003502, 39.58299279212952, 23.94030947238207, 33.669860288500786, 27.98720631748438, 20.312746725976467, 17.85442303866148, 17.740109972655773, 19.26190361380577, 14.234458934515715, 13.332612477242947, 12.946722283959389, 13.116526622325182, 17.635209001600742, 14.210696909576654, 12.462898045778275, 10.6708980537951, 10.988326370716095, 11.716624740511179, 8.884645253419876, 12.958709690719843, 11.415919326245785, 13.507388848811388, 17.600936740636826, 15.72357527911663, 20.75058203190565, 28.40354047715664, 31.900599226355553, 28.458230942487717, 36.59053556621075, 27.550877630710602, 38.14268007874489, 42.34249971807003, 34.4380346685648, 30.52510343492031, 32.420669719576836, 38.42669203877449, 44.14585255086422, 48.42743240296841, 46.900841519236565, 28.08376483619213, 22.794876135885715, 13.981564454734325, 5.216677375137806, 1.8910849001258612, 0.2799995237728581, 0.08171788067556918, 0.08647966344142333, 0.12337485241005197, 0.0829030830936972, 0.1478544154088013, 0.15072533948114142, 0.20835703995544463, 0.10502050878130831, 0.13092121778754517, 0.19722087658010423, 0.1467466412577778, 0.18528556858655065, 0.212815388222225, 0.16251000633928925, 0.15177924855379388, 0.09157059612334706, 0.1991096424171701, 0.14098754560109228, 0.13948309351690114, 0.11626835796050727, 0.09769098411197774, 0.14154218224575743, 0.14781981648411602, 0.13229046540800482, 0.23239159636432305, 0.17679719516308978, 0.13766782998573035, 0.1154257902817335, 0.2017534989863634, 0.287258677999489, 0.23554806917672977, 0.10981884974171408, 0.17718897492159158, 0.12245725360116921, 0.14501279132673517, 0.14876001368975267, 0.15570308722089976, 0.08175740746082738, 0.12454017269192263, 0.13687833328731358, 0.0931778950325679, 0.1545887821703218, 0.08984016749309376, 0.1029199043114204, 0.12391975949867629, 0.10063698384328745, 0.16794266091892496, 0.1477042937767692, 0.17751146777300164, 0.19775434717303142, 0.1259722505346872, 0.21962833357974887, 0.20141730608884245], [0.043181283690501004, 0.022513673175126314, 0.04036763857584447, 0.04741981523693539, 0.025946150708477944, 0.062181158500607125, 0.06848742108559236, 0.05397960288973991, 0.017901546343637165, 0.0097754931266536, 0.030636464653071016, 0.08470659842714667, 0.04592696663166862, 0.024170541983039584, 0.013434075226541609, 0.0472669476584997, 0.08335515492944978, 0.05816687800688669, 0.055785044096410275, 0.025605436276237015, 0.013052212416369002, 0.037765360830235295, 0.023256290260178503, 0.019441376607574057, 0.025446681611356325, 0.06648979702731594, 0.020623810814868193, 0.01420821410647477, 0.02833577716955915, 0.0059222368781775, 0.025132832925010007, 0.05258519646304194, 0.03663290284748655, 0.02236680029454874, 0.010136367072846042, 0.052622314979089424, 0.056372168255620636, 0.025443143422307912, 0.034000627492787316, 0.042208187078358606, 0.024606412735010963, 0.02811680835293373, 0.01424548197974218, 0.032522273031645454, 0.053829106473131105, 0.04853770857152995, 0.03666523451101966, 0.022818133693363052, 0.03818302298896015, 0.04274923128832597, 0.02063046231342014, 0.032555896032135934, 0.03989502780314069, 0.01889861061499687, 0.09498714716755785, 0.02443219542328734, 0.012983908854948822, 0.02412048968835734, 0.020513924719125498, 0.08595184059231542, 0.11328980763209984, 0.0826047694135923, 1.4759913738816977, 5.079709449782968, 11.97060501202941, 19.553444869816303, 28.73354896903038, 43.47728602588177, 47.34119608998299, 46.55120708048344, 47.468021884560585, 37.152628004550934, 31.25788651406765, 27.654594965279102, 19.7146113216877, 27.092200443148613, 20.02697166055441, 27.157099060714245, 25.761000774800777, 25.30294295400381, 18.60703345388174, 23.262762129306793, 22.159289941191673, 16.416618190705776, 13.486430123448372, 13.58905216678977, 12.626858297735453, 19.96608942747116, 16.461060605943203, 14.138056207448244, 20.74075385928154, 36.32452704012394, 27.103772722184658, 15.722597781568766, 11.692887414246798, 11.607242859899998, 14.989288430660963, 12.395960837602615, 16.254594884812832, 14.110799320042133, 20.208161137998104, 21.996183693408966, 25.4620024189353, 30.640573538839817, 38.37577477097511, 15.321034379303455, 17.4749867990613, 20.482861697673798, 19.47756104171276, 20.232789516448975, 21.32688570767641, 32.66567297279835, 36.85403622686863, 39.06978853046894, 32.38688953220844, 29.343490339815617, 20.787863731384277, 10.079531986266375, 5.875927275046706, 2.299658926203847, 0.33222436672076583, 0.051102916040690616, 0.020859056785411667, 0.020958844106644392, 0.06676976481685415, 0.0013965682796879264, 0.03454999859968666, 0.04131444089580327, 0.04260102810803801, 0.0118201730583678, 0.05306938102876302, 0.05029870255384594, 0.060975424567004666, 0.03347366553498432, 0.019214060484955553, 0.036284839297877625, 0.003423782345635118, 0.09506862756097689, 0.01992248868191382, 0.02132387500751065, 0.07170785218477249, 0.061072805474395864, 0.046963943605078384, 0.025992900445999112, 0.039783601750968955, 0.026960158211295493, 0.03956516913603991, 0.0365460901230108, 0.051479433532222174, 0.00685806097862951, 0.03259715944295749, 0.02861680623027496, 0.04120259181945585, 0.023346355446847156, 0.018969064549310133, 0.025442059886700008, 0.052746368673979305, 0.021818670429638587, 0.10042986526968889, 0.010520409941818798, 0.007661937715965905, 0.02051900100923376, 0.06161779419926461, 0.017328623180219438, 0.0554078438290162, 0.016706553142284974, 0.03176418031216599, 0.014027621746208752, 0.010128065223398153, 0.08917406768887304, 0.02003981666348409, 0.08444724007858895, 0.10547623198362999, 0.01941139384143753, 0.018300281881238334, 0.06345036832499318, 0.08368948503630236, 0.029386704663920682, 0.07001939942711033, 0.04094497751793824, 0.055349815302179195, 0.06514855063869618, 0.03110484147327952, 0.038057637138990685, 0.029518671508412808, 0.03390308702364564, 0.0365578865603311, 0.025933883007382974, 0.03806693624937907, 0.04881877845036797, 0.06664472777629271, 0.04827572302019689, 0.06050758580386173, 0.03014984027686296, 0.06132722854090389, 0.11405799727072008, 0.048074808801175095, 0.014842307864455506, 0.01969646389625268, 0.017992915854847524, 0.043140625130035914, 0.04565659481158946, 0.06118784578575287, 0.026614335947670043, 0.044951910749659874, 0.015826590497454163, 0.05070850907941349, 0.05014963848225307, 0.026611460125423037, 0.06587386640603654, 0.08947920170612633, 0.02696457213460235, 0.04212738203932531, 0.06617233593715355, 0.026563788269413635, 0.020043853946845047, 0.020366174248920288, 0.08884846523869783, 0.055611704374314286, 0.025571308615326416, 0.036108905769651756, 0.06467150553362444, 0.05504696338903159, 0.0027169736540599843, 0.06338783496175893, 0.007072208154568216, 0.022540989775734488, 0.024915465291996952, 0.05239620113570709, 0.04128267326450441, 0.0641497534525115, 0.009353276964247925, 0.037954586223349907, 0.0191986460777116, 0.023530161306553055, 0.06615859136218205, 0.10017856664489955, 0.1960530033102259, 1.9772087037563324, 6.6346420627087355, 16.09730802476406, 26.284418888390064, 36.29417046904564, 48.96084018051624, 52.54496745765209, 51.526983082294464, 51.05334609746933, 42.96504311263561, 36.5123775601387, 31.425636112689972, 20.053251050412655, 27.83879578113556, 26.752316281199455, 27.391006909310818, 28.11838287860155, 27.05936260521412, 26.7107655107975, 29.112278446555138, 28.39290864765644, 22.24465236067772, 21.21386457234621, 22.726635597646236, 19.989313781261444, 26.944912746548653, 23.2794888317585, 19.96761504560709, 26.072553656995296, 37.10407800972462, 30.863670967519283, 19.63197335600853, 16.933968029916286, 20.35141345113516, 20.014510229229927, 17.030290961265564, 20.951346158981323, 18.8692706823349, 27.31536816805601, 26.892458461225033, 27.64967802911997, 36.93021073937416, 45.158201828598976, 21.80231049656868, 21.385398767888546, 22.593521140515804, 23.44294846057892, 24.691637456417084, 24.82934206724167, 34.342591390013695, 38.23086194694042, 41.01259768009186, 38.391467928886414, 34.67044159770012, 26.894588246941566, 13.318259697407484, 8.627895880490541, 3.8683484634384513, 0.6563007831573486, 0.16859494935488328, 0.07938238646602258, 0.006937505568203051, 0.07103224546881393, 0.04087727138539776, 0.053646790474886075, 0.030218390602385625, 0.021053970740467776, 0.003012501033481385, 0.04940654456731863, 0.016236584415310062, 0.014849441758997273, 0.05337788810720667, 0.027774802583735436, 0.04588034120388329, 0.04799169568286743, 0.03596564900362864, 0.03657606175693218, 0.03567847867088858, 0.05039181240135804, 0.046513749402947724, 0.01803834271413507, 0.02851335084415041, 0.025567191551090218, 0.056167806760640815, 0.01963906062883325, 0.04394113158923574, 0.03295375398010947, 0.06928253584192134, 0.10313143124221824, 0.04664380336180329, 0.0782088580308482, 0.04958473422448151, 0.02485412307578372, 0.012790898508683313, 0.029000541107961908, 0.022239182435441762, 0.029280095150170382, 0.021136352843313944, 0.02194554799643811, 0.011003220606653485, 0.07998670989763923, 0.020317287126090378, 0.08392744726734236, 0.013586368568212492, 0.0855397482519038, 0.046840613504173234, 0.09190842916723341, 0.019714050940820016, 0.0849570361606311, 0.04711206514912192, 0.04457903349248227, 0.03684518676891457, 0.050208780230605043, 0.07379584756563418, 0.23351399082457647, 0.10196525006904267, 0.17488484387286007, 0.16933573147980496, 0.17045782908098772, 0.13283775479067117, 0.18944889830891043, 0.1354090144741349, 0.2818536461563781, 0.07879349228460342, 0.11107595142675564, 0.2606721280608326, 0.12453012401238084, 0.10248623773804866, 0.0878454749181401, 0.17806706920964643, 0.15140720992349088, 0.1516437323880382, 0.18572677538031712, 0.27336457511410117, 0.15352887654444203, 0.12258520728209987, 0.06376126882969402, 0.18215941992821172, 0.142440655909013, 0.11173278922797181, 0.26524411397986114, 0.11158769193571061, 0.1169245872006286, 0.05964492076600436, 0.17063190724002197, 0.1943574333563447, 0.1312306636827998, 0.17832312500104308, 0.18020945659372956, 0.12132520379964262, 0.16982957138679922, 0.17602309060748667, 0.13924257829785347, 0.11651465450995602, 0.12225367507198825, 0.15586190682370216, 0.1322433538734913, 0.11645280392258428, 0.16995233745547011, 0.217927509220317, 0.17879989551147446, 0.17713956272928044, 0.15927985310554504, 0.07451564175426029, 0.13384066347498447, 0.0903665876830928, 0.12200583485537209, 0.1514063638751395, 0.25399843929335475, 0.2492349495878443, 0.167440612858627, 0.08104568041744642, 0.09364955956698395, 0.2026579692028463, 0.23691494192462415, 0.31571478699333966, 1.8757617473602295, 7.38904170691967, 17.888832092285156, 28.81973784416914, 39.447932839393616, 54.67151574790478, 59.92315694689751, 60.53367778658867, 58.3123891800642, 53.99702534079552, 42.05351382493973, 43.48104402422905, 29.44231353700161, 40.10328747332096, 34.32320103049278, 37.68968738615513, 39.5104318857193, 36.79718367755413, 30.537825152277946, 37.51113496720791, 36.67468585073948, 28.617934472858906, 26.549952439963818, 27.084329165518284, 21.774735376238823, 31.634539403021336, 25.868189223110676, 22.94597502797842, 31.667289845645428, 47.10177853703499, 34.96296510100365, 23.138936273753643, 20.028966553509235, 20.457423962652683, 22.876478657126427, 20.0922654569149, 24.693354964256287, 22.726880684494972, 30.55884562432766, 34.16082814335823, 33.448096588253975, 45.82000091671944, 51.33660949766636, 24.100368283689022, 29.565499126911163, 34.307416677474976, 29.422997273504734, 31.448508985340595, 33.43204624950886, 44.14218954741955, 48.32869090139866, 48.832008093595505, 43.23524661362171, 39.41882260143757, 29.789081029593945, 16.745824925601482, 9.634606260806322, 4.2157498095184565, 0.851334105245769, 0.25651654636021703, 0.13248076691525057, 0.11704716031090356, 0.19376006384845823, 0.10160893754800782, 0.16162269457709044, 0.18285047815879807, 0.14751121663721278, 0.061833811123506166, 0.1257562410319224, 0.10026129384641536, 0.10687569243600592, 0.19121240446111187, 0.15207411866867915, 0.14763481391128153, 0.11220647240406834, 0.2959129214286804, 0.1399402119568549, 0.20157845603534952, 0.14221339544747025, 0.19378915603738278, 0.171413863718044, 0.13503406662493944, 0.13863122672773898, 0.11618756776442751, 0.18082111986586824, 0.15158860565861687, 0.1345622685039416, 0.1330774833331816, 0.1917154766852036, 0.0952296142349951, 0.12364823734969832, 0.19290246767923236, 0.08954577977419831, 0.0855767739994917, 0.11844248700072058, 0.1589500278350897, 0.18853911431506276, 0.1201793500513304, 0.09379108712892048, 0.12665958318393677, 0.2712523040827364, 0.19902261818060651, 0.1706338071380742, 0.10920337183051743, 0.11862436513183638, 0.08565152311348356, 0.11410274135414511, 0.20938816509442404, 0.13255386846140027, 0.19635922828456387, 0.226763415557798, 0.1170122274197638, 0.13312968600075692, 0.18231996131362393], [0.07096304761944339, 0.07637315575266257, 0.034895527714979835, 0.06508284830488265, 0.02035852270637406, 0.006859875065856613, 0.008236328940256499, 0.030421444062085357, 0.03623842909291852, 0.07537400975706987, 0.016120197105919942, 0.01725903755868785, 0.06108575966209173, 0.06974959163926542, 0.020029632541991305, 0.024233064214058686, 0.08341813358129002, 0.049066232750192285, 0.037795462340000086, 0.017704472738842014, 0.015730137274658773, 0.029043272115814034, 0.04491432096983772, 0.0416561071324395, 0.010123347019543871, 0.08112790295854211, 0.03641128270828631, 0.039149451404227875, 0.023109426656446885, 0.030586128486902453, 0.03707419498823583, 0.0017443333467781486, 0.021062104679003824, 0.03423812217079103, 0.04624692504876293, 0.02461663581925677, 0.04904985355096869, 0.03679358895169571, 0.06107882800279185, 0.052496302014333196, 0.03626969948527403, 0.07631917193066329, 0.030925204628147185, 0.0037428367340908153, 0.08867127748089842, 0.011202384284842992, 0.08048135874560103, 0.005095347532915184, 0.010639430020091822, 0.06565156349097379, 0.04125417850445956, 0.03569074637198355, 0.02242802376713371, 0.07885474915383384, 0.03319709678180516, 0.0243100360603421, 0.0009260561034807324, 0.02911691914050607, 0.030879041187290568, 0.04599719977704808, 0.01683855523879174, 0.04564938113617245, 0.02763486136245774, 0.7041292323265225, 2.141530648805201, 7.40117778070271, 12.727550994604826, 24.704718254506588, 29.959784969687462, 32.59765662252903, 44.15742672979832, 40.35914294421673, 36.60222753882408, 30.014722421765327, 36.05339638888836, 31.18739079684019, 30.472993031144142, 22.21750281751156, 29.103407822549343, 24.996449500322342, 16.975623294711113, 19.42561972886324, 25.897086672484875, 21.282589584589005, 14.770733658224344, 16.686025634407997, 30.75577385723591, 23.703038804233074, 29.301219508051872, 32.983544915914536, 18.896836303174496, 28.436758294701576, 66.16788625717163, 51.72151364386082, 22.44091372936964, 12.921703476458788, 19.50008623301983, 23.232576549053192, 26.557249948382378, 22.96250034123659, 19.47044212371111, 22.86806780844927, 19.831926226615906, 40.57540833950043, 35.9191419929266, 22.68786057829857, 18.879000060260296, 27.39687379449606, 21.3186002522707, 21.06247689574957, 25.549331232905388, 35.13681337237358, 36.220678612589836, 32.95057788491249, 22.590775787830353, 14.472797345370054, 9.940012022852898, 3.9090725407004356, 1.0659138159826398, 0.060967379686189815, 0.1571953235543333, 0.09757277483004145, 0.013529065490729408, 0.035470818329486065, 0.0759035766532179, 0.03385401621926576, 0.03796725097345188, 0.06884846108732745, 0.033639416797086596, 0.02073287127132062, 0.019454345638223458, 0.02320958134077955, 0.10570122889475897, 0.0861631374573335, 0.010636408551363274, 0.07268060740898363, 0.03499861944874283, 0.03858374933770392, 0.07594409791636281, 0.02977320404170314, 0.006967555127630476, 0.006399191997843445, 0.03904739125573542, 0.07272211572853848, 0.03419934866542462, 0.008948460454121232, 0.05270043344353326, 0.02977088668558281, 0.03853201793390326, 0.06506194942630827, 0.02276027214975329, 0.029809049774485175, 0.02813735842210008, 0.0317013241146924, 0.050810580360121094, 0.037944923460599966, 0.0937506697664503, 0.035627211109385826, 0.055956250143935904, 0.03413745725993067, 0.02348717982386006, 0.03785434804740362, 0.06483707868028432, 0.018496785887691658, 0.014615212530770805, 0.004401526657602517, 0.06194571957166772, 0.07088212383678183, 0.03431029232160654, 0.055828021868364885, 0.006688725607091328, 0.08822597403195687, 0.011729762773029506, 0.013857620760973077, 0.09612783556804061, 0.05790147486550268, 0.03414739832805935, 0.0953286315780133, 0.04618402061169036, 0.06011479672451969, 0.12261911600944586, 0.037945346484775655, 0.014723071635671658, 0.10183714795857668, 0.08313069236464798, 0.11914701521163806, 0.041503128231852315, 0.04770231375005096, 0.06609779462451115, 0.051975852402392775, 0.013665552014572313, 0.019847823059535585, 0.033916163665708154, 0.03809668523899745, 0.03983124021033291, 0.05423124661319889, 0.01974766837520292, 0.03210851085896138, 0.06673041614703834, 0.035424204033915885, 0.026430600591993425, 0.02762810225249268, 0.015644311606592964, 0.01694649505225243, 0.025237982263206504, 0.03467766284302343, 0.023911833013698924, 0.03408463489904534, 0.019987341256637592, 0.08186205770471133, 0.031052679623826407, 0.09251914991182275, 0.05357841269869823, 0.04748166582430713, 0.017671230089035816, 0.012353511920082383, 0.006976125077926554, 0.02870063552109059, 0.03083762749156449, 0.059537661873036996, 0.06208490565768443, 0.06442726473324001, 0.022824738807685208, 0.028556061442941427, 0.05266643194772769, 0.021765647688880563, 0.1294795810827054, 0.07964262797031552, 0.032526117356610484, 0.07259603968122974, 0.021139627569937147, 0.015843507753743324, 0.02030404535616981, 0.07154929233365692, 0.04030773983686231, 0.0637903090682812, 0.020432097371667624, 0.02501727496564854, 0.07365379307884723, 1.3170090923085809, 2.871430632658303, 9.541702196002007, 17.552717328071594, 31.660999283194542, 36.05344958603382, 42.08008199930191, 50.87643139064312, 47.47308321297169, 44.33755226433277, 37.258266136050224, 39.557986333966255, 35.36614626646042, 32.92152464389801, 26.829851120710373, 33.93040470778942, 27.499551884829998, 17.382665053009987, 23.504463359713554, 28.907389640808105, 24.05849453061819, 19.39057420939207, 22.531147487461567, 33.04681912064552, 30.913915671408176, 34.46147181093693, 39.95298273861408, 30.797292329370975, 39.995149075984955, 70.34994944930077, 50.33689834177494, 24.337526857852936, 18.66412729024887, 26.73682641237974, 28.36376041173935, 31.0042330250144, 30.37504568696022, 26.189997754991055, 28.90468418598175, 24.47440881282091, 45.808818116784096, 42.4576373398304, 22.197255603969097, 22.58290071040392, 28.565761372447014, 25.096251145005226, 22.54812877625227, 28.883547820150852, 39.93673101067543, 42.62816458940506, 39.24809396266937, 27.37338535487652, 18.800082094967365, 12.732486929744482, 5.473821451887488, 1.4709098590537906, 0.22337447240715846, 0.10356350961956196, 0.09426435470231809, 0.05032247725466732, 0.008471281762467697, 0.021033780612924602, 0.011988737060164567, 0.03275455783295911, 0.019808494798780885, 0.05348356622562278, 0.0329853954463033, 0.04603016597684473, 0.04072533149155788, 0.0067389003561402205, 0.09733977014548145, 0.00962224519753363, 0.007293327807929018, 0.012931797100463882, 0.0080748320397106, 0.06853724145912565, 0.058032408269355074, 0.04870190503424965, 0.015512214886257425, 0.013237785515229916, 0.04836553031054791, 0.03666049218736589, 0.01941349226399325, 0.0673168983485084, 0.024260124773718417, 0.05286492305458523, 0.02273066231282428, 0.08650397619931027, 0.035737709476961754, 0.03842642516246997, 0.028224900306668133, 0.03558442258508876, 0.06205096353369299, 0.03529896661348175, 0.05373248626710847, 0.023743875717627816, 0.0646657835750375, 0.042207292790408246, 0.015506269355682889, 0.029969804527354427, 0.03065252287342446, 0.07413820771034807, 0.05542936240090057, 0.021971550995658617, 0.029358382453210652, 0.05036733637098223, 0.025302007343270816, 0.017170655191875994, 0.028308447581366636, 0.05903346529521514, 0.035970933095086366, 0.0916433785459958, 0.022190046693140175, 0.1163021034153644, 0.2049629611428827, 0.14684666792163625, 0.12717104167677462, 0.24641251744469628, 0.28541319421492517, 0.11749336175853387, 0.14389986667083576, 0.1335192096303217, 0.22470861644251272, 0.20778395351953804, 0.09858995501417667, 0.18073369486955926, 0.1602238797931932, 0.13217399275163189, 0.10413128227810375, 0.20119780849199742, 0.13285176653880626, 0.09908947977237403, 0.1353067613672465, 0.07090461833286099, 0.08515939756762236, 0.18951805162942037, 0.1054742801352404, 0.07950434359372593, 0.15884387103142217, 0.11689868624671362, 0.11180718211107887, 0.2232725013163872, 0.11167639342602342, 0.15692665125243366, 0.07763273621094413, 0.09390195657033473, 0.1222173024143558, 0.09059456060640514, 0.11290036563877948, 0.31403278349898756, 0.13611165020847693, 0.1757515684585087, 0.11844483960885555, 0.14493902184767649, 0.11354241243680008, 0.12617133907042444, 0.12141740080551244, 0.12947647890541703, 0.15299650433007628, 0.2830798225477338, 0.13055936142336577, 0.15644820348825306, 0.145983490801882, 0.2024583166348748, 0.26073532935697585, 0.13738682318944484, 0.10985776054440066, 0.18346322496654466, 0.15069826593389735, 0.10008703757193871, 0.14789216103963554, 0.17796034837374464, 0.1506967074237764, 0.09216841091983952, 0.09532842377666384, 0.11193219688721001, 1.5368257532827556, 3.5714523447677493, 10.829726681113243, 19.483902901411057, 34.00982424616814, 40.146004781126976, 46.48523882031441, 56.611691638827324, 58.11512656509876, 53.25612969696522, 47.80346408486366, 50.63688084483147, 46.45627297461033, 44.329082518815994, 33.487800657749176, 43.90740014612675, 36.09521694481373, 28.30685466527939, 29.063280075788498, 37.29085698723793, 32.194524854421616, 26.414301618933678, 30.885253809392452, 43.2905450463295, 37.12835870683193, 43.533116430044174, 46.04707293212414, 31.529708728194237, 42.56682828068733, 77.85004779696465, 58.80361162126064, 32.114645540714264, 23.851314447820187, 31.935219168663025, 33.58570620417595, 38.386554792523384, 34.34601500630379, 30.703488662838936, 36.111567467451096, 28.58357671648264, 54.364857003092766, 50.27162924408913, 33.50444756448269, 30.314638428390026, 41.79532527923584, 34.989126697182655, 31.05470761656761, 37.12336577475071, 48.13946485519409, 48.337373435497284, 43.93037751317024, 32.81392961740494, 22.243584617972374, 13.792377356439829, 6.172797745093703, 2.0162209728732705, 0.45166160620283335, 0.30211531673558056, 0.20334154658485204, 0.15471594175323844, 0.11606328029301949, 0.11777789375628345, 0.15110761974938214, 0.10662198183126748, 0.1142681363853626, 0.15035943099064752, 0.1296095608267933, 0.07874771661590785, 0.11822546075563878, 0.19733230263227597, 0.24562496517319232, 0.09583182996721007, 0.16322521405527368, 0.11094415342085995, 0.1322694032569416, 0.15125753358006477, 0.11020147881936282, 0.20572579989675432, 0.08787962113274261, 0.1024525442335289, 0.18898746056947857, 0.14637325191870332, 0.08153580216458067, 0.18659977853531018, 0.12364126858301461, 0.17088760680053383, 0.09738874447066337, 0.16366168594686314, 0.24537777062505484, 0.16157144185854122, 0.11879637269885279, 0.17024055792717263, 0.12942237633978948, 0.2306929836049676, 0.10591536076390184, 0.10451680573169142, 0.18900151684647426, 0.13346311810892075, 0.10304282623110339, 0.1017151314590592, 0.12239195202710107, 0.11376315684174187, 0.14867717516608536, 0.07984467025380582, 0.1487983381957747, 0.15668908978113905, 0.09383132637594827, 0.07827342487871647, 0.14154357748338953, 0.12084444795618765, 0.11959396622842178, 0.157310786889866, 0.16284481884213164], [0.07166853320086375, 0.016210637077165302, 0.037581679280265234, 0.028695728069578763, 0.1176136861613486, 0.07556341326562688, 0.016005026918719523, 0.040931051116785966, 0.04488351070904173, 0.056817827935446985, 0.10104118715389632, 0.09204080604831688, 0.1019466741126962, 0.022468025526904967, 0.029394291268545203, 0.047010249909362756, 0.02228848145023221, 0.018523234175518155, 0.015006264056864893, 0.0615754138561897, 0.10642485998687334, 0.0465779154910706, 0.02923260697571095, 0.03090338363108458, 0.033557832502992824, 0.12038732209475711, 0.010027592343249125, 0.034097251409548335, 0.0109628264362982, 0.022887507802806795, 0.010211138451268198, 0.045006124637438916, 0.04946388660755474, 0.059373224212322384, 0.03388742028619163, 0.09555806653224863, 0.0038018724944777205, 0.06574602404725738, 0.04251434525940567, 0.039537824704893865, 0.06603842281037942, 0.006521268796859658, 0.023957554876687936, 0.018146672155125998, 0.02247864566015778, 0.025888624986691866, 0.012683439235843252, 0.017306262270722073, 0.06644151289947331, 0.022767381924495567, 0.027939355277339928, 0.051752065191976726, 0.11174238519743085, 0.04159993397479411, 0.05988041535601951, 0.01536963996841223, 0.034885497589129955, 0.04006483119155746, 0.06325899070361629, 0.030767668940825388, 0.0395024279714562, 0.045976890905876644, 0.025232139705622103, 0.06878924512420781, 0.13724048651056364, 1.0179684637114406, 4.043167820200324, 6.821843292564154, 15.392982568591833, 19.505787827074528, 27.2117705270648, 34.65138182044029, 36.52263320982456, 38.68642330169678, 37.133446633815765, 43.409797847270966, 32.76968479156494, 25.38552202284336, 28.155257999897003, 29.212518967688084, 32.38463245332241, 28.70616763830185, 25.56742586195469, 28.371192812919617, 30.188386403024197, 26.47251259535551, 21.192568615078926, 24.586643390357494, 24.010596200823784, 20.025130659341812, 22.00491562485695, 14.879423975944519, 38.47747251391411, 67.9399211704731, 63.68939325213432, 33.53619486093521, 23.707414269447327, 17.85198736935854, 23.58866684138775, 21.82802751660347, 26.981504783034325, 20.465264841914177, 28.040671348571777, 46.296050772070885, 38.49912375211716, 36.169886738061905, 20.501157715916634, 30.59385124593973, 31.765406280755997, 36.634157225489616, 32.50292010605335, 32.255819365382195, 31.69662807136774, 23.521877825260162, 13.631598483771086, 5.521077616140246, 2.0816000271588564, 0.35047297657001764, 0.046785026643192396, 0.05433209335024003, 0.015922954662528355, 0.022202609397936612, 0.04227906589221675, 0.008075558416749118, 0.05091718245239463, 0.054064727228251286, 0.026708108161983546, 0.04304616457375232, 0.02238570094050374, 0.02628498936246615, 0.042063869041157886, 0.046937389561207965, 0.022007500629115384, 0.0314601075660903, 0.012488737720559584, 0.04268986318493262, 0.015388908905151766, 0.07467141113011166, 0.07885952858487144, 0.05712508820579387, 0.05790558265289292, 0.0416288628912298, 0.05905001889914274, 0.03465433714154642, 0.02133655274519697, 0.01058984620613046, 0.053408175153890625, 0.044200905540492386, 0.01361084274321911, 0.050597120134625584, 0.013232941146270605, 0.05405608862929512, 0.041981345930253156, 0.009429305355297402, 0.030118621834844816, 0.031002022478787694, 0.034063862185576, 0.15521022694883868, 0.01692859073955333, 0.08467207371722907, 0.08978023164672777, 0.019285085872979835, 0.029629626296809874, 0.05481697924551554, 0.07898020921857096, 0.014050734080228722, 0.04358932019385975, 0.04443609213922173, 0.031112864089664072, 0.08190207430743612, 0.05871501343790442, 0.04246267693815753, 0.004660946233343566, 0.08258439745986834, 0.03646547433163505, 0.09802543296245858, 0.01760593779181363, 0.05123436523717828, 0.05175779457204044, 0.06888070740387775, 0.042851803518715315, 0.05728419353545178, 0.05181275431823451, 0.05210271512623876, 0.025017714688146953, 0.061598635656991974, 0.0160991368102259, 0.04248912708135322, 0.012992666197533254, 0.048413161348435096, 0.027804152668977622, 0.030871385934005957, 0.06159592681797221, 0.0230555986854597, 0.03771412666537799, 0.04753641034767497, 0.08083653578069061, 0.016390810123994015, 0.014074031023483258, 0.02668365996214561, 0.042250864280504175, 0.07875637005781755, 0.04881559463683516, 0.015350369176303502, 0.024907561419240665, 0.004031669477626565, 0.012447888984752353, 0.04503374366322532, 0.09975423628930002, 0.05169160242076032, 0.058731637545861304, 0.01845260769187007, 0.0623722503951285, 0.05488024733494967, 0.0413736160408007, 0.04480677635001484, 0.04049542527354788, 0.033914337982423604, 0.020917653055221308, 0.038139781754580326, 0.006925635379957384, 0.023506555444328114, 0.031618270368198864, 0.09028056534589268, 0.044847208555438556, 0.048799972428241745, 0.032560979743720964, 0.04860400833422318, 0.09180021661450155, 0.03341116556839552, 0.04254210529325064, 0.08882147332769819, 0.04088104520633351, 0.06539351874380372, 0.04023593333840836, 0.027773902729677502, 0.01639828540646704, 0.03885309699398931, 0.013598852419818286, 0.067919284774689, 0.40445718448609114, 1.9500667601823807, 5.675928331911564, 10.307266116142273, 19.06012114137411, 25.25842074304819, 34.56008031964302, 39.67743672430515, 42.95914962887764, 44.663232788443565, 44.75288897752762, 49.35322992503643, 38.43826241791248, 29.76373638957739, 30.153095796704292, 31.972039192914963, 31.906378716230392, 27.817828506231308, 26.770137324929237, 23.792693093419075, 30.515640042722225, 27.84164372831583, 28.113148659467697, 28.985610343515873, 31.247019097208977, 30.008673146367073, 26.031804643571377, 19.72787071019411, 49.691423177719116, 76.21415957808495, 59.303349405527115, 29.711646884679794, 26.495731249451637, 23.619646579027176, 29.256399013102055, 25.525540709495544, 26.562187783420086, 24.68207336962223, 29.366452507674694, 49.39432851970196, 42.95415669679642, 36.54654532670975, 23.08510646224022, 34.94986340403557, 36.27485990524292, 39.17527087032795, 36.73599176108837, 39.00087542831898, 34.89199250936508, 27.29913353919983, 16.808023788034916, 7.261364283040166, 3.1735901813954115, 0.7043825124856085, 0.1270350653794594, 0.07700524292886257, 0.039028314349707216, 0.03699317843711469, 0.05232488074398134, 0.017727954291331116, 0.005005607499697362, 0.04287908486730885, 0.05078293164842762, 0.023902973625808954, 0.029231445514597, 0.010582530485407915, 0.04044074012199417, 0.007010059316598927, 0.03877368348184973, 0.04462604112632107, 0.03154259728034958, 0.008514678847859614, 0.04688683075073641, 0.040101181584759615, 0.048593718456686474, 0.03341039002407342, 0.004568618423945736, 0.01204365691592102, 0.04099729150766507, 0.05444619855552446, 0.03165361144056078, 0.009553677246003645, 0.0721399082976859, 0.030378709343494847, 0.01563352077937452, 0.05711092802812345, 0.03646632409072481, 0.03251381996960845, 0.06925920271896757, 0.029845841745554935, 0.012970330335519975, 0.046008495264686644, 0.041462881563347764, 0.03657100773125421, 0.04921335610561073, 0.04389610548969358, 0.08800034629530273, 0.0647760667197872, 0.0135551167295489, 0.04250396632414777, 0.0069300697123253485, 0.024898264164221473, 0.042041077686008066, 0.03200912615284324, 0.05360785740776919, 0.014112863900663797, 0.044008949043927714, 0.03237542056012899, 0.026987187229678966, 0.056734848403721116, 0.05681619521055836, 0.054254041679087095, 0.10737699834862724, 0.1008659512444865, 0.2103724458720535, 0.13826662441715598, 0.18957200576551259, 0.09787066548597068, 0.10160300778807141, 0.12800056982086971, 0.14035107975360006, 0.13424262549960986, 0.2460472917300649, 0.16625979653326795, 0.13117093563778326, 0.12462256592698395, 0.08842633906169794, 0.1832877960987389, 0.13228129246272147, 0.07547845219960436, 0.07645511112059467, 0.16717370686819777, 0.2705743967089802, 0.17382333520799875, 0.11693566004396416, 0.14297810441348702, 0.18330617167521268, 0.21082690742332488, 0.1450298458803445, 0.10615228398819454, 0.1193996422807686, 0.14126369875157252, 0.1552190733491443, 0.09715168023831211, 0.22604197380132973, 0.1725220089429058, 0.1567531964974478, 0.1424331305315718, 0.2130302696605213, 0.20392839243868366, 0.1422188724973239, 0.10462375663337298, 0.1856725540710613, 0.13635267008794472, 0.07776441547321156, 0.15345944120781496, 0.09205155976815149, 0.20741562562761828, 0.16660122899338603, 0.13295177835971117, 0.15374556882306933, 0.17072718415874988, 0.1666231668787077, 0.22622100950684398, 0.1715304105891846, 0.21698495198506862, 0.10377419792348519, 0.2068134766886942, 0.15508100419538096, 0.12463314895285293, 0.11242078981013037, 0.09748614393174648, 0.09394024396897294, 0.15764607436722144, 0.08386075045564212, 0.19324617111124098, 0.38045743480324745, 1.8795272265560925, 5.904603386297822, 11.261915490031242, 20.62089879065752, 27.878271862864494, 37.3525732755661, 46.75084076821804, 50.3139703720808, 56.041486635804176, 52.44106203317642, 60.34654542803764, 45.13373874127865, 37.73881494998932, 39.150845780968666, 44.78735692799091, 41.689922735095024, 41.672850251197815, 37.89232671260834, 38.898698911070824, 42.69257113337517, 34.595688208937645, 32.80085451900959, 36.54661752283573, 34.50052231550217, 34.32676523923874, 31.392287202179432, 21.46623943001032, 54.32830296456814, 74.69734936952591, 72.57916823029518, 45.98059929907322, 35.70351876318455, 30.67569885402918, 35.87430439889431, 33.96522603929043, 37.97697477042675, 35.24183593690395, 37.82819755375385, 60.56995823979378, 52.20877669751644, 48.4197948127985, 30.77402427792549, 42.43788219988346, 46.19670510292053, 48.59124541282654, 44.80061821639538, 45.684150606393814, 42.02530413866043, 30.674792602658272, 20.328760966658592, 8.24355410411954, 3.465472706593573, 0.9602049726527184, 0.19864813046297058, 0.19827304902719334, 0.15025000873720273, 0.12531924963695928, 0.1115185757225845, 0.11045449180528522, 0.1340468172566034, 0.2120549391838722, 0.09107661520829424, 0.12068176918546669, 0.18141752458177507, 0.10390795519924723, 0.14436888915952295, 0.07019623095402494, 0.12114981946069747, 0.11716527311364189, 0.09910080494591966, 0.10877794309635647, 0.1399553072405979, 0.14524505386361852, 0.20341276307590306, 0.16667369229253381, 0.09524613444227725, 0.0932413709233515, 0.10016127460403368, 0.165655005548615, 0.14596138964407146, 0.09908630338031799, 0.2095418341923505, 0.112361692590639, 0.12776285992003977, 0.1966780549264513, 0.11286526947515085, 0.098759899410652, 0.1227067710715346, 0.20326785132056102, 0.1594136474886909, 0.09486361668678, 0.1829176870523952, 0.30151518643833697, 0.14285619923612103, 0.24247530527645722, 0.3122786432504654, 0.13673824549186975, 0.14855497312964872, 0.09927920982590877, 0.12840832059737295, 0.11650070213363506, 0.12227383180288598, 0.1709491159999743, 0.14723074418725446, 0.17711568041704595, 0.16122469562105834, 0.08578744003898464, 0.09251978815882467, 0.19308197835925967, 0.10443074628710747, 0.16204056824790314], [0.06161529316159431, 0.013218300427979557, 0.04220419803459663, 0.03722708483110182, 0.009714906045701355, 0.04650338531064335, 0.024367788137169555, 0.010296756317984546, 0.05368018712033518, 0.022242583327169996, 0.04635857374523766, 0.016170188173418865, 0.03425247530685738, 0.027613006968749687, 0.04230466998706106, 0.05599146505119279, 0.027195135153306182, 0.0075628076592693105, 0.05488390241225716, 0.03864983387757093, 0.11098636678070761, 0.01641919541725656, 0.06076528545236215, 0.051067753083771095, 0.006929761257197242, 0.0881381705403328, 0.01811901787732495, 0.05078843096271157, 0.0349588997050887, 0.02127318632119568, 0.09388548831338994, 0.05840512225404382, 0.030251598000177182, 0.037471537143574096, 0.037745541776530445, 0.0035108095971736475, 0.03544430139299948, 0.04026481030450668, 0.08863553564879112, 0.02130351418600185, 0.025692208182590548, 0.05276361247524619, 0.019491697930789087, 0.08248229278251529, 0.008767326326051261, 0.029080019558023196, 0.0183619265226298, 0.012813442172046052, 0.056154047342715785, 0.04951071983668953, 0.05750471529609058, 0.027712614319170825, 0.06838295637862757, 0.11020133781130426, 0.07070025312714279, 0.03495839875540696, 0.12913724320242181, 0.02868096489692107, 0.039273516231332906, 0.06426325009670109, 0.040357296747970395, 0.019000086322193965, 0.031710994298919104, 0.05292225025186781, 0.03446192051342223, 0.11638024414423853, 0.3664204239612445, 1.6981963254511356, 3.0200539575889707, 9.625086821615696, 11.442941576242447, 22.327979989349842, 28.513795360922813, 32.78461039066315, 39.346573278307915, 40.4874012619257, 46.419293358922005, 40.8096619695425, 38.64340580999851, 47.06866331398487, 35.258832424879074, 44.73396599292755, 30.783088691532612, 40.10233372449875, 23.547011576592922, 24.88613571971655, 25.77843613922596, 25.121308900415897, 27.508829087018967, 25.565250478684902, 33.12351040542126, 41.2203249335289, 23.37641403079033, 42.95288756489754, 75.30100777745247, 55.31543679535389, 33.29802364110947, 26.665998212993145, 27.6306239515543, 25.25691982358694, 24.074679762125015, 23.337352126836777, 31.836122386157513, 36.00299969315529, 37.88479931652546, 40.61882860958576, 33.094498962163925, 32.18995749950409, 35.839441269636154, 34.380931332707405, 28.99003330618143, 23.741397745907307, 17.613225281238556, 7.360339472070336, 4.039160935208201, 0.8994392270687968, 0.05908182734856382, 0.059740576180047356, 0.07038538955384865, 0.06572482088813558, 0.06068970884371083, 0.02271970450237859, 0.05488808070367668, 0.06630543270148337, 0.02907120098825544, 0.02532810867705848, 0.0654983619460836, 0.024320045777130872, 0.035010697902180254, 0.03439894186158199, 0.03467103546427097, 0.06087766516429838, 0.009198402804031502, 0.0552933564176783, 0.029431908878905233, 0.03808113353443332, 0.02674943651072681, 0.028341647557681426, 0.04171753840637393, 0.010909585689660162, 0.040149484266294166, 0.08129090085276403, 0.03162296816299204, 0.002778132420644397, 0.04620111227268353, 0.01030646453727968, 0.07506345064030029, 0.01905866403831169, 0.06846013973699883, 0.06956084122066386, 0.009653931192588061, 0.05119054883834906, 0.041083699761657044, 0.026006136649812106, 0.01616149762412533, 0.059969940630253404, 0.03616788424551487, 0.016434001263405662, 0.02177429742005188, 0.03049129129067296, 0.03975837986217812, 0.048353967649745755, 0.05509875416464638, 0.06352183714625426, 0.0007425094736390747, 0.08543923177057877, 0.06990897527430207, 0.06609133051824756, 0.0192184762636316, 0.06455896625993773, 0.05677971865225118, 0.04172529384959489, 0.0814753765007481, 0.04291018827643711, 0.04100197817024309, 0.003599157639655459, 0.05363676777051296, 0.04037001715914812, 0.03483133936242666, 0.11983678210526705, 0.04544133487797808, 0.01599475188413635, 0.08009852928807959, 0.02739609390118858, 0.049417791815358214, 0.07394752770778723, 0.012986684487259481, 0.003231131477150484, 0.02900678813603008, 0.015197791035461705, 0.008269901845778804, 0.03176055121002719, 0.017367647160426714, 0.02268930427817395, 0.045468182070180774, 0.03296827409940306, 0.09441046131541952, 0.01797201326553477, 0.06498792019556277, 0.03890892505296506, 0.07229972237837501, 0.002259206298731442, 0.05152005127456505, 0.05256444972474128, 0.04654289725294802, 0.03955832282372285, 0.08171865250915289, 0.068457623856375, 0.0708880164893344, 0.013324727187864482, 0.05468095841933973, 0.04756525391712785, 0.021620997540594544, 0.029827193429809995, 0.049485969211673364, 0.028366752558213193, 0.06074711767723784, 0.03648836587672122, 0.059082350562675856, 0.030418931892199907, 0.05066476318461355, 0.04604320551152341, 0.023605565365869552, 0.018118785956175998, 0.018918910209322348, 0.09462051879381761, 0.027880020570592023, 0.029867232296965085, 0.028252114861970767, 0.06088530186389107, 0.08005010415217839, 0.02725544763961807, 0.08825997923850082, 0.028543944026750978, 0.032451754159410484, 0.018946111777040642, 0.03549686400219798, 0.05525940316147171, 0.062088375198072754, 0.0795562939310912, 0.03771641990169883, 0.014855654462735401, 0.5228916043415666, 2.2485640179365873, 5.034010726958513, 12.900073137134314, 16.081578768789768, 26.72054808586836, 33.80614377558231, 40.40769673883915, 45.04981644451618, 46.746831983327866, 49.487161338329315, 43.23025368154049, 44.00035075843334, 48.83652605116367, 42.00505122542381, 45.4900836199522, 33.68141546845436, 39.68126691877842, 27.41753328591585, 25.67099690437317, 25.787065476179123, 26.605609953403473, 26.054517924785614, 23.14703743904829, 29.549473486840725, 33.38338986039162, 25.71254387497902, 47.92429380118847, 80.93987479805946, 53.634217008948326, 31.805684119462967, 27.55475342273712, 27.429977618157864, 25.014813914895058, 26.367982104420662, 26.22736304998398, 36.714762300252914, 43.12004819512367, 44.96737226843834, 46.229618936777115, 35.740099400281906, 38.46778683364391, 41.43495261669159, 41.47424630820751, 34.25726696848869, 27.741247415542603, 22.631332911551, 10.405637137591839, 5.025221323594451, 1.2936127977445722, 0.13966883823741227, 0.060873921029269695, 0.02133150428562658, 0.016396016289945692, 0.040381672588409856, 0.04236503998981789, 0.0821309007005766, 0.04133436013944447, 0.01717185376037378, 0.03392717713722959, 0.05165603128261864, 0.030941938202886377, 0.02277672741911374, 0.029196187933848705, 0.06228958998690359, 0.0383347921888344, 0.03555746407073457, 0.07101784780388698, 0.020050368148076814, 0.024066320329438895, 0.08064935129368678, 0.04538259388937149, 0.01812015336327022, 0.027935739162785467, 0.0076453739075077465, 0.01880282346974127, 0.0039203422238642816, 0.02498266490874812, 0.015088383624970447, 0.015025404045445612, 0.05400387482950464, 0.02488196660124231, 0.022729669690306764, 0.05248375971859787, 0.03178669707267545, 0.033677685642032884, 0.020079428795725107, 0.005698168115486624, 0.07151251149480231, 0.06189370615174994, 0.034854535188060254, 0.035048202335019596, 0.023529376485385, 0.0744756696803961, 0.027371966680220794, 0.03758138984267134, 0.04361649393104017, 0.07350267696892843, 0.03460647974861786, 0.04613664932549, 0.04305116293835454, 0.049169973863172345, 0.01637066266994225, 0.027011743040930014, 0.006581864226973266, 0.033109579017036594, 0.09946795282303356, 0.025370069706696086, 0.031556152607663535, 0.042375949560664594, 0.22779924591304734, 0.18920155533123761, 0.17748038662830368, 0.19624352746177465, 0.08485471626045182, 0.14929493889212608, 0.12664809473790228, 0.08410707669099793, 0.26398385816719383, 0.15392173983855173, 0.2083348052110523, 0.06671042268862948, 0.08638477986096404, 0.14256119553465396, 0.1634167178417556, 0.1680269985808991, 0.15291439311113209, 0.14435311109991744, 0.17674886650638655, 0.0840499610058032, 0.2000998455332592, 0.11108998543932103, 0.18193723575677723, 0.2594871853943914, 0.14946889830753207, 0.11747892698622309, 0.12139358528656885, 0.13639311713632196, 0.16870382241904736, 0.08958803766290657, 0.12643058609683067, 0.1553270113072358, 0.13147098594345152, 0.15818091051187366, 0.18878850562032312, 0.15340404730523005, 0.12107448405004106, 0.07190289601567201, 0.2573202922940254, 0.17091433895984665, 0.08284831259516068, 0.14614535321015865, 0.12962033681105822, 0.13905197993153706, 0.08838459325488657, 0.1423637248808518, 0.11747704935260117, 0.10013878752943128, 0.10492244880879298, 0.2477740022004582, 0.11368030347512104, 0.13272555690491572, 0.15072820417117327, 0.1869845821056515, 0.1396577653940767, 0.12979567662114277, 0.24824795254971832, 0.14462948689470068, 0.2525863697519526, 0.15038179932162166, 0.100150713842595, 0.14075050363317132, 0.12997162499232218, 0.1921152716386132, 0.08478490242850967, 0.23207121121231467, 0.7202402490656823, 2.325249365530908, 4.488181890919805, 14.124989658594131, 18.650280833244324, 28.718049600720406, 38.253083154559135, 45.903452038764954, 54.196233451366425, 55.75815483927727, 62.43256889283657, 56.939830631017685, 50.774330869317055, 63.40252764523029, 48.40398006141186, 58.459593281149864, 41.359625458717346, 53.4058378636837, 38.46902936697006, 36.09576791524887, 38.19400392472744, 33.95824581384659, 38.50227378308773, 34.85831491649151, 45.370154455304146, 53.8518351316452, 32.21167333424091, 51.35987184941769, 83.5142594575882, 64.61957573890686, 44.52287971973419, 37.30854123830795, 40.24851568043232, 36.30254901945591, 35.14512352645397, 35.006833747029305, 43.27813871204853, 50.521199852228165, 54.946347400546074, 54.71443824470043, 44.35370519757271, 45.78534297645092, 48.99935491383076, 47.331050634384155, 39.66574855148792, 31.543948464095592, 24.177570641040802, 13.06288680061698, 6.239658007398248, 1.4383841981180012, 0.2736232284223661, 0.21956802665954456, 0.16764544561738148, 0.16444790235254914, 0.18559550429927185, 0.16780004982138053, 0.14159601763822138, 0.11617076554102823, 0.15622604900272563, 0.15991541353287175, 0.1377492881147191, 0.08416333890636452, 0.11957788388826884, 0.1985661083017476, 0.1296737714437768, 0.18083464179653674, 0.18113028374500573, 0.17274903191719204, 0.1975246673100628, 0.12952575751114637, 0.1406984345521778, 0.17967010819120333, 0.1496575225610286, 0.0553705954371253, 0.11522928441991098, 0.19637548131868243, 0.13119631708832458, 0.21789841703139246, 0.07522939486079849, 0.09866955777397379, 0.16143592569278553, 0.08130722810165025, 0.14229474967578426, 0.12519412353867665, 0.13497116218786687, 0.11064586200518534, 0.10445958614582196, 0.10610736921080388, 0.20704324560938403, 0.2111251765745692, 0.07461010231054388, 0.11021062950021587, 0.10315992971300147, 0.20652552339015529, 0.1518979179672897, 0.15330783528042957, 0.1573478349018842, 0.20323133765487, 0.13313498493516818, 0.17651235888479277, 0.17865198547951877, 0.18858174327760935, 0.139941384550184, 0.1446393723017536, 0.07725289760855958, 0.13496764440787956, 0.19753550266614184, 0.11325419196509756, 0.122547068312997, 0.11097829963546246], [0.0032576219746260904, 0.025941504864022136, 0.04680643760366365, 0.07686647615628317, 0.03241941878513899, 0.030736485750821885, 0.13005418149987236, 0.10299653105903417, 0.040432049572700635, 0.04005681970738806, 0.06852964928839356, 0.04436476061528083, 0.06439222794142552, 0.02707441926759202, 0.023480207346437965, 0.03702335416164715, 0.04007356626971159, 0.04146465900703333, 0.014479882829618873, 0.0860664653009735, 0.05344261080608703, 0.054536369498237036, 0.03729870579263661, 0.04068600137543399, 0.017691724497126415, 0.04290731987566687, 0.03576619681552984, 0.013253019951662282, 0.04499612048675772, 0.031265657453332096, 0.017507465927337762, 0.021220803682808764, 0.034984982485184446, 0.007569740246253787, 0.034424827972543426, 0.028180419685668312, 0.047645398444728926, 0.015990900137694553, 0.009582318580214633, 0.045112125590094365, 0.05063106968009379, 0.021652995237673167, 0.006452610396081582, 0.04345619003288448, 0.013364049882511608, 0.048230648681055754, 0.04304835762013681, 0.05251160138868727, 0.035855484602507204, 0.015952319590724073, 0.03952330087486189, 0.016251564666163176, 0.04697804441093467, 0.03842635465844069, 0.018378925415163394, 0.016908374636841472, 0.03881752956658602, 0.014084198446653318, 0.04358916434284765, 0.05144392547663301, 0.07695451713516377, 0.00915243324925541, 0.016010619001463056, 0.00590618236856244, 0.0075043375545646995, 0.055983735583140515, 0.03689871417009272, 0.07490760704968125, 0.17205240757903084, 1.0885443328879774, 3.0932817282155156, 6.039489498361945, 12.54028469324112, 18.624936193227768, 30.17213847488165, 35.908909142017365, 43.423458114266396, 47.98288285732269, 49.818085581064224, 53.61170321702957, 43.90185244381428, 44.746995493769646, 43.107573464512825, 41.2536833435297, 43.4224321693182, 34.419031888246536, 38.8311917334795, 38.71888116002083, 46.029654666781425, 39.804539903998375, 30.913201309740543, 41.07346661388874, 45.60594700276852, 35.170156583189964, 44.44870389997959, 52.800192162394524, 46.17035731673241, 27.03142650425434, 30.367400497198105, 31.209490410983562, 29.06175445765257, 31.66235961019993, 42.14058615267277, 33.58281835913658, 44.48374941945076, 34.91603381931782, 37.11713410913944, 31.248542815446854, 28.547735139727592, 22.32470266520977, 17.036763913929462, 11.814829520881176, 4.135772176086903, 1.5899942815303802, 0.3620290767867118, 0.046530173131031916, 0.060870904198964126, 0.04342817766882945, 0.008702035884198267, 0.02550527231505839, 0.03241024955059402, 0.035123470952385105, 0.03821122460067272, 0.023569292898173444, 0.03784584674576763, 0.03123652444628533, 0.0325137197796721, 0.01931012036948232, 0.06370422735926695, 0.03569304331904277, 0.0449136159295449, 0.017061644830391742, 0.051025213178945705, 0.02879984396713553, 0.03639846581791062, 0.033192744085681625, 0.013626465879497118, 0.023265875097422395, 0.005222365180088673, 0.011621325720625464, 0.029374589103099424, 0.052859553616144694, 0.02154393292585155, 0.04680382524384186, 0.02786103457765421, 0.04478070841287263, 0.08827231373288669, 0.042028052994282916, 0.05157281797437463, 0.06921857755514793, 0.032284347907989286, 0.034194624895462766, 0.04619855557393748, 0.002374956056883093, 0.07095470587955788, 0.08073412682279013, 0.026155959567404352, 0.03691982456075493, 0.02863404075469589, 0.06447666950407438, 0.041289356304332614, 0.07639320858288556, 0.018174597316829022, 0.0548097729915753, 0.02976789211970754, 0.008722754791961052, 0.019389617373235524, 0.038304148911265656, 0.02814748317177873, 0.026579224941087887, 0.05475804900925141, 0.057397730997763574, 0.028059104515705258, 0.01533102416942711, 0.026102589872607496, 0.07599215197842568, 0.054236964861047454, 0.07880072080297396, 0.02480194638337707, 0.05881144439626951, 0.010317810119886417, 0.036986695777159184, 0.04634122233255766, 0.14398401137441397, 0.048063079157145694, 0.011571922805160284, 0.045560631406260654, 0.05504412096343003, 0.009001396920211846, 0.03661698749056086, 0.007258573032231652, 0.0386080324096838, 0.018936371088784654, 0.027916070393985137, 0.044520915907924064, 0.020456118836591486, 0.04328214898123406, 0.044009913835907355, 0.04876161823631264, 0.02433025772916153, 0.03705926668772008, 0.06663418927928433, 0.010766229661385296, 0.01578558312758105, 0.0266550019296119, 0.029144079890102148, 0.03517658275086433, 0.0157545873298659, 0.021413841859612148, 0.05237850833509583, 0.05008109743357636, 0.08332986253662966, 0.03522319704643451, 0.02158576222427655, 0.03887628910888452, 0.01533104643385741, 0.03397929816856049, 0.03031307194760302, 0.02129923384927679, 0.04195729663479142, 0.0157415292414953, 0.05363514988857787, 0.036465856537688524, 0.007397484987450298, 0.05171209682885092, 0.041842189530143514, 0.08969918169896118, 0.01971885078091873, 0.015004741726443172, 0.013068766947981203, 0.03761307212698739, 0.013346717023523524, 0.00900161307072267, 0.03424878312216606, 0.07687497374718077, 0.03698046173667535, 0.027064648893428966, 0.07604410973726772, 0.03344488133734558, 0.038138816962600686, 0.0356752206425881, 0.022616625756199937, 0.029909831573604606, 0.2846109919482842, 0.2803405554732308, 1.9456842890940607, 4.792887065559626, 8.642590641975403, 17.297424226999283, 22.875954285264015, 36.23142443597317, 41.095114052295685, 51.490075662732124, 54.17964734137058, 54.39579874277115, 59.982023388147354, 49.23172764480114, 49.860027730464935, 47.317929938435555, 47.75147907435894, 44.849726781249046, 37.39105001091957, 39.504553601145744, 36.89981997013092, 45.37331968545914, 37.44918689131737, 32.116499841213226, 43.963694125413895, 42.922382801771164, 35.70057392120361, 50.462477803230286, 58.29664662480354, 46.08579285442829, 29.010377414524555, 32.87022739648819, 33.10087502002716, 32.14089833199978, 33.117103949189186, 46.44448220729828, 40.16847677528858, 48.542843610048294, 41.50474727153778, 42.67537705600262, 36.79369166493416, 35.62925934791565, 27.707110047340393, 21.81823544204235, 14.476255159825087, 5.666632605716586, 2.3382004955783486, 0.5621605971828103, 0.033396096259821206, 0.05166488881513942, 0.035159468825440854, 0.09892591784591787, 0.06499795403215103, 0.03248845707275905, 0.049518204396008514, 0.05083652584289666, 0.01851144330430543, 0.011528496033861302, 0.055169013285194524, 0.052388152544153854, 0.053479243215406314, 0.11996271714451723, 0.06329476964310743, 0.07530118280556053, 0.03483340253296774, 0.06515370856504887, 0.07056120433844626, 0.03107076761807548, 0.07630059597431682, 0.0623140214884188, 0.06049377072486095, 0.0070604738721158355, 0.03442276480200235, 0.02691317469725618, 0.04160655022133142, 0.018863456934923306, 0.01761115694534965, 0.024178212079277728, 0.01982451962248888, 0.050130209056078456, 0.10603875765809789, 0.015757863911858294, 0.031501667835982516, 0.0670986549812369, 0.014798679785599234, 0.04986620486306492, 0.026589180852170102, 0.03422351670451462, 0.061678980564465746, 0.01899672995932633, 0.05898219773371238, 0.022652080006082542, 0.05903026292799041, 0.04739572512335144, 0.005740784090448869, 0.02372959123022156, 0.05226259971095715, 0.09580624813679606, 0.01947537253727205, 0.044083586835768074, 0.0555399275617674, 0.026951347063004505, 0.08539091795682907, 0.1233190057973843, 0.04552555379632395, 0.05075184308225289, 0.044837946552434005, 0.005085423626951524, 0.0512274113134481, 0.09470967299421318, 0.17133722954895347, 0.12006897042738274, 0.13715604494791478, 0.2323521437938325, 0.09357699236716144, 0.19734711589990184, 0.2666038472671062, 0.16407083196099848, 0.10561272036284208, 0.23411453672451898, 0.15641974954633042, 0.1373985194368288, 0.12269948318134993, 0.0639663242327515, 0.0767476212058682, 0.12626775889657438, 0.17652491602348164, 0.2026366101927124, 0.17961875157197937, 0.16864851757418364, 0.1379088350222446, 0.1428313521319069, 0.10691460323869251, 0.08828696372802369, 0.1506479928502813, 0.12268906342796981, 0.13371009001275524, 0.0874114446924068, 0.1992309241904877, 0.0988626126490999, 0.08568327961256728, 0.17643995495745912, 0.07287615590030327, 0.14394583529792726, 0.15919904806651175, 0.1022479118546471, 0.0668410629441496, 0.07434194209054112, 0.19107141124550253, 0.08041490684263408, 0.08160228375345469, 0.08261828392278403, 0.1580299428314902, 0.13700396404601634, 0.24914788082242012, 0.21865471004275605, 0.12327933058259077, 0.14547658909577876, 0.14298862806754187, 0.22232954332139343, 0.10373148732469417, 0.11141334660351276, 0.07646558282431215, 0.09660541501943953, 0.10383159562479705, 0.21252624748740345, 0.08247686026152223, 0.22116668696980923, 0.14948938158340752, 0.13052482187049463, 0.2205465335282497, 0.09996509528718889, 0.15020913124317303, 0.0942896693595685, 0.15821105655049905, 0.28126191697083414, 0.3638399764895439, 0.4596329847117886, 1.7848161212168634, 4.735453622415662, 9.128216933459044, 17.193999476730824, 26.222826093435287, 38.38373154401779, 46.78341642022133, 56.40133112668991, 61.05556458234787, 63.71586263179779, 68.40490221977234, 57.85459354519844, 61.7077349871397, 55.7557837665081, 55.87402582168579, 56.581517457962036, 44.60255764424801, 55.409417152404785, 48.831039145588875, 60.46797551214695, 49.26598280668259, 39.99119348824024, 56.15828096866608, 56.06392823159695, 43.62471051514149, 56.86657436192036, 65.43975412845612, 59.94514636695385, 39.051553308963776, 43.90588402748108, 45.53315810859203, 41.298570334911346, 44.49092723429203, 54.301913380622864, 46.249282881617546, 61.44134648144245, 50.93007691204548, 50.051108077168465, 43.857619017362595, 41.88136786222458, 31.490048356354237, 23.880886361002922, 15.454791951924562, 6.975060570985079, 2.4943210557103157, 0.7330568425823003, 0.17629413778195158, 0.20019967923872173, 0.16002119926270097, 0.1515230443328619, 0.13851907337084413, 0.11999343463685364, 0.10487402367289178, 0.1089913105533924, 0.10200076183537021, 0.20023791468702257, 0.126019035524223, 0.1648494487744756, 0.19330457813339308, 0.23899484047433361, 0.14000516472151503, 0.1588434851146303, 0.19960582751082256, 0.12568609323352575, 0.1211823032645043, 0.16984324174700305, 0.16091398807475343, 0.14168595109367743, 0.11863316700328141, 0.10374659002991393, 0.09154971950920299, 0.09799842620850541, 0.1974766651983373, 0.08820554270641878, 0.1613204920431599, 0.08266776290838607, 0.15764169569592923, 0.14770914742257446, 0.30040748650208116, 0.1193404411606025, 0.1614520896691829, 0.14538089657435194, 0.09811863186769187, 0.1452285930281505, 0.0971087024663575, 0.16907171986531466, 0.19956404459662735, 0.16022784286178648, 0.17537032719701529, 0.08734515606192872, 0.19312693766551092, 0.18209510541055351, 0.17580374144017696, 0.11416923778597265, 0.1340425424859859, 0.17210078076459467, 0.18120568594895303, 0.20499438367551193, 0.16547154664294794, 0.12338770640781149, 0.16112622746732086, 0.2043333527399227, 0.18110975594026968, 0.17922789207659662, 0.16305135854054242, 0.08412215713178739, 0.19955926516558975], [0.07584522900287993, 0.0480231961410027, 0.06930889692739584, 0.05562376798479818, 0.022448332638305146, 0.007310812807190814, 0.01488363157477579, 0.001435064407360187, 0.032925222112680785, 0.03831987873127218, 0.12547657010145485, 0.03371516038896516, 0.14895430795149878, 0.018777846489683725, 0.026204609202977736, 0.017418714342056774, 0.026280324964318424, 0.040882232642616145, 0.06573989390744828, 0.049795415106927976, 0.01244642695382936, 0.03535812320478726, 0.011512201253935928, 0.008450948771496769, 0.06753474837751128, 0.01227068174557644, 0.020332246967882384, 0.030811203323537484, 0.034003885521087795, 0.06814161737565883, 0.06270797573961318, 0.013633299204229843, 0.06094700402172748, 0.03275506620411761, 0.010473445909155998, 0.032989106184686534, 0.016575408226344734, 0.08644996269140393, 0.01301263646382722, 0.01520050544058904, 0.020399769418872893, 0.021476480978890322, 0.04382613209600095, 0.033909495468833484, 0.04671404392865952, 0.014690720490762033, 0.029333963939279784, 0.08111179093248211, 0.040056448633549735, 0.03264400380430743, 0.041383182324352674, 0.0026466950521353283, 0.02327025191334542, 0.025032978810486384, 0.01823018417780986, 0.07947525140480138, 0.03896030393661931, 0.02885333240556065, 0.017056288379535545, 0.02428010895528132, 0.09327373598353006, 0.07203476823633537, 0.05528750829398632, 0.0567063907510601, 0.040292618577950634, 0.012591940776474075, 0.046776328672422096, 0.015929357541608624, 0.05964978554402478, 0.045517909675254487, 0.15235096943797544, 1.1260842997580767, 1.8112742202356458, 6.573539916425943, 12.051192987710238, 14.811845552176237, 23.1660820171237, 26.944029293954372, 39.0327937155962, 41.293467208743095, 45.2818737924099, 49.22504000365734, 54.29626688361168, 50.8386842161417, 50.32028563320637, 44.88996282219887, 46.31272807717323, 48.334493190050125, 44.54493373632431, 42.30484373867512, 45.57834908366203, 44.65452365577221, 40.58069385588169, 40.58088764548302, 38.752543553709984, 46.43173389136791, 45.801435112953186, 40.878126695752144, 37.125900238752365, 42.579162418842316, 38.463895842432976, 42.689926475286484, 43.82716365158558, 37.13448017835617, 39.451379254460335, 29.972985461354256, 29.40946239978075, 26.409865356981754, 13.96594824269414, 9.769502822309732, 4.280727747827768, 2.326310221105814, 0.5455928924493492, 0.06930102274054661, 0.060293294372968376, 0.044230591447558254, 0.02771769060927909, 0.01796470496628899, 0.04623799330147449, 0.08076684811385348, 0.021396178744907957, 0.0649025732127484, 0.030843418098811526, 0.011046113959309878, 0.010149866739084246, 0.01275884978895192, 0.042652859701775014, 0.06613312085391954, 0.019941142563766334, 0.020425247348612174, 0.05410492936789524, 0.04390632486320101, 0.014140361399768153, 0.029151085764169693, 0.04727383849967737, 0.016653625025355723, 0.03061404622712871, 0.011711775896401377, 0.09346138060209341, 0.011735648004105315, 0.04951412629452534, 0.01144762420153711, 0.022812879287812393, 0.022393933213606942, 0.015949566222843714, 0.09507928480161354, 0.04243788920575753, 0.012838780021411367, 0.040875174818211235, 0.03263187340053264, 0.040683908518985845, 0.003960547610404319, 0.043547177338041365, 0.04873301586485468, 0.05935855566349346, 0.019195297136320733, 0.05218677448283415, 0.018104898517776746, 0.06757702110917307, 0.04134706570766866, 0.02802645743940957, 0.020211512528476305, 0.040916200741776265, 0.024563815313740633, 0.05359615744964685, 0.0639566317840945, 0.014511497392959427, 0.019767583908105735, 0.029341795452637598, 0.05792579504486639, 0.01568218896863982, 0.024195917867473327, 0.031095354970602784, 0.04318146551668178, 0.05065646597358864, 0.05120133595482912, 0.08724327402887866, 0.025521755414956715, 0.03048196063900832, 0.01038373602568754, 0.01047372885295772, 0.020964964969607536, 0.009848082590906415, 0.04004511974926572, 0.012112293516111095, 0.05310068852850236, 0.06525120450532995, 0.042308666452299803, 0.01958256463694852, 0.043519153841771185, 0.021140436510904692, 0.017723499549902044, 0.036315297038527206, 0.053210196128929965, 0.030934637325117365, 0.008855302367010154, 0.04703128237451892, 0.0254947356734192, 0.015318896548706107, 0.07250516369822435, 0.07335943504585885, 0.027259147245786153, 0.01864727117208531, 0.03906652011210099, 0.027975234406767413, 0.05584038604865782, 0.05539822559512686, 0.04698940669186413, 0.034115831076633185, 0.006748310788680101, 0.0495688893715851, 0.016991394986689556, 0.015950343622535, 0.01140000058512669, 0.01948420780536253, 0.031701940097264014, 0.024060581672529224, 0.025594808721507434, 0.0517448774917284, 0.04926504669128917, 0.026830241549760103, 0.025321833818452433, 0.04097678596735932, 0.0930739646719303, 0.025172715941153, 0.10023024238762446, 0.08570358477300033, 0.016965696268016472, 0.046397443729802035, 0.008717407617950812, 0.0582644333189819, 0.010733474973676493, 0.055041382438503206, 0.04111618356546387, 0.031149132846621796, 0.04276922845747322, 0.04527869321464095, 0.04331534153607208, 0.021237498294794932, 0.04056995916471351, 0.03838611170067452, 0.035327016084920615, 0.033171032555401325, 0.040100628684740514, 0.02096655502100475, 0.04110849491553381, 0.3247805661521852, 1.6886931541375816, 3.2487491983920336, 9.282993078231812, 15.291825346648693, 21.107354387640953, 29.610674902796745, 34.13997866213322, 45.36138832569122, 48.49573373794556, 52.09159858524799, 54.87345591187477, 58.085484355688095, 59.440191462635994, 55.29551446437836, 49.18096996843815, 49.04971361160278, 52.93572708964348, 47.455938532948494, 44.37615819275379, 45.293303579092026, 48.591298609972, 43.002759888768196, 41.10435515642166, 42.636041566729546, 51.493240892887115, 53.02842691540718, 44.79384317994118, 42.72640831768513, 46.80591881275177, 42.63174779713154, 50.22587589919567, 50.59843070805073, 42.094775810837746, 46.530669182538986, 36.55218042433262, 34.18996497988701, 30.12038715183735, 18.010862544178963, 12.399206813424826, 6.552967820316553, 3.364935563877225, 1.0131871327757835, 0.17009675939334556, 0.03654596395790577, 0.07547026631073095, 0.032412071523140185, 0.01836283194279531, 0.04085649867192842, 0.03936461856937967, 0.026381492680229712, 0.05102752867969684, 0.0664219944155775, 0.08071914286119863, 0.04669344561989419, 0.04544584713585209, 0.007860522982809925, 0.05286700477881823, 0.05541863836697303, 0.007656597035747836, 0.030837597805657424, 0.04171990214672405, 0.09066634112969041, 0.009639007530495292, 0.016746397195674945, 0.04130275206989609, 0.050751457165461034, 0.035220840727561153, 0.04687209540861659, 0.04037388745928183, 0.01882873741124058, 0.05011392633605283, 0.022210067982086912, 0.0323762369225733, 0.06152843219751958, 0.018581886106403545, 0.027573103543545585, 0.0743876954948064, 0.046154468291206285, 0.04047168396937195, 0.05259815436147619, 0.03738633116881829, 0.02684709572349675, 0.009768668151082238, 0.032683679019100964, 0.05531843358767219, 0.03308302868390456, 0.013815614274790278, 0.07307689200388268, 0.01952048212842783, 0.029018723726039752, 0.05151003228093032, 0.06263361254241318, 0.0134348739629786, 0.030525880938512273, 0.0321097242704127, 0.024704661955183838, 0.009121358598349616, 0.15744024713058025, 0.09589935056283139, 0.022335396315611433, 0.11882634062203579, 0.05318002411513589, 0.006464428633989883, 0.05998630127578508, 0.04196102963760495, 0.24566913780290633, 0.11316877076751553, 0.14684990368550643, 0.10088765906402841, 0.06799311362556182, 0.07171578574343584, 0.10881317284656689, 0.1764207036467269, 0.1222929495270364, 0.18954620871227235, 0.224911104014609, 0.12547800986794755, 0.19430441432632506, 0.12997968471609056, 0.1715890402556397, 0.10491260793060064, 0.18006929458351806, 0.15236278442898765, 0.13008504000026733, 0.1109371252823621, 0.196240751829464, 0.08750592009164393, 0.09144831987214275, 0.12181129568489268, 0.2786905237007886, 0.13128351944033056, 0.065287844336126, 0.10240853487630375, 0.08721668287762441, 0.1562789047602564, 0.1708028238499537, 0.26389957987703383, 0.155983752629254, 0.1785841234959662, 0.09791088246856816, 0.08424976942478679, 0.13885859108995646, 0.14525774458888918, 0.22431838035117835, 0.14052944752620533, 0.1321214932249859, 0.10640600943588652, 0.0956609430431854, 0.1448112091748044, 0.18724583293078467, 0.1044196734437719, 0.09438464941922575, 0.1758616289589554, 0.13004451873712242, 0.24926724785473198, 0.18667161843040958, 0.08131722483085468, 0.12769631895935163, 0.0984076687018387, 0.16710860567400232, 0.21598769846605137, 0.16316438763169572, 0.1356057429802604, 0.13407875929260626, 0.13405324425548315, 0.13967379578389227, 0.1794314186554402, 0.15204673341941088, 0.08370645795366727, 0.12609365105163306, 0.10721918806666508, 0.11929905158467591, 0.1661092444555834, 0.09274408002966084, 0.17792849539546296, 0.48815858841408044, 1.7985173547640443, 3.2036273321136832, 8.607623968273401, 15.736353993415833, 22.24050298333168, 33.311862498521805, 37.08757169544697, 52.861000299453735, 57.327687218785286, 60.3766094148159, 63.65693539381027, 68.06980580091476, 69.57118883728981, 64.35779258608818, 57.87846386432648, 58.46143618226051, 62.000984251499176, 56.428929045796394, 54.26291227340698, 54.93782825767994, 58.249114975333214, 51.854992881417274, 52.88022726774216, 47.978836074471474, 60.58956898748875, 60.56951746344566, 57.14679412543774, 50.82199551165104, 56.35542958974838, 51.05208836495876, 57.31813833117485, 56.14581383764744, 49.742066860198975, 52.485458850860596, 43.171090856194496, 38.97395007312298, 34.605799466371536, 21.900468729436398, 13.994558807462454, 7.347440114244819, 3.4374641720205545, 1.1382451909594238, 0.2097376572783105, 0.0999313646752853, 0.1339201771770604, 0.13608269160613418, 0.19732247659703717, 0.12338466360233724, 0.13388085819315165, 0.13640319550177082, 0.30912175483535975, 0.194589443563018, 0.23266521136974916, 0.1403449199278839, 0.08072609678492881, 0.0911056851327885, 0.26137007342185825, 0.1626129719079472, 0.12110750962165184, 0.1542505854740739, 0.1610425132093951, 0.34586269583087415, 0.10328207237762399, 0.11563967724214308, 0.17984809004701674, 0.10677223704988137, 0.1420716749271378, 0.17656224605161697, 0.24422396847512573, 0.1617060080752708, 0.11688126804074273, 0.1362091238843277, 0.19930053764255717, 0.14513894158881158, 0.15271370153641328, 0.08622465407825075, 0.09012707436340861, 0.09903335114358924, 0.10606931187794544, 0.13721930561587214, 0.08212128988816403, 0.19397993251914158, 0.11207473376998678, 0.10617129039019346, 0.15213203587336466, 0.23855387116782367, 0.0860147672938183, 0.1673009555088356, 0.10461010853759944, 0.15232938778353855, 0.13908050808822736, 0.14547888975357637, 0.08923914661863819, 0.1805535756284371, 0.136252747324761, 0.14484747051028535, 0.13559659972088411, 0.2694270364008844, 0.2518045617034659, 0.18808500899467617, 0.3295167745091021, 0.15683060250012204, 0.11555169563507661, 0.11216563943889923, 0.15285908826626837], [0.049456661799922585, 0.07139442095649429, 0.07240958992042579, 0.01475734030464082, 0.008899364602257265, 0.037759015467599966, 0.030149779049679637, 0.02665333766344702, 0.00784260382715729, 0.05900740477954969, 0.07432013779180124, 0.020595534988387953, 0.03610444917285349, 0.025103900297835935, 0.06121206206444185, 0.007985056290635839, 0.04428742511663586, 0.015692933411628474, 0.03434230857237708, 0.11913637281395495, 0.055490014419774525, 0.042787136480910704, 0.05883640653337352, 0.08450394758256152, 0.023723114136373624, 0.04083524727320764, 0.06277128093643114, 0.04399784651468508, 0.02071372015052475, 0.01607147882168647, 0.024788400332909077, 0.06285534400376491, 0.06357536825817078, 0.01735699177515926, 0.0054625891061732545, 0.10869461475522257, 0.02178464666940272, 0.02316039735887898, 0.01591716591065051, 0.015603712417942006, 0.04558967535558622, 0.029160418271203525, 0.04591405326209497, 0.043570989146246575, 0.059569184595602565, 0.03776684883632697, 0.031122632608457934, 0.03877258139254991, 0.029024727700743824, 0.10351786011597142, 0.03739461724762805, 0.040277334046550095, 0.039403855917043984, 0.06191522843437269, 0.02944696148915682, 0.05224792745138984, 0.047656975948484614, 0.04330419447796885, 0.03038403610844398, 0.022293756264843978, 0.09537403617287055, 0.062416400760412216, 0.04567904106806964, 0.06954800206585787, 0.08620156586403027, 0.02039309936662903, 0.02278529922477901, 0.028838797443313524, 0.01945639211044181, 0.09626036087865941, 0.03807797569606919, 0.010696034551074263, 0.18657289794646204, 0.29089689371176064, 2.371941260062158, 3.1542534939944744, 7.546671973541379, 13.846414256840944, 15.23215714842081, 25.252054184675217, 27.903069332242012, 37.53696218132973, 40.63707523047924, 45.64074173569679, 45.1207472383976, 51.61149054765701, 53.890357464551926, 53.6102668941021, 55.101173892617226, 52.22824305295944, 53.106892704963684, 54.68226917088032, 48.398462757468224, 54.1483636200428, 47.04684108495712, 45.274513587355614, 42.71235667169094, 43.686005026102066, 45.616605430841446, 43.606296703219414, 43.01944859325886, 40.11994577944279, 38.168051317334175, 35.42617164552212, 21.377193108201027, 18.217140175402164, 13.189698345959187, 8.672146406024694, 4.543981896713376, 1.4884468680247664, 0.5019716487731785, 0.06182271972647868, 0.009297175238316413, 0.007096664239725214, 0.03490760616841726, 0.04487836762564257, 0.10379816929344088, 0.04847569471166935, 0.035740945240831934, 0.06401581806130707, 0.06614727361011319, 0.038961008976912126, 0.026620096869010013, 0.035309445738676004, 0.05121879497892223, 0.06920710395206697, 0.06878648433485068, 0.04007675750472117, 0.06028790638083592, 0.03423293826926965, 0.015339996734837769, 0.0344728820346063, 0.02506962791812839, 0.051998161361552775, 0.047418004396604374, 0.0280331126486999, 0.025512165011605248, 0.014447652283706702, 0.03808480716543272, 0.007587301315652439, 0.0394948803295847, 0.03127388044958934, 0.10274650892824866, 0.07965269891428761, 0.09482665031100623, 0.03578120675229002, 0.099877826141892, 0.03771913245145697, 0.035973560297861695, 0.07034238951746374, 0.05162502064194996, 0.03796561453782488, 0.021921849365753587, 0.09164458824670874, 0.016059840090747457, 0.02087132634187583, 0.02317448888788931, 0.026567678978608456, 0.05001703153538983, 0.016979123574856203, 0.043856241027242504, 0.026411401231598575, 0.053092717862455174, 0.024835630611050874, 0.044537877693073824, 0.04148470070504118, 0.062030906992731616, 0.045465773800970055, 0.011825237288576318, 0.05148826137883589, 0.0173443233143189, 0.061047973213135265, 0.06004385482810903, 0.0776598097581882, 0.030495987230096944, 0.02442980941850692, 0.052692778190248646, 0.0407289791473886, 0.05133392805873882, 0.019300392668810673, 0.029874327228753828, 0.05103698364109732, 0.008499706946167862, 0.04377579964057077, 0.02703898357140133, 0.03493197087664157, 0.04428297594131436, 0.020954001593054272, 0.049878153440658934, 0.034316700766794384, 0.021997158801241312, 0.006981480137255858, 0.04632901771401521, 0.008861912119755289, 0.04684472500230186, 0.015551879896520404, 0.024862303398549557, 0.0159271719167009, 0.023275986859516706, 0.07602099183714017, 0.01151422360635479, 0.035938868604716845, 0.0456406942976173, 0.03924085802282207, 0.061142144331824966, 0.016695801277819555, 0.07187951094238088, 0.030836278638162185, 0.054917510569794104, 0.03043483055080287, 0.04134755552513525, 0.07220290921395645, 0.027424828003859147, 0.010563448013272136, 0.018830655862984713, 0.07419526402372867, 0.07855100295273587, 0.018326299723412376, 0.03198146259819623, 0.0620018073823303, 0.0741555517015513, 0.01544539747555973, 0.04883819674432743, 0.06684651772957295, 0.025164982762362342, 0.08757217161473818, 0.054279152245726436, 0.03267799045715947, 0.07673025495023467, 0.02786135741189355, 0.017970278495340608, 0.03204217027814593, 0.06605385948205367, 0.07549210771685466, 0.08127800974762067, 0.046005511831026524, 0.03235032483644318, 0.10292671722709201, 0.03083025982050458, 0.03881364442349877, 0.014379043514054501, 0.007477236176782753, 0.05351651387172751, 0.013848390299244784, 0.07033366186078638, 0.12437955709174275, 0.037376000473159365, 0.07263898776727729, 0.3132930106949061, 0.6061663327272981, 3.7376637384295464, 5.137415053322911, 10.872126705944538, 17.254304140806198, 20.549358129501343, 31.71076711267233, 32.6562836766243, 44.646536484360695, 47.228980511426926, 51.12256318330765, 51.78622417151928, 57.67212353646755, 60.48910237848759, 58.10449853539467, 59.834291115403175, 58.83677624166012, 57.99158379435539, 58.954657316207886, 53.35023544728756, 56.66875697672367, 52.21687026321888, 51.85009494423866, 49.3238765001297, 50.08926942944527, 50.32866798341274, 49.472737312316895, 47.80547797679901, 46.21808275580406, 43.26032526791096, 40.87724134325981, 26.721298545598984, 23.771256543695927, 16.969494223594666, 11.467336267232895, 6.274869767948985, 2.4597908835858107, 0.6251610384788364, 0.1778828978422098, 0.024335161469934974, 0.00393286039980012, 0.01952971073478693, 0.040453634937875904, 0.037587315891869366, 0.05658359128574375, 0.03635313914855942, 0.041119356246781535, 0.08293641294585541, 0.013984162505948916, 0.06081204817746766, 0.03858274001686368, 0.039964136594790034, 0.026725479983724654, 0.05276595395116601, 0.027299649955239147, 0.054272116685751826, 0.03826080748694949, 0.052141299383947626, 0.04246125201461837, 0.019490250742819626, 0.018847127830667887, 0.024331580607395153, 0.044273476451053284, 0.013098202380206203, 0.016253156572929583, 0.0208662426302908, 0.038486817429657094, 0.01214370862726355, 0.009476197956246324, 0.07781459949910641, 0.04615706951881293, 0.08518912058207206, 0.05493874712556135, 0.022127068041299935, 0.052694615005748346, 0.022495659395644907, 0.030767277457925957, 0.010161286536458647, 0.011369420390110463, 0.034123475197702646, 0.08361572297872044, 0.0351070064061787, 0.030009255242475774, 0.07127304270397872, 0.03000121778313769, 0.06841452734079212, 0.04222242518153507, 0.015799774846527725, 0.029315169049368706, 0.05623378368909471, 0.05778914339316543, 0.027387631562305614, 0.026192501063633244, 0.06687305693048984, 0.06371969371684827, 0.018611382765811868, 0.024576363175583538, 0.008050995184021303, 0.05125756477355026, 0.005778109016318922, 0.026591401729092468, 0.020394320199557114, 0.02746724730968708, 0.12168656292487867, 0.1303417340386659, 0.11420599636039697, 0.10897460480919108, 0.10670977047993802, 0.11801482440205291, 0.12833067710744217, 0.11138691872474737, 0.08161118952557445, 0.11160243098856881, 0.19378590543055907, 0.12021337010082789, 0.13844919274561107, 0.12085924638085999, 0.1633756622322835, 0.1790824014460668, 0.07274639880051836, 0.08305002091219649, 0.10904211798333563, 0.25333448429591954, 0.13846026558894664, 0.11997423527645878, 0.1488235712167807, 0.19680999394040555, 0.1465327394544147, 0.13734213105635718, 0.17625421023694798, 0.14369552372954786, 0.1829607316176407, 0.06841334732598625, 0.22666258737444878, 0.16112766723381355, 0.1685586731764488, 0.10963747627101839, 0.1571001802221872, 0.17038797814166173, 0.11955970869166777, 0.05332932196324691, 0.10849584534298629, 0.24530694005079567, 0.13455981941660866, 0.1744316885014996, 0.13910275767557323, 0.2172194854938425, 0.19446529709966853, 0.15860672516282648, 0.1413125023827888, 0.24393950327066705, 0.096458929911023, 0.13809159630909562, 0.1639637994230725, 0.09898831762257032, 0.1894714595982805, 0.08306545016239397, 0.20556819741614163, 0.0963078805943951, 0.14596220600651577, 0.15182422270299867, 0.10293699597241357, 0.1307437554351054, 0.17158711067168042, 0.19368479523109272, 0.09737516316818073, 0.15135721885599196, 0.15054630377562717, 0.13874749158276245, 0.1265699020586908, 0.14523358026053756, 0.13388066523475572, 0.321462067659013, 0.13238351588370278, 0.1892636582488194, 0.3090831631561741, 0.6751530559267849, 3.3990180725231767, 5.529922116547823, 10.783230476081371, 19.408017173409462, 22.869308441877365, 33.412363305687904, 39.563944414258, 49.28475379943848, 53.929236978292465, 57.38887533545494, 59.081148728728294, 66.42780750989914, 69.57145482301712, 66.7583517730236, 70.13753324747086, 65.27730524539948, 64.40098106861115, 69.40949231386185, 62.484135925769806, 67.05429509282112, 60.583094134926796, 60.15396796166897, 56.575540378689766, 59.32421788573265, 61.13803155720234, 56.84601366519928, 55.99878832697868, 53.349304497241974, 50.03747060894966, 45.20682021975517, 31.284190602600574, 27.02995978295803, 19.002337642014027, 12.742962017655373, 7.0339151378721, 2.9298767214640975, 0.9612873801961541, 0.2359767336747609, 0.16905840573599562, 0.13793212361633778, 0.0975029609980993, 0.20094673993298784, 0.21669057168764994, 0.11757569562178105, 0.14763963787117973, 0.20243577018845826, 0.16043027106206864, 0.14032669278094545, 0.19052596238907427, 0.14505104161798954, 0.11976830413914286, 0.14124691137112677, 0.20084686169866472, 0.12774454371538013, 0.13077774579869583, 0.14751932088984177, 0.1683078717906028, 0.11936887283809483, 0.06867423449875787, 0.16987135430099443, 0.09166542775346898, 0.09465827184612863, 0.16058253007940948, 0.11152502498589456, 0.09897749710944481, 0.15949811873724684, 0.19561964843887836, 0.10839136579306796, 0.1873813639394939, 0.17762847477570176, 0.21018552855821326, 0.10888743956456892, 0.2635489002568647, 0.09438103516004048, 0.1464993873378262, 0.13261226064059883, 0.11134332497022115, 0.1794277227600105, 0.06066125861252658, 0.1503475714707747, 0.14145768131129444, 0.18906456971308216, 0.19151898566633463, 0.16946945164818317, 0.10557303030509502, 0.12155464617535472, 0.14671327429823577, 0.12142731589847244, 0.1281816538539715, 0.1296916720457375, 0.09900095639750361, 0.14698938291985542, 0.1730310925631784, 0.13010843249503523, 0.09446651572943665, 0.18849696032702923, 0.1849644264439121, 0.11993804815574549, 0.17407663021003827, 0.15778010623762384, 0.1303409325191751, 0.09278828976675868], [0.03395637322682887, 0.032055669944384135, 0.0011108540638815612, 0.04732597808470018, 0.00850510978125385, 0.012870670107076876, 0.0179618476977339, 0.03028253257070901, 0.03345635122968815, 0.06141025631222874, 0.011988891983492067, 0.024481544533045962, 0.05735725426347926, 0.04692706999776419, 0.007849341600376647, 0.020049282757099718, 0.08490514519507997, 0.02970952591567766, 0.04981259582564235, 0.021938347308605444, 0.019769251885008998, 0.015184843341558008, 0.083711519400822, 0.022529610796482302, 0.01252741196367424, 0.021265803807182238, 0.03571435408957768, 0.019399387747398578, 0.06108736270107329, 0.0223316410483676, 0.018626606070029084, 0.022974789935688023, 0.06411829381249845, 0.018775801872834563, 0.030763833892706316, 0.026322198791604023, 0.045598662763950415, 0.050443024301785044, 0.019536449435690884, 0.017830545075412374, 0.013399170165939722, 0.019129233005514834, 0.04791908024344593, 0.028407448226062115, 0.06118149671237916, 0.02309576371771982, 0.04431473615113646, 0.006070512881706236, 0.0661581386520993, 0.05847298052685801, 0.1016404120309744, 0.047964996920200065, 0.05108691162604373, 0.023701450845692307, 0.04311821969167795, 0.012831939275201876, 0.031063168025866617, 0.026113386265933514, 0.037012173706898466, 0.02318809802090982, 0.016867326448846143, 0.02538416680181399, 0.02209643404057715, 0.04166686085227411, 0.11258997721597552, 0.01863964931544615, 0.0707047208561562, 0.049133849825011566, 0.019857300285366364, 0.04286943323677406, 0.031452032999368384, 0.04334429271693807, 0.0711346544267144, 0.04805023258086294, 0.02073357445624424, 0.45367543876636773, 0.5588138673920184, 2.5901433639228344, 5.431113168597221, 7.704230519011617, 11.614648662507534, 17.283250987529755, 17.945982925593853, 26.604943089187145, 29.51199419796467, 30.586188957095146, 32.76370011270046, 39.96426813304424, 37.92372442781925, 36.895552799105644, 43.6032834649086, 42.26740434765816, 47.79392659664154, 43.17302495241165, 42.39933326840401, 42.12810382246971, 38.95824931561947, 37.42422603070736, 37.01116159558296, 32.640563920140266, 32.74706840515137, 31.262531764805317, 23.632584884762764, 15.034949630498886, 10.047201421111822, 5.517647350206971, 3.3049028227105737, 1.3752251747064292, 0.08986302564153448, 0.019131021581415553, 0.038935705451876856, 0.011594212282943772, 0.016992222481349017, 0.025497390706732403, 0.0952594485715963, 0.05420934583526105, 0.0461681200977182, 0.03990436773165129, 0.040911402757046744, 0.03847150321234949, 0.046291431644931436, 0.0646804335701745, 0.04517718967690598, 0.10421306695207022, 0.02412892790744081, 0.00670454958708433, 0.0160613800471765, 0.0220059922139626, 0.025745852472027764, 0.04103931933059357, 0.013639018379763002, 0.05154621940164361, 0.04474223547731526, 0.05494200886460021, 0.02486169854819309, 0.12988742091692984, 0.026768081115733366, 0.03662597118818667, 0.0471133973042015, 0.0584063653514022, 0.030283161540864967, 0.03721034940099344, 0.037442867978825234, 0.11405149605707265, 0.010391345822426956, 0.04717676929431036, 0.00987709407127113, 0.056104839241015725, 0.08854967658407986, 0.03802486018685158, 0.025862460570351686, 0.04523960429651197, 0.023862211164669134, 0.03459044193732552, 0.08345115173142403, 0.030219526088330895, 0.039141773886512965, 0.05171906930627301, 0.012086937113053864, 0.025686948210932314, 0.07636479174834676, 0.04527071141637862, 0.07362136864685453, 0.019970449975517113, 0.013230937347543659, 0.025127964436251204, 0.10776059221825562, 0.019501750321069267, 0.08771888678893447, 0.02525008483644342, 0.031446181164938025, 0.04245283605996519, 0.015612525421602186, 0.06928495524334721, 0.017194687789015006, 0.08741065801586956, 0.06065769259294029, 0.03441444903728552, 0.01012546306810691, 0.037069207755848765, 0.051634839255711995, 0.041593855785322376, 0.08157213029335253, 0.050918603665195405, 0.04538691689958796, 0.0562551426992286, 0.011963061533606378, 0.021450719177664723, 0.01573607631144114, 0.04473917782888748, 0.01774575655872468, 0.021770057901449036, 0.024559937592130154, 0.03014897753018886, 0.013899500154366251, 0.029494627779058646, 0.042541051443549804, 0.01584921858011512, 0.021186193625908345, 0.028308616419963073, 0.0077843090548412874, 0.024445914023090154, 0.025407700304640457, 0.06883873895276338, 0.09012428388814442, 0.0852000672603026, 0.057344897504663095, 0.07457784857251681, 0.03424625610932708, 0.03489981361781247, 0.037807522239745595, 0.024820197650115006, 0.014668587791675236, 0.08286527809104882, 0.03403317437914666, 0.06461671277065761, 0.03248556640755851, 0.034935384755954146, 0.051652821493917145, 0.012152589351899223, 0.07023060723440722, 0.0387970388692338, 0.11901204823516309, 0.04350196941231843, 0.05046239064540714, 0.08020208857487887, 0.02143772417184664, 0.013643505590152927, 0.03346965051605366, 0.03156804923492018, 0.02363298030104488, 0.06251824568607844, 0.0089902749095927, 0.042993119568564, 0.07723507864284329, 0.05150223973032553, 0.05469050243846141, 0.03125387956970371, 0.01688919568550773, 0.04009966389276087, 0.02521810198231833, 0.04244194133207202, 0.007133058234103373, 0.023408083579852246, 0.06554044914082624, 0.003591677950680605, 0.011168072942382423, 0.03614755310991313, 0.028662155164056458, 0.05141295936482493, 0.06767347062123008, 0.9803007286973298, 1.1712523573078215, 3.845097036100924, 7.8624331299215555, 10.542133413255215, 15.639766976237297, 21.587378829717636, 22.434410378336906, 31.73797745257616, 34.70719322562218, 36.440614610910416, 39.85896818339825, 47.60008379817009, 43.65307979285717, 43.667712807655334, 49.63555857539177, 49.31453660130501, 51.976160779595375, 49.67067249119282, 47.571566328406334, 48.35139848291874, 44.8581737279892, 42.11961127817631, 43.95948775112629, 39.29077327251434, 37.73127615451813, 37.26549334824085, 28.784490935504436, 20.24950671941042, 13.149309363216162, 7.595464680343866, 4.901879942044616, 1.9793394394218922, 0.4166221426567063, 0.08741344106965698, 0.022926513229322154, 0.06868481010315008, 0.0412844247330213, 0.018842327990569174, 0.11000405269442126, 0.018764623273455072, 0.04675735566706862, 0.0005409709808645857, 0.045527156835305505, 0.03334327760967426, 0.033117174898507074, 0.10448136075865477, 0.052489700610749424, 0.022321096985251643, 0.03655105880170595, 0.05955845314019825, 0.008902464924176456, 0.0219991755875526, 0.03295382448413875, 0.04265725321602076, 0.0376145972404629, 0.023035441954561975, 0.07882998368586414, 0.061877831612946466, 0.01792268085409887, 0.07943234042613767, 0.013397197908489034, 0.031618812136002816, 0.051589705544756725, 0.010435053682158468, 0.053887550602667034, 0.01892743934149621, 0.05821677259518765, 0.07813246877049096, 0.032289557784679346, 0.017252851757803, 0.047844572327448986, 0.09065679711056873, 0.03284855825768318, 0.019104827479168307, 0.0398394743388053, 0.04619837745849509, 0.06630899501033127, 0.06937592770555057, 0.044534964763442986, 0.055293538243859075, 0.061607140669366345, 0.10622830959619023, 0.04560343477351125, 0.017811232537496835, 0.08163763224729337, 0.010491865086805774, 0.049626788022578694, 0.07457183717633598, 0.003929704880647478, 0.009270373502658913, 0.06702959071844816, 0.04013401048723608, 0.021955938063911162, 0.031016704015200958, 0.064399204129586, 0.05113595645525493, 0.027697301957232412, 0.03404044371563941, 0.03729321761056781, 0.0760432711103931, 0.07843324638088234, 0.10623157504596747, 0.061195493617560714, 0.11511166143463925, 0.12364821508526802, 0.11512306082295254, 0.13849403330823407, 0.12921316490974277, 0.08325295377289876, 0.2332192097674124, 0.0563046513707377, 0.10908607539022341, 0.27915380196645856, 0.2045148820616305, 0.0996347059844993, 0.09155591644230299, 0.18890214327257127, 0.11046703410102054, 0.12840846902690828, 0.12628706957912073, 0.14698999148095027, 0.16915973857976496, 0.20449025760171935, 0.08687911700690165, 0.11927401894354261, 0.14641228888649493, 0.09942633318132721, 0.10645192611264065, 0.11633841670118272, 0.12479112250730395, 0.16872693289769813, 0.1725238939980045, 0.12249239429365844, 0.10300330686732195, 0.18464758875779808, 0.15460700931726024, 0.11663048149785027, 0.17494915839051828, 0.10546877339947969, 0.18950672645587474, 0.1398153233458288, 0.13414491433650255, 0.13209020427893847, 0.1957330634468235, 0.28262167994398624, 0.17415511974832043, 0.2194552795845084, 0.12035244857543148, 0.1962816293234937, 0.19817639171378687, 0.24198997038183734, 0.15575220255414024, 0.1476757210912183, 0.13054543873295188, 0.10404707078123465, 0.1418963648029603, 0.07339048650464974, 0.19377538177650422, 0.16154451674083248, 0.20735076192067936, 0.09442735259654, 0.06321789798676036, 0.18054021697025746, 0.14086679817410186, 0.08822633768431842, 0.12139022335759364, 0.3252177208196372, 0.22704129049088806, 0.09423573748790659, 0.15128788742003962, 0.16367737494874746, 0.12066082577803172, 0.1470591893303208, 0.29865572112612426, 0.1322160873678513, 0.7585474185179919, 1.254827685188502, 3.5885103419423103, 8.2342379540205, 9.977110382169485, 17.183550037443638, 23.0777595564723, 23.726586140692234, 33.592880219221115, 38.17441217601299, 41.28272898495197, 45.126857310533524, 52.73067869246006, 51.65959216654301, 51.055546179413795, 58.25088948011398, 56.28402002155781, 57.917822152376175, 55.293523371219635, 55.20384058356285, 54.630945324897766, 51.36952333152294, 47.48309947550297, 48.937748819589615, 45.29432192444801, 41.19335398077965, 42.00792767107487, 32.94719986617565, 23.84888257831335, 15.049391705542803, 8.707820791751146, 5.391410524025559, 2.3697226541116834, 0.6395262863952667, 0.15794885577633977, 0.19164198922226205, 0.1749913123785518, 0.1814546319656074, 0.1368264274788089, 0.3176857531070709, 0.21549405151745304, 0.24781859043287113, 0.10100615036208183, 0.09886866115266457, 0.1044310060387943, 0.0953794019005727, 0.20302503544371575, 0.16539057833142579, 0.1891292553045787, 0.14008426282089204, 0.12097706974600442, 0.09633128793211654, 0.0881054789351765, 0.16148334892932326, 0.24833598610712215, 0.1349019940244034, 0.16940512228757143, 0.1505603303667158, 0.149905132711865, 0.0800397215061821, 0.26866315864026546, 0.06693789837299846, 0.16144272376550362, 0.1716088259126991, 0.2177417793427594, 0.15364993567345664, 0.12601091642864048, 0.176803607319016, 0.16842113836901262, 0.1571008184691891, 0.09822697800700553, 0.15695311623858288, 0.13155055901734158, 0.15396263217553496, 0.13099062343826517, 0.11951578097068705, 0.166292940848507, 0.1641026107245125, 0.13650826876983047, 0.2573752705939114, 0.11004984320607036, 0.18015640787780285, 0.16659371845889837, 0.16499462770298123, 0.121838139166357, 0.11994923232123256, 0.14903177332598716, 0.1653585917665623, 0.14994829602073878, 0.10677850819774903, 0.12608652643393725, 0.18983808055054396, 0.07272812712471932, 0.26043760939501226, 0.08798050868790597, 0.11196882187505253, 0.21356097946409136, 0.1271440868731588, 0.18728859547991306, 0.09036491785082035, 0.197646216256544], [0.021346638532122597, 0.012699872240773402, 0.014563458862539846, 0.009236222649633419, 0.04174576228251681, 0.05670872109476477, 0.04638472702936269, 0.018266226579726208, 0.019072625691478606, 0.03386979427887127, 0.019806375967164058, 0.06637847487581894, 0.047925473845680244, 0.02945431802800158, 0.048174612820730545, 0.03197415986505803, 0.03628477621532511, 0.038034593453630805, 0.028689419814327266, 0.020593161971191876, 0.04779144568601623, 0.014428321192099247, 0.08398101548664272, 0.04881034394202288, 0.014156085653667105, 0.043485345304361545, 0.012400706946209539, 0.018445247442286927, 0.0239818639238365, 0.0734652578830719, 0.008121268219838385, 0.0009966085463020136, 0.05513523443369195, 0.0634137359156739, 0.043598886477411725, 0.05211889023485128, 0.03330048537463881, 0.05934491869993508, 0.010182860769418767, 0.05917731577937957, 0.02139664073183667, 0.0662296891096048, 0.06432271839003079, 0.0322578755003633, 0.04980124096618965, 0.007044857229629997, 0.03645565200713463, 0.04679684905568138, 0.045042593774269335, 0.007020600596661097, 0.016893457468540873, 0.021626643429044634, 0.030465358795481734, 0.03222704668587539, 0.03529783112753648, 0.0504212125815684, 0.07201529428130016, 0.04313191973778885, 0.04136346346058417, 0.020672117207141127, 0.04042225693410728, 0.033925804164027795, 0.0098136265296489, 0.0633812446903903, 0.07229044553241692, 0.019289191805000883, 0.007571795995318098, 0.02669954006705666, 0.06411681693862192, 0.02545918494433863, 0.09018335142172873, 0.0625321757979691, 0.03455639962339774, 0.006345296305880765, 0.04201884294161573, 0.05668041929311585, 0.07180944478022866, 0.12110947631299496, 0.41479933890514076, 0.8126559213269502, 1.3974322518333793, 4.400497796013951, 3.959725722670555, 6.524940999224782, 9.337593298405409, 11.96707310155034, 11.334719583392143, 11.536105927079916, 19.40239727497101, 17.39627592265606, 19.302578531205654, 20.096203945577145, 24.52114250510931, 21.24996453523636, 26.629417575895786, 18.187344074249268, 21.253486946225166, 22.15847108513117, 17.586222030222416, 16.86182700097561, 15.403505153954029, 15.48437051475048, 9.869324415922165, 5.737186269834638, 2.4716894701123238, 1.1354335793294013, 0.17106134357163683, 0.01882327334897127, 0.019560526561690494, 0.028525317975436337, 0.06359307590173557, 0.004981631491318694, 0.02856550898286514, 0.04520228168985341, 0.08855821870383807, 0.052467265486484393, 0.02860145305021433, 0.06974386968067847, 0.10590214311378077, 0.026231508345517796, 0.02756648915237747, 0.03805411935900338, 0.06915869365911931, 0.03293809095339384, 0.042566102638375014, 0.05054240900790319, 0.014564541470463155, 0.046582787690567784, 0.07128649784135632, 0.04602435867127497, 0.008659879113110946, 0.04395957395900041, 0.15210625366307795, 0.06704784755129367, 0.009340758788312087, 0.033928650300367735, 0.017827940137067344, 0.03608592145610601, 0.06172091932967305, 0.07172668789280578, 0.07187105788034387, 0.03789180424064398, 0.06880987682961859, 0.04008774129033554, 0.02366533979511587, 0.028057390154572204, 0.037744554720120504, 0.037180745130172, 0.04000842796813231, 0.020637713096220978, 0.14091203949647024, 0.03550699431798421, 0.024837170567479916, 0.05336972819350194, 0.024557605393056292, 0.05327570550434757, 0.05608923558611423, 0.09356666909297928, 0.03532707916747313, 0.03887578073772602, 0.05492393385793548, 0.01153234314188012, 0.028144941315986216, 0.032418027258245274, 0.0030840946283205994, 0.05393252846261021, 0.05566968837229069, 0.010140502690774156, 0.06556586769875139, 0.04704625520389527, 0.02835782266629394, 0.07301389108761214, 0.06482547891209833, 0.024885178245313, 0.026279601370333694, 0.03136896440992132, 0.035441199215711094, 0.03693485305120703, 0.09710401951451786, 0.0530613955197623, 0.057005261041922495, 0.06325971058686264, 0.0523919041006593, 0.03421587258344516, 0.036878319951938465, 0.05975310363282915, 0.04464436846319586, 0.07103141426341608, 0.04405584164487664, 0.014664310238003964, 0.06876612722408026, 0.011337495052430313, 0.03168842558807228, 0.03557661890226882, 0.052914832485839725, 0.0465455133235082, 0.04580346583679784, 0.04606632712238934, 0.04305443580960855, 0.023748009480186738, 0.02817518568917876, 0.05972693921648897, 0.010559104593994562, 0.05139001215866301, 0.019958746306656394, 0.0277069981166278, 0.05608811494312249, 0.02576117967691971, 0.027988689544145018, 0.033180613681906834, 0.03715523380378727, 0.07202381413662806, 0.019088067929260433, 0.047720941656734794, 0.01941324364452157, 0.05522146828297991, 0.04114757641218603, 0.04247454759024549, 0.05067999576567672, 0.02359098773013102, 0.003109886811216711, 0.06505577475763857, 0.04380162266897969, 0.049738859743229114, 0.06391067057847977, 0.03689859913720284, 0.07044663900160231, 0.01754271608660929, 0.03682882241264451, 0.032635216775815934, 0.013471585225488525, 0.026911825843853876, 0.007219257759061293, 0.03210362381651066, 0.0037209229685686296, 0.014536876988131553, 0.06903914851136506, 0.042920923442579806, 0.02502105249732267, 0.004049499111715704, 0.06441845544031821, 0.02476392615790246, 0.008886166433512699, 0.04937158570101019, 0.06326905422611162, 0.0646979185694363, 0.022555179639311973, 0.08118812824250199, 0.03218264399038162, 0.04434995476913173, 0.05966386779618915, 0.06635075566009618, 0.03600449672376271, 0.21417610114440322, 0.7697552733588964, 1.282840019557625, 2.2465099906548858, 5.942859733477235, 5.629783133044839, 8.821906819939613, 11.887149140238762, 14.482524823397398, 14.893589615821838, 15.438505075871944, 22.61112369596958, 20.99985245615244, 24.242246970534325, 24.865723215043545, 28.977645970880985, 25.90071737766266, 30.268159322440624, 23.120125383138657, 26.81966956704855, 26.410002149641514, 21.79738976061344, 20.623433254659176, 18.292560428380966, 18.461183980107307, 11.72275761142373, 6.877981955185533, 3.5944715095683932, 1.416924730874598, 0.30250829877331853, 0.05370444792788476, 0.009885562903946266, 0.03670431600767188, 0.10284704767400399, 0.027475846945890225, 0.06198179165949114, 0.025147661035589408, 0.09583833860233426, 0.02356336499360623, 0.06822082679718733, 0.060591455912799574, 0.11196622435818426, 0.04727489606011659, 0.08885659175575711, 0.023633557320863474, 0.06415357551304623, 0.03651576225820463, 0.023480220334022306, 0.03957235312554985, 0.0566821113898186, 0.019107306252408307, 0.055543274647789076, 0.0417572061996907, 0.05984256582451053, 0.05417482112534344, 0.0685751206765417, 0.0898149493150413, 0.029760439101664815, 0.040002353489398956, 0.006652942956861807, 0.04638299782527611, 0.02016598176851403, 0.04831545018532779, 0.01384221841362887, 0.06892446443089284, 0.05188778173760511, 0.037244569830363616, 0.033138841899926774, 0.02765293265838409, 0.05054042376286816, 0.023107179804355837, 0.01534431232357747, 0.039102551381802186, 0.012158376248407876, 0.026802932370628696, 0.01563150955917081, 0.05126883428602014, 0.0201605659458437, 0.0570255550701404, 0.07378424037597142, 0.0648354236909654, 0.021651859751727898, 0.030505510840157513, 0.06609392061363906, 0.043023321268265136, 0.022591878841922153, 0.03792393923504278, 0.03370799124240875, 0.019053663818340283, 0.04374499309051316, 0.04371529234049376, 0.03620668743678834, 0.06909565563546494, 0.025467001614742912, 0.028622630234167445, 0.0841344174114056, 0.05486454349011183, 0.028604909603018314, 0.03253189868701156, 0.15691899228841066, 0.12819795141695067, 0.18683109112316743, 0.12438336430932395, 0.14383780828211457, 0.2077618968905881, 0.13065215956885368, 0.10080634194309823, 0.15295904071535915, 0.13174087536754087, 0.0893775348959025, 0.22394850879209116, 0.10840595641639084, 0.12177956887171604, 0.1718119962606579, 0.09260221107979305, 0.15432672982569784, 0.1150351831165608, 0.17374175833538175, 0.14820494659943506, 0.2170600721728988, 0.09190200958983041, 0.22654338361462578, 0.19183040567440912, 0.1308442125446163, 0.16496918688062578, 0.14580950170056894, 0.11739619236323051, 0.09832249983446673, 0.15788436314323917, 0.0842306442791596, 0.08535602217307314, 0.14648927928647026, 0.12140603852458298, 0.09224995068507269, 0.1119250054762233, 0.11916637042304501, 0.1375985876074992, 0.10194983566179872, 0.1424232154386118, 0.0691788800759241, 0.1273710950044915, 0.17872741736937314, 0.15634315990610048, 0.17310603463556617, 0.14627794531406835, 0.12938267143908888, 0.1199276655097492, 0.16629351972369477, 0.08289398436318152, 0.1650154375238344, 0.09587003572960384, 0.13617940829135478, 0.10893475147895515, 0.11366451799403876, 0.12447148692444898, 0.258127273991704, 0.09742624519276433, 0.10252646214212291, 0.12927503034006804, 0.09365855439682491, 0.14957555977161974, 0.12301593495067209, 0.11727576405974105, 0.20877347385976464, 0.10152804345125332, 0.11221255059354007, 0.1518577232491225, 0.1519558797008358, 0.1647948267054744, 0.12487826548749581, 0.1703412673668936, 0.1477016368880868, 0.16006599529646337, 0.12373036341159604, 0.15760804672027007, 0.19450253807008266, 0.34059499099384993, 0.9237784647848457, 1.405173148959875, 2.8529880847781897, 6.119541227817535, 5.635512275621295, 9.339023921638727, 12.291884422302246, 16.17731463164091, 16.186304949223995, 17.555728666484356, 26.610817573964596, 23.687262050807476, 27.94310588389635, 28.49318526685238, 31.592057682573795, 29.033643566071987, 34.45319585502148, 27.0333644002676, 30.294624902307987, 30.76848227530718, 25.234523825347424, 23.627966232597828, 20.013976357877254, 19.010972678661346, 13.818239718675613, 7.960727205500007, 3.6518268194049597, 1.4671764406375587, 0.4227070411434397, 0.13917373667936772, 0.12216209404869005, 0.09639327952754684, 0.3850653109839186, 0.15139447466935962, 0.19822492817183957, 0.11272040224866942, 0.21440478652948514, 0.10333926227758639, 0.09939586801920086, 0.16034274216508493, 0.2046952981618233, 0.12150537499110214, 0.15299073042115197, 0.1434345994493924, 0.26668180245906115, 0.1158075881539844, 0.13186046504415572, 0.1374462989042513, 0.1436123883468099, 0.12737630488118157, 0.10899237182457, 0.11590452006203122, 0.1388024105108343, 0.14075054816203192, 0.18582853866973892, 0.1950180041603744, 0.1166640265728347, 0.07144931019865908, 0.08427178152487613, 0.11963161538005807, 0.12026630007312633, 0.15542457404080778, 0.1475840955390595, 0.11393572101951577, 0.1299389556515962, 0.13797041843645275, 0.08903777226805687, 0.08233263870351948, 0.10354903031839058, 0.13316376542206854, 0.096344112243969, 0.14773843256989494, 0.3097503539174795, 0.09971971157938242, 0.10141310704057105, 0.14775579882552847, 0.16768506146036088, 0.1645135082071647, 0.1276924746343866, 0.18928638281067833, 0.11913630602066405, 0.15583645115839317, 0.2629309584153816, 0.11281708924798295, 0.13969505089335144, 0.13378319155890495, 0.12578736670548096, 0.06573943377588876, 0.12110042953281663, 0.12353793936199509, 0.17087153188185766, 0.15308896108763292, 0.0640568217204418, 0.17589685128768906, 0.14328781748190522, 0.12223984143929556, 0.1135289276135154, 0.23268689692486078], [0.011931783719774103, 0.1186128766858019, 0.04132680878683459, 0.028588790155481547, 0.010816564899869263, 0.08743851081817411, 0.012182130540168146, 0.03550733199517708, 0.05884663332835771, 0.014005490902491147, 0.042255602893419564, 0.03220548358513042, 0.03461978645646013, 0.028974445340281818, 0.0047606282623746665, 0.053954262257320806, 0.01245184463186888, 0.055273489124374464, 0.09791751726879738, 0.03241477665142156, 0.09455782957957126, 0.03754637160454877, 0.02050006325589493, 0.061154330396675505, 0.0038193899627003702, 0.04139490825764369, 0.05306669816491194, 0.0683581834891811, 0.0259865736370557, 0.023258611327037215, 0.044953450706088915, 0.03223489489755593, 0.0608327540976461, 0.06922370579559356, 0.00612092187111557, 0.032370897170039825, 0.033772142487578094, 0.04997341922717169, 0.05555293369980063, 0.022040539188310504, 0.04476451103982981, 0.05154479447810445, 0.02659007142938208, 0.04121644400584046, 0.09266305234632455, 0.012305316849960946, 0.055513069237349555, 0.042157761854468845, 0.04042484702949878, 0.07653016451513395, 0.049021455270121805, 0.0074905786004819674, 0.06625335619901307, 0.011519699728523847, 0.010375520450907061, 0.02690018154680729, 0.03216135548427701, 0.061065851550665684, 0.04108620451006573, 0.07510835057473741, 0.023050934287311975, 0.02783241365250433, 0.035937595821451396, 0.0025322806959593436, 0.06930567600647919, 0.026352979366492946, 0.04508220590651035, 0.03914771106792614, 0.06523424643091857, 0.02453608682117192, 0.02371203387156129, 0.0437200643500546, 0.037795451207784936, 0.021223865041974932, 0.04817382985493168, 0.027062619119533338, 0.05589358690485824, 0.020890750201942865, 0.006289059601840563, 0.061207568360259756, 0.03821545484242961, 0.1711932974285446, 0.27735961542930454, 0.5777648754883558, 0.5402426014188677, 1.3274251646362245, 1.9362634071148932, 1.6299557872116566, 2.1107052778825164, 2.6260039396584034, 3.155860095284879, 3.187369192019105, 4.4516948238015175, 3.8759701419621706, 7.470185402780771, 6.8353615421801805, 3.3444976480677724, 5.909704137593508, 3.873853893019259, 5.483568403869867, 3.0772192776203156, 2.258681212551892, 2.5342260394245386, 0.7394728576764464, 0.1460341943311505, 0.07334451045608148, 0.08141631638864055, 0.03759360559342895, 0.04799731745151803, 0.03235406526073348, 0.09793869816348888, 0.045842306135455146, 0.012751848553307354, 0.019387667380215134, 0.06380422433721833, 0.046074687415966764, 0.022256144220591523, 0.03867142295348458, 0.03109631419647485, 0.00556213291019958, 0.06451736146118492, 0.01993661731830798, 0.025104787164309528, 0.0259735378131154, 0.042409780362504534, 0.024578585907875095, 0.0018784667986437853, 0.1104552487959154, 0.10078986626467668, 0.027972451352979988, 0.07258300756802782, 0.06404426458175294, 0.07372261985437945, 0.018474098433216568, 0.017692652181722224, 0.06127957152784802, 0.05254920972220134, 0.09215711543220095, 0.030797740764683113, 0.057690408066264354, 0.07753374113235623, 0.059862459092983045, 0.07620671429322101, 0.012445763659343356, 0.03685352850880008, 0.055851581346360035, 0.027749474938900676, 0.02469399172696285, 0.039178072329377756, 0.06138534612546209, 0.029329498065635562, 0.015955521957948804, 0.03617786984250415, 0.037383151066023856, 0.036719415002153255, 0.03869746120471973, 0.049215371036552824, 0.0014714931899106887, 0.02378178462095093, 0.06817009358201176, 0.03748765288037248, 0.061709093206445687, 0.006188551469676895, 0.028510922165878583, 0.029855090760975145, 0.04302047142118681, 0.010088386297866236, 0.018144774112442974, 0.07970885722897947, 0.02808296641887864, 0.006113863582868362, 0.03169111587340012, 0.06511476807645522, 0.017768121178960428, 0.07754910358926281, 0.07131022430257872, 0.027174839269719087, 0.062239465332822874, 0.04090312038897537, 0.06435257499106228, 0.042724480663309805, 0.03539035838912241, 0.04590297299728263, 0.010517701102799037, 0.06436586685595103, 0.04685916348535102, 0.06601318236789666, 0.017412361557944678, 0.022866894651087932, 0.02915843859227607, 0.025885825234581716, 0.03901076255715452, 0.04907234062557109, 0.0460571282019373, 0.05958734494925011, 0.01577358074428048, 0.029154544172342867, 0.045696711604250595, 0.04420805613335688, 0.03476464997220319, 0.020401298243086785, 0.09239870676537976, 0.05216564553848002, 0.024967543649836443, 0.031770759451319464, 0.04821409878786653, 0.03476204503385816, 0.06087919398851227, 0.0789245184569154, 0.04555011146294419, 0.015762812181492336, 0.010574878015177092, 0.019765528159041423, 0.022887873310537543, 0.06930393195943907, 0.04853907783399336, 0.07167735733673908, 0.03604117737268098, 0.046795412999927066, 0.025669140377431177, 0.08847766599501483, 0.013148648940841667, 0.01591239204572048, 0.08749797911150381, 0.032706481506465934, 0.032199598354054615, 0.04451256674656179, 0.052034092441317625, 0.03848743341222871, 0.1305817297543399, 0.014049895453354111, 0.062090360443107784, 0.03100455320236506, 0.029926826755399816, 0.039247374079423025, 0.023299392341868952, 0.014877642443025252, 0.06416176882339641, 0.04014649341115728, 0.06360678336932324, 0.11133340987726115, 0.051182132883695886, 0.021914275748713408, 0.05934790584433358, 0.02408335447398713, 0.04126057210669387, 0.010155993168154964, 0.05508191112312488, 0.06901123633724637, 0.026550416623649653, 0.060911562759429216, 0.019844793241645675, 0.04365023567515891, 0.04048691283969674, 0.02744470642937813, 0.06841236026957631, 0.05044942532549612, 0.2350129807018675, 0.46878443739842623, 0.8159379952121526, 1.057024549227208, 2.042099009267986, 2.431001728400588, 2.282451787032187, 3.405269687063992, 4.145762789994478, 4.572517890483141, 4.935162356123328, 6.059017600491643, 5.558647625148296, 9.31922983378172, 8.37424049153924, 5.810472937300801, 7.7336998376995325, 5.328994123265147, 7.340785721316934, 4.3368597608059645, 2.965476536192, 2.8816758329048753, 1.0322232800535858, 0.2710583066800609, 0.022368405188899487, 0.07435582025209442, 0.0036254795304557774, 0.032973190827760845, 0.05654400141793303, 0.015412578777613817, 0.06011883400788065, 0.037284835052560084, 0.024008950458664913, 0.04686345680966042, 0.04451230699487496, 0.06529748483444564, 0.017498448833066504, 0.0203979530124343, 0.030583811130782124, 0.029125062355888076, 0.03783707827096805, 0.08138959907228127, 0.023663052124902606, 0.011080812146246899, 0.01696128791081719, 0.03190453157003503, 0.08257437104475684, 0.06357573191053234, 0.022733734804205596, 0.05960107839200646, 0.10906663112109527, 0.021668346562364604, 0.017526542833365966, 0.025636489590397105, 0.0041307271749246866, 0.10317361491615884, 0.07538306395872496, 0.025297676911577582, 0.030517446430167183, 0.03276879222539719, 0.0245151545459521, 0.007488952369385515, 0.006300184859355795, 0.008239766939368565, 0.05480544255988207, 0.014138611786620459, 0.0908847180835437, 0.05225240260188002, 0.04576092593197245, 0.027733440838346723, 0.04538510234851856, 0.03287207320681773, 0.013287230176501907, 0.011331352852721466, 0.06139736891782377, 0.02940736048913095, 0.01808300516131567, 0.040307654489879496, 0.033390114549547434, 0.06634213190409355, 0.043793733639176935, 0.05276246585708577, 0.04823090843274258, 0.03463252913206816, 0.00898982776561752, 0.008333167152159149, 0.026164937698922586, 0.0968248606659472, 0.039502309227827936, 0.012486322957556695, 0.028581283331732266, 0.040034347475739196, 0.024496270598319825, 0.058687583659775555, 0.014413594199140789, 0.16125654859934002, 0.1991680494393222, 0.17880614439491183, 0.14186951390001923, 0.17862981010694057, 0.1509529264876619, 0.16662137088133022, 0.12697974569164217, 0.13174795545637608, 0.09468540476518683, 0.17921597318490967, 0.13433960935799405, 0.1468040092731826, 0.18237964482977986, 0.06862874084617943, 0.08133078386890702, 0.11994472006335855, 0.27552268118597567, 0.16494396870257333, 0.06557940447237343, 0.14670091011794284, 0.13155299326172099, 0.12285274409805425, 0.20613070082617924, 0.05351689978851937, 0.21440776996314526, 0.15997851092834026, 0.23783741664374247, 0.11662257020361722, 0.09475721497437917, 0.20566014951327816, 0.1378621836192906, 0.14144095330266282, 0.21416246047010645, 0.12310949008679017, 0.09335509763332084, 0.14748791320016608, 0.08588395634433255, 0.20091840473469347, 0.16646424337523058, 0.15473439154447988, 0.14785098668653518, 0.12766562373144552, 0.13787284085992724, 0.2187400867114775, 0.10957560341921635, 0.11644878148217686, 0.1372566950158216, 0.11535910089151002, 0.1760727699729614, 0.12056917796144262, 0.13621964753838256, 0.17475737258791924, 0.1373781549045816, 0.08754720576689579, 0.10862699025892653, 0.1327792735537514, 0.13966352446004748, 0.08666051740874536, 0.14117845566943288, 0.19585572561481968, 0.19314253760967404, 0.1440792586072348, 0.15683334844652563, 0.3026937763206661, 0.1455113512929529, 0.13695370580535382, 0.12143873755121604, 0.18246603081934154, 0.16849777253810316, 0.15818684769328684, 0.12985953100724146, 0.08849831996485591, 0.1004035264486447, 0.21365552907809615, 0.07793895376380533, 0.07584698789287359, 0.08698194156750105, 0.1204806323221419, 0.13993924716487527, 0.1673597187618725, 0.37895363580901176, 0.6768672983162105, 1.0829168348573148, 1.005875850096345, 2.1446937415748835, 3.16491833422333, 2.75404566898942, 3.8562871981412172, 4.183577885851264, 5.506879203021526, 5.2886065654456615, 6.528322342783213, 5.922631518915296, 10.24053979665041, 9.845645036548376, 7.246838137507439, 8.953762594610453, 5.571991084143519, 7.217266699299216, 4.766486082226038, 3.5111481556668878, 3.123803115449846, 1.0299398400820792, 0.4538447968661785, 0.1352949018473737, 0.1496352581307292, 0.06715282434015535, 0.18115551676601171, 0.19911050330847502, 0.12548850383609533, 0.16829941130708903, 0.18286778504261747, 0.10175735224038363, 0.12170668996986933, 0.10441387727041729, 0.13454040483338758, 0.09255915167159401, 0.17376826785039157, 0.1353368628770113, 0.1300784942577593, 0.09449949677218683, 0.11717616784153506, 0.09944477555109188, 0.12177593234810047, 0.09642928853281774, 0.12016295600915328, 0.20096679276321083, 0.30182029819115996, 0.12234413545229472, 0.16664730152115226, 0.22771757998270914, 0.16166213230462745, 0.12342153349891305, 0.18102334026480094, 0.12501629011239856, 0.1664723624708131, 0.18430213385727257, 0.08303430964588188, 0.16874438821105286, 0.12671242409851402, 0.16260060772765428, 0.15490887046325952, 0.12117989870603196, 0.12795258255209774, 0.1759161174413748, 0.22601107077207416, 0.23387611436191946, 0.2800971013493836, 0.21017948747612536, 0.06207339494721964, 0.12541933567263186, 0.09645818034186959, 0.09820449093240313, 0.1664800214348361, 0.137524803285487, 0.11592963433940895, 0.12796511000487953, 0.0972177907533478, 0.14187674241838977, 0.13272711541503668, 0.17007565271342173, 0.10269304460962303, 0.17529296572320163, 0.16171203431440517, 0.0823009861051105, 0.13863087049685419, 0.06517604721011594, 0.223166047653649, 0.127347880625166, 0.11638307914836332, 0.17597922967979684, 0.1926862503751181, 0.13948009524028748, 0.2088543976424262, 0.1707372031523846], [0.017584152046765666, 0.059235240405541845, 0.04842445683607366, 0.041668526973808184, 0.02409631051705219, 0.028234184574102983, 0.03542536920576822, 0.04590508440742269, 0.05634605207887944, 0.013161622609914048, 0.024670862694620155, 0.010381577303633094, 0.028384588222252205, 0.0687761907465756, 0.022347343037836254, 0.04577259249344934, 0.10642047389410436, 0.014161067319946596, 0.04341673004091717, 0.039768038914189674, 0.016309309321513865, 0.03108267908828566, 0.049439206486567855, 0.029210095781309064, 0.040011808450799435, 0.024903501871449407, 0.04640613798983395, 0.040280169050674886, 0.04563738802971784, 0.053737484631710686, 0.017418810821254738, 0.043426671109045856, 0.039508090558229014, 0.02015705558733316, 0.022029308638593648, 0.04369822294393089, 0.07678267284063622, 0.05222503961704206, 0.06943313986994326, 0.07719314729911275, 0.026987137134710792, 0.02712941055506235, 0.01446707150535076, 0.03361647701240145, 0.0317713494587224, 0.07840658843633719, 0.00824027252747328, 0.07090670376783237, 0.0482258358533727, 0.037021584139438346, 0.05825696360261645, 0.04893650162557606, 0.04524100695562083, 0.021226551616564393, 0.03615834764786996, 0.02256505762488814, 0.02680404002603609, 0.020974881917936727, 0.02455555892083794, 0.03978602857387159, 0.040393513554590754, 0.08145022511598654, 0.15332822949858382, 0.03821436759608332, 0.014484588973573409, 0.07341996461036615, 0.0302849686704576, 0.01420933196641272, 0.06215744317159988, 0.0303458099369891, 0.022017775663698558, 0.01652400151215261, 0.06118022763985209, 0.028131022336310707, 0.04949548725562636, 0.050131608004448935, 0.06461581477196887, 0.040907406291808, 0.044171089757583104, 0.045986290206201375, 0.06654193290160038, 0.0528022078651702, 0.07234396922285669, 0.060572442089323886, 0.023007602139841765, 0.037549663029494695, 0.056499721176805906, 0.046019697983865626, 0.018308016915398184, 0.06707118067424744, 0.27432078786659986, 0.09185725066345185, 0.19811203266726807, 0.35963897535111755, 0.16570461069932207, 0.7452117372304201, 0.25219781091436744, 0.6967285356950015, 0.4733149817911908, 0.25107749446760863, 0.13752630242379382, 0.12911232188344002, 0.024220568302553147, 0.06681838291115128, 0.04120994279219303, 0.025538626287016086, 0.0612865254515782, 0.01993317189771915, 0.06604988157050684, 0.029669286668649875, 0.02767683723504888, 0.09457822379772551, 0.04254677340213675, 0.10880857895244844, 0.01751582993165357, 0.006842036154921516, 0.03043034241272835, 0.03742752036487218, 0.023803857948223595, 0.06343065688270144, 0.06518026260891929, 0.033806893552537076, 0.030247414142650086, 0.0392562538763741, 0.030325402731250506, 0.02445054502459243, 0.017608516754989978, 0.13134968932718039, 0.05621698888717219, 0.0073480653736623935, 0.04496997091337107, 0.038527052965946496, 0.09057320159627125, 0.019109829554508906, 0.09060186333954334, 0.06922284490428865, 0.08152303722454235, 0.02222086623078212, 0.04268846423656214, 0.044712460512528196, 0.021820459005539306, 0.03385407188034151, 0.07011553723714314, 0.06395560019882396, 0.026856200020120014, 0.033958406711462885, 0.10019530207500793, 0.04108517292479519, 0.05428256241430063, 0.051048887689830735, 0.06863843329483643, 0.054336757748387754, 0.05345923491404392, 0.019693871945491992, 0.11963962315348908, 0.04809561862202827, 0.04789734273799695, 0.03936074455850758, 0.034592980082379654, 0.019385535561013967, 0.1691747151198797, 0.03839941098704003, 0.046781319615547545, 0.01292342289161752, 0.05342417585779913, 0.07547378409071825, 0.03229776964872144, 0.03373184757947456, 0.08182463119737804, 0.093667831242783, 0.014676719874842092, 0.04034554855024908, 0.03498660407785792, 0.02964582366985269, 0.028341087236185558, 0.03107717235252494, 0.041340115494676866, 0.06778605442377739, 0.06962825791561045, 0.07121774528059177, 0.04093431285582483, 0.03578745563572738, 0.02159373660106212, 0.04001799796242267, 0.1138525633723475, 0.012926994477311382, 0.03631954583397601, 0.022115364372439217, 0.03932762621843722, 0.05659642301907297, 0.04421610101417173, 0.03548731627233792, 0.09544977976474911, 0.03850534885714296, 0.03206665372999851, 0.025547140576236416, 0.07029577522189356, 0.05451194170746021, 0.010068010633403901, 0.03924679520423524, 0.04498715163208544, 0.07208875205833465, 0.026571256130409893, 0.07663816926651634, 0.014678326624562033, 0.0300742729450576, 0.060433434118749574, 0.012445000174921006, 0.027051631623180583, 0.03957215645641554, 0.046674710101797245, 0.006896650338603649, 0.06717911863233894, 0.0644265819573775, 0.050525762635516, 0.1119274842494633, 0.03494432021398097, 0.05229357695498038, 0.01766252469678875, 0.010420127237011911, 0.01915754965011729, 0.05412833299487829, 0.01910718379804166, 0.10376676902524196, 0.0734019378433004, 0.055525002971990034, 0.03689059136377182, 0.018924448486359324, 0.06654727636487223, 0.058502295360085554, 0.017353702205582522, 0.006008326008668519, 0.0042642302651074715, 0.04391986163682304, 0.01897800000733696, 0.024186060290958267, 0.06741329591022804, 0.07369483384536579, 0.058246926055289805, 0.04748635990836192, 0.027067960727436002, 0.06389557529473677, 0.021038192680862267, 0.027515807887539268, 0.029222975754237268, 0.043739786924561486, 0.06037545383151155, 0.019673644710564986, 0.027438066063041333, 0.041226080793421715, 0.03060068756894907, 0.0471369679144118, 0.02530866626329953, 0.011755529212678084, 0.010666275356925325, 0.049937161602429114, 0.04100739584828261, 0.009072387056221487, 0.028463992457545828, 0.01715019974653842, 0.0211252521694405, 0.02900541887356667, 0.025006502692122012, 0.07066332385875285, 0.18057419249089435, 0.17304123030044138, 0.2308716779225506, 0.22396446496713907, 0.2718094195006415, 0.490042693563737, 0.4129170742817223, 1.1869163042865694, 0.42445153347216547, 0.939151489874348, 0.7608355488628149, 0.40305366448592395, 0.3436554892687127, 0.21963752136798576, 0.01288621902858722, 0.05439508313429542, 0.023861250083427876, 0.049917824944714084, 0.022419745109800715, 0.03155666097882204, 0.08733345981454477, 0.01939305722771678, 0.03041635292902356, 0.018858026269299444, 0.050232410212629475, 0.03293599438620731, 0.05381132461479865, 0.013519958411052357, 0.02429741398373153, 0.032732645922806114, 0.0552814486582065, 0.021296747654560022, 0.04903410888800863, 0.03163353634590749, 0.0438500886230031, 0.022567987252841704, 0.04377912817290053, 0.00438929374467989, 0.04715193703304976, 0.023493232038163114, 0.012629571374418447, 0.00390894469092018, 0.06860176377813332, 0.06806151737691835, 0.0035895368546334794, 0.025049528703675605, 0.06067755617550574, 0.11772828118409961, 0.031860652088653296, 0.028976540052099153, 0.015470295602426631, 0.059328676798031665, 0.03347558398672845, 0.0393219413672341, 0.03943720803363249, 0.05557503114687279, 0.044419701807782985, 0.04525226162513718, 0.0728886759316083, 0.06042496250302065, 0.016070886958914343, 0.013066649044048972, 0.017718413982947823, 0.11365602782461792, 0.10379793180618435, 0.028845200322393794, 0.06594510516151786, 0.023625364010513294, 0.08112529802019708, 0.043461258901515976, 0.05260411380731966, 0.06880700471810997, 0.007160376226238441, 0.01347209545201622, 0.04627020622137934, 0.027010757839889266, 0.03151754237478599, 0.03080778016737895, 0.005372583291318733, 0.013036349009780679, 0.04416031006257981, 0.01621544433874078, 0.018593407949083485, 0.07786688380292617, 0.06949595524929464, 0.050582499825395644, 0.02618892762257019, 0.04941386214341037, 0.10185684455791488, 0.10610275305225514, 0.08867800876032561, 0.10872338782064617, 0.13763956900220364, 0.1113251868810039, 0.09885417443001643, 0.15210594196105376, 0.22024194127880037, 0.07567224922240712, 0.06238142334041186, 0.23558335087727755, 0.13416398753179237, 0.11809695046395063, 0.12431547263986431, 0.12850957922637463, 0.17595629731658846, 0.11379123228834942, 0.1829066884238273, 0.10353386081987992, 0.14095119520789012, 0.13872116018319502, 0.10881055306526832, 0.14868921280140057, 0.16263357392745093, 0.11915960945771076, 0.22227637586183846, 0.26107253157533705, 0.09111768566071987, 0.1979656663024798, 0.13919634249759838, 0.17151331150671467, 0.1457541374838911, 0.17722961492836475, 0.11116191439214163, 0.1011731632752344, 0.1754723725025542, 0.1497118329280056, 0.1483037116122432, 0.23672023206017911, 0.13089850806863979, 0.10243704076856375, 0.10141268401639536, 0.14301141200121492, 0.07205635731224902, 0.2224856466636993, 0.13242469023680314, 0.2779195213224739, 0.1899918238632381, 0.22078753856476396, 0.1027985112159513, 0.17486827913671732, 0.16135387384565547, 0.1937814525444992, 0.09464166258112527, 0.1504001600551419, 0.058480880688875914, 0.08757598625379615, 0.09107381731155328, 0.14428861846681684, 0.23017475672531873, 0.17427971150027588, 0.2631812106119469, 0.08182210789527744, 0.11538825245224871, 0.175640840025153, 0.10206444552750327, 0.08805325400317088, 0.23043433029670268, 0.13783160713501275, 0.14237789990147576, 0.11397353344364092, 0.13522083550924435, 0.08702512714080513, 0.20296821661759168, 0.09207183524267748, 0.13484803988831118, 0.13978099159430712, 0.14915209030732512, 0.07463215893949382, 0.15036931639770046, 0.15843695146031678, 0.167440167570021, 0.1426286864443682, 0.11155389453051612, 0.14384024252649397, 0.13927325868280604, 0.1292510738130659, 0.2493143593892455, 0.18158431485062465, 0.47086607257369906, 0.36253106547519565, 0.4162028292194009, 0.6015758228022605, 0.5322535894811153, 1.282329778186977, 0.6319131574127823, 1.0407326859422028, 0.7537717279046774, 0.5396708508487791, 0.3503250516951084, 0.3909201140049845, 0.1594144044793211, 0.1584818513947539, 0.17000816180370748, 0.2143079659435898, 0.1875192698207684, 0.16554794332478195, 0.15352982649346814, 0.21832089201780036, 0.09979640512028709, 0.164220018486958, 0.2301563959917985, 0.18177512101829052, 0.19410394539590925, 0.14669163327198476, 0.07706675212830305, 0.15375058574136347, 0.11662262957543135, 0.11794740770710632, 0.1305584263172932, 0.19096709496807307, 0.19067500048549846, 0.09080677773454227, 0.18458192353136837, 0.14050014753593132, 0.12912300880998373, 0.2440089831361547, 0.17080377379897982, 0.15821420325664803, 0.1541468480718322, 0.20232389884768054, 0.11972905937000178, 0.10493576293811202, 0.18121430970495567, 0.1501046071643941, 0.1534181332681328, 0.15204811381408945, 0.12281694289413281, 0.21937355428235605, 0.20928699552314356, 0.11280321108642966, 0.13343855302082375, 0.1642802363494411, 0.10860926035093144, 0.10685111250495538, 0.3116507863160223, 0.1650020491797477, 0.08009944212972187, 0.22154828446218744, 0.0837372793466784, 0.19561486900784075, 0.12104266075766645, 0.1226748809858691, 0.20565756683936343, 0.16172555624507368, 0.15404536679852754, 0.1727093121735379, 0.21973229362629354, 0.09496472688624635, 0.2527876995736733, 0.14145055669359863, 0.18605429999297485, 0.12492641602875665, 0.18069983809255064, 0.18817995936842635, 0.14015067019499838, 0.16107951669255272, 0.15164929849561304, 0.1921277100336738, 0.08923188841436058, 0.19982038240414113, 0.10487168590771034, 0.10513448782148771, 0.10789322885102592, 0.1546099630650133], [0.02669830253580585, 0.05269278561172541, 0.04295010097848717, 0.08386233123019338, 0.062146247873897664, 0.07462277077138424, 0.019465299737930764, 0.07345713136601262, 0.025422728795092553, 0.04014612233731896, 0.07085013727191836, 0.007357755039265612, 0.06514672495541163, 0.034412270833854564, 0.07412117542116903, 0.052555688671418466, 0.03190787123457994, 0.05130847239342984, 0.017394214191881474, 0.03963628914789297, 0.12101139407604933, 0.008399001217185287, 0.04641396022634581, 0.026280360216333065, 0.04368576228443999, 0.03677876455185469, 0.07934444045531563, 0.03128132790152449, 0.03701341680425685, 0.03579838747100439, 0.025569618373992853, 0.036771710438188165, 0.005139551240063156, 0.07823773499694653, 0.04873589910857845, 0.0407897313561989, 0.020928015292156488, 0.059119565557921305, 0.015943039034027606, 0.0198640426970087, 0.03908018676156644, 0.06441397286835127, 0.02769471742794849, 0.0703379069454968, 0.04888163835857995, 0.03942283263313584, 0.09295447147451341, 0.03955952139222063, 0.016792080095910933, 0.028247764021216426, 0.03404344570299145, 0.043818740305141546, 0.02498694339010399, 0.05926331956288777, 0.012492231380747398, 0.08466170591418631, 0.04691521418862976, 0.03780400445975829, 0.036026289890287444, 0.05876657785847783, 0.01417243795003742, 0.03577728450181894, 0.021105332925799303, 0.021797303998027928, 0.04463361845409963, 0.03566136474546511, 0.03324676501506474, 0.024265631509479135, 0.04839158711547498, 0.04965473730408121, 0.030978637405496556, 0.05741500077419914, 0.04686927153670695, 0.015194678653642768, 0.006671319461020175, 0.03413219914364163, 0.047441563874599524, 0.03220846701879054, 0.01807482298318064, 0.01053496345775784, 0.0580625023576431, 0.057916288133128546, 0.04314385347242933, 0.0031480689176532906, 0.01386584004649194, 0.011009946319973096, 0.016419121202488896, 0.031504180005867966, 0.043109651596751064, 0.050533510657260194, 0.05546210224565584, 0.029535160174418706, 0.007588382068206556, 0.03233025345252827, 0.05305972197675146, 0.01341471630439628, 0.014184853152983123, 0.04400605466798879, 0.019240987458033487, 0.034631263770279475, 0.009989232585212449, 0.07378784721367992, 0.07899140822701156, 0.02886278922233032, 0.023006260707916226, 0.02310039100848371, 0.0323612529609818, 0.01943097355251666, 0.004249025050739874, 0.02562511061114492, 0.011897136555489851, 0.04755418478453066, 0.04510176520852838, 0.016658493514114525, 0.023740307842672337, 0.05401828733738512, 0.026491183962207288, 0.03717743886227254, 0.021637111422023736, 0.02968848046293715, 0.0374458625447005, 0.007037791519906023, 0.03104260682448512, 0.03420727851334959, 0.015832984099688474, 0.06160794218885712, 0.06682460953015834, 0.053162502008490264, 0.029790577718813438, 0.016633054547128268, 0.04276451210898813, 0.032074847040348686, 0.00228256261380011, 0.033037063767551444, 0.013809582469548332, 0.022044648831069935, 0.031234164416673593, 0.043387422629166394, 0.05611411608697381, 0.032733944681240246, 0.044037454936187714, 0.0071292612210527295, 0.06605195216252469, 0.03895876398019027, 0.04578865999064874, 0.04597526931320317, 0.008617193561804015, 0.031243745543179102, 0.05913100205361843, 0.04995141083782073, 0.08359295388800092, 0.052022258896613494, 0.04584688889735844, 0.03484431952529121, 0.05160722022992559, 0.03387627693882678, 0.009684470569482073, 0.04381641367217526, 0.007584795175716863, 0.0360031274612993, 0.0460417026624782, 0.01643438903556671, 0.03384526258741971, 0.047809420502744615, 0.031950964039424434, 0.03893033601343632, 0.0733536908228416, 0.03324761848489288, 0.01879197698144708, 0.03327347119920887, 0.01923190357047133, 0.01792955499695381, 0.014061268866498722, 0.03143590613035485, 0.0203434645300149, 0.035940382585977204, 0.03626460093073547, 0.04840450419578701, 0.057821014925139025, 0.050390420874464326, 0.016413909470429644, 0.0534903791412944, 0.004214366290398175, 0.010845209944818635, 0.025402868923265487, 0.08066239824984223, 0.024292150301334914, 0.04484846649575047, 0.026267448702128604, 0.05205737361393403, 0.06638499835389666, 0.06719603217788972, 0.035410181153565645, 0.058769175375346094, 0.051616626951727085, 0.027591289872361813, 0.03659625188447535, 0.03557075222488493, 0.052173820295138285, 0.027803662851511035, 0.03845730592729524, 0.08963885251432657, 0.02177932547056116, 0.03011029493791284, 0.02036915026110364, 0.07246334367664531, 0.003744136188288394, 0.027995042328257114, 0.04377247110824101, 0.07179808992077596, 0.03188002956449054, 0.04937494020850863, 0.04230369035212789, 0.036433313362067565, 0.06539147783769295, 0.033057788241421804, 0.0167861781665124, 0.061847615070291795, 0.027747409912990406, 0.09853966708760709, 0.057529265541234054, 0.010598197222861927, 0.03192277727066539, 0.031239797317539342, 0.014332060927699786, 0.06181290853419341, 0.029460717196343467, 0.03472920499916654, 0.005027150655223522, 0.051301329222042114, 0.019638290650618728, 0.021019542509748135, 0.04445215963642113, 0.018272347442689352, 0.013995083209010772, 0.023544805735582486, 0.028174924082122743, 0.029299272246134933, 0.019424058591539506, 0.061752835390507244, 0.049027971326722763, 0.05889948537515011, 0.00833122829135391, 0.02939511505246628, 0.042986139669665135, 0.047906779145705514, 0.027658678736770526, 0.10653678327798843, 0.03906030462530907, 0.05133509694132954, 0.003072786616939993, 0.031084037218533922, 0.06260827562073246, 0.034025815984932706, 0.02731460794166196, 0.027348180847184267, 0.010440440746606328, 0.03424389236897696, 0.04912699980195612, 0.03840906261757482, 0.05788767091871705, 0.0889203348197043, 0.04188735292700585, 0.03939347698178608, 0.03433926576690283, 0.08979315243777819, 0.026353953435318545, 0.023331197080551647, 0.06452630434068851, 0.04579398861096706, 0.006566713745996822, 0.03155885773594491, 0.042537069821264595, 0.02239572178950766, 0.0036994382571720053, 0.04620791405614, 0.02672791051736567, 0.04507812038355041, 0.06910390089615248, 0.06959417107282206, 0.06707127715344541, 0.03174712575855665, 0.021364895364968106, 0.011754553288483294, 0.06748739193426445, 0.05508423775609117, 0.09041087163495831, 0.03081192135141464, 0.028608596221602056, 0.039085003299987875, 0.028837823374487925, 0.030694630477228202, 0.028588882923941128, 0.0538700952893123, 0.04324606947193388, 0.061236348847160116, 0.01518472552561434, 0.03916602727258578, 0.023228431891766377, 0.05799786500574555, 0.05027589635574259, 0.04419898337800987, 0.06358770275255665, 0.034261525797774084, 0.003258253495914687, 0.011583897357922979, 0.024704339120944496, 0.04125108374864794, 0.008599786488048267, 0.007169042191890185, 0.0287213488627458, 0.06204488905495964, 0.06590459874132648, 0.014289555347204441, 0.006976403383305296, 0.04323879642470274, 0.04860048684349749, 0.12021384507534094, 0.0652233071741648, 0.032185564341489226, 0.007836509867047425, 0.0163355720724212, 0.040492274856660515, 0.06259654968744144, 0.016019307695387397, 0.027580560272326693, 0.015948670079524163, 0.03748164148419164, 0.01606535053724656, 0.05662432777171489, 0.04162158984399866, 0.03101406568021048, 0.031041708825796377, 0.02022039974690415, 0.05267307045869529, 0.05350508479750715, 0.04313114048272837, 0.003137066578347003, 0.016291915235342458, 0.018299352341273334, 0.05801874904136639, 0.04501289673498832, 0.09421774782822467, 0.046470660308841616, 0.0645516041549854, 0.031204307815642096, 0.0447593568242155, 0.027400865910749417, 0.015653961381758563, 0.060249915841268376, 0.030975377521826886, 0.07086495053954422, 0.13752700004260987, 0.1719451227108948, 0.13993681292049587, 0.12191762318252586, 0.19223941810196266, 0.12530477775726467, 0.08832576320855878, 0.1133144914638251, 0.07638089635293, 0.20192851225147024, 0.13593749783467501, 0.23362874169833958, 0.16974128549918532, 0.1440393310622312, 0.18552605411969125, 0.13432568666758016, 0.1533005473902449, 0.10929835931165144, 0.12240613446920179, 0.16586994635872543, 0.27875859348569065, 0.09094927008845843, 0.08842751907650381, 0.10705917360610329, 0.08579774847021326, 0.18351784703554586, 0.1116971364535857, 0.12765512976329774, 0.2200824092142284, 0.12966450944077224, 0.10149442416150123, 0.13890853762859479, 0.10762071964563802, 0.11824204775621183, 0.18382580863544717, 0.08365582863916643, 0.09576232041581534, 0.17147972190286964, 0.08562808608985506, 0.13392697524977848, 0.09596903822966851, 0.19578853156417608, 0.07592096517328173, 0.2770446182694286, 0.09831599119934253, 0.14452288480242714, 0.14885549840983003, 0.07287340995389968, 0.07460367531166412, 0.1290966328815557, 0.12252720101969317, 0.1483309335890226, 0.09341092940303497, 0.11331631714710966, 0.17937612865353003, 0.17228511540452018, 0.15196098567685112, 0.09584530736901797, 0.128036979585886, 0.11151655708090402, 0.12989083479624242, 0.1261260235332884, 0.11879629106260836, 0.1569731393828988, 0.09363897654111497, 0.1735660177655518, 0.17172748048324138, 0.10623515961924568, 0.13939229917014018, 0.1638607299537398, 0.105320863367524, 0.16947601223364472, 0.10221957665635273, 0.11493972066091374, 0.13044250285020098, 0.138987724785693, 0.11589021887630224, 0.1193132191838231, 0.1294663263252005, 0.10842195712029934, 0.14318204659502953, 0.11568454006919637, 0.12206536994199269, 0.10279830341460183, 0.09249105962226167, 0.1690370764117688, 0.1106114783033263, 0.11422915136790834, 0.16379859735025093, 0.16634929954307154, 0.0793655842426233, 0.12940594519022852, 0.177683571819216, 0.12723001273116097, 0.1245067389390897, 0.10910116325248964, 0.13122011034283787, 0.09902431920636445, 0.1290748582687229, 0.12967501825187355, 0.09630063723307103, 0.1682418948621489, 0.13968071260023862, 0.14541939919581637, 0.15876083954935893, 0.13588882779004052, 0.13294505450176075, 0.13957495655631647, 0.11550719646038488, 0.11403213342418894, 0.1416676794178784, 0.10068629213492386, 0.09064624377060682, 0.09904193037073128, 0.11931544562685303, 0.13543415843741968, 0.1363611305714585, 0.22886939317686483, 0.12761641934048384, 0.07041927601676434, 0.1323250198038295, 0.09063124496606179, 0.08415924967266619, 0.14118764345766976, 0.13745063304668292, 0.16782538674306124, 0.21902566513745114, 0.1786881874431856, 0.12915793427964672, 0.1809430102002807, 0.1138240129512269, 0.15973504196153954, 0.10377741142292507, 0.0944036929286085, 0.09444437004276551, 0.17229844437679276, 0.1463293909910135, 0.1169752239366062, 0.18897365662269294, 0.11457632805104367, 0.1847281414666213, 0.20441225788090378, 0.13022367318626493, 0.11652279586996883, 0.12711889838101342, 0.09713624356663786, 0.1647674711421132, 0.2108601704821922, 0.10171225934755057, 0.15863238862948492, 0.1097660162486136, 0.12183285507489927, 0.17106824554502964, 0.10526143218157813, 0.15406331192934886, 0.08039370368351229, 0.09525455039693043, 0.12882098439149559, 0.15476006985409185, 0.1339373950031586, 0.12238910218002275, 0.07723687464022078, 0.07946857207571156, 0.1163344610540662, 0.11558593090740032, 0.09455972205614671, 0.18930791993625462, 0.0687958428170532, 0.1020459141000174, 0.10240706542390399, 0.18137131846742705, 0.10967448717565276, 0.08990641159471124, 0.09282488506869413, 0.11254303637542762, 0.12406215537339449], [0.01025707275402965, 0.03786507950280793, 0.045328706546570174, 0.04017728511826135, 0.03232738505175803, 0.03217006829800084, 0.058268659850000404, 0.02649156431289157, 0.03702681256982032, 0.052921322567272, 0.01222775685164379, 0.06977186349104159, 0.10618312764563598, 0.02364768966799602, 0.04739434472867288, 0.06174281268613413, 0.04321551154134795, 0.028245040339243133, 0.044838039320893586, 0.036998781652073376, 0.03522253282426391, 0.04009033138572704, 0.015072029473230941, 0.02424828566290671, 0.06468987368862145, 0.05494292170624249, 0.02190104882174637, 0.03859597250993829, 0.02510332142264815, 0.016122991291922517, 0.013337303807929857, 0.033813524642027915, 0.024785279601928778, 0.019824523333227262, 0.038287253919406794, 0.03453097364399582, 0.09630138680222444, 0.02784345309919445, 0.050575167406350374, 0.10854307562112808, 0.03780136612476781, 0.003881694883602904, 0.012438081503205467, 0.06216320223757066, 0.05658882713760249, 0.04226426375680603, 0.03210906375898048, 0.04571885729092173, 0.039688617980573326, 0.02882869495806517, 0.10766145613160916, 0.06776415364583954, 0.05084732038085349, 0.006895878968862235, 0.004953755960741546, 0.004255347685102606, 0.020447359638637863, 0.013518398973246804, 0.050293047388549894, 0.0538262083864538, 0.042640328538254835, 0.014073231359361671, 0.005813391644551302, 0.018023293814621866, 0.030425896948145237, 0.041775158751988783, 0.037277710434864275, 0.029193705449870322, 0.0329158784734318, 0.03863131729303859, 0.01854855625424534, 0.011718668592948234, 0.022181014755915385, 0.0005984273002468399, 0.016648968048684765, 0.05320089701854158, 0.04524546726315748, 0.06387940389686264, 0.025530624079692643, 0.03436614264501259, 0.04035195328469854, 0.029095651043462567, 0.04902573746221606, 0.020984188449801877, 0.03548694890923798, 0.040671306851436384, 0.06822708310210146, 0.018784746607707348, 0.028462658447097056, 0.034205972333438694, 0.019802169845206663, 0.03161140550218988, 0.029892075690440834, 0.03169308998622, 0.014421579708141508, 0.03923420466890093, 0.040899227824411355, 0.10663606779417023, 0.08795541667495854, 0.033566255879122764, 0.02697434993024217, 0.05076329813164193, 0.02835959825461032, 0.05038127761508804, 0.03139361855573952, 0.04533077713858802, 0.06808109523262829, 0.025948907787096687, 0.03158824307320174, 0.0878205090702977, 0.03369007208675612, 0.04243546609359328, 0.03076059256272856, 0.018549602682469413, 0.08888457814464346, 0.02490931288775755, 0.06709294786560349, 0.04489888800890185, 0.04353876880486496, 0.012192631929792697, 0.06120837359048892, 0.060464960552053526, 0.06173988862428814, 0.04710519657237455, 0.00918892650588532, 0.03137689425784629, 0.008989352791104466, 0.04231638849887531, 0.014419220606214367, 0.044780637908843346, 0.03745209287444595, 0.030729808277101256, 0.05201162763114553, 0.025268185818276834, 0.046358221225091256, 0.05516399636690039, 0.027346596361894626, 0.015832976678211708, 0.01525240475530154, 0.027917489751416724, 0.04031010357721243, 0.021849905569979455, 0.0729779785615392, 0.009371551423100755, 0.03891421285516117, 0.09448362965486012, 0.04792197833012324, 0.02199426628067158, 0.04808851626876276, 0.04350562077888753, 0.010238179529551417, 0.0343934944976354, 0.06329794603516348, 0.015060349924169714, 0.03567801111785229, 0.033425656001782045, 0.028146705772087444, 0.03741564600204583, 0.03465992180281319, 0.030100613621470984, 0.10309185992809944, 0.0035183660520488047, 0.04182990698609501, 0.04167365150351543, 0.03162350993079599, 0.03146781848045066, 0.026030532899312675, 0.03336643632792402, 0.03587847633752972, 0.030784222544752993, 0.07061664276989177, 0.015190062495094026, 0.014686098766105715, 0.05551165544602554, 0.020432728197192773, 0.03724761263583787, 0.00836279925351846, 0.004395402547743288, 0.03255749907111749, 0.04236889544699807, 0.12014446168905124, 0.05185972484468948, 0.024436024905298837, 0.07795058321789838, 0.05053703956946265, 0.046931444958318025, 0.02735741130891256, 0.04227284298394807, 0.038161400516401045, 0.030548429240297992, 0.05496481135196518, 0.012294076095713535, 0.03643369927885942, 0.03710725766723044, 0.04339008322858717, 0.028636254210141487, 0.05629330022202339, 0.046046675051911734, 0.018365039832133334, 0.032814033547765575, 0.049785774608608335, 0.04734762653242797, 0.023247607132361736, 0.0338636344531551, 0.03874243164318614, 0.028716088891087566, 0.036573972611222416, 0.05087218974949792, 0.026546255030552857, 0.033022410061676055, 0.0635550259903539, 0.047759971203049645, 0.03718310887052212, 0.01368479868688155, 0.07188350369688123, 0.06548835779540241, 0.022911985688551795, 0.030746640186407603, 0.025034899117599707, 0.05762126587796956, 0.03074483305681497, 0.024547070606786292, 0.02090274887450505, 0.03774589058593847, 0.030599453748436645, 0.044972408868488856, 0.10945916044875048, 0.10091048752656206, 0.037378293709480204, 0.04568919735902455, 0.11447279845015146, 0.1151814752665814, 0.0705917362938635, 0.0156439498096006, 0.0018808265963343729, 0.024263900450023357, 0.05124174589582253, 0.06556273583555594, 0.019913185860787053, 0.03354470391059294, 0.019323148771945853, 0.026938057053484954, 0.028584630417753942, 0.030193146449164487, 0.009282107785111293, 0.011773602363973623, 0.040483461853000335, 0.03643007017672062, 0.016375091436202638, 0.04408223612699658, 0.06971123002585955, 0.04752435415866785, 0.07785362162394449, 0.048791619556141086, 0.03881489123159554, 0.028298129873292055, 0.014232971225283109, 0.048655275895725936, 0.12304979914915748, 0.03561396377335768, 0.04858829335717019, 0.07109391794074327, 0.021116893731232267, 0.08717108532437123, 0.025401160128240008, 0.05449154748930596, 0.037062001501908526, 0.031394817124237306, 0.04244469469995238, 0.05884551639610436, 0.03789724789385218, 0.07400796821457334, 0.01577378669026075, 0.08989704569103196, 0.05026017766795121, 0.0179765218126704, 0.03198017868271563, 0.009391298117407132, 0.03146684626699425, 0.019169116021657828, 0.008404730597249, 0.0541498218808556, 0.043069211969850585, 0.004666683962568641, 0.06732948517310433, 0.05976905238640029, 0.020127844654780347, 0.040046303474809974, 0.07293830334674567, 0.09731720885611139, 0.11621792160440236, 0.04958419987815432, 0.06214276720129419, 0.0273993649170734, 0.01937607132276753, 0.046409047208726406, 0.03140947454085108, 0.04110460606170818, 0.047150415630312636, 0.0847923090623226, 0.06463911078753881, 0.07987956603756174, 0.027446836393210106, 0.03194415112375282, 0.051672974514076486, 0.1211919957131613, 0.041797252488322556, 0.00869199184307945, 0.04308072639105376, 0.01482486275563133, 0.022619633309659548, 0.0490799958788557, 0.057347595211467706, 0.011978189286310226, 0.043246926652500406, 0.02479512790159788, 0.06545695010572672, 0.04449496671441011, 0.019544969291018788, 0.014577288784494158, 0.054245963401626796, 0.01741773656249279, 0.039058527181623504, 0.0635625958966557, 0.09943833370925859, 0.01789906200428959, 0.03726589915459044, 0.06735037663020194, 0.010781219189084368, 0.028129265301686246, 0.014958945648686495, 0.006073191107134335, 0.034900013997685164, 0.016739315251470543, 0.0802218890748918, 0.029426355758914724, 0.054373653620132245, 0.027259516464255285, 0.05918061091506388, 0.01629883947316557, 0.02560659959272016, 0.01008340370390215, 0.019321966901770793, 0.04084053136466537, 0.045630875683855265, 0.06630331758060493, 0.06845768322818913, 0.07566634172690101, 0.015085137656569714, 0.06076342266169377, 0.06476185459177941, 0.03868600986606907, 0.06073474607546814, 0.12469759705709293, 0.13365083694225177, 0.11846728957607411, 0.20746005058754236, 0.07846400098060258, 0.15408710518386215, 0.18980585649842396, 0.15091779321664944, 0.17040835751686245, 0.10879716472118162, 0.14939771150238812, 0.15802617272129282, 0.12674439582042396, 0.1422076066955924, 0.1640479441266507, 0.14366245362907648, 0.16533009329577908, 0.1393690551049076, 0.10070399977848865, 0.1407275118981488, 0.16786964843049645, 0.09273341536754742, 0.10413002804853022, 0.12011671278742142, 0.11827361871837638, 0.16798254393506795, 0.14195839350577444, 0.18921215320006013, 0.11920998644200154, 0.10519860195927322, 0.12317767119384371, 0.14995325356721878, 0.194272160588298, 0.13855094119207934, 0.19342165935086086, 0.22421170404413715, 0.15922735357889906, 0.11554593656910583, 0.17877121892524883, 0.10949391522444785, 0.08849221951095387, 0.104690015577944, 0.164571558998432, 0.08677898644236848, 0.15463028306839988, 0.07414102787151933, 0.13250254152808338, 0.14861637842841446, 0.13256212114356458, 0.2881448913831264, 0.2440171319176443, 0.11248522307141684, 0.21209210593951866, 0.19023180473595858, 0.13884910644264892, 0.1804726815316826, 0.07104881762643345, 0.17081863159546629, 0.22870999469887465, 0.12547756457934156, 0.1496144334669225, 0.10849110301933251, 0.08006778210983612, 0.1048546536185313, 0.13037493772571906, 0.19588860275689512, 0.16586274752626196, 0.1295873409253545, 0.1519957627169788, 0.05201781714276876, 0.09844862783211283, 0.1466903419350274, 0.08330683369422331, 0.0829690600221511, 0.10404798362287693, 0.18358248809818178, 0.1426119584357366, 0.14601754053728655, 0.12373198129353113, 0.10049065458588302, 0.14933121507056057, 0.16112126992084086, 0.13341814395971596, 0.17672018992016092, 0.13652222114615142, 0.14714000921230763, 0.17644483828917146, 0.1358425771468319, 0.16044628660893068, 0.19615513767348602, 0.12175306677818298, 0.12419422797393054, 0.14241062861401588, 0.12111861957237124, 0.1855763272033073, 0.10363697481807321, 0.17483056319179013, 0.2611306862672791, 0.07380185896181501, 0.1318707808968611, 0.13051906280452386, 0.1073176042700652, 0.050406532900524326, 0.0706688454374671, 0.11848450740217231, 0.20620398048777133, 0.11388988597900607, 0.12482201069360599, 0.2286116749746725, 0.19422265933826566, 0.08104559135972522, 0.17163958051241934, 0.16163232765393332, 0.18505508720409125, 0.1745293996646069, 0.11995348482741974, 0.09239972350769676, 0.13907378423027694, 0.09489731019129977, 0.12213164372951724, 0.12195904244435951, 0.12047289172187448, 0.19983552221674472, 0.13222306355601177, 0.2092678629560396, 0.05582241494266782, 0.18689306045416743, 0.18858440016629174, 0.2271919316262938, 0.1076002289482858, 0.17803183203795925, 0.14591095328796655, 0.11346184488502331, 0.14003216405399144, 0.14084141672356054, 0.11796126360422932, 0.16581755073275417, 0.13233686448074877, 0.1408590649953112, 0.15327029745094478, 0.10697103614802472, 0.19637675781268626, 0.13028930872678757, 0.13056623371085152, 0.2019599050981924, 0.10840487288078293, 0.1345104814390652, 0.16748438472859561, 0.07214047975139692, 0.08173072725185193, 0.194093466270715, 0.20615968911442906, 0.11042318059480749, 0.13744496303843334, 0.10542239659116603, 0.12597772758454084, 0.0851565774064511, 0.1200172798417043, 0.09679478884208947, 0.16728977876482531, 0.10696107652620412, 0.2160015914705582, 0.1398571507888846, 0.08240067880251445, 0.1616964492131956, 0.13036279618972912, 0.10611316538415849, 0.13410534302238375, 0.15522915171459317, 0.17117735609645024, 0.1435441998182796, 0.09214872916345485, 0.1019430004816968, 0.136148861492984, 0.08865662748576142], [0.03072289146075491, 0.021504035066755023, 0.06202698845299892, 0.027562605864659417, 0.1098465986433439, 0.021661873179255053, 0.0728366439579986, 0.02860727890947601, 0.02207964480476221, 0.02112319642037619, 0.04405552623211406, 0.04000243512564339, 0.021945781772956252, 0.00838300793475355, 0.02330669878574554, 0.01789215260942001, 0.10389870061771944, 0.03562768979463726, 0.0640212134749163, 0.02039247781794984, 0.041895690956152976, 0.05271823385555763, 0.004506935283643543, 0.08126174929202534, 0.04993335438484792, 0.005069530070613837, 0.0076878140862390865, 0.02533844679419417, 0.035971975812572055, 0.026680220107664354, 0.03906942190951668, 0.018225542044092435, 0.007298356322280597, 0.051765156676992774, 0.009923570141836535, 0.04007202631328255, 0.03843975042400416, 0.038670049980282784, 0.044579419409274124, 0.013733139403484529, 0.03867418745358009, 0.07619066163897514, 0.062118454443407245, 0.0750951403460931, 0.017291690201091114, 0.038321901083691046, 0.02806592299748445, 0.07724759867414832, 0.02162989960197592, 0.09412175844772719, 0.1315467295353301, 0.04795451779500581, 0.04130069261009339, 0.05328780251147691, 0.02102728125464637, 0.035949941448052414, 0.098176148312632, 0.022826365966466255, 0.03728081632289104, 0.025739974662428722, 0.04399720826768316, 0.040495443827239797, 0.04911706244456582, 0.03837880154605955, 0.013018561585340649, 0.02334780449018581, 0.05483050859766081, 0.02862380468286574, 0.02228687470051227, 0.05644205259159207, 0.04217266417981591, 0.04484037337533664, 0.0277389123220928, 0.0509895604045596, 0.02512707385903923, 0.02195907920395257, 0.03653554420452565, 0.05075703069451265, 0.055962380283745006, 0.08556339307688177, 0.03334208275191486, 0.113040876458399, 0.037232368922559544, 0.02795482534565963, 0.014028208970557898, 0.023538002096756827, 0.014101694578130264, 0.007458810969183105, 0.03855903953080997, 0.028905969229526818, 0.07577287702588364, 0.025245800788979977, 0.04102091035747435, 0.01041344141412992, 0.009293128678109497, 0.029688461909245234, 0.0398433260852471, 0.021289543255988974, 0.00886854691998451, 0.052550983455148526, 0.03445199799898546, 0.04704921637312509, 0.0333077027607942, 0.06789120932808146, 0.0697414280148223, 0.04429506923770532, 0.035506738277035765, 0.018970194469147827, 0.09820645020226948, 0.043434393155621365, 0.028923602658323944, 0.08349124254891649, 0.056852931520552374, 0.0386452362727141, 0.028551523209898733, 0.017231307210749947, 0.03063667430978967, 0.0420064564968925, 0.08374414421268739, 0.03615753128542565, 0.030112410058791284, 0.014343702441692585, 0.025582906528143212, 0.09659057948738337, 0.05268191685900092, 0.02126825103914598, 0.04164033649431076, 0.05231145900324918, 0.020902659816783853, 0.02101290585414972, 0.08358559920452535, 0.006764079571439652, 0.02670122845302103, 0.016580948358750902, 0.027053193844039924, 0.04592935263644904, 0.012578195273817983, 0.027074779209215194, 0.08517635564203374, 0.06182536919368431, 0.06896749415318482, 0.059873899299418554, 0.0167390592105221, 0.036308721610112116, 0.0161322458734503, 0.014198359313013498, 0.04508977952355053, 0.06485396253992803, 0.03322847478557378, 0.07032970621366985, 0.06857971457066014, 0.051565904868766665, 0.03356024819368031, 0.047522688037133776, 0.025131042493740097, 0.05142442183569074, 0.020956795779056847, 0.049668318606563844, 0.05217367557634134, 0.07251593968248926, 0.034107248138752766, 0.01429598049071501, 0.011700523082254222, 0.03860698969219811, 0.012317916662141215, 0.025328162482765038, 0.03513573123200331, 0.019116748226224445, 0.0399412376282271, 0.05594647976977285, 0.10306531330570579, 0.12650659686187282, 0.04585144568409305, 0.03187766582414042, 0.07747139330604114, 0.04538301691354718, 0.04742223463836126, 0.04714025562861934, 0.018968559888890013, 0.01350047517917119, 0.09310527588240802, 0.017931532820512075, 0.017738787792040966, 0.025225269273505546, 0.05348611179215368, 0.0915641691244673, 0.03843771693937015, 0.08128031782689504, 0.04108927329070866, 0.027501250660861842, 0.025041942099051084, 0.03989697594079189, 0.06755044480087236, 0.01676175779721234, 0.005639959153995733, 0.023744944410282187, 0.06944216438569129, 0.03232787115848623, 0.016171499919437338, 0.06849512457847595, 0.04442488570930436, 0.05394880376115907, 0.05077856039861217, 0.06563312112120911, 0.030100339026830625, 0.021648226938850712, 0.10190795626840554, 0.04633945231034886, 0.0251284746627789, 0.011426652963564266, 0.026644713907444384, 0.07089072532835416, 0.05696559695934411, 0.04820429872779641, 0.04435645227204077, 0.009280001941078808, 0.03407080497709103, 0.06053021759726107, 0.05119050430948846, 0.046396835168707184, 0.04421574478328694, 0.06255688189412467, 0.07770860596792772, 0.03355450397066306, 0.049343614155077375, 0.061982938277651556, 0.03872176654112991, 0.034832767996704206, 0.02207886554970173, 0.019672954513225704, 0.03725191709236242, 0.010625120485201478, 0.02846474017133005, 0.03198786362190731, 0.05325866208295338, 0.059871951161767356, 0.02053141713986406, 0.056548227948951535, 0.028813766657549422, 0.03559809294529259, 0.0190908417062019, 0.06457559036789462, 0.024544476800656412, 0.041235398457502015, 0.03315001493319869, 0.09608195599867031, 0.05485755988047458, 0.04991994006559253, 0.03585474245483056, 0.08178680393029936, 0.058014622700284235, 0.05558134311286267, 0.0526381449890323, 0.04651875147828832, 0.005996780510031385, 0.04604503861628473, 0.07144536939449608, 0.07398678731988184, 0.07545856264187023, 0.037417026396724395, 0.048756835094536655, 0.027734810100810137, 0.017378508491674438, 0.025980259815696627, 0.022678511595586315, 0.03382549177331384, 0.04922601343423594, 0.06121041820733808, 0.019889099457941484, 0.05681476657628082, 0.021645876186084934, 0.010347990482841851, 0.014348022668855265, 0.05648880047374405, 0.07867237378377467, 0.0230778631157591, 0.019204087875550613, 0.08900905115297064, 0.06198674549523275, 0.0726569774269592, 0.05309201282216236, 0.039938372938195243, 0.06130160218162928, 0.019038715108763427, 0.026775630612974055, 0.02216927026893245, 0.04138392447202932, 0.09799168008612469, 0.06038796644133981, 0.03345111908856779, 0.016861422664078418, 0.015275391851901077, 0.0572485556040192, 0.02925920554844197, 0.07603641366586089, 0.06413698109099641, 0.0148174329297035, 0.026994128165824804, 0.03513511524943169, 0.029349387623369694, 0.036714973248308524, 0.048692041891627014, 0.05290751490974799, 0.01869898958830163, 0.009638864667067537, 0.01360927773930598, 0.021740665142715443, 0.01775269935023971, 0.042824778211070225, 0.04077458412211854, 0.05700438159692567, 0.014263970733736642, 0.037196749544818886, 0.003390376655261207, 0.017404761965735815, 0.036804253613809124, 0.0365423942275811, 0.043067709120805375, 0.0603668783151079, 0.010824041110026883, 0.03982173329859506, 0.01824937240598956, 0.045557844641734846, 0.006785631539969472, 0.01990404816751834, 0.11344747690600343, 0.03567974032193888, 0.05578963799052872, 0.03480536048300564, 0.06358435566653498, 0.0390108553256141, 0.0038035910301914555, 0.05965859483694658, 0.01563981790241087, 0.016791128291515633, 0.09728303295560181, 0.0376169424271211, 0.02091348960675532, 0.061816378074581735, 0.06757701368769631, 0.046378979095607065, 0.054767099500168115, 0.018924711948784534, 0.027500016840349417, 0.022026195329090115, 0.04056563615449704, 0.1043191718054004, 0.06882442292408086, 0.03999554057372734, 0.07337686067330651, 0.05680986098013818, 0.01876661593996687, 0.12115511839510873, 0.13471718440996483, 0.21254129824228585, 0.12218549396493472, 0.1905732965678908, 0.17253446218091995, 0.1756895100697875, 0.14209631423000246, 0.20391113008372486, 0.1804292807355523, 0.1610184379387647, 0.1583799990476109, 0.13597595592727885, 0.12670559633988887, 0.13955895585240796, 0.12949705123901367, 0.22365147160599008, 0.1625975055503659, 0.11839116006740369, 0.19596154103055596, 0.18780333426548168, 0.1359928768943064, 0.061480908771045506, 0.26144137897063047, 0.11116252295323648, 0.17365606996463612, 0.10725386862759478, 0.12004603806417435, 0.10530799452681094, 0.10549189129960723, 0.23023731977446005, 0.14126331283478066, 0.13063189893728122, 0.19239013345213607, 0.0805491316714324, 0.11275607728748582, 0.14278959890361875, 0.14737865421921015, 0.14116094098426402, 0.08872876423993148, 0.11496381077449769, 0.1610783440992236, 0.20122372428886592, 0.15952832414768636, 0.16007539088604972, 0.11777082851040177, 0.1684939578990452, 0.18601514428155497, 0.08975130273029208, 0.123206421994837, 0.14966558228479698, 0.08586572177591734, 0.13695746107259765, 0.1762388032511808, 0.09894604489090852, 0.15969173022313043, 0.22207991452887654, 0.08425096428254619, 0.1330473818234168, 0.09176170657156035, 0.1810009719338268, 0.09521814063191414, 0.1342003676109016, 0.14569006045348942, 0.08420176731306128, 0.10359338106354699, 0.07756503749988042, 0.15676373499445617, 0.17177849571453407, 0.20710738201159984, 0.16935695690335706, 0.1497763255611062, 0.1771613076562062, 0.12172260161605664, 0.19998110190499574, 0.10864123207284138, 0.09590471629053354, 0.14359304797835648, 0.2030690002720803, 0.1534278702456504, 0.13084859121590853, 0.17759163456503302, 0.19545955234207213, 0.1749032046063803, 0.10714824617025442, 0.1299022787134163, 0.06440184617531486, 0.09049574364325963, 0.10792030239827, 0.11105281126219779, 0.2109700528671965, 0.11892407404957339, 0.09630416985601187, 0.15020322374766693, 0.117219294043025, 0.12830488005420193, 0.163748828927055, 0.1346727742929943, 0.1269715078524314, 0.11759654255001806, 0.07334778332733549, 0.18143405963201076, 0.1507000916171819, 0.14895046362653375, 0.10722544437157921, 0.17103260761359707, 0.15905483392998576, 0.11561594335944392, 0.13035948621109128, 0.09983509327867068, 0.09203262758092023, 0.23377004661597311, 0.18583244236651808, 0.09262761479476467, 0.1288319830200635, 0.23854650906287134, 0.1770354839391075, 0.08432332368101925, 0.12276750843739137, 0.16066152427811176, 0.1356455369386822, 0.11464160736068152, 0.06738344673067331, 0.14095477235969156, 0.13853841373929754, 0.13510632212273777, 0.18028048012638465, 0.09245348468539305, 0.09272066527046263, 0.1536609639879316, 0.12833711894927546, 0.10143821389647201, 0.1490154312341474, 0.14227661158656701, 0.13864986947737634, 0.12224388614413328, 0.08680371480295435, 0.13306096312589943, 0.11410338702262379, 0.135933430865407, 0.13731318729696795, 0.13372433924814686, 0.13759032008238137, 0.10454966060933657, 0.10974021177389659, 0.08604937363998033, 0.10029869066784158, 0.1317486382322386, 0.11595628486247733, 0.21253454469842836, 0.1311717223143205, 0.151925778191071, 0.12610769248567522, 0.12569694343255833, 0.22247142711421475, 0.12714764918200672, 0.21885837020818144, 0.14484326995443553, 0.15403487283037975, 0.15136885573156178, 0.18937031971290708, 0.15762660041218624, 0.11890336812939495, 0.11327466781949624, 0.13772629637969658, 0.17083386046579108, 0.30141006864141673, 0.237798439047765, 0.1461255081812851, 0.1185520131548401, 0.26599546428769827, 0.18355461303144693, 0.09098742390051484, 0.22580736607778817, 0.1415294618345797, 0.1284296202356927], [0.029582974893855862, 0.0271356631492381, 0.02539365701522911, 0.008817001980787609, 0.02273920257721329, 0.008005285380932037, 0.03948980775021482, 0.05993000195303466, 0.0141140142295626, 0.10405632536276244, 0.054449668095912784, 0.03006336894031847, 0.041197734462912194, 0.03209929709555581, 0.03537191601935774, 0.03511465423798654, 0.07012271380517632, 0.030783131587668322, 0.033858005263027735, 0.016874126376933418, 0.019186959107173607, 0.0355196998862084, 0.042688835310400464, 0.010615314859023783, 0.02592857479612576, 0.0526794863253599, 0.022894554494996555, 0.05237267505435739, 0.053814920320292, 0.014487411917798454, 0.03134508209768683, 0.054102973808767274, 0.027594241764745675, 0.07780446176184341, 0.07007391017396003, 0.060569492052309215, 0.034144177407142706, 0.009674807806732133, 0.01720029285934288, 0.013248098584881518, 0.014128890579740983, 0.07446799587341957, 0.07463725749403238, 0.04092495066288393, 0.021396557240223046, 0.019915885422960855, 0.03229976231523324, 0.0457256145455176, 0.017384842722094618, 0.049154975058627315, 0.06960758168133907, 0.04860001557972282, 0.04725814578705467, 0.07254667943925597, 0.0072523645030742045, 0.05133258848218247, 0.038475009860121645, 0.023410298890667036, 0.015704987745266408, 0.04074492047948297, 0.029158384786569513, 0.041591733242967166, 0.03626142082794104, 0.04063325694005471, 0.03412172743992414, 0.057925238434108905, 0.027630673794192262, 0.03935081833333243, 0.013095076083118329, 0.04144502920098603, 0.006007865877108998, 0.0323390107951127, 0.048560655777691863, 0.03708973184984643, 0.028235114114067983, 0.06313484424026683, 0.05696144093235489, 0.09994690524763428, 0.04299953914596699, 0.05580742727033794, 0.011161491020175163, 0.06168042775243521, 0.03339112015964929, 0.04173832596279681, 0.05563738268392626, 0.03117367195955012, 0.009372492095280904, 0.06154829949082341, 0.0976243540935684, 0.07400555623462424, 0.03588246909203008, 0.014838431998214219, 0.058564138525980525, 0.01608908441994572, 0.05431675315776374, 0.035997464874526486, 0.10767670726636425, 0.04184049743344076, 0.013737626613874454, 0.03750844414753374, 0.020382282564241905, 0.07772055454552174, 0.04226988923619501, 0.05518185986147728, 0.025630865966377314, 0.03709329786943272, 0.10450387751916423, 0.026949948114634026, 0.03764157430850901, 0.04021370601549279, 0.03056014589674305, 0.029156501586840022, 0.09949792074621655, 0.030359977536136284, 0.03866773819027003, 0.040039624145720154, 0.10653923978679813, 0.031338310000137426, 0.015270567892002873, 0.07834996999008581, 0.01002688080916414, 0.07602217927342281, 0.05333514040103182, 0.039127543204813264, 0.04182178417977411, 0.032689772051526234, 0.012189132703497307, 0.010121813556907, 0.045616392671945505, 0.03255827832617797, 0.08690353366546333, 0.02932764640718233, 0.03632032508903649, 0.010689825558074517, 0.030372774017450865, 0.027005223273590673, 0.04773622247739695, 0.016155979756149463, 0.060248457521083765, 0.03405665964237414, 0.0446070458565373, 0.06508707112516277, 0.03565559454727918, 0.07507144357077777, 0.042804109398275614, 0.04148636682657525, 0.05624972502118908, 0.07620635064085945, 0.06095896002079826, 0.08761526070884429, 0.017123996367445216, 0.03938851943530608, 0.06484335724962875, 0.05917755697737448, 0.017978104442590848, 0.02613316450151615, 0.024165139147953596, 0.04375639618956484, 0.03764204557228368, 0.013552081345551414, 0.07898153766291216, 0.05724727539927699, 0.027796762733487412, 0.04343241162132472, 0.010415896995255025, 0.0779723133018706, 0.033332141683786176, 0.036490210113697685, 0.07209007308119908, 0.03274209346272983, 0.05721888825064525, 0.05527727407752536, 0.03148475429043174, 0.06047180686437059, 0.027212512541154865, 0.04009482880064752, 0.03293952700914815, 0.06705900203087367, 0.0499469022906851, 0.03475902820355259, 0.06763033699826337, 0.005657318451994797, 0.028989612983423285, 0.07569859546492808, 0.04836875123146456, 0.05235843324044254, 0.03755181154701859, 0.0050579316939547425, 0.062487387185683474, 0.05431809273432009, 0.03553956346877385, 0.06062514199584257, 0.05062698415713385, 0.025290298108302522, 0.05053057546319906, 0.02109360142640071, 0.06140891302493401, 0.0651565584121272, 0.0766943943744991, 0.027968994800176006, 0.054331217615981586, 0.052654802493634634, 0.05335899673809763, 0.02219433074060362, 0.01592315689777024, 0.016473932519147638, 0.08113752861390822, 0.038282081150100566, 0.03182733336871024, 0.07200826614280231, 0.0711954734288156, 0.03306425605842378, 0.06334565128781833, 0.016667545860400423, 0.06941286439541727, 0.02051095427304972, 0.0397429580334574, 0.055521574249723926, 0.006247703422559425, 0.02810641086398391, 0.024297935342474375, 0.013730418504565023, 0.038081471211626194, 0.055887211856315844, 0.03902578362612985, 0.020719753811135888, 0.043815445169457234, 0.019386452113394625, 0.04574684367980808, 0.008034147504076827, 0.05928368409513496, 0.01801584079657914, 0.05615177266008686, 0.015372042671515374, 0.03324762961710803, 0.06528589990921319, 0.0738444656599313, 0.04703196515038144, 0.027154801282449625, 0.07130430196411908, 0.022999210304988082, 0.10852659252122976, 0.03164621222822461, 0.05010596680222079, 0.07990297337528318, 0.01568560841405997, 0.005566463805735111, 0.061416571988957, 0.09807641850784421, 0.04589466094330419, 0.011954859874094836, 0.040559431799920276, 0.02727105686062714, 0.04921285144519061, 0.02016456055571325, 0.041572693444322795, 0.17941715457709506, 0.013843474498571595, 0.023643552194698714, 0.025082042193389498, 0.033813661939348094, 0.03111967700533569, 0.0030101760239631403, 0.026382802570878994, 0.08125992360874079, 0.01107154086639639, 0.03990532881289255, 0.08066963418968953, 0.025583802671462763, 0.034768802288454026, 0.011810007490566932, 0.009194537142320769, 0.04693656577728689, 0.02569484837295022, 0.03891420172294602, 0.1055674122471828, 0.030267196088971104, 0.02141605902579613, 0.024199574800150003, 0.033934847233467735, 0.06207005157193635, 0.00932613755139755, 0.06356634374242276, 0.04923963926557917, 0.01363589579341351, 0.01708219675492728, 0.008650373129057698, 0.05361134921258781, 0.044327092909952626, 0.04619167586497497, 0.02585706144600408, 0.05298741081787739, 0.012178615543234628, 0.09705316755571403, 0.09361211079522036, 0.05638887771056034, 0.054470255272462964, 0.07203947345260531, 0.022972804690652993, 0.012909547513118014, 0.06317822277196683, 0.06734890717780218, 0.022714364749845117, 0.04711505229352042, 0.021794905005663168, 0.04909002971544396, 0.0517314223543508, 0.026023417558462825, 0.03762741413083859, 0.011754203551390674, 0.03962269671319518, 0.04728448831883725, 0.03157756356813479, 0.059906331152888015, 0.023196387810457963, 0.019106456493318547, 0.03775908968236763, 0.026882987840508576, 0.03377082146471366, 0.008370191972062457, 0.036186534416629, 0.05327500788553152, 0.03960606889449991, 0.06631109528825618, 0.03940852402593009, 0.08848674246110022, 0.06092439449275844, 0.09342889679828659, 0.05879907279449981, 0.022903515928192064, 0.03438308216573205, 0.038280118169495836, 0.021348261980165262, 0.050193692368338816, 0.02166550784750143, 0.0248774098145077, 0.04921572355669923, 0.1254824479110539, 0.044858374167233706, 0.008350190164492233, 0.03569358879758511, 0.03889858322509099, 0.04641321807866916, 0.052948433221899904, 0.043403215531725436, 0.03228234410926234, 0.038038805141695775, 0.02392422316916054, 0.029463609716913197, 0.04283778434910346, 0.03848820153507404, 0.03961777256336063, 0.09451318939682096, 0.1771190349245444, 0.09243953230907209, 0.06949908711249009, 0.0903297400509473, 0.1514684667927213, 0.12359970831312239, 0.1724637800361961, 0.13602655555587262, 0.2560678735608235, 0.15938405063934624, 0.0838092750927899, 0.19471476261969656, 0.2419521802221425, 0.12904812610941008, 0.13257383223390207, 0.206335652328562, 0.07326233986532316, 0.1395427918760106, 0.1088149836868979, 0.14618960005464032, 0.17695681628538296, 0.1910872635198757, 0.16164009051863104, 0.11727164514013566, 0.16881199786439538, 0.08459463060717098, 0.12066285926266573, 0.0739845831412822, 0.10129526141099632, 0.13446031225612387, 0.20647606666898355, 0.08113028525258414, 0.19501396687701344, 0.15007460955530405, 0.11268897229456343, 0.13716156652662903, 0.12103808170650154, 0.14484202314633876, 0.09815384677494876, 0.11681882373522967, 0.24024004553211853, 0.10509549538255669, 0.1153911319852341, 0.08413690360612236, 0.09672463362221606, 0.1568577205762267, 0.12986413232283667, 0.13301100174430758, 0.12085829643183388, 0.3299332380993292, 0.10392683543614112, 0.17789217468816787, 0.13061591307632625, 0.140972776862327, 0.15186370495939627, 0.14510685112327337, 0.1163601319422014, 0.1464809523895383, 0.20560092612868175, 0.21492059400770813, 0.16299779032124206, 0.14058025495614856, 0.09382522592204623, 0.12163128034444526, 0.2637008030433208, 0.12940569286001846, 0.14392711833352223, 0.10048269876278937, 0.07046972721582279, 0.125599677558057, 0.1343144357088022, 0.15811812481842935, 0.13705385121284053, 0.11651069886283949, 0.11520759886479937, 0.11479428940219805, 0.2015482951537706, 0.09411763210664503, 0.1764112783712335, 0.27758798911236227, 0.16839952702866867, 0.08231503496062942, 0.15989133826224133, 0.14604033931391314, 0.14209477056283504, 0.10681171188480221, 0.1471906978986226, 0.203864092763979, 0.16214737814152613, 0.12544105091365054, 0.10728961045970209, 0.16423950728494674, 0.11107181024271995, 0.15348143846495077, 0.15251916978741065, 0.17231143196113408, 0.10325663155526854, 0.10093439952470362, 0.1393346194527112, 0.16270415217150003, 0.20546183281112462, 0.12339406661340035, 0.09956137437256984, 0.14305059739854187, 0.1421759169897996, 0.2033617626875639, 0.10860206893994473, 0.16297533293254673, 0.23302130866795778, 0.13017271732678637, 0.16965617600362748, 0.21773539687274024, 0.1841065927874297, 0.16943324968451634, 0.13545712048653513, 0.11854963086079806, 0.16392011661082506, 0.13405959703959525, 0.14710223389556631, 0.15961733734002337, 0.24474229925544932, 0.0966116416384466, 0.2716005494585261, 0.09760374465258792, 0.12245896796230227, 0.10255961387883872, 0.12754371855407953, 0.07256871380377561, 0.1719815473188646, 0.18487850058590993, 0.0907003389147576, 0.07971351049491204, 0.14514452253933996, 0.11639296455541626, 0.13122337579261512, 0.14663726353319362, 0.08185262500774115, 0.1289368633297272, 0.08617363142548129, 0.22784853936173022, 0.21761105745099485, 0.06727202067850158, 0.15464172698557377, 0.24076483299722895, 0.14427848072955385, 0.15100805321708322, 0.2048358609317802, 0.16745576751418412, 0.19241627189330757, 0.1862146781058982, 0.12100579086109065, 0.18645261065103114, 0.1494086062302813, 0.09714476342196576, 0.09313160728197545, 0.1402711949776858, 0.12676462676608935, 0.09864477746305056, 0.10276224245899357, 0.1413918676553294, 0.35446587949991226, 0.15441654453752562, 0.08949182563810609, 0.12471830297727138, 0.1977968425489962, 0.12129809314501472, 0.09468950142036192, 0.19479228736599907, 0.13110800151480362, 0.0923662081186194, 0.1614869706099853, 0.10919380554696545, 0.16049694560933858, 0.09175376559142023, 0.1046849021804519], [0.04178741161013022, 0.08112363560940139, 0.020794916672457475, 0.03781797910050955, 0.042677499004639685, 0.023402493352477904, 0.017559588814037852, 0.05083170559373684, 0.011449174362496706, 0.005136252393640461, 0.07118340610759333, 0.011508882926136721, 0.06290242585237138, 0.011793092089646962, 0.05545298867218662, 0.07373611952061765, 0.041623979559517466, 0.004502561250774306, 0.037582529039354995, 0.06450113069149666, 0.03872257177135907, 0.02396999883785611, 0.010325713992642704, 0.016494656993017998, 0.017848801908257883, 0.012057576823281124, 0.04808916193724144, 0.027835220826091245, 0.018621147573867347, 0.06311011587968096, 0.03765820583794266, 0.07051979249808937, 0.03083118008362362, 0.052728145237779245, 0.02457984199281782, 0.04055660050653387, 0.0333690523984842, 0.03263933198468294, 0.07558964076451957, 0.05040397620177828, 0.006943086054889136, 0.04130675966734998, 0.013778838074358646, 0.017458063011872582, 0.021305302761902567, 0.04299254811485298, 0.019911284107365645, 0.06359195525874384, 0.06470171836554073, 0.07335710470215417, 0.015258260300470283, 0.02718985291721765, 0.023698560180491768, 0.037716186125180684, 0.06389877395122312, 0.05375660606659949, 0.02293052639288362, 0.04992212569050025, 0.019158863251504954, 0.05769092385889962, 0.0262387442853651, 0.023799254777259193, 0.06798915055696853, 0.07857891512685455, 0.10847476092749275, 0.040935055003501475, 0.07837360739358701, 0.012450188714865362, 0.009377277092426084, 0.07226877482025884, 0.08154901981470175, 0.053570787131320685, 0.03436376035097055, 0.0072049621394398855, 0.04254867701092735, 0.06398541227099486, 0.04746132355649024, 0.02794010299112415, 0.02225777137937257, 0.030010748814675026, 0.016832124529173598, 0.08582528214901686, 0.007146502703108126, 0.0483220441674348, 0.0491710685309954, 0.056821167599991895, 0.03090726320806425, 0.14475560747087002, 0.05269898996630218, 0.031205799532472156, 0.01419892520061694, 0.02219343830802245, 0.01663336624915246, 0.021862735447939485, 0.016195447169593535, 0.05210492672631517, 0.04310285723477136, 0.08664490262162872, 0.04809925885638222, 0.050034831947414204, 0.002617091708998487, 0.03397578409931157, 0.0846026161161717, 0.09894168848404661, 0.009775943053682568, 0.032388912804890424, 0.012024987263430376, 0.05783546082966495, 0.03179026309226174, 0.020992008830944542, 0.012007343630102696, 0.04996653580747079, 0.012219301934237592, 0.0396238655957859, 0.011352646924933651, 0.004640745901269838, 0.03411651756323408, 0.02399539513135096, 0.044059730498702265, 0.029482070640369784, 0.10208147781668231, 0.03004671700182371, 0.0303103983605979, 0.04333114928158466, 0.008718468889128417, 0.051185736010666005, 0.03791448056290392, 0.03633579515735619, 0.07249600559589453, 0.03156589329591952, 0.01384310806315625, 0.007894865866546752, 0.016390821256209165, 0.03490841139864642, 0.048483424179721624, 0.022551626607310027, 0.006460346821768326, 0.02543950318795396, 0.04687028456828557, 0.017017145655700006, 0.05575189978117123, 0.07503020984586328, 0.015117860803002259, 0.013571727849921444, 0.032635127718094736, 0.051951936693512835, 0.02298446197528392, 0.045939709307276644, 0.019435945941950195, 0.0310563328457647, 0.03211252958863042, 0.027730654073820915, 0.03464042558334768, 0.05817286342789885, 0.021613320022879634, 0.04820872563868761, 0.04192725820757914, 0.07153082027798519, 0.02262148496811278, 0.06724065009620972, 0.01814605431718519, 0.0032569628547207685, 0.04115861956961453, 0.020680935776908882, 0.01511491262135678, 0.042387887006043456, 0.034648637447389774, 0.043652213498717174, 0.03342564115882851, 0.05904008154175244, 0.02347700126847485, 0.02157861348678125, 0.022411655700125266, 0.07306567073101178, 0.05907003833272029, 0.012458416349545587, 0.04914667413686402, 0.0658171069517266, 0.07395194348646328, 0.017270602074859198, 0.041650878702057526, 0.07778665021760389, 0.010687214125937317, 0.0380979134934023, 0.047144218697212636, 0.005604639882221818, 0.052568368264473975, 0.07992486673174426, 0.023287326876015868, 0.02821114831021987, 0.01570886732224608, 0.06337616840028204, 0.032494731931365095, 0.025953885742637794, 0.05573631096922327, 0.05562123726122081, 0.028370151594572235, 0.025771343389351387, 0.03295342372439336, 0.010873281680687796, 0.04638982187316287, 0.04214216191030573, 0.03796438999415841, 0.050812072076951154, 0.0764799582248088, 0.008086506022664253, 0.013655653619935038, 0.035260605000075884, 0.01441186313968501, 0.0502147433871869, 0.014039308716746746, 0.051840139567502774, 0.08155490504577756, 0.0490940707095433, 0.01152489568994497, 0.027299050670990255, 0.05555201343668159, 0.06331531229079701, 0.03170861571561545, 0.06370836112182587, 0.027408311507315375, 0.0269939519057516, 0.024074545181065332, 0.020004935722681694, 0.052438039710978046, 0.04875546212133486, 0.037928065576124936, 0.018362711343797855, 0.02439857056742767, 0.005209422588450252, 0.02801139184157364, 0.07835972181055695, 0.01786395656381501, 0.11383818797185086, 0.0300814662114135, 0.04092094306543004, 0.047166145450319164, 0.0218594124817173, 0.03347281206515618, 0.025029793141584378, 0.023288588527066167, 0.009738731769175502, 0.028830203373217955, 0.02478229987900704, 0.07849390211049467, 0.058367502788314596, 0.06976074611884542, 0.026052580251416657, 0.03493983022053726, 0.017909452071762644, 0.04863459223997779, 0.05257181925117038, 0.04088218069227878, 0.06912257333169691, 0.020260063829482533, 0.028246097899682354, 0.049565601657377556, 0.06118472505477257, 0.06319262043689378, 0.022038062270439696, 0.09259841870516539, 0.024487390801368747, 0.018751494681055192, 0.13479272020049393, 0.00854466625241912, 0.029382056964095682, 0.03763479478948284, 0.07843761763069779, 0.023009782198641915, 0.009057174884219421, 0.05241953425866086, 0.035801871854346246, 0.05317416856996715, 0.05144907227077056, 0.11209260468604043, 0.03712144753080793, 0.06483978009782732, 0.09684469827334397, 0.03820860853011254, 0.03250253932492342, 0.07898620577179827, 0.044076644044253044, 0.03354962434968911, 0.03149635776935611, 0.029591748934763018, 0.10978595033520833, 0.015312786817958113, 0.048324979361495934, 0.015043095918372273, 0.015605057560605928, 0.026993933352059685, 0.06516854409710504, 0.03994140832219273, 0.05707885240553878, 0.08114338415907696, 0.0034707762961261324, 0.07317701514693908, 0.058772411139216274, 0.031664276102674194, 0.04972926377377007, 0.033970778313232586, 0.04527670796960592, 0.03578803822165355, 0.06660105238552205, 0.0846388477657456, 0.042738158444990404, 0.01781112492608372, 0.030393773085961584, 0.014078501535550458, 0.03850335247989278, 0.02465839461365249, 0.06415362004190683, 0.005094898997413111, 0.003045199596272141, 0.014240953023545444, 0.04002089233836159, 0.0261228393719648, 0.05256838681816589, 0.05094591098895762, 0.0007556325579116674, 0.018170840194215998, 0.018956871062982827, 0.03003519886988215, 0.01261412913663662, 0.024876498828234617, 0.05101110495161265, 0.07780089203151874, 0.028664001256402116, 0.05823413885082118, 0.03972471233282704, 0.033893535583047196, 0.04062027306645177, 0.029933828918728977, 0.024424629227723926, 0.024857182579580694, 0.031556542235193774, 0.025041348380909767, 0.034625285770744085, 0.02764798995485762, 0.024329196457983926, 0.031349301207228564, 0.01493353265686892, 0.06594686405151151, 0.026802049214893486, 0.050116149068344384, 0.06768875144189224, 0.007896339029684896, 0.07400108850561082, 0.044165731451357715, 0.045337612318689935, 0.01868934166850522, 0.028237477854418103, 0.13343602971872315, 0.20408237323863432, 0.18954597122501582, 0.0863937078975141, 0.1540939329424873, 0.20163796143606305, 0.07842085251468234, 0.10853670799406245, 0.09313032336649485, 0.10131040122359991, 0.13690395222511142, 0.12185760569991544, 0.17813778104027733, 0.1783053728286177, 0.12768448912538588, 0.305525396252051, 0.11033679460524581, 0.11058320989832282, 0.06701722653815523, 0.17401497258106247, 0.2373105808510445, 0.16424884350271896, 0.06973339055548422, 0.11800264575867914, 0.09740260036778636, 0.08046382921747863, 0.1677331971586682, 0.13167457189410925, 0.10385179688455537, 0.1500332125579007, 0.1036957158066798, 0.10168325621634722, 0.08096025921986438, 0.08678232610691339, 0.08744742401177064, 0.2723763609537855, 0.2529054635670036, 0.0903121214651037, 0.11541726300492883, 0.12731755647109821, 0.10945251822704449, 0.1503334558219649, 0.0985403721278999, 0.13508025789633393, 0.11940232885535806, 0.0831055038725026, 0.12408921407768503, 0.11228226794628426, 0.16741828905651346, 0.1550240963115357, 0.07990943006007001, 0.12494804221205413, 0.13488057564245537, 0.08767736362642609, 0.08635499005322345, 0.17379638040438294, 0.1393420557724312, 0.11929953398066573, 0.1401486515533179, 0.11229886236833408, 0.12538614682853222, 0.1005559710029047, 0.09452004684135318, 0.18110396718839183, 0.16654387582093477, 0.10588572680717334, 0.12635148799745366, 0.0702436690335162, 0.2929728588787839, 0.20966330892406404, 0.1499768390203826, 0.16582537296926603, 0.11419055968872271, 0.1290618855273351, 0.12372512384899892, 0.1579714467516169, 0.08745068946154788, 0.16562460717977956, 0.0933492420881521, 0.11820716681540944, 0.1634253712836653, 0.18051222315989435, 0.11062206132919528, 0.22130045166704804, 0.1803950231987983, 0.1544757976080291, 0.1441578965750523, 0.3205575083848089, 0.09472697987803258, 0.08940559549955651, 0.12627190008061007, 0.1555116576491855, 0.10329623997677118, 0.09086845020647161, 0.1631057431222871, 0.11919947763090022, 0.12356016668491066, 0.16434037999715656, 0.24538646859582514, 0.07498422637581825, 0.15891517658019438, 0.1466318903840147, 0.1898814961896278, 0.16737148922402412, 0.21995688235620037, 0.09520387655356899, 0.13188602461013943, 0.12457843782613054, 0.15171463717706501, 0.19862153189023957, 0.08799610863206908, 0.09426493357750587, 0.06117479882959742, 0.13737796194618568, 0.16344926843885332, 0.17489061778178439, 0.11367448503733613, 0.1904734777053818, 0.10224602679954842, 0.19834353821352124, 0.3070516377920285, 0.21801751689054072, 0.1448409099248238, 0.13335874245967716, 0.10965454566758126, 0.08282366587081924, 0.18081187270581722, 0.12463175371522084, 0.1989436091389507, 0.15112082997802645, 0.09290609086747281, 0.18352096405578777, 0.11179902590811253, 0.1537295532762073, 0.19218730449210852, 0.0880029883410316, 0.04481695119466167, 0.10393372998805717, 0.13874481985112652, 0.12323202608968131, 0.18611373117892072, 0.1435980648966506, 0.14142977655865252, 0.11755954648833722, 0.1800969915348105, 0.11561753897694871, 0.12009331287117675, 0.14619200461311266, 0.15132805245229974, 0.10364011410274543, 0.13109048682963476, 0.07532991876360029, 0.15901309554465115, 0.1639487931970507, 0.1395781774772331, 0.1220462225319352, 0.10324172180844471, 0.11792776305810548, 0.15471252787392586, 0.2443314017727971, 0.10606833966448903, 0.12604554503923282, 0.1315168061410077, 0.10516546506551094, 0.14746224973350763, 0.1286498599802144, 0.15150328836170956, 0.12180638266727328, 0.12034401777782477, 0.1930791581980884, 0.18571706808870658, 0.1154829801816959, 0.09460482237045653, 0.23965091386344284, 0.09519943851046264, 0.08091587878880091], [0.017956340961973183, 0.03155319885991048, 0.029815393281751312, 0.01530036697658943, 0.020291191358410288, 0.006991113214098732, 0.03596952301450074, 0.038634222801192664, 0.029763847414869815, 0.009521687898086384, 0.0663488706049975, 0.03301044293039013, 0.07385505610727705, 0.02328362170374021, 0.036197462541167624, 0.039431192926713265, 0.0504781130439369, 0.029384231456788257, 0.02623525433591567, 0.018584212739369832, 0.0520512508956017, 0.01814420822483953, 0.02959589568490628, 0.0925148677197285, 0.05373689091356937, 0.030012802708370145, 0.05874238384421915, 0.03198668360710144, 0.039082019866327755, 0.020191179537505377, 0.04380352998850867, 0.06739401491358876, 0.003405506263334246, 0.07914212357718498, 0.06868184893392026, 0.054970496203168295, 0.04540662463114131, 0.015694579124101438, 0.04060820945596788, 0.07586948981042951, 0.049981022530118935, 0.04368426314613316, 0.02508791072614258, 0.034580218853079714, 0.02616580415633507, 0.09240924526238814, 0.027812807966256514, 0.047484920141869225, 0.05484023815370165, 0.007888654090493219, 0.09606189574697055, 0.028681111471087206, 0.0516632115613902, 0.007826203291187994, 0.04157101619057357, 0.04093881027074531, 0.04184970377536956, 0.036076989708817564, 0.03493736257951241, 0.019600064479163848, 0.0333796762424754, 0.08600907502113841, 0.012790852124453522, 0.04531708451395389, 0.004942578752888949, 0.02984219965583179, 0.08273569168522954, 0.008289114193757996, 0.03240441255911719, 0.020772299722011667, 0.07493371580494568, 0.017434922847314738, 0.08089580369414762, 0.02197963112848811, 0.01906365683680633, 0.06473376430221833, 0.029210006723587867, 0.030592742878070567, 0.05781844709417783, 0.014616013122576987, 0.0826168515777681, 0.03407396281545516, 0.028456507898226846, 0.03945511605706997, 0.08873142855009064, 0.024619728719699197, 0.02050864619377535, 0.05693832674296573, 0.03905053425114602, 0.022107846416474786, 0.03128653406747617, 0.0385764057864435, 0.03192344891431276, 0.03166242073348258, 0.01762406845955411, 0.018935421139758546, 0.02052939664281439, 0.04301888322515879, 0.0077871505527582485, 0.06238309317268431, 0.018211422684544232, 0.03677428940136451, 0.0696955707098823, 0.04310588519729208, 0.029342656343942508, 0.04428843814821448, 0.032996186273521744, 0.07841282989829779, 0.0021765064639112097, 0.047808949238969944, 0.04938624311762396, 0.03908856931957416, 0.01364039320833399, 0.03457556929788552, 0.041724919065018184, 0.049073876871261746, 0.06110755282861646, 0.026974789652740583, 0.03934707048756536, 0.03561388213711325, 0.025734688715601806, 0.034709174433373846, 0.012501754063123371, 0.07672880034078844, 0.022184885056049097, 0.014715294855704997, 0.03014214049471775, 0.10434137686388567, 0.04085203465365339, 0.02281785538798431, 0.02743421988270711, 0.009651816071709618, 0.1145865028956905, 0.03035434834600892, 0.03294151967565995, 0.029001697002968285, 0.0330187920917524, 0.028283639439905528, 0.057446308273938484, 0.03617250782554038, 0.004227756953696371, 0.034170111757703125, 0.022845864041300956, 0.012475770545279374, 0.020978310640202835, 0.03918956448615063, 0.04665607106289826, 0.0462772083847085, 0.06971903741941787, 0.007121452435967512, 0.021141688885109033, 0.03794791431573685, 0.012252165161044104, 0.02156487633328652, 0.009743694881763076, 0.032676439368515275, 0.052430017094593495, 0.026464123402547557, 0.05574738381255884, 0.028053662717866246, 0.0076825902942800894, 0.05558638600632548, 0.006563594870385714, 0.02231729533377802, 0.14908246201230213, 0.08918914070818573, 0.012731484021060169, 0.060563053921214305, 0.027896054671145976, 0.03781163373787422, 0.04522214527241886, 0.014823195706412662, 0.04118235345231369, 0.038900587023817934, 0.047855919765424915, 0.06007496936945245, 0.01584214962349506, 0.04466010941541754, 0.06630527685047127, 0.04724777798401192, 0.008520577066519763, 0.036948360138922, 0.04249305675330106, 0.06051978300092742, 0.006336520873446716, 0.024871160931070335, 0.09783634115592577, 0.04934857912303414, 0.012029970785079058, 0.00609392764090444, 0.0070220236648310674, 0.05247435670753475, 0.010694661577872466, 0.10158751174458303, 0.007249878772199736, 0.004976160935257212, 0.03406450785405468, 0.028149681784270797, 0.049483802140457556, 0.06296136722085066, 0.07995215550181456, 0.05750016222009435, 0.020957103770342655, 0.04886984192125965, 0.06620019616093487, 0.021474185887200292, 0.045695769076701254, 0.043217044076300226, 0.03634063767094631, 0.0463678394589806, 0.05065999488579109, 0.045773976598866284, 0.05215017547016032, 0.0559135803632671, 0.025192319772031624, 0.026571180060273036, 0.07354840068728663, 0.05018706498958636, 0.04537193293799646, 0.03700330875290092, 0.013535876551031834, 0.0658181459584739, 0.03071718805585988, 0.09458272121264599, 0.01898041013191687, 0.01162092588856467, 0.05036151051172055, 0.011571313316380838, 0.048110958814504556, 0.069224804174155, 0.03080657603277359, 0.05777538026450202, 0.03620819770731032, 0.05740385371609591, 0.09558646110235713, 0.026904712358373217, 0.025667695044830907, 0.013871982246200787, 0.03973708764533512, 0.033892466890392825, 0.010583088023849996, 0.03250317386118695, 0.05613842513412237, 0.014539394724124577, 0.058644424061640166, 0.04950949158228468, 0.04170774576778058, 0.024441012137685902, 0.0023692702779953834, 0.0755353452404961, 0.03865530350594781, 0.02567738192738034, 0.036442323034862056, 0.0322986416722415, 0.05425562245363835, 0.033889197729877196, 0.06613024132093415, 0.06340989901218563, 0.018373971579421777, 0.06189159845234826, 0.04025596390420105, 0.022582232777494937, 0.02176788155338727, 0.02006580853048945, 0.015419428800669266, 0.007276638762050425, 0.04447719969903119, 0.007800376552040689, 0.02184734144975664, 0.023986331652849913, 0.03344665878103115, 0.005903907685933518, 0.03241650956624653, 0.05959966831142083, 0.020670256271841936, 0.060327652099658735, 0.04033112491015345, 0.08242126597906463, 0.032577436868450604, 0.022611712738580536, 0.03367319564858917, 0.07453221391187981, 0.018365865471423604, 0.040188740167650394, 0.045073496803524904, 0.04852003061387222, 0.0500108197593363, 0.030906832762411796, 0.04463879122340586, 0.030892256982042454, 0.05107908196805511, 0.04430320317624137, 0.018213112925877795, 0.025306527022621594, 0.05426724819699302, 0.05192883363633882, 0.044319931184872985, 0.036365343767101876, 0.04284064532839693, 0.07386270022834651, 0.037032196851214394, 0.023826946162444074, 0.05598340532742441, 0.020177115839032922, 0.01145967296906747, 0.08922182489186525, 0.04259625238773879, 0.011271568218944594, 0.07097608715412207, 0.05333855799108278, 0.009327444658993045, 0.061843069415772334, 0.03218238794943318, 0.026207811570202466, 0.03188775161106605, 0.029432417250063736, 0.022740673884982243, 0.05189958930714056, 0.07430500540067442, 0.05217867023020517, 0.027741691665141843, 0.043318740572431125, 0.010429328940517735, 0.014330496851471253, 0.024521358900528867, 0.01452251828595763, 0.05616185844701249, 0.02508991638023872, 0.021333567456167657, 0.025651017131167464, 0.033144029512186535, 0.015968815678206738, 0.03512511852022726, 0.03152601027977653, 0.01754638971760869, 0.022766355905332603, 0.07217345337267034, 0.013734837993979454, 0.05331430089427158, 0.03238287172280252, 0.004325982054069755, 0.035154247816535644, 0.037893121552770026, 0.06694652955047786, 0.04033274279208854, 0.08480503689497709, 0.02258541473565856, 0.015337228524003876, 0.027093462776974775, 0.017253881487704348, 0.02380523092142539, 0.010204136287939036, 0.07653463224414736, 0.12625635950826108, 0.16500270226970315, 0.12686426751315594, 0.09872066206298769, 0.17231307952897623, 0.18244801147375256, 0.10458641918376088, 0.125688913394697, 0.09036103641847149, 0.18563408113550395, 0.07919769559521228, 0.1199525645643007, 0.22416781343054026, 0.21063103980850428, 0.13087063300190493, 0.11681265648803674, 0.2227321732789278, 0.08292580765555613, 0.12037821594276465, 0.155565507884603, 0.17664443148532882, 0.09636395727284253, 0.1540413443581201, 0.1924746937584132, 0.09615522823878564, 0.24360475013963878, 0.1188183476915583, 0.12673124496359378, 0.101587162935175, 0.21224023861577734, 0.15986331476597115, 0.12485515500884503, 0.2736223675310612, 0.13388522202149034, 0.17026521207299083, 0.17295206867856905, 0.1050838065566495, 0.10652611119439825, 0.10248520615277812, 0.17092983500333503, 0.14874819869874045, 0.13958225928945467, 0.09432803839445114, 0.1427775909542106, 0.1620707439724356, 0.12337187639786862, 0.12374470170470886, 0.10854677151655778, 0.07794938836013898, 0.15207465301500633, 0.1335589590598829, 0.19348389585502446, 0.1296656671911478, 0.11772077064961195, 0.15947527543175966, 0.15324053732911125, 0.1660309627186507, 0.20235192234395072, 0.0797969575796742, 0.181824458995834, 0.13228773430455476, 0.10732921888120472, 0.20846957922913134, 0.0837660078832414, 0.19318237609695643, 0.2050551655702293, 0.11716912486008368, 0.1350182737223804, 0.0718997567309998, 0.13825169240590185, 0.16888232377823442, 0.1091434434056282, 0.12858070665970445, 0.0866394404147286, 0.11657332128379494, 0.08558416579035111, 0.24128595425281674, 0.2933023130754009, 0.10865329197258689, 0.21514374297112226, 0.17439017276046798, 0.12206062761833891, 0.17376626405166462, 0.1582945926929824, 0.07785016321577132, 0.16963046800810844, 0.1489192043663934, 0.09135769621934742, 0.06077759026084095, 0.10394066164735705, 0.09213137775077485, 0.10157102122320794, 0.19897859398042783, 0.1461196897435002, 0.06302961512119509, 0.08896895291400142, 0.0930427796265576, 0.1294117933139205, 0.17020625586155802, 0.116419889673125, 0.2076708502136171, 0.15439282549778, 0.2631813590414822, 0.18710020871367306, 0.14922119909897447, 0.14345696778036654, 0.11397593058063649, 0.14516402618028224, 0.16666680516209453, 0.1826567924581468, 0.09690971783129498, 0.1132999750552699, 0.10345166054321453, 0.17560168431373313, 0.1633770574699156, 0.1589306429377757, 0.13094731169985607, 0.16622865601675585, 0.15933505404973403, 0.13663940626429394, 0.12584234500536695, 0.11848167981952429, 0.22673919185763225, 0.10195777664193884, 0.10618335028993897, 0.15917642740532756, 0.15873786265728995, 0.10296956141246483, 0.17088851222069934, 0.1609980288776569, 0.0675316016713623, 0.17549186130054295, 0.13772499019978568, 0.10882182628847659, 0.13101178949000314, 0.15898912417469546, 0.15742497373139486, 0.18325857032323256, 0.14485441701253876, 0.1080602640286088, 0.1857695379294455, 0.1718923114822246, 0.17662221158389002, 0.18838701857021078, 0.17852475168183446, 0.15767212375067174, 0.12592050799867138, 0.15986325539415702, 0.11917405907297507, 0.11086942657129839, 0.09265692220651545, 0.15245498885633424, 0.15915155061520636, 0.07521458159317262, 0.24396421678829938, 0.09794584504561499, 0.14890838385326788, 0.20200001075863838, 0.12859327864134684, 0.10453791241161525, 0.10281505368766375, 0.18027285084826872, 0.13519772503059357, 0.22212671436136588, 0.19660584395751357, 0.1678727357648313, 0.13666377839399502, 0.08945288514951244, 0.18710244999965653, 0.10399958075140603, 0.1345997618045658, 0.15238455904182047, 0.15595127624692395, 0.08824647215078585, 0.14756135613424703], [0.026481036948098335, 0.0736649772443343, 0.055165595695143566, 0.014972225453675492, 0.057107098546111956, 0.009710721260489663, 0.07122506285668351, 0.10022558170021512, 0.043806198009406216, 0.0300429561684723, 0.0066603918003238505, 0.019926900749851484, 0.02789031044812873, 0.00935406364078517, 0.05422825946880039, 0.028558619997056667, 0.04146156054048333, 0.03062251413211925, 0.01431633760148543, 0.028792658122256398, 0.06065097244572826, 0.07440191504429094, 0.047758609362063, 0.022977880980761256, 0.044502384480438195, 0.03198243481165264, 0.024695040010556113, 0.012446515083865961, 0.02340993709367467, 0.04033111748867668, 0.06661933890427463, 0.05055394198279828, 0.03848620144708548, 0.02515673008019803, 0.018751511379377916, 0.007400733275062521, 0.03609689782024361, 0.02594383891846519, 0.044279602880124, 0.04859049011429306, 0.01964823171874741, 0.03407316129596438, 0.0363606237078784, 0.034756679306156, 0.06461836775997654, 0.06684035790385678, 0.030249386400100775, 0.011842862368212081, 0.036910176640958525, 0.03338499373057857, 0.007483808358301758, 0.01654757583310129, 0.03211093026038725, 0.0304267021783744, 0.05090318925795145, 0.015524014106631512, 0.0524150108685717, 0.0279970368501381, 0.017274117999477312, 0.004149372243773541, 0.08259453519713134, 0.03217072880943306, 0.028694282736978494, 0.06823851959779859, 0.057261205511167645, 0.03599615869461559, 0.07770758922561072, 0.00168654103163135, 0.04820121881493833, 0.02105711002513999, 0.023423457168973982, 0.03643686453870032, 0.06438137032091618, 0.08797929156571627, 0.06889391763252206, 0.04258700522768777, 0.028688798265648074, 0.031938009851728566, 0.054645179479848593, 0.03247054904932156, 0.07444147893693298, 0.042657498124754056, 0.028918580173922237, 0.012285564589546993, 0.009090944458876038, 0.05056577181676403, 0.017104232974816114, 0.059545131589402445, 0.06352571115712635, 0.04648038615414407, 0.03946102726331446, 0.017915693533723243, 0.06335935133392923, 0.008699634108779719, 0.012868577250628732, 0.025640871972427703, 0.06701239515678026, 0.05392249833676033, 0.016964744463621173, 0.018091645615641028, 0.026888563224929385, 0.04850388519116677, 0.04252965947671328, 0.011747924982046243, 0.06552646707859822, 0.10033156780991703, 0.05019339922000654, 0.04307988776417915, 0.04484156823309604, 0.043982773495372385, 0.020052225372637622, 0.025415479867660906, 0.03490354290988762, 0.056078856650856324, 0.00169471880326455, 0.011101032887381734, 0.01750888528476935, 0.010366069200244965, 0.05649412538332399, 0.03496706332953181, 0.004132075100642396, 0.039503455845988356, 0.01278347146580927, 0.016389468692068476, 0.04192266802419908, 0.09047577987075783, 0.054490501061081886, 0.09219953659339808, 0.039531709408038296, 0.0269199430840672, 0.010409107271698304, 0.009435256451979512, 0.05085435223008972, 0.03525806314428337, 0.0449093003408052, 0.014143905154924141, 0.028577817502082326, 0.026424923162267078, 0.016680815460858867, 0.014742623516212916, 0.0711174143361859, 0.003934131791538675, 0.03168808048940264, 0.04685990934376605, 0.02896845620853128, 0.04871585369983222, 0.031137358673731796, 0.020192049705656245, 0.027300726069370285, 0.02551071040215902, 0.009222266562574077, 0.02927661447756691, 0.023154057562351227, 0.0227798128980794, 0.04919610859360546, 0.05089809812488966, 0.025246782279282343, 0.06663497595582157, 0.03976848420279566, 0.028490347976912744, 0.10627724681398831, 0.02223608211352257, 0.017297141275776085, 0.08960403836681508, 0.031424217304447666, 0.03780610844842158, 0.05043562508944888, 0.031638790751458146, 0.016141622909344733, 0.054165381006896496, 0.021512452876777388, 0.04881139779172372, 0.012215421429573325, 0.005893973575439304, 0.05987980308418628, 0.01506174052337883, 0.03139173721137922, 0.038341890831361525, 0.04092682087502908, 0.026927397957479116, 0.01898274233099073, 0.04301574022974819, 0.009167552652797895, 0.010784921578306239, 0.02906117086240556, 0.029009352256252896, 0.057066198787651956, 0.021874392732570414, 0.0906951587239746, 0.046474697592202574, 0.11979873961536214, 0.044831382256234065, 0.08519423397956416, 0.041191411364707164, 0.027328575160936452, 0.06801318129873835, 0.059991032467223704, 0.035615848828456365, 0.04115543204534333, 0.0388627931533847, 0.04250423349731136, 0.0077544904888782185, 0.05269623659842182, 0.01612746829778189, 0.03114611972705461, 0.01984113816433819, 0.01029492043016944, 0.048295107917510904, 0.06629080497077666, 0.021337834805308376, 0.06548671022756025, 0.10000883747125044, 0.029779718242934905, 0.02062345087324502, 0.08312597230542451, 0.02766762161627412, 0.08624734153272584, 0.04044672183226794, 0.05624748744594399, 0.02733188885031268, 0.051827882998622954, 0.04334087141614873, 0.054046088189352304, 0.03839319550024811, 0.09987183701014146, 0.025705186490085907, 0.024082673553493805, 0.007906977716629626, 0.0371268986054929, 0.047075432739802636, 0.059053532968391664, 0.01767589448718354, 0.04674182622693479, 0.0353517407347681, 0.013925749917689245, 0.03964306124544237, 0.02308537921635434, 0.06421993835829198, 0.04330894793383777, 0.05209670744079631, 0.04700612727901898, 0.04790776249137707, 0.03481289328192361, 0.0054108776475914055, 0.03578725896659307, 0.026042859972221777, 0.01458671869841055, 0.00928515151827014, 0.030667697938042693, 0.04730580280011054, 0.05179209663765505, 0.010921481389232213, 0.038901963707758114, 0.014658622603747062, 0.011679281888063997, 0.030873875839461107, 0.057593598612584174, 0.045735856183455326, 0.03899911454936955, 0.029289793164934963, 0.02713098205276765, 0.02523378727346426, 0.04027566421427764, 0.06979613172006793, 0.015663199264963623, 0.05235565760813188, 0.043488076407811604, 0.08403154090046883, 0.013420593186310725, 0.04116075695492327, 0.03124751936411485, 0.03957289118261542, 0.030178097549651284, 0.03134600607154425, 0.06200878728122916, 0.05464572495839093, 0.05539315672649536, 0.03351824634592049, 0.012470593137550168, 0.06444705781177618, 0.024091347404464614, 0.025399976402695756, 0.03968033561250195, 0.04627962778613437, 0.012553437227325048, 0.02915128799941158, 0.013385439506237162, 0.06065736604796257, 0.0895249996392522, 0.03626697951403912, 0.04512156199780293, 0.008895905266399495, 0.044379273313097656, 0.02293766214279458, 0.05109422549139708, 0.021298428619047627, 0.0056602703443786595, 0.05963490177236963, 0.03141328546917066, 0.056866991508286446, 0.02549692871980369, 0.08109263610094786, 0.04918593003822025, 0.026883614955295343, 0.020447658353077713, 0.06537875742651522, 0.07945906516397372, 0.033515867762616836, 0.01585960122611141, 0.018896107721957378, 0.033054196246666834, 0.017736023291945457, 0.06084057633415796, 0.029499685515474994, 0.042977222765330225, 0.04506121054873802, 0.04566590505419299, 0.04749971856654156, 0.08903020978323184, 0.032112128828885034, 0.015176923698163591, 0.03475005934888031, 0.056942293522297405, 0.01693382659141207, 0.03281525438069366, 0.03891958971507847, 0.02984876395203173, 0.024246179818874225, 0.03344417629705276, 0.036864675566903315, 0.02225769159849733, 0.019368712928553578, 0.027363370754756033, 0.029855100037821103, 0.05196641599468421, 0.06539501046063378, 0.008281737245852128, 0.0558530062698992, 0.04121416561247315, 0.09238568949513137, 0.027025448653148487, 0.023732006920909043, 0.027648674586089328, 0.040044444394879974, 0.0528468257834902, 0.033862803247757256, 0.027859867550432682, 0.08121638180455193, 0.05664261057972908, 0.0374051631661132, 0.07305316554266028, 0.006352028512992547, 0.14797771582379937, 0.20742767810588703, 0.1833727868506685, 0.1288852543802932, 0.1731659853248857, 0.11220348154893145, 0.19959634286351502, 0.21012575598433614, 0.10967686204821803, 0.11484772403491661, 0.11506511393235996, 0.08321773886564188, 0.10841322204214521, 0.16687698138412088, 0.17895835888339207, 0.18236080912174657, 0.19288907933514565, 0.19819035893306136, 0.1392913077143021, 0.16777346609160304, 0.23241841758135706, 0.1943031229893677, 0.21099423203850165, 0.1775720715522766, 0.16827831947011873, 0.1036362029844895, 0.12858581263571978, 0.0945313720148988, 0.1650425704428926, 0.0989607913652435, 0.18939984234748408, 0.1392076231422834, 0.1729128832812421, 0.09183759117149748, 0.22974503837758675, 0.09721773138153367, 0.16668124735588208, 0.09964721859432757, 0.12612640945008025, 0.14250531181460246, 0.1432364757056348, 0.1761295145843178, 0.12818772462196648, 0.14846818638034165, 0.15804435533937067, 0.17329290742054582, 0.07903967751190066, 0.0803784970776178, 0.18241437734104693, 0.08124154803226702, 0.11726544820703566, 0.0834935209422838, 0.15184575982857496, 0.14710897259647027, 0.1787936911568977, 0.06150976347271353, 0.1894958910997957, 0.10930270087555982, 0.1409805248840712, 0.12777032592566684, 0.18059155874652788, 0.2006787949358113, 0.15317945857532322, 0.14249962696339935, 0.2060896303737536, 0.1438566588331014, 0.1848303500446491, 0.09690346894785762, 0.0943096331320703, 0.11583121813600883, 0.10375533252954483, 0.0557145697530359, 0.103418182261521, 0.17480767535744235, 0.1272639140370302, 0.08013612648937851, 0.14058794360607862, 0.3068843873916194, 0.13933645997894928, 0.08102590218186378, 0.16005668876459822, 0.17163610726129264, 0.1523339594132267, 0.10689330360037275, 0.11410438892198727, 0.20364953787066042, 0.09073614011867903, 0.20532423863187432, 0.12280566224944778, 0.1593885777401738, 0.13668767554918304, 0.14217300777090713, 0.1937002022168599, 0.08940568455727771, 0.10497205395950004, 0.13165315351216123, 0.1385153626324609, 0.11222895947867073, 0.11625609768088907, 0.15917427517706528, 0.18211735499789938, 0.12403619504766539, 0.0935200102685485, 0.144855648977682, 0.21082192019093782, 0.1590283095720224, 0.14864349650451913, 0.13509180571418256, 0.10363981724367477, 0.07954885018989444, 0.1321696734521538, 0.1805764634627849, 0.12598218047060072, 0.24347821396077052, 0.09006726468214765, 0.18759698752546683, 0.19570247211959213, 0.15061956859426573, 0.1355549503932707, 0.13342084537725896, 0.08483155383146368, 0.16259284486295655, 0.11104530072771013, 0.12717821082333103, 0.11375957226846367, 0.17676825140370056, 0.16298533708322793, 0.22048389626434073, 0.13010249531362206, 0.1919547450961545, 0.11837179001304321, 0.08531908548320644, 0.14648297103121877, 0.08632433193270117, 0.10681871775886975, 0.13362943340325728, 0.15758403082145378, 0.08477439361740835, 0.18149510869989172, 0.06926511763595045, 0.13926610437920317, 0.2300535491667688, 0.11082227050792426, 0.15143560449359939, 0.11459293731604703, 0.14186474931193516, 0.18587042548460886, 0.09367793929413892, 0.10131276867468841, 0.09973291438654996, 0.08112642608466558, 0.13088203239021823, 0.13265457790112123, 0.08041123321163468, 0.13130536826793104, 0.16189869929803535, 0.08593077844125219, 0.16585424251388758, 0.1523446018109098, 0.12190483597805724, 0.16322769282851368, 0.16494646231876686, 0.12919167231302708, 0.13967709091957659, 0.17062721686670557, 0.12672308133915067, 0.19232138089137152, 0.10612587095238268, 0.1746100711170584, 0.2380296477349475, 0.11987164078163914, 0.1489350269548595, 0.07985468924744055, 0.30621140787843615, 0.21044148044893518, 0.19266563351266086], [0.04240265203407034, 0.05528379013412632, 0.053437783135450445, 0.02694788679946214, 0.06539606431033462, 0.036545303446473554, 0.061933707911521196, 0.056338760477956384, 0.029131452247384004, 0.05613740468106698, 0.02015420759562403, 0.016963968919299077, 0.03649874481197912, 0.019162536882504355, 0.05060298310127109, 0.0055291880471486365, 0.015821840752323624, 0.047050196008058265, 0.022044179422664456, 0.01086390371710877, 0.06074087992601562, 0.02106789714162005, 0.07179754815297201, 0.021406869382190052, 0.021750114538008347, 0.051706296944757923, 0.058739441228681244, 0.010722039405663963, 0.011132519430248067, 0.05237237819528673, 0.01027181273457245, 0.023983272149052937, 0.05239001904556062, 0.024077589841908775, 0.005825817979712156, 0.08814360306132585, 0.010566241271590116, 0.052187420151312836, 0.05931179293838795, 0.045025873187114485, 0.028273412644921336, 0.03669124678708613, 0.015261990520230029, 0.020530689835140947, 0.0673181377351284, 0.029847192454326432, 0.06554759602295235, 0.0357712508412078, 0.03261129735619761, 0.016156306301127188, 0.09963219752535224, 0.03397490094357636, 0.06435837858589366, 0.02417158284515608, 0.05581857061770279, 0.045620181335834786, 0.03317965631140396, 0.025213023836840875, 0.024258974444819614, 0.04283727968868334, 0.004252866128808819, 0.08926057242206298, 0.02174103992729215, 0.059252981445752084, 0.01080297895896365, 0.030562138563254848, 0.06337552273180336, 0.03235252159356605, 0.042907805982395075, 0.05565136845689267, 0.03171837124682497, 0.04288494412321597, 0.033353830949636176, 0.07851458576624282, 0.014334606494230684, 0.05137800420925487, 0.009762693862285232, 0.030098422430455685, 0.05030981250456534, 0.026487007526156958, 0.07014750895905308, 0.04992026661057025, 0.006913697470736224, 0.012901196496386547, 0.07372054184088483, 0.06604864218388684, 0.0787445402238518, 0.037288657113094814, 0.0431033581844531, 0.015672385197831318, 0.03473530545306858, 0.0419710449205013, 0.03446692629950121, 0.04470066778594628, 0.022301255667116493, 0.015396725575556047, 0.03946779565012548, 0.0322900327591924, 0.05393063598603476, 0.05356245281291194, 0.04011540855572093, 0.015216842894005822, 0.060955145381740294, 0.014914802704879548, 0.06340536448988132, 0.0436400125909131, 0.06800556686357595, 0.023680572376179043, 0.034267448136233725, 0.03934671425668057, 0.0823824961844366, 0.010193782400165219, 0.05679702553607058, 0.07027886909781955, 0.04133365880989004, 0.01445467763915076, 0.02140871547453571, 0.04235937740304507, 0.052573396314983256, 0.045818401558790356, 0.03745317641005386, 0.0452694980049273, 0.05225790562690236, 0.015152358610066585, 0.059868425960303284, 0.028403169744706247, 0.04717826843261719, 0.03981726185884327, 0.023280115055968054, 0.06701163074467331, 0.03364694588526618, 0.07998542598215863, 0.07801796280546114, 0.06259753674385138, 0.01915308748721145, 0.0305004011534038, 0.032196466490859166, 0.04047907947096974, 0.03000558903295314, 0.031518685282208025, 0.017470711063651834, 0.009405442524439422, 0.04463710283744149, 0.04478732094867155, 0.036909282353008166, 0.022080620728957, 0.024929250685090665, 0.07196169637609273, 0.06008501433825586, 0.05573065580392722, 0.038794908905401826, 0.10895053696003743, 0.07648766913916916, 0.029289429512573406, 0.0625531563127879, 0.02156050508347107, 0.031413014585268684, 0.03687412310682703, 0.011070087184634758, 0.05641846713842824, 0.023030486263451166, 0.06859779328806326, 0.016965610921033658, 0.06122541330114473, 0.022095959066064097, 0.021976562347845174, 0.01371252532408107, 0.0766893032414373, 0.07202500899438746, 0.07019932570983656, 0.09034248272655532, 0.019050392802455463, 0.07147405340219848, 0.057092994029517286, 0.030595503667427693, 0.02012109853239963, 0.07374573775450699, 0.0505351470928872, 0.01891575793706579, 0.0482214757357724, 0.03783984648180194, 0.05464844864036422, 0.03348835263750516, 0.03807510729529895, 0.10547527461312711, 0.06863493777927943, 0.052883079697494395, 0.033070675635826774, 0.052289368977653794, 0.03499091224512085, 0.05884897109353915, 0.05619130686682183, 0.05211672316363547, 0.07737247986369766, 0.03560381861461792, 0.047854921576799825, 0.03907758553395979, 0.012780880442733178, 0.0381202447169926, 0.05677346976881381, 0.05713196791475639, 0.027499530733621214, 0.025737174910318572, 0.04286510651581921, 0.014078095209697494, 0.04905341214907821, 0.02077374876535032, 0.05244290077826008, 0.0842072963132523, 0.04440339682332706, 0.007581570544061833, 0.030696194553456735, 0.04086485525476746, 0.035942416070611216, 0.04721717552456539, 0.026250290247844532, 0.029405104360193945, 0.0075040759475086816, 0.0037798045013914816, 0.016554511203139555, 0.06526565412059426, 0.05112930310133379, 0.05711723257263657, 0.035141004191245884, 0.060312675559544004, 0.05929928032855969, 0.034850854135584086, 0.029550602412200533, 0.039776187695679255, 0.021432794455904514, 0.024612919514765963, 0.07184399917605333, 0.07181112945545465, 0.04081335020600818, 0.07709614859777503, 0.06600026899832301, 0.020944201532984152, 0.08778286734013818, 0.025311477147624828, 0.05909031751798466, 0.03708807686052751, 0.07156236155424267, 0.06619296764256433, 0.03252154572692234, 0.11129726728540845, 0.06873080099467188, 0.07757021026918665, 0.06263764982577413, 0.01290880907617975, 0.025634914381953422, 0.0371206794079626, 0.040993180009536445, 0.06890195509186015, 0.04930226910801139, 0.020257920878066216, 0.02307482216565404, 0.05595324815658387, 0.037656569402315654, 0.04928656526317354, 0.012364087524474598, 0.02691431946004741, 0.11080534954089671, 0.01264192256712704, 0.01009068046187167, 0.00905150487596984, 0.06285414914600551, 0.01303146196732996, 0.03914239729056135, 0.04229463986121118, 0.06602469307836145, 0.0037590394413200556, 0.030411341576837003, 0.018508649118302856, 0.018187226814916357, 0.02529202731238911, 0.02927277015260188, 0.041704654722707346, 0.010764277812995715, 0.03736956605280284, 0.03454188692558091, 0.037545829836744815, 0.06269805322517641, 0.03483204811345786, 0.018741425592452288, 0.028369704450597055, 0.026844060339499265, 0.036275566162657924, 0.042008497403003275, 0.1301862095715478, 0.05760928019299172, 0.029192586662247777, 0.03605924495786894, 0.006465444912464591, 0.05928809245233424, 0.03973413760832045, 0.00033573004088793823, 0.08075607212958857, 0.05293020607496146, 0.033237981697311625, 0.03025810292456299, 0.056805489730322734, 0.016840226926433388, 0.02832930564181879, 0.06327343289740384, 0.06443498306907713, 0.08760420270846225, 0.011438141409598757, 0.06772493114112876, 0.07254967771586962, 0.04999283752113115, 0.02407469361060066, 0.03436416111071594, 0.0364872860518517, 0.045474828002625145, 0.040089348040055484, 0.04783531403518282, 0.02108288295858074, 0.09041687560966238, 0.0678267092735041, 0.008300533991132397, 0.024206029629567638, 0.030400461691897362, 0.03056816480238922, 0.041478225466562435, 0.05083567237306852, 0.031366481925942935, 0.006756769416824682, 0.07030139327980578, 0.01339522008493077, 0.06917098362464458, 0.005102234663354466, 0.05671916682331357, 0.06507105557830073, 0.03452060955169145, 0.04227816789352801, 0.05624934652587399, 0.06223607742867898, 0.017145015845017042, 0.045769297357765026, 0.014623887309426209, 0.0022548554579771007, 0.032039157158578746, 0.036079182755202055, 0.01191680532429018, 0.07449750366504304, 0.07410936785163358, 0.04703094469732605, 0.06121277452621143, 0.09463779599172994, 0.01550496317577199, 0.03024879639269784, 0.013618849588965531, 0.1631475705653429, 0.16674873826559633, 0.1992686846642755, 0.18402629240881652, 0.1051262128748931, 0.22803965723142028, 0.13404215656919405, 0.2054654693347402, 0.15682325523812324, 0.13168920704629272, 0.13120269955834374, 0.17737866786774248, 0.11052268775529228, 0.16569747123867273, 0.16413884237408638, 0.11201896137208678, 0.14996233745478094, 0.18719060230068862, 0.14449147711275145, 0.1278394940891303, 0.13713562104385346, 0.1433459870168008, 0.18764111562632024, 0.1552686933428049, 0.08339200256159529, 0.13888052897527814, 0.2309054901706986, 0.1601890433812514, 0.09642419739975594, 0.1378950904472731, 0.12120070852688514, 0.09743401547893882, 0.17700490745482966, 0.13847301568603143, 0.1730508782202378, 0.1570274497498758, 0.10867359713301994, 0.24491055897669867, 0.1776960992719978, 0.1784934924216941, 0.1428536610910669, 0.14287702389992774, 0.1031106362643186, 0.06969240173930302, 0.18778242054395378, 0.16659854241879657, 0.22129585035145283, 0.06984483887208626, 0.18586511170724407, 0.15631886199116707, 0.11990134153165855, 0.1387918126420118, 0.1715171113028191, 0.13455254636937752, 0.1385644482797943, 0.17469549231464043, 0.13589261274319142, 0.07500407882616855, 0.18046984652755782, 0.2893094695173204, 0.11998423200566322, 0.18634287669556215, 0.1576765172649175, 0.2781143499305472, 0.1535779473488219, 0.11013720883056521, 0.15537073864834383, 0.09169221928459592, 0.1758999831508845, 0.12226881488459185, 0.17169096681755036, 0.12723964580800384, 0.08602914269431494, 0.18061066162772477, 0.10896270076045766, 0.14332024933537468, 0.10296719396137632, 0.1095640184939839, 0.1315316342515871, 0.1219096896238625, 0.18815114919561893, 0.15305491135222837, 0.1367748185293749, 0.07219343198812567, 0.15753832936752588, 0.1476895992527716, 0.12962493812665343, 0.1366899613640271, 0.12636359984753653, 0.2174417141941376, 0.11143582625663839, 0.10530268817092292, 0.11727451725164428, 0.16865543439053, 0.1412470152718015, 0.14330634148791432, 0.09802805274375714, 0.09543284395476803, 0.09974480359232984, 0.10642817738698795, 0.12850613566115499, 0.1872264628764242, 0.12375928490655497, 0.09704320793389343, 0.1218774655717425, 0.14639968721894547, 0.18210605951026082, 0.08546455384930596, 0.14832089975243434, 0.15671006287448108, 0.22859185963170603, 0.0836742264800705, 0.31568165752105415, 0.16127885755850002, 0.0897332611202728, 0.07217637743451633, 0.07580597681226209, 0.12126101544708945, 0.1416076099849306, 0.08687904279213399, 0.16456658660899848, 0.11107140948297456, 0.14137294288957492, 0.08281816655653529, 0.15926785999909043, 0.13230964250396937, 0.0749339755566325, 0.14268954255385324, 0.10041684057796374, 0.17247538722585887, 0.14102765126153827, 0.18454174365615472, 0.18641375179868191, 0.1785208479850553, 0.1247693330515176, 0.13676245434908196, 0.08779884577961639, 0.11920298798941076, 0.17039018974173814, 0.12278897876967676, 0.13977233815239742, 0.11621354293311015, 0.13284557702718303, 0.13875077187549323, 0.08258822694187984, 0.09330604909337126, 0.10046936236904003, 0.18145938171073794, 0.15195445477729663, 0.1563552865991369, 0.0990364162134938, 0.20938009052770212, 0.15642237674910575, 0.1534234915743582, 0.19563018693588674, 0.10256741385092027, 0.14179023768519983, 0.08994523333967663, 0.14470358291873708, 0.2100120292743668, 0.11454362902441062, 0.09172004982247017, 0.08870918638422154, 0.23358681035460904, 0.08860430607455783, 0.11012698945705779, 0.08702805120265111, 0.1269213980413042, 0.19069545407546684, 0.2045494513004087, 0.15939292672555894, 0.1833764382172376, 0.3050693910336122, 0.09375701512908563, 0.090891159925377, 0.0770613641361706], [0.04156892333412543, 0.013714494798477972, 0.0018479531649973069, 0.07285488594789058, 0.045271661365404725, 0.011226732294744579, 0.05939162947470322, 0.03956332860980183, 0.024339445517398417, 0.06383043699315749, 0.040286458752234466, 0.011545819616003428, 0.05524607789993752, 0.023682112332608085, 0.02327639318536967, 0.03631863299233373, 0.048416716235806234, 0.054347570840036497, 0.05860245189978741, 0.03952584644139279, 0.02735484162258217, 0.034962959252879955, 0.03494361888442654, 0.02182207132136682, 0.029088418814353645, 0.005718090142181609, 0.17164188117021695, 0.06415839947294444, 0.030614556453656405, 0.07517436461057514, 0.015014138243714115, 0.05145700211869553, 0.04288869567972142, 0.03433305770158768, 0.04219476904836483, 0.03362723444297444, 0.04447304738278035, 0.055499090885859914, 0.01226543197844876, 0.02529188073822297, 0.024152446567313746, 0.07411543861962855, 0.014505776362057077, 0.029614987433888018, 0.06906398077262565, 0.04111576796276495, 0.04152461711782962, 0.014869745064061135, 0.06638102044234984, 0.05709041506634094, 0.04151513989199884, 0.08752498586545698, 0.07154277627705596, 0.06544875679537654, 0.03704788214236032, 0.009973249507311266, 0.019679689503391273, 0.053865657246205956, 0.025690141301311087, 0.05194250770728104, 0.004339227534728707, 0.04091758113645483, 0.04077707773831207, 0.010081215295940638, 0.09046785373357125, 0.03125965718936641, 0.03983765607699752, 0.044449573251768015, 0.07841932369046845, 0.09074489746126346, 0.03272730617027264, 0.020376196953293402, 0.06374844451784156, 0.04418303091370035, 0.033629809695412405, 0.05557958051213063, 0.05223722939263098, 0.051321779101272114, 0.04760921132401563, 0.05294226968544535, 0.05518245729035698, 0.03586417515180074, 0.050156751967733726, 0.0383508596860338, 0.05998964836180676, 0.08686003639013506, 0.02789181329717394, 0.027589683122641873, 0.015213778751785867, 0.06512267194921151, 0.038245185278356075, 0.045422361872624606, 0.08225718454923481, 0.012821524160244735, 0.05719307635445148, 0.01818679451389471, 0.034306006418773904, 0.04506996046984568, 0.016789156034064945, 0.05866286272066645, 0.14254488312872127, 0.04549377132207155, 0.04741720658785198, 0.03980569919804111, 0.03454710422374774, 0.044138246012153104, 0.02278082407428883, 0.015041256319818785, 0.06846399890491739, 0.027893876467715017, 0.010523187429498648, 0.02672578611964127, 0.03869087835482787, 0.03645598226285074, 0.07854038281948306, 0.08220640680519864, 0.05242532672127709, 0.018807387677952647, 0.05160149827133864, 0.041023385419975966, 0.0358966515341308, 0.06674879914498888, 0.026581933780107647, 0.0341717556148069, 0.06404470244888216, 0.014407538274099352, 0.05565724626649171, 0.058405370873515494, 0.05562809841649141, 0.052605802193284035, 0.09345473095891066, 0.05158916748769116, 0.07690000638831407, 0.028325227540335618, 0.026992855382559355, 0.010814786528499098, 0.014652965583081823, 0.05637035741528962, 0.03596062095311936, 0.044889128766953945, 0.08117460631183349, 0.03042612886929419, 0.011388911971152993, 0.04811301456356887, 0.026465900846233126, 0.029214042151579633, 0.018489138055883814, 0.01047209983880748, 0.062050815104157664, 0.036724843812407926, 0.0237565608767909, 0.04517099274380598, 0.01446860496798763, 0.02892824664741056, 0.05784563938505016, 0.0704976097040344, 0.03947547316784039, 0.04121184269024525, 0.005330254898581188, 0.012923864469485125, 0.020698832668131217, 0.027054514866904356, 0.03702901303768158, 0.018298341165063903, 0.035109678137814626, 0.05887351020646747, 0.029604654882859904, 0.04273375008779112, 0.019782146700890735, 0.06135546354926191, 0.05118213659443427, 0.04947066612658091, 0.04431768989888951, 0.07182684814324602, 0.021504424694285262, 0.01070234280632576, 0.009387797963427147, 0.038945642809267156, 0.00965783117862884, 0.08540148613974452, 0.08248161000665277, 0.04077242818311788, 0.032735343629610725, 0.007916268477856647, 0.01825041697884444, 0.027198981333640404, 0.07065299316309392, 0.024623357821838, 0.022397267312044278, 0.021084664113004692, 0.04360557322797831, 0.019472235107969027, 0.030130588966130745, 0.08748295062105171, 0.07860087527660653, 0.025055417645489797, 0.07038396463030949, 0.03944444397347979, 0.08283691320684738, 0.038458404305856675, 0.043438423017505556, 0.047508928619208746, 0.0188891092693666, 0.04599160027282778, 0.0180684572114842, 0.029165383239160292, 0.031193568938761018, 0.02189503185945796, 0.012511602362792473, 0.05553879207582213, 0.04448695894097909, 0.04529779609583784, 0.023388581794279162, 0.043390910723246634, 0.03835027710010763, 0.06714949951856397, 0.019407959553063847, 0.03868421757942997, 0.04297268453228753, 0.031869131125858985, 0.0375048669957323, 0.04455819769646041, 0.01247069425517111, 0.02997862309712218, 0.06428598950151354, 0.028699527865683194, 0.010067976309073856, 0.046702882027602755, 0.06022201479936484, 0.048890217585721985, 0.021871858298254665, 0.039787754067219794, 0.002324183415112202, 0.023091258881322574, 0.026888910178968217, 0.1561057913932018, 0.04219379312417004, 0.012179064542578999, 0.012304567280807532, 0.04334226294304244, 0.03480899700662121, 0.020786524837603793, 0.03834347902738955, 0.03846788524242584, 0.03073290117754368, 0.01952968661498744, 0.03316286893095821, 0.07773229532176629, 0.08269971978734247, 0.03906688747520093, 0.01694120539468713, 0.045758346968796104, 0.057658462319523096, 0.034364647217444144, 0.015588978931191377, 0.03409130309592001, 0.07393802821752615, 0.0069362768499559024, 0.05887859020731412, 0.049190264180651866, 0.061523860567831434, 0.03653401538031176, 0.04766900616232306, 0.02238451907032868, 0.024996270331030246, 0.029653061465069186, 0.01491033404818154, 0.01847019844717579, 0.055563987989444286, 0.058832235663430765, 0.04925790351990145, 0.02238947847217787, 0.023003937785688322, 0.08550192840630189, 0.02611984295072034, 0.007198966050054878, 0.017728778075252194, 0.04132737281906884, 0.039767281923559494, 0.012748350254696561, 0.012738046461890917, 0.06528196652652696, 0.0871847705275286, 0.05955500957497861, 0.06095022494264413, 0.04234463835018687, 0.058891852386295795, 0.0696313675143756, 0.039197891383082606, 0.014486661420960445, 0.05131516656547319, 0.047651294808019884, 0.018142666413041297, 0.031104108602448832, 0.06913493009051308, 0.021960287049296312, 0.006411716667571454, 0.026513743396208156, 0.01466913141484838, 0.05440584056486841, 0.01396895497236983, 0.0667469808831811, 0.03523806968587451, 0.00035487211675899744, 0.045824138360330835, 0.02011118343943963, 0.04702741949586198, 0.05503706313902512, 0.025100491984630935, 0.04104051418835297, 0.030181886213540565, 0.05464218120323494, 0.04611520496837329, 0.003165688663102628, 0.05563615071878303, 0.016773344577813987, 0.006241791752472636, 0.04082189974724315, 0.0614985718857497, 0.011422030311223352, 0.00888613953065942, 0.017664077640802134, 0.00938830169616267, 0.008376290570595302, 0.029350344993872568, 0.028124007185397204, 0.05124610601342283, 0.05674949839885812, 0.029390324489213526, 0.0329037072515348, 0.030206269475456793, 0.03716865183378104, 0.02246337968244916, 0.046679712177137844, 0.031378415660583414, 0.07396584391244687, 0.06416300821001641, 0.0576465100311907, 0.03514213225571439, 0.018354980020376388, 0.035255866387160495, 0.033333551764371805, 0.04792839419678785, 0.03784799155255314, 0.04320638683566358, 0.036208639285177924, 0.06859781555249356, 0.0421587452001404, 0.058079263762920164, 0.032653659145580605, 0.044157916636322625, 0.02089881178108044, 0.10304938681656495, 0.11296902172034606, 0.062412519328063354, 0.24189453019062057, 0.253173349192366, 0.10429390909848735, 0.14851083018584177, 0.18215345306089148, 0.09252409261534922, 0.13485609961207956, 0.12182688820757903, 0.0951450687716715, 0.14508697640849277, 0.10312531594536267, 0.12524990335805342, 0.1457935752114281, 0.0873060523008462, 0.14785912062507123, 0.13455026055453345, 0.14079843153012916, 0.09659610848757438, 0.11354475762345828, 0.20941886032233015, 0.11967763595748693, 0.08923897592467256, 0.12051490470184945, 0.2231651422334835, 0.14365124719915912, 0.06912857730640098, 0.1047371790627949, 0.07591613379190676, 0.11988416081294417, 0.0848581078753341, 0.14666613307781518, 0.08196124574169517, 0.13269857241539285, 0.10382207387010567, 0.1194654188293498, 0.11252240467001684, 0.12422372834407724, 0.09794725512620062, 0.14699300460051745, 0.12920289358589798, 0.1549780831555836, 0.15504462411627173, 0.07697618042584509, 0.19646629050839692, 0.07888759661000222, 0.18092871643602848, 0.11883688654052094, 0.0944599774084054, 0.11948153827688657, 0.14641178422607481, 0.12892387574538589, 0.18252035602927208, 0.09207913797581568, 0.13898374687414616, 0.11228864299482666, 0.14606330136302859, 0.1954785067937337, 0.08027660762309097, 0.09380613046232611, 0.17646486143348739, 0.11674409688566811, 0.178216730710119, 0.08740614575799555, 0.13860885839676484, 0.17148683167761192, 0.18180473271058872, 0.19423772493610159, 0.10248579244944267, 0.11512173980008811, 0.14502770849503577, 0.11334250753861852, 0.18922594230389223, 0.12137273835833184, 0.12467711378121749, 0.12295804001041688, 0.10786646700580604, 0.09861956670647487, 0.16706655558664352, 0.08755088681937195, 0.18611402803799137, 0.09163869559415616, 0.1304657172295265, 0.15047545835841447, 0.10256320587359369, 0.08293337014038116, 0.1210036089469213, 0.1992033756687306, 0.10582946459180675, 0.14002362935571, 0.18729849572991952, 0.12038560031214729, 0.21968124870909378, 0.1321527673280798, 0.10636052320478484, 0.15788765827892348, 0.07057160182739608, 0.12580065114889294, 0.24774167424766347, 0.08582868860685267, 0.13156923145288602, 0.15388497384265065, 0.08398962439969182, 0.16544297395739704, 0.17466380260884762, 0.12965094298124313, 0.19330532028106973, 0.16548978863283992, 0.13335221156012267, 0.146548428456299, 0.09244091270375066, 0.1513976659043692, 0.15067898493725806, 0.23756987240631133, 0.17263330140849575, 0.10466061910847202, 0.10874390820390545, 0.1388452621176839, 0.10587938144453801, 0.12517556984676048, 0.111294358066516, 0.14017297915415838, 0.10487032035598531, 0.19709146086825058, 0.1695910154376179, 0.14377147512277588, 0.1533600379480049, 0.1987031681346707, 0.24959628644865006, 0.08998142046038993, 0.18228369997814298, 0.20905082928948104, 0.1334963069530204, 0.14209744229447097, 0.11061703698942438, 0.12518848321633413, 0.12703191867331043, 0.18423623114358634, 0.12888509110780433, 0.08070342417340726, 0.13635808776598424, 0.10005588963394985, 0.12034884173772298, 0.16659325832733884, 0.0691182837181259, 0.0770661435672082, 0.10545182274654508, 0.12252566477400251, 0.12736837874399498, 0.1413184989360161, 0.1322232565144077, 0.18905910750618204, 0.17859844694612548, 0.14985151996370405, 0.16509089909959584, 0.1829065993661061, 0.11053166032070294, 0.2121350762899965, 0.1484928108402528, 0.13316511613084003, 0.16010979685233906, 0.16214546340052038, 0.073189030517824, 0.1517119654454291, 0.09719655790831894, 0.15927062078844756, 0.10481511199031956, 0.14553599059581757, 0.11935779999475926, 0.11288029054412618, 0.14991397911217064, 0.15500150533625856, 0.11226968112168834, 0.10209933388978243], [0.07334947542403825, 0.021684547646145802, 0.02832534628396388, 0.05338180664693937, 0.05762989334471058, 0.05355332439648919, 0.017389889326295815, 0.02218111309048254, 0.007621695222042035, 0.03411005345697049, 0.02722901976085268, 0.03904973644239362, 0.01741107764246408, 0.006430266184906941, 0.04691997877671383, 0.04919263534247875, 0.051654944036272354, 0.03224464671802707, 0.056614869099576026, 0.03494504009722732, 0.0517581136955414, 0.052589942497434095, 0.020574281734297983, 0.01919056594488211, 0.02635579581692582, 0.055761210023774765, 0.09224236593581736, 0.08414324154728092, 0.02352616113057593, 0.013524783298635157, 0.04143517347984016, 0.046261007300927304, 0.006989191979300813, 0.01890241968794726, 0.029533473643823527, 0.060229751688893884, 0.05655799090163782, 0.05378157933591865, 0.03376382672286127, 0.02000468895857921, 0.052397013787413016, 0.008044915139180375, 0.07883768717874773, 0.008777452931099106, 0.06758272822480649, 0.0547520747204544, 0.08754431139095686, 0.03182310683769174, 0.07530165035859682, 0.04082218176336028, 0.051658228039741516, 0.07258776473463513, 0.012343291618890362, 0.02543479797168402, 0.05225567547313403, 0.03962746872275602, 0.07658144691959023, 0.028702123527182266, 0.02291408040036913, 0.03830823072348721, 0.08714068695553578, 0.027377740589145105, 0.03258647251641378, 0.03697436870425008, 0.06963562744203955, 0.016201701619138476, 0.021529145633394364, 0.11188907068572007, 0.032090591703308746, 0.04561622939945664, 0.06038063031155616, 0.0027667620224747225, 0.03804031170147937, 0.05139024222444277, 0.04527383956883568, 0.06262858820264228, 0.04748072700749617, 0.033726492983987555, 0.06690743321087211, 0.09328411862952635, 0.050966205017175525, 0.018826778141374234, 0.017731449806888122, 0.04053985765494872, 0.04327779999584891, 0.06405109976185486, 0.027416170851211064, 0.030114740402495954, 0.0184187397826463, 0.012398829312587623, 0.07924177174572833, 0.07061178170260973, 0.045256376834004186, 0.011947457878704881, 0.02728458621277241, 0.02249615477921907, 0.05642160642310046, 0.06614600453758612, 0.022897504532011226, 0.018897909285442438, 0.03555487026460469, 0.023103266830730718, 0.019303023582324386, 0.045791947704856284, 0.02627925441629486, 0.05765072914073244, 0.005927616521148593, 0.03893606539350003, 0.16505107545526698, 0.048064582006190903, 0.0697454801411368, 0.02694543029065244, 0.039134463731897995, 0.01580335014295997, 0.025797125599638093, 0.022396439817384817, 0.05649811813782435, 0.024485038193233777, 0.014453351050178753, 0.031176314005278982, 0.02146562335838098, 0.012927509342262056, 0.03831432375591248, 0.061328672018134966, 0.023541968876088504, 0.047102524840738624, 0.09632935834815726, 0.051036093063885346, 0.07707215496338904, 0.015368846798082814, 0.005607287494058255, 0.056940170979942195, 0.03911730156687554, 0.018331596802454442, 0.03547585380147211, 0.03547430271282792, 0.08965516492025927, 0.023962306477187667, 0.04955827665980905, 0.033033839135896415, 0.024799692109809257, 0.03246076754294336, 0.06679820391582325, 0.04617234291799832, 0.03735157639312092, 0.042679254183894955, 0.023712132206128445, 0.018748754300759174, 0.05230421564192511, 0.03866888851916883, 0.02582892291684402, 0.04840290486754384, 0.07917439957964234, 0.09693701402284205, 0.03217794619558845, 0.023545356780232396, 0.07611872526467778, 0.03163747715007048, 0.05395405816670973, 0.032135677174665034, 0.05249680296401493, 0.025041101616807282, 0.03633046282629948, 0.017868166396510787, 0.036891953204758465, 0.04736250659334473, 0.038103390543255955, 0.004568844778987113, 0.03982744412496686, 0.04214541622786783, 0.07232627642224543, 0.049369537373422645, 0.03122499147139024, 0.04282520865672268, 0.017758406465873122, 0.07780306652421132, 0.0766309852770064, 0.02506752764020348, 0.08824414922855794, 0.0197192775158328, 0.020006533195555676, 0.0571234220842598, 0.03294374611868989, 0.05489904593559913, 0.025533613079460338, 0.03142087021842599, 0.018225694184366148, 0.045202541441540234, 0.01897520025522681, 0.04538064204098191, 0.04439565622305963, 0.031179312281892635, 0.0208974480847246, 0.006676825269096298, 0.04199279355816543, 0.030157944529491942, 0.0632771807431709, 0.03275784183642827, 0.0366137034870917, 0.04457398688828107, 0.02552862213633489, 0.04582535919325892, 0.0812126488017384, 0.03173994176904671, 0.020385325369716156, 0.07100538714439608, 0.07351025429670699, 0.04585048089211341, 0.04459298957954161, 0.030599520541727543, 0.026894474431173876, 0.015771725375088863, 0.041617129536462016, 0.08410290582105517, 0.04547733275103383, 0.04046899739478249, 0.026353894063504413, 0.029372180833888706, 0.06489320730906911, 0.021285472575982567, 0.03022169130417751, 0.027400346407375764, 0.09197767896694131, 0.06310365177341737, 0.026904734622803517, 0.09131645507295616, 0.03824821695161518, 0.025618956351536326, 0.018205669184681028, 0.07105252094333991, 0.11095593130448833, 0.03496279598039109, 0.037933642815914936, 0.0189387292630272, 0.07322882447624579, 0.06174145084514748, 0.026553364805295132, 0.005115360008858261, 0.01004444930003956, 0.050090144213754684, 0.038209944395930506, 0.06784290293580852, 0.05471041797136422, 0.029527558726840653, 0.049910663219634444, 0.06032900280843023, 0.02923837902926607, 0.03094158753810916, 0.0696586562844459, 0.05306306906277314, 0.006027099097991595, 0.022522295075759757, 0.024726839183131233, 0.05919052600802388, 0.0677212500886526, 0.009577977943990845, 0.029242369928397238, 0.03366214135894552, 0.020020847368869, 0.05910491927352268, 0.041454606616753154, 0.04445138038136065, 0.028806152222387027, 0.07956674337037839, 0.03831165944575332, 0.041075369153986685, 0.05834701951243915, 0.028307837164902594, 0.04200254908937495, 0.033968240168178454, 0.027702548941306304, 0.04747463026433252, 0.05684167685103603, 0.04531141821644269, 0.06011916797433514, 0.07704705552896485, 0.04595147605868988, 0.04783440861501731, 0.06035728605638724, 0.025983816558436956, 0.0249003829958383, 0.03803123523539398, 0.037334273220039904, 0.02294904668815434, 0.15626468521077186, 0.00967826343185152, 0.031393403332913294, 0.016736634242988657, 0.07098422109265812, 0.016946428258961532, 0.03939857553632464, 0.006641816771661979, 0.04246334487106651, 0.022859519558551256, 0.1105553942034021, 0.11461181755294092, 0.030045848689042032, 0.04830626981856767, 0.021418213109427597, 0.06011598416080233, 0.05981121750664897, 0.09787506642169319, 0.0054349352922145044, 0.00977711100858869, 0.034381942969048396, 0.03569394873920828, 0.03411242461879738, 0.009556085515214363, 0.03789799004152883, 0.04994791161152534, 0.03238142453483306, 0.036644662177423015, 0.07622408797033131, 0.046243370161391795, 0.06336953360005282, 0.0439171490870649, 0.055458354399888776, 0.017208178178407252, 0.042917112514260225, 0.04234660504152998, 0.0465488121699309, 0.023809342419554014, 0.007190256019384833, 0.014809636668360326, 0.0180831313264207, 0.10467251573572867, 0.04797592875547707, 0.06223232216143515, 0.0301154825501726, 0.028080064621462952, 0.0451869674725458, 0.026333765163144562, 0.06019580214342568, 0.05605737889709417, 0.02215619919297751, 0.06690556299872696, 0.030974446126492694, 0.11777132574934512, 0.07087470978149213, 0.026819491540663876, 0.05228871217695996, 0.031237377916113473, 0.07536877019447275, 0.03740129657671787, 0.019539182394510135, 0.015408051676786272, 0.019283326982986182, 0.04235790423990693, 0.022236955992411822, 0.03050297269510338, 0.04415903356857598, 0.1227984188881237, 0.13643576094182208, 0.1240668012178503, 0.2079526288434863, 0.10466600710060447, 0.14909859630279243, 0.17162929434562102, 0.08462374506052583, 0.19577302067773417, 0.13394410401815549, 0.08005564799532294, 0.1088463245832827, 0.12304000279982574, 0.07291300353244878, 0.10779982214444317, 0.22848681604955345, 0.09514543242403306, 0.20878778246697038, 0.14372918754816055, 0.23771956359269097, 0.08446644686046056, 0.12883084011264145, 0.08618793261121027, 0.11276127974269912, 0.15133473178138956, 0.12280514274607413, 0.14541218552039936, 0.28611639398150146, 0.15086318599060178, 0.10981592567986809, 0.15474501909920946, 0.13717952650040388, 0.17680100980214775, 0.10056173006887548, 0.17187632562126964, 0.07752269797492772, 0.17110790591686964, 0.09747605814482085, 0.16801545076305047, 0.08209073566831648, 0.12182962673250586, 0.14992720418376848, 0.09372539963806048, 0.22617808368522674, 0.06777581278583966, 0.15656529954867437, 0.18571215507108718, 0.20767010806594044, 0.10780451993923634, 0.157567911373917, 0.22130180237581953, 0.11137583103845827, 0.11506553695653565, 0.06598491396289319, 0.13229050993686542, 0.1744809522642754, 0.15092603105586022, 0.16389114316552877, 0.10708013185649179, 0.1853640581248328, 0.24061159434495494, 0.25307912612333894, 0.14943723828764632, 0.13933356560301036, 0.24169088486814871, 0.12094051897292957, 0.2337741432711482, 0.19067571294726804, 0.11922469580895267, 0.22702444373862818, 0.18332257313886657, 0.11098753195255995, 0.11321772282826714, 0.19695254566613585, 0.22643146774498746, 0.12271244850126095, 0.16631510137813166, 0.13446561119053513, 0.13543077424401417, 0.1183511434646789, 0.14103174791671336, 0.10084926034323871, 0.09627603503759019, 0.11250988463871181, 0.1249022368574515, 0.12981350300833583, 0.14197881740983576, 0.15554944780888036, 0.13414248009212315, 0.13784940383629873, 0.09692919920780696, 0.11131765408208594, 0.12654325895709917, 0.16318230307660997, 0.13512258999980986, 0.07639878211193718, 0.10847329889656976, 0.1797615853138268, 0.12444374544429593, 0.19243991671828553, 0.20905862184008583, 0.09294146904721856, 0.11665618949336931, 0.2610038680722937, 0.08044562433497049, 0.1351206307299435, 0.19875388650689274, 0.17545908805914223, 0.0872715498553589, 0.3077043715165928, 0.10061326480354182, 0.14401696273125708, 0.11375821413821541, 0.1560086739482358, 0.096312904934166, 0.08792657681624405, 0.08535557688446715, 0.20434654812561348, 0.08744920516619459, 0.12995602504815906, 0.23566731746541336, 0.12149181595304981, 0.09879916644422337, 0.12408734386553988, 0.2516949316486716, 0.11788186864578165, 0.18173529737396166, 0.16128595249028876, 0.14892089646309614, 0.2461131796007976, 0.11006780317984521, 0.19254093786003068, 0.23972171475179493, 0.19399976270506158, 0.12943619512952864, 0.20777006051503122, 0.11483248032163829, 0.21522946102777496, 0.16531421133549884, 0.1306900239433162, 0.13503464550012723, 0.19678244541864842, 0.1227367835235782, 0.1723560647224076, 0.10543965894612484, 0.16052851657150313, 0.10985289205564186, 0.12015156404231675, 0.09072921588085592, 0.0913892597600352, 0.1637201226549223, 0.16071953054051846, 0.1449172175489366, 0.17963892314583063, 0.17597165977349505, 0.13234919897513464, 0.10299409681465477, 0.11243758461205289, 0.15682047960581258, 0.14235465583624318, 0.14698110055178404, 0.08401655693887733, 0.16501528909429908, 0.09593170820153318, 0.14410833595320582, 0.1653674233239144, 0.12418483980582096, 0.19299723993754014, 0.16412291588494554, 0.24586194776929915, 0.12171592228696682, 0.13634971634019166, 0.1166059980459977, 0.15114894253201783, 0.13105271151289344, 0.0921233996632509, 0.18641980772372335], [0.07702788585447706, 0.02646184129844187, 0.05749069983721711, 0.1424464743467979, 0.04627365720807575, 0.0224541417992441, 0.020136273597017862, 0.03951855484046973, 0.04350511611846741, 0.05630693347484339, 0.04956266646331642, 0.055641653743805364, 0.05389842677686829, 0.03629689548688475, 0.012656322087423177, 0.02771545488940319, 0.06214271154021844, 0.002124445268236741, 0.017249387783522252, 0.020250493835192174, 0.06779857445508242, 0.021451567081385292, 0.03849305518087931, 0.06344867622829042, 0.03626775505836122, 0.010972004947689129, 0.04528984769422095, 0.04555170708044898, 0.04198683411232196, 0.050868764737970196, 0.04664307605708018, 0.026392348445369862, 0.0365776499529602, 0.013561483428929932, 0.09271754825022072, 0.026632936023816, 0.051697324379347265, 0.046043246329645626, 0.08838567679049447, 0.021254610364849214, 0.06458690811996348, 0.056218577083200216, 0.002479008639966196, 0.056321913725696504, 0.029079214327794034, 0.08308472373755649, 0.07245010376209393, 0.03893870372849051, 0.02990712830069242, 0.03676409600302577, 0.03992835394456051, 0.06604320966289379, 0.05529746791580692, 0.0914490397553891, 0.06275389241636731, 0.033178984667756595, 0.04402559912705328, 0.06281693044002168, 0.06552678620209917, 0.01437306365914992, 0.0661207344091963, 0.08095908662653528, 0.04831713857129216, 0.03161184708005749, 0.06904371271957643, 0.0215550317443558, 0.04711003537522629, 0.05395003943704069, 0.018782562838168815, 0.008653699806018267, 0.03689560457132757, 0.046001678638276644, 0.029171229507483076, 0.05037504728534259, 0.017421341544832103, 0.04583580492180772, 0.02682468286366202, 0.05790366791188717, 0.040581740759080276, 0.02977562900923658, 0.04435147617186885, 0.03581518969440367, 0.009890133605949814, 0.05125132331158966, 0.029549847276939545, 0.02719763433560729, 0.05015014314267319, 0.02802945200528484, 0.07518298836657777, 0.042191110260318965, 0.029491874411178287, 0.03934092179406434, 0.012251037096575601, 0.03490426279313397, 0.050692497243289836, 0.05178975887247361, 0.007948782895255135, 0.045559440259239636, 0.011352617239026586, 0.05418430577265099, 0.06568076700204983, 0.023640971376153175, 0.035730941090150736, 0.01114215065172175, 0.04830105623113923, 0.03906564066710416, 0.030645863953395747, 0.03165722941048443, 0.018951061902043875, 0.0759381681564264, 0.043612623630906455, 0.054448844311991706, 0.050752010065480135, 0.11798593259300105, 0.07488241855753586, 0.05919033304962795, 0.08328766401973553, 0.04458691139006987, 0.013225446382421069, 0.032394708978245035, 0.10675015815650113, 0.06937901503988542, 0.061044084359309636, 0.03331188105221372, 0.050747705608955584, 0.0431107054464519, 0.04936620141961612, 0.013945145019533811, 0.06058339247829281, 0.10996469660312869, 0.02130109292920679, 0.037994038793840446, 0.05529903013666626, 0.051460085742291994, 0.02036988313193433, 0.029886363008699846, 0.05036326569097582, 0.02104494436935056, 0.06712254471494816, 0.043841713486472145, 0.02859661981347017, 0.04904508896288462, 0.02820465451804921, 0.035229252971475944, 0.008730421177460812, 0.010826430825545685, 0.023238276480697095, 0.040203612807090394, 0.0028708709623970208, 0.08185111844795756, 0.038962441321928054, 0.03361649185535498, 0.0056267967011081055, 0.0354495409555966, 0.018388660537311807, 0.03384008239663672, 0.008508889168297173, 0.04134315830015112, 0.022768997951061465, 0.012305950458539883, 0.009265555108868284, 0.01861941836978076, 0.024258185912913177, 0.05947648664005101, 0.02982862206408754, 0.07031042521703057, 0.010972915006277617, 0.03663072464405559, 0.022357135676429607, 0.035134784993715584, 0.05003351092454977, 0.06460169912315905, 0.00886405414348701, 0.019774652864725795, 0.06660513419774361, 0.03117027663392946, 0.04157451170613058, 0.06541670343722217, 0.027210874250158668, 0.04516206470725592, 0.02789376514556352, 0.049068848820752464, 0.0457095470483182, 0.056447355236741714, 0.03262009551690426, 0.09200004729791544, 0.11362312841811217, 0.028743620714521967, 0.017720401083352044, 0.026435446816321928, 0.021716328265029006, 0.05151645927981008, 0.031252239423338324, 0.024343928089365363, 0.04104097431991249, 0.021283917776599992, 0.03856750001432374, 0.006670588909400976, 0.09444002105738036, 0.02555921902967384, 0.03558290489309002, 0.03681018337374553, 0.03190673203789629, 0.07788216462358832, 0.01555122124045738, 0.0474752981972415, 0.0359243150887778, 0.038596031881752424, 0.07046261001960374, 0.052877984853694215, 0.020475924902711995, 0.019247882009949535, 0.020582283941621426, 0.006253760739127756, 0.08201249846024439, 0.05951115606876556, 0.060571121066459455, 0.06512262742035091, 0.02046803401754005, 0.008515555509802653, 0.036004852954647504, 0.06622844230150804, 0.10362674802308902, 0.02959561737952754, 0.060996022875769995, 0.051936203162767924, 0.025262725466745906, 0.04942971441778354, 0.08806823796476237, 0.04335146557423286, 0.03491876435873564, 0.052987774470238946, 0.022284138030954637, 0.02136780272849137, 0.05851844449352939, 0.07074858178384602, 0.015341699963755673, 0.061561353868455626, 0.03334713306685444, 0.06086988745664712, 0.031804222890059464, 0.0151824768181541, 0.048736993776401505, 0.021536053172894754, 0.02598883718746947, 0.06015059792844113, 0.06045860776794143, 0.022391812526620924, 0.02852069439541083, 0.06317628576653078, 0.0468213436397491, 0.042016404986497946, 0.05286369480018038, 0.052087579024373554, 0.0299296190860332, 0.02253593203931814, 0.05468189723615069, 0.04720321943750605, 0.08548201658413745, 0.13754415849689394, 0.031513991198153235, 0.06033722951542586, 0.022909564431756735, 0.010076804155687569, 0.06523519637994468, 0.01749278810166288, 0.028975116983929183, 0.0031304600724979537, 0.012716472228930797, 0.02150516684196191, 0.02352486422751099, 0.10677876794943586, 0.025378502359671984, 0.057483697673887946, 0.0589629167370731, 0.01909374721435597, 0.015838950967008714, 0.011472441619844176, 0.029246557496662717, 0.05809184687677771, 0.03406539843126666, 0.0700329510436859, 0.04864251095568761, 0.023508047161158174, 0.06581634996109642, 0.050320889058639295, 0.044612541460082866, 0.004007607658422785, 0.055907617206685245, 0.030372265646292362, 0.04569351294776425, 0.0781904230825603, 0.033124184483313, 0.03588389030483086, 0.02430075364827644, 0.08884557828423567, 0.06764382924302481, 0.03514909360092133, 0.04185594523733016, 0.09888545595458709, 0.012465791442082264, 0.037316554444259964, 0.023855786021158565, 0.06011265933921095, 0.06498454342363402, 0.08208673549233936, 0.04741499498777557, 0.04759257979458198, 0.06618101164349355, 0.03148893258185126, 0.010417016710562166, 0.030405343168240506, 0.07972439780132845, 0.024513529242540244, 0.03702973292092793, 0.030918124539311975, 0.0032085982502394472, 0.057614245160948485, 0.011607287069637096, 0.044066843984182924, 0.04294640508305747, 0.07827154724509455, 0.021686146974388976, 0.04139726828725543, 0.016097685911518056, 0.009192457273456967, 0.02115381372277625, 0.028744192168232985, 0.01247783649887424, 0.009024296814459376, 0.04976506868842989, 0.01028288743327721, 0.0390506938128965, 0.01726012666040333, 0.05596338218310848, 0.007452932231899467, 0.05741614739235956, 0.013232289911684347, 0.03286191691586282, 0.0858993039582856, 0.04557332213153131, 0.052284526464063674, 0.0280628356631496, 0.050236106108059175, 0.06521922536194324, 0.049065728089772165, 0.061530643797595985, 0.024416632586508058, 0.06325169539195485, 0.030606066284235567, 0.025413479779672343, 0.07699537236476317, 0.17308903945377097, 0.17154560977360234, 0.14998731814557686, 0.22450669290265068, 0.14878266403684393, 0.19948634173488244, 0.15273513476131484, 0.13367409585043788, 0.13179968314943835, 0.16414825280662626, 0.21313111268682405, 0.2072834491264075, 0.10315466788597405, 0.13998048088978976, 0.07856935626477934, 0.1470182227785699, 0.10848806021385826, 0.20476810284890234, 0.15959596348693594, 0.10096568847075105, 0.12275793473236263, 0.1339724540594034, 0.14705703710205853, 0.1679524572682567, 0.12907361146062613, 0.12858112226240337, 0.15197642234852538, 0.16156853263964877, 0.135845783224795, 0.19959755998570472, 0.12332676124060526, 0.12983573775272816, 0.13419186259852722, 0.10446890752064064, 0.14679317391710356, 0.07246554043376818, 0.07932249514851719, 0.1612085910164751, 0.1500447010039352, 0.17923653067555279, 0.13459964306093752, 0.10748740765848197, 0.08140934020048007, 0.14605087781092152, 0.12014921885565855, 0.14247785235056654, 0.16635945212328807, 0.1057310335454531, 0.1600582175888121, 0.14497207710519433, 0.10881074602366425, 0.1735132362227887, 0.11745379786589183, 0.11536505291587673, 0.09976208821171895, 0.07935782137792557, 0.06491489286418073, 0.109730029507773, 0.1889086444862187, 0.1275888114469126, 0.21658787329215556, 0.2148200329975225, 0.16978651197860017, 0.16148483322467655, 0.1375671205460094, 0.17434459005016834, 0.14668315794551745, 0.12799261399777606, 0.12348146934527904, 0.16547582141356543, 0.11906023588380776, 0.12270776554942131, 0.15735412831418216, 0.2525014086859301, 0.115254866250325, 0.11073101602960378, 0.1592770329443738, 0.08662743988679722, 0.1315858110319823, 0.07194414458354004, 0.1110414786671754, 0.2242568414658308, 0.15945026505505666, 0.1945236447500065, 0.18695298145757988, 0.20609231694834307, 0.09147323376964778, 0.10239642302622087, 0.19698061369126663, 0.09144722891505808, 0.07938047172501683, 0.22229914495255798, 0.09078839473659173, 0.09972567102522589, 0.14725064858794212, 0.17363800609018654, 0.14546613965649158, 0.150470960943494, 0.1186918634630274, 0.14519748219754547, 0.18350303376792, 0.12059071508701891, 0.1883877904037945, 0.27411117567680776, 0.1871814887272194, 0.11997936351690441, 0.08784632838796824, 0.07851376198232174, 0.19884287001332268, 0.1848500466439873, 0.15272866323357448, 0.13061560137430206, 0.13611279311589897, 0.171010714257136, 0.246058156772051, 0.12828398117562756, 0.2115765359485522, 0.07186566988821141, 0.12185991377918981, 0.16980813816189766, 0.1877026545116678, 0.15012581774499267, 0.11768878408474848, 0.14250825071940199, 0.14614841085858643, 0.13202516245655715, 0.19498247012961656, 0.13181906804675236, 0.15991630411008373, 0.16295091627398506, 0.1255978221888654, 0.1380095147760585, 0.17053284536814317, 0.1137149691930972, 0.11942599594476633, 0.1017109457461629, 0.15611925395205617, 0.09507863171165809, 0.12794772890629247, 0.1519199597532861, 0.16151851188624278, 0.23621447326149791, 0.09643570811022073, 0.195724499062635, 0.08658679245854728, 0.12037630862323567, 0.17029648617608473, 0.11303902851068415, 0.06017641724611167, 0.1715518586570397, 0.05374742941057775, 0.12974648707313463, 0.05995687883114442, 0.1141849861596711, 0.25112053903285414, 0.1491144931060262, 0.09409022459294647, 0.1304861411335878, 0.1635590023943223, 0.09412301267730072, 0.15685075923101977, 0.11435866355895996, 0.12422682309988886, 0.1383550587343052, 0.1733367089764215, 0.13487656804500148, 0.08003139460925013, 0.10590359030175023, 0.14881941518979147, 0.1385594462044537, 0.1947784240473993, 0.1043785733054392, 0.1424905876046978, 0.15749099518870935, 0.22319842013530433, 0.17253395752049983], [0.015474726224056212, 0.03139456108328886, 0.0665868773648981, 0.0068991133412055206, 0.04628427734132856, 0.01031450292430236, 0.08105176602839492, 0.01607012440217659, 0.043825738757732324, 0.03440456734097097, 0.02689811652089702, 0.05006613573641516, 0.04549187142401934, 0.026451805606484413, 0.029526588368753437, 0.06581806432222947, 0.023325259899138473, 0.035774891075561754, 0.04130847402848303, 0.020176303187326994, 0.010758080879895715, 0.03288857486040797, 0.0447686967527261, 0.048234641435556114, 0.020976644518668763, 0.02056054272543406, 0.016833935369504616, 0.0732274292386137, 0.02785544620564906, 0.019340971448400524, 0.012421914743754314, 0.02067718050966505, 0.01216751579704578, 0.000913140124794154, 0.10056741492007859, 0.02017751659877831, 0.034718295428319834, 0.009845968397712568, 0.028190934062877204, 0.04513975574809592, 0.03559200733434409, 0.008426759395661065, 0.016900873379199766, 0.03565055536455475, 0.028796524711651728, 0.025320405184174888, 0.05439183623821009, 0.0625371110800188, 0.042959548518410884, 0.04370124719571322, 0.015285282825061586, 0.055951303729671054, 0.08718825862160884, 0.032886663830140606, 0.01917320525535615, 0.048384058027295396, 0.0423516256705625, 0.014449614336626837, 0.025022388363140635, 0.029764342798443977, 0.023242122661031317, 0.01591642005223548, 0.08025637667742558, 0.07252904601045884, 0.022128363088995684, 0.03161147971695755, 0.0604089951957576, 0.021095267547934782, 0.07253738775034435, 0.12092388002201915, 0.03302840290416498, 0.03443141082243528, 0.013850061059201835, 0.021461474752868526, 0.03257146629039198, 0.06454085785662755, 0.014172706050885608, 0.030706649558851495, 0.01059043064742582, 0.05619776355160866, 0.029975263023516163, 0.05323161451087799, 0.02921082679677056, 0.02687694304768229, 0.02351838156755548, 0.08475356895360164, 0.05175053265702445, 0.02090084526571445, 0.02001108070544433, 0.025249986501876265, 0.06158702846732922, 0.02106835541781038, 0.03262065212766174, 0.04797452980710659, 0.03698021682794206, 0.04111976071726531, 0.0800832781533245, 0.033871467821882106, 0.0512137335317675, 0.05090956801723223, 0.047286699918913655, 0.05040591691795271, 0.072209469799418, 0.00719445518370776, 0.057036004509427585, 0.02717187253438169, 0.0325987290852936, 0.030540284169546794, 0.0618702988140285, 0.03325359648442827, 0.059987956265104, 0.027809058265120257, 0.047338156728073955, 0.029980012768646702, 0.059114492978551425, 0.05927805861574598, 0.021744785917690024, 0.032133888598764315, 0.0020692844464065274, 0.06047758819477167, 0.05265693245746661, 0.050493920789449476, 0.022837160504423082, 0.0038900939080122043, 0.04232263738231268, 0.1168994655017741, 0.009812202533794334, 0.09325914536020719, 0.01768642741808435, 0.012109757226426154, 0.004687946029662271, 0.025945660891011357, 0.012126103956688894, 0.05309640633640811, 0.019902905260096304, 0.034702884731814265, 0.007598776774102589, 0.03397865621082019, 0.01570610282215057, 0.02025668705755379, 0.020908352089463733, 0.02370839549257653, 0.03902394681063015, 0.021823982351634186, 0.03982641996117309, 0.036700835335068405, 0.02473754466336686, 0.04384651518194005, 0.05904588142584544, 0.015002915115474025, 0.050801240431610495, 0.029360512417042628, 0.026472416902834084, 0.04930006864015013, 0.005773846305601182, 0.008590672914579045, 0.059318520507076755, 0.05240292870439589, 0.05535274678550195, 0.02635335229570046, 0.03851969086099416, 0.020871988708677236, 0.013799418757116655, 0.10228965766145848, 0.015653013288101647, 0.004062436601088848, 0.015425280635099625, 0.018852406356018037, 0.08849797115544789, 0.02469075781846186, 0.01270841343284701, 0.03280932462075725, 0.03152651865093503, 0.06539103254908696, 0.05526636821741704, 0.0986505439504981, 0.019919468140869867, 0.04592620964103844, 0.015378833322756691, 0.06771256696083583, 0.01678326523688156, 0.036514318780973554, 0.05060972922365181, 0.009928680756274844, 0.01926270269905217, 0.050396157676004805, 0.0549621730169747, 0.03396126026927959, 0.05216791651037056, 0.024867628308129497, 0.03443469111516606, 0.06281241818214767, 0.040972474089358, 0.03489019538392313, 0.045912502173450775, 0.0444048699864652, 0.022958935805945657, 0.05917083683016244, 0.025575974868843332, 0.03496997996990103, 0.041895531394402497, 0.03652813385997433, 0.03258715529227629, 0.038648316185572185, 0.03268305561505258, 0.012236985458002891, 0.044620927728828974, 0.055598000617465004, 0.043447258285596035, 0.013408917347987881, 0.08267819750471972, 0.03998800035333261, 0.052397759645828046, 0.024244881060440093, 0.026966954428644385, 0.04397682147100568, 0.08202505559893325, 0.05302367586409673, 0.02901852520153625, 0.0160086393225356, 0.02547411324485438, 0.03773996824747883, 0.010227521361230174, 0.04051752643135842, 0.02152676519472152, 0.027570086713240016, 0.015451732633664506, 0.044990127644268796, 0.059565536939771846, 0.03759820690902416, 0.004501255534705706, 0.04885447946435306, 0.053027145404485054, 0.04191561762127094, 0.07980175185366534, 0.020326489757280797, 0.02486075602064375, 0.07596452182042412, 0.06045268914022017, 0.048354806276620366, 0.02726107126363786, 0.041274487375631, 0.03143630317936186, 0.04329782314016484, 0.026175353741564322, 0.030566710192942992, 0.06610366501263343, 0.01801221354980953, 0.04727718187496066, 0.014245056172512705, 0.02202901363489218, 0.03459194478637073, 0.012155632157373475, 0.029490013475879095, 0.03502096551528666, 0.03667389537440613, 0.03296775459602941, 0.004417662803462008, 0.01696268685918767, 0.02586867420177441, 0.031259976312867366, 0.0591415219969349, 0.03843640333798248, 0.005498874561453704, 0.028004198575217742, 0.03404041031899396, 0.012715152133750962, 0.03710344673891086, 0.04285839379008394, 0.05191131524043158, 0.07756850332953036, 0.029450948677549604, 0.09010594541905448, 0.023947624940774404, 0.05417278764070943, 0.03215539603843354, 0.040474018023815006, 0.0420262866828125, 0.0406730954273371, 0.012791531189577654, 0.023093236704880837, 0.031245381978806108, 0.04081075268913992, 0.03127307893009856, 0.025674439311842434, 0.045961765936226584, 0.08168779400875792, 0.02527972807001788, 0.03988139083958231, 0.020760039442393463, 0.010290014834026806, 0.06420485049602576, 0.03614582019508816, 0.028545842069434002, 0.029925566959718708, 0.0400881940004183, 0.06045488589734305, 0.060868618384120055, 0.018965546769322827, 0.026131453851121478, 0.031942232672008686, 0.04194255016045645, 0.05002236757718492, 0.08235222398070619, 0.02348497750062961, 0.026008954955614172, 0.06629060459090397, 0.029879075118515175, 0.05698681125068106, 0.03869964311888907, 0.02571438169979956, 0.041490652729407884, 0.04972678500053007, 0.012435312364686979, 0.02652226325153606, 0.030289777787402272, 0.05568894339376129, 0.015788290111231618, 0.027627994641079567, 0.04829029508982785, 0.050760466838255525, 0.022541286634805147, 0.04021617365651764, 0.02736484762863256, 0.032685757032595575, 0.056222395432996564, 0.016055088490247726, 0.030545722256647423, 0.01222572522237897, 0.00594595359871164, 0.03871390719723422, 0.008566836058889749, 0.05904727666347753, 0.09471582539845258, 0.04124514656723477, 0.02673579398106085, 0.033253370129386894, 0.14329437806736678, 0.04482663622184191, 0.04818786386749707, 0.027794692141469568, 0.015751687387819402, 0.04717558556876611, 0.01190427230540081, 0.03537304037308786, 0.024109787918860093, 0.018218499062641058, 0.01340547842119122, 0.02460169453115668, 0.07143667142372578, 0.032215628743870184, 0.013839209004800068, 0.09065133490366861, 0.09560601669363678, 0.13465738215018064, 0.14271096093580127, 0.08766424245550297, 0.12856246466981247, 0.2087278020917438, 0.06561897578649223, 0.2117843076121062, 0.14445546810748056, 0.1385113995638676, 0.11832225165562704, 0.1843183720484376, 0.1343243953306228, 0.16647442564135417, 0.16167906811460853, 0.06831357299233787, 0.10984374879626557, 0.09838354890234768, 0.09951879736036062, 0.14819758449448273, 0.10289427795214579, 0.10642877852660604, 0.14408351853489876, 0.11213542660698295, 0.10587109165498987, 0.17393433081451803, 0.1434351337957196, 0.13735784974414855, 0.09434691863134503, 0.1670622659730725, 0.1538410535431467, 0.12064618320437148, 0.10721607104642317, 0.24104772484861314, 0.048040473338915035, 0.23992203525267541, 0.0776402690098621, 0.086476813594345, 0.08566917880671099, 0.17453184875193983, 0.13191873847972602, 0.2993700234219432, 0.0884413972380571, 0.1380517429788597, 0.1352550188312307, 0.12762922880938277, 0.17060320096788928, 0.06834017898654565, 0.08698324032593518, 0.12044750284985639, 0.12121271647629328, 0.2275752805871889, 0.08089415612630546, 0.1925790248787962, 0.11346899918862619, 0.1599621243076399, 0.17103995487559587, 0.2904812613269314, 0.17638442746829242, 0.08035658887820318, 0.2226529861218296, 0.21096086507895961, 0.23262081609573215, 0.11562315703486092, 0.21468080609338358, 0.15036916796816513, 0.09534562675980851, 0.14568971906555817, 0.266390138422139, 0.1186496575246565, 0.11917875686776824, 0.09760355169419199, 0.14984663663199171, 0.09820052786380984, 0.122366117866477, 0.07266315951710567, 0.07673424770473503, 0.09740691966726445, 0.1768941048067063, 0.14937305735656992, 0.1089488374418579, 0.0975089575513266, 0.1223935402231291, 0.09330402303021401, 0.1471969170961529, 0.21164007863262668, 0.16998515522573143, 0.08669828530400991, 0.10851992803509347, 0.12980300904018804, 0.12966154085006565, 0.188086508132983, 0.16227916872594506, 0.14180269092321396, 0.07682383977225982, 0.23447894607670605, 0.12403806525981054, 0.12017316796118394, 0.15376915427623317, 0.12465419626096264, 0.14395344973308966, 0.11808820054284297, 0.0759232287236955, 0.15788449672982097, 0.13850507646566257, 0.13239390595117584, 0.17781113216187805, 0.19619337312178686, 0.09635122201871127, 0.12466705025872216, 0.18456915859133005, 0.14869267120957375, 0.12121149935410358, 0.13212704448960721, 0.10559475296759047, 0.10798503251862712, 0.08370330382604152, 0.10502480581635609, 0.16142069682246074, 0.13894799019908533, 0.16972935176454484, 0.12767369829816744, 0.11116811132524163, 0.17181785922730342, 0.23125493782572448, 0.10520843541598879, 0.18684174836380407, 0.14890937833115458, 0.1333952709683217, 0.11599034944083542, 0.16796139272628352, 0.13853458425728604, 0.09837727033300325, 0.08252706655184738, 0.07428346085362136, 0.15012387331807986, 0.1320683109224774, 0.11477133477455936, 0.14317023160401732, 0.11431748178438284, 0.2222922132932581, 0.13673377776285633, 0.16589465987635776, 0.20744707784615457, 0.07610504006152041, 0.07938701746752486, 0.15504515846259892, 0.16594853979768232, 0.2583256352227181, 0.18789797293720767, 0.09953686865628697, 0.08165584455127828, 0.1440197235206142, 0.1142999819421675, 0.09654539753682911, 0.16606142045930028, 0.18561209872132167, 0.14409620926016942, 0.120565066463314, 0.12937115330714732, 0.28951635060366243, 0.1468893265700899, 0.18921757087809965, 0.23156598675996065, 0.170516770449467, 0.08307546173455194, 0.060974723237450235, 0.1506941395928152, 0.1000883882807102, 0.09209667492541485, 0.08321526009240188, 0.09639433337724768, 0.2523325552465394, 0.1721439737593755, 0.13602836639620364], [0.04852460966503713, 0.04294430109439418, 0.0539488408685429, 0.02221620554337278, 0.007689124904572964, 0.06165235972730443, 0.048991732255672105, 0.009841112896538107, 0.013918167951487703, 0.03362494862813037, 0.08061196189373732, 0.07501426851376891, 0.07376795765594579, 0.014974219047871884, 0.0174626402076683, 0.08042272165766917, 0.022479096514871344, 0.05765060668636579, 0.04219614202156663, 0.04992641530407127, 0.029480562225217, 0.05131108104251325, 0.013478541004587896, 0.019971242218161933, 0.015053318074933486, 0.04641771920432802, 0.046867616547388025, 0.057545815434423275, 0.11691592633724213, 0.04989640285202768, 0.04507855082920287, 0.05015132686821744, 0.024793517441139556, 0.05724978385842405, 0.0302243055193685, 0.03082338567764964, 0.04225472344842274, 0.03029879488167353, 0.02901641564676538, 0.03647207202448044, 0.027385403263906483, 0.006259370447878609, 0.02265420069306856, 0.041448101692367345, 0.0373033330834005, 0.050961225206265226, 0.017112695313699078, 0.0194100282897125, 0.011200730223208666, 0.0355896807013778, 0.12262523130630143, 0.04636530502466485, 0.03158287734549958, 0.023626113579666708, 0.03650155384093523, 0.030085603684710804, 0.054475249926326796, 0.034655891940928996, 0.06829892299720086, 0.05233843236055691, 0.039408872835338116, 0.019343719250173308, 0.021388065215433016, 0.06092559306125622, 0.050303296447964385, 0.037349409321905114, 0.03760688261536416, 0.0009882843164632504, 0.041603355275583453, 0.03701472298416775, 0.009583039391145576, 0.0302516165538691, 0.02855696129699936, 0.01685224600805668, 0.015098181829671375, 0.016340188230969943, 0.025874475941236597, 0.02883373228542041, 0.029603261500597, 0.11585387590457685, 0.0018197958502241818, 0.046204158788896166, 0.08877655112883076, 0.028350263892207295, 0.04010222059150692, 0.02881931977753993, 0.011096506714238785, 0.014706516176374862, 0.06836103333625942, 0.019554787904780824, 0.07867289328714833, 0.07009772569290362, 0.02711213892325759, 0.017136835522251204, 0.05455961356346961, 0.04608057264704257, 0.012395429348543985, 0.014846915673842886, 0.07456532854121178, 0.07195264959591441, 0.06796365778427571, 0.007973309948283713, 0.046527119193342514, 0.05507710200618021, 0.04656949211494066, 0.1105507483589463, 0.03471248070127331, 0.02339240014407551, 0.034612721210578457, 0.008010988785827067, 0.019063883191847708, 0.08152983529726043, 0.04178016082732938, 0.025984363892348483, 0.02907598413003143, 0.005674004250977305, 0.0127762058400549, 0.024180115688068327, 0.03554646173142828, 0.06083896216296125, 0.0474374301120406, 0.01679243076068815, 0.04110857655177824, 0.03674649968161248, 0.02697031079151202, 0.01568397754454054, 0.07557371427537873, 0.030785222588747274, 0.05170865697436966, 0.04031686454254668, 0.026559886428003665, 0.10087625225423835, 0.011160266476508696, 0.035777896773652174, 0.06062313448637724, 0.07206909998785704, 0.06303440197370946, 0.11000453509041108, 0.04763730903505348, 0.04972222450305708, 0.06281198773649521, 0.059136319541721605, 0.021155969661776908, 0.020391863690747414, 0.03897194081218913, 0.06591576806386001, 0.007028862091829069, 0.06759288822649978, 0.03599411036702804, 0.026624642523529474, 0.01827763524488546, 0.07941789823235013, 0.038000603090040386, 0.02815114381519379, 0.034971289860550314, 0.034181700393673964, 0.023209803985082544, 0.007965856930240989, 0.035003688317374326, 0.03534860516083427, 0.05624078585242387, 0.04229635793308262, 0.051821812230627984, 0.028014278796035796, 0.028547511901706457, 0.06177800532896072, 0.03338588430779055, 0.02254718856420368, 0.015329305169871077, 0.06761143449693918, 0.040974633739097044, 0.045367806596914306, 0.050333375693298876, 0.03241747064748779, 0.043782211796496995, 0.12404150140355341, 0.05789284368802328, 0.0353362038731575, 0.048291976054315455, 0.011864817879541079, 0.027378991107980255, 0.010332348792871926, 0.04727027619082946, 0.01817284955905052, 0.0899314961861819, 0.034878061269409955, 0.049071030734921806, 0.03899900693795644, 0.049585086744627915, 0.011863446761708474, 0.016971199293038808, 0.04595241116476245, 0.02227134711574763, 0.03263200698711444, 0.016208468150580302, 0.07863429418648593, 0.021155370377528016, 0.02172123200580245, 0.00998792640530155, 0.02022134227445349, 0.026465886003279593, 0.05123125563841313, 0.05694475374184549, 0.03664479205326643, 0.05287818894430529, 0.019828753574984148, 0.022978599008638412, 0.006711097184961545, 0.026236541962134652, 0.04913923781714402, 0.04307445895392448, 0.031722171042929403, 0.03080102105741389, 0.03739769344974775, 0.05435178623883985, 0.010963586209982168, 0.039154282785602845, 0.08199135467293672, 0.032127647136803716, 0.13006418565055355, 0.015141603962547379, 0.0323829199624015, 0.04148430365603417, 0.03342550015076995, 0.02208279893238796, 0.04900151376205031, 0.03168918257870246, 0.04998292242817115, 0.035406785827944987, 0.022434827405959368, 0.026746449366328306, 0.015717973474238534, 0.03590639964386355, 0.03767475573113188, 0.05989420445985161, 0.020861878801952116, 0.06419460885808803, 0.047195259903674014, 0.03127216979919467, 0.02281647870404413, 0.03793070020037703, 0.030412080013775267, 0.022502761748910416, 0.040108502871589735, 0.0678089125722181, 0.020260616729501635, 0.027949450341111515, 0.06593632555450313, 0.02988855048897676, 0.04457357499632053, 0.035978402811451815, 0.033317154011456296, 0.02447591905365698, 0.06373185751726851, 0.03312941662443336, 0.055257343701669015, 0.03252359776524827, 0.06289514538366348, 0.02647281580721028, 0.06561106449225917, 0.035460777071421035, 0.004199822051305091, 0.07839236146537587, 0.05976564592856448, 0.03640071823610924, 0.01174588500362006, 0.02617137954075588, 0.039379472655127756, 0.02985523547977209, 0.03176671474648174, 0.025864377166726626, 0.030452254322881345, 0.019696660565386992, 0.10354650701628998, 0.06888943506055512, 0.026965614852088038, 0.03103688301052898, 0.045880690013291314, 0.009032458583533298, 0.048832793909241445, 0.02650729969900567, 0.028944505247636698, 0.017498485940450337, 0.002895560592151014, 0.010676562451408245, 0.028713953361148015, 0.027648669019981753, 0.0472155131137697, 0.0764277481357567, 0.03316760383313522, 0.021810189537063707, 0.011533093638718128, 0.05150656645128038, 0.010077524966618512, 0.03950785307097249, 0.05023635101679247, 0.0748090201523155, 0.07480616288376041, 0.025382313287991565, 0.042251736304024234, 0.06948589172679931, 0.032041587692219764, 0.02635296266817022, 0.050153193369624205, 0.020954122192051727, 0.0799989330698736, 0.08164163984474726, 0.042893348945654, 0.029563823773059994, 0.03865557438984979, 0.05253868977888487, 0.03567520579963457, 0.028277095552766696, 0.045135076506994665, 0.054478541351272725, 0.02446817103191279, 0.04567032083286904, 0.050187424931209534, 0.004901505517409532, 0.01337641684585833, 0.04780536466569174, 0.028290062728046905, 0.01781955943442881, 0.028304410298005678, 0.015599215003021527, 0.03751299351279158, 0.00593560249399161, 0.03378595756657887, 0.03598052906454541, 0.061276294945855625, 0.03311849221063312, 0.027534463624760974, 0.03852601395919919, 0.024478000777889974, 0.09607038591639139, 0.05307827566866763, 0.024537517310818657, 0.016390893615607638, 0.05850965746503789, 0.01997074683458777, 0.0401321922254283, 0.06185414968058467, 0.052213848030078225, 0.03473431097518187, 0.049585520901018754, 0.08265052281785756, 0.030545943045581225, 0.06577460415428504, 0.05762790809967555, 0.012284840995562263, 0.019853914236591663, 0.014726706303918036, 0.28924706974066794, 0.06045684887794778, 0.13830111944116652, 0.09246890651411377, 0.06879752007080242, 0.15739009279059246, 0.10279362788423896, 0.08954141594585963, 0.16482863895362243, 0.13634466973599046, 0.21223795280093327, 0.12766544561600313, 0.14575735840480775, 0.1701081290957518, 0.11887651722645387, 0.18759603757644072, 0.09249568320228718, 0.19851638440741226, 0.17984872829401866, 0.18576974573079497, 0.07388854181044735, 0.08858842411427759, 0.06507001657155342, 0.10694836353650317, 0.08445559666142799, 0.10964629298541695, 0.14162669802317396, 0.06194961584697012, 0.14629100711317733, 0.0946816717623733, 0.16580560215516016, 0.08399069309234619, 0.13334585877601057, 0.10079186264192685, 0.1340381192858331, 0.12073115911334753, 0.07936588852317072, 0.10938883453491144, 0.09980823495425284, 0.18641300965100527, 0.08478873933199793, 0.1375567601644434, 0.12258881411980838, 0.16054591251304373, 0.10231397041934542, 0.16426466609118506, 0.16322764829965308, 0.18155228375690058, 0.07731011719442904, 0.14542535122018307, 0.24156558065442368, 0.08968639449449256, 0.16630868922220543, 0.08647925526020117, 0.10127876346814446, 0.07190396470832638, 0.10996192097081803, 0.0994970895408187, 0.13973932742374018, 0.15243232366628945, 0.15095732000190765, 0.19981146178906783, 0.1937009592074901, 0.1547746901633218, 0.17560980340931565, 0.10026127900346182, 0.12095886486349627, 0.13712264830246568, 0.14664982067188248, 0.09843290172284469, 0.15499964996706694, 0.19876182748703286, 0.12945761351147667, 0.14069306140299886, 0.08926103997509927, 0.098122854687972, 0.09627533741877414, 0.10371349024353549, 0.1262399135157466, 0.19180595932994038, 0.13103663659421727, 0.12847039382904768, 0.10551920233410783, 0.092022719909437, 0.19508996279910207, 0.07470612137694843, 0.14236650051316246, 0.08991963666630909, 0.20222467370331287, 0.14550529536791146, 0.2321492406190373, 0.21744812635006383, 0.1018386025680229, 0.09321797100710683, 0.1453422158374451, 0.10153363924473524, 0.15135261754039675, 0.194846568047069, 0.11762806898332201, 0.0839595971046947, 0.1541567631647922, 0.08462935569696128, 0.13969690626254305, 0.18371513957390562, 0.15186213160632178, 0.15534256672253832, 0.09166808464215137, 0.08078665603534319, 0.1573536533396691, 0.16491766698891297, 0.1104031277645845, 0.1201023967587389, 0.19661109836306423, 0.10573419509455562, 0.20410668599652126, 0.0942849567218218, 0.13786206487566233, 0.12080671716830693, 0.1392555213533342, 0.1529146305983886, 0.1562130614183843, 0.16295312787406147, 0.10837928362889215, 0.11333352013025433, 0.2167215192457661, 0.09401582428836264, 0.2095118662691675, 0.21018327242927626, 0.08932098324294202, 0.22883651603478938, 0.15546674287179485, 0.17806788557209074, 0.08870915669831447, 0.13172675971873105, 0.17835376085713506, 0.09718605651869439, 0.1756529073463753, 0.23884715308668092, 0.08120809943648055, 0.0831549012218602, 0.1761991874082014, 0.24156715400749817, 0.12200425408082083, 0.055021414955263026, 0.10621511421049945, 0.11696836649207398, 0.11861493985634297, 0.16464779240777716, 0.09807037000427954, 0.10926236514933407, 0.06542002083733678, 0.18956342653837055, 0.12459363701054826, 0.10480060300324112, 0.08444595616310835, 0.15906004380667582, 0.14443293650401756, 0.07996393338544294, 0.13992201449582353, 0.1207683703978546, 0.09188750802422874, 0.08089933631708845, 0.14063199749216437, 0.07767071932903491, 0.126090919948183, 0.24089251208351925, 0.18084532872308046, 0.08399541315156966, 0.15525580965913832, 0.19545428309356794, 0.10062692774226889, 0.13956946466350928, 0.14372026693308726, 0.0843897310551256, 0.14497983996989205, 0.21550312056206167], [0.023967768684087787, 0.05417804204626009, 0.07172021636506543, 0.03002479952556314, 0.00762258162467333, 0.04664631182095036, 0.009561709139234154, 0.03372126826434396, 0.03538825440045912, 0.013310000194906024, 0.060546941895154305, 0.02531547361286357, 0.029509428059100173, 0.04074666081578471, 0.017655693227425218, 0.030435617227340117, 0.06400340193067677, 0.03490824812615756, 0.019892248019459657, 0.03788224908930715, 0.048062748901429586, 0.04250913538271561, 0.04744014637253713, 0.032591058989055455, 0.06813067069742829, 0.019417640869505703, 0.07311544657568447, 0.08019042201340199, 0.0900692684808746, 0.04029364645248279, 0.028791645090677775, 0.02111503836204065, 0.05354452252504416, 0.04577486346533988, 0.05922549971728586, 0.04560786910587922, 0.012855137883889256, 0.03473243705229834, 0.037147311377339065, 0.03372475264768582, 0.06422899998142384, 0.047656081660534255, 0.05189416420762427, 0.04866151364694815, 0.023812268336769193, 0.09741543210111558, 0.09336615563370287, 0.04021824795927387, 0.014523064692184562, 0.04870470664172899, 0.025808061145653483, 0.06358297527185641, 0.03825370884442236, 0.042878877065959387, 0.009238861912308494, 0.0630105122399982, 0.048478284807060845, 0.04087778717803303, 0.03842056590656284, 0.018733558827079833, 0.03889472776791081, 0.051265858273836784, 0.01404999749865965, 0.11232434029807337, 0.05878833762835711, 0.02659848367329687, 0.00896479419679963, 0.03907383026671596, 0.02578111190814525, 0.04070691138622351, 0.045289587942534126, 0.06665947425062768, 0.014245012571336702, 0.01270173410375719, 0.033849834217107855, 0.031055778090376407, 0.023015448496153113, 0.04229592377669178, 0.02262330879602814, 0.024746639683144167, 0.04051580835948698, 0.002225728248959058, 0.03649278907687403, 0.06234675020095892, 0.006802324296586448, 0.08041119610425085, 0.01843515237851534, 0.022563228230865207, 0.044755998605978675, 0.01722984146908857, 0.04428043779626023, 0.07267089269589633, 0.07886155464802869, 0.03218752361135557, 0.019681838020915166, 0.036244410803192295, 0.022872820700285956, 0.0637782936973963, 0.03887933933583554, 0.019715733760676812, 0.013439090289466549, 0.02883352448407095, 0.0328485545469448, 0.04193495798972435, 0.12545678444439545, 0.022393398867279757, 0.01951531678059837, 0.07937588525237516, 0.015803264795977157, 0.017015273588185664, 0.05896671282243915, 0.020273856644053012, 0.02658577996044187, 0.005895954182051355, 0.07434828003169969, 0.03992549667600542, 0.032386549064540304, 0.02093698043609038, 0.04337701771873981, 0.08802918615401722, 0.07116166118066758, 0.027658548860927112, 0.009737868094816804, 0.022573210117116105, 0.0502642743231263, 0.039913852378958836, 0.038098351360531524, 0.06739448988810182, 0.0290504505392164, 0.02570652050053468, 0.011677515576593578, 0.014966941362217767, 0.038608128888881765, 0.10629200070980005, 0.02523070364986779, 0.030875354568706825, 0.04056982186739333, 0.055124695936683565, 0.03108718021394452, 0.08654056407976896, 0.07543870277004316, 0.052898215799359605, 0.03524181753164157, 0.06775138128432445, 0.026662833442969713, 0.022227226436370984, 0.0426212590537034, 0.10106489135068841, 0.031652424004278146, 0.04197449961793609, 0.11115587331005372, 0.027110949631605763, 0.026432724989717826, 0.04795352331711911, 0.0697180132556241, 0.015968800835253205, 0.012144128868385451, 0.02553610669565387, 0.011743920167646138, 0.03570841690816451, 0.051468464589561336, 0.056695577659411356, 0.027473759655549657, 0.010577561806712765, 0.017462749674450606, 0.021053970740467776, 0.032851181749720126, 0.013466472755681025, 0.004979716286470648, 0.01044221076881513, 0.029053749385639094, 0.04529069003183395, 0.027305605690344237, 0.05277694886899553, 0.07633872752194293, 0.036506563337752596, 0.05547767250391189, 0.04291398807254154, 0.043797830294352025, 0.0503194270277163, 0.00801729333034018, 0.05057452915934846, 0.017601050749362912, 0.039066802128218114, 0.003120016199318343, 0.06012956175254658, 0.030024966508790385, 0.006372271054715384, 0.054205282576731406, 0.029144066902517807, 0.060605790495174006, 0.014832629331067437, 0.05040238429501187, 0.08206461207009852, 0.0659421514137648, 0.0195135616013431, 0.02186859284847742, 0.026520745559537318, 0.05892836234124843, 0.03938812980777584, 0.0800582900410518, 0.01431291815606528, 0.0682738161412999, 0.05354677494324278, 0.02831286892615026, 0.05064404984295834, 0.08666856971103698, 0.030542067179339938, 0.06996774594881572, 0.056121110828826204, 0.026962525662383996, 0.05670549646310974, 0.004398798801048542, 0.0468791087041609, 0.039521861108369194, 0.01501637025285163, 0.07872311442042701, 0.08036675630137324, 0.01875329253380187, 0.05700498273654375, 0.011780727909354027, 0.056891341373557225, 0.048440253449371085, 0.030894414776412304, 0.021915904762863647, 0.03480113024124876, 0.03735572499863338, 0.0479928089043824, 0.06285288749495521, 0.039428198360837996, 0.038657875047647394, 0.04620360217813868, 0.04889065174211282, 0.021714135218644515, 0.03214723983546719, 0.04547221935354173, 0.02713145331654232, 0.021692362461180892, 0.03695987456012517, 0.03902339762134943, 0.03578950767405331, 0.024342221149709076, 0.049771324993344024, 0.042548970159259625, 0.06238992093130946, 0.03816517062659841, 0.03683248120069038, 0.04195996836642735, 0.0217268203778076, 0.012760245026584016, 0.03076876360864844, 0.040723854617681354, 0.025133923882094678, 0.033787304564611986, 0.041110921738436446, 0.01946495278389193, 0.055556815132149495, 0.029988287715241313, 0.04595873426296748, 0.0826617144048214, 0.06480271724285558, 0.021356375509640202, 0.018010076164500788, 0.041135605570161715, 0.12144614418502897, 0.04180634750809986, 0.0884269253583625, 0.058795250733965077, 0.00562466441806464, 0.016849045496201143, 0.02212157614849275, 0.029036138221272267, 0.040195567926275544, 0.026201139662589412, 0.053157511065364815, 0.058123321359744295, 0.022511726892844308, 0.027830743820231874, 0.025269699799537193, 0.044929063733434305, 0.027541519593796693, 0.034493981293053366, 0.010833524829649832, 0.03525413718307391, 0.022605157719226554, 0.010670524152374128, 0.021190208644839004, 0.005584449290836346, 0.031840191077208146, 0.02636888915731106, 0.030570658418582752, 0.05665386895998381, 0.0738383577845525, 0.07899833246483468, 0.02043352971668355, 0.025803552598517854, 0.05563650694966782, 0.035109102973365225, 0.03416175888560247, 0.032475888801855035, 0.06921308566234075, 0.07912650136859156, 0.04359850427135825, 0.07473899851902388, 0.008193180474336259, 0.010487986437510699, 0.01329244376393035, 0.06868282856885344, 0.03381083435670007, 0.133692397212144, 0.031207636347971857, 0.03673397222883068, 0.02724162142840214, 0.051605565240606666, 0.07590884590172209, 0.06069610986742191, 0.032704050972824916, 0.027787801300291903, 0.06490747138741426, 0.034665807033888996, 0.030955936963437125, 0.11692835731082596, 0.053437015012605116, 0.03398125001695007, 0.008253890009655152, 0.03519556688843295, 0.023739664029562846, 0.039739707426633686, 0.031025407552078832, 0.02028986291406909, 0.04479997827729676, 0.031054017345013563, 0.02088240289594978, 0.0373313751333626, 0.07992238795850426, 0.03800565711571835, 0.010021277594205458, 0.037395325998659246, 0.01529850140286726, 0.08928904120693915, 0.05454870770336129, 0.06810377526562661, 0.05709229641070124, 0.028553614210977685, 0.0031234314701578114, 0.058803592473850586, 0.04832776241528336, 0.020138724539719988, 0.06443002552259713, 0.05939898044744041, 0.04977991906343959, 0.09237634585588239, 0.09034993388922885, 0.16498999670147896, 0.1537021086551249, 0.11790290853241459, 0.08434330229647458, 0.3046505228849128, 0.11433875173679553, 0.20098892360692844, 0.07227860827697441, 0.12571772356750444, 0.1455073882243596, 0.07355516165262088, 0.11718286943505518, 0.15511772566242144, 0.08687430788995698, 0.1488500807317905, 0.18771138216834515, 0.15377440868178383, 0.118344879738288, 0.07467100294888951, 0.1138193225779105, 0.11530588148161769, 0.1306026880047284, 0.0806052157713566, 0.22721204382833093, 0.08615093654952943, 0.2020298599381931, 0.10826402067323215, 0.14466071646893397, 0.15417957678437233, 0.14076043356908485, 0.14973768935305998, 0.19158891082042828, 0.14699907536851242, 0.1978538098046556, 0.14729455404449254, 0.10755012655863538, 0.18450871808454394, 0.0970801965740975, 0.10450029294588603, 0.1612509528058581, 0.11869710302562453, 0.1410533592570573, 0.20513199269771576, 0.08427447552094236, 0.13927879510447383, 0.22063263750169426, 0.11532543707289733, 0.11936292823520489, 0.15615020151017234, 0.12286672616028227, 0.112594474630896, 0.22444838978117332, 0.21039815386757255, 0.17788472352549434, 0.11962947799474932, 0.13754322339082137, 0.11203356683836319, 0.09382696996908635, 0.12785222934326157, 0.20837157120695338, 0.1736409598379396, 0.14323951851110905, 0.19047693611355498, 0.151653335778974, 0.10537809037487023, 0.08897106803487986, 0.12032140453811735, 0.07080225390382111, 0.1421173318522051, 0.09929773383191787, 0.12936880812048912, 0.11413321393774822, 0.1042298691754695, 0.14431120944209397, 0.1328584607108496, 0.11388432729290798, 0.14735422271769494, 0.08846740209264681, 0.05705173061869573, 0.13876298762625083, 0.15778720116941258, 0.25304474984295666, 0.22458285209722817, 0.15963550511514768, 0.2189178904518485, 0.0927848536230158, 0.09515091689536348, 0.1738483752706088, 0.09164319300907664, 0.08788910578005016, 0.16526430932572111, 0.13113335327943787, 0.07803407483152114, 0.08755047121667303, 0.09581047837855294, 0.13197576510719955, 0.14467137370957062, 0.11382465119822882, 0.1216283488611225, 0.11547057147254236, 0.1081195764709264, 0.11980998315266334, 0.1644396348274313, 0.19216992339352146, 0.22390905622160062, 0.1272578284260817, 0.13976269023260102, 0.10583740557194687, 0.07807018773746677, 0.21385611675214022, 0.06660100043518469, 0.08616586856078357, 0.1209180022124201, 0.1889044587733224, 0.2683142898604274, 0.220821128168609, 0.13705606281291693, 0.13240958011010662, 0.1678669173270464, 0.13957630726508796, 0.16441806801594794, 0.12595957465237007, 0.1144140723044984, 0.22158938460052013, 0.2690660854568705, 0.0777057561208494, 0.11561031788005494, 0.08975654229288921, 0.07564920553704724, 0.10064703252282925, 0.10600335721392184, 0.21918305981671438, 0.20203195279464126, 0.17903419153299183, 0.10578642744803801, 0.12640376487979665, 0.16674076759954914, 0.18137020524591208, 0.15953711117617786, 0.19473539432510734, 0.16952546895481646, 0.16780619480414316, 0.21350252791307867, 0.14920852321665734, 0.19286595401354134, 0.1242761907633394, 0.1928140185191296, 0.09955891044228338, 0.07679560105316341, 0.24856263800757006, 0.11860148471896537, 0.060021067183697596, 0.12006507415208034, 0.1643328694626689, 0.14291246887296438, 0.17591905634617433, 0.10790380445541814, 0.1558750873664394, 0.11555323188076727, 0.1029158967139665, 0.20757266407599673, 0.1214993635949213, 0.11065823360695504, 0.14932318503269926, 0.10244955337839201, 0.14126705325907096, 0.09650498017435893, 0.07451282159308903, 0.15593523101415485, 0.0960242169094272, 0.1741889913682826, 0.14921582594979554, 0.21288657502736896, 0.14281941839726642, 0.18772200972307473], [0.059255393425701186, 0.025272304737882223, 0.08760303011513315, 0.047966889396775514, 0.038643440275336616, 0.06416157586500049, 0.04260947745933663, 0.011404209490137873, 0.03219734593585599, 0.06878406493342482, 0.01779208512743935, 0.040201297306339256, 0.04240451853547711, 0.08478457588353194, 0.03432042263739277, 0.03326021273096558, 0.06735194256179966, 0.07939020870253444, 0.09872461028862745, 0.014268219529185444, 0.005906525148020592, 0.06492085973150097, 0.030252601754909847, 0.032879824939300306, 0.05170874603209086, 0.016217132724705152, 0.04663395135139581, 0.02677966604096582, 0.004663893951146747, 0.03142842157103587, 0.021193056636548135, 0.0511202934285393, 0.03687356278533116, 0.021575064165517688, 0.02318139457202051, 0.062197994120651856, 0.015489086781599326, 0.0408214247727301, 0.10874790095840581, 0.022565885119547602, 0.02957367578346748, 0.042194290363113396, 0.036748228885699064, 0.07583398546557873, 0.016288939223159105, 0.01939917066920316, 0.045906223604106344, 0.028887057451356668, 0.047643424331909046, 0.0419420083926525, 0.04534536405117251, 0.028122754811192863, 0.04115778094273992, 0.0455124845757382, 0.017619747304706834, 0.02214092579379212, 0.037352956787799485, 0.054719520412618294, 0.06859266504761763, 0.07218420709250495, 0.0467103740083985, 0.03437422463321127, 0.013180832174839452, 0.03242901475459803, 0.02374435069214087, 0.026761023291328456, 0.027169696186319925, 0.041293935355497524, 0.03623093340138439, 0.010577467182883993, 0.00402925146772759, 0.0283609749385505, 0.02952002963866107, 0.019720296113518998, 0.051853750555892475, 0.04022654517029878, 0.06028781361237634, 0.047740371082909405, 0.026127579840249382, 0.008011418303794926, 0.010710986971389502, 0.03719381435075775, 0.03895975474733859, 0.06201792311912868, 0.046786458988208324, 0.00948313703702297, 0.03475513934972696, 0.04274897895811591, 0.08207702820072882, 0.020228407520335168, 0.032170038612093776, 0.058251872469554655, 0.028948266080988105, 0.053321945015341043, 0.010204537047684425, 0.020543846258078702, 0.0246313693060074, 0.09447981501580216, 0.01845337395934621, 0.050895767781184986, 0.06460655276896432, 0.01932063103595283, 0.027797588372777682, 0.05764107008872088, 0.09304790786700323, 0.0060986096650594845, 0.04021522370749153, 0.013156680834072176, 0.021736779999628197, 0.03978833294240758, 0.014816236216574907, 0.04533457693469245, 0.04799792601261288, 0.009984902153519215, 0.005048717466706876, 0.030840525578241795, 0.005299498907334055, 0.017545055707159918, 0.03204779204679653, 0.017022182983055245, 0.08271065904409625, 0.07060084244585596, 0.04080534243257716, 0.027780099662777502, 0.008313336966239149, 0.05847823864314705, 0.09554318647133186, 0.05531137576326728, 0.023132457354222424, 0.03836101226625033, 0.01913774172862759, 0.04180927528068423, 0.01834066028095549, 0.05267966815154068, 0.018452787662681658, 0.08089685012237169, 0.024353820917895064, 0.07908865183708258, 0.016627069126116112, 0.04987230531696696, 0.012738082641590154, 0.06907531336764805, 0.04417792122694664, 0.03526745502313133, 0.035130907272105105, 0.015438679183716886, 0.06435635252273642, 0.0164142508583609, 0.07263337713084184, 0.042653742857510224, 0.07376084045972675, 0.021730456901423167, 0.006836109641881194, 0.04402943603054155, 0.036472721403697506, 0.008701911574462429, 0.04647569207008928, 0.02933502521045739, 0.031354674356407486, 0.028334780836303253, 0.020056759894941933, 0.01997302708332427, 0.09670167899457738, 0.043418867426225916, 0.015850671334192157, 0.025583726601325907, 0.03309568972326815, 0.03459444211330265, 0.013348149368539453, 0.08864719478879124, 0.031795458125998266, 0.01216146729348111, 0.047137743458733894, 0.03670056816190481, 0.01644427073188126, 0.01998542280489346, 0.03928058889869135, 0.07697456254391, 0.09550386006594636, 0.04603477100317832, 0.0775928160874173, 0.01738676302920794, 0.04294823076634202, 0.02580161930382019, 0.06924061191966757, 0.07492489166907035, 0.020278676893212833, 0.041393052888452075, 0.0404606296797283, 0.015989310086297337, 0.09051911387359723, 0.010313268176105339, 0.025712472524901386, 0.04983342420018744, 0.03069685506488895, 0.004695761772381957, 0.06464176025474444, 0.01720989810564788, 0.04241987357090693, 0.052552887063939124, 0.08160508165019564, 0.06490917832707055, 0.06650063238339499, 0.03629222366726026, 0.014249161176849157, 0.018487419984012377, 0.04345268338511232, 0.02768652411759831, 0.0369949039304629, 0.04447278392035514, 0.024410543264821172, 0.04508837686444167, 0.03738828672794625, 0.02804866249789484, 0.05533618947083596, 0.018452850745234173, 0.020939822861691937, 0.0030722191058885073, 0.038939123041927814, 0.025110876485996414, 0.013497603067662567, 0.040178862182074226, 0.029763637758151162, 0.045953917724546045, 0.02157790102501167, 0.005754002668254543, 0.044064172252546996, 0.03041386302356841, 0.018704633621382527, 0.018333435473323334, 0.012066554027114762, 0.05042756536568049, 0.05192829929001164, 0.02560023196565453, 0.06042121836799197, 0.017064977073459886, 0.0071133569963421905, 0.06039934727596119, 0.021940206388535444, 0.011649322314042365, 0.0804277831048239, 0.06336826452752575, 0.03008333642355865, 0.07750892371404916, 0.04647283109079581, 0.002075391162179585, 0.014554956633219263, 0.036465285083977506, 0.09428042962099425, 0.03447126415267121, 0.027531721389095765, 0.026784716355905402, 0.026300778554286808, 0.046652653472847305, 0.03411242832953576, 0.026880885707214475, 0.017845638503786176, 0.01546036752188229, 0.06552785489475355, 0.0545041306031635, 0.02091565667797113, 0.020589614505297504, 0.02706757852138253, 0.04182326476438902, 0.09970232305931859, 0.06341794389300048, 0.05768211456597783, 0.00822615038487129, 0.0749663999886252, 0.03784261840337422, 0.04111067682970315, 0.01805166797566926, 0.02773236843495397, 0.06308004405582324, 0.024895983915484976, 0.07150915698730387, 0.016521350189577788, 0.02333763892238494, 0.04854348619119264, 0.0594017709227046, 0.02513979241484776, 0.03132328522042371, 0.055018268249114044, 0.06435244140448049, 0.06327480587060563, 0.06825454998761415, 0.04247960532666184, 0.08663888380397111, 0.04898363913525827, 0.040111656999215484, 0.01039694439896266, 0.06694217314361595, 0.028878507910121698, 0.037826194675290026, 0.04003957219538279, 0.032636515534250066, 0.030897643118805718, 0.04688638175139204, 0.05099813963170163, 0.037019483861513436, 0.02341802464798093, 0.015572577467537485, 0.09688631049357355, 0.039631179461139254, 0.04593435842252802, 0.06306546085397713, 0.017933826056832913, 0.02646890283358516, 0.06534674117574468, 0.03966125499573536, 0.03761401465453673, 0.012502647423389135, 0.03270762812462635, 0.039417110674548894, 0.03761556203244254, 0.02535577408707468, 0.0045464815502782585, 0.043092956984764896, 0.0027051491542806616, 0.03151687815261539, 0.042503584118094295, 0.028294077746977564, 0.05399810463131871, 0.0729358616808895, 0.07265156717039645, 0.03860422890284099, 0.01968590499018319, 0.06092110306781251, 0.05998349966830574, 0.007751238490527612, 0.00823278982352349, 0.03346918667375576, 0.047149176243692636, 0.030227281531551853, 0.021666660031769425, 0.07216307072667405, 0.05373357722419314, 0.018199949081463274, 0.06534999920404516, 0.023905077614472248, 0.03092821774771437, 0.07521424762671813, 0.006621073280257406, 0.015040245143609354, 0.02715659542445792, 0.032107000588439405, 0.06520767012261786, 0.012936386356159346, 0.08954830307629891, 0.0684076476318296, 0.04419129472807981, 0.05757759790867567, 0.15159007511101663, 0.23599285312229767, 0.17235550069017336, 0.20491794246481732, 0.3187644499121234, 0.21307465009158477, 0.08758300697081722, 0.10504418329219334, 0.18430099094985053, 0.16188703273655847, 0.09104415366891772, 0.13617005723062903, 0.16891487437533215, 0.21158225048566237, 0.13311460555996746, 0.1580689797992818, 0.17359156248858199, 0.08278268447611481, 0.18775745469611138, 0.18575419031549245, 0.14951221004594117, 0.19480319693684578, 0.10206296123214997, 0.1642848228220828, 0.18188127782195807, 0.1377987299929373, 0.14173999428749084, 0.10725949410698377, 0.07058123490423895, 0.16758448560722172, 0.09389527724124491, 0.11306215383228846, 0.26395262859296054, 0.15959844226017594, 0.11606543994275853, 0.22763150569517165, 0.1460412744199857, 0.1487338010338135, 0.15834462828934193, 0.15066206397023052, 0.09944484234438278, 0.12260485193110071, 0.0908463861560449, 0.11589636385906488, 0.09271581162465736, 0.09073062596144155, 0.13761734910076484, 0.17558969120727852, 0.07869553621276282, 0.09615984439733438, 0.2100563800195232, 0.12225475118611939, 0.17223559931153432, 0.0813461463258136, 0.1865602220641449, 0.1623132184613496, 0.15082802303368226, 0.14014154177857563, 0.14580769086023793, 0.11463124697911553, 0.20300235541071743, 0.10560618204181083, 0.13549553405027837, 0.07460887776687741, 0.13934658287325874, 0.11134513581055216, 0.15094344184035435, 0.20021928678033873, 0.13158291665604338, 0.0756790250306949, 0.14353260747157037, 0.11506080205435865, 0.2560683188494295, 0.09336060436908156, 0.14329635218018666, 0.13059936318313703, 0.15006037516286597, 0.1829916494898498, 0.11857985111419111, 0.13095816189888865, 0.08247470061178319, 0.10953873352264054, 0.24522191961295903, 0.15266194415744394, 0.1646845880895853, 0.1214674735092558, 0.12256531772436574, 0.1372870191698894, 0.30428535654209554, 0.10649183139321394, 0.0931914837565273, 0.13676236529136077, 0.1752047540503554, 0.09224546811310574, 0.13561616273364052, 0.09489828240475617, 0.10299475732608698, 0.23617418948560953, 0.15363672544481233, 0.1922662541619502, 0.15575665544020012, 0.10768737192847766, 0.11575817596167326, 0.2605598559603095, 0.21488765749381855, 0.11866182874655351, 0.08589493270847015, 0.141981637571007, 0.145096089981962, 0.1220735558308661, 0.1746808720054105, 0.16044406016590074, 0.09088298887945712, 0.11003924533724785, 0.11772065932746045, 0.10947918359306641, 0.08389347916818224, 0.16474683943670243, 0.17221980640897527, 0.15969088417477906, 0.12323205577558838, 0.17895034368848428, 0.09583332168404013, 0.11114843699033372, 0.08104964348603971, 0.07475326259736903, 0.1567564471042715, 0.1739441865356639, 0.13795395760098472, 0.1485527615295723, 0.14908836950780824, 0.13702983531402424, 0.1730703076464124, 0.11186731091584079, 0.08979059944977053, 0.11399391281884164, 0.14053329185117036, 0.21728610066929832, 0.16743472020607442, 0.11647664912743494, 0.05354752822313458, 0.17257024854188785, 0.146119378041476, 0.247300244809594, 0.10744906088802963, 0.14074645150685683, 0.09171337049338035, 0.0891482483712025, 0.228837926115375, 0.12419429476722144, 0.20125416718656197, 0.10942775275907479, 0.12127176174544729, 0.13263118540635332, 0.09644957142882049, 0.13134994165739045, 0.09887042746413499, 0.1813565645716153, 0.11322829843265936, 0.09088973500183783, 0.14109361334703863, 0.07632665277924389, 0.19808886281680316, 0.18145573034416884, 0.20742089487612247, 0.17030712857376784, 0.12582662631757557, 0.12350711796898395, 0.10401334759080783, 0.17545260168844834, 0.17567840754054487, 0.08669772869325243, 0.20546008134260774, 0.10549247017479502, 0.11056450035539456, 0.1759623532416299], [0.012418069491104688, 0.02538110358727863, 0.014928716118447483, 0.04351683834102005, 0.04331124488089699, 0.05491094998433255, 0.07722827314864844, 0.01766089568263851, 0.02203727744927164, 0.06867507312563248, 0.025756305622053333, 0.07883329366450198, 0.05310380925948266, 0.07484168949304149, 0.03097411958151497, 0.09278046010877006, 0.06147890126158018, 0.019850107019010466, 0.10338183928979561, 0.006995919084147317, 0.12913988524815068, 0.10635552855092101, 0.05390998943767045, 0.02710205313633196, 0.018999141939275432, 0.023873770114732906, 0.02391513186012162, 0.10109474795171991, 0.06797474547056481, 0.017908212685142644, 0.027310006626066752, 0.06450283020967618, 0.08014559629373252, 0.04565967101370916, 0.03549515335180331, 0.03455143094470259, 0.026118158275494352, 0.0492440364905633, 0.0371651637397008, 0.047552054820698686, 0.03658854839159176, 0.06349950592266396, 0.11208458949113265, 0.018439163686707616, 0.03838970740616787, 0.024827563465805724, 0.07052483910229057, 0.004970720065102796, 0.14538870396791026, 0.036419186581042595, 0.04988388653146103, 0.018687280353333335, 0.02828843742463505, 0.02571994595200522, 0.03936291905120015, 0.06770127147319727, 0.07660034942091443, 0.027365578644094057, 0.009614475839043735, 0.0564144261443289, 0.008151470847224118, 0.02392305057583144, 0.018417108913126867, 0.047662679353379644, 0.026351532178523485, 0.09666784448199905, 0.026675472217903007, 0.031485073413932696, 0.08267685421742499, 0.06005365117744077, 0.020401402143761516, 0.02904521839809604, 0.039237744713318534, 0.025677654666651506, 0.019472196145216003, 0.03821058264293242, 0.050525317346910015, 0.05705155250325333, 0.02371795621002093, 0.022586498271266464, 0.030789276570430957, 0.11920583783648908, 0.09592071699444205, 0.04309994801587891, 0.0194936423577019, 0.07464164358680137, 0.018574819005152676, 0.02886454440158559, 0.02263898295495892, 0.08718669269001111, 0.008832557396090124, 0.059281876965542324, 0.05729121796321124, 0.013503413156286115, 0.12159970196080394, 0.053512354133999906, 0.013918227323301835, 0.024913081142585725, 0.017120484153565485, 0.05045098383561708, 0.03477411235508043, 0.016444346802018117, 0.03784134933084715, 0.05579432465310674, 0.02414164089714177, 0.042786379490280524, 0.03475970355793834, 0.03572953100956511, 0.030894160590833053, 0.011906733452633489, 0.03728554380359128, 0.017020496452460065, 0.03842014659312554, 0.04257140899426304, 0.037487029476324096, 0.036975255570723675, 0.050952352830790915, 0.02564802998676896, 0.043624316167552024, 0.042631355972844176, 0.03810331261774991, 0.09832157957134768, 0.036468383550527506, 0.1102343485399615, 0.03327677746710833, 0.05330407409928739, 0.06783065749914385, 0.048730084381531924, 0.03323876837384887, 0.09187469855532981, 0.06861068439320661, 0.05323832723661326, 0.04767257960338611, 0.08138058939948678, 0.021558055996138137, 0.02368945031776093, 0.053468860569410026, 0.03220341670385096, 0.015338522644015029, 0.03706260264152661, 0.11498656502226368, 0.06515152665087953, 0.03854166585369967, 0.011660466589091811, 0.0386897651333129, 0.07495491154259071, 0.05828786663187202, 0.014541700948029757, 0.0620190474728588, 0.04722049292468, 0.02862803863536101, 0.029585620650323108, 0.041133906051982194, 0.07810486829839647, 0.06718512260704301, 0.027325304145051632, 0.03504135602270253, 0.06239694164833054, 0.03501228980894666, 0.009382170628668973, 0.03072103238082491, 0.021511174527404364, 0.014844870129309129, 0.0332334063568851, 0.07767704242723994, 0.09576167474733666, 0.037296657465049066, 0.040817899571266025, 0.02805076463118894, 0.05479815095895901, 0.02445669742883183, 0.02623222451802576, 0.011703835843945853, 0.022414961968024727, 0.04330024996306747, 0.028268119276617654, 0.033804206977947615, 0.02734043653617846, 0.03819364312221296, 0.019680162622535136, 0.06704450788674876, 0.047071287845028564, 0.015885598659224343, 0.05427941199741326, 0.04499549337197095, 0.03192899275745731, 0.03610890205891337, 0.028899421631649602, 0.011095321133325342, 0.007486494005206623, 0.02935470882221125, 0.12313608865952119, 0.053429497056640685, 0.03627075704571325, 0.0827383337309584, 0.039702421927358955, 0.03924139979062602, 0.027130989474244416, 0.0635985158442054, 0.056148585135815665, 0.01587915681739105, 0.03281625628005713, 0.019139650903525762, 0.044771479806513526, 0.020394515013322234, 0.0321300628274912, 0.059202099801041186, 0.07979859772603959, 0.053363178740255535, 0.035167480309610255, 0.02611859243188519, 0.02953811392217176, 0.008789613020780962, 0.03317320333735552, 0.06538260917295702, 0.017083577149605844, 0.04497077243286185, 0.04142170349950902, 0.04911344818538055, 0.07437441105139442, 0.026350565531174652, 0.02958019369543763, 0.024698943707335275, 0.023916673671919852, 0.06710594287142158, 0.008175521998055046, 0.03767428075661883, 0.012532287873909809, 0.04084158150362782, 0.08471644672681578, 0.07264773768838495, 0.03264406317612156, 0.048308685509255156, 0.025290281409979798, 0.03938778841984458, 0.028085797712265048, 0.04242202950990759, 0.034954754810314626, 0.01914865872095106, 0.05861427431227639, 0.019759416572924238, 0.07556916491012089, 0.020183123524475377, 0.010299672030669171, 0.041742489411262795, 0.04641204919607844, 0.01127903886299464, 0.02387965163507033, 0.020002254714199807, 0.028080391166440677, 0.017438934155507013, 0.04132757690967992, 0.060241091705393046, 0.13966158003313467, 0.020009850595670287, 0.08395337048568763, 0.01161722999313497, 0.03822790065896697, 0.047987042416934855, 0.023201085605251137, 0.019088964072579984, 0.0638512839213945, 0.023387607725453563, 0.11595442949328572, 0.030051945432205684, 0.04826408614462707, 0.01465873392589856, 0.04529586651187856, 0.07038830619421788, 0.016251458910119254, 0.13400778028881177, 0.0471641453623306, 0.065543157979846, 0.033197289740201086, 0.03603024553740397, 0.0748239818494767, 0.05347218910173979, 0.02109793927957071, 0.02004564623348415, 0.058085894852411, 0.010768284482765011, 0.09208808827679604, 0.0670456507941708, 0.05278815900965128, 0.0071264869802689645, 0.037239552912069485, 0.013364471051318105, 0.06015706203470472, 0.05053122113167774, 0.03304416983155534, 0.019102918304270133, 0.05078968148154672, 0.024920279975049198, 0.02941880997241242, 0.0227451323371497, 0.010814141787705012, 0.039452789424103685, 0.0219684785042773, 0.05233324474829715, 0.01743080578307854, 0.034346676111454144, 0.0815199721546378, 0.051232465339126065, 0.11240912324865349, 0.042762155790114775, 0.03955219639465213, 0.047385160651174374, 0.018947288081108127, 0.06366954679833725, 0.0019195153345208382, 0.045912398272776045, 0.06034468438883778, 0.10668373593944125, 0.027452575050119776, 0.035711396631086245, 0.06824894677265547, 0.030856155208311975, 0.017137768772954587, 0.03048066373594338, 0.00503965120515204, 0.012171643993497128, 0.08051905984757468, 0.0180244589864742, 0.016928460863709915, 0.00948477718338836, 0.0305877333812532, 0.028314228911767714, 0.010038472228188766, 0.02627007219416555, 0.008279544199467637, 0.059223833595751785, 0.04753909321152605, 0.014746876950084697, 0.02568466981756501, 0.034923161583719775, 0.029426300097838975, 0.06039643434633035, 0.027331148558005225, 0.014982850225351285, 0.05084473028546199, 0.019810873382084537, 0.04816866079636384, 0.02898634753364604, 0.062071034917607903, 0.02922815223428188, 0.053746984121971764, 0.026956842666550074, 0.030878634861437604, 0.11461867499747314, 0.050088860298274085, 0.06227896243217401, 0.019407553227210883, 0.12156000448158011, 0.073114667320624, 0.054734908844693564, 0.13289941241964698, 0.18694743019295856, 0.149945461016614, 0.17592762073036283, 0.09863473620498553, 0.14179863879689947, 0.12003181109321304, 0.11024617095245048, 0.16757391742430627, 0.10382409993326291, 0.14784399565542117, 0.12973716569831595, 0.26746473857201636, 0.12591684178914875, 0.13298827718244866, 0.18858426657970995, 0.11202218971448019, 0.2436912845587358, 0.17733488115482032, 0.14068840071558952, 0.1553904649335891, 0.11624116566963494, 0.10599465182167478, 0.15879242535447702, 0.2568813267862424, 0.14444066968280822, 0.11086065438576043, 0.16296173678711057, 0.11903482474735938, 0.14504206163110211, 0.09664097873610444, 0.08939169507357292, 0.13618384633446112, 0.12478070275392383, 0.20465891808271408, 0.25232783518731594, 0.10560992988757789, 0.14151708281133324, 0.1662042542011477, 0.21018750267103314, 0.280040045036003, 0.15401153970742598, 0.1428928316454403, 0.12861337600043043, 0.10218343406450003, 0.1852383531513624, 0.17437187139876187, 0.13064751372439787, 0.08926204187446274, 0.16640114597976208, 0.15178404282778502, 0.14358810527483, 0.13916726515162736, 0.1840576555696316, 0.10108806862263009, 0.07157198720960878, 0.1290922542102635, 0.15585193235892802, 0.156840042618569, 0.14846092817606404, 0.130285894847475, 0.09686769000836648, 0.14831381966359913, 0.13049381494056433, 0.09612022113287821, 0.2246695349458605, 0.11638432595646009, 0.064160002511926, 0.11302008148049936, 0.20674540690379217, 0.19562563014915213, 0.052154609802528284, 0.09937672803062014, 0.11030859299353324, 0.25432658731006086, 0.10265459393849596, 0.18398326268652454, 0.09719364126794972, 0.21092846291139722, 0.21018704253947362, 0.13464957475662231, 0.11516091777593829, 0.15778962057083845, 0.08089220427791588, 0.2200030439416878, 0.13836901111062616, 0.23947987850988284, 0.07926298974780366, 0.16220159945078194, 0.20072470419108868, 0.11318454882712103, 0.1922479973291047, 0.17129274521721527, 0.1582274431711994, 0.06610000622458756, 0.18161190790124238, 0.16640849324176088, 0.11684101395076141, 0.10171305344556458, 0.10255114597384818, 0.12422473766491748, 0.10528508442803286, 0.19905052293324843, 0.16180275444639847, 0.13063083024462685, 0.14014920074259862, 0.1403926993953064, 0.07287938424269669, 0.12722251703962684, 0.1095132036425639, 0.1405309615074657, 0.13481522211804986, 0.18398171901935712, 0.10115406781551428, 0.14379932050360367, 0.12905038223834708, 0.13846580201061442, 0.14189750771038234, 0.14700277126394212, 0.0846682590781711, 0.14842371689155698, 0.1464548139483668, 0.09755417660926469, 0.16835741756949574, 0.20492932701017708, 0.12953700846992433, 0.19767697085626423, 0.12960222840774804, 0.16815381677588448, 0.10215158850769512, 0.23223687341669574, 0.11676947833620943, 0.11502975059556775, 0.2255899168085307, 0.1287251731264405, 0.15994330344256014, 0.15314083721023053, 0.12707082205452025, 0.08410839771386236, 0.0862773168773856, 0.07070258347084746, 0.0793083498138003, 0.1924408963532187, 0.15396445785881951, 0.12444823543773964, 0.18959058914333582, 0.15551189513644204, 0.12233151894179173, 0.19924744439776987, 0.17951925925444812, 0.1647649478400126, 0.12959808722371235, 0.1946001750184223, 0.12883841001894325, 0.14567210047971457, 0.19914054544642568, 0.08985149266663939, 0.21994664071826264, 0.10564026888459921, 0.09914822818245739, 0.12046577452565543, 0.12282138093723916, 0.14142689702566713, 0.10769574335427023, 0.10499852636712603, 0.10631065088091418, 0.15396466566016898, 0.16340473957825452, 0.16537580959266052, 0.19862390676280484, 0.1341665702057071, 0.1199986222491134, 0.14188034925609827], [0.029365497794060502, 0.03431238517805468, 0.031073233403731138, 0.046708848894922994, 0.0371985826495802, 0.04930877032165881, 0.02204169508331688, 0.04200354727800004, 0.023113306233426556, 0.012425495606294135, 0.023860936526034493, 0.06753845911589451, 0.03737877239473164, 0.06711254798574373, 0.03255483847169671, 0.027621844092209358, 0.07975656248163432, 0.019800206864601932, 0.036915189848514274, 0.0693823398614768, 0.10443453866173513, 0.029359857471717987, 0.06888924952363595, 0.047511578086414374, 0.046807368998997845, 0.04378142883069813, 0.00624826003331691, 0.01758752881869441, 0.05777019265224226, 0.06598521824344061, 0.055519277302664705, 0.03580705204512924, 0.02889665156544652, 0.01803389168344438, 0.017947325723071117, 0.031138687118072994, 0.048120929568540305, 0.011926466231670929, 0.0717769461334683, 0.010279993985022884, 0.05460879569000099, 0.04479269409785047, 0.018138501109206118, 0.05808360903756693, 0.03849032036669087, 0.04775913628691342, 0.07009172913967632, 0.04169223117060028, 0.016797072894405574, 0.035853443696396425, 0.05680561589542776, 0.05318585368513595, 0.08148293898557313, 0.03179194776748773, 0.04976433025149163, 0.03878806630382314, 0.043326829982106574, 0.08529751125024632, 0.03629965256550349, 0.03381817790796049, 0.032384964579250664, 0.03164649795508012, 0.04465246900508646, 0.04990665191144217, 0.029637634070240892, 0.018269393694936298, 0.026907853498414624, 0.05757100021583028, 0.03880982978444081, 0.03219303034711629, 0.021786995566799305, 0.02538807977543911, 0.043679446607711725, 0.060340621130308136, 0.010610534500301583, 0.054178257269086316, 0.0494475630694069, 0.04525649928837083, 0.04835553729208186, 0.02110537374392152, 0.04900207408354618, 0.057182092568837106, 0.08197184361051768, 0.05796783400001004, 0.005345061208572588, 0.022250169931794517, 0.05372044863179326, 0.05901796554098837, 0.02678366992768133, 0.015148593138292199, 0.03633119755249936, 0.020062904877704568, 0.0598430593527155, 0.006966901109990431, 0.06424327148124576, 0.059370415183366276, 0.01642602132051252, 0.03362704890605528, 0.053776443673996255, 0.057225307828048244, 0.01982462352316361, 0.052734939599758945, 0.040966247470350936, 0.027702489569492172, 0.024151312936737668, 0.05724219539843034, 0.013872972085664514, 0.0030011881517566508, 0.027892130565305706, 0.03423562113312073, 0.05674773950886447, 0.053783304829266854, 0.06376843797625042, 0.02129828390025068, 0.005995279516355367, 0.023115614312700927, 0.0648738669406157, 0.0751012482214719, 0.023979034485819284, 0.06174393703986425, 0.020116654923185706, 0.0791076582390815, 0.03970804740674794, 0.03260695950302761, 0.08191891363821924, 0.0937160782632418, 0.029974212884553708, 0.012548154991236515, 0.05493025324540213, 0.00928623598156264, 0.05083320473204367, 0.061235706889419816, 0.03091220776695991, 0.07610938904690556, 0.04666168912081048, 0.034114087029593065, 0.054684142232872546, 0.009567714969307417, 0.07374127002549358, 0.055971753608901054, 0.01903229182062205, 0.04665791158913635, 0.04412411552038975, 0.06677567973383702, 0.014373319700098364, 0.05652398940583225, 0.03722566361830104, 0.03438143459788989, 0.004489598713917076, 0.07444113754900172, 0.02752277479885379, 0.017336758974124677, 0.05421945017587859, 0.03149945994664449, 0.034043441992253065, 0.049800992346717976, 0.016885689037735574, 0.044626516100834124, 0.02273154732392868, 0.04411692039866466, 0.02411609802948078, 0.06727745319949463, 0.021060750259493943, 0.04927689136820845, 0.05439437438326422, 0.01712105189653812, 0.042592727186274715, 0.07734422630164772, 0.023580449233122636, 0.07188341463916004, 0.016815541239338927, 0.03466406669758726, 0.019387912288948428, 0.05008326821553055, 0.036821950125158764, 0.04609170486219227, 0.0271523280753172, 0.03683738308609463, 0.0077718470038234955, 0.014623469851358095, 0.05716284125810489, 0.017207192977366503, 0.007892671892477665, 0.08355155689059757, 0.009760525863384828, 0.051584677494247444, 0.0375067928689532, 0.025010269091580994, 0.015551191554550314, 0.06632724442170002, 0.032854680976015516, 0.043812736330437474, 0.054001414609956555, 0.006338814573609852, 0.016908632533159107, 0.016865174220583867, 0.05041095981141552, 0.038967079744907096, 0.04638284197426401, 0.023041878230287693, 0.004586248605846777, 0.10279926820658147, 0.025651547766756266, 0.026165407107328065, 0.05709414806915447, 0.033922876391443424, 0.04340414692705963, 0.05224905922659673, 0.04090084199560806, 0.0091321624131524, 0.02891388052375987, 0.059222193449386396, 0.03972837483161129, 0.017932005939655937, 0.026066553036798723, 0.04854088125284761, 0.046498750598402694, 0.03116681080427952, 0.039439594038412906, 0.05166082926734816, 0.023393415031023324, 0.041939355214708485, 0.08327325151185505, 0.09020240977406502, 0.029109835340932477, 0.10364878980908543, 0.05819248952320777, 0.022595634109165985, 0.018415819431538694, 0.02313220131327398, 0.008295301850012038, 0.04889567237114534, 0.006094293148635188, 0.04902227905404288, 0.016920120979193598, 0.030914347007637843, 0.026722507682279684, 0.0585756529471837, 0.05312707187840715, 0.08400646373047493, 0.037878649673075415, 0.056987761199707165, 0.01527186108432943, 0.05851274479937274, 0.03240437916247174, 0.0635139481164515, 0.014620530018873978, 0.012705765821010573, 0.054939960537012666, 0.0063991715887823375, 0.02586191323644016, 0.027514128778420854, 0.058415115272509865, 0.011123983804282034, 0.032945831553661264, 0.00586634712817613, 0.032511797617189586, 0.029342730558710173, 0.07170308759668842, 0.03365057869814336, 0.05349420491256751, 0.03885250698658638, 0.04799872011062689, 0.03259080294810701, 0.03764765620871913, 0.032815914892125875, 0.046196169569157064, 0.033564352270332165, 0.02900501811382128, 0.05554465504246764, 0.049033470641006716, 0.011855442699015839, 0.031034244675538503, 0.012994381486350903, 0.024405841759289615, 0.07242541993036866, 0.037582677468890324, 0.027965697809122503, 0.030058188749535475, 0.010614053207973484, 0.03136568040645216, 0.025335524587717373, 0.044165994913782924, 0.0670242917840369, 0.015693517852923833, 0.04081236314959824, 0.034020810198853724, 0.060746839371859096, 0.03656043583760038, 0.03673035425890703, 0.05522278559510596, 0.022906508638698142, 0.11311171445413493, 0.03205702065315563, 0.03380896414455492, 0.014795704701100476, 0.042023299538413994, 0.0276404478790937, 0.028789259085897356, 0.04231010992953088, 0.037369848068919964, 0.041696472544572316, 0.06416118252673186, 0.042431781330378726, 0.03684637420519721, 0.03605593868996948, 0.026678270114643965, 0.04147002844547387, 0.02555388298787875, 0.05302986166498158, 0.011260407245572424, 0.03726796974660829, 0.0388467256561853, 0.03401044610654935, 0.03137069732474629, 0.036307723421487026, 0.0221557149416185, 0.04493626627663616, 0.05993106693495065, 0.07544808351667598, 0.013321147253009258, 0.06787915684981272, 0.032234460741165094, 0.051424418124952354, 0.020886525526293553, 0.007676156801608158, 0.018088832875946537, 0.06672391493339092, 0.03347108286106959, 0.020028125982207712, 0.014067031643207883, 0.0072086710224539274, 0.027203289500903338, 0.03643853066023439, 0.04506407152803149, 0.014040935875527794, 0.07950373503263108, 0.0317699764855206, 0.02984538903547218, 0.03818822544417344, 0.03768175418372266, 0.020535263320198283, 0.05028761115681846, 0.020338581198302563, 0.02753969205514295, 0.011637196548690554, 0.020382443981361575, 0.02020509109570412, 0.04705660816398449, 0.023258026885741856, 0.03270178000093438, 0.004034420062453137, 0.11574152216780931, 0.12796424911357462, 0.13989416911499575, 0.10521289572352543, 0.13500599859980866, 0.14672146760858595, 0.15108740364667028, 0.1145034639921505, 0.10349267162382603, 0.11992076353635639, 0.11430814556661062, 0.12409761518938467, 0.10431842965772375, 0.16221483936533332, 0.13779559812974185, 0.15163542033405975, 0.17979906377149746, 0.1490562641993165, 0.11396403395337984, 0.09288261673646048, 0.14473343209829181, 0.15575337514746934, 0.263128993101418, 0.1361863102647476, 0.11802284701843746, 0.20382964226882905, 0.12407722839270718, 0.11957884125877172, 0.24764074216363952, 0.24995174549985677, 0.0945379474433139, 0.11702219446306117, 0.1065964593726676, 0.20695758692454547, 0.1193168037571013, 0.10763277954538353, 0.12129372189519927, 0.12106628331821412, 0.14949632808566093, 0.09450783851207234, 0.1271764445118606, 0.1641036942601204, 0.09821794606978074, 0.19974260532762855, 0.12888792611192912, 0.10882301372475922, 0.1885578312794678, 0.1843395084142685, 0.11356643575709313, 0.24232171039329842, 0.13060681434581056, 0.14040442532859743, 0.27473410475067794, 0.11324704508297145, 0.1970170234562829, 0.2113124798052013, 0.11762697802623734, 0.22622405231231824, 0.10178404729231261, 0.09506395945209078, 0.07692071972996928, 0.16176434088265523, 0.15161738614551723, 0.12322179929469712, 0.08722379265236668, 0.11083624514867552, 0.20965245872503147, 0.15119517833227292, 0.09589845998561941, 0.17782168550183997, 0.07627493250765838, 0.1379007159266621, 0.20054001332027838, 0.10779257136164233, 0.09942832213710062, 0.125106401683297, 0.181521826016251, 0.10199874319368973, 0.18744808301562443, 0.17963356483960524, 0.16504709754372016, 0.14637271757237613, 0.20480880222748965, 0.15394174813991413, 0.10240008923574351, 0.07779413848766126, 0.10809632498421706, 0.11025248662917875, 0.09890791334328242, 0.0770126718271058, 0.11565696928300895, 0.10295272950315848, 0.13173315703170374, 0.08261800932814367, 0.099853261053795, 0.3131117485463619, 0.1078001486894209, 0.13750874320976436, 0.14573878986993805, 0.2244833597796969, 0.09026333267684095, 0.12123761553084478, 0.07182972025475465, 0.1301173827960156, 0.10019099019700661, 0.08666660301969387, 0.12491507601225749, 0.16624011477688327, 0.20039406255818903, 0.06922680797288194, 0.2803646307438612, 0.21750852232798934, 0.11651616849121638, 0.1519618762540631, 0.1328778752940707, 0.10608480049995705, 0.2353048525401391, 0.13091826403979212, 0.1755583577323705, 0.10288654477335513, 0.09787659524590708, 0.17304847366176546, 0.08330609154654667, 0.14490932109765708, 0.1778860148624517, 0.16266665887087584, 0.2329981091315858, 0.09790548705495894, 0.11223623994737864, 0.09330544795375317, 0.14693145087221637, 0.16290197905618697, 0.11684217170113698, 0.20492949028266594, 0.19454461784334853, 0.1261067870655097, 0.13295387121615931, 0.12437461438821629, 0.10495085080037825, 0.08249862745287828, 0.08995755299110897, 0.12186957654193975, 0.1333659264491871, 0.16940633940976113, 0.1174240377440583, 0.1470271433936432, 0.15615263575455174, 0.1794730976689607, 0.0769011492957361, 0.10130798924365081, 0.1976134133292362, 0.17978589807171375, 0.180785407719668, 0.06754652626113966, 0.0805145401682239, 0.13858525810064748, 0.06730007386067882, 0.14830291009275243, 0.16474888776428998, 0.1450775659759529, 0.20970670972019434, 0.13501693785656244, 0.12892639904748648, 0.10794572837767191, 0.12930554745253175, 0.1371731291874312, 0.2451679209480062, 0.13668372732354328, 0.07446447809343226, 0.09862385632004589, 0.07768627474433742, 0.06234267581021413, 0.1211155099736061, 0.19433429319178686, 0.1632023262209259, 0.1124780390819069], [0.011484648093755823, 0.03360955277457833, 0.05462331580929458, 0.042504823504714295, 0.05111056016176008, 0.011964972563873744, 0.09293392882682383, 0.058183097644359805, 0.039812886898289435, 0.028208619442011695, 0.044754414120689034, 0.030320556506922003, 0.09697237735963427, 0.06190887936099898, 0.012069619097019313, 0.041350063984282315, 0.06665844266535714, 0.0064515704616496805, 0.03257692478655372, 0.0037144614134376752, 0.03700972090882715, 0.03266166691901162, 0.0626688422926236, 0.033584687116672285, 0.009376592461194377, 0.026249984111927915, 0.0553867297276156, 0.015064698909554863, 0.022000628341629636, 0.022536453398060985, 0.0170716137290583, 0.002142145722245914, 0.02329304326849524, 0.08612214121967554, 0.005931266496190801, 0.060195716796442866, 0.04021687127533369, 0.055472355015808716, 0.02598404847958591, 0.020824431885557715, 0.034086887317243963, 0.050046331525663845, 0.036029366092407145, 0.021668251938535832, 0.03504761974909343, 0.09713769075460732, 0.0068040618498343974, 0.028065019432688132, 0.017008058057399467, 0.025872204969346058, 0.00597305404880899, 0.040300585533259436, 0.0407636597083183, 0.014267728784034261, 0.060956236338824965, 0.023532847881142516, 0.046897673528292216, 0.060533560972544365, 0.021355186217988376, 0.023571138990519103, 0.026863089005928487, 0.032269623698084615, 0.037618230053340085, 0.0509524010703899, 0.021054976350569632, 0.013857305348210502, 0.013125100595061667, 0.02660711485077627, 0.03176775746396743, 0.03363147210620809, 0.05694152168871369, 0.004539087440207368, 0.054941404014243744, 0.02704842554521747, 0.012394776258588536, 0.05062043099314906, 0.03041313757421449, 0.010437698510941118, 0.019223274248361122, 0.014738040754309623, 0.03494214943202678, 0.0019418433112150524, 0.04443974350579083, 0.06777712638722733, 0.020983184695069212, 0.07941134506836534, 0.07254636773723178, 0.10509501298656687, 0.01448214545234805, 0.03922497606254183, 0.03516564720484894, 0.05925746030698065, 0.07359183859080076, 0.028848334040958434, 0.028592836715688463, 0.056140091255656444, 0.06016210492816754, 0.06562574417330325, 0.06709625784424134, 0.030366888786375057, 0.025649850103945937, 0.045133414096198976, 0.015437605852639535, 0.03739496234629769, 0.014286470795923378, 0.057597684135544114, 0.01980524233658798, 0.03721656488778535, 0.026983146235579625, 0.01925539439980639, 0.035130929536535405, 0.08703903498826548, 0.04508695565164089, 0.013503386253432836, 0.06317313163890503, 0.01641529543121578, 0.04391542730445508, 0.05563596518186387, 0.006101803219280555, 0.037855951086385176, 0.02667069093149621, 0.06244643547688611, 0.045724712836090475, 0.0008976299341156846, 0.031027209115563892, 0.033321848095511086, 0.04896951977571007, 0.057014419144252315, 0.075830386049347, 0.017653659742791206, 0.06251299870200455, 0.0386354770307662, 0.03112564572802512, 0.04202514377539046, 0.03605301091738511, 0.059394468189566396, 0.05028520288760774, 0.04597866463882383, 0.03572911911760457, 0.051998127964907326, 0.07735545499599539, 0.03966371892602183, 0.020916363573633134, 0.06087494890380185, 0.043700263850041665, 0.052631773651228286, 0.027869085024576634, 0.03294906360679306, 0.011667152411973802, 0.022577811432711314, 0.019697912939591333, 0.02250444271339802, 0.06525464064907283, 0.040867189309210517, 0.02731859884079313, 0.08956091216532513, 0.01814513776480453, 0.058958467561751604, 0.030900505953468382, 0.04277205232938286, 0.022711965757480357, 0.06326403730781749, 0.00758923321882321, 0.03549552813638002, 0.04865635200985707, 0.0850935245398432, 0.01583821067470126, 0.035325157004990615, 0.06068183465686161, 0.05051254869613331, 0.011708894508046797, 0.030919510500098113, 0.025130567519227043, 0.04570307180983946, 0.042709804693004116, 0.026716297761595342, 0.04218386689899489, 0.030674815134261735, 0.017741414994816296, 0.08711292321095243, 0.06654423355939798, 0.01932493549247738, 0.029492469984688796, 0.028069715372112114, 0.12811126856831834, 0.03234223913750611, 0.03554750815965235, 0.005489368577400455, 0.05379757261835039, 0.08533568732673302, 0.04085281761945225, 0.03415914652578067, 0.01901822441141121, 0.012903003625979181, 0.0606555663398467, 0.04728669249743689, 0.09154658764600754, 0.04632577452866826, 0.05144919101439882, 0.0437658325972734, 0.04355889584985562, 0.1099416974466294, 0.0018501764770917362, 0.01767231176927453, 0.04878035746514797, 0.006333185383482487, 0.022874462702020537, 0.042819293739739805, 0.03158705934765749, 0.09304352177423425, 0.045833159165340476, 0.04151555920543615, 0.048714191289036535, 0.020097364649700467, 0.06593042548047379, 0.0430679243436316, 0.007207883882074384, 0.031905496362014674, 0.030137105022731703, 0.0503858900628984, 0.015404447622131556, 0.09252609641407616, 0.008180095483112382, 0.045443635535775684, 0.05303059639118146, 0.024599401294835843, 0.004424022545208572, 0.043186322873225436, 0.011964192381128669, 0.022629926897934638, 0.04907173206447624, 0.03112866441369988, 0.01460458126530284, 0.04982432918041013, 0.023615595491719432, 0.017943787534022704, 0.0728072771744337, 0.0016781566182544339, 0.11953544788411818, 0.007799851482559461, 0.06088251881010365, 0.013873837615392404, 0.037163215602049604, 0.024879369084374048, 0.04227333651215304, 0.013186593096179422, 0.016829300657263957, 0.0438792587374337, 0.06584290400496684, 0.02071168852125993, 0.01701499342743773, 0.06322070330497809, 0.022266083433351014, 0.011593909857765539, 0.03558225551387295, 0.04673493909649551, 0.10594743638648652, 0.03375835709448438, 0.018037090339930728, 0.003995005063188728, 0.01894517852633726, 0.019954868585045915, 0.07876408839365467, 0.04538803383184131, 0.047498898493358865, 0.07407522163703106, 0.04832113874726929, 0.01178395625174744, 0.019124826503684744, 0.004832499234908028, 0.03238271958252881, 0.024459654887323268, 0.03091454924287973, 0.023203885357361287, 0.04832301267015282, 0.04379354068078101, 0.025279019318986684, 0.0727574122720398, 0.049500934619572945, 0.14815722650382668, 0.02976806652441155, 0.07187438270193525, 0.026384880584373605, 0.0037672802955057705, 0.012128613343520556, 0.03730512165930122, 0.034662697435123846, 0.029091726937622298, 0.04030771757243201, 0.04042555206979159, 0.03744046713109128, 0.03383417861186899, 0.016410569805884734, 0.05281672427372541, 0.01631739316508174, 0.03502476531139109, 0.04102520368178375, 0.067055432300549, 0.07798311155056581, 0.033302210867987014, 0.049638150303508155, 0.01024519004204194, 0.043369095292291604, 0.11448147415649146, 0.029341103399929125, 0.031483533457503654, 0.048497220705030486, 0.0792204869503621, 0.03235130447137635, 0.04004984722996596, 0.09592744827386923, 0.0844777720340062, 0.019815161140286364, 0.059997952994308434, 0.02586747006716905, 0.12722469895379618, 0.038912316667847335, 0.043713128980016336, 0.012567832109198207, 0.012209686483402038, 0.03724580550624523, 0.003428433756198501, 0.030914180024410598, 0.06533831779961474, 0.01880710566183552, 0.05682422524841968, 0.03437897437834181, 0.0443386295955861, 0.01133126101194648, 0.030663937104691286, 0.04767856502439827, 0.03186009547789581, 0.04408241424243897, 0.03861584722471889, 0.026790629417519085, 0.023759434843668714, 0.030925625796953682, 0.03558558404620271, 0.04580225613608491, 0.03435662089032121, 0.0199432966473978, 0.0649231752322521, 0.026775754922709893, 0.06876826460938901, 0.02545811625168426, 0.030775791747146286, 0.021527987883018795, 0.029069464362692088, 0.038230461068451405, 0.03987240343121812, 0.03251423186156899, 0.03360346345289145, 0.11376255570212379, 0.11436069704359397, 0.10321327528799884, 0.19411921879509464, 0.14896316919475794, 0.21473952481755987, 0.12395430647302419, 0.12891921505797654, 0.19735477486392483, 0.12156050914200023, 0.07131639897124842, 0.08740466146264225, 0.19492379593430087, 0.22148588468553498, 0.1670718248351477, 0.14149532304145396, 0.1459475708543323, 0.09731410667882301, 0.1964846215560101, 0.10939332452835515, 0.23861261957790703, 0.24224412627518177, 0.13003760192077607, 0.22408221411751583, 0.11419920570915565, 0.16246141050942242, 0.1297638681717217, 0.13598450546851382, 0.08551591789000668, 0.10095707955770195, 0.0696372750098817, 0.1390893099596724, 0.10661041917046532, 0.1620505130267702, 0.09113612803048454, 0.14555577625287697, 0.12980437459191307, 0.13127894781064242, 0.1854821783490479, 0.1114653711556457, 0.16080602043075487, 0.14794632297707722, 0.08539647664292715, 0.11951200343901291, 0.09748752432642505, 0.21342199004720896, 0.07066533507895656, 0.088848428131314, 0.135149470588658, 0.09647743907407857, 0.05992181606416125, 0.10672312171664089, 0.0831300912250299, 0.13071285240584984, 0.20313199376687407, 0.1576764727360569, 0.10374829696957022, 0.17138946190243587, 0.11283378014923073, 0.15045387670397758, 0.19590951647842303, 0.17826510389568284, 0.25209204002749175, 0.12438792851753533, 0.11666243837680668, 0.11199340180610307, 0.2382232592208311, 0.089958918542834, 0.1754328011884354, 0.13000598642975092, 0.17101800214732066, 0.17932263464899734, 0.2390563496737741, 0.13149488309863955, 0.09358685550978407, 0.1483593726879917, 0.11231806172872894, 0.1216246752301231, 0.06335919548291713, 0.1623307034606114, 0.22433684498537332, 0.13863961299648508, 0.1935156449326314, 0.15525077789789066, 0.1129315209982451, 0.11558877333300188, 0.15526069299085066, 0.17067471431801096, 0.13018585334066302, 0.15309871290810406, 0.21752591826952994, 0.11242294945986941, 0.12455321964807808, 0.1574175077257678, 0.07072243592119776, 0.11597949924180284, 0.10673573080566712, 0.13032565911998972, 0.18413374054944143, 0.09614394759410061, 0.10416096076369286, 0.17640949721680954, 0.1417223014868796, 0.23118140583392233, 0.12108399096177891, 0.1514198412769474, 0.1064859313191846, 0.10427516986965202, 0.11727977165719494, 0.1044531368825119, 0.14213230839231983, 0.24003832979360595, 0.09590856061549857, 0.07866737912991084, 0.19823044975055382, 0.08805005534668453, 0.11218989282497205, 0.12578708468936384, 0.10084318215376697, 0.15313249547034502, 0.13112591695971787, 0.1878111861879006, 0.15850322524784133, 0.13355107745155692, 0.13641848374390975, 0.10090434254379943, 0.10368427931098267, 0.11683752585668117, 0.16322557028615847, 0.14429886010475457, 0.12481619225582108, 0.1596955003333278, 0.18452025105943903, 0.15203012415440753, 0.1887984058703296, 0.21416896168375388, 0.16622816619928926, 0.11079397983849049, 0.08434166957158595, 0.21754819754278287, 0.14225793915102258, 0.13149497215636075, 0.12535775225842372, 0.15710623614722863, 0.11891536123584956, 0.15528346208157018, 0.09131547543802299, 0.17423337179934606, 0.07185275651863776, 0.1370031773694791, 0.11771695601055399, 0.1503059666720219, 0.16400099586462602, 0.12700895662419498, 0.10996598051860929, 0.2003320783842355, 0.1373353329836391, 0.14139537059236318, 0.12666209164308384, 0.10890044199186377, 0.12321624060859904, 0.15002558327978477, 0.10586660166154616, 0.10701918668928556, 0.11075037124101073, 0.13188163109589368, 0.08822313902783208, 0.13536306068999693, 0.17486477619968355, 0.17775177519069985, 0.11989552309387363, 0.1137091062264517, 0.23749359446810558, 0.10182357407757081, 0.15605692839017138, 0.18498252000426874], [0.05425780807854608, 0.03452262819337193, 0.05254053772659972, 0.032358963435399346, 0.010348626874474576, 0.10616404702886939, 0.036435896035982296, 0.09161203764961101, 0.018444065572111867, 0.09916047361912206, 0.016236905394180212, 0.010444458548590774, 0.010259648006467614, 0.08927076210966334, 0.05291922600008547, 0.031004647826193832, 0.044008537151967175, 0.04064657478011213, 0.04729068525193725, 0.01910299437440699, 0.07411653699818999, 0.05840223158884328, 0.0972352757526096, 0.017622940395085607, 0.007648603641428053, 0.030165794596541673, 0.036604152046493255, 0.04072567287948914, 0.041556674186722375, 0.021875676648051012, 0.024424349066975992, 0.0903728514094837, 0.02372151480813045, 0.02122964637237601, 0.034021659957943484, 0.05344310062355362, 0.014147229976515519, 0.04063084867084399, 0.05505178734892979, 0.03640078874013852, 0.02256641204439802, 0.02961337326269131, 0.008321043242176529, 0.02219138255895814, 0.038865806272951886, 0.04802285104233306, 0.03898086884873919, 0.039070831990102306, 0.0596076204237761, 0.0570206643169513, 0.033933548475033604, 0.028016802098136395, 0.03551617839548271, 0.032433578962809406, 0.0282260580570437, 0.03828243738098536, 0.05714279213862028, 0.015229259024636121, 0.024082053860183805, 0.04966608474205714, 0.03786511661019176, 0.028994544554734603, 0.10242359305266291, 0.029673025237570982, 0.027045371607528068, 0.024478368140989915, 0.0760532084677834, 0.02608363727631513, 0.03487859190499876, 0.05594597139861435, 0.05453165686049033, 0.026138784414797556, 0.05301167162542697, 0.02807953213050496, 0.015471260394406272, 0.004790581342604128, 0.012769393852067878, 0.0725007701839786, 0.021977937176416162, 0.04440216856892221, 0.026297232943761628, 0.1071268945815973, 0.018916563167294953, 0.025800877156143542, 0.038326661961036734, 0.04332580210757442, 0.06380133738275617, 0.040463390469085425, 0.02893241380661493, 0.02292734629008919, 0.021613769022224005, 0.032784228897071443, 0.04692415335739497, 0.019506462958815973, 0.02829879038472427, 0.049279559389106, 0.027120669910800643, 0.06153294445539359, 0.014364763665071223, 0.06301492059719749, 0.02541153535275953, 0.006389988902810728, 0.017824739625211805, 0.051773249797406606, 0.020632399318856187, 0.065679713152349, 0.06959218953852542, 0.0692380811960902, 0.06437622723751701, 0.0252557993735536, 0.06348708237055689, 0.02306905011209892, 0.011684659675665898, 0.050474135132390074, 0.05685517280653585, 0.037559704287559725, 0.006063805258236243, 0.012785377857653657, 0.03986396150139626, 0.08140561461914331, 0.07107595796696842, 0.04934236734698061, 0.0510316327563487, 0.0524005798069993, 0.08874526218278334, 0.03213654548744671, 0.07559443503851071, 0.009924888381647179, 0.04344048247730825, 0.061624447553185746, 0.08522899617673829, 0.02183182499720715, 0.025887040501402225, 0.03588715204386972, 0.06896672974107787, 0.03942499970435165, 0.03718482323165517, 0.04413321796164382, 0.026980997718055733, 0.031505705119343475, 0.02664352832653094, 0.01636186079849722, 0.04217454552417621, 0.015942484278639313, 0.03044716690055793, 0.020949507888872176, 0.04135056493396405, 0.05768529837951064, 0.08308726188261062, 0.029691834970435593, 0.05996589963615406, 0.021023331173637416, 0.03477955600828864, 0.042078326077898964, 0.011865218639286468, 0.00378277494746726, 0.019187235557183158, 0.060045921709388494, 0.01395583936755429, 0.03978134562203195, 0.014372669393196702, 0.05312339082593098, 0.0549101855722256, 0.038348547896021046, 0.0849546687095426, 0.014817604551353725, 0.03501614526612684, 0.052532760018948466, 0.017817822808865458, 0.0445138914801646, 0.027883007714990526, 0.026460366279934533, 0.018315592387807555, 0.05267691478366032, 0.02337424535653554, 0.02394329265371198, 0.04597525818098802, 0.054559928976232186, 0.04493146087042987, 0.019887550224666484, 0.01948809665918816, 0.12223300625919364, 0.03375947031599935, 0.04794845444848761, 0.03194370583514683, 0.0353369126241887, 0.0808245649386663, 0.12571476981975138, 0.017196832595800515, 0.037625540207955055, 0.023278352455236018, 0.06524161595734768, 0.060040975295123644, 0.026161440327996388, 0.017697103212412912, 0.036754715256392956, 0.035509551016730256, 0.015367476607934805, 0.056817816803231835, 0.0749291738611646, 0.03250979010772426, 0.02343242787901545, 0.02473841483151773, 0.03681128546304535, 0.08680728453327902, 0.04666440167056862, 0.018281025004398543, 0.05776922786026262, 0.016186572938750032, 0.0035246082097728504, 0.030699790258950088, 0.035106783761875704, 0.022745440328435507, 0.02831318062817445, 0.05859802127815783, 0.1172737379965838, 0.04826598604267929, 0.0771505999728106, 0.034784788149408996, 0.02216820157627808, 0.02909405913669616, 0.038107843429315835, 0.057984372760984115, 0.06620102736633271, 0.06557843225891702, 0.07137168155168183, 0.035635931344586425, 0.013686444399354514, 0.029439378595270682, 0.03739423875231296, 0.02379723242484033, 0.06888779491418973, 0.0405660666001495, 0.013117645721649751, 0.013133525826560799, 0.09510361240245402, 0.07329797037527896, 0.026264465268468484, 0.02501274229871342, 0.009350234158773674, 0.04257277454598807, 0.04659407575672958, 0.03940107657399494, 0.06780002906452864, 0.061085655761417, 0.01165517507615732, 0.012624177816178417, 0.02148588955606101, 0.04443492696736939, 0.05735486825869884, 0.05804392269055825, 0.006432811287595541, 0.03676684194942936, 0.11812170851044357, 0.015534863377979491, 0.044206905804458074, 0.0342405415722169, 0.039119546563597396, 0.0714830556535162, 0.008997256663860753, 0.029123405511199962, 0.04409442961332388, 0.018361813345109113, 0.056213433999801055, 0.04956309319823049, 0.017902774598042015, 0.01256602776265936, 0.04478527633182239, 0.028335888491710648, 0.04613697215972934, 0.019821936948574148, 0.04732175155368168, 0.08599481094279326, 0.037265498394845054, 0.020175249337626155, 0.07921314710984007, 0.05926553858444095, 0.023327588387473952, 0.00977272213276592, 0.011126301160402363, 0.023388290501316078, 0.03638903683167882, 0.03505393171508331, 0.04684599407482892, 0.13250433752546087, 0.0176009208735195, 0.027071536023868248, 0.0347374242846854, 0.046677660138811916, 0.04800318412890192, 0.018586533806228545, 0.025735260169312824, 0.04821826965780929, 0.02294147307111416, 0.06937873302376829, 0.05258497010800056, 0.04925003304379061, 0.04868294687184971, 0.03207953370292671, 0.02297960647410946, 0.04122321610338986, 0.04393448565679137, 0.043978068279102445, 0.07803354790667072, 0.06471313259680755, 0.04396903263113927, 0.026064784869959112, 0.019041284795093816, 0.030172037913871463, 0.11085775258834474, 0.028302710779826157, 0.01888399030576693, 0.021186813319218345, 0.031404086548718624, 0.020521153237496037, 0.04336816389695741, 0.01497854020271916, 0.057212041938328184, 0.07433262813719921, 0.01954072420630837, 0.03646850600489415, 0.02597283833893016, 0.03311877793748863, 0.043368063707021065, 0.04750788961246144, 0.014247444032662315, 0.01896945232147118, 0.011848579688376049, 0.06810015358496457, 0.022620149102294818, 0.06230262210010551, 0.01817001641029492, 0.012047781401633983, 0.05173796809685882, 0.014391107124538394, 0.04313698489568196, 0.06175675764097832, 0.009755270530149573, 0.047572081675753, 0.01054316790032317, 0.048105760070029646, 0.04921996864140965, 0.06406169763067737, 0.02523947954614414, 0.07760219683405012, 0.042873849015450105, 0.04855435123317875, 0.0037321611716834013, 0.008047578521654941, 0.046704559281351976, 0.007192795092123561, 0.059346829730202444, 0.13760440604528412, 0.1089153294742573, 0.13087821775116026, 0.13348628795938566, 0.10522744923946448, 0.24862619553459808, 0.1510718185454607, 0.19154185865772888, 0.15869324473896995, 0.13825534377247095, 0.15373405069112778, 0.2672301308484748, 0.165863667789381, 0.20360704249469563, 0.09310336114140227, 0.12953151657711715, 0.18082129798131064, 0.12045436029438861, 0.1208363585465122, 0.1523580792127177, 0.17357162840198725, 0.14416337362490594, 0.15526171715464443, 0.22576904157176614, 0.08339373918715864, 0.0947546397219412, 0.08327732590259984, 0.209910043340642, 0.1243268497637473, 0.10269487771438435, 0.11295649426756427, 0.138935002614744, 0.08603637863416225, 0.08554918094887398, 0.08036146478843875, 0.12458314304240048, 0.09020272889756598, 0.12652115779928863, 0.12742399529088289, 0.23067296046065167, 0.12208740430651233, 0.1062245543289464, 0.09667550344602205, 0.13537560298573226, 0.09934293804690242, 0.1761895840172656, 0.1543397322529927, 0.16994622215861455, 0.10119610305991955, 0.16285488236462697, 0.11501475179102272, 0.08190908760298043, 0.20382545655593276, 0.12637603824259713, 0.15522431291174144, 0.28704692842438817, 0.1253116352017969, 0.14618746266933158, 0.1006748853251338, 0.17646119522396475, 0.15798088687006384, 0.08596471685450524, 0.11063437355915084, 0.11730291182175279, 0.13768294011242688, 0.096477520710323, 0.18127641262253746, 0.19897685735486448, 0.15056950331199914, 0.11350218803272583, 0.12529489235021174, 0.1738386828219518, 0.19466852681944147, 0.17962599493330345, 0.14172204915666953, 0.08442872349405661, 0.1737616182072088, 0.17961575329536572, 0.1032133272383362, 0.10583464478258975, 0.1655051510897465, 0.14881236478686333, 0.14395613630767912, 0.11192974779987708, 0.12218213945743628, 0.1513634974253364, 0.10239273455226794, 0.22716534789651632, 0.10863305360544473, 0.08627336865174584, 0.16213683964451775, 0.13766006712103263, 0.09647414393839426, 0.21006645838497207, 0.10061662673251703, 0.1716959392069839, 0.23497631860664114, 0.0815721599792596, 0.10735556512372568, 0.248505151248537, 0.1257490273565054, 0.0900047981122043, 0.16395260783610865, 0.08088471600785851, 0.10255965840769932, 0.20271023124223575, 0.11011580529157072, 0.15662030753446743, 0.21731902234023437, 0.12668567709624767, 0.13557301426772028, 0.14710886869579554, 0.08307109048473649, 0.11906913423445076, 0.13502795132808387, 0.1383057504426688, 0.1429205434396863, 0.15188668185146526, 0.08615416489192285, 0.1492411777144298, 0.1827055960893631, 0.1308221262297593, 0.08892555211787112, 0.09981910741771571, 0.14573932421626523, 0.08820371702313423, 0.15955625858623534, 0.1187686386401765, 0.09577885546605103, 0.11417084824643098, 0.18866100464947522, 0.11788441421231255, 0.13557668047724292, 0.13358665601117536, 0.11258551690843888, 0.17494676867499948, 0.10185460327193141, 0.14720171137014404, 0.09194821570417844, 0.10387167159933597, 0.07388365847873501, 0.14911058940924704, 0.1777179480995983, 0.10065304391901009, 0.11240395790082403, 0.0917092441522982, 0.17334764823317528, 0.09867273416602984, 0.17014293582178652, 0.13628917193273082, 0.15148771810345352, 0.15734811691800132, 0.13568178343120962, 0.16682522400515154, 0.15614050906151533, 0.10251121842884459, 0.16986464528599754, 0.14002397074364126, 0.09232454394805245, 0.1328011669102125, 0.08540329698007554, 0.08257494991994463, 0.15363190148491412, 0.14667103125248104, 0.2204647340113297, 0.11063701560487971, 0.15772067505167797, 0.1565393095370382, 0.12754453491652384, 0.14028459816472605, 0.10581564580206759, 0.17944860679563135, 0.15475870430236682, 0.13603633706225082, 0.09220034553436562, 0.13394101668382064], [0.010955083980661584, 0.029565159638877958, 0.022552969894604757, 0.029915280792920385, 0.029956902289995924, 0.012620426259672968, 0.049077249932452105, 0.02838452513969969, 0.051794798055198044, 0.018479098653187975, 0.06008092881529592, 0.042045289374073036, 0.02274315080285305, 0.02560798926424468, 0.022238371639105026, 0.010275124568579486, 0.03276653980719857, 0.04248044395353645, 0.046262317191576585, 0.04997150077542756, 0.007756834747851826, 0.07107083714799955, 0.03535125091730151, 0.02336754561838461, 0.12656660692300647, 0.02758333590463735, 0.07655196881387383, 0.025676457953522913, 0.016818543226690963, 0.021774223205284216, 0.0492087362363236, 0.055626402609050274, 0.05855736271769274, 0.028968255828658585, 0.0013013040006626397, 0.03274381524533965, 0.023864814247644972, 0.05142781345057301, 0.02248614877316868, 0.010814296711032512, 0.045965450699441135, 0.0036401299894350814, 0.03744552486750763, 0.03561890647688415, 0.05115528569149319, 0.044948838258278556, 0.06370424962369725, 0.026116393819393124, 0.03242951199354138, 0.0045799941563018365, 0.04175111687800381, 0.057650773669593036, 0.09572188821039163, 0.040892251636250876, 0.031042439841257874, 0.024276604162878357, 0.02093526050884975, 0.048501580822630785, 0.02727874365518801, 0.0158549331172253, 0.054501781705766916, 0.040572144789621234, 0.01457572563595022, 0.024041983451752458, 0.02289702584675979, 0.0446839100914076, 0.022007229745213408, 0.09025012244819663, 0.04153530775511172, 0.04425369821547065, 0.026291366266377736, 0.03080426795349922, 0.037063021954963915, 0.08525818484486081, 0.030508883901347872, 0.03329506027512252, 0.03175687757902779, 0.03257240510720294, 0.042223597774864174, 0.04881246648437809, 0.06461355864303187, 0.06946070323465392, 0.044184207217767835, 0.017306952468061354, 0.04514960033702664, 0.04327520618971903, 0.03546000152709894, 0.03358414534886833, 0.04062681138748303, 0.006440715160351829, 0.016541109871468507, 0.05327022845449392, 0.07215975332655944, 0.015870226925471798, 0.0108215586260485, 0.010133078430953901, 0.031415081466548145, 0.040872384342947043, 0.06661743900622241, 0.02870995504054008, 0.022252700655371882, 0.04069679220265243, 0.03074014268349856, 0.015564042769256048, 0.029749230816378258, 0.12067153496900573, 0.0190685327470419, 0.02716928986046696, 0.0022100102569311275, 0.056703310838202015, 0.043489408562891185, 0.004912666026939405, 0.04159768155659549, 0.019483309806673788, 0.04459257397684269, 0.03565791004803032, 0.09494936442933977, 0.024793194606900215, 0.017584703091415577, 0.01773893993231468, 0.06461614873842336, 0.04050636453030165, 0.017924489839060698, 0.0383013064856641, 0.05001893143344205, 0.04585027309076395, 0.015045734253362752, 0.0678440606861841, 0.03922315780073404, 0.028628606378333643, 0.03223711020837072, 0.033458822581451386, 0.04624888431862928, 0.018654573905223515, 0.02652788502018666, 0.022315388014249038, 0.02301795695530018, 0.05125050694914535, 0.04654470438254066, 0.043861039011972025, 0.07686315875616856, 0.03864743674057536, 0.03934600179491099, 0.025881793517328333, 0.04534364597930107, 0.06293211175943725, 0.026472745303181, 0.05760933956480585, 0.04925301647745073, 0.05915898102102801, 0.03701993286085781, 0.05146317678736523, 0.007727181309746811, 0.050986573260161094, 0.08784695921349339, 0.03901641772245057, 0.03757183098059613, 0.05193646291445475, 0.02683774280740181, 0.04264205403160304, 0.02467087939294288, 0.07723075192188844, 0.025892755038512405, 0.04475875568459742, 0.021097115495649632, 0.04900765874481294, 0.03241968966904096, 0.025449321801715996, 0.0352562411717372, 0.02084428062516963, 0.02446717469865689, 0.0232944459276041, 0.0636762632348109, 0.04091078677447513, 0.02978563501528697, 0.031693334894953296, 0.03152432560455054, 0.02043718850472942, 0.0501006084959954, 0.03839437922579236, 0.017150260973721743, 0.05183585366467014, 0.02808158787956927, 0.02350244023546111, 0.016589707556704525, 0.027577988730627112, 0.040005299815675244, 0.13941818528110161, 0.03586405640817247, 0.006096060851632501, 0.019019903520529624, 0.029052817990304902, 0.0195240073298919, 0.019759160531975795, 0.027939882202190347, 0.0625545960792806, 0.02480504299455788, 0.02146215567336185, 0.02598441584268585, 0.02109263663442107, 0.04400092271680478, 0.012692487871390767, 0.05540739482967183, 0.039938766276463866, 0.035468925852910616, 0.016317947920470033, 0.011606975367612904, 0.06878777567180805, 0.06507039506686851, 0.04215712360746693, 0.05062219359388109, 0.04941827050060965, 0.057129418637487106, 0.0437640403106343, 0.044311979072517715, 0.054713575809728354, 0.0582415937242331, 0.047001618731883354, 0.020237932985764928, 0.02360799775487976, 0.02538914661272429, 0.031089822259673383, 0.03310472166049294, 0.01969789624126861, 0.005858002605236834, 0.02394316648860695, 0.028221966967976186, 0.012678844414040213, 0.00420402956478938, 0.02291733842866961, 0.05532135764951818, 0.031727911555208266, 0.04713939473731443, 0.025119314705079887, 0.0824870276846923, 0.015345869906013831, 0.02336379035114078, 0.05231540351815056, 0.038014039673726074, 0.016218991804635152, 0.059326554255676456, 0.06721943209413439, 0.019050398368563037, 0.07876897172536701, 0.02983996022521751, 0.04632821619452443, 0.012991115108889062, 0.0064888207089097705, 0.08553943654987961, 0.01812776223232504, 0.036694167138193734, 0.03338035901833791, 0.05258165270788595, 0.07037678806227632, 0.11641545905149542, 0.02025030644290382, 0.09120676564634778, 0.04423982376465574, 0.01281339393244707, 0.0208203407964902, 0.03368446516105905, 0.02189042126701679, 0.027406749286456034, 0.009951567662938032, 0.009669741721154423, 0.06634970181039535, 0.06158919924928341, 0.039674442959949374, 0.040518576570320874, 0.10694163225707598, 0.01672287853580201, 0.04390077359857969, 0.04137000549235381, 0.04203783078992274, 0.030462041395367123, 0.0408292581414571, 0.015757195978949312, 0.07014766481006518, 0.029261738127388526, 0.028219592095410917, 0.00988722624242655, 0.08081527324975468, 0.061309940210776404, 0.04131798094022088, 0.04014184385596309, 0.034727854290395044, 0.018851339518732857, 0.032659433054504916, 0.0551606307271868, 0.02306320940988371, 0.023193868219095748, 0.04849066383030731, 0.0533446176268626, 0.04116831572900992, 0.016713725999579765, 0.026765448346850462, 0.07624804449733347, 0.020730351679958403, 0.031954396472428925, 0.07494204270187765, 0.01571382857946446, 0.06836732674855739, 0.010530714662309038, 0.04622381828085054, 0.036777113273274153, 0.05358842798159458, 0.07195590762421489, 0.026298470475012437, 0.02788967776723439, 0.026508546507102437, 0.030969225117587484, 0.02965868879982736, 0.049901070960913785, 0.021688523702323437, 0.035575008441810496, 0.0412713666446507, 0.07668626043596305, 0.045183160254964605, 0.018429625233693514, 0.042912325661745854, 0.05146925126609858, 0.02737642698775744, 0.01927250461449148, 0.0024892273177101742, 0.01202211144118337, 0.03575267117412295, 0.06485467500169761, 0.04187046906736214, 0.037799455094500445, 0.048654403872205876, 0.03063107666093856, 0.03171072712575551, 0.04584216883813497, 0.034943073405884206, 0.06663049338385463, 0.0643555361602921, 0.06904297799337655, 0.03978929773438722, 0.05336254049325362, 0.015365540530183353, 0.02710460983507801, 0.006639668717980385, 0.06962182349525392, 0.03264658276748378, 0.00879329407325713, 0.019853791782225017, 0.052159879051032476, 0.022918770773685537, 0.03219985439500306, 0.05848818342201412, 0.015975602618709672, 0.03231022288673557, 0.10715315918787383, 0.11920119199203327, 0.13068417581962422, 0.15492795850150287, 0.12233298097271472, 0.08739453114685602, 0.15785536001203582, 0.08671945135574788, 0.15266740636434406, 0.14280542149208486, 0.09737839151057415, 0.33614830928854644, 0.11610685920459218, 0.17156606336357072, 0.12585037504322827, 0.2054450157447718, 0.09488559910096228, 0.21543401177041233, 0.1952587568666786, 0.16410565352998674, 0.09421236725756899, 0.21451652428368106, 0.23641856387257576, 0.12394106655847281, 0.276161462534219, 0.17225306946784258, 0.11991965031484142, 0.13046395091805607, 0.1266668562311679, 0.08822914300253615, 0.0778966884536203, 0.2334007984609343, 0.20315321919042617, 0.09375464025652036, 0.1409975200658664, 0.10939601852442138, 0.06269762277952395, 0.1225196014274843, 0.10331841534934938, 0.06476398455561139, 0.1887308110599406, 0.11217242266866378, 0.1334067594143562, 0.12790906301233917, 0.14338778477394953, 0.08228549006162211, 0.11362677978468128, 0.08117947480059229, 0.10504850259167142, 0.10597420565318316, 0.1435592951020226, 0.1611455826787278, 0.27255284367129207, 0.1758974598487839, 0.11651463966700248, 0.10526786660193466, 0.1510966508067213, 0.13145741948392242, 0.13378405245020986, 0.07387614052277058, 0.09098150898353197, 0.10171290501602925, 0.07948558952193707, 0.0981536612380296, 0.11282638835837133, 0.11872668503201567, 0.13457406865200028, 0.25369534618221223, 0.18070506281219423, 0.10093990626046434, 0.07173844351200387, 0.10239598515909165, 0.15387851715786383, 0.14757996919797733, 0.0884774730366189, 0.13235483929747716, 0.11436019238317385, 0.10268010155414231, 0.2181885374011472, 0.18512020324124023, 0.14173153380397707, 0.21994999522576109, 0.11841073792311363, 0.07805957502569072, 0.1192707238078583, 0.12389037045068108, 0.11001059843692929, 0.11099234106950462, 0.18286465317942202, 0.12928852258482948, 0.14342811307869852, 0.06611671196878888, 0.17564100329764187, 0.2035202260594815, 0.13013899413635954, 0.0963177734229248, 0.09499924417468719, 0.12232394161401317, 0.15936548210447654, 0.10513465851545334, 0.10785123813548125, 0.21656271448591724, 0.08786897131358273, 0.10777847797726281, 0.1227194321108982, 0.3494859498459846, 0.1836735793040134, 0.18532162212068215, 0.10884337083552964, 0.13971796841360629, 0.14665899361716583, 0.1005595110473223, 0.11619536773650907, 0.09692050865851343, 0.1294368036906235, 0.1498877367703244, 0.23212656058603898, 0.16411035874625668, 0.19786240387475118, 0.14084600319620222, 0.14488045155303553, 0.21257117710774764, 0.11974661858403124, 0.16704543406376615, 0.07351173117058352, 0.18762354156933725, 0.10399921709904447, 0.2192300822935067, 0.11106717924121767, 0.1000142699922435, 0.14551154425134882, 0.11225861569982953, 0.10025678901001811, 0.10899548142333515, 0.11963526674662717, 0.1191308067063801, 0.09210670876200311, 0.1506828737910837, 0.12725263339234516, 0.07989758538315073, 0.2397828974062577, 0.13724220829317346, 0.12452101043891162, 0.1182569500815589, 0.13080349832307547, 0.12292804240132682, 0.14157672179862857, 0.13968805986223742, 0.1024650716863107, 0.14093669364228845, 0.11411339859478176, 0.09727536657010205, 0.08028451891732402, 0.1309306430630386, 0.21389426314271986, 0.15931614412693307, 0.0998731357685756, 0.09382708871271461, 0.08503968914737925, 0.15812498226296157, 0.1614926109323278, 0.14520996512146667, 0.09031994370161556, 0.09406962999491952, 0.11611657391767949, 0.11415714820032008, 0.1578272326150909, 0.12440355814760551, 0.15970250620739534, 0.11646235536318272, 0.11492405392345972, 0.0888026153552346, 0.19870995136443526, 0.20122229936532676, 0.10150097732548602, 0.1102221105247736], [0.06691321454127319, 0.05902901611989364, 0.018738208382274024, 0.06731911737006158, 0.018607937345223036, 0.0307718268231838, 0.0521696123178117, 0.03193518226908054, 0.06090490940550808, 0.029969802671985235, 0.05802761770610232, 0.04754092631628737, 0.05709447832487058, 0.013084073743812041, 0.036776141059817746, 0.014350539477163693, 0.024524704131181352, 0.0253184329267242, 0.03957170374633279, 0.06252767838304862, 0.06872572470456362, 0.010481913814146537, 0.028655518508458044, 0.042730391869554296, 0.03346606594277546, 0.02589670883025974, 0.05319258496456314, 0.021554358245339245, 0.06537302804645151, 0.007916301874502096, 0.019208600133424625, 0.04157867886533495, 0.021107806132931728, 0.01712879806291312, 0.024709137105674017, 0.0361935068940511, 0.025383773463545367, 0.007472038823834737, 0.034715438159764744, 0.03184780551237054, 0.02858327228750568, 0.02340618182643084, 0.01086025420590886, 0.04926182205963414, 0.03174366363964509, 0.028200463239045348, 0.03319159004604444, 0.037932848717900924, 0.019977116317022592, 0.06117038305092137, 0.005036586599089787, 0.008651015086797997, 0.04326982561906334, 0.08164641927578487, 0.07024987338809296, 0.04777006812219042, 0.009475383449171204, 0.05968436962575652, 0.026928130828309804, 0.015411733656947035, 0.03544818282534834, 0.011719431149685988, 0.03353980202518869, 0.010103015883942135, 0.07533862415584736, 0.019624126762209926, 0.047781545436009765, 0.014314566651592031, 0.051527895775507204, 0.01842702586145606, 0.07437761712935753, 0.021095946613058913, 0.06510149847599678, 0.0665322330314666, 0.03447089678957127, 0.04905161986243911, 0.009651241834944813, 0.04413747417856939, 0.03643208139692433, 0.06891514305607416, 0.08525724973878823, 0.03998289808805566, 0.03889242339937482, 0.030522626620950177, 0.03246687541832216, 0.027101554042019416, 0.029765600738755893, 0.021815698128193617, 0.05711294295906555, 0.021834094113728497, 0.016078519947768655, 0.00908246542167035, 0.043556253804126754, 0.011654842965072021, 0.06325844893581234, 0.048402912289020605, 0.01876340244052699, 0.01481719173170859, 0.012661326945817564, 0.03597734896175098, 0.02410558550764108, 0.02726647595409304, 0.01678062504652189, 0.04082110564922914, 0.03816078824456781, 0.032620989804854617, 0.06410629328456707, 0.023143895705288742, 0.025622338689572643, 0.03458978884737007, 0.05245997388556134, 0.01810265352105489, 0.045545999964815564, 0.008566678352508461, 0.028905644539918285, 0.05266722975648008, 0.01588156879734015, 0.06100966355006676, 0.054435645215562545, 0.051723522192332894, 0.042640948231564835, 0.028048864733136725, 0.10940539184957743, 0.07401014270726591, 0.01917386947752675, 0.03610570711316541, 0.054976589235593565, 0.06082717314711772, 0.08889336517313495, 0.02177813988964772, 0.02290423581143841, 0.019687227868416812, 0.014707267600897467, 0.016337496090272907, 0.07730609475402161, 0.03538127079082187, 0.029090005155012477, 0.03952611361455638, 0.035134016870870255, 0.0024000213988983887, 0.020832938753301278, 0.10137145771295764, 0.03310819862235803, 0.021937890887784306, 0.062336515984497964, 0.09200219952617772, 0.07997259424882941, 0.01845266335294582, 0.033648092503426597, 0.039934736414579675, 0.009582589464116609, 0.04178869552561082, 0.08243599761044607, 0.059892523495364, 0.00546852814295562, 0.03463881141215097, 0.03469734831014648, 0.0253258915108745, 0.06616164158913307, 0.07649552848306485, 0.04510008424404077, 0.02254277093015844, 0.02973516340716742, 0.018819642391463276, 0.005680768463207642, 0.020204387910780497, 0.018851083477784414, 0.06242543269763701, 0.034042362167383544, 0.03787124303926248, 0.028521219464892056, 0.053754413020215, 0.0795762799680233, 0.06911008298629895, 0.06583414666238241, 0.021293758654792327, 0.0551774069754174, 0.04435602924786508, 0.09177355124847963, 0.0240974367261515, 0.011140137576148845, 0.0167480892923777, 0.042626339054550044, 0.024947036254161503, 0.047502342058578506, 0.06315854101558216, 0.01287937364395475, 0.02140645377949113, 0.04628653347026557, 0.024099429392663296, 0.011248339924350148, 0.060643591787084006, 0.01830817462177947, 0.08642564251204021, 0.02874740937841125, 0.008286724478239194, 0.045244394859764725, 0.02651228878676193, 0.019238228524045553, 0.02025607849645894, 0.05450512508105021, 0.04216307934257202, 0.0863209848466795, 0.0333505729213357, 0.03280744327639695, 0.009144749237748329, 0.02009738134802319, 0.11531457203091122, 0.04106012544070836, 0.06356324156513438, 0.026084570527018514, 0.04900636740785558, 0.032287891663145274, 0.0246964148391271, 0.03086972723394865, 0.04370228991319891, 0.02946580647403607, 0.03250503294111695, 0.038041640145820566, 0.006300429304246791, 0.08217854658141732, 0.02815868403558852, 0.04237976419972256, 0.024378922207688447, 0.026506767208047677, 0.04791831583133899, 0.0412687320203986, 0.017521950794616714, 0.03220402155420743, 0.034399591240799055, 0.03853952846839093, 0.04929482536681462, 0.06391748349415138, 0.06346277703414671, 0.05328739804099314, 0.03899496223311871, 0.08611584780737758, 0.052813295551459305, 0.08858966350089759, 0.04904071771306917, 0.05849645836860873, 0.026474198057258036, 0.01796294793166453, 0.04897520462691318, 0.05996867526846472, 0.037075037325848825, 0.057461559408693574, 0.04738724237540737, 0.0735257651831489, 0.07947915510158055, 0.010652266391844023, 0.07121092494344339, 0.03920337214367464, 0.038525082563865, 0.04669487054343335, 0.029674344405066222, 0.042972068549715914, 0.02612452404719079, 0.002021608879658743, 0.03893952751241159, 0.00625015900368453, 0.019261608031229116, 0.05539025863981806, 0.08702658175025135, 0.03590248481486924, 0.022479085382656194, 0.030832454722258262, 0.0459209515247494, 0.03161075241223443, 0.02651350776432082, 0.012359702359390212, 0.03113500977633521, 0.04114121249585878, 0.03742413617146667, 0.022158959982334636, 0.0184351171265007, 0.012328446809988236, 0.03332654589030426, 0.059682532810256816, 0.023330208168772515, 0.04057887606904842, 0.01728540977637749, 0.05213713964622002, 0.09054441368789412, 0.061885713221272454, 0.048411977622890845, 0.0661320447397884, 0.023559342553198803, 0.028980423339817207, 0.007648734444956062, 0.021229035955911968, 0.07106536751962267, 0.05875598741113208, 0.030441433809755836, 0.03994053629867267, 0.07012658039457165, 0.031164543543127365, 0.02887659502448514, 0.03921500901924446, 0.017294560457230546, 0.09909871951094829, 0.034868205548264086, 0.03314005531137809, 0.06557691085617989, 0.04363887339422945, 0.02515532927645836, 0.013020518999837805, 0.05239807134785224, 0.020540614204946905, 0.09151561782346107, 0.06415198731701821, 0.061923102621221915, 0.014615867476095445, 0.01807401033147471, 0.06296334133367054, 0.044949502480449155, 0.08976400087703951, 0.024048338091233745, 0.05255502444924787, 0.03960958667448722, 0.018502164602978155, 0.06876371524413116, 0.0784646169631742, 0.04110009380383417, 0.03289929147285875, 0.027351737589924596, 0.03212488263670821, 0.019357380333531182, 0.04188433609670028, 0.07433455029968172, 0.015074100065248786, 0.04159310250543058, 0.017167738551506773, 0.06261764152441174, 0.01283771689486457, 0.059713721566367894, 0.05389811878558248, 0.05771508818725124, 0.03430281889450271, 0.03641507137217559, 0.019189768136129715, 0.039992816891754046, 0.09431061276700348, 0.025513122382108122, 0.07537364610470831, 0.043710650206776336, 0.010623677935654996, 0.019339273785590194, 0.016691244491084944, 0.02054449749266496, 0.03203575441148132, 0.05616809990897309, 0.11489241616800427, 0.13830368727212772, 0.15096408838871866, 0.15396184549899772, 0.14142113795969635, 0.09211810072883964, 0.1731011364609003, 0.06959501712117344, 0.13730719074374065, 0.17646894324570894, 0.12435427954187617, 0.16934996587224305, 0.1319597495603375, 0.11099400348030031, 0.1508191617904231, 0.09541481718770228, 0.11029821034753695, 0.2092915226239711, 0.11676604961394332, 0.23204384080599993, 0.12868174264440313, 0.12465866398997605, 0.056265948369400576, 0.12835573201300576, 0.10905289396760054, 0.06733470247127116, 0.1609508876572363, 0.16085494280559942, 0.1463536443770863, 0.09215664787916467, 0.07038844720227644, 0.1402811545995064, 0.10602405571262352, 0.12178572127595544, 0.1042139575292822, 0.07586530409753323, 0.11278468708042055, 0.11407913363655098, 0.1250686263665557, 0.12086465663742274, 0.1798465909087099, 0.14376674022059888, 0.0889447217923589, 0.07870365530834533, 0.17209359677508473, 0.16666950657963753, 0.16130866220919415, 0.15094451053300872, 0.09616187046049163, 0.1898673063260503, 0.10471680710907094, 0.10973190714139491, 0.1603192902985029, 0.14753279829164967, 0.27148061839397997, 0.09488894618698396, 0.2123734838096425, 0.12676349870162085, 0.10992148134391755, 0.10758426535176113, 0.1655798705178313, 0.13460491230944172, 0.14380448585143313, 0.15803877438884228, 0.14673522702651098, 0.1457253421540372, 0.1124530954984948, 0.15516059211222455, 0.1815516158239916, 0.11924163904041052, 0.20949659286998212, 0.06814371765358374, 0.16608840494882315, 0.1971645772573538, 0.13343335798708722, 0.17148706916486844, 0.20280387543607503, 0.07692284969380125, 0.15074071678100154, 0.15627942426363006, 0.16428865230409428, 0.17109965323470533, 0.1280442823190242, 0.10319328182958998, 0.08814356595394202, 0.1209964175359346, 0.20838536031078547, 0.14028082805452868, 0.15148092003073543, 0.08945695211878046, 0.09759490567375906, 0.142631744092796, 0.13161897019017488, 0.14808226958848536, 0.14646213152445853, 0.16315683256834745, 0.13106602564221248, 0.1062826719135046, 0.1358560545486398, 0.11962547039729543, 0.14048471086425707, 0.06563295042724349, 0.13051012734649703, 0.09489513569860719, 0.1818687652121298, 0.09409428414073773, 0.10659651874448173, 0.17177466623252258, 0.14676498714834452, 0.12448782901628874, 0.21348737325752154, 0.07977774337632582, 0.16520470002433285, 0.04272937141649891, 0.13455275417072698, 0.19978749041911215, 0.16970189230050892, 0.15294033859390765, 0.208217263862025, 0.18219067918835208, 0.09245214139809832, 0.13373230991419405, 0.197310913936235, 0.14944179507438093, 0.16118205181555822, 0.12088398216292262, 0.10494325120816939, 0.22518172074342147, 0.10709885624237359, 0.11414894004701637, 0.08218807575758547, 0.09025448627653532, 0.146533333172556, 0.16683055262546986, 0.17477343266364187, 0.12366482435027137, 0.14705623558256775, 0.1459656495717354, 0.12540045543573797, 0.11723947303835303, 0.22663468262180686, 0.1440921422909014, 0.20090072677703574, 0.15408624429255724, 0.151268457993865, 0.3076069423696026, 0.18513819290092215, 0.15098574425792322, 0.1143882010364905, 0.11229243536945432, 0.13061128207482398, 0.14108782459516078, 0.18524019367760047, 0.16141719388542697, 0.07891848479630426, 0.10874586005229503, 0.10903382077231072, 0.16926924989093095, 0.19298155093565583, 0.15979471063474193, 0.1768881527823396, 0.1393575666588731, 0.13736121909460053, 0.10154561750823632, 0.09412544692168012, 0.15247076691593975, 0.15422533761011437, 0.21715239534387365, 0.11527882277732715, 0.1458015904063359, 0.07546641456428915, 0.09798859275178984, 0.13406391633907333, 0.14808629202889279, 0.11068524036090821, 0.126309051993303], [0.0643273419700563, 0.06909449788508937, 0.0397069490281865, 0.013660801341757178, 0.031305763113778085, 0.04217629328195471, 0.028436037609935738, 0.032706756101106293, 0.06369968541548587, 0.014580155329895206, 0.07205548157799058, 0.004621088728526956, 0.0700028940627817, 0.031654980703024194, 0.02063264237222029, 0.05670417544024531, 0.027693813863152172, 0.05697925989807118, 0.016634039748169016, 0.022628661536145955, 0.027557993416849058, 0.037997608524165116, 0.05645584169542417, 0.02736663805990247, 0.07274127056007273, 0.019149582694808487, 0.036059170743101276, 0.02361151739023626, 0.0806461600586772, 0.061447604894055985, 0.011159997447975911, 0.04634981640265323, 0.033647769669187255, 0.034830482181860134, 0.06580942572327331, 0.03271928726462647, 0.01686569557932671, 0.05200992811296601, 0.02515345720894402, 0.008404886448261095, 0.001109159879888466, 0.08009512283024378, 0.03204007000022102, 0.01825991646910552, 0.05936739835306071, 0.08089273862424307, 0.07430368437780999, 0.009760442371771205, 0.008766668597672833, 0.021679860983567778, 0.08174131027772091, 0.03345674085721839, 0.0301738005146035, 0.03042590065888362, 0.030703742195328232, 0.0461471173184691, 0.019587689166655764, 0.03271174704423174, 0.04595425540173892, 0.03280353957961779, 0.05158530460903421, 0.07157551241107285, 0.025910336516972166, 0.03442236404225696, 0.07243110478157178, 0.008571919770474778, 0.042833865809370764, 0.04230477388773579, 0.09864612817182206, 0.09081710843020119, 0.05224921878834721, 0.04572342520987149, 0.039624307173653506, 0.018241206926177256, 0.03199715902155731, 0.021364218155213166, 0.04990320834622253, 0.03787047120567877, 0.08939982901210897, 0.01907365171064157, 0.059132497481186874, 0.015112282635527663, 0.023573296784888953, 0.05963935465842951, 0.056473508520866744, 0.0022475844980363036, 0.018972246507473756, 0.07083697899361141, 0.027897600193682592, 0.04421579302288592, 0.026505822825129144, 0.11718426467268728, 0.095945823850343, 0.009102435687964316, 0.05444066584459506, 0.10720653444877826, 0.05978594737825915, 0.08316432649735361, 0.040902808686951175, 0.030835441866656765, 0.0344145863346057, 0.07001036748988554, 0.03916264307918027, 0.14741659280844033, 0.059950559443677776, 0.12155958145740442, 0.02706271374336211, 0.01526046076833154, 0.014826375809207093, 0.05248298417427577, 0.03080377442529425, 0.0275288362900028, 0.030120850133243948, 0.06419066805392504, 0.02031422576692421, 0.01820595676690573, 0.02680198613234097, 0.08819802475045435, 0.04211973791825585, 0.03501430845062714, 0.1060598272306379, 0.02750853484030813, 0.02678906163055217, 0.09530451919999905, 0.056766345151118, 0.03712969279149547, 0.03142433975881431, 0.058826246531680226, 0.022732679099135567, 0.015040249782032333, 0.05592854577116668, 0.030632562811661046, 0.0958036060910672, 0.019129335050820373, 0.1094609712890815, 0.027510184263519477, 0.032000057108234614, 0.057766081154113635, 0.03413077793084085, 0.039347063066088594, 0.05149495184014086, 0.0204536808814737, 0.08105205546598881, 0.03496475153951906, 0.05026251543313265, 0.056946104450616986, 0.07523686086642556, 0.031110517047636677, 0.03465184723609127, 0.025006938703882042, 0.03514342359267175, 0.0338748334615957, 0.11609824287006631, 0.03325027537357528, 0.011194046255695866, 0.04561114197713323, 0.06557127053383738, 0.01108104221202666, 0.035389593977015465, 0.05118238892464433, 0.07878233038354665, 0.070186568191275, 0.09316154551925138, 0.039180287640192546, 0.06485396253992803, 0.022874562891956884, 0.043483556728460826, 0.04537225206149742, 0.010529473420319846, 0.01954327348357765, 0.0026379495375294937, 0.07041287128231488, 0.00818408174382057, 0.015179420097410912, 0.04715888724604156, 0.039309135609073564, 0.0211779261007905, 0.019825918570859358, 0.05849078836035915, 0.02489331403921824, 0.03783136002311949, 0.0265628884153557, 0.0626391192781739, 0.026896574709098786, 0.019714052796189208, 0.02146387931134086, 0.060729361794074066, 0.04358700098237023, 0.12389334646286443, 0.08702322724275291, 0.043293218113831244, 0.04891151351330336, 0.014114538371359231, 0.0962445382901933, 0.019887164307874627, 0.010495478418306448, 0.04486948782869149, 0.015046994976728456, 0.04077792378666345, 0.03127493801002856, 0.07133137551136315, 0.03041686872165883, 0.04501830699155107, 0.04666501023166347, 0.02207314730185317, 0.014431912259169621, 0.03286320083134342, 0.0351551866333466, 0.026876397569139954, 0.04729755382868461, 0.04617065453203395, 0.03645237171440385, 0.03789874703215901, 0.07479621810489334, 0.015556162088614656, 0.06174030793772545, 0.03238800367398653, 0.023473915789509192, 0.03693856378959026, 0.013127538550179452, 0.055536869913339615, 0.07087430160026997, 0.03466765127086546, 0.06661909399554133, 0.07049933890812099, 0.01780117458110908, 0.04595376187353395, 0.027168746237293817, 0.02302869026607368, 0.06133538103313185, 0.030390056781470776, 0.03819809229753446, 0.028549968410516158, 0.02700060525967274, 0.010172672009503003, 0.026600324199534953, 0.03064585467654979, 0.040037868966464885, 0.047762494505150244, 0.007502831458623405, 0.022484087457996793, 0.02615875560877612, 0.03391837155504618, 0.01725360874843318, 0.09731021040352061, 0.025889012758852914, 0.028781787514162716, 0.01793795239791507, 0.02906597626861185, 0.05935446642979514, 0.03069242444325937, 0.03892098495271057, 0.057893185075954534, 0.05213464974076487, 0.019870119031111244, 0.04414070994243957, 0.0430916730692843, 0.04368913905636873, 0.015372476827906212, 0.08109681439236738, 0.05975944899546448, 0.028048139283782803, 0.041232919684262015, 0.03015782578586368, 0.055356939919875, 0.02445287722366629, 0.012385346344672143, 0.03422758367378265, 0.03715725615620613, 0.031130571733228862, 0.05757821760198567, 0.04165971768088639, 0.056243628278025426, 0.03786851193581242, 0.06641100320848636, 0.06447989784646779, 0.004755555219162488, 0.031539491392322816, 0.043819300626637414, 0.03055973029404413, 0.08180874181562103, 0.047410441911779344, 0.02187263384257676, 0.07393417647108436, 0.03374452717253007, 0.044268140409258194, 0.038388735192711465, 0.033832208209787495, 0.013001073803025065, 0.018104829869116656, 0.0065253640605078544, 0.064709050784586, 0.054680550238117576, 0.041676137698232196, 0.02891118096158607, 0.03169185802107677, 0.09387651574797928, 0.05672719686117489, 0.012011557173536858, 0.06439486998715438, 0.043486540162120946, 0.06151310313725844, 0.009212324566760799, 0.03272670874139294, 0.03808893721725326, 0.024006638668652158, 0.019210240279790014, 0.004251938908055308, 0.041986028882092796, 0.04993306123651564, 0.041062607924686745, 0.046874581603333354, 0.02363303781748982, 0.011946052436542232, 0.017496740038041025, 0.04055794750456698, 0.050968591021955945, 0.03751775067939889, 0.11418842972489074, 0.04340706356742885, 0.014658323889307212, 0.01663323080720147, 0.03512186791340355, 0.03432686076848768, 0.02444590845698258, 0.0478546172962524, 0.025965468812501058, 0.02584580121038016, 0.03071495233598398, 0.07034356953226961, 0.058990932811866514, 0.03157715167617425, 0.04569571712636389, 0.040378837584285066, 0.01615384051547153, 0.04837472552026156, 0.11871805385453627, 0.01857861137978034, 0.04714595903351437, 0.037611610096064396, 0.0517765709082596, 0.06489763050922193, 0.009467491636314662, 0.11985183286014944, 0.02725543650740292, 0.018383623209956568, 0.029639877211593557, 0.05055653578892816, 0.046101887128315866, 0.049388035404263064, 0.0645525986328721, 0.03968429497035686, 0.09800718355108984, 0.12311817321460694, 0.11107523154350929, 0.06045130132406484, 0.09414128435309976, 0.12656004633754492, 0.19711895001819357, 0.10981324652675539, 0.2662029390921816, 0.06716513657011092, 0.1543156272964552, 0.13549335213610902, 0.264113288722001, 0.1797381928190589, 0.19648897054139525, 0.16014182794606313, 0.11674250868964009, 0.2286860827007331, 0.09555598851875402, 0.15281585074262694, 0.13216725405072793, 0.11410225153667852, 0.08510931744240224, 0.0866677904559765, 0.14527788647683337, 0.056377674991381355, 0.27870616817381233, 0.14781135600060225, 0.15957702387822792, 0.09804255430935882, 0.15000597573816776, 0.07957179739605635, 0.10223782606772147, 0.10100039129611105, 0.11501384637085721, 0.11731330931070261, 0.13449630641844124, 0.12701379542704672, 0.13090008142171428, 0.15060295932926238, 0.15722742886282504, 0.16705572023056448, 0.09378719085361809, 0.0705384649336338, 0.16182236198801547, 0.13253929268103093, 0.23695464682532474, 0.11517026883666404, 0.15823810041183606, 0.1320583958295174, 0.1887177344178781, 0.143781894876156, 0.16203222650801763, 0.10667059250408784, 0.05322922479535919, 0.13334329094504938, 0.09566012668074109, 0.15913649986032397, 0.10518792245420627, 0.12552479485748336, 0.15152544889133424, 0.21495909662917256, 0.13960355892777443, 0.14602767827454954, 0.1408964247093536, 0.13973776891361922, 0.1127843902213499, 0.149751894059591, 0.14868312719045207, 0.15752912673633546, 0.13186206808313727, 0.07293893417227082, 0.10051413613837212, 0.13456670654704794, 0.1076314807869494, 0.1412421467830427, 0.1521084355772473, 0.13914752402342856, 0.1722400521975942, 0.10957785212667659, 0.13425464829197153, 0.1122847170336172, 0.06371383817167953, 0.128069203638006, 0.1660510600777343, 0.18940623966045678, 0.10775818765978329, 0.1422457382432185, 0.25655080389697105, 0.1327886839862913, 0.157591110910289, 0.15474769083084539, 0.11788782809162512, 0.14636832405813038, 0.1848311664070934, 0.14063395676203072, 0.1795107393991202, 0.13581501378212124, 0.13774957013083622, 0.2036886935820803, 0.10598965716781095, 0.12554697023006156, 0.11972822074312717, 0.1729976513888687, 0.12737876881146803, 0.16760207450715825, 0.07958641028380953, 0.1991954940604046, 0.11521059714141302, 0.16025724675273523, 0.1851769775385037, 0.11028916356735863, 0.15339168312493712, 0.15249361022142693, 0.08754814087296836, 0.15863112697843462, 0.13924167287768796, 0.23739951982861385, 0.16701905813533813, 0.16113657300593331, 0.20886958198389038, 0.13355943403439596, 0.1190613565267995, 0.24530037946533412, 0.14863237913232297, 0.16724863409763202, 0.07415543295792304, 0.11469529432361014, 0.11069770102039911, 0.08112676747259684, 0.10336688501411118, 0.11524250207003206, 0.17205568787176162, 0.10600903464364819, 0.1877963580773212, 0.12648977979552, 0.2223601346486248, 0.1375484629534185, 0.10137216275325045, 0.06729188797180541, 0.17344218300422654, 0.11353500580298714, 0.23603623907547444, 0.1905304004321806, 0.12723433203063905, 0.07950963510666043, 0.18431996024446562, 0.12308774515986443, 0.15503120608627796, 0.17051378701580688, 0.20292343542678282, 0.10415930577437393, 0.1673092824057676, 0.12326235766522586, 0.13534484838601202, 0.13203524082200602, 0.17993259098147973, 0.12226753839058802, 0.18614453030750155, 0.13807976647512987, 0.17212144215591252, 0.19228636636398733, 0.1586147552006878, 0.11856280398205854, 0.10400902086985298, 0.1935420950758271, 0.08348857081728056, 0.1539064961252734, 0.08329672564286739, 0.10118071833858266, 0.06515120752737857, 0.08905243710614741, 0.19638842437416315, 0.18088884826283902, 0.2571186952991411, 0.15092518500750884], [0.01011282151011983, 0.057258403903688304, 0.04370090951852035, 0.05022920042392798, 0.05518979342014063, 0.03621751537139062, 0.048064366783364676, 0.02239430985355284, 0.021287789932102896, 0.08472650282783434, 0.013848002527083736, 0.006778893302907818, 0.03943105934013147, 0.026335590846429113, 0.043982751230942085, 0.0634979028836824, 0.020534576833597384, 0.05093747276987415, 0.027381837244320195, 0.07629433224792592, 0.09121164155658334, 0.08481392782414332, 0.03277960902778432, 0.07378234789939597, 0.002506458595235017, 0.04137909309065435, 0.045131284132367, 0.026103435920958873, 0.04559190550935455, 0.015609447364113294, 0.013182309048715979, 0.06239101188839413, 0.008163766378856963, 0.017767878125596326, 0.08392357325647026, 0.04332858516136184, 0.024907353617891204, 0.10372706412454136, 0.05245670101430733, 0.056883734359871596, 0.07427503005601466, 0.05466061986226123, 0.06775370420655236, 0.0425126123445807, 0.04219910690153483, 0.0246994910412468, 0.0860295063466765, 0.10524531273404136, 0.055103808190324344, 0.017903772786667105, 0.02835387444065418, 0.05356495013984386, 0.024236563440354075, 0.10599701185128652, 0.017798792287067045, 0.047083603785722516, 0.051456011351547204, 0.045554137614089996, 0.011294632313365582, 0.05665546086675022, 0.0372451041766908, 0.039154238256742246, 0.030607120133936405, 0.01895046076242579, 0.014569012910214951, 0.023943188753037248, 0.028862839317298494, 0.014357856125570834, 0.014399908995983424, 0.0112620279105613, 0.033862090785987675, 0.06625189416809008, 0.01802225295250537, 0.003169431406604417, 0.009540689661662327, 0.00794669467722997, 0.08058440595050342, 0.021953084506094456, 0.07079128496116027, 0.05659256756189279, 0.05207881797105074, 0.02946090644400101, 0.02892972537665628, 0.09130406862823293, 0.08947316062403843, 0.06834212341345847, 0.04282614005205687, 0.030801379143667873, 0.1317386340815574, 0.05840931167767849, 0.035543125777621754, 0.06141102814581245, 0.020872515633527655, 0.06625993162742816, 0.026039279109681956, 0.0010795699881782639, 0.01066916694981046, 0.03738588959095068, 0.015073252161528217, 0.022743289955542423, 0.0208949693114846, 0.024380150462093297, 0.05197838312597014, 0.016436934602097608, 0.05037463168264367, 0.08798728449619375, 0.020894329209113494, 0.021835927218489815, 0.015618379111401737, 0.05621042088023387, 0.0220599277963629, 0.01949866855284199, 0.030197128071449697, 0.03367183009686414, 0.049341031481162645, 0.03394608334929217, 0.005535418840736384, 0.06528367346618325, 0.03592355067667086, 0.06028351286659017, 0.03218654768716078, 0.05539371704799123, 0.016458124773635063, 0.00540888915566029, 0.07603304431540892, 0.0367133405234199, 0.024060006508079823, 0.07442501067998819, 0.0075124135128135094, 0.04293406687793322, 0.08324901296873577, 0.0719342814409174, 0.03180473126121797, 0.004934949010930723, 0.011533380293258233, 0.021473594024428166, 0.04245882519171573, 0.04732793735456653, 0.034770086203934625, 0.1411371774156578, 0.04779672235599719, 0.06761418786481954, 0.025114615054917522, 0.10433571427711286, 0.01807260952773504, 0.05686152559064794, 0.07417129265377298, 0.010196513503615279, 0.05148062467924319, 0.01653545470617246, 0.04913774238957558, 0.05779841281764675, 0.028257204139663372, 0.025514651206322014, 0.0753404498391319, 0.04602624372637365, 0.016329692407452967, 0.021831311059941072, 0.03563528196536936, 0.06687153552775271, 0.034581539875944145, 0.022922529751667753, 0.04850556986639276, 0.010230723728454905, 0.00824933786134352, 0.020554095317493193, 0.02933587496954715, 0.056483757580281235, 0.03971815174736548, 0.04097408826055471, 0.04563379232422449, 0.09915121161611751, 0.06252781939110719, 0.029731116846960504, 0.05751589575083926, 0.01607379988854518, 0.0797152248560451, 0.0061551311682706, 0.02740533178439364, 0.030494998318317812, 0.04243059389409609, 0.03972980717662722, 0.09820252424106002, 0.03507984751195181, 0.05511076211405452, 0.013999793063703692, 0.0219012640445726, 0.03847999709250871, 0.023236935048771556, 0.07177992214565165, 0.039684473085799254, 0.02849675827746978, 0.05602069453743752, 0.03207498062693048, 0.04478067872696556, 0.037662272807210684, 0.0690919448970817, 0.02731786596996244, 0.034068493187078275, 0.06466811391874216, 0.0625176148605533, 0.03276378643931821, 0.07979699468705803, 0.042051931595779024, 0.03588839143048972, 0.06220229857717641, 0.0051561405598476995, 0.040203200915129855, 0.01430954509487492, 0.020451346827030648, 0.050667535106185824, 0.013400968946370995, 0.016356621235900093, 0.09030775021528825, 0.08638251631055027, 0.07860883109970018, 0.021074502255942207, 0.021248435696179513, 0.01144542187830666, 0.07727992662694305, 0.08943542983615771, 0.008808354104985483, 0.03534020404913463, 0.009507885806669947, 0.06437010451918468, 0.017383735066687223, 0.04920077299175318, 0.04602516390150413, 0.019517181426635943, 0.021308122923073824, 0.013716251833102433, 0.046975914447102696, 0.07249528571264818, 0.01253123402420897, 0.0164291234978009, 0.02753862521785777, 0.026987485944118816, 0.0422324887040304, 0.01917748373671202, 0.01846019058575621, 0.02945257212559227, 0.037765037995995954, 0.014685943842778215, 0.04248476696375292, 0.039940246861078776, 0.04201175914204214, 0.04484104130824562, 0.0222740986282588, 0.013759742614638526, 0.12103258239221759, 0.028887948028568644, 0.024650123377796263, 0.0395686906267656, 0.01308471384618315, 0.03037321373994928, 0.11496156948851421, 0.04227225297654513, 0.07080771611072123, 0.025094157754210755, 0.05606633290881291, 0.011790409225795884, 0.039180491730803624, 0.009991977603931446, 0.016724670822441112, 0.03434658334299456, 0.08297822554595768, 0.03670139565656427, 0.048542513977736235, 0.04902872460661456, 0.047390040272148326, 0.06642065854975954, 0.02510586884454824, 0.020227515087754, 0.030069447129790206, 0.02356941535254009, 0.14416525868000463, 0.00999076604784932, 0.0415557836095104, 0.012065243208780885, 0.06566802432644181, 0.02204231477662688, 0.014681631964776898, 0.03201173851266503, 0.030500256434606854, 0.065244465804426, 0.017668986947683152, 0.0483028336748248, 0.039962370283319615, 0.03286438455688767, 0.03228863010008354, 0.08040394532145001, 0.048084586596814916, 0.10958531813230366, 0.08873744736774825, 0.04644311549782287, 0.004580699660436949, 0.019999104297312442, 0.07161065310356207, 0.05876169081602711, 0.03875976079143584, 0.04024925859994255, 0.09285672320402227, 0.024022793368203565, 0.002924571840594581, 0.011975926663581049, 0.035644540257635526, 0.021905240100750234, 0.04577608429826796, 0.023985177613212727, 0.005985684474580921, 0.027218822651775554, 0.008501264528604224, 0.045258109748829156, 0.046424261236097664, 0.06726873296429403, 0.015355890755017754, 0.05206101755902637, 0.025018946653290186, 0.02508309975382872, 0.050548268263810314, 0.03715741200721823, 0.027542373063624837, 0.030441008930210955, 0.021969623267068528, 0.035624546799226664, 0.00440441639511846, 0.04093837982509285, 0.07914117362815887, 0.03374430081748869, 0.007432902593791368, 0.030883375329722185, 0.12929107557283714, 0.010887139433179982, 0.09858570992946625, 0.021778189984615892, 0.027532489511941094, 0.04817773726244923, 0.0478966673836112, 0.0462408023304306, 0.05149101103597786, 0.02491631319571752, 0.04282780617359094, 0.051557711558416486, 0.013537175309465965, 0.02778019057586789, 0.05684934323653579, 0.04024168127216399, 0.060839711732114665, 0.04707410429546144, 0.024416970263700932, 0.055282476532738656, 0.011029934212274384, 0.13427529484033585, 0.23260566144017503, 0.12347986630629748, 0.07735668696113862, 0.1814347572508268, 0.0913557963212952, 0.15795767249073833, 0.0960077041236218, 0.26593597372993827, 0.11099352850578725, 0.06562766633578576, 0.17665090301306918, 0.1301445602439344, 0.09916317503666505, 0.301937498152256, 0.14814423891948536, 0.13509208773029968, 0.1598087520687841, 0.0793344214616809, 0.1098974357591942, 0.2339147060411051, 0.22302082419628277, 0.16698595834895968, 0.2561250189319253, 0.09695590168121271, 0.14540543197654188, 0.19810737197985873, 0.14488128275843337, 0.1548249929328449, 0.09949781684554182, 0.13930395391071215, 0.10651856355252676, 0.1407953887246549, 0.09459216133109294, 0.1910292127286084, 0.12568325822940096, 0.13978629052871838, 0.20437375525943935, 0.30764544499106705, 0.21211870451224968, 0.1415194576838985, 0.15090354398125783, 0.16810155473649502, 0.18523486505728215, 0.18314180080778897, 0.06869736724183895, 0.13796406565234065, 0.10771233777632006, 0.14230052358470857, 0.11034021590603516, 0.1213993072451558, 0.21053272008430213, 0.1839875226141885, 0.2572349749971181, 0.10459493161761202, 0.2336465532425791, 0.18395311664789915, 0.0938523885270115, 0.10373500510468148, 0.07602747820783406, 0.1406789754400961, 0.20514334755716845, 0.13509112293832004, 0.16816925344755873, 0.10814910652698018, 0.08417263059527613, 0.09783939138287678, 0.16508809378137812, 0.12974066863534972, 0.11299595425953157, 0.14207611297024414, 0.14549299055943266, 0.1717330762767233, 0.13087177590932697, 0.26421718939673156, 0.09091933927265927, 0.2158919020439498, 0.11093587105278857, 0.1765911452821456, 0.22216591460164636, 0.10282715069479309, 0.21865614980924875, 0.17921343503985554, 0.26420926325954497, 0.18014775443589315, 0.17607656976906583, 0.10736593292676844, 0.11432812418206595, 0.3662245563464239, 0.12423167674569413, 0.0697974898503162, 0.15961479919496924, 0.09452375757973641, 0.13360580342123285, 0.1896619243780151, 0.08516707879607566, 0.08550192098482512, 0.21664194617187604, 0.1419723458820954, 0.20228515873895958, 0.09253403739421628, 0.1654902784503065, 0.14238493546145037, 0.1622715691337362, 0.13128675520420074, 0.11185096882400103, 0.09656703856308013, 0.12336469240835868, 0.13406982383457944, 0.14889696962200105, 0.1369457648252137, 0.10494834976270795, 0.1419509868719615, 0.20422575616976246, 0.2879061276325956, 0.0815903945476748, 0.2105630442383699, 0.1424969849176705, 0.12626833777176216, 0.0967616964771878, 0.11174584360560402, 0.08990424452349544, 0.1480348315089941, 0.22255039162700996, 0.17576802929397672, 0.18519055884098634, 0.058986561562051065, 0.19968050241004676, 0.08347746086656116, 0.12152703828178346, 0.14656882267445326, 0.203985107364133, 0.1517359961871989, 0.1959317215369083, 0.0895029355888255, 0.10690684037399478, 0.10928805830189958, 0.13003601372474805, 0.2261699497466907, 0.15902589017059654, 0.14281812706030905, 0.15438104019267485, 0.30183448805473745, 0.1837353259907104, 0.10428058754769154, 0.06163123820442706, 0.14554621739080176, 0.16006955760531127, 0.15971350483596325, 0.06559363144333474, 0.17668590269749984, 0.22261293983319774, 0.10826992816873826, 0.08616871840786189, 0.12311634753132239, 0.2049011253984645, 0.050867284153355286, 0.21384351508459076, 0.13369107618927956, 0.14309530437458307, 0.1123134233057499, 0.1706703208037652, 0.14564287470420823, 0.1633498354931362, 0.17284914763877168, 0.08911546770832501, 0.10133080286323093, 0.1523819615249522, 0.10012040453148074, 0.1918836621916853, 0.13418124988675117, 0.23482872027670965, 0.12806944112526253, 0.13006442313781008, 0.1102404564153403, 0.09805461420910433], [0.041558774464647286, 0.06124325082055293, 0.013168262048566248, 0.06962823565118015, 0.04081341699929908, 0.027065763970313128, 0.01090425243091886, 0.02885117646655999, 0.08611937300884165, 0.00298861964893149, 0.024701112633920275, 0.04234573301800992, 0.06235457243747078, 0.03942542272852734, 0.012357158648228506, 0.040116109885275364, 0.007317398440136458, 0.0052420084375626175, 0.03243914135964587, 0.017240517263417132, 0.05888491701625753, 0.116748549771728, 0.018710863951127976, 0.02187814057833748, 0.009683689459052403, 0.022207720940059517, 0.01875119225587696, 0.04419551383762155, 0.03220274877094198, 0.02510024522052845, 0.01758409824105911, 0.05628026439808309, 0.04765925063111354, 0.024207152127928566, 0.01589046158187557, 0.02008504499826813, 0.029126773006282747, 0.0514405858120881, 0.0395866394683253, 0.07326485574594699, 0.11393610693630762, 0.09894577771774493, 0.07244807027745992, 0.04561240733892191, 0.029225794060039334, 0.006395123637048528, 0.008564073414163431, 0.05483459412062075, 0.049261376771028154, 0.023909582450869493, 0.03426834613492247, 0.0589772810053546, 0.029633520716743078, 0.057149545682477765, 0.009786106766114244, 0.03949515492422506, 0.04321835767768789, 0.019753856031456962, 0.07044318059342913, 0.012669316165556666, 0.03095866064541042, 0.07812761512468569, 0.04999755386961624, 0.044046924740541726, 0.04221950483042747, 0.05126737967657391, 0.03900695905031171, 0.045460805122274905, 0.011109068491350627, 0.03564391314284876, 0.02593082721432438, 0.06020343142154161, 0.010277851961291162, 0.02106254996760981, 0.023140097764553502, 0.0027369817235012306, 0.063760697375983, 0.028215632737556007, 0.0053802946695213905, 0.008124877840600675, 0.029286362587299664, 0.003652956388577877, 0.04878768988419324, 0.13080168748274446, 0.032112084300024435, 0.040240222951979376, 0.05071482475614175, 0.007700893047513091, 0.03581757940992247, 0.04193016000499483, 0.11740431888028979, 0.01713142526568845, 0.08330779106472619, 0.06615893275011331, 0.02034664463280933, 0.03641299335868098, 0.028648622101172805, 0.0315548315847991, 0.05626639736874495, 0.01161552583653247, 0.020850035980402026, 0.032068316140794195, 0.03365864584338851, 0.03234402400266845, 0.017573170116520487, 0.04360641927632969, 0.04584091831929982, 0.029037975036771968, 0.035433154334896244, 0.00791478511018795, 0.028440507194318343, 0.03685240044433158, 0.012686100762948627, 0.0369581639097305, 0.004930029035676853, 0.07074541281326674, 0.02922434316133149, 0.01688589127297746, 0.05211020339629613, 0.06122158381913323, 0.025812944477365818, 0.03214335840311833, 0.1261644222540781, 0.01196691420773277, 0.017809646196838003, 0.0217955840707873, 0.0532826928247232, 0.06580167028005235, 0.039636010842514224, 0.03388944263861049, 0.09014256298542023, 0.04652476287446916, 0.046825959798297845, 0.03783929729252122, 0.026141879170609172, 0.09257420984795317, 0.016244332437054254, 0.055628836853429675, 0.053094417380634695, 0.026661215561034624, 0.05377980931370985, 0.04221307041007094, 0.05314683527103625, 0.06092260591685772, 0.025335557984362822, 0.05209258109971415, 0.0271901293672272, 0.06097752855566796, 0.024560820747865364, 0.028814106190111488, 0.03571257293515373, 0.06962755287531763, 0.05085591816168744, 0.035243138554506004, 0.038791558108641766, 0.04637598824047018, 0.0256192717642989, 0.016646698932163417, 0.033715167810441926, 0.021793984742544126, 0.03524126463162247, 0.03835920142591931, 0.05179340281756595, 0.059710656496463344, 0.07543272105976939, 0.04612434080627281, 0.011975705874647247, 0.012959228733961936, 0.05848116270499304, 0.036827954099862836, 0.05254728013824206, 0.032718623042455874, 0.06517342742881738, 0.017254742379009258, 0.08249042672105134, 0.08581703688832931, 0.05345330515410751, 0.05293120426358655, 0.043764366855612025, 0.037371580983744934, 0.024787676738924347, 0.03279121621744707, 0.014064016668271506, 0.0647364731412381, 0.04099271245650016, 0.06958683123230003, 0.08528996360837482, 0.03373435974936001, 0.023623206216143444, 0.026958269445458427, 0.06510607752716169, 0.02225912579888245, 0.03511476556013804, 0.011944176658289507, 0.08221332362154499, 0.021438544245029334, 0.017529123651911505, 0.0177003371209139, 0.05653006388456561, 0.05369205777242314, 0.03746981907170266, 0.033366970674251206, 0.02578312312834896, 0.021292849523888435, 0.008749152984819375, 0.002085543742396112, 0.018886478355852887, 0.03171772928908467, 0.03665892254502978, 0.10571293998509645, 0.026650005420378875, 0.006293233254837105, 0.010985624285240192, 0.06532308150781319, 0.11538276055944152, 0.04673915078456048, 0.026766073606268037, 0.043205440597375855, 0.08727153501240537, 0.047172275590128265, 0.06857080879854038, 0.07393127467366867, 0.03928902711777482, 0.0948678023996763, 0.03984689581557177, 0.029122453706804663, 0.046872228995198384, 0.04174432993750088, 0.06278345957980491, 0.012717866538878297, 0.021169625179027207, 0.008701418973942054, 0.026489881493034773, 0.07140653280657716, 0.06588711374206468, 0.01759680195391411, 0.030298331039375626, 0.02841168960003415, 0.15250782977091148, 0.030329786968650296, 0.05579693701292854, 0.03910685954906512, 0.04544390641967766, 0.035899174836231396, 0.037468817172339186, 0.053920327554806136, 0.03390781450434588, 0.013596756780316355, 0.04132846006541513, 0.01753421292960411, 0.04306869246647693, 0.05884671125386376, 0.1043119358655531, 0.005548039525820059, 0.03701073394040577, 0.010799945430335356, 0.04575577913783491, 0.019172793363395613, 0.015228432457661256, 0.041606683807913214, 0.026308461638109293, 0.07095001550624147, 0.058440474458620884, 0.03313990317110438, 0.03482255604467355, 0.06421066893381067, 0.04566137424262706, 0.04225220385706052, 0.05508515801921021, 0.08311114419484511, 0.026266751083312556, 0.00497528056257579, 0.061456440162146464, 0.048105355599545874, 0.03369675512658432, 0.014765272935619578, 0.028818026585213374, 0.019767287049035076, 0.005417843167379033, 0.011687789683492156, 0.030006193883309606, 0.011715989439835539, 0.06828685567597859, 0.07573976981802844, 0.037885844794800505, 0.014528543597407406, 0.024440759807475843, 0.01170211035059765, 0.03716324157721829, 0.02683860184333753, 0.01470248631449067, 0.052833942099823616, 0.012493820504460018, 0.031232732071657665, 0.03651892751804553, 0.0380453286197735, 0.01990466971619753, 0.0487720083037857, 0.05826469307066873, 0.04618745304469485, 0.03847014137136284, 0.027638787323667202, 0.02464274086378282, 0.03364336873346474, 0.0280724186450243, 0.015582503692712635, 0.06949318703846075, 0.007746545797999715, 0.01427496843461995, 0.016532859044673387, 0.03432938035984989, 0.025443688900850248, 0.04570305325614754, 0.04572201141854748, 0.03164731060678605, 0.024943676180555485, 0.031735117809148505, 0.08509100865921937, 0.06297385756624863, 0.032710830491851084, 0.020063615484104957, 0.033870432525873184, 0.018659256857063156, 0.08035769467824139, 0.05251453287201002, 0.02096461430483032, 0.04790186241734773, 0.02784202075417852, 0.04247652912454214, 0.01705250713712303, 0.007903087935119402, 0.04903128130536061, 0.024854425500961952, 0.03158917817927431, 0.02051231982477475, 0.019286764982098248, 0.04434344984474592, 0.022828911532997154, 0.010834105560206808, 0.026360966730862856, 0.05031255102949217, 0.033218552271137014, 0.00883501483258442, 0.02157881943276152, 0.03535048650519457, 0.03389874917047564, 0.014814686055615311, 0.01106314624848892, 0.07179261287092231, 0.015887094086792786, 0.03434981539612636, 0.07297466858290136, 0.16261726152151823, 0.16516662784852087, 0.10636034508934245, 0.12091060300008394, 0.11169550372869708, 0.09282352693844587, 0.08157679098076187, 0.1632111132494174, 0.21507482713786885, 0.10015247273258865, 0.18025575176579878, 0.09679237686214037, 0.11148324207169935, 0.14772465830901638, 0.11715795553755015, 0.2073584357276559, 0.17071584414225072, 0.08052809920627624, 0.2018019463866949, 0.08510445637512021, 0.14407329173991457, 0.21516948065254837, 0.10358354760683142, 0.20588800369296223, 0.12598544592037797, 0.10068897870951332, 0.061892325757071376, 0.13193329941714182, 0.1518743028282188, 0.06568904194864444, 0.08702772465767339, 0.17498795787105337, 0.08158223834470846, 0.15085717459442094, 0.09809002207475714, 0.11744674746296369, 0.13250644522486255, 0.2112963900435716, 0.23753180023049936, 0.12399790764902718, 0.2449462711228989, 0.24386607517953962, 0.11874932795763016, 0.12590698606800288, 0.14954360289266333, 0.11229122566874139, 0.17376378527842462, 0.19564758287742734, 0.15063518338138238, 0.07868315718951635, 0.1419005950447172, 0.17210441728821024, 0.17159897019155324, 0.17605157423531637, 0.12193875954835676, 0.0985130610933993, 0.1042434578994289, 0.12930897617479786, 0.09528746464638971, 0.13241339474916458, 0.17012951779179275, 0.2095193025888875, 0.2346577146090567, 0.0939355610171333, 0.1376563118537888, 0.22150786709971726, 0.09454349128645845, 0.1670456418651156, 0.16789998742751777, 0.12699262937530875, 0.12397660801070742, 0.10616418803692795, 0.13434551685350016, 0.09849850015598349, 0.12527749640867114, 0.102733818202978, 0.19111890869680792, 0.07138569329981692, 0.10916933693806641, 0.10151625072467141, 0.0931670967838727, 0.08623359695775434, 0.10992675059242174, 0.2713525830768049, 0.14789468434173614, 0.1704896820592694, 0.11831305644591339, 0.12464082275982946, 0.1969347638078034, 0.14614282990805805, 0.16750841547036543, 0.1528449429315515, 0.1500855784979649, 0.22046054829843342, 0.14936014398699626, 0.06995122574153356, 0.10139933277969249, 0.11194332168088295, 0.0812160107307136, 0.09940811345586553, 0.21315658319508657, 0.13753860723227262, 0.10874408631934784, 0.14044006326003, 0.12192185342428274, 0.14481304970104247, 0.19585084228310734, 0.12035481602651998, 0.1619805136579089, 0.08764362559304573, 0.11269246038864367, 0.07816478188033216, 0.1143574167508632, 0.24951019731815904, 0.12131301031331532, 0.2089258813066408, 0.11676708119921386, 0.07898678464698605, 0.1604276438592933, 0.13274250755785033, 0.17946578009286895, 0.15353683236753568, 0.19166979007422924, 0.09199911961331964, 0.15590193826938048, 0.1793669705512002, 0.11651996086584404, 0.09426602453459054, 0.1834476992371492, 0.11187212745426223, 0.1731072666007094, 0.13712235144339502, 0.11910164772416465, 0.09312276088166982, 0.1563228844315745, 0.11346843515639193, 0.1904362070490606, 0.09737800559378229, 0.09922935234499164, 0.1270161257707514, 0.19138064933940768, 0.1805265317671001, 0.16791855596238747, 0.10727014392614365, 0.15885737811913714, 0.09170172619633377, 0.08695256736245938, 0.2673457871424034, 0.11829095528810285, 0.20627794292522594, 0.2035959844943136, 0.187779362895526, 0.1115223384113051, 0.10808300343342125, 0.09456718064029701, 0.20740097563248128, 0.10491607376025058, 0.08090831630397588, 0.12643548427149653, 0.12427159686922096, 0.12066986513673328, 0.1707181299570948, 0.12778142845490947, 0.21788474667118862, 0.22778798011131585, 0.1469234802061692, 0.1208278832200449, 0.06849017445347272, 0.15151893283473328, 0.0673418641963508, 0.09484866241109557, 0.0848506715556141, 0.22364479227690026, 0.17328380869003013, 0.1899680751375854, 0.17945972416782752], [0.033602175826672465, 0.03082168801483931, 0.009491196760791354, 0.017813410740927793, 0.031670851531089284, 0.04577396917738952, 0.01983851096156286, 0.031072669371496886, 0.01944343606737675, 0.05292465109960176, 0.024816659461066592, 0.06553287181304768, 0.16609548503765836, 0.015702037708251737, 0.07370904597337358, 0.05689570891263429, 0.03335855100885965, 0.013059326829534257, 0.09058307958184741, 0.0325479142338736, 0.025387040768691804, 0.03948523983126506, 0.01637837729504099, 0.029103623564878944, 0.03177335696818773, 0.04681865335442126, 0.023806060271454044, 0.03650583603302948, 0.07639587289304473, 0.0597482240118552, 0.05120321729918942, 0.025951948737201747, 0.024783132939774077, 0.027237044232606422, 0.013242165114206728, 0.03859165321046021, 0.023229886501212604, 0.026914289774140343, 0.024780481617199257, 0.018272612760483753, 0.007849876874388428, 0.019366184060345404, 0.013596420958492672, 0.16747665154980496, 0.05565157254750375, 0.02051152758212993, 0.028566778055392206, 0.022966681972320657, 0.039028863538987935, 0.07970690538058989, 0.06392329451045953, 0.054685459544998594, 0.08334880956681445, 0.04044622459332459, 0.06944670632947236, 0.01303880551859038, 0.041410471094422974, 0.017044477099261712, 0.03380897527677007, 0.0759495675447397, 0.03154169928166084, 0.05200246952881571, 0.05207429458096158, 0.02471560121193761, 0.019223027484258637, 0.07383230928098783, 0.03322387346997857, 0.023416692492901348, 0.02157296574296197, 0.054536952084163204, 0.06432933834730648, 0.04893922159681097, 0.034400233198539354, 0.05299510317854583, 0.058916168854921125, 0.07253265284816734, 0.04181808828434441, 0.062483268266078085, 0.015372615052910987, 0.025148564600385725, 0.044650227719102986, 0.05125747942656744, 0.006148422617116012, 0.027684186352416873, 0.027777036448242143, 0.014018689998920308, 0.04457243579963688, 0.015537093531747814, 0.019656625408970285, 0.014784919439989608, 0.07465244925697334, 0.09171445402898826, 0.036883989960188046, 0.021406342457339633, 0.03215389690012671, 0.018947837270388845, 0.04490722232731059, 0.0355433818185702, 0.0272881077034981, 0.03998685744591057, 0.04657633471651934, 0.013023840110690799, 0.034039861129713245, 0.03922904303180985, 0.013694684093934484, 0.020133729885856155, 0.08931522417697124, 0.033500123099656776, 0.03678653854876757, 0.06605238260817714, 0.01924745156429708, 0.06788283048081212, 0.02603026387077989, 0.034648949149413966, 0.08268038684036583, 0.06685044369078241, 0.018086164855048992, 0.04015201498987153, 0.05410602032497991, 0.01958408047357807, 0.035128899762639776, 0.027539402617549058, 0.07174527127062902, 0.0800273499044124, 0.0555708009051159, 0.013166512435418554, 0.044606136725633405, 0.12451801216229796, 0.022677181295875926, 0.071738725528121, 0.04180658870609477, 0.011689111634041183, 0.02558059844886884, 0.06315035512670875, 0.05820588528877124, 0.030986942037998233, 0.06353482473059557, 0.019997189556306694, 0.005604701109405141, 0.04386019296362065, 0.04072719799296465, 0.004950336979163694, 0.03612690656154882, 0.09914745634887367, 0.009197431518259691, 0.009294221490563359, 0.05371809602365829, 0.015374456506833667, 0.053067080370965414, 0.01665799441980198, 0.023841520087444223, 0.007196401465989766, 0.03911832201993093, 0.06579978522495367, 0.03665134521725122, 0.06371413503075019, 0.017837949853856117, 0.016812142202979885, 0.017355119707644917, 0.05477469909237698, 0.07724552808213048, 0.02098162247420987, 0.014646670315414667, 0.047409273029188626, 0.05142414724105038, 0.031680562533438206, 0.025622787688917015, 0.042090148490387946, 0.04513748477620538, 0.038053918979130685, 0.039215276192408055, 0.020597496113623492, 0.033013355860020965, 0.060581117795663886, 0.04040137289848644, 0.039693033759249374, 0.041481954758637585, 0.022041483571229037, 0.023551460944872815, 0.06772047825506888, 0.06512582607683726, 0.06980000573094003, 0.02043113072431879, 0.023001392219157424, 0.03266769686888438, 0.07091113438946195, 0.012197422493045451, 0.010829299226315925, 0.049695907946443185, 0.0591909193462925, 0.03297147646662779, 0.038858770712977275, 0.012574334250530228, 0.029564757023763377, 0.02925290842540562, 0.027445886444183998, 0.0443781786452746, 0.04705882347479928, 0.010311016685591312, 0.025678292913653422, 0.05158263287739828, 0.014812097815593006, 0.034356821270193905, 0.0076017379433324095, 0.031670510143158026, 0.08452642723568715, 0.0615258383913897, 0.03947331351810135, 0.07191002063336782, 0.00525483553246886, 0.02142310571798589, 0.04331465876020957, 0.02368337954976596, 0.012621287150977878, 0.026853606213990133, 0.05968332690827083, 0.042938950209645554, 0.02959071734949248, 0.06269983437960036, 0.0924208524520509, 0.014350343735713977, 0.04511108287260868, 0.038916090488783084, 0.0495367543771863, 0.061102034960640594, 0.02503840205463348, 0.016410640309914015, 0.06995763047598302, 0.02340933780942578, 0.0666896128677763, 0.022268159591476433, 0.01635831518797204, 0.02251279744086787, 0.03818491917627398, 0.058171186174149625, 0.0432961050682934, 0.02128957479726523, 0.03485526249278337, 0.03683604722027667, 0.02781740557111334, 0.0128184776440321, 0.07523317239247262, 0.05902936121856328, 0.05525732885871548, 0.0538405281258747, 0.030750222904316615, 0.03293062123702839, 0.02490976930857869, 0.03485404537059367, 0.031121831088967156, 0.03140447988698725, 0.03991257217421662, 0.06829573176219128, 0.037173234595684335, 0.03598249575588852, 0.0128189646784449, 0.05975308878987562, 0.061006168034509756, 0.07983054718351923, 0.031833062748773955, 0.0138229791627964, 0.05906451304326765, 0.018271911430929322, 0.018417448445688933, 0.02931284427177161, 0.009473398204136174, 0.03556210620445199, 0.03295770591648761, 0.06287168609560467, 0.010628854415699607, 0.03289256390416995, 0.05049538653111085, 0.02069688638584921, 0.08757724790484644, 0.054294518413371406, 0.015974582165654283, 0.04754232897539623, 0.013397419625107432, 0.031914609935483895, 0.03390742858755402, 0.03953367609938141, 0.02953672425064724, 0.08565041731344536, 0.07592467591166496, 0.05359409798984416, 0.04365213928394951, 0.011976634486927651, 0.08915545462514274, 0.015892680603428744, 0.025958030637411866, 0.04960738086083438, 0.037939687608741224, 0.020496398901741486, 0.03225806103728246, 0.051152847736375406, 0.04544083392829634, 0.019017333834199235, 0.06202354488777928, 0.06453659050748684, 0.04357549398264382, 0.03474859731795732, 0.02905902234488167, 0.06568085605977103, 0.07102329516783357, 0.02367324552324135, 0.03259803146647755, 0.07013098875177093, 0.03363916075613815, 0.07714755716733634, 0.06063273787731305, 0.03378361609065905, 0.06068074369977694, 0.013736826022068271, 0.029509303749364335, 0.012754318977385992, 0.013297264940774767, 0.05456181403133087, 0.05717186206311453, 0.056120227673090994, 0.05896494651096873, 0.034897282894235104, 0.04165858219494112, 0.02692362784728175, 0.061876866820966825, 0.02743034030572744, 0.04177670241915621, 0.050761535530909896, 0.029244017496239394, 0.01709534761175746, 0.0569029225880513, 0.03603938879678026, 0.08908293195418082, 0.05266199390462134, 0.04753019486088306, 0.0326171417691512, 0.02827380783855915, 0.05007858155295253, 0.06363604625221342, 0.0681325038021896, 0.06712458562105894, 0.07904405618319288, 0.049172682702192105, 0.045154550462029874, 0.019097526601399295, 0.09070618703844957, 0.09803139982977882, 0.00477633674563549, 0.010624151054798858, 0.03758277394808829, 0.01657596669247141, 0.04003665926575195, 0.004229730602673953, 0.15031974093290046, 0.08845963922794908, 0.06640530351432972, 0.14653993828687817, 0.1101388489769306, 0.12144546883064322, 0.09554509379086085, 0.11468394688563421, 0.10901601664954796, 0.16952828911598772, 0.1763548157759942, 0.16341260634362698, 0.28844264103099704, 0.15547827584668994, 0.18647591408807784, 0.11497857209178619, 0.14414490899071097, 0.09138005712884478, 0.14926088915672153, 0.09915980568621308, 0.10831204504938796, 0.18651098798727617, 0.13447864330373704, 0.08645746580441482, 0.14866976853227243, 0.13041210448136553, 0.16499933291925117, 0.10418745543574914, 0.17450766958063468, 0.23752336943289265, 0.12113842007238418, 0.14159776910673827, 0.2568001061445102, 0.16612325620371848, 0.09854614603682421, 0.14970933931181207, 0.16580766532570124, 0.10094723125803284, 0.11691147345118225, 0.11887061715242453, 0.10388158669229597, 0.14638137101428583, 0.1272955592139624, 0.24764369591139257, 0.20235742907971144, 0.08289241843158379, 0.14907322969520465, 0.10179244840401225, 0.2101161822793074, 0.23546625481685624, 0.11143138079205528, 0.11968324659392238, 0.08695985525264405, 0.20340682589448988, 0.13278957456350327, 0.09979909911635332, 0.14481187710771337, 0.1248722689342685, 0.15885945613263175, 0.14746220520464703, 0.08535012952052057, 0.15092203830135986, 0.10612326601403765, 0.10644921727362089, 0.12429915281245485, 0.1528481490095146, 0.1025257125729695, 0.1583163079340011, 0.1192139791965019, 0.12251755309989676, 0.17631319613428786, 0.08121704231598414, 0.1415545167401433, 0.134788014984224, 0.13380518881604075, 0.23065357556333765, 0.14676469028927386, 0.09720607966301031, 0.08672639785800129, 0.10801360520417802, 0.1125781844893936, 0.2078785328194499, 0.14658976608188823, 0.07040967262582853, 0.1505231932969764, 0.14028811594471335, 0.12472778762457892, 0.1553781155962497, 0.12750000605592504, 0.11312873190036044, 0.2768337295856327, 0.15855609584832564, 0.0989321964152623, 0.14899092551786453, 0.08671205214341171, 0.10072168515762314, 0.11180121524375863, 0.14701535808853805, 0.12476954085286707, 0.15405541547806934, 0.1405689149396494, 0.20790657115867361, 0.12592789978953078, 0.15420046081999317, 0.10511910310015082, 0.07662717063794844, 0.17502795963082463, 0.15969250205671415, 0.12999991566175595, 0.16532065317733213, 0.12145761778810993, 0.1765096723102033, 0.14935960964066908, 0.16605542390607297, 0.25108853762503713, 0.10630918142851442, 0.07974511114298366, 0.11139854817884043, 0.13760973466560245, 0.12355162456515245, 0.0995021361450199, 0.12516808899817988, 0.14825253310846165, 0.18929226062027737, 0.17078689736081287, 0.10662273882189766, 0.17990042630117387, 0.17297056299867108, 0.14654915576102212, 0.20464642031583935, 0.16944862698437646, 0.1308872867957689, 0.2405797116807662, 0.13292985531734303, 0.14899508154485375, 0.1978903086273931, 0.1826301493565552, 0.16590294224442914, 0.13806228147586808, 0.1262695697369054, 0.11299935329589061, 0.22977346263360232, 0.18408977572107688, 0.1867650548228994, 0.10379882238339633, 0.14369956101290882, 0.12389479365083389, 0.10687281290302053, 0.10930143922450952, 0.19887252623448148, 0.1600674499059096, 0.20890991028863937, 0.14131861767964438, 0.11954150380915962, 0.10384799708845094, 0.1743207819527015, 0.11411933577619493, 0.12301882190513425, 0.12865478784078732, 0.12824838777305558, 0.16811237524962053, 0.11263951557339169, 0.2283656975487247, 0.08306516814627685, 0.11736116299289279, 0.1181020712829195, 0.12420239901985042, 0.08085625464445911, 0.14140550832962617, 0.1980967295821756, 0.10099662860739045, 0.20320810843259096, 0.179875697940588, 0.11245171510381624, 0.12572846986586228, 0.08051638069446199], [0.0036473237196332775, 0.026876304800680373, 0.041503977990942076, 0.011908701999345794, 0.028446898941183463, 0.03462909298832528, 0.0465481924766209, 0.020484264787228312, 0.022783861313655507, 0.03321360214613378, 0.031573997548548505, 0.048478592798346654, 0.03472303775197361, 0.035041166775044985, 0.06941025203559548, 0.041132688929792494, 0.03155703205266036, 0.06824657932156697, 0.03701385467138607, 0.08155933566740714, 0.017585317218618002, 0.013667238545167493, 0.02363021394558018, 0.027467839172459207, 0.016260258926195092, 0.014209457203833153, 0.03241004917072132, 0.0674498021544423, 0.0497134560282575, 0.01864700585429091, 0.022723244546796195, 0.05263028564513661, 0.05169245589058846, 0.07803727348800749, 0.04574801627313718, 0.03506862623908091, 0.02723454133956693, 0.03667765064164996, 0.07656370216864161, 0.02722082830587169, 0.01263644922801177, 0.029366670387389604, 0.03275898845458869, 0.03592340224713553, 0.011375196154403966, 0.060761459681089036, 0.04686488173319958, 0.021741872988059185, 0.03697315158206038, 0.12269337530597113, 0.029910612684034277, 0.00959271235842607, 0.012485672650655033, 0.03551991510903463, 0.03111854151939042, 0.04083856467332225, 0.08570291684009135, 0.03996470804850105, 0.06573558945092373, 0.009654671484895516, 0.011598417477216572, 0.018652039470907766, 0.023459571930288803, 0.017115697301051114, 0.022792811614635866, 0.0174673769652145, 0.0069076104682608275, 0.01045613160385983, 0.01841637789766537, 0.05661621609760914, 0.046984519649413414, 0.0173396756144939, 0.053591352043440565, 0.01749965853377944, 0.02645100965310121, 0.04245691416144837, 0.05350875100702979, 0.017932041191670578, 0.03449239309702534, 0.015970346357789822, 0.015467283410544042, 0.005341263267837348, 0.02887532966269646, 0.02293229270435404, 0.035460090584820136, 0.0866120848513674, 0.004093757088412531, 0.08401269777095877, 0.03626069723395631, 0.00686242759002198, 0.030839252794976346, 0.04363632411696017, 0.04469969557248987, 0.047575510398019105, 0.009059104468178703, 0.02864309866708936, 0.025455147660977673, 0.04732015593617689, 0.0605203841405455, 0.03416990024561528, 0.033285813115071505, 0.026187107505393215, 0.009607260308257537, 0.06339786879834719, 0.020683902512246277, 0.02328520433366066, 0.04652465897379443, 0.04799340262252372, 0.032510821692994796, 0.042875570798059925, 0.023262986287591048, 0.0563023284485098, 0.009444210463698255, 0.033339644796797074, 0.006761513595847646, 0.05283733000396751, 0.024702177615836263, 0.03270962079113815, 0.010667264268704457, 0.06030199976521544, 0.02484698732587276, 0.03386181248060893, 0.02607592636195477, 0.036476884852163494, 0.01768603779055411, 0.06091100614867173, 0.04820765694603324, 0.022494948789244518, 0.038556178551516496, 0.03980019246228039, 0.04824277166335378, 0.045545346874860115, 0.017782166323740967, 0.008862041067914106, 0.0656773011723999, 0.03292591231002007, 0.05959985384833999, 0.04036560880194884, 0.05714979430194944, 0.010217869730695384, 0.02208059660915751, 0.05782868873211555, 0.006934028606337961, 0.021186471931287088, 0.02777581747068325, 0.012608019405888626, 0.07191541604697704, 0.023998256110644434, 0.03844547980406787, 0.023059613704390358, 0.017640343758102972, 0.010850970866158605, 0.03601338765292894, 0.013814868416375248, 0.04699001525295898, 0.07531529845437035, 0.03524694206134882, 0.03950657286623027, 0.03373696097696666, 0.024054251152847428, 0.028059419928467833, 0.08815207096631639, 0.07373357395408675, 0.04633859141904395, 0.03709053336933721, 0.056597413786221296, 0.06264873751206324, 0.030281005601864308, 0.024641230593260843, 0.12043215523590334, 0.041538012883393094, 0.05252789153018966, 0.09879809033009224, 0.03460351857938804, 0.03567162864783313, 0.046817180191283114, 0.007224597511594766, 0.038825633819215, 0.06275735082454048, 0.03255745083151851, 0.016144376277225092, 0.03419048371142708, 0.04284259346604813, 0.03406966949114576, 0.025422136932320427, 0.026200809406873304, 0.05209999515500385, 0.06923260414623655, 0.02569104115536902, 0.008326065726578236, 0.05167221752344631, 0.019827128271572292, 0.018511780981498305, 0.04479454946704209, 0.05293500405969098, 0.05396567277784925, 0.057313478682772256, 0.04688316454121377, 0.061970325477886945, 0.027511996959219687, 0.016524248276255094, 0.041612331551732495, 0.04100272031791974, 0.013080832413834287, 0.05711265723221004, 0.044048861745977774, 0.010864345294976374, 0.04569291551888455, 0.024985607524286024, 0.02067051231279038, 0.054016001522541046, 0.02872079781809589, 0.01696851457381854, 0.05533864597964566, 0.08583230286603794, 0.012181118436274119, 0.004067283289259649, 0.03258062068198342, 0.05372193663788494, 0.06963455874938518, 0.048716840756242163, 0.04941544662870001, 0.03622374941187445, 0.057002622706932016, 0.04849686076340731, 0.08351268319529481, 0.0423131378920516, 0.019199892885808367, 0.007391673507299856, 0.0533236816409044, 0.01821401277993573, 0.03054170352697838, 0.026191113247477915, 0.0626213003124576, 0.01895485427667154, 0.06560285633895546, 0.06191751053847838, 0.0062716622687730705, 0.044746265339199454, 0.01461935649786028, 0.03578093215764966, 0.0321739942592103, 0.06815030792495236, 0.0789427307609003, 0.040562344729551114, 0.07176499755587429, 0.04868724019615911, 0.032423778902739286, 0.09324514845502563, 0.02108050623064628, 0.05534318792342674, 0.06512141771963798, 0.010587334963929607, 0.08370691808522679, 0.011548767797648907, 0.03699864806549158, 0.042476202579564415, 0.047041197467478923, 0.07714120438322425, 0.033687155446386896, 0.021507641904463526, 0.09582681304891594, 0.020373172701511066, 0.03609296814829577, 0.061013352024019696, 0.009227033006027341, 0.04433724549016915, 0.02915433080488583, 0.07319781012483872, 0.03242697013774887, 0.08737245967495255, 0.042812959509319626, 0.08181752884411253, 0.016093579979497008, 0.07025361381238326, 0.027001312155334745, 0.041246393375331536, 0.043634153335005976, 0.024370634273509495, 0.05373142128519248, 0.06321754917735234, 0.0019448650118647492, 0.024439726366836112, 0.03059141443372937, 0.021943733445368707, 0.022427958829212002, 0.02671919770364184, 0.026424698662594892, 0.03260180899815168, 0.010363427154516103, 0.07131692589609884, 0.03803006264206488, 0.030348247892106883, 0.014720746858074563, 0.02011630425840849, 0.03657375738839619, 0.05919026254559867, 0.009178066102322191, 0.003188953601238609, 0.016996636404655874, 0.04734614965855144, 0.03847531414066907, 0.013322832855919842, 0.033238705291296355, 0.08439825833193026, 0.048895679792622104, 0.05345042562112212, 0.002564595661169733, 0.027616079460131004, 0.042310666540288366, 0.05733943900850136, 0.021591447075479664, 0.050773814364220016, 0.028467141019064002, 0.10210543434368446, 0.023876406594354194, 0.022139101965876762, 0.03719361397088505, 0.05687566350388806, 0.013954670484963572, 0.10638062056386843, 0.04869510325079318, 0.08125518128508702, 0.011501900244184071, 0.0628581344790291, 0.06195035428390838, 0.031838617724133655, 0.06739189237123355, 0.027892484940821305, 0.03753762910491787, 0.02675703239219729, 0.005487087400979362, 0.010406532946944935, 0.05088423851702828, 0.030005800545040984, 0.08101302591967396, 0.03799319645622745, 0.05249787907814607, 0.07181283639511093, 0.0420151099388022, 0.04889822164841462, 0.0821196794277057, 0.0799083019956015, 0.01986880728509277, 0.03180673134920653, 0.04423399790539406, 0.03311672218842432, 0.018773028095893096, 0.07409097743220627, 0.032426357865915634, 0.03819309393293224, 0.10780339187476784, 0.06722368460032158, 0.1021328715432901, 0.17123816767707467, 0.12634938029805198, 0.0776263017905876, 0.05826579887070693, 0.09731450001709163, 0.10577159191598184, 0.11219909545616247, 0.1636983925709501, 0.10154210714972578, 0.16078181157354265, 0.12932533310959116, 0.13902135891839862, 0.21429531974717975, 0.10817681832122616, 0.08283591130748391, 0.19096143980277702, 0.13587793306214735, 0.15962815785314888, 0.10270958708133548, 0.13637576572364196, 0.1465547367115505, 0.10925747439614497, 0.0869234158017207, 0.10019162844400853, 0.11478619257104583, 0.10666742353350855, 0.2083796457736753, 0.08702328661456704, 0.16140597261255607, 0.18832892325008288, 0.15023774845758453, 0.16811724373837933, 0.10841983457794413, 0.14538030285621062, 0.060987655160715804, 0.18408165662549436, 0.18472174415364861, 0.0648553651990369, 0.1876059378264472, 0.09952537278877571, 0.12135134224081412, 0.1586518922704272, 0.15770093392347917, 0.15736327157355845, 0.19991502107586712, 0.19250767480116338, 0.12093251119949855, 0.18244925828184932, 0.2022926099016331, 0.10374679040978663, 0.12379631807561964, 0.0939823014778085, 0.09256908902898431, 0.1595890466705896, 0.21548562071984634, 0.19110737572191283, 0.1407640107208863, 0.11365890735760331, 0.16567991202464327, 0.07702118426095694, 0.20347351528471336, 0.11126464247354306, 0.16157892270712182, 0.17393713613273576, 0.1324881290202029, 0.12816243222914636, 0.09563033687300049, 0.17985499202040955, 0.20068974903551862, 0.10574405823717825, 0.2316224345122464, 0.06694750176393427, 0.09173200582154095, 0.13457046181429178, 0.12838474998716265, 0.15576711972244084, 0.10986060297000222, 0.12651177705265582, 0.22166006674524397, 0.08596749990829267, 0.1452569430693984, 0.0756245365482755, 0.10923358466243371, 0.18903164804214612, 0.11389580089598894, 0.17765545926522464, 0.1648306130664423, 0.14904063456924632, 0.14903398492606357, 0.2385533368214965, 0.16523990751011297, 0.09573290910338983, 0.1443511518300511, 0.1184563132119365, 0.2546039130538702, 0.08866536998539232, 0.21080238686408848, 0.1140500266046729, 0.0719245889922604, 0.09345107959234156, 0.08144944586092606, 0.17187399527756497, 0.259487007278949, 0.10656654339982197, 0.10692256648326293, 0.2147994309780188, 0.09655762813054025, 0.10070630043628626, 0.10699602426029742, 0.19706990889972076, 0.08109463247819804, 0.11360149481333792, 0.1210642943624407, 0.18673924292670563, 0.09370828571263701, 0.06815966640715487, 0.11307560896966606, 0.142450571001973, 0.12712651281617582, 0.06278700704569928, 0.13410561019554734, 0.1216657976328861, 0.18358572386205196, 0.16864725592313334, 0.19392493937630206, 0.06873696824186482, 0.2145548487897031, 0.1967542734928429, 0.14661559282103553, 0.08663311731652357, 0.09281882914365269, 0.08755745482631028, 0.1511953119188547, 0.16788560460554436, 0.13885301013942808, 0.12033232153044082, 0.25154644274152815, 0.12487078463891521, 0.08436150717898272, 0.1621059959870763, 0.18190611008321866, 0.1557051800773479, 0.16790650348411873, 0.13765576266450807, 0.1436477294191718, 0.0815407522895839, 0.11564452346647158, 0.2806926006451249, 0.11558485479326919, 0.15002886357251555, 0.13726203847909346, 0.14161163242533803, 0.11097898983280174, 0.16497328353580087, 0.11846910783788189, 0.13481743371812627, 0.21349621965782717, 0.10361517051933333, 0.13241573993582278, 0.15177915949607268, 0.103290525439661, 0.18928820849396288, 0.10044352078693919, 0.14264749246649444, 0.2066228783223778, 0.11247700749663636, 0.1225284329848364, 0.21113863913342357, 0.1202338162693195, 0.12502034223871306, 0.15545138041488826, 0.09223914501490071, 0.10782875106087886, 0.14336082997033373], [0.090561260440154, 0.07112878403859213, 0.038382746060960926, 0.06806968100136146, 0.047802752305869944, 0.02431001194054261, 0.055097429431043565, 0.025246633849747013, 0.014961655415390851, 0.06709814289934002, 0.04227502489811741, 0.01637290024518734, 0.02445423906465294, 0.04040215957502369, 0.0234377286687959, 0.015815647529962007, 0.059687913380912505, 0.021293035060807597, 0.02029017461609328, 0.0609189137321664, 0.03111866768449545, 0.05171925113245379, 0.06250090169487521, 0.030083811398071703, 0.00880237703313469, 0.045729510820819996, 0.018787384942697827, 0.015060149544297019, 0.07609753694850951, 0.06866404481115751, 0.07078026406816207, 0.029454336581693497, 0.014460843030974502, 0.004096981256225263, 0.056089736535795964, 0.0425667260424234, 0.009040181557793403, 0.04248768360412214, 0.1290899090236053, 0.010245466492051492, 0.03234468080336228, 0.03918931215594057, 0.07378038120805286, 0.014635281131631928, 0.029618508924613707, 0.04007653857115656, 0.022706707641191315, 0.06592891149921343, 0.05908311126404442, 0.018548077568993904, 0.009372668355354108, 0.01600670046173036, 0.06275438965531066, 0.04499029091675766, 0.04746547587274108, 0.014488553897535894, 0.015098844196472783, 0.024986503667605575, 0.07676362933125347, 0.05953103078354616, 0.025124966159637552, 0.01940601327078184, 0.012191989972052397, 0.023920087551232427, 0.013118620718159946, 0.06352941447403282, 0.006773315135433222, 0.028930441549164243, 0.012409006940288236, 0.020717584884550888, 0.06742321100318804, 0.046346721646841615, 0.016538822201255243, 0.013048239143245155, 0.04030802556371782, 0.023936255238368176, 0.025902944726112764, 0.059381591927376576, 0.06377845696988516, 0.029132131312508136, 0.031125389687076677, 0.01988438867556397, 0.01714770056423731, 0.06795413602958433, 0.05930589286435861, 0.026135043990507256, 0.048055345978355035, 0.07243439991725609, 0.07210247436887585, 0.06854377978015691, 0.04192777028947603, 0.02574091347923968, 0.08646404123282991, 0.03249704372137785, 0.03336738627695013, 0.05246358814474661, 0.030679601986776106, 0.028684221069852356, 0.015594767683069222, 0.08083290667855181, 0.02817764219798846, 0.03351742998347618, 0.034682857876759954, 0.02857442403183086, 0.031796615876373835, 0.07328999228775501, 0.06732997499057092, 0.12420159750035964, 0.031136690740822814, 0.07515291654272005, 0.06756841961760074, 0.017834652862802614, 0.03477953374385834, 0.11505577771458775, 0.007303585216504871, 0.04455271322512999, 0.02855404651199933, 0.030786890565650538, 0.014800715125602437, 0.06680256032268517, 0.0682009372394532, 0.02752767482888885, 0.00884826309629716, 0.06032953715475742, 0.04984640807379037, 0.07738560103462078, 0.05218270009208936, 0.010792665889312048, 0.030932299559935927, 0.06526395460241474, 0.023232513703987934, 0.0941844996123109, 0.06856318694190122, 0.02175750632886775, 0.04603878602210898, 0.042144046965404414, 0.027143500228703488, 0.014454919764830265, 0.06116211552580353, 0.05009457854612265, 0.07091457053320482, 0.02805331205308903, 0.024714838655199856, 0.06792847998440266, 0.028753890182997566, 0.13536032958654687, 0.02831928664818406, 0.06969702531932853, 0.055481101226178, 0.0027251922438153997, 0.03783508189371787, 0.054236794167081825, 0.010510400225030025, 0.031045478935993742, 0.05624067453027237, 0.05627016747894231, 0.025607076422602404, 0.031200667581288144, 0.04206717901979573, 0.0517256892635487, 0.02095495154208038, 0.054740556588512845, 0.01485642722400371, 0.07445457042194903, 0.05252134578768164, 0.04334922428824939, 0.026512390832067467, 0.06178307048685383, 0.07326163482503034, 0.05498722421179991, 0.04782133939443156, 0.041180991611327045, 0.023032308235997334, 0.05975157109787688, 0.03920641494914889, 0.055867463306640275, 0.041483324021101, 0.031579793721903116, 0.03280543205619324, 0.023507442310801707, 0.019901584237231873, 0.03419089560338762, 0.04735179740237072, 0.06660690050921403, 0.023001785557426047, 0.009812257267185487, 0.04432089226611424, 0.03039927611098392, 0.009891542758850846, 0.0813514378387481, 0.028410535560396966, 0.030613628769060597, 0.02861565961211454, 0.07688330064411275, 0.024181488661270123, 0.08720350975636393, 0.05676016677170992, 0.10003979987232015, 0.00553094229871931, 0.01882177049992606, 0.04251599282724783, 0.06988947163335979, 0.021989453452988528, 0.07625990401720628, 0.05674092288245447, 0.04221346745907795, 0.05042605509515852, 0.07529084468842484, 0.0559823440562468, 0.04342313848610502, 0.017816236468206625, 0.03155249753035605, 0.08149060537107289, 0.047653027722844854, 0.06919957857462578, 0.023544369723822456, 0.01896638910693582, 0.020977965541533194, 0.06819980175350793, 0.011811164313257905, 0.05833249568240717, 0.07785729525494389, 0.023189181556517724, 0.015753468542243354, 0.0378550827736035, 0.028495812039182056, 0.03602762946684379, 0.07245207045343705, 0.04866255265369546, 0.034490604521124624, 0.08733447655686177, 0.02216654844232835, 0.06357184305670671, 0.007926251291792141, 0.08076569778495468, 0.05517711382708512, 0.012318361950747203, 0.1024290404166095, 0.03452899953117594, 0.06450670422054827, 0.03756732985493727, 0.02772555366391316, 0.03526638261973858, 0.033865649384097196, 0.02616700829094043, 0.030821420841675717, 0.01436567186829052, 0.011525953250384191, 0.035652147271321155, 0.044368048329488374, 0.054293048960971646, 0.023016634077066556, 0.09181113360682502, 0.010688522161217406, 0.020265295970602892, 0.04009456533822231, 0.012629599204956321, 0.03066465513256844, 0.021198689537413884, 0.06651050294749439, 0.02115412356943125, 0.059189075109316036, 0.009562097839079797, 0.04901944404991809, 0.05028754807426594, 0.04732031549792737, 0.0630417195498012, 0.02848622163583059, 0.03953631814511027, 0.044354689671308734, 0.0635736390540842, 0.014698994509672048, 0.05388436678913422, 0.022727190917066764, 0.023246710989042185, 0.03396333457203582, 0.005046048054282437, 0.008072797627391992, 0.049100271353381686, 0.02981815592647763, 0.07632890148670413, 0.08531023908290081, 0.07522225540014915, 0.02564364574936917, 0.025760543285286985, 0.05477891449118033, 0.0036274554986448493, 0.035041994269704446, 0.016608072000963148, 0.008566319338569883, 0.04973795803380199, 0.04563430440612137, 0.05023184246965684, 0.07838804958737455, 0.01865697660832666, 0.022419793349399697, 0.09140755370026454, 0.026246872657793574, 0.05192172757233493, 0.0013791155174658343, 0.05342860647942871, 0.07310174652957357, 0.05920628551393747, 0.029006092372583225, 0.03902411750459578, 0.03450806354521774, 0.029245614969113376, 0.019391892055864446, 0.04421683945110999, 0.014858755712339189, 0.07746717790723778, 0.06517049594549462, 0.01097136298994883, 0.02630747087096097, 0.03234175303077791, 0.003126881529169623, 0.01737770697218366, 0.05393754538090434, 0.029003283343627118, 0.012521923781605437, 0.015927418680803385, 0.03783180902246386, 0.015410137111757649, 0.05383413452364039, 0.0675906914693769, 0.04397169694129843, 0.08515584268025123, 0.05980871275824029, 0.023986769519979134, 0.032473569590365514, 0.024422710775979795, 0.05698581677279435, 0.0774306345556397, 0.026245839217153843, 0.046434087271336466, 0.018887391197495162, 0.008190087573893834, 0.02822277405357454, 0.022807927307439968, 0.04625913337804377, 0.042271406928193755, 0.018973298501805402, 0.015086869643710088, 0.016654291102895513, 0.03578160751203541, 0.009169318964268314, 0.09115045148064382, 0.028409524384187534, 0.03863651232677512, 0.06504326214781031, 0.11815189165645279, 0.014302564268291462, 0.3337490645935759, 0.1785162911983207, 0.11581668688450009, 0.1727932193898596, 0.1115706522250548, 0.1550938285072334, 0.1414122767164372, 0.1034477271605283, 0.06600909313419834, 0.1810245870728977, 0.122292771411594, 0.13185034214984626, 0.12096282793208957, 0.1477923570200801, 0.1125126528495457, 0.10794534246088006, 0.14164802734740078, 0.10486672836123034, 0.24286165251396596, 0.14925913768820465, 0.26875085080973804, 0.1784140826202929, 0.20513671275693923, 0.14566785539500415, 0.11382246928405948, 0.10317072054021992, 0.10050039898487739, 0.22565060964552686, 0.12369496296742, 0.21141173463547602, 0.24821906816214323, 0.13551300420658663, 0.11168905446538702, 0.13975230016512796, 0.08504427562002093, 0.182422065990977, 0.2029463677899912, 0.1857202296378091, 0.21682752761989832, 0.08982416678918526, 0.08778798073763028, 0.15689871681388468, 0.11163193878019229, 0.07294278591871262, 0.17524672992294654, 0.2234694969956763, 0.1049154280917719, 0.11347024599672295, 0.17093949776608497, 0.08815597466309555, 0.1369657731265761, 0.1324124151142314, 0.17898696125485003, 0.17062738013919443, 0.13846235844539478, 0.11558149286429398, 0.10996125303790905, 0.11755299332435243, 0.2198987573501654, 0.20454471639823169, 0.09058399242348969, 0.2027132295188494, 0.1605879922863096, 0.1158025860786438, 0.13469168421579525, 0.20075222302693874, 0.12505409511504695, 0.07766196198645048, 0.07799169077770784, 0.10107712936587632, 0.13144937460310757, 0.14639603585237637, 0.11026845764718018, 0.1034057216020301, 0.1278251557960175, 0.07673981381230988, 0.1714661851292476, 0.10381342784967273, 0.1404802579781972, 0.12472559086745605, 0.20027638762257993, 0.10838316506124102, 0.04742591940157581, 0.24303046142449602, 0.19596762664150447, 0.19245429954025894, 0.15368915075669065, 0.16153982636751607, 0.19940197438700125, 0.17568769922945648, 0.11832468590000644, 0.09363260891404934, 0.13206550560425967, 0.17743315635016188, 0.09256871053366922, 0.15593154996167868, 0.15944364509778097, 0.11277592231635936, 0.11032693888409995, 0.1774820193531923, 0.13719460694119334, 0.0774517709214706, 0.12598575762240216, 0.1880061929114163, 0.13267118716612458, 0.22337824251735583, 0.16919218527618796, 0.22185979352798313, 0.22478244529338554, 0.15667443978600204, 0.1646675038500689, 0.21470022067660466, 0.0809894033591263, 0.21649158705258742, 0.20448057999601588, 0.16418251034338027, 0.10004806739743799, 0.11732688319170848, 0.12750748690450564, 0.11242555439821444, 0.27752763766329736, 0.10463081445777789, 0.15550889685982838, 0.1475419563939795, 0.15953844704199582, 0.1697418198455125, 0.1886750609264709, 0.12630964571144432, 0.19998821167973801, 0.17797842709114775, 0.17425315745640546, 0.15344716608524323, 0.1712270948337391, 0.18835632334230468, 0.1710824650945142, 0.21392169292084873, 0.09266759429010563, 0.13248729781480506, 0.10499513475224376, 0.10757604977698065, 0.23705865140073, 0.1862254540901631, 0.06796796966227703, 0.09927603343385272, 0.10918133004452102, 0.20363770803669468, 0.093441817589337, 0.13706789264688268, 0.14132174954283983, 0.09573621908202767, 0.09708962184959091, 0.24550392088713124, 0.11289391637546942, 0.07575188166811131, 0.10444391940836795, 0.18288565595867112, 0.15496500651352108, 0.12759635166730732, 0.07959407666930929, 0.10279989161062986, 0.17947897547855973, 0.18725104280747473, 0.11134144733659923, 0.25824100070167333, 0.10386284746346064, 0.0908536666247528, 0.11055523835239, 0.1834050109027885, 0.17316641577053815, 0.14438861544476822, 0.20335098670329899, 0.1264653482940048, 0.07258053621626459, 0.15380379772977903, 0.17195992113556713, 0.07556996642961167], [0.05019109485147055, 0.033611942490097135, 0.05524618180061225, 0.015360360339400358, 0.03705446499225218, 0.056262560465256684, 0.016769255344115663, 0.034658645308809355, 0.03302226905361749, 0.03458447507000528, 0.03543894308677409, 0.05308064311975613, 0.06304370108409785, 0.04055004734254908, 0.07937305766972713, 0.021192026906646788, 0.0685727977543138, 0.0439201584958937, 0.04876813058217522, 0.038927853529457934, 0.09427159064216539, 0.046616447798442096, 0.012395972971717129, 0.04573197475110646, 0.05459270963910967, 0.028039573044225108, 0.006355864488796215, 0.017415144611732103, 0.03576172537577804, 0.0612853305938188, 0.04109647583391052, 0.021515419612114783, 0.059543858806136996, 0.05139200853591319, 0.014911209782439983, 0.012931454784848029, 0.01630074122658698, 0.03801625869527925, 0.015815142869541887, 0.0259899819502607, 0.007206563786894549, 0.04469541338039562, 0.015378675616375403, 0.06690413065371104, 0.006352481223075301, 0.005422011718110298, 0.04911228301352821, 0.0233853200552403, 0.022914789151400328, 0.023217550151457544, 0.09634534420911223, 0.05803300198749639, 0.039309803541982546, 0.00702593153619091, 0.01494591539085377, 0.10988439622451551, 0.06301545494352467, 0.020017305469082203, 0.06402137674740516, 0.020006774393550586, 0.02457526294165291, 0.03067277793888934, 0.027809609309770167, 0.015401347300212365, 0.007770877573420876, 0.0414038251619786, 0.058441613655304536, 0.02798128847643966, 0.020114476719754748, 0.004327425067458535, 0.039148568248492666, 0.03398600347281899, 0.020975061888748314, 0.05448220756079536, 0.02356237979256548, 0.027378519844205584, 0.04714600356237497, 0.016823803198349196, 0.031092117351363413, 0.06706084255711176, 0.05802053761726711, 0.045068401959724724, 0.020878953764622565, 0.08103502317680977, 0.015240972898027394, 0.09972113650292158, 0.037142940127523616, 0.0466430500819115, 0.06199417810421437, 0.04776252790179569, 0.06821745744673535, 0.04534537518338766, 0.10197440817137249, 0.03232617906178348, 0.021921148036199156, 0.006269177465583198, 0.07982161914696917, 0.03848043124889955, 0.02771218201814918, 0.03789328853599727, 0.043130643243785016, 0.033246082239202224, 0.03611578176787589, 0.03448761737672612, 0.020686850693891756, 0.04023111308924854, 0.05026553226343822, 0.03761722444323823, 0.033159406812046655, 0.01395146626236965, 0.02090527217660565, 0.05954040039796382, 0.01535592693471699, 0.023873296995589044, 0.010509463263588259, 0.043657597780111246, 0.014884254978824174, 0.049735130451153964, 0.03568680185708217, 0.06308897951385006, 0.011133677180623636, 0.06335100217256695, 0.03783646228839643, 0.02948894107248634, 0.043234395488980226, 0.08678377329488285, 0.019504212395986542, 0.007565886644442799, 0.02781532755761873, 0.06588718053535558, 0.029370156626100652, 0.04411064182932023, 0.08759807999012992, 0.025034047503140755, 0.060911640684935264, 0.043429012584965676, 0.02462363612721674, 0.04249102697940543, 0.004718027130365954, 0.03259643584897276, 0.04711941241112072, 0.06277246837271377, 0.015836954589758534, 0.06714018556522205, 0.014211066736606881, 0.003617720376496436, 0.03332855711050797, 0.035319349699420854, 0.02313300468813395, 0.02942895698652137, 0.03366220815223642, 0.03310312233224977, 0.008678180474817054, 0.004492127118282951, 0.05868934626050759, 0.037207065397524275, 0.031915092331473716, 0.038526433272636496, 0.021199713701207656, 0.009020112029247684, 0.027514748471730854, 0.029949768395454157, 0.03071776322030928, 0.05866521161806304, 0.026968056517944206, 0.0324851470941212, 0.04909496128675528, 0.046572586870752275, 0.046194930182537064, 0.0383426923508523, 0.04876335115113761, 0.061075903940945864, 0.068752597871935, 0.03267082131060306, 0.03757269187190104, 0.09828346286667511, 0.05581349803833291, 0.01958176311745774, 0.06350579191348515, 0.013117673552187625, 0.026253253272443544, 0.026483057445148006, 0.019789516227319837, 0.04021474131150171, 0.03694684986840002, 0.028327292566245887, 0.017112404020735994, 0.039570186054334044, 0.038168376704561524, 0.04739868258184288, 0.050183855200884864, 0.050971381497220136, 0.027008635297534056, 0.0721758505096659, 0.01736870843160432, 0.029863191302865744, 0.036487479010247625, 0.019986333791166544, 0.022866963299748022, 0.011470738390926272, 0.049039738078136, 0.004774423396156635, 0.03305763239040971, 0.0373964874597732, 0.005529650497919647, 0.08719999939785339, 0.03955062675231602, 0.03988713877333794, 0.0545333229820244, 0.006542288738273783, 0.026411996805109084, 0.02316936806892045, 0.023227084893733263, 0.06503242679173127, 0.049411227519158274, 0.03510662791086361, 0.043703648043447174, 0.014066475960134994, 0.06197877482918557, 0.01496357665018877, 0.02520419227948878, 0.03948395220504608, 0.036550539298332296, 0.061890077049611136, 0.037910803221166134, 0.02286926766828401, 0.05021918514103163, 0.04531435341050383, 0.03474436707620043, 0.018483054300304502, 0.02817667555063963, 0.03954628889914602, 0.025865269599307794, 0.010312601170880953, 0.027022062604373787, 0.026618822230375372, 0.0515702575648902, 0.029213723028078675, 0.010216983791906387, 0.015038285873743007, 0.020796799872186966, 0.07395281179924496, 0.0640096137067303, 0.03298218194686342, 0.020596336507878732, 0.04243458664859645, 0.0369551322364714, 0.043335861919331364, 0.021871030803595204, 0.010576731528999517, 0.005612105424006586, 0.024815355136524886, 0.06009100718074478, 0.04546796313661616, 0.02471664578479249, 0.04473386405152269, 0.015527739687968278, 0.025136538097285666, 0.030703847951372154, 0.050180667676613666, 0.0369996165682096, 0.015379917786049191, 0.03459063489572145, 0.014705057856190251, 0.026200720349152107, 0.011630173048615688, 0.10484594080480747, 0.028410006780177355, 0.03208901463949587, 0.044578343295142986, 0.02867370298190508, 0.04108998204173986, 0.04998376847652253, 0.045577411365229636, 0.07831715221982449, 0.05417256128566805, 0.030398884628084488, 0.10322494184947573, 0.03873583766107913, 0.026952354528475553, 0.031037851513247006, 0.04771281142893713, 0.04405252795550041, 0.032180365597014315, 0.043964917422272265, 0.0984323896409478, 0.05265331819828134, 0.06742674362612888, 0.03711655306688044, 0.016566099839110393, 0.011967474529228639, 0.011733839946828084, 0.010087522623507539, 0.028537747093650978, 0.01520438316219952, 0.03841311845462769, 0.023812203398847487, 0.05072445412224624, 0.07013170863501728, 0.01495743073974154, 0.047761128953425214, 0.10798567076562904, 0.02495512195309857, 0.07036818657070398, 0.05270290850603487, 0.010828981958184158, 0.03764604203752242, 0.03133049147436395, 0.026626870821928605, 0.02911892850534059, 0.049411205254727975, 0.019795149128185585, 0.047072894594748504, 0.004899279074379592, 0.03182208638463635, 0.022487542155431584, 0.01115762535846443, 0.047336724383058026, 0.02946348540717736, 0.06760181626304984, 0.04522221577644814, 0.037646895507350564, 0.033896723107318394, 0.049487598225823604, 0.05298326592310332, 0.07796331847202964, 0.0418413731676992, 0.04887763818260282, 0.04310318377974909, 0.04715116891020443, 0.039355519838863984, 0.08483078941935673, 0.06094390926591586, 0.02819390265358379, 0.03713127727678511, 0.04156224400503561, 0.01170774510683259, 0.01894189823360648, 0.004874753876720206, 0.02045668657956412, 0.04159214142418932, 0.035059423607890494, 0.05175541969947517, 0.009232460888597416, 0.056732380762696266, 0.023631941294297576, 0.039664472205913626, 0.06357324571581557, 0.08953642871347256, 0.03187496440659743, 0.0324448892934015, 0.06843211624072865, 0.14071210491238162, 0.06033508470864035, 0.16188247594982386, 0.107735411147587, 0.1591464743250981, 0.0845555639534723, 0.07722485926933587, 0.1283988359500654, 0.21617860853439197, 0.19125543418340385, 0.1684509133337997, 0.27930157841183245, 0.187022669124417, 0.11117649017251097, 0.13894977135350928, 0.09031195077113807, 0.17609469301532954, 0.21471359417773783, 0.14562797237886116, 0.12276143024791963, 0.21557712752837688, 0.1347823449759744, 0.08473661087919027, 0.11536097852513194, 0.1477920007891953, 0.22238360135816038, 0.09658715076511726, 0.08130670117679983, 0.13041477621300146, 0.12432389601599425, 0.11927719533559866, 0.17788171040592715, 0.1345773637876846, 0.20597237104084343, 0.09027405671076849, 0.1425211937748827, 0.11068380801589228, 0.12562071002321318, 0.09612855545128696, 0.13987772312248126, 0.09735093204653822, 0.11929476939258166, 0.11647943218122236, 0.19462278083665296, 0.10747371503384784, 0.15158651280216873, 0.18775950302369893, 0.11238374921958894, 0.08563374125515111, 0.10735043688328005, 0.2083425532327965, 0.17242400092072785, 0.07446819625329226, 0.10680078747100197, 0.13200788525864482, 0.2535369718680158, 0.14678135892609134, 0.08554783766157925, 0.12636968545848504, 0.15892610099399462, 0.10615101491566747, 0.11891894580912776, 0.12493956688558683, 0.06644800669164397, 0.15266626345692202, 0.12910525663755834, 0.1629403926199302, 0.13011114875553176, 0.11230600182898343, 0.10916046085185371, 0.1955252027255483, 0.1370532574946992, 0.07533135110861622, 0.15306387649616227, 0.1637659131665714, 0.10160747551708482, 0.1393566612387076, 0.12067943142028525, 0.11810029754997231, 0.11978677619481459, 0.1248238660627976, 0.1581225628615357, 0.09336188086308539, 0.17816513660363853, 0.11322610909701325, 0.2255762612912804, 0.13343962171347812, 0.12910213961731642, 0.08758608688367531, 0.2427607649588026, 0.18279891373822466, 0.12060818524332717, 0.23234124906593934, 0.15686687867855653, 0.07615566195454448, 0.10959524064674042, 0.19671320304041728, 0.1431387645425275, 0.14251734944991767, 0.10539697061176412, 0.1126513750932645, 0.2073150349315256, 0.0761017671902664, 0.13327070890227333, 0.17940131714567542, 0.15792467660503462, 0.13860102131729946, 0.1721988630015403, 0.20266867097234353, 0.2399820601567626, 0.12665290385484695, 0.15312047267798334, 0.13744270690949634, 0.1280607728403993, 0.15306712710298598, 0.08090703238849528, 0.1366855826927349, 0.1426497782813385, 0.14340081688715145, 0.11133267515106127, 0.05816387230879627, 0.07805101806297898, 0.11516216458403505, 0.07360268136835657, 0.15147023310419172, 0.23138200835091993, 0.13126701407600194, 0.11294210402411409, 0.1948916757828556, 0.10455107811139897, 0.13094789057504386, 0.1677983725676313, 0.1436025177827105, 0.07706186137511395, 0.13036591320997104, 0.10922211105935276, 0.2355342949158512, 0.17485469783423468, 0.11746019517886452, 0.0723372824722901, 0.17523018002975732, 0.2193358531803824, 0.178129973646719, 0.20147130475379527, 0.10193819136475213, 0.09058901676326059, 0.12485227547585964, 0.08883492846507579, 0.14120110601652414, 0.12871945858933032, 0.10517653048736975, 0.10056389714009129, 0.13359723903704435, 0.13506062066880986, 0.16554452944546938, 0.17289790674112737, 0.1431402488378808, 0.23707822925643995, 0.13234324695076793, 0.09983781696064398, 0.14822387136518955, 0.18635347456438467, 0.1095996044750791, 0.11996823872323148, 0.1283799111843109, 0.08133326264214702, 0.12344888906227425, 0.1535810495261103, 0.13026677712332457, 0.10232283166260459, 0.1238075022411067, 0.14264280209317803, 0.2581381390336901, 0.13054435519734398, 0.10567610719590448, 0.22774944780394435], [0.07151057448936626, 0.061195883245090954, 0.02421624529233668, 0.030550564770237543, 0.014784161521674832, 0.012936437378812116, 0.0520902915741317, 0.033931967700482346, 0.03273355134297162, 0.026455137849552557, 0.06586141316802241, 0.017797166983655188, 0.08628810770460404, 0.016693335492163897, 0.029000218273722567, 0.03591614033211954, 0.05793080083094537, 0.024705853102204856, 0.02281957717059413, 0.009554616990499198, 0.06387025321600959, 0.05336436617653817, 0.053329270012909546, 0.039991106241359375, 0.08170453686034307, 0.09572901282808743, 0.00956555439188378, 0.042593977705109864, 0.038355906290235, 0.0459953369863797, 0.007428694616464782, 0.039601872049388476, 0.11351646695402451, 0.08805453049717471, 0.012607314365595812, 0.038508324869326316, 0.0398539499292383, 0.057291741177323274, 0.03968575700127985, 0.03420006483793259, 0.027326474883011542, 0.05677427499904297, 0.0478844293684233, 0.016933403567236383, 0.04611902702890802, 0.041282780875917524, 0.06686455191811547, 0.026770584008772857, 0.04182822231086902, 0.06217003370693419, 0.02611374991829507, 0.05263951425149571, 0.01805897813028423, 0.007275640109583037, 0.083137683395762, 0.033758750432753004, 0.028287756504141726, 0.035179139449610375, 0.04851388934184797, 0.03322544682305306, 0.0512156371405581, 0.02357114641199587, 0.14676369581138715, 0.03690001292852685, 0.021252767983241938, 0.0376183376647532, 0.041515073098707944, 0.02627945850690594, 0.04399427678436041, 0.016898546746233478, 0.13611828500870615, 0.01943332244991325, 0.03143670022836886, 0.013107398517604452, 0.09620630284189247, 0.09761524052009918, 0.058505096967564896, 0.021659867525158916, 0.049269388255197555, 0.09512986958725378, 0.04780159826623276, 0.016875098590389825, 0.05796371879114304, 0.03579153373721056, 0.029791685374220833, 0.02614636174257612, 0.0326295801642118, 0.028836988458351698, 0.023213273525470868, 0.04648560716304928, 0.04058187434566207, 0.05848330751177855, 0.07200226216809824, 0.048013930427259766, 0.05263967010250781, 0.0854470391641371, 0.05743168054323178, 0.02542146343330387, 0.01642540348257171, 0.09376534944749437, 0.02981848803756293, 0.07091745748766698, 0.01965874424058711, 0.02430891170661198, 0.014039246561878826, 0.03713281352247577, 0.05202727210416924, 0.0732248168787919, 0.04957434044627007, 0.025553242885507643, 0.0451952461298788, 0.07324248741497286, 0.029225161379144993, 0.019368443900020793, 0.01791409420548007, 0.010033331000158796, 0.03290700609795749, 0.012897450505988672, 0.015485208132304251, 0.029273497457324993, 0.04010960125015117, 0.061086338537279516, 0.06175348476972431, 0.050968602154171094, 0.055287675277213566, 0.06397177901817486, 0.02107030541083077, 0.030511904442391824, 0.02310065447090892, 0.009540806549921399, 0.017010887495416682, 0.011458741573733278, 0.08721689067897387, 0.0045824242261005566, 0.038452010703622364, 0.027253206353634596, 0.13985577039420605, 0.02076388005662011, 0.03416809682676103, 0.010761402918433305, 0.06432905633118935, 0.05249380468740128, 0.050390316973789595, 0.03807779758062679, 0.05275508519844152, 0.0329636616515927, 0.04787537887750659, 0.02318861566891428, 0.0720125854422804, 0.03627008540206589, 0.02425932696496602, 0.010482672660145909, 0.03401057969313115, 0.06510857856483199, 0.10158938195672818, 0.013634173083119094, 0.01700306896964321, 0.042091855430044234, 0.04700404555478599, 0.047851938143139705, 0.05906748163397424, 0.03097852608334506, 0.03788632348005194, 0.03159947918902617, 0.006989988396526314, 0.03022532597242389, 0.019702158024301752, 0.13342353195184842, 0.04209608196106274, 0.06522778232465498, 0.05287103464070242, 0.006520443157569389, 0.016555535366933327, 0.008458474148937967, 0.040658682919456623, 0.032644593811710365, 0.00741719967663812, 0.06628658215049654, 0.026231723568344023, 0.04693676615715958, 0.03140198256005533, 0.04291208817448933, 0.036067226756131276, 0.013135301414877176, 0.020681696478277445, 0.06627524955547415, 0.029043455797364004, 0.0359604354162002, 0.044079352883272804, 0.018131680772057734, 0.019871556942234747, 0.003843144022539491, 0.009042735473485664, 0.0254754806519486, 0.08154991039191373, 0.02695413011679193, 0.012379131785564823, 0.010181658490182599, 0.04473992739804089, 0.05234951633610763, 0.0400243210606277, 0.03864628270093817, 0.07986645970959216, 0.043281455073156394, 0.045040630793664604, 0.01104070648580091, 0.05113620136398822, 0.04954452466336079, 0.04367041095974855, 0.10025731593486853, 0.029051938545308076, 0.006105102993387845, 0.024659079244884197, 0.05621184580377303, 0.024639269468025304, 0.05455150188936386, 0.03596386784920469, 0.04217038207571022, 0.050116022903239354, 0.02331856572709512, 0.08276865788502619, 0.02443508979922626, 0.0482058943453012, 0.048577068373560905, 0.02810233832860831, 0.024997507862281054, 0.021487234698724933, 0.07032590641756542, 0.0333268019312527, 0.08048356292420067, 0.0972735631512478, 0.0356945647217799, 0.005591012195509393, 0.022367442252289038, 0.02850861408660421, 0.03130069424514659, 0.03549762841430493, 0.01159120287411497, 0.03195816287188791, 0.027573324332479388, 0.02904414042859571, 0.021429146800073795, 0.05755073216278106, 0.014185786403686507, 0.046009218858671375, 0.01695559378276812, 0.03500793711282313, 0.03424982583965175, 0.023947647205204703, 0.01745384946843842, 0.04908340604742989, 0.10207407860434614, 0.04202009346045088, 0.024001220990612637, 0.025744924787431955, 0.07489655647077598, 0.04037693397549447, 0.05017114592192229, 0.05246176246146206, 0.023948185262270272, 0.028203454094182234, 0.045645507125300355, 0.04005016635346692, 0.04098228528164327, 0.08037909821723588, 0.08842726674629375, 0.027367654802219477, 0.039141658853623085, 0.008608766474935692, 0.023621382388228085, 0.040977721073431894, 0.0575516524259001, 0.07423085742630064, 0.01940976482728729, 0.052053495892323554, 0.021923465392319486, 0.03478847662336193, 0.023814498490537517, 0.006418473458325025, 0.044122133986093104, 0.0065630544941086555, 0.038605716908932664, 0.04533019084192347, 0.018426478527544532, 0.02374820614932105, 0.018371930673311, 0.025569436547812074, 0.06488165949122049, 0.031613728424417786, 0.02341687802982051, 0.07382320312899537, 0.031290697515942156, 0.045328075721045025, 0.02672904600331094, 0.02758712271315744, 0.06290479330345988, 0.06917577047715895, 0.03733228055352811, 0.03052849329833407, 0.03595143687562086, 0.03974542938522063, 0.11346020473865792, 0.05454341247968841, 0.07877352851210162, 0.04402138743898831, 0.05612685505184345, 0.027404723223298788, 0.006285178633333999, 0.09477005412918516, 0.03838465709122829, 0.04344083870819304, 0.047743376780999824, 0.09863046885584481, 0.02614464367070468, 0.0649148112279363, 0.02411530393146677, 0.024313741232617758, 0.045749110940960236, 0.060248468653298914, 0.03224649095500354, 0.08381881911191158, 0.051117350813001394, 0.07377107467618771, 0.07140649569919333, 0.02520195470424369, 0.020185522516840138, 0.01407921585268923, 0.04847992124268785, 0.01696835501206806, 0.015111616557987873, 0.05265426072583068, 0.019901916348317172, 0.02964530787721742, 0.06131702772108838, 0.013696988462470472, 0.011477890839159954, 0.018439493942423724, 0.06264794341404922, 0.06352792275720276, 0.013992047825013287, 0.022598031246161554, 0.03401045352802612, 0.05889433858101256, 0.05329151696059853, 0.0862166091974359, 0.01601399948413018, 0.0336063281429233, 0.05681255497620441, 0.03979548353527207, 0.05792633681267034, 0.06674300297163427, 0.021506140910787508, 0.0825796922435984, 0.16418954590335488, 0.055550826000398956, 0.10286785749485716, 0.138033397088293, 0.13150561455404386, 0.10962442931486294, 0.12511935958173126, 0.1769293865072541, 0.18486851127818227, 0.21128127991687506, 0.1439789350843057, 0.17484870128100738, 0.08229664454120211, 0.1232648735458497, 0.16229413042310625, 0.11222076616832055, 0.11404659046093002, 0.14144169545033947, 0.10740439844084904, 0.13737104512983933, 0.22201925137778744, 0.09681807001470588, 0.12517050839960575, 0.14216341922292486, 0.15546488750260323, 0.15745100827189162, 0.11995785607723519, 0.1358671867637895, 0.10292299906723201, 0.11865180233144201, 0.15175612323218957, 0.21343263244489208, 0.15382061479613185, 0.12100264415494166, 0.1570538998930715, 0.10082088803756051, 0.11699086098815314, 0.15939484146656469, 0.16984960937406868, 0.086038070730865, 0.3098517016042024, 0.1151059394760523, 0.14114375284407288, 0.14661915512988344, 0.15161370509304106, 0.22160822030855343, 0.11769950811867602, 0.1331674464745447, 0.16619802016066387, 0.1175963347486686, 0.12576835288200527, 0.10825945646502078, 0.14570767903933302, 0.23266944161150604, 0.18728733382886276, 0.17494138068286702, 0.13535080041037872, 0.13697656395379454, 0.15868521470110863, 0.10289355064742267, 0.1467232932918705, 0.27763382415287197, 0.13675979746039957, 0.18339229049161077, 0.0873670939472504, 0.08338733445270918, 0.17424532037694007, 0.14331882441183552, 0.10717282610130496, 0.25429206260014325, 0.09242895670467988, 0.18560947151854634, 0.07251475966768339, 0.18765417742542922, 0.20483985368628055, 0.218143607780803, 0.08235920759034343, 0.10233293971396051, 0.2852159016765654, 0.09467935626162216, 0.131229639519006, 0.18855070666177198, 0.16188027919270098, 0.1339956239098683, 0.23075262259226292, 0.15206010692054406, 0.13967412232887, 0.1290348861948587, 0.1499515466275625, 0.09302599966758862, 0.11714886422851123, 0.10727789194788784, 0.10127953530172817, 0.09835848657530732, 0.1578375484677963, 0.16017351765185595, 0.18651860242243856, 0.08591621008235961, 0.2035917542525567, 0.17981501994654536, 0.19425871287239715, 0.12538242124719545, 0.14538923831423745, 0.06789035585825332, 0.17533311591250822, 0.09424202347872779, 0.14059610723052174, 0.12279315706109628, 0.15470503218239173, 0.15011676354333758, 0.220758936193306, 0.10437570119393058, 0.17477509507443756, 0.21039791638031602, 0.09269878675695509, 0.11214565340196714, 0.12414347991580144, 0.07209221788798459, 0.22097700886661187, 0.14476838725386187, 0.19747510668821633, 0.13705858611501753, 0.22165834496263415, 0.154121971281711, 0.16756608034484088, 0.10136167620657943, 0.18273256573593244, 0.20544899365631863, 0.11976584763033316, 0.07228669026517309, 0.10781620876514353, 0.2140344845247455, 0.11773096033721231, 0.1467032849905081, 0.08078176528215408, 0.1933145971270278, 0.08887758711352944, 0.1379112247377634, 0.09456326210056432, 0.2832882769871503, 0.26520207873545587, 0.12977550504729152, 0.08886863681254908, 0.14656724932137877, 0.10352119235903956, 0.22566561587154865, 0.20996373030357063, 0.24246151617262512, 0.08957166588515975, 0.09403500880580395, 0.14164900698233396, 0.07426122610922903, 0.1847842478309758, 0.15385135455289856, 0.07335754999076016, 0.1433498610276729, 0.132533919531852, 0.09997150744311512, 0.11451258498709649, 0.13934754766523838, 0.10426338456454687, 0.15439285518368706, 0.10041159359388985, 0.15195267362287268, 0.10886591728194617, 0.11937438699533232, 0.1492826489266008, 0.2679033181630075, 0.17475802567787468, 0.18683239730307832, 0.1840401260415092, 0.09040828896104358, 0.12607512704562396, 0.1403543452033773, 0.08598902961239219], [0.05141740482940804, 0.05085101998702157, 0.011903097856702516, 0.05559481680393219, 0.08152509297360666, 0.029734638337686192, 0.03570905886590481, 0.0428503897273913, 0.013946812996437075, 0.036374305200297385, 0.007461106060873135, 0.021178514252824243, 0.07045974532957189, 0.060682929324684665, 0.05552231639740057, 0.031234869456966408, 0.02244800238258904, 0.015488411427213578, 0.03986070347309578, 0.022945666205487214, 0.02928708061517682, 0.014337330176203977, 0.009298218883486697, 0.015444934560946422, 0.058510663075139746, 0.03248738466936629, 0.03821623780822847, 0.006255762682485511, 0.042915657904814, 0.05165249123820104, 0.03873357411066536, 0.05372830055421218, 0.017856870908872224, 0.07991130027221516, 0.03430333097639959, 0.0177843723577098, 0.016283512268273626, 0.018055382424790878, 0.05349865779862739, 0.031264176868717186, 0.05116340107633732, 0.016226109000854194, 0.019953651462856214, 0.04680952122726012, 0.10940789288724773, 0.009193885907734511, 0.05182342269108631, 0.019716353453986812, 0.010082955632242374, 0.02081043683574535, 0.024321747150679585, 0.02638352059875615, 0.09720977555844001, 0.02232223989267368, 0.013972523775009904, 0.032772491831565276, 0.011163965154992184, 0.032221217115875334, 0.0426527743547922, 0.02624608598125633, 0.05736267936299555, 0.014190577894623857, 0.07440550703904592, 0.031621038579032756, 0.04346786401583813, 0.061561754628201015, 0.030570688104489818, 0.02567439849372022, 0.030754907711525448, 0.03021760578121757, 0.03690511890454218, 0.037777513498440385, 0.1052875112509355, 0.03299830510513857, 0.060266198561294004, 0.016290948587993626, 0.03600316456868313, 0.032258398714475334, 0.011515050173329655, 0.039520061400253326, 0.022704011789755896, 0.09368291910504922, 0.031425890847458504, 0.04250092351867352, 0.0121060733908962, 0.018849777297873516, 0.03353366817464121, 0.0425542208540719, 0.012956546797795454, 0.03378418383363169, 0.05465123169415165, 0.044097876889281906, 0.040482129697920755, 0.01998586994886864, 0.008954984859883552, 0.011251642481511226, 0.018450676252541598, 0.005023844851166359, 0.04711440662504174, 0.07687075834837742, 0.0482660268608015, 0.026847355475183576, 0.04761842137668282, 0.025637177932367194, 0.028124318887421396, 0.042293853184673935, 0.0509250455070287, 0.027973701871815138, 0.050216424351674505, 0.03760106788831763, 0.03554186041583307, 0.05304142803652212, 0.025833036270341836, 0.03812666800513398, 0.052243378086132, 0.04090468632057309, 0.03482034444459714, 0.021418868054752238, 0.045277008539414965, 0.03260137113102246, 0.043058551018475555, 0.04264424707798753, 0.00774690110119991, 0.01703039299172815, 0.046576052700402215, 0.04868771888141055, 0.04685712628997862, 0.04835516992898192, 0.046227877828641795, 0.020468353141041007, 0.042351885422249325, 0.03287160936451983, 0.059558902139542624, 0.03398586617549881, 0.09138934139627963, 0.07268142377142794, 0.035590018378570676, 0.010888126489589922, 0.013308371180755785, 0.03015779238921823, 0.03142871843010653, 0.02634069496707525, 0.03729541436769068, 0.008181792218238115, 0.01702816654869821, 0.0458589376648888, 0.017621882834646385, 0.06141695790574886, 0.0957786847720854, 0.06698170735035092, 0.06379514044965617, 0.05432413752714638, 0.05700981040718034, 0.03954754312871955, 0.07164755268604495, 0.004086740082129836, 0.03243737133743707, 0.037757327081635594, 0.07943575430545025, 0.0369403263903223, 0.02879393276089104, 0.07424780807923526, 0.045905581646366045, 0.028990715072723106, 0.04791936225956306, 0.05747747476561926, 0.012769959739671322, 0.0648156825627666, 0.008164449154719478, 0.06126359308836982, 0.03044744149519829, 0.04278001928469166, 0.04156628499913495, 0.06600800217711367, 0.07713238024734892, 0.009281164329877356, 0.06609547912376001, 0.08711125337867998, 0.018216719763586298, 0.05259683704935014, 0.016605385426373687, 0.012617827815120108, 0.08430132642388344, 0.0535758968180744, 0.01627825971809216, 0.03907683967554476, 0.04612413300492335, 0.05088139609142672, 0.06221832525625359, 0.10263956544804387, 0.09273535237298347, 0.022983215167187154, 0.020819025339733344, 0.042246559823979624, 0.02652692208357621, 0.05300648401316721, 0.02471609474014258, 0.047589659443474375, 0.02300619762536371, 0.016727103211451322, 0.007079533615979017, 0.031705602596048266, 0.01666966469201725, 0.08022001144126989, 0.030388253362616524, 0.0346210555289872, 0.0049157533612742554, 0.01446633863452007, 0.030014537478564307, 0.07258696321514435, 0.05332862805516925, 0.02270006913022371, 0.007852060643926961, 0.054726292510167696, 0.034504983632359654, 0.0290036859587417, 0.038093557086540386, 0.028296419222897384, 0.02432413872156758, 0.006127052010924672, 0.06583657348528504, 0.05323526587744709, 0.020806496031582355, 0.04400688958412502, 0.04193061642581597, 0.06642991313128732, 0.029485660779755563, 0.05233223542745691, 0.06228753423783928, 0.0371626849664608, 0.02014436115132412, 0.036468186881393194, 0.038824550283607095, 0.03723910391272511, 0.04160647229582537, 0.022176114725880325, 0.07965237979078665, 0.019579694380809087, 0.03118711967545096, 0.02586434562545037, 0.027892566577065736, 0.029062356443319004, 0.07268045155797154, 0.04556027146463748, 0.024486277579853777, 0.015384526523121167, 0.009087970302061876, 0.03233042785723228, 0.048678041275707074, 0.03068347414227901, 0.03710267861606553, 0.0020449791099963477, 0.06983094586757943, 0.08080163257545792, 0.036787269564229064, 0.008526476212864509, 0.05060597766714636, 0.05443706642836332, 0.08133610506774858, 0.04141428573348094, 0.03582209537853487, 0.04404279468872119, 0.021447045546665322, 0.017342410428682342, 0.0537078024353832, 0.015255778744176496, 0.020491547111305408, 0.017514883693365846, 0.011820400341093773, 0.024521067607565783, 0.023409905552398413, 0.029328420096135233, 0.038025791582185775, 0.04464350386115257, 0.013560451843659393, 0.03294880756584462, 0.0333282194333151, 0.009390901068400126, 0.05275255818560254, 0.04333451121055987, 0.09736668784171343, 0.03331067135150079, 0.031597798224538565, 0.015023655359982513, 0.05634011860820465, 0.09562069637468085, 0.04679760975704994, 0.041896722541423514, 0.02457040001900168, 0.025865421739581507, 0.024395674336119555, 0.035640328569570556, 0.009332681438536383, 0.0865365935896989, 0.01570333646668587, 0.07872286209021695, 0.012634164340852294, 0.04066642351972405, 0.11205713744857349, 0.04257261869497597, 0.05851418827660382, 0.04323958310123999, 0.03398735418159049, 0.02073650965030538, 0.025609156291466206, 0.01938324603543151, 0.011300848727842094, 0.011289008689345792, 0.02755882276687771, 0.05176729035156313, 0.005064115175628103, 0.027183856363990344, 0.04167550316196866, 0.027297902197460644, 0.027687229157891124, 0.007526428044002387, 0.04081925770151429, 0.06521204879391007, 0.05871803397894837, 0.03339983297337312, 0.03844699007458985, 0.019995974289486185, 0.05060319461335894, 0.07170184821006842, 0.03269573149736971, 0.021237188448139932, 0.07013150083366781, 0.0534177414374426, 0.027174735369044356, 0.014802108507865341, 0.05636729234538507, 0.033891398197738454, 0.02821607431542361, 0.013097461160214152, 0.1252112671500072, 0.03661152899439912, 0.03050066461582901, 0.02026803449552972, 0.02502998981071869, 0.11435546490247361, 0.04156775445153471, 0.049400395873817615, 0.0869679669267498, 0.04915670055197552, 0.022056194793549366, 0.041613144203438424, 0.035811534617096186, 0.04554817445750814, 0.027942527958657593, 0.013115679030306637, 0.1081658122711815, 0.020927287987433374, 0.18481261271517724, 0.11352270841598511, 0.05408106189861428, 0.15301064966479316, 0.1289434387581423, 0.16344517178367823, 0.16944865667028353, 0.15561214444460347, 0.07291207584785298, 0.15774783765664324, 0.053373231130535714, 0.07597193587571383, 0.13434677850455046, 0.23005769035080448, 0.15640321449609473, 0.10487550796824507, 0.1927983295172453, 0.0973332540888805, 0.10879959154408425, 0.14768907974939793, 0.1622663444140926, 0.18642620503669605, 0.10928177231107838, 0.08892301397281699, 0.12472622911445796, 0.14952591009205207, 0.07208193172118627, 0.11668108854792081, 0.16149556468008086, 0.20489321410423145, 0.07882327467086725, 0.18162231281166896, 0.13027961627813056, 0.15605214895913377, 0.17977766023250297, 0.08102940511889756, 0.1143239755765535, 0.08483673402224667, 0.1549843468819745, 0.1623193486011587, 0.12444980136933737, 0.08714441995834932, 0.12835536093916744, 0.1589530409546569, 0.23281036061234772, 0.15550365729723126, 0.10312619910109788, 0.06255950167542323, 0.14859301561955363, 0.1193922059610486, 0.09077240887563676, 0.09426603195606731, 0.28106254641897976, 0.11526870730449446, 0.06500148665509187, 0.09426227668882348, 0.12318109991610982, 0.20748541719513014, 0.1801434945082292, 0.18206185719463974, 0.15032172988867387, 0.08386828325456008, 0.11300865982775576, 0.1685256921336986, 0.09636766801122576, 0.10068218063679524, 0.13737812521867454, 0.12231051616254263, 0.09592899936251342, 0.10921077846433036, 0.11825876834336668, 0.14560290263034403, 0.17673449852736667, 0.16561325232032686, 0.14392590121133253, 0.11579433339647949, 0.1416186531423591, 0.17353486240608618, 0.08545771866920404, 0.1713833911344409, 0.08766786413616501, 0.20713583595352247, 0.26836336066480726, 0.18218407407402992, 0.1088063079805579, 0.11037483709515072, 0.0909109678468667, 0.12330155790550634, 0.1109791531052906, 0.12597925640875474, 0.04727718929643743, 0.128480457351543, 0.19094487506663427, 0.06919356717844494, 0.15303836145903915, 0.07299691074877046, 0.08631683624116704, 0.16976893792161718, 0.1096409272577148, 0.17315189936198294, 0.16341107751941308, 0.07336738344747573, 0.16161746985744685, 0.16800022189272568, 0.2132900510332547, 0.1003427742398344, 0.15644614031771198, 0.12050521225319244, 0.26105860888492316, 0.20862407953245565, 0.2240355033427477, 0.12601305381394923, 0.08902982386643998, 0.10676278208848089, 0.14470888185314834, 0.15141624928219244, 0.09269239686545916, 0.12317194923525676, 0.09412503874045797, 0.2510119479848072, 0.1296002246090211, 0.1876873811124824, 0.18674483872018754, 0.09141002505202778, 0.27315151935908943, 0.12212012559757568, 0.11377182512660511, 0.14717871963512152, 0.142056891345419, 0.1353113033110276, 0.1374613496591337, 0.08446040577837266, 0.22941689036088064, 0.16675978142302483, 0.16339252382749692, 0.13856752077117562, 0.10815377463586628, 0.10455173120135441, 0.099616315565072, 0.20211921451846138, 0.11577070341445506, 0.09660226831329055, 0.21794831904117018, 0.07788622417137958, 0.10507890096050687, 0.12195746166980825, 0.09933215464116074, 0.1331486107665114, 0.2062004033359699, 0.15545798552921042, 0.18770390131976455, 0.3042768663726747, 0.12656831386266276, 0.1372427723254077, 0.1439718995243311, 0.14842497854260728, 0.17204286355990916, 0.12154447133070789, 0.21340771112591028, 0.1625115203205496, 0.09634990099584684, 0.1777463871985674, 0.09814632139750756, 0.19379770557861775, 0.14827561390120536, 0.16112251672893763, 0.25111703609582037, 0.13109841296682134, 0.21535538864554837, 0.11982254771282896, 0.10044889393611811, 0.08852807266521268, 0.12814453162718564, 0.20993434125557542, 0.23320472304476425, 0.10250143692246638], [0.04703011720266659, 0.11223690045881085, 0.00627918950158346, 0.01944701321917819, 0.11155811735079624, 0.06134170413133688, 0.04880993947153911, 0.04033544420963153, 0.0288815841122414, 0.05423313908977434, 0.03297128721897025, 0.0907806096074637, 0.02930462684162194, 0.12048120377585292, 0.03134516373393126, 0.03620496194344014, 0.02636114484630525, 0.06524784257635474, 0.05182207940379158, 0.06329368610749952, 0.015414868303196272, 0.06094917480368167, 0.07130066544050351, 0.03014490499481326, 0.03099150624620961, 0.06650289593380876, 0.07428803990478627, 0.021571861798292957, 0.10594425999443047, 0.06119342673628125, 0.06191446773300413, 0.13346216815989465, 0.057526226446498185, 0.01317363983616815, 0.013052954564045649, 0.04819898495043162, 0.03444943387876265, 0.05860755787580274, 0.03176856269419659, 0.02982946069096215, 0.00918681045732228, 0.017624625070311595, 0.032757745357230306, 0.015511905039602425, 0.02134316528099589, 0.028687367776001338, 0.029600894049508497, 0.059210831168456934, 0.08798211914836429, 0.05707956857804675, 0.028645109887293074, 0.024564952655055095, 0.04747040002257563, 0.003355285593897861, 0.07789338589645922, 0.06433402129914612, 0.022153646204969846, 0.021894788806093857, 0.06344322886434384, 0.039794503900338896, 0.018999481471837498, 0.0210967462771805, 0.03862175843096338, 0.03231378519558348, 0.019451920670690015, 0.09078536677407101, 0.034248686642968096, 0.01892321652121609, 0.03596226109948475, 0.04541762325970922, 0.06442579528084025, 0.06726917825290002, 0.042706119929789566, 0.04064178792759776, 0.054158597777131945, 0.02422017125354614, 0.05906095444515813, 0.04151224551605992, 0.023774826986482367, 0.0630454822385218, 0.04118449454836082, 0.016954786697169766, 0.014952578021620866, 0.04124919498281088, 0.055873934834380634, 0.05258655088255182, 0.022513316944241524, 0.03017605107743293, 0.024184806061384734, 0.02140615320968209, 0.04318345076171681, 0.04781576215464156, 0.009653841207182268, 0.021581465189228766, 0.013775757233815966, 0.02494552783900872, 0.04499853246670682, 0.02085783038637601, 0.04931010618747678, 0.02849687145499047, 0.04686331580160186, 0.06069921575544868, 0.050636231317184865, 0.014410410385607975, 0.042440868928679265, 0.027440583799034357, 0.023268019904207904, 0.03973562561441213, 0.05905955178604927, 0.0881207745987922, 0.016525029386684764, 0.062455415463773534, 0.07252137220348231, 0.043450701850815676, 0.07695098451222293, 0.08149420478730462, 0.01683190930634737, 0.032537939769099467, 0.00933873736357782, 0.025303176225861534, 0.05046798272815067, 0.016006967634893954, 0.049338497046846896, 0.010643342993716942, 0.0022897352391737513, 0.024709938625164796, 0.09785756657947786, 0.028380684525473043, 0.03392512138816528, 0.0419283083465416, 0.01603788921784144, 0.036364746338222176, 0.033521927398396656, 0.023942402076500002, 0.04008918476756662, 0.03936098575650249, 0.09231396834366024, 0.05140453598869499, 0.03165164103847928, 0.06228861035197042, 0.038122656696941704, 0.05506601431989111, 0.013032102997385664, 0.07483276887796819, 0.0699374960095156, 0.014305863114714157, 0.02289277148520341, 0.06112984694482293, 0.031512670175288804, 0.031991874930099584, 0.05542710256122518, 0.040165202954085544, 0.03032592408999335, 0.04203745600534603, 0.049091102118836716, 0.030836577352602035, 0.04100816026038956, 0.04679365039919503, 0.058148647149209864, 0.021791253639094066, 0.06032066849002149, 0.014349878038046882, 0.04034795310872141, 0.05663555646606255, 0.03743214394489769, 0.01904800494230585, 0.018872028740588576, 0.07945089411805384, 0.013937361745774979, 0.04305470298277214, 0.040838278946466744, 0.06093744515965227, 0.042598660656949505, 0.024991713544295635, 0.06323044028249569, 0.03048854534426937, 0.09438704655622132, 0.04647341738746036, 0.03473081174888648, 0.028292231654631905, 0.05849158245837316, 0.08444064980722032, 0.020718820560432505, 0.05918271861446556, 0.03752508680918254, 0.023747708910377696, 0.015402834378619445, 0.05951606908638496, 0.0434702388884034, 0.05957296583801508, 0.029872095219616313, 0.08890998185961507, 0.011262781190453097, 0.010805069960042601, 0.05252503055089619, 0.010079259736812674, 0.04328134746174328, 0.07511298899771646, 0.049326054941047914, 0.02798714216623921, 0.07178772953920998, 0.026731701036624145, 0.07320175092900172, 0.028319553821347654, 0.06801205323426984, 0.05092558727483265, 0.05065187579020858, 0.06574983868631534, 0.05913559965847526, 0.028293198301980738, 0.041089989463216625, 0.0382225831708638, 0.06637021477217786, 0.01410626342476462, 0.05315166294167284, 0.026602070101944264, 0.022460346153820865, 0.048552922598901205, 0.00560430962650571, 0.07529667796916328, 0.023705165294813924, 0.05215478049649391, 0.02986472383781802, 0.025267421406169888, 0.07530691960710101, 0.0585426310863113, 0.0314854481985094, 0.025734929913596716, 0.010378053029853618, 0.06716791962389834, 0.02098232009302592, 0.028854683114332147, 0.029412366275209934, 0.023626818619959522, 0.09847813562373631, 0.026863283819693606, 0.09476798353716731, 0.047767670985194854, 0.021417960779217537, 0.06645585119258612, 0.02139518241165206, 0.02184660486818757, 0.03319216149975546, 0.0480399278603727, 0.07561507416539825, 0.07135119827580638, 0.043941172407357953, 0.02603347551485058, 0.09531318006338552, 0.040109386027324945, 0.06361863546771929, 0.0654351977573242, 0.027735127368941903, 0.08737481228308752, 0.11889850706211291, 0.030998513975646347, 0.04963022416632157, 0.036002615379402414, 0.03540181714924984, 0.051714252767851576, 0.04313895529776346, 0.07237012250698172, 0.028760348723153584, 0.04349450711742975, 0.031520796692348085, 0.02246969164843904, 0.03803704254096374, 0.06156834861030802, 0.05846064232173376, 0.012396229012665572, 0.05116482971061487, 0.030040392048249487, 0.014399914562090999, 0.012508341551438207, 0.0442729198402958, 0.013495376624632627, 0.1130259147612378, 0.07751308716251515, 0.043454074912006035, 0.05177513856324367, 0.006943051266716793, 0.020015895388496574, 0.04591812765283976, 0.052412264922168106, 0.07634072389919311, 0.0695493898820132, 0.036919987833243795, 0.04542096663499251, 0.06333946919767186, 0.04503543575992808, 0.017010085975925904, 0.017575634046806954, 0.017298516104347073, 0.04233326493704226, 0.020042805663251784, 0.027439524383225944, 0.03310947882710025, 0.04728767213237006, 0.02071845876344014, 0.03468462418823037, 0.012964138040842954, 0.02249250712338835, 0.02695376460906118, 0.028367865779728163, 0.040900571111706086, 0.014159054244373692, 0.049026264387066476, 0.022436063081840985, 0.06924334302311763, 0.08143785351421684, 0.023405831161653623, 0.012520682539616246, 0.017057123295671772, 0.012790050604962744, 0.02617724621813977, 0.041969386220443994, 0.05655301851220429, 0.02578748139058007, 0.016959295244305395, 0.06553368075401522, 0.020013340545119718, 0.04678704157413449, 0.011361874603608157, 0.04299329397326801, 0.027633903991954867, 0.028233685479790438, 0.010023781414929545, 0.027115599186799955, 0.033719034399837255, 0.026757188243209384, 0.016269235202344134, 0.023079115489963442, 0.04844732611672953, 0.13086533406749368, 0.021977133801556192, 0.007162590609368635, 0.09198561252560467, 0.04805086711712647, 0.07571576134068891, 0.027986680179310497, 0.01297046856052475, 0.055169484548969194, 0.0280385785663384, 0.051759995039901696, 0.03285065853560809, 0.050373781923553906, 0.057147801635437645, 0.017660029225226026, 0.05941353396337945, 0.04287132942408789, 0.06170586486405227, 0.010304974675818812, 0.24523707426851615, 0.179768888046965, 0.17826902243541554, 0.0851768751454074, 0.2417016905383207, 0.12313054481637664, 0.11578677091165446, 0.24485204805387184, 0.08508834434906021, 0.10780313954455778, 0.08851392733049579, 0.21170317602809519, 0.11982015799731016, 0.2564624883234501, 0.1914962165756151, 0.10528871353017166, 0.1581597444601357, 0.1396575872786343, 0.11511383592733182, 0.12470010551624, 0.20367624034406617, 0.18380958528723568, 0.14223517006030306, 0.18338233086979017, 0.16952793288510293, 0.23143484926549718, 0.13234508747700602, 0.12743248546030372, 0.10837287147296593, 0.18850647466024384, 0.12560546630993485, 0.18552133406046778, 0.14178067882312462, 0.12542901327833533, 0.1409590322873555, 0.09066407757927664, 0.2012418326921761, 0.15487908065551892, 0.14988089416874573, 0.1637810975080356, 0.08817455061944202, 0.17339517537038773, 0.09292379108956084, 0.12237903865752742, 0.14038242807146162, 0.07850527923437767, 0.1383686697226949, 0.12479150842409581, 0.15050976042402908, 0.1678810775047168, 0.1043415030289907, 0.08503076111082919, 0.1301609171787277, 0.3210040437988937, 0.13993523956742138, 0.09759820823092014, 0.17500619986094534, 0.14556350943166763, 0.17975400056457147, 0.13298477424541488, 0.1552418721257709, 0.127194641972892, 0.1344043097924441, 0.13306963141076267, 0.09729743062052876, 0.16366538184229285, 0.21748003870015964, 0.12060275272233412, 0.2537275553913787, 0.15852275857469067, 0.13897593948058784, 0.1262828690232709, 0.22873727604746819, 0.1292453592759557, 0.1263533136807382, 0.13109440536936745, 0.21503317781025544, 0.277387312380597, 0.20575005328282714, 0.21603570057777688, 0.15725330013083294, 0.13352823414606974, 0.22212859941646457, 0.1279760047327727, 0.1636785623850301, 0.17402812343789265, 0.1137673351331614, 0.10039785644039512, 0.23384771979181096, 0.14889612357364967, 0.10523729753913358, 0.175958790932782, 0.23031390941469, 0.16353332408471033, 0.16375415754737332, 0.07854698051232845, 0.12204533937619999, 0.0869316907483153, 0.15671377361286432, 0.09719540015794337, 0.156485132756643, 0.12636500992812216, 0.12769575492711738, 0.12939874635776505, 0.07854043476982042, 0.12448247813154012, 0.1423867017729208, 0.2210473793093115, 0.2057589145260863, 0.19656643591588363, 0.14200180914485827, 0.14187028573360294, 0.14164443535264581, 0.18965490366099402, 0.11365219092112966, 0.16525823855772614, 0.1279197054100223, 0.11787202776758932, 0.12043886425090022, 0.13023251958657056, 0.19580086605856195, 0.12031741920509376, 0.0799716442998033, 0.09604714185115881, 0.07189658776042052, 0.09651836851844564, 0.1934671975322999, 0.2336160361301154, 0.1582703393069096, 0.19654151459690183, 0.1649670346523635, 0.09557751822285354, 0.12225282902363688, 0.12594960018759593, 0.146326006797608, 0.20534688897896558, 0.1842784890322946, 0.08780625983490609, 0.07213370394310914, 0.19808764569461346, 0.1294865572708659, 0.11474848404759541, 0.08796516849542968, 0.16415971156675369, 0.19914152508135885, 0.14116346428636461, 0.13980438408907503, 0.18143527675420046, 0.08923316490836442, 0.10093436241731979, 0.13647208164911717, 0.08957366968388669, 0.18029189435765147, 0.10765151877421886, 0.0983629617257975, 0.09493942707194947, 0.08747886880883016, 0.1436790925799869, 0.10572114813840017, 0.10964116474497132, 0.16994666744722053, 0.180736277543474, 0.12875168264145032, 0.13828376802848652, 0.07419829940772615, 0.151335607515648, 0.09686014236649498, 0.145871723361779, 0.07316124450881034, 0.12718120909994468, 0.15570293879136443, 0.14973230136092752, 0.2153565315529704, 0.23935604374855757, 0.15096854127477854, 0.11859764039400034], [0.07079691044054925, 0.03141424655041192, 0.018561176475486718, 0.029190393615863286, 0.12087322844308801, 0.10391941395937465, 0.008775868445809465, 0.052578249960788526, 0.0332396478188457, 0.019886084483005106, 0.02629309175972594, 0.06286231277044863, 0.0180979149081395, 0.02802623108436819, 0.021236077081994154, 0.05464093068439979, 0.014589298589271493, 0.04290622520784382, 0.055692950991215184, 0.04719263641163707, 0.04352638607088011, 0.0555666411673883, 0.05813344425405376, 0.010042787816928467, 0.07458682113792747, 0.03864959267957602, 0.01656429456488695, 0.09726597840199247, 0.05848378990776837, 0.010861705104616703, 0.030555949051631615, 0.0521018876315793, 0.06752927874913439, 0.04965110820194241, 0.026469815675227437, 0.03167595379636623, 0.07534420510637574, 0.04136990159167908, 0.02134392041625688, 0.023435279581462964, 0.03753039687580895, 0.056199882383225486, 0.03856626062770374, 0.06529959995532408, 0.007904447920736857, 0.056727434348431416, 0.02929204001702601, 0.015405338199343532, 0.055149209074443206, 0.024488728522555903, 0.0074455576032050885, 0.03594680587411858, 0.009370201642013853, 0.04213943080685567, 0.018989566378877498, 0.05802381790999789, 0.03728781106474344, 0.01744761728332378, 0.06601816960028373, 0.05334290697646793, 0.07070776366163045, 0.01593992201378569, 0.03703274604049511, 0.01189159735076828, 0.018757478246698156, 0.09078285831492394, 0.06118511097156443, 0.04609888885170221, 0.08237721951445565, 0.06624445042689331, 0.06366985107888468, 0.01065527487298823, 0.029599354093079455, 0.07921167023596354, 0.008296055129903834, 0.02425256599963177, 0.011862081209983444, 0.009510741219855845, 0.07270687943673693, 0.024330586129508447, 0.05707028802135028, 0.06644298235187307, 0.04960955906426534, 0.052070253586862236, 0.007254709689732408, 0.03654360392829403, 0.018371446421951987, 0.027878027904080227, 0.01423152774805203, 0.004597618308253004, 0.013838510458299424, 0.08063743240199983, 0.032272607131744735, 0.03936258508474566, 0.020962786766176578, 0.03635591849160846, 0.05905557016376406, 0.02799248934024945, 0.009487197512498824, 0.021363767300499603, 0.06124423787696287, 0.03326317761093378, 0.04145585342484992, 0.056521351070841774, 0.03407130221603438, 0.035285062476759776, 0.04821144189918414, 0.026237202473566867, 0.013141387953510275, 0.022681767768517602, 0.03957258319132961, 0.02761232048214879, 0.0589821494941134, 0.024112107130349614, 0.035731193420360796, 0.04637242964236066, 0.03554486240318511, 0.032968021769193, 0.02894559620472137, 0.04949641122948378, 0.04760937830724288, 0.01842496269091498, 0.018186074630648363, 0.08740243501961231, 0.03805149957770482, 0.0517622289044084, 0.015901632759778295, 0.029146393535484094, 0.05288448235660326, 0.06705371793941595, 0.05077179572253954, 0.07563946855952963, 0.025617395986046176, 0.04251831574947573, 0.01378725402901182, 0.03943006486224476, 0.04294350328564178, 0.030978542781667784, 0.03191042793332599, 0.0428418476076331, 0.1082162708917167, 0.055847803814685903, 0.008744088754610857, 0.031916491279844195, 0.05462838467792608, 0.026569239344098605, 0.0619105566147482, 0.011759486715163803, 0.016173459189303685, 0.049892257957253605, 0.019285740818304475, 0.03202374646207318, 0.016799575787445065, 0.06276245680055581, 0.02037896145338891, 0.06137029908131808, 0.014232381217880175, 0.03334143337269779, 0.04915584337140899, 0.024410016339970753, 0.036047737958142534, 0.020164265552011784, 0.03961728645663243, 0.0825365140917711, 0.06374507516738959, 0.05663998337695375, 0.0727738137356937, 0.04939098915201612, 0.04743112556752749, 0.02290830649144482, 0.042994114046450704, 0.05585933307884261, 0.09432984181330539, 0.07066826656227931, 0.021339207778510172, 0.13722715753829107, 0.015213425303954864, 0.027234856752329506, 0.02208081554272212, 0.009182716585200978, 0.09958212482160889, 0.05015621762140654, 0.008815049204713432, 0.08160744167980738, 0.02044000124442391, 0.07760615990264341, 0.06049847594113089, 0.020155163110757712, 0.05357945541618392, 0.016873686654435005, 0.04047764712595381, 0.025459411299380008, 0.056194672506535426, 0.03840790857793763, 0.05563878163229674, 0.0601813451066846, 0.005849571807630127, 0.023926944995764643, 0.0343494962726254, 0.005032399958508904, 0.023401680700771976, 0.045719755289610475, 0.015479410103580449, 0.03437006118474528, 0.05583592203038279, 0.03937450768717099, 0.009202845485560829, 0.07252840034198016, 0.05425153693067841, 0.04550944177026395, 0.03541889396728948, 0.03845270461170003, 0.07367550831986591, 0.02255826140753925, 0.02431633689411683, 0.018478937236068305, 0.016221910300373565, 0.014767751708859578, 0.013842631233274005, 0.02705383023567265, 0.003989914393969229, 0.01712249908450758, 0.03170065247104503, 0.061265014301170595, 0.009527847723802552, 0.026053602559841238, 0.03664027237391565, 0.008834046329866396, 0.014068555828998797, 0.02565164239058504, 0.017430698171665426, 0.031069029137142934, 0.03940151815186255, 0.03914946995791979, 0.019388886357774027, 0.015738757319923025, 0.02824189177772496, 0.013096756119921338, 0.024850492118275724, 0.04207307538308669, 0.05203919099585619, 0.0140157260466367, 0.08621402652352117, 0.07226666712085716, 0.04682794875407126, 0.04366386892797891, 0.06976419710554183, 0.0874869582185056, 0.07174333426519297, 0.09971426421543583, 0.010941883956547827, 0.05458852763695177, 0.030296275290311314, 0.04126376334170345, 0.05102628929307684, 0.05718340617022477, 0.026200486572633963, 0.03551607449480798, 0.026483261535759084, 0.07690722748520784, 0.03189114693668671, 0.05508769245352596, 0.060627271959674545, 0.043303971833665855, 0.01529260967799928, 0.01856790404417552, 0.0634274804906454, 0.0518367924814811, 0.06341873056953773, 0.04145334125496447, 0.02407070827757707, 0.07039473319309764, 0.05225580534897745, 0.05248409739579074, 0.057884026973624714, 0.03522674451232888, 0.01976645398826804, 0.02586853690445423, 0.010193235993938288, 0.028958516995771788, 0.04988108863472007, 0.03607468162954319, 0.043855176045326516, 0.03049956252652919, 0.06811600585933775, 0.057891452161129564, 0.042412522598169744, 0.01908384139824193, 0.050010422710329294, 0.010811245556396898, 0.043203065724810585, 0.06946570530999452, 0.03509982241666876, 0.026395302193122916, 0.04956802848028019, 0.044842158240498975, 0.0376208387024235, 0.043748150928877294, 0.010688627917261329, 0.0395483743341174, 0.04240634050802328, 0.07980589303770103, 0.02464375203999225, 0.023057741636876017, 0.06171102650114335, 0.07147684387746267, 0.006806369465266471, 0.01462371661546058, 0.040631935917190276, 0.027092449745396152, 0.04239841808157507, 0.015638209297321737, 0.08348250004928559, 0.02678991324501112, 0.040324798101210035, 0.005174658535906929, 0.08568056335207075, 0.06020950590027496, 0.014446739442064427, 0.03614609478972852, 0.03941666909668129, 0.03743842993571889, 0.007535668246418936, 0.041523578111082315, 0.016272413449769374, 0.028275088043301366, 0.03589987987652421, 0.025527401303406805, 0.0064571964048809605, 0.02497983175999252, 0.022081351744418498, 0.09260722057661042, 0.03206404879165348, 0.06687625558697619, 0.03912306063284632, 0.027073966557509266, 0.013185337938921293, 0.05194399200263433, 0.03142827314150054, 0.12301706301514059, 0.04823531307920348, 0.05132353428052738, 0.022068668440624606, 0.1185220452316571, 0.08728098997380584, 0.03965741067077033, 0.012741674636345124, 0.03585543265216984, 0.09931717810104601, 0.07321736571611837, 0.019720019663509447, 0.022932687897991855, 0.15063579194247723, 0.11306844724458642, 0.08071229283814318, 0.07894698326708749, 0.28036685718689114, 0.24064926576102152, 0.11732458995538764, 0.15847190661588684, 0.1421503722667694, 0.16687594237737358, 0.08097217811155133, 0.06684450650936924, 0.09615496106562205, 0.09459157503442839, 0.1344757340848446, 0.10090346680954099, 0.2045297547010705, 0.09298532997490838, 0.13965878955787048, 0.14359834691276774, 0.13562775508034974, 0.14713309239596128, 0.23235518659930676, 0.13655471237143502, 0.10192216839641333, 0.13447671371977776, 0.07906480663223192, 0.18606298312079161, 0.1465024153003469, 0.1531694841105491, 0.17291079042479396, 0.09854365984210745, 0.1821150691830553, 0.14904133218806237, 0.0922296752105467, 0.15002818079665303, 0.21841711888555437, 0.09852730290731415, 0.12831060943426564, 0.08418592988164164, 0.148112534370739, 0.16550448315683752, 0.19853995501762256, 0.11980291790678166, 0.12869823316577822, 0.16432387463282794, 0.12382776287267916, 0.10861702321562916, 0.1075667432451155, 0.07877449330408126, 0.12553267646580935, 0.21788146637845784, 0.04230750128044747, 0.0826357540790923, 0.1419659040402621, 0.2045716266729869, 0.13424866658169776, 0.09759101681993343, 0.15281441097613424, 0.09322574129328132, 0.15389727865112945, 0.09069773397641256, 0.09629140491597354, 0.11244385575992055, 0.15732224564999342, 0.22606123995501548, 0.18884389952290803, 0.14411054755328223, 0.19556113751605153, 0.11159969988511875, 0.14145199646009132, 0.15423917124280706, 0.1646045400411822, 0.21212810010183603, 0.09268458947190084, 0.1777743810089305, 0.1278896929579787, 0.09823756103287451, 0.16743936605053023, 0.09604066290194169, 0.08011132391402498, 0.1325330141116865, 0.18109031167114154, 0.2977855084463954, 0.1184230501530692, 0.123074824368814, 0.09917937612044625, 0.14292974607087672, 0.0808728119591251, 0.055014160461723804, 0.13338793854927644, 0.2022762381238863, 0.21716615476179868, 0.07660888411919586, 0.12279623697395436, 0.19972044479800388, 0.109061554830987, 0.13715070148464292, 0.11073914996813983, 0.06863495262223296, 0.1440327407908626, 0.1091463006741833, 0.171736772172153, 0.15229616925353184, 0.09857431054115295, 0.09234383978764527, 0.14052622660528868, 0.11161282847751863, 0.12177493787021376, 0.08058620936935768, 0.14297705056378618, 0.14742630010005087, 0.16295379580697045, 0.09765453723957762, 0.09186344759655185, 0.15084785321960226, 0.11839146434795111, 0.09310773239121772, 0.11760210865759291, 0.10157706230529584, 0.1220189114974346, 0.13678384304512292, 0.16427722322987393, 0.1547593277064152, 0.16276177251711488, 0.20136005681706592, 0.07526749672251754, 0.1430906733730808, 0.1636117690941319, 0.1940116222249344, 0.06092790856200736, 0.16593981214100495, 0.15677318995585665, 0.10895026236539707, 0.11490838718600571, 0.18874047382269055, 0.16103360743727535, 0.13087912317132577, 0.16043828625697643, 0.11222132277907804, 0.24549476278480142, 0.22445903217885643, 0.09640887947170995, 0.14468032401055098, 0.11203885092982091, 0.13321552280103788, 0.1416911609703675, 0.05813075025798753, 0.3340652195038274, 0.13407528604147956, 0.11450431004050188, 0.08106303925160319, 0.1474624130059965, 0.2187717764172703, 0.057785933604463935, 0.20374143059598282, 0.10287852957844734, 0.11471866455394775, 0.14246041188016534, 0.14698357932502404, 0.11972354521276429, 0.10588290664600208, 0.12493501009885222, 0.23762431635987014, 0.13333245558897033, 0.1973499360610731, 0.15885768982116133, 0.15935797156998888, 0.09460815461352468, 0.18170780822401866, 0.19947819295339286, 0.16443187196273357, 0.24528075708076358, 0.216465478297323, 0.1633361354470253, 0.24136824358720332], [0.11187374533619732, 0.011839763901662081, 0.03285386832430959, 0.050370074895909056, 0.027518947172211483, 0.007288466276804684, 0.03753244520339649, 0.017210384212376084, 0.03066140452574473, 0.048806147096911445, 0.0891136123391334, 0.04127092506678309, 0.04164896767179016, 0.012425035474734614, 0.018194212279922795, 0.03321688614960294, 0.043745052462327294, 0.010346387443860294, 0.019629451671789866, 0.04444677535502706, 0.05451200107927434, 0.0924530987686012, 0.06802674033679068, 0.008474829228362069, 0.021448761763167568, 0.012189892477181274, 0.0031765697076480137, 0.1059742872894276, 0.032129606406670064, 0.02694764560146723, 0.03851512665278278, 0.05002547717595007, 0.022375325715984218, 0.009207396706187865, 0.045165671544964425, 0.0064311344976886176, 0.02499452071788255, 0.0198466690198984, 0.0658296121400781, 0.04931706382194534, 0.059938072809018195, 0.013057544747425709, 0.034237313229823485, 0.03403012415219564, 0.08285169678856619, 0.048379972504335456, 0.03398977358301636, 0.020877820134046488, 0.05668880185112357, 0.013873986972612329, 0.024510521689080633, 0.02825924504577415, 0.04271066929504741, 0.0467347424273612, 0.04526732722297311, 0.03867756422550883, 0.0205377606471302, 0.058533016563160345, 0.047701549337944016, 0.04352371433924418, 0.06067704038287047, 0.03694233389978763, 0.058183568908134475, 0.06659091464825906, 0.03741395761608146, 0.02596001031633932, 0.04427412583027035, 0.05405702002462931, 0.08486979670124128, 0.056935454631457105, 0.031234409325406887, 0.04648919915780425, 0.02152454988390673, 0.035075869600404985, 0.11564919899683446, 0.020672412210842595, 0.0386558601167053, 0.006137873451734777, 0.045067496539559215, 0.047516146005364135, 0.04932363182888366, 0.07235104189021513, 0.054036199071560986, 0.03530665526341181, 0.022013250418240204, 0.027469406959426124, 0.009929670595738571, 0.056289255517185666, 0.022397630964405835, 0.032445490433019586, 0.03427848016144708, 0.02120360626577167, 0.04609112598700449, 0.05672707069606986, 0.0033382400852133287, 0.06483221019152552, 0.05924418328504544, 0.04045720837893896, 0.044017212858307175, 0.009307582004112191, 0.04353293181338813, 0.04715522845799569, 0.04066626395797357, 0.029616197134600952, 0.04507335208472796, 0.01415711816662224, 0.05313194778864272, 0.03481826643110253, 0.054096858511911705, 0.09742805603309534, 0.025208274091710337, 0.04552155362034682, 0.07537011348176748, 0.010217896633548662, 0.033193512208526954, 0.03550795168848708, 0.014733572097611614, 0.08157909163855948, 0.03359774891578127, 0.018748661532299593, 0.04648683541745413, 0.041089095175266266, 0.0345831429149257, 0.06500567236798815, 0.01907912690512603, 0.09723140916321427, 0.03422868576308247, 0.09695137458038516, 0.05755883270467166, 0.022211734103620984, 0.03984136681538075, 0.0837014707212802, 0.02190649618569296, 0.026629869098542258, 0.023534590072813444, 0.025274269573856145, 0.03844895676593296, 0.05877215509826783, 0.031396869162563235, 0.0196852166482131, 0.03397349457372911, 0.03813436778727919, 0.07022700039669871, 0.04428423759236466, 0.07216030251584016, 0.04815859727386851, 0.04376801080070436, 0.023467230894311797, 0.05552010108658578, 0.0630156924307812, 0.012699243270617444, 0.029311578909982927, 0.030146495046210475, 0.048366142582381144, 0.025370416660734918, 0.011575727239687694, 0.0674682593671605, 0.019067250686930493, 0.04762706739711575, 0.043631889784592204, 0.09037763826199807, 0.02824049468472367, 0.040513103231205605, 0.04451132735994179, 0.025213409753632732, 0.06219980867172126, 0.07986861193785444, 0.030491590005112812, 0.05487822869326919, 0.023482728793169372, 0.04378942176117562, 0.006565308303834172, 0.086759393743705, 0.024639512521389406, 0.07258408368215896, 0.03293479581770953, 0.07756940874969587, 0.028258883248781785, 0.008083434458967531, 0.055789782709325664, 0.008688920279382728, 0.04730599946924485, 0.03531798785843421, 0.04937611651257612, 0.05285828825435601, 0.044098129219491966, 0.024105453776428476, 0.00679167633279576, 0.035528575972421095, 0.01252954749361379, 0.005912364922551205, 0.024275090181617998, 0.01886087797174696, 0.06773167726350948, 0.04171182386926375, 0.028283040155656636, 0.054061673290561885, 0.02872977223887574, 0.05142598405655008, 0.016851388827490155, 0.038390479239751585, 0.009418822519364767, 0.06262188660912216, 0.02663122537342133, 0.059015037768404, 0.03628036785812583, 0.039344918259303086, 0.0636629194195848, 0.04407645850733388, 0.028571926704898942, 0.041145016002701595, 0.06778874841984361, 0.06521531424368732, 0.00907443816686282, 0.07421668240567669, 0.018618073227116838, 0.023943682281242218, 0.0025452817317273, 0.038384248910006136, 0.018170530347560998, 0.028876518954348285, 0.03465307549049612, 0.057491913248668425, 0.03250026835303288, 0.02093759827403119, 0.025531373648846056, 0.021037973747297656, 0.03369125952303875, 0.06774922163458541, 0.045977762929396704, 0.013633247253892478, 0.02848268715752056, 0.08293596023577265, 0.07263339197379537, 0.025731981731951237, 0.027294195169815794, 0.08961059895227663, 0.05250334128504619, 0.041120068708551116, 0.05007642932469025, 0.05366692123061512, 0.035314440392539836, 0.04750005253299605, 0.0686828359903302, 0.08095507902908139, 0.08257422261522152, 0.07805974571965635, 0.08403359664953314, 0.02095469921187032, 0.07918357994640246, 0.03771774092456326, 0.07058500501443632, 0.010107117177540204, 0.019224318821216002, 0.05321522046870086, 0.03031249863852281, 0.03470587187621277, 0.02259243916341802, 0.14417039434192702, 0.07351165695581585, 0.02145318310795119, 0.024433512735413387, 0.007865621537348488, 0.052303543998277746, 0.029976880905451253, 0.06701946040266193, 0.026702519789978396, 0.039133695609052666, 0.03512589406454936, 0.013821697102684993, 0.07318972071516328, 0.02320672407222446, 0.025250413236790337, 0.027458185686555225, 0.023311218465096317, 0.034859952866099775, 0.033930576173588634, 0.07222989370347932, 0.011058714699174743, 0.005279451643218636, 0.051227782387286425, 0.06107175904617179, 0.016671610974299256, 0.04063997708726674, 0.017272227378271054, 0.015132977423490956, 0.01027767106279498, 0.049846905312733725, 0.028487147465057205, 0.06855759856989607, 0.03234198309655767, 0.016046219825511798, 0.08070038878940977, 0.05402474031143356, 0.012638436328415992, 0.05395212116127368, 0.02999075164552778, 0.008146376003423939, 0.06964806583710015, 0.07891592438681982, 0.01206176068080822, 0.07377278903732076, 0.054395628612837754, 0.0836630274716299, 0.021772933723696042, 0.0655644724611193, 0.04270173754775897, 0.0643842201679945, 0.0019767015237448504, 0.01776967412297381, 0.04607416791259311, 0.05712779704481363, 0.06126654683612287, 0.007546028164142626, 0.027600679895840585, 0.03598753493861295, 0.016822851393953897, 0.03242575301555917, 0.06520238603116013, 0.1346025671227835, 0.03433607824263163, 0.028181499510537833, 0.058119109671679325, 0.041099960217252374, 0.0389198494667653, 0.05454532350995578, 0.030429117869061884, 0.021690585017495323, 0.012287892150197877, 0.041564351704437286, 0.007435423576680478, 0.016867914600879885, 0.027333567959431093, 0.043160893183085136, 0.04780886018124875, 0.053477855399250984, 0.021949401598249096, 0.04959242287441157, 0.04293515783501789, 0.028401987874531187, 0.03540496385539882, 0.06613790028495714, 0.027761532983276993, 0.007755367150821257, 0.011241734810027992, 0.03149662123178132, 0.045695012086071074, 0.018823792852344923, 0.0335649422777351, 0.05690252553904429, 0.036958546115783975, 0.06825105447205715, 0.1762908129603602, 0.11052104018745013, 0.08885357121471316, 0.20834515074966475, 0.12148844660259783, 0.10646507696947083, 0.10346809169277549, 0.07799753890139982, 0.12274436827283353, 0.18166976573411375, 0.1082660690008197, 0.18570127518614754, 0.057578199048293754, 0.1718433148926124, 0.07612089233589359, 0.1154863866395317, 0.08752531983191147, 0.15465182019397616, 0.08415326796239242, 0.12142654406488873, 0.17042708932422101, 0.1033424906199798, 0.236783952859696, 0.14607550227083266, 0.26371448824647814, 0.06979675512411632, 0.1618411680101417, 0.21380541322287172, 0.11542227992322296, 0.1200813271861989, 0.08724984945729375, 0.10824691416928545, 0.12200891476823017, 0.12151065908255987, 0.10985088825691491, 0.14145969995297492, 0.11526361617143266, 0.1634401993942447, 0.14672223944216967, 0.09844470187090337, 0.19939985184464604, 0.09994325388106517, 0.1451182653545402, 0.15693138615461066, 0.11468728655017912, 0.1572295365622267, 0.11119433140265755, 0.15167114732321352, 0.2524830331094563, 0.11044672894058749, 0.1893226441461593, 0.10553253872785717, 0.25182920100633055, 0.1099403912667185, 0.09428235920495354, 0.10981526516843587, 0.19015352299902588, 0.15913504525087774, 0.2032181274262257, 0.19972149864770472, 0.1259094351553358, 0.13183196657337248, 0.09746132651343942, 0.16411601391155273, 0.17799502151319757, 0.22470417839940637, 0.1748483450501226, 0.16878535476280376, 0.2782491536345333, 0.13969954830827191, 0.15084973827470094, 0.20330905535956845, 0.10498444782570004, 0.19943025021348149, 0.19089282082859427, 0.1553234044695273, 0.1614176985458471, 0.09260368053219281, 0.1682285955757834, 0.11840819235658273, 0.12229041880345903, 0.12133413183619268, 0.2282435994129628, 0.15620109799783677, 0.13112594664562494, 0.08394424949074164, 0.06970120361074805, 0.12499585136538371, 0.10481856297701597, 0.1536462249350734, 0.1926848106086254, 0.09443836606806144, 0.13005575485294685, 0.12728246772894636, 0.2652155561372638, 0.19133938592858613, 0.08976277633337304, 0.11145072858198546, 0.11019220197340474, 0.06423006125260144, 0.11425730102928355, 0.18712639168370515, 0.18434327852446586, 0.06805336859542876, 0.21199863986112177, 0.13376781425904483, 0.18270782253239304, 0.13413455395493656, 0.1759842169121839, 0.15843217202927917, 0.08218941162340343, 0.12790964188752696, 0.17018750921124592, 0.11304020110401325, 0.12354253325611353, 0.06810902967117727, 0.2553471294231713, 0.25513425178360194, 0.15773499850183725, 0.09601105120964348, 0.08828115271171555, 0.1684503789874725, 0.16129419032949954, 0.14239390060538426, 0.1049351024266798, 0.14760935824597254, 0.15425089717609808, 0.20646349468734115, 0.16042859380831942, 0.21054674667539075, 0.20267588464776054, 0.1972925235168077, 0.09466098068514839, 0.06703782113618217, 0.2508558891713619, 0.16061041998909786, 0.16715766163542867, 0.12430498609319329, 0.09717769993585534, 0.06788924263673835, 0.10773912188597023, 0.1354878008714877, 0.20074713189387694, 0.1815550445462577, 0.17240899469470605, 0.1326259013148956, 0.133666718902532, 0.13392201770329848, 0.10204121630522422, 0.21140309603651986, 0.16974340804154053, 0.11043149264878593, 0.09343930913018994, 0.13549026480177417, 0.07841668906621635, 0.10258950758725405, 0.11828622780740261, 0.16675630817189813, 0.10570787111646496, 0.20872593187959865, 0.1257633211207576, 0.13054146082140505, 0.15579451981466264, 0.1386394794099033, 0.10921551336650737, 0.1792757012299262, 0.17723785276757553, 0.08390744638745673, 0.12713144067674875, 0.11218712461413816, 0.21066112647531554, 0.16538198426133022, 0.16288179263938218, 0.08597452062531374, 0.14405819645617157, 0.09842263782047667], [0.048282599018421024, 0.014014969983691117, 0.037629224971169606, 0.028761385874531697, 0.06462377059506252, 0.017947917585843243, 0.02325589877727907, 0.027641232700261753, 0.05768953975348268, 0.007148868298827438, 0.05930368868575897, 0.05304162470565643, 0.01660311816522153, 0.058594997026375495, 0.020414024220372085, 0.04055691220855806, 0.03313507550046779, 0.11377521674148738, 0.04919486920698546, 0.041847113679978065, 0.011565101540327305, 0.08014548497158103, 0.03206686153134797, 0.00571983604459092, 0.027967584719590377, 0.02873128807550529, 0.04291520519473124, 0.035114427882945165, 0.03688301774673164, 0.009409226549905725, 0.017177037661895156, 0.0028931620636285516, 0.012125798748456873, 0.08543278992874548, 0.03699560897075571, 0.03156383383611683, 0.07045327380183153, 0.06180752796353772, 0.0362721411511302, 0.016853819361131173, 0.02434046040434623, 0.040643788015586324, 0.025976606593758333, 0.026090839819516987, 0.03543454586178996, 0.034710057589109056, 0.06138696400739718, 0.08310260949656367, 0.10438361248816364, 0.045110014179954305, 0.049772215570556, 0.08871365411323495, 0.007807982638041722, 0.014736547182110371, 0.02934492917120224, 0.08048954463447444, 0.01606994257599581, 0.01723328317893902, 0.05553616116230842, 0.05631076666759327, 0.02030480420216918, 0.038261056106421165, 0.025008775519381743, 0.08227674014051445, 0.05744797810621094, 0.05191217984247487, 0.04378505051136017, 0.020272207220841665, 0.03968478849856183, 0.055927985449670814, 0.053207899181870744, 0.05813750009110663, 0.03319726005429402, 0.022276482777670026, 0.01932148265041178, 0.030645153346995357, 0.01178837388579268, 0.014863028627587482, 0.1139468235487584, 0.026267081339028664, 0.054636655913782306, 0.03336251036671456, 0.06798522459575906, 0.03061625040572835, 0.023167393956100568, 0.06426394771551713, 0.03769687915337272, 0.025130326321232133, 0.0699546915711835, 0.03966647600464057, 0.08379377904930152, 0.03841484765871428, 0.007198994808277348, 0.06913495235494338, 0.03696665778988972, 0.04155672242632136, 0.011287157030892558, 0.08316851963172667, 0.0544788122351747, 0.04408246990351472, 0.018231909671158064, 0.019402309953875374, 0.09772978359251283, 0.04318545827118214, 0.04750548876472749, 0.024266754007840063, 0.0629090383881703, 0.08537433095625602, 0.021086345077492297, 0.01810541987651959, 0.016525673199794255, 0.011528732593433233, 0.028375270558171906, 0.06444157334044576, 0.009428018656763015, 0.08275152169517241, 0.06149998938781209, 0.0074287140978412936, 0.028143594317953102, 0.012498600863182219, 0.060914223358849995, 0.022083437179389875, 0.08342837521922775, 0.034301701962249354, 0.07038353418465704, 0.022440469583671074, 0.06996420590439811, 0.0201962651044596, 0.014632295842602616, 0.03873536639730446, 0.010996647961292183, 0.036422745179152116, 0.02944251973531209, 0.050139856975874864, 0.04132593676331453, 0.02034968743828358, 0.03501434184727259, 0.03521477738104295, 0.04038999948534183, 0.00868635708684451, 0.01074599778803531, 0.019436177863099147, 0.05765744557720609, 0.05340131028788164, 0.029773500900773797, 0.026828169102373067, 0.023822803123039193, 0.009677217931312043, 0.042699451732914895, 0.003980003011747613, 0.016227073792833835, 0.035573171626310796, 0.03507504581648391, 0.027865930896950886, 0.023255340311152395, 0.060187979906913824, 0.048290306222043, 0.020825708379561547, 0.008463162666885182, 0.012122478565288475, 0.05688871046004351, 0.03036901503946865, 0.08451186629827134, 0.048997413396136835, 0.03465016998234205, 0.001632525436434662, 0.029087511538818944, 0.015252219218382379, 0.04685735264502, 0.04900608539173845, 0.010464924198458903, 0.02934578078566119, 0.013760210167674813, 0.06320629079709761, 0.023353331635007635, 0.040274224447784945, 0.06801585303037427, 0.03970907157054171, 0.012869151487393538, 0.0655867368914187, 0.09330282817245461, 0.012282515290280571, 0.05673335668689106, 0.057977096003014594, 0.029857341323804576, 0.06334356585284695, 0.06087067784392275, 0.0305892826145282, 0.06853447324829176, 0.04552895283268299, 0.03511266528221313, 0.08232888343627565, 0.022423248046834487, 0.07421991816954687, 0.024067812046268955, 0.022187042850418948, 0.031784407547093, 0.08257364374003373, 0.06100357793911826, 0.013400331627053674, 0.04232072264130693, 0.03922214105841704, 0.11332524518365972, 0.023233879255712964, 0.06175911024911329, 0.0137574243308336, 0.03234365663956851, 0.020516063959803432, 0.047974210683605634, 0.029286997123563197, 0.017384664606652223, 0.057183743847417645, 0.0019698637925102958, 0.055765926372259855, 0.07174069964094087, 0.032728181904531084, 0.016923993134696502, 0.07864967148634605, 0.01600614756171126, 0.03596520371502265, 0.061508542639785446, 0.056728651470621116, 0.0352718448266387, 0.06787586913560517, 0.032193171355174854, 0.10512620545341633, 0.057068261958193034, 0.03070512815611437, 0.012590783026098507, 0.04285995601094328, 0.009122927313001128, 0.06354154858854599, 0.06665932582109235, 0.050402146807755344, 0.06937652884516865, 0.026550392503850162, 0.01871895707154181, 0.05605561258562375, 0.0428555253893137, 0.07344881931203417, 0.0469991956197191, 0.07064449557219632, 0.0412637522094883, 0.019096621181233786, 0.018019462477241177, 0.05563209117099177, 0.025812873973336536, 0.030243007640819997, 0.016805052837298717, 0.04192881300696172, 0.030889902518538292, 0.030474147679342423, 0.042125823529204354, 0.027519073337316513, 0.04980915968189947, 0.019372419956198428, 0.006875001890875865, 0.006834701416664757, 0.037156963007873856, 0.02574502312199911, 0.025729868466441985, 0.035165094304829836, 0.03977818036219105, 0.04472404543776065, 0.03749158997379709, 0.049132506537716836, 0.0356641774851596, 0.058716965286294, 0.020164768357062712, 0.006999197521508904, 0.05248387846222613, 0.045300753554329276, 0.05710729892598465, 0.01796198313968489, 0.017660177654761355, 0.05037475042627193, 0.032864113672985695, 0.04123336126212962, 0.09485855523962528, 0.01677671021752758, 0.025533113985147793, 0.007480366648451309, 0.005490532821568195, 0.11967231475864537, 0.04696954682003707, 0.02629186536069028, 0.031959858679329045, 0.0424805441434728, 0.05135369887284469, 0.047000757840578444, 0.010015274547185982, 0.029228217172203586, 0.0383336195955053, 0.05134847786393948, 0.035662407462950796, 0.009554293228575261, 0.03224681749998126, 0.04569035139866173, 0.039125858529587276, 0.04251069018209819, 0.0518180235667387, 0.04999525692255702, 0.0262092865887098, 0.020646190278057475, 0.06355740828439593, 0.026909081752819475, 0.015210640394798247, 0.05818785110022873, 0.04637775826267898, 0.03025374280696269, 0.03668977733468637, 0.0198271486806334, 0.013869726117263781, 0.10208338513621129, 0.05862868682015687, 0.035556658840505406, 0.01103312637496856, 0.015581781954097096, 0.06839123132522218, 0.050551596796140075, 0.049175287640537135, 0.02229499936220236, 0.04269985620339867, 0.08958746620919555, 0.0184536856613704, 0.011509121341077844, 0.018514974071877077, 0.04937823163345456, 0.015183398008957738, 0.03174770092300605, 0.03289906511781737, 0.05448457130114548, 0.02357222623686539, 0.03486489556962624, 0.04585987648169976, 0.020270420500310138, 0.01813940838474082, 0.03999635322543327, 0.03794176933297422, 0.07956659494084306, 0.01606648787856102, 0.04232503823004663, 0.028135851862316485, 0.0720918839215301, 0.056154025078285486, 0.040917406731750816, 0.05902679709834047, 0.06054382487491239, 0.022362239797075745, 0.07741957655525766, 0.028275796794332564, 0.08912518242141232, 0.11971646512392908, 0.07473633420886472, 0.10654326222720556, 0.2062743212445639, 0.1970976058510132, 0.10233047578367405, 0.11506915863719769, 0.12021043861750513, 0.12270671169972047, 0.1709917004336603, 0.1515637437114492, 0.09411196209839545, 0.1410014386055991, 0.10074494406580925, 0.09144065348664299, 0.19400641234824434, 0.0561502809432568, 0.22977341810474172, 0.21042948734248057, 0.10501759956241585, 0.10863007017178461, 0.22174459736561403, 0.1013279975450132, 0.1714309331146069, 0.13808589661493897, 0.13363452453631908, 0.20733391516841948, 0.09706772849312983, 0.11083705408964306, 0.09790570969926193, 0.1187180909619201, 0.11877802680828609, 0.04949710884829983, 0.12364972906652838, 0.10834792788955383, 0.10459613389684819, 0.11662767617963254, 0.1714990771142766, 0.12861793278716505, 0.11620977282291278, 0.14012606057804078, 0.17388439911883324, 0.0839729631843511, 0.11790543925599195, 0.14483561099041253, 0.09878453871351667, 0.11086527054430917, 0.2046317554777488, 0.16413088655099273, 0.16376858489820734, 0.1644043976557441, 0.1416916656307876, 0.15287219459423795, 0.1533460261998698, 0.11632329173153266, 0.15433980646776035, 0.16876565816346556, 0.08854198051267304, 0.23412164649926126, 0.150857204280328, 0.0698951119557023, 0.10178507887758315, 0.24403875810094178, 0.26046198152471334, 0.10716845485148951, 0.2713896904606372, 0.11063441808801144, 0.15695851907366887, 0.10104168439283967, 0.13704010663786903, 0.11762349735363387, 0.26719459681771696, 0.10878110464545898, 0.14013596082804725, 0.2599152264883742, 0.13071012130239978, 0.09206338218064047, 0.07657522772205994, 0.16950005781836808, 0.1577108193305321, 0.12799107033060864, 0.1971707964548841, 0.16570109291933477, 0.19483067124383524, 0.14751756942132488, 0.1623063610168174, 0.14930785226169974, 0.11294649011688307, 0.17986110731726512, 0.1179223602230195, 0.20394831168232486, 0.18267056671902537, 0.10192653964622878, 0.20037531590787694, 0.19315767742227763, 0.18625518452608958, 0.18468485941411927, 0.18135622318368405, 0.15075244271429256, 0.12996151694096625, 0.09726587450131774, 0.13082237855996937, 0.35178586549591273, 0.1632541578146629, 0.13765408541075885, 0.1336253812769428, 0.1473453763173893, 0.14314078318420798, 0.08293011953355744, 0.08648176371934824, 0.08613044585217722, 0.133543225529138, 0.10964978107949719, 0.2015337342163548, 0.1454717799788341, 0.14598914596717805, 0.13896890392061323, 0.08807534773950465, 0.12137196652474813, 0.08077206541202031, 0.13098532450385392, 0.11735028310795315, 0.1695226042647846, 0.10843892261618748, 0.14446563553065062, 0.15823507244931534, 0.10159314464544877, 0.06738281590514816, 0.12582800671225414, 0.14621930080465972, 0.16045934840803966, 0.1470507140038535, 0.13591861759778112, 0.1390656948206015, 0.06781844174838625, 0.2098234198638238, 0.172870016831439, 0.2604515617713332, 0.23077669786289334, 0.10569366640993394, 0.06432891532313079, 0.10999804871971719, 0.15786732343258336, 0.15928656212054193, 0.1319430660805665, 0.11155370899359696, 0.1353182943421416, 0.12818794726626948, 0.14729676564456895, 0.06418153963750228, 0.04961696940881666, 0.11496007035020739, 0.1033348316559568, 0.16055079584475607, 0.2082627872005105, 0.13156186934793368, 0.16969604417681694, 0.1267317496240139, 0.10060755026643164, 0.10854955457034521, 0.1351546953083016, 0.1409445604076609, 0.1853338972432539, 0.2000284063979052, 0.13651701126946136, 0.06356488913297653, 0.11166702752234414, 0.16915197571506724, 0.1260029902914539, 0.1523897986044176, 0.11819527760962956, 0.11714064123225398, 0.05792812538857106, 0.1565993344411254, 0.12220366174005903, 0.1250966647057794], [0.09882549042231403, 0.012121437703171978, 0.06366559857269749, 0.028032624686602503, 0.02531640315282857, 0.030125232515274547, 0.023266164535016287, 0.032926528292591684, 0.07792601070832461, 0.045618515214300714, 0.011637742027232889, 0.08803369099041447, 0.03640584276581649, 0.0346954409906175, 0.029275551351020113, 0.06069858864066191, 0.044958233847864904, 0.05558926182857249, 0.0663056924531702, 0.037934882202534936, 0.03211340161215048, 0.058261639132979326, 0.014525285569106927, 0.011952791137446184, 0.037581530850729905, 0.033517864139867015, 0.0379251303820638, 0.07090882631018758, 0.02130647721060086, 0.02014249279454816, 0.042743783924379386, 0.019369763067516033, 0.06239183567231521, 0.05193008044443559, 0.004502062620304059, 0.040494167333235964, 0.035644562522065826, 0.10405051434645429, 0.0471153231774224, 0.042927921895170584, 0.0932575052138418, 0.03879449701344129, 0.08295225037727505, 0.04482725962589029, 0.12165830936282873, 0.03442777058808133, 0.026444554823683575, 0.06599533371627331, 0.04515770087891724, 0.021544773408095352, 0.03285337479610462, 0.003045467233278032, 0.018835490955098066, 0.07332177847274579, 0.027299306711938698, 0.0633032078621909, 0.016271085005428176, 0.03802887520578224, 0.053239781846059486, 0.011221042805118486, 0.08146341308020055, 0.02440896991174668, 0.05384089548897464, 0.015782584850967396, 0.04265486350050196, 0.07591936213430017, 0.1190627517644316, 0.05581423647527117, 0.11133752879686654, 0.016105465474538505, 0.033007630190695636, 0.00913983343707514, 0.0216186171019217, 0.029352931378525682, 0.027585554926190525, 0.01962405254744226, 0.029593283325084485, 0.018873483350034803, 0.017560256746946834, 0.1158357600797899, 0.028013525516144, 0.015968455736583564, 0.043701410468202084, 0.054166045229067095, 0.03390109064639546, 0.011352876063028816, 0.03840578232484404, 0.022313684785331134, 0.07124172407202423, 0.007198458606580971, 0.026291065696568694, 0.03594409332436044, 0.033776869968278334, 0.012093598816136364, 0.03711641576956026, 0.018535147501097526, 0.03263787737523671, 0.05759446321462747, 0.008121775663312292, 0.06843413488240913, 0.02151306329324143, 0.12796291324775666, 0.0446757650206564, 0.0051665496448549675, 0.04200577372102998, 0.023875272963778116, 0.01937708249897696, 0.013217592604632955, 0.027814900822704658, 0.1062961715797428, 0.09437807399081066, 0.05947219702647999, 0.05455871556478087, 0.05029192674555816, 0.018023180637101177, 0.0454653210908873, 0.006998219741944922, 0.10384956302004866, 0.032659937714925036, 0.06608911891817115, 0.020563542857416905, 0.057120672427117825, 0.03798615718551446, 0.04843744813115336, 0.0533929982339032, 0.041585328508517705, 0.04165765451034531, 0.05154266822501086, 0.05813084302644711, 0.03488785761874169, 0.009018140699481592, 0.053127123828744516, 0.014226595249056118, 0.013346306986932177, 0.04201257921522483, 0.0393957739288453, 0.03562881414836738, 0.08430854752077721, 0.0419678128673695, 0.04820348978682887, 0.05234530093730427, 0.010788708386826329, 0.024291519475809764, 0.013516452690964798, 0.029171973510528915, 0.04249121993780136, 0.03777247802645434, 0.09450149314943701, 0.03411435420275666, 0.032694718465791084, 0.017680557029962074, 0.017889497576106805, 0.031978505139704794, 0.03870757296681404, 0.04739209602121264, 0.08438725970336236, 0.033655766310403123, 0.046946811125962995, 0.04513401523581706, 0.04003343092335854, 0.06942489460925572, 0.030146829012664966, 0.02866129798348993, 0.031678840750828385, 0.03887831146130338, 0.0010823662614711793, 0.036963332968298346, 0.033478374461992644, 0.014071613477426581, 0.06721446712617762, 0.025713274044392165, 0.006933835184099735, 0.03712305799126625, 0.047494642276433297, 0.010896272488025716, 0.09434498162590899, 0.003010757914125861, 0.013220826513133943, 0.08493179571814835, 0.0595046845410252, 0.08125336302327923, 0.012638163589144824, 0.010443428818689426, 0.047470852732658386, 0.06301791145233437, 0.020837265474256128, 0.025653494049038272, 0.04781260431627743, 0.08073382996371947, 0.016907779063330963, 0.022994861319602933, 0.09075689056771807, 0.07577781230793335, 0.016420878237113357, 0.03444045389187522, 0.022070043269195594, 0.0039717540403216844, 0.036039900878677145, 0.019681092162500136, 0.008481965905957622, 0.03279487500549294, 0.087525557319168, 0.018113414662366267, 0.036432912602322176, 0.042742852529045194, 0.03988210701209027, 0.011163154358655447, 0.05753195953730028, 0.02820515732310014, 0.045697628156631254, 0.06551887490786612, 0.03057711695873877, 0.01538132786663482, 0.02362797637033509, 0.029996933735674247, 0.041412883074372075, 0.05072878826467786, 0.02574248497694498, 0.02121864032233134, 0.04115439674933441, 0.024814091630105395, 0.029354634607443586, 0.031033101768116467, 0.030781623172515538, 0.04633284348528832, 0.02680925917957211, 0.06097803321608808, 0.0694738986203447, 0.05671520746545866, 0.045835693599656224, 0.027575927415455226, 0.0018321740617466276, 0.0622051113168709, 0.03997576604888309, 0.026850372305489145, 0.02876181260944577, 0.027623217065411154, 0.040246991338790394, 0.04412138070620131, 0.01212984067024081, 0.0171614024657174, 0.022364811338775326, 0.006386366758306394, 0.013069241922494257, 0.04795193512109108, 0.010375061247032136, 0.041194224104401655, 0.046662991589982994, 0.04211171901260968, 0.0424155208747834, 0.04219682850816753, 0.02396394105744548, 0.0051580529816419585, 0.03264889084675815, 0.02847354389814427, 0.08771398119279183, 0.060782206419389695, 0.026398443333164323, 0.02070908172754571, 0.02093889517709613, 0.05117565022374038, 0.06546047530719079, 0.0321908818295924, 0.009765116046764888, 0.018408967553114053, 0.015679895732318982, 0.03654504740552511, 0.05478674414916895, 0.02342236621188931, 0.03535584852215834, 0.06096482669818215, 0.014402742144739022, 0.014180758353177225, 0.036217626693542115, 0.03394230210687965, 0.06298792868619785, 0.007366631125478307, 0.0646988017251715, 0.041642318028607406, 0.03930278653569985, 0.04517992078035604, 0.00881568930708454, 0.059288615666446276, 0.13991408835863695, 0.02193800035456661, 0.056639389658812433, 0.021220668240857776, 0.03136317194730509, 0.0806943848147057, 0.07914921850897372, 0.02729136758716777, 0.04048979237268213, 0.024349011800950393, 0.05509588947461452, 0.03521455844747834, 0.02465429610310821, 0.058049332947121, 0.06601724191568792, 0.059470104170031846, 0.07774832571158186, 0.038811158228782006, 0.011180100373167079, 0.035792275884887204, 0.06501048148493282, 0.07847249115002342, 0.01733582201268291, 0.047553490876453, 0.026370763080194592, 0.05997951804602053, 0.042153056638198905, 0.08756408220506273, 0.07198989056632854, 0.0107336725704954, 0.08822111296467483, 0.02241729416709859, 0.08278870329377241, 0.10525693476665765, 0.01842631711042486, 0.06904446971020661, 0.01558657251734985, 0.07618165938765742, 0.024215215562435333, 0.042126250264118426, 0.058842688813456334, 0.016962302797765005, 0.024471265787724406, 0.025952139840228483, 0.014034058949619066, 0.01359426130875363, 0.05175104844965972, 0.02726425136643229, 0.08862487840815447, 0.04822247392439749, 0.033997491918853484, 0.04488752943871077, 0.03312917542643845, 0.005932696058152942, 0.026666033954825252, 0.029169665431254543, 0.04428233398357406, 0.028591647424036637, 0.012826986367144855, 0.03282678735558875, 0.040655758857610635, 0.012669168663705932, 0.03420688888581935, 0.01709968546492746, 0.012165706812083954, 0.05278080432617571, 0.05617058981442824, 0.03369619109435007, 0.011548136044439161, 0.16887131030671299, 0.10455068477313034, 0.15402828255901113, 0.127040512743406, 0.1373632822651416, 0.10678655307856388, 0.08329990203492343, 0.16869171056896448, 0.26127647375687957, 0.15522723697358742, 0.09608248292352073, 0.1744315549149178, 0.16386381728807464, 0.14434699580306187, 0.12313961386098526, 0.27693552256096154, 0.21897888014791533, 0.14443983847741038, 0.14047104050405324, 0.17522298119729385, 0.12320444788201712, 0.22173321282025427, 0.11277455676463433, 0.1497059699613601, 0.11816890168120153, 0.16269293089862913, 0.2545818267390132, 0.23031723423628137, 0.08484604055411182, 0.14205154788214713, 0.13464332587318495, 0.0901251522009261, 0.1304583254386671, 0.10670011513866484, 0.11482007161248475, 0.16753056115703657, 0.13011790229938924, 0.187659713847097, 0.14513436995912343, 0.08099140715785325, 0.17210014251759276, 0.081649974163156, 0.1965374476276338, 0.10535716923186556, 0.16965852119028568, 0.10513852510484867, 0.09946781923645176, 0.13355189381400123, 0.14793177688261494, 0.17854768404504284, 0.17251571553060785, 0.06653826669207774, 0.2545922464923933, 0.17278756422456354, 0.09866325694019906, 0.16258653660770506, 0.14463662635535002, 0.21702921367250383, 0.221544929954689, 0.13733990461332723, 0.11380655021639541, 0.1137818738061469, 0.14431815594434738, 0.1316183467861265, 0.12428521527908742, 0.12028014854877256, 0.16839955671457574, 0.16972434968920425, 0.20478003658354282, 0.09612773908884265, 0.09912010820698924, 0.1307548876502551, 0.09448239768971689, 0.12511178967542946, 0.14102030399953946, 0.08711222559213638, 0.12056870298692957, 0.13954200519947335, 0.10625167982652783, 0.19364483800018206, 0.14855387475108728, 0.1296216281480156, 0.15751910774270073, 0.13678957242518663, 0.1413623450207524, 0.11203847243450582, 0.12319336019572802, 0.12484811944887042, 0.10459689088747837, 0.11272072137217037, 0.11936754439375363, 0.22682349983369932, 0.09954737746738829, 0.16578954207943752, 0.13728424353757873, 0.111135716579156, 0.18715641897870228, 0.19675270013976842, 0.08721270496607758, 0.16541449032956734, 0.07568341112346388, 0.11468207667348906, 0.09621812525438145, 0.14062260190257803, 0.09546701243380085, 0.1416929272818379, 0.11528127186466008, 0.21247532131383196, 0.11066319115343504, 0.24164957692846656, 0.21114862844115123, 0.12549031467642635, 0.1696521684061736, 0.16229479835601524, 0.08421198668656871, 0.14723733445862308, 0.11048668617149815, 0.13418711285339668, 0.12784552032826468, 0.10505600570468232, 0.1815828899270855, 0.16809831897262484, 0.17350425623590127, 0.12078224855940789, 0.10333005964639597, 0.08483733516186476, 0.09610667693777941, 0.11016922508133575, 0.1770203886553645, 0.1578073579003103, 0.08675712277181447, 0.12301917071454227, 0.11816841928521171, 0.10565204676822759, 0.15424460376380011, 0.1329046074533835, 0.15021315368358046, 0.18419792148051783, 0.22791585215600207, 0.15564822766464204, 0.19197766261640936, 0.08346775357495062, 0.11416390174417756, 0.1335278630722314, 0.15917421580525115, 0.107385681476444, 0.09892739471979439, 0.17785782809369266, 0.19996983610326424, 0.08823375173960812, 0.24027241801377386, 0.09228117283782922, 0.20348267338704318, 0.1526644080877304, 0.21504061412997544, 0.2617789671057835, 0.08809079183265567, 0.11054012080421671, 0.1444167279987596, 0.097601867018966, 0.13746317534241825, 0.1841473812237382, 0.10280009199050255, 0.1531439839163795, 0.12157882534665987, 0.11029178334865719, 0.08944770495872945, 0.20708143652882427, 0.1457441778620705, 0.19021222688024864, 0.19552208570530638, 0.08908920310204849, 0.13069257693132386, 0.07647465186892077, 0.11910513581824489, 0.2138433072832413], [0.0062042404715612065, 0.015636266725778114, 0.028981634895899333, 0.023962805571500212, 0.08475408103549853, 0.042045931331813335, 0.06212731197592802, 0.03788720663578715, 0.0605514578637667, 0.03801369828579482, 0.019500395901559386, 0.026535718388913665, 0.010914903177763335, 0.10100698156747967, 0.026435858708282467, 0.04381977560115047, 0.023952311603352427, 0.04823073402803857, 0.032657941337674856, 0.023648945752938744, 0.029852580446458887, 0.04477504211536143, 0.025437796248297673, 0.04020203203253914, 0.024709539720788598, 0.08819625101750717, 0.036429754763958044, 0.03430054792261217, 0.04425969105795957, 0.06215123139554635, 0.03739758212759625, 0.06136201300250832, 0.027614587743300945, 0.08593840771936812, 0.01439760369976284, 0.0560455973027274, 0.03985035051300656, 0.02248425629659323, 0.018275711227033753, 0.07841790618840605, 0.020854414651694242, 0.02002927074499894, 0.05651934727211483, 0.12315559972194023, 0.011849826496472815, 0.06433042930439115, 0.02427942989015719, 0.043540279075386934, 0.06427670523407869, 0.05223691026913002, 0.04777679940161761, 0.029183220758568496, 0.04970936308382079, 0.04091438247996848, 0.029042754467809573, 0.07549396308604628, 0.014030312959221192, 0.03705685470777098, 0.025974908930948004, 0.0745459584868513, 0.028614318180189002, 0.037305733931134455, 0.07007806620094925, 0.059159374359296635, 0.051988947598147206, 0.06764855672372505, 0.08739464989048429, 0.02424210171739105, 0.01666343250690261, 0.05730994605983142, 0.032699334624339826, 0.015171328832366271, 0.02255013674584916, 0.016827935105538927, 0.015467809407709865, 0.026475274171389174, 0.005139070699442527, 0.03819997364189476, 0.07724511990090832, 0.03401051289984025, 0.016136388912855182, 0.03178391030814964, 0.008089809507509926, 0.05434469130705111, 0.009845356125879334, 0.019486957462504506, 0.06429747052607127, 0.015954980190144852, 0.043583498045336455, 0.10198503572610207, 0.02725856837059837, 0.11482877700473182, 0.045065166195854545, 0.05493011965882033, 0.03277412826719228, 0.06234160711755976, 0.03139338848995976, 0.04642327789042611, 0.03543686507327948, 0.09510405026958324, 0.01724843226838857, 0.030323139180836733, 0.03029818817594787, 0.00947047785302857, 0.0347021685593063, 0.026194187594228424, 0.0471988481876906, 0.11711087368894368, 0.02349258265894605, 0.03350952982145827, 0.06704658590024337, 0.053602851621690206, 0.02993723908730317, 0.036547463096212596, 0.020670400990638882, 0.026599877055559773, 0.01661610946030123, 0.03231736976886168, 0.041721601664903574, 0.03155714337481186, 0.025918782157532405, 0.04721552424598485, 0.04625801644579042, 0.07212117649032734, 0.026015467301476747, 0.019166750425938517, 0.05172838697035331, 0.06928127419087104, 0.008238123082264792, 0.06731326182489283, 0.02485994151356863, 0.06349753180984408, 0.13519821484806016, 0.01840959652327001, 0.04496629728237167, 0.054625271368422545, 0.02242891991045326, 0.06506211269879714, 0.03399436376639642, 0.0340410003263969, 0.030932063928048592, 0.00560376971407095, 0.043329780019121245, 0.07752163670375012, 0.02326866000657901, 0.024375387729378417, 0.046845686083543114, 0.04594149788317736, 0.07224039509310387, 0.09496612212387845, 0.03637272813648451, 0.04602313041687012, 0.15538587846094742, 0.028548610280267894, 0.0544056884245947, 0.023823380142857786, 0.04918415259453468, 0.02064307511318475, 0.02393680999375647, 0.004045123223477276, 0.010455024876137031, 0.08384875734918751, 0.03631553452578373, 0.02380747777351644, 0.01579321611643536, 0.0352035004470963, 0.03212827425159048, 0.02108087544911541, 0.021636027886415832, 0.05017998119001277, 0.035984555215691216, 0.012572428786370438, 0.06069203547667712, 0.030299592690425925, 0.062166159696062095, 0.03644529162556864, 0.027329747754265554, 0.027835243090521544, 0.04508950863964856, 0.03809155328781344, 0.11296433876850642, 0.015120394309633411, 0.0540622447442729, 0.044550293823704123, 0.054703178320778534, 0.07742785150185227, 0.02230715017503826, 0.023724540915281978, 0.007419392723022611, 0.05271699817967601, 0.029491553432308137, 0.04657614175812341, 0.05757994680607226, 0.025256031294702552, 0.006585755400010385, 0.03310674030217342, 0.011373662691767095, 0.013555750338127837, 0.050311341328779235, 0.034738860340439714, 0.033775367119233124, 0.0680643820669502, 0.013496645697159693, 0.020610463288903702, 0.053366989668575116, 0.04099322082765866, 0.04498485097428784, 0.026751661098387558, 0.052774117575609125, 0.08773628273047507, 0.032701100935810246, 0.03126698218693491, 0.01444280142095522, 0.02599240320705576, 0.014021685492480174, 0.03128465272311587, 0.0630010869645048, 0.10415269323857501, 0.051912183553213254, 0.09342558681964874, 0.04762452554132324, 0.026219275896437466, 0.025012666228576563, 0.07563288570963778, 0.027563394396565855, 0.03222797065973282, 0.06648246460827067, 0.036850812248303555, 0.023760963667882606, 0.01544553477287991, 0.022418954722525086, 0.09738642154843546, 0.02506924756744411, 0.03948790785216261, 0.024169729331333656, 0.060918676244909875, 0.01803913495677989, 0.07792002157657407, 0.04615722536982503, 0.028829503899032716, 0.033718574268277735, 0.06081539155275095, 0.055470848456025124, 0.030326445448736195, 0.04528151337581221, 0.0881688657682389, 0.058117180087720044, 0.008090219544101274, 0.033159681406687014, 0.032973855049931444, 0.016002139964257367, 0.019264392940385733, 0.02131784876837628, 0.0761575173237361, 0.032323744817404076, 0.026958787093462888, 0.023897797145764343, 0.03421111170609947, 0.026742944573925342, 0.015956019196892157, 0.006385704391504987, 0.03565501938282978, 0.04569553158944473, 0.04240894915710669, 0.019940031197620556, 0.03401701782422606, 0.035517525393515825, 0.05474349920405075, 0.018655791027413215, 0.05633359513012692, 0.06385644184774719, 0.021026427784818225, 0.021140403114259243, 0.005698651903003338, 0.03184225053701084, 0.03210565359040629, 0.06095013588492293, 0.0518559139163699, 0.04510605111136101, 0.06513390806503594, 0.030714243584952783, 0.017795357998693362, 0.022936220520932693, 0.022117854277894367, 0.031077534149517305, 0.11066224120440893, 0.040181467120419256, 0.04208847494737711, 0.04618608007149305, 0.03708501179062296, 0.04938745652907528, 0.04934140626573935, 0.09424355230294168, 0.039877279341453686, 0.046784774312982336, 0.0034385990920782206, 0.024735919359955005, 0.015548085666523548, 0.11085988255217671, 0.07726045267190784, 0.05020688033255283, 0.02479587376001291, 0.0351534388755681, 0.023214442408061586, 0.034280417166883126, 0.032206448377110064, 0.053852539786021225, 0.03449910582276061, 0.06066964859201107, 0.09622613302781247, 0.04200452320219483, 0.07199923420557752, 0.04329251307353843, 0.021662954859493766, 0.01709616026346339, 0.022781757324992213, 0.03173985271132551, 0.029683561879210174, 0.013451148333842866, 0.09646672988310456, 0.0357540330151096, 0.040502820775145665, 0.025528236219543032, 0.0878568297775928, 0.03937334622605704, 0.07273281007655896, 0.03417305437324103, 0.02316574267752003, 0.0361790535680484, 0.020188400194456335, 0.014110584579611896, 0.06587537296582013, 0.004951543432980543, 0.03672429833386559, 0.03515792886901181, 0.04886866190645378, 0.018390024233667646, 0.08456714887870476, 0.030005754160811193, 0.029707802277698647, 0.0637892700615339, 0.03970363533881027, 0.012880744761787355, 0.05666510136506986, 0.02428133720968617, 0.03679050161736086, 0.035998555831611156, 0.07777951075695455, 0.028326854699116666, 0.01712600944301812, 0.04772422937094234, 0.0486671242833836, 0.0848183139169123, 0.10520724055822939, 0.16928287572227418, 0.16149700444657356, 0.17156382207758725, 0.13325065607205033, 0.1254719539429061, 0.1822196674766019, 0.10239568087854423, 0.18330030870856717, 0.21389059693319723, 0.13185109914047644, 0.11471738805994391, 0.19382722821319476, 0.1450100602232851, 0.1562807452864945, 0.13884931424399838, 0.11671861895592883, 0.15529422322288156, 0.14083944261074066, 0.08503938486683182, 0.08816283210762776, 0.14866602810798213, 0.11140759495901875, 0.16439834173070267, 0.2596708224155009, 0.14515935064991936, 0.11842633044579998, 0.10878889719606377, 0.154137066565454, 0.12244655925314873, 0.16811031207907945, 0.1773238231544383, 0.190996587916743, 0.10048598647699691, 0.18232721951790154, 0.16556516115088016, 0.0982601816940587, 0.10407548761577345, 0.13548613846069202, 0.2188826829660684, 0.2550121833337471, 0.1355571174644865, 0.24760042870184407, 0.0999842352757696, 0.12598071101820096, 0.08419213423621841, 0.11524144822033122, 0.14777260104892775, 0.12559685739688575, 0.13423423923086375, 0.11240505627938546, 0.17545748502016068, 0.20100228226510808, 0.079169738892233, 0.1728734900825657, 0.2000692838919349, 0.159273975295946, 0.12589659600052983, 0.22081332077505067, 0.09854216070380062, 0.09762795350980014, 0.2216302917804569, 0.12429913796950132, 0.1085511724522803, 0.13899257843149826, 0.2068055802374147, 0.11864096697536297, 0.11111583444289863, 0.21316327736712992, 0.1725154186715372, 0.15944489190587774, 0.0922332375193946, 0.09027842053910717, 0.059084231907036155, 0.11189529730472714, 0.13660789467394352, 0.17355175368720666, 0.1627542619826272, 0.0911562773399055, 0.14866267360048369, 0.08512097658240236, 0.12449880538042635, 0.1634456467581913, 0.16822501842398196, 0.1410923368530348, 0.2873433125205338, 0.12674645899096504, 0.10080142150400206, 0.20009074680274352, 0.10466466381330974, 0.14096949656959623, 0.1559533245745115, 0.1652745361207053, 0.09612094843760133, 0.14651406701887026, 0.13748989265877753, 0.10624664806528017, 0.12398842300171964, 0.14948052034014836, 0.16716174344765022, 0.13322865881491452, 0.1564489901647903, 0.13941352459369227, 0.15293889882741496, 0.10339686035877094, 0.1068390451837331, 0.16513253358425573, 0.1580754661699757, 0.2309397773933597, 0.12064451337209903, 0.1804532075766474, 0.2180321965715848, 0.1401486515533179, 0.19952916365582496, 0.11520788088091649, 0.18011045409366488, 0.09616696901503019, 0.13057215604931116, 0.13472993450704962, 0.10887070413446054, 0.11075584829086438, 0.16792188078397885, 0.2919646364171058, 0.1573726671631448, 0.12049229146214202, 0.10496127797523513, 0.133303007169161, 0.09111565959756263, 0.14296073815785348, 0.1374178152764216, 0.1088139669445809, 0.3209007962141186, 0.09825687913689762, 0.2349466920713894, 0.1530382872442715, 0.24959043832495809, 0.12498370982939377, 0.22071333864005283, 0.1387553583481349, 0.13428014848614112, 0.1269947222317569, 0.1658115690224804, 0.16353728715330362, 0.20486054476350546, 0.1480670110322535, 0.11842883148347028, 0.19819166511297226, 0.13333071896340698, 0.16611556755378842, 0.11200577340787277, 0.087619973346591, 0.1602561483741738, 0.11581497252336703, 0.20776431629201397, 0.1602583154453896, 0.12868153484305367, 0.1422081410419196, 0.14041343500139192, 0.09361008473206311, 0.18311940279090777, 0.2682331879623234, 0.12640762404771522, 0.10753533555543981, 0.10379079976701178, 0.14824447338469326, 0.13851417519617826, 0.12027589604258537, 0.14843713492155075, 0.10819686372997239, 0.18465861707227305, 0.14988925075158477, 0.11879356738063507, 0.1108094907249324, 0.0989928818307817, 0.2500170248094946], [0.028448130906326696, 0.024201307714974973, 0.019994606882391963, 0.04641904764866922, 0.06939978775335476, 0.031750851339893416, 0.07996815620572306, 0.08262565344921313, 0.024383453019254375, 0.07822816871339455, 0.04388528126582969, 0.013359738932194887, 0.022190232230059337, 0.018324724514968693, 0.019455557194305584, 0.04176443471806124, 0.043133901272085495, 0.030773312973906286, 0.029106031834089663, 0.008929509713198058, 0.14118696068180725, 0.044079330618842505, 0.06364599103108048, 0.032262647509924136, 0.02851227473001927, 0.08403733707382344, 0.025066123125725426, 0.08943655047914945, 0.008381074640055886, 0.022567380547116045, 0.007172109581006225, 0.018543864025559742, 0.00916179265914252, 0.025054040961549617, 0.04660179780330509, 0.036511554280878045, 0.124091344041517, 0.053178844100330025, 0.09987694298615679, 0.016873469576239586, 0.03955250438593794, 0.04005470087577123, 0.05092435530968942, 0.03149468422634527, 0.05152778445335571, 0.021766525278508198, 0.008200951688195346, 0.046300211251946166, 0.013071106568531832, 0.03901642143318895, 0.05286921266815625, 0.05344215809600428, 0.012076789171260316, 0.020992472673242446, 0.054892344342079014, 0.05114837258588523, 0.06746315339114517, 0.02256835090520326, 0.030770010416745208, 0.05496218414918985, 0.05427960495580919, 0.0550243427278474, 0.030961376905906945, 0.07387005491182208, 0.011984569900960196, 0.02847695221134927, 0.06375207361998037, 0.0675635362858884, 0.01950137553649256, 0.04110186011530459, 0.044336306673358195, 0.016964904025371652, 0.02836974341335008, 0.027356760074326303, 0.025922869535861537, 0.01958923283382319, 0.042807118807104416, 0.082108547212556, 0.02489992286427878, 0.06863003218313679, 0.033457330864621326, 0.02869878757337574, 0.03609992207202595, 0.03051317537028808, 0.02496132074156776, 0.04513209678407293, 0.08246529760072008, 0.060544633815879934, 0.07521522726165131, 0.030132538959151134, 0.04301577362639364, 0.053560987071250565, 0.03532208822434768, 0.03390537283848971, 0.032810935081215575, 0.00631859986242489, 0.02224255178589374, 0.03683265560539439, 0.03891404216119554, 0.033134541154140607, 0.031804304526303895, 0.03241004917072132, 0.05762910295743495, 0.04268990029231645, 0.0507161865971284, 0.0532832457247423, 0.04185172241705004, 0.033029983678716235, 0.03233753021049779, 0.022960345886531286, 0.008669320159242488, 0.06978465069551021, 0.028822844979004003, 0.023847750417189673, 0.017858147402876057, 0.06954917465918697, 0.05737849081924651, 0.060893832851434126, 0.0705376040423289, 0.052691676100948825, 0.021119840057508554, 0.03710834862431511, 0.044633091529249214, 0.042299430424463935, 0.018605883451527916, 0.07697642533457838, 0.023576738494739402, 0.13490634300978854, 0.023848841374274343, 0.0352210967685096, 0.049336715892422944, 0.035894217289751396, 0.019867976079694927, 0.01881279607914621, 0.04050727737194393, 0.061459137868951075, 0.054424260670202784, 0.01651235535973683, 0.019356820012035314, 0.04143714017118327, 0.03363898264069576, 0.07871134395827539, 0.07225581692182459, 0.014336527729028603, 0.03860973934934009, 0.049768170865718275, 0.0018122559777111746, 0.09171934478217736, 0.09297029406297952, 0.01461922383896308, 0.04891175100055989, 0.016406543654738925, 0.016733279735490214, 0.021680742283933796, 0.00435857022239361, 0.026024493672593962, 0.0362684675201308, 0.04220256530970801, 0.04741105418361258, 0.05334753426723182, 0.032509582306374796, 0.015566373112960719, 0.029126058689143974, 0.06776317401090637, 0.049858323254738934, 0.02864121546735987, 0.10144653337192722, 0.06689233050565235, 0.016806859966891352, 0.0667754199821502, 0.008016806295927381, 0.019109055865556, 0.01053836527717067, 0.053657703756471165, 0.01887058897409588, 0.02250874531455338, 0.01880119445559103, 0.024722813031985424, 0.024896347567846533, 0.030174997227732092, 0.01755441233399324, 0.026813279764610343, 0.06959484642720781, 0.05877486022654921, 0.019372844835743308, 0.0686693808529526, 0.013203154121583793, 0.036249494514777325, 0.038811147096566856, 0.04414036484376993, 0.05671194943715818, 0.034508163735154085, 0.05072181949799415, 0.05496267767739482, 0.027013774670194834, 0.08390920527745038, 0.06918095808941871, 0.030615144605690148, 0.040031983735389076, 0.06363764186971821, 0.012063862814102322, 0.06186463622725569, 0.024697604130778927, 0.06980724167078733, 0.02286423961777473, 0.01705139391560806, 0.06459548734710552, 0.04070466267876327, 0.013734769345319364, 0.0316912976995809, 0.042008130039903335, 0.019222530245315284, 0.03253272247093264, 0.02002967150474433, 0.026668432947190013, 0.031843909237068146, 0.03509212634526193, 0.06160709985124413, 0.043575946692726575, 0.04136403491429519, 0.018402323476038873, 0.023487853322876617, 0.0469701145630097, 0.07989807520061731, 0.03817064396571368, 0.01923679061292205, 0.04193099863186944, 0.03529331886966247, 0.04161698481766507, 0.014089866599533707, 0.01226714262884343, 0.021824323739565443, 0.0232942474031006, 0.006899243680891232, 0.03247223372454755, 0.011563779589778278, 0.03576104631065391, 0.11348424290190451, 0.057933316711569205, 0.04273637729056645, 0.044885789102409035, 0.03923059040971566, 0.042979723803000525, 0.08323349466081709, 0.06946920824702829, 0.027872801329067443, 0.047413506981683895, 0.020794126285181846, 0.021382816375989933, 0.025297079482697882, 0.04512681640335359, 0.0309851126439753, 0.05680409820342902, 0.06294189326581545, 0.01362408636850887, 0.10925144073553383, 0.0519364740466699, 0.03431260782235768, 0.017042308172676712, 0.02706714436499169, 0.05342240954632871, 0.007573920393042499, 0.08374696437385865, 0.09743083908688277, 0.006666410617981455, 0.03202844425686635, 0.054849014049977995, 0.06496011192211881, 0.016860635987541173, 0.022167832357808948, 0.06674810152617283, 0.05503244698047638, 0.047892667207634076, 0.06399077799869701, 0.011951865308219567, 0.01626896431844216, 0.027731236659747083, 0.04285562928998843, 0.03700770597788505, 0.053170535757089965, 0.02554985498136375, 0.029978227903484367, 0.02766734702163376, 0.03541322766977828, 0.06952207142603584, 0.014987774375185836, 0.03251425412599929, 0.07644457262358628, 0.05237015175225679, 0.02760666346148355, 0.019373486793483607, 0.04303768182580825, 0.0665670917078387, 0.03408646800380666, 0.07287073822226375, 0.04683598621340934, 0.015330064015870448, 0.019659495665109716, 0.026237566125928424, 0.04399677040055394, 0.010205222606600728, 0.0408238367526792, 0.03308500279672444, 0.057327616596012376, 0.01494854908742127, 0.026999636756954715, 0.015460081795026781, 0.01804954543331405, 0.13788326061330736, 0.0046025554456718965, 0.03916507361282129, 0.026079753988597076, 0.011501795415824745, 0.02256136172945844, 0.007030844089968014, 0.052417393162613735, 0.04248753888532519, 0.03733386874955613, 0.030822034968878143, 0.020265268140065018, 0.054903098061913624, 0.031575559769407846, 0.02648603531270055, 0.06644836292252876, 0.0446534115326358, 0.04446193743206095, 0.04676602766267024, 0.07459269152604975, 0.03847420834063087, 0.06625880356295966, 0.005092166966278455, 0.04580051579978317, 0.033452510615461506, 0.02333201529836515, 0.0430687666812446, 0.0015710952061454009, 0.02924719017755706, 0.049512411933392286, 0.06895040991366841, 0.039935163149493746, 0.08712032984476537, 0.017168543781735934, 0.0981177858193405, 0.03615237706981134, 0.03517238961649127, 0.046672587559442036, 0.010895614759647287, 0.1037242662278004, 0.006876269571876037, 0.046752309062867425, 0.03321896045235917, 0.010808990355144488, 0.07006622152402997, 0.19302775705000386, 0.11351219218340702, 0.16433335928013548, 0.14826908300165087, 0.12009873054921627, 0.19694877555593848, 0.14392794953892007, 0.1004020198888611, 0.12114852070226334, 0.09032313493662514, 0.1286654153955169, 0.11942126846406609, 0.07585217550513335, 0.11324067745590582, 0.12677813385380432, 0.14276549394708127, 0.1598615781404078, 0.09986886841943488, 0.14428689668420702, 0.1631358001031913, 0.11811175631009974, 0.18220221216324717, 0.23156678827945143, 0.10166338150156662, 0.11677853253786452, 0.11132947649457492, 0.142063882376533, 0.12437343437341042, 0.13503497204510495, 0.13135423127096146, 0.11921161916689016, 0.1297149309539236, 0.08183098398149014, 0.12905820447485894, 0.07320037053432316, 0.1776343525853008, 0.14437200617976487, 0.11539769257069565, 0.11416971276048571, 0.20982852583983913, 0.1434854810941033, 0.14234788744943216, 0.13963465491542593, 0.1430771069135517, 0.10952567914500833, 0.12628236436285079, 0.24686432210728526, 0.15158670576056466, 0.12405097862938419, 0.17520821245852858, 0.1414604124147445, 0.12826603604480624, 0.09491461707511917, 0.15092211251612753, 0.19207837205613032, 0.1921142326318659, 0.0957490953442175, 0.11505950329592451, 0.17423697863705456, 0.16172159317648038, 0.24864115723175928, 0.1983852023840882, 0.3004194499226287, 0.12880574067821726, 0.169623966794461, 0.16195597825571895, 0.211000926210545, 0.1308417337713763, 0.10390186216682196, 0.1320236930041574, 0.18906721175881103, 0.0867780736007262, 0.10708927511586808, 0.16984891175525263, 0.08535972548997961, 0.1416490218252875, 0.14301898190751672, 0.12118830723920837, 0.2032732986845076, 0.10978206890285946, 0.14880580420140177, 0.11319142853608355, 0.11010097718099132, 0.1638426660792902, 0.11372118096915074, 0.1551574602490291, 0.216717645234894, 0.143833949114196, 0.14818832249147817, 0.09945896541466936, 0.07147243552026339, 0.13686469261301681, 0.10310573066817597, 0.2229970903135836, 0.21200934163061902, 0.13112833636114374, 0.10983044950990006, 0.09971225299523212, 0.11114583947346546, 0.10761450786958449, 0.11164695242769085, 0.11086766768130474, 0.16201879363507032, 0.08695008858921938, 0.19858469167957082, 0.11041132849641144, 0.1339626280241646, 0.14264536992413923, 0.10037764033768326, 0.09390527397044934, 0.15539353742497042, 0.13595366181107238, 0.1356879877857864, 0.06760161588317715, 0.14150553499348462, 0.1723180222325027, 0.13282139785587788, 0.18357138556893915, 0.12537534115836024, 0.07111561091733165, 0.19151065876940265, 0.10959121078485623, 0.17433805915061384, 0.13360599637962878, 0.15502154332352802, 0.08650710806250572, 0.20955118525307626, 0.10386985333752818, 0.11580046353628859, 0.15470690239453688, 0.129346217145212, 0.2157627238193527, 0.09283634382882155, 0.11375013957149349, 0.13667746359715238, 0.08653077515191399, 0.09294709452660754, 0.058451699442230165, 0.07284116363734938, 0.13764894974883646, 0.11764038863475434, 0.20135628670686856, 0.08905032198526897, 0.14326976845040917, 0.08939449297031388, 0.13386052334681153, 0.2108581963693723, 0.21461101452587172, 0.1186686713481322, 0.10089352203067392, 0.13608276582090184, 0.1268847062601708, 0.20320842013461515, 0.10759619908640161, 0.15968447201885283, 0.09363557008327916, 0.07004788305494003, 0.11638109019258991, 0.14512617664877325, 0.13858988910214975, 0.11565308042918332, 0.12215100636240095, 0.14102606306551024, 0.20015924703329802, 0.09351516404422, 0.20242505357600749, 0.09163917056866921, 0.12138456077082083, 0.17401040095137432, 0.1696232840185985, 0.19322194741107523, 0.10245385783491656, 0.20747591770486906, 0.1216383084829431, 0.11878703648108058], [0.05627698039461393, 0.01124512828027946, 0.04116615979000926, 0.027663395085255615, 0.01809436929761432, 0.011167859574925387, 0.01878534774732543, 0.05764969013398513, 0.020155116726527922, 0.08200525509892032, 0.012633026999537833, 0.05164526643056888, 0.032273846518364735, 0.027966274828941096, 0.02198628819314763, 0.023248837242135778, 0.0318375898496015, 0.028031730398652144, 0.03098902561760042, 0.01140060265242937, 0.0764898955821991, 0.03702527632412966, 0.042521243522060104, 0.052798768010688946, 0.02008142702834448, 0.042587264979374595, 0.019184452503395732, 0.034078545577358454, 0.05265231629891787, 0.030338067481352482, 0.02434774643916171, 0.05007311934605241, 0.05905738100409508, 0.041305698396172374, 0.041402886345167644, 0.015970971617207397, 0.043338674659025855, 0.03463754605036229, 0.07681528280954808, 0.016567090606258716, 0.00795316620497033, 0.02974712126160739, 0.01855749542301055, 0.008187481707864208, 0.02729618969169678, 0.03488615810056217, 0.05842663340445142, 0.04654728705645539, 0.08628832292743027, 0.02946306238300167, 0.02045845474640373, 0.01769548161973944, 0.04349465925770346, 0.025430293135286774, 0.03928494159481488, 0.02760323288384825, 0.07112727747880854, 0.018146143374906387, 0.06574586819624528, 0.04009988653706387, 0.022312168948701583, 0.06943955944734626, 0.07565429667010903, 0.04482388656469993, 0.07567461667349562, 0.032498071595910005, 0.08829399186652154, 0.03820294594333973, 0.04180969830485992, 0.02723848956520669, 0.0387295368273044, 0.04205159762932453, 0.035260170843685046, 0.022608580875385087, 0.04864777649345342, 0.07594153750687838, 0.004771995645569405, 0.05408101736975368, 0.03207434609066695, 0.007850473375583533, 0.006017855184836662, 0.019791048762272112, 0.05154174054041505, 0.09526261012069881, 0.04238541194354184, 0.05936122368439101, 0.04537406290182844, 0.054287987513816915, 0.041702380040078424, 0.035942471731686965, 0.08262485192972235, 0.07669590835575946, 0.04002411325927824, 0.043539477555896156, 0.06519881630083546, 0.04395798947371077, 0.04671458198572509, 0.0970838702050969, 0.08790621228399687, 0.061962466133991256, 0.02861303055397002, 0.019668327222461812, 0.06064792592951562, 0.018534598311816808, 0.038368433743016794, 0.012866884226241382, 0.06173821137053892, 0.08567078926716931, 0.06745875987689942, 0.022821441816631705, 0.03704787101014517, 0.016611615756119136, 0.037744120563729666, 0.01400096844008658, 0.06344730325508863, 0.025780128562473692, 0.03915308050636668, 0.03016836242750287, 0.01869568703114055, 0.037571686261799186, 0.029572362182079814, 0.061873571685282513, 0.061971093600732274, 0.1326245060772635, 0.04415236908243969, 0.048603885879856534, 0.10092628785059787, 0.06996848809649237, 0.03910634004569147, 0.03971426289353985, 0.014304579199233558, 0.05261048885586206, 0.07476567872799933, 0.04621008483809419, 0.027744135186367203, 0.01349786560240318, 0.02461641688569216, 0.023443509999196976, 0.0385571507649729, 0.0702634769550059, 0.06341834465274587, 0.035316447902005166, 0.02555032253440004, 0.04395174801175017, 0.12951425422215834, 0.023808852602087427, 0.03276236522651743, 0.016646179428789765, 0.02104167335346574, 0.11716001128661446, 0.04363562278740574, 0.022161403503559995, 0.011312355727568502, 0.05155825332622044, 0.04738832220027689, 0.019310678835608996, 0.029678270366275683, 0.028603926257346757, 0.02620978011691477, 0.03932799358153716, 0.028976462126593105, 0.023189702915260568, 0.04461051168618724, 0.0780787892290391, 0.09974785381928086, 0.03570701795979403, 0.016468477733724285, 0.03389055586012546, 0.0661209125246387, 0.08072173295659013, 0.011710724829754326, 0.02530490357457893, 0.00608813564213051, 0.06444922488299198, 0.03270031054853462, 0.042290936544304714, 0.011844096188724507, 0.02303019311511889, 0.031208701329887845, 0.017282691660511773, 0.03133219470328186, 0.05318177558365278, 0.05200623592827469, 0.048373293175245635, 0.0769655306066852, 0.052128642055322416, 0.027177614902029745, 0.0037530470626734314, 0.01969235610886244, 0.05341782307368703, 0.023829851670598146, 0.035423617737251334, 0.04622704291250557, 0.1155979314353317, 0.036093732560402714, 0.03863395191729069, 0.07718938461039215, 0.04570354678435251, 0.029298183144419454, 0.01734218036290258, 0.006630518037127331, 0.011271391031186795, 0.02121461417118553, 0.028123732590756845, 0.02444538338750135, 0.05906004902499262, 0.02434711561363656, 0.06621797059779055, 0.05124844748934265, 0.024949301659944467, 0.02441066571918782, 0.03588628002034966, 0.02648017976753181, 0.013998652011650847, 0.020161616084806155, 0.05220924300374463, 0.07055776077322662, 0.021732516361225862, 0.01771434886904899, 0.036701855788123794, 0.04730419233965222, 0.04411922847793903, 0.017089833454519976, 0.057109276749542914, 0.04722592915641144, 0.04479248629650101, 0.014546220627380535, 0.005107783608764294, 0.025576425723556895, 0.03864175931084901, 0.025938690268958453, 0.04359329439466819, 0.051445662102196366, 0.12358859094092622, 0.08710717156645842, 0.06384660096955486, 0.02892587177484529, 0.06283443028223701, 0.011472794139990583, 0.040792596046230756, 0.04537674205494113, 0.0347591135505354, 0.047418694593943655, 0.03318225011753384, 0.03198880243871827, 0.037503312196349725, 0.011672447635646677, 0.10879902009037323, 0.07302574318600819, 0.02027610535151325, 0.04256954249285627, 0.05109166508191265, 0.021100225094414782, 0.05358256501494907, 0.060895896021975204, 0.002814985618897481, 0.03827126063697506, 0.03102843551459955, 0.08416396973188967, 0.1133109736838378, 0.04475970934436191, 0.05825731612276286, 0.03590544227336068, 0.040980819539981894, 0.01162627306257491, 0.02953811206680257, 0.019707861429196782, 0.024013047113840003, 0.026227845846733544, 0.0070148146278370405, 0.061943129476276226, 0.058845683379331604, 0.025762307741388213, 0.04564068316540215, 0.059563655595411547, 0.065608622826403, 0.026253975011059083, 0.08193985704565421, 0.01867404229415115, 0.021086896122142207, 0.038702377933077514, 0.04846046955208294, 0.011656944170681527, 0.10410175222204998, 0.016280345153063536, 0.019519981178746093, 0.024773269797151443, 0.02080834954540478, 0.022099517664173618, 0.05033323468524031, 0.08126623186399229, 0.017617724952287972, 0.039513463707407936, 0.053070156573085114, 0.0117549503374903, 0.01832868016208522, 0.032782165726530366, 0.04837313732423354, 0.05206476169405505, 0.06074067212466616, 0.05288896121783182, 0.05447984382044524, 0.11048793297959492, 0.018480109829397406, 0.0549944638623856, 0.03925388271454722, 0.0359585986007005, 0.07554062191047706, 0.057891222095349804, 0.01855790731497109, 0.029782686833641492, 0.022801821287430357, 0.03831922193057835, 0.04593349753122311, 0.08064820838626474, 0.053502724767895415, 0.04946051354636438, 0.07627420520293526, 0.05244469677563757, 0.025422843827982433, 0.09204344067256898, 0.0401178947504377, 0.04033142547996249, 0.06748696891008876, 0.016279308001685422, 0.04847285970754456, 0.06233165491721593, 0.032630170171614736, 0.03517051198286936, 0.019236579100834206, 0.05381640832638368, 0.01851079021434998, 0.03082679399085464, 0.09739096349221654, 0.07694826083024964, 0.03435236467339564, 0.023803145486454014, 0.02012805616686819, 0.009512704200460576, 0.043376212488510646, 0.03381287526281085, 0.010037215215561446, 0.038902126980246976, 0.08701162005309016, 0.02830159013683442, 0.037158465856919065, 0.05105239433760289, 0.023075427016010508, 0.019187313482689206, 0.010974289834848605, 0.03176287042151671, 0.05198397149797529, 0.12537887378130108, 0.10595891741104424, 0.12547946447739378, 0.08428824236034416, 0.057805121832643636, 0.19469695107545704, 0.12202456666273065, 0.10975870609399863, 0.10421064012916759, 0.30386681493837386, 0.11128882906632498, 0.08221386538934894, 0.14500314340693876, 0.13298665930051357, 0.09136093940469436, 0.11578700839891098, 0.1939302679966204, 0.19521744892699644, 0.12578663940075785, 0.11054389091441408, 0.16362753231078386, 0.09525779358227737, 0.20446168491616845, 0.15026344161015004, 0.04668167144700419, 0.1806482143001631, 0.185597151867114, 0.1859654055442661, 0.1317752368049696, 0.12137246376369148, 0.1338192747789435, 0.13404914760030806, 0.15479949273867533, 0.08397104102186859, 0.107020285067847, 0.11655700887786224, 0.10903037720709108, 0.13283230742672458, 0.10777032919577323, 0.11657164403004572, 0.14484252780675888, 0.07398663146886975, 0.05922089098021388, 0.09534218319458887, 0.13327336579095572, 0.137434899515938, 0.18970985227497295, 0.13564212305936962, 0.2726509259082377, 0.136206095921807, 0.2031654943129979, 0.1277159561868757, 0.10078058199724182, 0.08231413696194068, 0.09239822436938994, 0.13492427329765633, 0.15742826886707917, 0.18629861500812694, 0.31769730092491955, 0.12776373565429822, 0.13457121880492195, 0.19415871589444578, 0.13680241157999262, 0.14606270764488727, 0.15380678116343915, 0.062466354720527306, 0.09975322696845978, 0.11864547181176022, 0.17420064308680594, 0.1277682775980793, 0.08743592072278261, 0.23174585367087275, 0.18950295634567738, 0.11451723825302906, 0.18435452948324382, 0.17993294721236452, 0.12118283018935472, 0.13606007094494998, 0.14634240826126188, 0.056977077983901836, 0.11418750204029493, 0.09414368149009533, 0.23315069469390437, 0.2112822001799941, 0.11009843161446042, 0.22192082775291055, 0.14977631071815267, 0.13023130246438086, 0.15799417131347582, 0.08506361598847434, 0.14125470392173156, 0.1771447726059705, 0.09898620992316864, 0.1599846559111029, 0.09926159124006517, 0.1928238000255078, 0.12051895682816394, 0.14031956816324964, 0.2675339364213869, 0.2989763586083427, 0.17419000068912283, 0.20777368219569325, 0.1468698080861941, 0.10048183787148446, 0.17540651431772858, 0.10690222421544604, 0.1561242263414897, 0.16632532817311585, 0.12001724273432046, 0.07699490481172688, 0.13491702993633226, 0.06603083063964732, 0.11179084744071588, 0.12610512465471402, 0.25331723678391427, 0.12268797247088514, 0.09947531492798589, 0.11152888415381312, 0.0994404339871835, 0.17164968856377527, 0.114750213251682, 0.162705042748712, 0.17095454852096736, 0.1831254587159492, 0.15542613255092874, 0.0984460451581981, 0.24464915972203016, 0.12160267055151053, 0.09353592933621258, 0.1734991354169324, 0.11340084776747972, 0.12120949555537663, 0.26353007939178497, 0.13976427842862904, 0.1762671087635681, 0.10519664268940687, 0.11597984805121087, 0.10057416846393608, 0.1929239899618551, 0.16544503712793812, 0.15119884454179555, 0.16960468579782173, 0.12057821732014418, 0.14147225709166378, 0.29063013615086675, 0.14565103832865134, 0.08012184014660306, 0.18629432539455593, 0.08634891186375171, 0.13436303153866902, 0.19686471991008148, 0.22110295132733881, 0.11844337015645579, 0.10517068978515454, 0.09722753515234217, 0.0838786362146493, 0.0943866309535224, 0.12566954334033653, 0.14865522243781015, 0.06722615595208481, 0.09166547970380634, 0.11547463102033362, 0.08442674938123673, 0.11189117096364498, 0.13574565266026184, 0.08384832690353505, 0.13503969210432842, 0.1837848123977892, 0.23718809679849073, 0.17867641698103398, 0.08619430765975267, 0.19136009184876457, 0.12120099796447903, 0.11100755509687588, 0.12825724901631474, 0.15351793728768826], [0.04168252016825136, 0.019740454699785914, 0.03831882117083296, 0.04190135354292579, 0.024987603901536204, 0.05478659943037201, 0.012584984069690108, 0.032044125837273896, 0.02804743609885918, 0.0618795274203876, 0.013976332847960293, 0.01783068979420932, 0.03161811451718677, 0.02167790171370143, 0.023703330334683415, 0.05116253647429403, 0.10542947668000124, 0.030443016439676285, 0.03654363732493948, 0.02218011304648826, 0.05251925664197188, 0.025012194964801893, 0.05904861995077226, 0.03586626800824888, 0.04759311785164755, 0.0244946601378615, 0.04672399612900335, 0.11343330930685624, 0.039598395087523386, 0.026627857878338546, 0.018962444592034444, 0.013101536478643538, 0.02621366711537121, 0.03644628610345535, 0.03278066658822354, 0.04445010388735682, 0.042336381957284175, 0.03016431215655757, 0.03993029837147333, 0.029842709882359486, 0.023506353209086228, 0.05512575720786117, 0.03012962974025868, 0.08177757161320187, 0.008992755538201891, 0.0064986922006937675, 0.01072784763891832, 0.05531768772925716, 0.048296083841705695, 0.06721578072756529, 0.02769219412584789, 0.07862122496590018, 0.031108908442547545, 0.0540766090125544, 0.06155854483949952, 0.033834835412562825, 0.09074591420358047, 0.036154714834992774, 0.017461085408285726, 0.0396324967732653, 0.015123557714105118, 0.027669258051901124, 0.026322545745642856, 0.022926537349121645, 0.033976789709413424, 0.020619185379473493, 0.04964305961038917, 0.02855293143511517, 0.11895827963599004, 0.03522393548337277, 0.0655979804287199, 0.02939602047263179, 0.04345566681877244, 0.0386273987533059, 0.018989577511092648, 0.011203038302483037, 0.03454521174717229, 0.0367964907491114, 0.042287611722713336, 0.03874755617289338, 0.05118317189044319, 0.032743514675530605, 0.05645907003781758, 0.01636060100281611, 0.032016903860494494, 0.06233457155758515, 0.06144524857518263, 0.004874976984865498, 0.03399124303541612, 0.05917041009524837, 0.030651174020022154, 0.04825701718800701, 0.027471063804114237, 0.041711860976647586, 0.029188753469497897, 0.07490435644285753, 0.03474275661574211, 0.06169440610392485, 0.024578600750828627, 0.04069046539370902, 0.03292499575763941, 0.0349062257737387, 0.02372426817601081, 0.043792713186121546, 0.0774580791767221, 0.010470858596818289, 0.03831054251349997, 0.05203534667089116, 0.024719222892599646, 0.025327221810584888, 0.024606021252111532, 0.0030420032589972834, 0.0442858666065149, 0.044153497146908194, 0.03910574261681177, 0.023848301461839583, 0.0827023247256875, 0.008367123191419523, 0.029022044836892746, 0.015954108166624792, 0.0384865947853541, 0.05585478000284638, 0.06757814175216481, 0.04284088652639184, 0.014305062522907974, 0.03784786538744811, 0.017077550910471473, 0.057039388702833094, 0.007811249015503563, 0.024880973978724796, 0.051776300024357624, 0.035832923313137144, 0.07550856855232269, 0.07835457130568102, 0.02782245588605292, 0.028875223906652536, 0.030510230899380986, 0.03454734542174265, 0.014689826202811673, 0.018645508571353275, 0.02588150407973444, 0.03933487329049967, 0.030461939350061584, 0.04629056333214976, 0.04957973214914091, 0.012804926955141127, 0.008015764506126288, 0.06071968418837059, 0.04312270968512166, 0.0279849973594537, 0.0286670366403996, 0.06709990921081044, 0.11074021123931743, 0.03453798693954013, 0.018884250057453755, 0.021107217980897985, 0.07920366246253252, 0.011987010639131768, 0.031196010604617186, 0.05778672028100118, 0.019601298299676273, 0.045209439704194665, 0.013046291005593957, 0.03890145162586123, 0.061026421244605444, 0.05293805057590362, 0.014581554278265685, 0.07292255497304723, 0.07592172958538868, 0.051426117643131875, 0.010520229971007211, 0.0014193554602570657, 0.047716559274704196, 0.04389900728710927, 0.03963969931646716, 0.02753535420197295, 0.030482196270895656, 0.044536708810483105, 0.02553641468693968, 0.010045911330962554, 0.020987331445212476, 0.05750655211159028, 0.0436307617201237, 0.03532544644258451, 0.04460373587789945, 0.001379286211431463, 0.021187629681662656, 0.02136479517503176, 0.030621749720012303, 0.009988277997763362, 0.046953282653703354, 0.09367076272610575, 0.02588549497886561, 0.07273128867382184, 0.03598440678615589, 0.09013893388328142, 0.04579978478432167, 0.03956825647037476, 0.06014505408529658, 0.05947833829850424, 0.11393457069061697, 0.031389547875733115, 0.004902346463495633, 0.022930819541215897, 0.028281110571697354, 0.028463975759223104, 0.055441195945604704, 0.07146125877625309, 0.029376503844105173, 0.06136601688922383, 0.013623299691971624, 0.02013878391153412, 0.07550298018031754, 0.10015252468292601, 0.05221385174081661, 0.02451314518111758, 0.0957289089274127, 0.020327799647930078, 0.06104894542659167, 0.03968220953538548, 0.020768605681951158, 0.05291369328915607, 0.020102849121030886, 0.023830903664929792, 0.03460696585534606, 0.0987290038028732, 0.011462748243502574, 0.08591580190113746, 0.03496833240205888, 0.03796296507061925, 0.06652542011579499, 0.019843255140585825, 0.025404533189430367, 0.025052543678611983, 0.02753310363914352, 0.04327274968090933, 0.03813409319263883, 0.03950105870899279, 0.009548891321173869, 0.01864225425379118, 0.07005864419625141, 0.0419555525877513, 0.08450330191408284, 0.02488900030584773, 0.05606684870144818, 0.021988542466715444, 0.03981476453191135, 0.0550892101455247, 0.03788201902352739, 0.016810821180115454, 0.0473290060472209, 0.0135121584389708, 0.034631070811883546, 0.04855441802646965, 0.014809053154749563, 0.043856541597051546, 0.03169665600580629, 0.036921858045388944, 0.0993410158844199, 0.030240688429330476, 0.10760611417936161, 0.05362271149351727, 0.1236279470322188, 0.022657158151559997, 0.021881168540858198, 0.02713863916142145, 0.022060245064494666, 0.01364423753329902, 0.055031330048223026, 0.027319446744513698, 0.030168490447977092, 0.03669239711598493, 0.034516861705924384, 0.03443114736001007, 0.013486446732713375, 0.020245469495421275, 0.04377024466521107, 0.04747026272525545, 0.09540553292026743, 0.01536856663733488, 0.055456736517953686, 0.03251393871323671, 0.02672709415492136, 0.12046608622767963, 0.06860507375677116, 0.006519240414490923, 0.02524995867133839, 0.06213566484802868, 0.0427867394319037, 0.16737533354898915, 0.028697063935396727, 0.03405186165764462, 0.030681778334837873, 0.03817320437519811, 0.04379260557470843, 0.031293231950257905, 0.02675145515240729, 0.040578401094535366, 0.013097356331854826, 0.0270180976804113, 0.018345339522056747, 0.008985357253550319, 0.039971379956114106, 0.044087112037232146, 0.014541944001393858, 0.012489035507314838, 0.025083437431021594, 0.04240038477291819, 0.10026129384641536, 0.02800353064230876, 0.06441970224841498, 0.014853160846541869, 0.032677311392035335, 0.031148613343248144, 0.061135580035625026, 0.007225242252388853, 0.01958317505341256, 0.07935459303553216, 0.10248205202515237, 0.036523476883303374, 0.060228467773413286, 0.025263885072490666, 0.017885295164887793, 0.056775069097056985, 0.03880760334141087, 0.03341225652548019, 0.03431608849496115, 0.026602680518408306, 0.07420201756758615, 0.025357492158946116, 0.03126082236121874, 0.02906793924921658, 0.02223539191618329, 0.011824487719422905, 0.07487432172638364, 0.05868088577699382, 0.04682721402787138, 0.042332274169893935, 0.035978688538307324, 0.03880876109178644, 0.060834282921859995, 0.052123027708148584, 0.037229081208352, 0.06118970486568287, 0.00960801451583393, 0.04373059171484783, 0.02250226079922868, 0.033106551054515876, 0.01972733167349361, 0.056033667278825305, 0.009852342518570367, 0.0029231561939013773, 0.12383484296151437, 0.07719905479461886, 0.1358986835111864, 0.13333701237570494, 0.20867033017566428, 0.20137023908318952, 0.10280392147251405, 0.1154205432976596, 0.10064805668662302, 0.12318770503043197, 0.13929242093581706, 0.09781703789485618, 0.08343424560735002, 0.08970440641860478, 0.17626486747758463, 0.19920944643672556, 0.29568543832283467, 0.10763975573354401, 0.16367372358217835, 0.1793541165534407, 0.1555367125547491, 0.15308973292121664, 0.20717515493743122, 0.11939936768612824, 0.16056391701567918, 0.12203450402012095, 0.20263150421669707, 0.19558683066861704, 0.20514815667411312, 0.061470270084100775, 0.14513799163978547, 0.1727590657537803, 0.11324559047352523, 0.12271495696040802, 0.13883176987292245, 0.17768305231584236, 0.21046191919595003, 0.1651756078354083, 0.15957335766870528, 0.10205893137026578, 0.1446889477665536, 0.09335490467492491, 0.17366037442116067, 0.13657806033734232, 0.20112252503167838, 0.07745932598481886, 0.07050720567349344, 0.14018022251548246, 0.11954683985095471, 0.17861695610918105, 0.13396859489148483, 0.22489830938866362, 0.11424617623561062, 0.17264698661165312, 0.12246690152096562, 0.11892053400515579, 0.1320224313531071, 0.07582300167996436, 0.1422486177762039, 0.1796459438628517, 0.11090714251622558, 0.14363085298100486, 0.14982239808887243, 0.05826349079143256, 0.19011521333595738, 0.07400304777547717, 0.168825801811181, 0.0919547094963491, 0.21954003284918144, 0.07474253114196472, 0.21253558370517567, 0.1523065593210049, 0.1226385380141437, 0.1371962990378961, 0.12740239879349247, 0.09952731721568853, 0.15929012442938983, 0.17853347933851182, 0.14654024998890236, 0.09879935198114254, 0.1360425414168276, 0.1570316799916327, 0.14238484640372917, 0.14943749061785638, 0.18650439771590754, 0.1313642947934568, 0.2235207794001326, 0.07489421128411777, 0.11110879146144725, 0.11892934329807758, 0.12411112227709964, 0.11627696687355638, 0.16918739100219682, 0.19207004515919834, 0.11294499097857624, 0.12131632771342993, 0.20050021936185658, 0.1754885513219051, 0.08446769366855733, 0.0590807697881246, 0.14529097796184942, 0.18476916739018634, 0.18799520912580192, 0.19059088546782732, 0.1052626789896749, 0.13708698068512604, 0.10751733847428113, 0.1436805768753402, 0.10179671575315297, 0.12737982266116887, 0.20586795086273924, 0.18236696894746274, 0.12375423830235377, 0.3495156654389575, 0.11618525968515314, 0.08240930997999385, 0.16493700735736638, 0.15964761696523055, 0.19279723113868386, 0.1382829516660422, 0.14859847782645375, 0.21081261365907267, 0.15685534570366144, 0.20760804967721924, 0.06639730316237547, 0.09602713354979642, 0.1333921984769404, 0.14811480534262955, 0.10289979210938327, 0.11342866346240044, 0.1710459217429161, 0.11623866463196464, 0.15574617631500587, 0.1893137680599466, 0.10622230562148616, 0.13073526526568457, 0.1708587075700052, 0.10887537966482341, 0.10108267320902087, 0.0997415158781223, 0.11250586961978115, 0.10803512748680077, 0.2004270881297998, 0.1473341550445184, 0.14536559348925948, 0.09742767011630349, 0.11490076532936655, 0.15530580072663724, 0.19737871654797345, 0.0986655056476593, 0.19509999663569033, 0.1485529841738753, 0.31468299392145127, 0.07387878256849945, 0.15254170139087364, 0.07941271804156713, 0.18713134923018515, 0.08477172188577242, 0.11938358220504597, 0.18458474369253963, 0.20318679395131767, 0.1836831826949492, 0.13609187939437106, 0.09159744702628814, 0.13226824550656602, 0.16521906800335273, 0.12027141347061843, 0.3538292949087918, 0.15024822758277878, 0.1306099907378666, 0.13699973380425945, 0.11243958098930307, 0.10044383991044015, 0.1650995822274126, 0.17647269851295277, 0.07481602602638304], [0.05948289508523885, 0.008922293254727265, 0.10614630969939753, 0.05867005784239154, 0.021169565807213075, 0.03474745441053528, 0.03596385671698954, 0.034148697086493485, 0.025033643032656983, 0.07855780102545395, 0.016211097208724823, 0.03108003147644922, 0.03481981751974672, 0.04608544484653976, 0.03301547469163779, 0.07055864392896183, 0.03724675545527134, 0.16915130778215826, 0.025763580524653662, 0.029155681513657328, 0.04766291684063617, 0.019373095310584176, 0.058290727611165494, 0.04425975785125047, 0.031708689930383116, 0.03950497724872548, 0.04355810546257999, 0.09213241675752215, 0.029334698665479664, 0.03781660241656937, 0.03419937092985492, 0.026839835663849954, 0.06236174900550395, 0.01353205077975872, 0.012160598980699433, 0.023728784144623205, 0.049574470322113484, 0.018971565586980432, 0.07587807645904832, 0.055945407366380095, 0.0995346273703035, 0.03248916211305186, 0.04698419310443569, 0.038131952096591704, 0.05140331144502852, 0.029013048151682597, 0.015843440960452426, 0.032344766150345095, 0.052968871968914755, 0.03645620490715373, 0.06006821211485658, 0.03976764557592105, 0.03774261771468446, 0.06491989493952133, 0.032450514772790484, 0.05385177908465266, 0.017499207679065876, 0.059873877034988254, 0.040766936290310696, 0.009456262941966997, 0.07832993200281635, 0.042903330831904896, 0.02292009550728835, 0.0071910965016286355, 0.020408289274200797, 0.028067338644177653, 0.013335389066924108, 0.030465119452856015, 0.049477545835543424, 0.0282063169288449, 0.017326372617390007, 0.04152166337007657, 0.012729067402688088, 0.03807382337981835, 0.05701852322090417, 0.057806980912573636, 0.029166591084504034, 0.04009726304502692, 0.027776351817010436, 0.0075305010432202835, 0.014530840544466628, 0.02270107845106395, 0.09357087707030587, 0.06188394319906365, 0.010643882906151703, 0.03309229068690911, 0.0225175713057979, 0.024731407102080993, 0.035876498513971455, 0.0678177441295702, 0.03036758083908353, 0.06299398461123928, 0.0829220523883123, 0.07951973573653959, 0.06178145260491874, 0.018692421581363305, 0.030057029143790714, 0.06781458258046769, 0.03986961666669231, 0.044379729733918793, 0.024136046959029045, 0.06692701106658205, 0.03060346505662892, 0.03627163649071008, 0.01758930811774917, 0.05892731962376274, 0.024636638554511592, 0.055918485959409736, 0.05505334214831237, 0.05661734416207764, 0.032846565591171384, 0.06605337708606385, 0.020594790985342115, 0.00446536991148605, 0.035499554287525825, 0.029233358400233556, 0.044172870912007056, 0.08196676732040942, 0.016708584771549795, 0.029825955898559187, 0.018005779129453003, 0.04790475679328665, 0.019842579786200076, 0.04315074060286861, 0.07384245443972759, 0.07396709072054364, 0.028484427493822295, 0.006107910630817059, 0.10024704461102374, 0.011518098544911481, 0.02781847055302933, 0.020288480664021336, 0.022038900897314306, 0.012223838311911095, 0.04030298638099339, 0.049253907054662704, 0.06131670859758742, 0.07926471153041348, 0.10707186433137394, 0.02112063786626095, 0.0629278963606339, 0.04145784238062333, 0.026478122163098305, 0.04264435097866226, 0.03941620896512177, 0.04118087286769878, 0.03413239952351432, 0.0378241649013944, 0.03971463396737818, 0.02521271955629345, 0.010476771658431971, 0.051475975124049, 0.046249132938100956, 0.02707463634578744, 0.0008015202445221803, 0.01693719965260243, 0.02834289065503981, 0.060784755696658976, 0.09232685202732682, 0.060519619728438556, 0.048346175099140964, 0.035031767474720255, 0.008816832214506576, 0.027814665190817323, 0.025265488111472223, 0.09126967750489712, 0.0355654903978575, 0.02673516130016651, 0.06269724428420886, 0.04294577425753232, 0.00833791875265888, 0.0697103988204617, 0.02620782826852519, 0.021622569038299844, 0.0596528135065455, 0.034003666587523185, 0.02376927572186105, 0.05537842880585231, 0.06680797800072469, 0.06900779277202673, 0.020924660784658045, 0.04486129451834131, 0.0135941351436486, 0.0411280839034589, 0.012159922698629089, 0.04649372254789341, 0.0579024211037904, 0.027401919760450255, 0.029942376604594756, 0.07269254856510088, 0.022663603704131674, 0.03982079077104572, 0.00982307035883423, 0.14157608355162665, 0.03271598841820378, 0.07243356129038148, 0.02786366363579873, 0.00986414266662905, 0.05045375946792774, 0.005548143426494789, 0.04016454615339171, 0.018592430169519503, 0.02059355902019888, 0.0053310615203372436, 0.03218405778170563, 0.059210118706687354, 0.061948339352966286, 0.029569619946414605, 0.07515470511862077, 0.007171119741542498, 0.027470820750750136, 0.06960588216315955, 0.03075998214626452, 0.04049135088280309, 0.01520553627415211, 0.03244641440687701, 0.026782044624269474, 0.05077119087218307, 0.04714026305009611, 0.04124261213291902, 0.014082690959185129, 0.0210106311715208, 0.0334024045150727, 0.00797758657427039, 0.08330836993991397, 0.03225501081033144, 0.08120162048726343, 0.03601555472414475, 0.045777364503010176, 0.05451290649943985, 0.09633243826101534, 0.036488351033767685, 0.029830991370545235, 0.0629610035684891, 0.041339529198012315, 0.0455552879429888, 0.040547531461925246, 0.023599754349561408, 0.01951844122231705, 0.047706989280413836, 0.017096525771194138, 0.03403028371394612, 0.03153061530611012, 0.07329572166781873, 0.0369203403533902, 0.025561024303897284, 0.07102449002559297, 0.031285472796298563, 0.030862339153827634, 0.01009763902402483, 0.01362628405331634, 0.03674914543807972, 0.01877154194517061, 0.056142711036955006, 0.020307377599237952, 0.04119055418414064, 0.022958609260967933, 0.028836938363383524, 0.1098018248740118, 0.05919712370086927, 0.015607387904310599, 0.057877785511664115, 0.03351105493493378, 0.043375177192501724, 0.039562360107083805, 0.061003963855910115, 0.024433915350527968, 0.01459423479900579, 0.02592568598629441, 0.03890501022397075, 0.018123439222108573, 0.011680820916808443, 0.02072488390695071, 0.14436730096349493, 0.022231072616705205, 0.06932856384082697, 0.02161588414310245, 0.05644938501063734, 0.040990448906086385, 0.06916676822584122, 0.0280857420511893, 0.028044558421242982, 0.035321104878676124, 0.08252050596638583, 0.034073472997988574, 0.04406613152241334, 0.03170425188727677, 0.06629488678299822, 0.036959061908419244, 0.04525063261098694, 0.045734650193480775, 0.05550835659960285, 0.028480080363806337, 0.05724946844566148, 0.044835939042968675, 0.015414231911563547, 0.015707575985288713, 0.006420196168619441, 0.03416112806007732, 0.08800768613582477, 0.023556876767543145, 0.03823973049293272, 0.056278364500030875, 0.014027244178578258, 0.024306037739734165, 0.037952140846755356, 0.015227618878270732, 0.043481066823005676, 0.043332522254786454, 0.01782850788003998, 0.12708658527117223, 0.03967833923525177, 0.08591223217081279, 0.01852690224040998, 0.05537769779039081, 0.026092596854141448, 0.016300115967169404, 0.05637929658405483, 0.074775222747121, 0.06633733763010241, 0.07672500796616077, 0.015114234483917244, 0.02657352339156205, 0.11005922395270318, 0.009941071839421056, 0.05578423886618111, 0.02452460023050662, 0.027689808121067472, 0.05907917417061981, 0.057576317703933455, 0.020204799802741036, 0.03597503717173822, 0.07193779922090471, 0.04515509594057221, 0.024612533597974107, 0.023605316746397875, 0.053292281372705474, 0.023582660833199043, 0.018219287594547495, 0.015300872564694146, 0.08070406984188594, 0.01904001757793594, 0.009890694855130278, 0.04759637587994803, 0.01825804811232956, 0.05535059826797806, 0.04758967428642791, 0.03760189538297709, 0.02529694960685447, 0.02459491130139213, 0.04243069408403244, 0.0811279920162633, 0.13991845218697563, 0.10602672002278268, 0.2590258960844949, 0.1625591068295762, 0.1445477467495948, 0.14508292428217828, 0.1482077073887922, 0.11262776737567037, 0.15723139193141833, 0.17173870175611228, 0.10392257550847717, 0.19758635462494567, 0.22492613992653787, 0.17587890615686774, 0.0933664153853897, 0.18265857361257076, 0.11728708181180991, 0.3244855476077646, 0.07851270071114413, 0.1477916445583105, 0.1177315392124001, 0.08593225531512871, 0.27612803620286286, 0.1314518236904405, 0.0772408970806282, 0.12588994635734707, 0.1481018029153347, 0.19468130660243332, 0.12395593919791281, 0.259562706341967, 0.10856318782316521, 0.09816743549890816, 0.20346362987766042, 0.08168851389200427, 0.14333009021356702, 0.1869340121629648, 0.16144414868904278, 0.14027472760062665, 0.27671077055856586, 0.15555498423054814, 0.17141816817456856, 0.15431429143063724, 0.12622097390703857, 0.13704124954529107, 0.11489496173453517, 0.08003126102266833, 0.1311349860043265, 0.08560827816836536, 0.2217197057325393, 0.06130948007921688, 0.18113556783646345, 0.10306031865184195, 0.14441439765505493, 0.21304224792402238, 0.24430937482975423, 0.1186140938079916, 0.13983821118017659, 0.22006075334502384, 0.10928374642389826, 0.1112149260006845, 0.2134278233279474, 0.10561861301539466, 0.13806262286379933, 0.16233153466600925, 0.1376422110479325, 0.2045712704421021, 0.16745083965361118, 0.18572947679786012, 0.1544718790682964, 0.17991317639825866, 0.16781803948106244, 0.1285196130629629, 0.09993197323638014, 0.16926736483583227, 0.1343301692395471, 0.13795731210848317, 0.1301664239144884, 0.15178920817561448, 0.06946435460122302, 0.1275664134300314, 0.17365731677273288, 0.1286902031279169, 0.17957907635718584, 0.09828726266277954, 0.10121642306330614, 0.18861184478737414, 0.1749263596138917, 0.16210880130529404, 0.11386882382794283, 0.12077600709744729, 0.06879218402900733, 0.13257543527288362, 0.12238749914104119, 0.14818654133705422, 0.08468379222904332, 0.1336222345707938, 0.07157442887546495, 0.2057716646231711, 0.07079392700688913, 0.10866241296753287, 0.09150573241640814, 0.14258028357289732, 0.09716352491523139, 0.14406223373953253, 0.04957792130880989, 0.13546969246817753, 0.12312129765632562, 0.18577407987322658, 0.1435814704746008, 0.19555327075067908, 0.22670670063234866, 0.12047016061842442, 0.12374978541629389, 0.15593402873491868, 0.11398497736081481, 0.19751037354581058, 0.13555416371673346, 0.14360041008330882, 0.10225951162283309, 0.18507368542486802, 0.061107990695745684, 0.11932787660043687, 0.11755357962101698, 0.17754735803464428, 0.10290851234458387, 0.10447603955981322, 0.09399156348081306, 0.24069483362836763, 0.16834092704812065, 0.1128722308203578, 0.07746711111394688, 0.16750667884480208, 0.13285510620335117, 0.0949891732307151, 0.2908919658511877, 0.1898012700257823, 0.24527848610887304, 0.1316185249015689, 0.13613965886179358, 0.18245417129946873, 0.1257376724970527, 0.08166141065885313, 0.13400182826444507, 0.1835536037106067, 0.11476176106953062, 0.15524772024946287, 0.11864327505463734, 0.22349562059389427, 0.1531666936352849, 0.1956396270543337, 0.08822266405331902, 0.1181492347677704, 0.13885529595427215, 0.17912762792548165, 0.09606151725165546, 0.11572167713893577, 0.19179534661816433, 0.16583727701799944, 0.13349226966965944, 0.20062161987880245, 0.12199862860143185, 0.09906585721182637, 0.14294387656264007, 0.06609776493860409, 0.18715815560426563, 0.17690525186480954, 0.14342965674586594, 0.12111752861528657, 0.17612810450373217, 0.14680059539387003, 0.15316356177208945, 0.12164084662799723, 0.11526851434609853, 0.11117734364233911, 0.0939465151168406, 0.18847295927116647], [0.01348732432234101, 0.045052805726299994, 0.04365631386463065, 0.025720741905388422, 0.0158570575149497, 0.022324906058202032, 0.016404217021772638, 0.01946875072462717, 0.09745537448907271, 0.03422556503210217, 0.04325522015278693, 0.013507853054761654, 0.029289461053849664, 0.04917716527415905, 0.08505596444592811, 0.04184580750006717, 0.033872992935357615, 0.013491623212757986, 0.04204620221571531, 0.03767044756386895, 0.01983754616958322, 0.043720884423237294, 0.018915546424977947, 0.04666647968406323, 0.04603986213624012, 0.10074033532873727, 0.04321178967074957, 0.025054727448150516, 0.02944560892501613, 0.03139071675832383, 0.04520216665696353, 0.03027214992471272, 0.08211449181544594, 0.04775574467203114, 0.02540437733841827, 0.027508968996698968, 0.032397955874330364, 0.03809156813076697, 0.039864781574578956, 0.005233144875091966, 0.04858812637394294, 0.015091515488165896, 0.06003386552038137, 0.03658210283902008, 0.036200872709741816, 0.036635986471083015, 0.03612675813201349, 0.01626419045351213, 0.06300624489085749, 0.04156357616011519, 0.012138114689150825, 0.05734484555432573, 0.032079470620374195, 0.033412735210731626, 0.029161952661524992, 0.025072984280996025, 0.01210258065839298, 0.019946387692471035, 0.04475222478504293, 0.0638252790668048, 0.052072123799007386, 0.05318575720593799, 0.03329805484099779, 0.044378286256687716, 0.027937295817537233, 0.018879398267017677, 0.006391432380041806, 0.04888687421043869, 0.003706541306200961, 0.07586724852444604, 0.018328158803342376, 0.027972549687547144, 0.09336415183497593, 0.04846949777856935, 0.008434290339209838, 0.022279015356616583, 0.008857973170961486, 0.032981257973005995, 0.09388372942339629, 0.012245420894032577, 0.02338662809052039, 0.029354458347370382, 0.02412085890682647, 0.04499347473029047, 0.007035307180558448, 0.029240332733024843, 0.025222705153282732, 0.034082345373462886, 0.02286318576807389, 0.016328966958099045, 0.02506336419173749, 0.11471830832306296, 0.03813611554505769, 0.03182347420079168, 0.026690953418437857, 0.010587946308078244, 0.024903342309698928, 0.040842401576810516, 0.04227678378811106, 0.04329002316808328, 0.024437650208710693, 0.06573731865501031, 0.01427196088116034, 0.027542558600543998, 0.024739657928876113, 0.02269307995447889, 0.04264545306796208, 0.05876698603969999, 0.028354681526252534, 0.02556045656092465, 0.021027244147262536, 0.003363686241755204, 0.03408470540307462, 0.1428732241038233, 0.03872547356877476, 0.04711267371021677, 0.06397977194865234, 0.043940782779827714, 0.04497175577853341, 0.06459954689489678, 0.06952645009732805, 0.007211811698653037, 0.051431706015137024, 0.043227508358540945, 0.027600505491136573, 0.0398384130676277, 0.004895353577012429, 0.05595413131231908, 0.0515119618648896, 0.04821416558115743, 0.023505945027864072, 0.024655819361214526, 0.019604764129326213, 0.035692267774720676, 0.024940477524069138, 0.034087336316588335, 0.04519691225141287, 0.0648901125532575, 0.10324287955882028, 0.019626497924036812, 0.021689785353373736, 0.02944581301562721, 0.021464665987878107, 0.018513684590288904, 0.048842731266631745, 0.032160156915779226, 0.061493770190281793, 0.06568991768290289, 0.050587687437655404, 0.024565629864810035, 0.04437881689227652, 0.04776355948706623, 0.013232909604994347, 0.04711293717264198, 0.045633020490640774, 0.07947721067466773, 0.07094165150192566, 0.019796959968516603, 0.008458071533823386, 0.03307188533653971, 0.028737447901221458, 0.0026188183619524352, 0.017214445615536533, 0.06635249228565954, 0.021484644603333436, 0.05706177187676076, 0.018533687325543724, 0.07052951463265345, 0.07094977059750818, 0.03728495750692673, 0.02493134354153881, 0.018921142218459863, 0.008083329630608205, 0.029603127914015204, 0.06423227285267785, 0.029408215814328287, 0.00578739374759607, 0.06004979200952221, 0.12968255847226828, 0.024799163329589646, 0.039597797658643685, 0.051172722451156005, 0.07926511971163563, 0.028952084430784453, 0.016076410392997786, 0.06219835406227503, 0.08571927377488464, 0.04445574049896095, 0.08728720917133614, 0.011794256333814701, 0.023860563596826978, 0.03693889775604475, 0.07199300016509369, 0.0009127346686454985, 0.05306496525008697, 0.03628725869930349, 0.050189332250738516, 0.012954875110153807, 0.028375903239066247, 0.06497131093055941, 0.028329691558610648, 0.03287804749561474, 0.02489037513441872, 0.08948906484874897, 0.0388584107713541, 0.05651787781971507, 0.10130928058060817, 0.015724480253993534, 0.03973449383920524, 0.015226226423692424, 0.01901558236568235, 0.023616458238393534, 0.0361444843292702, 0.016910332051338628, 0.010705054428399308, 0.03797832381678745, 0.09298589400714263, 0.0949913848307915, 0.017327482128166594, 0.008182225446944358, 0.018643938929017168, 0.04961617160006426, 0.07279325058334507, 0.011867532284668414, 0.02349974438402569, 0.030659450821985956, 0.04100034544535447, 0.016565313162573148, 0.03859916003420949, 0.015098924905032618, 0.12637943727895617, 0.01681896254012827, 0.036149482693872415, 0.06415622498025186, 0.056947206539916806, 0.06015430866682436, 0.009021882979141083, 0.023933147494972218, 0.013345910865609767, 0.05684350253432058, 0.03657459972600918, 0.058978999077226035, 0.02588126288173953, 0.04456191585632041, 0.04219416790874675, 0.032790347904665396, 0.026216440892312676, 0.028662292461376637, 0.04777683279826306, 0.0485616650985321, 0.05076676396129187, 0.04817286506295204, 0.0143642154034751, 0.060336980895954184, 0.07841200611437671, 0.0468989834189415, 0.006453109490394127, 0.012943071251356741, 0.025972547045967076, 0.055093047049012966, 0.05732279263611417, 0.027100301667815074, 0.037099687760928646, 0.038131736873765476, 0.02963350958452793, 0.025658444174041506, 0.05086775170639157, 0.030111539890640415, 0.027927024493692443, 0.06016866922436748, 0.058722561079775915, 0.016272185239358805, 0.013818219213135308, 0.05690174257324543, 0.047683151497039944, 0.02993126294313697, 0.01226633276019129, 0.048607077114866115, 0.006006273042657995, 0.009822226165852044, 0.027853639076056425, 0.019296548343845643, 0.03062639185372973, 0.10882658345508389, 0.04735659167636186, 0.04537848610198125, 0.06290083765634336, 0.030513216188410297, 0.04964988736901432, 0.045899418109911494, 0.020654808467952535, 0.032867820700630546, 0.026477194478502497, 0.07540577367763035, 0.0638277801044751, 0.009252253039448988, 0.056043500735540874, 0.013542605975089828, 0.07411508981022052, 0.02328992253751494, 0.05960086316918023, 0.0085757882152393, 0.01962394679139834, 0.09200079686706886, 0.06930809540790506, 0.02704719914618181, 0.012994527132832445, 0.014887705965520581, 0.05618061994027812, 0.029450766851368826, 0.019366967026144266, 0.011781200100813294, 0.023342739332292695, 0.02672694387001684, 0.0658814214693848, 0.010718946505221538, 0.04050560382893309, 0.006959909151191823, 0.04686838095949497, 0.04018819839984644, 0.023239621623361018, 0.021528793113247957, 0.04816464577743318, 0.044009179109707475, 0.049147516474477015, 0.025296966305177193, 0.03075132870435482, 0.07866533822380006, 0.021405642983154394, 0.0037250381774356356, 0.0736239216348622, 0.027786899590864778, 0.03384895477211103, 0.036893674987368286, 0.027227327664149925, 0.008551558948965976, 0.06461818222305737, 0.030186383628461044, 0.010599508041195804, 0.03125940856989473, 0.030018502402526792, 0.022261899575823918, 0.05720073531847447, 0.09246849833289161, 0.12789614964276552, 0.017358936202072073, 0.003972105168941198, 0.027514451612660196, 0.04515547814662568, 0.05191559001104906, 0.07254428972373717, 0.06657905512838624, 0.10973156575346366, 0.09009731424157508, 0.18070492922561243, 0.13819469546433538, 0.10548255508183502, 0.161088882596232, 0.1377765991492197, 0.1428668267908506, 0.2178359281970188, 0.11990908955340274, 0.2063138480298221, 0.12457404431188479, 0.19957624550443143, 0.12229221480083652, 0.1613487975555472, 0.1310716214356944, 0.14793382521020249, 0.12201437697513029, 0.12003095762338489, 0.21024432149715722, 0.10858518508030102, 0.1794546181918122, 0.08956710167694837, 0.23932096984935924, 0.1677885465323925, 0.24675454362295568, 0.11046436236938462, 0.1676945312647149, 0.0612710999121191, 0.1107648728066124, 0.17906353605212644, 0.1536935442709364, 0.18852087232517079, 0.18286060105310753, 0.0901300874829758, 0.17057063552783802, 0.12024846626445651, 0.14308516663732007, 0.11557239413377829, 0.2667637949343771, 0.19055373355513439, 0.13509830692782998, 0.09743503222125582, 0.09892050016787834, 0.12229870117153041, 0.13426708668703213, 0.14993734192103148, 0.06728393957018852, 0.16326974291587248, 0.1238784144516103, 0.16480575111927465, 0.3017302311491221, 0.13905481493566185, 0.10079582571052015, 0.19932793773477897, 0.14875634748023003, 0.1048363522568252, 0.19393409747863188, 0.19591368734836578, 0.3003753366647288, 0.12184967956272885, 0.13567200192483142, 0.16087981959572062, 0.1964437440619804, 0.10580615373328328, 0.10995714153978042, 0.13700249459361658, 0.3366106969770044, 0.18990888143889606, 0.1290543601498939, 0.08693984695128165, 0.07939338509459049, 0.2292265888536349, 0.14991185656981543, 0.21082904480863363, 0.1464574263081886, 0.12304367643082514, 0.1401583440019749, 0.14449769631028175, 0.11995793771347962, 0.1434959305333905, 0.16529349057236686, 0.11065651182434522, 0.20310598891228437, 0.16856020200066268, 0.08191430490114726, 0.19840516615658998, 0.09010721449158154, 0.10523787641432136, 0.1359938268433325, 0.14076525752898306, 0.22231759474379942, 0.12794217764167115, 0.14062509551877156, 0.1839267258765176, 0.11380034586181864, 0.07317711904761381, 0.17852096672868356, 0.14977138285757974, 0.11847986897919327, 0.1773806568235159, 0.13545125751988962, 0.19140460586640984, 0.16583228978561237, 0.1858299784362316, 0.10508221836062148, 0.12703758868156, 0.11816574013209902, 0.07788551913108677, 0.08300623419927433, 0.09923360485117882, 0.13116244546836242, 0.1086913789913524, 0.18863960111048073, 0.09395810004207306, 0.14383789733983576, 0.09938453542417847, 0.2078458634787239, 0.18168836395489052, 0.11973109285463579, 0.20012721593957394, 0.09228850525687449, 0.13923830352723598, 0.09086660968023352, 0.1121320720994845, 0.20173427736153826, 0.043044802732765675, 0.2648840832989663, 0.15743969794129953, 0.12205743638332933, 0.10879503475734964, 0.11756279709516093, 0.12463403953006491, 0.13603963219793513, 0.1392208630568348, 0.1105876182555221, 0.0798415754979942, 0.21562226495007053, 0.1979571019182913, 0.0963092313031666, 0.10121914674527943, 0.1103222114033997, 0.08400118706049398, 0.09431626793229952, 0.11313032009638846, 0.09353627072414383, 0.1900563164963387, 0.1692143309628591, 0.11261105420999229, 0.09431017489987426, 0.1048895345593337, 0.2699352888157591, 0.09157350534223951, 0.1705106848385185, 0.23310107470024377, 0.25687467714305967, 0.08859378242050298, 0.05886525752430316, 0.053948109853081405, 0.07190022428403609, 0.164723654743284, 0.09485687798587605, 0.12171487585874274, 0.14031602069735527, 0.12224511810927652, 0.12973875389434397, 0.12755342584569007, 0.176434270106256, 0.23206353740533814, 0.10651257442077622, 0.13314533047378063, 0.0761412939755246, 0.09345326892798766, 0.13412867614533752, 0.2101361460518092, 0.11769365257350728], [0.06195411697262898, 0.008734823040867923, 0.0531221699930029, 0.03565504535799846, 0.04363152613223065, 0.03238301273086108, 0.06343102795653977, 0.07190138945588842, 0.047058504351298325, 0.05032726039644331, 0.023394680392812006, 0.009805918398342328, 0.04339220577094238, 0.04627515263564419, 0.10082635024446063, 0.028293845825828612, 0.011029501911252737, 0.07061311014695093, 0.03729854252014775, 0.045598339929711074, 0.003472666685411241, 0.035725924171856605, 0.014110746924416162, 0.02974518240080215, 0.016638216184219345, 0.04366253677289933, 0.0200422490524943, 0.04389733374409843, 0.051346006512176245, 0.04605953276040964, 0.01356397147901589, 0.021481449657585472, 0.028093766522943042, 0.08759158619795926, 0.019192534491594415, 0.009950115836545592, 0.006249757316254545, 0.02431303062621737, 0.011962722001044312, 0.037343891453929245, 0.028597796117537655, 0.05444777190859895, 0.09003344501252286, 0.05591900917352177, 0.037215165939414874, 0.03583358753530774, 0.08479301410261542, 0.04481925556319766, 0.03907232741767075, 0.06315462247584946, 0.04896630998700857, 0.039337481939583085, 0.013982253331050742, 0.03106741682131542, 0.055756308138370514, 0.014464471205428708, 0.01985812221391825, 0.04300300497561693, 0.03229608126275707, 0.010559445054241223, 0.020914100023219362, 0.048313962179236114, 0.02740953419561265, 0.028492459387052804, 0.014843620538158575, 0.013535881189454813, 0.032244561371044256, 0.005719963137380546, 0.02936501354270149, 0.02956985557830194, 0.01846024810220115, 0.013989810249768198, 0.10305918316589668, 0.03549688626662828, 0.06480562646174803, 0.06355390534736216, 0.05143606242199894, 0.05334841371222865, 0.018987783369084354, 0.07914529996924102, 0.02461842439515749, 0.05417907734226901, 0.0318748605059227, 0.030159104135236703, 0.04695684867328964, 0.012514383561210707, 0.02325037719856482, 0.0818808785697911, 0.044644843437708914, 0.021463009143189993, 0.06322066619759426, 0.04685159357904922, 0.02836091927747475, 0.038907299749553204, 0.0394664412306156, 0.026790408628585283, 0.03080674672673922, 0.04126406762225088, 0.021069500180601608, 0.12053704296704382, 0.01664810344664147, 0.030399589668377303, 0.03404364237212576, 0.08627638177131303, 0.04491530060477089, 0.034437529830029234, 0.026741708898043726, 0.0484619835333433, 0.03595312526158523, 0.05642423733661417, 0.049376123934052885, 0.029444714637065772, 0.13467578741256148, 0.03513896699587349, 0.02650316593644675, 0.033694784724502824, 0.010170853747695219, 0.030562993888452183, 0.04328489492763765, 0.02448870254738722, 0.03551513567799702, 0.08770246306085028, 0.007751088205623091, 0.03177751670591533, 0.027122842548124027, 0.021470749743457418, 0.08506950864102691, 0.020266642968636006, 0.07717474945820868, 0.015568844464723952, 0.07271873895660974, 0.018192835595982615, 0.035873537344741635, 0.048783582096803, 0.0040846370211511385, 0.04924188426230103, 0.033151284005725756, 0.03315536581794731, 0.02145763413864188, 0.0478398337145336, 0.011096215421275701, 0.01058858919350314, 0.028762092770193703, 0.11557661695405841, 0.025654746423242614, 0.00573235839510744, 0.04059398619574495, 0.045207042567199096, 0.06002584290399682, 0.010078778268507449, 0.007320523345697438, 0.016265745252894703, 0.04047966947837267, 0.03525550273479894, 0.06503080890979618, 0.04815990716451779, 0.015797706109879073, 0.014867605823383201, 0.09217961734975688, 0.04754019159008749, 0.03815635391219985, 0.03473111974017229, 0.0414021219330607, 0.08636262675281614, 0.059705231396947056, 0.13268245296785608, 0.048204484264715575, 0.05280328397930134, 0.02718724797887262, 0.018121925240848213, 0.03197484264092054, 0.021076587690913584, 0.004576988922053715, 0.03278353869973216, 0.018702036104514264, 0.016765748696343508, 0.052539428215823136, 0.021209263286436908, 0.040893019759096205, 0.024052753869909793, 0.008978900568763493, 0.021243821392999962, 0.006245561862670002, 0.03269052162067965, 0.022837579817860387, 0.035984852074761875, 0.050369592499919236, 0.0371616014308529, 0.03470556388492696, 0.004075228907822748, 0.09663861870649271, 0.014322115221148124, 0.003923666581613361, 0.03819955432845745, 0.010213825025857659, 0.046356373277376406, 0.05961553913948592, 0.03277487041486893, 0.041476537080598064, 0.027468353109725285, 0.03547526750480756, 0.04010149699752219, 0.054700747787137516, 0.06521099494420923, 0.012037170545227127, 0.0511147161887493, 0.08129635563818738, 0.017894366064865608, 0.02012998389545828, 0.05884190213691909, 0.10497635099454783, 0.04598974119289778, 0.053464890079339966, 0.02405006543995114, 0.01456112759115058, 0.02093421408062568, 0.038410424458561465, 0.04536832610028796, 0.0741918056155555, 0.029462724705808796, 0.047820860709180124, 0.008947010483097984, 0.05052157321188133, 0.027682457148330286, 0.027947750822931994, 0.004457730428839568, 0.011096593916590791, 0.02177921043767128, 0.012660647880693432, 0.03821037484158296, 0.03675150546769146, 0.006136003703431925, 0.040730934706516564, 0.039831017566029914, 0.03235176460293587, 0.04788769110746216, 0.06782275362638757, 0.05089526683150325, 0.07392417974187993, 0.013584021526185097, 0.02181666663091164, 0.021727436360379215, 0.03663485469587613, 0.051087768806610256, 0.023446996237908024, 0.04209899860143196, 0.036065204403712414, 0.03271052621130366, 0.053807944132131524, 0.02631802792166127, 0.09624352896935306, 0.015518700329266721, 0.013718615573452553, 0.02452912176522659, 0.014379730928339995, 0.013592753821285442, 0.026321061450289562, 0.022616568239754997, 0.022747496077499818, 0.023341537053056527, 0.04921672174532432, 0.006111969714766019, 0.02949241803435143, 0.0841203833988402, 0.02799301997583825, 0.020177587102807593, 0.02252248061267892, 0.09146837270236574, 0.019521461763361003, 0.1236774111748673, 0.023313923593377694, 0.05215676203079056, 0.011696337369357934, 0.017337972385575995, 0.029745885585725773, 0.07106345277861692, 0.022105219213699456, 0.021536225722229574, 0.022060566043364815, 0.06997723801760003, 0.053822898407815956, 0.03236081880459096, 0.034295909499633126, 0.039054293229128234, 0.02383682229265105, 0.05016055547457654, 0.03663764517114032, 0.03510440517857205, 0.07188175964984111, 0.012949102128914092, 0.03155535850964952, 0.04078688521985896, 0.030914256094547454, 0.011693192518578144, 0.0992169659002684, 0.03359378213644959, 0.03726339811692014, 0.07591465691803023, 0.03805915483098943, 0.011188931930519175, 0.02120390683558071, 0.03299148847872857, 0.07224854387459345, 0.0846509299299214, 0.026129433354071807, 0.03178063743689563, 0.03639381626271643, 0.020026406054967083, 0.02720725071412744, 0.029436556578730233, 0.01867762501206016, 0.07363777011050843, 0.022161991655593738, 0.04285878341761418, 0.07924317440483719, 0.03658616609754972, 0.02569366650277516, 0.017720803698466625, 0.03602627504733391, 0.04026878079457674, 0.03067921606998425, 0.05555094474402722, 0.05267010557872709, 0.03953714192903135, 0.020474772718444, 0.02994593705807347, 0.015765508032927755, 0.025149893044726923, 0.008386509944102727, 0.0552274685469456, 0.036348025751067325, 0.09520442574284971, 0.010838061207323335, 0.02416851777525153, 0.061146779044065624, 0.032861434519873, 0.0323402279173024, 0.03583927609724924, 0.024863193975761533, 0.05247464985586703, 0.007833441086404491, 0.01069840107447817, 0.010773708654596703, 0.029056448947812896, 0.054522057180292904, 0.05830321053508669, 0.04954791998898145, 0.013247983551991638, 0.019935190539399628, 0.044895566898048855, 0.03636239001934882, 0.048740069978521205, 0.1997344268602319, 0.15721586620202288, 0.1632423873525113, 0.12283281743293628, 0.11328994121868163, 0.16605794720817357, 0.12743230734486133, 0.11550864364835434, 0.12381251915940084, 0.16909101570490748, 0.08660824052640237, 0.09222681794199161, 0.1590659364592284, 0.14084052614634857, 0.2082958276150748, 0.08100967141217552, 0.0852163128729444, 0.11582599341636524, 0.1379521022317931, 0.1734001180739142, 0.11492231729789637, 0.08367401125724427, 0.1836103928508237, 0.11438579647801816, 0.09514341378235258, 0.18462875304976478, 0.13348728243727237, 0.08425298292422667, 0.07853284259908833, 0.1269324411987327, 0.13512045261450112, 0.101937909348635, 0.10566733501036651, 0.21098544501001015, 0.15644090075511485, 0.14553692570189014, 0.19872580363880843, 0.1082027266966179, 0.11766700947191566, 0.16319895687047392, 0.1124654448358342, 0.14802882011281326, 0.18462103471392766, 0.17974911723285913, 0.14093348756432533, 0.13046433683484793, 0.1673049631062895, 0.11997683279332705, 0.1540230875252746, 0.15181408496573567, 0.12638478074222803, 0.13617434684420004, 0.07054642075672746, 0.12256191126652993, 0.07080580879119225, 0.08685133841936477, 0.16666208510287106, 0.15809810167411342, 0.06097444493207149, 0.10052550584077835, 0.13041449419688433, 0.22043577540898696, 0.1526798150734976, 0.08132247923640534, 0.07703650218900293, 0.09940241376170889, 0.14628953766077757, 0.13127807207638398, 0.08170571687514894, 0.1064227671304252, 0.0727624366118107, 0.11597058604820631, 0.17785542353522032, 0.19147720275213942, 0.21002948458772153, 0.15738507587229833, 0.13439031288726255, 0.13088703446555883, 0.1452065067132935, 0.08937467020587064, 0.15710657753515989, 0.11762402427848428, 0.1248895312892273, 0.16420590283814818, 0.14525336591759697, 0.09960514624253847, 0.09711791994050145, 0.2964237565174699, 0.1172046663123183, 0.1545179812819697, 0.1298091243370436, 0.19961878540925682, 0.11457462853286415, 0.28741883346810937, 0.12389517214614898, 0.16294882341753691, 0.1504429374472238, 0.12200957527966239, 0.09041844896273687, 0.15506657684454694, 0.07622368721058592, 0.24016511830268428, 0.1666396574000828, 0.17206867545610294, 0.20586985076079145, 0.08413819494307972, 0.11737967215594836, 0.17184221651405096, 0.10032764927018434, 0.1609386719064787, 0.11950199186685495, 0.12225981263327412, 0.24356991372769699, 0.11469201403087936, 0.09228363676811568, 0.06691628703265451, 0.11770947516197339, 0.135447591310367, 0.1366617003805004, 0.15626128617441282, 0.15389843640150502, 0.179054778709542, 0.08767096631345339, 0.12704739987384528, 0.1620065185124986, 0.08978158235549927, 0.1984600702417083, 0.14403802488232031, 0.16232712630880997, 0.1570227593765594, 0.1896698950440623, 0.08922334629460238, 0.14834969508228824, 0.11562195475562476, 0.14471541275270283, 0.1309274963568896, 0.18745531153399497, 0.13705359888263047, 0.16622072987956926, 0.10433846764499322, 0.09478065941948444, 0.09745604242198169, 0.12093877492588945, 0.17027439986122772, 0.1327113521983847, 0.13262768246931955, 0.1585588714806363, 0.16413869394455105, 0.21206285047810525, 0.07944295313791372, 0.10510696156416088, 0.19267995696282014, 0.14017453766427934, 0.16130202740896493, 0.13708024198422208, 0.18776441604131833, 0.16244475671555847, 0.09588340923073702, 0.16274624678771943, 0.09972083964385092, 0.10946023656288162, 0.1766783179482445, 0.11880153062520549, 0.16345738753443584, 0.12790734122972935, 0.1507133463746868, 0.10942488806904294, 0.16950960183748975, 0.2286329449270852, 0.10572676619631238, 0.16434824676252902, 0.10209019063040614, 0.14166649198159575, 0.1880198484286666, 0.13638838223414496, 0.1180922007188201], [0.027322177847963758, 0.037241389727569185, 0.021226751996437088, 0.01565209673572099, 0.03352802414156031, 0.07064375342451967, 0.03806344073382206, 0.043056395079474896, 0.07586480685858987, 0.048932482895907015, 0.04494293076277245, 0.012367287108645542, 0.022082162540755235, 0.03909572733391542, 0.021249218661978375, 0.0591049155627843, 0.03778119455091655, 0.016172919276868924, 0.031072229648998473, 0.04427937281434424, 0.005545177154999692, 0.03577931798645295, 0.02645835320436163, 0.03179003302648198, 0.08294415354612283, 0.011690124665619805, 0.03145677532302216, 0.03900268427969422, 0.04238897054165136, 0.022114137973403558, 0.1076524835661985, 0.04875159553193953, 0.031100577834877186, 0.01240448447788367, 0.03431778801314067, 0.017304167558904737, 0.019795271582552232, 0.13111386448144913, 0.049295003482257016, 0.06052205397281796, 0.013320057223609183, 0.025347176306240726, 0.02277495925227413, 0.03162250060995575, 0.01866558366600657, 0.02373504230490653, 0.03984271752415225, 0.0748907528759446, 0.009086246664082864, 0.08326629758812487, 0.012435756725608371, 0.0058016160801344085, 0.024268898814625572, 0.0321593442640733, 0.03777202531637158, 0.05703428643755615, 0.03049280341656413, 0.08007993848877959, 0.05391577818954829, 0.02309037201484898, 0.01234608302183915, 0.039115171603043564, 0.019880405197909568, 0.015574609096802305, 0.025486228805675637, 0.06295666200458072, 0.03487253597995732, 0.03826717511401512, 0.03095799642323982, 0.03300587872217875, 0.022788278947700746, 0.06260313995881006, 0.015457742174476152, 0.05379431830078829, 0.02732246543018846, 0.00909131367734517, 0.058126156363869086, 0.04140311270020902, 0.03509408561512828, 0.05652223793731537, 0.013036382406426128, 0.057798030611593276, 0.0454907285165973, 0.06447263222071342, 0.007833583949832246, 0.05777873106126208, 0.056738414423307404, 0.11159571455209516, 0.040712265981710516, 0.0787913920066785, 0.07120943322661333, 0.1301949966000393, 0.1168551815499086, 0.03619880211772397, 0.0509039759344887, 0.03191639480064623, 0.037772440919070505, 0.028452114383981097, 0.015092038702277932, 0.03430828481214121, 0.024743507819948718, 0.02400746801868081, 0.005175470259928261, 0.04822909759241156, 0.03602600787417032, 0.04040041923872195, 0.06961603474337608, 0.050446467867004685, 0.06590604592929594, 0.04136271389143076, 0.07743243797449395, 0.0875642232131213, 0.019728888328245375, 0.04044440262077842, 0.053648660687031224, 0.08846731303492561, 0.04707446052634623, 0.01738914717861917, 0.10405510824057274, 0.04757923226861749, 0.037259876626194455, 0.02397626256424701, 0.05919761722907424, 0.08885776434908621, 0.04230749014823232, 0.03253303046221845, 0.04314745659939945, 0.023232135208672844, 0.0418742391775595, 0.10756266885437071, 0.030782686299062334, 0.03978516768256668, 0.021781568611913826, 0.027171230576641392, 0.015098074218258262, 0.015599159341945779, 0.06935641664313152, 0.018625795273692347, 0.05856495859916322, 0.10693586576962844, 0.0501249323860975, 0.012520495147327892, 0.022096265201980714, 0.040410738802165724, 0.012845987203036202, 0.021146501712792087, 0.08460482029477134, 0.00383115091608488, 0.05371332401409745, 0.038778474045102485, 0.026549073336354923, 0.0028077218485123012, 0.020995636077714153, 0.0663751648971811, 0.036858593666693196, 0.047989602826419286, 0.033916438260348514, 0.06720339428284205, 0.025234147215087432, 0.01553863256049226, 0.03181678745022509, 0.0249326293123886, 0.03922534713638015, 0.02888984978199005, 0.0207339381086058, 0.015420871350215748, 0.03907298421836458, 0.0577592274203198, 0.06449051797972061, 0.03427732612180989, 0.007963107273099013, 0.021429510452435352, 0.020667549288191367, 0.0818556455487851, 0.028491897210187744, 0.029172142349125352, 0.04021647422632668, 0.02073584542813478, 0.05491281277500093, 0.019374995208636392, 0.051364378377911635, 0.0036185075168759795, 0.026667388374335133, 0.023294744642043952, 0.010313758921256522, 0.024481307045789436, 0.027561720853555016, 0.0436934398021549, 0.011355360402376391, 0.02875376958400011, 0.016126030386658385, 0.04536498643574305, 0.040766383390291594, 0.07167557618231513, 0.022350691979227122, 0.03229777707019821, 0.027149691595695913, 0.046891981255612336, 0.06196423986693844, 0.1080550393089652, 0.08892047582776286, 0.049122224081656896, 0.008134745621646289, 0.058708263604785316, 0.01793701358110411, 0.07438017753884196, 0.07928034858196042, 0.061057624843670055, 0.0296500928743626, 0.021809892677993048, 0.04735070273454767, 0.017163255979539827, 0.04512840088864323, 0.048302028444595635, 0.02837997948518023, 0.029910549601481762, 0.00881867274074466, 0.06336329213809222, 0.04291545381420292, 0.04319419706007466, 0.013206790645199362, 0.08344223111635074, 0.047703567979624495, 0.02578858347987989, 0.03557895295671187, 0.015577963604300749, 0.07572351678390987, 0.02085976182570448, 0.09511845535598695, 0.013978294900880428, 0.03571794608433265, 0.0642132070788648, 0.05050494539318606, 0.04851444224186707, 0.006960681912460132, 0.012622159174497938, 0.025112939656537492, 0.01803270795790013, 0.08057194529101253, 0.04529895755695179, 0.040503922864445485, 0.07360328250797465, 0.03700524946907535, 0.05874310743820388, 0.005051815469414578, 0.011213358793611405, 0.023817582114133984, 0.05044378500315361, 0.010098425700562075, 0.08977232035249472, 0.041171662815031596, 0.088853163033491, 0.0356158636714099, 0.051852188335033134, 0.040514238717150874, 0.011227624727325747, 0.0289028967381455, 0.012606479449459584, 0.02922221876360709, 0.06418347664293833, 0.060729680917575024, 0.0444954120030161, 0.01598899281816557, 0.03302062519651372, 0.014331127676996402, 0.04819230191060342, 0.009461018253205111, 0.06692073249723762, 0.18156102625653148, 0.0169100722996518, 0.039672962375334464, 0.012491034667618806, 0.020795742311747745, 0.0072885734243755, 0.03681327812955715, 0.030285590219136793, 0.017515006147732493, 0.05556439245992806, 0.05623498967906926, 0.043701377071556635, 0.03524191401083954, 0.019367254608368967, 0.0241928249670309, 0.027438312827143818, 0.07716058928053826, 0.020583076184266247, 0.05148753036337439, 0.036889808397972956, 0.008964782136899885, 0.0892994535388425, 0.014745304524694802, 0.040291850455105305, 0.025009337696246803, 0.04819636516913306, 0.05174303696549032, 0.02360209768085042, 0.012695192071987549, 0.019061179918935522, 0.04255395739164669, 0.03350714381667785, 0.012651692013605498, 0.015132583157537738, 0.08997028082376346, 0.052881873707519844, 0.05895626338315196, 0.0031253346151061123, 0.019611695788626093, 0.05440094610094093, 0.030134316402836703, 0.029033013779553585, 0.023431895388057455, 0.042742166042444296, 0.07309913416975178, 0.054297156748361886, 0.05991068384901155, 0.07304349535843357, 0.07452687044860795, 0.0036821916728513315, 0.0667321082437411, 0.05800198392535094, 0.05801351318950765, 0.011088499868492363, 0.046515712383552454, 0.04863141955866013, 0.01896283978567226, 0.036101009318372235, 0.03608057799283415, 0.031350047065643594, 0.07337122777244076, 0.033633872953942046, 0.05427511496236548, 0.05584823797107674, 0.03808747147559188, 0.0473618497926509, 0.055672467715339735, 0.009316570340160979, 0.012987962836632505, 0.041333595727337524, 0.03188568844052497, 0.07648263737792149, 0.06939033279195428, 0.03242808707000222, 0.035373986611375585, 0.016074501218099613, 0.04030850795970764, 0.03498480065900367, 0.011545365050551482, 0.06604192574741319, 0.039470415431424044, 0.05374969667172991, 0.04623809720214922, 0.049911776441149414, 0.1642969940439798, 0.12148049820098095, 0.15950426372000948, 0.17570513969985768, 0.07644425350008532, 0.15265370631823316, 0.17892764881253242, 0.10615964609314688, 0.09336234099464491, 0.13529822666896507, 0.1390414562774822, 0.0748793980164919, 0.17312786862021312, 0.12821073119994253, 0.12753442686516792, 0.23810421873349696, 0.11403274198528379, 0.10959959705360234, 0.11559243212104775, 0.1392650802154094, 0.10736453026765957, 0.151279041019734, 0.09845658365520649, 0.2433176725753583, 0.21575399616267532, 0.15680269774748012, 0.1001766964327544, 0.13916897209128365, 0.0847020787477959, 0.15367625223007053, 0.1600226093432866, 0.21342540392652154, 0.1117305776278954, 0.12162558807176538, 0.1564911293098703, 0.2063120371894911, 0.09993794752517715, 0.1427490182686597, 0.1345811042119749, 0.1271206053206697, 0.13100242358632386, 0.2090707336901687, 0.13655638962518424, 0.126078971370589, 0.08782616423559375, 0.16619007918052375, 0.16968878597253934, 0.1939791755285114, 0.10659847059287131, 0.1828513984219171, 0.24802279978757724, 0.12657429557293653, 0.2754600142361596, 0.17089770000893623, 0.10569075719104148, 0.1868603762704879, 0.11042593396268785, 0.1382829961949028, 0.13837505219271407, 0.1140185521217063, 0.20499221660429612, 0.09220906576956622, 0.21847021213034168, 0.1335038323304616, 0.0941310056077782, 0.18932466278783977, 0.18087474745698273, 0.14147535926895216, 0.0810660449496936, 0.1642318780068308, 0.13093463581753895, 0.11779666267102584, 0.13324479310540482, 0.12945608468726277, 0.13384989579208195, 0.13712695275899023, 0.13273980614030734, 0.15011703071650118, 0.1379036548314616, 0.18624326563440263, 0.11640149183222093, 0.11273775366134942, 0.13226897281128913, 0.16977368766674772, 0.2417222925578244, 0.1272446330403909, 0.14067161333514377, 0.27278970752377063, 0.09868112043477595, 0.10228755738353357, 0.08682646162924357, 0.334263788536191, 0.22993235645117238, 0.10941846107016318, 0.10717739030951634, 0.08385441251448356, 0.09077809372683987, 0.15856759913731366, 0.08490379448630847, 0.23917620652355254, 0.12865161144873127, 0.09492859171587043, 0.21919858554610983, 0.09999001660617068, 0.17057450953871012, 0.13634891482070088, 0.15894676238531247, 0.18018763745203614, 0.12202724581584334, 0.14584938471671194, 0.14602347771869972, 0.09779327432624996, 0.10337634739698842, 0.1683177423547022, 0.07419878180371597, 0.19550696073565632, 0.22082565526943654, 0.11186085423105396, 0.2594205999048427, 0.11621379526332021, 0.1224752952111885, 0.0491114443866536, 0.13701405725441873, 0.15165845659794286, 0.11256907091592439, 0.14009966980665922, 0.20112467725994065, 0.1925863276119344, 0.12408479087753221, 0.1281139106140472, 0.10217934483080171, 0.13116174784954637, 0.09293859693570994, 0.07376331923296675, 0.11256237674388103, 0.22267983702477068, 0.15134098066482693, 0.1631298629217781, 0.10983292828314006, 0.16462560219224542, 0.21516204433282837, 0.11223100038478151, 0.15592791343806311, 0.22517643665196374, 0.13815138372592628, 0.07873389040469192, 0.11531077965628356, 0.1399472772027366, 0.2082379104103893, 0.1078307325951755, 0.16587647725827992, 0.11868835310451686, 0.2394291156088002, 0.13576649216702208, 0.10869796184124425, 0.10532411397434771, 0.16022385010728613, 0.1431858612340875, 0.08766742626903579, 0.10933739627944306, 0.1255542878061533, 0.12617404048796743, 0.12073363788658753, 0.1823520369362086, 0.15891949587967247, 0.11520005864440463, 0.15944236860377714, 0.09447457545320503, 0.2694892877480015, 0.16044515854446217, 0.10056283586891368, 0.2595086779911071, 0.09683649754151702, 0.12164897314505652, 0.08033048012293875, 0.16060722875408828], [0.05793575466668699, 0.039622782060178, 0.017597299192857463, 0.01921788996696705, 0.06124503197497688, 0.02231123755336739, 0.007882305944804102, 0.022982897899055388, 0.04361009661806747, 0.0388683481287444, 0.0460930704139173, 0.029923728288849816, 0.05225438413617667, 0.044756469869753346, 0.07468960116966628, 0.09351196538773365, 0.029616816827910952, 0.03626317971793469, 0.033402256085537374, 0.05959060668828897, 0.03435512546275277, 0.033628603705437854, 0.03325073921587318, 0.036095662144361995, 0.07578035045298748, 0.013450560181809124, 0.0489955394732533, 0.02759999711997807, 0.030521467015205417, 0.0287641299655661, 0.027148548688273877, 0.05084404750959948, 0.03836350959318224, 0.0245009238642524, 0.03905199628206901, 0.01646101358346641, 0.03300993826997001, 0.06871754623716697, 0.046126845554681495, 0.024666780882398598, 0.048891056212596595, 0.057701425248524174, 0.06525185017380863, 0.015308179936255328, 0.038741593016311526, 0.024882775542209856, 0.027933594355999958, 0.10781787117593922, 0.01439521120119025, 0.041967159777414054, 0.03717096733453218, 0.05166106675460469, 0.024408563585893717, 0.06371066177962348, 0.0135140175189008, 0.08679676087922417, 0.04747595128719695, 0.0537214579526335, 0.058485359550104477, 0.034437748763593845, 0.0827075271809008, 0.03576395181880798, 0.0617599488759879, 0.0432007390918443, 0.01872456956334645, 0.05060909468738828, 0.048228470477624796, 0.01471112213039305, 0.07124677067622542, 0.049163250005221926, 0.02999495034600841, 0.0646729527215939, 0.0760397088015452, 0.1460868274443783, 0.07228287562611513, 0.04786789802892599, 0.007336767566812341, 0.027281962720735464, 0.0368818748393096, 0.07509972681873478, 0.0678525137482211, 0.03705527022248134, 0.055517429354949854, 0.01872074935818091, 0.01692769645160297, 0.025760051612451207, 0.06318770741927437, 0.021612824639305472, 0.06413724826416001, 0.09625804537790827, 0.05394694468122907, 0.03034191922779428, 0.046767456296947785, 0.04625396060873754, 0.04772319407493342, 0.045084847952239215, 0.038712430323357694, 0.09432212347746827, 0.06286272095167078, 0.021046165202278644, 0.03345911201904528, 0.019983660204161424, 0.009737974778545322, 0.020841584773734212, 0.050697224723990075, 0.03441251574258786, 0.03260995406890288, 0.017837623308878392, 0.032459995709359646, 0.03551240457454696, 0.02506270739104366, 0.018354015228396747, 0.01776200588210486, 0.0326395620504627, 0.020383375376695767, 0.07269042602274567, 0.07724880837486126, 0.06973799187107943, 0.05405020339821931, 0.012622133199329255, 0.025863896626105998, 0.05158462554391008, 0.031056761436047964, 0.019858200139424298, 0.023150139022618532, 0.03933217187295668, 0.024321747150679585, 0.08831460130750202, 0.05781403131550178, 0.04059130333189387, 0.01884217585029546, 0.050600552567630075, 0.05082255862362217, 0.023784753211657517, 0.03160442560329102, 0.011234610192332184, 0.002317701218998991, 0.014369783366419142, 0.04949824062350672, 0.06828107434557751, 0.024837031414790545, 0.0030058029187784996, 0.07137721055187285, 0.03232514005503617, 0.023440235272573773, 0.014257033508329187, 0.0218424154445529, 0.08774558926234022, 0.03450764423178043, 0.03715211678354535, 0.0693546280672308, 0.03744313515198883, 0.017714608620735817, 0.07358099581324495, 0.039755934485583566, 0.05241110717179254, 0.02425334525469225, 0.006445684302889276, 0.030995651140983682, 0.029338314780034125, 0.03050026385608362, 0.00808001315817819, 0.027183858219359536, 0.028501665728981607, 0.03754057172045577, 0.012847313792008208, 0.025394603253516834, 0.022024454992788378, 0.0384748428768944, 0.027746190935431514, 0.005862142397745629, 0.008336058745044284, 0.014608504443458514, 0.09715430744108744, 0.04188242135569453, 0.015357131997006945, 0.030011221933818888, 0.022240139805944636, 0.014426125362660969, 0.033526320912642404, 0.08258906556875445, 0.01729657353280345, 0.021613240242004395, 0.08208248298615217, 0.035499186924425885, 0.026378006441518664, 0.018995681675733067, 0.007282803226189571, 0.023835174724808894, 0.06257661560084671, 0.06949927264940925, 0.08358053775737062, 0.08358582184882835, 0.021915049437666312, 0.009005039937619586, 0.03167984265019186, 0.029810858759447, 0.0035178743792130263, 0.07756037681247108, 0.038201242714421824, 0.053494646490435116, 0.05295466726238374, 0.06175261645694263, 0.021991767098370474, 0.002081825582536112, 0.07302097859792411, 0.06548742268932983, 0.029299064444785472, 0.04546014832158107, 0.08250851285993122, 0.029828160077158827, 0.06850379286333919, 0.03273729176726192, 0.05019136573537253, 0.029477734642568976, 0.029017601227678824, 0.02216877674072748, 0.01298527718972764, 0.07574376999400556, 0.007160421218941337, 0.031375042599393055, 0.08940850471844897, 0.019880893160006963, 0.04294194106478244, 0.06736829949659295, 0.022705837473040447, 0.023977208802534733, 0.038225366224651225, 0.018737065474851988, 0.0358971599052893, 0.06413600145606324, 0.033055940293706954, 0.15158238646108657, 0.029677585735043976, 0.014865667890262557, 0.033979591316892765, 0.04664321335440036, 0.03267757114372216, 0.046948625677032396, 0.015034597399790073, 0.024384551397815812, 0.03586062397516798, 0.058209388225805014, 0.011678551800287096, 0.021726716477132868, 0.06250318008824252, 0.02599477993499022, 0.03803689411142841, 0.025583711758372374, 0.07274574571056291, 0.042959470592904836, 0.022511264905915596, 0.06075332574255299, 0.0208956557980855, 0.05404101189924404, 0.08875350002199411, 0.02819366145558888, 0.04897483355307486, 0.03393014943867456, 0.017491457801952492, 0.034629875954124145, 0.05538612858799752, 0.034014442571788095, 0.04444363235961646, 0.03974212311732117, 0.0637358873791527, 0.03846551408059895, 0.02179966959374724, 0.022142560374049935, 0.035972881232737564, 0.0698307529091835, 0.0490390293271048, 0.03742658154806122, 0.045197172003099695, 0.025510016494081356, 0.10559410729911178, 0.046594803061452694, 0.030073749730945565, 0.06277636464801617, 0.024025925231399015, 0.019395634335523937, 0.082180431636516, 0.05610777072433848, 0.0982391789148096, 0.07276397285750136, 0.046040099623496644, 0.04889893782092258, 0.02872915440093493, 0.04919024933769833, 0.04657266108551994, 0.0170297844306333, 0.014369073687703349, 0.03777492711378727, 0.02446284612233285, 0.013512988716684049, 0.04206785808491986, 0.05025912010751199, 0.041875916431308724, 0.023068719856382813, 0.02434191501379246, 0.08053518671658821, 0.021875598722544964, 0.03036194608284859, 0.0403206235205289, 0.07679103684495203, 0.025106583161687013, 0.06689372574328445, 0.09824194712564349, 0.03470203126198612, 0.06679709811578505, 0.03410625366086606, 0.005003529486202751, 0.002564101669122465, 0.021307033821358345, 0.03281583696661983, 0.04860531822487246, 0.02047323461738415, 0.032355015209759586, 0.041672694133012556, 0.08767300721956417, 0.03274928116297815, 0.014051084745005937, 0.03118736458418425, 0.02189680002629757, 0.0684498535702005, 0.0056751286047074245, 0.03297025563369971, 0.034766126846079715, 0.03103912058577407, 0.040291702025569975, 0.050742232269840315, 0.009815170196816325, 0.06342682740068994, 0.027765631493821274, 0.05339443428965751, 0.012317746895860182, 0.01969874785572756, 0.08546011580619961, 0.06586531686480157, 0.024587235639046412, 0.037786935063195415, 0.060496564910863526, 0.06348253300529905, 0.023072026124282274, 0.07250873342854902, 0.02027822789386846, 0.00996274904537131, 0.0318728233105503, 0.0394870024319971, 0.02719812600844307, 0.07369720871793106, 0.013601417467725696, 0.20559720054734498, 0.12478045042371377, 0.09381715877680108, 0.18460418796166778, 0.11834015225758776, 0.10743657054263167, 0.10873089835513383, 0.1586701936321333, 0.16183969855774194, 0.1378623172058724, 0.07640534269739874, 0.13529971096431836, 0.1649002858903259, 0.1477897891891189, 0.17350955517031252, 0.20353251602500677, 0.18676238309126347, 0.09499065010459162, 0.12321082293055952, 0.1887917859130539, 0.08611415571067482, 0.12254865650902502, 0.1392836487502791, 0.07383688091067597, 0.1962090769666247, 0.1266338158166036, 0.12341041612671688, 0.19978766853455454, 0.11214622485567816, 0.18380191148025915, 0.17829566553700715, 0.15409847488626838, 0.14323923649499193, 0.14181679172907025, 0.14797496987739578, 0.18961637135362253, 0.12684737623203546, 0.15718542330432683, 0.1934020221233368, 0.10466796637047082, 0.14548573235515505, 0.1747118789353408, 0.17248347663553432, 0.11997093271929771, 0.06833130290033296, 0.16346423013601452, 0.09906906328978948, 0.30321728729177266, 0.19497503380989656, 0.11125432662083767, 0.13773334678262472, 0.1378730486612767, 0.09632491288357414, 0.22839725366793573, 0.10655143327312544, 0.1603213237831369, 0.3672293946146965, 0.1073389632801991, 0.10508651539566927, 0.12674353492911905, 0.18521616293583065, 0.05626276455586776, 0.14763803483219817, 0.11794406804256141, 0.11566298067918979, 0.18428686045808718, 0.13138888956746086, 0.11927756640943699, 0.2124612353509292, 0.14033837418537587, 0.08590095894760452, 0.12395824727718718, 0.13494831888237968, 0.20034150365972891, 0.11277687226538546, 0.13499268447048962, 0.14158166450215504, 0.17620269034523517, 0.15773053077282384, 0.1585673468071036, 0.14363687922013924, 0.10960103682009503, 0.1682518990128301, 0.08589557837694883, 0.0748995844332967, 0.10052916462882422, 0.18135880585759878, 0.11480669068987481, 0.17955592134967446, 0.236275581701193, 0.13528909825254232, 0.1169306282827165, 0.13683997909538448, 0.11676470632664859, 0.21991186367813498, 0.16753545933170244, 0.16252194007392973, 0.13884992280509323, 0.16390907345339656, 0.2395841947873123, 0.11591201575356536, 0.1295373943867162, 0.12909587589092553, 0.13225316506577656, 0.16474252013722435, 0.13182157650589943, 0.131661836639978, 0.18849114188924432, 0.14970190299209207, 0.18287565180798993, 0.0845618944731541, 0.13096574664814398, 0.10306661206413992, 0.15623722574673593, 0.07452735284459777, 0.08293952254462056, 0.11418461508583277, 0.17798108397983015, 0.12485616432968527, 0.10175911855185404, 0.2121653559152037, 0.12769686814863235, 0.07037804229184985, 0.13437685032840818, 0.21171365515328944, 0.0879186209931504, 0.10151901151402853, 0.15968025662004948, 0.13850568502675742, 0.08327855044626631, 0.20518934587016702, 0.18401432898826897, 0.12357474246528, 0.13688732811715454, 0.11210464974283241, 0.20825699844863266, 0.10645283153280616, 0.1377976019284688, 0.1548384703346528, 0.2938216383336112, 0.11786452465457842, 0.11913981637917459, 0.20302110206102952, 0.14627606025896966, 0.11190205827006139, 0.10959443170577288, 0.09037542666192167, 0.1772499200887978, 0.1749485795153305, 0.0992632017005235, 0.17166419012937695, 0.12378458472085185, 0.15048905450385064, 0.1288101787213236, 0.09463484224397689, 0.11263201246038079, 0.21389506466221064, 0.12710975512163714, 0.3394860145635903, 0.07229451992316172, 0.08445681378361769, 0.12574567284900695, 0.15773541410453618, 0.2291731839068234, 0.14130764873698354, 0.13836666592396796, 0.1898030363372527, 0.18315852881642058, 0.10849458369193599, 0.08798398936050944, 0.07891905625001527, 0.11140734262880869, 0.14941489964257926, 0.20633672102121636, 0.10349003699957393, 0.1412776214419864], [0.06964930522372015, 0.05351525222067721, 0.04832270096812863, 0.020482110703596845, 0.03701416637341026, 0.04576619146973826, 0.03794009578996338, 0.06218202310265042, 0.025664730164862704, 0.026941927353618667, 0.07052942557493225, 0.05911139822273981, 0.05822440187330358, 0.033647149975877255, 0.025149037719529588, 0.006812894334871089, 0.022519389567605685, 0.06475038098869845, 0.049731690596672706, 0.048766230684123, 0.03209091824828647, 0.03434165548242163, 0.019027421476494055, 0.040106205924530514, 0.021504773503693286, 0.011738152752513997, 0.040145398743334226, 0.04757525064633228, 0.06338672174024396, 0.04346855421317741, 0.0931409360782709, 0.026978051391779445, 0.0611352757550776, 0.03190394527337048, 0.03521564198308624, 0.027613294550974388, 0.026590791312628426, 0.027746079613280017, 0.053555465492536314, 0.06677331970422529, 0.03476815661997534, 0.034671933462959714, 0.056885923695517704, 0.0454381213785382, 0.043690244856406935, 0.007090832814355963, 0.05663220195856411, 0.011346888786647469, 0.05397356922912877, 0.011044615748687647, 0.0034695132535489392, 0.00472273327432049, 0.02284762293129461, 0.026241514351568185, 0.04062580948811956, 0.028250825380382594, 0.04540494366665371, 0.02215393935330212, 0.01849714211857645, 0.05453881858556997, 0.0671693000185769, 0.03842136371531524, 0.11694382366840728, 0.0331342331628548, 0.010348509986215504, 0.07593678034027107, 0.05485855806909967, 0.032323548148269765, 0.031880011010798626, 0.0746612659713719, 0.04004612907010596, 0.0202265410189284, 0.02339011803996982, 0.027109506154374685, 0.07071437619742937, 0.03844045175355859, 0.07259583187988028, 0.023278857115656137, 0.014698930499434937, 0.06950669412617572, 0.053181482435320504, 0.024243782681878656, 0.054049349928391166, 0.056273922746186145, 0.0299432746032835, 0.051806976698571816, 0.03667146484076511, 0.06429005647078156, 0.031697591111878864, 0.05691301208571531, 0.0063355648944707355, 0.025545587632223032, 0.02395091636572033, 0.10393681732239202, 0.024780043750070035, 0.03498022531857714, 0.03279088967246935, 0.04231257385981735, 0.012212813708174508, 0.023871348857937846, 0.01626967863558093, 0.004713102516689105, 0.09712026512715966, 0.019891350020770915, 0.0805852519988548, 0.025440184108447284, 0.037589564599329606, 0.019186669669579715, 0.014331441234389786, 0.03567492007277906, 0.0501180267019663, 0.016448417482024524, 0.01140303504143958, 0.07086967802024446, 0.02148275398212718, 0.03278255164332222, 0.02161706972401589, 0.08243704403867014, 0.0357719818566693, 0.037559210759354755, 0.0029397457456070697, 0.008701038623257773, 0.04201240109978244, 0.033921169451787136, 0.05426184907264542, 0.04571001460135449, 0.01593848781340057, 0.021819470093760174, 0.05089450984087307, 0.013072931324131787, 0.04356809477030765, 0.019253574282629415, 0.011285102209512843, 0.013149281621736009, 0.024199046019930393, 0.05876470764633268, 0.08663391141453758, 0.037108467367943376, 0.042408863810123876, 0.028714458021568134, 0.0751808361383155, 0.013867138804926071, 0.0654912150639575, 0.028009653360641096, 0.018503756509744562, 0.017388607266184408, 0.03390199977729935, 0.043258689693175256, 0.02717750543524744, 0.0454467970848782, 0.03245061496272683, 0.05272672031424008, 0.055628387854085304, 0.04773835986270569, 0.0648256644490175, 0.032068108339444734, 0.0266106715935166, 0.02405177423497662, 0.040098862373270094, 0.05096755572594702, 0.013292617240949767, 0.014224328915588558, 0.05855485796928406, 0.045164936818764545, 0.030477112559310626, 0.018490496186132077, 0.019734914567379747, 0.07122463983250782, 0.03192597963789012, 0.05376323344535194, 0.0444841462012846, 0.0679345136450138, 0.01197266863528057, 0.028344380516500678, 0.04203543736366555, 0.02409597840596689, 0.05037614937464241, 0.0444979130406864, 0.040854795443010516, 0.032087055369629525, 0.019671657610160764, 0.09505256748525426, 0.05036087226471864, 0.09219515792210586, 0.03329674495034851, 0.007684227657591691, 0.06758554838597775, 0.03690849196573254, 0.008752267222007504, 0.027319480141159147, 0.011556921217561467, 0.028702010349661577, 0.025428688240936026, 0.05499410763150081, 0.01969962915609358, 0.04260320260073058, 0.015022586667328142, 0.03234372714359779, 0.03901479984051548, 0.010516847632970894, 0.032484059847774915, 0.02128046122379601, 0.053817721927771345, 0.00542896285878669, 0.05571862930082716, 0.02032434866123367, 0.10442276819958352, 0.04590388583892491, 0.01492411109211389, 0.05510557079105638, 0.05972917308099568, 0.04780221053806599, 0.016848106679390185, 0.041857785763568245, 0.058672881714301184, 0.04384881212899927, 0.032834297890076414, 0.03289125772425905, 0.04212958621792495, 0.09279942198190838, 0.05013904803490732, 0.030075543872953858, 0.03857867304759566, 0.029026148913544603, 0.019743174671020824, 0.040625520050525665, 0.020338534814072773, 0.015992415974324103, 0.02317322538146982, 0.043349988700356334, 0.052581634154194035, 0.04896252874459606, 0.04690848661994096, 0.03893767956469674, 0.041076356210396625, 0.052277227441663854, 0.046892612081137486, 0.07748721589450724, 0.04104874831682537, 0.021346590292523615, 0.006818302272222354, 0.05629258033877704, 0.04506686942477245, 0.024193726676458027, 0.04310890202759765, 0.048168612556764856, 0.08640219064545818, 0.02920626815466676, 0.041702023809193633, 0.026550845213932917, 0.043745913353632204, 0.04518802132224664, 0.017762699790182523, 0.012098577699362068, 0.0304814782430185, 0.04603696033882443, 0.04521355491306167, 0.05017457093345001, 0.0217695792161976, 0.00644333076706971, 0.026228775386698544, 0.020623534364858642, 0.03249874323955737, 0.03314670866529923, 0.04792048661329318, 0.07601823104778305, 0.0047655570506321965, 0.048803256431710906, 0.05554833980568219, 0.0771096334210597, 0.019172359207004774, 0.04888081086392049, 0.010910350101767108, 0.006731898192811059, 0.051276162994327024, 0.016393860350945033, 0.033577788854017854, 0.015153813219512813, 0.05564480787143111, 0.04977102442353498, 0.07628886261954904, 0.03979134235123638, 0.10150572707061656, 0.019867595729010645, 0.06531257269671187, 0.08488029066938907, 0.03517925819323864, 0.06751645443728194, 0.006233916174096521, 0.0460342440783279, 0.04014448219095357, 0.040380833961535245, 0.038539205634151585, 0.049416600668337196, 0.02039386934484355, 0.015713583670731168, 0.026534124626778066, 0.02358184261538554, 0.021135035531187896, 0.05518586745893117, 0.03508835252432618, 0.06479768548160791, 0.01997421266423771, 0.005844207471454865, 0.061098190635675564, 0.07054452085867524, 0.06134335540991742, 0.01649890764383599, 0.07829006382962689, 0.09162394169834442, 0.04716596733487677, 0.025995325413532555, 0.08305632174597122, 0.04242974042426795, 0.0045817562931915745, 0.036427654486033134, 0.02983621794555802, 0.004506832310653408, 0.008807290978438687, 0.04643294436391443, 0.03417176674702205, 0.011463020055089146, 0.017454471017117612, 0.0505829080066178, 0.07917517141322605, 0.030639720826002304, 0.006258183011595975, 0.0011376613656466361, 0.0976080862164963, 0.04812348626728635, 0.035562451303121634, 0.03518902485666331, 0.006365999906847719, 0.08281371367047541, 0.05195302393985912, 0.016186597058549523, 0.017284864297835156, 0.043351135318516754, 0.02519339588616276, 0.08492915367241949, 0.027548805628612172, 0.01418041882061516, 0.041300636949017644, 0.06027146409905981, 0.06296316321822815, 0.07556551354355179, 0.09028416476212442, 0.023361307867162395, 0.009100652678171173, 0.045622545076184906, 0.035205110907554626, 0.104480113950558, 0.12399456056300551, 0.08810887797153555, 0.1275921065825969, 0.07438211454427801, 0.11113482600194402, 0.13811697775963694, 0.21327523776562884, 0.1480947673553601, 0.1007631489483174, 0.13333192124264315, 0.11999299676972441, 0.14630788355134428, 0.11553781747352332, 0.19886961701558903, 0.17529752250993624, 0.09307943430030718, 0.13492618803866208, 0.15851722215302289, 0.15440079616382718, 0.09264809807064012, 0.13312456518178806, 0.0899055358604528, 0.19242566748289391, 0.07796878810040653, 0.1003799113095738, 0.09939108858816326, 0.11667799379210919, 0.20978481334168464, 0.26325100217945874, 0.1176086618215777, 0.19845773989800364, 0.1063667720882222, 0.23187305778265, 0.16221200436120853, 0.09747499687364325, 0.15097351366421208, 0.2150554273976013, 0.11768735916120932, 0.08946118978201412, 0.12200245808344334, 0.15978092153090984, 0.16489492758410051, 0.11010025729774497, 0.13826040521962568, 0.17413183115422726, 0.11309715351671912, 0.15693598747020587, 0.13628917193273082, 0.12331492398516275, 0.08325062342919409, 0.11269292794167995, 0.09006735373986885, 0.0785204338899348, 0.18423737405100837, 0.1289469565381296, 0.12309014229686, 0.1409839090774767, 0.12475348077714443, 0.08938804370700382, 0.19896480487659574, 0.12649041804252192, 0.16138798295287415, 0.1937447756063193, 0.1131165903643705, 0.10433221876155585, 0.12592208135174587, 0.1403724536066875, 0.1504253040184267, 0.06993815652094781, 0.19108718930510804, 0.2699231175938621, 0.06693895964417607, 0.13499805761966854, 0.09796552680199966, 0.2829751797253266, 0.3791399742476642, 0.17022829764755443, 0.09977733934647404, 0.0767909329442773, 0.13161444308934733, 0.12199160788441077, 0.11352378453011625, 0.10214487949269824, 0.1411800883943215, 0.12345806942903437, 0.09632717643398792, 0.1575577587937005, 0.10550398830673657, 0.12119568418711424, 0.1518627698533237, 0.09568458786816336, 0.14268976519815624, 0.14459983067354187, 0.20783363288501278, 0.07610319953528233, 0.095016283885343, 0.09948538587195799, 0.06981440339586698, 0.1482305210083723, 0.1356592369847931, 0.12083948298823088, 0.06433053320506588, 0.14949764910852537, 0.09190083699650131, 0.18561141594545916, 0.14798632473684847, 0.16409082541940734, 0.0857804341649171, 0.1480668774456717, 0.14145020046271384, 0.1208897189644631, 0.12316111387917772, 0.12624260009033605, 0.1566028522211127, 0.19749276980292052, 0.11978222682955675, 0.12129115406423807, 0.19380045152502134, 0.12793184694601223, 0.1211933241575025, 0.1824116165516898, 0.12032939004711807, 0.10311318925232626, 0.12193621398182586, 0.13147347955964506, 0.1311269262805581, 0.16675929160555825, 0.15872471180045977, 0.14877500507282093, 0.1616946977446787, 0.1437635044567287, 0.14305478311143816, 0.12747431290335953, 0.1490784395718947, 0.11910857938346453, 0.11414778971811756, 0.12052127975039184, 0.11028981665731408, 0.10913830032222904, 0.11642685843980871, 0.20325303805293515, 0.07243728687171824, 0.11113528613350354, 0.21985615807352588, 0.09147817647317424, 0.061926156558911316, 0.0893190833448898, 0.18268564715981483, 0.09540627506794408, 0.1398095494369045, 0.11935908391023986, 0.1294053514720872, 0.18973671802086756, 0.2621741162147373, 0.16035657579777762, 0.10289907964761369, 0.10943515197141096, 0.16586512239882722, 0.10273439707816578, 0.08568140197894536, 0.07604028767673299, 0.1313422084785998, 0.1344472059281543, 0.2903002663515508, 0.1797413098393008, 0.08736111223697662, 0.10429864400066435, 0.16980938496999443, 0.1531181571772322, 0.1386139792157337, 0.13450996193569154, 0.1515414792811498, 0.17036445206031203, 0.2109105177805759, 0.15400837815832347, 0.17157027876237407], [0.006307875364655047, 0.021766202444268856, 0.010377749676990788, 0.055285437701968476, 0.062339855649042875, 0.019397354262764566, 0.032192117505474016, 0.04961268350598402, 0.02700099674257217, 0.018401037705189083, 0.0359994760947302, 0.03413573547732085, 0.014976431575632887, 0.05070526589406654, 0.042085532331839204, 0.02058112804661505, 0.01377140082695405, 0.011925369708478684, 0.022534835516125895, 0.09150623707682826, 0.029697566205868497, 0.07494265868444927, 0.04347064335888717, 0.055089681409299374, 0.07386554265394807, 0.012669082389038522, 0.030357521027326584, 0.018263128113176208, 0.05946236356976442, 0.04140547644055914, 0.025322292094642762, 0.03343489202961791, 0.03897976675943937, 0.028844677108281758, 0.05713045764423441, 0.013840480860380922, 0.02642264291353058, 0.02156018410460092, 0.05625265650451183, 0.056045074088615365, 0.051733715590671636, 0.025959910126402974, 0.00902337098523276, 0.041350282917846926, 0.06503855693154037, 0.02867939525458496, 0.011411775685701286, 0.021453478111652657, 0.005089844044050551, 0.013256754809845006, 0.05188718430872541, 0.025573499806341715, 0.023425377476087306, 0.04059304737893399, 0.04744790923723485, 0.05628476552374195, 0.06314187237876467, 0.018891923864430282, 0.025648343544162344, 0.02978321190312272, 0.03463839952019043, 0.025263356292271055, 0.02111071349645499, 0.06702266648062505, 0.09548996706143953, 0.016428095623268746, 0.02517202574381372, 0.02369079174968647, 0.032747704099165276, 0.010838562157005072, 0.023199957540782634, 0.022609235820709728, 0.07860955098294653, 0.05089003097964451, 0.009012246191559825, 0.020580057498591486, 0.06271685182582587, 0.07204838664620183, 0.029883381430408917, 0.09874417330138385, 0.02405598777841078, 0.029788451465719845, 0.029196464383858256, 0.08999057856271975, 0.06339990970445797, 0.025745696621015668, 0.05246621534752194, 0.07920346950413659, 0.04118977492908016, 0.05007308966014534, 0.046435578988166526, 0.007960245366120944, 0.08881260466296226, 0.0475775475933915, 0.06639005237957463, 0.021078426361782476, 0.04023700203106273, 0.05184694135095924, 0.02801574082695879, 0.018758370679279324, 0.06308877913397737, 0.05124045826960355, 0.0408560830692295, 0.14296057488536462, 0.08116297685774043, 0.033877802052302286, 0.02096443062328035, 0.022975767715252005, 0.009298075092374347, 0.013776337036688346, 0.030434247964876704, 0.04546224117802922, 0.013550576641137013, 0.044601995541597717, 0.021917658086749725, 0.023857940104790032, 0.04289431744837202, 0.07737112915492617, 0.12889159232145175, 0.02333165906748036, 0.015109480100363726, 0.012407033755152952, 0.016753182280808687, 0.13197212858358398, 0.02631151186506031, 0.06505748169729486, 0.021739885887654964, 0.025496535381535068, 0.0073043426709773485, 0.046707334913662635, 0.04686056614445988, 0.021956810087431222, 0.08744303049752489, 0.023344049222941976, 0.025452075169596355, 0.03048555263376329, 0.023793115360604133, 0.04779716764460318, 0.08268350386060774, 0.06956368364626542, 0.01302269998632255, 0.030823610177321825, 0.021725901970057748, 0.053080472425790504, 0.00978520691205631, 0.032177322791540064, 0.03268229491368402, 0.008423506933468161, 0.014579991129721748, 0.02987900090374751, 0.0474590971134603, 0.005026981352784787, 0.06310039374511689, 0.006415800799004501, 0.015752830295241438, 0.016897433524718508, 0.04017361890873872, 0.059213484346400946, 0.05777140977443196, 0.06471360757132061, 0.016693578545528, 0.05567061234614812, 0.06460612974478863, 0.02457860446156701, 0.06359697959851474, 0.010765112729131943, 0.0350715057720663, 0.021604499597742688, 0.03810025496932212, 0.016772897433838807, 0.03205480163160246, 0.03477287296846043, 0.026280315687472466, 0.13511310535250232, 0.0405256529484177, 0.03227306355256587, 0.0405108693666989, 0.0618523945013294, 0.04150601147557609, 0.05578412012255285, 0.020260672390577383, 0.02503579897165764, 0.015724088771094102, 0.037169286370044574, 0.008667557558510453, 0.031895481079118326, 0.050604062926140614, 0.025859449306153692, 0.05890455795451999, 0.03696240899444092, 0.029429591522784904, 0.11791911703767255, 0.03708274081873242, 0.029182348735048436, 0.04280732660845388, 0.05373039712139871, 0.023615280078956857, 0.05856283605680801, 0.0432954631105531, 0.03761789979762398, 0.01736083795549348, 0.06394394105882384, 0.015176747438090388, 0.02677521129953675, 0.03374290929059498, 0.018501639533496927, 0.03156747407047078, 0.0601546760299243, 0.023426561201631557, 0.009557799876347417, 0.03315301320981234, 0.004039110435769544, 0.047822033302509226, 0.02872214296075981, 0.006175754524520016, 0.061192487919470295, 0.0009295264555930771, 0.03244834028009791, 0.04865612194407731, 0.045093156295479275, 0.0334539281175239, 0.01628166988666635, 0.03026298996701371, 0.011767646628868533, 0.02082028328004526, 0.07048407293041237, 0.02876764217944583, 0.04265678937372286, 0.021742546487075742, 0.030649246291432064, 0.048974210149026476, 0.04492318221309688, 0.016614736487099435, 0.04202623102173675, 0.002023971460403118, 0.012282316765777068, 0.007122824481484713, 0.021921264924458228, 0.03534346949891187, 0.06841400783741847, 0.02556656072556507, 0.06120632155216299, 0.0684587296564132, 0.02556807656219462, 0.016097199804789852, 0.04293518009944819, 0.007920186089904746, 0.04928636488330085, 0.03731910743226763, 0.04738782125059515, 0.010474953396624187, 0.067092613899149, 0.01276439177672728, 0.028640762757277116, 0.061643505905522034, 0.03149001611745916, 0.02494754833605839, 0.03799833582888823, 0.03201270701538306, 0.03451248674537055, 0.045565830150735565, 0.01901106083096238, 0.03700934612425044, 0.0313113143783994, 0.027830517465190496, 0.07701416354393587, 0.02725203932641307, 0.008203277393477038, 0.06988417269894853, 0.031364611713797785, 0.022876694711158052, 0.04201722134894226, 0.018753962322080042, 0.040445040867780335, 0.007825342399883084, 0.046565183947677724, 0.04894147772574797, 0.027570810307224747, 0.020355225715320557, 0.04634726712538395, 0.023635047182324342, 0.023780721494404133, 0.014909384099155432, 0.0267080079720472, 0.03372804778337013, 0.023029224612400867, 0.041992901169578545, 0.03857006784528494, 0.03317808666906785, 0.03728075695107691, 0.002206995745837048, 0.027611697078100406, 0.03160885251418222, 0.06651035451795906, 0.03567757325072307, 0.05170924327103421, 0.015351377569459146, 0.05779992679890711, 0.08239520917413756, 0.15621470898622647, 0.04764285658893641, 0.06675976066617295, 0.031150461290962994, 0.03942931529309135, 0.007935211797303054, 0.0228631616482744, 0.060598387572099455, 0.023648329770367127, 0.03313163193524815, 0.029914924562035594, 0.058870678913081065, 0.042350267540314235, 0.03391025617020205, 0.020396134750626516, 0.02005642221774906, 0.09393878935952671, 0.07332924447837286, 0.009689322359918151, 0.04437976313056424, 0.031018843255878892, 0.050308209465583786, 0.03922750307538081, 0.01718506398901809, 0.034368435881333426, 0.03178167273290455, 0.03868204679747578, 0.03253464092267677, 0.03881920682033524, 0.060312675559544004, 0.05891762346436735, 0.04069148584676441, 0.029713876756432, 0.023939821257954463, 0.04803594994882587, 0.0673752831062302, 0.05341181538824458, 0.05731456963985693, 0.03268740088969935, 0.03472544231044594, 0.05071374493127223, 0.04500337498029694, 0.03946744684071746, 0.06387294721207581, 0.0790728886204306, 0.02985034658195218, 0.039461706328438595, 0.012172944607300451, 0.033818756783148274, 0.0664479992701672, 0.04614464225596748, 0.08248341342550702, 0.058031777443829924, 0.10740435391198844, 0.2028135085129179, 0.12584920244989917, 0.16023906413465738, 0.1466510971658863, 0.15982409968273714, 0.16568038699915633, 0.1465824930346571, 0.11733758496120572, 0.1600136887282133, 0.07331329572480172, 0.0872555268870201, 0.12830084277084097, 0.1370526192476973, 0.19143867044476792, 0.20839287084527314, 0.12380402898998, 0.08929214338422753, 0.09927951410645619, 0.25494464789517224, 0.07793885728460737, 0.20633902167901397, 0.1350396772613749, 0.11367925704689696, 0.11118276132037863, 0.19690494431415573, 0.16153509146533906, 0.07933517103083432, 0.2432978423894383, 0.1092454738682136, 0.11762869238737039, 0.11363353332853876, 0.11627060666796751, 0.1441339697339572, 0.17615183838643134, 0.1148644372005947, 0.16199044359382242, 0.10287206547218375, 0.12207894382299855, 0.13206883042585105, 0.1029632383142598, 0.12297143577598035, 0.12705961562460288, 0.21933117765001953, 0.14146556291962042, 0.09867231114185415, 0.15024951891973615, 0.13585391716333106, 0.10291079073795117, 0.15255721227731556, 0.17837948369560763, 0.12557860056404024, 0.13033297669608146, 0.08575060724979267, 0.21710408153012395, 0.1679182591033168, 0.16648113465635106, 0.0824854988604784, 0.11166073411004618, 0.07289984525414184, 0.10216061302344315, 0.11056835952331312, 0.10632763864123262, 0.15716844296548516, 0.14292517444118857, 0.13492753874743357, 0.22600857715588063, 0.10328038028092124, 0.1398943769163452, 0.13167521014111117, 0.1537302360520698, 0.14697881473693997, 0.1843305432703346, 0.1437674229964614, 0.08810817293124273, 0.1610287686344236, 0.20589640480466187, 0.15924705017823726, 0.21414016635389999, 0.3012746712192893, 0.146932860952802, 0.1565553547698073, 0.14520005002850667, 0.1122301617579069, 0.1506824285024777, 0.14421017345739529, 0.12480736069846898, 0.14425740373553708, 0.13005278626224026, 0.11225957307033241, 0.09981412760680541, 0.08285487318062223, 0.14961441862396896, 0.11602972037508152, 0.1878841986763291, 0.1755095986300148, 0.15411900269100443, 0.147111555270385, 0.06357291174936108, 0.19607425841968507, 0.09786043869098648, 0.0900880151311867, 0.11141180293634534, 0.1712113167741336, 0.13422465068288147, 0.12766676663886756, 0.11825525798485614, 0.06408655215636827, 0.12161411446868442, 0.13065777020528913, 0.11917422234546393, 0.09752080222824588, 0.08226304751588032, 0.14826105296378955, 0.15523994254181162, 0.1221827331755776, 0.08222584365285002, 0.22619899740675464, 0.2980675542494282, 0.2003734011668712, 0.12015658096061088, 0.15267303184373304, 0.20049118000315502, 0.2714823401765898, 0.20766345842275769, 0.22146388742839918, 0.12043927243212238, 0.11110136256320402, 0.12816845846828073, 0.13587775494670495, 0.17687421524897218, 0.11191083045559935, 0.13752596103586257, 0.13243018212961033, 0.25034202612005174, 0.09310046676546335, 0.1487596277729608, 0.11079340838477947, 0.12731632450595498, 0.15865474211750552, 0.12452237599063665, 0.13693231710931286, 0.13360252312850207, 0.16009875369491056, 0.16749234055168927, 0.08980262966360897, 0.11016342148650438, 0.07293313799891621, 0.13946517807198688, 0.0967676039726939, 0.1234233591821976, 0.0808593345573172, 0.1114666550711263, 0.14996806683484465, 0.11871165654156357, 0.15823102032300085, 0.08904061469365843, 0.09093537708395161, 0.11494684527860954, 0.1490003359504044, 0.11538463819306344, 0.18885391851654276, 0.25663324166089296, 0.1260006451047957, 0.12011465703835711, 0.1743424971937202, 0.17437892180169, 0.10140719212358817, 0.10681093262974173, 0.12295225125853904, 0.14461284794379026, 0.1958206220297143, 0.1096132599923294, 0.25492499582469463, 0.2460387273458764, 0.11469656339613721], [0.015102945490070852, 0.06142393780464772, 0.028818278915423434, 0.027311537305649836, 0.08383620021049865, 0.016095524406409822, 0.0529956635000417, 0.05724663344153669, 0.043024237820645794, 0.03333397107780911, 0.0478757759265136, 0.070996110298438, 0.10499128300580196, 0.025649133931437973, 0.06901792308781296, 0.019520213099895045, 0.021435519993247, 0.034613660027389415, 0.03250584559282288, 0.024936364170571323, 0.0333095841051545, 0.02669664754648693, 0.03567034473235253, 0.08675146760651842, 0.07110660866601393, 0.10067577590234578, 0.04275470091670286, 0.039673789869993925, 0.0441532299737446, 0.011383480377844535, 0.04104014682525303, 0.03175516321789473, 0.028995570573897567, 0.05170473472389858, 0.02861208802642068, 0.027536005436559208, 0.013878359150112374, 0.022642825424554758, 0.014468223689618753, 0.01686100149527192, 0.013922196885687299, 0.03816369746346027, 0.0389333936618641, 0.030269654453149997, 0.013527083956432762, 0.0433159575186437, 0.06001242858474143, 0.02058490372291999, 0.03537045769917313, 0.04886088419880252, 0.07334097783314064, 0.04913471442705486, 0.05234511168964673, 0.07708037053816952, 0.013368835807341384, 0.025568141500116326, 0.06468403298640624, 0.059246728851576336, 0.06150687280751299, 0.025533618645567913, 0.026216418627882376, 0.017409615611541085, 0.032583771098870784, 0.08882522117346525, 0.04799341746547725, 0.02176926009269664, 0.04302446046494879, 0.03336856258101761, 0.04641740750230383, 0.05600351752946153, 0.01997534629481379, 0.012303238836466335, 0.030063843914831523, 0.04293231169867795, 0.04080713100847788, 0.01789085756172426, 0.030423716889345087, 0.026488005714782048, 0.04213123378576711, 0.03275933726399671, 0.09407575271325186, 0.05880611948668957, 0.047818096209084615, 0.03916606066923123, 0.008924887988541741, 0.06954597600270063, 0.04933947297104169, 0.03669350662676152, 0.023838007873564493, 0.04963083272741642, 0.04229472891893238, 0.04802640964044258, 0.09426275166333653, 0.025625774833315518, 0.04963311854226049, 0.013742944101977628, 0.06107663495640736, 0.10132590468856506, 0.06583730821148492, 0.03552533278707415, 0.0632783533365, 0.06238324902369641, 0.04918058286421001, 0.0604164537799079, 0.006490375972134643, 0.03427566742175259, 0.037275060967658646, 0.03571033164917026, 0.015339888195740059, 0.04733617890451569, 0.004200948260404402, 0.026750427277875133, 0.027229520710534416, 0.07229593742522411, 0.024744021757214796, 0.046250598679762334, 0.029952224904263858, 0.051171093437005766, 0.025546647048031446, 0.031575385364703834, 0.06611104938201606, 0.03236743505112827, 0.057669086163514294, 0.04270853562047705, 0.0675894520827569, 0.013317410539457342, 0.09690507198683918, 0.0406242955068592, 0.036751145526068285, 0.04462276825506706, 0.03404169052373618, 0.10455967218149453, 0.023725706087134313, 0.016476721139042638, 0.019337770936544985, 0.030298241981654428, 0.0411348560010083, 0.06910131822223775, 0.07563398408819921, 0.08025294795515947, 0.04973141971277073, 0.03667504570330493, 0.038086681088316254, 0.04843472073844168, 0.02356105876970105, 0.013159204136172775, 0.038874192541697994, 0.055883861059555784, 0.05003283185942564, 0.02418252766801743, 0.0116311220699572, 0.035903605457860976, 0.03657246605143882, 0.07833574301912449, 0.03842828424239997, 0.050606322765816, 0.01859238192992052, 0.05546662192500662, 0.017235151535714976, 0.04744270678202156, 0.04504662734689191, 0.02074402575090062, 0.07579013938084245, 0.056021021082415245, 0.01317743963227258, 0.02384523453656584, 0.01094499726605136, 0.016042407041823026, 0.03539930869010277, 0.020012824752484448, 0.05009786626033019, 0.017368782646371983, 0.030785085291427094, 0.04380527032481041, 0.04341985819337424, 0.021087536224513315, 0.03000177996000275, 0.062355463014682755, 0.06567382792127319, 0.024072699088719673, 0.017867633905552793, 0.06494572167866863, 0.09921611243044026, 0.012990419345442206, 0.0429873419489013, 0.005360537770684459, 0.010327457111998228, 0.075172049109824, 0.07201654851087369, 0.058248577333870344, 0.08803047006949782, 0.011756569147109985, 0.04561179877782706, 0.05449658667203039, 0.019702256358868908, 0.05651148050674237, 0.028438371664378792, 0.0663401503697969, 0.02483475302142324, 0.010850321486941539, 0.07758022926282138, 0.06826638724305667, 0.051281981432111934, 0.04861613502725959, 0.039347293131868355, 0.034903401901829056, 0.04173190267465543, 0.05063466167484876, 0.030234797632147092, 0.0469888612133218, 0.07724808107013814, 0.029052313329884782, 0.06615765625610948, 0.010067347338917898, 0.022328754093905445, 0.03228091918572318, 0.043363714721635915, 0.043089754617540166, 0.013170935635571368, 0.017603444175620098, 0.029351890516409185, 0.028615019509743433, 0.023850783945817966, 0.033064400777220726, 0.027734793402487412, 0.0250679655073327, 0.04962740400515031, 0.0812027337087784, 0.06201677650096826, 0.013155620490579167, 0.05802604806376621, 0.04457311486476101, 0.08519599286955781, 0.0484410030185245, 0.06861751215183176, 0.058744940542965196, 0.09112737810937688, 0.08623802757938392, 0.03301787925011013, 0.024531847302569076, 0.03955899446737021, 0.06785790916183032, 0.05089845435577445, 0.08815722147119232, 0.02016607268160442, 0.04973667411832139, 0.034157855188823305, 0.029059588232485112, 0.029982918276800774, 0.04081543935171794, 0.04048640817927662, 0.03339420378324576, 0.02854292542906478, 0.028664587553066667, 0.04143774502153974, 0.02675828476640163, 0.06933204451343045, 0.054057669403846376, 0.02015956775721861, 0.07700418907916173, 0.023886828203103505, 0.029700842787860893, 0.08823237876640633, 0.0566821113898186, 0.06120423240645323, 0.041474299505352974, 0.03380411049874965, 0.05986508258501999, 0.020430253134691156, 0.06624798304983415, 0.02181139923777664, 0.045362136588664725, 0.04770503001054749, 0.038781479743192904, 0.05266790511086583, 0.0314433090534294, 0.02093353687087074, 0.02028559556492837, 0.025568143355485518, 0.011966923484578729, 0.02257837917568395, 0.04252131773682777, 0.04776577108714264, 0.08166416402673349, 0.03091931197559461, 0.08340868604136631, 0.010315889812773094, 0.019077583237958606, 0.023027155875752214, 0.03177236249030102, 0.03126153853372671, 0.06872865618788637, 0.04995214556402061, 0.0017931093793777109, 0.02531118028855417, 0.1129948633024469, 0.014558290731656598, 0.040710829925956205, 0.04407727858051658, 0.022114351340860594, 0.058715733321150765, 0.023109758767532185, 0.05347002574126236, 0.03458174025581684, 0.044216568567208014, 0.025452741247136146, 0.04852790851145983, 0.03132313308015, 0.0516705365589587, 0.02560831024311483, 0.050465140302549116, 0.05240678045083769, 0.05724948328861501, 0.03493679854727816, 0.06631942218518816, 0.024426351010333747, 0.025484126672381535, 0.06292285717790946, 0.04368605172203388, 0.03304155747173354, 0.01975668732484337, 0.053857003804296255, 0.08454363764030859, 0.050550186715554446, 0.05407077944255434, 0.03215375960280653, 0.025412930590391625, 0.04958851546689402, 0.08966665336629376, 0.04637181365978904, 0.0628135610895697, 0.022892088709340896, 0.025365028668602463, 0.03964773677580524, 0.013296392917254707, 0.029340463297558017, 0.03992907382780686, 0.021244847412162926, 0.02261789297335781, 0.06455973067204468, 0.016254648289759643, 0.02269123200676404, 0.05167504510609433, 0.03363651871040929, 0.0402064218360465, 0.025709346227813512, 0.028598141216207296, 0.07519279955886304, 0.02191194911574712, 0.03122011556115467, 0.027248675542068668, 0.02304803620063467, 0.07430234109051526, 0.14900081092491746, 0.1489970408147201, 0.18327136494917795, 0.14505026978440583, 0.19576697959564626, 0.2589022839674726, 0.18179434264311567, 0.08418441590038128, 0.1153044639795553, 0.11573936993954703, 0.1309114956529811, 0.1839725609170273, 0.11088055136497132, 0.16853072389494628, 0.12371023636660539, 0.14163066109176725, 0.23461242875782773, 0.12626280135009438, 0.16507688735146075, 0.12010582548100501, 0.19849113654345274, 0.12351643192232586, 0.15375820017652586, 0.13086352322716266, 0.22955372754950076, 0.10635327984346077, 0.10599572793580592, 0.11968081977101974, 0.10034059974714182, 0.07506998896133155, 0.15799518063431606, 0.16955187456915155, 0.08395381577429362, 0.19900315906852484, 0.09057950243004598, 0.13254663994302973, 0.13134088745573536, 0.1277047349140048, 0.12103319095331244, 0.08582744922023267, 0.09398401583894156, 0.19442888733465225, 0.08157121745171025, 0.1529932685662061, 0.16551978624192998, 0.14867834775941446, 0.11799746556789614, 0.14438451878959313, 0.1411728747189045, 0.16167368012247607, 0.16859438532264903, 0.14621328940847889, 0.1674213763908483, 0.24105925782350823, 0.11051189692807384, 0.17200544447405264, 0.16626061289571226, 0.12924721464514732, 0.1271249691490084, 0.3711530996952206, 0.25577558611985296, 0.07570246947580017, 0.14343771646963432, 0.20085643540369347, 0.14081425411859527, 0.12273817876121029, 0.21271930978400633, 0.13144928554538637, 0.1830688476911746, 0.21367648732848465, 0.09793772595003247, 0.1649829908274114, 0.11222700020880438, 0.1190092132310383, 0.10077920160256326, 0.13459091540426016, 0.08869311146554537, 0.10284196396241896, 0.1397816595272161, 0.1650716774747707, 0.196156473539304, 0.10518482027691789, 0.1355678786057979, 0.08899049003957771, 0.10593905753921717, 0.20716908416943625, 0.2627498150104657, 0.21132459165528417, 0.10650043288478628, 0.2114324999274686, 0.12346258910838515, 0.2097703711478971, 0.10552154009928927, 0.04379109901492484, 0.11048149855923839, 0.12419650636729784, 0.2741401788080111, 0.1318781281588599, 0.07792045202222653, 0.1245886943070218, 0.13524381240131333, 0.14835831883829087, 0.14574730972526595, 0.18227552151074633, 0.10098396756802686, 0.14645989023847505, 0.17980654462007806, 0.11965817684540525, 0.29118983424268663, 0.1086417812621221, 0.1575154860620387, 0.10692439216654748, 0.1605825894512236, 0.11034388211555779, 0.19467269768938422, 0.1826759398682043, 0.11042479847674258, 0.1259454441606067, 0.1427167942165397, 0.14202054095221683, 0.15792405320098624, 0.1429078824003227, 0.08154069291776977, 0.23914200835861266, 0.08586282739997841, 0.166215653589461, 0.12491200352087617, 0.23507717647589743, 0.1290439403965138, 0.14591027051210403, 0.19027866394026205, 0.09070401996723376, 0.11510426222230308, 0.11899421442649327, 0.13002933439565822, 0.08520946284988895, 0.2277151754242368, 0.21400156285380945, 0.15943316597258672, 0.1909488975070417, 0.20232465583831072, 0.11808473471319303, 0.10253442538669333, 0.1473930073552765, 0.16725232999306172, 0.1380649977363646, 0.11539163664565422, 0.12616854859516025, 0.16121204942464828, 0.088538136187708, 0.14863301737932488, 0.2105163928354159, 0.1656575288507156, 0.1394393661757931, 0.0863643188495189, 0.06454055357608013, 0.1404524125973694, 0.10165685060201213, 0.25000090536195785, 0.1744205117574893, 0.1224292375263758, 0.19221642636694014, 0.17005530302412808, 0.10451883179484867, 0.14496533840429038, 0.088890121987788, 0.11601959748077206, 0.12979630002519116, 0.07957843219628558, 0.17476811888627708, 0.14585164084564894, 0.22515305900014937, 0.10665523004718125, 0.14184955012751743, 0.07731442907243036], [0.014141586871119216, 0.037842191668460146, 0.1213781486148946, 0.08642916771350428, 0.01908504553284729, 0.031298189496737905, 0.0492137828405248, 0.09548492045723833, 0.048922912901616655, 0.057768077531363815, 0.07067961400025524, 0.03408971489989199, 0.03775299664994236, 0.019946018474001903, 0.03192383112036623, 0.058952637991751544, 0.00900524031749228, 0.04050407871545758, 0.05100776157632936, 0.0660759383754339, 0.03837788499367889, 0.027207575403735973, 0.041440928835072555, 0.039899907424114645, 0.03837038930214476, 0.0494950568099739, 0.07515174394939095, 0.05326563084963709, 0.04790955106727779, 0.05420536421297584, 0.05635124340187758, 0.07530898277764209, 0.05113233477459289, 0.007488591500077746, 0.04277839027054142, 0.0584194679686334, 0.03653490224678535, 0.005334269917511847, 0.02126536037394544, 0.004450156811799388, 0.05316318478435278, 0.03587955987313762, 0.0389856260153465, 0.06896926046465524, 0.03764147040783428, 0.013675721293111565, 0.04871591678238474, 0.01057749223036808, 0.035585346558946185, 0.020971898484276608, 0.013771709745924454, 0.06967703928239644, 0.08621331406175159, 0.035442598164081573, 0.038073667528806254, 0.04143103229580447, 0.01783728748705471, 0.028293265095271636, 0.029145881453587208, 0.02208776761108311, 0.02273265869007446, 0.025862195252557285, 0.06020231077854987, 0.06248524980037473, 0.03334518492920324, 0.045254732976900414, 0.042836069987970404, 0.047820630643400364, 0.010915155507973395, 0.04797250003321096, 0.049930163149838336, 0.028210049931658432, 0.060248561421758495, 0.06936305886483751, 0.02336811707209563, 0.06914765792316757, 0.0476909737335518, 0.053973034882801585, 0.008916330098145409, 0.1183003508776892, 0.06373913056449965, 0.04869968230195809, 0.00632163617410697, 0.014172493611113168, 0.011877251636178698, 0.09227836009813473, 0.09288403423852287, 0.0459680036874488, 0.02766749916190747, 0.014298856312962016, 0.05618470546323806, 0.014392018110811478, 0.05013063579099253, 0.039518729245173745, 0.01402764864906203, 0.023949728929437697, 0.05112177401315421, 0.035627853067126125, 0.032473239334649406, 0.056533459210186265, 0.030380221469386015, 0.06347467366140336, 0.0342634702246869, 0.03687157011881936, 0.03780352206376847, 0.08873025595676154, 0.03150831747916527, 0.06129236615379341, 0.03469391216640361, 0.022704720540787093, 0.015914729810901918, 0.031506692175753415, 0.0029476282816176536, 0.013469785517372657, 0.034025793720502406, 0.044656205718638375, 0.07882173100369982, 0.06836639906396158, 0.01416252285707742, 0.04912188269372564, 0.04179054718406405, 0.010947773826046614, 0.017365467101626564, 0.02554092694481369, 0.07038470677798614, 0.018010243147728033, 0.08813813343294896, 0.03704050148371607, 0.012365618204057682, 0.025038428029802162, 0.02381258746027015, 0.029232885281089693, 0.005460762959046406, 0.018455481658747885, 0.037600077121169306, 0.07201810702099465, 0.024216800047724973, 0.09067749560927041, 0.055788361496524885, 0.011852266306959791, 0.022379973415809218, 0.030084950594755355, 0.011147841069032438, 0.02513842500775354, 0.032690944644855335, 0.017105106853705365, 0.025284663352067582, 0.02576770872110501, 0.039781661034794524, 0.006483694323833333, 0.07189600888523273, 0.02171837659261655, 0.015392985151265748, 0.025942927932192106, 0.0886001500475686, 0.02560829911089968, 0.037179947321419604, 0.04561700865451712, 0.03412344551179558, 0.04116822667128872, 0.03833479589957278, 0.06460907607106492, 0.06304360460489988, 0.03241734448238276, 0.04552455560769886, 0.026287943110219203, 0.02278603395097889, 0.036101892474107444, 0.13234266807558015, 0.03469973802566528, 0.035136083752149716, 0.03900751566106919, 0.050775350609910674, 0.03784063315833919, 0.028113492808188312, 0.0514802016550675, 0.008129147972795181, 0.04193555912934244, 0.025665123503131326, 0.054752100695623085, 0.04466691490961239, 0.03161305307003204, 0.07961378069012426, 0.03712717320013326, 0.05787679103377741, 0.048119931379915215, 0.02677436339581618, 0.05071353341918439, 0.031077352323336527, 0.03101165926636895, 0.03929871956643183, 0.008792748594714794, 0.018363472045166418, 0.04302549576095771, 0.026557255514489952, 0.06409916866687126, 0.09322619400336407, 0.05447034433018416, 0.024298885291500483, 0.03558612952474505, 0.038883246743353084, 0.05167574272491038, 0.026153913095186, 0.014158634003251791, 0.037022407923359424, 0.03977621738158632, 0.034824964313884266, 0.047303580067818984, 0.06011776902596466, 0.004738506231660722, 0.06360352534102276, 0.059034964433521964, 0.03304006575490348, 0.015891702823864762, 0.059847081793122925, 0.03280788485426456, 0.0435259222285822, 0.051271001357235946, 0.06174249356263317, 0.01830710407375591, 0.03558932075975463, 0.03270216220698785, 0.037174956378294155, 0.05069014092441648, 0.02715955659368774, 0.040216915804194286, 0.035067089993390255, 0.05548045184696093, 0.006287430123848026, 0.04973030278051738, 0.054334557280526496, 0.11622374004218727, 0.01038111995512736, 0.03854620779748075, 0.007608237765452941, 0.03340908755490091, 0.05119188470416702, 0.015130406809475971, 0.046425318796536885, 0.024062730190053117, 0.039008380263112485, 0.04126235326111782, 0.03738754086953122, 0.05246457891189493, 0.032598450779914856, 0.028433981860871427, 0.016774708274169825, 0.08238766895374283, 0.057680322279338725, 0.017278060659009498, 0.025065355002880096, 0.026978466994478367, 0.034437540962244384, 0.03889850158884656, 0.01505403888586443, 0.06360208557453007, 0.041038176423171535, 0.014809392687311629, 0.021330327981559094, 0.04189298953860998, 0.027918007399421185, 0.05825508225825615, 0.00773401370679494, 0.043311463814461604, 0.038271991652436554, 0.02526621727156453, 0.01668398814217653, 0.05553110342589207, 0.06040485401172191, 0.04522861308942083, 0.03087090910412371, 0.04031824864796363, 0.041732782119652256, 0.04186167832813226, 0.014727594098076224, 0.005505569197339355, 0.0369068184227217, 0.07818220750777982, 0.03438504885707516, 0.033093066231231205, 0.043129448386025615, 0.04559210588922724, 0.057514177678967826, 0.040876573766581714, 0.008302778987854254, 0.009380467399751069, 0.03843954633339308, 0.027254488413746003, 0.04720198005088605, 0.019012745506188367, 0.05497922385984566, 0.006776686805096688, 0.04753104461997282, 0.033333989631501026, 0.06102628765802365, 0.017591250689292792, 0.04785068020282779, 0.015700260264566168, 0.04439301788806915, 0.06174344722239766, 0.020795720047317445, 0.054348257326637395, 0.06737554285791703, 0.06029883450537454, 0.022494648219435476, 0.06585775437997654, 0.09089901926927269, 0.08112364303087816, 0.028304041079536546, 0.09215014666551724, 0.04793310312379617, 0.038453895758721046, 0.015320366001105867, 0.013423113705357537, 0.06056798549252562, 0.01222271303049638, 0.03192088479408994, 0.042991646405425854, 0.04038379142002668, 0.04430465036421083, 0.01266874656721484, 0.01722819946735399, 0.017222008100361563, 0.025629704505263362, 0.027820270261145197, 0.044769620726583526, 0.052543613928719424, 0.05595429087406956, 0.022099914713180624, 0.06142243495560251, 0.03436275845160708, 0.022759492894692812, 0.02264825423480943, 0.016777335476945154, 0.03185756104358006, 0.03196233003109228, 0.006573747914444539, 0.0029997952333360445, 0.030012320312380325, 0.008188991978386184, 0.004857914082094794, 0.022128134878585115, 0.04499135218793526, 0.07436287065502256, 0.016730617280700244, 0.033246612874791026, 0.049430096623837017, 0.053075930482009426, 0.0593583701265743, 0.02100794645230053, 0.01607301877811551, 0.05703018978238106, 0.11127782301628031, 0.17724037606967613, 0.15678865631343797, 0.17076020973036066, 0.11042082798667252, 0.09670142666436732, 0.12558395887026563, 0.2503579971380532, 0.10752581380074844, 0.23313021141802892, 0.16303780692396685, 0.20458927494473755, 0.09356173381092958, 0.18489911744836718, 0.14464961393969133, 0.11276425575488247, 0.09984218821045943, 0.14783093385631219, 0.10860761278308928, 0.18653194623766467, 0.11451487080194056, 0.17141528864158317, 0.1290075306314975, 0.11912247238797136, 0.10999444188200869, 0.11169752979185432, 0.1582366754882969, 0.12537019065348431, 0.1803226489573717, 0.08190067164832726, 0.16481373662827536, 0.1588401009212248, 0.22708059463184327, 0.06357416597893462, 0.24658042093506083, 0.10937218074104749, 0.10044214039226063, 0.11304244981147349, 0.16305731056490913, 0.1334980732644908, 0.17313030286459252, 0.13498216081643477, 0.2323310519568622, 0.16405003698309883, 0.12468082451960072, 0.1604280446190387, 0.15963176469085738, 0.11981799092609435, 0.13033775612711906, 0.11747302691219375, 0.13877944846171886, 0.14353142003528774, 0.21370739035774022, 0.09073593973880634, 0.1446150743868202, 0.20590330677805468, 0.16593737789662555, 0.204835771874059, 0.07715399158769287, 0.1934149651788175, 0.16113799792947248, 0.17546149261761457, 0.20981207984732464, 0.11045236184145324, 0.1207435158721637, 0.09298912234953605, 0.1018315002147574, 0.12432692397851497, 0.09958467038813978, 0.09959301954950206, 0.11121693722088821, 0.14765884465305135, 0.1842177368234843, 0.145031641877722, 0.16754521115217358, 0.14310995436972007, 0.07983476258232258, 0.127984702703543, 0.07067464161082171, 0.24547281005652621, 0.2932623855303973, 0.14312558399979025, 0.07924929712316953, 0.15451047074748203, 0.10621716995956376, 0.23150781722506508, 0.10614614642690867, 0.13691753352759406, 0.11611846639425494, 0.07611312947119586, 0.10487839492270723, 0.11359437019564211, 0.15866970381466672, 0.08053106037550606, 0.09159678651485592, 0.09400398703292012, 0.10852413601242006, 0.20614021515939385, 0.1255670824320987, 0.10131178903975524, 0.15081378864124417, 0.21351848408812657, 0.14268317492678761, 0.11522308006533422, 0.16990721487673, 0.17955017712665722, 0.12249096937011927, 0.16823652171297, 0.15482013928703964, 0.084853217122145, 0.0764984599663876, 0.11907683772733435, 0.09640323914936744, 0.14082547539146617, 0.16498915065312758, 0.13489863951690495, 0.2109129074960947, 0.22783682827139273, 0.14724141627084464, 0.10663655019016005, 0.13187599077355117, 0.07059580326313153, 0.08699410536792129, 0.25381180399563164, 0.10623962734825909, 0.15828599862288684, 0.19099510362138972, 0.12056920022587292, 0.086594555323245, 0.17500891612144187, 0.1216482458403334, 0.13158953661331907, 0.08507529739290476, 0.14452751580392942, 0.23799193179002032, 0.18960489775054157, 0.09737812433741055, 0.08957578480476514, 0.09583097649738193, 0.1212713164568413, 0.14528685162076727, 0.09345289043267258, 0.12404403954860754, 0.29480664641596377, 0.07921022304799408, 0.0951823839568533, 0.08815205612336285, 0.08191570013877936, 0.1418517468846403, 0.13375686015933752, 0.1710229745367542, 0.1820335813681595, 0.10027295298641548, 0.10149754860321991, 0.2020651416387409, 0.11036705938749947, 0.15652324946131557, 0.10851447324967012, 0.24183107656426728, 0.12200846205814742, 0.09474545935518108, 0.08736609946936369, 0.27290197962429374, 0.12241225718753412, 0.14000725757796317, 0.05875295573787298, 0.1318633891060017, 0.16487300454173237, 0.19232571503380314, 0.12500398530391976, 0.13931942026829347, 0.1252170855877921, 0.1236662121664267, 0.07840112622943707, 0.1754855233593844, 0.2088476440985687], [0.021447129038278945, 0.023911755088192876, 0.04621972533641383, 0.03775209865125362, 0.012076457060175017, 0.01836662988353055, 0.031159233476500958, 0.026712102771853097, 0.020586978025676217, 0.06080129816837143, 0.034075287549057975, 0.13969944440759718, 0.02265026545501314, 0.07186923219705932, 0.003102135542576434, 0.07896233088104054, 0.02021398388023954, 0.07540684979176149, 0.046793631845503114, 0.06580750356079079, 0.07106397970346734, 0.03536812735546846, 0.06497574155218899, 0.01987007821298903, 0.055723349360050634, 0.04293964411772322, 0.005691537489838083, 0.06331603217404336, 0.03018098635948263, 0.06262056558625773, 0.03931676117645111, 0.009617178184271324, 0.016400838394474704, 0.039642415576963685, 0.04257942418917082, 0.02850853059499059, 0.038081126112956554, 0.013459905676427297, 0.005910389418204431, 0.04345787841884885, 0.022920349692867603, 0.0648786018427927, 0.0851751459413208, 0.06037997722160071, 0.046905577401048504, 0.06091770774219185, 0.030534513971360866, 0.07954348446219228, 0.08056116930674762, 0.04765935824252665, 0.032354670111089945, 0.04694728610047605, 0.03490517192403786, 0.057680953104863875, 0.03140658758638892, 0.033546299528097734, 0.03451445714745205, 0.08797884627711028, 0.01749110899254447, 0.011395133024052484, 0.022164741312735714, 0.023638184611627366, 0.008891140678315423, 0.04596779588609934, 0.04332556090957951, 0.05903119803406298, 0.032272020835080184, 0.04272285907063633, 0.031802159719518386, 0.04532098078925628, 0.027231197964283638, 0.053172888365224935, 0.05923483593505807, 0.04166640072071459, 0.06757114329957403, 0.01680985082202824, 0.025279344008595217, 0.05296156552503817, 0.015097656760190148, 0.005493194812515867, 0.011929386582778534, 0.032540945467189886, 0.020374295199871995, 0.0517603698244784, 0.008566362939745886, 0.08834575666696765, 0.09302548016421497, 0.01825422605179483, 0.07935106041259132, 0.07725907969870605, 0.030221090164559428, 0.08632302575279027, 0.008468683317914838, 0.07021945275482722, 0.040023341425694525, 0.029409683411358856, 0.03393387502001133, 0.0976589233323466, 0.012783494657924166, 0.027245387827861123, 0.007258809127961285, 0.07519966442487203, 0.013487779815477552, 0.09152867220109329, 0.02317868758836994, 0.018395076403976418, 0.032398805633420125, 0.0181688920565648, 0.032301491519319825, 0.020424742688192055, 0.023561596826766618, 0.056055723907775246, 0.031763152437633835, 0.07484485846362077, 0.024815631586534437, 0.01279730417081737, 0.008349018498847727, 0.04805101183592342, 0.09095462839468382, 0.004718860654975288, 0.01287934488573228, 0.028348347295832355, 0.01725304471619893, 0.056318369970540516, 0.0200133887847187, 0.033816177819971927, 0.05787249028799124, 0.06642911903327331, 0.06450681554269977, 0.027032024081563577, 0.06600947162951343, 0.0802863817079924, 0.03649531237897463, 0.05730536700866651, 0.03295466311101336, 0.026131047525268514, 0.04906551657768432, 0.010284604577464052, 0.07262797429575585, 0.08219079943955876, 0.05626839374599513, 0.08433569528278895, 0.07776922459015623, 0.0669551978353411, 0.038978427182883024, 0.03632369443948846, 0.04262418682628777, 0.02314501820364967, 0.05271194786473643, 0.03258482123783324, 0.015923589198791888, 0.04197936810669489, 0.04531498794676736, 0.12131522191339172, 0.07650561426999047, 0.03823643164651003, 0.024768254734226502, 0.030685260862810537, 0.027284417374175973, 0.04114518298592884, 0.055210258142324165, 0.0530724386771908, 0.0822129005973693, 0.014693813391204458, 0.04295875070965849, 0.04796726047061384, 0.028885621395602357, 0.039170576637843624, 0.037926789082121104, 0.03806303255259991, 0.05026786260714289, 0.038498120338772424, 0.0372518762742402, 0.05448264542792458, 0.01735118818032788, 0.036089027344132774, 0.019092129332420882, 0.030446886739809997, 0.025015477112901863, 0.04860730346990749, 0.07541986706200987, 0.06501556519651785, 0.007060217831167392, 0.048860461174626835, 0.04313360441301484, 0.03167658833262976, 0.04217009634885471, 0.045041217090329155, 0.03606835853133816, 0.06997322299866937, 0.034911743641714565, 0.03530464775394648, 0.011546986643224955, 0.12603099894477054, 0.040174854584620334, 0.06759138908819295, 0.015615826123394072, 0.05640843330183998, 0.03239075333112851, 0.0556253784452565, 0.032304738415405154, 0.008980328275356442, 0.02161317715945188, 0.04326121670601424, 0.0275771946326131, 0.051254406935186125, 0.023084304957592394, 0.049508441443322226, 0.007621959148309543, 0.024267614899144974, 0.05627050886687357, 0.03278986179793719, 0.04324713445384987, 0.07677387839066796, 0.04233436702634208, 0.033951760779018514, 0.04173773595539387, 0.03554399037966505, 0.04875469399848953, 0.03467466085567139, 0.10829474558704533, 0.046433753304881975, 0.038711343077011406, 0.04072913128766231, 0.029757819320366252, 0.043203652021475136, 0.023338753999269102, 0.03816408338025212, 0.015838689359952696, 0.026528282069193665, 0.05245151340204757, 0.025030982433236204, 0.03352632833411917, 0.05306899511197116, 0.0412458256323589, 0.02179297913244227, 0.028730763006024063, 0.019137300150759984, 0.035347811062820256, 0.024342152501048986, 0.03552204136212822, 0.041565108695067465, 0.036283084118622355, 0.020163167173450347, 0.012079569441993954, 0.050106282214983366, 0.010298626530129695, 0.050147330402978696, 0.026842271763598546, 0.03734036254172679, 0.053087693522684276, 0.04222653296892531, 0.04969187066308223, 0.029478033357008826, 0.034683477570069954, 0.055333554846583866, 0.06160773067676928, 0.0522469403949799, 0.04189213606878184, 0.03338265225465875, 0.04896907448710408, 0.04874925776675809, 0.06704783270834014, 0.03088810837653, 0.07534903648775071, 0.08687606677995063, 0.028411617240635678, 0.030351895547937602, 0.03960616908443626, 0.030100648873485625, 0.031017592737043742, 0.008129571924655465, 0.028668244485743344, 0.06691265050903894, 0.020956046209903434, 0.020199953578412533, 0.03259225755755324, 0.05335523033863865, 0.027767160318035167, 0.026988595454895403, 0.04909428593236953, 0.028894067036162596, 0.07167684525484219, 0.04874833008216228, 0.0495819029310951, 0.01566289869515458, 0.015403124743897934, 0.04500861825363245, 0.033530087312101386, 0.035343324780114926, 0.007639059158464079, 0.03053464570257347, 0.03592399225453846, 0.052246313280193135, 0.06847225900855847, 0.038822910137241706, 0.05450583754281979, 0.02762845477263909, 0.04173296023509465, 0.0834884075447917, 0.04391877067973837, 0.04416905627294909, 0.07003435370279476, 0.0673528628249187, 0.03917033172911033, 0.0407266116963001, 0.0705114210722968, 0.037464683409780264, 0.04804455515113659, 0.05577945943514351, 0.08339013977092691, 0.04237045766785741, 0.027560926755541004, 0.04313678451580927, 0.03206965571735054, 0.06755457856343128, 0.06641831336310133, 0.05264977444312535, 0.015463331474165898, 0.041799567989073694, 0.016194610398088116, 0.05871705063327681, 0.04693684408266563, 0.027502861121320166, 0.1309994253097102, 0.00803425975391292, 0.006032324281477486, 0.04682532526203431, 0.05274943745462224, 0.024226444256782997, 0.13682933669770136, 0.06267721371841617, 0.05188056435144972, 0.009089730119740125, 0.03767431415326428, 0.013332085582078435, 0.022710589073540177, 0.03824544131930452, 0.04541432441328652, 0.05293611357046757, 0.03693978091177996, 0.030442515489994548, 0.04133483140321914, 0.026992191160388757, 0.03714920014317613, 0.045200556196505204, 0.019612100259109866, 0.04382492981676478, 0.03773594209633302, 0.03955574757128488, 0.03572978705051355, 0.031698155144113116, 0.19446204649284482, 0.11150082355015911, 0.10859461035579443, 0.20384389150422066, 0.11765151342842728, 0.20497076853644103, 0.15026784996734932, 0.12502929253969342, 0.1009228294424247, 0.10665091074770316, 0.15447753423359245, 0.208640466153156, 0.11097148671979085, 0.17932092770934105, 0.11224780260818079, 0.19496547494782135, 0.11294121344690211, 0.3205337596591562, 0.16009189625037834, 0.20557100273435935, 0.1477540473570116, 0.08831413375446573, 0.13468032935634255, 0.09898091098875739, 0.10069867115817033, 0.0719432688492816, 0.11785407521529123, 0.2741354290628806, 0.11384825891582295, 0.19987123436294496, 0.17036920180544257, 0.10638618667144328, 0.12079976324457675, 0.12488107080571353, 0.13356002775253728, 0.0853142021514941, 0.10530936750001274, 0.1423727790825069, 0.0769696495262906, 0.1719939411850646, 0.19260514847701415, 0.10633652957039885, 0.20726088783703744, 0.19296537211630493, 0.17865017463918775, 0.19246512005338445, 0.15748256439110264, 0.119692315638531, 0.1377188303740695, 0.12966514768777415, 0.06527056713821366, 0.1138810247357469, 0.1832099596504122, 0.07184042944572866, 0.09483126646955498, 0.10964008120936342, 0.11013959854608402, 0.1808720757253468, 0.10503211597097106, 0.10988709022058174, 0.08514976449077949, 0.21897944418014959, 0.07341985328821465, 0.13241720938822255, 0.1323630622937344, 0.16301742754876614, 0.09675384455476888, 0.09870752604911104, 0.09821814644965343, 0.15264135698089376, 0.14360205765115097, 0.12225942671648227, 0.09600764475180767, 0.1488130327197723, 0.11381728909327649, 0.09033788883243687, 0.10495459122466855, 0.11915834038518369, 0.1504260758520104, 0.14014213549671695, 0.13744466617936268, 0.09820262072025798, 0.09189374948618934, 0.2550854184664786, 0.12183062863186933, 0.16040364280343056, 0.21957714023301378, 0.13296286604600027, 0.189879329118412, 0.12802555051166564, 0.16320878290571272, 0.14179578894982114, 0.10682396474294364, 0.17723722936352715, 0.12068524985807016, 0.11681017029331997, 0.21326254704035819, 0.19587080605560914, 0.11188920427230187, 0.10144926447537728, 0.12025211763102561, 0.16749106405768543, 0.15935400850139558, 0.23724571714410558, 0.14106680697295815, 0.1679388908087276, 0.10761278608697467, 0.10402111045550555, 0.0781556534639094, 0.15771697915624827, 0.09700424518086948, 0.22006265324307606, 0.11735042411601171, 0.2686263481155038, 0.10769066706416197, 0.12467430846299976, 0.16697948682121933, 0.16391750425100327, 0.17629345500608906, 0.13116584450472146, 0.14733930554939434, 0.0674706490826793, 0.1345501863397658, 0.1452083620824851, 0.18813209084328264, 0.12131733703427017, 0.12043487891787663, 0.14535938913468271, 0.12283625357667916, 0.1959564647404477, 0.1333810662617907, 0.16391312557971105, 0.13436315028229728, 0.1368171803187579, 0.14957891427911818, 0.14990299532655627, 0.12379063322441652, 0.0883798954600934, 0.08634125289972872, 0.11189195021870546, 0.16518668067874387, 0.12834752385970205, 0.2739498030859977, 0.12588028359459713, 0.10518621551454999, 0.16791015485068783, 0.18502359045669436, 0.08777471113717183, 0.15745359094580635, 0.08741110330447555, 0.09751672041602433, 0.09894855335005559, 0.10384648310719058, 0.2167648755130358, 0.20137773477472365, 0.14515385875711218, 0.12129142865887843, 0.12633918318897486, 0.16264215315459296, 0.13351855654036626, 0.10363411754951812, 0.15340707526775077, 0.1974240320851095, 0.09238391576218419, 0.13028479646891356, 0.1359173856326379, 0.11296117721940391, 0.08939223684137687, 0.0950512316194363, 0.09990180493332446, 0.14449693931965157, 0.1279808286926709, 0.08578986686188728, 0.10917157080257311, 0.1244992580905091, 0.11927956278668717], [0.007306328379854676, 0.031090486481843982, 0.03085472657403443, 0.09354971844004467, 0.026968915553879924, 0.04794526692421641, 0.02389629058598075, 0.03185377980116755, 0.029624143680848647, 0.02566691950050881, 0.015079294171300717, 0.03019317056896398, 0.022459887877630536, 0.06638297229073942, 0.03671936305181589, 0.01905431319755735, 0.04500745308178011, 0.048808681531227194, 0.016321461989718955, 0.04078931575349998, 0.02053113883448532, 0.04528355428192299, 0.030732782433915418, 0.1393135721446015, 0.03758029517484829, 0.03374092033482157, 0.016512761685589794, 0.05219363563810475, 0.04035855097754393, 0.06875453487737104, 0.051072354399366304, 0.025243741329177283, 0.008903127290977864, 0.047369946623803116, 0.07043267178232782, 0.07296669791685417, 0.0804948880977463, 0.08046015558647923, 0.05035031521401834, 0.02482001953467261, 0.04346172645455226, 0.03346476347360294, 0.047081236334634013, 0.055952454058569856, 0.056113470418495126, 0.02027994782110909, 0.03529130022798199, 0.06326414120849222, 0.050897233522846363, 0.07640120893483981, 0.016542263911105692, 0.056793867697706446, 0.04442300436494406, 0.04388339621073101, 0.04176935886789579, 0.027812140033347532, 0.08899780761566944, 0.02110040692059556, 0.027622933193924837, 0.035403156725806184, 0.04232114566548262, 0.060333563305903226, 0.016048921243054792, 0.05382523246225901, 0.0467283896432491, 0.009503088749625022, 0.03317647991934791, 0.027202341407246422, 0.07088757862220518, 0.05732834018999711, 0.04852150748774875, 0.06164435937535018, 0.03514888208883349, 0.029051021992927417, 0.026220548679702915, 0.08985789740108885, 0.022487761088996194, 0.018960054876515642, 0.0467494369513588, 0.08184881779015996, 0.03159073668939527, 0.030835690486128442, 0.02612204712931998, 0.012607951684913132, 0.03912681590009015, 0.016999413892335724, 0.04050119547173381, 0.020520093821687624, 0.04489443512284197, 0.01833033329603495, 0.023768745086272247, 0.03519348887493834, 0.01327404777839547, 0.08359305036719888, 0.014316220713226357, 0.037615372784784995, 0.08925774483941495, 0.03222117629775312, 0.043260812235530466, 0.018500867699913215, 0.017710647407511715, 0.006494803810710437, 0.019892003110726364, 0.01705860202491749, 0.04621051899448503, 0.025844819720077794, 0.026917301038338337, 0.032534804195165634, 0.03749988347408362, 0.0422082761360798, 0.063874720945023, 0.04171550492173992, 0.06888343850732781, 0.04541611298918724, 0.031018357149150688, 0.028960639538126998, 0.007405300730169984, 0.006055028898117598, 0.018679682616493665, 0.034906407599919476, 0.03010118136444362, 0.04571794816001784, 0.0873197078180965, 0.020742693595821038, 0.006132216431069537, 0.011215535141673172, 0.025341747495986056, 0.02730994539888343, 0.035946627758676186, 0.03994306331151165, 0.028894740535179153, 0.047322746031568386, 0.012817754977731965, 0.044070610383641906, 0.06925956637132913, 0.01867548948212061, 0.013605527110485127, 0.025686317385407165, 0.015654896487831138, 0.06507426165626384, 0.0120420677922084, 0.02875446905818535, 0.02975457056891173, 0.03309516279841773, 0.04828451375942677, 0.09968863043468446, 0.03407424483157229, 0.05582158744800836, 0.018805730833264533, 0.029836811663699336, 0.07340043128351681, 0.027413955540396273, 0.0425752013688907, 0.033455022785346955, 0.012578538517118432, 0.04962247243383899, 0.02027061716944445, 0.018373324055573903, 0.04903707747871522, 0.06140376252005808, 0.00971729947195854, 0.08135063631925732, 0.03276623181591276, 0.029427481968014035, 0.005905757025175262, 0.03737794861081056, 0.006385061042237794, 0.005277462687445222, 0.03959935616876464, 0.05282989739498589, 0.04784391181601677, 0.05154713595402427, 0.053036143945064396, 0.048340735156671144, 0.018593394961499143, 0.03428576805163175, 0.021341738502087537, 0.023746723709336948, 0.0053825990380573785, 0.05162778885278385, 0.07067069338518195, 0.048157343044294976, 0.016002243864932097, 0.05732390585762914, 0.033671893179416656, 0.01379636110868887, 0.042147112035308965, 0.020205013170198072, 0.02427543528028764, 0.029288420191733167, 0.12183486629510298, 0.04005046321253758, 0.012911682115372969, 0.026088763661391567, 0.07767180286464281, 0.0755029208085034, 0.054454569981317036, 0.03451902506640181, 0.006798639997214195, 0.06804170945542865, 0.05679409034200944, 0.11201901332242414, 0.07754285470582545, 0.047113623659242876, 0.037142973524169065, 0.10340866050682962, 0.05206925910897553, 0.027406565604906064, 0.03673484425235074, 0.023243770228873473, 0.07311765817576088, 0.05733721256547142, 0.025663342348707374, 0.038430748172686435, 0.040815765896695666, 0.052508499211398885, 0.030536048361682333, 0.05793361728137825, 0.013014543783356203, 0.044051158693036996, 0.0390357543801656, 0.04452296794624999, 0.036424578283913434, 0.03187263777363114, 0.04872131219599396, 0.04639346952899359, 0.024675579043105245, 0.03818649252934847, 0.01598698345333105, 0.03497641810099594, 0.029149792571843136, 0.018341801333008334, 0.1241582263901364, 0.06328453542664647, 0.034939366378239356, 0.04310206313675735, 0.04635652541765012, 0.02521821515983902, 0.06153373484266922, 0.08137894183164462, 0.04564265727822203, 0.038385877924156375, 0.05498914637428243, 0.020336814886832144, 0.014419203907891642, 0.05173990881303325, 0.03219615107809659, 0.02333052358153509, 0.05322447876096703, 0.020344538788776845, 0.06015134749759454, 0.05822260216518771, 0.05393749714130536, 0.031610882288077846, 0.06339707470033318, 0.06034848418494221, 0.07663333788514137, 0.02494801959983306, 0.0026558357603789773, 0.012485873958212323, 0.023484051671402995, 0.03833455470157787, 0.047662174692959525, 0.033181177714141086, 0.011445906129665673, 0.06801562296459451, 0.016141580235853326, 0.04017443527118303, 0.03724622481968254, 0.030050108616705984, 0.019198352929379325, 0.00230193243623944, 0.015524734917562455, 0.008905402901291382, 0.04964014297001995, 0.005278046201055986, 0.021529401674342807, 0.07292386115295812, 0.04436305367562454, 0.04133518763410393, 0.012097763192286948, 0.03163938075886108, 0.007047400013107108, 0.043117618552059866, 0.012725704546028282, 0.06363672160659917, 0.020437722851056606, 0.057462075201328844, 0.01686920593783725, 0.038460307914647274, 0.07963075360748917, 0.05591485314653255, 0.02766544155747397, 0.06105818887590431, 0.028167573109385557, 0.04204153781756759, 0.009019805893331068, 0.03857944859191775, 0.03802140548941679, 0.018108227050106507, 0.09355292451800779, 0.018852475004678126, 0.05659266033035237, 0.018026195612037554, 0.06966149871004745, 0.027468820662761573, 0.09864910418400541, 0.056515417600166984, 0.05138090971740894, 0.029578134235634934, 0.032509994198335335, 0.05357612688385416, 0.034026929206447676, 0.02006062462896807, 0.02930635975644691, 0.03246162843424827, 0.011064670434279833, 0.06030402582837269, 0.10293024985003285, 0.052551076223608106, 0.01758910402713809, 0.04561606612696778, 0.012698269201791845, 0.07724591399892233, 0.03927646255760919, 0.06377084253472276, 0.10415971395559609, 0.03687601929414086, 0.04510097482125275, 0.057085053049377166, 0.052829511478194036, 0.018881092219089624, 0.0345992104121251, 0.058160228363703936, 0.044592136109713465, 0.05532402195967734, 0.036085735919186845, 0.010754352515505161, 0.07878765158238821, 0.04284822636691388, 0.01636061213503126, 0.05378474459575955, 0.0159373968563159, 0.022049632352718618, 0.11418303431128152, 0.018606126504892018, 0.03453760844422504, 0.0753977510612458, 0.01949168865394313, 0.0346674879983766, 0.033582405012566596, 0.024198075661843177, 0.0756999610166531, 0.15291630785213783, 0.16498741402756423, 0.13447647623252124, 0.1064761720772367, 0.1150127850996796, 0.09728510354761966, 0.09388852369738743, 0.12523175042588264, 0.08487763378070667, 0.1340342007461004, 0.11670573527226225, 0.11414499924285337, 0.18350848113186657, 0.22760835068766028, 0.09670915242168121, 0.08241188523243181, 0.1778082229429856, 0.08605134033132344, 0.17379128927132115, 0.16059338027844205, 0.14896011154633015, 0.09402323834365234, 0.2445850381627679, 0.1449643142404966, 0.13940899749286473, 0.20212516654282808, 0.1524098514346406, 0.08749773420277052, 0.3233261645073071, 0.23153195186750963, 0.18614451546454802, 0.08754946189583279, 0.15382453333586454, 0.1347910874756053, 0.2616920764558017, 0.1871306516113691, 0.1584146573441103, 0.1267093961359933, 0.05741943881730549, 0.2124386592186056, 0.14059986249776557, 0.07817693083779886, 0.19168286671629176, 0.16131059179315343, 0.13973840716062114, 0.09739924586028792, 0.23089783120667562, 0.1443883779575117, 0.18307941587409005, 0.1149372715735808, 0.11709364844136871, 0.11282784296781756, 0.2198301235330291, 0.11398928923881613, 0.18856020615203306, 0.26338639960158616, 0.19473729422315955, 0.19898945902241394, 0.14559402654413134, 0.10884122602874413, 0.15083934820722789, 0.1355390387470834, 0.1453721392317675, 0.13760330766672269, 0.10543859767494723, 0.10338740539737046, 0.09909093438182026, 0.1647342971409671, 0.10174121052841656, 0.1865927578182891, 0.12766587606165558, 0.19767250312725082, 0.13032616378040984, 0.2381051835254766, 0.1801693657762371, 0.19823408627416939, 0.09033313166582957, 0.22794489981606603, 0.10666349015082233, 0.15103518613614142, 0.1260737466509454, 0.09005305997561663, 0.17579430132173002, 0.10741052858065814, 0.059595178317977116, 0.2268981302040629, 0.1138922460086178, 0.10787526887725107, 0.12287975827348419, 0.05694804516679142, 0.19292050186777487, 0.12138648293330334, 0.15006469446234405, 0.13732549210544676, 0.1451223620097153, 0.20656205189879984, 0.06685380561975762, 0.0885505968471989, 0.19043077452806756, 0.06901894725160673, 0.16753326257457957, 0.1124519896984566, 0.08409736939938739, 0.14612041704822332, 0.0911514979088679, 0.1130779244704172, 0.11497437153593637, 0.11108882768894546, 0.27621857821941376, 0.13872550916858017, 0.1586073188809678, 0.12965266476385295, 0.16780077712610364, 0.17934921837877482, 0.12419258040608838, 0.12071314718923531, 0.12407099435222335, 0.11152829785714857, 0.14459831669228151, 0.1579844788648188, 0.1776021285331808, 0.1800693094264716, 0.06728797685354948, 0.13353880232898518, 0.1025676958670374, 0.13943374069640413, 0.08224834557040595, 0.13142301351763308, 0.1529784404556267, 0.27953407843597233, 0.08676455909153447, 0.10912836296483874, 0.14611445018090308, 0.14217489282600582, 0.1275225228164345, 0.14768476044991985, 0.1746903418097645, 0.14366527379024774, 0.1509864121908322, 0.17946261854376644, 0.26337877032347023, 0.1336841148440726, 0.11138336383737624, 0.14418226870475337, 0.3239485592348501, 0.11927024141186848, 0.1516084061586298, 0.12964702444151044, 0.1936505822231993, 0.21296930965036154, 0.13849682378349826, 0.24893979745684192, 0.15319899190217257, 0.1065082625427749, 0.1675856878864579, 0.09005859639728442, 0.14971058611990884, 0.14817857067100704, 0.16559281357331201, 0.095217287162086, 0.1400773014756851, 0.15657686220947653, 0.1394494593841955, 0.10344458045437932, 0.1041555282426998, 0.10690270661143586, 0.10313206948922016, 0.16187011176953092, 0.13283600332215428, 0.11420635259128176, 0.18792084592860192, 0.12517056777141988, 0.2279334410559386, 0.12800082215107977, 0.19183944503311068], [0.03571019435185008, 0.0331409607315436, 0.04815344676899258, 0.022001038378220983, 0.03820312405878212, 0.02665610401891172, 0.056171513788285665, 0.044025773531757295, 0.008873386650520843, 0.06510231483844109, 0.013832277345500188, 0.007342329963648808, 0.03463423978246283, 0.00667162606077909, 0.046682881147717126, 0.023072816511557903, 0.027939936007896904, 0.019971025139966514, 0.03911986197635997, 0.009601661731721833, 0.055172846477944404, 0.017346841050311923, 0.03531718633894343, 0.017990346168517135, 0.07808065944118425, 0.04728653664642479, 0.04782603347848635, 0.032285012130159885, 0.013354978982533794, 0.004052621234222897, 0.07389853111817501, 0.034598123165778816, 0.014154482614685548, 0.05395819192926865, 0.045299525299924426, 0.03201795771019533, 0.02160404317692155, 0.021140406824997626, 0.07483133653295226, 0.06894591249874793, 0.05061367373855319, 0.09314132941653952, 0.043843479797942564, 0.04184086108580232, 0.03363405106938444, 0.056195911893155426, 0.020087262164452113, 0.008973576586868148, 0.026270994312653784, 0.02102504739013966, 0.020033580767631065, 0.034583525120979175, 0.009427989898540545, 0.02033226737694349, 0.03662078728666529, 0.06331924567348324, 0.038049866852816194, 0.031701160842203535, 0.05378385030780919, 0.05663825788360555, 0.021410414992715232, 0.06842728485935368, 0.05409262084867805, 0.019134904869133607, 0.007349018569584587, 0.009813931737880921, 0.03461503300059121, 0.0912641262402758, 0.06830952086602338, 0.006243572906896588, 0.05725033304770477, 0.005126306223246502, 0.043174248130526394, 0.10268508878652938, 0.053490056307055056, 0.05220302009547595, 0.026824699561984744, 0.035451678340905346, 0.01902833431813633, 0.07404906093142927, 0.05729532575060148, 0.017807731455832254, 0.040582427245681174, 0.04074488708283752, 0.028437935652618762, 0.13729962083743885, 0.07010174813331105, 0.02264843977172859, 0.039526006003143266, 0.015675745271437336, 0.026450028162798844, 0.039830650202929974, 0.03877572438796051, 0.08550218815798871, 0.05430260040157009, 0.05995329425786622, 0.014257980674301507, 0.031745927190058865, 0.1293605554383248, 0.06622505810810253, 0.027532743697520345, 0.03396766129299067, 0.01942708098795265, 0.009308462376793614, 0.09299486657255329, 0.02787015928333858, 0.07284480016096495, 0.009273150990338763, 0.0386769296892453, 0.013851866333425278, 0.017767659192031715, 0.07365584140643477, 0.033631646510912105, 0.04845480696531013, 0.05450228265544865, 0.013722393105126685, 0.013783415270154364, 0.05575779243372381, 0.05274007155094296, 0.012645354072446935, 0.03958715155022219, 0.028130447171861306, 0.022014205933373887, 0.007656429588678293, 0.030769720979151316, 0.038905143810552545, 0.04562810376228299, 0.0428833670594031, 0.0629823848430533, 0.02161573571356712, 0.01740942450851435, 0.04150608197960537, 0.03379342728294432, 0.02163161952921655, 0.040945545260910876, 0.06458968375227414, 0.010156508960790234, 0.04117538468562998, 0.020305800535425078, 0.04095112992217764, 0.023806828394299373, 0.0465636848093709, 0.015867735164647456, 0.025136847943940666, 0.0329203721776139, 0.054410386219387874, 0.03007359387993347, 0.05291352259519044, 0.05874740447325166, 0.03195192140992731, 0.05157340427103918, 0.016669074684614316, 0.06426140214898624, 0.06692902228678577, 0.02716025606787298, 0.015529643296758877, 0.059232887797406875, 0.06489691804745235, 0.029976893893035594, 0.045898616590420716, 0.032383060970460065, 0.03484448650851846, 0.02380543686740566, 0.030250887393776793, 0.06130003253929317, 0.015280279822036391, 0.04636983954696916, 0.03650466715043876, 0.11631645655143075, 0.022947059587750118, 0.02483630411006743, 0.010833088817889802, 0.0353190083114896, 0.028335853239696007, 0.009456485586269991, 0.051716731541091576, 0.06337627972243354, 0.049201748915947974, 0.04264481111022178, 0.010097183530888287, 0.02448094524879707, 0.05189518466067966, 0.034319606274948455, 0.03186809211911168, 0.04314163816161454, 0.017011048912536353, 0.010297521657776088, 0.03068849848204991, 0.09192675279336981, 0.03088854438829003, 0.03600482697947882, 0.05979944333375897, 0.018527069223637227, 0.04262295115040615, 0.012638809257623507, 0.057136691684718244, 0.0506282569403993, 0.027388091693865135, 0.009880912421067478, 0.03863856807583943, 0.04112972776056267, 0.019042257008550223, 0.013291511440911563, 0.1050900480186101, 0.058705588162411004, 0.007714767962170299, 0.03739434636372607, 0.06984955893130973, 0.05871188157470897, 0.058372400962980464, 0.10838441186933778, 0.0799259651103057, 0.042864460847340524, 0.020421788940439, 0.010565458305791253, 0.0693661833065562, 0.003542847648532188, 0.03778559548663907, 0.041608821193221956, 0.0411119941418292, 0.01111900492105633, 0.02043009728367906, 0.058077464054804295, 0.07514645243645646, 0.05577655021625105, 0.046620451685157605, 0.07354848232353106, 0.04248536439263262, 0.005786896508652717, 0.017523878523206804, 0.01171461924968753, 0.01792275877960492, 0.02545980463764863, 0.037403771639219485, 0.05919124960200861, 0.05851753165188711, 0.06291726880590431, 0.018771727482089773, 0.03398368055059109, 0.04248104138241615, 0.018549125852587167, 0.040815071988618, 0.03016861290234374, 0.011229244464630028, 0.06539748923387378, 0.03045821562409401, 0.08787174694589339, 0.04902066488284618, 0.045687768724747, 0.06437479489250109, 0.06731253452016972, 0.020329543694970198, 0.05542498372960836, 0.02202593557740329, 0.05543648701859638, 0.058546145155560225, 0.057121752251987346, 0.11151450875331648, 0.06127539694716688, 0.03978539403760806, 0.04895743761153426, 0.04131294546823483, 0.08869785378919914, 0.012453293675207533, 0.03226115950383246, 0.04304078029235825, 0.039400241657858714, 0.06388501453329809, 0.027369274539523758, 0.04501052557316143, 0.011975309753324836, 0.04873380625213031, 0.04715630457212683, 0.07335999165661633, 0.04161246513831429, 0.054734908844693564, 0.04483281089051161, 0.03038722734345356, 0.030423872740357183, 0.024938833666965365, 0.07289185232366435, 0.05156921855814289, 0.1095268591598142, 0.042114301686524414, 0.024353629814868327, 0.07310899731237441, 0.03872273875458632, 0.041088327052420937, 0.04130234017793555, 0.027891247409570497, 0.04356070297944825, 0.009564581250742776, 0.058749449090100825, 0.08260177113697864, 0.11485253315186128, 0.024214816658059135, 0.0576712532347301, 0.05083872260001954, 0.017111626621044707, 0.037109049953869544, 0.020097462984267622, 0.05287590312946122, 0.05885231446882244, 0.02848926258593565, 0.013863791718904395, 0.009571635364409303, 0.01538329548566253, 0.039025627775117755, 0.0680296792415902, 0.008498868319293251, 0.025376611738465726, 0.040208433056250215, 0.043233968754066154, 0.026489803567528725, 0.03645574106485583, 0.04567136355035473, 0.051511405254132114, 0.02318139457202051, 0.08043020250624977, 0.009763716170709813, 0.0317645105678821, 0.018307308164366987, 0.055470863298978657, 0.05170316879230086, 0.031704775101388805, 0.051076703384751454, 0.07088015714543872, 0.04684481777076144, 0.0261833262629807, 0.09727328113513067, 0.03769681978155859, 0.027209391810174566, 0.012059103792125825, 0.05298300246067811, 0.017192379709740635, 0.031661637767683715, 0.032210166536970064, 0.02668582517799223, 0.07260101949214004, 0.019654077987070195, 0.09617142932256684, 0.05975622065307107, 0.03234723750210833, 0.00884386308825924, 0.04009368960396387, 0.05403307834058069, 0.04328723640355747, 0.059020370099460706, 0.07728644268354401, 0.05919084513152484, 0.027365001624275465, 0.0603165050415555, 0.1869734053616412, 0.14620769361499697, 0.13447895500576124, 0.10475651200977154, 0.12166257671196945, 0.19652416318422183, 0.20487972185947, 0.08142347069224343, 0.10752693444374017, 0.09000436766655184, 0.09057982155354694, 0.20761897409101948, 0.18601835035951808, 0.11004069994669408, 0.1454157626722008, 0.18170497321989387, 0.1370162540115416, 0.10659976935130544, 0.10687371832318604, 0.08899754044250585, 0.06312300698482431, 0.16966778319329023, 0.08581295507610776, 0.2274738735286519, 0.16158491926034912, 0.29056610364932567, 0.17148724728031084, 0.15454208623850718, 0.09073947236174718, 0.13405273959506303, 0.13959821546450257, 0.1280110192601569, 0.16994518315186724, 0.08824772638035938, 0.20276409632060677, 0.19190610473742709, 0.10591657046461478, 0.14831787178991362, 0.14025612937984988, 0.14306603407021612, 0.08643407330964692, 0.333274535369128, 0.1211564319964964, 0.07317023191717453, 0.08571251280955039, 0.10783756777527742, 0.15873142081545666, 0.10253869273583405, 0.13197530497564003, 0.18303165124962106, 0.12559905415400863, 0.19676804775372148, 0.07874002796597779, 0.05843825543706771, 0.09934961737599224, 0.13997552334330976, 0.13405990874161944, 0.18369999976130202, 0.16071375663159415, 0.17938274861080572, 0.1878092862898484, 0.15589706978062168, 0.12401936313835904, 0.09570144946337678, 0.08429829103988595, 0.10330493052606471, 0.09955466535757296, 0.149868396401871, 0.15271846612449735, 0.13831633346853778, 0.19311476644361392, 0.08287186836241744, 0.1627898999140598, 0.24478716950397938, 0.18745188281172886, 0.11529831899679266, 0.1940450633992441, 0.15680421172874048, 0.10773148518637754, 0.11240507854381576, 0.11047575433622114, 0.21441303921164945, 0.11987741469056346, 0.09143260118435137, 0.13365653663640842, 0.22184935893164948, 0.18020950112259015, 0.07727394491666928, 0.11322898862999864, 0.10014721832703799, 0.07872567482991144, 0.13427275669528171, 0.14681101514725015, 0.14322284987429157, 0.21561582310823724, 0.16847993130795658, 0.08132590795867145, 0.12777362106135115, 0.22113253333372995, 0.18705234018852934, 0.1206742660724558, 0.16684901725966483, 0.16156725614564493, 0.1391744046122767, 0.19224842777475715, 0.126361551519949, 0.29806684178765863, 0.13431323342956603, 0.09236893180059269, 0.18499239056836814, 0.1558501660474576, 0.183908884646371, 0.10665179390343837, 0.20395233412273228, 0.16299326322041452, 0.14410358620807528, 0.19099262484814972, 0.2935811528004706, 0.13938464020611718, 0.09728804245241918, 0.13006759952986613, 0.13406192738329992, 0.09347710671136156, 0.11674207824398763, 0.11538305741851218, 0.17508255201391876, 0.38599409395828843, 0.11074750655097887, 0.12957540719071403, 0.0777998381818179, 0.09600378558388911, 0.17281907581491396, 0.12475175899453461, 0.1445768983103335, 0.11060872493544593, 0.14748770539881662, 0.11583416446228512, 0.11985394055955112, 0.07261161736096255, 0.14119864208623767, 0.1464095726259984, 0.1675356671330519, 0.10725124884629622, 0.12702954380074516, 0.0847281058668159, 0.15108667634194717, 0.15060920821269974, 0.11237396029173397, 0.2261523311608471, 0.12793076341040432, 0.12582517170812935, 0.1469741392065771, 0.11644610232906416, 0.17334056814434007, 0.12849932274548337, 0.14417052792850882, 0.20816682750592008, 0.14527123683365062, 0.08994480289402418, 0.13892866467358544, 0.11811604592367075, 0.1518250539083965, 0.17584457440534607, 0.08065039030043408, 0.20176261255983263, 0.14938300213543698, 0.12988648581085727, 0.12738221237668768, 0.1667970817652531, 0.10333972983062267, 0.0840413966216147, 0.12313519066083245, 0.1648194808512926, 0.1354529644595459, 0.12281758114113472, 0.17878347920486704], [0.0705000884772744, 0.034571739815874025, 0.06405153762898408, 0.05139239816344343, 0.04735897025966551, 0.06954696305911057, 0.05373205211071763, 0.01712953464448219, 0.024773637160251383, 0.03618993345298804, 0.020366675198602024, 0.016293460757879075, 0.03512020550260786, 0.021151854452909902, 0.046613393860752694, 0.08235780493123457, 0.060849637957289815, 0.08007664335309528, 0.022475838486570865, 0.030757052518310957, 0.07671906336327083, 0.019269035074103158, 0.022501501953229308, 0.029386945861915592, 0.03882918870658614, 0.02107741889631143, 0.16615325381280854, 0.08365073750610463, 0.047770138626219705, 0.018335559871047735, 0.006038345882188878, 0.07894632275565527, 0.05687212345947046, 0.01987439380172873, 0.02541898466006387, 0.038888582785148174, 0.021970252237224486, 0.03823609025857877, 0.028499988475232385, 0.028117236943216994, 0.03909989078238141, 0.03484521381324157, 0.04606039365171455, 0.07083423304720782, 0.07125749471015297, 0.022344829012581613, 0.09210153599269688, 0.07429892721120268, 0.04430460583535023, 0.0607107635732973, 0.036915731616318226, 0.017439613220631145, 0.0668544067593757, 0.06638610415393487, 0.0186578523425851, 0.03461347077973187, 0.09191569479298778, 0.07381227129371837, 0.04217030786094256, 0.10212345368927345, 0.026001822916441597, 0.041114903360721655, 0.04969491717929486, 0.0450326861027861, 0.015567506743536796, 0.024435177001578268, 0.03178141298121773, 0.045880393154220656, 0.018317314170417376, 0.03675402134831529, 0.032845945897861384, 0.012131202511227457, 0.011392588385206182, 0.020720243628602475, 0.030744382202101406, 0.04220925948175136, 0.06366725356201641, 0.040170023203245364, 0.019376755953999236, 0.040214618857135065, 0.03952535291318782, 0.04980595360393636, 0.030205202638171613, 0.02258617358165793, 0.026877032105403487, 0.042351139563834295, 0.09978703179513104, 0.0138677742688742, 0.01071501776095829, 0.04545654148387257, 0.031004809243313503, 0.03725896749529056, 0.039744928435538895, 0.03332854597829282, 0.04839653352973983, 0.024262816914415453, 0.04074998934811447, 0.008883452028385364, 0.033614328494877554, 0.01010023932394688, 0.014943283549655462, 0.05639803952362854, 0.06513116211863235, 0.012402597567415796, 0.03464719768089708, 0.053099133729119785, 0.025702880266180728, 0.10715350057580508, 0.039378678557113744, 0.024319639451277908, 0.027034979684685823, 0.05669574093190022, 0.015955072958604433, 0.10220261858194135, 0.019538458800525405, 0.03737870560144074, 0.02156889135221718, 0.02297029994224431, 0.0248244037720724, 0.030392834269150626, 0.03271487519668881, 0.013383408804656938, 0.023375104392471258, 0.013736253640672658, 0.037369228375609964, 0.03864330668875482, 0.02348505542613566, 0.09387970698298886, 0.04886495487880893, 0.016572562090004794, 0.02897555114032002, 0.09563883446389809, 0.0016321570296895516, 0.061143049751990475, 0.0155986454046797, 0.05272424896247685, 0.05765558278653771, 0.08588175958720967, 0.061079072911525145, 0.031172532762866467, 0.042719764314824715, 0.03492244541121181, 0.007391061235466623, 0.07214211247628555, 0.053525456751231104, 0.0196718487131875, 0.017700869611871894, 0.0030287524441519054, 0.06886912990012206, 0.10043952803243883, 0.09040242599439807, 0.05796775978524238, 0.11653666661004536, 0.06319361491478048, 0.039373435283778235, 0.03547809879819397, 0.02173785982449772, 0.03296392140327953, 0.03832706643152051, 0.02040296807535924, 0.05210721254115924, 0.04269113967893645, 0.05521587991097476, 0.0623563610133715, 0.03142180161376018, 0.06428844601032324, 0.025562675582477823, 0.05144291615579277, 0.02838831380358897, 0.023143409598560538, 0.01611399831745075, 0.023274014602066018, 0.06994324023253284, 0.012913523569295648, 0.055907387140905485, 0.06731756628141738, 0.05934110035013873, 0.028516996644611936, 0.07570690751890652, 0.036005335350637324, 0.05042049269832205, 0.05105921096401289, 0.032594903314020485, 0.034647847060114145, 0.04969224173692055, 0.020500250648183282, 0.0049429085447627585, 0.027617124032985885, 0.05868968022696208, 0.03671403814223595, 0.04035834317619447, 0.03477057231066283, 0.0354168307967484, 0.03134935686830431, 0.017574782432348002, 0.03936830704333261, 0.04182917225989513, 0.01423230700311251, 0.02141703494999092, 0.022456585320469458, 0.05970103455183562, 0.049395712921977974, 0.17264906462514773, 0.05388443358242512, 0.011159434343426256, 0.029867269404348917, 0.027971618292212952, 0.03153571757138707, 0.008834705913614016, 0.040052203548839316, 0.060649866645690054, 0.05060564370069187, 0.038334421114996076, 0.05585684317338746, 0.05991452075249981, 0.018803962666424923, 0.031018718946143053, 0.009506507267360575, 0.008834247637423687, 0.07414070874801837, 0.015158705828071106, 0.028281030790822115, 0.010137372682947898, 0.03963716488215141, 0.03715856233611703, 0.05535418284125626, 0.032621067730360664, 0.020656224114645738, 0.01286370876186993, 0.027758709111367352, 0.019923857944377232, 0.07557138393167406, 0.021719369215134066, 0.012185106552351499, 0.04077087338373531, 0.030642913916381076, 0.026033549729618244, 0.0035518313461579964, 0.03612427564803511, 0.01425255093636224, 0.05590048516751267, 0.07523812993895262, 0.025314594167866744, 0.028399113907653373, 0.017986681814363692, 0.03855969262076542, 0.05645967859891243, 0.050372138066450134, 0.023577107713208534, 0.06938750520930625, 0.02089811045152601, 0.06860395311377943, 0.04111564179765992, 0.10384893961600028, 0.03785658562264871, 0.028262645937502384, 0.018673728736757766, 0.0441396857786458, 0.029640652755915653, 0.022413258739106823, 0.08624019465059973, 0.047794388301554136, 0.04181023265118711, 0.03250872512580827, 0.03536156305926852, 0.034120191194233485, 0.004839918856305303, 0.03657966859464068, 0.05572156820562668, 0.07733137972536497, 0.034677592338994145, 0.05539660400245339, 0.01610805185919162, 0.040913859265856445, 0.028489086325862445, 0.024508128262823448, 0.04543747199932113, 0.021770020794065204, 0.06911761578521691, 0.019016337500943337, 0.008178754051186843, 0.034033515767077915, 0.0017002508184305043, 0.05097447625303175, 0.05103846051497385, 0.022675010513921734, 0.054606279809377156, 0.039420372413587756, 0.04476328278542496, 0.0425387062568916, 0.025548400371917523, 0.0808458126266487, 0.027135646450915374, 0.004862277446591179, 0.04102094746485818, 0.025233149026462343, 0.044783380144508556, 0.009555465821904363, 0.035736700156121515, 0.07498601495171897, 0.049630083158263005, 0.04758181494253222, 0.030158842528180685, 0.021659132798959035, 0.04638342456019018, 0.02057417597825406, 0.03577617499104235, 0.08537801943020895, 0.015164231117523741, 0.05066958343377337, 0.029269475016917568, 0.040272903424920514, 0.05237400720943697, 0.09069076520972885, 0.007180772763604182, 0.020541948215395678, 0.026504653942538425, 0.03716563500347547, 0.03296814793429803, 0.05401498849096242, 0.07492452801670879, 0.03318459159345366, 0.017775668820831925, 0.1034005191468168, 0.026950246829073876, 0.00914451638891478, 0.14620468049542978, 0.030028304317966104, 0.06294933700701222, 0.0783046692959033, 0.034929139583255164, 0.057777061228989623, 0.011508456191222649, 0.04295205282687675, 0.055745717691024765, 0.06291755082202144, 0.049748696910683066, 0.010947492737614084, 0.004866397293881164, 0.08878140477463603, 0.023975479598448146, 0.03131814213702455, 0.051215180719736964, 0.04553769533231389, 0.06915447083883919, 0.03974252387706656, 0.047233499062713236, 0.05984910414554179, 0.07115159023669548, 0.06453607842558995, 0.04218057176331058, 0.020792909162992146, 0.11461437054094858, 0.13988287362735718, 0.23765317106153816, 0.17138459341367707, 0.15816020459169522, 0.08243474338087253, 0.1677390155964531, 0.11583805331611075, 0.15089223365066573, 0.18658615270396695, 0.09433140774490312, 0.07425941526889801, 0.14171844231896102, 0.18110537726897746, 0.13802296249195933, 0.14796744449995458, 0.08856261963956058, 0.10074487727251835, 0.07567610096884891, 0.1299067761283368, 0.15488846140215173, 0.10294191641150974, 0.24865862738806754, 0.17205650423420593, 0.2733504446223378, 0.14038416469702497, 0.3018245432758704, 0.1728518193704076, 0.1906720022088848, 0.11804236550233327, 0.14949705539038405, 0.2545189223019406, 0.14979596278863028, 0.1856182437040843, 0.15986154845450073, 0.12648458476178348, 0.1842896212474443, 0.13260384468594566, 0.08995729323942214, 0.13384936144575477, 0.10817474030773155, 0.10416208882816136, 0.134422967385035, 0.21949581569060683, 0.18004982062848285, 0.08352144053787924, 0.19335404969751835, 0.19688094325829297, 0.16980683198198676, 0.18741382547887042, 0.14212631183909252, 0.12861650786362588, 0.09930019776220433, 0.14033700863365084, 0.11981472547631711, 0.13801687688101083, 0.15122195502044633, 0.11176312080351636, 0.09685617187642492, 0.20013088214909658, 0.11805465546785854, 0.08947699752752669, 0.12054770762915723, 0.09489282019785605, 0.122210971894674, 0.0942488363943994, 0.10403060994576663, 0.13072264875518158, 0.13311853894265369, 0.13645174680277705, 0.1917595899431035, 0.10066983129945584, 0.13790589611744508, 0.14427511137910187, 0.17606300330953673, 0.20052291423780844, 0.09763959780684672, 0.16688976116711274, 0.09370342464535497, 0.1698665154981427, 0.12779876502463594, 0.10186671512201428, 0.057293244026368484, 0.11866354310768656, 0.18657482753042132, 0.11730545738828368, 0.27252327650785446, 0.1428423952893354, 0.09496237427811138, 0.11432659535785206, 0.1772424837690778, 0.11709369297022931, 0.13274382858071476, 0.17836940533015877, 0.12222885023220442, 0.1617737513151951, 0.13764786621322855, 0.12423731706803665, 0.11392042535590008, 0.10754907270893455, 0.12823835393646732, 0.20881509350147098, 0.19434518791968003, 0.12221327997394837, 0.07245291650178842, 0.11634011621936224, 0.10563592732069083, 0.2386647035018541, 0.11916196206584573, 0.0965445589099545, 0.15681663528084755, 0.15491149766603485, 0.15064791863551363, 0.1353235635906458, 0.1448590776999481, 0.14429354632738978, 0.17101115954574198, 0.05123497008753475, 0.16612600215012208, 0.12132420190027915, 0.20127551135374233, 0.11180848829098977, 0.07492305856430903, 0.13462570728734136, 0.14911605161614716, 0.15632907394319773, 0.17735955014359206, 0.20207643712637946, 0.10815451678354293, 0.1056840259116143, 0.15095286711584777, 0.21868623647606, 0.06945496643311344, 0.1785593802924268, 0.12838408205425367, 0.13856713485438377, 0.16512601752765477, 0.15024177089799196, 0.17221297865035012, 0.17878244019811973, 0.16004849545424804, 0.14625557698309422, 0.11462603710242547, 0.1509086648002267, 0.23483551834942773, 0.15093616879312322, 0.1385022563044913, 0.18254248687298968, 0.1109235810872633, 0.08406227323575877, 0.18104345246683806, 0.14098675892455503, 0.18036630208371207, 0.10708221729146317, 0.07444481118000112, 0.11917189942323603, 0.14557213318767026, 0.12749810615787283, 0.20836269512074068, 0.1101375205325894, 0.1484373427229002, 0.06282713497057557, 0.12229271203977987, 0.12220438162330538, 0.15703484154073521, 0.11353568115737289, 0.15904843661701307, 0.19180744362529367, 0.19191941886674613, 0.07963500611367635, 0.12991477648029104, 0.1177091189310886, 0.12765802413923666, 0.1624216462369077, 0.17412650253390893, 0.23733808484394103]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0015436820103786886, 0.041855340386973694, 0.052538352101692, 0.04300841894291807, 0.032215502578765154, 0.014885177097312408, 0.02310132054844871, 0.013984371234982973, 0.06062806605768856, 0.02528199904190842, 0.023821229769964702, 0.061177418610895984, 0.05935479297477286, 0.014100309545028722, 0.03397237764147576, 0.10420845821499825, 0.022536340220540296, 0.009419962643733015, 0.021312405115168076, 0.10078119797981344, 0.02858457104593981, 0.027753447284339927, 0.03553478032699786, 0.07657601439859718, 0.040058456143015064, 0.043266845896141604, 0.020197213198116515, 0.029645999929925893, 0.04716987474239431, 0.031236539289238863, 0.0662854837719351, 0.033443593711126596, 0.023910203999548685, 0.05109998084662948, 0.004575780149025377, 0.020090327234356664, 0.02446322461764794, 0.030659818185085896, 0.017704591482470278, 0.02634832610056037, 0.06092142590205185, 0.048095028614625335, 0.009163580307358643, 0.053158097362029366, 0.0372377123858314, 0.029697666395804845, 0.05176593222131487, 0.009265518929169048, 0.05593618618149776, 0.020207258166919928, 0.023248423494806048, 0.021017351318732835, 0.021262417758407537, 0.049604757368797436, 0.029448872519424185, 0.024323092293343507, 0.009505037814960815, 0.01692340683803195, 0.06788129423512146, 0.026214260833512526, 0.023474748850276228, 0.050576176727190614, 0.021763001932413317, 0.022130671168270055, 0.0690176262287423, 0.03036221140064299, 0.04731568449642509, 0.01455087389331311, 0.02011440992646385, 0.012046529955114238, 0.032926105268415995, 0.017078406235668808, 0.039541038204333745, 0.10883599388762377, 0.03601113523473032, 0.06770942025468685, 0.05762806766142603, 0.01902893174701603, 0.055322630432783626, 0.005043558612669585, 0.02359614194574533, 0.06201786374731455, 0.07265855820151046, 0.004223616697345278, 0.027388008202251513, 0.027093175194750074, 0.07984141222550534, 0.007584805380247417, 0.08526874560629949, 0.03638011621660553, 0.10670432311599143, 0.0595280993002234, 0.03483407788735349, 0.077206105197547, 0.045336959228734486, 0.06752063272870146, 0.028154852698207833, 0.013458319335768465, 0.03771153285924811, 0.03288174710178282, 0.04880187603703234, 0.03467456808721181, 0.12225622063851915, 0.04452171371667646, 0.09651062791817822, 0.043660878072842024, 0.018008534352702554, 0.059289439450367354, 0.030175093706930056, 0.015612054157827515, 0.025566523618181236, 0.02711232260480756, 0.03384604555321857, 0.07611952678416856, 0.0390759231231641, 0.056388784942100756, 0.028260979815968312, 0.02791749717289349, 0.04255247680703178, 0.04578089341521263, 0.0632745683833491, 0.0366929129086202, 0.08875303989043459, 0.022218003396119457, 0.029427151712297928, 0.045875057112425566, 0.09726708420203067, 0.013911833721067524, 0.040005002956604585, 0.068316333781695, 0.051841093227267265, 0.04001480672741309, 0.01427965602488257, 0.020046974677825347, 0.025601983434171416, 0.056210840193671174, 0.019182424584869295, 0.058569945831550285, 0.03599645926442463, 0.06431402784073725, 0.03695934392453637, 0.04591865457769018, 0.04236211963871028, 0.06429684712202288, 0.017866995658550877, 0.021764361918030772, 0.015439755297848023, 0.1179348431469407, 0.014301679257187061, 0.029066913230053615, 0.004275947849237127, 0.017587476868357044, 0.030664909318147693, 0.03414103812247049, 0.008323627771460451, 0.03213732474250719, 0.04626919318980072, 0.08779262658208609, 0.04088829969987273, 0.03629024955444038, 0.030904018167348113, 0.03252621383580845, 0.05145075323525816, 0.02264187362015946, 0.07069474639138207, 0.04583052825182676, 0.05835055584611837, 0.038495723201776855, 0.04137674790399615, 0.002672719851943839, 0.05422527603514027, 0.0694885931443423, 0.07445405834005214, 0.012280272148927907, 0.03874093992635608, 0.01725782043649815, 0.039786640845704824, 0.030531929442076944, 0.05400778594776057, 0.06311907360213809, 0.009315807783423224, 0.029714900920225773, 0.06470233434811234, 0.03269585766247474, 0.017522490707051475, 0.06697896140394732, 0.02154899437300628, 0.09791471195057966, 0.030505481154250447, 0.02544777813454857, 0.04037059232359752, 0.049727375007933006, 0.009682181043899618, 0.048008753947215155, 0.0346755440114066, 0.016886757730389945, 0.0405493348807795, 0.015752906365378294, 0.06119579789810814, 0.02810144218528876, 0.05468612005643081, 0.026960228715324774, 0.04644555345294066, 0.07400479182251729, 0.03365921729709953, 0.03349421560415067, 0.060609371357713826, 0.052813707443419844, 0.06632848380832002, 0.04130789886403363, 0.07507588903536089, 0.02400776487775147, 0.07783251494402066, 0.050204546278109774, 0.014306052362371702, 0.02830839377566008, 0.016878803762665484, 0.03239268291508779, 0.043567935208557174, 0.010683749223971972, 0.06369365175487474, 0.04696425901784096, 0.020461501262616366, 0.023624243367521558, 0.05341922944353428, 0.04127478794544004, 0.040235551132354885, 0.01159548321084003, 0.026307062689738814, 0.06504732911707833, 0.008587310985603835, 0.03175190147885587, 0.01272294097361737, 0.025729156004672404, 0.04996195675630588, 0.05304434096615296, 0.06179084077302832, 0.022046763951948378, 0.008184667112800526, 0.008472177905787248, 0.008439518769591814, 0.0612506500328891, 0.052685798291349784, 0.06270589772611856, 0.047946376434993, 0.004647278192351223, 0.1072889647912234, 0.043261465325485915, 0.02475382738339249, 0.07062470991513692, 0.016088999072962906, 0.05924152639636304, 0.03897998569300398, 0.07449750366504304, 0.02125426341081038, 0.039097478802432306, 0.021241147805994842, 0.043703581250156276, 0.04850124314543791, 0.018635452470334712, 0.03045315417693928, 0.03142883346299641, 0.0227575039389194, 0.06419409677619115, 0.07128985977033153, 0.010416009245091118, 0.05205530302191619, 0.03832147805951536, 0.04575889615807682, 0.05007504150853492, 0.01425055455911206, 0.09530752489808947, 0.05141154186276253, 0.06702233251417056, 0.02176078847696772, 0.11240695617743768, 0.04029986936075147, 0.019134316717099864, 0.045365428013610654, 0.04343886088463478, 0.06342155815218575, 0.029834685410605744, 0.04140938755881507, 0.029819356350344606, 0.02246919997560326, 0.057090340851573274, 0.026286854008503724, 0.02975872474053176, 0.011292749113636091, 0.0656112574506551, 0.03542786282196175, 0.049318459059577435, 0.051081775964121334, 0.03496669225569349, 0.060556938624358736, 0.007429674715240253, 0.09189082542434335, 0.023287530966626946, 0.0358761348616099, 0.03597892602556385, 0.014625743606302422, 0.03272991853009444, 0.00845193118948373, 0.04076658748090267, 0.07122403127141297, 0.03247419670515228, 0.031016943357826676, 0.050597624795045704, 0.008574556250096066, 0.0963463238440454, 0.03607362406910397, 0.045893796341260895, 0.01574975594849093, 0.06754945774446242, 0.012216349114169134, 0.059496762114576995, 0.002548366514929512, 0.05408237178926356, 0.029695935336349066, 0.018792435257637408, 0.023379102713079192, 0.05525203734578099, 0.03652797058748547, 0.08424467087024823, 0.05172658355149906, 0.05281769277644344, 0.026354949768574443, 0.013094547302898718, 0.026795887533808127, 0.13142868352588266, 0.07415873551508412, 0.01759869628585875, 0.0225309169763932, 0.07801719097187743, 0.03085905143962009, 0.028731020902341697, 0.03290801541879773, 0.01927798723045271, 0.02763403386779828, 0.03515922391670756, 0.027359079285815824, 0.05806576038594358, 0.009009311925183283, 0.0337968188978266, 0.04169887710304465, 0.04273254038707819, 0.0738866270694416, 0.09000408565043472, 0.026327996820327826, 0.04257621811120771, 0.0051793066995742265, 0.03978492648457177, 0.11471682402770966, 0.1552620140137151, 0.09205800903146155, 0.12919041066197678, 0.17775818734662607, 0.13442007300909609, 0.10282476840075105, 0.11872520815813914, 0.11691793755744584, 0.16264288045931607, 0.11577503755688667, 0.1998308763722889, 0.18599166272906587, 0.15958419302478433, 0.176729689410422, 0.1401298603741452, 0.17783019051421434, 0.11332171998219565, 0.11606218933593482, 0.12454845505999401, 0.10289814454154111, 0.10373178418376483, 0.13171775004593655, 0.12830768537241966, 0.1481686407350935, 0.22740869811968878, 0.0995902661816217, 0.14513675967464224, 0.20673758466728032, 0.10157860597246327, 0.1284889772068709, 0.12352314835879952, 0.11867641194839962, 0.17294123332249, 0.17320769402431324, 0.08464142301818356, 0.17942954844329506, 0.12035709441988729, 0.1736562480800785, 0.08933594494010322, 0.24935692897997797, 0.18335938366362825, 0.10533722772379406, 0.15365999919595197, 0.14438258920563385, 0.12641696026548743, 0.17232913960469887, 0.12413238480803557, 0.11342355006490834, 0.08798747003311291, 0.16871102125151083, 0.1116634281061124, 0.14114627614617348, 0.15676701528718695, 0.2257794761680998, 0.1804621727205813, 0.1438044710084796, 0.08110372378723696, 0.12331959951552562, 0.11614303148235194, 0.12842104100855067, 0.1399628326180391, 0.14054841682082042, 0.09364446843392216, 0.15217963722534478, 0.20400532346684486, 0.1689590173191391, 0.15008163027232513, 0.19381159858312458, 0.10336222432670183, 0.16043432318838313, 0.1548824054771103, 0.15272611024556682, 0.2445241078385152, 0.10122195206349716, 0.15096282673766837, 0.1395762775791809, 0.1360413688234985, 0.1512965705478564, 0.07619924086611718, 0.14026892400579527, 0.18128888070350513, 0.21257206768495962, 0.0761451457219664, 0.09000411533634178, 0.20624297292670235, 0.11433215404395014, 0.13307858171174303, 0.12540093041025102, 0.12203686404973269, 0.2478050981881097, 0.19603516208007932, 0.11044736718758941, 0.14188125467626378, 0.09688121936051175, 0.21905545494519174, 0.14230559987481683, 0.1404177988297306, 0.10872099810512736, 0.16941016889177263, 0.12669900606852025, 0.1403622268117033, 0.14360722299898043, 0.17933332157554105, 0.23506366938818246, 0.10001908653066494, 0.18041213712422177, 0.16457347373943776, 0.10307723219739273, 0.14853161032078788, 0.10953769451589324, 0.18728144117631018, 0.06762716802768409, 0.15902548941085115, 0.14492110640276223, 0.14604857715312392, 0.13163440686184913, 0.12095192578271963, 0.16329249716363847, 0.08454144830466248, 0.18514625262469053, 0.11444044081144966, 0.13749934762017801, 0.07024015125352889, 0.11275958764599636, 0.11432833198341541, 0.1262474834220484, 0.07550612688646652, 0.14454655931331217, 0.15661689365515485, 0.16152216325281188, 0.15154006920056418, 0.07647526785149239, 0.16482423059642315, 0.11510314157931134, 0.11490706616314128, 0.07450733712175861, 0.3292177483672276, 0.21763210475910455, 0.1415733969770372, 0.12101732383598574, 0.1197320873325225, 0.1613929108134471, 0.2100897321361117, 0.15789274941198528, 0.11474470651592128, 0.1468437141738832, 0.17903140105772763, 0.15408495295559987, 0.11503372108563781, 0.09482687295530923, 0.13762732356553897, 0.07743316527921706, 0.16691757686203346, 0.1406644145026803, 0.14841062540654093, 0.14678885461762547, 0.21892495569773018, 0.10868363839108497, 0.14541095355525613, 0.08094949065707624, 0.1816146686905995, 0.08726487052626908, 0.13304453197633848, 0.13038911274634302, 0.17961247300263494, 0.20489414921030402, 0.2054334233980626, 0.10841379349585623, 0.1207944865745958, 0.16554926434764639, 0.19824164133751765, 0.14945954724680632, 0.2255313761997968, 0.1084157898731064, 0.10424001433420926], [0.03081083224969916, 0.07606424420373514, 0.02308946288394509, 0.04740087562822737, 0.05586173392657656, 0.03306039689050522, 0.03180063460604288, 0.0719098276749719, 0.06352051612338983, 0.01379916086079902, 0.03376807922904845, 0.008279772409878206, 0.034120903656003065, 0.04702877762611024, 0.04885430505964905, 0.0450785879365867, 0.03866490689688362, 0.047044629900483415, 0.00707695233359118, 0.010947521495836554, 0.013942924142611446, 0.03485990462650079, 0.07766049253405072, 0.03996395105787087, 0.03788094662013464, 0.07239629063406028, 0.05429687844298314, 0.019704961487150285, 0.02866470444132574, 0.07294312730664387, 0.025998997189162765, 0.034938264288939536, 0.09608724009012803, 0.013194210314395605, 0.05004009748518001, 0.0527056025021011, 0.03928147576516494, 0.07127404460334219, 0.027961007435806096, 0.018580533542262856, 0.06405607215128839, 0.03414137951040175, 0.06004332419252023, 0.016396769569837488, 0.009537581918266369, 0.037785844106110744, 0.03914246779459063, 0.06192223801917862, 0.00640138643575483, 0.04031208882224746, 0.034906155269709416, 0.018551793873484712, 0.04647269379347563, 0.012645490442082519, 0.008858064084051875, 0.052300890820333734, 0.0548241149954265, 0.04968916924553923, 0.01675256444286788, 0.004586915611071163, 0.05284141923766583, 0.04404583749419544, 0.019091511494480073, 0.03824087711109314, 0.010858707755687647, 0.025091537972912192, 0.09393280022777617, 0.04300490858440753, 0.06264447016292252, 0.05035516885982361, 0.011087390357715776, 0.06499137860373594, 0.0379288930707844, 0.02241466881969245, 0.05046600490459241, 0.017428918872610666, 0.048089302945300005, 0.007064939281917759, 0.014479602668870939, 0.045998776840860955, 0.04868056457780767, 0.04466983526071999, 0.02940408947324613, 0.020143862057011575, 0.042055983722093515, 0.056116064224625006, 0.03181927735568024, 0.03952937164285686, 0.03048644506634446, 0.017391781802871265, 0.050259424388059415, 0.04979106241080444, 0.008414230087510077, 0.07742395522654988, 0.009648268605815247, 0.019277946412330493, 0.03915542569302488, 0.03886727943609003, 0.031248120503732935, 0.03092075916356407, 0.05280075696646236, 0.08037443752982654, 0.041211757343262434, 0.008163223683368415, 0.02084206531435484, 0.04435149472556077, 0.032001893923734315, 0.029522374825319275, 0.016274931185762398, 0.02772137537249364, 0.04037180573504884, 0.05280307988869026, 0.04239579458953813, 0.026890938097494654, 0.04021455577458255, 0.05383217525377404, 0.008570154386688955, 0.09595534560503438, 0.022506643181259278, 0.021922354026173707, 0.04927640526148025, 0.01506562473878148, 0.02469157047016779, 0.05547782093344722, 0.05209600611124188, 0.03520117010339163, 0.02497677782230312, 0.04901474625512492, 0.07621483338880353, 0.040286102521349676, 0.04584103706292808, 0.07089244711096399, 0.03884999852743931, 0.011720781858457485, 0.024041775650402997, 0.06547322540427558, 0.06318959989584982, 0.010957612848869758, 0.03263753227656707, 0.03382270871952642, 0.007391981498585665, 0.04376478245831095, 0.04642878091544844, 0.039746913680573925, 0.013211497716838494, 0.020606531761586666, 0.06634672579821199, 0.003791248186644225, 0.018322397882002406, 0.036981819866923615, 0.05184740890399553, 0.06403555176802911, 0.010292805309290998, 0.018244693164888304, 0.046050567616475746, 0.04328055707446765, 0.025512528663966805, 0.01989878077438334, 0.028528583425213583, 0.01445384086764534, 0.09232438067556359, 0.028766159739461727, 0.019316831239848398, 0.07107132696546614, 0.021486390505742747, 0.11635621340246871, 0.03307102815597318, 0.07335050700930879, 0.042745780301629566, 0.03785549466556404, 0.04376686047180556, 0.054711178672732785, 0.06553798521053977, 0.07011022345977835, 0.035257565905340016, 0.009627406834624708, 0.02407387539278716, 0.08336042417795397, 0.04025793430628255, 0.0355035655957181, 0.04516176413744688, 0.007390536165985395, 0.033056170359486714, 0.042250945916748606, 0.037666451098630205, 0.05307345913024619, 0.044318532236502506, 0.03828721681202296, 0.021820368092448916, 0.08503732169629075, 0.07220670901006088, 0.07962621166370809, 0.00902071038581198, 0.05490402574650943, 0.045844265405321494, 0.030703046431881376, 0.05027386658184696, 0.027055297832703218, 0.06510391045594588, 0.03284373800852336, 0.0559891606826568, 0.02470285111485282, 0.04969079454895109, 0.020084575589862652, 0.054503421852132306, 0.05250130037893541, 0.04892579614534043, 0.05630489256873261, 0.042527466430328786, 0.0215467772068223, 0.09667322505265474, 0.025383636166225187, 0.10299579633283429, 0.04722013669379521, 0.07259796184371226, 0.0629635046061594, 0.027628992829704657, 0.0431294298323337, 0.029082325781928375, 0.05776264129963238, 0.03736735074198805, 0.025440378922212403, 0.03723937479662709, 0.0311676123237703, 0.006472738832599134, 0.02168727503885748, 0.049335914372932166, 0.06393616335117258, 0.023693918046774343, 0.036068603440071456, 0.02879960462450981, 0.012960320618731203, 0.04807585894013755, 0.016694433870725334, 0.01845093229349004, 0.0717386587348301, 0.06450347587815486, 0.03352899264427833, 0.044450274581322446, 0.03729629752342589, 0.01520646117569413, 0.016780769765318837, 0.04657331788621377, 0.02897634152759565, 0.026059840311063454, 0.03321474134281743, 0.021764836892543826, 0.05438212894659955, 0.043440924055175856, 0.026619471609592438, 0.06799924376537092, 0.03691501173307188, 0.02989226864883676, 0.01445728257749579, 0.022647983350907452, 0.04058572980284225, 0.016850216234161053, 0.01932230828970205, 0.06844031697255559, 0.025041300141310785, 0.06678828882286325, 0.04181280790362507, 0.0259478428051807, 0.023531897932116408, 0.03568886131688487, 0.018210764028481208, 0.02772851297777379, 0.035029277569265105, 0.02199971364461817, 0.0862550969759468, 0.0456525575282285, 0.05707789874577429, 0.04298168307286687, 0.0764650410565082, 0.056881255586631596, 0.07484060595743358, 0.031367283445433713, 0.026162182475673035, 0.019451436419331003, 0.02079564397718059, 0.014379855238075834, 0.18847241008188576, 0.05547411390580237, 0.03519562626024708, 0.06990625901380554, 0.049282620748272166, 0.01028128532198025, 0.06027055125741754, 0.03778327256441116, 0.02409496908512665, 0.10366967384470627, 0.004890098707619472, 0.023223448370117694, 0.0677717755024787, 0.027886321404366754, 0.03947593329939991, 0.061075436387909576, 0.004309727164582, 0.04731145054392982, 0.014340998241095804, 0.04292572884878609, 0.04083988940692507, 0.03083800598687958, 0.02228649434982799, 0.059679156038328074, 0.004953589905198896, 0.03237279335735366, 0.06984043793636374, 0.0606636000884464, 0.03574318652681541, 0.055725991405779496, 0.023798145266482607, 0.08649570125271566, 0.0438093669799855, 0.026428387136547826, 0.028763922164216638, 0.012107374004699523, 0.03169743897160515, 0.04428281637956388, 0.02016820821154397, 0.0556341877381783, 0.047772524631000124, 0.048127033733180724, 0.05222298757871613, 0.017347004322800785, 0.0514952078810893, 0.017783572693588212, 0.055080489910324104, 0.05064837656391319, 0.013132851399859646, 0.08557526001823135, 0.09020275858347304, 0.06078805454308167, 0.05629103667160962, 0.03451915123150684, 0.017948077147593722, 0.028022540755046066, 0.0741718863719143, 0.13570418144809082, 0.0854690364212729, 0.031041972288221586, 0.038969937013462186, 0.055391379282809794, 0.017063071609300096, 0.08265720956842415, 0.038847282266942784, 0.04156511240580585, 0.039674936488154344, 0.03873165936965961, 0.00446635047410382, 0.028140868780610617, 0.01648769379244186, 0.0776374562701676, 0.1839815260609612, 0.1356194430263713, 0.15860733372392133, 0.10167067681322806, 0.16759171412559226, 0.18340089940465987, 0.13707503210753202, 0.13458451809128746, 0.08288189477752894, 0.10652450073393993, 0.11342383208102547, 0.17527804855490103, 0.14905656105838716, 0.10371556083555333, 0.19694717251695693, 0.10789620486320928, 0.2120266782003455, 0.07600705430377275, 0.10546428340603597, 0.18625877652084455, 0.13536729093175381, 0.17084451770642772, 0.13261610496556386, 0.19538566411938518, 0.2264252188615501, 0.23399211204377934, 0.09988142555812374, 0.1305821750429459, 0.2030529995681718, 0.09138209803495556, 0.10129626331035979, 0.1315353301470168, 0.11404207820305601, 0.22644151642452925, 0.11962639066041447, 0.16904123243875802, 0.18349748250329867, 0.10126798748387955, 0.1815593638457358, 0.17189381062053144, 0.15227084717480466, 0.08390102681005374, 0.25207508937455714, 0.09943107550498098, 0.08844881871482357, 0.06810502207372338, 0.2062386684701778, 0.11450982419773936, 0.0978425974608399, 0.12477136653615162, 0.14526008977554739, 0.1210024586180225, 0.24537278339266777, 0.07304730257601477, 0.13365162361878902, 0.12931819364894181, 0.093474486930063, 0.2022880531148985, 0.1023695943877101, 0.22846753505291417, 0.16892210289370269, 0.09015710165840574, 0.1282435341272503, 0.08680381870362908, 0.1380849615088664, 0.10983836822560988, 0.1234508260677103, 0.12765521882101893, 0.15543606248684227, 0.2051661760197021, 0.14160507183987647, 0.16453161661047488, 0.07549108355306089, 0.152634707337711, 0.12907983065815642, 0.09489740667049773, 0.11638514974038117, 0.050839112227549776, 0.12566112738568336, 0.19748174148844555, 0.13031222624704242, 0.2141789806773886, 0.09714014726341702, 0.1420601419522427, 0.11099605922936462, 0.136369694955647, 0.15360113204224035, 0.12973718054126948, 0.10985043554683216, 0.1575301805860363, 0.1167321260436438, 0.10573973893770017, 0.29115625948179513, 0.1386085170088336, 0.12434665026376024, 0.1820174025488086, 0.14591619285056368, 0.15159197500906885, 0.13478253793437034, 0.24694196559721604, 0.10229802166577429, 0.09431559999939054, 0.12485475424909964, 0.1724761739023961, 0.24796534271445125, 0.10652009237674065, 0.19267462834250182, 0.1459473036811687, 0.14271842694142833, 0.1234880521951709, 0.14677041966933757, 0.13053944217972457, 0.13648753316374496, 0.22989023214904591, 0.09918578085489571, 0.16961964749498293, 0.2376317823654972, 0.13431927451165393, 0.18792670889524743, 0.17640044301515445, 0.07124021009076387, 0.06563069429830648, 0.15649981243768707, 0.12195443370728754, 0.16201402904698625, 0.08053942437982187, 0.14689737145090476, 0.28284666943363845, 0.1634201910928823, 0.0941708218306303, 0.15477436361834407, 0.11477986205136403, 0.10106265006470494, 0.1132814287848305, 0.10479332253453322, 0.1926133269444108, 0.12164922547526658, 0.10507516795769334, 0.1669298074557446, 0.12722748942906037, 0.1680699540884234, 0.25797186826821417, 0.07623983634402975, 0.15509960241615772, 0.17222550610313192, 0.18579392490210012, 0.1446372052305378, 0.1064463822694961, 0.13741593022132292, 0.1227466763521079, 0.18367620650678873, 0.12016833657980897, 0.07379645612672903, 0.22968487988691777, 0.1352260008570738, 0.10871752485400066, 0.1282344205537811, 0.16093608923256397, 0.14789027598453686, 0.1610314700519666, 0.20103097369428724, 0.16590083454502746, 0.1886302648927085, 0.16663953865645453, 0.18231310386909172, 0.14028517703991383, 0.18668800505110994, 0.13649326254380867, 0.08943449473008513, 0.14190268790116534, 0.21900202031247318, 0.19801651826128364, 0.11493174999486655, 0.09304513965616934, 0.195370034489315], [0.021493771164387, 0.038050902148825116, 0.08838086025207303, 0.053629231260856614, 0.030040123019716702, 0.05028270184993744, 0.005292520863804384, 0.04658348530938383, 0.02601536896690959, 0.030037603428354487, 0.05734637066780124, 0.025993945018853992, 0.046082238768576644, 0.014746744291187497, 0.030913799673726317, 0.09748063719598576, 0.01768153852026444, 0.04045288165798411, 0.0765371035959106, 0.04756348018418066, 0.05349174840375781, 0.032979569587041624, 0.07448761083651334, 0.007323875533984392, 0.02998675889102742, 0.05011077220842708, 0.032302122344844975, 0.023254123188962694, 0.04485657816985622, 0.030534929574059788, 0.053128018116694875, 0.025514307963021565, 0.030008531648491044, 0.018381355948804412, 0.04903344095509965, 0.06402383325621486, 0.019436775291978847, 0.024789914314169437, 0.0989752855093684, 0.08007970100152306, 0.00618036604464578, 0.014905599146004533, 0.04724571481347084, 0.03168929761159234, 0.056456123711541295, 0.10893594633671455, 0.061147584274294786, 0.016408447263529524, 0.060990983693045564, 0.062358824943657964, 0.058958044537575915, 0.05882394587388262, 0.05431605182820931, 0.026476676830498036, 0.0073609824539744295, 0.029433612107823137, 0.05354889748559799, 0.010636227652867092, 0.03669915808131918, 0.0010884808625633013, 0.016002540724002756, 0.022706349554937333, 0.06810937105910853, 0.028416021887096576, 0.05795896162453573, 0.03683577633637469, 0.04315016543841921, 0.012712329189525917, 0.00773808160374756, 0.03925438366422895, 0.042280197667423636, 0.03392785249161534, 0.06697804856230505, 0.011921036493731663, 0.07720815352513455, 0.031205569466692396, 0.03572992063709535, 0.020618933049263433, 0.011428019442973891, 0.03250557841965929, 0.08216676127631217, 0.021596029837382957, 0.013030907211941667, 0.05522993618797045, 0.009727716442284873, 0.020167861257505137, 0.050291166044189595, 0.045955338937346824, 0.027737368654925376, 0.052905273623764515, 0.017282556218560785, 0.06533893378218636, 0.06534164262120612, 0.0842780304083135, 0.012410292711138027, 0.022979704808676615, 0.05208872564253397, 0.07855298448703252, 0.034724447832559235, 0.07243917192681693, 0.05056926733232103, 0.02150597021682188, 0.019119559110549744, 0.025307293290097732, 0.055875322650535963, 0.058389937912579626, 0.029345508046390023, 0.006818459050919046, 0.04137905598327052, 0.045554055977845564, 0.06782230091630481, 0.04895546720945276, 0.012229158583068056, 0.0607825366751058, 0.026814192606252618, 0.0592914655135246, 0.05964575939287897, 0.023370514209091198, 0.08344283967744559, 0.04725529593997635, 0.050666251190705225, 0.03364845615578815, 0.02986986506584799, 0.036465296216192655, 0.028207083196321037, 0.028751455938618165, 0.033072204460040666, 0.0470260205474915, 0.05586211984336842, 0.11063926431233995, 0.03973264589149039, 0.013894268013245892, 0.02528106950194342, 0.025018002270371653, 0.02802460949169472, 0.05544339641346596, 0.01936925655172672, 0.037264938073349185, 0.016038156391005032, 0.01500481965194922, 0.05401165624789428, 0.05904355850361753, 0.06159790093079209, 0.03353967586008366, 0.05263859398837667, 0.02460227711708285, 0.03652381456049625, 0.04198937225737609, 0.05948508442088496, 0.06271505582844839, 0.024339029914699495, 0.05414423721958883, 0.02331422787392512, 0.09228845330653712, 0.032509226075490005, 0.018284067809872795, 0.04816319858946372, 0.047401217016158625, 0.06516648092656396, 0.025219565868610516, 0.012574988268170273, 0.009605070044926833, 0.019875757498084567, 0.07410759411868639, 0.08745328697841614, 0.04994620096113067, 0.06403558887541294, 0.037806052787345834, 0.007177697953011375, 0.053649417677661404, 0.06556545209605247, 0.046417481717071496, 0.053820671964786015, 0.05002126177714672, 0.0630146088951733, 0.053297995909815654, 0.029546427831519395, 0.016607285324425902, 0.01783971987606492, 0.05669691352522932, 0.039172725155367516, 0.014035827116458677, 0.011396657209843397, 0.041167955787386745, 0.07195624159066938, 0.027092798554804176, 0.11475398336187936, 0.05240749662334565, 0.050400725594954565, 0.0049446920183982, 0.08304564966238104, 0.055447096019634046, 0.05611155938822776, 0.06782089083571918, 0.033582531177671626, 0.03363394345797133, 0.020924914970237296, 0.11747223281417973, 0.08553131003282033, 0.023553127066406887, 0.03800393904384691, 0.01867921691882657, 0.052197012410033494, 0.02725279817241244, 0.034540398919489235, 0.01920157199492678, 0.04469955456443131, 0.04100232326891273, 0.06489244289696217, 0.026733343038358726, 0.03974933679273818, 0.03686364769237116, 0.005210560857449309, 0.015654089402232785, 0.01570628835906973, 0.03897015223628841, 0.05454929400002584, 0.022157848616188858, 0.03269560533226468, 0.06960479120607488, 0.05531705690373201, 0.0366911206219811, 0.0360017990169581, 0.10284926669555716, 0.040375060052610934, 0.023099487443687394, 0.0359028262028005, 0.0644186780846212, 0.03518708785122726, 0.07848967186873779, 0.010373026834713528, 0.07126816679374315, 0.03381575479579624, 0.009072415814443957, 0.02283845555211883, 0.030569643531634938, 0.05096102111565415, 0.12355117927654646, 0.07955457214848138, 0.030419009817705955, 0.07254247146192938, 0.04896420599834528, 0.019869775787810795, 0.01012247314065462, 0.03233556722989306, 0.02693429993087193, 0.007361182833847124, 0.025895441613101866, 0.07268510482390411, 0.04964771658706013, 0.06401774764526635, 0.062340293516172096, 0.01393442005792167, 0.041337603324791417, 0.03685761403176002, 0.02035301411524415, 0.03645941098511685, 0.0396505124081159, 0.06120297075540293, 0.033728938360582106, 0.02198003374360269, 0.047517121929558925, 0.045917815950815566, 0.017478965601185337, 0.031370474680443294, 0.04059366707224399, 0.014327083899843274, 0.05121681715536397, 0.07386857803794555, 0.05175345671887044, 0.021817121196363587, 0.019065098458668217, 0.041402025453862734, 0.06163993617519736, 0.03594685040297918, 0.05550716174184345, 0.03572344168787822, 0.022152609053591732, 0.05519361176993698, 0.02407620573649183, 0.059541424561757594, 0.0266118887157063, 0.014380317225004546, 0.02862763973098481, 0.026741900001070462, 0.03339446724567097, 0.03419323707930744, 0.0701892250799574, 0.037552613066509366, 0.03724246584170032, 0.04600063221005257, 0.07924163073766977, 0.04657699151721317, 0.015079083586897468, 0.04750784137286246, 0.07029301443253644, 0.03481329033093061, 0.0444241472723661, 0.07329989995923825, 0.07210555428173393, 0.016662042835378088, 0.025044951507879887, 0.014588621379516553, 0.033428331444156356, 0.021830663536093198, 0.019497247340041213, 0.05913739565585274, 0.05601921024208423, 0.033157354773720726, 0.03002642853971338, 0.023892999161034822, 0.009338883937743958, 0.03242368984501809, 0.07773131568683311, 0.02392131766100647, 0.03441576634941157, 0.017302293636021204, 0.07745266892015934, 0.022724175942130387, 0.050037358960253187, 0.03481217710941564, 0.01293722869377234, 0.01783975698344875, 0.041153565543936566, 0.005861222134626587, 0.0729357058298774, 0.012506409184425138, 0.02437457693304168, 0.03679800473037176, 0.05483859058585949, 0.06666206434601918, 0.08290928744827397, 0.028568900597747415, 0.013812246779707493, 0.015188856505119475, 0.06407706008758396, 0.06208421546034515, 0.04661833656427916, 0.027049074924434535, 0.030290653521660715, 0.07216687794425525, 0.01722823471936863, 0.08527469020918943, 0.05235911601630505, 0.04758522140036803, 0.034743784490274265, 0.04173563567746896, 0.05140911875059828, 0.07322766672587022, 0.007096050112522789, 0.034343343868386, 0.03353975378558971, 0.17111213615862653, 0.09497942141024396, 0.1675948014599271, 0.14312300132587552, 0.17253640660783276, 0.1143061566108372, 0.10051089295302518, 0.1078271480218973, 0.1584968130919151, 0.1135216026159469, 0.21878620376810431, 0.18832317902706563, 0.2018967631738633, 0.11513384422869422, 0.23222418269142509, 0.2786693279631436, 0.08728665256057866, 0.12963914283318445, 0.12365546586806886, 0.1466764192446135, 0.2401804065448232, 0.19544886541552842, 0.26318907737731934, 0.12546678859507665, 0.14429713832214475, 0.21294159785611555, 0.12289748076000251, 0.1418852771166712, 0.12234974608873017, 0.21030197152867913, 0.11248261813307181, 0.11019980898709036, 0.12197207455756143, 0.0725628731015604, 0.16356998617993668, 0.1090717370971106, 0.08507404316333123, 0.17336931894533336, 0.16297003399813548, 0.18044149648630992, 0.0978475327428896, 0.1086958689847961, 0.1579387328820303, 0.14459444268140942, 0.11675076879328117, 0.16371354722650722, 0.09526022782665677, 0.18699181062402204, 0.1519018513499759, 0.17963163525564596, 0.21562339301453903, 0.1373309246264398, 0.2186389616690576, 0.11949107487453148, 0.0991206722392235, 0.11958014001720585, 0.2140879340004176, 0.08921810673200525, 0.14309226156910881, 0.0785513294977136, 0.13262889959150925, 0.18638085981365293, 0.19809417659416795, 0.09098383190575987, 0.2652256196597591, 0.08763957346673124, 0.17747437523212284, 0.06838360946858302, 0.10918173822574317, 0.13133425265550613, 0.1057076855795458, 0.135494242713321, 0.11085119200288318, 0.1251449339906685, 0.2645808120723814, 0.1331900671357289, 0.0876320777751971, 0.1285156499943696, 0.15871101175434887, 0.09032303845742717, 0.09180403867503628, 0.22314005764201283, 0.16904779302421957, 0.1988742925459519, 0.19203514937544242, 0.1002719288226217, 0.15553064178675413, 0.12545181205496192, 0.08960876584751531, 0.1621618797071278, 0.1311786094447598, 0.2004543991643004, 0.18592706619529054, 0.16907240264117718, 0.1289084687596187, 0.10756419025710784, 0.12294944594032131, 0.15429034974658862, 0.11987126228632405, 0.210914391791448, 0.12425690234522335, 0.12179206663859077, 0.14733489719219506, 0.1972730050329119, 0.29704113432671875, 0.16647927928715944, 0.10069067822769284, 0.13304960826644674, 0.09477738654823042, 0.2337759392685257, 0.12279011425562203, 0.13659109245054424, 0.1128039087052457, 0.09571621820214204, 0.1747083611553535, 0.16969608870567754, 0.07766581373289227, 0.12027966615278274, 0.22351648978656158, 0.21440288663143292, 0.17841420136392117, 0.15115351416170597, 0.08779781419434585, 0.12523124576546252, 0.10767442145152017, 0.10347430346882902, 0.13478080130880699, 0.11838680366054177, 0.19544666865840554, 0.23461312637664378, 0.15405330777866766, 0.1394439081195742, 0.13448689598590136, 0.2048411895520985, 0.19974266469944268, 0.11202279085409828, 0.12544452416477725, 0.19165542209520936, 0.08538507725461386, 0.1251719333231449, 0.11286018576356582, 0.22802439867518842, 0.18074510910082608, 0.1813494844827801, 0.12004350734059699, 0.13187962729716673, 0.12574193242471665, 0.15749820886412635, 0.14323380397399887, 0.24071784020634368, 0.10961852181935683, 0.10327756011974998, 0.12436541917850263, 0.2627687546191737, 0.15149274986470118, 0.11798354287748225, 0.1894590657320805, 0.14551801577908918, 0.19776243658270687, 0.1438336374121718, 0.10262052193866111, 0.11731672319001518, 0.17996291513554752, 0.16869741026312113, 0.24542661878513172, 0.18666539923287928, 0.16868011822225526, 0.16197773802559823, 0.1517012043041177, 0.13694457738893107, 0.10412568648462184, 0.11294797441223636, 0.17816509207477793, 0.14311687118606642, 0.16529852233361453, 0.13154410233255476], [0.03461007545411121, 0.06804058881243691, 0.05478279592352919, 0.018611187952046748, 0.08177070674719289, 0.019522827315086033, 0.040883965557441115, 0.07250910450238734, 0.014918710112397093, 0.04534353094641119, 0.09400193870533258, 0.0412067849538289, 0.05597019138804171, 0.0378235229436541, 0.08764554775552824, 0.011363066678313771, 0.011449512967374176, 0.029504476078727748, 0.0533148500835523, 0.04646286033676006, 0.04467824750463478, 0.027484878883115016, 0.027923050292884, 0.0245457848359365, 0.003377778930371278, 0.052498239019769244, 0.05746618298871908, 0.021147750376258045, 0.018210138769063633, 0.03765709261642769, 0.054694057325832546, 0.055749628809280694, 0.05352675179892685, 0.03382287199201528, 0.15342343220254406, 0.00636034056697099, 0.013376092156249797, 0.09184965107124299, 0.04558892949717119, 0.08171125329681672, 0.011603589318838203, 0.02809735666232882, 0.058488491413299926, 0.05105475807795301, 0.054451976175187156, 0.027367415459593758, 0.05171296885237098, 0.03229415538953617, 0.0313368331262609, 0.032035368494689465, 0.02218777943198802, 0.07743948095594533, 0.05939390786807053, 0.02215713986515766, 0.011951084197789896, 0.06303924819803797, 0.04495885725191329, 0.04295794919016771, 0.06570458994247019, 0.049411698782932945, 0.05054496199591085, 0.02427205294225132, 0.05906247584789526, 0.07862827536882833, 0.039051884959917516, 0.019064063162659295, 0.030340780031110626, 0.00576793973777967, 0.008063102395681199, 0.08831298342556693, 0.057239393790951, 0.02025296889769379, 0.056072203296935186, 0.015196319727692753, 0.08271287064417265, 0.03805698033829685, 0.05758134946518112, 0.06847322380053811, 0.05628091748803854, 0.04168652776570525, 0.007939788993098773, 0.04000056862423662, 0.006652958263657638, 0.019936160897486843, 0.01154297719040187, 0.003588042122828483, 0.015128262002690462, 0.01772013391018845, 0.042772839005920105, 0.03285991682787426, 0.04206759091175627, 0.02796214663248975, 0.007653541706531541, 0.044397255551302806, 0.018860313939512707, 0.01994640439079376, 0.05740245105698705, 0.055955240823095664, 0.03033627519471338, 0.05021606441005133, 0.02251334848551778, 0.08656904770759866, 0.018451247706252616, 0.011039036653528456, 0.0401017604599474, 0.11230244694161229, 0.00953996328462381, 0.04680317586462479, 0.05732326389988884, 0.015621575912518892, 0.04088689704076387, 0.10278028406901285, 0.08692090734257363, 0.019373939503566362, 0.027138312616443727, 0.028437065484467894, 0.02485399691067869, 0.039978827408049256, 0.005875501983609865, 0.054132696823216975, 0.01906544541270705, 0.02329316015675431, 0.05627145881589968, 0.01774076747096842, 0.074009281815961, 0.025521855604893062, 0.0032917403586907312, 0.03138554027827922, 0.060365820754668675, 0.012756625201291172, 0.019225882897444535, 0.03479092942143325, 0.0648663638276048, 0.03224140724341851, 0.06797452282626182, 0.053264658636180684, 0.008972222167358268, 0.03006087903486332, 0.0033695547745082877, 0.09067451217561029, 0.08445057232165709, 0.018091552847181447, 0.0346227810223354, 0.012637248892133357, 0.019173465007042978, 0.017445888079237193, 0.0829700767644681, 0.021501504343177658, 0.05531975461053662, 0.01906891124235699, 0.034806098919943906, 0.06077133395592682, 0.027695730459527113, 0.05337959875760134, 0.025396970704605337, 0.02419969725451665, 0.06066290989110712, 0.007511774801969295, 0.05628154089208692, 0.00941923348364071, 0.016918300862016622, 0.02375950905843638, 0.037935717118671164, 0.03317095462989528, 0.027344715017534327, 0.02097226955811493, 0.0347710658388678, 0.03503315900161397, 0.027225848934904207, 0.06451497174566612, 0.04802746349014342, 0.03072646119107958, 0.039472515709348954, 0.024501779189449735, 0.018749238552118186, 0.03206789311661851, 0.031253044653567486, 0.018541528115747496, 0.02298169376445003, 0.06349627015879378, 0.022362737036019098, 0.007615527511006803, 0.027119228288938757, 0.10403576045064256, 0.025826206656347495, 0.04750418258481659, 0.011002593491866719, 0.03125526367512066, 0.04939563128573354, 0.0756829880992882, 0.049166485769092105, 0.016334373503923416, 0.031512466084677726, 0.036883782158838585, 0.02607537346193567, 0.01125051070630434, 0.02237681001133751, 0.034182735689682886, 0.03764784545637667, 0.04450100408575963, 0.028805359979742207, 0.06512190753710456, 0.04070009475981351, 0.07928117978735827, 0.043944790377281606, 0.027586297073867172, 0.06050926305761095, 0.04056448582559824, 0.017473121188231744, 0.03140327760775108, 0.08796307563898154, 0.020459482620935887, 0.050815482245525345, 0.055050562805263326, 0.039410583485732786, 0.018986868672072887, 0.007436675950884819, 0.08655125100631267, 0.05879905424080789, 0.02756963214778807, 0.004083313679075218, 0.02847858122549951, 0.06800432747695595, 0.03532896422257181, 0.020759295439347625, 0.0316368982748827, 0.03509526562993415, 0.04991143134247977, 0.03844242586637847, 0.06531666935188696, 0.020158254155830946, 0.029897953500039876, 0.020111753037781455, 0.029788460742565803, 0.03962699374824297, 0.045045083679724485, 0.03352659179654438, 0.008007989581528818, 0.0655397069931496, 0.0440131570212543, 0.017578298356966116, 0.029233772147563286, 0.04757518385304138, 0.016890806145966053, 0.10300490990630351, 0.03525326515955385, 0.04351104587840382, 0.016365931478503626, 0.04171770538960118, 0.03538076613040175, 0.015364675928140059, 0.023704168961558025, 0.09461840367293917, 0.05715245119063184, 0.05655752705933992, 0.03786401452089194, 0.047180951296468265, 0.02988724987517344, 0.02290951248141937, 0.025742587022250518, 0.0061217085476528155, 0.021672888506145682, 0.021011224889662117, 0.045675849833060056, 0.01636205561226234, 0.03264909493736923, 0.05251127484370954, 0.03732289238541853, 0.050288768907194026, 0.023205006000353023, 0.02066074936010409, 0.018064844807668123, 0.04924985121760983, 0.029322853988560382, 0.02856587634596508, 0.044612229758058675, 0.028903544261993375, 0.03711564022523817, 0.017931106085598003, 0.01386236957841902, 0.02520449284929782, 0.06968985617277212, 0.01693902533588698, 0.06704309038468637, 0.05052134314610157, 0.04739296062325593, 0.030245519810705446, 0.13603742059785873, 0.09410895640030503, 0.003956670352636138, 0.048104472443810664, 0.07272191534866579, 0.038758703230996616, 0.03923154035874177, 0.026428108831169084, 0.06038957319105975, 0.016383307010983117, 0.02757344122073846, 0.06562205569935031, 0.05206823494518176, 0.04429079075634945, 0.041868194384733215, 0.007100983539203298, 0.007052850160107482, 0.06924570305272937, 0.010526639343879651, 0.035222369551775046, 0.06624962319619954, 0.00829744387374376, 0.053280117572285235, 0.05990303972794209, 0.08591115605668165, 0.030885097112332005, 0.0266236183597357, 0.03378489629540127, 0.045002473270869814, 0.05167902672837954, 0.013498477874236414, 0.06143061713373754, 0.05526243112399243, 0.024286354127980303, 0.042969511850969866, 0.07367184211034328, 0.0271188646365772, 0.13314249546965584, 0.02152955381461652, 0.04571455283439718, 0.07243819229188375, 0.041914753019227646, 0.03822669095825404, 0.008279201883851783, 0.01952620965312235, 0.05314233785611577, 0.05798817997856531, 0.02418110645521665, 0.02262101370433811, 0.018204875086667016, 0.032657021074555814, 0.0373485706950305, 0.055602245702175424, 0.01855519847595133, 0.007262613098646398, 0.041981954491348006, 0.03458256403973792, 0.036606608555302955, 0.094518050464103, 0.04325487505411729, 0.02248571461677784, 0.043838203127961606, 0.02592467666545417, 0.011785882124968339, 0.017992652392422315, 0.1394536450970918, 0.10034447375801392, 0.1812702527968213, 0.12243550867424347, 0.10959751904010773, 0.1236093117040582, 0.1256727345753461, 0.303906089393422, 0.12109629577025771, 0.15199902816675603, 0.2563929936150089, 0.12651704630116, 0.18519527890020981, 0.21073991287266836, 0.21739586431067437, 0.11863908934174106, 0.14915731502696872, 0.07130170444725081, 0.12787330633727834, 0.08338130821357481, 0.16767519089626148, 0.10376921069109812, 0.14213496528100222, 0.13498247251845896, 0.11682529526297003, 0.16064267372712493, 0.0966053779120557, 0.2141870849300176, 0.07008240034338087, 0.15532870340393856, 0.20904768258333206, 0.13675271737156436, 0.11209480886464007, 0.12125604305765592, 0.24270099238492548, 0.08076855505350977, 0.12535126588772982, 0.20406684750923887, 0.1133182541525457, 0.21453429129906, 0.13500742352334782, 0.17587062378879637, 0.14179819350829348, 0.10463109647389501, 0.1872198429191485, 0.07480337240849622, 0.11712189458194189, 0.09537219564663246, 0.13281715277116746, 0.09348898849566467, 0.09898073287331499, 0.17311255069216713, 0.12493714748416096, 0.1274620823096484, 0.14957024599425495, 0.15039934369269758, 0.21253622195217758, 0.13422674353932962, 0.18980763765284792, 0.11006701650330797, 0.10198934018262662, 0.09080090734641999, 0.17380130826495588, 0.18931703350972384, 0.08472945657558739, 0.12372842640616, 0.10709147929446772, 0.11590515830903314, 0.14992962358519435, 0.31807259016204625, 0.2658993116347119, 0.11334113456541672, 0.14128544367849827, 0.14768765482585877, 0.22526883403770626, 0.1749468280468136, 0.15521138469921425, 0.24810413917293772, 0.10862959519727156, 0.1591145619750023, 0.0918642342730891, 0.1027898577740416, 0.1284100572229363, 0.13479211163939908, 0.11300518657662906, 0.1055156029178761, 0.09587459251633845, 0.14325381227536127, 0.18995352904312313, 0.21280860499246046, 0.10253341606585309, 0.1288435753667727, 0.11192599253263324, 0.1152089866809547, 0.12537396076368168, 0.12534200388472527, 0.1818853893200867, 0.20429200027137995, 0.13830860028974712, 0.0998790432640817, 0.08983408930362202, 0.17809178272727877, 0.08829341299133375, 0.11093640539911576, 0.18211634567705914, 0.21473024797160178, 0.12823706259950995, 0.1565428718458861, 0.17311053205048665, 0.10455311159603298, 0.10283152194460854, 0.16542741854209453, 0.21933948970399797, 0.14810287160798907, 0.10640340449754149, 0.14580536051653326, 0.08723453895072453, 0.1258273536222987, 0.10111134237376973, 0.11706050412612967, 0.132854349212721, 0.12937998486449942, 0.14143924636300653, 0.1365322549827397, 0.19799634668743238, 0.07666840436286293, 0.056262449143105187, 0.13621405174490064, 0.20551746420096606, 0.09594779796316288, 0.1407206989824772, 0.19366244174307212, 0.13832222612109035, 0.1135612629877869, 0.13293050840729848, 0.13768423144938424, 0.09015788091346622, 0.15971392043866217, 0.09504052984993905, 0.1543493356439285, 0.12640735687455162, 0.07643816046766005, 0.31844093289691955, 0.12109714181860909, 0.07751379962428473, 0.1474782355944626, 0.21499595168279484, 0.09526628375169821, 0.18822619516868144, 0.148727492778562, 0.1110315635742154, 0.09602984981029294, 0.1734908382059075, 0.10646294700563885, 0.06845968702691607, 0.130201171268709, 0.11690396291669458, 0.12285876291571185, 0.13584521919256076, 0.11016302814823575, 0.07859642981202342, 0.12797702889656648, 0.15071894216816872, 0.11881249956786633, 0.16255855764029548, 0.09633502093493007, 0.15498630615184084, 0.1509831170551479, 0.1121582550695166, 0.25166429579257965, 0.09941074065864086, 0.08134671035804786, 0.1996828179107979, 0.14529035455780104, 0.07996696876944043, 0.11921688099391758], [0.03021313063072739, 0.06112572431447916, 0.017388028390996624, 0.032586639499641024, 0.026989437792508397, 0.02491770101187285, 0.07966986479004845, 0.013817301733070053, 0.06070086332329083, 0.03704283924889751, 0.033649743782007135, 0.01855439695646055, 0.0820564261812251, 0.0159904251631815, 0.056390413956250995, 0.027575213098316453, 0.01092682670787326, 0.035082548929494806, 0.023186198122857604, 0.04800714348675683, 0.017742170130077284, 0.05378979491069913, 0.023644622742722277, 0.032829240153660066, 0.03093552790232934, 0.028730390076816548, 0.049294725176878273, 0.04025931099022273, 0.04281192050257232, 0.029287934085004963, 0.014184992305672495, 0.02043968026555376, 0.04111550821107812, 0.054914816573727876, 0.019993699606857263, 0.00999768008114188, 0.08267272045486607, 0.05856335556018166, 0.07851805901736952, 0.07877495343564078, 0.0990536563040223, 0.08117376026348211, 0.027030302298953757, 0.0326816789311124, 0.04056373625644483, 0.013568467966251774, 0.04425956489285454, 0.11537421101820655, 0.03591520893678535, 0.06652200623648241, 0.012086914848623564, 0.037536063173320144, 0.015289025104721077, 0.07744060902041383, 0.04530024147243239, 0.04044969413371291, 0.0329649455670733, 0.018813601309375372, 0.07726785930572078, 0.019142317069054116, 0.0024466878767270828, 0.008917268914956367, 0.08911295182770118, 0.0665486567595508, 0.025600374829082284, 0.013681124128197553, 0.053497559420065954, 0.05519822421774734, 0.04885769296379294, 0.02533685303205857, 0.0922682075179182, 0.031362555964733474, 0.018789128989737947, 0.014508525091514457, 0.03904776232957374, 0.07122982744476758, 0.005137028401804855, 0.03692060010507703, 0.02056879169685999, 0.03519401951052714, 0.04050961142638698, 0.04216837456624489, 0.01876484035165049, 0.027594046950980555, 0.07072234686347656, 0.07918644463643432, 0.1035422099812422, 0.03160660380672198, 0.03550185123458505, 0.05235431432083715, 0.00998789115328691, 0.022992061567492783, 0.05187492031836882, 0.012537008860817878, 0.04689130590122659, 0.029316653344722, 0.016494217270519584, 0.077782419975847, 0.046418799029197544, 0.03726417366124224, 0.02169425493775634, 0.03644137679657433, 0.04336266087193508, 0.01678719861956779, 0.0379232045088429, 0.04715334340289701, 0.004757797432830557, 0.022449802090704907, 0.054741061248932965, 0.10770401830086485, 0.051415742418612354, 0.021281192239257507, 0.09504259302048013, 0.0428126106999116, 0.07985692311194725, 0.02809367189911427, 0.11219473162782378, 0.03142003159155138, 0.07900444034021348, 0.04016967439383734, 0.01591526230185991, 0.05636831650917884, 0.021687432745238766, 0.02576477352704387, 0.07155787898227572, 0.022318146948236972, 0.02610438401461579, 0.028121211144025438, 0.04842797832679935, 0.06598129970370792, 0.044215800444362685, 0.024271668880828656, 0.033451683120802045, 0.009715561918710591, 0.013767754098807927, 0.0597110646776855, 0.014911660637153545, 0.02259489196148934, 0.012197464238852262, 0.0393066939432174, 0.021996080831740983, 0.033644949508016, 0.012293052859604359, 0.013485174877132522, 0.022540000863955356, 0.01280896980460966, 0.04921324107272085, 0.04689694251283072, 0.08125574531732127, 0.003945526077586692, 0.013481695132213645, 0.05052378481195774, 0.02844065191311529, 0.025395017000846565, 0.04008184863778297, 0.024893054287531413, 0.021734162073698826, 0.066896790813189, 0.05583427075180225, 0.05022272889618762, 0.07157225438277237, 0.015207600372377783, 0.06824577038059942, 0.059596094870357774, 0.11550713708857074, 0.036437662347452715, 0.005956810755378683, 0.045205090718809515, 0.08881926914909855, 0.013775938132312149, 0.01615713565115584, 0.016288558872474823, 0.023784530567354523, 0.0897616556903813, 0.034569721174193546, 0.03692838152346667, 0.049636818148428574, 0.03767184280150104, 0.025505621124466415, 0.026611753273755312, 0.047421551862498745, 0.0664766610134393, 0.03486921857984271, 0.019335455435793847, 0.0423280105314916, 0.04918466838716995, 0.05556967655138578, 0.024163591770047788, 0.0365918583702296, 0.017091028312279377, 0.05201562409638427, 0.051557240294641815, 0.009168027627310948, 0.046134671501931734, 0.01726177979435306, 0.05056797970610205, 0.031105706075322814, 0.04653315285395365, 0.04802238348929677, 0.013738468023802852, 0.01968679000128759, 0.04404888772114646, 0.08188803287339397, 0.010476054558239412, 0.09140093374298885, 0.019752904227061663, 0.04643038395443, 0.05976949767500628, 0.015992775915947277, 0.019989298671134748, 0.03281104640336707, 0.01580086023750482, 0.05146212664840277, 0.005127263129907078, 0.07365617537288927, 0.1002672384493053, 0.01545510012874729, 0.0635721992875915, 0.04824691655812785, 0.05366324017813895, 0.046660984080517665, 0.014365398201334756, 0.03993052843725309, 0.07174710437539034, 0.037578109549940564, 0.026402103976579383, 0.08226884368923493, 0.024918326271290425, 0.025773178349481896, 0.1204945327481255, 0.007360397084994474, 0.010644124104146613, 0.015643829210603144, 0.05724373535485938, 0.0702584080863744, 0.0682838425564114, 0.02390261368418578, 0.04650922230212018, 0.09158756904071197, 0.028838272373832297, 0.020774451950273942, 0.015403324196086032, 0.03638324807980098, 0.016775455987954047, 0.07145339201088063, 0.012847530870203627, 0.0805047141329851, 0.04300501248508226, 0.0673616275889799, 0.027513449713296723, 0.009312880010838853, 0.044592228878173046, 0.02998139687406365, 0.0224144368985435, 0.08755856062634848, 0.022117459084256552, 0.08614267644588836, 0.022725688068021554, 0.03748091789020691, 0.0357136861566687, 0.038557143343496136, 0.057902974003809504, 0.028340775534161367, 0.02689615354029229, 0.023291434663406108, 0.022292156936600804, 0.04620614032319281, 0.010662156437319936, 0.03846119107038248, 0.012968102037120843, 0.015526507722825045, 0.01417135348674492, 0.014179199843056267, 0.07838551144232042, 0.06505217534140684, 0.09443671850021929, 0.03158207953674719, 0.01763435091561405, 0.016168466390809044, 0.03898298025887925, 0.0473612968926318, 0.03706921517732553, 0.03628666869190056, 0.05133841805218253, 0.002668647548489389, 0.015591964220220689, 0.017207298733410425, 0.017675924173090607, 0.01818107997678453, 0.03440727617999073, 0.08991154725663364, 0.012390050633257488, 0.053223795985104516, 0.0643458882404957, 0.035667231422849, 0.04905035821138881, 0.04039081584778614, 0.04504876102146227, 0.028936046619492117, 0.0412340737238992, 0.0644486682722345, 0.05007842199120205, 0.031454545169253834, 0.05596350834821351, 0.03952944585762452, 0.05319528267136775, 0.045005089341429994, 0.023811526189092547, 0.04812853287148755, 0.018153739256376866, 0.030908862536307424, 0.08315309780300595, 0.0193799508997472, 0.044821437477367, 0.025380422666785307, 0.017726987643982284, 0.030242671818996314, 0.0356598841608502, 0.04557047228445299, 0.01375089992507128, 0.04531498794676736, 0.05327507467882242, 0.04180416559393052, 0.04453900946828071, 0.054196254350245, 0.011927620271308115, 0.04159748859819956, 0.014464301439147675, 0.022707479474775027, 0.04432514477230143, 0.06128503002400976, 0.04111076959816273, 0.04517415800364688, 0.03784293381613679, 0.03927236219169572, 0.02741955318924738, 0.07576969321235083, 0.01229002953550662, 0.04499521506659221, 0.0684847567754332, 0.04858447871811222, 0.09494034733506851, 0.01882449047116097, 0.06614098761929199, 0.08965014058048837, 0.02019565839873394, 0.042260137415723875, 0.02495601995178731, 0.008551557093596784, 0.013206286912463838, 0.03967086951888632, 0.042689239780884236, 0.09451143792830408, 0.17792530416045338, 0.1128151522425469, 0.11224623667658307, 0.1928906378452666, 0.15540392749244347, 0.21748262137407437, 0.08855300140567124, 0.13924235565355048, 0.10288499368471093, 0.10451678346726112, 0.11956972026382573, 0.14463983243331313, 0.1605257112532854, 0.29904232069384307, 0.1141661949804984, 0.07935684916446917, 0.12391049007419497, 0.14899851026711985, 0.11422996773035266, 0.09035150724230334, 0.16694110294338316, 0.12075804712367244, 0.13365730846999213, 0.13331304100574926, 0.12862878298619762, 0.15967103914590552, 0.2869955718051642, 0.1227542239939794, 0.09834980344749056, 0.1463313799467869, 0.13050047942670062, 0.13702177559025586, 0.08233216372900642, 0.09835815260885283, 0.06277237931499258, 0.2580391662195325, 0.17036667850334197, 0.14464447827776894, 0.21918337151873857, 0.19621329236542806, 0.23064006847562268, 0.1867943548131734, 0.11322452090098523, 0.10442539540235884, 0.12315102067077532, 0.09934561720001511, 0.2553986938437447, 0.18548179243225604, 0.1322293866542168, 0.12273683547391556, 0.2071208445704542, 0.15630771493306383, 0.12380606247461401, 0.18170509196352214, 0.1252489534090273, 0.16811486886581406, 0.09093335844227113, 0.16290650615701452, 0.16185327986022457, 0.1880951615748927, 0.08430776826571673, 0.2709701395360753, 0.16532832698430866, 0.12045157724060118, 0.0943011132767424, 0.09083497934625484, 0.18249043263494968, 0.21614245109958574, 0.10660841537173837, 0.23959093348821625, 0.1851384897599928, 0.1399726141244173, 0.12420390557963401, 0.14064900751691312, 0.14052638987777755, 0.15101238735951483, 0.08072843455011025, 0.2641927282093093, 0.12911401398014277, 0.23452905588783324, 0.135504380450584, 0.09527985021122731, 0.12201463672681712, 0.11706760647939518, 0.2180903364205733, 0.11884895386174321, 0.04918861661280971, 0.13356767187360674, 0.160391902027186, 0.07939475064631552, 0.0885856113745831, 0.10913065620115958, 0.0930217768473085, 0.24518214049749076, 0.08801955307717435, 0.11212767858523875, 0.16638657019939274, 0.17295226163696498, 0.16020985320210457, 0.062337940908037126, 0.13259517640108243, 0.1566723469295539, 0.10962944623315707, 0.11204104026546702, 0.08809736726107076, 0.1259871677029878, 0.15051793889142573, 0.15927130356431007, 0.18547315383329988, 0.14984602807089686, 0.07254202617332339, 0.15004180662799627, 0.13383377634454519, 0.23702890612185, 0.10728879409725778, 0.19183566007995978, 0.128766406851355, 0.13693384593352675, 0.19778622983722016, 0.12875935644842684, 0.14134640368865803, 0.1065144594758749, 0.10049711127066985, 0.16509377863258123, 0.11677287737256847, 0.267871999531053, 0.169976843171753, 0.14171958522638306, 0.15518322761636227, 0.27412806695792824, 0.09866883789072745, 0.10907607866101898, 0.08716663243831135, 0.18698195490287617, 0.2030739132896997, 0.21166259539313614, 0.06557119631906971, 0.08698798264958896, 0.08354835081263445, 0.21432610403280705, 0.16547674167668447, 0.07230321789393201, 0.0643346669676248, 0.10606905954773538, 0.18233379494631663, 0.15608412068104371, 0.12545840232633054, 0.12945016234880313, 0.06482554570538923, 0.08861906739184633, 0.14584009302780032, 0.09022944621392526, 0.1711728735244833, 0.11743065770133398, 0.09433302562683821, 0.10841320719919167, 0.20652262901421636, 0.12900524481665343, 0.14304068230558187, 0.3129895613528788, 0.09751205230713822, 0.2152389011462219, 0.1257670170161873, 0.2548036101507023, 0.12014407577225938, 0.07349780105869286, 0.15051437658257782, 0.18522575148381293, 0.07469778705853969, 0.12646619434235618, 0.10940973341348581, 0.18699412612477317, 0.1372554778936319, 0.1657791223260574, 0.08318118067109026], [0.008462401037832024, 0.029680140578420833, 0.006586917324966635, 0.025112119583354797, 0.019339806276548188, 0.08399168014875613, 0.09894951814203523, 0.006927795029696426, 0.051586536574177444, 0.06482678509200923, 0.033708050614222884, 0.018124070047633722, 0.022386285381799098, 0.059753244640887715, 0.03140854314551689, 0.025514847875456326, 0.04882250774244312, 0.00869488436364918, 0.03519908837915864, 0.026452141428308096, 0.12784047372406349, 0.027352932447683997, 0.030144650809234008, 0.06391898263245821, 0.028248925482330378, 0.03632871877925936, 0.06994021227001213, 0.047307012500823475, 0.03809585774433799, 0.030940810138417874, 0.0763175763131585, 0.05707425851142034, 0.0477028146997327, 0.013925995754107134, 0.06197241091285832, 0.06212009830051102, 0.020909533959638793, 0.03989815595559776, 0.033093374222517014, 0.09350866283057258, 0.024917511764215305, 0.09319625576608814, 0.03490996248729061, 0.05209270726481918, 0.02707397212361684, 0.05004338891012594, 0.019180520976078697, 0.024655004854139406, 0.048014542699093, 0.06290380624704994, 0.04125975574424956, 0.01290406396947219, 0.05395900829171296, 0.07527269175625406, 0.041697470733197406, 0.03525730986439157, 0.0405047392268898, 0.046184558668755926, 0.09074877147213556, 0.10514246590901166, 0.06018159372615628, 0.0810971186729148, 0.031685657377238385, 0.031462693950743414, 0.0686806243902538, 0.06525669639813714, 0.07638557930476964, 0.01619009257410653, 0.020780925333383493, 0.02670642719749594, 0.02507678778783884, 0.02074134288704954, 0.0464235227991594, 0.03236335323890671, 0.01519367768196389, 0.12188384804176167, 0.029209509484644514, 0.03752738375624176, 0.005645216806442477, 0.02677936547115678, 0.008380198905797442, 0.029460305304382928, 0.062355084519367665, 0.03490559494821355, 0.04240687485435046, 0.01084814792193356, 0.10151942711672746, 0.09094729597563855, 0.048992466981871985, 0.037161230357014574, 0.039527323315269314, 0.11478320171590894, 0.03393464314285666, 0.029101373002049513, 0.03331333937239833, 0.008475131653540302, 0.033218140379176475, 0.028756287319993135, 0.04964250671037007, 0.02597140413854504, 0.09529797345749103, 0.04349301540059969, 0.032006105611799285, 0.017373330156260636, 0.016359903384000063, 0.047052960508153774, 0.017796450811147224, 0.020226717279001605, 0.02642519961227663, 0.08718743483768776, 0.03802110491960775, 0.010013267037720652, 0.017815353312471416, 0.01245082881723647, 0.06230744606000371, 0.06456733026425354, 0.020074903550266754, 0.02002760647883406, 0.055566685696248896, 0.029110427203704603, 0.07252692346810363, 0.01152537808593479, 0.02991029541590251, 0.013975019246572629, 0.029045569062873255, 0.047348828811664134, 0.03299286887340713, 0.0172922690762789, 0.03610352890973445, 0.017062830411305185, 0.04097675999219064, 0.049596170720178634, 0.08869888537446968, 0.015048267759993905, 0.03140020511636976, 0.044776196154998615, 0.06415151234250516, 0.06254354550037533, 0.02505480166291818, 0.012525932306743925, 0.07974678839673288, 0.03691632533445954, 0.06726841384079307, 0.017881007406685967, 0.04956933837092947, 0.04988788299669977, 0.035640981659526005, 0.012759385990648298, 0.01756230507453438, 0.042664118082029745, 0.03854207032418344, 0.013541094776883256, 0.03813652372627985, 0.016992153832688928, 0.02241028458229266, 0.04594157209794503, 0.04115873089176603, 0.04136254319746513, 0.010947621685772901, 0.02094041101372568, 0.05497284510056488, 0.09060876531293616, 0.022136962725198828, 0.06769877043552697, 0.04449031715921592, 0.05166468101378996, 0.015795618819538504, 0.013385839338297956, 0.040954013165901415, 0.034206391646876, 0.007212821019493276, 0.04920000115816947, 0.054569109342992306, 0.092740324762417, 0.015059831348480657, 0.05670614213158842, 0.03432103119848762, 0.02970275567349745, 0.027263362644589506, 0.035745145796681754, 0.016503516380907968, 0.050583464617375284, 0.0372934179904405, 0.03295549060567282, 0.07368010963546112, 0.01654833282373147, 0.034905891807284206, 0.03095158055657521, 0.015507460502703907, 0.04777579379151575, 0.05280898738419637, 0.030712891020812094, 0.0012710542932836688, 0.06855593615910038, 0.08779866024269722, 0.0556271707318956, 0.10958809376461431, 0.05202707543503493, 0.010420887010695878, 0.023336299345828593, 0.04417160926095676, 0.0311961182160303, 0.0777914519130718, 0.03135873390419874, 0.039246387023013085, 0.005188393834032468, 0.03629542603448499, 0.09716273823869415, 0.07349303647060879, 0.02513490351702785, 0.03974560750066303, 0.01338536714683869, 0.03757779413717799, 0.028461038709792774, 0.033033828003681265, 0.08412340393988416, 0.02945658899989212, 0.08135228388709947, 0.07558502460597083, 0.056883571087382734, 0.10136920158402063, 0.03335812427394558, 0.0433605531725334, 0.014870040995447198, 0.015010605620773276, 0.01951023306901334, 0.044172618581796996, 0.013419162696663989, 0.018173808784922585, 0.04504942524363287, 0.06390889684553258, 0.05213159580307547, 0.08882962953066453, 0.04856317536905408, 0.071479248435935, 0.00905504584807204, 0.048094672383740544, 0.018386317206022795, 0.034287059388589114, 0.09111359642702155, 0.04253232749761082, 0.008184217185771558, 0.06624402740271762, 0.011076229384343605, 0.05580806180660147, 0.017858524042821955, 0.013280426537676249, 0.00953827675402863, 0.060286477746558376, 0.03675722371554002, 0.023731092223897576, 0.06103788371547125, 0.025982816514442675, 0.048088338153320365, 0.03988981792645063, 0.03552798596501816, 0.05282546677335631, 0.046422543164226227, 0.012717274676106172, 0.012183823564555496, 0.047367293445859104, 0.04484286328079179, 0.045592833193950355, 0.05155045335413888, 0.04347756759671029, 0.028032784248352982, 0.03556906012818217, 0.07406443080981262, 0.07052705070236698, 0.04005792179668788, 0.0663240383437369, 0.054999150524963625, 0.061205238016555086, 0.03390424848475959, 0.03668290133646224, 0.04438087635207921, 0.004451995018825983, 0.05702565154933836, 0.02243192560854368, 0.0056588565530546475, 0.01615548066183692, 0.0052684423462778796, 0.035086645584669895, 0.034137119582737796, 0.020019776820845436, 0.07798391307005659, 0.015441457599081332, 0.00609689762313792, 0.028002437829854898, 0.02919049009506125, 0.05955026725132484, 0.026324505015509203, 0.02584676785772899, 0.029738664488832, 0.046641038861707784, 0.04544002869806718, 0.012275693097762996, 0.02867355455236975, 0.03347304584167432, 0.010256748064421117, 0.08306573959998786, 0.024064702447503805, 0.023602183027833235, 0.020066136930836365, 0.06492005821201019, 0.05911935033509508, 0.08393981144763529, 0.06991008849581704, 0.019479734510241542, 0.05324895479134284, 0.03895678244589362, 0.04359819256933406, 0.030060322424105834, 0.06960015278309584, 0.005341210389815387, 0.009862264105322538, 0.046506465223501436, 0.08924406705773436, 0.06552214777912013, 0.012387982824293431, 0.044889151031384245, 0.003600514378376829, 0.022388333709386643, 0.027235552515776362, 0.01594687593751587, 0.02059663336694939, 0.031804293394088745, 0.0922385067678988, 0.07707372831646353, 0.031109986412047874, 0.0203034497826593, 0.06148147280327976, 0.015358025357272709, 0.03722860252310056, 0.0218671586480923, 0.08238447771873325, 0.02136190265446203, 0.03735977712494787, 0.049005194814526476, 0.02129786829755176, 0.05325847654603422, 0.027700953323801514, 0.01369027851978899, 0.02354174623178551, 0.00990037246083375, 0.05493429423950147, 0.02675025101780193, 0.009552920255373465, 0.03001308472448727, 0.12622857349924743, 0.041122350812656805, 0.03929784754291177, 0.12491611501900479, 0.17377843527356163, 0.11317686759866774, 0.13357592455577105, 0.10231138032395393, 0.2520500047830865, 0.21710032626288012, 0.15330137859564275, 0.16425948590040207, 0.14054964878596365, 0.1395189095637761, 0.07278556193341501, 0.14433394884690642, 0.12411274015903473, 0.14149964234093204, 0.05912874963541981, 0.08914351346902549, 0.18018155184108764, 0.15620136517100036, 0.11285217056865804, 0.23852182523114607, 0.13080673408694565, 0.11954511064686812, 0.13372203859034926, 0.10529812396271154, 0.10520963769522496, 0.16091643716208637, 0.11698339498252608, 0.11021635888027959, 0.10091627627843991, 0.17035232536727563, 0.30571434705052525, 0.16455134289572015, 0.1768552904832177, 0.13923218823038042, 0.14421020314330235, 0.11434428073698655, 0.13116952555719763, 0.20690542878583074, 0.15700488846050575, 0.09774945050594397, 0.2013372431974858, 0.1873974982299842, 0.1552927982993424, 0.2598892216337845, 0.1485678568133153, 0.11960860138060525, 0.0938906091323588, 0.1712791490717791, 0.1332331117009744, 0.10045084578450769, 0.08791516258497722, 0.16841613629367203, 0.17097531381295994, 0.17541878944030032, 0.10860847367439419, 0.23792105668690056, 0.07109812591806985, 0.18047676334390417, 0.25270217447541654, 0.1872474211268127, 0.15347746055340394, 0.13685663288924843, 0.15243609377648681, 0.16067106829723343, 0.10866040916880593, 0.16860165836988017, 0.09642292090575211, 0.10247676051221788, 0.16297212685458362, 0.1207396863901522, 0.14805929269641638, 0.20765924302395433, 0.09134642299613915, 0.11592076567467302, 0.1494055931107141, 0.12759200268192217, 0.2812175068538636, 0.130446347175166, 0.1577382639516145, 0.13952726614661515, 0.18530277156969532, 0.15943772275932133, 0.11947816150495782, 0.13566842477302998, 0.16865387588040903, 0.22588343621464446, 0.16975143807940185, 0.170469451113604, 0.12076035520294681, 0.10388850350864232, 0.16667416726704687, 0.16109913907712325, 0.11005848180502653, 0.19828327582217753, 0.1892666713683866, 0.150627346301917, 0.15910626476397738, 0.15998113813111559, 0.12091621363651939, 0.2235674753319472, 0.15271944575943053, 0.15842292486922815, 0.13972737884614617, 0.08556510001653805, 0.15595596662024036, 0.10702613319153897, 0.106375804025447, 0.24658064357936382, 0.2174534252844751, 0.09300970952608623, 0.08265757322078571, 0.1366064400644973, 0.17022083164192736, 0.11791734330472536, 0.15320841717766598, 0.11055783586925827, 0.07650629704585299, 0.14314302447019145, 0.07879469456383958, 0.13062045502010733, 0.14310633268905804, 0.15071575093315914, 0.10875653213588521, 0.1987357484176755, 0.0897245854139328, 0.1397450122749433, 0.19243583490606397, 0.10999011516105384, 0.1751614423119463, 0.1463393060839735, 0.11188130782102235, 0.10046236391644925, 0.13487659773090854, 0.16915528569370508, 0.2668644004734233, 0.11228087270865217, 0.11494766906253062, 0.13893461669795215, 0.14143264124868438, 0.13488017488270998, 0.13847902708221227, 0.1602671915316023, 0.10557536064879969, 0.15762467082822695, 0.08657214246341027, 0.12842332682339475, 0.1547902901074849, 0.12905649753520265, 0.20274874870665371, 0.116087734058965, 0.14258029841585085, 0.23326805792748928, 0.14269412902649492, 0.11795727827120572, 0.15833210083656013, 0.11631684988969937, 0.09574044932378456, 0.06344754074234515, 0.11171759004355408, 0.15626189473550767, 0.13621320569654927, 0.12159193909610622, 0.11447370387031697, 0.13274981029098853, 0.12193380942335352, 0.156378768151626, 0.1285311608808115, 0.09217123108101077, 0.18535628041718155, 0.14371584373293445, 0.11806193593656644, 0.2369913534494117, 0.22503311309264973, 0.10722381164669059, 0.13205649593146518], [0.07351752734393813, 0.015466270378965419, 0.055062244209693745, 0.050849632170866244, 0.044977629877394065, 0.042103080413653515, 0.07706719741690904, 0.012697257097897818, 0.07134376937756315, 0.08843379764584824, 0.07663048803806305, 0.0845505396137014, 0.03347806275996845, 0.021678870216419455, 0.05463066678203177, 0.00931952037717565, 0.018976569517690223, 0.050775328345480375, 0.014332764112623408, 0.03962077455071267, 0.015271437132469146, 0.037523416976910084, 0.0705423166800756, 0.09471089753787965, 0.03591775079257786, 0.06973573574214242, 0.05783869659353513, 0.05559778910537716, 0.027495400681800675, 0.009558610672684154, 0.015332459297496825, 0.05486557507538237, 0.030338509059220087, 0.007711931102676317, 0.04781851552252192, 0.0338009341066936, 0.04999727927497588, 0.04102297352801543, 0.01079181984096067, 0.06647264599450864, 0.02141806839063065, 0.03358580404892564, 0.017366905012750067, 0.0375662611622829, 0.03720761829754338, 0.06007152209349442, 0.03844494545774069, 0.017991284985328093, 0.07343104487517849, 0.03997049308964051, 0.12220327582326718, 0.04726832434243988, 0.038059759681345895, 0.002059631656265992, 0.05201549793127924, 0.0651428806304466, 0.030629000502813142, 0.05397431137680542, 0.01739520866976818, 0.04438711410330143, 0.04225596654578112, 0.048667565861251205, 0.02545181541790953, 0.04289078482543118, 0.04280095898138825, 0.038328498776536435, 0.012632652214961126, 0.06575852923560888, 0.027172097034053877, 0.07874300397816114, 0.0528202902933117, 0.042000244720838964, 0.07190107033238746, 0.030703376687597483, 0.04039600717078429, 0.07356590052950196, 0.04494622960919514, 0.025907251038006507, 0.056269518099725246, 0.03725228816620074, 0.08381853709579445, 0.03004932565090712, 0.04186433521681465, 0.10934650243143551, 0.021538762011914514, 0.08567054435843602, 0.03398673077754211, 0.05467174094519578, 0.042837687869905494, 0.06240040747798048, 0.06948156500584446, 0.03569035674445331, 0.0236350787236006, 0.035332697225385346, 0.029034485087322537, 0.06528185520437546, 0.06668150861514732, 0.034221524038002826, 0.049986770463874564, 0.01475443665185594, 0.017293454657192342, 0.02280084907397395, 0.024291335794259794, 0.03614077730162535, 0.015032302308100043, 0.03913306107278913, 0.04645749089831952, 0.06293940707109869, 0.022231694165384397, 0.05256194868707098, 0.024462417532049585, 0.0026232812206217204, 0.029315606916497927, 0.028976597568544094, 0.02478692345903255, 0.05201662970648613, 0.04982857055438217, 0.011535509329405613, 0.05549552115553524, 0.012294472217035946, 0.02519627356377896, 0.03129948454443365, 0.03930009996111039, 0.025214432062057313, 0.07309320440981537, 0.027624790418485645, 0.028732267710438464, 0.03757592392503284, 0.014974781224736944, 0.059009720280300826, 0.07525085777160712, 0.05653665786667261, 0.03308676910819486, 0.0932437829033006, 0.045419719826895744, 0.02454037829011213, 0.0559922591492068, 0.016519235068699345, 0.016518825032107998, 0.024087159836199135, 0.021426369312393945, 0.04946490334987175, 0.04210953709844034, 0.012900999827252235, 0.04113891925953794, 0.02657321725564543, 0.028564974636537954, 0.03954179890570231, 0.040631108422530815, 0.07143563241697848, 0.05437546446046326, 0.03338903101393953, 0.008845280590321636, 0.02930849714175565, 0.05048756800533738, 0.07497561004129238, 0.03084414540353464, 0.053244461087160744, 0.024689065721759107, 0.05852891248650849, 0.04950439302774612, 0.05682124181475956, 0.0191035008901963, 0.05483649772941135, 0.047297980563598685, 0.033542136079631746, 0.04351154311734717, 0.009969801303668646, 0.035254352405900136, 0.018806040679919533, 0.052294812630862, 0.028759560191247147, 0.027188839885639027, 0.0427557102375431, 0.02248705419333419, 0.07252719806274399, 0.05852307178429328, 0.07478507846826687, 0.02594224515632959, 0.054396318810177036, 0.02846095336280996, 0.04581341061566491, 0.023933158627187368, 0.04191502019239124, 0.02827395812346367, 0.06434879003791139, 0.024572518850618508, 0.052035194530617446, 0.05351564926968422, 0.011662902688840404, 0.06789856401155703, 0.03657295957964379, 0.05432089063106105, 0.027306765296088997, 0.006563759070559172, 0.06442621088353917, 0.06670881222817115, 0.020923202464473434, 0.0458768865064485, 0.05253099741821643, 0.003828396852441074, 0.08330758326337673, 0.03794000673224218, 0.06708189728669822, 0.05175632511964068, 0.03670901380246505, 0.04759050178108737, 0.029748342094535474, 0.022637637812294997, 0.06028693045664113, 0.03084874857449904, 0.03998255298938602, 0.05058453702076804, 0.0743107644666452, 0.03449517615081277, 0.0216334452125011, 0.029302674993232358, 0.03126256640825886, 0.0546022870548768, 0.010910058808804024, 0.016405243040935602, 0.006062654465495143, 0.023305420436372515, 0.049665680271573365, 0.05080472481495235, 0.022909297258593142, 0.029706815221288707, 0.058737318686326034, 0.023937002952152397, 0.032581488994765095, 0.02723174158745678, 0.04708181892056018, 0.03419889595534187, 0.004910132520308252, 0.004235905271343654, 0.019815886589640286, 0.05502774176420644, 0.029153649884392507, 0.036584607587428764, 0.08119048827211373, 0.05340785974112805, 0.0476010959391715, 0.03492122828902211, 0.018502454040572047, 0.025192238135787193, 0.033368978183716536, 0.05227176894550212, 0.013346581581572536, 0.019968134474765975, 0.05760612606536597, 0.040452280518366024, 0.06401055623427965, 0.04550702236883808, 0.02108235417836113, 0.06150490611616988, 0.03223004867322743, 0.05128307609993499, 0.017339898258796893, 0.0745262173586525, 0.07497560261981562, 0.014745403786946554, 0.039890671396278776, 0.007975814696692396, 0.019091789799858816, 0.02625473014632007, 0.014612781997129787, 0.04573114354570862, 0.03990749959484674, 0.06473924877354875, 0.055128228559624404, 0.05035223737650085, 0.05348440485249739, 0.01154600051449961, 0.06127524109615479, 0.02880760312109487, 0.06293205238762312, 0.013781296438537538, 0.0380328902247129, 0.014322092029033229, 0.031889636666164733, 0.07244233347591944, 0.03526784093992319, 0.022007246443536133, 0.03310020940261893, 0.046413385061896406, 0.07144863484427333, 0.06712822956615128, 0.09497908744378947, 0.021263208145683166, 0.0731219477893319, 0.026203998786513694, 0.02080793765344424, 0.005601962120636017, 0.030462664799415506, 0.047117111753323115, 0.011207250918232603, 0.026241941086482257, 0.028770146927854512, 0.04229053949529771, 0.028533060431072954, 0.05226728637353517, 0.010300890080543468, 0.06650044684647582, 0.0479698134586215, 0.04484609904466197, 0.04661664817831479, 0.044485997859737836, 0.03599884897994343, 0.06177146700792946, 0.07557508724858053, 0.050383671041345224, 0.03048527432838455, 0.02790932427160442, 0.0798714320990257, 0.016926037751545664, 0.027553195432119537, 0.030581532737414818, 0.030064892198424786, 0.015489325196540449, 0.047906274485285394, 0.02312243464984931, 0.021574060410785023, 0.022098506487964187, 0.05633946922898758, 0.064598745375406, 0.014491964993794682, 0.018143304660043214, 0.13694690773263574, 0.05104549978568684, 0.08816843532258645, 0.06612319833948277, 0.018337318761041388, 0.045333916423260234, 0.01964609618880786, 0.04744708174257539, 0.04665427506552078, 0.07992061422555707, 0.11282154213404283, 0.0224860560047091, 0.07866974658099934, 0.07915706300991587, 0.058335976355010644, 0.03193327494955156, 0.01413670353940688, 0.03774929704377428, 0.016326050317729823, 0.08342931774677709, 0.04498175621847622, 0.03994736405729782, 0.047504579633823596, 0.021094018884468824, 0.019387585743970703, 0.0778002389415633, 0.19624024716904387, 0.09054747875779867, 0.12469612760469317, 0.08712800365174189, 0.13459740177495405, 0.1615512405987829, 0.1509178229025565, 0.1124827962485142, 0.16970932862022892, 0.21915582299698144, 0.2743065980030224, 0.17484301642980427, 0.11103714452474378, 0.167841951479204, 0.11528502713190392, 0.088701957865851, 0.0872108421754092, 0.07416118460241705, 0.23000296438112855, 0.15615502547007054, 0.08252275467384607, 0.1217998072388582, 0.18866516067646444, 0.13857756945071742, 0.14575401874026284, 0.09300357196480036, 0.1634647644823417, 0.12968223192729056, 0.12790910754119977, 0.13038106786552817, 0.16295951034408063, 0.10371480384492315, 0.12586385244503617, 0.12956139544257894, 0.1752381952246651, 0.13596454169601202, 0.16916379070607945, 0.09706323849968612, 0.1190367914387025, 0.08869395009241998, 0.2081648533931002, 0.10451276844833046, 0.18214000534499064, 0.12827563943574205, 0.1964384748134762, 0.10365888301748782, 0.13741487637162209, 0.1526771136559546, 0.13425273355096579, 0.20093737402930856, 0.14354126091348007, 0.11405686178477481, 0.1566199809894897, 0.13953096204204485, 0.1504228252451867, 0.1133220613701269, 0.1260570334852673, 0.06403416395187378, 0.10752510876045562, 0.1299474309780635, 0.07814653989044018, 0.1520391635131091, 0.17177245463244617, 0.19492927298415452, 0.10647786417393945, 0.1509080859250389, 0.15340953919803724, 0.10700878920033574, 0.190136453602463, 0.114462675555842, 0.07302572092157789, 0.17787316086469218, 0.09639119409257546, 0.2199678067700006, 0.17726369434967637, 0.10976440578815527, 0.11381581964087673, 0.0960451528953854, 0.1355427791713737, 0.18581605574581772, 0.11814067780505866, 0.12550166953587905, 0.2308579778764397, 0.09105749748414382, 0.2107221755431965, 0.12421164617990144, 0.2178435426321812, 0.14728780050063506, 0.11426905664848164, 0.20297154143918306, 0.10680043866159394, 0.11618288481258787, 0.14689201314467937, 0.16070777492132038, 0.19840200460748747, 0.20092208578716964, 0.12583983654621989, 0.12785791419446468, 0.16426861431682482, 0.11359825162799098, 0.09372328451718204, 0.0963561276148539, 0.1007445581490174, 0.12621695146663114, 0.10053484948002733, 0.15587971836794168, 0.08459678283543326, 0.11562562838662416, 0.17630522546824068, 0.15849500225158408, 0.15337232791353017, 0.08306611067382619, 0.08697160345036536, 0.13278167811222374, 0.12001457100268453, 0.09614174341550097, 0.10953227683785371, 0.17081906204111874, 0.2102670757449232, 0.17836593207903206, 0.1261307584354654, 0.13434703083476052, 0.09481004104600288, 0.1757389964768663, 0.10686458990676329, 0.1593102960032411, 0.14530515298247337, 0.10011820777435787, 0.1681084863957949, 0.16949386830674484, 0.22123524657217786, 0.17951066518435255, 0.2064922751742415, 0.11321816069539636, 0.15173192921793088, 0.17818413558416069, 0.11065723170759156, 0.10877121923840605, 0.18320133589440957, 0.12603545183083043, 0.11545886038220488, 0.14961562090320513, 0.11521668275236152, 0.10664038709364831, 0.10823883218108676, 0.09723197319544852, 0.12239589283126406, 0.23505396209657192, 0.09015509785967879, 0.11850355833303183, 0.19570839445805177, 0.13971001259051263, 0.19692297850269824, 0.1672365519334562, 0.13932480826042593, 0.1267935408395715, 0.10823396369232796, 0.1308022515149787, 0.0895760148705449, 0.20910190389258787, 0.19924501015339047, 0.07559266872704029, 0.1606700589763932, 0.18545744998846203, 0.1307961659040302, 0.11852277253638022, 0.09100778843276203, 0.17683445097645745, 0.09412503874045797, 0.13002088875509799, 0.07213472068542615, 0.15316449687816203, 0.10758833974250592, 0.11866303102578968, 0.16344129777280614], [0.07483699169824831, 0.02295716021762928, 0.011363808825990418, 0.040868473224691115, 0.00490369717226713, 0.008540961080143461, 0.05754099889600184, 0.020259444136172533, 0.015343262184615014, 0.03428862532018684, 0.0411510348203592, 0.028518428989627864, 0.03770925817661919, 0.04209908394841477, 0.04347683287051041, 0.0742721208371222, 0.00916151157070999, 0.05098423920571804, 0.034394440735923126, 0.013400261123024393, 0.10787961044115946, 0.05204016692005098, 0.009861487633315846, 0.0261911169582163, 0.0071297357317234855, 0.05053928085544612, 0.0919668139249552, 0.09964327036868781, 0.0152847484787344, 0.048983802407747135, 0.015698503229941707, 0.060343430159264244, 0.03890113250236027, 0.005414626421043067, 0.05328164639649913, 0.016929377416090574, 0.04005060422059614, 0.04995578208763618, 0.021190991610637866, 0.04258606641087681, 0.015781069014337845, 0.053635005169780925, 0.03883392360876314, 0.07392981264274567, 0.01809944002161501, 0.05340926982171368, 0.05567274602071848, 0.02688510481675621, 0.04589212279825006, 0.019729864252440166, 0.11587869332288392, 0.054003937912057154, 0.04231723454722669, 0.04493008789722808, 0.006634004275838379, 0.06984112813370302, 0.06641160434810445, 0.024954060681920964, 0.031265011784853414, 0.00652251885185251, 0.0918159872526303, 0.0275905403032084, 0.03421216555580031, 0.01855640446592588, 0.06035496684489772, 0.009374579385621473, 0.02479373823007336, 0.042624858469935134, 0.0927170658542309, 0.02499642432667315, 0.10140098776901141, 0.022358313835866284, 0.06316382510703988, 0.059473610817804, 0.040788543919916265, 0.030355548769875895, 0.02718478033784777, 0.07220178857096471, 0.03764729626709595, 0.01940829723025672, 0.0776228062750306, 0.06424978753784671, 0.03977236934588291, 0.020775797092937864, 0.012604298462974839, 0.07301950914552435, 0.041685718824737705, 0.04292658602935262, 0.011096615253336495, 0.02196027220634278, 0.03662186340079643, 0.019713948895514477, 0.07835724303731695, 0.03481778774585109, 0.08206984421121888, 0.05087075740448199, 0.035227223197580315, 0.015134398636291735, 0.031103275541681796, 0.03969118210079614, 0.045423541887430474, 0.01115351757107419, 0.0235687715394306, 0.092508559464477, 0.02081997528875945, 0.10667497859685682, 0.03269191314757336, 0.02607608592370525, 0.03494899945508223, 0.027664951740007382, 0.036571976233972237, 0.11909020380699076, 0.015881746912782546, 0.04997840274882037, 0.05275038740364835, 0.04160088021308184, 0.010984155760525027, 0.04186520352959633, 0.04647267523978371, 0.03930022612621542, 0.03462856977421325, 0.07278677905560471, 0.06673015639535151, 0.07055904468870722, 0.06294223465374671, 0.016553201312490273, 0.02851237677532481, 0.03739063562534284, 0.03215313990949653, 0.023002347734291106, 0.041446917966823094, 0.018450284769642167, 0.045116968103684485, 0.06839202542323619, 0.0700020999647677, 0.007301065625142655, 0.0661368464352563, 0.058218754129484296, 0.04074257900356315, 0.0358761793904705, 0.07828551446436904, 0.030983786055003293, 0.060035616988898255, 0.03664626150566619, 0.07877492374973372, 0.048846015270100906, 0.10122348088771105, 0.015460784052265808, 0.03028668674232904, 0.023369365735561587, 0.03935966102289967, 0.03318607217806857, 0.09391147090354934, 0.033007296224241145, 0.08535136890714057, 0.027860342524945736, 0.03461149666691199, 0.0327262300561415, 0.011622328547673533, 0.02579393250925932, 0.04168862433289178, 0.03696231251524296, 0.04936553719744552, 0.02283514000737341, 0.08478905845549889, 0.027929724055866245, 0.11365801678039134, 0.03824398299911991, 0.014065200393815758, 0.020227233071636874, 0.03246120541007258, 0.06162248086184263, 0.035518364020390436, 0.011567352103156736, 0.07555950214737095, 0.04845671799557749, 0.05961221431789454, 0.024365539429709315, 0.047269738133763894, 0.015515839349973248, 0.03680070243717637, 0.010261494098813273, 0.08765893609961495, 0.0175659082015045, 0.03791813935094979, 0.06193668763444293, 0.03409807148273103, 0.0265400042917463, 0.07505539833800867, 0.02043148509983439, 0.02291219905600883, 0.027011160455003846, 0.085952775698388, 0.07882912279455923, 0.014690169446112122, 0.033115430851466954, 0.032939578959485516, 0.06504453122033738, 0.042393761104904115, 0.013417066129477462, 0.015987987208063714, 0.029530454958148766, 0.04641842424462084, 0.021884415436943527, 0.0770105715491809, 0.033771927264751866, 0.01282083489059005, 0.010909608881775057, 0.02804003317578463, 0.025901922417688183, 0.03167523391311988, 0.025286856398452073, 0.039247166278073564, 0.01800260830350453, 0.06929645111085847, 0.03405250361538492, 0.0245870834987727, 0.019549672651919536, 0.005704208269889932, 0.06540969014167786, 0.04169537787674926, 0.053434729197761044, 0.0148831426849938, 0.03632144944276661, 0.031975866804714315, 0.015548789779131766, 0.09306326290243305, 0.04224119780701585, 0.02523246996133821, 0.054838353098602965, 0.028795099788112566, 0.02559817807195941, 0.03410606070247013, 0.040184747413150035, 0.032250988369924016, 0.013983189364807913, 0.019198286136088427, 0.014714108347106958, 0.026435639774717856, 0.0286240124842152, 0.04702877391537186, 0.015710685584053863, 0.03754119141376577, 0.0897645129589364, 0.041726926574483514, 0.0076211497434997, 0.03987031428550836, 0.03284844693553168, 0.04161401993769687, 0.009225147023244062, 0.021917569029028527, 0.05011417124478612, 0.08664847235195339, 0.04021555767394602, 0.0429229161090916, 0.08024828726775013, 0.038198099719011225, 0.04287262818252202, 0.029782462333969306, 0.04460547621420119, 0.005301242954374175, 0.029884075338486582, 0.03498485260934103, 0.004179016868874896, 0.035067642893409356, 0.049499821398057975, 0.044573430277523585, 0.06656122874119319, 0.0654304405907169, 0.044859773115604185, 0.06875455714180134, 0.011393120876164176, 0.03543817496392876, 0.009963698994397419, 0.014301123574114172, 0.03081273585848976, 0.033279107810813, 0.01750231171172345, 0.0369093639892526, 0.09607285726815462, 0.04222870746161789, 0.019217552289774176, 0.017295154175371863, 0.03575836344680283, 0.061586598021676764, 0.036623099076678045, 0.05933841377554927, 0.028981553259654902, 0.03450221171078738, 0.021402616876002867, 0.11417593195801601, 0.021453958652273286, 0.06163701953482814, 0.058431698562344536, 0.03283194157120306, 0.03947915422031656, 0.06805097887990996, 0.04062066269398201, 0.05198001585085876, 0.04897189464827534, 0.0060389242935343646, 0.027272337065369356, 0.06865541363367811, 0.03581183518690523, 0.06393254167051055, 0.030067699372011703, 0.018720604639383964, 0.01687661813775776, 0.04443496036401484, 0.04252280945365783, 0.01867435399617534, 0.032733061525505036, 0.005718989532397245, 0.05305321334162727, 0.03597128561523277, 0.06364616914652288, 0.03236759461287875, 0.01607882608368527, 0.04506351862801239, 0.019234797946410254, 0.024688831945240963, 0.04550626908894628, 0.0741309866134543, 0.023095529941201676, 0.03741772772627883, 0.044698344863718376, 0.02375241969275521, 0.04140290118812118, 0.014461261416727211, 0.06804496748372912, 0.07463808869943023, 0.061023152084089816, 0.032555944271734916, 0.022020616233930923, 0.04935220080369618, 0.0657562434207648, 0.017749873622960877, 0.007301680216187378, 0.05690268510079477, 0.029309454512258526, 0.04587608127621934, 0.03273812297265977, 0.04811427621461917, 0.027813505585072562, 0.018857811046473216, 0.05137511354405433, 0.008285270796477562, 0.08982927276520059, 0.0539402542199241, 0.02384338658885099, 0.04423742662766017, 0.003718772131833248, 0.10462403122801334, 0.11422375595429912, 0.14331852755276486, 0.09377553171361797, 0.0991367842652835, 0.07708632256253622, 0.21596583479549736, 0.1599715941119939, 0.11789934622356668, 0.22355145978508517, 0.1460691198008135, 0.08749576008995064, 0.13919561519287527, 0.21954221476335078, 0.06885989016154781, 0.16870977444341406, 0.3021360671846196, 0.11678552356897853, 0.13437686517136171, 0.11604456332861446, 0.16465752938529477, 0.12740864767692983, 0.140070503402967, 0.12165251318947412, 0.09213699580868706, 0.19156256457790732, 0.1433122341404669, 0.12219534226460382, 0.15538529958575964, 0.2258753913338296, 0.1528581086313352, 0.13400068535702303, 0.12027456759824418, 0.12832997948862612, 0.2160186757100746, 0.1823211635928601, 0.1320273888995871, 0.10684189503081143, 0.14374545542523265, 0.09463453796342947, 0.11750153280445375, 0.1349468345870264, 0.13804865564452484, 0.16193113115150481, 0.0753021401760634, 0.14282654301496223, 0.11423342613852583, 0.11289511865470558, 0.15865953639149666, 0.13088191364658996, 0.25020078057423234, 0.13950342836324126, 0.14618238637922332, 0.19265485752839595, 0.15017074736533687, 0.12603479874087498, 0.22470449010143057, 0.16353847458958626, 0.11700784874847159, 0.08754339854931459, 0.1877324443194084, 0.10052494923002087, 0.13055480463663116, 0.23273604194400832, 0.19375801552087069, 0.21716213232139125, 0.11458734152256511, 0.12118193219066598, 0.14698984305141494, 0.12759660399751738, 0.20522231206996366, 0.09656261536292732, 0.13814713864121586, 0.20081499387742952, 0.1608406490413472, 0.29939668136648834, 0.209652696212288, 0.19840944092720747, 0.129479402967263, 0.190434574324172, 0.21649093396263197, 0.2796253626001999, 0.1406981673790142, 0.1479492025100626, 0.0796050085045863, 0.18875881971325725, 0.21013516641687602, 0.12129330629250035, 0.08853762410581112, 0.09974082568078302, 0.10813585176947527, 0.16414706537034363, 0.1886698362068273, 0.22334288660204038, 0.1843380686477758, 0.08480133357807063, 0.2163719231612049, 0.058215217795805074, 0.12857891066232696, 0.13805609196424484, 0.1950452261371538, 0.11628664447925985, 0.23442387871909887, 0.2245846184086986, 0.11157063738210127, 0.1930533759878017, 0.15191236016107723, 0.10709495996707119, 0.17617727920878679, 0.1386430417187512, 0.18438301311107352, 0.35667837015353143, 0.10951521486276761, 0.10716049902839586, 0.23779270966770127, 0.11718929643393494, 0.11729271471267566, 0.16349434648873284, 0.15800920722540468, 0.18775234872009605, 0.09832191353780217, 0.15826861752429977, 0.12133345648180693, 0.16298143338644877, 0.09216631806339137, 0.11351298628142104, 0.1870250588399358, 0.08861394657287747, 0.1679369612247683, 0.1344282366335392, 0.12449997797375545, 0.1475041513913311, 0.14305641583632678, 0.23546343465568498, 0.16829194530146196, 0.09484660666203126, 0.13004342035856098, 0.22929936385480687, 0.16404830035753548, 0.19173883949406445, 0.12278042180696502, 0.12356631908915006, 0.17859789775684476, 0.13574358948972076, 0.13438854657579213, 0.14498969569103792, 0.14620656555052847, 0.1585000636987388, 0.1267201275913976, 0.0568737302091904, 0.09245893204933964, 0.14748875924851745, 0.21807957527926192, 0.283364302595146, 0.2631466859020293, 0.1651016008690931, 0.09526456939056516, 0.08817958238068968, 0.11172703016200103, 0.16412518685683608, 0.11639716511126608, 0.13684789038961753, 0.2215557504678145, 0.09000839752843603, 0.23301204666495323, 0.13353044574614614, 0.2096142529626377, 0.11692757805576548, 0.11696607325575314, 0.13029260386247188, 0.06988740104134195, 0.1872261511744, 0.1024100933864247, 0.11582154053030536, 0.16353476385120302, 0.14205332903657109], [0.006722889447701164, 0.011495056714920793, 0.08744018065044656, 0.03837544332782272, 0.05159766507858876, 0.01565121357998578, 0.03563428748748265, 0.035865514728357084, 0.009755279806995532, 0.07671761617530137, 0.06192565931996796, 0.05306278333591763, 0.03344774973811582, 0.08737928001210093, 0.06659828417468816, 0.03005124039191287, 0.036848459640168585, 0.05092462248285301, 0.021218415822659153, 0.10601464528008364, 0.03322566575661767, 0.03655117383459583, 0.014932784015400102, 0.05391855753259733, 0.03708257012476679, 0.05127661570440978, 0.02877741069823969, 0.04839402135985438, 0.04938354170008097, 0.030242890752560925, 0.04666634980821982, 0.02596152429759968, 0.04156069291639142, 0.03437220599153079, 0.001291568530632503, 0.0250295222576824, 0.0267869743402116, 0.011285371238045627, 0.003343036214573658, 0.0706887869455386, 0.02057015910395421, 0.012205424700368894, 0.03264047860284336, 0.04006286078947596, 0.004381377348181559, 0.048832255852175876, 0.028072203422198072, 0.04774046756210737, 0.030300657672341913, 0.0761663488810882, 0.03725730137375649, 0.013511800352716818, 0.01150161730038235, 0.05288863096211571, 0.0244965637466521, 0.07837201177608222, 0.045212916666059755, 0.005632090069411788, 0.05399358495196793, 0.07149604323785752, 0.023742254124954343, 0.05277577256492805, 0.039518350749858655, 0.04586602888593916, 0.07316733754123561, 0.012816290163755184, 0.07549852729425766, 0.017109641376009677, 0.03372531296918169, 0.013144797194399871, 0.01262859452253906, 0.010573805611784337, 0.05375158543756697, 0.01950108980963705, 0.020927154400851578, 0.04523833151324652, 0.03723349698702805, 0.01677128140727291, 0.017393587077094708, 0.04008705851447303, 0.06916709477081895, 0.02438106144836638, 0.06712671558489092, 0.04388873967400286, 0.03248411179811228, 0.02884734327381011, 0.047947255879989825, 0.011066825445595896, 0.03529781257384457, 0.06650948620517738, 0.01999188320041867, 0.03594827532651834, 0.03866492545057554, 0.02870691409043502, 0.006004373144605779, 0.031450185051653534, 0.015401756409119116, 0.1083936812938191, 0.021959672922093887, 0.02834903007169487, 0.033296897090622224, 0.08482439210638404, 0.03195548000803683, 0.034747536046779715, 0.020766375528182834, 0.026666442136047408, 0.023136863856052514, 0.07405035226838663, 0.049344371145707555, 0.044790011233999394, 0.018935395164589863, 0.07360714909736998, 0.038519030349561945, 0.01689728695055237, 0.0651723142073024, 0.028185356823087204, 0.034217724241898395, 0.087379532342311, 0.010179782711929874, 0.0728096891543828, 0.02143028970749583, 0.01779414087650366, 0.06927839465788566, 0.055266431299969554, 0.0367723449744517, 0.040033876211964525, 0.01644232073886087, 0.022395862797566224, 0.05054502878920175, 0.04781331306730863, 0.027224587283853907, 0.02091229474899592, 0.036986365521443076, 0.08331274861120619, 0.030995781016827095, 0.027357233193470165, 0.020020210977236275, 0.035553167035686783, 0.05526064625883009, 0.022151634984766133, 0.014581111772713484, 0.026288987683074083, 0.016682279347151052, 0.06421056503313594, 0.05371140556235332, 0.059006057781516574, 0.03347231853695121, 0.04702756050392054, 0.03347765828948468, 0.06133358874649275, 0.04982394697435666, 0.061395884622470476, 0.04428398155141622, 0.07945749181089923, 0.03151625845930539, 0.004060779292558436, 0.01622638916160213, 0.04298091495002154, 0.04237006804032717, 0.020508863271970768, 0.051048843160970137, 0.027592224978434388, 0.020668428733188193, 0.008514474757248536, 0.06997276286710985, 0.0232870096078841, 0.018812744128808845, 0.04895886995655019, 0.028951269923709333, 0.04879010186414234, 0.023898374165582936, 0.03784671876928769, 0.028147214143245947, 0.054438662045868114, 0.03241974161937833, 0.029206485232862178, 0.04941625185892917, 0.03285134873294737, 0.047663666409789585, 0.03314258603495546, 0.06846273725386709, 0.007687958805036033, 0.07251758725033142, 0.03570944107195828, 0.040811517101246864, 0.020114493418077473, 0.050522552846814506, 0.027449259505374357, 0.055253202517633326, 0.02828524990036385, 0.07510107010602951, 0.010397349797131028, 0.018890923820436, 0.01517095497547416, 0.14839576761005446, 0.038168321043485776, 0.056295578615390696, 0.03369893704075366, 0.05642871619784273, 0.06554520630743355, 0.03184840294125024, 0.06681678729364648, 0.09251111245248467, 0.03514746087603271, 0.030465633390122093, 0.03652801882708445, 0.018435825877531897, 0.029794644688081462, 0.06068430229788646, 0.05871840134204831, 0.013705046330869664, 0.010746337320597377, 0.0446746146917576, 0.04037171667732764, 0.05443723341159057, 0.055756471410859376, 0.008002948543435195, 0.04345298766565975, 0.03296577306173276, 0.07551437956863083, 0.0059237754430796485, 0.04961613449268043, 0.04314508172683418, 0.04241745045874268, 0.024931742445915006, 0.049279785744147375, 0.053041179417050444, 0.039945786993484944, 0.008483811998303281, 0.0799357911455445, 0.044511898813652806, 0.07056235466734506, 0.03174165241944138, 0.08419102101470344, 0.04655688302591443, 0.054158942875801586, 0.0710208089731168, 0.029069037627778016, 0.012020417489111423, 0.020835066861764062, 0.03218541220121551, 0.02426402847049758, 0.06625170120969415, 0.046656289996462874, 0.02123466329067014, 0.07102384435711429, 0.01857784140156582, 0.041916749396477826, 0.05447891613584943, 0.053210081096040085, 0.04940624399750959, 0.02451663327519782, 0.04366789507912472, 0.03980140216299333, 0.028477475425461307, 0.048051490521174856, 0.030295314209070057, 0.08656279882416129, 0.010345058999519097, 0.0037309941444618744, 0.04204116303299088, 0.026336750452173874, 0.02680045916349627, 0.006370625806084718, 0.06257271932554431, 0.011464605468063382, 0.037715269572800025, 0.026637173687049653, 0.027771075147029478, 0.03383863891940564, 0.029973177588544786, 0.060463101472123526, 0.04612026641552802, 0.04766587800986599, 0.02865206010028487, 0.05465674214065075, 0.0576112988346722, 0.05402051749115344, 0.09156327854725532, 0.05077442663605325, 0.005725222645196482, 0.01934497347974684, 0.01695476999884704, 0.06458232906879857, 0.03594613051973283, 0.017744465221767314, 0.056545211118645966, 0.03995430684881285, 0.045301829668460414, 0.0415885160327889, 0.04090648973942734, 0.02887676757381996, 0.026187242947344203, 0.046669281291542575, 0.07011611611233093, 0.026948972190439235, 0.03702982568938751, 0.02407402753306087, 0.0414001292665489, 0.018521176571084652, 0.03134065889753401, 0.0022306498476609704, 0.01866923317720648, 0.034483617200748995, 0.09211542899720371, 0.0093488120182883, 0.03387640310393181, 0.023224875149026047, 0.07265006061061285, 0.017591974283277523, 0.012170259888080182, 0.046172472793841735, 0.03260560508351773, 0.07500879146391526, 0.064016011019703, 0.025582793350622524, 0.016488374712935183, 0.027358531951904297, 0.049156362874782644, 0.0395854446105659, 0.01580433534400072, 0.039639498936594464, 0.0295028266555164, 0.04352447132987436, 0.06339677041978575, 0.013733652413066011, 0.04299369844375178, 0.023758894931233954, 0.03413716782233678, 0.026986059165210463, 0.013370471315283794, 0.017532897472847253, 0.04539291716355365, 0.04341232168371789, 0.03542046732036397, 0.03327135607833043, 0.06798394810175523, 0.04886299560894258, 0.06136141557362862, 0.028478507010731846, 0.01969602602912346, 0.0454609164444264, 0.01359952870188863, 0.053444429067894816, 0.04808006691746414, 0.043658169233822264, 0.04235329179209657, 0.06730473454808816, 0.04665875392674934, 0.035654626044561155, 0.03561705110769253, 0.03179824860126246, 0.21176247362745926, 0.08580741865443997, 0.17602552485186607, 0.21260438079480082, 0.1989131810842082, 0.08940198124037124, 0.13849640818079934, 0.20327184407506138, 0.10863473085919395, 0.13055327581241727, 0.13193160732043907, 0.19667851505801082, 0.1321234376518987, 0.18026749254204333, 0.1643609968596138, 0.08371849558898248, 0.10955442994600162, 0.14985457761213183, 0.29652356053702533, 0.14503005368169397, 0.12774886301485822, 0.10699486650992185, 0.15556773432763293, 0.25671615439932793, 0.114054694713559, 0.17015014949720353, 0.18413874262478203, 0.12785132392309606, 0.08121174338157289, 0.1428741295239888, 0.09776937717106193, 0.0859710993245244, 0.11418522364692762, 0.18646328273462132, 0.06988508554059081, 0.11871399430674501, 0.11751420868677087, 0.06085248780436814, 0.10792765708174556, 0.1347493936191313, 0.13887107401387766, 0.1118929372751154, 0.11633491376414895, 0.14758483768673614, 0.09493905599811114, 0.0910920296155382, 0.13675276190042496, 0.12308553355978802, 0.08551415900001302, 0.1639679109212011, 0.2215252778842114, 0.14755418698769063, 0.11503582878503948, 0.1931923654046841, 0.14354445214848965, 0.15142451680731028, 0.11416338224080391, 0.20757524674991146, 0.14057470369152725, 0.15603524283505976, 0.1350582903251052, 0.20820440986426547, 0.10631307770381682, 0.13188725657528266, 0.21940105827525258, 0.09591009686118923, 0.15522103261901066, 0.07225022854981944, 0.10755866125691682, 0.153108153026551, 0.14933759754057974, 0.1585836146841757, 0.1754663759493269, 0.2046548659563996, 0.10264902040944435, 0.10358632323914208, 0.08525465222191997, 0.08780450094491243, 0.14770270558074117, 0.11914783899555914, 0.12661719170864671, 0.17806622316129506, 0.19813414866803214, 0.1331604109145701, 0.20882739830994979, 0.1525831874459982, 0.2104169302037917, 0.09869718793197535, 0.15774049039464444, 0.1693909175810404, 0.06673394134850241, 0.11301697930321097, 0.15648741857148707, 0.37451176322065294, 0.11439878406235948, 0.17533658916363493, 0.0727291290240828, 0.13721740571781993, 0.08605540730059147, 0.08791126630967483, 0.159385297447443, 0.2265499293571338, 0.3115413343766704, 0.146410285087768, 0.11099613344413228, 0.18111921090167016, 0.09871033878880553, 0.20293075300287455, 0.13353365182410926, 0.14023760537384078, 0.1654333111946471, 0.18194536969531327, 0.1902102676103823, 0.12524113117251545, 0.12299026406253688, 0.08048496558330953, 0.10765519982669502, 0.14065561263123527, 0.11863419116707519, 0.10644886846421286, 0.12795060843927786, 0.13078154559480026, 0.16146381560247391, 0.09915740112774074, 0.1368693236145191, 0.23062681371811777, 0.08758016454521567, 0.128178047016263, 0.11576377917663194, 0.13289006135892123, 0.3140434407396242, 0.12016497465083376, 0.2761218318482861, 0.14520379045279697, 0.18210549547802657, 0.13101734075462446, 0.13885897700674832, 0.19858798681525514, 0.154251090134494, 0.17112071538576856, 0.10562728872173466, 0.1546801850781776, 0.08940480882301927, 0.1430938349221833, 0.11207687115529552, 0.1777421124279499, 0.23998908087378368, 0.10811787695274688, 0.10271459657815285, 0.14286121615441516, 0.1424457025132142, 0.11852105817524716, 0.10999995603924617, 0.15452100924449041, 0.09702310315333307, 0.2598211815347895, 0.10134463649592362, 0.1300707907648757, 0.1511715038213879, 0.10855356958927587, 0.15099960757652298, 0.09621912715374492, 0.12319128960371017, 0.09008517270558514, 0.14741723105544224, 0.16104594193166122, 0.1302967598894611, 0.12441652346751653, 0.19631821720395237, 0.13002123014302924, 0.08919938234612346, 0.12336881132796407, 0.09996263877837919, 0.131155276321806, 0.13405143341515213, 0.12161866383394226], [0.053668802574975416, 0.03587882514693774, 0.02742321383266244, 0.029845953067706432, 0.035013269443879835, 0.028626149869523942, 0.017694676389510278, 0.04308939467591699, 0.03385327407158911, 0.030590074857173022, 0.016872070627869107, 0.008747785577725153, 0.05795317658339627, 0.06489926323411055, 0.06509096740046516, 0.02167618920793757, 0.03660536545794457, 0.030182838017935865, 0.02963944491057191, 0.049511046381667256, 0.050786241627065465, 0.009399240025231848, 0.07833457042579539, 0.03820448589976877, 0.09302956197643653, 0.009074017925740918, 0.063910885801306, 0.03642562100139912, 0.01619885919353692, 0.05361831055779476, 0.017747303936630487, 0.05392619794292841, 0.030812225631962065, 0.02371476497501135, 0.048290577105944976, 0.02947718730865745, 0.020497053847066127, 0.04445583326742053, 0.0676998910785187, 0.03575203663785942, 0.047315365372924134, 0.0676653663686011, 0.0341587643197272, 0.010561767976469127, 0.02218181442003697, 0.04973639210220426, 0.0658544221369084, 0.043976027372991666, 0.04706083098426461, 0.019716915630851872, 0.014426606830966193, 0.03533618903020397, 0.015896252189122606, 0.12122732936404645, 0.03017876919329865, 0.030297631565190386, 0.04595292695739772, 0.03845288272714242, 0.07656738322111778, 0.039273089496418834, 0.0320731401006924, 0.05676820052030962, 0.030253056320361793, 0.041425963427172974, 0.047550355302519165, 0.02719312578847166, 0.016058207365858834, 0.047377312439493835, 0.04432029483723454, 0.0523218787566293, 0.03398572145670187, 0.07382111027254723, 0.027445083069324028, 0.02941161670605652, 0.05562008693232201, 0.019701681194419507, 0.01823360176786082, 0.056765384069876745, 0.05925397592363879, 0.025658958111307584, 0.05730149299779441, 0.08346025046193972, 0.035450932482490316, 0.07055258058244362, 0.03944320087612141, 0.019036162120755762, 0.05762842389231082, 0.05408503609942272, 0.02111952650011517, 0.033276562244282104, 0.046618043415946886, 0.03130682438495569, 0.12355775470496155, 0.021157973460503854, 0.1336071392870508, 0.0012036570797135937, 0.05753124336479232, 0.08402984880376607, 0.04174424087977968, 0.0454009620443685, 0.008253962369053625, 0.01952262879058253, 0.09596694537322037, 0.01435272231901763, 0.00897228803296457, 0.03388660021300893, 0.07136350308428518, 0.06013977741531562, 0.02857741117622936, 0.06317647872492671, 0.025023316047736444, 0.038384594008675776, 0.014174759016896132, 0.036581579624908045, 0.07366022007772699, 0.03263915757997893, 0.054616951892967336, 0.07271473878063262, 0.03839700642856769, 0.03770697978325188, 0.035671105433721095, 0.04883192559645977, 0.08646247530123219, 0.01984965245355852, 0.029568389836640563, 0.04715262351965066, 0.04221661416522693, 0.03784041422477458, 0.0778063022880815, 0.0615976337576285, 0.03541589940141421, 0.03853994407108985, 0.04748648978420533, 0.01930438356794184, 0.057532215578248724, 0.09115183187532239, 0.056971066587721, 0.01836457413446624, 0.04088170200702734, 0.030068278247199487, 0.024070565414149314, 0.033499410637887195, 0.06146047744550742, 0.009018152759381337, 0.03465964720817283, 0.039281572244362906, 0.032177953617065214, 0.03569237167539541, 0.05706687785277609, 0.012816792041121516, 0.07592486887006089, 0.03269576860475354, 0.03129705772153102, 0.10009171310230158, 0.01038611739204498, 0.030675128691655118, 0.009805749559745891, 0.0060994960676907795, 0.028328539374342654, 0.0481327927991515, 0.017096728006436024, 0.06456217975937761, 0.020653535684687085, 0.015899038953648414, 0.01882453500002157, 0.019168340477335732, 0.05095968896057457, 0.025702806051413063, 0.02779081627522828, 0.06045095251465682, 0.018058623754768632, 0.05811094604723621, 0.021109743138367776, 0.04513451989623718, 0.02729912488575792, 0.01648304609261686, 0.023813372281438205, 0.024363392767554615, 0.008004575702216243, 0.01434645673725754, 0.04708361862867605, 0.024749916265136562, 0.01704688351310324, 0.08957458252552897, 0.014193668012012495, 0.017773832005332224, 0.03733937548531685, 0.03171962918713689, 0.05239680969680194, 0.05065828423539642, 0.032149841063073836, 0.030200432483979966, 0.03068390829866985, 0.07871947789681144, 0.03252740869356785, 0.017207094642799348, 0.06384451553458348, 0.010701882674766239, 0.01676141455391189, 0.031000050221337005, 0.03987843338109087, 0.03167323382513132, 0.068587314162869, 0.06056633421394508, 0.0747518525167834, 0.032084691629279405, 0.039079288762877695, 0.04125545499846339, 0.04273313781595789, 0.041882985387928784, 0.021724328616983257, 0.012858683494414436, 0.08727782100322656, 0.03078427820582874, 0.041619445037213154, 0.0319906095683109, 0.022765439352951944, 0.03992309211753309, 0.0028874544841528405, 0.03288189553131815, 0.06414453615434468, 0.0023858962413214613, 0.0935673741332721, 0.051720998890232295, 0.039158346044132486, 0.08505876234266907, 0.05600419288384728, 0.012536852082121186, 0.0016107142960208876, 0.04421766694576945, 0.01602313346666051, 0.10386216468759812, 0.044315994091448374, 0.03790400143770967, 0.07594394206535071, 0.035991026743431576, 0.03949945567001123, 0.0030246316691773245, 0.021102837454236578, 0.06307505682343617, 0.03916711451893207, 0.01841688441345468, 0.018449294002493843, 0.02450456224323716, 0.01373941147903679, 0.03090343001531437, 0.0034522968189776293, 0.021368337074818555, 0.036327564739622176, 0.024190741387428716, 0.011650840933725704, 0.02534876264689956, 0.04816908010980114, 0.03726878981979098, 0.06411183712771162, 0.04394247487653047, 0.06385444547049701, 0.08892446116078645, 0.04028937539260369, 0.09375605775858276, 0.05170553253265098, 0.06195418747665826, 0.04253104729286861, 0.04247161610692274, 0.08238944268669002, 0.025706127162266057, 0.07074349065078422, 0.00976047669610125, 0.05523159488802776, 0.04152500674535986, 0.07979913949384354, 0.025808888640312944, 0.04091326925845351, 0.015404356709041167, 0.030739203866687603, 0.12016458131256513, 0.06489103281637654, 0.04580583699862473, 0.007601504630656564, 0.03572088869987056, 0.018318507172807585, 0.003030647008017695, 0.019538473643478937, 0.02219172580225859, 0.03742852968571242, 0.04768189726746641, 0.029147091154300142, 0.03748650255147368, 0.032085908751469105, 0.08387832451262511, 0.04600048378051724, 0.04250697202223819, 0.02557079838879872, 0.12886352429632097, 0.041050421859836206, 0.06255933840293437, 0.079152387479553, 0.036390565655892715, 0.03399557346710935, 0.0927378014603164, 0.025103163716266863, 0.08736989926546812, 0.05926517493207939, 0.04927014153508935, 0.08222804783144966, 0.07630550157045946, 0.024805184002616443, 0.06126579726696946, 0.014031170139787719, 0.025742820798768662, 0.01762899260938866, 0.026557133060123306, 0.0518800374265993, 0.02429460124403704, 0.03249243869504426, 0.04607126240443904, 0.03772832023969386, 0.05906788239371963, 0.03008004314324353, 0.03735461177711841, 0.014363579939526971, 0.02375199481321033, 0.049083962658187374, 0.08013514685444534, 0.041777904698392376, 0.009148672415904002, 0.0386856053955853, 0.026146851560042705, 0.02437573468341725, 0.045389930019155145, 0.024702880800759885, 0.00644757585178013, 0.01041812251060037, 0.00988920499366941, 0.038439676209236495, 0.05488047368999105, 0.021557709042099304, 0.016010019717214163, 0.06277991953538731, 0.03779341030167416, 0.06482495198724791, 0.0478279927483527, 0.06848334669484757, 0.040152144865714945, 0.08279643647256307, 0.040628021088195965, 0.0694674790429417, 0.020965042895113584, 0.00189836679282962, 0.035496296259225346, 0.00498417752169189, 0.03146981485770084, 0.11257071848376654, 0.12860046263085678, 0.1340534965856932, 0.14306123979622498, 0.11957776514464058, 0.10967213456751779, 0.14544340025167912, 0.21682757214875892, 0.27423137391451746, 0.1280201625195332, 0.147543307102751, 0.09794478377443738, 0.10453201975906268, 0.16690168005879968, 0.15370939654530957, 0.1098734643892385, 0.06936129997484386, 0.14061046036658809, 0.1476109167560935, 0.10408983333036304, 0.20676154119428247, 0.11730967278708704, 0.16413165838457644, 0.15648330707335845, 0.1588263118173927, 0.07345800710027106, 0.12098837265511975, 0.15254493715474382, 0.2201956312637776, 0.07758851905236952, 0.11700406379532069, 0.14727850881172344, 0.15362559322966263, 0.13736231747316197, 0.1111886317085009, 0.11357462164596654, 0.1740834876545705, 0.07574480900075287, 0.18778476573061198, 0.07239683240186423, 0.16068041935795918, 0.10534621513215825, 0.2163806656608358, 0.10983102096361108, 0.14687409769976512, 0.11019605371984653, 0.2167989846202545, 0.08394113989197649, 0.1618462146143429, 0.16319891234161332, 0.1017919734294992, 0.0974980925093405, 0.08520442366716452, 0.22351417428581044, 0.1260973172611557, 0.16076689440524206, 0.19402333331527188, 0.14784411439904943, 0.1526159606873989, 0.11888183842529543, 0.06298790642176755, 0.1861759676830843, 0.21115907788043842, 0.10491968059795909, 0.0996201895759441, 0.10662890606909059, 0.12080275409971364, 0.10360715532442555, 0.09158874905551784, 0.11015738782589324, 0.16973279532976449, 0.24354019813472405, 0.1347954958328046, 0.175209756125696, 0.20445659378310665, 0.1107303480966948, 0.19038042722968385, 0.12162736922618933, 0.14851207699393854, 0.16992778721032664, 0.1372009448823519, 0.21765147481346503, 0.11357354553183541, 0.20807730965316296, 0.1679205003893003, 0.1516189891844988, 0.18372452032053843, 0.2072012933786027, 0.1363107535871677, 0.08735755734960549, 0.15201790840364993, 0.1761490775970742, 0.1576996871153824, 0.11204216832993552, 0.22405739669920877, 0.0939438359637279, 0.10445649881148711, 0.16167580266483128, 0.11647221108432859, 0.2829815325094387, 0.14897627552272752, 0.10379640298197046, 0.1324621241656132, 0.18966122675919905, 0.08733063965337351, 0.11836827965453267, 0.11366836974048056, 0.15559048857539892, 0.14470793190412223, 0.17781603033654392, 0.13325412932317704, 0.10739852063125, 0.13177139248000458, 0.16195387055631727, 0.21933318144874647, 0.15667579049477354, 0.1735273073427379, 0.25237948866561055, 0.1058255386305973, 0.15029723901534453, 0.11321603815304115, 0.14887847530189902, 0.29979693645145744, 0.21211986226262525, 0.09447154006920755, 0.18547115003457293, 0.186122874438297, 0.14157850295305252, 0.1141252284287475, 0.1459597866050899, 0.15702173521276563, 0.13987148908199742, 0.1060446874180343, 0.15055823751026765, 0.11132760628242977, 0.22101462091086432, 0.1603706320747733, 0.13382970937527716, 0.06555893603945151, 0.14252248511184007, 0.13723279786063358, 0.16976985818473622, 0.18690518714720383, 0.12054646082106046, 0.1427619910100475, 0.15008859161753207, 0.19035927602089942, 0.16273072105832398, 0.15424933866597712, 0.10001675618696027, 0.1816503214649856, 0.10428141133161262, 0.1036460958130192, 0.1826806747703813, 0.19955309049692005, 0.09652852852013893, 0.09318599186372012, 0.16203228587983176, 0.11457547458121553, 0.11208782525500283, 0.16570713400142267, 0.07364151795627549, 0.1097250496968627, 0.11384096360416152, 0.14752174029126763, 0.0803905569773633, 0.2029972939635627, 0.19916598626878113, 0.11825365494587459, 0.10059123043902218, 0.24467685667332262, 0.12238718001754023, 0.11687561287544668, 0.13244759291410446, 0.14452288480242714, 0.1346818433376029], [0.05422717964393087, 0.02375303938606521, 0.02746309128269786, 0.07755253231152892, 0.053506717522395775, 0.010578334567981074, 0.050255546666448936, 0.06965396591112949, 0.04622325795935467, 0.0235629289818462, 0.0453334377380088, 0.03261624377046246, 0.009151000904239481, 0.08721034493646584, 0.016024929464037996, 0.033396875514881685, 0.02022838896664325, 0.03268578300776426, 0.026653450840967707, 0.020824144303333014, 0.05925303339608945, 0.10497983908862807, 0.03742218061233871, 0.0339410738524748, 0.03632523810665589, 0.018334125670662615, 0.03875149697705638, 0.04269517325155903, 0.05012662077206187, 0.05665047363436315, 0.028937159841007087, 0.01966681138583226, 0.030372857509064488, 0.01735082081722794, 0.03177647027769126, 0.0250618353675236, 0.027419421458034776, 0.03119213659374509, 0.050790946843335405, 0.04009652831882704, 0.02244988558231853, 0.05997265689074993, 0.07768922107061371, 0.02704585400351789, 0.013489380999089917, 0.016468676258227788, 0.03461965286987834, 0.05914790075621568, 0.06964990636333823, 0.012389538551360602, 0.03756436868570745, 0.018708897259784862, 0.07992588347406127, 0.03642546886112541, 0.016613793959550094, 0.04426301959028933, 0.007776687662044424, 0.04321621287090238, 0.0650596190826036, 0.1396891730837524, 0.011008965757355327, 0.05537505945540033, 0.07663122276426293, 0.0011303829842290725, 0.026401829381939024, 0.005601561824732926, 0.011810288578999462, 0.020954691790393554, 0.06487015620223247, 0.006219213764779852, 0.008254245312855346, 0.042943436492350884, 0.07491493946872652, 0.057300520784338005, 0.02426831066259183, 0.04288463984266855, 0.03617875299823936, 0.07634210429387167, 0.025779135939956177, 0.02638591959112091, 0.02751877091213828, 0.05433430495031644, 0.029790839325869456, 0.004297162140574073, 0.08634080018964596, 0.019582104505388997, 0.07335839603911154, 0.03309912215627264, 0.02688988981390139, 0.0034487314951547887, 0.04661753133405, 0.010616365925670834, 0.03429094824241474, 0.08079279359662905, 0.052937980071874335, 0.03454928984865546, 0.013232404944574228, 0.00604851284151664, 0.08862557602697052, 0.05429221404483542, 0.029447128472384065, 0.04124287559534423, 0.036832199184573255, 0.03812928778643254, 0.035137286031385884, 0.052460968363448046, 0.06331906013656408, 0.03170706462697126, 0.04921264735457953, 0.01871815740742022, 0.0448319499992067, 0.04967367320205085, 0.030188476484909188, 0.03758318955078721, 0.05409427212725859, 0.04361108367447741, 0.02900343548390083, 0.09576957862009294, 0.022070540508138947, 0.049632402369752526, 0.02510549962607911, 0.02805389834975358, 0.0639752225833945, 0.022679565445287153, 0.052611071441788226, 0.017053362462320365, 0.075111541809747, 0.0583982648095116, 0.03452607175859157, 0.019042375752178486, 0.03520168218528852, 0.016339800458808895, 0.026197963270533364, 0.020718122941616457, 0.014495089435513364, 0.022152104393171612, 0.05487536400323734, 0.017751732702890877, 0.0334291849139845, 0.034688988016569056, 0.014923527578503126, 0.029763665588689037, 0.009794211946427822, 0.07450672856066376, 0.04405922954902053, 0.02857163726730505, 0.041297527350252494, 0.07208507100585848, 0.02145615540939616, 0.028904896826134063, 0.01589748415426584, 0.061594357175636105, 0.04373329313239083, 0.037361083304858766, 0.04903634275251534, 0.013288540994835785, 0.011223898218304384, 0.04876258302829228, 0.023747371233184822, 0.03222651233954821, 0.023300563079828862, 0.039259860714082606, 0.030760136141907424, 0.011810942596639507, 0.05696005311619956, 0.017394114001945127, 0.022718838044966105, 0.009808139275264693, 0.011078661773353815, 0.011578115099837305, 0.049658611314953305, 0.03801450351602398, 0.02348588292079512, 0.018186696179327555, 0.021967177890473977, 0.04590796394040808, 0.02542637645092327, 0.07975285174325109, 0.04254551917256322, 0.07927113852929324, 0.025461986551817972, 0.0628212868468836, 0.06621609296416864, 0.03620243493060116, 0.06318624538835138, 0.05187359929550439, 0.028019119454256725, 0.029287958204804454, 0.04277869826182723, 0.0403385946265189, 0.028997355439059902, 0.024965281954791863, 0.025033394413185306, 0.025347831251565367, 0.028753673104802147, 0.03540824785886798, 0.021769031882286072, 0.032219313507084735, 0.01608895825484069, 0.00477250355288561, 0.033111130105680786, 0.02986587416671682, 0.005456264616441331, 0.029558600908785593, 0.03135461127385497, 0.04068224981892854, 0.04079558690136764, 0.02448951705446234, 0.025705264415591955, 0.011294332671241136, 0.018159910214308184, 0.06211786443600431, 0.05373616731958464, 0.03616971735027619, 0.07148775344830938, 0.050056383915944025, 0.04947164576151408, 0.023952493429533206, 0.020718544110422954, 0.02817160297126975, 0.07268783592735417, 0.04822178372705821, 0.013440017974062357, 0.06274336134083569, 0.03320938674733043, 0.04569077442283742, 0.061583351125591435, 0.06321612425381318, 0.13062213227385655, 0.04009309588582255, 0.00832670675663394, 0.06249216661672108, 0.0027702974284693482, 0.04762115619087126, 0.1090631504484918, 0.15156638575717807, 0.07363587763393298, 0.021088398971187416, 0.030792063334956765, 0.01153560951934196, 0.04557395295705646, 0.04039833751448896, 0.04306833252485376, 0.04735617236292455, 0.02632833264215151, 0.04545505718851928, 0.011637127900030464, 0.03098949688137509, 0.117490719712805, 0.0375227267795708, 0.020835393406741787, 0.05054550747445319, 0.01905912416987121, 0.09047727158758789, 0.02184427823522128, 0.014668279800389428, 0.14258871437050402, 0.06502060437924229, 0.03397383596166037, 0.029114971002854872, 0.04023330984637141, 0.028034979150106665, 0.04574429811327718, 0.024830422589730006, 0.025419209159736056, 0.011604718310991302, 0.05217587975494098, 0.019283950387034565, 0.042022152920253575, 0.04095861077075824, 0.058674065439845435, 0.11797365004895255, 0.13367494189878926, 0.023679906298639253, 0.019664202736748848, 0.04595379898091778, 0.08659729384817183, 0.03546116298821289, 0.07226317902677692, 0.07998418659553863, 0.019586739217629656, 0.02599729396024486, 0.04690362555265892, 0.024097303139569703, 0.025469910833635367, 0.04263449525751639, 0.022078941619838588, 0.0439071226719534, 0.016129551877384074, 0.05522748710063752, 0.01367499862681143, 0.09762945264810696, 0.04628304908692371, 0.095489952218486, 0.03149523341562599, 0.030572326395486016, 0.03107422231551027, 0.029611920508614276, 0.06667455469141714, 0.009857212862698361, 0.046310274774441496, 0.01751299307215959, 0.0032454843812956824, 0.06600311884540133, 0.05219594371737912, 0.03794996635406278, 0.028052814814145677, 0.038737425857107155, 0.03018501251062844, 0.029914709339209367, 0.021766187601315323, 0.03638622038124595, 0.02180314841098152, 0.01852179440902546, 0.04968692424881738, 0.07406429722323082, 0.011282030645816121, 0.0738344837736804, 0.05940308823483065, 0.032945979983196594, 0.021734690853918437, 0.040079640748444945, 0.03820262681983877, 0.026138671237276867, 0.0015032357737254642, 0.05070816769148223, 0.00771915219957009, 0.01783385690941941, 0.05793271186121274, 0.0518595430185087, 0.07146582298446447, 0.01776302819052944, 0.03581239179766271, 0.0029061174109301646, 0.030296091608761344, 0.023453298927051947, 0.031083341455087066, 0.011988914247922366, 0.01165598308944027, 0.0359058801404899, 0.0463672197656706, 0.014632481379521778, 0.0967466457223054, 0.04587494950101245, 0.03901084048266057, 0.08376310608582571, 0.015667871084588114, 0.08671361065353267, 0.02576727456471417, 0.05380563605285715, 0.026843730083783157, 0.06919652092619799, 0.11543699671165086, 0.1561382826184854, 0.12704827560810372, 0.2147843356942758, 0.1381049698102288, 0.23651378141948953, 0.24532490002457052, 0.168441369314678, 0.21768800332210958, 0.09016592579428107, 0.1516869995975867, 0.1122559662326239, 0.1697631343267858, 0.13934419315773994, 0.16431139170890674, 0.11701150011504069, 0.10539092210819945, 0.14990807161666453, 0.09096612426219508, 0.08770609958446585, 0.10495517009985633, 0.13935188180767, 0.11853206422529183, 0.1486493446282111, 0.132097432797309, 0.11353438239893876, 0.16075653402367607, 0.08911295924917795, 0.15005019289674237, 0.17997783230384812, 0.08830311286146753, 0.09898860706016421, 0.08913553538150154, 0.18463360669557005, 0.08951213822001591, 0.12485859857406467, 0.1794554790831171, 0.19344842119608074, 0.24761939799645916, 0.13826512527884915, 0.1608778306399472, 0.1813300550566055, 0.14001418923726305, 0.0583611054753419, 0.21004756330512464, 0.10045572169474326, 0.0787559173477348, 0.15782068687258288, 0.08200918106012978, 0.10052837795228697, 0.14016046654433012, 0.12609090510522947, 0.18806934967869893, 0.15594247437547892, 0.11295721415081061, 0.1837718693423085, 0.22166321345139295, 0.12200729688629508, 0.17904055916005746, 0.3351698617916554, 0.14173626870615408, 0.13620530924526975, 0.23514149099355564, 0.09404789248947054, 0.16062181937741116, 0.17112151690525934, 0.13368638581596315, 0.15994527755538002, 0.17389174638083205, 0.15962413541274145, 0.0975261753774248, 0.12071260542143136, 0.2041846708743833, 0.1763553055934608, 0.0963897246401757, 0.13885870983358473, 0.1161026957561262, 0.15274496079655364, 0.10434246782097034, 0.13324883038876578, 0.20836083975154907, 0.212954867456574, 0.08728294182219543, 0.08338513769558631, 0.1862132383394055, 0.08533948712283745, 0.19564884452847764, 0.07560365251265466, 0.1423341577174142, 0.2518840308766812, 0.14725495304446667, 0.11284725755103864, 0.13991514220833778, 0.20730295276734978, 0.12657034734729677, 0.14325372321764007, 0.21127045940374956, 0.09539843798847869, 0.18938973429612815, 0.1475159070105292, 0.2552665618713945, 0.2158782910555601, 0.17599810991669074, 0.14386316004674882, 0.06343847169773653, 0.12352780904620886, 0.11784582253312692, 0.17706966726109385, 0.1468735039816238, 0.0914970863959752, 0.09360480806208216, 0.17932453454704955, 0.12902473361464217, 0.11463454211479984, 0.10736011448898353, 0.15129397303098813, 0.14677954808576033, 0.285779518308118, 0.13811184209771454, 0.12509920285083354, 0.09212363715050742, 0.08382206971873529, 0.1594280599965714, 0.11261400053626858, 0.09972491403459571, 0.11294242314761505, 0.1719700885587372, 0.12175895943073556, 0.20128723728703335, 0.12189308778033592, 0.14115889265667647, 0.09844254222116433, 0.07008933200268075, 0.1172057721123565, 0.09869637156953104, 0.07644797908142209, 0.18003097007749602, 0.06870148616144434, 0.11700772258336656, 0.23969663016032428, 0.1297044221428223, 0.09996842010878026, 0.1214981910015922, 0.14175877062371, 0.18466480658389628, 0.15284238994354382, 0.19596697355154902, 0.20421978930244222, 0.15355642506619915, 0.13893296913011, 0.09637272203690372, 0.14123908913461491, 0.13292437826748937, 0.09504550966084935, 0.15751306666061282, 0.13216686813393608, 0.14223196398233995, 0.22623457596637309, 0.09940115953213535, 0.15256141283316538, 0.1573140820255503, 0.11713224754203111, 0.06851570433354937, 0.16882743453606963, 0.1502214212086983, 0.1143805643368978, 0.12151431787060574, 0.15325695363571867, 0.09907811749144457, 0.1864035546896048, 0.1487013988662511, 0.18560672557214275, 0.12154496856965125, 0.19772302854107693, 0.12742213992169127, 0.18187207519076765], [0.024283786297019105, 0.010624986898619682, 0.05122900322021451, 0.03275190094427671, 0.036931016147718765, 0.001999579617404379, 0.030674963563797064, 0.07498241553548723, 0.04452702007256448, 0.057114876253763214, 0.021155207105039153, 0.022576998781005386, 0.008042841764108744, 0.022393417420971673, 0.04497211943089496, 0.0645464907574933, 0.05557921314903069, 0.022684114810544997, 0.03863693906168919, 0.05441464243631344, 0.021072529998491518, 0.03278727912402246, 0.01945766303833807, 0.07496113816159777, 0.05641946532705333, 0.031599716676282696, 0.06781647505704314, 0.02859033011191059, 0.012011085909762187, 0.04094383089977782, 0.042318306950619444, 0.027430781883595046, 0.00842577141156653, 0.08902480694814585, 0.05369056605559308, 0.02191562089137733, 0.035902020972571336, 0.10650337921106257, 0.03705155577335972, 0.006117882312537404, 0.12072169673047028, 0.027282569426461123, 0.08101192754111253, 0.1195298224047292, 0.05213416734477505, 0.026300876888853963, 0.04711044726718683, 0.0508170852845069, 0.08686200308147818, 0.06568342389073223, 0.02710255594138289, 0.02719762134802295, 0.02058289621345466, 0.030563967957277782, 0.07114497770089656, 0.033411139593226835, 0.10960094776237383, 0.0604498949542176, 0.06924723187694326, 0.03301509248558432, 0.04978182267223019, 0.0336521854478633, 0.0970320163469296, 0.05663013878802303, 0.1035161160689313, 0.049789964032243006, 0.03953046259994153, 0.030140891831251793, 0.04718550437246449, 0.04680221107264515, 0.028996294167882297, 0.12649620679439977, 0.05409998295363039, 0.05188080554944463, 0.03468997136224061, 0.04343995184171945, 0.05053442720964085, 0.05332796754373703, 0.06717400523484685, 0.029027252858213615, 0.029790690896334127, 0.07185156908235513, 0.019797683562501334, 0.03039236671611434, 0.013326421139936429, 0.07433750404743478, 0.012430260194378207, 0.02820382887875894, 0.07462164270691574, 0.06884533664560877, 0.045116348410374485, 0.019591216223489027, 0.04993682392523624, 0.07783988447044976, 0.030385934151127003, 0.01984724232897861, 0.06162710444186814, 0.01669077879341785, 0.017388946798746474, 0.06223199190571904, 0.03158435421937611, 0.018257766096212436, 0.03267139276431408, 0.04456469148863107, 0.05138337735843379, 0.015253908532031346, 0.08859934852807783, 0.020545504958136007, 0.042386955610709265, 0.016328200690622907, 0.12113951845094562, 0.05195804827963002, 0.07701077192905359, 0.009533522370475112, 0.015473271614609985, 0.05301121149386745, 0.02418761323497165, 0.02645004671649076, 0.05268144188448787, 0.0060493482214951655, 0.05475739963003434, 0.0036734670311489026, 0.026309879140171688, 0.01247867976417183, 0.019622644322225824, 0.0724088774586562, 0.0058003864342026645, 0.018492707786208484, 0.044276701082708314, 0.020527224005491007, 0.02701927955058636, 0.007738846479696804, 0.03155776677886024, 0.03063087999180425, 0.031543792138108984, 0.023402435836032964, 0.03212727235222701, 0.039300645439652726, 0.025583795249985997, 0.11039652265026234, 0.03395325991732534, 0.10075615791720338, 0.030727956618648022, 0.008522136504325317, 0.011111134444945492, 0.017118933064921293, 0.04567795753246173, 0.031374241079902276, 0.028323158803686965, 0.023243291543622036, 0.034492934864829294, 0.048344212118536234, 0.0392965562059544, 0.05905205980525352, 0.05007613617635798, 0.023482582219003234, 0.014065308005228871, 0.02991363322507823, 0.045527683760155924, 0.04492180923989508, 0.0038485872119053965, 0.07418294437229633, 0.016475823140353896, 0.03413879683648702, 0.09418406916665845, 0.03294317837571725, 0.01632779065403156, 0.0261432892511948, 0.07022481848252937, 0.030543395623681135, 0.08298243352328427, 0.07504681168938987, 0.03517265307891648, 0.013812883171340218, 0.023368367546936497, 0.09151486825430766, 0.016984231406240724, 0.04760570096550509, 0.03614008710428607, 0.05587613159150351, 0.025529397680656984, 0.043158919070265256, 0.09996913257054985, 0.049385452730348334, 0.021828880526300054, 0.07028439809801057, 0.012231873915879987, 0.04818279870960396, 0.13285780762089416, 0.018936764427053276, 0.060936888548894785, 0.04710789427917916, 0.06553379949764349, 0.044763160331058316, 0.03406320538488217, 0.042276479507563636, 0.05368416132114362, 0.04519855610851664, 0.015389241016237065, 0.07069873914588243, 0.07116747961845249, 0.019888691276719328, 0.037212598108453676, 0.10418063509860076, 0.05556488969887141, 0.05177020328119397, 0.028405839620972984, 0.015580793042317964, 0.03625685290899128, 0.030793015139352065, 0.0588376496307319, 0.03442846078542061, 0.03534061223035678, 0.03741515247384086, 0.028760812565451488, 0.04741461649246048, 0.030649836298834998, 0.03180684267135803, 0.03872582608892117, 0.039166743445093744, 0.02110791188897565, 0.080248227895936, 0.019682914135046303, 0.02936243086878676, 0.030557036297977902, 0.02778531696094433, 0.04999818098440301, 0.030698847731400747, 0.01109090628233389, 0.04714227427029982, 0.09512504562735558, 0.06740980039467104, 0.055059398073353805, 0.02870376738428604, 0.02749823011981789, 0.03453633195022121, 0.04170601285295561, 0.06429810135159642, 0.036110122891841456, 0.08787689002929255, 0.040220986484200694, 0.055844248927314766, 0.029770836590614635, 0.05608378451142926, 0.0503406079224078, 0.010843900981853949, 0.039164153349702246, 0.05584347709373105, 0.029319343630049843, 0.03999936634500045, 0.05258647295704577, 0.0587670491222525, 0.06346420195768587, 0.010516839283809531, 0.014281246076279785, 0.03736284219485242, 0.0320649727655109, 0.030184012466634158, 0.02973566806758754, 0.015375926886918023, 0.02473843895131722, 0.03148442403471563, 0.03377638015081175, 0.02347991605347488, 0.04018799059849698, 0.029201546240074094, 0.06524436932522804, 0.024389293721469585, 0.03252307084039785, 0.05032462206145283, 0.08733895170735195, 0.017375751413055696, 0.08193026107619517, 0.027303010028845165, 0.01480635823099874, 0.022934469052415807, 0.062170267483452335, 0.04674691735999659, 0.04622185530024581, 0.03608584724133834, 0.05246419670584146, 0.03540347213856876, 0.04837162334297318, 0.0640344459679909, 0.04130412875383627, 0.07119160683942027, 0.05414185863628518, 0.0384847357054241, 0.1120096399972681, 0.04552270765998401, 0.017728974744386505, 0.035124918140354566, 0.042913717188639566, 0.035734874472836964, 0.017204704927280545, 0.017155975510831922, 0.029873750208935235, 0.02398298827756662, 0.034908448506030254, 0.06676235076156445, 0.022981484107731376, 0.025496609596302733, 0.03637296933447942, 0.03248437526053749, 0.07972485793288797, 0.047863344952929765, 0.025651269461377524, 0.061438687989721075, 0.04475702648051083, 0.026579878031043336, 0.031475477444473654, 0.003821304007942672, 0.03909944178303704, 0.06443906488129869, 0.04553589562419802, 0.0946863176068291, 0.017475143540650606, 0.05112359227496199, 0.025853610459307674, 0.026908096551778726, 0.06452370682382025, 0.03591154272726271, 0.0312518238206394, 0.10094483412103727, 0.0904994914890267, 0.012496671279222937, 0.016924154551816173, 0.08687320208991878, 0.12054094666382298, 0.04193111366475932, 0.02603484106657561, 0.02658083540154621, 0.08291646401630715, 0.043410662983660586, 0.01753969740093453, 0.03858059521007817, 0.04858238957240246, 0.0749760924372822, 0.03749236922885757, 0.04424252147146035, 0.014126962851150893, 0.043123422146891244, 0.0743264979973901, 0.0609116555278888, 0.009759922868397553, 0.043273825795040466, 0.016964840942819137, 0.049639092831057496, 0.007596894965899992, 0.027284257812425494, 0.058045596233569086, 0.032901525337365456, 0.1097484644560609, 0.17377349257003516, 0.15124953322811052, 0.13066881336271763, 0.09579301564372145, 0.07869542489061132, 0.23279640823602676, 0.17361145204631612, 0.08567280790884979, 0.19924339227145538, 0.057644424596219324, 0.16205866180825979, 0.16767401830293238, 0.1172875271004159, 0.15728200640296564, 0.1780199576751329, 0.17235144856385887, 0.22937530040508136, 0.20501958701061085, 0.1363221084466204, 0.11012269984348677, 0.1313762433710508, 0.12088526607840322, 0.149220991297625, 0.22472201962955296, 0.08411016402533278, 0.13352637877687812, 0.15509559481870383, 0.12718083802610636, 0.17318146652542055, 0.18762731167953461, 0.1491302711656317, 0.1128885209618602, 0.21092442562803626, 0.12462528218748048, 0.11091199616203085, 0.09642569653806277, 0.24044394318480045, 0.13157153211068362, 0.04969352936313953, 0.2327565400628373, 0.10775927861686796, 0.23674148716963828, 0.16066103446064517, 0.2213650630437769, 0.15079606615472585, 0.14886315737385303, 0.09163900729618035, 0.21113264258019626, 0.10521323711145669, 0.1335911831120029, 0.22574704431463033, 0.1492071131360717, 0.0938797886192333, 0.174307482666336, 0.13720136048505083, 0.2348178849206306, 0.1501850559725426, 0.16542167431907728, 0.16925158677622676, 0.17850835021818057, 0.2397795725846663, 0.2056884253397584, 0.2475461331778206, 0.3133199654985219, 0.1675428362796083, 0.14080770837608725, 0.1881293745827861, 0.19748701073694974, 0.08665186396683566, 0.15342604456236586, 0.2842761349165812, 0.1247534214053303, 0.22578585863811895, 0.08300457920995541, 0.14641025540186092, 0.2585535933030769, 0.14004581957124174, 0.1689956200425513, 0.083384098688839, 0.13538219325710088, 0.17639259109273553, 0.1403845802997239, 0.0985983783903066, 0.11012602466507815, 0.1012213880312629, 0.19695935858180746, 0.16010856488719583, 0.16858182818396017, 0.14073799102334306, 0.10790171902044676, 0.10887442229432054, 0.10700498198275454, 0.08382913496461697, 0.18976496416144073, 0.13820018735714257, 0.1455209101550281, 0.19470026105409488, 0.16472252667881548, 0.08848744750139304, 0.15175598964560777, 0.07999870300409384, 0.09469833297771402, 0.12254412198672071, 0.19931576651288196, 0.1404788627405651, 0.1477543739019893, 0.18308983562747017, 0.10450859015691094, 0.12282138093723916, 0.35347264842130244, 0.1269635817152448, 0.2104545125621371, 0.13557227212004364, 0.08692143426742405, 0.14450860588112846, 0.11575030177482404, 0.06745245904312469, 0.16975293721770868, 0.14638842141721398, 0.20448817958822474, 0.08728913133381866, 0.14570410188753158, 0.13583580876002088, 0.1247237206553109, 0.1164877664996311, 0.08255487482529134, 0.15099779673619196, 0.1173023997398559, 0.07826294575352222, 0.09192609970341437, 0.14307961537269875, 0.11207858551642857, 0.09613059635739774, 0.15961047989549115, 0.07255261662066914, 0.09423253140994348, 0.1558574242517352, 0.1721418957458809, 0.23009849363006651, 0.11141624840092845, 0.12350332559435628, 0.16928701690630987, 0.0879941122548189, 0.1504244579700753, 0.08721267528017052, 0.15319344063755125, 0.25577315187547356, 0.09174885257380083, 0.15457327128387988, 0.14226941275410354, 0.18962679110700265, 0.3027638350613415, 0.15569149487419054, 0.25732400303240865, 0.18013638473348692, 0.15596726210787892, 0.1580805573030375, 0.09385469660628587, 0.08852526734699495, 0.15242794499499723, 0.24462584144202992, 0.14379715343238786, 0.0893639239075128, 0.14127864560578018, 0.15732914762338623, 0.12984982371563092, 0.18991749035194516, 0.13337704382138327, 0.1730221719481051, 0.12389074894599617, 0.11546218520379625, 0.09483068017289042, 0.12068421827279963, 0.13916071940911934, 0.17588530346984044], [0.017178468151541892, 0.028514172772702295, 0.03062848285480868, 0.026586152889649384, 0.01825107006879989, 0.009634608450141968, 0.030600231148127932, 0.0085018452591612, 0.05866639534360729, 0.1066446395998355, 0.04189567611319944, 0.029903452814323828, 0.022861892575747333, 0.09378254500916228, 0.05626338053843938, 0.04217722838802729, 0.08154009919962846, 0.045182414396549575, 0.05030487351177726, 0.016769912144809496, 0.033307443009107374, 0.09097231377381831, 0.04519920919847209, 0.024882649377104826, 0.018657707623788156, 0.03919177979696542, 0.012489797136367997, 0.007809350972820539, 0.007661127383471467, 0.05081440984213259, 0.05426173775049392, 0.04193270557152573, 0.012349099852144718, 0.02828317003150005, 0.01793472962162923, 0.04430591572599951, 0.043879937802557833, 0.014674635367555311, 0.021859983935428318, 0.013383484874793794, 0.04750974498165306, 0.08482912700856104, 0.02338453894481063, 0.00686550843056466, 0.048372718010796234, 0.01584704779816093, 0.02709217144001741, 0.03313101224193815, 0.025875670798995998, 0.040396779004368, 0.055212440056493506, 0.03861031451378949, 0.0078011956975387875, 0.027365233545424417, 0.019767650701396633, 0.03244849984184839, 0.04508207974140532, 0.04219715134240687, 0.010968607766699279, 0.009511149401078, 0.017785676682251506, 0.05080166716652457, 0.015370849669125164, 0.02453807206620695, 0.07012226109509356, 0.021589868156297598, 0.036437684611883014, 0.04628498980309814, 0.024146010291588027, 0.02984163376822835, 0.053805316929356195, 0.08240555471275002, 0.04055392506415956, 0.05088107325718738, 0.022825939231552184, 0.017778596593416296, 0.017551675664435606, 0.04164038102317136, 0.020676449494203553, 0.03414403268834576, 0.010145754313271027, 0.04544341660221107, 0.06287395706749521, 0.009703842479211744, 0.0675497917109169, 0.07881882920628414, 0.017480945280112792, 0.01880830979644088, 0.054685530049027875, 0.010124660620931536, 0.03355863031174522, 0.03469126640993636, 0.01900480638141744, 0.08588142562075518, 0.02943678293377161, 0.011372723874956137, 0.05791454037535004, 0.029452965463860892, 0.04184664983768016, 0.052665901312138885, 0.03269864813773893, 0.05155364458914846, 0.07258234705659561, 0.012126719011575915, 0.027819450187962502, 0.020782038554898463, 0.03876705239235889, 0.014591692015528679, 0.02885764613893116, 0.06986023843637668, 0.017359721023240127, 0.04244912532158196, 0.0537480825005332, 0.03782815023441799, 0.045268425601534545, 0.036602326363208704, 0.03133732665446587, 0.03398825218027923, 0.026375470151833724, 0.013758492095803376, 0.0446498269593576, 0.04151452019868884, 0.0009110512110055424, 0.01740393076033797, 0.060506409499794245, 0.01191265115267015, 0.04238604276906699, 0.03201937521225773, 0.056446290254825726, 0.020362932918942533, 0.027588592165557202, 0.021961802885925863, 0.013491274403349962, 0.025132701193797402, 0.06458829593611881, 0.049105536891147494, 0.016591611165495124, 0.022136535990284756, 0.0786021888779942, 0.04444766222150065, 0.055132132256403565, 0.016569279941904824, 0.025782954289752524, 0.019888732094841544, 0.01696254956186749, 0.054940669288043864, 0.010727218668762362, 0.05826636290294118, 0.02208946712926263, 0.09149112695013173, 0.029075878373987507, 0.01728395145619288, 0.03968084027292207, 0.02821958467393415, 0.07003117731073871, 0.024921309704950545, 0.06716788251651451, 0.06739915799698792, 0.10455006136908196, 0.02432613695418695, 0.056947848497657105, 0.03259396078647114, 0.02043045165919466, 0.025366754161950666, 0.034665428538573906, 0.01794583771697944, 0.01971545731066726, 0.022674105093756225, 0.01609124221431557, 0.05800209524750244, 0.03232865783502348, 0.04485234050662257, 0.05040938645834103, 0.046357679457287304, 0.02522818962461315, 0.0385992899100529, 0.03557030693627894, 0.07732957630651072, 0.08675466626300476, 0.07411309343297035, 0.0725320220226422, 0.026491363933018874, 0.03857383053400554, 0.07326383158215322, 0.011550892195373308, 0.041186234884662554, 0.03333014901727438, 0.013671607011929154, 0.04311337717808783, 0.05527367095055524, 0.042991316149709746, 0.023619315506948624, 0.05663699994329363, 0.04037055521621369, 0.021650134258379694, 0.004506865707298857, 0.04346456888015382, 0.07131442485842854, 0.033194580901181325, 0.035098178559564985, 0.04744160840346012, 0.03721396737091709, 0.03704612325236667, 0.03588935993320774, 0.07967396144522354, 0.023744601166981738, 0.02546925774367992, 0.025294110891991295, 0.09118315792875364, 0.04129513392399531, 0.0558150045981165, 0.029577959830930922, 0.026532632909948006, 0.032030147485784255, 0.033846494552562945, 0.07016705712885596, 0.02597396269266028, 0.03881223434291314, 0.004603003053489374, 0.02818296339683002, 0.028464344977692235, 0.03137280131340958, 0.025721643614815548, 0.0969303866440896, 0.03624299701186828, 0.017551625569467433, 0.08310074670589529, 0.034795437968568876, 0.03170728356053587, 0.03818739052803721, 0.06376378471031785, 0.03679629779071547, 0.04707787811639719, 0.011176768130098935, 0.03069394027988892, 0.02874302885174984, 0.010685061897675041, 0.012329240908002248, 0.049343866485287435, 0.032265367481159046, 0.0781518685107585, 0.038054078540881164, 0.019946959146182053, 0.04275672326912172, 0.010224324560113018, 0.08492249660775997, 0.030897802680556197, 0.0287479066173546, 0.06438882890506648, 0.0056439059881085996, 0.028539429913507774, 0.1411970390472561, 0.028681974217761308, 0.09092169930227101, 0.040809739657561295, 0.012110674706491409, 0.01994583108171355, 0.013600387737824349, 0.022860135541122872, 0.03691036217787769, 0.00835791684949072, 0.052859486822853796, 0.060959060210734606, 0.05141083682246972, 0.05882785699213855, 0.06567434742464684, 0.01623156749701593, 0.05961318653135095, 0.03933313666493632, 0.14562193129677325, 0.039583028919878416, 0.020547809326671995, 0.02730257958319271, 0.04014781072328333, 0.03022058921487769, 0.07478326020645909, 0.07633124667336233, 0.03151341232296545, 0.01904785280203214, 0.05195013327465858, 0.02315061956323916, 0.03516415548801888, 0.06234853877685964, 0.02531228237785399, 0.007405021960948943, 0.07331401560804807, 0.023827417426218744, 0.01374252757159411, 0.06385278305970132, 0.026631158580130432, 0.04318561783293262, 0.04155151626036968, 0.018357434673816897, 0.0068473536430246895, 0.02983451100590173, 0.04204642857075669, 0.03594207839341834, 0.08085926034254953, 0.026038637151941657, 0.02175026667828206, 0.023421635196427815, 0.1245974813355133, 0.04461063785129227, 0.03456334241491277, 0.022118676206446253, 0.10935900761978701, 0.07214814613689668, 0.037316060916054994, 0.01479099206335377, 0.007888808086136123, 0.11369765488780104, 0.08080817831796594, 0.05007903426303528, 0.053069663044880144, 0.026618059673637617, 0.04062825857545249, 0.08228801336372271, 0.01581970336701488, 0.05638611692120321, 0.04466394260816742, 0.055807638782425784, 0.07333595349336974, 0.006568122435055557, 0.037278927557053976, 0.02279725522384979, 0.054819532233523205, 0.02561581706686411, 0.07486672955565155, 0.041155265062116086, 0.029674053112103138, 0.013997069381730398, 0.03076488217629958, 0.048015904540079646, 0.005208138209127355, 0.11629365777480416, 0.04614748839230742, 0.06807163284975104, 0.07605818085721694, 0.07454791775671765, 0.028498532010416966, 0.015650707064196467, 0.043249394293525256, 0.05315513990353793, 0.009598958458809648, 0.026874056093220133, 0.02081239796098089, 0.05098789057228714, 0.04319185929489322, 0.021033509729022626, 0.06734118884196505, 0.010058395182568347, 0.029282872637850232, 0.10668857474229299, 0.1317593696876429, 0.17292318429099396, 0.1530852948781103, 0.2804696001112461, 0.21402338199550286, 0.1407773100072518, 0.11069366373703815, 0.12589799123816192, 0.13079002092126757, 0.12104754408937879, 0.18794219009578228, 0.1602462778100744, 0.16776266042143106, 0.13288568268762901, 0.21009327960200608, 0.14270897198002785, 0.12918285559862852, 0.12760043347952887, 0.10767198720714077, 0.1486470884992741, 0.1587199026835151, 0.13022030383581296, 0.13074121729005128, 0.13291732786456123, 0.06968127694563009, 0.19002223707502708, 0.13530677621020004, 0.16392510384321213, 0.06542494127643295, 0.12165537787950598, 0.11702783478540368, 0.12064397160429507, 0.14731821371242404, 0.11180433968547732, 0.17704979254631326, 0.08191342174541205, 0.1913727677310817, 0.14773608738323674, 0.10729369227192365, 0.20862489589489996, 0.1788158220006153, 0.08156933981808834, 0.12669765535974875, 0.14800680801272392, 0.1299827720504254, 0.14646507042925805, 0.18528061104007065, 0.1110277563566342, 0.17517033324111253, 0.18213320727227256, 0.14247439394239336, 0.08081533262156881, 0.15565210167551413, 0.15101243188837543, 0.1145507387991529, 0.2125465971766971, 0.13074427493847907, 0.1322665237239562, 0.1525502509321086, 0.07040944256004877, 0.12141052109654993, 0.1597718524863012, 0.12552313244668767, 0.2188415382988751, 0.2263470707111992, 0.1292107009794563, 0.163915129378438, 0.09661229472840205, 0.12914757389808074, 0.26138260087464005, 0.2335655700881034, 0.22323690791381523, 0.1520980751956813, 0.11495146885863505, 0.23395506403176114, 0.11462715032394044, 0.24607917439425364, 0.11659088791930117, 0.19041140447370708, 0.06281166861299425, 0.10656111830030568, 0.18383192393230274, 0.25819498754572123, 0.22219874721486121, 0.12888028199085966, 0.13640965218655765, 0.06072282347304281, 0.177096102561336, 0.11760299181332812, 0.12453484407160431, 0.14823724486632273, 0.09405744393006898, 0.26640792028047144, 0.1006329020310659, 0.0912082425202243, 0.10428369714645669, 0.10109955706866458, 0.11921184923266992, 0.2857011475134641, 0.21929739508777857, 0.13995217537740245, 0.1413631613831967, 0.07788616479956545, 0.11935757735045627, 0.10608528289594688, 0.14815344155067578, 0.07356638292549178, 0.08470615313854069, 0.1710775520768948, 0.10510344378417358, 0.17640203121118248, 0.162591464468278, 0.14436740486416966, 0.11069620188209228, 0.15187112643616274, 0.11893210408743471, 0.1003540845704265, 0.17522878479212523, 0.12503223144449294, 0.16356998617993668, 0.15848916897084564, 0.11141146896989085, 0.06984529900364578, 0.214891012001317, 0.21927481895545498, 0.11590092064579949, 0.12218060321174562, 0.13129134167684242, 0.15105853410204872, 0.11206743103684857, 0.09383261029142886, 0.08899387423298322, 0.1475304234190844, 0.1929811353329569, 0.1593523460905999, 0.15161924151470885, 0.16285592137137428, 0.13759886962361634, 0.13757191482000053, 0.15549454372376204, 0.10289900543284602, 0.12083353838534094, 0.1744614337803796, 0.1428362206206657, 0.13599749305285513, 0.2547824737848714, 0.1839657628443092, 0.10293771585565992, 0.13632902526296675, 0.0793174040154554, 0.2252327953465283, 0.10228639221168123, 0.1677690280484967, 0.2459676147555001, 0.10814078705152497, 0.2138597532757558, 0.10146747677936219, 0.2914168720599264, 0.1249193210969679, 0.15922018443234265, 0.14641089364886284, 0.23401217971695587, 0.16603146737907082, 0.1188258285401389, 0.20484742359258235, 0.13720048475079238, 0.12979322753380984, 0.14456732460530475, 0.12254764718818478, 0.11830087780253962, 0.15518790314672515, 0.1296894159168005, 0.21709900524001569, 0.07969612197484821, 0.07456333958543837], [0.07855246498365887, 0.07950650324346498, 0.023964384490682278, 0.008861748847266426, 0.010294310013705399, 0.03252541602705605, 0.009248401293007191, 0.016486287422594614, 0.025603141184546985, 0.06553421510034241, 0.04574430553475395, 0.027988034598820377, 0.030862684252497274, 0.032546956863370724, 0.02743552606261801, 0.06820250317105092, 0.07836300210328773, 0.045634489943040535, 0.08064762208960019, 0.02156204132916173, 0.040559235130785964, 0.01890172206913121, 0.06900710999616422, 0.03526580745528918, 0.034971360364579596, 0.019432654517004266, 0.046802263022982515, 0.06050538162526209, 0.10024587201769464, 0.017503087256045546, 0.031034749335958622, 0.05357998234103434, 0.030876169075781945, 0.031040376670716796, 0.0010697419816096954, 0.022329743005684577, 0.038672324662911706, 0.0416169996606186, 0.0838525645667687, 0.033092617231886834, 0.051119221025146544, 0.010812977543537272, 0.015412397879117634, 0.016906120363273658, 0.04175627851509489, 0.009866071322903736, 0.075568875472527, 0.013787972056888975, 0.024734631733736023, 0.042185807615169324, 0.019157301030645613, 0.009675960918684723, 0.06299708678852767, 0.010087172886414919, 0.08274104256997816, 0.03638030917500146, 0.06658197919023223, 0.03577978925022762, 0.03127563191810623, 0.060321132332319394, 0.0467179661791306, 0.014854761102469638, 0.016435470715805423, 0.038120396857266314, 0.04839617358811665, 0.004925537186863949, 0.01960841178515693, 0.021426107705337927, 0.041170330659952015, 0.11095816516899504, 0.03651349128631409, 0.017818735650507733, 0.031305006123147905, 0.03148152965877671, 0.016966056209639646, 0.06505882498458959, 0.05013628353481181, 0.02274903788929805, 0.010104769207828213, 0.04337455378845334, 0.06747987397830002, 0.07294860435649753, 0.06375370634486899, 0.06837367953266948, 0.02511345359380357, 0.04009043528640177, 0.023109474896045867, 0.01091852300305618, 0.053733272943645716, 0.022115633400972, 0.013123793487466173, 0.03621174888394307, 0.03313455970783252, 0.03795935452217236, 0.07068441569572315, 0.023770186708134133, 0.052258098585298285, 0.042897798120975494, 0.020200918370392174, 0.011165932774019893, 0.04179738607490435, 0.034714039211394265, 0.038234156963881105, 0.08297588035929948, 0.07476328901248053, 0.06700964921037666, 0.021751259300799575, 0.02664521485712612, 0.05567618958593812, 0.03151536417135503, 0.037228650762699544, 0.03475604848063085, 0.012976283287571277, 0.012014337444270495, 0.050114772384404205, 0.03482328334939666, 0.02458097747876309, 0.05175378326384816, 0.07687983481446281, 0.013375026246649213, 0.03968186072597746, 0.019859356034430675, 0.015019151451269863, 0.03173427176079713, 0.0101407364672923, 0.05657677094859537, 0.028801528642361518, 0.01841790301114088, 0.011042405076295836, 0.04816920627490617, 0.06003368369420059, 0.07393720443360507, 0.007331016386160627, 0.019849878808599897, 0.01649648638704093, 0.042342923989053816, 0.06451010325690731, 0.05096136992506217, 0.03893257358868141, 0.008072560140135465, 0.007012607666183612, 0.028067214334441815, 0.009476837130932836, 0.03276367511716671, 0.059287558106007054, 0.017777104876586236, 0.042723400838440284, 0.05628870632790495, 0.018492743038223125, 0.0717867944331374, 0.03722891051438637, 0.0570806187170092, 0.058045985861099325, 0.03226632114092354, 0.026604194499668665, 0.054982500441838056, 0.06736055889632553, 0.02817066415445879, 0.04398406112159137, 0.05348247526853811, 0.01577833234478021, 0.027394071548769716, 0.031258814851753414, 0.06791377061745152, 0.020747786584252026, 0.023020027547318023, 0.0965185985842254, 0.04006269380624872, 0.030902023645467125, 0.057032560944207944, 0.05304186590365134, 0.07206302921986207, 0.04835122170334216, 0.08970304086687975, 0.07978788853506558, 0.004916829011563095, 0.13840929488651454, 0.08676593948621303, 0.015073036011017393, 0.025226473408110905, 0.0032410150288342265, 0.019212865627196152, 0.010310219804523513, 0.014911579000909114, 0.031329047997132875, 0.027682631553034298, 0.03120746936474461, 0.021744181067333557, 0.0404760106903268, 0.03196153593307827, 0.01028280765240197, 0.04548272816464305, 0.06073005199141335, 0.013348757001949707, 0.025362950655107852, 0.017349460831610486, 0.05502375272044446, 0.03250072477385402, 0.021316787497198675, 0.00944842307944782, 0.008775889782555168, 0.022236109944060445, 0.044846540622529574, 0.11011820242856629, 0.017616400218685158, 0.033072078294935636, 0.013357236039155396, 0.09717715816805139, 0.06969100650167093, 0.033532369416207075, 0.05166096285392996, 0.021704678401874844, 0.04658380072214641, 0.03630099214205984, 0.027386082329030614, 0.04473570457776077, 0.025338624909636565, 0.026279888952558395, 0.030842455162201077, 0.0034782471720973263, 0.09587952037691139, 0.042577854546834715, 0.0349376074882457, 0.012049669239786454, 0.01328583957729279, 0.006186241535033332, 0.04543314527836628, 0.029501234748749994, 0.02661215217813151, 0.02519762983865803, 0.022692397178616375, 0.06073429336538538, 0.062388444057432935, 0.026061836688313633, 0.07443865135428496, 0.023324376743403263, 0.04763904937135521, 0.004084797974428511, 0.040896426216932014, 0.013519946351152612, 0.04475933084904682, 0.052252165114623494, 0.07037253555608913, 0.021520731534110382, 0.020347904428490438, 0.030985730481916107, 0.04955820615577977, 0.03825085899734404, 0.08200374853913672, 0.06657717749476433, 0.035305638521094806, 0.026513227603572886, 0.05052053791587241, 0.04703041406173725, 0.02089767443976598, 0.0348913086054381, 0.04669015419494826, 0.004591624538079486, 0.03550401459506247, 0.002972148840854061, 0.06343835295410827, 0.06976405609748326, 0.031857668654993176, 0.0525934157485608, 0.04622583321179263, 0.0351657436840469, 0.028712702842312865, 0.04128312226384878, 0.024866615276550874, 0.055641943181399256, 0.06811710423789918, 0.01830260665883543, 0.013066296523902565, 0.03693896454933565, 0.01962740334420232, 0.1028466246498283, 0.008400524475291604, 0.003848139604087919, 0.03712588928465266, 0.013170471793273464, 0.02469112147082342, 0.029136790144548286, 0.027830391300085466, 0.059325737893232144, 0.04746904189232737, 0.006174772570375353, 0.0463541839417303, 0.03241754115151707, 0.09827378526097164, 0.022285958148131613, 0.07848982029827312, 0.025518027978250757, 0.06314380196272396, 0.031215080089168623, 0.03073715924983844, 0.06385494270944037, 0.06772252658265643, 0.036523855378618464, 0.03418999018322211, 0.029139979524188675, 0.011061106270062737, 0.026711410719144624, 0.058560212564771064, 0.03896094218362123, 0.03820457495748997, 0.016002700285753235, 0.06903299610712565, 0.015789982207934372, 0.0442542845121352, 0.029754780225630384, 0.029157470089558046, 0.021147488769202027, 0.06736871509929188, 0.03138552914606407, 0.02498005997040309, 0.06033160403603688, 0.046627554038423114, 0.11852385607198812, 0.05650530212733429, 0.037918195012025535, 0.05903243742068298, 0.04276544350432232, 0.08258952570031397, 0.046072965633356944, 0.09672847052570432, 0.0694292139087338, 0.0531166595465038, 0.007086916593834758, 0.04569937591440976, 0.04008042371424381, 0.08194438414648175, 0.08643325694720261, 0.09836071301833726, 0.02957811753731221, 0.06453989306464791, 0.03449168805673253, 0.016451803530799225, 0.010640634154697182, 0.028523156470328104, 0.039363301257253624, 0.03449794807238504, 0.03840974910417572, 0.09030940520460717, 0.07581304205814376, 0.008641651966172503, 0.04712556481536012, 0.019732962718990166, 0.049489297744003125, 0.048036799707915634, 0.0219173538062023, 0.06456220944528468, 0.012697187521553133, 0.2104459927068092, 0.2215464587789029, 0.10045054150396027, 0.07707906435825862, 0.09246606408851221, 0.10612596743158065, 0.07222946325782686, 0.08240527269663289, 0.08143274753820151, 0.08885285133146681, 0.09167241878458299, 0.10904565802775323, 0.15644162805983797, 0.09313551097875461, 0.06612856406718493, 0.1436210417887196, 0.186122874438297, 0.11954479152336717, 0.20616690278984606, 0.10027746524428949, 0.11490162622067146, 0.1452579375472851, 0.11666469450574368, 0.22964579839026555, 0.1024885532387998, 0.10563683274085633, 0.13777869200566784, 0.3095432947156951, 0.17360904748784378, 0.16768685745773837, 0.12042344984365627, 0.24693629558896646, 0.15811827324796468, 0.09606795167201199, 0.10411444294732064, 0.1159129360166844, 0.15686355385696515, 0.12437453275197186, 0.1610877545317635, 0.12865435739513487, 0.14544912963174284, 0.09795729638426565, 0.12700551305897534, 0.10004707291955128, 0.16077364794909954, 0.1295506491442211, 0.11758561813621782, 0.12109719376894645, 0.130652530642692, 0.13413471722742543, 0.1472705975174904, 0.1438667520415038, 0.14441071660257876, 0.10549299709964544, 0.1630853340611793, 0.0773090856091585, 0.12808306695660576, 0.25054466212168336, 0.17364185041515157, 0.18177647172706202, 0.1391026537748985, 0.07198345614597201, 0.1437074871500954, 0.13956714916275814, 0.12086536167771555, 0.10987057001329958, 0.13573314005043358, 0.14994372439105064, 0.16807397652883083, 0.1602833703509532, 0.11201384055311792, 0.12004708449239843, 0.13808841991703957, 0.083987679972779, 0.14872841304168105, 0.18563528341474012, 0.10595254978397861, 0.11585814325371757, 0.13560899358708411, 0.15973418107023463, 0.11029209505068138, 0.20984900911571458, 0.16344226256478578, 0.11888871071278118, 0.25935208483133465, 0.11482085086754523, 0.1345697493525222, 0.1760167526663281, 0.157162283139769, 0.1659624624880962, 0.13445070886518806, 0.19810070749372244, 0.12254612578544766, 0.1634044575621374, 0.10967506605084054, 0.17684206541161984, 0.1120502948469948, 0.2346681195194833, 0.12894214742118493, 0.16363694274332374, 0.08486732534947805, 0.08398359816055745, 0.1289533983799629, 0.1325948053272441, 0.1584661623928696, 0.1567710970994085, 0.11826123227365315, 0.10164200022700243, 0.17253198340767995, 0.07167376534198411, 0.09402792129549198, 0.15155884553678334, 0.13889436260797083, 0.13294713251525536, 0.18576897389721125, 0.16317535657435656, 0.13704855227842927, 0.09985029246308841, 0.1369011469068937, 0.1389364869100973, 0.135714853531681, 0.08525788798579015, 0.06303602727712132, 0.06436015231884085, 0.12795359187293798, 0.11874825184349902, 0.19909298862330616, 0.18255274335388094, 0.13094035035464913, 0.11559791659237817, 0.23806721525033936, 0.21407362539321184, 0.10446420972584747, 0.12043493828969076, 0.076473405060824, 0.10035651139332913, 0.2009341976372525, 0.1581080464529805, 0.11068356310715899, 0.11631340632447973, 0.16604429169092327, 0.21010936936363578, 0.1040500022645574, 0.09752996775205247, 0.17006370413582772, 0.2186375664314255, 0.26102052186615765, 0.12503800535341725, 0.2073227532673627, 0.23330449737841263, 0.1508510741405189, 0.08896795101463795, 0.1761162598268129, 0.1260425170767121, 0.15802036912646145, 0.18921914423117414, 0.22916258603800088, 0.11840050370665267, 0.1820710746687837, 0.12376341866911389, 0.11101097639766522, 0.12004741845885292, 0.1393827106221579, 0.1220559817738831, 0.0998728018021211, 0.1016267787781544, 0.17370573448715732, 0.21792238840134814, 0.1706723394454457, 0.13122586940880865, 0.1134224739507772, 0.15184630901785567, 0.11137650639284402, 0.19896548765245825, 0.18609363381983712, 0.15121995122171938], [0.050573367698234506, 0.017132037537521683, 0.032612299255561084, 0.06190456377225928, 0.02030635343544418, 0.021975577146804426, 0.03810684895142913, 0.06174934358568862, 0.033656879531918094, 0.016011619045457337, 0.035121886467095464, 0.022152553392515983, 0.03126931253063958, 0.023657630736124702, 0.045286752938409336, 0.06610374664887786, 0.016271367021545302, 0.0665570430282969, 0.03037925296666799, 0.027882306385436095, 0.024296950141433626, 0.04943230080243666, 0.03496398341667373, 0.04782351017638575, 0.015523896290687844, 0.02015025009313831, 0.015602059283992276, 0.022647276455245446, 0.044047336632502265, 0.015714936234871857, 0.017262677793041803, 0.041196072052116506, 0.058539740421110764, 0.04401727594085969, 0.03473739459877834, 0.026503416411287617, 0.05957200475677382, 0.09562418446876109, 0.05482236352690961, 0.06994393042987213, 0.009850588266999694, 0.04996776406187564, 0.06534297848702408, 0.047844698492554016, 0.042017733430839144, 0.06318723986623809, 0.011018316818081075, 0.04279499211406801, 0.017047334367816802, 0.04943268300849013, 0.03736109072633553, 0.03606276644859463, 0.06975807438720949, 0.08454893657471985, 0.010286837514286162, 0.018737347490969114, 0.04727707426354755, 0.03487817259156145, 0.027681894971465226, 0.024077703019429464, 0.020763906031788792, 0.06865976261906326, 0.042189332816633396, 0.02831959463946987, 0.02982279434945667, 0.022160516637086403, 0.03325223835418001, 0.058222034422215074, 0.014240819436963648, 0.024011464483919553, 0.038023691304260865, 0.0408919362234883, 0.03160950189339928, 0.01793217106751399, 0.029496646420739125, 0.010826004090631614, 0.033882381103467196, 0.05768891263869591, 0.05740445114497561, 0.02988338328577811, 0.012557928148453357, 0.03293016110546887, 0.021072858398838434, 0.01711036868073279, 0.05528797955776099, 0.017654607836448122, 0.04842808593821246, 0.028393811262503732, 0.021093480827403255, 0.07526995323132724, 0.03889652747602668, 0.025998345954576507, 0.011751106940209866, 0.03546861786162481, 0.02056536297459388, 0.0390748618519865, 0.02409902121144114, 0.02461914613377303, 0.050125158741138875, 0.019617759135144297, 0.021088146640977357, 0.03877819573972374, 0.026846882356039714, 0.03208177869964857, 0.0989058130653575, 0.021546638054132927, 0.06607449118746445, 0.08106828623567708, 0.01974267743207747, 0.038520844900631346, 0.08066887719905935, 0.061072519747540355, 0.06906064852955751, 0.07017347670625895, 0.01211079159475048, 0.05488607319421135, 0.06930792471393943, 0.06752187211532146, 0.02541816829761956, 0.049065382991102524, 0.040359315389650874, 0.05311295251885895, 0.014922403224773007, 0.04393379917019047, 0.040196521586040035, 0.05697885913832579, 0.0666908967832569, 0.0330287962424336, 0.034348353365203366, 0.05277220283460338, 0.09963164833607152, 0.05492929216416087, 0.01478749747548136, 0.014868300659145461, 0.01698259682598291, 0.0686184769438114, 0.009663976161391474, 0.06234709158889018, 0.030874124458932783, 0.040288648087880574, 0.052044556723558344, 0.047274558382923715, 0.1010131710791029, 0.02690279947273666, 0.0942018510249909, 0.06011183555528987, 0.05618930677883327, 0.06628282688325271, 0.04161650613241363, 0.022897894159541465, 0.019786395496339537, 0.03268402040703222, 0.06521150702610612, 0.04714061557024252, 0.04711192043032497, 0.08496045746142045, 0.05536309603485279, 0.06956970246392302, 0.06234351443708874, 0.023384130763588473, 0.03262955418904312, 0.04646355795557611, 0.07871397858252749, 0.06051127056707628, 0.03060745966649847, 0.03430995835515205, 0.04814028106920887, 0.01251473237061873, 0.029984901666466612, 0.10074587175040506, 0.039461409469367936, 0.024277626471302938, 0.04770276274939533, 0.01759837345161941, 0.009694920008769259, 0.0523382134269923, 0.04748428189486731, 0.04568932352412958, 0.044678318008664064, 0.07778767438139766, 0.01041857614836772, 0.04831167636439204, 0.04664061954827048, 0.05014920803660061, 0.016169544360309374, 0.021522618444578256, 0.021951201306364965, 0.03666779120976571, 0.07947388585307635, 0.009695596290839603, 0.01319533559581032, 0.04399559409648646, 0.02001266704610316, 0.013942402783868602, 0.022890018117323052, 0.1036620519880671, 0.04291685647331178, 0.05685359574272297, 0.028118350164731964, 0.017402452031092253, 0.029818219009030145, 0.016425078792963177, 0.046651013326481916, 0.029699230472033378, 0.05818989571707789, 0.04808636775123887, 0.06706420448608696, 0.03693910184665583, 0.05475063495396171, 0.05279563243675511, 0.049352082060067914, 0.022369989674189128, 0.018690870492719114, 0.03777140562306158, 0.07467363015166484, 0.020066378128831275, 0.005973725692456355, 0.060536466480698436, 0.06281287089223042, 0.056425977672915906, 0.10936461083474569, 0.08008039119886234, 0.05341387113730889, 0.015985096542863175, 0.026603654587233905, 0.052045784977963194, 0.04746932019770611, 0.046610903955297545, 0.06499737515696324, 0.08521526644472033, 0.06172521265398245, 0.046433408206212334, 0.015849598930799402, 0.09609933709725738, 0.013572919924627058, 0.008204090972867562, 0.04140687538892962, 0.06078060709114652, 0.04310761811211705, 0.01914217235025717, 0.04660333775973413, 0.02572746390796965, 0.046939571475377306, 0.056585743514006026, 0.0382833799085347, 0.029062686699035112, 0.06515234301332384, 0.05322432662069332, 0.02453804794640746, 0.10806917722220533, 0.027754052134696394, 0.018915329346782528, 0.01668653370870743, 0.04207104931992944, 0.031747994071338326, 0.04287317366106436, 0.020303546261857264, 0.061355407888186164, 0.027522665332071483, 0.022429921809816733, 0.006222935171535937, 0.0636976222449448, 0.0633381333318539, 0.06578170650755055, 0.06284548086114228, 0.04989195738744456, 0.02671083369932603, 0.02662765564309666, 0.036537191772367805, 0.00033976001873270434, 0.011929079519177321, 0.030320500845846254, 0.013573990472650621, 0.041135880164802074, 0.01523500695839175, 0.07584516220958903, 0.047437571120099165, 0.03774900018470362, 0.03718962863786146, 0.04671748749387916, 0.05457492407003883, 0.07655623616301455, 0.012228904397488805, 0.05558846773055848, 0.04404617146064993, 0.05333515153324697, 0.016061929236457217, 0.08102903404505923, 0.0985083929845132, 0.01821460093196947, 0.028761441535607446, 0.03737149563676212, 0.00772568541833607, 0.06197196191351395, 0.05184154593735002, 0.022642374569841195, 0.034063261045957915, 0.013823575663991505, 0.06967823414015584, 0.01812443369999528, 0.05555896364967339, 0.037105791925569065, 0.029689749535464216, 0.007652557897017687, 0.04211080988170579, 0.03312836277473252, 0.06705827472615056, 0.03282601923274342, 0.03811192153079901, 0.02868125433451496, 0.027774971422331873, 0.08259990834631026, 0.0520208413945511, 0.06378492107614875, 0.057699944663909264, 0.009543531159579288, 0.054518788019777276, 0.04622457527148072, 0.11603012855630368, 0.028438382796593942, 0.05755008649430238, 0.05556252224778291, 0.02890210635086987, 0.06109144080255646, 0.003694022666422825, 0.015996052497939672, 0.049994551882264204, 0.0396417476440547, 0.057750095293158665, 0.03801670027314685, 0.027069062816735823, 0.049932972178794444, 0.010763412283267826, 0.06143581587821245, 0.011177279284311226, 0.034494842184358276, 0.0022597663883061614, 0.047915228497004136, 0.04070565715664998, 0.06807014855439775, 0.07263042338308878, 0.02493863328709267, 0.03634700158727355, 0.058647901023505256, 0.03254686409491114, 0.05579983509960584, 0.11377201808500104, 0.03881444223225117, 0.0050895703770947875, 0.005575911345658824, 0.012223027515574358, 0.008479842435917817, 0.1595502917189151, 0.28888751403428614, 0.17098929587518796, 0.236243802937679, 0.07631517175468616, 0.1456516914186068, 0.1582294618128799, 0.16924563475186005, 0.15116575959837064, 0.1112609391566366, 0.10663569672033191, 0.16239669523201883, 0.12460021243896335, 0.10928893403615803, 0.1196986461582128, 0.233126871753484, 0.14736991171957925, 0.22800943697802722, 0.11492248057038523, 0.30276199453510344, 0.11527877824846655, 0.10705759283155203, 0.17710806598188356, 0.10663885084795766, 0.07938939234009013, 0.14457404846325517, 0.15403499157400802, 0.1413884834619239, 0.20286007085815072, 0.19144245539791882, 0.12176085190731101, 0.1407385550555773, 0.20427159121027216, 0.1508383240434341, 0.18196506629465148, 0.1142705038364511, 0.1903296643286012, 0.17422161618014798, 0.2002478000940755, 0.15487832366488874, 0.161348708497826, 0.12211674140417017, 0.1388778572436422, 0.10142046914552338, 0.21605027635814622, 0.18409304117085412, 0.16185724292881787, 0.12461925594834611, 0.16935090097831562, 0.15484762843698263, 0.11768690645112656, 0.14577043504687026, 0.17978039133595303, 0.26268094370607287, 0.19013412325875834, 0.1697437049006112, 0.13045498577412218, 0.19978946453193203, 0.08388686663238332, 0.08397791330935434, 0.05930110972258262, 0.12017005094094202, 0.14055010891752318, 0.1010047180170659, 0.12036891683237627, 0.11076249051257037, 0.14616754342569038, 0.16953115380601957, 0.11581705795833841, 0.1791608167695813, 0.22439802763983607, 0.11718376743374392, 0.10176405383390374, 0.20728450297610834, 0.06619267820497043, 0.10089229748700745, 0.14879173308145255, 0.12285445103771053, 0.19392823451198637, 0.1957309854333289, 0.14680942695122212, 0.1724577834829688, 0.07961351351696067, 0.09258249963750131, 0.11088235478382558, 0.13432586478302255, 0.13793053542030975, 0.08378515529329889, 0.09987749217543751, 0.1663077689590864, 0.14020702888956293, 0.1276863444945775, 0.117566544940928, 0.1084221871860791, 0.06747473831637762, 0.09872728944174014, 0.10329281125450507, 0.13011508213821799, 0.08413629504502751, 0.17731836094753817, 0.09391996849444695, 0.1401875400915742, 0.12782260280800983, 0.1481243790476583, 0.25975183525588363, 0.3030675812624395, 0.141404973983299, 0.14283368247561157, 0.0709749516681768, 0.15521279477979988, 0.1361215059296228, 0.26630556327290833, 0.18306310346815735, 0.204108600737527, 0.1729947718558833, 0.1383195395465009, 0.19545563380233943, 0.21838189655682072, 0.10537141846725717, 0.12215078371809795, 0.13126394158462062, 0.16174457006854936, 0.14192379458108917, 0.1739224564516917, 0.10919406529865228, 0.11841836720122956, 0.1690782656078227, 0.20253769675036892, 0.10396960540674627, 0.2206511318217963, 0.16148407623404637, 0.13455367443384603, 0.11841441155411303, 0.2175654302118346, 0.15978158946381882, 0.2703298442065716, 0.13557813508668914, 0.13758692104602233, 0.1771097580785863, 0.07984105599462055, 0.10427027169498615, 0.1081073384557385, 0.38680668629240245, 0.24774143676040694, 0.18399904074613005, 0.22361310257110745, 0.11775168110034429, 0.10891506230109371, 0.10063207082566805, 0.07584870225400664, 0.13264047709526494, 0.1864566034055315, 0.2046454555238597, 0.1280313392635435, 0.0862897552724462, 0.18771426170133054, 0.10501324315555394, 0.10346009134082124, 0.19794537598500028, 0.11142981486045755, 0.11724995216354728, 0.14208089240128174, 0.12361238419543952, 0.22168918862007558, 0.11826847563497722, 0.15734191256342456, 0.10717860001022927, 0.10253869273583405, 0.14921735477400944, 0.18518622469855472, 0.17473445506766438, 0.14524217433063313, 0.23531450045993552, 0.1098883815575391, 0.1834492725902237, 0.12006328557617962], [0.03363155003171414, 0.06688263805699535, 0.07931241678306833, 0.014571915635315236, 0.03227914174203761, 0.05880847580556292, 0.04647900575946551, 0.03780827551963739, 0.031500632539973594, 0.02445870493829716, 0.05064779397798702, 0.04539860201475676, 0.05394334526499733, 0.014357285599544412, 0.05587239487795159, 0.0330956117977621, 0.06936199017218314, 0.040373913434450515, 0.053615174983860925, 0.02055999168078415, 0.037050282990094274, 0.03182238324370701, 0.020729359057440888, 0.010800160653161583, 0.018446481262799352, 0.05675356907886453, 0.02053251922916388, 0.03460554464254528, 0.04117110249353573, 0.0409880777442595, 0.025810035258473363, 0.06882142464746721, 0.03241928519855719, 0.06850899531855248, 0.03443409739702474, 0.031122883083298802, 0.014953958416299429, 0.03750573159777559, 0.041191192431142554, 0.06427707630791701, 0.03200835802999791, 0.07379825212410651, 0.05435468803625554, 0.0067112604574504076, 0.009578720091667492, 0.0666808481037151, 0.027791656757472083, 0.0034606098006406683, 0.031056518382683862, 0.048287946192431264, 0.04454303561942652, 0.03809973546594847, 0.07526915913331322, 0.05652601917972788, 0.032584034561295994, 0.06098493890021928, 0.03147969655401539, 0.025167155399685726, 0.010161254067497794, 0.06896615086589009, 0.03400274261366576, 0.03761690160899889, 0.04618516351911239, 0.05050020306953229, 0.05043224460678175, 0.007089820710461936, 0.04264742718078196, 0.02778154128463939, 0.03131323654088192, 0.05971702412352897, 0.026080433053721208, 0.024340582858712878, 0.02537409029173432, 0.04076303630426992, 0.07700190326431766, 0.037288453022483736, 0.044793109700549394, 0.011270205450273352, 0.04480663534195628, 0.037534846051130444, 0.021771866886410862, 0.029712065916100983, 0.022232818519114517, 0.030496413965011016, 0.013956698403490009, 0.03486244648229331, 0.016208529377763625, 0.09710568192531355, 0.02648929148563184, 0.03282369259977713, 0.046846847544657066, 0.032968118248390965, 0.03303434008557815, 0.03694366976560559, 0.020307941631472204, 0.032762806804385036, 0.04933880132739432, 0.03152832206978928, 0.052449572685873136, 0.01304332241488737, 0.05565160965488758, 0.018871939682867378, 0.010914817830780521, 0.04523367453657556, 0.011113367381767603, 0.024011982131924015, 0.02490957635018276, 0.05410706675320398, 0.08945335270254873, 0.043834425596287474, 0.01935451935423771, 0.056135538179660216, 0.02483226497133728, 0.020833875714743044, 0.038809310281067155, 0.013469859732140321, 0.0162738903236459, 0.04011989112768788, 0.07093805208569393, 0.033744130123523064, 0.02204239455750212, 0.039048786493367516, 0.03949288395233452, 0.08857942186295986, 0.09714641098980792, 0.06880261862534098, 0.056756088670226745, 0.03302597608126234, 0.057818673449219204, 0.06606733688386157, 0.04663915009587072, 0.03457445236563217, 0.0359040878538508, 0.06786210971768014, 0.04698343611380551, 0.014995935216575162, 0.04342715721577406, 0.04199244474875741, 0.041116944266832434, 0.03166993126797024, 0.030490786630252842, 0.02126003360899631, 0.04634423916286323, 0.03493508047540672, 0.012683289878623327, 0.0067960151136503555, 0.021517039349419065, 0.03036810776393395, 0.06498283648397774, 0.0358482709270902, 0.035967797521152534, 0.03623315984441433, 0.022274224793363828, 0.012883604813396232, 0.019254587314208038, 0.02874211972084595, 0.025793583699851297, 0.0321548505598912, 0.038602184285991825, 0.03879260824760422, 0.05154161437531002, 0.01669122593739303, 0.026583998806017917, 0.025957466605177615, 0.04054425487993285, 0.051016915967920795, 0.10584045579889789, 0.010254780445393408, 0.03607179467508104, 0.031694882272859104, 0.05970191028609406, 0.03801343482336961, 0.02984090275276685, 0.015880251485214103, 0.09213058365276083, 0.0732309024897404, 0.04102132224943489, 0.035586378144216724, 0.04658309197111521, 0.011694196273310808, 0.007881160254328279, 0.010800447307701688, 0.04872368706855923, 0.03216298820916563, 0.04716499512142036, 0.04585095215588808, 0.06791558145778254, 0.0452328470419161, 0.0038432437486335402, 0.043412651939434, 0.04535704545560293, 0.06145307081169449, 0.01959027740667807, 0.03407421143492684, 0.006781673573641456, 0.018082635942846537, 0.012699684848485049, 0.04001586428785231, 0.031929081815178506, 0.027926697948714718, 0.02123184869560646, 0.0745820788142737, 0.03920566909073386, 0.026621714750945102, 0.03467398550128564, 0.07519241364207119, 0.0586046226817416, 0.025636756763560697, 0.05464812580612488, 0.020893275359412655, 0.047104947952902876, 0.058818075485760346, 0.014342598497023573, 0.019905508343072142, 0.02708399111725157, 0.0345895402278984, 0.028941801974724513, 0.032713654363760725, 0.036111577501287684, 0.05003728103474714, 0.03217100340407342, 0.07942180935060605, 0.07039129704935476, 0.014247951476136222, 0.03530384994519409, 0.013020608985243598, 0.06701543054077774, 0.06334571808110923, 0.030422880117839668, 0.05782936037576292, 0.033451234121457674, 0.026358575159974862, 0.03914527682354674, 0.03588869942177553, 0.02799778270855313, 0.051229366872576065, 0.03742111563042272, 0.05892425455385819, 0.047143001575022936, 0.053798581939190626, 0.012669266998273088, 0.039513920128229074, 0.02103369712131098, 0.061334590645856224, 0.010839647547982167, 0.042810239538084716, 0.020622886841010768, 0.019814608240267262, 0.01948610213730717, 0.03565343489754014, 0.06069618037145119, 0.04837311134906486, 0.043802112486446276, 0.029856261498935055, 0.023700230012764223, 0.08046676812227815, 0.029760465076833498, 0.025392066963831894, 0.04191734311461914, 0.028452914048102684, 0.06045269656169694, 0.03140262822853401, 0.015869933777139522, 0.07376139707048424, 0.026066037244163454, 0.04453229303180706, 0.038240134963416494, 0.057524916555848904, 0.11476815838250332, 0.00979229813310667, 0.03868598389090039, 0.07911182168754749, 0.047517270359094255, 0.0462096840783488, 0.028528299553727265, 0.027667321046465077, 0.052325990254757926, 0.02657662371348124, 0.008737847292650258, 0.05744695394241717, 0.046733948329347186, 0.00883074562807451, 0.06795793582568876, 0.09664194352808408, 0.04114076720725279, 0.02147830480680568, 0.0529802602250129, 0.019872861266776454, 0.029952657205285504, 0.03712057921802625, 0.03742887107364368, 0.025694981959532015, 0.02572397395852022, 0.008183236623153789, 0.018260176220792346, 0.06760427277185954, 0.04007129158708267, 0.039855174472904764, 0.02706854145799298, 0.022318013361655176, 0.03856128823827021, 0.07118149878806435, 0.018610716688272078, 0.03387452547030989, 0.03668086043035146, 0.05017229625082109, 0.0643382738053333, 0.011450298716226825, 0.030925776081858203, 0.017427677630621474, 0.02995359231135808, 0.04375383949081879, 0.08754402195336297, 0.060651484527625144, 0.04030452633742243, 0.046813725493848324, 0.038599211984546855, 0.018638061119418126, 0.03490503833745606, 0.03228761335776653, 0.05915193061809987, 0.01698312375083333, 0.009768015061126789, 0.053076743133715354, 0.07015959112322889, 0.07051149528706446, 0.01842971429141471, 0.02780647002509795, 0.01212607612615102, 0.036540472065098584, 0.016203421546379104, 0.07220270883408375, 0.014975288668210851, 0.017384096863679588, 0.049648317726678215, 0.03577608222258277, 0.0013837488381795993, 0.02935913758847164, 0.016568417195230722, 0.013213880938565126, 0.0685142348811496, 0.061864472954766825, 0.11160638663568534, 0.018026381148956716, 0.04654804404708557, 0.0351825867255684, 0.055339373284368776, 0.02825735071382951, 0.03211064453353174, 0.011895322932105046, 0.08928144161473028, 0.044285929689067416, 0.15270304429577664, 0.18527559412177652, 0.18225739826448262, 0.15267798939021304, 0.1133731211302802, 0.09178813445032574, 0.13330279936781153, 0.14874797605443746, 0.15035839198390022, 0.10715626136516221, 0.24307099753059447, 0.059350273295422085, 0.11251942865783349, 0.12226359758642502, 0.10337964253267273, 0.1390330254798755, 0.12578479887451977, 0.11938019801164046, 0.13432086270768195, 0.15302895102649927, 0.08682939311256632, 0.11180078479810618, 0.12720973725663498, 0.07926434787805192, 0.14817699731793255, 0.1353034217027016, 0.10245860015857033, 0.1826299267122522, 0.16675978142302483, 0.15171597304288298, 0.1818057123455219, 0.22560167242772877, 0.08014919570996426, 0.21030206058640033, 0.09127437529969029, 0.131051390490029, 0.11110873951110989, 0.0971778409439139, 0.13999382470501587, 0.12382751796394587, 0.1068977416434791, 0.1967134405276738, 0.1822981718578376, 0.14253743196604773, 0.17302757478319108, 0.19604246481321752, 0.12963338376721367, 0.07399026057100855, 0.114963165106019, 0.12253913475433365, 0.2006985360640101, 0.14789599052164704, 0.13651154906256124, 0.1854895256110467, 0.10430422495119274, 0.10425090164062567, 0.14088760799495503, 0.0897864434227813, 0.0894678097392898, 0.10102578016812913, 0.16666275303578004, 0.10568693513050675, 0.15547502523986623, 0.13789466000162065, 0.08483813668135554, 0.09248136717360467, 0.13060942670563236, 0.11596552460105158, 0.107592659041984, 0.23573463025968522, 0.11403035969124176, 0.13888232497265562, 0.10160988007555716, 0.18832531641237438, 0.0905313593102619, 0.15081067162100226, 0.13475527142873034, 0.09506882051937282, 0.13258864550152794, 0.155629510700237, 0.14552223117789254, 0.05585889521171339, 0.1358576724305749, 0.12544038298074156, 0.1507900102296844, 0.14486970525467768, 0.0836174373398535, 0.2741929009789601, 0.12917746760649607, 0.10407953974208795, 0.12447869317838922, 0.11248045848333277, 0.24444207083433867, 0.14512956084217876, 0.10189307620748878, 0.1411158184055239, 0.10086653754115105, 0.16897427587537095, 0.09521117186523043, 0.22891414468176663, 0.1110910318675451, 0.23310278163990006, 0.09189584234263748, 0.08242012307164259, 0.10980189908877946, 0.10911546443821862, 0.22838647768367082, 0.26580473233480006, 0.1911688403924927, 0.16651812329655513, 0.1481328989029862, 0.10994503711117432, 0.11397129215765744, 0.1630647765705362, 0.10916727376752533, 0.13308071909705177, 0.15711977292085066, 0.11237238693865947, 0.12129974813433364, 0.10549307873588987, 0.11406059478758834, 0.15761625487357378, 0.17306632973486558, 0.1347268620156683, 0.1678584420005791, 0.19679368153447285, 0.13816641963785514, 0.18833275273209438, 0.15826297720195726, 0.13210118806455284, 0.2395745468675159, 0.11171813181135803, 0.11515359277836978, 0.10842275863979012, 0.21777784771984443, 0.10411589755676687, 0.20808541390579194, 0.16744862805353478, 0.15518169879214838, 0.1672677815076895, 0.18722674489254132, 0.11847877060063183, 0.24279197969008237, 0.1728191351867281, 0.10078576218802482, 0.09064421770744957, 0.13175700965803117, 0.07861643811338581, 0.14741614751983434, 0.1881880487781018, 0.11697713125613518, 0.2931995107792318, 0.09778868043213151, 0.07788868810166605, 0.10030164441559464, 0.11484791699331254, 0.06589988610357977, 0.1186784528545104, 0.13743144110776484, 0.1435208963812329, 0.11007698354660533, 0.09962033058400266, 0.11390140411094762, 0.10503348894417286, 0.18467363814124838, 0.1408628054196015, 0.16172117757378146, 0.07653248001588508, 0.10152431786991656, 0.12439903846825473, 0.12954232224728912, 0.17264315712964162, 0.15535289741819724, 0.06360356986988336, 0.18313904001843184, 0.22571118373889476], [0.01091353205993073, 0.05166086266399361, 0.036247679963707924, 0.03425134353165049, 0.04411208530655131, 0.01481664718085085, 0.05100377995404415, 0.07449817159795202, 0.03441931381530594, 0.022714880542480387, 0.050480517602409236, 0.06328630173811689, 0.030563314867322333, 0.09117749534198083, 0.05945896824414376, 0.059735640897997655, 0.06132757735031191, 0.04712400259450078, 0.01527562562841922, 0.02906168665504083, 0.07418160850647837, 0.0019312319909658981, 0.01895313434943091, 0.06495623048976995, 0.06325021851807833, 0.04619812512828503, 0.06728926076903008, 0.05915817579079885, 0.01279168704058975, 0.049423391319578514, 0.051880408500437625, 0.008416065047640586, 0.027267136465525255, 0.04842880582145881, 0.011841797386296093, 0.0006020696798714198, 0.0399219380778959, 0.05002377765777055, 0.032468775316374376, 0.04790670864167623, 0.04782381816767156, 0.0340545445214957, 0.0074462501197558595, 0.00755336846850696, 0.05856357078300789, 0.0808516755932942, 0.03754652745556086, 0.04038702718389686, 0.015551454089290928, 0.05301450662955176, 0.029736326723650564, 0.02438349383737659, 0.06752399465767667, 0.03961871509090997, 0.06554847917868756, 0.009853517894953256, 0.010007204618887044, 0.05766367590695154, 0.029274317530507687, 0.06876511048176326, 0.013506994946510531, 0.04946025008393917, 0.005536807120734011, 0.057900198371498846, 0.02063471110886894, 0.05355901666916907, 0.07577497730380856, 0.04845515206397977, 0.058071059320354834, 0.03567549523722846, 0.04787597259564791, 0.07537207275163382, 0.02645136773935519, 0.016558207098569255, 0.054945007141213864, 0.05498794780578464, 0.029065592207189184, 0.04173735003860202, 0.031968638286343776, 0.01531155485281488, 0.03337771326187067, 0.048921981506282464, 0.028823984175687656, 0.028418706606316846, 0.04052672906254884, 0.01886346250103088, 0.031071877128852066, 0.04591792727296706, 0.028550560273288283, 0.03514994336001109, 0.037378427296062, 0.013076171726424946, 0.021314156583684962, 0.04635762008547317, 0.02712379806325771, 0.03797133649641182, 0.004395672503960668, 0.021558469743467867, 0.01706762097455794, 0.09586953106918372, 0.03896420763339847, 0.045999867797945626, 0.019345919718034565, 0.014299896247393917, 0.010634703467076179, 0.04951130613335408, 0.03143992486002389, 0.054379208595491946, 0.018590496874821838, 0.04342773238022346, 0.05632432199490722, 0.02398567299678689, 0.024212731223087758, 0.025121420549112372, 0.07673438871279359, 0.02918383488577092, 0.0243859039619565, 0.01527192509456654, 0.01478943169786362, 0.016576771922700573, 0.03003289079060778, 0.02901488682255149, 0.011126338267786196, 0.03389937257452402, 0.04400374658871442, 0.05035209636844229, 0.02807308657793328, 0.019746169236896094, 0.05334562694770284, 0.00856529981319909, 0.01629108031920623, 0.009268937446904602, 0.07105446537025273, 0.028070327643945348, 0.08639173378469422, 0.05404398420068901, 0.04035713347548153, 0.044076347185182385, 0.027582432339841034, 0.012021355378237786, 0.00936757072850014, 0.024175297294277698, 0.014197036434779875, 0.039082765724742785, 0.02337028785404982, 0.09130538965109736, 0.04020381689770147, 0.03877671144437045, 0.012156369666627143, 0.012042509370076004, 0.09792634882614948, 0.11592973824008368, 0.04897611004707869, 0.05829907677252777, 0.014005471421114635, 0.036927286855643615, 0.01105611718230648, 0.010380564272054471, 0.041444038433837704, 0.026251004564983305, 0.03738994542800356, 0.03194814387825318, 0.064587590895826, 0.05481674175825901, 0.05120182948303409, 0.031942759596859105, 0.021565297502093017, 0.01379325150992372, 0.015217957043205388, 0.0865662943397183, 0.04621680869604461, 0.028786377697542775, 0.02874449644878041, 0.03759682280360721, 0.0163067563335062, 0.01852450324804522, 0.05785804067272693, 0.06451308669056743, 0.019797906206804328, 0.03750015435798559, 0.043690474922186695, 0.037616760600940324, 0.049524828064022586, 0.04747046310512815, 0.006999826027822564, 0.03294914524303749, 0.050949391661561094, 0.05813213065266609, 0.022738760999345686, 0.04476727182918694, 0.07066584716085345, 0.02595720870885998, 0.04023468653031159, 0.02819641296810005, 0.06184246827615425, 0.025959524209611118, 0.05646674755553249, 0.03447498231253121, 0.017181555485876743, 0.007901240915089147, 0.053091526715434156, 0.10832481741090305, 0.04618800223397557, 0.03114767823717557, 0.04241802562319208, 0.061239410206326284, 0.047205898590618744, 0.05956247929134406, 0.07216492609586567, 0.04521514681982808, 0.06530538870720193, 0.0071524273607792566, 0.056464009030605666, 0.022700555236951914, 0.02352952491492033, 0.058273802933399566, 0.09402097479323857, 0.041091136081377044, 0.020440615371626336, 0.019256834166299086, 0.03296149086963851, 0.05694223415048327, 0.04694306699093431, 0.0226196221774444, 0.01823115824663546, 0.032258996143355034, 0.022832113900221884, 0.043208609567955136, 0.10813386281370185, 0.022044832512619905, 0.02320941992365988, 0.050001910276478156, 0.023130104746087454, 0.05860385084815789, 0.01818537144572474, 0.04545635965769179, 0.03089629241003422, 0.07751307231956162, 0.028479653628892265, 0.05244624044280499, 0.03369617625139654, 0.028625752820516936, 0.0929237317177467, 0.051795165418297984, 0.02160674088372616, 0.0882866074971389, 0.07650282379472628, 0.0544167315820232, 0.0343860359134851, 0.024617572780698538, 0.06881100489408709, 0.03545507737726439, 0.035081365203950554, 0.01491128770794603, 0.03879153584421147, 0.05083805837784894, 0.05110063393658493, 0.04852086181927007, 0.06806506484281272, 0.06041473941877484, 0.022521617866004817, 0.03299826799775474, 0.07520727143855765, 0.02608890281408094, 0.024434843035123777, 0.013767908094450831, 0.04842578528041486, 0.009583556111465441, 0.07796344463713467, 0.05150424723979086, 0.039524673848063685, 0.0813875359017402, 0.035924077601521276, 0.04554002938675694, 0.04552318263449706, 0.07023438476608135, 0.006275021414694493, 0.02776654433546355, 0.02332918029424036, 0.0452256111020688, 0.033860461771837436, 0.06759514435543679, 0.06483083721832372, 0.012078834715794073, 0.021166728947719093, 0.027378955855965614, 0.05458456827909686, 0.05159902691957541, 0.024874600785551593, 0.0051281959167681634, 0.08442289021331817, 0.013670584703504574, 0.022097153923823498, 0.04040464205900207, 0.061538618174381554, 0.05660196686221752, 0.050179610116174445, 0.01380003937811125, 0.04321300679293927, 0.09095314409933053, 0.02829904271493433, 0.023178221890702844, 0.024697303560969885, 0.01855692211393034, 0.0974827968457248, 0.027027652831748128, 0.0715265900362283, 0.045430050522554666, 0.0212476638625958, 0.06243110270588659, 0.03668133169412613, 0.09545738677843474, 0.036354875774122775, 0.03637882116890978, 0.059542548915487714, 0.07636678812559694, 0.03851075169222895, 0.1016701127809938, 0.026203377237834502, 0.04181145348411519, 0.09959629984223284, 0.019493599684210494, 0.0514042242866708, 0.0417709507746622, 0.012311007267271634, 0.008823131192912115, 0.05968662575469352, 0.056075324027915485, 0.02763250689895358, 0.03486126646748744, 0.023184511592262425, 0.01791230562957935, 0.00536185879354889, 0.05134598053700756, 0.09354531008284539, 0.022195097008079756, 0.02639071572048124, 0.04001515182608273, 0.0419393737684004, 0.05570830231590662, 0.026548937894403934, 0.046595756721217185, 0.0684871687553823, 0.09705024349386804, 0.053904786982457153, 0.050163201231043786, 0.020393633712956216, 0.12253080785740167, 0.043177094266866334, 0.06296874416875653, 0.0722889463941101, 0.046843255549902096, 0.1345141773344949, 0.11730823302059434, 0.1042809957289137, 0.13179278117604554, 0.1279724424239248, 0.0868288216588553, 0.17239372129552066, 0.2033948476309888, 0.12132785326684825, 0.15916790754999965, 0.12502666533691809, 0.20200404804199934, 0.10059225460281596, 0.2049589535454288, 0.18554796231910586, 0.1867129560559988, 0.14593903615605086, 0.13538376661017537, 0.09525216810288839, 0.23405940999509767, 0.14301105577033013, 0.0675886134558823, 0.125843487912789, 0.14238308009225875, 0.17502491682535037, 0.2050550765125081, 0.22450979507993907, 0.15071471192641184, 0.09933541266946122, 0.15894719283096492, 0.1767519538407214, 0.12201059944345616, 0.16998864331981167, 0.1313613707316108, 0.16118162136990577, 0.08892089885193855, 0.13637871947139502, 0.11515751131810248, 0.13027529697865248, 0.1413330450304784, 0.19276098464615643, 0.1069296539935749, 0.17909816466271877, 0.13101305114105344, 0.14928992197383195, 0.15012494201073423, 0.1409375248476863, 0.1448378968052566, 0.06422278078389354, 0.12597682216437533, 0.11087606137152761, 0.1294971106108278, 0.25505570287350565, 0.13578503101598471, 0.348446408752352, 0.12894014362245798, 0.0709974387427792, 0.20287679886678234, 0.05422672693384811, 0.09915049915434793, 0.07718746244790964, 0.23497231100918725, 0.08964103442849591, 0.1162340039445553, 0.07041502351057716, 0.10862773982807994, 0.19589117058785632, 0.14654663245892152, 0.13251284253783524, 0.18394970276858658, 0.2055221248883754, 0.3837161755654961, 0.08055500948103145, 0.10747355918283574, 0.17758312955265865, 0.11678985028993338, 0.07321908007725142, 0.08393820840865374, 0.1562435191590339, 0.10050614320789464, 0.079441387206316, 0.11123785094241612, 0.1552243425976485, 0.13123694225214422, 0.1888676334056072, 0.12276883688173257, 0.2184262769878842, 0.060955019216635264, 0.11656581074930727, 0.10804669014760293, 0.1383379744947888, 0.12813240493414924, 0.16439292405266315, 0.21746040147263557, 0.13922206533607095, 0.10983030108036473, 0.13295686949277297, 0.1258921282715164, 0.0730650695913937, 0.2559573232429102, 0.12351763420156203, 0.13668507803231478, 0.08785414320300333, 0.0987635507772211, 0.1771935317083262, 0.1425915939034894, 0.15739013731945306, 0.13539620500523597, 0.1041840563993901, 0.0942910423327703, 0.18040009948890656, 0.07562260696431622, 0.08227744518080726, 0.16482433449709788, 0.17660607729339972, 0.1684563310118392, 0.07934715671581216, 0.09303226339397952, 0.11648266052361578, 0.1724126609042287, 0.18668257253011689, 0.07734443410299718, 0.09040032571647316, 0.1962214708328247, 0.07856640993850306, 0.10625822556903586, 0.08989802532596514, 0.10551112776738591, 0.15546372975222766, 0.14526362239848822, 0.17808608303312212, 0.11174504950759001, 0.12087784460163675, 0.1529459492303431, 0.1604167788173072, 0.2270084578776732, 0.2660420414758846, 0.16343239200068638, 0.240113390609622, 0.16987130977213383, 0.1444925754913129, 0.19478237227303907, 0.18044548924081028, 0.1053804875118658, 0.15182331728283316, 0.1596345700090751, 0.1583666997612454, 0.11642590106930584, 0.11922705583856441, 0.12564276665216312, 0.15512223792029545, 0.20036685542436317, 0.2950065810000524, 0.16835324669955298, 0.13732004474150017, 0.2104878646787256, 0.23031497810734436, 0.13616560434456915, 0.14308987185359, 0.06650804643868469, 0.22962503309827298, 0.09547416673740372, 0.24601273733424023, 0.18526046915212646, 0.07428637007251382, 0.16270397405605763, 0.2070019525126554, 0.1661215492640622, 0.11710294013028033, 0.2309987781336531, 0.10569031932391226, 0.23297274252399802, 0.11774626342230476, 0.13430066144792363, 0.23483278724597767, 0.10416401841212064], [0.01304235298448475, 0.04774267174070701, 0.021214458320173435, 0.022266098276304547, 0.07099641457898542, 0.05017001043597702, 0.005878297097297036, 0.032406987811555155, 0.054034981949371286, 0.013148814996384317, 0.055468429054599255, 0.014595190314139472, 0.037087420059833676, 0.05013562673411798, 0.05885839265829418, 0.05049434752436355, 0.036328010028228164, 0.01896694942843169, 0.029802439094055444, 0.008500521453242982, 0.0316540047788294, 0.018087626885971986, 0.017246729039470665, 0.1305814180523157, 0.10220065189059824, 0.0590409980941331, 0.03844269675028045, 0.0647475162986666, 0.03196755103999749, 0.06570905025000684, 0.036723051525768824, 0.023013400168565568, 0.026379715236544143, 0.037779958875034936, 0.04536648928478826, 0.01069162433850579, 0.023355812263616826, 0.047448758996324614, 0.029799776639265474, 0.025668873204267584, 0.03209209084161557, 0.05866770523425657, 0.06636035905103199, 0.057580369830247946, 0.1015438289323356, 0.013183218179619871, 0.02928051631897688, 0.03888721352268476, 0.0493649880081648, 0.06211140032974072, 0.02511697693989845, 0.06587403710000217, 0.09218019622494467, 0.03047938909730874, 0.010860018574021524, 0.0231690470900503, 0.07750318691250868, 0.02621502153488109, 0.008864889987307834, 0.034749246697174385, 0.05271012218145188, 0.03419840613787528, 0.02212024399341317, 0.037363124210969545, 0.009077829781745095, 0.04773551001562737, 0.03232443872548174, 0.013920540968683781, 0.0860268939868547, 0.029172045869927388, 0.03773532240302302, 0.023081367908162065, 0.040832278682501055, 0.03249773020797875, 0.016063127804955002, 0.026305413266527466, 0.04058652019011788, 0.02513723200536333, 0.05426206800621003, 0.0074151290846202755, 0.015520301512879087, 0.07891238434240222, 0.033898526526172645, 0.0448201758263167, 0.08329774980666116, 0.017439956463931594, 0.038305410562315956, 0.02320343079190934, 0.059871145931538194, 0.03977872584073339, 0.03932186715246644, 0.06223458571184892, 0.0489212653337745, 0.009874660754576325, 0.047530513984384015, 0.08886891882866621, 0.10634021062287502, 0.04250231875630561, 0.05566853804339189, 0.08081160704023205, 0.040683748957235366, 0.04087234723556321, 0.03864111364237033, 0.03628275757364463, 0.02982893005537335, 0.03183023516612593, 0.011724635460268473, 0.029454345858539455, 0.029378001127042808, 0.04254059502272867, 0.05665644792316016, 0.05183038403629325, 0.040122733553289436, 0.01593414996023057, 0.03800351230893284, 0.08866876902175136, 0.04543459988781251, 0.04022965476906393, 0.0058735213769978145, 0.08185062120901421, 0.04176236041530501, 0.027235463458055165, 0.013080288790661143, 0.03479665880149696, 0.010220698241028003, 0.05770827156084124, 0.07261562495841645, 0.0760969432303682, 0.0031575452157994732, 0.05495908197190147, 0.017250404525839258, 0.012322022594162263, 0.026227927482977975, 0.07660177434445359, 0.04705669722170569, 0.0535381177905947, 0.03509611538902391, 0.08154041090165265, 0.05029285071941558, 0.012754825493175304, 0.0465444297879003, 0.03329662991745863, 0.08889378077583387, 0.04613407036231365, 0.05095216358313337, 0.03778303878789302, 0.038346069122781046, 0.008633893739897758, 0.010232097629341297, 0.10541477473452687, 0.04492224339628592, 0.04739508316561114, 0.013595833734143525, 0.03800727499765344, 0.009481155502726324, 0.03579111071303487, 0.047385977013618685, 0.030731392762390897, 0.004379109159344807, 0.07276687465491705, 0.011582704355532769, 0.018946414202218875, 0.05536805729207117, 0.03411492194572929, 0.05776353558758274, 0.03573017296730541, 0.017976438321056776, 0.03098189914453542, 0.031963049914338626, 0.029143378560547717, 0.03523029197822325, 0.03128654519969132, 0.023195738431240898, 0.048751291251392104, 0.039609056038898416, 0.0615152145473985, 0.052881439551129006, 0.07358546354225837, 0.00838802763610147, 0.05032553119235672, 0.00038939453645525646, 0.04892176999419462, 0.037846792984055355, 0.02422208784992108, 0.05176494887564331, 0.037604563403874636, 0.05557192154810764, 0.023566003328596707, 0.056536075280746445, 0.04028040653793141, 0.07264474683324806, 0.06386427892721258, 0.03375921427505091, 0.03717551669979002, 0.0021900237561567337, 0.06639003011514433, 0.0203316458282643, 0.03473660421150271, 0.030879241567163263, 0.03690353812999092, 0.0634035091206897, 0.04789251877809875, 0.01936712102178717, 0.03470915216894355, 0.021806695876875892, 0.06928249873453751, 0.04601219487085473, 0.041102038230746984, 0.044175509246997535, 0.018214832853118423, 0.01585393492860021, 0.030963651588535868, 0.011456736847321736, 0.039538088167319074, 0.021816605403728317, 0.02458413346175803, 0.032768291275715455, 0.00347868457538425, 0.020112452511966694, 0.07094314321875572, 0.02267081923491787, 0.017073227900255006, 0.02821631551341852, 0.07191604687250219, 0.05126362440933008, 0.05746450573496986, 0.02398760258074617, 0.015491508038394386, 0.025226968791685067, 0.021775460736535024, 0.054089811819721945, 0.051072859059786424, 0.015271055854100268, 0.015471770620933967, 0.03574041089450475, 0.07231478797621094, 0.026067310027428903, 0.05502013475052081, 0.0225108437371091, 0.07034992973785847, 0.05123162300151307, 0.04276886480511166, 0.0670391198946163, 0.014558672937710071, 0.07818171769031323, 0.07305685401661322, 0.010550440947554307, 0.04669229529099539, 0.05197785249038134, 0.04821663322218228, 0.0455377806792967, 0.055026669360813685, 0.02483359341567848, 0.04552854094072245, 0.027206671838939656, 0.048186090134549886, 0.04890621828963049, 0.06894405712955631, 0.08191114335204475, 0.04284283837478142, 0.07356464629992843, 0.021096536620461848, 0.01931134676851798, 0.033786926069296896, 0.062275533709907904, 0.073694477614481, 0.01864285353804007, 0.04482239113713149, 0.03134684469841886, 0.024409034849668387, 0.01648647852562135, 0.01865562218881678, 0.007199066703833523, 0.03231547358154785, 0.05442603811388835, 0.03887609243975021, 0.037799284400534816, 0.028528939656098373, 0.018816287883964833, 0.010710805145208724, 0.027700142527464777, 0.038705146143911406, 0.022960288370086346, 0.02483712789398851, 0.004415362145664403, 0.04326877919083927, 0.05016008792154025, 0.06802488496759906, 0.04862710768065881, 0.010901270852627931, 0.02904730568843661, 0.01752373565977905, 0.06552425547852181, 0.003572356831682555, 0.0462300671642879, 0.03856688774249051, 0.024690748541615903, 0.047868914771243, 0.09818776292377152, 0.02622921696456615, 0.03855094269965775, 0.022047767706681043, 0.021734898655267898, 0.052051707316422835, 0.055804046787670814, 0.05100434769701678, 0.0923266368045006, 0.0234642864234047, 0.02752510514255846, 0.019021946282009594, 0.014097152634349186, 0.021481650037458166, 0.06877171559608541, 0.0525394579017302, 0.004157487164775375, 0.03172605989675503, 0.0198497897508787, 0.07306660583708435, 0.07281388228875585, 0.011613353199209087, 0.10030271310824901, 0.01784895961463917, 0.09481537708779797, 0.05631546817312483, 0.06331074066110887, 0.09506022644927725, 0.04491029481869191, 0.06708691420499235, 0.02298031708050985, 0.03858347474306356, 0.04386269400129095, 0.03642777694039978, 0.03864145874103997, 0.07859535369789228, 0.02792394458083436, 0.018656789216038305, 0.05387571334722452, 0.011132424806419294, 0.004625332421710482, 0.051711462292587385, 0.0357286255893996, 0.044327938958304, 0.025451974979660008, 0.02533284543460468, 0.039209698952618055, 0.1349343071342446, 0.038014603705960326, 0.015779555033077486, 0.056773094984237105, 0.03563202764780726, 0.03958992718253285, 0.04363854313851334, 0.12977741978829727, 0.15797285683220252, 0.10424800726468675, 0.1525856662192382, 0.13619076315080747, 0.17664020124357194, 0.1086268195649609, 0.11414091000915505, 0.14803652360569686, 0.12264746605069377, 0.14856873254757375, 0.0854259695915971, 0.1089626933389809, 0.10658318235073239, 0.1687604037579149, 0.14771829068195075, 0.2317918965127319, 0.1489060535095632, 0.06588624542928301, 0.15139163966523483, 0.04656811543100048, 0.09801475345739163, 0.10164953302592039, 0.23570982768433169, 0.09245595603715628, 0.1817360395216383, 0.10826479992829263, 0.15812731260666624, 0.1480808001360856, 0.17584119021194056, 0.14395322708878666, 0.1206528625334613, 0.21706179395550862, 0.17699386429740116, 0.1452879945281893, 0.13747533172136173, 0.12787204468622804, 0.22795316734118387, 0.09690841907286085, 0.09705070362542756, 0.15364643273642287, 0.16466391185531393, 0.19902129715774208, 0.1510094039258547, 0.25739278527908027, 0.06309238597168587, 0.10248305392451584, 0.13125674275215715, 0.14601380011299625, 0.158084386785049, 0.11101450902060606, 0.23679331876337528, 0.16230340726906434, 0.1538994605652988, 0.14415359211852774, 0.09846252083661966, 0.18964491435326636, 0.08692144168890081, 0.09400504088262096, 0.1683504116954282, 0.1440134152653627, 0.1863819285063073, 0.12638938205782324, 0.15434553584782407, 0.1456931626307778, 0.23163846490206197, 0.09915204282151535, 0.15906569897197187, 0.21545537078054622, 0.15540891472483054, 0.17975661292439327, 0.15028632944449782, 0.13181278947740793, 0.10984163367538713, 0.1624212900060229, 0.14127708709565923, 0.1296922509209253, 0.16353384358808398, 0.21423033729661256, 0.1413436874281615, 0.07781167543726042, 0.18300871888641268, 0.1386663451557979, 0.26100921153556556, 0.17200170404976234, 0.1268135046120733, 0.0747282596421428, 0.10328195363399573, 0.2066496995394118, 0.12517871655290946, 0.15395032736705616, 0.0955194525886327, 0.11862205705256201, 0.10161110461922362, 0.10393590448074974, 0.1315397978760302, 0.19760961353313178, 0.17873282020445913, 0.22336645721225068, 0.157100313808769, 0.19246034062234685, 0.13625268795294687, 0.24817397526931018, 0.11852231982629746, 0.1114801547373645, 0.14308354875538498, 0.10267529985867441, 0.11651395689113997, 0.09919163640006445, 0.20505725842667744, 0.11799724292359315, 0.1580828134319745, 0.16256394563242793, 0.1241472945548594, 0.1258308268734254, 0.11088072205893695, 0.14145451976219192, 0.1300831401022151, 0.15786300413310528, 0.14747298118891194, 0.1473387860460207, 0.14478576835244894, 0.1823921871255152, 0.07893994028563611, 0.19840163353364915, 0.14283498865552247, 0.1902668786351569, 0.15039293153677136, 0.17829847085522488, 0.12501038261689246, 0.130476315098349, 0.05371421459130943, 0.16182028397452086, 0.1002027458162047, 0.08871643716702238, 0.17531690740725026, 0.14448055269895121, 0.20139992499025539, 0.10311114834621549, 0.1220286262105219, 0.08591618781792931, 0.1506012078607455, 0.2113587749772705, 0.2315500602708198, 0.17254387261345983, 0.15931875648675486, 0.15182817092863843, 0.21979499026201665, 0.12937836698256433, 0.15990034793503582, 0.12328245502430946, 0.090448253613431, 0.0895693949132692, 0.07500016770791262, 0.13171383150620386, 0.17233724385732785, 0.13476793246809393, 0.14405985886696726, 0.17370358225889504, 0.1653892721515149, 0.18637299304828048, 0.07767655260977335, 0.11177880980540067, 0.11523732930072583, 0.13129907485563308, 0.08896785453543998, 0.12078961808583699, 0.11134023021440953, 0.1287494710413739, 0.15168630197877064, 0.10991358489263803, 0.12324271301622503, 0.21637760801240802, 0.09293061142670922, 0.13954638387076557, 0.11418576541473158], [0.045949190243845806, 0.04701040576037485, 0.011370319316483801, 0.053463235090021044, 0.002489291096026136, 0.025387836722075008, 0.023774559813318774, 0.020615777066268492, 0.05333547436748631, 0.015213874303299235, 0.059035836457042024, 0.05163226400327403, 0.058389295954839326, 0.02920121969509637, 0.021382851628004573, 0.04205946810543537, 0.04346574889495969, 0.049721408140612766, 0.029774987051496282, 0.048175024712691084, 0.0037165846515563317, 0.041759978121262975, 0.028511441669252235, 0.055339614482363686, 0.05907784201554023, 0.034399865835439414, 0.0352476322586881, 0.007603559452036279, 0.052542456178343855, 0.06514386026537977, 0.03229095302231144, 0.06302699533989653, 0.07368694481556304, 0.1007246611698065, 0.0393083303788444, 0.013526292641472537, 0.04439112912223209, 0.026422453665873036, 0.02364017356740078, 0.08232705033151433, 0.044125763088231906, 0.04470555853913538, 0.04154806898441166, 0.004710293487732997, 0.00766479173762491, 0.05386068485677242, 0.08448317486909218, 0.03177003214659635, 0.019306233371025883, 0.007825488974049222, 0.05320280804880895, 0.04015903570689261, 0.048075165032059886, 0.03463293731329031, 0.08074423487414606, 0.005132224387125461, 0.06222774682100862, 0.029333594720810652, 0.05221315412200056, 0.022877640949445777, 0.04701463600213174, 0.05705182709789369, 0.062024776852922514, 0.014118773251539096, 0.09462955815251917, 0.049107154773082584, 0.025668574489827733, 0.018134448982891627, 0.03995975792349782, 0.022469897594419308, 0.03615087793150451, 0.009526344874757342, 0.03694387385621667, 0.04113946473808028, 0.018247667321702465, 0.050536037670099176, 0.01536222776849172, 0.020914083324896637, 0.03147743671434, 0.02837719272065442, 0.05301863297063392, 0.08008543038158678, 0.04327236376411747, 0.016727656111470424, 0.08270446211099625, 0.024728679709369317, 0.05719454580685124, 0.03624915312684607, 0.04238843990606256, 0.018842802965082228, 0.06304692942649126, 0.03856309165712446, 0.0505221780622378, 0.036925943568348885, 0.039257025709957816, 0.06315251477644779, 0.005904212430323241, 0.007570270881842589, 0.05782928616099525, 0.0192842305477825, 0.00853513614856638, 0.07364583725575358, 0.05807635454402771, 0.08147689790348522, 0.018240618774143513, 0.0496779553941451, 0.05998539214488119, 0.012946915576321771, 0.020149749143456575, 0.03883814642904326, 0.04053261800436303, 0.04423417973157484, 0.10142762344912626, 0.06166446415591054, 0.020861246121057775, 0.0527123968640808, 0.05815137454192154, 0.017109791660914198, 0.023336321610258892, 0.06299782893620431, 0.07309033971978351, 0.02779585545795271, 0.05954961045063101, 0.02599192081106594, 0.01357793034912902, 0.049540665495442227, 0.0268756572768325, 0.03302858844108414, 0.027648889808915555, 0.04204099976050202, 0.07251354254549369, 0.02878236824471969, 0.04675709220464341, 0.04596487182425335, 0.055091232497943565, 0.04087479261215776, 0.05664136006089393, 0.02795028154650936, 0.03331181425892282, 0.03332561449497007, 0.023999556724447757, 0.07799148297635838, 0.02500023525499273, 0.07218301965622231, 0.06822421099059284, 0.05501903266122099, 0.027083145068900194, 0.04585338640026748, 0.018917162451543845, 0.029781623707094695, 0.035777863377006724, 0.04350009920017328, 0.037285020589479245, 0.04837972388486378, 0.022450601754826494, 0.07093332460499369, 0.05984060655464418, 0.04154232476139441, 0.0025690228039820795, 0.029261138843139634, 0.05360111499612685, 0.07736796018434688, 0.036398540032678284, 0.08419914753176272, 0.12236559094162658, 0.008905651520763058, 0.037042364274384454, 0.08424531653872691, 0.05813033836602699, 0.0530383555451408, 0.0388503324938938, 0.0588787275046343, 0.017257436375075486, 0.007657059022676549, 0.059180536700296216, 0.07758931315038353, 0.056720009160926566, 0.048307995311915874, 0.0364673890726408, 0.026628503546817228, 0.0300751802205923, 0.06838392117060721, 0.042554985266178846, 0.03888851970259566, 0.038317184735205956, 0.02857612355001038, 0.04195098466880154, 0.009533433312753914, 0.06092589734180365, 0.054960351044428535, 0.034987231192644686, 0.02870289536076598, 0.037570320710074157, 0.03220074868295342, 0.0655903882579878, 0.020015758091176394, 0.03759399522095919, 0.027397281337471213, 0.03823224964435212, 0.10131376315257512, 0.0008941125599903899, 0.05717984386137687, 0.034428245562594384, 0.03263617785705719, 0.04821084447030444, 0.0031579209280607756, 0.0519960091332905, 0.054203753752517514, 0.02844996957719559, 0.09314738534158096, 0.05602286531939171, 0.046404078530031256, 0.01043380965711549, 0.04150596694671549, 0.04261079477146268, 0.06090955524996389, 0.0384768132789759, 0.04704078186478, 0.00665968815155793, 0.013090833781461697, 0.0667429064924363, 0.04071542753081303, 0.029949751697131433, 0.05344603952835314, 0.029145766420697328, 0.021665867789124604, 0.0724129295849707, 0.03634704611613415, 0.04153368245169986, 0.022047791826480534, 0.03275569331890438, 0.03490426650387235, 0.06028427727869712, 0.027983364634565078, 0.017865607842395548, 0.032093356203404255, 0.07985590636963025, 0.09038494099513628, 0.012651827455556486, 0.02914368098572595, 0.07276798787643202, 0.03899778981576674, 0.022065050470700953, 0.03456799197010696, 0.03841110723442398, 0.015665006394556258, 0.033280811039730906, 0.025261129849241115, 0.028503502544481307, 0.02047458903689403, 0.03484009299427271, 0.016187378168979194, 0.046794745067018084, 0.05907869177462999, 0.04433919733855873, 0.028157645028841216, 0.02224841660790844, 0.07759176965919323, 0.046587964170612395, 0.05742326829931699, 0.054132444493006915, 0.05137323591043241, 0.04886039067059755, 0.011302213351882529, 0.005395968828452169, 0.061699831203441136, 0.015842914035602007, 0.07321896133362316, 0.11212174882530235, 0.018136649450752884, 0.03439527194132097, 0.07933361994219013, 0.032566720255999826, 0.06537500958074816, 0.1156089300638996, 0.06552290476975031, 0.041136626023217104, 0.027040132044930942, 0.03400447923922911, 0.04614352532371413, 0.04516670684097335, 0.05645832417940255, 0.01204674425025587, 0.08200236814445816, 0.016641294241708238, 0.014879604495945387, 0.06756283124559559, 0.03546950843883678, 0.0589554804173531, 0.04844220900849905, 0.04356895195087418, 0.016151805175468326, 0.090451177675277, 0.038473058011732064, 0.06004786613630131, 0.019018760613107588, 0.010661745473043993, 0.06567564618308097, 0.027058383311668877, 0.050794687267625704, 0.0408945263188798, 0.05475863530591596, 0.04801646115083713, 0.020922310031892266, 0.03091761245741509, 0.014652496174676344, 0.03950824640924111, 0.05703942952095531, 0.025711745220178273, 0.015169653433986241, 0.021879097948840354, 0.0021865734652237734, 0.015557805945718428, 0.015067838194227079, 0.02842316320311511, 0.05427321506431326, 0.01509577727119904, 0.06262164912186563, 0.07537847748608328, 0.02551590914663393, 0.05888637162570376, 0.030855236800562125, 0.029589656078314874, 0.03183011642249767, 0.009356751143059228, 0.029132669369573705, 0.05606835155049339, 0.04849762888625264, 0.01777685625711456, 0.012510163523984374, 0.051065619409200735, 0.05021389362809714, 0.06713430033414625, 0.0029106401052558795, 0.08289718301966786, 0.012959929135831771, 0.013060340788797475, 0.04986389678379055, 0.003565564556993195, 0.07119490197510459, 0.031357932384707965, 0.05036540678702295, 0.04280885914340615, 0.04778552334755659, 0.047853867727098987, 0.018023176926362794, 0.066220085718669, 0.036638888268498704, 0.04211870262224693, 0.038527787692146376, 0.03823383784038015, 0.09638567251386121, 0.10803753204527311, 0.13291039620526135, 0.09698935769847594, 0.16331470222212374, 0.10939486077404581, 0.17895231780130416, 0.1875346916494891, 0.13364856597036123, 0.14620519999880344, 0.083570229326142, 0.09015929099405184, 0.11146520046168007, 0.17981090844841674, 0.0885508640203625, 0.09312339170719497, 0.1765762726427056, 0.15444459771970287, 0.13296246528625488, 0.27087852882687, 0.10883606068091467, 0.11871135226101615, 0.09969748425646685, 0.20140414038905874, 0.23410203895764425, 0.185553201881703, 0.12794585869414732, 0.12755437579471618, 0.1391381729627028, 0.1645633953739889, 0.14554158638929948, 0.10840326242032461, 0.12025275587802753, 0.23077643068972975, 0.25713971292134374, 0.15134314773604274, 0.07829430891433731, 0.11211853532586247, 0.15938253665808588, 0.1606900672777556, 0.14700486412039027, 0.08689040507306345, 0.17776025051716715, 0.1889402006054297, 0.1380199790582992, 0.16464160289615393, 0.11118800830445252, 0.17834222788223997, 0.21460423129610717, 0.11365025391569361, 0.10811107145855203, 0.1626206308719702, 0.14446934626903385, 0.14494540431769565, 0.25616209662985057, 0.16742769948905334, 0.14979428553488106, 0.126375533582177, 0.138511355035007, 0.13393016648478806, 0.12533085682662204, 0.1979350156034343, 0.2181628590915352, 0.13558705570176244, 0.08891899153240956, 0.2543896995484829, 0.1346265830215998, 0.16931734106037766, 0.15621957747498527, 0.12695737736066803, 0.17644086037762463, 0.0850378634640947, 0.09907864441629499, 0.12282155905268155, 0.09201813343679532, 0.13247661088826135, 0.13483618036843836, 0.12848881393438205, 0.12747604952892289, 0.08416303462581709, 0.09987401150283404, 0.15579883911414072, 0.12654569320147857, 0.1763444850803353, 0.16139187180669978, 0.1256011618534103, 0.08131951064569876, 0.14917517110006884, 0.12707000569207594, 0.07752194098429754, 0.10955972888041288, 0.1854863195330836, 0.1553348929155618, 0.18960985529702157, 0.10040056527941488, 0.10603173694107682, 0.13368227431783453, 0.1412988023366779, 0.09585026491549797, 0.18108557676896453, 0.16784851206466556, 0.15366728708613664, 0.11902660175110213, 0.13817504339385778, 0.15034855110570788, 0.1337820486514829, 0.10585509095108137, 0.09221075786626898, 0.1323420595144853, 0.09622795128962025, 0.07854957060771994, 0.16253507608780637, 0.1260978664504364, 0.20647042634664103, 0.10208890671492554, 0.13954074354842305, 0.08986486616777256, 0.20370188896777108, 0.12598474830156192, 0.08276934808236547, 0.14618244575103745, 0.169502729550004, 0.22882535413373262, 0.21657470759237185, 0.1043885774561204, 0.09565629719872959, 0.13063589169178158, 0.10370358257205226, 0.0939711692626588, 0.12492046400438994, 0.12680740415817127, 0.1035693429003004, 0.16465730674099177, 0.09279073885409161, 0.14162954787025228, 0.09528694514301606, 0.12460962287150323, 0.1281754791853018, 0.06594462276552804, 0.10806378923007287, 0.11643629855825566, 0.10871253762161359, 0.1624263366102241, 0.2537925081560388, 0.16101260465802625, 0.1223633496556431, 0.31111679621972144, 0.07180010856245644, 0.08675341203343123, 0.10665201654774137, 0.23986846703337505, 0.12706780893495306, 0.16075133898993954, 0.10903666319791228, 0.17284147383179516, 0.14452445815550163, 0.13398892973782495, 0.23875116370618343, 0.09757718318724073, 0.07910682703368366, 0.08375670135137625, 0.10429134126752615, 0.1391232112655416, 0.18217935401480645, 0.14731843635672703, 0.2705567632801831, 0.13733085041167215, 0.14371962868608534, 0.16828393010655418, 0.1826050944509916, 0.0625212216982618, 0.14226289669750258, 0.18015370646025985, 0.09117462323047221, 0.0775991020782385, 0.1295209929230623, 0.17442543961806223], [0.03187372501997743, 0.04463143653993029, 0.026499306768528186, 0.020573996007442474, 0.05912174376135226, 0.006690619939035969, 0.019589628027461004, 0.024940462681115605, 0.031471232359763235, 0.031075430160854012, 0.02872769422538113, 0.01689756340056192, 0.051417156209936365, 0.04676524840760976, 0.034971716595464386, 0.03521029109833762, 0.03428985728533007, 0.008452625097561395, 0.019818491527985316, 0.018415004924463574, 0.07111290949978866, 0.023082091502146795, 0.10121876082848758, 0.02864725283870939, 0.03164085021126084, 0.01756742589350324, 0.04691203779657371, 0.03060482875298476, 0.01837926309235627, 0.02747144415479852, 0.06522093230159953, 0.045209346935735084, 0.0547776157327462, 0.017177241752506234, 0.06174703550641425, 0.058323307894170284, 0.07538845937233418, 0.017087735031964257, 0.01792464197933441, 0.04593054749420844, 0.034663190963328816, 0.018702323686738964, 0.019269983167760074, 0.07551115122623742, 0.034980611235369, 0.005678331899616751, 0.0876208342378959, 0.017191771148645785, 0.02322057440323988, 0.032919496443355456, 0.04401371734275017, 0.03586344042560086, 0.05040893374825828, 0.05292613168421667, 0.025764665915630758, 0.05835996627865825, 0.02880900021409616, 0.0450272869784385, 0.026826605026144534, 0.058616790192900226, 0.06716990857967176, 0.04776249821588863, 0.047023593724588864, 0.07222257612738758, 0.03278317133663222, 0.01501027722042636, 0.06411377413314767, 0.03517222634400241, 0.04398778299218975, 0.03305943952000234, 0.03409634970012121, 0.06158866119221784, 0.01713064601062797, 0.059811818646267056, 0.06595360275241546, 0.037743430366390385, 0.007844034316804027, 0.024424543880741112, 0.051101342687616125, 0.013382900433498435, 0.007753574400339858, 0.058993240891140886, 0.04017010855022818, 0.037688919619540684, 0.030869042602716945, 0.011478193264338188, 0.027820175637316424, 0.029535510839195922, 0.06109653193561826, 0.0513961237447802, 0.011287879697192693, 0.07111018581781536, 0.05586503648373764, 0.039821518075768836, 0.1175341650377959, 0.05486846202984452, 0.0668744150607381, 0.02515924410545267, 0.0684972619637847, 0.016225916042458266, 0.03625763958552852, 0.04794733380549587, 0.02240562575025251, 0.006471286542364396, 0.028683712698693853, 0.019690040608111303, 0.031847441860008985, 0.008818790556688327, 0.01681904603174189, 0.02454798715916695, 0.060463754562078975, 0.06926245332579128, 0.009803947996260831, 0.056096968764904886, 0.03805497653956991, 0.020636770568671636, 0.09953220054740086, 0.028422163159120828, 0.06857948450488038, 0.029867748089600354, 0.0075197241312707774, 0.022847018080938142, 0.03072853920457419, 0.02760241837677313, 0.038481952651636675, 0.06613523597479798, 0.029003533818467986, 0.03898313982062973, 0.02673811133718118, 0.04731846012873575, 0.0666412990540266, 0.04081809624040034, 0.10539059556322172, 0.015698592287662905, 0.03315408932394348, 0.08587516189436428, 0.05007870771805756, 0.005059646982772392, 0.020600926691258792, 0.04722725760075264, 0.05468351511808578, 0.012713811629510019, 0.006330186179184238, 0.07193114215624519, 0.014689492236357182, 0.031167044580797665, 0.05701629306713585, 0.09909419983159751, 0.08665923349326476, 0.10216073918854818, 0.01507404162111925, 0.016389067932323087, 0.039824490377213806, 0.01954093200765783, 0.04489800114242826, 0.02942052247817628, 0.0558912491396768, 0.055604991648579016, 0.05128371805767529, 0.009770625565579394, 0.0745770767389331, 0.0498694851557957, 0.03463854423898738, 0.03292222012532875, 0.03748921510123182, 0.05960087801213376, 0.024598874369985424, 0.03467009293672163, 0.03981272362580057, 0.0352043427847093, 0.04746216218336485, 0.0383997709286632, 0.056200936232926324, 0.011543673881533323, 0.027158992561453488, 0.030110348743619397, 0.02872483881219523, 0.0263636570161907, 0.04956240300089121, 0.05335137488145847, 0.015721489398856647, 0.010391220585006522, 0.06321380133158527, 0.02076095228403574, 0.06900814158143476, 0.033695463789626956, 0.03318039474834222, 0.023191291111288592, 0.03642927607870661, 0.016447055641037878, 0.04483515607716981, 0.030798020925431047, 0.05485954512550961, 0.06985375206568278, 0.037346232929849066, 0.0969376225839369, 0.021927608431724366, 0.03407080868782941, 0.004209205117149395, 0.024555276904720813, 0.046158598343026824, 0.021976772004563827, 0.05615040339762345, 0.020379518064146396, 0.038167883176356554, 0.05926563135290053, 0.060322408826323226, 0.026767127455968875, 0.07006951665971428, 0.04653787662391551, 0.0124367243006418, 0.05722726338717621, 0.024778336810413748, 0.047521196320303716, 0.038865208844072185, 0.03213108328054659, 0.033080249340855516, 0.04887076218437869, 0.009166126801574137, 0.03552750356902834, 0.018800901307258755, 0.03468213057203684, 0.11144435353344306, 0.017415294896636624, 0.06211610554601066, 0.018900430732173845, 0.03754355515411589, 0.03559493139619008, 0.0683225084503647, 0.10856133245397359, 0.029570009573944844, 0.013548683236876968, 0.012603219565789914, 0.06819928225013427, 0.0680881085281726, 0.014762440714548575, 0.0621083501027897, 0.042121879014302976, 0.06959893566090614, 0.04450765743968077, 0.03009461892361287, 0.03288529456767719, 0.10095258956425823, 0.0945749731909018, 0.032688799838069826, 0.02566046838182956, 0.013884147901990218, 0.012883565850643208, 0.023715004317637067, 0.01732365635689348, 0.038198763941181824, 0.03364594769664109, 0.08633964986074716, 0.057578050618758425, 0.050434062868589535, 0.008809869013930438, 0.051775268439087085, 0.02725247719354229, 0.06444156591896899, 0.019784386131505016, 0.037961595808155835, 0.0034399880678392947, 0.015279918025044026, 0.0073606679688964505, 0.038350577669916674, 0.045097345719113946, 0.02768106191069819, 0.04112635098863393, 0.012271873820282053, 0.11352468995028175, 0.05010779990698211, 0.05802023704745807, 0.060970225822529756, 0.024616149712528568, 0.016884219585335813, 0.013695064444618765, 0.094891105836723, 0.05610489119135309, 0.030074647729634307, 0.026272554678143933, 0.026318436102883425, 0.017615114447835367, 0.05380476031859871, 0.08750525958021171, 0.02874847807106562, 0.07280180012458004, 0.047825220826780424, 0.04104410618310794, 0.019150209809595253, 0.022110657300800085, 0.01052266236001742, 0.028729030091199093, 0.02009089683269849, 0.07054489935399033, 0.05944915334112011, 0.040850513250916265, 0.03244795436330605, 0.038135822396725416, 0.05282994934532326, 0.03891440210281871, 0.07866072948672809, 0.04414861381519586, 0.05443271002150141, 0.02440163563733222, 0.03484262000711169, 0.010246640940749785, 0.04718205709650647, 0.03388682656805031, 0.0634944073681254, 0.022687678974762093, 0.038803595743956976, 0.07104110671207309, 0.04346641311713029, 0.05601929558906704, 0.022421602334361523, 0.044636935854214244, 0.01810556830605492, 0.05011359608033672, 0.012078495183232008, 0.04513233798206784, 0.03590040680137463, 0.0419345275440719, 0.01660606634686701, 0.05320288968505338, 0.05685584073944483, 0.058734428021125495, 0.06250197780900635, 0.006571766380147892, 0.07677864297875203, 0.013888936609873781, 0.020922894473187625, 0.08136328251566738, 0.03480634753941558, 0.019798995308519807, 0.014496873372991104, 0.06855459287180565, 0.044670239731203765, 0.12012477993266657, 0.03865223843604326, 0.050279666465939954, 0.07261854902026244, 0.04478316863242071, 0.011640844204521272, 0.0829936028458178, 0.03844383965770248, 0.02943872179457685, 0.02599187813757453, 0.06429786386433989, 0.01748071521433303, 0.04576916377118323, 0.059879754844587296, 0.023473678302252665, 0.09726464995765127, 0.18252056383062154, 0.09867074521025643, 0.10802418080857024, 0.14754973410163075, 0.10692001349525526, 0.11844659107737243, 0.23361896019196138, 0.11218125422601588, 0.10165314728510566, 0.085150669910945, 0.09213427954819053, 0.20496122451731935, 0.14060698711546138, 0.14323341805720702, 0.11987049045274034, 0.11849688642541878, 0.16079790133517236, 0.20565618644468486, 0.2111592114670202, 0.08695608514244668, 0.08251215680502355, 0.16132065531564876, 0.18753866956103593, 0.13614743656944484, 0.08800040566711687, 0.1926894416101277, 0.07026328399660997, 0.10346421026042663, 0.17234656523214653, 0.16358454711735249, 0.10386148933321238, 0.1902571416576393, 0.10478684358531609, 0.10815379690029658, 0.23082799511030316, 0.1657410798361525, 0.15999231487512589, 0.1145367047865875, 0.08349519077455625, 0.07644287310540676, 0.15093892958248034, 0.08452293914160691, 0.15491768717765808, 0.11435116786742583, 0.10929919793852605, 0.327972216764465, 0.11104079589131288, 0.16169386653928086, 0.11163828414282762, 0.11533541895914823, 0.23846332915127277, 0.18453945784131065, 0.17063558829249814, 0.051325129898032174, 0.16896183748031035, 0.0894382203114219, 0.12141741564846598, 0.11676633905153722, 0.1324029007810168, 0.20091904298169538, 0.15302479499951005, 0.14531140186591074, 0.14972191129345447, 0.10744498649728484, 0.1327500626211986, 0.20083684270503, 0.1336731162155047, 0.16475436481414363, 0.149219180457294, 0.21883606124902144, 0.14560921088559553, 0.08733415001188405, 0.09423901778063737, 0.1401769125368446, 0.1266732980730012, 0.2483825187664479, 0.1444598170928657, 0.07196735896286555, 0.08229225102695636, 0.11938048744923435, 0.15796473773662, 0.11039022923796438, 0.08116813478409313, 0.10483702018973418, 0.07272927003214136, 0.10703588501201011, 0.10397817721241154, 0.12971288262633607, 0.07983641015016474, 0.18890186125645414, 0.11698744710884057, 0.10420752310892567, 0.13944090984296054, 0.18092343234457076, 0.09276546130422503, 0.2092598774470389, 0.09239248756784946, 0.16184149455511943, 0.12297790730372071, 0.23926207300974056, 0.15344122890383005, 0.10877314882236533, 0.18322404561331496, 0.1292295812163502, 0.08238947237259708, 0.1508114582975395, 0.09606282343156636, 0.17412581975804642, 0.12029056088067591, 0.1411830124561675, 0.14936238527297974, 0.04191638945485465, 0.1570861684740521, 0.06640375242568552, 0.08789021158008836, 0.19374501309357584, 0.2184883353766054, 0.1977344130864367, 0.05571459943894297, 0.13034393079578876, 0.11156148670124821, 0.13618231751024723, 0.0837560037325602, 0.2282701979856938, 0.09561196129652672, 0.2130799787119031, 0.11216241109650582, 0.08676978381117806, 0.16426312242401764, 0.16331458347849548, 0.17864687950350344, 0.24453328078379855, 0.07342677752603777, 0.06378956692060456, 0.1777698242221959, 0.09862174862064421, 0.12367720337351784, 0.15519952517934144, 0.14053575578145683, 0.1116561699018348, 0.12373941761325113, 0.10269972393871285, 0.22828251763712615, 0.11507672112202272, 0.17243188252905384, 0.12592304614372551, 0.21585185575531796, 0.16658221516991034, 0.2173005131771788, 0.13460638176184148, 0.053940202269586734, 0.20398491440573707, 0.11518306346260943, 0.18866873782826588, 0.15337302553234622, 0.11663625540677458, 0.14387665229151025, 0.14280941424658522, 0.13748119468800724, 0.08186162725905888, 0.1597462929203175, 0.25856730819214135, 0.16723828855901957, 0.15594838187098503, 0.07258786863530986, 0.0846819368598517, 0.1434651462477632, 0.1541971805272624, 0.13708839076571167, 0.07998584900633432, 0.16038284782553092, 0.1478933187900111, 0.06516369045129977, 0.13070074055576697, 0.1305283248075284], [0.025446805921092164, 0.008410943300987128, 0.03559394433978014, 0.051030400791205466, 0.01592823875398608, 0.014457339166256133, 0.03583069315936882, 0.13514102494809777, 0.02834259194059996, 0.059934755408903584, 0.03504383108520415, 0.04355820936325472, 0.06283561029704288, 0.0515876089775702, 0.05784449647762813, 0.03785525346756913, 0.01544912676763488, 0.04754330489959102, 0.02148905481590191, 0.036310328359832056, 0.041601989723858424, 0.054113694131956436, 0.013758830700680846, 0.03393807928659953, 0.02918872378359083, 0.005394305953814182, 0.06546719916514121, 0.04038333870994393, 0.06692540060612373, 0.04721086355857551, 0.06077715239371173, 0.009004900784930214, 0.03692310485348571, 0.06474777605035342, 0.07605400998727418, 0.03904751742084045, 0.018630962476891, 0.05498600337887183, 0.04243914343533106, 0.004291510686016409, 0.03071115253987955, 0.035104123162454925, 0.01794280789908953, 0.05237471224972978, 0.08263248862931505, 0.014623329770984128, 0.045830839953850955, 0.0415626002359204, 0.04524752301222179, 0.00758831481107336, 0.017347787288599648, 0.038094829869805835, 0.019281814857095014, 0.05204408545978367, 0.07437515319907106, 0.05662180818035267, 0.018856866663554683, 0.06944057618966326, 0.023547271521238144, 0.017800055793486536, 0.030530196527251974, 0.030992346728453413, 0.025856339707388543, 0.03371048856934067, 0.05112059028760996, 0.018750995586742647, 0.039967305565369315, 0.05764953057223465, 0.05324653167917859, 0.03160677450068761, 0.055017811828292906, 0.022901380398252513, 0.05302101526467595, 0.06111317459726706, 0.045096529356669635, 0.04153199406573549, 0.014406896316359052, 0.024684254749445245, 0.044263976960792206, 0.0474839293747209, 0.019218810230086092, 0.049295163044007495, 0.05655120396113489, 0.026686736164265312, 0.07109400699846447, 0.062457849708152935, 0.04353154028649442, 0.03466715403192211, 0.11000895086908713, 0.024080116854747757, 0.027895997154701035, 0.03529126312059816, 0.035380313420319, 0.06323577632429078, 0.014773867005715147, 0.02079684996715514, 0.023976164229679853, 0.06296639898209833, 0.047424535296158865, 0.02509473662939854, 0.05709644501621369, 0.028277520432311576, 0.03329209539515432, 0.014910320132912602, 0.051049574176431634, 0.03804683517955709, 0.021858961627003737, 0.031678781379014254, 0.07362436692346819, 0.0453617432503961, 0.032350584588130005, 0.061473654277506284, 0.04467262944672257, 0.06518248163047247, 0.018735386365733575, 0.03173888791934587, 0.0645516932127066, 0.02135409155016532, 0.048571190563961864, 0.027916983235627413, 0.027976108285656665, 0.0362845572817605, 0.048345807736041024, 0.09049519445397891, 0.04461324650037568, 0.09049356172909029, 0.08061205095145851, 0.10608860029606149, 0.011568469963094685, 0.023293956110137515, 0.01236270156368846, 0.007424988052662229, 0.05899413888982963, 0.0595102172519546, 0.0942824111552909, 0.03040482923097443, 0.021799320784339216, 0.012478676981118042, 0.03847902858979069, 0.09539748803945258, 0.023915575293358415, 0.02438651252305135, 0.04073531708854716, 0.04688258566602599, 0.03808525245403871, 0.07536599456216209, 0.04401320526085328, 0.02391492591414135, 0.10114612683537416, 0.0750322878593579, 0.04529458259639796, 0.009947054477379424, 0.10203048484981991, 0.0433513690950349, 0.046369579795282334, 0.06739339893101715, 0.07984152354765683, 0.01743250530125806, 0.006654912895101006, 0.022374195796146523, 0.028571824659593403, 0.003443860223342199, 0.005442139690785552, 0.014800304161326494, 0.06082702842832077, 0.014131508505670354, 0.055283003457589075, 0.024552306458645035, 0.05388168392528314, 0.01623911884962581, 0.020157884937361814, 0.05118488996231463, 0.008775536334724165, 0.021408750726550352, 0.008099127171590226, 0.008280704732896993, 0.0526615597482305, 0.030092307133600116, 0.014077712075959425, 0.028161407717561815, 0.02955726689833682, 0.029228838720882777, 0.05599947653536219, 0.03697855441714637, 0.013653856694872957, 0.03829105742624961, 0.021730306616518646, 0.013279550803417806, 0.06342490523820743, 0.08172517598723061, 0.036826310242759064, 0.04298817686503753, 0.015859187478781678, 0.08144781313603744, 0.024586502768215723, 0.057230276506743394, 0.00900037368410267, 0.05191523006942589, 0.03866607577947434, 0.010971119008900132, 0.05178561026696116, 0.03913438580639195, 0.05699804736650549, 0.013737554254475981, 0.06947757967282087, 0.040856172126950696, 0.06120208759966772, 0.049627207336016, 0.0574346639768919, 0.03736248967470601, 0.03148568939650431, 0.0665831814694684, 0.03335307766974438, 0.030829723618808202, 0.03508404806780163, 0.017091763038479257, 0.015595474578731228, 0.012277651439944748, 0.03737301332876086, 0.08192819048417732, 0.047823250424698927, 0.01933541276230244, 0.02596103076939471, 0.02673583850992145, 0.04895951191429049, 0.03282055331510492, 0.05922652388107963, 0.06218901042302605, 0.028186219569761306, 0.028334441303741187, 0.019000316387973726, 0.04756920214276761, 0.07704483650741167, 0.03985019837273285, 0.0474021298578009, 0.041169057876686566, 0.011252023759880103, 0.09822117441217415, 0.07111065337085165, 0.18578721588710323, 0.015566894471703563, 0.02024555669777328, 0.022356135632435326, 0.04325549474742729, 0.054001585303922184, 0.05712881749786902, 0.04028570547234267, 0.10142335609998554, 0.06899526531924494, 0.03992577127064578, 0.010369749325036537, 0.03661232680315152, 0.08096451172605157, 0.03556226576620247, 0.008856739350449061, 0.05906604928895831, 0.013733929790760158, 0.03712912504852284, 0.04722871963167563, 0.04385796652059071, 0.036820480672759004, 0.020297742667025886, 0.008364892109966604, 0.008638924573460827, 0.03569410459022038, 0.053253415098879486, 0.0717150881246198, 0.03980971421697177, 0.1334268122445792, 0.009520148869341938, 0.008305589872179553, 0.03236707139876671, 0.014470157912001014, 0.01993794576264918, 0.023323142922890838, 0.046832594598527066, 0.03326425372506492, 0.025506168458377942, 0.07332927416427992, 0.0014296329300123034, 0.036852133271167986, 0.009969740076485323, 0.08077567967120558, 0.026820294915523846, 0.0628520488680806, 0.03205598906788509, 0.0792740477481857, 0.007336152048083022, 0.027528943901415914, 0.034283779095858335, 0.05130774137796834, 0.005849158060300397, 0.059596310093184, 0.04000028289738111, 0.014790669229114428, 0.07493751560105011, 0.024262891129183117, 0.020185106914141215, 0.03123183036223054, 0.026773851313919295, 0.03481755768007133, 0.037529899636865593, 0.07740798420854844, 0.044140257232356817, 0.014904710424161749, 0.023268936456588563, 0.04912936354230624, 0.02856273335055448, 0.016874067005119286, 0.025518577167531475, 0.10622376023093238, 0.03454249177593738, 0.029835110290150624, 0.03038898252270883, 0.03948844219848979, 0.057821185619104654, 0.022938539732422214, 0.0157526837210753, 0.06160944503790233, 0.00879695007824921, 0.019262557980255224, 0.05006826941098552, 0.03693491984449793, 0.005741747954743914, 0.11433498162659816, 0.04945088046952151, 0.028655011992668733, 0.07924300371087156, 0.04240138296154328, 0.025327724615635816, 0.08341106833540834, 0.04027559371024836, 0.04028036943054758, 0.02073167826893041, 0.04407318934681825, 0.018112850630132016, 0.024583382037235424, 0.048887924349401146, 0.0385485418519238, 0.05776944679382723, 0.053316646080929786, 0.04399074416141957, 0.019214088315493427, 0.04222975388984196, 0.03849528533464763, 0.07884300095611252, 0.09258337537175976, 0.08332437806529924, 0.038412272406276315, 0.005854490391357103, 0.050191065165563487, 0.01711968634481309, 0.1405160888680257, 0.17973755457205698, 0.133806420781184, 0.11532475429703481, 0.20922759402310476, 0.16148766822880134, 0.20295079099014401, 0.35042728995904326, 0.11254797907895409, 0.1856058498378843, 0.13255704485345632, 0.11057460098527372, 0.19287011004053056, 0.1712242598296143, 0.11905872932402417, 0.1814234914490953, 0.11469609584310092, 0.1842510444112122, 0.07327342013013549, 0.12602635310031474, 0.11553475982509553, 0.12523356126621366, 0.17684675578493625, 0.13047287153312936, 0.22654301254078746, 0.13160509202862158, 0.17894554941449314, 0.13222248468082398, 0.16148388327565044, 0.09247185284039006, 0.1468733258661814, 0.22163081128383055, 0.14497083029709756, 0.19093527167569846, 0.1521925357519649, 0.1015327635104768, 0.21788986749015749, 0.13411315041594207, 0.19119570613838732, 0.12593094259500504, 0.09346933642518707, 0.10171776608331129, 0.137916449457407, 0.1793504651868716, 0.16624979238258675, 0.07997410823008977, 0.12040494810207747, 0.11215548685868271, 0.14565103832865134, 0.09638107861974277, 0.11806264097685926, 0.12189633838715963, 0.1526955486042425, 0.1317967294016853, 0.11958204733673483, 0.14443627616856247, 0.16865978337591514, 0.13011110422667116, 0.18212676543043926, 0.13687181723071262, 0.11377595888916403, 0.13155931635992602, 0.1301143696764484, 0.255067577236332, 0.09809359180508181, 0.1098887600528542, 0.15347100386861712, 0.23610652046045288, 0.21221485716523603, 0.08989347596070729, 0.1770309271523729, 0.20572621549945325, 0.2096843413892202, 0.15064310951856896, 0.12158964585978538, 0.18065419601043686, 0.12544370780233294, 0.09127948869718239, 0.14372201840160415, 0.13252713630208746, 0.1660975778941065, 0.1536976409261115, 0.21864859474590048, 0.0858323770808056, 0.09217677492415532, 0.178794284875039, 0.11715517990523949, 0.12794642272638157, 0.2415799634763971, 0.14070716220885515, 0.14359196444274858, 0.12246667145518586, 0.2731408621184528, 0.1251243765000254, 0.09960589581169188, 0.09236536207026802, 0.13777459535049275, 0.20477773592574522, 0.15882663836237043, 0.14536051719915122, 0.11235339537961408, 0.13342845981242135, 0.1461936967098154, 0.09389903250848874, 0.12114526267396286, 0.11711200917488895, 0.1667447603540495, 0.13401272299233824, 0.2361507821478881, 0.10393049422418699, 0.16806372004793957, 0.1595122047001496, 0.15561926906229928, 0.21953961724648252, 0.1657661347417161, 0.11831193580292165, 0.1618605529074557, 0.10322770263883285, 0.10109495575306937, 0.1329533220268786, 0.10912088211625814, 0.14781681820750237, 0.13233772537205368, 0.16924670344451442, 0.11257877078605816, 0.23343993932940066, 0.18869305058615282, 0.15913621784420684, 0.180106446496211, 0.14075164654059336, 0.18064324191072956, 0.09584748928318731, 0.21117595431860536, 0.10028268254245631, 0.28659154660999775, 0.07561679594800808, 0.1626643878989853, 0.112014219048433, 0.14304733194876462, 0.18502376857213676, 0.12580318929394707, 0.14976560894865543, 0.14180516969645396, 0.16424685454694554, 0.08383654901990667, 0.1697222568327561, 0.12990451999939978, 0.12295621432713233, 0.21843328286195174, 0.19287564646219835, 0.06924540619365871, 0.18457203812431544, 0.2992127771722153, 0.09015653020469472, 0.1400259300135076, 0.21317472128430381, 0.20724304660689086, 0.15426243015099317, 0.11025530679035, 0.12248348110006191, 0.09586841042619199, 0.09887168911518529, 0.10211690794676542, 0.11833648604806513, 0.13871888921130449, 0.16404372872784734, 0.1505789434304461, 0.20219365193042904, 0.2241346097434871, 0.14801178040215746, 0.11252184063778259, 0.13732759980484843, 0.20601180876838043, 0.10270361279253848, 0.10069963595014997, 0.07159811822930351], [0.05811358067148831, 0.038354800490196794, 0.01745866971759824, 0.12983671738766134, 0.1216645359818358, 0.05724772810935974, 0.012870160808233777, 0.02213844516518293, 0.05078165886516217, 0.10738350698375143, 0.09294138741097413, 0.02174452802137239, 0.01970176654140232, 0.09536947196465917, 0.03549628141627181, 0.05577545925916638, 0.006184863923408557, 0.03526564047206193, 0.0635464170773048, 0.04257855958712753, 0.10678454185836017, 0.053506535696214996, 0.03151707111101132, 0.03259459903347306, 0.039403800255968235, 0.03671828322694637, 0.004638311193048139, 0.04346765250375029, 0.03309899599116761, 0.06325199967250228, 0.020551308552967384, 0.05329064864781685, 0.02998254720296245, 0.04162805023952387, 0.05435693674371578, 0.03373658990312833, 0.015032485061965417, 0.051508377291611396, 0.0428802685928531, 0.03353533800691366, 0.031203387552523054, 0.03361587216204498, 0.014029106041562045, 0.022152495876071043, 0.04778912276378833, 0.05528170469915494, 0.14003605290781707, 0.037724138237535954, 0.027662370921461843, 0.013156453551346203, 0.01673288639722159, 0.0861296072253026, 0.016950701174209826, 0.025191928289132193, 0.01951147245563334, 0.09028815751662478, 0.08451686095213518, 0.01581993157742545, 0.009393288928549737, 0.02400716744887177, 0.03899948933394626, 0.04573753343720455, 0.030591280847147573, 0.0706478649226483, 0.031316193999373354, 0.05768600713054184, 0.04220695140247699, 0.052495496784104034, 0.055628666159464046, 0.0712453160667792, 0.016836193353810813, 0.03665314492536709, 0.10677548023522831, 0.02336993162316503, 0.08077669641352259, 0.020435058540897444, 0.06636692705797032, 0.033138359503936954, 0.04988727443560492, 0.00986994997219881, 0.023070578936312813, 0.025733876063895877, 0.020362255709187593, 0.06563168135471642, 0.029164249608584214, 0.025849344965536147, 0.017822307236201596, 0.04028118208225351, 0.03181482446962036, 0.007671410303373705, 0.025156013907690067, 0.016006578007363714, 0.048136959958355874, 0.03796542157942895, 0.06445985985919833, 0.036735860994667746, 0.017691188295430038, 0.01731410862703342, 0.011346386909281136, 0.017399926873622462, 0.013464109943015501, 0.06257138345972635, 0.009306907577411039, 0.004337521058914717, 0.04641272083972581, 0.06898511273902841, 0.02804908923280891, 0.031258254530257545, 0.008483446490572533, 0.03369295904121827, 0.04295626451494172, 0.008603969417890767, 0.07216901532956399, 0.03309662111860234, 0.032730571620049886, 0.043019948207074776, 0.021622791682602838, 0.029850892060494516, 0.0643903503078036, 0.029561187293438707, 0.024071092338999733, 0.08571243117330596, 0.006933299446245655, 0.04265194686013274, 0.05337459297152236, 0.05889038664463442, 0.03966243501054123, 0.10252508174744435, 0.04634460652596317, 0.023378666701319162, 0.03682801718241535, 0.037693546910304576, 0.027906901159440167, 0.017569195915712044, 0.05227022527833469, 0.0375638046534732, 0.031957713872543536, 0.11220377840800211, 0.060635754707618617, 0.10309606790542603, 0.06040626780304592, 0.02544291150115896, 0.04746266684378497, 0.025546684155415278, 0.04311103199142963, 0.0696286883612629, 0.05263468287012074, 0.06870242126751691, 0.022849261222290806, 0.033591629908187315, 0.0017568546536494978, 0.05188728820940014, 0.010736294207163155, 0.058341394033050165, 0.05096495820907876, 0.039540841535199434, 0.0470358020538697, 0.039245778461918235, 0.021043537999503314, 0.034420501251588576, 0.03859018375806045, 0.06557189393788576, 0.020111419071326964, 0.054478771417052485, 0.061387850873870775, 0.05877029601833783, 0.017559497900947463, 0.028197305400681216, 0.037485270586330444, 0.06925687979673967, 0.03855725466564763, 0.013730118862440577, 0.03565864848496858, 0.0056785517608659575, 0.013318473666004138, 0.03154488680593204, 0.06892254226841033, 0.017578242695890367, 0.019956636751885526, 0.046649336072732694, 0.07419407658744603, 0.03855755894619506, 0.05932163752731867, 0.022131140576675534, 0.04444962520210538, 0.04197034359094687, 0.04956722696078941, 0.008762948582443641, 0.0105164478009101, 0.040150526983779855, 0.050557392969494686, 0.04211227562336717, 0.011299620473437244, 0.06460053395130672, 0.07931315150926821, 0.040061524923658, 0.0026334189578847145, 0.013791720830340637, 0.08157735501299612, 0.06025111440976616, 0.040478296505170874, 0.10834243599674664, 0.035309171144035645, 0.043827393747051246, 0.030702335825480986, 0.05853508715517819, 0.057711870977072977, 0.03356501278176438, 0.060516669691423886, 0.04931682633468881, 0.10887919430388138, 0.028818082246289123, 0.002854656195268035, 0.03188572925864719, 0.04589063850289676, 0.01856147890066495, 0.03459300234680995, 0.024418602988589555, 0.023699359844613355, 0.03222759216441773, 0.009525497898721369, 0.042900024564005435, 0.018689642238314264, 0.0177539183277986, 0.051186578348279, 0.007782424927427201, 0.022819317418907303, 0.10386262481915765, 0.0067946773924632, 0.034768067562254146, 0.07765187619952485, 0.1290134826558642, 0.06716293981298804, 0.029450167567119934, 0.0054812388134450885, 0.03697899228427559, 0.006928027878529974, 0.04870578275586013, 0.021399047145678196, 0.03293116300483234, 0.024412075799773447, 0.03665992073365487, 0.015187302633421496, 0.010754243976407452, 0.0537188901216723, 0.03579839860321954, 0.019793345709331334, 0.04090344693395309, 0.1408082278794609, 0.10634595484589227, 0.0357185323809972, 0.0916271551977843, 0.021277412852214184, 0.09769433119799942, 0.02386512038356159, 0.026863050043175463, 0.008102579085971229, 0.043906792416237295, 0.03730703640030697, 0.04781463409017306, 0.014465744916378753, 0.04711632878752425, 0.05574681235884782, 0.024789658273220994, 0.00650534230771882, 0.027651815726130735, 0.019124527789244894, 0.047832671989453956, 0.02758617833023891, 0.04654218108044006, 0.030756399428355508, 0.010185186474700458, 0.07956416811794043, 0.07153568876674399, 0.010842677365872078, 0.01600662995770108, 0.015221963712974684, 0.0552833967958577, 0.02207061101216823, 0.043945718061877415, 0.08311194571433589, 0.04607196373399347, 0.029350367258302867, 0.017599379061721265, 0.018834422262443695, 0.02703343787288759, 0.023793998516339343, 0.02124364513292676, 0.026127847013412975, 0.047958388095139526, 0.02251323159725871, 0.035249027496320195, 0.03773412012378685, 0.0335834217548836, 0.041866060710162856, 0.009871611455309903, 0.03443160007009283, 0.012519376359705348, 0.0280475641193334, 0.025838808323896956, 0.07324618331040256, 0.035745939894695766, 0.02414757436781656, 0.08163331294781528, 0.02593010176497046, 0.04085625747393351, 0.04761804288136773, 0.08331123462994583, 0.05387056284234859, 0.06593270387384109, 0.03396522704861127, 0.01652392358664656, 0.039176751306513324, 0.06754429239663295, 0.08059279221924953, 0.0928086023486685, 0.09312644193414599, 0.05947956655290909, 0.06515787943499163, 0.02219205976871308, 0.05289832341077272, 0.070948790962575, 0.053168721206020564, 0.01732008662656881, 0.009494826790614752, 0.032072676258394495, 0.04110607180336956, 0.02391547881416045, 0.04104084815480746, 0.05767493428720627, 0.03150580530927982, 0.05455904953123536, 0.08256185843492858, 0.054677199441357516, 0.04028219140309375, 0.034951173947774805, 0.03363721632922534, 0.0561583592207171, 0.010800603158713784, 0.032655473696650006, 0.03257352946093306, 0.019273836769571062, 0.06885744107421488, 0.054566367107327096, 0.01402819969371194, 0.061126959990360774, 0.02450037467497168, 0.0188859440095257, 0.04597914332407527, 0.03215194505173713, 0.09948473278200254, 0.08483363926643506, 0.2756855677580461, 0.12387825117912143, 0.06487024525995366, 0.25478947965893894, 0.17292364442255348, 0.09976431465474889, 0.09728654331411235, 0.13209073862526566, 0.09517285478068516, 0.17901106621138752, 0.16655496350722387, 0.07227478621643968, 0.13030907954089344, 0.22477659716969356, 0.12152120500104502, 0.17514257691800594, 0.14401191612705588, 0.11960715419263579, 0.10921117180259898, 0.1863830565707758, 0.2501744491746649, 0.08922675275243819, 0.07881874014856294, 0.148911589931231, 0.16926013631746173, 0.1488873068592511, 0.1883939205436036, 0.12648695963434875, 0.11927046405617148, 0.15200074994936585, 0.09531577758025378, 0.18893236352596432, 0.11476899700937793, 0.1291503050015308, 0.34469078527763486, 0.1534120031283237, 0.13075463532004505, 0.19629883230663836, 0.11723424089723267, 0.1935718403547071, 0.13681997079402208, 0.10897081985604018, 0.11181228066561744, 0.09114218395552598, 0.25926546135451645, 0.1447428870596923, 0.25284193572588265, 0.061718433134956285, 0.068499540357152, 0.203122494276613, 0.11447152937762439, 0.21336600242648274, 0.11128431680845097, 0.13139298622263595, 0.30685084231663495, 0.2528354345122352, 0.14782754966290668, 0.08060258856858127, 0.13342601072508842, 0.1020049920771271, 0.1414833150920458, 0.15885016444372013, 0.10592385093332268, 0.11858004407258704, 0.08606722229160368, 0.1388369352207519, 0.10860727881663479, 0.13517814717488363, 0.08601094523328356, 0.17414236965123564, 0.0858507897646632, 0.11826112095150165, 0.37491843046154827, 0.22270127024967223, 0.16001872048946097, 0.18287642364157364, 0.14870821178192273, 0.2575636870460585, 0.1906574858003296, 0.10930306452792138, 0.09678947506472468, 0.09853410098003224, 0.13226532144472003, 0.20063606207259, 0.11914979826542549, 0.13940570235718042, 0.20139689702773467, 0.1613935935893096, 0.12577564077218994, 0.11824365079519339, 0.09268253372283652, 0.1493461025529541, 0.13237217586720362, 0.0919779238756746, 0.17647173372097313, 0.13151575229130685, 0.1397152224672027, 0.12226611346704885, 0.14100114174652845, 0.09936247879522853, 0.21349616028601304, 0.16592142172157764, 0.08931614444009028, 0.10704321000957862, 0.12169640380307101, 0.12135485259932466, 0.11441372349509038, 0.11066696868510917, 0.13959533593151718, 0.1419211970642209, 0.1603250642074272, 0.11865909022162668, 0.1627917107543908, 0.09391833576955833, 0.0986507220659405, 0.14568425685865805, 0.11210825658054091, 0.13757371081737801, 0.13478474953444675, 0.06544651550939307, 0.1207336898369249, 0.1343449528212659, 0.1039635569031816, 0.0986827902670484, 0.15155222557950765, 0.11777869527577423, 0.12067992865922861, 0.17079577344702557, 0.14215417206287384, 0.21863437519641593, 0.1265756314387545, 0.11115003260783851, 0.14840681076748297, 0.13000684732105583, 0.16201637423364446, 0.11456260574050248, 0.16369377641240135, 0.19449434475973248, 0.1605615866719745, 0.1803479265072383, 0.20440321852220222, 0.09982393137761392, 0.1530689824721776, 0.1655664821737446, 0.152649357332848, 0.19616152014350519, 0.14408829796593636, 0.18087737465975806, 0.09519612111034803, 0.11374191657523625, 0.10766572348074988, 0.1545054538291879, 0.08949807452154346, 0.11996659115538932, 0.1910751368268393, 0.13672359549673274, 0.14182771614287049, 0.129338558181189, 0.1905505423201248, 0.2396176804904826, 0.13857479381840676, 0.1024709346529562, 0.05586045372183435, 0.10207285406067967, 0.29446712869685143, 0.1392524637049064, 0.10302402020897716, 0.10329566852306016, 0.08075322228251025, 0.22809414571383968, 0.1520340278511867, 0.06160048731544521, 0.1913963828701526, 0.09949806175427511, 0.12372401804896072, 0.12244773184647784], [0.06065529916668311, 0.035553593770600855, 0.03387337514141109, 0.059441208650241606, 0.016462371713714674, 0.02290329142851988, 0.013835334066243377, 0.04846981319133192, 0.06899030777276494, 0.018797448465193156, 0.028008219160255976, 0.008695348205947084, 0.021753144355898257, 0.02119218832376646, 0.028660524294537026, 0.013602922172140097, 0.04335264558903873, 0.022022369557817, 0.026838286430574954, 0.02281714292621473, 0.047402100171893835, 0.015950540291669313, 0.007633191089553293, 0.054552789515582845, 0.033359326553181745, 0.025736662828421686, 0.01523092607385479, 0.03999513610324357, 0.04764860823343042, 0.039769656796124764, 0.03963862320233602, 0.0940333167091012, 0.03144506052194629, 0.019666228799906094, 0.007621764334544423, 0.023723010235698894, 0.023148406107793562, 0.04111880705750082, 0.04538026354566682, 0.04909771836537402, 0.027659088773361873, 0.015005367913545342, 0.03131913661491126, 0.033279857379966415, 0.0680234155151993, 0.07937194444821216, 0.10055214894236997, 0.07270557325682603, 0.05621332267764956, 0.0425362274836516, 0.05486789428687189, 0.06324003625195473, 0.0272688081531669, 0.012096040481992532, 0.09427601384231821, 0.07156993146054447, 0.02044168777501909, 0.011297713153908262, 0.007787932590872515, 0.020514770767476875, 0.014066583571548108, 0.05858917116711382, 0.04691971902502701, 0.010822245112649398, 0.03697324063978158, 0.045758636406389996, 0.09907173502142541, 0.028468443488236517, 0.03892326705681626, 0.049972506385529414, 0.01181422381705488, 0.01377468946884619, 0.050225018421770073, 0.022869677704875357, 0.09281663238652982, 0.0446292657579761, 0.04797298985067755, 0.008450226105196634, 0.06996068812441081, 0.024864893493941054, 0.06449415450333618, 0.02329531609575497, 0.030984901131887455, 0.012461448950489284, 0.020992977333662566, 0.02524126997741405, 0.1393696339800954, 0.05292068803100847, 0.022849268643767573, 0.10753479378763586, 0.039923214571899734, 0.017127987266576383, 0.0637682450178545, 0.020865711994701996, 0.015798682034073863, 0.05422595138952602, 0.025326780232717283, 0.020316136797191575, 0.04296778264688328, 0.010690401650208514, 0.022559198368981015, 0.03721838686033152, 0.09178182619507425, 0.018594554567243904, 0.03699203924043104, 0.06109485468186904, 0.06652670403127559, 0.010038127129519125, 0.0406167033361271, 0.06095592092606239, 0.01098232265576371, 0.008804413300822489, 0.03416303909034468, 0.016354717627109494, 0.02715002185141202, 0.034947878812090494, 0.02425585927994689, 0.025348239432787523, 0.030091342341620475, 0.047031030044308864, 0.0270323728909716, 0.018759752929327078, 0.014099483905738452, 0.017073285416699946, 0.044101925304858014, 0.10748291766503826, 0.03176925289153587, 0.03443102119490504, 0.06250281643588096, 0.03565202852769289, 0.05065347511845175, 0.01004785297482158, 0.02062789262708975, 0.04119801276829094, 0.03476073885394726, 0.03529329289449379, 0.06365157940308563, 0.04156834074819926, 0.062409535894403234, 0.07578356395242736, 0.053583077096845955, 0.003769518334593158, 0.03663319228508044, 0.11063103389460593, 0.029515569331124425, 0.0684438792814035, 0.022980680732871406, 0.11735661362763494, 0.04182437427516561, 0.0454782901215367, 0.011310615391266765, 0.013924262839282164, 0.09426269971299917, 0.086877135472605, 0.037821834557689726, 0.06693798000924289, 0.030481450412480626, 0.04209055296087172, 0.04169612373516429, 0.06684876643703319, 0.04534360516117886, 0.011361382930772379, 0.07812682102667168, 0.04842463866225444, 0.06829455916886218, 0.015442162639374146, 0.02428591440548189, 0.009410114344063913, 0.023486890386266168, 0.08863802184350789, 0.02734675035753753, 0.04785126278875396, 0.05941626506682951, 0.05678629779140465, 0.08207449747715145, 0.05484973022248596, 0.03981535825005267, 0.0707618884916883, 0.014987491431384115, 0.048869652673602104, 0.0824210062273778, 0.04536205124168191, 0.040283690541400574, 0.06920466970768757, 0.06080059312807862, 0.04582691770337988, 0.014451202532654861, 0.0177245719532948, 0.0633431576716248, 0.026552969611657318, 0.04162719676969573, 0.04705023682618048, 0.03071415823796997, 0.027490843895066064, 0.06541703740367666, 0.050169234891654924, 0.03682996903080493, 0.02812896102113882, 0.026101957191713154, 0.02046251614956418, 0.06607216084375978, 0.02925817210780224, 0.07538190620834939, 0.04337904007115867, 0.05370534221583512, 0.027926879774895497, 0.06378899546689354, 0.04246368996973615, 0.02426380026008701, 0.03105428822891554, 0.01803540752007393, 0.03042720869416371, 0.05794625605631154, 0.10775245827971958, 0.08884869530447759, 0.04138347918342333, 0.031826810154598206, 0.0994178578548599, 0.04591219789290335, 0.039108217679313384, 0.03495544500765391, 0.035997991799376905, 0.04727743420517072, 0.12610055302502587, 0.04652510426240042, 0.05297938078001607, 0.07119539921404794, 0.023635106554138474, 0.04614541037881281, 0.05473014425660949, 0.04403563667437993, 0.038644219530397095, 0.010326665797038004, 0.04905877787678037, 0.0671643647365272, 0.03662351839011535, 0.02013352765061427, 0.05298732176015619, 0.044354014316922985, 0.023440053446392994, 0.026212488955934532, 0.04007384828582872, 0.04133729904424399, 0.02877984123188071, 0.01211456077726325, 0.01088094064471079, 0.0229219657194335, 0.014489526110992301, 0.06787837017327547, 0.0031094983432922163, 0.05597244751697872, 0.02451873540849192, 0.01118438256526133, 0.016458781574328896, 0.06343375905998982, 0.030592805960623082, 0.040437971911160275, 0.01728839321003761, 0.011710744311130838, 0.06396184166078456, 0.040087756133289076, 0.10452261674799956, 0.06987634304095991, 0.034847514471039176, 0.034932215785374865, 0.06024070207786281, 0.08923282352043316, 0.020981026900699362, 0.03226501867175102, 0.03561643141438253, 0.050641775160329416, 0.023003744827292394, 0.06148440428660251, 0.021206368910497986, 0.03758936050871853, 0.07176538347266614, 0.021943826213828288, 0.014009008682478452, 0.15914009185507894, 0.031882270850474015, 0.01040845510942745, 0.042539010537439026, 0.04056220001075417, 0.03250793844927102, 0.05708889366360381, 0.048105184905580245, 0.03178545397531707, 0.050686378235695884, 0.02351337949221488, 0.08006111762369983, 0.03061819854337955, 0.03765566769288853, 0.016162213796633296, 0.05980569592793472, 0.015191996717476286, 0.07955000794027, 0.027814889690489508, 0.09429936180822551, 0.03606880010920577, 0.029576078486570623, 0.01809571258490905, 0.03407257499929983, 0.010992067054758081, 0.0754450481326785, 0.04509330101427622, 0.03220111975679174, 0.03684604023874272, 0.06783655015169643, 0.01767650304827839, 0.026674253240344115, 0.019141398661304265, 0.02801865375658963, 0.04652598741813563, 0.02453760265780147, 0.03455660000327043, 0.04157527982897591, 0.06770147185306996, 0.01763368669344345, 0.04682579652580898, 0.006878887961647706, 0.06070820316381287, 0.051308249749126844, 0.039002172197797336, 0.004024942836622358, 0.02752143522229744, 0.08034434344153851, 0.021587107366940472, 0.018484985739632975, 0.03166442453220952, 0.05041197655373253, 0.046261500829132274, 0.02398726861429168, 0.026444382274348754, 0.02924585060100071, 0.033879924594657496, 0.07352521599386819, 0.049522026456543244, 0.026961735275108367, 0.03131561883492395, 0.0640892016235739, 0.032168947655009106, 0.03892333013936877, 0.04352158808615059, 0.041665658573037945, 0.019555971630325075, 0.037013479886809364, 0.05922950731473975, 0.030546139714715537, 0.02253478356578853, 0.03378914138011169, 0.08029720964259468, 0.017875519224617165, 0.13785238726995885, 0.20795714110136032, 0.10210093692876399, 0.2763156808214262, 0.1188888814067468, 0.12260269228136167, 0.14845068653812632, 0.23185986239695922, 0.1225954934488982, 0.17694709415081888, 0.1388297660741955, 0.13058649434242398, 0.23811371822375804, 0.1556738614453934, 0.12716448109131306, 0.09389227154315449, 0.23590933182276785, 0.07131256948923692, 0.127957881486509, 0.11542851396370679, 0.11533436510944739, 0.07710640507866628, 0.12456736498279497, 0.22430764889577404, 0.12546564568765461, 0.1907456826302223, 0.13225144328316674, 0.1726378285093233, 0.1479709622799419, 0.10753822250990197, 0.15299266000511125, 0.20188349357340485, 0.12940533662913367, 0.08879066677764058, 0.14871226390823722, 0.10254782857373357, 0.17634969495702535, 0.12778334319591522, 0.18102141068084165, 0.16734061588067561, 0.09743169997818768, 0.1424595361459069, 0.12776018818840384, 0.1751293073175475, 0.11453078986960463, 0.15016028308309615, 0.15699213836342096, 0.26723556336946785, 0.1784961938392371, 0.14377022831467912, 0.3196607861900702, 0.1489234049222432, 0.14832878136076033, 0.11700116941938177, 0.26025367551483214, 0.2770639437949285, 0.1471866012434475, 0.09434143416001461, 0.16888870624825358, 0.09031044421135448, 0.13906765409046784, 0.16149461473105475, 0.10559997026575729, 0.18999219493707642, 0.0766496651340276, 0.1455002636066638, 0.286979689844884, 0.10960824307403527, 0.08148973705829121, 0.12825683341361582, 0.18146420567063615, 0.12410227587679401, 0.26660239265765995, 0.11096412461483851, 0.22889039595611393, 0.06737215124303475, 0.1142617168079596, 0.16712381970137358, 0.146660195896402, 0.14628741511842236, 0.17388661071890965, 0.13878982368623838, 0.18717618979280815, 0.1577808038564399, 0.14599144662497565, 0.22221721184905618, 0.1737563786446117, 0.15102052129805088, 0.08666481444379315, 0.19499207352055237, 0.18640872003743425, 0.09004503735923208, 0.1225161727052182, 0.15285145898815244, 0.11055344235501252, 0.13196777959819883, 0.14697764214361086, 0.12139316968386993, 0.09592111033271067, 0.16760878352215514, 0.19648713001515716, 0.0994499705848284, 0.2857198496349156, 0.09857301920419559, 0.09637520823162049, 0.23102668288629502, 0.2184550277888775, 0.22181752079632133, 0.136649351043161, 0.11828746719402261, 0.12468668748624623, 0.08470977481920272, 0.1064155757194385, 0.11254338518483564, 0.13428249367279932, 0.14921432681148872, 0.11645934224361554, 0.1218938225065358, 0.12234076610184275, 0.18202681298134848, 0.10322929825633764, 0.2083265080000274, 0.13172434031730518, 0.09186068680719472, 0.06795386143494397, 0.16576959314988926, 0.09855442840489559, 0.15863117150729522, 0.1503642846364528, 0.1626967010088265, 0.29736485914327204, 0.1255136329564266, 0.09883838152745739, 0.19113274232950062, 0.20921748597174883, 0.14495490380795673, 0.16011073195841163, 0.09574177034664899, 0.12653807876631618, 0.13473811297444627, 0.13101900316542014, 0.11306152300676331, 0.19464639597572386, 0.16952361358562484, 0.11138053625472821, 0.1709258570917882, 0.1323784692795016, 0.30740923422854394, 0.14759006240637973, 0.19413838104810566, 0.07508706577937119, 0.07993328268639743, 0.13279511098517105, 0.19904403656255454, 0.11932201363379136, 0.10618815940688364, 0.10863544332096353, 0.06882961053634062, 0.1770308380946517, 0.1401492304285057, 0.16701027110684663, 0.16120174841489643, 0.17500900517916307, 0.20803119259653613, 0.1607358132605441, 0.0932101858779788, 0.12051667101331986, 0.11124879762064666, 0.09332774949143641, 0.10448807719512843, 0.12677372549660504, 0.10710129048675299, 0.12984897766727954, 0.14907809818396345, 0.2033269262756221, 0.18495647062081844], [0.052885662371409126, 0.03498719037452247, 0.05967386452539358, 0.04729255917482078, 0.06424486709875055, 0.028498428109742235, 0.0286732335734996, 0.11668364153592847, 0.11705288226949051, 0.04879561973211821, 0.028220658932696097, 0.04448705542017706, 0.056949269710457884, 0.01445613595933537, 0.029627583535329904, 0.03968678858655039, 0.03613241700804792, 0.026671958148654085, 0.03693260805448517, 0.03316866510431282, 0.02495532789907884, 0.03003209854796296, 0.027002802016795613, 0.04012150900962297, 0.03766265501326416, 0.043734955543186516, 0.01546950150441262, 0.019229586214351002, 0.047131513128988445, 0.05177147235372104, 0.04397905904625077, 0.04256488551618531, 0.052275609559728764, 0.07655459601664916, 0.02520499750971794, 0.010556534907664172, 0.05515611104783602, 0.02082299026369583, 0.03645403041446116, 0.01572556750033982, 0.04698650118371006, 0.004263714472472202, 0.027612016201601364, 0.07094007814885117, 0.012258133883733535, 0.014421146479435265, 0.044520021619973704, 0.01853993806435028, 0.010942586213786853, 0.005039581628807355, 0.004135911540288362, 0.03072359464567853, 0.06402596322004683, 0.09109066406381316, 0.036579019215423614, 0.017650099289312493, 0.07319583601201884, 0.02374569212406641, 0.012505879476520931, 0.03648023935966194, 0.055774049178580754, 0.029491714849427808, 0.05393643215938937, 0.029777627241855953, 0.03861381374008488, 0.0424315438431222, 0.02951106449472718, 0.03328560160298366, 0.006947748133825371, 0.04854009828704875, 0.021202611787884962, 0.03499439662846271, 0.02415684564766707, 0.03317796050396282, 0.08624348236480728, 0.07513829623349011, 0.1145989190263208, 0.01078704597603064, 0.08195818809326738, 0.09009614164824598, 0.020062236944795586, 0.02945404157799203, 0.04769226878124755, 0.01934966570843244, 0.04445870537892915, 0.03030357060197275, 0.048494511866010725, 0.032051699454314075, 0.04470201849471778, 0.03266956708102953, 0.04600273990945425, 0.027284113093628548, 0.07459543747245334, 0.05655298140482046, 0.05117527172842529, 0.05767634807853028, 0.023461306700482965, 0.06974805539357476, 0.07305557010113262, 0.055733197659719735, 0.02085360756609589, 0.02063261083094403, 0.014443444306380115, 0.03246979948016815, 0.059519828064367175, 0.009859028341452358, 0.02457414972013794, 0.03374528416316025, 0.08610492339357734, 0.041499283906887285, 0.03226865519536659, 0.07949946768349037, 0.050937183332280256, 0.0369887069973629, 0.010784579262690386, 0.04943597814417444, 0.02639173802890582, 0.014945109232940013, 0.032783130518510006, 0.029097148326400202, 0.0002226590589771149, 0.022636157227680087, 0.021731510751124006, 0.029970413088449277, 0.026313465568819083, 0.04392381728393957, 0.04731622997496743, 0.02753704073256813, 0.035301070602145046, 0.004515822502071387, 0.009523700973659288, 0.04790187726030126, 0.03779504302656278, 0.05304542079102248, 0.06051427997590508, 0.02790577866107924, 0.04931350522383582, 0.009847656783676939, 0.03823822764388751, 0.04366896377177909, 0.04382848470413592, 0.04707476109615527, 0.021200645096541848, 0.02779082740744343, 0.01789227877452504, 0.06232234838535078, 0.06846706397482194, 0.048468358581885695, 0.045322004953050055, 0.014065898012631806, 0.011225212747376645, 0.09966712299501523, 0.08312189791467972, 0.051053258939646184, 0.05046064659836702, 0.09664079319918528, 0.06160927063319832, 0.015475293039344251, 0.06341898289974779, 0.076421573467087, 0.04679923877120018, 0.02208486581366742, 0.03913069362170063, 0.02499073205399327, 0.029946985341666732, 0.008366872716578655, 0.03287931285740342, 0.06452225963585079, 0.026756592669698875, 0.06663594074780121, 0.047684335222584195, 0.03576296105165966, 0.05503256572410464, 0.02257710824778769, 0.0165261500296765, 0.04412769267219119, 0.05364327640563715, 0.04239046967995819, 0.03954191764933057, 0.055511681421194226, 0.015110280692169908, 0.015584101165586617, 0.018925561707874294, 0.08720643381820992, 0.16132493008626625, 0.026297364674974233, 0.05045918085670564, 0.03590009881008882, 0.0374448235379532, 0.04688877146691084, 0.06609913791180588, 0.03360994240210857, 0.030223069843486883, 0.0347746281477157, 0.029055552804493345, 0.04993559938156977, 0.040752004279056564, 0.020224607724230736, 0.023861430054239463, 0.012424132837622892, 0.022358716450980864, 0.04206176505249459, 0.10658549785148352, 0.02636969253217103, 0.02041255105723394, 0.03181662046699785, 0.052316635483293794, 0.06441044024541043, 0.008401159939239733, 0.03411097372008953, 0.04612251141224988, 0.017152374239230994, 0.034909736132249236, 0.02171561209252104, 0.05852213296748232, 0.02489876511390321, 0.029903610520705115, 0.07031082597677596, 0.053113249377929606, 0.009942248143488541, 0.0009330946204499924, 0.07970053775352426, 0.04709549670224078, 0.021635295015585143, 0.02127533112798119, 0.048919287510216236, 0.01663345716224285, 0.020340221344667953, 0.01823985807277495, 0.05171922515728511, 0.030129464612400625, 0.06022345456585754, 0.0260454445015057, 0.032459353751619346, 0.00800696449005045, 0.04737866314826533, 0.021334255798137747, 0.020877148490399122, 0.05743789974076208, 0.009682266390882432, 0.006476281660070526, 0.012933821308251936, 0.024184872854675632, 0.0916126610536594, 0.030127121281111613, 0.06266401833272539, 0.036822580950683914, 0.02770767347101355, 0.03924590091628488, 0.03203534994099755, 0.03409831268072594, 0.0481000826403033, 0.08976452780188993, 0.03006596274644835, 0.041598928364692256, 0.01282318749872502, 0.012050972636643564, 0.04956482982379384, 0.01316854499236797, 0.06502050790004432, 0.033125668778666295, 0.06890812976052985, 0.059936569959972985, 0.031837701171753, 0.07154079474275932, 0.023048077018756885, 0.05288186999678146, 0.05721120331145357, 0.00598838032601634, 0.012228161322127562, 0.008043744401220465, 0.030526136979460716, 0.02310874388058437, 0.036168704318697564, 0.013268127295305021, 0.03434180762269534, 0.02650195252499543, 0.011604268383962335, 0.055798484390834346, 0.016801885722088628, 0.07723408416495658, 0.03262918682594318, 0.06320390850305557, 0.01908351856400259, 0.09448860946577042, 0.01581635257025482, 0.04343893138866406, 0.11023276034393348, 0.04992375470465049, 0.018362173286732286, 0.048540573261561804, 0.024552686809329316, 0.03340711715281941, 0.08013847909751348, 0.053942384183756076, 0.07028289153822698, 0.007050315725791734, 0.0706105942663271, 0.028670391147898044, 0.019644058993435465, 0.01907771311380202, 0.012175652518635616, 0.003107234097114997, 0.029677838065254036, 0.04985240833775606, 0.028554922246257775, 0.02979454078740673, 0.05090294805995654, 0.018106748320860788, 0.040066868386929855, 0.013246698708826443, 0.0404551192332292, 0.06138919045042712, 0.018712710043473635, 0.0372867349506123, 0.031280173861887306, 0.03300934084109031, 0.026267200082656927, 0.0154119627950422, 0.013499498327291803, 0.0326295801642118, 0.039912817082949914, 0.03820598874881398, 0.09125858239713125, 0.013942540081188781, 0.034758130204863846, 0.01908439058752265, 0.005332895088940859, 0.0753952945524361, 0.02799833189783385, 0.007957306461321423, 0.05114480656629894, 0.07877403317252174, 0.031757081669638865, 0.03402196794922929, 0.01881047872302588, 0.044584091228898615, 0.03202366853656713, 0.05531011411221698, 0.02651912953297142, 0.020713258163596038, 0.022797540950705297, 0.032140486291609704, 0.031476683434448205, 0.03889226383762434, 0.01940683891007211, 0.02701698260352714, 0.019002288645424414, 0.07615779191837646, 0.04027135233627632, 0.01383326161885634, 0.018249672975798603, 0.18430473137414083, 0.11673651955788955, 0.1290272717596963, 0.11756475636502728, 0.11740091984393075, 0.061972151161171496, 0.08339563908521086, 0.17753008083673194, 0.32230235694441944, 0.12867662182543427, 0.13692960084881634, 0.09863742277957499, 0.17256169900065288, 0.12826501188101247, 0.13496213767211884, 0.18232827336760238, 0.0897706876276061, 0.14867569087073207, 0.09784263456822373, 0.16255407506832853, 0.13259149534860626, 0.0986422467394732, 0.22036153095541522, 0.07990896992851049, 0.10353357138228603, 0.15694413625169545, 0.20598900999175385, 0.07348253508098423, 0.10141321836272255, 0.1408036710927263, 0.12802393262973055, 0.15195967949694023, 0.09416698492714204, 0.24225751461926848, 0.2119626456988044, 0.10568441924988292, 0.19696327712154016, 0.09082252610824071, 0.10133440970093943, 0.12375006743241102, 0.13391992484685034, 0.1646813374827616, 0.12074264755938202, 0.16820429766085, 0.15261682157870382, 0.20435995131265372, 0.1578251991304569, 0.14737424586201087, 0.16034805594244972, 0.15204328985419124, 0.1158618539921008, 0.05252291543001775, 0.100900542747695, 0.21409692883025855, 0.08609934986452572, 0.2624211326474324, 0.11304807529086247, 0.1635666168294847, 0.1484927217825316, 0.07864356361096725, 0.10630620541633107, 0.1616455675684847, 0.20549674343783408, 0.1626852570916526, 0.13130879699019715, 0.17349820031085983, 0.1691900924197398, 0.1805997668998316, 0.09282945669838227, 0.13372715940931812, 0.08118245081277564, 0.19545184884918854, 0.11360557662555948, 0.12058831052854657, 0.1465820922749117, 0.15956323477439582, 0.32409752311650664, 0.09643409764976241, 0.16642124333884567, 0.24789768853224814, 0.09737820597365499, 0.19511316233547404, 0.14021038339706138, 0.14434325537877157, 0.16097854007966816, 0.11261841631494462, 0.180911825154908, 0.16240092547377571, 0.17838954721810296, 0.1341890572803095, 0.1745829381980002, 0.0980261602671817, 0.12998410791624337, 0.17534188809804618, 0.13245416834251955, 0.11888484412338585, 0.10402606800198555, 0.14085097558563575, 0.16166700079338625, 0.24882060853997245, 0.1140757420216687, 0.07289479864994064, 0.1007429847959429, 0.09979520284105092, 0.1371094974456355, 0.14469485526205972, 0.18127209332305938, 0.19351138500496745, 0.20244990068022162, 0.09268819630960934, 0.14550434541888535, 0.30020146630704403, 0.11643238743999973, 0.1452893452369608, 0.12157081757322885, 0.1785793885937892, 0.08779117197263986, 0.17285070614889264, 0.13565629807999358, 0.11266454079304822, 0.12957410101080313, 0.13391101907473058, 0.11570120870601386, 0.1175762596540153, 0.09495640741079114, 0.20067017117980868, 0.08894177546608262, 0.18235015188110992, 0.1569803530583158, 0.09315384944784455, 0.12901346781291068, 0.1293807418551296, 0.14634341758210212, 0.1386877041659318, 0.11877815297339112, 0.16474519186886027, 0.1506376324687153, 0.10817979433340952, 0.11358210991602391, 0.10827430684003048, 0.11575189739232883, 0.11970902880420908, 0.058572276175254956, 0.09022595069836825, 0.12263426324352622, 0.10426329550682567, 0.1430095121031627, 0.19897856429452077, 0.11290498921880499, 0.12509577412856743, 0.07698185785557143, 0.26247343921568245, 0.21139307704288512, 0.13047169893980026, 0.08267108030850068, 0.22639928822172806, 0.17801470326958224, 0.16912089457036927, 0.09375045454362407, 0.19887058180756867, 0.10596830557915382, 0.11180745670571923, 0.15209427539957687, 0.10830507628270425, 0.21578340005362406, 0.16980714368401095, 0.12314229301409796, 0.18116037041181698, 0.18605011428007856, 0.17448544967919588, 0.09846418324741535, 0.14958777552237734, 0.19944190193200484, 0.09481269793468527, 0.09733641563798301, 0.14040124893654138], [0.039296329850913025, 0.04513164036325179, 0.04328096896642819, 0.012990942559554242, 0.04100316560652573, 0.02830882978742011, 0.04870115175435785, 0.06561436704942025, 0.023830942627682816, 0.04221128183417022, 0.06662792555289343, 0.011811463027697755, 0.03652350285847206, 0.030327790591400117, 0.059938566337223165, 0.013027793902438134, 0.051772641236311756, 0.029124719112587627, 0.04784480239322875, 0.036259580301702954, 0.05083375763206277, 0.041026814142242074, 0.048559253118583, 0.021579765671049245, 0.008106716559268534, 0.03446625836659223, 0.04666222717787605, 0.040303049463545904, 0.02556165141868405, 0.022935491360840388, 0.03904014047293458, 0.03205829343642108, 0.024851076559571084, 0.024533567229809705, 0.020750962976308074, 0.0013861549041394028, 0.04189169449091423, 0.02175427242036676, 0.058604385194485076, 0.024436583371425513, 0.1197205543576274, 0.052536637740558945, 0.006836964503236231, 0.016849461098900065, 0.026520027531660162, 0.01940949023264693, 0.014079460761422524, 0.023321003682212904, 0.02689041488338262, 0.01595114328665659, 0.03107402750174515, 0.08911722659831867, 0.04376943201350514, 0.02291752211021958, 0.106168603815604, 0.03441224485868588, 0.053789973026141524, 0.010883765444305027, 0.054339982380042784, 0.05241951199423056, 0.02106184863805538, 0.05704654300643597, 0.013886987544537988, 0.08932845667004585, 0.031390661097248085, 0.01327467211012845, 0.09137132205069065, 0.037094555809744634, 0.08015800500288606, 0.05306223414663691, 0.03996575818746351, 0.10919280364760198, 0.14628014207119122, 0.023835740612412337, 0.026938008813885972, 0.05449197422422003, 0.014950060285627842, 0.04960157355526462, 0.009668227739894064, 0.02846057301212568, 0.015631735914212186, 0.0388044974533841, 0.021725725709984545, 0.01733238957967842, 0.052929912926629186, 0.06071481198887341, 0.05358249451091979, 0.07493797573260963, 0.09079213516088203, 0.04121275924262591, 0.04862636553298216, 0.03152439610857982, 0.02456725516822189, 0.06386504333931953, 0.054769990165368654, 0.05398985565989278, 0.0024508193200745154, 0.027611710065684747, 0.04759913666930515, 0.02774976623186376, 0.034934891227749176, 0.0236744737776462, 0.0018563581033959053, 0.10295107451383956, 0.01684206559730228, 0.04042202315758914, 0.037756455058115534, 0.016521815887244884, 0.04437406714714598, 0.026098342932527885, 0.03044857698114356, 0.03073970667173853, 0.010383794469817076, 0.07008233355008997, 0.0371515972801717, 0.021644696171279065, 0.035472952004056424, 0.013624065959447762, 0.08126546003040858, 0.012723511499643791, 0.0450278398784576, 0.046515849680872634, 0.028396445886755828, 0.01892348926048726, 0.023712866932328325, 0.008802594111330109, 0.005064222323198919, 0.060900096577825025, 0.03888719867973123, 0.04889500072749797, 0.06137114512966946, 0.09069366700714454, 0.043751112098107114, 0.08026998766581528, 0.012999894715903793, 0.029576022825494874, 0.009574574269208824, 0.04867704679782037, 0.023141053279687185, 0.06708629080094397, 0.03208746355085168, 0.14558506140019745, 0.023286913128686137, 0.0194257636758266, 0.03324773351778276, 0.017888016991491895, 0.0694116398517508, 0.009160740664810874, 0.032669140346115455, 0.00819333075924078, 0.07954128770506941, 0.10094399549416266, 0.02816780503053451, 0.0867683366232086, 0.02728386261878768, 0.03895316076523159, 0.04814633328351192, 0.015983361772669014, 0.059821537070092745, 0.03384491748875007, 0.03592598492105026, 0.008495043475704733, 0.03283678408479318, 0.04889415838988498, 0.025759979253052734, 0.017510714678792283, 0.03864539954520296, 0.01238315144291846, 0.053327143759815954, 0.033821788456407376, 0.03159734551445581, 0.01940560880029807, 0.0482288897910621, 0.010575907745078439, 0.008643913661217084, 0.02585386835562531, 0.05111715414386708, 0.0463156738987891, 0.046355842641787603, 0.09111457606195472, 0.059392631374066696, 0.032834631856530905, 0.015980964635673445, 0.005838086144649424, 0.06312434285064228, 0.053487013501580805, 0.04585060334648006, 0.019151564229105134, 0.02452198044920806, 0.042394748161314055, 0.02656797212694073, 0.020781463390449062, 0.04589021176798269, 0.03681972739286721, 0.03180702078680042, 0.031624916300643235, 0.02614741744764615, 0.03250131478125695, 0.03431921293667983, 0.06091663904953748, 0.05252856317383703, 0.05159531989193056, 0.03848121421469841, 0.024566401698393747, 0.0055743347456882475, 0.026454503313289024, 0.003622413069024333, 0.021341356296034064, 0.04441171629878227, 0.010725853117037332, 0.02296550195751479, 0.024813768795866054, 0.04543592091067694, 0.051382360616116785, 0.026384670927654952, 0.04064586973981932, 0.028240886167623103, 0.020833014823438134, 0.08919580519432202, 0.005661721706928802, 0.05557552838581614, 0.047972433239920065, 0.013704746688745217, 0.0289776588397217, 0.02498124369594734, 0.00699673730196082, 0.03042281332454877, 0.0033991070949923596, 0.055275589402299374, 0.04229776430292986, 0.045892968846601434, 0.04112586488190573, 0.02634406802826561, 0.043149026241735555, 0.03756863603484817, 0.03600085648940876, 0.05846126201504376, 0.011893499104189686, 0.0442814842244843, 0.05803551786812022, 0.04408587636135053, 0.05814695505250711, 0.026078329065057915, 0.04545643758319784, 0.08072449374594726, 0.04544587682175916, 0.06716060946928337, 0.025219807066605426, 0.04225930621032603, 0.006784576762584038, 0.0169612415265874, 0.028172931415610947, 0.03451534401392564, 0.01932304301590193, 0.02883996261516586, 0.020344824515632354, 0.046118778409436345, 0.04012419929495081, 0.008913568381103687, 0.05587471408944111, 0.011022288235835731, 0.030694682427565567, 0.04740609663713258, 0.004751396409119479, 0.024222299362008926, 0.046862109811627306, 0.07352365748374723, 0.02663287850737106, 0.026968574165948667, 0.013883130231988616, 0.04314520789193921, 0.055151376145659015, 0.03157315521093551, 0.03964374402130488, 0.041037738556042314, 0.010445042989886133, 0.009575733874953585, 0.05120733992953319, 0.06886690345709212, 0.10156184827792458, 0.08571347760153003, 0.06498468443169259, 0.027249293380009476, 0.019365946573088877, 0.015479748708457919, 0.031466182044823654, 0.011332098711136496, 0.08683703723363578, 0.03038804185052868, 0.07971733997692354, 0.07813444288331084, 0.0265132906861254, 0.0522067493875511, 0.07703097318881191, 0.012096883747290121, 0.07000840079854243, 0.044224509547348134, 0.02813974813761888, 0.03624876721005421, 0.022034191970305983, 0.03950272483052686, 0.016220494653680362, 0.017831717668741476, 0.06991865288000554, 0.03146835653751623, 0.033747584820957854, 0.0368887582590105, 0.02293997022206895, 0.014084677131904755, 0.02472838470566785, 0.040473075496265665, 0.024340991039935034, 0.0400440176599659, 0.01898723789054202, 0.011947300172323594, 0.03703829730511643, 0.04631741423509084, 0.02493252726708306, 0.04465231315407436, 0.022025544094503857, 0.020755614386871457, 0.04783164040418342, 0.15303855441743508, 0.016720247622288298, 0.027246296958765015, 0.023302470399357844, 0.05336679671017919, 0.04558888867904898, 0.0016091904581116978, 0.06948094160179608, 0.016494816554768477, 0.04305324095184915, 0.06547963756020181, 0.05559654971875716, 0.05027933992096223, 0.01706312355963746, 0.017441576201235875, 0.06328237577690743, 0.011400047897041077, 0.04645430337404832, 0.04146409497479908, 0.025817085661401507, 0.06307533141807653, 0.06682760038529523, 0.02514413026801776, 0.02301806085597491, 0.0369062432582723, 0.07621505603310652, 0.020795124473806936, 0.018188879948866088, 0.05659274567733519, 0.0161771959028556, 0.1425255576032214, 0.18331157451029867, 0.16902989242225885, 0.18156733451178297, 0.16931878082687035, 0.14283611671999097, 0.15680875367252156, 0.14525186677929014, 0.11895410876604728, 0.18086275435052812, 0.1733591515221633, 0.1204756970400922, 0.21170853433432057, 0.19770793325733393, 0.1731053221737966, 0.11423994219512679, 0.19001840759301558, 0.1476151024689898, 0.08271536426036619, 0.14983912609750405, 0.1220645684225019, 0.19312471122248098, 0.10170296023716219, 0.15478822693694383, 0.12796610448276624, 0.18194345495430753, 0.1343304364127107, 0.18017212656559423, 0.13915012154029682, 0.14346287527587265, 0.09857497105258517, 0.09352889377623796, 0.07657194742932916, 0.16171399358427152, 0.1000054384348914, 0.0939788504911121, 0.15868527407292277, 0.2066857530735433, 0.08116577475448139, 0.11275255950749852, 0.17856512451544404, 0.15661048149922863, 0.10532470027101226, 0.10043208429124206, 0.14762794162379578, 0.10127557223313488, 0.12484791164752096, 0.11111986430478282, 0.1467816112563014, 0.08995899275760166, 0.11542763822944835, 0.13758699526079, 0.13005250424612314, 0.10205050799413584, 0.15469020407181233, 0.09205032780300826, 0.23356748482910916, 0.08386112895095721, 0.2787995006656274, 0.11817841601441614, 0.24978529661893845, 0.14112052362179384, 0.16440929583040997, 0.11370805979822762, 0.11365110738552175, 0.07275944575667381, 0.18920323258498684, 0.14986513095209375, 0.15136438800254837, 0.14390785217983648, 0.12427443187334575, 0.29043809801805764, 0.2245434737415053, 0.12474847870180383, 0.0846795471443329, 0.15438705158885568, 0.11602385740843602, 0.09483220899710432, 0.09620136755984277, 0.1388998396578245, 0.17518015927635133, 0.1453670035698451, 0.14089587552007288, 0.1702148944605142, 0.10814778550411575, 0.1709122461033985, 0.12653530313400552, 0.09393479660502635, 0.14668526564491913, 0.1783619393245317, 0.19217764172935858, 0.08452005960862152, 0.0751285369915422, 0.11830866293166764, 0.13291995506733656, 0.11985238204943016, 0.07443072521709837, 0.0678959145443514, 0.11416364199249074, 0.112273696140619, 0.19916942983400077, 0.14356153638800606, 0.12498074123868719, 0.16774606599938124, 0.13227605290012434, 0.2532184717711061, 0.11266165383858606, 0.08642389846500009, 0.13331718218978494, 0.1087322787498124, 0.1498714688932523, 0.10579660229268484, 0.08236688139731996, 0.1704251003684476, 0.1865535872639157, 0.13059332210104913, 0.13286815315950662, 0.19327345245983452, 0.14685266447486356, 0.1709127359208651, 0.096899357449729, 0.10067097420687787, 0.17221852991497144, 0.0989157058938872, 0.15670221095206216, 0.07878394084400497, 0.09527127840556204, 0.14563564618583769, 0.15272654069121927, 0.16676303202984855, 0.17494002997409552, 0.21339458995498717, 0.09807631460716948, 0.17711815919028595, 0.09768382980837487, 0.10864002237212844, 0.08810279236058705, 0.08943748558522202, 0.10507222163141705, 0.12856173736508936, 0.18864326732000336, 0.33151252835523337, 0.1370509568369016, 0.0932671531336382, 0.12100826963433065, 0.11666578546282835, 0.23509800113970414, 0.06547427925397642, 0.07715834057307802, 0.0939812847354915, 0.10660758416634053, 0.179912656894885, 0.1571868927567266, 0.12800965370843187, 0.14103225257713348, 0.12236403243150562, 0.09084199264179915, 0.1100139158370439, 0.11649850537651218, 0.11577483717701398, 0.11678731956635602, 0.1382713147904724, 0.1245118078077212, 0.10471869216416962, 0.09758056738064624, 0.11140881950268522, 0.16371175122912973, 0.15605916967615485, 0.12861613678978756, 0.3593465988524258, 0.13253881770651788, 0.18869561841711402, 0.10405597655335441, 0.07510220559197478, 0.1458560788887553, 0.06967554014408961], [0.016940552304731682, 0.03421262568735983, 0.023426388652296737, 0.03625168385042343, 0.021111555834067985, 0.03601330972742289, 0.0271718706790125, 0.05172425320779439, 0.00887093292476493, 0.03055625518754823, 0.07597834803164005, 0.008503581884724554, 0.08827762008877471, 0.020023198121634778, 0.010474812388565624, 0.020586363898473792, 0.06514309585327283, 0.0006514226743092877, 0.04492487059906125, 0.060238601799937896, 0.0534443882497726, 0.017569084593560547, 0.07026357343420386, 0.03214629730791785, 0.07321967379539274, 0.06699297315208241, 0.031875190761638805, 0.022600565680477303, 0.05488202106789686, 0.07573414433863945, 0.01545276514661964, 0.005531645947485231, 0.06681657207082026, 0.03318012386444025, 0.048236812217510305, 0.09016146548674442, 0.022697328749927692, 0.05670709579135291, 0.04891534299531486, 0.047170635443762876, 0.021812525446875952, 0.04255590924003627, 0.022061280360503588, 0.11150060090585612, 0.035459274222375825, 0.014522487672365969, 0.06582691814401187, 0.012864663349319017, 0.06561309797689319, 0.0313206320424797, 0.021882714063394815, 0.007579522216474288, 0.01124718866776675, 0.029434758725983556, 0.043312072375556454, 0.01625609176699072, 0.06365345703670755, 0.020252981885278132, 0.09451992809772491, 0.0014519857222694554, 0.040107504682964645, 0.03962949849665165, 0.03141804634651635, 0.05944040713075083, 0.04184860168606974, 0.10029446784756146, 0.02671049973287154, 0.03486446883471217, 0.07948921862407587, 0.03825192768999841, 0.042731675785034895, 0.03913140608347021, 0.04385519459901843, 0.04954207186528947, 0.04175620058958884, 0.08290338737424463, 0.006667191264568828, 0.026820545390364714, 0.05748243231209926, 0.005908393040954252, 0.023655754957871977, 0.08408191046328284, 0.06108592664531898, 0.14876001368975267, 0.01860110216512112, 0.04660629521822557, 0.05295448543620296, 0.057942430285038427, 0.04397811280796304, 0.034573253797134385, 0.01695065850071842, 0.05283777900331188, 0.033411781550967135, 0.01772323237673845, 0.036946141117368825, 0.019218298148189206, 0.028752305697707925, 0.011528600862220628, 0.007812865042069461, 0.050177443044958636, 0.07295477160369046, 0.040055598874459974, 0.04167717299424112, 0.05728867239668034, 0.03871151748171542, 0.09507752591161989, 0.008581547281210078, 0.04464993457077071, 0.014910468562447932, 0.03206073881301563, 0.03479364939266816, 0.016478865945828147, 0.0187177640691516, 0.05182797947782092, 0.07928955121315084, 0.017141483222076204, 0.04464406789338682, 0.06884011192596518, 0.03010981439729221, 0.03813658309809398, 0.010719671026890865, 0.07396519082249142, 0.025547647092025727, 0.0005161069464065804, 0.04319304302043747, 0.03446475551754702, 0.03716713785252068, 0.025704004619910847, 0.01724083638691809, 0.038016945181880146, 0.041001109857461415, 0.03193294469383545, 0.014621687769249547, 0.05957683613814879, 0.05738028681662399, 0.047120577582973056, 0.026332067500334233, 0.021273991551424842, 0.05053713233792223, 0.0457047008239897, 0.011462617439974565, 0.015025436514406465, 0.053462570867850445, 0.028904863429488614, 0.012867097593698418, 0.03719956599525176, 0.01584107165399473, 0.04747699771542102, 0.019347032939549536, 0.023775639638188295, 0.06209858715010341, 0.05036640497564804, 0.031672781115048565, 0.01955760621058289, 0.09304016726673581, 0.0569394177000504, 0.015904215433693025, 0.04947907094901893, 0.017558189865667373, 0.018235915413242765, 0.04388677669339813, 0.0290343607775867, 0.059212953710812144, 0.028663381563092116, 0.03324749974126462, 0.00899804983419017, 0.09870607886114158, 0.007751935181659064, 0.03889049381541554, 0.03449559175351169, 0.0626785347412806, 0.038998750897007994, 0.007403791851174901, 0.016175796954485122, 0.016364241237170063, 0.1009487229748629, 0.050177947705378756, 0.04529619305685628, 0.0021414223601823323, 0.01674080140219303, 0.05631318977975752, 0.020449218718567863, 0.015032978590170387, 0.0630504175205715, 0.01916326604259666, 0.04904745641397312, 0.04101811246073339, 0.0543814313277835, 0.044608626631088555, 0.009581074555171654, 0.01650767240789719, 0.05125339019286912, 0.009290366961067775, 0.04107012216991279, 0.027228533654124476, 0.055524635608890094, 0.04989015396859031, 0.051272422570036724, 0.025640654894232284, 0.09669016086263582, 0.06037044804543257, 0.05377974623115733, 0.015838455583434552, 0.018780907848849893, 0.026859888494072948, 0.019036438570765313, 0.04027856972243171, 0.017377285803377163, 0.07987595177837647, 0.01759636779752327, 0.02143774643627694, 0.0237866160023259, 0.05316952272551134, 0.031137210244196467, 0.03468580049229786, 0.0022335875928547466, 0.03239273115468677, 0.021348538430174813, 0.04211396772006992, 0.16144422290381044, 0.054057587767601945, 0.019699041004059836, 0.03204021842975635, 0.05259005010884721, 0.0023674988642596873, 0.03832973445241805, 0.024086193188850302, 0.00859211268107174, 0.08698558551259339, 0.048553727829130366, 0.0344989759469172, 0.01646272237849189, 0.06612854180275463, 0.006759770012649824, 0.03193320815626066, 0.037317656533559784, 0.04942284584103618, 0.022539069468621165, 0.0400008172437083, 0.07701070513576269, 0.05389165839005727, 0.11057928393711336, 0.038269041615421884, 0.007834160969650839, 0.0728602368326392, 0.02996986575453775, 0.03902140866557602, 0.04815500898985192, 0.021336471108952537, 0.07529471869929694, 0.0408666846487904, 0.04794672524440102, 0.020372942635731306, 0.07056317845126614, 0.06377204481395893, 0.004356684703452629, 0.054124180678627454, 0.06312528537819162, 0.007604412458022125, 0.006604035888813087, 0.0388620844023535, 0.025308653275715187, 0.0395842052239459, 0.04811005339433905, 0.0373374607443111, 0.03985497409303207, 0.04086259541509207, 0.013618470165965846, 0.04935761106025893, 0.0808024340949487, 0.011123857639177004, 0.04525529329839628, 0.02430312666547252, 0.049201003057532944, 0.03270044042437803, 0.009780869986570906, 0.0677162702777423, 0.01159813453341485, 0.045456615698640235, 0.010448001376062166, 0.04178505529125687, 0.026770578442665283, 0.061275515690795146, 0.02864741054509068, 0.10926913353614509, 0.005445957576739602, 0.05375342596380506, 0.02249856490379898, 0.0915788859128952, 0.03866450613713823, 0.04940523467666935, 0.024878459953470156, 0.05470527488796506, 0.020693698861578014, 0.04353547737991903, 0.07928822276880965, 0.006219686883923714, 0.05236732045887038, 0.0325360510032624, 0.02514581679861294, 0.014865518533042632, 0.091483586729737, 0.03587553001125343, 0.010757722793641733, 0.052120953405392356, 0.044444604573072866, 0.05438251857412979, 0.057494358625262976, 0.024063644887064584, 0.032949330779956654, 0.034419157964293845, 0.025140131947409827, 0.04638958809664473, 0.051553188168327324, 0.023230951483128592, 0.07571562033263035, 0.06592972786165774, 0.03327335245558061, 0.06692845825455151, 0.03008154784765793, 0.0355858957482269, 0.049299385864287615, 0.019206468314223457, 0.05305431172018871, 0.043278668308630586, 0.006969949945414555, 0.027428833745943848, 0.01816332594898995, 0.048123868473339826, 0.01118765821956913, 0.060150386416353285, 0.10743308244855143, 0.04019023930595722, 0.06979706682614051, 0.07779718871461228, 0.02720456413953798, 0.013508839183486998, 0.021195062290644273, 0.09873082206468098, 0.0487537922890624, 0.02139753687515622, 0.013059429802524392, 0.05306970015226398, 0.08028595126233995, 0.017241441237274557, 0.02947366396256257, 0.0734625564655289, 0.0420955587469507, 0.04070415430760477, 0.047467108597629704, 0.02905833400291158, 0.048973887314787135, 0.14804572623688728, 0.16482486884342507, 0.1267483292031102, 0.10886641452088952, 0.10296640728483908, 0.13688759529031813, 0.10977830621413887, 0.18776233802782372, 0.105163461266784, 0.10608445169054903, 0.18390078039374202, 0.17341338767437264, 0.17474160937126726, 0.18436824437230825, 0.14471471513388678, 0.1242214351077564, 0.15180552058154717, 0.19685529463458806, 0.14674858568469062, 0.0859428160765674, 0.135347549803555, 0.11953806024393998, 0.22677877801470459, 0.1658365348703228, 0.2983023104025051, 0.18540481687523425, 0.09173147889669053, 0.1447504569659941, 0.1175402061198838, 0.20932765037287027, 0.08776792048593052, 0.09725400013849139, 0.13412495056400076, 0.1359813884482719, 0.11621517565799877, 0.14184463710989803, 0.14744060870725662, 0.2894681703764945, 0.13570198469096795, 0.1606425698264502, 0.12672325945459306, 0.07814944910933264, 0.18414781166939065, 0.19966592662967741, 0.14582041127141565, 0.12585168122313917, 0.22946204262552783, 0.14987016271334141, 0.13585468899691477, 0.13655071961693466, 0.10494004513020627, 0.10110584305948578, 0.1331888500135392, 0.12546959391329437, 0.14493283233605325, 0.06924868648638949, 0.14615755411796272, 0.07195186291937716, 0.16399620159063488, 0.11646644459688105, 0.15563670953270048, 0.11361041542841122, 0.08600808796472847, 0.13579761784058064, 0.13544968416681513, 0.14992034673923627, 0.12485898449085653, 0.09841774706728756, 0.19069140194915235, 0.11331072135362774, 0.15330652910051867, 0.17433477885788307, 0.09187765972455963, 0.17628031899221241, 0.1376505973166786, 0.17227104428457096, 0.09148069235379808, 0.08040364104090258, 0.19888122420525178, 0.04307770956074819, 0.1253136686864309, 0.17451031162636355, 0.1833819449529983, 0.24300749937538058, 0.11593658826313913, 0.15972839231835678, 0.11803838016930968, 0.09941563883330673, 0.0731451844330877, 0.14297770365374163, 0.10266171855619177, 0.16700109816156328, 0.13453040068270639, 0.15035254386020824, 0.12023080314975232, 0.07825129403499886, 0.16570434352615848, 0.17555733356857672, 0.09740734269144014, 0.09509204974165186, 0.16026978904847056, 0.225997697270941, 0.21489586564712226, 0.10396120429504663, 0.14414106466574594, 0.16956431296421215, 0.11895027928403579, 0.1295904876315035, 0.19556352723157033, 0.05625820776913315, 0.09873925286228769, 0.07274610936292447, 0.12774779432220384, 0.18245850544190034, 0.1467239166959189, 0.2965042943833396, 0.21648916765116155, 0.13095931964926422, 0.10886389121878892, 0.16209768393309787, 0.09398547044838779, 0.23653429438127205, 0.07933258093544282, 0.07966690362081863, 0.08247840392868966, 0.18957528605824336, 0.13959383679321036, 0.0759544360334985, 0.12214738468173891, 0.09815564277232625, 0.14577747060684487, 0.125848445459269, 0.09682381423772313, 0.23741375422105193, 0.24249574402347207, 0.24574085895437747, 0.069698027218692, 0.13395649788435549, 0.26608107844367623, 0.1511559632490389, 0.1748972525820136, 0.09461280045798048, 0.13795658480376005, 0.15553582197753713, 0.10388320457423106, 0.1092464238172397, 0.09937579292454757, 0.16110516531625763, 0.13655481627210975, 0.10063023029942997, 0.1564402476651594, 0.10469524029758759, 0.17454568238463253, 0.10301735572284088, 0.10317691005184315, 0.19667737215058878, 0.08413331903284416, 0.0771581476146821, 0.13846606918377802, 0.10958647588267922, 0.12051514961058274, 0.13485307164955884, 0.14331704325741157, 0.119159156747628, 0.12361662185867317, 0.06263825838686898, 0.2485847836942412, 0.1404349721269682, 0.0967729622789193, 0.12034711253363639, 0.1469896946218796, 0.10895642219111323, 0.10051412871689536, 0.15505602350458503, 0.10404690008726902, 0.20449554169317707], [0.026672236454032827, 0.010907252562901704, 0.059748435523943044, 0.09706815893878229, 0.033606135184527375, 0.040592331206426024, 0.0533339937828714, 0.009577780347171938, 0.06365883760736324, 0.03381083806743845, 0.03602787808631547, 0.014264806577557465, 0.029189909364504274, 0.040090027105179615, 0.013035300726187415, 0.06911824661074206, 0.02514376290491782, 0.037007869250373915, 0.024157806728908326, 0.027297544111206662, 0.019281456770841032, 0.005455725167848868, 0.012402610555000138, 0.03459760366240516, 0.05865157836524304, 0.0528542843676405, 0.06213835884409491, 0.022625416495429818, 0.018753459517029114, 0.034994667512364686, 0.06709152294206433, 0.015401493874378502, 0.046867249184288085, 0.031691405310994014, 0.06901089494931512, 0.06553001454449259, 0.03956597807700746, 0.019106486179225612, 0.030094544708845206, 0.03036488313227892, 0.04858198881265707, 0.07135556210414506, 0.039751444492139854, 0.01382928927341709, 0.05535229778615758, 0.06629171781241894, 0.03335600544232875, 0.030789332231506705, 0.02253920119983377, 0.06190963635162916, 0.04475680754694622, 0.04392746865050867, 0.012651207762246486, 0.03250118861615192, 0.06281066671363078, 0.026752705671242438, 0.017471275095886085, 0.04164704179856926, 0.012756281957990723, 0.03177406200848054, 0.04968866458511911, 0.13526747206924483, 0.033759600191842765, 0.02657929915585555, 0.06064253793738317, 0.04983184713637456, 0.040259912129840814, 0.04081470462551806, 0.0044343829267745605, 0.008443082006124314, 0.07228050817502663, 0.01915981134516187, 0.033573784967302345, 0.052691123200929724, 0.028692002488241997, 0.04207252248306759, 0.058802041385206394, 0.04269410826964304, 0.033962009838433005, 0.030645991973869968, 0.09633056062739342, 0.0843224256823305, 0.09073641471331939, 0.014451709976128768, 0.07284559425897896, 0.04810091013496276, 0.12331464196904562, 0.024087772108032368, 0.018387799646006897, 0.015746351346024312, 0.023291327051992994, 0.05172653902263846, 0.03253505281463731, 0.04752977554744575, 0.09475530023337342, 0.045051061679259874, 0.027474995331431273, 0.012829996703658253, 0.015877431324042846, 0.03015797792613739, 0.05904145822569262, 0.046229851941461675, 0.059224991346127354, 0.017078619603125844, 0.03672446902783122, 0.06215370274730958, 0.03872018576657865, 0.03044776061869925, 0.04518356472544838, 0.012775876512023387, 0.04829996527405456, 0.024685013595444616, 0.03324714351037983, 0.0003956387524794991, 0.047629215914639644, 0.0069030207487230655, 0.02475245069945231, 0.04361666091426741, 0.018523104299674742, 0.03760132392926607, 0.06128104840172455, 0.04781218871357851, 0.021708194326492958, 0.02514410614821827, 0.05047654340160079, 0.06199312054377515, 0.03321367265016306, 0.02727124981902307, 0.0443198606808437, 0.02078758981951978, 0.04023276436782908, 0.03958722576498985, 0.005450850185297895, 0.036367900465847924, 0.04866868279350456, 0.047809123643673956, 0.06574251368874684, 0.01215665353811346, 0.03313484543468803, 0.026446961237525102, 0.012248986913618864, 0.014369074615387945, 0.005167735225768411, 0.014396919996215729, 0.024759951957094017, 0.04206886369502172, 0.0254588379902998, 0.042789121725945733, 0.06078716025513131, 0.04773570668476168, 0.043190809155930765, 0.020194226053718012, 0.017734702269081026, 0.03696226056490559, 0.07503639935748652, 0.019697857278515585, 0.06484090074081905, 0.016990897747746203, 0.02207689143688185, 0.028591196569323074, 0.03708874479343649, 0.013717297333641909, 0.03566943560144864, 0.08475881593767554, 0.04435503848071676, 0.05067120502644684, 0.03618420407292433, 0.01830614113714546, 0.03330472674861085, 0.038948923101997934, 0.01076300874046865, 0.028796359583793674, 0.031249489766196348, 0.03187281217833515, 0.031165322798187844, 0.010772158493637107, 0.02799911115289433, 0.037082380877109244, 0.09185989270918071, 0.009425524112884887, 0.03882283592247404, 0.0662450293020811, 0.037244098566588946, 0.03302972392702941, 0.045865795109421015, 0.04855708233662881, 0.05641748750349507, 0.015167162600846495, 0.04225152850267477, 0.0536855157406535, 0.015183489849732723, 0.035437655460555106, 0.024007670253922697, 0.14200428791809827, 0.038785246142651886, 0.03939709495170973, 0.02767414323898265, 0.03345802477269899, 0.05419462904683314, 0.06355383855407126, 0.037101650741533376, 0.038071890085120685, 0.028864412670372985, 0.01997393435885897, 0.08679002217832021, 0.05250822090602014, 0.10556341207120568, 0.037827434061910026, 0.033545909900567494, 0.06657880279817618, 0.0387680913991062, 0.06098988902522251, 0.010200138895015698, 0.032549379975534976, 0.028444414601835888, 0.07136132117011584, 0.0202818050456699, 0.03695450141094625, 0.021042400658188853, 0.025507263126200996, 0.031493827045778744, 0.03631572748417966, 0.02110708439431619, 0.05381756607675925, 0.0784705689875409, 0.05298690986819565, 0.030432828607445117, 0.029975123870826792, 0.05897992305108346, 0.015091467248566914, 0.03582751676731277, 0.04983277482097037, 0.031854444023338147, 0.017398826639691833, 0.00899700062291231, 0.021545944146055263, 0.03695800063724164, 0.05853329857927747, 0.03134917875286192, 0.05065484809165355, 0.037358188928919844, 0.0369656670227414, 0.04959284589858726, 0.04056992205732968, 0.09176560284686275, 0.03401016780117061, 0.03447409544605762, 0.06893612357089296, 0.048391011951025575, 0.11190719393198378, 0.03957291344704572, 0.014737480432813754, 0.03864882826746907, 0.01390248173265718, 0.05349365201254841, 0.021894820347370114, 0.019370375339349266, 0.0642315307050012, 0.05620023119263351, 0.023633351374883205, 0.04730209577246569, 0.0349582354829181, 0.06554005580255762, 0.021917544909229036, 0.004842315529458574, 0.01782457264198456, 0.03799776437517721, 0.00829139073175611, 0.003120450819551479, 0.032701605596230365, 0.03719770691532176, 0.01629859827517066, 0.1389546546852216, 0.03830676869256422, 0.024687368058948778, 0.044512722597573884, 0.046584695010096766, 0.01355899630652857, 0.02654221960256109, 0.0679565554310102, 0.03146404465951491, 0.034647776556084864, 0.011504926351335598, 0.07224697794299573, 0.061967111978447065, 0.040891583703341894, 0.022625112214882392, 0.019943096267525107, 0.020260227101971395, 0.03828330940450542, 0.030675262278236914, 0.04439567477675155, 0.029285731761774514, 0.08083332228125073, 0.024405392759945244, 0.06647094647632912, 0.03011212062119739, 0.09652852852013893, 0.03831481357337907, 0.05705481053155381, 0.02868665716960095, 0.009095064306166023, 0.024102192037389614, 0.05823304418299813, 0.031482650301768444, 0.06035113365214784, 0.0448115446488373, 0.05393327432102524, 0.010417419325676747, 0.07450347053236328, 0.015816873928997666, 0.001650644392157119, 0.03756100675673224, 0.0473482833331218, 0.03172503944369964, 0.040001997258514166, 0.02317618840606883, 0.04925785156956408, 0.021412092246464454, 0.03610218562243972, 0.035924066469306126, 0.01040409499182715, 0.025405887608940247, 0.021547873730014544, 0.03274963739386294, 0.029699260157940444, 0.029618265871249605, 0.034264086207258515, 0.011064771551900776, 0.05454971702420153, 0.028778781816072296, 0.016498887234774884, 0.013155419183021877, 0.05709989971364848, 0.0317793164140312, 0.04831959136936348, 0.057956174860009924, 0.03557347219611984, 0.042809181977645494, 0.04144397906202357, 0.01335761360678589, 0.02595696751086507, 0.024032888431975152, 0.06849563666037284, 0.046101311963866465, 0.05780612744274549, 0.060122396316728555, 0.06105490116169676, 0.05095461638120469, 0.02960126326797763, 0.06795491528464481, 0.018171263218391687, 0.12766658852342516, 0.1903408410726115, 0.17053244460839778, 0.17948376975255087, 0.15905608073808253, 0.11063790618209168, 0.24586671235738322, 0.1080304074275773, 0.14938923617592081, 0.16428314556833357, 0.2065587864490226, 0.1228617166634649, 0.15766311407787725, 0.1671261797309853, 0.11958287854213268, 0.15877137804636732, 0.15950934001011774, 0.17368271306622773, 0.18107107520336285, 0.08922036286094226, 0.07445680428645574, 0.10617284890031442, 0.17437147063901648, 0.11498735169880092, 0.11006555447238497, 0.1759164736722596, 0.14884608797729015, 0.19804743613349274, 0.15203193499473855, 0.1410846333601512, 0.19076365744695067, 0.15911496273474768, 0.08011855985387228, 0.1749361411202699, 0.08970140072051436, 0.20061878487467766, 0.13109572639223188, 0.10040207926067524, 0.23836086824303493, 0.17138057097326964, 0.11447703611338511, 0.14340375579195097, 0.13757287961198017, 0.06818576031946577, 0.1365358618204482, 0.1818187444587238, 0.10587781551294029, 0.19166015699738637, 0.13481066533131525, 0.1409337398945354, 0.15667179774027318, 0.15257739869412035, 0.09185828224872239, 0.14537031354848295, 0.27211512497160584, 0.12383761117234826, 0.08686356159159914, 0.09132748338743113, 0.14093970676185563, 0.08860837304382585, 0.16333049512468278, 0.15458519017556682, 0.1386461142101325, 0.19954063725890592, 0.1432209202903323, 0.14166825829306617, 0.182082251412794, 0.17231110541615635, 0.16011736675864086, 0.19555894075892866, 0.1380772134871222, 0.16982143744826317, 0.12929508317029104, 0.23137819371186197, 0.14346137613756582, 0.2164063142845407, 0.12842354946769774, 0.08270664402516559, 0.2615706610959023, 0.09276647804654203, 0.1666370895691216, 0.20264407619833946, 0.13362410478293896, 0.14061301335459575, 0.17120603268267587, 0.11749319106456824, 0.16173233947483823, 0.09391325947945006, 0.1239291179808788, 0.13246023911051452, 0.11125761433504522, 0.1111990588833578, 0.09467033174587414, 0.17355234740534797, 0.1741501473588869, 0.12964945868588984, 0.2478355707717128, 0.2024229013477452, 0.09498711006017402, 0.14826344267930835, 0.14245171390939504, 0.1439889837638475, 0.1058053967426531, 0.08344089525053278, 0.16782449616584927, 0.10847346959053539, 0.1518580349511467, 0.12682160886470228, 0.11671987318550237, 0.07487430688343011, 0.15864907210925594, 0.09286462707677856, 0.14594898093491793, 0.09595947194611654, 0.13643760146806017, 0.12163140650955029, 0.06504968914669007, 0.21856611245311797, 0.09120767848799005, 0.2550390490796417, 0.14017719455296174, 0.13531051663449034, 0.16332837258232757, 0.17462164862081409, 0.11761931906221434, 0.1617754582548514, 0.11716531022102572, 0.1764882984571159, 0.23827706492738798, 0.11474932267447002, 0.17715700319968164, 0.11694706685375422, 0.09761022360180505, 0.13706652709515765, 0.17491196194896474, 0.07814297758159228, 0.14116576494416222, 0.10422431791084819, 0.15752727136714384, 0.1077252956747543, 0.10229745021206327, 0.12406778827426024, 0.12089473588275723, 0.09201184744597413, 0.1456231632619165, 0.05878860851225909, 0.06712068934575655, 0.20241096761310473, 0.07124072959413752, 0.20325746125308797, 0.09808450049604289, 0.11784715839894488, 0.1381527938065119, 0.13892680930439383, 0.13423233933281153, 0.13560942403273657, 0.13273229560581967, 0.0960089880391024, 0.08886534909834154, 0.10428530760691501, 0.11595063711865805, 0.13599863596027717, 0.12331818943494, 0.12497207295382395, 0.07244796637678519, 0.12356185878161341, 0.11248019131016918, 0.16104655049275607, 0.17285063193412498, 0.19255704246461391, 0.16654175327857956, 0.15809605334652588, 0.11480467204819433, 0.0940521078882739, 0.11490423858049326, 0.1387307487311773], [0.04655030388676096, 0.016102079425763804, 0.034500623514759354, 0.03905722471245099, 0.048170620066230185, 0.058216412653564475, 0.03648829908343032, 0.0679799256613478, 0.042577086423989385, 0.03682475915411487, 0.0799950367945712, 0.04020585780381225, 0.04859497268626001, 0.03894159810442943, 0.035892083615181036, 0.011132083418488037, 0.02397464468231192, 0.024964610311144497, 0.013811128919769544, 0.053111089728190564, 0.024825145919749048, 0.03318406095786486, 0.025795294350245968, 0.012864883210568223, 0.0644697601092048, 0.012288943216844928, 0.01315247935053776, 0.017186826589750126, 0.022690135483571794, 0.04167618593783118, 0.10789692474645562, 0.013941686611360637, 0.009099670260184212, 0.021601200751319993, 0.012686076643149136, 0.06969447975279763, 0.01134287376771681, 0.08709752364666201, 0.023222895470098592, 0.07308648797334172, 0.033663135836832225, 0.029151091330277268, 0.03668042256322224, 0.02298038572916994, 0.06502327611087821, 0.022108189659775235, 0.1313241891330108, 0.036097350530326366, 0.021764065058960114, 0.050872434658231214, 0.0843063804495614, 0.010234249857603572, 0.03166178990795743, 0.044067968337913044, 0.006909505727890064, 0.04260701723978855, 0.045725447562290356, 0.02044074710283894, 0.016494265510118566, 0.010662352178769652, 0.03131971549009904, 0.05554478491831105, 0.032218890482909046, 0.02197315960074775, 0.030148745609039906, 0.02366259755945066, 0.034383917081868276, 0.06787528283894062, 0.03631182749813888, 0.02042552750936011, 0.05944453347183298, 0.06698167024296708, 0.0343997582240263, 0.06347573493258096, 0.04038582119392231, 0.03463541237579193, 0.06946633613551967, 0.038333812553901225, 0.01857539788034046, 0.0629722916346509, 0.004094470477866707, 0.05097697357996367, 0.02898039365391014, 0.05196495396376122, 0.055617545076529495, 0.014175270171108423, 0.020221279191900976, 0.03691947575134691, 0.03039097889995901, 0.014765921387152048, 0.024150760036718566, 0.01335587605353794, 0.0388901041878853, 0.03783354564802721, 0.03710451172082685, 0.0167932601107168, 0.025429515735595487, 0.03862576231767889, 0.03336808018502779, 0.03633623673522379, 0.06108125853643287, 0.07207755304989405, 0.057884969501174055, 0.04639872393454425, 0.06750591594027355, 0.052250814405852, 0.05598481911874842, 0.04120276622415986, 0.01881004271126585, 0.025189302941726055, 0.09471962519455701, 0.020897115973639302, 0.049228774223593064, 0.015977335533534642, 0.048873463601921685, 0.03473823693639133, 0.02611684652947588, 0.03000665772560751, 0.04065944733156357, 0.023568604556203354, 0.02683422131667612, 0.06647493923082948, 0.07604116341099143, 0.03099490157183027, 0.01161823931397521, 0.07195739191956818, 0.05208389055042062, 0.09369678984512575, 0.037508692767005414, 0.03760019215405919, 0.05499432656506542, 0.031690889518358745, 0.039870184409664944, 0.02775100747385295, 0.03575155795260798, 0.010676853744371329, 0.01933945375640178, 0.037879944720771164, 0.0694426690461114, 0.02214471074694302, 0.06586988107301295, 0.08075147081399336, 0.015637955111742485, 0.039906850215629674, 0.09166389892925508, 0.02480909326550318, 0.044412243223632686, 0.03431330915191211, 0.051219863671576604, 0.05382648669183254, 0.023851459300203715, 0.011443214916653233, 0.04572838275635149, 0.04710920045909006, 0.04972595379513223, 0.03205788154446054, 0.007762107707094401, 0.02341142881050473, 0.014855201752652647, 0.015758093977638055, 0.04376341690658592, 0.054800206708023325, 0.01133688278059708, 0.04939423604810145, 0.024683635056135245, 0.02076277982268948, 0.02724775898968801, 0.04471354775887448, 0.05749595053202938, 0.03431001772696618, 0.044392709896783344, 0.06253944142372347, 0.03371613631315995, 0.030961499360273592, 0.0203071902069496, 0.03554340779373888, 0.024992984472191893, 0.010868056961044203, 0.02388197826803662, 0.023403914565278683, 0.0318152140971506, 0.03699592809425667, 0.07739569424302317, 0.0155648721192847, 0.03568151776562445, 0.062074237284832634, 0.041616450471337885, 0.04467458129511215, 0.03183524095220491, 0.024789864219201263, 0.06339247338473797, 0.02153446497686673, 0.04041313593916129, 0.03604856916354038, 0.06616260638111271, 0.10760126053355634, 0.0302342651411891, 0.04331015021307394, 0.06578363609150983, 0.04464034231205005, 0.008596608240623027, 0.028812358432332985, 0.03699432134453673, 0.04249527948559262, 0.03588337822293397, 0.03780964107136242, 0.06427942891605198, 0.021751409585704096, 0.030754341823922005, 0.024529253496439196, 0.03681089583551511, 0.05429513068520464, 0.0318506034091115, 0.009257452711608494, 0.048186628191615455, 0.05639601717120968, 0.0517375970230205, 0.0805321364896372, 0.042831468672375195, 0.02118770389643032, 0.029033434948360082, 0.033967587078223005, 0.02832215319358511, 0.051504900329746306, 0.04539038643997628, 0.01960696274181828, 0.023241044691530988, 0.02021436237555463, 0.00564037800359074, 0.02192322976043215, 0.00389890111364366, 0.050491430883994326, 0.05340607116522733, 0.04485057790589053, 0.05495767931279261, 0.033398422892787494, 0.06250607446418144, 0.04152043511567172, 0.01639995152800111, 0.0519519441149896, 0.049584993976168334, 0.022227872104849666, 0.01977421128685819, 0.04780376904818695, 0.04832464539504144, 0.07192778022726998, 0.013379888241615845, 0.05830336638609879, 0.02673885719559621, 0.09584245010046288, 0.02267087489599362, 0.00549229124771955, 0.025263319184887223, 0.024068635830190033, 0.04262959708285052, 0.022542366459674668, 0.045746583928121254, 0.024058928538579494, 0.03652771825727541, 0.0374925176583929, 0.06707619017106481, 0.0445586207206361, 0.05000319048122037, 0.026288069275324233, 0.02613027383631561, 0.01633390780625632, 0.0644660196849145, 0.030948901403462514, 0.0638810292002745, 0.0243636617960874, 0.03732029115781188, 0.05609649379039183, 0.019647918161354028, 0.07322503952309489, 0.018774417767417617, 0.035554447240429, 0.004003164049208863, 0.024863759863364976, 0.031627153875888325, 0.04439224234374706, 0.015496805117436452, 0.00723496531463752, 0.0226766116975341, 0.027440561534604058, 0.024988503755594138, 0.014979483657953097, 0.06873464531963691, 0.03580901873647235, 0.021535461310122628, 0.028954782137589063, 0.015537376475549536, 0.03720809327205643, 0.039805060951039195, 0.03814207870163955, 0.02213837651652284, 0.020548293578031007, 0.03204010339686647, 0.03018579176568892, 0.03879386618791614, 0.020227555905876216, 0.03722305496921763, 0.02428913903713692, 0.05645868783176411, 0.0532219628803432, 0.03186085246852599, 0.02884045799874002, 0.04605681649991311, 0.020394207022036426, 0.055051468225428835, 0.1108132979425136, 0.06484441109932959, 0.044770114254788496, 0.04130547575186938, 0.012709846705547534, 0.012856886569352355, 0.04464803096198011, 0.07477583130821586, 0.05538412478927057, 0.033581139650777914, 0.10148088738787919, 0.02934648025984643, 0.005061884558017482, 0.026663480966817588, 0.08724375642486848, 0.02928734593297122, 0.021199368602538016, 0.018678292944969144, 0.05016829236410558, 0.040588947013020515, 0.0820056113298051, 0.058012440786114894, 0.0497863571945345, 0.051234380080131814, 0.03496295554214157, 0.036449080289457925, 0.031083259818842635, 0.045433894847519696, 0.05986972100799903, 0.07493203112971969, 0.016584623845119495, 0.03063529948121868, 0.04126977473788429, 0.04103897052118555, 0.023551715130452067, 0.03565303784853313, 0.030631978370365687, 0.005698366639990127, 0.03000563541718293, 0.009442728951398749, 0.07449830518453382, 0.02782717223453801, 0.02207309164077742, 0.16018822701880708, 0.10517242641071789, 0.15299454506020993, 0.20690247503807768, 0.13709173043025658, 0.14718602236825973, 0.10167647298658267, 0.15273734636139125, 0.10246464124065824, 0.16807933483505622, 0.08698076155269518, 0.1706214132718742, 0.08287884455057792, 0.11988240934442729, 0.11665506885037757, 0.11208359501324594, 0.165219409391284, 0.09709631602163427, 0.1433374671614729, 0.16988757764920592, 0.14780017925659195, 0.08784833960817195, 0.12201885212562047, 0.11616240895818919, 0.16499968915013596, 0.13226919545559213, 0.04630942872609012, 0.1948805435677059, 0.13145507429726422, 0.17402028635842726, 0.2929461415624246, 0.07192137549282052, 0.1170061640732456, 0.13293870171764866, 0.10166884370846674, 0.1907774168648757, 0.08804520912235603, 0.1593607768882066, 0.1315826049540192, 0.14339468674734235, 0.12293340812902898, 0.1335493111400865, 0.06630613774177618, 0.18017807858996093, 0.14448398142121732, 0.0999236389179714, 0.15163781004957855, 0.0987909508694429, 0.13332778005860746, 0.1449880184372887, 0.15228761971229687, 0.1347099558915943, 0.09859941739705391, 0.10308732540579513, 0.10204418489593081, 0.09274850322981365, 0.16114294063299894, 0.11136231652926654, 0.16490007808897644, 0.13030648202402517, 0.10882232352741994, 0.14329604047816247, 0.10542664167587645, 0.21493836102308705, 0.19811185455182567, 0.17476804467150941, 0.1378157697035931, 0.1681664036004804, 0.12478122225729749, 0.16965182701824233, 0.16571145330090076, 0.13083119527436793, 0.14209301909431815, 0.17977013485506177, 0.1502089828136377, 0.07439383305609226, 0.20058011898072436, 0.09246009722119197, 0.07907482562586665, 0.09176473453408107, 0.1297638681717217, 0.11584523730562069, 0.1893996197031811, 0.17095701245125383, 0.15958772564772516, 0.18218083831015974, 0.16312024468788877, 0.11673425600747578, 0.10411049472168088, 0.09835746983299032, 0.15688871266320348, 0.11993524283752777, 0.14669509168015793, 0.1467106322525069, 0.16730344912502915, 0.22006167360814288, 0.08921452958020382, 0.1841085372143425, 0.2043562405742705, 0.13580563303548843, 0.11917899435502477, 0.14334113337099552, 0.10929840384051204, 0.12390020390739664, 0.1383493738831021, 0.12561650946736336, 0.11951693872106262, 0.1346079254290089, 0.12872582621639594, 0.13935155526269227, 0.14194470830261707, 0.12800702650565654, 0.07613589114043862, 0.09797088510822505, 0.13580631581135094, 0.07934878944070078, 0.11153013838338666, 0.19892694050213322, 0.14258801675168797, 0.09366936748847365, 0.10108486996614374, 0.09301694546593353, 0.19849845411954448, 0.08051824348513037, 0.15668819920392707, 0.22712448524544016, 0.18031116051133722, 0.15954383503412828, 0.10737017801147886, 0.14958390151150525, 0.16735447919927537, 0.12035011081025004, 0.10258574489853345, 0.2245437409146689, 0.12308277277043089, 0.12893340492155403, 0.09940046933479607, 0.12535668356576934, 0.15514509606873617, 0.11172608021297492, 0.23152122041210532, 0.137931099452544, 0.10823195989360102, 0.15588388923788443, 0.17470888065872714, 0.07293359813047573, 0.10960312225506641, 0.1673432282404974, 0.09427597673493437, 0.07334882975555956, 0.14852735039312392, 0.10815156303578988, 0.10484701691893861, 0.1757165094022639, 0.20705178030766547, 0.14284643257269636, 0.15316414064727724, 0.11138395013404079, 0.1084272783191409, 0.11931749395444058, 0.16774452233221382, 0.10331197350751609, 0.13755903113633394, 0.14816050679655746, 0.1471947500249371, 0.14014859218150377, 0.12368993120617233, 0.22054694913094863, 0.12640639208257198, 0.11141943221446127, 0.14201797312125564, 0.15339711564593017, 0.07404901640256867, 0.14986229594796896, 0.11701906259986572, 0.11870079149957746], [0.043061879550805315, 0.03125109651591629, 0.02577887433290016, 0.03724408372363541, 0.07615077862283215, 0.015218561893561855, 0.030262195868999697, 0.04919904007692821, 0.0710714679735247, 0.035862130534951575, 0.04461028162040748, 0.036472869833232835, 0.03708998789079487, 0.04280561966879759, 0.0663437126786448, 0.021325118104869034, 0.013734863969148137, 0.0859019385825377, 0.038259252687566914, 0.07483605659217574, 0.039201357212732546, 0.08974429685622454, 0.0492279244645033, 0.03962333867093548, 0.04648292058845982, 0.03248931796406396, 0.020497729201451875, 0.007140559955587378, 0.049246114504057914, 0.09036448740516789, 0.0014472481529992365, 0.03484521010250319, 0.0721650967898313, 0.048946724709821865, 0.06394984113285318, 0.012318549343035556, 0.05535779710044153, 0.012180605426692637, 0.041894796668202616, 0.028574216230481397, 0.0237580655812053, 0.10609925753669813, 0.041859392513288185, 0.009723091934574768, 0.010844833304872736, 0.055614227676414885, 0.04814036641619168, 0.054326441895682365, 0.04749994492158294, 0.0625746266450733, 0.06018576088536065, 0.06840190340881236, 0.052782080820179544, 0.1290996014722623, 0.015222010097204475, 0.021803460113005713, 0.01178030024675536, 0.017103451864386443, 0.0008827521924104076, 0.05416639403847512, 0.009713381859910442, 0.032882463274290785, 0.05483918430400081, 0.04170282161794603, 0.06734432812663727, 0.06423835104214959, 0.018202279425167944, 0.07074160559568554, 0.020429598189366516, 0.04515853950579185, 0.04929440234263893, 0.037089104735059664, 0.04907956172246486, 0.01871191223472124, 0.07549526926595718, 0.030343891485244967, 0.008094545337371528, 0.06968118788790889, 0.03808941961324308, 0.027905990173167083, 0.03143546084174886, 0.03159222469548695, 0.053482445582631044, 0.042894770158454776, 0.03799298865487799, 0.0023290196668313, 0.04979478057066444, 0.02754974630079232, 0.028112615218560677, 0.08507526028552093, 0.09244638975360431, 0.026061807002406567, 0.04735156733659096, 0.0179430361095001, 0.10967490277835168, 0.041628558610682376, 0.028171356207167264, 0.026822794097824953, 0.0245231660301215, 0.04567851414321922, 0.03657080735138152, 0.029731254144280683, 0.02477742211340228, 0.044847932149423286, 0.04532019040198065, 0.052051076490897685, 0.09761490655364469, 0.08599432854680344, 0.03515955417242367, 0.03209071415767539, 0.023748089261061978, 0.06540528178447857, 0.01734496898279758, 0.022198447804839816, 0.05361545328923967, 0.044174236463732086, 0.009689730541140307, 0.0359437259612605, 0.0516248128406005, 0.027415842450864147, 0.0661020100233145, 0.035362728231120855, 0.009955450950656086, 0.023559928849863354, 0.03959633562772069, 0.061294184415601194, 0.027148044027853757, 0.026454193466634024, 0.06968790432438254, 0.05973322149657179, 0.020204948232276365, 0.028396601737767924, 0.07086348108714446, 0.060574186136364006, 0.05637761561956722, 0.0634271465241909, 0.052183527586748824, 0.04349106355221011, 0.020809123234357685, 0.08537757414160296, 0.02122441423125565, 0.0271999999313266, 0.02210436203313293, 0.05182632819924038, 0.0181230124871945, 0.022993531019892544, 0.035078244472970255, 0.01713319528789725, 0.06755814829375595, 0.014962906861910596, 0.04013750971353147, 0.024935646142694168, 0.03493142168736085, 0.03002016295795329, 0.027108613721793517, 0.04796482993697282, 0.04439285461558029, 0.056882331700762734, 0.059580817760434, 0.02076056451187469, 0.030131538915156852, 0.051408940635155886, 0.033110521544585936, 0.03663965268060565, 0.011075687616539653, 0.022134643513709307, 0.04028593182738405, 0.01914548789500259, 0.005843050184921594, 0.04601190914399922, 0.054153606834006496, 0.012400159612298012, 0.015291505733330268, 0.017965864572033752, 0.06785065095755272, 0.05750075222749729, 0.053303495224099606, 0.0656930347031448, 0.022315812893793918, 0.06228220561752096, 0.02772216575976927, 0.04207545025565196, 0.04596187725837808, 0.03181411200785078, 0.034766126846079715, 0.032603155996184796, 0.014959648833610117, 0.027004058101738337, 0.040472845430485904, 0.02794403822917957, 0.09060856493306346, 0.04204610573651735, 0.051823960748151876, 0.06979101090109907, 0.03496940109471325, 0.037515591029659845, 0.0466192790918285, 0.028283208994253073, 0.040620321306050755, 0.06040409702109173, 0.01183484439025051, 0.03412793550523929, 0.009893651385937119, 0.029286459066497628, 0.07278143559233285, 0.07505374334868975, 0.02005137375817867, 0.07882806152338162, 0.04082871637365315, 0.02544020451750839, 0.04621497559128329, 0.03990491321019363, 0.06580221946933307, 0.06484391386038624, 0.09399200134794228, 0.033784354527597316, 0.01554347971250536, 0.10606154901324771, 0.02161019372579176, 0.01686373074335279, 0.038729655570932664, 0.04266540941898711, 0.020161168940830976, 0.011457910368335433, 0.02893715241953032, 0.03257461670727935, 0.041065672994591296, 0.04799946225830354, 0.035746878711506724, 0.10288573583238758, 0.01838690906879492, 0.030508013733197004, 0.03133286634692922, 0.03624037351983134, 0.007001102985668695, 0.03885456644638907, 0.02421174602204701, 0.039789832080714405, 0.07195219688583165, 0.05374742569983937, 0.02700687269680202, 0.10553394138696603, 0.056788576184771955, 0.0429973015707219, 0.017171048530144617, 0.050373963749734685, 0.0601466645457549, 0.06792139247409068, 0.04591326658555772, 0.01760832565196324, 0.04535147192655131, 0.0362460917676799, 0.030633848582510836, 0.0391560194111662, 0.04880830674665049, 0.0535751658026129, 0.020646871198550798, 0.010718790654209442, 0.02628580572491046, 0.07034078647848219, 0.0066459111076255795, 0.027349360861990135, 0.0631808202888351, 0.0958282825013157, 0.020813355331483763, 0.01096990652513341, 0.038756313515477814, 0.05536287710128818, 0.04524961215793155, 0.0034585695902933367, 0.14566347672371194, 0.04169992724200711, 0.020376467837195378, 0.051213748374721035, 0.12069839329342358, 0.07327221785089932, 0.057475307694403455, 0.046681997991981916, 0.0070492321901838295, 0.018123788031516597, 0.04413667265907861, 0.041209152404917404, 0.01358627394438372, 0.019276384191471152, 0.01257623507626704, 0.00923260839044815, 0.0376549663633341, 0.06863274102215655, 0.06156193274364341, 0.037186834451858886, 0.01502537992564612, 0.07668667603866197, 0.03136876031931024, 0.04390069567307364, 0.06600839551538229, 0.007242041692734347, 0.07018129152129404, 0.019944853302149568, 0.0295822141924873, 0.026965817087329924, 0.037610656436299905, 0.032500643137609586, 0.021673176088370383, 0.022333088236337062, 0.0029855617685825564, 0.06540073241922073, 0.039001597033347934, 0.048280706541845575, 0.0814383062242996, 0.030217767198337242, 0.05634250832372345, 0.007123908480934915, 0.06186573089507874, 0.04275494582543615, 0.043635426118271425, 0.040290336473844945, 0.0913449090148788, 0.029910096891399007, 0.027367766124370974, 0.028820022962463554, 0.007680349472138914, 0.039536217955173925, 0.01745974768709857, 0.0326657004916342, 0.03644206328317523, 0.041920018556993455, 0.02030067229497945, 0.007671329594813869, 0.009662238608143525, 0.012256609697942622, 0.054976014071144164, 0.12082849920261651, 0.05941925221122801, 0.06745819584466517, 0.03484221553662792, 0.020128488467889838, 0.02046451067144517, 0.02063651081698481, 0.009211828255502041, 0.0389327962329844, 0.04151698783971369, 0.040707100633881055, 0.027748636312026065, 0.042934634620905854, 0.050334830302745104, 0.0338449323317036, 0.03754903962544631, 0.031137277037487365, 0.04612906828697305, 0.024668244768690784, 0.04493526808801107, 0.055519084344268776, 0.15323250729124993, 0.26155558065511286, 0.09291327485698275, 0.16704185691196471, 0.14784555416554213, 0.13942695746663958, 0.14093463047174737, 0.1963341436930932, 0.20395341765834019, 0.12252870757947676, 0.12110281924833544, 0.10014816085458733, 0.20290226937504485, 0.12636036408366635, 0.19869826996000484, 0.09813586453674361, 0.08381683015613817, 0.22243771876674145, 0.08490645137499087, 0.16616943263215944, 0.15962544159265235, 0.1776046073064208, 0.2658572170184925, 0.17032188246957958, 0.1187924986879807, 0.17964730941457674, 0.11679334580549039, 0.0878963120339904, 0.16093390731839463, 0.24136536405421793, 0.1350342744262889, 0.1494441699469462, 0.17351926246192306, 0.12827563943574205, 0.16424618661403656, 0.10511360378586687, 0.20639480149839073, 0.1995383811299689, 0.2955714741256088, 0.07520406536059454, 0.0818707408325281, 0.21802388451760635, 0.14037123648449779, 0.13808197807520628, 0.10979144222801551, 0.1658224785933271, 0.13271319272462279, 0.1926069296314381, 0.12158764206105843, 0.12359517379081808, 0.20214891526848078, 0.15653494570869952, 0.1476667559472844, 0.2533492975635454, 0.12177939075627364, 0.14031315600732341, 0.1332813364570029, 0.2466339446255006, 0.08381469277082942, 0.2127968642162159, 0.07270374015206471, 0.14593689877074212, 0.1840978057589382, 0.15279648068826646, 0.18731915712123737, 0.278981831506826, 0.13315828837221488, 0.20805776148336008, 0.1774669240694493, 0.1227132574422285, 0.11571285300306045, 0.18825099774403498, 0.22940642607863992, 0.11251485702814534, 0.17758854723069817, 0.17431580956326798, 0.08250570754171349, 0.15035287040518597, 0.1902833246276714, 0.1260696945246309, 0.13054475595708936, 0.11339543751091696, 0.13104100042255595, 0.17151056556031108, 0.14378760941326618, 0.19322766194818541, 0.11567861773073673, 0.20382170128868893, 0.17653523187618703, 0.129581477958709, 0.145256764953956, 0.14668821939267218, 0.14653892896603793, 0.046580412818002515, 0.3235341142863035, 0.22854774637380615, 0.1295707019744441, 0.12150016511441208, 0.13297413184773177, 0.15739392227260396, 0.2030952722998336, 0.17503818642580882, 0.13513208949007094, 0.16932311496930197, 0.08938579499954358, 0.17200868023792282, 0.16148238413734362, 0.17967463529203087, 0.09316856623627245, 0.08613431986304931, 0.1630315580405295, 0.1843044048291631, 0.09406773751834407, 0.14818345400271937, 0.17566031398018822, 0.20499551173998043, 0.09698118665255606, 0.11558489190065302, 0.20462351763853803, 0.11666928097838536, 0.1526365923928097, 0.09468277014093474, 0.11125987046398222, 0.05056167887232732, 0.15473796869628131, 0.13132499065250158, 0.12203703474369831, 0.08157038624631241, 0.16125773603562266, 0.13797265972243622, 0.1378654342261143, 0.12159503385191783, 0.15997175738448277, 0.1799291474162601, 0.15554251614958048, 0.15606319211656228, 0.16912136954488233, 0.13219900312833488, 0.11057350260671228, 0.17618821846554056, 0.1327955414308235, 0.1528316584881395, 0.1099059556145221, 0.20111507386900485, 0.09853069452219643, 0.218616608181037, 0.09534895900287665, 0.11007240449544042, 0.15691151143983006, 0.20193388540064916, 0.1083240752632264, 0.15478335844818503, 0.12840052804676816, 0.1318966076360084, 0.11663888260954991, 0.21063642780063674, 0.13227024930529296, 0.12767596927005798, 0.08053984740399756, 0.11405314362491481, 0.14147547801258042, 0.11685904071782716, 0.07563764287624508, 0.11619553100899793, 0.09754518177942373, 0.16713360120775178, 0.1661850028904155, 0.08488226478220895, 0.17768839577911422, 0.22875073860632256, 0.20352646009996533, 0.1550411360221915, 0.27808549522887915, 0.12845330958953127, 0.14363662688992918, 0.12645728857023641], [0.021872119905310683, 0.0411603970133001, 0.053717984701506793, 0.0350046679523075, 0.008699307563801995, 0.09244830449461006, 0.0927344172669109, 0.04811387916561216, 0.07287623011507094, 0.01813624498026911, 0.02761795709375292, 0.017225672454515006, 0.020322081400081515, 0.0370207974629011, 0.03754911755095236, 0.04308328680053819, 0.0374037679284811, 0.06635143101448193, 0.04494769164011814, 0.039361776143778116, 0.006800133105571149, 0.10638577849022113, 0.0372892359882826, 0.03640144183009397, 0.015042216473375447, 0.027351848912076093, 0.0732951947429683, 0.041467345581622794, 0.03936708621040452, 0.02867183276975993, 0.027271669132460374, 0.01603887627425138, 0.08158912547514774, 0.046263671611086465, 0.02894984314480098, 0.04283493821276352, 0.08627523886389099, 0.044389266331563704, 0.07441531823133118, 0.03134690035949461, 0.06913022487424314, 0.007363192198681645, 0.07612970162881538, 0.0214361174221267, 0.026360792326158844, 0.046375951133086346, 0.011184536560904235, 0.06251932922168635, 0.008304994298669044, 0.01746247693517944, 0.035740281018661335, 0.10139020436326973, 0.08277291039121337, 0.033587236393941566, 0.05009752858313732, 0.02252703925478272, 0.0894854283251334, 0.08642064043669961, 0.06657751146121882, 0.07400251342914999, 0.0061178011401352705, 0.016662599446135573, 0.0914960473892279, 0.039390096499118954, 0.005072063113402692, 0.042405338608659804, 0.0568017121986486, 0.021117140495334752, 0.10029656070400961, 0.04028663315693848, 0.03112313170277048, 0.08940572166466154, 0.05586897357716225, 0.08003637442016043, 0.026617824041750282, 0.006488096651082742, 0.10835405060788617, 0.048006286306190304, 0.04370078335341532, 0.030292015362647362, 0.0067373413821769645, 0.09840115264523774, 0.014653615889983485, 0.03071583363635, 0.005380223237807513, 0.05984503717627376, 0.0724849921243731, 0.08871306039509363, 0.023122970851545688, 0.03562408295692876, 0.01994441914575873, 0.06685252912575379, 0.029295901040313765, 0.048299137779395096, 0.057715937946341, 0.0320174344960833, 0.053748190111946315, 0.01917529069032753, 0.02168164213799173, 0.04105505286133848, 0.007349395673372783, 0.05746089889726136, 0.026299824894522317, 0.054794562674942426, 0.07120551468688063, 0.03976737840275746, 0.04771953528688755, 0.027594204657361843, 0.0198804200408631, 0.05376476598030422, 0.03147630122839473, 0.005843844746777904, 0.03519657992001157, 0.014545029480359517, 0.042495895468164235, 0.007431002695739153, 0.025134790339507163, 0.06497615715488791, 0.04467717881198041, 0.03696351108374074, 0.045901358826085925, 0.04370630493212957, 0.03021300261025317, 0.02966161657241173, 0.09155102568911389, 0.05246972941677086, 0.052419170606299303, 0.024087514211714733, 0.02159085706807673, 0.012459964655135991, 0.01879812938568648, 0.026985541517206002, 0.036562083405442536, 0.028470230208768044, 0.02307697996002389, 0.033577547656022944, 0.08086012865533121, 0.0748300897248555, 0.010921669709205162, 0.05811857161461376, 0.004003570838904125, 0.006703624221700011, 0.05439916865725536, 0.08079314240603708, 0.03642174327978864, 0.0372129469178617, 0.02954296756797703, 0.028490257063822355, 0.05658904978190549, 0.0495757059979951, 0.0015637053866157657, 0.03082975330471527, 0.016218583623412997, 0.017324326145171653, 0.09742841226398014, 0.029494583250198048, 0.10099150036694482, 0.017643054452491924, 0.025339912535855547, 0.05679088797478471, 0.006551914857482188, 0.05339500574336853, 0.056487739202566445, 0.17058587924111634, 0.0198538177573937, 0.06141077581560239, 0.011576018532650778, 0.06683505154796876, 0.04604540597938467, 0.021612000855384395, 0.037002143581048585, 0.03867970903229434, 0.06557692569913343, 0.0387592375773238, 0.011982433443336049, 0.010160448837268632, 0.026021011144621298, 0.11016188524081372, 0.05366114361095242, 0.05291041299642529, 0.009031314748426666, 0.025374179349455517, 0.04584412439726293, 0.05797993471787777, 0.04754104505991563, 0.012733999901684001, 0.08055136553593911, 0.008369062052224763, 0.025089660339290276, 0.05395986547227949, 0.023649587710679043, 0.024456346764054615, 0.03435243146668654, 0.04871174962318037, 0.0076063420419814065, 0.04508981292019598, 0.03902549418853596, 0.05396763946919236, 0.04954129261022899, 0.018863160075852647, 0.018045979413727764, 0.034348902554484084, 0.03709126809553709, 0.048865774951991625, 0.017612474257475697, 0.03291960405476857, 0.04927634588966612, 0.040209924773080274, 0.06579571825568564, 0.012553099550132174, 0.019626924658950884, 0.009170883968181442, 0.002940866620519955, 0.01195373273731093, 0.030085971047810744, 0.08349113122676499, 0.0374949741672026, 0.009841406972554978, 0.12352285892120562, 0.02258095257275272, 0.012329669498285512, 0.03092251248745015, 0.020418260028236546, 0.07758450403343886, 0.0336163545580348, 0.07049408450257033, 0.04086829510924872, 0.08382558007724583, 0.031602009912603535, 0.03281417826656252, 0.025699195502966177, 0.07422505383146927, 0.058773008568095975, 0.03253504168242216, 0.015082701556821121, 0.09506801899988204, 0.0290460681571858, 0.03509097972710151, 0.03967180091422051, 0.05708120130293537, 0.018846691818907857, 0.037326447272789665, 0.04131194356887136, 0.03652947714726906, 0.030311123809951823, 0.013353726608329453, 0.008632426142867189, 0.016914181942411233, 0.023817040346330032, 0.06319000065559521, 0.04304273214074783, 0.03097868564509554, 0.06506102916318923, 0.012647589792322833, 0.05492990072525572, 0.05184862973692361, 0.05600738411885686, 0.0353648656164296, 0.036791035963688046, 0.029458021344908047, 0.0835071764595341, 0.04388344445032999, 0.012275866574782412, 0.06627795839449391, 0.03895098256180063, 0.022011263317835983, 0.009712922656035516, 0.02604655957838986, 0.05619260933599435, 0.03384842784726061, 0.030577796023862902, 0.02255689771118341, 0.04290325661713723, 0.043858489734702744, 0.04341144966019783, 0.05426179341156967, 0.042974584430339746, 0.05825923086376861, 0.040745625519775786, 0.035422667788225226, 0.0728341429203283, 0.03239910620322917, 0.03514716401696205, 0.050329323566984385, 0.022154495964059606, 0.061235762550495565, 0.06404948187991977, 0.022141070512589067, 0.048354134632973, 0.0701938931888435, 0.057629047296359204, 0.029179179764469154, 0.02585549922514474, 0.06095442549849395, 0.02265052891743835, 0.054208919100346975, 0.029254735964059364, 0.026824736669368576, 0.017157079455500934, 0.05431789606518578, 0.022198206606844906, 0.01850150594691513, 0.04129381290113088, 0.050844849029090255, 0.03713018260896206, 0.026019896067737136, 0.04581490975397173, 0.07324527046876028, 0.0894356302160304, 0.029273705258674454, 0.015638745499018114, 0.032701353266020305, 0.009008955694298493, 0.012294932348595466, 0.03229365815059282, 0.07270366593729705, 0.06934106902917847, 0.057483950004098006, 0.037979763583280146, 0.03104644187260419, 0.013382838278630516, 0.012323901155468775, 0.03078901496337494, 0.04331182746682316, 0.03859412456222344, 0.04592014629452024, 0.04676367505453527, 0.07718154753092676, 0.019797227141680196, 0.08594693499617279, 0.038197858521016315, 0.049479464287287556, 0.05610312116914429, 0.04654300857509952, 0.04061021696543321, 0.026369128499936778, 0.02047869496891508, 0.04534829924523365, 0.04613114258972928, 0.029835642781108618, 0.06237700014025904, 0.05330316867912188, 0.05627286518574692, 0.021837760323251132, 0.03458951054199133, 0.015579635291942395, 0.02048478985670954, 0.03414757644350175, 0.026115031978406478, 0.0036316711293693515, 0.05309574582497589, 0.08609966898802668, 0.13221773493569344, 0.18211121001513675, 0.13269932940602303, 0.14752622286323458, 0.1596223097294569, 0.13439273228868842, 0.18644585710717365, 0.182327872607857, 0.1586856896756217, 0.136079010553658, 0.12702952895779163, 0.1503927237354219, 0.11958088958635926, 0.1270197771373205, 0.11896947122295387, 0.07300119294086471, 0.08197189556085505, 0.08811108215013519, 0.1883887848816812, 0.12379755004076287, 0.13848011061782017, 0.12483496859204024, 0.1454574119998142, 0.13143579330062494, 0.1558625599136576, 0.11468900091131218, 0.18900070048402995, 0.08675603923620656, 0.09183215122902766, 0.09606677907868288, 0.12983024585992098, 0.19940282043535262, 0.13151573744835332, 0.18364855408435687, 0.11941934630158357, 0.054155488178366795, 0.11722171344445087, 0.12908268050523475, 0.2284452409367077, 0.16203759965719655, 0.2124356757849455, 0.09423532930668443, 0.28944961668457836, 0.13581976352725178, 0.09320732860942371, 0.11582893974264152, 0.17825704417191446, 0.17337461787974462, 0.11643977923085913, 0.12701673433184624, 0.14335651067085564, 0.29266097873914987, 0.1509996669483371, 0.0837040385522414, 0.1052971146418713, 0.15615260606864467, 0.2368301441310905, 0.23034801852190867, 0.14351953082950786, 0.18839007621863857, 0.11453130195150152, 0.1578797321417369, 0.1567937622894533, 0.19035926117794588, 0.09979949245462194, 0.08770067448494956, 0.13446881726849824, 0.12302959046792239, 0.19991850916994736, 0.11921808327315375, 0.1518254101392813, 0.18955189356347546, 0.17668464104644954, 0.16940586443524808, 0.15396266186144203, 0.1459613154293038, 0.2700394269777462, 0.12737952580209821, 0.11632370733423159, 0.14272333995904773, 0.12918696709675714, 0.1392823425703682, 0.12058310807333328, 0.13777751941233873, 0.16970106109511107, 0.13029876368818805, 0.1132554016658105, 0.17887647030875087, 0.06762739067198709, 0.17948607041034847, 0.09993097133701667, 0.21337421057978645, 0.20451158692594618, 0.1559816746157594, 0.12185852596303448, 0.1572693305206485, 0.25133902730885893, 0.12384024579660036, 0.10666499671060592, 0.27938900340814143, 0.06283106093178503, 0.22662380273686722, 0.08440340141532943, 0.12222826393553987, 0.20441160479094833, 0.08681608640472405, 0.08646390022477135, 0.20353083877125755, 0.07695479172980413, 0.13967811508337036, 0.17302977154031396, 0.16844819707330316, 0.09897991651087068, 0.18986589624546468, 0.2750393352471292, 0.07706440694164485, 0.08489244704833254, 0.13015493546845391, 0.1124283300305251, 0.22447482508141547, 0.11706707955454476, 0.1235486262885388, 0.10244773511658423, 0.09176550636766478, 0.15545667934929952, 0.12088470946764573, 0.12174405710538849, 0.1342935219872743, 0.12501545890700072, 0.17130586638813838, 0.10492742119822651, 0.11663658937322907, 0.1791185885667801, 0.15682303259382024, 0.13495010003680363, 0.19047512527322397, 0.14459675818216056, 0.0840708747273311, 0.11560133789316751, 0.12282155905268155, 0.15515569393755868, 0.1694951151148416, 0.16710492462152615, 0.16336672677425668, 0.05701272333681118, 0.1879437782918103, 0.12571721890708432, 0.1345334731740877, 0.10234067289275117, 0.1380130325560458, 0.1790738370618783, 0.12189358501927927, 0.07448024131008424, 0.1282120670657605, 0.12907735188491642, 0.12035724284942262, 0.256501198746264, 0.09041243014507927, 0.11155668500578031, 0.16973859892459586, 0.09641287964768708, 0.10842416129889898, 0.2125228484510444, 0.19942591607104987, 0.13821327884215862, 0.20464927016291767, 0.13960164418676868, 0.13381203141761944, 0.2039325633086264, 0.10488972751772963, 0.06990131631027907, 0.13180599140468985, 0.1450529563589953, 0.0803533308499027, 0.11398870294215158, 0.1824089596630074], [0.031693987984908745, 0.03572019479179289, 0.04147744250076357, 0.06737648538546637, 0.025162496567645576, 0.021858497784705833, 0.0035504699690136476, 0.03804630825470667, 0.06588502088561654, 0.005109938156238059, 0.026556962366157677, 0.033042240247596055, 0.033634800638537854, 0.040930064060376026, 0.05961055932857562, 0.03478999431536067, 0.02077090448437957, 0.06151189714728389, 0.016996456433844287, 0.008752348858251935, 0.05910206942644436, 0.017053583251254167, 0.04760948220791761, 0.02855274960893439, 0.049920248056878336, 0.033145109337056056, 0.015750943384773564, 0.0238312784495065, 0.03308600098534953, 0.004564048649626784, 0.028636356255447026, 0.07646341575309634, 0.04043350047140848, 0.017520817164040636, 0.023053834229358472, 0.03702353598782793, 0.022618401344516315, 0.07496118269045837, 0.01427126790076727, 0.03209310758393258, 0.060428717770264484, 0.05318455121596344, 0.01826195923058549, 0.01782730560080381, 0.023715195420663804, 0.06575406892807223, 0.06571975944098085, 0.026444740360602736, 0.06345601606881246, 0.03226953464036342, 0.033108673596871085, 0.0096598980599083, 0.02534775518142851, 0.05162446032045409, 0.00795515145000536, 0.016265383455902338, 0.05456495702674147, 0.04260798203176819, 0.02453064502333291, 0.10658053288352676, 0.04358950573077891, 0.05865040577191394, 0.017729867176967673, 0.030309242465591524, 0.051241816399851814, 0.08727205451577902, 0.06006934017932508, 0.07223158580018207, 0.033405079957447015, 0.03179665669449605, 0.0582866977492813, 0.02622756383061642, 0.06133417133241892, 0.01594234512594994, 0.03539453668054193, 0.04461974029254634, 0.05842377613589633, 0.08129922032821923, 0.032098209849209525, 0.03176613958203234, 0.0264250734471716, 0.06557741551660001, 0.027856921224156395, 0.02886219179345062, 0.01213417202961864, 0.028337007279333193, 0.04434024747752119, 0.04300931694160681, 0.015095050894160522, 0.04149792577663902, 0.01745234661939321, 0.029569527177955024, 0.022337910340866074, 0.036916455210302956, 0.0455185256578261, 0.0919324450660497, 0.03278612879512366, 0.04527621444140095, 0.05063800133939367, 0.052821752324234694, 0.00247038511588471, 0.060605122562265024, 0.050112649842048995, 0.043776634556706995, 0.020536951706162654, 0.030885970991221257, 0.00787889577622991, 0.05076758032373618, 0.009034411359607475, 0.017837669693108182, 0.05577035328315105, 0.06344279841869138, 0.023142363170336466, 0.028738603796227835, 0.09443788367207162, 0.05184513793210499, 0.019994942704215646, 0.044069278228562325, 0.02407487729215063, 0.01627320198167581, 0.051913389543187805, 0.027411239279899746, 0.056520801881561056, 0.021402065831352957, 0.02241517348011257, 0.02300791940797353, 0.024073079439403955, 0.08760000215261243, 0.039301517463172786, 0.032096180075313896, 0.07630323059856892, 0.015777443622937426, 0.06634594654315151, 0.009409556805621833, 0.030752716520510148, 0.03475945493846666, 0.02289142634253949, 0.01989006053918274, 0.01604409728315659, 0.028490440745372325, 0.04245651711244136, 0.08368656097445637, 0.07104995311237872, 0.017223189970536623, 0.043377036272431724, 0.07111207829439081, 0.028305243358772714, 0.04897324906778522, 0.01743001539580291, 0.020251495734555647, 0.03742956498172134, 0.09792245255084708, 0.012202598973090062, 0.008480549331579823, 0.023946238979988266, 0.041688943456392735, 0.02165056470403215, 0.038374597279471345, 0.013575344892160501, 0.04922174608509522, 0.05471291900903452, 0.007572304366476601, 0.02147985404008068, 0.03712785226525739, 0.03782708154176362, 0.02823856695613358, 0.023883744579507038, 0.060712860140483826, 0.039488145339419134, 0.03522390208672732, 0.04487733975111041, 0.04242067509039771, 0.03411566780414432, 0.037712571865995415, 0.01648001627472695, 0.021902716798649635, 0.02015160451264819, 0.052891859304509126, 0.004452283528735279, 0.06505034223664552, 0.02698453961784253, 0.04469224812055472, 0.012970098414371023, 0.009249072936654557, 0.02177388552809134, 0.019448614402790554, 0.03867430619720835, 0.07037251329165883, 0.03606721562391613, 0.009693971915112343, 0.019543579619494267, 0.07538483769167215, 0.028169131619506516, 0.03448387324169744, 0.04735729671665467, 0.02720232841966208, 0.04606431219144724, 0.03391159203602001, 0.027836875815410167, 0.0488884883816354, 0.06106974040449131, 0.056439655454596505, 0.08085423600277863, 0.02634543172462145, 0.028901601690449752, 0.039407232688972726, 0.05960773916740436, 0.01570827174873557, 0.07320297547266819, 0.03220625912945252, 0.061327339863055386, 0.03999289110652171, 0.012558026483020512, 0.013347471231099917, 0.06663685358944349, 0.05255722120637074, 0.09865274812909774, 0.0478206454863539, 0.02754673874733271, 0.012054516391799552, 0.024692284787306562, 0.07380212613497861, 0.04043660264869686, 0.017023067994159646, 0.03249804191000294, 0.0805777488858439, 0.07241454004542902, 0.027128072833875194, 0.05845158812007867, 0.018917663401225582, 0.038681928053847514, 0.00974124393906095, 0.060440792512963526, 0.030456749882432632, 0.04398001641675364, 0.08250875034718774, 0.03549958026269451, 0.01746671459841309, 0.05838735894940328, 0.02943712803244125, 0.04208536905935034, 0.03578871728677768, 0.028361748627503403, 0.03351430183101911, 0.05476839083712548, 0.053285650283214636, 0.08348044430022128, 0.07215409073978662, 0.008409256770391949, 0.02221213300799718, 0.034849303046939895, 0.015216356787277618, 0.011472468522697454, 0.016652545200486202, 0.03319072915473953, 0.06632943375734612, 0.062251413910416886, 0.02816815940605011, 0.024743966096139047, 0.05616196976916399, 0.042284019727958366, 0.051628664587042294, 0.03102235361438943, 0.022101658760220744, 0.023132273672672454, 0.05723967209632974, 0.03595018635678571, 0.030925353057682514, 0.017687043400655966, 0.03759071863896679, 0.03479960512777325, 0.06587010371731594, 0.02889564409997547, 0.04428365871717688, 0.033055320600396954, 0.029076047212583944, 0.03242616861825809, 0.03820796657237224, 0.02664697189175058, 0.03775235469220206, 0.018087361568177585, 0.045149158759159036, 0.046631134900962934, 0.03467102433205582, 0.08131377384415828, 0.08209720719605684, 0.050665620365180075, 0.011989509821432875, 0.05995509396598209, 0.0201146641120431, 0.06328072820906527, 0.04509227685048245, 0.02955469721200643, 0.011556159588508308, 0.020755419573106337, 0.05035401110944804, 0.06722623016685247, 0.013300934861035785, 0.06745601393049583, 0.040075955985230394, 0.06342614462482743, 0.07536042845458724, 0.007154866243581637, 0.02042308584350394, 0.053727213307865895, 0.023712198999419343, 0.0799966101476457, 0.03483264554233756, 0.06640730731305666, 0.019507746874296572, 0.030614489660365507, 0.029383997680270113, 0.013822415130562149, 0.05682775044988375, 0.028402247626218013, 0.03595737034629565, 0.04379728481580969, 0.02952306873339694, 0.009219221901730634, 0.029575245425803587, 0.0592120557121234, 0.05687000462785363, 0.006785573095839936, 0.03929455240722746, 0.03958866553148255, 0.032882255472941324, 0.028170161349407863, 0.04055675264680758, 0.028602377024071757, 0.058163015128229745, 0.01071876004061778, 0.020267891632101964, 0.025558040870237164, 0.06376639707013965, 0.038962337421253324, 0.046701928367838264, 0.05787243462691549, 0.04252778184309136, 0.018515833107812796, 0.05090298887807876, 0.08941171079641208, 0.03681238384160679, 0.011539503011590568, 0.02927051031292649, 0.062079632698441856, 0.059472857537912205, 0.01739999366691336, 0.0517419794050511, 0.023361456296697725, 0.05426519244792871, 0.026553310999588575, 0.06520393711980432, 0.10858352266950533, 0.14393483666935936, 0.14677571860374883, 0.16453921620268375, 0.15067062835441902, 0.1404179324163124, 0.09381402691360563, 0.13968044542707503, 0.16940843226620927, 0.1419061463093385, 0.11795726342825219, 0.23792052234057337, 0.08615121856564656, 0.15698899165727198, 0.2168502373388037, 0.14701755484566092, 0.14144908724119887, 0.20750925497850403, 0.13085642829537392, 0.14629862154833972, 0.17811404715757817, 0.1158672122983262, 0.10467929154401645, 0.12498178024543449, 0.1959328050725162, 0.1321907207602635, 0.16895101696718484, 0.12165691412519664, 0.16030021710321307, 0.13764799979981035, 0.14962595159886405, 0.16915058047743514, 0.11619371274719015, 0.07677027897443622, 0.11389809413230978, 0.22617962735239416, 0.17979824740905315, 0.16827759216539562, 0.14837697643088177, 0.1509104311116971, 0.1589093284565024, 0.12490888650063425, 0.1303385873325169, 0.1313640721491538, 0.14220307959476486, 0.20878606068436056, 0.13145137840183452, 0.06796704197768122, 0.16422735090600327, 0.11484133414342068, 0.1445218309527263, 0.13411594089120626, 0.05726613337174058, 0.08226987527450547, 0.08071074917097576, 0.0941547098045703, 0.23396765085635707, 0.15191412647254765, 0.14948773401556537, 0.19302014261484146, 0.12139018625020981, 0.1327536249300465, 0.12750321213388816, 0.1191330850997474, 0.10001015107263811, 0.12045185183524154, 0.19211828475818038, 0.1005955423170235, 0.1328265483607538, 0.23849323770264164, 0.25601227185688913, 0.14714187942445278, 0.12210804343339987, 0.1014821045100689, 0.1597932560252957, 0.11619491502642632, 0.11263966400292702, 0.126921531627886, 0.12048569376929663, 0.18627415382070467, 0.15914699382847175, 0.15724227181635797, 0.11010462854756042, 0.13800984132103622, 0.12718300509732217, 0.11065710554248653, 0.17610799230169505, 0.13619114906759933, 0.16622127906884998, 0.15662753605283797, 0.15740434202598408, 0.10538573449593969, 0.0872999221610371, 0.10407335765194148, 0.16097852523671463, 0.14755749696632847, 0.11509569041663781, 0.11769923352403566, 0.14151380251860246, 0.10183957478147931, 0.0851579726440832, 0.12370161261060275, 0.1444249806809239, 0.17137705319328234, 0.11559581631445326, 0.09833376563619822, 0.09776797451195307, 0.20337883208412677, 0.21982158883474767, 0.10803907571244054, 0.23635744058992714, 0.14291165251052007, 0.13051532238023356, 0.07157506712246686, 0.2183383918600157, 0.16709118004655465, 0.1336672532488592, 0.16745780099881813, 0.09804387533222325, 0.0987077561148908, 0.1230004834360443, 0.11229534458834678, 0.2555730688618496, 0.186046477756463, 0.1494553912198171, 0.15728745376691222, 0.12689212773693725, 0.10773712550872006, 0.17032830946845934, 0.11639351374469697, 0.20550933026243, 0.15258673491189256, 0.14729721093317494, 0.07044889513053931, 0.09186473151203245, 0.17081520287320018, 0.07877962896600366, 0.12154799653217196, 0.10708344183512963, 0.11751627927878872, 0.0837277204846032, 0.11513510587974451, 0.13106550613883883, 0.11553683041711338, 0.12300252434215508, 0.13552958378568292, 0.12876559048891068, 0.19560906541300938, 0.12508912448538467, 0.20013806613860652, 0.10054025973659009, 0.12051878613419831, 0.06651465155300684, 0.15318086865590885, 0.11229299198021181, 0.08794382432824932, 0.13083486148389056, 0.16591889841947705, 0.15030816342914477, 0.18078758963383734, 0.1869834095123224, 0.15259682812029496, 0.14726673834957182, 0.20184371445793658, 0.23972315451828763, 0.0763843473396264, 0.13350714230909944, 0.11224769870750606, 0.12445299260434695, 0.1627666558488272, 0.14673357945866883, 0.1341824373230338, 0.1541915105190128, 0.15327262779464945, 0.11839285958558321, 0.09408160083694384], [0.05964459793176502, 0.06698017110466026, 0.036758077185368165, 0.05211278978094924, 0.025706420310598332, 0.020634263964893762, 0.07183257010183297, 0.030378124902199488, 0.06295197163126431, 0.03366768520209007, 0.059318360945326276, 0.10215555899776518, 0.031061963891261257, 0.03710795157530811, 0.033076494073611684, 0.1347269510733895, 0.03834080729575362, 0.024097650093608536, 0.05010422275518067, 0.06087955764087383, 0.018048298625217285, 0.031861338575254194, 0.01582683911692584, 0.04335381447162945, 0.008362463431694778, 0.03643663818365894, 0.011461802932899445, 0.0414770157658495, 0.028463044363888912, 0.028828665272158105, 0.04156334980507381, 0.06523409800138324, 0.049966814112849534, 0.04681641948991455, 0.05000923898478504, 0.024061845178948715, 0.033805665298132226, 0.04948380956193432, 0.04212240222841501, 0.024792710355541203, 0.03528334440488834, 0.03641759838501457, 0.049003517560777254, 0.0787879187555518, 0.01811954480217537, 0.1025205769110471, 0.0260664250163245, 0.012657920487981755, 0.016605121963948477, 0.04526923454250209, 0.05891045802854933, 0.05462721579533536, 0.03631969426351134, 0.007649581884834333, 0.044645451998803765, 0.08583671864471398, 0.05372493862523697, 0.013809283755108481, 0.007077168020259705, 0.006114815387263661, 0.049431929728598334, 0.03655458400317002, 0.02661980557604693, 0.03894310095347464, 0.05476837970491033, 0.017244190894416533, 0.03965468698879704, 0.04659734862798359, 0.045738906410406344, 0.03617448564909864, 0.07655209497897886, 0.03234369374695234, 0.03021234766492853, 0.04208205165923573, 0.05091154213005211, 0.0411503038048977, 0.0291783949433011, 0.01843082565756049, 0.03776151279453188, 0.018197700374003034, 0.0475086948426906, 0.020005898659292143, 0.021178013303142507, 0.01750645475112833, 0.08335756690939888, 0.03097403794527054, 0.023919660816318356, 0.03247193686547689, 0.06488281724159606, 0.08355124518857338, 0.09881875914288685, 0.059339990839362144, 0.041590746186557226, 0.017471655446570367, 0.08059218365815468, 0.029171895585022867, 0.17508773220470175, 0.013757535652985098, 0.03086233544308925, 0.0131508327103802, 0.03324797471577767, 0.03680207169963978, 0.030449090918409638, 0.03262370977608953, 0.04496602268773131, 0.023954664211487398, 0.008261447856057202, 0.05243928280833643, 0.002639832273416687, 0.0671932936529629, 0.0579353539069416, 0.038699349970556796, 0.013114548182784347, 0.04061344901856501, 0.023538278546766378, 0.019368868779565673, 0.05407072007074021, 0.022371835766534787, 0.021444284757308196, 0.019082436883763876, 0.03735378799319733, 0.02398745415121084, 0.023640802537556738, 0.023466700258722994, 0.13003064057556912, 0.08288335680845194, 0.048547415863140486, 0.048418256192235276, 0.037182222004048526, 0.07519330421928316, 0.06808854639530182, 0.022140181790746283, 0.009992260547733167, 0.03579606825951487, 0.032816237726365216, 0.014429957627726253, 0.06759444673662074, 0.020970438308722805, 0.0193387635590625, 0.043769795665866695, 0.018753472504613455, 0.029071252938592806, 0.055160797710414045, 0.04729215470433701, 0.02793795632896945, 0.033856869777082466, 0.023189480270957574, 0.02702148187381681, 0.07141842943383381, 0.01208586007123813, 0.06663496853434481, 0.08806637517409399, 0.03828001797955949, 0.027303765164106153, 0.019621288047346752, 0.021947321729385294, 0.020304716999817174, 0.05239326594164595, 0.03374423773493618, 0.024905618847697042, 0.058038883507833816, 0.030082503362791613, 0.06348838855046779, 0.01232036574947415, 0.03950104015530087, 0.012388729610393057, 0.016335564650944434, 0.04697794051025994, 0.09615850111003965, 0.013648492822539993, 0.0019218047441427188, 0.012738989917124854, 0.04195414992864244, 0.03155757010972593, 0.07437352789565921, 0.06098282377934083, 0.07935377667308785, 0.05367907018808182, 0.03343821685120929, 0.05751069700636435, 0.03230535439797677, 0.04384378778922837, 0.09536717130686156, 0.026389962440589443, 0.015363651764346287, 0.04261488029442262, 0.01741788313665893, 0.05972208185994532, 0.08045200680498965, 0.15459525369806215, 0.054227669461397454, 0.08630660944618285, 0.02837434472894529, 0.03340242306876462, 0.050175016222056, 0.016604387237748597, 0.04243504678015597, 0.03820602214545943, 0.019153139437548816, 0.0450147149967961, 0.0259775658196304, 0.02270249038701877, 0.016080436544143595, 0.06940280087292194, 0.01384753682941664, 0.06978442805120721, 0.008723833689145977, 0.028874209019704722, 0.0894902522850316, 0.011427596418798203, 0.05089624275569804, 0.03771793388295919, 0.05668110206897836, 0.036197039516991936, 0.05904460864257999, 0.0543233137432253, 0.031012280815048143, 0.03827119384368416, 0.03387073680642061, 0.014744239542778814, 0.04865019960561767, 0.07649800725630485, 0.027288608653179836, 0.04693988688813988, 0.11203522924915887, 0.03711539531650487, 0.05612113680399489, 0.02202058840339305, 0.009310120149166323, 0.03388799916137941, 0.039474972218158655, 0.08509794031851925, 0.006563787828781642, 0.01706799946987303, 0.0354429247090593, 0.020132119425397832, 0.023638149359612726, 0.04590568925777916, 0.029113789132679813, 0.10956686091958545, 0.024292128036904614, 0.025359852188557852, 0.024489279567205813, 0.09687934172688983, 0.08263046998763457, 0.01873623055871576, 0.03741524153156206, 0.041367701123817824, 0.01799682511773426, 0.07775205871439539, 0.034124562444048934, 0.031809859501663595, 0.03113063852651976, 0.011364234633219894, 0.05881191566004418, 0.02217925401055254, 0.037947880919091403, 0.025728376749611925, 0.047435185115318745, 0.06402156970580108, 0.03384793431905564, 0.023656255907553714, 0.013889794718124904, 0.046411525981966406, 0.05729010845243465, 0.06119167526776437, 0.0287448304152349, 0.023855695108068176, 0.030447775461652782, 0.07304460115847178, 0.016506635256519075, 0.018306866586499382, 0.04703943857748527, 0.059936673860647716, 0.054858446746948175, 0.036006426307721995, 0.040090750699164346, 0.025966852917918004, 0.013112016531522386, 0.03357149915245827, 0.025143649727397133, 0.03207986395864282, 0.01858612748037558, 0.02822194655891508, 0.0158304107026197, 0.006993847564444877, 0.09635832437197678, 0.06531145205372013, 0.029592021674034186, 0.04531483951723203, 0.060858840588480234, 0.038038289349060506, 0.03656405009678565, 0.05476843907672446, 0.027361892025510315, 0.06020134227583185, 0.04929484763124492, 0.05435489954834338, 0.05921650859818328, 0.030901472600817215, 0.06476368027506396, 0.08050162679865025, 0.021382295017247088, 0.033067510375985876, 0.07247252404340543, 0.07653649503481574, 0.015447089572262485, 0.03569772627088241, 0.04835315499803983, 0.03886944650730584, 0.051258767052786425, 0.06967614870518446, 0.025125691608991474, 0.05667906858434435, 0.05337277099897619, 0.0542533551924862, 0.01949693563801702, 0.07299471399164759, 0.057805511460173875, 0.04089913876669016, 0.025763528574316297, 0.025203739569406025, 0.023082321567926556, 0.03012956294696778, 0.02918695561675122, 0.00382531253308116, 0.1473238243488595, 0.04800397080543917, 0.03251849178923294, 0.06266067124670371, 0.038213625448406674, 0.051344537059776485, 0.07385268123471178, 0.034934097129735164, 0.016133147582877427, 0.0030167254772095475, 0.028848825713794213, 0.06527626683237031, 0.02917359881394077, 0.08012006641365588, 0.01627239675144665, 0.011181602294527693, 0.0570062332553789, 0.07371312036411837, 0.07622117132996209, 0.06556032385560684, 0.015440034530911362, 0.03490255956421606, 0.08683538966579363, 0.027315724873915315, 0.07143424460082315, 0.04255443978763651, 0.14612574566854164, 0.10682023174013011, 0.21151045511942357, 0.13821474829455838, 0.1531656546285376, 0.14243770216125995, 0.19877851096680388, 0.09776570354006253, 0.11609090302954428, 0.17662043042946607, 0.10069752825074829, 0.12126332352636382, 0.2004538945038803, 0.19523822906194255, 0.16652483231155202, 0.23037485458189622, 0.13105750578688458, 0.1334353766287677, 0.14929961442248896, 0.17701593576930463, 0.09893917260342278, 0.11624210819718428, 0.07596414332510903, 0.22770956478780136, 0.1709510901127942, 0.08049144453252666, 0.29191995912697166, 0.15112123073777184, 0.07326755716348998, 0.16834429639857262, 0.11381473610526882, 0.13659561955137178, 0.24660065188072622, 0.19920727936550975, 0.15261881053447723, 0.1662660899455659, 0.11135316584841348, 0.1337187286117114, 0.1295551168732345, 0.1676449112710543, 0.14817203977145255, 0.07291263988008723, 0.08891018223948777, 0.13062611018540338, 0.13484799535945058, 0.1612469452084042, 0.15454950771527365, 0.1671239236020483, 0.18195532931713387, 0.18080409499816597, 0.12810087850084528, 0.194420441694092, 0.09511942756944336, 0.07864450613851659, 0.22377336194040254, 0.1937583420658484, 0.14359196444274858, 0.10622949703247286, 0.07102022267645225, 0.12180708028608933, 0.1390229322714731, 0.30320416612084955, 0.058376360320835374, 0.2677218778990209, 0.09762332992977463, 0.14817770977970213, 0.08300064582726918, 0.16875727189471945, 0.19834566075587645, 0.17458278976846486, 0.20467773894779384, 0.14831760461675003, 0.1522365302662365, 0.1293722665286623, 0.07539395126514137, 0.1372098654974252, 0.17766625009244308, 0.05887884624826256, 0.17154666362330317, 0.06374739808961749, 0.10921649300144054, 0.10571103266556747, 0.15628559893229976, 0.14643703209003434, 0.11753616883652285, 0.10065602735267021, 0.13554349163314328, 0.10889341385336593, 0.1780213083839044, 0.19754028209717944, 0.23660972627112642, 0.11955115172895603, 0.098305044521112, 0.11772902333177626, 0.1266773056704551, 0.12302678514970466, 0.1381678890902549, 0.10254099339363165, 0.12969701550900936, 0.12523896410129964, 0.1515403066878207, 0.1246617958531715, 0.14957695500925183, 0.16339984140358865, 0.09069219013326801, 0.15482488903217018, 0.10233926281216554, 0.12437726385542192, 0.14153971831547096, 0.11888675144291483, 0.12293425417738035, 0.11833305732579902, 0.17257425613934174, 0.20441500382730737, 0.13123602198902518, 0.15282221836969256, 0.18442310392856598, 0.12833913759095594, 0.09873535658698529, 0.1888401442556642, 0.16388032265240327, 0.12601535447174683, 0.08545967793907039, 0.1411279896274209, 0.22755724639864638, 0.16342590562999249, 0.12162119455751963, 0.14017398847499862, 0.11009155932697468, 0.15614986012224108, 0.13789045944577083, 0.1575137345935218, 0.09408305544639006, 0.11469996985397302, 0.08735533090657555, 0.17142993863672018, 0.11403095340938307, 0.12959295156178996, 0.12133996511693113, 0.09859224082902074, 0.16975161619484425, 0.150291821337305, 0.13554046367062256, 0.13871829549316317, 0.2262191689806059, 0.1825681800255552, 0.19121203338727355, 0.10564438038272783, 0.12458321725716814, 0.1387243514182046, 0.22017036855686456, 0.22594153153477237, 0.1543731734273024, 0.16713716351659968, 0.09167212192551233, 0.11649077961919829, 0.09362764394609258, 0.10641618428053334, 0.10735906063928269, 0.14812400797381997, 0.2283497859025374, 0.15409951389301568, 0.10253910833853297, 0.17541935347253457, 0.09811531446757726, 0.15368996711913496, 0.11573040479561314, 0.2327536605298519, 0.2032535130274482, 0.13846410991391167, 0.24047802260611206, 0.0922979527967982, 0.12427657668013126, 0.1551351067610085, 0.19673248403705657, 0.0961767505214084], [0.02314972156455042, 0.04760838382935617, 0.029758878736174665, 0.009540010596538195, 0.03484234541247133, 0.05573117530730087, 0.034612008748808876, 0.051527483883546665, 0.01171292622530018, 0.02048315898719011, 0.05778470906079747, 0.05469146723044105, 0.053870971023570746, 0.037367532568168826, 0.011840831666631857, 0.05476807171362452, 0.06057246806449257, 0.00063753935251043, 0.02992436468048254, 0.012725491178571247, 0.00866756683535641, 0.10724908919655718, 0.009823814361880068, 0.023579710796184372, 0.009316390369349392, 0.04504105010710191, 0.028530114104796667, 0.026841238322958816, 0.024312874775205273, 0.03578809759346768, 0.05871449764526915, 0.031028352022985928, 0.03684078954393044, 0.04362893974757753, 0.06248803285416216, 0.016717950675229076, 0.025748847037903033, 0.018399584951112047, 0.07814196083927527, 0.02601532072731061, 0.045400865565170534, 0.03642442243290134, 0.04735282898764126, 0.03875113332469482, 0.020789985101146158, 0.017319715552730486, 0.02579728145065019, 0.015535047987214057, 0.06437490621465258, 0.03777696801989805, 0.025631873431848362, 0.017936579424713273, 0.05153414465894457, 0.04086330045538489, 0.009969446000468452, 0.03503599400573876, 0.009319935052189976, 0.08314134960528463, 0.05731100733100902, 0.016207609114644583, 0.03853015885397326, 0.01748142396536423, 0.04247691133059561, 0.011760590659832815, 0.008179917367669987, 0.003634351905930089, 0.00883176144270692, 0.029208537271188106, 0.03505758308165241, 0.031342451184173115, 0.10346185023081489, 0.03729356641997583, 0.013050385805399856, 0.02951241891423706, 0.04752258042572066, 0.04412570000567939, 0.005849196095368825, 0.026866758926189505, 0.06408271525288001, 0.06720591758494265, 0.10968487724312581, 0.04923647400573827, 0.05864531463885214, 0.006571911098944838, 0.025015425162564497, 0.008901021446945379, 0.014148095506243408, 0.05874740447325166, 0.03073760453844443, 0.02949741083284607, 0.03531482630933169, 0.030602160732087214, 0.04783000396855641, 0.07678036476136185, 0.055859934218460694, 0.05363171745557338, 0.009740492514538346, 0.045307384643820114, 0.021184664801694453, 0.013062786165392026, 0.022240985854296014, 0.07180111046181992, 0.02468435122864321, 0.0460282252606703, 0.020821492980758194, 0.04310961077862885, 0.1425495438161306, 0.05599024050752632, 0.016814871451060753, 0.08053296769503504, 0.007210290295915911, 0.02073656902211951, 0.05853422997461166, 0.05845285348186735, 0.031768065455253236, 0.06520030059618875, 0.0293696593871573, 0.052200904974597506, 0.036484610609477386, 0.004775988863912062, 0.05492088363098446, 0.07568275803350843, 0.06876595653011464, 0.05861741359694861, 0.007870004847063683, 0.07365896584815346, 0.07029145592241548, 0.035421417269390076, 0.02936074619356077, 0.07906920756795444, 0.04308264484279789, 0.01766080291417893, 0.05095621199870948, 0.057792601801338606, 0.07203389992355369, 0.02793301362544298, 0.03603462420869619, 0.0525222178112017, 0.15249966614646837, 0.01045405359036522, 0.05103442323161289, 0.04099886486073956, 0.06937629135791212, 0.05257653188891709, 0.023477982758777216, 0.05933979045948945, 0.05247263492492493, 0.032055209812824614, 0.029129055110388435, 0.024381480761803687, 0.09361726130009629, 0.027165922365384176, 0.025853716215351596, 0.037283643905539066, 0.020971783451386727, 0.024127898177539464, 0.06107110224547796, 0.03725507121998817, 0.04198789167276118, 0.018548135085438844, 0.062019303513807245, 0.016821060962683987, 0.056588084989925846, 0.020362118411867414, 0.004844456161663402, 0.043319130199961364, 0.04716371120593976, 0.030181555957824457, 0.010485183902346762, 0.01643781033635605, 0.09244432658306323, 0.018813068818417378, 0.052598562542698346, 0.025162266501865815, 0.04694204653787892, 0.012368056159175467, 0.015093169549800223, 0.035371348276385106, 0.03132383440970443, 0.047836516314418986, 0.011154216117574833, 0.02185291683417745, 0.03994140832219273, 0.04750964850245509, 0.024490736032021232, 0.013435631881293375, 0.006085113245717366, 0.010122341409442015, 0.039896007438073866, 0.0348713893617969, 0.059164869962842204, 0.024169669959519524, 0.02773333322693361, 0.007816338293196168, 0.025614230726205278, 0.056087947959895246, 0.022261723315750714, 0.04499895920162089, 0.018211289097962435, 0.03786531699006446, 0.0737776055757422, 0.039503578300355, 0.04906359812594019, 0.05777140235295519, 0.0315388308808906, 0.03218373494746629, 0.04115850824746303, 0.04741999706311617, 0.0787991177639924, 0.027135624186485074, 0.014380204975168454, 0.03348970705701504, 0.041003807564266026, 0.024837172422849108, 0.05937494970567059, 0.06265727963182144, 0.046883936374797486, 0.016861749209056143, 0.013986130124976626, 0.018033411142823752, 0.017473260340921115, 0.01188233070934075, 0.041184550209436566, 0.020899555784126278, 0.02469314382324228, 0.04395355885208119, 0.06088140929932706, 0.0857020856346935, 0.018296840171387885, 0.043287125081405975, 0.02634863594721537, 0.09492045777733438, 0.014552056691172766, 0.05161951019545086, 0.03498251113342121, 0.04821419897780288, 0.050550494706840254, 0.02768524020211771, 0.01151385624325485, 0.07450876204529777, 0.05814862117404118, 0.039928205515025184, 0.029246340418467298, 0.05975219821266364, 0.019705636841536034, 0.04143900667259004, 0.08852518571075052, 0.06384949534549378, 0.014021311635588063, 0.03593554749386385, 0.01695171606115764, 0.047489625358139165, 0.033337477725581266, 0.05751190670707729, 0.04590944081428461, 0.03293362693511881, 0.039110514626372606, 0.01259385180674144, 0.07682869341806509, 0.003952531487811939, 0.033816782670328394, 0.01478651227444061, 0.03181977088388521, 0.017198572932102252, 0.0040615965826873435, 0.08155678267939948, 0.02077558743621921, 0.032880927028600127, 0.03706953801156487, 0.04452386223420035, 0.054440213134512305, 0.04082594816281926, 0.03994848098955117, 0.003792032312048832, 0.016869231913005933, 0.04994127310055774, 0.022135389372124337, 0.013592328941740561, 0.03131584518996533, 0.026945664067170583, 0.008137477652780944, 0.0481867729104124, 0.04558763816021383, 0.013828125956933945, 0.0324256565363612, 0.050327097123954445, 0.029607903634314425, 0.04258431865309831, 0.07543088795500807, 0.0381673191441223, 0.07989565579919145, 0.04519249647273682, 0.02839004300767556, 0.05965598247712478, 0.038520993330166675, 0.047671804059064016, 0.05931698797212448, 0.0033739137325028423, 0.04232956162013579, 0.02316275924385991, 0.01216699814904132, 0.042914036312140524, 0.03960319307225291, 0.01146682820035494, 0.06958098310860805, 0.07873294787714258, 0.004627960088328109, 0.09514814126305282, 0.03377441345946863, 0.041709174402058125, 0.03197407080733683, 0.031192611568258144, 0.026598878866934683, 0.05944737589743454, 0.025194579611707013, 0.046881698799552396, 0.050012582360068336, 0.04743919271277264, 0.050265632453374565, 0.05206184505368583, 0.012043170809192816, 0.055692238529445603, 0.04819672882149462, 0.02487858055246761, 0.026412683291709982, 0.07156966428738087, 0.08694153162650764, 0.04362162588222418, 0.018457374135323334, 0.08336748942383565, 0.11317559110466391, 0.02207651108619757, 0.03691214704304002, 0.023394197996822186, 0.027861294329341035, 0.03781119216000661, 0.02334851695195539, 0.04545446347037796, 0.005299203903632588, 0.03453090313996654, 0.028524056324386038, 0.02805832711601397, 0.021360822829592507, 0.024513599746569525, 0.012457425582397263, 0.0680138343886938, 0.014916408526914893, 0.02981323177664308, 0.017635113472351804, 0.028024833991366904, 0.09657979608164169, 0.029523039047489874, 0.086168428970268, 0.10847775178262964, 0.11697858586558141, 0.10495439826627262, 0.09078320712433197, 0.11333878195728175, 0.23887885763542727, 0.15280084451660514, 0.1568609118112363, 0.08403911080677062, 0.0814355825423263, 0.10175403484026901, 0.11892769573023543, 0.09466840216191486, 0.07757128638331778, 0.1150773667905014, 0.09795089164981619, 0.10207033075857908, 0.11888848806847818, 0.0839520939916838, 0.07161921006627381, 0.15593042189721018, 0.14814287336776033, 0.08271886719739996, 0.13042377104284242, 0.1447453213040717, 0.09261715051252395, 0.0991169095505029, 0.11604520157561637, 0.1706363749690354, 0.1252108218614012, 0.13070660352241248, 0.1463863582466729, 0.13485807372489944, 0.12826131598558277, 0.12536205671494827, 0.16740819584811106, 0.11430827915319242, 0.15266439324477687, 0.1951238641049713, 0.14215941162547097, 0.10299429719452746, 0.16376583895180374, 0.11572149902349338, 0.09663366116001271, 0.11449499608715996, 0.1581253978656605, 0.12051173573127016, 0.2937018853845075, 0.13732409686781466, 0.17246572446310893, 0.1749988822848536, 0.09352141292765737, 0.12431726121576503, 0.1204397993569728, 0.14220628567272797, 0.06392763607436791, 0.16936709464062005, 0.12240400450536981, 0.16312212974298745, 0.11689378807204776, 0.11064751699450426, 0.08173005189746618, 0.15363389044068754, 0.1725744194118306, 0.10995957578415982, 0.13334755087271333, 0.11996891407761723, 0.14434536307817325, 0.19661623402498662, 0.26738028216641396, 0.19799416477326304, 0.10981493862345815, 0.14796788978856057, 0.1149496431753505, 0.1276772457640618, 0.1085535844322294, 0.12011858299956657, 0.10307133954484016, 0.21794591448269784, 0.1456814812263474, 0.1708879481884651, 0.1334243334713392, 0.09447848657146096, 0.1567314367275685, 0.10513795365113765, 0.22126120689790696, 0.10271038860082626, 0.12382546963635832, 0.16720913699828088, 0.12747558939736336, 0.23264671704964712, 0.20419167674845085, 0.2073556897812523, 0.13192694663302973, 0.11761156361899339, 0.08735703784623183, 0.06145042134448886, 0.09004124498460442, 0.11804842884885147, 0.09303524682763964, 0.1599400825216435, 0.18011395703069866, 0.12264350298210047, 0.15534308622591197, 0.09497118357103318, 0.2694919001078233, 0.10422980980365537, 0.16295869398163632, 0.18361650814767927, 0.1104043894156348, 0.14617762179113925, 0.24961368239019066, 0.15610148693667725, 0.18267114559421316, 0.11822546817711554, 0.1287432518438436, 0.0937419272668194, 0.12038539251079783, 0.10819567629368976, 0.1749457890400663, 0.16811620473163202, 0.1152968050155323, 0.1745268318336457, 0.10955593650578521, 0.14870502054691315, 0.09729554556543007, 0.10965114663122222, 0.13174768828321248, 0.20005160593427718, 0.25217703077942133, 0.1799342385493219, 0.23667787027079612, 0.1442538117407821, 0.07379777714959346, 0.14106726710451767, 0.09730767225846648, 0.22965308628045022, 0.2568119211355224, 0.14980758482124656, 0.147966509393882, 0.14312788465758786, 0.17881426349049434, 0.20667910343036056, 0.0629807669611182, 0.0916770423646085, 0.0991551746847108, 0.1928735536057502, 0.196418555569835, 0.11792031189543195, 0.21744299068814144, 0.16188960056751966, 0.09073827008251101, 0.21129480184754357, 0.21374764444772154, 0.08945139343268238, 0.14292665873654187, 0.08355966856470332, 0.07121920731151477, 0.12803933961549774, 0.14706442889291793, 0.09881989462883212, 0.20422584522748366, 0.12723036896204576, 0.13567917107138783, 0.12921703892061487, 0.20640661648940295, 0.08610897551989183, 0.09687359750387259, 0.19952790200477466, 0.13924940605647862, 0.12279272661544383, 0.184295573271811, 0.12011044163955376, 0.18427369475830346, 0.09267412518966012], [0.1442975242389366, 0.03259659912146162, 0.027517091803019866, 0.0273679590827669, 0.04824313902645372, 0.0516210946807405, 0.03291798617283348, 0.018252448608109262, 0.03605949357734062, 0.04454628251551185, 0.03851008375931997, 0.08515740119037218, 0.050005546800093725, 0.010302977370884037, 0.02737792983680265, 0.13175273488741368, 0.02826632327924017, 0.031405752670252696, 0.05929379214649089, 0.008919735628296621, 0.03191350042470731, 0.061302036338020116, 0.0011141102368128486, 0.06609962772927247, 0.043969425969407894, 0.011619936976785539, 0.056582919642096385, 0.04894949663139414, 0.06993319897446781, 0.016056639578891918, 0.039284692975343205, 0.06808617894421332, 0.036238328902982175, 0.060489369789138436, 0.019119494172628038, 0.06282368398387916, 0.021824856230523437, 0.017127449209510814, 0.05715614708606154, 0.05359662500268314, 0.03133494064968545, 0.047965698249754496, 0.006681619543087436, 0.0728047093434725, 0.03726463379280176, 0.06003756512654945, 0.0429693931073416, 0.037174117751419544, 0.0346898637508275, 0.02980898669193266, 0.03130553675873671, 0.037141251741559245, 0.020301056356402114, 0.040791493956930935, 0.04176385213213507, 0.04348859962192364, 0.021791654398839455, 0.017855642654467374, 0.025919310937752016, 0.04140127588470932, 0.06553276049089618, 0.0337092194968136, 0.028941814962308854, 0.01993019959627418, 0.08458142780000344, 0.01735653535433812, 0.030190652832970954, 0.07151596990297548, 0.09208792500430718, 0.03347911289893091, 0.0503833890252281, 0.0045471304656530265, 0.05328367245965637, 0.1164881227305159, 0.013019511534366757, 0.005030164702475304, 0.06085879234888125, 0.05441848676127847, 0.010746977422968484, 0.009396278856002027, 0.01896994584967615, 0.02553736834670417, 0.04065944733156357, 0.06573381571797654, 0.04348536385805346, 0.031031619328132365, 0.05502009022166021, 0.0745101721258834, 0.04736629154649563, 0.047983313124859706, 0.03226160479243845, 0.042589135191519745, 0.0050024635766021674, 0.005380557204262004, 0.014175116175465519, 0.03214943288185168, 0.016715841120458208, 0.11473099904833362, 0.01392864151057438, 0.034647639258764684, 0.041735156992217526, 0.04470060841413215, 0.015811940502317157, 0.019230231882829685, 0.04098396995686926, 0.06959747362998314, 0.006967104736759211, 0.06010107812471688, 0.06550423975568265, 0.026834160089492798, 0.09482311026658863, 0.005687273851435748, 0.07890188295277767, 0.008543756193830632, 0.031418202197528444, 0.04593472578562796, 0.022943731055420358, 0.02949201727460604, 0.06757830502465367, 0.07259799895109609, 0.04801752613275312, 0.07424722920404747, 0.060040481766918674, 0.06449908236390911, 0.03449860858381726, 0.0201807059784187, 0.06660282611846924, 0.027836460212711245, 0.015222753172565717, 0.047895591269480065, 0.034141249634558335, 0.05364329867006745, 0.01142437920861994, 0.045728453260380775, 0.030694049746671226, 0.06215565459569916, 0.066848454735009, 0.042959092097589746, 0.016044026779127307, 0.014225380909920204, 0.02592299755633576, 0.06261941525735892, 0.04563562913972419, 0.10022575981565751, 0.0037209658739811857, 0.050076455299858935, 0.07342630255152471, 0.072818231274141, 0.06866152150905691, 0.01381196198053658, 0.035198123587179, 0.0803335451928433, 0.027707083463610616, 0.017420990880054887, 0.02429779062367743, 0.0339343685482163, 0.042502114665694535, 0.03767770205740817, 0.03000663360580802, 0.033209717003046535, 0.07712158199865371, 0.022042012351448648, 0.03496706332953181, 0.04534871855867095, 0.06071895688364748, 0.016429908318968955, 0.03954570631321985, 0.01227051105161081, 0.09582931408658624, 0.04305149690480903, 0.08493268629536033, 0.013501414923666744, 0.04638496451661922, 0.03119980297924485, 0.055609670889680274, 0.06652807700447738, 0.07826667133485898, 0.10982802268699743, 0.04424679253133945, 0.004269647015462397, 0.060362573858583346, 0.07400425005471334, 0.008109896662062965, 0.03640101138444152, 0.02229118843388278, 0.05309522261086386, 0.007949188293423504, 0.047266342808143236, 0.03765734865737613, 0.03345570556120947, 0.05571503359533381, 0.023619159655936528, 0.02561705459811492, 0.07009532855590805, 0.03859522294078488, 0.020483817643253133, 0.039508480185759254, 0.08160007215337828, 0.036120405347901396, 0.06179339747177437, 0.034361652651568875, 0.04515828717558179, 0.04758220457006246, 0.023986552441783715, 0.04255841769918334, 0.019750098908843938, 0.024282179547299165, 0.09817803336773068, 0.06742904428392649, 0.014810553220740985, 0.034164040989708155, 0.036836915533058345, 0.014434001404879382, 0.051137975096935406, 0.019657451048260555, 0.017644284562265966, 0.0650498153117951, 0.07141487454646267, 0.044603257192648016, 0.05379233305575326, 0.05428974640381057, 0.07686849479796365, 0.034687414663494565, 0.054152916636667214, 0.0427582335396437, 0.0173554777938989, 0.0582092806143919, 0.04610489653714467, 0.05421339054009877, 0.006174593063406064, 0.12603059818502516, 0.033221788035007194, 0.04434419570316095, 0.04982481157639995, 0.014922078535164474, 0.07156808351282962, 0.03951628757931758, 0.05831132591993082, 0.033871215491672046, 0.09720085494336672, 0.052377272659214213, 0.040796347602736205, 0.013026020169490948, 0.06289573910180479, 0.08687502777320333, 0.025240527829737402, 0.04607255745213479, 0.034443749027559534, 0.06219183800567407, 0.039273861330002546, 0.02787959383567795, 0.052016867193742655, 0.0753148234798573, 0.0917152852343861, 0.04464001576707233, 0.01007389122605673, 0.02446942526148632, 0.030789766387897544, 0.014918828856025357, 0.11320300603983924, 0.00462100384538644, 0.016282421311188955, 0.06660444400040433, 0.050705384637694806, 0.03558051146683283, 0.01799701993149938, 0.030107983147900086, 0.037861331657040864, 0.05283577149384655, 0.046641580629511736, 0.022465029105660506, 0.0348843138635857, 0.02076889326417586, 0.06488142200396396, 0.02507890105334809, 0.010232611566607375, 0.02089998251904035, 0.01739036615617806, 0.05003886552003678, 0.039621806135983206, 0.08741502926568501, 0.01586439921084093, 0.033405699650757015, 0.045140976581024006, 0.13014436728553846, 0.05032278524595313, 0.011622271031228593, 0.02262250542116817, 0.028476803781813942, 0.019634674536064267, 0.08173139518476091, 0.06000365268846508, 0.06471786749898456, 0.02050935865554493, 0.03791856608586386, 0.10752481190138496, 0.0632783533365, 0.021069028916826937, 0.030081533004704397, 0.05033148321672343, 0.05682127521140501, 0.010449110886838753, 0.023409851746691857, 0.08224977791542187, 0.026898482028627768, 0.02589650288427947, 0.011435840751801152, 0.010763070895336568, 0.04656478689867072, 0.059860358815058134, 0.025442746373300906, 0.06879455148009583, 0.046754843497183174, 0.04922205778711941, 0.025029609460034408, 0.02687648662686115, 0.07626142541994341, 0.1031402702210471, 0.045302174767130055, 0.021748702602053527, 0.08423798411968164, 0.08061647415161133, 0.0037646118107659277, 0.03335426139528863, 0.04971587914042175, 0.04174756570137106, 0.02512179718905827, 0.042787010315805674, 0.06564254639670253, 0.02564981856266968, 0.03353748281369917, 0.008680674091010587, 0.015652796209906228, 0.07410656995489262, 0.016196304350160062, 0.021773360458610114, 0.02161830911063589, 0.05252609924355056, 0.052166855239192955, 0.10142727463971823, 0.02297194194397889, 0.02149700692825718, 0.03333689885039348, 0.0460231341276085, 0.04200584051432088, 0.01946684340509819, 0.0935550247959327, 0.015890745453361887, 0.03101588023127988, 0.036377644864842296, 0.051229103410150856, 0.028371379848977085, 0.2833070087945089, 0.17065347405150533, 0.07646987243788317, 0.1646845435607247, 0.17516625142889097, 0.1228743554383982, 0.09223290355294012, 0.15592081850627437, 0.13089363957988098, 0.14620926696807146, 0.10436683252919465, 0.13207979936851189, 0.11465910720289685, 0.13994551089126617, 0.2210033402661793, 0.25301832938566804, 0.08285967487609014, 0.16837531817145646, 0.12913293874589726, 0.06031860160874203, 0.08734252143767662, 0.22891114640515298, 0.11146513366838917, 0.15916149539407343, 0.10898162552621216, 0.07705432115471922, 0.11323016122332774, 0.11174730563652702, 0.12085672307875939, 0.13921691483119503, 0.1271430923952721, 0.264426950016059, 0.14311241830000654, 0.11759715111111291, 0.14527105871820822, 0.08736600299016573, 0.07457085011992604, 0.11145780867082067, 0.17604574095457792, 0.09810383344301954, 0.1060903443431016, 0.18655251857126132, 0.12132823918364011, 0.13285618973895907, 0.12305527619901113, 0.14807450672378764, 0.1266886605299078, 0.1511255351942964, 0.08202490716939792, 0.13183307979488745, 0.18297063186764717, 0.1694968220544979, 0.12579794973134995, 0.13079767988529056, 0.22054461878724396, 0.17542321264045313, 0.1470429214532487, 0.22799895785283297, 0.08741553392610513, 0.14260211755754426, 0.12835154630010948, 0.15903540450381115, 0.09224897105013952, 0.1692198822274804, 0.23556380270747468, 0.13318445649929345, 0.12428022804670036, 0.3525277756853029, 0.27552668878342956, 0.12491783680161461, 0.11948910818318836, 0.13032306160312146, 0.13609846966573969, 0.1598899281816557, 0.13566161185735837, 0.08864364732289687, 0.1320941376616247, 0.23238119145389646, 0.10632915262249298, 0.10500128715648316, 0.09834845273871906, 0.18426055874442682, 0.10542283445829526, 0.13506939285434783, 0.21280936198309064, 0.08653897588374093, 0.11619950149906799, 0.1849947654409334, 0.16131498530739918, 0.13341909390874207, 0.18897919304436073, 0.09347793049528264, 0.08992205606773496, 0.14007666322868317, 0.08719127916265279, 0.09400849929079413, 0.10339222935726866, 0.11520509782712907, 0.10040108478278853, 0.1504978266893886, 0.06819886664743535, 0.114186069695279, 0.17079311655834317, 0.07407908080494963, 0.16690116055542603, 0.09311606670962647, 0.07083185817464255, 0.17629425652557984, 0.25226469326298684, 0.08374703116714954, 0.17991963308304548, 0.12464206956792623, 0.18503521248931065, 0.10101392806973308, 0.17811474477639422, 0.11773119782446884, 0.09409226549905725, 0.1013357233023271, 0.28533512027934194, 0.28460469853598624, 0.18507429398596287, 0.10723335566581227, 0.1596996415173635, 0.14081167144468054, 0.1930289444862865, 0.21313892008038238, 0.17770451522665098, 0.20777985686436296, 0.13725936674745753, 0.12914993392769247, 0.11082532815635204, 0.10293378989445046, 0.11835930708912201, 0.15094359026988968, 0.10182108788285404, 0.14275443594669923, 0.13867658679373562, 0.13748716155532748, 0.17372698959661648, 0.10289204408763908, 0.1860347221372649, 0.16750099399359897, 0.1729368546511978, 0.29239944589789957, 0.19607020629337057, 0.11235442696488462, 0.17617506760871038, 0.11426245153415948, 0.13725779339438304, 0.07453107842593454, 0.05604101825156249, 0.18430802650982514, 0.2677653677528724, 0.0871240851120092, 0.15829993615625426, 0.0932487627142109, 0.08678105703438632, 0.11232770222704858, 0.11348562329658307, 0.08244071024819277, 0.22652845160337165, 0.13915999210439622, 0.09551649884087965, 0.1572782066068612, 0.168521135346964, 0.11456234598881565, 0.13457377179292962, 0.1437278516823426, 0.15384611499030143, 0.10755073511973023, 0.16576950409216806, 0.09743011178215966, 0.15707613463746384, 0.0865188414172735, 0.1290315910591744, 0.11986989673459902], [0.04154416157689411, 0.05490449329954572, 0.06870440280181356, 0.027928223062190227, 0.048365775219281204, 0.013166355656721862, 0.0634360671392642, 0.0656252246699296, 0.014396957103599561, 0.12870037055108696, 0.018626594937813934, 0.055104290586314164, 0.018190243645221926, 0.02185173496400239, 0.05652635314618237, 0.040617979830130935, 0.05883209094463382, 0.08679798542289063, 0.06240986243938096, 0.02825066025252454, 0.06707820881274529, 0.032756736036390066, 0.04498180074733682, 0.013240151110949228, 0.07025363607681356, 0.04458589093701448, 0.11209348042029887, 0.03580137090466451, 0.02973745849885745, 0.027309852630423848, 0.09123554613324814, 0.04958150217134971, 0.023161054159572814, 0.04025072434160393, 0.029900020381319337, 0.1207843933661934, 0.04893380762950983, 0.029131673036317807, 0.014562126707460266, 0.01898867394629633, 0.037823519232915714, 0.035042257732129656, 0.025926034795702435, 0.07820013037417084, 0.012422492691257503, 0.028367743325361516, 0.06897527928231284, 0.07331949265790172, 0.060107835379312746, 0.04490106992307119, 0.03314841560495552, 0.037306836020434275, 0.026153091166634113, 0.04923481901641935, 0.014620122765336419, 0.008380125618714374, 0.024418810789939016, 0.018658373701327946, 0.0607857019349467, 0.03561374112905469, 0.06188685983943287, 0.03986563875514548, 0.0668163420050405, 0.018845172271539923, 0.03616616246290505, 0.08232330248574726, 0.09611878136638552, 0.05053440123447217, 0.021457379953062627, 0.07355039706453681, 0.04753460692882072, 0.01788435078196926, 0.09409671096364036, 0.0790236916509457, 0.012179023724456783, 0.0212139128416311, 0.03118555003311485, 0.0897804023406934, 0.042514727465459146, 0.053421107077156194, 0.027621619592537172, 0.030360252130776644, 0.02317561138625024, 0.02826034713507397, 0.06575736406375654, 0.01710045358777279, 0.022326618563965894, 0.07575735871796496, 0.0522179038671311, 0.009668010661698645, 0.039512406146968715, 0.02601035204861546, 0.0398073170799762, 0.0587070947221946, 0.05277579482935835, 0.011527957049111137, 0.06100092847191263, 0.045191676399554126, 0.05227005829510745, 0.05704152237740345, 0.017818665146478452, 0.08378442798857577, 0.044046568509656936, 0.027752846144721843, 0.006857867556391284, 0.03379201349162031, 0.04160862823482603, 0.01620563129108632, 0.10597479937132448, 0.009483742815064033, 0.01329757849816815, 0.02186679128499236, 0.06830278216511942, 0.01908230329718208, 0.057947031600633636, 0.005083558053229353, 0.02614094777527498, 0.042837357614189386, 0.02512868060875917, 0.05393750827352051, 0.08590121127781458, 0.05038369330577552, 0.018010291387327015, 0.06278882530750707, 0.018653028382686898, 0.028936638482264243, 0.020571114619087894, 0.03666372795123607, 0.07881678087869659, 0.023958070669323206, 0.05197941471124068, 0.08898657149984501, 0.03988376942288596, 0.009723081730044214, 0.007708113680564566, 0.01369661924400134, 0.026811006937350612, 0.06581646128324792, 0.002771649064925441, 0.02302470678841928, 0.020108758471906185, 0.029753166054433677, 0.06490476996987127, 0.03587276551115792, 0.013997201112943003, 0.03864182981487829, 0.10776746450574137, 0.08750343389692716, 0.017158977498183958, 0.027369389572413638, 0.04770418025145773, 0.02689126649784157, 0.029769378270430025, 0.07539948026533239, 0.0012618340360859293, 0.023006589108263142, 0.04202158517728094, 0.0306472907323041, 0.021174523353693075, 0.023084902386472095, 0.07613984678755514, 0.0036476567584031727, 0.04707379259343725, 0.037094533545314334, 0.02339421283977572, 0.04423749713168945, 0.08145660016452894, 0.08781065334915183, 0.017949182947631925, 0.02184801680414239, 0.011248327864450403, 0.046878863795427606, 0.02331337997020455, 0.020131570236117113, 0.03051701969525311, 0.026935754540318158, 0.01903645712445723, 0.014939262036932632, 0.0065586294385866495, 0.019976407565991394, 0.0026401140576126636, 0.03388824035937432, 0.037524541330640204, 0.0802740991639439, 0.05358820904802997, 0.0668052320543211, 0.05150720840902068, 0.04708113985543605, 0.017726989499351475, 0.04195101064397022, 0.03254900890169665, 0.007611483270011377, 0.051254124919069, 0.06757757771993056, 0.037021398602519184, 0.04532021266641095, 0.03678840133943595, 0.027082219239673577, 0.013826131435052957, 0.057038345985347405, 0.019031690681003965, 0.01297969994993764, 0.035146974769304506, 0.027249452941759955, 0.036409753884072416, 0.02016685564740328, 0.06750971573637798, 0.07910578802693635, 0.03818950193817727, 0.0898136431351304, 0.07275543815921992, 0.15380872559035197, 0.04549000121187419, 0.045165166884544306, 0.039424513597623445, 0.015576271507597994, 0.010930425196420401, 0.05564753526414279, 0.05326062877429649, 0.0455198095733067, 0.031191847156151198, 0.04746589147544, 0.06547764118295163, 0.0293578406854067, 0.08721455291379243, 0.05242751234618481, 0.04262330367055256, 0.02882250915718032, 0.04330915573518723, 0.013030019417783478, 0.07433376362314448, 0.06544149859109893, 0.09734410428791307, 0.05467875424074009, 0.07763912610244006, 0.056469987030141056, 0.04493382090004161, 0.12079241598257795, 0.04655092729080934, 0.04222586503601633, 0.05165838018001523, 0.04261504356691148, 0.021497908637684304, 0.021741169803135563, 0.030068369160289876, 0.07300174213014543, 0.008580732774134958, 0.04134352937398944, 0.04998136020731181, 0.009726242351462133, 0.03497401354252361, 0.04389981251733843, 0.04585788010444958, 0.040141380013665184, 0.03722135916177649, 0.041039245115825906, 0.09133641884545796, 0.08923617060645483, 0.013604005707748001, 0.09413056774064898, 0.034552265860838816, 0.05674526073562447, 0.03628080572525505, 0.024933714703365695, 0.04815315733139869, 0.014365858332894277, 0.020856793234997895, 0.05399382614996284, 0.00770643735449994, 0.052524715138133615, 0.00662383221424534, 0.061915321202832274, 0.028097981921746396, 0.020055650384165347, 0.00894999669981189, 0.014422462863876717, 0.025687464003567584, 0.04005623341072351, 0.036222354174242355, 0.03264889084675815, 0.024237539364548866, 0.06376199613441713, 0.030845336550555658, 0.0164288581800065, 0.08877371612470597, 0.045007111693848856, 0.06771759130060673, 0.030167598015395924, 0.05731974611990154, 0.02345021530345548, 0.008050904270930914, 0.030538814717147034, 0.061918063438497484, 0.010921808861894533, 0.027090111980214715, 0.033761997328838333, 0.06741838704328984, 0.1131547664408572, 0.0239781012351159, 0.052967046285630204, 0.034324619482504204, 0.03848633874440566, 0.03138869069516659, 0.036387778891366906, 0.03465982532361522, 0.037292145207175054, 0.0364791409811005, 0.048335744213545695, 0.08320411303429864, 0.10300525871571153, 0.05540828169614542, 0.05302782818034757, 0.01891553900350118, 0.028426669850887265, 0.03777840407565236, 0.012928320138598792, 0.02264375681988895, 0.028846634522778913, 0.016611051723884884, 0.029689894254261162, 0.026020768091257196, 0.06581355948583223, 0.006601608138225856, 0.03895024041412398, 0.012209780179546215, 0.01818989298044471, 0.04942671243043151, 0.06469644911703654, 0.01693148511549225, 0.021796621222165413, 0.0056550804129074095, 0.047857263052719645, 0.02435588223306695, 0.022954432824917603, 0.048246842343360186, 0.027384625864215195, 0.1176345998828765, 0.045668550810660236, 0.0881590174685698, 0.014061440488148946, 0.019468144018901512, 0.052896186025463976, 0.06217818248842377, 0.050485163446865045, 0.048958428378682584, 0.01440042757167248, 0.027531884661584627, 0.010347549832658842, 0.02737616166996304, 0.07885757673648186, 0.049385512102162465, 0.038350703835021704, 0.12361161978333257, 0.15693024324718863, 0.09924055135343224, 0.160553244932089, 0.16778761142631993, 0.1454110722988844, 0.2099947223905474, 0.16009433049475774, 0.1842241786653176, 0.20041212643263862, 0.10538733753492124, 0.11570566159207374, 0.05888205603696406, 0.0931273918831721, 0.15315116790588945, 0.09520416599116288, 0.18824213650077581, 0.15606607164954767, 0.11318711665808223, 0.1865309220738709, 0.14656288549304008, 0.14836032263701782, 0.1298517532995902, 0.11354932925314642, 0.16184340929612517, 0.07937333968584426, 0.1861586162704043, 0.09441718517336994, 0.11181107838638127, 0.10938137595076114, 0.1703647043905221, 0.2094550326000899, 0.11686603174894117, 0.2079835021868348, 0.141297496156767, 0.2734741161111742, 0.15959263866534457, 0.15807058283826336, 0.13002964609768242, 0.12261684503755532, 0.16474658710649237, 0.09921192671754397, 0.10906510971835814, 0.14937696105334908, 0.11023849714547396, 0.08579336237744428, 0.1877776114270091, 0.14213404501788318, 0.20003790588816628, 0.19510001147864386, 0.1462796374107711, 0.13517400599084795, 0.09229898438206874, 0.1016007071302738, 0.13267946953419596, 0.1597785169724375, 0.1297499454813078, 0.14250770153012127, 0.18220783764263615, 0.09592910326318815, 0.1812193711521104, 0.21873691031942144, 0.14359552675159648, 0.1356059656245634, 0.21576316910795867, 0.2435876362142153, 0.1635742312646471, 0.27011616504751146, 0.10387113725300878, 0.26609455584548414, 0.1992337146657519, 0.0783228815998882, 0.2590611926279962, 0.16056983935413882, 0.11357460680301301, 0.07954415981657803, 0.17222768801730126, 0.13425647397525609, 0.13084026431897655, 0.14895239321049303, 0.1375965541228652, 0.17675468494417146, 0.10178212512983009, 0.14403737179236487, 0.09221696222084574, 0.12509375548688695, 0.15602229977957904, 0.0998717627953738, 0.142824865761213, 0.16040141636040062, 0.16052694321842864, 0.13497660955181345, 0.10614227983751334, 0.14239479118259624, 0.11668574923533015, 0.2094717012369074, 0.10958090235362761, 0.20069374179001898, 0.12392938515404239, 0.243864442454651, 0.12622763839317486, 0.22608773462707177, 0.13290290051372722, 0.12479011318646371, 0.09595047711627558, 0.17492223327280954, 0.16729912982555106, 0.09091251151403412, 0.15396358212456107, 0.1193230229546316, 0.15652575792046264, 0.08740525518078357, 0.12175410578493029, 0.16995198122458532, 0.10425084226881154, 0.09549151072860695, 0.18539923592470586, 0.13742247596383095, 0.17769439233234152, 0.1878494958509691, 0.17250309902010486, 0.212488635443151, 0.12215964496135712, 0.14201274840161204, 0.10025302632129751, 0.07772390163154341, 0.13530077965697274, 0.08553147330530919, 0.25543657306116074, 0.16956061706878245, 0.21549519442487508, 0.18107819982105866, 0.15659571276046336, 0.2903415000764653, 0.13136193476384506, 0.05530091519176494, 0.07979760324815288, 0.1343301247106865, 0.09593524824595079, 0.06269513658480719, 0.06953546719159931, 0.09094852794078179, 0.2156706529785879, 0.11203977119293995, 0.14687461720313877, 0.14286011777585372, 0.15566572750685737, 0.15913856303086504, 0.10303203540388495, 0.16891383536858484, 0.0863218012091238, 0.14521087054163218, 0.13320113997906446, 0.1719458054867573, 0.0802739655773621, 0.17123626777902246, 0.15393630077596754, 0.10616232524625957, 0.0955715513555333, 0.06978194185649045, 0.28445371601264924, 0.11941774326260202, 0.22017915558535606, 0.09659348128479905, 0.16846707731019706, 0.1488406109274365, 0.2189678221475333, 0.23605842929100618, 0.20750656840391457, 0.10327723357477225, 0.10850763064809144, 0.14444834348978475, 0.17194484069477767, 0.15151498460909352, 0.13229080679593608, 0.09607208543457091], [0.03585101316275541, 0.04247440658218693, 0.015524163463851437, 0.031756380340084434, 0.031247523074853234, 0.01475409804697847, 0.03715484788699541, 0.04870616125117522, 0.09328045242000371, 0.05404640731285326, 0.0661891233175993, 0.06160198274301365, 0.057370557260583155, 0.054680331304552965, 0.03633748725405894, 0.02728595176449744, 0.02265639188408386, 0.055136574010248296, 0.011802444078057306, 0.019676203264680225, 0.0385013561026426, 0.04176483547780663, 0.08719261502847075, 0.008220574072765885, 0.10797867231303826, 0.021813781531818677, 0.001057675935953739, 0.0769767741439864, 0.036152451284579, 0.0060125339859951055, 0.019341695042385254, 0.04910076859232504, 0.009170768935291562, 0.03943480347516015, 0.05833688177517615, 0.04165349106187932, 0.020946420554537326, 0.05397009226726368, 0.08837487854179926, 0.02952632676169742, 0.025106642533501144, 0.02321296553418506, 0.02732715023739729, 0.051063415230601095, 0.0798053883772809, 0.04543529750662856, 0.019451206353551243, 0.03040205359866377, 0.041350487008458, 0.008735076298762579, 0.01938466724823229, 0.05726576600864064, 0.04544943541986868, 0.056296380134881474, 0.03979084882303141, 0.014195172716426896, 0.01752584706991911, 0.048688245806260966, 0.053910364222247154, 0.01317423726504785, 0.022411433055822272, 0.05905586702283472, 0.004734288977488177, 0.010428992191009456, 0.06518434442114085, 0.04576705607178155, 0.01165896188467741, 0.0517771906015696, 0.013148720372555545, 0.052887859128532, 0.017518017411930487, 0.022091860555519816, 0.05477593847899698, 0.009777784507605247, 0.04072892348631285, 0.03689787183247972, 0.026561893937468994, 0.01064478647094802, 0.04141687953961082, 0.008736556883377489, 0.11754382780054584, 0.029528558770834934, 0.08611395533080213, 0.027350414711690973, 0.03490491217235103, 0.043095788278151304, 0.025670505929156207, 0.025161346238746773, 0.021179490177019034, 0.03611445332353469, 0.06468493840657175, 0.054130010248627514, 0.021667930959665682, 0.009419547041034093, 0.01048302425260772, 0.03648158264695667, 0.016670993136358447, 0.026875091389229055, 0.06269011224503629, 0.026329100764996838, 0.04546606694930233, 0.09102628275286406, 0.04710909284767695, 0.03999921049398836, 0.05642088653985411, 0.05100396920170169, 0.027658276121655945, 0.0302032582112588, 0.02873999717849074, 0.03110797148110578, 0.04289178301405627, 0.015672405606892426, 0.01826472744141938, 0.042907794850179926, 0.0807041663210839, 0.03536393793183379, 0.07463646339601837, 0.028914264585182536, 0.027312409329169895, 0.029983673412061762, 0.019288967305328697, 0.05718202948628459, 0.03770864219404757, 0.0695419312978629, 0.024160337452485692, 0.05746952636400238, 0.017134579393314198, 0.014292303148977226, 0.09007951754028909, 0.026413481100462377, 0.03905278666934464, 0.10781921446323395, 0.03228752801078372, 0.036144951882306486, 0.03769576593185775, 0.019265925475338008, 0.010029354016296566, 0.025775274916668423, 0.00515303745487472, 0.02083160845359089, 0.020518060337053612, 0.03247857166570611, 0.048236237053060904, 0.06168522573716473, 0.027444034785730764, 0.03760630374017637, 0.061134971474530175, 0.04417749820277095, 0.061279437941266224, 0.026746111689135432, 0.034510631376178935, 0.02550137047364842, 0.03099988509347895, 0.03372442239196971, 0.02252798920380883, 0.034235305720358156, 0.05940560411545448, 0.03414893457375001, 0.04597469414875377, 0.06966021479456685, 0.00782630162575515, 0.015331170743593248, 0.022083446456235833, 0.06457196126575582, 0.07284744962817058, 0.057199418006348424, 0.02354048458073521, 0.012876209311798448, 0.014089645810599905, 0.03277587973570917, 0.011882121052622097, 0.009909101045195712, 0.015249790540110553, 0.014062577829463407, 0.021146303188288584, 0.019079807825619355, 0.0034547408040452865, 0.031215336130117066, 0.02276783277920913, 0.048509763000765815, 0.023648832575418055, 0.08118591664242558, 0.010378812803537585, 0.07112846491509117, 0.021537845459533855, 0.041860082710627466, 0.026558856698102318, 0.02443504155962728, 0.046214051617425866, 0.036414158530533314, 0.07467213101335801, 0.09879441669909284, 0.06517258880194277, 0.08928490002290346, 0.04608420917065814, 0.04425422885105945, 0.009134365664067445, 0.04702173093392048, 0.0736782097374089, 0.045361494630924426, 0.09909950618748553, 0.03454815436271019, 0.02934684576757718, 0.08587876131059602, 0.023035842714307364, 0.00736725452952669, 0.041139483291772194, 0.05345902711269446, 0.04896388687484432, 0.044974991542403586, 0.05265493236947805, 0.06559305256814696, 0.05948963749688119, 0.09917968782247044, 0.005973610659566475, 0.014405052079382585, 0.02524962656025309, 0.023014839935058262, 0.05822150007588789, 0.05087270925287157, 0.03549098619259894, 0.040806396282278, 0.049498214648338035, 0.03261211371864192, 0.031070053300936706, 0.06528934347443283, 0.03286708226369228, 0.02519241996196797, 0.029369130606937688, 0.026928490769932978, 0.021597425075015053, 0.08800549680017866, 0.01565238617331488, 0.02092892627842957, 0.02026779329753481, 0.008947029964474496, 0.10116471763467416, 0.028449897217797115, 0.040371089562540874, 0.004736141099783708, 0.06407724562450312, 0.030890123307472095, 0.03341415271279402, 0.017381491925334558, 0.030610513604187872, 0.020221806116751395, 0.033266268656007014, 0.02632186296978034, 0.09295260126236826, 0.02112787009536987, 0.03277351970609743, 0.03314700923510827, 0.052464731052168645, 0.04938932674122043, 0.06321279201074503, 0.021353200972953346, 0.06535371736390516, 0.07252469702507369, 0.024073409695120063, 0.073217536410084, 0.051593022944871336, 0.03388780991372187, 0.047554659759043716, 0.020943207055097446, 0.027081966909463517, 0.05965175965684466, 0.07772462893626653, 0.010374065841460833, 0.01864507812570082, 0.009572777344146743, 0.03267893669544719, 0.0419578977744095, 0.0233289056996, 0.06037051854946185, 0.05308388630510308, 0.038157637827680446, 0.009031391746248119, 0.026922776232822798, 0.014187446959113004, 0.04220051327138208, 0.021988679764035624, 0.00412002123084676, 0.03646629069407936, 0.02775753651803825, 0.039057781323208474, 0.03587391212931834, 0.010782481767819263, 0.041387694582226686, 0.02193525626353221, 0.022146417686599307, 0.03960507812735159, 0.14155220123939216, 0.05018774034397211, 0.021760474919574335, 0.054832464156788774, 0.024218302896770183, 0.03727103852725122, 0.060654620101558976, 0.03511458373395726, 0.019728049701370765, 0.032081466997624375, 0.032553899654885754, 0.019058257712458726, 0.023462130484404042, 0.0296878273729817, 0.07602062076330185, 0.0400924205314368, 0.04797125693585258, 0.027696511569956783, 0.05396555774495937, 0.0428760197974043, 0.0549683476856444, 0.08469611930195242, 0.010425792606838513, 0.036792720638914034, 0.025410494490643032, 0.05200241386773996, 0.03944527517887764, 0.043652261738316156, 0.0798181162099354, 0.0371471926337108, 0.02445224454277195, 0.07188276154920459, 0.04522440140135586, 0.0630531412025448, 0.022628179140156135, 0.04518268156971317, 0.03780797494982835, 0.044413642172003165, 0.053093879323569126, 0.019345999498909805, 0.03694924700539559, 0.030855455734126735, 0.08387847294216044, 0.04873196572589222, 0.031654880513087846, 0.029131739829608705, 0.06377212645020336, 0.04050678384373896, 0.06153154550702311, 0.05946273093286436, 0.0619626331172185, 0.051218442458775826, 0.042865596333285794, 0.02293094941705931, 0.013997655678394949, 0.06521616771351546, 0.08312104444485158, 0.011681132618832635, 0.011777765812439611, 0.05965991585981101, 0.05386353841458913, 0.21097309567267075, 0.22781091247452423, 0.10764400823973119, 0.10462150792591274, 0.16861124691786245, 0.18454058590577915, 0.10820847091963515, 0.24733393831411377, 0.15397285897051916, 0.11467397242086008, 0.20665210409788415, 0.06897058148751967, 0.12255486086360179, 0.09138562323641963, 0.1417282980401069, 0.21603265777230263, 0.16716034821001813, 0.21889041614485905, 0.11580175487324595, 0.165228433907032, 0.10919751628534868, 0.15997977257939056, 0.19008100032806396, 0.07755958271445706, 0.22600985364988446, 0.12921168061438948, 0.10303908580681309, 0.14042836701264605, 0.16170309885637835, 0.130642838194035, 0.11398010145057924, 0.14536425762344152, 0.21179241186473519, 0.09264381587854587, 0.10387098140199669, 0.2014428804977797, 0.09803649096284062, 0.1318435143912211, 0.19291089847683907, 0.08537426416296512, 0.10467742875334807, 0.15749470592709258, 0.1501423676381819, 0.15164687909418717, 0.11711239509168081, 0.15130651532672346, 0.14116068865405396, 0.15783501032274216, 0.08923488669097424, 0.10128530178917572, 0.11058530275477096, 0.1300548345898278, 0.13158992253011093, 0.15619677869835868, 0.1844123427872546, 0.17018241807818413, 0.14011458697495982, 0.08336630940902978, 0.13202091737184674, 0.07851163943996653, 0.2490778814535588, 0.14838540722848848, 0.1878197505720891, 0.14109947631368414, 0.10893857353948988, 0.15590196795528755, 0.12159846257418394, 0.17637210781686008, 0.11330796798574738, 0.11638585478067398, 0.11324033606797457, 0.08772582586971112, 0.20589836407452822, 0.06942633437574841, 0.20208179543260485, 0.07883346435846761, 0.1383392806746997, 0.11397691763704643, 0.18011913722148165, 0.0840103228983935, 0.193339473917149, 0.12797205650713295, 0.1923496715608053, 0.2649714192375541, 0.16995388112263754, 0.14584174059564248, 0.08392456773435697, 0.12910647375974804, 0.13933000329416245, 0.18829200882464647, 0.12021776361507364, 0.1431059616152197, 0.0761946098646149, 0.09262219711672515, 0.14408383023692295, 0.08978744532214478, 0.10638211970217526, 0.16211176989600062, 0.11737139720935374, 0.20031339110573754, 0.12911689351312816, 0.19564177928259596, 0.20667413104092702, 0.18060349248116836, 0.09944277175236493, 0.1173148826637771, 0.14521590230287984, 0.14716545003466308, 0.08534240376320668, 0.10495456153876148, 0.12735524273011833, 0.12222977791680023, 0.0798392748401966, 0.15470095037017018, 0.16811414156109095, 0.22725062066456303, 0.18695914128329605, 0.12107984977774322, 0.21191632084082812, 0.1861230525537394, 0.12924190086778253, 0.12419102189596742, 0.09394858570885845, 0.1348960420000367, 0.18048889003694057, 0.14462200604612008, 0.1549731701379642, 0.08997534227091819, 0.25178232695907354, 0.20495133911026642, 0.10247786631225608, 0.19384165556402877, 0.12026745040202513, 0.11293540243059397, 0.19752451888052747, 0.11894016381120309, 0.15658314077882096, 0.07584650549688376, 0.08752215086133219, 0.12193407659651712, 0.17946653708349913, 0.16087763768155128, 0.1380663039162755, 0.16831389802973717, 0.13576291501522064, 0.1402999903075397, 0.1432301229215227, 0.08014115825062618, 0.1511730920174159, 0.114410398673499, 0.13258791819680482, 0.07260106402100064, 0.19721872435184196, 0.13443482690490782, 0.05833364601130597, 0.12043568043736741, 0.2122795575996861, 0.2945937094045803, 0.1859633275307715, 0.11607775959419087, 0.156936269486323, 0.215101262438111, 0.09369745035655797, 0.11085835372796282, 0.22293575922958553, 0.11924979524337687, 0.10782510711578652, 0.12136502744397148, 0.13566520385211334, 0.17227102944161743, 0.1742667832877487, 0.12226420614751987, 0.06250061967875808, 0.08599262902862392, 0.09778255771379918, 0.06935013065231033], [0.030349088374350686, 0.07611617969814688, 0.019218192392145284, 0.018708283132582437, 0.03498809579468798, 0.023462790995836258, 0.02847095009201439, 0.044789933308493346, 0.04451616987353191, 0.019554504033294506, 0.020927942932758015, 0.055026016270858236, 0.04055580269778147, 0.04180018397164531, 0.028196079001645558, 0.010949814732157392, 0.02010206058912445, 0.050933394668390974, 0.055305494242929853, 0.022559085191460326, 0.09043941463460214, 0.02508216093701776, 0.028020820827805437, 0.044080202642362565, 0.060604584505199455, 0.02648135236086091, 0.06669644062640145, 0.04797277462785132, 0.013695108973479364, 0.020427770650712773, 0.02885684276407119, 0.015122387903829804, 0.027310088262311183, 0.039230445690918714, 0.07030364940874279, 0.043636747141135857, 0.01692409518000204, 0.03891022010066081, 0.021764079901913647, 0.024041668038989883, 0.012807761031581322, 0.04014879777969327, 0.011825709480035584, 0.006703024473608821, 0.04419151366164442, 0.06438499200157821, 0.06633354525547475, 0.002395503574916802, 0.023306257207877934, 0.007402519995594048, 0.046374333251151256, 0.040246750140795484, 0.025149460743705276, 0.04473746717849281, 0.12169734633062035, 0.02561631987191504, 0.04813569459656719, 0.032167489334824495, 0.06717431693687104, 0.012166222604719223, 0.020504061576502863, 0.0038198134507183568, 0.08529726634151302, 0.09071858090464957, 0.026147519492951687, 0.010258446654916042, 0.06235474313143641, 0.037334974549594335, 0.02403909464192111, 0.045045911174383946, 0.03472071111900732, 0.03502248691802379, 0.007260422835315694, 0.027055307109549176, 0.05549794055696111, 0.059755563852377236, 0.04046463356644381, 0.03163388144457713, 0.11257903795922175, 0.005532249406314804, 0.0654302402108442, 0.026821009232662618, 0.008138668799801962, 0.05124143419379834, 0.009401739207532955, 0.03272171408752911, 0.025521632960590068, 0.07975619882927276, 0.025048652969417162, 0.05121895454067271, 0.03011658463947242, 0.009194099275191547, 0.02266230309032835, 0.04772430729644839, 0.038932799943722785, 0.03668842291517649, 0.05214218625042122, 0.015930047738947906, 0.038885187459527515, 0.06401907608960755, 0.010980479346471839, 0.030831376752757933, 0.034380829747533426, 0.028895501236547716, 0.04304768597648945, 0.050435888551874086, 0.045944325465825386, 0.030286326800705865, 0.08315057450090535, 0.012701774921879405, 0.06422392369131558, 0.07234690070617944, 0.04744630990899168, 0.012720170907414285, 0.0272595795468078, 0.06462668723543175, 0.030571832867281046, 0.04067731824761722, 0.04056637088069692, 0.02459610430378234, 0.03418436841457151, 0.021583619272860233, 0.07657838184968568, 0.0031529543366559665, 0.03780214909056667, 0.011023213137377752, 0.057974134833784774, 0.07733241131063551, 0.014952452784200432, 0.006040601547283586, 0.009265794451494003, 0.07444233982823789, 0.05415130617620889, 0.012766920644935453, 0.0654701009625569, 0.03735586971743032, 0.07076151741784997, 0.028806836853618734, 0.014396798469533678, 0.07146558549720794, 0.017110079243138898, 0.0033737680860213004, 0.02759657581918873, 0.007528165597250336, 0.01680998069787165, 0.030857427991577424, 0.012608794950210722, 0.020069706661161035, 0.0594966953212861, 0.05298700634739362, 0.025755491114978213, 0.0973939172399696, 0.038429634951171465, 0.034815186518244445, 0.01621367431653198, 0.04185102479823399, 0.05689273290045094, 0.06810364910052158, 0.0364686952525517, 0.043446868658065796, 0.10439866324304603, 0.05762408232840244, 0.021206977471592836, 0.019135290785925463, 0.04768024598888587, 0.062129872385412455, 0.07713058424997143, 0.011608573768171482, 0.04401133504870813, 0.043958824389846995, 0.039649747996008955, 0.08892219761037268, 0.024973857471195515, 0.05790089599031489, 0.010923766276391689, 0.02795049120322801, 0.02016774807998445, 0.03658955029095523, 0.01406547220540233, 0.0033038222909453907, 0.014938409494789084, 0.07071914078551345, 0.03049792423553299, 0.00994512767647393, 0.042721278296085075, 0.037389967692433856, 0.008142492715705885, 0.057615655241534114, 0.04554791470582131, 0.07316505172639154, 0.04851636440434959, 0.013253083961899392, 0.04970809030055534, 0.06998024371569045, 0.07036996772512794, 0.009456750904064393, 0.04723584424937144, 0.03261012476286851, 0.017355750533170067, 0.04736834729555994, 0.06249851197935641, 0.0908106443239376, 0.0513310782116605, 0.018436812933941837, 0.009993809781008167, 0.05016683404392097, 0.0010016216378971876, 0.05384913332818542, 0.013955702997918706, 0.036812220569117926, 0.054603392854915, 0.010466829662618693, 0.07317168652662076, 0.022649732964055147, 0.013244693054730305, 0.010065119968203362, 0.007977390832820674, 0.03990600787801668, 0.036320172948762774, 0.03279832599218935, 0.013856996429240098, 0.03927720841602422, 0.0313913438731106, 0.023565162846352905, 0.005971610571577912, 0.048707638125051744, 0.05339099814591464, 0.034136856120312586, 0.0317142040876206, 0.002553000067564426, 0.022570894616364967, 0.026035479313577525, 0.041605975056882016, 0.0516780174075393, 0.08587166637880728, 0.005746237948187627, 0.007915586629678728, 0.07267870751093142, 0.07461977991624735, 0.08764434547629207, 0.049672151799313724, 0.020207653360557742, 0.07326745326281525, 0.03836238152871374, 0.032790414697956294, 0.046697568250237964, 0.030670766718685627, 0.06510138715384528, 0.07928713181172498, 0.04371775627078023, 0.01725687790894881, 0.030655079572170507, 0.02641903978656046, 0.010760311033664038, 0.050920818976010196, 0.04290550532459747, 0.040678572477190755, 0.026877982054429594, 0.021004076152166817, 0.039456299782614224, 0.03808611334534362, 0.05364400742109865, 0.03618141730839852, 0.0593919671518961, 0.00928709687286755, 0.026340939875808544, 0.09263470972655341, 0.0396072006697068, 0.021120875353517476, 0.019800943446171004, 0.05866888524906244, 0.028819323488278314, 0.017382751721015666, 0.0332600754336454, 0.022542442529811524, 0.021131842440809123, 0.06947694142581895, 0.027685242057486903, 0.05825603591802064, 0.026475537633814383, 0.003544688406691421, 0.054012235123082064, 0.06203299984917976, 0.033604495038161986, 0.006949329836061224, 0.003549208781805646, 0.035075743435299955, 0.011657851446216227, 0.020258158365322743, 0.04056195139128249, 0.003788086405620561, 0.032182822105824016, 0.03127339805359952, 0.02014339635934448, 0.04813582818314899, 0.050098994324798696, 0.028258890670258552, 0.02254237017041305, 0.034061516998917796, 0.011861757448059507, 0.05360448805731721, 0.03821190737653524, 0.06579597800737247, 0.038504135445691645, 0.06110586444265209, 0.0032343816201318987, 0.05940007140452508, 0.0773103027313482, 0.04019105195766315, 0.05040431016823277, 0.0561046017537592, 0.013470382018567761, 0.14126830006716773, 0.01718572821118869, 0.03956200016546063, 0.023872081728768535, 0.014813013440289069, 0.025788030579860788, 0.04884334353846498, 0.033648137032287195, 0.03896908354363404, 0.06563816772541031, 0.0540071143041132, 0.052187383043929, 0.0216685469422373, 0.0605048472789349, 0.04643548250896856, 0.028055902148480527, 0.006803000578656793, 0.022640133283857722, 0.03253213988500647, 0.004584639073073049, 0.0365052571578417, 0.018373290658928454, 0.015612237839377485, 0.0026243320553476224, 0.04639204460545443, 0.06849010766018182, 0.05870008884812705, 0.016344160576409195, 0.015964897138474043, 0.06765748476027511, 0.028731718521157745, 0.03433540288824588, 0.038462994489236735, 0.04709150394774042, 0.05788924798252992, 0.10832853557076305, 0.05798121863335837, 0.04688437424192671, 0.04231569459079765, 0.015482340659218607, 0.11541518499143422, 0.17242475791135803, 0.18204352614702657, 0.18370559555478394, 0.09994024076149799, 0.1460022374521941, 0.0816276429395657, 0.11985622637439519, 0.13778905238723382, 0.12400880237692036, 0.05773849552497268, 0.12031908161588944, 0.12331452322541736, 0.19335820572450757, 0.19475745095405728, 0.08389951282879338, 0.08475879367324524, 0.15307803667383268, 0.10522934913751669, 0.12119675287976861, 0.19817471446003765, 0.1058750695665367, 0.12902020651381463, 0.15360000397777185, 0.08162964673829265, 0.15563071297947317, 0.25175614398904145, 0.1850832739728503, 0.07522258936660364, 0.17780639725970104, 0.07182479981565848, 0.1701659572427161, 0.12737792276311666, 0.11993135398370214, 0.1313245453638956, 0.09013833274366334, 0.1588368948432617, 0.10367273149313405, 0.20458085899008438, 0.08297680062241852, 0.12051802914356813, 0.10842724863323383, 0.10889662735280581, 0.2146413832088001, 0.1563695803633891, 0.15486506890738383, 0.1582202294957824, 0.10610004421323538, 0.09708352881716564, 0.13955295929918066, 0.15834176359931007, 0.06637982558459044, 0.08972051844466478, 0.1103337221138645, 0.18648525030585006, 0.243465137318708, 0.09719859881442972, 0.13625629479065537, 0.26309850567486137, 0.08726775005925447, 0.06261995702516288, 0.13617007207358256, 0.22314091853331774, 0.18508207169361413, 0.1513230800628662, 0.07940002731629647, 0.18349142657825723, 0.13672950299223885, 0.12672576791374013, 0.13850299845216796, 0.10371619908255525, 0.12144758395152166, 0.1549134124070406, 0.11559405000298284, 0.07772008699248545, 0.14190728921676055, 0.19480033224681392, 0.07964993812493049, 0.19379936798941344, 0.07916642149211839, 0.12374393729260191, 0.09307717817137018, 0.11036026131478138, 0.10162786973523907, 0.1112895118421875, 0.10964336892357096, 0.12016478169243783, 0.18259050382766873, 0.06775022353394888, 0.1684579488937743, 0.15985719946911559, 0.08752787281991914, 0.08992024522740394, 0.15149705432122573, 0.10345563103328459, 0.12136669727624394, 0.11896402385900728, 0.11742095040972345, 0.13523186382371932, 0.13731682382058352, 0.19176664034603164, 0.14130987518001348, 0.20776565215783194, 0.10063085370347835, 0.13833963690558448, 0.17296671867370605, 0.17285716283367947, 0.07030026521533728, 0.19592769909650087, 0.06350886440486647, 0.07560250960523263, 0.11380748532246798, 0.12064324429957196, 0.07695822045207024, 0.10247970683849417, 0.2302443701773882, 0.0835837067279499, 0.12633695674594492, 0.10110706760315225, 0.2737776841968298, 0.18259563948959112, 0.11730162790627219, 0.12362206922261976, 0.13611591013614088, 0.15388028346933424, 0.10749862893135287, 0.20288141502533108, 0.13233983307145536, 0.12302492235903628, 0.06831327613326721, 0.09135560336289927, 0.28918600582983345, 0.13356001290958375, 0.17048037552740425, 0.14946533599868417, 0.14442478772252798, 0.23939831648021936, 0.09309985078289174, 0.1580639331950806, 0.10886776522966102, 0.07659053822862916, 0.06376414836267941, 0.17983257916057482, 0.13679832976777107, 0.08695815573446453, 0.1536451859283261, 0.1650371972937137, 0.08261978306109086, 0.1637223342549987, 0.1151221628242638, 0.05941802395682316, 0.1065280481998343, 0.12111859730794095, 0.15694064815761521, 0.09111749270232394, 0.10015731895691715, 0.09480252309003845, 0.13497603067662567, 0.13277775957249105, 0.1144787430530414, 0.18852461274946108, 0.2221916225971654, 0.08899007443687879, 0.07802496867952868, 0.08503697288688272, 0.13940083386842161, 0.20393784740008414, 0.1012651673227083, 0.13799467182252556, 0.09844452375546098, 0.17123801924753934, 0.24067960475804284, 0.1512562422431074, 0.12688108457950875, 0.09385177996591665, 0.1001308168633841], [0.032786054580355994, 0.03439083018747624, 0.012860294882557355, 0.025247817575291265, 0.04172297092736699, 0.06570643046870828, 0.032606458553345874, 0.051264437061036006, 0.057910491959773935, 0.029309261553862598, 0.033490515997982584, 0.02606574780656956, 0.02177131398639176, 0.01603187596629141, 0.04016542930912692, 0.037150146381463856, 0.04340336025052238, 0.0524546267115511, 0.03643655283667613, 0.052599560731323436, 0.049075457645813, 0.006568715225512278, 0.03851818430121057, 0.010823514185176464, 0.041378811074537225, 0.0386043810431147, 0.020850483124377206, 0.028576600379892625, 0.009809907442104304, 0.055201916402438655, 0.05262664912152104, 0.04333123091782909, 0.02428105890430743, 0.015115594469534699, 0.06901690634549595, 0.03159004649205599, 0.019150226507917978, 0.024416781016043387, 0.02174692886910634, 0.0451207716105273, 0.05256573364022188, 0.042049879557453096, 0.04028126371849794, 0.06628251518122852, 0.043203707682550885, 0.018010360035987105, 0.03341752577398438, 0.057231872124248184, 0.01988821259146789, 0.010359104144299636, 0.10289386977092363, 0.02707060833927244, 0.02410980647255201, 0.05737934428907465, 0.025480935437371954, 0.06994767085416242, 0.054625375269097276, 0.006396837070496986, 0.03083283136220416, 0.034781229551299475, 0.05259455123450607, 0.04229082151141483, 0.03826200605544727, 0.0112035114216269, 0.02328758106159512, 0.04809917722013779, 0.02535543269914342, 0.03483075306576211, 0.028538567166833673, 0.10734605079051107, 0.07464847876690328, 0.03349441598402336, 0.019243130409449805, 0.029715348064200953, 0.01682371599599719, 0.15935271716443822, 0.020874601068499032, 0.039179771847557276, 0.03361784256412648, 0.0905362945923116, 0.07633046741830185, 0.047617386080673896, 0.024471369688399136, 0.028287431814533193, 0.01868302970251534, 0.04126916246605106, 0.028945295634912327, 0.05826814776810352, 0.04151679117057938, 0.01677877524343785, 0.06159673946967814, 0.023119020770536736, 0.015271932516043307, 0.025295548803114798, 0.06507752710604109, 0.024582749356341083, 0.04392763563373592, 0.04591205688484479, 0.026666358644433785, 0.06903449524543248, 0.041280498771811835, 0.07474631609511562, 0.039152297540567815, 0.024235301789303776, 0.0671880911977496, 0.045754940510960296, 0.041877018520608544, 0.020824558050662745, 0.07477236547856592, 0.07939996052300557, 0.04192591492028441, 0.040216466804849915, 0.04099717647477519, 0.07999859168194234, 0.02695042308914708, 0.04365147135104053, 0.004686826778197428, 0.024291482368425932, 0.022709945260430686, 0.03814575604337733, 0.048719126571086235, 0.027544766489882022, 0.05624742807412986, 0.04594756865117233, 0.008219580522563774, 0.06531527411425486, 0.054692231642547995, 0.047561224055243656, 0.05394064384745434, 0.05264237894152757, 0.030502358567900956, 0.03909901133738458, 0.016535703325644135, 0.01189364660604042, 0.028163194438093342, 0.032211784418905154, 0.023559192268294282, 0.023966733388078865, 0.05138438667927403, 0.02115760053129634, 0.006727761647198349, 0.08919261395931244, 0.027501814693096094, 0.022495334706036374, 0.07319179872865789, 0.011930282726098085, 0.031101772692636587, 0.0014233233991944871, 0.028756532228726428, 0.04071195799042471, 0.02935650853032712, 0.04209736216580495, 0.046950562682468444, 0.040912861077231355, 0.052613309017033316, 0.040487821970600635, 0.06621787411859259, 0.02890506380936131, 0.04407966829603538, 0.07096954883309081, 0.034023589541902766, 0.045204712223494425, 0.022358204369083978, 0.028571529655891936, 0.04300437794881873, 0.02356586974201491, 0.02714726662816247, 0.047001848797663115, 0.010192024437856162, 0.06461021897848696, 0.010874279869312886, 0.02918968486483209, 0.04583463232847862, 0.0018314782982997713, 0.040246935677714646, 0.04152076166064944, 0.018720387561188545, 0.07097004607203417, 0.04137320414884016, 0.03903983248164877, 0.051818613574141636, 0.06518804773804732, 0.04033441633509938, 0.013511426495824708, 0.03459567407844588, 0.03215523647668306, 0.06266332071390934, 0.07262316517881118, 0.035205901294830255, 0.007879213972046273, 0.05663154886860866, 0.034507636810303666, 0.0625048424990382, 0.059559087676461786, 0.09233904551365413, 0.03959545247198548, 0.017563106594025157, 0.03258423494116869, 0.0361414749204414, 0.06362639833241701, 0.054912853593123145, 0.06641662126639858, 0.009912008408718975, 0.05621572723612189, 0.0354998251714278, 0.008796423153398791, 0.025106071079790127, 0.06408624045434408, 0.05511546361958608, 0.049040112862712704, 0.0683358967944514, 0.062131078375387006, 0.012086248771083774, 0.06262682931264862, 0.01717689294309821, 0.03609262676036451, 0.0454131777951261, 0.10025001320173033, 0.04537685337709263, 0.022149096839712, 0.04639321719878353, 0.030720961876795627, 0.017368650915159378, 0.01475867060435121, 0.02468588932970306, 0.028668552477029152, 0.02156076669052709, 0.002472641940585163, 0.05117112312291283, 0.0534073179733241, 0.019825480703730136, 0.01897438760352088, 0.014542711196554592, 0.01273931831747177, 0.018988143310707528, 0.04910296534944791, 0.027248406513535883, 0.07968945748871192, 0.02183911103202263, 0.07067474551149644, 0.007726122357780696, 0.029482874015229754, 0.006212427751961513, 0.03672802391520236, 0.07533152180258185, 0.049208038617507555, 0.028866971224488225, 0.03413601007196121, 0.019395081435504835, 0.005702583430320374, 0.03652640836662613, 0.04076630175404716, 0.07114236534107476, 0.029670286712644156, 0.021034532037447207, 0.02094957097142469, 0.04702736754552461, 0.03870021457260009, 0.02789164260320831, 0.01968541146197822, 0.034297653546673246, 0.04884795969701372, 0.0145783639709407, 0.05738137406297028, 0.016871475054358598, 0.03233710347558372, 0.08767888502916321, 0.011458896497060778, 0.03278570206020959, 0.022295980852504726, 0.0333782810048433, 0.004855429278904921, 0.03775066630623769, 0.07628432067576796, 0.019072013419645373, 0.022247366468945984, 0.058910005318466574, 0.05128926190081984, 0.03899202332831919, 0.02421364035399165, 0.022571490189875476, 0.02644193318701582, 0.028912366542499512, 0.011032309084839653, 0.032340164834749885, 0.05604900747130159, 0.003285500520178175, 0.0342039796669269, 0.0674496685678605, 0.10672235730453394, 0.009621128265280277, 0.016097639527288266, 0.036095673276577145, 0.009375659210490994, 0.05436456973257009, 0.016374006045225542, 0.07820229002390988, 0.0897223070205655, 0.05706631010980345, 0.03674828454677481, 0.031702871492598206, 0.04115415926207788, 0.04038175422465429, 0.03610813022532966, 0.008669573417137144, 0.057834499748423696, 0.029390068448265083, 0.023416839067067485, 0.010134847525478108, 0.002512047199161316, 0.04842411173740402, 0.02018908297031885, 0.05506537978362758, 0.04120974241232034, 0.012710532264463836, 0.044632761273533106, 0.009167591615550919, 0.022678246277791914, 0.010917773433902767, 0.02428181589493761, 0.009509345054539153, 0.04625402369129006, 0.050292164232814685, 0.04362021209090017, 0.02132938174327137, 0.05004384904168546, 0.03571914836356882, 0.12448500143364072, 0.016411733122367878, 0.03727693860128056, 0.0383485144993756, 0.02659973419213202, 0.05426800147688482, 0.02758266797172837, 0.0738122861366719, 0.07296796698938124, 0.045772622179356404, 0.03887946921167895, 0.02782539108011406, 0.03809076290053781, 0.013261472086014692, 0.017377968579239678, 0.056796780627337284, 0.019674021350510884, 0.02944044172181748, 0.08622520326753147, 0.01742377022310393, 0.04053846241731662, 0.03492957002890762, 0.07311469700653106, 0.024928909297159407, 0.01987929568713298, 0.09087116646696813, 0.16927898686844856, 0.15279683691915125, 0.10243100710795261, 0.14465218177065253, 0.15684684069128707, 0.09284054438467138, 0.0825228808389511, 0.08838298279442824, 0.1602145584183745, 0.17859721498098224, 0.1358465847442858, 0.18024614837486297, 0.11886008607689291, 0.18565627135103568, 0.13638384029036388, 0.26123247924260795, 0.10609973993268795, 0.13095831032842398, 0.18878041621064767, 0.1213530714449007, 0.12649844808038324, 0.1410912533174269, 0.15416826645378023, 0.08886284806067124, 0.15684290730860084, 0.09718998990138061, 0.1580267515964806, 0.17679721000604331, 0.11451087062596343, 0.1483037561411038, 0.12022214970784262, 0.16865258454345167, 0.12434323638444766, 0.24093968298984692, 0.12443897343473509, 0.11487517607747577, 0.20989338954677805, 0.13349005806958303, 0.10017622145824134, 0.16113443562062457, 0.21137213363545015, 0.14492259069811553, 0.19669732108013704, 0.11535138997714967, 0.11159459390910342, 0.11167173273861408, 0.09307823202107102, 0.06787660386180505, 0.1227203152666334, 0.1502587809227407, 0.12957093946170062, 0.14584318036213517, 0.10250959312543273, 0.11062128949561156, 0.16475963406264782, 0.18082187685649842, 0.08747812666115351, 0.1533511618617922, 0.11342645186232403, 0.17086255189497024, 0.1293375637033023, 0.11040511672035791, 0.14706800604471937, 0.18729292962234467, 0.11031576214008965, 0.16322703973855823, 0.1332003384595737, 0.16690286749508232, 0.24842865066602826, 0.15239195083267987, 0.09510595016763546, 0.1048783578153234, 0.10353394245612435, 0.14149671827908605, 0.23323911416810006, 0.2661398268537596, 0.11920474687940441, 0.12614998006029055, 0.16129894007463008, 0.18809436005540192, 0.16481738799484447, 0.12887740245787427, 0.07489817435271107, 0.07754568970995024, 0.13627921231091022, 0.0952074165979866, 0.21220305701717734, 0.11295034186332487, 0.10515114161535166, 0.12671150383539498, 0.07887891348218545, 0.17301543324720114, 0.08733379378099926, 0.0957700313301757, 0.18546620733104646, 0.2084539644420147, 0.2838545653503388, 0.15980990981915966, 0.10870775819057599, 0.15405777550768107, 0.16024762851884589, 0.10208336287178099, 0.12932701036334038, 0.1581393353990279, 0.13236240920377895, 0.13360705022932962, 0.09630347223719582, 0.11181758702150546, 0.1429679963621311, 0.13206801406340674, 0.09940363088389859, 0.09979520284105092, 0.1449931095703505, 0.150718838267494, 0.14592069026548415, 0.08839054527925327, 0.13405495119513944, 0.1609688624739647, 0.13007298752199858, 0.16127715061884373, 0.16746105160564184, 0.1655993890017271, 0.20854569389484823, 0.13893532915972173, 0.12289779988350347, 0.14099547173827887, 0.15657781215850264, 0.10602873866446316, 0.10932022298220545, 0.09655867455876432, 0.14587611687602475, 0.06374081523972563, 0.07269036665093154, 0.10874459097976796, 0.14905054966220632, 0.16213004157179967, 0.13349768734769896, 0.10312472964869812, 0.19934355252189562, 0.16825167636852711, 0.19906840869225562, 0.10538243936025538, 0.09698641137219965, 0.2794139989418909, 0.10722757433541119, 0.1344642901676707, 0.10513696659472771, 0.06986289532505907, 0.09837100660661235, 0.09247145950212143, 0.28402647643815726, 0.09888902568491176, 0.13577360194176435, 0.1786370386253111, 0.11401585812564008, 0.1020460922154598, 0.07480717220460065, 0.17682863253867254, 0.13896565331378952, 0.1274428458418697, 0.11634168957243674, 0.12944078160217032, 0.14447151334024966, 0.10332459001801908, 0.12076655213604681, 0.17258403764571995, 0.1373878473532386, 0.10493708396097645, 0.30627342173829675, 0.12326897762250155, 0.11823052962427028, 0.10444181913044304, 0.16848606144776568, 0.18521461926866323, 0.12901990965474397], [0.0028772047289749025, 0.031137425467022695, 0.023666874185437337, 0.056775929988361895, 0.029013962848694064, 0.018953818980662618, 0.06751857697963715, 0.016328017009072937, 0.03589803192880936, 0.018428675284667406, 0.019359653160790913, 0.021620949300995562, 0.098793140205089, 0.07363100172369741, 0.05720482084143441, 0.025033266392711084, 0.06016691404511221, 0.0419901886198204, 0.08080785919446498, 0.005472700404425268, 0.040441092642140575, 0.02367244214838138, 0.12340581481112167, 0.050202620404888876, 0.04416265153849963, 0.0909157695423346, 0.049870650327648036, 0.06314346799626946, 0.05697218351997435, 0.01808376400731504, 0.018527598003856838, 0.04416999508976005, 0.01751276671711821, 0.014674815338366898, 0.02066433949948987, 0.06601927540032193, 0.10459067168994807, 0.057341880674357526, 0.07714896724792197, 0.017023659856931772, 0.015734658809378743, 0.012897047890874092, 0.07281486934516579, 0.10249035665765405, 0.09280705868150108, 0.026360816445958335, 0.03350164079165552, 0.007627376826349064, 0.01849052401666995, 0.04703708225861192, 0.025452904519625008, 0.03007601699209772, 0.08169154927600175, 0.009224759251083015, 0.04610724914527964, 0.010485430666449247, 0.06121175778389443, 0.037234480332699604, 0.06387477289536037, 0.020495964745350648, 0.047169407189358026, 0.04730252250737976, 0.012728005203825887, 0.039239236430148594, 0.16255112132057548, 0.05886107923288364, 0.04738344629004132, 0.018690651559154503, 0.02515639425837435, 0.06703880077111535, 0.056939480782602914, 0.03778302394493949, 0.025868945085676387, 0.032313210031134076, 0.028076899361622054, 0.01860556803876534, 0.00976197954514646, 0.023147400497691706, 0.05041016200266313, 0.03220901249733288, 0.028293766044953372, 0.03974563347583171, 0.04064749133249279, 0.011195517563464819, 0.021677736585843377, 0.019811044076050166, 0.03782919295190368, 0.047321183810709044, 0.014234422123990953, 0.04843953356612474, 0.035646477263071574, 0.02663836297870148, 0.044947814094484784, 0.04822189133847132, 0.0559273472026689, 0.026353079556429293, 0.04478901675611269, 0.04817739216377959, 0.02683979855646612, 0.025928029317583423, 0.04030450407299213, 0.029035880324954633, 0.0108968736276438, 0.018559612399258185, 0.06199176983500365, 0.08618496402050368, 0.007912234905234072, 0.009859770489129005, 0.06490641011623666, 0.07250903028761968, 0.05870199987839442, 0.02983915685035754, 0.03171430427755695, 0.01821698693674989, 0.05474423764098901, 0.029307513796084095, 0.0339187871577451, 0.029103799824952148, 0.009380389474245021, 0.07984682248206809, 0.06927622758666985, 0.019892108866770286, 0.06902914436068386, 0.043657033747876994, 0.07157404295867309, 0.0017303619529229763, 0.0509075605077669, 0.036271424978622235, 0.025805072145885788, 0.02856382059690077, 0.027420076403359417, 0.027587324948399328, 0.01646935532335192, 0.024764978152234107, 0.013800697106489679, 0.0756404481944628, 0.015831939526833594, 0.05230382601439487, 0.030801609209447633, 0.046221269003581256, 0.012973929751751712, 0.0038427214622061, 0.01008005940093426, 0.03379711204615887, 0.0376764329848811, 0.05216246543568559, 0.04331383868702687, 0.012254429639142472, 0.016539584757992998, 0.10024754927144386, 0.012849389950133627, 0.006784444567529135, 0.03462015381956007, 0.044673371594399214, 0.04587700525007676, 0.03111235571850557, 0.08914749138057232, 0.019421004653850105, 0.017318763748335186, 0.05994737191940658, 0.05187679795199074, 0.05858526747033466, 0.005968865089016617, 0.03872423789289314, 0.056095005784300156, 0.025703885876282584, 0.03178840772307012, 0.06443188089178875, 0.08476827832055278, 0.028820980332966428, 0.0327771784941433, 0.06158407843031455, 0.009704082749522058, 0.07752213394269347, 0.026861135302169714, 0.02802637951390352, 0.041861388890538365, 0.0623747959616594, 0.005285897195790312, 0.053427155580720864, 0.03090814450843027, 0.028112450090702623, 0.01189890286696027, 0.06345882138703018, 0.05018228926928714, 0.046302356058731675, 0.05290166307531763, 0.038781732073402964, 0.009651971922721714, 0.03605175297707319, 0.03348713551531546, 0.02252126349048922, 0.017147281250800006, 0.07447222611517645, 0.09529630362521857, 0.03458494633377995, 0.045198812149465084, 0.023413670096488204, 0.06452500558225438, 0.03839742945274338, 0.10309600111213513, 0.10570612706942484, 0.04971628361090552, 0.025763552694115788, 0.00918807674679556, 0.056613640845171176, 0.046377799080801196, 0.03679952984384727, 0.02757182333880337, 0.03511639457428828, 0.03781559309572913, 0.025656585094111506, 0.013633642447530292, 0.03888539897161536, 0.039384727060678415, 0.03546435051248409, 0.0019520406522133271, 0.038589916584896855, 0.10861861883313395, 0.026093478154507466, 0.02022004537138855, 0.03959878100431524, 0.038101460959296674, 0.0394405031693168, 0.027870704761880916, 0.00802425189249334, 0.019680800869537052, 0.05035457885242067, 0.060628110586549155, 0.03514471492962912, 0.05045132522354834, 0.018991573888342828, 0.04474799083254766, 0.03345517492562067, 0.04678009878261946, 0.0435197920887731, 0.014898806639394024, 0.027493782799865585, 0.015353528870036826, 0.02893594642955577, 0.08720027399249375, 0.016492046488565393, 0.0073336282821401255, 0.0019661166425066767, 0.021265395625960082, 0.0021528753222810337, 0.02801935508614406, 0.06538868736242875, 0.01942104361660313, 0.0696215637435671, 0.021852052232134156, 0.01727061691781273, 0.10156286502024159, 0.05564285602304153, 0.030636947049060836, 0.009337759584013838, 0.05778240469226148, 0.04125102066609543, 0.01364325697068125, 0.003715039129019715, 0.06652028445387259, 0.04345948516856879, 0.014699966723128455, 0.03178304570610635, 0.0234147777518956, 0.03922328025510069, 0.03257979318732396, 0.03356773275299929, 0.06354368597385474, 0.07832499672076665, 0.03465363581199199, 0.03153875295538455, 0.03280086784798186, 0.04236825719999615, 0.038881929431227036, 0.036162128890282474, 0.026216220103378873, 0.07618116957019083, 0.04607487666362431, 0.017481054746895097, 0.07664939053938724, 0.03542473466950469, 0.08783129247603938, 0.06897992512676865, 0.06134793075034395, 0.07500992694986053, 0.03357663481438067, 0.050267743863514625, 0.029122240339347627, 0.07016829651547596, 0.01670833800744731, 0.009427873010281473, 0.058390750564285554, 0.08338328974787146, 0.05455528684251476, 0.047042451697052456, 0.0031023992369227926, 0.020244608604116365, 0.018804285500664264, 0.05241000137175433, 0.032177460088860244, 0.014286907735368004, 0.056903093282016926, 0.028940792653884273, 0.03231036760553252, 0.013168574678275036, 0.010786737984744832, 0.06243053125217557, 0.02874323479773011, 0.02747780250501819, 0.0066688787228486035, 0.03423129812290426, 0.01565659600601066, 0.051855427809641697, 0.06800964867579751, 0.052161975618219, 0.03023307399416808, 0.017434529509046115, 0.007271027661772678, 0.029954609053675085, 0.037900190509390086, 0.06282432965235785, 0.01841505873017013, 0.07076906505972147, 0.013985446421429515, 0.045842120598535985, 0.02907731628511101, 0.015570621908409521, 0.029723840088990983, 0.0378705751063535, 0.027481698780320585, 0.01618393089302117, 0.027936594487982802, 0.0910196999029722, 0.05003359627153259, 0.03609384017181583, 0.03470393116003834, 0.07263687264639884, 0.03439470790908672, 0.025594786457077134, 0.040870135635486804, 0.028602970742213074, 0.03840987898001913, 0.0217283473466523, 0.025475940783508122, 0.03704172973812092, 0.021735896843892988, 0.025720710364112165, 0.03721666136698332, 0.06621941778576002, 0.04559229884762317, 0.018802578561007977, 0.10269849939504638, 0.10263447431498207, 0.1479869184549898, 0.25758485309779644, 0.1013813802273944, 0.08553640116588213, 0.16693351819412783, 0.14128718030406162, 0.11633420130237937, 0.15631417161785066, 0.13723407435463741, 0.1282810274278745, 0.23109340196242556, 0.23234813619637862, 0.12435827229637653, 0.11902410071343184, 0.1496052902075462, 0.14364081260282546, 0.2011051884619519, 0.09451533420360647, 0.20745533052831888, 0.10087009984999895, 0.1576838645269163, 0.12124322616728023, 0.19906074972823262, 0.3384041413664818, 0.14970748394262046, 0.20403248607181013, 0.1343369227834046, 0.1357516788993962, 0.10017878186772577, 0.19862356537487358, 0.1550305975251831, 0.08964471548097208, 0.15148330974625424, 0.19644231913844123, 0.22971091442741454, 0.17221901973243803, 0.1484381887712516, 0.0885161834594328, 0.08937035832786933, 0.07942138632643037, 0.23483137716539204, 0.13919258723035455, 0.1283915332169272, 0.12155809716205113, 0.11523396737175062, 0.14150825125398114, 0.12044143208186142, 0.17966322106076404, 0.09693563362816349, 0.20569240325130522, 0.1725215933402069, 0.11380214185919613, 0.14304963260656223, 0.1317076271516271, 0.2862755995010957, 0.13060158962616697, 0.13370865024626255, 0.07854230498196557, 0.14372112782439217, 0.08072992626694031, 0.12765104795107618, 0.08945288514951244, 0.1850324813858606, 0.17667496344074607, 0.1372931493096985, 0.13339371245820075, 0.11017797500244342, 0.13275418896228075, 0.21761010750196874, 0.14136084588244557, 0.17323463398497552, 0.16589739097980782, 0.10095670848386362, 0.10751567606348544, 0.1576664240565151, 0.10544942560954951, 0.08243046861025505, 0.1641210456728004, 0.11631614484940656, 0.20936668734066188, 0.10094332756125368, 0.07055877751554362, 0.08999561032396741, 0.13450488564558327, 0.11627315223449841, 0.13753712293691933, 0.12053693906636909, 0.11434051804826595, 0.11241065207286738, 0.1417487664730288, 0.1494363773963414, 0.17238049622392282, 0.15087071136804298, 0.06836870714323595, 0.2053797512780875, 0.12327783886576071, 0.11929621658055112, 0.12299441266804934, 0.1213978006853722, 0.17769473372027278, 0.1645194602315314, 0.13091247528791428, 0.10934648758848198, 0.15906391781754792, 0.09213623881805688, 0.09736126274219714, 0.16864278819411993, 0.2460625651292503, 0.16870655352249742, 0.2125234273262322, 0.11788275922299363, 0.13350758759770542, 0.16642704693367705, 0.1603946479735896, 0.19978343829279765, 0.19383687613299116, 0.14717561745783314, 0.15791860583703965, 0.11718061330611818, 0.10852716397494078, 0.2012294388259761, 0.10737647884525359, 0.22895674395840615, 0.11284462292678654, 0.1567122299456969, 0.1019208028446883, 0.14325848780572414, 0.16227210348006338, 0.09884143917588517, 0.13807614479446784, 0.1039845374180004, 0.11141638198751025, 0.10428109220811166, 0.15974105335772038, 0.1188863358402159, 0.12579786067362875, 0.19845671573420987, 0.18156454403651878, 0.0709847777034156, 0.13511748402379453, 0.07949013146571815, 0.1202589602326043, 0.11677270667860284, 0.13512532110325992, 0.11499875108711421, 0.15736836270662025, 0.1221133943181485, 0.12071317687514238, 0.05313188841682859, 0.06935828685527667, 0.2104886810411699, 0.11198795444215648, 0.16523665690328926, 0.14382106543052942, 0.15694858913775533, 0.23697789089055732, 0.09429245241335593, 0.08423721228609793, 0.1134512470162008, 0.23058175051119179, 0.10342466121073812, 0.12922383699333295, 0.09830348601099104, 0.15530180797213688, 0.0972041575005278, 0.17529955599457026, 0.1686770308879204, 0.1618721304112114, 0.10962205444229767, 0.10367098002461717, 0.1471346360631287, 0.21470755309564993, 0.21108293352881446, 0.12147556291893125], [0.01722969489492243, 0.021110065972607117, 0.03655705164419487, 0.03600691612518858, 0.01924897667777259, 0.006637459437115467, 0.04444502388651017, 0.029226113183540292, 0.021540689740504604, 0.029760964171146043, 0.010191944656980922, 0.03098777509876527, 0.07341589021962136, 0.05917913775192574, 0.03787831199588254, 0.0720249347796198, 0.08828055157209747, 0.014286614587035729, 0.022775536272092722, 0.04851646088354755, 0.034634395633474924, 0.0353920430643484, 0.0021439340662254835, 0.0850995433575008, 0.06791598963900469, 0.09148142707999796, 0.07685262768063694, 0.007541961194874602, 0.06240871953195892, 0.029721435530518647, 0.009754557140695397, 0.014628095286752796, 0.024832450508256443, 0.06469916537753306, 0.08590873665525578, 0.03632673353422433, 0.02810099504131358, 0.007904284648247994, 0.04751240929181222, 0.021710305736633018, 0.04764090474054683, 0.0606494139356073, 0.03698095155414194, 0.011614936756814132, 0.04365693726867903, 0.03821742153377272, 0.01973814290977316, 0.033293249434791505, 0.029610913043143228, 0.002230007889920671, 0.014598374127672287, 0.03360974573297426, 0.03340584436955396, 0.06979986472288147, 0.012870121845480753, 0.0220899829218979, 0.020049130616826005, 0.043426852935226634, 0.027648338764265645, 0.026205733556707855, 0.016035659064073116, 0.06695117539493367, 0.0403992355131777, 0.013817536437272793, 0.022365041404555086, 0.04543784678389784, 0.016269157276838087, 0.013243148459878284, 0.0319670166936703, 0.06240310147404671, 0.025555450774845667, 0.026813118347490672, 0.03531161280989181, 0.03655821310530882, 0.026253963878843933, 0.0857701628410723, 0.04819938199943863, 0.030365569618879817, 0.0737790898710955, 0.07326167935389094, 0.06499122275272384, 0.040862242894945666, 0.01294973109907005, 0.012085959333489882, 0.04416302632307634, 0.05627399696095381, 0.02186175395763712, 0.02982335281558335, 0.06814284934080206, 0.006927636859472841, 0.09003382350783795, 0.03898325485351961, 0.021972615977574605, 0.04987438704119995, 0.04385110536532011, 0.03041039719391847, 0.03399228946364019, 0.06971052498556674, 0.08296284824609756, 0.044905400354764424, 0.06294948543654755, 0.026807066133187618, 0.019189231934433337, 0.010647918334143469, 0.04840097528358456, 0.03411056553886738, 0.05829641246236861, 0.07420339796226472, 0.07156589417718351, 0.038603538705501705, 0.01827072770538507, 0.022058256108721253, 0.035849495470756665, 0.04205813223961741, 0.053763912510476075, 0.11813849589088932, 0.023949222413648386, 0.023474804511351977, 0.07016209216089919, 0.013421915136859752, 0.024898711308196653, 0.031168239438557066, 0.06058694365492556, 0.05676369939465076, 0.05284303711960092, 0.009480101653025486, 0.029210876891738735, 0.06362691783579066, 0.04988917433365714, 0.09413887979462743, 0.03813046409050003, 0.04429820110090077, 0.03595544818381313, 0.026759130814753007, 0.01641732334974222, 0.02077020315482514, 0.09633956287871115, 0.060329314510454424, 0.05666170232871082, 0.01657275133766234, 0.028996832224947866, 0.06035360129317269, 0.018185556982643902, 0.056646540251676925, 0.02206254572229227, 0.025773681154532824, 0.03671883241622709, 0.0902439997298643, 0.02958760775072733, 0.032932450631051324, 0.04635964614863042, 0.028036322437401395, 0.05977457396511454, 0.009206331724271877, 0.012826570764445933, 0.04384501233289484, 0.01494542835644097, 0.022279098848230205, 0.031200355879263952, 0.026030660919786897, 0.06391221424564719, 0.0708003094769083, 0.052102188201388344, 0.0547733224084368, 0.056992993340827525, 0.03250478061090689, 0.04405261701322161, 0.027514887624420226, 0.05085103854071349, 0.0244281321647577, 0.03645464268629439, 0.024731171470193658, 0.05754985271778423, 0.025923442844941746, 0.06511120576760732, 0.022688866411044728, 0.06717054682667367, 0.04017753373773303, 0.050307897763559595, 0.03594757028622553, 0.07819638252840377, 0.012701573614322115, 0.024163280068023596, 0.05069486469437834, 0.030081391996645834, 0.0519016598991584, 0.05214778575464152, 0.05728523254219908, 0.07633693152456544, 0.014104820875218138, 0.054566341132158414, 0.06426687919883989, 0.04877027538896073, 0.026893730428128038, 0.018826386658474803, 0.01697131803666707, 0.007623196679560351, 0.048570407598163, 0.1173323231341783, 0.07631618849700317, 0.018464235290593933, 0.05027780367527157, 0.04408354972838424, 0.03351952283992432, 0.08289006582344882, 0.028686046753136907, 0.003974137725890614, 0.043933851120527834, 0.04196278110612184, 0.05861622987140436, 0.0753059696580749, 0.02225284722953802, 0.0669750725501217, 0.027942483429796994, 0.08112587689538486, 0.043007895728806034, 0.010173079263040563, 0.02794333875499433, 0.03651898688985966, 0.03516521675919648, 0.03641346833319403, 0.016365163355658296, 0.01626360601221677, 0.015110013519006316, 0.061095403871149756, 0.023018157335172873, 0.0034011419711532653, 0.024963690048025455, 0.020426189876161516, 0.07636729278601706, 0.011521143205754925, 0.030215086189855356, 0.011750208013836527, 0.05378514535550494, 0.007443929516739445, 0.07503231754526496, 0.031549862906103954, 0.03689915574796032, 0.013772129987046355, 0.021767942780570593, 0.04570249293465167, 0.055515870844828896, 0.023943463347677607, 0.04903065419057384, 0.018962489120895043, 0.07341267672018148, 0.0239784110817709, 0.018157698614231776, 0.014144356009637704, 0.044024511880706996, 0.04711470719485078, 0.005863230107934214, 0.013697062677238137, 0.11745903000701219, 0.07369590253802016, 0.07658923204871826, 0.02801208018354373, 0.05770141782704741, 0.052714615885633975, 0.016931524078245275, 0.011587803837755928, 0.03762593725696206, 0.07955486900755204, 0.026068035476782825, 0.06571889112819918, 0.020660777190641966, 0.053411032422445714, 0.022959587040531915, 0.049976421214523725, 0.05900653646676801, 0.013252828848635545, 0.05056409827375319, 0.06392645605956204, 0.045977558838785626, 0.042937792459269986, 0.0633988410118036, 0.03579637996153906, 0.060725528601324186, 0.02300441647093976, 0.011583345385588473, 0.034487543161958456, 0.011847045298054582, 0.04916940983093809, 0.016636436885164585, 0.01991142882616259, 0.027611446603259537, 0.013515052814909723, 0.017462688447267283, 0.052541161130648106, 0.028668982922681607, 0.02909301641921047, 0.011557043671928113, 0.027118619727843907, 0.03170654512359761, 0.024458220686938148, 0.01340022865406354, 0.025541793402226176, 0.06758925170288421, 0.07584580045659095, 0.11533611657796428, 0.0601479484612355, 0.04239428060827777, 0.04806777695193887, 0.0361748493014602, 0.020915805107506458, 0.0526801505475305, 0.03558235941454768, 0.03479021695966367, 0.031801250588614494, 0.024326027487404644, 0.016503228798683267, 0.025235959910787642, 0.033119494109996594, 0.02723068402701756, 0.006211260260897689, 0.05872049790923484, 0.01608665203093551, 0.060590123757719994, 0.04289372001949232, 0.02903775981394574, 0.01909385853650747, 0.025773950183065608, 0.022111642501840834, 0.06553203318617307, 0.028353145280561876, 0.0704951531952247, 0.04342680098488927, 0.029831039610144217, 0.006387380253727315, 0.05243080006039236, 0.03487996116746217, 0.054154720055521466, 0.00808073675216292, 0.03644249743956607, 0.05243027684628032, 0.029247906350065023, 0.04151138462475501, 0.04195800167508423, 0.055609544724575244, 0.041840423218673095, 0.04689743604103569, 0.05680805385054555, 0.04532614242634736, 0.020937893277732655, 0.023900314881757367, 0.011978686525253579, 0.017539235414005816, 0.040371961586060934, 0.08938280414440669, 0.09723483788548037, 0.008327007326442981, 0.06955392440431751, 0.19241996778873727, 0.12250221290742047, 0.12866403500083834, 0.09284947242122144, 0.14454853342613205, 0.09572980692610145, 0.10899404165684246, 0.21855388185940683, 0.15962363075232133, 0.13237949344329536, 0.10704824919230305, 0.14116218779236078, 0.1913464957033284, 0.13787848118226975, 0.11661200944217853, 0.1775266372715123, 0.15043938998132944, 0.08833465413772501, 0.1135204522870481, 0.10390952855232172, 0.1675460720434785, 0.153013959643431, 0.1928896433673799, 0.16773039184045047, 0.13545526511734352, 0.13505244220141321, 0.17698427574941888, 0.11758345106500201, 0.20406763418577611, 0.14251061074901372, 0.10463959406479262, 0.05731966819439549, 0.10495428694412112, 0.12423045962350443, 0.18744984932709485, 0.06327370007056743, 0.18936748470878229, 0.10548290389124304, 0.2002926851855591, 0.1060659351060167, 0.10349817093810998, 0.11397486930945888, 0.15214385086437687, 0.07305611186893657, 0.12250713334651664, 0.157211413315963, 0.10909968637861311, 0.11811024975031614, 0.18205044296337292, 0.16251230699708685, 0.09392610605573282, 0.10386761947302148, 0.15284439374227077, 0.15232028905302286, 0.08522676973370835, 0.1456305550527759, 0.09019821663969196, 0.14491012261714786, 0.10284410876920447, 0.12112290918594226, 0.12686345115071163, 0.1973662039381452, 0.1326849911129102, 0.1284251525066793, 0.1678455137880519, 0.18776907672872767, 0.1478343625785783, 0.11044016093364917, 0.07974408697918989, 0.15525741269811988, 0.09112775660469197, 0.09850943941273727, 0.09179525164654478, 0.16892573941731825, 0.08863969909725711, 0.15721892385045066, 0.11768354452215135, 0.1940762039157562, 0.149669871898368, 0.21768194739706814, 0.1506104550207965, 0.14240675460314378, 0.09792816708795726, 0.08408469351707026, 0.12812591856345534, 0.10886670395848341, 0.12434593038051389, 0.1278833847027272, 0.19668682711198926, 0.08578111694077961, 0.17030326940584928, 0.091679187171394, 0.12216109957080334, 0.172718811663799, 0.13171221362426877, 0.20772060379385948, 0.214323150285054, 0.1378294252208434, 0.1965575004578568, 0.15082444588188082, 0.15287856222130358, 0.19445214624283835, 0.13204490358475596, 0.13929196080425754, 0.11181369816767983, 0.09672458909335546, 0.21131553745362908, 0.1958812851808034, 0.2228374543483369, 0.14636204548878595, 0.09133867497439496, 0.10841453564353287, 0.08976584140327759, 0.19001419219421223, 0.07681877832510509, 0.10012893922976218, 0.09274702635593712, 0.16440886538475752, 0.23435445822542533, 0.11428003301261924, 0.24820038088364527, 0.19361783866770566, 0.12381703883875161, 0.2371113290428184, 0.19724426907487214, 0.1034019143844489, 0.10011290883994661, 0.14948767464375123, 0.1119018578901887, 0.18757772137178108, 0.10595656480290927, 0.10503690282348543, 0.15194771607639268, 0.1048447607900016, 0.07918889372376725, 0.1608205516822636, 0.24517707905033603, 0.17532507103169337, 0.14034791820449755, 0.07602573416079395, 0.15335601550759748, 0.1860039823804982, 0.10365378446294926, 0.15357404365204275, 0.12940925516886637, 0.07853348826756701, 0.07717207772657275, 0.1614566019270569, 0.09871214962913655, 0.10728703520726413, 0.19639979407656938, 0.0779526834958233, 0.1920259912731126, 0.19664743391331285, 0.20679854467744008, 0.09774078222108074, 0.17755694658262655, 0.10580383823253214, 0.081434320891276, 0.05434702165075578, 0.14796103234402835, 0.20118899177759886, 0.10779801872558892, 0.16363771457690746, 0.15579641971271485, 0.1420102993142791, 0.12233920017024502, 0.13258630031486973, 0.12869113823398948, 0.1797203515889123, 0.16449918475700542, 0.19563602021662518, 0.1368735686992295, 0.13856649660738185, 0.13406243204372004, 0.12463233259040862], [0.08650733070680872, 0.027093132521258667, 0.13343067141249776, 0.0488598266383633, 0.04283625181415118, 0.03508881636662409, 0.026120740949409083, 0.017048013432940934, 0.022311124375846703, 0.03011196848092368, 0.021846098352398258, 0.029280594244482927, 0.05332308792276308, 0.019191100291209295, 0.02470124622050207, 0.04120325233088806, 0.012447881563275587, 0.018484870706743095, 0.0651836022734642, 0.040982058926601894, 0.013409795865300111, 0.08353525190614164, 0.02014556714129867, 0.028621960445889272, 0.0427532314643031, 0.05102441908093169, 0.08712115362868644, 0.023926887479319703, 0.03153378056595102, 0.03035431680473266, 0.06087896763347089, 0.0211097153078299, 0.035544216734706424, 0.030799431006016675, 0.02606155838293489, 0.0022487021260531037, 0.05742935391026549, 0.016528970190847758, 0.059526151162572205, 0.03660051923361607, 0.03299512500234414, 0.06266599986702204, 0.012003616193396738, 0.053298548809834756, 0.09994800362619571, 0.05937145419011358, 0.021790058781334665, 0.0155149868078297, 0.03163241570291575, 0.028186540548631456, 0.02002876608457882, 0.05131242432980798, 0.026367807477072347, 0.0725279476318974, 0.020374927880766336, 0.004804691425306373, 0.017563961919222493, 0.01952153783349786, 0.019580141524784267, 0.06117511795309838, 0.05160406981303822, 0.004935957404086366, 0.07160116103477776, 0.009302234830101952, 0.056228870671475306, 0.02014959329244448, 0.028809785035264213, 0.037572684450424276, 0.022417828513425775, 0.03962657443480566, 0.02369166748394491, 0.02461494928866159, 0.06217142152308952, 0.007801958254276542, 0.023568522919958923, 0.12194834809633903, 0.024936265836004168, 0.08031725505134091, 0.04180291507509537, 0.060775712627219036, 0.02177400983782718, 0.037660873858840205, 0.015129196181078441, 0.028870678252133075, 0.06252651321119629, 0.04900435989839025, 0.04175621914328076, 0.007535643662777147, 0.07503631029976532, 0.03108844000962563, 0.05268836612231098, 0.04671992173825856, 0.06008863230817951, 0.05710723213269375, 0.025308534532086924, 0.0189501490604016, 0.026008559761976358, 0.03527331427903846, 0.01295421923714457, 0.024068170132522937, 0.018598306123749353, 0.02238078050140757, 0.06092930008890107, 0.024919689967646264, 0.06113496776379179, 0.015594854885421228, 0.02344676060602069, 0.03875376423820853, 0.012648085175896995, 0.005307473284119624, 0.06856974010588601, 0.022705510928062722, 0.07884783975896426, 0.02055712142464472, 0.026302424266759772, 0.02916163910413161, 0.03240976344386581, 0.045672795895370655, 0.07055070294882171, 0.06388405716279522, 0.02278464613482356, 0.036746384648722596, 0.02847687057510484, 0.022931572821107693, 0.032227324991254136, 0.07152955862693489, 0.02779991686111316, 0.11690915052895434, 0.038877027545822784, 0.021314054538379423, 0.05028561849030666, 0.03814547773799859, 0.04671398455684539, 0.02966462227050215, 0.047300207006628625, 0.15123427467187867, 0.05056347858044319, 0.015039189438539324, 0.018347256118431687, 0.06354922981699929, 0.07185456735896878, 0.027164818420715164, 0.029944645721116103, 0.03187865288055036, 0.06814163964008912, 0.029813513792760205, 0.025974166783271357, 0.031866433419054374, 0.008733576232771156, 0.022660082213405985, 0.0337818794650957, 0.024239107151515782, 0.03368752652022522, 0.02283911977428943, 0.017808579359552823, 0.05218403224716894, 0.014193225506460294, 0.03216039440303575, 0.017143301483883988, 0.00982706496870378, 0.03589947540604044, 0.04707480562501587, 0.04702762729721144, 0.032761277980171144, 0.06385693908669055, 0.02786770277452888, 0.02154592002625577, 0.039008443345665, 0.0742400081071537, 0.062314941751537845, 0.03214849035430234, 0.022432907098846044, 0.022909907675057184, 0.05458195591927506, 0.03671653917990625, 0.028849619811808225, 0.0795859946811106, 0.03779211525397841, 0.09012173832161352, 0.03958339999371674, 0.04559690387395676, 0.03446924180025235, 0.01609888448001584, 0.06065208937798161, 0.00978865047727595, 0.05835464136907831, 0.02867286435503047, 0.038775056455051526, 0.08383911685086787, 0.04228205303661525, 0.03319793911941815, 0.0042899577420030255, 0.031017904439067934, 0.018215189084003214, 0.06429589717299677, 0.036643504427047446, 0.055717234063195065, 0.020687780233856756, 0.05386108190577943, 0.06664026746875606, 0.01812909253203543, 0.031442748731933534, 0.0566139228612883, 0.04048035596497357, 0.046241614982136525, 0.03220386199245695, 0.021857551546418108, 0.013088526629871922, 0.04364031687146053, 0.03314943976874929, 0.023421162077283952, 0.019267417192168068, 0.039156887723947875, 0.05777826350822579, 0.06691308837616816, 0.024601264085504226, 0.018528377258917317, 0.021525826377910562, 0.03474326498690061, 0.05037991577410139, 0.06647145113674924, 0.08362680324353278, 0.0663588747556787, 0.010861684695555596, 0.03379073699761648, 0.07915325579233468, 0.0563264296943089, 0.013483116345014423, 0.11159171437611803, 0.09737715954543091, 0.02112172882334562, 0.05394259569584392, 0.06740590411936864, 0.06411025635316037, 0.023553631726827007, 0.06032680605130736, 0.031748921755934134, 0.03146346578432713, 0.03060981041926425, 0.04887888870143797, 0.03467568501946516, 0.05721260968130082, 0.07795408615493216, 0.06785083649447188, 0.04335584424552508, 0.02382260459853569, 0.0013717015781367081, 0.023388401823467575, 0.058784541542991064, 0.016440326216979884, 0.02096646225254517, 0.036290349744376726, 0.04697213320469018, 0.05459026426251512, 0.056013146895566024, 0.03416820814891253, 0.06005960320180748, 0.06047031143680215, 0.017487363002146594, 0.06894672886119224, 0.08234974520746619, 0.08150060952175409, 0.051929787296103314, 0.01607993930520024, 0.010905232065852033, 0.004570426017380669, 0.08113273433991708, 0.04311887649237178, 0.045414740015985444, 0.0883945454552304, 0.05714239880035166, 0.043815719764097594, 0.01772970204910962, 0.09832596566411667, 0.023618181876372546, 0.029232530905574095, 0.039118811837397516, 0.0536922433093423, 0.009101130435738014, 0.033399688254576176, 0.0400874184560962, 0.039664368305238895, 0.02532900110963965, 0.019503149269439746, 0.021801315306220204, 0.05951953862677328, 0.01412684410752263, 0.02261969453684287, 0.005929912076680921, 0.055252226593438536, 0.05203952867304906, 0.0260758094736957, 0.027342393950675614, 0.036373110342537984, 0.0989530878723599, 0.07427368676871993, 0.028359331081446726, 0.04041457941639237, 0.048375816477346234, 0.021157893679628614, 0.02563988306064857, 0.050245434904354624, 0.02826816195010906, 0.032847801267053, 0.07923365265014581, 0.035362624330446124, 0.01143425441114232, 0.022731814497092273, 0.09266730485251173, 0.011913298676518025, 0.05927504549617879, 0.07899342686869204, 0.028725586525979452, 0.0166962558432715, 0.06427616346627474, 0.03266898820584174, 0.004873214384133462, 0.038437839393736795, 0.0172935307273292, 0.03466395537543576, 0.02755280951532768, 0.0323940744419815, 0.03431036282563582, 0.049035719348466955, 0.026870616238738876, 0.08239315342507325, 0.013555589848692762, 0.033572133688721806, 0.044629488402279094, 0.07050610729493201, 0.022437521402025595, 0.027253942935203668, 0.013456327596941264, 0.056933424857561477, 0.028350009706628043, 0.01978741038328735, 0.026533929813012946, 0.10451118025230244, 0.002924794021055277, 0.03155040096316952, 0.03303316749224905, 0.01838450822106097, 0.10003482006140985, 0.033457924582762644, 0.06071611445804592, 0.03177418446284719, 0.01096260100894142, 0.03396540887479205, 0.07344222161918879, 0.05863724749360699, 0.07801166939316317, 0.020110981204197742, 0.18531102425185964, 0.08220917501603253, 0.30821844236925244, 0.2269317940226756, 0.14924169721780345, 0.10083136716275476, 0.26746328396257013, 0.14156719262246042, 0.06338264734949917, 0.19985897408332676, 0.1468428978114389, 0.1811174297472462, 0.1995623970287852, 0.09434697800315917, 0.13292586256284267, 0.09195922175422311, 0.1269052637508139, 0.13180630310671404, 0.12782561592757702, 0.12363386194920167, 0.163342755404301, 0.18438014842104167, 0.23388202185742557, 0.1714006534893997, 0.18312253465410322, 0.1276836876058951, 0.2719464199617505, 0.079443865979556, 0.1163816690677777, 0.15398624731460586, 0.19372723123524338, 0.06876610495964997, 0.15550974290817976, 0.13409222185146064, 0.18376738677034155, 0.09857336059212685, 0.1908323506359011, 0.13476301945047453, 0.15164757671300322, 0.17881286825286224, 0.2269087577587925, 0.22381870716344565, 0.1005908296792768, 0.13385084574110806, 0.14550097606843337, 0.1795015367679298, 0.17143078468507156, 0.1736191555391997, 0.11083405581302941, 0.145157391380053, 0.12107134476536885, 0.12261493029654957, 0.2778611588291824, 0.20462713931920007, 0.07527031688368879, 0.0991439088829793, 0.1014097970619332, 0.1297053720918484, 0.11272928575635888, 0.09544071814161725, 0.18111376353772357, 0.09523102431558073, 0.08977886609500274, 0.12690582778304815, 0.19193633983377367, 0.22364826552802697, 0.16162492102012038, 0.20272177906008437, 0.16210014786338434, 0.14073033205932006, 0.14344605820951983, 0.12384242028929293, 0.19909046532120556, 0.07738790169241838, 0.17227803531568497, 0.14032292267074808, 0.12605737487319857, 0.19541178771760315, 0.13392160210059956, 0.20927351812133566, 0.22358163550961763, 0.12210921602672897, 0.13551353855291381, 0.13852576754288748, 0.23380507598631084, 0.16483902902109548, 0.20025312871439382, 0.07661830939468928, 0.09802925502299331, 0.1519060370628722, 0.3107138694031164, 0.12219842217746191, 0.1332316719344817, 0.1874069680343382, 0.19710965832928196, 0.17031640541972592, 0.05896184433368035, 0.18731019197730348, 0.05253854877082631, 0.1343617995735258, 0.1499136080383323, 0.11143809722852893, 0.18497444543754682, 0.15958416333887726, 0.13530169992009178, 0.1129975424555596, 0.111785155168036, 0.14552922220900655, 0.09680236616986804, 0.11753602040698752, 0.14863435324514285, 0.07922899938421324, 0.14145070512313396, 0.15511708741541952, 0.11812668832135387, 0.12938201834913343, 0.12955701677128673, 0.12222178498632275, 0.19648436922580004, 0.14906282478477806, 0.126157401537057, 0.16816273739095777, 0.07665362078114413, 0.08040747794439085, 0.15024393796920776, 0.1896370475878939, 0.07307148916879669, 0.18052258354146034, 0.19553201564121991, 0.11346444240189157, 0.1346986900898628, 0.20803720399271697, 0.188024093513377, 0.0823802845843602, 0.18874308618251234, 0.2570912358351052, 0.21308878058334813, 0.12989512440981343, 0.1474370018695481, 0.14736513228854164, 0.14528996864100918, 0.2477787816314958, 0.11710861013852991, 0.19019794795894995, 0.11766200739657506, 0.14081878121942282, 0.10763198544736952, 0.10405694876681082, 0.11801945540355518, 0.12914712860947475, 0.09132794351899065, 0.10289384750649333, 0.06342344320728444, 0.25702975632157177, 0.13777594605926424, 0.12736615230096504, 0.08340805521584116, 0.11283182830084115, 0.1054583016957622, 0.07414377381792292, 0.14105426467722282, 0.15383403282612562, 0.11216189901460893, 0.09546971385134384, 0.16016918350942433, 0.10117510770214722, 0.19492127263220027, 0.10540819930611178, 0.18754015385638922, 0.15685999154811725, 0.05862127276486717, 0.11114778390037827, 0.1920158535358496, 0.18513044487917796, 0.12452065420802683, 0.1124719757353887], [0.02498016201570863, 0.0876360631082207, 0.019260255467088427, 0.013713376010855427, 0.010059577052743407, 0.10816483263624832, 0.030727810044481885, 0.015411488748213742, 0.06324870453681797, 0.05604724858130794, 0.05386041397287045, 0.03977914515417069, 0.05435059509181883, 0.04842577414819971, 0.017637707278481685, 0.0341655586817069, 0.0341728614148451, 0.06819670699769631, 0.031784177481313236, 0.04895963065791875, 0.04472394895856269, 0.053594680575770326, 0.05379561705922242, 0.04588153235090431, 0.08058718158281408, 0.01494148013080121, 0.028333302107057534, 0.04533021310635377, 0.05268484463158529, 0.02298261402756907, 0.014119628576736432, 0.047264194290619344, 0.05455233309476171, 0.061623148794751614, 0.0499233984737657, 0.02403162492555566, 0.013875109470973257, 0.026800924861163367, 0.05846889871463645, 0.07818126498023048, 0.03635408909758553, 0.020540450932458043, 0.0062870776037016185, 0.05622045100608375, 0.00897283907761448, 0.03462557891907636, 0.08479079508106224, 0.03813011157035362, 0.044653656441369094, 0.03695833831443451, 0.07216891142888926, 0.049604905798332766, 0.09814836230361834, 0.06649134811596014, 0.02121688514307607, 0.02584397923783399, 0.040811094077071175, 0.0530278207588708, 0.04776819419930689, 0.04699925128079485, 0.0243772950489074, 0.045754183520330116, 0.07271028589457273, 0.010049660104414215, 0.03280568067566492, 0.034004182380158454, 0.05708477103326004, 0.06771273023332469, 0.02089166304358514, 0.034313580035814084, 0.008696231361682294, 0.01990506862057373, 0.034834831167245284, 0.011773832429753384, 0.016705081834516022, 0.012680574545811396, 0.020807147266168613, 0.04029089308460243, 0.018513126124162227, 0.05322263081325218, 0.06832325801951811, 0.03612787877500523, 0.04323670727899298, 0.025575911786290817, 0.046794058580417186, 0.04842947375436779, 0.03650328304502182, 0.040579592241556384, 0.02445700727548683, 0.007174568409027415, 0.04309440417273436, 0.04593284073052928, 0.017574199846421834, 0.05059994029579684, 0.035059149013250135, 0.012143718831794104, 0.008302514597744448, 0.0028101653697376605, 0.030209783544705715, 0.052020448056282476, 0.015492902348341886, 0.03244786901632324, 0.013452205894282088, 0.06876194151118398, 0.06272845159401186, 0.08176111077773385, 0.08736294534173794, 0.017229078912350815, 0.05267146370897535, 0.05308202722517308, 0.010231990945612779, 0.0398575345025165, 0.04325798094214406, 0.07019318814855069, 0.050020348935504444, 0.03832246882666368, 0.01912942225317238, 0.07066946884151548, 0.0221376547779073, 0.013144740605639527, 0.01210904105391819, 0.02476965182722779, 0.0712029988062568, 0.07947231992147863, 0.030386394282686524, 0.02427813484246144, 0.011304071504127933, 0.019431333494139835, 0.04507654331973754, 0.02457357826642692, 0.01653354924201267, 0.047129435115493834, 0.039524581079604104, 0.07391345570795238, 0.05598268915491644, 0.04043016451760195, 0.017234839833690785, 0.035368546668905765, 0.014299128124548588, 0.08536577399354428, 0.003746140914699936, 0.015440952010976616, 0.024440108572889585, 0.013730061345995637, 0.03930967366613913, 0.016307504047290422, 0.06228668076801114, 0.06574830986210145, 0.009805394256545696, 0.07747246199869551, 0.029521150281652808, 0.07862921789637767, 0.030773561593377963, 0.04079632904904429, 0.015616918935847934, 0.017994778645515908, 0.08409135800320655, 0.029031548037892208, 0.008457041803922039, 0.013155980432202341, 0.05604486257652752, 0.020516010154096875, 0.007388915500996518, 0.013420259219856234, 0.008695694232301321, 0.032391287677455693, 0.018507211207179353, 0.0440194430120755, 0.023175138267106377, 0.009448574292036938, 0.045512124634115025, 0.03178765073243994, 0.028842519313911907, 0.04293645659345202, 0.04009922602563165, 0.06768344508600421, 0.09942295640939847, 0.0118768972606631, 0.044732954920618795, 0.029205874816398136, 0.08658503356855363, 0.05967830256849993, 0.021981026366120204, 0.03458405575656798, 0.05496999896422494, 0.07735322855296545, 0.07522958039771765, 0.05094306485261768, 0.09989013837184757, 0.033032429055310786, 0.01929761332576163, 0.03790554510487709, 0.023480307536374312, 0.005471764370668097, 0.006555095887961215, 0.03812254166405182, 0.06091501003538724, 0.04151715482294094, 0.044359706589602865, 0.06126783446234185, 0.014688307583128335, 0.052323440977488644, 0.05283025362587068, 0.0338164932327345, 0.05876783950952813, 0.04019996886199806, 0.08185784230590798, 0.0393462652573362, 0.05987127580738161, 0.04786238758242689, 0.061287208227440715, 0.06775236834073439, 0.07670966777368449, 0.05517359604709782, 0.012541478445200482, 0.028142113733338192, 0.0471363482211018, 0.028058254756615497, 0.039413429622072726, 0.02181754793127766, 0.053609182141372, 0.032456552144140005, 0.03974623090471141, 0.010419876762171043, 0.031704385473858565, 0.051031180046265945, 0.10341821936890483, 0.07331204149522819, 0.0017247621008209535, 0.045239908577059396, 0.006471602882811567, 0.026324829705117736, 0.050537173156044446, 0.11721902686986141, 0.03658387286122888, 0.0719020796532277, 0.01831596531701507, 0.021164918107388075, 0.08166041618096642, 0.028135221036791336, 0.029407315960270353, 0.12883008312201127, 0.029263161195558496, 0.042339651117799804, 0.0251838481563027, 0.05370358703657985, 0.07192147197201848, 0.07593643895233981, 0.008660001567477593, 0.02389642602793174, 0.06309772943495773, 0.029048233373032417, 0.018167613707191776, 0.060952781641390175, 0.04218834204948507, 0.04208953621855471, 0.04013844481960405, 0.05461993903736584, 0.00706290301422996, 0.05552545568207279, 0.14897192653734237, 0.06547802709974349, 0.0707578586298041, 0.01400259096044465, 0.014206259475031402, 0.025065650006581564, 0.07204172958154231, 0.01379191471642116, 0.03912902750016656, 0.04987135165720247, 0.02668877707037609, 0.029746642576355953, 0.032688569772290066, 0.008769973937887698, 0.01844711950980127, 0.03352086241648067, 0.03159995787427761, 0.04073089759913273, 0.018582875018182676, 0.05374024542106781, 0.04740439340821467, 0.04922846994304564, 0.018816254487319384, 0.008015850780793699, 0.06689739937428385, 0.03166438742482569, 0.026664312172215432, 0.060976389358984306, 0.049958082745433785, 0.018410349803161807, 0.02590053089079447, 0.01524628110928461, 0.019695276459970046, 0.06815331362304278, 0.03450748095929157, 0.02242362839751877, 0.0766582295182161, 0.054749863120377995, 0.05614328620140441, 0.06598567837500013, 0.06584006157936528, 0.04339043945947196, 0.02617554669996025, 0.06814942476921715, 0.09235453413566574, 0.04443783618626185, 0.021786676443298347, 0.03547446598531678, 0.05534131771128159, 0.00790526150012738, 0.016111224540509284, 0.04551969082967844, 0.07812967829522677, 0.04516117784078233, 0.0310575722323847, 0.014857198129902827, 0.04172793589532375, 0.037533654904109426, 0.07267057357239537, 0.027412441559135914, 0.06886606483021751, 0.02312089469342027, 0.04773287539137527, 0.0629043480148539, 0.037638954527210444, 0.08906652306905016, 0.02161447591788601, 0.09176920226309448, 0.049818332627182826, 0.03372166902408935, 0.032857916739885695, 0.06811933068092912, 0.10113448253832757, 0.047013782532303594, 0.04439442796865478, 0.017010638875945006, 0.011845710359921213, 0.01943185670825187, 0.02415399951132713, 0.007235278872030904, 0.0110056520679791, 0.01918744521390181, 0.060574746457859874, 0.04292503494070843, 0.008847409626469016, 0.022565662475244608, 0.046231688756961375, 0.03367353703652043, 0.01594007229869021, 0.03587854313082062, 0.0359989009302808, 0.10035329789388925, 0.18802585982484743, 0.2100028860149905, 0.1273188181221485, 0.09158941698842682, 0.21256066829664633, 0.1555446832207963, 0.048389932126156054, 0.07999714449397288, 0.1470950647490099, 0.2018999247229658, 0.12136911667766981, 0.19255637453170493, 0.17409815249266103, 0.12569235695991665, 0.09677311812993139, 0.24306590639753267, 0.1553487265482545, 0.12160770231275819, 0.1032472359656822, 0.11922796868020669, 0.1283776105265133, 0.1453659200342372, 0.21428154548630118, 0.2109990708413534, 0.18981220928253606, 0.13742479146458209, 0.17390933528076857, 0.16505233710631728, 0.08708216118975542, 0.10027684926171787, 0.1837900371174328, 0.19277343788417056, 0.13242270128102973, 0.1887766015715897, 0.16134729841724038, 0.20516167860478163, 0.16130361560499296, 0.1194654188293498, 0.17282471613725647, 0.2113719258341007, 0.1298968165065162, 0.12541984033305198, 0.12881316215498373, 0.07054555244394578, 0.12378485931549221, 0.07501450600102544, 0.26883311045821756, 0.09584520346834324, 0.13964921585284173, 0.13644886726979166, 0.1831553821102716, 0.14324493618914858, 0.16358282533474267, 0.14549410378094763, 0.05677437147824094, 0.10680200459319167, 0.175324002339039, 0.20984452654374763, 0.16187072033062577, 0.182109740562737, 0.2710119669791311, 0.09771079945494421, 0.21759729803306982, 0.11222809858736582, 0.10321838868549094, 0.2209431372466497, 0.23098920442862436, 0.1048920578614343, 0.13921413919888437, 0.1915509722311981, 0.17748825339367613, 0.1769714811234735, 0.1511358658899553, 0.16083322756458074, 0.1279975863872096, 0.09136507316725329, 0.0960114445479121, 0.21627106529194862, 0.1711368199903518, 0.11005573585862294, 0.1567413963493891, 0.06791733292629942, 0.09588807733962312, 0.11271021998254582, 0.2374295619665645, 0.09110876504564658, 0.08632839148049243, 0.14485572319244966, 0.14079999004025012, 0.19641055521788076, 0.27772133820690215, 0.15252340002916753, 0.09654380191932432, 0.17147259728517383, 0.14870016690110788, 0.1181301986798644, 0.1376518589677289, 0.08892104728147388, 0.10518662369577214, 0.11823743901913986, 0.15002540516434237, 0.09181832501781173, 0.15651498193619773, 0.20174091216176748, 0.12768294545821846, 0.2848935127258301, 0.21028554037911817, 0.10516033682506531, 0.14331711747217923, 0.14352016907650977, 0.08842138893669471, 0.10563356729107909, 0.2157445708871819, 0.12448967696400359, 0.1710907623055391, 0.13457003136863932, 0.12926400202559307, 0.14570160827133805, 0.12544452416477725, 0.10798896590131335, 0.2898130315588787, 0.1247224590042606, 0.13328316214028746, 0.12191250978503376, 0.11444156887591816, 0.11456734806415625, 0.14653817197540775, 0.19807516277069226, 0.10258756316034123, 0.12791373854270205, 0.09798170562135056, 0.15304741566069424, 0.1964647023123689, 0.10326794188586064, 0.15589690650813282, 0.27569898578803986, 0.15407163882628083, 0.12975055404240265, 0.19632793933851644, 0.23568293225253, 0.15516793937422335, 0.14130353723885491, 0.14534506568452343, 0.07974652864504606, 0.15128931234357879, 0.14823663630522788, 0.1860568084521219, 0.16622350551187992, 0.10173493195907213, 0.22923922020709142, 0.19399011478526518, 0.19650749454740435, 0.17622155573917553, 0.11554945434909314, 0.11707361045409925, 0.20982083718990907, 0.21758745715487748, 0.15342819679062814, 0.12416923244018108, 0.19556272571207955, 0.1493713355739601, 0.13864601030945778, 0.0895770316128619, 0.08170217683073133, 0.09740953202708624, 0.09503644061624072, 0.1061349622614216, 0.19691073306603357, 0.14553778659319505, 0.12663380097365007, 0.1667701714904979, 0.08485895392368548, 0.13352811540244147, 0.15909623092738912, 0.07991744525497779, 0.18936669803224504], [0.010229546496702824, 0.0715251502697356, 0.08665204950375482, 0.0708993268199265, 0.058880916840280406, 0.06057327329472173, 0.021043684573669452, 0.09562082253978588, 0.034243005502503365, 0.025731417699716985, 0.02145824455510592, 0.03727210721990559, 0.024008169348235242, 0.06341128682834096, 0.048072994250105694, 0.03621917036070954, 0.012126134570280556, 0.014743554911547108, 0.02072561863315059, 0.03513413561449852, 0.0497060197085375, 0.04265911229595076, 0.03131607525574509, 0.021495387190952897, 0.02988701238791691, 0.08727623280719854, 0.024586139115854166, 0.013106688838888658, 0.022860690296511166, 0.030866404267726466, 0.06648456488619559, 0.024215736921178177, 0.028245166504348163, 0.04638548401999287, 0.03744583656953182, 0.05658359128574375, 0.052390022756299004, 0.008737469725019764, 0.0482017568720039, 0.003340582952660043, 0.016121518128784373, 0.01827431784477085, 0.05412459999206476, 0.08739866490941495, 0.004419269553181948, 0.037734294528490864, 0.07888781183282845, 0.026444632749189623, 0.013482496651704423, 0.06399447389412671, 0.021186548001423944, 0.06050758951460011, 0.04045962406962644, 0.05734682337788399, 0.044120779566583224, 0.028144501593487803, 0.02598037855932489, 0.07875012117438018, 0.02234094758023275, 0.05028982646763325, 0.06674435368040577, 0.05888099105504807, 0.008625067748653237, 0.04936982681101654, 0.04578416628646664, 0.035977003863081336, 0.06652536816545762, 0.06598565611056983, 0.024531500348530244, 0.06849559213151224, 0.039012280249153264, 0.04195060988422483, 0.023571428428112995, 0.058845457024290226, 0.018524738879932556, 0.033209750399691984, 0.0525110633316217, 0.07345207734033465, 0.020574188965838403, 0.032645443570800126, 0.01969194050616352, 0.08300396322738379, 0.09752034209668636, 0.01001098122287658, 0.018323603871976957, 0.03407233009056654, 0.04266637421096675, 0.0373239833425032, 0.036745568286278285, 0.06068936374504119, 0.04456727045180742, 0.03653499130450655, 0.05748637311626226, 0.04485756151552778, 0.02655503649293678, 0.029989610593474936, 0.026105621545866597, 0.02621885472763097, 0.04267769938451238, 0.09918168419972062, 0.02690884797630133, 0.09613889356842265, 0.011764844093704596, 0.012025562427879777, 0.04871523029578384, 0.06913760924362577, 0.04654725737054832, 0.064443599403603, 0.06207044862094335, 0.07199876665254124, 0.057416217896388844, 0.03503831321722828, 0.06954895201488398, 0.07911948065157048, 0.04539332163403742, 0.01617537021957105, 0.10279453330440447, 0.02122217480064137, 0.017527129130030517, 0.10937937957351096, 0.027659205661620945, 0.13219308078987524, 0.04669508576625958, 0.06863006929052062, 0.08477112074615434, 0.06148767344711814, 0.05508696143806446, 0.004650463397410931, 0.049323783969157375, 0.06482357901404612, 0.03357041932758875, 0.007680113840251579, 0.05888616753509268, 0.02449449872074183, 0.03528462089889217, 0.0352216274040984, 0.030463165749097243, 0.09337305018561892, 0.02373535586229991, 0.034800543944584206, 0.08067091068369336, 0.05444144509965554, 0.021767668185930233, 0.02769826489384286, 0.08453669855953194, 0.06797660083975643, 0.036299493003753014, 0.015989927924238145, 0.03783408370509278, 0.06497284717625007, 0.00856215032399632, 0.00329629320276581, 0.02780891354632331, 0.017055266071110964, 0.026811530151462648, 0.031351575889857486, 0.031239700838341378, 0.08386665795114823, 0.0438985137589043, 0.05796861325507052, 0.02622248382976977, 0.030833076270937454, 0.0031564009168505436, 0.007407257680824841, 0.034381609002593905, 0.03827067805104889, 0.03651493105280679, 0.047576623619534075, 0.10202667021076195, 0.032112600092659704, 0.010980510887748096, 0.07930415667942725, 0.06713611859595403, 0.036219300236552954, 0.041452795776422136, 0.022107274962763768, 0.03998375897936057, 0.01739306015224429, 0.14427754562348127, 0.03331870881083887, 0.0038184393179108156, 0.06580921792192385, 0.08874497274518944, 0.011475300743768457, 0.02793031406326918, 0.025025598151842132, 0.030122438329271972, 0.05419043962319847, 0.06062050357286353, 0.11872535658767447, 0.028659492709266488, 0.06845806172350422, 0.046452321839751676, 0.026868421336985193, 0.0038373550387404975, 0.00979232689132914, 0.05183462541026529, 0.04535377258434892, 0.015380458626168547, 0.024531876988476142, 0.03842457721475512, 0.026665455079637468, 0.06344896566588432, 0.029401716456050053, 0.010007859564211685, 0.06984083127463236, 0.040050574534689076, 0.07638877053977922, 0.05523978077690117, 0.058503260152065195, 0.02614433196868049, 0.06959947000723332, 0.04164032907283399, 0.017912459625222255, 0.02282545498019317, 0.0981451191182714, 0.006347128946799785, 0.032381843848270364, 0.03068712365347892, 0.05591699053184129, 0.05237616314843763, 0.02892462125601014, 0.05861907971848268, 0.03272120200563222, 0.03819627774646506, 0.029304945965122897, 0.053082895537954755, 0.09204904388752766, 0.019347253728483338, 0.0188041222281754, 0.08040381915634498, 0.026273879411746748, 0.021222436407697387, 0.04000765984528698, 0.05231463539530523, 0.030153675324982032, 0.07252592156874016, 0.04861830580921378, 0.07607511666719802, 0.031657837971579283, 0.012038524037052412, 0.049075758215622045, 0.023441283556167036, 0.06558893364854157, 0.01689818123850273, 0.033401235632481985, 0.031238031006068923, 0.04179818388365675, 0.025558831257512793, 0.007840315229259431, 0.04407552340126131, 0.019290833806735463, 0.050187150336569175, 0.015067740787344519, 0.02828071352269035, 0.05538590965443291, 0.02233547424111748, 0.025380370716447942, 0.04844052062253468, 0.02439454441628186, 0.009279270925617311, 0.10744190658442676, 0.06889552809298038, 0.057288505413453095, 0.04338700702646747, 0.045139425492379814, 0.020797477081941906, 0.09877985576167703, 0.02088639379508095, 0.06049600458936766, 0.09738972410559654, 0.014510754317598185, 0.04238116685883142, 0.04261227906681597, 0.04914298937364947, 0.07614013622514904, 0.014009041151439305, 0.001955682278094173, 0.0043777862811111845, 0.03035745794477407, 0.04743578625493683, 0.11800493157352321, 0.03951605751353782, 0.07566764790681191, 0.057686300278874114, 0.0600536882848246, 0.022930817685846705, 0.048464777719345875, 0.0882657383044716, 0.05603314777545165, 0.04917298698273953, 0.03042935350094922, 0.05407552176620811, 0.051405474805505946, 0.023956224576977547, 0.02851006869605044, 0.010609814617055235, 0.09029889639350586, 0.03705219402036164, 0.006789599246985745, 0.07727890246314928, 0.05168332005268894, 0.004624044331649202, 0.014101367105467943, 0.0264793188762269, 0.016899287038540933, 0.03573816218704451, 0.06804223638027906, 0.0708088515966665, 0.0337534403661266, 0.057610126241343096, 0.03536245734721888, 0.023680997255723923, 0.026975283180945553, 0.052926387725165114, 0.03699756824062206, 0.037127009927644394, 0.04659617232391611, 0.020880339725408703, 0.061549316233140416, 0.03856948154862039, 0.05352946063794661, 0.06066497677238658, 0.021632498974213377, 0.053932743685436435, 0.066915604256792, 0.03568758111214265, 0.03929511643946171, 0.0878675167041365, 0.009468599291722057, 0.05331940315954853, 0.01941147547768196, 0.020024354016641155, 0.036727749320562, 0.022663130584987812, 0.05602483572147321, 0.05059900890046265, 0.028581513397512026, 0.004107752602067194, 0.024313121539307758, 0.02960159723443212, 0.04379840916953981, 0.05925829893385526, 0.08334483907674439, 0.052314961940282956, 0.032481224843650125, 0.03235964250052348, 0.03330091210955288, 0.032570609109825455, 0.043683773328666575, 0.08506868485710584, 0.036454026703722775, 0.10472805064637214, 0.15576432924717665, 0.2676957246148959, 0.1395005636732094, 0.13302384089911357, 0.12936254439409822, 0.13650488457642496, 0.11134515807498246, 0.11464404160506092, 0.1212974548980128, 0.07899923046352342, 0.18315274006454274, 0.1648875357932411, 0.20293964393204078, 0.11783486843341962, 0.14644144044723362, 0.08156493888236582, 0.15749206388136372, 0.0874675733211916, 0.10553355547017418, 0.16356189677026123, 0.15285560017218813, 0.08642812870675698, 0.1620640794862993, 0.05979709814710077, 0.21235657768556848, 0.20400045497808605, 0.12757064367178828, 0.142522678070236, 0.15080940996995196, 0.1749264486716129, 0.14256708818720654, 0.1598817645572126, 0.13059361896011978, 0.09677838737843558, 0.20137458806857467, 0.17331012524664402, 0.0805991301604081, 0.11316271484247409, 0.16962760331807658, 0.1081643502402585, 0.11367415107088163, 0.12380354659399018, 0.13150456070434302, 0.13839825172908604, 0.13722328352741897, 0.15383550227852538, 0.20350245904410258, 0.13039904268225655, 0.13049430475803092, 0.08861109672579914, 0.12051264857291244, 0.0919235912442673, 0.15510749886743724, 0.12075790611561388, 0.10897179206949659, 0.1029133956762962, 0.18832521251169965, 0.1567237777635455, 0.15516914165345952, 0.2579926187172532, 0.2387386659393087, 0.14399958163267002, 0.0944797630654648, 0.09868063803878613, 0.1257917156908661, 0.13481464324286208, 0.1358341018203646, 0.11754462189855985, 0.13721988449105993, 0.12020189649774693, 0.20992886420572177, 0.1376469459501095, 0.18250411783810705, 0.11656825983664021, 0.09191349061438814, 0.20058742171386257, 0.1691680061048828, 0.11652925997623242, 0.15047945111291483, 0.09604273349395953, 0.11014232964953408, 0.2243685643770732, 0.16944650444202125, 0.09400554554304108, 0.17296337900916114, 0.24132479826221243, 0.092573007568717, 0.12813310255296528, 0.12103687942726538, 0.06346685884636827, 0.15087210660567507, 0.14401329652173445, 0.14156652468955144, 0.14762544800760224, 0.07505713496357203, 0.24417445238213986, 0.0945228744240012, 0.17125869548181072, 0.18224921979708597, 0.1842095731990412, 0.13392871187534183, 0.07780652493238449, 0.10629970420268364, 0.11755722356610931, 0.21772322565084323, 0.19898476864909753, 0.1696345943491906, 0.26471267687156796, 0.28831677278503776, 0.13410422980086878, 0.19195855973521248, 0.2180745138321072, 0.2503793709911406, 0.10464164981385693, 0.12256740315933712, 0.21154236746951938, 0.10743982114945538, 0.11325351661071181, 0.21354248514398932, 0.1715604230412282, 0.22841703932499513, 0.13552878226619214, 0.13274580269353464, 0.18563232966698706, 0.2558686217525974, 0.1620689034461975, 0.12206230487208813, 0.1501544498023577, 0.17831800418207422, 0.1446098496671766, 0.12664622452575713, 0.24042109987931326, 0.09945865371264517, 0.15610776550602168, 0.1527662604348734, 0.1734033686807379, 0.10594967025099322, 0.17695794434985146, 0.1566252947668545, 0.2053110729320906, 0.11160078342072666, 0.12691286334302276, 0.1105927984463051, 0.107056227279827, 0.176784222421702, 0.13903814629884437, 0.210202538582962, 0.11204580485355109, 0.14726250810781494, 0.12833400192903355, 0.07178967396612279, 0.15432239568326622, 0.07674175081774592, 0.11663761353702284, 0.1295630430104211, 0.1068332712748088, 0.17976421251660213, 0.11708542544511147, 0.1752337274956517, 0.1338960722205229, 0.1448940476984717, 0.09668685830547474, 0.0707284473173786, 0.17747977806720883, 0.12343616122961976, 0.12395212455885485, 0.10744584738858975, 0.323445086251013, 0.10881364782107994, 0.1235091217677109, 0.15247161296429113, 0.11630268229055218, 0.11782343935919926, 0.18322769697988406, 0.08933379271184094], [0.024845206171448808, 0.024599360476713628, 0.08320114444359206, 0.054483131534652784, 0.015645057465007994, 0.017594443779671565, 0.020597110196831636, 0.07029357104329392, 0.04699452008935623, 0.07148326345486566, 0.016481190723425243, 0.03724824346136302, 0.04756217029353138, 0.015485189578612335, 0.06738746174960397, 0.054832464156788774, 0.026455662919033784, 0.05984145260299556, 0.01724182158795884, 0.07572592876385897, 0.01113095164328115, 0.030118068934825715, 0.012138247348048026, 0.04179579787887633, 0.062292818329297006, 0.048510382694075815, 0.03243206498154905, 0.022268517677730415, 0.016524606362509076, 0.03149820571707096, 0.04911884359898977, 0.034386050756438635, 0.013678137911483645, 0.06657167075900361, 0.02256044517707778, 0.03846774052362889, 0.024021531717153266, 0.027930241703870706, 0.03545814615790732, 0.06518599941045977, 0.07811597824911587, 0.019829427074000705, 0.010049934699054575, 0.01018366136122495, 0.05353589876904152, 0.00278520949450467, 0.03594998597691301, 0.09701885806862265, 0.09983043259126134, 0.015727257741673384, 0.020202643863740377, 0.05759395113273058, 0.05869414053449873, 0.0331609245040454, 0.027716137665265705, 0.11245265763136558, 0.03656461041828152, 0.06884119546157308, 0.035332203697180375, 0.041498192949802615, 0.07474903235561214, 0.047655692033004016, 0.02053561769571388, 0.018167220368923154, 0.035043749448959716, 0.03792695606534835, 0.045578557983390056, 0.06085219465603586, 0.016508336630067788, 0.021471378713613376, 0.04341245527029969, 0.038957049619057216, 0.02010769534535939, 0.08277902568806894, 0.010068516221508617, 0.047388626480824314, 0.09530874202027917, 0.011426033270254266, 0.016091284887806978, 0.04989250657672528, 0.030747866585443262, 0.055234622850548476, 0.03450688724115025, 0.020860349977738224, 0.0337991863489151, 0.09381914773257449, 0.021263757334963884, 0.043762118148151785, 0.01683174974459689, 0.03038300266780425, 0.04998421005439013, 0.044876159736304544, 0.09399749324074946, 0.051389362779445946, 0.006721012277921545, 0.006005861614539754, 0.020695090388471726, 0.0639194279210642, 0.025338628620374948, 0.03166879207128659, 0.012668687195400707, 0.07093532840372063, 0.06587547686649486, 0.0589444372599246, 0.013325669715413824, 0.08903871479560621, 0.018355284300923813, 0.016903320611163508, 0.03378834357135929, 0.0072193945925391745, 0.07748680771328509, 0.042480206466279924, 0.05843565049872268, 0.038793921848991886, 0.0196634605890722, 0.03934358981496189, 0.06744744954630733, 0.02408576459856704, 0.048538487826590426, 0.033639138491707854, 0.024852033930073958, 0.06234675762243569, 0.034991454012924805, 0.026066545615321957, 0.06502255622763187, 0.01621144787350204, 0.04826918098842725, 0.02186168530897703, 0.04674674666603096, 0.06499968323623762, 0.01979441996809328, 0.028587465421878733, 0.0012179804139123007, 0.004472211121537839, 0.03624352022598032, 0.03559034121281002, 0.050717284975689836, 0.07620536358444951, 0.030057118201511912, 0.05941935982264113, 0.041464043024461716, 0.035083970142295584, 0.029734931486018468, 0.03982830872701015, 0.05611017157207243, 0.049352416026522405, 0.00814445476862602, 0.03675319385365583, 0.06346769747324288, 0.06041647233359981, 0.07071629835991189, 0.07052907676552422, 0.04307357579818927, 0.050170500253443606, 0.0339168835489545, 0.026752854100777768, 0.05409892168245278, 0.03515133859764319, 0.00700254924595356, 0.039206852816278115, 0.03530615802446846, 0.03470583105809055, 0.017928467750607524, 0.00603578918344283, 0.05579707431024872, 0.024511017072654795, 0.018420190681354143, 0.015986699581844732, 0.029302715811354574, 0.03216212731786072, 0.05407634926086757, 0.019773485837504268, 0.016235519433394074, 0.054963438378763385, 0.06311436096439138, 0.024143759728758596, 0.09952276785043068, 0.08251561521319672, 0.03889792271365877, 0.01418715566614992, 0.0270382599774166, 0.08732087298994884, 0.020729828465846367, 0.02947172510175733, 0.00961821255259565, 0.02899552790040616, 0.013613256578537403, 0.03438830317463726, 0.038802115159342065, 0.03378091467311606, 0.016206395703193266, 0.027611893747234717, 0.06421826110454276, 0.02437019269564189, 0.012862601106462535, 0.020102528142160736, 0.022244854299060535, 0.055496968343504705, 0.004352025871412479, 0.026555311087577138, 0.028145924661657773, 0.06690492475172505, 0.026620467942848336, 0.028754706545441877, 0.056754827019176446, 0.04186275815300178, 0.039139640211942606, 0.05423770329798572, 0.058712037425721064, 0.05058306014689151, 0.012697603124252055, 0.045406157078105025, 0.007680108737986302, 0.0013896607401875372, 0.11612052956479602, 0.002604349033390463, 0.05035146925365552, 0.015694093017373234, 0.053682836587540805, 0.01948818015080178, 0.05386730110330973, 0.024077925663732458, 0.030797822400927544, 0.022517530487675685, 0.021380296784627717, 0.012297709836275317, 0.007293005437531974, 0.041859255215968005, 0.08578995591960847, 0.01244456323547638, 0.04347109606896993, 0.03627782229159493, 0.04467606187972706, 0.025081784297071863, 0.053406189908855595, 0.03282460544141941, 0.02584447091066977, 0.0329036181938136, 0.0756668760732282, 0.03401289890462067, 0.04080534243257716, 0.02367975415836554, 0.07963867232319899, 0.05861889418156352, 0.028224319576111156, 0.027126445675094146, 0.010823856500792317, 0.03146155104332138, 0.06399294506991282, 0.05905185571464244, 0.06128619148512371, 0.06051447293430101, 0.07565251551568508, 0.06430234643630683, 0.014108534396655159, 0.06397379765985534, 0.0338239295524545, 0.056650076585356146, 0.037517071614274755, 0.005371697352529736, 0.011371796190360328, 0.05889056104933843, 0.07110588878276758, 0.04401273028634023, 0.02279788790474413, 0.03637907349911984, 0.07116262597264722, 0.0730684315203689, 0.04399041390570346, 0.03585809325159062, 0.030275009048637003, 0.044962471511098556, 0.03903036267729476, 0.03385781601537019, 0.019516402171575464, 0.03139424567052629, 0.027077955601271242, 0.01607017264177557, 0.04546612261037808, 0.017657940079516266, 0.017360945566906594, 0.055905550325405784, 0.08968215683125891, 0.03511387127218768, 0.006302021674855496, 0.023137303578550927, 0.029189384295023046, 0.014405695892492076, 0.056122513487935066, 0.043807229594676755, 0.014101319793553557, 0.027125987398903817, 0.05899351919651963, 0.04299569482100196, 0.040825176329235546, 0.047953475077520125, 0.018614579566929024, 0.011391110583645059, 0.01581639524374623, 0.06837237335275859, 0.05336975045793224, 0.024947427737060934, 0.022819742298452184, 0.019813417093246244, 0.03301672521047294, 0.0697280174063053, 0.015954937516653445, 0.07468899260857143, 0.049595988893997855, 0.02572893336036941, 0.0693708068865817, 0.06552762482897379, 0.03410622026422061, 0.027322552632540464, 0.03174485849740449, 0.06124000021372922, 0.0069307135254348395, 0.06646109075518325, 0.03847736988973338, 0.05642042640829459, 0.07820637183613144, 0.060138567714602686, 0.0461156020173803, 0.048103073495440185, 0.05172902892809361, 0.030055696988711134, 0.021415699084172957, 0.08442386984825134, 0.042840649039135315, 0.08610645221779123, 0.039243117862497456, 0.004723947149614105, 0.042450828550499864, 0.03673902254377026, 0.01729281084408285, 0.01426552460543462, 0.03893142697052099, 0.03555540461093187, 0.02787644898489816, 0.032296430072165094, 0.04041154774313327, 0.07321126526221633, 0.058077935318578966, 0.05665066659275908, 0.044196797753102146, 0.013846035835740622, 0.020874348738288973, 0.03737431950867176, 0.04227201920002699, 0.060961687413509935, 0.05781082152680028, 0.007642636774107814, 0.1513815761427395, 0.135935464350041, 0.1576601603301242, 0.16529433662071824, 0.07894710943219252, 0.14371747645782307, 0.100485125585692, 0.11224576170207001, 0.13794393860735, 0.17560346546815708, 0.11604021434322931, 0.1314189613913186, 0.1261604146566242, 0.09535554927424528, 0.13909588538808748, 0.18953872786369175, 0.12107392743928358, 0.15819091466255486, 0.15211049874778837, 0.08062293083639815, 0.14367930038133636, 0.23495580564485863, 0.10573836596449837, 0.14099038060521707, 0.22290773573331535, 0.13652774272486567, 0.0986408069729805, 0.1347380832885392, 0.13465739699313417, 0.14695784164359793, 0.1516146253561601, 0.10760114178992808, 0.09735882107634097, 0.1601530343759805, 0.06104419197072275, 0.12852847430622205, 0.19885290384991094, 0.1401273816009052, 0.14829995634499937, 0.13016131793847308, 0.2986807166598737, 0.15620135032804683, 0.20684690302005038, 0.12045519892126322, 0.11449417972471565, 0.07967368685058318, 0.15978301438735798, 0.21318776824045926, 0.14078752195928246, 0.14419157523661852, 0.06401982565876096, 0.14839048351859674, 0.1949212874751538, 0.16807304142275825, 0.2683156554121524, 0.23300530796404928, 0.1071564172161743, 0.12709485279629007, 0.20562642632285133, 0.1272649085149169, 0.11124067110358737, 0.13150249753380194, 0.18206078850198537, 0.13446700642816722, 0.16485946776811033, 0.12652598175918683, 0.11803838016930968, 0.12785435188561678, 0.07574092014692724, 0.12137764395447448, 0.1483605452813208, 0.16742602223530412, 0.10921891240286641, 0.17922679369803518, 0.20308862265665084, 0.12621410161955282, 0.21781013114377856, 0.09350341584649868, 0.10084022098453715, 0.15017537836683914, 0.08979992082458921, 0.12083966110367328, 0.21625597000820562, 0.27177332143764943, 0.09871867310721427, 0.2639124932466075, 0.18672144622541964, 0.15877884405199438, 0.12168645160272717, 0.08231226674979553, 0.15153374610235915, 0.2272220776649192, 0.239644902467262, 0.10402960062492639, 0.08481441764160991, 0.09119875045143999, 0.10806394508108497, 0.15219819091726094, 0.1322218612767756, 0.0893351953709498, 0.07210574724012986, 0.16332098079146817, 0.15503355127293617, 0.09491437216638587, 0.10724180130637251, 0.1737504859920591, 0.1914155896520242, 0.07009127642959356, 0.15183692827122286, 0.13941787357907742, 0.17026170913595706, 0.15886408713413402, 0.18823864840669557, 0.22393188468413427, 0.13297799101565033, 0.08131041191518307, 0.2012941986322403, 0.07885604791226797, 0.144822979636956, 0.15082760743098333, 0.08238335707574151, 0.12101080777938478, 0.1582361856708303, 0.17569737683515996, 0.09726447926368564, 0.1427312067244202, 0.14384551177499816, 0.10420410180813633, 0.11921343000722118, 0.16436181322205812, 0.09248878865037113, 0.1430439922842197, 0.14672069577500224, 0.14863120653899387, 0.13817513245157897, 0.1708817735197954, 0.17044099717168137, 0.2291977489949204, 0.11959697934798896, 0.1837218040600419, 0.08711681948625483, 0.08565596857806668, 0.20790532435057685, 0.12330032594036311, 0.12198740732856095, 0.08630532553070225, 0.09379397408338264, 0.15060192032251507, 0.12400964100379497, 0.12352590172667988, 0.1327807133202441, 0.18615030421642587, 0.1584127574460581, 0.14956009341403842, 0.0970629787479993, 0.07403290437650867, 0.16592732921708375, 0.11240703781368211, 0.10908440555795096, 0.05726233357563615, 0.20738141261972487, 0.12140866572735831, 0.12757895572576672, 0.134227144299075, 0.2211172302486375, 0.11467218384495936, 0.08587162927142344, 0.10205608152318746, 0.14214391558198258, 0.10949552568490617, 0.10106099507538602, 0.061859459747211076, 0.097128421330126, 0.21749951265519485, 0.15221120818750933, 0.15388240601168945], [0.05130172627104912, 0.02783924141112948, 0.037843030295334756, 0.016018606365832966, 0.00889374654434505, 0.034484845455153845, 0.025095042765315156, 0.024817798657750245, 0.07145226394641213, 0.03733570185431745, 0.013187422446208075, 0.018692924386414234, 0.040252201215480454, 0.06185286205436569, 0.048603807954350486, 0.05609998188447207, 0.06034072503098287, 0.020494272648647893, 0.022983781054790597, 0.0466589394636685, 0.03561679877748247, 0.032013118907343596, 0.03728361793037038, 0.04853868449572474, 0.02632116164022591, 0.03789375979977194, 0.08522286603692919, 0.03760836691071745, 0.03973234161094297, 0.02337559977604542, 0.02108204433170613, 0.061064901601639576, 0.02635120563354576, 0.024865127270459197, 0.026646576698112767, 0.03678925852000248, 0.04058067948790267, 0.027691316536220256, 0.07143702765461057, 0.02585149348306004, 0.02267049640067853, 0.04683879524236545, 0.015820221015019342, 0.038306007991195656, 0.03176244739734102, 0.07143002178054303, 0.029816575151926372, 0.03674145307741128, 0.050216231393278576, 0.025209222185367253, 0.02355848908337066, 0.04838574641325977, 0.0117177242100297, 0.07333256929996423, 0.03561660952982493, 0.018546828905527946, 0.0408659313688986, 0.09850770278717391, 0.008329836764460197, 0.03280609627836384, 0.0489703101629857, 0.017737926900736056, 0.06543310490087606, 0.02676079879165627, 0.07543116254964843, 0.031004263764771167, 0.04142947007494513, 0.05727709489292465, 0.0339558796986239, 0.0357744161010487, 0.05308302541379817, 0.00708393269633234, 0.008663170538056875, 0.0420801777363522, 0.0037077363958815113, 0.045992487139301375, 0.0026417648723509046, 0.08193975314497948, 0.008573839149903506, 0.04019485546450596, 0.01366217988106655, 0.03107666769210482, 0.020446374437597115, 0.02635240049130516, 0.04089148722414393, 0.014701087366120191, 0.05358060203434434, 0.05480760592035949, 0.05445038426842075, 0.024636061534693, 0.053722760421806015, 0.06073414122511167, 0.06018084044626448, 0.05609286468825303, 0.03586090599128511, 0.05934517103014514, 0.00591497542700381, 0.060366989637259394, 0.05491060859640129, 0.07389448641333729, 0.007374186652668868, 0.03156687664159108, 0.0402665098226862, 0.010160306901525473, 0.009184631326206727, 0.04112754213565495, 0.019517964392434806, 0.014179838090058183, 0.02970787278172793, 0.06054185076209251, 0.043068143277196214, 0.08826085497275926, 0.034606130939209834, 0.08248598125646822, 0.014108957420830848, 0.04611054799170233, 0.015932227797748055, 0.07923589393612929, 0.028881869839096908, 0.03325056852190755, 0.029367414390435442, 0.0534034216980217, 0.06213128246599808, 0.018542786056059413, 0.04374478157842532, 0.03941664312151261, 0.04362132902315352, 0.025266762750106864, 0.03017147202626802, 0.033884537042467855, 0.06358589191222563, 0.02989411474118242, 0.01817070289689582, 0.034264820933458395, 0.046029186341911554, 0.023612912627868354, 0.0009224299003562919, 0.007097091902323882, 0.04984948056517169, 0.04151964472839609, 0.06305697068455629, 0.06694320472888649, 0.0774469469615724, 0.0157768517601653, 0.016878197056939825, 0.03567830426618457, 0.05276729352772236, 0.03930674218281638, 0.03220215505280066, 0.015872084150032606, 0.011521053220349131, 0.058801284394576214, 0.039119015928008594, 0.08007441691006534, 0.06247169818379916, 0.06039868305379059, 0.04031311298604123, 0.06559655550518073, 0.016623757292109076, 0.03756397905817721, 0.030788886942900717, 0.03294327114417683, 0.02728224659222178, 0.017642731618252583, 0.02845995517418487, 0.035504259503795765, 0.06480768963228911, 0.07158742388128303, 0.037770388880744576, 0.06748850515577942, 0.013888330831832718, 0.03814487288764212, 0.06175520284159575, 0.08693916417541914, 0.04549087694613263, 0.014822935954725835, 0.012216538361826679, 0.011041446778108366, 0.05501322906638961, 0.04174318703007884, 0.033580738891032524, 0.033258272014791146, 0.04081346523889806, 0.044719573998008855, 0.047462210422963835, 0.03463949789875187, 0.025177473107760306, 0.04307159055315424, 0.03554665840056259, 0.06766693972167559, 0.04950847855070606, 0.019478220528981183, 0.03246207372285426, 0.04058073514897842, 0.005583424663200276, 0.015249570678861346, 0.07084852681146003, 0.059569885925156996, 0.0406086918519577, 0.00828692671348108, 0.010605956376821268, 0.014541152686433634, 0.016134867510118056, 0.02152078719518613, 0.02359230875299545, 0.05660336209984962, 0.04187345621176064, 0.017804866765800398, 0.06334154721116647, 0.04242016300850082, 0.02989233544212766, 0.023309836215048563, 0.031132683143368922, 0.04018456929770764, 0.037048824669909663, 0.036435354268178344, 0.05995488987537101, 0.027220431256864686, 0.05105634998471942, 0.03061633946344955, 0.048189645021921024, 0.060335823145578615, 0.04281572029867675, 0.06440162353101186, 0.020327556594565976, 0.03196561032382306, 0.09778677311260253, 0.032826126844156533, 0.07527033914811909, 0.023185008831205778, 0.030004217915120535, 0.056558187570772134, 0.034605077089508995, 0.016143010725500062, 0.053003860521130264, 0.0712885832763277, 0.048223798658000305, 0.03799664002144709, 0.006382956125889905, 0.012532226646726485, 0.03323307981190737, 0.023840729700168595, 0.04257377273461316, 0.014053168324608123, 0.018534321861807257, 0.0498417102789972, 0.022815931370132603, 0.009379564762639347, 0.0451517562760273, 0.03344276250572875, 0.03599538315029349, 0.025734506889421027, 0.023359391270787455, 0.07577341137221083, 0.057225927521358244, 0.02078795532725053, 0.05542343635170255, 0.038184993391041644, 0.03332055304781534, 0.034782320508384146, 0.0416345959820319, 0.06694115640129894, 0.03219610283849761, 0.05983878087135963, 0.06528322817757726, 0.033477710239822045, 0.02980149285576772, 0.02005825903324876, 0.13365082209929824, 0.03628459438914433, 0.05017552088247612, 0.10326003059162758, 0.03721789333212655, 0.042116769327549264, 0.011220877677260432, 0.06509164275485091, 0.05452320008771494, 0.03148906245769467, 0.0331539074977627, 0.011271935582044534, 0.01486680244852323, 0.07497336133383214, 0.03535731426381972, 0.05274009381537326, 0.04836183070437983, 0.047389431711053476, 0.06677049212157726, 0.04378562938654795, 0.01765469874953851, 0.050146009380114265, 0.051511876517906785, 0.021817414344695862, 0.004882289922534255, 0.014460993315879023, 0.005195229014134384, 0.029251303531054873, 0.08166961139068007, 0.05387248871556949, 0.047871033602859825, 0.042692486676969565, 0.030219169857446104, 0.006696946747979382, 0.06312533732852899, 0.03181944804964587, 0.036753579770447686, 0.02080778551317053, 0.025192766916006804, 0.09679165697889403, 0.06219624636287335, 0.005185569034438231, 0.027357780527381692, 0.018743340333458036, 0.021596614278678317, 0.021803298695886042, 0.0424346868385328, 0.08572164122597314, 0.02223287974629784, 0.056088623314280994, 0.019766825062106363, 0.026545175205683336, 0.06606530339922756, 0.036967923151678406, 0.042460906915948726, 0.04037767241243273, 0.05697612061339896, 0.03999594133347273, 0.06547215671162121, 0.06296328938333318, 0.022387122153304517, 0.06443750637117773, 0.061106981374905445, 0.091340834624134, 0.0363000496145105, 0.032933623224380426, 0.02531358113628812, 0.029160811609472148, 0.030451003804046195, 0.014468008466792526, 0.013862206305930158, 0.0713469457696192, 0.047253006414393894, 0.05495518940733746, 0.029959585153847, 0.025144039354927372, 0.057298661704408005, 0.027769806074502412, 0.03389947647519875, 0.002870641824301856, 0.042917398241115734, 0.06393933974322863, 0.03508654539473355, 0.024959044203569647, 0.18708805233472958, 0.11466265466879122, 0.12712048657704145, 0.09632846034946851, 0.16845882462803274, 0.07330956272198819, 0.07628828374436125, 0.1232262299163267, 0.14931399724446237, 0.11735884007066488, 0.08822115007205866, 0.162445216847118, 0.1413583819521591, 0.16295289038680494, 0.11800651976955123, 0.19880568841472268, 0.16159818886080757, 0.2403662700089626, 0.13394913577940315, 0.127362753264606, 0.12167701148428023, 0.15931544650811702, 0.1119906484382227, 0.08608061063569039, 0.10916036437265575, 0.14569516642950475, 0.2665394585346803, 0.11473729246063158, 0.1540016839862801, 0.13388364866841584, 0.13322082173544914, 0.11872203918755986, 0.1412346214056015, 0.07034039314021356, 0.14156545599689707, 0.11639787015155889, 0.10942961554974318, 0.15192457591183484, 0.1902359162340872, 0.17306978814303875, 0.16331572638591751, 0.18167053756769747, 0.12192193506052718, 0.11725554053555243, 0.13392791035585105, 0.1357264310354367, 0.0864607238327153, 0.18085465009789914, 0.1830535742919892, 0.10417549943667836, 0.18016681278822944, 0.12059035143465735, 0.21095835661981255, 0.16375645820517093, 0.2116614524857141, 0.1467359988600947, 0.10016954212915152, 0.1274943063617684, 0.11041575169656426, 0.16913698433199897, 0.24098192603560165, 0.1739041699329391, 0.16001542535377666, 0.05400005647970829, 0.10143114865059033, 0.14541902812197804, 0.10490839253179729, 0.1245849538827315, 0.15099151816684753, 0.1720891587319784, 0.1270515559008345, 0.11432473998866044, 0.07853302813600749, 0.07964066870044917, 0.15232958074193448, 0.11207228468265384, 0.09942470045643859, 0.13571932126069441, 0.15633395727491006, 0.11494291931740008, 0.1068467041477561, 0.1901462351088412, 0.09820752631640062, 0.17314348340732977, 0.1460372519795783, 0.0998158790753223, 0.08450391789665446, 0.15666688472265378, 0.12357857936876826, 0.10654889512807131, 0.15538998995907605, 0.060350421190378256, 0.3252519486704841, 0.21305720962118357, 0.17663079081103206, 0.17925241263583302, 0.18791471578879282, 0.17082410864531994, 0.11552716765436344, 0.1567282306496054, 0.09875734642264433, 0.20559346012305468, 0.11906973537406884, 0.11598246041103266, 0.1396864716662094, 0.1638346360414289, 0.0832316096057184, 0.090103704133071, 0.10733566072303802, 0.15772150625707582, 0.13901416008593515, 0.10596059466479346, 0.34758480498567224, 0.1526073517743498, 0.10345462171244435, 0.1831923855934292, 0.16039966489188373, 0.17992092442000285, 0.11037573509383947, 0.09562611405272037, 0.1422862001345493, 0.13908689055824652, 0.1848751906072721, 0.13326910586329177, 0.12508864951087162, 0.1507541348109953, 0.19758464768528938, 0.1314963970798999, 0.1923278672620654, 0.10617600302794017, 0.16690316435415298, 0.21073247655294836, 0.09255048338673078, 0.08439132667263038, 0.1170147729862947, 0.12011315047857352, 0.07063720026053488, 0.18182104511652142, 0.11457624641479924, 0.21971516485791653, 0.12295409178477712, 0.13779061089735478, 0.21962426661048084, 0.09116459681536071, 0.14602490264223889, 0.13757727312622592, 0.1739096618257463, 0.08369630537345074, 0.27271828323137015, 0.17611744726309553, 0.17272838536882773, 0.11077165603637695, 0.07513826654758304, 0.15965819999109954, 0.2333252626704052, 0.15585199173074216, 0.1409817420062609, 0.16115002072183415, 0.10052739089587703, 0.10246441117487848, 0.12642236310057342, 0.0940434544463642, 0.12012451275950298, 0.12237522401846945, 0.10927084789727814, 0.1456449378747493, 0.14993418037192896, 0.09797887803870253, 0.13698849768843502, 0.17931773647433147, 0.13035078824032098, 0.11249944262090139, 0.1309614718775265, 0.11667919607134536, 0.10133593852515332, 0.1473155419807881], [0.02612416967167519, 0.020753521530423313, 0.014485470273939427, 0.00974578773821122, 0.019946959146182053, 0.04767170386912767, 0.04763382465171162, 0.02023194570938358, 0.0382653420092538, 0.03396540887479205, 0.043950115286861546, 0.019981663826911245, 0.053928005072521046, 0.04094484022061806, 0.11430666127125733, 0.045210393363959156, 0.011469425717223203, 0.07366764155449346, 0.016621792456135154, 0.050165839566034265, 0.056319813447771594, 0.030733689709450118, 0.010062768287752988, 0.03154184771119617, 0.05258378267171793, 0.07986263022758067, 0.07365247947745956, 0.060199397848919034, 0.029885624571761582, 0.02396120809862623, 0.03386725242307875, 0.10488064363016747, 0.01716833412501728, 0.016801099045551382, 0.0392960700992262, 0.0784778494562488, 0.021577123625320382, 0.05293398360663559, 0.029663770656043198, 0.0237414006551262, 0.03384845011169091, 0.012790513519576052, 0.03298972958873492, 0.06872214755276218, 0.027507701779541094, 0.03376449836650863, 0.015388826341222739, 0.029750891371804755, 0.018032988118648063, 0.02609835963085061, 0.020616584151866846, 0.020026624988531694, 0.058937858120771125, 0.02967517004435649, 0.022043029093765654, 0.04325729074480478, 0.03809618057857733, 0.015264100075000897, 0.04359240010671783, 0.056807660512276925, 0.1063383775181137, 0.02886542941268999, 0.007440100962412544, 0.07045883990940638, 0.048966966787702404, 0.022071176899771672, 0.06006128416629508, 0.023158989133662544, 0.050905404568766244, 0.06053222139598802, 0.04950632632244378, 0.03021021399035817, 0.05317286239005625, 0.04741904711409006, 0.03533679016982205, 0.05386252167227212, 0.04416097428475041, 0.04539345150988083, 0.024613643108750694, 0.009115549437410664, 0.053340057129389606, 0.07754971215035766, 0.008414470357820392, 0.022953391962801106, 0.043488592200446874, 0.027828244637930766, 0.055316055004368536, 0.05547506385482848, 0.0694205827312544, 0.03403393508051522, 0.018104714836226776, 0.049807304312707856, 0.0061871887010056525, 0.049496882493258454, 0.02290111322508892, 0.014742056700924877, 0.02803153187414864, 0.036792561077163555, 0.014165184384182794, 0.004340230361776776, 0.07525547393015586, 0.09837598641752265, 0.05094524676678702, 0.030515472317347303, 0.009731358532008016, 0.014312908879219322, 0.015799518805579282, 0.04031788499560207, 0.01567486582644051, 0.050252618893864565, 0.03375120650161989, 0.02860188535123598, 0.07940568990306929, 0.0336548868654063, 0.03917347843525931, 0.032116214351844974, 0.027166425170435105, 0.018750049348454922, 0.05331697262590751, 0.01779923386493465, 0.021758543480245862, 0.025134565839834977, 0.004762385296999128, 0.058210007919115014, 0.051199736626585945, 0.06693413568427786, 0.01899557035358157, 0.0268489882000722, 0.05096305088954978, 0.05675336127751507, 0.0471758972707903, 0.017409548818250187, 0.006725653483954375, 0.03399844928935636, 0.025034657919604797, 0.037844555408810265, 0.0309153080888791, 0.0244777076295577, 0.04348740847490262, 0.03046517140319338, 0.057889192321454175, 0.0344851868430851, 0.09723965442390181, 0.02282670549902832, 0.035373333521420136, 0.01913728530780645, 0.034203059403807856, 0.022944081720197573, 0.0287637310611899, 0.08590952333179303, 0.06787698977859691, 0.043337628230801784, 0.05850108194863424, 0.020126226772845257, 0.060428387514548376, 0.008727527729206486, 0.0495551893254742, 0.02068856505502481, 0.042197422226308845, 0.05931469102506526, 0.04229387915984262, 0.04638279373466503, 0.03122742571576964, 0.012205846796859987, 0.024327714017999824, 0.055717738723615184, 0.032731269238865934, 0.008202695735235466, 0.06937560858204961, 0.0249881141280639, 0.05186376583878882, 0.04028650699183345, 0.045938447656226344, 0.017435542540624738, 0.06633608340052888, 0.022052615786378738, 0.02727673800109187, 0.006569800152647076, 0.07518778264056891, 0.06290748729952611, 0.03888385159370955, 0.018641309870872647, 0.026256388846377376, 0.012333513823250541, 0.06476704220403917, 0.028565160173457116, 0.07695643929764628, 0.023542707313026767, 0.021147110273886938, 0.01685860250290716, 0.020105305629840586, 0.050244369922438636, 0.05775994359282777, 0.012684859520959435, 0.03523198036418762, 0.06246061049751006, 0.0892546797695104, 0.018815163530234713, 0.03281401870481204, 0.03934105538064614, 0.056998362779268064, 0.036393801419762895, 0.0266277354239719, 0.056779225124046206, 0.026080763309437316, 0.05601803393801674, 0.02228052562713856, 0.031517330862698145, 0.07067676415317692, 0.02224395258963341, 0.02898604881920619, 0.021056861405668315, 0.04362495441455394, 0.0493259473296348, 0.045752806836389937, 0.017188179153890815, 0.03496858844300732, 0.03543150676705409, 0.04165655613178387, 0.02937807163107209, 0.024231065981439315, 0.01959966371941846, 0.07062240925733931, 0.03621076553827152, 0.05384719632274937, 0.009466785668337252, 0.04399772406031843, 0.042713508009910583, 0.023876054074207786, 0.050508952990639955, 0.03471586118394043, 0.019412952351558488, 0.020173768753011245, 0.0588346179574728, 0.015993321394489612, 0.04053869990457315, 0.028758962762367446, 0.005218475862420746, 0.03848847984045278, 0.036659946708823554, 0.05788408263470046, 0.034995699097635224, 0.06360456434777007, 0.035608360558399, 0.009768374075065367, 0.05038796807639301, 0.044334837220958434, 0.041368035090272315, 0.05120259760587942, 0.024035968344833236, 0.028146475706307683, 0.07669630911550485, 0.03232385242881719, 0.049888847788679413, 0.08693716779816896, 0.0401408901961986, 0.04725129947473761, 0.044340611129882745, 0.02456360380165279, 0.02118445328960661, 0.02521778100344818, 0.06357316407957114, 0.008228215410781559, 0.03466948808636516, 0.06949459711904638, 0.05516858283954207, 0.007928249524411513, 0.027797853690572083, 0.0664317536575254, 0.030224875117710326, 0.009442798527743435, 0.01347974421150866, 0.07237994854222052, 0.031285576696973294, 0.048229650492430665, 0.0027580174355534837, 0.007564280358565156, 0.04566496623738203, 0.07317466253880411, 0.06450011394917965, 0.03781218663789332, 0.027392897100071423, 0.01348570644040592, 0.015033380277600372, 0.02590563501144061, 0.06360728802974336, 0.010132687875739066, 0.01654727711866144, 0.0474753427261021, 0.0233658442448359, 0.007073418319123448, 0.059871824996662326, 0.024461465727654286, 0.11550597933819517, 0.03446645874646492, 0.018413871293887496, 0.052478742800303735, 0.04061441381054465, 0.05695090985682327, 0.023466984130209312, 0.028874800882476848, 0.0743278487061616, 0.024506120753358118, 0.006519772441606619, 0.04845040602958761, 0.05205296154599637, 0.032767890515970066, 0.008126843604259193, 0.04627221373084467, 0.03440121283347253, 0.04316401762480382, 0.006636514126512338, 0.04410733556142077, 0.06154717142635491, 0.03635424123785924, 0.013695454072149005, 0.06238832531380467, 0.025516961140965577, 0.02721225464483723, 0.019821092755591962, 0.011970405084866798, 0.06431822839658707, 0.07010334375081584, 0.06584285205462947, 0.03197288708179258, 0.05234282958554104, 0.09322979341959581, 0.026855361393245403, 0.027911394863622263, 0.03563337093510199, 0.013609344532596879, 0.04408009132021107, 0.04386659027659334, 0.0848220766056329, 0.07665789555176161, 0.062479594635078683, 0.029443929815897718, 0.018050734724965878, 0.04462213742954191, 0.04682617131038569, 0.05384961943491362, 0.05076755063782912, 0.024428289871138986, 0.07388941012322903, 0.017850135918706656, 0.09016458250698633, 0.04593213197949808, 0.03097040142165497, 0.045419883099384606, 0.02035833902482409, 0.12260444374987856, 0.039870106484158896, 0.11713206942658871, 0.0959535718720872, 0.1282703405013308, 0.1204097646404989, 0.1622503882390447, 0.1674141627154313, 0.1683112559840083, 0.06385123197105713, 0.12035984778776765, 0.09182725305436179, 0.22948852245463058, 0.11036755662644282, 0.08904329384677112, 0.14864037948427722, 0.2644145116209984, 0.15994839457562193, 0.1125176549248863, 0.16721406485885382, 0.07436364248860627, 0.17766204953659326, 0.24596911389380693, 0.07309505977900699, 0.12492095382185653, 0.1952422663453035, 0.2943439915543422, 0.1755824775318615, 0.2165540016721934, 0.143811417510733, 0.09153565581073053, 0.12299797497689724, 0.16518240590812638, 0.142988910083659, 0.1758180055185221, 0.16970741387922317, 0.12337464460870251, 0.13195842853747308, 0.18271950393682346, 0.09936825270415284, 0.14869893493596464, 0.11181944981217384, 0.14016628498211503, 0.12344922302872874, 0.1112236239714548, 0.24230464099673554, 0.27465249819215387, 0.07289037544978783, 0.13347929692827165, 0.11890845184097998, 0.08747415617108345, 0.0922076556889806, 0.23706841806415468, 0.10824507364304736, 0.1399037873488851, 0.0944397241983097, 0.121577645331854, 0.10397274469141848, 0.19629250920843333, 0.1717404235387221, 0.13741165545070544, 0.22512475348776206, 0.19536950014298782, 0.1773625929490663, 0.14306515833595768, 0.11676730384351686, 0.2156429857132025, 0.08031176315853372, 0.2027397241909057, 0.14947038260288537, 0.1340374513529241, 0.10504244666662998, 0.16007415892090648, 0.19420382363023236, 0.1528024475555867, 0.13275350618641824, 0.13759964145720005, 0.2245127785135992, 0.1572927230154164, 0.16981352615403011, 0.1761297817574814, 0.14661875437013805, 0.12091925644199364, 0.14885212905937806, 0.12963482353370637, 0.1428565406240523, 0.11714047053828835, 0.20616185618564487, 0.125939269491937, 0.09753925201948732, 0.1442322597722523, 0.08441671554464847, 0.11665921745589003, 0.08798867973382585, 0.10399311664514244, 0.09636639151722193, 0.07893038884503767, 0.106082069396507, 0.14213863149052486, 0.1287397340638563, 0.21851874858839437, 0.03973871665948536, 0.11662399512715638, 0.1869669189909473, 0.21775792847620323, 0.15439579408848658, 0.12680937827099115, 0.07050207001157105, 0.10949998599244282, 0.11209670876269229, 0.1507022141595371, 0.12137350277043879, 0.15943294332828373, 0.17198882036609575, 0.2109581488184631, 0.07365971541730687, 0.14069242315599695, 0.14353444799780846, 0.1300882757641375, 0.21147817169548944, 0.16065895644715056, 0.14499880926450714, 0.17124017147580162, 0.11168745142640546, 0.10429867368657142, 0.15255973557941616, 0.10380950188846327, 0.16045419790316373, 0.11757664557080716, 0.10736123513197526, 0.11768400465371087, 0.11786846545874141, 0.21689570130547509, 0.07759756583254784, 0.1284476395812817, 0.1307644316693768, 0.1422140930662863, 0.15367977001005784, 0.1323567985673435, 0.07985445176018402, 0.10291746264556423, 0.09436519772862084, 0.09815057390369475, 0.09373162625706755, 0.14200946810888126, 0.10625930910464376, 0.07942968353745528, 0.20370954793179408, 0.14978486025938764, 0.1607266700011678, 0.11851397066493519, 0.2813347661867738, 0.16003898112103343, 0.16126250062370673, 0.09763393522007391, 0.11732643790310249, 0.19226770877139643, 0.13156707922462374, 0.1394821287249215, 0.18430664611514658, 0.23317002021940425, 0.21480824769241735, 0.08500015494064428, 0.13567473302828148, 0.08628165101981722, 0.1097668548754882, 0.10490694534382783, 0.13119487732183188, 0.13836072874255478, 0.21814647247083485, 0.10073203811771236, 0.18119878397556022, 0.1412497166893445, 0.1700732481549494, 0.07608314670505933, 0.0720746438310016, 0.22987114411080256, 0.10767279614810832], [0.01399715101797483, 0.03216719618649222, 0.07165941220591776, 0.052421560321818106, 0.09799279330763966, 0.04021163913421333, 0.05271454167086631, 0.029843672818969935, 0.052635213505709544, 0.05035090151068289, 0.04025014175567776, 0.028740132620441727, 0.08385208217077889, 0.041177859748131596, 0.04825585943763144, 0.07049363921396434, 0.07375323344604112, 0.04826444237551186, 0.04401936137583107, 0.04666881744924467, 0.02418469844997162, 0.01853960409789579, 0.06435987772420049, 0.008896173367247684, 0.04241224058205262, 0.03822473168838769, 0.04301641929487232, 0.05241476967057679, 0.04782995572895743, 0.07487447015591897, 0.0597216439928161, 0.027720659199985676, 0.02779959402687382, 0.017748187092365697, 0.052200878999428824, 0.023673434770898893, 0.07174183512688614, 0.07748375748633407, 0.04456238712009508, 0.0203883922949899, 0.029882702365284786, 0.012892446575278882, 0.0373122314340435, 0.027910895769309718, 0.017771030397852883, 0.08214546163799241, 0.07271075344760902, 0.09971839797799475, 0.017280986576224677, 0.07505473782657646, 0.04944774860632606, 0.006510478897325811, 0.027891750214621425, 0.04104263673070818, 0.0077556088126584655, 0.035584474535426125, 0.03736015933100134, 0.032286596615449525, 0.010448885459481971, 0.006361849445966072, 0.08701784667209722, 0.004564855735225137, 0.04120506317121908, 0.048711048293625936, 0.012455624018912204, 0.055455036999774165, 0.030009988113306463, 0.05257437966065481, 0.039568842767039314, 0.05987960641505197, 0.035826600214932114, 0.025732373214850668, 0.05005912986234762, 0.03718912397744134, 0.03944686337490566, 0.03463513778115157, 0.038378990793717094, 0.023204456811072305, 0.06091195609769784, 0.04508029487624299, 0.05824165680678561, 0.05418912973254919, 0.020538456410577055, 0.04385314998216927, 0.04168476145423483, 0.03881398581143003, 0.04765907993714791, 0.04968562177964486, 0.05245864544122014, 0.004397229158712435, 0.02485139197233366, 0.054495673830388114, 0.008063438217504881, 0.06324039248283952, 0.07009440829278901, 0.032036893608164974, 0.013233567333372775, 0.03477320322417654, 0.037732747150585055, 0.024641395721118897, 0.06942627500393428, 0.012585002623382024, 0.08973957679700106, 0.02049551945674466, 0.01756363722961396, 0.06668426940450445, 0.050319337969995104, 0.07137177060940303, 0.03389171732123941, 0.030646559716842603, 0.04630426337826066, 0.027064014357165433, 0.01880324834928615, 0.05636003414110746, 0.05504956090589985, 0.12414257449563593, 0.016894594809855334, 0.03919112670700997, 0.019450994841463398, 0.017214274921570905, 0.10809819519636221, 0.03238382538256701, 0.07711833881330676, 0.039710407436359674, 0.03464277819148265, 0.04578982145176269, 0.034333428775426, 0.03994395759946201, 0.05541500555409584, 0.0213037461071508, 0.03259216478909366, 0.042265885349479504, 0.08439733806881122, 0.05796367426228244, 0.03311170898086857, 0.029309096426004544, 0.06552442617248744, 0.030752705388295, 0.0075714982085628435, 0.06793032051064074, 0.1507894610404037, 0.027957404308835976, 0.029807730606989935, 0.017312667005171534, 0.025838947476586327, 0.06904832887812518, 0.0262542811469757, 0.035334456115379, 0.012056112009304343, 0.028426736644178163, 0.006492675702247652, 0.044778971787309274, 0.040245443960884586, 0.04069889990205411, 0.04896556041785516, 0.02765861379884882, 0.014184077608661028, 0.016794757393654436, 0.03761309810215607, 0.019904007349396124, 0.0032307277024301584, 0.051893251365981996, 0.014158496705931611, 0.009362533401144901, 0.05452819103084039, 0.04086902612471022, 0.10811171712703072, 0.040233105755760334, 0.05683883071469609, 0.05563991711824201, 0.07536148230428807, 0.03490258182864636, 0.04187533013464417, 0.024970321137516294, 0.06741902529029176, 0.017777056636987254, 0.06290248522418551, 0.027865871525136754, 0.09386826306581497, 0.02499465801520273, 0.03901476273313165, 0.024692125225556083, 0.05458884304971434, 0.08761359087657183, 0.09175381012028083, 0.022124451970739756, 0.03259837656514719, 0.04950292357534636, 0.0032516119699721457, 0.022241696460696403, 0.04350474875536747, 0.03533307943143882, 0.0840326763864141, 0.04706402221927419, 0.03823782317340374, 0.07807244386640377, 0.04047911657835357, 0.007712425094723585, 0.014794249163969653, 0.05165804992429912, 0.05369981692638248, 0.1069034932879731, 0.011836776757263578, 0.015121084506972693, 0.019766782388614956, 0.04591365621308796, 0.07703636860242113, 0.034540228225523606, 0.045183976617408916, 0.006282852000367711, 0.04842166636080947, 0.01652403861953644, 0.008248361009464134, 0.06614026031456888, 0.0659933002316393, 0.054482730774907395, 0.01959162254934199, 0.03489018425170798, 0.029752314439974725, 0.046980389597592875, 0.03662092087324709, 0.022939662230783142, 0.09225668938597664, 0.03889548846927937, 0.023361103776551317, 0.03931811930669937, 0.008193267676688265, 0.011365544523869175, 0.040212667008745484, 0.07484515532269143, 0.056447744864271954, 0.03815027572272811, 0.016660950022924226, 0.013303005453053629, 0.03244324914703611, 0.07382671348750591, 0.0248697304414236, 0.01783540428732522, 0.04262466180080082, 0.020457885148061905, 0.037410829463624395, 0.0341141018725466, 0.01887327369331615, 0.044347965813358314, 0.05351974592485931, 0.04312390825361945, 0.02836195271811448, 0.01672449456236791, 0.06346025373204611, 0.05057388720160816, 0.06568616983713582, 0.06371563416905701, 0.03083664043515455, 0.03942573443055153, 0.0223908662883332, 0.023846870972192846, 0.039337136840913445, 0.05001399615139235, 0.06928289207280613, 0.05917694099480286, 0.09257619138224982, 0.03953159066441003, 0.02284365429659374, 0.03102257069258485, 0.06873733189422637, 0.0305289293100941, 0.03963027033023536, 0.06815885746618733, 0.050407104354235344, 0.04293834907002747, 0.03041010961169377, 0.04435879374796059, 0.03538054348609876, 0.017222124988620635, 0.03775685210712254, 0.06628326475038193, 0.0028135982665844494, 0.019374859766685404, 0.03760088235139847, 0.060938320893910713, 0.02431570606859168, 0.05064494784164708, 0.11437268272857182, 0.01765344823070336, 0.014143150947347749, 0.006139591523606214, 0.02030395444307942, 0.012633028854907025, 0.03008028434123844, 0.0621138382848585, 0.016766804401413538, 0.06741531455190852, 0.023590549863001797, 0.029292437066033017, 0.009287975390179781, 0.061725375926471315, 0.01637362569454126, 0.043142461945535615, 0.029961180771351792, 0.04357619531219825, 0.04404298393637873, 0.010948220970021794, 0.09298691074945964, 0.04069340429850854, 0.013548028291552328, 0.023064901506586466, 0.034804607203113846, 0.123047557863174, 0.034994975503650494, 0.04641887324396521, 0.03155398182570934, 0.04369907270302065, 0.02831873374816496, 0.01430360049198498, 0.023791657040419523, 0.004001042898380547, 0.03988432603364345, 0.012952188535564346, 0.015741868774057366, 0.02243692026240751, 0.0052549834981618915, 0.05532877541554626, 0.011341881145199295, 0.049027065906557254, 0.023849783901823685, 0.01982185716769891, 0.09046110761119053, 0.03381699789315462, 0.013374784120969707, 0.03539681507390924, 0.05113420498673804, 0.013004245556658134, 0.026690827253332827, 0.010970761850330746, 0.020657897657656576, 0.03940340691769961, 0.05044200013799127, 0.03425056427659001, 0.056119415021385066, 0.044622215355047956, 0.02828664699336514, 0.025450110333622433, 0.026474908663658425, 0.0025113669744314393, 0.02086228512780508, 0.05513987285667099, 0.04410175832163077, 0.09853096911683679, 0.021467398946697358, 0.046927392832003534, 0.04553595499601215, 0.08900410844944417, 0.10826071811607108, 0.12421626233845018, 0.15622555918525904, 0.17215991509146988, 0.09027565974975005, 0.12422194718965329, 0.10790456144604832, 0.2242756326450035, 0.1920294645242393, 0.1470577050349675, 0.10889500204939395, 0.11473306221887469, 0.21516085689654574, 0.15535623708274215, 0.1500006768037565, 0.19151715998305008, 0.2853269566548988, 0.11796615435741842, 0.08293025312013924, 0.15753218438476324, 0.1279920054366812, 0.06222942778549623, 0.12510465021478012, 0.16330541053321213, 0.11829782015411183, 0.11624193750321865, 0.09293622948462144, 0.10998384401318617, 0.11988511818344705, 0.1831596568808891, 0.1671573202474974, 0.1065266529622022, 0.1405923519632779, 0.11175973661011085, 0.11233861921937205, 0.06590594945009798, 0.1356319704791531, 0.2246127903345041, 0.17587255337275565, 0.10598159744404256, 0.12999506201595068, 0.1948660716880113, 0.15337921504396945, 0.10804637844557874, 0.1347319976775907, 0.13976585178170353, 0.27619212807621807, 0.1290582786896266, 0.0517271067656111, 0.13655824499437585, 0.12632564641535282, 0.1283551234519109, 0.08385490975342691, 0.1315574164618738, 0.09672102678450756, 0.17844764253823087, 0.16629325255053118, 0.07761079832562245, 0.21589773532468826, 0.1451466599246487, 0.14490341360215098, 0.15254854399245232, 0.11703603551723063, 0.08760533077293076, 0.07934671884868294, 0.11910936606000178, 0.10942819804768078, 0.147387144388631, 0.13312272465554997, 0.16048081131884828, 0.11930714099435136, 0.12094483085093088, 0.13757549197180197, 0.13005921326112002, 0.1546661733300425, 0.19822874281089753, 0.0993806762562599, 0.20577645889716223, 0.11936924391193315, 0.12860421789810061, 0.11790282689617015, 0.12923744798172265, 0.14767632965231314, 0.15502970694797114, 0.1597398065496236, 0.15582232066662982, 0.10514192414120771, 0.16126411850564182, 0.16458511061500758, 0.11787792042014189, 0.09540635670418851, 0.13914832554291934, 0.10996622542734258, 0.12001561000943184, 0.18801483151037246, 0.17749566002748907, 0.15544158406555653, 0.1816564070759341, 0.14993855904322118, 0.10077958751935512, 0.13450199126964435, 0.11433120409492403, 0.14806338935159147, 0.15588494308758527, 0.11971189349424094, 0.19801359419943765, 0.19720131356734782, 0.07987287186551839, 0.14877680107019842, 0.06024004898790736, 0.1342234038747847, 0.09035943337948993, 0.1342285395367071, 0.21171690576011315, 0.24185712594771758, 0.22314173489576206, 0.11544093751581386, 0.1097361819120124, 0.10529764898819849, 0.1226636151841376, 0.1351227829582058, 0.16295636363793164, 0.11666293561575003, 0.17935564537765458, 0.13745073694735765, 0.12513344554463401, 0.20252810820238665, 0.170387651596684, 0.15420136624015868, 0.10851220969925635, 0.1446456805570051, 0.2920104714576155, 0.1601242835749872, 0.13358552794670686, 0.1348494054400362, 0.1439877221127972, 0.11173635895829648, 0.08662455293233506, 0.1527823056676425, 0.13565718865720555, 0.2415478284819983, 0.07026321720331907, 0.09295799667597748, 0.08373425880563445, 0.07383122574537992, 0.19241557427449152, 0.09103826843784191, 0.11268425965681672, 0.09465928116696887, 0.11418139416491613, 0.172676672518719, 0.20002842124085873, 0.1386140682734549, 0.13079425116302446, 0.16953204438323155, 0.12477388983825222, 0.07856770127546042, 0.05560527366469614, 0.1293462616740726, 0.13479182962328196, 0.1585322877508588, 0.15870565344812348, 0.16089512268081307, 0.1369435532251373, 0.11192784790182486, 0.13996825029607862, 0.24375844892347232, 0.14368416887009516, 0.17115071299485862, 0.14351628022268414, 0.22895092552062124, 0.1486796687822789, 0.0799532093515154, 0.08645546200568788, 0.11713465210050344, 0.19020845677005127], [0.06559199129696935, 0.04011935678136069, 0.07061103213345632, 0.037436511483974755, 0.025892458179441746, 0.024984802294056863, 0.055046878042048775, 0.017123547368100844, 0.039783327156328596, 0.028141566399426665, 0.04076592325873207, 0.03716688181157224, 0.033079317945521325, 0.02352900726691587, 0.022390274425561074, 0.049589435730013065, 0.09951807005563751, 0.048979420025716536, 0.05378241796279326, 0.024284966311824974, 0.043153649821761064, 0.05078043061075732, 0.038698626376572065, 0.024810314098431263, 0.030782402427576017, 0.022944050178921316, 0.05530567235837225, 0.022203221669769846, 0.06437380041461438, 0.07581526107969694, 0.00351925454197044, 0.017502450864412822, 0.017767982026271056, 0.06580211556865834, 0.011239909126743441, 0.03425405979214702, 0.015981207689037547, 0.03869898631819524, 0.03360036127560306, 0.030496276667690836, 0.05901967248064466, 0.08034944941755384, 0.058051114101544954, 0.02592832432128489, 0.05199388659093529, 0.038216323155211285, 0.035628264959086664, 0.029239887444418855, 0.028308872460911516, 0.05088874706416391, 0.014870945487928111, 0.01933144227223238, 0.0160037485693465, 0.05259833989839535, 0.01337672019872116, 0.048861229297472164, 0.058584829603205435, 0.022433586163970176, 0.04496331384871155, 0.025069093571801204, 0.023231882878462784, 0.01971726815099828, 0.06581093970453367, 0.03230715781683102, 0.032246398186543956, 0.009430655136384303, 0.05196195197640918, 0.028156969674455468, 0.011222775719943456, 0.014021191036590608, 0.0104759905480023, 0.05035018904891331, 0.013974500670883572, 0.028275863587623462, 0.03790902206674218, 0.03161371729220264, 0.016771463233453687, 0.06776024252758361, 0.04438051641045604, 0.02310774569195928, 0.03665686308522709, 0.09940613192156889, 0.054351378057617694, 0.014563351251126733, 0.016716368045308627, 0.012448002162273042, 0.06880655942950398, 0.03492382951662876, 0.02194249776948709, 0.04265703057171777, 0.021817082233610563, 0.06311522185569629, 0.040895454003475606, 0.0794460330507718, 0.04482560092583299, 0.03025260546564823, 0.1165647865855135, 0.030828658636892214, 0.09974103348213248, 0.04367393245047424, 0.0616900571185397, 0.02401008408924099, 0.041513421820127405, 0.08174520655302331, 0.06654780328972265, 0.013408452578005381, 0.019372085989743937, 0.04195951565634459, 0.005862118277946138, 0.06561692745890468, 0.02323784417967545, 0.06560130525031127, 0.013572051611845382, 0.049296458091703244, 0.04791679442860186, 0.03666422147944104, 0.02890623640269041, 0.032441701769130304, 0.03517051198286936, 0.13061223202385008, 0.0301654569193488, 0.03315635287435725, 0.03715132268553134, 0.056473118893336505, 0.02012613771512406, 0.050545711565064266, 0.05421851506980602, 0.061130013928050175, 0.04978457232937217, 0.02954865798528772, 0.015176442229858367, 0.019992853558505885, 0.053940157740726136, 0.10175207557040267, 0.03577568146283738, 0.041050833751796745, 0.043875933915842324, 0.07126666023395956, 0.02556249004555866, 0.0483540455752518, 0.01596453719685087, 0.014376799445017241, 0.05482914675667416, 0.07794136574375443, 0.005887893530598376, 0.028401442395988852, 0.02329243656276958, 0.06705303516355343, 0.033613352570682764, 0.02301890133821871, 0.06173019246489275, 0.08083355234703049, 0.011994499836873729, 0.08828019534121267, 0.06577880471013486, 0.03327506310597528, 0.019000065913132858, 0.08545375560061075, 0.01152054206613684, 0.06092571551562287, 0.01900729814224178, 0.027693264673871454, 0.04609654737578239, 0.06226503974176012, 0.03731234646693338, 0.039676450469414704, 0.036195488428347744, 0.01041516783516272, 0.03104639363300521, 0.0076826236909255385, 0.043176994076929986, 0.012334081566223176, 0.006886325209052302, 0.045668710372410715, 0.04768188242451288, 0.044496428745333105, 0.022979038731136825, 0.06011402860167436, 0.09069471343536861, 0.022499628030345775, 0.005526330314751249, 0.03201306324626785, 0.048752508373581804, 0.10997214034432545, 0.01935725231305696, 0.04958025907399133, 0.0825845384679269, 0.04264983544999268, 0.034999361596419476, 0.02620406186906621, 0.05069362901849672, 0.0247568349368521, 0.07524708023993298, 0.06080791812564712, 0.027262889525445644, 0.02510568516299827, 0.010953236032946734, 0.03883683653839398, 0.04202152580546681, 0.01763602816936327, 0.07206170819699764, 0.06811582032241859, 0.03176590951625258, 0.037368783087003976, 0.04236008615407627, 0.06782302079955116, 0.07637092188815586, 0.02178584152716212, 0.0597586474759737, 0.09735465020639822, 0.057312695716973394, 0.07340604191995226, 0.07994471918209456, 0.036690107590402476, 0.009427844252059003, 0.03177532365953084, 0.09077281705685891, 0.07676004475797527, 0.015120315456442768, 0.04939087782986462, 0.07578090706374496, 0.06451871216995642, 0.017807247204473242, 0.031003408439573832, 0.055364205545629375, 0.04007884665043093, 0.0329915923794033, 0.009724509436637163, 0.02220490263425745, 0.058918855429510586, 0.031241726901498623, 0.02219490776042221, 0.02364231837418629, 0.07351662934524938, 0.03069423899432877, 0.019159230614604894, 0.046467068314086646, 0.006759252364645363, 0.02616979876620462, 0.05219037389906589, 0.005320526270224946, 0.010993313862854848, 0.06382343111908995, 0.05709848221158609, 0.00426778051405563, 0.03960211695812177, 0.018431194876029622, 0.10988968031597324, 0.08906820774427615, 0.04526929020357784, 0.016495035488333087, 0.027638021056191064, 0.07317833616980352, 0.029020849979133345, 0.0641747193003539, 0.04680314988945611, 0.039910019186208956, 0.050462809958844446, 0.03521778307913337, 0.04391235110233538, 0.03628968552220613, 0.022791930314269848, 0.05855408984643873, 0.0130323163648427, 0.011453041879576631, 0.04672040042351, 0.03881917342368979, 0.013475065898091998, 0.0636666821083054, 0.0911215967789758, 0.032908052526181564, 0.04230740109051112, 0.0897665019147098, 0.04583642461511772, 0.04570929100736976, 0.03573552385205403, 0.022731530625605956, 0.02958472821774194, 0.03305769176222384, 0.025783104574657045, 0.07967502271640114, 0.05793486408947501, 0.025304745868197642, 0.03647224642918445, 0.06679194761090912, 0.015191262918961002, 0.021612724449369125, 0.019900016450264957, 0.036538969216053374, 0.05889718100661412, 0.018757511643343605, 0.03517473109241109, 0.0753679835179355, 0.031191197776934132, 0.028791244330932386, 0.06020327185979113, 0.05281538840790745, 0.0317750898830127, 0.027579727211559657, 0.02161639065889176, 0.05075904933619313, 0.03216538163542282, 0.02691232493816642, 0.05641333518724423, 0.02468119524564827, 0.027698483827407472, 0.02146376242308179, 0.05971658625639975, 0.05474802259413991, 0.02115195649821544, 0.057988974076579325, 0.0536471392842941, 0.04155563146923669, 0.07397946232231334, 0.03249161862186156, 0.03525361025822349, 0.0534969953878317, 0.06937696671229787, 0.06996871816227213, 0.09406127341208048, 0.005029753274357063, 0.035409951087785885, 0.03117275540716946, 0.011859429887408623, 0.04845651019422803, 0.048192402100539766, 0.046130059054121375, 0.04630973300663754, 0.07830789763829671, 0.0841650681104511, 0.041220113926101476, 0.08447873682598583, 0.05209748669585679, 0.07528115223976783, 0.029760745237581432, 0.03580904842237942, 0.05467241629958153, 0.014743945466761943, 0.07545984655735083, 0.05419163077021949, 0.0068483606446534395, 0.016131444353959523, 0.03804002597462386, 0.019153675639245193, 0.08110974260489456, 0.06668688176432624, 0.04523234238149598, 0.02105818799464032, 0.03193449207174126, 0.08522402378730476, 0.01324254082646803, 0.07666456745937467, 0.12612139253178611, 0.13160806061932817, 0.21312890108674765, 0.12655986822210252, 0.08058477702434175, 0.09016062685986981, 0.1611085791955702, 0.22306655533611774, 0.11150050442665815, 0.1543616404524073, 0.19536369654815644, 0.20384797331644222, 0.10205588114331476, 0.07216371639515273, 0.08928661438403651, 0.17682842473732308, 0.18646714190253988, 0.1290322293061763, 0.15615864715073258, 0.1342641923110932, 0.1108688254316803, 0.1233157106617, 0.07664015822228976, 0.10233877299469896, 0.11630048553342931, 0.18761629820801318, 0.11419772141380236, 0.17327916284557432, 0.12213038207846694, 0.14922299509635195, 0.131421395635698, 0.0778555215219967, 0.11036360097932629, 0.13824777386616915, 0.15631102491170168, 0.1472121904953383, 0.07323908837861381, 0.0883659727696795, 0.08891315825167112, 0.09275665201130323, 0.28290286485571414, 0.16080407600384206, 0.1248663169099018, 0.1414555884548463, 0.14900662936270237, 0.17885919311083853, 0.13404454628471285, 0.08655195604660548, 0.10595419735182077, 0.24824490974424407, 0.11278116187895648, 0.14475597854470834, 0.15445050521520898, 0.26295099640265107, 0.09944462712155655, 0.14246492413803935, 0.1395733535173349, 0.16041575465351343, 0.07344194702454843, 0.060438002037699334, 0.10737788150436245, 0.10364003988797776, 0.17534568789415061, 0.10864218944334425, 0.14920090878149495, 0.0569040729169501, 0.2333342723431997, 0.10488141546375118, 0.10479141521500424, 0.08716610551346093, 0.07870962217566557, 0.21848872129339725, 0.16595605033216998, 0.11815149831818417, 0.1590207841945812, 0.15017631347291172, 0.11814789148047566, 0.16263675031950697, 0.17244577553356066, 0.15212293714284897, 0.1657965627964586, 0.15748744772281498, 0.15160098468186334, 0.06949689777684398, 0.07549996706075035, 0.13974480447359383, 0.11153770828968845, 0.0643096565909218, 0.18488489789888263, 0.08607282550656237, 0.12528534833109006, 0.14773582021007314, 0.15397741575725377, 0.1924682073877193, 0.13844626868376508, 0.09101163275772706, 0.21389984409324825, 0.13447487319353968, 0.2496026986045763, 0.12503822799772024, 0.10627369934809394, 0.2288294953177683, 0.1241325332375709, 0.16880678798770532, 0.15635635529179126, 0.1272066796082072, 0.13075828668661416, 0.17928217275766656, 0.08339327163412236, 0.0969402126793284, 0.08745594386709854, 0.18424481037072837, 0.13042721460806206, 0.23978549492312595, 0.11876831951667555, 0.17175214947201312, 0.21036208549048752, 0.12358505089650862, 0.10052089710370637, 0.22871950903208926, 0.16640965099213645, 0.13537785911466926, 0.14628909237217158, 0.16154282464412972, 0.12390352130751126, 0.1413990813307464, 0.10822807846125215, 0.19637858349597082, 0.07629383500898257, 0.15561469743261114, 0.1648361940169707, 0.09688487814855762, 0.2577009843662381, 0.15875206736382097, 0.13796577259199694, 0.1440459064906463, 0.13574731507105753, 0.2499957400141284, 0.12350288772722706, 0.09561678525642492, 0.12948547373525798, 0.16441400104667991, 0.11890085967024788, 0.16723275213735178, 0.11495206999825314, 0.09255071345251054, 0.11051229026634246, 0.16868854901986197, 0.129489318060223, 0.12456711265258491, 0.16537095594685525, 0.10148116940399632, 0.24532117444323376, 0.20054682623595, 0.08988252186099999, 0.16264961916022003, 0.18270521017257124, 0.17187620687764138, 0.11709705489920452, 0.1479113381356001, 0.08751863308134489, 0.12020245310850441, 0.1330710860202089, 0.1722668288857676, 0.10731412359746173, 0.17900486185681075, 0.13482752692652866, 0.1731153708533384, 0.15806874231202528, 0.12197228235891089, 0.24031623441260308, 0.10841137409443036, 0.1590517911245115, 0.1688795184600167, 0.13209268305217847, 0.1243433180206921], [0.008455076967948116, 0.031987997208489105, 0.049369021580787376, 0.042552814484224655, 0.03611652020481415, 0.02174756897147745, 0.05604872916592285, 0.011478069882286945, 0.04202871350571513, 0.062478206818923354, 0.030623343482147902, 0.024252556722785812, 0.04172905282757711, 0.013477700522344094, 0.05920886076637544, 0.018847574974643067, 0.023238230096467305, 0.05664942720613908, 0.015499211531277979, 0.013876781158614904, 0.06801493276725523, 0.004473847557164845, 0.0721734607941471, 0.029237267663120292, 0.02993669917486841, 0.06940853025298566, 0.038562264162465, 0.054704844442312606, 0.05432456426206045, 0.027069550778833218, 0.009024673454405274, 0.014872681185806869, 0.053970429944456555, 0.042133823881158605, 0.04329778974351939, 0.03341650161019061, 0.041384859578101896, 0.04342922038631514, 0.03900688112480566, 0.03343780124851037, 0.031244023848557845, 0.05365837540011853, 0.04903891429421492, 0.071516875323141, 0.014898941153660417, 0.08565990938222967, 0.05290545173920691, 0.044460727731348015, 0.04475725283555221, 0.01857560197095154, 0.03709781383804511, 0.026237265556119382, 0.0320575809746515, 0.05882403493160382, 0.03312069638923276, 0.05010312808735762, 0.03739493266039062, 0.026783729299495462, 0.02991525296238251, 0.06373195399646647, 0.021544981209444813, 0.022847661894047633, 0.01834017974033486, 0.04431680303241592, 0.04266640389687382, 0.04940048493153881, 0.018948939359688666, 0.06371295501594432, 0.0493217430630466, 0.01558799558551982, 0.05801087856525555, 0.005195523553993553, 0.0897853598871734, 0.06016406790877227, 0.011955852496612351, 0.018269978136231657, 0.02036856396443909, 0.07464811511454172, 0.012065221872035181, 0.007887367391958833, 0.05962398478004616, 0.013326383104868, 0.0352476322586881, 0.07669875820283778, 0.030528923743986525, 0.03135313811071683, 0.04941540209983941, 0.044543020776472986, 0.047984415214159526, 0.07279978890437633, 0.023829877645766828, 0.07374417924438603, 0.055348609312204644, 0.03246462671086192, 0.0060797767400799785, 0.010895361501752632, 0.05399952955485787, 0.036123225509072654, 0.030998638285382185, 0.01187520423627575, 0.03490281931590289, 0.012271435025468236, 0.07883862970629707, 0.034138106639147736, 0.025647655202192254, 0.05425958181149326, 0.08699990896275267, 0.03215398966858629, 0.042182664619758725, 0.09243594031431712, 0.04247309669153765, 0.07412938357447274, 0.03140493259707, 0.06268836819799617, 0.03947629695176147, 0.08275602653156966, 0.06350815194309689, 0.022541858088516165, 0.05293816931953188, 0.009570891361363465, 0.055223078743438236, 0.02687893942493247, 0.019496490349411033, 0.052841022188658826, 0.09591629379428923, 0.034259254825883545, 0.043783762885141186, 0.00748979006857553, 0.05318228395481128, 0.026055090565932915, 0.01875514048151672, 0.06736818075296469, 0.06494082350400276, 0.029697723912249785, 0.04334789213316981, 0.02174808661948191, 0.055577725142939016, 0.022963349729252513, 0.060837151322630234, 0.0070301232790370705, 0.052426666297833435, 0.028213450823386665, 0.05977466673357412, 0.017968912943615578, 0.05298896932799835, 0.04208352111163549, 0.11785480252001435, 0.030380447824427392, 0.04982018057489768, 0.13232157623860985, 0.040624280663905665, 0.03337567606649827, 0.053697423500125296, 0.0863392639439553, 0.054993068624753505, 0.029368772520683706, 0.04599325897288509, 0.02773308089672355, 0.016099324202514254, 0.0530968293605838, 0.025144022656604648, 0.02246518310130341, 0.03955368069000542, 0.05402233204222284, 0.08793189059360884, 0.01773987132764887, 0.04976276060915552, 0.04961358892614953, 0.07088870668667369, 0.05403643284807913, 0.060251040194998495, 0.052954607890569605, 0.04920342245895881, 0.1428480801405385, 0.012786871429852908, 0.06139821867691353, 0.06893536658026278, 0.026141057242057286, 0.038417482282966375, 0.02849276552296942, 0.07315314025618136, 0.018435193196637556, 0.047068452840903774, 0.007131771999411285, 0.04541466951195616, 0.011495381404529326, 0.04219737027597148, 0.020762577587447595, 0.05174362697289325, 0.04533278464805335, 0.03290249755082186, 0.05889317340916023, 0.04430325512657873, 0.04780891955306288, 0.030017836324987, 0.02760971554380376, 0.04236861343088094, 0.02331452844373416, 0.030894231094862334, 0.030466946991509758, 0.05705254698114004, 0.05036700611526612, 0.035997739469166845, 0.06372931937221438, 0.05138349239132367, 0.055561152985319495, 0.023599329470016528, 0.025356965234095696, 0.04824741750780959, 0.023318061066675, 0.015356972435256466, 0.03237792901927605, 0.02298756044183392, 0.019122876510664355, 0.03493170370347798, 0.02711949731747154, 0.051724190125241876, 0.017155658242700156, 0.07886634150054306, 0.04939604317769408, 0.020533949718810618, 0.0717335008084774, 0.038330680690705776, 0.04935212658892851, 0.03461236869043205, 0.011764102873712545, 0.053499796995311044, 0.0031838666427574935, 0.021923192653048318, 0.044668451155303046, 0.02783393134450307, 0.01999019666982349, 0.05380820388381835, 0.026908257968898397, 0.039226133812917396, 0.017425716505385935, 0.0056694112845434574, 0.03189931798260659, 0.05978513843729161, 0.019630093629530165, 0.04251876103808172, 0.09649197032558732, 0.04790647857589647, 0.0055085248004616005, 0.04243854600645136, 0.038431597931776196, 0.01984870064916322, 0.05219458929786924, 0.06382345338352025, 0.03283961537817959, 0.035803007340291515, 0.021845283845323138, 0.02222958646598272, 0.027631265656964388, 0.07464481255738065, 0.02238608129118802, 0.019447694139671512, 0.014656143830507062, 0.07453504149452783, 0.058599012045306154, 0.015778326778672636, 0.008963347936514765, 0.058227440968039446, 0.032167467070394196, 0.05246433400316164, 0.08710023248568177, 0.035923457908211276, 0.07592959635076113, 0.06798558082664385, 0.03171601863869, 0.027387067530071363, 0.020366953503980767, 0.049709930826793425, 0.04031402953842189, 0.017334337717329618, 0.05409135919762775, 0.08207321356167085, 0.018747424001048785, 0.05481888285430614, 0.0757993568549864, 0.022625653982686345, 0.05438943910121452, 0.04596327620674856, 0.024373660380661022, 0.025657058213255368, 0.09030280009028502, 0.01501753449701937, 0.04238745284965262, 0.050139756785938516, 0.03223522144253366, 0.03272424481110647, 0.052465191183728166, 0.08260145201347768, 0.0401136014261283, 0.05534375937713776, 0.03195266726834234, 0.023427164196618833, 0.044607157178688794, 0.036104694081586786, 0.02494911983376369, 0.019489673723001033, 0.03878998846630566, 0.019972268237324897, 0.041536925637046807, 0.021677289441868197, 0.01549882190374774, 0.034813004604075104, 0.028425359960237984, 0.0658630087855272, 0.02848700274626026, 0.025196637216140516, 0.016803566686576232, 0.017250975979550276, 0.06558461434906349, 0.04764553203131072, 0.004701250882135355, 0.05428308933915105, 0.04252243095834274, 0.08262201692559756, 0.025139786848740187, 0.10651604767190292, 0.013145032826287206, 0.009244557895726757, 0.11198775406228378, 0.09766948409378529, 0.029012584309384692, 0.046736553267692216, 0.05354128676117398, 0.02240236401121365, 0.022448655472544488, 0.01698492531431839, 0.019260930821474176, 0.01244082281118608, 0.033374989579897374, 0.01256814566659159, 0.03330287137941923, 0.08350069751031697, 0.06109724068664946, 0.016998649480228778, 0.05060856776253786, 0.07816512326826341, 0.08756027498748153, 0.02681348199985223, 0.015417494578287005, 0.040661451130290516, 0.03546927837305702, 0.050692541772150435, 0.0828910231939517, 0.059150056695216335, 0.043055901551269926, 0.021715560142183676, 0.042695525771705434, 0.11090309038991109, 0.19966711406596005, 0.10721540311351418, 0.09112374900723808, 0.19406432955292985, 0.10413228417746723, 0.12901539739686996, 0.22011938301147893, 0.11188978314748965, 0.1253890263615176, 0.10700643659220077, 0.09285305699449964, 0.1437096542213112, 0.14300994254881516, 0.1521401252830401, 0.18471418909030035, 0.10463963117217645, 0.1515950178145431, 0.1469784733490087, 0.12600414804182947, 0.15746760269394144, 0.12128353962907568, 0.15101666213013232, 0.07793113152729347, 0.2200866097700782, 0.2505219227168709, 0.14704024972161278, 0.20263834681827575, 0.17648120352532715, 0.12189539585961029, 0.10153271156013943, 0.07458110660081729, 0.21186077850870788, 0.16121221269713715, 0.12545945617603138, 0.1478169221081771, 0.05452250989037566, 0.1296971194096841, 0.10645279442542233, 0.09148155324510299, 0.09517407932435162, 0.0957738162833266, 0.12443214567610994, 0.12292015337152407, 0.10574521598755382, 0.27661918953526765, 0.1774186102556996, 0.12324894705670886, 0.10078222214360721, 0.09334361660876311, 0.12241600503330119, 0.09419293040991761, 0.06520467926748097, 0.12611870595719665, 0.1472390117123723, 0.22760152292903513, 0.10151314112590626, 0.1060089678503573, 0.1818865619134158, 0.11861199353006668, 0.07221022679004818, 0.10029747354565188, 0.1631510438164696, 0.17044938344042748, 0.13170985359465703, 0.17563757457537577, 0.0934841571142897, 0.17797922861063853, 0.13954457303043455, 0.13936442410340533, 0.11794084712164477, 0.08840445312671363, 0.1290498924208805, 0.15940628538373858, 0.14625956973759457, 0.1537652060505934, 0.17856421909527853, 0.17140719923190773, 0.09216215461492538, 0.10310720012057573, 0.1279964583227411, 0.12048981268890202, 0.12925015354994684, 0.17355107091134414, 0.08740901786950417, 0.11044811675674282, 0.12800472584785894, 0.22589816042454913, 0.13495336548658088, 0.24263931991299614, 0.06772527252906002, 0.23944801068864763, 0.17056236800272018, 0.06948276728508063, 0.13754402491031215, 0.10324707269319333, 0.1413454388966784, 0.11803182700532489, 0.11131715684314258, 0.15759934874949977, 0.15829313808353618, 0.17007813148666173, 0.1309317711275071, 0.11719392743543722, 0.09623399237170815, 0.13176995271351188, 0.16235247807344422, 0.1889228937216103, 0.16640637069940567, 0.20543352729873732, 0.1307270274264738, 0.16013299638871104, 0.18245305807795376, 0.14280383329605684, 0.14376723003806546, 0.2901231305440888, 0.14681576489238068, 0.10773192305350676, 0.225415185559541, 0.13456023501930758, 0.17957723583094776, 0.10264503507642075, 0.07710891353781335, 0.0897358066868037, 0.09766365823452361, 0.13481540023349226, 0.11093946304754354, 0.09973220192478038, 0.11723275660187937, 0.09166139789158478, 0.12785916100256145, 0.139805719954893, 0.19526181451510638, 0.11924312333576381, 0.10430078880744986, 0.09671385763795115, 0.12063545917044394, 0.11364386402419768, 0.14512788358842954, 0.1280767735443078, 0.11388078724849038, 0.07811283154296689, 0.250633274554275, 0.13390122272539884, 0.1620350021403283, 0.12439301222912036, 0.2045951527543366, 0.21519244270166382, 0.15461882430827245, 0.31678778410423547, 0.09563959145452827, 0.15935210860334337, 0.1680480013601482, 0.19330883806105703, 0.1001156993152108, 0.10339568776544183, 0.09751821955433115, 0.15276465739589185, 0.116199056210462, 0.08673764139530249, 0.1740194551530294, 0.11796377948485315, 0.09419947615242563, 0.11766511699534021, 0.2046956098638475, 0.26994475862011313, 0.11917094947420992, 0.12929779943078756, 0.14197926269844174, 0.15383554680738598, 0.17885923763969913, 0.16910735779674724, 0.15076624666107818, 0.21296576218446717, 0.06650463255937211, 0.1260641432600096], [0.01363536237477092, 0.052601902207243256, 0.05896840862988029, 0.0224550713392091, 0.02289957326865988, 0.07427202435792424, 0.05465601112518925, 0.04580704298859928, 0.05217734178586397, 0.06291956946370192, 0.02262838137539802, 0.026681652452680282, 0.055231798978638835, 0.018599042705318425, 0.08406248103710823, 0.016139227627718356, 0.04439108459337149, 0.02251362122478895, 0.054439374507637694, 0.0398996736475965, 0.030724355347047094, 0.032695085828891024, 0.003819143894361332, 0.027995010786980856, 0.02376101561821997, 0.07626957420143299, 0.019533475278876722, 0.03510933674988337, 0.12443431274732575, 0.021427664360089693, 0.03389786601474043, 0.052285710189607926, 0.049999899056274444, 0.055386996900779195, 0.027739877114072442, 0.013929074739280622, 0.04600229462084826, 0.024942102827480994, 0.0506877029692987, 0.08344508096342906, 0.021101308630022686, 0.07175636637839489, 0.05956237539066933, 0.018827570384019054, 0.04830852965824306, 0.012794140766345663, 0.028994945314479992, 0.02931727489340119, 0.06747145802364685, 0.050066781404893845, 0.03024759040272329, 0.00850653284942382, 0.024339616211364046, 0.0457077102328185, 0.031359735803562216, 0.051051010232185945, 0.04343350628914777, 0.034815772814908996, 0.06072569187381305, 0.004982606487828889, 0.017339877849735785, 0.07142094531445764, 0.030958699608163442, 0.0284520253262599, 0.04438289499375969, 0.006204776673257584, 0.024850677655194886, 0.026688916223065462, 0.04188060680462513, 0.002717811585171148, 0.04490783830988221, 0.0314205362519715, 0.023675804077356588, 0.016582994830969255, 0.0243521084121312, 0.023996352501853835, 0.03799449521466158, 0.06030378463037778, 0.057949992769863456, 0.09156339729088359, 0.04136022398597561, 0.015042633931443561, 0.07008768443483859, 0.06411327689420432, 0.03372378043422941, 0.05518961901543662, 0.05436659208498895, 0.040202455056714825, 0.025539691268932074, 0.02916337201895658, 0.013889155543438392, 0.057927075249608606, 0.02245804364065407, 0.041496816265862435, 0.025331841679872014, 0.05982932219922077, 0.02275001010275446, 0.03456519036262762, 0.03186884168826509, 0.04863176465732977, 0.021974849842081312, 0.03127235162537545, 0.0875614104734268, 0.03588590152503457, 0.04932510499202181, 0.07290794208529405, 0.02511550748749869, 0.051360226061660796, 0.02062306310108397, 0.023204514327517245, 0.0761588680325076, 0.007904353296908084, 0.04190370244032238, 0.019493493928166572, 0.05606534956314135, 0.06862507463665679, 0.06972570932703093, 0.008525359280611156, 0.006824432875873754, 0.04437600786332041, 0.07258492230903357, 0.030870855298417155, 0.04256738655385561, 0.0411478918249486, 0.02617683247081004, 0.017667406173131894, 0.005191113805267378, 0.031925649382174015, 0.011098619979748037, 0.019215383363189176, 0.05520167149370536, 0.03434845355513971, 0.083110194245819, 0.018763413572742138, 0.06349903836962767, 0.022113616614660714, 0.04583181958878413, 0.021009937263443135, 0.04629320537787862, 0.017007664719130844, 0.015781811162014492, 0.023509997154178564, 0.022164774709381163, 0.06167163701320533, 0.06409953974070959, 0.018654470004548784, 0.018261942532262765, 0.04204327073239256, 0.05759173211117741, 0.05119637098687235, 0.05752016309997998, 0.04075484299391974, 0.07008958433289081, 0.010710745773394592, 0.03571646549971774, 0.0326575331564527, 0.037693179547204636, 0.025350868490932044, 0.00852128396218177, 0.03947509096178692, 0.02473965236276854, 0.015835874764889013, 0.06607940420508385, 0.07646438796655275, 0.02741896874795202, 0.04088080029760022, 0.05222681334998924, 0.0889682478737086, 0.02967973610793706, 0.09183725720504299, 0.09474573394982144, 0.06736177601851523, 0.029307753138709813, 0.0627219355374109, 0.08225299883633852, 0.02913239848567173, 0.023488283768529072, 0.09087203477974981, 0.00782215858635027, 0.017111739798565395, 0.03800690021307673, 0.01993773981666891, 0.05864593433216214, 0.040960659098345786, 0.04274288963642903, 0.03346974328451324, 0.04915585450362414, 0.06270839876378886, 0.04058035294292495, 0.029777104027743917, 0.014720438866788754, 0.04010953816759866, 0.08000688889296725, 0.031843783071963117, 0.06472543740528636, 0.05908210194320418, 0.05386752003687434, 0.03021830525540281, 0.005174433108550147, 0.045783754394506104, 0.03140638720651623, 0.01780498365405947, 0.03930608167138416, 0.03371200255060103, 0.035619221889646724, 0.01919751059176633, 0.033735639954102226, 0.05421389520051889, 0.01796345444745384, 0.1047429307072889, 0.04422097321366891, 0.030230083139031194, 0.015670694956497755, 0.030148753030516673, 0.030662068747915328, 0.08192758192308247, 0.028177747954032384, 0.010923265326709952, 0.02711918561544735, 0.030741521222807933, 0.06209915489307605, 0.06307697898591869, 0.039675177686149254, 0.023036634956952184, 0.04190783991361968, 0.03800228405452799, 0.02715996106417151, 0.040373512674705125, 0.08908184841857292, 0.07493684024666436, 0.033853426211862825, 0.02608835362480022, 0.11174628889421001, 0.02829167318850523, 0.019458037822914775, 0.05778497623396106, 0.08607034673332237, 0.037579868439934216, 0.034869396695285104, 0.039370670783682726, 0.03612668391724583, 0.057271751429652795, 0.06179464799060952, 0.01877543265436543, 0.0595244479336543, 0.022508919719257392, 0.08290416662930511, 0.06573592341737822, 0.005468198814924108, 0.00505022820107115, 0.0522811348491814, 0.014609790214308305, 0.04449989828572143, 0.03655165623058565, 0.03979539076681249, 0.05171475371753331, 0.05589613247138914, 0.03786600718740374, 0.0253537554453942, 0.09334830698207952, 0.010751616773632122, 0.03829813009360805, 0.08823869444313459, 0.018108618533005938, 0.05507856032636482, 0.05229023729043547, 0.06245534124900587, 0.03145558417600114, 0.027279025671305135, 0.12333470964222215, 0.07917109702248126, 0.03024102610652335, 0.042879322354565375, 0.08991552516818047, 0.06853514118120074, 0.02985004786751233, 0.015200248471956002, 0.05291368215694092, 0.0496675541944569, 0.062401869508903474, 0.03460714026005007, 0.021433924375742208, 0.06528161029564217, 0.009945107267412823, 0.05882062476302963, 0.031861694806138985, 0.048341655419790186, 0.03538605022185948, 0.029734386007476132, 0.041403598806937225, 0.06452390720369294, 0.08137831100611947, 0.01907603771542199, 0.025832436986092944, 0.03731668803084176, 0.02882395634514978, 0.05474332851008512, 0.0483988861378748, 0.05716643325285986, 0.0372215113020502, 0.010285894986736821, 0.061499210132751614, 0.03614772380387876, 0.006572360562131507, 0.03539244753483217, 0.01735314745019423, 0.0423496330040507, 0.03834358292806428, 0.039468983086408116, 0.02542521684517851, 0.050081539011443965, 0.01376989797790884, 0.05677252353052609, 0.010184945276705548, 0.04921190891764127, 0.032893985116970725, 0.04263968286977615, 0.05728065349103417, 0.05240088408754673, 0.013701416301046265, 0.047384644858539104, 0.02635579396155663, 0.035455210963846184, 0.04762416559970006, 0.028489822907431517, 0.04064018117787782, 0.04794855463842396, 0.10660247076884843, 0.059386916836956516, 0.027064878959208727, 0.02764180415397277, 0.016290063576889224, 0.03194317891029641, 0.0317112392076524, 0.036307081463746727, 0.00989379517704947, 0.05585387087194249, 0.08395688084419817, 0.02134909689630149, 0.06181834847666323, 0.033077918997150846, 0.06589922559214756, 0.06596080158487894, 0.038824813746032305, 0.05988336539303418, 0.030964829747972544, 0.0679927870805841, 0.021998231204634067, 0.02868105766538065, 0.05173842451767996, 0.021603724053420592, 0.023189814237412065, 0.10125533386599272, 0.20098591048736125, 0.17151329666376114, 0.08824523276416585, 0.09942860415321775, 0.12279518312425353, 0.12662611232372, 0.16056995809776708, 0.1759971896535717, 0.1749604390352033, 0.0940024211013224, 0.2539355051703751, 0.16200835903873667, 0.15925304673146456, 0.197207696037367, 0.1601241054595448, 0.10495529626496136, 0.12246267127920873, 0.16352505655959249, 0.1505330638610758, 0.16306246106978506, 0.12493144779000431, 0.03638917041826062, 0.11257344216573983, 0.2540664793923497, 0.14861562143778428, 0.16631039616186172, 0.09707726509077474, 0.28120892762672156, 0.08569928031647578, 0.10665271416655742, 0.20875747315585613, 0.11720923052052967, 0.15333706105593592, 0.05401655442256015, 0.0901088620594237, 0.1718585882917978, 0.16797807620605454, 0.1305059713195078, 0.1770778011996299, 0.16904463147511706, 0.11549826842383482, 0.1030153593455907, 0.0629870084230788, 0.11517084771185182, 0.18106576142599806, 0.10635892758728005, 0.14354825194459409, 0.17743277043337002, 0.17153953900560737, 0.14856435387628153, 0.15256334241712466, 0.1454229763476178, 0.10926963077508844, 0.1262841306743212, 0.11993920590612106, 0.21051971765700728, 0.11374599096598104, 0.10217663599178195, 0.12805790815036744, 0.15939546487061307, 0.21641373576130718, 0.2118886832613498, 0.18547649349784479, 0.10707766050472856, 0.10205156184383668, 0.12760159122990444, 0.16662150446791202, 0.1245030207792297, 0.07430358047713526, 0.16026450495701283, 0.2733916189754382, 0.12237185466801748, 0.09195279475534335, 0.16880111797945574, 0.11172746060765348, 0.13856853009201586, 0.212820345768705, 0.10119824786670506, 0.1381129553192295, 0.0926241341221612, 0.14512859605019912, 0.0904285347496625, 0.18534290691604838, 0.11293944713543169, 0.12500748824095353, 0.1640624160063453, 0.0806981029745657, 0.15527371026109904, 0.10903523085289635, 0.11081952456152067, 0.11774025202612393, 0.086393774690805, 0.24577798118116334, 0.2256029934505932, 0.10934226476820186, 0.07091224018950015, 0.19298214465379715, 0.11001806444255635, 0.13328393397387117, 0.11377919465303421, 0.12864690623246133, 0.20024731027660891, 0.2608960191719234, 0.17587618989637122, 0.12096479462343268, 0.13803623209241778, 0.19696591916726902, 0.14609960722737014, 0.079564086481696, 0.15064946230268106, 0.09397795991390012, 0.10531231382628903, 0.11357661060173996, 0.24894815403968096, 0.18860730284359306, 0.1498677729978226, 0.15918159275315702, 0.08770417742198333, 0.11990499289822765, 0.26972018473315984, 0.13335941039258614, 0.09402688971022144, 0.11342471523676068, 0.08341135035152547, 0.14521095959935337, 0.11903904014616273, 0.09147548989858478, 0.12820117233786732, 0.14232002722565085, 0.12896306114271283, 0.10740255049313419, 0.18308041035197675, 0.15076281793881208, 0.09337600393337198, 0.08260684000561014, 0.14452742674620822, 0.125503005401697, 0.10880589237785898, 0.08381933861528523, 0.09808887916733511, 0.1484764093765989, 0.11519527179189026, 0.10074459525640123, 0.15676228038500994, 0.07725100513198413, 0.1787130642333068, 0.14909270365023986, 0.19600875646574423, 0.11865819222293794, 0.18114141596015543, 0.2231205688440241, 0.1473457770771347, 0.15630916954251006, 0.09478740554186516, 0.1512630403158255, 0.1199712889501825, 0.11353082009009086, 0.11714731313986704, 0.11846066219732165, 0.13061573496088386, 0.1612718219985254, 0.10940420441329479, 0.16327234043274075, 0.10845153170521371, 0.2864779980154708, 0.2277422192855738, 0.10396309677162208, 0.2139250622713007, 0.11987980440608226, 0.13115365843987092, 0.10047876538010314, 0.09089489292819053, 0.20122624759096652, 0.17449092672904953, 0.12167735287221149], [0.07319197684410028, 0.04309670111979358, 0.03172176657244563, 0.05856908122950699, 0.023550395962956827, 0.026209290299448185, 0.023389880552713294, 0.00458936840914248, 0.08400056365644559, 0.06994638693868183, 0.017145685633295216, 0.05463615867483895, 0.02626904060889501, 0.07202629290986806, 0.02769435192021774, 0.01261732501006918, 0.032695397530915216, 0.02210787424701266, 0.03730010845174547, 0.04889770214504097, 0.01586065693118144, 0.02171060630644206, 0.02391441197687527, 0.04639740291167982, 0.02436995335301617, 0.020896199421258643, 0.014116024522081716, 0.04361820829217322, 0.08867026816005819, 0.09233704913640395, 0.03789247217355296, 0.031433638869202696, 0.030965770420152694, 0.012464905503293267, 0.031335107632912695, 0.020028335638926364, 0.04955672186042648, 0.03607230304623954, 0.03332079795654863, 0.010782947465486359, 0.048206480641965754, 0.0775060812884476, 0.0596359927294543, 0.0719430239405483, 0.04561195833957754, 0.026013947754108813, 0.039502468789578415, 0.05629938583297189, 0.05268356442684308, 0.06253471394302323, 0.029972847332828678, 0.054816010742797516, 0.05228200687270146, 0.05190262840187643, 0.00911583145352779, 0.02882138294808101, 0.016673145364620723, 0.05900068463233765, 0.01606501842616126, 0.02240236401121365, 0.009542274146951968, 0.047411751802428626, 0.05769452698586974, 0.009807024198380532, 0.021646404966304544, 0.03170844131091144, 0.05131897378305439, 0.031168454661383294, 0.03103133916738443, 0.03624557597504463, 0.025176001799991354, 0.03904697936377488, 0.009787888848222792, 0.022676363078062423, 0.07332612003665417, 0.01713180561637273, 0.06194584573677275, 0.0242995012740721, 0.10372517164796591, 0.09654133056756109, 0.008061444623308489, 0.06422148202545941, 0.03273984475526959, 0.05271377354802098, 0.025125385473074857, 0.08252099578385241, 0.04957006938639097, 0.030585048662032932, 0.016065159434219822, 0.04773385502630845, 0.04521777402260341, 0.018295014488103334, 0.005059302811787347, 0.04263944167178124, 0.015885839857219253, 0.03670832731586415, 0.12646843562833965, 0.057270890538347885, 0.006475707887148019, 0.0576935621938901, 0.06971870345296338, 0.021401050944405142, 0.013090367156110005, 0.066280815663049, 0.05190949697862379, 0.02319953822734533, 0.08618971376563422, 0.0776983865944203, 0.035684096728800796, 0.03197183694283012, 0.04384815532830544, 0.04012038836663123, 0.07580081146443263, 0.05593920301180333, 0.04302990040741861, 0.05729404183512088, 0.01858088235167088, 0.07931877698865719, 0.050003780488623306, 0.05086643810500391, 0.07731623991276138, 0.05130309553351253, 0.02884675512177637, 0.011776518076658249, 0.09852788178250194, 0.052418023988138884, 0.02554839480580995, 0.03979691959102638, 0.0557959276920883, 0.0030355043645613478, 0.06902561915921979, 0.05613373105006758, 0.015785293689987157, 0.018810942565323785, 0.032997117668855935, 0.06186014252307359, 0.033661748020676896, 0.052880771618220024, 0.06466404694947414, 0.03274136244726833, 0.015174072923400672, 0.009985417018469889, 0.0441345501167234, 0.0072479881509934785, 0.03217468816728797, 0.01864538797235582, 0.015260635173035553, 0.11365393496816978, 0.03745699847058859, 0.01631460454518674, 0.02064344247628469, 0.01734057175781345, 0.017238832588191144, 0.1177101802022662, 0.08636059326818213, 0.016164210173883475, 0.013942101286374964, 0.0950213750184048, 0.033907992619788274, 0.05113558167067822, 0.011276040586380986, 0.04135574883548543, 0.033071009602281265, 0.020703228037746157, 0.0312966198544018, 0.01984492682822747, 0.07938591166748665, 0.048873864361667074, 0.046757585732848383, 0.028733633262163494, 0.050257301845704205, 0.020176737343717832, 0.0653858672012575, 0.008400354709010571, 0.027348993498890195, 0.07434399041812867, 0.10508333158213645, 0.011304587296763202, 0.036772192834177986, 0.03914197426638566, 0.027855741209350526, 0.013747822795266984, 0.018909826321760193, 0.010397998248663498, 0.13707908423384652, 0.039019156247377396, 0.05667019620887004, 0.04163563127804082, 0.009258196714654332, 0.05603012352366932, 0.06749640902853571, 0.030397363225347362, 0.04803534880920779, 0.04992378810129594, 0.03459597835899331, 0.017331042581645306, 0.014465452695731074, 0.02839634569681948, 0.025872754158626776, 0.05549772904487327, 0.04916592544759624, 0.02499851161701372, 0.06572551108547486, 0.0772829694324173, 0.030340672419697512, 0.07578043951070867, 0.04456076552742161, 0.037143307490623556, 0.01217949591591605, 0.018160542895202525, 0.02248550681542838, 0.07319696407648735, 0.08313852944411337, 0.02763108383078361, 0.03121452718914952, 0.028894343486172147, 0.03196360281435773, 0.02534986473619938, 0.03594979672925547, 0.07464313530363142, 0.0366167351603508, 0.0503493504220387, 0.026661228548618965, 0.04522345887380652, 0.07877566589741036, 0.0699944410007447, 0.04004959118901752, 0.026155501291214023, 0.021115090312378015, 0.03843501181108877, 0.08246631434303708, 0.014153310021356447, 0.05579364558798261, 0.02853447793313535, 0.051949123953818344, 0.03918047317711171, 0.020148261137364898, 0.03977884087362327, 0.057034386627492495, 0.02352687359234551, 0.017837818122643512, 0.09125933196628466, 0.059294478633091785, 0.03425659793720115, 0.048110465286299586, 0.041780680330703035, 0.004369999296613969, 0.05202912005188409, 0.07353806999162771, 0.023441396733687725, 0.012135635915910825, 0.026185396854998544, 0.057298832398373634, 0.009768869458639529, 0.04469815190532245, 0.03264307611971162, 0.07192485616542399, 0.0579861910227919, 0.0645950940088369, 0.10521499600145034, 0.010768217689474113, 0.012319565157667967, 0.04747186576423701, 0.05161971057532355, 0.016348943718185183, 0.03211482282495126, 0.042001680776593275, 0.03187792557582725, 0.060579017517738976, 0.05092324208817445, 0.0493295764317736, 0.06489202729426324, 0.056508626948925667, 0.013981298743601656, 0.04905176829197444, 0.014266409616539022, 0.048620721499901265, 0.010732264345278963, 0.00832946197988349, 0.01950709007360274, 0.01919607453601202, 0.07295008123037405, 0.07465465343557298, 0.03593023371649906, 0.034588159833219834, 0.010897630618273979, 0.10326817937311716, 0.05077051551779732, 0.06917831604368985, 0.030970497900852934, 0.06044138994184323, 0.036003487402922474, 0.04001936722488608, 0.03738737017556559, 0.02502492836356396, 0.03900557123415638, 0.07144626739318483, 0.04585054026392754, 0.032521423272555694, 0.06649172661127523, 0.03630115170381032, 0.08843081421218812, 0.033836694492492825, 0.049174207815667614, 0.02784861844702391, 0.029436410004564095, 0.03413679303776007, 0.05689430996426381, 0.03417291336518247, 0.01573021334479563, 0.015466480963368667, 0.04294800812203903, 0.03577890609449241, 0.030819845633232035, 0.08271308586699888, 0.020984561379009392, 0.048228926898445934, 0.07461585395503789, 0.08632079930976033, 0.009125178803515155, 0.015959436786943115, 0.03895714609825518, 0.07271842725458555, 0.11173721242812462, 0.05779289494967088, 0.03108523949777009, 0.0922125687066, 0.008600815290265018, 0.01813677190511953, 0.059517545960261486, 0.019900291044905316, 0.05873648748092819, 0.02901252308220137, 0.018012805412581656, 0.021289179603627417, 0.0965287140570581, 0.04488328435400035, 0.0300909823999973, 0.018536407296778634, 0.022261333688220475, 0.033658133761491627, 0.03436457300267648, 0.05303117155563086, 0.019543379239621572, 0.02220271144324215, 0.10382751381257549, 0.01254061569852638, 0.022499718943436164, 0.00418660069044563, 0.05510217175469734, 0.023725926876068115, 0.09190416181809269, 0.2731505100382492, 0.10961912295897491, 0.23540464171674103, 0.1627413189271465, 0.06542549046571366, 0.15229383890982717, 0.11021723461453803, 0.08693867435795255, 0.26522193860728294, 0.10207101353444159, 0.13192939572036266, 0.18676327366847545, 0.11558734840946272, 0.12302146395086311, 0.2414666672120802, 0.10051696372102015, 0.09002262449939735, 0.14836542861303315, 0.12038341097650118, 0.20975155028281733, 0.15850151830818504, 0.14894351712428033, 0.10566639248281717, 0.13463017501635477, 0.12070283875800669, 0.15454866166692227, 0.1616761737386696, 0.2016118378378451, 0.11126275741844438, 0.15504459443036467, 0.09165609153569676, 0.1559357950463891, 0.1248427908285521, 0.0844165300077293, 0.1917182671604678, 0.11219700259971432, 0.28930810396559536, 0.1616039330838248, 0.13723646407015622, 0.08701400976860896, 0.23734972171951085, 0.11804661800852045, 0.22704485279973596, 0.20648283505579457, 0.16792468610219657, 0.11962639066041447, 0.07964688789797947, 0.16922188602620736, 0.24288648477522656, 0.1649401689064689, 0.1866284105926752, 0.08987489258288406, 0.18168264941778034, 0.09343456680653617, 0.21971464535454288, 0.12616161693586037, 0.1179258557385765, 0.11620496370596811, 0.0885926246701274, 0.1805809757206589, 0.16648019955027848, 0.15384529862785712, 0.13313854724401608, 0.15288077382138, 0.07725502015091479, 0.13259922852739692, 0.18218728015199304, 0.14040536043467, 0.15025958244223148, 0.09695630986243486, 0.1144067250424996, 0.20662750932388008, 0.17037533194525167, 0.12184654027805664, 0.17879268183605745, 0.0793495835387148, 0.14579973503714427, 0.14893087092787027, 0.14443179359659553, 0.20329716615378857, 0.12476867996156216, 0.21083266648929566, 0.10273902807966806, 0.22201546642463654, 0.10461065772688016, 0.2163178354385309, 0.12261996205779724, 0.13785750808892772, 0.12262237403774634, 0.06539138877997175, 0.18765923887258396, 0.14343189803184941, 0.12231772241648287, 0.0856738691800274, 0.17429875500965863, 0.2936564659466967, 0.34071735630277544, 0.19980251148808748, 0.08922021443140693, 0.19237344997236505, 0.21466651232913136, 0.08797916540061124, 0.05990150719298981, 0.24263915664050728, 0.09070591986528598, 0.16189436515560374, 0.16487241082359105, 0.2018005956779234, 0.18719477317063138, 0.09035797134856693, 0.26979906018823385, 0.10305156130925752, 0.18251527973916382, 0.19840384513372555, 0.12902934977319092, 0.11823783977888525, 0.06932503121788613, 0.25709874636959285, 0.14622976508690044, 0.17279072577366605, 0.1113922028162051, 0.1019045127031859, 0.11465892166597769, 0.11839111553854309, 0.22716724779456854, 0.20937685476383194, 0.132853903924115, 0.19451258674962446, 0.1260491815628484, 0.11298137105768546, 0.1719436384155415, 0.17386054649250582, 0.09798987666727044, 0.08666079200338572, 0.16906995355384424, 0.15758195280795917, 0.12831629428546876, 0.143769501009956, 0.1384207239607349, 0.22726887749740854, 0.14162077568471432, 0.24493010714650154, 0.2110170605010353, 0.08180160235497169, 0.1155159760673996, 0.10160272577195428, 0.18115899001713842, 0.17487236094893888, 0.1962737031863071, 0.1286006555892527, 0.10726418448030017, 0.11839971703011543, 0.07551485454314388, 0.1829513508710079, 0.1199773077678401, 0.13735878485022113, 0.12866992765339091, 0.12116277735913172, 0.14207931904820725, 0.15187736047664657, 0.12413304531946778, 0.09478475607465953, 0.09491105476627126, 0.11741307622287422, 0.1059987633198034, 0.09127930316026323, 0.165974989940878, 0.12552731815958396, 0.1486426207702607, 0.13519952102797106, 0.22339198709232733, 0.15787759475642815, 0.13813622907036915, 0.10866906261071563, 0.10589425408397801, 0.2499390102457255], [0.03230074937164318, 0.05521204671822488, 0.06708065047860146, 0.039059146874933504, 0.001065998426383885, 0.1289968437049538, 0.030489708660752513, 0.03985446201113518, 0.013784564671368571, 0.0631024717586115, 0.03279865253716707, 0.03409891010960564, 0.04181077812972944, 0.02646504552103579, 0.08673033866216429, 0.05891589797101915, 0.0391547800245462, 0.01757129248289857, 0.029507958606700413, 0.0825944090320263, 0.03438162755628582, 0.029359141299210023, 0.09236072364728898, 0.013691364838450681, 0.02894790242862655, 0.022117475782579277, 0.08007956741494127, 0.01979699150979286, 0.05021391960326582, 0.009254596370738, 0.015535850434389431, 0.02170912757719634, 0.04276342115190346, 0.05571772016992327, 0.054486092703882605, 0.04471390770049766, 0.033197081938851625, 0.01844116377469618, 0.014685057903989218, 0.050269339481019415, 0.005628086646538577, 0.006742007171851583, 0.01971563728147885, 0.047842713247518986, 0.028040925608365797, 0.020186288784316275, 0.04946372333506588, 0.018294886467629112, 0.08739508033613674, 0.054998553096083924, 0.026860712277994025, 0.006610444797843229, 0.046998152902233414, 0.02985110171721317, 0.05280889090499841, 0.0710714234446641, 0.011897964050149312, 0.03136498278763611, 0.022170884440129157, 0.04623799330147449, 0.035825338563881814, 0.02995216924318811, 0.059808798105223104, 0.020348316320450976, 0.017436711423215456, 0.038149028914631344, 0.027425790940469597, 0.014055464343982749, 0.036090430003241636, 0.0642455869819969, 0.03561160003300756, 0.03993685153545812, 0.04326499423768837, 0.0675402328488417, 0.05244489715551026, 0.04874881618889049, 0.03835841846012045, 0.07179774853284471, 0.05634234505123459, 0.047887995388009585, 0.0648578662367072, 0.018214673291367944, 0.058013761808979325, 0.05643946620693896, 0.06004585862683598, 0.02049518734565936, 0.049961285112658516, 0.07159284155932255, 0.030570641720260028, 0.06282487884163857, 0.04361613027867861, 0.08028006603126414, 0.010015130756073631, 0.02122388545103604, 0.01144981075412943, 0.029424420608847868, 0.03376993459824007, 0.041624614095781, 0.005535313548534759, 0.039165069902082905, 0.0128294772002846, 0.017853714925877284, 0.02200984767114278, 0.023111940681701526, 0.09418990986887366, 0.04798497924639378, 0.03212045572581701, 0.02139249954780098, 0.008267941648227861, 0.019870081923727412, 0.04309319447202142, 0.021681465877918527, 0.09367752369144, 0.03255870506109204, 0.039055580855347216, 0.026215420439257286, 0.02765350967820268, 0.030941027216613293, 0.047252709555323236, 0.03285553815658204, 0.03941193419450428, 0.020451489690458402, 0.05236359116679523, 0.012020718058920465, 0.04735723363410216, 0.05622918608423788, 0.026490024356462527, 0.03594441986933816, 0.014371148918144172, 0.014902751154295402, 0.033984170368057676, 0.01715857673843857, 0.05858018004801124, 0.027387356967665255, 0.02395913008513162, 0.07780121857649647, 0.045366634003585204, 0.03252088892622851, 0.0946170232782606, 0.07663695214432664, 0.025434308154217433, 0.06052541590179317, 0.029517831026169006, 0.05133862214279361, 0.007935135727166198, 0.0375507243006723, 0.09517938568023965, 0.055712246830808, 0.012724578336928971, 0.06003751317621209, 0.042069260744028725, 0.057652161485748366, 0.0698828071472235, 0.04021568383905105, 0.004635256327674142, 0.06125893611169886, 0.03707944939378649, 0.005404701123552513, 0.061246297336765565, 0.048062103232950903, 0.07325715967454016, 0.03023778848728398, 0.04582981579005718, 0.04390748632431496, 0.024825338878144976, 0.030467870965367183, 0.022307248509605415, 0.07039712290861644, 0.05040481482865289, 0.0496823155117454, 0.02361107210163027, 0.009591139933036175, 0.09093395216041245, 0.027389781935198698, 0.018372984523011837, 0.034058830424328335, 0.0523517130932305, 0.03041098163521383, 0.052674784819828346, 0.011466977557574864, 0.026237382444378454, 0.035825672530336305, 0.05956509165116586, 0.06827102566603571, 0.029350582481129095, 0.020357505964057054, 0.017395015711372253, 0.0191801220717025, 0.06436603754991665, 0.05962074901617598, 0.10787234481540509, 0.04583284004183952, 0.03606977974413894, 0.031972104115993716, 0.011076194132328965, 0.013159339578123763, 0.002333256634301506, 0.06529540682095103, 0.029929118136351462, 0.04988698128727265, 0.029089546878822148, 0.026900198245130014, 0.09314014198025689, 0.0329086647980148, 0.007795108231221093, 0.027832074119942263, 0.019603754808485974, 0.07534761898568831, 0.05640134208078962, 0.018256777184433304, 0.03438261461269576, 0.06777746035368182, 0.03384276897122618, 0.024104923140839674, 0.017292519551119767, 0.021273596357787028, 0.03104479987086961, 0.021259766435832717, 0.04836167114262935, 0.010941574109892827, 0.025487635175522882, 0.10858520734473132, 0.04177480994258076, 0.04938025027513504, 0.058506566419964656, 0.02768105077848304, 0.013634502411150606, 0.04164872647379525, 0.023698077784501947, 0.006988957275098073, 0.06698355529806577, 0.11133306848932989, 0.0443168512720149, 0.06970101065235212, 0.02098680823110044, 0.047120347517193295, 0.050495538671384566, 0.12769106455380097, 0.06766630147467367, 0.057398120625293814, 0.010979996022797422, 0.0202746340437443, 0.035388989126659, 0.012863907286373433, 0.0651377894973848, 0.17605157423531637, 0.015844530062167905, 0.024769264055066742, 0.04854333776165731, 0.01673106071393704, 0.02163371980714146, 0.019651211441669147, 0.043374546366976574, 0.0473543244152097, 0.0124339356807468, 0.02344613163586473, 0.036863113346043974, 0.05990670222672634, 0.02367136417888105, 0.03841729303530883, 0.03414039245399181, 0.016060322486737277, 0.0604430560633773, 0.017612539195397403, 0.021066934205009602, 0.03150452139379922, 0.058326658690930344, 0.04740984077216126, 0.019869291536451783, 0.021963595172564965, 0.066209947981406, 0.018365730029472616, 0.04714255628641695, 0.03936678564059548, 0.023286456707865, 0.06392114970367402, 0.029338210879359394, 0.03433634541579522, 0.034421866803313605, 0.018693833517318126, 0.035639248744701035, 0.03987354262790177, 0.06129386900283862, 0.021760116833320353, 0.04277229723811615, 0.0645987008465454, 0.048217623989330605, 0.024493025557603687, 0.03506303415633738, 0.01590095183928497, 0.02208542799053248, 0.05824108906381298, 0.013668194060301175, 0.04795847715286072, 0.0061727084721496794, 0.02444254838337656, 0.01914637290610699, 0.026438092572789174, 0.02993985701323254, 0.033242594145121984, 0.013293584815983195, 0.0499712039163569, 0.04440624667040538, 0.035521095123840496, 0.0665945808577817, 0.07343552002566867, 0.015284356995834969, 0.027735819421650376, 0.036399356395122595, 0.048655654391041026, 0.07159433327615261, 0.035971630713902414, 0.06022901325195562, 0.036179413509671576, 0.0650671667244751, 0.012838803213526262, 0.04229416488669813, 0.08719334233319387, 0.03197529164026491, 0.02652887393196579, 0.0063863704690447776, 0.0595549019635655, 0.03215164448192809, 0.09188052441459149, 0.019730771527974866, 0.052571466731023975, 0.044569207457243465, 0.04490435021580197, 0.06715551091474481, 0.04058105798321776, 0.06335821584798396, 0.03314017776574474, 0.03952852559450548, 0.026673357097024564, 0.021865555609110743, 0.013464737985486863, 0.07097931549651548, 0.03785955050261691, 0.045022796984994784, 0.03175963836838491, 0.04184813042229507, 0.03381542454008013, 0.05438314197817817, 0.08683573105372488, 0.011251479209022364, 0.008893411650205962, 0.02505798176571261, 0.032625130988890305, 0.025422051585337613, 0.039866135994088836, 0.005985444204270607, 0.012521040625870228, 0.08476012211758643, 0.12715091463178396, 0.13774473132798448, 0.11502699722768739, 0.07843418148695491, 0.17107781925005838, 0.13797519786749035, 0.17659550911048427, 0.07201790664112195, 0.1585070844157599, 0.14597664820030332, 0.07929436775157228, 0.10909923366853036, 0.22877660987433046, 0.12221650089486502, 0.12845617427956313, 0.16477376455441117, 0.15035037678899243, 0.14555267407558858, 0.14208625070750713, 0.13038549106568098, 0.15978791256202385, 0.10691253264667466, 0.07804330714861862, 0.07891446235589683, 0.11671857442706823, 0.2666446060175076, 0.09529847811791115, 0.19711825239937752, 0.07819043050403707, 0.13872852228814736, 0.19404534541536123, 0.1669571184902452, 0.1667387192719616, 0.21080108068417758, 0.11109022292657755, 0.1476149243535474, 0.11355519221979193, 0.10540995819610544, 0.15213328268146142, 0.17036467470461503, 0.08824208605801687, 0.10928662595688365, 0.1343448637635447, 0.12049990589730442, 0.23792356514604762, 0.16517707728780806, 0.13869315152987838, 0.1654854990192689, 0.09431870959815569, 0.16558576317038387, 0.14548163569997996, 0.11882034406880848, 0.1277822002884932, 0.1466328403330408, 0.23689016903517768, 0.1406924973707646, 0.2343276666942984, 0.09962779658962972, 0.25802545133046806, 0.09883727572741918, 0.1766775461146608, 0.15032401570351794, 0.10752625908935443, 0.12661643471801654, 0.29159216734115034, 0.09342752382508479, 0.12833894463256001, 0.11999610636848956, 0.32806103699840605, 0.1513357411022298, 0.14768161374377087, 0.15489797573536634, 0.10327017575036734, 0.07432833110215142, 0.14701890555443242, 0.0854010037437547, 0.17838635598309338, 0.08872317586792633, 0.12362281879177317, 0.08472725981846452, 0.14025752461748198, 0.19195133121684194, 0.15634859242709354, 0.2090682103880681, 0.11592053560889326, 0.1739884927519597, 0.14174179028486833, 0.13403586315689608, 0.1159795511921402, 0.1795201053027995, 0.13484235503710806, 0.08350632298970595, 0.1711392542347312, 0.15415872243465856, 0.13937451731180772, 0.1704327593324706, 0.11481262787128799, 0.13862904481356964, 0.17933838302269578, 0.1197135410620831, 0.15095145703526214, 0.10322143891244195, 0.14287562866229564, 0.18120844673831016, 0.08400313890888356, 0.19673983129905537, 0.13769370125373825, 0.2092805239954032, 0.1663547320640646, 0.16134646721184254, 0.11281327460892498, 0.11404158838558942, 0.1006736682029441, 0.16611552302492782, 0.13072880858089775, 0.16918578796321526, 0.1470541872549802, 0.11691073872498237, 0.1058574509806931, 0.16398995270719752, 0.08819105598377064, 0.10142036524484865, 0.09776175531442277, 0.11613021459197626, 0.12243219127412885, 0.12699473707471043, 0.17185564938699827, 0.09534869925118983, 0.14925054361810908, 0.07763439120026305, 0.2234651183243841, 0.20238948985934258, 0.17667931242613122, 0.15693459223257378, 0.19932367780711502, 0.13057890959316865, 0.15172694198554382, 0.14250724139856175, 0.1351020621950738, 0.18448370770784095, 0.13298098929226398, 0.0815655400219839, 0.1379048719536513, 0.0924071078770794, 0.1923073988291435, 0.2490974444663152, 0.2112407289678231, 0.07956837609526701, 0.1243925595190376, 0.16365944466087967, 0.1701762730954215, 0.11552313037100248, 0.10867160817724653, 0.16264372650766745, 0.14586643927032128, 0.0869791659351904, 0.14037754473974928, 0.1161186074023135, 0.07652983797015622, 0.1772490146686323, 0.1067497870826628, 0.16828406369313598, 0.12911603262182325, 0.20417300431290641, 0.12419217222486623, 0.10697586752939969, 0.23737504379823804, 0.1624015488778241, 0.13262155232951045, 0.16044217511080205, 0.10863752133445814, 0.0939600593119394, 0.1871567009948194, 0.06631633485085331, 0.170906605781056], [0.03349752558278851, 0.02519567613489926, 0.07442366739269346, 0.034821624649339356, 0.040341470448765904, 0.008835406315483851, 0.016081217654573265, 0.03368333709659055, 0.028784383175661787, 0.053064879903104156, 0.004527006667558453, 0.025770616084628273, 0.044866419048048556, 0.10604954848531634, 0.011865535907418234, 0.028060388431185856, 0.011703780182870105, 0.015516549956373638, 0.034852182579925284, 0.06062025124265347, 0.012420011134963715, 0.033916211905307136, 0.0548389431060059, 0.08673953387187794, 0.0386843214801047, 0.05020904369303025, 0.02510312660888303, 0.045217358419904485, 0.009058552495844197, 0.02430464250210207, 0.07762817942420952, 0.009520083003735635, 0.003446072287260904, 0.04460525728063658, 0.08482765013468452, 0.02088323781208601, 0.03346058147144504, 0.03971709418692626, 0.031804007667233236, 0.018841292694560252, 0.01653733790590195, 0.016413326884503476, 0.06700553029077128, 0.05225839915510733, 0.029315202446014155, 0.012601090529642534, 0.04188896338746417, 0.04622904671123251, 0.036933654482709244, 0.04285404851543717, 0.05259543810097966, 0.044249939237488434, 0.07114335981896147, 0.020830020257562865, 0.004000199169240659, 0.00874274917805451, 0.0892164814285934, 0.04421430501679424, 0.11576118908124045, 0.0826614694960881, 0.09181373112369329, 0.06770984327886254, 0.03711116878548637, 0.024059999086603057, 0.029391519346972927, 0.028661201504291967, 0.032724178017815575, 0.06772896100301296, 0.02916859302786179, 0.03197698373696767, 0.026990120568370912, 0.025793739550863393, 0.013651899280375801, 0.05693352875823621, 0.04189267412584741, 0.015660149038012605, 0.027604928691289388, 0.0946665764786303, 0.028254242970433552, 0.07203922112239525, 0.04756407761306036, 0.024091853920253925, 0.02436752838548273, 0.02005965983698843, 0.015885225730016828, 0.02640860890096519, 0.05549625217099674, 0.04351401446911041, 0.03155240847263485, 0.060390322760213166, 0.034390997170703486, 0.0027877696720679523, 0.06311295088380575, 0.04813439583813306, 0.05790343042463064, 0.014296864574134815, 0.04814680083654821, 0.04561786583508365, 0.0354340931517072, 0.07493958619306795, 0.07812046824255958, 0.04133002228627447, 0.056135801642085426, 0.03590939049900044, 0.047668579427408986, 0.01688228629063815, 0.02943042643892113, 0.12923968926770613, 0.0052551091994246235, 0.008108438341878355, 0.03492697993351612, 0.04608563038345892, 0.016606819626758806, 0.022832392205600627, 0.04304363013943657, 0.12534997455077246, 0.01122908026445657, 0.057569133714423515, 0.008283407078124583, 0.07356829024502076, 0.05631169435218908, 0.08062932814937085, 0.05775107863883022, 0.06049493589671329, 0.033279363851761445, 0.04559197972412221, 0.04410327230289113, 0.03215250908397138, 0.01729484061797848, 0.042720213314169087, 0.01890468138299184, 0.038919500657357275, 0.03641121962573379, 0.013287723704706877, 0.03089255013037473, 0.07735245671938173, 0.02511759477783926, 0.030878532816132065, 0.07196050151833333, 0.03513948649924714, 0.032089226151583716, 0.04958356905262917, 0.016272589709842578, 0.014812628451181808, 0.03012878183653811, 0.08831218932755291, 0.020567286992445588, 0.05214334400079679, 0.03830106528766919, 0.03527027147356421, 0.031947509341989644, 0.04199482704279944, 0.05855055722349789, 0.016493209805048537, 0.03683939059555996, 0.01459326536860317, 0.01406969038725947, 0.050202824495499954, 0.014232141875254456, 0.02177978374675149, 0.02037307251157472, 0.0591787481243955, 0.025095590099226683, 0.05698312648746651, 0.02085795840685023, 0.0415811019774992, 0.017028342808771413, 0.07431221907609142, 0.03587439452530816, 0.07219393664854579, 0.02974810831801733, 0.04727288112917449, 0.10557096713455394, 0.04767091719259042, 0.00619390189058322, 0.0238305696984753, 0.060563087317859754, 0.014774698211112991, 0.016508950757270213, 0.019417273506405763, 0.046432662347797304, 0.02749833402049262, 0.046813773733447306, 0.01398224962031236, 0.09294405172113329, 0.05818595120217651, 0.05366780067561194, 0.016385385024477728, 0.021602475389954634, 0.060510610055644065, 0.010441937101859367, 0.03510988593916409, 0.049289882663288154, 0.03176047699525952, 0.05523790685401764, 0.08191211556550115, 0.043085554061690345, 0.046433100214926526, 0.059209005485172383, 0.03392585611436516, 0.046904018890927546, 0.06210008999914862, 0.025080659943341743, 0.030608253764512483, 0.053487002369365655, 0.04491482563025784, 0.06439481061534025, 0.0558945257216692, 0.013681984091817867, 0.06648624956142157, 0.027572148028411902, 0.04693805007264018, 0.023372748073597904, 0.032199553825194016, 0.03905778874468524, 0.18430222291499376, 0.08369954113732092, 0.0247177719938918, 0.016985567272058688, 0.024383536510867998, 0.009049376767507056, 0.013951158271083841, 0.03842608377453871, 0.05061619704065379, 0.023259503759618383, 0.007234032991618733, 0.040298826643265784, 0.05837211894686334, 0.014654979586339323, 0.06398801720933989, 0.1350343189551495, 0.026266684290021658, 0.03283982689026743, 0.06366264482494444, 0.03359452428412624, 0.0821520815952681, 0.07556045209639706, 0.09905702565447427, 0.037569953346974216, 0.010520425712456927, 0.04183097567874938, 0.027829953432956245, 0.0374669543816708, 0.04906519745418336, 0.03493686534056906, 0.05818707184516825, 0.04775794885063078, 0.03032828597497428, 0.008586523381381994, 0.00852923792990623, 0.04412728078023065, 0.019554971586330794, 0.028035596988047473, 0.01172560767372488, 0.048152556191780604, 0.0108074160743854, 0.04800579648872372, 0.07433040911564603, 0.021903681590629276, 0.008728878437977983, 0.04823317940463312, 0.018321973002457526, 0.004678074074035976, 0.023130453555495478, 0.03167284419760108, 0.07306558167329058, 0.015105030925042229, 0.014713156542711658, 0.041501566010992974, 0.00944888784943032, 0.049621314683463424, 0.030745291333005298, 0.007774634232191602, 0.055153097928268835, 0.09879639081191272, 0.049712546897353604, 0.026280877864337526, 0.05433763719338458, 0.06170675915200263, 0.05445843285997398, 0.020723022971651517, 0.01541680067020934, 0.04076122917467728, 0.07455161365214735, 0.023411100410157815, 0.044929787327419035, 0.007911443590273848, 0.056633986823726445, 0.06417652271920815, 0.04264380921085831, 0.045652542685274966, 0.05713918901165016, 0.02145032398402691, 0.06252436840441078, 0.021355150965973735, 0.0706824786902871, 0.02923229712905595, 0.041211564384866506, 0.05562547121371608, 0.024284795617859345, 0.03600609605200589, 0.027101737723569386, 0.018225677486043423, 0.06469541011028923, 0.00553455655790458, 0.02974377232021652, 0.020498807170952205, 0.02397308431682177, 0.05767270784417633, 0.03594574089220259, 0.011108944181614788, 0.05461278844450135, 0.04644849606847856, 0.03872608212986961, 0.0888521240267437, 0.025290105149906594, 0.01403993397616432, 0.02960006098874146, 0.033426412992412224, 0.028882613842142746, 0.00756648824790318, 0.005050643339927774, 0.04018506653665099, 0.03770068637095392, 0.09221213826094754, 0.02375782438321039, 0.028604132203327026, 0.032933070324361324, 0.009439556270081084, 0.06425524974474683, 0.059281476205796935, 0.049618457414908335, 0.03454749385127798, 0.014059798486414365, 0.06509896033094265, 0.03313451888971031, 0.012341301735432353, 0.02870443346182583, 0.07687717792578042, 0.03554755268851295, 0.08736485266126692, 0.0684981005906593, 0.007524418679167866, 0.04010089214716572, 0.018879008639487438, 0.04098077872185968, 0.022689192956022453, 0.01677246327744797, 0.03169717550917994, 0.008485601501888596, 0.04082386272784788, 0.08209339997847565, 0.23817653360310942, 0.1036436838330701, 0.14766748325200751, 0.09792651209863834, 0.16272521432256326, 0.09101437870413065, 0.1441746691125445, 0.07910250773420557, 0.14230980043066666, 0.1389658314292319, 0.09308844397310168, 0.12390664574922994, 0.16201857099076733, 0.23034101264784113, 0.1306412648409605, 0.11546260822797194, 0.059191149412072264, 0.12147929592174478, 0.35754828597418964, 0.23851023288443685, 0.14261446689488366, 0.10874903644435108, 0.15886865876382217, 0.16616670152870938, 0.1415103441104293, 0.10372992881457321, 0.11691041960148141, 0.16619466565316543, 0.15817311796126887, 0.1267454496701248, 0.2123730830498971, 0.09510365693131462, 0.08059343788772821, 0.1369901155703701, 0.26652740605641156, 0.10832372645381838, 0.14675410726340488, 0.12937559135025367, 0.10799281022627838, 0.3110322804423049, 0.1612106541870162, 0.1497900256072171, 0.16516742936801165, 0.10577460503554903, 0.08785749028902501, 0.07271502079674974, 0.12716330849798396, 0.11796778708230704, 0.1887020602589473, 0.18461787316482514, 0.2688444801606238, 0.14407059032237157, 0.11946139638894238, 0.16426030226284638, 0.1794094213983044, 0.08619376589194871, 0.12125363849918358, 0.10633880796376616, 0.21676350996131077, 0.1795496724662371, 0.20004176505608484, 0.2255076274741441, 0.10143698193132877, 0.14514385460643098, 0.12044859380694106, 0.11932962806895375, 0.0756012553756591, 0.13058705837465823, 0.10584480478428304, 0.10614272512611933, 0.10039908840553835, 0.08585286777815782, 0.0762532617955003, 0.09052587483893149, 0.10205918370047584, 0.10865411575650796, 0.11725743301212788, 0.21584845671895891, 0.14319141249870881, 0.12893273698864505, 0.1779792582965456, 0.18585725978482515, 0.08511749590979889, 0.08376638637855649, 0.1045757916290313, 0.13596158794825897, 0.19758151582209393, 0.10489045482245274, 0.2065861865412444, 0.1999127649469301, 0.08244977187132463, 0.09116737986914814, 0.12743016995955259, 0.19421394652454183, 0.1767452002968639, 0.08073869845247827, 0.13642173435073346, 0.17021565145114437, 0.16965069895377383, 0.23955529555678368, 0.19264051923528314, 0.21173675078898668, 0.12198069831356406, 0.11502224006108008, 0.16867237020051107, 0.08031333651160821, 0.229282071813941, 0.17799316614400595, 0.135318695101887, 0.16058549867011607, 0.07965461365529336, 0.12324916970101185, 0.15553908742731437, 0.1489371049683541, 0.1215294873691164, 0.20548044587485492, 0.08318354812217876, 0.17129284911789, 0.11466073992778547, 0.20676338172052056, 0.182161349512171, 0.15110203879885375, 0.17223107221070677, 0.10993353382218629, 0.0839009674382396, 0.07039663309114985, 0.18248295178636909, 0.193255418271292, 0.10611003352096304, 0.07945713558001444, 0.09519469618680887, 0.17280632571782917, 0.15617991710314527, 0.10739641293184832, 0.11277100187726319, 0.11090995525592007, 0.10281869763275608, 0.07656935733393766, 0.24420756701147184, 0.14681364235002548, 0.1834098793915473, 0.1389949829899706, 0.08267106546554714, 0.12701305327937007, 0.2041260857367888, 0.13597062730696052, 0.06571367383003235, 0.1245562921394594, 0.2076371418661438, 0.1304503993014805, 0.1277443952858448, 0.13055038143647835, 0.1491153094684705, 0.11129573846119456, 0.15943479869747534, 0.15595596662024036, 0.18108973279595375, 0.22550456982571632, 0.14654290687758476, 0.11548922164365649, 0.06677412122371607, 0.16904982650885358, 0.10642304172506556, 0.11586677443119697, 0.12650177290197462, 0.11911276509636082, 0.11099001072579995, 0.21488035476068035, 0.10336923020076938, 0.14020879520103335, 0.09249279624782503, 0.09891127527225763, 0.18770223890896887, 0.08869833618518896, 0.1118407271860633, 0.18738603946985677], [0.03575745060516056, 0.0386316920776153, 0.03694763654493727, 0.013326467524166219, 0.026330867076467257, 0.010254578210151521, 0.017551877899677493, 0.03361238035722636, 0.05365455705032218, 0.015386357772513293, 0.07839199039153755, 0.013555351433751639, 0.05939765200309921, 0.058146146111539565, 0.04867724717769306, 0.10458535791258328, 0.041681655566208065, 0.059997908465447836, 0.008528430844307877, 0.054912898121983744, 0.03418552616494708, 0.08146750973537564, 0.0535360360663617, 0.05856109200976789, 0.039231191549333744, 0.042216829388053156, 0.015448559024662245, 0.051026923829340376, 0.010815319947141688, 0.042690386399044655, 0.08470590822980739, 0.024976015265565366, 0.024933831591624767, 0.037919631067779846, 0.020365539712656755, 0.022928661746846046, 0.10354008001741022, 0.038181104537216015, 0.030898375989636406, 0.016253342109848745, 0.033392756595276296, 0.015746559147373773, 0.028777084153261967, 0.027395503893785644, 0.006435457507905085, 0.08474493777612224, 0.06543879717355594, 0.05836290518345777, 0.043873054382856935, 0.047907365442370065, 0.024710328252695035, 0.0486548417393351, 0.03836861556919757, 0.10997576944646426, 0.032629134875605814, 0.024999365086841863, 0.01942718488862738, 0.04789443722984288, 0.03982853137131315, 0.02651872877322603, 0.03470306284725666, 0.02088050670863595, 0.023929217823024374, 0.014766942767892033, 0.032734093110775575, 0.011701033308781916, 0.005801822953799274, 0.02704463873669738, 0.04197536421997938, 0.03802093422564212, 0.024692102961125784, 0.03955667154514231, 0.08712372888112441, 0.03708647011080757, 0.018646840726432856, 0.024445537383144256, 0.018072119710268453, 0.04128137450607028, 0.02941842220025137, 0.12469433160731569, 0.08053294543060474, 0.010847662742889952, 0.019013290984730702, 0.03822234568360727, 0.05891806875297334, 0.023159028096415568, 0.05468015318911057, 0.01581179578352021, 0.05841578691615723, 0.04164407691860106, 0.03957889886805788, 0.03657989494968206, 0.012232660592417233, 0.061947786452947184, 0.06269024583161809, 0.03567793690308463, 0.0317483540129615, 0.09251195107935928, 0.03036247300769901, 0.03710632256115787, 0.032457505803904496, 0.049652573943603784, 0.059488980696187355, 0.039653544081375, 0.04644605811336078, 0.04125407831452321, 0.03205341752618551, 0.02938930589152733, 0.11426560566178523, 0.03222456791263539, 0.06460542470449582, 0.06836883330834098, 0.011574089876376092, 0.0636058185773436, 0.05998783381073736, 0.022405638737836853, 0.017401592995156534, 0.04418550968694035, 0.029293798907019664, 0.08322738678543828, 0.024642187963763718, 0.01929787493281765, 0.040935077267931774, 0.025780301111808512, 0.0540629312308738, 0.05354782137146685, 0.025016412218974438, 0.039213290947373025, 0.09921160017256625, 0.06289983575697988, 0.049812755387392826, 0.04789525359228719, 0.08517314214259386, 0.06737908290233463, 0.016108127929328475, 0.09426537886611186, 0.04155124908720609, 0.037736201848019846, 0.047397246526088566, 0.032497002903255634, 0.04378764431749005, 0.04255974243278615, 0.039949241690919735, 0.043815560202347115, 0.01836855761212064, 0.03541333899192978, 0.013308727411640575, 0.0249896188324783, 0.048602750393911265, 0.15028511232230812, 0.06572033831616864, 0.022217660152819008, 0.02831641453667544, 0.038738631847081706, 0.03100151410762919, 0.022339943825500086, 0.03951634695113171, 0.0812358854454942, 0.01364481269774842, 0.03230604459531605, 0.011662072411127156, 0.04282386536942795, 0.0733786121418234, 0.047048726555658504, 0.10539596129092388, 0.03668906858365517, 0.032896634584176354, 0.084715645207325, 0.035159183098585345, 0.03592788852984086, 0.023258576075022575, 0.07949654362164438, 0.017653637478360906, 0.011707847152138129, 0.08153816219419241, 0.006134521727290121, 0.10233889173832722, 0.03604824632930104, 0.04606345130014233, 0.03332325075461995, 0.030995231827546377, 0.01924154221342178, 0.04876132879871875, 0.04915193967462983, 0.061961249011801556, 0.020164636625850108, 0.021946752131043468, 0.046002906892681494, 0.011245090245211031, 0.03279874530562665, 0.09307145621278323, 0.07660840172320604, 0.03188519120158162, 0.07678443915210664, 0.025065557238121983, 0.029630301651195623, 0.04063235523062758, 0.05255332122032996, 0.03610805229982361, 0.015445776898559416, 0.0506244719872484, 0.0838863619719632, 0.02059230479062535, 0.04886982336756773, 0.021267488482408226, 0.010728882934927242, 0.02028228744165972, 0.026194350866717286, 0.051362541562411934, 0.03061175113543868, 0.0274268744760775, 0.04483392411202658, 0.10957544756820425, 0.008850150006765034, 0.04562410729704425, 0.013655215752805816, 0.05372128725866787, 0.02384385785262566, 0.024394540705543477, 0.03645661679911427, 0.022306146420305595, 0.009228457929566503, 0.06135543757409323, 0.053291936274035834, 0.05131170073582325, 0.031851620151428506, 0.09024051905726083, 0.08348310118890367, 0.03506619199470151, 0.04288669559173286, 0.07065247365972027, 0.02674227478564717, 0.03995880426373333, 0.007088724651111988, 0.02505622473108815, 0.020019108887936454, 0.05411960904893931, 0.04063241089170333, 0.042799025686690584, 0.034004330809693784, 0.012362727538857143, 0.03505911932734307, 0.07179123247624375, 0.06818838010076433, 0.04806012169865426, 0.028023180857417174, 0.052114559803158045, 0.05676546199538279, 0.045009327004663646, 0.09664535740739666, 0.0723865684994962, 0.047194651342579164, 0.06938784659723751, 0.05901478543819394, 0.10017620661528781, 0.02472374999342719, 0.1239465139224194, 0.02670966110599693, 0.01786096199793974, 0.044318060972727835, 0.04922803949739318, 0.054972548241494223, 0.06583517824765295, 0.06964966145460494, 0.06081202591303736, 0.037522763886954635, 0.03096020060183946, 0.06557107757544145, 0.05624198813166004, 0.03933354113542009, 0.05387591001635883, 0.03946780307160225, 0.013076302529952955, 0.05924155608227011, 0.007458247864633449, 0.02072839797619963, 0.1027288383920677, 0.046552927378797904, 0.04674975236412138, 0.028446394280763343, 0.038704741673427634, 0.02544983202824369, 0.007521188945247559, 0.014791977264394518, 0.08250000784755684, 0.01493139248850639, 0.04706374020315707, 0.023217368325276766, 0.015798774802533444, 0.10450063433381729, 0.04343110173067544, 0.012406149671733147, 0.014157603345665848, 0.041960265225498006, 0.07784645989886485, 0.022801750783401076, 0.08430778310867026, 0.06883257912704721, 0.03829100547591224, 0.04828403878491372, 0.017637742530496325, 0.01666081829171162, 0.09021346777444705, 0.041381909541087225, 0.04211017905618064, 0.04936473196721636, 0.07628705920069478, 0.03458857914665714, 0.01823390048230067, 0.062178427397157066, 0.05667902405548375, 0.0179111219040351, 0.01462633268602076, 0.06080462670070119, 0.03525090141920373, 0.023911244861665182, 0.042875811996054836, 0.05750518284912687, 0.03473483047855552, 0.03752672695554793, 0.05501040519447997, 0.03350603801663965, 0.08051174969295971, 0.02417100768070668, 0.03202256644726731, 0.0453755768830888, 0.014631179838033859, 0.022165715381561313, 0.0614606592716882, 0.02293660829309374, 0.040670457092346624, 0.03895533154718578, 0.040304162685060874, 0.03223191146389581, 0.043592760048341006, 0.020992274148738943, 0.02368594923609635, 0.015350492558354745, 0.008425989417446544, 0.028623481848626398, 0.02456617534335237, 0.027190986547793727, 0.06982641134527512, 0.010353046363889007, 0.06632041666307487, 0.021090937116241548, 0.015376829524029745, 0.08542708281311207, 0.013506835384760052, 0.04038311977637932, 0.09615538408979774, 0.0019394286641727376, 0.2913762617390603, 0.2182590711163357, 0.1534656752482988, 0.09209914627717808, 0.1055090720183216, 0.09289763038395904, 0.18658413406228647, 0.09653131157392636, 0.21445501508424059, 0.1127955224364996, 0.14670270611532032, 0.1190737949218601, 0.16437025886261836, 0.17029722832376137, 0.13014313532039523, 0.24828492634696886, 0.11470632263808511, 0.2843682502862066, 0.08227541169617325, 0.10527574078878388, 0.15131530235521495, 0.0927414973557461, 0.18441989785060287, 0.11622972175246105, 0.13355193834286183, 0.1532537624007091, 0.12976502592209727, 0.14048241020645946, 0.12046128453221172, 0.11502040695631877, 0.15576668927678838, 0.09383098498801701, 0.14294457418145612, 0.16518703690962866, 0.1274359883973375, 0.07478982079192065, 0.17835064383689314, 0.18728660652413964, 0.09983135285438038, 0.16305785975418985, 0.15901774138910696, 0.13966579543193802, 0.09798750179470517, 0.09951291212928481, 0.06256137188756838, 0.21432104258565232, 0.2043495315592736, 0.13856651145033538, 0.1360293015022762, 0.18287661659996957, 0.1593551365658641, 0.1487629080656916, 0.1201112728449516, 0.13854282209649682, 0.16050513891968876, 0.20483278844039887, 0.09148323792032897, 0.1351405054447241, 0.07502042833948508, 0.11199127184227109, 0.12983285821974277, 0.12108656621421687, 0.18621951690874994, 0.11222645101952367, 0.15388789790449664, 0.09062098848517053, 0.10054377751657739, 0.12241978256497532, 0.13552959862863645, 0.09453001388465054, 0.08722115802811459, 0.14734976983163506, 0.18272689572768286, 0.1544161734636873, 0.11221118504181504, 0.14954749174648896, 0.15173871244769543, 0.18460405437508598, 0.18887981947045773, 0.1989045721711591, 0.12890509940916672, 0.12320337176788598, 0.22416993597289547, 0.10440629252116196, 0.14109965442912653, 0.1040913250471931, 0.15930581343127415, 0.1480333917425014, 0.13751273596426472, 0.14388063020305708, 0.17746425233781338, 0.19526329881045967, 0.089440854935674, 0.11059692478738725, 0.11663923141895793, 0.12277287416509353, 0.0998358428478241, 0.1525876997038722, 0.13371871376875788, 0.21065330423880368, 0.1831020662211813, 0.1570839568739757, 0.15021247090771794, 0.11948367566219531, 0.12728475354379043, 0.13894503645133227, 0.12142210602178238, 0.08683096646564081, 0.1880232771509327, 0.1263056677998975, 0.1470614899881184, 0.08546243130695075, 0.107954782579327, 0.20544647035421804, 0.300303318654187, 0.16319014015607536, 0.06466010614531115, 0.1676493344712071, 0.15398120071040466, 0.17475761007517576, 0.1487490744329989, 0.14364994101924822, 0.1210137021553237, 0.19017504528164864, 0.13100527343340218, 0.13788091542664915, 0.16614299733191729, 0.1379277152591385, 0.20871966815320775, 0.21967854729155079, 0.2899381279712543, 0.25865247705951333, 0.2503825176972896, 0.14948095078580081, 0.12998122838325799, 0.15842164837522432, 0.1730666117509827, 0.13673782988917083, 0.1494310487760231, 0.12130157381761819, 0.08127509310725145, 0.21283587149810046, 0.12704239779850468, 0.1333921539480798, 0.12786854174919426, 0.1775873894803226, 0.21113556664204225, 0.10116118501173332, 0.14964830508688465, 0.21635599667206407, 0.11886721811606549, 0.10824511817190796, 0.15646117622964084, 0.11409650731366128, 0.08833536659949459, 0.12538782408228144, 0.12632438476430252, 0.16494813957251608, 0.105932897713501, 0.16808733518701047, 0.06754507165169343, 0.14378700085217133, 0.17721180338412523, 0.09586493717506528, 0.10416101271403022, 0.10671043099137023, 0.1602895895484835, 0.17322730156593025, 0.11924071877729148, 0.16097004991024733, 0.15978380106389523, 0.13484153867466375, 0.11015787764335983, 0.13817265367833897, 0.23597314168000594, 0.08544367723516189], [0.06268994155107066, 0.018648184013727587, 0.03321538330055773, 0.014601997663703514, 0.07376722292974591, 0.013691465028387029, 0.018463947708369233, 0.03243914878112264, 0.01922576044307789, 0.04582003799441736, 0.03288039268227294, 0.05208035792747978, 0.03042141437617829, 0.03254387323977426, 0.009057743554876652, 0.06845189447631128, 0.05365287979657296, 0.04884211528406013, 0.03217403507733252, 0.033208915483555757, 0.02793574101815466, 0.08362544511328451, 0.07715494895819575, 0.08662265303428285, 0.03221367318474222, 0.050381366672809236, 0.04477740585571155, 0.04012616598629393, 0.03857508105284069, 0.07049091553199105, 0.013453829342324752, 0.04504917662416119, 0.04599658008373808, 0.013721078576054424, 0.04115237810765393, 0.0235975872783456, 0.02834169579728041, 0.028648794650507625, 0.04299283755244687, 0.06611231103306636, 0.040239866721094586, 0.025385526787431445, 0.05556352414714638, 0.026683170144679025, 0.023868341304478236, 0.009141253722191323, 0.027462037432997022, 0.008480244123347802, 0.02305541685927892, 0.026007055057561956, 0.027953893950325437, 0.04170996478933375, 0.040947267043520696, 0.013370203214435605, 0.04290425480576232, 0.07033248184598051, 0.01944904484844301, 0.023534189313068055, 0.022648894337180536, 0.01148918354374473, 0.04958875295415055, 0.07458083200617693, 0.062414530548267066, 0.0861783217987977, 0.023455890877812635, 0.02127130312146619, 0.022670984362775926, 0.10079932122607715, 0.051811314551741816, 0.04017885104985908, 0.02826690029905876, 0.007340862830460537, 0.033702703440212645, 0.02832768404914532, 0.08600514905992895, 0.063856352790026, 0.01335899029072607, 0.040048266455414705, 0.033936509644263424, 0.040044793204288, 0.03764643166505266, 0.01694510538072791, 0.05301404278725386, 0.11215633290703408, 0.005925849281993578, 0.039001678669592366, 0.06823633026215248, 0.05161009234143421, 0.017508916826045606, 0.03789031252381392, 0.017385699902661145, 0.032797735984786414, 0.03646109194960445, 0.027580114983720705, 0.027638089704851154, 0.03894539418979548, 0.05545192369027063, 0.035287767605041154, 0.034762512586894445, 0.016174976881302428, 0.04571154713630676, 0.03228149435017258, 0.05998415646899957, 0.04239281486661639, 0.08117000499623828, 0.0667641319159884, 0.023934162381920032, 0.04538326553301886, 0.05254062307358254, 0.025220738461939618, 0.004625243363989284, 0.038042178202886134, 0.031125616042118054, 0.011871380320371827, 0.007901076714915689, 0.06135098839877173, 0.016770071706559975, 0.019174517001374625, 0.034688171654124744, 0.009003872910398059, 0.059706663741962984, 0.08008571981918067, 0.032879513237276115, 0.04361685387266334, 0.0403267313959077, 0.02173321398004191, 0.03279086740803905, 0.04675130716350395, 0.015226564100885298, 0.017695646747597493, 0.01611452524230117, 0.029165928717702627, 0.005747477334807627, 0.039964229363249615, 0.02780250881187385, 0.05518191181181464, 0.03729049021785613, 0.04007302821264602, 0.032751054895925336, 0.039014966823742725, 0.036157735376036726, 0.020872196510026697, 0.021339777376852, 0.036322206433396786, 0.0315469982160721, 0.03974869854573626, 0.025393503019586205, 0.06323731256998144, 0.03524471932905726, 0.033059279958251864, 0.029366635135374963, 0.058457562408875674, 0.027190214714210015, 0.05004282858863007, 0.024569015913584735, 0.018256823568663094, 0.08361341489944607, 0.034005228808382526, 0.009925464473781176, 0.07120849812054075, 0.0983481781440787, 0.004068236485181842, 0.03396444037207402, 0.021008135699958075, 0.054349485581042245, 0.04300373599107843, 0.006247563806027756, 0.028715185326291248, 0.04973044007783756, 0.018012289619946387, 0.012187647480459418, 0.01300550999076222, 0.023599258965987246, 0.06041895852831658, 0.04093364863365423, 0.04481992720684502, 0.028450220052036457, 0.018348547455389053, 0.048922270943876356, 0.03656075496110134, 0.04568589480186347, 0.03552444963133894, 0.050332948958384804, 0.030242061402532272, 0.023245492011483293, 0.03222988540073857, 0.05316379705618601, 0.01944371993886307, 0.043290442481520586, 0.07139289955375716, 0.00782088580308482, 0.05372147279558703, 0.022769090719521046, 0.031973295263014734, 0.06406018364941701, 0.017714777459332254, 0.03577703959308565, 0.057095791926258244, 0.061939663646626286, 0.0441663548554061, 0.01480562350479886, 0.017400205179001205, 0.08547101795556955, 0.07734346931101754, 0.06044527137419209, 0.07379840797511861, 0.04397088800033089, 0.053242969370330684, 0.057271454570582137, 0.024367810401599854, 0.055985216167755425, 0.07227055597468279, 0.036874991419608705, 0.01665600731939776, 0.03132248741167132, 0.07988403376657516, 0.02207004883530317, 0.03938224086596165, 0.054892173648113385, 0.06482714874437079, 0.023073528973327484, 0.01627441539312713, 0.04582346671668347, 0.08339238847838715, 0.005757170711149229, 0.06615363381570205, 0.02711861230636714, 0.005667897767125396, 0.022173804791236762, 0.03325043122458737, 0.06441776524297893, 0.07702223068918101, 0.04899156898318324, 0.04773723179823719, 0.05883746409381274, 0.04866231516643893, 0.06101091406890191, 0.046789063926553354, 0.04510320126428269, 0.05288582564389799, 0.01664266164880246, 0.01453326365663088, 0.01813603717891965, 0.018604237739054952, 0.06273603634326719, 0.039447234448743984, 0.03089275793172419, 0.00949604020206607, 0.024583111153333448, 0.03450318763498217, 0.04355149663751945, 0.030007581699464936, 0.053367724394774996, 0.024767614631855395, 0.052226932093617506, 0.03471042866294738, 0.06331971322651953, 0.039325626130448654, 0.05718115375202615, 0.04886113652901258, 0.0437993628293043, 0.03718043713888619, 0.02479127058904851, 0.04897397637250833, 0.06066562986234203, 0.01999861819058424, 0.07183552384958602, 0.08014806022401899, 0.025095914788835216, 0.021831461344845593, 0.025516751484246925, 0.014950124295864953, 0.009196892533509526, 0.016412616278103087, 0.03393463201064151, 0.029919214175606612, 0.024752309691393748, 0.08754348760703579, 0.06806486446294002, 0.012571109618875198, 0.03835437004454434, 0.06830507540144026, 0.03896084199368488, 0.053322119420045055, 0.014084331105550518, 0.013529467178159393, 0.047129724553087726, 0.09817001817282289, 0.05944265954894945, 0.034221475798403844, 0.056098137647495605, 0.03423720190767199, 0.03459208950516768, 0.0107707215101982, 0.055934264019015245, 0.05545262873056345, 0.0072984551206900505, 0.0062249134589364985, 0.03695042702020146, 0.03223954816348851, 0.04044417255499866, 0.021706999468733557, 0.08078980274149217, 0.03489221402560361, 0.016359907094738446, 0.029932830730103888, 0.029287674333318137, 0.0018811809718499717, 0.027837480665766634, 0.06262252485612407, 0.0565371922129998, 0.033679555854178034, 0.02440214029775234, 0.08517429247149266, 0.03894481902534608, 0.04920338906231336, 0.0507371003186563, 0.0329886274994351, 0.016717746584618, 0.021164205645618495, 0.005434383783722296, 0.03991798614151776, 0.02936120261438191, 0.06960953352972865, 0.0479598983656615, 0.024922092670749407, 0.0424332470720401, 0.055310073294094764, 0.022585693041037302, 0.0768641680770088, 0.03222149913199246, 0.02351123097469099, 0.013206293406256009, 0.057064740467467345, 0.0318426141893724, 0.0679207913344726, 0.07097937486832961, 0.03283817190094851, 0.09608195599867031, 0.04668635439884383, 0.03141226130537689, 0.040976162563310936, 0.025210426319972612, 0.03426598239457235, 0.025017165498866234, 0.05652745894622058, 0.04321251697547268, 0.06686155364150181, 0.05106801283545792, 0.04937106990837492, 0.03867456594889518, 0.010105973342433572, 0.11795067315688357, 0.11044343380490318, 0.11803561937995255, 0.1187340694013983, 0.13697105721803382, 0.1478213898371905, 0.22345535166095942, 0.1408985917805694, 0.14314590400317684, 0.25293883052654564, 0.16548448969842866, 0.11593505943892524, 0.24057272064965218, 0.09705409524030983, 0.056323706012335606, 0.23770264262566343, 0.1048014267871622, 0.192740278725978, 0.11131230319733731, 0.15771202160976827, 0.11007786670234054, 0.10939687199424952, 0.2221395238302648, 0.19523295981343836, 0.11603595441556536, 0.13273216201923788, 0.2059102532803081, 0.21478927839780226, 0.14618225279264152, 0.19215261650970206, 0.19207840174203739, 0.1555231906240806, 0.08402169260079972, 0.14805040176725015, 0.18243589962366968, 0.16688786126906052, 0.17062301631085575, 0.10568266035988927, 0.2168513208744116, 0.15330042864661664, 0.1520848204381764, 0.09654861845774576, 0.12922506895847619, 0.13570026290835813, 0.11668307750369422, 0.10747079839347862, 0.11829097013105638, 0.16430126881459728, 0.0901907061052043, 0.1375011881464161, 0.07513051110436209, 0.11672666383674368, 0.19577711733290926, 0.1574303617235273, 0.1315179787343368, 0.22813980263890699, 0.17548328207340091, 0.11179099587025121, 0.15847487520659342, 0.17666586471023038, 0.1730431747273542, 0.17282551765674725, 0.17072035640012473, 0.15376715047750622, 0.11988012352958322, 0.1716023395420052, 0.08241988558438607, 0.14687501796288416, 0.12407223373884335, 0.16020394570659846, 0.13886771950637922, 0.12961485976120457, 0.1250298268860206, 0.1699057305813767, 0.13953640940599144, 0.15262030967278406, 0.11128064317745157, 0.22212548239622265, 0.1203899789834395, 0.1332749836728908, 0.19272822624770924, 0.19658221397548914, 0.08788827457465231, 0.1911402677069418, 0.177510725625325, 0.10467043772223406, 0.11395497975172475, 0.1998464614734985, 0.18560148600954562, 0.1358232367783785, 0.21696190087823197, 0.1779642965993844, 0.12354308244539425, 0.10597480679280125, 0.16416861733887345, 0.16760581493144855, 0.11805145681137219, 0.06887488896609284, 0.16682017740095034, 0.08649615396279842, 0.15765584103064612, 0.19330704206367955, 0.19449873827397823, 0.11721777264028788, 0.14174349722452462, 0.202916756097693, 0.15612113900715485, 0.15082696918398142, 0.166094638989307, 0.3190299606649205, 0.08999537283671089, 0.23949129274114966, 0.1448522202554159, 0.07806341192917898, 0.10096032274304889, 0.1477521177730523, 0.13297625439008698, 0.09153259816230275, 0.1616476901108399, 0.1885523839155212, 0.08713190734852105, 0.11269815266132355, 0.1151764286623802, 0.12974210840184242, 0.1624923580675386, 0.15506662137340754, 0.19635335047496483, 0.08927770119043998, 0.14193468930898234, 0.14570184575859457, 0.16746262495871633, 0.14188391156494617, 0.07102900970494375, 0.1340845035156235, 0.1560032562701963, 0.09848989124293439, 0.15907334309304133, 0.18741329113254324, 0.1497514042421244, 0.20143303961958736, 0.13857360638212413, 0.29854638793040067, 0.04827167831535917, 0.10103510154294781, 0.1449582731584087, 0.18647601798875257, 0.13196213927585632, 0.18575873225927353, 0.16798392432974651, 0.12281706905923784, 0.14947072399081662, 0.14079242013394833, 0.1647718349704519, 0.23926989524625242, 0.09973232808988541, 0.17235086968867108, 0.12723243213258684, 0.11999493377516046, 0.1789320126408711, 0.1538386638276279, 0.2373277986771427, 0.1494557029218413, 0.17093146772822365, 0.07957374182296917, 0.10954160563414916, 0.11802028660895303, 0.09964986064005643, 0.1709856593515724, 0.08337930441484787, 0.14616824104450643, 0.11954540008446202, 0.15054444840643555, 0.08156921365298331, 0.12455630698241293, 0.1739290912519209, 0.08850666912621818], [0.060954492291784845, 0.04452457098523155, 0.014951671673770761, 0.038078947909525596, 0.04213452149997465, 0.0025936171141438535, 0.018676077634154353, 0.03559937315003481, 0.027114691911265254, 0.029016467597102746, 0.08835521904984489, 0.02499463389540324, 0.02563588659540983, 0.0338680836284766, 0.013940004719188437, 0.041347344013047405, 0.015226697687467095, 0.02500225204130402, 0.025919472354871687, 0.06273487117141485, 0.03814492854871787, 0.09485127477091737, 0.022478630817204248, 0.026543156564002857, 0.012187536158307921, 0.0459370635508094, 0.029281681490829214, 0.04052736359881237, 0.07575135474326089, 0.014268618433561642, 0.02266710107505787, 0.06104103413235862, 0.09094446839299053, 0.10624180926242843, 0.030051739486225415, 0.04300765082007274, 0.017513872517156415, 0.03576040435291361, 0.07250592068885453, 0.06248808480449952, 0.0255851886322489, 0.037290712862159126, 0.07951985448016785, 0.011188363259861944, 0.05084041469672229, 0.03346275225339923, 0.03407041534956079, 0.006157596026241663, 0.01010724427032983, 0.023193278211692814, 0.02974855546199251, 0.019329314163769595, 0.04776098423462827, 0.0632041459903121, 0.01315265189987258, 0.007004146718827542, 0.11361524680978619, 0.03819322009803727, 0.022123097551229876, 0.05348469800082967, 0.0628545721701812, 0.025908030293066986, 0.023158404692367185, 0.024076291083474644, 0.026847802619158756, 0.058775201614480466, 0.05792568001197651, 0.043485668138600886, 0.010447501354065025, 0.02714071346417768, 0.018914156753453426, 0.013110856925777625, 0.06027549767168239, 0.07097581255948171, 0.010548038244451163, 0.01952843609615229, 0.09735148123581894, 0.19838315405650064, 0.037021513635409065, 0.12073065445292741, 0.04954163028742187, 0.005443502923299093, 0.370307348202914, 0.29941642249468714, 0.4481816163752228, 0.19183370081009343, 0.1255633420078084, 0.03950582329707686, 0.04580840854032431, 0.09207556082401425, 0.04720136035757605, 0.06002109686960466, 0.017139318006229587, 0.024781095744401682, 0.056488726258976385, 0.023927703841764014, 0.06327903611236252, 0.023477737850043923, 0.046663945249747485, 0.07841652579372749, 0.04851854631851893, 0.06284447154030204, 0.07585370432934724, 0.017958611933863722, 0.018276917217008304, 0.06546793389134109, 0.04021157234092243, 0.03989620781794656, 0.056607028309372254, 0.022601369055337273, 0.02179340586735634, 0.03423464149818756, 0.018870195635827258, 0.006702442815367249, 0.028547209476528224, 0.03262393242039252, 0.06458556483266875, 0.06744443642674014, 0.014949729102227138, 0.0787481470615603, 0.058972089682356454, 0.015187631961453008, 0.07647828097105958, 0.019865963004122023, 0.01855540813266998, 0.048091826247400604, 0.04090823007572908, 0.013183735827624332, 0.04275023689842783, 0.031704144275863655, 0.006718885560985655, 0.07943579883431084, 0.025050816329894587, 0.08292126571177505, 0.016121314038173296, 0.07702203773078509, 0.02027622966124909, 0.014680712629342452, 0.06240113478270359, 0.054461156541947275, 0.04426423671247903, 0.10829482722328976, 0.022270458393904846, 0.05709129822207615, 0.01955502539203735, 0.0378229032503441, 0.015629143963451497, 0.038560000612051226, 0.027251738756604027, 0.03296714974567294, 0.048900900801527314, 0.048466692460351624, 0.019641674844024237, 0.02474989028996788, 0.02646131437359145, 0.008760637720115483, 0.030618988930655178, 0.028805641995859332, 0.008909661901270738, 0.08256645975052379, 0.0213223591708811, 0.08613376325229183, 0.029243136195873376, 0.04973196890205145, 0.010301349284418393, 0.06463710698881187, 0.024124820120050572, 0.04215281915094238, 0.06828279612818733, 0.0677820913551841, 0.01909721118863672, 0.06872332756756805, 0.0326153717469424, 0.049761870031943545, 0.0071338124416797655, 0.04487912461627275, 0.05061128773377277, 0.023947543304529972, 0.04585316375596449, 0.05601086850219872, 0.010428551540826447, 0.00404474611968908, 0.012448271190805826, 0.039068672340363264, 0.054831109737278894, 0.047991435931180604, 0.011758820637624012, 0.05516912460734602, 0.02866775652364595, 0.018080934569297824, 0.015026436558400746, 0.06413925206288695, 0.05312633715220727, 0.08113726144074462, 0.042762200318975374, 0.06222872274520341, 0.04337122525612358, 0.05430872683064081, 0.07018700605840422, 0.039665641088504344, 0.016639090063108597, 0.08121316088363528, 0.02612409916764591, 0.0410972328245407, 0.03820040037680883, 0.020307015802245587, 0.005612277509499108, 0.06107910259743221, 0.04087630659341812, 0.04752557499159593, 0.016901548733585514, 0.05487144175276626, 0.04198092661681585, 0.09992428458645009, 0.008191749057004927, 0.07409298865240999, 0.02315638976142509, 0.003999047912657261, 0.036685491431853734, 0.023752076449454762, 0.05262523904093541, 0.05950891849352047, 0.03444908135861624, 0.028544743690872565, 0.010353642865084112, 0.05653411972161848, 0.02760077637503855, 0.077125545067247, 0.022176253878569696, 0.026290470123058185, 0.013067669497104362, 0.045035799412289634, 0.07107225465006195, 0.06665673572570086, 0.05151071134605445, 0.06187390194099862, 0.022587934327020776, 0.07295108312973753, 0.07001184436376207, 0.019218320412619505, 0.041547152432031, 0.03573030284314882, 0.01077079665265046, 0.03538311502779834, 0.08386464673094451, 0.042387976063764654, 0.03457670478383079, 0.018122133042197675, 0.04117975964618381, 0.046235785412136465, 0.005359116094041383, 0.026220138643111568, 0.08916541424696334, 0.1806663375464268, 0.1623580590239726, 0.21446265920531005, 0.13254597201012075, 0.0751361514267046, 0.27902828995138407, 0.32393226167187095, 0.7207405159715563, 0.4560815409058705, 0.10631689234287478, 0.03466493129963055, 0.015162028794293292, 0.02780808605166385, 0.12337034015217796, 0.03335269546369091, 0.032568360402365215, 0.07706813994445838, 0.02992466339492239, 0.06464132238761522, 0.0230003791875788, 0.01249081666173879, 0.07031629560515285, 0.06072010721254628, 0.010913235200860072, 0.08337150444276631, 0.03914025619451422, 0.05039164541813079, 0.039489559130743146, 0.04908902039460372, 0.011340307792124804, 0.011622860110946931, 0.013044941224507056, 0.03127127180050593, 0.029320482826733496, 0.02747324757365277, 0.026042342324217316, 0.02328633054275997, 0.03667442229925655, 0.03170031479385216, 0.03945561700675171, 0.047487606716458686, 0.03180474981490988, 0.044795347275794484, 0.07141319729271345, 0.024907401857490186, 0.032921871315920725, 0.021441950702865142, 0.04566964547848329, 0.028379779105307534, 0.017699904819892254, 0.02527678916521836, 0.037902209151070565, 0.008410357932007173, 0.028897610791318584, 0.03741236199857667, 0.014896965185471345, 0.037447929425979964, 0.0713306333636865, 0.04534992825938389, 0.05956934786809143, 0.03795189222728368, 0.013871264218323631, 0.06375892364303581, 0.06564610128407367, 0.049794082951848395, 0.010575160031294217, 0.04384804400615394, 0.13104616577038541, 0.022378650537575595, 0.04328780414653011, 0.02923902284237556, 0.007709944929956691, 0.023456176604668144, 0.045913155263406225, 0.03403362337849103, 0.042813497566385195, 0.06427269021514803, 0.10097213773406111, 0.013051986061327625, 0.02198762962507317, 0.030109608451311942, 0.052706593269249424, 0.03481062231003307, 0.01731049436784815, 0.03281509481894318, 0.03425088711082935, 0.05697877750208136, 0.02336702982574934, 0.022835052805021405, 0.050675513193709776, 0.014108344221313018, 0.052438188140513375, 0.004828621049455251, 0.03491989613394253, 0.047019738267408684, 0.029262669522722717, 0.05029582302086055, 0.07401593145914376, 0.034843072717194445, 0.13193052378483117, 0.08219395356718451, 0.11067873914726079, 0.20581616379786283, 0.2059973220457323, 0.17463460651924834, 0.10561372226220556, 0.07289010827662423, 0.12961684871697798, 0.19289281975943595, 0.14792442962061614, 0.1581197278574109, 0.11768309923354536, 0.17802680027671158, 0.12670093565247953, 0.18049027043161914, 0.11557189689483494, 0.18709565192693844, 0.17044196196366102, 0.23548053373815492, 0.05471835895150434, 0.14266073238104582, 0.13872383191483095, 0.1092219032580033, 0.1710593546158634, 0.14960117870941758, 0.14201352023519576, 0.16585462843067944, 0.21184995799558237, 0.10320914894691668, 0.18898664420703426, 0.14030681806616485, 0.13890368398278952, 0.17456165340263397, 0.11545123852556571, 0.15893770818365738, 0.0883535566390492, 0.16941007983405143, 0.10832380066858605, 0.151117920759134, 0.09775986283784732, 0.1439906907035038, 0.1535535158473067, 0.15298973594326526, 0.07442898859153502, 0.1431556261377409, 0.18007766600931063, 0.12603473936906084, 0.059980545920552686, 0.13161062845028937, 0.10052186931716278, 0.13091867964249104, 0.1230231931549497, 0.2937698067398742, 0.11214819154702127, 0.1364396943245083, 0.21478725975612178, 0.20263101439923048, 0.2152082059183158, 0.16460969054605812, 0.10171574002015404, 0.09860421167104505, 0.1290693663759157, 0.0934322587272618, 0.20130383170908317, 0.15444045653566718, 0.1792407312314026, 0.22539764118846506, 0.0965980306500569, 0.1031677371065598, 0.11675725516397506, 0.09440151843591593, 0.2211509385961108, 0.23839116271119565, 0.08647180409752764, 0.06760479969670996, 0.18902045645518228, 0.305650700465776, 0.3786989604122937, 0.2829691831720993, 0.3644475876353681, 0.3322446718811989, 0.5982673284597695, 0.6006479007191956, 0.9334561892319471, 0.5816176906228065, 0.2651595982024446, 0.11588995912461542, 0.17916887649334967, 0.16923616494750604, 0.24072676082141697, 0.14172184135532007, 0.1235709129832685, 0.13615171134006232, 0.13580077938968316, 0.16364240495022386, 0.13252749253297225, 0.11039100849302486, 0.28526369598694146, 0.21248177799861878, 0.1969348528655246, 0.120284742442891, 0.15780533925862983, 0.08354636185686104, 0.1174399493902456, 0.14890673628542572, 0.11928561129025184, 0.15701515978435054, 0.1455226170946844, 0.07414175517624244, 0.11910159577382728, 0.08485868675052188, 0.17038036370649934, 0.07623463388881646, 0.11659007155685686, 0.16022680385503918, 0.1397672321763821, 0.11451701560872607, 0.12503993493737653, 0.13174393301596865, 0.14095472783083096, 0.06665560023975559, 0.20489171496592462, 0.08615987942903303, 0.08089591501629911, 0.11112531166872941, 0.10882803806453012, 0.0516322046314599, 0.1536400947952643, 0.08972894924227148, 0.05917326736380346, 0.20469161710934713, 0.1488626527134329, 0.18107109004631639, 0.12212981804623269, 0.1404404640197754, 0.13345458341063932, 0.11154367515700869, 0.13393176952376962, 0.15635387651855126, 0.09329598557087593, 0.21775117493234575, 0.1432040290092118, 0.07829357418813743, 0.22218059428269044, 0.13998034730320796, 0.08790765205048956, 0.16199382778722793, 0.07687792007345706, 0.09260891267331317, 0.11015602227416821, 0.08556241344194859, 0.1598888446460478, 0.08234811248257756, 0.3487494424916804, 0.12952287797816098, 0.10810888212290592, 0.17811052937759086, 0.14041796210221946, 0.133203856239561, 0.15711042186012492, 0.28913625224959105, 0.18734704703092575, 0.1110935329052154, 0.15014793374575675, 0.1662691475939937, 0.12305411844863556, 0.11964912264375016, 0.13063115678960457, 0.22299042582744732, 0.13522586727049202, 0.15284817869542167, 0.1463395732571371, 0.09808500515646301, 0.11131805484183133, 0.10575189531664364], [0.06033058358298149, 0.05166865150386002, 0.06748839383362792, 0.08020833003683947, 0.027187539271835703, 0.05220003666181583, 0.051850525924237445, 0.006353704839057173, 0.02043320688244421, 0.07440311732352711, 0.026124164105567615, 0.008899094646039885, 0.038626341192866676, 0.05541624122997746, 0.09101558840484358, 0.033953367528738454, 0.06794868124416098, 0.024846684900694527, 0.016682822970324196, 0.03669753648864571, 0.04757313923619222, 0.0837349118955899, 0.026672633503039833, 0.013072262463538209, 0.039566972554894164, 0.018159134669986088, 0.044052398079656996, 0.03558612952474505, 0.028223217486811336, 0.05286857071041595, 0.09140125286648981, 0.04590126234688796, 0.05908652885409538, 0.03302315963082947, 0.019578373357944656, 0.03514908989018295, 0.05319869283994194, 0.0516581872216193, 0.04260758498276118, 0.06108758534537628, 0.018584791614557616, 0.03905955876689404, 0.012896493135485798, 0.0976353972509969, 0.015053080587676959, 0.00619538247519813, 0.07416540742269717, 0.02603839780931594, 0.0153894989125547, 0.022329431303660385, 0.017584918314241804, 0.04637324600480497, 0.015645571402274072, 0.036694582740892656, 0.06385655316989869, 0.008276372445834568, 0.006229296304809395, 0.005091266184535925, 0.03562953032087535, 0.05323401535861194, 0.021415918017737567, 0.06968256086111069, 0.058924076438415796, 0.025859632987703662, 0.0747704433160834, 0.03685418159875553, 0.03571374181774445, 0.015540773656539386, 0.10921005115960725, 0.07644756347872317, 0.03478938204352744, 0.03419646913243923, 0.04429673164850101, 0.0985243046307005, 0.4662448971066624, 1.8224180722609162, 3.2755382359027863, 1.6785647976212204, 5.014982298016548, 5.915529699996114, 7.539041982963681, 8.289175406098366, 7.75933088734746, 5.452448073774576, 4.24896857701242, 4.6707867924124, 1.9364034058526158, 1.5871437219902873, 0.8103595382999629, 0.33322950184810907, 0.2162407708237879, 0.09853001174633391, 0.02276535400596913, 0.12598556466400623, 0.16879342932952568, 0.05695098778232932, 0.09427133831195533, 0.10170381370699033, 0.19394871778786182, 0.355865599703975, 0.1328169894986786, 0.018763307816698216, 0.05774886332801543, 0.08510286075761542, 0.035723998298635706, 0.00411843210713414, 0.027301356894895434, 0.05039816147473175, 0.02582511198852444, 0.008754714453971246, 0.03231675749702845, 0.029454622308549006, 0.04599075793521479, 0.046344550864887424, 0.04804983924259432, 0.03418208259972744, 0.05864465041668154, 0.06038571031240281, 0.007070723859214922, 0.037599283023155294, 0.03496685552818235, 0.06709599067107774, 0.07818142825271934, 0.07877257114159875, 0.022989781318756286, 0.062236493031377904, 0.017279993953707162, 0.02762912270554807, 0.026333436762797646, 0.0460416803980479, 0.03650437771284487, 0.12176842923508957, 0.08594565850216895, 0.06617517094127834, 0.02475590354151791, 0.007716721202086774, 0.028787342489522416, 0.07271280919667333, 0.04011801349406596, 0.060475877544377, 0.027226867532590404, 0.06486761063570157, 0.034090204717358574, 0.04205253273539711, 0.026288716799172107, 0.04531876176770311, 0.03477307705907151, 0.02866353555873502, 0.03981380345067009, 0.010561508224782301, 0.02923372947407188, 0.004467511007533176, 0.026845353531825822, 0.036254901060601696, 0.038719673684681766, 0.024806813016766682, 0.023774656292516738, 0.07461019878974184, 0.056642536364961416, 0.02837715932400897, 0.009922603494487703, 0.051210557139711455, 0.07741783250821754, 0.017147589242085814, 0.04461929129320197, 0.038528648583451286, 0.009618928725103615, 0.04338149286922999, 0.025756136783456896, 0.02349786489503458, 0.04533744904620107, 0.026831393734028097, 0.03165332200296689, 0.06122254490037449, 0.01365908790830872, 0.017179824426420964, 0.06158030089864042, 0.06213770575413946, 0.044210234336787835, 0.0505394181527663, 0.02269085351144895, 0.03928098965843674, 0.03276898147305474, 0.01602328375156503, 0.06041374123014975, 0.00663046283989388, 0.021443653931783047, 0.01980032004212262, 0.012086453789379448, 0.11467353455373086, 0.051649953093146905, 0.010115355944435578, 0.028811968804802746, 0.015243233665387379, 0.06174921370984521, 0.08001029535080306, 0.018018464288616087, 0.049075517017627135, 0.058693836253951304, 0.03816192373051308, 0.16310143866576254, 0.044332955876598135, 0.0279459566809237, 0.008877000909706112, 0.04282171685190406, 0.05239215643086936, 0.07578231714433059, 0.08689945185324177, 0.0625298751401715, 0.03879454525304027, 0.018766231878544204, 0.04803142655873671, 0.061038596177240834, 0.04480985997361131, 0.009693188021628885, 0.04537533568509389, 0.016985114561975934, 0.04295296566851903, 0.04406933017889969, 0.006495546422229381, 0.0454958196496591, 0.026434971841808874, 0.05472195094625931, 0.014650138000433799, 0.028525969210022595, 0.05418367494712584, 0.06634222096181475, 0.014963237117626704, 0.006296135052252794, 0.0359987450792687, 0.012205978528072592, 0.019222383671149146, 0.015042858431115746, 0.04928385642415378, 0.08475037771859206, 0.02436166541883722, 0.050719314749585465, 0.06288880744250491, 0.0822327753121499, 0.06661601408268325, 0.008749220705794869, 0.017617131234146655, 0.025457964111410547, 0.014308009776868857, 0.04161115524766501, 0.06100913662521634, 0.07817175064701587, 0.017155287168861832, 0.060827766865259036, 0.0906952700461261, 1.1574626597575843, 3.5750080039724708, 5.390867153182626, 3.520094300620258, 7.813867935910821, 8.519328106194735, 12.635146602988243, 14.311649892479181, 14.33321563526988, 11.062333099544048, 5.853323712944984, 6.867261780425906, 3.5767673095688224, 2.9261676454916596, 1.713321888819337, 0.7486601115670055, 0.37992846162524074, 0.043067204460385256, 0.0647868204396218, 0.066081051772926, 0.19126537896227092, 0.09275155345676467, 0.1273984505678527, 0.2278537195525132, 0.2625739556970075, 0.4516207880806178, 0.1299556836602278, 0.11384500830899924, 0.20801740349270403, 0.05242208353593014, 0.00953963117353851, 0.026421958282298874, 0.03125459574221168, 0.03396136045921594, 0.05121532914927229, 0.035774282514466904, 0.01652524460951099, 0.03670112848340068, 0.01571334432810545, 0.11650848726276308, 0.06439704447984695, 0.03880981865222566, 0.14842576521914452, 0.017173592241306324, 0.03675405103422236, 0.0786440831143409, 0.037808301494806074, 0.006150612880446715, 0.026200879910902586, 0.05863607118953951, 0.07850913098081946, 0.04847268901357893, 0.009475720198679483, 0.01055422033459763, 0.039491039715358056, 0.05544896994251758, 0.03426481722272001, 0.1563402358442545, 0.02661066046130145, 0.0333758467604639, 0.023234511936607305, 0.011002498868037947, 0.0639205337211024, 0.056084307725541294, 0.017535621154820547, 0.010661428204912227, 0.005963174207863631, 0.020782329847861547, 0.03929103091650177, 0.048216592404060066, 0.018085192641592585, 0.0622755782387685, 0.054887056539882906, 0.024435596315015573, 0.04052756768942345, 0.008560977730667219, 0.007985225129232276, 0.04756689777423162, 0.023657575075048953, 0.039105579344322905, 0.085480569396168, 0.017719606985338032, 0.009822708561841864, 0.06368217073031701, 0.029790002554364037, 0.008632845456304494, 0.04140389937674627, 0.01864261234004516, 0.025957284778996836, 0.039336966146947816, 0.03981374407885596, 0.018739219558483455, 0.04004044421890285, 0.04666429776989389, 0.038845927847432904, 0.03819406243565027, 0.042466977683943696, 0.015835700360185, 0.023432069792761467, 0.017139156589109916, 0.014816331768088276, 0.07228334317915142, 0.16200387646676973, 0.16476235032314435, 0.1732512135640718, 0.2012940650456585, 0.12429970200173557, 0.12621683272300288, 0.08618756895884871, 0.09220594132784754, 0.25980141072068363, 0.11422124007367529, 0.11610216883127578, 0.056921305586001836, 0.12995235883863643, 0.15798173291841522, 0.1282113546039909, 0.11452140170149505, 0.15447667334228754, 0.09018744065542705, 0.13022371771512553, 0.18314944492885843, 0.21109887486090884, 0.21421763172838837, 0.07268750196089968, 0.09659446091973223, 0.23913506185635924, 0.16939964523771778, 0.21593355137156323, 0.17290687188506126, 0.10345082933781669, 0.16489004425238818, 0.21910823648795485, 0.1828878972446546, 0.1250845825416036, 0.1162278515403159, 0.04328639777668286, 0.1305075001437217, 0.18654126761248335, 0.21024666668381542, 0.08015222367248498, 0.14926485222531483, 0.1290959055768326, 0.07143420749343932, 0.11801926244515926, 0.20483660307945684, 0.09479379543336108, 0.06768777180695906, 0.15909939247649163, 0.11866499029565603, 0.10658620289177634, 0.1350620307493955, 0.16468491463456303, 0.20188466616673395, 0.07319780270336196, 0.07771927063004114, 0.09860795209533535, 0.16741680476116017, 0.11997813155176118, 0.10542301257373765, 0.14808247738983482, 0.12258695875061676, 0.15238395048072562, 0.1439120527356863, 0.11588121662498452, 0.13026943401200697, 0.11767990799853578, 0.1415168007952161, 0.2087037416640669, 0.11187755997525528, 0.16672178346198052, 0.13523220521165058, 0.12111408505006693, 0.1261618989519775, 0.1995522147626616, 0.3928954736329615, 1.1411491851322353, 3.6686603911221027, 6.124202152714133, 4.767805086448789, 9.039106965065002, 9.96713686734438, 13.709304314106703, 15.378683935850859, 15.724557526409626, 12.911712862551212, 7.421531388536096, 8.564774617552757, 4.706310611218214, 3.376323552802205, 2.060928661376238, 1.119647326413542, 0.5474444024730474, 0.2614232705673203, 0.17960966768441722, 0.3766305651515722, 0.3988981421571225, 0.16528822132386267, 0.2643277694005519, 0.5022708827164024, 0.5458166648168117, 0.6897749681957066, 0.3871104324935004, 0.28342637582682073, 0.26366393314674497, 0.1327374461106956, 0.08693257390405051, 0.07641899821464904, 0.21759376541012898, 0.12966477661393583, 0.15227381576551124, 0.11113870743429288, 0.13132258609402925, 0.11890612891875207, 0.11493750163936056, 0.22553591814357787, 0.11893798189703375, 0.16946826421190053, 0.3579250891925767, 0.06855724233901128, 0.09538240759866312, 0.18406282091746107, 0.18704414687817916, 0.15866710629779845, 0.18982923415023834, 0.11858745812787674, 0.13781956949969754, 0.20372795319417492, 0.09869617861113511, 0.1250606557005085, 0.14150807313853875, 0.1453650146140717, 0.13767099153483286, 0.21245044452371076, 0.1438863595831208, 0.17230660800123587, 0.11167453063535504, 0.12135680444771424, 0.18881829542806372, 0.15217074629617855, 0.14517763716867194, 0.10270748680341057, 0.0765754132589791, 0.12157504781498574, 0.19220150919863954, 0.1591339914011769, 0.13266701629618183, 0.22270814253715798, 0.10176605763263069, 0.08164794809999876, 0.10977892961818725, 0.07711672093137167, 0.10059627704322338, 0.10098584520164877, 0.14932245772797614, 0.12200475131976418, 0.15806592215085402, 0.09737985354149714, 0.0847004831302911, 0.26029829343315214, 0.10063558118417859, 0.10590168298222125, 0.10200960081419908, 0.13337429787497967, 0.22749989322619513, 0.11048427419154905, 0.16127263836096972, 0.10205259342910722, 0.10554587512160651, 0.11030805864720605, 0.09671727893874049, 0.1802392167155631, 0.12072819052264094, 0.09100818177103065, 0.20768949296325445, 0.10105599300004542, 0.07150411780457944, 0.2061064771260135], [0.010096862552018138, 0.02261513775010826, 0.09648422972531989, 0.028397106398188043, 0.03820028534391895, 0.024520549959561322, 0.028705715521937236, 0.015413822802656796, 0.06199482006195467, 0.07858648503315635, 0.015174739000940463, 0.06897388404468074, 0.06375669720000587, 0.02270177792524919, 0.062093243686831556, 0.022129982826299965, 0.06169327061797958, 0.029390309646259993, 0.05079775975900702, 0.04805351287359372, 0.05407312833995093, 0.051966890969197266, 0.052241953162592836, 0.03981626738095656, 0.03391202619241085, 0.006852444776086486, 0.029338164495129604, 0.004113679578949814, 0.06334863472147845, 0.016926087846513838, 0.059101902443217114, 0.07195058642537333, 0.04128474014578387, 0.04094106268894393, 0.03553501039277762, 0.051875911085517146, 0.03014634105056757, 0.05176311206014361, 0.03144725727906916, 0.04408365362905897, 0.04110828340344597, 0.050036015672958456, 0.049976317313848995, 0.09004045830806717, 0.02129433567461092, 0.06111147136834916, 0.025957900761568453, 0.11175789608387277, 0.004875471440755064, 0.032011671719374135, 0.018442798354953993, 0.03001175256940769, 0.06634387595113367, 0.0404983641783474, 0.03817508200882003, 0.03842116333544254, 0.03757229482289404, 0.05574351722316351, 0.04434093767486047, 0.05861667144927196, 0.017129002153524198, 0.04501214345509652, 0.019960310382884927, 0.0815635065373499, 0.022073061954870354, 0.05717136853490956, 0.100647485232912, 0.01310067744270782, 0.20245116233127192, 0.1358489744598046, 0.35235099610872567, 1.846045560669154, 2.2646694537252188, 6.778858574107289, 16.761102005839348, 28.58989007771015, 30.469550415873528, 26.845194697380066, 30.563490875065327, 34.16906990110874, 40.90684935450554, 39.19893220067024, 43.06399740278721, 37.24140264093876, 32.282410338521004, 31.74001794308424, 27.618325911462307, 24.255468361079693, 22.091849260032177, 9.450157508254051, 6.515906983986497, 3.383049904368818, 3.222393337637186, 1.5420681657269597, 2.0207075821235776, 2.4732257751747966, 4.075201051309705, 1.947643083985895, 3.2425310695543885, 4.157936861738563, 2.261052285321057, 4.1567370761185884, 4.0713380835950375, 1.6424026130698621, 1.1049823695793748, 0.25764440302737057, 0.09752494341228157, 0.033402831249986775, 0.06142754835309461, 0.02581229324277956, 0.014152677340462105, 0.04225706863508094, 0.023672234347031917, 0.06781588876037858, 0.02971161691675661, 0.03763401182368398, 0.017150435378425755, 0.02192345982621191, 0.03525695363350678, 0.06438390104449354, 0.03812711329373997, 0.06889153533848003, 0.09433598679606803, 0.032588305621175095, 0.11239900777582079, 0.046288158773677424, 0.034384674072498456, 0.029166604072088376, 0.04196420231892262, 0.03151031385641545, 0.019154896472173277, 0.09086776000913233, 0.03788033063756302, 0.02005944090342382, 0.06043567540473305, 0.0640929643122945, 0.036946853579138406, 0.05192687807721086, 0.03294654030469246, 0.044080284278606996, 0.01894497443572618, 0.04658761536120437, 0.03752210337552242, 0.1134919463947881, 0.03477768950688187, 0.030445873708231375, 0.02567700343206525, 0.029484480764949694, 0.10340405176975764, 0.046861352820997126, 0.19333228992763907, 0.0627071742201224, 0.013526085767807672, 0.00891378453161451, 0.04824824871320743, 0.051254188001621515, 0.006915861758898245, 0.07502685533836484, 0.010404259192000609, 0.08805811507045291, 0.017976425333472434, 0.03936691180570051, 0.03490081180643756, 0.021376233526098076, 0.026018645548901986, 0.05356382578611374, 0.04473141125345137, 0.05567511347180698, 0.03890757434419356, 0.02000728462007828, 0.030071866531216074, 0.02064170770609053, 0.058851698486250825, 0.03794874923187308, 0.02866387880203547, 0.029869768586650025, 0.03831830537819769, 0.06774033812689595, 0.05896361806662753, 0.04797684901859611, 0.040493180276826024, 0.053209379766485654, 0.026751542354759295, 0.012183878297946649, 0.040939437385532074, 0.026735580613603815, 0.011774857521231752, 0.09462569156312384, 0.021930599286861252, 0.007652967005924438, 0.0899181301065255, 0.004292384101063362, 0.07750264514470473, 0.017822526169766206, 0.017577470862306654, 0.03651394399639685, 0.042360768929938786, 0.017058628000086173, 0.021344718225009274, 0.03559966629836708, 0.020612461521523073, 0.04677888908190653, 0.06236694403924048, 0.05832806877151597, 0.05220766593993176, 0.0448269924527267, 0.03447153874731157, 0.018827318053808995, 0.028302482569415588, 0.05740364962548483, 0.04432630623341538, 0.05216485515120439, 0.017719519782986026, 0.043554097865126096, 0.04677392411394976, 0.020088011733605526, 0.024110992053465452, 0.037277665906003676, 0.013032033421040978, 0.04694879266025964, 0.056897378744906746, 0.02572714107373031, 0.07434457671479322, 0.0461602422001306, 0.06909872812684625, 0.030742565795662813, 0.0381705957261147, 0.035759799502557144, 0.07928081613499671, 0.012329133296589134, 0.016025148397602607, 0.060882893594680354, 0.09172499252599664, 0.03617196976847481, 0.03119298635283485, 0.003868479320772167, 0.013959244897705503, 0.04713336478744168, 0.03962278948165476, 0.01543105361633934, 0.028742359063471667, 0.010610251556499861, 0.1390541173168458, 0.021443752266350202, 0.2004435341223143, 0.5084313615225255, 0.9219310514163226, 2.9201653925701976, 5.080426186323166, 11.656374223530293, 23.44418339431286, 36.10383868217468, 39.46799956262112, 37.22310282289982, 41.42305165529251, 46.59412197768688, 52.54668116569519, 52.21467398107052, 56.93739116191864, 51.657471880316734, 48.60236741602421, 44.36509318649769, 37.23729506134987, 34.00271862745285, 28.92788954079151, 13.788101635873318, 8.170042298734188, 4.215348931029439, 3.794159581884742, 1.6576327895745635, 2.027147999033332, 2.963279541581869, 4.742754455655813, 1.9225227506831288, 4.0422378201037645, 4.917365536093712, 2.80263579916209, 5.228663356974721, 4.9214607663452625, 2.2257612040266395, 1.252029372844845, 0.4455157328629866, 0.030382906188606285, 0.03415512037463486, 0.04650037590181455, 0.053505121904890984, 0.03656659937405493, 0.06172737601445988, 0.013160323851479916, 0.04836901840462815, 0.03984448754636105, 0.08112514959066175, 0.006125938325567404, 0.0008578638062317623, 0.013191239868319826, 0.01689470427663764, 0.06444559578085318, 0.021503096249944065, 0.03068490648729494, 0.03718166539329104, 0.041138496235362254, 0.0265474628758966, 0.02856019706086954, 0.02666064967343118, 0.0443224953050958, 0.014733718671777751, 0.012776105650118552, 0.049270304807578214, 0.04195100693323184, 0.06389183487044647, 0.004849061187996995, 0.03402869180717971, 0.0077693487492069835, 0.06675503318547271, 0.012754857034451561, 0.07180313652497716, 0.09242920903488994, 0.1075629805563949, 0.03553013077180367, 0.02228812521934742, 0.07978363602887839, 0.049491386889712885, 0.03243025414121803, 0.06345299552776851, 0.0510253245010972, 0.03805369262408931, 0.05050619220128283, 0.021638579019054305, 0.05394506333686877, 0.03783930100325961, 0.05740819528000429, 0.04341544983617496, 0.023183411358331796, 0.05133075166668277, 0.012807318526029121, 0.06837952765636146, 0.09010405294247903, 0.05483092420035973, 0.06803965370636433, 0.0528809534444008, 0.02516969540010905, 0.01172005919215735, 0.0983827473828569, 0.005069757817182108, 0.034542948196758516, 0.056234941439470276, 0.02824026276357472, 0.010175581228395458, 0.017496222390036564, 0.024453216756228358, 0.03711636752996128, 0.023243534596986137, 0.09999469213653356, 0.15838676743442193, 0.213207257038448, 0.13400561321759596, 0.22228902205824852, 0.09367454767925665, 0.1516726316185668, 0.0988698931178078, 0.15493070444790646, 0.1304252998670563, 0.11366621009074152, 0.24545379623305053, 0.10799078416312113, 0.10205900558503345, 0.16892924235435203, 0.1382824915344827, 0.23281683214008808, 0.15283853077562526, 0.1352004412910901, 0.11390979037969373, 0.15786528994794935, 0.11323042839649133, 0.11268978123553097, 0.151422809867654, 0.1105246321822051, 0.20262449834262952, 0.1490277360426262, 0.10467610773048364, 0.16198315570363775, 0.16756251803599298, 0.16148633236298338, 0.29052299971226603, 0.08558639223338105, 0.11587142769712955, 0.09811718467972241, 0.14980596693931147, 0.1655771245714277, 0.16197649121750146, 0.14348185941344127, 0.09702950788778253, 0.11484744201879948, 0.18230574176413938, 0.12872435676399618, 0.2262538718059659, 0.11008934772689827, 0.10487206440302543, 0.14728273905348033, 0.20980817615054548, 0.1512094572535716, 0.1476158743025735, 0.10066770875710063, 0.16250533080892637, 0.1335625213687308, 0.13587530585937202, 0.11798510880907997, 0.17076127842301503, 0.18843230442143977, 0.13108213024679571, 0.11046522326068953, 0.15016862482298166, 0.13457776454742998, 0.17711539840092883, 0.10476877228938974, 0.16816307877888903, 0.08563057228457183, 0.14697816164698452, 0.2445451106177643, 0.2182352778618224, 0.2776752656791359, 1.2246269057504833, 1.8614939879626036, 3.8257890846580267, 5.494949743151665, 13.941846136003733, 26.989136673510075, 41.345064640045166, 44.389658868312836, 42.76421248912811, 48.72187860310078, 53.46391014754772, 59.76487264037132, 61.185593605041504, 66.73773407936096, 60.55759370326996, 57.16171972453594, 51.63881868124008, 43.86248275637627, 39.77700278162956, 33.176194578409195, 17.4420178681612, 11.383298076689243, 5.691176913678646, 4.426152594387531, 2.504606628790498, 3.0427634390071034, 4.672829182818532, 6.4396080281585455, 3.0845443345606327, 5.682187546044588, 6.4308010507375, 4.2361855879426, 5.993301551789045, 6.526585835963488, 2.7079809783026576, 1.760955301579088, 0.8414111752063036, 0.23061441985191777, 0.09153708815574646, 0.17223686096258461, 0.15223143913317472, 0.11997833935311064, 0.18723091576248407, 0.09237469828804024, 0.12609106837771833, 0.11202472785953432, 0.1397396094398573, 0.05914201552513987, 0.13295397511683404, 0.15824578906176612, 0.21282346278894693, 0.1300508715212345, 0.22220925602596253, 0.16026668687118217, 0.087282637541648, 0.12663200497627258, 0.15646635642042384, 0.13683816825505346, 0.16290966770611703, 0.21046065754489973, 0.126460479805246, 0.07547903107479215, 0.25869507633615285, 0.15407395432703197, 0.1493244169978425, 0.15915811120066792, 0.2257589780492708, 0.1022107302560471, 0.12755442032357678, 0.1083971990738064, 0.20499534846749157, 0.18828262807801366, 0.26605887338519096, 0.1507478265557438, 0.18697319756029174, 0.1557810720987618, 0.11912739282706752, 0.09430268662981689, 0.19489215075736865, 0.17860536376247182, 0.10343787143938243, 0.33458205114584416, 0.17718440329190344, 0.08714309151400812, 0.10372321979957633, 0.13201754802139476, 0.14894822234055027, 0.12460521451430395, 0.1827704004244879, 0.08334099475177936, 0.15842920343857259, 0.17229599528945982, 0.20828298846026883, 0.10498971707420424, 0.21336137142498046, 0.12364493479253724, 0.08824772638035938, 0.18978457170305774, 0.12893267761683092, 0.16486360895214602, 0.16110942524392158, 0.19510639394866303, 0.1010777082410641, 0.24588802683865651, 0.11128033147542737, 0.12934436177602038, 0.09544003536575474], [0.020546119085338432, 0.05787992660771124, 0.1016407459974289, 0.011589580353756901, 0.11441856971941888, 0.03104363840975566, 0.02089671335852472, 0.03582930534321349, 0.037568539555650204, 0.042489386833040044, 0.039048842154443264, 0.04572803765768185, 0.02098423668940086, 0.0597493966051843, 0.017301432744716294, 0.051092908179271035, 0.018043411582766566, 0.06700920392177068, 0.0427420547202928, 0.01418745901901275, 0.016646199837850872, 0.04080644823261537, 0.050709778151940554, 0.0556199347920483, 0.08760432887356728, 0.02750602267042268, 0.03187954716850072, 0.0684337638085708, 0.013607845394290052, 0.10125386441359296, 0.05333003071427811, 0.06387081724824384, 0.031896249201963656, 0.08445583414868452, 0.009929731822921894, 0.033907936958712526, 0.062293872178997844, 0.06334836012683809, 0.04566316281852778, 0.05516758836165536, 0.05118493449117523, 0.011575280095712515, 0.08452768888673745, 0.06551928308908828, 0.04025585629278794, 0.0028921302464368637, 0.04839398054173216, 0.01788944377040025, 0.08508173923473805, 0.02809802088449942, 0.036767005221918225, 0.01372838965835399, 0.0605991742486367, 0.03645248303655535, 0.003683482777887548, 0.048613882609060965, 0.009811041072680382, 0.08324030015501194, 0.061466596453101374, 0.038353056443156675, 0.027267563200439326, 0.09977276029530913, 0.04437703944859095, 0.011745189240173204, 0.03683150156575721, 0.1786918833386153, 0.9574159816838801, 1.7789360554888844, 4.079024596139789, 12.213259041309357, 14.223077595233917, 23.277446441352367, 37.8245535492897, 46.62761718034744, 57.56844989955425, 61.45835816860199, 65.53397387266159, 65.63570201396942, 64.47753936052322, 61.854198127985, 73.5326586663723, 72.68082037568092, 71.28281459212303, 78.33372384309769, 72.34538957476616, 70.03907293081284, 63.51977035403252, 54.68538500368595, 51.3157182186842, 33.14161643385887, 21.270859614014626, 19.29072316735983, 18.28284814953804, 13.232112620025873, 11.138252075761557, 5.266337860375643, 11.977234706282616, 12.604649439454079, 21.497766338288784, 18.95454950630665, 13.664297629147768, 18.878939263522625, 13.879115302115679, 13.513117991387844, 8.911419566720724, 6.376646356657147, 2.043530107475817, 0.6911355920601636, 0.09725081632495858, 0.07659656446776353, 0.03433638623391744, 0.03658696390630212, 0.027216245543968398, 0.045381621675915085, 0.07256709592184052, 0.051583174645202234, 0.03698681823152583, 0.045554148746305145, 0.0948340272589121, 0.058534463751129806, 0.035151208721799776, 0.03693626313179266, 0.02136939649062697, 0.06317733219475485, 0.04754509347549174, 0.05425263901997823, 0.02134296861186158, 0.0719603085599374, 0.03909150822437368, 0.017887269277707674, 0.08629352538264357, 0.05411926766100805, 0.0478043553448515, 0.04231382808939088, 0.006510973817057675, 0.06534701577038504, 0.060863879771204665, 0.0421378537430428, 0.018837990137399174, 0.02058041744021466, 0.029617126674565952, 0.03689666584250517, 0.020235613774275407, 0.01295794203542755, 0.03750051429960877, 0.009398764123034198, 0.032405288293375634, 0.01913953401526669, 0.04602331595378928, 0.06706726955599152, 0.009799560048122657, 0.015249761781888083, 0.024816446093609557, 0.024132052349159494, 0.01998901479964843, 0.07438872708007693, 0.017746209268807434, 0.026123271672986448, 0.04700589350250084, 0.06598193052923307, 0.018993039630004205, 0.04971616857801564, 0.03174609046254773, 0.0212736464527552, 0.13325733540114015, 0.058922848184010945, 0.05281008576275781, 0.026772407836688217, 0.010494885627849726, 0.05246036722382996, 0.06063118307793047, 0.008442874204774853, 0.030313463430502452, 0.05416043088189326, 0.045853987539885566, 0.03265105791797396, 0.014894075447955402, 0.02928953712398652, 0.007742701009192388, 0.06315271515632048, 0.07819510603439994, 0.0373295160534326, 0.058110905229113996, 0.029619857778016012, 0.04828691089642234, 0.03705422750499565, 0.015671785913582426, 0.03408172939089127, 0.013540834097511834, 0.07127170683816075, 0.023044188164931256, 0.01805616353522055, 0.07250657377880998, 0.07800255581969395, 0.036068006011191756, 0.02004942376515828, 0.06734178256010637, 0.015955970957293175, 0.029677019847440533, 0.06733733709552325, 0.05194176555960439, 0.02930937844212167, 0.061045483307680115, 0.05074974280432798, 0.0149068459541013, 0.04640139566618018, 0.06480014941189438, 0.10631803525029682, 0.005782761354566901, 0.052149711627862416, 0.0403744477807777, 0.014070347187953303, 0.06886334856972098, 0.02126172013959149, 0.041426790921832435, 0.044964007756789215, 0.015397076240333263, 0.040729914253461175, 0.03519317717291415, 0.03503361171169672, 0.008737670104892459, 0.037066279983264394, 0.039489867122028954, 0.05314110589097254, 0.010844990083569428, 0.06729760250891559, 0.018334574670006987, 0.057121752251987346, 0.033865408186102286, 0.03915261295333039, 0.04312598997785244, 0.021074945689179003, 0.0515924329374684, 0.027589673845795915, 0.04995580806280486, 0.08499420291627757, 0.026556337106740102, 0.10201752695138566, 0.07395964697934687, 0.018708314673858695, 0.05075369474070612, 0.4192640696419403, 1.3744269800372422, 3.349147173576057, 6.270317612215877, 15.57887239381671, 19.174149222671986, 29.35987316071987, 49.29334133863449, 57.65311695635319, 70.1760783791542, 74.18486326932907, 75.51938205957413, 76.78052678704262, 78.42868834733963, 76.46083474159241, 85.98930224776268, 84.95258867740631, 81.29356741905212, 90.02938225865364, 84.72229063510895, 83.43063354492188, 73.28257888555527, 66.97661206126213, 61.26051038503647, 44.00813654065132, 28.286219872534275, 25.41832946240902, 23.475092835724354, 18.006300888955593, 16.009741723537445, 6.759111983701587, 14.662736803293228, 18.76639310270548, 27.42617592215538, 23.592728823423386, 19.1841521859169, 26.844012960791588, 20.538794696331024, 18.664879649877548, 12.727348655462265, 8.026928678154945, 2.4231948098167777, 0.9016713104210794, 0.08063775894697756, 0.05904066412767861, 0.03569125103240367, 0.0329904865793651, 0.08381421779631637, 0.03224022722861264, 0.07620871067047119, 0.09226246329490095, 0.014738190111529548, 0.017616181285120547, 0.04951389993948396, 0.03956293898227159, 0.09746516341692768, 0.06869454708066769, 0.037887852304265834, 0.031213031761581078, 0.017919933052326087, 0.046642578818136826, 0.029040047484159004, 0.010416419281682465, 0.01252530055353418, 0.03939313559385482, 0.11136313289171085, 0.010235174759145593, 0.05222774103458505, 0.050244551748619415, 0.04836074345803354, 0.05228720561717637, 0.059128252396476455, 0.021845727278559934, 0.01815977848309558, 0.023095266478776466, 0.11111918152892031, 0.0586089827993419, 0.019663128477986902, 0.047901454236125574, 0.05990494704747107, 0.06925577399670146, 0.060870685265399516, 0.015095476701389998, 0.05116326377901714, 0.05400112517236266, 0.04689482368121389, 0.017819114145822823, 0.03744400717550889, 0.015673585621698294, 0.06361705469316803, 0.04735341157356743, 0.03347080455569085, 0.016613209518254735, 0.02091101268888451, 0.03850487388262991, 0.07060365518555045, 0.02695929546462139, 0.03982915106462315, 0.04141300552873872, 0.09860098332865164, 0.05643460142891854, 0.05270063382340595, 0.08381154606468044, 0.020178681770630646, 0.011625245188042754, 0.02780417493340792, 0.0931248908455018, 0.0710345535480883, 0.1253387681208551, 0.05425239782198332, 0.004847332447752706, 0.12514868925791234, 0.11223804336623289, 0.12924754119012505, 0.10081667263875715, 0.2151160905486904, 0.1334355992730707, 0.1836413107230328, 0.08702946128323674, 0.1280024103471078, 0.16478421399369836, 0.10538534115767106, 0.212934369337745, 0.12809954263502732, 0.2016828762134537, 0.08671669056639075, 0.12597852910403162, 0.12953642959473655, 0.19674505601869896, 0.1080937497317791, 0.12909719691378996, 0.10332156947697513, 0.09838377154665068, 0.28718627407215536, 0.15456426161108539, 0.15961506636813283, 0.14876851870212704, 0.11475685547338799, 0.16082619200460613, 0.1263080575154163, 0.2551922877319157, 0.35881281655747443, 0.19870784366503358, 0.1310556652606465, 0.2313712175237015, 0.13181140908272937, 0.12247912469319999, 0.2727297419914976, 0.21008401759900153, 0.1418207844835706, 0.1401484734378755, 0.13203056529164314, 0.05791120071080513, 0.2131455548806116, 0.14995724632171914, 0.11335220740875229, 0.07784824847476557, 0.2261240256484598, 0.11121615054435097, 0.1528075386886485, 0.20105234754737467, 0.17949925095308572, 0.14352073310874403, 0.18723505694651976, 0.16743108368245885, 0.11348722633556463, 0.12164766696514562, 0.09204895482980646, 0.1968183505232446, 0.1871217309962958, 0.19211259990697727, 0.1756488106912002, 0.3852959111100063, 0.15387247607577592, 0.08140577789163217, 0.17575225123437122, 0.5472342856228352, 2.209112634882331, 4.631856456398964, 8.865122850984335, 19.388252533972263, 24.229682944715023, 34.91753473877907, 58.43993693590164, 66.43269404768944, 80.32826721668243, 82.72710889577866, 87.15919867157936, 87.52220839262009, 89.52095434069633, 93.38026285171509, 98.9715564250946, 98.94201681017876, 93.26576739549637, 103.42946961522102, 96.93467572331429, 93.4420095384121, 85.65216153860092, 78.31346333026886, 74.58075642585754, 53.86875942349434, 36.86671994626522, 33.68434131145477, 27.89869576692581, 23.193850927054882, 20.26502698659897, 12.511543035507202, 19.707102924585342, 23.957799933850765, 33.70084382593632, 27.65370961278677, 24.904424138367176, 33.2899946719408, 25.7814284786582, 21.798303611576557, 16.220930591225624, 9.774048328399658, 3.662533932365477, 1.3006100035272539, 0.2619503438472748, 0.2540419588331133, 0.08989749097963795, 0.11298713754513301, 0.1472183206351474, 0.1604458858491853, 0.2971998351858929, 0.22160354477819055, 0.11385894584236667, 0.10241774492897093, 0.20773961761733517, 0.09432763021322899, 0.33045660064090043, 0.16234937589615583, 0.08332798490300775, 0.11300650017801672, 0.18795020529069006, 0.1530128761078231, 0.20607333281077445, 0.17640786449192092, 0.14837529917713255, 0.1565877569373697, 0.21580259199254215, 0.21137229690793902, 0.2465607540216297, 0.11505714326631278, 0.1416411847458221, 0.09501532651484013, 0.1930040231673047, 0.14419470709981397, 0.1286643763887696, 0.06442568395868875, 0.20832343550864607, 0.20203230902552605, 0.1419817266287282, 0.11998222820693627, 0.13576675934018567, 0.22467131610028446, 0.09507812705123797, 0.1447762391762808, 0.1466067464207299, 0.15199755871435627, 0.1045277227240149, 0.08777295966865495, 0.11062167541240342, 0.06883007808937691, 0.11838862934382632, 0.11226526534301229, 0.11449784593423828, 0.16554567235289142, 0.17522802780149505, 0.13038537232205272, 0.17515167564852163, 0.12045766285154969, 0.08455986098852009, 0.1276165380841121, 0.26388164958916605, 0.1552660809829831, 0.185428372642491, 0.12947886862093583, 0.0720645283581689, 0.16083548369351774, 0.11916242219740525, 0.20241651887772605, 0.10570548882242292, 0.2985020074993372, 0.13183253060560673, 0.1577576488489285], [0.05079272057628259, 0.04132357302296441, 0.013173928346077446, 0.040956480806926265, 0.017934321440407075, 0.11086869926657528, 0.032153510983334854, 0.029138408026483376, 0.039885840014903806, 0.05148268413904589, 0.09238073937012814, 0.03848045722406823, 0.014416869853448588, 0.06400750600732863, 0.0652864045696333, 0.04655222233850509, 0.026236031735606957, 0.04850615616305731, 0.013597611177829094, 0.016177611505554523, 0.020223655919835437, 0.015107554227142828, 0.10828126818523742, 0.028387501151883043, 0.060324943260638975, 0.08450184730463661, 0.07505162080633454, 0.07674978827708401, 0.04168919949734118, 0.00927047369259526, 0.08008661039639264, 0.06947660003788769, 0.015473212242795853, 0.029196612813393585, 0.023837252738303505, 0.03607816601288505, 0.07300756798940711, 0.01320080893492559, 0.03546095518686343, 0.020595173191395588, 0.0506783185119275, 0.07804566717823036, 0.01734657387714833, 0.01189374401292298, 0.03877146817103494, 0.051310453927726485, 0.06043323744961526, 0.05196138794417493, 0.039765619512763806, 0.029085696987749543, 0.04819414985831827, 0.04294558872061316, 0.042192694745608605, 0.02494465581548866, 0.008009611174202291, 0.03811692360613961, 0.02611748848721618, 0.031106082715268712, 0.028172617858217563, 0.035673309612320736, 0.059301569854142144, 0.11773732054280117, 0.08208868734072894, 1.1198829137720168, 2.511661662720144, 9.057786762714386, 16.22031882405281, 23.34987435489893, 36.355324387550354, 44.02957119047642, 52.26026773452759, 61.35922148823738, 70.66315144300461, 72.49995008111, 77.25605607032776, 75.312779545784, 77.88496792316437, 72.08444237709045, 75.01258805394173, 72.04064592719078, 70.2306966483593, 62.21816539764404, 73.08912366628647, 66.29038408398628, 64.77860480546951, 69.7662703692913, 71.22801393270493, 73.38730126619339, 73.16834941506386, 76.15834817290306, 65.90478837490082, 52.88853362202644, 49.87347140908241, 47.18725115060806, 43.360069915652275, 40.36621816456318, 43.59447553753853, 47.42597334086895, 42.60557100176811, 38.10340918600559, 43.554486483335495, 51.350163370370865, 51.40748709440231, 37.19412557780743, 37.77593895792961, 22.864969074726105, 20.312041863799095, 13.900431208312511, 4.414464421570301, 1.3625349244102836, 0.11061126308050007, 0.0391684800706571, 0.06897742408909835, 0.015482271082873922, 0.03569342181435786, 0.014545742869813694, 0.040502865304006264, 0.025283221730205696, 0.05950817263510544, 0.03829060842690524, 0.048011024919105694, 0.05809597692859825, 0.02013683206314454, 0.033509051136206836, 0.05952746476395987, 0.022186946371220984, 0.08430003508692607, 0.014225044160411926, 0.023041664862830658, 0.06939927567145787, 0.04327796326833777, 0.06305125614744611, 0.005446369932542439, 0.009625639595469693, 0.01709618252789369, 0.06908474606461823, 0.05028539955674205, 0.013383321602304932, 0.020723594425362535, 0.03285743805463426, 0.025099130143644288, 0.04203423508442938, 0.08730002606171183, 0.06013880149112083, 0.015096825554792304, 0.10502545148483478, 0.009881862370093586, 0.046625190298072994, 0.019399042648728937, 0.028248671296751127, 0.019437882947386242, 0.06319960404653102, 0.033582805772311985, 0.023010617114778142, 0.02140430897270562, 0.024979779809655156, 0.05660171453200746, 0.06700555255520158, 0.02246934840513859, 0.03345283716043923, 0.04093596784514375, 0.024173389974748716, 0.050728209389490075, 0.03769123512029182, 0.10889751793001778, 0.034390455402899534, 0.03592728367948439, 0.03479868857539259, 0.065134160395246, 0.012877130502602085, 0.009401295774296159, 0.01656094562349608, 0.04656406330468599, 0.04894173005595803, 0.05794769953354262, 0.06483593577286229, 0.031661878965678625, 0.04458233233890496, 0.016981396402115934, 0.08434267889242619, 0.06435242656152695, 0.05140950466739014, 0.055796384112909436, 0.033699720006552525, 0.021075095974083524, 0.024539496989746112, 0.05141330817423295, 0.011815993839263683, 0.09747656280524097, 0.010701180417527212, 0.030357853138411883, 0.06212355670868419, 0.005555327879847027, 0.03493703974527307, 0.03489323076792061, 0.06042734850780107, 0.020804816922463942, 0.0011051083333768474, 0.028410962295311037, 0.013156407167116413, 0.014010296308697434, 0.04197165719233453, 0.027962660569755826, 0.016304338787449524, 0.0438954820856452, 0.03126418429019395, 0.01857798983110115, 0.07549750313046388, 0.035920162772526965, 0.03481209176243283, 0.11463383707450703, 0.041362699048477225, 0.02886480971937999, 0.045488379619200714, 0.06105119042331353, 0.09499370775301941, 0.0551356871437747, 0.02690338391403202, 0.041057891576201655, 0.0430792792030843, 0.060225781198823825, 0.0816647577448748, 0.03543340295436792, 0.035878632188541815, 0.05155088751052972, 0.012344731385383056, 0.03661139169707894, 0.05199416489631403, 0.023025306072668172, 0.03336639922054019, 0.07359928233199753, 0.03290624910732731, 0.01794560765119968, 0.02341000388696557, 0.04105382089619525, 0.01925363550981274, 0.04749417843413539, 0.0909046373271849, 0.17593588825548068, 1.7424412700347602, 4.589726692065597, 12.496938519179821, 22.024233788251877, 29.476308412849903, 43.10908578336239, 51.45728722214699, 60.76253190636635, 70.25852635502815, 79.18479457497597, 82.35162064433098, 85.03787130117416, 83.24082612991333, 87.63665065169334, 85.02844780683517, 86.18996188044548, 80.87642580270767, 78.9936876296997, 71.24800086021423, 82.96839594841003, 76.75884515047073, 72.96981006860733, 78.35649982094765, 82.93349862098694, 83.01185801625252, 82.89949044585228, 86.81419238448143, 82.99333781003952, 70.40823072195053, 61.801593750715256, 59.26871046423912, 53.91877993941307, 56.75971269607544, 58.82811650633812, 61.42045900225639, 52.28281952440739, 49.86855827271938, 56.78714342415333, 61.92499592900276, 64.5500698685646, 48.32661621272564, 48.25807549059391, 30.969850569963455, 28.466666489839554, 18.589628487825394, 6.44302261993289, 1.9559583440423012, 0.10602841211948544, 0.06269089892157353, 0.034636900381883606, 0.004276446943549672, 0.03800547157879919, 0.056292331719305366, 0.03617748763645068, 0.033455746379331686, 0.0220620744585176, 0.06163232174003497, 0.0329822301864624, 0.06328410498099402, 0.031202701065922156, 0.0365180480730487, 0.03434072408708744, 0.10104980348842219, 0.0457368803472491, 0.018460804712958634, 0.0333615492854733, 0.03395559026103001, 0.03790969371038955, 0.011726954671757994, 0.04177814960712567, 0.03942009039747063, 0.04734701426059473, 0.06878118540043943, 0.011084780780947767, 0.04149191809119657, 0.013078658848826308, 0.02904289918660652, 0.015005933801148785, 0.07617031194968149, 0.013383604546106653, 0.047579517995473, 0.037660139132640325, 0.08725419102120213, 0.03475808938674163, 0.03424538408580702, 0.03313442241051234, 0.01839431941334624, 0.04945069122186396, 0.016394426238548476, 0.03655742642877158, 0.0509521784260869, 0.003415609212424897, 0.059880842090933584, 0.03269452179665677, 0.05989973717078101, 0.027147582040925045, 0.04384732041216921, 0.033062678994610906, 0.03213278279872611, 0.008054855279624462, 0.04177193783107214, 0.032683426688890904, 0.02965576102724299, 0.09017797085107304, 0.0068103246485407, 0.09460151239181869, 0.016948003467405215, 0.024055373651208356, 0.00836962051835144, 0.02862729463231517, 0.005978514400339918, 0.029270514023664873, 0.13287223497172818, 0.1725294897914864, 0.11134968517581001, 0.12837640824727714, 0.169879280438181, 0.1216051567462273, 0.22493924625450745, 0.11364964535459876, 0.14233173831598833, 0.07756681865430437, 0.09655558722442947, 0.12905247509479523, 0.10171899062697776, 0.11068141087889671, 0.13416303758276626, 0.17180273425765336, 0.1416364943725057, 0.11040313518606126, 0.16730048053432256, 0.09017252348712645, 0.11493946833070368, 0.15573136304738, 0.07075227025779895, 0.152689240348991, 0.08413006100454368, 0.135836313420441, 0.1397042238386348, 0.15725157834822312, 0.15533645142568275, 0.14852709806291386, 0.08260985312517732, 0.2250318811275065, 0.19653088704217225, 0.208271351584699, 0.12989217066206038, 0.12459540332201868, 0.11684516997775063, 0.12381984415696934, 0.13478097942424938, 0.2102166393888183, 0.2662416792009026, 0.13234127283794805, 0.1548974562319927, 0.17985324055189267, 0.10867016841075383, 0.1861345855286345, 0.21609876828733832, 0.29234152869321406, 0.12641857814742252, 0.1260690117487684, 0.11722982511855662, 0.11319236364215612, 0.2073168903007172, 0.18978691688971594, 0.1747207104926929, 0.11601656209677458, 0.11152542574563995, 0.10655212347046472, 0.1446518552256748, 0.07539806276326999, 0.13291940587805584, 0.1575178757775575, 0.408666082075797, 0.6485557893756777, 2.33055483084172, 6.500352993607521, 15.969688072800636, 27.358049377799034, 38.43448922038078, 50.59057652950287, 60.97947746515274, 72.3733788728714, 82.76998579502106, 91.82828933000565, 96.00773826241493, 98.67897972464561, 94.97135147452354, 101.47825911641121, 96.09129577875137, 98.39837238192558, 93.76095682382584, 92.67295360565186, 85.83209708333015, 98.29858213663101, 89.98496264219284, 87.02085569500923, 91.16433575749397, 92.30552852153778, 94.89772662520409, 96.46540850400925, 99.75804582238197, 95.7898199558258, 85.26791855692863, 71.06203123927116, 69.14506450295448, 64.42790642380714, 66.19294211268425, 69.35638636350632, 72.94845521450043, 62.47380807995796, 59.549458399415016, 68.28663736581802, 71.92443296313286, 75.71523115038872, 59.72091279923916, 57.842042818665504, 38.60035412013531, 33.59313480556011, 22.30512421578169, 8.337917290627956, 2.441863208077848, 0.3499765391461551, 0.17926513304701075, 0.13340612116735429, 0.14841037307633087, 0.13486890908097848, 0.1346934208413586, 0.14920086425263435, 0.15807910269359127, 0.1619414915330708, 0.14242756442399696, 0.26211352727841586, 0.24381642549997196, 0.11054514514398761, 0.10564466982032172, 0.15432757587404922, 0.13199927634559572, 0.23154865019023418, 0.11091500186012127, 0.10188644140725955, 0.21224872878519818, 0.12897785956738517, 0.10163031882257201, 0.1170743971306365, 0.07693380379350856, 0.11826211542938836, 0.11644631755189039, 0.11488463103887625, 0.08058365638135001, 0.11446781863924116, 0.1701016872539185, 0.10423460407764651, 0.12988011818379164, 0.1625660533318296, 0.11769777149311267, 0.21572318219114095, 0.12160196551121771, 0.0823345163371414, 0.10848950740182772, 0.09282881102990359, 0.16402110806666315, 0.1561960217077285, 0.15482110407901928, 0.15820459986571223, 0.16549195570405573, 0.05672653634974267, 0.11254563389229588, 0.16802417841972783, 0.1367613856564276, 0.10901316680246964, 0.11269413022091612, 0.1340255473041907, 0.12250894418684766, 0.14319427718874067, 0.16012551554013044, 0.1310960529372096, 0.18202669423772022, 0.1803763656062074, 0.08048319185036235, 0.23117441480280831, 0.1096082356525585, 0.07709971090662293, 0.1584443135652691, 0.16462858562590554, 0.12275436500203796, 0.18264039099449292, 0.345070764888078], [0.026384442717244383, 0.027476856266730465, 0.04934424126986414, 0.047892184811644256, 0.031439605736522935, 0.023427397973136976, 0.05422217756859027, 0.07033683083136566, 0.027323628746671602, 0.048592352904961444, 0.04480921801587101, 0.061389045731630176, 0.041011919238371775, 0.025556358050380368, 0.057019640153157525, 0.0822400112519972, 0.11776505460147746, 0.04293892052373849, 0.029177012693253346, 0.014755114789295476, 0.03982076479587704, 0.027643023131531663, 0.08188329797121696, 0.015411017484439071, 0.04996691430278588, 0.00753211753362848, 0.00439115931840206, 0.0406998758262489, 0.04149621141550597, 0.03645242366474122, 0.04968391855072696, 0.012542460863187443, 0.058591312263160944, 0.00924436029890785, 0.07648541301023215, 0.0677159585757181, 0.01552052879560506, 0.03373811501660384, 0.029800843476550654, 0.029947733055450954, 0.04003821777587291, 0.03361093687999528, 0.03599654832214583, 0.02665298143256223, 0.059579285225481726, 0.040826048352755606, 0.05423318361863494, 0.03659767680801451, 0.04105500833247788, 0.04359271551948041, 0.09059527306817472, 0.02306241716723889, 0.03831312889815308, 0.032071793102659285, 0.049829680065158755, 0.06601851098821498, 0.045273038049344905, 0.036722661898238584, 0.04177636103122495, 0.5368685012217611, 1.7753553413785994, 4.501008102670312, 10.751593373715878, 23.891846872866154, 31.40944328159094, 41.081514582037926, 44.10860314965248, 57.16165512800217, 67.33522161841393, 77.43735954165459, 66.28492757678032, 66.60955175757408, 71.19024395942688, 71.07591569423676, 62.30308324098587, 61.31998859345913, 45.970605835318565, 49.87306483089924, 58.87907937169075, 44.208765774965286, 44.053905084729195, 40.292467921972275, 46.40660963952541, 61.15136884152889, 58.84832762181759, 59.12066660821438, 63.67754548788071, 55.87818659842014, 56.454509273171425, 59.15607690811157, 71.6034109890461, 67.10800901055336, 70.47390639781952, 69.21403080224991, 58.99477556347847, 67.65529364347458, 59.21528913080692, 59.56875756382942, 59.3984355032444, 61.954942122101784, 68.22704136371613, 63.4227729588747, 71.46901220083237, 61.63714237511158, 66.72999009490013, 58.49095679819584, 51.882134824991226, 44.709263518452644, 26.94500584155321, 13.520011771470308, 7.246032580733299, 2.1805904153734446, 0.7639848079998046, 0.16233085189014673, 0.06164523139887024, 0.011722379331331467, 0.059371918032411486, 0.02282123030454386, 0.02840918670699466, 0.03349462749611121, 0.03605897036322858, 0.011686907455441542, 0.0337854640383739, 0.044900008651893586, 0.02867533385142451, 0.016146719608514104, 0.04061988714965992, 0.04341601757914759, 0.023831380494812038, 0.054720841435482726, 0.02210619699326344, 0.03193784286850132, 0.03198210826667491, 0.06290730918408372, 0.022844437262392603, 0.047075269467313774, 0.01690854347543791, 0.02187051130022155, 0.022351281986630056, 0.004838414151890902, 0.048289853511960246, 0.13333250011783093, 0.017273158773605246, 0.01407873345669941, 0.012728660149150528, 0.020402274167281576, 0.020347199388197623, 0.019487113313516602, 0.05640661504003219, 0.057124449958791956, 0.022338429844239727, 0.02103250411892077, 0.029555828987213317, 0.06790233412175439, 0.03166317772411276, 0.05922728458244819, 0.018328355472476687, 0.007505529629270313, 0.040671343958820216, 0.03218378689780366, 0.02305253547092434, 0.03229329078749288, 0.05222204505116679, 0.009084935845748987, 0.025233611013391055, 0.029090717616782058, 0.050574158085510135, 0.05206418652960565, 0.008876960091583896, 0.027847933815792203, 0.05360084782296326, 0.050484373059589416, 0.03507653753331397, 0.03540589153999463, 0.03943217627238482, 0.05508790025487542, 0.07231940413475968, 0.013719055295950966, 0.01414084008501959, 0.007332594377658097, 0.011540674677235074, 0.0251377923268592, 0.035281778473290615, 0.020791610404558014, 0.043886687635676935, 0.03600750242185313, 0.03576928414986469, 0.07577226104331203, 0.03577276111172978, 0.003268241644036607, 0.021465890531544574, 0.006002514528518077, 0.06874979997519404, 0.05955849766905885, 0.0204977681642049, 0.0468796838686103, 0.028405015837051906, 0.04027005357784219, 0.07592782261781394, 0.02228269455372356, 0.0744545778434258, 0.00437076046182483, 0.056196082587121055, 0.052668413482024334, 0.06903432455146685, 0.02375486321398057, 0.018729599469224922, 0.015299611841328442, 0.022901035299582873, 0.048465189611306414, 0.07339430856518447, 0.07030414664768614, 0.02244903582322877, 0.03831266876659356, 0.04318750659876969, 0.03516838201903738, 0.07329006650252268, 0.05310872227710206, 0.04102188628166914, 0.02995954804646317, 0.008986369357444346, 0.02968648408568697, 0.022520183665619697, 0.058547911467030644, 0.04156858936767094, 0.056823579579941, 0.07273520721355453, 0.054355337415472604, 0.016901708295335993, 0.06914451863849536, 0.040705011488171294, 0.07195690952357836, 0.029588797042379156, 0.014291611096268753, 0.05567092775891069, 0.7636566599830985, 2.4434633972123265, 5.974087882786989, 14.774346314370632, 30.50779726356268, 39.59590829908848, 49.73293974995613, 50.75361058115959, 65.64360558986664, 76.03315249085426, 87.76132956147194, 75.00718474388123, 76.8058942258358, 80.51974654197693, 81.02562099695206, 74.80957254767418, 73.24731677770615, 56.21235206723213, 58.9302322268486, 67.73378223180771, 53.85047860443592, 53.50228428840637, 53.82792301476002, 56.62319742143154, 69.81785640120506, 72.36717760562897, 71.16483852267265, 73.19294929504395, 63.11836749315262, 64.20553475618362, 68.42075496912003, 81.71995773911476, 76.35622635483742, 83.91384601593018, 83.51514101028442, 74.15748193860054, 80.03053799271584, 73.28575551509857, 73.21599125862122, 75.61149671673775, 79.56647649407387, 82.30372801423073, 74.71181139349937, 82.5342008471489, 73.43299761414528, 76.86130285263062, 71.5901193022728, 63.04894141852856, 52.51990020275116, 34.05879981815815, 17.736310176551342, 10.577673856168985, 3.151002055965364, 1.0865451651625335, 0.17345981643302366, 0.05555092247959692, 0.06216581830813084, 0.047855266675469466, 0.0805108665372245, 0.027845328877447173, 0.029708269830734935, 0.004686068859882653, 0.016632904262223747, 0.028954965819139034, 0.030506822586175986, 0.029097768019710202, 0.07923224256956019, 0.05287133521051146, 0.0516259854339296, 0.05007094114262145, 0.027183043712284416, 0.04294754056900274, 0.0695817029918544, 0.005118805429447093, 0.03155311722366605, 0.0646655609307345, 0.06135759351309389, 0.025544314848957583, 0.053846880909986794, 0.021122229773027357, 0.019007702612725552, 0.04639065307856072, 0.0421824716613628, 0.011897266431333264, 0.1008337271923665, 0.038873687881277874, 0.11685096615110524, 0.034545022499514744, 0.11346380415488966, 0.0731464238197077, 0.054630789236398414, 0.025703566752781626, 0.07032371708191931, 0.05073643238574732, 0.019479350448818877, 0.056650900369277224, 0.05672284045431297, 0.01743674853059929, 0.022520834900205955, 0.08610590302851051, 0.06367198104271665, 0.0571724891779013, 0.03799313708441332, 0.035400299457251094, 0.02503005845937878, 0.011666041045828024, 0.04731976630864665, 0.06325801849015988, 0.040602442968520336, 0.012602995066117728, 0.08831815619487315, 0.022787980233260896, 0.06632685108343139, 0.00672337045216409, 0.0691056449431926, 0.05896802271308843, 0.011053851776523516, 0.16231617220910266, 0.08986156361061148, 0.15517570223892108, 0.0958256701414939, 0.165421778219752, 0.09634567817556672, 0.1310830208240077, 0.11704669275786728, 0.09044354839716107, 0.13982682663481683, 0.20670911588240415, 0.161691224493552, 0.1532747651799582, 0.10184111844864674, 0.3092294553061947, 0.13642002741107717, 0.23083133477484807, 0.15788565448019654, 0.06509345359518193, 0.09260459337383509, 0.13702673313673586, 0.10337642161175609, 0.1864242012379691, 0.1483047506189905, 0.15064379229443148, 0.08835072163492441, 0.09652522596297786, 0.2580410661175847, 0.2184267816483043, 0.13108738465234637, 0.09013640315970406, 0.08007176002138294, 0.19780678732786328, 0.17441160598536953, 0.11554893484571949, 0.1810868235770613, 0.10425491665955633, 0.10341316534322686, 0.11878283592523076, 0.08579189292504452, 0.1265323197003454, 0.12708093010587618, 0.14785990730160847, 0.08933985605835915, 0.2123631679569371, 0.09977210720535368, 0.15241615968989208, 0.13749799691140652, 0.14911063393810764, 0.1365872926544398, 0.2063139816164039, 0.13596279022749513, 0.08601015855674632, 0.14108178351307288, 0.15173124644206837, 0.2566286997171119, 0.1862087260815315, 0.10419124781037681, 0.26004569604992867, 1.0400768648833036, 3.244153819978237, 8.765510246157646, 17.772303745150566, 38.01276884973049, 49.47194695472717, 60.82301326096058, 65.91370269656181, 78.0514445900917, 88.69800209999084, 98.41314598917961, 86.19259133934975, 85.5326883494854, 91.77918836474419, 91.91843569278717, 85.17358481884003, 83.26917260885239, 67.83364847302437, 69.89784210920334, 79.14114251732826, 66.87448874115944, 66.63520038127899, 61.91238820552826, 66.89541801810265, 81.19136810302734, 78.74736964702606, 81.23191192746162, 83.7563444674015, 78.28111946582794, 78.55854257941246, 82.18597993254662, 94.17009606957436, 91.47570624947548, 96.29254058003426, 96.8529649078846, 86.47376865148544, 92.202637642622, 87.44451776146889, 86.77253901958466, 91.29818737506866, 93.30759555101395, 94.56165745854378, 86.86078548431396, 95.37094563245773, 84.62388351559639, 88.10435995459557, 82.77552589774132, 76.70783668756485, 62.45477110147476, 41.70687362551689, 21.890999637544155, 13.540517371147871, 4.794792663305998, 1.6597067657858133, 0.3088222537189722, 0.18341014656471089, 0.13615172618301585, 0.17553659796249121, 0.13220361928688362, 0.0912467970920261, 0.12666967639233917, 0.16949707438470796, 0.12268815058632754, 0.08195879665436223, 0.1759806991321966, 0.1869872389943339, 0.1687674838467501, 0.16270737309241667, 0.11486837800475769, 0.17036057804943994, 0.17121946555562317, 0.19767757941735908, 0.1725909099332057, 0.09815475219511427, 0.11034561131964438, 0.11604991421336308, 0.23923283239128068, 0.11281516708550043, 0.17859770479844883, 0.11036866984795779, 0.0991678134596441, 0.1380576950032264, 0.18409854790661484, 0.14269668201450258, 0.15008525195298716, 0.23315479134907946, 0.18443724926328287, 0.1025034704071004, 0.1478047508862801, 0.1373711638734676, 0.19256881292676553, 0.10604256487567909, 0.19238725391915068, 0.11763781338231638, 0.16676040482707322, 0.10045955117675476, 0.12971527234185487, 0.11375451824278571, 0.07312392932362854, 0.19773095467826352, 0.13577725330833346, 0.15357284137280658, 0.128917166730389, 0.12406154681229964, 0.13751744118053466, 0.1502376890857704, 0.15655216353479773, 0.23680209094891325, 0.1520649011945352, 0.13548633141908795, 0.24343923636479303, 0.10716432851040736, 0.1763914036564529, 0.1027633631019853, 0.16288179263938218, 0.11340806886437349, 0.1663012825883925], [0.04825125070055947, 0.048396266356576234, 0.024928089223976713, 0.04309726515202783, 0.03923840522475075, 0.03265729937993456, 0.013639746612170711, 0.04378963327326346, 0.03141832465189509, 0.057604330067988485, 0.015328831123042619, 0.05505285233084578, 0.03743445573491044, 0.0938422285253182, 0.07453920494299382, 0.04176972623099573, 0.05460532243887428, 0.06652081137872301, 0.031171701557468623, 0.005348237600628636, 0.03746813068573829, 0.012470027249946725, 0.029329421995498706, 0.04358319005405065, 0.018853376714105252, 0.06187362363561988, 0.031715940713183954, 0.037020905074314214, 0.048379671934526414, 0.0437193110701628, 0.04660860329749994, 0.07656314555788413, 0.06491838095826097, 0.030042974722164217, 0.013210853903729003, 0.03377616492798552, 0.007826087330613518, 0.05073700383945834, 0.013394007601164049, 0.020185201537969988, 0.054848301588208415, 0.046099775718175806, 0.03955916145059746, 0.07700168804149143, 0.0251895367182442, 0.025245201504731085, 0.026021076082543004, 0.01939314628543798, 0.0024422407886959263, 0.06455276190536097, 0.01846947670856025, 0.027214050642214715, 0.053386712243082, 0.04033738121506758, 0.043342634016880766, 0.019715965681825764, 0.07864629471441731, 0.2683461725246161, 2.2518546413630247, 6.745971338823438, 16.128869131207466, 20.45664880424738, 32.49994866549969, 45.0407425314188, 52.4083685874939, 55.28408467769623, 62.69757427275181, 69.14483651518822, 64.38889771699905, 62.18744404613972, 64.74179238080978, 67.95169293880463, 49.32673394680023, 47.20679730176926, 43.63577552139759, 52.43421480059624, 48.91802407801151, 28.784156553447247, 37.401412054896355, 38.61825495958328, 29.65855423361063, 23.07039175182581, 38.69005970656872, 39.69731725752354, 23.61154731363058, 25.613488890230656, 33.40808093547821, 34.74668450653553, 39.68714140355587, 52.50868320465088, 54.053680300712585, 59.29049089550972, 55.23829333484173, 62.81923234462738, 52.61951565742493, 60.436551198363304, 57.095641270279884, 65.46060740947723, 63.54975074529648, 56.158185973763466, 57.895619943737984, 62.59154096245766, 55.98091408610344, 53.23929660022259, 58.0187751352787, 58.100877329707146, 54.15358453989029, 56.06729865074158, 53.047399297356606, 41.02525480091572, 27.293300852179527, 22.101462744176388, 11.911759469658136, 4.012208506464958, 0.9416734264232218, 0.2295900630997494, 0.04731678658572491, 0.09505106092547067, 0.05685656062269118, 0.05866635081474669, 0.03499643753457349, 0.03555705217877403, 0.018551795728853904, 0.12316604916122742, 0.09560491831507534, 0.02722017336054705, 0.05492008582223207, 0.036875314253848046, 0.03271322391810827, 0.03924250187992584, 0.009500597916485276, 0.012820090887544211, 0.01593677901837509, 0.03929391044948716, 0.024605221587989945, 0.08233610453316942, 0.06915645237313583, 0.00862551396494382, 0.03686308366013691, 0.09430670907022431, 0.02491622042725794, 0.010868505032703979, 0.025866685246000998, 0.021550632664002478, 0.07677522909943946, 0.016893255233298987, 0.030409265418711584, 0.017163918346341234, 0.03510271679260768, 0.017979694493988063, 0.03963240400480572, 0.0575083629519213, 0.019894428078259807, 0.03585577775083948, 0.0737033314362634, 0.030133997279335745, 0.05439681975985877, 0.07785365130985156, 0.0067254943860461935, 0.045353312452789396, 0.04315376856538933, 0.04024094654596411, 0.03657446985016577, 0.04404816041642334, 0.06392403665813617, 0.01709417501842836, 0.019537839107215405, 0.06930362025741488, 0.0681799789890647, 0.036555470869643614, 0.04320322157582268, 0.020932371699018404, 0.0486899861425627, 0.02953796363726724, 0.02921578434325056, 0.058841345526161604, 0.030750827754673082, 0.032121012336574495, 0.014715282795805251, 0.02644767184392549, 0.008477193896396784, 0.03274893977504689, 0.01859957519627642, 0.018154449862777255, 0.04362448315077927, 0.07999655819730833, 0.03376775268407073, 0.08399621467106044, 0.05560683588555548, 0.021879693522350863, 0.12732693721773103, 0.032390475025749765, 0.00881905772985192, 0.04954055417329073, 0.03830465728242416, 0.0381495038891444, 0.05222319909080397, 0.03687791548145469, 0.02742807675531367, 0.03602699493058026, 0.02866688635549508, 0.03320939787954558, 0.052571615160559304, 0.028735503474308643, 0.07213106931885704, 0.05280661993310787, 0.01698106985713821, 0.0594551313406555, 0.08444757404504344, 0.04143532190937549, 0.0439419590838952, 0.004898241923001478, 0.0464620773709612, 0.04131198067625519, 0.025920273874362465, 0.03176672958943527, 0.03268199805461336, 0.0397652892570477, 0.016422379230789375, 0.012847425114159705, 0.03766750494833104, 0.032162728457478806, 0.03252853675803635, 0.021975634663249366, 0.02418630334432237, 0.0611532245966373, 0.03731702199729625, 0.0646940000297036, 0.0686125249194447, 0.008726834748813417, 0.019641749058791902, 0.06140634519397281, 0.059503545344341546, 0.4076337249716744, 3.057113606482744, 8.612646348774433, 20.79332783818245, 29.01322916150093, 41.705520898103714, 54.965635165572166, 63.562293872237206, 68.00473809242249, 74.68068346381187, 77.45544657111168, 76.68966606259346, 71.28485888242722, 75.22040650248528, 77.43738234043121, 59.69483479857445, 57.5677203387022, 52.9026460647583, 58.86422596871853, 59.787625819444656, 39.536069110035896, 47.45507597923279, 48.513414189219475, 37.71290794014931, 29.198947995901108, 51.11120939254761, 57.007231414318085, 36.41843140125275, 37.72691398859024, 43.63095358014107, 45.376104936003685, 50.98588451743126, 66.14922165870667, 60.985484942793846, 68.51322680711746, 66.43114373087883, 72.14987486600876, 63.07362489402294, 72.62294948101044, 67.20103561878204, 77.701316177845, 74.97743234038353, 63.77680376172066, 67.28575587272644, 76.29216939210892, 66.97725042700768, 62.6066679507494, 68.17987069487572, 67.06244945526123, 64.79217007756233, 66.04912742972374, 63.13497640192509, 50.6979663670063, 33.97172749042511, 28.279102854430676, 15.435926914215088, 6.112628923729062, 1.680086615961045, 0.29144056141376495, 0.07360662959399633, 0.0778732959588524, 0.025350608739245217, 0.06142729602288455, 0.03725072223460302, 0.006845716279713088, 0.04190294916043058, 0.07561441365396604, 0.01839931221184088, 0.019314610362926032, 0.04161483630014118, 0.05362648531445302, 0.027884623741556425, 0.019099107375950553, 0.041081269228016026, 0.037393051316030324, 0.03495479191769846, 0.026708232471719384, 0.07042703888146207, 0.05109537953103427, 0.09004861451103352, 0.09036253555677831, 0.054410594020737335, 0.018155789439333603, 0.06713056733133271, 0.0549075954768341, 0.042681525155785494, 0.08872881619026884, 0.0326568244054215, 0.014155875996948453, 0.03853206246276386, 0.013945956743555143, 0.010815152963914443, 0.03107113683654461, 0.02563619829743402, 0.01955790306965355, 0.04854973507463001, 0.09707135017379187, 0.0302357698456035, 0.02011399617913412, 0.017224820840056054, 0.051903901185141876, 0.013572546995419543, 0.028043519414495677, 0.09104276585276239, 0.03383549592399504, 0.027571782520681154, 0.01950603436853271, 0.04236842047248501, 0.056398377200821415, 0.021768555052403826, 0.05297434159729164, 0.024293404530908447, 0.015321383671107469, 0.023701571444689762, 0.06030522439687047, 0.029631221914314665, 0.07679405738599598, 0.05534148840524722, 0.008314850019814912, 0.07421780304866843, 0.13562506850576028, 0.0983085845655296, 0.10379591316450387, 0.07226114554214291, 0.1222569627861958, 0.1451150147477165, 0.14374526246683672, 0.27768740721512586, 0.1610975360381417, 0.18344182142755017, 0.1341842333204113, 0.1134016715514008, 0.18031347601208836, 0.30728128796909004, 0.1692787790670991, 0.1273130887420848, 0.13753140839980915, 0.15116549242520705, 0.16781271086074412, 0.09289097331929952, 0.1739652783726342, 0.15447447658516467, 0.17375761060975492, 0.09863541155937128, 0.17242049798369408, 0.12338392887613736, 0.1620124705368653, 0.10940505046164617, 0.10739501769421622, 0.09539267150103115, 0.1647678719018586, 0.23711256100796163, 0.13432245090370998, 0.14065844763536006, 0.12212973640998825, 0.12896884989459068, 0.17777864093659446, 0.10461464305990376, 0.11405807890696451, 0.15863511973293498, 0.122224827791797, 0.13219275424489751, 0.16494836221681908, 0.21246843418339267, 0.23025473055895418, 0.09652321474277414, 0.10755248658824712, 0.10415890501462854, 0.13222419162048027, 0.16485997242853045, 0.1936157012823969, 0.10777625895570964, 0.13451799197355285, 0.10134519310668111, 0.1454023297992535, 0.2768978214589879, 0.9618056961335242, 4.533615577965975, 13.13498793169856, 26.168207824230194, 40.61563678085804, 56.32334031164646, 70.17279535531998, 78.58688905835152, 81.44406974315643, 85.44987559318542, 89.94467720389366, 86.36553525924683, 82.74673864245415, 84.08340811729431, 87.62015953660011, 69.66423824429512, 66.38399586081505, 61.739467084407806, 68.70107352733612, 67.72889569401741, 46.988719403743744, 55.024794191122055, 54.28472310304642, 45.89429073035717, 37.346805185079575, 59.48356993496418, 59.25319589674473, 38.18232715129852, 42.58402995765209, 52.440404668450356, 53.029262870550156, 60.675945952534676, 74.04611751437187, 72.09850162267685, 80.1463557779789, 78.15498903393745, 83.6815644800663, 74.7656013071537, 83.50566431879997, 79.97958272695541, 90.0442622601986, 86.24351620674133, 75.76490968465805, 81.22273162007332, 87.36420527100563, 80.99363431334496, 75.94144821166992, 79.0840619802475, 79.27785158157349, 76.34531334042549, 77.15245082974434, 75.05144476890564, 60.6930298358202, 42.229577377438545, 34.09296378493309, 20.01650132238865, 8.168178498744965, 2.6833870355039835, 0.7061835564672947, 0.26087396254297346, 0.2538945386186242, 0.1671304990304634, 0.206972919695545, 0.0891355873318389, 0.1270575079252012, 0.09244610031601042, 0.2752730227075517, 0.27359300816897303, 0.14202699763700366, 0.18524485436500981, 0.20861109194811434, 0.14979965868405998, 0.18235116120195016, 0.1574453234206885, 0.09596638134098612, 0.10986940484144725, 0.1257329375948757, 0.12943007983267307, 0.1944618535344489, 0.2734983101254329, 0.1762515978771262, 0.14637755637522787, 0.13956333452370018, 0.1799107124679722, 0.14739720791112632, 0.12593290186487138, 0.18071594269713387, 0.13201478723203763, 0.15879469632636756, 0.10947558417683467, 0.09905744867864996, 0.12035355437546968, 0.11975953195360489, 0.1032914753886871, 0.19266729592345655, 0.12183261016616598, 0.11653844034299254, 0.2648521412629634, 0.08671361807500944, 0.14755380107089877, 0.18195644253864884, 0.09679098904598504, 0.14289067941717803, 0.22383203613571823, 0.21853992948308587, 0.12271228522877209, 0.09124145362875424, 0.23219820752274245, 0.1894676746451296, 0.09606575491488911, 0.25867768039461225, 0.16637488879496232, 0.11474545608507469, 0.06012606623698957, 0.21507018129341304, 0.11368451145244762, 0.16758102719904855, 0.15295366756618023, 0.13286096916999668], [0.030529061041306704, 0.036257606188883074, 0.04506928140472155, 0.034363593367743306, 0.03776099700189661, 0.04563902075460646, 0.033699144842103124, 0.035150381227140315, 0.06270457670325413, 0.06827674762462266, 0.060842145976494066, 0.0848690842394717, 0.05454309706692584, 0.041717126514413394, 0.06636335732764564, 0.030528259521815926, 0.032070705856313, 0.04847980620979797, 0.03742411390703637, 0.08760170909226872, 0.01616772609850159, 0.029166553977120202, 0.020870331863989122, 0.018727675451373216, 0.03400960376893636, 0.028977447327633854, 0.01761871015332872, 0.08394839067477733, 0.10145316817215644, 0.10757261363323778, 0.03207404552085791, 0.0015859691211517202, 0.06783240154618397, 0.0388199452572735, 0.05682179471477866, 0.040791916981106624, 0.06755785885616206, 0.0232154572950094, 0.006659722939730273, 0.041753024197532795, 0.02364252803090494, 0.02198793947172817, 0.0410123125766404, 0.021409077271528076, 0.05693041173799429, 0.022056224479456432, 0.04002110756118782, 0.03243700026359875, 0.015795462968526408, 0.025113379379035905, 0.03805563334026374, 0.048823669203557074, 0.030673280743940268, 0.07253140604007058, 0.3624043066520244, 0.938452921109274, 3.624377567321062, 10.949141923338175, 24.226914793252945, 33.289542496204376, 40.0222834199667, 46.23961240053177, 57.21342355012894, 48.970248475670815, 51.58903755247593, 54.71215456724167, 58.26386198401451, 54.996949285268784, 51.08021065592766, 53.97881291806698, 41.02080523967743, 30.289643369615078, 30.322156324982643, 25.78360766172409, 28.404357433319092, 32.52336300909519, 21.73384767025709, 24.489163421094418, 34.84569199383259, 25.295795537531376, 27.072496600449085, 35.53996033966541, 24.729171842336655, 16.332091726362705, 18.064791150391102, 19.978569857776165, 20.153922848403454, 19.432332068681717, 22.874924540519714, 25.881575904786587, 36.571874767541885, 34.63220424950123, 35.24712525308132, 37.74569258093834, 36.215548887848854, 44.13988307118416, 43.33971820771694, 38.55716563761234, 45.366886630654335, 41.85787372291088, 39.22120280563831, 41.362566500902176, 41.4497946202755, 48.34863223135471, 53.997872695326805, 47.65489965677261, 58.38010534644127, 58.20627987384796, 60.52038609981537, 58.92018176615238, 54.472509026527405, 54.76352021098137, 41.69303096830845, 27.46543351560831, 15.267089623957872, 7.5911390874534845, 2.724927356466651, 1.0958302044309676, 0.5114824196789414, 0.09788138951989822, 0.05555571675358806, 0.054177029014681466, 0.039097189364838414, 0.09439561094040982, 0.004020262203994207, 0.054977346226223744, 0.012297751582082128, 0.04175995956757106, 0.09080885574803688, 0.021852371355635114, 0.08157495045452379, 0.04217843437800184, 0.03369901496625971, 0.03859046948491596, 0.05316863956977613, 0.033141699168481864, 0.018244943639729172, 0.09861753322184086, 0.014952079854992917, 0.06823755480581895, 0.023823997980798595, 0.04267361386155244, 0.0679556277464144, 0.017539417240186594, 0.008769805099291261, 0.023621614309377037, 0.028783793168258853, 0.053597905207425356, 0.03776544617721811, 0.06099822334363125, 0.03293828762252815, 0.05320831107383128, 0.018898033595178276, 0.08347222130396403, 0.04502309384406544, 0.01634529049624689, 0.018885203717218246, 0.012546044508781051, 0.05866377927304711, 0.054585232501267456, 0.011880849197041243, 0.057046160800382495, 0.03735126098035835, 0.0645590627391357, 0.03567383282643277, 0.026257719146087766, 0.021405277475423645, 0.024067212762020063, 0.011716618409991497, 0.047452707221964374, 0.01400729153829161, 0.07324799415073358, 0.04275035564205609, 0.033537683193571866, 0.028185768715047743, 0.05887338033062406, 0.052014722386957146, 0.14483981154626235, 0.05398332104959991, 0.03437089981161989, 0.10545015291427262, 0.07203758097602986, 0.0485536536143627, 0.04478988877963275, 0.044589980170712806, 0.022331475920509547, 0.01138119085226208, 0.03977656990173273, 0.04530832346063107, 0.06876186729641631, 0.018893092747021, 0.059083749511046335, 0.042735338283819146, 0.0710421011899598, 0.027081940934294835, 0.10276725195581093, 0.04842219699639827, 0.04052438758662902, 0.028700377624772955, 0.06839161724201404, 0.04231143095239531, 0.043536560915526934, 0.04703886712377425, 0.059425174549687654, 0.05371258557715919, 0.07104714037268423, 0.009727958567964379, 0.03306930266262498, 0.04192904678347986, 0.03670903606689535, 0.08854862273437902, 0.04750096166389994, 0.05575990384386387, 0.011317411608615657, 0.02653904135513585, 0.03286114508227911, 0.04431973822647706, 0.08622362991445698, 0.09864985375315882, 0.048397598511655815, 0.02290796324814437, 0.009928541603585472, 0.02348476969928015, 0.03830673529591877, 0.01665637653786689, 0.029617729669553228, 0.057122679936583154, 0.05463271510961931, 0.020714230377052445, 0.048797816489241086, 0.5725327343679965, 1.5373921603895724, 4.705971954390407, 14.248474482446909, 29.89581160247326, 38.89795035123825, 48.48964266479015, 55.57053230702877, 68.05042684078217, 60.50256885588169, 64.92080077528954, 66.89822226762772, 68.64999666810036, 65.09901881217957, 59.87460695207119, 64.48473617434502, 50.657836720347404, 40.96155881881714, 42.43192791938782, 38.255218639969826, 41.19229383766651, 46.950440257787704, 36.35620214045048, 36.81821934878826, 43.875462859869, 39.75530594587326, 40.75863070785999, 40.01756027340889, 37.80864380300045, 29.32709041982889, 27.91364226490259, 30.241887532174587, 30.56382905691862, 31.05750046670437, 38.45852293074131, 36.98593094944954, 49.58917826414108, 48.10684360563755, 42.740684151649475, 51.57677561044693, 45.5794358253479, 52.12638571858406, 54.56024631857872, 50.77742390334606, 54.32927571237087, 55.238540321588516, 51.159846782684326, 49.93551827967167, 52.418802827596664, 59.51620638370514, 62.013287991285324, 57.66216427087784, 66.12389981746674, 67.39212736487389, 68.92535269260406, 67.75674059987068, 63.92060324549675, 63.04299473762512, 50.74458606541157, 34.857136979699135, 21.49215593934059, 11.441690493375063, 4.483471568673849, 1.5476685902103782, 0.8506022288929671, 0.11673709843307734, 0.010824565251823515, 0.01810016176023055, 0.03219193567929324, 0.03816918564552907, 0.008271368515124777, 0.03252745693316683, 0.040871285964385606, 0.018208248147857375, 0.059402372062322684, 0.026696495406213216, 0.04720233257103246, 0.04987588989024516, 0.026743304515548516, 0.06027311537764035, 0.009032419620780274, 0.01833448746765498, 0.037575070455204695, 0.049546906957402825, 0.06444164013373666, 0.023682687497057486, 0.1361685135634616, 0.04478541733988095, 0.06373537529725581, 0.007682051309529925, 0.027572142462304328, 0.0037526409687416162, 0.05216384583036415, 0.039820723977754824, 0.026766964183480013, 0.04309550626203418, 0.01865911213826621, 0.03129726923361886, 0.01837233328842558, 0.04928110305627342, 0.07408892168314196, 0.027931282565987203, 0.007283910881596967, 0.0052964843962399755, 0.01860023199697025, 0.030440307600656524, 0.03183252098097, 0.012995974320801906, 0.0404983864427777, 0.1160580555733759, 0.055623111184104346, 0.03943833609810099, 0.022496887650049757, 0.05119061934237834, 0.03560328055755235, 0.0868217638344504, 0.011816402020485839, 0.025790884137677494, 0.04582982321153395, 0.04877521438174881, 0.028565789143613074, 0.041316255446872674, 0.14273993438109756, 0.24871644069207832, 0.12190562265459448, 0.11218688712688163, 0.2118592051556334, 0.15550202457234263, 0.1502133021131158, 0.14628230914240703, 0.09959778413758613, 0.12727835623081774, 0.19065858417889103, 0.15581883257254958, 0.12221460841828957, 0.21935636614216492, 0.13761112990323454, 0.12297107954509556, 0.1906233766931109, 0.2020306614576839, 0.13952707318821922, 0.16021389048546553, 0.12994830671232194, 0.32548581424634904, 0.11125223376438953, 0.19704966311110184, 0.10622194939060137, 0.159420000272803, 0.1331075996858999, 0.1650193115347065, 0.23538099689176306, 0.2537690266035497, 0.09287370354286395, 0.17672010086243972, 0.24764378496911377, 0.12676400336204097, 0.19813272374449298, 0.16137909202370793, 0.23442974168574437, 0.1220352461677976, 0.11228355186176486, 0.10238279719487764, 0.10488410203834064, 0.11746325282729231, 0.3115980641450733, 0.13318625249667093, 0.1536306249909103, 0.14948406780604273, 0.16897905530640855, 0.13467072596540675, 0.17000684078084305, 0.10593044862616807, 0.22530430869664997, 0.14913739578332752, 0.11106596211902797, 0.23486195364966989, 0.6525813171174377, 2.074844464659691, 7.112380927428603, 17.841093353927135, 36.00298069417477, 47.75137647986412, 59.45832408964634, 67.74987816810608, 78.76467391848564, 72.68751561641693, 75.24638950824738, 76.648278683424, 81.12927943468094, 74.6305413544178, 70.19956111907959, 73.99738132953644, 60.2384602278471, 47.376617789268494, 48.381451070308685, 42.76918262243271, 44.61993791162968, 48.59702870249748, 36.558385491371155, 38.37947577238083, 50.083600133657455, 41.613964810967445, 43.09116214513779, 51.09263598918915, 39.00684870779514, 27.548973932862282, 29.172955490648746, 34.10657085478306, 34.508676677942276, 32.54365012049675, 39.08971846103668, 41.79817512631416, 55.751782581210136, 55.62386244535446, 51.84137061238289, 58.4492464363575, 53.17430108785629, 61.31926283240318, 65.12500181794167, 59.96751196682453, 65.83234146237373, 63.58731932938099, 60.14921061694622, 58.69795449078083, 59.96272802352905, 67.22659304738045, 71.57362058758736, 66.79034605622292, 78.33932474255562, 78.04102554917336, 79.814922362566, 78.12774449586868, 73.74290898442268, 71.56532183289528, 59.05998766422272, 42.85509981215, 26.649347506463528, 13.514446020126343, 5.765921277925372, 2.2999028256163, 0.9642743761651218, 0.31920795736368746, 0.1611494566895999, 0.2376905010896735, 0.16077121370472014, 0.155813607852906, 0.0901274305942934, 0.20961459435056895, 0.13435207743896171, 0.17624603176955134, 0.240934532484971, 0.11425942357163876, 0.12835018074838445, 0.19744776596780866, 0.12968325609108433, 0.10853543892153539, 0.07272481714608148, 0.10893959028180689, 0.11343682708684355, 0.2747834427282214, 0.11347124047460966, 0.19274277234217152, 0.15426088648382574, 0.13500481116352603, 0.12874538922915235, 0.06991531321546063, 0.14409077673917636, 0.19136923510814086, 0.14247614541091025, 0.13852116622729227, 0.10340597393224016, 0.1540729301632382, 0.09676842033513822, 0.12654512916924432, 0.1471588300773874, 0.17581751570105553, 0.15471779712243006, 0.11601035032072105, 0.08613297657575458, 0.09250334216631018, 0.16248324449406937, 0.07194421137683094, 0.1282083266414702, 0.09268300127587281, 0.09179718865198083, 0.18447892827680334, 0.12504410580731928, 0.18556008901214227, 0.09784425987163559, 0.201545994495973, 0.2306341312942095, 0.16696219478035346, 0.08692559029441327, 0.17840697284555063, 0.21279445965774357, 0.13170283287763596, 0.13483649207046255, 0.2640193625120446], [0.01751647374476306, 0.011467042495496571, 0.03921442272257991, 0.040542354981880635, 0.04973467031959444, 0.014456139670073753, 0.0358407232852187, 0.05657212510413956, 0.08224104283726774, 0.025937968530342914, 0.0995184708153829, 0.005631360909319483, 0.05829966306919232, 0.02105861101881601, 0.014416528465517331, 0.07659741793759167, 0.0289060174691258, 0.052333838466438465, 0.0826888250594493, 0.04242713548592292, 0.03232230505091138, 0.04725849830720108, 0.009927960873028496, 0.04203899596177507, 0.055344145293929614, 0.0190762789134169, 0.053452447973540984, 0.04467577986360993, 0.029417761688819155, 0.027356153368600644, 0.051013691336265765, 0.03127267445961479, 0.05024422520364169, 0.04347044297901448, 0.0455848773708567, 0.02411079352896195, 0.05437159416032955, 0.09235291625373065, 0.04360589606221765, 0.020782203682756517, 0.047864298612694256, 0.08774858753895387, 0.01675843112025177, 0.11607643114984967, 0.08550658167223446, 0.060694610729115084, 0.0018366979156780872, 0.08213424778659828, 0.027488836385600735, 0.084570414328482, 0.0479449811973609, 0.1207854991662316, 0.06189242594700772, 4.569167895242572, 8.877872116863728, 16.736190542578697, 25.127688758075237, 33.93753692507744, 49.62318643927574, 57.780292332172394, 62.22820445895195, 64.47979643940926, 68.542500436306, 65.57817310094833, 53.29689770936966, 46.00826561450958, 52.63357490301132, 42.703879326581955, 44.5027370005846, 32.389112412929535, 33.75422716140747, 18.262135460972786, 11.358328666538, 17.00107242912054, 11.475900057703257, 14.312611240893602, 25.156441815197468, 22.598983347415924, 30.445735193789005, 18.869320079684258, 15.09347788989544, 20.930207893252373, 19.66140277683735, 25.027186051011086, 23.705903850495815, 22.36398495733738, 19.50662948191166, 23.13481729477644, 17.259732149541378, 21.72885663807392, 13.57730034738779, 20.27012061327696, 21.943480521440506, 11.051493231207132, 23.33546932786703, 22.476470321416855, 26.690734885632992, 28.10181576758623, 29.68418575823307, 32.81642608344555, 24.367710538208485, 38.63161504268646, 36.01643957197666, 30.028517581522465, 39.39282439649105, 37.491049244999886, 41.906704902648926, 60.80963797867298, 51.612349301576614, 53.87311019003391, 66.24870792031288, 61.74965813755989, 61.070368587970734, 53.66781860589981, 45.42352259159088, 36.38481080532074, 27.76495434343815, 9.753350839018822, 7.0126196555793285, 3.8232835941016674, 0.48642089415807277, 0.060842305538244545, 0.042526420002104715, 0.0646843743743375, 0.0186430687608663, 0.03450471274845768, 0.009504431109235156, 0.017084391656680964, 0.02801838101731846, 0.03307178514660336, 0.037846915438422, 0.04339721897849813, 0.027641123233479448, 0.019532874139258638, 0.012652701334445737, 0.010289601086697076, 0.015889251881162636, 0.08479547803290188, 0.020385080460982863, 0.03161768407153431, 0.0371051202819217, 0.03531841830408666, 0.06658958620391786, 0.047013552466523834, 0.029998551617609337, 0.08404325941228308, 0.05278706805256661, 0.01682978676399216, 0.09403170624864288, 0.04953171890520025, 0.020142596695222892, 0.029893044193158858, 0.013293836218508659, 0.02683793947653612, 0.008925105994421756, 0.032246557748294435, 0.03806999389780685, 0.05737849081924651, 0.023014771286398172, 0.015101804438018007, 0.056294843889190815, 0.0145589985550032, 0.011692654461512575, 0.01953846622200217, 0.09193249701638706, 0.0470203097211197, 0.04160264281381387, 0.10111011783010326, 0.022781081970606465, 0.04551593927317299, 0.019554056889319327, 0.01247452095412882, 0.13084958569379523, 0.04699575947597623, 0.0738669082056731, 0.059585367125691846, 0.007172535388235701, 0.08705002619535662, 0.034919658646686, 0.04041562584461644, 0.018508960820327047, 0.0410116706189001, 0.022331763502734248, 0.0274461517619784, 0.0438544487406034, 0.01520087280368898, 0.04798583271622192, 0.06391896036802791, 0.05469384210300632, 0.040473201661370695, 0.03276147836004384, 0.0514146032219287, 0.04707493550085928, 0.04083913241629489, 0.027619420980045106, 0.03998728789156303, 0.014320514965220354, 0.09220096151693724, 0.04708373737230431, 0.07392498868284747, 0.034232826947118156, 0.04968959969119169, 0.044520711817312986, 0.06852697013528086, 0.054816756601212546, 0.013489070224750321, 0.042508623300818726, 0.058215425597154535, 0.042829390658880584, 0.07310784698347561, 0.02388280576269608, 0.047402456402778625, 0.06326283502858132, 0.053442625649040565, 0.018708843454078306, 0.03091943628533045, 0.08115589676890522, 0.024150151475623716, 0.038062791354605, 0.04591367476677988, 0.013658197331096744, 0.03982908798207063, 0.013584949210780906, 0.04104153093066998, 0.09048201391124167, 0.06317995939753018, 0.025403590661881026, 0.13478813372785226, 0.20163190551102161, 6.0542545560747385, 12.796346303075552, 21.227973215281963, 32.664282247424126, 42.8210574388504, 59.4743250310421, 66.60717308521271, 73.64287555217743, 75.53261294960976, 77.83124640583992, 75.16447350382805, 63.33774112164974, 53.243590369820595, 61.3831640034914, 53.080138340592384, 52.916279733181, 48.23761358857155, 40.17774447798729, 22.765589207410812, 19.476698487997055, 25.128285326063633, 18.999962769448757, 20.539094880223274, 23.68587512522936, 23.154452741146088, 39.55591544508934, 28.87064751237631, 27.16709442436695, 35.45923367142677, 25.914314948022366, 31.870989315211773, 28.653358072042465, 31.270539835095406, 30.288353338837624, 31.897228807210922, 26.84977725148201, 31.862947046756744, 23.226857855916023, 35.53541198372841, 35.39111092686653, 21.972628757357597, 33.63036520779133, 36.05562686920166, 39.790150076150894, 40.8875197917223, 44.3411772698164, 41.26008979976177, 34.28536266088486, 51.70838534832001, 46.10926799476147, 36.69016242027283, 47.24309295415878, 42.704213708639145, 49.92092706263065, 69.01365235447884, 62.338854521512985, 62.50816583633423, 75.73743715882301, 71.23208731412888, 68.44264939427376, 64.79030057787895, 56.23334214091301, 46.32242135703564, 36.961574256420135, 15.618409272283316, 9.684812016785145, 5.286073051393032, 0.9574612230062485, 0.19799621310085058, 0.02915010612923652, 0.04177220871497411, 0.029289884078025352, 0.04344091663369909, 0.026987300407199655, 0.018128734445781447, 0.014445975957642077, 0.059377231809776276, 0.04535346830380149, 0.02276886436447967, 0.025023362431966234, 0.008207985392800765, 0.03169627379975282, 0.04181744632660411, 0.01634383403143147, 0.017268121446250007, 0.04078249912708998, 0.07179307300248183, 0.06769434723537415, 0.02038971331785433, 0.026689676924434025, 0.055260019144043326, 0.05360246199415997, 0.030172559272614308, 0.06412039409042336, 0.14038499590242282, 0.10313586928532459, 0.022370264268829487, 0.07076639332808554, 0.02415742081211647, 0.027737795389839448, 0.042177729337709025, 0.013508817846741294, 0.016567847596888896, 0.03590608052036259, 0.024273173585243057, 0.04495056746236514, 0.034885163622675464, 0.06355242847348563, 0.0478708406444639, 0.036755116016138345, 0.010890032881434308, 0.10825222794665024, 0.07165205010096543, 0.04131963964027818, 0.0630491336050909, 0.0030611849933848134, 0.04046041074616369, 0.022791505434724968, 0.04831287122215144, 0.02077215314784553, 0.07237143610836938, 0.04129235087020788, 0.044248770354897715, 0.09067982595297508, 0.10149331836146303, 0.12290278711589053, 0.08091549287200905, 0.09773811048944481, 0.11158710563904606, 0.12852765794377774, 0.28592714632395655, 0.18333769810851663, 0.12895270076114684, 0.2231730832136236, 0.1317892930819653, 0.11594029900152236, 0.10237988055450842, 0.14489415159914643, 0.18938721099402755, 0.12372682336717844, 0.13538213388528675, 0.20242630038410425, 0.16300777962896973, 0.11843338827020489, 0.1972120747086592, 0.08456368304905482, 0.13897681521484628, 0.2484450224437751, 0.10023243172327057, 0.1473291974980384, 0.15325551386922598, 0.22308488638373092, 0.08145794345182367, 0.10048405689303763, 0.07098648464307189, 0.22472926299087703, 0.15932148759020492, 0.16110182565171272, 0.09125918353674933, 0.16930138488532975, 0.21945106418570504, 0.14366375980898738, 0.09641361437388696, 0.14813576359301805, 0.1593801617855206, 0.11448272096458822, 0.11231762386159971, 0.10088696886668913, 0.13073020381852984, 0.15563777822535485, 0.14422512031160295, 0.16986964736133814, 0.28852688963525, 0.21618530270643532, 0.2330105029977858, 0.5905647855252028, 7.828178443014622, 17.16357260942459, 28.77482235431671, 43.72320123016834, 55.2568743377924, 71.08232975006104, 78.89710441231728, 82.2752371430397, 85.23586347699165, 86.57812625169754, 85.10705038905144, 73.57369646430016, 63.60063761472702, 69.0428651869297, 61.48953169584274, 60.762391313910484, 50.21658159792423, 50.36346271634102, 33.615466207265854, 23.364218585193157, 28.346537835896015, 25.573775321245193, 27.60896511375904, 38.57768453657627, 36.24530129134655, 45.82807168364525, 29.091848842799664, 26.408244743943214, 33.9556809514761, 32.37651988863945, 39.701645225286484, 34.75440949201584, 35.830291360616684, 31.391897723078728, 36.54412105679512, 30.034485161304474, 35.029172748327255, 25.64079612493515, 37.31084391474724, 37.57809117436409, 23.14769860357046, 36.989571154117584, 37.99281232059002, 42.6808525621891, 44.6124143153429, 47.42151238024235, 49.304733127355576, 39.51752230525017, 55.7650400698185, 50.74879623949528, 44.68961477279663, 55.554979741573334, 52.39274762570858, 60.34571707248688, 79.0494154393673, 71.59195080399513, 73.50146234035492, 85.87027743458748, 80.96909523010254, 81.43021568655968, 76.59347802400589, 69.5568636059761, 55.44290095567703, 44.86946292221546, 20.538158230483532, 12.105830255895853, 6.149180112406611, 1.4051894168369472, 0.3306072566192597, 0.16561748256208375, 0.16907510405872017, 0.15295788296498358, 0.17320396844297647, 0.1591563003603369, 0.17364661500323564, 0.08764021913520992, 0.11964298508246429, 0.13568292633863166, 0.1368920927052386, 0.06740445693139918, 0.12565771350637078, 0.17137292685220018, 0.10187104184296913, 0.09391124825924635, 0.2670787030365318, 0.1544913975521922, 0.14309833233710378, 0.10214447873295285, 0.15154036605963483, 0.19931463844841346, 0.156343842681963, 0.1686952283489518, 0.2634268021211028, 0.1927208196138963, 0.33543546160217375, 0.16339752590283751, 0.09353808898595162, 0.17871741321869195, 0.19137156545184553, 0.1030968694249168, 0.10505201295018196, 0.12058812499162741, 0.07726033392827958, 0.15947653708280995, 0.15550146054010838, 0.06944983077119105, 0.09746001291205175, 0.10415365803055465, 0.16485278843902051, 0.16250497457804158, 0.0984721168060787, 0.3310858231270686, 0.13152296596672386, 0.14529274427331984, 0.23360460705589503, 0.1407715360983275, 0.08367416710825637, 0.18435111560393125, 0.12119701263145544, 0.1642258814536035, 0.17163972894195467, 0.1696656903368421, 0.1335671968990937], [0.040201813098974526, 0.02396315809164662, 0.02553431440901477, 0.01877405225968687, 0.05202211417781655, 0.1010083471192047, 0.051277895909151994, 0.023810318343748804, 0.014362285819515819, 0.05783263324701693, 0.019220904941903427, 0.029405896602838766, 0.03936372428142931, 0.03257026030041743, 0.03197786689270288, 0.04863049187406432, 0.028913307214679662, 0.04445729900908191, 0.0644015047873836, 0.09046994659001939, 0.0634930343949236, 0.025347209702886175, 0.06972602102905512, 0.010508799969102256, 0.029355963051784784, 0.014204713952494785, 0.027623920250334777, 0.03703949216287583, 0.05821008584462106, 0.0021215759397819056, 0.013466039526974782, 0.03666737931780517, 0.024958780741144437, 0.10807606435264461, 0.043089086684631184, 0.03744954359717667, 0.029276228560775053, 0.01974463855731301, 0.028920077456859872, 0.041138934102491476, 0.0829394483298529, 0.051532634388422593, 0.02609952109196456, 0.06042251341568772, 0.02270376502565341, 0.09900333127006888, 0.036333119714981876, 0.018832221794582438, 0.027812616863229778, 0.025468435815128032, 0.15365976170869544, 0.44910550117492676, 6.870466908439994, 15.955571830272675, 23.976470232009888, 30.111609622836113, 41.239521503448486, 52.30566389858723, 57.64571115374565, 60.84484688937664, 60.60225650668144, 58.93063500523567, 53.30958902835846, 52.65595570206642, 50.34015856683254, 54.720924496650696, 38.74046020209789, 37.65641637146473, 21.33023902773857, 19.79446403682232, 35.456911996006966, 27.622765973210335, 24.664660803973675, 37.38540731370449, 26.313325837254524, 30.17798826098442, 42.978277802467346, 44.708628952503204, 30.346457920968533, 42.87754140794277, 42.34960533678532, 36.03240251541138, 41.65987394750118, 41.346675753593445, 41.94399990141392, 33.285434916615486, 29.92407638579607, 28.51499229669571, 35.82286275923252, 24.02168780565262, 24.75195351988077, 22.04090729355812, 15.309285409748554, 16.363542638719082, 15.875066500157118, 14.554979335516691, 20.84938433021307, 11.377832069993019, 18.467955216765404, 35.18604353070259, 20.113335326313972, 14.769945200532675, 31.842308454215527, 35.69797486066818, 38.058639988303185, 28.45382697880268, 33.05139787495136, 34.19191047549248, 37.11540900170803, 51.375211626291275, 44.19479392468929, 61.61981150507927, 52.66917139291763, 53.81073273718357, 53.591898679733276, 60.07675230503082, 62.07267500460148, 49.50536236166954, 32.196040973067284, 21.595183610916138, 10.733721982687712, 3.6655319714918733, 1.5103458054363728, 0.05971942868200131, 0.026350469051976688, 0.09916700451867655, 0.0071072231457947055, 0.009957628226402448, 0.06909833478857763, 0.08336754879564978, 0.02785383017908316, 0.04597679813741706, 0.018517566022637766, 0.027834224492835347, 0.047464195667998865, 0.05181874716072343, 0.05132760496053379, 0.02867215374863008, 0.03769951006688643, 0.024396004591835663, 0.04734750036732294, 0.05613163077214267, 0.009463546193728689, 0.020391967591422144, 0.005106664357299451, 0.04294858328648843, 0.02877262384572532, 0.03902255528373644, 0.07518724829424173, 0.006709827184749884, 0.05251367198070511, 0.04447717743460089, 0.08047971859923564, 0.023937392579682637, 0.024079617760435212, 0.04162635814282112, 0.10782463956275024, 0.048409970113425516, 0.030866528577462304, 0.029346070223255083, 0.04294581136491615, 0.06428068314562552, 0.023222403797262814, 0.03293748610303737, 0.03356537643412594, 0.030397951377381105, 0.06283667898969725, 0.035595306180766784, 0.04031165466585662, 0.058490669616730884, 0.020575892194756307, 0.0546461962221656, 0.03268685170041863, 0.0425499497941928, 0.08904974311008118, 0.023343269967881497, 0.12781203462509438, 0.06949148009880446, 0.07410861828248017, 0.030801991415501107, 0.02688131615286693, 0.056825423816917464, 0.012634047452593222, 0.022107755503384396, 0.003208375605936453, 0.057384223910048604, 0.07359707815339789, 0.01210753171108081, 0.027857544628204778, 0.047959430812625214, 0.08300236018840224, 0.0240781594402506, 0.011786803315771976, 0.015410788346343907, 0.01440115580408019, 0.03936461485864129, 0.06257144283154048, 0.09516590827843174, 0.060407432974898256, 0.0486541329883039, 0.0929971672303509, 0.039701676068943925, 0.06896110426168889, 0.028368403836793732, 0.056104082250385545, 0.036416258808458224, 0.07210201423731633, 0.08877423562807962, 0.04177790840913076, 0.01934061336214654, 0.09399931892403401, 0.014916087548044743, 0.016706482638255693, 0.006099519723647973, 0.043576555253821425, 0.0402002026385162, 0.05363483818655368, 0.01779684786015423, 0.05425008974270895, 0.020079686692042742, 0.03389735764358193, 0.06681940707494505, 0.007203051573014818, 0.020535636249405798, 0.089108476677211, 0.014628799399361014, 0.15590643568430096, 0.5432214040774852, 8.811407033354044, 22.455425150692463, 32.33092613518238, 40.4660502076149, 53.40357318520546, 62.84906454384327, 69.46245387196541, 70.67104741930962, 68.51380437612534, 67.97665759921074, 63.45690652728081, 62.840074226260185, 59.6267082542181, 63.269587978720665, 45.94357028603554, 50.212227031588554, 33.76610912382603, 31.62107102572918, 42.9205247014761, 36.97815656661987, 22.433021552860737, 34.92581829428673, 28.321489579975605, 38.78031626343727, 51.50601960718632, 42.099954932928085, 43.783872574567795, 38.10834512114525, 38.30142416059971, 36.074838638305664, 36.90871149301529, 35.05446419119835, 41.34874664247036, 30.097590275108814, 29.27778236567974, 30.021468959748745, 29.629290103912354, 27.42334697395563, 24.510719664394855, 30.605894699692726, 25.24332035332918, 21.467195078730583, 28.286333866417408, 23.763968534767628, 25.527976378798485, 19.96861059218645, 23.22169203311205, 41.499511152505875, 25.8408135920763, 29.040920175611973, 38.85099247097969, 41.58824019134045, 47.81612120568752, 36.33528046309948, 42.77360938489437, 45.155678763985634, 47.39597015082836, 61.46018207073212, 55.28898261487484, 68.9191210269928, 63.32323729991913, 61.48449696600437, 62.5250369310379, 67.86502718925476, 71.24293953180313, 59.40952330827713, 43.89840602874756, 31.738494224846363, 15.724112000316381, 5.840507950633764, 2.460433761589229, 0.18898952374001965, 0.027798547598649748, 0.043728654709411785, 0.02581300570454914, 0.07706091884756461, 0.03430034754273947, 0.02672024227649672, 0.034615678669069894, 0.018991212091350462, 0.020161911088507622, 0.07763813162455335, 0.045877958909841254, 0.04701157464296557, 0.050317022469243966, 0.038894894751138054, 0.011827651123894611, 0.06047041904821526, 0.028917110721522477, 0.08387101435801014, 0.027817917653010227, 0.019474298278510105, 0.03014256537426263, 0.037551269779214635, 0.06541211696458049, 0.024362925214518327, 0.015463553190784296, 0.011717721426975913, 0.02748559505562298, 0.08157070536981337, 0.06335985599434935, 0.12121296880650334, 0.025609386357245967, 0.017222366186615545, 0.051158321075490676, 0.07308147105504759, 0.02983639235026203, 0.0505135023558978, 0.023326846239797305, 0.05866310391866136, 0.02717603598284768, 0.03412199832382612, 0.04491092935495544, 0.024857512835296802, 0.03777095291297883, 0.039792333118384704, 0.03299515839898959, 0.03586459446523804, 0.04280617256881669, 0.006270642279559979, 0.015676546790928114, 0.009905617589538451, 0.03312412511149887, 0.04578949861752335, 0.1471540061174892, 0.14006465527927503, 0.24032283952692524, 0.1846144741284661, 0.1453813270200044, 0.12996922043384984, 0.15194657316897064, 0.1500198687426746, 0.1261991250794381, 0.28105150326155126, 0.09835496137384325, 0.14174726733472198, 0.12706626526778564, 0.11286091306828894, 0.13992873835377395, 0.16869450104422867, 0.16093364014523104, 0.14665166119812056, 0.13414427608950064, 0.26023515150882304, 0.1609498041216284, 0.2926464920165017, 0.16975937905954197, 0.1262498731375672, 0.10233044609776698, 0.09671913430793211, 0.14535484719090164, 0.14382183726411313, 0.12444429463357665, 0.1602656627073884, 0.165533545659855, 0.17355963529553264, 0.09072056986042298, 0.2012655368889682, 0.17864949186332524, 0.17455467721447349, 0.07980673166457564, 0.06770337917259894, 0.08389241047552787, 0.19245372066507116, 0.40425763581879437, 0.1842019587638788, 0.1393106926116161, 0.1335449324687943, 0.10785839243908413, 0.2714984893100336, 0.07819005200872198, 0.13850800052750856, 0.15350573637988418, 0.13378261268371716, 0.4015653021633625, 1.2390660122036934, 12.478557955473661, 29.940221719443798, 48.060128912329674, 56.829613745212555, 66.72619789838791, 74.08157721161842, 77.93217658996582, 77.81068190932274, 76.8394236266613, 74.78162884712219, 69.7354008257389, 70.30891165137291, 67.87504345178604, 71.97516024112701, 55.65054461359978, 55.93528613448143, 36.13968215882778, 32.43386261165142, 50.482054352760315, 40.28865672647953, 39.97043140232563, 53.03642548620701, 45.60303255915642, 48.116270899772644, 61.435578390955925, 62.6047832518816, 48.11939813196659, 58.181372210383415, 57.33055606484413, 51.111334785819054, 59.51936401426792, 55.80992706120014, 58.29118251800537, 47.734117805957794, 44.19895090162754, 41.70001499354839, 52.809342071413994, 37.10744842886925, 39.87486273050308, 37.978855669498444, 27.287234477698803, 27.19772268086672, 28.00162274390459, 25.096175149083138, 35.717897191643715, 22.85043865442276, 31.852864287793636, 50.321174785494804, 35.87251849472523, 26.051574982702732, 43.46850469708443, 51.45150013267994, 54.72951963543892, 44.013087674975395, 50.11432908475399, 51.25553324818611, 54.05286334455013, 68.85557323694229, 61.571675688028336, 81.4430969953537, 72.76031211018562, 71.76264524459839, 71.7999516427517, 76.33791133761406, 81.67253628373146, 68.99634048342705, 52.12581194937229, 38.36053378880024, 19.76011198014021, 8.604104407131672, 2.900314782746136, 0.4341867001494393, 0.21391148096881807, 0.1877671471447684, 0.11135044216644019, 0.08048081697779708, 0.2205726719694212, 0.21170068241190165, 0.12077692736056633, 0.15913832554360852, 0.1369801559485495, 0.16279059753287584, 0.0857110285141971, 0.11443661132943816, 0.1418542701867409, 0.11884361781994812, 0.1623229554388672, 0.10132275056093931, 0.11954879912082106, 0.14194209594279528, 0.16853283159434795, 0.1217476194142364, 0.06151453919301275, 0.2553224901203066, 0.15703328303061426, 0.13221733417594805, 0.1498605593224056, 0.05228143170825206, 0.23775886773364618, 0.14303771371487528, 0.1808655002969317, 0.2561783348210156, 0.11954725545365363, 0.08481187207507901, 0.18594916735310107, 0.1792173387366347, 0.13275197736220434, 0.1250574050936848, 0.10294269566657022, 0.16101018525660038, 0.14477779768640175, 0.07833212875993922, 0.10182185229496099, 0.10689241302316077, 0.11762598354835063, 0.11097241440438665, 0.2275184469181113, 0.14580669638235122, 0.0945625125314109, 0.15314331598347053, 0.1809280485031195, 0.14681708591524512, 0.22949621110456064, 0.09268029985832982], [0.011745101110136602, 0.010563557480054442, 0.06033239813405089, 0.0919645355315879, 0.03930280880013015, 0.03728965159098152, 0.04236996413965244, 0.038235099491430447, 0.05831825386849232, 0.03692552425491158, 0.07329098676564172, 0.029890619225625414, 0.08778894552960992, 0.05080532966530882, 0.08548997982870787, 0.03363979900314007, 0.056504767781007104, 0.021725072620029096, 0.043935654539382085, 0.03623670359957032, 0.06301873523625545, 0.015852276228542905, 0.014649929271399742, 0.03627736216003541, 0.17490549042122439, 0.039706288516754285, 0.07027529936749488, 0.06626119327847846, 0.029576599845313467, 0.04704355378635228, 0.034499465764383785, 0.04988311469787732, 0.025790106737986207, 0.06339812112855725, 0.0032766311596788, 0.090377608576091, 0.05212273827055469, 0.020374367559270468, 0.06158263495308347, 0.08659616578370333, 0.016587998761679046, 0.029567992787633557, 0.06338345629046671, 0.03458550294453744, 0.048859852613531984, 0.03656955683254637, 0.0640567549271509, 0.053256613755365834, 0.09594718198059127, 1.2725785514339805, 2.4329557735472918, 10.760163813829422, 21.71768143773079, 33.35767284035683, 49.79324251413345, 45.78861840069294, 52.03907400369644, 58.21320690214634, 63.50030779838562, 61.414345130324364, 48.644529953598976, 47.48050421476364, 56.893868297338486, 43.68545785546303, 30.801014229655266, 24.622598960995674, 42.27671764791012, 18.279285840690136, 13.510166499763727, 20.710325092077255, 25.09587686508894, 14.47621526196599, 29.863935112953186, 37.16767139732838, 24.3013945966959, 24.21684343367815, 18.97525269538164, 19.33810092508793, 34.609116688370705, 50.450265258550644, 48.45922909677029, 43.41418281197548, 35.45863710343838, 42.95588180422783, 39.10779409110546, 35.69205857813358, 34.29767780005932, 36.15934990346432, 35.397536382079124, 37.80969254672527, 29.349507316946983, 35.411899611353874, 27.470532841980457, 27.28492420166731, 21.613916605710983, 25.16888614743948, 29.2682296782732, 37.12986342608929, 43.27191464602947, 35.31628914177418, 51.924126371741295, 27.708533070981503, 57.31557346880436, 38.726826533675194, 22.461138144135475, 20.476240552961826, 14.192816019058228, 16.97434276342392, 23.771976605057716, 33.566760420799255, 47.27265536785126, 46.15515053272247, 35.28848223388195, 48.640000596642494, 48.31581339240074, 58.125367015600204, 57.42446802556515, 65.35057291388512, 58.85696455836296, 51.0580350458622, 40.718098282814026, 30.500058978796005, 17.948486991226673, 7.213244615122676, 1.1142340418882668, 0.03694470135087613, 0.03921977731806692, 0.00868941566295689, 0.02675998242921196, 0.010275213626300683, 0.05806676228530705, 0.045587359854835086, 0.06509916071081534, 0.05606004691799171, 0.028769898308382835, 0.009609219578123884, 0.028765571587427985, 0.04053086282510776, 0.0877762251184322, 0.05825892658322118, 0.04004765418358147, 0.056969871729961596, 0.04389953050122131, 0.05382001516409218, 0.041460528955212794, 0.024827357519825455, 0.033482278158771805, 0.0009248064543498913, 0.04156735369178932, 0.11322314050630666, 0.05471513060911093, 0.017991353633988183, 0.01806271669920534, 0.04977596712706145, 0.009364225497847656, 0.044675909739453346, 0.017635111616982613, 0.05654514432535507, 0.05342066549928859, 0.04298346051655244, 0.025895679100358393, 0.031600815054844134, 0.02902109674323583, 0.03135878956527449, 0.023674332769587636, 0.04983639650163241, 0.04776237576152198, 0.025500778610876296, 0.03016700800799299, 0.0940492283552885, 0.06158439384307712, 0.019355228105268907, 0.05539654834137764, 0.0944981312204618, 0.011577665172808338, 0.08607166033471003, 0.03521146369166672, 0.009224791720043868, 0.043873340109712444, 0.06809630925999954, 0.02979072800371796, 0.038833077560411766, 0.018975630700879265, 0.03270241453719791, 0.013333407532627461, 0.011416626548452768, 0.039445616566808894, 0.019906328416254837, 0.08199364790925756, 0.0219129491597414, 0.08537275760318153, 0.03986075913417153, 0.027182264457223937, 0.06990214009420015, 0.01893994824058609, 0.04362647210655268, 0.09946529593435116, 0.043858742064912803, 0.016976288570731413, 0.037708003947045654, 0.06944096952793188, 0.08296590589452535, 0.031284430078812875, 0.07317567928112112, 0.028076775051886216, 0.044070057483622804, 0.024901052784116473, 0.060937760572414845, 0.016986242626444437, 0.06566766809555702, 0.01346172208286589, 0.023103960738808382, 0.016557791495870333, 0.028112752515880857, 0.02596643545984989, 0.03344802804349456, 0.012562650063046021, 0.0219002454468864, 0.010378918559581507, 0.0256165499376948, 0.0681849142711144, 0.02533139082515845, 0.016275881134788506, 0.028138792622485198, 0.1355031187995337, 1.382694742642343, 3.745948956348002, 15.199127420783043, 24.88344546407461, 41.09362073242664, 59.948015213012695, 56.04434788227081, 62.39525869488716, 66.32888361811638, 73.53036358952522, 69.54467386007309, 61.495098397135735, 55.49136355519295, 60.97359158098698, 51.02975696325302, 37.64636591076851, 34.41112071275711, 50.37145748734474, 25.410271994769573, 20.93903671950102, 20.1169166341424, 32.69797503948212, 25.911193415522575, 37.36854761838913, 49.664015248417854, 31.863266229629517, 26.134045757353306, 24.223966151475906, 28.712194114923477, 32.97523096203804, 39.102968350052834, 41.26926630735397, 35.83503730595112, 29.723817631602287, 33.755207508802414, 26.873071901500225, 24.309303872287273, 22.336208447813988, 26.590150482952595, 27.07450859248638, 25.569787435233593, 24.65098723769188, 26.136591620743275, 26.164360530674458, 24.674910753965378, 18.56732938438654, 22.785536237061024, 35.305892899632454, 30.26169016957283, 46.560030207037926, 50.980108827352524, 52.905727699398994, 24.76767897605896, 55.812149941921234, 50.82771420478821, 32.158920764923096, 32.112434059381485, 23.867488279938698, 29.189222417771816, 36.27956785261631, 43.67532379925251, 53.42682793736458, 55.448786839842796, 42.08630606532097, 58.802688270807266, 57.15596303343773, 66.07013270258904, 66.0599872469902, 74.30182859301567, 69.93650123476982, 63.981559574604034, 54.16821375489235, 38.4184692800045, 24.462954327464104, 11.489113848656416, 2.1479283180087805, 0.18467771995346993, 0.01767909314366989, 0.024428980068478268, 0.014189942430675728, 0.04596096070599742, 0.05347343219909817, 0.04476425870961975, 0.041044039389817044, 0.007413522798742633, 0.011323031521897065, 0.07176614046329632, 0.018066926531901117, 0.040803564988891594, 0.009720587186166085, 0.04782584794156719, 0.045403529875329696, 0.022565497347386554, 0.10039039043476805, 0.040857893909560516, 0.062193518970161676, 0.021928641872364096, 0.09786606417037547, 0.026423856324981898, 0.07278513890923932, 0.071601153613301, 0.05841730089741759, 0.03878894945955835, 0.016774160940258298, 0.06127813918283209, 0.024356255162274465, 0.02856120452634059, 0.015443838037754176, 0.11175299048773013, 0.0231878586782841, 0.012240239775564987, 0.05531018090550788, 0.024388688871113118, 0.08366547655896284, 0.024781938082014676, 0.05899929310544394, 0.043470910532050766, 0.07323241647100076, 0.022017070623405743, 0.019423555786488578, 0.03906640878994949, 0.08852967570419423, 0.05553744136705063, 0.02028219652856933, 0.08290754340123385, 0.023694714000157546, 0.04868588577664923, 0.0778185625676997, 0.12774733419064432, 0.14813865796895698, 0.2157388415071182, 0.07104801610694267, 0.1085151411825791, 0.0969498160702642, 0.14449885406065732, 0.1644450525054708, 0.24493159144185483, 0.24085798737360165, 0.13922319340053946, 0.2363640457042493, 0.1540359266800806, 0.16811185574624687, 0.1779173780232668, 0.11770413169870153, 0.1528694634907879, 0.07745260212686844, 0.12285517834243365, 0.15301746258046478, 0.08907439725589938, 0.09348711086204275, 0.11166215903358534, 0.19069621106609702, 0.1308815722586587, 0.18313467619009316, 0.09789603209355846, 0.11722698269295506, 0.17042682215105742, 0.17964181752176955, 0.17893806856591254, 0.15714260138338432, 0.18185476830694824, 0.09153627179330215, 0.22981258865911514, 0.2139364171307534, 0.06270114055951126, 0.20147934963461012, 0.151283998566214, 0.07642534357728437, 0.12223403042298742, 0.24219679209636524, 0.08849204139551148, 0.15746007731650025, 0.14804517704760656, 0.19073480274528265, 0.12749393528793007, 0.17411277280189097, 1.6338050994090736, 5.889743333682418, 22.179024182260036, 35.4314761608839, 52.969389483332634, 71.8763579428196, 68.95091772079468, 73.27366456389427, 76.67358532547951, 85.10337978601456, 80.2183087170124, 65.05288168787956, 64.06245723366737, 73.28536793589592, 60.08746013045311, 44.04564432799816, 40.136083513498306, 55.79376272857189, 31.0365179926157, 24.6993263438344, 32.651796117424965, 38.821213468909264, 27.00514331459999, 47.61785924434662, 52.78325267136097, 40.67653991281986, 37.46906362473965, 33.47151853144169, 36.333775743842125, 48.53914640843868, 67.04960614442825, 62.69640773534775, 61.15341313183308, 52.37739644944668, 59.83895346522331, 55.83318941295147, 52.40018382668495, 51.87994994223118, 53.45308072865009, 52.25406266748905, 52.43223890662193, 45.68513095378876, 50.478315353393555, 41.93996071815491, 41.79315559566021, 37.07805320620537, 40.288523733615875, 43.085732236504555, 52.63533040881157, 61.0038835555315, 48.85346554219723, 65.76457589864731, 40.769710913300514, 73.2777987420559, 49.63567636907101, 35.04967264831066, 35.5155960470438, 27.33333170413971, 31.247283183038235, 39.50082220137119, 49.62365381419659, 64.96524319052696, 63.488710820674896, 52.52822935581207, 68.58262628316879, 67.5630421936512, 78.00297439098358, 75.6186555325985, 83.30619022250175, 78.95079553127289, 75.03481686115265, 64.00203287601471, 46.52309238910675, 31.01272936910391, 14.094042219221592, 2.837771326303482, 0.3561532264575362, 0.14825829217443243, 0.14779397490201518, 0.17192208644701168, 0.13832523924065754, 0.08356819584150799, 0.18972070247400552, 0.12887149496236816, 0.17575090052559972, 0.1399931122432463, 0.09747115254867822, 0.13997034315252677, 0.13495246006641537, 0.172772899386473, 0.16467072477098554, 0.12017848173854873, 0.13430174498353153, 0.2495517279021442, 0.15710127860074863, 0.20622486452339217, 0.07157062907936051, 0.16928066412219778, 0.08157031203154474, 0.17846822971478105, 0.240656687237788, 0.21746822370914742, 0.09965613920940086, 0.08119497084408067, 0.12257584879989736, 0.12854345084633678, 0.17368937755236402, 0.13185412710299715, 0.15837784681934863, 0.1272147096460685, 0.13485786592354998, 0.1596050028456375, 0.11551717834663577, 0.2225834914133884, 0.16990191594231874, 0.17861199856270105, 0.1340463274391368, 0.15973536850651726, 0.19339494203450158, 0.1574643372441642, 0.20432006829651073, 0.1681538761476986, 0.1502202040865086, 0.1900772747467272, 0.142810215766076, 0.10158267294173129, 0.1689431502018124], [0.010315656963939546, 0.0876112531113904, 0.09621701945434324, 0.10157234224607237, 0.033742686646291986, 0.06306759823928587, 0.03186904577887617, 0.05876573923160322, 0.05537935649044812, 0.01655198233493138, 0.08142732986016199, 0.021648874462698586, 0.0006969957019009598, 0.04662801788072102, 0.0607448467053473, 0.04378595964226406, 0.05541688318771776, 0.06756686852895655, 0.07688707075431012, 0.0647732985089533, 0.019092626571364235, 0.03362132323672995, 0.026367864993517287, 0.06591803903575055, 0.030670351115986705, 0.10241519194096327, 0.026846379550988786, 0.07420896406983957, 0.03395590938453097, 0.01842195328208618, 0.039584175538038835, 0.046541568808606826, 0.026712766994023696, 0.02907977093855152, 0.01035851877531968, 0.028888456399727147, 0.06284681672696024, 0.01004120240395423, 0.0165103701147018, 0.0162354470739956, 0.02789017315080855, 0.022730324635631405, 0.05226516012044158, 0.07331365937716328, 0.06272168320720084, 0.016740319006203208, 0.03845430022920482, 0.14317781635327265, 1.364601538516581, 5.737452255561948, 18.893678672611713, 32.81706444919109, 41.68289311230183, 56.13635614514351, 59.864647686481476, 70.53761377930641, 68.94081026315689, 58.69944401085377, 57.03583247959614, 59.646698981523514, 26.595620289444923, 43.83373349905014, 40.00218249857426, 26.29813425242901, 23.450715243816376, 21.998155787587166, 14.14365615695715, 18.75805824995041, 26.145714931190014, 39.57353509962559, 24.958200752735138, 38.75255115330219, 18.229419216513634, 24.91301167756319, 32.373890429735184, 39.37581270933151, 40.18863469362259, 26.422402784228325, 41.13724619150162, 31.414164528250694, 29.90783415734768, 28.305120058357716, 20.819341242313385, 23.342048674821854, 31.03380873799324, 23.387963511049747, 20.614585429430008, 24.791043922305107, 19.74799443036318, 26.95510569959879, 21.08234602957964, 29.892619773745537, 35.281513407826424, 26.55595611780882, 45.48707418143749, 34.34089668095112, 27.93152030557394, 39.85588274896145, 21.107947155833244, 28.10438822954893, 41.59293293952942, 79.80224624276161, 81.37538462877274, 26.69045940041542, 28.276325203478336, 23.051502965390682, 19.69745524227619, 17.65093255788088, 10.515724830329418, 31.659355871379375, 27.975102066993713, 23.742993660271168, 26.171965822577477, 25.867271572351456, 34.96396444737911, 39.13077525794506, 55.95050051808357, 52.631587609648705, 61.81610897183418, 61.47813230752945, 58.388240709900856, 51.080054864287376, 42.745597288012505, 30.398794412612915, 16.79131418466568, 10.369858257472515, 2.190132890827954, 0.10394999786512926, 0.07739769062027335, 0.03715690734679811, 0.005467433475132566, 0.04918311729852576, 0.051920896366937086, 0.04155552385782357, 0.034096802410203964, 0.053685716120526195, 0.033327069104416296, 0.05541895006899722, 0.01787184188287938, 0.05225009081186727, 0.019891951160389, 0.06628803675994277, 0.058641874784370884, 0.039505737950094044, 0.03171341370034497, 0.09521618136204779, 0.026101198345713783, 0.04720298195024952, 0.038786541190347634, 0.04035766782180872, 0.025750618915481027, 0.030834605095151346, 0.02710749307880178, 0.09163923736196011, 0.045400234739645384, 0.037622586460202, 0.02533165243221447, 0.031090096854313742, 0.026934251691272948, 0.007985239044501213, 0.03255090879974887, 0.03559973309165798, 0.03707623589434661, 0.05682595074176788, 0.021591654876829125, 0.015121302512852708, 0.016645236901240423, 0.059695015734178014, 0.046392085423576646, 0.03140599015750922, 0.044295714906184, 0.044480947544798255, 0.026888299762504175, 0.03090845435508527, 0.02831929592503002, 0.11530168092576787, 0.08483603640343063, 0.08659497834742069, 0.07995234846021049, 0.03379446628969163, 0.03145253023831174, 0.04774938817718066, 0.055126269289758056, 0.05410432451753877, 0.10396032113931142, 0.01045719844114501, 0.03543060505762696, 0.026737463813333306, 0.04104615451069549, 0.010803612567542586, 0.07851425179978833, 0.06966563247260638, 0.03342374497151468, 0.02130084059899673, 0.05943790980381891, 0.030337447788042482, 0.03259230208641384, 0.027069155585195404, 0.020027775317430496, 0.026929392479360104, 0.016341627997462638, 0.014071001205593348, 0.04212892570649274, 0.0033200521329490584, 0.11315206502331421, 0.06149142129288521, 0.016759787395130843, 0.020709159653051756, 0.03803500163485296, 0.11648858286207542, 0.024318383366335183, 0.053687152176280506, 0.060992453145445324, 0.03963516479416285, 0.0027933309092986747, 0.03639393500634469, 0.003599342944653472, 0.09791765827685595, 0.035613737418316305, 0.059914914090768434, 0.035260731165180914, 0.009272213101212401, 0.016697359787940513, 0.10612561862217262, 2.132893237285316, 7.688642330467701, 21.867682188749313, 38.89741078019142, 48.911226242780685, 65.80338701605797, 72.61143609881401, 80.93640178442001, 77.68059968948364, 67.75463551282883, 67.63489633798599, 66.84316322207451, 34.01142776012421, 47.42539197206497, 51.5289019793272, 40.23224115371704, 33.363623321056366, 30.59997271746397, 21.52085579931736, 21.910036616027355, 24.150580689311028, 33.37260223925114, 35.00015750527382, 35.95202162861824, 20.444878935813904, 29.38378717750311, 30.685671418905258, 34.66713197529316, 32.66719289124012, 24.257615245878696, 28.969711996614933, 28.02020564675331, 24.09986101090908, 21.418660283088684, 21.123984195291996, 18.20738609880209, 21.864902637898922, 17.648565284907818, 13.728035409003496, 16.294317953288555, 14.79364262893796, 23.16255960613489, 21.49063792079687, 27.783360555768013, 31.962623298168182, 27.090129554271698, 38.19214962422848, 33.00421200692654, 38.013251423835754, 50.80123722553253, 32.51431569457054, 33.792741894721985, 51.91792510449886, 70.1243631541729, 82.8415435552597, 34.45427879691124, 33.36170442402363, 34.38715919852257, 22.918776087462902, 25.61110831797123, 19.34386521577835, 39.03333328664303, 35.7412925362587, 34.24738749861717, 36.17381952702999, 35.429735854268074, 46.61194682121277, 52.41159461438656, 65.87837979197502, 61.919828206300735, 69.57333192229271, 68.18591237068176, 65.23213326931, 61.04226529598236, 50.10137937963009, 38.83303463459015, 21.375790983438492, 13.127084355801344, 3.2566803228110075, 0.10937627739622258, 0.024554421579523478, 0.04582315872539766, 0.01010223570119706, 0.08661964733619243, 0.04053985765494872, 0.04181699732725974, 0.011525345616973937, 0.031605590775143355, 0.07629770901985466, 0.017679820448393002, 0.10896917970967479, 0.021098143370181788, 0.024197496786655392, 0.020436542836250737, 0.06989563888055272, 0.07829531081370078, 0.03388480792636983, 0.04959282363415696, 0.038266403280431405, 0.0607040360046085, 0.017562998982612044, 0.059519976493902504, 0.04467916405701544, 0.04360946208180394, 0.034075228177243844, 0.08174482063623145, 0.03517490920785349, 0.03903280805388931, 0.12473191396566108, 0.023605107089679223, 0.011105751091236016, 0.07765312300762162, 0.03474906858173199, 0.025984284111473244, 0.02257135845866287, 0.034185281256213784, 0.012024008556181798, 0.01637142337131081, 0.05430780285678338, 0.015507803746004356, 0.022610506748605985, 0.07968511592480354, 0.09398223468451761, 0.041674909443827346, 0.02557048854214372, 0.014095863152761012, 0.05301956807670649, 0.06721127589116804, 0.18827578547643498, 0.15239919419400394, 0.22086237673647702, 0.10775183487567119, 0.11639402582659386, 0.13807281997287646, 0.13040227844612673, 0.17972131638089195, 0.2031917218118906, 0.14811900589847937, 0.16025129472836852, 0.10330599921871908, 0.09925477090291679, 0.1757751835975796, 0.21910256647970527, 0.2587195672094822, 0.11754747916711494, 0.12918468128191307, 0.193547913513612, 0.1583752641454339, 0.11031053742044605, 0.18648253404535353, 0.11300224767182954, 0.20084407122340053, 0.0732643659284804, 0.25260866386815906, 0.08098725113086402, 0.11453680868726224, 0.22737543506082147, 0.14273956330725923, 0.12775141600286588, 0.13176796375773847, 0.12395611731335521, 0.20739398460136726, 0.08374057448236272, 0.12020878362818621, 0.15858840895816684, 0.09034647548105568, 0.15721334289992228, 0.09236083496944048, 0.13814133504638448, 0.1645698817446828, 0.21857964922674, 0.14311399165308103, 0.14075246290303767, 0.09452988771954551, 0.15432665561093017, 0.3080722689628601, 3.470001588575542, 11.052445080131292, 30.748293958604336, 49.148690700531006, 62.50250793993473, 77.1006292104721, 81.48095816373825, 89.66418385505676, 87.25207328796387, 75.25091126561165, 73.6154942214489, 74.50117349624634, 40.719006434082985, 56.17376133799553, 52.71731860935688, 39.98632974922657, 36.916759461164474, 34.96994152665138, 26.235933490097523, 29.98445324599743, 39.877078011631966, 54.959992468357086, 38.60177904367447, 54.506699591875076, 34.73042517900467, 38.385038673877716, 48.618615344166756, 56.07671834528446, 54.151479452848434, 37.51919813454151, 50.465228855609894, 41.23726822435856, 38.10877449810505, 38.70336279273033, 31.6908485814929, 33.190565407276154, 41.56872443854809, 32.41976156830788, 29.489619098603725, 32.819766104221344, 28.518034033477306, 36.321350410580635, 31.011887714266777, 44.1129045188427, 48.06052789092064, 40.45632652938366, 62.05788239836693, 47.25516490638256, 40.31522110104561, 54.01447020471096, 32.851627394557, 42.5400473177433, 59.25520218908787, 91.47034093737602, 91.77373945713043, 36.32268413901329, 41.85842849314213, 34.36715707182884, 33.15851792693138, 28.033611327409744, 19.637226574122906, 45.85239797830582, 40.573219656944275, 37.507677152752876, 40.224037393927574, 41.539959982037544, 50.70648550987244, 55.02494238317013, 72.98860386013985, 70.34424975514412, 79.15137156844139, 77.9376482963562, 75.20701602101326, 71.78886383771896, 59.08048376441002, 48.470932468771935, 27.86293588578701, 16.314814053475857, 4.316721316426992, 0.6203606491908431, 0.19293197547085583, 0.13472413091221824, 0.04689983317803126, 0.20251051930245012, 0.141627618286293, 0.1789033954264596, 0.16449474671389908, 0.11284727239399217, 0.13762150512775406, 0.11501197615871206, 0.2066949408617802, 0.1371188781922683, 0.09996620108722709, 0.08229931627283804, 0.15628684574039653, 0.15727443649666384, 0.245166021049954, 0.21044781839009374, 0.11483697773655877, 0.12690916744759306, 0.17292404518229887, 0.21548536838963628, 0.16079196415375918, 0.10553580417763442, 0.11505657923407853, 0.17426329519366845, 0.09709535865113139, 0.12671341857640073, 0.21916744502959773, 0.13905757572501898, 0.10953707111184485, 0.1922438116162084, 0.10985592001816258, 0.12614665523869917, 0.1567728485679254, 0.17343082814477384, 0.13636224379297346, 0.10525337245780975, 0.13760931906290352, 0.1239674944372382, 0.2904075215337798, 0.09773900848813355, 0.22180917905643582, 0.11327623375109397, 0.13815748417982832, 0.130890270229429, 0.08414020616328344, 0.16663444752339274], [0.07660034199943766, 0.0501243349572178, 0.02047367990599014, 0.08082484695478342, 0.02495134813216282, 0.03864038262690883, 0.048438279336551204, 0.037967907774145715, 0.037977006504661404, 0.09681887153419666, 0.046919347951188684, 0.0047602214726794045, 0.025542207149555907, 0.0286729459912749, 0.05795082026452292, 0.06431017609429546, 0.012704318633041112, 0.09694243170088157, 0.03811681228398811, 0.03097288019489497, 0.022254658069869038, 0.021944833679299336, 0.05721016801544465, 0.041077513960772194, 0.07579278142657131, 0.06157476447697263, 0.013315746273292461, 0.036016259764437564, 0.041364190765307285, 0.04260293542756699, 0.02475384964782279, 0.08238628855906427, 0.04115388837817591, 0.03728012983629014, 0.015348786546383053, 0.019107165244349744, 0.047007414905237965, 0.026600407691148575, 0.022732308025297243, 0.05246039690973703, 0.018733228571363725, 0.050527384228189476, 0.0630715538864024, 0.08715814226889051, 0.09163610549876466, 0.027944340654357802, 0.16230147768510506, 3.2392302341759205, 11.209917180240154, 22.94307578355074, 48.969347923994064, 59.18077178299427, 67.79093876481056, 66.04773670434952, 60.77002890408039, 58.793846145272255, 54.68083284795284, 53.76833461225033, 48.266792222857475, 44.521356001496315, 41.60547226667404, 34.87436905503273, 23.200724758207798, 16.118138507008553, 21.707953959703445, 17.617330960929394, 24.670520089566708, 21.60284399986267, 27.148384228348732, 29.839973598718643, 34.13829155266285, 44.170862808823586, 35.48779673874378, 30.465678423643112, 25.594178326427937, 14.754573125392199, 10.231991205364466, 13.109430503100157, 14.031533673405647, 7.232154775410891, 11.459455490112305, 9.06700886785984, 7.865305300801992, 10.437070950865746, 9.943584781140089, 9.145215321332216, 10.553352311253548, 10.14467379078269, 11.907628141343594, 12.849620394408703, 11.468913182616234, 13.40714642778039, 19.846625737845898, 13.939064685255289, 12.632847726345062, 18.024669103324413, 21.030513010919094, 15.837092287838459, 28.580470383167267, 38.11496436595917, 19.10510502755642, 42.98688434064388, 41.702032685279846, 42.26600222289562, 38.01487013697624, 25.90408019721508, 26.395384334027767, 32.55627304315567, 30.45437403023243, 24.61408171802759, 21.423892602324486, 13.777446057647467, 12.938468176871538, 21.399503611028194, 22.66061034053564, 27.93833713978529, 34.562629982829094, 39.4035854190588, 48.505723401904106, 49.8157525062561, 54.1214382648468, 55.68989150226116, 53.83428767323494, 56.41097880899906, 47.41517052054405, 25.33310003578663, 10.514280907809734, 3.9833390805870295, 0.6944420677609742, 0.05802522427984513, 0.04515001593972556, 0.018783622253977228, 0.033207145461346954, 0.030945227772463113, 0.03380126065167133, 0.01631641909625614, 0.02646121047291672, 0.02638026257045567, 0.02281644530739868, 0.050355773710180074, 0.04927487643726636, 0.07238708800286986, 0.025443006124987733, 0.1026336727954913, 0.02963198632642161, 0.019823818292934448, 0.03618182920035906, 0.019578070932766423, 0.03489351278403774, 0.06115082745964173, 0.03260898185544647, 0.0752603349974379, 0.03642446325102355, 0.021662027174897958, 0.01763995227520354, 0.0032483395625604317, 0.025457147748966236, 0.02141439661500044, 0.07477687773643993, 0.0858140089258086, 0.040240542075480334, 0.047985803030314855, 0.01671375568548683, 0.04431091409060173, 0.014878290894557722, 0.07285781743121333, 0.07334690759307705, 0.018862046854337677, 0.06887723415275104, 0.026924538833554834, 0.10639089930918999, 0.06779271148843691, 0.0812349577608984, 0.0404078444262268, 0.038989696695352904, 0.013980981475469889, 0.008655749988975003, 0.06005980358168017, 0.006575673787665437, 0.05608850085991435, 0.03334893277497031, 0.017484748786955606, 0.017142781980510335, 0.026415900501888245, 0.07254072741488926, 0.09238763392204419, 0.05375809036195278, 0.019252772763138637, 0.028681844341917895, 0.04710382730991114, 0.042868754171649925, 0.10415136479423381, 0.03216660988982767, 0.06054310499166604, 0.07775662292260677, 0.04130569468543399, 0.032281535168294795, 0.06313896315987222, 0.06053181321476586, 0.04369644550024532, 0.06592582416487858, 0.03767266287468374, 0.05222701744060032, 0.052990320036769845, 0.03710865290486254, 0.05354201035515871, 0.0399770907824859, 0.02776360543066403, 0.053640467376681045, 0.026887724598054774, 0.03561551857274026, 0.04849183271289803, 0.041518138168612495, 0.03356071945745498, 0.03092228613240877, 0.0419133021205198, 0.028876073665742297, 0.04768047234392725, 0.07788114045979455, 0.0888927120831795, 0.025113290321314707, 0.04822993250854779, 0.34037448407616466, 4.564366852864623, 14.74030964076519, 26.927669271826744, 58.96496616303921, 69.4585932791233, 78.12157362699509, 76.53472557663918, 68.49142357707024, 69.55988064408302, 65.80081075429916, 62.74238146841526, 56.546585932374, 56.834895461797714, 44.36148717999458, 44.693528562784195, 34.1415935754776, 19.42191492766142, 24.626355059444904, 21.033763736486435, 22.916275821626186, 27.835626751184464, 33.286240473389626, 41.72327734529972, 34.29538652300835, 34.521273002028465, 34.29816797375679, 21.396397277712822, 23.16493257880211, 14.56162802875042, 9.931472931057215, 10.879825092852116, 10.917960796505213, 7.017083941027522, 9.698052406311035, 8.557057231664658, 7.762771127745509, 8.83648568764329, 7.870425526052713, 6.2999374978244305, 7.339195981621742, 5.833332035690546, 9.249940551817417, 10.308684390038252, 11.917348969727755, 14.093026723712683, 15.985656715929508, 14.191430043429136, 17.675040364265442, 18.23933858424425, 18.807052820920944, 14.557419754564762, 23.141012862324715, 31.689015179872513, 23.516126833856106, 46.4122599363327, 49.26589161157608, 38.64887751638889, 37.056200578808784, 28.29359907656908, 33.70716668665409, 29.689885452389717, 24.88942824304104, 37.740312069654465, 33.5487911850214, 23.87549065053463, 23.794423900544643, 34.858223721385, 31.344223581254482, 39.30541768670082, 45.739787220954895, 53.40204946696758, 58.446996957063675, 60.596530213952065, 62.70815670490265, 64.9353539943695, 63.328595012426376, 66.45328134298325, 56.61276698112488, 31.4534867182374, 14.251663461327553, 5.078823147341609, 1.0710968566127121, 0.15906509041087702, 0.048574485699646175, 0.02602051019493956, 0.044281213340582326, 0.03738097657333128, 0.01675061630521668, 0.0615474831283791, 0.06098123558331281, 0.028255035213078372, 0.017329057336610276, 0.014656655912403949, 0.051846061905962415, 0.032924120023380965, 0.02197214100306155, 0.03972987396991812, 0.02225088424893329, 0.012772997906722594, 0.04552613267151173, 0.0668434081308078, 0.07035719536361285, 0.05454724196169991, 0.027926658985961694, 0.02730784697632771, 0.03428542666370049, 0.025160374025290366, 0.021514571708394215, 0.02336018907953985, 0.016798306714918, 0.038515267660841346, 0.025230319588445127, 0.03473411801678594, 0.07339786345255561, 0.08912162753404118, 0.01677203839790309, 0.04803554176760372, 0.07479555759346113, 0.05875550501514226, 0.035971389515907504, 0.0601281850686064, 0.03365624128491618, 0.03986596901086159, 0.013339312245079782, 0.058833404546021484, 0.046828553604427725, 0.011824359698948683, 0.019163939541613217, 0.07936130205052905, 0.16101753251859918, 0.1205164409475401, 0.08790929961833172, 0.18859349889680743, 0.12479162716772407, 0.08265447104349732, 0.15111964254174381, 0.08026244002394378, 0.1284205511910841, 0.1880938999238424, 0.12490768422139809, 0.11386494981707074, 0.10806321035488509, 0.07806401306879707, 0.16394612146541476, 0.2234579046489671, 0.11907467065611854, 0.227903651248198, 0.22799159574788064, 0.17314522003289312, 0.1425074491999112, 0.13004962471313775, 0.15968120656907558, 0.08960778621258214, 0.13743941177381203, 0.12965717702172697, 0.08557750130421482, 0.11380185242160223, 0.11922607620363124, 0.08536356981494464, 0.1459479716140777, 0.09906265113386326, 0.141392357472796, 0.07211434131022543, 0.16754138167016208, 0.09605342784198001, 0.14577781199477613, 0.08041475841309875, 0.13542025058995932, 0.14934834383893758, 0.06857134314486757, 0.1080885918054264, 0.26030141045339406, 0.16331992694176733, 0.11741293521481566, 0.16000697971321642, 0.6472030619625002, 5.573766063898802, 21.123590916395187, 35.436374098062515, 68.6205330491066, 79.90658864378929, 87.25578188896179, 84.1694051027298, 79.06479701399803, 76.73630475997925, 71.05260774493217, 70.00919133424759, 64.2125415802002, 58.74694146215916, 53.61814387142658, 49.33550767600536, 36.00916676223278, 27.63660103082657, 33.07414345443249, 26.847347281873226, 38.539006412029266, 31.704607643187046, 38.615564703941345, 44.84140522778034, 47.359032332897186, 60.40804132819176, 47.151890248060226, 42.718474343419075, 33.91579069197178, 22.259006090462208, 15.359262228012085, 18.545408360660076, 18.018249347805977, 10.812113676220179, 15.28241515159607, 12.502088192850351, 11.878166422247887, 15.067324843257666, 12.665936350822449, 12.289081122726202, 14.413933753967285, 13.612250871956348, 16.120055504143238, 17.81249038875103, 16.49113029241562, 19.058540426194668, 27.252111062407494, 21.081603169441223, 20.789043568074703, 26.824337616562843, 29.70150712877512, 24.80405632406473, 41.270862221717834, 48.77010941505432, 32.086340859532356, 55.58576948940754, 55.866654217243195, 55.59877619147301, 51.479793414473534, 38.34487862884998, 41.94637477397919, 45.86046114563942, 42.617783546447754, 38.6856709420681, 32.97333486378193, 25.717135928571224, 25.648336820304394, 37.499564588069916, 36.19651950895786, 42.3603131622076, 49.119671657681465, 54.49998535215855, 66.06570973992348, 69.12389203906059, 71.10638245940208, 75.16157045960426, 74.20288950204849, 77.60537892580032, 69.24624547362328, 42.17231065034866, 20.490387193858624, 8.210042752325535, 2.2388807125389576, 0.3846346872160211, 0.15148871258134022, 0.11652718938421458, 0.18604307872010395, 0.11542086242116056, 0.11842581836390309, 0.17278061772231013, 0.09476188308326527, 0.11155937158036977, 0.14088400115724653, 0.22614600806264207, 0.14052472746698186, 0.163947130786255, 0.11045728970202617, 0.2109980912064202, 0.11395020032068714, 0.13005829299800098, 0.12682840693742037, 0.2300995177938603, 0.16841897129779682, 0.12238155453815125, 0.12619464250747114, 0.16232910042162985, 0.2539070957573131, 0.13211001962190494, 0.09841580264037475, 0.12415748424245976, 0.14992285519838333, 0.10711568073020317, 0.10036553590907715, 0.20441317814402282, 0.15602461528033018, 0.2583692438201979, 0.08931869742809795, 0.2027719482430257, 0.21209422848187387, 0.1736868394073099, 0.1355764429899864, 0.182884928653948, 0.21573139034444466, 0.09633204492274672, 0.20632780040614307, 0.12482870486564934, 0.13565714412834495, 0.11896383090061136, 0.0931608107930515, 0.1481475934269838], [0.04268368851626292, 0.0375780575996032, 0.005469024454214377, 0.05025642611144576, 0.028577602279256098, 0.061884741007816046, 0.02809405039442936, 0.014040728074178332, 0.015889708301983774, 0.06442090452765115, 0.06528237470774911, 0.03046080015337793, 0.02857356499589514, 0.07426665863022208, 0.027238554503128398, 0.05833183146023657, 0.019685455990838818, 0.02349234146095114, 0.033281189535045996, 0.038655900934827514, 0.037361075883382, 0.026924377416435163, 0.04124073821003549, 0.027360925378161483, 0.03454545665590558, 0.004386024120321963, 0.020052238360221963, 0.06853505212347955, 0.017662231548456475, 0.1338582078460604, 0.08314244798384607, 0.02068063706246903, 0.023184359451988712, 0.025776618203963153, 0.031425007691723295, 0.05428930853668135, 0.02373719082243042, 0.041832860733848065, 0.0372420057101408, 0.01569658848893596, 0.04570529083139263, 0.02075989657896571, 0.03636700246715918, 0.06443968086387031, 0.019536289873940405, 0.4595180111937225, 4.006351595744491, 20.64415544271469, 36.27114750444889, 45.07370576262474, 62.304682955145836, 70.34462973475456, 67.4555915594101, 68.30252051353455, 58.67192968726158, 57.09151089191437, 49.02301624417305, 29.373957104980946, 27.00028907507658, 23.340979032218456, 32.56981551647186, 23.93934242427349, 25.680526793003082, 29.77509967982769, 29.437009021639824, 38.14312845468521, 25.29254101216793, 34.63905528187752, 32.74293042719364, 28.817017190158367, 32.23736755549908, 27.20594923943281, 14.388653710484505, 14.667979571968317, 10.90947775170207, 9.814218822866678, 6.772085437551141, 3.3685209089890122, 1.784521162044257, 1.424474569503218, 1.0198607621714473, 1.2761580781079829, 1.7046914831735194, 0.9487705549690872, 0.6127447891049087, 0.8493323251605034, 1.275001633912325, 1.9019893649965525, 1.046459216158837, 3.8149062311276793, 5.589398425072432, 4.865754805505276, 6.926466403529048, 7.965931026265025, 5.703247915953398, 6.882915990427136, 14.66188469901681, 21.556146405637264, 18.237282894551754, 22.18436859548092, 19.88278079777956, 22.937928959727287, 26.534738056361675, 34.3575169891119, 30.779034309089184, 44.66609783470631, 28.688642978668213, 40.3227598965168, 50.188132524490356, 23.684123419225216, 22.58502669632435, 23.902628794312477, 19.222606122493744, 14.923202376812696, 18.208024464547634, 24.758052192628384, 20.631861202418804, 25.003372728824615, 35.49608789384365, 36.61237299442291, 49.16654594242573, 43.77448707818985, 47.440024986863136, 45.2339431643486, 51.96484878659248, 39.246638640761375, 38.293805569410324, 18.409577049314976, 5.467380797490478, 0.6361216690856963, 0.18763557920465246, 0.05363866024708841, 0.043524857246666215, 0.03105554060311988, 0.07883143829531036, 0.028673730812442955, 0.05060545074229594, 0.07492482487577945, 0.04214393193251453, 0.09489866090007126, 0.0163167159553268, 0.019359428661118727, 0.03298875737527851, 0.060787553593399934, 0.04704730163211934, 0.0318530153890606, 0.021546361604123376, 0.04782975905982312, 0.03502226056298241, 0.05919464863836765, 0.020015277550555766, 0.006225980760063976, 0.054731101627112366, 0.05438473388494458, 0.022482447311631404, 0.04059506602061447, 0.038484579854412004, 0.01969583121535834, 0.021906351466896012, 0.0792651939264033, 0.0935350387590006, 0.013300570280989632, 0.029798208852298558, 0.12484454229706898, 0.04955483309458941, 0.025936649362847675, 0.016886653829715215, 0.009645197969803121, 0.07788990522385575, 0.06039336556568742, 0.029319482782739215, 0.009442252121516503, 0.07745220136712305, 0.05662873241817579, 0.04016427155875135, 0.03165793816151563, 0.027425631378719117, 0.01827043084631441, 0.025812283965933602, 0.02494628854037728, 0.028759250344592147, 0.06297757572610863, 0.017583860753802583, 0.03167805036355276, 0.03423715737881139, 0.004759304920298746, 0.04085889951966237, 0.03826813248451799, 0.017642852217250038, 0.03948910270992201, 0.09593490685801953, 0.07815168297383934, 0.00880812682225951, 0.02927116340288194, 0.01910555292852223, 0.037617884954670444, 0.0342422670655651, 0.005242666165941046, 0.013465925421769498, 0.015145336037676316, 0.03427592717343941, 0.018183606989623513, 0.02903999553382164, 0.009941185016941745, 0.047556804565829225, 0.11748178425477818, 0.014718260663357796, 0.02125196831912035, 0.06277427921304479, 0.020996129605919123, 0.02353117619350087, 0.06387078756233677, 0.09652685868786648, 0.0952606434293557, 0.05073426160379313, 0.01709419728285866, 0.027937472077610437, 0.01709283173113363, 0.032390716223744676, 0.009915708014887059, 0.04555766281555407, 0.7699737616349012, 5.86463950574398, 23.23332890868187, 43.10253493487835, 58.04361820220947, 73.55422630906105, 79.97538015246391, 76.96426972746849, 76.30383476614952, 68.37124362587929, 65.20387798547745, 59.99188765883446, 43.52924443781376, 38.61969128251076, 30.632037296891212, 46.39409311115742, 32.705795019865036, 31.497351564466953, 25.370298139750957, 28.97039595991373, 29.2250943928957, 33.66567671298981, 36.595688089728355, 31.9114438444376, 25.677844136953354, 26.195925436913967, 24.645270444452763, 14.894446469843388, 11.572029199451208, 8.44088701531291, 6.414775885641575, 4.638767335563898, 2.0993070770055056, 1.5020437259227037, 1.474286571610719, 1.1928310431540012, 1.0511640761978924, 1.7842861684039235, 1.1573690897785127, 1.2366994516924024, 1.0224372614175081, 1.4208547887392342, 1.5474217222072184, 1.573148479219526, 2.628177423030138, 3.6124193714931607, 4.460251489654183, 5.05848616361618, 4.720092946663499, 4.650119226425886, 5.88455518707633, 9.25379354506731, 13.649916350841522, 15.949879735708237, 15.423680171370506, 18.040592148900032, 22.739173024892807, 28.09997096657753, 29.932511933147907, 27.818890549242496, 35.481272488832474, 28.676742017269135, 35.1117043197155, 49.706933945417404, 30.914960615336895, 31.46343268454075, 29.606945402920246, 28.35926905274391, 23.10648411512375, 25.359088741242886, 39.05172049999237, 32.29988940060139, 34.79881010949612, 45.6853361427784, 47.43620999157429, 57.52956658601761, 52.70825229585171, 57.028130292892456, 55.023259073495865, 60.10427042841911, 47.0442496240139, 43.85485276579857, 22.430962063372135, 6.836854862049222, 1.0869228886440396, 0.10821576623129658, 0.009014322349685244, 0.019125320031889714, 0.020748450806422625, 0.07863427192205563, 0.05246392582193948, 0.03515045544190798, 0.017832114717748482, 0.03436223152675666, 0.08306063362397254, 0.05867442538146861, 0.05060287548985798, 0.056426975861540996, 0.10414878212031908, 0.057634086479083635, 0.0252437153540086, 0.05929497958277352, 0.010460007470101118, 0.033312827290501446, 0.04963148581737187, 0.04579910571919754, 0.039035090157995, 0.0545700184738962, 0.04023394809337333, 0.01022627177007962, 0.01692103011009749, 0.025857124528556596, 0.04860999746597372, 0.02204249660280766, 0.033348999568261206, 0.08924939567805268, 0.03635797052993439, 0.07985946867847815, 0.014471029007836478, 0.059681864877347834, 0.06451745051890612, 0.025050435979210306, 0.060155355095048435, 0.08045182868954726, 0.010658352002792526, 0.04480173716729041, 0.05061421179561876, 0.09561487793689594, 0.054297305177897215, 0.04753739740408491, 0.11191915735253133, 0.14291934116045013, 0.08351562210009433, 0.09866128282737918, 0.2750253531849012, 0.07865933424909599, 0.2101621063775383, 0.12188259381218813, 0.1241074338031467, 0.19295529375085607, 0.17184246884426102, 0.11003692241501994, 0.15743938623927534, 0.08577596643590368, 0.15052083326736465, 0.14650734316091985, 0.16377130115870386, 0.12187244865344837, 0.16793307237094268, 0.12616845953743905, 0.15309243433875963, 0.09317296717199497, 0.1404135685879737, 0.10608511962345801, 0.13378719915635884, 0.18405740323942155, 0.1085327152395621, 0.10538488844758831, 0.15962512989062816, 0.13312793453224003, 0.24781701707979664, 0.18640064547071233, 0.12074769416358322, 0.18824048893293366, 0.1445532831712626, 0.10617920168442652, 0.15557043574517593, 0.27373781602364033, 0.21098823548527434, 0.127295826387126, 0.09605333878425881, 0.13728041405556723, 0.10616982835927047, 0.17344950058031827, 0.13917017437051982, 0.17487057979451492, 1.1348036443814635, 8.998665735125542, 31.592946834862232, 55.003553330898285, 73.48938658833504, 87.05309316515923, 90.75727120041847, 86.60274893045425, 85.89407175779343, 77.03640505671501, 73.52809891104698, 65.1140584051609, 41.58097118139267, 38.53495202958584, 35.057488828897476, 46.986070945858955, 34.19819913804531, 35.87130255997181, 43.55791009962559, 44.32763859629631, 54.46861803531647, 37.79180310666561, 47.87699393928051, 47.93160080909729, 40.555486008524895, 42.39790454506874, 33.671239614486694, 20.683679021894932, 18.92866149544716, 14.964735098183155, 13.355120569467545, 8.774145282804966, 4.579656282439828, 2.4929410172626376, 2.5585765577852726, 1.7929299920797348, 2.058458556421101, 3.131160708144307, 1.725719436071813, 1.7597248801030219, 1.7553666327148676, 2.279200586490333, 2.4826882174238563, 2.0080483239144087, 4.82737828977406, 7.477788319811225, 6.625039502978325, 8.421281967312098, 10.348297264426947, 8.126142304390669, 9.496669862419367, 18.14155463129282, 25.816910974681377, 22.683234326541424, 28.733465373516083, 27.345762737095356, 30.4123729839921, 35.35119406878948, 45.25011129677296, 43.21939006447792, 56.991675049066544, 43.65192465484142, 56.551229283213615, 65.59768125414848, 35.101152285933495, 33.86192098259926, 34.05331291258335, 29.973621927201748, 23.951059095561504, 29.06278420239687, 36.17534704506397, 32.348370999097824, 36.736576929688454, 49.55126769840717, 51.00193865597248, 66.44563615322113, 62.11456775665283, 65.79154685139656, 65.3552694618702, 74.55235674977303, 59.04150165617466, 53.66346783936024, 29.93460562080145, 10.890737157315016, 2.697987277060747, 0.3277835628250614, 0.1648386282613501, 0.12345600625849329, 0.07252805153257214, 0.21546285162912682, 0.15173820778727531, 0.1762768457410857, 0.1604184412281029, 0.1400389918126166, 0.1736428152071312, 0.18379719142103568, 0.23160576587542892, 0.16176159493625164, 0.19177355716237798, 0.11045086270314641, 0.126021514297463, 0.13545811496442184, 0.08100849139736965, 0.13136430963641033, 0.09306786421802826, 0.1443866710178554, 0.15972410270478576, 0.13383021403569728, 0.12138422680436634, 0.1350856458884664, 0.1290197018533945, 0.13467918644892052, 0.10423806990729645, 0.12043071546941064, 0.19511632388457656, 0.18886764824856073, 0.15758425346575677, 0.1778515346813947, 0.19505772390402853, 0.1868753824965097, 0.16319549846230075, 0.1492327914456837, 0.16826114617288113, 0.17952243564650416, 0.2588894299697131, 0.19385525170946494, 0.11201660876395181, 0.16253633773885667, 0.14576380024664104, 0.11445553609519266, 0.2228005399229005], [0.0672329094959423, 0.025457964111410547, 0.04540538153378293, 0.029670568728761282, 0.08476882008835673, 0.031105077105166856, 0.03951483296987135, 0.09707196615636349, 0.04762674085213803, 0.015678155396017246, 0.02494263902917737, 0.0428021427069325, 0.01963600854651304, 0.08993237934191711, 0.010578022865956882, 0.04999075950763654, 0.04897292994428426, 0.022260554433159996, 0.034183526076958515, 0.02201320960011799, 0.11069373795180582, 0.022077735629864037, 0.05574695336690638, 0.02096332853398053, 0.03942152645322494, 0.07506460096919909, 0.03063444972212892, 0.06458077798015438, 0.042329105199314654, 0.07664124917937443, 0.007344948817262775, 0.02283846482896479, 0.0921801665390376, 0.07266862914548256, 0.019016333790204953, 0.09277977733290754, 0.055824737864895724, 0.014124362551228842, 0.060039138479623944, 0.025078962280531414, 0.03408381111512426, 0.03226828412152827, 0.05365465352952015, 0.023985281513887458, 1.0390244401060045, 9.846817273646593, 24.32970117777586, 48.477509915828705, 71.34628638625145, 75.83542630076408, 78.09909403324127, 73.81094053387642, 60.007664412260056, 52.96383798122406, 45.34935437142849, 38.99092756211758, 41.523297876119614, 26.282389797270298, 28.050866201519966, 37.87939980626106, 23.070824928581715, 21.12995557487011, 32.01087310910225, 36.23196020722389, 28.046561032533646, 28.869469575583935, 28.022669814527035, 29.317266047000885, 24.703139439225197, 26.81777536869049, 18.143576122820377, 9.120003674179316, 7.075514830648899, 4.346687458455563, 1.7134374263696373, 1.2206166959367692, 0.4257187951589003, 0.4642892786068842, 0.15890374750597402, 0.24184422742109746, 0.3123061917722225, 0.2545559109421447, 0.14681573520647362, 0.14040672598639503, 0.2921208139741793, 0.0923683306609746, 0.14181616832502186, 0.07925878919195384, 0.1959205893217586, 0.40828242141287774, 0.5108451819978654, 0.5127196689136326, 1.1216266639530659, 0.8218397910241038, 1.9542828714475036, 2.111689900048077, 1.743199685588479, 0.922699203947559, 2.3435983434319496, 5.255264779552817, 4.939119843766093, 6.4962672628462315, 11.358690597116947, 16.980973407626152, 20.135575532913208, 29.0544056519866, 29.121924228966236, 21.446548886597157, 30.17439365386963, 40.925008580088615, 36.77218481898308, 36.22808061540127, 29.50096718966961, 28.743417039513588, 30.118240267038345, 28.181003518402576, 26.682747714221478, 35.00120624899864, 34.40364271402359, 22.39129789173603, 36.4332240074873, 39.73421707749367, 40.025832429528236, 43.41118477284908, 48.01960788667202, 55.07764175534248, 51.13305442035198, 36.504584178328514, 17.84633707255125, 5.539880907163024, 0.9888767497614026, 0.177563002507668, 0.037846540653845295, 0.04713309019280132, 0.03746899528778158, 0.020354878761281725, 0.03096916203503497, 0.040234289481304586, 0.039653295461903326, 0.016422323569713626, 0.04929758986691013, 0.029639769600180443, 0.026070523526868783, 0.022615696216234937, 0.05606900835118722, 0.036747471895068884, 0.01898940867249621, 0.05706602067220956, 0.02894867426221026, 0.03960368660045788, 0.024095260378089733, 0.019486233868519776, 0.032756758300820366, 0.05672142295225058, 0.075970436737407, 0.05551204507355578, 0.07791294890921563, 0.017781294300220907, 0.07585872124764137, 0.06097185112594161, 0.03254317933169659, 0.07068357706884854, 0.012023298877466004, 0.046010332080186345, 0.0327021065459121, 0.017155704626929946, 0.04134456466999836, 0.04880638458416797, 0.038005538372090086, 0.02209296635555802, 0.03245408821385354, 0.02736078437010292, 0.039577967472723685, 0.05026424092648085, 0.02901367155573098, 0.017250588207389228, 0.03885219899530057, 0.03750481133465655, 0.017676072602625936, 0.02974376860947814, 0.07104354095645249, 0.03621599025791511, 0.02899697508837562, 0.02396426203631563, 0.04687054803071078, 0.027383876295061782, 0.035868854392901994, 0.028388879691192415, 0.058315218484494835, 0.07130689948098734, 0.03198387086740695, 0.023743395177007187, 0.03321193602459971, 0.06436803392716683, 0.057251668913522735, 0.04038407714688219, 0.03848338128591422, 0.04090356938831974, 0.05633981432765722, 0.026789620096678846, 0.013316170225152746, 0.0690402023610659, 0.055324211207334884, 0.04429634573170915, 0.03259995733969845, 0.07408890684018843, 0.03760545398108661, 0.03347199199197348, 0.08117321107420139, 0.08769242922426201, 0.05509042355697602, 0.017108457650465425, 0.034495517538744025, 0.023897155188024044, 0.06016187115164939, 0.05459957079438027, 0.06569353936356492, 0.02767117093753768, 0.06407228065654635, 0.04573350728605874, 1.719762661959976, 14.541594553738832, 28.594275042414665, 58.7667004019022, 83.66342425346375, 91.14819422364235, 89.97670948505402, 86.05538830161095, 69.98709931969643, 66.35864362120628, 58.252553790807724, 49.15319725871086, 47.66367718577385, 28.039330020546913, 31.084330826997757, 45.65267689526081, 31.24750167131424, 28.368008583784103, 25.814173221588135, 38.097546100616455, 38.48428554832935, 36.38462841510773, 27.49622706323862, 24.71018996089697, 21.61390520632267, 20.199206918478012, 13.777416609227657, 7.322123972699046, 6.4307245798408985, 3.0940483370795846, 1.9433355401270092, 0.9368080843705684, 0.31022390350699425, 0.297795690712519, 0.17067364562535658, 0.09912771522067487, 0.0850442385126371, 0.1390004897257313, 0.025744824597495608, 0.08290555444546044, 0.1015204809664283, 0.0744307400600519, 0.12325381554546766, 0.14909372781403363, 0.10740383440861478, 0.5223233567085117, 0.5407325376290828, 0.6320570153184235, 0.7880304520949721, 0.8692486595828086, 1.2985414895229042, 1.0378890135325491, 1.3741906802169979, 1.3063839124515653, 2.135856128297746, 4.439701242372394, 4.536030348390341, 6.4043734688311815, 11.095763705670834, 13.082251511514187, 17.6840952783823, 21.577062383294106, 24.021708704531193, 22.887425869703293, 30.056491680443287, 34.622347578406334, 28.67975525557995, 33.03847096860409, 22.970485612750053, 23.090777657926083, 25.860559232532978, 22.53710176795721, 24.453927911818027, 36.284104809165, 47.09344178438187, 30.65150935202837, 46.71479590237141, 48.67297142744064, 50.03789618611336, 53.93176384270191, 60.01340590417385, 62.934692949056625, 59.734896048903465, 42.75703467428684, 19.13527350872755, 7.03748932108283, 1.2835620995610952, 0.31998169084545225, 0.05187227456190158, 0.01943376217241166, 0.04576887433358934, 0.010305126816092525, 0.04631595220416784, 0.06548645789735019, 0.032012796073104255, 0.03517378856486175, 0.013353544782148674, 0.02245658717583865, 0.0496326732536545, 0.05291548928653356, 0.03406976225960534, 0.03443399349635001, 0.02707503896090202, 0.01356527951429598, 0.08644135377835482, 0.062467720272252336, 0.072981607663678, 0.05350128129066434, 0.05179570347536355, 0.020849813336099032, 0.05738650601415429, 0.059578539367066696, 0.08301288384245709, 0.01744182110996917, 0.04743262099509593, 0.0760449557856191, 0.015210352812573547, 0.07042870871373452, 0.04277215994079597, 0.014304003107099561, 0.07979825633810833, 0.0685232000250835, 0.053480278511415236, 0.008304946986754658, 0.023989834589883685, 0.028488240277511068, 0.011174647443112917, 0.09375268840813078, 0.05545618732867297, 0.08064606357947923, 0.04273150880180765, 0.01882362957985606, 0.19033120799576864, 0.060760001360904425, 0.10522465134272352, 0.12809446634491906, 0.258307111216709, 0.14440737693803385, 0.18989806092577055, 0.1930024052853696, 0.18947886623209342, 0.16760082769906148, 0.11413863903726451, 0.15465027652680874, 0.11852180774440058, 0.16662908921716735, 0.15281703817890957, 0.13922476675361395, 0.16824109334265813, 0.16930395271629095, 0.14966445422032848, 0.12293553809286095, 0.2379241440212354, 0.1869697985239327, 0.13618571654660627, 0.12386073649395257, 0.15003867476480082, 0.1981434551998973, 0.11801705084508285, 0.15859811624977738, 0.0806869039661251, 0.12773689959431067, 0.12895013293018565, 0.08344416070031002, 0.21035880519775674, 0.19852055527735502, 0.10992760406224988, 0.21758977265562862, 0.08520623450749554, 0.09087550060939975, 0.15563377062790096, 0.15598489553667605, 0.1617652759887278, 0.14283371216151863, 0.18199469282990322, 0.265459485235624, 2.56455244962126, 19.49347648769617, 37.89063960313797, 67.08558261394501, 94.58228275179863, 103.99116307497025, 99.86864268779755, 91.16943508386612, 76.42502546310425, 68.75949159264565, 61.28911904990673, 51.56252637505531, 54.97589461505413, 36.21101953089237, 40.63288405537605, 52.575145438313484, 35.2533645182848, 30.694467946887016, 48.57144087553024, 50.09881071746349, 39.89521823823452, 40.70655070245266, 36.91871255636215, 41.186449751257896, 34.59555521607399, 34.459119737148285, 22.73548722267151, 12.64522461220622, 9.72240624949336, 5.8334241807460785, 2.8291241778060794, 1.7567622265778482, 0.6128122354857624, 0.7481359771918505, 0.29292349121533334, 0.36245349620003253, 0.3381398180499673, 0.47469611861743033, 0.24717403517570347, 0.322504517971538, 0.48516550683416426, 0.35674750863108784, 0.36646789172664285, 0.4804366605821997, 0.3355363936861977, 0.8548205369152129, 0.8044322719797492, 0.7368441706057638, 1.5478495554998517, 1.2507801898755133, 3.0392773635685444, 2.5648842193186283, 2.705910801887512, 1.523992179427296, 3.334816717542708, 6.589879989624023, 7.137742666527629, 9.07040873542428, 14.74358506500721, 21.81257374584675, 25.928328596055508, 38.01674343645573, 38.792642802000046, 34.867297634482384, 41.777287647128105, 53.19295048713684, 50.63161812722683, 49.80528026819229, 43.88361722230911, 43.70463162660599, 42.275471314787865, 39.06406983733177, 36.02500431239605, 46.24411515891552, 47.774027064442635, 34.40650016069412, 53.17473046481609, 53.66301566362381, 57.023635134100914, 61.124728471040726, 68.51526349782944, 75.52509695291519, 72.02027142047882, 53.04220877587795, 28.41214131563902, 10.957775060087442, 3.386003295890987, 0.6287299375981092, 0.17879778781207278, 0.15617062541423365, 0.1374539133394137, 0.1211796241113916, 0.19574818841647357, 0.11529276031069458, 0.1469393918523565, 0.14429419941734523, 0.12090424279449508, 0.14156584191368893, 0.09486683018621989, 0.08351777432835661, 0.25011884747073054, 0.1251769353984855, 0.18584608304081485, 0.11212997924303636, 0.16980607499135658, 0.18237462791148573, 0.20054836990311742, 0.11622319827438332, 0.13436485722195357, 0.13565034605562687, 0.14094715792452917, 0.14669896569103003, 0.21433984860777855, 0.1772888976847753, 0.28522222477477044, 0.2006167365470901, 0.12669327668845654, 0.1572489066165872, 0.11817867576610297, 0.09439731788006611, 0.13283480104291812, 0.20085959695279598, 0.13445425633108243, 0.13558033184381202, 0.1479930040659383, 0.10222281242022291, 0.07296726937056519, 0.20437369588762522, 0.1718407025327906, 0.24474739038851112, 0.11512568802572787, 0.15120077412575483], [0.01404666896632989, 0.02234406831121305, 0.09118234156630933, 0.10229549836367369, 0.022085556011006702, 0.0066594956570043, 0.08658970167743973, 0.04189295243122615, 0.02260865509015275, 0.05875755334272981, 0.04215668574033771, 0.029995718468853738, 0.0319001343450509, 0.05375447610276751, 0.02975856332341209, 0.01355684964437387, 0.04138173142564483, 0.09118893925915472, 0.01768962978530908, 0.04858260850596707, 0.01573933805048, 0.056988737123901956, 0.054641301758238114, 0.06284159942879342, 0.012463805269362638, 0.022271252491918858, 0.05162838628166355, 0.024303373429575004, 0.08330117852892727, 0.054760605707997456, 0.03824451363470871, 0.015015069639048306, 0.054293163993861526, 0.015712776585132815, 0.021943236206425354, 0.016751089424360543, 0.0812099251197651, 0.04930340459395666, 0.1367516041500494, 0.017318797144980635, 0.04117956668778788, 0.003126856481685536, 0.3375519480323419, 1.2794623570516706, 12.885408774018288, 37.164737954735756, 58.10294821858406, 72.9206483066082, 79.11700621247292, 73.8098917901516, 64.63233545422554, 47.77716189622879, 46.14630080759525, 34.3257012963295, 35.52351862192154, 36.45452566444874, 33.78297261893749, 46.750536784529686, 33.44043619930744, 29.93186216801405, 37.07565173506737, 43.773677721619606, 47.21112906932831, 37.41150811314583, 33.50242227315903, 23.784139752388, 24.485540315508842, 20.090576447546482, 12.687215209007263, 5.455242823809385, 4.33949681930244, 2.9336107335984707, 0.4895973752718419, 0.4589595302240923, 0.5371710599865764, 0.1572976805618964, 0.13766115065664053, 0.12849571590777487, 0.011549192677193787, 0.0717783636355307, 0.06582181216799654, 0.041543304396327585, 0.05042699762270786, 0.07450565244653262, 0.14809303072979674, 0.037864452388021164, 0.02826236577675445, 0.06946098525077105, 0.06893789730384015, 0.06396810538717546, 0.07587196116219275, 0.15216350293485448, 0.029751397887594067, 0.04255281819496304, 0.07332634268095717, 0.06424710838473402, 0.11540820138179697, 0.2757187862880528, 0.5092090729158372, 0.5523871653713286, 1.1606820370070636, 2.2879498545080423, 2.3286126600578427, 3.2365986378863454, 5.22035320289433, 10.029174238443375, 10.641171298921108, 19.10259336233139, 30.775392204523087, 43.67988735437393, 48.82170684635639, 48.96682485938072, 72.07312658429146, 81.34873285889626, 88.85830029845238, 112.4985721707344, 92.8491273522377, 59.22143720090389, 31.39013461768627, 26.863904893398285, 24.95807345956564, 23.137437254190445, 32.1104733645916, 39.159178733825684, 46.371966898441315, 55.4177463054657, 53.571410179138184, 47.819183841347694, 33.56051355600357, 17.003775984048843, 6.438676603138447, 1.5038658468984067, 0.1208611908077728, 0.018540296150604263, 0.04281433248252142, 0.04018948231532704, 0.0210806342511205, 0.06784943383536302, 0.038317540966090746, 0.06854054401628673, 0.04729081512778066, 0.08620155102107674, 0.05965655764157418, 0.05900269956327975, 0.08265945085440762, 0.03831993439234793, 0.051758455083472654, 0.05127136129885912, 0.0361195630102884, 0.07009561057202518, 0.05368521517084446, 0.023336267804552335, 0.02551860499806935, 0.006085827099013841, 0.018112334837496746, 0.006427033667932847, 0.02358149937208509, 0.058270003137295134, 0.012509896350820782, 0.03610051207942888, 0.0943181752518285, 0.040990986963151954, 0.06654070093645714, 0.03228227360523306, 0.04112392045499291, 0.02553087269916432, 0.07163639820646495, 0.04020061081973836, 0.027272611660009716, 0.021939026373729575, 0.06725943385390565, 0.046239295770647004, 0.006405592557712225, 0.007300103616216802, 0.07882945676101372, 0.056046302343020216, 0.011449127978266915, 0.017116018279921263, 0.02027663042099448, 0.06473579036537558, 0.011540046634763712, 0.04482835058297496, 0.045682848285650834, 0.023634891331312247, 0.05146705450897571, 0.1041197418817319, 0.01012067157716956, 0.0371894653653726, 0.022206017711141612, 0.015765233438287396, 0.026811147945409175, 0.04754268149554264, 0.040841733643901534, 0.027368502705940045, 0.0656375962716993, 0.07933904504170641, 0.05368508158426266, 0.04553017737634946, 0.00809281427791575, 0.05388199191656895, 0.016838789015309885, 0.09519624727545306, 0.01559426116727991, 0.03425103554036468, 0.06096883058489766, 0.06355710400384851, 0.07523602966102771, 0.03146380346152, 0.019790315891441423, 0.03971533900767099, 0.06041682485374622, 0.0018418138643028215, 0.06477741000708193, 0.04409518289321568, 0.10398355036159046, 0.004613057762981043, 0.07676186301978305, 0.0346403550793184, 0.2981407300103456, 1.8685950944200158, 17.630141973495483, 42.8177972137928, 65.15421465039253, 80.25747701525688, 88.5087950527668, 80.01397848129272, 72.99923568964005, 57.81492367386818, 56.49721898138523, 42.7311846613884, 40.34512549638748, 46.87637843191624, 46.14570043981075, 53.37259724736214, 38.20146672427654, 32.46355041861534, 23.134794495999813, 26.248267628252506, 46.13037206232548, 45.16058810055256, 27.24570270627737, 18.198277987539768, 19.23044890165329, 12.80389554798603, 8.67939356714487, 4.550855727866292, 3.289122744463384, 2.553637297824025, 0.6453394400887191, 0.5270919820759445, 0.393003411591053, 0.1153699510905426, 0.1998744998127222, 0.05004265418392606, 0.09533079864922911, 0.05492851290910039, 0.020867580351477955, 0.04849177705182228, 0.04067887675773818, 0.10952421711408533, 0.07458760039298795, 0.16515669791260734, 0.046226556805777363, 0.06802922653150745, 0.1771444609039463, 0.2202955837128684, 0.21593785582808778, 0.15876394172664732, 0.09877151402179152, 0.16501992009580135, 0.11939911535591818, 0.12259989438462071, 0.08322015826706775, 0.2695955632952973, 0.5202623829245567, 0.46740107412915677, 1.1069347523152828, 2.011319473385811, 2.2109332121908665, 3.6191483354195952, 4.714133441448212, 8.749633748084307, 9.418717045336962, 15.311448443681002, 23.979831151664257, 29.97296266257763, 33.414601385593414, 35.010599344968796, 53.253211453557014, 70.10888278484344, 79.81721743941307, 88.89552310109138, 76.67810708284378, 57.50678300857544, 36.61635898053646, 31.572671122848988, 33.724740743637085, 34.29264687001705, 40.897182673215866, 47.20771685242653, 54.52509440481663, 64.76152092218399, 61.347734704613686, 55.33111855387688, 38.80960129201412, 18.907983005046844, 7.25408292375505, 1.798862423747778, 0.10798929986776784, 0.008731334019103087, 0.06062274856958538, 0.03666901946417056, 0.035152114141965285, 0.07496590274968185, 0.04928799760818947, 0.060952874409849755, 0.028849491791334003, 0.039653328858548775, 0.046908241711207666, 0.027371384094294626, 0.07209647039417177, 0.02006126473133918, 0.02401055535301566, 0.07810394803527743, 0.010799341507663485, 0.05547891560127027, 0.010924832185992273, 0.02526718391891336, 0.027704556450771634, 0.05958264344371855, 0.027701357794285286, 0.04247463664796669, 0.04913213175314013, 0.004385384481793153, 0.03598935320042074, 0.02523878192732809, 0.019652139126264956, 0.011474670845927903, 0.08555323307518847, 0.036478150213952176, 0.06065080175176263, 0.05276536394376308, 0.017732989763317164, 0.026699330410338007, 0.019066894456045702, 0.031611041849828325, 0.034608186688274145, 0.018248088490508962, 0.08234587861807086, 0.008877971267793328, 0.03529933397658169, 0.04280412424122915, 0.08889009230188094, 0.07936140595120378, 0.1244275295175612, 0.1737584121292457, 0.13459616980981082, 0.07602220895932987, 0.31995853583794087, 0.20618946407921612, 0.1373237109510228, 0.21696237585274503, 0.10503281358978711, 0.168434155639261, 0.1229922530183103, 0.18134059355361387, 0.1592787992558442, 0.19206933269742876, 0.11683245698804967, 0.12117528254748322, 0.16225579107413068, 0.3080066927941516, 0.1322330825496465, 0.14109857089351863, 0.1750921702478081, 0.24526540946681052, 0.1470864113071002, 0.16036132554290816, 0.13003516767639667, 0.0966572540346533, 0.13688467122847214, 0.09994343199650757, 0.22566962346900254, 0.13255517464131117, 0.18579751689685509, 0.09573662726324983, 0.16222209756961092, 0.17243066540686414, 0.1529493779526092, 0.12875245447503403, 0.2506850764621049, 0.07881352285039611, 0.14988334325607866, 0.13025828695390373, 0.6508493225555867, 3.684304626658559, 23.87573003768921, 53.044902831315994, 79.94429022073746, 93.19797143340111, 99.11489233374596, 87.4248044192791, 80.1846881210804, 63.077477887272835, 62.45496869087219, 47.30542480945587, 50.13490878045559, 50.53377337753773, 47.966498136520386, 60.88002920150757, 43.1329371035099, 42.02169433236122, 51.11168056726456, 60.28255306184292, 65.18522098660469, 51.01572811603546, 43.806184977293015, 32.33716920018196, 32.90567569434643, 25.245149955153465, 16.41259230673313, 7.36941528506577, 5.8859592117369175, 3.627270399592817, 1.0677969711832702, 0.6260828452650458, 0.47860925551503897, 0.5602944816928357, 0.289256569230929, 0.2982295799301937, 0.2621389681007713, 0.1953371721901931, 0.18930165620986372, 0.11210597076569684, 0.21402937854873016, 0.2615638036513701, 0.3075725364033133, 0.26032794965431094, 0.23500128445448354, 0.141498276789207, 0.32533839403185993, 0.3829438966931775, 0.3938189131440595, 0.4134871921269223, 0.2817045635310933, 0.24396988679654896, 0.19400249380851164, 0.23639661114430055, 0.4999857803341001, 0.3954546066233888, 0.9464884211774915, 1.2068401789292693, 1.669633376877755, 3.348502633161843, 3.364084647037089, 4.733006553724408, 6.8639687821269035, 12.818877194076777, 15.293452609330416, 24.776593297719955, 37.65687234699726, 55.411852821707726, 62.279915884137154, 64.80991512537003, 89.67646479606628, 92.58691862225533, 97.87664517760277, 119.54163864254951, 101.89042299985886, 70.83139881491661, 42.54966840147972, 39.74602684378624, 38.88658136129379, 36.8254579603672, 46.09887935221195, 56.0750388354063, 62.53724567592144, 72.58857652544975, 71.58516436815262, 67.82217308878899, 50.28868652880192, 27.71881341934204, 11.459956113249063, 2.1691858023405075, 0.35368493234273046, 0.16328109777532518, 0.18342387629672885, 0.16019146278267726, 0.11360410717315972, 0.18413149926345795, 0.131577113061212, 0.24109784950269386, 0.10438903758767992, 0.19169061473803595, 0.13241548760561273, 0.1313716865843162, 0.19890645722625777, 0.09215138605213724, 0.14719528437126428, 0.14320540940389037, 0.09228915092535317, 0.23125645180698484, 0.14006890036398545, 0.13538308383431286, 0.07372847539954819, 0.14913570368662477, 0.10356250772019848, 0.1224108471069485, 0.08716545242350549, 0.1079558883793652, 0.13246731919934973, 0.1271182601340115, 0.21104765182826668, 0.11059722906793468, 0.2468553718063049, 0.12743174331262708, 0.1827015884919092, 0.2372136415215209, 0.1430159984738566, 0.12378723418805748, 0.14171182236168534, 0.12222731398651376, 0.18197777186287567, 0.09462401430937462, 0.26721418951638043, 0.08205851161619648, 0.15615502547007054, 0.14962807414121926], [0.02944653846498113, 0.06724172621034086, 0.023014066246105358, 0.035135037323925644, 0.020013947250845376, 0.022030935797374696, 0.041148574600811116, 0.010650956501194742, 0.02295358121045865, 0.0443925874424167, 0.05120216344948858, 0.03736478291102685, 0.004383916420920286, 0.06078661106585059, 0.09493087010923773, 0.06412678398191929, 0.02546266005083453, 0.023006314513622783, 0.037935420259600505, 0.03512983115797397, 0.028464376518968493, 0.018186365923611447, 0.01686320381850237, 0.03066331184527371, 0.01759988743287977, 0.08951608644565567, 0.03608552069636062, 0.04944126594637055, 0.01473009606343112, 0.05644655742798932, 0.08879649263690226, 0.009188705716951517, 0.026608248481352348, 0.028405420307535678, 0.036260901324567385, 0.02894531047786586, 0.002624192902658251, 0.036239935652702115, 0.02771937713987427, 0.03402957125217654, 0.07851776215829886, 0.13236782688181847, 3.6138602066785097, 19.371987506747246, 48.14042240381241, 69.93781596422195, 77.93171301484108, 77.65846967697144, 66.38828203082085, 57.180228531360626, 57.77852922677994, 43.41962032020092, 35.17733059823513, 39.620534777641296, 37.798581942915916, 27.073843628168106, 22.341934740543365, 25.573287047445774, 46.72898814082146, 61.64009101688862, 58.756596744060516, 67.31721058487892, 40.757954344153404, 23.86128891259432, 24.761654399335384, 13.77860689535737, 8.448963481932878, 6.107261711731553, 4.3618538696318865, 1.870792682748288, 0.60358383692801, 0.13910419744206592, 0.276417889399454, 0.13321798673132434, 0.18343497882597148, 0.058477348065935075, 0.08586678304709494, 0.1698589455918409, 0.022678639616060536, 0.03884976846165955, 0.042926856913254596, 0.06860151886940002, 0.05851821071701124, 0.05706791685952339, 0.02372473758441629, 0.14096580067416653, 0.02862097338947933, 0.10984217544319108, 0.11982920477748848, 0.040341771018574946, 0.02289563803060446, 0.11360242249793373, 0.37772235344164073, 0.23768079379806295, 0.11494660779135302, 0.04187328180705663, 0.05158606531040277, 0.0868212962814141, 0.04109628287551459, 0.27652021672111005, 0.2036377228796482, 0.18061373411910608, 0.6565002724528313, 0.5680346069857478, 0.930125133600086, 1.9670025701634586, 4.232190577313304, 6.6458875592797995, 8.298862986266613, 18.471766412258148, 25.3125811368227, 35.24369403719902, 50.929491743445396, 62.660997435450554, 67.43435069918633, 69.7739839553833, 72.2751085460186, 54.99671749770641, 38.87493498623371, 22.646114118397236, 21.226295605301857, 23.441369645297527, 27.20567185431719, 34.87197898328304, 39.34128776192665, 48.041179329156876, 62.668946608901024, 54.73101295530796, 49.33600924909115, 35.526577457785606, 15.988654755055904, 5.934998905286193, 1.5585691365413368, 0.03659674541268032, 0.04277069048839621, 0.036469337210292, 0.06743052857927978, 0.08566755350329913, 0.018623604082677048, 0.024535908705729526, 0.031109331466723233, 0.1023643696680665, 0.08628145063994452, 0.07254397060023621, 0.043997360407956876, 0.04601727858243976, 0.04011294833617285, 0.012582714953168761, 0.06501704949187115, 0.028871702415926848, 0.05129387805936858, 0.062163291295291856, 0.0075342043601267505, 0.03703037858940661, 0.02982607464218745, 0.05283930782752577, 0.020711799843411427, 0.03532807735609822, 0.03672360813652631, 0.03984476214100141, 0.0422293679730501, 0.08880054476321675, 0.021491054903890472, 0.051742391297011636, 0.03835370582237374, 0.04793735934072174, 0.055808477409300394, 0.02462526514136698, 0.03643776995886583, 0.029108560702297837, 0.06354489567456767, 0.05079286900581792, 0.06530245722387917, 0.04316239974286873, 0.041481954758637585, 0.0848070035863202, 0.004394201196191716, 0.0540561146044638, 0.055063505860744044, 0.06323620676994324, 0.022700488443661015, 0.043313612331985496, 0.049074990092776716, 0.017971052184293512, 0.045430325117195025, 0.026707601646194234, 0.07291048765182495, 0.044339349478832446, 0.05918592469242867, 0.025882762020046357, 0.032732556865084916, 0.04906260364805348, 0.008185150436474942, 0.019468455720925704, 0.06023696536431089, 0.022440642133005895, 0.04070681861776393, 0.016066068565123715, 0.014018338406458497, 0.010132138686458347, 0.061974733835086226, 0.04702030601038132, 0.09282424682169221, 0.028808664392272476, 0.01637411922274623, 0.049540594991412945, 0.04480853152927011, 0.0304586163838394, 0.0605360545887379, 0.03292826491815504, 0.030803275330981705, 0.08180591423297301, 0.05826703825732693, 0.002267311015202722, 0.037399971843115054, 0.034750174381770194, 0.1037094826460816, 0.18792010378092527, 5.273292912170291, 22.856848910450935, 52.87539392709732, 77.99665153026581, 91.08091503381729, 90.84666520357132, 78.69489446282387, 71.69188544154167, 69.9688071012497, 52.09758706390858, 43.460392132401466, 43.965856209397316, 45.169502422213554, 34.32298444211483, 29.68606475740671, 30.227020829916, 34.644317999482155, 46.75378181040287, 60.699219703674316, 72.35312595963478, 42.86544285714626, 23.988274298608303, 16.92322600632906, 13.642288260161877, 6.7590041644871235, 3.9384053042158484, 2.819466758519411, 1.2309497664682567, 0.616468054940924, 0.15771166537888348, 0.2900214266264811, 0.11120471404865384, 0.20932195067871362, 0.09724667514092289, 0.06387887697201222, 0.21273645339533687, 0.2859044662909582, 0.0408350580255501, 0.1299903864855878, 0.15970957145327702, 0.051195766136515886, 0.07786985981510952, 0.12664079200476408, 0.25671603565569967, 0.13087379455100745, 0.2063162822742015, 0.2778888260945678, 0.3961975558195263, 0.3754756646230817, 0.36086942651309073, 0.6612079823389649, 0.6306046026293188, 0.7344666263088584, 0.327986198826693, 0.21543735143495724, 0.14078229723963886, 0.15087819221662357, 0.46173738897778094, 0.15526695671724156, 0.1888489758130163, 0.5349706811830401, 0.26084516721311957, 0.7723433501087129, 1.7981792916543782, 3.9555981941521168, 7.085793279111385, 8.23717899620533, 17.483496442437172, 21.162785813212395, 33.00280228257179, 53.972326666116714, 68.14466178417206, 78.68769764900208, 82.26660400629044, 81.29052758216858, 65.61165690422058, 45.89500889182091, 31.198698990046978, 31.278481408953667, 27.827732674777508, 33.67988035082817, 42.223668694496155, 47.84288316965103, 55.97241774201393, 71.82655781507492, 62.863260582089424, 54.49657693505287, 41.5783379226923, 17.646994069218636, 6.940306210890412, 1.6286392766050994, 0.10350015989388339, 0.0492802013468463, 0.07532620060374029, 0.044351338874548674, 0.016637078842904884, 0.007114331992852385, 0.03041391868464416, 0.050431008930900134, 0.11051045716158114, 0.10375458296039142, 0.03262132377130911, 0.035639809066196904, 0.06322989851469174, 0.06157443051051814, 0.08660547231556848, 0.006100385253375862, 0.018724424844549503, 0.02246769712655805, 0.08298829648992978, 0.06070181327231694, 0.056048354381346144, 0.010254058706777869, 0.07696878121350892, 0.0688554001681041, 0.007584614741062978, 0.03410328135942109, 0.004356870240371791, 0.05239745536528062, 0.0075846425716008525, 0.023178771079983562, 0.05181645763514098, 0.005391622162278509, 0.03338594739034306, 0.06776416848879308, 0.12129413749789819, 0.06670339455013163, 0.023332824239332695, 0.03024193338205805, 0.048091495991684496, 0.01732365635689348, 0.0473853758740006, 0.005692588556485134, 0.039172918113763444, 0.1780332569614984, 0.19159979070536792, 0.12157882534665987, 0.19649676309200004, 0.1497328357072547, 0.14703116583405063, 0.16594156360952184, 0.09603211336070672, 0.11452491948148236, 0.14055378996999934, 0.18815428105881438, 0.21780425333417952, 0.18103335925843567, 0.09867660075542517, 0.18230810179375112, 0.29214254405815154, 0.11612432936090045, 0.11421177026932128, 0.26536909164860845, 0.05593782632786315, 0.13139804766979069, 0.13347105908906087, 0.13150620827218518, 0.11961218595388345, 0.18865858524804935, 0.22721804038155824, 0.23290669138077646, 0.11105321944341995, 0.14661538501968607, 0.20275618502637371, 0.2068744515418075, 0.10585548428934999, 0.16341066191671416, 0.12465930223697796, 0.14577833149814978, 0.13264029897982255, 0.15090645320015028, 0.16464317624922842, 0.11072550929384306, 0.12049572018440813, 0.34620773512870073, 0.9836281626485288, 7.096015680581331, 29.468136951327324, 64.46321412920952, 91.7133378982544, 99.44003328680992, 96.52195706963539, 84.6810932457447, 76.05351939797401, 73.98504719138145, 57.14669533073902, 48.119101747870445, 51.05638973414898, 48.98196704685688, 39.46362219750881, 31.35168258100748, 36.15845315158367, 63.37182529270649, 78.88163924217224, 73.7178835272789, 78.61959770321846, 50.485253781080246, 33.02460551261902, 32.2357602417469, 19.016064405441284, 10.915155597031116, 7.709244349971414, 5.6787007581442595, 2.8569937823340297, 1.1551501275971532, 0.22940381371881813, 0.44730148860253394, 0.3199745959136635, 0.2670653146924451, 0.13885165943065658, 0.20977365144062787, 0.6117282249033451, 0.3429830737877637, 0.210452894680202, 0.15571588184684515, 0.31131699797697365, 0.351666112546809, 0.2599331270903349, 0.2853602939285338, 0.2936770679662004, 0.2684662223327905, 0.4549234046135098, 0.2774733124533668, 0.5184723227284849, 0.48639871878549457, 0.5160978657659143, 1.1799523467198014, 0.67305515287444, 0.8148153929505497, 0.2537604473764077, 0.16889367863768712, 0.28919790987856686, 0.20329275779658929, 0.43483634653966874, 0.37177258520387113, 0.3065483132377267, 1.130756267812103, 0.8287383802235126, 1.2508412241004407, 2.7105363411828876, 5.855081118643284, 9.243280459195375, 11.400469355285168, 24.66445181518793, 32.29217201471329, 44.251391887664795, 59.434506967663765, 72.2526441514492, 77.870764285326, 79.15216192603111, 80.81195086240768, 65.09119883179665, 52.101770639419556, 35.62365084886551, 35.330135598778725, 36.03450000286102, 41.83665566146374, 48.064494878053665, 56.14817351102829, 66.52011215686798, 81.6081753373146, 72.81621471047401, 65.92514768242836, 50.22608868777752, 26.18320371955633, 10.37755474448204, 2.6668491354212165, 0.21603641303954646, 0.11479691660497338, 0.1989013809361495, 0.1766386130475439, 0.13998255890328437, 0.08654731762362644, 0.06971010938286781, 0.1725316420197487, 0.19897776277503, 0.15953017951687798, 0.15406782418722287, 0.13012530893320218, 0.17743854434229434, 0.2406786399660632, 0.11649003005004488, 0.11710861013852991, 0.13545343943405896, 0.30513057368807495, 0.12524067104095593, 0.12131021241657436, 0.08730520625249483, 0.14738459140062332, 0.13548057235311717, 0.14749542373465374, 0.11397368187317625, 0.08196672279154882, 0.08793630637228489, 0.14345106028486043, 0.278539274004288, 0.0652157150034327, 0.22298515657894313, 0.08812071522697806, 0.1509493196499534, 0.21083815838210285, 0.1720056522754021, 0.1676523030619137, 0.1961444952758029, 0.11122448486275971, 0.16945557348662987, 0.08906238930649124, 0.1656587905017659, 0.13572914729593322, 0.1557513713487424], [0.016353138707927428, 0.0354081550904084, 0.019853379890264478, 0.043529837057576515, 0.05208676266192924, 0.09359537536511198, 0.03490001028694678, 0.07080701849190518, 0.06636764694121666, 0.0607355067768367, 0.004249851617714739, 0.08865460142260417, 0.020150641576037742, 0.05654686610796489, 0.04651002382161096, 0.011925999606319238, 0.03513933806971181, 0.040790506900520995, 0.032496509375050664, 0.010454809653310804, 0.08267544413683936, 0.04338424252637196, 0.02618347654788522, 0.048844256380107254, 0.06132850132416934, 0.03746829395822715, 0.026229307877656538, 0.0772646235418506, 0.0330169107473921, 0.0259384583478095, 0.021572166078840382, 0.025296359599451534, 0.018350078134972136, 0.023476581955037545, 0.02365361386182485, 0.02483050793671282, 0.13175156229408458, 0.004120890007470734, 0.01567483057442587, 0.0694058882072568, 0.723394020460546, 2.763567720539868, 19.14911236613989, 53.69090996682644, 67.18413412570953, 69.96269702911377, 65.75367048382759, 61.412665620446205, 54.546247869729996, 48.25756251811981, 32.77140989899635, 31.670057997107506, 38.01643565297127, 40.412366688251495, 39.10975478589535, 55.27589611709118, 59.292569383978844, 68.86249646544456, 73.28293606638908, 57.68780529499054, 30.5892800912261, 16.782612651586533, 18.728237450122833, 12.243058942258358, 6.026586340740323, 2.0380080537870526, 1.783652314916253, 0.9349481435492635, 0.2046307609998621, 0.23121101752622053, 0.06675746000837535, 0.19809787248959765, 0.03739317005965859, 0.08323350208229385, 0.19720971467904747, 0.1940968059352599, 0.30525789654348046, 0.13183113536797464, 0.532998883863911, 0.33912274811882526, 0.27507086168043315, 0.11491549696074799, 0.05393499610363506, 0.03462140062765684, 0.033815075730672106, 0.26779342093504965, 0.24997053667902946, 0.07802536943927407, 0.05098989437101409, 0.3290225041564554, 0.6551207683514804, 0.5417434021364897, 0.6609783321619034, 0.46557755791582167, 0.5780128121841699, 0.426806605537422, 0.5193231208249927, 0.2725306386128068, 0.11791286073275842, 0.09799417370231822, 0.3301346569787711, 0.2576315787155181, 0.07295683477423154, 0.03766526366234757, 0.03740944906894583, 0.164686027856078, 0.30152964347507805, 0.9529845288489014, 3.142431853339076, 3.9254178386181593, 7.537151584401727, 12.568928506225348, 20.180791206657887, 31.82323917746544, 32.41777807474136, 33.731979355216026, 26.75499513745308, 20.758871287107468, 22.797433398663998, 19.28360804915428, 23.350284732878208, 27.387936674058437, 21.107012405991554, 21.16397514939308, 34.01385582983494, 48.459871262311935, 53.97809475660324, 52.641531676054, 62.00229898095131, 47.02029950916767, 29.707942083477974, 12.45546754449606, 1.6904180240817368, 0.37264291662722826, 0.07098664049408399, 0.03743143148312811, 0.004324279288994148, 0.06563154034665786, 0.0746491170139052, 0.03837605188891757, 0.04317661187087651, 0.07793418175424449, 0.04409631095768418, 0.04509186495852191, 0.04138343836530112, 0.013288424106576713, 0.06780036303098314, 0.08744072983972728, 0.06857342115836218, 0.022846238825877663, 0.019369353030924685, 0.09516920341411605, 0.030803731751802843, 0.05309592765115667, 0.03952547536755446, 0.038604904257226735, 0.06465010199462995, 0.056927936675492674, 0.045360140211414546, 0.061931767195346765, 0.02432051518553635, 0.04366810659121256, 0.037844347607460804, 0.035634751329780556, 0.061355556317721494, 0.04808108365978114, 0.010175057086598827, 0.01753350232320372, 0.06601702669286169, 0.011681153027893743, 0.12114290264435112, 0.01620992276002653, 0.03189255701727234, 0.032908672219491564, 0.020505208194663282, 0.016723936096241232, 0.024832003364281263, 0.060440447414293885, 0.012267454330867622, 0.0315579300513491, 0.10190376313403249, 0.04445385544386227, 0.031572149600833654, 0.03667871933430433, 0.014030026304681087, 0.0636404991382733, 0.03742252942174673, 0.06846772448625416, 0.010187187490373617, 0.003536995118338382, 0.058581100311130285, 0.06563260903931223, 0.02688635533559136, 0.036084737730561756, 0.06286819800152443, 0.008834190120978747, 0.012374102807370946, 0.030993647342256736, 0.030895288655301556, 0.06767669154214673, 0.027713855561160017, 0.04533685903879814, 0.026924800440610852, 0.06296933788689785, 0.04983445949619636, 0.026950645733450074, 0.06277572640101425, 0.05230180366197601, 0.07964596021338366, 0.010837208665179787, 0.041264820902142674, 0.02477074278431246, 0.048151409573620185, 0.051662933256011456, 0.024243663938250393, 0.13806289003696293, 0.6465748487971723, 3.8411110499873757, 23.25467236340046, 58.876913487911224, 75.69584459066391, 80.2811649441719, 77.01479941606522, 70.91124773025513, 64.78603720664978, 53.941267132759094, 41.04467935860157, 37.508611902594566, 44.958039969205856, 42.27113574743271, 39.585014283657074, 45.04133529961109, 37.7970240265131, 49.919984713196754, 71.88372194766998, 68.2114166021347, 39.43011559545994, 27.711958587169647, 23.167801424860954, 12.640764601528645, 6.959715094417334, 2.551203528419137, 1.6046086535789073, 0.8062707795761526, 0.1598658083821647, 0.28183838760014623, 0.40952964511234313, 0.4218776762718335, 0.27222374570555985, 0.14120759238721803, 0.46779022668488324, 0.4562990792328492, 0.5330346256960183, 0.554447426693514, 1.4161507599055767, 1.3203627686016262, 0.4060442524496466, 0.5711550114210695, 0.16648233693558723, 0.1606510896817781, 0.019384502120374236, 0.3964862512657419, 0.37709586205892265, 0.9394414024427533, 0.6999130616895854, 1.057572669815272, 1.6239784704521298, 1.7604542034678161, 2.1387537103146315, 1.149354251101613, 1.9538534944877028, 1.4151771808974445, 1.2347354320809245, 1.1843646224588156, 0.4845428152475506, 0.4232230712659657, 0.8673250128049403, 0.34894201497081667, 0.2156843530246988, 0.11499881045892835, 0.08099488783045672, 0.06483373159426264, 0.4933952714782208, 0.7139002892654389, 2.9081988846883178, 3.6945177661255, 8.472855649888515, 14.438013061881065, 26.022438146173954, 39.31645229458809, 40.58409467339516, 43.053061589598656, 40.30806228518486, 32.86463789641857, 28.387790322303772, 25.490081012248993, 29.947618022561073, 32.56537735462189, 27.97880496829748, 27.012712508440018, 40.780129954218864, 57.025892212986946, 61.28997020423412, 61.26591369509697, 72.50081643462181, 52.408186197280884, 34.981956481933594, 14.884854834526777, 2.0232524955645204, 0.2380872383946553, 0.03769159135117661, 0.02037458834820427, 0.024436433086520992, 0.040011463352129795, 0.014167764275043737, 0.05811326525872573, 0.020222286657372024, 0.0680307850416284, 0.04125564424612094, 0.04555228595563676, 0.052858555427519605, 0.01963551687367726, 0.06798414106015116, 0.05003108781238552, 0.08325961083755828, 0.024516835510439705, 0.05328109720721841, 0.07228643793496303, 0.02951544873212697, 0.07262627477757633, 0.05586051309364848, 0.04376887169200927, 0.018489908034098335, 0.019009071875188965, 0.023506690886279102, 0.02189346221712185, 0.05198868784646038, 0.03592692002712283, 0.049118836177513, 0.07000628567766398, 0.017298208113061264, 0.04912156357022468, 0.0419754495669622, 0.0179005203244742, 0.01261300942132948, 0.00487950686874683, 0.011182081907463726, 0.020769969378306996, 0.0363457510684384, 0.038287472852971405, 0.07485691094188951, 0.036128813881077804, 0.1068877597572282, 0.16780889622168615, 0.07052192988339812, 0.1258898276137188, 0.1888441963819787, 0.1753564935643226, 0.15409089013701305, 0.1566857352736406, 0.26649662177078426, 0.1469527801964432, 0.1210756714863237, 0.1730059931287542, 0.11632879104581662, 0.08114849013509229, 0.13433604704914615, 0.10956380327115767, 0.12205897262901999, 0.21248623088467866, 0.1111912218038924, 0.13882552098948509, 0.1250327509478666, 0.08901677691028453, 0.19657926022773609, 0.19288226641947404, 0.13267405185615644, 0.21532188809942454, 0.12651624478166923, 0.21524648589547724, 0.19049795373575762, 0.15734974964288995, 0.19327014248119667, 0.13496381492586806, 0.11443783587310463, 0.09344509046059102, 0.23148905573179945, 0.11222260669455864, 0.13900909863878042, 0.09473749611061066, 0.13251572207082063, 0.14278532413300127, 1.2131300289183855, 6.946837585419416, 33.01355570554733, 74.52931478619576, 90.86287513375282, 91.8407678604126, 87.29003325104713, 80.4498378932476, 71.67880654335022, 60.13491578400135, 46.453552320599556, 42.92530104517937, 50.32549515366554, 54.59273837506771, 50.993024334311485, 69.5755510032177, 73.61808568239212, 82.96080395579338, 86.0769635438919, 68.25830608606339, 39.607790261507034, 23.475541211664677, 23.852125704288483, 16.735717467963696, 9.703722652047873, 3.563693161122501, 3.3693015296012163, 1.391396513208747, 0.48044651630334556, 0.38767903635744005, 0.29129646602086723, 0.46664693334605545, 0.46228393621277064, 0.3356972022447735, 0.9169923851732165, 0.9072256030049175, 0.9364918700885028, 0.7239009370096028, 0.8775922399945557, 1.3670571567490697, 1.0242505953647196, 0.5439628392923623, 0.25284802133683115, 0.3049177851062268, 0.26264042244292796, 0.875274958088994, 0.804145565489307, 0.6279662973247468, 0.6691312696784735, 0.9775500919204205, 2.1451278682798147, 2.377431490458548, 2.029120330698788, 1.2313472013920546, 1.5145568107254803, 2.1944962441921234, 0.984102840302512, 0.9830972598865628, 0.7248700631316751, 0.4641244624508545, 0.7624655426479876, 0.5939865612890571, 0.21594745921902359, 0.1061238300462719, 0.09663287448347546, 0.40110665489919484, 0.515738547546789, 1.3238065713085234, 3.9814353827387094, 5.111859999597073, 9.845918621867895, 15.087941586971283, 26.252166219055653, 39.20759953558445, 44.96144078671932, 46.884308606386185, 41.23040959239006, 32.99167647957802, 34.884799495339394, 29.795487485826015, 35.84391362965107, 40.08610099554062, 33.332339599728584, 34.89954650402069, 49.608937203884125, 62.98911362886429, 69.47392165660858, 69.55513089895248, 82.32932344079018, 66.9252236187458, 44.10691983997822, 21.99144534766674, 4.470236403867602, 1.0051681380718946, 0.10668564325897023, 0.10640496300766245, 0.132501472835429, 0.15518653759500012, 0.11690237472066656, 0.18408704461762682, 0.0880997272906825, 0.15319611236918718, 0.17516366875497624, 0.1704086543759331, 0.14440130617003888, 0.11082247830927372, 0.1654868051991798, 0.2649619791191071, 0.2037388924509287, 0.1965379374451004, 0.154090637806803, 0.23936857120133936, 0.08704731735633686, 0.1578922595945187, 0.1697129206149839, 0.1910325078642927, 0.15851928532356396, 0.1294654654338956, 0.15488917386392131, 0.1871156899142079, 0.09081601747311652, 0.12267451733350754, 0.10084542343975045, 0.23838558176066726, 0.2381169836735353, 0.13901105790864676, 0.17389881162671372, 0.10547356025199406, 0.12338195476331748, 0.12442946652299725, 0.26318530726712197, 0.09617027899366803, 0.12943258829182014, 0.13198956905398518, 0.10306526135536842, 0.14894942461978644], [0.11438586327130906, 0.03910123778041452, 0.0498435916233575, 0.13324961706530303, 0.015540669755864656, 0.04610663316270802, 0.07346395912463777, 0.012415146356943296, 0.03543414881278295, 0.047063933161552995, 0.039393599436152726, 0.06663175503490493, 0.027866481941600796, 0.003847467496598256, 0.0138937791234639, 0.034906567161669955, 0.07264646861585788, 0.04982091530109756, 0.0387765667255735, 0.039379917943733744, 0.03945765791286249, 0.08554909931262955, 0.02949823461676715, 0.054531226414837874, 0.07694633124629036, 0.022442803638114128, 0.07573697192128748, 0.031868834266788326, 0.037317715905373916, 0.05829186309711076, 0.05978037755994592, 0.04515485845331568, 0.015480254296562634, 0.01473810754760052, 0.029777950076095294, 0.025430751411477104, 0.05768215167336166, 0.0098573371724342, 0.021120932869962417, 0.5102970020379871, 4.68068478628993, 18.13024453818798, 53.300967290997505, 67.83197656273842, 74.94037672877312, 67.3655515909195, 65.19007712602615, 55.449865981936455, 47.65931122004986, 41.659224182367325, 44.645240753889084, 54.25315819680691, 71.23722463846207, 81.2452720105648, 91.1488401889801, 102.03287735581398, 112.43049502372742, 82.87473857402802, 38.95873188972473, 27.24768240004778, 25.414018593728542, 24.784798957407475, 6.80375293828547, 1.9261284009553492, 1.169703109189868, 1.093309277202934, 0.2885403670370579, 0.18117157684173435, 0.24274565483210608, 0.2628203190397471, 0.23680146754486486, 0.16486782435094938, 0.4340430203592405, 0.37615297827869654, 0.46521619136910886, 0.15645823732484132, 0.3561031463323161, 0.4538458655588329, 1.7097253818064928, 1.0014855419285595, 0.8264979848172516, 0.8899277437012643, 0.06446262064855546, 0.05821300990646705, 0.04610087409673724, 0.2651736099505797, 0.1618277351371944, 0.8988322096411139, 1.0037584137171507, 1.3088642293587327, 0.8404526766389608, 0.9410281735472381, 1.4238867885433137, 1.543336941394955, 2.0013559330254793, 1.2529909587465227, 1.0635630483739078, 0.6556460307911038, 0.0846869611996226, 0.6431709439493716, 0.4850442102178931, 0.24183121015084907, 0.2453037488157861, 0.15960354823619127, 0.10725904139690101, 0.026644472709449474, 0.051741300339926966, 0.2534377615666017, 0.18114211357897148, 0.7153383339755237, 1.2539472011849284, 3.862875569611788, 8.626410160213709, 13.4881485812366, 23.372241854667664, 27.370434813201427, 33.0160977691412, 38.47105845808983, 38.505218625068665, 35.78847460448742, 33.705772161483765, 33.87382194399834, 31.239170618355274, 24.475611448287964, 31.17752842605114, 39.964218735694885, 53.58551502227783, 58.560147285461426, 55.76295778155327, 61.752944961190224, 44.528001844882965, 29.933116100728512, 13.677675761282444, 2.782242768444121, 0.3777840704424307, 0.06504890247015283, 0.02341296691156458, 0.01816572308598552, 0.05064876990218181, 0.11702229094225913, 0.04259575514879543, 0.08215993351768702, 0.0261771293298807, 0.011070543605455896, 0.027289317404211033, 0.02714699017815292, 0.05178143568628002, 0.02080567410303047, 0.019847325820592232, 0.016561479969823267, 0.008288880417239852, 0.03341342540807091, 0.08349035197170451, 0.026636106849764474, 0.04845774587010965, 0.003438128292145848, 0.04407058811921161, 0.03872604502248578, 0.021128215194039512, 0.016055030973802786, 0.03315413756354246, 0.04217343601339962, 0.024511683150194585, 0.035483624087646604, 0.010950139421765925, 0.03237973614886869, 0.06340405088849366, 0.04843658723984845, 0.06794131171773188, 0.07862640515668318, 0.0617545052227797, 0.05735899831051938, 0.07381254588835873, 0.05273552960716188, 0.035922700917581096, 0.01800972364435438, 0.08621385582955554, 0.03040208885067841, 0.03531323811330367, 0.055695682094665244, 0.05449896525533404, 0.04437685762241017, 0.05567660518863704, 0.03830228240985889, 0.028873773007944692, 0.03356539869855624, 0.017180295690195635, 0.06743607242242433, 0.019688367065100465, 0.007755188571536564, 0.024299102369695902, 0.031741600469104014, 0.07410639926092699, 0.027892373618669808, 0.05304463040374685, 0.03447486727964133, 0.025799070026550908, 0.06184669480717275, 0.019484718031890225, 0.025413813746126834, 0.04574214217427652, 0.021742288590758108, 0.051293046853970736, 0.07141937938285992, 0.017334758886136115, 0.05500054205185734, 0.0027700304872269044, 0.005456609715110972, 0.03498406593280379, 0.05439175831270404, 0.06183217468787916, 0.019587768947531004, 0.054679114182363264, 0.03870938380714506, 0.06126360050984658, 0.6435465894173831, 5.463663646951318, 18.96635927259922, 58.203076645731926, 75.2946089208126, 85.01204028725624, 79.97216552495956, 76.30152449011803, 67.42381766438484, 60.19109196960926, 55.37599414587021, 54.43817786872387, 58.50895643234253, 70.26078343391418, 74.06915187835693, 87.32812240719795, 98.78206059336662, 95.1676793396473, 77.55037307739258, 45.385452434420586, 28.996631652116776, 21.350839622318745, 15.683596674352884, 8.342082817107439, 3.0484519712626934, 1.5833040280267596, 0.999859229195863, 0.25637999118771404, 0.5162980675231665, 0.5397762358188629, 0.6184093945194036, 0.6791787024121732, 0.5390920944046229, 1.4746107417158782, 1.1793916393071413, 1.7406640341505408, 1.5769478003494442, 1.8431275547482073, 1.872415670659393, 1.6704939119517803, 1.9355929805897176, 1.8437844444997609, 2.2721479274332523, 0.10926421309704892, 0.07765157934045419, 0.08009144177776761, 0.1751079483074136, 1.4197660284116864, 1.9634494045749307, 1.785628090146929, 1.0648391861468554, 3.32425803411752, 3.0795834632590413, 3.660441907122731, 3.5503031546249986, 4.766580602154136, 3.180445251055062, 3.391460753045976, 2.276766342110932, 2.3401569155976176, 1.520467868540436, 1.1251101270318031, 0.9085960232187063, 0.8403291832655668, 0.37389613687992096, 0.18628666643053293, 0.22320406045764685, 0.29236901784315705, 0.41153641242999583, 0.37559859396424145, 0.9812588116619736, 1.6906665544956923, 4.989109011366963, 9.75125715136528, 14.6071020886302, 24.541669003665447, 27.817902602255344, 34.61424641311169, 34.11563336849213, 35.26832431554794, 29.45511505007744, 29.34231050312519, 35.878776758909225, 31.79165717214346, 28.13759084790945, 38.75720590353012, 49.12693306803703, 58.97471264004707, 63.78943428397179, 62.987525314092636, 70.4208080470562, 50.929909721016884, 34.14274111390114, 13.648854307830334, 3.0080900620669127, 0.41831512993667275, 0.04388446861412376, 0.01373023111227667, 0.06778114882763475, 0.05706319680029992, 0.06140954756119754, 0.040785605015116744, 0.05053316926932894, 0.006439189583034022, 0.02600187301140977, 0.023198445414891466, 0.030990892119007185, 0.032500973393325694, 0.018591541447676718, 0.030696925568918232, 0.028615848859772086, 0.06132941416581161, 0.03191896634234581, 0.03368804231286049, 0.06019134554662742, 0.039704303271719255, 0.04657307668821886, 0.029170231318857986, 0.04087300774699543, 0.06407651089830324, 0.07050425192574039, 0.028771185934601817, 0.0503783869498875, 0.028262747982807923, 0.021982404905429576, 0.02195026805566158, 0.06170790205942467, 0.04593870740791317, 0.06395623102434911, 0.15793301834492013, 0.07867313819588162, 0.05672309278452303, 0.069344802031992, 0.05357358502806164, 0.08796116831945255, 0.023298579690163024, 0.012795069378626067, 0.2743464958621189, 0.07952221450977959, 0.1502045596134849, 0.15987210179446265, 0.15410675725433975, 0.1934009385877289, 0.20254654315067455, 0.07782682267134078, 0.13684374920558184, 0.08053467463469133, 0.13589239009888843, 0.1575286072329618, 0.15546800452284515, 0.11516695885802619, 0.13543242181185633, 0.13745821779593825, 0.11890311579918489, 0.1793587178690359, 0.12765806866809726, 0.11302171420538798, 0.08252195315435529, 0.17327877692878246, 0.11197740852367133, 0.133014801540412, 0.1792628175462596, 0.21985863684676588, 0.24115223408443853, 0.16124854824738577, 0.1297825702931732, 0.13221605768194422, 0.14174386829836294, 0.14484031620668247, 0.10803804412717, 0.15630983747541904, 0.14550554769812152, 0.14620681788073853, 0.18564917641924694, 0.12789344822522253, 0.2038950551650487, 1.416567787528038, 8.465736731886864, 27.95461356639862, 69.58097711205482, 87.87628099322319, 95.54820612072945, 89.68072816729546, 83.3015924692154, 72.28466883301735, 63.58215920627117, 59.38312612473965, 61.77943333983421, 69.75207433104515, 84.27177920937538, 92.32159405946732, 99.83860909938812, 110.18513470888138, 120.18020957708359, 93.36923584342003, 49.04814429581165, 38.58977168798447, 35.03824666142464, 31.65893219411373, 10.402843337506056, 3.0900371773168445, 1.710399726871401, 1.4759373455308378, 0.4900869255652651, 0.3965554788010195, 0.5765797547064722, 0.5679776694159955, 0.6955276220105588, 0.6109774683136493, 1.468041012994945, 1.257418671157211, 1.7315923771820962, 1.8529626145027578, 2.7870459482073784, 2.4527529487386346, 5.736857587471604, 4.1512112226337194, 2.4770079972222447, 2.9882639134302735, 0.30369748652447015, 0.2937001932878047, 0.15065626037539914, 1.5092348400503397, 2.7262836461886764, 4.309018654748797, 3.611233360134065, 3.4270406188443303, 4.723736476153135, 3.5610613273456693, 4.827156951650977, 5.91536583378911, 6.680599171668291, 5.3215408232063055, 4.451093031093478, 2.0289911376312375, 1.8607624084688723, 2.367693562991917, 1.587392846122384, 0.9198425291106105, 1.1075120838358998, 0.5217442440334707, 0.1970668215653859, 0.24101186427287757, 0.36600491032004356, 0.541700713802129, 0.6771227158606052, 1.2486279616132379, 1.9169511809013784, 5.752330832183361, 12.000054381787777, 18.87396913021803, 31.787401400506496, 37.872465178370476, 45.852337181568146, 52.88762927055359, 55.013698786497116, 49.6306112408638, 47.797540202736855, 46.653121411800385, 45.33241108059883, 38.5927165299654, 46.30203925073147, 55.01271843910217, 71.01283147931099, 73.17092567682266, 71.51188910007477, 79.63938698172569, 61.441855654120445, 43.856976851820946, 20.827712193131447, 4.986886605620384, 0.9294529259204865, 0.2470353723037988, 0.11884717270731926, 0.21693231887184083, 0.20887712220428512, 0.2025707668508403, 0.1183054642751813, 0.1820064484491013, 0.20166663802228868, 0.10971797702950425, 0.1581229636212811, 0.13099219679133967, 0.242213579476811, 0.12245364676346071, 0.10865088741411455, 0.11277176628937013, 0.074769471102627, 0.13495474588125944, 0.2443590245093219, 0.19940089085139334, 0.11787534516770393, 0.11845535584143363, 0.120683824934531, 0.10224728845059872, 0.14860753202810884, 0.14470925292698666, 0.099751631350955, 0.10982595951645635, 0.14067449286812916, 0.10293704050127417, 0.1564685977064073, 0.20055810688063502, 0.1355111043085344, 0.15310785616748035, 0.31324765062890947, 0.28666929400060326, 0.24815815268084407, 0.14594084699638188, 0.16323992342222482, 0.1703033287776634, 0.14146697300020605, 0.12959023530129343], [0.04856980645854492, 0.01120993192671449, 0.06701877020532265, 0.04425780971359927, 0.051484413343132474, 0.02490698254405288, 0.050277762857149355, 0.019662703598442022, 0.035998255261802115, 0.06586058938410133, 0.02595947968075052, 0.06355202029226348, 0.015060056775837438, 0.026766047631099354, 0.037397723135654815, 0.022177495120558888, 0.02261937170260353, 0.04798266745638102, 0.031735885931993835, 0.0685141680878587, 0.04174574001808651, 0.08719786943402141, 0.008841602320899256, 0.012290803224459523, 0.031277016023523174, 0.05730500335630495, 0.010422623636259232, 0.12152238501585089, 0.03615756839280948, 0.07328713501919992, 0.028034552415192593, 0.009595016726962058, 0.03768378766835667, 0.02942646708106622, 0.010157028464163886, 0.022885708094690926, 0.028424846022971906, 0.12352789068245329, 0.2270530757959932, 3.7919502379372716, 13.227649759501219, 45.164916068315506, 59.40570071339607, 62.66444005072117, 64.23255130648613, 49.65970627963543, 50.62323197722435, 40.6755443662405, 35.48612482845783, 29.99553345143795, 23.697705790400505, 22.910313941538334, 45.2707289904356, 45.12965016067028, 38.30371543765068, 40.60339003801346, 55.89588604867458, 48.176125288009644, 34.76426616311073, 22.977387942373753, 9.66916635632515, 6.499818647280335, 2.6948854560032487, 1.394070500973612, 0.18258829222759232, 0.22294727736152709, 0.1271459273993969, 0.18790279689710587, 0.29320440895389766, 0.46295840002130717, 0.8525237382855266, 0.9902990609407425, 1.127968761138618, 0.7204583217389882, 0.9378239954821765, 1.6195796127431095, 2.28292818646878, 1.556992696132511, 3.096134662628174, 2.9157139314338565, 0.803032343974337, 1.5023125614970922, 0.289655874366872, 0.2290812021237798, 0.03650994382041972, 0.07921206357423216, 0.4760242364136502, 1.6418502177111804, 0.9461748192552477, 1.3273454876616597, 3.0712495604529977, 3.60720272641629, 4.242135593667626, 1.1796774552203715, 4.680224061012268, 1.9088238920085132, 3.6030882596969604, 2.8419672511518, 1.5140661620534956, 1.4325187378562987, 2.070413902401924, 1.1277490854263306, 1.0352385370060802, 0.40760846226476133, 0.27966425113845617, 0.14840721152722836, 0.1783442316809669, 0.09466584175243042, 0.09792884986381978, 0.08460413009743206, 0.14540152827976272, 0.6147242453880608, 2.3279640823602676, 5.052994033321738, 11.325367335230112, 20.754032246768475, 32.02247008681297, 41.36864997446537, 54.8846311122179, 67.1305949985981, 71.1978967487812, 58.92994724214077, 36.40092574059963, 21.747545935213566, 24.12197582423687, 33.81340138614178, 47.98479415476322, 49.07085947692394, 52.023589834570885, 53.5334388166666, 56.40426456928253, 40.10489858686924, 24.555986635386944, 8.318400587886572, 1.503396334592253, 0.07626606384292245, 0.04765342477185186, 0.06566331911017187, 0.004928431562802871, 0.03100234902376542, 0.03956523221859243, 0.09522814478259534, 0.048039497414720245, 0.01685743176494725, 0.015565512221655808, 0.023823244700906798, 0.06435779971070588, 0.017493927298346534, 0.05146699884789996, 0.02303705612575868, 0.04280609093257226, 0.052696140119223855, 0.09338755917269737, 0.10823310280102305, 0.05369610989873763, 0.03665740485303104, 0.05299780459608883, 0.05127866032125894, 0.01907670564833097, 0.008997637014545035, 0.019972164336650167, 0.05221044899371918, 0.07810736191459, 0.047544503468088806, 0.05455791775602847, 0.015328137214964954, 0.053600142782670446, 0.05827353204949759, 0.05373223022616003, 0.02998529871547362, 0.05372747305955272, 0.028797643499274272, 0.006013453321429552, 0.01493135909186094, 0.009773873389349319, 0.010995795419148635, 0.024084753422357608, 0.11456476539024152, 0.06865843417472206, 0.006450405753639643, 0.02933850402769167, 0.11846736379084177, 0.016489038935105782, 0.011523193388711661, 0.018511196540202945, 0.0290094839874655, 0.04153212023084052, 0.04711074783699587, 0.031299599577323534, 0.05343041360902134, 0.016017099806049373, 0.009443748476769542, 0.06709253226290457, 0.016513578048034105, 0.05910740917897783, 0.022637175825366285, 0.035968580486951396, 0.020368795885588042, 0.08625716014648788, 0.014790986497246195, 0.026413980194774922, 0.012485998267948162, 0.034482377814128995, 0.03743109009519685, 0.0326192234933842, 0.025701624181238003, 0.007280971976797446, 0.03238080855226144, 0.03202071107807569, 0.019129270112898666, 0.0043424920568213565, 0.05288290529279038, 0.06240123126190156, 0.04605028560035862, 0.2955705241765827, 3.545975424349308, 14.682256355881691, 48.70009817183018, 69.69453021883965, 75.12392207980156, 77.44589388370514, 61.96516737341881, 61.00951485335827, 50.4067499935627, 44.04909074306488, 36.20508424937725, 33.92938636243343, 36.96225821971893, 59.408379569649696, 68.89258325099945, 54.63177368044853, 58.02358187735081, 74.35443297028542, 54.009500071406364, 32.07269959151745, 22.846635058522224, 12.115512136369944, 6.8944882694631815, 2.4626896530389786, 1.2306701252236962, 0.4605621536029503, 0.3553759603528306, 0.31914638879243284, 0.6914375571068376, 0.6120144564192742, 1.3617926579900086, 1.6440353379584849, 3.1473832251504064, 1.871516543906182, 3.2338278740644455, 2.462932365015149, 3.3586096158251166, 3.903572098352015, 3.2004483276978135, 2.6540131866931915, 2.1340410131961107, 1.388465326745063, 1.1406710045412183, 0.47053887450601906, 0.12247045640833676, 0.15043489256640896, 0.12092975783161819, 1.4698659838177264, 2.6939051086083055, 3.820346826687455, 3.9947707671672106, 3.106765542179346, 5.00189152546227, 5.397391403093934, 4.529863754287362, 4.12012841552496, 3.855226580053568, 6.509034102782607, 4.507738491520286, 3.84164753369987, 4.106702785938978, 5.3901945892721415, 2.8525620326399803, 2.481498643755913, 2.2658502403646708, 0.8500079170335084, 0.712140864925459, 0.571378783788532, 0.409681458841078, 0.28289303882047534, 0.23340344050666317, 0.2672344056190923, 0.6444363947957754, 2.257228740490973, 5.248073190450668, 10.9695515781641, 19.3292872980237, 27.04681757837534, 36.04359291493893, 42.44422405958176, 51.44201964139938, 58.30960772931576, 54.693182185292244, 41.92329481244087, 30.402062237262726, 30.26643991470337, 38.655052185058594, 57.67840079963207, 60.70482060313225, 60.64821884036064, 60.94088673591614, 65.63438728451729, 48.75917360186577, 29.17065091431141, 8.62962193787098, 2.0302697690203786, 0.06878505941131152, 0.02428313691780204, 0.01579067982675042, 0.03678588545881212, 0.06021231121849269, 0.0553478003712371, 0.05423380331194494, 0.01613522745174123, 0.004877263263551868, 0.07453441066900268, 0.03140551518299617, 0.053526158080785535, 0.05234074043983128, 0.023778988579579163, 0.05376873647037428, 0.03326561927678995, 0.047490267315879464, 0.008161792266037082, 0.07722809503320605, 0.03800776852585841, 0.008090733481367351, 0.039546648840769194, 0.037569066480500624, 0.019441836739133578, 0.025744049053173512, 0.03470861782261636, 0.0117347657760547, 0.04593055120494682, 0.044434299852582626, 0.04590689524775371, 0.049650176806608215, 0.04670229202019982, 0.02371128801314626, 0.016236909104918595, 0.06158167387184221, 0.015242794870573562, 0.08079823353909887, 0.015379033702629386, 0.03916678426321596, 0.017608854432182852, 0.05998239015752915, 0.0923214788781479, 0.2910240087658167, 0.11079210220486857, 0.12352100355201401, 0.13599669153336436, 0.20342263364000246, 0.12707448826404288, 0.10483321297215298, 0.08099507336737588, 0.1840804988751188, 0.08548866622732021, 0.14486559375654906, 0.09243940614396706, 0.21326262125512585, 0.10666795045835897, 0.1209640153683722, 0.16097022802568972, 0.15539410145720467, 0.12996380275581032, 0.3026785177644342, 0.20625082484912127, 0.1625910637085326, 0.17563441302627325, 0.09446909840335138, 0.11039904595236294, 0.1203791139414534, 0.15863838518271223, 0.1799591153394431, 0.1329076205729507, 0.1528701017377898, 0.10243446551612578, 0.11386852696887217, 0.13957268558442593, 0.08122525046928786, 0.14420779858483002, 0.13888431392842904, 0.19442424149019644, 0.23548771772766486, 0.6060338148381561, 6.277079824358225, 22.061998061835766, 59.81278046965599, 83.95098522305489, 89.02087837457657, 90.0209391117096, 69.34930354356766, 71.5955302119255, 57.25089333951473, 50.696115866303444, 42.48518206179142, 36.593689396977425, 34.07960370182991, 59.57119323313236, 57.09753356873989, 50.29249772429466, 51.52871198952198, 66.52591824531555, 56.36178284883499, 43.12833555042744, 27.74737648665905, 13.027890678495169, 7.380759101361036, 3.060178142040968, 1.984081466216594, 0.6751028867438436, 0.5175685649737716, 0.5616874631959945, 1.1033674562349916, 0.6917927192989737, 1.6438523540273309, 3.50895163603127, 3.1546177994459867, 3.6122433934360743, 3.59523621853441, 5.196426836773753, 5.252866158261895, 7.067823093384504, 4.913014294579625, 8.245986923575401, 6.903849542140961, 2.8381144953891635, 3.3318274654448032, 0.6934494304005057, 0.43537199904676527, 0.18070503312628716, 0.6199720606673509, 2.709548631682992, 5.107642700895667, 7.235930822789669, 5.254003247246146, 7.132813856005669, 9.092157818377018, 13.118653558194637, 7.73006153292954, 11.416521593928337, 7.679003197699785, 7.249905522912741, 7.06375683657825, 4.204744175076485, 4.565802225843072, 8.277976457029581, 4.068062659353018, 3.125528935343027, 2.1275141509249806, 0.7585068675689399, 0.44446140818763524, 0.5147071997635067, 0.40435087925288826, 0.35954311955720186, 0.36395144707057625, 0.41583635669667274, 0.8160290122032166, 3.0883652670308948, 6.419195048511028, 12.627812996506691, 26.216315142810345, 43.53301003575325, 53.31912271678448, 68.67026478052139, 81.5646904706955, 79.7049030661583, 71.75655037164688, 50.917613580822945, 35.18869958817959, 36.13801024854183, 46.107748076319695, 61.214768439531326, 64.47855770587921, 69.19981196522713, 70.085688829422, 74.69614863395691, 57.30172321200371, 36.599658876657486, 14.441240038722754, 4.140811180695891, 0.12358413805486634, 0.16981597524136305, 0.08747266445425339, 0.16104659502161667, 0.15175530686974525, 0.18749089009361342, 0.359416538849473, 0.126792858063709, 0.08054622245253995, 0.2342068450525403, 0.1259361970005557, 0.13110672502079979, 0.12977330829016864, 0.10243924494716339, 0.2309774636523798, 0.07891923436545767, 0.15284979657735676, 0.2307348110480234, 0.33203571278136224, 0.13900262711104006, 0.0974026597396005, 0.20254614239092916, 0.10895519022597, 0.09652055785409175, 0.09566208595060743, 0.13672757340827957, 0.16782534221420065, 0.16944169532507658, 0.2003021104610525, 0.17003853048663586, 0.07936258596600965, 0.17514208710053936, 0.14256961148930714, 0.1678393836482428, 0.1736691762926057, 0.07970540624228306, 0.12714420561678708, 0.058211889263475314, 0.12442574836313725, 0.1191071915673092, 0.07104086922481656], [0.059779935982078314, 0.014891441751387902, 0.03288748761406168, 0.039674765794188716, 0.01680146269791294, 0.03738967454410158, 0.05850121553521603, 0.02629713275382528, 0.022752692966605537, 0.013501093017111998, 0.05764854351582471, 0.04567542680888437, 0.028874305498902686, 0.07252288618474267, 0.04643867003323976, 0.027710775648301933, 0.00806240477686515, 0.029503142068278976, 0.02654659085237654, 0.035450049326755106, 0.026672093590605073, 0.024886241371859796, 0.0382431443722453, 0.05528165645955596, 0.04131241483264603, 0.022315968744806014, 0.08293233113363385, 0.04475959802221041, 0.08399639278650284, 0.05357308407837991, 0.09485989852692, 0.04654039250453934, 0.11915959461475722, 0.04764858225826174, 0.11090318686910905, 0.11838426551548764, 0.039527130356873386, 0.15088797372300178, 1.3991395477205515, 11.650358196347952, 31.528669483959675, 59.504214227199554, 63.34624886512756, 54.81149643659592, 54.251999258995056, 52.21984550356865, 49.85003426671028, 36.99309356510639, 33.103990852832794, 27.50296600162983, 36.51176579296589, 26.623755879700184, 27.76849765330553, 29.39032092690468, 38.09418328106403, 35.553347021341324, 17.140348255634308, 18.4610927850008, 10.746652688831091, 4.774328861385584, 1.63722503464669, 0.5198438710067421, 0.28935064387042075, 0.18261607823660597, 0.06468261548434384, 0.5869029695168138, 0.582020350266248, 0.9458011924289167, 0.9339223767165095, 1.2174892262555659, 1.2105213501490653, 2.151000928133726, 2.797477338463068, 3.232921860180795, 3.0969972163438797, 2.6810185750946403, 1.875516304280609, 2.002203525044024, 0.6717347830999643, 1.0379932704381645, 1.2789796642027795, 1.1627455637790263, 0.10166603096877225, 0.07499621948227286, 0.06302560010226443, 0.016820769669720903, 1.3096199138090014, 1.9340374390594661, 2.0671213790774345, 1.153474417515099, 1.6249661799520254, 4.038026221096516, 2.5411936780437827, 4.173630494624376, 3.399109742604196, 2.3557942640036345, 4.716409994289279, 3.6621591774746776, 5.617576763033867, 1.9596107793040574, 2.1348042972385883, 1.2321773380972445, 2.115471172146499, 0.8441575372125953, 0.2899939374765381, 1.2539766496047378, 0.3548721014522016, 0.18295048997970298, 0.1681531933718361, 0.061069651346770115, 0.07405119089526124, 0.16868899430846795, 0.41131139325443655, 0.577625707956031, 1.9068041816353798, 6.791430674493313, 16.18813455104828, 29.675161242485046, 58.86260725557804, 61.93915776908398, 75.14919832348824, 59.36812832951546, 25.099543668329716, 20.062402859330177, 22.184974662959576, 31.150072999298573, 29.39284399151802, 34.98798295855522, 52.5500325858593, 62.83103071153164, 53.62100891768932, 54.37430329620838, 35.85113324224949, 27.06571016460657, 7.386658284813166, 0.8454384247306734, 0.148393303679768, 0.06478235271060839, 0.0074724177829921246, 0.00778836303652497, 0.028888751403428614, 0.017473857769800816, 0.032523709087399766, 0.10500338743440807, 0.09035553710418753, 0.04005170259915758, 0.041009752167155966, 0.08445049068541266, 0.025947750036721118, 0.04994801180146169, 0.02370746595261153, 0.0701888465846423, 0.030892088143446017, 0.0728639104636386, 0.09743137343320996, 0.03390037818462588, 0.03862477526126895, 0.02045109820755897, 0.04890129785053432, 0.03429479998885654, 0.011864858697663294, 0.059761875818367116, 0.07211854186607525, 0.05187574781302828, 0.06660702667431906, 0.052121561966487207, 0.07426256939652376, 0.07251250353874639, 0.1442762988153845, 0.02998548610776197, 0.018864026533265132, 0.013637511819979409, 0.04755810703500174, 0.07324927064473741, 0.038528752484126016, 0.020602791337296367, 0.02149324423953658, 0.07196595630375668, 0.02358821209782036, 0.07078355178236961, 0.04642303298169281, 0.020295315844123252, 0.11357719689840451, 0.05464421097713057, 0.00617836085439194, 0.019606639907578938, 0.027520591029315256, 0.03987562806287315, 0.02713884325203253, 0.02093109520501457, 0.052203302111593075, 0.017811048855946865, 0.03073598851187853, 0.08985765991383232, 0.016774580253695603, 0.11969385188422166, 0.016075998501037247, 0.025138193086604588, 0.012473858587327413, 0.014037573946552584, 0.04710363064077683, 0.05225237662671134, 0.04750840540509671, 0.10667746479157358, 0.02642101389938034, 0.04301856410165783, 0.044265683900448494, 0.03795276796154212, 0.07046584578347392, 0.03138735854008701, 0.04049943287100177, 0.04171641034190543, 0.0396722462028265, 0.2987187443068251, 1.1711076088249683, 12.267579976469278, 33.05739775300026, 65.18243953585625, 74.43808928132057, 69.08073395490646, 66.22220814228058, 62.57207840681076, 59.44590635597706, 47.782432213425636, 41.55605211853981, 38.35375875234604, 39.169829562306404, 29.286559894680977, 29.804046526551247, 29.74800903350115, 37.233586460351944, 38.51836211979389, 25.3171693906188, 25.43865267187357, 16.28738332539797, 7.26752232760191, 2.2333263605833054, 0.6053709879051894, 0.6344157981220633, 0.6544770591426641, 0.6122492125723511, 1.0364772705361247, 1.8177418294362724, 2.321722679771483, 2.373672779649496, 4.02547406964004, 3.878216058947146, 4.642072208225727, 5.057630259543657, 5.307495826855302, 6.789625296369195, 6.500566732138395, 4.788825558498502, 4.362969109788537, 3.294209484010935, 3.959639039821923, 2.6060129748657346, 2.8095925133675337, 0.28978352376725525, 0.06467524595791474, 0.07752650519250892, 0.026344878824602347, 0.790187845705077, 1.468674628995359, 2.5952790258452296, 5.136639419943094, 6.837074300274253, 7.73477423004806, 5.723342662677169, 5.999893248081207, 7.5864591635763645, 5.916653014719486, 7.558543011546135, 8.352200724184513, 6.9595027808099985, 4.704451560974121, 4.59708072245121, 4.173657093197107, 4.219536781311035, 4.750536913052201, 4.35828348621726, 2.697109286673367, 2.3924064869061112, 1.1387188592925668, 0.591340062674135, 0.37214701354969293, 0.4026652540778741, 0.20102367096114904, 0.61718734446913, 0.6084766681306064, 2.497964110225439, 6.166414087638259, 16.464826203882694, 25.128766000270844, 58.181303814053535, 69.61549445986748, 83.70890021324158, 66.49891689419746, 31.3873303681612, 27.94554155319929, 30.09336870163679, 39.68384698033333, 39.9435630440712, 41.725834608078, 58.87676529586315, 70.92830881476402, 61.206663474440575, 61.76500931382179, 41.39508135616779, 29.763880781829357, 8.495780769735575, 1.0626621404662728, 0.12481994752306491, 0.03857558942399919, 0.025880062457872555, 0.04426461520779412, 0.032406104655819945, 0.056778776124701835, 0.009375825266033644, 0.05096766704809852, 0.08965189947048202, 0.08131617098115385, 0.013953018278698437, 0.02593450826680055, 0.02547469954151893, 0.039719669439364225, 0.026899270560534205, 0.09256229095626622, 0.032732289691921324, 0.048179937730310485, 0.054766891698818654, 0.08442765480140224, 0.044795922440243885, 0.005904302879571333, 0.011165674877702259, 0.05646713347232435, 0.04863513029704336, 0.0696720891573932, 0.036155520065221936, 0.06537580367876217, 0.06339467014186084, 0.05945872333541047, 0.032522744295420125, 0.020275541319279, 0.03126254043309018, 0.034874216944444925, 0.01660458761762129, 0.039539212521049194, 0.03505903769109864, 0.07768293507979251, 0.0174905931999092, 0.020429347714525647, 0.08730750691029243, 0.2569139515981078, 0.1153240269923117, 0.1440549606923014, 0.17758339672582224, 0.07978643392561935, 0.2653617592295632, 0.1067165017593652, 0.1257257239194587, 0.12037610082188621, 0.2421361586311832, 0.09143562914687209, 0.12822137359762564, 0.12146969995228574, 0.11098795497673564, 0.11402720556361601, 0.23499362549046054, 0.15568699745927006, 0.08943393069785088, 0.18606976635055616, 0.09178146996418945, 0.08667740126838908, 0.08711275993846357, 0.195464227872435, 0.18889478116761893, 0.14018106856383383, 0.16519028751645237, 0.1584191102301702, 0.18871234642574564, 0.1606599657679908, 0.17323973996099085, 0.17950164066860452, 0.21788836835185066, 0.15592883370118216, 0.21021797525463626, 0.25585300696548074, 0.11258098980761133, 0.6621068122331053, 2.8822087543085217, 17.31762584298849, 45.374262034893036, 78.48481133580208, 86.18909552693367, 77.63855874538422, 74.79270905256271, 71.06004774570465, 66.63008585572243, 54.52225595712662, 49.41798985004425, 43.35459440946579, 50.80314092338085, 39.30998884141445, 40.380098819732666, 40.53354598581791, 52.0020791888237, 48.004245311021805, 26.357986740767956, 24.96627151966095, 15.068943556398153, 6.545949596911669, 2.806002893485129, 1.014129719696939, 0.7493840320967138, 0.6483013811521232, 0.46771915862336755, 1.1422657314687967, 1.5503290412016213, 1.6169119183905423, 3.690423723310232, 3.2915341900661588, 4.744235426187515, 6.348513141274452, 7.2857556492090225, 6.748849684372544, 8.354731388390064, 10.422803666442633, 5.916647789999843, 9.668876621872187, 3.759872834198177, 2.9690191335976124, 3.6853794939816, 3.805333594791591, 0.5533699470106512, 0.29775276489090174, 0.5179697403218597, 0.14489587338175625, 5.439661284908652, 6.086159069091082, 8.465086966753006, 8.228302672505379, 8.82991299033165, 11.847124937921762, 9.697454888373613, 11.471386849880219, 14.222091548144817, 11.883226800709963, 14.771060440689325, 8.922226186841726, 12.210753075778484, 10.258328542113304, 4.9999849777668715, 6.117530185729265, 7.770365495234728, 5.441939737647772, 4.5926164370030165, 6.197983743622899, 2.690716367214918, 1.17369978222996, 0.3991996025433764, 0.7591426803264767, 0.42861373513005674, 0.4371180053567514, 0.6796986807603389, 1.1085795890539885, 2.9079017881304026, 8.570720348507166, 19.606725610792637, 35.690447464585304, 65.81736266613007, 70.47113254666328, 84.36694130301476, 69.22470062971115, 37.97232002019882, 30.86106240749359, 33.04891660809517, 43.47935311496258, 42.46863394975662, 48.8701618462801, 67.73131236433983, 77.50004857778549, 69.08864513039589, 73.9187103509903, 49.9625538289547, 36.83146543800831, 13.901613894850016, 2.729460275731981, 0.3395511454436928, 0.16209124209126458, 0.08614861362730153, 0.11680207346216775, 0.15912481845589355, 0.12217508905450813, 0.09125585129368119, 0.18174322351114824, 0.21409312903415412, 0.35174368182197213, 0.20704049966298044, 0.2849418413825333, 0.12753154733218253, 0.18835900991689414, 0.10362513014115393, 0.25937146972864866, 0.13346734835067764, 0.1704397503635846, 0.17269967909669504, 0.21627802663715556, 0.2017067139968276, 0.14181946346070617, 0.13675371184945107, 0.1477546856040135, 0.11696029192535207, 0.2198380051413551, 0.11160228998051025, 0.26038551062811166, 0.14841730473563075, 0.1468953231233172, 0.17092921159928665, 0.1452218840131536, 0.36236060899682343, 0.10788036743178964, 0.13221016502939165, 0.17697519186185673, 0.0898760354903061, 0.1807855858351104, 0.12455182441044599, 0.11720597991370596], [0.04739216652524192, 0.018075396292260848, 0.028331934699963313, 0.06250456790439785, 0.05297922121826559, 0.03606423219025601, 0.031486208899877965, 0.02731976957875304, 0.05125234747538343, 0.007211635902422131, 0.031766102474648505, 0.019503744842950255, 0.020168249029666185, 0.025541526229062583, 0.12106489550205879, 0.07376476642093621, 0.02596307353087468, 0.08347688199137338, 0.028147729935881216, 0.007312313800866832, 0.06972868533921428, 0.0113536321259744, 0.028205953276483342, 0.08169528970029205, 0.004461492653717869, 0.06120029531302862, 0.04182952478004154, 0.052699331354233436, 0.11459691522759385, 0.0250605291876127, 0.09958497466868721, 0.04209261242067441, 0.0350325764156878, 0.028651609245571308, 0.05788785645563621, 0.0696013327979017, 0.09286347674787976, 0.19630698108812794, 5.734248077496886, 18.92482940107584, 47.962227165699005, 59.67589661478996, 56.70679673552513, 56.64918802678585, 47.69609324634075, 39.61779512465, 34.70036119222641, 27.480505406856537, 25.465859211981297, 24.583062082529068, 25.697373189032078, 38.94356310367584, 49.17910426855087, 56.871460899710655, 45.67718558013439, 34.04456578195095, 23.483847565948963, 10.195793397724628, 3.4296168806031346, 1.8912067310884595, 0.333471946651116, 0.07888742591603659, 0.4004109062952921, 0.4974477837095037, 0.9271266788709909, 0.39722923014778644, 1.0150497453287244, 1.4792818785645068, 1.4799502864480019, 3.831812236458063, 1.3564736559055746, 4.8368896543979645, 1.9624177599325776, 4.318422200158238, 2.7035713149234653, 4.488127743825316, 2.757343892008066, 1.752936306875199, 2.2424166603013873, 1.025029078591615, 1.2781327846460044, 0.9946769603993744, 0.3175726201152429, 0.01707891460682731, 0.08954334552981891, 0.05769069008238148, 0.9326209465507418, 1.2390411947853863, 2.3092384496703744, 5.473288055509329, 4.9960811622440815, 4.241320537403226, 3.9311992283910513, 3.459139633923769, 2.8103201743215322, 2.950453804805875, 9.30349487811327, 7.025428768247366, 4.518329948186874, 3.8790826499462128, 5.99312343634665, 3.556047733873129, 3.6671171989291906, 6.472174180671573, 2.849541432224214, 1.636022161692381, 1.5693497518077493, 0.8415856095962226, 1.1766262189485133, 0.507836218457669, 0.11010229078237899, 0.060442707253969274, 0.14138904749415815, 0.11012952760211192, 0.5503284477163106, 0.9629111993126571, 3.948858780786395, 12.142925765365362, 21.16900607943535, 21.320920027792454, 25.757305473089218, 29.0389708802104, 29.179627932608128, 28.916558548808098, 29.51028998941183, 17.213792614638805, 27.82325841486454, 38.81364807486534, 43.72176870703697, 43.99776689708233, 59.90992225706577, 54.79902170598507, 48.24967794120312, 36.57971754670143, 20.934592857956886, 5.6055789068341255, 0.4521565296454355, 0.007502435801143292, 0.039617523943888955, 0.032222779336734675, 0.02725949791056337, 0.04551550511678215, 0.04921787949569989, 0.03127269672404509, 0.03780818275117781, 0.03914286113285925, 0.0018089492459694156, 0.06844603150966577, 0.0538565510942135, 0.0317452555464115, 0.01710033855488291, 0.03246723907068372, 0.06369524737237953, 0.024840853475325275, 0.0030436002680289675, 0.059997251664754, 0.011602714512264356, 0.027497246774146333, 0.07901791032054462, 0.11887209402630106, 0.04154051392106339, 0.07079430550220422, 0.015406680558953667, 0.02867904830054613, 0.033411814947612584, 0.02817100554239005, 0.07722983908024617, 0.02471109266480198, 0.018788243978633545, 0.04819913337996695, 0.04895369347650558, 0.09775981088750996, 0.009825765282585053, 0.042613922923919745, 0.04994778173568193, 0.02028003873419948, 0.028253326418052893, 0.05865343744517304, 0.05690030651749112, 0.03255070099839941, 0.018955316263600253, 0.018253383714181837, 0.03914923618140165, 0.03843927173875272, 0.06587952899280936, 0.048174015391850844, 0.022963418377912603, 0.05627214159176219, 0.039706243987893686, 0.020598325463652145, 0.036670975023298524, 0.07156326697440818, 0.027324400580255315, 0.08129178400849923, 0.005702926209778525, 0.0661109529028181, 0.04015699109004345, 0.022570688670384698, 0.018995622303918935, 0.03987609932664782, 0.043005958723369986, 0.043195492107770406, 0.031424343469552696, 0.035757161167566665, 0.06248462639632635, 0.09866000633337535, 0.06631973388721235, 0.05268612854706589, 0.01509882935351925, 0.057510377882863395, 0.03354975793627091, 0.046279943198896945, 0.09906446939567104, 0.27080841071438044, 5.496242623776197, 21.132127158343792, 55.29191605746746, 69.76419568061829, 66.7558591067791, 69.19319272041321, 57.2623535245657, 49.80379454791546, 44.96357627213001, 34.851152300834656, 31.16067063063383, 28.006340190768242, 34.87992815673351, 41.518437936902046, 54.44002836942673, 53.57933275401592, 42.12873078882694, 31.415410861372948, 18.28052457422018, 10.097900200635195, 3.7278469651937485, 2.1553880302235484, 0.5060471675824374, 0.5593127687461674, 0.4014923342037946, 0.7448195270262659, 1.140674448106438, 1.6887386329472065, 2.871915581636131, 3.791050873696804, 4.243518244475126, 7.323585469275713, 6.830046102404594, 8.676619715988636, 6.912869783118367, 9.206847064197063, 10.115592051297426, 7.317880550399423, 8.4174470230937, 7.416350841522217, 3.6298072384670377, 5.3784646186977625, 1.8002539803273976, 0.8123680867720395, 0.20005433703772724, 0.013762932921963511, 0.04322974222304765, 0.1840489130700007, 0.09160080895526335, 0.7379828626289964, 4.753608098253608, 5.384919997304678, 5.864608632400632, 7.46704819612205, 8.668985925614834, 8.433581907302141, 8.988141249865294, 8.56994329020381, 5.435967883095145, 10.146231707185507, 8.005667869001627, 6.018161242827773, 6.171141033992171, 5.3545368276536465, 5.539246341213584, 6.282920585945249, 6.8908841628581285, 3.613808434456587, 3.7956146663054824, 3.1617512041702867, 2.3650161316618323, 0.7654404267668724, 0.550272281980142, 0.16433214215794578, 0.37343838019296527, 0.27277985180262476, 0.6699432386085391, 1.4167069550603628, 4.135767426341772, 13.404316529631615, 26.37375209480524, 30.011940971016884, 37.20804803073406, 38.9509879052639, 34.6774560213089, 29.852093048393726, 29.96542576700449, 24.99164465814829, 29.528694301843643, 41.09986759722233, 52.53487139940262, 55.332592874765396, 65.10466530919075, 65.40962174534798, 54.02961239218712, 43.376868814229965, 23.35843149572611, 7.12226134724915, 0.5440369946882129, 0.050945020411745645, 0.023582837093272246, 0.09509198294836096, 0.04563170688925311, 0.017270529715460725, 0.02998526717419736, 0.0264765302563319, 0.07473237114027143, 0.004572612569972989, 0.03403845847060438, 0.020726724433188792, 0.024334803383680992, 0.0638189930759836, 0.03251103691582102, 0.03292987908935174, 0.03967670651036315, 0.0214980422242661, 0.03508776622766163, 0.05748812829551753, 0.021121630488778464, 0.05713346334232483, 0.08805541365290992, 0.05558560304052662, 0.025536500033922493, 0.07076959198457189, 0.029454503564920742, 0.03219298210751731, 0.02262842590425862, 0.049172831131727435, 0.03426062408834696, 0.01661777187109692, 0.03741338987310883, 0.021206482088018674, 0.007925523059384432, 0.06590987541130744, 0.02122916583175538, 0.006609111715079052, 0.05229702794167679, 0.028124916316301096, 0.12380705695250072, 0.12396090416586958, 0.12822221964597702, 0.18970525095937774, 0.09951432963134721, 0.10123931831913069, 0.08970361232059076, 0.1279115120996721, 0.154003880743403, 0.0883389957016334, 0.184595504833851, 0.15632272115908563, 0.14380594046087936, 0.0832006249402184, 0.1460569485789165, 0.164478033548221, 0.11394740242394619, 0.13289096677908674, 0.11128852478577755, 0.08723422724870034, 0.16017311689211056, 0.0964293627475854, 0.17427334387321025, 0.19567055976949632, 0.1743144291685894, 0.10549022888881154, 0.11596716474741697, 0.07782005428452976, 0.306707993731834, 0.16615203669061884, 0.2988365083001554, 0.1430703088408336, 0.17597211990505457, 0.18826487590558827, 0.1764065434690565, 0.09156245476333424, 0.2459129036287777, 1.0447191470302641, 9.015361089259386, 28.291321098804474, 67.32489377260208, 81.96871519088745, 81.58549055457115, 79.64460790157318, 68.78894001245499, 54.94496427476406, 49.49172109365463, 41.68639652431011, 37.918754294514656, 37.19443716108799, 37.79168151319027, 52.42959804832935, 66.90915808081627, 71.70253247022629, 59.652676060795784, 43.954931795597076, 29.595103338360786, 14.067973718047142, 4.881988959386945, 3.023650939576328, 0.9174049599096179, 0.4244580049999058, 0.8762786979787052, 1.7273172503337264, 1.823938109446317, 3.0811618035659194, 4.472570428624749, 5.445649763569236, 4.255125196650624, 10.076940525323153, 6.325890105217695, 11.143783628940582, 8.487800247967243, 15.259955506771803, 10.199998822063208, 14.238238781690598, 10.903322082012892, 10.882270261645317, 8.125222753733397, 6.460078479722142, 6.658162325620651, 4.243968045338988, 0.743683862965554, 0.22495402983622625, 0.3627188882092014, 0.6669822474941611, 2.3316840827465057, 6.954823806881905, 11.530889756977558, 14.115768503397703, 12.37655432894826, 14.449715483933687, 15.5043032951653, 11.764094643294811, 13.403528071939945, 11.52973746880889, 19.254590906202793, 15.199491251260042, 13.179558590054512, 13.96666830405593, 14.950021337717772, 12.001578100025654, 10.356196090579033, 16.28824967890978, 10.129233319312334, 4.451027009636164, 7.2658556420356035, 2.5967400474473834, 3.1345301773399115, 0.8361762436106801, 0.4015422658994794, 0.15354092902271077, 0.4611086117802188, 0.36314016091637313, 0.8440370124299079, 1.4912403118796647, 5.6557689886540174, 14.203618839383125, 25.636711344122887, 31.483968682587147, 37.873415127396584, 41.40680752694607, 39.822984114289284, 38.860282972455025, 41.02184638381004, 28.758464232087135, 38.43362286686897, 52.306674644351006, 56.12901493906975, 60.107162073254585, 75.71716144680977, 71.5397036075592, 63.98882478475571, 51.98108531534672, 32.60682553052902, 10.74397288262844, 1.4638732303865254, 0.10765369326691143, 0.13570226670708507, 0.19101198005955666, 0.16618797148112208, 0.14712084695929661, 0.17933991184690967, 0.17319405335001647, 0.15229183511110023, 0.20126241986872628, 0.12587921490194276, 0.21667881606845185, 0.10386169713456184, 0.10217703675152734, 0.23314987833146006, 0.10551198123721406, 0.16044263524236158, 0.09378445232869126, 0.09567862100084312, 0.12238093855557963, 0.08631859513116069, 0.14248652063542977, 0.21722934121498838, 0.2160645998083055, 0.10505003883736208, 0.19168075901689008, 0.10458538017701358, 0.09136217879131436, 0.08161216173903085, 0.16037956753280014, 0.22205549787031487, 0.10774949711048976, 0.11913410926354118, 0.13767125870799646, 0.09227324670064263, 0.1509975889348425, 0.06415528987417929, 0.13207458949182183, 0.17936594638740644, 0.14673533092718571], [0.011290960537735373, 0.07215659919893369, 0.0248870595896733, 0.07927127211587504, 0.09744468014105223, 0.041628295148257166, 0.050924273673444986, 0.005940650953561999, 0.10067709692521021, 0.052677044659503736, 0.039240178957697935, 0.07725041883531958, 0.08330160155310296, 0.03739476567716338, 0.04193346627289429, 0.05941003473708406, 0.10621690278640017, 0.06199966257554479, 0.03429390941164456, 0.03349583719682414, 0.04536303458735347, 0.013038893648626981, 0.026863990715355612, 0.05902749100641813, 0.042612765173544176, 0.05989146593492478, 0.022444120950240176, 0.03116070292890072, 0.0493675335746957, 0.02461557825881755, 0.030901734207873233, 0.018011139291047584, 0.06462166289566085, 0.13742615701630712, 0.032788303287816234, 0.03879477531882003, 0.11763040674850345, 4.038956221193075, 12.9038130864501, 27.47939396649599, 50.1146786659956, 59.42119628190994, 60.31890191137791, 51.988510116934776, 51.92805536091328, 47.59386733174324, 33.62024635076523, 32.32344053685665, 31.327086500823498, 72.57333174347878, 68.34077686071396, 60.022107437253, 42.73279197514057, 26.40188578516245, 24.581677056849003, 18.057408146560192, 6.927427751943469, 2.8362001106142998, 1.1885373922996223, 0.16190775349969044, 0.11930758628295735, 0.22848546534078196, 0.31071763951331377, 0.7749674061778933, 0.26876711868681014, 1.282278480939567, 3.406220586039126, 5.669370358809829, 5.760947344824672, 8.008990790694952, 7.903829058632255, 5.38386270403862, 7.77041251771152, 4.68739902600646, 12.213924955576658, 4.750328399240971, 7.139716660603881, 4.301338316872716, 2.9818795435130596, 6.6514224372804165, 1.279903370887041, 1.3703056261874735, 0.1789535497664474, 0.10342898793169297, 0.05148009404365439, 0.015363887396233622, 0.09369033316033892, 0.424124572891742, 1.3628124282695353, 2.8893466712906957, 6.099841659888625, 7.262845253571868, 4.7988969180732965, 7.51959272660315, 6.508913934230804, 5.374035481363535, 2.873840178363025, 11.473616380244493, 6.233327072113752, 1.913474842440337, 3.4487061062827706, 2.7429189160466194, 4.132336210459471, 3.2952886261045933, 5.966358622536063, 1.4981830143369734, 2.5335558503866196, 4.098376482725143, 1.717210030183196, 0.3949057142017409, 1.4263960788957775, 0.5071907874662429, 0.6008883565664291, 0.06529001882881857, 0.1857758907135576, 0.22617349721258506, 0.8159475540742278, 2.174297240562737, 9.126849006861448, 19.92397628724575, 33.087989911437035, 40.265379175543785, 39.46698501706123, 44.06254582107067, 35.6112939119339, 25.49296125769615, 29.811349734663963, 27.143858671188354, 29.712076261639595, 48.902137130498886, 55.811473578214645, 56.75509214401245, 58.72852765023708, 52.99281142652035, 39.928151071071625, 15.050279907882214, 3.3331687934696674, 0.1515232224483043, 0.05061538438894786, 0.10995695600286126, 0.07421298651024699, 0.036166789577691816, 0.10509945102967322, 0.01767162342730444, 0.03393085818970576, 0.03356349880050402, 0.0653609013534151, 0.07949784238007851, 0.016261442651739344, 0.07263058665557764, 0.09605086743249558, 0.08251617924543098, 0.031302412317018025, 0.0477195018902421, 0.01979015261895256, 0.027936989681620616, 0.02211429011367727, 0.051309006739757024, 0.018889632483478636, 0.011164456827827962, 0.03156663544359617, 0.03645663906354457, 0.0058845241801464, 0.09588975459337234, 0.004036080154037336, 0.02839166460034903, 0.053654330695280805, 0.05366655386751518, 0.0035556118928070646, 0.09640052288887091, 0.02783251755317906, 0.03607894897868391, 0.03682099646539427, 0.047677574257249944, 0.06563157745404169, 0.010824838918779278, 0.0468847304728115, 0.016207160115300212, 0.02020357711444376, 0.05003631995350588, 0.08058715189690702, 0.08080562532995827, 0.028215020465722773, 0.03207857262168545, 0.05088170037197415, 0.06404003433999605, 0.04072775460372213, 0.01161621417850256, 0.04720505254226737, 0.11359204727341421, 0.048756823962321505, 0.025186063467117492, 0.045577385390060954, 0.04264544193574693, 0.017142770848295186, 0.0940818976960145, 0.023031836972222663, 0.006268086972340825, 0.0441042964666849, 0.0211856722671655, 0.05309837302775122, 0.054624295444227755, 0.03521641010593157, 0.016004744902602397, 0.03360950082424097, 0.0345473788183881, 0.044595267972908914, 0.06438030904973857, 0.05022066201490816, 0.04664559193770401, 0.04184288343822118, 0.050668844996835105, 0.19387669977732003, 3.276023422367871, 14.238249231129885, 30.66673893481493, 58.73014256358147, 70.52560642361641, 74.12427932024002, 64.05291974544525, 60.20959697663784, 51.167879551649094, 41.31131865084171, 38.064712062478065, 37.60162331163883, 70.55774509906769, 58.01890812814236, 47.93980456888676, 42.90641225874424, 30.16194362193346, 28.500617668032646, 18.800733759999275, 8.40931735932827, 3.4496235195547342, 1.1559221986681223, 0.4881685628788546, 0.46606995805632323, 0.5525972228497267, 1.6186956851743162, 2.270652470178902, 3.393729943782091, 5.255450019612908, 5.780198536813259, 8.70912317186594, 6.510918801650405, 11.51515955105424, 7.642259169369936, 9.332880601286888, 8.369285557419062, 11.153149176388979, 11.150074191391468, 8.712140209972858, 8.863061461597681, 6.173123577609658, 4.258305625990033, 5.496065458282828, 2.735055712983012, 0.7110754970926791, 0.20436621503904462, 0.242751027981285, 0.13368340238230303, 0.12232403067173436, 0.27619919332209975, 0.9561035083606839, 3.4785026824101806, 5.105463992804289, 4.851919747889042, 6.967096198350191, 9.894725102931261, 7.4615593906491995, 5.903094867244363, 5.98729407414794, 5.469834990799427, 8.658390194177628, 7.272816393524408, 7.6939259469509125, 10.131700336933136, 9.366773832589388, 5.872102780267596, 7.840155400335789, 7.9932985827326775, 5.132082039490342, 5.4097155667841434, 2.931433687917888, 3.9192170463502407, 2.823370574042201, 2.0368997007608414, 1.7124960268847644, 0.6487703591119498, 0.34906996123027056, 0.4545432172017172, 0.3462875902187079, 0.8255735656712204, 2.5599706079810858, 10.211079977452755, 18.605116456747055, 29.057411290705204, 33.84439252316952, 36.387440264225006, 39.19697530567646, 37.048844173550606, 26.13536048680544, 36.81627005338669, 36.793611869215965, 38.596561923623085, 53.410978987812996, 64.04620170593262, 65.1451027393341, 67.28584706783295, 61.16066314280033, 46.93291939795017, 16.904872991144657, 3.488675211556256, 0.32870510243810713, 0.06351201853249222, 0.0233865149129997, 0.011140400110889459, 0.0377906569337938, 0.11770609839004464, 0.05388991434301715, 0.06797306821681559, 0.019425524333200883, 0.05332709180947859, 0.07358030561590567, 0.030657198403787334, 0.05831263952131849, 0.0049004103857441805, 0.04763395081681665, 0.005319977544786525, 0.021382634549809154, 0.06190018881170545, 0.027941071493842173, 0.01701221593975788, 0.02509818019461818, 0.01796480701159453, 0.01577701132191578, 0.016939923334575724, 0.009407290472154273, 0.024429252807749435, 0.06543338691699319, 0.02967941512906691, 0.04708479864348192, 0.011276763252681121, 0.016861823423823807, 0.0943620213365648, 0.049286075445706956, 0.031215458584483713, 0.01946721262356732, 0.015155838354985463, 0.04658917758206371, 0.1148132438538596, 0.014612642844440416, 0.1819143776083365, 0.17031928495271131, 0.13575133751146495, 0.19917127036023885, 0.25721962738316506, 0.13349839980946854, 0.09975954264518805, 0.1694152451818809, 0.3335770347621292, 0.2509513293625787, 0.1744167268043384, 0.14726569934282452, 0.18001152580836788, 0.21850840304978192, 0.12594342551892623, 0.12379202104057185, 0.17524615104775876, 0.2749514055904001, 0.08898924323148094, 0.15091243491042405, 0.12288132420508191, 0.1217721845023334, 0.2163942321203649, 0.15561345062451437, 0.16042623377870768, 0.16452596144517884, 0.2077362482668832, 0.10211459986749105, 0.09683079784736037, 0.11654138666926883, 0.10972103467793204, 0.16079104389064014, 0.17661682359175757, 0.31630428973585367, 0.08855245963786729, 0.27281874034088105, 0.5502107134088874, 7.037605689838529, 21.03061180561781, 41.539044231176376, 70.7958935201168, 83.54136720299721, 84.09684419631958, 72.6306402683258, 69.18923333287239, 64.93276253342628, 49.84812296926975, 46.437927559018135, 46.25366024672985, 84.05706033110619, 80.31096294522285, 73.44369783997536, 56.66925095021725, 38.640407770872116, 32.94819541275501, 24.127251841127872, 9.131586402654648, 3.9716380834579468, 1.509430529549718, 0.5316470470279455, 0.4638210724806413, 1.0791565803810954, 1.739760038908571, 2.6610831823199987, 4.250124664977193, 5.896147890016437, 8.724825829267502, 15.515036769211292, 13.64269768819213, 19.023175723850727, 18.972015269100666, 16.972072385251522, 17.571258433163166, 18.10648251324892, 24.371603429317474, 11.915202084928751, 19.072888456285, 14.425988607108593, 9.199612252414227, 17.01169665902853, 8.649631664156914, 3.5198769997805357, 0.422364198602736, 0.5885724455583841, 0.25854355946648866, 0.3908340248744935, 0.5109587602782995, 1.4008912537246943, 7.814857307821512, 12.408451717346907, 15.13602040708065, 17.106611765921116, 16.89322281628847, 17.87209779024124, 18.29269152134657, 16.218823604285717, 14.602573681622744, 26.382556222379208, 19.60076943039894, 10.653319247066975, 13.738930374383926, 14.90843066945672, 12.599783800542355, 12.244120985269547, 16.871223896741867, 10.306157525628805, 7.507955376058817, 11.134439930319786, 5.264657875522971, 3.3123941207304597, 4.943547556176782, 2.2011622739955783, 1.53824022738263, 0.3019818488974124, 0.6303625437431037, 0.42596768180374056, 1.1341234808787704, 2.50242720823735, 12.697153575718403, 26.47117506712675, 42.81341604888439, 52.39175207912922, 53.96571882069111, 59.14946526288986, 51.17162235081196, 36.2496330589056, 44.054847434163094, 38.735695257782936, 42.372852489352226, 62.30298064649105, 70.34782156348228, 74.6885034441948, 79.42332297563553, 70.6530287861824, 57.39952236413956, 23.30404881387949, 6.081475345417857, 0.6850070552900434, 0.15884112508501858, 0.13801061315461993, 0.11864522690302692, 0.11716942914063111, 0.25171491026412696, 0.14841438067378476, 0.17185468459501863, 0.10976660996675491, 0.11159326546476223, 0.17740651324857026, 0.21504431002540514, 0.09389906961587258, 0.19423368765274063, 0.19397473748540506, 0.0638001128390897, 0.15303877706173807, 0.14472390292212367, 0.09094712528167292, 0.134973922977224, 0.18840051081497222, 0.20439918123884127, 0.11038850745535456, 0.08292819737107493, 0.1180970246787183, 0.10760475604911335, 0.2716434752801433, 0.15386759274406359, 0.16175381722860038, 0.09212862438289449, 0.10519371862756088, 0.12518167030066252, 0.1619319326709956, 0.17871975840535015, 0.16064501891378313, 0.06507594633148983, 0.19964599254308268, 0.22044117824407294, 0.1165063572989311], [0.0765580841107294, 0.01905433731735684, 0.020900156923744362, 0.01830614113714546, 0.04228006779158022, 0.10460493576829322, 0.05164725167560391, 0.04361509498266969, 0.025212906948581804, 0.09820759310969152, 0.017179445931105874, 0.06235173001186922, 0.032757975423010066, 0.08024411639780737, 0.0740340027550701, 0.04186112171737477, 0.014211795896699186, 0.05585613442235626, 0.06677947952994145, 0.038847742398502305, 0.10603175178403035, 0.09937744049238972, 0.0653524260269478, 0.021347252659325022, 0.043364219382056035, 0.03646580829808954, 0.02211812330642715, 0.007170910084823845, 0.05335541958629619, 0.011360309599695029, 0.0226251326239435, 0.04685649917519186, 0.07161953661125153, 0.06170265136461239, 0.008161209680110915, 0.044670031929854304, 0.4976359033025801, 10.438970848917961, 23.493751734495163, 44.261769130825996, 64.4814683496952, 56.55682258307934, 52.38006770610809, 54.61221233010292, 45.48740476369858, 34.92208689451218, 29.676067493855953, 18.482208251953125, 19.525670260190964, 29.030244648456573, 40.65887086093426, 60.904336497187614, 63.210428953170776, 36.630262434482574, 12.292233053594828, 6.405226048082113, 1.9774911948479712, 0.37861940218135715, 0.14273800479713827, 0.28940437536221, 0.3632529970491305, 0.4416006070096046, 0.9154042485170066, 0.5615724599920213, 3.2698682276532054, 2.7339274110272527, 2.316655176691711, 4.824770679697394, 2.5570298032835126, 6.981418104842305, 7.039483264088631, 8.814315777271986, 6.18201082572341, 9.157904740422964, 9.631220642477274, 7.903583021834493, 8.35837159305811, 6.252614362165332, 2.204353390261531, 2.2466301592066884, 1.6329693817533553, 0.1735702034784481, 0.09029813940287568, 0.03643451193056535, 0.12173855779110454, 0.06661421808530577, 0.0732891091320198, 0.44686617446132004, 3.1666762148961425, 3.418214642442763, 2.4962755758315325, 5.156670045107603, 6.769416555762291, 5.808393023908138, 6.376732802018523, 7.402720497921109, 1.2948549748398364, 6.746803969144821, 5.660000536590815, 7.584338402375579, 5.938390698283911, 5.464906180277467, 4.175175586715341, 4.2331471759825945, 5.675234394147992, 4.707054421305656, 3.261268101632595, 2.7555349515751004, 4.692608546465635, 3.3489491092041135, 1.7084659868851304, 0.3110091551207006, 0.25751108361873776, 0.5896237422712147, 0.32455501263029873, 0.19976402370957658, 0.0597271767037455, 0.5931953724939376, 2.4218900548294187, 7.4510458298027515, 20.196944139897823, 34.2432951182127, 43.37009757757187, 35.8112657815218, 25.545314848423004, 24.206247702240944, 17.305358201265335, 19.45951011031866, 29.4936715811491, 37.179530560970306, 39.32093225419521, 48.03156964480877, 56.80760532617569, 48.43741066753864, 49.097093269228935, 34.28176425397396, 8.53506401181221, 1.89535052748397, 0.15019926067907363, 0.044028333941241726, 0.004767201371578267, 0.09388198537635617, 0.04254160063283052, 0.06370794551912695, 0.013941399029135937, 0.04617784594302066, 0.016014350148907397, 0.04230802078382112, 0.02505328768165782, 0.02190571878600167, 0.00927572995351511, 0.012200567343825242, 0.08179703072528355, 0.03374136191268917, 0.035045493495999835, 0.030952665947552305, 0.07367405371041968, 0.04679352423409, 0.012635133771254914, 0.060985647651250474, 0.02800159178150352, 0.05363805539673194, 0.03339062292070594, 0.05109615878609475, 0.03407994823646732, 0.04992699046852067, 0.02631961240695091, 0.05608192914223764, 0.028284127402002923, 0.05863960010174196, 0.03615031389927026, 0.0935239288082812, 0.05225679982686415, 0.013648903786815936, 0.029090337266097777, 0.07063389028189704, 0.014834491194051225, 0.0509243144915672, 0.0358904100721702, 0.013328456479939632, 0.013712382460653316, 0.07441040521371178, 0.0625349217443727, 0.02426548679068219, 0.10186995088588446, 0.021585066460829694, 0.05273509545077104, 0.09219455678248778, 0.0360626625479199, 0.03319755691336468, 0.029870397556805983, 0.06986666543525644, 0.06125884705397766, 0.05010438231693115, 0.056180683022830635, 0.046842209121678025, 0.08425865293247625, 0.018147371629311237, 0.01485636970755877, 0.04058853141032159, 0.025462422563578002, 0.047589165915269405, 0.03127664494968485, 0.06259752932237461, 0.05835727228259202, 0.05677528060914483, 0.035304547564010136, 0.023917308208183385, 0.07065943500492722, 0.0534388555388432, 0.03969815457821824, 0.060148735137772746, 0.5927481246180832, 10.793581120669842, 26.06374192982912, 47.696807608008385, 70.95991551876068, 69.31688368320465, 64.20515477657318, 65.38059890270233, 56.54442384839058, 46.7403419315815, 34.93664771318436, 27.999690547585487, 31.141437962651253, 45.98189502954483, 57.019896134734154, 66.20092928409576, 54.347955510020256, 31.784741543233395, 13.985226508229971, 7.43167731910944, 2.2312177112326026, 0.5841206875629723, 0.32313661999069154, 0.8284911559894681, 0.5010909272823483, 1.6461533680558205, 2.948815142735839, 4.397040456533432, 4.257461121305823, 5.120506910607219, 7.798375217244029, 7.035978427156806, 8.800353426486254, 10.830595884472132, 9.862195998430252, 9.41061682999134, 6.3749464228749275, 6.768525503575802, 12.204333320260048, 7.592050563544035, 8.143330682069063, 6.390257701277733, 6.829193998128176, 4.8784171510487795, 0.7688291918020695, 0.8334681764245033, 0.31609295576345176, 0.0941748294280842, 0.0498355356103275, 0.12792662222636864, 0.19552260520868003, 0.974841668503359, 2.1767737576738, 2.110161194577813, 2.713001696392894, 6.353222513571382, 6.1402349174022675, 6.160274092108011, 4.98801039531827, 5.902997497469187, 5.598716950044036, 9.134715534746647, 9.000052660703659, 7.691065650433302, 10.947958286851645, 8.97459402680397, 8.507264703512192, 9.459379613399506, 6.752900741994381, 9.14855059236288, 8.39730715379119, 7.544496115297079, 5.771199194714427, 3.631155928596854, 4.679902978241444, 2.4038381734862924, 1.6132867941632867, 0.8418531389907002, 0.757465367205441, 0.22810161171946675, 0.3369614656548947, 0.5113379086833447, 3.08591416105628, 7.970947232097387, 21.015661507844925, 33.208249658346176, 40.97054913640022, 37.422257736325264, 27.57204059511423, 31.27417054027319, 27.30337981134653, 25.63898552209139, 32.95694634318352, 40.901993215084076, 47.998971194028854, 56.44703887403011, 66.59066677093506, 56.73488102853298, 55.69555699825287, 39.48248818516731, 11.214606128633022, 2.357305157929659, 0.1354127994272858, 0.04151073895627633, 0.008209785100916633, 0.06672921386780217, 0.037461963438545354, 0.047364321144414134, 0.04767801954585593, 0.040068245070870034, 0.04567799835058395, 0.03685498311824631, 0.0184332357821404, 0.0773872560239397, 0.009085527708521113, 0.031452641560463235, 0.040540759364375845, 0.08452021545963362, 0.027462740617920645, 0.06770362408133224, 0.010605480474623619, 0.06730035587679595, 0.017401528057234827, 0.06979707424761727, 0.04111759735678788, 0.0167489297746215, 0.03936335320759099, 0.047529493531328626, 0.03817343444097787, 0.06631989715970121, 0.054702721899957396, 0.02083302038954571, 0.03384452415048145, 0.05109958008688409, 0.053110611042939126, 0.0745152855233755, 0.007253721705637872, 0.007745255852569244, 0.032867579502635635, 0.008580652065575123, 0.1156462229846511, 0.0944993706070818, 0.11489577809697948, 0.18340646551223472, 0.12828349135816097, 0.20603794720955193, 0.19574823294533417, 0.09347213432192802, 0.1376050739781931, 0.19341552921105176, 0.11868016721564345, 0.14447722787735984, 0.1277992845280096, 0.19736050424398854, 0.21318613551557064, 0.20815116818994284, 0.20203637599479407, 0.16339862428139895, 0.10313720515114255, 0.11712026185705326, 0.11908550601219758, 0.17196717933984473, 0.15096520161023363, 0.0910459051374346, 0.12712171854218468, 0.2239727770211175, 0.1283214002614841, 0.1658986377879046, 0.1405196957057342, 0.13825985603034496, 0.29506948543712497, 0.14893410669174045, 0.15681466116802767, 0.21023384237196296, 0.07140432120650075, 0.21140616852790117, 1.4670998509973288, 15.496640056371689, 33.029970824718475, 62.24962390959263, 84.55068424344063, 80.27367174625397, 74.5980454981327, 76.23442009091377, 62.53270871937275, 51.08164317905903, 43.24472330510616, 34.25365336239338, 30.25076575577259, 39.95014429092407, 52.99224145710468, 72.3484218120575, 72.29462429881096, 44.5109673589468, 17.620788775384426, 8.71485136449337, 2.5618201587349176, 0.6689183623529971, 0.33197960641700774, 1.1706898687407374, 1.0177490254864097, 1.3585400325246155, 4.385569347068667, 5.468162605538964, 9.038207363337278, 10.011193603277206, 12.18157634139061, 13.085609581321478, 15.685424376279116, 17.57087465375662, 17.30251595377922, 19.89114984869957, 17.633073516190052, 16.583841517567635, 22.587903141975403, 23.177354112267494, 18.568767607212067, 19.80247400701046, 11.236811187118292, 12.73495964705944, 4.281644448637962, 1.176760874222964, 0.5374127032700926, 0.27971014555078, 0.3159428638173267, 0.6835302407853305, 0.48762830905616283, 1.8538843025453389, 8.631571233272552, 11.887467373162508, 9.273647479712963, 11.327783055603504, 17.298315279185772, 14.970385394990444, 15.294968727976084, 18.80521561950445, 10.915751215070486, 16.857774518430233, 15.39384227246046, 16.31164312362671, 20.67039303481579, 13.7498414888978, 17.378677166998386, 16.880105920135975, 15.951781533658504, 16.314407475292683, 12.259174827486277, 9.973918553441763, 10.918558314442635, 7.483758274465799, 4.4541095942258835, 2.527739549987018, 1.5761116077192128, 1.6638238448649645, 0.6621609593275934, 0.4415417695418, 0.4024646070320159, 0.9010013588704169, 3.1306242244318128, 9.132693093270063, 24.989807456731796, 42.422200441360474, 56.20789870619774, 51.06281898915768, 37.36237674951553, 36.6085048019886, 27.35685434192419, 30.946557819843292, 40.34363977611065, 50.31697601079941, 53.37011218070984, 62.94208735227585, 73.58158484101295, 65.7958634197712, 67.00526252388954, 49.03657391667366, 15.691633243113756, 3.185163647867739, 0.33686593640595675, 0.11513690929859877, 0.05265482475806493, 0.14218468917533755, 0.09929805295541883, 0.21025438501965255, 0.15045944281155244, 0.10816069145221263, 0.09088357517612167, 0.1026048106723465, 0.05619397859845776, 0.1585739667643793, 0.10076196893351153, 0.14192835136782378, 0.13193773746024817, 0.1031068067823071, 0.17248181422473863, 0.1464491884689778, 0.09393806947628036, 0.12487033935030922, 0.1253352503408678, 0.16948828735621646, 0.08833581930957735, 0.09199826614349149, 0.11825959954876453, 0.11038520489819348, 0.19395685172639787, 0.12024487426970154, 0.16838251700391993, 0.2047116550966166, 0.12831299914978445, 0.17484585143392906, 0.10623241367284209, 0.2409828908275813, 0.14864719239994884, 0.09500855070655234, 0.10995120435836725, 0.1922243376611732], [0.01970316363440361, 0.016281159660138655, 0.05718898341001477, 0.0541820236685453, 0.07425828720442951, 0.011708172769431258, 0.09761763023561798, 0.0353983290551696, 0.036441599440877326, 0.02315646954230033, 0.057027477232622914, 0.06068236529245041, 0.02289980333443964, 0.023960100443218835, 0.018091092715621926, 0.05437173145764973, 0.04249254096066579, 0.024076478475762997, 0.009374544133606832, 0.03155232312565204, 0.04715129507530946, 0.006518704676636844, 0.012545821864478057, 0.05020195989345666, 0.053652241549571045, 0.022139510147098918, 0.046411537114181556, 0.10595209707389586, 0.05188102448300924, 0.04670983224059455, 0.040562645299360156, 0.05601243443379644, 0.10284783435054123, 0.018357764929533005, 0.05682906034053303, 0.3572004858870059, 2.7183111989870667, 10.905602909624577, 27.781527154147625, 57.32806719839573, 61.70789837837219, 55.50976976752281, 49.529855847358704, 40.18396854400635, 34.15319815278053, 33.76459300518036, 33.261971175670624, 21.26940429210663, 26.154036484658718, 30.730440616607666, 28.679956644773483, 30.14996476471424, 23.599785044789314, 10.514514595270157, 5.175191201269627, 1.9632439780980349, 0.1598097020178102, 0.22438003798015416, 0.16243073012446985, 0.2713777864119038, 1.2740261550061405, 1.5189921227283776, 2.766087935306132, 4.350905232131481, 4.181739259511232, 5.237277969717979, 7.774355756118894, 7.696815216913819, 7.260365411639214, 11.561515163630247, 3.60941207036376, 4.58739741705358, 4.951265892013907, 6.427435856312513, 8.36346996948123, 5.328133944422007, 4.409604482352734, 2.7294503012672067, 4.415883170440793, 3.184206811711192, 0.9517029288690537, 0.15333535411627963, 0.07635083195054904, 0.05609499094134662, 0.05580706361797638, 0.6843753985594958, 1.2892189272679389, 3.2980703143402934, 5.046264119446278, 1.578079427126795, 1.522520233411342, 5.19256766885519, 4.185240296646953, 3.1842217734083533, 1.222205723170191, 1.06258780695498, 3.224623817950487, 2.3679063515737653, 3.8680280931293964, 5.393017837777734, 6.578947976231575, 8.591255396604538, 3.3492889534682035, 7.313250498846173, 4.527363013476133, 3.247466767206788, 5.953125357627869, 0.8431174024008214, 2.9214677726849914, 3.2014393620193005, 3.292845357209444, 2.7199420239776373, 1.3847026973962784, 0.4005883389618248, 1.1043244111351669, 0.2907694224268198, 0.5161577125545591, 0.10217967137577944, 0.8068426488898695, 1.763681536540389, 6.00179742090404, 14.061722103506327, 34.65809226036072, 38.984049931168556, 41.352713629603386, 28.488505817949772, 29.475827738642693, 28.399506993591785, 29.842777848243713, 34.96116399765015, 37.30499982833862, 42.82761588692665, 45.73431171476841, 55.16334615647793, 53.263923078775406, 46.75530172884464, 20.706964172422886, 3.826466160826385, 0.5235251015983522, 0.03594293557398487, 0.015788319797138683, 0.08920507461880334, 0.013632876180054154, 0.020069649144716095, 0.06393818199285306, 0.07231205687276088, 0.020756978083227295, 0.02805216357955942, 0.041659027483547106, 0.07100896429619752, 0.0354409765714081, 0.040863675239961594, 0.02645573898917064, 0.02588984767498914, 0.018215044365206268, 0.05371712752094027, 0.050507587438914925, 0.035725649577216245, 0.10573370527708903, 0.06878636559122242, 0.024022160687309224, 0.012792290035577025, 0.02546665651607327, 0.11192433754331432, 0.01247476215212373, 0.04002607623988297, 0.06734316295478493, 0.05158055486390367, 0.042697525859694, 0.08923057481297292, 0.10506255886866711, 0.0729521740868222, 0.034163718155468814, 0.05453238416521344, 0.04596856771968305, 0.019268376418040134, 0.03572882596927229, 0.026218186794721987, 0.043611532673821785, 0.034946090236189775, 0.022761619147786405, 0.03464094508672133, 0.06010025063005742, 0.020295753711252473, 0.04211646504700184, 0.022138907152111642, 0.05977928660286125, 0.03152789533487521, 0.06968011919525452, 0.02052858213573927, 0.0404394710494671, 0.004588191177390399, 0.046011467566131614, 0.024309503569384106, 0.018161286898248363, 0.022832824506622273, 0.03987491189036518, 0.03380871181434486, 0.04605996691680048, 0.058457851846469566, 0.014682625514979009, 0.032211027428274974, 0.062895605515223, 0.011872168852278264, 0.036741345465998165, 0.03773699594603386, 0.06091888775699772, 0.07336239621508867, 0.029358464089455083, 0.006936807485544705, 0.03996564315457363, 0.29316100815776736, 2.7660525497049093, 14.095523189753294, 31.86149552464485, 64.68573778867722, 75.51196485757828, 68.29974666237831, 60.29030844569206, 52.30562210083008, 40.267009288072586, 37.77452923357487, 36.534176990389824, 28.176191076636314, 25.5971497669816, 32.01128348708153, 23.445243537425995, 32.78919294476509, 34.22861270606518, 15.153538417071104, 5.286103924736381, 1.933881409931928, 0.26747744414024055, 0.26486627175472677, 0.674516768194735, 0.5819204868748784, 2.154851546511054, 3.2539230957627296, 4.520965106785297, 6.069049062207341, 7.668365193530917, 7.177720796316862, 7.653550263494253, 8.501571658998728, 10.860639922320843, 8.247588537633419, 9.3504480086267, 9.540360867977142, 8.850297946482897, 6.47488771006465, 7.213636469095945, 9.05065169557929, 7.998592648655176, 7.537405695766211, 6.966688670217991, 3.868619198910892, 1.2090318300761282, 0.7983546168543398, 0.10289913159795105, 0.09171934478217736, 0.014016651875863317, 0.2114336725207977, 0.7317488815169781, 2.0777387218549848, 2.8512596525251865, 0.9632464125752449, 2.191826649941504, 3.7781268171966076, 6.824032925069332, 6.814692076295614, 5.7127906288951635, 5.878250375390053, 5.612545358017087, 6.8071328569203615, 7.761840652674437, 10.584248453378677, 10.933197978883982, 10.212918128818274, 8.805302660912275, 8.976726662367582, 9.122161008417606, 8.290210850536823, 11.115446649491787, 5.523454388603568, 9.753911308944225, 9.877918604761362, 5.878632254898548, 6.613657688722014, 4.777001067996025, 2.0072211557999253, 2.3715299321338534, 0.795413990272209, 0.9618940413929522, 0.31598623492754996, 0.5269651638809592, 1.999776167795062, 6.568509936332703, 16.44346185028553, 33.24115589261055, 36.00260071456432, 42.96670362353325, 27.75563344359398, 26.85783851891756, 31.90273091197014, 31.99707604944706, 44.941883236169815, 44.238863959908485, 49.44786384701729, 52.5033824890852, 60.77227458357811, 62.3445238173008, 53.23003649711609, 23.919435292482376, 4.5960182044655085, 0.49072407418861985, 0.10229825173155405, 0.01811209920560941, 0.07694892134168185, 0.1302957208827138, 0.022562202211702242, 0.04407515974889975, 0.02700894885492744, 0.03659719070128631, 0.012969974104635185, 0.09918565468979068, 0.01736950067424914, 0.044640160485869274, 0.04391696726088412, 0.047998827722040005, 0.06394480937160552, 0.030881204547767993, 0.039015619913698174, 0.07804060573107563, 0.021293111130944453, 0.02336043027753476, 0.04955519674695097, 0.0066599029105418595, 0.06509507147711702, 0.007908436964498833, 0.03710307937581092, 0.021675486023013946, 0.019492360297590494, 0.034057383236358874, 0.03902908989402931, 0.06150118053483311, 0.02924325679487083, 0.09832362047745846, 0.02847351977834478, 0.0477981806761818, 0.05810203656437807, 0.059635688448906876, 0.07012830959865823, 0.13911740767071024, 0.09927585531841032, 0.22289206157438457, 0.10214640831691213, 0.1702489738818258, 0.15524243615800515, 0.1531421730760485, 0.09272553375922143, 0.13163167575839907, 0.09069748906767927, 0.12199019780382514, 0.14309812453575432, 0.13299333862960339, 0.12266098798136227, 0.23533894680440426, 0.15231132390908897, 0.08715720716281794, 0.13613951043225825, 0.11021753889508545, 0.11097272610641085, 0.15990762098226696, 0.09994815205573104, 0.11415950080845505, 0.21737432718509808, 0.16262404475128278, 0.08484455625875853, 0.10703696112614125, 0.18536632909672335, 0.19057760102441534, 0.19518210785463452, 0.2571205951971933, 0.19857225328451023, 0.1968191668856889, 0.15749037178466097, 0.1392822980415076, 0.6440511310938746, 4.7059534303843975, 17.60575868189335, 44.24349591135979, 78.03927004337311, 82.55287304520607, 78.41538146138191, 69.63910639286041, 57.316504418849945, 47.55336910486221, 47.87830486893654, 47.12424673140049, 35.81114038825035, 42.25221276283264, 47.924985364079475, 42.676824778318405, 41.16864770650864, 30.55537451058626, 14.501906633377075, 6.727135274559259, 2.4604871962219477, 0.612106304615736, 0.49211367149837315, 0.7904522283934057, 0.742644559359178, 3.0785135831683874, 5.576790226623416, 6.752607682719827, 12.885906547307968, 13.375400081276894, 14.67349212616682, 15.995173305273056, 18.885011337697506, 15.304854847490788, 26.832845360040665, 15.287087950855494, 17.079764306545258, 14.922934491187334, 15.96415176987648, 19.119852036237717, 16.61232478916645, 13.802054487168789, 10.675902385264635, 14.234650824218988, 9.85381554812193, 2.1224100748077035, 1.0866903886198997, 0.4212298704078421, 0.1398375877761282, 0.20197642530547455, 0.8269715344067663, 0.7103055040352046, 4.079190362244844, 6.08778728172183, 4.075643727555871, 6.379118598997593, 14.31611655279994, 16.308173909783363, 12.518007438629866, 8.526720609515905, 9.209320731461048, 9.775018226355314, 10.306154675781727, 11.973282918334007, 17.23520826548338, 20.028368085622787, 18.086934462189674, 14.38224820420146, 21.673292219638824, 14.434830732643604, 14.228842835873365, 18.504887335002422, 13.232678789645433, 13.092863392084837, 15.240506250411272, 12.677027005702257, 8.010063283145428, 5.096851279959083, 3.206107411533594, 3.567885048687458, 1.1026032222434878, 1.0707031027413905, 0.3447527694515884, 1.2090408545918763, 2.9406567430123687, 8.42758297920227, 18.809036314487457, 42.37608231604099, 52.25961036980152, 54.10979948937893, 40.608918741345406, 42.47233495116234, 41.00605443120003, 42.54662476480007, 48.53637255728245, 49.48694095015526, 57.63209268450737, 61.474731490015984, 71.69963702559471, 71.35176569223404, 65.53426265716553, 32.35445447266102, 7.390988627448678, 1.2358884327113628, 0.15503128030104563, 0.1398798159789294, 0.16187544038984925, 0.15212207625154406, 0.14921218942617998, 0.11525043562869541, 0.1392174937063828, 0.09853675786871463, 0.11232464457862079, 0.18633181869518012, 0.13368540618102998, 0.17465615848777816, 0.11527363516506739, 0.1138006427208893, 0.12844676384702325, 0.14311707898741588, 0.18927292025182396, 0.15177590888924897, 0.1337030841386877, 0.09826606692513451, 0.18611315230373293, 0.1421843923162669, 0.1609970343997702, 0.11216189901460893, 0.21494048356544226, 0.13211021258030087, 0.12066106326528825, 0.13029208435909823, 0.11770791665185243, 0.23979226330993697, 0.20105783944018185, 0.2407781916554086, 0.12235299669555388, 0.10367458686232567, 0.12518367409938946, 0.16970115015283227, 0.13488372234860435], [0.018240045465063304, 0.07795665398589335, 0.07517668753280304, 0.02492090152372839, 0.07313870548387058, 0.03588817620766349, 0.0876309274462983, 0.0743165829044301, 0.06460598873673007, 0.018415659869788215, 0.059429501270642504, 0.011159855512232753, 0.06787146077840589, 0.0501757472375175, 0.05137577034474816, 0.05638578295474872, 0.11050142522435635, 0.11201715053175576, 0.05415672014351003, 0.03427316638408229, 0.06760731557733379, 0.039357070927508175, 0.04746690079628024, 0.07196316582849249, 0.0445499227498658, 0.018433113327773754, 0.048258122988045216, 0.02964366587548284, 0.1051730869221501, 0.05756679965998046, 0.040031764801824465, 0.060547034663613886, 0.03565246639482211, 0.047550388699164614, 0.04435607377672568, 0.7336161844432354, 3.9054237864911556, 14.957059510052204, 40.61219036579132, 51.177698224782944, 44.11641553044319, 47.13929012417793, 42.511564046144485, 46.187342405319214, 42.79883623123169, 32.06247813999653, 26.168236322700977, 25.478043258190155, 39.349103942513466, 44.49201017618179, 49.425779432058334, 27.607937268912792, 12.934036664664745, 7.589178392663598, 0.7381659059319645, 0.4689433757448569, 0.0534647713357117, 0.04445098704309203, 0.30670306587126106, 0.8188408613204956, 0.34246164083015174, 3.303483836352825, 2.7412828663364053, 3.180930675007403, 4.229776281863451, 3.114701178856194, 3.932876600883901, 2.811217401176691, 8.270177375525236, 4.605850176885724, 8.0773757211864, 7.91453973390162, 4.037426803261042, 2.8756683552637696, 4.428130863234401, 2.560433470644057, 5.522384746000171, 5.195541009306908, 5.01051421277225, 2.9048966243863106, 0.45830961666069925, 0.7153832784388214, 0.1600933657027781, 0.40582015353720635, 1.50042952504009, 4.205812867730856, 10.130767486989498, 12.607225701212883, 8.913951180875301, 3.0361446691676974, 1.831075195223093, 2.873173551633954, 2.288498687557876, 3.6133427219465375, 4.027165453881025, 3.9114141650497913, 3.780539925210178, 6.713896784931421, 8.649313431233168, 5.252491403371096, 8.101302087306976, 7.038748953491449, 5.284121381118894, 7.13110632263124, 5.556722553446889, 7.167726857587695, 7.624947298318148, 8.338581304997206, 8.218474499881268, 5.122837610542774, 5.830624205991626, 4.535749163478613, 4.440899603068829, 2.4653262365609407, 1.4263101085089147, 0.27895532199181616, 0.16667099087499082, 0.13666146289324388, 0.11808828960056417, 0.28489873744547367, 2.328824973665178, 6.941527845337987, 19.17398203164339, 33.293828666210175, 31.803263649344444, 47.417161613702774, 46.531018763780594, 25.228856429457664, 23.275799229741096, 22.169726081192493, 28.08467298746109, 36.107589080929756, 46.83893524110317, 50.62065951526165, 51.80894315242767, 46.91762521862984, 30.986641868948936, 14.358084350824356, 2.4579786183312535, 0.057292602068628184, 0.12400294683175161, 0.14471277070697397, 0.03940034926927183, 0.023789976075931918, 0.08339016945683397, 0.04067685440531932, 0.024499120445398148, 0.10286321165040135, 0.010204450773017015, 0.01014536654110998, 0.003573068133846391, 0.0300531811080873, 0.04638597012672108, 0.0618753454182297, 0.02561206551035866, 0.0259983255455154, 0.016216928634094074, 0.07600023396662436, 0.06921787251485512, 0.04413131806359161, 0.009203060708387056, 0.01476342869864311, 0.03999502107035369, 0.027943565110035706, 0.06311026430921629, 0.043753316276706755, 0.13414104032563046, 0.057706316001713276, 0.02673034105100669, 0.07504020657506771, 0.11398371570976451, 0.0316763805312803, 0.040463598270434886, 0.11256784637225792, 0.051892182673327625, 0.040901383763412014, 0.06591129291336983, 0.050059998175129294, 0.019086177308054175, 0.05651896877679974, 0.004526085012912517, 0.03851599867630284, 0.07687458783038892, 0.016775717595010065, 0.03568412641470786, 0.029735875868937, 0.004296820288800518, 0.022490952324005775, 0.06412926275515929, 0.04711026915174443, 0.019771235274674837, 0.02639150796312606, 0.07341390126384795, 0.024848807443049736, 0.007522532696384587, 0.08129379522870295, 0.04691228270530701, 0.042099176716874354, 0.04414436873048544, 0.11320318415528163, 0.04798130190465599, 0.037462137843249366, 0.05106969008920714, 0.028169070392323192, 0.01630782131542219, 0.10052357625681907, 0.05662453557306435, 0.053353838811744936, 0.0665533693972975, 0.05169771029613912, 0.030606685977545567, 0.937133738771081, 4.776767380535603, 16.27379335463047, 48.13268221914768, 63.513576686382294, 59.52450133860111, 58.41952823102474, 50.69596007466316, 49.18231509625912, 47.052031606435776, 38.81096921861172, 34.818489253520966, 30.86033284664154, 41.4623187482357, 44.38598446547985, 42.78123177587986, 28.32996502518654, 12.03961880877614, 6.234506908804178, 1.5001098671928048, 0.4792683123378083, 0.354019136284478, 0.3810406441334635, 1.8082206090912223, 2.3643419053405523, 3.9224380860105157, 7.288175644353032, 8.503292966634035, 9.663548357784748, 8.398638982325792, 7.620961787179112, 8.35562339052558, 9.922231826931238, 10.314117148518562, 7.724641123786569, 8.513037543743849, 8.33487555384636, 7.851421320810914, 7.144841635599732, 5.803278498351574, 7.0628672093153, 4.052170962095261, 8.255260325968266, 5.160698303952813, 4.670051531866193, 1.8443878996185958, 1.6362769855186343, 0.12902173533802852, 0.3161795198684558, 1.536357190925628, 3.3404541900381446, 8.47941979765892, 9.523048996925354, 6.748425532132387, 2.465694104321301, 1.9415866839699447, 1.5734716993756592, 3.641252461820841, 5.316426297649741, 4.8097633849829435, 4.463819498196244, 7.3158167861402035, 10.429508406668901, 8.237087801098824, 8.14620902761817, 6.79005229845643, 10.23190001025796, 8.362861052155495, 8.957315403968096, 10.382726266980171, 9.658268541097641, 10.278647001832724, 9.540308620780706, 10.45695623382926, 8.376872800290585, 9.132971428334713, 8.912537656724453, 7.027768492698669, 4.035771992057562, 3.921449426561594, 2.17672246042639, 1.857139659114182, 0.583197099622339, 0.28625888633541763, 0.5194393708370626, 2.6641325186938047, 7.740363730117679, 20.39470072835684, 32.69773185253143, 31.315865702927113, 36.443358063697815, 40.23506440222263, 29.139663577079773, 31.624775826931, 30.887123309075832, 35.62179654836655, 42.93766178190708, 53.42927120625973, 57.69123271107674, 60.17262116074562, 57.23439462482929, 37.09999322891235, 16.190779209136963, 2.878195932134986, 0.039772781237843446, 0.12410884388373233, 0.043946233854512684, 0.0614029610005673, 0.052105954600847326, 0.03710554330609739, 0.08752293011639267, 0.05100464084534906, 0.06181231110531371, 0.01328407790424535, 0.06824714335380122, 0.007365632936853217, 0.030415028195420746, 0.026282467915734742, 0.024450203636661172, 0.024265817046398297, 0.011190845743840327, 0.058387114040669985, 0.031682718472438864, 0.01852810637501534, 0.031027557924971916, 0.009535777571727522, 0.03148643525491934, 0.023890833945188206, 0.025362104606756475, 0.04144022008404136, 0.05262257102003787, 0.012891016085632145, 0.054392864112742245, 0.03639013149950188, 0.06786237689084373, 0.05624882331176195, 0.04252460174029693, 0.0434677601151634, 0.02883959525206592, 0.04796330482349731, 0.05836030024511274, 0.17257400380913168, 0.2461354885599576, 0.11794014950282872, 0.09721192036522552, 0.10858445035410114, 0.11382602417143062, 0.19671881367685273, 0.1650554095976986, 0.159623482322786, 0.09826669775065966, 0.14591622253647074, 0.09846106622717343, 0.13551435491535813, 0.20549932611174881, 0.09705170552479103, 0.08576528693083674, 0.3072033921489492, 0.21218055509962142, 0.090792008995777, 0.18562131619546562, 0.1336536422604695, 0.20131178753217682, 0.10717993587604724, 0.2523278055014089, 0.1430929295020178, 0.29788112675305456, 0.19328945316374302, 0.1159647898748517, 0.17000728606944904, 0.20183728745905682, 0.13851822732249275, 0.18270571483299136, 0.14872133295284584, 0.1804566362989135, 0.16590766230365261, 1.1390446918085217, 7.019665902480483, 25.358207188546658, 59.29288476705551, 71.68572217226028, 69.67180743813515, 69.46626126766205, 60.11367492377758, 60.54122798144817, 57.82292604446411, 46.57532058656216, 37.69569106400013, 42.22521521151066, 56.46948426961899, 59.33585666120052, 64.90100383758545, 35.62837019562721, 18.00023451447487, 9.295215122401714, 1.4500479097478092, 0.8636938326526433, 0.24583773891208693, 0.42707704415079206, 1.6684099612757564, 3.5790666611865163, 4.816471450030804, 10.196018535643816, 11.727020982652903, 12.51071847975254, 13.655540999025106, 14.432150926440954, 18.981106281280518, 14.813457615673542, 18.43112949281931, 13.42000113800168, 21.790686920285225, 17.08798136562109, 15.617068894207478, 12.954269628971815, 14.376391768455505, 10.423429682850838, 15.884371250867844, 14.44024259224534, 12.676610928028822, 7.728524040430784, 1.725918569136411, 2.3804782144725323, 0.6066777615342289, 0.8837450004648417, 2.6248908368870616, 2.8733310056850314, 6.339997798204422, 8.135270364582539, 6.633300259709358, 3.2788274344056845, 5.115997027605772, 7.325951317325234, 8.708178922533989, 11.426426712423563, 10.000194143503904, 12.034819666296244, 10.737059153616428, 15.335812736302614, 19.93929896503687, 15.670647919178009, 16.50532443076372, 19.11103080958128, 14.706925582140684, 18.58610987663269, 17.58737336844206, 17.361068911850452, 17.32707403600216, 15.589294284582138, 16.705079711973667, 12.914701402187347, 15.096277389675379, 13.977976497262716, 11.445534937083721, 5.915035726502538, 4.321294371038675, 2.2246884740889072, 2.318009091541171, 0.3396893333410844, 0.38021068554371595, 0.631814778316766, 3.0980858579277992, 9.943054709583521, 24.385314993560314, 40.86083382368088, 43.46035413444042, 63.952369540929794, 61.98549248278141, 37.435017451643944, 34.50413592159748, 32.407248839735985, 41.426623463630676, 47.23821401596069, 59.797683879733086, 64.68753889203072, 67.87051409482956, 66.51822745800018, 46.80305756628513, 20.908953733742237, 3.5551813803613186, 0.13851093943230808, 0.13668277737451717, 0.1270259518059902, 0.16996225254843011, 0.08718715282157063, 0.20340192771982402, 0.15106196282431483, 0.1515293525881134, 0.25068748102057725, 0.13678589137271047, 0.14495517098112032, 0.15055311669129878, 0.14035327651072294, 0.08129338704748079, 0.20417419174918905, 0.07547364308265969, 0.19548776879673824, 0.14617650856962427, 0.20336251967819408, 0.14496903429972008, 0.18011786072747782, 0.13162545656086877, 0.22629531333222985, 0.13684987934539095, 0.1310789241688326, 0.12126143104978837, 0.12317831686232239, 0.19722470606211573, 0.08067395348916762, 0.10869887468288653, 0.13916063035139814, 0.20138833264354616, 0.1482037443201989, 0.1439377458882518, 0.22768746362999082, 0.15453557018190622, 0.20180565712507814], [0.03406146504858043, 0.029710770868405234, 0.04623157001333311, 0.05834368355863262, 0.0626812806876842, 0.03683173534227535, 0.03653931060398463, 0.028180308363516815, 0.046594999730587006, 0.05394084051658865, 0.022890340951562393, 0.10109635841217823, 0.013713730386371026, 0.12205221166368574, 0.006705506957587204, 0.06314369806204922, 0.03014245034137275, 0.052945130664738826, 0.07656006564502604, 0.06590006421902217, 0.023260195812326856, 0.028469350763771217, 0.017853809549706057, 0.11944987825700082, 0.035300654999446124, 0.032754847270553, 0.06441737932618707, 0.055213126543094404, 0.1158184977248311, 0.020716948492918164, 0.02562505495006917, 0.041245473112212494, 0.05215506622334942, 0.022600166776101105, 0.2598356385715306, 1.9632169045507908, 8.913349863141775, 24.401340633630753, 33.600590005517006, 44.684602841734886, 52.54158943891525, 54.78723093867302, 46.09083518385887, 38.94393548369408, 27.065647467970848, 19.74358856678009, 20.439374931156635, 33.89676131308079, 33.20892222225666, 39.12208132445812, 25.46412270516157, 10.065938215702772, 8.098159655928612, 1.5069550811313093, 0.23660781153012067, 0.02978744585561799, 0.16691190685378388, 0.25207767204847187, 1.726264706812799, 0.0795304894563742, 2.947115683928132, 3.7114420579746366, 5.69023028947413, 6.653850981965661, 7.733454275876284, 4.357204344123602, 4.031398426741362, 7.920348197221756, 9.639681838452816, 4.832564536482096, 4.524114187806845, 5.533537622541189, 5.1004463620483875, 4.901469089090824, 1.177763189189136, 6.234239973127842, 1.6520149097777903, 7.242086967453361, 3.9825002755969763, 3.8821115624159575, 2.136062504723668, 2.4788143252953887, 0.3317770001012832, 3.0498108733445406, 8.960738070309162, 16.01614248007536, 35.44043608009815, 31.327004805207253, 22.935240603983402, 10.402540303766727, 3.043835456483066, 1.955101490020752, 4.186617247760296, 4.48256341740489, 4.245129832997918, 3.5019058641046286, 4.926833678036928, 6.124499961733818, 5.018546981737018, 8.02522636950016, 5.018883738666773, 7.025044988840818, 6.352738039568067, 3.4890604158863425, 8.28860068693757, 5.8679192047566175, 8.974351789802313, 4.2744547594338655, 7.086518090218306, 6.790470751002431, 4.469084590673447, 11.12638721242547, 6.6060452722013, 3.2059827307239175, 3.573177452199161, 1.4413416269235313, 2.446715785190463, 1.5368720632977784, 0.12577568530105054, 0.059571789533947594, 0.3049927420215681, 1.4495945465750992, 5.933527434244752, 13.981384914368391, 35.378765389323235, 34.41261783242226, 31.017591208219528, 36.84590846300125, 24.901124015450478, 25.685261338949203, 23.16444620490074, 34.43380929529667, 40.31128451228142, 50.26036284863949, 50.0478782504797, 55.53882300853729, 52.990793734788895, 28.375486582517624, 6.175248613581061, 1.2260868586599827, 0.11530677205882967, 0.024783509579719976, 0.04257940934621729, 0.032460188667755574, 0.02269826756673865, 0.05426645038824063, 0.02224946118076332, 0.015186571617959999, 0.08437475451501086, 0.10259929651510902, 0.0503344555181684, 0.06185575643030461, 0.051472134509822354, 0.08125081003527157, 0.029567326710093766, 0.033695255988277495, 0.06992840470047668, 0.08505544494255446, 0.01492173621954862, 0.02536596748541342, 0.03921623727364931, 0.007200905838544713, 0.03998779626272153, 0.06729563581757247, 0.022315191345114727, 0.06022099063557107, 0.02467776466801297, 0.041740274100448005, 0.07587415049783885, 0.017323986612609588, 0.0279673138356884, 0.06056186648493167, 0.03958366716688033, 0.04006287934316788, 0.027632744386210106, 0.03688582677568775, 0.0815856819099281, 0.03619699869886972, 0.05997435640892945, 0.039057399117155, 0.06995650241151452, 0.04678127879742533, 0.08314988430356607, 0.03111588091996964, 0.039056130044627935, 0.07795201556291431, 0.030518409366777632, 0.028805011170334183, 0.062000404723221436, 0.040473442859365605, 0.04961794533301145, 0.006481003110820893, 0.04027639522973914, 0.04666764856665395, 0.01221516817167867, 0.04684256164182443, 0.021721512166550383, 0.04098130935744848, 0.010045813924079994, 0.03351012353959959, 0.0683112649130635, 0.026826686662388965, 0.008220776308007771, 0.0787294672045391, 0.03362617688253522, 0.025429868255741894, 0.040644982873345725, 0.05237662699073553, 0.04150690576352645, 0.03572333778720349, 0.21501636074390262, 1.5843682084232569, 9.966394007205963, 30.273912213742733, 44.92237128317356, 55.41187942028046, 59.93201047182083, 61.67676284909248, 52.604327872395515, 48.23250286281109, 37.91029214859009, 30.062499158084393, 26.558805964887142, 42.2476302087307, 41.62647753953934, 36.760280057787895, 27.281639277935028, 10.794177688658237, 7.820480531081557, 1.8780989781953394, 0.27998589794151485, 0.21253981394693255, 1.0909113683737814, 2.105307192541659, 3.02461632527411, 5.355673441663384, 7.620470663532615, 8.542637005448341, 4.893069164827466, 7.684651594609022, 13.956690039485693, 10.023954268544912, 8.967837989330292, 7.7270549442619085, 8.643707782030106, 8.709133621305227, 7.155516212806106, 7.061142576858401, 6.664550257846713, 5.540284160524607, 5.051082260906696, 8.25309444218874, 4.0772519912570715, 6.6993478406220675, 2.67374434042722, 3.8557488145306706, 2.1541910944506526, 1.8946675141341984, 0.5124837253242731, 2.869283747859299, 8.677080441266298, 16.836735047399998, 31.162903010845184, 30.25294303894043, 21.405892968177795, 9.712188597768545, 2.286190311424434, 1.830860625486821, 2.8499278239905834, 4.969054637476802, 5.5502766743302345, 6.044000806286931, 5.225131921470165, 8.077464066445827, 6.427677618339658, 14.308010637760162, 7.881816364824772, 5.941882710903883, 8.902677185833454, 8.97172898054123, 10.510517209768295, 6.820598384365439, 14.315311945974827, 7.981919143348932, 11.45562244579196, 11.465624459087849, 8.614468351006508, 9.758932739496231, 7.062597898766398, 6.6472098883241415, 5.425990568473935, 4.246547631919384, 1.9656927092000842, 2.516120010986924, 0.717114144936204, 0.09703705552965403, 0.4485667316475883, 1.6556187788955867, 7.014394160360098, 14.908063989132643, 28.172564171254635, 34.94977980852127, 31.520195938646793, 33.298836797475815, 25.711939707398415, 26.021545194089413, 25.853911489248276, 40.56381516158581, 51.201511546969414, 60.44622927904129, 57.363606691360474, 61.68766066431999, 59.76850524544716, 33.11460368335247, 7.561605172231793, 1.2096976255998015, 0.006999188708505244, 0.08581878093536943, 0.08251716630184092, 0.020257939431758132, 0.015932756577967666, 0.06059955645469017, 0.05927564292505849, 0.07471040356904268, 0.0257181128472439, 0.05519582708075177, 0.04807391822396312, 0.07874514136346988, 0.00866835258420906, 0.008735011360840872, 0.02668889210326597, 0.07056959802866913, 0.041384536743862554, 0.054131995493662544, 0.026475552476767916, 0.08724508486920968, 0.03411172699998133, 0.031939189866534434, 0.07387853023828939, 0.06211367872310802, 0.016919063418754376, 0.05327864440914709, 0.04224360607622657, 0.010126814704563003, 0.08223017037380487, 0.014559418796125101, 0.04035753423522692, 0.03601083837565966, 0.035615321903605945, 0.02305599944520509, 0.027858848952746484, 0.02100490364682628, 0.16060706548159942, 0.13375503447605297, 0.18810040113748983, 0.1774068843224086, 0.21051992545835674, 0.14061921770917252, 0.16036718850955367, 0.1003251779184211, 0.18391321878880262, 0.2698175248224288, 0.09686791265266947, 0.20996644656406716, 0.17169921949971467, 0.221200380474329, 0.1714554091449827, 0.13269460934679955, 0.17365166160743684, 0.1403743089758791, 0.1890443536103703, 0.19611194467870519, 0.14074467035243288, 0.14564521989086643, 0.0550279495655559, 0.20448101044166833, 0.1664001218159683, 0.09712370127090253, 0.23812547384295613, 0.21407602995168418, 0.34918199584353715, 0.14488980261376128, 0.17068277404177934, 0.21660452708601952, 0.10992747047566809, 0.22387476899893954, 0.5876143032219261, 3.2173773692920804, 14.469004198908806, 39.951664209365845, 55.34642793238163, 68.71195614337921, 75.12433245778084, 73.11200603842735, 60.3484833240509, 54.12270739674568, 40.193962007761, 34.296465665102005, 32.80393995344639, 48.10895249247551, 46.74328677356243, 53.078021854162216, 34.48559291660786, 13.689529225230217, 10.265470258891582, 2.212543375790119, 0.5861546471714973, 0.5131754069589078, 1.0419552703388035, 1.3932639942504466, 5.065293973311782, 5.711391353979707, 14.203663486987352, 13.467097710818052, 16.58091377466917, 18.520745784044266, 22.265769727528095, 15.673592761158943, 15.118058770895004, 17.742270156741142, 23.83897840976715, 13.311312720179558, 14.616383090615273, 16.31913062185049, 19.08064004033804, 13.038384765386581, 9.719058629125357, 15.369952004402876, 9.762434251606464, 17.50603873282671, 12.247286215424538, 11.33752953261137, 7.904881602153182, 8.110555540770292, 0.859537449432537, 4.307173378765583, 11.15536730736494, 16.02497510612011, 26.771043576300144, 24.994958080351353, 16.998513266444206, 8.92560800537467, 3.98324194829911, 4.851278532296419, 10.140843596309423, 13.4544044919312, 10.639495588839054, 9.937976282089949, 10.515738129615784, 12.71735044196248, 15.801581293344498, 18.387346342206, 13.783714771270752, 18.47054097801447, 16.08592003583908, 11.77677171304822, 18.006471879780293, 20.0858760997653, 21.574170738458633, 14.499341771006584, 18.871360570192337, 20.301261842250824, 13.930657636374235, 19.915559738874435, 13.622961547225714, 10.142141226679087, 10.295404102653265, 4.293021988123655, 4.914861945435405, 3.2970552938058972, 0.9838844113983214, 0.30441710259765387, 0.7724253425840288, 1.9770361692644656, 8.739956617355347, 18.23188528418541, 45.00024050474167, 47.82035417854786, 46.62699781358242, 49.62040118873119, 35.95892585813999, 37.11884781718254, 34.215252622962, 47.93443165719509, 55.27255989611149, 67.5233343243599, 66.66326567530632, 72.51043751835823, 69.87007319927216, 41.426536068320274, 11.165418718010187, 2.1421348163858056, 0.2874724759021774, 0.19528965989593416, 0.22107659024186432, 0.19869494513841346, 0.15476657106773928, 0.1832189247943461, 0.14079540356760845, 0.1653170760255307, 0.23167977284174412, 0.22808921785326675, 0.16261782555375248, 0.11246569716604427, 0.15640475816326216, 0.14829228253802285, 0.1280970044899732, 0.15825888054678217, 0.1748346895328723, 0.21498208836419508, 0.15417971037095413, 0.21735737653216347, 0.1170634207664989, 0.12766314495820552, 0.1496807814692147, 0.2118438872275874, 0.2438533547683619, 0.16795518837170675, 0.14854390028631315, 0.10229282663203776, 0.17515223968075588, 0.05560974881518632, 0.1570089257438667, 0.17977191600948572, 0.14882771240081638, 0.18407236493658274, 0.10377775281085633, 0.1699552169884555], [0.060983502844464965, 0.10784065510961227, 0.0353503900259966, 0.07041477860184386, 0.01913671199872624, 0.026892706264334265, 0.019177480025973637, 0.049833880621008575, 0.05907115526497364, 0.12075598395313136, 0.0443045241991058, 0.045028159001958556, 0.03916410882084165, 0.1082153209426906, 0.03487741560093127, 0.06751908906153403, 0.060759864063584246, 0.029906304516771343, 0.04513361447607167, 0.04644144566555042, 0.013000898470636457, 0.03025134195922874, 0.0736935721943155, 0.01745610003126785, 0.03908855447662063, 0.062106105106067844, 0.05737167790357489, 0.06640848732786253, 0.10748231652542017, 0.14708454109495506, 0.10857777844648808, 0.021053788914286997, 0.06454327725805342, 0.051131180734955706, 0.3662581311073154, 3.6266956804320216, 13.720884192734957, 27.968988195061684, 43.88517513871193, 58.752367570996284, 56.081000715494156, 52.69190177321434, 43.84955205023289, 36.69444099068642, 31.29897940903902, 24.0715791285038, 26.14445149898529, 24.3420847132802, 30.156868994235992, 31.581473350524902, 16.36929363012314, 10.905344523489475, 2.178400307893753, 0.1295232045231387, 0.06811439539887942, 0.07955086141009815, 1.560662230476737, 1.4676622208207846, 2.820877432823181, 6.499671405181289, 4.366254033520818, 8.209237195551395, 5.564389592036605, 9.552865996956825, 6.387696163728833, 5.811973856762052, 7.093052314594388, 5.267905276268721, 6.288310596719384, 10.486948974430561, 5.9965551272034645, 5.138811003416777, 3.6351851373910904, 1.5659511904232204, 4.307606080546975, 7.378149591386318, 2.1391788125038147, 7.224084958434105, 5.169879561290145, 8.935496974736452, 7.841275865212083, 6.308597233146429, 7.1219991613179445, 13.076965995132923, 23.019495382905006, 43.19579713046551, 61.61900594830513, 52.542904168367386, 43.669377118349075, 33.16403903067112, 10.711338333785534, 3.628538344055414, 4.21541447751224, 4.678102349862456, 7.258940963074565, 5.015967395156622, 8.74434633180499, 12.047749422490597, 4.471546383574605, 6.802936932072043, 1.662363891955465, 2.9449025401845574, 5.4959785379469395, 8.757885005325079, 9.470400922000408, 5.572797115892172, 8.817112427204847, 6.879754085093737, 11.185116861015558, 5.1832823920995, 7.64794603921473, 6.2921911384910345, 6.6743371076881886, 5.087447734549642, 4.553799144923687, 5.30996854417026, 0.8405947533901781, 0.16573117958614603, 0.3860714554321021, 0.0610255232459167, 0.07540398510172963, 0.5409035284537822, 3.2555707823485136, 7.035562824457884, 16.007591038942337, 29.186923541128635, 45.366894230246544, 34.735756292939186, 31.59402597695589, 29.560485295951366, 23.015864677727222, 16.378580331802368, 24.52200695872307, 29.322857446968555, 43.73143158853054, 53.24035294353962, 50.66506773233414, 34.894276186823845, 17.692667618393898, 4.186770664528012, 0.10986247318214737, 0.07343575009144843, 0.07960218834341504, 0.03319929353892803, 0.07721728936303407, 0.0947722137789242, 0.14976354577811435, 0.17138422233983874, 0.07144792980398051, 0.009782104734767927, 0.019828794393106364, 0.06123469014710281, 0.030045852399780415, 0.04335324301791843, 0.03202734216756653, 0.07501914442400448, 0.044956330239074305, 0.09443913790164515, 0.04638706108380575, 0.10375803394708782, 0.044713377064908855, 0.03456079684838187, 0.05762323256931268, 0.11010140020516701, 0.016283823970297817, 0.039731766446493566, 0.0628696897183545, 0.02407304975349689, 0.010854903321160236, 0.0338871605345048, 0.0489726776140742, 0.07559352219686843, 0.098660525836749, 0.04091950329893734, 0.08628190335002728, 0.05560608260566369, 0.011019722260243725, 0.01863188088464085, 0.04467166094400454, 0.01868528768682154, 0.026537208250374533, 0.06372888150508516, 0.044459948476287536, 0.019576820413931273, 0.059012655474361964, 0.06195861067681108, 0.053024191656732, 0.03137868654448539, 0.04693758251960389, 0.14985502290073782, 0.04416033603774849, 0.023311752811423503, 0.07160920591559261, 0.07265278429258615, 0.09357424642075785, 0.007630615837115329, 0.07791440351866186, 0.024658374204591382, 0.0215256631054217, 0.10247158774291165, 0.029066089446132537, 0.03930495360691566, 0.04016284663521219, 0.04971695896529127, 0.019347001398273278, 0.15735867025796324, 0.06843185648904182, 0.008759890934015857, 0.060875698472955264, 0.02687433996470645, 0.3985350241418928, 4.5497499871999025, 16.214742623269558, 33.484301045536995, 49.05859373509884, 65.118937343359, 63.7241005897522, 61.68421044945717, 49.270166382193565, 38.68955813348293, 31.776079908013344, 28.47879733890295, 27.085951678454876, 25.77455084770918, 31.337967216968536, 28.709226474165916, 20.1393411308527, 8.499728757888079, 2.108248472213745, 0.32473461236804724, 0.56857910589315, 0.5138874531257898, 2.2781884158030152, 4.357512602582574, 4.776406874880195, 7.5886449962854385, 8.151960019022226, 9.256046824157238, 11.186736524105072, 10.103955175727606, 11.21090892702341, 7.449279399588704, 8.979004640132189, 9.850128795951605, 8.27520165592432, 6.363388868048787, 6.602728525176644, 7.2635638900101185, 5.083318781107664, 5.2181982435286045, 5.599058931693435, 8.469838611781597, 2.781922873109579, 5.190782239660621, 5.362040475010872, 7.424567425623536, 6.082362597808242, 5.772821707651019, 6.609752923250198, 13.017578981816769, 23.699246607720852, 42.39660881459713, 58.44228520989418, 52.58475512266159, 43.630626797676086, 32.035909965634346, 10.421350244432688, 3.360220016911626, 3.583677476271987, 3.830031557008624, 5.144438026472926, 4.590622968971729, 6.106189219281077, 7.002317933365703, 8.229782693088055, 14.409369248896837, 8.176263514906168, 5.307727614417672, 9.890882559120655, 10.117850080132484, 11.382758505642414, 9.652142319828272, 14.093133118003607, 13.669403605163097, 7.770208278670907, 13.433024939149618, 12.42712201550603, 11.13250583410263, 7.79092856682837, 10.768736153841019, 8.803520556539297, 6.756072146818042, 4.9489047937095165, 3.3002701587975025, 1.446616337634623, 0.6001999403815717, 0.6001381936948746, 0.5492714513093233, 2.953871483914554, 6.8863448314368725, 17.613664157688618, 27.35860224813223, 40.5500029027462, 35.830678939819336, 33.60055960714817, 33.66580590605736, 27.030427157878876, 22.69372746348381, 33.40370737016201, 39.176072627305984, 49.705725610256195, 64.70577791333199, 59.93659682571888, 39.823918864130974, 20.720295757055283, 4.814183497801423, 0.15940388082526624, 0.016490122470713686, 0.035909364523831755, 0.012012745537504088, 0.0317991688643815, 0.043542794956010766, 0.04650216447771527, 0.056979623550432734, 0.038640479106106795, 0.04134218237595633, 0.039533613016828895, 0.0736289014457725, 0.05185814778087661, 0.05267904845823068, 0.03331997046188917, 0.04535160551313311, 0.06961258375667967, 0.06675452852505259, 0.04947754954628181, 0.05311332730343565, 0.07933780565508641, 0.058513598269200884, 0.023218021415232215, 0.012369430060061859, 0.05976822489174083, 0.03484344750177115, 0.0238052068016259, 0.01001036616798956, 0.053234386432450265, 0.015310232902265852, 0.04204040233162232, 0.09592105096089654, 0.033396107392036356, 0.053585221903631464, 0.02807463395583909, 0.016482214887219016, 0.14874640270136297, 0.25798181304708123, 0.1444609896861948, 0.14072524092625827, 0.16404108668211848, 0.20938681438565254, 0.15524684451520443, 0.09896715157083236, 0.1911336774355732, 0.2499194472329691, 0.14578894420992583, 0.05314455687766895, 0.10371581316576339, 0.20255461771739647, 0.11134272383060306, 0.15262551954947412, 0.2617678348906338, 0.13614955911180004, 0.20119337044889107, 0.22091502469265833, 0.2061993643292226, 0.07561361955595203, 0.16024767304770648, 0.16154279495822266, 0.13771249243291095, 0.10623615409713238, 0.1675441869883798, 0.25977653393056244, 0.38861812034156173, 0.2880530431866646, 0.231699098367244, 0.1440225139958784, 0.16087290277937427, 0.11902379643288441, 0.5941581458318979, 6.59807899966836, 22.597526125609875, 41.58634029328823, 62.050127014517784, 80.69082096219063, 75.74373722076416, 69.04510706663132, 58.59450504183769, 49.085997864603996, 43.00084099173546, 34.88140627741814, 39.52802114188671, 36.4054398983717, 43.86792026460171, 39.25901457667351, 22.946940176188946, 13.928171619772911, 3.173727449029684, 0.45264032087288797, 0.5020796461030841, 0.6589177739806473, 3.778923349454999, 5.580637045204639, 9.51775113120675, 14.339143317192793, 12.457638178020716, 20.708900168538094, 16.285209842026234, 21.74876756966114, 17.37220611423254, 19.365109875798225, 21.977000422775745, 16.734704822301865, 16.426849141716957, 21.070920042693615, 16.29225466400385, 15.672527868300676, 12.209023218601942, 11.266847625374794, 9.990702252835035, 13.893993403762579, 7.300771493464708, 12.601373065263033, 10.40603706613183, 16.243955455720425, 13.908827807754278, 11.45037967711687, 9.507485032081604, 17.917953729629517, 30.389728099107742, 43.10675270855427, 54.72546145319939, 47.99924097955227, 40.71063548326492, 31.14377673715353, 12.818730901926756, 5.55635254830122, 6.983572589233518, 11.361272558569908, 12.526827715337276, 10.528052318841219, 18.348675817251205, 21.98801603168249, 8.97074293345213, 15.165665466338396, 8.668109122663736, 15.035439804196358, 18.5915207862854, 21.22332226485014, 19.686190746724606, 12.362889312207699, 15.334422010928392, 16.669200137257576, 23.88427197933197, 18.76466229557991, 21.091163456439972, 20.265604555606842, 22.361030615866184, 15.879744049161673, 14.327792376279831, 12.438486255705357, 5.160852670669556, 3.725168821401894, 0.9097760973963886, 0.4254386789398268, 0.9151043614838272, 0.870006006443873, 4.1901211347430944, 8.993690852075815, 20.328094102442265, 37.807370871305466, 59.315064176917076, 47.6220428198576, 47.61462941765785, 42.13508404791355, 34.21250157058239, 27.03114341944456, 37.35134594142437, 41.222205832600594, 59.02731701731682, 68.58848556876183, 69.25075963139534, 51.257216557860374, 28.180220760405064, 7.120346250012517, 0.5600711842998862, 0.2630531456088647, 0.14726800000062212, 0.14246591861592606, 0.08819787632091902, 0.17418587434804067, 0.25088786089327186, 0.3586994460783899, 0.14498295699013397, 0.13983583630761132, 0.06796695291996002, 0.25431536603718996, 0.1385668825241737, 0.13647021143697202, 0.10870136829908006, 0.13156330911442637, 0.14186034095473588, 0.1843021932290867, 0.13868676905985922, 0.14271873864345253, 0.13894338888349012, 0.1786129633546807, 0.10397552774520591, 0.3815625817514956, 0.1505923763033934, 0.16362981812562793, 0.11951958076679148, 0.10617672291118652, 0.12881780799943954, 0.10201596101978794, 0.09407909237779677, 0.1853231361019425, 0.16463585867313668, 0.2872200566343963, 0.11835728102596477, 0.16326540877344087], [0.05076955814729445, 0.013492678917828016, 0.07614262984134257, 0.087995507492451, 0.03826508967904374, 0.025328207011625636, 0.043902706893277355, 0.04250724661687855, 0.01679782431892818, 0.10670213378034532, 0.03152136072458234, 0.027366265130694956, 0.08145318628521636, 0.030419813192565925, 0.05307478757458739, 0.045900854165665805, 0.09754816521308385, 0.10621423105476424, 0.07148020580643788, 0.09682207019068301, 0.030808279261691496, 0.03814679876086302, 0.030339998920680955, 0.03657546061731409, 0.06267944758292288, 0.024053707529674284, 0.029174318697187118, 0.24945305194705725, 0.08369318093173206, 0.08686335379024968, 0.12411544157657772, 0.0927762001811061, 0.05270316083624493, 0.03263966224039905, 1.6771572106517851, 7.925708284601569, 19.779559336602688, 41.509056240320206, 61.40058986842632, 62.095971554517746, 56.18135713040829, 53.915371522307396, 48.05249132215977, 36.522044241428375, 33.06845135986805, 32.702834978699684, 30.584154166281223, 33.475949093699455, 39.52873170375824, 18.514339327812195, 6.833240780979395, 2.5959634641185403, 0.7571325288154185, 0.2336776492302306, 0.16579859628109261, 0.5183538165874779, 1.1908255820162594, 5.151087669655681, 2.0816252008080482, 5.847352333366871, 8.273092769086361, 5.142408460378647, 3.963024658150971, 3.4897933015599847, 11.816207896918058, 5.927684297785163, 4.890739414840937, 6.322271274402738, 4.69666862860322, 4.2677386198192835, 3.818835695274174, 3.2625697692856193, 3.0284294206649065, 4.602524880319834, 6.197780929505825, 12.267632223665714, 6.8381985649466515, 12.844560965895653, 12.470376994460821, 14.372495077550411, 15.97768284380436, 15.403630547225475, 20.586060360074043, 35.554042384028435, 40.79647287726402, 65.35802811384201, 76.59874454140663, 66.29486784338951, 62.50217355787754, 49.81421358883381, 24.247519187629223, 13.625125531107187, 6.60531903617084, 8.192994967103004, 8.348515871912241, 9.573592934757471, 6.203078795224428, 9.619747158139944, 7.810425795614719, 19.35889720916748, 8.45380537211895, 0.471470418269746, 5.827050497755408, 6.8551109824329615, 7.9314834997057915, 3.7857185723260045, 19.314612485468388, 11.775750517845154, 5.695856837555766, 13.067120723426342, 8.783680871129036, 10.731061175465584, 5.460555413737893, 8.275017365813255, 4.09403664059937, 6.132878987118602, 1.6188936308026314, 3.3585443068295717, 1.0383201716467738, 0.2887041145004332, 0.08982342464150861, 0.08654326549731195, 0.28931427863426507, 1.9718292611651123, 6.854417519643903, 18.614473454654217, 28.948621228337288, 35.029001757502556, 24.814796447753906, 25.68470846861601, 20.73054000735283, 25.081988610327244, 25.786826089024544, 32.782395109534264, 44.2483976483345, 38.155435994267464, 55.13265520334244, 48.222843781113625, 30.974497720599174, 10.933810696005821, 0.9083578235004097, 0.04207215883070603, 0.028306254534982145, 0.09098521230043843, 0.03610950690926984, 0.1170286734122783, 0.0719904100697022, 0.09213666926370934, 0.06114992203947622, 0.14392708864761516, 0.07185249676695094, 0.014586128691007616, 0.020056381399626844, 0.05115678482980002, 0.061655740209971555, 0.07416315129376017, 0.039738787163514644, 0.07390576705802232, 0.11424137454014271, 0.02563104408181971, 0.014571281099051703, 0.044068740171496756, 0.02767732148640789, 0.05620817217277363, 0.1343945282860659, 0.04701716301497072, 0.111638684902573, 0.01874384870461654, 0.07505984380259179, 0.0727202529378701, 0.021474119093909394, 0.15327469096519053, 0.15681518067140132, 0.08176709248800762, 0.04996533723897301, 0.07482555520255119, 0.021822043490828946, 0.03202576139301527, 0.035156726589775644, 0.11176885018358007, 0.034535901504568756, 0.05440844179247506, 0.0068653298512799665, 0.04674792297009844, 0.08197145027224906, 0.0742215954232961, 0.049429625360062346, 0.0697703346668277, 0.12016547188977711, 0.03612928143411409, 0.022559517492481973, 0.037375863175839186, 0.0546089033014141, 0.02608724225865444, 0.0948673571110703, 0.03322870485135354, 0.021896508733334485, 0.05183000183023978, 0.12141177532612346, 0.0369470539590111, 0.037723062123404816, 0.02513152674509911, 0.013485031086020172, 0.023550362566311378, 0.13002219493500888, 0.03843556471110787, 0.04499595350353047, 0.025867460790323094, 0.05455825543322135, 0.03638863236119505, 1.7396098282188177, 8.12872426584363, 23.820948377251625, 48.90713766217232, 67.6861023902893, 72.52930730581284, 61.25530086457729, 56.55945584177971, 49.800241738557816, 41.6718965023756, 37.95164152979851, 31.23196240514517, 33.759740665555, 31.46894048899412, 31.42918512225151, 19.26855705678463, 7.983908336609602, 2.9286828730255365, 0.6909224472474307, 0.4513530805706978, 0.47904154169373214, 1.274990828242153, 4.19842273928225, 6.2606043834239244, 6.743054995313287, 9.387066643685102, 8.991254232823849, 8.733908291906118, 9.407411701977253, 12.88863005116582, 10.31256778165698, 9.700700864195824, 8.883403670042753, 6.555590154603124, 7.860469585284591, 6.567656407132745, 7.603693138808012, 5.808973917737603, 5.379767473787069, 4.3549619894474745, 7.0650839153677225, 7.976214699447155, 7.372924396768212, 11.341523118317127, 12.444131802767515, 13.267651163041592, 15.911606289446354, 16.21430564671755, 21.872496530413628, 36.52031913399696, 42.58083812892437, 69.31514337658882, 76.54240876436234, 70.16486898064613, 62.54180543124676, 52.29131206870079, 26.260282583534718, 12.972254063934088, 6.079893680289388, 7.556577092036605, 7.01267427764833, 7.888575252145529, 9.020796697586775, 12.179941479116678, 10.896550845354795, 15.747635588049889, 13.036323375999928, 5.229977136477828, 8.56469577178359, 14.98325815424323, 12.421829849481583, 7.238290496170521, 11.332154721021652, 18.792674392461777, 9.286418594419956, 10.405692234635353, 12.1186688169837, 10.766715612262487, 11.699220724403858, 12.117825262248516, 9.289144948124886, 7.979006599634886, 7.400858597829938, 4.783515818417072, 3.07534194085747, 0.6045605626422912, 0.4916254273848608, 0.08914760270272382, 0.5314319429453462, 1.800494792405516, 7.537845047190785, 19.914754182100296, 35.78250132501125, 34.70411539077759, 28.58354441821575, 32.754234820604324, 25.231045112013817, 27.439619600772858, 28.809675984084606, 34.28442791104317, 54.054409861564636, 45.89900627732277, 61.50004953145981, 53.36764991283417, 35.662655755877495, 12.672886177897453, 0.7851417758502066, 0.043309352404321544, 0.014187664964993019, 0.03284658043412492, 0.07476193088223226, 0.014157719306240324, 0.10239680152153596, 0.039567488347529434, 0.019089184861513786, 0.1533439036575146, 0.06612215933273546, 0.04466544916795101, 0.03975541498220991, 0.06928616494406015, 0.09041321682161652, 0.029226484257378615, 0.06428862412576564, 0.07578090706374496, 0.06904138237587176, 0.03537169337505475, 0.054273218775051646, 0.023925464411149733, 0.03850023917038925, 0.024229995433415752, 0.04771986925334204, 0.019278840700280853, 0.04385002554045059, 0.06328650211798958, 0.02936236222012667, 0.08118822472169995, 0.040805928729241714, 0.09692512481706217, 0.05757112267019693, 0.09003057290101424, 0.028535735873447265, 0.03533700539264828, 0.14684309076983482, 0.10490288579603657, 0.13244547037174925, 0.19624023232609034, 0.12474064162233844, 0.13414460263447836, 0.10946332389721647, 0.14635101717431098, 0.20140856358921155, 0.19942974555306137, 0.13824317255057395, 0.09370207393658347, 0.304640251561068, 0.12213372916448861, 0.11101787837105803, 0.21631523792166263, 0.20723094959976152, 0.1791674960986711, 0.17546417919220403, 0.10492719855392352, 0.09778741878108121, 0.19580401276471093, 0.14272019325289875, 0.1611590155516751, 0.10176888521527871, 0.12875123735284433, 0.1373881145264022, 0.2520229312358424, 0.36122948687989265, 0.18254192284075543, 0.26939298666547984, 0.2658882091054693, 0.15870866656769067, 0.22594310488784686, 2.7157584484666586, 13.03758965805173, 32.03266493976116, 58.50789248943329, 79.75437641143799, 81.61232471466064, 70.64330890774727, 66.60736307501793, 60.37417374551296, 46.5859904140234, 44.77663390338421, 46.24732218682766, 45.34249193966389, 46.748682484030724, 51.21766448020935, 26.40378188341856, 9.705178923904896, 3.74291576910764, 1.0869049583561718, 0.39049563521984965, 0.39680347486864775, 2.4897366017103195, 5.204047802835703, 9.4551732391119, 9.175482597202063, 19.333679862320423, 18.589687384665012, 19.578664116561413, 16.25261139124632, 17.479960732162, 22.919431552290916, 17.281174398958683, 15.98474096506834, 15.750477835536003, 14.326779730618, 14.227290619164705, 11.110363472253084, 9.993590097874403, 9.289175346493721, 10.674606654793024, 13.13561774790287, 18.36101945489645, 10.619059335440397, 16.85616910457611, 17.14744057506323, 19.955049119889736, 21.198424100875854, 20.858798325061798, 26.875059194862843, 44.00599725544453, 50.938725247979164, 70.33995598554611, 78.4811483323574, 67.6301921904087, 60.21604523062706, 49.49442654848099, 29.570115879178047, 16.437353678047657, 10.151816457509995, 12.074557933956385, 13.270494360476732, 14.346143491566181, 12.500763963907957, 15.625882521271706, 14.708944223821163, 27.497473396360874, 16.801161356270313, 4.863083548843861, 14.556125923991203, 17.604500949382782, 17.41562258452177, 10.32209387049079, 31.933668851852417, 26.34032528847456, 14.704960137605667, 22.56463699042797, 17.496885024011135, 22.726001031696796, 14.440021254122257, 20.77629905194044, 12.753732539713383, 14.493015110492706, 9.041917864233255, 5.789689477533102, 3.692537359893322, 0.5987536429893225, 0.3535081824520603, 0.46792048844508827, 0.49749783414881676, 2.8973547415807843, 9.389292374253273, 24.583778344094753, 41.29122152924538, 48.81498120725155, 38.07755917310715, 39.65537130832672, 34.778184816241264, 38.1695294380188, 37.47906468808651, 47.64718987047672, 60.787439569830894, 53.16587693989277, 72.99383997917175, 66.11888408660889, 43.06637227535248, 16.791574470698833, 1.6966742696240544, 0.10295848856912926, 0.159703248355072, 0.193217791384086, 0.16612284060101956, 0.3039516869466752, 0.2180997171672061, 0.28101665200665593, 0.13372266199439764, 0.29405796783976257, 0.15954160859109834, 0.09528739785309881, 0.1336399867432192, 0.1300883648218587, 0.25849460740573704, 0.11949595078476705, 0.09535712262731977, 0.22947143821511418, 0.1398137499927543, 0.17081487632822245, 0.16947724419878796, 0.08271920858533122, 0.13068928179563954, 0.12617982923984528, 0.17828661133535206, 0.09542740401229821, 0.239072305848822, 0.14987589209340513, 0.14900806912919506, 0.1631651891511865, 0.12476206000428647, 0.2516627521254122, 0.20487586269155145, 0.1940599805675447, 0.18514273484470323, 0.12884427298558876], [0.0973291351692751, 0.08885999079211615, 0.07887195955845527, 0.04393975861603394, 0.02262549998704344, 0.08728470071218908, 0.05455739825265482, 0.022726905190211255, 0.020506208238657564, 0.02081152779283002, 0.046269512313301675, 0.02166663220123155, 0.019245919029344805, 0.13883988896850497, 0.029467634012689814, 0.08409374771872535, 0.08303699622047134, 0.060292752605164424, 0.0898326792230364, 0.139656993560493, 0.03189707669662312, 0.04643970532924868, 0.017911062532220967, 0.022080535381974187, 0.05683524614141788, 0.09407733348780312, 0.03584790356399026, 0.13446639786707237, 0.17348898283671588, 0.0702523447398562, 0.16274945286568254, 0.04727974228444509, 0.1700469761271961, 0.22947394667426124, 1.956562155392021, 16.203728914260864, 27.72667519748211, 38.48971925675869, 61.84358149766922, 52.57137604057789, 50.19697085022926, 45.35962522029877, 41.02921038866043, 29.442171044647694, 22.073323354125023, 23.554373681545258, 26.577844843268394, 30.53702149540186, 22.707330733537674, 9.290987849235535, 4.9563599936664104, 0.8591258246451616, 0.2313050624798052, 0.1194592441606801, 0.8441071899142116, 1.0353166703134775, 3.005528999492526, 5.692323027178645, 5.511975204572082, 7.350908853113651, 6.78894323296845, 6.061794776469469, 12.016459051519632, 10.987187381833792, 6.335074687376618, 3.69444462005049, 2.4936252180486917, 4.774967227131128, 5.929618868976831, 3.685171455144882, 5.9224277548491955, 7.683317866176367, 9.117557555437088, 9.492870066314936, 13.582828100770712, 17.879663184285164, 17.372692488133907, 22.40191452205181, 28.555547520518303, 26.45584288984537, 26.274987794458866, 29.255754947662354, 43.75712960958481, 53.650681525468826, 53.27338457107544, 69.80989202857018, 74.27722871303558, 63.460694923996925, 68.3398725092411, 67.37309038639069, 40.392934530973434, 29.925596304237843, 22.848778143525124, 14.241244420409203, 13.38583717122674, 13.48991833627224, 15.190453436225653, 19.583014883100986, 20.256853625178337, 23.857897594571114, 15.439005699008703, 7.979113943874836, 7.342541702091694, 13.421417511999607, 7.922775316983461, 12.122783996164799, 6.431629406288266, 13.067152071744204, 4.923007283359766, 11.483935676515102, 12.659022621810436, 7.755208108574152, 6.300203958526254, 10.412936545908451, 8.163305260241032, 5.862953346222639, 6.129191284999251, 4.401383148506284, 2.3014588421210647, 1.5326801757328212, 0.7281783199869096, 0.1513181225163862, 0.32442219788208604, 0.6031348078977317, 2.2612125892192125, 5.7387802843004465, 17.38352570682764, 32.20049813389778, 42.50787064433098, 28.838425241410732, 20.571921318769455, 18.685159161686897, 31.81025717407465, 43.21028955280781, 35.15730947256088, 35.61254784464836, 43.358002826571465, 52.843240052461624, 40.5662926286459, 17.323677018284798, 2.652797014452517, 0.05425392293545883, 0.07681181697989814, 0.11245425324887037, 0.09488261566730216, 0.10412184958113357, 0.09639659692766145, 0.11082060809712857, 0.05936445202678442, 0.059024455622420646, 0.09723440743982792, 0.015529973552474985, 0.05997467182169203, 0.055027485723257996, 0.028022909973515198, 0.05055612389696762, 0.03971663405536674, 0.05632944652461447, 0.09776024133316241, 0.021105392297613434, 0.09643457262427546, 0.003149620006297482, 0.04146632883930579, 0.03853889022138901, 0.039610098756384104, 0.10969361232127994, 0.10555191620369442, 0.07078712151269428, 0.03392198581423145, 0.05685570715286303, 0.02955591247882694, 0.03372042592673097, 0.04238016867020633, 0.03949858364649117, 0.03172573335177731, 0.014286114565038588, 0.0876133979181759, 0.05608336519799195, 0.09250993985915557, 0.0677484943298623, 0.0059041725398856215, 0.0588786161824828, 0.015865117238718085, 0.008865897452778881, 0.06207867532793898, 0.029603198418044485, 0.02641320836119121, 0.007135403420761577, 0.04166953258391004, 0.07352804357651621, 0.08420881771598943, 0.01546160041471012, 0.06474362744484097, 0.026171027020609472, 0.11524287314387038, 0.024317492789123207, 0.031916639709379524, 0.04464463192562107, 0.02475955305271782, 0.01600278748810524, 0.08239586968556978, 0.017841768203652464, 0.055124373102444224, 0.01952722082933178, 0.042126202024519444, 0.06108080211561173, 0.05118617758853361, 0.037249753731884994, 0.06627190246945247, 0.21957871358608827, 2.6817524107173085, 17.381867095828056, 33.10934476554394, 46.92935138940811, 72.01223865151405, 65.11728823184967, 58.70921328663826, 54.555576369166374, 47.63545610010624, 33.86498361825943, 28.32551546394825, 33.458283841609955, 30.818521790206432, 28.2890697196126, 24.075392223894596, 11.548128481954336, 5.603121863678098, 1.0868151881732047, 0.5019425565842539, 0.37262362078763545, 2.0306542608886957, 4.599589062854648, 4.336831262335181, 7.061588102951646, 9.954873025417328, 7.844726555049419, 11.1322863958776, 10.001213438808918, 14.141316432505846, 14.023554101586342, 13.872207272797823, 10.974246226251125, 10.026664473116398, 9.601600281894207, 6.788032706826925, 8.179672881960869, 7.313866540789604, 8.153265248984098, 10.709312092512846, 9.189700484275818, 13.22800599038601, 19.184079989790916, 15.862842556089163, 22.60034367442131, 24.714217744767666, 26.156377159059048, 26.861780807375908, 34.36578154563904, 45.523442029953, 55.56683510541916, 59.02075096964836, 77.94932886958122, 78.48695442080498, 71.87799945473671, 73.65898668766022, 68.36066499352455, 44.38412256538868, 30.80129351466894, 21.19532346725464, 15.721245054155588, 14.6364726126194, 15.248935148119926, 14.499057736247778, 16.01793598383665, 20.451897159218788, 19.73809026181698, 14.100960697978735, 8.066560551524162, 7.662540106102824, 8.3992251008749, 10.596103817224503, 10.056137591600418, 7.2762993816286325, 10.333007834851742, 7.934835394844413, 11.753540709614754, 15.224913787096739, 14.45420304313302, 12.498700674623251, 13.010321371257305, 10.505606923252344, 9.197024591267109, 9.944217447191477, 8.840414676815271, 3.8477564183995128, 2.466144855134189, 0.8906665665563196, 0.17666221334366128, 0.4814009479014203, 0.972579721128568, 3.2381869526579976, 7.854602700099349, 20.346992388367653, 38.557355627417564, 44.10258047282696, 36.92599296569824, 24.56935241818428, 21.863124333322048, 34.63711738586426, 49.74785014986992, 44.448981285095215, 42.47408665716648, 54.44259703159332, 61.32123112678528, 44.72742274403572, 20.20693000406027, 3.4870662353932858, 0.15194442094070837, 0.04492656640650239, 0.04081143546500243, 0.03732497410965152, 0.0478113055578433, 0.012355871022009524, 0.03364129443070851, 0.04138111544307321, 0.04079962047399022, 0.027079254359705374, 0.013735570864810143, 0.06225839752005413, 0.07578542674309574, 0.08340765445609577, 0.08803439603070728, 0.038708322535967454, 0.022354584543791134, 0.062239097969722934, 0.06435981093090959, 0.054085841329651885, 0.03949760030081961, 0.03528827597619966, 0.010874154631892452, 0.01996354985749349, 0.07415471307467669, 0.04382547158456873, 0.05259888908767607, 0.06474257359514013, 0.02831991561834002, 0.07736374478554353, 0.0542364898865344, 0.06267841599765234, 0.023392119983327575, 0.014211457291821716, 0.017200354086526204, 0.14829918451141566, 0.15824077214347199, 0.18471825605956838, 0.20851385575952008, 0.0786094248178415, 0.25117890152614564, 0.13939333817688748, 0.12383148103253916, 0.09632522458559833, 0.18534700357122347, 0.19356289005372673, 0.1299149842816405, 0.1164546592917759, 0.20916939480230212, 0.20969458302715793, 0.19093075941782445, 0.19113078305963427, 0.15997750160750002, 0.19745207042433321, 0.23765893012750894, 0.10159206110984087, 0.15212048805551603, 0.1290065806824714, 0.11584092542761937, 0.13584930100478232, 0.17121017386671156, 0.16975891892798245, 0.35377262451220304, 0.3471086727222428, 0.14577089517842978, 0.33738377736881375, 0.17024235392455012, 0.31850452010985464, 0.7063515787012875, 4.073089314624667, 22.774870209395885, 42.36370638012886, 57.17541418969631, 81.89739301800728, 70.44920012354851, 66.92783027887344, 58.41898865997791, 53.8646974414587, 41.166527420282364, 32.93019197881222, 33.638971745967865, 39.76428486406803, 42.84708224236965, 30.427632965147495, 12.096427660435438, 7.01776790432632, 1.923427814617753, 0.7230916398111731, 0.4912364232586697, 2.42339501157403, 6.065282514318824, 9.699458330869675, 16.391182355582714, 16.043020337820053, 19.256306514143944, 21.87703348696232, 19.09992590546608, 25.557303205132484, 21.5346110612154, 20.481144189834595, 14.429700057953596, 11.371437013149261, 13.059039507061243, 13.531417809426785, 11.661611292511225, 12.964813113212585, 13.377748355269432, 15.912584736943245, 12.861565053462982, 19.847043715417385, 24.850818514823914, 19.188886731863022, 31.46725717931986, 35.53280532360077, 33.035579323768616, 30.068746022880077, 40.70732206106186, 51.274304240942, 65.18364787101746, 66.58559784293175, 81.90388306975365, 82.50215336680412, 71.93669110536575, 73.14672097563744, 73.8501088321209, 53.482753336429596, 34.48221869766712, 24.27032746374607, 21.024125553667545, 19.369308650493622, 22.57026068866253, 22.990062162280083, 26.46615743637085, 32.07084909081459, 31.47199932485819, 22.730636782944202, 14.846984166651964, 15.104340557008982, 19.683515690267086, 17.07601770758629, 22.192536257207394, 17.185835614800453, 25.107620134949684, 15.735765974968672, 24.529068879783154, 26.187788173556328, 22.745497785508633, 18.773728609085083, 19.22766365110874, 22.922741174697876, 16.21260903775692, 16.552430503070354, 13.17637911066413, 7.427527941763401, 4.411684395745397, 2.34091782476753, 0.3050777327734977, 0.7153068075422198, 1.1229669232852757, 3.79997540730983, 8.358249049633741, 22.891542948782444, 43.62095631659031, 53.19026783108711, 42.08447456359863, 32.61991582810879, 29.137374199926853, 46.68712578713894, 58.49818781018257, 48.476643562316895, 52.55296602845192, 63.630534410476685, 71.24250635504723, 56.49861350655556, 27.150287926197052, 5.212748385965824, 0.23746919265249744, 0.19136439630528912, 0.2160559463663958, 0.22000889206537977, 0.18713986908551306, 0.15690876549342647, 0.27942260785494, 0.14736097626155242, 0.12415317236445844, 0.14006857381900772, 0.12500232289312407, 0.1292231393745169, 0.2225923229707405, 0.161155586829409, 0.15624035760993138, 0.1257908993284218, 0.13511556928278878, 0.18793010793160647, 0.21670140704372898, 0.14188995264703408, 0.1397830547648482, 0.2132184783113189, 0.11657064955215901, 0.17435523244785145, 0.19339877151651308, 0.21829401142895222, 0.1785999015555717, 0.16470830712933093, 0.1373928048997186, 0.16495231044245884, 0.1159563145483844, 0.2742953767301515, 0.16722779459087178, 0.11614818940870464, 0.16432933683972806], [0.04003681882750243, 0.05003119913453702, 0.051386999039095826, 0.048363767709815875, 0.009714976549730636, 0.036464572622207925, 0.027000694317393936, 0.03148899195366539, 0.09984270029235631, 0.04453734334674664, 0.06882877190946601, 0.01575510312250117, 0.01822936781536555, 0.07510425391956232, 0.027091670490335673, 0.03067508601816371, 0.0829291992704384, 0.12999785249121487, 0.031191290545393713, 0.07419628818752244, 0.027417621749918908, 0.07054971589241177, 0.009443498001928674, 0.04119478071515914, 0.06041503256710712, 0.062260638806037605, 0.03136199193249922, 0.10521059506572783, 0.2356332677300088, 0.14749065914656967, 0.13430480263195932, 0.07759228174109012, 0.0651649669453036, 0.4849010647740215, 5.332044409587979, 20.01311380416155, 31.462304145097733, 46.5889048576355, 52.21664987504482, 52.48570203781128, 42.85387247800827, 30.228455252945423, 32.881277203559875, 31.447521038353443, 32.738800048828125, 31.230005510151386, 43.06715503334999, 31.51198647916317, 8.122686389833689, 3.2054564589634538, 1.2435819511301816, 0.29015332111157477, 0.64854332129471, 0.5523687007371336, 1.2582967802882195, 1.858058616053313, 3.6546168196946383, 5.164416404440999, 5.886758593842387, 3.0463891569525003, 7.014583675190806, 5.82139877602458, 7.248234562575817, 12.558963540941477, 8.303594682365656, 9.998262897133827, 13.183516077697277, 6.398448636755347, 6.2764424085617065, 7.253273567184806, 11.234497111290693, 15.94467781484127, 18.8210341706872, 20.625773929059505, 26.52194794267416, 30.531185008585453, 36.23166762292385, 36.62613205611706, 40.19677385687828, 41.20672546327114, 41.04953929781914, 48.297395780682564, 51.521701365709305, 58.946844935417175, 44.7384649515152, 61.42561912536621, 67.9881177842617, 57.45322868227959, 65.65962553024292, 72.01980784535408, 46.33476309478283, 34.955289512872696, 38.829660415649414, 31.94053128361702, 22.30470433831215, 25.289997048676014, 24.72848977893591, 27.444116659462452, 22.80938945710659, 28.131632767617702, 21.95150949060917, 15.625618435442448, 11.22464993968606, 13.912669401615858, 14.719878137111664, 3.341388702392578, 3.9715233771130443, 9.26648486405611, 7.747256560251117, 7.911031572148204, 11.09080782160163, 10.269517991691828, 14.729654062539339, 10.021807383745909, 6.429018946364522, 5.006553875282407, 7.841321462765336, 6.862410865724087, 2.5586694153025746, 1.2017857376486063, 1.0185687127523124, 0.1254421196063049, 0.11150718375574797, 0.10319650275050662, 1.1733301333151758, 4.074801122769713, 11.027088090777397, 20.478581227362156, 26.533921100199223, 27.119640670716763, 24.16158489882946, 48.73598724603653, 63.40788535773754, 63.4326296299696, 45.28258815407753, 36.06439299881458, 41.307735443115234, 47.30391249060631, 49.07907843589783, 29.719124883413315, 6.889727124944329, 0.5066723527852446, 0.02601013311505085, 0.025469172396697104, 0.04887147093540989, 0.13327110966201872, 0.048414571429020725, 0.18383805407211185, 0.1322603935841471, 0.1211774347757455, 0.03806125881965272, 0.06207425954926293, 0.012106585472793086, 0.04436460105353035, 0.013500899131031474, 0.027419295292929746, 0.035251825393061154, 0.05227363915764727, 0.029749889472441282, 0.09816109013627283, 0.025797016132855788, 0.03295533846539911, 0.013834847959515173, 0.0682815196341835, 0.02936688375484664, 0.09828782669501379, 0.08048052011872642, 0.03923924014088698, 0.02701211782550672, 0.05598024006758351, 0.03695699502713978, 0.0580295250256313, 0.1359557843534276, 0.04417834796186071, 0.08240247479989193, 0.07333599060075358, 0.045210185562609695, 0.04166686085227411, 0.019325518078403547, 0.02231027276138775, 0.036643214989453554, 0.05136997417139355, 0.04815172498638276, 0.011577934201341122, 0.017554946680320427, 0.04331744923547376, 0.02678917851881124, 0.042280208799638785, 0.04411153611727059, 0.0804515763593372, 0.04569138298393227, 0.026302852857043035, 0.04980536730727181, 0.10737301301560365, 0.03347143909195438, 0.02539513945521321, 0.041515577759128064, 0.04301228924305178, 0.058687112396000884, 0.030388093800866045, 0.047525096306344494, 0.02631303883390501, 0.07589207336422987, 0.04149215928919148, 0.06745579128619283, 0.07858634402509779, 0.12056748586473987, 0.0494275992969051, 0.04390436559333466, 0.7229795458260924, 6.000351123511791, 23.037236630916595, 38.265413492918015, 52.89804831147194, 63.24630282819271, 59.167388901114464, 49.78636488318443, 35.25630556046963, 37.75372534990311, 39.231184870004654, 31.166395023465157, 26.225921027362347, 36.692415699362755, 29.458715356886387, 11.494453512132168, 4.100253582000732, 1.5122284856624901, 0.18748446309473366, 0.5197039316408336, 1.6855864645913243, 2.243683417327702, 4.702729778364301, 6.2562692910432816, 8.40170731768012, 14.132882785052061, 12.486235443502665, 16.518882103264332, 10.737192146480083, 11.124811246991158, 12.026505712419748, 11.779776401817799, 10.835269633680582, 11.673023980110884, 9.45058023557067, 7.91497053578496, 9.402022641152143, 12.646949719637632, 13.832924980670214, 19.443231783807278, 21.339510530233383, 27.729804329574108, 30.570176616311073, 34.55957114696503, 36.33206203579903, 39.997189566493034, 41.96934834122658, 42.473558485507965, 51.68459102511406, 57.30135463178158, 64.1752427816391, 54.00450713932514, 69.95879083871841, 71.71304270625114, 66.458038687706, 71.40025109052658, 76.71238124370575, 55.83799235522747, 40.60326464474201, 41.48674763739109, 33.79870377480984, 23.244264721870422, 25.57913303375244, 23.784377239644527, 26.47817049175501, 24.03135448694229, 26.995567828416824, 19.52922496944666, 14.507298544049263, 10.891664307564497, 10.756288021802902, 8.254636209458113, 6.204057242721319, 6.842809142544866, 6.585260387510061, 10.649193618446589, 9.238259978592396, 10.030225832015276, 12.377927005290985, 10.850597061216831, 12.208170164376497, 8.931555636227131, 12.522133067250252, 8.336567413061857, 8.06225823238492, 5.313257742673159, 3.667868608608842, 2.409806940704584, 0.15367156185675412, 0.4003200971055776, 0.20382809860166162, 0.6296526349615306, 4.532665628939867, 11.887607015669346, 23.338737152516842, 32.153680846095085, 31.750252693891525, 27.152153626084328, 39.64355394244194, 62.12039664387703, 70.90293377637863, 50.454475432634354, 42.34895557165146, 49.18932572007179, 56.1066797375679, 54.985340908169746, 34.771326184272766, 8.720792345702648, 0.7566540513653308, 0.05826849286677316, 0.014620896454289323, 0.01762643219990423, 0.16400473628891632, 0.03580583863367792, 0.15417501999763772, 0.06844393123174086, 0.052319986280053854, 0.07566100568510592, 0.05986021780699957, 0.03995674109319225, 0.010252899101033108, 0.06447332983952947, 0.07939384522615, 0.04856573948927689, 0.02267692339955829, 0.03604059849749319, 0.00541810059985437, 0.023610550742887426, 0.014929501867300132, 0.024453370751871262, 0.037734053330495954, 0.016923777911870275, 0.09098720125621185, 0.08510554733220488, 0.027961029700236395, 0.007167819967435207, 0.026916647948382888, 0.011187010695721256, 0.057163568562828004, 0.06605248650885187, 0.02779075690341415, 0.010671740346879233, 0.033003255230141804, 0.11357061404851265, 0.1644118339754641, 0.2103747020009905, 0.08464134138193913, 0.10344961221562698, 0.1211525134567637, 0.10640964595950209, 0.15520452725468203, 0.17938403994776309, 0.16150424780789763, 0.20222551975166425, 0.16254568879958242, 0.10917579362285323, 0.28608273016288877, 0.2598830172792077, 0.24577513133408502, 0.3247996245045215, 0.20700263528851792, 0.12054653503582813, 0.1387977646663785, 0.13852137402864173, 0.15650566056137905, 0.23370341659756377, 0.31351138022728264, 0.1997945853509009, 0.16751407063566148, 0.13365767954383045, 0.2307785680750385, 0.3444945317460224, 0.22854436218040064, 0.24787989183096215, 0.2722821675706655, 0.31528941763099283, 1.352958963252604, 9.736171960830688, 30.363522805273533, 51.61347784101963, 65.6788221001625, 69.83385354280472, 69.54418748617172, 57.001349329948425, 41.39361083507538, 43.10448043048382, 45.30240789055824, 44.37961980700493, 43.584618866443634, 57.86540776491165, 42.63957537710667, 12.57107824087143, 5.396233890205622, 1.7123821517452598, 0.8025627722963691, 0.9455983189400285, 1.9659015792421997, 5.827005375176668, 8.48852600902319, 11.21892174705863, 14.280282575637102, 17.804398722946644, 17.838771678507328, 25.13272348791361, 16.271097399294376, 17.27930299937725, 29.521904066205025, 20.72025015950203, 19.36478689312935, 20.123129300773144, 14.659278988838196, 13.7988056614995, 13.019549176096916, 16.276103630661964, 19.2037021368742, 23.926715701818466, 25.04493299871683, 33.2461716234684, 37.22429595887661, 39.98851843178272, 40.15540547668934, 45.73673218488693, 47.17625834047794, 45.93295745551586, 55.9055033326149, 62.12347827851772, 72.59286269545555, 60.319373086094856, 74.78795170783997, 78.7786115705967, 67.73110717535019, 73.7591265141964, 78.17002862691879, 60.07839381694794, 46.308107525110245, 43.95028844475746, 41.24255754053593, 27.54149593412876, 30.28591386973858, 29.933176897466183, 34.451299756765366, 34.225797057151794, 39.79556478559971, 30.51506247371435, 22.711267322301865, 20.33940799534321, 21.487544886767864, 23.213131092488766, 12.726961076259613, 12.159355133771896, 17.609366588294506, 18.231115825474262, 18.14147863537073, 24.25152227282524, 24.83954641968012, 27.703502140939236, 22.415348701179028, 17.010989896953106, 17.56559293717146, 16.15660384297371, 13.847467750310898, 7.02291757799685, 3.6550915567204356, 4.353123838081956, 0.47513698402326554, 0.8747903059702367, 0.3251815040130168, 1.6689274460077286, 5.533252162858844, 14.463627487421036, 27.975523844361305, 36.61782190203667, 38.49859178066254, 37.55798265337944, 63.08535486459732, 77.62836769223213, 73.21491971611977, 58.55766601860523, 50.98358944058418, 57.906297370791435, 65.55613428354263, 67.44409337639809, 42.51806929707527, 12.207550797611475, 1.1093869269825518, 0.19669904286274686, 0.14537495939293876, 0.2116095318342559, 0.2949438843643293, 0.1517726285965182, 0.3835340228397399, 0.2528576989425346, 0.22385250456864014, 0.13169229438062757, 0.1905454066582024, 0.13443041854770854, 0.14667397015728056, 0.1707736574462615, 0.15786862961249426, 0.18404064554488286, 0.1940802560420707, 0.2157596661709249, 0.27309473021887243, 0.08924078676500358, 0.1397600630298257, 0.09195018239552155, 0.16263562225503847, 0.10745740262791514, 0.28134043619502336, 0.15420188574353233, 0.17275688383961096, 0.1816179638262838, 0.16585525183472782, 0.11460722365882248, 0.298076934996061, 0.19968335225712508, 0.1447546575218439, 0.2160960074979812, 0.14389667543582618], [0.07030997250694782, 0.009100525585381547, 0.061788272942067124, 0.05468937066325452, 0.015900987091299612, 0.011976007372140884, 0.07573942100862041, 0.0639516742376145, 0.06064184031856712, 0.052093056074227206, 0.09898543066810817, 0.023867729032645002, 0.019839464621327352, 0.04541910755506251, 0.02257840329548344, 0.09892611822579056, 0.04931183910230175, 0.03316620859550312, 0.03063889147597365, 0.0800745133892633, 0.06994797513470985, 0.057273588245152496, 0.017599080347281415, 0.025159049291687552, 0.10578266475931741, 0.012846287772845244, 0.014519606284011388, 0.15349617751780897, 0.14088333322433755, 0.13363321835640818, 0.022386166638170835, 0.10228375758742914, 0.10758737495052628, 1.3469786779023707, 9.96837655082345, 26.56444676220417, 40.38359463214874, 49.153835624456406, 56.87572807073593, 46.26180320978165, 44.363212287425995, 40.68323515355587, 35.23933947086334, 24.609001390635967, 33.10351587831974, 45.15165477991104, 33.29183757305145, 8.623730354011059, 5.734432367607951, 2.185224504210055, 0.9151354129426181, 0.1761048604384996, 0.8171181881334633, 1.3380213710479438, 2.723576291464269, 4.022863609716296, 2.384745622985065, 3.0894011864438653, 13.862639386206865, 7.044662861153483, 9.91413351148367, 8.299646694213152, 15.115500558167696, 10.328339785337448, 10.262730605900288, 8.541102837771177, 9.084362536668777, 10.805827863514423, 6.806837422773242, 17.610016353428364, 23.44150833785534, 26.54702089726925, 35.19011311233044, 34.550968408584595, 41.41957864165306, 44.36231933534145, 45.684511587023735, 54.60969686508179, 52.814711183309555, 54.391010999679565, 56.67627677321434, 57.2630450874567, 56.581498458981514, 58.684237226843834, 41.939899921417236, 51.76697060465813, 58.95796313881874, 54.42922554910183, 56.594645753502846, 69.58080992102623, 39.73354451358318, 52.09835842251778, 51.54636964201927, 48.67845833301544, 42.043573558330536, 31.441048085689545, 35.501912981271744, 35.69002948701382, 32.642167434096336, 31.38639561831951, 23.93077578395605, 19.173096679151058, 19.8546452075243, 13.01768347620964, 11.420990154147148, 9.899214562028646, 5.799651117995381, 5.770143801346421, 5.421888213604689, 8.7840143032372, 11.959660649299622, 12.984056230634451, 9.314087759703398, 13.143072947859764, 6.5228924341499805, 9.00845305994153, 6.836852012202144, 6.437715254724026, 4.018694758415222, 4.961949018761516, 0.25476374197751284, 0.3218878526240587, 0.553032299503684, 0.28433375526219606, 0.30420499679166824, 0.8880425104871392, 5.26740750297904, 11.39652706682682, 32.03667752444744, 39.65327002108097, 47.862034142017365, 51.621499210596085, 52.8276152908802, 33.76924395561218, 24.180070906877518, 31.022160463035107, 40.019296780228615, 46.782899647951126, 50.524365082383156, 31.761895269155502, 9.629830867052078, 2.1357250353321433, 0.16586800193181261, 0.04793711814272683, 0.11413967804401182, 0.05695961524907034, 0.020191856747260317, 0.2200611837906763, 0.08028201787965372, 0.03923192256479524, 0.06707241263939068, 0.024338994662684854, 0.012037762407999253, 0.06277798252995126, 0.0449720006872667, 0.0683670150465332, 0.03998485735792201, 0.04675286567362491, 0.06009615397488233, 0.06291790705290623, 0.0733004862559028, 0.08522087708115578, 0.02959966765047284, 0.07756237318972126, 0.1883227634243667, 0.08562295042793266, 0.04764650795550551, 0.1453453180147335, 0.03401191184821073, 0.059735926624853164, 0.034569925264804624, 0.07166746450820938, 0.061523378171841614, 0.09727736294735223, 0.03346824043546803, 0.02062644543912029, 0.03724215413967613, 0.023791621788404882, 0.026860806901822798, 0.11707202225807123, 0.03317689181130845, 0.03089418099989416, 0.03126457020698581, 0.029148963221814483, 0.07877652678871527, 0.11025093554053456, 0.037984914088156074, 0.013074193902866682, 0.013311476141097955, 0.05229516144027002, 0.01729331550450297, 0.033773129543988034, 0.05558188116992824, 0.08140883554005995, 0.036995430855313316, 0.007790659983584192, 0.01039754182784236, 0.02752675827650819, 0.06517323447042145, 0.03286975028458983, 0.08277813511085697, 0.04380976773973089, 0.0195928823450231, 0.07260287486133166, 0.1482956815743819, 0.07156908541219309, 0.07923073600977659, 0.11874956544488668, 0.14721860265126452, 1.1006586765870452, 12.969493512064219, 31.571658477187157, 47.72694379091263, 58.53390209376812, 63.540315851569176, 54.51934911310673, 50.69141931831837, 44.25744116306305, 39.979474917054176, 28.154593035578728, 34.89893093705177, 39.12285268306732, 34.956566244363785, 14.401192087680101, 6.1902677826583385, 2.1651530312374234, 1.13194833509624, 0.5373790394514799, 1.046324917115271, 2.39846502430737, 3.173498511314392, 6.6641398798674345, 7.797245727851987, 11.201897710561752, 15.286114253103733, 11.89637029543519, 11.566429249942303, 8.24363674968481, 13.641706891357899, 12.464594654738903, 9.260542932897806, 15.807730313390493, 14.165179152041674, 9.155051093548536, 12.436213977634907, 16.766928993165493, 20.591285079717636, 27.113144919276237, 33.77758450806141, 34.091888442635536, 40.44533371925354, 45.62187194824219, 47.35563911497593, 52.4479016661644, 52.295260056853294, 54.786687567830086, 57.78471149504185, 57.49795228242874, 59.76878643035889, 67.64188036322594, 50.972820818424225, 62.9156369715929, 65.5966705083847, 62.26892687380314, 63.84546607732773, 76.0450154542923, 51.113857850432396, 54.60265964269638, 54.33868780732155, 50.820122212171555, 41.18964917957783, 32.83217243850231, 35.931274741888046, 35.38361392915249, 36.62729859352112, 32.43249848484993, 26.491861157119274, 22.61687658727169, 18.29479470849037, 16.192717105150223, 11.623166855424643, 8.695490453392267, 8.309419769793749, 5.757134249433875, 8.202267419546843, 8.005279339849949, 9.64010551571846, 13.023463916033506, 14.234021957963705, 12.946541793644428, 11.02496400475502, 16.530412584543228, 12.815924752503633, 9.431226924061775, 8.859031777828932, 3.9032802265137434, 3.529308093711734, 0.8651409612502903, 0.4293952463194728, 0.6476337451022118, 0.5566922156140208, 1.0998794808983803, 6.060162289068103, 13.169099651277065, 27.484284304082394, 31.79578185081482, 42.2730128467083, 56.663760244846344, 65.29106810688972, 47.821790501475334, 31.430824734270573, 35.93610428273678, 48.60398232936859, 55.41993498802185, 60.997651889920235, 39.04178403317928, 11.354854702949524, 2.134200129657984, 0.09861408965662122, 0.0572379762888886, 0.11618522999924608, 0.09937535505741835, 0.04080438877281267, 0.06318818239378743, 0.04418765820446424, 0.011116333189420402, 0.09262461651815102, 0.089329310139874, 0.03757816521101631, 0.004301700373616768, 0.029150421541999094, 0.035563141500460915, 0.007203632303571794, 0.05023565339797642, 0.031195068077067845, 0.08552619663532823, 0.010955212001135806, 0.024036036993493326, 0.032222686568275094, 0.06768658437067643, 0.00905942823010264, 0.0822239882836584, 0.0245248043211177, 0.07387683072010987, 0.028542491272673942, 0.015918722565402277, 0.039086105389287695, 0.07272383008967154, 0.02710444099648157, 0.047295572294387966, 0.060574531235033646, 0.03223767052986659, 0.10945962800178677, 0.059548909121076576, 0.14009514270583168, 0.1614386567962356, 0.10252692227368243, 0.16533182992134243, 0.11132113475468941, 0.16447521338704973, 0.2844977402128279, 0.3038601949810982, 0.22947025077883154, 0.14682069275295362, 0.1302169938571751, 0.18676202686037868, 0.16912355145905167, 0.19909240974811837, 0.2595507726073265, 0.2884572761831805, 0.10772459063446149, 0.2684340428095311, 0.11995083536021411, 0.13736397988395765, 0.14154832722852007, 0.17850147793069482, 0.21431866771308705, 0.2045060059754178, 0.07901243327069096, 0.2438330347649753, 0.27519462222699076, 0.41372295760083944, 0.24082303221803159, 0.18068992299959064, 0.2118325323681347, 3.0491687078028917, 18.448654152452946, 39.42380413413048, 58.684358820319176, 69.25455942749977, 75.60371473431587, 61.76718659698963, 58.53444926440716, 54.03827212750912, 47.25221246480942, 36.73775866627693, 45.99823035299778, 60.33237598836422, 44.77640211582184, 14.532110262662172, 7.5583720207214355, 2.2772541409358382, 1.577012634370476, 1.135680447332561, 2.4662134889513254, 3.1121978256851435, 7.6403687708079815, 12.169551886618137, 11.071786992251873, 11.789663471281528, 29.376084990799427, 18.335547521710396, 19.02285274118185, 23.82095977663994, 31.405455395579338, 22.987955175340176, 21.486534141004086, 18.84656310081482, 17.823682688176632, 19.132419861853123, 12.18078788369894, 26.22590772807598, 28.099665082991123, 30.78175686299801, 41.1906523257494, 37.51549333333969, 46.2801144272089, 47.85934008657932, 50.47273725271225, 56.9105190038681, 58.34779568016529, 59.06474880874157, 60.250649973750114, 61.549678668379784, 65.74996188282967, 74.0825879573822, 58.75757709145546, 64.42074000835419, 73.52143406867981, 62.82447226345539, 67.18314617872238, 77.59514227509499, 57.2220528870821, 58.24504539370537, 55.867657363414764, 52.73467607796192, 50.92999331653118, 37.73388661444187, 42.24826857447624, 40.70281930267811, 43.17653976380825, 38.126340955495834, 27.335451990365982, 23.13150007277727, 23.446974344551563, 20.718876533210278, 16.367840208113194, 15.90656965970993, 13.661334738135338, 15.669811014086008, 16.941814608871937, 20.508248135447502, 21.31155163049698, 23.42104833573103, 19.608583711087704, 21.856508888304234, 13.791911881417036, 16.41825020313263, 15.002112742513418, 19.347505420446396, 12.687475495040417, 11.021485291421413, 2.639085450209677, 0.536615636665374, 1.4181046863086522, 1.322631009388715, 0.5998861009720713, 1.363313882611692, 7.320300070568919, 17.263683937489986, 41.790149956941605, 51.169741451740265, 61.165606677532196, 61.015985906124115, 58.63137446343899, 42.5120884180069, 35.93584969639778, 46.0890606790781, 56.748750284314156, 66.14913806319237, 69.77838411927223, 50.71122005581856, 16.204460375010967, 3.546673161908984, 0.323251741938293, 0.30410130391828716, 0.2348463240195997, 0.21535443869652227, 0.16786433465313166, 0.27753226866479963, 0.19698583841091022, 0.14535935944877565, 0.2405051703681238, 0.1610279522719793, 0.08075477337115444, 0.13944896956672892, 0.1464360227691941, 0.11675861329422332, 0.12134084827266634, 0.14886807039147243, 0.16766232205554843, 0.4264427156886086, 0.17753585474565625, 0.18984826281666756, 0.1451787949190475, 0.21856296574696898, 0.2759972104104236, 0.20434907142771408, 0.26161898975260556, 0.19074887386523187, 0.11559482925804332, 0.15949041524436325, 0.11610327463131398, 0.1267614949028939, 0.17811912344768643, 0.13137287402059883, 0.17129865271272138, 0.13001699990127236], [0.04840754329052288, 0.018690686811169144, 0.027671441821439657, 0.0332134871132439, 0.035367192249395885, 0.02050975941529032, 0.054276684604701586, 0.0415544329007389, 0.0824521244794596, 0.06076544872485101, 0.06393572548404336, 0.06982417748076841, 0.05983643939543981, 0.040169002750189975, 0.02048027945420472, 0.03826249216217548, 0.035340085305506364, 0.03905865705746692, 0.01944549923791783, 0.033320274742436595, 0.041728499927558005, 0.031809870633878745, 0.01794083378626965, 0.06526658180519007, 0.12337955762632191, 0.13279574923217297, 0.04374813608592376, 0.1127145838108845, 0.10815507339430042, 0.03843517508357763, 0.050372401528875344, 0.01952432645339286, 0.13085776416119188, 4.498877367004752, 15.513874981552362, 30.23194346576929, 46.56818076968193, 53.23238097131252, 56.547961458563805, 44.63352978229523, 34.774077236652374, 21.29983875900507, 18.39215688407421, 38.59047085046768, 28.785435184836388, 29.26075167953968, 21.42241258174181, 8.658701777458191, 3.816102216951549, 0.2573864918667823, 0.3481391893001273, 0.6063401733990759, 0.867273478070274, 1.9208666332997382, 1.4923474774695933, 2.9986214451491833, 4.751257924363017, 10.833553075790405, 13.145789802074432, 12.248037625104189, 15.075229369103909, 7.364153042435646, 3.95394932013005, 5.700589958578348, 5.390926999971271, 11.25549953430891, 11.83383135125041, 8.402201291173697, 21.287899799644947, 20.62051311135292, 30.980776883661747, 38.98492768406868, 43.210946917533875, 49.55683059990406, 50.22800378501415, 58.694253489375114, 60.35639829933643, 64.93945017457008, 64.49854463338852, 62.24114656448364, 64.26640748977661, 63.90131548047066, 60.05324296653271, 53.04884321987629, 41.03929124772549, 41.90959274768829, 52.9215956479311, 54.698790684342384, 50.523631721735, 62.22904421389103, 45.794086307287216, 62.99173168838024, 68.52676168084145, 56.74272380769253, 54.76717561483383, 44.326468259096146, 38.39221268892288, 46.823287680745125, 43.4313540905714, 37.10147514939308, 32.120725214481354, 32.72281810641289, 25.784922391176224, 27.94265180826187, 20.31305070966482, 12.785316444933414, 13.983413055539131, 5.659644305706024, 11.623218152672052, 5.5213697254657745, 6.913673439994454, 8.12208317220211, 14.385315589606762, 11.724169235676527, 11.664160005748272, 24.189484901726246, 7.318887496367097, 6.910828342661262, 6.223829006776214, 2.600143952295184, 2.8671950474381447, 0.46696133678779006, 0.09841067439992912, 0.9040891088079661, 0.1784183573909104, 0.5178598430939019, 2.1245932951569557, 9.209874551743269, 17.93175458908081, 35.575317442417145, 42.67353035509586, 31.389845833182335, 17.339605763554573, 16.672809943556786, 24.749827533960342, 28.39689653366804, 37.02024310827255, 43.10164578258991, 51.82648681104183, 38.27394403517246, 15.687520913779736, 2.7891408232972026, 0.126348267076537, 0.0834226532606408, 0.1363175071310252, 0.10337998392060399, 0.0981460913317278, 0.07771296237478964, 0.08852200931869447, 0.03641215844254475, 0.035946338321082294, 0.038284007023321465, 0.060165693212184124, 0.036473066502367146, 0.0668906384089496, 0.04794769374711905, 0.032183026196435094, 0.032152546191355214, 0.12358366308035329, 0.06084775290219113, 0.08894941216567531, 0.06378515856340528, 0.1043068669969216, 0.04282780617359094, 0.0940519075084012, 0.13272727868752554, 0.07852788505260833, 0.029736538235738408, 0.02516596796340309, 0.008972308442025678, 0.06503993732621893, 0.019268695541541092, 0.03333497297717258, 0.035220521604060195, 0.014304827818705235, 0.03141153771139216, 0.0553576931997668, 0.017352605682390276, 0.011320337525830837, 0.05652894324157387, 0.012012143470201408, 0.04460171352548059, 0.040310096155735664, 0.04449425054190215, 0.07008007742115296, 0.048683585118851624, 0.024563292099628597, 0.03206982270057779, 0.027776119895861484, 0.07074768378515728, 0.02029952382144984, 0.07920401127194054, 0.04353299860667903, 0.06648344424320385, 0.06049733674444724, 0.0772966249496676, 0.05058716422354337, 0.021809764657518826, 0.05251874084933661, 0.025015467836055905, 0.045558980127680115, 0.09574853131198324, 0.08786179474554956, 0.10145541687961668, 0.06930497838766314, 0.06422234291676432, 0.07687335586524568, 0.022788405112805776, 0.1681360200745985, 6.060957871377468, 17.364217042922974, 36.51781886816025, 54.65816706418991, 63.93343135714531, 67.32871636748314, 50.32551795244217, 38.7534137070179, 26.17134265601635, 25.74183840304613, 37.80973054468632, 29.657057113945484, 28.584137186408043, 25.182413421571255, 9.018475972115993, 3.542649415321648, 0.6955201411619782, 0.2945437777088955, 0.7592089986428618, 2.608789913356304, 5.154495611786842, 3.512237509712577, 9.290659166872501, 12.506381962448359, 8.615081068128347, 15.32369613647461, 12.769613787531853, 16.241844668984413, 11.931877490133047, 14.240923337638378, 13.653504308313131, 11.765762753784657, 15.860676672309637, 14.50997930020094, 11.961206216365099, 20.323712937533855, 26.215885765850544, 31.80580571293831, 42.438657358288765, 44.13368180394173, 51.800378412008286, 53.1471211463213, 58.44075009226799, 62.04496309161186, 66.69367164373398, 63.305165469646454, 63.916636258363724, 62.7057134360075, 64.37030911445618, 61.391158774495125, 62.833257392048836, 48.32923427224159, 52.94458821415901, 59.404252991080284, 61.51628226041794, 56.99117727577686, 68.36518675088882, 54.373216554522514, 66.75487115979195, 69.54581379890442, 57.63205088675022, 58.24703648686409, 47.73249909281731, 39.39833790063858, 45.69447085261345, 44.1803964972496, 38.80731761455536, 32.718862518668175, 32.782243117690086, 27.59008202701807, 26.680851615965366, 21.264578551054, 14.425809066742659, 11.209427006542683, 9.306669607758522, 9.942064862698317, 7.812839141115546, 9.326708782464266, 9.407080169767141, 11.833330728113651, 11.968573071062565, 16.527338549494743, 18.192154616117477, 16.991086564958096, 8.237155247479677, 11.315979938954115, 4.8106007650494576, 7.588478280231357, 2.861477304250002, 0.6596042308956385, 1.429046792909503, 0.1941909547895193, 0.6208785495255142, 2.68917768727988, 8.651259876787663, 18.613702096045017, 35.92218182981014, 42.42592044174671, 39.05501112341881, 29.782965257763863, 21.94298654794693, 29.14957344532013, 32.71941728889942, 44.52370427548885, 51.926691234111786, 61.21001109480858, 47.17622794210911, 20.28687011450529, 3.6380613455548882, 0.12763878767145798, 0.08470535904052667, 0.11062393154134043, 0.024692600200069137, 0.04298580199247226, 0.024406418779108208, 0.03292376750323456, 0.015693747918703593, 0.0189706212040619, 0.019632982439361513, 0.06771980290068313, 0.026695745837059803, 0.07142401780583896, 0.07158770589740016, 0.031250473111867905, 0.07879107288317755, 0.07492955977795646, 0.08417877557803877, 0.013523337966034887, 0.03340994844620582, 0.07685791177209467, 0.10831611944013275, 0.06917922888533212, 0.08452516558463685, 0.09599243814591318, 0.050348797522019595, 0.02647354682267178, 0.03585753664083313, 0.05383562624047045, 0.05388385099649895, 0.02421740489808144, 0.029254780492919963, 0.10589514466118999, 0.046624125316157006, 0.16135890560690314, 0.13613924325909466, 0.09154623883659951, 0.19698944524861872, 0.0894049572525546, 0.15208195574814454, 0.23487041413318366, 0.21104517305502668, 0.23095418990124017, 0.1651026398758404, 0.15084725950146094, 0.11289152665995061, 0.2114998720935546, 0.13020744983805344, 0.0978571583982557, 0.16788493667263538, 0.168754362675827, 0.15374846319900826, 0.14814330381341279, 0.16123462555697188, 0.17685255937976763, 0.12982301734155044, 0.2031413745135069, 0.14798865508055314, 0.3898934565950185, 0.3142423660028726, 0.1847267462289892, 0.2621124288998544, 0.2643026551231742, 0.18713020632276312, 0.17481957940617576, 0.12059313448844478, 0.4090192849980667, 9.143280275166035, 23.772276788949966, 43.441465348005295, 67.28191047906876, 75.30068099498749, 74.67156395316124, 57.48920135200024, 46.575825959444046, 31.680408641695976, 27.55884390324354, 50.12734718620777, 43.566174656152725, 42.67951883375645, 31.31045289337635, 12.73795673623681, 5.026782564818859, 0.8652220037765801, 0.7149521203245968, 0.6408496841322631, 2.6244415109977126, 8.058731071650982, 6.522351913154125, 11.674366258084774, 17.994261234998703, 21.64384949952364, 22.398846186697483, 27.75402992963791, 25.46758431941271, 19.882397018373013, 16.328267231583595, 15.155131481587887, 12.515425477176905, 18.686004616320133, 19.16606515645981, 13.379952237010002, 26.426175981760025, 30.566492713987827, 35.2995890378952, 43.482514545321465, 47.84343793988228, 53.99405390024185, 54.57696922123432, 61.910780891776085, 63.72439697384834, 68.80316644906998, 66.5789557993412, 63.97452995181084, 65.28673633933067, 65.47923400998116, 64.4717712700367, 66.55287399888039, 56.749563440680504, 55.20012818276882, 65.46218052506447, 64.44710299372673, 59.25372786819935, 71.4777897298336, 60.11577621102333, 71.49093702435493, 69.82168659567833, 62.337995767593384, 60.723770186305046, 55.8446191996336, 46.185697093605995, 49.021203741431236, 45.80642804503441, 40.280300974845886, 36.43699340522289, 38.615025132894516, 30.892880000174046, 32.50258572399616, 29.532522596418858, 19.290683269500732, 17.303376607596874, 11.37428306043148, 17.504201531410217, 13.424793630838394, 15.174931269139051, 15.2517213486135, 24.036993384361267, 23.025109581649303, 22.758574783802032, 39.11231204867363, 20.293485559523106, 16.326310336589813, 14.58353005349636, 9.142418671399355, 9.586447644978762, 3.371062260121107, 0.792085665743798, 1.5516587323509157, 0.4316734318854287, 1.1915292567573488, 2.985071847215295, 12.54620572552085, 22.34752234071493, 46.681669279932976, 53.81986364722252, 42.077410742640495, 26.577839143574238, 28.366374671459198, 36.43945947289467, 40.02303957939148, 52.40225091576576, 61.326357051730156, 68.55085238814354, 60.987894013524055, 29.821751676499844, 5.1141859497874975, 0.550123555585742, 0.2543689194135368, 0.2311525066033937, 0.1945435639936477, 0.22775678022298962, 0.16316539695253596, 0.23848022043239325, 0.1449989280081354, 0.11029079629224725, 0.10900437235250138, 0.174369451997336, 0.1477138526388444, 0.19669979985337704, 0.23313328390941024, 0.09975481516448781, 0.18095942650688812, 0.2911478583700955, 0.31000977905932814, 0.1898665344924666, 0.21957826829748228, 0.2721830760128796, 0.2741318370681256, 0.18034673907095566, 0.19917328900191933, 0.2317611567559652, 0.23395034397253767, 0.12408905822667293, 0.06908741779625416, 0.1573047903366387, 0.06398086290573701, 0.13027559383772314, 0.18630118283908814, 0.14582988107576966, 0.15671447123168036], [0.025535123349982314, 0.02242631682747742, 0.027555959932215046, 0.054698384046787396, 0.04754163135658018, 0.018701692861213814, 0.023863613823777996, 0.09014766153995879, 0.06535294553032145, 0.043891485620406456, 0.06790805608034134, 0.06433332368033007, 0.017645900588831864, 0.09601243160432205, 0.024410910627921112, 0.03228911249607336, 0.042248029276379384, 0.044790311803808436, 0.07934534587548114, 0.07924695193651132, 0.03935843276849482, 0.044991893955739215, 0.09937955561326817, 0.05516122073458973, 0.035798220487777144, 0.02518926397897303, 0.02993906291521853, 0.05830838330439292, 0.11141409617266618, 0.16525377082871273, 0.04721390636404976, 0.019702159879670944, 0.4794121702434495, 8.147424012422562, 29.83815159648657, 44.961288794875145, 55.313160717487335, 50.04631653428078, 40.572619289159775, 43.94432656466961, 68.3872863650322, 39.07739572227001, 23.320253044366837, 28.648520931601524, 42.61074632406235, 36.76888279616833, 12.961003817617893, 6.41041561961174, 0.7376179634593427, 0.5114304693415761, 0.31422387168277055, 1.1754726245999336, 1.6435303213074803, 3.0823150416836143, 1.758687060791999, 5.6039397697895765, 7.213649293407798, 11.82583088055253, 11.029209326952696, 12.841264642775059, 10.159958470612764, 3.1559453532099724, 11.718243453651667, 15.227719936519861, 9.90486865863204, 25.342177748680115, 21.108786910772324, 24.301920868456364, 34.82960745692253, 39.33467611670494, 49.04277518391609, 59.835868030786514, 57.31195606291294, 60.349649861454964, 59.07224580645561, 59.64270539581776, 64.42973032593727, 65.89137509465218, 71.26970529556274, 69.21163693070412, 69.28083121776581, 68.00596162676811, 59.54259596765041, 52.774760127067566, 45.34830182790756, 36.083885952830315, 44.50166545808315, 53.1728495657444, 49.065623357892036, 57.47295342385769, 48.32940146327019, 62.309261709451675, 71.27393066883087, 69.08458694815636, 58.7502358853817, 50.16732484102249, 46.21350780129433, 43.287668600678444, 48.59025366604328, 48.01111154258251, 45.026375502347946, 43.990851268172264, 41.212816536426544, 37.77530439198017, 33.263430297374725, 28.427897170186043, 19.678678549826145, 14.125386737287045, 10.819517578929663, 7.552453838288784, 8.020810056477785, 8.29696973785758, 8.352143727242947, 6.901444271206856, 13.980913739651442, 15.75181346386671, 21.730762235820293, 4.911264488473535, 8.200750350952148, 3.2852937374264, 7.717223446816206, 3.1024052761495113, 0.8715759159531444, 1.5340387215837836, 0.672478771302849, 0.3351375932106748, 0.8569602970965207, 3.366186646744609, 11.972226575016975, 19.72138825803995, 28.406846299767494, 31.160056963562965, 34.84028868377209, 35.43331526219845, 22.661102414131165, 28.54639381170273, 36.98837421834469, 46.61147564649582, 41.68742246925831, 45.48664480447769, 28.715691827237606, 8.95272335037589, 0.9496147627942264, 0.023000015535217244, 0.1413374237017706, 0.16095822007628158, 0.02396291689365171, 0.19017875602003187, 0.14335109299281612, 0.034329061236348934, 0.020619485949282534, 0.021318774597602896, 0.03222044157155324, 0.13381407974520698, 0.03434333273617085, 0.05250626905763056, 0.046082698900136165, 0.052309247403172776, 0.0045011363272351446, 0.06508479273179546, 0.035629021949716844, 0.03788630863709841, 0.0060475081590993796, 0.07372576656052843, 0.03025901947694365, 0.023150784691097215, 0.04872205063293222, 0.07730299257673323, 0.07170817130827345, 0.0775930832605809, 0.028228147202753462, 0.0105271375105076, 0.01970309684111271, 0.02477205081959255, 0.03352084386278875, 0.026243384563713335, 0.04024946640129201, 0.053741395749966614, 0.013354310121940216, 0.041576114745112136, 0.02544379651226336, 0.015232292553264415, 0.07248741152579896, 0.034345458989264444, 0.043808123882627115, 0.06232555446331389, 0.04573226047796197, 0.04468113816983532, 0.03543570732290391, 0.032249826908810064, 0.0892794229730498, 0.039236401426023804, 0.03432869758398738, 0.05340599695045967, 0.06549747136887163, 0.018646814751264174, 0.040132841604645364, 0.050444000225979835, 0.058181227432214655, 0.012947783889103448, 0.13028852205025032, 0.03881410084431991, 0.04484440323722083, 0.012470620040403446, 0.05798066944407765, 0.06227357444004156, 0.060124140363768674, 0.03171666801790707, 0.7640250027179718, 9.512359220534563, 33.485372588038445, 49.39191184937954, 63.80399510264397, 59.61728475987911, 49.96758855879307, 48.18531699478626, 64.79460194706917, 37.91663020849228, 23.9953476190567, 34.19523149728775, 36.67553320527077, 37.426418513059616, 17.572945542633533, 6.922662332653999, 1.4078435744158924, 0.3173433558549732, 1.7143867816776037, 2.019496872089803, 3.283436349593103, 6.752196354791522, 7.269982220605016, 13.0795194581151, 8.016921915113926, 6.768417209386826, 14.660390429198742, 8.24286824092269, 20.056534074246883, 13.172711357474327, 9.887642282992601, 12.868234645575285, 8.765660338103771, 15.14215612784028, 12.053769249469042, 21.026458628475666, 31.54512260109186, 40.15938386321068, 46.30775414407253, 56.739444583654404, 59.51037369668484, 60.30597880482674, 59.370818585157394, 63.865665793418884, 64.12476629018784, 67.06857472658157, 70.20828545093536, 69.61392894387245, 69.14416775107384, 67.56263941526413, 62.31806203722954, 58.954425528645515, 54.49439965188503, 45.32272160053253, 53.83207619190216, 60.19038900732994, 56.02116532623768, 63.46834771335125, 56.260822266340256, 65.09062126278877, 72.34011545777321, 71.05329930782318, 61.67825996875763, 55.2472760528326, 49.67728793621063, 44.78457547724247, 50.23244574666023, 47.79065117239952, 46.9586668163538, 43.72851334512234, 40.18587604165077, 36.83944121003151, 31.669516526162624, 23.333806917071342, 20.821072049438953, 14.265210684388876, 11.499282103031874, 7.2895715944468975, 10.687035787850618, 10.651109665632248, 12.015171870589256, 14.194019604474306, 22.564724385738373, 14.047377873212099, 18.274011723697186, 13.82303411141038, 12.512238398194313, 5.03802141174674, 6.523784436285496, 7.4634193908423185, 1.6190513223409653, 2.2580592334270477, 0.8897819265257567, 0.2068247870192863, 0.9661778958979994, 3.9647825388237834, 11.400347761809826, 20.23522138595581, 30.565008893609047, 36.493446975946426, 32.40912973880768, 34.068759083747864, 28.08831699192524, 33.78484591841698, 41.55210793018341, 52.59191393852234, 49.3740414083004, 53.23643155395985, 33.85464437305927, 10.841796733438969, 1.1166111705824733, 0.01840950561017962, 0.12955857528140768, 0.0725825697008986, 0.04888666640908923, 0.011932267043448519, 0.028019095334457234, 0.08197781047783792, 0.02682840102352202, 0.034915944197564386, 0.05343679236830212, 0.07986499767866917, 0.0892636671778746, 0.07144563656765968, 0.0101332556187117, 0.021528913712245412, 0.08567639990360476, 0.049751724873203784, 0.0614779661555076, 0.014335015603137435, 0.017614296230021864, 0.03739802741620224, 0.025768588166101836, 0.04365349370345939, 0.052268703875597566, 0.07871993802837096, 0.06755388094461523, 0.02292040164320497, 0.04516044682532083, 0.05983022761938628, 0.02445687925501261, 0.0898696604417637, 0.09767323193955235, 0.039039661787683144, 0.10700847749831155, 0.12523991405032575, 0.0841665746702347, 0.27113866643048823, 0.18711567507125437, 0.09860082005616277, 0.14427393878577277, 0.13992378080729395, 0.13444426702335477, 0.16347059776308015, 0.12582610681420192, 0.15740391158033162, 0.16969222953775898, 0.27326960989739746, 0.22997253632638603, 0.1890822031418793, 0.2584725507767871, 0.2190521894954145, 0.14019226015079767, 0.1441567685105838, 0.13363249105168507, 0.17727018072037026, 0.10413178693852387, 0.09587804350303486, 0.23906893649837002, 0.11218781481147744, 0.1393581455340609, 0.2784906781744212, 0.23838604189222679, 0.1779322061338462, 0.12839913280913606, 0.1114170796063263, 1.5792344463989139, 13.502713199704885, 43.12474474310875, 60.74607878923416, 73.76677930355072, 68.45967248082161, 55.657076463103294, 55.43754704296589, 80.8560436964035, 51.287299543619156, 35.074929893016815, 39.459636211395264, 56.13254114985466, 47.8651537746191, 18.692336976528168, 8.033910803496838, 1.2459381809458137, 0.7165064150467515, 1.5651765069924295, 3.814581111073494, 8.244196269661188, 8.471647314727306, 10.412119589745998, 17.670744694769382, 19.461425207555294, 26.270612329244614, 24.1447252035141, 23.501056842505932, 25.191760919988155, 18.29426273703575, 22.617970928549767, 28.869974948465824, 20.593300871551037, 35.759873539209366, 28.33560772240162, 29.23604730516672, 40.248956456780434, 52.754229828715324, 54.038253128528595, 68.72954919934273, 60.51738426089287, 60.619701370596886, 61.67513653635979, 62.6475727558136, 64.67135176062584, 67.27041989564896, 71.18851125240326, 69.57630336284637, 70.75195267796516, 69.1286113858223, 64.55528318881989, 63.623880967497826, 60.360961854457855, 47.486116513609886, 58.45817595720291, 62.99389757215977, 60.12354679405689, 67.87514224648476, 60.73121398687363, 66.44567415118217, 71.21566459536552, 71.15571901202202, 64.36188876628876, 57.60003000497818, 55.60395911335945, 53.02525408565998, 53.54202635586262, 50.359248742461205, 48.95192965865135, 46.88918374478817, 44.7020211070776, 45.14731541275978, 37.474086955189705, 32.33415976166725, 27.731086760759354, 22.303714491426945, 17.790371775627136, 13.03892433643341, 15.001100096851587, 14.622967187315226, 19.11805473268032, 16.057419665157795, 23.74504365026951, 26.61746721714735, 30.521058551967144, 19.883799143135548, 19.307888746261597, 9.662449266761541, 14.728029649704695, 9.397389739751816, 1.512608346529305, 3.588761128485203, 1.4512906805612147, 0.2688291622325778, 1.1034308653324842, 4.737608106806874, 15.798589903861284, 26.18201058357954, 38.67418795824051, 41.0364755988121, 46.7863916605711, 49.74351078271866, 35.171212926506996, 41.83991588652134, 49.99494709074497, 63.090435191988945, 57.79362961649895, 60.77573999762535, 42.14453414082527, 13.303537387400866, 1.6751201637089252, 0.07386463723378256, 0.1819566503399983, 0.35200031648855656, 0.20519500103546306, 0.2932896965648979, 0.2205392307951115, 0.21594821620965376, 0.11519618463353254, 0.12251357518834993, 0.17591677053133026, 0.3045345103600994, 0.14197587850503623, 0.15208263852400705, 0.22997065127128735, 0.1659142822609283, 0.21883524488657713, 0.15659372380468994, 0.32508413423784077, 0.14855196001008153, 0.07088435027981177, 0.13292397750774398, 0.15872422198299319, 0.18282950506545603, 0.16414914338383824, 0.1295789546566084, 0.1942409755429253, 0.15684005746152252, 0.19822906935587525, 0.20216018107021227, 0.06877606458147056, 0.16951469297055155, 0.1733431508182548, 0.10834165674168617], [0.042740351491374895, 0.020360235212137923, 0.0725106184836477, 0.04654751712223515, 0.05095181106298696, 0.027807332771772053, 0.03967261356592644, 0.035869292260031216, 0.034580025894683786, 0.15249948803102598, 0.07481932858354412, 0.0928457394184079, 0.024448877047689166, 0.10159157871385105, 0.04703118960605934, 0.048063550420920365, 0.019620553321146872, 0.015500292283832096, 0.03673356033687014, 0.06331908240099438, 0.063318236352643, 0.026064718076668214, 0.10201954559306614, 0.027546877900022082, 0.035769877868006006, 0.09401330098626204, 0.040113668219419196, 0.19038894708501175, 0.1084244655794464, 0.04221650284307543, 0.05807543057017028, 0.09937549606547691, 1.6189591772854328, 15.593277420848608, 26.413613855838776, 44.181623831391335, 50.43535865843296, 48.64438936114311, 38.50733891129494, 43.97572048008442, 36.511617600917816, 30.602602176368237, 31.842762529850006, 33.85665446519852, 53.4244454652071, 18.020650818943977, 8.870129082351923, 3.374667791649699, 0.18948265118524432, 0.5717219528742135, 0.36257179453969, 0.9503635601140559, 2.950724777765572, 5.934051806107163, 3.1031863717362285, 12.388095259666443, 10.313428435474634, 0.7561794924549758, 14.429649710655212, 2.8759409906342626, 19.17270340025425, 13.109045773744583, 13.489789143204689, 12.21258932724595, 13.20091724395752, 23.325517661869526, 32.51920223236084, 35.46668127179146, 44.82780955731869, 50.73218733072281, 54.64382283389568, 60.53662642836571, 63.91413599252701, 66.50957152247429, 65.16270339488983, 63.723849803209305, 69.17939186096191, 68.89201328158379, 65.98551884293556, 72.12113320827484, 68.09421569108963, 67.01377406716347, 62.12288171052933, 50.233741477131844, 51.152471378445625, 33.15692961215973, 37.658008486032486, 51.91946022212505, 47.620686292648315, 57.31953665614128, 46.699969097971916, 73.66556793451309, 67.69943207502365, 66.52502909302711, 62.58362598717213, 57.079017162323, 58.14398601651192, 51.966266110539436, 50.92087000608444, 50.74474185705185, 53.77762511372566, 52.0290045440197, 49.57771807909012, 47.11898021399975, 48.32377016544342, 38.16503047943115, 30.627414844930172, 30.546002313494682, 22.348614782094955, 14.027255102992058, 13.887756988406181, 11.02624548599124, 10.239272564649582, 10.355907306075096, 23.945226408541203, 8.536248598247766, 17.454344406723976, 10.153566263616085, 13.372749723494053, 3.8520900858566165, 6.2589305732399225, 4.289518101140857, 2.4197163339704275, 2.2544658137485385, 0.38350979913957417, 0.7639298890717328, 0.2512145839864388, 1.4884734665974975, 7.514604544267058, 18.859068229794502, 18.855350129306316, 38.84198695421219, 47.29934513568878, 41.70258365571499, 34.28063191473484, 25.23934006690979, 39.17147107422352, 39.26969960331917, 52.325282245874405, 49.19252134859562, 33.20019789040089, 14.01592506095767, 2.0348549354821444, 0.19830442703096196, 0.08056177786784247, 0.07692374769249, 0.04871423952863552, 0.03381375841854606, 0.09235989244189113, 0.08046064540394582, 0.014551352578564547, 0.019447350896371063, 0.04513833082455676, 0.02975043680635281, 0.071227652952075, 0.04340550505730789, 0.07825824795872904, 0.03955721702368464, 0.026584102706692647, 0.10255495319142938, 0.07106713383109309, 0.023961467850313056, 0.06219868802872952, 0.04434791757375933, 0.031538170369458385, 0.029551305597124156, 0.08481900411425158, 0.04706708357844036, 0.026934980851365253, 0.05164004171092529, 0.057539306799299084, 0.04585811017022934, 0.058525624772300944, 0.04423866972501855, 0.011599657791521167, 0.04811103302927222, 0.0708075454167556, 0.007918483788671438, 0.02225433894636808, 0.03810873029578943, 0.02139226948202122, 0.05709282704629004, 0.033362963076797314, 0.020304980462242384, 0.027373864722903818, 0.030081000513746403, 0.03180047875503078, 0.1320491635124199, 0.025744112135726027, 0.058055188492289744, 0.026650476684153546, 0.0742995431937743, 0.05857806863787118, 0.02245596748252865, 0.040468244114890695, 0.10069295662106015, 0.030368412044481374, 0.05042567659984343, 0.024804289714666083, 0.05233114818111062, 0.0815792623325251, 0.011479533768579131, 0.06173299036163371, 0.14739984995685518, 0.009195860020554392, 0.0255536733311601, 0.0324079080746742, 0.10234240209683776, 2.0749672455713153, 17.93788556009531, 35.70929065346718, 51.75119765102863, 59.64610621333122, 55.42362079024315, 42.29429170489311, 44.59212340414524, 49.189405515789986, 34.770159646868706, 27.668259032070637, 32.769859582185745, 51.74206294119358, 24.07586719840765, 8.937104288488626, 3.1929907528683543, 0.31954952341038734, 0.5896428599953651, 1.4159214659594, 4.374457793310285, 7.124489927664399, 9.151811767369509, 9.636230673640966, 10.554373506456614, 10.281759034842253, 9.498559311032295, 16.187773570418358, 14.073822554200888, 11.664899066090584, 14.777123015373945, 14.266777150332928, 13.612547256052494, 16.541669480502605, 19.87357199192047, 23.383646942675114, 31.680898815393448, 40.782189443707466, 52.60641776025295, 56.61466307938099, 65.56395426392555, 65.99962368607521, 69.14964705705643, 67.94528648257256, 64.99667510390282, 68.92001017928123, 68.84094402194023, 67.96394348144531, 71.92341461777687, 68.50627318024635, 69.52094793319702, 63.34556110203266, 57.93538101017475, 59.844546765089035, 41.60759635269642, 46.90915547311306, 58.725879192352295, 54.71282713115215, 63.71917985379696, 55.34548178315163, 75.48633903265, 69.50346127152443, 71.35422796010971, 64.53898206353188, 58.29961806535721, 60.97782835364342, 56.04224659502506, 54.665356278419495, 54.03440773487091, 54.38345320522785, 53.45550499856472, 52.01954685151577, 48.84329728782177, 45.02923294901848, 37.08009369671345, 29.89455197006464, 26.276008039712906, 17.023774310946465, 14.951314218342304, 11.437295079231262, 8.726741876453161, 6.02311902679503, 14.573391247540712, 15.994234755635262, 13.99332482367754, 19.89405859261751, 7.225177399814129, 12.60167134925723, 10.868781935423613, 8.542256075888872, 9.865846652537584, 2.7904239669442177, 6.048068962991238, 2.101440425030887, 0.983925674809143, 0.49065529194194824, 1.5175254014320672, 7.932081967592239, 16.99713584035635, 26.688741892576218, 44.16483633220196, 43.750772550702095, 37.08509422838688, 33.24399434030056, 30.544134713709354, 45.83680361509323, 45.817641243338585, 56.36214762926102, 57.09064073860645, 38.923576176166534, 16.730874627828598, 2.206232864409685, 0.1929563030716963, 0.02642570798343513, 0.13727094425121322, 0.04205469238513615, 0.05938837144640274, 0.1160147215705365, 0.034990789790754206, 0.03188814123859629, 0.04270384524716064, 0.0394323358341353, 0.09069006016943604, 0.04713413662102539, 0.04683342580392491, 0.07958232847158797, 0.023564160946989432, 0.01953715633135289, 0.015394555721286451, 0.03914476103091147, 0.01741376607242273, 0.029926320239610504, 0.10700611746869981, 0.029108159942552447, 0.007873529120843159, 0.021006599454267416, 0.013491380159393884, 0.019283987494418398, 0.029424760141409934, 0.0368603191600414, 0.04744498888612725, 0.04761011303344276, 0.0237109688896453, 0.024062568772933446, 0.06817788613261655, 0.11024244537111372, 0.11550924478797242, 0.16585977893555537, 0.12444499967386946, 0.11711276616551913, 0.09025038219988346, 0.16033864550990984, 0.0988611951470375, 0.16752505442127585, 0.21973717695800588, 0.19245812902227044, 0.23191387590486556, 0.11933086003409699, 0.25057039980310947, 0.17300853127380833, 0.15203071787254885, 0.17908896203152835, 0.13706290541449562, 0.10597134838462807, 0.19217455439502373, 0.15105332422535866, 0.10771971472422592, 0.2038885687943548, 0.2162690318073146, 0.2533772320020944, 0.19018962106201798, 0.18553142726887017, 0.42527223005890846, 0.14997036749264225, 0.3191524447174743, 0.182530241436325, 0.30608999251853675, 3.836759808473289, 23.23391977697611, 42.3963238298893, 61.055465787649155, 69.07900124788284, 65.92669039964676, 53.390988260507584, 56.15162752568722, 47.60934390127659, 42.407229244709015, 42.912488132715225, 45.81637591123581, 65.82443028688431, 26.363190561532974, 12.79950013384223, 4.392124470323324, 0.5244108696933836, 1.365006691776216, 2.2428080393001437, 4.392037075012922, 8.720461763441563, 19.05870571732521, 12.53404637798667, 23.13558105379343, 21.048926822841167, 12.469682581722736, 35.15066742897034, 15.297813825309277, 33.53637345135212, 26.041079945862293, 25.030263885855675, 22.512450590729713, 21.760767325758934, 29.597178027033806, 41.09517864882946, 38.11346724629402, 50.657939314842224, 55.88590018451214, 59.97890755534172, 65.53654253482819, 66.53854876756668, 71.06846809387207, 69.44370567798615, 64.70494955778122, 70.61659634113312, 68.01318123936653, 67.5652688741684, 70.56843772530556, 66.39831349253654, 68.91747191548347, 62.84179173409939, 62.802737429738045, 62.813791036605835, 42.051332741975784, 50.20896300673485, 63.75487893819809, 58.063795119524, 65.62583014369011, 61.136150658130646, 78.56909841299057, 70.17146542668343, 69.99581605195999, 63.49715396761894, 60.509226098656654, 61.56116545200348, 58.832322880625725, 57.21340075135231, 56.56180411577225, 57.31761775910854, 55.70637121796608, 54.84121844172478, 52.001680210232735, 54.72493328154087, 46.036205515265465, 37.72518128156662, 37.1551700681448, 25.76528124511242, 20.56620642542839, 20.821898505091667, 20.382444486021996, 17.487759813666344, 20.36054626107216, 39.147277772426605, 17.244888246059418, 30.682513788342476, 17.642639502882957, 21.693735122680664, 14.649192430078983, 15.674006938934326, 13.581304382532835, 5.123861655592918, 7.048314465209842, 1.411433075554669, 1.6214622929692268, 0.7899842597544193, 2.0863533345982432, 9.902905113995075, 23.657332956790924, 28.389834612607956, 51.71807862818241, 60.678791999816895, 56.09197832643986, 47.752307429909706, 38.58732081949711, 53.36368292570114, 54.24307733774185, 68.32667961716652, 66.40361800789833, 46.792022958397865, 21.2603759765625, 3.227903754450381, 0.4453801573254168, 0.21787909150589257, 0.2957911795238033, 0.1868626769282855, 0.09289573790738359, 0.18952810030896217, 0.16725237452192232, 0.15744609525427222, 0.10975685814628378, 0.1040575944352895, 0.17839284235378727, 0.14914155181031674, 0.138320934784133, 0.20249822933692485, 0.10182942962273955, 0.1640424077049829, 0.19629351852927357, 0.19762435258598998, 0.09217024402460083, 0.16367387201171368, 0.16456734359962866, 0.20040702045662329, 0.1223868757369928, 0.14614855928812176, 0.18775464937789366, 0.08280080772237852, 0.1458827219903469, 0.09024844519444741, 0.11621942074270919, 0.24467173585435376, 0.13317598117282614, 0.19510550337145105, 0.13620153913507238], [0.02075278123811586, 0.08819669630611315, 0.02399941015028162, 0.005325425836417708, 0.026607558284013066, 0.040021092718234286, 0.004715373952421942, 0.06291205150773749, 0.040675611307960935, 0.05339814873877913, 0.10274676125845872, 0.048952498618746176, 0.01706765622657258, 0.06021753593813628, 0.15148702048463747, 0.021793272280774545, 0.05629626139125321, 0.05483308013936039, 0.014734420929016778, 0.0374187518900726, 0.08274507985333912, 0.0348014753399184, 0.013156123295630096, 0.05640914947434794, 0.010008808585553197, 0.043184519454371184, 0.08938448139815591, 0.162489389476832, 0.010691558472899487, 0.0342769476264948, 0.061837618341087364, 0.1227963854034897, 2.886825744062662, 14.2966596968472, 29.92321953177452, 46.86993397772312, 49.4381857663393, 44.712538942694664, 41.55931234359741, 36.590850949287415, 23.740086816251278, 23.572430312633514, 23.59065793454647, 33.394048288464546, 31.31317164748907, 21.516780517995358, 11.811371706426144, 0.9422083664685488, 0.33382363559212536, 0.38043193460907787, 1.8575659487396479, 4.266437664628029, 3.28199646435678, 7.291622534394264, 9.992637299001217, 11.26886436715722, 4.440109245479107, 7.084700837731361, 10.32427305355668, 10.345669705420732, 10.594915430992842, 9.822317138314247, 8.232742734253407, 13.493749480694532, 20.716153979301453, 27.02934041619301, 26.390150114893913, 38.949448987841606, 53.98047722876072, 60.97199946641922, 62.34682649374008, 66.23101606965065, 65.77552691102028, 64.59215641021729, 62.83965244889259, 64.63280662894249, 65.65633490681648, 70.55782109498978, 67.28495791554451, 66.96486309170723, 70.40190786123276, 64.74376067519188, 67.34306439757347, 57.325646728277206, 49.03311990201473, 35.111537128686905, 34.11141559481621, 49.17153887450695, 44.224595725536346, 51.91346034407616, 47.94100530445576, 65.03142043948174, 69.2268817126751, 64.90013748407364, 62.328211292624474, 61.343231946229935, 64.67979490756989, 61.56688794493675, 61.89194530248642, 57.51357324421406, 56.26719832420349, 52.47386947274208, 56.426861956715584, 57.04475820064545, 54.375944808125496, 49.98272314667702, 41.10879331827164, 32.59059280157089, 25.479245893657207, 22.804666310548782, 21.585133150219917, 13.285706844180822, 11.080279536545277, 20.451579876244068, 17.94728245586157, 11.896141357719898, 16.76922596991062, 9.647343177348375, 9.137121755629778, 5.253428528085351, 2.881953692995012, 7.236867472529411, 3.2935274206101894, 4.228803059086204, 2.9798107920214534, 0.19345895969308913, 0.4200923361349851, 0.5426925199571997, 4.108237903565168, 9.406203366816044, 13.570533860474825, 25.770593360066414, 48.67064595222473, 46.08763575553894, 29.136922024190426, 26.57748196274042, 21.85867667198181, 35.10686717927456, 41.514235362410545, 54.01423841714859, 35.59647850692272, 23.376704715192318, 5.881483526900411, 0.1100771913479548, 0.06955244010896422, 0.09308943845098838, 0.03409988232306205, 0.039307335900957696, 0.022566282168554608, 0.026380932358733844, 0.03863637502945494, 0.06109218666097149, 0.023511893341492396, 0.06512509877211414, 0.025043619352800306, 0.09497988154180348, 0.0423124291410204, 0.03120492008747533, 0.002638669188854692, 0.03360862880072091, 0.030303737585199997, 0.0319567045517033, 0.0409328359819483, 0.04667691799113527, 0.10245592100545764, 0.028008642184431665, 0.022293682050076313, 0.07374809036264196, 0.04346157060354017, 0.07260793630848639, 0.024600462566013448, 0.05240355952992104, 0.018895716239057947, 0.07405801865388639, 0.016561867741984315, 0.07205511792562902, 0.03364992189744953, 0.047148118683253415, 0.0058148963489657035, 0.06966707966057584, 0.03727148752659559, 0.07345960271777585, 0.039947211917024106, 0.028517881655716337, 0.07841361657483503, 0.040023352557909675, 0.05540207363083027, 0.03485991575871594, 0.057420051089138724, 0.07235599943669513, 0.029926863862783648, 0.025683434141683392, 0.04327621922129765, 0.03782073617912829, 0.06299989210674539, 0.0421023753733607, 0.0878502098203171, 0.013833046396030113, 0.02551549725467339, 0.025461908626311924, 0.042226744481013156, 0.08261354902060702, 0.06301123212324455, 0.11734718093066476, 0.01100520492400392, 0.08909798270906322, 0.017535031147417612, 0.25522384385112673, 3.549334444105625, 18.44262957572937, 35.91504581272602, 53.828941360116005, 56.68522909283638, 50.876925364136696, 44.81207840144634, 41.26069776713848, 28.521045371890068, 33.292833119630814, 29.560834877192974, 35.79699754714966, 39.07496765255928, 20.41196320205927, 10.585750322788954, 1.2945774709805846, 0.38588657160289586, 0.8297270990442485, 5.946339871734381, 5.056716883555055, 9.281754344701767, 12.671246565878391, 8.679202627390623, 11.122697610408068, 11.782036330550909, 9.519727975130081, 14.252634309232235, 10.857326500117779, 11.723063495010138, 16.909478344023228, 11.844324488192797, 14.286293853074312, 16.03291478008032, 24.28550384938717, 26.877211779356003, 36.713983342051506, 50.32455660402775, 57.466201186180115, 63.608822375535965, 69.3213902413845, 68.57786893844604, 67.6818922162056, 65.03803208470345, 67.64666050672531, 65.96326723694801, 69.10784170031548, 66.19310930371284, 67.32320666313171, 70.2493916451931, 64.1248194873333, 65.02301529049873, 60.47431357204914, 58.25145184993744, 43.74250799417496, 43.17698813974857, 56.174084320664406, 51.600687727332115, 58.29825393855572, 55.050906389951706, 69.65151652693748, 70.38645029067993, 66.6910345852375, 63.1977566331625, 64.75573763251305, 63.08321937918663, 61.163300201296806, 64.5931063592434, 60.541528165340424, 58.350140154361725, 56.62625625729561, 56.69110357761383, 57.4871950596571, 56.363363564014435, 51.453666016459465, 40.79520374536514, 36.738997399806976, 26.34829916059971, 22.66673181205988, 18.540388830006123, 12.2289246506989, 6.5753737930208445, 11.489231642335653, 12.036113496869802, 14.715619515627623, 16.32726788520813, 6.654916349798441, 15.50296576693654, 12.005997262895107, 9.508200343698263, 13.739485144615173, 7.250771401450038, 6.241103354841471, 8.634984400123358, 1.4838769007474184, 0.5306301265954971, 0.7554029684979469, 3.960175523534417, 11.217053197324276, 18.432182036340237, 29.394715391099453, 47.58668951690197, 59.5047689974308, 36.473053470253944, 29.086943306028843, 30.089865289628506, 42.69692949950695, 49.74267862737179, 61.248715817928314, 42.935606092214584, 26.674830839037895, 6.662695482373238, 0.11962965611019172, 0.027045952338085044, 0.019841147441184148, 0.01496020173362922, 0.019881696534866933, 0.05106653967231978, 0.032533887642784975, 0.08302064670715481, 0.0940060502034612, 0.04379805293865502, 0.04040602616441902, 0.0732109832460992, 0.06426221108995378, 0.11718889567418955, 0.022269651308306493, 0.04191172876744531, 0.05943338641372975, 0.02674404480785597, 0.021030984571552835, 0.03964182185882237, 0.0352835967350984, 0.0834699725965038, 0.04565509567328263, 0.03536370044457726, 0.1100470007804688, 0.03951810584112536, 0.0077569205586769385, 0.0524330265034223, 0.023930145507620182, 0.04314641388191376, 0.08633344550617039, 0.05228539477684535, 0.11297105520498008, 0.2999958617147058, 0.13737223256612197, 0.1438638279796578, 0.1619414470042102, 0.1258642235188745, 0.17064384097466245, 0.11544180582859553, 0.09727573764394037, 0.2098630802356638, 0.17898895021062344, 0.14974807942053303, 0.1361373285180889, 0.1350611847010441, 0.16519484430318698, 0.2700249699410051, 0.17237987281987444, 0.17005893954774365, 0.15881669358350337, 0.12692907184828073, 0.1565827548620291, 0.20588599989423528, 0.18341264018090442, 0.12830510269850492, 0.195045315194875, 0.26290023350156844, 0.12474536168156192, 0.26044431841000915, 0.2525694784708321, 0.0906515798124019, 0.17497304070275277, 0.10134689262486063, 0.4543029988417402, 6.042614355683327, 22.753441259264946, 45.06150461733341, 64.87401768565178, 67.94039994478226, 60.331247448921204, 54.77814942598343, 49.103583320975304, 36.21472053229809, 36.897011920809746, 32.6001150906086, 45.39096973836422, 43.80086146295071, 29.61809780448675, 13.90611095353961, 1.3722936320118606, 0.718164254212752, 0.5680926132481545, 7.062002280727029, 9.748959224671125, 10.858845468610525, 23.828827254474163, 18.00513245165348, 21.700354367494583, 16.35493230074644, 16.46815102547407, 22.426075525581837, 17.727335058152676, 23.054797388613224, 22.551582790911198, 15.368130952119827, 21.09507344663143, 28.05461660027504, 38.70275482535362, 27.410135082900524, 40.09770557284355, 53.13165217638016, 61.826676204800606, 64.03541028499603, 71.13524571061134, 70.5599869787693, 68.66526424884796, 65.92105150222778, 67.32788801193237, 65.14708623290062, 70.94714820384979, 66.80046871304512, 69.77105811238289, 68.89499232172966, 64.76944729685783, 66.5730433166027, 64.64215412735939, 63.01376290619373, 43.16613592207432, 45.85850425064564, 60.29811702668667, 56.317028850317, 60.53346499800682, 60.04310891032219, 70.17627596855164, 72.0103007555008, 66.79434344172478, 65.02109259366989, 64.67538714408875, 67.53661841154099, 62.15801082551479, 65.51619842648506, 62.13913343846798, 59.201845452189445, 57.64377325773239, 60.72800315916538, 63.280633985996246, 60.60201331973076, 54.99368526041508, 44.13369320333004, 37.89145275950432, 32.15096399188042, 31.575843952596188, 28.495714031159878, 21.19184285402298, 19.140568524599075, 34.76879172027111, 31.782402768731117, 27.27002140134573, 33.48017446696758, 21.58532503992319, 18.253321833908558, 11.53592923656106, 13.938160333782434, 16.96768742054701, 8.50338701158762, 9.554669000208378, 6.543683968484402, 1.3792436965741217, 0.5793000524863601, 0.966106946580112, 5.7996520679444075, 12.84698998555541, 20.322742089629173, 34.89797718822956, 63.88966530561447, 60.46813890337944, 40.60620188713074, 37.52102963626385, 33.46610002219677, 49.761643409729004, 55.84292069077492, 69.25367027521133, 51.95878051221371, 31.55565183609724, 9.361636508256197, 0.2491211041342467, 0.2208294253796339, 0.21397536504082382, 0.20751774514792487, 0.184811380750034, 0.11498162231873721, 0.15815435646800324, 0.19564798363717273, 0.13866440072888508, 0.08944665110902861, 0.20712103752885014, 0.16406679467763752, 0.25665028137154877, 0.28928298968821764, 0.09474953374592587, 0.18235423369333148, 0.19993136316770688, 0.21833583887200803, 0.06734397931722924, 0.1737910814699717, 0.20372458384372294, 0.2700302837183699, 0.12837060465244576, 0.16959938686341047, 0.2723440923728049, 0.10714153715525754, 0.10179051882005297, 0.08465592458378524, 0.12574686028528959, 0.1049214914382901, 0.3311207634396851, 0.17982502409722656, 0.17082122911233455], [0.02706665083678672, 0.03824988307314925, 0.01553879861603491, 0.05338093833415769, 0.052195042007952, 0.055255807455978356, 0.018172914496972226, 0.09234689001459628, 0.054730997726437636, 0.02079754016449442, 0.055112509871833026, 0.03571188644855283, 0.02703085519897286, 0.06102357881900389, 0.0353430427639978, 0.03532317547069397, 0.03287527557404246, 0.05040575364546385, 0.010849150748981629, 0.02116461197147146, 0.07633687957422808, 0.006887015870233881, 0.054202091341721825, 0.013967966988275293, 0.022627557591476943, 0.08216851274482906, 0.06856201434857212, 0.13297264755237848, 0.05873121081094723, 0.061185200029285625, 0.022492868920380715, 0.5675893777515739, 5.067252293229103, 18.192922174930573, 37.580960020422935, 56.02037876844406, 52.21983790397644, 49.67975400388241, 38.67703780531883, 27.074048817157745, 23.626461513340473, 14.561235699802637, 25.467069447040558, 33.87045532464981, 25.129581056535244, 16.079690270125866, 4.454950774088502, 0.6903812731616199, 0.22065439727157354, 1.0211885534226894, 3.7538180965930223, 5.620554853230715, 13.896693158894777, 5.988888563588262, 6.333464048802853, 7.64323809184134, 9.2716003395617, 8.734949436038733, 11.677537187933922, 13.979124035686255, 3.1755777122452855, 15.919435769319534, 21.469666846096516, 20.567091777920723, 25.717417113482952, 32.183034271001816, 41.88320696353912, 48.832806050777435, 58.210364654660225, 63.26883181929588, 63.84754836559296, 67.97050192952156, 63.382137939333916, 63.03477957844734, 61.817070320248604, 64.49764028191566, 68.73287782073021, 69.91931095719337, 68.21774706244469, 66.21109753847122, 65.0421890616417, 63.556153401732445, 60.95172755420208, 55.22099286317825, 48.02562676370144, 39.848385751247406, 30.79243429005146, 44.41723398864269, 43.62316019833088, 48.967163041234016, 47.811664044857025, 64.52705830335617, 65.66328093409538, 64.52609315514565, 63.2296559214592, 62.93383039534092, 64.20605152845383, 64.67674747109413, 66.79353028535843, 67.52882122993469, 63.940742164850235, 63.438466116786, 56.575118601322174, 59.6964231133461, 56.78267106413841, 58.41757893562317, 50.43150946497917, 51.54591366648674, 37.836294919252396, 30.085087046027184, 24.907399378716946, 14.299388900399208, 6.154948677867651, 10.468321423977613, 6.885119397193193, 12.720413077622652, 11.31793588399887, 1.7659867065958679, 15.253562349826097, 16.4548422396183, 8.441428486257792, 12.31357080861926, 3.8601352041587234, 8.692447766661644, 12.803792003542185, 1.9512254605069757, 0.5528480093926191, 0.14817000628681853, 1.373361018486321, 9.093756582587957, 17.593073062598705, 39.53559413552284, 39.01803910732269, 11.574560813605785, 21.53043318539858, 24.7028848528862, 31.68950155377388, 34.52622793614864, 37.46554121375084, 47.25198067724705, 49.9394890666008, 25.810244232416153, 6.578234089538455, 1.1487788194790483, 0.020687104879471008, 0.04987430540495552, 0.10109101494890638, 0.053466218523681164, 0.048260427356581204, 0.0595344075554749, 0.07501283616875298, 0.018324338598176837, 0.03612212713051122, 0.009673676031525247, 0.06077756428567227, 0.04338616839959286, 0.05140553788805846, 0.03822318802122027, 0.06795276305638254, 0.015558556442556437, 0.045325942046474665, 0.02863640820578439, 0.04887754541414324, 0.07598096781293862, 0.04323699300584849, 0.012472765774873551, 0.016373553335142788, 0.04311323617002927, 0.04461461205210071, 0.029363731482590083, 0.06733470989274792, 0.005046415881224675, 0.11171853999258019, 0.03970222896896303, 0.07201686763437465, 0.03293493682576809, 0.035425718015176244, 0.043945877623627894, 0.028916440933244303, 0.022885431644681375, 0.03574991780624259, 0.07945513178128749, 0.03877308605297003, 0.09274172742152587, 0.06695113828754984, 0.04763821816595737, 0.03894799912814051, 0.0750308703572955, 0.03663875839265529, 0.050600964459590614, 0.037801829967065714, 0.07351188702159561, 0.02510069236450363, 0.07580208795843646, 0.024821036276989616, 0.049605410458752885, 0.09733231898280792, 0.03294467009254731, 0.040490426908945665, 0.0036992183959227987, 0.02778242815111298, 0.020333477077656426, 0.02319143954082392, 0.12677498714765534, 0.0503561670484487, 0.07837812707293779, 0.047507629860774614, 0.8087661175522953, 5.635760212317109, 19.25437431782484, 43.655150681734085, 63.34565989673138, 57.40885466337204, 56.8520363420248, 46.06139816343784, 35.23633383214474, 31.02064624428749, 23.007649518549442, 28.176964335143566, 33.789158686995506, 28.36503904312849, 17.650543078780174, 6.909245252609253, 0.8786186599172652, 0.6574390002060682, 2.6859433483332396, 2.9389309231191874, 5.931460345163941, 8.865860011428595, 11.769072376191616, 7.327008610591292, 12.493932880461216, 12.704283893108368, 12.221539746969938, 13.568954095244408, 15.312821120023727, 9.23756081610918, 11.679292693734169, 16.976128667593002, 13.909252434968948, 24.258388504385948, 31.130599044263363, 39.58036333322525, 50.21837890148163, 56.802927777171135, 65.11984929442406, 66.40587508678436, 70.65804451704025, 65.9389941394329, 65.69839105010033, 64.43128824234009, 67.43961721658707, 71.09363034367561, 69.61043313145638, 68.23397219181061, 66.39092668890953, 64.41375598311424, 63.396276980638504, 63.4630735963583, 58.584465980529785, 54.019216150045395, 47.854685336351395, 39.56342004239559, 51.94212980568409, 50.102868899703026, 56.79283931851387, 56.88488557934761, 66.91223591566086, 66.8892927467823, 66.99414432048798, 64.6690034866333, 64.30185198783875, 64.66970264911652, 67.52995356917381, 68.37409347295761, 67.75012135505676, 64.37111467123032, 65.23793175816536, 61.2146620452404, 63.313570618629456, 60.06453596055508, 59.828124046325684, 52.07019813358784, 50.60436598956585, 37.976317405700684, 30.995926670730114, 21.776887960731983, 14.920268934220076, 7.30883608572185, 7.047932585701346, 7.235932722687721, 12.363952305167913, 15.321361161768436, 10.812714993953705, 15.956379286944866, 15.877073742449284, 13.599048480391502, 10.491799414157867, 8.084217254072428, 5.885479962453246, 6.706299092620611, 1.017476033885032, 0.4519690037705004, 0.5277663865126669, 1.6024444322101772, 8.663750756531954, 18.182902112603188, 33.410649597644806, 44.50066611170769, 19.08708829432726, 24.932310841977596, 29.407013431191444, 34.894800558686256, 39.274190962314606, 42.87419758737087, 55.069350600242615, 56.99262119829655, 31.008241809904575, 8.167792819440365, 1.2163865729235113, 0.023524140633526258, 0.03660260837932583, 0.04639059741748497, 0.07933279615826905, 0.00881152864167234, 0.056820306708686985, 0.09046504099387676, 0.03484411914541852, 0.053065280662849545, 0.0585054940165719, 0.007279324872797588, 0.022435784776462242, 0.04605732858181, 0.06512710999231786, 0.02676615895325085, 0.034671603207243606, 0.03550657129380852, 0.08553211897378787, 0.02618738952151034, 0.048654711863491684, 0.01771643615938956, 0.0376759914070135, 0.0352885542815784, 0.03674899700854439, 0.051356919793761335, 0.11457237982540391, 0.012991259827686008, 0.03503338906739373, 0.07621890777954832, 0.04849054879741743, 0.07321327648242004, 0.04881960223428905, 0.16935401799855754, 0.18281841737916693, 0.13126308069331571, 0.09386186575284228, 0.115328784158919, 0.28881365549750626, 0.1372100436128676, 0.1939758358639665, 0.17204655945533887, 0.12533131695818156, 0.13192503189202398, 0.1565220471820794, 0.09131417667958885, 0.1136383276025299, 0.15352506190538406, 0.1362528363824822, 0.15404370438773185, 0.1647980624693446, 0.08606316274381243, 0.11752592719858512, 0.17478965601185337, 0.16546826635021716, 0.10800525604281574, 0.11681141710141674, 0.12150766080594622, 0.13069076609099284, 0.22084426833316684, 0.30498086765874177, 0.2254915377125144, 0.23734958813292906, 0.11809177027316764, 1.218793150037527, 7.8341431729495525, 24.869469814002514, 51.73214927315712, 72.90759980678558, 67.03835874795914, 66.19921937584877, 52.17801354825497, 40.13715885579586, 33.72131332755089, 22.89052650332451, 37.07871817052364, 45.21415762603283, 33.85102316737175, 20.479060001671314, 6.244091894477606, 1.2880488275550306, 0.8426882629282773, 3.894638065248728, 7.285853018984199, 11.562259923666716, 22.48498946428299, 17.05589398741722, 18.786482624709606, 19.833727329969406, 18.770276494324207, 18.219205364584923, 21.66416320949793, 28.114854767918587, 13.34847092628479, 25.820416286587715, 30.912188664078712, 26.10151380300522, 37.773377895355225, 37.15501427650452, 44.844555258750916, 52.63794846832752, 57.63677403330803, 64.76123213768005, 63.964794874191284, 72.01868310570717, 66.30974784493446, 67.76986509561539, 65.21694168448448, 67.68947660923004, 71.00485950708389, 71.2123815715313, 67.43068769574165, 67.94074952602386, 64.1800457239151, 64.21285316348076, 63.06399621069431, 61.689454168081284, 59.600675851106644, 47.01876059174538, 41.96905955672264, 56.50726564228535, 54.948653876781464, 56.93621702492237, 60.27614280581474, 71.43673673272133, 68.82314577698708, 67.73283988237381, 65.58721661567688, 67.56040513515472, 66.06700927019119, 70.58609917759895, 71.11066862940788, 69.75341185927391, 65.85947960615158, 67.35075518488884, 62.53193736076355, 65.40743306279182, 64.98146831989288, 64.17734786868095, 57.818126901984215, 60.959775522351265, 44.72685657441616, 38.597523272037506, 32.023887410759926, 19.53118186444044, 11.295974962413311, 18.89979064464569, 13.229969535022974, 24.58998341113329, 25.826039984822273, 12.870898302644491, 28.196440190076828, 28.53752888739109, 19.27043605595827, 19.83546193689108, 10.551357418298721, 16.037465035915375, 19.654112868010998, 4.263573093339801, 1.0631497018039227, 0.5977754923515022, 1.9038359471596777, 12.080315575003624, 22.884581722319126, 50.48544757068157, 47.32591710984707, 22.346614189445972, 36.22034803032875, 38.78425285220146, 46.467527970671654, 47.67129197716713, 51.93388044834137, 63.14463168382645, 66.11095771193504, 40.775851383805275, 10.812378711998463, 2.158575584180653, 0.16485324857058004, 0.20653809537179768, 0.23471523105399683, 0.24156118714017794, 0.1889290238614194, 0.16862733667949215, 0.18215042509837076, 0.1460131915519014, 0.10286557168001309, 0.21421592478873208, 0.17571083939401433, 0.2003990497905761, 0.1621712456108071, 0.22870131157105789, 0.19137224822770804, 0.1397743122652173, 0.16569577914196998, 0.15421848016558215, 0.19499372108839452, 0.3220677195349708, 0.2133459792821668, 0.187431666709017, 0.13294276868691668, 0.11942006618482992, 0.24874887254554778, 0.311904393020086, 0.2235969979665242, 0.1217091539001558, 0.24125316616846249, 0.13551940151955932, 0.15966839710017666, 0.12287132747587748], [0.09007804808788933, 0.045594313778565265, 0.02367234010307584, 0.034590330615174025, 0.021655058408214245, 0.031912108897813596, 0.04464809404453263, 0.10308016368071549, 0.042929873743560165, 0.03045663113880437, 0.008607287745689973, 0.03663987161417026, 0.08462318844976835, 0.049256248530582525, 0.03267700711148791, 0.02065170443529496, 0.04695277428254485, 0.05819794430863112, 0.07038265102892183, 0.033638555905781686, 0.06356954982038587, 0.03024740486580413, 0.03142914145428222, 0.04358197664259933, 0.018420420747133903, 0.0678138701186981, 0.04958232595527079, 0.03044796842004871, 0.06088642621762119, 0.042318986015743576, 0.007609272597619565, 1.4141068258322775, 9.968434497714043, 26.727763898670673, 46.24430514872074, 58.64787697792053, 53.04838724434376, 42.77744337916374, 29.523988254368305, 25.691777989268303, 22.986640445888042, 27.210717983543873, 32.34977312386036, 47.675893530249596, 28.081781342625618, 7.739623719826341, 2.288142694160342, 0.12027012213366106, 0.198786674591247, 2.211459008976817, 5.566440531983972, 4.000121355056763, 7.820426858961582, 11.06521999463439, 3.4770744340494275, 8.38580422103405, 13.60317125916481, 8.278122749179602, 12.419456876814365, 10.105307903140783, 9.926046822220087, 16.242220848798752, 20.80437194555998, 25.58045156300068, 31.707824170589447, 39.73455525934696, 50.523669719696045, 57.87920482456684, 58.72419588267803, 62.324662283062935, 65.92079311609268, 66.07775509357452, 62.1665907651186, 58.06408390402794, 60.34531809389591, 62.254027873277664, 65.95434531569481, 67.5195649266243, 69.58580285310745, 66.11269041895866, 63.80289316177368, 64.37098547816277, 58.89739818871021, 52.600862458348274, 52.922123819589615, 45.40848299860954, 35.45638382434845, 41.74765303730965, 41.19660660624504, 48.27897436916828, 50.27407631278038, 61.446392610669136, 64.61569234728813, 60.694929733872414, 62.483869940042496, 63.99694874882698, 66.66537836194038, 62.44581878185272, 63.17365072667599, 62.155635952949524, 60.880557373166084, 62.35574081540108, 57.22405157983303, 53.609313145279884, 55.912650749087334, 53.435366079211235, 49.94046941399574, 46.29719831049442, 41.546092852950096, 32.608569636940956, 30.885253809392452, 25.29197484254837, 13.639805093407631, 8.000472597777843, 7.114838445559144, 10.026489682495594, 8.962103147059679, 9.042012859135866, 11.942458022385836, 10.921892635524273, 9.645144045352936, 11.43944576382637, 9.972170647233725, 3.53989290073514, 8.721997831016779, 1.1822170251980424, 0.8109804487321526, 0.37544909573625773, 0.8826439501717687, 4.642177652567625, 19.082040265202522, 34.96402904391289, 26.391274854540825, 35.73682397603989, 23.585566207766533, 20.942593328654766, 22.14824963361025, 26.031949035823345, 39.839399233460426, 45.12831263244152, 48.583482429385185, 32.93278343975544, 5.614402033388615, 1.6819278546608984, 0.07075864530634135, 0.040288225063704886, 0.034052945193252526, 0.02086915741529083, 0.0879857259860728, 0.0258979352292954, 0.10243324839393608, 0.04022663793875836, 0.03404413218959235, 0.014998108781583142, 0.055581684500793926, 0.02005621812713798, 0.05920646362937987, 0.013696029236598406, 0.03451757787843235, 0.09322473939391784, 0.04481057243538089, 0.04788499711139593, 0.01959275803528726, 0.04888954594207462, 0.07615830400027335, 0.02862899415049469, 0.021334743760235142, 0.09754639890161343, 0.01589001443790039, 0.04840483074076474, 0.021513961291930173, 0.004660365966628888, 0.043665605553542264, 0.04983935024938546, 0.03291557419288438, 0.06880768007249571, 0.1063780156255234, 0.0396028405521065, 0.0640470402140636, 0.030192189078661613, 0.05535679520107806, 0.03323576267575845, 0.012177797325421125, 0.04519140922639053, 0.08842563402140513, 0.033867771926452406, 0.005885751506866654, 0.020407450647326186, 0.007063245329845813, 0.07111552185961045, 0.01665288844378665, 0.024917660193750635, 0.02247377902676817, 0.07405005540931597, 0.12358511768979952, 0.05138662425451912, 0.03725455913809128, 0.07697504493989982, 0.02290697619173443, 0.02320124887774, 0.029469782530213706, 0.09143415969447233, 0.058694849285529926, 0.04460293806914706, 0.041375174550921656, 0.053586899157380685, 0.050328830038779415, 1.1869573895819485, 10.695651825517416, 31.197296865284443, 53.71232181787491, 66.9518905878067, 59.264880269765854, 50.121810883283615, 35.74552170932293, 29.066373109817505, 24.418580308556557, 24.143938645720482, 29.452430494129658, 40.471510514616966, 31.44536465406418, 9.810256585478783, 3.384560323320329, 0.3526531392708421, 0.7057806593365967, 2.0142771396785975, 4.266301346942782, 5.463384361937642, 15.522823501378298, 11.933696642518044, 10.81323366612196, 10.777716021984816, 12.272725850343704, 13.632885664701462, 14.585612341761589, 11.821254026144743, 14.585404302924871, 7.145774960517883, 14.817356206476688, 24.638238921761513, 28.155655078589916, 38.98872368037701, 47.40219421684742, 57.49162942171097, 58.72893422842026, 62.10301637649536, 66.91717565059662, 67.9486683011055, 65.19681796431541, 63.31094115972519, 62.388213872909546, 64.45670887827873, 66.64055809378624, 70.35528436303139, 69.70466047525406, 65.82877725362778, 63.301008492708206, 64.5318840444088, 60.362968146800995, 53.18638063967228, 56.35980695486069, 51.281835436820984, 42.37493857741356, 48.50210599601269, 49.25420343875885, 55.631522834300995, 57.13713884353638, 65.12628614902496, 66.9611544907093, 63.89035686850548, 63.768801391124725, 65.42004838585854, 66.30906388163567, 65.17105534672737, 65.23375198245049, 64.61595833301544, 64.61278930306435, 64.8624587059021, 57.70104378461838, 57.20305770635605, 61.533643528819084, 59.26374793052673, 56.12617269158363, 52.263163179159164, 42.76520423591137, 34.79442894458771, 27.680467776954174, 20.37744775414467, 14.589716121554375, 9.175414200872183, 8.966608755290508, 12.460439577698708, 16.881050169467926, 12.825492639094591, 11.607164964079857, 15.699953846633434, 8.662179540842772, 17.052842751145363, 11.648527644574642, 6.38516359962523, 5.269585261121392, 2.720350264571607, 1.3145287754014134, 0.5777407111600041, 1.113388231024146, 5.074951155111194, 17.587234675884247, 38.91412988305092, 28.924769908189774, 34.308530017733574, 29.664656706154346, 28.857593312859535, 28.154473342001438, 34.13143292069435, 47.29759722948074, 50.621134489774704, 55.124960616230965, 40.05050450563431, 8.479584138840437, 2.0608925633132458, 0.07108496021828614, 0.07358279181062244, 0.02332774794922443, 0.028016020987706725, 0.020516023141681217, 0.00979773807557649, 0.013699506198463496, 0.04411723952216562, 0.02768130125332391, 0.07780415748129599, 0.08732817572308704, 0.03632089283200912, 0.08319605331053026, 0.01927905592310708, 0.03046731620997889, 0.07295369548955932, 0.05961671173281502, 0.03667471173685044, 0.018590251966088545, 0.026568409994069953, 0.057069133981713094, 0.0049497381587571, 0.11753182727261446, 0.09095753019209951, 0.0022749059689886053, 0.04239406538545154, 0.06084721484512556, 0.02142585723049706, 0.020351158746052533, 0.0921047198062297, 0.010024806506407913, 0.04781366929819342, 0.2236321460804902, 0.14296818932052702, 0.1670436974382028, 0.1475960886455141, 0.12168711953563616, 0.1156775638810359, 0.20743621280416846, 0.30238207429647446, 0.2906453056493774, 0.20826082793064415, 0.12599868583492935, 0.11395975918276235, 0.11889184999745339, 0.12817981332773343, 0.13931079651229084, 0.10435144780785777, 0.08340959146153182, 0.24825429049087688, 0.1402975560631603, 0.17154638160718605, 0.13310875743627548, 0.1891206909203902, 0.15457952016731724, 0.11080604715971276, 0.12371161676128395, 0.16684875008650124, 0.2038302063010633, 0.16648888267809525, 0.2666336519178003, 0.3313761216122657, 0.11378735085600056, 2.46733870357275, 14.936953838914633, 38.21662411093712, 63.789647072553635, 72.95724034309387, 66.74860149621964, 57.04738385975361, 41.944015100598335, 35.822034403681755, 33.83668273687363, 37.6538211107254, 46.14375874400139, 59.37572032213211, 35.10480009019375, 11.309423390775919, 3.659396725706756, 0.6363685964606702, 0.7884110847953707, 4.1839174926280975, 9.938057027757168, 9.437192603945732, 21.340773962438107, 25.541480854153633, 15.871974416077137, 22.298193387687206, 24.61008433252573, 21.48760948330164, 25.044171139597893, 17.490953542292118, 15.18506532534957, 23.795700632035732, 29.03802663087845, 33.720040395855904, 35.058123394846916, 44.76203128695488, 51.42546772956848, 59.61357235908508, 59.51277896761894, 62.88101702928543, 69.11346539855003, 69.0854761004448, 66.41453102231026, 63.241290897130966, 63.30518826842308, 65.25482565164566, 67.54201412200928, 71.39151155948639, 72.50900879502296, 67.07133337855339, 65.21671369671822, 66.00460141897202, 63.02541308104992, 58.10252644121647, 61.33147917687893, 53.17978039383888, 46.48199379444122, 54.57923769950867, 53.122285678982735, 58.43723528087139, 62.93734520673752, 66.89382210373878, 68.1316588819027, 66.62225067615509, 68.32167148590088, 68.43862161040306, 69.67151865363121, 67.29286149144173, 66.89971938729286, 66.67455106973648, 65.32639861106873, 66.00235193967819, 62.077903524041176, 63.79927575588226, 67.34457671642303, 65.43732225894928, 61.44402153789997, 56.412928104400635, 48.96071098744869, 41.33833900094032, 33.909946605563164, 30.89601293206215, 18.237121403217316, 15.04639271646738, 17.621814720332623, 17.283078096807003, 15.038594584912062, 16.23962938785553, 24.34536773711443, 19.822219647467136, 16.74246970564127, 26.811999678611755, 25.128756500780582, 11.478362325578928, 16.969585418701172, 4.003003025427461, 1.322028029244393, 0.9379460045602173, 1.3852047454565763, 5.6915502436459064, 25.23415334522724, 39.65640105307102, 36.19313769042492, 50.5094850808382, 34.91980321705341, 33.856825456023216, 34.60750177502632, 39.91768643260002, 54.23803120851517, 60.152189657092094, 62.360171377658844, 49.751706942915916, 13.441787268966436, 3.0979892006143928, 0.195620613230858, 0.18967216601595283, 0.0966090738074854, 0.2162899455288425, 0.14084977330639958, 0.13353553687920794, 0.1761189167154953, 0.1971005744417198, 0.1809252134989947, 0.16559201205382124, 0.18605631863465533, 0.16937980020884424, 0.18374491453869268, 0.06584730494068936, 0.07604359023389407, 0.1762449333909899, 0.1886984088923782, 0.18332598701817915, 0.12428528207237832, 0.19921247439924628, 0.1309788232902065, 0.22075164830312133, 0.20217205543303862, 0.15008428716100752, 0.16467853216454387, 0.13100561482133344, 0.165105163177941, 0.15270222793333232, 0.12023037270409986, 0.1429195489617996, 0.11712927152984776, 0.13852990872692317], [0.057320970663568005, 0.030520075488311704, 0.0346744382113684, 0.03796037497522775, 0.018333253647142556, 0.09362387383589521, 0.07804508830304258, 0.049237153070862405, 0.04013490477518644, 0.04460969903448131, 0.023605233254784252, 0.03293122979812324, 0.025333646954095457, 0.05261836304271128, 0.04066008928930387, 0.050437435929779895, 0.06345499932649545, 0.03432325764151756, 0.06418536911951378, 0.010867769378819503, 0.02300570224178955, 0.0837449383107014, 0.030057249932724517, 0.025891352379403543, 0.027944409303017892, 0.02155280530132586, 0.0545334565686062, 0.035493862014845945, 0.09951104191713966, 0.08088694987236522, 0.2579562534810975, 2.5397414434701204, 12.289127670228481, 32.596391290426254, 47.52674773335457, 53.52753013372421, 52.490740567445755, 32.89876006543636, 24.133865386247635, 26.080054454505444, 32.670806497335434, 29.797237291932106, 37.93143801391125, 32.10654817521572, 12.379583716392517, 5.016180658712983, 1.893966095522046, 0.8944292552769184, 0.8300417696591467, 1.8166939169168472, 1.7178637138567865, 6.077382015064359, 9.982646685093641, 7.096818862482905, 5.692418972030282, 9.300465490669012, 9.098535776138306, 13.269470315426588, 10.99378477782011, 16.837677396833897, 17.045906223356724, 9.497924745082855, 21.851928234100342, 28.810943216085434, 39.62627246975899, 50.18001616001129, 56.517528891563416, 62.65501655638218, 61.65489882230759, 62.42794834077358, 64.4397845864296, 63.62067013978958, 59.535463750362396, 60.78139789402485, 58.24117720127106, 60.415268540382385, 64.52440604567528, 65.26033535599709, 67.5594399869442, 69.93737518787384, 63.79669949412346, 64.32662665843964, 57.04315848648548, 59.09775383770466, 57.40743733942509, 51.818275451660156, 41.28747873008251, 42.37991251051426, 38.91118884086609, 46.27482131123543, 52.67336256802082, 60.93020170927048, 61.42751522362232, 59.03113201260567, 63.923247903585434, 65.30396461486816, 62.77361959218979, 59.85430844128132, 58.42459715902805, 60.313874781131744, 63.01871784031391, 55.0025387853384, 50.90934902429581, 54.22842152416706, 56.100584864616394, 54.76953528821468, 52.7143357694149, 44.67116676270962, 35.477354899048805, 29.71887979656458, 18.79621960222721, 13.672342747449875, 12.302648294717073, 11.367536522448063, 7.247040001675487, 14.698352292180061, 26.695036254823208, 12.702900767326355, 10.199382305145264, 7.165205217897892, 11.243542525917292, 11.606556996703148, 6.43946411088109, 3.6284758849069476, 2.243942515924573, 1.2399310595355928, 0.26059102616272867, 0.4231495986459777, 0.9708375146146864, 3.911112556234002, 16.046272963285446, 16.06794700026512, 21.86225987970829, 22.29472417384386, 19.18271016329527, 28.00851747393608, 27.648631185293198, 27.676320299506187, 37.289025485515594, 47.24764510989189, 48.76456931233406, 35.53272932767868, 15.256333351135254, 2.883376954123378, 0.4011542710941285, 0.08847259712638333, 0.018727781207417138, 0.04970118832716253, 0.07090013576089405, 0.013115283836668823, 0.02079842332022963, 0.05031724511354696, 0.028678103917627595, 0.0021787781315651955, 0.08279241403215565, 0.014913413033355027, 0.05419355664344039, 0.06267176635446958, 0.020238215001882054, 0.04540075795375742, 0.06172392502776347, 0.030603253544541076, 0.05487266258569434, 0.004655754910345422, 0.021383541825343855, 0.07404114963719621, 0.014674933154310565, 0.053426342929014936, 0.05051523898146115, 0.06621396300033666, 0.042227879966958426, 0.022248169843805954, 0.021133311893208884, 0.052019620561623015, 0.02957682248961646, 0.09208888979628682, 0.029541334843088407, 0.03726972863660194, 0.037661805254174396, 0.05501643143361434, 0.045558508863905445, 0.053987117134965956, 0.03532224036462139, 0.05645406054100022, 0.027872738246514928, 0.0542649957787944, 0.03599594718252774, 0.024289389511977788, 0.027737092204915825, 0.03798495119553991, 0.01959166707820259, 0.022307923863991164, 0.07928266408271156, 0.027818934395327233, 0.024150299905159045, 0.054952239370322786, 0.02473883971106261, 0.049376216702512465, 0.022014602982380893, 0.1102778161293827, 0.026114534739463124, 0.009747501171659678, 0.05187633039895445, 0.05722855843487196, 0.025989349269366357, 0.018337660148972645, 0.17432557622669265, 3.4128260565921664, 14.740159548819065, 38.44952501356602, 56.7854031175375, 62.115513905882835, 59.28435802459717, 38.73026914894581, 27.27956458926201, 28.91534261405468, 30.909479409456253, 27.13975679129362, 35.976404920220375, 41.41570284962654, 15.378844477236271, 6.00833117030561, 1.7548225494101644, 0.46497909002937376, 1.0398885374888778, 3.556553819216788, 4.805724676698446, 9.811898097395897, 9.620109088718891, 11.32155803963542, 9.902606830000877, 9.858882576227188, 15.47121562063694, 16.13078612834215, 12.397684045135975, 9.969052914530039, 16.757602393627167, 12.611177489161491, 17.36853551119566, 28.572667501866817, 39.70029629766941, 49.32896442711353, 57.344835698604584, 63.33085589110851, 61.49154178798199, 64.34293538331985, 65.40328368544579, 64.74074363708496, 62.10906185209751, 62.34311789274216, 60.08189722895622, 63.20781089365482, 66.88749924302101, 67.91561767458916, 68.55423420667648, 71.87261894345284, 63.44305247068405, 65.20189449191093, 60.56388236582279, 62.395106703042984, 58.99309605360031, 56.73038586974144, 47.391600385308266, 47.790088802576065, 46.76301911473274, 53.692167699337006, 57.86731906235218, 65.21298229694366, 64.75100308656693, 60.75055114924908, 64.82117012143135, 64.85144689679146, 64.24043968319893, 61.920933946967125, 60.90424910187721, 62.01190106570721, 65.17632946372032, 58.85478727519512, 57.84321315586567, 59.567104652523994, 59.488213285803795, 58.33919674158096, 54.96876619756222, 47.54518434405327, 40.33890523016453, 30.0251604616642, 21.38848040252924, 16.36186882853508, 13.905467838048935, 10.8810980245471, 8.992423620074987, 9.967341106384993, 12.738686297088861, 11.133956406265497, 10.810205228626728, 15.291799698024988, 6.196487573906779, 7.726500174030662, 9.431722797453403, 4.928164556622505, 2.4458791175857186, 3.503292314708233, 1.2701465631835163, 0.39980908390134573, 1.4493729709647596, 4.376000510528684, 18.54153446853161, 18.817032985389233, 24.03994582593441, 25.299500338733196, 22.24117174744606, 30.879877097904682, 28.171498328447342, 31.30211804062128, 42.76921682059765, 54.71015207469463, 55.75219675898552, 40.611498802900314, 17.551645785570145, 3.8894964661449194, 0.42125364881940186, 0.09915320057189092, 0.046982385974843055, 0.0879629940027371, 0.011752260979847051, 0.019731033135030884, 0.032670209038769826, 0.03485932946205139, 0.02747425503912382, 0.07711420505074784, 0.04369517642771825, 0.033486385946162045, 0.04987607913790271, 0.030132256943034008, 0.021845983319508377, 0.032817614410305396, 0.04013413665234111, 0.0312351588945603, 0.030516396291204728, 0.046366677997866645, 0.06674842064967379, 0.065606589341769, 0.02491484374331776, 0.07989857243956067, 0.05816728247737046, 0.022915701993042603, 0.03421738285396714, 0.06028931646142155, 0.02914963672083104, 0.047995499189710245, 0.031082102068467066, 0.02236070726212347, 0.0938412340474315, 0.18821484030922875, 0.16444511187728494, 0.10353846213547513, 0.1334153237985447, 0.14513916423311457, 0.17027183203026652, 0.1937416140572168, 0.1596244322718121, 0.16694079124135897, 0.09133063009358011, 0.11091274573118426, 0.1322196051478386, 0.12294826592551544, 0.14205876155756414, 0.1464001028216444, 0.1257510608411394, 0.13894586765673012, 0.2185613923938945, 0.07875903436797671, 0.09852633811533451, 0.1547444550669752, 0.0999423633038532, 0.20402804802870378, 0.149231574323494, 0.08832702485960908, 0.24677051464095712, 0.1573143937275745, 0.19146519480273128, 0.28277919336687773, 0.4804853454697877, 4.661287302151322, 20.18254291266203, 44.442704021930695, 65.21989792585373, 69.66355428099632, 67.53193706274033, 46.086028441786766, 37.44694881141186, 37.29858957231045, 45.44592998921871, 42.18104638159275, 50.25987267494202, 40.9319432079792, 17.521743290126324, 7.951740212738514, 2.877844925969839, 1.5396419959142804, 1.9231726345606148, 3.8113864324986935, 5.049103042110801, 17.741502597928047, 20.136278495192528, 18.323790952563286, 16.793326176702976, 19.371577128767967, 21.338406689465046, 25.24795040488243, 22.67416801303625, 29.080443754792213, 29.3371294811368, 15.006348565220833, 27.731559835374355, 35.428124740719795, 43.15364599227905, 53.81611704826355, 58.43388006091118, 64.5163656771183, 60.99306933581829, 63.78719240427017, 65.37692070007324, 66.76467463374138, 63.966854363679886, 65.16717195510864, 60.427066907286644, 65.57286858558655, 67.8611209988594, 68.24625313282013, 71.30264192819595, 72.53225594758987, 64.73994567990303, 65.55356562137604, 61.2765721231699, 65.99546670913696, 64.6187473833561, 59.096746891736984, 49.764098078012466, 53.3091102540493, 53.15917029976845, 56.92924439907074, 64.4486153125763, 72.29788452386856, 68.7350133061409, 63.67760248482227, 63.85860577225685, 68.57948765158653, 65.92026114463806, 64.38145011663437, 61.938667595386505, 64.55413565039635, 67.4672569334507, 63.984166234731674, 61.19306020438671, 64.67642828822136, 63.75936269760132, 62.72101141512394, 59.32247757911682, 55.46037241816521, 44.77767504751682, 39.57657873630524, 26.940223798155785, 20.012490637600422, 15.497107431292534, 16.748323291540146, 10.233804658055305, 21.5052405372262, 36.81397117674351, 22.21001721918583, 16.180073283612728, 14.90018891170621, 18.30314666032791, 19.35217346996069, 12.986486200243235, 10.362684242427349, 6.688441475853324, 5.26422374881804, 1.9007427943870425, 1.1449144268408418, 1.4615025138482451, 5.266318386420608, 17.90716040879488, 20.831352397799492, 33.85885834693909, 34.132139682769775, 30.78254722058773, 43.1211843341589, 41.952804028987885, 38.65285210311413, 51.10345020890236, 58.90660509467125, 65.62497138977051, 47.53947705030441, 22.524159662425518, 4.996439293026924, 0.8621528965886682, 0.21873849851544946, 0.19822028232738376, 0.1377597523969598, 0.30994871514849365, 0.1427522095036693, 0.130994823994115, 0.13166677934350446, 0.15267280919943005, 0.14456052653258666, 0.18134629324777052, 0.12083505978807807, 0.17009350878652185, 0.09535163815598935, 0.09247672132914886, 0.1596875741961412, 0.12534415611298755, 0.16050585138145834, 0.20760530373081565, 0.12545886245789006, 0.1682970512774773, 0.14813295827480033, 0.12129818962421268, 0.23525713244453073, 0.11583327388507314, 0.20441026892513037, 0.150658679776825, 0.09625998238334432, 0.11800897627836093, 0.12651620025280863, 0.17945010593393818, 0.18455162906320766], [0.036471745479502715, 0.009304020622948883, 0.019321840736665763, 0.02285514274262823, 0.049346471423632465, 0.11092161439592019, 0.08021888337680139, 0.009768476120370906, 0.015506122781516751, 0.015711626256234013, 0.035041753071709536, 0.025666949186415877, 0.043595617316896096, 0.08175841678166762, 0.028292263195908163, 0.03882256132783368, 0.05462358669319656, 0.032500101369805634, 0.028895308278151788, 0.08385359615203924, 0.06064794819394592, 0.049328144086757675, 0.0354359522316372, 0.02290930468006991, 0.007238996568048606, 0.019249073156970553, 0.03394553787074983, 0.014458783571171807, 0.040607274349895306, 0.02699489072256256, 0.2768956543877721, 4.330626195296645, 18.499265536665916, 35.12744687497616, 51.43385387957096, 54.83022943139076, 42.23190285265446, 29.78427428752184, 30.245425142347813, 26.21096882969141, 32.95566201210022, 47.654823660850525, 35.719071328639984, 15.582369156181812, 13.530652150511742, 2.2302157524973154, 0.9945603541564196, 0.1473072447697632, 1.1873649177141488, 1.9216943951323628, 5.127153228968382, 4.053644333034754, 11.176284234970808, 8.090905845165253, 12.36771885305643, 5.616911323741078, 12.236511893570423, 15.467970594763756, 9.98833877965808, 6.024265615269542, 27.575481310486794, 21.535908691585064, 22.849902883172035, 43.6056013405323, 47.82520271837711, 55.14044098556042, 59.58501309156418, 63.087433353066444, 60.414694771170616, 61.46417945623398, 63.34760159254074, 63.99365812540054, 61.26648746430874, 59.940332025289536, 56.08459912240505, 57.643055096268654, 59.70191761851311, 63.43128830194473, 66.13742709159851, 65.71503415703773, 64.2591118812561, 60.44594809412956, 60.49020051956177, 61.22696578502655, 55.43422222137451, 55.780440643429756, 47.77180418372154, 44.77798283100128, 41.38121210038662, 46.62393517792225, 51.29456475377083, 62.61140249669552, 58.42049337923527, 61.532176807522774, 66.91524535417557, 63.63384023308754, 62.89094589650631, 61.850128546357155, 61.47964462637901, 60.730818808078766, 56.91195532679558, 53.00785481929779, 61.59915581345558, 65.03768250346184, 63.89343470335007, 61.3474041223526, 55.268972888588905, 51.58091738820076, 46.756494864821434, 33.25382821261883, 29.46198508143425, 19.306129440665245, 16.90597303211689, 11.15639990195632, 15.063557345420122, 12.032542638480663, 17.04845018684864, 11.88148744404316, 11.172111108899117, 29.938264824450016, 3.012978262268007, 10.914580877870321, 8.658484239131212, 6.902034664526582, 2.8810472041368484, 4.212199375033379, 1.692665722221136, 0.7720596715807915, 0.3813300223555416, 2.2080361051484942, 4.286568984389305, 17.202927097678185, 22.470991015434265, 42.5925263017416, 46.20695695281029, 29.858395010232925, 23.81417904049158, 24.460913836956024, 36.503451839089394, 40.31077153980732, 49.54159341752529, 45.71572691202164, 20.722140558063984, 5.120611405000091, 0.21149561216589063, 0.03727431139850523, 0.11943652702029794, 0.03138529908028431, 0.006148593774923938, 0.03786344677791931, 0.017674267328402493, 0.01594292771187611, 0.12263068609172478, 0.017788569202821236, 0.023961694205354434, 0.03311314503662288, 0.036086941909161396, 0.049134443543152884, 0.023670371556363534, 0.0657537869119551, 0.024346534883079585, 0.08893784208339639, 0.02226504442660371, 0.04225044867780525, 0.013170588681532536, 0.048770984139991924, 0.03086994245677488, 0.024966042656160425, 0.04673340285080485, 0.03346302313730121, 0.0411913594143698, 0.06535753200296313, 0.02108508713718038, 0.033003989956341684, 0.0336894338397542, 0.01588973798789084, 0.04406121850479394, 0.055730154854245484, 0.03140721470117569, 0.005944893255218631, 0.036379021548782475, 0.02778561753075337, 0.05381404458603356, 0.02614669570903061, 0.060204277469892986, 0.06417360607883893, 0.024850794543453958, 0.058416146857780404, 0.09445170246181078, 0.06489064689958468, 0.051318417172296904, 0.03960813948651776, 0.03551808200427331, 0.10848825317225419, 0.017747992278600577, 0.04424212071171496, 0.04903357825241983, 0.05210203235037625, 0.003880654021486407, 0.07269613313837908, 0.03890085790771991, 0.008100954710243968, 0.05106735974550247, 0.06931703086593188, 0.011695085922838189, 0.055868231429485604, 0.3061543218791485, 5.493350503966212, 22.82459434121847, 41.61421179771423, 59.0997601300478, 61.821839064359665, 49.58941385149956, 31.092887967824936, 33.100039064884186, 28.440468795597553, 37.29121796786785, 39.891304448246956, 38.569317385554314, 17.878352254629135, 13.010212127119303, 3.6069906502962112, 1.0408215061761439, 0.7374602719210088, 1.8788368511013687, 6.111955409869552, 8.85055348277092, 10.455868542194366, 10.895525850355625, 12.058135215193033, 9.471910391002893, 12.063750363886356, 12.0516537129879, 11.040487121790648, 7.9706935957074165, 11.190659813582897, 20.014605224132538, 19.017966203391552, 25.92400062829256, 40.10892257094383, 48.09536822140217, 53.45552399754524, 59.13780748844147, 62.192037999629974, 60.29157377779484, 62.83799573779106, 66.25651270151138, 65.58679103851318, 63.20010490715504, 61.05390787124634, 60.413691624999046, 60.73592573404312, 60.758937299251556, 64.75071430206299, 66.6232842206955, 67.30828866362572, 63.92205476760864, 60.622015446424484, 62.123900055885315, 63.25801379978657, 57.88170509040356, 58.30119878053665, 52.65243709087372, 50.18916606903076, 46.21120512485504, 53.587840497493744, 57.45175056159496, 64.87080305814743, 61.05911359190941, 63.80449667572975, 68.56315612792969, 67.26234152913094, 62.999262884259224, 63.389691933989525, 63.526963368058205, 62.12887778878212, 60.10491259396076, 57.883494794368744, 64.01071161031723, 68.45159411430359, 65.53237795829773, 64.85919088125229, 60.604505985975266, 57.72519148886204, 51.79107651114464, 40.89834541082382, 32.25994974374771, 20.38315124809742, 16.31757840514183, 9.97613763436675, 9.137800019234419, 8.009146582335234, 11.767756696790457, 9.974025897681713, 8.71250119060278, 16.7508140578866, 10.059855692088604, 11.461675520986319, 11.086755339056253, 9.923264421522617, 7.07885580137372, 4.733144296333194, 1.9311305950395763, 1.0434939502738416, 0.29686952009797096, 3.014889797195792, 5.928883133456111, 19.49198506772518, 23.60951442271471, 36.79920896887779, 38.500503078103065, 33.665152341127396, 31.443430557847023, 31.07798896729946, 44.35253106057644, 46.56095735728741, 55.528027787804604, 51.49886839091778, 24.26257397979498, 6.276725968346, 0.36990210588555783, 0.05579802054853644, 0.06040857217158191, 0.006374793892973685, 0.03400643850909546, 0.040713126873015426, 0.03856633855320979, 0.04880214692093432, 0.03995658153144177, 0.02410989924101159, 0.010012496131821536, 0.05160272652574349, 0.08816599365673028, 0.05889892505365424, 0.05180043095606379, 0.005268682152745896, 0.043524501015781425, 0.0658838111849036, 0.036093665767111816, 0.04154337861109525, 0.10308441618690267, 0.07975143424118869, 0.04725786377093755, 0.046926327850087546, 0.04338314785854891, 0.05634482382447459, 0.027203777463000733, 0.00829361253636307, 0.03129351396637503, 0.017315650438831653, 0.03164033070788719, 0.045474931903299876, 0.10728696841397323, 0.1322628278285265, 0.10452355185407214, 0.10926969756837934, 0.11652091081487015, 0.12517714319983497, 0.18353317980654538, 0.1584585034288466, 0.15857895399676636, 0.19094483053777367, 0.17337053606752306, 0.1265336704091169, 0.1774049992673099, 0.2246594417374581, 0.18943862698506564, 0.11477402877062559, 0.15404463949380443, 0.23747118160827085, 0.18317927926545963, 0.23715605086181313, 0.17480383103247732, 0.1880505881854333, 0.23018124309601262, 0.1095787798112724, 0.11946308106416836, 0.1137710755574517, 0.10642740555340424, 0.18450848059728742, 0.11996907735010609, 0.15006628265837207, 0.5406875337939709, 8.612509556114674, 27.02176172286272, 49.4028552621603, 70.29021665453911, 69.38100904226303, 54.648454785346985, 39.78244408965111, 41.96429081261158, 37.71615296602249, 47.377544939517975, 61.43455244600773, 47.332980930805206, 22.406360283493996, 17.88727417588234, 3.8972668116912246, 1.9614294567145407, 0.8754125225823373, 3.8168676383793354, 6.612787060439587, 16.063790023326874, 13.82454738020897, 20.882311463356018, 16.35996513068676, 22.567467838525772, 17.67145335674286, 23.296903297305107, 27.086458951234818, 16.263328716158867, 12.591824177652597, 34.9077844619751, 28.339088335633278, 28.522550091147423, 46.907795146107674, 49.960501939058304, 57.91884049773216, 58.297695368528366, 61.794586926698685, 60.80463744699955, 61.8639750033617, 67.51881256699562, 68.08874398469925, 64.78308096528053, 62.84075818955898, 61.549868658185005, 62.983208745718, 63.592760637402534, 68.05507019162178, 69.2715673148632, 70.47965168952942, 65.01100793480873, 60.91128632426262, 62.679289653897285, 62.837064787745476, 62.25812405347824, 59.989672377705574, 53.14059689640999, 53.643674701452255, 54.194493144750595, 57.560192942619324, 62.00069546699524, 68.76902148127556, 63.94706502556801, 63.718070313334465, 69.82270494103432, 68.40516060590744, 67.03724160790443, 65.75647473335266, 66.89625397324562, 65.87517276406288, 63.78659963607788, 61.33654810488224, 68.01070377230644, 67.1650667488575, 64.58169177174568, 64.11618635058403, 61.16969905793667, 59.68715161085129, 56.542919129133224, 44.70449477434158, 40.038675740361214, 26.17226030677557, 22.575983181595802, 15.44089324772358, 20.787966325879097, 20.75322099030018, 26.86450906097889, 22.211084961891174, 22.763541117310524, 44.813427329063416, 18.61590787768364, 21.760263852775097, 21.04866273701191, 19.840622060000896, 10.436085853725672, 10.604309476912022, 5.553637593984604, 1.0366984899155796, 0.90487863519229, 3.0738854315131903, 6.362884445115924, 24.004759714007378, 30.933980494737625, 56.475088968873024, 61.64988309144974, 45.31186178326607, 40.00920072197914, 37.28806033730507, 50.41899673640728, 53.12934949994087, 61.68529339134693, 60.72803735733032, 31.785410307347775, 8.948407731950283, 0.6823106249794364, 0.26334127702284604, 0.3187344077741727, 0.14961818873416632, 0.10716054355725646, 0.16685164446244016, 0.09199043648550287, 0.13560471881646663, 0.1766190055059269, 0.13031715410761535, 0.15402176650241017, 0.07591252695419826, 0.32883886713534594, 0.12698443606495857, 0.14628217555582523, 0.18976776947965845, 0.15042475482914597, 0.11683011922286823, 0.10824438344570808, 0.16990693286061287, 0.19779654568992555, 0.18742333981208503, 0.09633459048927762, 0.1579220494022593, 0.151291434885934, 0.08737124997423962, 0.250518805696629, 0.1445979901473038, 0.17283233057241887, 0.17754640808561817, 0.11166067473823205, 0.12467168126022443], [0.042064934023073874, 0.022986222720646765, 0.051812275632983074, 0.04721631463326048, 0.06150575587525964, 0.0525730103981914, 0.04727506675408222, 0.06770622901967727, 0.03426835726713762, 0.006395316595444456, 0.04093940769962501, 0.02812423354043858, 0.012379047366266605, 0.02548561096773483, 0.07647704900591634, 0.016388631920563057, 0.05144214432220906, 0.045382241369225085, 0.027203092831769027, 0.02878042752854526, 0.02735681573540205, 0.061848234763601795, 0.1314805744914338, 0.0700169058109168, 0.030976962007116526, 0.060957831956329755, 0.08182527686585672, 0.07739056600257754, 0.050555073758005165, 0.009128981382673373, 0.8713292854372412, 8.095273710787296, 23.574026226997375, 43.513669073581696, 48.85609120130539, 49.55949805676937, 44.94763992726803, 33.02655480802059, 21.372129879891872, 26.789607480168343, 37.21024431288242, 33.287775591015816, 17.745661474764347, 22.88508329540491, 7.3097090888768435, 1.1826137476600707, 0.17840428627096117, 0.2853233349742368, 1.1380547261796892, 7.5558066833764315, 4.056081902235746, 11.694999150931835, 5.48975732177496, 13.473602961748838, 5.12324751354754, 6.633911551907659, 12.760454379022121, 8.154512532055378, 8.816536758095026, 14.409962967038155, 22.91889578104019, 31.308456100523472, 36.835971996188164, 44.82752837240696, 52.87448577582836, 57.18834109604359, 63.89342710375786, 61.36477679014206, 62.18810901045799, 60.49951381981373, 62.711789309978485, 62.581927478313446, 60.8064803481102, 59.594957157969475, 57.94101610779762, 58.474446684122086, 57.92344205081463, 58.91078867018223, 63.601849749684334, 66.44911676645279, 65.24986311793327, 59.93274003267288, 56.77128687500954, 59.06903117895126, 56.092791482806206, 54.812412187457085, 50.58754049241543, 45.458332523703575, 41.851292476058006, 39.82980474829674, 54.243799299001694, 48.93171854317188, 55.0431814044714, 61.98143810033798, 62.80209146440029, 61.323731392621994, 58.69966059923172, 59.306754022836685, 59.17037934064865, 56.81736320257187, 55.2057670801878, 60.3348458558321, 64.78810429573059, 64.73239928483963, 63.79534676671028, 64.10743162035942, 64.87657874822617, 58.333067670464516, 55.66101685166359, 46.21234506368637, 39.46595147252083, 32.945212572813034, 28.981160782277584, 17.914022840559483, 14.035378117114305, 7.524528661742806, 9.330089651048183, 6.509397458285093, 5.101621448993683, 8.995392210781574, 5.264081731438637, 4.96349411085248, 9.854791145771742, 5.803830893710256, 3.804008890874684, 3.7679673498496413, 0.9535711817443371, 1.1568953027017415, 0.8310971630271524, 1.3372026337310672, 7.321006832644343, 12.249458748847246, 16.24875459820032, 25.99867232143879, 35.42141430079937, 31.278986781835556, 18.94746668636799, 19.930437840521336, 24.595280326902866, 36.03651009500027, 44.07613009214401, 45.02296708524227, 34.2213436961174, 11.952933110296726, 0.5797788267955184, 0.036582737375283614, 0.04663339474063832, 0.055736526192049496, 0.05494447650562506, 0.03867531180731021, 0.10662885411875322, 0.06866808209451847, 0.028264015199965797, 0.025517092872178182, 0.049588897672947496, 0.06648193026194349, 0.0546883576316759, 0.02791456012346316, 0.016087687326944433, 0.02670537149242591, 0.023780515548423864, 0.00950596642724122, 0.06194988302013371, 0.034979186311829835, 0.01291413862418267, 0.013303851501405006, 0.059482475771801546, 0.026312007248634472, 0.016444575012428686, 0.038939030273468234, 0.049383894220227376, 0.010818648479471449, 0.16712497745174915, 0.053815599385416135, 0.029968986309540924, 0.03782451000006404, 0.06667676629149355, 0.0024439245362373185, 0.020262648358766455, 0.02504726144252345, 0.016793781469459645, 0.02796706150547834, 0.0438781974662561, 0.04709875844127964, 0.010315690360584995, 0.01937549986905651, 0.020829183486057445, 0.0421105427085422, 0.026607385734678246, 0.02609157640108606, 0.03778099788178224, 0.03803334664553404, 0.04634247285139281, 0.04946462133375462, 0.01852730300015537, 0.04515315893513616, 0.020554709444695618, 0.05697392756701447, 0.035860946809407324, 0.04282247755327262, 0.028641773933486547, 0.04340734187280759, 0.06594236663659103, 0.038443921293946914, 0.05616025169729255, 0.13249409588752314, 1.3070474518463016, 9.982572589069605, 26.775624230504036, 50.75453773140907, 57.11852364242077, 56.56354822218418, 47.855490893125534, 35.4946705698967, 25.326228104531765, 29.687440283596516, 34.495548382401466, 39.12175454199314, 21.36148665100336, 19.31126296520233, 7.742156758904457, 1.4511832175776362, 0.22394904313841835, 0.9924912464339286, 2.3556073615327477, 8.181025609374046, 7.970439959317446, 10.751406233757734, 9.35629304498434, 14.180620573461056, 8.716887105256319, 12.156890965998173, 11.475595124065876, 10.882253162562847, 8.225294183939695, 11.744045969098806, 21.877542659640312, 30.543507747352123, 37.976438999176025, 46.580575704574585, 52.972984090447426, 58.503636717796326, 62.85120762884617, 61.0242922604084, 61.44521087408066, 61.79566986858845, 64.89509895443916, 65.24344146251678, 63.108313232660294, 60.77005170285702, 59.03482161462307, 59.53873537480831, 59.67951022088528, 60.90060509741306, 67.11066126823425, 67.11710572242737, 66.09168514609337, 62.56275370717049, 59.264272302389145, 61.318286284804344, 57.081475630402565, 57.90144123136997, 52.84172773361206, 50.27585841715336, 47.349152863025665, 46.79276391863823, 57.49692253768444, 53.219803646206856, 56.99965842068195, 65.67278042435646, 65.85588499903679, 63.71825650334358, 60.08169963955879, 60.04432484507561, 61.25910446047783, 62.065424993634224, 59.88981373608112, 63.6653633415699, 66.68323740363121, 65.6777885556221, 66.24296262860298, 66.16115301847458, 63.21316860616207, 60.94307541847229, 56.19873359799385, 50.638936534523964, 42.26637840270996, 36.58040151000023, 29.694093726575375, 19.74678609520197, 15.198075827211142, 6.848222427070141, 8.969408255070448, 7.3082556668668985, 4.519675076007843, 11.759925317019224, 8.689108695834875, 12.728422097861767, 14.36931274831295, 8.646456934511662, 7.935216324403882, 4.036248391494155, 2.305724825710058, 2.081451597623527, 0.9543596988078207, 1.8459335854277015, 6.5358559135347605, 13.24035057798028, 20.855684392154217, 32.10544243454933, 43.102960512042046, 33.22172373533249, 23.676037453114986, 24.658797718584538, 31.063034869730473, 40.589710772037506, 49.97749462723732, 52.0474411547184, 39.552651420235634, 13.781727477908134, 1.1165848094969988, 0.016734947712393478, 0.03183878099662252, 0.003966658268836909, 0.09074805158888921, 0.04819141133339144, 0.1406408884213306, 0.025406021195522044, 0.02334058895939961, 0.047192539932439104, 0.032702318057999946, 0.057397133568883874, 0.017707409788272344, 0.011503967125463532, 0.09074146873899736, 0.051814353646477684, 0.04501242176047526, 0.02316892092494527, 0.006656686164205894, 0.051103969890391454, 0.02238077864603838, 0.02892257663916098, 0.05316108450642787, 0.007171998722697026, 0.02286647719301982, 0.06840340254711919, 0.015511742694798158, 0.07886168081313372, 0.10081061671371572, 0.017169282218674198, 0.06327147362753749, 0.030999569680716377, 0.22794972377596423, 0.07673141270061024, 0.126797592965886, 0.2008742914767936, 0.1514283611322753, 0.15828308940399438, 0.17547875497257337, 0.23108082998078316, 0.16852765140356496, 0.07451023149769753, 0.11724934360245243, 0.13649109547259286, 0.14726503140991554, 0.10737805219832808, 0.12253441469511017, 0.10117630255990662, 0.13449995778501034, 0.12512612796854228, 0.10783021309180185, 0.09813782380660996, 0.12339786640950479, 0.09288291359553114, 0.205093119002413, 0.12670978205278516, 0.13506869523553178, 0.10750304471002892, 0.2658356650499627, 0.11373579385690391, 0.1343596918741241, 0.2630121790571138, 2.017653496004641, 14.273768775165081, 33.803597912192345, 59.18529734015465, 65.3807432949543, 63.71506467461586, 57.038762122392654, 43.9656738191843, 30.885212011635303, 38.530472069978714, 53.31909991800785, 47.45197534561157, 26.431748382747173, 27.84206360578537, 9.05575767159462, 2.130635208450258, 0.6301041576080024, 0.7077888515777886, 4.5142413675785065, 19.23668436706066, 15.29574578627944, 23.590678833425045, 15.504434388130903, 27.3382106423378, 15.460297856479883, 17.061914764344692, 24.905793964862823, 18.145950995385647, 16.51223625987768, 22.95354802161455, 31.85333166271448, 39.57095503807068, 40.326605290174484, 47.17112481594086, 54.25816252827644, 59.74373057484627, 64.82626184821129, 61.037021577358246, 61.92372679710388, 62.00547181069851, 66.68455213308334, 67.6977601647377, 64.77214515209198, 64.54626247286797, 62.56295129656792, 61.659458577632904, 61.000053361058235, 62.039742171764374, 67.96820685267448, 69.38658714294434, 66.73516541719437, 64.20703947544098, 60.556339770555496, 60.892606526613235, 59.640079736709595, 59.509077966213226, 56.03289529681206, 54.283073991537094, 54.53959822654724, 50.64262613654137, 63.51858101785183, 57.13425859808922, 61.82489410042763, 69.00811225175858, 67.37246721982956, 66.09496057033539, 64.37124386429787, 64.24399629235268, 65.34725949168205, 64.10062998533249, 63.59283663332462, 64.17046263813972, 65.06086885929108, 63.82118538022041, 66.10488563776016, 67.2996099293232, 66.98564037680626, 63.1285585463047, 59.127061665058136, 51.25753194093704, 45.04002816975117, 40.164251402020454, 34.88718196749687, 25.08981429040432, 20.00633306801319, 13.01947982981801, 18.005254045128822, 13.0868074670434, 12.881916761398315, 19.009530656039715, 14.435782581567764, 12.098456751555204, 15.802725031971931, 13.569017741829157, 10.139179285615683, 9.997587483376265, 2.3738050600513816, 2.9071769770234823, 1.4788235281594098, 2.396830399520695, 8.930929619818926, 16.120541878044605, 22.559944242239, 37.9516377300024, 48.74634549021721, 46.570038869977, 34.9097603559494, 34.09025453031063, 38.239054307341576, 49.80832390487194, 58.32728438079357, 59.61027413606644, 46.55327036976814, 18.240664713084698, 2.2096626553684473, 0.12027857519569807, 0.09744302515173331, 0.21809492289321497, 0.130638103291858, 0.1779256307054311, 0.3505480522289872, 0.22046722762752324, 0.10428829104057513, 0.11429226360633038, 0.09823943866649643, 0.153073895489797, 0.1324044296052307, 0.08604118775110692, 0.2650119998725131, 0.12831905507482588, 0.11533597556990571, 0.1360326263238676, 0.2298323149443604, 0.21872870216611773, 0.14838236442301422, 0.10461610509082675, 0.1374284873600118, 0.0813177517557051, 0.07301976889721118, 0.1662464824039489, 0.11207640360225923, 0.1191504365124274, 0.23408396024024114, 0.1764307523262687, 0.15825027163373306, 0.06901367058162577], [0.04809597856365144, 0.012169330348115182, 0.047509778378298506, 0.01430975753464736, 0.07399743713904172, 0.040966922824736685, 0.029642918161698617, 0.023805410892236978, 0.05617463823000435, 0.06183565536048263, 0.015558165887341602, 0.029974047756695654, 0.04832896840525791, 0.08129873793222941, 0.040729617394390516, 0.03311632142867893, 0.03040710205823416, 0.04169260966591537, 0.04692789007094689, 0.027575146305025555, 0.04945816835970618, 0.048595625776215456, 0.015583776475978084, 0.08684540865942836, 0.044216902533662505, 0.01526888878288446, 0.08153961680363864, 0.04055520526890177, 0.056511610382585786, 0.06415510433726013, 2.3929073475301266, 14.079516548663378, 30.84900565445423, 49.030593037605286, 56.52431532740593, 53.485606983304024, 38.38685877621174, 31.821785755455494, 25.627835020422935, 26.120419688522816, 40.08580081164837, 25.094355046749115, 22.871664315462112, 9.673307184129953, 3.814477566629648, 0.6272661255206913, 0.09213249097228982, 1.8148120678961277, 0.801880827639252, 4.152890732511878, 8.445765953511, 7.248709537088871, 10.469135530292988, 9.109757523983717, 7.866905014961958, 14.059918150305748, 6.370983235538006, 10.663760136812925, 10.830262452363968, 24.86554842442274, 33.492626398801804, 36.856338903307915, 47.044219225645065, 52.6362157613039, 55.80717220902443, 62.314003854990005, 60.07237873971462, 63.95466461777687, 61.31859786808491, 63.12314383685589, 62.85937339067459, 63.331551253795624, 59.22106482088566, 52.88253754377365, 52.29498267173767, 55.39009138941765, 59.29159663617611, 61.307259276509285, 63.19751724600792, 63.31664465367794, 66.47772163152695, 51.90810263156891, 55.38620799779892, 62.4371362477541, 57.302578166127205, 54.39029663801193, 47.02895924448967, 43.43359597027302, 40.0776806473732, 45.99049396812916, 44.97466787695885, 52.597545236349106, 63.9228755235672, 60.60734823346138, 58.885884806513786, 57.72482670843601, 56.281572952866554, 58.083409667015076, 56.810918748378754, 56.09352104365826, 60.88727921247482, 65.46302407979965, 64.05310213565826, 64.07219231128693, 65.00399351119995, 65.62275990843773, 63.47193092107773, 62.07325257360935, 59.595481529831886, 56.236286982893944, 53.02773915231228, 40.49745932221413, 33.012613356113434, 26.134824715554714, 16.61197140812874, 14.70143772661686, 5.916411727666855, 7.6057773269712925, 3.4202677197754383, 9.822746515274048, 5.712450072169304, 15.098989494144917, 12.98072000965476, 5.410878304392099, 8.788869492709637, 1.6853741509839892, 2.483720574527979, 1.475802215281874, 0.1884642316144891, 2.375839613378048, 2.9324662825092673, 9.465170502662659, 12.088298946619034, 20.718137472867966, 27.881541587412357, 21.60101629793644, 20.55094264447689, 19.0307829156518, 31.763217598199844, 38.50356571376324, 46.876093447208405, 46.09862856566906, 42.286137342453, 19.57733988761902, 3.8036982575431466, 0.013035349893470993, 0.056134918486350216, 0.04954445787006989, 0.026177608015132137, 0.033256594761041924, 0.054414735204773024, 0.09841578037594445, 0.011672775108308997, 0.052485915657598525, 0.04140664161241148, 0.010560949758655624, 0.05399231959017925, 0.019665991312649567, 0.08581584945204668, 0.01654908981436165, 0.04606699134455994, 0.02423340189125156, 0.05240817568846978, 0.04547590411675628, 0.01603922322829021, 0.04001723355031572, 0.04765033743751701, 0.0340283838158939, 0.03969682984461542, 0.062122057570377365, 0.04355680299340747, 0.00921993992960779, 0.031772470101714134, 0.05858110402186867, 0.008401102422794793, 0.023076594043232035, 0.032799138643895276, 0.012553172837215243, 0.047278588244807906, 0.01892592536023585, 0.024010017295950092, 0.0480181272723712, 0.0442035141895758, 0.04883497582341079, 0.014811743440077407, 0.03765550813113805, 0.03046032888960326, 0.05119458612171002, 0.06136909309134353, 0.012783812853740528, 0.05795932527689729, 0.021335331912268884, 0.04999533113732468, 0.027178084310435224, 0.048043412243714556, 0.06900382228195667, 0.022134122154966462, 0.07928564009489492, 0.030465614836430177, 0.05282647238345817, 0.021366051259974483, 0.05726541348849423, 0.03957508051826153, 0.056242823047796264, 0.01891125866677612, 0.004470897983992472, 3.6119581712409854, 15.35116771236062, 35.87672106921673, 55.327265560626984, 61.89263306558132, 58.33695866167545, 44.880501329898834, 34.07652206718922, 26.817678473889828, 29.270336665213108, 45.83195507526398, 28.424424156546593, 21.57211694866419, 11.101288609206676, 3.537976616062224, 0.9520630782935768, 0.20365973497973755, 2.782688532024622, 3.065409748815, 8.25039278715849, 8.130822703242302, 14.052231162786484, 8.85705303400755, 9.189608339220285, 9.331601969897747, 5.339992633089423, 6.18882006034255, 8.479604087769985, 12.850700486451387, 24.31680466979742, 29.496907107532024, 37.780658304691315, 43.67017887532711, 52.19586879014969, 57.29049101471901, 62.381773218512535, 61.04500114917755, 62.63675853610039, 60.941407307982445, 63.22507716715336, 64.83383104205132, 65.27172714471817, 61.77308388054371, 54.5968421548605, 55.44315554201603, 58.01403298974037, 61.09557643532753, 62.7956698089838, 66.09976351261139, 65.25326773524284, 67.38816797733307, 55.90586431324482, 58.73766615986824, 62.57362872362137, 59.32917281985283, 57.95067138969898, 51.48698642849922, 47.77944177389145, 46.86248637735844, 53.223584443330765, 49.92753490805626, 54.43681374192238, 64.89451378583908, 61.63922846317291, 61.36728085577488, 61.12003192305565, 58.58551852405071, 59.43923011422157, 59.813950806856155, 60.434176325798035, 64.58499759435654, 67.3772169649601, 66.76912039518356, 64.92201671004295, 64.15251240134239, 65.48285141587257, 63.32786165177822, 63.4370031952858, 61.33910536766052, 56.91914074122906, 53.54094721376896, 42.913593873381615, 35.24997889995575, 27.708990946412086, 16.43053874373436, 12.777621857821941, 5.985422674566507, 5.684608491137624, 5.431327382102609, 10.23658325895667, 14.463078416883945, 17.913107089698315, 14.383626580238342, 7.368262046948075, 10.642827060073614, 5.922846682369709, 2.629778799600899, 3.055944931693375, 0.8526465191971511, 2.3368119075894356, 3.5921298852190375, 10.157737489789724, 14.421391803771257, 21.179466918110847, 29.117980040609837, 28.042274862527847, 30.46390011906624, 27.879231311380863, 38.49556714296341, 45.00074967741966, 51.94204241037369, 52.01675400137901, 46.40593707561493, 22.492714449763298, 4.816888002678752, 0.12384648725856096, 0.006670004468105617, 0.04107327629753854, 0.018738017279247288, 0.054496824159286916, 0.05745973743614741, 0.05540845239011105, 0.008524937184120063, 0.07375728557235561, 0.04114240735361818, 0.03958517743740231, 0.0451045259978855, 0.050009172191494144, 0.03375883577973582, 0.02853283593140077, 0.019543783710105345, 0.013955293889011955, 0.015916562915663235, 0.06605271657463163, 0.016534337773919106, 0.07781751613947563, 0.06773278306354769, 0.08931688658776693, 0.06550078134750947, 0.05696331485523842, 0.06576621788553894, 0.02906423222157173, 0.03897415612300392, 0.06400323865818791, 0.045999489302630536, 0.049568503454793245, 0.22750072443159297, 0.07067479004035704, 0.13664639729540795, 0.14890896272845566, 0.17910289956489578, 0.16255728114629164, 0.10039329223218374, 0.16290459141600877, 0.1427441052510403, 0.11366903025191277, 0.049422704832977615, 0.20696745748864487, 0.12368372685159557, 0.11434694504714571, 0.19843598012812436, 0.15033333707833663, 0.1479546944028698, 0.10800326708704233, 0.19470630213618279, 0.13399167568422854, 0.16496327938511968, 0.1813453432987444, 0.11546283087227494, 0.20201850507874042, 0.1464764995034784, 0.13540404208470136, 0.1749561939504929, 0.08922077104216442, 0.1432048305287026, 0.224544245575089, 4.926763381808996, 20.640650130808353, 41.93030923604965, 64.35992047190666, 71.30752086639404, 65.23832693696022, 51.36547654867172, 43.571087792515755, 35.455057695508, 38.19208882749081, 54.300997629761696, 36.221320778131485, 31.9503765553236, 13.122115172445774, 5.467312876135111, 1.42791599733755, 0.4538685752777383, 4.9295771308243275, 4.681660383939743, 14.67261627316475, 19.034225530922413, 19.208560176193714, 20.63591368496418, 20.830995216965675, 19.75305385887623, 23.032494485378265, 14.14036363363266, 19.231978319585323, 19.26426898688078, 33.90547804534435, 41.52789182960987, 44.76091794669628, 48.185807168483734, 54.46016728878021, 56.172693595290184, 63.95398825407028, 59.038488417863846, 62.66098603606224, 60.519903525710106, 65.35434231162071, 68.25633779168129, 67.67732486128807, 62.90367141366005, 55.85444927215576, 57.28963226079941, 61.69121727347374, 62.81017363071442, 65.46530395746231, 67.08714812994003, 69.08128872513771, 66.5722605586052, 59.06532257795334, 59.28500398993492, 61.558023020625114, 63.25257249176502, 62.02898494899273, 56.836362183094025, 54.991393983364105, 52.065505385398865, 57.30251356959343, 54.24812726676464, 56.762957721948624, 68.15847784280777, 65.63687235116959, 64.4416768848896, 63.77193242311478, 62.73939862847328, 62.11396738886833, 63.15288484096527, 62.15024024248123, 64.94799971580505, 68.28810408711433, 67.0618262887001, 67.61142879724503, 69.1682280600071, 68.34329232573509, 65.58587148785591, 66.94981589913368, 64.09230843186378, 60.58963358402252, 57.15038113296032, 44.88728776574135, 36.95762246847153, 30.62604881823063, 20.221838504076004, 17.415273003280163, 9.26474740728736, 13.616525642573833, 9.579934794455767, 17.106070294976234, 13.677512370049953, 22.297019250690937, 24.486967138946056, 15.7799101062119, 17.709327824413776, 9.452135302126408, 7.253550477325916, 4.754430279135704, 1.4302958571352065, 4.225507210940123, 3.8431589026004076, 11.405129805207253, 17.33061734586954, 30.482255034148693, 42.810813188552856, 35.241854935884476, 34.34740953147411, 29.76555649191141, 47.39927597343922, 51.37599818408489, 60.09377159178257, 60.10038323700428, 53.04154381155968, 27.256864607334137, 6.736947298049927, 0.2678691199980676, 0.1687211886746809, 0.1897119896602817, 0.17612561088753864, 0.1633331668563187, 0.19011907250387594, 0.17024138913257048, 0.04837782027607318, 0.18148697476135567, 0.19609264883911237, 0.11937444636714645, 0.16609291720669717, 0.16823799116536975, 0.1862912529031746, 0.07288517299457453, 0.14713131124153733, 0.0915369694121182, 0.10234548200969584, 0.18358349741902202, 0.11282626961474307, 0.11978993032244034, 0.12116146375774406, 0.1558058598311618, 0.23427867010468617, 0.21246292744763196, 0.13922261452535167, 0.06832570710685104, 0.16867826285306364, 0.2184321844833903, 0.13630882400320843, 0.10532776534091681], [0.025688267378427554, 0.049782308778958395, 0.09321962599642575, 0.06268622339121066, 0.03500882026855834, 0.004900359363091411, 0.045922038771095686, 0.05967822464299388, 0.021057766825833824, 0.012510692304203985, 0.026043731995741837, 0.02267614043375943, 0.06303020883933641, 0.03598156064981595, 0.021335758647182956, 0.01581054340931587, 0.07241289989906363, 0.0765345135005191, 0.04390783884446137, 0.028130276477895677, 0.04947793917381205, 0.048488634056411684, 0.028825728222727776, 0.09801682404940948, 0.06213775028300006, 0.02152762423065724, 0.014065491686778842, 0.015145022480282933, 0.07520897095673718, 0.182362130144611, 5.0534276850521564, 16.66401531547308, 31.067685820162296, 54.69029054045677, 45.57427570223808, 40.21873667836189, 30.579313226044178, 23.540616519749165, 22.28427853435278, 27.932939529418945, 20.045071989297867, 24.931828267872334, 19.111959859728813, 7.164204446598887, 1.8862783955410123, 0.1990555992233567, 0.431632554391399, 2.4764845753088593, 3.1369209615513682, 5.170969627797604, 1.657368941232562, 10.064241606742144, 7.1085944306105375, 7.050413377583027, 4.917761664837599, 4.924746640026569, 8.385050911456347, 11.279130466282368, 18.750405460596085, 29.794518537819386, 35.02276249229908, 43.82424920797348, 51.143579855561256, 58.82826469838619, 62.36638784408569, 62.90333703160286, 64.80512738227844, 62.255126014351845, 60.81688418984413, 65.02368405461311, 60.942915827035904, 59.05567869544029, 52.53886118531227, 52.12203495204449, 55.09320192039013, 58.96543353796005, 59.118151143193245, 60.91176509857178, 62.32057750225067, 66.02219447493553, 58.79315458238125, 49.81435038149357, 57.87614978849888, 60.3716354817152, 57.571299746632576, 50.62736615538597, 48.42993646860123, 39.130117893218994, 38.62914137542248, 34.818120673298836, 50.300070717930794, 62.44838364422321, 60.68304017186165, 56.07884243130684, 57.34436072409153, 54.14189636707306, 55.29116369783878, 55.058992356061935, 53.892329558730125, 58.309391140937805, 59.7613388299942, 59.960413947701454, 59.699994921684265, 60.75110211968422, 59.23077329993248, 59.781587943434715, 58.67170549929142, 57.74686552584171, 59.96640622615814, 57.616369128227234, 51.19757115840912, 47.679708525538445, 35.40271170437336, 31.923736184835434, 24.48662705719471, 14.617117401212454, 9.67318369075656, 7.2658907901495695, 5.762789770960808, 7.113314727321267, 10.970682967454195, 15.368537530303001, 16.879332661628723, 6.311628520488739, 6.407456528395414, 3.2678533857688308, 2.578872456215322, 2.3546445881947875, 0.6520426366478205, 0.3931269940221682, 2.6280275685712695, 4.666624115779996, 14.66331247240305, 16.073635295033455, 20.523745603859425, 26.38640731573105, 18.506887927651405, 18.8169189915061, 17.836087122559547, 23.228894546628, 43.57900656759739, 46.58528745174408, 34.96084101498127, 26.805954203009605, 4.898329032585025, 0.3537508053705096, 0.021956190394121222, 0.05252584320260212, 0.028699605791189242, 0.022025850230420474, 0.05863174446858466, 0.055097418298828416, 0.03341579285915941, 0.026647274316928815, 0.04974452233000193, 0.04537810760666616, 0.07414164385409094, 0.04632886928447988, 0.0423502526973607, 0.06856444859295152, 0.016845494319568388, 0.03560444572940469, 0.09281652106437832, 0.05714931190595962, 0.04757683513162192, 0.10055947393993847, 0.061116989236325026, 0.05846189284056891, 0.052554816647898406, 0.0792712572729215, 0.02673886832781136, 0.06672342511592433, 0.013168629411666188, 0.0147482044667413, 0.047280343424063176, 0.05622446973575279, 0.015981356118572876, 0.055854394086054526, 0.09289484733017161, 0.0497585155244451, 0.0110606275848113, 0.05211248550040182, 0.04683438688516617, 0.03133807622361928, 0.046205913968151435, 0.029069336342217866, 0.022202774525794666, 0.0033619897385506192, 0.02397242009465117, 0.05298907693941146, 0.02664648764039157, 0.02536204337957315, 0.031536771421087906, 0.058125109935645014, 0.02074004412861541, 0.034630221052793786, 0.113300925004296, 0.060545038286363706, 0.06245256561669521, 0.03358146990649402, 0.047441575006814674, 0.02555835813836893, 0.020819253550143912, 0.052473944815574214, 0.042617548315320164, 0.2551922877319157, 6.0236818715929985, 18.700525537133217, 37.588206231594086, 64.8887836933136, 54.36677969992161, 47.83514678478241, 35.13073369860649, 30.708441697061062, 27.753484658896923, 32.79836945235729, 26.88380252569914, 28.382569402456284, 19.053923673927784, 6.655916171148419, 2.515932871028781, 0.47121295239776373, 0.36433255474548787, 3.468926246277988, 5.052042184397578, 6.91785654053092, 11.830004006624222, 14.00030504912138, 14.019609913229942, 7.677015429362655, 13.830776195973158, 10.927293095737696, 10.221577864140272, 9.79901583865285, 16.427565403282642, 26.773617938160896, 35.83200886845589, 43.834801241755486, 50.3580442070961, 56.29811346530914, 61.461793184280396, 63.4099068492651, 64.62347432971, 62.722250148653984, 61.58385403454304, 66.5550246834755, 64.30084884166718, 60.579465329647064, 55.07796473801136, 53.32967095077038, 56.39945402741432, 59.78725343942642, 60.431106090545654, 63.34245286881924, 65.29428273439407, 67.92416721582413, 60.0904543697834, 54.879942163825035, 59.81263987720013, 60.9827034920454, 58.55869576334953, 56.286117509007454, 51.316394582390785, 45.02550154924393, 44.93301451206207, 41.74977332353592, 52.12021864950657, 62.91797764599323, 64.41667422652245, 58.5561802983284, 59.36366356909275, 56.47541955113411, 57.8789996355772, 57.94955424964428, 58.22825789451599, 60.34149929881096, 63.720479384064674, 64.38927009701729, 62.65616409480572, 62.575847804546356, 61.622345969080925, 61.36328727006912, 60.410328805446625, 60.23546978831291, 61.24539479613304, 58.713187873363495, 54.05611217021942, 50.05893185734749, 38.17067697644234, 34.95594307780266, 26.93463809788227, 16.85410961508751, 9.333312828093767, 7.13917376473546, 7.576115168631077, 13.953275922685862, 16.642472371459007, 23.95849149674177, 17.710418365895748, 8.03303400054574, 11.38035323470831, 4.934827974066138, 5.208650305867195, 2.145038335584104, 1.0580996540375054, 0.8207942533772439, 3.7239224882796407, 5.019131675362587, 14.512905143201351, 20.397605672478676, 26.561593115329742, 30.890643820166588, 22.096034735441208, 19.33735616505146, 23.356955274939537, 32.988389655947685, 49.510511085391045, 55.960946157574654, 41.75630137324333, 31.664595790207386, 6.003771889954805, 0.5623353878036141, 0.030586896609747782, 0.04471519903745502, 0.03822466860583518, 0.014819698335486464, 0.07656347952433862, 0.05932193438638933, 0.018077483582601417, 0.012331843990978086, 0.04701440593635198, 0.04741489108710084, 0.03465371744823642, 0.011159579062223202, 0.05843854116392322, 0.08427529930486344, 0.06473630244727246, 0.0322924224747112, 0.04648676862416323, 0.05570186418481171, 0.05325184916728176, 0.05694167753972579, 0.0916262497776188, 0.06935594166861847, 0.0644499744521454, 0.05922967058722861, 0.023300453613046557, 0.11376208072761074, 0.03424319846089929, 0.007888112322689267, 0.06181916112836916, 0.06470166641520336, 0.09073176886886358, 0.16783417377155274, 0.20051201950991526, 0.16017862362787127, 0.09854591597104445, 0.09935722438967787, 0.1227900994126685, 0.1901071981410496, 0.0971397093962878, 0.12664126697927713, 0.11471398902358487, 0.15342505008447915, 0.11117481291876175, 0.20718762301839888, 0.1293545588850975, 0.14244877500459552, 0.2948093181475997, 0.1710739452391863, 0.10539395749219693, 0.1034527515002992, 0.19402909238124266, 0.15430520754307508, 0.0793495167454239, 0.1373655829229392, 0.16651951853418723, 0.07416537031531334, 0.1023729563166853, 0.10123854648554698, 0.10374233010224998, 0.673621678724885, 8.038414511829615, 23.506889529526234, 47.57829576730728, 69.87149432301521, 61.26498654484749, 51.96535035967827, 41.99548713862896, 36.88078299164772, 32.640579119324684, 41.05427384376526, 32.74102672934532, 35.71478895843029, 23.563780076801777, 10.621204320341349, 3.1047867983579636, 0.622663622489199, 1.0948850051499903, 7.66602024435997, 6.389210857450962, 14.20061795040965, 15.95508735626936, 22.304453551769257, 15.347308069467545, 17.0084136351943, 13.864904064685106, 14.533884767442942, 15.34154187887907, 16.778423376381397, 24.19782355427742, 35.684120804071426, 38.676285445690155, 45.44469125568867, 53.23800086975098, 61.83751322329044, 64.04228031635284, 63.53085055947304, 64.45524215698242, 61.82835951447487, 61.24806225299835, 69.12423402070999, 65.46253010630608, 62.931459322571754, 56.082509234547615, 56.131568402051926, 58.581722527742386, 62.4637234210968, 63.107800260186195, 66.00542217493057, 65.94374388456345, 69.53253731131554, 63.12481954693794, 57.02166683971882, 60.56848391890526, 63.48670832812786, 62.45220243930817, 63.001698553562164, 59.3624172359705, 51.649822890758514, 50.76240710914135, 47.725534066557884, 55.84570214152336, 67.54123896360397, 66.33443132042885, 62.62076139450073, 62.09131680428982, 59.91085700690746, 60.73662869632244, 61.81600257754326, 61.58766143023968, 62.7318674325943, 63.66898074746132, 65.35507947206497, 64.83927994966507, 63.77619579434395, 62.434218004345894, 63.12407098710537, 62.553687393665314, 61.88770093023777, 64.48982790112495, 60.81594184041023, 57.29163855314255, 50.79227350652218, 39.2230761051178, 34.86357003450394, 29.93123710155487, 17.697535157203674, 14.974270686507225, 12.241820208728313, 12.913228031247854, 13.828113488852978, 16.603134982287884, 26.317408718168736, 26.74161035567522, 13.145667258650064, 18.19591261446476, 9.85803047195077, 6.2902347184717655, 4.336341563612223, 2.5941851595416665, 1.3583530113101006, 3.858663495630026, 7.004076763987541, 18.5117706656456, 23.94224926829338, 32.06460602581501, 40.08104346692562, 28.41698605567217, 31.579976230859756, 28.527069948613644, 37.81861066818237, 55.810470432043076, 63.186098858714104, 51.409949362277985, 37.463025748729706, 9.201113171875477, 0.707044032169506, 0.13747868622886017, 0.1862110267393291, 0.14176024007610977, 0.1045076698937919, 0.1978720963234082, 0.1308867969783023, 0.1720442291116342, 0.20629994018236175, 0.24229184637079015, 0.11015550277079456, 0.18445878638885915, 0.11116352485259995, 0.2595367014873773, 0.17602377338334918, 0.1523844848270528, 0.1018040110648144, 0.1249232396367006, 0.12399627492413856, 0.09210655291099101, 0.1811384770553559, 0.23237804474774748, 0.21894656703807414, 0.18538540229201317, 0.17449557257350534, 0.07821052786312066, 0.11552516385563649, 0.11785400100052357, 0.12300208647502586, 0.19556613959139213, 0.14061396330362186], [0.06496834233985282, 0.05864782680873759, 0.018938519606308546, 0.03243350103730336, 0.059559132205322385, 0.013839645944244694, 0.03977311520429794, 0.03082033359532943, 0.03408236021641642, 0.0049604979085415835, 0.006066033556635375, 0.02152737190044718, 0.06641516665695235, 0.029121965744707268, 0.012210224540467607, 0.08615388287580572, 0.06412097296561114, 0.02071063467155909, 0.016139574581757188, 0.06552094549988396, 0.038643336374661885, 0.0695495902618859, 0.027170707362529356, 0.019118048840027768, 0.006674408650724217, 0.02757643578661373, 0.02808345809171442, 0.04110565620067064, 0.04744376434246078, 0.2557650476228446, 4.804938118904829, 25.10633960366249, 45.1314664632082, 52.28803664445877, 43.665706515312195, 38.395035937428474, 29.720454812049866, 25.574001409113407, 22.79016438871622, 29.451826326549053, 31.115747541189194, 23.02816081792116, 10.799738690257072, 3.0827382439747453, 0.7474061788525432, 0.35203920502681285, 0.3340987645788118, 2.028484814800322, 3.906556600704789, 5.223875138908625, 10.357062444090843, 14.27150409668684, 10.098217483609915, 2.9758065193891525, 10.066342893987894, 3.1688062380999327, 6.558042448014021, 8.337678853422403, 15.279111228883266, 24.912665896117687, 41.21396027505398, 53.89163799583912, 56.54210217297077, 60.467363744974136, 61.942106410861015, 61.375792399048805, 59.673669934272766, 59.77691039443016, 64.83753964304924, 61.92808136343956, 58.053497672080994, 55.024718195199966, 50.245995819568634, 50.29096640646458, 54.66110050678253, 57.616988494992256, 58.49799782037735, 60.76835319399834, 62.37369105219841, 60.170413479208946, 56.80437169969082, 57.80307590961456, 54.29829977452755, 57.20707029104233, 54.20829780399799, 49.81205150485039, 42.61556066572666, 31.811334416270256, 37.244305685162544, 31.814345754683018, 56.10981456935406, 60.81121489405632, 59.61251221597195, 53.68497848510742, 55.76689437031746, 58.34832765161991, 55.839873254299164, 53.55712294578552, 54.78015951812267, 57.64315769076347, 56.31219930946827, 55.11343203485012, 55.509290993213654, 55.45984044671059, 55.93139134347439, 54.32855375111103, 57.11036168038845, 60.47351561486721, 60.01578077673912, 63.413144275546074, 54.19190548360348, 48.82915824651718, 43.940644562244415, 36.535043343901634, 23.465998023748398, 16.46604023873806, 11.19422972202301, 6.548140654340386, 8.648742511868477, 14.577849358320236, 30.97959704697132, 32.03635074198246, 12.740554846823215, 5.837022587656975, 10.946841146796942, 3.3910864731296897, 2.449103007093072, 1.7770933918654919, 0.15126165992114693, 0.7286416576243937, 1.0558124142698944, 5.135690420866013, 9.748948775231838, 11.679374389350414, 23.801463022828102, 31.66991550475359, 26.693286448717117, 26.462595127522945, 17.038652412593365, 23.69044817984104, 32.1109027415514, 45.14549911022186, 41.62434205412865, 27.714392356574535, 11.6384581848979, 1.5335244429297745, 0.07668782636756077, 0.032720448725740425, 0.02028896862611873, 0.026304023595002946, 0.09638389878091402, 0.04271941179467831, 0.041640618510427885, 0.04672771428886335, 0.03553470240149181, 0.0661891678464599, 0.048062930727610365, 0.06016270235704724, 0.026187144612777047, 0.038603423672611825, 0.02612782845972106, 0.057663119296194054, 0.08405724889598787, 0.026727732401923276, 0.03750581694475841, 0.08348537216079421, 0.05898012714169454, 0.022085708151280414, 0.03281585180957336, 0.03697139640280511, 0.01058937494235579, 0.04251290549291298, 0.028925302176503465, 0.018582001139293425, 0.03544575229170732, 0.15069805813254789, 0.03621562660555355, 0.0657392705033999, 0.019774203865381423, 0.06285621231654659, 0.05122349277371541, 0.013427828198473435, 0.0656558531045448, 0.020424625799932983, 0.02438002800772665, 0.05059501243522391, 0.026129327598027885, 0.08186404666048475, 0.04060474362631794, 0.03921038543921895, 0.05404893061495386, 0.02671886744792573, 0.011574021227716003, 0.0049798150848801015, 0.050723685999400914, 0.04379100995720364, 0.06130043329903856, 0.04845057672355324, 0.01170430154161295, 0.07155660248827189, 0.03626033358159475, 0.04158838615694549, 0.022386122109310236, 0.028563148953253403, 0.08738851975067519, 0.29170173802413046, 6.2682286743074656, 28.45154520124197, 52.86745995283127, 58.63337315618992, 47.2461973875761, 40.82705743610859, 36.72926612198353, 30.54016962647438, 24.818514548242092, 27.743272706866264, 32.18547374010086, 22.814990356564522, 10.743020083755255, 4.503443771973252, 1.0110863205045462, 0.5555632011964917, 0.9191152837593108, 2.500332808122039, 6.594671532511711, 10.91524489223957, 12.559294123202562, 17.04645149409771, 15.577221382409334, 9.016986452043056, 10.335829183459282, 11.875689905136824, 12.975495290011168, 9.10817300900817, 15.452607069164515, 25.8146158978343, 42.26274199783802, 55.719324722886086, 59.3830843269825, 60.64976155757904, 60.931493639945984, 61.29282005131245, 60.82299806177616, 59.42638300359249, 63.72719742357731, 63.94761219620705, 61.55168116092682, 56.34833537042141, 50.90963400900364, 51.367159858345985, 55.665694400668144, 61.55181035399437, 60.54701507091522, 61.979416608810425, 62.06391267478466, 60.30790530145168, 57.16489255428314, 61.149544939398766, 53.64707171916962, 60.4178562015295, 58.19764293730259, 55.47157421708107, 48.72006230056286, 38.93884755671024, 42.933736592531204, 37.12731376290321, 56.572238355875015, 62.72384226322174, 61.647994592785835, 57.023190557956696, 58.082919493317604, 59.459179043769836, 57.40529805421829, 57.44368739426136, 57.53474950790405, 60.12510471045971, 56.784019991755486, 58.00535425543785, 56.36400192975998, 57.66762837767601, 57.336286157369614, 56.602876111865044, 59.110426157712936, 61.498434618115425, 61.519778072834015, 63.75599607825279, 56.663881838321686, 49.743130803108215, 43.38748924434185, 36.15152232348919, 26.540004573762417, 19.56211220473051, 14.844102021306753, 7.566696424037218, 7.81431726180017, 6.835859315469861, 16.635378152132034, 14.832563940435648, 10.654303394258022, 10.84491541609168, 12.9533557780087, 8.020618166774511, 5.760488994419575, 3.829693137668073, 1.2404585187323391, 0.8746150997467339, 1.215699641034007, 5.477935206145048, 9.384357389062643, 14.46542764082551, 21.402552947402, 33.92764985561371, 28.39251346886158, 31.813908778131008, 21.562252677977085, 27.664569430053234, 39.95606817305088, 51.285764425992966, 47.81870126724243, 33.59099552035332, 14.292488470673561, 1.5477026696316898, 0.04840769914153498, 0.024482238441123627, 0.08767617619014345, 0.02544744416809408, 0.06163695274153724, 0.09100479015614837, 0.03400679102924187, 0.03610501691582613, 0.05531261514988728, 0.08018104868824594, 0.06231500854482874, 0.04054510092828423, 0.05408027151133865, 0.13525959046091884, 0.04977904703991953, 0.021823616843903437, 0.04778562353749294, 0.061890822908026166, 0.04381556762382388, 0.023792690481059253, 0.0738345728314016, 0.018517989046813454, 0.0370611665857723, 0.03704394133819733, 0.047882796643534675, 0.031276017834898084, 0.0406353386642877, 0.04720032877230551, 0.06953612028155476, 0.07959988026414067, 0.1211451216659043, 0.16762993473093957, 0.1582230644999072, 0.11435208813054487, 0.12893692270154133, 0.08238507143687457, 0.08735985058592632, 0.16345415177056566, 0.24525761691620573, 0.13578510523075238, 0.11055497860070318, 0.30872069823089987, 0.1264432174502872, 0.14120972977252677, 0.24145839968696237, 0.16753393050748855, 0.11765463787014596, 0.07618997886311263, 0.23320359498029575, 0.10371922704507597, 0.13985438999952748, 0.14210513094440103, 0.15136250294744968, 0.15882178471656516, 0.08936850295867771, 0.14990939263952896, 0.11801840897533111, 0.13436962181003764, 0.1526061346521601, 0.7092375832144171, 9.206450935453176, 35.51708936691284, 64.10591170191765, 66.62982746958733, 54.96350347995758, 50.31582847237587, 40.8604234457016, 36.987188681960106, 34.994606003165245, 42.42312379181385, 46.42701454460621, 32.26168245077133, 14.93667645379901, 4.094983264803886, 1.3787171873264015, 0.535436631180346, 0.7467389584053308, 5.710926353931427, 11.901701409369707, 19.657591581344604, 16.344836242496967, 29.46205347776413, 24.01568792760372, 11.002079732716084, 21.777072250843048, 10.908807087689638, 12.606322299689054, 14.18332602828741, 20.212741792201996, 30.133887827396393, 49.7630151361227, 63.74760612845421, 58.989763632416725, 62.178636118769646, 62.42352157831192, 61.72456048429012, 58.49000304937363, 60.09385518729687, 65.65030843019485, 66.97205990552902, 63.46851110458374, 57.65626318752766, 52.641064301133156, 54.55899238586426, 57.885295897722244, 62.77145370841026, 63.03898215293884, 63.745219856500626, 63.69050279259682, 62.30367600917816, 59.80451591312885, 59.57099564373493, 57.405077666044235, 63.08135747909546, 61.56286396086216, 62.925379648804665, 50.36066226661205, 44.58742305636406, 48.656886890530586, 43.01359310746193, 58.08500938117504, 65.45787915587425, 64.00235965847969, 59.64912325143814, 62.57154643535614, 64.25007596611977, 61.86301365494728, 60.09094834327698, 59.83533225953579, 61.67484775185585, 58.453266620635986, 60.3595445305109, 59.09806542098522, 59.121829345822334, 60.286512449383736, 57.845147252082825, 62.8821075707674, 64.63251024484634, 64.1315071284771, 69.27571669220924, 59.9595931917429, 55.27410261332989, 48.57587903738022, 41.84546738862991, 26.24272182583809, 21.71008564531803, 16.769140474498272, 10.712768007069826, 12.799293994903564, 21.10741328448057, 40.76407201588154, 40.3412801027298, 22.161142341792583, 19.37968209385872, 19.12553083151579, 12.993790358304977, 10.995973460376263, 4.433982549235225, 2.146113202907145, 1.3073981017805636, 1.8428276083432138, 6.041751801967621, 13.068510498851538, 17.299132235348225, 34.48161832988262, 44.48178872466087, 42.15053781867027, 40.832901522517204, 29.435031227767467, 36.917059645056725, 45.951329469680786, 58.68033103644848, 57.022324204444885, 39.76493842899799, 18.59796144068241, 2.322196466848254, 0.23452874418580905, 0.11828420916572213, 0.12805237172869965, 0.11368722029146738, 0.16278739145491272, 0.12914416001876816, 0.3269574634032324, 0.08528297257726081, 0.13466680742567405, 0.27473217516671866, 0.1256598805775866, 0.15635870047844946, 0.10184168990235776, 0.23134996241424233, 0.14510279899695888, 0.12898817542009056, 0.20143249043030664, 0.23462520854081959, 0.14643229718785733, 0.1325155291124247, 0.14609510981244966, 0.07009561057202518, 0.11181330482941121, 0.12807131133740768, 0.12984908156795427, 0.1141017246118281, 0.08551124978112057, 0.10398246682598256, 0.14738319616299123, 0.21990769280819222], [0.016639424029563088, 0.05935798049904406, 0.05953258187219035, 0.012603434788616141, 0.055752085318090394, 0.038044026150600985, 0.037940964102745056, 0.03085575815930497, 0.055378035467583686, 0.06047368449799251, 0.072886397538241, 0.09656772876041941, 0.10246046294923872, 0.028905908002343494, 0.11463167000329122, 0.07995881998795085, 0.02859689440811053, 0.08970866634626873, 0.0762643272173591, 0.058118363813264295, 0.0759260191989597, 0.04469203660846688, 0.06482248063548468, 0.01422227223883965, 0.03689363045850769, 0.09828683963860385, 0.045753033191431314, 0.03924505857867189, 0.09863268045592122, 0.9509913576766849, 11.121722012758255, 34.82132390141487, 49.778073728084564, 55.066804736852646, 53.457104712724686, 33.84465470910072, 20.767050348222256, 20.148082561790943, 31.47375103086233, 33.69633726775646, 27.207727544009686, 22.843454629182816, 7.697082627564669, 2.17044519726187, 0.21504840668058023, 0.8787626365665346, 1.5102951019071043, 1.5224366378970444, 5.643922174349427, 6.539713181555271, 13.570899590849876, 14.377143178135157, 21.780467368662357, 7.869649892672896, 12.763202581554651, 16.662757582962513, 18.841670863330364, 15.55790226906538, 13.651962541043758, 14.451282899826765, 19.196416027843952, 40.361962392926216, 59.476817697286606, 64.5169660449028, 63.06965410709381, 62.41545841097832, 60.67222975194454, 58.88406850397587, 61.695887222886086, 61.137427389621735, 55.89666500687599, 48.06571841239929, 48.76756355166435, 54.716326743364334, 56.4736944437027, 59.623771011829376, 61.89595028758049, 60.396763533353806, 58.816253542900085, 60.85101775825024, 61.831555142998695, 62.5710828602314, 59.82492081820965, 56.47303327918053, 53.1661581248045, 49.253762662410736, 34.9766481667757, 29.715541675686836, 43.29592555761337, 40.32598212361336, 60.53338140249252, 58.6330159753561, 55.93331404030323, 56.23749151825905, 60.1521934568882, 57.32133015990257, 57.041900753974915, 55.15896879136562, 55.814087837934494, 58.80650706589222, 59.054428562521935, 58.150415271520615, 57.4788773059845, 57.914854511618614, 53.81286442279816, 51.76793575286865, 52.831107303500175, 53.68302159011364, 57.960003688931465, 60.96026189625263, 57.79946230351925, 51.157186925411224, 46.908490508794785, 33.862414956092834, 33.83879542350769, 25.484803095459938, 18.512437529861927, 13.48681390285492, 4.449992040172219, 14.011991322040558, 16.43572546541691, 18.83293703198433, 14.319708310067654, 9.452307242900133, 10.396205093711615, 4.036675868555903, 4.94454737752676, 3.703489084728062, 1.2959237862378359, 0.7125974341761321, 0.8624154981225729, 2.2486623376607895, 7.16565121896565, 12.97897020354867, 27.224328853189945, 32.44316831231117, 25.760594196617603, 16.38068351894617, 17.7855821326375, 23.401101306080818, 32.165471613407135, 45.628901571035385, 47.67064221203327, 36.46328039467335, 17.851854376494884, 2.4507278949022293, 0.058089386657229625, 0.09753583071869798, 0.014261722953960998, 0.017696856448310427, 0.07707009179284796, 0.034769318081089295, 0.026505652131163515, 0.09717577777337283, 0.04025434231152758, 0.030604869571106974, 0.01768202091625426, 0.03937650406442117, 0.013847693608113332, 0.03826285210379865, 0.0792836734035518, 0.0182835353189148, 0.005498486325450358, 0.057170307263731956, 0.030422442250710446, 0.0567874369880883, 0.015011028644948965, 0.07134601066354662, 0.06071198440622538, 0.027980939667031635, 0.02835390969266882, 0.027814737550215796, 0.032125212892424315, 0.028368106977723073, 0.03905047859007027, 0.04448139283340424, 0.057452460678177886, 0.07291643225471489, 0.05812393363157753, 0.04260379260813352, 0.03334085820824839, 0.03474706849374343, 0.028684137578238733, 0.03061690164031461, 0.05143039241374936, 0.08360263891518116, 0.07176202154369093, 0.07036596012767404, 0.019847520634357352, 0.05508604117494542, 0.08706055727088824, 0.06941252300748602, 0.022475307850982063, 0.02451471853419207, 0.06925178866367787, 0.07695404216065072, 0.09147415403276682, 0.05162840483535547, 0.0588706937560346, 0.06062258158635814, 0.06156152827315964, 0.04984706116374582, 0.012697954716713866, 0.0306445243768394, 0.09350329710287042, 1.4580432744696736, 14.214491005986929, 41.84248834848404, 56.1340344697237, 60.5620052665472, 57.95290946960449, 40.221354737877846, 25.423506684601307, 25.29610712081194, 31.85827899724245, 35.914209857583046, 32.42373235523701, 19.104493260383606, 9.301117155700922, 2.02404095325619, 0.44803309778217226, 0.7704168534837663, 1.9281418179161847, 4.4949673768132925, 5.746434023603797, 12.166187167167664, 8.339513204991817, 14.208990801125765, 15.720570590347052, 13.57346635311842, 8.866300787776709, 12.258172631263733, 13.090362176299095, 15.671180840581656, 16.224042624235153, 15.178400482982397, 26.16847760975361, 44.36997592449188, 62.49718062579632, 64.82508391141891, 65.3043369948864, 61.0091994702816, 60.33934861421585, 58.0624195933342, 64.69965264201164, 64.79115933179855, 58.01703862845898, 49.26132045686245, 50.18372096121311, 56.206789165735245, 59.09220613539219, 58.797953724861145, 63.96303936839104, 61.269922479987144, 59.38932739198208, 59.85656552016735, 62.6951690018177, 63.236180171370506, 60.25273986160755, 58.10824133455753, 57.426128536462784, 54.19223986566067, 41.558157205581665, 37.015854343771935, 49.02746960520744, 44.00833033025265, 60.31886771321297, 60.54871737957001, 58.4114308655262, 57.62924283742905, 61.06552764773369, 58.70111972093582, 59.494463950395584, 59.790832847356796, 58.56414847075939, 60.229374915361404, 60.89687369763851, 58.979207798838615, 59.490382969379425, 59.95542861521244, 56.13328590989113, 55.552194491028786, 54.71656993031502, 57.74793706834316, 61.173229068517685, 62.94714868068695, 60.813730359077454, 53.3569572865963, 49.96060073375702, 39.77748915553093, 35.3328600525856, 23.002156913280487, 19.85201384872198, 12.64212777838111, 4.788143495097756, 10.410270988941193, 13.703248389065266, 15.220762509852648, 15.044199284166098, 9.01954086497426, 11.458711680024862, 9.927861224859953, 9.961579665541649, 5.17902709543705, 1.6306506749242544, 0.5789942876435816, 0.5442034732550383, 2.6319503830745816, 8.417681660503149, 13.939071334898472, 27.42180235683918, 32.71823175251484, 28.617744483053684, 22.58125349879265, 23.326365016400814, 28.553043454885483, 38.38615961372852, 50.686031207442284, 54.9895016849041, 41.50199621915817, 21.0104937851429, 3.631540657952428, 0.033081258661695756, 0.025822707430052105, 0.0558800501312362, 0.004387738481455017, 0.03560105040378403, 0.040910348907345906, 0.035496478085406125, 0.03300700307590887, 0.02931935105152661, 0.05200726380280685, 0.02049814665951999, 0.04209916187392082, 0.08202101831557229, 0.014053534760023467, 0.011827269845525734, 0.05503734886588063, 0.03510258691676427, 0.07030599459540099, 0.005098218252896913, 0.12371896402328275, 0.023032894532661885, 0.06728423642925918, 0.11564309112145565, 0.054091808196972124, 0.03411101824895013, 0.04860888053372037, 0.03459535124420654, 0.05456157654407434, 0.031639948501833715, 0.05808572415844537, 0.1467533057439141, 0.16150231822393835, 0.3099546523299068, 0.10695610413677059, 0.135244331904687, 0.11099721697974019, 0.11038247379474342, 0.16884392505744472, 0.1543185513583012, 0.23739741212921217, 0.21766229532659054, 0.382724636583589, 0.20683738868683577, 0.2278475003549829, 0.1775343852932565, 0.2053557799081318, 0.12290940707316622, 0.22338846931234002, 0.19646716624265537, 0.21694042312446982, 0.21252805832773447, 0.12228548352140933, 0.160338036948815, 0.15651431400328875, 0.1839415094582364, 0.15756783715914935, 0.14294319378677756, 0.16605563170742244, 0.17090402310714126, 1.9210088881663978, 19.308477714657784, 48.13531167805195, 62.67869308590889, 66.59882113337517, 66.19902938604355, 46.549071595072746, 31.688363514840603, 31.951949670910835, 44.61728945374489, 47.53642201423645, 38.365408927202225, 28.44432558864355, 10.173101015388966, 2.8658511070534587, 0.830945111811161, 1.74857224104926, 5.988037884235382, 4.831534791737795, 16.25356514006853, 14.872014373540878, 24.365569353103638, 27.580561637878418, 37.46068887412548, 25.81447910517454, 21.744777783751488, 24.134150370955467, 23.618738427758217, 18.25651366263628, 17.922230400145054, 20.533119700849056, 26.97073806077242, 45.62087640166283, 70.82311525940895, 64.96504560112953, 63.00664968788624, 61.995246559381485, 60.18660821020603, 58.74535694718361, 64.94883567094803, 68.24767425656319, 58.76985043287277, 52.84702844917774, 51.46256133913994, 59.710877537727356, 60.01006968319416, 61.977839693427086, 63.84679600596428, 63.229747116565704, 59.013371765613556, 61.437816470861435, 61.77269630134106, 66.13176539540291, 63.87286260724068, 60.553516522049904, 60.400236546993256, 65.15979275107384, 44.97486546635628, 41.21786266565323, 55.19613079726696, 48.18527139723301, 61.93759225308895, 63.21843512356281, 61.04605749249458, 62.44668133556843, 66.55488789081573, 62.91080743074417, 60.74013210833073, 61.3250233232975, 60.10998532176018, 61.897557601332664, 62.38284856081009, 61.98276802897453, 61.63044713437557, 62.58035056293011, 57.12427653372288, 58.14373143017292, 56.455649212002754, 60.46070650219917, 63.62337179481983, 65.8740708231926, 63.25908534228802, 55.04217445850372, 52.86841370165348, 39.77158047258854, 37.94506028294563, 29.160845540463924, 25.069420784711838, 20.215101465582848, 10.593463908880949, 23.55799488723278, 28.147850297391415, 30.42667731642723, 25.702140033245087, 15.629270039498806, 22.354118786752224, 12.37576587125659, 12.158742416650057, 8.787126336246729, 2.452508811838925, 1.1456746235489845, 1.8384701921604574, 3.332214094698429, 9.810092244297266, 17.3388135060668, 36.55852988362312, 44.50049512088299, 37.24895283579826, 29.195524379611015, 29.94939062744379, 33.969056233763695, 45.88166780769825, 57.44010038673878, 63.976749032735825, 50.51914036273956, 26.612865664064884, 5.56895837187767, 0.20180674066068605, 0.17584267450729385, 0.09619684045901522, 0.14284759032307193, 0.1735848980024457, 0.12139666519942693, 0.1228384132264182, 0.15884887310676277, 0.2230434151715599, 0.09802702857996337, 0.15917872806312516, 0.1489690618473105, 0.15324733540182933, 0.08598509622970596, 0.1502222821000032, 0.16388289048336446, 0.2390987114631571, 0.220754423935432, 0.07396922068437561, 0.23372918396489695, 0.1717717421706766, 0.2481665092636831, 0.3397131711244583, 0.12895255233161151, 0.1665043638786301, 0.12202340149087831, 0.18933644809294492, 0.1904777079471387, 0.08186959792510606, 0.16706093010725453], [0.042448936073924415, 0.1295346484403126, 0.04120664765650872, 0.019177329741069116, 0.024605108410469256, 0.054287712919176556, 0.04728163105028216, 0.014263616358221043, 0.0577190141484607, 0.06591931552975439, 0.07834440388251096, 0.04620936124410946, 0.03704086884681601, 0.09014323833980598, 0.06618845538469031, 0.02397490072326036, 0.030540252628270537, 0.05266173044219613, 0.024693449959158897, 0.04671196220442653, 0.02102420876326505, 0.04102732622413896, 0.047846327506704256, 0.07374716267804615, 0.07997286884346977, 0.03628975602623541, 0.03568578882550355, 0.08589688455685973, 0.11411592931835912, 1.135119739919901, 12.180180866271257, 33.20637635886669, 47.15038172900677, 55.096671134233475, 41.22858949005604, 31.913324743509293, 29.506406597793102, 23.50276105105877, 23.55147633701563, 33.31598527729511, 34.8152594268322, 15.76933242380619, 5.647197123616934, 0.7167425367515534, 0.7875829667318612, 0.40943684696685523, 1.737364623695612, 3.8734805630519986, 3.835492101497948, 11.972999833524227, 8.397274855524302, 9.138863012194633, 8.177833780646324, 10.123690366744995, 4.823249811306596, 15.131031274795532, 20.599224753677845, 21.087699942290783, 33.38951513171196, 43.006240501999855, 34.35277484357357, 29.844991229474545, 40.92746704816818, 54.35018599033356, 62.60199800133705, 63.38948294520378, 59.091860353946686, 60.1238127797842, 61.368675380945206, 61.91076949238777, 53.17794509232044, 49.58452731370926, 51.88504546880722, 58.09101685881615, 54.77498039603233, 64.83011484146118, 52.233794555068016, 58.12340632081032, 63.601602762937546, 59.01800751686096, 55.892492830753326, 54.879110008478165, 65.04472732543945, 59.171257093548775, 50.97459152340889, 41.55546315014362, 36.82964153587818, 36.999758407473564, 40.202686339616776, 46.6021965444088, 56.666154116392136, 57.52383649349213, 55.95380254089832, 58.16467970609665, 60.68261839449406, 60.21155387163162, 57.73828558623791, 56.49347998201847, 58.27247612178326, 59.961382895708084, 60.98571293056011, 60.73498338460922, 61.518311351537704, 60.13959713280201, 59.38439145684242, 52.93022498488426, 53.37737739086151, 54.44224365055561, 58.827436342835426, 57.05791689455509, 62.46137134730816, 54.94344815611839, 47.03649424016476, 34.44694139063358, 36.74942784011364, 28.820892982184887, 24.673305340111256, 15.068593975156546, 6.072167744860053, 2.6244075503200293, 4.500769665464759, 6.754645798355341, 6.938165025785565, 8.73446211218834, 10.206528771668673, 13.812394682317972, 6.788446409627795, 4.835459031164646, 0.819122699322179, 0.6074194342363626, 0.017945670733752195, 1.14461436169222, 2.5324168615043163, 7.410403210669756, 10.862521771341562, 25.303856804966927, 33.37809294462204, 36.928645223379135, 26.763675771653652, 24.4066546484828, 28.99582989513874, 41.11684128642082, 45.550420582294464, 40.51730565726757, 20.292362719774246, 4.743418470025063, 0.33330499310977757, 0.04087927518412471, 0.02253916594781913, 0.049288505979347974, 0.06069771661714185, 0.013831435007887194, 0.06524560871184804, 0.05381552517064847, 0.07500551859266125, 0.023237851601152215, 0.06036217309883796, 0.025047623239515815, 0.0309203101642197, 0.03278258503996767, 0.02827734231686918, 0.06919331484823488, 0.09104229087824933, 0.037894576162216254, 0.06789312406908721, 0.021279195862007327, 0.03473848555586301, 0.01818760716560064, 0.04908846749458462, 0.047721676382934675, 0.06298073727521114, 0.04021083390398417, 0.018009018604061566, 0.06165710947243497, 0.030327180174936075, 0.08533284490113147, 0.10809548635734245, 0.02238637815025868, 0.04197788752207998, 0.039952087827259675, 0.0430846560630016, 0.048251866683131084, 0.007364823532043374, 0.07810158058418892, 0.06034234291291796, 0.1202140528766904, 0.047285000400734134, 0.03483702792436816, 0.03164529196510557, 0.04614175901224371, 0.06353705859510228, 0.021500524708244484, 0.012108519695175346, 0.014526601025863783, 0.03466403701168019, 0.004681205937231425, 0.042875559665844776, 0.044560554015333764, 0.02429023927106755, 0.049850783034344204, 0.005691101478078053, 0.026351508058723994, 0.019990825639979448, 0.04281174609786831, 0.1348467930802144, 1.658629048615694, 15.271623730659485, 39.551469683647156, 53.94373320043087, 62.08508513867855, 48.736241832375526, 35.99751278758049, 30.5622673407197, 23.35058681666851, 28.23066495358944, 31.340040005743504, 23.72082944959402, 17.115683779120445, 6.507437713444233, 1.075914166867733, 0.4167719674296677, 1.4351769327186048, 3.0458111129701138, 5.633594803512096, 7.232154775410891, 12.837682384997606, 11.150730606168509, 11.680427882820368, 17.282779812812805, 6.713046580553055, 8.280199337750673, 8.36894167587161, 20.08385080844164, 23.306765668094158, 32.94529236853123, 41.37653075158596, 34.83433060348034, 34.06651720404625, 47.165368124842644, 57.77345269918442, 62.515845224261284, 62.61605724692345, 60.062495470047, 60.49240060150623, 64.38769698143005, 63.83418828248978, 54.51269946992397, 49.80998441576958, 52.583265602588654, 59.628589153289795, 57.22407057881355, 66.12873315811157, 54.371871426701546, 55.556499660015106, 63.521415665745735, 59.919623136520386, 59.02998827397823, 56.923727095127106, 65.88432267308235, 60.715186446905136, 53.73038984835148, 48.13238963484764, 44.050124287605286, 41.871606186032295, 45.802670046687126, 49.30094093084335, 58.460854813456535, 59.94753643870354, 57.32215091586113, 59.303349405527115, 62.31277272105217, 61.796946600079536, 59.99370776116848, 59.1862852871418, 60.84586523473263, 61.756505370140076, 61.0413533449173, 61.847255900502205, 63.34926590323448, 61.11926816403866, 58.83423037827015, 54.89352263510227, 55.86524449288845, 56.29851624369621, 59.727881625294685, 60.566268637776375, 62.117486000061035, 58.0250333994627, 50.13030342757702, 39.9626874178648, 37.598667070269585, 30.27506735175848, 22.13576540350914, 11.517239939421415, 9.023449905216694, 4.715648610144854, 11.944919340312481, 10.480039045214653, 16.3965305685997, 13.42852408066392, 13.004302494227886, 10.822206884622574, 8.649909999221563, 9.988124091178179, 2.0803228206932545, 1.2052545952610672, 0.23200036579510197, 1.5579966735094786, 3.7098131328821182, 8.654326312243938, 16.439194679260254, 30.82392130047083, 33.34037996828556, 35.620113238692284, 28.200701661407948, 26.537910886108875, 35.30513674020767, 47.52978757023811, 52.192711159586906, 46.377902179956436, 24.376828148961067, 5.303185908123851, 0.28533945442177355, 0.02158556741051143, 0.08509519437211566, 0.10156423057196662, 0.03811299764493015, 0.04882453380560037, 0.05838500634126831, 0.05225918583164457, 0.03677388493088074, 0.03630541163147427, 0.031861271781963296, 0.04344224878877867, 0.04157193274295423, 0.026015398652816657, 0.05047097358328756, 0.04304054280510172, 0.014737924793735147, 0.05589045504166279, 0.04424527483934071, 0.024577897565905005, 0.060440677480073646, 0.09974084794521332, 0.03274017130024731, 0.05952043291472364, 0.05650003658956848, 0.03946722419641446, 0.03019273455720395, 0.08940738407545723, 0.028460869871196337, 0.04588444156979676, 0.193005507462658, 0.19285753805888817, 0.09522467153146863, 0.16052437538746744, 0.15215407765936106, 0.11369902043952607, 0.13003681524423882, 0.15129646664718166, 0.24424075585557148, 0.15326225257012993, 0.11888294422533363, 0.18852238630643114, 0.10205053025856614, 0.115324271901045, 0.12089133684639819, 0.24390555743593723, 0.14880111382808536, 0.17327071720501408, 0.15116185590159148, 0.11115241490188055, 0.08672005249536596, 0.12003884665318765, 0.09733036713441834, 0.1459222487756051, 0.10149633148103021, 0.14643569622421637, 0.13883626728784293, 0.17358844546834007, 0.35534651193302125, 2.989166839979589, 20.500642843544483, 46.06578312814236, 59.64018613100052, 68.092992156744, 53.09396579861641, 44.71400946378708, 41.335622146725655, 34.83213052153587, 35.37821061909199, 44.30879920721054, 44.988240748643875, 21.140995882451534, 7.5912711303681135, 1.2736182706430554, 1.4826185745187104, 1.3276176480576396, 5.263297073543072, 9.244188610464334, 11.272552069276571, 25.224971137940884, 20.0588633492589, 18.53823434561491, 18.263892866671085, 21.83007560670376, 13.803376816213131, 18.37134540081024, 24.6122008189559, 23.03172692656517, 37.38683983683586, 48.04578088223934, 42.17413455247879, 40.039827078580856, 50.10286509990692, 64.24123764038086, 64.84603598713875, 62.69103862345219, 59.23766233026981, 60.77842265367508, 67.49267756938934, 66.2545520067215, 58.096066787838936, 53.05988162755966, 56.350003480911255, 61.19716018438339, 59.92359012365341, 67.6802659034729, 58.73928867280483, 57.67695687711239, 64.99808862805367, 61.66316717863083, 60.69955788552761, 60.01436725258827, 67.65572682023048, 62.74060316383839, 57.02785290777683, 54.976027607917786, 46.220134645700455, 47.59116567671299, 51.71529717743397, 52.10144005715847, 62.060375064611435, 61.67264387011528, 61.46371208131313, 61.81276135146618, 63.75142112374306, 63.381845355033875, 61.72953441739082, 59.565630331635475, 61.41670860350132, 62.63639755547047, 61.47650219500065, 64.43576440215111, 65.17898172140121, 63.52261260151863, 63.32845821976662, 56.81868553161621, 58.84485460817814, 60.53784616291523, 64.11500841379166, 61.1442556232214, 68.42532992362976, 59.65111434459686, 50.62785632908344, 41.89130812883377, 41.983023807406425, 34.38980385661125, 27.75102809071541, 18.751640394330025, 10.765945203602314, 6.747591951861978, 12.310861553996801, 15.310561191290617, 13.621416930109262, 21.089827828109264, 24.07430738210678, 24.8198064789176, 14.860081113874912, 13.352662101387978, 3.2270041527226567, 1.773720954079181, 0.23602338507771492, 1.7181888339109719, 4.195917248725891, 10.733147263526917, 18.630738481879234, 34.949415028095245, 44.77107860147953, 51.94947861135006, 39.36974823474884, 36.684759110212326, 41.911112666130066, 53.45680072903633, 60.00110976397991, 52.318594604730606, 29.267213232815266, 7.980702258646488, 0.9175120072904974, 0.14899773843353614, 0.14904266805388033, 0.19256547326222062, 0.13618448458146304, 0.10246698642731644, 0.14051752863451838, 0.10557142726611346, 0.18361302005359903, 0.14258899638662115, 0.17647741857217625, 0.1171065321250353, 0.08586408162955195, 0.1559695033938624, 0.16747107059927657, 0.13475145678967237, 0.22543039958691224, 0.11722360592102632, 0.1531255934969522, 0.13785243179881945, 0.11225572874536738, 0.125780628004577, 0.1238499530882109, 0.12270975450519472, 0.12271661194972694, 0.11050808971049264, 0.07027693951386027, 0.15217637177556753, 0.11971277664997615, 0.23296060098800808], [0.05992003862047568, 0.0755177711835131, 0.04703169055574108, 0.017984709556913003, 0.028673834713117685, 0.08376654965104535, 0.04110796799068339, 0.07875985073042102, 0.01639618698391132, 0.06445012288168073, 0.053473654843401164, 0.05992923383018933, 0.06017661762598436, 0.036911876159138046, 0.06353147022309713, 0.0382051427004626, 0.017429442086722702, 0.03281116143625695, 0.03228299719921779, 0.043601962679531425, 0.07423623799695633, 0.08672698415466584, 0.06540165268233977, 0.016128011920955032, 0.06108052752097137, 0.05549185865675099, 0.047891954745864496, 0.12636213039513677, 0.4586040711728856, 3.5199945559725165, 22.494291365146637, 39.553020000457764, 48.79520706832409, 46.12032540142536, 32.448761612176895, 31.40967696905136, 23.62930566072464, 24.79978535324335, 37.11750268936157, 43.41559633612633, 28.92909597605467, 11.205870397388935, 2.2040779050439596, 0.3977988730184734, 0.554793089395389, 1.1779034254141152, 0.9106346138287336, 7.5095204170793295, 4.815686792135239, 11.490680314600468, 5.875093219801784, 7.130158273503184, 10.544540584087372, 3.839255324564874, 8.578137550503016, 12.881622277200222, 22.691177800297737, 34.12611700594425, 38.015660494565964, 44.276147559285164, 66.42169743776321, 62.86694258451462, 49.24794517457485, 48.708955496549606, 54.623030349612236, 59.29659716784954, 63.76845940947533, 59.588885083794594, 61.34858585894108, 56.42593860626221, 52.965240105986595, 48.232225477695465, 56.54929518699646, 58.68508078157902, 64.89960551261902, 49.93396036326885, 52.942532524466515, 59.805545657873154, 60.542094334959984, 55.12030586600304, 51.583056673407555, 53.47227729856968, 55.50733029842377, 61.67168252170086, 51.07985347509384, 39.19628754258156, 43.32809463143349, 35.429154485464096, 31.198670491576195, 55.64493231475353, 59.719408079981804, 56.62292003631592, 54.83040802180767, 60.31960487365723, 58.750961646437645, 53.50858435034752, 54.49559658765793, 55.90376302599907, 60.02424292266369, 60.554648861289024, 57.94186346232891, 60.1283573359251, 58.39465096592903, 57.140619456768036, 59.44426864385605, 57.39223815500736, 55.426653027534485, 52.894674092531204, 53.01280215382576, 55.99932789802551, 55.52602909505367, 58.43649052083492, 50.82192711532116, 55.8683755248785, 46.559942811727524, 33.03763881325722, 24.83911894261837, 12.320577632635832, 8.85783864185214, 6.457020118832588, 13.05748539045453, 10.743398163467646, 22.202533520758152, 7.715811347588897, 7.769009917974472, 4.763169335201383, 9.738367293030024, 5.7247319631278515, 2.574894307181239, 1.0704102809540927, 0.24466447765007615, 0.313681450788863, 2.777196876704693, 4.876335337758064, 18.97801134735346, 25.28064765036106, 34.88992162048817, 19.445589557290077, 34.21098165214062, 30.778616331517696, 26.384832300245762, 34.54825155436993, 46.89897961914539, 36.71107269823551, 21.205719709396362, 7.089981604367495, 0.5010306648910046, 0.038669007262797095, 0.0047635235659981845, 0.019642910519905854, 0.025615661215852015, 0.10225204561720602, 0.11348114072461613, 0.0550588451733347, 0.07549215224571526, 0.05382236035075039, 0.04561247042147443, 0.0023166346136349603, 0.09669189748819917, 0.042800576775334775, 0.019996399169031065, 0.05037098773755133, 0.10016992062446661, 0.053853296776651405, 0.025702869133965578, 0.06555582644068636, 0.021489568753167987, 0.006279139406615286, 0.037146565518924035, 0.012824582736357115, 0.009699171587271849, 0.052353772553033195, 0.03664278825453948, 0.03970532001403626, 0.056561723904451355, 0.01664150389842689, 0.0482201695558615, 0.03746297275938559, 0.08519489449099638, 0.08928094437578693, 0.016332050581695512, 0.04456248731003143, 0.02942023304058239, 0.03442486879066564, 0.02603298198664561, 0.07189775293227285, 0.12396583944791928, 0.05708030330424663, 0.01644849169679219, 0.04592670687998179, 0.013739379010075936, 0.08853470004396513, 0.02214826748968335, 0.0205200993877952, 0.056860894765122794, 0.02423387129965704, 0.028323568840278313, 0.08931613701861352, 0.06360456434777007, 0.06597890998818912, 0.0679378533095587, 0.0893316553265322, 0.04075267592270393, 0.013477659704221878, 0.3635111456969753, 4.447087571024895, 25.732906982302666, 44.577463790774345, 55.11565871536732, 54.50712136924267, 38.246019333601, 37.05694913864136, 29.841774702072144, 26.994384191930294, 34.47092950344086, 35.857235714793205, 29.420992881059647, 13.979502115398645, 2.880758657120168, 0.5941792228259146, 0.5392284120898694, 1.924925884231925, 3.372810403816402, 9.421868026256561, 6.840062364935875, 13.367556352168322, 11.00709356367588, 8.431817851960659, 14.034794848412275, 9.430209528654814, 5.962486155331135, 9.207195695489645, 22.421646863222122, 30.676116831600666, 38.06964419782162, 48.84461961686611, 67.4245548248291, 64.7899965941906, 52.109598219394684, 54.998811185359955, 56.614051312208176, 61.4803209900856, 62.68069177865982, 60.762125328183174, 60.99629916250706, 58.781679198145866, 53.41402642428875, 50.5984915047884, 58.01673084497452, 60.39772488176823, 64.47090491652489, 53.64986836910248, 54.24850344657898, 61.64209730923176, 64.38973367214203, 57.26864218711853, 55.20392797887325, 56.59025698900223, 57.93915040791035, 62.91260473430157, 52.38409548997879, 44.389837458729744, 47.566132619977, 40.14189340174198, 35.64994543790817, 55.08532494306564, 59.33040015399456, 59.20009754598141, 58.13263602554798, 60.201480612158775, 60.36885783076286, 54.27088424563408, 55.62978632748127, 56.60998933017254, 61.20500296354294, 59.196407943964005, 58.55879455804825, 59.804698303341866, 61.689241379499435, 58.288689851760864, 60.43987222015858, 59.68466654419899, 57.241017669439316, 54.94515806436539, 56.39653578400612, 58.05583454668522, 58.79952684044838, 60.19195072352886, 50.817808136343956, 52.29842908680439, 43.09780038893223, 31.69251099228859, 26.658556312322617, 16.893198117613792, 15.773345958441496, 11.582268700003624, 16.61589279770851, 17.141425497829914, 20.252043083310127, 15.425383429974318, 10.968862865120173, 12.36544182524085, 11.872013602405787, 7.65467120334506, 4.804094089195132, 1.4637566241435707, 0.6213918188586831, 0.5515722278505564, 2.3887821938842535, 5.848859902471304, 16.842949613928795, 24.59358561784029, 34.31972421705723, 26.188890114426613, 36.441830545663834, 35.796549171209335, 31.204345487058163, 39.22819063067436, 52.29453429579735, 43.78861851990223, 25.045708157122135, 8.91418106853962, 0.49220228393096477, 0.029516534123104066, 0.035483568426570855, 0.012522639954113401, 0.03959017951274291, 0.015620663070876617, 0.11154913736390881, 0.12838512106100097, 0.07263992287334986, 0.06580397093784995, 0.01112191970605636, 0.029000500289839692, 0.06358198821544647, 0.05396438886236865, 0.02019754159846343, 0.037432058597914875, 0.017222477508767042, 0.018475710749044083, 0.053847192612010986, 0.044009097473463044, 0.022522866529470775, 0.03853116446407512, 0.05643791882903315, 0.06556931126397103, 0.05145514674950391, 0.020914057349727955, 0.0893329169775825, 0.01737713551847264, 0.03866785322315991, 0.004607115015460295, 0.11100555129814893, 0.15080540237249807, 0.1780960723408498, 0.19195398810552433, 0.23856409796280786, 0.12012541075819172, 0.12036349173285998, 0.11996498811640777, 0.14977286715293303, 0.26247655623592436, 0.13993541768286377, 0.1469795568846166, 0.15348431799793616, 0.08975525837740861, 0.15873817435931414, 0.2189705235650763, 0.26458107924554497, 0.12481933896197006, 0.1829665945842862, 0.2008948489674367, 0.1294948099530302, 0.16335774678736925, 0.29788088926579803, 0.1653493446065113, 0.15922943159239367, 0.21808143064845353, 0.1377352318377234, 0.2045021764934063, 0.7255314651411027, 6.714888056740165, 32.072828784585, 51.90934516489506, 63.10987874865532, 59.254050850868225, 42.56891056895256, 41.7702504247427, 32.829303592443466, 36.74188144505024, 49.242785051465034, 56.545130610466, 34.338776394724846, 14.512894693762064, 3.377562048844993, 0.9173498628661036, 1.1864225682802498, 2.5809908425435424, 4.023370407521725, 17.884886004030704, 14.187860134989023, 26.621031425893307, 12.964915707707405, 17.592299804091454, 26.614364683628082, 11.175643019378185, 21.009870618581772, 21.474127806723118, 25.626524090766907, 37.42390304803848, 42.008303850889206, 47.26516976952553, 65.92422053217888, 64.6615406870842, 57.25874751806259, 58.62713009119034, 62.1888043731451, 62.717458605766296, 62.45664440095425, 60.72272144258022, 64.24937680363655, 60.44115275144577, 56.113678961992264, 53.43871369957924, 60.91391198337078, 62.384919449687004, 64.67933133244514, 55.309927091002464, 56.60990573465824, 62.315785959362984, 67.74216458201408, 60.247066766023636, 57.51822039484978, 59.466577246785164, 60.414934158325195, 66.52761295437813, 55.895783454179764, 53.31890992820263, 49.32029329240322, 46.622833237051964, 42.29730114340782, 57.29919634759426, 62.4712698161602, 61.86039559543133, 60.23415885865688, 64.00698021054268, 61.69104628264904, 55.298436507582664, 56.53142474591732, 56.859704330563545, 60.3840646147728, 61.05300351977348, 60.26440903544426, 60.675748363137245, 62.35149264335632, 61.46262913942337, 62.916624918580055, 62.96591207385063, 60.648659616708755, 58.292892426252365, 58.6064326018095, 61.09454669058323, 60.532568246126175, 65.16530245542526, 57.76921592652798, 61.712264344096184, 50.25340922176838, 36.17314696311951, 27.9228662699461, 16.59324411302805, 14.256277363747358, 12.322702668607235, 24.84520811587572, 22.44050145149231, 30.08541762828827, 13.866544626653194, 16.302702203392982, 17.050819359719753, 20.936316065490246, 12.922302894294262, 6.353243887424469, 2.7670711325481534, 0.9943298134021461, 0.8276537759229541, 3.258142056874931, 6.946261441335082, 24.089386872947216, 34.88950364291668, 46.8844947963953, 32.4748358130455, 47.95112036168575, 44.28052492439747, 38.477563709020615, 47.77334310114384, 60.09829334914684, 52.29223161935806, 31.750279292464256, 12.657511252909899, 0.9282491623889655, 0.08134325194987468, 0.21236561704427004, 0.08069891191553324, 0.12217194976983592, 0.17815045692259446, 0.3021824068855494, 0.22221881488803774, 0.3738968790275976, 0.31942941423039883, 0.10109730836120434, 0.06923799213836901, 0.20569290791172534, 0.15014164033345878, 0.09317163872765377, 0.17443161428673193, 0.11903015663847327, 0.1507260074140504, 0.15117085073143244, 0.1485070600756444, 0.13729124941164628, 0.10145338339498267, 0.1268739451188594, 0.18097210238920525, 0.1082905450311955, 0.13141305389581248, 0.16835471615195274, 0.10294452134985477, 0.12406148001900874, 0.09797089995117858], [0.02258665597764775, 0.04422237958351616, 0.017791220525396056, 0.0447649563284358, 0.03850003136903979, 0.0323390553239733, 0.04878084728261456, 0.01709212298010243, 0.035612694700830616, 0.08134218325722031, 0.035782134436885826, 0.036057252291357145, 0.03578230884158984, 0.04495729132031556, 0.04622667554940563, 0.05003105441574007, 0.04811427992535755, 0.04370141417894047, 0.012419751383276889, 0.04092956311069429, 0.004505236693148618, 0.06175199676363263, 0.08848198529449292, 0.03621947093051858, 0.03359633141371887, 0.038173575449036434, 0.03114930725132581, 0.049255662233917974, 0.40047808550298214, 4.607226178050041, 24.23300016671419, 43.546932488679886, 48.18150959908962, 37.21702314913273, 29.33514028787613, 20.188668183982372, 20.280193872749805, 29.509300142526627, 46.82413503527641, 32.881106212735176, 21.231292337179184, 6.611779164522886, 0.9184389794245362, 0.4111927980557084, 0.08634088924736716, 2.8900501085445285, 4.332173187285662, 6.861443342640996, 6.00925974547863, 7.540018055588007, 11.202653869986534, 10.429744943976402, 19.97361872345209, 8.421719893813133, 3.76004904974252, 12.833784744143486, 38.09102185070515, 37.13384561240673, 47.269892916083336, 52.17234805226326, 58.06590400636196, 65.07097631692886, 69.9014139175415, 60.4612422734499, 52.41644695401192, 57.47885450720787, 58.76249402761459, 60.993981286883354, 65.4834745824337, 61.42176993191242, 50.86336389183998, 46.72983169555664, 58.990105614066124, 58.5598699003458, 60.570573806762695, 61.31826348602772, 63.71985241770744, 57.80694790184498, 56.06678947806358, 53.85633789002895, 48.99511434137821, 48.68667349219322, 56.23347893357277, 56.506072506308556, 53.19899596273899, 41.88285358250141, 43.097044229507446, 32.71383918821812, 30.393497496843338, 47.8596630692482, 58.35639841854572, 58.86568509042263, 58.010898157954216, 55.929244458675385, 56.185916885733604, 54.459775909781456, 56.04143723845482, 58.20450156927109, 59.93536189198494, 60.18046393990517, 58.83391499519348, 60.69871813058853, 56.66671648621559, 55.937683805823326, 59.42835129797459, 58.77876475453377, 57.243726924061775, 55.73310278356075, 54.19033996760845, 53.15706521272659, 57.563821747899055, 55.86596645414829, 58.847081288695335, 51.5401341766119, 44.77377645671368, 36.665319353342056, 24.84279904514551, 11.865325961261988, 15.079403445124626, 8.677840400487185, 15.188744477927685, 11.601581163704395, 22.85937387496233, 18.91567189246416, 11.122312881052494, 9.136599283665419, 7.186310235410929, 9.582855887711048, 2.416525217704475, 1.7290947237052023, 0.6007721659261733, 0.5704627954401076, 0.5416609346866608, 3.7380332686007023, 8.667454607784748, 23.809613585472107, 32.32189781963825, 33.00680726766586, 19.520065560936928, 12.420989144593477, 23.208922818303108, 39.54143442213535, 42.9429093003273, 52.822987139225006, 24.85809702426195, 13.943174164742231, 1.0839912272058427, 0.006257724735405645, 0.042558803615975194, 0.029003316740272567, 0.010633259062160505, 0.021413368740468286, 0.028561028266267385, 0.009772277771844529, 0.04405734820466023, 0.06759913710993715, 0.00941442436669604, 0.024672454601386562, 0.01899672995932633, 0.044924933681613766, 0.02858529463992454, 0.03353087398863863, 0.0314949662424624, 0.03186759116942994, 0.04982676342478953, 0.0240416197993909, 0.03836620358924847, 0.05002588535717223, 0.12188378124847077, 0.04917641941574402, 0.020518190212897025, 0.0991019478533417, 0.04791703191585839, 0.017828307500167284, 0.038573333295062184, 0.02696349416510202, 0.04006890929304063, 0.05733301572035998, 0.032779445755295455, 0.029511355787690263, 0.028472089288698044, 0.08700193502590992, 0.05035971451434307, 0.027649301700876094, 0.03320225470815785, 0.025274879990320187, 0.03708433643623721, 0.06753159424988553, 0.043841461156262085, 0.016176856370293535, 0.07050526124658063, 0.06378428282914683, 0.0231045989858103, 0.10361514083342627, 0.06373724550940096, 0.025274555300711654, 0.02788060315651819, 0.04607178190781269, 0.042010104152723216, 0.06689784466288984, 0.03170170261000749, 0.09007710556033999, 0.02516620730602881, 0.06223851909453515, 0.4780070768902078, 6.490648314356804, 29.423221461474895, 50.37546627223492, 54.64218892157078, 44.080556854605675, 31.745107769966125, 25.819293446838856, 22.580083161592484, 27.312448024749756, 39.48506824672222, 33.743580132722855, 23.827814608812332, 7.741167386993766, 0.8503496018238366, 0.5429995316080749, 0.49125714402180165, 2.886766134761274, 4.637769414111972, 7.242373377084732, 7.948046810925007, 10.454969890415668, 14.465520735830069, 10.169632751494646, 14.674440175294876, 6.299825878813863, 5.974880140274763, 8.921917453408241, 24.17445670813322, 34.20357584953308, 47.595809027552605, 52.79445827007294, 60.03564231097698, 65.80517292022705, 70.6061241030693, 63.481840789318085, 57.673145681619644, 58.19605842232704, 58.976103365421295, 58.88029910624027, 64.04141396284103, 61.812654957175255, 53.92674811184406, 49.01091389358044, 60.69877132773399, 60.254544764757156, 61.11786983907223, 60.84998421370983, 63.96287217736244, 59.312472715973854, 58.928100541234016, 55.864142552018166, 53.53498533368111, 52.291908636689186, 58.609119057655334, 60.85401199758053, 57.91238084435463, 44.891779124736786, 48.18228475749493, 38.61986227333546, 34.46211017668247, 49.00850102305412, 59.150821790099144, 60.61648674309254, 60.25714002549648, 57.42293290793896, 57.33271434903145, 56.80974081158638, 57.72108390927315, 59.2366211861372, 60.33402509987354, 60.181037709116936, 60.46077869832516, 61.40900641679764, 58.703308403491974, 57.29590192437172, 60.59456951916218, 60.406194627285004, 59.38279174268246, 57.67928995192051, 55.396125465631485, 56.431604102253914, 57.92123816907406, 58.96708644926548, 58.13005596399307, 52.70056910812855, 48.300150632858276, 38.0353282392025, 28.677743263542652, 20.508052445948124, 17.23169155418873, 14.640296157449484, 12.764639854431152, 14.687070697546005, 19.612364508211613, 18.074948005378246, 13.242225777357817, 5.955210495740175, 8.769703321158886, 10.350826028734446, 5.933300871402025, 1.7277634888887405, 0.648109728936106, 0.6262734881602228, 0.8866157464217395, 3.2289135502651334, 11.570519730448723, 24.122323505580425, 38.48452873528004, 35.816391706466675, 28.07375617325306, 19.48350392282009, 29.02446325868368, 44.86644588410854, 48.00068870186806, 60.87860427796841, 31.52283489704132, 15.959115140140057, 1.34837094694376, 0.030072766385274008, 0.016136463127622847, 0.04802903684321791, 0.017345685155305546, 0.07954541404615156, 0.0409762367780786, 0.03431912016822025, 0.015728580619907007, 0.04758711016620509, 0.023288562551897485, 0.030663211655337363, 0.09419958005310036, 0.07649464532732964, 0.029367121242103167, 0.026151363817916717, 0.04195439112663735, 0.020283523117541336, 0.02109217835823074, 0.02441406475554686, 0.00747353193219169, 0.02005232741794316, 0.041499502840451896, 0.022553945818799548, 0.02317709197086515, 0.09925131249474362, 0.03808828041655943, 0.06706651256536134, 0.033865074219647795, 0.01566573184391018, 0.20629827777156606, 0.10284477670211345, 0.11754991341149434, 0.1271127088693902, 0.14807646599365398, 0.1385377606493421, 0.14761959988391027, 0.09276370241423137, 0.11405370765714906, 0.19445400161202997, 0.12022994225844741, 0.162571634282358, 0.09148535304120742, 0.24493988865287974, 0.17997569491853938, 0.14833339751930907, 0.08886071809683926, 0.18201533937826753, 0.11145801647217013, 0.15346064348705113, 0.09694745604065247, 0.11732189595932141, 0.16166662971954793, 0.13846715271938592, 0.11329315471812151, 0.15309731767047197, 0.18258875235915184, 0.2938209258718416, 0.7150330441072583, 8.024431262165308, 34.64693605899811, 57.584203854203224, 60.3994195908308, 50.50345100462437, 39.06275510787964, 30.031350329518318, 29.590771570801735, 40.66317602992058, 61.213316917419434, 41.85276299715042, 25.972700715065002, 8.53625524789095, 1.4895036863163114, 0.9046489256434143, 1.1598315951414406, 6.426596576347947, 11.913474127650261, 8.91428841277957, 13.504314813762903, 18.155150301754475, 17.61190105229616, 21.293975673615932, 34.486748054623604, 17.86543294787407, 9.684328492730856, 19.501834139227867, 46.99272818863392, 39.94657248258591, 52.91698269546032, 56.10049366950989, 60.84974482655525, 63.32971975207329, 67.57151573896408, 64.01464059948921, 59.7385286539793, 60.87812550365925, 60.97969025373459, 60.72279363870621, 66.83767631649971, 64.29510354995728, 56.41645811498165, 50.49582481384277, 64.28583964705467, 61.06272719800472, 62.605482414364815, 63.85516315698624, 63.421678617596626, 61.877749264240265, 61.982923820614815, 58.031341060996056, 55.992074087262154, 52.907452806830406, 60.70453941822052, 61.39572232961655, 60.78819192945957, 51.094836071133614, 49.75530534982681, 45.637261122465134, 41.382272243499756, 51.61683306097984, 59.50161896646023, 61.980856731534004, 62.35523544251919, 59.1271186619997, 60.3853527456522, 58.80771540105343, 58.85585121810436, 58.95837351679802, 60.77799327671528, 61.36536195874214, 59.81811158359051, 63.449211940169334, 57.62398771941662, 56.57517559826374, 61.21638335287571, 62.50396706163883, 61.1066148430109, 62.0780099183321, 59.94919694960117, 58.69616858661175, 62.630188688635826, 61.327736377716064, 61.994748786091805, 56.2717504799366, 51.0114723443985, 40.79070098698139, 26.684488020837307, 17.28657390922308, 20.6645280495286, 13.713081311434507, 23.435932137072086, 19.964180029928684, 34.39405582845211, 32.361457496881485, 22.663262598216534, 17.92732782661915, 13.48244033753872, 19.04558502137661, 6.9012571312487125, 2.876414777711034, 1.1249117064289749, 0.6183091748971492, 0.8828978834208101, 5.658522415906191, 12.088199201971292, 31.279440857470036, 44.29036259651184, 46.93099670112133, 32.05888353288174, 21.40750788152218, 33.81416514515877, 52.10631139576435, 54.32494394481182, 68.95852491259575, 41.88409611582756, 19.55579314380884, 2.2628130158409476, 0.08299088658532128, 0.16326488927006721, 0.16441438696347177, 0.10028496835730039, 0.16510217974428087, 0.17630859481869265, 0.07050503860227764, 0.06727033600327559, 0.15814021113328636, 0.10654019715730101, 0.11057866795454174, 0.09436896783881821, 0.1841312024043873, 0.18523084261687472, 0.19643497187644243, 0.07879228258389048, 0.10390016264864244, 0.11728169381967746, 0.0838688992371317, 0.15616480697644874, 0.11186602700036019, 0.20457075093872845, 0.13157767709344625, 0.0990708963945508, 0.25287087948527187, 0.0965705415001139, 0.09961811156244949, 0.09375652531161904, 0.08964392138295807], [0.055305208516074345, 0.04127689193410333, 0.009972511998057598, 0.03333157023007516, 0.05263618571916595, 0.04071969487995375, 0.045106284887879156, 0.03170741714711767, 0.024372582411160693, 0.0669142090191599, 0.028601148769666906, 0.016237818235822488, 0.07447248586686328, 0.10059679654659703, 0.05210754279687535, 0.0939442367234733, 0.06141487989225425, 0.05374673550250009, 0.034482229384593666, 0.038609791299677454, 0.07698246641666628, 0.09116575456573628, 0.041770260577322915, 0.031977095059119165, 0.03498702710203361, 0.07316979405004531, 0.06341864151181653, 0.07124707495677285, 0.2758604771224782, 7.104342458769679, 31.89041957259178, 49.87661004066467, 47.39485681056976, 40.012445747852325, 27.28477980941534, 28.36379460990429, 18.006754964590073, 44.913525357842445, 54.69360016286373, 41.92579507827759, 17.718485333025455, 3.7824956327676773, 0.48936327220872045, 0.4485934489639476, 0.5396577890496701, 1.5685977484099567, 1.7245482676662505, 9.198611006140709, 4.8808580450713634, 9.291226286441088, 13.084606435149908, 4.538521114736795, 6.49020136334002, 7.357812132686377, 3.791741249151528, 9.740697517991066, 26.233817003667355, 41.05111621320248, 48.3800907433033, 52.533917650580406, 62.03893281519413, 58.15902940928936, 59.081201925873756, 63.465676456689835, 62.24286027252674, 56.47574633359909, 58.80584970116615, 57.99727588891983, 60.15248604118824, 61.88828989863396, 55.88601037859917, 45.833307802677155, 49.548345655202866, 58.86888451874256, 60.822211503982544, 59.274364560842514, 54.949417635798454, 57.01833821833134, 55.88957078754902, 47.928218990564346, 43.93167324364185, 46.47261589765549, 49.96796853840351, 58.20760980248451, 54.709783494472504, 46.361152678728104, 42.31790363788605, 36.859545931220055, 35.96421517431736, 57.45889037847519, 58.31430807709694, 55.06064906716347, 57.98312544822693, 54.77802403271198, 55.754594430327415, 50.055489242076874, 54.85031135380268, 55.936258882284164, 59.56078939139843, 59.51260417699814, 58.80872614681721, 61.45925872027874, 59.27320562303066, 57.21250779926777, 55.37437543272972, 58.44170764088631, 57.266537100076675, 56.87211446464062, 55.60678616166115, 53.55923943221569, 53.448760360479355, 58.385615050792694, 52.181725949048996, 56.502599492669106, 48.5940420627594, 43.20749290287495, 37.19287544488907, 32.69446022808552, 23.99640966206789, 25.658265687525272, 16.97931669652462, 21.75833735615015, 17.46291484683752, 17.907471992075443, 7.9908752627670765, 9.073085691779852, 11.36490136384964, 5.333741493523121, 5.686566811054945, 1.4163515553809702, 0.7823551597539335, 0.04863469614065252, 0.5023190926294774, 2.4946476006880403, 7.487680139020085, 15.579577255994081, 26.098249778151512, 31.408751718699932, 21.575124487280846, 22.88594964891672, 21.235158629715443, 34.856794998049736, 43.89294572174549, 42.5781174749136, 34.78013791143894, 11.89563313499093, 2.9316182155162096, 0.06287409065407701, 0.01575554098963039, 0.03250191963161342, 0.02746012083662208, 0.012081927616236499, 0.030906762258382514, 0.05899188276089262, 0.03630462866567541, 0.019599647021095734, 0.055774835855118, 0.049458762077847496, 0.04913712640700396, 0.018175515724578872, 0.08780020390986465, 0.04094708521733992, 0.01198674439365277, 0.041849559056572616, 0.015696629307058174, 0.02590057727502426, 0.014473261016973993, 0.020675557061622385, 0.11667951519484632, 0.03948564801248722, 0.0823008079896681, 0.05425961149740033, 0.009236420246452326, 0.023919278610264882, 0.10483737642061897, 0.019846850846079178, 0.011850225400849013, 0.06043022804078646, 0.012030491216137307, 0.0523702370992396, 0.005914723560636048, 0.04253536288160831, 0.09187911433400586, 0.02387052878475515, 0.026867757114814594, 0.042294380109524354, 0.03839441262243781, 0.07986493830685504, 0.02431116226944141, 0.10055508784716949, 0.043667008212651126, 0.0871835756697692, 0.0039416887102561304, 0.004614044819390983, 0.04970607165887486, 0.01881884272734169, 0.043341016134945676, 0.019390515371924266, 0.016323168929375242, 0.028612496207642835, 0.09395638568094, 0.016359608380298596, 0.052474371550488286, 0.07806884445017204, 0.2304019281291403, 8.810525480657816, 37.43913263082504, 56.351211816072464, 52.33647644519806, 44.21785108745098, 30.610532350838184, 30.852077789604664, 20.329216942191124, 42.33961567282677, 53.439036682248116, 40.8723434060812, 20.02525605261326, 3.90322370454669, 0.7855713902972639, 0.08513909240718931, 1.1023380677215755, 1.5820415457710624, 6.618930380791426, 9.508719965815544, 11.632994078099728, 8.616186808794737, 16.765861250460148, 10.340284444391727, 11.414224617183208, 8.956341706216335, 5.64455246552825, 13.476640898734331, 30.91799095273018, 45.27846157550812, 48.08242991566658, 55.42386777698994, 62.023562639951706, 58.78663793206215, 60.59076592326164, 65.47519862651825, 65.11155053973198, 59.63611274957657, 58.48094433546066, 58.86732280254364, 60.71791850030422, 64.62571620941162, 56.897888481616974, 47.27666035294533, 51.657859459519386, 61.235982701182365, 61.004255935549736, 62.25567698478699, 55.941137820482254, 59.628015384078026, 58.566124364733696, 51.96355685591698, 46.833645924925804, 48.4149082750082, 52.745611891150475, 60.39148561656475, 56.79198056459427, 49.77226383984089, 45.70244662463665, 40.93273736536503, 39.187057837843895, 57.92414501309395, 58.140201419591904, 55.95089189708233, 58.53565379977226, 55.88759109377861, 57.353875413537025, 52.04943984746933, 56.935149282217026, 58.007440343499184, 61.212667152285576, 61.300776824355125, 60.83737649023533, 61.8068640679121, 60.625549256801605, 56.7120860517025, 56.7896892875433, 59.162278175354004, 59.24658045172691, 59.28097240626812, 56.93593584001064, 56.672929152846336, 57.74536080658436, 60.43472729623318, 57.6972895860672, 56.360851898789406, 49.11713719367981, 42.56411902606487, 36.15585409104824, 26.216231547296047, 22.42835160344839, 20.389836989343166, 11.50903332978487, 13.894627019762993, 17.896068803966045, 24.244116470217705, 16.585874408483505, 9.723106361925602, 8.923412673175335, 10.222843196243048, 8.676846753805876, 3.2522585475817323, 1.5785583201795816, 0.7336490764282644, 0.49439363821875304, 3.116899123415351, 7.92511124163866, 16.807577311992645, 24.36508297920227, 33.84707137942314, 21.73648662865162, 22.215690314769745, 25.188527293503284, 40.740615874528885, 50.76355844736099, 48.567112907767296, 40.40350556373596, 15.441211480647326, 3.4379590954631567, 0.05669991180184297, 0.06010551245708484, 0.036522916561807506, 0.04757829345180653, 0.11582379665924236, 0.0424830229167128, 0.021837177737324964, 0.06117783050285652, 0.05017209958168678, 0.09323288817540742, 0.043353272703825496, 0.038694243994541466, 0.03752352829906158, 0.0436177481606137, 0.053844402136746794, 0.046557829264202155, 0.05620813877612818, 0.035420704807620496, 0.060842865859740414, 0.02422554254735587, 0.042236381268594414, 0.033985591580858454, 0.06766034945030697, 0.04289374228392262, 0.09383176424307749, 0.03885547928803135, 0.0914411804114934, 0.06511363259050995, 0.019692038840730675, 0.1510875966050662, 0.1156375027494505, 0.0850983039708808, 0.14248730731196702, 0.21978932025376707, 0.10802464094012976, 0.15869017224758863, 0.11921290308237076, 0.09502917499048635, 0.2288202481577173, 0.07355550304055214, 0.14467374858213589, 0.20168421207927167, 0.2291256419266574, 0.16064884839579463, 0.19708020990947261, 0.16980660933768377, 0.16349927434930578, 0.1981773565057665, 0.14009340608026832, 0.2586651826277375, 0.13646463048644364, 0.07862097263569012, 0.13229846575995907, 0.13781293469946831, 0.2797517948783934, 0.16538327559828758, 0.17263889720197767, 0.8752876636572182, 12.197827119380236, 45.998021364212036, 66.21618166565895, 59.40379701554775, 51.73523090779781, 37.97664798796177, 37.890677601099014, 28.042820133268833, 61.43498942255974, 62.22275175154209, 47.67965912818909, 21.157127916812897, 5.018565505743027, 0.8487501251511276, 1.060523686464876, 1.4799214317463338, 5.209282971918583, 8.715427983552217, 19.59775809198618, 16.45753439515829, 21.35141149163246, 25.677963830530643, 13.849885370582342, 19.64481096714735, 16.6648056730628, 11.832970697432756, 14.844027925282717, 28.243817947804928, 45.09241595864296, 53.206014186143875, 55.474374666810036, 64.7019325196743, 61.176428496837616, 62.076866179704666, 62.17230565845966, 63.6235997825861, 57.6504684984684, 61.431736797094345, 59.87755559384823, 60.96242778003216, 66.15324944257736, 60.80401048064232, 50.20358249545097, 52.824066281318665, 64.14877340197563, 65.33776000142097, 63.862519562244415, 59.97328765690327, 62.60412968695164, 60.210843309760094, 52.369264885783195, 49.743328392505646, 50.78393675386906, 54.92008700966835, 63.205094039440155, 60.76261170208454, 54.13496553897858, 48.959555849432945, 48.55041280388832, 46.11411273479462, 56.48528002202511, 58.46707507967949, 58.130033165216446, 60.5503398925066, 58.19220542907715, 58.711892142891884, 54.388370141386986, 58.05353946983814, 59.45130966603756, 60.94866871833801, 62.64561206102371, 63.195016980171204, 64.3560066819191, 63.45829725265503, 58.12952779233456, 56.067503839731216, 60.93995198607445, 60.303421542048454, 61.90038464963436, 58.03036831319332, 60.11805608868599, 57.81860567629337, 63.582675978541374, 57.31227524578571, 62.763489335775375, 53.55314075946808, 48.35201404988766, 42.98708193004131, 35.65231271088123, 28.79043571650982, 30.320982187986374, 26.69911153614521, 31.194177232682705, 28.976515531539917, 24.003332890570164, 14.29062182083726, 16.21289972215891, 24.301907569169998, 16.31488434970379, 15.899174306541681, 6.085565825924277, 2.0316308084875345, 0.7436529896222055, 0.7184366520959884, 3.035342199727893, 10.924343504011631, 20.905742906033993, 35.37457421422005, 43.630026429891586, 32.71089814603329, 34.175358563661575, 32.23958283662796, 48.106015250086784, 56.966208815574646, 56.5940909832716, 47.51364603638649, 19.730129688978195, 4.604769134894013, 0.2459247037768364, 0.10499921656446531, 0.20205745298881084, 0.1308073426480405, 0.19811268575722352, 0.11569132329896092, 0.09997054265113547, 0.12217580893775448, 0.07037545219645835, 0.18191299721365795, 0.12920951354317367, 0.14517453499138355, 0.1404620159883052, 0.18663682654732838, 0.1306932745501399, 0.1822361134691164, 0.23323080211412162, 0.18767635279800743, 0.14247108396375552, 0.15691538545070216, 0.09527593167149462, 0.29768742620944977, 0.1078914180106949, 0.12973952572792768, 0.16376258834498003, 0.14818412193562835, 0.18301755044376478, 0.2173343996400945, 0.10854346153791994], [0.015977702896634582, 0.05879074589756783, 0.05176527542062104, 0.09275623640860431, 0.02241094880446326, 0.028767339754267596, 0.05033302688389085, 0.06730388849973679, 0.0261833707918413, 0.09612624737201259, 0.08356561316759326, 0.0514927291078493, 0.038248042546911165, 0.03651203296612948, 0.05772317017544992, 0.09163013120996766, 0.08037782914470881, 0.03452019765973091, 0.018588519051263575, 0.027839627327921335, 0.09352600682177581, 0.015643760561943054, 0.07110770704457536, 0.08212058484787121, 0.052362388887559064, 0.0562155045918189, 0.018858278599509504, 0.01600812352990033, 1.698798593133688, 13.03581515327096, 37.12931625545025, 44.70103695988655, 46.91771641373634, 38.99490214884281, 24.49325580149889, 22.369504161179066, 46.20998919010162, 57.59460389614105, 53.21031175553799, 30.605343729257584, 12.702891267836094, 2.6729252468794584, 0.27391515963245183, 0.2702630509156734, 0.5520492210052907, 0.6790399504825473, 4.644347336143255, 5.152130713686347, 7.945948848500848, 4.195059444755316, 15.076442454010248, 9.30927911773324, 10.201542489230633, 5.324612008407712, 8.582667857408524, 11.308587435632944, 25.16166653484106, 43.966661766171455, 53.72525632381439, 58.251885026693344, 59.5674504339695, 61.79891489446163, 60.480492040514946, 55.652205124497414, 61.90207175910473, 61.01901054382324, 57.06129111349583, 58.773608431220055, 56.82515658438206, 58.19831930100918, 60.27762472629547, 53.74221481382847, 44.316478595137596, 46.891262233257294, 53.727813586592674, 56.12841457128525, 52.9891712218523, 48.88903923332691, 45.453795567154884, 41.64811357855797, 43.355893939733505, 44.16377238929272, 49.798098653554916, 51.63013994693756, 56.61729633808136, 48.79503607749939, 44.00532849133015, 42.644366919994354, 35.990733951330185, 55.0261165201664, 51.13296702504158, 60.368242263793945, 58.575179278850555, 57.95764021575451, 54.88492749631405, 52.17605285346508, 55.073724165558815, 60.893609672784805, 58.208118975162506, 56.3153151422739, 54.81589660048485, 53.69440957903862, 57.46280036866665, 57.08718292415142, 53.55217941105366, 56.24010197818279, 58.76415453851223, 56.24999664723873, 57.41558410227299, 55.56554697453976, 54.56661477684975, 57.49689593911171, 56.31358243525028, 52.93405897915363, 55.94737708568573, 44.664175137877464, 37.113311514258385, 29.806831777095795, 28.567716367542744, 22.03633613884449, 9.706931579858065, 10.855557695031166, 17.83582303673029, 23.34861282259226, 20.674396120011806, 4.226159825921059, 4.957405887544155, 7.522809728980064, 5.012002782896161, 1.2769719469361007, 0.9695061016827822, 0.7562262180726975, 0.11059511394705623, 1.1405819468200207, 4.683437263593078, 16.09772030264139, 31.985064893960953, 36.18228167295456, 28.472856357693672, 21.191814355552197, 24.493069611489773, 30.212758295238018, 42.10175223648548, 48.66673216223717, 38.01889792084694, 17.494027577340603, 3.2466493360698223, 0.07588562410091981, 0.0675040234636981, 0.047667570106568746, 0.07797460653819144, 0.022086051394580863, 0.0038666169939460815, 0.00984748608971131, 0.05498290862306021, 0.050275328612769954, 0.009669598857726669, 0.0886487310344819, 0.02097589309414616, 0.03841748970444314, 0.035093829574179836, 0.03862298668536823, 0.0736039578623604, 0.0178713502100436, 0.02028452501690481, 0.03696734056575224, 0.05850995432410855, 0.039126144256442785, 0.04905155306914821, 0.05977430679195095, 0.05697890737792477, 0.028671148138528224, 0.024772091637714766, 0.020021461496071424, 0.034715497531578876, 0.06228635422303341, 0.006819528671258013, 0.025246221957786474, 0.01804581243050052, 0.07771632430376485, 0.04610495219822042, 0.022840088277007453, 0.035204261148464866, 0.03102693266555434, 0.03931356251996476, 0.09335560971521772, 0.0366477420902811, 0.02261412657389883, 0.07316194212762639, 0.027860811933351215, 0.021153910201974213, 0.07868328335462138, 0.017086560583265964, 0.07086262019583955, 0.08261953815235756, 0.007336598264373606, 0.02111479901941493, 0.02153141474991571, 0.023826474898669403, 0.08533410655218177, 0.05742638160882052, 0.051902787963626906, 0.03582335702958517, 0.010276612574671162, 2.1616804925724864, 15.033946484327316, 44.05505642294884, 51.29823915660381, 54.4434367865324, 42.26858228445053, 29.25079431384802, 22.50842660665512, 33.40291701257229, 55.799595415592194, 60.39828345179558, 35.12598015367985, 14.379998724907637, 2.654998996295035, 0.40236723725683987, 0.20721788780065253, 1.6387139610014856, 4.003012999892235, 6.609039511531591, 7.433355879038572, 12.685468252748251, 11.253781076520681, 9.853616058826447, 12.908836416900158, 15.37245512008667, 12.546997033059597, 7.920694928616285, 18.55492305010557, 29.40351191908121, 42.08846814930439, 55.28298273682594, 61.561598628759384, 61.07561990618706, 62.39064194262028, 61.37897662818432, 56.87513530254364, 61.495003402233124, 61.75869405269623, 58.33593271672726, 58.39757680892944, 57.19310604035854, 60.01566678285599, 61.10917970538139, 54.74992834031582, 45.17532370984554, 49.37619969248772, 57.3607986420393, 58.25134925544262, 55.20457774400711, 52.46373921632767, 48.37158299982548, 43.62727537751198, 44.613941833376884, 45.83296202123165, 53.13080482184887, 55.17197169363499, 58.71066860854626, 50.78399375081062, 49.61505867540836, 46.974185183644295, 39.35174100100994, 55.90836077928543, 54.99264031648636, 60.64403146505356, 58.357291370630264, 58.60815390944481, 56.5320099145174, 55.21233692765236, 57.29886196553707, 61.895209327340126, 59.758272394537926, 58.78051646053791, 57.168145179748535, 57.55904920399189, 60.109229162335396, 57.598019912838936, 54.286281019449234, 57.1177788823843, 60.57353004813194, 59.71745878458023, 60.65436311066151, 58.56808885931969, 56.829955726861954, 58.56785707175732, 56.76184058189392, 56.85817301273346, 57.522548362612724, 46.58310256898403, 39.19360488653183, 31.56295884400606, 26.947185024619102, 18.564865216612816, 13.48825117573142, 15.506894756108522, 12.731825765222311, 15.9529347717762, 20.23777484893799, 10.024506188929081, 6.330070830881596, 11.450868900865316, 5.725355129688978, 4.484158856794238, 1.2924284487962723, 0.9550221101380885, 0.13818691775668412, 1.5123322675935924, 5.831204149872065, 17.76947859674692, 32.2107157856226, 37.402551993727684, 31.889648213982582, 24.286364503204823, 26.736771315336227, 35.22888623178005, 46.564008593559265, 54.02084246277809, 41.5370075404644, 20.123286992311478, 4.057523924857378, 0.10557601373875514, 0.06793761582230218, 0.025547654513502494, 0.045173278558650054, 0.02332546213438036, 0.0432321430707816, 0.026989884936483577, 0.02280135373439407, 0.05949560807493981, 0.03457146151049528, 0.05075977293017786, 0.015938239193928894, 0.04449478117749095, 0.03477432386716828, 0.047317844146164134, 0.06528188489028253, 0.03442708039074205, 0.061847318211221136, 0.05618079063424375, 0.07927413680590689, 0.026911066997854505, 0.04260971494659316, 0.05447307172289584, 0.0158097622988862, 0.028999938112974633, 0.04660255850467365, 0.037276734510669485, 0.09693975254776888, 0.024780158782959916, 0.09075536916498095, 0.1015797711443156, 0.2599521557567641, 0.11939534524572082, 0.16504850762430578, 0.10830883897142485, 0.13551021373132244, 0.16891545325051993, 0.1816632942063734, 0.2786269661737606, 0.10956879050354473, 0.11350037719239481, 0.1582005328964442, 0.1366262702504173, 0.1926033673225902, 0.24667292222147807, 0.12876811379101127, 0.12271715371753089, 0.10368410119554028, 0.11700187445967458, 0.1890817133244127, 0.12096984864911065, 0.113366612495156, 0.1401560433441773, 0.17166117700980976, 0.1283768832217902, 0.18160040461225435, 0.10902052148594521, 3.101924601942301, 19.656615033745766, 51.503325551748276, 58.9262006431818, 59.8402301967144, 50.118569657206535, 35.028811767697334, 32.01650060713291, 57.23389685153961, 66.13703951239586, 59.976468086242676, 35.01967705786228, 15.2762452326715, 3.892139461822808, 0.8353319170419127, 0.5834333400707692, 2.3238857137039304, 5.364200184121728, 10.48532361164689, 16.4313879981637, 17.48954001814127, 13.674631174653769, 27.406705766916275, 20.244247801601887, 18.301985822618008, 11.233100686222315, 15.424543675035238, 15.207375828176737, 28.66859145462513, 45.916625931859016, 56.79081402719021, 62.00753130018711, 63.640809059143066, 62.339291498064995, 63.509624898433685, 58.2527931779623, 61.21385648846626, 61.68701849877834, 57.30982057750225, 59.47610333561897, 57.1576539427042, 60.7727837562561, 65.3629982471466, 57.751318886876106, 48.924688920378685, 52.273152843117714, 59.17124569416046, 58.758637234568596, 57.61109501123428, 54.04847837984562, 50.09095273911953, 46.504325196146965, 47.634380757808685, 48.76786753535271, 55.74405379593372, 57.86711007356644, 60.842278227210045, 55.98029091954231, 54.38699461519718, 51.35742478072643, 46.32392227649689, 59.32330973446369, 55.57365953922272, 59.740907326340675, 59.89132985472679, 58.19041572511196, 60.625290870666504, 55.96891053020954, 59.76711072027683, 62.99473352730274, 60.12507811188698, 58.638677671551704, 58.92150029540062, 58.03253039717674, 60.105026587843895, 60.14655075967312, 53.70866261422634, 55.91729409992695, 60.66815257072449, 60.5403958261013, 62.88482442498207, 61.27971455454826, 58.442820981144905, 63.80069687962532, 60.51461800932884, 59.70038630068302, 60.71167543530464, 49.81784999370575, 42.00421527028084, 34.73527751863003, 32.69402325153351, 26.839422807097435, 16.494145430624485, 20.133770629763603, 24.687121398746967, 30.521448031067848, 35.494856759905815, 13.775711450725794, 13.617091812193394, 17.968021742999554, 13.297584056854248, 4.498749123886228, 2.6704496797174215, 2.1080777188763022, 0.37094108294695616, 1.901751640252769, 7.300685998052359, 20.429495461285114, 40.20143620669842, 47.873224541544914, 41.72036290168762, 33.16169835627079, 35.936016887426376, 40.74696533381939, 54.44971784949303, 62.36079454421997, 50.273042768239975, 26.36298917233944, 5.923163965344429, 0.42858318833168596, 0.21930861636064947, 0.12995666329516098, 0.16063655843026936, 0.0823502053390257, 0.1291849632980302, 0.08706062406417914, 0.17466827033786103, 0.12009708298137411, 0.10930652293609455, 0.2297918382100761, 0.24745447793975472, 0.09688504884252325, 0.09573788149282336, 0.15228674397803843, 0.10747801206889562, 0.08212945351260714, 0.0775075433193706, 0.11002982006175444, 0.2270496470737271, 0.19500013324432075, 0.10918072890490294, 0.20968036347767338, 0.24639244977151975, 0.11186692499904893, 0.3379000152926892, 0.17776808759663254, 0.24270589055959135, 0.17045679007424042], [0.031073320606083144, 0.020417297091626097, 0.021805335891258437, 0.021295732767612208, 0.130694447143469, 0.03585752550861798, 0.025396954006282613, 0.0792070318129845, 0.008353323883056873, 0.028274089854676276, 0.04502301220782101, 0.030248100629250985, 0.0819549523293972, 0.02286556249600835, 0.04265882285835687, 0.02591266129456926, 0.008727471140446141, 0.013687710688827792, 0.035098282460239716, 0.03163333225529641, 0.043309163156664, 0.08081013758783229, 0.01879700688732555, 0.004159791533311363, 0.034612535673659295, 0.0024635132922412595, 0.05513209514901973, 0.0586281710275216, 2.8319034911692142, 17.26415891200304, 34.516128078103065, 38.00296537578106, 41.15076206624508, 34.443897753953934, 20.719750486314297, 31.22736845165491, 49.26334194839001, 49.2865777015686, 26.107574477791786, 18.165605440735817, 7.950329063460231, 0.7273520424496382, 0.34937732911203057, 0.06367267124005593, 1.1057293857447803, 2.5160691887140274, 6.259563714265823, 7.253343388438225, 11.8343585729599, 6.084590228274465, 9.510323479771614, 9.375341422855854, 7.9586420673877, 11.040147040039301, 3.774412991479039, 17.405874207615852, 35.47266975045204, 40.26433043181896, 48.69965739548206, 60.01144140958786, 59.694249629974365, 60.57082459330559, 59.48298096656799, 61.221429482102394, 57.05711513757706, 57.2964870929718, 59.16847564280033, 57.07503117620945, 56.08974024653435, 57.742716148495674, 57.96911180019379, 58.401369005441666, 50.260514840483665, 46.36764653027058, 43.37710440158844, 45.18879398703575, 44.59849186241627, 41.5906036645174, 40.353059470653534, 39.14113350212574, 38.91197919845581, 42.663267105817795, 43.07463303208351, 46.67776308953762, 52.27289825677872, 57.54328764975071, 43.2207465916872, 46.52153827250004, 26.884560585021973, 47.46310114860535, 47.4884419888258, 54.21575300395489, 54.644449800252914, 56.01201541721821, 51.5344724804163, 54.391953349113464, 51.70514792203903, 56.933313980698586, 59.486814960837364, 57.16655686497688, 52.7735897898674, 48.906054720282555, 55.323287174105644, 56.104316264390945, 56.27677381038666, 54.60604526102543, 53.21299821138382, 59.28706347942352, 58.42316463589668, 56.830008924007416, 54.29487235844135, 55.218978971242905, 57.433367148041725, 57.759146466851234, 55.438846573233604, 44.15461868047714, 40.08474826812744, 34.81043368577957, 30.013436190783978, 22.651950605213642, 14.676099736243486, 15.893707349896431, 13.360018506646156, 21.646119877696037, 17.519410215318203, 9.740084800869226, 3.686152989976108, 9.07699378207326, 4.7536760196089745, 3.5246276948601007, 2.469980511814356, 0.5569332058075815, 0.18845112528651953, 0.9836716821882874, 4.237472293898463, 8.628930374979973, 18.90314396470785, 27.87507053464651, 27.687408104538918, 32.97868877649307, 23.085602335631847, 26.067477129399776, 40.09452134370804, 39.33682680130005, 43.50774139165878, 27.773553282022476, 6.041312925517559, 0.6107015674933791, 0.019014304016309325, 0.06205748701177072, 0.030781435780227184, 0.017103451864386443, 0.05292714471579529, 0.03221067490812857, 0.06611177668673918, 0.02295818067068467, 0.006762137927580625, 0.06127532273239922, 0.07964177450048737, 0.015398872237710748, 0.03755537385586649, 0.0689124342170544, 0.023913287623145152, 0.04615308418578934, 0.03074164553254377, 0.02298885734489886, 0.01614288084965665, 0.010701702703954652, 0.05001680146961007, 0.06165516133478377, 0.024689865385880694, 0.08739450888242573, 0.038440147473011166, 0.03367958925082348, 0.01860675918578636, 0.04387957786093466, 0.00037837216495972825, 0.049945507053053007, 0.07502746389945969, 0.015245555659930687, 0.07918617746327072, 0.04007847557659261, 0.029959774401504546, 0.03062626754399389, 0.040771767671685666, 0.04612815173459239, 0.018539978882472496, 0.03641257033450529, 0.005441512575998786, 0.020996715902583674, 0.046135614029481076, 0.009536592078802641, 0.0217669891208061, 0.047024387822602876, 0.030969154613558203, 0.03531277056026738, 0.018387682757747825, 0.050048019911628217, 0.04027127812150866, 0.0478968677634839, 0.013445051590679213, 0.06477059709141031, 0.04429344764503185, 0.09724443385493942, 3.7790627544745803, 20.296126417815685, 39.788272976875305, 45.17559729516506, 46.61932982504368, 39.32961858808994, 21.922908425331116, 31.578380316495895, 56.92664913833141, 60.52259758114815, 36.71215943992138, 22.20802992582321, 10.238800439983606, 1.5468427282758057, 0.5755479913204908, 0.07380451585049741, 1.701970947906375, 4.298711232841015, 8.603286501020193, 8.402731362730265, 11.270882058888674, 11.861358024179935, 10.079531986266375, 14.255609549582005, 18.94302472472191, 14.996895622462034, 9.868164528161287, 21.34477324783802, 37.49956078827381, 42.24252708256245, 52.170337960124016, 59.8830197006464, 60.715057253837585, 59.59910273551941, 60.44890433549881, 59.14748556911945, 56.8581236153841, 57.47700020670891, 60.56571386754513, 57.126632407307625, 55.443520322442055, 58.62132780253887, 61.15033529698849, 60.59170447289944, 53.821721747517586, 47.52598777413368, 45.004180893301964, 46.70669473707676, 47.755556255578995, 43.878791481256485, 42.72803843021393, 41.414198130369186, 41.97155222296715, 43.53598527610302, 45.87710425257683, 48.53618636727333, 55.00556722283363, 58.39554771780968, 46.877294182777405, 50.0437630712986, 32.69763305783272, 48.899196088314056, 50.132640302181244, 55.033875703811646, 55.52779600024223, 57.44860053062439, 53.97408217191696, 55.33530592918396, 54.01023343205452, 58.3030416816473, 62.249148935079575, 58.77345263957977, 55.52773140370846, 50.79679146409035, 57.71556660532951, 58.043105229735374, 56.980074271559715, 54.4698491692543, 57.10668347775936, 59.75665368139744, 60.926306918263435, 57.59360454976559, 57.33882062137127, 56.92839704453945, 61.76950067281723, 57.968690022826195, 58.0790551006794, 47.252356857061386, 42.61880189180374, 33.9093766361475, 33.507943376898766, 19.954705238342285, 12.634298298507929, 14.99615466222167, 16.27182886004448, 11.880100518465042, 14.939086474478245, 13.97653542459011, 10.01679165288806, 10.25622345507145, 8.147119078785181, 7.186473151668906, 2.2934847325086594, 1.301975199021399, 0.06297776868450455, 1.1621202598325908, 3.650257266126573, 11.03705020621419, 21.99381072074175, 33.201869800686836, 31.928292140364647, 33.92066203057766, 25.9625381603837, 31.50093287229538, 44.883905947208405, 45.07660120725632, 48.856060802936554, 31.783525608479977, 7.431999826803803, 0.6876566412393004, 0.04778291469847318, 0.07350367144681513, 0.031361305445898324, 0.07818873098585755, 0.05002804500691127, 0.023276753126992844, 0.02351203434955096, 0.017509603312646504, 0.04688866014475934, 0.06363169726682827, 0.028811005868192296, 0.030997352514532395, 0.09236229700036347, 0.015617380922776647, 0.041900429569068365, 0.04841610025323462, 0.04756377333251294, 0.10760681921965443, 0.00792196909969789, 0.028697234629362356, 0.011289530975773232, 0.07318172778468579, 0.08158150361850858, 0.06483620294602588, 0.02687165524548618, 0.0330320282955654, 0.046084235145826824, 0.0375192312640138, 0.1570276723941788, 0.16217569849686697, 0.196368980105035, 0.17531334509840235, 0.2500456420239061, 0.1893123728223145, 0.21828457131050527, 0.11001249091350473, 0.19014635385246947, 0.06900356253026985, 0.20222532679326832, 0.09524712892016396, 0.1922043738886714, 0.10970714909490198, 0.11122649608296342, 0.1337226471514441, 0.09490729207755066, 0.11893033777596429, 0.15031499118776992, 0.10058033571112901, 0.12711337680229917, 0.2479673019843176, 0.1444530487060547, 0.13587999623268843, 0.13355208677239716, 0.16239746706560254, 0.12258373782970011, 0.2825976046733558, 5.451161842793226, 24.45884484797716, 48.38083930313587, 52.53718927502632, 53.25257308781147, 44.46555979549885, 29.31460428982973, 42.87080816924572, 61.52967654168606, 59.49175089597702, 36.00611172616482, 24.616192504763603, 11.130739878863096, 1.775505195837468, 0.7792574353516102, 0.15703625162132084, 2.414968963712454, 7.270856173709035, 12.835149820894003, 15.810827147215605, 23.28754059970379, 17.150488011538982, 22.096887789666653, 19.690993689000607, 16.829923912882805, 21.60160716623068, 10.725381430238485, 21.12650156021118, 41.48906551301479, 43.69461916387081, 52.401464357972145, 64.44417715072632, 63.07442665100098, 62.49396599829197, 60.57115517556667, 61.17085039615631, 57.55713030695915, 57.97865688800812, 59.51401770114899, 56.16009347140789, 54.73329283297062, 58.660777285695076, 61.7216232419014, 64.99093741178513, 54.0181940048933, 49.10718932747841, 48.13237063586712, 47.6664624363184, 49.121533557772636, 47.4263571202755, 44.130026400089264, 44.06825311481953, 43.58706973493099, 46.36857748031616, 47.464917451143265, 52.2499018907547, 56.55701257288456, 62.23460331559181, 49.09792922437191, 53.36852766573429, 39.0340818464756, 51.354837119579315, 54.49358269572258, 57.24218800663948, 55.311925783753395, 57.370142340660095, 54.97467868030071, 55.814988389611244, 55.08930332958698, 59.10676695406437, 64.16278705000877, 60.84711156785488, 57.43748612701893, 52.78783902525902, 59.55822452902794, 60.88728681206703, 57.319472059607506, 53.1327161192894, 55.30307225883007, 61.34111166000366, 61.750030517578125, 60.35045921802521, 57.055382430553436, 58.125522807240486, 63.79774823784828, 60.10721147060394, 61.0627955943346, 49.52078953385353, 45.48199385404587, 39.29657556116581, 34.511180743575096, 27.476046346127987, 23.937537521123886, 25.459133572876453, 21.801394745707512, 33.10264952480793, 27.099045775830746, 20.18952503800392, 15.179026499390602, 18.8439754396677, 14.298731535673141, 10.924150664359331, 4.316067276522517, 1.285007803235203, 0.534057958284393, 1.4798468607477844, 5.999660985544324, 12.300704699009657, 24.449653141200542, 39.344042614102364, 39.19796705245972, 45.65056800842285, 33.82089078426361, 39.31794561445713, 52.71737940609455, 52.545887008309364, 54.89394061267376, 37.21049129962921, 9.76287692785263, 1.1578675755299628, 0.14468381210463122, 0.25678066187538207, 0.09667957041529007, 0.17453708831453696, 0.18576173053588718, 0.13792960031423718, 0.10591889338684268, 0.19067995803197846, 0.24253810581285506, 0.15355728595750406, 0.09041029275977053, 0.08721975536900572, 0.12962453736690804, 0.1613055748748593, 0.14818763971561566, 0.22552208451088518, 0.10397165373433381, 0.17081641999538988, 0.09725441574119031, 0.12866456934716552, 0.17746175872161984, 0.2002593775978312, 0.17409472377039492, 0.24526993656763807, 0.12785418861312792, 0.13252844248199835, 0.0841625893372111, 0.20156160928308964], [0.01697019368293695, 0.05787008944025729, 0.01807132561225444, 0.0546330490760738, 0.07030597233097069, 0.04622275700967293, 0.015081452893355163, 0.03542844540788792, 0.04205926030408591, 0.05776837067969609, 0.0661556153499987, 0.026514604287513066, 0.07396228902507573, 0.03641350915131625, 0.03699974644405302, 0.06902668043039739, 0.0714511433034204, 0.007306938796318718, 0.034560756030259654, 0.031870771272224374, 0.03138529908028431, 0.06292282007052563, 0.05016993993194774, 0.006712934000461246, 0.03510022317641415, 0.0718238869740162, 0.026937804723274894, 0.04062497457198333, 4.486939357593656, 16.620824933052063, 34.71402145922184, 48.302799090743065, 44.00064334273338, 28.354897387325764, 27.81441628932953, 38.477537110447884, 34.673166051506996, 19.72209881991148, 22.821545004844666, 16.535014137625694, 5.363586517050862, 1.2293106294237077, 0.20100593363167718, 0.2905718924012035, 2.294808723963797, 4.957167925313115, 5.289652934297919, 3.258204753510654, 8.82393591105938, 14.42878145724535, 5.597943216562271, 12.101268600672483, 27.62084897607565, 19.564291387796402, 10.90225338935852, 28.115833215415478, 29.620083197951317, 43.38807061314583, 55.97074203193188, 57.93063506484032, 58.041725903749466, 59.968819096684456, 58.525151163339615, 57.08074986934662, 57.8016471862793, 59.12283629179001, 57.550693452358246, 58.30290108919144, 54.73500274121761, 56.39280818402767, 58.369519114494324, 57.44720980525017, 55.180965811014175, 54.7439094632864, 51.40395328402519, 45.40083780884743, 41.68781764805317, 40.05368873476982, 40.94173528254032, 39.88467760384083, 41.58028721809387, 46.02870091795921, 50.20352929830551, 47.80962735414505, 50.50525210797787, 55.82002691924572, 48.15793186426163, 40.51255591213703, 39.06092740595341, 57.34117269515991, 59.28046703338623, 54.692437425255775, 57.60582849383354, 56.77569463849068, 55.76625980436802, 54.24573339521885, 57.371943444013596, 58.39242808520794, 59.832995384931564, 56.0239277780056, 51.25487208366394, 44.96021345257759, 54.171451181173325, 54.99852620065212, 57.964856028556824, 55.26762776076794, 56.743517965078354, 55.13271979987621, 57.86592833697796, 58.68855759501457, 58.20052698254585, 56.63073621690273, 57.019949331879616, 53.42224158346653, 55.014846324920654, 50.23391246795654, 47.58964195847511, 36.75531752407551, 38.53538140654564, 21.657006293535233, 17.530251033604145, 14.641064666211605, 9.28742554038763, 5.787582015618682, 14.584517050534487, 8.696480300277472, 7.08831824362278, 9.294697400182486, 5.497556878253818, 7.140189735218883, 1.4817725261673331, 1.65939518250525, 0.08494070149026811, 0.42180559888947755, 2.9724123515188694, 11.556881312280893, 17.762285582721233, 29.444350227713585, 28.264796622097492, 30.190915167331696, 24.523213393986225, 36.853458657860756, 32.8367055952549, 44.12833169102669, 42.01981343328953, 30.15095081180334, 7.987444996833801, 0.40236230939626694, 0.0688318740867544, 0.004511634006121312, 0.045033550704829395, 0.01894440112664597, 0.029041322122793645, 0.04203069504001178, 0.06252518476685509, 0.0749686561175622, 0.02990340828546323, 0.062157483989722095, 0.04329049072111957, 0.06961182676604949, 0.0542223037336953, 0.010368113817094127, 0.08540665148757398, 0.0286305415284005, 0.048882621704251505, 0.04075779303093441, 0.00339309152423084, 0.029736605029029306, 0.032587455862085335, 0.060126300013507716, 0.026873909519053996, 0.022970056888880208, 0.05858169031853322, 0.04064759523316752, 0.035733809490920976, 0.04557602354907431, 0.016106857001432218, 0.009454290684516309, 0.019453169334155973, 0.045692856147070415, 0.035147913586115465, 0.051386824634391814, 0.016981912194751203, 0.006952850862944615, 0.01213046036355081, 0.11898601369466633, 0.05874437279999256, 0.03780598228331655, 0.03548989523551427, 0.021093438153911848, 0.01766905559634324, 0.025140402831311803, 0.06415118579752743, 0.10772574838483706, 0.04272484431567136, 0.03314408517326228, 0.06172419591166545, 0.038295907361316495, 0.03341518800880294, 0.023862405978434253, 0.00899808508620481, 0.02200976974563673, 0.0974955469428096, 0.10429391651996411, 5.286407908424735, 20.235012397170067, 41.42117075622082, 53.09190630912781, 48.72170001268387, 32.723973244428635, 27.575260922312737, 37.99476161599159, 37.6888932287693, 28.248677887022495, 22.796652540564537, 18.89385536313057, 6.12753932364285, 1.518543865531683, 0.26856854965444654, 0.8214436029084027, 3.3640934340655804, 5.519156344234943, 8.371933065354824, 13.018428236246109, 7.9559404123574495, 15.005979035049677, 9.753957856446505, 10.822790153324604, 16.687338463962078, 16.95978954434395, 14.243574645370245, 21.611368842422962, 36.567242816090584, 41.09249219298363, 56.53396300971508, 58.281812220811844, 60.198246985673904, 59.769128412008286, 59.97544974088669, 58.25912743806839, 58.28276216983795, 58.98151807487011, 58.94616097211838, 57.30874143540859, 55.6966969370842, 55.041053518652916, 58.03740553557873, 58.162301033735275, 58.0654252320528, 55.64522109925747, 53.34008239209652, 46.59056916832924, 43.53136092424393, 41.71511918306351, 43.57768043875694, 40.82413159310818, 45.17164930701256, 46.95078603923321, 50.61300292611122, 49.491911083459854, 54.23004783689976, 58.947452902793884, 52.15041182935238, 45.61085633933544, 41.133385598659515, 58.77911813557148, 59.776313826441765, 54.28848870098591, 59.76584538817406, 56.455975994467735, 56.66563734412193, 57.260294035077095, 57.5635177642107, 58.34819085896015, 59.68101114034653, 57.9771863669157, 52.89993681013584, 47.82882772386074, 56.30629442632198, 57.230237647891045, 58.12447406351566, 55.84426961839199, 56.64082087576389, 55.39546050131321, 58.38249161839485, 60.97105711698532, 58.95755276083946, 58.52973751723766, 58.38205464184284, 58.05111140012741, 57.67168655991554, 52.463180646300316, 49.24530051648617, 37.984585762023926, 31.86920341104269, 24.054727032780647, 17.944765090942383, 15.143620949238539, 16.10557448118925, 9.175687786191702, 9.479488134384155, 12.983865290880203, 6.9831717107445, 11.779635809361935, 9.909965135157108, 8.346081152558327, 5.0124293100088835, 1.5810338873416185, 0.27662684849929065, 0.4341629514237866, 3.7957201106473804, 10.287950802594423, 20.67398764193058, 31.618243977427483, 33.406523019075394, 34.673466235399246, 27.29253139346838, 38.261883482337, 39.2788153141737, 48.96326445043087, 48.38786132633686, 34.1818980127573, 10.550213679671288, 0.5336772068403661, 0.06470946638728492, 0.038451105283456855, 0.034351600261288695, 0.01577273098519072, 0.03652374405646697, 0.05759902371210046, 0.037702348781749606, 0.03912365064024925, 0.026293256887583993, 0.02767674817732768, 0.061110918468330055, 0.028531860007205978, 0.03245401399908587, 0.00632800797575328, 0.03034960973309353, 0.029425207285385113, 0.03258501790696755, 0.03676609238027595, 0.04211639454297256, 0.05768909446487669, 0.025921478008967824, 0.016336286389559973, 0.05321089374774601, 0.0259933457346051, 0.058657586050685495, 0.03307347353256773, 0.046662409004056826, 0.02706663784920238, 0.36696513066999614, 0.14858235837891698, 0.07600726210512221, 0.1992550291470252, 0.20429976313607767, 0.18914576066890731, 0.12734180985717103, 0.09486189490417019, 0.1314666072721593, 0.20932885265210643, 0.14592425257433206, 0.1353134258533828, 0.1674700464354828, 0.14827466395217925, 0.1176197495078668, 0.19226617994718254, 0.2775389183079824, 0.22871694120112807, 0.1184826297685504, 0.11475761246401817, 0.12595881766173989, 0.0846300384728238, 0.1230355647567194, 0.09399957125424407, 0.13763575436314568, 0.16012383828638121, 0.26010328670963645, 0.3719497803831473, 7.298139659687877, 24.911809042096138, 50.32044142484665, 61.76865331828594, 55.801559910178185, 41.568781435489655, 41.71203374862671, 48.80236588418484, 45.91057285666466, 31.464426331222057, 33.919989466667175, 22.473238594830036, 7.869045725092292, 2.0266093779355288, 0.49009099253453314, 1.0745595395565033, 6.2454023491591215, 11.268222201615572, 15.775859523564577, 15.576667562127113, 18.492847681045532, 23.837551586329937, 11.547065488994122, 28.0123058706522, 42.184257209300995, 30.497110337018967, 17.8488677367568, 33.87921765446663, 36.50329224765301, 47.11083345115185, 59.179145470261574, 60.658288300037384, 59.201552867889404, 60.59751056134701, 59.12829279899597, 59.398348107934, 58.1985966861248, 60.81129848957062, 57.313004806637764, 57.92579032480717, 55.12249834835529, 56.17788411676884, 58.92443373799324, 60.281933695077896, 59.66714568436146, 59.401399344205856, 56.38656131923199, 50.245729833841324, 45.014094561338425, 44.59378771483898, 45.378806591033936, 44.73886393010616, 48.000662103295326, 51.88807010650635, 54.53856088221073, 52.31237053871155, 56.19665130972862, 62.658117190003395, 52.79825046658516, 46.48285634815693, 48.05359326303005, 58.78827564418316, 59.391930252313614, 56.29793107509613, 61.129915192723274, 57.539149671792984, 58.789445981383324, 57.790840566158295, 59.68260705471039, 60.196377485990524, 60.54883897304535, 59.9828365445137, 55.36771059036255, 49.87525351345539, 58.30626390874386, 59.238597080111504, 60.087722316384315, 55.988217294216156, 55.73491148650646, 55.63529223203659, 59.7545599937439, 63.10174718499184, 62.046372815966606, 62.32161104679108, 60.57379983365536, 58.6649114638567, 59.59159053862095, 56.036562100052834, 53.37445914745331, 41.42316944897175, 40.46889245510101, 28.08951012790203, 26.78875632584095, 23.07315420359373, 16.081166490912437, 14.148973021656275, 25.406413301825523, 27.04233381897211, 14.660155791789293, 16.925836466252804, 13.020552322268486, 14.286768827587366, 5.929599869996309, 3.782928097061813, 0.3420466318493709, 0.7352671364787966, 3.984754029661417, 14.632610119879246, 25.46601690351963, 37.845520824193954, 42.7317850291729, 42.584409937262535, 35.96695102751255, 46.16161398589611, 44.80983652174473, 56.20662197470665, 57.401733845472336, 39.73044767975807, 12.811656631529331, 0.9254716895520687, 0.18520480807637796, 0.09444828116102144, 0.1697906680055894, 0.13417992886388674, 0.19186972465831786, 0.13057344738626853, 0.10641861110343598, 0.14989943301770836, 0.20344267162727192, 0.08388369766180404, 0.14085620030527934, 0.16956143343122676, 0.148006837698631, 0.10626362840412185, 0.24352059059310704, 0.11644014288322069, 0.10601644869893789, 0.159943466715049, 0.12210169807076454, 0.1454357264447026, 0.20135027531068772, 0.10745565115939826, 0.13036701158853248, 0.09156084430287592, 0.15441776165971532, 0.14185772859491408, 0.12289365127799101, 0.17016236524796113], [0.03652433035313152, 0.02016039154113969, 0.020964311879652087, 0.049858471684274264, 0.01924670756125124, 0.03974287639721297, 0.056519907593610696, 0.058345698489574715, 0.06633180862991139, 0.004878483168795356, 0.00856492781167617, 0.03515975084155798, 0.03932642764993943, 0.10960531901218928, 0.07547278219135478, 0.06613099089008756, 0.013033537197770784, 0.05473312769026961, 0.0650773267261684, 0.047715616747154854, 0.03292167093604803, 0.052663262977148406, 0.07374688808340579, 0.048919654873316176, 0.07322112840483896, 0.09736812760820612, 0.09396175883011892, 0.04809899168321863, 5.828505344688892, 19.731708504259586, 33.83406087756157, 42.9739498347044, 36.745616644620895, 33.801523223519325, 26.705101914703846, 55.84920175373554, 44.22191686928272, 24.13591157644987, 28.356945477426052, 14.33723771944642, 4.370806664228439, 1.209178597200662, 0.4877068579662591, 0.6112248706631362, 2.6666076108813286, 3.135222215205431, 7.114475090056658, 14.087151288986206, 6.8700142577290535, 9.95614405721426, 11.499937567859888, 9.419018179178238, 16.6349620744586, 15.133036617189646, 18.555437922477722, 22.132108099758625, 41.34679734706879, 40.95310427248478, 52.88690350949764, 54.5407609641552, 61.25815071165562, 56.27115771174431, 59.30519990622997, 57.06575207412243, 58.23550410568714, 56.37461096048355, 59.120020642876625, 56.23182602226734, 58.662456795573235, 58.59360069036484, 56.023889780044556, 54.21211279928684, 58.36724303662777, 56.26681074500084, 55.87999530136585, 55.81733286380768, 48.64605367183685, 40.754181146621704, 39.68177609145641, 42.08706982433796, 50.76406382024288, 52.85051666200161, 54.293382838368416, 52.39132650196552, 51.80871896445751, 56.568799540400505, 49.986203759908676, 29.3492204323411, 46.134658232331276, 59.16676573455334, 52.96531990170479, 56.3952362537384, 54.783051162958145, 55.11107236146927, 54.37807649374008, 53.66095997393131, 54.74127620458603, 56.02917529642582, 55.39327181875706, 56.57045245170593, 50.23306131362915, 43.28035019338131, 51.19383215904236, 55.672264248132706, 58.68466280400753, 55.59414803981781, 56.70681573450565, 53.96106407046318, 57.319282069802284, 58.14158454537392, 57.18729995191097, 56.77994281053543, 57.31822952628136, 57.22019478678703, 58.88534143567085, 53.16247992217541, 53.0712354183197, 39.643850326538086, 36.84650123119354, 26.27495739609003, 13.339906185865402, 14.08186862245202, 23.0111301317811, 8.310130331665277, 4.255261514335871, 9.916623327881098, 8.371653780341148, 9.675247929990292, 10.860041454434395, 5.197905907407403, 5.6065222062170506, 0.9128393267747015, 0.11877070923219435, 0.5414563394151628, 1.3199807703495026, 8.164566792547703, 17.720596119761467, 28.1569280102849, 30.62712036073208, 33.76773923635483, 25.99122852087021, 28.675729371607304, 31.75685103982687, 34.43174980580807, 47.4640928953886, 36.731998175382614, 9.492627829313278, 1.4332532859407365, 0.05071539249911439, 0.04315735313866753, 0.052539736207108945, 0.013036931595706847, 0.041340872485307045, 0.051458549496601336, 0.059510818391572684, 0.04960687248967588, 0.01666228588874219, 0.05543518826016225, 0.011184299073647708, 0.05091425096907187, 0.048779396383906715, 0.06173681984364521, 0.027120697741338518, 0.013000828894291772, 0.08294122948427685, 0.024469634918204974, 0.03743087487237062, 0.11391433232347481, 0.04867047508014366, 0.04848094169574324, 0.01956795917067211, 0.039076420362107456, 0.02978783548314823, 0.04058028614963405, 0.07452692239894532, 0.023670165610383265, 0.072137808019761, 0.07620925243827514, 0.04941558392602019, 0.021726775848947, 0.018713342724367976, 0.09606274921679869, 0.02261341411212925, 0.03977403546741698, 0.018794581919792108, 0.07393022082396783, 0.03720981134392787, 0.008176767878467217, 0.020703936788777355, 0.06439088465413079, 0.07570228393888101, 0.029809420848323498, 0.09222554144798778, 0.051183980831410736, 0.023916415775602218, 0.023902342800283805, 0.10548107078648172, 0.0336944359150948, 0.05634699831716716, 0.019290616728540044, 0.08232503168983385, 0.1263561041560024, 0.05853757706063334, 0.16923325572861359, 7.325296327471733, 22.48842068016529, 39.61364954710007, 50.54246351122856, 43.34930509328842, 36.865959987044334, 31.39852836728096, 55.8904143422842, 49.78142514824867, 24.836063906550407, 29.76678192615509, 16.592102274298668, 5.734879318624735, 1.8335050460882485, 0.49386864295229316, 1.0010074800811708, 3.4082192787900567, 5.549255954101682, 8.70984323322773, 12.036464028060436, 13.900378961116076, 12.672618292272091, 7.390137473121285, 13.125693630427122, 15.999945849180222, 17.486825063824654, 17.100815176963806, 21.81859642267227, 37.5834146887064, 44.63172107934952, 53.16996552050114, 56.903633773326874, 60.24034112691879, 57.04735346138477, 60.5511112511158, 58.75709071755409, 58.36909733712673, 57.87027910351753, 59.688101559877396, 57.78180845081806, 59.69540096819401, 58.366262689232826, 55.99959388375282, 55.260294154286385, 59.07671436667442, 57.67811581492424, 57.76389621198177, 56.63641691207886, 50.743708312511444, 42.9262737929821, 40.5578038841486, 43.8784608989954, 52.71461695432663, 55.49653507769108, 55.81240072846413, 54.951853305101395, 54.45789121091366, 58.5734161734581, 51.975518614053726, 33.328121826052666, 46.45110905170441, 58.45179229974747, 55.56563816964626, 58.07771377265453, 57.47854672372341, 57.14280813932419, 55.781648978590965, 55.61440095305443, 56.841662898659706, 57.58916638791561, 58.04576128721237, 59.06396605074406, 52.76167742908001, 45.041183307766914, 53.943926990032196, 58.68101879954338, 58.73916707932949, 55.369078516960144, 56.59116134047508, 54.62432987987995, 57.88962006568909, 59.47901777923107, 61.87456503510475, 58.35990943014622, 60.35867057740688, 57.83374786376953, 60.305393636226654, 54.75522145628929, 51.42542593181133, 39.31038402020931, 33.864284455776215, 24.649414122104645, 19.41532038152218, 14.072179142385721, 18.87235041707754, 17.750154733657837, 13.105936590582132, 8.688588123768568, 9.038878977298737, 12.130983956158161, 11.247775498777628, 8.245822582393885, 2.573932958766818, 2.5933653535321355, 0.469821811420843, 0.35917246132157743, 1.869832284282893, 8.728437535464764, 16.699450314044952, 29.07441157847643, 30.68213950842619, 35.653600841760635, 28.18856131285429, 34.29657585918903, 39.33125250041485, 41.37164421379566, 53.81482891738415, 43.64378549158573, 12.137804590165615, 1.8321408005431294, 0.031634727492928505, 0.014894731320964638, 0.028473144993768074, 0.02114404891472077, 0.019095814095635433, 0.004591191773215542, 0.04794307387783192, 0.026041650271508843, 0.06714314673445188, 0.03498528676573187, 0.029049010772723705, 0.09769459094968624, 0.015107107083167648, 0.013767202126473421, 0.015616460659657605, 0.02107381576934131, 0.023685659798502456, 0.029131749106454663, 0.03927370547899045, 0.010455860719957855, 0.05567961459746584, 0.05051786618423648, 0.006634321543970145, 0.07756393912131898, 0.007715478568570688, 0.06009187549352646, 0.01913200492708711, 0.060282507256488316, 0.22943560732528567, 0.25752055342309177, 0.18662582791876048, 0.11184902439708821, 0.13762696733465418, 0.17420901451259851, 0.09213220895617269, 0.15046909073134884, 0.1967520173639059, 0.22398459201212972, 0.1301636779680848, 0.05785496447060723, 0.11780158311012201, 0.2900773548753932, 0.12683275592280552, 0.16286046331515536, 0.20979978988179937, 0.12273827524040826, 0.14089114061789587, 0.19946691230870783, 0.1590481397579424, 0.061568363453261554, 0.167204906756524, 0.1576847699470818, 0.2171835210174322, 0.12250656189280562, 0.27937662438489497, 0.344968467252329, 8.60578391700983, 28.30039881169796, 48.721483424305916, 56.41217574477196, 50.07370166480541, 44.470917508006096, 40.01917138695717, 67.37416192889214, 54.44792814552784, 35.81832580268383, 36.85704566538334, 19.197808653116226, 6.374661913141608, 2.204560241661966, 1.05087636038661, 1.7404385400004685, 4.817689284682274, 9.69252085313201, 18.043164610862732, 24.705582708120346, 11.818798407912254, 20.32818339765072, 25.821214243769646, 20.16400370746851, 25.847126953303814, 20.592854395508766, 24.894903749227524, 26.773842126131058, 45.601649433374405, 45.9329042583704, 54.12887446582317, 57.30019569396973, 62.28588156402111, 58.60680878162384, 60.3993283957243, 58.53486344218254, 60.38816079497337, 58.51610764861107, 62.34010465443134, 57.9039490967989, 61.592460572719574, 60.3631467372179, 56.05264663696289, 54.03301700949669, 59.07968960702419, 59.21076737344265, 59.82224956154823, 61.19575046002865, 54.6605571359396, 45.4823662340641, 42.39763095974922, 46.02545589208603, 56.08896888792515, 57.38698683679104, 59.55506309866905, 58.343186527490616, 58.1518629938364, 61.33100040256977, 54.589728936553, 36.631136387586594, 50.34855231642723, 58.61212469637394, 58.222721591591835, 59.68954548239708, 61.40987277030945, 59.85449083149433, 60.493285953998566, 57.734751775860786, 58.82622420787811, 58.77022661268711, 60.14069527387619, 62.20247983932495, 55.13058811426163, 47.27298595011234, 55.18249712884426, 59.284080639481544, 60.90367153286934, 54.17338527739048, 57.81215742230415, 53.26121382415295, 58.55074658989906, 60.4791659116745, 61.616235896945, 59.59890894591808, 63.59691001474857, 60.78562706708908, 62.576448172330856, 57.57318064570427, 58.07726539671421, 44.20825660228729, 44.57902170717716, 31.86012949794531, 22.595470435917377, 23.16061221063137, 35.66412627696991, 23.940579257905483, 19.251034297049046, 25.234782211482525, 21.805078648030758, 22.781156972050667, 20.190343894064426, 14.100562669336796, 8.600752986967564, 2.819985430687666, 0.5046857718843967, 1.1296587204560637, 2.1012107748538256, 10.514161214232445, 21.930384524166584, 36.69304646551609, 41.60112909972668, 45.51934964954853, 38.03774490952492, 41.35079473257065, 44.40116085112095, 46.81295983493328, 59.16971057653427, 51.76825113594532, 15.871242005378008, 2.9191684210672975, 0.26671493193134665, 0.19882131804479286, 0.11397603448131122, 0.13329334440641105, 0.12482998135965317, 0.14998044585809112, 0.1721962506417185, 0.16293120483169332, 0.13909443077864125, 0.18765724991681054, 0.20478509803069755, 0.19917817233363166, 0.09998388646636158, 0.15326391498092562, 0.10924280955805443, 0.08958298363722861, 0.14455570257268846, 0.12824354897020385, 0.15725897013908252, 0.2806781732942909, 0.19401145895244554, 0.18639178422745317, 0.07426279946230352, 0.14194496063282713, 0.09602934514987282, 0.12972753262147307, 0.15713203320046887, 0.31821977288927883], [0.049330830661347136, 0.029429719543259125, 0.03164935151289683, 0.02783630436169915, 0.01980032004212262, 0.03431388431636151, 0.017745500517776236, 0.02980941157147754, 0.03492407442536205, 0.012229017575009493, 0.021475460525834933, 0.057312202188768424, 0.03434680969803594, 0.07066774705890566, 0.04213678876112681, 0.023884238107712008, 0.03635722467151936, 0.09475498110987246, 0.028831147756136488, 0.011249321414652513, 0.04896806516626384, 0.022042995697120205, 0.05227934627328068, 0.011204119055037154, 0.03532095273840241, 0.02006106991757406, 0.021727966995968018, 0.3103150095557794, 6.592812007293105, 23.31696432083845, 35.52607588469982, 45.182649716734886, 40.44815696775913, 27.621821723878384, 37.40655317902565, 36.146100014448166, 22.419306188821793, 27.5184615701437, 17.06620093435049, 9.827216975390911, 3.4022778226062655, 0.7547136023640633, 0.0371076881128829, 1.4828098705038428, 3.289722162298858, 3.431751891039312, 5.524100828915834, 9.527827240526676, 14.58502622321248, 13.649659864604473, 3.608992430381477, 5.153592210263014, 8.075791206210852, 20.17841063439846, 18.85709423571825, 21.09872505068779, 37.88536548614502, 39.827384278178215, 57.90922701358795, 57.44714140892029, 57.70165555179119, 55.46791881322861, 56.01564422249794, 54.26641948521137, 57.08155542612076, 57.183648347854614, 54.80216793715954, 52.60666474699974, 54.12062510848045, 56.342293694615364, 59.669706746935844, 57.09434553980827, 54.32119354605675, 56.16461902856827, 56.04089006781578, 53.84108550846577, 55.07598124444485, 44.589459747076035, 42.291206270456314, 46.80570602416992, 55.01279443502426, 55.70895127952099, 54.988863319158554, 56.072663962841034, 53.94737720489502, 56.911909729242325, 53.54613393545151, 33.48355248570442, 50.85970088839531, 56.70519322156906, 54.000308364629745, 50.63091516494751, 50.23348689079285, 51.31129905581474, 52.18179054558277, 53.88821817934513, 50.27111627161503, 49.58675019443035, 53.44647668302059, 50.80877982079983, 44.892352893948555, 41.70172490179539, 49.70729112625122, 54.10949930548668, 56.45303875207901, 57.89549455046654, 54.89865995943546, 54.58263471722603, 56.42960540950298, 57.3648302257061, 56.99158005416393, 55.072686821222305, 60.379037484526634, 58.432531133294106, 58.51386196911335, 55.39346560835838, 48.89954946935177, 43.45558539032936, 29.5650165528059, 25.314703322947025, 22.282011955976486, 14.395550340414047, 14.47703031823039, 10.094515532255173, 10.038193054497242, 4.786200849339366, 3.224602206610143, 12.201698161661625, 7.8865281119942665, 8.511534724384546, 2.3874900257214904, 2.004617345519364, 0.2086585300276056, 0.18767439352814108, 1.6576061910018325, 6.110748024657369, 17.18713704496622, 37.67656669020653, 66.87855452299118, 56.576209142804146, 47.22040057182312, 37.088419049978256, 28.324269130825996, 37.76275746524334, 35.41421368718147, 36.143132373690605, 13.348162192851305, 2.572786845266819, 0.057232332255807705, 0.04844854694965761, 0.07831103692296892, 0.011164612678840058, 0.033155963246827014, 0.02994575708726188, 0.087492093880428, 0.021630784613080323, 0.06919236489920877, 0.03187211827025749, 0.02605342073366046, 0.05139134060300421, 0.06014767015585676, 0.050597832596395165, 0.01608941838640021, 0.07029936721664853, 0.0427129959280137, 0.04157379182288423, 0.07853774819523096, 0.1214116565824952, 0.012234369387442712, 0.05115420215588529, 0.01961050835234346, 0.006744843103660969, 0.051598117788671516, 0.04021418470074423, 0.11517247301526368, 0.06188379476952832, 0.03133460668323096, 0.06236402739887126, 0.01463348142351606, 0.04047512382385321, 0.041538680816302076, 0.028651952488871757, 0.007697149840169004, 0.016676546256348956, 0.05908870334678795, 0.020585831407515798, 0.013142481693648733, 0.07027825311524794, 0.00796549606093322, 0.004063762726218556, 0.025033912061189767, 0.014840172334515955, 0.0069477945180551615, 0.05309469939675182, 0.016248648025793955, 0.04587735405948479, 0.00761825258450699, 0.042809055812540464, 0.06211951200384647, 0.018785112115438096, 0.02511806789698312, 0.005049917426731554, 0.009379856055602431, 0.32186250085942447, 7.492971830070019, 25.491847917437553, 42.41316832602024, 50.46612560749054, 47.341469675302505, 34.749997928738594, 40.38894474506378, 44.76999565958977, 29.58796352148056, 29.68300972133875, 23.102125748991966, 13.335772957652807, 4.353933669626713, 0.9693421167321503, 0.40208352904301137, 0.8001249062363058, 3.6780043272301555, 6.549354689195752, 9.898464102298021, 12.341315969824791, 15.53181666880846, 12.02931186184287, 12.29183692485094, 9.764439594000578, 12.882510479539633, 15.894399862736464, 17.06736747175455, 25.65718464553356, 38.23759898543358, 44.55671310424805, 54.63575966656208, 58.383566960692406, 57.04996392130852, 57.04503558576107, 56.169642359018326, 55.82211680710316, 57.32637248933315, 59.471053406596184, 57.5173844397068, 55.46895235776901, 57.63080455362797, 58.835389316082, 59.570706859230995, 57.53536507487297, 55.18374726176262, 57.69059434533119, 57.03240506350994, 56.93213224411011, 56.47923454642296, 46.96661598980427, 43.37538309395313, 47.498009875416756, 57.53378055989742, 57.41099014878273, 57.28850372135639, 59.37034361064434, 55.89809753000736, 58.120514675974846, 54.28590103983879, 38.38806711137295, 50.546050518751144, 58.0689400434494, 57.04023264348507, 53.16737785935402, 53.020481541752815, 54.35191109776497, 54.03846591711044, 55.96342742443085, 53.22611130774021, 52.843661829829216, 54.767152816057205, 54.85263302922249, 46.616943553090096, 42.67091989517212, 51.13040216267109, 56.015047654509544, 58.71638350188732, 58.92135590314865, 54.90448884665966, 54.85289141535759, 55.58166950941086, 57.41060636937618, 57.736157700419426, 58.21409225463867, 59.927777498960495, 61.88774272799492, 60.235522985458374, 58.44868026673794, 51.49401605129242, 43.33977520465851, 29.853333681821823, 26.785382106900215, 21.06905624270439, 19.432381466031075, 16.246613413095474, 14.008216224610806, 10.890529118478298, 9.995146114379168, 14.834289997816086, 12.492567803710699, 10.81710185855627, 9.12786640226841, 4.992249067872763, 2.4982243962585926, 0.39933749358169734, 0.3821833140682429, 1.592474242206663, 7.132075745612383, 19.60068203508854, 32.16498903930187, 53.91330823302269, 49.65250566601753, 46.78860314190388, 38.769790828228, 31.972768753767014, 42.501882165670395, 42.73555442690849, 41.67601928114891, 18.138731382787228, 3.066398883238435, 0.11211524761165492, 0.014025197706359904, 0.0829814761527814, 0.010364065401518019, 0.0320711251697503, 0.022899554714967962, 0.017450070081395097, 0.05242016137344763, 0.05117534594319295, 0.010482438883627765, 0.02506751650798833, 0.03998026717454195, 0.11804284789832309, 0.034895078715635464, 0.05141063273185864, 0.009800100888242014, 0.048122732987394556, 0.09441914444323629, 0.07363378477748483, 0.015825466143724043, 0.010271783048665384, 0.02567389568866929, 0.06477071583503857, 0.004328233080741484, 0.02444305304379668, 0.08697619734448381, 0.07250546055729501, 0.07967105222633108, 0.08687389970873483, 0.11935871283640154, 0.15460120572242886, 0.17528815660625696, 0.1947963543352671, 0.14426666573854163, 0.143266087397933, 0.1429410564014688, 0.14085637842072174, 0.09144676136202179, 0.08173725815140642, 0.11908836328075267, 0.10069976953673176, 0.17634573188843206, 0.13853921525878832, 0.26124631287530065, 0.21391216374468058, 0.13814595120493323, 0.15615177486324683, 0.13574525190051645, 0.1960367354331538, 0.13561571744503453, 0.10382278633187525, 0.09942888616933487, 0.16722921951441094, 0.13790206663543358, 0.14973731827922165, 0.8132733881939203, 10.05132419988513, 30.625771433115005, 48.87909896671772, 60.711455047130585, 57.08579979836941, 41.10226146876812, 48.276816084980965, 49.5557476580143, 34.775080382823944, 40.58476723730564, 24.448967278003693, 15.87687710300088, 5.193008445203304, 1.3040225766599178, 0.563149256631732, 3.47247501835227, 6.655251681804657, 10.88472492992878, 12.885602563619614, 20.560917109251022, 25.997013710439205, 29.537783414125443, 17.633533291518688, 9.351269714534283, 16.382060945034027, 27.014656104147434, 24.003139100968838, 29.125659428536892, 40.243108570575714, 43.2795712351799, 58.63311097025871, 58.69800388813019, 60.509123504161835, 56.39641419053078, 57.24070988595486, 55.66049247980118, 59.316143319010735, 61.3477499037981, 60.06162531673908, 56.30407154560089, 58.64680543541908, 59.74769376218319, 62.91805364191532, 58.35555486381054, 55.53928658366203, 57.664854526519775, 60.12624464929104, 59.04055930674076, 58.03359434008598, 49.91491958498955, 47.57313184440136, 50.55559940636158, 59.51350852847099, 59.22958396375179, 58.91000211238861, 62.969293892383575, 58.64340081810951, 60.721832290291786, 55.68103797733784, 41.34490504860878, 53.318871930241585, 58.97992976009846, 58.73825892806053, 55.465901121497154, 54.61771443486214, 57.122483029961586, 57.48264290392399, 57.99471862614155, 54.962006360292435, 54.41454313695431, 57.52486243844032, 55.86731158196926, 48.23795177042484, 45.887538492679596, 54.5931601524353, 57.47241385281086, 60.535836070775986, 61.00240923464298, 54.51454997062683, 53.61745610833168, 56.45518183708191, 57.118641436100006, 57.95213811099529, 58.34203518927097, 62.43864096701145, 62.943413481116295, 62.086228877305984, 59.0723218023777, 54.81530003249645, 49.08179149031639, 32.82027907669544, 32.333726584911346, 27.820370569825172, 18.64937838166952, 20.664704740047455, 17.423607856035233, 16.15221317857504, 16.682337932288647, 15.152897201478481, 21.379343792796135, 14.216045122593641, 14.92822190746665, 8.584176376461983, 4.15506231598556, 0.5687055084854364, 0.33118343038950115, 2.3398021096363664, 7.933364873751998, 22.568930760025978, 45.805155113339424, 74.82354059815407, 65.06036728620529, 57.8998377174139, 49.13979917764664, 40.092632845044136, 51.4264252781868, 50.391448214650154, 46.349346712231636, 22.488658167421818, 4.207374108955264, 0.2107704448280856, 0.21894595847697929, 0.2402926786453463, 0.12472576898289844, 0.14053811581106856, 0.1846883920370601, 0.19837916130200028, 0.23862992646172643, 0.13746172073297203, 0.11009561887476593, 0.189268882968463, 0.13495164370397106, 0.2262841069023125, 0.13063528313068673, 0.1555102178826928, 0.185872295696754, 0.18637799512362108, 0.20648268662625924, 0.2741694787982851, 0.20050235674716532, 0.0796519938739948, 0.2143723695189692, 0.13369063090067357, 0.10713423442211933, 0.11888728578924201, 0.18707347655436024, 0.20616424590116367, 0.1550389689509757], [0.023593288387928624, 0.02833668258972466, 0.017569149531482253, 0.09246242756489664, 0.022175003359734546, 0.010014778235927224, 0.03314512789074797, 0.08719156860024668, 0.059640152467181906, 0.04024176290840842, 0.014401934131456073, 0.005895592848901288, 0.05829768153489567, 0.0374632807506714, 0.018334129381401, 0.012274296004761709, 0.049207018164452165, 0.04355418321210891, 0.02222897976025706, 0.06772639317205176, 0.03765099587326404, 0.12275224245968275, 0.054141899454407394, 0.06817936300649308, 0.05731411321903579, 0.04309781805204693, 0.021142111909284722, 0.2974803966935724, 4.5294799748808146, 20.48229742795229, 40.45509919524193, 40.02020873129368, 32.195554599165916, 28.877848125994205, 23.58441486954689, 16.458972617983818, 31.23779509216547, 24.883055984973907, 19.924783743917942, 10.810369569808245, 2.6444284385070205, 0.24505501060048118, 0.21181948541197926, 0.37129176256712526, 3.0452133575454354, 4.4789887592196465, 8.325933683663607, 9.16907424107194, 14.293519165366888, 5.043199583888054, 5.213220035657287, 15.093914866447449, 16.475526429712772, 17.378213591873646, 24.65609036386013, 35.071061700582504, 40.58905340731144, 54.46768708527088, 53.01408268511295, 56.245873868465424, 55.65421521663666, 56.209164038300514, 58.065847009420395, 56.96486368775368, 56.295696794986725, 56.21007978916168, 51.47549584507942, 50.338095277547836, 49.74618583917618, 54.077767208218575, 53.825434148311615, 54.87763188779354, 56.28669127821922, 54.48548913002014, 53.147565722465515, 55.59167817234993, 51.62584237754345, 46.085941046476364, 42.870682775974274, 52.851215824484825, 53.08866128325462, 53.31807777285576, 53.510621041059494, 55.363093838095665, 54.466668739914894, 54.43651355803013, 56.9005711376667, 36.732632741332054, 51.157787293195724, 56.001516580581665, 46.94484315812588, 49.06523197889328, 45.70039473474026, 49.238430485129356, 47.94310659170151, 47.30049267411232, 46.35908558964729, 44.88249622285366, 45.25676853954792, 44.498219043016434, 41.9698841124773, 41.5780795365572, 45.004180893301964, 50.99267475306988, 54.79942448437214, 53.73146519064903, 55.59597194194794, 56.808939054608345, 55.754104256629944, 55.88290594518185, 55.110365599393845, 55.30623748898506, 55.498092994093895, 57.989288717508316, 55.893176794052124, 55.32380394637585, 50.62148027122021, 42.86323517560959, 32.87923291325569, 26.100033782422543, 23.225068151950836, 20.91806184500456, 18.339043334126472, 19.78838626295328, 10.856212209910154, 3.797022015787661, 13.601702637970448, 7.756985938176513, 10.747601687908173, 3.740532584488392, 2.8282108018174767, 3.489114800468087, 0.6212743814103305, 0.2518422924913466, 0.5970282386988401, 4.3409583158791065, 12.89007492363453, 31.49122629314661, 55.860205963253975, 62.252295166254044, 46.95028826594353, 38.82195822894573, 35.20541489124298, 36.99723534286022, 42.97569014132023, 39.0186432749033, 16.81366078555584, 2.511857827194035, 0.10430357928271405, 0.009151497215498239, 0.09947354861651547, 0.0786256926949136, 0.049966045990004204, 0.022934315056772903, 0.009339575062767835, 0.06372526724589989, 0.09449375997064635, 0.05095319887914229, 0.04142349207540974, 0.015498006468988024, 0.06954548618523404, 0.060645335834124126, 0.09682007381343283, 0.12267773083294742, 0.04373454365122598, 0.026335182665206958, 0.016267327882815152, 0.015864517954469193, 0.07169133197749034, 0.01719592160952743, 0.0172283961364883, 0.030297002595034428, 0.052909507576259784, 0.03375244588823989, 0.05102574381453451, 0.049746021468308754, 0.019801331218332052, 0.03508473826514091, 0.021307859460648615, 0.018350488171563484, 0.041251269285567105, 0.04831671925785486, 0.0047214317328325706, 0.09298768258304335, 0.04759979718073737, 0.03726162438397296, 0.0538082818093244, 0.031180599908111617, 0.03090204219915904, 0.02805771669954993, 0.030291596049210057, 0.08296211351989768, 0.06233420048374683, 0.04344854591181502, 0.05102447474200744, 0.011647229457594221, 0.038062973180785775, 0.02944968331576092, 0.0950385705800727, 0.025503580218355637, 0.006082422960389522, 0.010423094900033902, 0.04799405200174078, 0.360458514187485, 6.237491173669696, 24.41407185047865, 45.685746520757675, 49.7230488806963, 38.29846031963825, 33.464184924960136, 34.69039812684059, 25.728499218821526, 34.0842242538929, 31.626257747411728, 20.611399300396442, 13.283961787819862, 3.310770895332098, 0.37335917819291353, 0.09564106090692803, 1.2072238395921886, 6.156171737238765, 6.675430973991752, 10.781196635216475, 10.533849857747555, 19.899967275559902, 10.705272909253836, 11.874264981597662, 10.336605291813612, 15.738687068223953, 17.583100497722626, 23.26471332460642, 36.18149131536484, 39.703480526804924, 52.52342641353607, 56.84263564646244, 56.68449193239212, 56.29505082964897, 56.02377958595753, 59.09361585974693, 57.71183900535107, 57.846648171544075, 57.60694183409214, 53.54934476315975, 51.27216875553131, 52.77495011687279, 56.07384949922562, 56.62543550133705, 57.420204654335976, 59.082478657364845, 54.522100165486336, 54.92012120783329, 57.077497243881226, 54.448368921875954, 47.60294124484062, 45.21321527659893, 52.019938230514526, 56.184913739562035, 56.220217645168304, 55.4890950769186, 55.53704470396042, 56.13208517432213, 54.442118257284164, 57.519428730010986, 39.94713865220547, 53.304584696888924, 56.33221283555031, 50.15140749514103, 51.14352285861969, 50.155374482274055, 52.36477732658386, 52.22215577960014, 49.3259359896183, 48.052643314003944, 46.052043065428734, 48.42618986964226, 48.129254803061485, 44.69210363924503, 43.65315578877926, 47.066436633467674, 52.84157194197178, 57.089417204260826, 57.371977642178535, 58.20053078234196, 55.750692039728165, 55.39425976574421, 54.72462549805641, 56.95558078587055, 56.78320683538914, 58.103981763124466, 58.179647102952, 58.00790011882782, 56.448566392064095, 52.88565717637539, 43.75674583017826, 34.264805763959885, 29.24556579440832, 18.281206637620926, 15.16945481300354, 19.162719435989857, 14.852521419525146, 15.867296867072582, 10.567881781607866, 13.751608394086361, 12.676022909581661, 7.527914280071855, 13.495503086596727, 2.889482514001429, 4.419712889939547, 0.7078965520486236, 0.5599902605172247, 1.0391744133085012, 5.079611130058765, 16.23864334076643, 33.442153707146645, 59.86831448972225, 64.85327079892159, 54.546023681759834, 42.96159289777279, 37.736531272530556, 42.92669557034969, 47.844353690743446, 42.25544258952141, 19.572413451969624, 3.303945274092257, 0.10663764114724472, 0.04772034793859348, 0.08212428074330091, 0.07915795358712785, 0.04407489628647454, 0.03055158336792374, 0.017420595686417073, 0.015135837475099834, 0.03645728102128487, 0.028189614895381965, 0.021102906102896668, 0.04086492204805836, 0.03627863865403924, 0.03346687117300462, 0.041616060843807645, 0.006531950157295796, 0.01708779440377839, 0.0640902406303212, 0.027527524543984327, 0.04970221620169468, 0.08600184650276788, 0.045006985528743826, 0.021153411107661668, 0.026952770131174475, 0.03721115834196098, 0.0782215413346421, 0.01815108051232528, 0.07776445258059539, 0.1311696888296865, 0.06911267308169045, 0.09286030035582371, 0.16246350336587057, 0.1363223310909234, 0.15756829729070887, 0.14053694321773946, 0.15053573559271172, 0.12954368779901415, 0.1667384966276586, 0.23567880591144785, 0.09418432891834527, 0.09214389778207988, 0.10601743575534783, 0.19852448866004124, 0.19872185541316867, 0.13088840001728386, 0.12354525693808682, 0.167596330284141, 0.23303008085349575, 0.17047213768819347, 0.21772389358375221, 0.20043011609232053, 0.1639836296089925, 0.15402302815346047, 0.15601082617649809, 0.16431645315606147, 0.7258467888459563, 7.394821671769023, 29.89587239921093, 53.533894792199135, 56.42870865762234, 44.332821518182755, 39.16389808058739, 35.01251444220543, 30.058754459023476, 44.552989304065704, 37.14713729918003, 26.793684661388397, 16.43355008214712, 3.6952511267736554, 0.707810225430876, 0.5337976722512394, 2.0773117197677493, 8.227565512061119, 12.704062554985285, 17.577507197856903, 21.25247810035944, 28.17823726683855, 17.787833511829376, 17.444096356630325, 26.386525109410286, 25.49446977674961, 24.803604148328304, 31.28297656774521, 44.54017259180546, 47.76187151670456, 57.57764920592308, 55.91464564204216, 56.34269267320633, 55.213765650987625, 55.51828891038895, 59.646486192941666, 57.46864065527916, 58.60822230577469, 59.109525606036186, 54.98999945819378, 54.83867637813091, 54.279198199510574, 58.066371381282806, 58.487548381090164, 58.614058792591095, 59.89769071340561, 57.33446225523949, 57.39717788994312, 60.677283480763435, 56.43449954688549, 50.62254041433334, 48.02818402647972, 56.302984803915024, 58.5145915299654, 56.42767131328583, 56.24458193778992, 58.05467940866947, 58.44748713076115, 56.86900623142719, 59.10078227519989, 44.117456674575806, 53.65701198577881, 60.4440937936306, 52.715418711304665, 53.58290836215019, 51.81339651346207, 54.12243001163006, 54.360293447971344, 51.65224716067314, 50.4997918009758, 48.00816670060158, 50.50581827759743, 49.451686441898346, 46.788420751690865, 45.810018852353096, 50.39229936897755, 55.58591388165951, 59.299842193722725, 58.995740711688995, 57.89518676698208, 56.795442178845406, 55.389908999204636, 56.28143236041069, 57.28085093200207, 57.38334283232689, 57.567670941352844, 59.33941327035427, 59.45753753185272, 58.069586008787155, 55.632533580064774, 47.072972282767296, 35.82630157470703, 30.13854257762432, 28.86101122945547, 26.783909685909748, 27.769514098763466, 32.78961852192879, 29.01909414678812, 16.92504420876503, 22.45787411928177, 19.016410186886787, 22.061382494866848, 12.40037715062499, 6.835015285760164, 5.808501793071628, 1.774625068064779, 1.0408321931026876, 1.6238755197264254, 5.967827718704939, 17.905047722160816, 36.9172078371048, 62.339154705405235, 68.09035509824753, 57.73214511573315, 49.45019692182541, 47.67617851495743, 49.60370108485222, 58.619777485728264, 48.880896270275116, 25.23230094462633, 4.564959146082401, 0.1677642040885985, 0.33207240456249565, 0.24181969201890752, 0.18409115611575544, 0.15908221917925403, 0.07393205392872915, 0.11537326849065721, 0.15775715903146192, 0.22300387354334816, 0.160469189286232, 0.14276724541559815, 0.14369497454026714, 0.14721702929819003, 0.17193767154822126, 0.21853544691111892, 0.15237311512464657, 0.12411713367328048, 0.1235421399178449, 0.11448827965068631, 0.09327827792731114, 0.21894162433454767, 0.11835755562060513, 0.061967731671757065, 0.06345142959617078, 0.24452277197269723, 0.09244726548786275, 0.10637290964950807, 0.18183958396548405], [0.014945647290005581, 0.04667809800594114, 0.04505733282712754, 0.02547113166656345, 0.06875853505334817, 0.0389936820283765, 0.022547778571606614, 0.014224074730009306, 0.03366317665495444, 0.06421222744393162, 0.031187939748633653, 0.01631479935895186, 0.09930587519193068, 0.060437178253778256, 0.13614817871712148, 0.01829042987083085, 0.07430125013343059, 0.06076741170545574, 0.08069622534094378, 0.06703094142721966, 0.05191939722863026, 0.10455297058797441, 0.07061425305437297, 0.045212033510324545, 0.09163827999145724, 0.06637210724875331, 0.053259496999089606, 0.46049458847846836, 3.848313088528812, 21.07557099312544, 42.04549625515938, 35.8626314252615, 35.53254313766956, 23.344256356358528, 13.30413680523634, 22.892793081700802, 20.607576705515385, 23.34073204547167, 21.23230878263712, 8.104313425719738, 2.7323003858327866, 0.1423195522511378, 0.23287865304155275, 0.528514115139842, 4.591378653421998, 4.547204123809934, 10.824136231094599, 8.636192735284567, 14.771990440785885, 8.358663227409124, 12.984565403312445, 8.913085777312517, 18.661598525941372, 29.72302347421646, 28.59631933271885, 38.06545302271843, 43.46729256212711, 51.00489489734173, 56.883920431137085, 57.176728919148445, 55.78814662992954, 57.61868700385094, 56.888130605220795, 55.924973487854004, 56.688363924622536, 56.33997581899166, 51.579515263438225, 47.405097261071205, 43.30959342420101, 45.01030996441841, 48.97982396185398, 53.90624061226845, 52.59458139538765, 54.745782762765884, 52.088186368346214, 50.378346517682076, 44.49535399675369, 45.97163178026676, 44.7543329000473, 50.86147919297218, 52.80898489058018, 49.70179662108421, 55.142196491360664, 54.01405982673168, 52.70829789340496, 53.89094263315201, 57.52157561480999, 39.63394805788994, 50.75725458562374, 54.625002443790436, 50.59233583509922, 45.424632132053375, 41.5100821852684, 41.38615183532238, 41.29537470638752, 42.29206882417202, 40.56785814464092, 40.18419653177261, 39.10164222121239, 38.96013021469116, 40.773674100637436, 42.544964253902435, 41.25534385442734, 44.46472384035587, 49.09487038850784, 53.664056807756424, 53.6803313344717, 55.37567116320133, 53.07367868721485, 55.922135040163994, 55.943341702222824, 57.90119044482708, 56.66425421833992, 56.073093339800835, 55.85086226463318, 56.71669900417328, 50.41377581655979, 41.9306930154562, 30.710212402045727, 31.458534747362137, 15.235714707523584, 19.430118687450886, 17.577510997653008, 9.812376871705055, 10.95171058550477, 10.455560758709908, 17.601451613008976, 10.790452938526869, 4.840554557740688, 14.186470359563828, 2.8209472540766, 3.322765901684761, 0.630439727101475, 0.28374731016810983, 0.8836793946102262, 3.6409864760935307, 14.598309360444546, 31.882060021162033, 41.83678485453129, 25.592485517263412, 15.397913753986359, 23.53646334260702, 29.579094797372818, 41.91721513867378, 44.16912630200386, 40.81207484006882, 19.055734276771545, 1.9587454944849014, 0.09273069168557413, 0.06984331004787236, 0.039488928305217996, 0.07264621628564782, 0.03982568894571159, 0.07498614853830077, 0.027919667954847682, 0.06720984354615211, 0.02091498317895457, 0.0445648399181664, 0.04529625985014718, 0.0600345668499358, 0.036084930688957684, 0.013097030714561697, 0.017282463450101204, 0.04590096177707892, 0.09394014748977497, 0.1706037056283094, 0.05487846618052572, 0.009122468109126203, 0.054710993135813624, 0.04846249932597857, 0.060409785583033226, 0.06168386389617808, 0.059751730659627356, 0.04560665198368952, 0.057195232293452136, 0.05726293100451585, 0.019715418347914238, 0.05629765291814692, 0.03501080922433175, 0.037325976009014994, 0.08680123602971435, 0.05536564531212207, 0.010962273536279099, 0.051719403272727504, 0.018283266290382016, 0.055600193663849495, 0.028946384736627806, 0.01431077798770275, 0.0578449677414028, 0.06664221189566888, 0.02876875725632999, 0.0428851370816119, 0.024780605926935095, 0.025925999543687794, 0.04218649410177022, 0.007196724764071405, 0.05210190618527122, 0.010226393296761671, 0.03882996054016985, 0.038609884068137035, 0.0842235864547547, 0.04603186549502425, 0.06475000249338336, 0.5583605635911226, 5.01529673114419, 25.22142592817545, 48.23941469192505, 43.16398523747921, 40.87481327354908, 27.659177519381046, 17.16208688914776, 26.113363467156887, 28.248594291508198, 25.635860189795494, 22.235833033919334, 9.458637703210115, 2.856629714369774, 0.3576223226264119, 0.6850611430127174, 0.4528085212223232, 4.567412389442325, 11.355293579399586, 10.978270210325718, 9.56593919545412, 19.76936638355255, 13.909118492156267, 15.296379402279854, 10.30011584982276, 15.705535747110844, 22.539092861115932, 28.399199210107327, 37.67005003988743, 44.8050943762064, 51.2334830313921, 55.728980004787445, 58.44249799847603, 55.244498401880264, 57.206048145890236, 56.58481948077679, 56.942292898893356, 57.423651069402695, 56.936015635728836, 53.42351831495762, 49.97596710920334, 45.73767453432083, 48.6326289921999, 50.60856096446514, 55.25208279490471, 54.26364943385124, 56.33227363228798, 54.55227814614773, 53.36807928979397, 47.305728793144226, 46.782580465078354, 46.22544676065445, 52.969089299440384, 54.415268898010254, 51.391341760754585, 56.257493644952774, 55.326889380812645, 53.42887982726097, 54.681528210639954, 57.44463734328747, 40.794398188591, 51.99554733932018, 56.33363015949726, 52.47211396694183, 47.265656143426895, 43.26132461428642, 44.34061489999294, 44.49657753109932, 44.504720494151115, 41.71511918306351, 42.41221837699413, 41.41760274767876, 41.98155328631401, 42.467049434781075, 43.85544553399086, 43.75065475702286, 47.37032912671566, 51.5232402831316, 56.26292735338211, 55.88731370866299, 57.38141633570194, 52.55084954202175, 56.16759046912193, 54.933340698480606, 57.67249971628189, 55.55672384798527, 57.11389169096947, 55.29183246195316, 56.62342920899391, 51.66338436305523, 42.85911239683628, 34.2052211612463, 32.03742228448391, 19.139358289539814, 19.419150575995445, 19.55527637153864, 12.272838894277811, 14.5922458358109, 11.737226285040379, 12.63010997325182, 14.714434929192066, 10.345880594104528, 13.510950207710266, 6.5259503200650215, 4.248304087668657, 1.173177903983742, 0.4285162762971595, 0.5968972644768655, 4.799464037641883, 13.135727941989899, 32.51799389719963, 49.336966797709465, 36.95998594164848, 24.925807490944862, 29.821899868547916, 34.53942462801933, 45.18684469163418, 50.22893853485584, 46.52266301214695, 22.155047468841076, 2.479111896827817, 0.08133403447573073, 0.042180965101579204, 0.0669576988730114, 0.03054140481253853, 0.056516441763960756, 0.056766864654491656, 0.019275144804851152, 0.07386972094536759, 0.018551291068433784, 0.029421862054732628, 0.012545406261779135, 0.04541465466900263, 0.050603376439539716, 0.03308465027657803, 0.03077089542784961, 0.05292310001095757, 0.059099575810250826, 0.08699722980963998, 0.03917168614862021, 0.03681609086925164, 0.028642944671446458, 0.037275116628734395, 0.02605798679724103, 0.01515168696641922, 0.060140805289847776, 0.010646889531926718, 0.0876109191449359, 0.052576068046619184, 0.12779846816556528, 0.11930252483580261, 0.11276766221271828, 0.10741613921709359, 0.21770235645817593, 0.1562651156564243, 0.10343712929170579, 0.17558117135195062, 0.229061015706975, 0.2795660501578823, 0.1464668070548214, 0.11361900207703002, 0.1856978316209279, 0.22867967054480687, 0.24625346035463735, 0.11627917847363278, 0.21756133355665952, 0.15719615475973114, 0.16149108210811391, 0.17158150003524497, 0.134316157491412, 0.2596892276778817, 0.26773099147249013, 0.14758178003830835, 0.15092451707459986, 0.14455632597673684, 0.1594238297548145, 0.8007646969053894, 6.993687646463513, 29.626434557139874, 53.115271255373955, 51.01936832070351, 49.57515701651573, 32.53054462373257, 22.274482659995556, 34.54602487385273, 31.24339409172535, 34.121830835938454, 28.35675548762083, 12.163050435483456, 3.6294861556962132, 0.5539290513843298, 0.9802432567812502, 1.1648971983231604, 5.89836934581399, 10.505141448229551, 21.545094698667526, 18.58824536204338, 26.72126054763794, 21.718739680945873, 25.676694698631763, 17.75648709386587, 26.221676655113697, 35.50485782325268, 33.61046947538853, 38.79139646887779, 48.538728430867195, 50.847742930054665, 57.67339646816254, 58.97708371281624, 55.710835978388786, 58.60134847462177, 56.45796708762646, 56.8477463722229, 56.75120875239372, 59.8797632753849, 54.96876619756222, 52.40024082362652, 46.588258892297745, 49.57268334925175, 54.518292769789696, 58.73741917312145, 57.27176181972027, 59.927709102630615, 57.525291815400124, 55.36260366439819, 49.89576481282711, 50.339482203125954, 49.7990258038044, 54.35071416199207, 57.60386019945145, 55.66901162266731, 56.67927101254463, 55.967747792601585, 56.10823765397072, 57.30870723724365, 59.99159887433052, 44.88792613148689, 54.23642389476299, 59.87902991473675, 55.34283712506294, 50.17055086791515, 44.564704075455666, 45.86024835705757, 45.71601949632168, 46.51579678058624, 44.00307521224022, 42.485588639974594, 41.962219923734665, 43.64228457212448, 43.57004664838314, 46.2925473600626, 45.26149548590183, 50.007288828492165, 53.37257444858551, 59.34868857264519, 57.58285492658615, 56.84264324605465, 51.54877111315727, 56.248104348778725, 54.43179041147232, 58.93886536359787, 56.454714462161064, 56.16933077573776, 55.285832583904266, 56.84896610677242, 52.005992978811264, 43.059285655617714, 34.8960354924202, 37.02091567218304, 22.264287807047367, 29.778823480010033, 25.666380152106285, 21.194060035049915, 19.52997922897339, 20.39918828755617, 29.546325355768204, 20.811787247657776, 16.55670717358589, 27.743888273835182, 8.90478702262044, 7.284512165933847, 1.213913974352181, 0.5379507306497544, 1.4389316062442958, 5.488352347165346, 18.52884314954281, 36.52839370071888, 49.82694290578365, 38.533044531941414, 29.494163654744625, 33.60343985259533, 40.46349674463272, 52.987525910139084, 58.21952596306801, 50.54260030388832, 27.31967903673649, 4.086400950327516, 0.5367375269997865, 0.17124596022767946, 0.1878606280661188, 0.11443389506894164, 0.18144596368074417, 0.2778550732182339, 0.15904120809864253, 0.15998349816072732, 0.3871316579170525, 0.17764590040314943, 0.10043726448202506, 0.14659784064861014, 0.14480074489256367, 0.13598311023088172, 0.10657659207936376, 0.28364186582621187, 0.1626740358187817, 0.24168076197383925, 0.16606294928351417, 0.17611649731406942, 0.1931276946561411, 0.10880733956582844, 0.17408997402526438, 0.17139110947027802, 0.12264371078344993, 0.14692207012558356, 0.20238442841218784, 0.10590046586003155], [0.016171451679838356, 0.021671491413144395, 0.01860385738837067, 0.04813195417227689, 0.01939351364853792, 0.04444045596756041, 0.06323667432297952, 0.062358023424167186, 0.024036185423028655, 0.035236611365689896, 0.05515080840268638, 0.018942818496725522, 0.02348295514821075, 0.042436531075509265, 0.05372720959712751, 0.033030098711606115, 0.0519159796385793, 0.03665490381536074, 0.015040149592095986, 0.03388122706383001, 0.11606191474129446, 0.03613091044826433, 0.0345937444944866, 0.03824203115073033, 0.06402318758773617, 0.12582304916577414, 0.007002479205766576, 0.13290445902384818, 2.3340235697105527, 20.084757059812546, 31.25575102865696, 43.62607464194298, 40.3273918479681, 29.306729212403297, 22.080322578549385, 21.963032372295856, 26.75412878394127, 34.16664183139801, 17.26692896336317, 10.824256874620914, 1.7041732859797776, 0.06261984570301138, 0.6882197235245258, 0.8254335669334978, 5.7849435321986675, 11.942845601588488, 8.099737521260977, 6.550805261358619, 23.777653500437737, 9.270327407866716, 10.405830927193165, 10.044338274747133, 19.04681045562029, 30.12731797993183, 34.941895231604576, 47.71346591413021, 48.95930126309395, 55.989357233047485, 54.828242138028145, 53.80463406443596, 54.729105457663536, 56.80978260934353, 56.10229477286339, 57.445819079875946, 56.571071818470955, 56.558038517832756, 52.77495011687279, 46.078292056918144, 41.68342128396034, 40.547529235482216, 41.51513211429119, 44.087502881884575, 44.81474205851555, 42.92136825621128, 41.171603947877884, 40.919529274106026, 42.573151141405106, 45.271059572696686, 53.20489704608917, 50.75312040746212, 52.898439690470695, 56.513694897294044, 54.14377726614475, 54.38284903764725, 52.628323584795, 49.432178288698196, 58.293732181191444, 39.92405869066715, 53.40678781270981, 55.03325253725052, 47.023354545235634, 44.2428233474493, 39.73864383995533, 40.25606207549572, 40.054498091340065, 40.02155385911465, 39.493765980005264, 39.31718185544014, 38.35416153073311, 40.6232363730669, 46.195207983255386, 48.39161932468414, 42.71078735589981, 41.39400601387024, 45.30581250786781, 49.77946065366268, 55.0094810128212, 54.79056715965271, 58.025029599666595, 55.4839463531971, 52.348932176828384, 55.01881331205368, 53.76229673624039, 54.542037695646286, 58.45504492521286, 58.77120316028595, 53.4350810945034, 44.5736525952816, 38.06600019335747, 30.096070356667042, 18.769647628068924, 10.729589704424143, 22.080307379364967, 12.158610373735428, 13.950868751853704, 8.65211483091116, 8.78340918570757, 14.960564821958542, 4.484531236812472, 14.684730023145676, 3.7144139735028148, 3.805746822617948, 0.8323184412438422, 0.8751285471953452, 0.1242168783210218, 3.715248266234994, 12.123575303703547, 27.022734470665455, 30.79256158322096, 32.16582499444485, 26.741897240281105, 24.47888497263193, 28.859204426407814, 38.76778833568096, 44.547749385237694, 34.166714027523994, 12.081001438200474, 2.520072986371815, 0.03399854576855432, 0.01738472026772797, 0.030431242266786285, 0.032465216718264855, 0.016279601150017697, 0.060447308569564484, 0.022183159562700894, 0.03953699349949602, 0.07640824449481443, 0.03732289980689529, 0.03583100115065463, 0.02025872981903376, 0.016498851982760243, 0.10511390064493753, 0.014356138053699397, 0.053615761280525476, 0.0575877282244619, 0.0481228554417612, 0.021481696421687957, 0.012489941855164943, 0.09171807570965029, 0.005977398859613459, 0.032259285580948927, 0.022968082776060328, 0.04061998362885788, 0.04327336937421933, 0.06467342027463019, 0.01308395221712999, 0.024908811938075814, 0.06223796619451605, 0.05593818255874794, 0.031224019257933833, 0.014947989693609998, 0.034957151947310194, 0.06198791066708509, 0.05269633678835817, 0.03417636064114049, 0.053061321304994635, 0.020510188005573582, 0.0931455819227267, 0.05509047921805177, 0.05096568551380187, 0.05228260801231954, 0.04697447096987162, 0.03851095578284003, 0.05402137838245835, 0.054902159245102666, 0.045891525369370356, 0.05161319080798421, 0.03551923975464888, 0.03029894516657805, 0.06012413294229191, 0.035344482530490495, 0.01629584119655192, 0.06431122252251953, 0.3191266773501411, 3.8987805554643273, 23.86249914765358, 37.72419713437557, 49.96042974293232, 46.30029894411564, 33.28428737819195, 28.079968839883804, 28.305178955197334, 26.992925070226192, 39.158775955438614, 21.965730227530003, 11.385654900223017, 2.357988408766687, 0.2558801101986319, 0.5709053529426455, 2.316570393741131, 3.9454774372279644, 9.210654459893703, 10.511341765522957, 11.796854585409164, 17.22418885678053, 13.7587159126997, 12.081575207412243, 4.849753864109516, 20.239127576351166, 22.767434008419514, 31.83611288666725, 44.15141545236111, 48.542296439409256, 53.49773973226547, 55.85155002772808, 52.45949104428291, 55.56777745485306, 56.6957925260067, 57.07695387303829, 56.98019586503506, 57.80820943415165, 58.87914776802063, 55.980507507920265, 48.29611524939537, 42.98645496368408, 43.79398003220558, 43.91724541783333, 45.53720869123936, 48.44865046441555, 46.474492996931076, 45.02292148768902, 42.44919419288635, 44.29980508983135, 47.20031104981899, 55.07942385971546, 52.48627960681915, 54.904785230755806, 56.7604536563158, 54.95195209980011, 56.655073910951614, 53.90709936618805, 51.27545937895775, 60.8087944239378, 43.12061816453934, 55.03482565283775, 57.161567732691765, 49.63726848363876, 45.81207454204559, 42.058381363749504, 41.675464510917664, 41.15979038178921, 42.81199112534523, 41.54598645865917, 41.00934125483036, 39.721111580729485, 43.165360763669014, 46.87923587858677, 50.6745558232069, 44.12254840135574, 43.39285835623741, 47.87786029279232, 54.37362693250179, 56.81098334491253, 56.64587460458279, 56.78286485373974, 54.929309114813805, 52.92096488177776, 54.41871151328087, 55.459479466080666, 55.553710609674454, 58.57543386518955, 59.7787456959486, 53.488445430994034, 44.74453702569008, 35.81959493458271, 28.55763740837574, 19.179130755364895, 17.30976216495037, 24.25212074071169, 12.481169365346432, 14.003826510161161, 16.97371769696474, 9.778643231838942, 14.718201477080584, 9.511937443166971, 13.39486263692379, 5.607193345203996, 2.465094686485827, 2.425176165997982, 0.5743682733736932, 0.22440495929913595, 3.2024078350514174, 12.110826037824154, 30.675926841795444, 37.5326494127512, 33.53570468723774, 26.416374407708645, 25.85811786353588, 33.78407076001167, 45.364682748913765, 51.7717469483614, 41.15344472229481, 14.677859041839838, 3.097320911474526, 0.13241539854789153, 0.08733912982279435, 0.08277605709736235, 0.0359789594222093, 0.03558941352821421, 0.025456743278482463, 0.06234177039004862, 0.032648163542035036, 0.02311954398464877, 0.03320398391224444, 0.03277036557847168, 0.02057657125988044, 0.05012355570215732, 0.03302804667328019, 0.056413698839605786, 0.039557484196848236, 0.01950795282027684, 0.004567900859910878, 0.024016906281758565, 0.023525007090938743, 0.08447503350907937, 0.06007668001984712, 0.05034594767494127, 0.0411305181478383, 0.06707751119392924, 0.05125068506458774, 0.1020259725919459, 0.027330549273756333, 0.10010522019001655, 0.10263293064781465, 0.16539111267775297, 0.21388344262959436, 0.12504747515777126, 0.09088536375202239, 0.2007916904403828, 0.1974119053920731, 0.12376636499539018, 0.14760377729544416, 0.22608930798014626, 0.12603588227648288, 0.1561605470487848, 0.23062342952471226, 0.08582691487390548, 0.1707561279181391, 0.14944994385587052, 0.14393256569746882, 0.10534942121012136, 0.10912334604654461, 0.1790732136578299, 0.11522375541971996, 0.1577484462177381, 0.1609155020560138, 0.1328576888772659, 0.155855746997986, 0.13178084744140506, 0.4028483567526564, 5.8985094632953405, 28.731221593916416, 44.61322367191315, 56.42312295734882, 53.86067345738411, 38.280867263674736, 35.38947321474552, 32.899447828531265, 41.21169179677963, 47.672386318445206, 23.91528781503439, 14.93694718927145, 2.8874878585338593, 0.4212317703058943, 1.0396667243912816, 3.4545582672581077, 10.640889164060354, 19.726774469017982, 18.649032600224018, 17.292571887373924, 39.14619103074074, 21.76651831716299, 22.52297032624483, 17.77080662548542, 23.74457247555256, 37.81461328268051, 40.352212116122246, 52.480724304914474, 53.7227750569582, 56.379698887467384, 55.860129967331886, 53.23699772357941, 55.01489572227001, 56.88635230064392, 55.669570192694664, 56.39868266880512, 57.24759131669998, 61.21419467031956, 59.55349758267403, 51.70981787145138, 45.47221697866917, 44.94670517742634, 44.299250319600105, 47.209882736206055, 48.76279100775719, 48.16251441836357, 46.37578949332237, 46.159413903951645, 46.44864298403263, 49.85681690275669, 57.65495605766773, 57.12437152862549, 55.34701690077782, 59.790479466319084, 59.11481112241745, 57.48513177037239, 56.83108426630497, 53.919479101896286, 63.41204613447189, 46.69898495078087, 57.37267680466175, 60.50521731376648, 53.288815543055534, 48.124949634075165, 44.466638937592506, 44.39218573272228, 43.20281155407429, 44.41356718540192, 42.27165251970291, 43.174168691039085, 42.51558803021908, 44.52722288668156, 49.60224576294422, 52.41820625960827, 47.16116175055504, 45.647604167461395, 50.254032388329506, 56.0741800814867, 60.57620890438557, 58.156563341617584, 57.739767506718636, 54.059452190995216, 52.22341351211071, 54.81101766228676, 55.813016295433044, 54.10019360482693, 60.328538194298744, 59.11772556602955, 56.54523320496082, 45.99504232406616, 39.81658145785332, 32.472643330693245, 22.7769410982728, 17.653877399861813, 35.73404632508755, 21.22565533965826, 26.33475288748741, 21.666313894093037, 23.275164663791656, 28.234248161315918, 15.0700549967587, 25.39972946047783, 8.815424367785454, 8.174613453447819, 3.32379849627614, 2.390622482635081, 0.35840617900248617, 4.73668665625155, 13.44078317284584, 31.62262324243784, 42.01192505657673, 47.106235697865486, 37.93046906590462, 37.17457942664623, 40.60977749526501, 49.47712607681751, 56.54742568731308, 47.98351362347603, 19.091079980134964, 4.544731881469488, 0.2327752867131494, 0.17404301092028618, 0.18405590410111472, 0.09167273790808395, 0.14097770472289994, 0.213901536189951, 0.30192128964699805, 0.15287394606275484, 0.13338234275579453, 0.2178821639972739, 0.07498675709939562, 0.08085429537459277, 0.10364670437411405, 0.2070224506314844, 0.12323730275966227, 0.08948370654252358, 0.12116215395508334, 0.18415843922412023, 0.1601706084329635, 0.14444582018768415, 0.2251802958198823, 0.10148093933821656, 0.10856116918148473, 0.07834504212951288, 0.17352738155750558, 0.21876048092963174, 0.1582426720415242, 0.12383054592646658], [0.09520576903014444, 0.05735305370762944, 0.02476364043104695, 0.0531834973662626, 0.03869352411129512, 0.026329111897211988, 0.03254506809753366, 0.05922919561271556, 0.012205048988107592, 0.01609023289347533, 0.037052290499559604, 0.048698194295866415, 0.0333002441766439, 0.05259222460153978, 0.02875062287785113, 0.04045584282721393, 0.017543476787977852, 0.02277885181683814, 0.0338357482542051, 0.050510582004790194, 0.03896660477039404, 0.06967394452658482, 0.03686926946102176, 0.041007147228810936, 0.02948719517007703, 0.020264277372916695, 0.03195997742295731, 0.07278412958839908, 3.183767697773874, 17.50515718013048, 36.48419827222824, 44.347142949700356, 41.41488589346409, 34.23535354435444, 22.920655086636543, 16.400727443397045, 19.27419975399971, 18.2926744222641, 17.327936589717865, 9.194690566509962, 1.688442723825574, 0.1497578460839577, 0.5321419110987335, 1.1669527692720294, 1.5820803749375045, 11.508909836411476, 6.532395724207163, 4.791018515825272, 11.542918011546135, 14.848167803138494, 9.424955360591412, 4.740531099960208, 26.730319261550903, 26.454630754888058, 33.879738226532936, 43.21109510958195, 48.66683855652809, 53.57743285596371, 55.58495633304119, 55.030444487929344, 54.51487675309181, 56.28722704946995, 56.929643377661705, 56.41986273229122, 55.24884536862373, 55.54048731923103, 51.79405935108662, 44.73035238683224, 40.812492817640305, 38.41201342642307, 37.71298013627529, 37.9181045293808, 37.970127537846565, 37.44119971990585, 38.610317185521126, 39.33039754629135, 42.80984804034233, 47.239597141742706, 50.391448214650154, 55.56462362408638, 50.72364538908005, 53.75299483537674, 54.735656306147575, 47.88745477795601, 50.50440475344658, 49.242013692855835, 57.63045497238636, 46.082798615098, 52.506638914346695, 54.19026017189026, 47.38390199840069, 39.59779679775238, 38.73438812792301, 38.937057852745056, 37.7298816293478, 41.40874162316322, 40.624387711286545, 43.204198479652405, 39.94887135922909, 37.633066624403, 39.57309432327747, 39.23601061105728, 40.99867522716522, 42.704608887434006, 42.684139385819435, 48.31547141075134, 52.681725919246674, 52.37052641808987, 53.23145002126694, 53.68156246840954, 50.74119284749031, 58.017688393592834, 53.3311452716589, 54.69690598547459, 53.518494218587875, 52.23588444292545, 45.353997722268105, 46.64551801979542, 33.76106299459934, 31.40977956354618, 24.00012206286192, 29.00352258235216, 24.534616582095623, 9.93848355486989, 15.068831462413073, 12.283764258027077, 5.8546123187989, 8.018951956182718, 9.092932976782322, 10.314843859523535, 7.79354615136981, 3.067075959406793, 2.4542871164157987, 0.20738015096867457, 0.1979926211060956, 2.7946274913847446, 9.577927552163601, 21.540770530700684, 30.281546004116535, 31.977951675653458, 33.571646958589554, 28.3309605717659, 27.95428678393364, 37.81772531569004, 46.42547942698002, 36.61906823515892, 15.210879240185022, 2.7472680201753974, 0.05207281770708505, 0.00593259911511268, 0.03496408731734846, 0.06352584474370815, 0.06625051377341151, 0.028431067075871397, 0.047792859477340244, 0.06167327344883233, 0.01872814114904031, 0.11231548647629097, 0.05014007219870109, 0.023730691464152187, 0.10044632610515691, 0.05468270988785662, 0.005599717587756459, 0.031388746356242336, 0.040800592687446624, 0.025275442167185247, 0.03166628361213952, 0.04416360148752574, 0.03740296269825194, 0.019049389047722798, 0.024154559832822997, 0.01403231861331733, 0.022626288518949877, 0.041979004454333335, 0.03452512923104223, 0.04099044148460962, 0.1023232917941641, 0.07343153469264507, 0.04263838040060364, 0.031106485330383293, 0.09777706582099199, 0.05874952701560687, 0.03149819458485581, 0.0175698471502983, 0.037267346342559904, 0.058125043142354116, 0.045286007079994306, 0.03588084378861822, 0.09273600546293892, 0.04500348630244844, 0.040579224878456444, 0.07300972021766938, 0.007701493259446579, 0.056119734144886024, 0.06108095054514706, 0.09476030973019078, 0.05735333572374657, 0.040858580396161415, 0.04708797874627635, 0.028845719825767446, 0.021689128552679904, 0.07451272511389107, 0.04047077112772968, 0.1532631431473419, 4.146070573478937, 22.068803496658802, 39.92833346128464, 51.294621750712395, 45.63112445175648, 37.90201239287853, 24.740276746451855, 19.949106238782406, 25.413558818399906, 24.962895400822163, 19.234318993985653, 11.721451431512833, 1.6741602402180433, 0.056702553847571835, 0.10009149787947536, 2.172765447758138, 3.8055463833734393, 12.252713274210691, 12.421145886182785, 13.990977499634027, 13.678394872695208, 11.465177033096552, 14.717655256390572, 8.508963212370872, 17.20699667930603, 24.062341824173927, 33.7612833827734, 46.432155668735504, 49.92160342633724, 54.61663529276848, 55.82588240504265, 54.644974172115326, 55.19135445356369, 56.04235678911209, 55.76928824186325, 57.55973316729069, 56.48034028708935, 56.77137427031994, 54.10643666982651, 46.442798897624016, 43.60701106488705, 39.6068175137043, 40.23059204220772, 39.92074906826019, 39.120223224163055, 39.1502720117569, 40.300375297665596, 40.73595352470875, 45.131052285432816, 48.85117046535015, 53.40923108160496, 57.48288609087467, 52.62351684272289, 57.28737138211727, 55.600402504205704, 50.63527353107929, 51.728611662983894, 53.390878066420555, 59.5430975407362, 46.901715472340584, 55.59512838721275, 55.585526302456856, 49.490007385611534, 43.19806940853596, 40.079075172543526, 39.576894119381905, 40.00879794359207, 42.01971843838692, 41.9121690094471, 43.109135180711746, 39.68190908432007, 39.020520374178886, 42.28346228599548, 42.01227083802223, 43.449277728796005, 44.44607064127922, 43.59888710081577, 48.868170753121376, 55.49979530274868, 54.40992258489132, 56.783495619893074, 54.46394808590412, 52.82123543322086, 56.540947034955025, 53.183701783418655, 55.73907986283302, 55.992598459124565, 52.77966946363449, 49.386565536260605, 47.16133654117584, 38.22868466377258, 30.930017307400703, 24.21513732522726, 23.11644148081541, 19.66591313481331, 11.169470250606537, 11.50291945785284, 20.824220180511475, 12.594413738697767, 16.578069627285004, 11.866197064518929, 8.687454834580421, 7.76977795176208, 4.317961949855089, 1.0417712177149951, 0.6248500489164144, 0.5424499267246574, 3.2071882160380483, 11.058246418833733, 24.589320346713066, 32.201976254582405, 38.61989267170429, 38.06214340031147, 34.11048084497452, 32.588776499032974, 43.76379445195198, 52.816322296857834, 43.335280045866966, 17.225438989698887, 3.6172569869086146, 0.055677299096714705, 0.033516049588797614, 0.07918481933302246, 0.02308019345946377, 0.03218372010451276, 0.06419523226213641, 0.04829127843549941, 0.061771118198521435, 0.020979685468773823, 0.04805598051461857, 0.11677529677399434, 0.02710004562686663, 0.027556655695661902, 0.05754674682975747, 0.03023161752935266, 0.03857967494695913, 0.02797858334815828, 0.032135172514244914, 0.007607816596646444, 0.07181130014942028, 0.00818385167804081, 0.032692469758330844, 0.05988359174807556, 0.044286033589742146, 0.040638878708705306, 0.06342938038869761, 0.037489025853574276, 0.031362567096948624, 0.2047562730149366, 0.21573309728410095, 0.11726184136932716, 0.09885856794426218, 0.13913315604440868, 0.17966224142583087, 0.192616117419675, 0.10694635231629945, 0.1079650093743112, 0.07310240704100579, 0.12644093163544312, 0.12794321664841846, 0.16392632096540183, 0.15840447507798672, 0.1450905090314336, 0.23229864978929982, 0.1196364541829098, 0.14833977998932824, 0.13966074882773682, 0.15250529162585735, 0.14250823587644845, 0.17589441704330966, 0.1304534124210477, 0.17718838120345026, 0.11004553132806905, 0.15071318310219795, 0.13733629777561873, 0.35966236784588546, 6.294904667884111, 26.451070345938206, 49.228911995887756, 58.46157677471638, 52.67705596983433, 45.99394038319588, 31.92562848329544, 27.588303722441196, 32.49011479318142, 28.04016027599573, 23.60275838524103, 12.551174908876419, 2.681176266632974, 0.44827586913015693, 1.6897283610887825, 2.048031440936029, 6.745098810642958, 21.77543453872204, 18.35710186511278, 14.749777782708406, 16.09241008758545, 26.57362326979637, 22.16995406895876, 12.022492177784443, 29.62101984769106, 31.059195175766945, 39.27722319960594, 49.40307945013046, 51.79693199694157, 56.284574791789055, 57.25028157234192, 55.599152371287346, 53.75989906489849, 56.84672422707081, 57.545350939035416, 57.71751210093498, 56.43809795379639, 60.41015021502972, 55.71143254637718, 48.0142729729414, 45.34924037754536, 42.19255596399307, 42.96573467552662, 43.363276943564415, 41.692563593387604, 40.963812097907066, 41.51075854897499, 44.32541951537132, 48.437893241643906, 52.083033844828606, 54.31191064417362, 58.44851687550545, 54.288306310772896, 57.46114365756512, 57.154484912753105, 52.96405076980591, 55.717652812600136, 54.695739448070526, 60.43741375207901, 52.09843821823597, 57.53859110176563, 57.52726010978222, 51.46633453667164, 44.347545728087425, 42.29755952954292, 43.39405909180641, 42.045253068208694, 44.22889329493046, 44.89210210740566, 46.30787953734398, 42.76544362306595, 41.247470676898956, 43.77270497381687, 43.41876156628132, 44.600847736001015, 46.81598827242851, 45.78923776745796, 51.91245719790459, 58.81960116326809, 57.16080017387867, 57.408379688858986, 57.38461196422577, 51.714651212096214, 58.51988084614277, 53.378494530916214, 56.64496645331383, 54.79577288031578, 54.864739179611206, 49.072584584355354, 51.6025610268116, 37.832392528653145, 37.60709881782532, 28.38617730885744, 34.97065968811512, 31.54828403145075, 17.946746684610844, 27.460472881793976, 19.761075228452682, 18.442564979195595, 23.03736962378025, 22.364537827670574, 18.98350965231657, 15.505525879561901, 5.65275670029223, 3.487065522931516, 0.6474069447722286, 0.8154292381368577, 3.965296223759651, 12.671304512768984, 27.40764621645212, 39.176296815276146, 43.04422706365585, 44.605624079704285, 42.13690795004368, 39.61675398051739, 51.78496263921261, 60.49678936600685, 50.37826672196388, 23.1965259835124, 4.5062570460140705, 0.259541985578835, 0.16016005509300157, 0.26564775325823575, 0.2268196109798737, 0.10775695569464006, 0.1368417008779943, 0.2080113920965232, 0.1578002778114751, 0.21506458549993113, 0.17898365127621219, 0.20429047144716606, 0.12758072203723714, 0.1729130168678239, 0.10195439244853333, 0.099297793203732, 0.10070592936244793, 0.13528342824429274, 0.1283894997322932, 0.0867572934657801, 0.16999685147311538, 0.1392159055103548, 0.12747236847644672, 0.1624232789617963, 0.17481267743278295, 0.10245842204312794, 0.11273126729065552, 0.14703526248922572, 0.08649300725664943], [0.010727311437221942, 0.035008026170544326, 0.024802951993478928, 0.03280390323197935, 0.030446012860920746, 0.009732166545290966, 0.0479873207223136, 0.016375362320104614, 0.04285606715711765, 0.05710415593057405, 0.026726185024017468, 0.04560493762255646, 0.02800374772050418, 0.014520565509883454, 0.03529587556840852, 0.073408401949564, 0.029362035675148945, 0.04424190177815035, 0.024118502587953117, 0.03875420952681452, 0.029212301815277897, 0.03848246473353356, 0.029334668979572598, 0.09364562618429773, 0.05280307988869026, 0.04273363134416286, 0.02512184171791887, 0.1365401514340192, 1.8892567232251167, 16.687775440514088, 31.428288370370865, 44.116335734725, 46.06342725455761, 30.926620289683342, 24.588630683720112, 28.47297605127096, 24.65802066028118, 16.332397609949112, 16.586311385035515, 8.134251069277525, 1.7036252841353416, 0.054886514772078954, 0.31343867944087833, 3.386259782128036, 5.131247034296393, 5.644007194787264, 8.858318366110325, 20.240286514163017, 13.61667288467288, 6.927616316825151, 7.808584319427609, 6.637344192713499, 20.419110618531704, 21.101574897766113, 36.285522133111954, 43.380915597081184, 47.55920559167862, 53.61560560762882, 55.63159503042698, 55.29484950006008, 56.412293538451195, 54.09847229719162, 57.47435934841633, 57.1205223351717, 56.058600917458534, 53.11266839504242, 51.332456320524216, 44.84157621860504, 40.06527051329613, 38.895776867866516, 44.22897309064865, 46.743461564183235, 47.27974958717823, 41.99922613799572, 46.4391814917326, 48.43889258801937, 52.48421631753445, 54.410348162055016, 56.67194500565529, 53.08038532733917, 57.44179889559746, 52.46706783771515, 52.0267740637064, 47.221236526966095, 47.956618666648865, 50.49416050314903, 56.02385178208351, 44.13204409182072, 49.25093561410904, 52.12510518729687, 44.54695142805576, 39.93311360478401, 41.395605728030205, 45.586024671792984, 47.29767702519894, 48.88593479990959, 51.44590683281422, 50.670896619558334, 48.497823625802994, 47.45253011584282, 44.46888841688633, 40.8156618475914, 39.466814026236534, 38.369106128811836, 37.21573881804943, 43.413939625024796, 51.45011320710182, 55.897637754678726, 51.645202338695526, 51.735979467630386, 52.769151628017426, 51.97396069765091, 55.863105207681656, 54.27273474633694, 57.541809529066086, 54.04080279171467, 51.70766718685627, 42.86541625857353, 36.81408517062664, 30.616131350398064, 20.038612335920334, 22.393237687647343, 26.070725955069065, 11.645868737250566, 7.866170229390264, 26.727192029356956, 6.640329882502556, 12.41794740781188, 7.844540365040302, 7.768750106915832, 5.502757374197245, 4.092598892748356, 1.9010810949839652, 0.571667687036097, 0.35617258166894317, 1.6979555133730173, 6.620313031598926, 17.900389172136784, 25.704549103975296, 31.03892706334591, 22.794000282883644, 16.94779548794031, 22.21917472779751, 38.137557953596115, 42.32834927737713, 37.58153758943081, 14.904339239001274, 1.164417949039489, 0.06873353951959871, 0.04231759448884986, 0.017457369103794917, 0.050368661104585044, 0.016396676801377907, 0.030976481466495898, 0.057681506004882976, 0.06155779155960772, 0.046788525869487785, 0.038581125845666975, 0.026055294656543992, 0.048060808185255155, 0.06480861731688492, 0.03730936674401164, 0.027292512349958997, 0.02132756719220197, 0.0655446645396296, 0.023848050986998715, 0.06316550978226587, 0.04875414109847043, 0.06429689907236025, 0.05942669595242478, 0.07726137293502688, 0.047106495330808684, 0.046915618659113534, 0.02622160995088052, 0.03088455348915886, 0.03314849724119995, 0.022926969650143292, 0.017424783254682552, 0.09133269326412119, 0.015085511513461825, 0.08541664821677841, 0.021722996461903676, 0.05203414068091661, 0.010840245904546464, 0.025160318364214618, 0.0609668082324788, 0.02603304135845974, 0.035465701221255586, 0.03388768374861684, 0.036679216573247686, 0.005683888266503345, 0.014495608011202421, 0.06341381013044156, 0.05135241866810247, 0.02997708314069314, 0.021160823307582177, 0.005289117189022363, 0.05554963485337794, 0.030476637584797572, 0.05004986785934307, 0.024539376390748657, 0.059310212163836695, 0.044208776016603224, 0.054763210646342486, 3.24783724732697, 20.747703686356544, 37.29215271770954, 52.75716707110405, 51.37108504772186, 37.31430172920227, 26.072407364845276, 31.030861996114254, 31.541963070631027, 19.878671318292618, 18.327398858964443, 9.530773982405663, 2.164498516358435, 0.12100274063413963, 0.42584582115523517, 3.0619388725608587, 4.486372238025069, 8.096715733408928, 9.81931434944272, 9.398458432406187, 13.047983050346375, 14.03758104890585, 14.506634529680014, 7.271200530230999, 22.788855358958244, 24.46211837232113, 37.62014351785183, 43.8528236746788, 51.9673490524292, 55.12500621378422, 58.016856238245964, 55.7109347730875, 57.357519418001175, 54.041631147265434, 57.3132935911417, 56.46688900887966, 56.93671099841595, 55.053752437233925, 53.79709526896477, 46.88407301902771, 42.81313866376877, 40.111711621284485, 45.45493930578232, 46.75114095211029, 48.650351241230965, 42.498701736330986, 48.744764775037766, 49.252569526433945, 55.30105076730251, 55.21415323019028, 58.097712099552155, 54.31268960237503, 56.889528930187225, 54.33011546730995, 54.870480671525, 49.25315849483013, 49.86532464623451, 52.376442700624466, 57.11626656353474, 46.51281014084816, 51.87852501869202, 54.32501994073391, 47.298885360360146, 41.37946419417858, 43.03698845207691, 45.60723893344402, 48.29256623983383, 49.3316812813282, 52.925425842404366, 51.547676771879196, 50.34032575786114, 47.84391671419144, 45.727320089936256, 40.564293935894966, 42.05441437661648, 40.384856164455414, 40.177174508571625, 46.28609910607338, 52.77124151587486, 56.459920182824135, 53.8274784386158, 53.64395968616009, 55.10614402592182, 54.0260823816061, 56.4686369150877, 54.26730863749981, 57.97367915511131, 54.17457081377506, 53.66076238453388, 45.408836379647255, 41.01853296160698, 31.908286213874817, 22.393615767359734, 17.010765708982944, 15.049395505338907, 11.004686392843723, 5.521223433315754, 22.77331229299307, 15.531561132520437, 13.65430986508727, 14.134636390954256, 11.633888930082321, 9.174328409135342, 5.314211966469884, 2.49826286919415, 0.7571457093581557, 0.42995930823963135, 2.781113041564822, 8.400234896689653, 19.861064963042736, 28.558973036706448, 32.6513135433197, 28.25814887881279, 24.772109538316727, 27.04714436084032, 45.796043202281, 47.550481259822845, 44.505655243992805, 18.731205090880394, 1.7343721655197442, 0.06617995779379271, 0.15282524633221328, 0.02021346994297346, 0.049663925092318095, 0.027636275153781753, 0.017677876021480188, 0.042077086691278964, 0.033182977422256954, 0.01872199802164687, 0.08798579277936369, 0.021505406184587628, 0.11007954395608976, 0.0026683588066589436, 0.12149741916800849, 0.010145391588594066, 0.03525594060192816, 0.043025213744840585, 0.04240928312356118, 0.03446033602813259, 0.0481439918075921, 0.0833244745444972, 0.024500020299456082, 0.05378565372666344, 0.042221256298944354, 0.04249170233379118, 0.007507550590162282, 0.02346865581785096, 0.03123685841273982, 0.11197452156920917, 0.11431630919105373, 0.12888709490653127, 0.2077109707170166, 0.15589849470416084, 0.06947627349290997, 0.21569394157268107, 0.09942747608874924, 0.17983876867219806, 0.21073584590340033, 0.10472620269865729, 0.0850503463880159, 0.1250015213736333, 0.08948280854383484, 0.10450750662130304, 0.13620428508147597, 0.10521337069803849, 0.1229793693346437, 0.08646275731734931, 0.13355067669181153, 0.06574964572791941, 0.16911740647628903, 0.12986242538318038, 0.11920126620680094, 0.09809028924792074, 0.22281106357695535, 0.1929018145892769, 0.2784550847718492, 4.7734178602695465, 25.38540232926607, 42.95004911720753, 59.245508909225464, 59.038891196250916, 43.44106636941433, 35.02275109291077, 41.90826661884785, 38.20798337459564, 27.035615779459476, 23.15680481493473, 11.845092996954918, 2.588194068521261, 0.23501165967900306, 0.9079811093397439, 6.796053126454353, 8.109215162694454, 10.5303293466568, 16.709766760468483, 27.97050431370735, 26.254423297941685, 16.416941173374653, 20.644444227218628, 12.46985262259841, 27.43138164281845, 24.27175998687744, 41.03510767221451, 48.984543308615685, 53.406046852469444, 58.445857018232346, 59.924502074718475, 57.695279493927956, 58.29477332532406, 53.41016203165054, 57.53529667854309, 57.03903190791607, 58.2184012234211, 56.80572062730789, 56.679111421108246, 49.048566073179245, 43.8686840236187, 42.38382630050182, 49.239836409687996, 51.237100437283516, 53.35200995206833, 45.64810574054718, 51.99155755341053, 52.49212369322777, 58.1600933521986, 58.76983143389225, 60.75841672718525, 55.95432311296463, 59.565862119197845, 58.1378835439682, 56.56200550496578, 52.13452868163586, 52.48611621558666, 55.1282474398613, 58.67900110781193, 48.821144476532936, 52.837528958916664, 56.50474637746811, 50.630147606134415, 43.5591222345829, 46.286034509539604, 49.58285540342331, 51.751345843076706, 52.458943873643875, 56.51946298778057, 55.82648277282715, 54.038150534033775, 51.70882612466812, 49.484049305319786, 43.6731731146574, 44.19734738767147, 42.68168851733208, 42.38372750580311, 47.75326497852802, 54.38017018139362, 58.177857398986816, 56.70656494796276, 54.48943331837654, 54.52655732631683, 54.67579431831837, 59.00614455342293, 55.80073155462742, 58.209688290953636, 54.145760759711266, 53.614389672875404, 47.325176149606705, 45.51251381635666, 37.77875080704689, 26.74940563738346, 31.439471170306206, 34.305178597569466, 24.98455423861742, 20.90415269136429, 38.47744211554527, 20.106176510453224, 25.66797226667404, 19.327412098646164, 20.567006282508373, 12.876859232783318, 10.82534171640873, 5.511083202436566, 1.3299971516244113, 0.920687805628404, 2.793651893734932, 10.039316844195127, 22.16446526348591, 34.02775548398495, 43.420026898384094, 35.53611494600773, 30.055323243141174, 33.9406755566597, 52.89936304092407, 55.57541884481907, 50.355011969804764, 21.775626428425312, 2.7485264651477337, 0.24142093607224524, 0.28409006365109235, 0.12221694618347101, 0.1124432026699651, 0.17469442362198606, 0.11761929679778405, 0.10540474831941538, 0.14163296174956486, 0.1074008658179082, 0.2366289627389051, 0.14249588653910905, 0.20757397025590762, 0.1281314401421696, 0.18135208199964836, 0.17988825507927686, 0.08911887416616082, 0.08650083691463806, 0.14525179256452248, 0.1294711502850987, 0.14008047786774114, 0.13547312119044363, 0.13795572391245514, 0.13615064264740795, 0.18853941117413342, 0.12812403350835666, 0.09407344463397749, 0.08386235349462368, 0.1606020930921659], [0.019457772505120374, 0.04249400670232717, 0.023995788469619583, 0.027080068866780493, 0.03270660396083258, 0.05658019596012309, 0.04263827649992891, 0.03907471342245117, 0.03172837539750617, 0.09112528525292873, 0.024221162020694464, 0.018981358225573786, 0.06534508618642576, 0.03340746225148905, 0.03144481190247461, 0.049534249628777616, 0.057039618768612854, 0.04223736090352759, 0.039201598410727456, 0.05480577652633656, 0.02263207356008934, 0.050124160552513786, 0.04224413300107699, 0.07048315266729333, 0.08067163056693971, 0.03412947175092995, 0.034584660606924444, 0.16730205388739705, 1.9088128488510847, 10.283373948186636, 31.363380253314972, 42.381219640374184, 39.528154134750366, 28.236507140100002, 20.509367175400257, 20.88142231106758, 19.910682700574398, 18.856727555394173, 16.36198092252016, 8.089410625398159, 2.028881893493235, 0.3791423194343224, 0.3285783139290288, 2.1449298039078712, 2.7845803555101156, 11.524963025003672, 10.823133084923029, 6.251418851315975, 10.12283256277442, 9.958016406744719, 18.275280855596066, 9.840654004365206, 20.136840865015984, 26.963786333799362, 35.88872842490673, 43.53603847324848, 50.41713863611221, 50.431957840919495, 56.75734922289848, 55.05728244781494, 55.81027664244175, 55.72343610227108, 57.05905303359032, 55.639927983284, 56.432136073708534, 53.2938426733017, 48.5103515535593, 41.800261214375496, 38.41952182352543, 43.159968852996826, 53.562176674604416, 54.775633960962296, 53.84781114757061, 53.61240617930889, 53.85340824723244, 53.189815655350685, 54.355612099170685, 54.10322964191437, 55.900449603796005, 55.231506898999214, 54.288709089159966, 49.99270141124725, 49.21148993074894, 46.31042160093784, 48.090888261795044, 49.053471609950066, 57.66970306634903, 48.68225432932377, 50.94523049890995, 51.18616037070751, 43.74690815806389, 42.65379801392555, 48.445671424269676, 52.08091355860233, 55.02906136214733, 55.959464237093925, 55.18633112311363, 54.700960367918015, 54.419832453131676, 52.66490422189236, 51.83977849781513, 47.368851006031036, 47.167256623506546, 44.72940243780613, 41.76215685904026, 36.638082414865494, 43.75265344977379, 51.582053527235985, 58.44651818275452, 54.53629620373249, 57.315740659832954, 54.76565569639206, 53.74081268906593, 55.09788706898689, 56.588778868317604, 55.10931685566902, 58.00045631825924, 49.90694001317024, 47.297050058841705, 30.501501001417637, 27.710799649357796, 16.756831035017967, 8.314554244279861, 6.356789097189903, 3.0096420412883162, 23.387148454785347, 15.273949205875397, 13.792041074484587, 12.458711620420218, 3.47828870639205, 6.640393054112792, 2.7348709478974342, 1.3163848570547998, 1.0376056912355125, 0.21129309490788728, 1.8312330055050552, 5.540964799001813, 15.661799143999815, 29.401551224291325, 37.46749810874462, 27.879535295069218, 25.08903343230486, 24.748974479734898, 38.30894395709038, 40.3008920699358, 31.469366066157818, 14.013990014791489, 1.5859891776926816, 0.12304467833018862, 0.05408756682300009, 0.014155194148770534, 0.02159583873435622, 0.06102664759964682, 0.01585789243108593, 0.011200134649698157, 0.03613027962273918, 0.004384449839562876, 0.07208665178040974, 0.005062428181190626, 0.09349201645818539, 0.047964295590645634, 0.04975895339157432, 0.09725214476929978, 0.055108940141508356, 0.07828034169506282, 0.020156224381935317, 0.10737569959019311, 0.034751391503959894, 0.005464019131977693, 0.08253235806478187, 0.06775939647923224, 0.04688664892455563, 0.03227348657674156, 0.03328695231175516, 0.03699516368214972, 0.03184860703186132, 0.03919927177776117, 0.038784819407737814, 0.04210343293379992, 0.035015930043300614, 0.10036568433861248, 0.025125660067715216, 0.01763136562658474, 0.020152055367361754, 0.026200683241768274, 0.06235851324163377, 0.06773404471459799, 0.010835701177711599, 0.015339813980972394, 0.08494082023389637, 0.05806009408843238, 0.026376355162938125, 0.04143523285165429, 0.023105984946596436, 0.02382592014328111, 0.054177934434846975, 0.017984885816986207, 0.01691249170107767, 0.030519322208419908, 0.07434529659803957, 0.07958532674820162, 0.03304243691673037, 0.0313013992854394, 0.24314383190358058, 2.5530165061354637, 14.229116421192884, 35.10970562696457, 48.28210540115833, 45.73916785418987, 31.658533215522766, 25.229705683887005, 27.463643811643124, 25.023868829011917, 20.39022646844387, 18.577307648956776, 8.845055177807808, 2.766408543102443, 0.13358745753066614, 0.32074506394565105, 1.7297911550849676, 5.596514968201518, 9.09446619451046, 8.413766920566559, 14.108540341258049, 12.14060503989458, 12.359493244439363, 17.45234951376915, 11.083998586982489, 18.235069513320923, 25.839052386581898, 39.067048877477646, 47.88989804685116, 51.893830597400665, 55.3126135468483, 57.60451376438141, 57.56179265677929, 57.05285556614399, 54.76162411272526, 57.87591800093651, 56.59240007400513, 56.50684766471386, 55.31731769442558, 50.57547613978386, 43.25908653438091, 39.91746224462986, 45.3396762907505, 55.54418072104454, 55.40790483355522, 55.783681869506836, 55.98931543529034, 55.97189337015152, 53.841925263404846, 54.30832363665104, 55.77508293092251, 56.84093713760376, 55.87056040763855, 58.22033911943436, 51.85661919414997, 51.00657440721989, 48.26303422451019, 50.11860005557537, 51.82916946709156, 58.9635868370533, 50.95528095960617, 53.82845878601074, 54.168639332056046, 46.86698153614998, 43.554323092103004, 49.395878836512566, 53.60681667923927, 55.8123779296875, 56.24056175351143, 56.72658987343311, 55.935916900634766, 57.70311087369919, 55.45347958803177, 53.95146578550339, 49.60454843938351, 47.8826442360878, 45.911686196923256, 42.020531594753265, 39.20658499002457, 46.91992029547691, 55.183306485414505, 59.60284173488617, 58.18239815533161, 57.01239913702011, 56.215011924505234, 55.19656777381897, 56.222448125481606, 56.82400144636631, 55.63875384628773, 56.63091480731964, 50.31989045441151, 45.19230879843235, 33.65537166595459, 25.905432924628258, 15.072094537317753, 7.792425211519003, 7.612496316432953, 4.47680720128119, 11.535659451037645, 14.407112170010805, 17.524340450763702, 13.900732342153788, 10.404009874910116, 9.91919293999672, 3.8995742378756404, 2.2425529779866338, 0.6526255491189659, 0.3723394375992939, 2.0349910156801343, 6.357255522161722, 17.601238824427128, 30.598629489541054, 41.41108989715576, 28.993175737559795, 26.936425901949406, 30.042726919054985, 43.309346437454224, 48.26228566467762, 36.2800732254982, 16.11173205077648, 2.0555897103622556, 0.10894061444560066, 0.03479258070001379, 0.018243292361148633, 0.029989610593474936, 0.04451630717085209, 0.019269964614068158, 0.0473413999134209, 0.031051722253323533, 0.02501514129107818, 0.09963507705833763, 0.04419350632815622, 0.05023798003094271, 0.08473005771520548, 0.012285099819564493, 0.06087094501708634, 0.02858947107597487, 0.04661074810428545, 0.059969090871163644, 0.036026326997671276, 0.020344549920991994, 0.026726723081083037, 0.03646957098681014, 0.012236759102961514, 0.052921556343790144, 0.01830953831813531, 0.07222405300126411, 0.07917140130302869, 0.07192945005954243, 0.1440743455896154, 0.16922108450671658, 0.10620562214171514, 0.15306896762922406, 0.1784667157335207, 0.1862609584350139, 0.13838018785463646, 0.097998470737366, 0.10094936122186482, 0.20630065264413133, 0.14356532134115696, 0.11093434222857468, 0.12310522273764946, 0.1470195289584808, 0.18150039279134944, 0.11607564447331242, 0.15676263661589473, 0.09662867392762564, 0.1495859053102322, 0.14125378365861252, 0.13383744255406782, 0.10675650351913646, 0.18588687147712335, 0.2223465681890957, 0.2675109595293179, 0.2242448483593762, 0.08759963850025088, 0.42821101611480117, 4.3045861925929785, 16.549573056399822, 40.86794704198837, 55.96730701625347, 52.133301347494125, 38.97485062479973, 31.440660506486893, 33.10617573559284, 31.43770806491375, 27.71172869950533, 22.33483102172613, 10.334628447890282, 3.071163115091622, 1.018432395067066, 1.7109263548627496, 5.029681334272027, 8.23963176459074, 21.753768101334572, 21.37496642768383, 18.737028278410435, 23.784194849431515, 21.92990954965353, 29.18654166162014, 15.358732156455517, 25.55911760777235, 31.605467163026333, 41.95291802287102, 50.80072045326233, 55.64452953636646, 55.83588346838951, 60.117254331707954, 59.33976665139198, 57.298975959420204, 54.91269640624523, 56.40923470258713, 55.91226316988468, 58.01647245883942, 56.9279258698225, 52.242127507925034, 46.146517395973206, 42.26505607366562, 47.60295644402504, 57.881154119968414, 59.25517179071903, 58.62309470772743, 58.91965739428997, 59.54237177968025, 56.247367188334465, 56.94626748561859, 57.21110187470913, 57.416492253541946, 57.910112366080284, 60.04699610173702, 54.10856455564499, 53.640809655189514, 51.6653336584568, 53.27827870845795, 54.34340715408325, 60.893343687057495, 53.83465625345707, 55.0208880007267, 56.12607389688492, 49.48657616972923, 47.92221151292324, 52.311150804162025, 55.4546233266592, 58.40103082358837, 59.4153293967247, 59.737878888845444, 58.06320235133171, 59.268406480550766, 57.16244548559189, 56.40214428305626, 51.73284463584423, 52.779536470770836, 48.2965712249279, 45.43857738375664, 41.90480500459671, 48.87955114245415, 56.30684919655323, 62.977011278271675, 59.40170332789421, 61.041239351034164, 57.67038322985172, 56.152372285723686, 58.21474961936474, 58.79827290773392, 53.85610610246658, 58.8430193066597, 50.4783571511507, 50.79311706125736, 37.12681598961353, 33.12550529837608, 22.342373616993427, 16.990279108285904, 11.089027617126703, 12.863108720630407, 34.19434994459152, 25.03282304853201, 25.971650071442127, 20.96937619149685, 13.825671169906855, 16.379796266555786, 9.159913882613182, 1.9404415204189718, 2.6883431570604444, 0.7488605508115143, 2.683463506400585, 8.237493429332972, 20.420558340847492, 39.03813622891903, 49.2364127933979, 39.05743159353733, 38.66924822330475, 35.94853721559048, 50.78644461929798, 54.10806678235531, 44.11079563200474, 20.38340013474226, 3.10700255446136, 0.21297017054166645, 0.13778862194158137, 0.08472104804241098, 0.18685004557482898, 0.08484752484946512, 0.06454859103541821, 0.1582759351003915, 0.0864866396295838, 0.12718710175249726, 0.20539955177810043, 0.13541049876948819, 0.18492994626285508, 0.17770027014194056, 0.05091707113024313, 0.14066392468521371, 0.10299944769940339, 0.13457449909765273, 0.12143959102104418, 0.17163477139547467, 0.16613158310065046, 0.11439845009590499, 0.1668715785490349, 0.17048493231413886, 0.09831003917497583, 0.12832990527385846, 0.14865152654238045, 0.13724385586101562, 0.12574126449180767], [0.05047708888014313, 0.041633653454482555, 0.0687176501378417, 0.0706007014377974, 0.028108156766393222, 0.002895125971917878, 0.03588896288420074, 0.026534777716733515, 0.0142343673905998, 0.07015570969088003, 0.0523479504045099, 0.05049826606409624, 0.04985736588423606, 0.028056963419658132, 0.0320310009556124, 0.039445375368813984, 0.03017279119376326, 0.03900533374689985, 0.10134870346519165, 0.03422907539061271, 0.05285765371809248, 0.04510165388637688, 0.04587235569488257, 0.02868420251616044, 0.05148530392034445, 0.051592321615316905, 0.029298025438038167, 0.0821635032480117, 2.0917917927727103, 8.125597983598709, 28.367351219058037, 46.11198104918003, 40.20454064011574, 34.359948858618736, 24.064177125692368, 25.673290081322193, 26.961620450019836, 21.861260533332825, 12.844788953661919, 8.189321514219046, 3.1651434721425176, 1.96913045598194, 7.076518451794982, 7.596402280032635, 3.2675085542723536, 5.802987813949585, 4.140183264389634, 10.492898505181074, 7.215175861492753, 12.735249381512403, 10.352534987032413, 7.298889644443989, 21.350199356675148, 27.24522963166237, 38.19183424115181, 45.774087980389595, 50.76669327914715, 52.18185894191265, 51.9616037607193, 53.145430237054825, 54.3010014295578, 54.69266161322594, 56.43489472568035, 56.533503234386444, 57.89360985159874, 54.56139765679836, 51.24827183783054, 43.28236408531666, 38.71194653213024, 47.04486899077892, 54.67245049774647, 53.75297963619232, 55.06613977253437, 52.617988139390945, 55.863420590758324, 53.12895052134991, 56.433173418045044, 53.9019126445055, 56.539104133844376, 53.41623030602932, 49.20214623212814, 47.65524163842201, 45.63391350209713, 42.44097523391247, 47.22291223704815, 48.29178728163242, 57.25122772157192, 46.145761236548424, 51.219613775610924, 51.38278841972351, 43.72400298714638, 47.36756667494774, 51.02187238633633, 55.66659115254879, 54.04037721455097, 49.270071387290955, 56.13035626709461, 56.30968004465103, 55.02301208674908, 56.23469866812229, 54.73634406924248, 55.895278081297874, 54.547482803463936, 52.61079512536526, 53.264736235141754, 46.42729572951794, 39.941313564777374, 41.09110526740551, 47.67500817775726, 49.31451380252838, 49.8249252140522, 51.86821237206459, 52.98006311058998, 55.13932004570961, 54.90691311657429, 51.50751292705536, 55.51390014588833, 47.725689858198166, 41.79484650492668, 34.350206181406975, 29.247687980532646, 15.387932639569044, 10.359775498509407, 7.091345256194472, 0.7338425691705197, 5.443859584629536, 12.835362609475851, 12.029794435948133, 11.467834990471601, 12.158484030514956, 8.034137841314077, 3.92329185269773, 2.475544363260269, 0.671847352059558, 0.36306259164121, 0.9658799087628722, 5.842747930437326, 15.601214244961739, 22.982945144176483, 26.825504153966904, 27.188937552273273, 24.337072782218456, 28.80127653479576, 41.10191948711872, 45.46272128820419, 34.71052944660187, 13.844140078872442, 1.8658421421423554, 0.05208986112847924, 0.021246543219604064, 0.06614152938709594, 0.012428425234247698, 0.04130079651076812, 0.038998992095002905, 0.05740448825235944, 0.048129801944014616, 0.04331704476498999, 0.013849386632500682, 0.09674501299741678, 0.07463816291419789, 0.05270359128189739, 0.04562360263662413, 0.031826268386794254, 0.01648344685236225, 0.01856150116509525, 0.06834357060142793, 0.026897947682300583, 0.05766971327830106, 0.0908179470570758, 0.02308994527993491, 0.053380886383820325, 0.035209905181545764, 0.029777215349895414, 0.09780584630789235, 0.021588487761619035, 0.030746206030016765, 0.013055033505224856, 0.02188649716117652, 0.05041360927862115, 0.049823312438093126, 0.04261817543010693, 0.09275198390241712, 0.012709065595117863, 0.05494408316735644, 0.05587065083091147, 0.05659664937411435, 0.041674289750517346, 0.02294816353241913, 0.038620073755737394, 0.034806718613253906, 0.04401527956360951, 0.0417392350937007, 0.08261410563136451, 0.045269720649230294, 0.05336035115760751, 0.010640604468790116, 0.02140100084943697, 0.04305584589019418, 0.03205601875379216, 0.03482356536551379, 0.04441090735781472, 0.014346361185744172, 0.08477394832880236, 0.09539097198285162, 2.74354659486562, 9.869936183094978, 34.05658073723316, 52.136242389678955, 45.9111238270998, 40.23534558713436, 25.883004628121853, 27.79635775834322, 28.086806572973728, 25.60879424214363, 15.353504586964846, 8.732021693140268, 3.7533093988895416, 2.23900705575943, 6.66190417483449, 3.6994992988184094, 2.811350869014859, 7.613725550472736, 7.8619130328297615, 13.784985803067684, 10.782251078635454, 10.953131709247828, 12.084696739912033, 9.888625480234623, 26.008888073265553, 29.145788848400116, 39.98131021857262, 46.131561398506165, 53.82846258580685, 53.54840621352196, 54.53897126019001, 55.09358949959278, 55.9041316062212, 55.17992466688156, 56.40819735825062, 55.78160338103771, 57.735488936305046, 57.01309069991112, 53.79854679107666, 46.5193609893322, 40.90931922197342, 50.17286874353886, 57.080533280968666, 54.66070532798767, 55.68965591490269, 54.56824108958244, 57.63551250100136, 54.0999960154295, 56.25347726047039, 56.093794628977776, 59.30778756737709, 56.48237317800522, 52.98189081251621, 49.83948603272438, 48.838817328214645, 44.307560473680496, 47.94725216925144, 52.06044025719166, 57.84410610795021, 48.72500963509083, 54.19263884425163, 53.84464971721172, 46.35752387344837, 49.741356298327446, 54.088459834456444, 56.29243277013302, 56.46921828389168, 50.74990198016167, 57.596853375434875, 55.69826625287533, 56.321121230721474, 56.648454666137695, 55.93019440770149, 57.29929894208908, 56.622239872813225, 54.61907476186752, 53.81886810064316, 47.75043033063412, 41.37681573629379, 42.88020506501198, 50.558981224894524, 53.213636577129364, 52.36516870558262, 54.205675944685936, 55.559911876916885, 57.2345732152462, 54.61145617067814, 52.40148715674877, 55.31208537518978, 50.00316224992275, 43.682429417967796, 35.052214711904526, 27.89227031171322, 17.221800684928894, 10.966003518551588, 5.528449695557356, 7.58963436819613, 15.012198351323605, 14.739120304584503, 15.244375392794609, 16.438022442162037, 11.952050607651472, 9.03160996735096, 4.153491100296378, 3.8125876430422068, 1.1661923350766301, 0.5724673660006374, 1.071995864622295, 6.441525500267744, 15.258925762027502, 28.052239827811718, 33.65470290184021, 31.40202607959509, 29.13011658936739, 32.977602034807205, 45.97953535616398, 50.684925466775894, 37.85731919109821, 16.943311728537083, 2.428940813988447, 0.051295740850036964, 0.020398242450028192, 0.04219328475301154, 0.06467096376582049, 0.0563760719523998, 0.03557027725037187, 0.08491042186506093, 0.03452163000474684, 0.06152436893898994, 0.01686609448370291, 0.07615076377987862, 0.011118279471702408, 0.04919429775327444, 0.029064180271234363, 0.07141157941077836, 0.004127702923142351, 0.01183275060611777, 0.026531462171988096, 0.03310828768007923, 0.03701355410157703, 0.08658642138470896, 0.07327172803343274, 0.021600365835183766, 0.008928345469030319, 0.029006977383687627, 0.03837209253106266, 0.01604109344043536, 0.016556646733079106, 0.16492778988322243, 0.08753581380005926, 0.14787678373977542, 0.08926379334297962, 0.18479275284335017, 0.17064434563508257, 0.09123280018684454, 0.1386974411434494, 0.1252086102613248, 0.2521107124630362, 0.14914152212440968, 0.10038999709649943, 0.23673065181355923, 0.1355183031409979, 0.11903978971531615, 0.13709173043025658, 0.1730595316621475, 0.12810170970624313, 0.1676843489985913, 0.17720776610076427, 0.11556670928257518, 0.16056927532190457, 0.14595159329473972, 0.15141629381105304, 0.2712083392543718, 0.1787380746100098, 0.16922728886129335, 0.3010390541749075, 3.6987979989498854, 14.07746085897088, 39.554855301976204, 58.16909506917, 53.34310322999954, 46.06135256588459, 34.56008791923523, 38.28339032828808, 41.06634579598904, 31.774917170405388, 19.011666141450405, 11.067867502570152, 4.366515269502997, 3.413583403453231, 10.42370231822133, 12.733804509043694, 11.89649948850274, 14.06137727200985, 12.814021054655313, 20.78660599887371, 15.949117876589298, 24.080894328653812, 18.508094362914562, 11.603938937187195, 28.43870759010315, 31.200667284429073, 44.57062415778637, 48.50301794707775, 55.037151128053665, 56.209122240543365, 55.333698615431786, 56.68870970606804, 56.11589804291725, 55.70989362895489, 56.51835724711418, 56.06935814023018, 59.28810462355614, 59.78470377624035, 57.26671189069748, 48.023540675640106, 42.97846779227257, 53.30966882407665, 57.35378421843052, 55.93179412186146, 56.62983566522598, 56.194337233901024, 58.159831166267395, 55.09176179766655, 58.17551292479038, 58.73022995889187, 61.360794603824615, 59.19919699430466, 54.12974461913109, 53.1174523383379, 50.01018047332764, 46.993830129504204, 51.79945506155491, 54.70518574118614, 60.28300903737545, 51.234261989593506, 55.23789055645466, 56.31863996386528, 49.42164525389671, 52.14186988770962, 56.39999359846115, 58.70585046708584, 58.608887270092964, 53.55203501880169, 58.07074874639511, 57.01420024037361, 57.918996289372444, 57.824274972081184, 59.07337814569473, 59.78795260190964, 59.17290240526199, 56.86539642512798, 58.1028950214386, 50.8438291400671, 44.25531707704067, 44.30261693894863, 51.84349849820137, 53.53307783603668, 54.36615653336048, 55.043701976537704, 58.729891777038574, 58.256858959794044, 55.56710489094257, 52.07781292498112, 56.24325580894947, 51.117775440216064, 45.793991312384605, 37.830857411026955, 35.60899883508682, 22.04022902995348, 15.044936444610357, 12.986526098102331, 5.4349390882998705, 15.455722901970148, 23.12184479087591, 18.44394240528345, 23.511555679142475, 18.739315755665302, 15.226616095751524, 6.785201383754611, 5.207376899197698, 1.6444596089422703, 0.6000545981805772, 1.4868906140327454, 7.953961668536067, 20.60905482620001, 29.807671532034874, 38.63983400166035, 39.58556525409222, 36.261290833353996, 41.95782735943794, 53.26560638844967, 60.13472959399223, 45.06949558854103, 20.31454972922802, 3.5837525222450495, 0.15864294196944684, 0.10606051000650041, 0.1517980100470595, 0.16224949766183272, 0.13614495779620484, 0.1371147666941397, 0.12822745920857415, 0.19815789739368483, 0.15042543760500848, 0.08062938009970821, 0.1683232342475094, 0.11389137769583613, 0.0945253309328109, 0.12435766373528168, 0.07688172729103826, 0.13248159812064841, 0.16989155556075275, 0.1744100177893415, 0.14278391405241564, 0.09758028536452912, 0.11376950962585397, 0.18917415523901582, 0.19346339773619547, 0.12358847961877473, 0.14060563640668988, 0.21232662460533902, 0.0662903967895545, 0.17186767217935994], [0.0463392222445691, 0.021784850760013796, 0.026109360114787705, 0.04945126267557498, 0.010150430771318497, 0.01905500153952744, 0.054883279008208774, 0.003773175035348686, 0.0280175312582287, 0.019345483706274536, 0.023261878632183652, 0.02950665984826628, 0.027704741987690795, 0.035827635510941036, 0.05205964458582457, 0.018135218961106148, 0.04823140196094755, 0.05372909094148781, 0.0730477181787137, 0.0385096347599756, 0.03909252496669069, 0.02678929169633193, 0.034262857952853665, 0.042750244319904596, 0.05853962909895927, 0.023904101690277457, 0.09369106046506204, 0.034191181330243126, 1.0950140794739127, 8.880659267306328, 31.683321185410023, 40.914916321635246, 32.790260687470436, 26.211341209709644, 21.989226266741753, 28.154699429869652, 18.109322860836983, 14.04370442032814, 17.048805467784405, 7.002802407369018, 2.393557825125754, 0.07472281227819622, 1.1168646882288158, 7.586901839822531, 6.695969821885228, 7.009820630773902, 6.369712203741074, 15.963690094649792, 10.14382928609848, 6.2767682410776615, 14.659628570079803, 11.689006872475147, 13.777537252753973, 22.496423050761223, 35.81979252398014, 46.31015941500664, 50.38805119693279, 52.68690884113312, 53.56682762503624, 53.19705426692963, 54.37725953757763, 53.414262011647224, 55.32265640795231, 55.41130185127258, 55.88273875415325, 51.49534597992897, 50.91625705361366, 42.274597361683846, 39.15205031633377, 47.33130142092705, 53.34124892950058, 54.71767947077751, 54.59352873265743, 53.8618665933609, 55.23370698094368, 55.96805937588215, 54.00659702718258, 52.32850447297096, 52.678211107850075, 50.42385667562485, 49.10394810140133, 42.57843665778637, 41.55397742986679, 41.309038773179054, 47.6382527500391, 49.73073206841946, 56.31371922791004, 43.62510569393635, 50.77477164566517, 51.065364852547646, 45.58352440595627, 46.07280895113945, 48.93650248646736, 53.14696915447712, 55.2798593044281, 52.81525835394859, 52.323507741093636, 54.585032388567924, 52.98696354031563, 55.98691776394844, 53.523449152708054, 54.01869177818298, 53.3273720741272, 54.6968299895525, 52.203369587659836, 54.43480744957924, 47.11241416633129, 40.89820481836796, 38.671201318502426, 43.02321419119835, 44.442464634776115, 49.27432715892792, 53.58825847506523, 54.06538367271423, 54.47864189743996, 53.43067713081837, 54.36378926038742, 51.13047815859318, 42.16159142553806, 34.76108953356743, 25.75088571757078, 17.045547142624855, 7.428751476109028, 4.173847083002329, 8.851490132510662, 12.824935968965292, 12.163749597966671, 19.620117992162704, 13.744689915329218, 6.119680870324373, 5.555478595197201, 1.591067723929882, 4.001431334763765, 0.3860751067986712, 0.6305004050955176, 0.9527595690451562, 4.717491511255503, 12.734705060720444, 21.23216439038515, 31.533052548766136, 26.610500290989876, 27.63327620923519, 34.05888341367245, 34.69085790216923, 48.72383929789066, 27.831332981586456, 13.123160116374493, 1.4860037178732455, 0.016139366780407727, 0.05571579058596399, 0.040060074024950154, 0.003028115356755734, 0.00864355835801689, 0.01628204838198144, 0.0707247514219489, 0.014221661822375609, 0.027423839092080016, 0.03111880498181563, 0.023474001136492006, 0.06301754779997282, 0.04678917524870485, 0.0322937063901918, 0.022771244803152513, 0.03187316840921994, 0.049388577172067016, 0.01609408649528632, 0.05511108865903225, 0.014813996785960626, 0.018032579937425908, 0.0333933317597257, 0.02162061347917188, 0.03780273538723122, 0.03823881022981368, 0.02401855199423153, 0.016881063602340873, 0.046773274734732695, 0.040426346167805605, 0.04095093325304333, 0.021715432121709455, 0.12272489431779832, 0.06124974461272359, 0.012736734715872444, 0.03669497978989966, 0.06875500243040733, 0.02354966309212614, 0.029246635422168765, 0.03377517787157558, 0.022525688546011224, 0.014627314176323125, 0.02688112133910181, 0.05701011097698938, 0.005973556853859918, 0.04926124318444636, 0.07956986781209707, 0.022446688781201374, 0.028379478535498492, 0.06073041935451329, 0.003786948368542653, 0.017705997852317523, 0.052665841940324754, 0.017883116961456835, 0.030637553754786495, 0.04343295709986705, 0.0587899555102922, 1.6925630089826882, 11.36399321258068, 36.281904727220535, 46.878966093063354, 39.45081688463688, 29.747611954808235, 25.715635009109974, 33.482705131173134, 28.21887418627739, 18.0012908577919, 17.620961666107178, 8.600115571171045, 2.801933311857283, 0.21889109892072156, 1.9011568534187973, 11.777280885726213, 6.744792927056551, 3.437004159204662, 9.435155913233757, 17.370368912816048, 17.239057458937168, 10.744243618100882, 10.966511741280556, 16.982453428208828, 20.95722444355488, 28.095035031437874, 35.25519981980324, 47.66409896314144, 50.73262430727482, 56.78570710122585, 53.4045497328043, 56.42452508211136, 54.99341927468777, 56.825240179896355, 55.90604670345783, 55.14568850398064, 56.102344170212746, 54.65423047542572, 52.00457185506821, 44.53003853559494, 40.104096829891205, 49.029905274510384, 54.115043208003044, 56.283974424004555, 53.56377258896828, 54.892428293824196, 55.03866724669933, 58.28471526503563, 54.91545505821705, 55.346431732177734, 54.058183059096336, 54.09776173532009, 50.08516184985638, 46.68964885175228, 44.141680374741554, 44.57750178873539, 48.28845106065273, 51.82617902755737, 57.244730070233345, 46.065456345677376, 54.049135744571686, 53.39082106947899, 46.7628975212574, 47.790115401148796, 52.11665444076061, 55.54663918912411, 56.4266187697649, 55.14567710459232, 54.1300980001688, 54.26550753414631, 53.780448362231255, 55.43025903403759, 54.97104987502098, 55.92691518366337, 55.231765285134315, 55.265070497989655, 54.25774835050106, 56.50161154568195, 49.177014380693436, 42.797228917479515, 40.817200765013695, 45.97179897129536, 45.01069374382496, 52.028829753398895, 55.09021908044815, 56.68839432299137, 54.017149060964584, 54.56158384680748, 54.62246038019657, 51.11605413258076, 42.39054054021835, 35.88700711727142, 29.256533905863762, 23.892747424542904, 13.256887290626764, 6.04833067394793, 12.530371975153685, 15.391740035265684, 15.78353701159358, 16.258179992437363, 15.302972998470068, 13.013093322515488, 10.798705145716667, 8.260303605347872, 3.816424487158656, 0.6811776326503605, 1.0289751668460667, 1.7590725026093423, 5.388266667723656, 16.208237372338772, 24.794060960412025, 33.612293377518654, 30.736484192311764, 33.36137004196644, 40.171524211764336, 40.21104969084263, 52.60334372520447, 33.56726959347725, 14.888084661215544, 1.9459446938708425, 0.05129674646013882, 0.08734492599614896, 0.03868288913508877, 0.023001865338301286, 0.060365267854649574, 0.0046328577991516795, 0.06576450352440588, 0.04903454675513785, 0.10983314350596629, 0.02888638209697092, 0.0281086707036593, 0.07164343376643956, 0.03645527351181954, 0.02107402542605996, 0.023791417697793804, 0.05585785620496608, 0.01870738142315531, 0.05010863111237995, 0.03051412531931419, 0.07627683982718736, 0.05531532769964542, 0.09562241815729067, 0.03898528091667686, 0.07539645972428843, 0.08232535081333481, 0.03112769034487428, 0.04715910989034455, 0.0203248292018543, 0.09852201139437966, 0.1320023339940235, 0.1916425532544963, 0.26366203324869275, 0.16731659998185933, 0.07843702391255647, 0.2088755340082571, 0.18978195934323594, 0.20029808802064508, 0.10415586963063106, 0.08052354241954163, 0.13310106878634542, 0.19531835132511333, 0.12150726004620083, 0.20161189720965922, 0.1908758850186132, 0.10064233472803608, 0.1247211082954891, 0.18854144465876743, 0.21957939636195078, 0.17777709726942703, 0.23709829692961648, 0.08408179914113134, 0.16979917301796377, 0.24792825017357245, 0.06712518676067702, 0.16549995605600998, 0.26098172238562256, 1.89854591852054, 14.653727486729622, 42.30130612850189, 54.323070645332336, 44.56013672053814, 37.31108710169792, 31.063355952501297, 39.74982663989067, 31.239983774721622, 24.439526684582233, 22.96470232307911, 10.049312207847834, 3.7256093602627516, 0.21330112387659028, 1.9214627263136208, 13.665450867265463, 14.184321574866772, 16.561964191496372, 16.372232772409916, 27.94689618051052, 25.537090189754963, 15.253233667463064, 23.36995627731085, 19.052027575671673, 19.17521506547928, 25.403046682476997, 38.005689829587936, 49.55932326614857, 53.588604256510735, 57.73832358419895, 56.29757769405842, 57.42636412382126, 56.98172338306904, 55.98640099167824, 57.09466852247715, 55.7454065233469, 58.08573514223099, 55.89175567030907, 54.70337323844433, 47.53283880650997, 43.737385869026184, 51.10061556100845, 57.23640091717243, 57.37398773431778, 53.73734347522259, 55.22530943155289, 56.31061479449272, 60.27866207063198, 59.56057660281658, 57.95157954096794, 57.346260622143745, 55.657669231295586, 52.43437059223652, 47.27660335600376, 46.836210787296295, 46.14032372832298, 51.96586333215237, 55.115297734737396, 59.9932973831892, 49.08134691417217, 55.90744502842426, 55.842305123806, 50.283727794885635, 50.29765784740448, 54.274558648467064, 56.30400314927101, 60.807532891631126, 56.007957234978676, 55.10135628283024, 55.02654209733009, 55.42916089296341, 56.08348958194256, 54.199980050325394, 57.132677882909775, 55.938059985637665, 57.78569184243679, 54.90049906075001, 58.54975484311581, 51.56466566026211, 45.898907482624054, 42.64387294650078, 46.942928060889244, 46.90937586128712, 54.49627295136452, 56.715992242097855, 58.35276581346989, 54.10543352365494, 54.37306836247444, 53.80517743527889, 52.75763064622879, 42.75637350976467, 37.952952459454536, 27.675624936819077, 20.39532959461212, 11.83259641751647, 7.780665792524815, 13.856890294700861, 18.84370945394039, 18.133928440511227, 29.943863824009895, 21.932056434452534, 15.32171169295907, 12.878664135932922, 7.2797448467463255, 8.142115697264671, 1.6217672266066074, 1.4667185652069747, 1.8687101569958031, 6.523997224867344, 17.71300222724676, 30.046437419950962, 41.13421395421028, 38.61401058733463, 40.45276992022991, 48.121605813503265, 46.78752399981022, 61.207153648138046, 39.98293653130531, 18.764641396701336, 2.6139108510687947, 0.15707306214608252, 0.13109094696119428, 0.15913905284833163, 0.12432362142135389, 0.1115681289229542, 0.07731236590188928, 0.2061433915514499, 0.10736932454165071, 0.17438137088902295, 0.16912282415432855, 0.09792884244234301, 0.12600432615727186, 0.1333908032393083, 0.16622788418317214, 0.08660573948873207, 0.0992880339617841, 0.117650823231088, 0.12232753360876814, 0.10027589931269176, 0.11341703400830738, 0.12697786063654348, 0.21349409711547196, 0.15953724476275966, 0.10462535967235453, 0.1779867391451262, 0.12012657593004405, 0.10412308896775357, 0.14487776497844607], [0.046722300321562216, 0.0473489252908621, 0.013147429963282775, 0.04526612494373694, 0.037171709482208826, 0.0359480415500002, 0.01712415036308812, 0.085376015631482, 0.03532973234541714, 0.03533781804435421, 0.08254837361164391, 0.06855753919808194, 0.035608735342975706, 0.032363794816774316, 0.034430609302944504, 0.10528973769396544, 0.009136322150880005, 0.15729897189885378, 0.04941601066093426, 0.04283756541553885, 0.033650007244432345, 0.04909838258754462, 0.032749997335486114, 0.0430494671309134, 0.06548102537635714, 0.013530211181205232, 0.03174738179950509, 0.048980269784806296, 1.0657573118805885, 5.64133926294744, 30.477231703698635, 47.6958804577589, 41.076719239354134, 34.59447607398033, 18.637840300798416, 16.66617549955845, 19.278894402086735, 24.417094588279724, 14.706192221492529, 9.065813831984997, 2.136641498655081, 0.1434431193047203, 0.20390158606460318, 0.43480389984324574, 3.645953997038305, 2.276879148557782, 7.642652448266745, 9.28288858383894, 12.83286614343524, 10.90365931391716, 8.169250041246414, 11.96415675804019, 28.62167727202177, 25.150709822773933, 32.148072347044945, 43.17292995750904, 48.53414207696915, 51.11938275396824, 52.54559442400932, 50.16418240964413, 53.90831530094147, 55.12072764337063, 55.27054600417614, 53.293010517954826, 56.082338243722916, 53.102306351065636, 55.28147801756859, 45.09643994271755, 41.42492115497589, 45.24472698569298, 53.67649354040623, 55.81814602017403, 54.333805069327354, 54.41698640584946, 54.53695356845856, 51.10917270183563, 50.04651792347431, 48.586013093590736, 48.04691702127457, 45.450193360447884, 41.937779635190964, 39.34543713927269, 40.11302635073662, 40.45271672308445, 46.16952136158943, 49.95141662657261, 55.64567707479, 40.920695811510086, 51.00223124027252, 53.045469000935555, 44.274194464087486, 44.08586136996746, 46.691522151231766, 50.53827613592148, 51.02370008826256, 55.34788705408573, 52.770618349313736, 56.70004449784756, 54.4046750664711, 55.36345101892948, 54.6552412211895, 55.96720442175865, 52.50001586973667, 54.717158898711205, 53.9814879745245, 52.50107601284981, 52.4966112524271, 46.416728496551514, 44.19790215790272, 43.05444471538067, 47.003701999783516, 50.7735975086689, 55.78169837594032, 56.590511575341225, 53.183633387088776, 54.52426224946976, 54.12493787705898, 49.91193674504757, 45.09516701102257, 35.33357061445713, 27.612346932291985, 23.655488155782223, 14.480757918208838, 7.221918599680066, 16.444219909608364, 22.018649987876415, 16.85519065707922, 13.491111472249031, 17.01239012181759, 19.003355987370014, 12.327206376940012, 9.363316018134356, 2.2733503254130483, 1.468985618557781, 0.6584457680583, 0.8069837163202465, 4.258426744490862, 11.838941127061844, 23.062577471137047, 35.91866321861744, 26.054164543747902, 22.947958521544933, 22.982654459774494, 38.2557126134634, 40.255328714847565, 32.55708999931812, 12.448905296623707, 2.403706843033433, 0.06389135989593342, 0.046250750820036046, 0.06550412843353115, 0.040246442149509676, 0.013342086022021249, 0.04940675607940648, 0.023644978973607067, 0.019167392383678816, 0.006757333912901231, 0.05191702977754176, 0.03150730815832503, 0.09866114924079739, 0.0924353911250364, 0.010161107493331656, 0.038413396760006435, 0.0530347932362929, 0.03800482962105889, 0.028287914210523013, 0.11050408211303875, 0.09123334937612526, 0.02094747069349978, 0.05443191221274901, 0.004879488778897212, 0.007450552257068921, 0.03812961804214865, 0.05247455708740745, 0.082536135596456, 0.05228572503256146, 0.08061591754085384, 0.022192768519744277, 0.02603251443360932, 0.03715694816492032, 0.011945542210014537, 0.015104253525350941, 0.014573816461052047, 0.013010089041927131, 0.06268410827033222, 0.07058173956465907, 0.0678241859714035, 0.03282112105807755, 0.031193895483738743, 0.05193031422095373, 0.04731183646072168, 0.009044891412486322, 0.04300755063013639, 0.05675215528754052, 0.03599718656914774, 0.016959352760750335, 0.10967213456751779, 0.035420003478066064, 0.015658416123187635, 0.015134516452235403, 0.08386199726373889, 0.07207876275060698, 0.06394837168045342, 0.04343240048910957, 1.359621430747211, 7.618154212832451, 35.61704680323601, 50.720993131399155, 44.41058434545994, 36.76353268325329, 24.304200746119022, 21.917881295084953, 20.07343176752329, 25.81657089293003, 18.380206525325775, 7.931534796953201, 2.2813279973343015, 0.020128653595747892, 0.0684026010276284, 0.900080205174163, 7.633144883438945, 3.1544648576527834, 8.271475955843925, 10.035238713026047, 14.750036168843508, 10.505878608673811, 12.439929228276014, 11.62749482318759, 16.605194471776485, 31.752688363194466, 33.28086756169796, 47.746242955327034, 47.82792717218399, 54.05640095472336, 53.69383580982685, 52.39098072052002, 54.26619149744511, 56.105763986706734, 56.11191965639591, 54.246732741594315, 56.612626388669014, 54.97410871088505, 56.436612233519554, 47.3334901034832, 41.814453452825546, 47.9208017885685, 54.70311865210533, 57.79004640877247, 54.37099747359753, 55.837247595191, 56.49142049252987, 53.915911093354225, 52.09900438785553, 51.116377115249634, 51.46311230957508, 48.0147897452116, 44.84733670949936, 41.6215606033802, 40.82049138844013, 42.99099572002888, 48.788789212703705, 51.28715895116329, 56.682250052690506, 43.82115617394447, 53.12325082719326, 55.16309916973114, 46.822455525398254, 47.114329263567924, 48.64035777747631, 53.458905816078186, 54.470039159059525, 56.7603662610054, 55.299698039889336, 56.79525598883629, 55.93052119016647, 56.255384758114815, 55.09210757911205, 55.77184170484543, 52.44645394384861, 55.762938782572746, 53.83452706038952, 55.35042151808739, 53.384866788983345, 47.984642162919044, 45.43370604515076, 46.060087233781815, 49.10301335155964, 53.53399358689785, 56.99606381356716, 59.113272204995155, 52.7871398627758, 54.059022814035416, 53.26696291565895, 50.02544045448303, 46.72294266521931, 35.565859749913216, 27.307679280638695, 25.383166149258614, 12.364106196910143, 9.266366120427847, 16.290229372680187, 9.951715394854546, 13.78811588510871, 14.320411272346973, 15.471965130418539, 9.324996024370193, 10.987996738404036, 7.2924798633903265, 3.324372977949679, 1.273639288265258, 0.5587131134234369, 1.4147771336138248, 4.478882364928722, 13.487824648618698, 25.806976407766342, 37.34208203852177, 31.602913700044155, 28.24641890823841, 30.38873065263033, 44.63051654398441, 47.203392684459686, 38.02374646067619, 16.212709732353687, 2.9205505969002843, 0.04671531671192497, 0.02925536307884613, 0.04634654353139922, 0.05860160214069765, 0.052624277959694155, 0.0563901467830874, 0.012878746529167984, 0.016453258140245453, 0.014108298764767824, 0.05936098990787286, 0.03251027250371408, 0.061911684679216705, 0.10156074247788638, 0.039934565720614046, 0.06933165117516182, 0.048753669834695756, 0.03362975774507504, 0.005386752281992813, 0.05806387904158328, 0.04473806831811089, 0.020032400752825197, 0.03028368104423862, 0.04010150070826057, 0.0480938189139124, 0.06577311243745498, 0.055259180517168716, 0.04027887771371752, 0.03301529286545701, 0.15155232948018238, 0.10401672436273657, 0.10120896447915584, 0.13161897019017488, 0.08710858906852081, 0.15112403605598956, 0.15887095942161977, 0.15085978695424274, 0.11668342631310225, 0.1470755907939747, 0.12391713229590096, 0.13235271675512195, 0.15176256507402286, 0.07136946995160542, 0.14408623479539528, 0.1982009271159768, 0.20258611446479335, 0.19172865722794086, 0.10803541692439467, 0.08977214965852909, 0.1409458665875718, 0.11056936884415336, 0.13663851568708196, 0.09414577434654348, 0.26844303763937205, 0.2373160727438517, 0.2015688081155531, 0.17537405277835205, 1.9330335804261267, 11.012930050492287, 41.45533852279186, 59.22457203269005, 54.589044973254204, 46.058688908815384, 29.289312846958637, 28.11561092734337, 30.584218762815, 34.345464035868645, 21.74218252301216, 11.316428314894438, 3.161104526370764, 0.6939674494788051, 0.6789013766683638, 0.8749587438069284, 6.844892855733633, 8.275310900062323, 13.241745103150606, 18.879001960158348, 19.17531196027994, 19.317922107875347, 15.08249742910266, 17.029603198170662, 36.415197774767876, 29.88036923110485, 35.95251180231571, 45.78753165900707, 50.99390208721161, 55.75300231575966, 56.815843284130096, 52.88727968931198, 57.988061383366585, 57.94531747698784, 57.64570735394955, 55.28305493295193, 59.0178669244051, 57.512182518839836, 60.17862483859062, 50.262486934661865, 44.53269839286804, 50.01963436603546, 57.66811475157738, 58.395528718829155, 53.830278888344765, 56.792064160108566, 59.12829279899597, 56.45127944648266, 55.39201408624649, 54.66327778995037, 54.10443797707558, 50.4543462395668, 46.70206658542156, 43.82399842143059, 43.482153564691544, 44.70650866627693, 51.18061266839504, 54.1770026832819, 59.581638872623444, 47.342336028814316, 56.17260999977589, 57.833390682935715, 49.53575313091278, 49.36592124402523, 52.77655743062496, 54.616262912750244, 55.693512707948685, 57.45336927473545, 56.75242468714714, 59.67873886227608, 58.556803464889526, 57.634634748101234, 56.267468109726906, 57.75785833597183, 52.40381643176079, 56.05049595236778, 55.89712478220463, 56.142937391996384, 57.21544124186039, 51.72585681080818, 48.333284854888916, 47.22054876387119, 51.87641613185406, 54.37951661646366, 57.554671838879585, 59.63937297463417, 54.1115777939558, 52.981035858392715, 54.406909346580505, 49.449695348739624, 46.847469583153725, 37.411101534962654, 30.778939314186573, 27.480608001351357, 19.183420725166798, 13.607661668211222, 24.18358001857996, 29.774229526519775, 26.39086827635765, 19.36014924198389, 26.11896436661482, 28.99286225438118, 21.13435383886099, 17.15060580521822, 5.494733154773712, 1.729396570008248, 1.3837176002562046, 1.601429411675781, 6.005740659311414, 15.36812525242567, 30.97186256200075, 47.53025874495506, 38.087966814637184, 34.8154304176569, 35.30306585133076, 51.97556421160698, 52.25577637553215, 47.55780726671219, 19.294553361833096, 3.6743930960074067, 0.20487843052251264, 0.11753050624975003, 0.13384011428570375, 0.196168199472595, 0.0820879006641917, 0.1424072147347033, 0.1006663877342362, 0.17821233719587326, 0.0787380983820185, 0.18947999429656193, 0.08842241310048848, 0.17890360322780907, 0.20157311257207766, 0.0860033456410747, 0.17025890381773934, 0.12824264355003834, 0.27868850505910814, 0.14531293069012463, 0.16029555641580373, 0.18989228701684624, 0.11720003531081602, 0.14243347191950306, 0.1398539001820609, 0.11737016524421051, 0.12615720857866108, 0.1256817887770012, 0.17665569728706032, 0.18528699351008981], [0.03777893842197955, 0.011217505543754669, 0.06408301211195067, 0.03910949046257883, 0.06826415337854996, 0.0650002843758557, 0.047603934654034674, 0.03248006338253617, 0.047053146045072936, 0.05152257457666565, 0.02233338509540772, 0.02913050600909628, 0.03527743319864385, 0.05918334943999071, 0.04717716634331737, 0.025464136924711056, 0.08252508501755074, 0.016291028368868865, 0.04342384352639783, 0.05542360704566818, 0.03449258605542127, 0.042961385333910584, 0.010506301714485744, 0.04485026249312796, 0.02672013837582199, 0.03915833120117895, 0.0066143243748229, 0.09841101578786038, 1.2043313635513186, 7.530062589794397, 30.08058238774538, 43.94501052796841, 44.06470790505409, 25.458810590207577, 19.972191900014877, 16.697128638625145, 27.514716871082783, 16.21031206101179, 14.579914547502995, 5.8856946509331465, 1.3657216471619904, 0.17312395008048043, 0.27866353921126574, 2.078788890503347, 2.524120956659317, 2.575815520249307, 5.891499314457178, 12.217122483998537, 16.776073202490807, 8.966135680675507, 10.037818774580956, 12.15661358088255, 10.2621416375041, 29.92788378149271, 25.84141205996275, 42.41525441408157, 44.610958993434906, 54.28468890488148, 54.598118886351585, 55.6126606464386, 52.92438469827175, 51.62253275513649, 53.27675499022007, 53.24017435312271, 55.06544440984726, 52.9201403260231, 52.191525623202324, 48.245817348361015, 43.06869775056839, 49.13936220109463, 53.46174046397209, 55.44979378581047, 55.001949816942215, 53.70900459587574, 46.65086433291435, 48.27591173350811, 46.698031201958656, 45.77308863401413, 42.890510112047195, 40.78587904572487, 38.115123957395554, 37.50304900109768, 38.223790526390076, 40.70809341967106, 45.32923445105553, 48.5394161939621, 55.38673996925354, 44.87904980778694, 48.555561527609825, 51.66491948068142, 45.79898804426193, 43.79793182015419, 43.08257080614567, 48.68005804717541, 47.12774634361267, 50.912898033857346, 49.27429296076298, 49.34837378561497, 49.93602365255356, 52.73048110306263, 53.69973309338093, 53.65755915641785, 53.79699647426605, 51.76756717264652, 51.39493636786938, 55.29707618057728, 52.56964333355427, 53.63535314798355, 50.000301003456116, 49.92177441716194, 49.5404002815485, 52.376818880438805, 58.77552352845669, 51.591461822390556, 51.93679869174957, 54.56961661577225, 53.33451949059963, 51.19231604039669, 46.807746514678, 36.63681708276272, 32.08431176841259, 33.748090490698814, 15.07842119783163, 8.727307096123695, 14.08466337248683, 9.949730951339006, 16.087181568145752, 16.45504552870989, 15.01701744273305, 7.746669016778469, 11.313553769141436, 9.426386933773756, 2.943610134534538, 0.6671486666891724, 0.35450031515210867, 1.2102545332163572, 3.065100065432489, 12.01731400564313, 20.526166073977947, 28.46967212855816, 30.260527431964874, 22.422676607966423, 27.308950312435627, 35.21335646510124, 47.92307786643505, 27.972465008497238, 10.517761521041393, 1.709751624148339, 0.032628262852085754, 0.03673775718198158, 0.07539430749602616, 0.04420754034072161, 0.07221092440886423, 0.013862258256267523, 0.07033493093331344, 0.03919716036762111, 0.0661132535606157, 0.03658303423435427, 0.05045732177677564, 0.02738164799666265, 0.08866565942298621, 0.1068318537727464, 0.043592563379206695, 0.018334044034418184, 0.05982249444059562, 0.018956314452225342, 0.017482680050306953, 0.02080270365695469, 0.08077815102296881, 0.028947785540367477, 0.09414104686584324, 0.032003456144593656, 0.023944611821207218, 0.05204533597861882, 0.04398655102704652, 0.011889066627190914, 0.03933446510927752, 0.03943599833291955, 0.037446289279614575, 0.05823846186103765, 0.03654005275166128, 0.015480594756809296, 0.04861974186496809, 0.012691651099885348, 0.018945223055197857, 0.032904727704590186, 0.038925801491132006, 0.026709379089879803, 0.021048458438599482, 0.028515339799923822, 0.06116587079304736, 0.07479094143491238, 0.015453336600330658, 0.03084277057496365, 0.05688511846528854, 0.07655882625840604, 0.04527506411250215, 0.030396526453841943, 0.07103617143002339, 0.04018215731775854, 0.0375116836221423, 0.07976057750056498, 0.073185312357964, 0.015918904391583055, 1.455464162863791, 9.592647962272167, 35.65482057631016, 50.683055967092514, 52.46472716331482, 32.19243496656418, 23.337806202471256, 18.175819292664528, 35.11005140841007, 23.70343778282404, 15.882955826818943, 8.00568401813507, 1.6806450672447681, 0.3011788451112807, 0.5875776708126068, 2.530238628387451, 4.772751946002245, 5.282445196062326, 8.850885014981031, 12.636009156703949, 12.061621528118849, 12.86537054926157, 10.958778206259012, 15.116047728806734, 15.623642541468143, 30.666089169681072, 27.93095413595438, 42.87588469684124, 47.83645011484623, 53.30822490155697, 55.38385972380638, 56.83356933295727, 53.99636797606945, 53.19595992565155, 55.614260360598564, 55.78762225806713, 55.607116743922234, 54.913505762815475, 54.57582548260689, 48.501159846782684, 45.16944162547588, 50.42535379528999, 54.75365974009037, 55.32972402870655, 55.344064459204674, 55.8014003187418, 49.487290531396866, 50.499924793839455, 49.00432124733925, 48.4972270578146, 45.43502077460289, 43.99940460920334, 40.290522426366806, 39.706406369805336, 40.43363034725189, 43.52012112736702, 47.62593761086464, 51.81403487920761, 57.26978212594986, 48.33914794027805, 50.65516546368599, 53.60468499362469, 48.566109761595726, 45.38891404867172, 44.75867986679077, 49.992617815732956, 50.65476268529892, 53.45126822590828, 52.16745011508465, 53.12391959130764, 52.310216054320335, 54.26100477576256, 54.62860085070133, 54.65151362121105, 54.584234431385994, 52.40672707557678, 51.86656706035137, 55.200097784399986, 54.10780839622021, 55.19383952021599, 51.71403184533119, 51.208012998104095, 53.46865989267826, 54.33900699019432, 59.89688515663147, 52.76387371122837, 53.99916462600231, 53.62010836601257, 54.63237404823303, 51.07811316847801, 47.18182124197483, 38.279442340135574, 32.17359937727451, 26.169324964284897, 17.836677990853786, 13.321555070579052, 15.800826083868742, 14.141781907528639, 13.174476362764835, 13.08826183900237, 12.601477559655905, 11.049914415925741, 8.895423375070095, 8.527140486985445, 4.683155603706837, 1.514604426920414, 0.19913160998839885, 0.7119965320453048, 4.34717383235693, 13.575989417731762, 23.133455067873, 33.95418003201485, 34.23151955008507, 26.36502966284752, 30.80094013363123, 40.32620631158352, 53.94856654107571, 34.51025739312172, 12.676537781953812, 2.9545616218820214, 0.04333112701715436, 0.03329649262013845, 0.0893141480628401, 0.056296138936886564, 0.039947501354618, 0.0466795451939106, 0.05884085570869502, 0.04599402338499203, 0.014109369312791387, 0.03536437579896301, 0.03383826042409055, 0.06472609791671857, 0.0754362833686173, 0.046633624806418084, 0.038514499537996016, 0.09339146286947653, 0.05701640067854896, 0.016426822840003297, 0.020902114338241518, 0.09970335464458913, 0.05880678741959855, 0.012964141751581337, 0.03702740999870002, 0.04765413723362144, 0.025114420241152402, 0.055822637586970814, 0.05998681706842035, 0.08310491757583804, 0.1723320785094984, 0.11634484370006248, 0.19505079224472865, 0.24074828310403973, 0.19403117039473727, 0.1319365797098726, 0.16500905505381525, 0.13633879192639142, 0.130598442920018, 0.14162803388899192, 0.12356315754004754, 0.10397737569292076, 0.16303627809975296, 0.16902972914977, 0.13054944633040577, 0.1749689143616706, 0.1645196828758344, 0.09679691138444468, 0.1956278714351356, 0.1952276163501665, 0.11845761197037064, 0.13767162978183478, 0.1986856386065483, 0.14783624763367698, 0.12629472854314372, 0.18981157103553414, 0.10254522363538854, 0.17075309995561838, 2.271716888062656, 12.461176738142967, 42.066596522927284, 56.499065682291985, 58.304880782961845, 37.873107343912125, 30.50196647644043, 26.19401603937149, 41.833463832736015, 24.591512829065323, 20.986224487423897, 9.086747858673334, 2.114754910580814, 0.6008512491825968, 0.5069373291917145, 3.6495129810646176, 5.737349186092615, 4.7784853633493185, 8.533364553004503, 17.78801590204239, 23.3549926802516, 16.62129420787096, 19.654772132635117, 20.416840240359306, 13.354860283434391, 34.16150450706482, 30.452973805367947, 43.197184056043625, 47.36285112798214, 54.83339846134186, 56.66907615959644, 60.29475800693035, 57.50158488750458, 56.811443120241165, 57.65230379998684, 57.50783555209637, 56.67393609881401, 56.128498166799545, 56.38669811189175, 53.56349520385265, 48.03623579442501, 53.48204277455807, 58.5410875082016, 56.164873614907265, 56.53969310224056, 58.91947500407696, 50.272134616971016, 53.33882845938206, 51.967637836933136, 50.450831428170204, 47.70406521856785, 45.538561418652534, 42.64181725680828, 41.150062903761864, 42.74554029107094, 45.07878229022026, 50.32495558261871, 54.13440316915512, 60.10965473949909, 51.733988374471664, 54.791034534573555, 54.85481031239033, 51.3928996771574, 48.23690302670002, 47.880497351288795, 52.63688072562218, 52.58906029164791, 56.79958015680313, 54.579260498285294, 54.11258853971958, 54.61847819387913, 56.51407867670059, 57.93753929436207, 56.745953634381294, 54.793572798371315, 52.2311232984066, 51.51066675782204, 56.456447169184685, 56.24922148883343, 59.0410190820694, 54.82662342488766, 53.899617567658424, 56.54267594218254, 56.23242259025574, 60.45365788042545, 54.68647174537182, 53.3386954665184, 54.23716105520725, 53.506308272480965, 51.814734041690826, 47.2942990064621, 38.52440379559994, 38.322224244475365, 35.90295106172562, 20.466866455972195, 13.47353171557188, 21.413234174251556, 22.381211332976818, 27.253936864435673, 23.646788522601128, 29.0014972910285, 12.354089934378862, 22.262748889625072, 16.753242127597332, 5.03850351087749, 2.9481295170262456, 0.8984689135104418, 2.4107359908521175, 4.441132340580225, 16.7008638381958, 27.856459133327007, 40.72640083730221, 43.74106027185917, 35.105062276124954, 38.24717827141285, 46.20598800480366, 61.76275223493576, 41.669248044490814, 16.6030190885067, 3.7093877932056785, 0.17228793556569144, 0.13764403673121706, 0.21944729407550767, 0.14903423725627363, 0.2265121985692531, 0.12220988093758933, 0.11016775562893599, 0.1189150866412092, 0.15349611814599484, 0.09866572087048553, 0.09424491785466671, 0.12972058611921966, 0.15433505672262982, 0.21555434359470382, 0.19876837322954088, 0.18963179318234324, 0.3147577727213502, 0.13276722107548267, 0.10274974469211884, 0.17086154257413, 0.20975316816475242, 0.14069301687413827, 0.227781968715135, 0.18232906004413962, 0.22245900356210768, 0.08825257260468788, 0.12751976202707738, 0.1998781066504307], [0.013354367638385156, 0.03389238154341001, 0.0061246372479217825, 0.07452985388226807, 0.06690174093819223, 0.011416224861022783, 0.07804113265592605, 0.11295801567030139, 0.039965090254554525, 0.04212261374050286, 0.06140342113212682, 0.056615522189531475, 0.02191103070799727, 0.061773311244905926, 0.011527338283485733, 0.00540668265784916, 0.05001595171052031, 0.057134294547722675, 0.0027049710388382664, 0.04368930232885759, 0.05029642787121702, 0.02705914401303744, 0.039745214162394404, 0.05748803181631956, 0.01702754685538821, 0.017397878546034917, 0.04316503065638244, 0.0375444605742814, 0.8430143923033029, 6.20575575158, 24.794053360819817, 46.1509745568037, 39.607558473944664, 27.427108772099018, 19.455678015947342, 13.56680816039443, 13.560108169913292, 14.895162731409073, 14.677744098007679, 6.440378436818719, 2.06726529635489, 0.22810337803093717, 0.5798121343832463, 1.7290316708385944, 4.777847472578287, 3.55109422467649, 14.61870001628995, 12.048250995576382, 12.062896359711885, 12.4261530674994, 8.67279902100563, 6.406355062499642, 10.63737815245986, 27.901847697794437, 25.06774317473173, 40.8389849960804, 47.404291704297066, 52.26685658097267, 53.19794721901417, 54.99929375946522, 53.41463819146156, 53.04888501763344, 54.05273795127869, 53.60420621931553, 54.03414934873581, 52.7823369204998, 50.40440931916237, 50.23048125207424, 49.14121650159359, 52.55838833749294, 56.88259810209274, 53.35383005440235, 54.23121817409992, 48.12526501715183, 45.85102245211601, 45.583076030015945, 43.13475340604782, 39.973334446549416, 39.25513118505478, 38.34026947617531, 37.73155353963375, 38.17016780376434, 40.66550150513649, 42.06443823873997, 48.614971339702606, 48.46993312239647, 56.722862273454666, 45.57407811284065, 48.11321586370468, 54.439348205924034, 46.552620604634285, 45.116799250245094, 41.98448292911053, 44.84006009995937, 45.602044612169266, 48.47701974213123, 49.101406037807465, 48.06386411190033, 50.004184395074844, 49.692141339182854, 48.34767088294029, 52.05319784581661, 50.140745267271996, 54.9368517100811, 50.9915804117918, 52.73830868303776, 55.24314567446709, 56.7396991699934, 54.092430621385574, 53.36483046412468, 54.413452595472336, 57.68603838980198, 53.106824308633804, 53.71998220682144, 54.92145873606205, 53.10319170355797, 52.13159903883934, 51.42610229551792, 49.251129403710365, 40.38430519402027, 27.582309544086456, 23.43415953218937, 19.65783666819334, 17.661237604916096, 19.398515783250332, 8.668363709002733, 6.912637520581484, 10.829775128513575, 12.21748061478138, 9.588353242725134, 5.4459114745259285, 3.5225710552185774, 4.763116138055921, 1.766216594260186, 0.17659828474279493, 0.5188992654439062, 4.267205223441124, 10.72102116420865, 25.560126453638077, 33.83032187819481, 34.18659456074238, 24.658436737954617, 30.59543576091528, 45.06009869277477, 41.34371191263199, 30.301964208483696, 12.595099601894617, 1.9691305747255683, 0.1288027424016036, 0.07193935773102567, 0.02267732415930368, 0.08941295018303208, 0.134629150852561, 0.02271764875331428, 0.028900286233692896, 0.018759827144094743, 0.01783504063496366, 0.039770888761268, 0.04412631598825101, 0.015001611718616914, 0.040297657760675065, 0.022941617789911106, 0.052007961421622895, 0.08535974775440991, 0.028414402149792295, 0.05263101666059811, 0.040150905479094945, 0.010553695265116403, 0.0697366931126453, 0.02583342960861046, 0.0679505143489223, 0.0068562473552447045, 0.036401801771717146, 0.004252722801538766, 0.009068689305422595, 0.052930692181689665, 0.0281647974770749, 0.03393085818970576, 0.10363880792283453, 0.034720165640464984, 0.04893499135505408, 0.023607945804542396, 0.031714300566818565, 0.07501749685616232, 0.03495887001918163, 0.02014367280935403, 0.01950034395122202, 0.05714647690183483, 0.07706835516728461, 0.09178419364616275, 0.013013668976782355, 0.06790205952711403, 0.05741922359447926, 0.08118212426779792, 0.0476928773423424, 0.0329414417501539, 0.03848860229481943, 0.06670237038633786, 0.029716969656874426, 0.05844525760039687, 0.09338177042081952, 0.009943534842022927, 0.03393859136849642, 0.04368639310996514, 1.1050323606468737, 7.488251058384776, 29.713742472231388, 51.33074641227722, 43.924890607595444, 32.18433000147343, 23.758612722158432, 19.935786053538322, 23.500253185629845, 20.817790925502777, 18.81571065634489, 7.523578237742186, 1.8440691917203367, 0.4534091561799869, 0.12108579438063316, 2.6369019923731685, 6.194653697311878, 6.996195036917925, 12.75549279525876, 10.895228516310453, 10.060754343867302, 12.455126512795687, 12.827701270580292, 9.957633577287197, 18.043379299342632, 27.015431262552738, 29.971919618546963, 37.99129240214825, 48.76454271376133, 52.37048082053661, 55.11262267827988, 54.98394638299942, 55.65038502216339, 53.410146832466125, 56.12664386630058, 54.676254093647, 57.04856559634209, 53.767354264855385, 52.515222653746605, 51.71270951628685, 50.65674997866154, 53.654093742370605, 57.841795831918716, 53.78455214202404, 56.082672625780106, 51.33567474782467, 48.75786267220974, 47.46559001505375, 46.05665221810341, 41.7221450060606, 41.57686360180378, 40.21209463477135, 39.97979409992695, 39.123232662677765, 42.525832280516624, 43.94472174346447, 50.27854107320309, 52.170337960124016, 58.02403785288334, 46.926892921328545, 49.91305008530617, 55.68112537264824, 48.69709253311157, 46.47681087255478, 43.02022375166416, 46.94774240255356, 49.0875443816185, 51.17040641605854, 50.79777181148529, 51.7652340978384, 50.852553471922874, 52.228923216462135, 50.49530044198036, 54.12353195250034, 54.36924196779728, 55.478026270866394, 51.307252272963524, 52.94673129916191, 55.34603275358677, 57.458757385611534, 56.33785933256149, 55.55013120174408, 55.308616161346436, 57.741902992129326, 55.0811717659235, 54.96552117168903, 54.28422152996063, 54.91741195321083, 53.308050110936165, 53.029844239354134, 49.23678517341614, 40.93657895922661, 30.801280215382576, 22.822521552443504, 18.72688852250576, 11.136133689433336, 10.185916777700186, 11.340315733104944, 13.034167941659689, 12.526271995157003, 6.856059981510043, 15.343266986310482, 5.432329578325152, 7.448265329003334, 6.3716330006718636, 1.3094402546994388, 0.3511366347083822, 0.6547479727305472, 4.162424895912409, 11.838832832872868, 26.891954988241196, 35.369873866438866, 38.54477450251579, 30.11989887803793, 37.56449170410633, 50.816178023815155, 50.094285160303116, 35.069784969091415, 15.95733493566513, 2.4713577004149556, 0.10506668520974927, 0.020371847967908252, 0.05411153077147901, 0.08863125345669687, 0.06476180264144205, 0.026464921211299952, 0.028107182697567623, 0.013423612799670082, 0.021701869372918736, 0.055944947234820575, 0.03227187611628324, 0.038143819037941284, 0.06657138132140972, 0.027374139317544177, 0.08662221516715363, 0.0510632148507284, 0.05052554370195139, 0.04861958230321761, 0.03656168264569715, 0.004738674142572563, 0.026821512037713546, 0.04968590750650037, 0.07998308079550043, 0.02236939595604781, 0.03261933110479731, 0.024428393771813717, 0.08822920237435028, 0.030507145420415327, 0.0998431901098229, 0.15318772610044107, 0.13538771483581513, 0.17098907323088497, 0.17726608406519517, 0.107298924413044, 0.17193933395901695, 0.21215567830950022, 0.1357250357978046, 0.16137725149746984, 0.15215808525681496, 0.13256065169116482, 0.22714637860190123, 0.2238779453909956, 0.15695311623858288, 0.1498492044629529, 0.22735275502782315, 0.13095134898321703, 0.0893566879676655, 0.14632946520578116, 0.19134656991809607, 0.12255979614565149, 0.12548146827612072, 0.173727672372479, 0.1407166023273021, 0.13257878978038207, 0.11441368638770655, 0.1025926839793101, 1.6049768775701523, 9.87720899283886, 36.42787769436836, 60.870001539587975, 52.98015810549259, 39.71118651330471, 31.59552689641714, 24.813200533390045, 24.898255169391632, 24.198420122265816, 20.363038927316666, 8.88221338391304, 2.7207551803439856, 0.7816500007174909, 1.1970080877654254, 3.3347575832158327, 8.78043869510293, 9.501806236803532, 23.028953075408936, 21.817769967019558, 20.095907561481, 22.472913712263107, 17.724118530750275, 12.113718632608652, 16.72396469861269, 33.1732003390789, 30.080905370414257, 40.71071907877922, 47.940043956041336, 52.964312955737114, 54.13339242339134, 56.93209804594517, 55.4944071918726, 56.17844268679619, 57.090857326984406, 57.75682859122753, 57.54623629152775, 56.77754133939743, 53.599631264805794, 54.909698367118835, 53.834557458758354, 56.38869680464268, 58.59403386712074, 53.825494945049286, 56.66119918227196, 52.58541248738766, 51.13515950739384, 49.75204512476921, 48.50402869284153, 44.67598870396614, 43.183481991291046, 42.07212522625923, 42.78337866067886, 40.86398385465145, 45.00603899359703, 46.45792968571186, 52.11725100874901, 55.17937749624252, 59.48889344930649, 50.846971571445465, 52.514477893710136, 59.5292092859745, 52.22124382853508, 48.721483424305916, 45.912989526987076, 49.23256739974022, 51.77428901195526, 53.355874344706535, 54.165002927184105, 54.47302579879761, 54.166443049907684, 54.46555159986019, 53.07322271168232, 57.28970065712929, 56.746519804000854, 57.43285417556763, 52.37091779708862, 53.03686626255512, 57.654511481523514, 58.91525723040104, 57.46678255498409, 57.65716753900051, 58.2729434967041, 58.56560759246349, 55.85663415491581, 55.97215175628662, 53.99344973266125, 55.77774278819561, 51.932770907878876, 52.96573027968407, 52.57718972861767, 43.61234597861767, 32.496456652879715, 29.308216832578182, 22.294995859265327, 25.64284611493349, 28.598882295191288, 15.886328145861626, 17.207215167582035, 23.96936271339655, 21.479217633605003, 20.148135758936405, 13.862513992935419, 9.992163274437189, 9.182243384420872, 4.05996766872704, 0.7844374480191618, 0.9700349264312536, 6.074149813503027, 14.069164954125881, 34.56015631556511, 46.3030119985342, 45.64535088837147, 36.51339590549469, 44.10928711295128, 56.862774565815926, 54.75305177271366, 44.506460800766945, 19.269856587052345, 3.65480063483119, 0.3594214073382318, 0.1420760981272906, 0.19929651520214975, 0.23640256316866726, 0.1583703511278145, 0.0895906203368213, 0.10604323280858807, 0.13303840183652937, 0.12608654127689078, 0.1493919821223244, 0.2570451039355248, 0.08246439960203134, 0.2197216363856569, 0.09389362225192599, 0.12809596548322588, 0.1753410420496948, 0.1691330361063592, 0.1819110379437916, 0.15985957434168085, 0.07688246201723814, 0.10834418746526353, 0.11285895379842259, 0.18287854618392885, 0.0677754713979084, 0.12429909344064072, 0.09569507441483438, 0.19911906769266352, 0.15432016924023628], [0.0381755310081644, 0.015741028291813564, 0.015804643335286528, 0.027975705670542084, 0.06140266785223503, 0.055083840707084164, 0.02188487556850305, 0.06813862652052194, 0.015837980608921498, 0.045023383281659335, 0.029247928614495322, 0.061359493411146104, 0.06359970328048803, 0.04840748762944713, 0.01802898979804013, 0.11926192193641327, 0.030137808207655326, 0.03128096053842455, 0.03490726106974762, 0.017179789174406324, 0.03643358053523116, 0.022443315720011014, 0.055312715339823626, 0.02367100980336545, 0.018917325724032708, 0.022682897688355297, 0.026220660001854412, 0.022844568993605208, 0.3531985584413633, 7.041837712749839, 27.33978185802698, 44.25321198999882, 44.360134452581406, 31.774322502315044, 22.7461988478899, 19.949930794537067, 21.857377141714096, 19.38405755907297, 12.849714439362288, 6.889225076884031, 1.5598768601194024, 0.66403514938429, 0.7270677108317614, 4.7047279961407185, 7.682320419698954, 7.765790540724993, 11.16595258936286, 8.49414685741067, 7.726052273064852, 10.56513262912631, 8.84463720023632, 11.93047346547246, 20.0586923584342, 20.42933776974678, 26.6530542075634, 33.79236951470375, 44.006571024656296, 49.49928268790245, 55.20119212567806, 51.38422094285488, 55.896152034401894, 52.84828998148441, 53.03717024624348, 52.76927322149277, 51.4830232411623, 53.5956946760416, 51.733148619532585, 51.11725486814976, 52.83940985798836, 52.31340408325195, 55.169106647372246, 55.11482276022434, 53.57450321316719, 47.32061639428139, 46.2794304639101, 41.48229047656059, 39.717836156487465, 38.4266160428524, 39.50070060789585, 38.68374824523926, 36.34159192442894, 37.209225967526436, 37.246843948960304, 41.40585757791996, 48.76548506319523, 48.03402051329613, 56.83019131422043, 46.49661920964718, 46.448981165885925, 55.20369999110699, 46.89157761633396, 47.063829973340034, 45.157213881611824, 44.2796965688467, 42.64690138399601, 46.02621205151081, 45.280414670705795, 45.29872968792915, 45.75832262635231, 46.65635883808136, 48.790324330329895, 48.89752417802811, 49.80563364923, 52.98622637987137, 54.064270332455635, 52.2830893099308, 51.15461066365242, 50.95970772206783, 54.07501995563507, 54.31651599705219, 55.35208582878113, 53.30472148954868, 52.336145862936974, 52.32159644365311, 53.36199201643467, 54.4151359051466, 53.307818323373795, 52.33785957098007, 46.50571212172508, 40.4361230134964, 32.88701109588146, 26.314099095761776, 25.825091935694218, 12.964523378759623, 11.879386156797409, 14.319437574595213, 12.663186248391867, 8.570356518030167, 3.509781416505575, 13.190474454313517, 3.7120293639600277, 7.834647120907903, 4.856804860755801, 0.24864474922651425, 0.44814427150413394, 0.42387256922665983, 3.502744431607425, 11.414018478244543, 23.079853244125843, 28.657841831445694, 32.52649404108524, 28.89935117214918, 28.98794911801815, 34.27344650030136, 40.498975440859795, 33.60193893313408, 12.518027387559414, 2.3220195388421416, 0.09749464152264409, 0.033008958635036834, 0.036969585562474094, 0.08592720128945075, 0.06674091753666289, 0.016666443771100603, 0.034603229141794145, 0.03986717129009776, 0.09267143119359389, 0.01712956618575845, 0.01680763736658264, 0.04566045026876964, 0.061541167451650836, 0.070026909961598, 0.010450769586896058, 0.05257314027403481, 0.11298171244561672, 0.05494953424204141, 0.0332604947470827, 0.051313266667420976, 0.018532575959397946, 0.04779224349476863, 0.022235785254451912, 0.035695559199666604, 0.054949541663518175, 0.038202619398362, 0.04080293787410483, 0.02245518822746817, 0.04556935164146125, 0.028658446281042416, 0.02582609904493438, 0.05526051638298668, 0.053484556992771104, 0.018642096547409892, 0.03913025575457141, 0.0358811369369505, 0.017262299297726713, 0.06633059150772169, 0.03923819000192452, 0.030347205174621195, 0.07464903537766077, 0.026746803741843905, 0.017929044770426117, 0.005486170384756406, 0.08181132448953576, 0.024083122552838176, 0.05634453067614231, 0.022915891240700148, 0.022918490612937603, 0.03608810337027535, 0.05211835217778571, 0.04581813067488838, 0.0728345436800737, 0.1291674337699078, 0.03897634174791165, 0.07235855984617956, 0.5705994693562388, 8.587644640356302, 31.35589275509119, 50.816751793026924, 49.0652509778738, 36.516728326678276, 26.936363205313683, 24.306064546108246, 24.572966024279594, 21.29167679697275, 13.781864270567894, 8.637689854949713, 2.0754963671788573, 0.6053630320820957, 0.7181084447074682, 1.130872992798686, 4.564516944810748, 7.039205403998494, 7.235557492822409, 8.199300728738308, 10.629431828856468, 13.258724492043257, 17.047004364430904, 13.623222783207893, 19.284825883805752, 26.69731993228197, 28.325513564050198, 35.291788056492805, 44.75134626030922, 51.04805678129196, 54.33846361935139, 53.224614188075066, 56.84912949800491, 55.78394025564194, 54.502162635326385, 54.18158903717995, 53.29370588064194, 54.82804834842682, 54.347792118787766, 53.89085903763771, 55.89474990963936, 53.60587812960148, 55.452035665512085, 56.12230069935322, 55.389437824487686, 49.30275723338127, 48.136041238904, 44.71074543893337, 41.442863792181015, 40.062249675393105, 40.75592525303364, 40.5282224714756, 39.29336853325367, 39.068515598773956, 39.59830977022648, 42.897190153598785, 49.63319890201092, 50.64235255122185, 60.02020753920078, 49.30936887860298, 49.36916247010231, 57.076570093631744, 49.07208301126957, 48.93294967710972, 46.925255209207535, 45.48653841018677, 44.62608978152275, 49.038508012890816, 47.75419972836971, 48.959358260035515, 46.53691604733467, 47.6988784968853, 50.041555389761925, 50.802578553557396, 50.71124665439129, 55.601793229579926, 54.92192231118679, 52.84346044063568, 51.4704155176878, 52.69877180457115, 53.89848902821541, 55.33162772655487, 55.30024141073227, 54.42719265818596, 52.36992605030537, 54.023221135139465, 52.06139400601387, 54.45937693119049, 54.09274600446224, 53.41377563774586, 47.77746967971325, 42.05318704247475, 32.2213514149189, 23.51418513804674, 15.966059267520905, 14.961411226540804, 10.703980978578329, 15.242724381387234, 11.263715643435717, 15.501801129430532, 9.53100387006998, 15.274730063974857, 8.236620426177979, 4.9092714954167604, 3.702760236337781, 1.1213440541177988, 0.6038822396658361, 0.45277295750565827, 4.142403295263648, 12.540402486920357, 27.736756056547165, 38.392034098505974, 38.7932051718235, 32.50858560204506, 33.04158680140972, 40.58103583753109, 45.63524343073368, 41.82379335165024, 14.667057171463966, 2.9818498576059937, 0.08217293594498187, 0.016293848530040123, 0.0751917011803016, 0.054900526520214044, 0.08347655544639565, 0.03606651058362331, 0.026748981945274863, 0.02548777989431983, 0.0826762753422372, 0.06139181765320245, 0.025598148386052344, 0.04149517983023543, 0.030310287038446404, 0.08069154981058091, 0.045314108501770534, 0.009857288932835218, 0.023430921319231857, 0.052420239298953675, 0.01439056999515742, 0.061714303083135746, 0.05381010007113218, 0.0553836312610656, 0.04797377281647641, 0.03476078338280786, 0.051957053801743314, 0.0354664285259787, 0.03609542836784385, 0.007849888006603578, 0.11767276111640967, 0.06623372639296576, 0.11399743802030571, 0.17442021489841864, 0.10996478566084988, 0.11238903331104666, 0.18235417432151735, 0.14447273046243936, 0.08086772824754007, 0.2477030231966637, 0.19948478322476149, 0.18123002839274704, 0.14986250374931842, 0.2069913101149723, 0.1486128309625201, 0.14465921733062714, 0.1687010022578761, 0.07933624714496545, 0.15036777273053303, 0.12425705819623545, 0.11727057644748129, 0.13966643367893994, 0.1260564842959866, 0.1347289400291629, 0.12712112482404336, 0.13925535808084533, 0.1443534524878487, 0.14259070332627743, 0.8569923578761518, 11.477755308151245, 37.22525350749493, 56.70916400849819, 56.656377241015434, 42.31077902019024, 33.96306775510311, 30.921321474015713, 32.44108222424984, 27.87404838949442, 18.975005708634853, 9.439754616469145, 2.4518462223932147, 1.0324276378378272, 1.23771779704839, 7.274097874760628, 11.499028466641903, 15.669991504400969, 19.870691746473312, 15.853554904460907, 16.51735458523035, 20.69148950278759, 16.114897280931473, 19.333339780569077, 25.146391354501247, 26.64298664778471, 29.569110833108425, 35.88259555399418, 45.655218958854675, 51.53343893587589, 56.72238349914551, 52.76019170880318, 57.9233318567276, 57.623968720436096, 56.495353281497955, 57.56076291203499, 55.63150763511658, 56.847639977931976, 56.26090586185455, 55.10950304567814, 58.023692071437836, 52.71438516676426, 55.79726614058018, 57.27596439421177, 58.29931788146496, 52.03856863081455, 51.38119250535965, 45.44211499392986, 42.74779736995697, 41.42954170703888, 42.91935436427593, 43.45119662582874, 39.675327837467194, 41.55292108654976, 41.73830173909664, 45.49127295613289, 52.06997014582157, 54.739129319787025, 61.585765331983566, 52.365533486008644, 51.83259308338165, 58.77843797206879, 51.3010586053133, 51.6187709569931, 49.5865374058485, 48.64887312054634, 46.461269706487656, 50.78985683619976, 50.05502946674824, 50.73256351053715, 48.90195474028587, 49.64027792215347, 53.5197177529335, 53.90069670975208, 54.16739299893379, 58.61039198935032, 56.76512360572815, 53.96589361131191, 51.84374928474426, 51.771583557128906, 53.552289605140686, 56.331798657774925, 55.90059019625187, 54.77868139743805, 55.03554381430149, 52.989095225930214, 53.62317480146885, 54.78454068303108, 54.803349673748016, 54.34375673532486, 49.32935580611229, 47.628901451826096, 34.61353585124016, 30.389215126633644, 31.768168732523918, 21.878547705709934, 22.363549880683422, 28.659300953149796, 23.765543550252914, 18.920493833720684, 12.525990810245275, 21.596500240266323, 9.415701907128096, 14.970480389893055, 9.568964783102274, 1.5019630989991128, 1.0656135133467615, 1.2946791155263782, 5.064052864909172, 15.672846101224422, 30.264329127967358, 39.495259299874306, 44.91797871887684, 39.69397723674774, 41.14404022693634, 48.040054589509964, 54.23815280199051, 48.78267914056778, 18.312349766492844, 3.4089858876541257, 0.24666440236615017, 0.07777593360515311, 0.15389110398245975, 0.18301820353372023, 0.17840752203483135, 0.160357867134735, 0.10602396665490232, 0.1093929608759936, 0.14074447739403695, 0.24652027728734538, 0.18040257826214656, 0.1354590500704944, 0.10145547625143081, 0.18674899474717677, 0.17925376334460452, 0.14874370128381997, 0.1855034483014606, 0.11775278690038249, 0.14390112832188606, 0.13781217770883814, 0.19438936054939404, 0.21615330129861832, 0.09622372104786336, 0.21916723722824827, 0.13785419811028987, 0.18734128796495497, 0.1262226956896484, 0.045194511403678916], [0.05245561376796104, 0.011220162432437064, 0.019428270279604476, 0.019435487665759865, 0.027664025910780765, 0.09710566708236001, 0.04042795662826393, 0.054840590673848055, 0.10533349472098053, 0.02084556454065023, 0.029375212507147808, 0.039009092724882066, 0.007118481526049436, 0.0705486249353271, 0.062494148151017725, 0.031369190764962696, 0.03812842689512763, 0.05909026185690891, 0.04052330034028273, 0.10840646107681096, 0.011179229277331615, 0.04602287808666006, 0.03884549740178045, 0.0459458060504403, 0.020228850953571964, 0.039086539545678534, 0.08881777743226849, 0.10103985870955512, 0.4129834222840145, 7.243213132023811, 24.167780466377735, 45.04206486046314, 40.5373989790678, 35.60406669974327, 25.752781815826893, 22.840798571705818, 26.805412732064724, 30.47648124396801, 14.391327816992998, 6.140152746811509, 2.397387782111764, 0.6616026267874986, 0.08107719200779684, 0.6859912618529052, 3.4162499103695154, 5.486437724903226, 5.604543937370181, 4.568556128069758, 8.188444711267948, 10.10882556438446, 21.198331005871296, 6.238479120656848, 15.39353258907795, 25.413135141134262, 26.22093189507723, 31.63365975022316, 45.86784414947033, 50.08176863193512, 53.23664054274559, 49.12651129066944, 51.969419941306114, 49.25672270357609, 53.47749061882496, 54.900540858507156, 57.91455052793026, 53.0634306371212, 55.786786302924156, 53.21310840547085, 53.29914718866348, 52.53260672092438, 55.108085721731186, 53.56169410049915, 50.311553701758385, 48.22823189198971, 46.198650598526, 39.79420065879822, 40.457865446805954, 38.31502363085747, 39.24250826239586, 37.61175736784935, 39.99603442847729, 37.49932520091534, 38.136254623532295, 39.3042017519474, 46.97792798280716, 46.57123200595379, 56.675570011138916, 43.05979482829571, 42.738119289278984, 56.05624124407768, 48.09523902833462, 48.278541192412376, 43.15721780061722, 44.36816722154617, 42.52608306705952, 43.972133472561836, 42.83919006586075, 42.658927738666534, 40.28951548039913, 42.71054036915302, 44.304653629660606, 46.16149619221687, 48.426778838038445, 50.5734546482563, 51.90950855612755, 54.1999876499176, 52.57588639855385, 53.96089307963848, 52.44977876543999, 52.19637416303158, 52.093958258628845, 53.055853843688965, 54.31924805045128, 54.11524839699268, 53.96989479660988, 53.41253310441971, 55.55985487997532, 51.44727095961571, 47.93909400701523, 39.22875680029392, 34.374217092990875, 23.474948443472385, 16.40026766806841, 9.541086629033089, 6.267455890774727, 9.033487066626549, 9.285382200032473, 15.452436078339815, 4.490582887083292, 15.771474558860064, 5.420716451480985, 3.949706847779453, 4.293847493827343, 1.1184224858880043, 0.47318673867266625, 0.5267529690172523, 3.084500399418175, 9.98581001535058, 21.991652436554432, 25.786271318793297, 25.021592751145363, 23.628720492124557, 29.894179590046406, 44.39553715288639, 37.676008120179176, 31.899546682834625, 13.670993819832802, 1.7583905579522252, 0.062057438772171736, 0.023632709417142905, 0.02133425765350694, 0.014719547361892182, 0.022482475142169278, 0.05395272972236853, 0.06338859937386587, 0.007489515937777469, 0.012228194718773011, 0.03795847878791392, 0.04199644121399615, 0.036909545815433376, 0.012850846414949046, 0.12379344596411102, 0.059128757056896575, 0.0198001697572181, 0.039089697384042665, 0.040731476474320516, 0.0492348301486345, 0.06852478822111152, 0.041027778934221715, 0.03400722147489432, 0.022751381220587064, 0.13868127716705203, 0.04982848891813774, 0.016244562502834015, 0.029706984059885144, 0.03483458625851199, 0.0594047580671031, 0.04635759782104287, 0.0803350740170572, 0.025631921671447344, 0.07167028466938064, 0.02882809752918547, 0.04775733657879755, 0.06830260404967703, 0.029637858569913078, 0.011551120405783877, 0.007006683936197078, 0.028842185347457416, 0.0678832535049878, 0.06141890975413844, 0.036027666574227624, 0.04371424591226969, 0.005670339432981564, 0.005700739193343907, 0.054694814316462725, 0.059735158502007835, 0.00894732125743758, 0.11796028396929614, 0.03294402813480701, 0.05013508125557564, 0.051628883520606905, 0.050305556287639774, 0.05741326414863579, 0.08534923894330859, 0.3599736839532852, 8.678938541561365, 28.802224583923817, 48.80003660917282, 48.359275460243225, 40.59750035405159, 33.092621862888336, 28.061524629592896, 28.445381931960583, 28.70844941586256, 18.47065307199955, 6.538760382682085, 3.158167046494782, 0.4482704069232568, 0.3071407548850402, 0.6803857313934714, 4.237232906743884, 5.606310842558742, 7.57723088376224, 8.622726257890463, 13.195617478340864, 12.251386195421219, 16.3943874835968, 13.363332878798246, 18.002214208245277, 24.826380126178265, 28.714808374643326, 33.9564561098814, 44.7197699546814, 51.12838827073574, 53.410591408610344, 51.23150713741779, 51.54102332890034, 51.567131727933884, 53.90811391174793, 55.93362182378769, 57.49610558152199, 52.86307878792286, 56.03316508233547, 53.749518021941185, 52.055010348558426, 53.43125469982624, 55.01430295407772, 55.801046937704086, 52.267597541213036, 51.249689161777496, 47.45447181165218, 42.09400065243244, 42.1488469094038, 41.28039211034775, 41.40548139810562, 39.51613537967205, 41.40142701566219, 38.589444905519485, 39.41017426550388, 42.441932782530785, 49.80156406760216, 49.71150130033493, 56.36144086718559, 46.03437401354313, 45.51916345953941, 57.349372655153275, 49.55880269408226, 50.46428270637989, 44.299550503492355, 45.69801606237888, 44.65096704661846, 46.25701926648617, 44.52310770750046, 45.479736775159836, 41.55945673584938, 45.329876616597176, 47.66619265079498, 49.56299386918545, 50.31823754310608, 52.38654635846615, 54.420303627848625, 56.057495176792145, 52.88852982223034, 53.38471479713917, 51.25875927507877, 53.763615265488625, 53.03134895861149, 54.327751994132996, 53.60518656671047, 54.346754774451256, 53.42375010251999, 53.16758684813976, 54.12696696817875, 53.050667122006416, 48.63936223089695, 42.44343750178814, 33.80491264164448, 26.77801050245762, 16.315688006579876, 15.896928627043962, 8.820968270301819, 9.150756374001503, 10.037708580493927, 14.307924192398787, 10.266747940331697, 10.579658299684525, 9.816545248031616, 6.336814519017935, 3.8152831234037876, 0.7401753449812531, 0.49719248490873724, 0.40318932908121496, 3.762074578553438, 11.806234382092953, 26.44749093800783, 29.03463341295719, 33.15096393227577, 29.359344989061356, 37.763414829969406, 48.95354837179184, 47.49087005853653, 37.00008139014244, 16.412996985018253, 2.3374927835538983, 0.09682397751021199, 0.01323969469012809, 0.02688559834496118, 0.02767201884125825, 0.049751646947697736, 0.08964842621935531, 0.0755404809024185, 0.02938022942544194, 0.018882333461078815, 0.01639350040932186, 0.02639266942424001, 0.05258320008579176, 0.10226809827145189, 0.022889840001880657, 0.08429310342762619, 0.023902010689198505, 0.042975304313586093, 0.02061351351585472, 0.057094244548352435, 0.04940795093716588, 0.062485286907758564, 0.013139008442522027, 0.03447431809036061, 0.00928928157009068, 0.02919695049058646, 0.025901887165673543, 0.03430979879340157, 0.056668377947062254, 0.09973822074243799, 0.18890586885390803, 0.11873741648741998, 0.13062924204859883, 0.10816725203767419, 0.18556575902039185, 0.15609931986546144, 0.20666282071033493, 0.23728459083940834, 0.13193738122936338, 0.05851910129422322, 0.17377524403855205, 0.25855564163066447, 0.19388860382605344, 0.1971474484889768, 0.0920278555713594, 0.08408264518948272, 0.10093212855281308, 0.25662445463240147, 0.14148996473522857, 0.05960653317742981, 0.13793653197353706, 0.11047030697227456, 0.09415768581675366, 0.12912349862745032, 0.11677160087856464, 0.3320436686044559, 0.227541305066552, 0.9730616421438754, 10.291930139064789, 33.8811669498682, 57.65635058283806, 54.4622153788805, 47.465647011995316, 38.1703881919384, 34.23692286014557, 37.89222791790962, 42.331639900803566, 22.25004807114601, 9.05947957187891, 3.843417763710022, 0.8813774900045246, 0.6255617388524115, 2.1875867899507284, 8.720578607171774, 11.662042569369078, 11.284776963293552, 15.795013345777988, 20.02487037330866, 16.995887607336044, 34.96890418231487, 13.181638028472662, 19.450476095080376, 30.048198625445366, 30.20929668098688, 33.548855781555176, 48.4440641105175, 51.028191447257996, 53.174612671136856, 50.62036693096161, 52.41438366472721, 50.661070346832275, 53.85748542845249, 56.78147792816162, 58.5476915538311, 54.88968104124069, 55.955501049757004, 52.93599307537079, 54.617653638124466, 55.24860218167305, 58.13108570873737, 58.169007673859596, 54.908224046230316, 52.9929406195879, 49.60444964468479, 43.67374688386917, 44.47267681360245, 43.90071250498295, 43.77379551529884, 41.622909530997276, 44.16226387023926, 39.99269440770149, 42.20048613846302, 45.24548314511776, 51.791160106658936, 53.40759716928005, 59.10854525864124, 48.75493302941322, 47.92959451675415, 59.28571455180645, 53.73257853090763, 53.444679379463196, 47.96945057809353, 48.217406272888184, 47.039914056658745, 47.57964089512825, 46.83586120605469, 46.744088530540466, 43.44594530761242, 47.4369927495718, 49.9715631455183, 51.92589707672596, 53.30926604568958, 54.18803349137306, 58.706849813461304, 57.62635499238968, 54.26320865750313, 55.46417601406574, 53.68886947631836, 53.06468456983566, 54.57931749522686, 53.39726932346821, 55.678009539842606, 54.986651837825775, 54.627453312277794, 53.243024200201035, 57.912874817848206, 52.9372052103281, 50.89027024805546, 43.767347261309624, 38.14024440944195, 26.016223579645157, 21.811998076736927, 15.50814488902688, 12.84717047587037, 18.28636486083269, 23.028386905789375, 29.455324038863182, 16.00658029317856, 27.513930313289165, 17.567194551229477, 7.919266205281019, 7.5833300314843655, 3.7151098111644387, 0.9677205537445843, 1.0180338914506137, 3.8442660681903362, 14.486262872815132, 29.598088078200817, 35.36243386566639, 38.596991300582886, 35.432076528668404, 42.88843162357807, 57.09792494773865, 52.69312910735607, 44.74397085607052, 20.46405080705881, 3.2985426764935255, 0.1321587193524465, 0.1543402369134128, 0.16322500625392422, 0.1014419765851926, 0.13435538741759956, 0.15288038790458813, 0.2302357167354785, 0.09665442645200528, 0.18371993384789675, 0.2593048842390999, 0.2417864289600402, 0.15625995030859485, 0.18770016089547426, 0.1459574859472923, 0.2312231293763034, 0.20593392779119313, 0.10679974846425466, 0.13588231173343956, 0.16495667427079752, 0.22323033248540014, 0.15031131013529375, 0.1557796323322691, 0.08112512732623145, 0.1518113983911462, 0.21010580705478787, 0.09695680710137822, 0.09235459350747988, 0.09210871998220682], [0.043999828048981726, 0.029173843722674064, 0.04086637665750459, 0.024386835357290693, 0.0038828403421575786, 0.033875230510602705, 0.033589381200727075, 0.05588734544289764, 0.07371089392108843, 0.019164258665114176, 0.032328539091395214, 0.04763501950947102, 0.1060222003434319, 0.011924047757929657, 0.11642286568530835, 0.02152503413526574, 0.009042624151334167, 0.011843614720419282, 0.04181398791843094, 0.021165478428883944, 0.06316585117019713, 0.02387668861047132, 0.0321721574437106, 0.11141386610688642, 0.053437345268321224, 0.03577861665689852, 0.04629398092220072, 0.03654767089756206, 0.38540750043466687, 6.614780528470874, 24.397578835487366, 40.60836777091026, 45.0997381657362, 39.093107879161835, 22.69443992525339, 16.881703734397888, 27.932310663163662, 20.2349554002285, 7.481497870758176, 6.57459388487041, 2.939816750586033, 0.4965683090267703, 1.236122832633555, 0.5497002939227968, 3.2456115167587996, 4.739743592217565, 2.9957217257469893, 4.275823635980487, 5.149443782866001, 11.793911643326283, 17.084863632917404, 20.260231643915176, 19.294809848070145, 23.129685670137405, 25.470574758946896, 35.7215715944767, 41.674085184931755, 50.36628596484661, 54.28457111120224, 57.453502267599106, 54.73597928881645, 54.61422622203827, 54.62616518139839, 56.02582007646561, 56.142329424619675, 57.625306248664856, 56.62623345851898, 55.006828755140305, 53.64372409880161, 53.356106132268906, 52.252797335386276, 50.11194661259651, 48.3490502089262, 44.74796064198017, 38.3499513566494, 40.17489083111286, 38.40112701058388, 37.36391946673393, 39.09043662250042, 37.87541761994362, 37.78160445392132, 36.05177767574787, 38.65569435060024, 40.13369344174862, 48.14597390592098, 44.614542201161385, 54.79686722159386, 44.71422225236893, 44.024939239025116, 56.771875843405724, 45.768779665231705, 49.42340835928917, 45.14394499361515, 43.45620855689049, 39.44259412586689, 41.93638511002064, 39.39369075000286, 40.32544255256653, 38.66317614912987, 39.793212711811066, 39.62907671928406, 43.0673336237669, 45.62921695411205, 47.730344608426094, 47.54931092262268, 51.22466370463371, 52.574400678277016, 53.20960499346256, 53.55017691850662, 53.829165548086166, 53.60327146947384, 54.91896606981754, 51.445192471146584, 52.03031167387962, 53.6961080878973, 54.399955719709396, 52.07732655107975, 52.082038298249245, 47.967896461486816, 40.19253708422184, 33.4017238765955, 24.364761896431446, 9.957784619182348, 17.794416658580303, 7.753910478204489, 8.090287428349257, 4.67043531127274, 11.122605465352535, 8.992531914263964, 7.433011997491121, 10.516784973442554, 6.437248829752207, 1.3438732945360243, 0.659896043362096, 0.6806641852017492, 0.7242197636514902, 3.9687827741727233, 12.010597866028547, 29.236738868057728, 32.741475105285645, 23.015214912593365, 19.6246150508523, 29.746565110981464, 39.756149500608444, 43.07408206164837, 32.172915413975716, 14.397296346724033, 2.7131249522790313, 0.06597761122975498, 0.05028028986998834, 0.07924854755401611, 0.01874073910585139, 0.028695533255813643, 0.023239081710926257, 0.03182091379130725, 0.16347079072147608, 0.006911041973580723, 0.023022363457130268, 0.04565466893836856, 0.03559752520231996, 0.03127296389720868, 0.034423944816808216, 0.007652584336028667, 0.04735107380838599, 0.054707516173948534, 0.012080879332643235, 0.026257604113197885, 0.09259383965400048, 0.022156121267471462, 0.03489297472697217, 0.044043217712896876, 0.029792017485306133, 0.011286467761237873, 0.02046399673417909, 0.03246982174459845, 0.034779415000230074, 0.03149466196191497, 0.039833863702369854, 0.02615056229842594, 0.014247461658669636, 0.036331063965917565, 0.06166228595247958, 0.02250274505058769, 0.019889639370376244, 0.04982837759598624, 0.03208365633327048, 0.05527594192244578, 0.028836019955633674, 0.03418690284888726, 0.055261796587728895, 0.017439501898479648, 0.056737590639386326, 0.05784444081655238, 0.033717279220581986, 0.06974499032367021, 0.09374870307510719, 0.09010213820147328, 0.030078605232120026, 0.028987395817239303, 0.062220358740887605, 0.06328077273792587, 0.053082825033925474, 0.04180036950856447, 0.028257055710128043, 0.4787822352955118, 8.115349933505058, 28.699618689715862, 47.28163808584213, 49.29841786623001, 45.14056317508221, 28.040053881704807, 24.812001697719097, 31.961255371570587, 30.142389871180058, 12.76447456330061, 8.308025244623423, 3.372909198515117, 0.6501939764712006, 0.4108267411356792, 0.43622941710054874, 2.5982837146148086, 5.355627369135618, 7.401032913476229, 10.61631303280592, 11.866051722317934, 15.686569064855576, 14.639775585383177, 10.031930040568113, 12.261088024824858, 26.50871515274048, 26.235241927206516, 35.23693799972534, 45.15859700739384, 50.03185071051121, 55.44351652264595, 55.538644418120384, 55.058201998472214, 55.77328182756901, 55.54716736078262, 56.579055190086365, 57.622483000159264, 58.25191542506218, 57.412392273545265, 55.662996545434, 56.707872077822685, 54.474146738648415, 55.258493050932884, 51.630451530218124, 49.98956277966499, 48.07392977178097, 40.943084210157394, 42.4090151488781, 41.20173633098602, 39.67446528375149, 40.05368113517761, 39.98511001467705, 39.83785651624203, 38.88995558023453, 40.44434197247028, 41.90427303314209, 48.84796343743801, 48.59124921262264, 57.18786992132664, 46.7710442841053, 46.30856730043888, 58.51779855787754, 47.845429033041, 51.61257728934288, 47.210038527846336, 45.7278748601675, 41.499537751078606, 44.64275188744068, 41.798570305109024, 43.450356870889664, 40.71390710771084, 42.16240078210831, 41.2462243437767, 46.14845149219036, 47.749202996492386, 50.17880402505398, 49.241645112633705, 51.99683167040348, 53.89004968106747, 54.97585281729698, 55.154956206679344, 55.16595281660557, 54.23219092190266, 52.99799054861069, 50.493107959628105, 52.813449651002884, 52.950618490576744, 54.66116510331631, 52.22252056002617, 52.554394751787186, 48.683287873864174, 40.26126779615879, 36.36448949575424, 27.96358298510313, 14.503342006355524, 19.119283966720104, 14.472972135990858, 11.86414897441864, 8.329471293836832, 14.113589320331812, 13.414747919887304, 10.970299188047647, 5.487881172448397, 7.454913547262549, 4.610593747347593, 0.6380866386462003, 0.5592798173893243, 0.676844558911398, 4.7999808099120855, 12.66148203983903, 29.0468592569232, 36.92270614206791, 28.419828303158283, 26.48427866399288, 31.701277121901512, 47.93368689715862, 46.661868542432785, 38.826806768774986, 16.253055967390537, 2.8446128591895103, 0.03687007469125092, 0.040510349863325246, 0.10095301258843392, 0.04004283393442165, 0.02782506082439795, 0.025497654169157613, 0.0719801610102877, 0.04925296452711336, 0.01720288666547276, 0.040901947795646265, 0.005299042950355215, 0.013442598792607896, 0.0018034750951301248, 0.07675830813241191, 0.02437956787616713, 0.05185980648093391, 0.08768397616222501, 0.03781487692322116, 0.006498506199932308, 0.06363964566844516, 0.06193010849528946, 0.03775878169108182, 0.045453736165654846, 0.03821177378995344, 0.04251042671967298, 0.010125203316420084, 0.02897270314861089, 0.03182242777256761, 0.19951227237470448, 0.1407112440210767, 0.17131667205831036, 0.17350390000501648, 0.08646758869872428, 0.1758156158030033, 0.08306720905238762, 0.15805205883225426, 0.16940985718974844, 0.11739133129594848, 0.24580290250014514, 0.1202030319836922, 0.15869775699684396, 0.142195257358253, 0.15507745672948658, 0.11208874551812187, 0.17028373607899994, 0.09701522154500708, 0.1669861513073556, 0.10432116076117381, 0.2724641124950722, 0.21884364599827677, 0.13079588388791308, 0.37607754638884217, 0.1539740909356624, 0.17217300657648593, 0.14195849740644917, 0.1522582900361158, 0.7522670680191368, 10.346981585025787, 34.391247779130936, 52.875956296920776, 57.107158452272415, 52.67048232257366, 35.588301345705986, 29.443381279706955, 37.93581157922745, 31.83959349989891, 13.818662445992231, 10.38708083331585, 4.082928411662579, 1.0553217655979097, 1.6805953136645257, 1.4170006080530584, 7.499903608113527, 9.134845677763224, 10.683326236903667, 15.014576073735952, 16.46048303693533, 19.02271594852209, 23.876624889671803, 29.060527123510838, 23.73823631554842, 25.82068607211113, 25.814000330865383, 37.9167328029871, 45.18331468105316, 53.53704862296581, 56.77976422011852, 58.21281172335148, 55.901616141200066, 58.56545940041542, 57.7767813205719, 59.195302203297615, 58.68732266128063, 60.655408054590225, 59.92387130856514, 57.22579188644886, 58.709080293774605, 57.997272089123726, 56.6048102080822, 55.93399040400982, 52.90733881294727, 49.880797415971756, 42.95687735080719, 45.04475511610508, 42.49758459627628, 41.420558989048004, 42.03828044235706, 42.470495849847794, 41.28634259104729, 41.5618772059679, 42.81771741807461, 44.81140963733196, 52.572325989603996, 51.45866274833679, 57.53300920128822, 50.70400804281235, 50.33299595117569, 59.029536098241806, 50.91125652194023, 54.06442232429981, 50.675243586301804, 49.6848039329052, 43.100217059254646, 46.9578992575407, 42.13137164711952, 44.83089119195938, 42.05980248749256, 44.09148506820202, 43.544641211628914, 47.70341545343399, 50.777667090296745, 52.75604613125324, 53.337403535842896, 57.519607320427895, 57.214631885290146, 57.19291225075722, 57.33002029359341, 57.54237949848175, 54.57609906792641, 53.35646711289883, 50.81879988312721, 52.723462879657745, 54.017441645264626, 55.55437557399273, 53.689131662249565, 54.94343675673008, 49.4579941034317, 44.16189529001713, 38.22684936225414, 31.638027615845203, 13.480136711150408, 26.37548480182886, 16.628962196409702, 21.629505269229412, 18.931832425296307, 21.301761455833912, 19.699843414127827, 16.347028724849224, 17.77073822915554, 15.273495130240917, 6.854447443038225, 1.008785900194198, 1.106312891934067, 1.1820810637436807, 5.154598206281662, 15.216175206005573, 36.05495050549507, 42.205361276865005, 36.1824906617403, 32.31910116970539, 42.61553406715393, 53.023498579859734, 57.39066503942013, 44.613881036639214, 19.949841499328613, 3.7931588105857372, 0.24110798723995686, 0.13377294992096722, 0.23580372420838103, 0.24084290693281218, 0.08195541246095672, 0.0936317777086515, 0.17627865658141673, 0.23155540373409167, 0.10372011020081118, 0.14849521539872512, 0.09927887585945427, 0.16263502853689715, 0.13676493312232196, 0.1272354304092005, 0.12405271525494754, 0.10765094732050784, 0.14716941310325637, 0.14154083153698593, 0.11725749238394201, 0.1865086131147109, 0.15193032013485208, 0.1054424791072961, 0.13185835734475404, 0.1531701668864116, 0.07448491684044711, 0.14991011994425207, 0.1114973725634627, 0.14793642272707075], [0.05114378982398193, 0.023768756218487397, 0.04531180784397293, 0.04303350724512711, 0.041172742639901116, 0.06543442592374049, 0.11023017767001875, 0.043901719836867414, 0.05268939770758152, 0.050938433851115406, 0.03717166866408661, 0.03891959713655524, 0.06077789454138838, 0.04647045992896892, 0.055090657333494164, 0.012229825588292442, 0.03915652407158632, 0.028394837281666696, 0.030170776262821164, 0.05086767749162391, 0.03700993984239176, 0.060918320014025085, 0.02274674279760802, 0.03344076612847857, 0.05100165741168894, 0.0721176883962471, 0.06586724644876085, 0.019392682443140075, 0.016409744166594464, 4.319712230935693, 18.939849995076656, 37.07983151078224, 45.31656973063946, 39.27254185080528, 22.91681159287691, 19.58348225802183, 24.003583677113056, 23.018803820014, 22.609011009335518, 10.739795956760645, 4.392292136326432, 1.1980592063628137, 0.3672565572196618, 0.48238085000775754, 2.0708736777305603, 5.0157170835882425, 9.796747360378504, 12.218414414674044, 16.197624541819096, 14.455444626510143, 10.555089768022299, 6.566633312031627, 13.83830264210701, 25.8536322042346, 26.180787049233913, 30.83440113812685, 43.3377081155777, 49.96096931397915, 55.756403133273125, 51.40899561345577, 51.71640671789646, 48.42762239277363, 48.6934295296669, 50.4444819688797, 51.826369017362595, 50.02099089324474, 51.32306322455406, 49.4790867716074, 50.18779814243317, 48.18939797580242, 47.57298745214939, 46.70128382742405, 43.86759728193283, 38.90958912670612, 37.77656212449074, 36.6843943297863, 40.49356833100319, 39.641961827874184, 39.71514590084553, 36.86681114137173, 36.789941266179085, 37.16402359306812, 37.65625298023224, 38.765519857406616, 47.76071257889271, 45.07642641663551, 53.60311187803745, 45.1209220290184, 40.90900383889675, 55.38735933601856, 48.37714970111847, 49.95362810790539, 45.65694786608219, 42.891273871064186, 39.268992841243744, 40.07154777646065, 39.534036219120026, 39.17155086994171, 36.76334269344807, 38.0198934674263, 39.354256466031075, 39.13052827119827, 40.652437806129456, 44.177672043442726, 46.235330030322075, 47.6095224916935, 46.15836516022682, 48.30748803913593, 46.168126836419106, 50.71432828903198, 53.3200004696846, 54.40383531153202, 54.59116905927658, 53.943436816334724, 51.40453465282917, 53.4729840606451, 51.80064059793949, 52.788728177547455, 45.401426777243614, 39.612524807453156, 32.67863027751446, 26.826826483011246, 16.019199416041374, 21.55227441340685, 10.525451358407736, 3.338840939104557, 8.44311274588108, 10.085733253508806, 10.695465635508299, 7.588614597916603, 2.1276784921064973, 8.137985318899155, 5.847283937036991, 0.1364999864017591, 0.5045671469997615, 0.408126600086689, 4.985636947676539, 11.31400404497981, 24.709080420434475, 27.106065899133682, 33.69533412158489, 26.5788346901536, 34.224117547273636, 41.88815049827099, 48.991728723049164, 32.0612546056509, 15.789801925420761, 2.42974613327533, 0.10916432001977228, 0.040802247676765546, 0.08442034464678727, 0.08733720766031183, 0.05503316686372273, 0.03266699925006833, 0.046769946202402934, 0.009914530783134978, 0.015280577608791646, 0.03082355637161527, 0.018132894183509052, 0.023020146290946286, 0.033741079896572046, 0.03976813539338764, 0.03140489920042455, 0.024615082875243388, 0.027793139197456185, 0.012127920363127487, 0.02293480672960868, 0.06497218666481785, 0.00790137542935554, 0.006433359085349366, 0.028036032999807503, 0.03809600617387332, 0.019425815626163967, 0.04306601702410262, 0.03924634991562925, 0.02935759948741179, 0.024292109483212698, 0.017571324024174828, 0.019308786359033547, 0.055524936178699136, 0.0023005295452094288, 0.09664435550803319, 0.023651149931538384, 0.04693591268733144, 0.025219690178346355, 0.1044145155174192, 0.08788000704953447, 0.020913899643346667, 0.038356934164767154, 0.02520355959859444, 0.029394808916549664, 0.08910213131457567, 0.08982190323877148, 0.05776461912319064, 0.0481942760234233, 0.026250889532093424, 0.04317303100833669, 0.02672525919479085, 0.03777213663852308, 0.05408974131569266, 0.04079019148775842, 0.12882476934464648, 0.0623451842693612, 0.007896289862401318, 0.1845954157761298, 5.866335639730096, 23.824620880186558, 42.641118094325066, 50.854559764266014, 46.436331644654274, 29.707820490002632, 25.487046875059605, 30.23320309817791, 24.582199528813362, 20.662920735776424, 11.318836435675621, 4.5078163873404264, 0.9182559361215681, 0.5224813451059163, 0.5658490711357445, 2.6153782848268747, 4.15103405714035, 4.897501626983285, 9.044649917632341, 9.388477317988873, 13.909848053008318, 12.049790862947702, 12.317569144070148, 12.15891245752573, 18.294238038361073, 25.16801029443741, 32.60123983025551, 44.1367444396019, 50.46757332980633, 55.7362300157547, 53.28273206949234, 53.09748061001301, 50.60108296573162, 51.37513943016529, 53.46391774713993, 54.22752097249031, 52.16442167758942, 54.20863978564739, 52.75341287255287, 52.95309975743294, 49.99474190175533, 49.75927613675594, 49.88935835659504, 46.115499660372734, 41.970210894942284, 39.14477750658989, 39.2904768884182, 40.68167723715305, 41.140700206160545, 41.58805400133133, 38.083844035863876, 38.53011108934879, 38.80786098539829, 41.14480398595333, 41.361795142292976, 49.704361483454704, 47.0803514868021, 56.53354123234749, 47.445648685097694, 43.87919045984745, 56.942076310515404, 51.33197754621506, 52.198403254151344, 48.077642172575, 44.86481957137585, 41.677455604076385, 41.82302199304104, 41.64206810295582, 40.88611766695976, 39.37304645776749, 40.124961510300636, 40.698605328798294, 41.221187487244606, 42.54286676645279, 47.325947508215904, 49.150275215506554, 49.50685188174248, 48.393713012337685, 51.4200834184885, 50.19113816320896, 52.849939092993736, 55.75049065053463, 55.303034260869026, 55.073689967393875, 53.25699605047703, 51.01956591010094, 54.142485335469246, 51.67368181049824, 53.39260697364807, 47.079181149601936, 40.71245178580284, 32.97915995121002, 28.67961086332798, 18.017588183283806, 16.37173119932413, 17.502218037843704, 14.33809457346797, 11.74966586753726, 8.146883491426706, 9.614269752055407, 10.379517339169979, 8.650356475263834, 7.77310467325151, 5.106779672205448, 0.9506964578758925, 0.26163656380958855, 0.6748257984872907, 4.925811057910323, 12.618095017969608, 30.27524594217539, 31.187660582363605, 36.22936874628067, 33.37697960436344, 38.97502161562443, 47.0048913359642, 56.11794613301754, 37.55262494087219, 18.43564935028553, 3.080299012362957, 0.06032175944710616, 0.08140189645928331, 0.018817161762854084, 0.02279266689583892, 0.024034535999817308, 0.039970392899704166, 0.023808680052752607, 0.018016004069068003, 0.03454733800026588, 0.06379865822964348, 0.019732400542125106, 0.022604517616855446, 0.019200968999939505, 0.04303029374568723, 0.030025183586985804, 0.05028584855608642, 0.06555098763783462, 0.016625831594865303, 0.03838701712084003, 0.030367885119630955, 0.029844509590475354, 0.03512372699333355, 0.06096106400946155, 0.02349556980334455, 0.04306507820729166, 0.0437763228546828, 0.027745456209231634, 0.028538544902403373, 0.11356305156368762, 0.0732533005066216, 0.07229880953673273, 0.09346627877675928, 0.17551940982230008, 0.11723948788130656, 0.3105781157501042, 0.17236964602489024, 0.15401712065795437, 0.19893494085408747, 0.1682175969472155, 0.16199523786781356, 0.22331806918373331, 0.1409399590920657, 0.14648913085693493, 0.1388799204141833, 0.1658028710517101, 0.15429613849846646, 0.17585843772394583, 0.14921821566531435, 0.14101078966632485, 0.16428817732958123, 0.08465182792861015, 0.19198187801521271, 0.23152920592110604, 0.22558509284863248, 0.16262907651253045, 0.1181996933883056, 0.24434602208202705, 8.379843290895224, 29.035801850259304, 50.927766636013985, 58.43837521970272, 52.83480450510979, 34.0703359991312, 30.909506008028984, 36.40603266656399, 34.48478356003761, 31.128849238157272, 15.03054566681385, 6.485917093232274, 1.8267091107554734, 0.9788036090321839, 1.2511322647333145, 5.832847561687231, 9.937461409717798, 19.933969751000404, 18.37136819958687, 23.099251203238964, 24.75672986358404, 18.728241249918938, 14.771070890128613, 19.963391572237015, 30.675290375947952, 30.99191788583994, 32.91350707411766, 46.4163751155138, 53.683952540159225, 59.5425009727478, 57.054455280303955, 57.22557909786701, 53.004378005862236, 54.099281653761864, 54.899784699082375, 56.91884435713291, 54.202305525541306, 57.76841796934605, 54.84014689922333, 57.36718989908695, 52.60685093700886, 51.11667349934578, 51.50031991302967, 46.93650260567665, 42.738438472151756, 41.259630024433136, 40.846922770142555, 42.97117218375206, 44.18492205440998, 44.013756439089775, 40.55521622300148, 39.6231984347105, 41.47570922970772, 42.39655181765556, 44.33075822889805, 51.69480487704277, 51.27485141158104, 57.69280582666397, 50.59509068727493, 47.48901195824146, 59.475863948464394, 55.06979897618294, 55.870127230882645, 50.95157615840435, 46.917872205376625, 43.641285225749016, 45.62241531908512, 43.04259315133095, 43.15153710544109, 41.41501888632774, 43.34261745214462, 41.73439174890518, 43.90856668353081, 43.45641754567623, 49.751722142100334, 49.95553940534592, 51.828941479325294, 50.596789196133614, 54.05475564301014, 51.44631341099739, 55.47977417707443, 57.21190743148327, 57.800761833786964, 54.54522952437401, 54.6755663305521, 52.13406890630722, 54.54441636800766, 53.29294212162495, 55.43276309967041, 48.09241957962513, 43.47969509661198, 35.76623059809208, 31.568200662732124, 20.5879108607769, 26.31126444786787, 14.530287310481071, 15.308571998029947, 14.222173243761063, 17.318889275193214, 22.973128370940685, 17.307904064655304, 10.335852932184935, 12.64846108853817, 9.960530921816826, 1.4882716024294496, 0.9144946723245084, 0.8696669340133667, 6.839674785733223, 15.176543332636356, 33.03021401166916, 38.18182937800884, 47.750453129410744, 40.19722603261471, 46.3738401979208, 56.96443811058998, 60.81182286143303, 46.21822714805603, 20.89892227202654, 4.32991610839963, 0.1455858035478741, 0.2426804052083753, 0.22969964862568304, 0.1505242768325843, 0.19810756493825465, 0.15411098749609664, 0.143120507709682, 0.11605646737734787, 0.14087355171795934, 0.12477166339522228, 0.18396150291664526, 0.1251355532440357, 0.11471236372017302, 0.1349015042069368, 0.1302975317230448, 0.10963587323203683, 0.1793273547082208, 0.09539024467812851, 0.10524983983486891, 0.13394264940870926, 0.09023934646393172, 0.047169050958473235, 0.14234724920243025, 0.09394409571541473, 0.20783784828381613, 0.14478279976174235, 0.12529860308859497, 0.10243148950394243], [0.005703227243429865, 0.07770793061354198, 0.03935896711482201, 0.0834253324137535, 0.057278601452708244, 0.03512600909743924, 0.03252272945246659, 0.041423165530432016, 0.03683866329083685, 0.0534808833617717, 0.07428377255564556, 0.070909353235038, 0.03175655845552683, 0.07361998825217597, 0.014679102168884128, 0.11254557452048175, 0.07233910815557465, 0.10387262154836208, 0.036077828335692175, 0.0388740589551162, 0.03287569859821815, 0.01023133785565733, 0.05925020952417981, 0.010087569935421925, 0.03142324509099126, 0.019687459789565764, 0.08498053255607374, 0.03055376342672389, 0.12776085612131283, 3.212451171129942, 14.953408855944872, 33.38318847119808, 47.384483367204666, 40.86517319083214, 27.84644667059183, 19.93890568614006, 23.95666379481554, 25.45040924102068, 21.22805491089821, 11.838919278234243, 5.304142031818628, 1.6495493170805275, 0.44454853632487357, 0.1382707804441452, 1.3193268491886556, 3.792115291580558, 0.8171934122219682, 7.243615435436368, 7.787258438766003, 16.505736708641052, 11.828649379312992, 9.420622643083334, 4.371075499802828, 16.36769011616707, 20.810835398733616, 29.67299345880747, 44.332152754068375, 49.82769526541233, 51.90515398979187, 47.63656564056873, 46.40984706580639, 44.34936963021755, 46.003500670194626, 42.40187533199787, 44.66888688504696, 44.36099320650101, 45.392269268631935, 43.58565241098404, 44.12704735994339, 42.85857282578945, 42.55306161940098, 39.73948359489441, 39.76037487387657, 38.81480321288109, 40.14145642518997, 40.315183103084564, 38.71318906545639, 38.83435696363449, 37.221058532595634, 38.24551396071911, 38.4157258272171, 37.03189328312874, 38.77162232995033, 41.384491324424744, 47.05105885863304, 46.0033904761076, 54.655032232403755, 45.04409775137901, 40.12583926320076, 53.31051617860794, 51.00609563291073, 50.50688602030277, 46.01388171315193, 45.445736199617386, 38.56545679271221, 39.81463976204395, 38.02798703312874, 38.73005636036396, 39.44411404430866, 44.141577780246735, 40.24606481194496, 39.10667695105076, 40.1354755461216, 41.076240465044975, 40.38049779832363, 43.54494519531727, 42.81005322933197, 46.55236981809139, 46.58422730863094, 46.30337677896023, 47.221038937568665, 49.66202795505524, 53.095204532146454, 54.81626898050308, 56.30096711218357, 53.10961715877056, 53.53778578341007, 49.18751321732998, 46.088274121284485, 35.65713845193386, 34.497630670666695, 25.80331340432167, 14.413905255496502, 12.466190569102764, 26.653831265866756, 18.16329326480627, 6.857406534254551, 11.46498704329133, 8.478456549346447, 10.002851150929928, 7.771088881418109, 6.415352979674935, 3.0024492647498846, 0.8299980126321316, 0.2897726290393621, 0.7207989378366619, 4.645079746842384, 11.43497720360756, 21.016134582459927, 37.715161219239235, 32.3474932461977, 24.689479172229767, 27.68845684826374, 43.760401234030724, 41.45481415092945, 32.259052991867065, 11.478173285722733, 2.4276614701375365, 0.054675845021847636, 0.028198726613481995, 0.07149623619625345, 0.10252523759845644, 0.03961267771956045, 0.015716953021183144, 0.040309190735570155, 0.03256775926274713, 0.023577846150146797, 0.021842218775418587, 0.030388162449526135, 0.036424017962417565, 0.02379820649366593, 0.037904572891420685, 0.03837743599433452, 0.04394686839077622, 0.032403213990619406, 0.0614830350241391, 0.043116549859405495, 0.010722002298280131, 0.03891442436724901, 0.043903144760406576, 0.04642762316507287, 0.05862526180862915, 0.020018006798636634, 0.05512960524356458, 0.019906189263565466, 0.027645386871881783, 0.021849491822649725, 0.015573434648104012, 0.026195046630164143, 0.07299220553250052, 0.04700110664998647, 0.06357399528496899, 0.023880141452536918, 0.040069669994409196, 0.04063869688252453, 0.0409539500833489, 0.050986090864171274, 0.08317277213791385, 0.01472628049668856, 0.020048347651027143, 0.032642827500239946, 0.06124050858488772, 0.06109564135840628, 0.07376865527476184, 0.06088982896471862, 0.02733265697315801, 0.0863777739868965, 0.08383631153265014, 0.06331239565042779, 0.06343934743199497, 0.023466446073143743, 0.038734913687221706, 0.061911558514111675, 0.02424980149953626, 0.03823416067461949, 3.821142646484077, 18.591541685163975, 41.13617464900017, 54.168817922472954, 46.2965789437294, 31.981781870126724, 24.392238222062588, 29.088309332728386, 31.26618716865778, 25.225142128765583, 14.0531668625772, 5.822368199005723, 1.741009815596044, 0.4430454794783145, 0.6415986595675349, 1.5979588916525245, 4.230201384052634, 5.815964117646217, 14.559563789516687, 12.32240628451109, 6.56265065073967, 7.892766902223229, 10.22708186879754, 10.300215594470501, 14.733171723783016, 22.136080786585808, 31.163244992494583, 46.967866122722626, 51.08082242310047, 53.62798534333706, 50.47390379011631, 49.51796628534794, 46.20268598198891, 48.30879136919975, 44.843723103404045, 46.9729046523571, 47.10293747484684, 47.38947629928589, 45.12148439884186, 48.130626529455185, 46.52237802743912, 46.99144005775452, 42.2791913151741, 41.228399500250816, 40.519384145736694, 41.473984122276306, 42.52707861363888, 40.347511768341064, 39.515478014945984, 41.27461642026901, 39.35366369783878, 40.55114284157753, 38.12889441847801, 40.79814478754997, 42.913753464818, 49.319628328084946, 49.529650658369064, 56.58438630402088, 48.338669165968895, 44.798342138528824, 56.81385979056358, 54.0958808362484, 52.49348022043705, 47.68332213163376, 46.86435967683792, 41.06173284351826, 40.93702353537083, 40.22210709750652, 40.2917193621397, 40.69960467517376, 44.39241752028465, 40.219888016581535, 39.68427635729313, 41.139404475688934, 41.5176285803318, 43.19907255470753, 46.015359833836555, 47.1766497194767, 49.45197522640228, 48.734330534935, 49.03338588774204, 51.225917637348175, 50.13085439801216, 53.6046127974987, 57.62644998729229, 55.200215578079224, 51.917754113674164, 53.563324213027954, 51.65491081774235, 46.08457311987877, 39.197587072849274, 33.47516633570194, 23.200825452804565, 17.723983637988567, 19.580613411962986, 19.93509829044342, 12.123358715325594, 10.529154259711504, 12.764906790107489, 12.54239832982421, 9.647667109966278, 4.885370302945375, 6.660357182845473, 5.207846174016595, 1.143341667484492, 0.7890682714059949, 0.7851195707917213, 5.030395220965147, 14.059330131858587, 24.716007448732853, 38.82030911743641, 36.1378088593483, 28.337574116885662, 32.35826566815376, 49.130922853946686, 49.481260254979134, 39.91427421569824, 13.987743873149157, 2.791045233607292, 0.09936339905834757, 0.05652328807627782, 0.032547049631830305, 0.020886033853457775, 0.03386412798136007, 0.025882771296892315, 0.04590315111272503, 0.03461712956777774, 0.026396549001219682, 0.037408569623949006, 0.02777765243081376, 0.007151664340199204, 0.07079942632117309, 0.028110110470151994, 0.05099712660012301, 0.031190707959467545, 0.028574893440236337, 0.05148299955180846, 0.11651730397716165, 0.06240057075046934, 0.03595755588321481, 0.016134097531903535, 0.06696209980873391, 0.04911869516945444, 0.03422311965550762, 0.043233029937255196, 0.057116000607493334, 0.10270089653204195, 0.17390311608323827, 0.133196419919841, 0.09725199633976445, 0.2327578017138876, 0.12211412904434837, 0.1681752351578325, 0.11476536790723912, 0.10932535122265108, 0.19593347300542518, 0.19452414941042662, 0.1568008869071491, 0.21931164432317019, 0.1221601347788237, 0.16987534705549479, 0.08282331706141122, 0.20330247993115336, 0.18430195574183017, 0.14720108796609566, 0.2047850238159299, 0.1668527873698622, 0.25225495628546923, 0.17611082730581984, 0.17636627453612164, 0.18786405678838491, 0.23473805951653048, 0.117455000145128, 0.20168919931165874, 0.2010474939015694, 0.3276715282117948, 4.776411624625325, 22.182839177548885, 47.93959937989712, 60.80842584371567, 53.61106105148792, 41.33606672286987, 33.52808989584446, 35.306983441114426, 36.17043390870094, 29.9590877071023, 16.774192303419113, 6.623418414965272, 2.2817637864500284, 0.8309515833389014, 1.378233425784856, 4.555075401440263, 9.966316111385822, 10.429766792804003, 16.57925896346569, 17.072103917598724, 26.547864452004433, 21.238413155078888, 17.075939811766148, 8.269197978079319, 20.24964351207018, 25.073980540037155, 35.45887269079685, 49.97554913163185, 53.95899698138237, 56.093973219394684, 53.99112805724144, 50.68172983825207, 47.974884286522865, 50.360039100050926, 46.970180198550224, 50.44264666736126, 49.900750145316124, 49.971513748168945, 48.27361285686493, 49.03315030038357, 47.90120244026184, 48.532382771372795, 44.38931688666344, 43.74686636030674, 43.892485946416855, 43.88224169611931, 44.775319173932076, 41.87405705451965, 41.73205107450485, 41.563868299126625, 41.36587992310524, 41.48972287774086, 40.55526562035084, 42.368691712617874, 45.195607021450996, 51.00497089326382, 53.310588374733925, 58.80688324570656, 52.96482972800732, 49.16240036487579, 58.40060144662857, 57.463621124625206, 55.37847921252251, 51.36765383183956, 49.51292395591736, 43.09148132801056, 42.99845851957798, 42.3631402105093, 41.435507386922836, 43.79320107400417, 46.30817212164402, 43.815369084477425, 41.45101435482502, 44.91719976067543, 45.02780042588711, 44.268148988485336, 47.857823967933655, 49.2520185559988, 51.48757539689541, 51.25228822231293, 51.18029348552227, 53.713089376688, 52.604362070560455, 57.084948644042015, 58.90411622822285, 56.50899454951286, 52.25164979696274, 54.693079590797424, 50.2925281226635, 48.4531532227993, 39.26767811179161, 39.21005420386791, 28.19025032222271, 18.703989051282406, 17.59703055024147, 34.745289981365204, 26.593443006277084, 14.986620023846626, 22.957342118024826, 15.85448395460844, 20.872213505208492, 17.6521522924304, 10.497844889760017, 8.498125243932009, 1.8159761116839945, 1.2082386226393282, 1.7538026603870094, 6.196816256269813, 15.915569476783276, 28.73715877532959, 51.233996003866196, 41.75950840115547, 36.31019800901413, 38.771246150135994, 58.34043927490711, 55.18282391130924, 46.409577280282974, 18.420708552002907, 3.4489196073263884, 0.1831046785810031, 0.1751263832557015, 0.2413420012453571, 0.1604972721543163, 0.1530116589856334, 0.12441405211575329, 0.09052332185092382, 0.15643399878172204, 0.07764171619783156, 0.1660535833798349, 0.13678988412721083, 0.09265537111787125, 0.20247789449058473, 0.179568552703131, 0.12867976853158325, 0.188725586340297, 0.14897134766215459, 0.14840471791103482, 0.1877730101114139, 0.11780412867665291, 0.18717406725045294, 0.13571149902418256, 0.16692559205694124, 0.14343268470838666, 0.09357385308248922, 0.1500640859012492, 0.12745394837111235, 0.10515038462472148], [0.02108826723997481, 0.02730620497459313, 0.035306143181514926, 0.044173857968416996, 0.09413951062015258, 0.0366631898941705, 0.04402973660035059, 0.026715086205513217, 0.029872946834075265, 0.053200073234620504, 0.02701558179978747, 0.03004357400641311, 0.02064542586595053, 0.075379026675364, 0.014802470304857707, 0.06497986047179438, 0.02785134955047397, 0.030676549904455896, 0.060849682486150414, 0.05673728264810052, 0.04946451743307989, 0.04963837294781115, 0.031698244201834314, 0.006909332714712946, 0.05114191219036002, 0.0280268934511696, 0.04268264950951561, 0.05683766554284375, 0.038810297337477095, 2.9413079330697656, 14.959822911769152, 30.58201488107443, 44.02386389672756, 42.20528148114681, 32.036225348711014, 24.199326373636723, 26.94483295083046, 21.050338447093964, 20.460055321455002, 11.565013825893402, 5.983903231099248, 1.7273482424207032, 0.8092220930848271, 0.8121034665964544, 0.9699229511898011, 1.9344957894645631, 3.5700359707698226, 13.464667741209269, 9.93848355486989, 5.296658808365464, 5.690579870715737, 9.602462835609913, 10.333554055541754, 9.207584224641323, 19.188527651131153, 30.441240034997463, 46.33518107235432, 48.36505874991417, 47.51450479030609, 45.753439888358116, 45.608922243118286, 42.89434030652046, 44.685655385255814, 42.53497079014778, 40.34959405660629, 37.03573487699032, 39.40878354012966, 38.03360313177109, 37.98503413796425, 36.47368423640728, 38.15672792494297, 37.826278656721115, 38.64557929337025, 41.311542838811874, 48.62083442509174, 44.404725059866905, 37.2238589823246, 39.04585361480713, 38.7575326859951, 36.98758006095886, 37.86296188831329, 38.24194975197315, 41.64204530417919, 45.07629722356796, 45.89116349816322, 48.01605507731438, 52.36898750066757, 40.74717812240124, 35.354917868971825, 48.58278326690197, 49.70569521188736, 49.451925829052925, 46.53147093951702, 42.80550867319107, 39.13849264383316, 37.95598089694977, 37.70357944071293, 37.75338336825371, 38.254154697060585, 40.92692367732525, 38.56498561799526, 40.520353093743324, 38.72038967907429, 38.77369321882725, 39.539276137948036, 38.065681010484695, 37.874437272548676, 40.2248315513134, 40.53005397319794, 44.697411954402924, 43.42092365026474, 48.70082013309002, 51.269771084189415, 54.94278319180012, 55.13371154665947, 54.05847564339638, 51.66775792837143, 50.944789722561836, 43.67688551545143, 37.77153119444847, 28.092568963766098, 24.19863861054182, 19.670860469341278, 22.195957973599434, 16.357525661587715, 10.947346519678831, 12.543604765087366, 4.109691800549626, 7.7362020034343, 9.429093338549137, 3.503868696279824, 7.056206641718745, 3.554643946699798, 1.019266212824732, 0.3679461608408019, 0.31380334112327546, 5.090772081166506, 11.134093198925257, 19.578837007284164, 22.92100466787815, 34.81487564742565, 32.71966427564621, 33.89526419341564, 40.37077412009239, 45.950736701488495, 32.773701176047325, 12.815297786146402, 1.6533017344772816, 0.10099419436301105, 0.016269439292955212, 0.06488580067525618, 0.07619741518283263, 0.03541670092090499, 0.014979513343860162, 0.06407398759620264, 0.06190162857819814, 0.011867372722917935, 0.03586851300497074, 0.06507576079457067, 0.016259058502328116, 0.05954679400019813, 0.04796822897333186, 0.03958873974625021, 0.03059726997889811, 0.04923253691231366, 0.0641017068119254, 0.05337232942110859, 0.07527453228249215, 0.04696568023064174, 0.12127233319915831, 0.03836689007584937, 0.0665781793941278, 0.05256684686173685, 0.11506098016980104, 0.06438594937208109, 0.015199059180304175, 0.01886469075543573, 0.046068123119766824, 0.018509534129407257, 0.0368589907157002, 0.037590952415484935, 0.05213420445215888, 0.07787193782860413, 0.034965875893249176, 0.04898185427009594, 0.01581263441039482, 0.08867671742336825, 0.023336815138463862, 0.06911603501066566, 0.006104522726673167, 0.03594020818127319, 0.03481781743175816, 0.010436794018460205, 0.026949881321343128, 0.040819725254550576, 0.06465579426730983, 0.04266031086444855, 0.129601530788932, 0.07125621079467237, 0.027972761199634988, 0.0320730733074015, 0.021709567299694754, 0.012669493353314465, 0.015460610575246392, 0.05160587694263086, 3.663510004989803, 18.00098117440939, 36.65691040456295, 50.98760962486267, 47.71759249269962, 41.64390340447426, 33.210795521736145, 32.414495050907135, 28.115282244980335, 25.557337403297424, 14.307427369058132, 6.268072882667184, 1.7912838491611183, 0.5251812189817429, 0.2782500145258382, 1.6575247328728437, 2.94439360499382, 4.858738956972957, 11.924573332071304, 10.38840126246214, 7.795948572456837, 5.206856327131391, 11.50864765048027, 11.821536161005497, 12.91336577385664, 20.73309727013111, 31.773570142686367, 46.501281559467316, 52.002185583114624, 49.42023552954197, 47.44825154542923, 48.53738330304623, 45.4011569917202, 45.86433693766594, 43.271736055612564, 42.6585553586483, 39.130376279354095, 41.82111829519272, 41.4276722073555, 39.2383398860693, 39.178432300686836, 38.85226160287857, 40.44433057308197, 41.182596758008, 42.55662962794304, 50.066603645682335, 44.068800285458565, 39.540123492479324, 41.11190155148506, 39.725758731365204, 39.896730557084084, 40.44508293271065, 41.969732120633125, 42.605692595243454, 47.418423146009445, 49.15833078324795, 49.690959602594376, 53.720989152789116, 46.13245815038681, 38.978646621108055, 50.78932486474514, 51.09775051474571, 51.8541569262743, 47.94941425323486, 46.22264251112938, 40.797966197133064, 39.60610695183277, 39.76237736642361, 39.98003728687763, 38.85822728276253, 43.3253625780344, 40.76453559100628, 41.68888919055462, 39.87982526421547, 41.178283989429474, 41.207063645124435, 39.054270163178444, 40.413377434015274, 43.94116513431072, 43.86460304260254, 46.87713839113712, 45.43945133686066, 51.20760262012482, 53.16568695008755, 55.712310299277306, 56.59851014614105, 56.196438521146774, 50.95760643482208, 51.03311978280544, 45.331008955836296, 37.44123391807079, 30.2210608497262, 22.74008497595787, 16.82817790657282, 14.285042770206928, 16.29591576755047, 10.672208033502102, 12.075636126101017, 13.575182911008596, 8.182470481842756, 10.22001139819622, 7.325607435777783, 5.505698891356587, 0.6162283115554601, 0.823108566692099, 0.5258157849311829, 1.0223788395524025, 4.902843665331602, 12.943704295903444, 23.388717770576477, 31.843729577958584, 38.932855278253555, 37.104651778936386, 38.1456933170557, 45.78071862459183, 51.496311128139496, 36.12650826573372, 15.59119988232851, 2.332559935748577, 0.1824140953249298, 0.014954984435462393, 0.026126937882509083, 0.023873794234532397, 0.02192056730564218, 0.03520295496855397, 0.042104880121769384, 0.05444625421660021, 0.047951823798939586, 0.05568182248680387, 0.040414130417048, 0.022568640342797153, 0.07454652251908556, 0.0610911662079161, 0.04865255963522941, 0.02681949710677145, 0.027825571050925646, 0.03568617845303379, 0.02395621530013159, 0.02505748823750764, 0.04788901955180336, 0.13523265050025657, 0.010087550454045413, 0.004665574451792054, 0.05103557727125008, 0.07174002428655513, 0.06809722952311859, 0.07693272025790066, 0.2342034163302742, 0.13892928807763383, 0.059416157455416396, 0.20361299451906234, 0.19492784806061536, 0.12042909758747555, 0.19135103764710948, 0.0683806705637835, 0.11090461179264821, 0.13561228872276843, 0.13287797919474542, 0.12712738855043426, 0.1908467334578745, 0.12447481916751713, 0.14245337632019073, 0.1836973725585267, 0.16120342566864565, 0.1915691400063224, 0.1670957516762428, 0.20115338353207335, 0.1379246576107107, 0.178728248574771, 0.1475302898325026, 0.17226528521860018, 0.19753789238166064, 0.08928912284318358, 0.0803148208069615, 0.1641930191544816, 0.2071198055637069, 4.565043216571212, 22.180247716605663, 44.07715983688831, 57.398363426327705, 54.95239667594433, 46.67591258883476, 39.11131650209427, 37.45769843459129, 32.311155796051025, 29.77542456239462, 17.589719742536545, 8.928805533796549, 2.36291223205626, 1.7590614594519138, 1.5132666612043977, 3.2993197347968817, 7.352509517222643, 10.183773692697287, 25.0384733453393, 18.838534131646156, 12.003157865256071, 13.47258746623993, 16.939608827233315, 17.994785606861115, 13.962779212743044, 21.981725469231606, 34.10719782114029, 50.920676216483116, 54.27895501255989, 52.556640431284904, 51.15605838596821, 50.9981844574213, 47.6270167529583, 49.82935197651386, 46.80365793406963, 45.65143056213856, 40.60509614646435, 44.435647800564766, 42.76541702449322, 40.38777060806751, 40.808978006243706, 41.819400787353516, 41.8531733751297, 43.102189153432846, 43.79670448601246, 50.55966138839722, 46.68265342712402, 41.316516771912575, 43.86684492230415, 42.12008245289326, 42.22812965512276, 42.20247343182564, 42.945683151483536, 45.25421507656574, 49.385330602526665, 51.389430463314056, 53.449284732341766, 55.55721402168274, 48.996565863490105, 45.03960259258747, 52.023890018463135, 54.610396027565, 54.93911638855934, 51.03386454284191, 48.04259665310383, 43.53137232363224, 41.64986528456211, 41.79145708680153, 42.090075463056564, 41.72496825456619, 44.63074453175068, 41.7495833337307, 43.927060291171074, 40.258596539497375, 43.88849996030331, 44.35317322611809, 42.12966553866863, 41.83452397584915, 46.126716658473015, 45.36986567080021, 49.20545965433121, 46.77285298705101, 54.76760499179363, 55.56049324572086, 60.136960074305534, 55.68448059260845, 57.672564312815666, 50.69763198494911, 52.98490785062313, 45.8600165694952, 40.8896628767252, 29.67288326472044, 28.932637386024, 22.042470909655094, 29.346406683325768, 21.362740583717823, 16.308893971145153, 28.976171649992466, 16.312961652874947, 12.933460045605898, 20.709040760993958, 12.40291541442275, 16.694605574011803, 9.483313579112291, 1.5044940006919205, 1.1667271563783288, 0.6966725480742753, 7.675308845937252, 15.065599735826254, 27.088932618498802, 33.26973795890808, 50.463412553071976, 45.16143545508385, 47.45547495782375, 52.633947283029556, 59.46930170059204, 42.68429897725582, 19.904832914471626, 3.314979407005012, 0.32543125154916197, 0.1113561938109342, 0.15488648728933185, 0.22121238842373714, 0.11245067609706894, 0.16220091667491943, 0.16039775015087798, 0.14874818385578692, 0.1187772698176559, 0.11472558879177086, 0.15971044718753546, 0.2830737072508782, 0.20661646616645157, 0.16938048298470676, 0.1428388775093481, 0.12688009010162205, 0.09908550186082721, 0.1474361409782432, 0.11765170638682321, 0.1693273600540124, 0.15234412683639675, 0.19177600624971092, 0.11294964424450882, 0.15685777994804084, 0.19643826701212674, 0.23741057782899588, 0.172058567404747, 0.12860441085649654], [0.05672331542882603, 0.03198731814336497, 0.009786668942979304, 0.025999592762673274, 0.058429275450180285, 0.026408555095258635, 0.08129175432259217, 0.061611374621861614, 0.025362277156091295, 0.04269496173947118, 0.09430129881366156, 0.055477186397183686, 0.028520232408482116, 0.07822938583558425, 0.008551251885364763, 0.031514473594143055, 0.024540777194488328, 0.08097825630102307, 0.025750821150722913, 0.038831218480481766, 0.02974186500068754, 0.013293710981088225, 0.12018666762742214, 0.016894906511879526, 0.05620192700007465, 0.06977138851652853, 0.06799679467803799, 0.05628157057799399, 0.06328388233669102, 2.0054815616458654, 11.196574196219444, 32.828935012221336, 44.08678092062473, 38.99889953434467, 23.20181529968977, 17.227924056351185, 20.32418981194496, 23.862639740109444, 20.460511296987534, 12.960210610181093, 8.301971219480038, 2.5388508662581444, 0.7344657357316464, 0.24252024973975495, 0.9623453265521675, 1.7155919107608497, 4.456032766029239, 13.119288124144077, 9.272733628749847, 5.463341139256954, 2.747791917063296, 8.858352564275265, 9.330575075000525, 9.681856725364923, 17.677780017256737, 27.920502796769142, 43.805242627859116, 45.52840456366539, 46.42622418701649, 43.786574229598045, 45.514550507068634, 47.51388542354107, 48.908114209771156, 48.999943882226944, 45.20661883056164, 41.56846225261688, 38.409855142235756, 36.35065443813801, 38.079170286655426, 37.08789847791195, 39.060137048363686, 41.96978531777859, 42.99463972449303, 44.73953269422054, 41.7284070700407, 37.60119393467903, 37.28151708841324, 37.93793946504593, 39.39320057630539, 39.56441178917885, 41.87662951648235, 42.31402784585953, 46.078463047742844, 47.71626636385918, 50.437402948737144, 50.85774779319763, 53.57749365270138, 44.49936658143997, 35.26127189397812, 50.01138120889664, 51.145122572779655, 49.30719539523125, 46.39890745282173, 42.63036847114563, 39.183926805853844, 37.63276644051075, 36.887459233403206, 37.32925392687321, 38.307963609695435, 38.03261138498783, 37.29805760085583, 37.49364070594311, 37.79012359678745, 38.479235619306564, 37.60275945067406, 39.644484892487526, 38.28507363796234, 37.8711998462677, 38.04876051843166, 38.76915246248245, 43.27560044825077, 45.112786665558815, 47.21445769071579, 50.87854407727718, 53.01971398293972, 55.466357097029686, 52.86122828722, 50.5918874591589, 42.40630589425564, 36.27043314278126, 27.359328009188175, 18.796027712523937, 14.65848483145237, 17.542889155447483, 15.022978372871876, 7.054149052128196, 8.152180407196283, 16.28748022019863, 16.30640510469675, 4.845353700220585, 3.8363382685929537, 2.709695636294782, 0.7541422673966736, 1.4864809485152364, 0.6678522820584476, 1.0593160637654364, 3.979339557699859, 17.61374205350876, 24.968933276832104, 36.84453293681145, 26.242642030119896, 27.500422038137913, 34.87218037247658, 47.835743352770805, 43.856289088726044, 32.07342155277729, 9.475729186087847, 0.9726307808887213, 0.0517474230582593, 0.026716162319644354, 0.007855562653276138, 0.010356347993365489, 0.030906777101336047, 0.05346880490833428, 0.06476414040662348, 0.0559061663079774, 0.01956498686922714, 0.09278035620809533, 0.04169015686784405, 0.02850674016372068, 0.03724800226336811, 0.006502147361970856, 0.004287714600650361, 0.024103765390464105, 0.03511780465487391, 0.008934375418903073, 0.02315991310751997, 0.009110824739764212, 0.007912187593319686, 0.005719794298784109, 0.05330345069523901, 0.06251544778933749, 0.03334274697408546, 0.01064129837686778, 0.04135083581786603, 0.12045700234011747, 0.061802470227121376, 0.02040834864601493, 0.008188821284420555, 0.0420850239606807, 0.08423888211837038, 0.00482700548673165, 0.05550057518121321, 0.06823062314651906, 0.05628114384307992, 0.0700713497644756, 0.0353523158992175, 0.07469820266123861, 0.06651523042819463, 0.14355801860801876, 0.068039505276829, 0.04998577598598786, 0.025621041786507703, 0.032399803822045214, 0.02108352677169023, 0.02270351084007416, 0.05276144540403038, 0.034864877015934326, 0.04192778513242956, 0.023348823087872006, 0.07320453398278914, 0.060267564113019034, 0.040890333184506744, 0.01327175268670544, 0.017121484197559766, 2.3936022352427244, 14.492019563913345, 39.184055998921394, 49.942015931010246, 45.378042832016945, 29.295702204108238, 23.800579570233822, 25.059032142162323, 25.421046316623688, 26.44781582057476, 15.754172187298536, 9.263735711574554, 3.031479469500482, 0.7274746452458203, 0.3486773354234174, 1.47506671724841, 2.1896315552294254, 3.436478362418711, 4.86027929931879, 9.838743656873703, 8.973630778491497, 5.149863660335541, 7.881790716201067, 9.399559423327446, 13.384784627705812, 18.04993774741888, 29.973639026284218, 46.65505550801754, 49.636394530534744, 50.223341435194016, 45.74914611876011, 48.63274298608303, 49.93646822869778, 49.91268910467625, 49.18662786483765, 45.65371423959732, 43.471582531929016, 41.15809567272663, 38.384282514452934, 40.13071060180664, 38.79760153591633, 40.573212057352066, 42.3473596572876, 44.72732774913311, 45.59714287519455, 44.23817239701748, 40.90611979365349, 39.52297501266003, 40.334383472800255, 40.37915647029877, 41.02879241108894, 42.806747406721115, 43.71174484491348, 47.598613277077675, 48.82030092179775, 52.6633121073246, 53.68266820907593, 54.292094707489014, 46.52127608656883, 38.64354260265827, 50.77157981693745, 54.211136251688, 51.848012655973434, 48.15642334520817, 44.32932570576668, 40.3704359382391, 39.60547998547554, 37.452880293130875, 38.65534096956253, 39.56690825521946, 40.00171512365341, 39.475260972976685, 39.81666125357151, 40.6616485118866, 39.22178417444229, 38.13200645148754, 40.53468592464924, 39.441499784588814, 38.70495490729809, 38.7812814116478, 41.19161367416382, 44.38642144203186, 47.64414623379707, 51.49359807372093, 54.17238973081112, 54.23358544707298, 55.51077291369438, 54.13024999201298, 48.72916281223297, 44.06565025448799, 35.93402959406376, 28.372425846755505, 23.32105290144682, 18.53987205773592, 13.261123113334179, 14.783979747444391, 11.335006467998028, 12.199304290115833, 14.018345531076193, 10.255534742027521, 12.027323618531227, 6.467331340536475, 1.8676872993819416, 1.9795068679377437, 0.9366500959731638, 0.2808447409188375, 1.344953030347824, 5.181682202965021, 17.947702333331108, 27.05005880445242, 34.64105777442455, 34.60365258157253, 36.434341147542, 41.368418186903, 52.87570171058178, 50.44183351099491, 36.29503682255745, 11.969043295830488, 1.4581905165687203, 0.12304572475841269, 0.026090186729561538, 0.05226162749750074, 0.01357773089694092, 0.004066886704094941, 0.07572568385512568, 0.023023446992738172, 0.04594081881805323, 0.05907469159865286, 0.09974224318284541, 0.030141546776576433, 0.05009290871385019, 0.03282533274614252, 0.024621059019409586, 0.036731497166329063, 0.016156452875293326, 0.021195993685978465, 0.01031984545988962, 0.043464082773425616, 0.034870925519498996, 0.04794764921825845, 0.01948167151567759, 0.030205970761016943, 0.02133263977157185, 0.04308625910198316, 0.019141352277074475, 0.01032257656333968, 0.09813251745072193, 0.14937816333258525, 0.0708485119685065, 0.06523778647533618, 0.13526503782486543, 0.14332468737848103, 0.12345757219009101, 0.20282462588511407, 0.13823961024172604, 0.13571461604442447, 0.13972809130791575, 0.18999157153302804, 0.1191644482605625, 0.17582456610398367, 0.26875206793192774, 0.12518201168859378, 0.2334227808751166, 0.11185897659743205, 0.2138410066254437, 0.10816160429385491, 0.12063551854225807, 0.08589760444010608, 0.10421443250379525, 0.23331815289566293, 0.07712538921623491, 0.23199229122838005, 0.1941664342302829, 0.15727173507912084, 0.1096330233849585, 0.22368791105691344, 3.423014972358942, 17.746672220528126, 44.466251358389854, 57.49792568385601, 53.41766282916069, 34.84719291329384, 29.677853398025036, 32.47021526098251, 33.88930231332779, 30.541767440736294, 19.140085950493813, 12.19730369746685, 3.7330298870801926, 1.4678567228838801, 1.0862164827995002, 3.090283451601863, 5.539809660986066, 10.495116636157036, 24.155885204672813, 16.13921407610178, 14.159462358802557, 8.567386977374554, 14.85213479027152, 12.60894700884819, 13.134862538427114, 21.691375449299812, 31.62081453949213, 49.94174234569073, 51.311420649290085, 52.05794759094715, 48.50377790629864, 51.25257320702076, 53.898443430662155, 53.778434470295906, 54.07798379659653, 49.16425086557865, 47.569518238306046, 43.75005438923836, 40.81424452364445, 41.97112284600735, 40.30978739261627, 42.194049283862114, 46.75193130970001, 46.23537942767143, 47.87039369344711, 44.123939126729965, 42.57369451224804, 39.99289579689503, 42.438630759716034, 43.73252592980862, 43.38924095034599, 45.051336362957954, 46.36623300611973, 49.90557588636875, 53.8760170340538, 54.74440723657608, 55.9135664999485, 54.736161679029465, 49.230481311678886, 44.631968066096306, 50.41734002530575, 57.259591072797775, 55.27496516704559, 50.24810090661049, 46.227749437093735, 43.2386664301157, 42.39108771085739, 39.502102732658386, 41.305968537926674, 41.49178236722946, 42.97897316515446, 40.7031536847353, 42.0994533598423, 42.41397388279438, 41.970837861299515, 40.102854296565056, 44.28068071603775, 43.005434945225716, 41.47353574633598, 42.225169613957405, 43.02964724600315, 46.274999901652336, 49.56970430910587, 52.785289362072945, 56.947821602225304, 58.09684954583645, 56.64783909916878, 55.064832642674446, 50.78536547720432, 44.510773569345474, 37.329063937067986, 30.602583177387714, 21.23074136674404, 22.029986679553986, 22.636819817125797, 19.034425020217896, 16.10316351056099, 17.804398722946644, 25.589128397405148, 28.25013130903244, 17.85540148615837, 7.707213833928108, 8.467407692223787, 2.9030929086729884, 2.1433436265215278, 0.9660542837809771, 2.338596861809492, 5.4239847511053085, 23.772388882935047, 32.96222046017647, 49.227487072348595, 37.79909111559391, 39.800671711564064, 48.18463683128357, 62.55731239914894, 54.962435737252235, 43.18580746650696, 14.773687049746513, 2.8531483886763453, 0.16024843003833666, 0.08466017708997242, 0.21570131852058694, 0.09744835377205163, 0.08742325968341902, 0.18129281408619136, 0.26500448933802545, 0.13710047292988747, 0.21785902383271605, 0.25446008483413607, 0.11259301259997301, 0.15686738333897665, 0.14377022831467912, 0.10549065191298723, 0.15348359069321305, 0.13588361791335046, 0.12830124353058636, 0.08327915158588439, 0.1318855644785799, 0.2089758575311862, 0.12906357762403786, 0.14963610417908058, 0.11272872914560139, 0.24416753556579351, 0.17722468706779182, 0.12013355211820453, 0.12526056059869006, 0.18377461528871208], [0.026637798946467228, 0.054855556081747636, 0.013453317260427866, 0.016998942628561053, 0.020653698957175948, 0.02022380806010915, 0.038882834851392545, 0.05167779105249792, 0.04833603736187797, 0.12344790942734107, 0.07133742401492782, 0.05415208914200775, 0.08223091994295828, 0.07854106559534557, 0.10722663922933862, 0.02779188125714427, 0.03001416083861841, 0.08061990287387744, 0.030741194677830208, 0.0650064367800951, 0.04328933668148238, 0.04379097656055819, 0.032987202575895935, 0.03436076578509528, 0.047270198265323415, 0.012365327838779194, 0.06839104578830302, 0.11910431945580058, 0.059385814747656696, 1.1820865259505808, 8.862880021333694, 25.17345730215311, 45.36563649773598, 37.813062965869904, 30.796906650066376, 30.075541958212852, 29.482148699462414, 27.786586582660675, 21.6113156452775, 14.684332944452763, 6.688796756789088, 3.7774359667673707, 0.885742090176791, 0.4010418802499771, 0.9962712717242539, 1.143886938225478, 1.8938274029642344, 2.8971961000934243, 6.697469316422939, 7.904979446902871, 2.9510819585993886, 7.57831335067749, 9.095402844250202, 9.038570243865252, 14.585764333605766, 26.065334044396877, 43.990619480609894, 48.470932468771935, 44.61307168006897, 43.927326276898384, 48.74421000480652, 52.66436085104942, 53.684123530983925, 50.5123957246542, 51.32774077355862, 48.57528626918793, 45.359279438853264, 40.131785944104195, 39.373901411890984, 38.38281959295273, 40.44882953166962, 40.768304988741875, 44.50261540710926, 43.81598845124245, 42.015018090605736, 37.319674640893936, 38.307826817035675, 38.46201874315739, 42.91694909334183, 45.543159171938896, 45.39719000458717, 46.821478977799416, 48.25621359050274, 48.55741582810879, 53.07201437652111, 51.39148235321045, 48.58694024384022, 36.27385675907135, 38.52090038359165, 53.737066090106964, 51.692262813448906, 49.15872596204281, 47.02907703816891, 43.27831730246544, 38.10294561088085, 36.97662904858589, 38.779495507478714, 38.03516864776611, 39.43684123456478, 38.42831835150719, 39.836678579449654, 40.01136280596256, 38.31341251730919, 38.588270768523216, 43.50819356739521, 43.55653457343578, 41.05978734791279, 38.83865833282471, 39.69876118004322, 38.55458937585354, 41.80896274745464, 43.36178742349148, 46.694934368133545, 47.97434091567993, 53.42920280992985, 53.23032908141613, 55.5201356112957, 45.96927210688591, 44.185431227087975, 33.764725998044014, 25.599982514977455, 19.554683603346348, 15.855652391910553, 3.0627563036978245, 15.133737679570913, 7.801599819213152, 9.827516209334135, 10.829758029431105, 4.088422916829586, 9.35766002163291, 7.441103188320994, 0.9851303289178759, 0.5690964718814939, 1.2137473770417273, 0.09477775762206875, 2.137380796484649, 3.3902251068502665, 14.766755271703005, 28.234050571918488, 33.85651767253876, 28.621705770492554, 26.450184993445873, 32.88423344492912, 46.26615397632122, 44.493005722761154, 26.731626391410828, 12.608182299882174, 0.7662751944735646, 0.031887651421129704, 0.08488941166433506, 0.03720303553564008, 0.013883363080822164, 0.06976406351896003, 0.025330233074782882, 0.04970486195816193, 0.03164079083944671, 0.04129533059312962, 0.025253246385545935, 0.07184863759903237, 0.039720348504488356, 0.038621691637672484, 0.04989668115740642, 0.03559255652362481, 0.05889569300052244, 0.03599027717427816, 0.07262489438289776, 0.017178162015625276, 0.10448495275340974, 0.03783137115533464, 0.020233817776897922, 0.040235963024315424, 0.016364599323424045, 0.05178608153073583, 0.004808565900020767, 0.031125834975682665, 0.045605638952110894, 0.016425640969828237, 0.07603127058246173, 0.023049147566780448, 0.04227629768138286, 0.04262095106241759, 0.025002958936966024, 0.030875918600941077, 0.02990856250107754, 0.053615323413396254, 0.1051818071573507, 0.0317966232978506, 0.02616126963403076, 0.06099547739722766, 0.015626466665707994, 0.06537285735248588, 0.021913719137955923, 0.09191412143991329, 0.025159249671560246, 0.029536740948969964, 0.033941871661227196, 0.03026658196176868, 0.03335029832669534, 0.04809531805221923, 0.01381936954203411, 0.029073078621877357, 0.07233325261040591, 0.04532718514383305, 0.08728393630008213, 0.012757389613398118, 1.4610998542048037, 10.702908486127853, 31.471488252282143, 50.33255137503147, 45.6627881526947, 34.69341516494751, 32.194695845246315, 30.655559934675694, 33.07965695858002, 25.64441353082657, 16.84950616210699, 8.737127669155598, 3.394937803968787, 1.133725333493203, 0.14925351220881566, 1.7317427066154778, 1.836112537421286, 6.14913783967495, 3.8255371106788516, 5.065165255218744, 9.219044409692287, 4.623804688453674, 5.932566085830331, 7.621666649356484, 10.703697893768549, 16.583345644176006, 30.164998658001423, 46.425502225756645, 50.3671333193779, 47.620180919766426, 46.89664274454117, 50.75904808938503, 53.86952318251133, 55.81433862447739, 53.67935098707676, 54.934856817126274, 50.41234329342842, 45.4837341606617, 41.63343496620655, 40.177208706736565, 39.740688130259514, 41.25144526362419, 43.01112323999405, 46.138173043727875, 45.9915617108345, 42.91230954229832, 39.56946551799774, 40.19539453089237, 40.4362104088068, 44.032090455293655, 47.79309444129467, 47.710194289684296, 48.76889728009701, 50.50600066781044, 50.85554391145706, 54.4962577521801, 54.42994751036167, 51.13155350089073, 40.097279995679855, 41.108139753341675, 54.216026589274406, 53.833941891789436, 51.17262929677963, 49.02183450758457, 44.64446559548378, 40.67103400826454, 39.67714414000511, 40.22143453359604, 41.06533885002136, 41.068557277321815, 40.88189609348774, 40.27930922806263, 41.38748176395893, 40.22430717945099, 40.51293969154358, 44.7008203715086, 46.231686025857925, 43.90822850167751, 41.35725058615208, 41.179252937436104, 40.47420836985111, 41.98187626898289, 45.1916666328907, 48.92817713320255, 50.095698684453964, 55.50323411822319, 55.50352290272713, 55.35357154905796, 48.93382743000984, 42.76697114109993, 35.32909445464611, 26.257675923407078, 20.305346623063087, 16.15182749927044, 9.297939576208591, 17.300591357052326, 17.1362691745162, 12.917377408593893, 14.193727970123291, 10.274023599922657, 11.64590958505869, 10.117313358932734, 3.32797993440181, 2.5642636651173234, 1.1494133854284883, 0.15481314825592563, 1.78605129243806, 3.9087312715128064, 16.716737486422062, 28.105516768991947, 37.079945504665375, 32.04108528792858, 31.04738350957632, 41.22926585376263, 52.93419577181339, 52.41859383881092, 32.249302715063095, 13.688558377325535, 1.1830243631266057, 0.06544698306242935, 0.0973056090879254, 0.037317508104024455, 0.03548416956618894, 0.04613243021594826, 0.06942424151930027, 0.03896638583682943, 0.06729776578140445, 0.08296409505419433, 0.045405366690829396, 0.08371916352189146, 0.026566476699372288, 0.02185309123888146, 0.03643126132374164, 0.03475331737718079, 0.014973743145674234, 0.037920603281236254, 0.05995051862555556, 0.014879873524478171, 0.023892878562037367, 0.024369303973799106, 0.06443272694014013, 0.049260757077718154, 0.0660019091446884, 0.022242464583541732, 0.019450659019639716, 0.0667232544219587, 0.0057461238429823425, 0.0883001962210983, 0.17468680918682367, 0.09850510527030565, 0.07916774251498282, 0.20511001028353348, 0.10704535481636412, 0.18019367853412405, 0.13740836031502113, 0.10674751611077227, 0.2199363397085108, 0.1952784089371562, 0.15149344748351723, 0.08924687979742885, 0.16512790258275345, 0.17156728048576042, 0.12624791386770085, 0.19841948960674927, 0.21896515041589737, 0.11666441248962656, 0.19531299301888794, 0.11522791144670919, 0.13883046369301155, 0.14274134446168318, 0.10018458546255715, 0.1704709354089573, 0.16485687025124207, 0.11431407532654703, 0.24477787781506777, 0.12849378632381558, 1.7461786069907248, 13.209430687129498, 36.42212100327015, 58.0882316082716, 51.36977791786194, 44.15364593267441, 45.556089878082275, 41.3628438860178, 40.20645193755627, 30.957126952707767, 21.72293085604906, 10.184469055384398, 5.285796141251922, 1.781575488857925, 1.2786836363375187, 4.682954214513302, 5.291871540248394, 8.783881310373545, 6.633393354713917, 13.564765769988298, 14.389214180409908, 9.954986069351435, 15.540716741234064, 14.456508569419384, 13.915126919746399, 18.019685670733452, 31.312062107026577, 51.142352521419525, 53.95200155675411, 49.79441665112972, 50.03135673701763, 54.252048656344414, 56.58290058374405, 58.49395103752613, 55.39881572127342, 58.57773654162884, 54.866642877459526, 49.74906988441944, 44.69952084124088, 43.26608195900917, 40.955175161361694, 44.825020506978035, 44.80239272117615, 48.02055023610592, 47.99032285809517, 45.74567690491676, 42.254032865166664, 42.468208372592926, 42.18725524842739, 47.37651139497757, 49.95807766914368, 51.34156823158264, 51.1465322971344, 53.04771088063717, 53.47542352974415, 56.92982956767082, 56.16173878312111, 50.0092039257288, 44.92160752415657, 45.575803220272064, 55.55363841354847, 55.79065829515457, 53.07630054652691, 51.96189634501934, 47.20669090747833, 42.53375865519047, 40.2471249550581, 42.123441472649574, 42.37602911889553, 44.12339195609093, 41.41740135848522, 42.39457592368126, 42.34327867627144, 41.99169874191284, 43.339000046253204, 48.153368309140205, 48.84886018931866, 46.48701712489128, 42.856414541602135, 44.49361369013786, 42.36233465373516, 45.33350542187691, 46.295108422636986, 51.531478241086006, 52.505928352475166, 59.38902720808983, 58.71650129556656, 58.09318274259567, 47.6773526519537, 45.08621849119663, 35.850897654891014, 28.973829075694084, 21.743824034929276, 20.61270073056221, 6.046357154846191, 24.750427901744843, 19.17026773095131, 18.063541017472744, 21.439524963498116, 12.3016413487494, 16.21767606586218, 12.135993037372828, 3.7750133592635393, 4.30156440474093, 2.3716337140649557, 0.31878612062428147, 3.2364625576883554, 4.8606768529862165, 20.16981739550829, 39.727696627378464, 42.12685368955135, 42.260112538933754, 37.81851567327976, 46.94668985903263, 58.08560594916344, 60.87669678032398, 37.84654676914215, 17.822576947510242, 1.647671980317682, 0.18629206926561892, 0.15837299317354336, 0.1570084656123072, 0.1081927893392276, 0.16420695668784901, 0.09374714456498623, 0.26565740117803216, 0.13790282362606376, 0.14601225644582883, 0.1625749294180423, 0.2052338153589517, 0.17697210452752188, 0.12358730702544563, 0.15022568113636225, 0.14445062930462882, 0.17250385601073503, 0.16027306934120134, 0.19791715953033417, 0.06404332947568037, 0.1958871481474489, 0.09223264380125329, 0.2082984845037572, 0.09780586115084589, 0.18829899985576048, 0.18646838871063665, 0.09564635984133929, 0.11425888180383481, 0.10175547460676171], [0.03632705265772529, 0.02933913485321682, 0.011115055767731974, 0.03276528186688665, 0.02710599950660253, 0.05016664108552504, 0.09026944797369651, 0.10799016075907275, 0.01829214052122552, 0.022455236467067152, 0.047454373343498446, 0.032795349980005994, 0.015533831792708952, 0.06453717680415139, 0.015462531810044311, 0.02377832992351614, 0.034687826555455104, 0.05319568714185152, 0.03895797359291464, 0.030102162854745984, 0.020778370490006637, 0.007312417237699265, 0.06448876651120372, 0.07963093172293156, 0.053699635100201704, 0.03906292811734602, 0.030642648598586675, 0.021282615307427477, 0.05816522672830615, 0.3802883141906932, 6.676828823983669, 21.155830286443233, 36.196409314870834, 46.48169741034508, 35.12551657855511, 25.987873300909996, 24.862575083971024, 22.33162399381399, 20.612714029848576, 12.726411055773497, 10.213659089058638, 4.958239942789078, 2.165506649762392, 0.1239132285991218, 0.537858169991523, 0.9323732473421842, 2.215569675900042, 3.0531774926930666, 6.79218920879066, 6.816943930462003, 2.7359175542369485, 3.2159063732251525, 4.531953167170286, 8.795955162495375, 10.948445610702038, 25.69840483367443, 41.24949596822262, 45.76880246400833, 46.0607597976923, 43.58043909072876, 45.652285516262054, 52.308012172579765, 53.512087762355804, 54.368664398789406, 52.10254579782486, 51.15424208343029, 48.60850028693676, 45.015131905674934, 43.77750411629677, 45.04191666841507, 45.11519193649292, 46.06485217809677, 47.23285250365734, 44.89510394632816, 40.763992220163345, 35.798316076397896, 37.04890497028828, 43.010690063238144, 48.163889944553375, 49.16580878198147, 49.00652892887592, 48.811660185456276, 49.61586803197861, 51.87613494694233, 53.285410925745964, 51.183306723833084, 41.31615959107876, 37.11176499724388, 37.16552451252937, 50.673761665821075, 50.97980484366417, 47.96769507229328, 45.63991338014603, 41.43474742770195, 38.40489640831947, 37.84154623746872, 37.44581267237663, 36.93267300724983, 37.42945075035095, 37.66544468700886, 38.00500586628914, 39.67672236263752, 38.750803247094154, 46.88993990421295, 47.48043201863766, 50.27635999023914, 45.82083687186241, 42.935564294457436, 41.16968885064125, 39.97946351766586, 39.862885773181915, 43.209901973605156, 44.44569066166878, 47.06387557089329, 46.65841452777386, 51.0762170702219, 53.690742775797844, 49.135011434555054, 39.86453868448734, 33.47011260688305, 23.157564774155617, 21.367216743528843, 12.205661348998547, 13.99117223918438, 17.133254036307335, 15.582675989717245, 12.689101807773113, 13.128353487700224, 10.631104689091444, 13.872742094099522, 14.046011846512556, 1.8800805718638003, 3.5668612411245704, 0.8529350068420172, 0.36556585575453937, 1.2453467189334333, 6.519897719845176, 12.51133594661951, 23.536786325275898, 31.221908144652843, 30.57541463524103, 31.13625694066286, 28.88910312205553, 41.360560208559036, 42.08340682089329, 24.565343633294106, 14.633342530578375, 1.6975085623562336, 0.0048488343691133196, 0.036843880589003675, 0.03843117861833889, 0.06991208487306722, 0.015874468299443834, 0.011167065476911375, 0.06138472272141371, 0.02674652172572678, 0.04933931340929121, 0.011292160961602349, 0.10840114729944617, 0.0779994016920682, 0.07520175728132017, 0.0756280988571234, 0.014294075954239815, 0.03455234007560648, 0.039052204083418474, 0.05099778340081684, 0.00505926245750743, 0.06298765409155749, 0.03352972365973983, 0.04001667693955824, 0.02261427685880335, 0.08002481175935827, 0.0399505330278771, 0.038777535228291526, 0.05811998911667615, 0.08264005111414008, 0.027603765374806244, 0.04552455931843724, 0.04595626662194263, 0.1231183810159564, 0.06595047831069678, 0.0342751330754254, 0.0558974460727768, 0.019126861843687948, 0.032650067150825635, 0.03342424221045803, 0.005529297513930942, 0.061520235176431015, 0.06742475467035547, 0.07184162430348806, 0.007843337625672575, 0.04298403568100184, 0.031515449518337846, 0.009101457908400334, 0.02558353364292998, 0.11579821482882835, 0.02229056874057278, 0.08620936583611183, 0.14218476339010522, 0.043573801885941066, 0.012310349538893206, 0.07616179209435359, 0.015748147343401797, 0.0337236728228163, 0.04674075753428042, 0.41397715802304447, 9.673585519194603, 24.667843133211136, 44.73729461431503, 50.77537201344967, 40.73247291147709, 34.396031722426414, 34.10313583910465, 30.093053318560123, 26.781211830675602, 17.51329254359007, 11.324201747775078, 5.434563858434558, 2.135922387242317, 0.43251446331851184, 1.1078855325467885, 2.4683024268597364, 5.197570100426674, 6.009273519739509, 6.762311412021518, 9.614874869585037, 5.924855824559927, 4.485790869221091, 5.82179537974298, 10.445211064070463, 16.17671426385641, 29.836876764893532, 44.744601622223854, 49.224485233426094, 47.838479205965996, 46.938007324934006, 48.619128316640854, 53.46582144498825, 53.946146070957184, 54.2102774977684, 54.21698793768883, 52.083368226885796, 49.33493010699749, 47.33335331082344, 46.19197055697441, 46.52086190879345, 46.92519821226597, 47.87332333624363, 48.32516849040985, 47.05655716359615, 42.6002436876297, 38.265174105763435, 38.14426079392433, 44.19251024723053, 49.586256220936775, 50.54279029369354, 50.45817643404007, 50.78373536467552, 52.39727318286896, 54.286615401506424, 54.03347298502922, 52.29788191616535, 44.148284420371056, 39.58798572421074, 40.94940707087517, 51.72640398144722, 54.59472946822643, 49.557107985019684, 47.45386764407158, 44.54618386924267, 39.86319735646248, 40.0251180678606, 39.637512266635895, 38.91100265085697, 40.12752637267113, 38.66261377930641, 39.4159309566021, 42.64447331428528, 40.58922439813614, 46.70903921127319, 49.781683534383774, 51.9493418186903, 49.449714347720146, 44.83374483883381, 43.404557928442955, 42.88350708782673, 42.73860186338425, 43.98529216647148, 46.17302857339382, 49.85035724937916, 49.30699780583382, 53.97009998559952, 55.54513826966286, 50.98769702017307, 40.396802723407745, 33.86543959379196, 24.887796230614185, 19.86304845660925, 13.614165019243956, 13.046960905194283, 8.107709493488073, 13.441488035023212, 12.310006599873304, 10.333740245550871, 9.148429948836565, 7.967220107093453, 7.801333358511329, 3.4334188140928745, 2.6447160355746746, 0.4411278589395806, 0.29903495858889073, 1.3562681106850505, 7.025813972577453, 15.475182607769966, 31.213529594242573, 39.42446909844875, 37.92389161884785, 33.75882491469383, 33.82518835365772, 47.478748708963394, 49.19463023543358, 31.26040767878294, 16.21206756681204, 2.17489262111485, 0.03458923223661259, 0.02862210702005541, 0.02474193817761261, 0.013785158389509888, 0.08046866802033037, 0.03329183564346749, 0.004726122106148978, 0.06901928121806122, 0.029214223977760412, 0.04141742501815315, 0.033238222895306535, 0.13199143926613033, 0.0625359384866897, 0.07938347000163049, 0.019358315439603757, 0.04824563264264725, 0.02931297043687664, 0.06023710266163107, 0.011832695872726617, 0.07086131401592866, 0.04760734853334725, 0.02688086715352256, 0.013006464578211308, 0.0655779053340666, 0.012573764652188402, 0.008989055004349211, 0.015418730254168622, 0.06473555287811905, 0.10266094672260806, 0.08808665064861998, 0.11616163712460548, 0.20820975332753733, 0.1743583643110469, 0.18022505653789267, 0.18260610377183184, 0.19981408899184316, 0.1291130788740702, 0.1128835188865196, 0.09153304345090874, 0.1363239935017191, 0.1233786522061564, 0.1696178811835125, 0.15097761031938717, 0.16936561034526676, 0.12256238624104299, 0.09454906481551006, 0.15423397620907053, 0.18249423243105412, 0.12285379794775508, 0.2106779138557613, 0.24359861999982968, 0.10326324409106746, 0.09649721730966121, 0.15314065909478813, 0.16984543850412592, 0.14263873512391, 0.1765954794245772, 0.7721393485553563, 11.35475305840373, 32.2519625723362, 49.04163904488087, 62.11387239396572, 47.22092114388943, 39.063454270362854, 37.71525241434574, 33.419677913188934, 31.842973418533802, 20.98933082073927, 15.697946604341269, 7.248924225568771, 3.063334347680211, 0.5548574484419078, 2.2622717823833227, 4.828221844509244, 9.834901113063097, 11.33236275985837, 17.494287863373756, 16.260961443185806, 9.100012946873903, 7.487441701814532, 8.95894456654787, 13.442799914628267, 15.762606784701347, 30.798502564430237, 46.95384107530117, 52.87701264023781, 51.019854694604874, 50.10829500854015, 51.80115357041359, 57.13931232690811, 56.23463027179241, 56.595177724957466, 55.31944938004017, 56.90564386546612, 52.28435464203358, 49.14977744221687, 48.787588477134705, 50.924483612179756, 49.780577793717384, 50.96358351409435, 50.00625528395176, 48.48143510520458, 44.35260705649853, 40.30477546155453, 40.593723356723785, 48.603815138339996, 52.50596635043621, 53.7923227250576, 53.0776646733284, 52.994266748428345, 53.803285136818886, 56.60569176077843, 54.30669732391834, 53.680076748132706, 46.61646477878094, 42.002402767539024, 45.86016856133938, 54.63719218969345, 56.953232511878014, 53.00813600420952, 50.54415822029114, 45.989437624812126, 42.0348834246397, 41.689588353037834, 41.32361479103565, 39.010040536522865, 40.450843423604965, 42.1503896266222, 41.707622185349464, 43.17799508571625, 43.00446979701519, 51.23668245971203, 53.09408739209175, 54.37369152903557, 51.13764837384224, 47.36166179180145, 45.70132948458195, 43.99185821413994, 45.33100135624409, 46.64476566016674, 48.24296370148659, 52.73923583328724, 52.47711829841137, 57.86629691720009, 57.825612500309944, 53.04980456829071, 40.92780902981758, 35.109375044703484, 25.72043225169182, 26.735610477626324, 14.557266812771559, 19.939811937510967, 23.9341614022851, 23.11829198151827, 21.299627870321274, 27.41685312241316, 24.015579633414745, 21.751020848751068, 23.36326103657484, 8.107288666069508, 5.8157271053642035, 1.9318085024133325, 0.9266372176352888, 1.8063521781004965, 9.049818590283394, 17.362908013164997, 33.60104978084564, 44.02040608227253, 42.95846946537495, 44.35993306338787, 42.424020543694496, 53.9592819660902, 58.52327786386013, 35.63421428203583, 18.130700513720512, 3.4767395770177245, 0.11515658363350667, 0.1254364792839624, 0.09109726917813532, 0.12408083523041569, 0.1396181940799579, 0.09775288664968684, 0.08730071625905111, 0.13056399242486805, 0.10404856991954148, 0.15090124332346022, 0.1616255592671223, 0.1680828823009506, 0.19000776519533247, 0.14744099462404847, 0.10048946714960039, 0.16986308677587658, 0.10945006913971156, 0.12894275598227978, 0.09327508669230156, 0.33150878793094307, 0.12594091705977917, 0.08165673512849025, 0.13278074300615117, 0.20631080522434786, 0.11980723720625974, 0.10633527534082532, 0.16987781098578125, 0.22329587896820158], [0.05441990797407925, 0.023410161593346857, 0.023490500934713054, 0.05559992277994752, 0.026553164425422437, 0.059670309638022445, 0.00648158801595855, 0.01993918514926918, 0.07551605682238005, 0.04739804433484096, 0.03874167465255596, 0.02186066485592164, 0.06430578258004971, 0.032727309881011024, 0.04926166249788366, 0.03299067211628426, 0.07561556398286484, 0.01872009626822546, 0.06646941765211523, 0.05509759641427081, 0.043248358997516334, 0.03939300571801141, 0.06693394272588193, 0.03718626670888625, 0.01057779094480793, 0.06234364060219377, 0.01592878052179003, 0.029560046241385862, 0.043414941465016454, 0.15088585118064657, 3.4889877447858453, 19.162683337926865, 34.864991158246994, 42.96347379684448, 36.40658363699913, 39.73343051970005, 29.010162726044655, 25.935023836791515, 23.3424324542284, 20.776044465601444, 13.612441811710596, 7.424206444993615, 1.9842301332391798, 0.5048441758845001, 0.9237338171806186, 1.7767425044439733, 5.6824378576129675, 2.7663199603557587, 2.364595541730523, 6.189282685518265, 2.985073747113347, 3.1458568945527077, 2.376601709984243, 7.437269669026136, 14.31169643998146, 28.111184164881706, 40.692054480314255, 51.864743158221245, 46.1535470187664, 42.3244658857584, 45.894226133823395, 48.70229445397854, 54.04046081006527, 54.61553335189819, 52.676702588796616, 53.55371452867985, 51.35989084839821, 49.25598934292793, 46.48871563374996, 46.45956739783287, 46.86144143342972, 47.42469280958176, 47.26584993302822, 44.024243876338005, 38.685108572244644, 37.62776590883732, 38.0984428524971, 45.043542981147766, 46.49323359131813, 53.780284970998764, 48.87814521789551, 52.714647352695465, 51.70637905597687, 51.08625993132591, 49.22977834939957, 47.948232516646385, 51.84795945882797, 41.3310319930315, 38.31375449895859, 46.375534906983376, 50.704030841588974, 46.86729311943054, 45.55006340146065, 41.55384063720703, 37.18117967247963, 36.91834397614002, 38.64119812846184, 37.75181025266647, 37.053559720516205, 38.353222981095314, 37.045317962765694, 36.801124066114426, 41.2190406024456, 49.53376203775406, 50.2917567640543, 51.430916637182236, 49.48625698685646, 48.06799829006195, 43.8679164648056, 43.347207605838776, 41.094813868403435, 43.74311976134777, 42.38223418593407, 47.61740706861019, 48.162218034267426, 48.21804463863373, 50.37334978580475, 47.22899191081524, 39.06259551644325, 29.67556592077017, 21.90770924091339, 14.554575607180595, 12.49978456646204, 11.980166248977184, 7.801433578133583, 16.87254812568426, 11.665275245904922, 6.78150893189013, 7.54061889834702, 7.777034612372518, 6.172996759414673, 4.0182045847177505, 0.5400155042298138, 0.3074058797210455, 0.2118177487864159, 1.3004968408495188, 5.853663319721818, 12.612495068460703, 20.59900626540184, 30.295495055615902, 26.56386349350214, 28.21162797510624, 42.86262720823288, 43.63061919808388, 39.96025174856186, 27.35492404550314, 9.54282883554697, 1.5650030225515366, 0.07500384876038879, 0.025473235655226745, 0.03947361037717201, 0.07218261147500016, 0.045350087821134366, 0.025964743363147136, 0.007732459835096961, 0.01132506407884648, 0.018347792320128065, 0.04405445753945969, 0.012935010599903762, 0.007675053784623742, 0.1266305652097799, 0.031357186526292935, 0.022104974304966163, 0.03255091993196402, 0.06238074798602611, 0.046362800276256166, 0.06465166792622767, 0.017802898219088092, 0.03198335878551006, 0.01308500792220002, 0.0979553371143993, 0.003117933315479604, 0.04910561481665354, 0.07988364042830653, 0.015980667776602786, 0.029690092778764665, 0.015478244931728113, 0.0502675063762581, 0.02635846012708498, 0.052052716637263075, 0.05753849785833154, 0.0042040750213345746, 0.06255156811675988, 0.034712903725448996, 0.05920515744946897, 0.06623625711654313, 0.019132331472064834, 0.02960161022201646, 0.05959654758044053, 0.047815502402954735, 0.06861975343781523, 0.02086236676404951, 0.039790555674699135, 0.06851352984085679, 0.04858428947045468, 0.02649917318194639, 0.0365255511860596, 0.009935227426467463, 0.011100955889560282, 0.009879224035103107, 0.051566810288932174, 0.061739777302136645, 0.017721616350172553, 0.06295108105405234, 0.00834365740956855, 0.17487078759586439, 5.29839389026165, 25.061315819621086, 38.595695570111275, 50.100862607359886, 40.19295126199722, 41.184245869517326, 32.42253541946411, 28.302994072437286, 28.188927993178368, 21.92108642309904, 15.578973088413477, 7.597715584561229, 2.0523681957274675, 0.2636160497786477, 0.7273886748589575, 0.4148550296667963, 3.681984138675034, 5.575962821021676, 8.237085901200771, 8.19856071844697, 6.130811898037791, 4.905186239629984, 5.020970301702619, 8.341542296111584, 16.015762500464916, 30.52770059555769, 43.82380083203316, 53.47815178334713, 49.01793211698532, 45.857345312833786, 48.0747277289629, 52.51857407391071, 55.72635814547539, 55.16185663640499, 53.16782243549824, 54.81463506817818, 54.052950739860535, 51.17684707045555, 48.90989251434803, 48.559334725141525, 47.98326663672924, 49.552263244986534, 49.55916367471218, 45.681243762373924, 40.90774990618229, 39.12464998662472, 39.760747253894806, 47.312477231025696, 49.48511324822903, 54.43995997309685, 49.76196639239788, 53.72005820274353, 51.87869220972061, 51.76546588540077, 50.457443073391914, 49.64625880122185, 51.34383670985699, 44.00856211781502, 41.94856345653534, 47.74215817451477, 53.10666471719742, 49.30451653897762, 48.03978480398655, 42.67483368515968, 38.58006700873375, 39.83519285917282, 39.77258741855621, 39.16629955172539, 37.61665530502796, 38.76609742641449, 39.63450662791729, 38.6725502461195, 42.790841460227966, 51.03275880217552, 53.1106811016798, 53.640631064772606, 51.334325820207596, 50.19414760172367, 46.4959542453289, 45.3089739382267, 42.46934071183205, 44.71215896308422, 44.60806354880333, 48.56485202908516, 49.47690188884735, 51.227528750896454, 52.849475517868996, 49.626173079013824, 40.91724559664726, 31.71475499868393, 23.36802788078785, 16.6843993216753, 12.578975167125463, 8.932188302278519, 6.780951786786318, 12.208139766007662, 11.849805694073439, 10.430681593716145, 10.411439426243305, 5.983376009389758, 4.388209255412221, 2.3034268990159035, 0.917771402746439, 0.26023078768048435, 0.3560872346861288, 1.599248566199094, 6.637237323448062, 16.53367280960083, 25.703238174319267, 32.65037879347801, 31.902407929301262, 37.080150693655014, 44.569548815488815, 49.21810917556286, 46.11257001757622, 30.006702952086926, 12.928914539515972, 1.9544690614566207, 0.039183144908747636, 0.03359712922247127, 0.016819851261971053, 0.030220592925616074, 0.022412151083699428, 0.04957363169523887, 0.02353598716581473, 0.015279590552381705, 0.03592522050894331, 0.028043599195370916, 0.03047075791982934, 0.10867940814932808, 0.05433046062535141, 0.037443075780174695, 0.01767148612998426, 0.11488995223771781, 0.0888244567613583, 0.05419697794422973, 0.03389350218640175, 0.03825252511887811, 0.06319739244645461, 0.01717261075100396, 0.05490788120368961, 0.012140496983192861, 0.018086172276525758, 0.0075291401299182326, 0.040532462153350934, 0.025658995218691416, 0.15030342852696776, 0.12568190752062947, 0.11020141202607192, 0.2659519447479397, 0.1402125504682772, 0.16324557858752087, 0.25777356640901417, 0.07334249923587777, 0.2221735884086229, 0.13255475903861225, 0.13222552748629823, 0.09725381460157223, 0.10855237473151647, 0.12210017666802742, 0.09872248032479547, 0.10457210315507837, 0.15052187227411196, 0.14377122279256582, 0.1328589505283162, 0.11679196541081183, 0.10417757002869621, 0.045410149832605384, 0.12015901520499028, 0.08698343328433111, 0.15387808671221137, 0.1571045143646188, 0.1372110380907543, 0.1427399937529117, 0.16275202069664374, 0.31984166242182255, 6.389818349853158, 29.16423875838518, 47.40184083580971, 56.24275043606758, 48.18342089653015, 53.322705924510956, 40.27952581644058, 39.70199480652809, 35.62855638563633, 29.699464738368988, 19.731484316289425, 9.955610185861588, 3.5797273507341743, 0.9190687956288457, 1.6707756905816495, 4.773419760167599, 11.807190030813217, 9.05066879466176, 9.587854519486427, 16.00250881165266, 9.815191570669413, 9.552107937633991, 8.8742252625525, 11.714895833283663, 17.81810838729143, 32.70691595971584, 45.22755950689316, 56.87387377023697, 52.09776185452938, 47.9721674323082, 50.96806727349758, 54.02006350457668, 57.522643357515335, 56.28938913345337, 54.0117609500885, 55.91920159757137, 56.80220201611519, 54.309425577521324, 51.3949553668499, 50.77332392334938, 51.28075249493122, 53.21117050945759, 52.90270306169987, 47.80384786427021, 43.97806875407696, 42.63976916670799, 43.56817714869976, 48.400263860821724, 52.39917688071728, 58.289377614855766, 53.50404739379883, 55.61533570289612, 52.837323769927025, 53.34509052336216, 49.6197210252285, 51.47542744874954, 49.809767827391624, 47.33192838728428, 45.893025398254395, 48.80234308540821, 55.711485743522644, 51.04137673974037, 50.3763098269701, 45.07472790777683, 40.3021802008152, 41.451789513230324, 42.4492359906435, 41.58221751451492, 39.85954575240612, 40.711562633514404, 41.21100403368473, 40.62561124563217, 45.9296440333128, 54.41594146192074, 56.397698521614075, 55.74432358145714, 54.772932305932045, 53.02553907036781, 49.61128547787666, 48.55867736041546, 45.739418640732765, 46.19550436735153, 47.58323170244694, 51.195785254240036, 53.00577253103256, 52.24785000085831, 56.99693776667118, 50.08485786616802, 43.64589437842369, 32.41615556180477, 26.598846316337585, 17.9190556704998, 15.278111882507801, 18.788439519703388, 16.05226904153824, 25.268115922808647, 23.244103230535984, 14.816412907093763, 17.236819379031658, 19.085275791585445, 11.423194035887718, 7.357784109190106, 2.408497198484838, 1.177434625569731, 0.5100152234081179, 2.5939692836254835, 7.7754914201796055, 19.52685009688139, 29.967110976576805, 41.039511635899544, 40.2454948425293, 42.354852855205536, 55.102484822273254, 57.48344466090202, 53.025789856910706, 37.92312026023865, 14.0902110747993, 2.1938861394301057, 0.19584299036068842, 0.1894336100667715, 0.16618593799648806, 0.1692684186855331, 0.14795760362176225, 0.14082595036597922, 0.07837181881768629, 0.20588343206327409, 0.10561729199253023, 0.15495020808884874, 0.11763031026930548, 0.18143518769647926, 0.2038256940431893, 0.11474470651592128, 0.1302844996098429, 0.19680588244227692, 0.21637582685798407, 0.15827357507077977, 0.11052613132051192, 0.1763315568678081, 0.0882048525090795, 0.10063726585940458, 0.1584968130919151, 0.1774076561559923, 0.09973708525649272, 0.13981590222101659, 0.11718810899765231, 0.1691373108769767], [0.00703396992321359, 0.06797979207476601, 0.018056994740618393, 0.03408186668821145, 0.04601448439643718, 0.06954757904168218, 0.06195446949277539, 0.0208153164567193, 0.07365767451119609, 0.016084731723822188, 0.07868947286624461, 0.025520323069940787, 0.036340589431347325, 0.024173263809643686, 0.030893373914295807, 0.011690710962284356, 0.027748387692554388, 0.027397490994189866, 0.06051993514120113, 0.09036760442540981, 0.06988198336330242, 0.03697160791489296, 0.0503301176649984, 0.025106720459007192, 0.0061545912558358395, 0.041650500206742436, 0.09727440919959918, 0.02313230335857952, 0.014059060977160698, 0.11328195570968091, 2.637941474094987, 11.039880104362965, 32.93737359344959, 43.351425379514694, 44.85002316534519, 40.59179686009884, 27.717658281326294, 26.59159440547228, 27.723861448466778, 24.11421474069357, 13.509968910366297, 6.490023247897625, 3.207200802862644, 0.563316032057628, 0.9127252735197544, 0.5584602488670498, 2.267945590429008, 6.405495358631015, 5.228663356974721, 7.906802399083972, 5.3748244140297174, 2.485977178439498, 3.4548786375671625, 5.844310121610761, 13.076927047222853, 22.897660620510578, 36.42334073781967, 48.92871670424938, 51.20925933122635, 47.485462948679924, 45.11968329548836, 46.3422866910696, 49.80250261723995, 53.076992109417915, 52.03725390136242, 53.31992067396641, 52.76916302740574, 53.01355451345444, 50.96116304397583, 51.499122977256775, 51.21129222214222, 47.41400018334389, 45.63004530966282, 42.879996076226234, 36.25477038323879, 35.72048865258694, 36.74687817692757, 47.495805993676186, 49.73558820784092, 52.503507882356644, 52.34895497560501, 52.75097340345383, 54.36331428587437, 52.731104269623756, 46.35743647813797, 49.891129061579704, 52.61122450232506, 44.75438989698887, 36.062303110957146, 47.7322369068861, 51.21541500091553, 48.159618973731995, 43.84919486939907, 41.724918857216835, 38.54693278670311, 39.89532843232155, 37.134423181414604, 38.20497773587704, 37.57363021373749, 37.12478689849377, 37.61151798069477, 36.75294265151024, 40.32506637275219, 52.33429156243801, 52.41842284798622, 54.518627151846886, 52.33442075550556, 49.82052505016327, 48.761700466275215, 46.97045758366585, 43.24662320315838, 42.610229551792145, 43.79692867398262, 47.400157526135445, 46.74440771341324, 52.007623091340065, 52.59515896439552, 46.02198287844658, 37.07086779177189, 28.402227647602558, 17.159195244312286, 11.889485064893961, 9.870553649961948, 6.999974884092808, 4.983141906559467, 5.206227460876107, 7.956634350121021, 6.736523620784283, 5.598135106265545, 3.2795436959713697, 2.1408205619081855, 1.778652851935476, 0.9934341302141547, 0.2617695863591507, 0.5062026029918343, 1.3182691996917129, 6.54957365244627, 17.244536764919758, 32.4952445179224, 34.10635806620121, 37.843541130423546, 35.65949432551861, 42.06797584891319, 48.960893377661705, 38.62694889307022, 24.553503468632698, 5.875826580449939, 0.7413801772054285, 0.027191938352189027, 0.020749423019879032, 0.05532550625503063, 0.08382625543163158, 0.03863921003357973, 0.04329581934143789, 0.012813990433642175, 0.029211910332378466, 0.019299991909065284, 0.02994934537127847, 0.021817692650074605, 0.05908726729103364, 0.02298222440003883, 0.03772638323425781, 0.0765643923659809, 0.056069483325700276, 0.026541648148850072, 0.04315876321925316, 0.016409684794780333, 0.056791285023791716, 0.06185292142617982, 0.07052972985547967, 0.014297825655376073, 0.03830992282018997, 0.04183322067547124, 0.03571557863324415, 0.01543556216347497, 0.031288894097087905, 0.017537556304887403, 0.025032028861460276, 0.06452916903072037, 0.038753456246922724, 0.028536123645608313, 0.008521444451616844, 0.04563553637126461, 0.022206950961844996, 0.02545723309594905, 0.005608971705441945, 0.053913165829726495, 0.025080320410779677, 0.02043721262452891, 0.045672291234950535, 0.07997669832548127, 0.032495154955540784, 0.026782332206494175, 0.01970731780602364, 0.10118200967554003, 0.041650396306067705, 0.04714886083093006, 0.0051289895509398775, 0.05547999913687818, 0.02581639917480061, 0.03037534926988883, 0.1203019602689892, 0.042631615724531, 0.03635372544522397, 0.022828508917882573, 0.048585157783236355, 3.273610076867044, 16.27987302839756, 39.32084105908871, 48.8092815130949, 50.15869550406933, 48.15729349851608, 34.32065896689892, 30.130477510392666, 32.477788254618645, 27.79686313122511, 17.268517278134823, 8.254013992846012, 3.413412650115788, 0.8205777837429196, 0.7858971634414047, 1.0426642885431647, 4.098222116008401, 6.863379813730717, 7.875416558235884, 10.197032131254673, 7.349259266629815, 6.227128179743886, 2.553218132816255, 7.104774210602045, 15.358802452683449, 24.57364808768034, 39.07878264784813, 51.32534310221672, 53.496128618717194, 49.064095839858055, 48.59653852880001, 48.359575644135475, 52.015040293335915, 54.236982464790344, 52.31839321553707, 54.723709747195244, 53.74566122889519, 54.921291545033455, 51.93089760839939, 52.238012328743935, 51.74701787531376, 49.77846510708332, 47.110145688056946, 46.378217563033104, 38.26776176691055, 37.89972111582756, 37.97651119530201, 49.06971573829651, 51.49426303803921, 53.787892162799835, 53.35759565234184, 52.857424691319466, 54.29295726120472, 52.50483401119709, 48.23351740837097, 49.66403424739838, 53.159656673669815, 46.55360855162144, 40.45359067618847, 50.131895542144775, 53.035137355327606, 50.29511198401451, 46.67430907487869, 43.28516073524952, 39.91079360246658, 40.336157977581024, 39.307366982102394, 39.575093016028404, 39.87005978822708, 39.21112194657326, 38.91966238617897, 38.6691190302372, 43.16333167254925, 53.45794066786766, 54.45054240524769, 55.83969086408615, 54.030174762010574, 51.104837134480476, 50.324887186288834, 48.82765732705593, 45.78397884964943, 45.62945254147053, 46.37268505990505, 51.26925051212311, 50.525676012039185, 53.74231360852718, 55.21544136106968, 48.014766946434975, 38.61809156835079, 29.20076809823513, 21.05150308459997, 17.219313718378544, 12.697496507316828, 8.472436722368002, 5.617181584239006, 12.426864579319954, 13.030959013849497, 10.98523048684001, 8.111003916710615, 6.219627857208252, 2.7244706684723496, 2.160359350964427, 1.618020033929497, 0.7957662432454526, 0.5932071874849498, 1.5143598150461912, 6.996675236150622, 18.133499063551426, 34.55419443547726, 37.470450550317764, 40.36116823554039, 37.92777121067047, 48.88833627104759, 56.04765370488167, 44.43565919995308, 30.94027105718851, 7.67747662961483, 0.9890213201288134, 0.011688164468068862, 0.06990600668359548, 0.042491936110309325, 0.12299125111894682, 0.046825158278807066, 0.04066896166477818, 0.0933318016177509, 0.020497187433647923, 0.017458493457525037, 0.04835281361010857, 0.04685433210397605, 0.011832576201413758, 0.02752110125584295, 0.017497266962891445, 0.04964219500834588, 0.02754516724962741, 0.03570145185221918, 0.02533134258555947, 0.058982194022974, 0.1093691230926197, 0.01377685839543119, 0.04798527239472605, 0.001954811414179858, 0.04749377767439, 0.03634130931459367, 0.04930148243147414, 0.05443818707135506, 0.0900481766439043, 0.14302175753982738, 0.11849344286019914, 0.10178032171097584, 0.19867208698997274, 0.10024244329542853, 0.145214403164573, 0.1469795568846166, 0.09166730538709089, 0.10366007787524723, 0.1002807158511132, 0.1496880396734923, 0.08744627368287183, 0.12785310507752, 0.10279784328304231, 0.15687563602114096, 0.12122902888222598, 0.16192577284527943, 0.1242576222284697, 0.17209981597261503, 0.26781515101902187, 0.1599060179432854, 0.1012957289640326, 0.14533092034980655, 0.09664520897786133, 0.10964408138534054, 0.1791553248767741, 0.2116180071607232, 0.17238533502677456, 0.09789033982087858, 0.21874427242437378, 3.938225763849914, 18.97884540259838, 45.2110455930233, 58.05562175810337, 55.78324869275093, 52.92432390153408, 39.125463142991066, 40.265018194913864, 40.610092878341675, 32.538235411047935, 21.44810490310192, 10.064851474016905, 4.621314397081733, 1.2558118323795497, 2.2260312270373106, 2.7455635741353035, 6.509819235652685, 12.189478017389774, 15.21858997642994, 15.054078754037619, 14.115082640200853, 9.195768758654594, 8.010156378149986, 11.201571878045797, 18.84052712470293, 30.226828940212727, 43.72350141406059, 54.597750306129456, 55.95708176493645, 52.67973102629185, 50.851516127586365, 50.59987463057041, 53.972224071621895, 54.82424095273018, 53.05317498743534, 55.52978329360485, 53.84885989129543, 57.964745834469795, 55.619705468416214, 55.41803888976574, 54.524919614195824, 51.94894663989544, 49.89941641688347, 47.09713518619537, 38.97549279034138, 40.79124055802822, 39.86902244389057, 51.78336672484875, 54.73127134144306, 56.29286214709282, 55.74696443974972, 54.73378300666809, 54.75378133356571, 52.77120731770992, 48.42673324048519, 50.1172549277544, 53.58272597193718, 48.98084230720997, 44.306838512420654, 52.526869028806686, 55.133038982748985, 53.32108721137047, 48.81535738706589, 46.122232899069786, 43.81628103554249, 43.501680716872215, 41.712881103158, 42.232450023293495, 41.75377830862999, 39.723254665732384, 41.92971646785736, 41.46381586790085, 44.91017773747444, 56.84299662709236, 57.13891714811325, 58.034316301345825, 56.41194775700569, 53.94910991191864, 53.97872552275658, 52.25433625280857, 47.09891729056835, 47.86258511245251, 48.653714060783386, 54.57894131541252, 51.54514230787754, 57.08736911416054, 56.82823061943054, 50.543934032320976, 40.63891813158989, 32.2880682349205, 20.97590994089842, 16.40522640198469, 14.256211817264557, 14.771245680749416, 8.952027037739754, 13.457167893648148, 15.215945318341255, 14.763271808624268, 15.845305547118187, 7.612066939473152, 4.679624643176794, 4.532153131440282, 2.747051906771958, 1.188899204134941, 1.602131542749703, 1.9844990875571966, 9.296511802822351, 22.6786270737648, 43.4711379557848, 45.34450963139534, 50.20520120859146, 47.136128693819046, 54.748716205358505, 64.00247365236282, 50.27130626142025, 32.34556294977665, 10.499778036028147, 1.3146814797073603, 0.1532061758916825, 0.09552501869620755, 0.15665762271964923, 0.29634108126629144, 0.2146126324078068, 0.1107089890865609, 0.181598890630994, 0.12907046475447714, 0.11539738829014823, 0.070028943446232, 0.1374238563585095, 0.1442422639229335, 0.10346600625780411, 0.1595006271963939, 0.1709881381248124, 0.2084057396859862, 0.11018061704817228, 0.07829027163097635, 0.09740674155182205, 0.2213796685100533, 0.23241038754349574, 0.17244751215912402, 0.10729125060606748, 0.13547804905101657, 0.0927862933895085, 0.22864182101329789, 0.18518701137509197, 0.23204479075502604], [0.03481899002508726, 0.028321401769062504, 0.07684866461204365, 0.03286251063400414, 0.01525765452242922, 0.05462295957840979, 0.011291167411400238, 0.05434588616481051, 0.04247149365255609, 0.13652606547111645, 0.08569753626943566, 0.001979259382096643, 0.0256785415331251, 0.03280477525549941, 0.05108223980641924, 0.0389303842530353, 0.025468105559411924, 0.010732402570283739, 0.01961384987225756, 0.040480511815985665, 0.015798155109223444, 0.09170193399768323, 0.05680691094312351, 0.06532560480991378, 0.06042364890163299, 0.04216551358695142, 0.04940294144034851, 0.03186217349139042, 0.021859071093786042, 0.0353723019361496, 1.3495429465547204, 8.294917847961187, 23.938846550881863, 41.54605485498905, 42.18388482928276, 35.11605128645897, 27.9877819865942, 22.236912176012993, 23.599682450294495, 21.243029907345772, 11.648119166493416, 8.171305730938911, 3.096066741272807, 0.8936010184697807, 0.6726579554378986, 0.38185774872545153, 2.806922444142401, 5.644670734182, 7.097168918699026, 6.484024319797754, 3.4275932516902685, 4.052308704704046, 1.924888479989022, 4.220071602612734, 13.494236804544926, 21.5283926948905, 34.61625650525093, 44.326373264193535, 45.18123999238014, 45.101535469293594, 44.901795387268066, 46.24029256403446, 48.71345445513725, 52.567325457930565, 54.505867436528206, 53.12391199171543, 51.80984370410442, 52.59776942431927, 53.81048955023289, 51.84757947921753, 50.80810725688934, 47.95702904462814, 46.49173267185688, 39.96665060520172, 37.56655119359493, 37.71440885961056, 37.64460280537605, 46.462333649396896, 52.654929757118225, 50.77093385159969, 53.26678432524204, 53.8462570309639, 52.02904254198074, 57.958305180072784, 54.66972604393959, 53.297957852482796, 52.41040147840977, 48.61610367894173, 34.48792219161987, 49.05728280544281, 48.615974485874176, 50.847047567367554, 46.789294704794884, 44.593464732170105, 43.94546650350094, 44.8054363578558, 45.65404862165451, 41.473452150821686, 37.86141537129879, 36.83769330382347, 37.66324460506439, 37.67029322683811, 40.27142845094204, 49.700048714876175, 52.308380752801895, 54.78791110217571, 52.01126329600811, 54.855486676096916, 49.75844018161297, 47.62822508811951, 46.09175853431225, 45.45815013349056, 46.51039347052574, 46.751239746809006, 50.03629267215729, 51.86049498617649, 53.752417266368866, 47.555728778243065, 37.94694498181343, 27.593277655541897, 16.350516937673092, 13.168920110911131, 10.182631853967905, 4.354132208973169, 2.1325666923075914, 10.89607397094369, 8.356627486646175, 11.246394272893667, 8.458017446100712, 3.7570833088830113, 2.564469804055989, 1.5232603624463081, 0.27284554671496153, 0.2977962250588462, 0.5689836060628295, 1.9416619674302638, 7.530092988163233, 16.65272992104292, 24.24341920763254, 29.806387200951576, 34.62357111275196, 37.34368175268173, 40.60441218316555, 42.825742587447166, 41.45414158701897, 19.655782878398895, 6.82432503439486, 0.862761220196262, 0.04002219851827249, 0.05316344082530122, 0.029005596989009064, 0.047710555300000124, 0.016471498274768237, 0.033017051755450666, 0.018166144254792016, 0.04521651237155311, 0.04440011653059628, 0.03299065356259234, 0.056376572902081534, 0.026922655633825343, 0.020411985169630498, 0.02930785332864616, 0.02373770661506569, 0.038370834590750746, 0.028708229547191877, 0.04844737435632851, 0.03113498751190491, 0.02340435985388467, 0.024780696840025485, 0.12465217761928216, 0.06643849235842936, 0.047968280923669226, 0.02662316750502214, 0.07884350561653264, 0.05389234487665817, 0.018305599369341508, 0.041256720360252075, 0.029195751922088675, 0.03074936757911928, 0.052596347231883556, 0.01835558858147124, 0.041932620224542916, 0.03798077661485877, 0.03051088027859805, 0.03606781676353421, 0.030965738878876437, 0.06335726589895785, 0.019432133158261422, 0.023148478467192035, 0.040632956370245665, 0.04213123749650549, 0.06063138716854155, 0.07738337459159084, 0.09103088406845927, 0.07983509654877707, 0.03147448667732533, 0.020096112275496125, 0.0331757080857642, 0.05193522352783475, 0.06350150229991414, 0.058771093827090226, 0.07178197789471596, 0.06629886469454505, 0.044059500432922505, 0.02915929762821179, 0.10558517926256172, 1.994253401644528, 11.797928977757692, 30.07463950663805, 48.23841154575348, 49.411374405026436, 40.19754521548748, 33.541712164878845, 29.364980086684227, 27.95897763222456, 27.75500077754259, 15.794944949448109, 9.87294752150774, 3.82611776702106, 1.1192528600804508, 0.7189931441098452, 0.7363297138363123, 1.4994688890874386, 4.8280242551118135, 7.865083012729883, 8.511501476168633, 7.393293678760529, 8.2393828779459, 5.300678042694926, 4.683097656816244, 16.234267875552177, 25.344398729503155, 37.451516166329384, 46.10242456197739, 48.499883115291595, 48.74853417277336, 48.21142919361591, 48.87806162238121, 51.63647040724754, 54.75035011768341, 55.52002161741257, 52.554128766059875, 52.24474176764488, 53.33324275910854, 55.98274938762188, 53.137241676449776, 52.42897108197212, 48.57828430831432, 48.08780662715435, 42.33797036111355, 39.15771961212158, 39.09949153661728, 39.01346795260906, 47.06297501921654, 54.50630061328411, 51.97699673473835, 55.64715139567852, 53.514455035328865, 54.32791918516159, 56.98024906218052, 55.17900511622429, 53.1067369133234, 53.48348289728165, 49.56843137741089, 37.16637186706066, 52.09123760461807, 50.343874767422676, 52.30604387819767, 48.295484483242035, 46.489859372377396, 45.65296947956085, 46.30659140646458, 46.872217655181885, 42.50828102231026, 40.43805330991745, 39.24247406423092, 39.709484204649925, 38.83972607553005, 42.88666471838951, 51.98763236403465, 54.02850665152073, 56.86467446386814, 53.70342269539833, 54.85210485756397, 52.38531522452831, 50.54370604455471, 48.852675184607506, 47.51901134848595, 47.77747727930546, 49.05505992472172, 51.63056172430515, 54.62252877652645, 55.59967294335365, 47.989281713962555, 40.851064547896385, 29.40812297165394, 19.685425087809563, 17.37716104835272, 7.573042083531618, 8.859629295766354, 6.657866416499019, 14.730249680578709, 11.201831214129925, 10.405813828110695, 7.744206273928285, 6.4658840931952, 5.636232811957598, 2.9054188588634133, 1.021088333800435, 0.16544518555747345, 0.6066991947591305, 2.282764557749033, 9.656382892280817, 19.38554707914591, 30.502162165939808, 36.573683470487595, 38.73175486922264, 41.07546150684357, 45.70984102785587, 51.425745114684105, 46.21476173400879, 22.096321620047092, 7.930863182991743, 0.9910472645424306, 0.051591312294476666, 0.025383105530636385, 0.038332606563926674, 0.05230736234807409, 0.06252902167034335, 0.03462997243332211, 0.05702528047550004, 0.03648936777608469, 0.06097967336245347, 0.07183844048995525, 0.05961280803603586, 0.03453056175203528, 0.029319677596504334, 0.05595856564468704, 0.03236607321014162, 0.013741614729951834, 0.05094703534268774, 0.011660306099656736, 0.024062175434664823, 0.034865426205215044, 0.036767706551472656, 0.05353471504349727, 0.08885440984158777, 0.009255896056856727, 0.008454075068584643, 0.0642998973489739, 0.08363648827071302, 0.01681848385487683, 0.2626328822225332, 0.08387022025999613, 0.21975550800561905, 0.10180591096286662, 0.11856460740091279, 0.19198640511604026, 0.07093857901054434, 0.14194010698702186, 0.14687451330246404, 0.30088976374827325, 0.2133691342896782, 0.10277879977365956, 0.0725466720177792, 0.24678877147380263, 0.1770380962989293, 0.1195958438620437, 0.20537310163490474, 0.18051584484055638, 0.10355934617109597, 0.09930181564413942, 0.1133901385765057, 0.16128135117469355, 0.12677120219450444, 0.16062938928371295, 0.19778247456997633, 0.1470832052291371, 0.12198705851915292, 0.14617129869293422, 0.16011577856261283, 0.2079578535631299, 2.3885929165408015, 15.616275686770678, 35.41314594447613, 55.735428258776665, 57.06438034772873, 45.257133319973946, 42.11890451610088, 33.920434042811394, 34.34737153351307, 33.05148907005787, 19.861957915127277, 12.841672170907259, 5.622839480638504, 1.8483399250544608, 1.910854170564562, 1.713596899062395, 6.661398326978087, 13.931908719241619, 13.397562392055988, 14.540166780352592, 11.466538310050964, 10.632433667778969, 7.6797284837812185, 9.127524420619011, 20.948585607111454, 26.63100779056549, 37.1612573415041, 51.24890260398388, 52.33328841626644, 51.59860923886299, 50.442445278167725, 50.10964773595333, 53.14616359770298, 56.980442851781845, 57.74523161351681, 55.03029249608517, 52.83454231917858, 52.6791762560606, 57.993643283843994, 53.8988234102726, 54.968378618359566, 50.18301039934158, 49.290833473205566, 43.36826987564564, 41.03539265692234, 41.71442002058029, 41.36529855430126, 48.64522911608219, 55.499354526400566, 54.597579315304756, 55.75099602341652, 57.416560649871826, 55.002781972289085, 61.63572885096073, 55.25342792272568, 54.255472272634506, 54.249168410897255, 50.763535648584366, 41.89245946705341, 53.850474804639816, 54.21553261578083, 55.28717391192913, 53.3337177336216, 49.430548176169395, 48.342905938625336, 49.47880178689957, 50.53124651312828, 44.94811490178108, 42.271287739276886, 40.864930003881454, 41.74933634698391, 42.04406373202801, 46.126648262143135, 54.220202565193176, 57.20142379403114, 58.14200632274151, 54.71248134970665, 58.58258508145809, 54.375644624233246, 51.868740543723106, 51.70787997543812, 49.14376996457577, 51.01886294782162, 50.41596069931984, 54.640403017401695, 57.17139780521393, 57.51022182404995, 47.8299942612648, 41.899492889642715, 30.93610268086195, 20.234486125409603, 16.382173039019108, 15.782562363892794, 12.066041640937328, 7.457669349387288, 20.32320186495781, 18.628395907580853, 19.14994642138481, 16.3058028370142, 12.376979906111956, 8.332504481077194, 4.271822450682521, 1.3050189544446766, 0.5811175424605608, 0.9300351853016764, 3.1338129658252, 11.137939542531967, 24.0837574750185, 33.78396436572075, 42.3247204720974, 47.305899783968925, 49.18498635292053, 53.92211616039276, 58.19523386657238, 53.37129391729832, 28.054552003741264, 10.000828709453344, 1.5695324982516468, 0.12392928867484443, 0.14763564511667937, 0.07730325974989682, 0.1437760319095105, 0.1363185906666331, 0.13697043381398544, 0.096437860338483, 0.14767343527637422, 0.13423404627246782, 0.19154478271957487, 0.14739797974471003, 0.08820362796541303, 0.06947490794118494, 0.2188283874420449, 0.12537231319583952, 0.09406976358150132, 0.11628765380010009, 0.16996195568935946, 0.06891310957144015, 0.08787803293671459, 0.20377994806040078, 0.24078706774162129, 0.16051769605837762, 0.131870053592138, 0.188095977937337, 0.2105627176933922, 0.17166530335089192, 0.09447375909076072], [0.03670855367090553, 0.0180183065822348, 0.06196917514898814, 0.07807123416569084, 0.03737941806321032, 0.06239518275833689, 0.027413155876274686, 0.049016519988072105, 0.03008096155099338, 0.04230009093589615, 0.03422962086915504, 0.037609572900692, 0.0775086936482694, 0.007675138203921961, 0.007857542332203593, 0.036209878671797924, 0.03874283611366991, 0.0786736948066391, 0.008875880266714375, 0.06698366662021726, 0.019806496566161513, 0.043867417771252804, 0.0732372330094222, 0.054010398307582363, 0.02817619315464981, 0.018878260925703216, 0.05194405137444846, 0.042537448316579685, 0.10476316907443106, 0.062061179196462035, 0.5638278764672577, 6.3358693197369576, 23.18517219275236, 41.05471841990948, 48.63344594836235, 44.30624194443226, 24.90856021642685, 21.157004423439503, 32.83669799566269, 26.199886724352837, 24.574157260358334, 12.608949858695269, 4.198944736272097, 1.1656196345575154, 0.786502102855593, 0.8850225631613284, 1.2709822808392346, 3.6273224093019962, 6.1569364462047815, 7.72000347264111, 7.991202045232058, 7.95204752124846, 2.8748069889843464, 3.588215382769704, 13.645604532212019, 20.129072181880474, 31.649347208440304, 43.8848065584898, 51.63107089698315, 49.7745893150568, 46.19339168071747, 42.750544622540474, 44.817781895399094, 49.17791873216629, 54.383635595440865, 53.906761184334755, 53.153808787465096, 50.260659232735634, 51.904979199171066, 52.21377342939377, 51.009925827383995, 47.47167348861694, 46.155948489904404, 38.435587361454964, 38.519410863518715, 37.174393236637115, 35.49541532993317, 42.13524743914604, 48.416591584682465, 49.737393110990524, 50.26238813996315, 50.33740371465683, 51.05545498430729, 52.52776198089123, 51.10633805394173, 52.300594970583916, 54.26372542977333, 48.172800466418266, 32.332472652196884, 49.20386753976345, 52.273977398872375, 51.50023251771927, 48.069237023591995, 46.42763011157513, 48.223067969083786, 49.471939355134964, 47.198601141572, 48.21824222803116, 42.29201562702656, 38.16068351268768, 36.17153964936733, 38.05398903787136, 39.03211735188961, 47.61138059198856, 52.0423836261034, 54.12314437329769, 52.88750387728214, 54.574845135211945, 54.776781499385834, 53.43498609960079, 51.532359793782234, 46.66036382317543, 50.03959849476814, 52.05168932676315, 50.7391257584095, 55.46796441078186, 53.123949989676476, 42.42721997201443, 34.69686917960644, 22.969980239868164, 17.172469832003117, 15.351374801248312, 3.2442345656454563, 4.187864055857062, 6.525935595855117, 15.230025462806225, 12.299116384238005, 11.104907914996147, 5.12136091478169, 5.702830888330936, 3.289978173561394, 2.642444707453251, 0.8724445255938917, 0.3084638260770589, 0.43612643668893725, 2.4417378148064017, 6.857988853007555, 21.504060700535774, 43.03532414138317, 37.93674252927303, 41.471548452973366, 38.499507531523705, 42.39776775240898, 44.74131099879742, 36.002482920885086, 21.43476951867342, 6.065007504075766, 0.5823663098271936, 0.0640705662954133, 0.06962497762287967, 0.11291685616015457, 0.020309114224801306, 0.02564329137385357, 0.01638469853787683, 0.03965736614190973, 0.09186778173898347, 0.07496256308513694, 0.04847994350711815, 0.09185199625790119, 0.03472262586001307, 0.033530669898027554, 0.029771903427899815, 0.04386781853099819, 0.06034563804860227, 0.014309305752249202, 0.034161825678893365, 0.06476306429249234, 0.060089277976658195, 0.04495079381740652, 0.06413776776753366, 0.08612024132162333, 0.014556014193658484, 0.03730542965058703, 0.05695364096027333, 0.051265479778521694, 0.1107078832865227, 0.01918490892421687, 0.039156097336672246, 0.04473885870538652, 0.0723668051068671, 0.058096800712519325, 0.017232823047379497, 0.04646317946026102, 0.0695161490875762, 0.018995149184775073, 0.0788029917748645, 0.027230218329350464, 0.051859294399037026, 0.04369927308289334, 0.022145760885905474, 0.03487273264909163, 0.024906244107114617, 0.05776942824013531, 0.05771124386228621, 0.04848407726967707, 0.0332643464935245, 0.04678874109231401, 0.00753829220229818, 0.09391343759489246, 0.03561733683454804, 0.0016635720248814323, 0.03218924910470378, 0.015027591525722528, 0.10392464610049501, 0.03722465058672242, 0.06548200501129031, 0.7654041505884379, 8.498109094798565, 27.964969910681248, 49.00424525141716, 53.54652911424637, 48.42087395489216, 29.45099227130413, 26.301795355975628, 34.607847556471825, 28.715741224586964, 26.045027934014797, 14.481452330946922, 5.692531066015363, 1.7635424877516925, 0.5495898623485118, 1.1278665228746831, 1.6667876858264208, 3.8497983338311315, 7.418110147118568, 8.715320639312267, 6.569818491116166, 9.929688926786184, 5.355008002370596, 5.144587643444538, 14.245125912129879, 23.38480018079281, 35.30197910964489, 46.73127181828022, 54.504366517066956, 51.494346633553505, 48.498123809695244, 45.93154013156891, 49.11283582448959, 51.25944323837757, 55.733532160520554, 54.474302530288696, 51.769592463970184, 50.26213355362415, 53.25196512043476, 55.015678480267525, 53.14594700932503, 50.34369617700577, 45.76382473111153, 41.66044771671295, 40.35421080887318, 38.69356691837311, 38.09224918484688, 44.478308111429214, 51.35033056139946, 51.68892279267311, 52.980743274092674, 53.62134709954262, 53.93039591610432, 55.16254059970379, 53.436171635985374, 54.53576423227787, 54.52062584459782, 49.77542906999588, 37.252349853515625, 53.61376270651817, 53.1545003503561, 53.2784952968359, 49.15191672742367, 48.870150446891785, 50.04824683070183, 50.66032938659191, 50.85102595388889, 49.68239106237888, 44.432672560214996, 39.96346637606621, 38.24437402188778, 39.558620899915695, 41.02083183825016, 50.596310421824455, 54.475716054439545, 55.01983925700188, 53.49291019141674, 55.7121355086565, 56.112402230501175, 53.96713614463806, 52.9532403498888, 49.73753750324249, 50.43021373450756, 52.489805817604065, 52.17299021780491, 56.87865771353245, 55.96500813961029, 45.47394208610058, 36.14842168986797, 25.864604115486145, 18.06584559381008, 13.878093156963587, 7.104516299441457, 11.465796399861574, 5.481725502759218, 9.936061184853315, 11.141244415193796, 9.145993329584599, 7.215413823723793, 7.169028762727976, 3.5858851578086615, 3.4860692638903856, 2.8906044038012624, 0.3373838070547208, 0.5112045595888048, 2.515326803550124, 8.751513697206974, 22.10179142653942, 38.75680312514305, 35.86711138486862, 45.057853013277054, 44.53357994556427, 47.279814183712006, 51.472995579242706, 42.025984302163124, 25.96562549471855, 7.59446675889194, 0.7867252221331, 0.01829730401368579, 0.042987560882465914, 0.10960966057609767, 0.0612622238259064, 0.021222740688244812, 0.06454009344452061, 0.07251036615343764, 0.03139065367577132, 0.0007736115492207318, 0.023136971467465628, 0.04801100636541378, 0.043035210474045016, 0.050916388354380615, 0.017303727836406324, 0.014476056130661163, 0.04103063249203842, 0.05037805298343301, 0.058510295712039806, 0.10162100486923009, 0.01435963635231019, 0.15889334259554744, 0.04531317710643634, 0.02194792472437257, 0.02410217533906689, 0.043384669261286035, 0.060364718665368855, 0.06576882282388397, 0.04665604508772958, 0.11276185119641013, 0.08412471754127182, 0.19646611239295453, 0.2552570920670405, 0.12802143901353702, 0.1650898007210344, 0.1293400870054029, 0.17914552852744237, 0.1904915415798314, 0.22281821788055822, 0.16841527540236712, 0.07804732958902605, 0.12370590964565054, 0.1491294102743268, 0.11116010355181061, 0.09103429794777185, 0.12714729295112193, 0.16549124324228615, 0.2011477283667773, 0.1372585355420597, 0.21706535626435652, 0.15041182661661878, 0.24161925277439877, 0.13336721778614447, 0.11374923415132798, 0.0807040327345021, 0.11172209487995133, 0.17516764666652307, 0.1762694094213657, 0.18881307070842013, 0.9154494304675609, 9.783809054642916, 32.764980643987656, 52.74665303528309, 62.85281874239445, 56.44421562552452, 35.073497369885445, 33.71516525745392, 43.6503591388464, 37.33043186366558, 33.95390264689922, 17.7694159001112, 6.527327271178365, 2.1387978829443455, 1.614649852272123, 2.692745695821941, 5.05653734318912, 9.50959961861372, 13.627105224877596, 18.063960894942284, 15.161714628338814, 16.499626636505127, 8.7886025570333, 6.691365893930197, 18.601865731179714, 26.381993852555752, 34.848861023783684, 47.42821902036667, 55.46607971191406, 56.115214079618454, 52.837015986442566, 49.50299508869648, 49.57473523914814, 52.57182441651821, 58.21656592190266, 57.239421755075455, 53.177834898233414, 51.3213837146759, 53.51829282939434, 56.17758013308048, 54.918152913451195, 52.013626769185066, 49.41654592752457, 43.196310102939606, 42.58540168404579, 41.33893556892872, 38.78321550786495, 46.1693199723959, 52.26186364889145, 54.02817986905575, 55.275645330548286, 53.369929790496826, 56.55261240899563, 55.0587909668684, 54.87299233675003, 55.96891053020954, 55.20132511854172, 49.851136207580566, 40.15735477209091, 55.609571412205696, 55.530626848340034, 55.699352994561195, 52.36139550805092, 52.68859975039959, 52.78927534818649, 53.39046768844128, 52.125162184238434, 53.84751096367836, 46.59712001681328, 42.57464446127415, 39.790321066975594, 43.58046568930149, 42.7732940018177, 52.61391095817089, 56.94876775145531, 57.18548744916916, 54.32326063513756, 56.32519841194153, 58.013941794633865, 59.15139555931091, 56.64126545190811, 51.8378634005785, 54.99607913196087, 56.88074380159378, 54.29841756820679, 58.5517231374979, 55.96966288983822, 48.59115041792393, 43.30391652882099, 29.590642377734184, 23.057413548231125, 19.55840740352869, 7.164608174934983, 8.885811790823936, 13.359947260469198, 27.9790348559618, 25.24461418390274, 18.971198312938213, 14.045582469552755, 15.281972475349903, 8.625185675919056, 7.233219193294644, 3.0673559568822384, 0.601171322632581, 1.102597403805703, 3.876210004091263, 9.761557448655367, 30.460725389420986, 52.13575601577759, 47.629843801259995, 53.62679980695248, 52.75733806192875, 56.17363214492798, 59.050560370087624, 48.38576763868332, 28.568805009126663, 8.807739280164242, 0.9638669667765498, 0.09953260872862302, 0.18513299786718562, 0.19989113876363263, 0.13871360511984676, 0.17407490842742845, 0.15894688112894073, 0.2266124775633216, 0.20848937972914428, 0.11905222811037675, 0.10302361202775501, 0.18903724383562803, 0.11580838225199841, 0.1366881059948355, 0.10974567398079671, 0.2033592839143239, 0.13434591761324555, 0.07325370126636699, 0.115860703663202, 0.2492973196785897, 0.13591624272521585, 0.23519545997260138, 0.129680851532612, 0.1551237964304164, 0.15146926831221208, 0.14278345392085612, 0.11133324660477228, 0.13624649844132364, 0.18718476901995018], [0.0439746692427434, 0.036382301841513254, 0.037367231998359784, 0.03564703387382906, 0.022924435215827543, 0.031501942430622876, 0.001453057893741061, 0.028937020688317716, 0.014633404425694607, 0.04039510175061878, 0.009006087293528253, 0.05234566830040421, 0.08236702982685529, 0.04688348366471473, 0.033869285907712765, 0.03616154630435631, 0.048567394478595816, 0.04984080485883169, 0.07346867918386124, 0.06901575601659715, 0.04300984386645723, 0.050110274969483726, 0.07097524852724746, 0.02951215545181185, 0.0469551973947091, 0.053485258322325535, 0.06972472227062099, 0.07103516953065991, 0.09104940065299161, 0.01796185697457986, 0.12364342823275365, 4.675399269908667, 18.98806180804968, 38.12377989292145, 42.817527428269386, 38.79719875752926, 28.56486652046442, 25.502493046224117, 26.93871147930622, 23.514190837740898, 24.37773060053587, 8.883583210408688, 2.880685036070645, 2.438267176039517, 0.8740076667163521, 0.7125954749062657, 0.5774614261463284, 2.203158591873944, 5.023893294855952, 5.417773984372616, 4.74736693315208, 7.061424711719155, 4.448652612045407, 2.910026586614549, 10.490435287356377, 17.420448325574398, 30.08648157119751, 39.544633850455284, 51.01830057799816, 49.021914303302765, 49.173153787851334, 46.88006043434143, 46.07769548892975, 46.81769818067551, 48.894358947873116, 54.26922753453255, 52.59570233523846, 48.57115589082241, 51.997838616371155, 51.23127534985542, 51.398329585790634, 45.92812031507492, 43.24299819767475, 39.26152624189854, 37.23645530641079, 37.04402223229408, 37.75624841451645, 37.78144486248493, 41.97499483823776, 44.69209983944893, 48.503029346466064, 46.68880149722099, 48.37295852601528, 49.18411619961262, 50.709829330444336, 51.03048272430897, 52.52441816031933, 54.549428299069405, 32.10457228124142, 46.807062551379204, 52.10185043513775, 54.23907235264778, 50.54782122373581, 50.897546857595444, 50.49605280160904, 50.438827872276306, 52.610905319452286, 49.944595992565155, 45.29250182211399, 39.991307482123375, 37.41927109658718, 38.53576898574829, 38.3324608951807, 45.91816104948521, 51.196720004081726, 54.96239393949509, 52.52343401312828, 54.49106343090534, 54.665390476584435, 54.40172262489796, 51.50325335562229, 50.399321392178535, 48.89451093971729, 51.3665746897459, 54.83972892165184, 53.02902728319168, 46.35799504816532, 43.925741761922836, 41.216658130288124, 27.767893485724926, 11.458415295928717, 8.789222873747349, 3.763884943909943, 8.377227131277323, 4.0129304677248, 7.085656486451626, 6.606086594983935, 5.028295833617449, 5.824440512806177, 4.588191099464893, 5.071517564356327, 4.162274328991771, 2.8758630948141217, 0.10623957539792173, 0.36861982312984765, 2.5361404241994023, 9.527227822691202, 21.73588816076517, 27.160228192806244, 29.898707047104836, 23.097256310284138, 33.37183468043804, 48.549379259347916, 45.998405143618584, 32.18686826527119, 14.528157524764538, 3.789691496640444, 0.12523419951321557, 0.04096031028893776, 0.012796457194781397, 0.038141603727126494, 0.04187913364148699, 0.045100028582965024, 0.015306269833672559, 0.08426358821452595, 0.017626632579776924, 0.040229387595900334, 0.016098303749458864, 0.017770668600860517, 0.02675170933798654, 0.02334734621399548, 0.052498743680189364, 0.059594855483737774, 0.02492449351848336, 0.040293401543749496, 0.021686733271053527, 0.015259328993124655, 0.01624568314582575, 0.05267505570373032, 0.02567703868407989, 0.058580903641995974, 0.038102908147266135, 0.02219404501374811, 0.025071689233300276, 0.023513501946581528, 0.08344461341039278, 0.08631777876871638, 0.035495951160555705, 0.016022745694499463, 0.06700261365040205, 0.00940513546083821, 0.05226346431300044, 0.04534106330538634, 0.04390820620756131, 0.05298354051774368, 0.05101654489408247, 0.033613790437811986, 0.030851850751787424, 0.040041126994765364, 0.04645590641302988, 0.05355745815904811, 0.03446249938861001, 0.05038880670326762, 0.050572506806929596, 0.1196267839986831, 0.0356169917358784, 0.03626180303399451, 0.05215446508373134, 0.07073202446918003, 0.0042392532850499265, 0.03756033140234649, 0.007712201058893697, 0.06539736306876875, 0.061512075262726285, 0.06655280536506325, 0.03749665884242859, 0.3184575866907835, 5.912814270704985, 23.945608288049698, 44.86196972429752, 49.80024553835392, 44.89744082093239, 31.91180482506752, 26.717065572738647, 32.65631787478924, 29.345281943678856, 31.057557463645935, 13.132787849754095, 5.0416630413383245, 2.295063310302794, 0.7523152185603976, 0.5332087632268667, 1.7405772325582802, 3.7049788422882557, 7.577297855168581, 8.69634160771966, 6.754186972975731, 5.740302102640271, 6.480635851621628, 4.988421723246574, 12.930333763360977, 20.772964730858803, 30.59445731341839, 43.436115235090256, 54.74647432565689, 53.421371430158615, 50.73099799454212, 47.47956946492195, 48.60105648636818, 48.93201492726803, 53.10666471719742, 55.34130200743675, 52.646585404872894, 50.341610088944435, 51.57095052301884, 53.08862328529358, 53.60224932432175, 48.65013465285301, 46.40839174389839, 41.14266090095043, 38.18587616086006, 38.12546320259571, 38.91640596091747, 39.86550763249397, 44.054798036813736, 49.23595301806927, 50.64185097813606, 50.129520669579506, 50.71678675711155, 52.65879414975643, 52.705470845103264, 53.34137812256813, 53.79152476787567, 54.90062825381756, 36.15553490817547, 49.39907066524029, 53.478242978453636, 56.32732629776001, 52.11080275475979, 53.314338773489, 52.50690869987011, 52.56791442632675, 53.51035885512829, 52.44452744722366, 48.04290823638439, 41.96357645094395, 39.72416661679745, 39.75834958255291, 39.77185785770416, 48.10066893696785, 53.44059459865093, 56.175258457660675, 53.77751111984253, 54.449698850512505, 55.777602195739746, 56.619804203510284, 52.93536610901356, 50.56729517877102, 51.31095327436924, 53.09895113110542, 56.849843859672546, 54.67403881251812, 49.912157133221626, 45.982928574085236, 44.65482383966446, 30.99873472005129, 18.111315853893757, 12.455412447452545, 6.105435434728861, 12.297439724206924, 10.79895593225956, 10.594567749649286, 9.432938732206821, 10.782537963241339, 8.931068312376738, 6.019404726102948, 3.235485297627747, 1.4667690312489867, 1.372808029409498, 0.4773688002023846, 0.4075783013831824, 2.748817387036979, 8.692809697240591, 25.602444782853127, 32.33258284628391, 35.76117306947708, 32.72527277469635, 42.18146815896034, 55.11399060487747, 52.420930713415146, 37.276839539408684, 17.92407900094986, 5.26057974435389, 0.32754378975369036, 0.04974903829861432, 0.027955098084930796, 0.02972196802147664, 0.03301573444332462, 0.010376273730798857, 0.06773558096028864, 0.04124512059206609, 0.0719962285074871, 0.03837264914182015, 0.025151410736725666, 0.05499720609805081, 0.0813266501063481, 0.022245626132644247, 0.03677047476230655, 0.009503634228167357, 0.043840659636771306, 0.03096303375059506, 0.02296406775712967, 0.04364655462268274, 0.04542420239886269, 0.02054340653558029, 0.08280129011836834, 0.04388801236927975, 0.05820027465233579, 0.0391627024509944, 0.019875412399414927, 0.03585666461731307, 0.07758621839457192, 0.20274969865567982, 0.1665168022736907, 0.08260270624305122, 0.1460356786265038, 0.07709740282734856, 0.12218104850035161, 0.1445339576457627, 0.16988947754725814, 0.13303253886988387, 0.12456087861210108, 0.11451432903413661, 0.16132960561662912, 0.1798008003970608, 0.11091582564404234, 0.13302384089911357, 0.1038741206866689, 0.11143300609546714, 0.15309659036574885, 0.29700340353883803, 0.0983331941824872, 0.12171914320788346, 0.19675771705806255, 0.1313428912544623, 0.07495248471968807, 0.13658726296853274, 0.16151019983226433, 0.22210180788533762, 0.15400751726701856, 0.20879861782304943, 0.13443010684568435, 0.4140468902187422, 6.658753668889403, 26.59762278199196, 50.83095163106918, 56.17240101099014, 52.6703417301178, 40.23559257388115, 36.183520406484604, 39.59440357983112, 36.050185561180115, 36.69641688466072, 15.661103781312704, 6.421891953796148, 3.818198754452169, 1.6386062605306506, 2.3397396504879, 3.809553268365562, 4.999584574252367, 12.621352393180132, 13.12875246629119, 11.393030304461718, 14.761609397828579, 9.709842223674059, 7.19609803520143, 13.90677971765399, 20.69172129034996, 34.57535929977894, 43.4289526194334, 56.57889939844608, 54.8808579146862, 54.005255699157715, 50.94127491116524, 50.641140416264534, 51.87629833817482, 54.70623828470707, 58.173955008387566, 53.972448259592056, 50.116768553853035, 53.32886919379234, 54.88764815032482, 56.30839951336384, 51.960555016994476, 46.967641934752464, 43.65249082446098, 41.348750442266464, 40.35995610058308, 41.30178116261959, 41.47759772837162, 45.74174791574478, 49.85033445060253, 51.218568831682205, 52.32212841510773, 53.18368658423424, 55.11896833777428, 54.16619226336479, 53.88588510453701, 54.57166850566864, 56.57527059316635, 40.31119331717491, 51.46954916417599, 53.96633438766003, 56.70249916613102, 56.34300045669079, 57.76720583438873, 55.75905159115791, 54.470312744379044, 56.128642559051514, 54.572204276919365, 50.4576026648283, 44.63087372481823, 42.48705916106701, 41.987207382917404, 42.94656090438366, 50.51937215030193, 55.43642230331898, 57.45329707860947, 54.25191566348076, 55.10376915335655, 56.30464531481266, 58.98112289607525, 56.28151595592499, 54.496117159724236, 53.97980846464634, 55.80520011484623, 58.169452250003815, 60.08182503283024, 54.91539806127548, 49.81383740901947, 44.75486867129803, 29.989989548921585, 15.315655767917633, 13.793340604752302, 7.56286290474236, 18.5748852789402, 10.843822974711657, 19.030456133186817, 11.748543977737427, 17.54154972732067, 16.29704050719738, 11.300145238637924, 9.508356135338545, 6.246034540235996, 4.535777186974883, 0.48858274065423757, 0.6278169772122055, 3.88730825856328, 13.018251545727253, 29.36065971851349, 37.41609826683998, 42.0303350687027, 34.42231871187687, 45.36041937768459, 62.50473842024803, 58.728041276335716, 42.48725675046444, 19.41178847104311, 6.632982026785612, 0.39669841644354165, 0.1277514308458194, 0.10649160874891095, 0.12083698195056058, 0.10969560127705336, 0.260891328798607, 0.11992563202511519, 0.17057206045137718, 0.16539832635316998, 0.31803972786292434, 0.1233851385768503, 0.1793124820687808, 0.14776295312913135, 0.13365956459892914, 0.1541766824084334, 0.10394346696557477, 0.24401318369200453, 0.12636299128644168, 0.14820350683294237, 0.12741087411995977, 0.07573337250505574, 0.1524231507210061, 0.1960183895425871, 0.1865529638598673, 0.13487772579537705, 0.140579097205773, 0.16705337504390627, 0.12547189457109198, 0.20999264437705278], [0.023256396016222425, 0.02845525181328412, 0.04718042066087946, 0.010390751176601043, 0.031245081408997066, 0.04506709206907544, 0.028420109265425708, 0.03104138970229542, 0.031211617970257066, 0.0758935725025367, 0.04020623258838896, 0.020455616031540558, 0.0613651819730876, 0.12354798804153688, 0.03840216435492039, 0.051311292554601096, 0.06442247788072564, 0.027029459961340763, 0.017020806299115065, 0.10809791318024509, 0.033565361591172405, 0.025861516187433153, 0.04420947363541927, 0.03711870529514272, 0.034231791651109233, 0.025966702633013483, 0.03027099031896796, 0.023305205213546287, 0.01993754500290379, 0.140657972660847, 0.1295999574358575, 2.4695950699970126, 13.902244661003351, 36.1542771756649, 48.39920751750469, 50.73553875088692, 40.17796866595745, 31.930822804570198, 27.74348359555006, 20.994920320808887, 18.38760282844305, 11.305018477141857, 10.547911003232002, 4.13076214492321, 1.3056069728918374, 0.5696248216554523, 1.4517774106934667, 4.6322848834097385, 5.49111669883132, 6.925174947828054, 5.0338064879179, 4.371321061626077, 3.993039960041642, 5.850356072187424, 9.73688442260027, 15.769831147044897, 24.56052929162979, 36.48965857923031, 48.29446233808994, 50.903455540537834, 49.36593644320965, 46.82787783443928, 47.42136798799038, 47.35013701021671, 51.156879141926765, 52.69900739192963, 53.27953644096851, 51.035471856594086, 52.77894750237465, 54.32836756110191, 51.17781601846218, 48.62601354718208, 45.21582953631878, 44.65764708817005, 38.3499551564455, 37.19284504652023, 39.10828046500683, 38.6544556170702, 37.796625047922134, 40.210567116737366, 40.81994041800499, 42.17557467520237, 46.57350428402424, 49.62919011712074, 48.41848388314247, 51.40570878982544, 51.90296150743961, 56.52103990316391, 31.914502680301666, 45.29114529490471, 48.63566882908344, 51.90186716616154, 54.254586920142174, 52.73273438215256, 54.382795840501785, 52.85400867462158, 54.73650366067886, 50.01353569328785, 47.644096836447716, 41.500404104590416, 35.467646420001984, 37.29818679392338, 38.26781116425991, 42.57265716791153, 48.181931376457214, 52.61469751596451, 53.49967762827873, 53.422545567154884, 52.64752395451069, 54.41750317811966, 55.27075879275799, 51.72471687197685, 51.199976429343224, 51.52205854654312, 51.35187327861786, 52.144750133156776, 55.33364541828632, 50.59195965528488, 34.89423058927059, 23.104046545922756, 16.71914655715227, 14.818374551832676, 5.860364260151982, 18.07607464492321, 5.958413723856211, 4.829033575952053, 13.068071622401476, 7.077627517282963, 7.09059527143836, 5.860287789255381, 2.072810623794794, 1.109708840958774, 2.2131150076165795, 0.7419801293872297, 0.43338265735656023, 3.7325283139944077, 12.995427120476961, 18.362689465284348, 28.962619677186012, 28.80776848644018, 24.382856525480747, 29.352619349956512, 41.738974303007126, 39.55616243183613, 33.37857931852341, 14.352534748613834, 2.68956882879138, 0.21018834871938452, 0.02089169644023059, 0.07489000330679119, 0.011855424145323923, 0.026981424452969804, 0.023498508708144072, 0.012503775487857638, 0.05319550902640913, 0.040370403075939976, 0.07984228053828701, 0.08710713445907459, 0.05919440372963436, 0.0246871417039074, 0.0545718107605353, 0.0563250567211071, 0.04696468575275503, 0.042012089397758245, 0.03629365972301457, 0.05416855368821416, 0.06371987183229066, 0.02650791753694648, 0.1138017485209275, 0.027568086625251453, 0.04603845576639287, 0.004194810699118534, 0.034992407672689296, 0.05914633482461795, 0.044515639237943105, 0.045930517808301374, 0.006923697446836741, 0.017957613745238632, 0.042941477222484536, 0.03806540000368841, 0.1034166089084465, 0.009842711297096685, 0.017848746247182135, 0.0470705716725206, 0.017903908228618093, 0.03167901886627078, 0.04607890281477012, 0.05366195255191997, 0.020507978260866366, 0.02647268964210525, 0.0939416911569424, 0.009578244189469842, 0.08185649901861325, 0.03247969230869785, 0.03133832484309096, 0.052739518650923856, 0.05649856342643034, 0.03363474868820049, 0.06514129985589534, 0.02928825135313673, 0.0695022709260229, 0.045440815374604426, 0.026636635629984085, 0.06746765822754242, 0.05164706613868475, 0.06837888198788278, 0.20542245445540175, 3.20611999835819, 17.856625020503998, 40.837533473968506, 52.8633713722229, 53.55255179107189, 43.6202609539032, 36.49775214493275, 35.49120895564556, 29.31360114365816, 25.096304342150688, 14.173612799495459, 9.058457426726818, 4.295831937342882, 1.3650119164958596, 0.4922861763043329, 1.1589728412218392, 3.316928702406585, 4.681974342092872, 5.4291315749287605, 7.40376116707921, 5.8383767399936914, 7.289094245061278, 4.983854368329048, 11.927979849278927, 18.66883523762226, 28.003116063773632, 41.54748737812042, 49.814547970891, 53.4835284948349, 50.76858177781105, 48.331688940525055, 49.738783836364746, 49.01917465031147, 52.65546552836895, 53.45592677593231, 54.60077114403248, 49.798885211348534, 52.90591388940811, 53.847716152668, 54.568389281630516, 51.11647970974445, 46.77935063838959, 45.484984293580055, 40.128244534134865, 38.63107547163963, 40.16634128987789, 39.538622573018074, 39.494966715574265, 41.7910923063755, 42.310946211218834, 43.628996685147285, 48.09424728155136, 50.722117871046066, 50.89177876710892, 53.72594028711319, 54.415629878640175, 57.88697920739651, 36.44060701131821, 46.83003231883049, 49.37969170510769, 54.48152594268322, 56.62469834089279, 54.02456246316433, 56.48308753967285, 54.0134746581316, 56.43446534872055, 51.162054464221, 50.57102657854557, 43.14851626753807, 38.274031430482864, 38.46742585301399, 39.87848773598671, 44.31281939148903, 51.520002856850624, 54.22467492520809, 56.14641800522804, 54.21229898929596, 53.98761324584484, 56.505772322416306, 57.453414872288704, 53.113040775060654, 52.659740298986435, 53.361619636416435, 54.8616499453783, 54.02751110494137, 57.25406236946583, 51.760906130075455, 39.597071036696434, 30.62406152486801, 25.619959942996502, 14.767646323889494, 11.35411849245429, 11.457171812653542, 9.177588634192944, 10.82424072548747, 10.339526385068893, 10.043757855892181, 8.761953637003899, 6.755345435813069, 2.72711627651006, 1.2126592104323208, 0.5785916280001402, 0.2971739193890244, 0.6543790362775326, 4.208044772967696, 13.024426214396954, 21.67334731668234, 31.832786165177822, 30.652107819914818, 26.488720625638962, 33.93189422786236, 49.28239032626152, 48.11874456703663, 37.82781757414341, 17.321528233587742, 3.9735534181818366, 0.17587350332178175, 0.052469632937572896, 0.10823885444551706, 0.001988251196962665, 0.018646744247234892, 0.04990706380340271, 0.05565146493609063, 0.05527209759748075, 0.03117366082733497, 0.012540092484414345, 0.009676119552750606, 0.022843557817395777, 0.05446960960398428, 0.026756191909953486, 0.010573425261100056, 0.04951110946421977, 0.06960315105970949, 0.064019729179563, 0.05961478214885574, 0.09392986874445342, 0.01411165698300465, 0.028789754469471518, 0.01696469622402219, 0.08331065575475805, 0.01681701440247707, 0.027077211598225404, 0.03127423296973575, 0.06589422351680696, 0.04744606871099677, 0.12209326727315784, 0.15496738138608634, 0.13578562473412603, 0.11810603435151279, 0.188733022660017, 0.09208975068759173, 0.13717283232836053, 0.11675081332214177, 0.12641348701436073, 0.21038755599875003, 0.22181192500283942, 0.09845890657743439, 0.13495480525307357, 0.19765939679928124, 0.13360313168959692, 0.07404023679555394, 0.2199935889802873, 0.21338607009965926, 0.13682388933375478, 0.1660857183742337, 0.157308085472323, 0.17598659178474918, 0.14239357406040654, 0.13637931318953633, 0.21005643939133734, 0.15983523189788684, 0.13395710644545034, 0.1820106341619976, 0.1334253279492259, 0.17864045250462368, 0.3680826269555837, 4.119791183620691, 20.300422087311745, 46.380721628665924, 62.235849648714066, 63.68461310863495, 52.41544000804424, 45.10209783911705, 41.062451004981995, 33.23435425758362, 29.202348813414574, 19.589516334235668, 13.836157657206059, 5.411503370851278, 2.1965657081454992, 1.6247986326925457, 2.7372940303757787, 11.245978195220232, 14.662619959563017, 15.033095329999924, 12.142990361899137, 11.758894622325897, 11.379517279565334, 11.223563198000193, 14.560215454548597, 20.385178439319134, 29.33966014534235, 40.52562341094017, 52.38066807389259, 55.62246032059193, 54.277560487389565, 50.91208107769489, 52.45254881680012, 51.63727216422558, 55.23807294666767, 56.11622862517834, 56.34968809783459, 53.07682491838932, 51.904489025473595, 56.650863736867905, 56.0161267966032, 53.9027713984251, 49.90086793899536, 48.15508961677551, 42.95824147760868, 41.94744251668453, 42.81980350613594, 41.23744681477547, 41.447545140981674, 42.71155871450901, 43.395142033696175, 44.812834560871124, 49.70466926693916, 53.52342635393143, 53.69005501270294, 56.506311893463135, 56.49853751063347, 58.38498808443546, 39.93934907019138, 47.730447202920914, 50.850136801600456, 53.984820395708084, 55.03610238432884, 56.7173145711422, 58.95930826663971, 53.99422109127045, 57.79448837041855, 54.61752824485302, 52.50343568623066, 45.84667928516865, 39.72626410424709, 42.33053036034107, 42.00932219624519, 47.74004928767681, 52.7593519538641, 57.12373696267605, 56.76474742591381, 55.02150356769562, 54.56985980272293, 58.057658448815346, 60.402413830161095, 56.635607555508614, 55.164945870637894, 56.599954068660736, 58.824039325118065, 58.24793703854084, 59.88564535975456, 50.578884556889534, 40.30364692211151, 28.826894760131836, 22.27217998355627, 18.42823214828968, 11.453792843967676, 28.95132288336754, 13.359525483101606, 13.208298347890377, 22.685894183814526, 17.492256872355938, 15.26393199339509, 13.045051507651806, 7.462114160880446, 3.3694986440241337, 4.371277363970876, 1.6218944010324776, 0.659230425953865, 5.57690754532814, 16.761784069240093, 26.714686900377274, 42.21619829535484, 42.18386583030224, 35.419309213757515, 41.594901233911514, 53.83270315825939, 55.34590736031532, 42.84271627664566, 20.10689467191696, 4.645876279100776, 0.4073547071311623, 0.1537766054389067, 0.2531602280214429, 0.153676237387117, 0.0992335454793647, 0.14372363628353924, 0.18457279511494562, 0.0896514616033528, 0.13738388428464532, 0.2145531863789074, 0.19663027545902878, 0.19201015384169295, 0.16481936210766435, 0.13530440133763477, 0.19203574309358373, 0.2105526690138504, 0.24681577080627903, 0.10312576865544543, 0.1420585685991682, 0.1290509314276278, 0.09232926400727592, 0.1615525467786938, 0.1528893827344291, 0.18816419615177438, 0.13696295296540484, 0.11713339787092991, 0.13949162821518257, 0.12739788653561845, 0.12426018263795413], [0.0259403174277395, 0.025494854417047463, 0.07350697400397621, 0.042924834560835734, 0.04496627501794137, 0.050684979287325405, 0.04318384781072382, 0.056554699476691894, 0.02596936137706507, 0.0959523324854672, 0.047810763790039346, 0.021711574809160084, 0.022374013969965745, 0.028630743763642386, 0.08445794926956296, 0.03355319408001378, 0.025119917700067163, 0.004903020890196785, 0.04240945752826519, 0.11075060872826725, 0.02379550878686132, 0.04404252009408083, 0.1125633118499536, 0.010099818155140383, 0.03720103544765152, 0.08309101714985445, 0.020978175198251847, 0.018243693120894022, 0.06554532505106181, 0.00750928164961806, 0.13721776194870472, 0.920883851358667, 9.862727969884872, 26.133194603025913, 46.66258290410042, 47.94684179127216, 43.89022506773472, 35.37725307047367, 26.34600218385458, 24.118535108864307, 15.351661685854197, 12.573345769196749, 7.435595383867621, 3.5005149012431502, 2.036657938733697, 0.2990770828910172, 1.300337843131274, 1.7873450042679906, 2.5708631984889507, 4.173595821484923, 5.889690136536956, 3.3409137278795242, 6.79979782551527, 1.9253385183401406, 7.73799360729754, 14.851815607398748, 21.01057168096304, 35.410159304738045, 43.206075578927994, 50.46344295144081, 51.280953884124756, 50.559915974736214, 47.51166634261608, 48.59004467725754, 50.708791986107826, 52.2101104259491, 51.25289238989353, 52.50967115163803, 52.515127658843994, 53.078861609101295, 51.61920793354511, 50.05969561636448, 47.82223887741566, 47.51927733421326, 44.96678330004215, 42.63978436589241, 38.653011694550514, 37.83308409154415, 37.53960303962231, 38.28641876578331, 39.27136771380901, 41.75193540751934, 43.98889817297459, 46.908251121640205, 47.60407358407974, 52.61062793433666, 51.76645003259182, 58.06327074766159, 30.3098563849926, 42.307799980044365, 49.41436484456062, 47.851048931479454, 57.84603260457516, 51.21241316199303, 53.812811225652695, 48.02272751927376, 51.01842597126961, 50.97470171749592, 49.38981056213379, 40.8337526768446, 36.27463571727276, 36.3015952706337, 36.377800181508064, 39.96139168739319, 46.18204928934574, 50.80916740000248, 53.27409513294697, 53.122175484895706, 53.17058868706226, 53.84212665259838, 53.971726298332214, 55.38382172584534, 50.921284183859825, 49.97657127678394, 55.37389285862446, 57.28790335357189, 51.870290860533714, 44.78080227971077, 36.7106357216835, 32.92673036456108, 28.73050343245268, 12.523981668055058, 8.473994638770819, 7.091157641261816, 15.92988995835185, 14.820111058652401, 8.724998719990253, 7.614675024524331, 6.232397072017193, 3.60962200909853, 1.4248438621871173, 0.8803086786065251, 0.39044525823555887, 0.18869313964387402, 0.9048004425130785, 2.906692740507424, 12.82436029985547, 22.044351808726788, 28.503860794007778, 35.73624640703201, 28.71207632124424, 35.22272676229477, 41.64015680551529, 40.75421154499054, 27.261648550629616, 9.90122465416789, 1.0339321196079254, 0.058098247900488786, 0.024386336262978148, 0.08198877199902199, 0.0406621413276298, 0.024004857514228206, 0.04129111519432627, 0.038337103978847153, 0.023331783377216198, 0.023988342873053625, 0.04686344938818365, 0.08637251215986907, 0.02488514299329836, 0.008519646598870168, 0.10111116425832734, 0.007668202370041399, 0.02211634400737239, 0.009381931286043255, 0.07804951892467216, 0.09379845665534958, 0.08315042607137002, 0.02332856060093036, 0.010283800274919486, 0.042482722346903756, 0.045916654489701614, 0.061856153479311615, 0.0610429637163179, 0.026327171181037556, 0.08999719851999544, 0.010914761242020177, 0.01773748346749926, 0.043583234582911246, 0.07267609515110962, 0.02361027800361626, 0.028914381473441608, 0.054320371127687395, 0.0021747684468209627, 0.02940460341051221, 0.03141769382636994, 0.06023697649652604, 0.01243469452674617, 0.023776741727488115, 0.07190866992459632, 0.029146373126422986, 0.0602074612834258, 0.03456857826677151, 0.030643427853647154, 0.031174065297818743, 0.037316120287869126, 0.004463882833078969, 0.02160757765523158, 0.04818977860850282, 0.058057689529960044, 0.087710448569851, 0.08257897236035205, 0.016219158787862398, 0.0439060836652061, 0.03882698823872488, 0.046591270438511856, 0.0036038964844919974, 0.02326254099898506, 1.4175190427340567, 12.77178157120943, 32.893873527646065, 51.90699689090252, 55.67175507545471, 48.98539446294308, 42.491831704974174, 33.38336706161499, 28.07843752205372, 24.33011155575514, 18.59394695609808, 11.123779602348804, 4.4637245032936335, 1.7826361069455743, 0.3673563612392172, 0.3281786822481081, 4.108021315187216, 4.545489465817809, 7.5004265550524, 6.24824364669621, 6.225058240815997, 9.44954764097929, 5.161833493039012, 8.617905266582966, 15.382421035319567, 22.916881889104843, 36.4496885240078, 47.62163624167442, 54.018186405301094, 53.076323345303535, 51.477574333548546, 49.38805125653744, 50.48982493579388, 54.24590438604355, 54.75515305995941, 53.006384298205376, 51.55452400445938, 52.35048249363899, 53.46117429435253, 53.46496269106865, 52.031812593340874, 50.27479827404022, 48.853351548314095, 45.99122352898121, 43.94151471555233, 38.76548185944557, 40.02574123442173, 38.954259529709816, 40.29452361166477, 40.88226467370987, 42.70233280956745, 44.99393284320831, 49.174278527498245, 50.03599248826504, 54.346488788723946, 52.90991887450218, 57.702860087156296, 34.53406311571598, 45.80389358103275, 52.15569734573364, 49.84661445021629, 56.484626457095146, 51.07786238193512, 53.34817215800285, 48.777237832546234, 53.28365162014961, 54.17316108942032, 50.97904868423939, 43.171372041106224, 38.79523046314716, 37.20657750964165, 38.50829266011715, 42.15732045471668, 48.48232805728912, 53.67979176342487, 54.01144176721573, 53.0899266153574, 52.72451922297478, 54.555868953466415, 54.70447897911072, 57.39585556089878, 53.53776678442955, 53.47551092505455, 57.17254914343357, 59.23828549683094, 54.7556584328413, 47.553483098745346, 40.26543237268925, 31.174967363476753, 25.968055464327335, 11.128477100282907, 8.494865018874407, 9.518379047513008, 10.22417787462473, 11.636977214366198, 11.198528241366148, 7.922142650932074, 5.554085969924927, 7.3729524202644825, 4.004464996978641, 0.7486798823811114, 0.48011724022217095, 0.36127956700511277, 0.9319042693823576, 3.2293065916746855, 15.274868756532669, 24.003507681190968, 33.47142733633518, 42.26936884224415, 32.3149935901165, 39.087089002132416, 47.476544827222824, 46.375398114323616, 32.83314898610115, 12.45361989364028, 1.950950212776661, 0.055678193384665065, 0.028734815132338554, 0.033693901568767615, 0.04607595277775545, 0.013878199588361895, 0.03152589524688665, 0.014446633686020505, 0.03474658980849199, 0.016138138526002876, 0.06382108593243174, 0.034573554366943426, 0.025598977736080997, 0.013525598733394872, 0.05706223571905866, 0.04986226405890193, 0.009308338994742371, 0.03182547057804186, 0.03372393999597989, 0.0431964235031046, 0.03740917076356709, 0.04080804385012016, 0.05676436732755974, 0.0869043574493844, 0.002789577961266332, 0.016584508812229615, 0.08399583617574535, 0.04728913045255467, 0.032281260573654436, 0.06866367373731919, 0.12129022637964226, 0.08616661070846021, 0.14657072257250547, 0.11200798500794917, 0.1743182141217403, 0.19632105220807716, 0.1371064843260683, 0.10360921107348986, 0.15146049612667412, 0.147435829276219, 0.08544260854250751, 0.1157406167476438, 0.15696537651820108, 0.08887652584235184, 0.14445745706325397, 0.1370366630726494, 0.09053999790921807, 0.060211828822502866, 0.13003642932744697, 0.1567948012962006, 0.120882349438034, 0.08700750113348477, 0.15080286422744393, 0.153765027935151, 0.20650306600145996, 0.11711697414284572, 0.1559103690669872, 0.11727874749340117, 0.12536312540760264, 0.1036784979805816, 0.1836236476083286, 1.7964709270745516, 15.264371819794178, 35.77308923006058, 58.553113862872124, 61.4711444824934, 57.83415824174881, 47.48042441904545, 38.557914197444916, 35.76167844235897, 28.259664997458458, 20.932894349098206, 12.031371351331472, 5.654223896563053, 3.0367991840466857, 0.8131969172973186, 3.1707265600562096, 5.970869930461049, 9.02114912867546, 12.821809686720371, 15.62310392037034, 12.099757231771946, 13.3859739638865, 6.199042461812496, 10.895978026092052, 17.718236446380615, 23.819654546678066, 39.9311301112175, 47.531478479504585, 56.64603799581528, 54.05676573514938, 55.364689752459526, 50.97358837723732, 53.7635088711977, 55.40785163640976, 57.33509302139282, 53.612554371356964, 51.6576124727726, 53.78627724945545, 55.070817321538925, 55.86250863969326, 55.34070543944836, 52.86620981991291, 53.10429364442825, 51.66064091026783, 47.38731041550636, 41.95153869688511, 41.6746361553669, 40.380782783031464, 42.686677649617195, 42.51716494560242, 45.8602711558342, 48.112129122018814, 50.43003134429455, 51.2244813144207, 56.625686287879944, 54.27689932286739, 58.332877680659294, 38.488514721393585, 46.82974733412266, 54.99265931546688, 53.08050312101841, 56.40345521271229, 51.36969432234764, 53.44048820436001, 50.367034524679184, 55.32194584608078, 55.97662791609764, 53.903968334198, 45.94065584242344, 40.096516236662865, 39.898497462272644, 40.24331755936146, 43.57333727180958, 50.69485813379288, 55.85544861853123, 58.093638718128204, 56.22005805373192, 54.007030203938484, 56.71542227268219, 56.72402881085873, 59.85858701169491, 57.14609116315842, 56.579769551754, 59.86182443797588, 59.59136255085468, 55.5006692558527, 50.90010792016983, 42.33671262860298, 37.31331758201122, 35.29998801648617, 15.884810127317905, 13.72840778902173, 13.275106362998486, 26.190402433276176, 23.03140964359045, 14.979123026132584, 14.8422771692276, 14.444330222904682, 11.689900774508715, 6.804051697254181, 2.0614166976884007, 0.886792199453339, 1.018301302101463, 1.7561993817798793, 4.035683171823621, 18.265635073184967, 30.437512435019016, 39.71163868904114, 50.62119148671627, 43.10929097235203, 49.20344956219196, 58.08636590838432, 55.79485706984997, 37.66078233718872, 13.6841544136405, 2.5290291057899594, 0.2361147731426172, 0.13635310053359717, 0.2544323285110295, 0.19887700880644843, 0.15976048278389499, 0.15814558428246528, 0.10194933842285536, 0.16899594658752903, 0.13468000281136483, 0.19618543214164674, 0.13154031737940386, 0.07343853314523585, 0.19322353560710326, 0.22778328973799944, 0.1167645950044971, 0.11072011388023384, 0.10792261789902113, 0.16707183967810124, 0.11274763164692558, 0.14363630034495145, 0.15911414637230337, 0.13509158306987956, 0.28044172504451126, 0.13145759759936482, 0.11302786660962738, 0.14325863623525947, 0.1408871478633955, 0.14176371332723647, 0.13977821596199647], [0.0693500267516356, 0.037442088723764755, 0.018026104698947165, 0.040852958627510816, 0.06543216237332672, 0.03200090315658599, 0.012429410435288446, 0.006107998760853661, 0.0913804059382528, 0.04416443269292358, 0.058727852592710406, 0.022585388760489877, 0.08138838937156834, 0.07255836084368639, 0.03764112901990302, 0.01763382399076363, 0.04778937880473677, 0.013543639415729558, 0.08247375808423385, 0.10765167462523095, 0.06954086260520853, 0.03791396848100703, 0.024207378482969943, 0.033491135691292584, 0.012297000157559523, 0.04935911019856576, 0.04471881329664029, 0.012058869087923085, 0.015983641933416948, 0.037967024618410505, 0.09264668056857772, 0.18188975314842537, 6.085279891267419, 23.512161746621132, 40.63182391226292, 47.6212752610445, 45.301252752542496, 33.60527515411377, 23.144753761589527, 31.717760637402534, 25.970130153000355, 23.24465610086918, 13.28400643542409, 7.435664730146527, 2.0798934437334538, 1.155364578589797, 0.2634478791151196, 3.3949879137799144, 2.092244680970907, 4.111925130710006, 4.242932600900531, 4.0688534919172525, 4.857196714729071, 5.496510984376073, 8.147081080824137, 11.366876307874918, 19.296582452952862, 28.644584342837334, 37.47042015194893, 47.85977706313133, 51.67112074792385, 51.647440418601036, 49.12042401731014, 51.87676951289177, 53.572474122047424, 50.968036875128746, 51.78421787917614, 47.504765912890434, 49.94547374546528, 50.57407781481743, 52.843464240431786, 51.53451047837734, 49.48921702802181, 48.88082027435303, 48.04603546857834, 45.550207793712616, 43.843590170145035, 40.61041206121445, 39.260108917951584, 38.07664342224598, 39.847352206707, 45.97360007464886, 45.01909889280796, 46.709734573960304, 48.05628351867199, 53.68467450141907, 50.965266823768616, 59.678978249430656, 32.03936778008938, 27.865694537758827, 43.382306322455406, 43.89236055314541, 52.31754966080189, 52.12479740381241, 52.81623490154743, 53.292615339159966, 53.94081875681877, 51.332961693406105, 47.51676946878433, 41.028518825769424, 36.83835066854954, 36.62313401699066, 37.81301736831665, 38.31957958638668, 45.013057217001915, 50.247850120067596, 52.69192837178707, 52.16506004333496, 50.85123874247074, 53.924494832754135, 52.46025860309601, 52.71071836352348, 53.53546790778637, 55.36501653492451, 57.01201155781746, 54.874006882309914, 53.999537006020546, 46.163016110658646, 38.58402259647846, 32.13638797402382, 26.256370693445206, 9.415972642600536, 9.888397492468357, 11.092021856456995, 5.343905473127961, 9.55332862213254, 8.224098198115826, 6.618132898584008, 4.06879554502666, 4.304593317210674, 2.3754627211019397, 0.45382276992313564, 0.20103567891055718, 0.22639961476670578, 1.2070995150133967, 4.720332808792591, 14.202135019004345, 28.769422844052315, 34.415505677461624, 28.61955128610134, 33.01330491900444, 40.54090619087219, 42.972369119524956, 40.6216062605381, 22.562290616333485, 8.439684379845858, 1.2105977023020387, 0.025544526361045428, 0.05246200365945697, 0.062017745003686287, 0.0201174749963684, 0.03612731474277098, 0.05235804732365068, 0.017490969839855097, 0.027922927838517353, 0.044673809461528435, 0.07530513845267706, 0.09295896888943389, 0.013693110740859993, 0.04093725176062435, 0.08599876658990979, 0.0860986670886632, 0.04289444361347705, 0.05964665368082933, 0.043195273174205795, 0.003478717276266252, 0.01015197722153971, 0.028953518631169572, 0.022617360482399818, 0.030858017998980358, 0.03925147815607488, 0.028976115172554273, 0.029162414648453705, 0.04020080748887267, 0.015658230586268473, 0.06146666324639227, 0.09013888935442083, 0.013403369794104947, 0.02103529459418496, 0.029978246457176283, 0.026473326033737976, 0.026714152954809833, 0.045412491308525205, 0.018774746167764533, 0.05770434559963178, 0.07560214595287107, 0.019038887658098247, 0.005900361611566041, 0.0754052319098264, 0.0482263664889615, 0.027481053111841902, 0.013545696092478465, 0.02918183665315155, 0.035591510095400736, 0.0737342270440422, 0.05855488394445274, 0.02876912276406074, 0.023103960738808382, 0.03824934872682206, 0.060203483371878974, 0.035780731777776964, 0.029442170925904065, 0.04688295673986431, 0.03174618323100731, 0.02974668524984736, 0.035236978728789836, 0.014940297332941554, 0.19767121179029346, 8.022165633738041, 26.33216142654419, 46.76596395671368, 53.021518886089325, 52.508481815457344, 40.882097482681274, 27.24697183817625, 37.17886559665203, 24.994547702372074, 23.734451718628407, 13.731704112142324, 7.241123719140887, 2.0316493324935436, 1.0471222805790603, 0.3811590018449351, 2.176765683107078, 2.9320908151566982, 7.208646861836314, 7.326046787202358, 7.358490871265531, 6.354231359437108, 5.6311363354325294, 5.872703623026609, 13.410381954163313, 20.96535410732031, 31.22054021805525, 41.135030910372734, 50.436726585030556, 54.07431319355965, 52.43601590394974, 51.10275864601135, 52.811230570077896, 54.91303838789463, 53.166241720318794, 52.67750434577465, 49.11325000226498, 51.12727113068104, 50.875219255685806, 52.93305583298206, 53.67066465318203, 51.212420761585236, 50.596447214484215, 50.46628899872303, 47.02597260475159, 44.79298062622547, 41.491622775793076, 40.500373765826225, 39.00014586746693, 41.676562651991844, 47.84177742898464, 46.14483028650284, 49.52235125005245, 49.73893962800503, 55.484569519758224, 53.7861442565918, 59.35606397688389, 34.10236068069935, 33.1977242231369, 42.86086790263653, 45.98786070942879, 53.45089964568615, 54.153580740094185, 53.29014167189598, 52.2371231764555, 55.29751315712929, 52.88320630788803, 50.2008618414402, 43.454456850886345, 38.61103914678097, 37.540108412504196, 37.959271520376205, 40.757106989622116, 46.44729025661945, 52.310447841882706, 54.905932769179344, 52.89905525743961, 50.86630493402481, 54.54228848218918, 53.243856355547905, 53.83372910320759, 55.65450020134449, 56.47474318742752, 58.37249435484409, 56.592844650149345, 55.04545748233795, 45.67377716302872, 40.882998034358025, 27.647713534533978, 18.96396730095148, 12.822603844106197, 10.0330756790936, 11.418502237647772, 9.280570708215237, 10.433484893292189, 9.65916434302926, 7.026107981801033, 5.397681137546897, 4.4595475774258375, 4.235613718628883, 1.152140332851559, 0.26049520005472004, 0.2515511034289375, 1.2242299458011985, 5.192708261311054, 14.9289077706635, 27.964977510273457, 36.66704826056957, 35.095046013593674, 36.04087606072426, 45.32401733100414, 48.724432066082954, 47.235394567251205, 28.07202536612749, 9.776157215237617, 1.4009871985763311, 0.0308765549925738, 0.0492337243485963, 0.014973926827224204, 0.03686665710119996, 0.025146506995952222, 0.06500213974504732, 0.05103049727040343, 0.025412411087017972, 0.022914338296686765, 0.02365038923016982, 0.04328347371483687, 0.03778182166570332, 0.09582192229572684, 0.06729156884830445, 0.05676214459526818, 0.040832931772456504, 0.054119649867061526, 0.04059413833601866, 0.02107824639097089, 0.032863757442100905, 0.011079801897722064, 0.03246890519221779, 0.001184215245757514, 0.030215555598260835, 0.07482665358111262, 0.02646557244588621, 0.01349793888948625, 0.05249955262115691, 0.02681144109374145, 0.21610978175885975, 0.1803436962654814, 0.17810999503126368, 0.19029371469514444, 0.10264171025482938, 0.12139454265707172, 0.1380240757134743, 0.12423496445990168, 0.16899222100619227, 0.11261014878982678, 0.09666085345088504, 0.154538627830334, 0.25823325267992914, 0.14504788006888703, 0.16796988289570436, 0.1397623191587627, 0.17095267830882221, 0.09492437631706707, 0.1639505149796605, 0.16355465340893716, 0.2477678275317885, 0.16143705375725403, 0.13070464425254613, 0.21914230106631294, 0.1576081060920842, 0.14430824085138738, 0.16118605941301212, 0.18491047230781987, 0.08373020667931996, 0.24332209577551112, 0.15243101748637855, 0.40420233097393066, 9.667240809649229, 30.960835553705692, 53.14292997121811, 60.22897593677044, 61.53521664440632, 48.4970560669899, 33.607536032795906, 44.40557241439819, 36.75177991390228, 32.68532171845436, 18.553648218512535, 10.132062267512083, 3.156620766967535, 1.8560302373953164, 0.9504712605848908, 7.533056354150176, 8.005540575832129, 9.642984811216593, 12.70454227924347, 11.41000684350729, 10.819107200950384, 9.711568281054497, 12.326188031584024, 15.475382097065449, 23.90993770211935, 31.944266483187675, 39.58442531526089, 52.28444203734398, 55.3095281124115, 56.11324958503246, 53.00789661705494, 55.17041377723217, 57.79664285480976, 55.75214736163616, 54.00340139865875, 52.779312282800674, 50.18742196261883, 51.46836742758751, 52.839364260435104, 56.14602282643318, 54.75058190524578, 53.3103109896183, 52.6210355758667, 50.30808828771114, 47.658091485500336, 44.34277318418026, 43.31810496747494, 40.89295729994774, 42.98831306397915, 49.35101464390755, 49.560812786221504, 51.134361550211906, 52.44935318827629, 56.96058891713619, 56.57142139971256, 60.231476202607155, 39.77168306708336, 39.36956584453583, 45.43806441128254, 51.042718067765236, 55.03673695027828, 56.46843932569027, 53.83465625345707, 51.87888979911804, 55.749791488051414, 57.18854248523712, 52.16855585575104, 46.87724098563194, 41.250993087887764, 39.92836005985737, 41.26863934099674, 43.82706865668297, 48.19201983511448, 53.5569291561842, 58.008428290486336, 55.288317650556564, 52.386029586195946, 54.13206249475479, 55.500752851367, 55.61498612165451, 57.30751030147076, 59.17464271187782, 56.63928955793381, 59.97772581875324, 55.58799996972084, 48.57849709689617, 42.698742002248764, 36.40168949961662, 29.70672994852066, 16.911456137895584, 17.81921412795782, 20.123205296695232, 16.20125524699688, 14.98276038095355, 17.18031831085682, 16.16372086107731, 14.860700480639935, 12.914290074259043, 8.155636321753263, 2.150045041926205, 1.6783845447935164, 0.5737704585772008, 1.8242983776144683, 6.877854187041521, 19.266254380345345, 39.52630743384361, 45.4609239846468, 41.05768606066704, 46.53794199228287, 55.424612537026405, 58.25907804071903, 55.238718912005424, 32.82269574701786, 12.272470314055681, 1.7807020107284188, 0.14874805026920512, 0.1317051038495265, 0.1658739391132258, 0.11761449510231614, 0.13582835759734735, 0.1278595469193533, 0.10049714095657691, 0.10657243605237454, 0.0943938668933697, 0.13394493522355333, 0.2542841067770496, 0.0651180706336163, 0.14312363957287744, 0.26784106681589037, 0.16437258920632303, 0.1285457515041344, 0.13462251605233178, 0.15414392400998622, 0.12048963457345963, 0.16244336147792637, 0.08198652329156175, 0.09755249935551547, 0.1483198904315941, 0.11442680755862966, 0.15424409910338, 0.12868098565377295, 0.10933985278825276, 0.1465079517220147, 0.21120678313309327], [0.03909302962711081, 0.07895324699347839, 0.03438664447457995, 0.04809656114957761, 0.030639668875664938, 0.037105001538293436, 0.03480364612187259, 0.057185558398487046, 0.07989198958966881, 0.011562467843759805, 0.018510999871068634, 0.05606523453025147, 0.014622057915403275, 0.04648952941352036, 0.012160332735220436, 0.05404079667641781, 0.02498485609976342, 0.05256044583802577, 0.0726878507703077, 0.016773906754679047, 0.007981606231624028, 0.04715823415608611, 0.05535201577004045, 0.0342583345627645, 0.047116618225118145, 0.10637844607117586, 0.01047141613526037, 0.026273959192621987, 0.14346584386657923, 0.02975220682856161, 0.14486951229628175, 0.07295081595657393, 3.008041614666581, 17.344169318675995, 35.3723931312561, 48.4172223508358, 40.11653356254101, 34.42485697567463, 24.5755859836936, 23.64247005432844, 24.362616911530495, 18.57558824121952, 16.81282103061676, 8.913180772215128, 3.1624320801347494, 0.8407196716871113, 0.47105160949286073, 1.066948666702956, 2.4142688512802124, 7.858677981421351, 4.595379838719964, 4.174634115770459, 9.155407324433327, 3.8322869734838605, 3.6621451657265425, 10.011100508272648, 17.11606565862894, 26.327749863266945, 37.4839436262846, 41.040662974119186, 52.779604867100716, 50.419505909085274, 51.747074872255325, 50.17705611884594, 57.48468719422817, 49.29640017449856, 51.76738478243351, 51.93466700613499, 47.611072808504105, 50.96526302397251, 49.49596926569939, 52.251235619187355, 51.26635506749153, 52.28705249726772, 48.934541791677475, 49.51730892062187, 47.69101671874523, 48.14554452896118, 44.54249806702137, 45.89063912630081, 44.42748203873634, 45.09903900325298, 44.092066437006, 46.72676905989647, 46.31437338888645, 51.15901082754135, 47.266066521406174, 57.94478930532932, 37.077509835362434, 32.71521471440792, 54.98878352344036, 46.62452794611454, 49.30958166718483, 51.42192251980305, 52.12851360440254, 51.727213338017464, 53.889833092689514, 52.51860447227955, 49.717523977160454, 44.21616777777672, 36.67965978384018, 34.803328067064285, 38.28626297414303, 37.39464841783047, 42.67911605536938, 47.948240116238594, 50.68757012486458, 54.42726105451584, 50.29219754040241, 53.258827552199364, 51.90820902585983, 55.00019811093807, 54.52321730554104, 56.597320809960365, 55.50166480243206, 54.483870416879654, 51.64291486144066, 43.46168406307697, 34.83170874416828, 26.238327361643314, 17.02806618064642, 10.667705275118351, 4.412805810570717, 8.644147608429193, 7.57608762010932, 10.044708754867315, 9.437118507921696, 4.705466581508517, 4.293352570384741, 4.2318120226264, 4.403017535805702, 0.5872142559383065, 0.5635130277369171, 0.2886526094516739, 0.9218851570039988, 4.895331943407655, 18.328702189028263, 27.812892571091652, 32.13499344885349, 33.68624500930309, 32.41904340684414, 39.97028701007366, 46.610510498285294, 38.44958961009979, 23.160862997174263, 6.61567110568285, 0.6854667118750513, 0.06555488391313702, 0.018025998942903243, 0.03385286217962857, 0.02535012819862459, 0.03970177625888027, 0.009265355656680185, 0.09062876619282179, 0.028840543345722836, 0.01697130504908273, 0.03793152398429811, 0.00612797088251682, 0.045431093240040354, 0.05404678580816835, 0.06409575478755869, 0.006090793922339799, 0.013436396293400321, 0.09787510352907702, 0.03919383554602973, 0.04882408851699438, 0.03730576361704152, 0.04112327849725261, 0.0417137386102695, 0.020585911188391037, 0.023566893905808683, 0.08453113987343386, 0.04770103725604713, 0.09327402542112395, 0.026048136642202735, 0.048323487644665875, 0.04358113059424795, 0.027155235438840464, 0.046533327258657664, 0.07533814175985754, 0.07939708841149695, 0.01331784469584818, 0.004421387920956477, 0.014286517180153169, 0.07342525612330064, 0.0719555513933301, 0.023249863261298742, 0.065814806293929, 0.00704937598129618, 0.02986878709634766, 0.026038885771413334, 0.06281720503466204, 0.05290905486617703, 0.035220729405409656, 0.04853045778872911, 0.027989042064291425, 0.024179204701795243, 0.0028097045424146927, 0.07275697440491058, 0.05636412708554417, 0.04686762396886479, 0.031146709734457545, 0.017965343213290907, 0.050194505020044744, 0.09504929461400025, 0.06395925898686983, 0.11302440820145421, 0.10537330352235585, 4.1934269573539495, 21.89797416329384, 42.9802954941988, 55.205911472439766, 47.362657338380814, 40.89924596250057, 29.556178227066994, 30.85600107908249, 27.8691428527236, 22.824050970375538, 21.554808877408504, 9.989386573433876, 3.2134759286418557, 0.6673708360176533, 0.6042030255775899, 1.8417283985763788, 4.590771161019802, 6.550079975277185, 7.409643726423383, 4.809768609702587, 6.835480760782957, 5.884796474128962, 6.039291433990002, 10.910672787576914, 17.751011587679386, 27.642213329672813, 40.80169379711151, 45.88920280337334, 54.85622763633728, 52.47830383479595, 54.87532541155815, 51.61614529788494, 58.94355811178684, 50.831646993756294, 55.121582597494125, 52.67055831849575, 48.22880566120148, 50.47082215547562, 50.08105047047138, 54.136018082499504, 52.17064954340458, 53.70141640305519, 52.12996132671833, 51.55809201300144, 49.105205833911896, 49.55786794424057, 44.303726479411125, 44.67117816209793, 45.82993358373642, 47.597370743751526, 46.04443207383156, 48.84053863584995, 48.75055946409702, 52.84912593662739, 48.53297933936119, 60.288621336221695, 38.30863997340202, 35.76413691043854, 56.913068667054176, 48.45791436731815, 47.93344371020794, 50.2267574518919, 52.14302122592926, 51.79458752274513, 55.172526463866234, 53.25315825641155, 51.951986476778984, 46.06162615120411, 37.88774415850639, 36.20455227792263, 42.382944747805595, 40.318682715296745, 45.89818932116032, 51.488859727978706, 53.709745556116104, 55.880538672208786, 51.353104412555695, 53.16896237432957, 53.14594700932503, 56.89426727592945, 55.442688167095184, 57.18298718333244, 57.531500682234764, 57.11475804448128, 54.03693079948425, 45.97617253661156, 34.894815757870674, 27.248457558453083, 17.12531816214323, 12.694073840975761, 8.002026714384556, 10.655528828501701, 8.182768765836954, 9.476906172931194, 9.215104971081018, 5.1868627499789, 8.082682136446238, 3.746785861440003, 3.711083452217281, 1.2678350997157395, 0.42161053279414773, 0.5382452148478478, 1.2569556897506118, 5.5572250764817, 18.33568811416626, 33.79257470369339, 39.149291664361954, 37.166238874197006, 41.448711678385735, 47.77679331600666, 50.140650272369385, 45.077380165457726, 27.415228709578514, 8.822060711681843, 0.8908056153450161, 0.06008776028465945, 0.019745456775126513, 0.033282313888776116, 0.057683212944539264, 0.03795129479840398, 0.038751114771002904, 0.08916436781873927, 0.07918775081634521, 0.016942003203439526, 0.05002625643101055, 0.04437617113580927, 0.056936452820082195, 0.02318798484338913, 0.052009531063959, 0.013663636345881969, 0.01328345171714318, 0.09523936605546623, 0.038955821364652365, 0.08047767769312486, 0.03688508833874948, 0.04126601204916369, 0.06155285627755802, 0.03897297239745967, 0.030638769021607004, 0.04526187985902652, 0.059776102789328434, 0.08418300581979565, 0.009426581673324108, 0.047742389724589884, 0.13684609439224005, 0.0925088934309315, 0.11340537486830726, 0.16231142246397212, 0.1699342142092064, 0.10422344959806651, 0.15350521687651053, 0.11380033101886511, 0.19748249847907573, 0.1906432514078915, 0.09142856390099041, 0.14621651032939553, 0.10383151398855262, 0.16221749625401571, 0.1332774624461308, 0.1832162233768031, 0.13181188405724242, 0.15075425355462357, 0.2601515263086185, 0.0724389121751301, 0.15973283036146313, 0.1713736986857839, 0.1409282034728676, 0.12998305406654254, 0.16494401323143393, 0.18981793866259977, 0.11647107559838332, 0.1629813591716811, 0.32432503590825945, 0.19461917399894446, 0.3297989984275773, 0.38188241771422327, 4.701950820162892, 24.14155427366495, 47.08168521523476, 61.73074655234814, 53.60406942665577, 49.42902445793152, 36.38835981488228, 36.99109107255936, 33.97261664271355, 28.25389500707388, 23.527592718601227, 12.038505468517542, 4.396906513720751, 1.6318603162653744, 1.1161139910109341, 4.411372812464833, 7.385088969022036, 16.203694716095924, 14.581750798970461, 10.127379968762398, 19.15776640176773, 9.238097537308931, 6.073736110702157, 11.251003425568342, 21.294826827943325, 30.985283441841602, 43.403581380844116, 47.411553114652634, 57.05803468823433, 53.67867462337017, 56.7715984582901, 53.18514570593834, 60.458392426371574, 51.635854840278625, 54.737362414598465, 55.02026483416557, 50.94319000840187, 50.10487139225006, 49.67488266527653, 53.63240450620651, 54.79500152170658, 55.357424542307854, 54.385900273919106, 54.35919910669327, 53.362588584423065, 52.52090334892273, 47.43526764214039, 48.057290464639664, 47.8890772908926, 49.125846326351166, 48.39553691446781, 50.70187255740166, 51.397045254707336, 54.81616638600826, 52.88677431643009, 59.98438686132431, 43.00234191119671, 41.216950714588165, 55.47352351248264, 49.33715298771858, 50.93586020171642, 51.14843599498272, 53.244129940867424, 53.402258455753326, 55.742332488298416, 55.96877373754978, 56.03593893349171, 48.59100982546806, 40.91197147965431, 38.08938413858414, 43.606897071003914, 42.13374651968479, 47.642808705568314, 52.257322892546654, 57.864115834236145, 58.704604133963585, 53.30608941614628, 53.64910840988159, 54.785331040620804, 56.71581745147705, 56.39409251511097, 59.132875353097916, 58.9471261203289, 58.54318879544735, 56.641174256801605, 49.405731707811356, 38.688760176301, 29.042035415768623, 20.78093860298395, 13.719337675720453, 11.2070844322443, 17.22801525145769, 17.521270215511322, 20.703209973871708, 21.575829349458218, 14.067146312445402, 9.491970464587212, 7.69521027803421, 11.298907455056906, 3.589719389565289, 1.1038583423942327, 0.8961278828792274, 1.7493421747349203, 6.7659316677600145, 25.085581317543983, 39.382348358631134, 44.03297200798988, 45.645229294896126, 47.6375687867403, 53.87322798371315, 59.3160293251276, 51.877134293317795, 32.2427024692297, 10.132966618984938, 1.2815491575747728, 0.24120428832247853, 0.07465384449460544, 0.07841252561775036, 0.14606505283154547, 0.24879580596461892, 0.1366682312800549, 0.18567066901596263, 0.21282997884554788, 0.09155224281130359, 0.10103839667863213, 0.11920778968487866, 0.22979994246270508, 0.12316828302573413, 0.099670848576352, 0.12727510562399402, 0.09928478335496038, 0.18409071082714945, 0.10037237108917907, 0.16386631090426818, 0.2730357740074396, 0.14136014826362953, 0.21097607910633087, 0.16619157831883058, 0.09837850971962325, 0.09207954615703784, 0.24821884551784024, 0.2203782441210933, 0.16934428102103993, 0.14318013185402378], [0.02894380762882065, 0.033014283544616774, 0.10746653846581466, 0.01874582467280561, 0.05390361067838967, 0.010619424501783215, 0.03329717910673935, 0.032224972383119166, 0.04182586599199567, 0.054768212721683085, 0.02854658607247984, 0.043470186938066036, 0.047096717535168864, 0.023798748261469882, 0.08770080807153136, 0.021639024307660293, 0.0448113665333949, 0.019460459079709835, 0.022901163320057094, 0.031250165120582096, 0.019471060659270734, 0.03234962350688875, 0.09465039023780264, 0.014455105301749427, 0.019482480456645135, 0.019807867683994118, 0.04173541303316597, 0.05852746900927741, 0.0037630818269462907, 0.050343839975539595, 0.06855333864223212, 0.025518287729937583, 1.0318208578974009, 9.54347100108862, 26.966505087912083, 37.52308912575245, 40.11877164244652, 34.20121617615223, 29.896527864038944, 23.579366840422153, 18.971268609166145, 20.62615390866995, 18.07146169245243, 11.691351346671581, 3.8727662013843656, 0.9723185445182025, 0.5535461031831801, 1.4250737498514354, 2.3570664832368493, 4.86341318115592, 5.848321756348014, 5.043164435774088, 2.859178427606821, 4.0257039573043585, 3.4776864387094975, 6.8908129166811705, 16.131781674921513, 18.020392432808876, 30.412129797041416, 42.124600410461426, 47.37001374363899, 48.30035202205181, 54.314186722040176, 53.91807317733765, 53.574799597263336, 54.03343118727207, 49.461417719721794, 53.8221625238657, 47.49082826077938, 53.8508889824152, 51.02085404098034, 50.94659462571144, 52.16326653957367, 52.05553852021694, 53.36083307862282, 49.61641900241375, 47.135064750909805, 48.47554162144661, 48.340907245874405, 49.43014159798622, 47.076460495591164, 51.49127259850502, 49.16295513510704, 48.7982203066349, 45.29143787920475, 50.05573622882366, 46.7112734913826, 57.70034462213516, 37.5486845523119, 37.78139166533947, 49.51717592775822, 49.894594475626945, 53.031835332512856, 51.20531514286995, 56.58969081938267, 55.13555824756622, 56.46677501499653, 49.412445947527885, 50.2013748139143, 42.10747092962265, 36.82102359831333, 37.4791444838047, 37.03485332429409, 38.62126439809799, 41.84093043208122, 47.12116129696369, 51.164733320474625, 53.47393400967121, 51.79809853434563, 52.51868046820164, 53.19630190730095, 52.80289001762867, 55.49729883670807, 54.92800958454609, 55.48571705818176, 51.91888265311718, 50.82936331629753, 44.73635986447334, 33.72669003903866, 22.76285905390978, 17.056783139705658, 13.847295809537172, 9.392657093703747, 8.153205402195454, 3.68770235683769, 5.437883930280805, 6.326493322849274, 2.379805650562048, 5.976762939244509, 1.9258381915278733, 2.403247067704797, 1.702330622356385, 0.26777281891554594, 0.2954171964665875, 1.3473943993449211, 8.570957835763693, 16.065505631268024, 24.45408370345831, 32.30482913553715, 32.268012911081314, 30.514754690229893, 34.99622851610184, 38.9931770414114, 38.07088293135166, 18.638729453086853, 5.551021909341216, 0.3550101409200579, 0.020510902322712354, 0.05430111981695518, 0.022498609432659578, 0.04441554207005538, 0.04092015267815441, 0.04582027919241227, 0.014864567656331928, 0.010634352802298963, 0.014396568403753918, 0.06496229383628815, 0.03894231056619901, 0.04672567709349096, 0.0028567309618665604, 0.01672504560701782, 0.00791096954344539, 0.0605719745362876, 0.02733824720053235, 0.13111260283039883, 0.031792793815839104, 0.06479916235548444, 0.03864171107125003, 0.05029978237871546, 0.011353403915563831, 0.07637575326953083, 0.04353852018539328, 0.012725108044833178, 0.006142689062471618, 0.022778393540647812, 0.03193955351889599, 0.030951543449191377, 0.051420792733551934, 0.03657504130387679, 0.015717563437647186, 0.04566442818031646, 0.03962167626013979, 0.005752503529947717, 0.0394099823461147, 0.01614110155060189, 0.035856679460266605, 0.032942781326710247, 0.025921878768713214, 0.04119726690987591, 0.006367580217556679, 0.07429866745951585, 0.04616203819750808, 0.07885199578595348, 0.019240896544943098, 0.02549906053900486, 0.028194184669700917, 0.012197811192891095, 0.07406964068650268, 0.08428828688920476, 0.027256408720859326, 0.053774124462506734, 0.01963158905709861, 0.06582012007129379, 0.02984984192153206, 0.0077071553823770955, 0.06766967082512565, 0.014445305241679307, 0.05098713358165696, 1.800777877215296, 12.419945150613785, 33.638671562075615, 46.11407473683357, 46.584417298436165, 39.15111556649208, 33.705677166581154, 28.584919944405556, 25.101215578615665, 21.845179796218872, 22.362865917384624, 13.27992545440793, 4.228783585131168, 0.9763861075043678, 0.44777530536521226, 1.3116352306678891, 4.067788124084473, 5.948026031255722, 6.748968902975321, 6.034374972805381, 6.755980476737022, 6.615379946306348, 4.313300075009465, 9.449679683893919, 15.33609677106142, 22.23728835582733, 33.72131712734699, 43.88213910162449, 50.645601376891136, 51.87731668353081, 54.389244094491005, 55.991587713360786, 53.956489115953445, 54.69929985702038, 50.234968811273575, 54.10543732345104, 48.26054535806179, 54.485629722476006, 50.58377489447594, 51.17770962417126, 52.191217839717865, 54.72822390496731, 53.95740866661072, 52.31243893504143, 49.87824395298958, 51.61212131381035, 48.38919885456562, 50.75720138847828, 47.30954758822918, 53.36585260927677, 48.79205323755741, 50.99580958485603, 47.824294567108154, 52.813202664256096, 49.37458477914333, 59.62700463831425, 40.18467530608177, 40.13216592371464, 52.67251901328564, 51.00416913628578, 53.43783974647522, 52.20654621720314, 55.72445064783096, 54.79779437184334, 58.00881206989288, 51.54755137860775, 51.8806567043066, 44.31890666484833, 39.57332231104374, 38.90698626637459, 39.043083563447, 40.7975710183382, 43.35488319396973, 49.62041638791561, 53.03991749882698, 54.51193191111088, 54.16137792170048, 54.26956571638584, 54.5651176571846, 52.91237734258175, 56.75237908959389, 57.727513164281845, 58.286656960844994, 53.640201687812805, 52.83931486308575, 44.9489014595747, 35.45946925878525, 25.50123531371355, 17.05992367118597, 11.276206523180008, 8.800258431583643, 11.731501892209053, 8.36978143081069, 8.933245595544577, 6.542455684393644, 4.852169584482908, 5.237116478383541, 3.581032818183303, 3.0074345972388983, 1.280283231753856, 0.141805644670967, 0.31528428196907043, 1.3429019716568291, 9.129622858017683, 20.91911818832159, 29.310867190361023, 32.89332635700703, 34.9295648932457, 35.73329396545887, 41.35226525366306, 48.618896529078484, 44.12926644086838, 22.908136658370495, 7.166879503056407, 0.32479018438607454, 0.045559095160569996, 0.05383754469221458, 0.08607714480604045, 0.04531473190581892, 0.05878043004486244, 0.04261469846824184, 0.030869478614476975, 0.037389474164228886, 0.0688119548431132, 0.029801066120853648, 0.04710567896836437, 0.05935455177677795, 0.05196707650611643, 0.03982558504503686, 0.06074005243135616, 0.03885747566528153, 0.027690951028489508, 0.09028343003592454, 0.031043816525198054, 0.07210861935163848, 0.042161628443864174, 0.038640594138996676, 0.01861554064817028, 0.0610708053864073, 0.020561772835208103, 0.043017569623771124, 0.008927023518481292, 0.044337145300232805, 0.05204458269872703, 0.10182029378484003, 0.15396187518490478, 0.2529571467312053, 0.06385167725966312, 0.1596057746792212, 0.16009116894565523, 0.1313861584640108, 0.2827664581127465, 0.15698351460741833, 0.23639871884370223, 0.15696188842412084, 0.15824017842533067, 0.1411889644805342, 0.08951312527642585, 0.2364803254022263, 0.12221149881952442, 0.21041871135821566, 0.08535845641745254, 0.09273420204408467, 0.13032147340709344, 0.17768814344890416, 0.15504444600082934, 0.19258828688180074, 0.08310699558933266, 0.19483473821310326, 0.17731117695802823, 0.155054212664254, 0.11229902564082295, 0.1069184104562737, 0.15498091815970838, 0.2009096770780161, 0.1723268983187154, 2.198195345699787, 14.780667275190353, 38.37066784501076, 53.3774533867836, 53.01868423819542, 47.52506822347641, 41.61830797791481, 35.79964220523834, 28.633506037294865, 30.64515419304371, 24.473795145750046, 15.73374068364501, 5.3484205808490515, 1.5441066375933588, 1.1835109745152295, 1.4841870591044426, 7.512513231486082, 13.434910587966442, 15.602725613862276, 11.053938400000334, 6.164094787091017, 10.339303147047758, 8.392443414777517, 10.385619811713696, 18.301964923739433, 21.660861186683178, 35.67247062921524, 47.41403438150883, 52.16947540640831, 53.49095329642296, 56.8612926453352, 56.80888965725899, 54.184735268354416, 56.12660586833954, 52.697890251874924, 56.04936361312866, 52.160827070474625, 53.681611865758896, 52.209095880389214, 51.560033708810806, 53.61326493322849, 54.49594236910343, 57.60466195642948, 54.60047855973244, 51.118109822273254, 53.52843448519707, 51.68070763349533, 54.44193206727505, 49.87978667020798, 55.913277715444565, 52.78514876961708, 53.194462805986404, 51.19019575417042, 54.48385901749134, 50.52037909626961, 60.55953919887543, 42.36713759601116, 43.65336857736111, 52.556135058403015, 50.23835062980652, 52.70390532910824, 52.330229580402374, 57.12136968970299, 55.80550789833069, 59.97471258044243, 53.71905505657196, 55.68088598549366, 46.28584071993828, 41.41747735440731, 41.223288774490356, 41.21159300208092, 43.153433203697205, 45.68883195519447, 52.54302196204662, 57.14071065187454, 56.708806827664375, 53.60098019242287, 54.67806659638882, 55.22095866501331, 54.308122247457504, 56.564023196697235, 57.575673311948776, 58.94469425082207, 54.43250857293606, 54.39027763903141, 47.364709228277206, 37.73688085377216, 26.886412985622883, 21.03997640311718, 18.013640195131302, 16.01899042725563, 13.769878763705492, 12.581457383930683, 16.31652396172285, 10.549034792929888, 11.698770448565483, 16.229628324508667, 10.413468517363071, 6.101779555901885, 4.275859259068966, 0.8068788656964898, 0.7110676600132138, 2.174776727333665, 11.593670938163996, 23.14149733632803, 34.56241339445114, 44.636888802051544, 44.83015023171902, 43.010716661810875, 48.638731464743614, 55.57920344173908, 51.28139466047287, 27.019810527563095, 8.52870600298047, 0.7871094171423465, 0.08730018191272393, 0.15760902635520324, 0.1450157302315347, 0.14221483521396294, 0.15422631724504754, 0.18063256982713938, 0.09761080247699283, 0.17775714833987877, 0.11492207981063984, 0.18582589662401006, 0.1254931348375976, 0.138228774885647, 0.12586576718604192, 0.1353574203676544, 0.14603591611376032, 0.08914611098589376, 0.10828164668055251, 0.20633721083868295, 0.10185613951762207, 0.1836461792117916, 0.08593644844950177, 0.12276239503989927, 0.15079474513186142, 0.132105759694241, 0.09458377506234683, 0.2639910124707967, 0.07080207578837872, 0.2338149762363173, 0.18888450984377414], [0.09204630536260083, 0.021106193817104213, 0.00858794088344439, 0.04542171620414592, 0.027999773519695736, 0.02004835507250391, 0.07195781494374387, 0.023383776388072874, 0.04085771579411812, 0.03461776410404127, 0.033931804427993484, 0.03572408364561852, 0.01985388640605379, 0.015387658386316616, 0.03498756886983756, 0.03559445271093864, 0.057585316244512796, 0.05631793952488806, 0.02713769663387211, 0.036364872503327206, 0.04433211353898514, 0.05629748593491968, 0.02097014701575972, 0.010400605970062315, 0.05245144660875667, 0.05191486270632595, 0.06792343338020146, 0.07018972974037752, 0.04295502141758334, 0.018170342955272645, 0.07871083929785527, 0.14650349883595482, 0.5310348642524332, 5.884700054302812, 19.935385175049305, 41.76695980131626, 47.58051484823227, 43.62070932984352, 34.68801565468311, 21.747031062841415, 25.756211131811142, 23.89416664838791, 23.136502504348755, 16.17620889097452, 5.954382615163922, 1.2779009970836341, 0.7519999542273581, 2.2729185735806823, 4.905116893351078, 3.392890663817525, 3.95911134313792, 3.3061591302976012, 6.944030486047268, 4.46084663271904, 2.1259488724172115, 6.418382367119193, 8.589716479182243, 19.803214967250824, 25.77689342200756, 34.75110746920109, 41.466369330883026, 50.6038948148489, 51.58739224076271, 53.9221503585577, 53.29282432794571, 51.047357618808746, 49.06377665698528, 52.817542031407356, 52.424008548259735, 51.037949323654175, 52.374504804611206, 52.585667073726654, 49.071136862039566, 52.713549211621284, 52.22750209271908, 53.00611071288586, 50.9188599139452, 52.40735404193401, 49.502151533961296, 51.64403960108757, 49.234357103705406, 52.14171789586544, 50.64316190779209, 50.81358276307583, 46.06003783643246, 49.25907477736473, 46.0325463116169, 56.37457676231861, 39.16928619146347, 36.62167489528656, 55.10943464934826, 50.71782410144806, 53.8349374383688, 52.17707879841328, 53.763873651623726, 51.694010719656944, 52.762342393398285, 49.417051300406456, 50.93174122273922, 42.612467631697655, 38.462505117058754, 37.51286767423153, 38.72852884232998, 38.66788789629936, 41.00634701550007, 46.77410311996937, 50.4769816249609, 52.364332750439644, 52.5874187797308, 52.14469313621521, 53.76933395862579, 55.96528172492981, 55.305872708559036, 55.371582582592964, 56.5765967220068, 53.52202042937279, 50.081198662519455, 39.138728231191635, 32.10003152489662, 20.179788060486317, 14.150808323174715, 10.30429657548666, 5.454950714483857, 11.509026680141687, 5.040610022842884, 7.37010732293129, 5.53074904717505, 2.4502438958734274, 4.887050287798047, 1.7808861820958555, 1.9640014437027276, 0.5906818073708564, 0.07750242250040174, 0.4934799059992656, 2.0011590560898185, 7.405181340873241, 14.52268011868, 33.34946148097515, 38.11990030109882, 33.39200779795647, 34.37743552029133, 45.201530903577805, 47.14807525277138, 30.49708753824234, 18.182096555829048, 3.921531359665096, 0.389475449337624, 0.07459619446308352, 0.08482105244183913, 0.020426199153007474, 0.02710664146434283, 0.031798601121408865, 0.030589852212870028, 0.06324525355012156, 0.055435574176954105, 0.027750382214435376, 0.03662031602289062, 0.04380217185826041, 0.0393287802580744, 0.013361192613956518, 0.0802778395882342, 0.06750344458851032, 0.07855052797822282, 0.06710721936542541, 0.05578492164204363, 0.018630335362104233, 0.05504432505404111, 0.05754827936470974, 0.06593564277864061, 0.08184107718989253, 0.019597344507928938, 0.04764424440509174, 0.01711932083708234, 0.07445298964739777, 0.03911369843990542, 0.0764574043569155, 0.05658391411998309, 0.04909428964310791, 0.0305954795476282, 0.032552088814554736, 0.0896128847671207, 0.027702328152372502, 0.050520589866209775, 0.02739630170253804, 0.06158414893434383, 0.04404906583658885, 0.023156118877523113, 0.051672421614057384, 0.02708502084715292, 0.03355769891641103, 0.05114240942930337, 0.033744074462447315, 0.011540220111783128, 0.07972140694619156, 0.04333842603955418, 0.04377339508209843, 0.029184332124714274, 0.04421513993293047, 0.022177458013175055, 0.03215857985196635, 0.05011817142076325, 0.031248855229932815, 0.03679902518342715, 0.0422921128483722, 0.0134850913855189, 0.0022289398930297466, 0.02326322934095515, 0.02763535303529352, 0.7198684627655894, 7.765373513102531, 25.833802968263626, 44.91565704345703, 52.82144822180271, 47.344205528497696, 41.0904935002327, 26.240863725543022, 28.314887434244156, 27.97939393669367, 24.976306781172752, 16.76969524472952, 5.799702415242791, 1.1829310306347907, 0.432530760881491, 0.9574921557214111, 1.7529126768931746, 3.9272593148052692, 5.787634737789631, 6.991933090612292, 8.316905368119478, 5.428746845573187, 3.3063056599348783, 8.240406922996044, 11.165406368672848, 21.071556508541107, 29.42263439297676, 37.80515179038048, 44.66599904000759, 53.43567006289959, 54.98617306351662, 55.658767372369766, 54.24213498830795, 51.66652299463749, 50.939044430851936, 53.690495789051056, 53.11238721013069, 50.88880352675915, 51.27774305641651, 52.21080958843231, 50.15494130551815, 53.60765263438225, 53.011331632733345, 54.602002277970314, 53.75225007534027, 54.48638208210468, 52.27731741964817, 51.777807623147964, 51.63884148001671, 52.8668861836195, 53.20530742406845, 52.40576572716236, 48.571323081851006, 50.64084403216839, 48.55203531682491, 56.29217818379402, 41.109435483813286, 38.660892471671104, 54.32024359703064, 51.5568570792675, 55.20202808082104, 53.12314823269844, 54.36533957719803, 52.27694123983383, 55.03573380410671, 52.09406465291977, 52.75156617164612, 45.29522247612476, 40.332008600234985, 39.309673458337784, 39.43793937563896, 40.27592360973358, 43.4908626973629, 47.82681383192539, 53.52356694638729, 54.846241772174835, 54.07559372484684, 53.08655619621277, 54.67970810830593, 55.58614566922188, 55.562518537044525, 56.180308386683464, 58.3182180672884, 54.827109798789024, 52.827539294958115, 42.53456421196461, 34.885099679231644, 22.243691012263298, 15.347803942859173, 12.5990941375494, 6.551082646474242, 6.285499222576618, 9.463530890643597, 7.247064225375652, 6.4552427642047405, 6.055035414174199, 6.218640860170126, 3.283684286288917, 1.714893935713917, 1.1952996044419706, 0.2797238010680303, 0.551272340817377, 2.0971017703413963, 8.272999674081802, 17.190028689801693, 32.391719073057175, 40.61605475842953, 38.74924533069134, 38.16543325781822, 50.990512669086456, 50.08186362683773, 36.66962452232838, 21.801930516958237, 4.777334025129676, 0.36744651733897626, 0.009300042711402057, 0.06326492788502946, 0.042746032631839626, 0.00260460414665431, 0.020063543124706484, 0.06067881411581766, 0.05590624423348345, 0.04654280448448844, 0.057285933871753514, 0.04601901149726473, 0.04616899212123826, 0.06797562862630002, 0.0894781255919952, 0.038856395840412006, 0.049644150567473844, 0.030836874211672693, 0.015636943935533054, 0.03239972960727755, 0.008394802516704658, 0.01925610500620678, 0.03445799455221277, 0.04661962790123653, 0.029734287672908977, 0.059403440754977055, 0.10293099941918626, 0.026998662688129116, 0.053479358248296194, 0.044102374304202385, 0.08354862540727481, 0.20789071888430044, 0.1432430956629105, 0.11345425271429121, 0.135321173875127, 0.17815231229178607, 0.16063217975897714, 0.14253185101551935, 0.06621584805543534, 0.15783864684635773, 0.10959173770970665, 0.10507507147849537, 0.11571283816010691, 0.14240875840187073, 0.18698357278481126, 0.12702684238320217, 0.10712874995078892, 0.11085139238275588, 0.16255584137979895, 0.09861711761914194, 0.16423542547272518, 0.12159994686953723, 0.17329865164356306, 0.10021634196164086, 0.12310865145991556, 0.19257302832556888, 0.14033427753020078, 0.2714826667215675, 0.2090068199322559, 0.11239859217312187, 0.13871589093469083, 0.1977303609601222, 0.34191028447821736, 0.8268064213916659, 9.25772063434124, 28.351872749626637, 54.35304343700409, 60.994942635297775, 56.229975521564484, 49.61644560098648, 33.79984371364117, 37.35027439892292, 33.06359522044659, 30.590072348713875, 21.066170297563076, 7.288852008059621, 1.9128097593784332, 1.128658780362457, 3.5969378147274256, 8.940371163189411, 9.094147961586714, 12.037383578717709, 12.9711920209229, 15.682845264673233, 10.377382803708315, 6.5285147074609995, 11.389938220381737, 12.208702135831118, 22.204834297299385, 31.275021694600582, 38.90006683766842, 47.244791463017464, 54.85996663570404, 57.181934639811516, 55.669004023075104, 54.62244138121605, 50.97396455705166, 52.34322868287563, 55.97605414688587, 53.89081723988056, 51.55224032700062, 52.70991660654545, 52.67826810479164, 50.69846414029598, 53.444584384560585, 54.803022891283035, 55.62742665410042, 54.68681372702122, 57.7849280834198, 53.918190971016884, 56.01023331284523, 53.941137939691544, 56.05203486979008, 54.39957194030285, 54.6850810199976, 51.22047632932663, 53.50809797644615, 51.44240342080593, 57.65718653798103, 44.996516704559326, 42.354062497615814, 53.07120122015476, 51.7152363806963, 56.118611097335815, 55.50309732556343, 55.81237033009529, 55.124094262719154, 55.79842507839203, 54.256475418806076, 55.54329916834831, 46.07746750116348, 41.96004644036293, 41.15681514143944, 40.15724457800388, 42.046187818050385, 45.296115428209305, 51.83489955961704, 56.32034607231617, 56.0691187530756, 54.91741955280304, 54.31868948042393, 54.72163125872612, 58.47203381359577, 58.715650141239166, 56.97771079838276, 57.84920543432236, 55.47372870147228, 56.18319623172283, 43.44604790210724, 37.335838973522186, 23.247619941830635, 18.7151737511158, 15.476823169738054, 12.79110448434949, 20.68050429224968, 13.259893879294395, 13.77759899944067, 15.57943856343627, 10.303959343582392, 14.985888563096523, 8.301160912960768, 5.208836495876312, 2.2681239433586597, 0.6529214582405984, 1.1428142082877457, 2.82822220120579, 9.625301510095596, 22.060700431466103, 44.553528875112534, 49.11773756146431, 46.02273903787136, 49.27775837481022, 62.246637269854546, 61.99001424014568, 41.49757705628872, 25.31601045280695, 6.309449337422848, 0.5326197354588658, 0.20578768017003313, 0.14282173389801756, 0.10261280360282399, 0.13078311894787475, 0.08605466515291482, 0.11387320249923505, 0.22193809010786936, 0.20612998836440966, 0.12742178369080648, 0.14247163315303624, 0.1576678638230078, 0.20226960332365707, 0.2072150379535742, 0.1074766242527403, 0.18218625598819926, 0.15842038672417402, 0.2006930293282494, 0.1337590123875998, 0.0347709545167163, 0.10796222632052377, 0.1373024855274707, 0.15000805375166237, 0.12493981921579689, 0.11266175773926079, 0.1937874045688659, 0.1210583646025043, 0.21668016677722335, 0.11532724049175158, 0.22895502217579633], [0.09555418509989977, 0.11569105612579733, 0.0898893793055322, 0.0012205865118630754, 0.030085108301136643, 0.01802230119210435, 0.03800196493102703, 0.04182381024293136, 0.023441806770279072, 0.037035699788248166, 0.021355496064643376, 0.015984256060619373, 0.05039785348344594, 0.019507529796101153, 0.014883066614856943, 0.05183597982977517, 0.07290862486115657, 0.0353981954685878, 0.0632562447572127, 0.054280870317597874, 0.010517920964048244, 0.06479457588284276, 0.031624834664398804, 0.020649646830861457, 0.016430125397164375, 0.05694169238267932, 0.0760507519589737, 0.029240870790090412, 0.05775806224846747, 0.06459538344643079, 0.005167312201592722, 0.011623084610619117, 0.09867335757007822, 2.7326568542048335, 16.357138082385063, 31.908499002456665, 47.638017162680626, 40.82994528114796, 34.15169723331928, 21.443887129426003, 23.248072117567062, 21.09818547964096, 26.862396374344826, 17.38133892416954, 8.828885145485401, 2.000374160706997, 0.28609795903321356, 0.8079673291649669, 0.7990730158053339, 3.2126235868781805, 3.8955051312223077, 7.8740044590085745, 6.981565346941352, 4.457029262557626, 1.3226127228699625, 3.459369521588087, 5.730307213962078, 12.336747664958239, 19.280942492187023, 28.41334395110607, 37.898011207580566, 47.56349556148052, 52.08013840019703, 54.397485852241516, 50.46666897833347, 56.44174575805664, 50.52136704325676, 55.40502838790417, 50.010754242539406, 52.10933603346348, 52.28202536702156, 54.296399876475334, 51.93521037697792, 51.03530466556549, 48.13010215759277, 50.47074235975742, 48.642763048410416, 54.31800551712513, 52.41046227514744, 54.22797694802284, 53.38241212069988, 55.66784888505936, 50.608093589544296, 54.12968762218952, 46.45674414932728, 48.25884684920311, 46.13170199096203, 56.046304777264595, 42.4232491850853, 37.24576860666275, 55.09140461683273, 50.57893015444279, 53.84549327194691, 49.101003259420395, 51.707826778292656, 50.6525170058012, 52.135444432497025, 48.709426671266556, 48.955258280038834, 40.73141656816006, 40.13805940747261, 39.19390507042408, 38.13266381621361, 40.188296511769295, 42.906537652015686, 45.42022816836834, 50.24024672806263, 53.501524329185486, 53.20921741425991, 50.781105905771255, 51.99411101639271, 53.25307086110115, 51.23375281691551, 57.23841480910778, 58.081935346126556, 55.911871790885925, 46.416352316737175, 36.87471091747284, 27.52496112138033, 19.280488416552544, 12.63170113787055, 13.80849989131093, 6.978396791964769, 7.920228028669953, 9.022214971482754, 6.0460146982222795, 4.080572538077831, 3.052826961502433, 3.0449150735512376, 1.7906141350977123, 0.8006812201347202, 0.7847972412128001, 0.17923048959346488, 0.558040312025696, 2.0808716537430882, 10.387254673987627, 20.299246050417423, 32.63632334768772, 34.27756167948246, 30.939621292054653, 35.8140130341053, 43.20749670267105, 44.62658375501633, 31.883272156119347, 14.648802001029253, 3.8962418166920543, 0.12595633888849989, 0.05655825065332465, 0.08343850553501397, 0.05524538399185985, 0.05520422819245141, 0.011714973625203129, 0.028549163180286996, 0.01757567486492917, 0.03125980932964012, 0.06512339925393462, 0.0977347708248999, 0.04910404146357905, 0.01796417433070019, 0.01697545736533357, 0.01652680497500114, 0.023596225437358953, 0.03679221226775553, 0.02501355680578854, 0.02823329956299858, 0.06139162840554491, 0.08243659875006415, 0.037650903104804456, 0.028505704867711756, 0.08086771340458654, 0.024893249101296533, 0.04240838883561082, 0.016269830775854643, 0.05428506716270931, 0.014406839727598708, 0.030369866653927602, 0.021035732461314183, 0.0442840743198758, 0.03648157151474152, 0.01633473344554659, 0.07633017055923119, 0.022410574019886553, 0.06373231764882803, 0.023636568585061468, 0.006567028694917099, 0.0893748112139292, 0.021001126115152147, 0.08897864536265843, 0.06579391483683139, 0.026693272629927378, 0.04684828731114976, 0.047073870518943295, 0.04573857986542862, 0.05026848230045289, 0.08775960101047531, 0.05252291543001775, 0.059121517406310886, 0.03397674889129121, 0.08624922658782452, 0.034869686132878996, 0.006408623303286731, 0.08124999367282726, 0.0750220165355131, 0.07652815329493023, 0.01218636356497882, 0.018682231893762946, 0.03618216316681355, 0.028041762379871216, 0.22469245246611536, 4.220021730288863, 20.18412932753563, 40.43616101145744, 53.99424768984318, 48.18818584084511, 40.10820060968399, 27.660015374422073, 28.428792022168636, 23.49536284804344, 23.765858933329582, 21.33917424827814, 9.289739616215229, 2.3305374942719936, 0.34758513153064996, 0.5564350169152021, 0.9841319324914366, 3.7606807658448815, 5.822656508535147, 6.264950400218368, 7.566507859155536, 4.651474328711629, 2.9868090664967895, 4.288322115316987, 8.963616415858269, 16.245458275079727, 22.38536261022091, 31.594227366149426, 41.42114795744419, 50.403197184205055, 53.339436426758766, 56.43856152892113, 53.16275730729103, 56.012414395809174, 50.04807583987713, 56.136755123734474, 50.30103586614132, 50.829332917928696, 53.188022151589394, 52.868717685341835, 50.88298223912716, 51.00473910570145, 49.53368604183197, 51.92797176539898, 49.16586957871914, 55.36163851618767, 53.429328203201294, 56.33141867816448, 53.940153792500496, 57.04234912991524, 54.43384990096092, 56.400400176644325, 48.95433872938156, 50.72003938257694, 49.011966437101364, 58.14941592514515, 43.74087028205395, 40.33835045993328, 54.55304950475693, 51.59893222153187, 55.74568010866642, 50.84464609622955, 52.744335159659386, 52.11207188665867, 54.885755851864815, 51.33387744426727, 50.69206528365612, 42.98718832433224, 40.63311204314232, 40.73915675282478, 40.812295228242874, 40.88171370327473, 45.35247400403023, 48.23694482445717, 52.74475693702698, 54.53615181148052, 54.73286345601082, 50.835344195365906, 54.06612083315849, 53.575817942619324, 52.90417358279228, 57.33095124363899, 57.980051413178444, 56.605140790343285, 50.06675943732262, 39.952298775315285, 31.251886636018753, 21.198501996695995, 15.19006110727787, 11.387060824781656, 6.763555370271206, 8.898151628673077, 9.245986863970757, 7.37236107699573, 5.912182554602623, 6.114602917805314, 5.871758423745632, 2.8171503078192472, 1.8773942347615957, 1.0888404794968665, 0.2940047113224864, 0.4738430940778926, 2.6318093156442046, 11.204657312482595, 21.930521316826344, 39.5621433109045, 40.064453557133675, 35.37086561322212, 40.27273938059807, 49.921177849173546, 53.554432690143585, 35.978084430098534, 17.803766056895256, 4.647431820631027, 0.12346220319159329, 0.005167553399587632, 0.055159673356683925, 0.02629330883792136, 0.026458154679858126, 0.011330145007377723, 0.027403422609495465, 0.029820643976563588, 0.08569740268285386, 0.0301904654406826, 0.06882568457513116, 0.01975892490008846, 0.017043816587829497, 0.011801528453361243, 0.035144332723575644, 0.11205618007807061, 0.12296860077185556, 0.07930193023639731, 0.057600957006798126, 0.031173141323961318, 0.08458196214633062, 0.030424549950112123, 0.012348589625617024, 0.012665686135733267, 0.021777126858069096, 0.031045261857798323, 0.026803698638104834, 0.042079394770553336, 0.016989686191664077, 0.030104404140729457, 0.17215434898389503, 0.20787376823136583, 0.17401437886292115, 0.1291331317042932, 0.14596198336221278, 0.13255619880510494, 0.15448320424184203, 0.10005590447690338, 0.14013236883329228, 0.14266607584431767, 0.06975351017899811, 0.1214601485116873, 0.17887363530462608, 0.10204739097389393, 0.13284265296533704, 0.23983597580809146, 0.2866970800096169, 0.10828236656379886, 0.16787199361715466, 0.19454574590781704, 0.10002737632021308, 0.08443526923656464, 0.20371282822452486, 0.14266804995713755, 0.1376114267623052, 0.1655514759477228, 0.12660800392040983, 0.12408806374878623, 0.11228407136513852, 0.129653139738366, 0.16092768812086433, 0.12308404184295796, 0.2422308863606304, 5.07629438303411, 24.439919963479042, 43.82212892174721, 63.7308756262064, 54.593977108597755, 47.47965686023235, 32.85776026546955, 34.40012410283089, 32.21147574484348, 35.694125667214394, 23.960877768695354, 10.826199520379305, 3.46723438706249, 0.7562564383260906, 2.240639068186283, 3.801687452942133, 7.917013876140118, 10.49954054877162, 15.751971155405045, 16.368803456425667, 11.01718582212925, 5.148621601983905, 6.806034715846181, 8.816493060439825, 14.37546081840992, 22.621709927916527, 32.658149376511574, 43.603382259607315, 51.70437656342983, 54.542140290141106, 56.209566816687584, 52.091815173625946, 57.48100519180298, 52.52522751688957, 55.757303684949875, 51.40489563345909, 52.96237125992775, 53.41948293149471, 54.794473350048065, 50.38881495594978, 51.21344670653343, 49.67461287975311, 52.28367067873478, 49.93656322360039, 56.689367070794106, 55.06222978234291, 57.24212720990181, 57.42447182536125, 58.097902089357376, 56.80719114840031, 58.38189885020256, 50.955584943294525, 52.813012674450874, 51.53460927307606, 59.39504228532314, 46.72544293105602, 42.998196333646774, 55.57100348174572, 53.567595183849335, 57.45405703783035, 52.897649332880974, 55.18926456570625, 54.20432701706886, 55.85618197917938, 53.82461719214916, 53.35923336446285, 43.704278245568275, 44.23360504209995, 44.12797451019287, 42.272667065262794, 44.35873992741108, 48.35802152752876, 50.01475162804127, 55.72625555098057, 57.445887476205826, 55.05404882133007, 52.16996558010578, 55.07772155106068, 55.60939282178879, 53.15936028957367, 59.36167247593403, 60.364571660757065, 58.73083792626858, 51.988817900419235, 40.484749004244804, 31.247934848070145, 24.2917488142848, 16.271990351378918, 17.664095051586628, 12.005321849137545, 18.3694664016366, 18.23311261832714, 15.102619249373674, 12.520483005791903, 11.327721308916807, 10.081984754651785, 5.599713921546936, 4.415069539099932, 2.116694706492126, 0.5979095539078116, 0.91624133172445, 3.1484177196398377, 13.716319687664509, 29.157404825091362, 42.73999638855457, 47.02610559761524, 43.29085662961006, 48.65273751318455, 57.985181137919426, 59.74915288388729, 44.93575036525726, 19.80548344552517, 5.628035226836801, 0.23013411671854556, 0.09261772938771173, 0.15233113925205544, 0.14261868229368702, 0.2858491020742804, 0.13397352275205776, 0.09388182952534407, 0.14278487884439528, 0.11742458693333901, 0.1369122791220434, 0.19605693669291213, 0.09549992668326013, 0.13916778465500101, 0.09878819750156254, 0.12143780986662023, 0.23569007171317935, 0.21204996679443866, 0.177200878970325, 0.13722714269533753, 0.2023067107074894, 0.12127069305279292, 0.16673417732818052, 0.1749363192357123, 0.12599487119587138, 0.09397643108968623, 0.2501808910164982, 0.12381445616483688, 0.15606093598762527, 0.06798917282139882, 0.18383373477263376], [0.04496024135733023, 0.034311743220314384, 0.06302122143097222, 0.036700100608868524, 0.04793357438757084, 0.027203157769690733, 0.08839838235871866, 0.0068306799039419275, 0.03717563915415667, 0.04983932798495516, 0.022800142178311944, 0.05306052720698062, 0.0403402978554368, 0.02774708151264349, 0.07357483598752879, 0.053876615056651644, 0.050991909301956184, 0.027620237342489418, 0.05241030936304014, 0.029148445573810022, 0.01055318225553492, 0.04360658997029532, 0.010184779221162898, 0.005368738502511405, 0.04169766740233172, 0.03820774763880763, 0.0408747406618204, 0.02179797193093691, 0.005117120754221105, 0.022507131143356673, 0.07046253580483608, 0.03547492982761469, 0.058221540894010104, 2.263874583877623, 11.276091579347849, 30.76499216258526, 42.18630909919739, 43.45368929207325, 30.66505942493677, 19.56276196986437, 26.896818727254868, 26.241921968758106, 27.2587189078331, 22.351297438144684, 12.866667229682207, 1.5156417712569237, 0.5708959721960127, 0.3521281143184751, 0.6055604433640838, 2.841726439073682, 3.859283337369561, 2.5843695737421513, 6.917923986911774, 2.885240991599858, 1.637184543069452, 2.1406728448346257, 4.327945439144969, 10.17400536686182, 14.509160444140434, 24.68139510601759, 34.32290084660053, 43.04554559290409, 48.11428740620613, 53.135379776358604, 59.37486156821251, 59.72948893904686, 55.27048520743847, 50.623440966010094, 49.54445846378803, 51.67586289346218, 49.75322686135769, 51.48485094308853, 51.78406588733196, 51.418757289648056, 50.71585200726986, 53.51214475929737, 53.83129723370075, 52.93503172695637, 55.45912228524685, 55.83533629775047, 55.46050541102886, 55.441780015826225, 53.5809400677681, 51.335610151290894, 48.17537672817707, 48.36071938276291, 48.54871429502964, 52.942695915699005, 42.596124708652496, 37.183755934238434, 53.78696881234646, 52.12070882320404, 49.94366504251957, 48.10034595429897, 47.22618006169796, 45.32622501254082, 47.10288427770138, 46.45029589533806, 44.623623713850975, 40.707515850663185, 41.40216417610645, 38.946952521800995, 40.76392762362957, 41.86268426477909, 46.158771738409996, 47.68389970064163, 48.741702139377594, 53.34042817354202, 54.69484269618988, 52.55829334259033, 52.776527032256126, 56.73825144767761, 58.763516172766685, 52.61854290962219, 57.42248833179474, 53.35797183215618, 46.40133552253246, 33.58822166919708, 27.18678116798401, 17.064230740070343, 9.805648382753134, 8.637946341186762, 3.9274554792791605, 3.317133178934455, 7.326384969055653, 5.176704470068216, 3.1135593401268125, 4.335321793332696, 4.988454971462488, 1.5156169538386166, 0.7666811195667833, 0.9695553802885115, 0.049075758215622045, 0.6408139423001558, 2.3827383806928992, 7.866326496005058, 18.198293186724186, 27.64655839651823, 33.11361953616142, 27.225624583661556, 26.17126666009426, 45.52906192839146, 37.36030586063862, 31.495086885988712, 12.839660178869963, 1.7249191040173173, 0.10264379568980075, 0.00934440087803523, 0.02492330051609315, 0.08711508286069147, 0.04679622194089461, 0.021726061531808227, 0.055420619901269674, 0.04447817933396436, 0.052013379099662416, 0.01191358533105813, 0.029547941812779754, 0.07369874496362172, 0.09311700923717581, 0.024560395868320484, 0.028077070055587683, 0.05138799351698253, 0.05767185808508657, 0.04355474353360478, 0.10117590180016123, 0.03629616447142325, 0.010781613455037586, 0.05616478250885848, 0.031080851549631916, 0.039920438939589076, 0.009443863509659423, 0.037437350110849366, 0.02212847441114718, 0.02881877800973598, 0.04036129321320914, 0.018047357953037135, 0.022123258968349546, 0.05642951771733351, 0.05858593911398202, 0.0720730927423574, 0.0588414568483131, 0.023873059508332517, 0.023981984522833955, 0.010388867049186956, 0.014374499714904232, 0.06388053938280791, 0.04216127963445615, 0.11039089717087336, 0.028217673643666785, 0.015970422427926678, 0.02068555935693439, 0.06955329357879236, 0.010868043045775266, 0.06619069667067379, 0.06781759570003487, 0.08956750243669376, 0.03436535225773696, 0.0038150592990859877, 0.01695661423582351, 0.03557796218956355, 0.010404211880086223, 0.031715688382973894, 0.048652956684236415, 0.07145086128730327, 0.06663009262410924, 0.039003882848192006, 0.025153191891149618, 0.030928130545362365, 0.010018097491411027, 3.059764914214611, 14.408405050635338, 36.17903284728527, 49.33134689927101, 49.54488404095173, 38.84509518742561, 24.821199104189873, 31.136047951877117, 27.968442924320698, 32.91769064962864, 24.76762767881155, 13.618976511061192, 2.200225624255836, 0.38836371211800724, 0.5454086617100984, 1.0137220728211105, 2.2928088437765837, 4.337425930425525, 7.241643816232681, 4.393229736015201, 6.461001355201006, 6.494721695780754, 4.292235905304551, 8.176747988909483, 11.605159621685743, 18.51737156510353, 26.74769002944231, 37.59131446480751, 47.208674401044846, 50.57812459766865, 53.66803519427776, 58.396421670913696, 58.44544284045696, 54.48972590267658, 51.369371339678764, 50.38610950112343, 52.047403156757355, 50.053543746471405, 53.192988485097885, 52.13398151099682, 50.96758469939232, 50.27129106223583, 53.44782181084156, 52.69274912774563, 51.442373022437096, 55.38028031587601, 55.44262357056141, 55.46750083565712, 57.60419078171253, 55.60843527317047, 53.50859954953194, 48.702727630734444, 48.99029240012169, 49.57855403423309, 56.05961926281452, 45.516549199819565, 40.51225572824478, 52.48462289571762, 52.93950788676739, 53.477608412504196, 49.916982874274254, 50.13090379536152, 47.86778703331947, 49.865799620747566, 49.738061875104904, 45.96659705042839, 42.98644356429577, 44.229421466588974, 40.889514684677124, 41.31045609712601, 43.289006128907204, 48.03994819521904, 50.252740457654, 50.339064225554466, 56.07030048966408, 56.521465480327606, 52.65316665172577, 53.97383898496628, 58.564125671982765, 58.577793538570404, 54.21993277966976, 57.65903323888779, 55.75692370533943, 47.180890291929245, 36.87305420637131, 28.859506510198116, 19.33787863701582, 11.003574952483177, 7.900876617059112, 5.151752633973956, 5.272730067372322, 9.81650060042739, 8.630679231137037, 5.984252812340856, 4.75115722976625, 4.167096745222807, 3.4905494609847665, 1.3310305774211884, 1.0118155251257122, 0.282307454617694, 0.6894309085328132, 2.9720753571018577, 10.430332012474537, 23.65129128098488, 32.938395738601685, 36.50420419871807, 32.29522705078125, 32.52282343804836, 51.896942630410194, 43.53381559252739, 37.1327930688858, 15.587268993258476, 2.628215183503926, 0.12102077482268214, 0.07078481343341991, 0.05219821468926966, 0.012376720733300317, 0.046470864399452694, 0.038219948546611704, 0.09024330953252502, 0.04287408279196825, 0.03510983027808834, 0.033669618496787734, 0.007014313214313006, 0.06095874479797203, 0.047854669246589765, 0.04949281552399043, 0.041109556186711416, 0.03970071498770267, 0.06513790824101306, 0.023710740679234732, 0.018096174571837764, 0.02679859822819708, 0.012088247931387741, 0.028623693360714242, 0.07926680438686162, 0.013695890083909035, 0.017068444758479018, 0.037655686246580444, 0.01701844812487252, 0.06897159822983667, 0.03359561524121091, 0.04645672277547419, 0.14031852915650234, 0.1526276717777364, 0.13749675010330975, 0.1099445769796148, 0.14123181608738378, 0.08299927285406739, 0.11833401469630189, 0.08533415108104236, 0.15601391351083294, 0.1328839163761586, 0.08658979073516093, 0.24790095398202538, 0.11027141139493324, 0.13091038243146613, 0.14305185904959217, 0.12241933727636933, 0.19389418477658182, 0.12024219511658885, 0.15296528959879652, 0.13594674499472603, 0.15695575828431174, 0.07507795220590197, 0.08712322422070429, 0.15384794067358598, 0.1501360593829304, 0.14785003673750907, 0.1584916329011321, 0.22258635610342026, 0.11830321556772105, 0.1355950115248561, 0.23250925645697862, 0.10691065501305275, 0.18359789508394897, 3.214390017092228, 15.94431683421135, 42.01512448489666, 55.59120699763298, 57.89408482611179, 45.657593831419945, 31.78018368780613, 38.06382670998573, 37.821810096502304, 36.21443934738636, 28.437218070030212, 15.978655591607094, 3.012973750010133, 0.8860906620975584, 1.2434761505573988, 1.5388533007353544, 5.683752587065101, 12.44774540886283, 9.897420108318329, 15.080821719020605, 8.583395518362522, 7.321798140183091, 5.091801825910807, 8.94440844655037, 14.212703201919794, 18.30799140036106, 28.784371241927147, 38.26499551534653, 45.98669417202473, 50.47999866306782, 53.61891523003578, 62.46967390179634, 59.79912020266056, 56.58007733523846, 53.45169000327587, 52.354035302996635, 52.54760071635246, 52.41261675953865, 51.79114490747452, 54.61195394396782, 52.79633156955242, 50.305181443691254, 53.416921868920326, 53.673164919018745, 52.74722680449486, 53.473079055547714, 54.31877687573433, 56.055994257330894, 58.84748786687851, 58.36875535547733, 54.59156043827534, 51.89995586872101, 51.01890094578266, 52.78675988316536, 56.55497208237648, 48.26836533844471, 44.774984791874886, 52.31340408325195, 54.671865329146385, 53.88670966029167, 51.38061873614788, 51.32490232586861, 49.263030365109444, 51.417890936136246, 50.692198276519775, 48.76416273415089, 45.22194340825081, 47.03604206442833, 44.021679013967514, 44.57103833556175, 45.69043546915054, 50.09387478232384, 52.90968708693981, 52.9403742402792, 59.0874981880188, 58.89092333614826, 52.758124619722366, 56.51210658252239, 58.73364217579365, 61.24371528625488, 54.71962496638298, 58.96313466131687, 56.040662080049515, 50.53748197853565, 38.23373079299927, 31.01543292403221, 20.652478896081448, 12.418755814433098, 11.35542657226324, 8.016935214400291, 8.860643841326237, 15.319652203470469, 13.907190095633268, 10.971762109547853, 12.468042969703674, 11.52208847925067, 8.20922389626503, 3.8398355059325695, 2.9342704731971025, 0.4063994443276897, 1.4405061467550695, 4.014232372865081, 12.390145249664783, 26.832058802247047, 39.00049924850464, 45.06951838731766, 39.74250063300133, 37.7091309428215, 58.84062923491001, 52.34357446432114, 40.71076847612858, 18.454074561595917, 2.999774683266878, 0.2892639016499743, 0.184040927561, 0.16757761331973597, 0.2064272333518602, 0.1656069143791683, 0.18862208642531186, 0.14607830758905038, 0.18652663246029988, 0.08835505577735603, 0.10326902542146854, 0.10353179022786207, 0.10829326129169203, 0.2256578381638974, 0.09620824726880528, 0.09093556262087077, 0.1375803753035143, 0.18152243457734585, 0.0792401390208397, 0.1636445423355326, 0.09555327967973426, 0.1238495968573261, 0.09476485167397186, 0.2380813012132421, 0.11033031565602869, 0.12723312975140288, 0.08505915568093769, 0.09311901303590275, 0.17736378038534895, 0.06938582795555703, 0.15337308490416035], [0.053696525501436554, 0.05912083463044837, 0.039134901599027216, 0.03106515698164003, 0.08669103452120908, 0.03138448271784, 0.06414049144950695, 0.03571978289983235, 0.100203784822952, 0.008680750161147444, 0.0357248183718184, 0.09368154613184743, 0.04765049699926749, 0.05033106019254774, 0.017365133135172073, 0.066268199152546, 0.06210958577867132, 0.031535290836472996, 0.023621649561391678, 0.0635586550924927, 0.019123999009025283, 0.019191848004993517, 0.03643434123659972, 0.03427748197282199, 0.02229459489171859, 0.03807489949394949, 0.0322051570401527, 0.03545817584381439, 0.023408586384903174, 0.035883085074601695, 0.026596847237669863, 0.03467276837909594, 0.017720692376315128, 0.6367580755613744, 7.283927947282791, 25.723310597240925, 36.05491250753403, 45.31239375472069, 34.523005709052086, 29.977535717189312, 27.686898931860924, 15.557473842054605, 27.356379367411137, 25.948638506233692, 7.2685962449759245, 3.0935849994421005, 0.7356781675480306, 0.36705712729599327, 1.245673382654786, 2.0538144931197166, 4.316368410363793, 6.007443917915225, 2.439975659362972, 3.643806637264788, 4.339236058294773, 2.667192779481411, 5.148806367069483, 7.400763127952814, 12.857680711895227, 20.272349193692207, 27.293713130056858, 36.29788666963577, 48.07801455259323, 62.57680535316467, 61.882586404681206, 57.84596420824528, 49.206314608454704, 49.33136589825153, 53.683249577879906, 52.50848941504955, 53.9320982247591, 50.4813551902771, 50.9616494178772, 53.245459869503975, 51.98857091367245, 55.619637072086334, 54.7421083599329, 54.9209001660347, 56.18095815181732, 53.73949036002159, 52.83403314650059, 52.80648082494736, 51.3016589730978, 50.30219480395317, 46.0078514367342, 50.69966867566109, 47.74333231151104, 55.86422994732857, 41.628233045339584, 36.027899757027626, 53.199410140514374, 51.26282125711441, 50.74531562626362, 46.36665478348732, 46.301788464188576, 44.9129743874073, 44.572755843400955, 39.78386901319027, 41.160113364458084, 38.3972892165184, 41.39315865933895, 41.37665614485741, 45.60354933142662, 47.97844849526882, 49.12123717367649, 47.71492123603821, 50.270880684256554, 54.33938317000866, 53.82229171693325, 51.85319557785988, 54.946613386273384, 46.69054180383682, 60.740971863269806, 54.17870879173279, 55.09419746696949, 51.954543739557266, 43.276307210326195, 33.55305455625057, 24.227066785097122, 13.60135780647397, 10.0202352181077, 4.618667364120483, 5.170927830040455, 5.799614069983363, 8.071286547929049, 5.53715075366199, 5.52102061919868, 2.020266568288207, 3.4060906805098057, 1.167231104336679, 1.0502959415316582, 0.7626256684307009, 0.3914149187039584, 0.9800966084003448, 5.2094473131001, 14.06076455488801, 23.4690435603261, 33.55271257460117, 29.73361350595951, 33.043004125356674, 39.29540142416954, 48.74758042395115, 44.16732519865036, 22.745948061347008, 11.253268104046583, 1.0044072289019823, 0.04387321023386903, 0.04095429147128016, 0.06725304396240972, 0.031415619523613714, 0.09036507370183244, 0.04758283539558761, 0.021642044848704245, 0.02529495508497348, 0.018368171695328783, 0.05635089459246956, 0.0328292995254742, 0.05589923464867752, 0.017231915771844797, 0.05788224210846238, 0.05392959326854907, 0.057635830526123755, 0.029494395857909694, 0.05434461709228344, 0.05356792615202721, 0.0368492314737523, 0.1045000554586295, 0.020759573744726367, 0.008236130415752996, 0.10423714964417741, 0.03218813959392719, 0.02549730535974959, 0.042675962758949026, 0.0171260799470474, 0.036509672936517745, 0.0354390952270478, 0.021944939435343258, 0.04117204502108507, 0.03705113645992242, 0.06487193735665642, 0.08141149242874235, 0.07270006652106531, 0.04619454797648359, 0.01903043459606124, 0.028655969363171607, 0.03011410401086323, 0.04834635321458336, 0.02979728302307194, 0.08141052021528594, 0.006278822602325818, 0.018918639325420372, 0.041176572121912614, 0.022628455590165686, 0.05031256216170732, 0.0841430708533153, 0.018960598499688786, 0.037432403696584515, 0.021156748916837387, 0.05338638569810428, 0.016731023606553208, 0.023597364634042606, 0.03128343931166455, 0.040937604280770756, 0.0827049593499396, 0.056085216856445186, 0.04353148091468029, 0.09125386975938454, 0.08939191029639915, 0.012981642521481263, 0.9727659705094993, 10.036955270916224, 32.062896117568016, 44.30555038154125, 52.4591376632452, 40.40072411298752, 33.3035409450531, 32.83385194838047, 22.73358542472124, 29.990259334445, 29.58647970110178, 10.604943092912436, 2.9527693055570126, 0.6979371083434671, 0.5342527572065592, 0.35441232612356544, 2.851957152597606, 3.33200890570879, 3.679729434661567, 7.652071192860603, 9.435118865221739, 5.395710943266749, 5.758111272007227, 8.249231949448586, 9.439405985176563, 18.160730302333832, 24.342369697988033, 32.66933597624302, 38.896419033408165, 48.30385163426399, 59.92568001151085, 62.019557654857635, 59.38288293778896, 53.399488404393196, 51.2150464206934, 53.240178152918816, 54.08459924161434, 55.317902863025665, 52.7374043315649, 51.68126620352268, 54.8580439388752, 53.386101722717285, 54.46316912770271, 55.6345284730196, 54.87885922193527, 56.44929215312004, 54.69583444297314, 54.24105204641819, 54.37992699444294, 52.51363813877106, 52.07156606018543, 48.04674983024597, 52.481617256999016, 50.82878954708576, 57.26263850927353, 44.74045604467392, 39.523829966783524, 53.93503546714783, 54.191149324178696, 53.70317570865154, 48.73232804238796, 48.37045446038246, 47.6016341149807, 46.27797894179821, 43.36933761835098, 42.32985019683838, 40.021808445453644, 42.7076069265604, 42.75478519499302, 45.80542869865894, 49.4766853004694, 51.897235214710236, 49.380178079009056, 51.33486919105053, 56.64410389959812, 54.01746444404125, 53.457636684179306, 56.34434178471565, 49.79106143116951, 59.94179114699364, 56.76811024546623, 56.99104428291321, 52.47737668454647, 46.04306414723396, 34.85909767448902, 26.634220518171787, 16.36691875755787, 9.947573617100716, 8.061792757362127, 6.395968794822693, 6.141293635591865, 6.707126973196864, 8.469456732273102, 6.364606702700257, 4.982608510181308, 4.39160437323153, 2.4812583066523075, 1.4212956838309765, 0.41881827637553215, 0.26616194285452366, 1.0942702693864703, 5.329962596297264, 13.714201301336288, 26.83512143790722, 31.545895859599113, 31.896552443504333, 38.145343735814095, 42.605160623788834, 56.972771063447, 51.52756445109844, 29.243124425411224, 13.352877739816904, 1.3181457063183188, 0.056787474095472135, 0.12401951898937114, 0.04572229343466461, 0.026562322527752258, 0.02963258004456293, 0.0623365085630212, 0.18787389766657725, 0.06672620816971175, 0.021895978097745683, 0.03519548525218852, 0.04768922968651168, 0.010726407872425625, 0.04006042654509656, 0.037651348393410444, 0.047336917341453955, 0.06311681747320108, 0.033189348760060966, 0.04478643779293634, 0.009760263328644214, 0.023617092774657067, 0.04537757697107736, 0.029943283880129457, 0.07254501702846028, 0.02489246428012848, 0.043043218247476034, 0.02121228197211167, 0.05911507556447759, 0.04200007031613495, 0.058713106118375435, 0.031112177603063174, 0.16059902060078457, 0.14090170880081132, 0.17351322137983516, 0.09310813315096311, 0.27315802057273686, 0.12228596591739915, 0.2169195539318025, 0.09284700849093497, 0.16223584214458242, 0.14695732214022428, 0.14010253449669108, 0.10862129056476988, 0.23453963891370222, 0.12330373981967568, 0.14759687532205135, 0.14790826564421877, 0.18300226220162585, 0.13467669283272699, 0.18008885759627447, 0.0938373155076988, 0.14573234802810475, 0.15362209029262885, 0.1288650679634884, 0.13668720057467, 0.10575533146038651, 0.1523799725691788, 0.17278968676691875, 0.1336985718808137, 0.12576048611663282, 0.14026764751179144, 0.17248190328245983, 0.14120876498054713, 0.12200168624985963, 1.2924028001725674, 11.28230044618249, 35.69573298096657, 50.583653301000595, 59.855607971549034, 49.26861986517906, 42.97435641288757, 40.55670574307442, 25.39555538445711, 38.78184378147125, 33.236117362976074, 11.748447082936764, 4.683732697740197, 0.994816068559885, 0.9080793696921319, 2.222968591377139, 5.2513163164258, 9.09916179254651, 10.442285221070051, 8.47289364784956, 11.863410864025354, 11.03446539491415, 6.31123524159193, 8.768872115761042, 11.17224695160985, 19.305819757282734, 24.700684770941734, 31.984164342284203, 40.857520401477814, 50.5440404266119, 64.1338250041008, 63.30921605229378, 60.356983467936516, 54.635394886136055, 52.56650470197201, 54.706363677978516, 55.18957234919071, 56.240987330675125, 54.80184495449066, 53.83367210626602, 55.12817144393921, 51.981195509433746, 56.901148706674576, 56.32136061787605, 57.465722411870956, 58.72920781373978, 54.633396193385124, 55.937649607658386, 57.33456864953041, 55.791965425014496, 53.78256484866142, 51.00068472325802, 53.811542093753815, 53.06896314024925, 57.84693695604801, 47.25920408964157, 42.91083142161369, 54.01508957147598, 56.238741651177406, 53.65342117846012, 49.1320513933897, 50.464689284563065, 50.38191832602024, 49.65005099773407, 45.44052667915821, 44.680639654397964, 43.05603303015232, 44.879927560687065, 44.71191577613354, 48.820544108748436, 53.09851415455341, 55.91016948223114, 52.95445628464222, 56.21976926922798, 57.2886823117733, 53.78455974161625, 54.56911124289036, 57.47586786746979, 51.97233058512211, 60.65376274287701, 57.61063143610954, 57.5844394415617, 53.21065753698349, 46.624953523278236, 37.2078238427639, 27.515284940600395, 16.7318207770586, 13.97700184956193, 9.395847972482443, 10.575318932533264, 12.585499417036772, 14.217431098222733, 14.175976272672415, 10.71079971268773, 10.27821572497487, 8.66335367783904, 5.74356185272336, 2.7030590549111366, 1.2792429188266397, 0.9204292413778603, 1.5157385473139584, 7.042926829308271, 19.66406263411045, 34.003596380352974, 43.603477254509926, 43.589129224419594, 46.255157366395, 53.4549730271101, 65.05079939961433, 59.25735667347908, 32.22714230418205, 14.784449972212315, 1.8474073125980794, 0.1319058844819665, 0.2383387670852244, 0.1249430698226206, 0.13577137549873441, 0.1004146809282247, 0.19833267317153513, 0.3084909589961171, 0.18997512554051355, 0.12020423426292837, 0.17545922164572403, 0.14187172550009564, 0.14680503343697637, 0.2246441089664586, 0.1716150005813688, 0.11198871885426342, 0.2377616730518639, 0.09175788451102562, 0.21390763664385304, 0.13224537251517177, 0.13116624526446685, 0.21540753194130957, 0.07127322081942111, 0.1725208808784373, 0.2915992622729391, 0.11344477548846044, 0.10020095724030398, 0.2607939293375239, 0.1791786283138208, 0.1689404487842694, 0.08263142735813744], [0.06135470284789335, 0.04745157915749587, 0.032127153608598746, 0.008679847524035722, 0.01822412268666085, 0.020076777473150287, 0.08097049343632534, 0.03056871770240832, 0.0043026711955462815, 0.03746069436601829, 0.0498551876808051, 0.029720285201619845, 0.018625403790792916, 0.04120195357245393, 0.05894376561627723, 0.047262164516723715, 0.0414775464014383, 0.027951424453931395, 0.03015339701960329, 0.0473153950588312, 0.021208719663263764, 0.06338174192933366, 0.03452856166404672, 0.05448451564006973, 0.055398474214598536, 0.03026437778316904, 0.014268195409385953, 0.04995799739845097, 0.06133797483926173, 0.06145063656731509, 0.04718702948594, 0.05568532913457602, 0.05223584157647565, 0.1901147235184908, 4.208955774083734, 17.14515119791031, 34.86169293522835, 42.15692527592182, 36.93194344639778, 32.02861435711384, 23.846002332866192, 18.900700695812702, 30.338090769946575, 21.06648948043585, 10.824545659124851, 6.114015374332666, 0.9063751611392945, 0.7468076515942812, 0.34125015896279365, 2.1371748950332403, 1.3280330132693052, 3.681216579861939, 4.053734578192234, 8.057319447398186, 6.580329677090049, 5.334964552894235, 6.818032572045922, 4.49983349069953, 12.200564872473478, 14.747251868247986, 23.370110169053078, 32.809400260448456, 51.25289998948574, 55.82602299749851, 50.512540116906166, 44.770653024315834, 46.54769226908684, 53.36720913648605, 54.60124991834164, 52.70041711628437, 52.374402210116386, 55.48371836543083, 51.41086511313915, 51.95595346391201, 52.28060804307461, 51.924931928515434, 52.584663927555084, 51.420505195856094, 50.924293622374535, 51.28886125981808, 49.035813957452774, 50.616213753819466, 47.53627382218838, 46.45783469080925, 46.32863402366638, 50.526112988591194, 47.418483942747116, 54.262159913778305, 40.12374557554722, 35.65652288496494, 50.9132020175457, 51.049276515841484, 51.21632695198059, 47.36929178237915, 49.704182893037796, 48.52810800075531, 46.392470598220825, 45.91795206069946, 46.220442429184914, 47.08776868879795, 47.7781992405653, 49.07362572848797, 50.10395184159279, 49.74403515458107, 49.69966873526573, 48.5714028775692, 53.8496920466423, 54.43019449710846, 55.650518015027046, 53.21397475898266, 47.78410792350769, 53.97663563489914, 49.94851738214493, 57.58956916630268, 56.9852913916111, 53.20770129561424, 41.50223560631275, 29.73497573286295, 20.740740559995174, 13.403557520359755, 4.809514498338103, 5.405516792088747, 3.4832500526681542, 1.9973630597814918, 5.707626705989242, 7.540486855432391, 3.492360063828528, 3.2458827272057533, 1.9471886521205306, 1.742855804041028, 1.273061956744641, 0.07934881912660785, 0.16584453522227705, 1.956064619589597, 3.424974954687059, 11.556965857744217, 22.69823022186756, 32.87719242274761, 29.97425839304924, 37.972829192876816, 55.14221169054508, 48.979922756552696, 37.64881677925587, 21.843743473291397, 7.0892582181841135, 0.5955603299662471, 0.041343455159221776, 0.042236013905494474, 0.027787817998614628, 0.0744866460445337, 0.027574352207011543, 0.04046369474963285, 0.04282372807210777, 0.045739618872175924, 0.017948067870747764, 0.07225054025184363, 0.048164508480113, 0.06586195493582636, 0.0773823652707506, 0.06614872821955942, 0.05020644617616199, 0.06146897503640503, 0.053290685755200684, 0.034259310486959293, 0.0025143395077975583, 0.0276125171512831, 0.02373917421209626, 0.04103317805856932, 0.06942491687368602, 0.05149306307430379, 0.07036848342977464, 0.005318390740285395, 0.0449850142467767, 0.009790702515601879, 0.02035927969700424, 0.046794333175057545, 0.0226279435082688, 0.032546715665375814, 0.04431515917531215, 0.007990097328729462, 0.05157595354830846, 0.04621667510946281, 0.07157398358685896, 0.03144872673146892, 0.04654965079680551, 0.01979317130462732, 0.04692840586358216, 0.02746082031080732, 0.06189488987729419, 0.015260716809279984, 0.022321408687275834, 0.0342162622109754, 0.020659342990256846, 0.052321800831123255, 0.004808777875950909, 0.0853192710201256, 0.030188699129212182, 0.044970538656343706, 0.017555048725625966, 0.0553558563842671, 0.02175497374992119, 0.03720241584233008, 0.06614872821955942, 0.0494244785659248, 0.033244212027057074, 0.15936137060634792, 0.04298914165701717, 0.008836309880280169, 0.10576517976005562, 0.3528479381930083, 5.527161564677954, 21.611954011023045, 41.76024556159973, 51.48495353758335, 43.802514374256134, 37.53459110856056, 30.958513878285885, 20.365043319761753, 32.798977419734, 23.181598484516144, 10.526625495404005, 5.28741960413754, 1.6218664962798357, 0.24184168927604333, 0.35630696977023035, 2.2803315008059144, 2.6691197510808706, 7.025208380073309, 6.078159073367715, 12.083695493638515, 8.746792450547218, 5.217577451840043, 6.77064199000597, 5.421829791739583, 13.791216518729925, 18.075227290391922, 26.78148351609707, 35.78104980289936, 50.82558251917362, 57.38161772489548, 56.68426774442196, 50.29125519096851, 50.19252508878708, 53.58069688081741, 56.06395103037357, 56.13927438855171, 54.20610152184963, 54.827976152300835, 55.23364998400211, 54.28769074380398, 54.10733342170715, 54.60590086877346, 53.934241309762, 53.63116197288036, 52.28935517370701, 52.62222111225128, 51.17061920464039, 50.87565243244171, 48.92209745943546, 48.520592004060745, 48.61904852092266, 52.09788724780083, 50.2735785394907, 55.17202869057655, 42.902574464678764, 37.57677264511585, 51.09072849154472, 52.73597560822964, 53.16408343613148, 49.76923540234566, 50.96275895833969, 51.080833822488785, 48.592134565114975, 47.65003591775894, 47.18731954693794, 47.40819789469242, 48.35674099624157, 49.76115703582764, 51.54957666993141, 52.31176637113094, 50.85057757794857, 51.45989388227463, 55.85421748459339, 55.788705199956894, 54.89721603691578, 54.72124747931957, 53.21288421750069, 56.03313848376274, 54.52593795955181, 59.55157108604908, 56.16779185831547, 53.87551546096802, 42.27668724954128, 32.7633049339056, 24.782251194119453, 15.944086946547031, 7.550356350839138, 6.633608043193817, 4.970714673399925, 6.375082265585661, 7.520697517320514, 9.791241455823183, 9.082686826586723, 4.129199478775263, 4.363189972937107, 4.053088137879968, 1.374942921102047, 0.39121875423006713, 0.3671817487338558, 1.7394064203836024, 4.872998641803861, 15.348678845912218, 28.71798500418663, 38.194076120853424, 34.52352628111839, 43.47109995782375, 59.37875635921955, 54.110654443502426, 44.24755409359932, 26.154995933175087, 9.219412989914417, 0.9076318249572068, 0.014331875390780624, 0.0438700301310746, 0.01772968164004851, 0.0789294092101045, 0.02783823394565843, 0.032306482462445274, 0.033979316722252406, 0.012852007876062999, 0.07345984020503238, 0.021807456578244455, 0.06416658536181785, 0.015435269015142694, 0.06193289897055365, 0.036081947255297564, 0.0404122490726877, 0.03585972597647924, 0.04224303091177717, 0.04252501734299585, 0.022282445934251882, 0.04128434680751525, 0.03418856154894456, 0.007206567497632932, 0.05152435944182798, 0.03603267607104499, 0.01784392043191474, 0.07755777187412605, 0.05951239916612394, 0.04531799735559616, 0.026458471947989892, 0.05292982757964637, 0.13916897209128365, 0.1507852307986468, 0.19892432814231142, 0.08524257005774416, 0.22571560693904757, 0.0967393207247369, 0.14488235145108774, 0.15644802537281066, 0.18466777517460287, 0.11683252378134057, 0.15926172985928133, 0.108879810286453, 0.21520786453038454, 0.08962150110164657, 0.11110004896181636, 0.12714640237390995, 0.17683085898170248, 0.08288796554552391, 0.06499916373286396, 0.10775452887173742, 0.20391898200614378, 0.17172966239741072, 0.0896179536357522, 0.22915385838132352, 0.18104210175806656, 0.08730814515729435, 0.29213921923656017, 0.16668331052642316, 0.17265250819036737, 0.2341758826514706, 0.10923725087195635, 0.10079998173750937, 0.10966904723318294, 0.6230329745449126, 6.758024292066693, 23.60115297138691, 48.02894398570061, 58.48446674644947, 53.31341162323952, 45.58341421186924, 36.25393062829971, 30.590167343616486, 41.23100236058235, 29.052847735583782, 16.386861987411976, 7.997806090861559, 2.251316257752478, 1.0584485228173435, 0.728181644808501, 5.417150817811489, 5.876021794974804, 11.780791897326708, 13.377584964036942, 16.43694519996643, 15.596721936017275, 12.047478687018156, 11.97725560516119, 8.020306583493948, 15.885661281645298, 18.589244708418846, 27.527856566011906, 37.92335584759712, 55.93886934220791, 58.28998178243637, 58.80312144756317, 53.34549330174923, 49.941328167915344, 54.45450559258461, 58.33864577114582, 57.18185104429722, 58.4632258862257, 58.980742916464806, 55.650989189743996, 56.15522973239422, 56.128334775567055, 57.69877910614014, 57.28413015604019, 54.65932220220566, 54.22119051218033, 54.51464496552944, 52.1552337706089, 52.60820746421814, 50.74509523808956, 51.05768546462059, 50.09827874600887, 54.088779017329216, 52.85534240305424, 54.89334784448147, 45.23334659636021, 42.456261813640594, 52.58713759481907, 55.54141826927662, 54.8633636534214, 52.588463723659515, 53.00653629004955, 53.585492223501205, 50.36723971366882, 49.52493891119957, 52.66045466065407, 50.726267248392105, 51.87760166823864, 51.8054511398077, 54.161393120884895, 54.78799469769001, 54.88359376788139, 54.42277729511261, 57.76381641626358, 58.1729556620121, 54.52873840928078, 55.97194276750088, 54.9800705909729, 58.59453544020653, 57.33719050884247, 60.88150352239609, 59.960011169314384, 55.04247844219208, 43.49899806082249, 32.691112607717514, 24.94745682924986, 15.978999473154545, 6.876185601577163, 9.112876206636429, 9.021246023476124, 7.362144850194454, 13.177594095468521, 15.791489034891129, 13.075506873428822, 12.043796684592962, 9.382111709564924, 5.7823520712554455, 3.0454793432727456, 0.8698376279789954, 0.7946581277064979, 3.2049584481865168, 5.603329427540302, 16.46034624427557, 34.98835153877735, 43.75057876110077, 43.005313351750374, 52.672021239995956, 68.23650285601616, 62.11263366043568, 49.04618360102177, 32.8855861723423, 11.029467713087797, 1.2755502294749022, 0.06901275031850673, 0.16799848526716232, 0.13583665480837226, 0.13598091347375885, 0.0967006325663533, 0.07015908646280877, 0.1345843548187986, 0.13132742489688098, 0.11572266419534571, 0.1378741321968846, 0.16086821240605786, 0.19516392523655668, 0.12000338683719747, 0.1168118030182086, 0.1261270625400357, 0.11746864081942476, 0.1285841502249241, 0.132968150137458, 0.0688416555931326, 0.1861847101827152, 0.0994676782283932, 0.13476337568135932, 0.19185326382284984, 0.17780710972147062, 0.24720801069634035, 0.13092598237562925, 0.20386790740303695, 0.08173791866283864, 0.12033161649014801, 0.11953812703723088], [0.04575337457936257, 0.019285052476334386, 0.05196047139179427, 0.06578163229278289, 0.07348226048634388, 0.02182999003707664, 0.026793880024342798, 0.053756465058540925, 0.08024922979529947, 0.014707933678437257, 0.07687808334594592, 0.010299208188371267, 0.018892222578870133, 0.031383811074192636, 0.08018022490432486, 0.058088974765269086, 0.03959268797188997, 0.027652114440570585, 0.05683658571797423, 0.05056665868323762, 0.031727369787404314, 0.06993847564444877, 0.016891596533241682, 0.01871629461675184, 0.016160226696229074, 0.03445210932113696, 0.050204141807626, 0.011399756604077993, 0.09390105857164599, 0.026692916399042588, 0.014703000251756748, 0.03340800030855462, 0.09454151717363857, 0.023201217336463742, 1.8671059305779636, 13.117934446781874, 24.077130630612373, 40.15800453722477, 41.88328295946121, 37.14562118053436, 29.18165512382984, 22.906286157667637, 28.57194174081087, 27.248622849583626, 20.258643329143524, 8.915919475257397, 1.2737270398065448, 0.3182607394410297, 0.1975389165454544, 2.144041839055717, 2.1840691287070513, 2.118709310889244, 6.84276164509356, 12.708458919078112, 4.360973741859198, 3.868441083468497, 3.958172556012869, 3.0911490926519036, 5.300176469609141, 16.01487524807453, 20.422361344099045, 25.980380102992058, 36.58968061208725, 39.30938087403774, 39.03026685118675, 45.73741614818573, 55.11565871536732, 54.08963397145271, 51.617479026317596, 49.52606365084648, 50.22295005619526, 50.4657494276762, 51.07031598687172, 50.464826077222824, 49.96816232800484, 51.185195222496986, 49.73947919905186, 49.93287742137909, 48.76732796430588, 47.47265003621578, 46.177618727087975, 48.48681181669235, 43.77529263496399, 47.45066061615944, 48.56941558420658, 50.78924886882305, 51.24595396220684, 54.66847211122513, 41.7856851965189, 36.402179673314095, 53.04384268820286, 50.532622039318085, 52.59080059826374, 50.75083293020725, 52.55310282111168, 51.217770874500275, 50.27588501572609, 50.11586420238018, 50.69171950221062, 48.51442493498325, 52.46597349643707, 50.994669646024704, 50.57177893817425, 52.698346227407455, 53.242579624056816, 53.56738239526749, 51.04930691421032, 49.64575342833996, 52.51609280705452, 57.84257858991623, 48.974758833646774, 49.13620077073574, 47.68476605415344, 42.95376531779766, 53.00777122378349, 47.19941049814224, 41.4432779699564, 29.798377230763435, 20.623404756188393, 11.82682927697897, 7.333417916670442, 5.580525901168585, 2.8611802076920867, 8.163610193878412, 4.958229493349791, 8.030465338379145, 5.882315207272768, 2.95043908059597, 3.49813599139452, 2.4979778844863176, 1.2865718943066895, 0.3300206334097311, 0.21449716907227412, 1.1571529763750732, 6.530670616775751, 15.738003104925156, 25.7442569732666, 31.478952951729298, 34.14160117506981, 37.933733090758324, 49.853708669543266, 44.25488010048866, 34.04050000011921, 19.80024542659521, 4.444409664720297, 0.4266503982944414, 0.026799490660778247, 0.034730574261629954, 0.07101401832187548, 0.0452266501088161, 0.007488083128919243, 0.024507870366505813, 0.08755542134167627, 0.005234476566329249, 0.0334280345850857, 0.03767757589230314, 0.008165491872205166, 0.04572358106088359, 0.02944325631688116, 0.03703981499711517, 0.04368739500932861, 0.04512458996032365, 0.013711810079257702, 0.10218865878414363, 0.032099530872073956, 0.066988282778766, 0.028804153989767656, 0.03425766291911714, 0.05978185072308406, 0.011138103163830237, 0.0469737881940091, 0.0619812684453791, 0.07050146887195297, 0.03503868058032822, 0.04020312670036219, 0.058900791555061005, 0.049208246418857016, 0.041040343494387344, 0.08376539190066978, 0.040142311408999376, 0.011355964325048262, 0.054968945114524104, 0.07610840199049562, 0.026327009763917886, 0.026700072558014654, 0.0095791830062808, 0.03668398116133176, 0.019383858307264745, 0.025370834118803032, 0.024766766728134826, 0.07174569429480471, 0.022994121027295478, 0.06466226579505019, 0.03897633432643488, 0.027767579631472472, 0.01860225991549669, 0.028453119994082954, 0.08095640747342259, 0.02302960867382353, 0.06110449518018868, 0.03772980453504715, 0.017558603612997103, 0.04388844652567059, 0.049011814771802165, 0.019690582375915255, 0.015029014593892498, 0.06843822411610745, 0.05753767036367208, 0.02220864120317856, 0.03517640463542193, 2.660985100083053, 16.447402238845825, 31.160906217992306, 47.65203841030598, 46.680175960063934, 42.69761726260185, 32.81263388693333, 24.728881157934666, 29.92441836744547, 27.076516784727573, 19.50904045253992, 10.312581080943346, 1.807272203732282, 0.4118593060411513, 0.20172552001895383, 0.9657176455948502, 1.7442516353912652, 3.0822796560823917, 9.470057040452957, 8.388392832130194, 6.525489119812846, 6.4976774621754885, 5.721627054736018, 6.433383487164974, 11.700177323073149, 15.295255612581968, 24.139103405177593, 29.83388252556324, 41.70952208340168, 44.65600557625294, 45.940823033452034, 47.350190207362175, 54.885653257369995, 55.596382319927216, 53.737666457891464, 53.803661316633224, 52.78303608298302, 53.760579228401184, 52.9595822095871, 54.49357129633427, 53.11530165374279, 53.59015457332134, 52.60299414396286, 51.970054507255554, 50.0579971075058, 49.04075749218464, 48.78763027489185, 49.169399589300156, 47.736177295446396, 48.87751445174217, 50.430817902088165, 52.02159494161606, 53.40428374707699, 55.50756588578224, 43.406127244234085, 38.47688354551792, 52.43007302284241, 52.916241735219955, 54.42106358706951, 53.84210005402565, 53.96218881011009, 54.17860999703407, 51.87808804214001, 51.94150663912296, 52.20397375524044, 52.19140402972698, 54.16712321341038, 51.99878476560116, 52.90573909878731, 54.86002743244171, 54.785882011055946, 54.824107959866524, 51.86289645731449, 50.24238981306553, 54.63575966656208, 57.3481073230505, 49.9392344802618, 54.6826833486557, 51.919752806425095, 49.434921741485596, 56.5611619502306, 50.29359586536884, 42.77188427746296, 31.287690214812756, 24.40726261585951, 15.059206578880548, 7.309425054118037, 7.15830716304481, 5.240366728976369, 6.7565722949802876, 7.5250758323818445, 9.195631965994835, 7.25345928221941, 4.137279745191336, 3.6211729142814875, 2.1728670923039317, 0.889578340575099, 0.5946985480841249, 0.24102911178488284, 1.707307524047792, 6.675769155845046, 15.29009833931923, 28.022196739912033, 34.66403894126415, 38.46866458654404, 42.58190207183361, 57.704171016812325, 51.30044683814049, 40.82133874297142, 24.18679654598236, 5.710083274170756, 0.6653483945410699, 0.15573912591207772, 0.07055563823087141, 0.0864768803876359, 0.06453791895182803, 0.010549683956924127, 0.0192281705676578, 0.038385707230190746, 0.018763309672067408, 0.05742510882555507, 0.04738891220767982, 0.09580727230058983, 0.0430266275361646, 0.03207121051673312, 0.06409835230442695, 0.04203853211947717, 0.052586740130209364, 0.023533612293249462, 0.021546016505453736, 0.05451031269330997, 0.03067475390707841, 0.05254732466710266, 0.040678112345631234, 0.05184758330869954, 0.05515175835171249, 0.01766118326486321, 0.012631661447812803, 0.05499998544109985, 0.08367171802092344, 0.08669880480738357, 0.0381902700610226, 0.1353859039954841, 0.14798736374359578, 0.11938148192712106, 0.20140307169640437, 0.15474898216780275, 0.13883280887966976, 0.14592064573662356, 0.11696743880747817, 0.15604480169713497, 0.09837924444582313, 0.18037396104773507, 0.10613106598611921, 0.17457079666201025, 0.14478826196864247, 0.1473802572581917, 0.1620870118495077, 0.19789388577919453, 0.15048599685542285, 0.13471475016558543, 0.16505321284057572, 0.20916152803692967, 0.13230885582743213, 0.1178877464553807, 0.20826965948799625, 0.12641934998100623, 0.1296650734730065, 0.16008558799512684, 0.08113496078294702, 0.18402902351226658, 0.13552100455854088, 0.1595941378036514, 0.1605210654088296, 0.1469331726548262, 0.13475093728629872, 3.1461798772215843, 17.93808124959469, 35.594422817230225, 55.77990107238293, 55.13486668467522, 50.78213185071945, 41.542661637067795, 34.21875223517418, 39.74442332983017, 38.198046907782555, 26.780003495514393, 13.004466835409403, 2.580252494663, 0.8087784075178206, 0.5494308052584529, 4.408821724355221, 5.267624091356993, 8.598277419805527, 15.945027396082878, 22.298605665564537, 11.658882088959217, 8.525016400963068, 11.67654164135456, 6.434511551633477, 11.967997401952744, 19.230327308177948, 27.94680118560791, 34.1446828097105, 45.521488934755325, 49.95035648345947, 50.68039231002331, 50.24473808705807, 57.075129970908165, 58.01092475652695, 56.49498090147972, 55.014777928590775, 55.409743934869766, 55.638202875852585, 56.26364931464195, 56.50168754160404, 54.45210412144661, 56.22500158846378, 53.929768949747086, 53.804664462804794, 50.964829847216606, 50.86361847817898, 51.93863399326801, 51.911830231547356, 49.15105037391186, 50.896330922842026, 52.610734328627586, 54.422427713871, 56.76170378923416, 56.9020264595747, 45.905982702970505, 41.925415098667145, 54.35490533709526, 53.78848113119602, 55.80998785793781, 55.523905009031296, 56.77195563912392, 56.133016124367714, 55.21829880774021, 54.95740860700607, 55.19091747701168, 53.39346192777157, 56.70911841094494, 54.53097268939018, 56.23717613518238, 57.23512038588524, 57.84647338092327, 56.198520809412, 52.18288108706474, 50.61139941215515, 54.18242119252682, 58.93998250365257, 53.465259075164795, 54.755388647317886, 58.44046130776405, 51.53881184756756, 61.35757617652416, 54.15632799267769, 49.56142835319042, 33.658472299575806, 27.407718412578106, 19.00200515985489, 11.24805573374033, 10.2694296464324, 8.882391974329948, 15.126109588891268, 13.348648566752672, 17.712523452937603, 14.276720266789198, 11.06226185336709, 8.292475529015064, 5.973991462960839, 2.3712910199537873, 1.2779190461151302, 0.8381284482311457, 1.977153131738305, 9.647865649312735, 23.35689637809992, 36.3818583637476, 44.62755270302296, 47.04286269843578, 50.90367212891579, 62.996758818626404, 58.04202228784561, 45.89180566370487, 26.698019094765186, 6.831147568300366, 0.8952561859041452, 0.18101121357176453, 0.1339234277838841, 0.2277287864126265, 0.2686018869280815, 0.08309921046020463, 0.13325409963726997, 0.15616526710800827, 0.09142745810095221, 0.1627093175193295, 0.12174850999144837, 0.2617353881942108, 0.15236967155942693, 0.15729327220469713, 0.1348504889756441, 0.141699947998859, 0.22202506981557235, 0.1537489381735213, 0.2642935118637979, 0.13680034840945154, 0.21779552567750216, 0.15859323291806504, 0.18511015456169844, 0.15418877941556275, 0.20017634611576796, 0.12482212943723425, 0.1596645824611187, 0.1928849084652029, 0.15248595125740394, 0.23756221344228834, 0.15013003314379603], [0.07275943833519705, 0.019971900874224957, 0.027589005912886932, 0.03717172803590074, 0.03802919804002158, 0.048054440558189526, 0.029173717557569034, 0.05176614002266433, 0.1063559961039573, 0.015704386605648324, 0.03496282937703654, 0.0808751794102136, 0.03515542783134151, 0.026720431524154264, 0.04164540165220387, 0.019599077422753908, 0.07272847593412735, 0.057405018887948245, 0.10052031822851859, 0.018796043950715102, 0.05912390712182969, 0.012919630516989855, 0.042796101624844596, 0.013611368740384933, 0.03534453448082786, 0.05288084583298769, 0.014726380686624907, 0.04036741222080309, 0.08577952874475159, 0.02384351460932521, 0.019977567171736155, 0.003105853238594136, 0.02139566480764188, 0.11662313423585147, 0.4454668698599562, 6.85689783655107, 23.403054401278496, 38.71712185442448, 38.69865484535694, 41.937840431928635, 34.14540097117424, 31.413271576166153, 25.96722710877657, 18.724570646882057, 16.33900735527277, 8.58162671327591, 3.8392897602170706, 0.604747524484992, 0.4453674517571926, 0.6893480848520994, 0.8959101664368063, 2.9390271054580808, 3.876971388235688, 4.733219342306256, 6.365946605801582, 4.319147961214185, 3.8235733285546303, 3.9352699974551797, 8.941588997840881, 8.458216935396194, 16.25297997146845, 25.996183454990387, 33.01683872938156, 34.143364280462265, 42.01096750795841, 54.117668867111206, 51.79673060774803, 53.934613689780235, 51.03499308228493, 49.779437854886055, 49.442509934306145, 49.55771595239639, 51.153938099741936, 48.90762023627758, 48.517358377575874, 46.98541358113289, 46.4108008146286, 45.373258888721466, 44.508828073740005, 42.22873382270336, 44.51776519417763, 44.64664667844772, 44.87273834645748, 47.972688004374504, 47.86431781947613, 51.0510890185833, 48.57185125350952, 54.20914135873318, 38.15553858876228, 36.02271303534508, 50.10510317981243, 49.96151268482208, 54.78004552423954, 50.71068428456783, 52.51846008002758, 52.4675428122282, 53.26524540781975, 51.56428948044777, 52.36681021749973, 52.75998651981354, 52.04825811088085, 54.18796889483929, 54.22405555844307, 54.5100662112236, 53.07993695139885, 52.2300061583519, 51.41608603298664, 52.612311244010925, 51.864135190844536, 51.52910336852074, 52.73082308471203, 45.108644887804985, 55.80187529325485, 48.17978449165821, 42.90780298411846, 37.83178836107254, 28.606170304119587, 25.734493397176266, 15.209506563842297, 12.41531889885664, 6.180156050249934, 5.550914565101266, 5.897791301831603, 3.3160932222381234, 6.720718843862414, 5.766055220738053, 6.606492223218083, 0.8241124846972525, 2.8826129576191306, 1.9333281833678484, 0.8296999067533761, 0.24153044738341123, 0.9308732184581459, 1.8792433105409145, 8.598736245185137, 23.912173882126808, 30.495254136621952, 47.041749358177185, 40.48267051577568, 40.72369538247585, 45.50642654299736, 43.529635816812515, 30.537251383066177, 14.666385557502508, 3.877093931660056, 0.025904334397637285, 0.043280894751660526, 0.002755115406216646, 0.06375773620675318, 0.022682554445054848, 0.06986155203776434, 0.04740041549666785, 0.03906027865014039, 0.03892962355166674, 0.02809102243190864, 0.11304742962238379, 0.037552026769844815, 0.012279992915864568, 0.022732588186045177, 0.008372218962904299, 0.054164553512237035, 0.039652742561884224, 0.0627702493511606, 0.019774547108681872, 0.00768077527936839, 0.08933739212807268, 0.02477306199580198, 0.010832904208655236, 0.06340908264974132, 0.009189277170662535, 0.07899787233327515, 0.018421235254209023, 0.013102318516757805, 0.04313864359573927, 0.0306935024127597, 0.03925886994693428, 0.04482911499508191, 0.020736344522447325, 0.05396797714638524, 0.09514213728834875, 0.06899778862134553, 0.039632099724258296, 0.00445552346718614, 0.046696870631421916, 0.0480497316311812, 0.021868347939744126, 0.05870046363270376, 0.020656611886806786, 0.021613514836644754, 0.05495590557984542, 0.07649381412193179, 0.043060847965534776, 0.033685259259073064, 0.06107588538725395, 0.05096820881590247, 0.0261175719788298, 0.14184423635015264, 0.06939651488210075, 0.01853128462244058, 0.03372784369275905, 0.06923286389792338, 0.052784938088734634, 0.011794247056968743, 0.07706007279921323, 0.06701445090584457, 0.02662545331986621, 0.07589922024635598, 0.027761371566157322, 0.024015175222302787, 0.02610802424896974, 0.8308817027136683, 9.787539504468441, 26.89386248588562, 46.10970497131348, 46.5767303109169, 47.402163818478584, 38.90619210898876, 32.74639964103699, 32.73053169250488, 26.07009518891573, 19.339527748525143, 10.594826135784388, 2.9105350468307734, 0.630508242174983, 0.24922328302636743, 0.49014795979019254, 1.8100700411014259, 2.801852091215551, 9.3351842276752, 8.221098259091377, 8.893504478037357, 10.4996307939291, 5.724186217412353, 6.337350765243173, 6.10481321811676, 13.579793013632298, 21.787187308073044, 29.63355727493763, 39.1092874109745, 40.63293345272541, 45.193505734205246, 54.1703986376524, 52.43155874311924, 55.30965730547905, 52.46888034045696, 52.239444851875305, 51.909470558166504, 53.03836338222027, 52.63353690505028, 52.00258456170559, 51.077824383974075, 50.01686051487923, 48.57023634016514, 48.14914673566818, 46.20861366391182, 44.9149464815855, 47.542326897382736, 46.85332506895065, 47.170900627970695, 50.92273190617561, 50.705421566963196, 52.020116820931435, 51.694542691111565, 53.03874336183071, 42.329170033335686, 39.30559627711773, 52.040457129478455, 51.88936963677406, 56.195496171712875, 51.357880756258965, 54.025956988334656, 54.33612674474716, 54.92872394621372, 53.2681218534708, 54.91448611021042, 55.21766044199467, 55.15312850475311, 56.185745894908905, 54.61538515985012, 54.599319621920586, 53.29485721886158, 52.783575654029846, 52.15174935758114, 52.91442543268204, 53.40700440108776, 52.460486590862274, 53.57117459177971, 48.466919884085655, 60.59333078563213, 49.928139075636864, 48.88330154120922, 44.83102798461914, 35.638774037361145, 27.262873984873295, 17.663143202662468, 13.263845667243004, 7.97618905082345, 8.203635346144438, 6.113823959603906, 9.863008204847574, 9.700768310576677, 7.38713325932622, 6.5357594937086105, 3.485933421179652, 4.25167023204267, 1.5175484376959503, 0.48623155744280666, 0.19556462561013177, 0.6924651050940156, 2.25444040261209, 9.090254120528698, 24.227273873984814, 32.335037514567375, 48.14500115811825, 43.261507004499435, 46.78850054740906, 52.40330345928669, 50.02927824854851, 36.744947880506516, 17.61128928512335, 4.833797570317984, 0.12380673782899976, 0.08135326352203265, 0.017329365327896085, 0.04119784578506369, 0.011531226209626766, 0.0729856820544228, 0.05597952760581393, 0.05578496246016584, 0.03020811371243326, 0.03461030180915259, 0.06765035272110254, 0.07241234328830615, 0.0020044900838911417, 0.060161804358358495, 0.03562490674084984, 0.044272363229538314, 0.03718137595569715, 0.02660470658156555, 0.010123974134330638, 0.01723473036690848, 0.06100249069277197, 0.05067493060778361, 0.022302235302049667, 0.0376437228260329, 0.07602160039823502, 0.0920746628253255, 0.02378870329266647, 0.020829697423323523, 0.01893860309792217, 0.032336572839994915, 0.05562252117670141, 0.24414835846982896, 0.1350531101343222, 0.12240033087437041, 0.1058188964088913, 0.23061525105731562, 0.15029689762741327, 0.11567926339921542, 0.09715025531477295, 0.17427576327463612, 0.08686474902788177, 0.21665408770786598, 0.16653323342325166, 0.14325655822176486, 0.16269848216325045, 0.1381056525860913, 0.0741224444936961, 0.14453003910603002, 0.1242760794411879, 0.18831526773283258, 0.10701986946514808, 0.2791192178847268, 0.13214429200161248, 0.15841223794268444, 0.2375484540243633, 0.12662289140280336, 0.1115406843018718, 0.12778371426975355, 0.22068126301746815, 0.12217381998198107, 0.13973674474982545, 0.20470344694331288, 0.18093432707246393, 0.12123200489440933, 0.19949926994740963, 0.9856240649241954, 11.270920056849718, 30.381284952163696, 53.657034784555435, 54.24902401864529, 55.84672428667545, 47.5615880638361, 43.53850834071636, 38.491980135440826, 28.256051391363144, 24.93055533617735, 13.066665697842836, 5.902226138859987, 1.0209124744869769, 0.891931839287281, 1.8882394465617836, 4.033852620050311, 8.884675651788712, 12.026903741061687, 12.117780614644289, 19.122285805642605, 15.389220770448446, 9.409470241516829, 8.594067245721817, 14.046478271484375, 15.306604653596878, 27.22483992576599, 35.32301478087902, 46.539534106850624, 47.48513236641884, 49.85935516655445, 55.764842480421066, 53.28978069126606, 57.60714702308178, 55.03473825752735, 54.88232083618641, 54.24159921705723, 55.27954012155533, 54.90217477083206, 53.41434180736542, 52.325145453214645, 51.615427136421204, 51.07829175889492, 50.59533767402172, 47.47611165046692, 45.643538385629654, 49.737248718738556, 49.16271194815636, 48.739285469055176, 52.499822080135345, 52.17807434499264, 54.18323054909706, 53.78354899585247, 53.56340020895004, 45.469264537096024, 43.42118203639984, 52.30458855628967, 54.30019207298756, 57.908261865377426, 54.49032627046108, 55.300169214606285, 54.6091078966856, 57.90110684931278, 56.019045040011406, 55.84879517555237, 58.20613168179989, 57.20011666417122, 58.31927441060543, 55.61977006494999, 55.864982306957245, 54.19846773147583, 53.83858524262905, 53.37964586913586, 54.37232740223408, 53.6275065690279, 53.73166657984257, 54.324176385998726, 49.91300828754902, 59.8660422116518, 52.40678787231445, 49.81264427304268, 48.00626680254936, 38.104226142168045, 34.840980246663094, 20.66309742629528, 17.426896579563618, 11.92215571179986, 13.668103124946356, 12.495708335191011, 10.13569962233305, 14.68573221936822, 13.095127120614052, 12.651739362627268, 7.659342102706432, 7.487313933670521, 4.952636193484068, 2.6832747040316463, 0.6186677212826908, 1.141906650736928, 2.983189048245549, 12.447040546685457, 32.76333533227444, 40.80856762826443, 59.98253256082535, 52.579955980181694, 54.69699338078499, 60.28142832219601, 56.371681317687035, 42.64045313000679, 19.067732132971287, 5.4349390882998705, 0.18882209522416815, 0.16877094225492328, 0.13421904004644603, 0.12421554245520383, 0.10837674548383802, 0.1260054690646939, 0.1471037181909196, 0.12815840978873894, 0.07114065097994171, 0.14445065899053589, 0.16116668935865164, 0.16603964584646747, 0.11074030029703863, 0.12661784479860216, 0.09957738991943188, 0.12561983428895473, 0.1348047875217162, 0.12304623684030958, 0.1744520678767003, 0.22997691499767825, 0.1937095235916786, 0.11105706376838498, 0.11824356915894896, 0.22868952626595274, 0.1240540733851958, 0.15516805811785161, 0.1471453972044401, 0.1268011998035945, 0.12703476852038875, 0.14958053216105327, 0.13667727063875645], [0.09370902043883689, 0.01604912533366587, 0.043236414130660705, 0.02648047848197166, 0.06199412986461539, 0.03799432080995757, 0.030654148176836316, 0.048990448340191506, 0.05562377169553656, 0.09328782194643281, 0.07811189643689431, 0.07912171451607719, 0.03415231505641714, 0.020353555883048102, 0.06919701816514134, 0.03544631261320319, 0.10250179315335117, 0.053806808646186255, 0.011759801200241782, 0.03336775364005007, 0.029057731007924303, 0.1011494813428726, 0.09528842943836935, 0.03946429271309171, 0.01836733121308498, 0.029598548862850294, 0.006457511353801237, 0.05214831639023032, 0.06658508878899738, 0.1467144172056578, 0.08966648267232813, 0.022979500718065538, 0.02699568296520738, 0.026053602559841238, 0.20430711039807647, 4.398054052144289, 17.614950388669968, 33.299976736307144, 43.513273894786835, 46.31146654486656, 33.54978293180466, 30.559117309749126, 21.729432307183743, 20.196148082613945, 22.846483066678047, 12.956223674118519, 4.99100130982697, 1.1022429540753365, 0.14168926107231528, 0.22046354657504708, 1.0051130410283804, 1.6205446422100067, 8.825104348361492, 6.533033140003681, 3.437784304842353, 9.05985290184617, 3.0585109815001488, 5.2976040076464415, 5.883000595495105, 9.707861579954624, 16.26762818545103, 20.36269124597311, 28.164426907896996, 37.246365174651146, 51.55120298266411, 53.91358181834221, 55.34641273319721, 52.083736807107925, 49.08927708864212, 50.09230926632881, 49.19300012290478, 48.56137901544571, 47.923020869493484, 47.6676631718874, 47.32692405581474, 43.375926464796066, 43.975690081715584, 43.77831347286701, 44.91419032216072, 44.13029998540878, 45.948927998542786, 47.508307322859764, 49.079564809799194, 50.60502715408802, 49.72350485622883, 53.82467798888683, 51.706162467598915, 52.31669470667839, 40.15682280063629, 37.48532295227051, 52.43817038834095, 49.87067475914955, 52.957385927438736, 49.76084925234318, 52.29519546031952, 51.64688564836979, 54.04566653072834, 51.59468024969101, 51.751611828804016, 50.30398830771446, 54.6548992395401, 52.290878891944885, 52.07497827708721, 50.37437193095684, 50.195830911397934, 51.77685387432575, 52.91509039700031, 51.70705161988735, 49.476141929626465, 53.16405303776264, 52.59981371462345, 51.59586578607559, 56.0924457013607, 52.915306985378265, 58.35045553743839, 45.09251855313778, 32.017173171043396, 18.137745335698128, 13.002091962844133, 7.4610131699591875, 4.099908750504255, 5.783807393163443, 3.840493820607662, 7.468360550701618, 7.482074964791536, 4.880332248285413, 4.063897607848048, 2.8962406888604164, 2.8483081609010696, 0.7207992940675467, 0.3320641815662384, 0.31146257766522467, 0.6275611440651119, 3.8093753904104233, 10.372486766427755, 21.290001086890697, 29.893955402076244, 40.686145797371864, 40.202830731868744, 45.19680775702, 39.92889203131199, 36.673352122306824, 26.47658407688141, 12.799540981650352, 2.092373874038458, 0.04262468035449274, 0.00992441247944953, 0.05676102766301483, 0.052030166480108164, 0.010043362981377868, 0.039429793978342786, 0.020773368414666038, 0.038726479178876616, 0.06850123987533152, 0.024027450344874524, 0.023223079151648562, 0.016664840732119046, 0.03420206863665953, 0.004385838119560503, 0.04188840677670669, 0.027206191298319027, 0.0108168886617932, 0.04544227740552742, 0.04973130096914247, 0.0486157342675142, 0.08451648987829685, 0.04646736888389569, 0.02790152058878448, 0.04196871828753501, 0.03344799464684911, 0.031012787330837455, 0.07524230080889538, 0.01289961108341231, 0.05504248823854141, 0.031034949715831317, 0.04091042312211357, 0.037382449736469425, 0.02253318794828374, 0.057096701057162136, 0.016350737860193476, 0.04158277180977166, 0.12202786179841496, 0.03247613742132671, 0.04038831109937746, 0.08279747547931038, 0.03885878555593081, 0.017494452367827762, 0.018391770136076957, 0.01190459513964015, 0.048485721126780845, 0.07630764637724496, 0.06512359221233055, 0.12745405227178708, 0.009029795201058732, 0.009012263817567145, 0.04692737427831162, 0.0238569066641503, 0.041887564439093694, 0.024750845805101562, 0.10622897010762244, 0.06918654646142386, 0.03055784894968383, 0.019819788431050256, 0.06600481836358085, 0.04156300470640417, 0.06866991519927979, 0.03410803110455163, 0.056617737500346266, 0.04081442632013932, 0.0588024606986437, 0.2943792287260294, 5.91419312171638, 21.950466446578503, 40.754371136426926, 48.60771752893925, 53.189576268196106, 38.50229278206825, 34.47263181209564, 27.891263365745544, 20.561091899871826, 24.004111848771572, 15.914727821946144, 5.821881350129843, 1.1290830513462424, 0.18684814567677677, 0.4401229019276798, 0.7337723323144019, 2.002662825398147, 5.336541468277574, 6.472068736329675, 5.798732992261648, 7.983554005622864, 7.513265116140246, 7.429214101284742, 8.731206636875868, 13.300527948886156, 20.08961319923401, 23.38150955736637, 32.609709575772285, 41.878491416573524, 53.238050267100334, 52.45976082980633, 55.74344962835312, 53.79236452281475, 52.21300207078457, 52.670166939496994, 50.846329405903816, 51.79312840104103, 50.94505190849304, 48.790331929922104, 49.522294253110886, 47.63483293354511, 46.461045518517494, 46.36367194354534, 47.437023147940636, 45.18236853182316, 46.66879177093506, 50.01997634768486, 50.529544204473495, 52.45283380150795, 51.94735072553158, 55.784358233213425, 54.393009692430496, 52.71334022283554, 43.23290593922138, 40.26497259736061, 52.562522515654564, 51.311815828084946, 54.67210851609707, 51.3122072070837, 53.83203059434891, 52.37279109656811, 53.587791100144386, 51.489311903715134, 52.252880930900574, 52.75232993066311, 55.16404531896114, 53.36700774729252, 54.442779421806335, 51.008854284882545, 52.09885239601135, 53.14448028802872, 53.18492911756039, 52.664550840854645, 53.32472361624241, 53.669353723526, 54.63312640786171, 53.50317344069481, 55.64264103770256, 53.89717809855938, 57.02901564538479, 47.957561016082764, 33.43275301158428, 24.110589735209942, 13.34013132378459, 8.294183537364006, 6.371677173301578, 6.534180678427219, 7.374246250838041, 8.668925128877163, 7.295338734984398, 6.421107770875096, 5.212952625006437, 3.7427426408976316, 2.2226014360785484, 0.7086103793699294, 0.42651039955671877, 0.1594179222593084, 0.8237842179369181, 4.332511844113469, 11.612245291471481, 26.070613861083984, 34.24160420894623, 49.75928373634815, 47.328580766916275, 49.64020952582359, 49.01554964482784, 43.78907449543476, 32.8466534614563, 14.855947885662317, 2.8014160646125674, 0.06408523113350384, 0.09502939021331258, 0.0475966912927106, 0.041000145065481775, 0.044427264292608015, 0.01694162841886282, 0.018790110480040312, 0.0668097888410557, 0.0495454968768172, 0.06554364037583582, 0.06354069511871785, 0.05763718123489525, 0.07667160301934928, 0.013708010283153271, 0.029125429718988016, 0.054701274711987935, 0.021567416333709843, 0.08207606340874918, 0.05358340735256206, 0.035697752246051095, 0.0234153974452056, 0.04490441700909287, 0.020986054951208644, 0.10381727959611453, 0.020032463835377712, 0.10489619162399322, 0.04937500700179953, 0.021836710184288677, 0.02094479525112547, 0.05592590001469944, 0.02886444235628005, 0.1957784828846343, 0.10776300419820473, 0.14400928892428055, 0.10820988842169754, 0.16523659753147513, 0.20532710332190618, 0.10364032932557166, 0.1937795229605399, 0.19517283100867644, 0.15822727989871055, 0.13964474812382832, 0.29897422122303396, 0.08525011769961566, 0.1401898407493718, 0.13167083146981895, 0.1667056343285367, 0.2494570892304182, 0.19582768727559596, 0.09290746384067461, 0.12292446524952538, 0.11300758371362463, 0.23411547183059156, 0.10633901576511562, 0.1263033226132393, 0.16341508511686698, 0.0744406328885816, 0.10299471279722638, 0.14160478982375935, 0.17674341914243996, 0.22123288654256612, 0.2440591374761425, 0.13370590429985896, 0.10683839209377766, 0.1077206053014379, 0.48935101192910224, 6.533197956159711, 23.86402476578951, 44.74772125482559, 58.463119491934776, 62.83280901610851, 46.85871317982674, 41.140297427773476, 32.99514189362526, 29.67995658516884, 33.24263021349907, 18.40502869337797, 6.772146234288812, 1.7797437496483326, 0.4505529860034585, 0.8507583173923194, 3.685982949100435, 4.717328120023012, 16.401601396501064, 13.887167070060968, 9.97159592807293, 18.907245844602585, 8.962385281920433, 10.524936486035585, 9.342419989407063, 15.410749465227127, 26.58763311803341, 29.843912087380886, 40.41377641260624, 46.26605898141861, 54.78860266506672, 55.72378948330879, 59.02355141937733, 54.743666276335716, 54.35726121068001, 53.93970541656017, 52.81779661774635, 53.56062635779381, 53.596922010183334, 50.82303285598755, 52.048638090491295, 47.1557242423296, 47.85720460116863, 48.17883834242821, 49.12060260772705, 47.584147453308105, 49.07183222472668, 51.37418568134308, 53.1286883354187, 54.42949913442135, 55.19185982644558, 58.23329642415047, 56.650392562150955, 53.045237213373184, 46.82782843708992, 44.60844732820988, 53.99340033531189, 52.26026013493538, 55.575871020555496, 52.44999535381794, 53.77395071089268, 50.85485614836216, 54.48901154100895, 51.56210459768772, 52.40134656429291, 51.51670083403587, 55.16612380743027, 52.28976175189018, 54.351109340786934, 53.292793929576874, 52.6146025210619, 53.3645074814558, 55.95477528870106, 51.67895592749119, 52.61240243911743, 54.453574642539024, 54.745148196816444, 54.46968197822571, 57.42286451160908, 55.0102523714304, 57.66797415912151, 49.101630225777626, 38.21225814521313, 25.346646308898926, 18.46433211117983, 11.37902045622468, 9.937240071594715, 14.241461958736181, 8.703229688107967, 13.557398915290833, 17.756969667971134, 13.708143476396799, 10.90542621910572, 8.502870239317417, 7.1668576542288065, 2.6406813645735383, 0.9290093590971082, 0.8350624283775687, 1.195679227821529, 5.428500808775425, 15.321059077978134, 30.241756439208984, 39.80572544038296, 56.65674202144146, 54.28018234670162, 58.470244109630585, 55.74536092579365, 51.558342799544334, 37.74020567536354, 16.144621185958385, 3.1348374858498573, 0.22478731378214434, 0.2214459126116708, 0.10910675904597156, 0.14214639435522258, 0.1545311024528928, 0.14511336717987433, 0.14382744790054858, 0.16698247025487944, 0.14390525466296822, 0.2048878706409596, 0.1495135310688056, 0.15563709544949234, 0.17258371110074222, 0.1483163281227462, 0.13929889246355742, 0.11917357667698525, 0.08761267061345279, 0.19061114609939978, 0.19078317593084648, 0.14669497293652967, 0.16412653756560758, 0.19078369543422014, 0.1113460560736712, 0.2635187393752858, 0.13599127385532483, 0.1766194062656723, 0.19119261880405247, 0.10319140419596806, 0.1276703883195296, 0.15980124153429642, 0.12505834019975737], [0.016113599413074553, 0.025853211554931477, 0.03924760785594117, 0.04013252619188279, 0.03239863122871611, 0.08881989255314693, 0.045244970024214126, 0.04430311411852017, 0.051662358091562055, 0.07631342770764604, 0.06203082906722557, 0.07434593484504148, 0.014057410626264755, 0.015540266213065479, 0.042527796686044894, 0.025838257279247046, 0.0498638411227148, 0.07084081589709967, 0.0820431936881505, 0.07006824758718722, 0.02076055152429035, 0.06631998621742241, 0.07116992870578542, 0.0070330714606825495, 0.03998151027190033, 0.025665503853815608, 0.0556061234237859, 0.05623902325169183, 0.051311177521711215, 0.03460020489001181, 0.03772792319068685, 0.08555649110348895, 0.026605287312122528, 0.029376709790085442, 0.06625948633882217, 1.5330326068215072, 12.838833723217249, 24.939467757940292, 46.72314405441284, 49.85798344016075, 37.14364908635616, 30.74685763567686, 29.027176313102245, 29.157357327640057, 17.820975333452225, 14.533183705061674, 8.979214578866959, 1.737404284067452, 0.6171951815485954, 0.14559839037247002, 0.41835695737972856, 1.5959001146256924, 5.780551917850971, 6.557794036343694, 5.3222019877284765, 6.981332134455442, 7.031334126368165, 4.165561152622104, 4.4578637927770615, 11.292491499334574, 16.027473472058773, 21.40224326401949, 30.326976366341114, 41.63439631462097, 52.147957161068916, 52.481944039464, 54.58461821079254, 50.29671549797058, 52.117144614458084, 50.18404774367809, 48.66142764687538, 48.455205112695694, 48.16945664584637, 47.13784620165825, 45.38487486541271, 45.88872782886028, 44.072033911943436, 47.1730513125658, 45.664866641163826, 46.69100537896156, 48.74047480523586, 50.766879469156265, 48.431315794587135, 50.22729702293873, 51.264162585139275, 52.64532387256622, 46.54608875513077, 52.41399608552456, 36.57136179506779, 36.171798035502434, 51.62695951759815, 50.04788964986801, 51.65065884590149, 52.297935113310814, 53.293413296341896, 52.354635670781136, 53.214073553681374, 53.327463269233704, 53.647379502654076, 53.28185431659222, 52.66079284250736, 52.302711457014084, 49.651985093951225, 52.74107873439789, 53.79114478826523, 51.95463493466377, 52.10144765675068, 54.52778086066246, 51.693573743104935, 53.6658389121294, 56.07818506658077, 51.59131743013859, 53.175889402627945, 50.610381066799164, 50.27353294193745, 45.97523018717766, 36.505879908800125, 26.045677699148655, 15.9808898717165, 8.407117277383804, 3.5755518497899175, 3.825922077521682, 5.705238534137607, 9.826479814946651, 5.134344818070531, 5.495586208999157, 4.011876974254847, 2.0792595902457833, 1.6291077202185988, 0.8291267312597483, 0.5518396978732198, 0.13636720133945346, 1.140972850844264, 2.929352824576199, 11.863237023353577, 21.762348040938377, 29.54799346625805, 28.05038932710886, 38.73771294951439, 43.01533341407776, 33.36808808147907, 39.495396092534065, 18.964273184537888, 6.106100399047136, 0.9070841199718416, 0.00587631092457741, 0.04075362587173004, 0.06572122889338061, 0.014175113392411731, 0.008613518075435422, 0.08059065483394079, 0.010264601842209231, 0.026123280949832406, 0.034645516716409475, 0.031038634479045868, 0.007517117337556556, 0.033302233132417314, 0.03194409917341545, 0.10856412292923778, 0.05471152748214081, 0.025597691965231206, 0.05045896192314103, 0.02452217711834237, 0.04757519127451815, 0.09059954041731544, 0.032431512081529945, 0.0322509030229412, 0.05488837014127057, 0.08715848365682177, 0.09112094368902035, 0.017969681066460907, 0.028235405407031067, 0.022695896404911764, 0.01665912062890129, 0.12642369896639138, 0.04002542314992752, 0.05461018350615632, 0.03660848247818649, 0.06142573009128682, 0.0762193975970149, 0.011432753417466301, 0.06668296322459355, 0.08004830073332414, 0.013147120116627775, 0.022710709672537632, 0.05131311452714726, 0.04904811692540534, 0.026576731324894354, 0.0508048027404584, 0.046997176978038624, 0.04006748436950147, 0.023488771730626468, 0.07535106255090795, 0.032080802775453776, 0.02677904634765582, 0.07860680503654294, 0.055086894644773565, 0.06082308020268101, 0.013317594221007312, 0.013607078199129319, 0.1138971144973766, 0.026473379839444533, 0.03552908805431798, 0.06195698537339922, 0.05841107056767214, 0.023355687953880988, 0.057638884463813156, 0.056413398269796744, 0.03533369170327205, 0.043440118824946694, 0.13061672943877056, 2.1866453904658556, 16.252233311533928, 31.054418832063675, 52.68402859568596, 54.06615503132343, 41.15535221993923, 35.07481589913368, 29.931620880961418, 31.4106972143054, 23.835777081549168, 15.971791259944439, 9.73594207316637, 2.2186045255512, 0.4728667839663103, 0.4880064184544608, 0.5861323233693838, 0.848721923539415, 2.822138015180826, 8.763730991631746, 7.111572045832872, 9.979323763400316, 6.169627765193582, 3.9909533970057964, 5.8986856788396835, 9.624764788895845, 18.136001229286194, 23.69692873209715, 34.382299259305, 44.70887213945389, 51.85983382165432, 52.89556324481964, 56.25233352184296, 53.151038736104965, 54.078926146030426, 51.517662182450294, 52.6526764780283, 51.53463967144489, 51.14220812916756, 47.764371782541275, 47.14330650866032, 45.89582584798336, 47.0211810618639, 46.782230883836746, 46.87019996345043, 47.46793828904629, 51.5003427118063, 51.625101417303085, 51.820863112807274, 52.84337304532528, 54.62221339344978, 53.898975402116776, 48.256202191114426, 50.10186195373535, 39.03243653476238, 40.26876099407673, 53.76429542899132, 51.85531206429005, 52.17436194419861, 52.59892076253891, 54.35368560254574, 53.77403050661087, 54.45092998445034, 53.72817076742649, 53.57634611427784, 52.80127130448818, 55.20760618150234, 53.19786362349987, 51.3124655932188, 54.68762308359146, 53.717489540576935, 53.66814158856869, 53.51904138922691, 56.63712367415428, 54.20317567884922, 54.964449629187584, 53.71507667005062, 52.16919422149658, 56.06936953961849, 52.997507974505424, 52.12364226579666, 47.3798818141222, 38.01455855369568, 26.063949018716812, 18.65589313209057, 8.26326459646225, 5.841148216277361, 6.108978744596243, 5.436185421422124, 10.784273520112038, 8.396459799259901, 7.1782351937144995, 5.6267033983021975, 4.309295089915395, 1.5326640265993774, 0.8781762805301696, 0.4604996944544837, 0.22090898361057043, 1.1108642164617777, 3.9312749868258834, 12.753497902303934, 26.83953870087862, 32.62985609471798, 35.28858482837677, 45.61902970075607, 48.69093306362629, 39.65357780456543, 44.318192303180695, 23.162346817553043, 8.17561849951744, 1.445967759937048, 0.09745177507284097, 0.019995230286440346, 0.055662278027739376, 0.07314692848012783, 0.039802478277124465, 0.0434274132567225, 0.007369514833044377, 0.02907470021455083, 0.041767919101403095, 0.027549380793061573, 0.09845978231169283, 0.035391853816690855, 0.06848368808277883, 0.04201782248856034, 0.03910002065822482, 0.016488272667629644, 0.02886701018724125, 0.03069273428991437, 0.04961606398865115, 0.09568950088578276, 0.009416133161721518, 0.011920581928279717, 0.073000198462978, 0.009621587469155202, 0.03587583058106247, 0.030921614488761406, 0.06378359263180755, 0.02772235129668843, 0.07054306624922901, 0.006151451507321326, 0.034385453327558935, 0.15161567920586094, 0.110669707210036, 0.16150461888173595, 0.1856089074863121, 0.10717587632825598, 0.20295766327762976, 0.1622507444699295, 0.11822184649645351, 0.10392334734206088, 0.18756706413114443, 0.18646730517502874, 0.20591296954080462, 0.09030162749695592, 0.14959052146878093, 0.1525322167435661, 0.1494191595702432, 0.35325205244589597, 0.13392093416769058, 0.20824502018513158, 0.19682071055285633, 0.26185555674601346, 0.16712885146262124, 0.1445352638256736, 0.12689597206190228, 0.15266424481524155, 0.1322502558468841, 0.0985764479264617, 0.261187891010195, 0.11069879197748378, 0.16870772611582652, 0.14845669793430716, 0.30361113022081554, 0.14760692400159314, 0.10150387912290171, 0.2808458392973989, 2.5424630474299192, 17.92572431266308, 35.74981167912483, 59.976167902350426, 63.54329489171505, 49.09647390246391, 42.91085422039032, 39.121423959732056, 41.387246176600456, 26.306740790605545, 23.123708590865135, 13.209268245846033, 3.4738168213516474, 0.737280078465119, 0.7705342909321189, 1.4599235798232257, 5.18980854190886, 10.23349117487669, 13.53642689064145, 13.41548603028059, 17.886276729404926, 14.723224807530642, 9.78183126077056, 9.561160001903772, 15.581399258226156, 25.554574951529503, 32.18235790729523, 40.29655270278454, 49.15535934269428, 55.51030933856964, 53.43122810125351, 58.469814732670784, 54.14247773587704, 56.56728722155094, 54.447426572442055, 54.350364580750465, 53.970525562763214, 52.37206533551216, 50.60725763440132, 49.38731029629707, 49.18228089809418, 50.52043989300728, 50.59187225997448, 49.05765898525715, 51.32743299007416, 52.662973925471306, 55.54377794265747, 52.54182882606983, 54.41111572086811, 56.22855819761753, 55.90030521154404, 48.97859662771225, 49.688489735126495, 42.11507052183151, 44.14537377655506, 53.46657380461693, 52.83042713999748, 54.17396664619446, 54.99854899942875, 55.50194598734379, 54.773308485746384, 55.75669951736927, 56.46780475974083, 53.62391196191311, 54.152877777814865, 54.08356949687004, 54.554865807294846, 52.57311634719372, 56.20907284319401, 56.591754108667374, 56.269850581884384, 56.40252806246281, 59.59096737205982, 54.863880425691605, 56.51651054620743, 56.272723227739334, 54.169118106365204, 57.105623334646225, 53.462755009531975, 52.11239106953144, 48.41043211519718, 39.54702012240887, 30.43976381421089, 20.327535532414913, 12.173810508102179, 8.361718263477087, 7.83524083904922, 14.447621796280146, 18.226839154958725, 13.269530162215233, 15.186940524727106, 11.37319726869464, 6.998302498832345, 6.042474238201976, 2.3587953904643655, 1.4902510587126017, 0.39082963136024773, 1.7304789181798697, 5.043535865843296, 18.221574537456036, 32.84369342029095, 39.94483597576618, 40.532368049025536, 51.438204646110535, 56.07564300298691, 47.754442915320396, 50.57652868330479, 28.033404238522053, 9.518701080232859, 1.512809379491955, 0.21904398134211078, 0.11158075285493396, 0.12727381428703666, 0.10735331641626544, 0.10699927486712113, 0.11209328746190295, 0.1038134130067192, 0.11455374449724331, 0.13018333003856242, 0.15173344319919124, 0.1559895116952248, 0.12122119180276059, 0.1777086267247796, 0.19975493982201442, 0.10912206213106401, 0.0958877730590757, 0.16896511777304113, 0.1614400075050071, 0.11760830559069291, 0.2309742575744167, 0.12566549121402204, 0.055387282627634704, 0.1604511254117824, 0.09932182394550182, 0.11767599688027985, 0.08139607060002163, 0.16017362155253068, 0.09016000345582142, 0.14803670172113925, 0.1930178567999974, 0.1407323803869076], [0.020562027020787355, 0.03976174179115333, 0.04457439135876484, 0.059484642843017355, 0.03068586200242862, 0.01413719706761185, 0.10465429601026699, 0.057397834898438305, 0.030173705890774727, 0.05035402595240157, 0.03565053681086283, 0.04995516610506456, 0.0677708700823132, 0.04680078614910599, 0.06888782460009679, 0.030274394921434578, 0.00729938697986654, 0.04144420541706495, 0.08686550601851195, 0.03601751770474948, 0.040755859736236744, 0.026983775205735583, 0.038793691783212125, 0.03896554720995482, 0.01754113345668884, 0.022811378294136375, 0.054554555827053264, 0.004115778001505532, 0.030563684085791465, 0.03844797713099979, 0.07792028874973767, 0.05488429575052578, 0.024598178606538568, 0.056934775566332974, 0.03280028155131731, 1.1199938203208148, 7.7784348372370005, 22.070604600012302, 40.305922999978065, 53.358644396066666, 42.099491357803345, 28.43409463763237, 25.516214109957218, 25.976323820650578, 37.76267386972904, 37.406651973724365, 15.430816188454628, 4.069664748385549, 0.5735878308769315, 0.6400994618888944, 0.5724173155613244, 0.3867675008950755, 1.2679815106093884, 4.994813455268741, 4.375325096771121, 5.001461673527956, 4.477410893887281, 3.5815526777878404, 7.996128480881453, 5.505202068015933, 10.84425425156951, 15.96427146345377, 22.415766678750515, 38.642961233854294, 49.04814429581165, 52.39399395883083, 54.27018128335476, 52.872498482465744, 50.55685333907604, 50.976594015955925, 50.67107520997524, 48.56522060930729, 47.531273290514946, 47.741219624876976, 46.2212023884058, 45.77380679547787, 46.08210325241089, 48.09019669890404, 48.838490545749664, 51.03997081518173, 50.127214193344116, 52.12009325623512, 51.830381602048874, 55.632499381899834, 50.071509182453156, 55.94815604388714, 55.017369389534, 58.89556288719177, 38.51409874856472, 34.45923373103142, 49.94065560400486, 49.66137059032917, 54.085803776979446, 49.65310223400593, 51.786349564790726, 52.13468447327614, 49.06444922089577, 49.49925608932972, 52.05920532345772, 51.67375400662422, 53.129239305853844, 53.838691636919975, 54.47463311254978, 52.29207582771778, 51.198536306619644, 49.27689962089062, 48.895688876509666, 49.802574813365936, 52.52091474831104, 54.020546078681946, 53.33428770303726, 48.993214443325996, 54.81587380170822, 51.37461505830288, 52.87325084209442, 43.26517380774021, 32.70329475402832, 22.855401188135147, 13.737115021795034, 6.980088176205754, 5.3047604486346245, 5.259634545072913, 4.433955475687981, 7.563411500304937, 5.761640332639217, 3.897646553814411, 4.164049308747053, 3.1968192849308252, 1.0601301700808108, 0.4160028352634981, 0.12677724327659234, 0.2762304525822401, 1.3872338365763426, 6.760666575282812, 10.352940615266562, 32.37074799835682, 31.011372841894627, 30.38295116275549, 42.84634508192539, 39.44159097969532, 42.580610141158104, 34.9323995411396, 18.90058670192957, 3.2217202987521887, 0.17451332474593073, 0.03082135590375401, 0.10750176079454832, 0.10326158168027177, 0.04677333781728521, 0.028754610066243913, 0.007151859153964324, 0.040441745732096024, 0.05613004628685303, 0.02479221497196704, 0.12398350256262347, 0.025509741899440996, 0.05231624956650194, 0.04426215869898442, 0.06230974671780132, 0.0060741461584257195, 0.055808982069720514, 0.028913709829794243, 0.05207642083405517, 0.08834576408844441, 0.03562456906365696, 0.0630702254420612, 0.0686967141518835, 0.030868259636918083, 0.05941964926023502, 0.05567615618929267, 0.018340606475248933, 0.05385718934121542, 0.03947254539525602, 0.08302720729261637, 0.023267275901162066, 0.031825581900193356, 0.03673968676594086, 0.0630865823768545, 0.06479231233242899, 0.014215602186595788, 0.06711775044095702, 0.02684003789909184, 0.024524915643269196, 0.0633493546047248, 0.035463036911096424, 0.039773697790224105, 0.024970768281491473, 0.03084503041463904, 0.050541336604510434, 0.03258191944041755, 0.05240171529294457, 0.023379484919132665, 0.03790145958191715, 0.05335704488970805, 0.033945025788852945, 0.016358216853404883, 0.04087262183020357, 0.037590881911455654, 0.02577143986854935, 0.03373812614881899, 0.0384871254209429, 0.08601925728726201, 0.025820870614552405, 0.036303144370322116, 0.02730579493800178, 0.03491704257612582, 0.05998391156026628, 0.054938914108788595, 0.09665388468420133, 0.015624952684447635, 0.024214393633883446, 1.3627173146232963, 10.33842634409666, 27.358626946806908, 48.82835268974304, 58.230773359537125, 46.30234703421593, 33.72350960969925, 28.46665509045124, 26.032538004219532, 26.967525333166122, 31.193544566631317, 16.652135252952576, 4.139043325558305, 0.6944617198314518, 0.25190276268403977, 0.3125434712274, 1.7999805137515068, 4.237070940434933, 7.651695013046265, 6.287413844838738, 6.386544825509191, 6.482992200180888, 5.0687717366963625, 6.055312799289823, 7.9535251669585705, 14.699026755988598, 23.04140690714121, 30.149987563490868, 42.3645955324173, 50.77766329050064, 53.45899701118469, 55.386565178632736, 54.75858807563782, 52.592305317521095, 53.75491753220558, 53.45414087176323, 52.34770484268665, 50.98799720406532, 50.84812670946121, 49.082574248313904, 48.14587131142616, 47.877385318279266, 49.579036608338356, 51.34586200118065, 53.31217288970947, 52.707967311143875, 54.68125842511654, 54.67595390975475, 56.883688643574715, 52.76593320071697, 55.62779523432255, 54.77573275566101, 60.58306373655796, 41.23390160501003, 37.0629908144474, 51.04647986590862, 50.766784474253654, 56.70641675591469, 51.21037267148495, 54.85306240618229, 54.477414563298225, 51.347856894135475, 52.51066669821739, 55.070585533976555, 54.7131235152483, 54.26103137433529, 56.15214429795742, 54.784483686089516, 54.29924592375755, 53.78235965967178, 51.93645291030407, 51.87646172940731, 52.31409564614296, 55.3324256837368, 55.41293956339359, 55.601132065057755, 50.79682566225529, 56.40777178108692, 53.97516891360283, 53.10087002813816, 43.67780886590481, 34.91826809942722, 23.654089830815792, 16.53027579188347, 7.19160620123148, 6.62109911441803, 6.566297980025411, 5.981201576068997, 8.08885395526886, 6.707234792411327, 5.7400494161993265, 4.976800521835685, 4.75758221000433, 0.9652823314536363, 0.5118187016341835, 0.3853678103769198, 0.17813530226703733, 1.990292826667428, 5.868589393794537, 13.480486292392015, 32.01457791030407, 34.49886180460453, 32.234878689050674, 45.74491694569588, 46.20978780090809, 47.57535472512245, 41.84826023876667, 22.55746677517891, 4.267759518697858, 0.3786242409842089, 0.02787450826872373, 0.05722610563680064, 0.03596498478145804, 0.03327926737256348, 0.020066931028850377, 0.023930117677082308, 0.051424540579319, 0.04568503762129694, 0.021738913674198557, 0.06041312895831652, 0.08358555467566475, 0.04607521434081718, 0.02032315565884346, 0.10169252564082853, 0.021800272588734515, 0.05987123498925939, 0.100232290715212, 0.027932683369726874, 0.07905362246674486, 0.0383578098990256, 0.04732248627988156, 0.032069384833448566, 0.0811901839915663, 0.03304209923953749, 0.048233977213385515, 0.047585046995664015, 0.0223406933946535, 0.041205204179277644, 0.10823839431395754, 0.07422247115755454, 0.035771959592239, 0.101843938609818, 0.16790417314041406, 0.1772970167803578, 0.1609379891306162, 0.13478173641487956, 0.075286072678864, 0.17763252690201625, 0.1544765694416128, 0.11657525086775422, 0.1606068279943429, 0.11483633206808008, 0.1947364630177617, 0.10003490169765428, 0.15234253864036873, 0.20119813503697515, 0.09015489005832933, 0.18354714702581987, 0.12224024219904095, 0.2652760857017711, 0.15112636639969423, 0.16969574731774628, 0.13167632336262614, 0.11609987559495494, 0.19186156103387475, 0.11265041030128486, 0.10186756859184243, 0.14463523111771792, 0.15120362397283316, 0.11063968733651564, 0.13367322011617944, 0.12280805938644335, 0.16801410005427897, 0.21934294811217114, 0.16936181054916233, 0.1724640026804991, 1.7131807026453316, 10.621662195771933, 32.2191209346056, 54.59448628127575, 64.22440454363823, 54.65405188500881, 37.693749368190765, 36.20948441326618, 35.13061210513115, 49.275121316313744, 43.16746965050697, 19.934235736727715, 5.384355252608657, 1.4312593429349363, 1.0529974778182805, 1.4942639996297657, 3.2635847898200154, 5.911028366535902, 13.1697304174304, 12.837921772152185, 10.857566837221384, 12.344864029437304, 10.069577470421791, 12.558813448995352, 10.139518417418003, 22.99163717776537, 32.3131050914526, 37.24257677793503, 49.214556366205215, 51.75063908100128, 54.94772672653198, 57.75548726320267, 56.59740820527077, 54.451663345098495, 55.52283726632595, 55.4393595457077, 53.59167069196701, 52.47496381402016, 54.2682433873415, 51.177914813160896, 50.1819084584713, 50.087149143218994, 51.81709751486778, 53.57255391776562, 56.53997428715229, 54.77596454322338, 56.80882126092911, 57.29822739958763, 59.73037049174309, 53.63450959324837, 55.391478314995766, 56.71854570508003, 60.79929493367672, 43.114185109734535, 42.434925958514214, 52.376777082681656, 53.026827201247215, 57.35227569937706, 54.224393740296364, 56.807840913534164, 55.7540662586689, 53.34833174943924, 55.06236657500267, 57.08830766379833, 56.391542851924896, 55.99493533372879, 57.59531445801258, 58.38786453008652, 56.067150458693504, 55.366335064172745, 54.788462072610855, 52.82011069357395, 53.90070430934429, 57.02424690127373, 56.704843640327454, 56.98567137122154, 50.9358374029398, 58.80039319396019, 55.658277198672295, 54.05816785991192, 44.34262499213219, 36.78418077528477, 27.196898125112057, 17.8170520439744, 9.946648366749287, 11.318391859531403, 11.909214556217194, 10.962710995227098, 16.88750982284546, 14.887166060507298, 12.145718615502119, 9.197176583111286, 8.662458825856447, 3.7308264803141356, 1.0911526554264128, 0.8184163528494537, 0.6657461263239384, 2.4608382023870945, 9.217445645481348, 16.13647822290659, 43.7360293418169, 43.27411472797394, 40.42392186820507, 56.231666430830956, 53.20405729115009, 56.06802441179752, 47.62083448469639, 25.16199331730604, 5.735568031668663, 0.5258768785279244, 0.1030241241096519, 0.16690350574208423, 0.1630147558171302, 0.11212083598366007, 0.11773057442042045, 0.10786664512124844, 0.16206609812797979, 0.1575709244934842, 0.05949603480985388, 0.13363857666263357, 0.22148658230435103, 0.17850843927590176, 0.11806560214608908, 0.23079865059116855, 0.0852696732908953, 0.1529483389458619, 0.19079687597695738, 0.12153186224168167, 0.11841470099170692, 0.16635136271361262, 0.12311890794080682, 0.14229917287593707, 0.13942384044639766, 0.1698141495580785, 0.14433383010327816, 0.11968715029070154, 0.10062812260002829, 0.11301254126010463, 0.2407410545856692, 0.12212533547426574, 0.11215245147468522], [0.05829662026371807, 0.041017518742592074, 0.007295320938283112, 0.023413358394464012, 0.04961034945154097, 0.035359229004825465, 0.01958030479727313, 0.07121692891814746, 0.031283201824408025, 0.02770487557427259, 0.06395869495463558, 0.024655162560520694, 0.008138677148963325, 0.08195405433070846, 0.07449486161931418, 0.029722385479544755, 0.07321583689190447, 0.05756981649028603, 0.025662702246336266, 0.049480380839668214, 0.021754836452601012, 0.048355711696785875, 0.01682000896835234, 0.015321733408200089, 0.007324278149098973, 0.06157385163533036, 0.012585126005433267, 0.06224339500477072, 0.036225497169652954, 0.021898043123655953, 0.08705942920641974, 0.005081575127405813, 0.03611756663303822, 0.03934406478947494, 0.09858057426754385, 0.33064184070099145, 6.462896978482604, 17.549459002912045, 36.69743902981281, 44.45635288953781, 43.577323257923126, 35.92891126871109, 34.87198658287525, 55.56330509483814, 70.2996401488781, 48.62949416041374, 23.379615359008312, 7.349150972440839, 0.8975875983014703, 0.6166760344058275, 0.2794984256615862, 1.4783947449177504, 2.7568527683615685, 9.356368090957403, 5.436772964894772, 6.975116143003106, 2.9402924375608563, 2.4749062350019813, 2.329650241881609, 5.740679707378149, 15.456382166594267, 17.428591288626194, 30.14471534639597, 40.99092744290829, 50.52159883081913, 51.73193648457527, 56.70485123991966, 52.010871917009354, 55.455938056111336, 51.51868812739849, 49.525904059410095, 50.97942866384983, 50.92538796365261, 49.05336521565914, 49.73081186413765, 48.7285890430212, 51.25308237969875, 48.24379965662956, 50.90500965714455, 51.673628613352776, 52.318894788622856, 53.514523431658745, 53.82127337157726, 53.06489355862141, 52.52969227731228, 47.009728476405144, 42.80783414840698, 35.82253597676754, 38.04776877164841, 36.92598916590214, 50.9856603294611, 51.823488771915436, 51.324453949928284, 49.82459083199501, 49.24943849444389, 47.81140185892582, 47.55384787917137, 49.255905747413635, 49.46327582001686, 51.187338307499886, 51.12665556371212, 49.76315952837467, 49.84648145735264, 49.13701772689819, 47.545765712857246, 48.065232038497925, 47.569252252578735, 49.4746258109808, 52.554470747709274, 54.391413778066635, 54.88421693444252, 51.44012354314327, 52.64601543545723, 51.00997142493725, 45.441070050001144, 43.54846000671387, 30.794128999114037, 20.448551438748837, 14.410432241857052, 6.805580165237188, 4.943689098581672, 6.466306820511818, 2.2959451004862785, 5.966149158775806, 5.88115531951189, 3.758606077171862, 3.7377907941117883, 3.6657642340287566, 0.5746962432749569, 0.9620031074155122, 0.09610415363567881, 0.41788842470850796, 1.6627285536378622, 6.56521076336503, 14.293529614806175, 23.16398072987795, 29.00783345103264, 45.638830438256264, 44.07816678285599, 42.68974408507347, 40.07654830813408, 27.71630745381117, 13.5525693744421, 1.615617019124329, 0.06313812453299761, 0.07361186915659346, 0.05343286269635428, 0.07988060504430905, 0.0480596689885715, 0.0796618867025245, 0.04729367239633575, 0.039913277214509435, 0.021807007578900084, 0.06387521818396635, 0.04087730107130483, 0.02362692994211102, 0.023227303827297874, 0.0627469236496836, 0.008145898245857097, 0.019975876930402592, 0.027989097725367174, 0.1600426621735096, 0.01772167015587911, 0.034961664205184206, 0.03625224046118092, 0.12473923154175282, 0.025344994392071385, 0.03185917892551515, 0.06965346867218614, 0.032700458978069946, 0.009405288528796518, 0.015967643084877636, 0.07700841189944185, 0.030892808026692364, 0.034701426411629654, 0.028244368695595767, 0.062362817698158324, 0.013011498194828164, 0.008303926533699268, 0.006478330915342667, 0.030895973286533263, 0.036729560160893016, 0.022509357586386614, 0.07645135585335083, 0.04259104622178711, 0.03770699091546703, 0.023517858353443444, 0.023771850974299014, 0.055447244449169375, 0.08000186455319636, 0.06454213435063139, 0.010468223044881597, 0.02539955523388926, 0.073099349392578, 0.040945875516626984, 0.04655706856283359, 0.022417366526497062, 0.05409842444350943, 0.02819152407028014, 0.03328146041894797, 0.040140485725714825, 0.06753409528755583, 0.027928779672947712, 0.0968000951979775, 0.040190599247580394, 0.013637707561429124, 0.03564991711755283, 0.01531866555524175, 0.026834616510313936, 0.009300311739934841, 0.08710217691259459, 0.5475956224836409, 6.951062483713031, 21.832311786711216, 43.17055128514767, 52.03417606651783, 49.043994918465614, 36.54591076076031, 33.58612038195133, 41.865936890244484, 65.56778445839882, 47.28959485888481, 23.044389747083187, 7.756399344652891, 0.9602296713273972, 0.35505211679264903, 0.30759465240407735, 0.8521217317320406, 2.402545055374503, 4.321594079956412, 6.295013912022114, 6.743681961670518, 1.9547209166921675, 3.3321105502545834, 3.127704318612814, 7.079035816714168, 19.22193355858326, 24.228508807718754, 33.853652626276016, 43.556758761405945, 51.29524491727352, 54.7500841319561, 57.86928355693817, 56.37652985751629, 55.82044489681721, 54.402243196964264, 53.13847281038761, 53.053357377648354, 52.824263870716095, 51.978759840130806, 51.960691809654236, 50.921215787529945, 50.500430166721344, 52.30088375508785, 53.39167982339859, 54.462526962161064, 53.37697461247444, 56.8648112565279, 54.723804742097855, 54.63103652000427, 51.561112850904465, 49.865438640117645, 44.09252241253853, 42.25434444844723, 41.436791718006134, 39.89518404006958, 51.08946695923805, 53.882450088858604, 52.7058470249176, 51.58159755170345, 51.81784227490425, 50.737096667289734, 50.9772589802742, 50.43898746371269, 51.85690797865391, 52.85147041082382, 53.4138098359108, 53.80743071436882, 52.11373619735241, 51.84811905026436, 49.886310920119286, 50.611266419291496, 49.48497645556927, 51.11640751361847, 54.20333907008171, 56.80557623505592, 55.2429860830307, 53.01589138805866, 56.00712887942791, 51.339812725782394, 47.55307652056217, 44.74523238837719, 32.541845217347145, 23.496548384428024, 15.429699048399925, 8.168622124940157, 7.301926156505942, 6.823687143623829, 5.273240189999342, 8.856351971626282, 7.533266292884946, 7.040181001648307, 4.475605515763164, 5.250003961846232, 1.4808190148323774, 0.6319494335912168, 0.13168953359127045, 0.28726464486680925, 2.2433609096333385, 8.882677908986807, 18.06804947555065, 33.5528189688921, 32.33392417430878, 45.764535292983055, 50.06300523877144, 45.860628336668015, 47.19419337809086, 33.80739390850067, 16.487047411501408, 1.8817413202486932, 0.21471164975082502, 0.09716501663206145, 0.03737029335752595, 0.004924827508148155, 0.03913400731107686, 0.09045080660143867, 0.06537784458487295, 0.01721464785077842, 0.04224773983878549, 0.046193175003281794, 0.05354385830287356, 0.03945058895624243, 0.018717756647674832, 0.03495063217997085, 0.031688470116932876, 0.02216860419139266, 0.06146054423879832, 0.049312558985548094, 0.04951418566633947, 0.022382563511200715, 0.05594381917035207, 0.028113333246437833, 0.01337885572866071, 0.0354031752794981, 0.017446645069867373, 0.027282574992568698, 0.06350502750137821, 0.02695459952519741, 0.02089920326397987, 0.03582929050025996, 0.02880952899431577, 0.01967392301594373, 0.10679953324142843, 0.19542680878657848, 0.06695365416817367, 0.09881838806904852, 0.10883552633458748, 0.10002495691878721, 0.07062238699290901, 0.18881131923990324, 0.16989954106975347, 0.1662292200489901, 0.11583032013732009, 0.1881025533657521, 0.20641662064008415, 0.2084539644420147, 0.2138474929961376, 0.14295846718596295, 0.1391768388566561, 0.16264427569694817, 0.13613709103083238, 0.19016579812159762, 0.10884656207053922, 0.1315255486406386, 0.12202695637824945, 0.05815884054754861, 0.13919321063440293, 0.13633303286042064, 0.1353900897083804, 0.18069168931106105, 0.12085578055121005, 0.15488638338865712, 0.1608109037624672, 0.059330892108846456, 0.17845920519903302, 0.12969520466867834, 0.3630476299440488, 0.6046229624189436, 8.658162206411362, 23.4022431448102, 48.143291249871254, 57.640535831451416, 56.11308999359608, 46.645103842020035, 45.14417678117752, 67.05528303980827, 79.67905685305595, 54.979937598109245, 27.688874825835228, 9.548236895352602, 1.4881975064054132, 1.1020008358173072, 1.1107534286566079, 2.729350319132209, 4.906518068164587, 16.81887410581112, 14.88430481404066, 15.049690939486027, 7.73231053724885, 6.763030998408794, 6.221294067800045, 13.471352532505989, 24.491578191518784, 33.40696379542351, 39.41949516534805, 44.86996069550514, 52.333607599139214, 54.58365686237812, 58.1877064704895, 56.2343642860651, 58.18891100585461, 57.630458772182465, 54.22525629401207, 56.21709801256657, 56.670569479465485, 53.0365888774395, 54.443140402436256, 52.74783477187157, 54.62937220931053, 52.633080929517746, 55.2247204631567, 57.85853013396263, 55.644540935754776, 57.01964154839516, 56.795081198215485, 54.67010982334614, 53.4087523072958, 50.27996599674225, 48.58075797557831, 43.80272716283798, 45.37186436355114, 43.239802569150925, 52.02756442129612, 54.84823666512966, 55.7356296479702, 53.872597217559814, 52.85427466034889, 51.119249761104584, 51.18772588670254, 51.96470059454441, 54.64233711361885, 56.05690620839596, 55.05477078258991, 55.6737157702446, 53.58520723879337, 53.36842507123947, 53.207720294594765, 53.745015263557434, 52.18017943203449, 54.44876790046692, 56.67422868311405, 57.07781262695789, 55.42069114744663, 55.32990641891956, 56.794078052043915, 55.859434604644775, 48.00033152103424, 46.45844645798206, 34.49921138584614, 24.08260803669691, 19.056403040885925, 10.685363877564669, 8.865546528249979, 12.840972058475018, 7.649145824834704, 13.588299807161093, 13.50922130048275, 10.943037550896406, 11.320762932300568, 11.254265550523996, 2.830289527773857, 1.956027215346694, 0.5374821682926267, 0.674972862470895, 2.8718433855101466, 10.561248287558556, 23.074924908578396, 33.6557212471962, 40.48360526561737, 55.901794731616974, 56.06002204120159, 57.2450340539217, 54.2415764182806, 37.6803170889616, 18.453120812773705, 2.5680254632607102, 0.22790427465224639, 0.18202987062977627, 0.16815475188195705, 0.13966103084385395, 0.19863530615111813, 0.2977874083444476, 0.21573985082795843, 0.09084568853722885, 0.16608525824267417, 0.14420083723962307, 0.21182619442697614, 0.1517681757104583, 0.1385470968671143, 0.2643621159950271, 0.13985271274577826, 0.11156012114952318, 0.15004170272732154, 0.2775984682375565, 0.14115648809820414, 0.14550467196386307, 0.09370231884531677, 0.19040615006815642, 0.11653556823148392, 0.1074566159513779, 0.11742754810256884, 0.12752979586366564, 0.12068821102729999, 0.11535743848071434, 0.14337108645122498, 0.1489903317997232, 0.09783243003766984, 0.128837623342406], [0.06016265040670987, 0.03667709774163086, 0.07479544627130963, 0.04579045969876461, 0.024488693270541262, 0.02135229926352622, 0.028965487617824692, 0.08517890120856464, 0.01758049511408899, 0.004373955871415092, 0.06016328123223502, 0.034633456816663966, 0.04984410370525438, 0.05708593991585076, 0.06331202457658947, 0.026164627852267586, 0.05984220217214897, 0.06392352457623929, 0.06366239249473438, 0.044309693257673644, 0.02224528474471299, 0.08676498953718692, 0.029474818002199754, 0.04214506370772142, 0.0539556574949529, 0.07722287773503922, 0.03860853707010392, 0.01924019707075786, 0.04375792130304035, 0.04489101753279101, 0.015019477996247588, 0.06292925449088216, 0.0812397149275057, 0.032564916837145574, 0.04623009685019497, 0.18769640562823042, 3.412556271068752, 16.089026369154453, 35.206034258008, 45.03091245889664, 44.397710636258125, 45.88830225169659, 56.61982320249081, 76.09565153717995, 74.2136961221695, 52.34720706939697, 23.157923854887486, 6.259683882817626, 1.2573987222276628, 0.40371892566327006, 0.24930005078203976, 0.8417503070086241, 3.600592981092632, 2.766148019582033, 3.287430410273373, 5.2117119915783405, 2.2387234959751368, 4.343358362093568, 4.978595450520515, 6.520012188702822, 13.31219332292676, 16.504725962877274, 26.957208886742592, 44.35634605586529, 47.98532612621784, 52.73613899946213, 56.25655509531498, 57.06549748778343, 52.76691734790802, 53.29310551285744, 53.57432082295418, 53.82615230977535, 52.12040863931179, 51.72908663749695, 52.11195029318333, 50.51401823759079, 48.207975178956985, 49.82019826769829, 50.65479688346386, 54.82243984937668, 51.56280755996704, 51.54600106179714, 52.503808066248894, 50.947772562503815, 50.62274940311909, 49.110267162323, 30.972071550786495, 43.13738666474819, 37.537338361144066, 33.08738574385643, 47.34707437455654, 53.7632504850626, 52.22132362425327, 51.007626950740814, 47.00832635164261, 45.15464521944523, 43.269266188144684, 43.55453588068485, 47.423970848321915, 49.78769101202488, 48.334485590457916, 46.6958387196064, 47.36388847231865, 48.25077228248119, 46.67770989239216, 46.61974400281906, 47.037649378180504, 48.45405377447605, 52.47288912534714, 55.894848704338074, 52.24117375910282, 56.00717827677727, 50.22376701235771, 50.62050752341747, 43.25827717781067, 39.40061777830124, 29.319553524255753, 18.602692186832428, 12.022510226815939, 5.251257894560695, 7.687443494796753, 3.2872028974816203, 6.1873500142246485, 6.446946859359741, 3.792582666501403, 4.524113237857819, 2.219444992952049, 3.1261867750436068, 0.7984003925230354, 0.35669555829372257, 0.025291572746937163, 0.5115832923911512, 3.275676453486085, 6.010860884562135, 14.704978186637163, 19.75043009966612, 27.133983001112938, 43.54058302938938, 42.166496962308884, 44.36522617936134, 41.229007467627525, 23.334709368646145, 9.084834661334753, 0.6951807125005871, 0.0644476292654872, 0.03936194312700536, 0.07624946199939586, 0.02861850389308529, 0.026222797387163155, 0.026155100531468634, 0.019282460525573697, 0.04592594617861323, 0.07180168191553093, 0.11048386601032689, 0.026336852497479413, 0.0014536331741510367, 0.03065068605792476, 0.03171817457769066, 0.044981759929214604, 0.0410840856784489, 0.0451853087724885, 0.11284405147307552, 0.08249334336142056, 0.03715217986609787, 0.053775697815581225, 0.08551054474082775, 0.12075084829120897, 0.01809976285585435, 0.03919436989235692, 0.061277018539840356, 0.02738610088272253, 0.05360522278351709, 0.033978949359152466, 0.038530659803655, 0.028745876843458973, 0.05074108936241828, 0.04448490319191478, 0.06030425960489083, 0.020328013015387114, 0.02623392218083609, 0.011473264476080658, 0.03898108407156542, 0.009425461958016967, 0.05402993534517009, 0.06463665427872911, 0.03314497575047426, 0.06916366604855284, 0.009746708929014858, 0.025881682195176836, 0.01657845474255737, 0.03488903763354756, 0.03612821274145972, 0.06668426940450445, 0.033796885691117495, 0.011711874230968533, 0.07890154898632318, 0.011999891539744567, 0.04798363595909905, 0.043023722028010525, 0.016775893855083268, 0.07257204604684375, 0.042781733645824715, 0.07121626098523848, 0.010604130693536717, 0.03364403666637372, 0.12674890807829797, 0.04793446496478282, 0.04373907817353029, 0.06836023181676865, 0.046942922272137366, 0.04578252985083964, 0.2396452586981468, 4.818181358277798, 19.21038217842579, 40.86912117898464, 52.29630120098591, 48.98573264479637, 49.52165588736534, 54.135144129395485, 75.50206258893013, 78.7575227022171, 63.26625935733318, 32.40095637738705, 9.149706680327654, 1.5636505326256156, 0.3635747922817245, 0.2886888856301084, 0.6046207656618208, 1.6994482395239174, 2.802175311371684, 4.388277176767588, 5.238372310996056, 2.993934634141624, 3.734831465408206, 4.367696531116962, 7.815052522346377, 15.847861859947443, 20.36258865147829, 30.05983740091324, 46.11010394990444, 48.72550740838051, 53.86655554175377, 58.34602117538452, 58.00408132374287, 56.13796725869179, 54.94034752249718, 55.739596635103226, 56.33347436785698, 53.54947775602341, 54.032800421118736, 54.06539887189865, 52.41928160190582, 52.03251175582409, 52.35515244305134, 52.587931752204895, 57.410385981202126, 53.383134081959724, 51.75604239106178, 53.01214098930359, 51.38096071779728, 52.00957998633385, 50.304402485489845, 33.74585621058941, 42.949334755539894, 40.45615553855896, 38.194710686802864, 49.27295543253422, 55.10477989912033, 53.49833630025387, 51.71288810670376, 49.69453141093254, 46.45957499742508, 45.094555243849754, 46.41012825071812, 51.218861415982246, 53.433823361992836, 49.87454675137997, 49.740189760923386, 49.42837469279766, 49.79708410799503, 49.00166518986225, 48.04504752159119, 49.644533693790436, 50.53842432796955, 54.32910092175007, 57.69714139401913, 55.12066304683685, 57.37831950187683, 52.74685062468052, 54.61112558841705, 45.18981993198395, 42.87686124444008, 30.14184270054102, 20.413762405514717, 15.299481935799122, 7.099425997585058, 3.650280302390456, 6.375834625214338, 6.9589038379490376, 6.9650728069245815, 5.246889078989625, 6.957244277000427, 3.7088786205276847, 3.408106709830463, 0.9690414578653872, 0.3661984030622989, 0.07714468505582772, 0.6958206812851131, 3.266501370817423, 8.005699217319489, 19.111961759626865, 21.65643062442541, 30.448693335056305, 49.58247922360897, 48.07053655385971, 48.7853579968214, 45.791179463267326, 27.488986551761627, 10.756841842085123, 0.8444571867585182, 0.021240875066723675, 0.05036180366005283, 0.05171019322006032, 0.029944762609375175, 0.03168599876516964, 0.008032523128349567, 0.033990103838732466, 0.06369979673763737, 0.07085792982252315, 0.07248882902786136, 0.05420742367277853, 0.013410739320534049, 0.05422032219939865, 0.05410793877672404, 0.017053310511983, 0.06615735939703882, 0.0842856448434759, 0.04283037029381376, 0.0327096319233533, 0.011048024061892647, 0.032695074696675874, 0.11195289538591169, 0.035088571457890794, 0.020741931039083283, 0.016072404650913086, 0.08753388421609998, 0.06159185242722742, 0.03208319620171096, 0.01834317245084094, 0.048096980463014916, 0.07308581261895597, 0.04850865348998923, 0.21771567058749497, 0.15377247909782454, 0.19791647675447166, 0.11559065838810056, 0.11737149368855171, 0.14086178125580773, 0.11104185716249049, 0.1702911575557664, 0.13031948445132002, 0.15742524090455845, 0.1458163294591941, 0.15131133928662166, 0.108890964766033, 0.10318279528291896, 0.17304011707892641, 0.1884896872797981, 0.16335108230123296, 0.20430427539395168, 0.19020277191884816, 0.24160138185834512, 0.08827278128592297, 0.15867200447246432, 0.1208923981175758, 0.12337106003542431, 0.20200818922603503, 0.17137990304036066, 0.184454660047777, 0.2075355121633038, 0.1899337730719708, 0.24852337839547545, 0.08438896664301865, 0.15686935745179653, 0.1520826088381, 0.18132962461095303, 0.14357814565300941, 0.3454733651597053, 4.851602464914322, 20.904202088713646, 47.57258467376232, 60.97426414489746, 58.62092882394791, 58.75041827559471, 65.0611424446106, 82.18072101473808, 79.72056582570076, 60.23995354771614, 29.5118498057127, 9.445407763123512, 2.4862835370004177, 0.7330609392374754, 0.5886501038912684, 2.30589154176414, 8.119490761309862, 8.822982162237167, 7.929012207314372, 9.345790408551693, 6.939850710332394, 10.565182026475668, 8.016121108084917, 12.152619995176792, 17.513015158474445, 21.737907752394676, 30.23617073893547, 45.52287966012955, 48.70189927518368, 55.374113246798515, 58.283339738845825, 60.07937416434288, 56.909629851579666, 56.86437048017979, 58.31591539084911, 58.95551607012749, 57.2873105853796, 56.43645644187927, 55.63735172152519, 53.83290454745293, 52.103476747870445, 53.93272519111633, 53.76209154725075, 57.579222321510315, 52.805758863687515, 52.57799908518791, 52.41760589182377, 52.26158246397972, 52.06454783678055, 53.701617792248726, 35.116013288497925, 46.84407256543636, 44.21504303812981, 43.09799037873745, 50.38473017513752, 54.76514272391796, 54.790631756186485, 54.40428748726845, 51.15873724222183, 48.93391862511635, 47.07663528621197, 47.50475451350212, 52.00338251888752, 54.68904800713062, 51.496010944247246, 50.10880798101425, 51.89755819737911, 52.60994017124176, 50.24981461465359, 50.090242177248, 52.06429325044155, 52.580848932266235, 55.17905831336975, 58.92908848822117, 55.39213187992573, 57.548531368374825, 54.32605728507042, 55.480017364025116, 47.924658581614494, 43.299295976758, 34.83252190053463, 23.379995338618755, 17.40841057151556, 9.099058248102665, 12.474240437150002, 10.988315921276808, 11.093480978161097, 14.584190268069506, 12.996390368789434, 11.823221370577812, 9.971025958657265, 8.670537192374468, 2.8868124447762966, 0.8182057610247284, 0.2428490508464165, 0.9612389327958226, 4.578122589737177, 9.524061642587185, 23.43486439436674, 29.720361717045307, 37.857311591506004, 56.18330642580986, 53.75191189348698, 56.20526164770126, 54.09695237874985, 32.52657003700733, 12.079160436987877, 1.08890246367082, 0.2545845875283703, 0.1000552588084247, 0.26142992021050304, 0.1552983050351031, 0.118322570779128, 0.09898572010570206, 0.12459938123356551, 0.20733458310132846, 0.2010570972925052, 0.164111175108701, 0.14526877290336415, 0.11957073700614274, 0.115399874484865, 0.14113609388004988, 0.20141745451837778, 0.12771727720974013, 0.12459522520657629, 0.2420079303556122, 0.13120657356921583, 0.16171049064723775, 0.17458476388128474, 0.2684641443192959, 0.1412462879670784, 0.2080857552937232, 0.11787475144956261, 0.23394939402351156, 0.20107054500840604, 0.15537801169557497, 0.15756666456582025, 0.21511606086278334, 0.16705831774743274, 0.16802100202767178], [0.06703036997350864, 0.014082930301810848, 0.02819666529831011, 0.03136467108561192, 0.09347184488433413, 0.03007984832947841, 0.037124920781934634, 0.05199826155148912, 0.03658474117401056, 0.032321228936780244, 0.024326879101863597, 0.03255506853747647, 0.03105095041973982, 0.04526485216047149, 0.07665952827665024, 0.10078337989398278, 0.059396750293672085, 0.08464807266136631, 0.057121199351968244, 0.02249707504233811, 0.0146470172694535, 0.06182959572470281, 0.04200710216537118, 0.07098197980667464, 0.037971659330651164, 0.004527454275375931, 0.008173537680704612, 0.13421734794974327, 0.03464248504315037, 0.007488221353924018, 0.07264641666552052, 0.09072205415577628, 0.09836941098910756, 0.019885819165210705, 0.03973057901021093, 0.0723408893099986, 1.2327841180376709, 8.61403327435255, 33.06929111480713, 40.33713452517986, 41.865963488817215, 47.17183917760849, 59.979519322514534, 63.73949356377125, 50.022389218211174, 18.05859748274088, 10.343148540705442, 9.550462625920773, 3.159443303011358, 0.5718819005414844, 0.35095454135444015, 0.24046536156674847, 1.1803332762792706, 1.4786787796765566, 2.9172300500795245, 3.872702792286873, 0.5684282421134412, 1.0907670948654413, 0.055174672161228955, 4.068936137482524, 8.191916774958372, 13.536184653639793, 19.384694024920464, 35.47955498099327, 48.065361231565475, 53.79496358335018, 55.12784466147423, 55.42853392660618, 58.1896747648716, 56.13486282527447, 55.1761856675148, 55.06269335746765, 55.10755755007267, 54.702195301651955, 52.93833754956722, 54.180559292435646, 52.68438197672367, 53.63576352596283, 53.13001446425915, 51.3350173830986, 51.66496127843857, 53.62067453563213, 51.574936509132385, 50.41773900389671, 50.55979058146477, 53.61480765044689, 49.298197478055954, 57.67726466059685, 44.272229969501495, 30.78266691416502, 44.35683622956276, 52.12965354323387, 53.129839673638344, 50.222767665982246, 48.396217077970505, 46.80244579911232, 43.7723021954298, 39.884058237075806, 42.568914368748665, 46.446306109428406, 45.08205771446228, 46.83428429067135, 48.35031934082508, 51.99879616498947, 49.98547799885273, 50.658095106482506, 48.21190036833286, 50.243313163518906, 53.107990846037865, 52.592176124453545, 54.12437170743942, 53.62616904079914, 52.59778842329979, 46.726894453167915, 40.123475790023804, 37.982811257243156, 23.69982797652483, 17.19113253057003, 10.721105709671974, 6.222967877984047, 2.311587673611939, 4.417433487251401, 5.471559623256326, 5.7297647930681705, 4.231512788683176, 8.289085160940886, 3.588473768904805, 2.221638187766075, 1.274966485798359, 0.4407090204767883, 0.4624518990749493, 0.4878853296395391, 4.658070299774408, 10.222589559853077, 19.865343533456326, 28.71222261339426, 28.81032954901457, 43.09396639466286, 40.00969469547272, 41.73313781619072, 31.044489964842796, 16.210874430835247, 4.573473064228892, 0.1899370236787945, 0.0636677879083436, 0.06933329874300398, 0.036407045045052655, 0.01226034177307156, 0.02049079012067523, 0.04475813599128742, 0.02162677516025724, 0.0461712853575591, 0.04358289319497999, 0.036076533287996426, 0.024455786442558747, 0.03478769365756307, 0.015077079788170522, 0.0322725477599306, 0.03540234778483864, 0.004402548966027098, 0.041470124924671836, 0.0918245961656794, 0.04511612205533311, 0.12552017869893461, 0.023889501790108625, 0.06843299197498709, 0.028517753635242116, 0.03305483820440713, 0.011269239730609115, 0.02149853389710188, 0.05741261848015711, 0.07338838622672483, 0.016722572399885394, 0.06351197400363162, 0.05239253121544607, 0.06667326335445978, 0.0815223841345869, 0.02324134711670922, 0.07183102643466555, 0.044282337694312446, 0.047851982672000304, 0.023027847928460687, 0.0574079726357013, 0.05894728339626454, 0.011046771687688306, 0.08575835527153686, 0.06425996238249354, 0.020368660443637054, 0.022315261849144008, 0.04180457748589106, 0.01333793834419339, 0.04205542340059765, 0.020613968081306666, 0.061723171747871675, 0.03143329005979467, 0.05676872002368327, 0.043983452560496517, 0.039474122459068894, 0.01036894316712278, 0.0037558296526185586, 0.030355125745700207, 0.1113291054207366, 0.08867376367561519, 0.05438463369500823, 0.03135266313620377, 0.015735003908048384, 0.028543918051582295, 0.11637367613730021, 0.009973693868232658, 0.039562178280903026, 0.03128089374513365, 0.03665901531348936, 1.6556929936632514, 12.26130461320281, 38.118281587958336, 45.86609624326229, 49.26583081483841, 49.93736878037453, 64.25684720277786, 68.42599108815193, 63.91517713665962, 32.35930301249027, 15.10603716596961, 8.795199003070593, 3.0444400990381837, 0.3972135856747627, 0.16163446503924206, 0.07623282304848544, 1.1162651516497135, 1.3749026670120656, 3.0911897029727697, 4.764585234224796, 1.9352899468503892, 3.508092169649899, 1.084194635041058, 5.234055267646909, 9.854302871972322, 16.047916375100613, 20.89502178132534, 39.95022028684616, 48.46216633915901, 54.097765535116196, 56.63675509393215, 56.65272183716297, 57.38199770450592, 56.42389811575413, 57.022597789764404, 57.77775026857853, 55.789263769984245, 56.64938181638718, 56.192152351140976, 55.92362456023693, 54.85303960740566, 55.67278482019901, 53.77678915858269, 52.468428164720535, 52.49453276395798, 54.229721054434776, 53.91316004097462, 52.1923653781414, 50.91053456068039, 52.80324339866638, 52.19006270170212, 57.618933990597725, 44.95321802794933, 33.44059959053993, 45.65882496535778, 54.368911385536194, 54.4917967915535, 51.47525265812874, 50.06207048892975, 48.36892694234848, 44.465069621801376, 41.77097238600254, 46.391870230436325, 47.85530850291252, 48.550777584314346, 50.00093176960945, 52.17353738844395, 52.61962965130806, 52.85398207604885, 51.54411256313324, 51.14450700581074, 52.609704583883286, 55.409109368920326, 53.656058236956596, 55.77762119472027, 54.21537682414055, 55.87827019393444, 50.00835657119751, 43.662233501672745, 37.569135054945946, 28.32462441176176, 17.569447830319405, 16.05300050228834, 6.208246992900968, 4.388645282015204, 6.300717405974865, 9.605236686766148, 9.898100271821022, 7.087322697043419, 6.931511582806706, 3.5451487312093377, 2.461778651922941, 0.592205822467804, 0.09903596350341104, 0.2997145877452567, 0.9122019703499973, 5.012300116941333, 12.154484745115042, 20.922030732035637, 29.625610001385212, 34.24443505704403, 48.85823428630829, 45.01996524631977, 48.498515188694, 37.99838662147522, 18.616187162697315, 5.730676744133234, 0.4163335362682119, 0.06444336933782324, 0.022326720609271433, 0.007801163228577934, 0.04673699113482144, 0.02824734470777912, 0.005681704496964812, 0.01938005294505274, 0.009922372501023347, 0.05033669680415187, 0.004940150074617122, 0.0041720685112522915, 0.0503236980875954, 0.02812105158227496, 0.12919386907014996, 0.03222674240532797, 0.014214383209036896, 0.05580102253588848, 0.05168962088646367, 0.053379624732770026, 0.06403652398148552, 0.031287172314478084, 0.05936411806032993, 0.02511924791178899, 0.058097717264899984, 0.07203257147921249, 0.05171439377591014, 0.0496557577571366, 0.020196430232317653, 0.018269308347953483, 0.040162534933188, 0.01955456711584702, 0.015847834474698175, 0.19470872153760865, 0.11302491286187433, 0.09878656477667391, 0.1074827543925494, 0.17052101553417742, 0.1438820402836427, 0.1385927537921816, 0.16823903017211705, 0.0998305513348896, 0.19215598586015403, 0.1196500874357298, 0.1627359606209211, 0.08596621599281207, 0.13884227868402377, 0.2289508216199465, 0.13403283519437537, 0.09694816108094528, 0.24424550560070202, 0.15231325349304825, 0.12716847384581342, 0.1823981391498819, 0.12131346302339807, 0.08569424855522811, 0.11164872616063803, 0.1468113120063208, 0.18936441221740097, 0.1721418066881597, 0.3312094649299979, 0.16310676728608087, 0.07302695288672112, 0.1101750806265045, 0.18680999928619713, 0.20012114517157897, 0.11557139223441482, 0.08922562468796968, 0.25417979049962014, 1.834997059777379, 13.899421412497759, 41.56741350889206, 53.39682474732399, 55.98560683429241, 57.22660884261131, 71.02971017360687, 71.23256608843803, 59.49989005923271, 27.077905610203743, 16.983445174992085, 13.593437131494284, 4.673319831490517, 1.1358713870868087, 0.6891170097514987, 0.9100218373350799, 3.1265964405611157, 3.555122958496213, 10.794283133000135, 14.12166103720665, 5.225711390376091, 2.809440759010613, 1.3655385444872081, 6.563518904149532, 10.839343965053558, 17.322698570787907, 22.667609564960003, 40.32946273684502, 49.57148261368275, 53.35683949291706, 57.51118317246437, 58.73262383043766, 61.58571593463421, 59.56034101545811, 58.18734548985958, 59.995117485523224, 58.2780846208334, 58.41018073260784, 56.973120644688606, 59.18403200805187, 57.69117571413517, 56.89800627529621, 53.273756951093674, 51.32745958864689, 52.81707085669041, 55.668019875884056, 54.913171380758286, 52.85160720348358, 51.436164155602455, 52.77625344693661, 51.04610748589039, 56.87979385256767, 47.802540734410286, 38.99387240409851, 47.835511565208435, 53.50904792547226, 55.01766197383404, 54.72771853208542, 52.8231505304575, 49.544272273778915, 47.01763965189457, 43.542163744568825, 47.108070999383926, 50.38047060370445, 48.46172176301479, 52.034567445516586, 54.22120951116085, 56.38066403567791, 55.16031391918659, 54.40951980650425, 51.82923786342144, 54.495619386434555, 56.80009312927723, 55.429252088069916, 55.20960867404938, 55.06889842450619, 58.04738000035286, 52.46366322040558, 45.41178122162819, 39.32315893471241, 27.97928374260664, 21.18710070848465, 16.421924605965614, 9.610081426799297, 7.515882225707173, 12.357841283082962, 15.694772824645042, 13.952657505869865, 12.535325959324837, 14.115823600441217, 6.898883683606982, 5.065929489210248, 3.1225071474909782, 1.1664376594126225, 0.9294252586551011, 1.131197875365615, 6.076178904622793, 15.233198292553425, 28.823625035583973, 40.3640066832304, 40.55488184094429, 55.72854682803154, 51.1696008592844, 53.889825493097305, 43.11451569199562, 21.744884178042412, 6.227788869291544, 0.5541352496948093, 0.26420077309012413, 0.17146913887700066, 0.1310628344072029, 0.06711468537105247, 0.1402057969244197, 0.18026312871370465, 0.15314450341975316, 0.07729355245828629, 0.12330477882642299, 0.10533376931562088, 0.10407663794467226, 0.10869436242501251, 0.19504299969412386, 0.30114607186987996, 0.16502302227308974, 0.07958249174407683, 0.1802065028459765, 0.21112332120537758, 0.1288441542419605, 0.17617690813494846, 0.1752765048877336, 0.15639378922060132, 0.20290510437916964, 0.1185879108379595, 0.17571766715263948, 0.13827251706970856, 0.12779817130649462, 0.09443599861697294, 0.11648599276668392, 0.2195251453667879, 0.1717282968456857, 0.09180612411000766], [0.019035727964364924, 0.02115590286848601, 0.040874336191336624, 0.022063777687435504, 0.04435032213223167, 0.046658460778417066, 0.04829185359994881, 0.03386038755706977, 0.06219742637767922, 0.022239805839490145, 0.04687568740337156, 0.0626435870071873, 0.017316791490884498, 0.007318228717849706, 0.07900254044216126, 0.0330684788787039, 0.06813540559960529, 0.02847852185368538, 0.09897894429741427, 0.039747956398059614, 0.014511781264445744, 0.05287096784741152, 0.039779193393769674, 0.07500751496991143, 0.01975543680600822, 0.005373859785322566, 0.06518150941701606, 0.04914639954222366, 0.11610536006628536, 0.09184591806842946, 0.04706791849457659, 0.06591786834178492, 0.06239940557861701, 0.051100585696985945, 0.07044910293188877, 0.05679586778569501, 1.2234009965322912, 5.108813513070345, 25.380703881382942, 44.23477157950401, 41.56364791095257, 39.12435740232468, 39.28376644849777, 54.20422062277794, 35.974843204021454, 29.198775105178356, 27.85661492496729, 14.678089879453182, 3.5973560297861695, 0.9114475327078253, 0.18715785874519497, 0.19223742914618924, 1.6510193631984293, 2.310403324663639, 2.707326700910926, 0.5889048089738935, 6.580310678109527, 7.631425000727177, 1.784424742218107, 3.447900074534118, 5.109451403841376, 9.45534897968173, 17.65360951423645, 29.375729709863663, 34.74269092082977, 49.289932921528816, 52.973162680864334, 55.67542187869549, 55.62431462109089, 57.53846190869808, 55.94238415360451, 58.36908973753452, 56.68872870504856, 56.69773802161217, 54.608469530940056, 54.723865538835526, 54.918950870633125, 52.923153564333916, 51.299637481570244, 51.65560618042946, 54.81327474117279, 53.80339153110981, 50.479782074689865, 52.54936382174492, 52.09124140441418, 51.91960461437702, 47.97988101840019, 52.98072807490826, 44.82296101748943, 29.59611788392067, 44.144887402653694, 51.36489138007164, 54.758078902959824, 51.58905275166035, 51.76153689622879, 50.952883288264275, 47.06545248627663, 44.04839538037777, 40.47441355884075, 43.96313555538654, 48.30315627157688, 50.199459716677666, 52.58753277361393, 53.9324402064085, 54.188113287091255, 50.16224831342697, 51.2260240316391, 51.94301515817642, 51.6714209318161, 54.22196187078953, 56.85439221560955, 53.46847750246525, 50.26881359517574, 46.93997181952, 36.759782284498215, 31.650988720357418, 22.968283630907536, 10.306982081383467, 11.908650286495686, 3.03270704112947, 2.7035827143117785, 4.566828170791268, 6.1578084994107485, 6.20700778439641, 4.427078794687986, 4.4091276079416275, 3.033229513093829, 2.0600383216515183, 0.0987513127620332, 0.19034545723116025, 0.20699372951639816, 1.8357180710881948, 6.127818133682013, 11.44185483455658, 28.76292709261179, 25.988642759621143, 33.119862601161, 38.66281136870384, 35.97820222377777, 40.80532260239124, 30.030903853476048, 12.264966666698456, 1.977443341165781, 0.02226959193649236, 0.0526238252496114, 0.03920345006918069, 0.051088410764350556, 0.03046137160708895, 0.041537946090102196, 0.03880227101035416, 0.02405604529485572, 0.016162822357728146, 0.03821761449216865, 0.027055205064243637, 0.015342142469307873, 0.06343864981317893, 0.00910920500245993, 0.11306112224701792, 0.032441805669805035, 0.03752575103135314, 0.003280421447016124, 0.061040009968564846, 0.03542916529113427, 0.03573831061657984, 0.12037241234793328, 0.04302873894630466, 0.05596403527306393, 0.014251544398575788, 0.02027449674642412, 0.04639134698663838, 0.04514181520789862, 0.03352192368765827, 0.00884000113728689, 0.023636620535398833, 0.011745633601094596, 0.02767113383015385, 0.027024496848753188, 0.05788806425698567, 0.0523664966749493, 0.06663177729933523, 0.07133533115847968, 0.039804589687264524, 0.055427369734388776, 0.020325651130406186, 0.05062056086899247, 0.036637845551013015, 0.025295250088674948, 0.12003211537376046, 0.02416326336970087, 0.018328858277527615, 0.08700877020601183, 0.007998956716619432, 0.07210304582258686, 0.03759843697480392, 0.013237103667051997, 0.08564204588765278, 0.04037395054183435, 0.06532704457640648, 0.02730371506913798, 0.03745269030332565, 0.014245516304072225, 0.00897696912943502, 0.0834944708913099, 0.06863274844363332, 0.014595232059946284, 0.0571637244138401, 0.04840958790737204, 0.07438060798449442, 0.003283839268988231, 0.08952607575338334, 0.03223848318157252, 0.043144046430825256, 1.5959091391414404, 6.390240602195263, 30.881404615938663, 49.47902977466583, 46.37318283319473, 45.39290763437748, 49.65439796447754, 64.2213799059391, 39.256233125925064, 20.494289584457874, 23.296472020447254, 16.437813453376293, 4.314001137390733, 1.1431126110255718, 0.2411846214090474, 0.027185967774130404, 0.8777843078132719, 2.2395815374329686, 5.526937376707792, 4.2126482259482145, 7.574731092900038, 8.525527473539114, 2.5191510608419776, 3.9629771606996655, 5.956690041348338, 11.50587759912014, 19.312070421874523, 30.059491619467735, 38.02504979074001, 51.064027324318886, 51.746903881430626, 56.273521184921265, 56.31100997328758, 59.85622353851795, 56.75479955971241, 58.91211859881878, 58.67701381444931, 58.03373113274574, 55.075627863407135, 57.00645625591278, 55.838262140750885, 55.049147084355354, 53.29260393977165, 52.81805880367756, 54.88331638276577, 56.440339833498, 52.55046956241131, 54.374082908034325, 55.56289091706276, 52.87302665412426, 48.84882979094982, 52.621236965060234, 47.14433245360851, 34.11573976278305, 44.61878277361393, 51.92073315382004, 55.78599974513054, 53.87829311192036, 53.44419300556183, 52.256688326597214, 49.41732108592987, 45.207713171839714, 41.53164602816105, 46.85896396636963, 49.31146256625652, 51.33431062102318, 53.85827958583832, 54.61110658943653, 55.427184998989105, 52.83857770264149, 53.55475567281246, 53.290221467614174, 54.267510026693344, 56.1998925358057, 57.404819279909134, 57.07232192158699, 51.817089915275574, 48.32836791872978, 39.916094318032265, 33.98394003510475, 23.315421603620052, 14.58429666236043, 10.232262890785933, 6.355555113404989, 3.7726145004853606, 3.5887295426800847, 9.204182457178831, 7.805537832900882, 3.3558345772325993, 5.615349132567644, 3.898501032963395, 0.979682489996776, 0.802656461019069, 0.15988281840691343, 0.24615693662781268, 2.03980321995914, 6.595705077052116, 13.273966424167156, 30.393125116825104, 28.30546773970127, 35.012100264430046, 45.587981566786766, 41.35344319045544, 45.23730978369713, 35.0376120954752, 14.228540752083063, 2.7598584070801735, 0.08491583212162368, 0.03829282373772003, 0.06972706003580242, 0.006019826978445053, 0.047454258310608566, 0.02500741924450267, 0.03733838471816853, 0.05044001118221786, 0.023609708405274432, 0.016627291770419106, 0.01984289334359346, 0.017558637009642553, 0.04274450009688735, 0.024273012168123387, 0.011184550476173172, 0.05648466671118513, 0.04846631025429815, 0.034197010900243185, 0.056128101859940216, 0.0451474184228573, 0.01521161817436223, 0.026270103735441808, 0.026614415728545282, 0.06250867940252647, 0.017479422022006474, 0.016794167386251502, 0.03752510907361284, 0.028408090183802415, 0.03452177843428217, 0.017272444456466474, 0.03626617057307158, 0.04818668756342959, 0.05449256052088458, 0.1369252073345706, 0.12542157695861533, 0.1732253868249245, 0.1757307883235626, 0.22118491411674768, 0.16524964448763058, 0.13576396886492148, 0.10297949876985513, 0.15273972123395652, 0.1393207858200185, 0.10502693578018807, 0.198749270348344, 0.0785137471393682, 0.12655681057367474, 0.1613309414824471, 0.10121959945536219, 0.18002574535785243, 0.1135987562884111, 0.2206423893221654, 0.1670682179974392, 0.12843626987887546, 0.23297657200600952, 0.08665209403261542, 0.21295047394232824, 0.08449429966276512, 0.19691923807840794, 0.2687827334739268, 0.15209443867206573, 0.13122857082635164, 0.28248165152035654, 0.07293614369700663, 0.14279228547820821, 0.13671883090864867, 0.19630879192845896, 0.19124667684081942, 0.17453989363275468, 1.754611898213625, 9.173043128103018, 33.2657215744257, 55.04948526620865, 54.973633736371994, 51.20095297694206, 51.234828159213066, 64.55026745796204, 47.24667236208916, 39.46394518017769, 37.45061941444874, 19.81722291558981, 5.7786862179636955, 1.863698938395828, 0.5226350587327033, 0.4294413485331461, 3.210743162781, 5.908468728885055, 8.111932016909122, 6.822757143527269, 13.419536612927914, 13.447616156190634, 4.1548604518175125, 5.225591221824288, 6.896986160427332, 11.553785428404808, 20.62844518572092, 32.41178199648857, 39.03934836387634, 51.45749241113663, 51.34283356368542, 57.70239271223545, 58.62181797623634, 60.385436341166496, 59.50275890529156, 59.87293504178524, 60.881594717502594, 60.053265765309334, 55.31461223959923, 57.79816657304764, 55.88370770215988, 55.170941948890686, 52.89122387766838, 53.367459923028946, 56.68054774403572, 56.0493978112936, 53.62431474030018, 55.43382324278355, 56.147310957312584, 54.008531123399734, 49.6681722253561, 52.565816938877106, 47.65884004533291, 37.7869887650013, 45.564080849289894, 50.580890849232674, 55.674715116620064, 55.983277559280396, 55.873737037181854, 55.799158439040184, 51.885676234960556, 47.67942354083061, 43.44554252922535, 48.74223791062832, 51.269273310899734, 54.383635595440865, 56.150715574622154, 57.455652952194214, 56.480868458747864, 51.95146210491657, 54.211155250668526, 55.97848601639271, 55.760328322649, 58.41485068202019, 57.595557644963264, 56.28963612020016, 53.48448224365711, 52.18907855451107, 40.66123053431511, 36.0648375749588, 26.144694685935974, 14.689843598753214, 15.525735095143318, 6.987716741859913, 5.118925720453262, 10.107471887022257, 12.259943336248398, 14.638902582228184, 10.01265462487936, 12.34339065849781, 8.13923355191946, 4.055898562073708, 1.6189087112434208, 0.63137038028799, 0.5983301438391209, 2.811917276121676, 9.040066413581371, 16.064796969294548, 39.52854931354523, 36.07702352106571, 44.67436999082565, 50.663274228572845, 47.66002558171749, 52.251843586564064, 40.99553279578686, 16.901208087801933, 3.1861957674846053, 0.22186635411344469, 0.14342447655508295, 0.14161390339722857, 0.1389721396844834, 0.19875967525877059, 0.1352941893856041, 0.1625105258426629, 0.15595813369145617, 0.12314701307332143, 0.16649992583552375, 0.07655636232811958, 0.11713926825905219, 0.09495124206296168, 0.10542641903157346, 0.2684699627570808, 0.15947242558468133, 0.11031458954676054, 0.1007418122026138, 0.166453838464804, 0.0927017924550455, 0.10870529426028952, 0.2479161086375825, 0.17349624104099348, 0.1632443317794241, 0.08498025053995661, 0.07778367420542054, 0.14020279864780605, 0.09869368499494158, 0.17511197074782103, 0.11964082543272525, 0.15354493662016466, 0.07568977132905275, 0.13917033764300868], [0.11811516276793554, 0.05834211391629651, 0.07017222989816219, 0.06734387541655451, 0.05384657662943937, 0.04491560117457993, 0.032934621413005516, 0.022538865378010087, 0.023247505087056197, 0.0836667233670596, 0.028946638922207057, 0.02440315147396177, 0.1023423056176398, 0.06256752429180779, 0.058397500397404656, 0.07693065708735958, 0.023449233813153114, 0.029657065351784695, 0.05128315031470265, 0.014163483010634081, 0.04022706838441081, 0.04366934597783256, 0.026102565752808005, 0.027550035738386214, 0.06633702592807822, 0.05550542882701848, 0.05505847781023476, 0.03318105897051282, 0.017499009154562373, 0.1277844564174302, 0.01234580842719879, 0.07067494589136913, 0.0961766169348266, 0.05316139620845206, 0.03147564813843928, 0.09830134120420553, 0.39753808232489973, 4.9167105462402105, 16.07612796127796, 38.442825973033905, 52.80784115195274, 43.88641007244587, 27.08727590739727, 27.054992839694023, 35.18933795392513, 24.484991244971752, 20.126714408397675, 14.132177922874689, 7.0023611560463905, 1.2911239312961698, 0.34407162631396204, 0.056166567374020815, 0.8477437135297805, 2.0257731853052974, 2.00515097938478, 2.4307359801605344, 1.2110434658825397, 7.258562408387661, 1.1730640288442373, 1.6041580215096474, 2.864430220797658, 6.319598592817783, 11.911711972206831, 23.90931263566017, 30.57586871087551, 36.570837423205376, 48.43765765428543, 54.35885712504387, 54.546855837106705, 54.74712789058685, 55.34798204898834, 55.53658872842789, 53.286167085170746, 53.016769140958786, 53.012695759534836, 58.36054399609566, 57.409219443798065, 50.5139422416687, 52.97145277261734, 52.68548011779785, 54.182436391711235, 52.04934485256672, 51.565760001540184, 51.375587806105614, 53.29371728003025, 55.85357151925564, 50.910694152116776, 55.065706595778465, 47.50169187784195, 27.103827819228172, 45.14470875263214, 50.886117070913315, 50.674772411584854, 52.31670990586281, 52.626647874712944, 51.41400374472141, 52.51351274549961, 46.00381225347519, 41.57539688050747, 42.37104758620262, 49.34545934200287, 51.136470437049866, 53.00129257142544, 54.02928180992603, 56.32713630795479, 55.99345341324806, 51.50640718638897, 51.60233683884144, 54.55875299870968, 54.94779892265797, 57.16174632310867, 49.44423124194145, 46.85886137187481, 44.88541066646576, 30.712549276649952, 27.417290098965168, 19.992805793881416, 11.55998194590211, 6.5569547563791275, 4.903068328276277, 4.271022118628025, 2.6346318516880274, 8.673212248831987, 9.989112988114357, 4.813290545716882, 4.847024185582995, 2.3535984568297863, 0.6466399796772748, 0.5013532913289964, 0.14581220311811194, 0.448637799709104, 1.2183389556594193, 7.592277601361275, 13.309624660760164, 21.81686371564865, 33.171623423695564, 36.549740955233574, 39.790845438838005, 39.83268879354, 44.34328615665436, 25.931695215404034, 8.472841400653124, 0.454350229119882, 0.12903049268061295, 0.03880736585415434, 0.002403428088655346, 0.023147281754063442, 0.04061993909999728, 0.019749863276956603, 0.025401649945706595, 0.05213675001868978, 0.012819737439713208, 0.008223944350902457, 0.047135483619058505, 0.012303480034461245, 0.059759901705547236, 0.0338474333693739, 0.045345772232394665, 0.05353226966690272, 0.04601302607625257, 0.02815794930938864, 0.03361818766279612, 0.010645518414094113, 0.08064682799158618, 0.025964068008761387, 0.012114444816688774, 0.06526419208967127, 0.013254369732749183, 0.006993579463596689, 0.05179037856578361, 0.02142814118997194, 0.032669233114575036, 0.027570201746129896, 0.05614693014649674, 0.030439032962021884, 0.0651328542153351, 0.022773751406930387, 0.06960460566915572, 0.07214270619442686, 0.05748659204982687, 0.027248152327956632, 0.006638622753598611, 0.01739603245368926, 0.08719219200429507, 0.05689852165232878, 0.03891983091307338, 0.06306874856818467, 0.02495939301297767, 0.04831277845369186, 0.04680235208070371, 0.03066229139221832, 0.024478485029248986, 0.08369663933990523, 0.06655826757196337, 0.09632348053855821, 0.01881515981949633, 0.025064030269277282, 0.02824545037583448, 0.04166080121649429, 0.026140025656786747, 0.017472178660682403, 0.04527510121988598, 0.0592816172138555, 0.00528484195456258, 0.035099499582429416, 0.03753498334845062, 0.03055720513657434, 0.11652620232780464, 0.04137942705710884, 0.029246728190628346, 0.026165249400946777, 0.05181764507142361, 0.4082075535552576, 6.028120983392, 21.003853641450405, 46.604525819420815, 58.35023134946823, 48.0451425164938, 32.34416842460632, 32.91299410164356, 39.73517842590809, 31.57360777258873, 27.49684453010559, 17.77831882238388, 7.358417250216007, 1.645898069255054, 0.2750484785065055, 0.09160293891909532, 1.232199661899358, 4.442666033282876, 4.693370405584574, 4.200278464704752, 4.356510881334543, 6.139233196154237, 3.937534913420677, 3.4292067401111126, 4.560709549114108, 8.892849963158369, 16.00228652358055, 25.129888840019703, 31.58433459699154, 40.85059717297554, 51.03626601397991, 54.21395190060139, 55.59881038963795, 55.01305282115936, 56.74546346068382, 56.49577505886555, 55.55522672832012, 53.551799431443214, 54.26777981221676, 57.97954984009266, 56.83464087545872, 52.739695608615875, 52.53224574029446, 53.00015643239021, 56.145597249269485, 53.292493745684624, 54.4690778106451, 53.81507970392704, 55.18117479979992, 55.56933917105198, 52.03451804816723, 55.131766051054, 47.45974212884903, 31.85652919113636, 45.3611109405756, 51.662901788949966, 52.31745086610317, 54.33206096291542, 54.785657823085785, 54.29591730237007, 54.75107967853546, 47.29660548269749, 43.36404450237751, 44.55227114260197, 51.01445138454437, 53.55912923812866, 56.41703188419342, 55.79047590494156, 55.29834911227226, 56.376750245690346, 54.53940063714981, 53.41738164424896, 55.81565335392952, 56.550028547644615, 57.932143583893776, 50.878426283597946, 50.30819088220596, 47.22757838666439, 33.851080164313316, 29.675752110779285, 22.600406371057034, 13.54774933308363, 8.628415502607822, 4.809319283813238, 4.015572750940919, 5.22457430139184, 7.739467928186059, 7.375714872032404, 5.8873485121876, 3.207427365705371, 2.730514006689191, 0.6085848435759544, 0.752917070640251, 0.12223085403093137, 0.6183760869316757, 1.6975332610309124, 9.832757078111172, 15.268409103155136, 28.012735247612, 34.63251583278179, 38.90753723680973, 42.85928338766098, 43.76007065176964, 50.434085726737976, 31.509579308331013, 10.652292352169752, 0.7987816783133894, 0.031856403293204494, 0.04062860367412213, 0.05574728362262249, 0.007234514923766255, 0.06909155898028985, 0.011886536831298145, 0.051601698651211336, 0.06196162008563988, 0.014882999821566045, 0.0336344369861763, 0.006602108624065295, 0.033741113293217495, 0.07836179240257479, 0.060592776935664006, 0.03375896194484085, 0.011843636984849581, 0.03740868836757727, 0.04429876513313502, 0.029876722510380205, 0.03192655851307791, 0.03586855382309295, 0.020440817606868222, 0.03727848226844799, 0.08473032488836907, 0.029257287096697837, 0.010601203848636942, 0.03102696791756898, 0.0764515636547003, 0.07484381945687346, 0.01850135566201061, 0.06402482773410156, 0.0471332720189821, 0.0214295661135111, 0.21189681719988585, 0.23690980626270175, 0.12590185040608048, 0.19482532778056338, 0.12130264251027256, 0.215309924678877, 0.11223823632462882, 0.18958520115120336, 0.1919601924601011, 0.16017457150155678, 0.14132618758594617, 0.1232361004804261, 0.1902627819799818, 0.15256139799021184, 0.16143828572239727, 0.10489363863598555, 0.19664142251713201, 0.15934259427012876, 0.1970356810488738, 0.13373958296142519, 0.20250489382306114, 0.1418530530645512, 0.14516404102323577, 0.17731252766679972, 0.09552020957926288, 0.17945993196917698, 0.3119023150065914, 0.10498581337742507, 0.13477660075295717, 0.3280937211820856, 0.09426085918676108, 0.1718829752644524, 0.1706719386857003, 0.1476267393445596, 0.10785911232233047, 0.17772810067981482, 0.7328442321158946, 7.208848251029849, 24.948775358498096, 51.516480445861816, 65.27967631816864, 55.2483019977808, 35.950756296515465, 36.13947317004204, 48.8615895062685, 35.118775740265846, 30.381387546658516, 21.650957018136978, 10.39242809638381, 2.6201743399724364, 0.8186778263188899, 0.30610053101554513, 2.077495059929788, 5.699165984988213, 5.109135070815682, 8.612494356930256, 5.786365130916238, 11.905726343393326, 3.1450297264382243, 3.252747058868408, 4.4766271859407425, 8.398804273456335, 16.57238893210888, 26.189887560904026, 32.37852618098259, 40.90425409376621, 53.425847589969635, 54.4533808529377, 56.265872195363045, 55.54643400013447, 56.76848642528057, 56.063130274415016, 54.11873281002045, 53.389274552464485, 54.288006126880646, 58.36270987987518, 57.273456528782845, 51.50935962796211, 53.2577446103096, 53.71221162378788, 55.64649783074856, 54.8559844493866, 55.67639842629433, 55.71255348622799, 57.46905863285065, 58.38619261980057, 51.993655040860176, 54.780041724443436, 49.61509667336941, 37.38038018345833, 49.52545568346977, 52.279259115457535, 52.01509349048138, 54.46453705430031, 55.06819166243076, 55.69860823452473, 56.64830647408962, 49.810691177845, 45.31673692166805, 45.88538020849228, 54.247728288173676, 55.25039188563824, 58.53751949965954, 56.26441307365894, 57.70128317177296, 57.74776607751846, 55.33330723643303, 55.26030175387859, 57.232175543904305, 57.36351549625397, 58.26936788856983, 51.578941494226456, 51.775896325707436, 49.93679501116276, 35.85793487727642, 29.62057337164879, 25.330318585038185, 15.75074952095747, 9.900828525424004, 7.82906474545598, 9.74605143070221, 8.647539876401424, 19.088004045188427, 19.378355965018272, 12.291684933006763, 11.781656350940466, 6.6357003059238195, 3.369230995886028, 1.3573356159031391, 0.4968166316393763, 1.2569113983772695, 2.0362359238788486, 11.689380202442408, 20.49536492675543, 33.51181536912918, 44.66387115418911, 48.82948882877827, 51.981598287820816, 51.070638969540596, 57.04198814928532, 35.02065360546112, 12.38571373745799, 1.4410070073790848, 0.16771685506682843, 0.1513074355898425, 0.1433956070104614, 0.1260750083019957, 0.11402647083741613, 0.124752382398583, 0.13796771701890975, 0.14355608902405947, 0.07614004716742784, 0.11544017310370691, 0.11462209629826248, 0.08261547118308954, 0.16564785124501213, 0.14328817371279, 0.11047642969060689, 0.11061665849410929, 0.20124555827351287, 0.14733850402990356, 0.11901630074135028, 0.1073327440826688, 0.1750421049655415, 0.10420359714771621, 0.18223059189040214, 0.1768254116177559, 0.05696142608940136, 0.17062950268154964, 0.20467488910071552, 0.07857258460717276, 0.21342246502172202, 0.14350820565596223, 0.16208276676479727, 0.13105529418680817, 0.22293801535852253], [0.008506278663844569, 0.015585587316309102, 0.04990682631614618, 0.04917492398817558, 0.03596099202695768, 0.02983490063343197, 0.056570021115476266, 0.02787797409837367, 0.02827124928444391, 0.03334166343847755, 0.011486904222692829, 0.020385607385833282, 0.048625393319525756, 0.04898127168416977, 0.020214768701407593, 0.069269199448172, 0.024319691401615273, 0.023565034825878683, 0.07290708861546591, 0.04323504486819729, 0.09666014098911546, 0.07410711172269657, 0.027766696475737263, 0.020288053929107264, 0.018483208295947406, 0.04844839852012228, 0.017453947803005576, 0.04638331323803868, 0.04190066705632489, 0.04670120106311515, 0.02752609405433759, 0.04182735770882573, 0.052741329491254874, 0.021832966049259994, 0.018543337100709323, 0.059172974215471186, 0.08457524570985697, 1.7394452495500445, 7.984857335686684, 29.18227829039097, 47.01758645474911, 47.6566019654274, 31.49951934814453, 24.319793209433556, 29.566287584602833, 20.343519374728203, 28.808636739850044, 25.554312765598297, 11.513298600912094, 3.191070193424821, 0.7080904603935778, 0.11179925597389229, 0.11798168008681387, 0.933125369483605, 3.7245546793565154, 2.59912536945194, 3.0009362334385514, 3.7825155816972256, 1.5062885731458664, 4.318542368710041, 2.0678623393177986, 6.127437204122543, 9.960943199694157, 15.885334499180317, 24.599805884063244, 31.36662147939205, 40.9275658428669, 46.84010557830334, 54.574039578437805, 57.62793950736523, 54.290844574570656, 53.601158782839775, 55.22093206644058, 53.38364705443382, 51.70376479625702, 54.9003204703331, 51.25677578151226, 52.69078083336353, 55.16539804637432, 53.2402503490448, 52.87196271121502, 50.73396943509579, 52.19420447945595, 50.5866589397192, 52.906130477786064, 53.07575337588787, 49.3258485943079, 51.163532584905624, 51.678610146045685, 29.090889394283295, 44.65073525905609, 51.15415848791599, 52.21959471702576, 53.821797743439674, 54.6148531883955, 53.948034569621086, 51.71006865799427, 45.365043729543686, 40.083148553967476, 44.60596226155758, 49.33258183300495, 51.55294708907604, 56.11519508063793, 56.250908598303795, 55.78503079712391, 52.07389533519745, 54.732878655195236, 51.67588569223881, 55.44284015893936, 56.16154499351978, 55.874132215976715, 52.1058364212513, 39.159881696105, 42.84320645034313, 25.948634706437588, 24.311937130987644, 13.668788988143206, 8.887706939131021, 3.8645363179966807, 3.1210655998438597, 2.9420006833970547, 2.4753688601776958, 5.417588744312525, 3.0552676180377603, 0.8813977951649576, 0.878325185040012, 1.876510069705546, 0.37141789798624814, 0.3764039132511243, 0.24310951499501243, 0.450731695163995, 4.101380221545696, 7.0904831774532795, 12.95529367402196, 25.426671914756298, 25.007900185883045, 29.26334124058485, 43.11857387423515, 38.49628910422325, 35.62504157423973, 21.626746617257595, 1.9345977902412415, 0.5705587996635586, 0.04747366918309126, 0.008676114521222189, 0.04743653211335186, 0.015778953893459402, 0.022766921792936046, 0.07915399794001132, 0.04259047105733771, 0.030338813339767512, 0.022947582801862154, 0.08627393268398009, 0.026704169213189743, 0.03570444641809445, 0.0328188092680648, 0.03237667107896414, 0.04075021941389423, 0.0999322255665902, 0.021822566704940982, 0.012636964092962444, 0.11196722625754774, 0.02936517495982116, 0.07005177933024243, 0.06804614749853499, 0.05932949687121436, 0.012606535110535333, 0.011190128643647768, 0.006499618029920384, 0.03311374988697935, 0.00805069925263524, 0.022682300259475596, 0.010406059827801073, 0.031760766432853416, 0.022328154809656553, 0.054955048399278894, 0.018570319734863006, 0.04539514360658359, 0.06932847478310578, 0.014969884905440267, 0.015141683743422618, 0.08196678216336295, 0.025352130141982343, 0.028398761387506966, 0.007554214980700635, 0.0037868602385060512, 0.022119587192719337, 0.07835597396478988, 0.027287515840725973, 0.010766433751996374, 0.016123518216772936, 0.06158155883895233, 0.03498635174764786, 0.03240995269152336, 0.05070182975032367, 0.03279340555309318, 0.0705671712057665, 0.08403272833675146, 0.09282192389946431, 0.02951124817627715, 0.0059768376104329946, 0.07810437848092988, 0.0021391690142991138, 0.07693178515182808, 0.03834619157714769, 0.08282071954454295, 0.036746922705788165, 0.02481774485204369, 0.03107725398876937, 0.04183866432867944, 0.08212027314584702, 0.03801970597123727, 0.0931942074385006, 2.8126164386048913, 10.840457305312157, 36.58865846693516, 53.88629928231239, 54.53539565205574, 33.98667208850384, 27.350548580288887, 33.04862402379513, 23.175064735114574, 27.187136448919773, 29.41251363605261, 13.037581108510494, 2.3583004670217633, 0.7458411378320307, 0.0771193036052864, 0.12759937962982804, 0.7157415873371065, 2.1100685745477676, 4.869737941771746, 2.707672482356429, 2.3147754650563, 4.351201616227627, 2.078281380236149, 2.4475327413529158, 7.07127520814538, 11.68409088626504, 18.206808529794216, 29.828578010201454, 33.12137492001057, 43.68580363690853, 48.80404159426689, 55.99949508905411, 58.043629601597786, 55.2910041064024, 53.780269771814346, 55.08569732308388, 53.380364030599594, 51.94893144071102, 55.715654119849205, 54.24387909471989, 51.9768675416708, 56.109339594841, 55.11837176978588, 54.731590524315834, 54.27276894450188, 53.86750549077988, 53.23837324976921, 55.421078726649284, 54.30953197181225, 51.02522760629654, 51.351029723882675, 51.6385792940855, 32.552203461527824, 46.46494410932064, 52.004286870360374, 53.04452285170555, 53.28988328576088, 56.144138127565384, 54.71881560981274, 53.83483104407787, 48.021283596754074, 43.00342485308647, 46.58081129193306, 52.735382840037346, 53.677641078829765, 57.1890402585268, 55.17989046871662, 54.84183020889759, 55.06488963961601, 57.4771673977375, 54.33301091194153, 57.25852333009243, 56.49969644844532, 57.0488315820694, 51.08040824532509, 44.58038203418255, 45.424966514110565, 30.75839001685381, 26.610359698534012, 15.474272556602955, 10.928661022335291, 7.5372727029025555, 4.786665374413133, 3.122721123509109, 6.027812724933028, 4.741098219528794, 5.025094980373979, 4.735811278223991, 1.9616525759920478, 2.150752991437912, 0.4362844250863418, 0.5921409884467721, 0.3483258542837575, 0.43826174398418516, 3.845130284316838, 9.60320284590125, 17.779443562030792, 27.664178051054478, 30.633910596370697, 36.900450736284256, 50.278126895427704, 45.26886709034443, 43.630068227648735, 24.974517077207565, 3.4335971670225263, 0.8974934346042573, 0.06991920949076302, 0.02418678759568138, 0.035956680148956366, 0.025309490047220606, 0.1290401999722235, 0.06269756340770982, 0.03502739993564319, 0.05549868270463776, 0.0466075494477991, 0.039234957948792726, 0.0335104983241763, 0.04783576674526557, 0.020914059205097146, 0.042859514433075674, 0.05040978350734804, 0.010391425603302196, 0.006884584872750565, 0.046153848597896285, 0.03304585079604294, 0.07133399529266171, 0.07745816081296653, 0.07048687082715333, 0.05615552050585393, 0.020498488047451247, 0.08279567206045613, 0.02431359465845162, 0.07055476249661297, 0.007683566682317178, 0.015003966182121076, 0.01819357403292088, 0.05187381451833062, 0.05721659130358603, 0.018997982333530672, 0.168463900918141, 0.1246169107616879, 0.1413886170485057, 0.1102765767427627, 0.13640289864270017, 0.18422775581711903, 0.134358519280795, 0.1006351804244332, 0.12784943886799738, 0.07576096555567347, 0.19243852148065343, 0.14650360273662955, 0.1425887440564111, 0.1586059236433357, 0.1568088575731963, 0.1911704582744278, 0.2069665669114329, 0.18175454868469387, 0.15952020505210385, 0.1576442932127975, 0.25283775001298636, 0.18271364097017795, 0.17026346060447395, 0.11540191539097577, 0.12083911933586933, 0.16693886165739968, 0.05863417129148729, 0.1781986519927159, 0.13212621328420937, 0.1169716838921886, 0.17937031021574512, 0.15014641976449639, 0.10442757731652819, 0.17721456417348236, 0.17838476778706536, 0.13102284749038517, 0.15353539260104299, 2.9723952524363995, 14.423988964408636, 43.56447994709015, 59.129512533545494, 61.888742074370384, 45.17093114554882, 35.874840170145035, 44.12883326411247, 30.30023530125618, 37.30183459818363, 33.097037225961685, 15.837270878255367, 4.383006384596229, 0.9619501477573067, 0.5497027875389904, 0.6281887635122985, 2.9225490521639585, 8.685477990657091, 9.68956746160984, 9.519226402044296, 9.093539044260979, 5.605246424674988, 7.725560199469328, 4.344376707449555, 9.63473355397582, 13.5087501257658, 18.174377270042896, 29.394990876317024, 33.743184953927994, 44.47715297341347, 51.904359832406044, 55.41597180068493, 58.12470965087414, 55.26320859789848, 52.47383527457714, 55.44142283499241, 52.313130497932434, 51.54241405427456, 55.15242554247379, 54.83286648988724, 54.142485335469246, 56.901346296072006, 55.24621590971947, 56.718066930770874, 54.53829489648342, 55.73773853480816, 54.07481096684933, 58.23686443269253, 56.778506487607956, 53.07611055672169, 51.998541578650475, 52.984277084469795, 37.041939944028854, 48.53687413036823, 52.88047045469284, 52.950405701994896, 54.42854918539524, 57.20246493816376, 57.744756639003754, 55.76464869081974, 49.48703974485397, 44.22736577689648, 48.29200766980648, 54.35115873813629, 55.40901057422161, 58.501330241560936, 56.672963351011276, 55.27747683227062, 56.08350858092308, 58.5582359880209, 55.88001050055027, 58.25419910252094, 58.31703633069992, 58.582037910819054, 52.6369871199131, 46.380516439676285, 49.64773692190647, 33.435336872935295, 27.046342603862286, 17.452558502554893, 12.134632710367441, 7.369174947962165, 6.410950440913439, 6.4407802652567625, 9.610638096928596, 12.743247952312231, 11.256722118705511, 8.396775182336569, 6.707942504435778, 7.146352529525757, 0.8983429265208542, 0.9580074436962605, 0.699601419037208, 0.7201286894269288, 5.439800452440977, 11.41098814085126, 21.034508496522903, 37.96822763979435, 37.61049583554268, 42.50613413751125, 57.09501810371876, 52.848772555589676, 47.40670457482338, 31.16068582981825, 3.92177383415401, 0.8689437853172421, 0.19501332863001153, 0.11990393162705004, 0.13495529507054016, 0.06628521659877151, 0.1682861862354912, 0.1411765706143342, 0.13602542749140412, 0.15329980524256825, 0.1301762499497272, 0.19104586652247235, 0.1302306048455648, 0.15433804015628994, 0.1532252787728794, 0.1071902591502294, 0.17502689093817025, 0.12690036557614803, 0.11451539772679098, 0.18396027095150203, 0.14312678627902642, 0.2002876831102185, 0.15660687466152012, 0.18729043600615114, 0.10526048223255202, 0.07954849395900965, 0.11496523569803685, 0.13975893496535718, 0.10923065317911096, 0.10937976549030282, 0.3265971061773598, 0.1012574415653944, 0.21116166055435315, 0.13309571048012003, 0.16468292567878962], [0.028271377304918133, 0.06451966211898252, 0.055752293119439855, 0.039938740301295184, 0.029990814728080295, 0.0756070515490137, 0.05688241704774555, 0.04976707248715684, 0.01791585124010453, 0.015262929337040987, 0.037922176634310745, 0.006153249360068003, 0.03752475655346643, 0.027531012638064567, 0.02359140333282994, 0.08426099811913446, 0.026944320779875852, 0.07740342742181383, 0.03843661485007033, 0.0732719358347822, 0.018965669223689474, 0.008765498787397519, 0.025639844097895548, 0.041339035669807345, 0.04937712583341636, 0.03832874368526973, 0.04689941386459395, 0.06835195687017404, 0.0830236152978614, 0.049694186163833365, 0.051970297427033074, 0.0831811509851832, 0.034197723362012766, 0.06216060843144078, 0.02619161419715965, 0.08271927537862211, 0.0857035254011862, 0.4460831789765507, 3.732874095439911, 18.408262319862843, 37.65396550297737, 41.70748919248581, 41.402046382427216, 22.848789542913437, 24.110479541122913, 29.6279164776206, 30.363672897219658, 18.398367650806904, 14.058498926460743, 5.094830738380551, 0.7823032094165683, 0.38458822877146304, 0.13732834195252508, 0.7462553156074136, 2.08937322255224, 2.4937662854790688, 2.5049797212705016, 1.7363705020397902, 5.740963267162442, 1.05359309585765, 2.653986825607717, 3.273876537568867, 5.487298853695393, 11.426147427409887, 18.5589337348938, 23.80276445299387, 35.141532719135284, 42.4484646320343, 48.184640631079674, 52.70827129483223, 57.62166224420071, 53.77177722752094, 56.14974282681942, 56.547817066311836, 55.272282510995865, 58.94980877637863, 53.517361879348755, 54.072219505906105, 53.541638776659966, 53.16561095416546, 53.40813674032688, 52.823929488658905, 51.74938514828682, 51.84687651693821, 52.29734994471073, 55.1228479295969, 56.25884257256985, 52.74128012359142, 51.657901257276535, 30.11008970439434, 40.67615993320942, 55.3402304649353, 53.42448726296425, 56.32332131266594, 51.21395207941532, 51.70995466411114, 49.57077585160732, 45.997952967882156, 42.79153682291508, 47.93185539543629, 50.01736968755722, 53.845440074801445, 54.857158586382866, 55.89998982846737, 55.374079048633575, 53.79442781209946, 53.97606186568737, 53.07506561279297, 54.46689672768116, 55.5191932618618, 53.58636237680912, 48.854115307331085, 35.17033897340298, 35.05446419119835, 21.18840593844652, 18.51675219833851, 11.65794163942337, 5.247374502941966, 5.665289852768183, 2.750635351985693, 0.8680999930948019, 4.237128887325525, 1.7418666696175933, 4.143360843881965, 5.242879344150424, 1.2933476432226598, 1.6010394576005638, 0.7359880290459841, 0.8417422918137163, 0.23548304219730198, 0.7283982925582677, 2.59276878554374, 9.652828183025122, 17.30936698615551, 24.93118990212679, 29.519762881100178, 30.338580943644047, 35.69674752652645, 35.17821975052357, 25.169361121952534, 14.10435201600194, 2.778507568873465, 0.060978248438914306, 0.03234026502468623, 0.05583952886809129, 0.027312787824484985, 0.05456515740661416, 0.06763593279174529, 0.07442513684509322, 0.03487046167720109, 0.06310670200036839, 0.019062120591115672, 0.09504890869720839, 0.024331467429874465, 0.02418050902633695, 0.12679100269451737, 0.027195574875804596, 0.022766908805351704, 0.07921625670860521, 0.029166117965360172, 0.05659712805936579, 0.024601514560345095, 0.02347892714169575, 0.016161562562047038, 0.01709257940092357, 0.017161536052299198, 0.023750579166517127, 0.04041074251290411, 0.04677738623286132, 0.042251966369803995, 0.027926169168495107, 0.02927647718024673, 0.023270658239198383, 0.04847636635531671, 0.04266127565642819, 0.05244766907708254, 0.0800536219321657, 0.0068832675606245175, 0.03577771123673301, 0.037435847261804156, 0.013491861627699109, 0.061268491263035685, 0.10569546240731142, 0.05644007847877219, 0.04924980668874923, 0.009148278149950784, 0.05012755958887283, 0.025134302377409767, 0.021596156002487987, 0.010133828000107314, 0.1242673592059873, 0.03149665833916515, 0.011833664375444641, 0.03206602290447336, 0.016765795080573298, 0.08305662602651864, 0.040786465906421654, 0.049701025054673664, 0.026922416291199625, 0.03566008082998451, 0.013208000345912296, 0.037469893286470324, 0.04562897578580305, 0.015736495624878444, 0.05224141510552727, 0.06894272868521512, 0.03054588923987467, 0.06171644417918287, 0.06746963976183906, 0.026754364371299744, 0.029101387845003046, 0.08060256630415097, 0.0883016805164516, 0.49881864921189845, 5.914991078898311, 22.30378668755293, 46.25171095132828, 49.73620757460594, 45.77156491577625, 27.674885876476765, 31.939619332551956, 32.859496772289276, 34.92088235914707, 22.25691430270672, 15.902888607233763, 5.119478590786457, 0.87597441743128, 0.2771663008024916, 0.08763784426264465, 0.5308192258235067, 0.7441410259343684, 3.294522254727781, 2.8337653912603855, 3.0877423379570246, 3.4739569388329983, 4.135942691937089, 4.083067579194903, 4.41934953443706, 7.164446208626032, 14.08592775464058, 20.82857094705105, 27.108720056712627, 38.72354730963707, 45.183721259236336, 49.91938814520836, 53.685316666960716, 56.40000119805336, 55.030281096696854, 58.500061109662056, 56.290757060050964, 55.45515529811382, 59.66896578669548, 55.875272154808044, 54.526344537734985, 54.228459522128105, 56.55330777168274, 55.400540828704834, 55.058160200715065, 53.22348564863205, 52.93933689594269, 54.48623389005661, 56.11612983047962, 56.499871239066124, 53.68893787264824, 52.8442469984293, 33.20496663451195, 43.25638487935066, 56.63718447089195, 53.992393389344215, 57.60865934193134, 54.566056206822395, 53.06532293558121, 52.22917780280113, 47.38654285669327, 46.13419085741043, 50.03009520471096, 52.87499114871025, 56.04508884251118, 56.05165109038353, 56.724815368652344, 55.730325132608414, 54.38057295978069, 55.594512820243835, 54.586928486824036, 55.45911468565464, 57.40888886153698, 54.11238335072994, 49.66213434934616, 39.342724084854126, 40.98469577729702, 25.618314631283283, 21.651033014059067, 14.624727442860603, 7.30977226048708, 7.210899190977216, 5.771505078300834, 5.722051681950688, 8.7541089579463, 5.434334920719266, 4.571927022188902, 5.118720531463623, 1.7450450803153217, 0.8271259604953229, 0.6443042925093323, 0.2913730259751901, 0.46231017855461687, 0.5673149018548429, 3.8193370308727026, 10.914877261966467, 21.60014994442463, 33.87331657111645, 31.10476043075323, 35.774004980921745, 42.499712482094765, 42.69409865140915, 30.551897697150707, 18.051071986556053, 3.972397092729807, 0.10620847198879346, 0.025018967062351294, 0.03152671532006934, 0.060655076522380114, 0.027292523482174147, 0.010268572332279291, 0.020398773085616995, 0.06520327660837211, 0.01053571580996504, 0.032510751188965514, 0.06529461272293702, 0.057600908767199144, 0.04169232022832148, 0.013478512246365426, 0.031894412386463955, 0.029869631289329845, 0.04478636728890706, 0.010240881874779006, 0.08163899037754163, 0.017040109560184646, 0.06225789285963401, 0.0583841677143937, 0.04087045104824938, 0.04747895698528737, 0.03653252737422008, 0.06210182291397359, 0.03587568586226553, 0.06351456409902312, 0.03322205891890917, 0.012945960988872685, 0.03241960432205815, 0.019802600290859118, 0.03949658726924099, 0.03071309325605398, 0.19643863808596507, 0.0859725613554474, 0.1291610809857957, 0.13867863512132317, 0.15349179884651676, 0.19243825430748984, 0.14671597571577877, 0.18249668151838705, 0.1985711103770882, 0.12936097104102373, 0.12340632689301856, 0.09168381817289628, 0.12898850196506828, 0.1456230296753347, 0.11951998152653687, 0.20481331448536366, 0.10676949852495454, 0.10711802591686137, 0.11909174005268142, 0.18464041961124167, 0.1282690343214199, 0.14750084141269326, 0.10800141171785071, 0.10625018068822101, 0.11807711285655387, 0.18033076805295423, 0.18381546309683472, 0.1656017341883853, 0.1605219708289951, 0.15426256373757496, 0.15926394145935774, 0.18955968611408025, 0.16941111884079874, 0.1307953495415859, 0.1322823017835617, 0.1534744622767903, 0.2346008809399791, 0.6467993929982185, 6.764598414301872, 26.604471914470196, 54.055481404066086, 57.16213770210743, 57.15177185833454, 33.12392458319664, 37.79266566038132, 41.61052219569683, 39.65409457683563, 26.900441832840443, 18.21244552731514, 6.615550462156534, 1.7356968694366515, 0.6685480603482574, 0.3811933781253174, 2.747597652487457, 5.344372848048806, 7.17668772675097, 6.143012093380094, 7.458621198311448, 13.900724742561579, 4.661131035536528, 7.655311468988657, 4.866787400096655, 7.964266240596771, 12.870552521198988, 22.377599626779556, 27.58867610245943, 37.80607134103775, 45.50940938293934, 52.35783509910107, 55.34519299864769, 56.93292260169983, 56.45189121365547, 58.93107958137989, 57.67418682575226, 56.03762224316597, 61.20560333132744, 55.09601376950741, 54.67863656580448, 55.09121462702751, 55.760537311434746, 56.95967696607113, 57.540855780243874, 54.414094761013985, 55.673369988799095, 55.99505692720413, 59.16066326200962, 58.59911039471626, 53.8151329010725, 52.75233753025532, 39.00110721588135, 46.51205778121948, 57.497199922800064, 54.788735657930374, 60.615928173065186, 56.6077284514904, 54.573344215750694, 53.43691259622574, 50.38746602833271, 47.70626150071621, 53.72367560863495, 55.36631226539612, 57.942562624812126, 57.504438534379005, 55.279270336031914, 56.483570113778114, 55.36344721913338, 56.168844401836395, 55.629223957657814, 58.38789492845535, 57.08645336329937, 54.831449165940285, 51.2331410497427, 43.721248134970665, 42.6757076382637, 28.070993721485138, 22.906413450837135, 14.708756133913994, 8.512506522238255, 8.840740509331226, 7.042018678039312, 6.083500161767006, 8.926781192421913, 7.304039793089032, 13.942965175956488, 13.962605372071266, 5.700174830853939, 3.889100099913776, 2.600141577422619, 1.8423237791284919, 0.5163949623238295, 1.2842765799723566, 4.337868606671691, 13.210764415562153, 27.054880745708942, 37.291229367256165, 40.88405817747116, 43.21801073849201, 47.3827962577343, 49.06965874135494, 36.708021461963654, 19.82863560318947, 4.947427622973919, 0.28947642305865884, 0.19246556534199044, 0.1430151375825517, 0.2157704421551898, 0.15491608413867652, 0.12406240770360455, 0.157987491984386, 0.16727100242860615, 0.1233524692361243, 0.10325557028409094, 0.25485288875643164, 0.146806666161865, 0.11403535434510559, 0.23699058161582798, 0.09980381175410002, 0.09603675920516253, 0.17698433512123302, 0.16253678302746266, 0.18325986166018993, 0.24895179056329653, 0.19908046117052436, 0.12378384999465197, 0.1268653362058103, 0.0705024559283629, 0.13219870626926422, 0.15600788727169856, 0.0871585652930662, 0.10507504179258831, 0.14476553740678355, 0.1573033060412854, 0.11039690114557743, 0.10166969717829488, 0.10210592416115105, 0.16744898428441957], [0.06675452110357583, 0.029877713277528528, 0.0696274712390732, 0.052194659801898524, 0.011585555130295688, 0.021351928189687897, 0.051517854517442174, 0.09264334090403281, 0.019134504109388217, 0.050028256518999115, 0.0504588134936057, 0.03124239854514599, 0.010106594891112763, 0.012818814393540379, 0.011823930180980824, 0.021988785520079546, 0.004532177581495489, 0.04427014049724676, 0.05887883140530903, 0.0323929909063736, 0.002734775921453547, 0.06481272139353678, 0.018807042579283006, 0.021030157076893374, 0.054894181157578714, 0.02781836850772379, 0.01565054935781518, 0.02722243134485325, 0.01722788034385303, 0.024344436460523866, 0.0069067922504473245, 0.05642539879772812, 0.011714647080225404, 0.0674978265305981, 0.03779911370656919, 0.01024464363581501, 0.14045677642570809, 0.09910660111927427, 1.1754329642280936, 11.38155397027731, 27.381494119763374, 45.69182239472866, 37.06891089677811, 33.20580258965492, 17.540901862084866, 14.454456679522991, 27.611680068075657, 24.291857108473778, 14.349265974014997, 8.409131169319153, 2.687142421491444, 0.5797226016875356, 0.09667102829553187, 0.09872298498521559, 0.5047597491648048, 2.5146383279934525, 1.3750816136598587, 1.5933302650228143, 3.1941171549260616, 2.894787029363215, 2.179889352992177, 3.358590854331851, 3.3114382345229387, 7.477612579241395, 14.109778124839067, 19.698750972747803, 28.591212406754494, 38.21479640901089, 42.317884638905525, 44.417879953980446, 52.07459069788456, 55.85698373615742, 54.91192884743214, 56.11939765512943, 52.34621152281761, 52.631124034523964, 56.01125165820122, 52.765944600105286, 55.900449603796005, 56.43900990486145, 52.80110791325569, 50.83403326570988, 49.24664944410324, 52.36702300608158, 53.74621219933033, 53.538465946912766, 51.420102417469025, 53.528407886624336, 48.393002450466156, 32.622298300266266, 43.67247395217419, 54.35576029121876, 53.79304088652134, 52.68806017935276, 50.23002527654171, 50.55588059127331, 45.988776460289955, 45.51354356110096, 46.37595288455486, 49.77601043879986, 50.980838388204575, 54.20532636344433, 54.96692709624767, 56.31743162870407, 52.83707678318024, 53.379429280757904, 54.994908794760704, 53.73861260712147, 54.68595877289772, 55.72220116853714, 51.84979476034641, 49.47187475860119, 33.578680381178856, 29.15787409991026, 18.76965142786503, 13.452103715389967, 8.800900597125292, 3.0260082380846143, 4.310901453718543, 4.741604067385197, 4.213673220947385, 8.946272246539593, 4.4983867183327675, 2.3937266785651445, 2.855925327166915, 0.5891785130370408, 0.7318325364030898, 0.2055733182351105, 0.21372714632889256, 0.7862259051762521, 0.6758746015839279, 5.274429051205516, 10.294665042310953, 18.35777822881937, 20.384756661951542, 21.50603659451008, 33.747953698039055, 36.40817955136299, 35.53722828626633, 26.340006105601788, 10.747415497899055, 1.1512720794416964, 0.059999158984282985, 0.05092624407552648, 0.03308738138002809, 0.08731077978154644, 0.07294266717508435, 0.07963108757394366, 0.041637657341198064, 0.030891509268258233, 0.035894310058210976, 0.022054114924685564, 0.03521949372952804, 0.09790912357857451, 0.0512671607430093, 0.03730816446477547, 0.009743017672008136, 0.052026563353138044, 0.03669751422421541, 0.01969030221516732, 0.040302247944055125, 0.005130547597218538, 0.06616702215978876, 0.02838825443177484, 0.051299069382366724, 0.046825087774777785, 0.038257337946561165, 0.0380545794905629, 0.0088844400124799, 0.06211291802173946, 0.03980212946771644, 0.024694720887055155, 0.039502079162048176, 0.11036954558221623, 0.042136610645684414, 0.039350610531982966, 0.05156352257472463, 0.01864327470684657, 0.041332701439387165, 0.0447699806682067, 0.06399120844434947, 0.022725999770045746, 0.02175601832277607, 0.024752808785706293, 0.04685974978201557, 0.04666983048082329, 0.05240215687081218, 0.03358867616043426, 0.029039598484814633, 0.11709297308698297, 0.031541439529974014, 0.03835913092189003, 0.0582955293066334, 0.03409931458008941, 0.045240253675729036, 0.021860575798200443, 0.03541674916050397, 0.0031175160893326392, 0.11465674717328511, 0.031249100138666108, 0.0192473142669769, 0.04124902799958363, 0.04605028560035862, 0.019798225330305286, 0.0252294846723089, 0.049978302558884025, 0.02377385662839515, 0.053147410435485654, 0.008136388551065465, 0.04538566638075281, 0.035377912572585046, 0.03280496079241857, 0.08242404903285205, 0.0729371678608004, 1.668884817045182, 14.077856037765741, 32.912507727742195, 51.75898723304272, 43.18868771195412, 34.56844747066498, 23.151116520166397, 23.349876254796982, 31.71305648982525, 22.288923785090446, 18.714970462024212, 8.95696772262454, 2.6901739463210106, 0.47366334591060877, 0.08912475939723663, 0.14330911712022498, 0.8352726045995951, 1.708167940378189, 1.279638335108757, 2.122991681098938, 3.293476360850036, 1.8300263327546418, 4.960895050317049, 3.436715374700725, 3.5415579238906503, 9.674000646919012, 16.752740554511547, 22.170763425529003, 29.57612905651331, 37.930826246738434, 45.98689176142216, 46.086267828941345, 53.90663579106331, 54.73249487578869, 54.62466426193714, 55.01268044114113, 54.870526269078255, 56.220852211117744, 56.88788361847401, 53.61439347267151, 58.59318271279335, 57.61768385767937, 55.22430248558521, 53.0258696526289, 53.94071616232395, 53.81570667028427, 54.27376069128513, 56.30008175969124, 54.03471551835537, 53.478687554597855, 50.9049716591835, 37.038200944662094, 46.06978431344032, 53.866509944200516, 55.43144457042217, 55.01579627394676, 51.99151195585728, 52.545708417892456, 48.7731796503067, 46.143017783761024, 47.776565328240395, 51.832646280527115, 52.81186893582344, 55.08807599544525, 55.83737298846245, 56.26067027449608, 54.020492881536484, 53.52214962244034, 55.64729578793049, 55.30136615037918, 57.39340089261532, 56.727612018585205, 53.79758924245834, 50.977923944592476, 37.84077487885952, 31.955601274967194, 23.590960018336773, 16.009931713342667, 10.3670160099864, 5.315913800150156, 5.507710883393884, 5.902506373822689, 6.555710798129439, 8.142618220299482, 5.69732878357172, 4.541740491986275, 2.0875089475885034, 1.764594556298107, 1.3114175735972822, 0.310650579049252, 0.16082684509456158, 0.515510025434196, 1.3341183867305517, 4.523432599380612, 10.578551609069109, 19.719982333481312, 25.918192639946938, 28.642277866601944, 38.42025898396969, 41.649310514330864, 42.044420912861824, 30.08709143847227, 12.496795076876879, 1.7685058526694775, 0.02998896121425787, 0.008391965657210676, 0.05273424569168128, 0.06611934659304097, 0.0720858428394422, 0.041867552426992916, 0.03201214669388719, 0.03468352209893055, 0.052549228275893256, 0.02159338037017733, 0.01766325942298863, 0.009722777449496789, 0.01979386892344337, 0.01335704029770568, 0.03148665047774557, 0.025134486058959737, 0.10835537905222736, 0.019726695281860884, 0.019010468968190253, 0.017453752989240456, 0.021328873372112866, 0.006286076632022741, 0.040517522720620036, 0.030487621370411944, 0.05096406763186678, 0.038077166755101644, 0.04595450031047221, 0.04043196422571782, 0.015230940916808322, 0.019527543663571123, 0.0261641602992313, 0.07171588222263381, 0.062412875558948144, 0.03086924298258964, 0.07781831023748964, 0.09976916087907739, 0.17655636824201792, 0.16464365122374147, 0.14525704697007313, 0.10925276175839826, 0.11009000823833048, 0.12977173493709415, 0.07171944453148171, 0.11166038530063815, 0.19801469257799909, 0.11676365247694775, 0.06912167533300817, 0.175284564611502, 0.09378527611261234, 0.1062568897032179, 0.17683038400718942, 0.09468132295296527, 0.19309404568048194, 0.10546524819801562, 0.06933798911632039, 0.16363866452593356, 0.20252488728147, 0.14927631098544225, 0.1364101271610707, 0.09192394747515209, 0.15932816691929474, 0.17283431952819228, 0.13956581329694018, 0.12050850738887675, 0.12119234452256933, 0.1661611651070416, 0.10613488804665394, 0.13318684621481225, 0.09655331625253893, 0.11582827180973254, 0.21040081075625494, 0.39886156911961734, 2.5680653611198068, 17.93358039110899, 39.19504500925541, 61.4656575769186, 51.93593993782997, 46.59835495054722, 28.48779145628214, 26.064712777733803, 38.66768650710583, 33.19614730775356, 22.910809814929962, 10.811938885599375, 3.9400164177641273, 0.7777575252112001, 0.2779378672130406, 0.47135663218796253, 1.2465333240106702, 7.115746596828103, 7.144826436415315, 4.651690442115068, 8.316039964556694, 8.016161005944014, 5.426413295790553, 8.579043801873922, 5.688240621238947, 9.244068916887045, 16.981182396411896, 23.5263691842556, 31.057736054062843, 39.729148149490356, 47.245623618364334, 47.667351588606834, 53.886086493730545, 54.764074981212616, 55.85565000772476, 55.436676889657974, 53.473098054528236, 57.87550762295723, 57.12891608476639, 53.65320459008217, 58.64860653877258, 59.969126880168915, 56.72222390770912, 53.55901524424553, 53.81394736468792, 57.359768897295, 56.92523941397667, 57.48628310859203, 55.30617669224739, 55.53542599081993, 50.88452495634556, 41.7788265645504, 49.84811916947365, 54.95669424533844, 56.393248960375786, 55.278662368655205, 54.1439026594162, 53.18955346941948, 50.98169334232807, 49.57411587238312, 49.89330634474754, 54.33989234268665, 53.65355037152767, 56.95163659751415, 55.120518654584885, 56.42482906579971, 54.01333786547184, 55.610376968979836, 57.59313717484474, 55.58424577116966, 58.42553570866585, 57.45806582272053, 55.760776698589325, 52.27997727692127, 39.718573316931725, 33.7906140089035, 28.632442094385624, 18.008071593940258, 10.84663387387991, 6.878081224858761, 6.812003245577216, 10.499873980879784, 8.443559221923351, 16.570042558014393, 14.92486858740449, 8.054319508373737, 6.619260488077998, 3.4836395317688584, 2.5004287529736757, 0.2989064186112955, 0.3364815632812679, 1.3250512420199811, 1.4156645047478378, 7.716648252680898, 15.65745597705245, 25.816145315766335, 33.47923591732979, 34.840072095394135, 46.78967088460922, 49.63663391768932, 50.78470051288605, 36.407856568694115, 14.559237957000732, 1.8842381425201893, 0.08868261749739759, 0.1279470609733835, 0.09362471246276982, 0.16742499807151034, 0.15317058248911053, 0.17552028555655852, 0.09613648158847354, 0.15561489039100707, 0.11536563179106452, 0.22246844368055463, 0.1267240461311303, 0.20240001351339743, 0.09050041175214574, 0.11763413975131698, 0.09406668366864324, 0.07245487577165477, 0.17453164095059037, 0.11990225437330082, 0.12749298533890396, 0.0543189758900553, 0.09384895980474539, 0.07993150895345025, 0.1381867247982882, 0.09324321144958958, 0.24801677354844287, 0.0860232648847159, 0.06486380341812037, 0.21596668084384874, 0.10705279113608412, 0.159896370023489, 0.16482460167026147, 0.17109065840486437, 0.26649861072655767, 0.1103980366315227], [0.06960992686799727, 0.08071513526374474, 0.04313257653848268, 0.06657748919678852, 0.01687821561063174, 0.03235585012589581, 0.02640642513142666, 0.08199683172279038, 0.08400729493587278, 0.014822141856711823, 0.014263731391110923, 0.05475938116433099, 0.023641680127184372, 0.08002562070032582, 0.012508426898421021, 0.024233489093603566, 0.1567268799408339, 0.023971900591277517, 0.021713825371989515, 0.018999067724507768, 0.02922282732470194, 0.03275451330409851, 0.06499744195025414, 0.07554217299912125, 0.03274990085628815, 0.010549834241828648, 0.08036857456318103, 0.05752726545324549, 0.01283977728235186, 0.044881610810989514, 0.04265152012521867, 0.06836761618615128, 0.07926848164061084, 0.07727527336101048, 0.07003352991887368, 0.026866402695304714, 0.14477812423137948, 0.05960406553640496, 0.4168605204904452, 4.87414475530386, 18.86105552315712, 41.816999316215515, 48.61788958311081, 40.96070006489754, 26.76578465849161, 23.531379215419292, 34.05468463897705, 23.513225689530373, 22.90245596319437, 13.463219068944454, 4.042830588296056, 0.9072117693722248, 0.19134602072881535, 0.15528956253547221, 0.6861392164137214, 0.540106164989993, 0.78281867550686, 2.9089901922270656, 2.0786815462633967, 3.054014160297811, 4.372546495869756, 1.890745887067169, 2.061930145137012, 7.4784893821924925, 9.033317025750875, 14.256843533366919, 22.8471290320158, 31.043424122035503, 36.435975059866905, 39.80461969971657, 46.81801736354828, 50.443551018834114, 53.98904576897621, 55.58942869305611, 54.96091201901436, 52.37796261906624, 56.25922255218029, 53.44573952257633, 56.78174011409283, 55.784263238310814, 53.98424282670021, 51.87629833817482, 52.06888720393181, 51.51945948600769, 51.320707350969315, 53.374337553977966, 53.73971074819565, 55.85460886359215, 48.9352485537529, 31.17790460586548, 43.789712861180305, 52.67264820635319, 54.01893496513367, 53.11605021357536, 51.1713981628418, 48.791164085268974, 49.19313691556454, 49.20832850039005, 50.02825990319252, 52.29909785091877, 52.42501549422741, 53.88119995594025, 54.515693709254265, 55.349194183945656, 53.88693764805794, 55.739072263240814, 54.564616084098816, 54.917913526296616, 54.68085564672947, 55.04134610295296, 49.418027848005295, 44.62871164083481, 31.867945678532124, 22.8187882527709, 16.09040379524231, 10.914550479501486, 10.654161851853132, 3.6437959503382444, 4.144940134137869, 4.607783323153853, 6.399705894291401, 7.221180964261293, 5.194963915273547, 3.834671820513904, 2.8081963257864118, 0.7549235410988331, 0.7598019449505955, 0.15166299854172394, 0.06491198364528827, 0.5677060433663428, 2.1171019971370697, 5.904215332120657, 17.548009380698204, 24.554339423775673, 26.472687385976315, 27.034553736448288, 35.770041793584824, 42.0714108645916, 34.35061655938625, 19.655532091856003, 6.316228648647666, 0.31614826060831547, 0.03694359555083793, 0.020698418920801487, 0.06320223867078312, 0.017378369338985067, 0.010936664803011809, 0.0288827344411402, 0.12320900466875173, 0.03740901120181661, 0.12524540594313294, 0.026382164323877078, 0.04563124675769359, 0.021722998317272868, 0.10556968321907334, 0.03728813389898278, 0.05507054884219542, 0.04187876627838705, 0.02939005360531155, 0.07999468798516318, 0.015609944603056647, 0.06421722951927222, 0.09079468072741292, 0.039355579210678115, 0.07972082807100378, 0.027322550777171273, 0.025183870420733, 0.023736320654279552, 0.03716497449204326, 0.050099109357688576, 0.05431989244243596, 0.035238010314060375, 0.0491617953957757, 0.02884672172513092, 0.054569565763813443, 0.017480108508607373, 0.04512186256761197, 0.0536217541230144, 0.13714476430322975, 0.04300663036701735, 0.022982209557085298, 0.018150995165342465, 0.0566870021430077, 0.04965476327924989, 0.05568960390519351, 0.03289679414592683, 0.03187052636349108, 0.05905525846173987, 0.027445346531749237, 0.042515725654084235, 0.04258449305780232, 0.03721830522408709, 0.08865552168572322, 0.03317558192065917, 0.026574324911052827, 0.04678037337725982, 0.059642686901497655, 0.03266420135332737, 0.07367623562458903, 0.013828675146214664, 0.03380977679626085, 0.019208603844163008, 0.04285303919459693, 0.032583140273345634, 0.027173727903573308, 0.027919330277654808, 0.043752006386057474, 0.09248176793335006, 0.03833328933978919, 0.09828413079958409, 0.05139401604537852, 0.012799626165360678, 0.03861444456561003, 0.09465595634537749, 0.4832607402931899, 6.634990694001317, 24.885693043470383, 48.38393233716488, 53.01662094891071, 46.69408701360226, 28.034092001616955, 24.19644232839346, 38.049060702323914, 25.991089828312397, 19.774653799831867, 15.01269992440939, 4.440256487578154, 0.8778570976573974, 0.033359014851157553, 0.18993635574588552, 0.2214682660996914, 0.6179209426045418, 1.4565707347355783, 2.236289489082992, 4.162055365741253, 3.578318813815713, 6.489966725930572, 6.108524668961763, 4.07818341627717, 8.088388480246067, 8.76961212605238, 15.921314768493176, 25.510069839656353, 34.02083985507488, 38.96743342280388, 43.04803065955639, 47.889419272542, 52.75062382221222, 54.68047186732292, 57.68997497856617, 55.4298410564661, 53.28911952674389, 56.02084994316101, 53.818659111857414, 58.48726339638233, 57.28535369038582, 56.64821907877922, 53.34789477288723, 54.302498549222946, 53.93182463943958, 55.80008938908577, 55.239292681217194, 55.3144146502018, 55.69413207471371, 49.54076126217842, 34.59006831049919, 47.14036926627159, 54.7225546091795, 54.93911638855934, 54.31655019521713, 52.968078553676605, 51.39370523393154, 50.436099618673325, 52.03846603631973, 50.92581734061241, 52.29763112962246, 52.85062685608864, 54.19950507581234, 54.16078895330429, 55.25698833167553, 53.56913410127163, 55.85637576878071, 56.84121452271938, 55.82614839076996, 53.898101449012756, 54.410690143704414, 50.53253084421158, 45.160021930933, 35.33642426133156, 25.344691313803196, 18.755823969841003, 12.949537932872772, 8.34024466574192, 5.055098170414567, 6.626345682889223, 5.07652142085135, 6.081632087007165, 7.139442600309849, 4.530894448980689, 3.8035125425085425, 2.565089170821011, 1.6857918910682201, 0.5289282335434109, 0.4088199738180265, 0.14685505419038236, 0.5098801525309682, 1.7702661082148552, 7.305997163057327, 19.31246940046549, 23.218688294291496, 24.49911128729582, 28.88884473592043, 41.37064106762409, 46.24784655869007, 40.311128720641136, 24.43115573376417, 7.867248421534896, 0.4222757345996797, 0.03381559523404576, 0.04695406190876383, 0.05020360003982205, 0.027666231944749597, 0.03555076247721445, 0.061965230634086765, 0.11093082444858737, 0.015625420237483922, 0.05625913916446734, 0.010887589360208949, 0.02738402472459711, 0.043310020337230526, 0.05595902577624656, 0.04673370342061389, 0.02198227317421697, 0.04007152536360081, 0.05854104289028328, 0.08581548579968512, 0.10635377708240412, 0.06102053230279125, 0.0561027872026898, 0.08327748175361194, 0.0900322427332867, 0.03309132960566785, 0.03053746586374473, 0.028394688852131367, 0.02661389808054082, 0.029352834899327718, 0.0675378653977532, 0.021780557435704395, 0.028446893375075888, 0.06679873084067367, 0.03611444961279631, 0.03711449731781613, 0.14594115869840607, 0.15523318899795413, 0.30278120131697506, 0.18250074848765507, 0.12108711540349759, 0.13689933606656268, 0.1491988159250468, 0.20898618822684512, 0.27512132772244513, 0.15667035797378048, 0.14484923682175577, 0.17301414191024378, 0.10925544091151096, 0.27848132711369544, 0.11663208453683183, 0.15056350675877184, 0.2846687607234344, 0.13298305246280506, 0.18044519238173962, 0.13082594086881727, 0.14813377463724464, 0.1359946432057768, 0.1686988351866603, 0.12103508342988789, 0.1493460134952329, 0.1109210577851627, 0.21710494242142886, 0.18051338091026992, 0.138530739932321, 0.1803181366994977, 0.14876905304845423, 0.18397601932520047, 0.09916108960169367, 0.2099230606108904, 0.29854264750611037, 0.15783550014020875, 0.17962059209821746, 0.300966709619388, 0.6462857080623507, 7.331146113574505, 28.66517163813114, 56.03214293718338, 62.89969302713871, 54.997181072831154, 37.90762089192867, 33.55843126773834, 49.246653243899345, 32.59901314973831, 31.08703438192606, 17.722756303846836, 6.42677279189229, 1.4323306479491293, 0.6217292288783938, 0.5617574031930417, 2.428633267991245, 3.415360045619309, 3.6483407439664006, 8.725465144962072, 5.7476024609059095, 8.460630755871534, 10.554417204111814, 6.371827740222216, 3.7082796776667237, 9.496274683624506, 9.871684089303017, 17.18116946518421, 26.25775571912527, 36.39014571905136, 40.69450534880161, 44.897231832146645, 50.15993043780327, 53.16725246608257, 56.289275139570236, 57.060732543468475, 56.42788790166378, 56.715950444340706, 57.75850810110569, 54.80998031795025, 58.58289286494255, 57.6755927503109, 57.53651261329651, 54.45214591920376, 56.30250222980976, 56.58446229994297, 55.85300154983997, 55.91853283345699, 56.52320198714733, 57.36318491399288, 49.91308428347111, 40.00444337725639, 49.30250644683838, 53.64180900156498, 57.44323521852493, 55.95857508480549, 54.40877124667168, 53.605539947748184, 53.916443064808846, 53.58236879110336, 54.658984020352364, 56.53580591082573, 57.00547210872173, 55.5626667290926, 54.21596959233284, 56.0726373642683, 54.494323655962944, 57.47329540550709, 57.2757326066494, 57.24133685231209, 55.16781471669674, 56.2139517813921, 53.3924587816, 48.25408570468426, 37.43332654237747, 28.274231515824795, 21.81408416479826, 15.049841031432152, 13.23502041399479, 7.364436602219939, 8.685268051922321, 10.8446323312819, 15.407974664121866, 16.850849390029907, 10.91331934556365, 9.249118845909834, 5.8936708979308605, 4.078390030190349, 2.841983400285244, 0.8402531279716641, 0.5172056844457984, 0.967951153870672, 3.0490905744954944, 8.757544923573732, 27.143689580261707, 33.29090282320976, 38.66627678275108, 38.700672537088394, 49.804949685931206, 53.31839315593243, 45.960787162184715, 27.243975698947906, 8.732081539928913, 0.6858647405169904, 0.11234689416596666, 0.178438009461388, 0.10646618276950903, 0.07649547653272748, 0.10557632544077933, 0.13682519551366568, 0.2214018438826315, 0.11193400030606426, 0.20295810856623575, 0.07112768566003069, 0.1650338279432617, 0.17662724334513769, 0.18892005871748552, 0.1220014932914637, 0.13873215881176293, 0.11829966068034992, 0.11027415734133683, 0.14639055880252272, 0.20710626879008487, 0.18160982988774776, 0.22899022966157645, 0.2436586152180098, 0.15836095553822815, 0.06094892247347161, 0.08250391896581277, 0.10109617287525907, 0.15890367329120636, 0.1060559532197658, 0.16747745306929573, 0.16333760489942506, 0.1474994610180147, 0.10200648379395716, 0.16841929784277454, 0.25430013716686517], [0.0913263404800091, 0.02664243736944627, 0.0446316777379252, 0.031189847068162635, 0.02367222507018596, 0.03219324556994252, 0.0954637915128842, 0.018958236614707857, 0.06196280010044575, 0.04647272719012108, 0.04196792047878262, 0.0318189767858712, 0.032129457977134734, 0.04086348970304243, 0.022770658506487962, 0.004591054012053064, 0.011753021681215614, 0.0200341485106037, 0.12094446719856933, 0.057791855942923576, 0.04253924431395717, 0.07833631447283551, 0.03872631961712614, 0.03954192507080734, 0.018251765832246747, 0.06653737611486576, 0.019697296957019717, 0.036361577367642894, 0.04818994930246845, 0.03309056148282252, 0.03520092890539672, 0.10515192829188891, 0.03462845474132337, 0.06356513404170983, 0.03029667233931832, 0.042517618130659685, 0.04068364134582225, 0.0419561945454916, 0.05254742856777739, 2.3598555335775018, 8.681156672537327, 32.94538736343384, 43.999530002474785, 41.0974395275116, 29.14910227060318, 42.29038551449776, 26.685996539890766, 21.726202480494976, 24.58487268537283, 17.916179224848747, 8.41751066967845, 1.5311669069342315, 0.18501401675166562, 0.1728642577654682, 0.17023856897139922, 0.5855418113060296, 1.072534010745585, 0.6122749205678701, 3.5345382755622268, 1.163415159098804, 5.917472345754504, 4.563181791454554, 1.915166701655835, 3.0328217474743724, 5.245419507846236, 9.918525125831366, 18.60469087958336, 23.12764897942543, 28.56685571372509, 34.27530840039253, 39.98114302754402, 42.253998667001724, 47.41376459598541, 48.65250952541828, 59.76811766624451, 55.067378506064415, 55.27438759803772, 55.75793445110321, 57.293599247932434, 57.54674546420574, 56.16874560713768, 53.98119919002056, 55.36857694387436, 52.84445218741894, 54.40850526094437, 55.914942026138306, 52.29186683893204, 52.30071276426315, 48.34917560219765, 35.67544586956501, 43.29900719225407, 49.94556114077568, 55.69657154381275, 55.71116656064987, 55.225153639912605, 55.16662918031216, 50.79821638762951, 51.54252044856548, 51.07170291244984, 52.91847601532936, 53.52572903037071, 53.118839263916016, 52.50061623752117, 52.19651475548744, 53.77035230398178, 50.805922374129295, 53.42603757977486, 52.450135946273804, 54.373216554522514, 54.78358693420887, 51.272985711693764, 43.82145635783672, 34.0935717523098, 19.362894594669342, 14.570573698729277, 6.4237448293715715, 4.361029788851738, 2.3752796184271574, 5.121058356016874, 3.009347557090223, 4.811018267646432, 3.875092389062047, 2.191410572268069, 2.584728179499507, 0.47957253351341933, 1.2491617142222822, 0.7247845083475113, 0.42741739307530224, 0.12351537807262503, 0.4232887364923954, 3.563349754549563, 7.3736572824418545, 12.874036934226751, 22.771317400038242, 23.54857139289379, 28.957856632769108, 44.0853787958622, 39.804163724184036, 35.5852273106575, 17.660490944981575, 3.081030948087573, 0.06494354718597606, 0.08746664563659579, 0.014699068724439712, 0.009619016855140217, 0.018356939290242735, 0.02056930934486445, 0.015403511588374386, 0.03351603474584408, 0.026964648204739206, 0.06526461511384696, 0.052492836184683256, 0.03590572057873942, 0.057015072234207764, 0.01739316405291902, 0.0657131320622284, 0.014572507498087361, 0.023551243866677396, 0.025522228534100577, 0.012309146331972443, 0.01905957131384639, 0.024628460087114945, 0.03551454938133247, 0.09111102859606035, 0.0590541897690855, 0.04959400735970121, 0.045566817207145505, 0.08690440939972177, 0.009583494884282118, 0.09056562426849268, 0.022361859446391463, 0.0476413314754609, 0.012751859685522504, 0.04175328023848124, 0.03849045395327266, 0.028733061808452476, 0.03881564080074895, 0.12013026440399699, 0.07041749486234039, 0.03576467541279271, 0.09658456809120253, 0.07680351976887323, 0.01991009667108301, 0.06429180051782168, 0.04320957807067316, 0.03553764501702972, 0.006346988866425818, 0.06914336088811979, 0.011488732689031167, 0.05227078559983056, 0.043862564125447534, 0.09283876323024742, 0.04040657906443812, 0.0407544756308198, 0.040400445213890634, 0.030814414967608172, 0.017302937449130695, 0.10893472921452485, 0.061946179703227244, 0.04117187432711944, 0.03100689653365407, 0.02957590408186661, 0.02146604638255667, 0.04648550697311293, 0.04048335424158722, 0.025834954722085968, 0.07925238445750438, 0.0455831741419388, 0.03668760655273218, 0.023383149273286108, 0.025025024842761923, 0.06590355973457918, 0.037883102559135295, 0.027572736180445645, 0.05002801161026582, 2.7132413210347295, 11.706479284912348, 40.273962914943695, 52.1066115796566, 46.50715984404087, 34.6596197783947, 43.708693608641624, 34.82022576034069, 30.5122297257185, 31.525832936167717, 17.16340731829405, 7.624667063355446, 2.0217057410627604, 0.22640185605268925, 0.21344038046663627, 0.25954097625799477, 0.7383525115437806, 1.6610622243024409, 1.8690324272029102, 2.950798636302352, 3.2849327567964792, 6.262299567461014, 5.96735036931932, 4.366719983518124, 5.201009390875697, 8.281118888407946, 14.540341570973396, 21.247129887342453, 25.45904617756605, 32.238017320632935, 37.691108509898186, 41.62838123738766, 45.04286661744118, 49.678146690130234, 49.663612470030785, 59.80331897735596, 54.934317246079445, 56.64436988532543, 55.80948248505592, 58.481666296720505, 58.55160154402256, 58.31485524773598, 56.02818734943867, 56.56436897814274, 56.646387577056885, 54.75840948522091, 57.266966477036476, 54.49631094932556, 53.42489764094353, 50.67118540406227, 38.54648441076279, 47.40593321621418, 53.16726766526699, 55.6858941167593, 56.75172932446003, 56.76503241062164, 53.827337846159935, 53.73350568115711, 54.04865697026253, 52.15961113572121, 55.45228265225887, 54.37850207090378, 54.22230385243893, 52.85212777554989, 52.38512523472309, 53.83143402636051, 52.971011996269226, 52.763406336307526, 54.02441807091236, 54.967090487480164, 55.55344082415104, 50.36066606640816, 45.23626483976841, 34.088757410645485, 23.097852878272533, 18.251387737691402, 9.335553757846355, 7.512381188571453, 6.983903171494603, 7.113741729408503, 6.3537150621414185, 5.073523381724954, 5.709759816527367, 3.213143921457231, 2.1698540914803743, 2.8145234612748027, 1.2613199930638075, 0.6219692097511142, 0.3495202073827386, 0.14275246183387935, 0.6313457409851253, 3.788885227404535, 9.754108898341656, 16.7171573638916, 26.01927101612091, 25.223308727145195, 31.918918043375015, 46.841355711221695, 46.18225447833538, 41.43788605928421, 20.33832125365734, 4.026049738749862, 0.11015033000148833, 0.05444553062261548, 0.030487623225781135, 0.04666788605391048, 0.035852133805747144, 0.08528214137186296, 0.06939139406313188, 0.033344799012411386, 0.06293301717960276, 0.02274464066431392, 0.03848667642159853, 0.08911603916203603, 0.03340868679515552, 0.05057136018876918, 0.12533717992482707, 0.021847781172255054, 0.026713032311818097, 0.006899253421579488, 0.0458738548331894, 0.02641870582010597, 0.04501021758187562, 0.07724175797193311, 0.006160756647659582, 0.01987634379474912, 0.09075177717022598, 0.04127193067688495, 0.047108046419452876, 0.02838084037648514, 0.04521164017205592, 0.04871670716966037, 0.0820417984505184, 0.07344860408920795, 0.05109110476041678, 0.010725021911639487, 0.027770598317147233, 0.23172471730504185, 0.31591127801220864, 0.12388983610435389, 0.09594797607860528, 0.13535311591112986, 0.14452506671659648, 0.2524077793350443, 0.11231489275814965, 0.20524151885183528, 0.11341736797476187, 0.09663035860285163, 0.14366781193530187, 0.10386522233602591, 0.10257108006044291, 0.12238345443620346, 0.2810767659684643, 0.2383872144855559, 0.11772894169553183, 0.25116488977801055, 0.19245308241806924, 0.14099190942943096, 0.2666880068136379, 0.14887537312461063, 0.10774434660561383, 0.15581666550133377, 0.14673614728963003, 0.14507728395983577, 0.10460012665134855, 0.09277452292735688, 0.21885920141357929, 0.14497998839942738, 0.2269210180384107, 0.1472761042532511, 0.11229662850382738, 0.1395761885214597, 0.16919904272072017, 0.17746518744388595, 0.1612290446064435, 0.17553156620124355, 3.5242859506979585, 14.253340121358633, 46.04577720165253, 58.85748133063316, 54.51316684484482, 40.78447312116623, 57.98400320112705, 38.550778180360794, 35.146362259984016, 33.365036845207214, 22.92269177734852, 11.130044516175985, 2.7809332637116313, 0.5052586505189538, 0.5776761146262288, 0.5511613155249506, 1.9536833348684013, 2.686731806024909, 3.1038097757846117, 8.960791267454624, 6.648287605494261, 12.422879543155432, 9.830887578427792, 4.346586288884282, 6.229026652872562, 8.318563979119062, 13.086417987942696, 22.0027307420969, 26.52027603238821, 32.25230075418949, 37.00868412852287, 42.913225293159485, 44.97290097177029, 51.14462099969387, 50.231393203139305, 60.73113039135933, 54.51440937817097, 56.894708052277565, 59.90690141916275, 59.45835828781128, 59.91869978606701, 59.436410665512085, 57.00348101556301, 57.946719601750374, 57.89363645017147, 58.68739865720272, 58.632958978414536, 55.01792035996914, 54.45472978055477, 52.84050039947033, 43.857543021440506, 49.663133695721626, 52.32456028461456, 57.895517349243164, 57.61579915881157, 59.79267194867134, 58.05012725293636, 55.26629403233528, 56.70251816511154, 55.09745009243488, 57.47131951153278, 56.13605596125126, 54.59588460624218, 53.11706855893135, 52.587623968720436, 55.203380808234215, 55.110924169421196, 55.331460535526276, 55.13352155685425, 57.50429414212704, 57.9705785214901, 54.382632449269295, 48.064453080296516, 36.96218982338905, 22.67418321222067, 19.144446216523647, 9.843444004654884, 7.1201477106660604, 7.950085876509547, 10.598112009465694, 9.40725876018405, 13.702262341976166, 13.27249115332961, 7.537646982818842, 5.857789423316717, 3.885436146520078, 2.2493078280240297, 2.1407231921330094, 1.2158453394658864, 0.23587225412484258, 0.9609548386652023, 5.329297157004476, 11.52591772377491, 19.82758115977049, 34.591048657894135, 34.85682539641857, 40.32470539212227, 54.18001972138882, 52.56878837943077, 46.250020042061806, 23.016037568449974, 4.650282142683864, 0.2763364015845582, 0.1537751211435534, 0.13380607939325273, 0.12297029286855832, 0.22367133147781715, 0.1531173408147879, 0.2187611785484478, 0.09729529323522002, 0.12921068613650277, 0.11734295811038464, 0.1499756218981929, 0.19115196395432577, 0.13731566607020795, 0.07744622707832605, 0.24161637324141338, 0.11775772218243219, 0.12856339977588505, 0.10593876068014652, 0.08888601048965938, 0.10017988024628721, 0.09722946473630145, 0.1973073070985265, 0.21504269214347005, 0.11045757913962007, 0.2820469904690981, 0.16328455618349835, 0.16152890195371583, 0.15582248393911868, 0.1245065608236473, 0.10716875171056017, 0.16934094135649502, 0.24711567268241197, 0.15080844517797232, 0.17025057692080736, 0.08149445711751468], [0.07282133345142938, 0.07340340729570016, 0.019638574522105046, 0.031798040799913, 0.03721424567629583, 0.061016851250315085, 0.03456980281043798, 0.060900371172465384, 0.04974132367351558, 0.08985851338366047, 0.06412591566913761, 0.01574544221512042, 0.03653948129795026, 0.07327475599595346, 0.007637536828042357, 0.0633105551241897, 0.09210304997395724, 0.04080948361661285, 0.021799415408167988, 0.03723179375811014, 0.05308759333274793, 0.05637445778120309, 0.0038529155563082895, 0.011892727270605974, 0.03205023742339108, 0.03483945474727079, 0.04201957766781561, 0.057845227493089624, 0.024388184210692998, 0.08982685336377472, 0.1283453419455327, 0.04248792480211705, 0.030132243955449667, 0.04449265863513574, 0.033447137466282584, 0.052922992399544455, 0.056336144407396205, 0.030187988522811793, 0.042258415633114055, 0.2718529390404001, 7.564286403357983, 23.445640616118908, 44.40102405846119, 47.013193890452385, 38.686867877840996, 22.964894212782383, 22.72628791630268, 19.01715114712715, 16.20990928262472, 18.52631438523531, 8.754351194947958, 4.007940860465169, 0.43909609608817846, 0.2707246073987335, 0.04462314675038215, 0.41721125948242843, 1.118230833671987, 2.135689649730921, 2.472123121842742, 2.5177202001214027, 5.994441490620375, 8.572398908436298, 4.741234062239528, 2.8618921944871545, 2.065267078578472, 5.7347966730594635, 9.825336076319218, 13.055197913199663, 20.74742630124092, 25.82932110875845, 30.440390780568123, 33.5625084489584, 39.37802419066429, 43.02042134106159, 46.94353982806206, 50.26049584150314, 47.398409619927406, 55.65314367413521, 54.45636749267578, 55.65263070166111, 55.11535093188286, 55.868960693478584, 54.292660877108574, 53.32212835550308, 54.304102063179016, 57.90431767702103, 57.518877759575844, 53.71783532202244, 42.61749096214771, 31.15657065063715, 38.91386389732361, 51.00244402885437, 54.80494938790798, 57.69657142460346, 54.60504211485386, 52.494179382920265, 52.431296557188034, 52.43954971432686, 53.03319185972214, 51.953958570957184, 48.07245925068855, 50.12838453054428, 50.11097006499767, 50.11051408946514, 49.96833711862564, 49.88594613969326, 51.81468464434147, 48.434959799051285, 44.22007016837597, 43.24080191552639, 38.8111288100481, 31.840858832001686, 26.96197383105755, 17.41716530174017, 16.034037619829178, 6.461642570793629, 3.5265240306034684, 6.155207064002752, 5.867171594873071, 4.718421986326575, 2.4081134190782905, 3.1053190072998405, 2.324241944588721, 2.100244201719761, 4.2650155909359455, 1.172694736160338, 0.3130217408761382, 0.3453212248859927, 0.3251728950999677, 1.4111635275185108, 4.046280328184366, 11.163208186626434, 19.149167463183403, 22.54443157464266, 21.560535170137882, 35.63529722392559, 42.89429850876331, 37.16898612678051, 26.171494647860527, 7.619388196617365, 1.0955470008775592, 0.050323664690949954, 0.10305441115633585, 0.043046112623414956, 0.146456713846419, 0.0025106830389631796, 0.04808891702850815, 0.03457609251199756, 0.02618719285237603, 0.03240415651816875, 0.039487343819928356, 0.01555660366648226, 0.07013145630480722, 0.046118652244331315, 0.06013088277541101, 0.06136634343420155, 0.036939702986273915, 0.019763932541536633, 0.041354631903232075, 0.06299303466221318, 0.04007824551081285, 0.01311527548750746, 0.027926386246690527, 0.0152306579730066, 0.028012427137582563, 0.03891646156262141, 0.06802055082516745, 0.027590902100200765, 0.006699616624246119, 0.04424123384524137, 0.03319228024338372, 0.03652768486062996, 0.0711065270297695, 0.02535086478019366, 0.015433716071129311, 0.1056765895918943, 0.010742452177510131, 0.07851233705878258, 0.04640306178771425, 0.03471964613709133, 0.06293110986007378, 0.04928959322569426, 0.06551485988893546, 0.009179572662105784, 0.04929525210172869, 0.07352552769589238, 0.07775081932777539, 0.03798163750616368, 0.02657779445144115, 0.008259308615379268, 0.03375311011041049, 0.022306252176349517, 0.024473110024700873, 0.07696911517996341, 0.08043268870096654, 0.04783021919138264, 0.011376172078598756, 0.03856051269394811, 0.0642539955151733, 0.03281168836110737, 0.05112265716888942, 0.022009335589245893, 0.022633836160821375, 0.025146451334876474, 0.05957226821919903, 0.007851227583159925, 0.04244126597768627, 0.005537404549613711, 0.014153553074720548, 0.0599540512484964, 0.028571687362273224, 0.0907312567869667, 0.03167690374539234, 0.03184323759342078, 0.04192012987914495, 0.7502838119398803, 9.33908186852932, 27.970327623188496, 50.81623502075672, 53.224143013358116, 43.936476185917854, 31.127276122570038, 27.4837751314044, 23.35167545825243, 21.74318376928568, 22.53254011273384, 9.770876448601484, 3.124404908157885, 0.576147943502292, 0.050771383830579, 0.20763215463375673, 0.633228124352172, 1.666051831562072, 1.6081421077251434, 4.8764868546277285, 6.55684313736856, 3.8167978171259165, 4.380670934915543, 3.846515309996903, 3.965917727909982, 3.30246739089489, 9.351414106786251, 13.174293022602797, 16.794355921447277, 23.801989294588566, 29.00527998805046, 33.49456429481506, 37.16128773987293, 41.67139492928982, 45.15914797782898, 48.23992006480694, 50.57408161461353, 49.3365678191185, 56.63309209048748, 57.04071141779423, 58.64954508841038, 56.99029952287674, 56.29922680556774, 56.14104889333248, 55.746242478489876, 58.38566444814205, 58.933929428458214, 56.76109962165356, 54.20588493347168, 42.28701129555702, 37.559985145926476, 43.24582904577255, 52.96097293496132, 55.830852538347244, 57.71011009812355, 57.14467003941536, 55.06935440003872, 54.13275025784969, 54.02996577322483, 56.135539188981056, 53.08836489915848, 50.67362107336521, 50.63052758574486, 51.62345990538597, 51.700561568140984, 51.08189396560192, 50.66854074597359, 53.03836338222027, 50.62375634908676, 49.40682604908943, 45.880258083343506, 43.98639790713787, 37.94259041547775, 30.55991716682911, 20.3694149851799, 16.520970091223717, 6.8372034933418036, 4.66300860978663, 6.21960885822773, 7.527699116617441, 6.065937979146838, 4.140215562656522, 4.819955388084054, 2.7139647072181106, 3.8688172632828355, 1.674681049771607, 3.0109247099608183, 0.3464586701011285, 0.12043789945892058, 0.24174923251848668, 1.528750117868185, 3.888447959907353, 12.21966264769435, 19.5943021774292, 25.025297552347183, 24.271290712058544, 37.39725507795811, 48.62814903259277, 42.95283816754818, 32.99665421247482, 10.182995684444904, 1.5228183986619115, 0.05138910302775912, 0.09455434890696779, 0.032772859194665216, 0.03823170787654817, 0.020793792318727355, 0.02436455793940695, 0.008376240475627128, 0.017769807709555607, 0.05633938388200477, 0.024576385440013837, 0.037978223626851104, 0.007292566642718157, 0.017309199320152402, 0.02274967984703835, 0.020609873281500768, 0.017594056007510517, 0.04434177630173508, 0.03519552235957235, 0.046502127370331436, 0.07463738365913741, 0.03307548846350983, 0.04538204098935239, 0.02871970686101122, 0.07813401243765838, 0.08079635590547696, 0.006524058808281552, 0.03130513599899132, 0.030246078276832122, 0.07095362976542674, 0.015094758673512843, 0.04482939330046065, 0.012646588820643956, 0.050518534117145464, 0.10937893428490497, 0.09821617975831032, 0.12637928884942085, 0.19598641782067716, 0.17459838971262798, 0.19888530601747334, 0.18741324660368264, 0.129757470858749, 0.14702386310091242, 0.25763885176274925, 0.1996799829066731, 0.2037443101289682, 0.15471644641365856, 0.15067693660967052, 0.131928876216989, 0.09804146335227415, 0.07769502466544509, 0.15139150607865304, 0.14841354946838692, 0.1904760010074824, 0.0997752019611653, 0.1029894212842919, 0.12529355648439378, 0.11776328086853027, 0.20907313824864104, 0.1017397410760168, 0.10836179120815359, 0.15638100943760946, 0.13817614177241921, 0.21592761419015005, 0.1103012086241506, 0.2070014478522353, 0.31901018985081464, 0.16305097262375057, 0.16071473626652732, 0.09029280336108059, 0.10268367128446698, 0.251416566898115, 0.16458591213449836, 0.1601954406942241, 0.11798394363722764, 0.8970354404300451, 11.345541402697563, 31.936970874667168, 57.075525149703026, 61.53003752231598, 51.304869800806046, 37.32963390648365, 35.696492940187454, 28.23319371789694, 26.84126950800419, 25.52907072007656, 11.49897051975131, 5.082610119134188, 1.184069663286209, 0.3872547356877476, 0.41338715062011033, 1.3135874946601689, 3.8971580425277352, 5.104898298159242, 6.952106952667236, 10.249615609645844, 12.700599040836096, 15.556795578449965, 10.363012924790382, 7.53505552187562, 4.840869465842843, 8.300561495125294, 13.48069528117776, 16.531064249575138, 23.191462755203247, 29.395824931561947, 34.129533022642136, 37.26843439042568, 40.76046600937843, 46.2135723978281, 48.62674690783024, 52.78553254902363, 51.48224428296089, 58.23559910058975, 57.96070285141468, 59.40866835415363, 57.714521661400795, 58.84000226855278, 57.79897592961788, 55.32881207764149, 57.512817084789276, 60.16205012798309, 58.74288707971573, 52.537063881754875, 45.41860945522785, 44.11677651107311, 47.38257206976414, 52.48271159827709, 56.91494956612587, 57.66094833612442, 56.77890546619892, 55.05166254937649, 56.3400062173605, 56.41905337572098, 57.60524332523346, 54.90116022527218, 50.288108959794044, 52.44754448533058, 52.875671312212944, 53.83923880755901, 52.22816705703735, 54.1768354922533, 54.77207355201244, 53.28684724867344, 52.374675795435905, 49.69156377017498, 49.41996194422245, 43.67938958108425, 37.47741937637329, 24.433754794299603, 18.051237277686596, 10.432214811444283, 6.133755790069699, 11.460779719054699, 12.61955888941884, 11.312325485050678, 10.8222078345716, 11.084088832139969, 8.493530340492725, 5.808519842103124, 8.073845710605383, 4.5858836732804775, 0.5158078344538808, 0.6498716468922794, 0.702365948818624, 2.1602239832282066, 5.558271920308471, 15.739466026425362, 27.556043453514576, 32.74085193872452, 33.45897160470486, 48.25047209858894, 53.99268597364426, 49.86057870090008, 37.93159760534763, 12.858460620045662, 1.6830886923708022, 0.1443779730470851, 0.14672407996840775, 0.14493529626633972, 0.38653586176224053, 0.06645142057095654, 0.10746768879471347, 0.0890427001286298, 0.11493315265397541, 0.14552926673786715, 0.09903647558530793, 0.12885841832030565, 0.12739490310195833, 0.10838631176739, 0.10611592617351562, 0.1586675812723115, 0.09377735739690252, 0.13265741290524602, 0.12758848490193486, 0.13676522998139262, 0.20131833327468485, 0.11814334211521782, 0.18319925788091496, 0.12199712204164825, 0.18654502287972718, 0.15600257349433377, 0.15757830144139007, 0.09067130609764718, 0.1395860590855591, 0.2634292363654822, 0.05331915454007685, 0.2521360939135775, 0.2087386671337299, 0.10507349812542088, 0.17200161499204114, 0.21999514749040827], [0.03596935232053511, 0.0456947189377388, 0.03606280355597846, 0.04822504175535869, 0.03610817475419026, 0.020646602170018014, 0.02701639816223178, 0.014103001685725758, 0.016752813062339555, 0.04451390261237975, 0.024467629264108837, 0.030843863387417514, 0.07108565041562542, 0.048147027191589586, 0.04348962378571741, 0.013332946473383345, 0.03506463719531894, 0.055743079356034286, 0.06709519657306373, 0.028892232076032087, 0.10252182371914387, 0.045539676866610534, 0.0359579566429602, 0.0626994261983782, 0.060768402472604066, 0.08237354588345625, 0.05634302411635872, 0.06463131823693402, 0.08449954664683901, 0.0324673318391433, 0.032714103363105096, 0.05460856933495961, 0.02636035260366043, 0.07179343665484339, 0.010916892133536749, 0.04019357525976375, 0.0110440285243385, 0.09230324430973269, 0.10397108970209956, 0.08742621343117207, 2.66875259578228, 19.032299034297466, 35.36602847278118, 48.61206069588661, 36.46448113024235, 34.525988548994064, 28.116610273718834, 27.443930469453335, 26.965055465698242, 17.19452764838934, 14.469176139682531, 5.078944740816951, 0.9596595831681043, 0.24904018035158515, 0.3371753229293972, 0.9680077945813537, 1.7506002634763718, 1.0487203323282301, 4.07690335996449, 3.294220408424735, 2.8937021875754, 2.5913611985743046, 2.5521370908245444, 2.091045370325446, 3.1706242030486465, 8.066958580166101, 4.15070584975183, 6.622099885717034, 10.098832100629807, 16.718266904354095, 22.420353032648563, 24.99758753925562, 29.75524004548788, 34.9623267352581, 37.22689501941204, 41.466000750660896, 43.0394621193409, 46.91708564758301, 53.65325778722763, 50.38112036883831, 56.32667653262615, 53.667822405695915, 54.345683231949806, 52.551290318369865, 54.04448099434376, 47.980302795767784, 55.47641135752201, 55.3798471391201, 56.723496839404106, 33.706714510917664, 38.82950082421303, 46.562070697546005, 57.373083382844925, 58.884418085217476, 50.77400028705597, 52.84495756030083, 53.350976407527924, 53.42089265584946, 50.59760995209217, 48.83464515209198, 48.26384358108044, 47.14005388319492, 45.80270044505596, 47.00439356267452, 46.93175666034222, 48.05606313049793, 48.57922665774822, 44.904348850250244, 42.58074313402176, 37.87819907069206, 34.56969380378723, 26.31936751306057, 24.180374890565872, 21.327883154153824, 13.940503858029842, 5.322449924424291, 3.448185296729207, 6.093260888010263, 6.94257658906281, 3.07266213465482, 2.332382295280695, 4.024767782539129, 1.480868412181735, 2.9987040907144547, 0.5743576458189636, 1.3568593352101743, 0.937096334528178, 0.15857549558859318, 0.6009950477164239, 1.4874886069446802, 5.68687554448843, 16.351010911166668, 19.767591878771782, 24.646497778594494, 31.954548731446266, 36.45848125219345, 38.31173300743103, 40.85983447730541, 18.107371665537357, 6.948661487549543, 0.6746067758649588, 0.04857141691900324, 0.046280804090201855, 0.02344271033507539, 0.06214811437530443, 0.08216958143748343, 0.055806447635404766, 0.027892475663975347, 0.05417044987552799, 0.08948224451160058, 0.03762400025152601, 0.038114144263090566, 0.06482056589447893, 0.012665575741266366, 0.05085164710180834, 0.05723392416257411, 0.021542090544244274, 0.03778055259317625, 0.012944536065333523, 0.03849687724141404, 0.08194108901079744, 0.06596350300242193, 0.05148378993908409, 0.04087176093889866, 0.006342674669213011, 0.04586619215842802, 0.0451548770070076, 0.028383419339661486, 0.07655776498722844, 0.036793433100683615, 0.035027373960474506, 0.02045895755145466, 0.08047317285672761, 0.022319375202641822, 0.018887300284404773, 0.07217185775516555, 0.033627642624196596, 0.1217650821490679, 0.015196611020655837, 0.06582147820154205, 0.11025456464267336, 0.013427798512566369, 0.015298278758564265, 0.027033413753088098, 0.04562972535495646, 0.015633188668289222, 0.09916444410919212, 0.034729576073004864, 0.013441871487884782, 0.037373955856310204, 0.031103904511837754, 0.05001113888283726, 0.060481083710328676, 0.05193229946598876, 0.12216181945404969, 0.033036444074241444, 0.06813497515395284, 0.03746608235815074, 0.013629547647724394, 0.06380550083122216, 0.03034471155842766, 0.1093753868190106, 0.003976795078415307, 0.044156161457067356, 0.035000485950149596, 0.06765839018044062, 0.013949442982266191, 0.05737776722526178, 0.04524692187260371, 0.03308578205178492, 0.027144693231093697, 0.01696490031463327, 0.04365575725387316, 0.09085736994165927, 0.03134667029371485, 0.1000834529986605, 4.670103304088116, 23.164689391851425, 43.627066388726234, 54.153519943356514, 44.19500291347504, 34.32603567838669, 31.2886705622077, 27.86886926740408, 27.960149869322777, 22.04270839691162, 15.28070144355297, 5.880409609526396, 1.0827643680386245, 0.2973568736342713, 0.07766895301756449, 0.26619646756444126, 1.011782989371568, 2.2520173201337457, 2.0317823253571987, 3.4328519320115447, 3.9133549109101295, 4.370819488540292, 2.4463194189593196, 5.395016530528665, 4.341270374134183, 2.7934262808412313, 5.8695844653993845, 8.195528481155634, 13.534234408289194, 20.338857024908066, 23.619183003902435, 28.55853036046028, 32.07537084817886, 37.620132118463516, 39.9123515188694, 43.312811851501465, 47.38083176314831, 50.41357822716236, 54.72339056432247, 53.74234400689602, 59.11214366555214, 55.926611199975014, 56.83487266302109, 55.132575407624245, 54.79435935616493, 53.689192458987236, 57.62359634041786, 56.10681653022766, 56.81167110800743, 37.636098861694336, 41.58685326576233, 49.141410291194916, 57.11891122162342, 59.575585797429085, 53.30213762819767, 52.76233099400997, 53.58595199882984, 53.84768195450306, 51.355916261672974, 49.95729871094227, 49.43391479551792, 48.92476111650467, 47.27617397904396, 47.63168290257454, 50.13883017003536, 50.11595919728279, 49.7871932387352, 48.80065977573395, 47.159075662493706, 42.83300779759884, 42.34963573515415, 32.904087379574776, 28.969197124242783, 22.392903305590153, 16.124981939792633, 6.261817468330264, 4.8472274746745825, 6.206822544336319, 4.4252643920481205, 5.762095358222723, 3.285886743105948, 4.290002100169659, 4.532888391986489, 2.9771675588563085, 1.4906728360801935, 1.354360613040626, 0.10532534593949094, 0.1590260534430854, 0.31700873631052673, 1.7936409101821482, 6.35647133924067, 16.446089409291744, 23.531346917152405, 25.75856890529394, 34.893280640244484, 42.887698262929916, 43.07569317519665, 44.75336395204067, 22.637974955141544, 8.548678681254387, 0.7395099650602788, 0.04186156700598076, 0.026126665143237915, 0.0037632133262377465, 0.06651281844824553, 0.025634111007093452, 0.07855994583223946, 0.03161242595524527, 0.06318831598036923, 0.029834494307579007, 0.05558056014706381, 0.016075723906396888, 0.0866739651246462, 0.021196249726926908, 0.03174399018462282, 0.013521913970180321, 0.006184459916767082, 0.04973832539690193, 0.02700898596231127, 0.030896782227500807, 0.07999130379175767, 0.041365107317687944, 0.022080238522903528, 0.036330410875962116, 0.0326204851444345, 0.04562256362987682, 0.021795185166411102, 0.08882705427822657, 0.05168313822650816, 0.06343096116324887, 0.04929993134282995, 0.03776986566663254, 0.028764048329321668, 0.09265866625355557, 0.08886225434252992, 0.01248181812115945, 0.10419105485198088, 0.16508286906173453, 0.1149583411461208, 0.12217542302096263, 0.2676963183330372, 0.15604943269863725, 0.1387419700040482, 0.12219569849548861, 0.08551120525225997, 0.1506691737449728, 0.09865642918157391, 0.1231222550268285, 0.08948985152528621, 0.18237710668472573, 0.182448664563708, 0.16920033405767754, 0.11839356462587602, 0.18277366587426513, 0.230407434864901, 0.10476828989339992, 0.15383980673504993, 0.12380079322610982, 0.1836180518148467, 0.12338398824795149, 0.17894203163450584, 0.18831985420547426, 0.1777316481457092, 0.12368231677100994, 0.1321705788723193, 0.16528050298802555, 0.054209264199016616, 0.20641350361984223, 0.13615113246487454, 0.10229351682937704, 0.14927708281902596, 0.11760830559069291, 0.222302989277523, 0.16998056875308976, 0.22130702709546313, 0.2773520752089098, 5.052580330520868, 25.121895968914032, 48.41715395450592, 63.44825439155102, 49.30813014507294, 44.863406047225, 42.605787590146065, 41.06068029999733, 37.41109013557434, 25.95857497304678, 18.712741881608963, 8.017201200127602, 1.5701936627738178, 0.609258416807279, 0.8390200941357762, 1.6381342546083033, 3.437910173088312, 3.180858241394162, 8.520189709961414, 11.656891945749521, 9.961767755448818, 8.388979900628328, 7.795759057626128, 6.535651199519634, 6.15496102720499, 10.237613003700972, 5.472524296492338, 9.217875022441149, 12.902388162910938, 17.929298020899296, 25.349999628961086, 27.044761888682842, 31.813449002802372, 39.26303096115589, 41.335690543055534, 42.902137488126755, 46.53369002044201, 51.63665659725666, 56.27819113433361, 54.48751822113991, 59.95948679745197, 55.822139605879784, 57.46808588504791, 56.6461443901062, 54.696947783231735, 54.6573843061924, 57.24207021296024, 57.72278241813183, 56.82724267244339, 42.59696066379547, 48.23404178023338, 51.30290910601616, 57.441589906811714, 60.305393636226654, 52.32574962079525, 54.362428933382034, 54.39139477908611, 54.150031730532646, 52.78301328420639, 51.5921837836504, 50.5914580821991, 50.97925007343292, 48.74227590858936, 48.477346524596214, 50.767016261816025, 51.60852290689945, 52.02662967145443, 49.320262894034386, 48.614085987210274, 46.84314161539078, 46.77748113870621, 40.92092379927635, 36.00227013230324, 30.974178537726402, 18.935869708657265, 9.875043109059334, 6.959815789014101, 13.730759862810373, 12.574901785701513, 13.633706420660019, 6.4395154081285, 5.197518803179264, 6.601242329925299, 6.492075612768531, 4.124248344451189, 2.875408544205129, 2.1038162475451827, 0.4247706866590306, 1.2103230482898653, 2.0481105241924524, 8.434624001383781, 23.17476835101843, 27.588389217853546, 36.321187019348145, 43.16067561507225, 49.59137834608555, 50.018300637602806, 51.729968190193176, 27.087699584662914, 10.45620197430253, 0.9823809389490634, 0.0811643127235584, 0.09468659220146947, 0.14807279978413135, 0.203908265393693, 0.1553840676206164, 0.24499421386281028, 0.10316026367945597, 0.2027711467235349, 0.23923566739540547, 0.11539683167939074, 0.10893659942667, 0.20743177476106212, 0.13171659229556099, 0.17783773073460907, 0.11547559581231326, 0.1069903839379549, 0.15400031843455508, 0.11797632920206524, 0.10421992439660244, 0.34163833188358694, 0.17960563040105626, 0.10941600456135347, 0.12716866680420935, 0.22649662831099704, 0.2269431043532677, 0.07096065048244782, 0.18670681107323617, 0.1144154007488396, 0.17621498031076044, 0.15139610739424825, 0.08243003816460259, 0.16621111164567992, 0.18920971895568073, 0.13331804308108985, 0.2911184396361932], [0.033159729646285996, 0.008164719110936858, 0.01093050961571862, 0.0397714639257174, 0.03156694343488198, 0.03637863563199062, 0.026856717668124475, 0.003187954484928923, 0.10458382908836938, 0.015684166792198084, 0.02006797931244364, 0.021685341744159814, 0.02964722632896155, 0.05308696621796116, 0.03248562949011102, 0.06657521822489798, 0.05339526920579374, 0.10192604982876219, 0.01820081739424495, 0.033865244913613424, 0.08705246786121279, 0.009741321864566999, 0.02816345790051855, 0.037770730268675834, 0.013194743733038194, 0.03540714948030654, 0.04346373396401759, 0.06741258344845846, 0.04676765667682048, 0.00391830642001878, 0.03222170322260354, 0.07158107109717093, 0.04016226404928602, 0.010829331695276778, 0.022504824919451494, 0.04267227428499609, 0.07379402930382639, 0.03176729362166952, 0.037954860817990266, 0.0737650335940998, 0.5486765457317233, 10.949096325784922, 22.96134900301695, 41.673074439167976, 39.924336075782776, 37.23092660307884, 27.452348917722702, 23.028343208134174, 24.02855023741722, 25.044309832155704, 15.459304209798574, 5.496769370511174, 2.8317265631631017, 0.5270172329619527, 0.13150634185876697, 0.11553470787475817, 0.7174569577910006, 1.8992587365210056, 1.6928402753546834, 3.6218908382579684, 1.469822523649782, 2.224005223251879, 2.383230929262936, 4.495552545413375, 1.9146770029328763, 2.138173053972423, 3.424528003670275, 2.3631031718105078, 6.7283958569169044, 7.648925436660647, 12.850438300520182, 16.977844275534153, 22.257839553058147, 23.17963019013405, 28.483552783727646, 27.222698740661144, 36.07314392924309, 36.59897491335869, 45.6753084808588, 47.8116450458765, 51.13784596323967, 54.42960172891617, 54.90344390273094, 51.94122925400734, 54.25500109791756, 55.42482152581215, 52.93294183909893, 45.74758820235729, 41.19213804602623, 45.93763880431652, 45.26089131832123, 55.75782045722008, 49.579215198755264, 54.09031793475151, 55.215300768613815, 54.96251553297043, 53.034802973270416, 51.86171852052212, 49.75783981382847, 49.396410807967186, 46.82557135820389, 46.06430880725384, 48.581586331129074, 49.472524523735046, 49.16524641215801, 50.21707557141781, 47.82334841787815, 41.48897051811218, 38.51692199707031, 27.248655147850513, 23.087108954787254, 25.841170772910118, 21.92611925303936, 16.207638904452324, 9.01824513450265, 5.633320743218064, 2.7008839091286063, 2.1008799551054835, 4.7733385395258665, 4.047548985108733, 2.7397681726142764, 5.041023725643754, 2.192946639843285, 2.9171616537496448, 0.737192208180204, 2.26096726488322, 0.1640957681229338, 0.17634104151511565, 0.7396038912702352, 4.5518821477890015, 7.3321283608675, 11.891880836337805, 19.748068526387215, 31.6983512789011, 30.316059552133083, 37.14855842292309, 39.41238574683666, 29.054462648928165, 16.504269987344742, 3.021121700294316, 0.11675767818815075, 0.049114579960587434, 0.02659302332176594, 0.06681784856482409, 0.010022789720096625, 0.01515888858193648, 0.03192351199686527, 0.03680674351926427, 0.04250253026839346, 0.025849092635326087, 0.058451480508665554, 0.07677652785787359, 0.02723101613810286, 0.07916630274849012, 0.03354911968926899, 0.03669453079055529, 0.046699186132173054, 0.04874124257185031, 0.05683057061105501, 0.08827644007396884, 0.07041478602332063, 0.05642833399178926, 0.031143403466558084, 0.035758307785727084, 0.05610476502624806, 0.015058722765388666, 0.04734161513624713, 0.03618685725086834, 0.10570366313913837, 0.027204912948946003, 0.06849255674751475, 0.06242639748961665, 0.049813248915597796, 0.019075347518082708, 0.033153117110487074, 0.07674235195736401, 0.017000046573230065, 0.05655188302625902, 0.016220255311054643, 0.045047380626783706, 0.10828534257598221, 0.04351963994849939, 0.0544880185771035, 0.03076402314036386, 0.10123251282493584, 0.023314821592066437, 0.03264028193370905, 0.006083007865527179, 0.06758618663297966, 0.04517448083788622, 0.02756598449195735, 0.03577151059289463, 0.057852890167851, 0.018913355233962648, 0.030440469017776195, 0.18612498213769868, 0.1116947022092063, 0.02142726916645188, 0.01768657770298887, 0.007605680139022297, 0.01638445919525111, 0.010387043221271597, 0.02531791713408893, 0.026717837718024384, 0.04327692055085208, 0.04193920307443477, 0.05381454924645368, 0.020706818177131936, 0.09185261966194957, 0.03758725280931685, 0.06405933017958887, 0.04089216628926806, 0.13149238948244601, 0.02426113780529704, 0.02285593312990386, 0.1701209830935113, 0.7713505940046161, 13.672669529914856, 28.13559215515852, 49.88616272807121, 43.58830846846104, 43.12283344566822, 32.47437223792076, 28.563278205692768, 28.472936153411865, 27.232091836631298, 19.803070574998856, 6.400949377566576, 2.874714843928814, 0.5490893579553813, 0.10697517733206041, 0.09530408133286983, 0.2650449809152633, 0.7922597439028323, 1.1133384774439037, 1.982389132026583, 2.900671251118183, 4.259719625115395, 3.6370135517790914, 4.256303608417511, 5.126050813123584, 3.44636756926775, 4.0937858540564775, 5.1778520084917545, 9.083652924746275, 11.38342346996069, 18.048168942332268, 19.0945852920413, 25.956656076014042, 24.99596882611513, 31.560973450541496, 30.946242436766624, 38.551268354058266, 38.539109006524086, 48.9429697394371, 50.34032575786114, 52.271199747920036, 55.8722323179245, 57.00554050505161, 53.53091575205326, 55.99702142179012, 54.0816505998373, 55.85498884320259, 46.46578386425972, 45.270827785134315, 51.692897379398346, 49.40861955285072, 54.378095492720604, 52.4268963932991, 56.100113689899445, 56.03148557245731, 56.180798560380936, 54.28451031446457, 53.87011215090752, 51.846032962203026, 50.66855974495411, 48.746470883488655, 49.68045696616173, 49.38892140984535, 51.72340214252472, 51.319806799292564, 53.397018536925316, 49.60340850055218, 45.91618895530701, 43.31105634570122, 35.541807040572166, 34.76724520325661, 33.89294631779194, 28.07403165847063, 20.065537691116333, 15.109311640262604, 7.104391381144524, 3.7500351620838046, 2.7373769134283066, 5.036398898810148, 5.013560224324465, 3.4516863338649273, 5.238839210942388, 3.31354355905205, 2.0188003219664097, 0.7298567611724138, 0.2763235179008916, 0.14643866481492296, 0.14330099802464247, 0.8282118116039783, 3.6143494304269552, 7.5854013953357935, 14.945976454764605, 19.399313740432262, 33.19104038178921, 36.022865027189255, 39.58922825753689, 44.76947508752346, 35.478563234210014, 19.963338375091553, 4.075513109564781, 0.26208413823042065, 0.07607043371535838, 0.02182582287787227, 0.03520409416523762, 0.09841198057984002, 0.08256809247541241, 0.06500907882582396, 0.06556216438184492, 0.1393638749141246, 0.052060601956327446, 0.04903458757326007, 0.047257288606488146, 0.04618590937752742, 0.047481881047133356, 0.05071010840765666, 0.008561622471461305, 0.038661971702822484, 0.051885206485167146, 0.015420225681737065, 0.049280004677711986, 0.08354284407687373, 0.009313425489381189, 0.0357458879443584, 0.03120790352113545, 0.05768290866399184, 0.021811757324030623, 0.044673475495073944, 0.046209320425987244, 0.017299543978879228, 0.08686736138770357, 0.12558553222334012, 0.04954541152983438, 0.07714627325185575, 0.04510686747380532, 0.030669445695821196, 0.023956304357852787, 0.21059776190668344, 0.10413192052510567, 0.10292316976119764, 0.15412758191814646, 0.14503599086310714, 0.0791363867756445, 0.09467615018365905, 0.07740278917481191, 0.1581038162112236, 0.1310676583671011, 0.1375062347506173, 0.09385070385178551, 0.1330574305029586, 0.15585933899274096, 0.07864492916269228, 0.08748001913772896, 0.11230538584641181, 0.16089543438283727, 0.09691684244899079, 0.22394524334231392, 0.20157471561105922, 0.08111000235658139, 0.07178308369475417, 0.09079324096092023, 0.1817389190546237, 0.11754857012419961, 0.08579538101912476, 0.16840371274156496, 0.09909828164381906, 0.14884506381349638, 0.19159042480168864, 0.16799239965621382, 0.19363649626029655, 0.1266169987502508, 0.1488397500361316, 0.13301431172294542, 0.19302683678688481, 0.14531398453982547, 0.17009683360811323, 0.3394120075972751, 1.3139997725374997, 15.759790185838938, 32.830245941877365, 55.32743275165558, 52.99861751496792, 50.43664298951626, 40.26889778673649, 34.56588260829449, 34.81274776160717, 34.848724231123924, 23.112776577472687, 8.627607095986605, 3.9873749390244484, 1.035635496955365, 0.3203211195068434, 0.4076159431133419, 2.116636522114277, 4.149806248024106, 5.3340117540210485, 6.72001208178699, 7.614869764074683, 6.15413979627192, 6.872986173257232, 8.863800521939993, 3.633493515662849, 3.9060334162786603, 6.329614380374551, 5.151518946513534, 8.671419695019722, 11.674703489989042, 17.2256650775671, 20.081842616200447, 27.190913446247578, 25.57539213448763, 31.500543393194675, 32.653836607933044, 40.32079920172691, 39.82663191854954, 50.053045973181725, 51.32673002779484, 53.0070910602808, 56.53930552303791, 58.423149436712265, 55.11991448700428, 57.5058900564909, 54.49364349246025, 55.283697098493576, 50.864492431283, 50.11512704193592, 53.39137963950634, 52.962660044431686, 57.80953176319599, 52.81141676008701, 57.73697845637798, 56.61100007593632, 56.679092422127724, 54.45077799260616, 53.939416632056236, 52.330529764294624, 53.59376057982445, 48.37568677961826, 49.81013260781765, 51.009454652667046, 51.20241589844227, 52.57013350725174, 53.63237410783768, 50.589003413915634, 45.497341230511665, 45.276607275009155, 36.68107710778713, 36.0703244805336, 36.9694360345602, 32.218904346227646, 23.231320716440678, 15.479654017835855, 7.3143011424690485, 7.745003281161189, 7.668520985171199, 11.351916510611773, 14.639535248279572, 11.003765892237425, 13.837875165045261, 5.837252475321293, 6.733651924878359, 2.4988197768107057, 3.9256356144323945, 0.588895546970889, 0.52510243258439, 1.2301738956011832, 6.394436527043581, 11.29067424684763, 19.034757502377033, 29.950431771576405, 44.30139720439911, 41.13289162516594, 47.280878126621246, 53.99848446249962, 39.673906713724136, 22.117794267833233, 4.589844960719347, 0.40174911729991436, 0.18327512021642178, 0.15463154471945018, 0.1022923961863853, 0.18811319576343521, 0.0935856087016873, 0.09579340898199007, 0.19157748174620792, 0.2000069138011895, 0.1762392040109262, 0.17320003506029025, 0.15997876325855032, 0.11807750619482249, 0.22138942033052444, 0.20027928199851885, 0.12919755012262613, 0.13439720001770183, 0.13372729299589992, 0.15857484249863774, 0.14122972323093563, 0.19384731072932482, 0.12209392778459005, 0.09598143951734528, 0.16453501564683393, 0.17522939335322008, 0.10950276904623024, 0.10148896195460111, 0.17428235354600474, 0.15510344674112275, 0.15333375107729807, 0.24585139442933723, 0.255791824311018, 0.13563703192630783, 0.13676938600838184, 0.13919484335929155, 0.19588501076214015], [0.0767922391241882, 0.02466577341692755, 0.04375846678158268, 0.043818246776936576, 0.03902175747498404, 0.041486084810458124, 0.05292071771691553, 0.08225362966186367, 0.06825591553933918, 0.03351803854457103, 0.019170756168023217, 0.05771108058979735, 0.014415110963454936, 0.02876351212762529, 0.0379741084179841, 0.0836482438899111, 0.01372339222143637, 0.01956920783413807, 0.08582351583754644, 0.056050146667985246, 0.03768371345358901, 0.046992679563118145, 0.03518202640407253, 0.032819863117765635, 0.0501471522875363, 0.05005393111787271, 0.049403483208152466, 0.08278600929770619, 0.01414719657987007, 0.042876431689364836, 0.018259487878822256, 0.030080729629844427, 0.03238394783693366, 0.051119209892931394, 0.08891120640328154, 0.011856375022034626, 0.020718891064461786, 0.03706661766045727, 0.029128455826139543, 0.05023469973821193, 0.07526587141910568, 3.89380163513124, 17.031079418957233, 32.12701767683029, 40.26797443628311, 32.93734699487686, 26.783548705279827, 23.871094286441803, 24.165825471282005, 19.814602956175804, 17.7313856408, 10.66614830866456, 4.4808354601264, 1.1194966407492757, 0.2222053226432763, 0.22802778286859393, 0.4915743973106146, 1.0027520614676178, 0.44050605793017894, 1.010346666444093, 1.0379090812057257, 3.090654881671071, 2.0505718421190977, 4.914962640032172, 7.463556658476591, 0.739681787090376, 2.5220488803461194, 1.3293572422116995, 2.877324828878045, 5.765811558812857, 8.62878693267703, 10.295569393783808, 13.760090488940477, 16.1441633105278, 20.988390371203423, 22.93822344392538, 24.44382805377245, 31.47254079580307, 30.8005278557539, 43.78938987851143, 46.35969735682011, 49.15671966969967, 52.910564839839935, 54.82780896127224, 54.82112132012844, 54.09101329743862, 54.20063741505146, 51.55004024505615, 48.16711597144604, 47.73517794907093, 48.38513687252998, 51.10860653221607, 51.68801464140415, 55.31728729605675, 54.116373136639595, 54.01470199227333, 53.7907800078392, 50.21257281303406, 49.851504787802696, 50.03964029252529, 49.11207586526871, 51.152266189455986, 51.10827594995499, 51.24387547373772, 49.02525432407856, 45.92078670859337, 42.298657670617104, 31.75261616706848, 27.930030785501003, 22.34084989875555, 15.75826171785593, 9.521461632102728, 10.777404438704252, 7.9054230730980635, 4.6432924177497625, 3.9903558790683746, 3.043194003403187, 0.6857819762080908, 0.764937725616619, 2.0897800382226706, 2.900723498314619, 4.819057686254382, 5.406894218176603, 0.9292026737239212, 0.2600516035454348, 0.059597289728117175, 0.29745617299340665, 0.7641299127135426, 1.3786745583638549, 4.686551671475172, 8.907515276223421, 16.893644593656063, 29.64451588690281, 29.259349554777145, 30.381011366844177, 35.49162693321705, 38.405789360404015, 25.136048309504986, 8.826017249375582, 1.5920147043652833, 0.05426600881037302, 0.01259161886991933, 0.06854580584331416, 0.02731664884777274, 0.03406277493922971, 0.033272213258896954, 0.026504460984142497, 0.07986090844497085, 0.12370765369269066, 0.06528834157506935, 0.039052664214977995, 0.043723801063606516, 0.07133737948606722, 0.03223498766601551, 0.06266403317567892, 0.007352732091021608, 0.03970705292886123, 0.01127512588936952, 0.08192186738597229, 0.002917797191912541, 0.05059215516666882, 0.023913671684567817, 0.05849651402968448, 0.052763753483304754, 0.07230028641060926, 0.010710140923038125, 0.028245237008377444, 0.014353763181134127, 0.010324539543944411, 0.07524488348281011, 0.020686685566033702, 0.003966424492318765, 0.05056238020188175, 0.08116777113173157, 0.02255685132695362, 0.07621488533914089, 0.026472903009562287, 0.08530002713087015, 0.03807532993960194, 0.03721068336744793, 0.03157076920615509, 0.09215189071255736, 0.050252804430783726, 0.09609421627828851, 0.05036383714468684, 0.03249537017836701, 0.04557873238809407, 0.02016717477090424, 0.010158969180338318, 0.07515664954553358, 0.03669099445687607, 0.07955502485856414, 0.029894808649260085, 0.06427349173463881, 0.04558951208309736, 0.014506374718621373, 0.017535836377646774, 0.06445365550462157, 0.054580801879637875, 0.039631765757803805, 0.023829358142393176, 0.06370027913362719, 0.06656660931184888, 0.007669327187613817, 0.036391459943843074, 0.030757807653571945, 0.032730523380450904, 0.0425722364889225, 0.04051367468491662, 0.06946064386283979, 0.021880318781768437, 0.03820278638158925, 0.014075505114305997, 0.03332146588945761, 0.013689746956515592, 0.06004586233757436, 0.0961470275069587, 6.65154118090868, 20.77168609946966, 38.89416575431824, 47.10708685219288, 40.49839027225971, 29.330812320113182, 26.511568799614906, 25.360521264374256, 21.640501879155636, 18.803416416049004, 11.228081155568361, 4.831712432205677, 0.9040755720343441, 0.23453987640095875, 0.20752423151861876, 0.364709387649782, 0.12301646187552251, 0.5212095414754003, 0.9291492390912026, 3.5431999107822776, 4.785222401842475, 4.81969035230577, 2.4397137109190226, 6.568047786131501, 3.523096852004528, 1.8634532578289509, 3.9857077784836292, 6.599624566733837, 7.878875797614455, 11.663608085364103, 14.800023436546326, 17.433702014386654, 17.850790433585644, 23.74484036117792, 24.857979230582714, 26.667463034391403, 32.52576068043709, 35.06928339600563, 44.67212811112404, 49.15338724851608, 52.06975735723972, 54.27737429738045, 55.068408250808716, 55.53378067910671, 55.10464310646057, 55.01615725457668, 52.009055614471436, 49.850604236125946, 51.30939535796642, 52.427181378006935, 55.54099649190903, 52.18733064830303, 56.13293632864952, 56.59169711172581, 54.8060817271471, 54.63634103536606, 53.27130988240242, 51.71854980289936, 52.196218371391296, 51.8830543756485, 51.74076721072197, 53.21593165397644, 52.77791775763035, 52.64492869377136, 48.05490419268608, 43.1734961271286, 35.758972987532616, 31.972495168447495, 24.44784253835678, 17.53028143197298, 13.948430232703686, 16.65101621299982, 13.025871086865664, 6.8472677282989025, 3.907935689203441, 4.388374546542764, 2.3540627444162965, 4.5286687184125185, 6.47397480905056, 3.8325154362246394, 2.7594069438055158, 1.3667110190726817, 0.7519930077251047, 0.4281314281979576, 0.17712722823489457, 0.07154561128118075, 0.46873135899659246, 1.684966622851789, 4.972096374258399, 9.450043514370918, 18.642605245113373, 29.04601950198412, 34.89043079316616, 32.825264409184456, 40.96712552011013, 44.2486522346735, 29.602547138929367, 10.522905495017767, 2.106356411240995, 0.05661671333655249, 0.03264729893999174, 0.04348905975348316, 0.041786806759773754, 0.04455604917893652, 0.00982816056421143, 0.037124920781934634, 0.027787216858996544, 0.06021947294357233, 0.04416544943524059, 0.11133705382235348, 0.01552622756207711, 0.030424629730987363, 0.07296287585631944, 0.03190269475453533, 0.05725378403440118, 0.04625592730008066, 0.04026958231406752, 0.09171622776193544, 0.04038340921397321, 0.023898943763924763, 0.043588637417997234, 0.05159818087122403, 0.017701526412565727, 0.0316175764601212, 0.04423421683895867, 0.02850738397683017, 0.020605006648111157, 0.1006090865121223, 0.02682649555936223, 0.06124384824943263, 0.026148788565478753, 0.005224575388638186, 0.01776245673681842, 0.05095978543977253, 0.07857104094000533, 0.16657743573887274, 0.16105294780572876, 0.19670524721732363, 0.09402123454492539, 0.09048245919984765, 0.14942796144168824, 0.17296959820669144, 0.19891576375812292, 0.1928379453602247, 0.11743185998057015, 0.18507125118048862, 0.11184180330019444, 0.16351098543964326, 0.15678620722610503, 0.15445280587300658, 0.1304948836332187, 0.17438371607568115, 0.1544681386440061, 0.13837995036737993, 0.13418479735264555, 0.19189230079064146, 0.12397257072734646, 0.23982732236618176, 0.1397817485849373, 0.1551165827549994, 0.15988338243914768, 0.19546673633158207, 0.0930914942000527, 0.12306711345445365, 0.1473824688582681, 0.0821671323501505, 0.14627205266151577, 0.19878964318195358, 0.17717552720569074, 0.17457578389439732, 0.10964173619868234, 0.26039682095870376, 0.11237789367442019, 0.07422860129736364, 0.14832435816060752, 0.33054705359973013, 7.467462373897433, 25.984628275036812, 44.11116801202297, 56.441681161522865, 46.213386207818985, 40.00515393912792, 36.757339015603065, 36.511249020695686, 29.947002455592155, 26.074711941182613, 15.812550354748964, 6.247193953022361, 2.037823051214218, 0.5789364001248032, 0.34877120226155967, 0.8979684684891254, 2.421545935794711, 1.4297603233717382, 3.053211928345263, 7.219935581088066, 10.172835979610682, 5.038743847981095, 10.971491374075413, 19.203966222703457, 3.77273490652442, 4.896733593195677, 4.145134398713708, 4.235018100589514, 10.268633589148521, 12.948587033897638, 15.750111155211926, 16.607499048113823, 19.887692034244537, 24.01817299425602, 24.89357192069292, 26.757098324596882, 35.206053256988525, 36.330234333872795, 47.457029074430466, 52.14948087930679, 51.67499653995037, 53.80032129585743, 55.603936314582825, 54.99777764081955, 56.32218897342682, 55.21254971623421, 54.0963102132082, 53.3610762655735, 55.363052040338516, 54.11481522023678, 54.39359486103058, 55.3144146502018, 56.76620654761791, 56.96439251303673, 55.41795529425144, 57.15530566871166, 53.901145085692406, 52.87428438663483, 52.908326759934425, 52.130873277783394, 53.969909995794296, 52.06598035991192, 54.751999229192734, 53.38962413370609, 47.28777855634689, 43.17622438073158, 34.288060516119, 30.044349431991577, 24.11949645727873, 19.319761209189892, 13.504639696329832, 15.739939101040363, 10.891369823366404, 7.518829442560673, 7.196165956556797, 6.247322196140885, 3.17084482870996, 6.68704885058105, 6.865638317540288, 6.731901643797755, 11.812712084501982, 12.006602380424738, 4.472034657374024, 1.119133522734046, 0.6267592089716345, 0.4942076560109854, 1.224316272418946, 1.9380474113859236, 7.016526320949197, 13.925085235387087, 25.337752886116505, 39.52741317451, 42.12944895029068, 41.53636537492275, 48.01738880574703, 50.42643293738365, 35.01473732292652, 13.511655069887638, 2.96268321108073, 0.18054256215691566, 0.08876692547346465, 0.2259053592570126, 0.1604414329631254, 0.2144053505617194, 0.22678091540001333, 0.13768500328296795, 0.15289101545931771, 0.18925844837212935, 0.21800170914502814, 0.16845609352458268, 0.18691881297854707, 0.137143072206527, 0.22027459577657282, 0.1527302514296025, 0.14058951695915312, 0.11947737482842058, 0.11922386460355483, 0.16493817995069548, 0.15464754542335868, 0.10040919645689428, 0.15310083545045927, 0.11360206626704894, 0.09561874452629127, 0.2057081664679572, 0.13041241618338972, 0.15626044012606144, 0.07122817987692542, 0.13281666295370087, 0.1766380638582632, 0.13421491370536387, 0.10209482163190842, 0.1145602753967978, 0.17393642367096618, 0.14416695077670738, 0.19984508107881993], [0.012580411512317369, 0.06645352084888145, 0.02557954088842962, 0.07869010369176976, 0.04807726902072318, 0.023964044958120212, 0.08973462667199783, 0.07084189943270758, 0.04003426955023315, 0.034656637799344026, 0.005710548066417687, 0.04133402988372836, 0.08495305824908428, 0.036768185236724094, 0.0845257518813014, 0.06412256858311594, 0.024349781779164914, 0.054447029760922305, 0.06373250318574719, 0.036257023602956906, 0.04994804519810714, 0.022722155445080716, 0.0765755023167003, 0.007085502802510746, 0.015104423291631974, 0.017512423473817762, 0.07242078150738962, 0.003516462907100504, 0.05365018580050673, 0.05608690524240956, 0.03919304144801572, 0.015452098141395254, 0.053418698807945475, 0.02983879134262679, 0.03159540850901976, 0.03550702771462966, 0.053652401111321524, 0.07472793309716508, 0.02538112770707812, 0.049852174561237916, 0.039236149095813744, 1.3286447804421186, 12.210193555802107, 30.054578483104706, 43.357189670205116, 37.76727922260761, 31.757533103227615, 20.799069330096245, 21.69993259012699, 20.611976869404316, 21.298847012221813, 12.416293546557426, 6.369266677647829, 2.618388435803354, 0.521516315639019, 0.27584720752201974, 0.1214647720917128, 0.20081235183170065, 0.2017143729608506, 1.0466432687826455, 3.2013163436204195, 2.390087661333382, 6.220071008428931, 0.7332353142555803, 4.478440163657069, 5.52704899571836, 0.8854282507672906, 3.2912565674632788, 4.836796084418893, 3.142116707749665, 5.418951446190476, 6.436160188168287, 9.674717858433723, 10.551715549081564, 12.289195116609335, 15.48667224124074, 16.2489065900445, 22.152045629918575, 28.701387494802475, 32.90164031088352, 42.01687999069691, 46.70191079378128, 52.100011333823204, 53.68391454219818, 54.572040885686874, 55.7254271954298, 52.124561816453934, 55.924973487854004, 56.832376196980476, 49.31867077946663, 51.329249292612076, 60.13005584478378, 57.14938938617706, 51.93521797657013, 57.77002528309822, 55.0025349855423, 56.000581830739975, 53.61731171607971, 53.38357485830784, 52.14027397334576, 53.10346148908138, 53.768049627542496, 49.17559705674648, 47.762810066342354, 44.06993642449379, 35.957831516861916, 32.4879565089941, 23.75758107751608, 17.253454886376858, 12.406931798905134, 8.837808016687632, 7.036665715277195, 4.529763059690595, 3.456252026371658, 2.1124648209661245, 2.515493519604206, 1.3409068412147462, 2.058979128487408, 4.10665956325829, 4.463400570675731, 1.9166631088592112, 2.128457687795162, 1.0720742354169488, 0.20403532107593492, 0.16409052856033668, 0.1871714400476776, 0.2687004441395402, 0.44725877058226615, 5.008435249328613, 7.496303301304579, 12.70949151366949, 19.405961483716965, 26.748362593352795, 28.910560570657253, 31.892551258206367, 35.61100892722607, 31.83038279414177, 19.11612443625927, 4.514622772112489, 0.45826099114492536, 0.0909900659462437, 0.02120294204360107, 0.02330570245248964, 0.038658164485241286, 0.03826202831987757, 0.015163447224040283, 0.022416613246605266, 0.0407419927068986, 0.06493838925962336, 0.060110128615633585, 0.03252801354392432, 0.03356886823894456, 0.03574707909137942, 0.03483176238660235, 0.053638081371900626, 0.03021913089469308, 0.01696937732049264, 0.05669306920026429, 0.04163135279668495, 0.03314827088615857, 0.023810227430658415, 0.05888819730898831, 0.02139148837159155, 0.009298575114371488, 0.03737283521331847, 0.07060077565256506, 0.03801535698585212, 0.033764936233637854, 0.015339887268055463, 0.06800487666623667, 0.021820883885084186, 0.031693023192929104, 0.12356450082734227, 0.03276862895290833, 0.0171574857813539, 0.036655070798587985, 0.02336353802093072, 0.05107530072564259, 0.0648529086902272, 0.009736951542436145, 0.028333752961771097, 0.06962608342291787, 0.058135507424594834, 0.04134712136874441, 0.012574321262945887, 0.026634665227902588, 0.05333941517164931, 0.034074278228217736, 0.035118650703225285, 0.05203801098105032, 0.035775065480265766, 0.02412061956420075, 0.014595634675060865, 0.023140557896113023, 0.06093798692745622, 0.05561157449847087, 0.04292724283004645, 0.0825242092832923, 0.03998421540018171, 0.0041088491252594395, 0.020708397096314002, 0.04648764064768329, 0.048701452324166894, 0.008126120937959058, 0.06005995943269227, 0.002260508304061659, 0.012533956778497668, 0.06940574719919823, 0.04606388545653317, 0.03199767852493096, 0.01865959453425603, 0.04273095590178855, 0.021028323972132057, 0.04188437320408411, 0.07308103318791837, 0.0818297965452075, 0.055089659144869074, 2.0812530582770705, 16.303306370973587, 34.88589383661747, 48.50522942841053, 44.76287104189396, 37.00598627328873, 25.090494453907013, 25.270823277533054, 22.662911117076874, 24.268024787306786, 14.255843237042427, 7.333132456988096, 2.4806061666458845, 0.5233149253763258, 0.1058302067394834, 0.020803147090191487, 0.5973022396210581, 0.8479820319917053, 1.4745836681686342, 1.6463337396271527, 3.094800696708262, 4.2258767411112785, 1.1472976114600897, 4.894655104726553, 8.77841530367732, 3.514601457864046, 3.150354428216815, 6.850119000300765, 4.169126786291599, 5.944939646869898, 7.988712228834629, 16.48244395852089, 12.787725515663624, 14.97625133022666, 20.20581666380167, 19.569215923547745, 27.83053122460842, 30.629396438598633, 35.8747223764658, 43.94360840320587, 48.5166972130537, 55.13153426349163, 55.43585233390331, 55.621635764837265, 56.875260695815086, 53.44668187201023, 56.16412125527859, 58.618964329361916, 51.953077018260956, 52.57432468235493, 57.273619920015335, 58.667172342538834, 55.883684903383255, 59.012171030044556, 56.784293577075005, 57.14117802679539, 54.91855949163437, 54.66388575732708, 54.96254213154316, 55.0320366024971, 53.281398341059685, 52.86305218935013, 52.06248454749584, 45.83561047911644, 38.19188743829727, 35.73130667209625, 25.056930854916573, 21.714117228984833, 17.707927599549294, 12.880266699939966, 8.165395148098469, 6.570234093815088, 6.266968566924334, 4.5955603290349245, 3.6307842610403895, 2.89992269128561, 3.1005450384691358, 3.481947435066104, 7.298805573955178, 4.20462685637176, 2.953136460855603, 2.103462154045701, 0.3743785625556484, 0.5896095524076372, 0.10608652970404364, 0.10290140999131836, 0.5931538122240454, 4.100928520783782, 8.158316127955914, 12.323816008865833, 18.374947607517242, 27.252943217754364, 31.422176398336887, 35.99150151014328, 40.20971596240997, 38.48606765270233, 23.38210802525282, 6.077094655483961, 0.49726954952348024, 0.07752520643407479, 0.05672279221471399, 0.06942298728972673, 0.02464050328853773, 0.025959531631087884, 0.05198470993491355, 0.02866611637728056, 0.04893302837444935, 0.06337955259368755, 0.030336336421896704, 0.04399855897645466, 0.038356039876816794, 0.035815193405142054, 0.006082602931201109, 0.06030280128470622, 0.07540214457549155, 0.07374242035439238, 0.07974784966791049, 0.058664001917350106, 0.07166489667724818, 0.08549106336431578, 0.01667094860749785, 0.09730036210385151, 0.03413031779928133, 0.02258711425383808, 0.02251501089631347, 0.0671657154452987, 0.054968522090348415, 0.022968184821365867, 0.024893388253985904, 0.007689733001825516, 0.05210327173699625, 0.08941556996433064, 0.010724097937782062, 0.04183570315944962, 0.053743989556096494, 0.09131281854934059, 0.19126772414892912, 0.12180118763353676, 0.14046069496544078, 0.15712278604041785, 0.11644354191957973, 0.15817933715879917, 0.15734724118374288, 0.0926229392644018, 0.1549306302331388, 0.08085865920293145, 0.11361029668478295, 0.14674067439045757, 0.10695706150727347, 0.2735454513458535, 0.11808494251454249, 0.11473566715721972, 0.17615877004573122, 0.1261618098942563, 0.1487203236320056, 0.2063382201595232, 0.19944893749197945, 0.1400807747268118, 0.10862971394089982, 0.1242353577981703, 0.19339160236995667, 0.21903359127463773, 0.08114123193081468, 0.15507996518863365, 0.12302183502470143, 0.09424497722648084, 0.18126262351870537, 0.1565832892083563, 0.16578725626459345, 0.08757133298786357, 0.12201617297250777, 0.2389856378431432, 0.1629823536495678, 0.25985157990362495, 0.17627500521484762, 0.19205034855986014, 3.066115085966885, 18.62716667354107, 39.76357810199261, 56.1998887360096, 52.15685248374939, 44.81093846261501, 33.36520403623581, 34.54388938844204, 31.4525443688035, 30.435477644205093, 17.34252020716667, 10.089709740132093, 3.1502627581357956, 1.1481998255476356, 0.7942371221724898, 0.5056056787725538, 0.8176213048864156, 1.337020481005311, 2.471373612061143, 5.62813307158649, 6.927232537418604, 12.266521733254194, 5.313725117594004, 9.241367261856794, 11.031469255685806, 3.9519028924405575, 5.4592986311763525, 10.684819556772709, 5.382639169692993, 9.267739746719599, 9.581273272633553, 14.369310848414898, 12.5281129963696, 13.74258577823639, 20.277321226894855, 21.590012088418007, 28.28803427517414, 31.690208315849304, 36.228361800312996, 45.736014023423195, 51.14334046840668, 55.816550105810165, 57.95647747814655, 54.74108621478081, 56.95272333920002, 54.35946889221668, 58.39446097612381, 58.386937379837036, 53.61984618008137, 53.85429359972477, 60.384585186839104, 58.987886533141136, 55.80625645816326, 59.681292325258255, 57.450595423579216, 57.906133979558945, 57.06646643579006, 56.54318891465664, 55.29060512781143, 55.46747423708439, 53.059387654066086, 51.62222117185593, 51.175376549363136, 46.935168877243996, 37.1528559923172, 34.2864266037941, 25.684484280645847, 19.421852231025696, 16.423913799226284, 10.763581730425358, 7.7133148815482855, 5.7679247204214334, 5.094730043783784, 3.643659157678485, 3.889960516244173, 3.8898959197103977, 4.780845511704683, 11.277724541723728, 12.569511774927378, 7.920972788706422, 3.2477365527302027, 2.246087738312781, 2.257647905498743, 1.8917740881443024, 0.6401028460823, 0.398738372605294, 0.6603696523234248, 6.806843597441912, 10.833061002194881, 18.620397336781025, 28.69393229484558, 38.499663323163986, 41.00912466645241, 42.70315736532211, 47.96969756484032, 44.231788739562035, 27.474646121263504, 7.097466252744198, 0.7241892465390265, 0.1295865690917708, 0.11309605513815768, 0.1280956092523411, 0.125818700180389, 0.14620298839872703, 0.09596799180144444, 0.11224346846574917, 0.1089293412223924, 0.08773802677751519, 0.14782477403059602, 0.17140774842118844, 0.22166489070514217, 0.07906832441221923, 0.10863291259738617, 0.17201253940584138, 0.19045023364014924, 0.16580022900598124, 0.2305318633443676, 0.1698050062987022, 0.13303700659889728, 0.12845178076531738, 0.15290293435100466, 0.1654932025121525, 0.1751082600094378, 0.10260380877298303, 0.1320629971451126, 0.10004719166317955, 0.14044283889234066, 0.08998867866466753, 0.2919033350190148, 0.10216641661827452, 0.10514662935747765, 0.3638748574303463, 0.10899930348386988, 0.07256226454046555, 0.17311170464381576], [0.04005598108051345, 0.012541207561298506, 0.03796951081312727, 0.06987517044763081, 0.04763525699672755, 0.025203303557645995, 0.04055636301927734, 0.047461108333664015, 0.014041672457096865, 0.03767036221688613, 0.07672625477425754, 0.06968732544919476, 0.039817384313209914, 0.10134367170394398, 0.033019723487086594, 0.024643638862471562, 0.06404131083399989, 0.1066831496427767, 0.03311123400635552, 0.011431129041739041, 0.040926286528701894, 0.05051101245044265, 0.0553613668307662, 0.04476308240555227, 0.03909892970114015, 0.018248593150929082, 0.02697982326935744, 0.03396439213247504, 0.04760321477078833, 0.01842505360400537, 0.04154574606218375, 0.06313085148576647, 0.01860905613284558, 0.02190654256992275, 0.031145359025686048, 0.02967273579997709, 0.03071474639000371, 0.010733920262282481, 0.10996572076692246, 0.09425616139196791, 0.028544931083160918, 0.7597774243913591, 5.988091081380844, 21.02161578834057, 35.5339452624321, 46.96733795106411, 33.60782481729984, 25.428442619740963, 22.086497247219086, 24.16577037423849, 29.14645191282034, 19.628416746854782, 9.774874784052372, 4.188607390969992, 1.8787399563007057, 0.13229441363364458, 0.03360626506037079, 0.7357994047924876, 0.6162425607908517, 1.332508223131299, 0.8656276913825423, 2.952044731937349, 2.9284795839339495, 0.817732805153355, 4.414717582985759, 5.15095230191946, 1.991081996820867, 1.2058534193783998, 4.8097367864102125, 1.801705383695662, 2.27954613044858, 3.170263934880495, 8.102589268237352, 4.270994095131755, 8.096999768167734, 10.47216871753335, 14.534661825746298, 17.893076464533806, 21.294450648128986, 26.656506322324276, 32.965374290943146, 39.815422520041466, 45.93495234847069, 52.17863291501999, 53.974986523389816, 55.194557681679726, 48.80317524075508, 52.92984500527382, 62.1232008934021, 55.05156755447388, 63.40895690023899, 63.50452937185764, 50.916705429553986, 51.40985056757927, 58.902448117733, 57.369070798158646, 54.52509440481663, 56.63819521665573, 55.145593509078026, 56.32422186434269, 52.44763948023319, 55.53743988275528, 43.8929533213377, 43.89120541512966, 35.61838433146477, 26.753929294645786, 21.306644193828106, 12.39372655749321, 10.23258302360773, 6.482713865116239, 4.822977650910616, 2.263229093514383, 2.1427950309589505, 1.2825322360731661, 2.784416964277625, 2.396317427046597, 1.152211104054004, 2.082065027207136, 1.6097286413423717, 8.414203897118568, 3.4541305527091026, 3.09159723110497, 2.6389612443745136, 0.008684190943313297, 0.18263341480633244, 0.05081307026557624, 0.7929524348583072, 0.8160968741867691, 5.345144206658006, 13.349159639328718, 21.07207328081131, 36.02399356663227, 33.21515388786793, 28.108317218720913, 35.05704045295715, 36.91422879695892, 30.434774681925774, 13.754690028727055, 1.9561874005012214, 0.025851324644463602, 0.023894973273854703, 0.007294714696399751, 0.049655431212158874, 0.09059298725333065, 0.01187892239613575, 0.01912542022182606, 0.06587756972294301, 0.02507050179701764, 0.047284796310123056, 0.067128333466826, 0.07370307910605334, 0.011241240354138426, 0.051509327240637504, 0.06697788528981619, 0.032408742990810424, 0.045729143457720056, 0.06361895459122024, 0.02619172737468034, 0.03294691880000755, 0.038039781065890566, 0.024930480794864707, 0.03706343013618607, 0.030370683016371913, 0.08452585578197613, 0.051985192330903374, 0.053467138786800206, 0.044595809740712866, 0.03527713633957319, 0.03211103787180036, 0.08891333636711352, 0.023839902205509134, 0.035926337441196665, 0.07054026835248806, 0.1025232560641598, 0.015191350121313008, 0.08999263431178406, 0.04153224639594555, 0.038561432957067154, 0.018605655241117347, 0.015309322843677364, 0.010849360405700281, 0.04092038274393417, 0.013444484775391174, 0.0148797121073585, 0.03473422933893744, 0.07642162541742437, 0.02629231064929627, 0.059926380272372626, 0.03229155787266791, 0.019739937051781453, 0.028912130910612177, 0.020644846990762744, 0.02591357599158073, 0.06526904573547654, 0.04708562984887976, 0.05986503805615939, 0.03046044392249314, 0.06055477526388131, 0.06401535792974755, 0.021784724594908766, 0.070528861542698, 0.07651380758034065, 0.03459676132479217, 0.07768052309984341, 0.08009327488252893, 0.027159129858773667, 0.03430729775573127, 0.03727776980667841, 0.018661674403119832, 0.01872872559033567, 0.021701065998058766, 0.025107444052991923, 0.02908591035520658, 0.05411147139966488, 0.04488256818149239, 0.08773352194111794, 0.023864211252657697, 1.030795150436461, 8.34617044776678, 26.369213238358498, 42.88543738424778, 50.799481719732285, 38.90744984149933, 28.588700741529465, 23.27521976083517, 26.32360428571701, 26.682365834712982, 20.332636758685112, 10.371382925659418, 5.296424645930529, 1.511130107101053, 0.13680377713171765, 0.05587711864791345, 0.49822653410956264, 0.36949635890778154, 0.9774099150672555, 0.2949003648245707, 2.43526509962976, 2.109706406481564, 1.0017565148882568, 1.1018015840090811, 7.102444935590029, 5.099395243450999, 3.807851909659803, 5.054789911955595, 1.6455153585411608, 2.2613410698249936, 2.944369618780911, 9.802848882973194, 8.484128694981337, 9.645236190408468, 11.767820343375206, 15.814639292657375, 21.37853253632784, 25.52349641919136, 29.3441192060709, 36.099750101566315, 43.22225131094456, 47.21964821219444, 53.013740703463554, 57.14435085654259, 55.67407675087452, 52.22931459546089, 55.41358932852745, 59.50295269489288, 57.107751220464706, 62.365111112594604, 64.0837512910366, 56.28131456673145, 53.70518960058689, 60.74829787015915, 59.81725662946701, 56.571208611130714, 58.65807183086872, 58.587467819452286, 58.098920434713364, 54.699049070477486, 56.1017058044672, 46.701006442308426, 45.84431201219559, 39.683174416422844, 28.155145905911922, 23.274338208138943, 16.4970313757658, 14.337321314960718, 8.093140125274658, 5.6333316676318645, 5.2554865926504135, 3.531790073029697, 2.358774966560304, 2.2151965834200382, 1.5003659971989691, 1.4528480032458901, 0.3931654669577256, 1.4793870854191482, 4.376457910984755, 4.946235911920667, 1.7146081198006868, 2.3720706906169653, 0.18496795906685293, 0.15845831047045067, 0.0930195207183715, 0.9173454099800438, 0.9972752491012216, 6.003674995154142, 15.004499014467001, 24.005968049168587, 34.97417829930782, 35.76288677752018, 30.52398819476366, 38.158464431762695, 43.09548631310463, 35.83868131041527, 16.03167224675417, 2.5760180968791246, 0.09153728111414239, 0.014418600912904367, 0.02635435048432555, 0.025706655942485668, 0.05777822640084196, 0.028671851323451847, 0.021176334194024093, 0.03760467472602613, 0.023780639858159702, 0.0496084606857039, 0.03243851424485911, 0.023475069829146378, 0.036876356971333735, 0.060390218859538436, 0.023833519735489972, 0.03462920802121516, 0.03235787618905306, 0.046326338560902514, 0.011147960740345297, 0.028291701019043103, 0.05137100204592571, 0.016892826643015724, 0.017910689603013452, 0.05225430249993224, 0.09179955610306934, 0.03179218896548264, 0.011183518890902633, 0.010210005748376716, 0.0738009758060798, 0.04716955932963174, 0.06484429235570133, 0.05797272104246076, 0.019971876754425466, 0.03364020347362384, 0.0110812546517991, 0.005545657695620321, 0.11099809271399863, 0.09259733516955748, 0.10671189302229322, 0.12730161513900384, 0.16085072740679607, 0.1277093362296, 0.2629746263846755, 0.17181159550091252, 0.15914522751700133, 0.07256196768139489, 0.13988965685712174, 0.2563495928188786, 0.15713841567048803, 0.1367845555068925, 0.15757399698486552, 0.07709371435339563, 0.12067029558238573, 0.13794021302601323, 0.29711505223531276, 0.12525532103609294, 0.14339222281705588, 0.19501148810377344, 0.14392302167834714, 0.18244335078634322, 0.13492085941834375, 0.16800765821244568, 0.13724891730817035, 0.12764187500579283, 0.17988919018534943, 0.2418077434413135, 0.19680132565554231, 0.12746711407089606, 0.1757905015256256, 0.15238274820148945, 0.0914354065025691, 0.15343441598815843, 0.17447642516344786, 0.10187760984990746, 0.0788598254439421, 0.12962922774022445, 0.17209203826496378, 0.10500965116079897, 1.422135557513684, 10.339183453470469, 29.94100447744131, 48.228049501776695, 63.14486347138882, 45.76605141162872, 38.79885546863079, 35.26183806359768, 36.71275220811367, 39.65533331036568, 27.949447743594646, 14.011006224900484, 6.076182229444385, 2.7879536245018244, 0.4070321697508916, 0.39033141278196126, 1.5207770769484341, 1.5293713845312595, 3.569747186265886, 2.170929196290672, 4.015559451654553, 7.498808316886425, 2.458868008106947, 9.198188278824091, 11.904471460729837, 5.237988056614995, 4.1672340128570795, 7.704928731545806, 4.682612232863903, 3.7319780560210347, 6.354516819119453, 15.525722745805979, 9.656224250793457, 10.53763635456562, 12.561663296073675, 17.21421629190445, 23.874886482954025, 27.770500145852566, 30.936775244772434, 37.37880326807499, 44.15150284767151, 48.53040687739849, 52.72555656731129, 57.47931428253651, 56.827512457966805, 51.70039437711239, 57.05934561789036, 62.69442044198513, 58.59500661492348, 65.26827692985535, 65.1743383705616, 56.17346495389938, 54.99343827366829, 61.02064445614815, 61.1170756816864, 58.05809922516346, 59.31440681219101, 59.23990420997143, 58.33289287984371, 54.04355004429817, 54.767726585268974, 47.11133502423763, 44.72086809575558, 39.272663444280624, 28.194747380912304, 22.415867373347282, 14.236077647656202, 13.329327553510666, 8.884312771260738, 6.402338203042746, 4.921393794938922, 5.2198112569749355, 5.05662901327014, 6.779256127774715, 4.885290982201695, 5.662156445905566, 7.876456277444959, 6.295040510594845, 13.9010857231915, 8.474370818585157, 5.8466346468776464, 4.353227382525802, 0.4021143133286387, 0.20088021381525323, 0.25151147274300456, 1.2866111984476447, 1.792331167962402, 6.728046275675297, 17.846004590392113, 28.74118845909834, 49.78537313640118, 44.694394916296005, 40.66034898161888, 46.22048422694206, 50.48964634537697, 41.549212485551834, 20.10117217898369, 3.2850370137020946, 0.2508308639517054, 0.12915578205138445, 0.16062950802734122, 0.1042858419532422, 0.1560125479591079, 0.08451075307675637, 0.08791281739831902, 0.143858514202293, 0.11384313067537732, 0.13262253196444362, 0.15836528968065977, 0.1304152957163751, 0.145492916344665, 0.15296146011678502, 0.1408037156215869, 0.14752356597455218, 0.16535807226318866, 0.16824367601657286, 0.08831575163640082, 0.16605095617705956, 0.06791263513150625, 0.1387905064621009, 0.0848925212631002, 0.1278557619662024, 0.16339368157787248, 0.13086540828226134, 0.18957761640194803, 0.21372435585362837, 0.12927164614666253, 0.10286456978064962, 0.2532497904030606, 0.20081180264241993, 0.1850194195867516, 0.15251023432938382, 0.1969936754903756, 0.07719690256635658, 0.1733167452039197], [0.009215002792188898, 0.024521095438103657, 0.056371834289166145, 0.011853729265567381, 0.04494134627748281, 0.026639071729732677, 0.028528288421512116, 0.028254645585548133, 0.008881130033842055, 0.07331733300816268, 0.052840265198028646, 0.023523227791883983, 0.03471762378467247, 0.08768749394221231, 0.05978496774332598, 0.028182453170302324, 0.06277893247897737, 0.09198953106533736, 0.05795752185804304, 0.11278001897153445, 0.025760005228221416, 0.03456015860137995, 0.029090494972479064, 0.03258522199757863, 0.0853561186522711, 0.08215648253099062, 0.03398021843167953, 0.008395376753469463, 0.08032679164898582, 0.14028726989636198, 0.031318420442403294, 0.02115348161169095, 0.025845799355010968, 0.016861329895618837, 0.09383551951032132, 0.042214866407448426, 0.01816939671698492, 0.03204491993528791, 0.04302723980799783, 0.038599360414082184, 0.04634561584680341, 0.12495344504714012, 3.6300649121403694, 16.685123182833195, 32.461152747273445, 43.28741021454334, 48.084610998630524, 34.71016466617584, 26.287677213549614, 29.215862788259983, 32.75868818163872, 21.1081675440073, 11.505778804421425, 7.298651682212949, 2.659998103044927, 0.7767432171385735, 0.16218512377236038, 0.06772103486582637, 0.6120866525452584, 0.6904146401211619, 0.3770438226638362, 2.5089433835819364, 0.5125433346256614, 0.4790424322709441, 0.5650987301487476, 7.751175099983811, 6.478351224213839, 2.9830387188121676, 3.1371517991647124, 0.4703148052794859, 0.532852829201147, 0.3624502901220694, 3.2892647618427873, 1.5061460807919502, 2.240915740840137, 5.128368688747287, 4.911611219868064, 7.376071577891707, 11.720736119896173, 20.362069979310036, 25.37518847733736, 31.30287989974022, 38.94569858908653, 45.38001112639904, 45.538390427827835, 51.848183646798134, 48.64148631691933, 45.514782294631004, 58.09694454073906, 57.24446788430214, 52.337141409516335, 52.566964477300644, 54.004860520362854, 50.9595937281847, 57.14701451361179, 54.102051705121994, 55.20409516990185, 55.89775934815407, 55.50762288272381, 55.49658827483654, 48.52300487458706, 44.88185405731201, 36.79317869246006, 29.217650592327118, 23.221070766448975, 16.369411423802376, 14.296619798988104, 7.130085127428174, 5.888693640008569, 4.259837893769145, 1.8777619837783277, 1.8128258432261646, 0.7010683184489608, 1.3373624626547098, 0.9530848078429699, 0.6871086987666786, 0.5187922774348408, 0.9881872055120766, 0.9306515834759921, 3.356039053760469, 2.9545720713213086, 2.192339147441089, 2.5465882010757923, 0.13511488650692627, 0.26025391300208867, 0.3571414406178519, 1.0528002446517348, 4.566399743780494, 7.678669765591621, 18.706303127110004, 20.58834593743086, 19.839966595172882, 19.693617448210716, 28.627948835492134, 35.58323621749878, 36.328022852540016, 21.485711485147476, 6.335040964186192, 0.573616863694042, 0.07531303490395658, 0.026696393360907678, 0.033119883737526834, 0.016138960454554763, 0.03795626347709913, 0.04127255037019495, 0.02397483021923108, 0.03451285410847049, 0.039758101556799375, 0.061924512701807544, 0.09179411616059951, 0.06451636698329821, 0.055129720276454464, 0.022899870127730537, 0.016708100520190783, 0.05982289520034101, 0.007890013148426078, 0.029815636335115414, 0.027244424891250674, 0.042715185263659805, 0.08178549032891169, 0.04887141898507252, 0.11221243184991181, 0.04763362798257731, 0.05587603882304393, 0.05657755391439423, 0.04009506257716566, 0.03344544536957983, 0.02639641912537627, 0.009658257913542911, 0.033202165650436655, 0.039738341874908656, 0.02428240219160216, 0.01659912541072117, 0.040941103507066146, 0.010954736098938156, 0.06203949364135042, 0.025446408872085158, 0.04230415419442579, 0.03558057083864696, 0.020630388098652475, 0.011740612044377485, 0.04644251435820479, 0.05154783357284032, 0.040804815507726744, 0.02194893404521281, 0.047411970735993236, 0.029198566517152358, 0.08250270926509984, 0.006331214053716394, 0.0218101468635723, 0.030563457730750088, 0.02579489544586977, 0.019552379635570105, 0.03538094795658253, 0.017734307075443212, 0.08253073276137002, 0.06700762314721942, 0.01671445515967207, 0.026419848727528006, 0.01956951768079307, 0.05302258119627368, 0.03277992072980851, 0.027354019694030285, 0.045773794772685505, 0.04834155894059222, 0.03648908947070595, 0.026882525853579864, 0.010763329719338799, 0.0454206363792764, 0.021171573316678405, 0.04489967839617748, 0.009100740808207775, 0.03393924816919025, 0.05290233100822661, 0.056781689054332674, 0.06024070207786281, 0.023682444443693385, 0.3237648925278336, 4.648330947384238, 19.40781958401203, 37.54502534866333, 51.36586032807827, 51.43161199986935, 39.81497794389725, 30.76787430793047, 33.07601295411587, 36.32253974676132, 23.96886494010687, 13.59631547704339, 7.280421685427427, 2.922804350964725, 0.8044990058988333, 0.1631021362845786, 0.11174238519743085, 0.4549017339013517, 0.3359030740102753, 0.2767241885885596, 1.1677314899861813, 1.29751744447276, 0.8149485045578331, 0.7436734135262668, 1.0611753514967859, 4.563849130645394, 1.257254092488438, 0.4412757244426757, 0.8062149106990546, 0.04998216172680259, 0.4787646612385288, 1.9737196597270668, 2.6600059401243925, 3.146996833384037, 4.777419995516539, 5.6337016727775335, 10.326267946511507, 14.649552460759878, 21.894753836095333, 28.05744744837284, 34.13085915148258, 41.77166394889355, 46.720309406518936, 48.90409402549267, 54.0173352509737, 52.494745552539825, 50.890061259269714, 58.993073254823685, 58.128566443920135, 57.15375915169716, 56.05196267366409, 55.22261917591095, 55.23220606148243, 57.24647417664528, 57.52318672835827, 57.491086050868034, 58.85906584560871, 56.11666940152645, 56.26342132687569, 50.75604625046253, 45.93592129647732, 39.35570418834686, 33.997946083545685, 25.903850309550762, 20.573207549750805, 16.563510708510876, 10.065244752913713, 8.016011863946915, 5.997069524601102, 3.4328303206712008, 4.47681812569499, 2.31240747962147, 0.33007460238877684, 0.9584415704011917, 0.877109665889293, 0.2708419557893649, 0.6753624603152275, 0.4721571126719937, 2.026936635375023, 3.39564670342952, 1.7880913079716265, 0.5492047767620534, 0.16087699943454936, 0.08276105087134056, 0.15911505179246888, 1.1702012387104332, 4.568382762372494, 8.807987216860056, 19.735267013311386, 23.215726353228092, 28.87010034173727, 24.55186765640974, 32.40455478429794, 39.28619831800461, 42.12177716195583, 25.35724774003029, 8.192465845495462, 0.9361043502576649, 0.0994860463833902, 0.015660310455132276, 0.05922831245698035, 0.02564047677878989, 0.03689270277391188, 0.04755646688863635, 0.0028826084917454864, 0.05262277882138733, 0.04511780301982071, 0.10992812356562354, 0.07239388607558794, 0.0502916744153481, 0.0395359136746265, 0.0998073146911338, 0.011237667840759968, 0.07773281482513994, 0.018551452485553455, 0.02337749225262087, 0.04185724028502591, 0.05740384258388076, 0.09080583520699292, 0.047441716014873236, 0.0511350102169672, 0.06170989843667485, 0.0486863793048542, 0.09302733553340659, 0.03211554641893599, 0.035292587854200974, 0.025822020943451207, 0.1036845167982392, 0.05828761059092358, 0.05911289365030825, 0.030965816804382484, 0.04705424442363437, 0.030313856768771075, 0.03257371499785222, 0.01586810809385497, 0.14207556378096342, 0.09992160543333739, 0.12557965441374108, 0.09999217625590973, 0.14260121213737875, 0.1227427800768055, 0.12476410833187401, 0.08781735494267195, 0.15095357957761735, 0.14423220040043816, 0.1414938535890542, 0.11187395313754678, 0.08689335139933974, 0.17317123973043635, 0.20427969546290115, 0.22912492946488783, 0.14964824571507052, 0.20458679617149755, 0.1252995678805746, 0.23613078868947923, 0.14139945240458474, 0.11977910238783807, 0.10635952872689813, 0.11440605710959062, 0.2032306103501469, 0.14996061567217112, 0.23230109887663275, 0.07669397877180018, 0.1526618847856298, 0.2420854105730541, 0.1404372282559052, 0.22414470295188949, 0.13937145966337994, 0.1406265501282178, 0.18810446810675785, 0.10082451713969931, 0.1090342660609167, 0.11236230115173385, 0.10223794481134973, 0.12509198917541653, 0.09237722159014083, 0.3395996819017455, 5.300704641267657, 22.70162343978882, 44.5648180693388, 55.69820165634155, 63.2246857881546, 45.64938247203827, 38.48717339336872, 42.44600996375084, 41.86087176203728, 29.98947847634554, 16.79852619767189, 9.8328454233706, 3.625862100161612, 1.5959142451174557, 0.33982036693487316, 0.324985992629081, 1.4960932452231646, 1.6045412071980536, 2.6339842239394784, 4.313092036172748, 2.853430286049843, 1.3969486090354621, 2.807593820616603, 15.700063090771437, 15.911910273134708, 9.625499099493027, 8.585766591131687, 2.657575970515609, 2.2704128455370665, 1.1580441473051906, 5.92654530890286, 5.121625000610948, 5.328255062922835, 5.999615387991071, 7.24763466976583, 11.816117651760578, 18.083497546613216, 23.839043006300926, 30.37186525762081, 34.985250905156136, 42.51038230955601, 49.12616930902004, 49.82385367155075, 55.84634430706501, 54.127521738409996, 52.819495126605034, 60.06736680865288, 61.00866749882698, 59.626609459519386, 58.15547280013561, 58.47320415079594, 56.21466614305973, 58.261540308594704, 57.47275963425636, 57.962944731116295, 58.71203653514385, 58.627460673451424, 58.21257993578911, 51.83474376797676, 46.918575167655945, 40.57842157781124, 34.439721778035164, 27.03876581043005, 22.424335218966007, 18.025966733694077, 12.111284863203764, 10.41976097971201, 7.917977124452591, 4.803630514070392, 6.71021668240428, 4.321391265839338, 3.4962140070274472, 3.6053605377674103, 2.7480355789884925, 3.175109149888158, 2.3402989329770207, 5.182600328698754, 5.2459457796067, 8.097723629325628, 6.86770873144269, 3.902784828096628, 0.7301032729446888, 0.35614660650026053, 0.8824958768673241, 1.5417457767762244, 6.11894465982914, 10.832523331046104, 24.497477374970913, 30.465653724968433, 30.702143535017967, 30.744754448533058, 40.12996584177017, 46.60470820963383, 48.914269879460335, 31.059400364756584, 10.766883753240108, 1.5050423587672412, 0.17847007024101913, 0.08210568252252415, 0.23844433017075062, 0.10145117921638303, 0.11500524487928487, 0.15397553070215508, 0.08054778096266091, 0.16642290574964136, 0.15384647122118622, 0.1667589056887664, 0.2937204687623307, 0.11587107888772152, 0.12200290337204933, 0.2981307258596644, 0.14341940026497468, 0.21841360110556707, 0.08330549782840535, 0.1394183188676834, 0.15512946643866599, 0.14941761590307578, 0.15753159066662192, 0.10546351899392903, 0.18537808471592143, 0.1591388598899357, 0.10644104622770101, 0.1964602345833555, 0.05570215733314399, 0.16651525860652328, 0.08805599994957447, 0.26831518043763936, 0.20143308414844796, 0.13594854099210352, 0.12807631341274828, 0.198528436885681, 0.10322902366169728, 0.12200526340166107, 0.12039337801979855], [0.013204582755861338, 0.021109659646754153, 0.030960653311922215, 0.038331048053805716, 0.024188169845729135, 0.02325474844838027, 0.03135749080684036, 0.051328391637071036, 0.028042142730555497, 0.05265010840957984, 0.056452142089256085, 0.088870514446171, 0.008885363986337325, 0.032514287522644736, 0.043919850504607894, 0.01106529291064362, 0.06033121811924502, 0.04001533365226351, 0.008936468275351217, 0.046336669256561436, 0.032867876361706294, 0.03762245658435859, 0.06743898906279355, 0.034277548766112886, 0.043913241679547355, 0.011197345102118561, 0.04540130714303814, 0.07705458090640604, 0.07957696274388582, 0.05377823967137374, 0.02302974411577452, 0.10686050067306496, 0.002614341356093064, 0.0428560782893328, 0.025851246718957555, 0.03619560717197601, 0.047936639457475394, 0.05376682544010691, 0.06531566003104672, 0.030505969116347842, 0.07963807860505767, 0.02562303630838869, 1.1066412180662155, 10.570108462125063, 26.356191337108612, 39.73618917167187, 49.32385750114918, 33.93116846680641, 23.239853158593178, 24.310498908162117, 26.224349811673164, 26.6088492795825, 15.24233965203166, 11.161184795200825, 3.3152914652600884, 1.0695579391904175, 0.46322978858370334, 0.11936158494791016, 0.06735998744261451, 0.1790292636724189, 0.06467603263445199, 1.0295560606755316, 1.280853794887662, 0.45081454853061587, 0.04739093827083707, 0.6671758589800447, 2.5111672142520547, 1.0540172480978072, 0.8733647887129337, 0.531984397675842, 0.2100886931293644, 0.11668085106066428, 0.11985798526438884, 0.8912546443752944, 0.5313982791267335, 0.8331532683223486, 1.2969569745473564, 2.50341871753335, 3.9423245564103127, 8.796128053218126, 14.51774513348937, 22.685018330812454, 28.23905110359192, 35.26917926967144, 40.31217746436596, 48.29240284860134, 45.767810717225075, 44.744328036904335, 41.20580971240997, 41.69303096830845, 45.0862754881382, 49.945872724056244, 53.40623304247856, 49.93710659444332, 53.371901884675026, 53.067800402641296, 53.147634118795395, 51.42947271466255, 48.88493925333023, 47.500289753079414, 39.81616348028183, 31.521115489304066, 22.092044949531555, 17.18276157975197, 8.56475941836834, 5.421784669160843, 3.856216426938772, 2.8430765541270375, 2.214720183983445, 1.1703184386715293, 0.6334423378575593, 2.719340706244111, 1.4239948452450335, 0.2573294355534017, 0.2987899607978761, 0.16541276854695752, 0.09602245059795678, 0.023637186423002277, 0.14037172630196437, 1.3788042264059186, 3.72874537948519, 0.4849573195679113, 0.58594761765562, 0.12487032450735569, 0.20050872437423095, 0.47851167793851346, 2.6976813934743404, 4.766124151647091, 8.58013054355979, 20.043586269021034, 27.461989000439644, 17.651390433311462, 26.804833263158798, 35.81323027610779, 35.452014058828354, 41.97098605334759, 17.655142731964588, 2.5462336326017976, 0.1793954987078905, 0.1365711138350889, 0.03861468576360494, 0.018873299668484833, 0.06366890855133533, 0.06530811238917522, 0.02047955586021999, 0.012695948134933133, 0.14201150159351528, 0.0577301240991801, 0.06578895729035139, 0.0508041607827181, 0.039551803056383505, 0.06578126121894456, 0.09691716157249175, 0.04739428164612036, 0.035155750665580854, 0.02650223825185094, 0.022544208841281943, 0.04461517237359658, 0.07245289423735812, 0.04083469437318854, 0.02287337731104344, 0.0430792346742237, 0.023031738637655508, 0.012489211767388042, 0.08312332283821888, 0.05647218749800231, 0.03250173780543264, 0.03375064246938564, 0.04905077752482612, 0.06426187712349929, 0.059157608047826216, 0.10725786880357191, 0.054518042161362246, 0.02650349062605528, 0.029260955161589663, 0.02080312668113038, 0.03720051965501625, 0.012875493139290484, 0.041240779028157704, 0.054120050626806915, 0.023789892584318295, 0.06385561806382611, 0.010896496987697901, 0.04654883814509958, 0.071416485006921, 0.024455437633150723, 0.03382322822290007, 0.06135662872111425, 0.026960848408634774, 0.017843172718130518, 0.04324134570197202, 0.032836272002896294, 0.026122499839402735, 0.01696770006674342, 0.02071034708933439, 0.04510455568379257, 0.017765386364771985, 0.040944454303826205, 0.08052131597651169, 0.04468108993023634, 0.048922282076091506, 0.052488646761048585, 0.08187774670659564, 0.03879585514368955, 0.06984500214457512, 0.10159494064282626, 0.024422389797109645, 0.0459487041371176, 0.055560121400048956, 0.017118489631684497, 0.07981024944456294, 0.02024003697442822, 0.039379413283313625, 0.04944827553117648, 0.03377144857950043, 0.07183013585745357, 0.005062636910224683, 0.02739842424489325, 1.877346618566662, 13.141819965094328, 31.944205686450005, 44.41265903413296, 54.84730951488018, 39.44635972380638, 28.59380766749382, 28.07840332388878, 31.397681012749672, 30.11061977595091, 19.5284878090024, 11.645291168242693, 4.419705765321851, 0.9084681957028806, 0.21537227992666885, 0.07008808519458398, 0.11666558508295566, 0.20319575909525156, 0.1319991279160604, 0.6499497801996768, 0.38149531348608434, 0.0213905031705508, 0.028208986805111635, 0.25457499898038805, 0.7018508389592171, 0.5157363507896662, 0.25989803834818304, 0.30781940440647304, 0.27466285857371986, 0.21972133952658623, 0.5530568794347346, 0.6222389952745289, 0.45231401338241994, 1.0399664333090186, 1.5529007907025516, 2.8033026633784175, 4.7998126689344645, 10.984010752290487, 16.714413911104202, 24.15036980062723, 30.908480063080788, 38.41093808412552, 42.435689717531204, 51.5371323376894, 48.59072484076023, 51.80049240589142, 44.33306850492954, 45.37829361855984, 50.85647106170654, 52.78022043406963, 56.49717718362808, 53.61570820212364, 56.87511250376701, 55.31818024814129, 54.42752704024315, 54.57225747406483, 52.31488600373268, 49.79704990983009, 41.924514546990395, 35.22872284054756, 24.399860613048077, 19.111900962889194, 11.305489651858807, 6.684624580666423, 5.725676687434316, 3.3194318180903792, 2.0656674820929766, 1.6012562834657729, 0.46342399378772825, 0.8352193480823189, 0.2999838982941583, 0.01773728865373414, 0.1972034657956101, 0.11763276677811518, 0.06140464567579329, 0.07927692728117108, 0.30686666490510106, 0.6370020937174559, 0.9221014485228807, 0.5485360720194876, 0.38813435880001634, 0.08920957203372382, 0.2719509322196245, 0.5866217846050858, 3.3761221636086702, 7.470735898241401, 11.83107839897275, 21.536835841834545, 30.099579468369484, 18.293954953551292, 28.42939618974924, 39.65256325900555, 40.526493564248085, 45.83515830338001, 21.38086561113596, 3.364791884087026, 0.17178474459797144, 0.06772717242711224, 0.025093259755522013, 0.0353888110112166, 0.09335261143860407, 0.0944363845337648, 0.015883008563832846, 0.015377195031760493, 0.035107807925669476, 0.0374967441894114, 0.14621529320720583, 0.053204481591819786, 0.03877249233482871, 0.049965081198024563, 0.07830150032532401, 0.049951117689488456, 0.052152680218569, 0.02085306023218436, 0.03146166978694964, 0.03516802578815259, 0.09297671364038251, 0.029910380762885325, 0.047783530681044795, 0.0754201713425573, 0.015627535358362366, 0.04583564164931886, 0.03131925535853952, 0.06932710923138075, 0.05649342776450794, 0.08878162741893902, 0.09314112903666683, 0.023314222307817545, 0.03306004065962043, 0.04789260041434318, 0.08000586472917348, 0.024448292606393807, 0.0031575201683153864, 0.06580126952030696, 0.08944472894654609, 0.11479675333248451, 0.19039007514948025, 0.12957402679603547, 0.16482595237903297, 0.11935882415855303, 0.13311511022038758, 0.15780896093929186, 0.1155870886577759, 0.155939802643843, 0.11233665252802894, 0.19427515886491165, 0.1356877206126228, 0.054616777488263324, 0.1085831070668064, 0.15920759760774672, 0.1663900286075659, 0.12832904438255355, 0.15798229695064947, 0.08262307819677517, 0.10652264536474831, 0.15092589746927842, 0.2235638684942387, 0.1737288004369475, 0.101571050909115, 0.09735722545883618, 0.14314928819658235, 0.17585083813173696, 0.13648034917423502, 0.21254882361972705, 0.13672390719875693, 0.2331658493494615, 0.11680893832817674, 0.08086336441920139, 0.13733735162531957, 0.10598574604955502, 0.15233047131914645, 0.11924065940547734, 0.11769569347961806, 0.19186620687833056, 0.17189340986078605, 0.12550716142868623, 1.9099429319612682, 14.343258496373892, 36.35788545012474, 52.22824305295944, 63.243031203746796, 49.6336130797863, 35.4012905806303, 37.04950533807278, 36.92368648946285, 38.00941362977028, 22.08892911672592, 14.910795092582703, 5.595777332782745, 1.1713363090530038, 0.7897522940766066, 0.22603444842388853, 0.32405349891632795, 0.4964604601264, 0.7641164946835488, 2.569777169264853, 3.372691422700882, 1.426778908353299, 0.5887316213920712, 2.6953711174428463, 7.9313514567911625, 3.0680753057822585, 2.4129367852583528, 2.099334863014519, 0.71855723625049, 0.8285492809955031, 1.005979988258332, 1.5830190433189273, 0.9661090839654207, 1.7919180588796735, 1.7234311276115477, 3.0999802937731147, 4.3697678949683905, 10.904840100556612, 17.614304423332214, 25.137444734573364, 31.981774270534515, 37.680852860212326, 44.05035987496376, 51.773787438869476, 51.113238483667374, 52.97845579683781, 47.0553982257843, 47.39888459444046, 52.72465601563454, 54.85889129340649, 58.790243938565254, 55.5165334045887, 58.25661197304726, 58.2412151992321, 56.639665737748146, 55.17105974256992, 52.82768748700619, 51.24390967190266, 43.55406850576401, 34.68141160905361, 25.653996616601944, 19.7187303006649, 10.775916818529367, 6.488757915794849, 7.015839507803321, 5.875989496707916, 4.715264830738306, 3.0642125755548477, 1.6701275878585875, 4.961882047355175, 2.350029735825956, 0.5262765695806593, 0.4211075941566378, 0.39549468259792775, 0.15231334255076945, 0.6654559762682766, 0.4618884902447462, 4.493243219330907, 8.337438516318798, 1.463931177277118, 1.075578003656119, 0.4792728245956823, 0.8044549520127475, 0.910629864083603, 4.381691655144095, 7.940469067543745, 13.058125656098127, 27.179548256099224, 39.68318201601505, 27.489368431270123, 38.07204186916351, 47.518050000071526, 46.54842182993889, 50.561580285429955, 25.955158956348896, 4.666148666292429, 0.3674297744873911, 0.19817643624264747, 0.09475469909375533, 0.1195536824525334, 0.18310096784261987, 0.1851743651786819, 0.24493969569448382, 0.10438840676215477, 0.18294965877430514, 0.3027706628199667, 0.1857070194091648, 0.1737437621341087, 0.09646256643463857, 0.1621104043442756, 0.33943352987989783, 0.15946068480843678, 0.1770949744968675, 0.12027913180645555, 0.11534210570971482, 0.09969771432224661, 0.220895268721506, 0.1620121143059805, 0.10416795921628363, 0.1294739852892235, 0.1011460971494671, 0.21894923876971006, 0.17295382014708593, 0.15315760974772274, 0.11288381574559025, 0.1974810883984901, 0.29242815217003226, 0.09064740152098238, 0.19516089727403596, 0.19023590139113367, 0.15437013062182814, 0.18754322634777054, 0.11299700068775564, 0.1503476605284959], [0.05437780964712147, 0.03376577114977408, 0.04048292379593477, 0.11238679944653995, 0.04978465767635498, 0.05756127065978944, 0.04443745769094676, 0.08062221837462857, 0.07183608046034351, 0.01927017427078681, 0.015322584094974445, 0.02014478788623819, 0.01514371073426446, 0.06459589552832767, 0.03438393563556019, 0.05629699240671471, 0.04507510726398323, 0.0210139949558652, 0.08364658890059218, 0.07270328002050519, 0.019155532863806002, 0.0690521732030902, 0.04526682256255299, 0.03191639108990785, 0.07367654732661322, 0.021055588622402865, 0.012620592315215617, 0.051942344434792176, 0.037207391942502, 0.05113683961099014, 0.0349079957959475, 0.019661356600408908, 0.033780324665713124, 0.0150738978300069, 0.0943679733609315, 0.049803044385043904, 0.07899461430497468, 0.04373165298602544, 0.04533700746833347, 0.03830971501884051, 0.070744514814578, 0.014171443472150713, 0.2301795213134028, 4.635662902146578, 17.80251782387495, 39.445960745215416, 47.18036592006683, 44.90709230303764, 22.634372748434544, 25.54527685046196, 29.831340461969376, 26.4785922691226, 31.663761734962463, 17.188085094094276, 6.6504354402422905, 3.1014030799269676, 0.6282843521330506, 0.20948866673279554, 0.242225305410102, 0.11098155024228618, 0.0602694751432864, 0.5590644758194685, 0.1676497352309525, 0.01843172180088004, 0.17116788629209623, 0.07727689124294557, 0.2926715469220653, 0.2651375415734947, 0.04751399377710186, 0.08060249951086007, 0.10620315821142867, 0.12339152846834622, 0.295152427861467, 0.19298526167403907, 0.10902335649007, 0.07435225052176975, 0.2715841925237328, 0.3541152592515573, 0.7335965323727578, 3.234003377147019, 7.032141583040357, 15.403421558439732, 20.57052869349718, 28.796243704855442, 31.24666951596737, 40.708177015185356, 39.914395809173584, 38.91560420393944, 39.344867169857025, 30.133587643504143, 34.188813641667366, 42.085960283875465, 46.998522877693176, 44.62154142558575, 50.110054314136505, 47.58875660598278, 47.68255457282066, 45.79677656292915, 39.1352704167366, 36.36607401072979, 27.660934925079346, 20.33551510423422, 12.77223089709878, 7.09516167640686, 2.585452515631914, 1.8650274421088398, 1.2872622697614133, 0.17429453961085528, 0.35320743452757597, 0.7201194867957383, 0.6520774285309017, 0.16816042189020663, 0.38526331598404795, 0.06139958422863856, 0.3437027789186686, 0.08204167970689014, 0.05234877418843098, 0.03912093809049111, 0.10267622754327022, 0.14737518096808344, 0.1623829803429544, 0.41016792180016637, 0.5014405085239559, 0.15044569823658094, 0.20112923404667526, 0.9350837487727404, 3.6909084348008037, 7.839124705642462, 15.736536383628845, 20.464157201349735, 16.59434985369444, 26.086231023073196, 22.113386504352093, 35.55269345641136, 40.67201055586338, 29.401114247739315, 9.614084511995316, 0.7960328226909041, 0.04178517403488513, 0.05877225899894256, 0.018565931786724832, 0.016964210117293987, 0.05119895366078708, 0.08283219314762391, 0.014574721881217556, 0.024045456702879164, 0.015987818369467277, 0.023937255282362457, 0.05291036475682631, 0.006887895315230708, 0.016544059908483177, 0.08355874088010751, 0.06312891448033042, 0.028098610891902354, 0.02282999877934344, 0.02917509980761679, 0.0419208942912519, 0.039667043747613207, 0.01816738920751959, 0.057752414504648186, 0.00204177164050634, 0.08170298577169888, 0.0004701901247017304, 0.0491783489997033, 0.022475480400316883, 0.08204243669752032, 0.06275732856011018, 0.053970763910911046, 0.04010106284113135, 0.023619246858288534, 0.031233110566972755, 0.03363735362654552, 0.05692018865374848, 0.0737456041679252, 0.03906332887709141, 0.05622340104309842, 0.06947127883904614, 0.04651884053600952, 0.017523089991300367, 0.03337054040457588, 0.029390586096269544, 0.11314686256810091, 0.047971973108360544, 0.03048206453968305, 0.04688606262789108, 0.03212785864889156, 0.03328765735204797, 0.010585849740891717, 0.004065605571668129, 0.07748761665425263, 0.01574438836541958, 0.10021145862992853, 0.049512972254888155, 0.03409065000596456, 0.05717929838283453, 0.09208915696945041, 0.04744554549688473, 0.10026348318206146, 0.020018194190924987, 0.007422053322443389, 0.04660017249989323, 0.048703496941016056, 0.023279087181435898, 0.03502743333228864, 0.02260517627291847, 0.03851995803415775, 0.022469446739705745, 0.0472936612641206, 0.0637853515218012, 0.015769502642797306, 0.03511682130920235, 0.10885419134865515, 0.04234592226566747, 0.029692745956708677, 0.05676257504092064, 0.07769888383336365, 0.08734018367249519, 0.06252778970520012, 0.49541026179213077, 6.1421386152505875, 22.259838245809078, 45.611639097332954, 54.26326185464859, 47.74229496717453, 29.159593507647514, 30.564070343971252, 31.628889106214046, 30.074333623051643, 28.998541049659252, 18.38689796626568, 7.251259675249457, 2.8832401614636183, 0.5859596701338887, 0.27863658440764993, 0.12149403497460298, 0.05946667544776574, 0.03936584311304614, 0.2499392774188891, 0.13613997056381777, 0.021099002406117506, 0.06294708829955198, 0.14543100638547912, 0.12839922186685726, 0.1216347684385255, 0.014350833553180564, 0.03839338103716727, 0.053194737192825414, 0.31463255756534636, 0.5274214956443757, 0.40371379000134766, 0.132361073337961, 0.23483099124860018, 0.32582135405391455, 1.0728681553155184, 1.272815444972366, 4.578410899266601, 7.960176235064864, 15.740673411637545, 21.525550447404385, 29.57734689116478, 34.27315391600132, 41.851136684417725, 43.34420956671238, 44.52252633869648, 40.819841623306274, 32.53473199903965, 38.699088022112846, 45.06317652761936, 52.62673906981945, 51.768794506788254, 53.86688992381096, 51.322576850652695, 50.61668872833252, 48.36780220270157, 42.19792127609253, 38.64690542221069, 30.036005079746246, 22.83976122736931, 15.441924892365932, 10.685143489390612, 5.013668518513441, 2.9258669866248965, 0.9064629720523953, 0.057927086381823756, 0.29311900259926915, 0.34940422454383224, 0.42387550813145936, 0.38148860447108746, 0.41968124569393694, 0.17913050745846704, 0.2976198313990608, 0.182610007468611, 0.05435890343505889, 0.13874902040697634, 0.04161937082244549, 0.24108631652779877, 0.05701093847164884, 0.0750839636020828, 0.3434109367663041, 0.347144830157049, 0.14052342128707096, 0.9584646066650748, 4.391326988115907, 7.991431932896376, 14.223685562610626, 23.54208704084158, 22.23786022514105, 27.304033376276493, 26.593349911272526, 38.606638982892036, 45.417625308036804, 34.000716134905815, 11.802500132471323, 1.0093784308992326, 0.09905131853884086, 0.023490640087402426, 0.05903577337448951, 0.009706485452625202, 0.05919366900343448, 0.04143383019254543, 0.014813344623689773, 0.025160086443065666, 0.06534576154081151, 0.020703480367956217, 0.13740558468271047, 0.011377404971426586, 0.03224012332793791, 0.043045355632784776, 0.023331621960096527, 0.019596609781729057, 0.0722630973905325, 0.010744949504442047, 0.027030242927139625, 0.04214375752781052, 0.03402564529096708, 0.02778473437501816, 0.04669766472943593, 0.08356470774742775, 0.036566855415003374, 0.029098291233822238, 0.013127136862749467, 0.05484497676661704, 0.023419193530571647, 0.05046087666414678, 0.054962544090813026, 0.012705803856079001, 0.031631398960598744, 0.030023643630556762, 0.04086961613211315, 0.0915630187955685, 0.08260755988885649, 0.07751163997454569, 0.11912766742170788, 0.10925037204287946, 0.10206388149526902, 0.23564895673189312, 0.13790939905447885, 0.23034096811898053, 0.11955966416280717, 0.12830775958718732, 0.12553606065921485, 0.15508385404245928, 0.09162593065411784, 0.10710373957408592, 0.19198026013327762, 0.1610626996261999, 0.15019020647741854, 0.12550051178550348, 0.12816832488169894, 0.1079237311205361, 0.20141114626312628, 0.2273116252035834, 0.20783370709978044, 0.2492096571950242, 0.11461244837846607, 0.18032350984867662, 0.11054568691179156, 0.11860467595397495, 0.07668341058888473, 0.19293990160804242, 0.18808474182151258, 0.13198192493291572, 0.2354117069626227, 0.17450719460612163, 0.18892020714702085, 0.1374305208446458, 0.12850797618739307, 0.23168855987023562, 0.30385075486265123, 0.12700812541879714, 0.1124134128622245, 0.15486103162402287, 0.2322195516899228, 0.17644568433752283, 0.6089756882283837, 7.6354779582470655, 24.2717257887125, 51.89742140471935, 60.915184915065765, 57.59236581623554, 35.85872143507004, 38.87539856135845, 42.19502583146095, 38.448898047208786, 42.02366642653942, 23.978277035057545, 9.736183360219002, 3.987363064661622, 1.15494588855654, 0.475285027641803, 0.4632785922149196, 0.3492146503413096, 0.3052557888440788, 1.2055329303257167, 0.9558297449257225, 0.4171464848332107, 0.5192658270243555, 0.3988550679059699, 0.43117975525092334, 0.4848298185970634, 0.15180601039901376, 0.3864925500238314, 0.19641690800199285, 0.4763200267916545, 1.0503525822423398, 0.8596316131297499, 0.28910989116411656, 0.3487071697600186, 0.6631962850224227, 0.9189799160230905, 1.3970874203369021, 4.061469538137317, 7.590463198721409, 15.838035587221384, 23.123642094433308, 30.295489355921745, 34.03109930455685, 41.89537391066551, 46.25742204487324, 47.559338584542274, 46.257042065262794, 37.034781128168106, 41.91962040960789, 50.07598914206028, 55.76141506433487, 53.09919811785221, 54.01246391236782, 52.84191392362118, 51.49586655199528, 48.66330474615097, 41.65479741990566, 38.955726251006126, 29.478248208761215, 21.95013016462326, 14.969384148716927, 8.832796085625887, 5.1159219816327095, 3.289223201572895, 2.006759005598724, 1.4390613930299878, 0.953754106303677, 1.5917224762961268, 1.2197222001850605, 1.7934924806468189, 1.0882416553795338, 0.351538106915541, 0.9919070871546865, 0.43125966971274465, 0.12844657088862732, 0.4691916983574629, 0.17584798828465864, 1.0505010117776692, 0.7011088100261986, 2.2031583543866873, 1.2341597629711032, 0.8689946075901389, 0.2262046525720507, 0.9954316355288029, 5.816814796999097, 10.433739479631186, 21.80302105844021, 28.69985807687044, 29.01432730257511, 35.54879106581211, 33.6946577578783, 46.4996400475502, 52.57621318101883, 37.641456574201584, 14.90224840119481, 1.4974344545044005, 0.20514239760814235, 0.1023695053299889, 0.13272382027935237, 0.23839327041059732, 0.10543086449615657, 0.21481384348589927, 0.1339512286358513, 0.09950538675184362, 0.1863658387446776, 0.13917572563514113, 0.22891637112479657, 0.11099642288172618, 0.07744141053990461, 0.19566061499062926, 0.15623318846337497, 0.13960817508632317, 0.15550837735645473, 0.16977866005618125, 0.13816961087286472, 0.12266358549823053, 0.11314704068354331, 0.20871628395980224, 0.13033961149631068, 0.16474715113872662, 0.12544415309093893, 0.13990516774356365, 0.14884031406836584, 0.17303198314039037, 0.2349493934889324, 0.14006159763084725, 0.2088990600896068, 0.16531358793145046, 0.10371402458986267, 0.10926218703389168, 0.20485818473389372, 0.2594126737676561, 0.19831518817227334, 0.2085703777265735], [0.05646181969495956, 0.01181646139229997, 0.04325619236624334, 0.03787515786825679, 0.0319454832788324, 0.02664824281964684, 0.041660103597678244, 0.04350927585619502, 0.02765828354313271, 0.09206771632307209, 0.04664640087867156, 0.029025948533671908, 0.02605222773127025, 0.05743337263993453, 0.030142480027279817, 0.00919717733268044, 0.07845050131436437, 0.06688002569717355, 0.04606459420756437, 0.03410868790524546, 0.06227382677025162, 0.028538383485283703, 0.025008595548570156, 0.00304728688661271, 0.05153454541868996, 0.06827599063399248, 0.03630467690527439, 0.025249515238101594, 0.014624354862462496, 0.075744645728264, 0.03425675749895163, 0.01396753839799203, 0.011675032164930599, 0.06348495982820168, 0.1008869985525962, 0.020839083736063913, 0.09388258651597425, 0.05628249084111303, 0.016436769474239554, 0.017763662726792973, 0.024866351814125665, 0.07067049300530925, 0.07954724715091288, 2.087955423630774, 9.899444449692965, 29.53156504780054, 40.75876370072365, 44.45914953947067, 26.932301223278046, 14.767699521034956, 23.50746139883995, 34.01603691279888, 33.16065341234207, 19.087855853140354, 12.401810623705387, 5.269007692113519, 2.350969947874546, 0.8497410407289863, 0.08761796212638728, 0.04571602228679694, 0.053435096560860984, 0.07375114801106974, 0.11235398167627864, 0.09467097741435282, 0.06496406014775857, 0.05486738962645177, 0.035786976950475946, 0.05355252658773679, 0.04954055788402911, 0.11303293547825888, 0.1930802417336963, 0.09085313969990239, 0.2241136514930986, 0.18810008943546563, 0.08591373130911961, 0.0031586950808559777, 0.29924620350357145, 0.27105177578050643, 0.3565052122576162, 1.655486379750073, 2.2482044622302055, 7.328987829387188, 12.19404062256217, 18.889759182929993, 22.51331314444542, 28.78691330552101, 31.006619296967983, 28.856356479227543, 29.058038257062435, 22.54707433283329, 26.588531769812107, 34.34321455657482, 41.79991163313389, 37.574716955423355, 45.31138300895691, 40.80486662685871, 40.206923112273216, 34.12003353238106, 29.898946434259415, 22.800167351961136, 17.79976487159729, 12.42448590695858, 5.541664911434054, 3.2743291882798076, 0.7347087445668876, 0.03992688449216075, 0.11519153878907673, 0.1907673236564733, 0.06357786929584108, 0.21725249622249976, 0.22108181496150792, 0.21620240178890526, 0.15926489140838385, 0.08639372274046764, 0.11463626389740966, 0.1299358089454472, 0.09047982457559556, 0.040868725554901175, 0.07595580900670029, 0.041767763250391, 0.20131769502768293, 0.09585717431036755, 0.09413077554199845, 0.13914660376030952, 0.5277524935081601, 3.211649414151907, 5.511046629399061, 15.950746089220047, 28.138715587556362, 32.252475544810295, 32.22497642040253, 24.05057765543461, 30.500752441585064, 37.55934678018093, 33.02410773932934, 19.6096533536911, 5.004452588036656, 0.275537256966345, 0.06428927721572109, 0.030503518173645716, 0.08763188481680118, 0.02512757109798258, 0.02020030795392813, 0.03340219671372324, 0.0313845495111309, 0.052543454366968945, 0.10806379665154964, 0.0554988719522953, 0.02892614451411646, 0.06861233196104877, 0.05475837184349075, 0.04361690953373909, 0.03183001252182294, 0.020103136703255586, 0.015375371203845134, 0.06529067934025079, 0.052965921931900084, 0.04871522658504546, 0.11620831079198979, 0.03347243728057947, 0.0207890240199049, 0.057192211752408184, 0.054918234163778834, 0.03248264976718929, 0.02520431844459381, 0.01841074128606124, 0.0513581443374278, 0.019673199421958998, 0.0351831841544481, 0.10958170387311839, 0.011229932806600118, 0.04108624161744956, 0.049061724203056656, 0.0558398591238074, 0.04517665904131718, 0.04566714815155137, 0.02768388578260783, 0.03265374449256342, 0.040956009543151595, 0.04692006783443503, 0.07451722995028831, 0.05864720711542759, 0.010883475079026539, 0.02105179439240601, 0.040174383320845664, 0.04697527620010078, 0.0872778581106104, 0.02640128761413507, 0.047217112442012876, 0.04800708782568108, 0.049368709878763184, 0.05374419364670757, 0.07366656544036232, 0.04920931882224977, 0.02744140201684786, 0.027830719700432383, 0.02659346861037193, 0.021674897870980203, 0.04091115784831345, 0.05362400654121302, 0.03586639046261553, 0.03520011254295241, 0.06646419293247163, 0.0310999766952591, 0.010480124310561223, 0.061893116144347005, 0.05602246084890794, 0.025692881681607105, 0.05894570262171328, 0.026792753815243486, 0.02888422430260107, 0.028380960975482594, 0.06784587894799188, 0.018828525899152737, 0.02444806625135243, 0.027470831882965285, 0.0918477882805746, 0.05340166280802805, 0.12355116443359293, 2.9519896348938346, 13.073773216456175, 32.93623365461826, 46.499556452035904, 49.7396881878376, 33.96192401647568, 23.491230569779873, 29.890860468149185, 38.18759746849537, 40.956197306513786, 21.61676835268736, 14.430312775075436, 5.842362251132727, 2.6939065335318446, 1.1083559948019683, 0.19961842917837203, 0.0397113314102171, 0.02999247157276841, 0.07503214685129933, 0.133595502411481, 0.04680857869971078, 0.02391633785009617, 0.06246677032322623, 0.09503200999461114, 0.2452935665496625, 0.09165119336103089, 0.12412960917572491, 0.10865194126381539, 0.12045553288771771, 0.24738340987823904, 0.19825299619697034, 0.15111820277525112, 0.04919272811093833, 0.4687818547245115, 1.0167159559205174, 1.0831281985156238, 2.2119382582604885, 4.026692379266024, 8.737372756004333, 12.884843554347754, 20.159392654895782, 23.200439773499966, 30.75573965907097, 32.90160611271858, 34.42404381930828, 31.029064692556858, 25.829231813549995, 29.08999264240265, 37.794557958841324, 46.396012008190155, 43.07902939617634, 48.80442537367344, 43.33065949380398, 42.87683844566345, 37.5313650816679, 33.15166309475899, 26.132940016686916, 20.423427186906338, 15.091531444340944, 7.241444326937199, 3.6225349036976695, 1.6851813113316894, 0.6806943460833281, 0.07614595466293395, 0.18818294280208647, 0.47263567917980254, 0.8289493876509368, 0.11889570174389519, 0.18383133021416143, 0.14074061822611839, 0.16575657587964088, 0.12998433056054637, 0.08707128130481578, 0.0364587133663008, 0.027143964071001392, 0.0468554713006597, 0.11953740715398453, 0.07423958508297801, 0.17008892231388018, 0.15598741883877665, 0.05229069742199499, 0.6865981011651456, 3.3130638347938657, 6.070690099149942, 17.07565862685442, 25.661191530525684, 30.913839675486088, 33.32853980362415, 25.438869260251522, 34.02790367603302, 40.76311446726322, 37.64397583901882, 22.33553398400545, 6.297832410782576, 0.21968050656141713, 0.08534493448678404, 0.046492108376696706, 0.08662214837386273, 0.02869490985176526, 0.025171916277031414, 0.00973349777268595, 0.0195557230108534, 0.010637831619533245, 0.09964401993784122, 0.012306479238759493, 0.10223010773188435, 0.03424823393288534, 0.023054763769323472, 0.08054969570366666, 0.06805193625041284, 0.04284877926693298, 0.03454921934462618, 0.0304653884813888, 0.03524776213453151, 0.06892928839079104, 0.01415910990544944, 0.040389854766544886, 0.08714381139725447, 0.036458858085097745, 0.010825851022673305, 0.05762241249612998, 0.05109284138598014, 0.09525550034595653, 0.05186131675145589, 0.08073934412095696, 0.025758767696970608, 0.03952442522859201, 0.05588467000052333, 0.023145988561736885, 0.08974141732323915, 0.05099230635096319, 0.043933428096352145, 0.03077357087022392, 0.07769310992443934, 0.1772749304655008, 0.13360810407903045, 0.1618037637672387, 0.27548477228265256, 0.11585084052057937, 0.12118239974370226, 0.149194170080591, 0.150929533992894, 0.25726572959683836, 0.19257544772699475, 0.07975952365086414, 0.1400172765715979, 0.18663114169612527, 0.13963226519990712, 0.18391335237538442, 0.19847482413752005, 0.12645810493268073, 0.12364687179797329, 0.1377872860757634, 0.1338175529963337, 0.16238323267316446, 0.11063277052016929, 0.17299002211075276, 0.1094842524616979, 0.104918062716024, 0.2104491987847723, 0.10583932031295262, 0.1884384494042024, 0.1295221655163914, 0.19865184120135382, 0.20590897678630427, 0.12373276797006838, 0.14850326027953997, 0.20652962004533038, 0.08683944921358489, 0.2649599011056125, 0.13232009194325656, 0.12729973008390516, 0.18973426893353462, 0.1815291287493892, 0.15565642097499222, 0.2687073015840724, 3.7250892631709576, 16.059256866574287, 37.71861143410206, 52.88139000535011, 57.75955304503441, 42.693616077303886, 30.83465952426195, 38.919905573129654, 46.62942588329315, 44.66947205364704, 28.194034919142723, 18.270787596702576, 7.511493936181068, 3.5370675148442388, 1.6310690087266266, 0.7016982533968985, 0.24536855315091088, 0.1156513586465735, 0.1371090521570295, 0.2120743240811862, 0.20733743294840679, 0.2659096126444638, 0.20692849473562092, 0.38567286275792867, 0.48334626539144665, 0.16937264590524137, 0.25835336185991764, 0.49550498952157795, 0.6484179280232638, 0.7349612528923899, 0.7821252127178013, 0.37156896956730634, 0.26382337615359575, 0.7524788472801447, 1.068030777387321, 0.8632629713974893, 3.025566511787474, 3.7265547970309854, 8.943245708942413, 13.83313586935401, 20.839957036077976, 24.521431289613247, 30.795261338353157, 35.36846034228802, 37.52901680767536, 35.753303691744804, 28.571119084954262, 33.008874356746674, 42.665470987558365, 49.12566013634205, 46.28180913627148, 49.387861266732216, 43.24095770716667, 41.89532831311226, 36.813427805900574, 32.85935238003731, 25.722573436796665, 19.46259744465351, 14.335399568080902, 7.422031536698341, 5.083020497113466, 1.3381758565083146, 1.2827022769488394, 0.4697931348346174, 0.31828787236008793, 0.646991163957864, 0.6690704729408026, 0.3924234083388001, 0.48920237459242344, 0.6035260087810457, 0.4137499717762694, 0.2859329350758344, 0.2397085787379183, 0.25703361548949033, 0.27161693607922643, 0.18100064538884908, 0.2473859183373861, 0.47589608235284686, 0.522465433459729, 0.2238015635521151, 0.351968968170695, 0.5328045005444437, 3.85347249917686, 7.945455349981785, 21.52065820991993, 35.78354246914387, 42.939147502183914, 45.597636848688126, 34.87849943339825, 43.951268792152405, 48.02409164607525, 44.044952765107155, 25.72006557136774, 8.242189027369022, 0.511322709498927, 0.22942184790736064, 0.19293590885354206, 0.1404188378364779, 0.11939310395973735, 0.12241161151905544, 0.09210037082084455, 0.12159937541582622, 0.23437740543158725, 0.18582197808427736, 0.14253581408411264, 0.20538751414278522, 0.17173711356008425, 0.1534564874600619, 0.16339577443432063, 0.3043134690960869, 0.1334365046932362, 0.13605934364022687, 0.09126629331149161, 0.14965694368584082, 0.1868038988322951, 0.12986736808670685, 0.19885636225808412, 0.16320893133524805, 0.15822465269593522, 0.1656597849796526, 0.1172728993697092, 0.17336425749817863, 0.12425768160028383, 0.130513274052646, 0.14366896968567744, 0.21474604087416083, 0.2106653418741189, 0.11726213080692105, 0.06990393609157763, 0.15349540568422526, 0.126425776979886, 0.27332206489518285, 0.16183551284484565], [0.03741583896044176, 0.05881800127099268, 0.05940948183706496, 0.045096310423105024, 0.01413856725775986, 0.00316875350108603, 0.02633744807098992, 0.03469075803877786, 0.028745268282364123, 0.03298743635241408, 0.03476304693322163, 0.02055031593044987, 0.027854089930769987, 0.03388023629668169, 0.048076140956254676, 0.04884839756414294, 0.005873648005945142, 0.016683858266333118, 0.03884970166836865, 0.01679491324466653, 0.1384392924956046, 0.007436800260620657, 0.03661309492599685, 0.03304877485788893, 0.02886827369366074, 0.021230343991192058, 0.06086529727326706, 0.07314755930565298, 0.03871453431202099, 0.036382899270392954, 0.023096069853636436, 0.013235612877906533, 0.014744095751666464, 0.07158857421018183, 0.03674930128909182, 0.02526135249354411, 0.015788885684742127, 0.07850054433220066, 0.022209006710909307, 0.0399839742021868, 0.0026939605822917656, 0.06159695840324275, 0.0794744276208803, 0.5855820060241967, 6.0647329688072205, 19.273107312619686, 28.073076009750366, 44.40152943134308, 29.518594443798065, 22.84082517027855, 20.198127776384354, 25.670789815485477, 21.040204390883446, 20.359275229275227, 18.551090955734253, 11.383940242230892, 3.8600865192711353, 2.8081362415105104, 0.6669618235900998, 0.09382287331391126, 0.07617444571224041, 0.020609114435501397, 0.07493024997529574, 0.11540056468220428, 0.014297394282039022, 0.020088959827262443, 0.02956296844786266, 0.03857097326545045, 0.045341894510784186, 0.17111543129431084, 0.06860052439151332, 0.20762449566973373, 0.24851836147718132, 0.11649259045952931, 0.27096236182842404, 0.11156802502227947, 0.6412500282749534, 1.1190929124131799, 0.33418022270780057, 0.9117600659374148, 1.804413094650954, 4.603927005082369, 7.267870483919978, 10.645860247313976, 13.711692485958338, 18.697992973029613, 20.38137674331665, 18.190651796758175, 19.44952804595232, 16.126190274953842, 17.49314222484827, 26.047786585986614, 33.181803077459335, 29.52635932713747, 36.42821967601776, 31.720960065722466, 29.41326219588518, 25.094626732170582, 20.01332089304924, 15.163819715380669, 11.208662297576666, 6.414441978558898, 3.3886852394789457, 0.5825475719757378, 1.0408245935104787, 1.2013626541011035, 0.18410059623420238, 0.036310647483333014, 0.2632440853631124, 0.4074802785180509, 0.030483469054161105, 0.130332546250429, 0.03561644254659768, 0.061532398976851255, 0.2764109132112935, 0.03902144206222147, 0.04995488408894744, 0.028380792136886157, 0.12625854142243043, 0.027220878400839865, 0.0676071597263217, 0.06468672698247246, 0.030487246585835237, 0.3007364657241851, 2.5404035579413176, 6.058492278680205, 11.084285471588373, 15.955151952803135, 25.70985931903124, 42.850505858659744, 31.501212157309055, 37.10703045129776, 30.79060658812523, 39.28505077958107, 25.265942439436913, 8.373114801943302, 2.365469019860029, 0.01834656963183079, 0.035177729369024746, 0.01576884213136509, 0.061772665576427244, 0.03397293054149486, 0.04545124254946131, 0.03996794381237123, 0.038185245721251704, 0.03871949556923937, 0.028682417650998104, 0.05203810003877152, 0.028210487798787653, 0.04097419587196782, 0.008991484610305633, 0.04301909102650825, 0.09030095214257017, 0.03146832314087078, 0.08155656745657325, 0.10423042578622699, 0.010355435151723213, 0.013772834099654574, 0.02444356698106276, 0.015163945390668232, 0.010034049028035952, 0.06872339436085895, 0.004677874621847877, 0.0524074632267002, 0.06632037955569103, 0.055080100282793865, 0.013508403171726968, 0.06854815102997236, 0.05699258515960537, 0.018766576977213845, 0.022932559877517633, 0.012382329514366575, 0.060100833215983585, 0.013558171594922896, 0.011358448664395837, 0.01685173949226737, 0.05066550904302858, 0.02713421781663783, 0.01769685830367962, 0.021011616372561548, 0.012970534426131053, 0.04312719225708861, 0.05037610484578181, 0.06250000369618647, 0.061664909444516525, 0.0546708726324141, 0.029859964815841522, 0.04231436243571807, 0.04386621920275502, 0.06320951171801426, 0.03971579542849213, 0.07943940567201935, 0.015119323761609849, 0.033796930219978094, 0.023386017674056347, 0.02802048129524337, 0.03888787774485536, 0.0033729106735336245, 0.07479586929548532, 0.030124733420962002, 0.02185702647693688, 0.03978402106440626, 0.0060724758623109665, 0.06446765240980312, 0.010407126665086253, 0.06782207827200182, 0.042936541940434836, 0.005199289025767939, 0.0386842992156744, 0.01803441675292561, 0.07794379256665707, 0.06719917146256194, 0.043962772615486756, 0.010008925473812269, 0.03514327516313642, 0.03549419969203882, 0.0354645471816184, 0.010962241995002842, 0.15532129677012563, 0.7006940979044884, 7.966461097821593, 23.52010142058134, 35.93269966542721, 50.413684621453285, 35.78971713781357, 28.313359916210175, 25.19510854035616, 32.26160265505314, 27.266696579754353, 24.671038761734962, 22.225945964455605, 11.863147728145123, 4.776869025081396, 2.283646110445261, 0.5267346231266856, 0.1004603823821526, 0.09280740006943233, 0.025967173896788154, 0.07085018922225572, 0.10376339967478998, 0.048746738175395876, 0.03535403397108894, 0.038458207636722364, 0.0238197695944109, 0.1426817203173414, 0.13227023446233943, 0.055518349618068896, 0.20310569205321372, 0.4286628356203437, 0.20886150741716847, 0.25458996067754924, 0.4797474725637585, 0.831637802766636, 2.445917115546763, 1.6857122140936553, 1.5040094079449773, 2.5626656133681536, 6.532704932615161, 7.540743816643953, 11.870158351957798, 14.928622785955667, 18.16655918955803, 22.784179709851742, 22.331986874341965, 23.9426501467824, 17.294775769114494, 19.98553868383169, 28.16865038126707, 37.05363571643829, 34.54536370933056, 40.06429396569729, 33.65251041948795, 32.02922612428665, 27.70795740187168, 22.32903443276882, 15.881592649966478, 13.241449669003487, 7.444475507363677, 3.9636031771078706, 3.314877999946475, 2.1951514715328813, 0.5936336552258581, 0.0872802255616989, 0.22140727640362456, 1.43866122700274, 1.8006001180037856, 0.6830183963757008, 0.335539688821882, 0.4278966423589736, 0.15147952479310334, 0.7607483910396695, 0.16015349450754002, 0.07301285208086483, 0.025714938310557045, 0.02167213893699227, 0.0476216126116924, 0.028039374519721605, 0.035078485670965165, 0.1694642417714931, 0.3724088135641068, 2.986866538412869, 6.912866458296776, 11.795696597546339, 15.91825308278203, 29.81764029711485, 49.56716224551201, 38.27276989817619, 40.893607065081596, 36.14716775715351, 45.33499874174595, 29.979597106575966, 10.730311665683985, 2.9964712355285883, 0.02692772264708765, 0.06542759074363858, 0.03608072642236948, 0.10593974773655646, 0.011200892568012932, 0.05831717775436118, 0.0684561172965914, 0.049243821267737076, 0.020685058407252654, 0.10769365049782209, 0.047751870661159046, 0.058879310090560466, 0.04514578198723029, 0.029946439863124397, 0.07022126359515823, 0.06561772897839546, 0.03245549829443917, 0.03993865866505075, 0.02473848348017782, 0.06261502916458994, 0.02363657044043066, 0.05429846663901117, 0.0915876061480958, 0.04327457907493226, 0.012610913781827549, 0.028402572315826546, 0.03505457367282361, 0.03606821381254122, 0.03262537960836198, 0.030529704854416195, 0.04576195751724299, 0.002172904032704537, 0.049768226526794024, 0.027239203882345464, 0.04649446469557006, 0.012397823702485766, 0.021652564792020712, 0.03529547109792475, 0.057052012634812854, 0.14072626509005204, 0.18688296724576503, 0.2655800397042185, 0.11431366714532487, 0.07465071263140999, 0.14845714322291315, 0.2912538667442277, 0.1075422672147397, 0.18812507012626156, 0.18568208324722946, 0.1235835294937715, 0.17342042323434725, 0.12521563097834587, 0.16381753695895895, 0.1821039369679056, 0.2101571933599189, 0.09180918175843544, 0.08142141494317912, 0.11974566121352836, 0.120147170528071, 0.2520981850102544, 0.15724558179499581, 0.21795131731778383, 0.12977204663911834, 0.11412988911615685, 0.12073996840626933, 0.0981449632672593, 0.20947524870280176, 0.16425817972049117, 0.2884305885527283, 0.1660348367295228, 0.07430401092278771, 0.10256947702146135, 0.1886581102735363, 0.17252426507184282, 0.12787571089575067, 0.20758784841746092, 0.21328254049876705, 0.1238015279523097, 0.13820211694110185, 0.1345984556246549, 0.16503627703059465, 0.32838390092365444, 0.9223545505665243, 9.31539298966527, 25.58731399476528, 41.49030424654484, 57.821797505021095, 46.66648909449577, 41.89777918159962, 32.122682109475136, 39.096238911151886, 32.31866419315338, 30.693658590316772, 26.49693388491869, 16.49962853640318, 5.704293809831142, 3.6123136896640062, 0.8177455107215792, 0.19941690639825538, 0.257026698673144, 0.20147804345469922, 0.1960713937296532, 0.3481712203938514, 0.1845978500205092, 0.2718679007375613, 0.11118144771899097, 0.16316254710545763, 0.49452384060714394, 0.5498110817279667, 0.25563897157553583, 0.71320581715554, 1.0999147477559745, 0.6479554215911776, 0.8920841873623431, 0.9218157513532788, 1.1228961520828307, 1.991871166974306, 1.5149474772624671, 1.4628218743018806, 2.305436753667891, 5.693747000768781, 9.477444794028997, 13.10081161558628, 15.595559198409319, 19.987199194729328, 23.896959498524666, 24.194776117801666, 27.1981368586421, 22.679970301687717, 24.350643754005432, 32.3051331192255, 40.687851905822754, 37.43636637926102, 41.9990361481905, 34.09686617553234, 33.33058029413223, 27.533573359251022, 23.457684069871902, 16.047302708029747, 14.25485149025917, 8.237531427294016, 6.991422018036246, 3.049774537794292, 4.914764575660229, 2.8055614046752453, 0.3333573293639347, 0.27007240802049637, 2.8462809696793556, 1.5106279402971268, 0.9821846557315439, 0.42104658961761743, 0.35355603613425046, 0.3039686079137027, 1.1108370241709054, 0.546587014105171, 0.14574989239918068, 0.12921562884002924, 0.22504719905555248, 0.22303287667455152, 0.17642402846831828, 0.17103369114920497, 0.28580513724591583, 0.22066210076445714, 3.3559573581442237, 9.026608485728502, 14.923356268554926, 22.351574823260307, 38.46770703792572, 53.592445850372314, 43.11160124838352, 48.93703065812588, 44.67682085931301, 49.95910741388798, 36.215336099267006, 13.759774155914783, 3.60394986346364, 0.16501086589414626, 0.15530042757745832, 0.15792089165188372, 0.24033334833802655, 0.1355340366717428, 0.1658919733017683, 0.12823143712012097, 0.25991481088567525, 0.24359640839975327, 0.13724955555517226, 0.1637423870852217, 0.17808295116992667, 0.12805122882127762, 0.09047361279954202, 0.14893030689563602, 0.15475266322027892, 0.17647914035478607, 0.24552452290663496, 0.1671889060526155, 0.12166326690930873, 0.07559462057542987, 0.1171298578265123, 0.20303125464124605, 0.14579673676053062, 0.15541091852355748, 0.08939856736105867, 0.1553109215456061, 0.19198693946236745, 0.15045877487864345, 0.16774585819803178, 0.20894397486699745, 0.12775454786606133, 0.17677219962934032, 0.16644289920805022, 0.14226847764803097, 0.12363844100036658, 0.11654229951091111, 0.12478367134463042, 0.10910833982052281], [0.0700938591035083, 0.02712252342462307, 0.013885098778700922, 0.05457863851916045, 0.013850028590240981, 0.047669611012679525, 0.09595263676601462, 0.0060051408036088105, 0.08472639150568284, 0.01652758237469243, 0.09067261969903484, 0.029991156116011553, 0.041723082249518484, 0.08476820410578512, 0.031389147115987726, 0.019904252258129418, 0.03838938086119015, 0.06468294945079833, 0.08063576999120414, 0.07568114757305011, 0.013562025196733885, 0.008918015701055992, 0.056417680461890996, 0.0543834239942953, 0.06279416877077892, 0.07356572983553633, 0.060574646267923526, 0.03604738543799613, 0.04177926653937902, 0.09952734690159559, 0.06377654222887941, 0.04703499311290216, 0.04589529176882934, 0.07874386486946605, 0.037532207716139965, 0.034547835239209235, 0.024113775107252877, 0.05442843154014554, 0.04261220856278669, 0.045459335669875145, 0.03996214392827824, 0.06358276004903018, 0.03870567677950021, 0.09293778057326563, 1.5878387284465134, 11.934021525084972, 26.664214208722115, 33.585235029459, 33.61093305051327, 27.598076798021793, 17.710294872522354, 20.60399539768696, 28.284074887633324, 21.874768808484077, 26.507565714418888, 21.24589115381241, 14.449464697390795, 5.319250971078873, 3.0029999976977706, 0.43503654829692096, 0.09893077149172314, 0.1417430370929651, 0.05041437740146648, 0.08762949510128237, 0.022291527966444846, 0.042058978287968785, 0.034406912527629174, 0.08065199333941564, 0.1306404484785162, 0.10571206425083801, 0.10455320807523094, 0.016512730144313537, 0.5236076284199953, 0.08165870924131013, 0.07851334637962282, 0.2137962551205419, 0.6129907071590424, 2.4418228352442384, 1.440718222875148, 0.1172405639954377, 1.3501695566810668, 2.4398899264633656, 2.187386588193476, 5.365838846191764, 6.585435178130865, 10.651884824037552, 10.821330081671476, 11.59120962023735, 12.159188892692327, 10.043981093913317, 12.504456415772438, 17.491952888667583, 22.948099114000797, 22.007885165512562, 25.732337012887, 22.86426231265068, 22.459749318659306, 17.623745016753674, 12.639425173401833, 8.239413276314735, 4.6519293542951345, 2.635090439580381, 0.5687001650221646, 2.1023032162338495, 2.4448762089014053, 0.3630957507994026, 0.13338312943233177, 0.27142296836245805, 0.21585702110314742, 2.555289496667683, 0.3481249400647357, 0.32506831164937466, 0.2735671220580116, 0.2336219436256215, 0.5230744101572782, 0.26561011152807623, 0.10185826205997728, 0.021624669316224754, 0.05805540000437759, 0.06533023581141606, 0.03317087670438923, 0.28062010766007006, 0.546923711663112, 1.5630854316987097, 4.200283689424396, 9.451148305088282, 12.377143297344446, 26.90097000449896, 25.280892737209797, 19.67648796737194, 26.34634606540203, 29.673778116703033, 41.190659925341606, 28.73130138963461, 16.514195054769516, 5.711915250867605, 0.4132266092346981, 0.012195117196824867, 0.023057018042891286, 0.034815620674635284, 0.017934022725967225, 0.05545429485209752, 0.032682844102964737, 0.038041328443796374, 0.03886374310241081, 0.055898930368130095, 0.08808081736788154, 0.053465921664610505, 0.041725390328792855, 0.03645089112978894, 0.03617452646722086, 0.07691050777793862, 0.011782813344325405, 0.01327506823145086, 0.024851609050529078, 0.057170099462382495, 0.030571393144782633, 0.08822832664009184, 0.05049155333836097, 0.04688511267886497, 0.03528055764036253, 0.03161198066663928, 0.03466897971520666, 0.02911760562710697, 0.04334969926276244, 0.047018086988828145, 0.07831475508282892, 0.034277604427188635, 0.05629580497043207, 0.025824700096563902, 0.0235235784566612, 0.07401553812087514, 0.04216727247694507, 0.052631061189458705, 0.07572713104309514, 0.03484980028588325, 0.027369604795239866, 0.04488804152060766, 0.011498083749756915, 0.07912817862234078, 0.05353515662136488, 0.03413341626583133, 0.06228012760402635, 0.018746372006717138, 0.04992315356503241, 0.06001133020617999, 0.02783755673590349, 0.06182028548209928, 0.011727318324119551, 0.03199266160663683, 0.038366689695976675, 0.03520358579407912, 0.0404321683163289, 0.022864178390591405, 0.014701930631417781, 0.048540391435381025, 0.016609582271485124, 0.05467736271384638, 0.08674507771502249, 0.0776574423070997, 0.054012201726436615, 0.029548299899033736, 0.04148382126004435, 0.04128064349060878, 0.07116989901987836, 0.062383419717662036, 0.026820933162525762, 0.044542193281813525, 0.012051630365021992, 0.06963550127693452, 0.045274715303094126, 0.04376037039037328, 0.035436022735666484, 0.052696863713208586, 0.0032901505392146646, 0.033180246318806894, 0.019903456304746214, 0.011778124826378189, 0.050425973458914086, 0.060926787919015624, 2.3108811490237713, 14.149414747953415, 30.992807038128376, 40.215487852692604, 39.333847761154175, 34.39972512423992, 24.279500171542168, 25.347527861595154, 32.27456375956535, 26.65345698595047, 30.25468524545431, 21.38472430408001, 13.41055579483509, 6.096059437841177, 2.266138787381351, 0.6343739409931004, 0.08528460530214943, 0.29930014279671013, 0.10921817767666653, 0.013402046915871324, 0.15738526883069426, 0.049490240271552466, 0.061248787242220715, 0.11279788246611133, 0.16213039780268446, 0.28000180958770216, 0.058636976609705016, 0.3776568069588393, 0.8225787326227874, 0.1600497867912054, 0.4880252690054476, 1.0455188853666186, 1.7084093461744487, 2.498347177170217, 2.7459782268851995, 2.2359503572806716, 2.3552326066419482, 3.3374283649027348, 3.719577183946967, 6.532410923391581, 7.16405862942338, 12.978402134031057, 15.889938902109861, 15.316982846707106, 15.97185205668211, 11.235380563884974, 15.332706402987242, 18.97099882364273, 25.228668339550495, 23.796603083610535, 28.142654076218605, 24.014798775315285, 24.241612404584885, 18.2777963206172, 14.29984962567687, 10.254787132143974, 7.016371954232454, 3.789870562031865, 2.0333297923207283, 4.457448665052652, 2.317325840704143, 0.03171733966155443, 0.1009340729797259, 0.2675431687384844, 2.217940748669207, 1.4755545160733163, 0.25676059420220554, 0.5590160877909511, 0.3643173852469772, 0.3418763534864411, 0.5586848524399102, 0.17538410145789385, 0.19244300405262038, 0.021775117493234575, 0.07650145082152449, 0.022592259192606434, 0.13576908968389034, 0.17170353879919276, 0.6755334511399269, 2.1516582928597927, 5.299285892397165, 12.930212169885635, 17.24828526377678, 29.561684131622314, 31.83287736028433, 24.556233622133732, 31.328976899385452, 36.08480550348759, 43.37220646440983, 33.50956588983536, 19.90827362984419, 6.998116308823228, 0.5378796032164246, 0.034920567777589895, 0.049841880972962826, 0.027464922532089986, 0.04317231854656711, 0.030197285777830984, 0.03277575728134252, 0.03627053440141026, 0.07046743397950195, 0.036041771090822294, 0.05626813028356992, 0.016835690548759885, 0.0321368126606103, 0.03445979797106702, 0.029030802179477178, 0.02232773735158844, 0.038770521932747215, 0.0403887675201986, 0.03600671574531589, 0.028834608019678853, 0.04815018502995372, 0.0749252553214319, 0.03901279233105015, 0.05270469337119721, 0.05091360530059319, 0.0358661975042196, 0.02898511927924119, 0.048964465750032105, 0.02995820475916844, 0.04870853612374049, 0.016206898508244194, 0.12527800106909126, 0.026091401996382046, 0.10297803673893213, 0.01464737350033829, 0.09458700340474024, 0.012883333929494256, 0.03323495744552929, 0.07305061997612938, 0.005118006229167804, 0.2647295978385955, 0.0743280045571737, 0.16932378290221095, 0.21058527898276225, 0.13265344983665273, 0.1830525352852419, 0.2536741504445672, 0.06850293939351104, 0.14041938702575862, 0.0726904408656992, 0.12879598885774612, 0.10522458454943262, 0.14709669747389853, 0.13070050306851044, 0.22026533377356827, 0.12402779393596575, 0.1470159666496329, 0.17344537423923612, 0.1590995112201199, 0.1352400571340695, 0.2007436883286573, 0.09696999506559223, 0.2510375966085121, 0.1343623487628065, 0.093609580071643, 0.18854518508305773, 0.12945232942001894, 0.19747999001992866, 0.14539651136146858, 0.20669758290750906, 0.14128606708254665, 0.08957905767601915, 0.16192295268410817, 0.17137902730610222, 0.10953229168080725, 0.15389474050607532, 0.09707475663162768, 0.13298746082000434, 0.14759936893824488, 0.1349997497163713, 0.1899051558575593, 0.13408040686044842, 0.19410385633818805, 0.22269923676503822, 2.9552208865061402, 16.31196040660143, 37.08097904920578, 46.185404509305954, 49.42655459046364, 45.009747594594955, 30.89553415775299, 32.87030719220638, 42.333611994981766, 31.15994106978178, 38.91379550099373, 26.794585213065147, 18.790329918265343, 6.977119585499167, 3.7205494567751884, 1.149890497326851, 0.31569198821671307, 0.7211697741877288, 0.20739009574754164, 0.19857255014358088, 0.3887104138266295, 0.11426163517171517, 0.2704816876212135, 0.17699977179290727, 0.2708448946941644, 0.49806308350525796, 0.26996360917109996, 0.43819643498864025, 1.1295997048728168, 0.15399693424114957, 0.8801275945734233, 1.2403279007412493, 1.9193456461653113, 4.223951194435358, 2.6177403330802917, 1.5625728154554963, 2.4179330421611667, 3.205274068750441, 2.829983406700194, 5.940384166315198, 8.823574930429459, 13.424319606274366, 16.056186631321907, 16.93447720259428, 19.766803421080112, 15.056483075022697, 18.848309107124805, 23.79739724099636, 27.914020344614983, 26.236967034637928, 30.427608266472816, 26.155303716659546, 24.597235321998596, 19.82526708394289, 14.907919596880674, 10.552616100758314, 6.268355017527938, 4.6953686233609915, 0.9601586032658815, 2.874974892474711, 6.85380432754755, 0.8748427906539291, 0.4462053661700338, 0.41229194845072925, 2.6814099540933967, 9.95657628402114, 1.2720535858534276, 0.9522929065860808, 0.9288846782874316, 1.055185804143548, 1.5248173289000988, 0.7841979421209544, 0.26385555567685515, 0.15256632585078478, 0.4491613997379318, 0.21886797359911725, 0.1743096497375518, 0.3369131073122844, 0.734173032687977, 2.7375913644209504, 5.9875567350536585, 14.285753332078457, 19.586647488176823, 37.688501849770546, 34.28096629679203, 29.418177232146263, 40.715765208005905, 42.766374573111534, 53.254704773426056, 38.79012353718281, 24.077639803290367, 8.851196598261595, 0.9037616138812155, 0.09288720320910215, 0.09946646852768026, 0.07838324047042988, 0.17609426256967708, 0.11056193252443336, 0.1269944105297327, 0.10774119247798808, 0.13552373566199094, 0.10884757881285623, 0.1971242341096513, 0.17687195912003517, 0.09978501315345056, 0.18579529045382515, 0.10379702638601884, 0.18766666034935042, 0.13003938307520002, 0.10236128975520842, 0.08505232050083578, 0.19043988810153678, 0.07240626509883441, 0.1689788920339197, 0.15284230088582262, 0.13823766581481323, 0.21771731815533713, 0.13249967683805153, 0.08708598325029016, 0.11964994642767124, 0.13658571930136532, 0.16089579061372206, 0.1523068264941685, 0.1631770041421987, 0.14394258469110355, 0.19835685234284028, 0.11365972372004762, 0.22006906539900228, 0.10820909432368353, 0.12970914220204577, 0.22210820519831032, 0.10797613416798413], [0.05031653265177738, 0.059100262296851724, 0.05437926796730608, 0.043986079763271846, 0.010792515604407527, 0.07609327702084556, 0.018673266749829054, 0.04097339806321543, 0.026746664589154534, 0.026351808628533036, 0.011472571495687589, 0.07070763007504866, 0.03386461779882666, 0.027508950443007052, 0.03798350029683206, 0.03760284904274158, 0.050221003402839415, 0.05427430602139793, 0.0436971356975846, 0.08873504280927591, 0.05169766576727852, 0.01289592168177478, 0.053237507163430564, 0.10586231204797514, 0.02542655642173486, 0.04939723061397672, 0.030172006372595206, 0.034348089902778156, 0.05230414884863421, 0.023000878281891346, 0.0627071742201224, 0.060252038383623585, 0.03731270269781817, 0.056893705113907345, 0.13530221942346543, 0.02707978870603256, 0.06888731993967667, 0.018741523927019443, 0.06316386963590048, 0.08856581087457016, 0.08462315876386128, 0.02614819855807582, 0.01897506295790663, 0.08605246097431518, 0.897990851663053, 4.942331621423364, 16.6422937810421, 31.466499119997025, 34.60966005921364, 29.998803175985813, 22.574045285582542, 21.76546387374401, 21.120383888483047, 25.245636329054832, 37.03137271106243, 32.746775820851326, 22.40769401192665, 9.558123964816332, 4.9609696213155985, 1.6775045357644558, 0.40387845772784203, 0.14329967700177804, 0.032621423961245455, 0.11194498409167863, 0.0733288362971507, 0.03603149605623912, 0.08267073149909265, 0.10752868591225706, 0.07729041317361407, 0.19528468750650063, 0.139986225112807, 0.42585374729242176, 0.4197986237704754, 0.2651783300098032, 0.2714846556773409, 0.4165609896881506, 1.4943264587782323, 3.73702276032418, 2.557974527589977, 1.6941250814124942, 1.8075727438554168, 1.6317701898515224, 0.9261549997609109, 2.213369831442833, 2.6815474592149258, 5.191703215241432, 9.008819740265608, 6.855908464640379, 8.534615635871887, 5.975989205762744, 7.199179194867611, 9.914659783244133, 13.518888931721449, 11.33957002311945, 16.65599774569273, 13.813821505755186, 12.724276520311832, 10.199691988527775, 7.976161502301693, 3.636544276960194, 2.272453336045146, 0.7537837803829461, 1.6079099639318883, 7.390095200389624, 0.9905540035106242, 0.022673233070236165, 0.05108212848426774, 0.4552976251579821, 1.071311307605356, 0.9673004981596023, 0.27005486364942044, 0.09377556139952503, 0.35500818165019155, 0.28640028031077236, 0.2014107900322415, 0.03419903325266205, 0.17406968370778486, 0.12752497190376744, 0.09528409529593773, 0.016772891867731232, 0.0768343337404076, 0.20768621267052367, 1.699894240591675, 5.309211909770966, 7.980641461908817, 11.87277926132083, 19.003150798380375, 26.437005400657654, 17.750133834779263, 22.860603109002113, 31.09096147119999, 33.32323148846626, 35.548297092318535, 26.066848263144493, 10.666130259633064, 2.4484983645379543, 0.2074976181029342, 0.055084356499719433, 0.0948974586208351, 0.1019170178915374, 0.03150145632389467, 0.06193089888256509, 0.019069488262175582, 0.0657067124848254, 0.05710275327146519, 0.09225883419276215, 0.06457012073951773, 0.013971045973448781, 0.01056193124895799, 0.04762412478157785, 0.10251971601974219, 0.03290108004875947, 0.022991085643297993, 0.019546145595086273, 0.03805106542131398, 0.07446348361554556, 0.02897769409173634, 0.05148281030415092, 0.027628336029010825, 0.012463455532270018, 0.07699898662394844, 0.06573354854481295, 0.029242907985462807, 0.059947197514702566, 0.038448593113571405, 0.03655670283478685, 0.029026406809862237, 0.051248336167191155, 0.09652272492530756, 0.05026449325669091, 0.05538415447517764, 0.14054654660867527, 0.03452129974903073, 0.05009875683754217, 0.07056711183395237, 0.07300338227651082, 0.0504811224527657, 0.09284066312829964, 0.015141292260523187, 0.01735709753120318, 0.012726692530122818, 0.03126158677332569, 0.026519895800447557, 0.029651348959305324, 0.018052269115287345, 0.01887118454760639, 0.0531513178430032, 0.04003326022939291, 0.033814500566222705, 0.05953976957243867, 0.04894082092505414, 0.04147901214309968, 0.012696813664661022, 0.09217635189997964, 0.07461793939000927, 0.05763559674960561, 0.029366950548137538, 0.017240311317436863, 0.07892382825957611, 0.050825452999561094, 0.07494800214772113, 0.07743647525785491, 0.06338756036711857, 0.044005679883412085, 0.020572541397996247, 0.054383579845307395, 0.06407973181921989, 0.04913306314847432, 0.04091953298484441, 0.04637104182620533, 0.08174346250598319, 0.06293089463724755, 0.04405063918966334, 0.018585825055197347, 0.033186064756591804, 0.05852483067428693, 0.011420417067711242, 0.018904525531979743, 0.050562844044179656, 0.09172705569653772, 1.055056017357856, 6.716834027320147, 21.201410740613937, 36.317816600203514, 40.714632868766785, 37.03253924846649, 27.768843434751034, 27.57038578391075, 26.824221722781658, 28.301191069185734, 45.12121841311455, 37.28918507695198, 27.225394695997238, 11.059643793851137, 4.730930915102363, 1.565444867592305, 0.3591246373252943, 0.18812253198120743, 0.022463826826424338, 0.06420016754418612, 0.06241539143957198, 0.18679468135815114, 0.1274620377807878, 0.06345437592244707, 0.268815269228071, 0.5822256579995155, 0.7704708818346262, 1.6757506923750043, 1.8496328056789935, 1.2201832816936076, 0.27494092646520585, 1.4373334357514977, 4.069280968979001, 3.9488464314490557, 5.232269363477826, 5.550856618210673, 3.168750903569162, 2.562030809931457, 1.7475883313454688, 3.039438617415726, 4.201690088957548, 7.3746713530272245, 10.15824381262064, 11.255397889763117, 11.619962677359581, 7.491857064887881, 8.124197758734226, 12.225494384765625, 15.919378772377968, 13.414366990327835, 18.332313895225525, 14.78339932858944, 16.045165322721004, 11.984477117657661, 9.113370180130005, 4.946632040664554, 4.421741981059313, 3.0953621165826917, 3.66329959128052, 6.860800227150321, 1.0383442766033113, 0.2671629219548777, 0.13919891032855958, 0.7042306393850595, 5.38104753009975, 0.28013070579618216, 0.4496843466768041, 0.6549522117711604, 0.5288418475538492, 0.6855321989860386, 0.9205925138667226, 0.011127292855235282, 0.279169327695854, 0.15987504069926217, 0.039629457678529434, 0.041344256678712554, 0.09171717028948478, 0.38719423580914736, 2.276071454398334, 6.521343067288399, 11.439036335796118, 14.937753695994616, 19.460832439363003, 34.21174541115761, 21.09649647027254, 24.58910185843706, 35.88651694357395, 37.95268267393112, 41.734608337283134, 29.557449258863926, 13.27833903953433, 2.9404403921216726, 0.14759019599296153, 0.0745845575875137, 0.05755196041718591, 0.0073765035449469, 0.007978553221619222, 0.01855385889939498, 0.05803016327263322, 0.05154548096470535, 0.060327125174808316, 0.05983570466923993, 0.09004785009892657, 0.08571075391955674, 0.05228990332398098, 0.034528762043919414, 0.02153166522475658, 0.021287743547873106, 0.03806728505878709, 0.015473984076379566, 0.04622599277354311, 0.03363127543707378, 0.040515121872886084, 0.03837439689959865, 0.04295733320759609, 0.05872082445421256, 0.04743938938190695, 0.052828683983534575, 0.013104410445521353, 0.06542868170072325, 0.05097351146105211, 0.019640218379208818, 0.01621500647161156, 0.04766560341522563, 0.05847513646585867, 0.048272041967720725, 0.0313976521283621, 0.05528214627702255, 0.037767724570585415, 0.07074677836499177, 0.027902006695512682, 0.06629479772527702, 0.11536770238308236, 0.19645610824227333, 0.14513377624098212, 0.14024835167219862, 0.10476984840352088, 0.17897326120873913, 0.10645942180417478, 0.07168041498516686, 0.07004495899309404, 0.10345859220251441, 0.2379752928391099, 0.150958833983168, 0.09665552483056672, 0.20957848144462332, 0.15584940905682743, 0.17005712870741263, 0.1558776551974006, 0.24855119409039617, 0.18070625024847686, 0.164898757066112, 0.13455288775730878, 0.06074948141758796, 0.20133231533691287, 0.2220640325685963, 0.12175062511232682, 0.1563621885725297, 0.1012240003910847, 0.18133041128749028, 0.10105237131938338, 0.11026372274500318, 0.16343766124919057, 0.13013151328777894, 0.14892558683641255, 0.1576019314234145, 0.23007069277809933, 0.19533804792445153, 0.22932449297513813, 0.1169578057306353, 0.20734383026137948, 0.23002098372671753, 0.10776295966934413, 0.16228810418397188, 0.11726991593604907, 0.11123388045234606, 1.3406798033975065, 7.299754098057747, 23.616547845304012, 42.27014400064945, 47.62198582291603, 46.96675658226013, 34.86081138253212, 34.06221203505993, 35.391661897301674, 35.57701215147972, 50.24730674922466, 39.958971217274666, 27.889498360455036, 12.198819816112518, 6.956317126750946, 2.8810422169044614, 0.7908688404131681, 0.33968695846851915, 0.13953712186776102, 0.35770838207099587, 0.23578215739689767, 0.489030463504605, 0.1529736164957285, 0.13757152890320867, 0.2911389822838828, 0.5113003263249993, 0.8790948218666017, 2.4005116894841194, 5.8492175582796335, 2.8244520910084248, 0.33191619731951505, 1.6643044003285468, 5.135779716074467, 7.094783121719956, 3.9453349448740482, 4.704123353585601, 4.139381032437086, 2.515085991472006, 2.9069665633141994, 2.880320968106389, 4.087497666478157, 6.574850371107459, 11.452231127768755, 11.193405166268349, 14.097431637346745, 11.524131819605827, 11.887101642787457, 15.225901734083891, 19.321701005101204, 15.417553000152111, 19.79289662092924, 15.086444467306137, 15.90278696268797, 12.142400443553925, 10.896916575729847, 4.397073704749346, 3.851477368734777, 4.5594969391822815, 3.6797037860378623, 13.257795441895723, 3.7526161735877395, 0.4010577325243503, 0.265497780055739, 0.5525291233789176, 11.358548104763031, 3.456330872140825, 1.1238959734328091, 1.217446953523904, 1.3769067032262683, 0.5401086586061865, 0.8284070261288434, 0.12291771912714466, 0.4550150450086221, 0.44215997855644673, 0.1958919721073471, 0.20319286471931264, 0.23442205303581432, 0.7293727621436119, 2.426502532325685, 5.927891386672854, 11.83572269976139, 17.12899636477232, 29.325032830238342, 38.98455150425434, 27.5387429818511, 32.88393326103687, 43.47543552517891, 46.226153522729874, 46.93865709006786, 33.00608150660992, 15.976522006094456, 3.259105305187404, 0.41670965671073645, 0.16369877848774195, 0.17331456328975037, 0.19345098902704194, 0.11464020470157266, 0.20134953316301107, 0.16766972868936136, 0.1988438199623488, 0.1959445161628537, 0.210405575344339, 0.19805073126917705, 0.20945670985383913, 0.10907350340858102, 0.13326882384717464, 0.26446916337590665, 0.15297092992113903, 0.12750301917549223, 0.06504677250632085, 0.14527980121783912, 0.18163114436902106, 0.13626882224343717, 0.11679736824589781, 0.10858039080630988, 0.2174730328260921, 0.1865982497110963, 0.2730224747210741, 0.12884547526482493, 0.18600030132802203, 0.17316132463747635, 0.11736332264263183, 0.1123456028290093, 0.15944759332342073, 0.11337572606862523, 0.16305132885463536, 0.10378910767030902, 0.2488959810580127, 0.15515982027864084, 0.1535248541040346, 0.16150105657288805, 0.23887571092927828], [0.03126872252323665, 0.029808461622451432, 0.022267001841100864, 0.020673948456533253, 0.04799428577825893, 0.005182471959415125, 0.02634807191498112, 0.012490252629504539, 0.014696761572849937, 0.048492812347831205, 0.07114549720427021, 0.06544225558172911, 0.0317564545548521, 0.016203571831283625, 0.014423240263568005, 0.029052209429210052, 0.008000898360478459, 0.00505387539305957, 0.0724796783470083, 0.021211999955994543, 0.052002428710693493, 0.05052509099186864, 0.08435761090368032, 0.02741582389717223, 0.10202678153291345, 0.06712442977004685, 0.07268865971127525, 0.01830485722166486, 0.0577191477350425, 0.05131180463649798, 0.036448794562602416, 0.028233826487849, 0.053963153186487034, 0.030783502661506645, 0.06659576829406433, 0.04687279673817102, 0.07562867773231119, 0.06931980649824254, 0.04441396871698089, 0.03522319704643451, 0.09688316378742456, 0.016663449205225334, 0.07477515595383011, 0.07497162470826879, 0.17659690434811637, 1.3121704082004726, 9.417221825569868, 21.436927802860737, 34.804357811808586, 30.429770350456238, 26.802616082131863, 21.09020210802555, 19.932922907173634, 21.4004098623991, 23.913794495165348, 27.40606550127268, 20.21656058728695, 16.79904107004404, 12.120715007185936, 5.019685495644808, 1.7154382565058768, 0.5869356240145862, 0.17034479998983443, 0.06463305486249737, 0.07398048648610711, 0.10492115747183561, 0.05987009950331412, 0.13434340915409848, 0.569044699659571, 0.47130756138358265, 0.26456395047716796, 1.5886221989057958, 0.40723088721279055, 1.140976888127625, 0.5420579540077597, 1.4614696218632162, 3.381175654940307, 0.5360042850952595, 8.835993614047766, 6.431075111031532, 0.8711858431342989, 1.8822331563569605, 0.9079846122767776, 1.5354660199955106, 0.6738520413637161, 3.279002937488258, 4.555567475035787, 4.399607693776488, 5.059991832822561, 3.2513207104057074, 4.237614311277866, 5.760479019954801, 8.42882551252842, 6.560094812884927, 8.10780543833971, 7.491008760407567, 7.400075364857912, 4.54189533367753, 3.140934258699417, 1.8075424642302096, 3.184037245810032, 0.7693411549553275, 3.988976078107953, 5.636975672096014, 0.19591874879552051, 0.02019743584241951, 0.21616493817418814, 2.310398337431252, 3.478161650709808, 0.3952937090070918, 0.05139341490576044, 0.26663213793653995, 0.07342491473536938, 1.0077630425803363, 0.5335323396138847, 0.07209568371763453, 0.12012248669634573, 0.17259818298043683, 0.017257898362004198, 0.051695328002097085, 0.8383588108699769, 1.3483112188987434, 3.3253003656864166, 4.634139658883214, 8.54382824152708, 15.637455750256777, 30.579883195459843, 22.05103375017643, 26.639707423746586, 28.442290797829628, 28.68762083351612, 34.2461259663105, 23.492391407489777, 14.542525503784418, 4.204211253672838, 0.6952762417495251, 0.012240286159794778, 0.08303751572384499, 0.04248019162332639, 0.014418379196285969, 0.031094323385332245, 0.03145264898194, 0.044631703713093884, 0.007736022143944865, 0.037813318413100205, 0.016465961853100453, 0.0695720105431974, 0.042322726440033875, 0.06549913377966732, 0.024441772839054465, 0.019473084867058787, 0.03046183173864847, 0.014649536860815715, 0.058242922168574296, 0.02865209349693032, 0.0657475454499945, 0.015847641516302247, 0.02436778071569279, 0.11475052495370619, 0.025896771912812255, 0.049868995338329114, 0.009132674495049287, 0.038727488499716856, 0.028713033098028973, 0.06532095154398121, 0.014699412895424757, 0.017352722570649348, 0.0564787851908477, 0.008958549951785244, 0.04057495010783896, 0.06347192771499977, 0.028524316076072864, 0.014843874723737827, 0.009743735699885292, 0.015662728001188952, 0.029613892766064964, 0.018324299635423813, 0.027485988393891603, 0.018840817720047198, 0.028279973230382893, 0.02393084498180542, 0.021475438261404634, 0.017084404644265305, 0.07633513552718796, 0.04087555702426471, 0.0407691478903871, 0.016529107488167938, 0.06813559113652445, 0.03807087705354206, 0.0070349402813008055, 0.034985520542250015, 0.041927191414288245, 0.07012142988969572, 0.06224728385859635, 0.06542975781485438, 0.059318728308426216, 0.03838504300802015, 0.04236883978592232, 0.0530315611831611, 0.035170660412404686, 0.042846007345360704, 0.027814438835775945, 0.016711468015273567, 0.05625538760796189, 0.009064923833648209, 0.05141295936482493, 0.0063707232129672775, 0.03651931714557577, 0.025912056444212794, 0.02071356058877427, 0.11240950174396858, 0.039648542006034404, 0.02957393924589269, 0.02284019774378976, 0.026906512066489086, 0.045683067219215445, 0.026715683634392917, 0.04337852056778502, 0.035124847636325285, 0.11403886470361613, 0.22784757456975058, 1.7326230718754232, 11.902254279702902, 27.049032859504223, 40.71715213358402, 37.527090311050415, 32.92083688080311, 28.099049516022205, 25.687670409679413, 28.34319021552801, 30.676014237105846, 33.466191217303276, 24.71959065645933, 20.534350834786892, 12.855893857777119, 5.723843760788441, 1.6739044664427638, 0.6361707695759833, 0.0757532323768828, 0.14175587624777108, 0.15629797795554623, 0.12852057785494253, 0.22121571324532852, 0.07175568360253237, 0.24917444970924407, 1.1016431800089777, 0.507351269479841, 1.9713088078424335, 3.7169422628358006, 4.016249114647508, 2.211053380742669, 5.84652635268867, 10.833609122782946, 6.365803638473153, 6.809716243296862, 5.302730407565832, 3.363608722575009, 6.553590036928654, 2.605308825150132, 1.9198846234939992, 2.8663066076114774, 5.835371101275086, 7.934846794232726, 7.23354977555573, 8.043000865727663, 6.212675180286169, 5.893427710980177, 10.314674768596888, 11.685400865972042, 6.633018599823117, 8.741659875959158, 10.729624852538109, 9.98695945367217, 6.981365382671356, 4.499996406957507, 4.036767538636923, 4.7324014361947775, 2.443016446195543, 5.792427230626345, 6.182646341621876, 2.4844767339527607, 0.16743837157264352, 0.1631701912265271, 2.372975517064333, 3.0601553432643414, 0.19352984963916242, 0.2391914650797844, 0.738284649560228, 0.5189184425398707, 0.8785075752530247, 0.23082808416802436, 0.16288453858578578, 0.1305783455609344, 0.05739901120250579, 0.057074013602687046, 0.017382833357260097, 0.6153659359551966, 1.352360851597041, 4.3664549477398396, 7.578628258779645, 13.248731028288603, 19.08767156302929, 37.821194529533386, 28.625041991472244, 29.76370219141245, 34.11916717886925, 33.96710693836212, 38.332472294569016, 27.810356207191944, 17.448487021028996, 6.145513309165835, 0.6393852189648896, 0.08160474026226439, 0.018250715693284292, 0.05457848637888674, 0.04769045423017815, 0.08767714840359986, 0.126681313267909, 0.04178423521807417, 0.047480938519584015, 0.044597724481718615, 0.03985154166002758, 0.024354557499464136, 0.02978339558467269, 0.040244534829980694, 0.06726049512508325, 0.041591239714762196, 0.07721329660853371, 0.08459203309030272, 0.015382272249553353, 0.023986422565940302, 0.06441297096898779, 0.04800893206265755, 0.04217282374156639, 0.10360414962633513, 0.04365793174656574, 0.04776215682795737, 0.020805648127861787, 0.014135699784674216, 0.04019777952635195, 0.04743039084132761, 0.04424150843988173, 0.047261715517379344, 0.07141947586205788, 0.0376882294222014, 0.013833768134645652, 0.03798160782025661, 0.014314322670543334, 0.03118685621302575, 0.04352466428827029, 0.05910487845540047, 0.013842297266819514, 0.10909147080383264, 0.12218276286148466, 0.14267977589042857, 0.0985837061307393, 0.14926373900379986, 0.07890554174082354, 0.10409175549284555, 0.16352453705621883, 0.11378640090697445, 0.12329996970947832, 0.13080294913379475, 0.1796554433531128, 0.23291614634217694, 0.137011697224807, 0.16927760647377, 0.1034925231942907, 0.1358958930359222, 0.13179549743654206, 0.18984069291036576, 0.11570011032745242, 0.12146281282184646, 0.12845654535340145, 0.18064117874018848, 0.1898801454808563, 0.125567453505937, 0.14955975202610716, 0.19729780760826543, 0.17443621560232714, 0.12063030124409124, 0.10225215693935752, 0.16102758119814098, 0.11891138332430273, 0.19820564717520028, 0.07986604410689324, 0.1814664766425267, 0.14402595756109804, 0.2425811206921935, 0.11256780184339732, 0.12590847036335617, 0.14146571134915575, 0.2378600966767408, 0.08333307603606954, 0.1937029036344029, 0.2190641380730085, 0.3636485617607832, 2.5698728766292334, 13.39179715141654, 30.598842278122902, 47.9793756455183, 46.557697132229805, 39.29329253733158, 39.139070212841034, 34.32195469737053, 35.311706587672234, 34.6310643106699, 36.89152501523495, 30.694751031696796, 22.414007373154163, 15.96867922693491, 6.726029058918357, 2.2709906520321965, 0.7506195595487952, 0.3747382073197514, 0.17983210418606177, 0.4162675444968045, 0.31447103654500097, 0.5328574008308351, 0.5610712431371212, 0.930389694403857, 2.6037162356078625, 3.1409656070172787, 5.12636287137866, 6.523199267685413, 4.639134015887976, 1.2065220647491515, 5.18606336787343, 9.163696579635143, 3.8839485263451934, 15.22844284772873, 13.123813681304455, 5.9607116505503654, 7.196632381528616, 2.936853147111833, 2.340712873265147, 2.3550343047827482, 5.230849189683795, 7.570159938186407, 8.88564269989729, 9.232753124088049, 6.875316398218274, 7.964486153796315, 10.57304285466671, 12.788377180695534, 10.183580853044987, 10.581813734024763, 10.004571508616209, 9.984147604554892, 6.3858219143003225, 3.4775448963046074, 3.989875204861164, 5.379230277612805, 3.3182759676128626, 11.10303271561861, 12.280986607074738, 1.915127991233021, 0.13396026799455285, 0.48537975002545863, 5.065194228664041, 15.373527612537146, 1.0103970137424767, 0.8793522580526769, 0.655762815149501, 0.5164069554302841, 2.418597531504929, 3.107695304788649, 0.5481681448873132, 0.6603296950925142, 0.3306507464731112, 0.24961804621852934, 0.18312778905965388, 1.0079583758488297, 1.701136773917824, 5.051590483635664, 8.146749548614025, 15.460600890219212, 25.86569845676422, 44.70964729785919, 31.02844912558794, 39.65011239051819, 42.84571051597595, 39.85031604766846, 46.442445516586304, 33.7098341435194, 19.123839922249317, 6.89639956690371, 1.0944647714495659, 0.14148689224384725, 0.12313637809711508, 0.08091638344922103, 0.20762747910339385, 0.1529481608304195, 0.2583055378636345, 0.21664840285666287, 0.12404053661157377, 0.120567322592251, 0.11069117754232138, 0.2032243911526166, 0.07827271241694689, 0.1526415054104291, 0.1408493280177936, 0.14551047555869445, 0.14944324968382716, 0.17069806228391826, 0.13915319403167814, 0.2785562543431297, 0.2617804514011368, 0.14441831619478762, 0.17331763578113168, 0.17012022610288113, 0.11701283598085865, 0.142406398372259, 0.1032348420994822, 0.18224479659693316, 0.24345114041352645, 0.20359763206215575, 0.12836224806960672, 0.11028672932297923, 0.12322973285336047, 0.09972555228159763, 0.09057238523382694, 0.17991572938626632, 0.08134679941576906, 0.12067903066053987, 0.12663209403399378, 0.12830519175622612, 0.21068000671220943], [0.038195461384020746, 0.014832592223683605, 0.05115731546538882, 0.012622995018318761, 0.07789185707224533, 0.07160154695156962, 0.028184269576740917, 0.03477891405054834, 0.08588636090280488, 0.0185733755279216, 0.03470069910690654, 0.06004705348459538, 0.03494726654025726, 0.01540015522550675, 0.09459394248551689, 0.029965154972160235, 0.019307511720398907, 0.00968841972280643, 0.03732344899617601, 0.032015527176554315, 0.041506018897052854, 0.033586902427487075, 0.07754877704428509, 0.0496824045694666, 0.09831062547164038, 0.057893322373274714, 0.05229497219261248, 0.052152004864183255, 0.03269564615038689, 0.07565747306216508, 0.0047547703979944345, 0.037558142066700384, 0.051402788230916485, 0.03868052168400027, 0.07205499176052399, 0.051998699418618344, 0.02096773689117981, 0.00922911565794493, 0.02870547803468071, 0.07871567067923024, 0.03425792638154235, 0.031134215678321198, 0.09412515748408623, 0.10730380032327957, 0.0865353542030789, 0.2894824492977932, 4.331654040142894, 11.55293332412839, 25.056856758892536, 37.17595495283604, 37.1014067530632, 33.74209061264992, 25.63669614493847, 19.302990809082985, 25.144759342074394, 22.36180767416954, 24.757503122091293, 20.92111498117447, 16.247618459165096, 10.803457740694284, 5.673305047675967, 2.3154375795274973, 0.9607703110668808, 0.15767292527016252, 0.08127032851916738, 0.03751215117517859, 0.06629466413869523, 0.14086991519434378, 0.39485741523094475, 0.8301758312154561, 0.6967712240293622, 0.7090780511498451, 1.341494859661907, 2.128596855327487, 3.7425942113623023, 5.381772816181183, 12.958756238222122, 11.211383901536465, 7.070064023137093, 5.685296254232526, 2.030457858927548, 4.297760808840394, 1.0539627447724342, 0.43605608108919114, 2.9839518573135138, 3.7820828799158335, 4.093711283057928, 1.4658538741059601, 2.532455096952617, 2.0216233329847455, 2.5860041985288262, 4.821160398423672, 4.2225452698767185, 3.62463619094342, 2.9322874546051025, 3.447780143469572, 3.613116634078324, 3.869078499265015, 1.3241860759444535, 1.9926653243601322, 2.3476890614256263, 2.114287060685456, 5.136468429118395, 3.40892200358212, 1.8821146502159536, 0.4530131758656353, 0.8092658501118422, 1.7689766711555421, 0.7882057770621032, 0.08637289065518416, 0.23309213924221694, 0.6361105665564537, 1.4420728501863778, 0.49722510972060263, 0.2209012207458727, 0.12451580056222156, 0.01139828529630904, 0.051548772389651276, 0.1174091873690486, 0.9225485776551068, 1.374189374037087, 4.261339763179421, 8.711672835052013, 20.61148289591074, 24.108938723802567, 29.852693416178226, 18.291796669363976, 16.175517328083515, 22.40971740335226, 29.021584913134575, 36.20937421917915, 28.09343531727791, 17.109011337161064, 5.720031140372157, 1.567723082844168, 0.022259717661654577, 0.06527172488858923, 0.030901749050826766, 0.017442231146560516, 0.01254774217159138, 0.0708176163607277, 0.06748810439603403, 0.018435868551023304, 0.021540775087487418, 0.032217513798968866, 0.05430672303191386, 0.028626647108467296, 0.0536444823956117, 0.09374642468173988, 0.08600286324508488, 0.050770738162100315, 0.047905691899359226, 0.026302934493287466, 0.06528007404995151, 0.0909195990243461, 0.021109641093062237, 0.07061189302476123, 0.039476508463849314, 0.025501303680357523, 0.03253957249398809, 0.0552734594384674, 0.06614478741539642, 0.04630959199857898, 0.05938020782195963, 0.055679421639069915, 0.0568315465352498, 0.043040980672230944, 0.002873208959499607, 0.0512175852782093, 0.018343281917623244, 0.03811419250268955, 0.0155995749446447, 0.0380761796986917, 0.02202356256020721, 0.012548464837891515, 0.06380670311045833, 0.034338312107138336, 0.021377573102654424, 0.018318366164749023, 0.024534481926821172, 0.024700014255358838, 0.049843817978398874, 0.023863075766712427, 0.04184899131359998, 0.08471554872812703, 0.08447044703643769, 0.053242935973685235, 0.018729395378613845, 0.05117139400681481, 0.0436523619282525, 0.06523567135445774, 0.03275852832302917, 0.01401597188305459, 0.01686996107309824, 0.06424572056857869, 0.02215199863712769, 0.015684662175772246, 0.05355147644877434, 0.07122056544176303, 0.06399078542017378, 0.0368448045628611, 0.0852151848084759, 0.04119617966352962, 0.03823810890025925, 0.09486766139161773, 0.04548577839159407, 0.02824353563482873, 0.07178439729614183, 0.025755114475032315, 0.05873150767001789, 0.039625706122023985, 0.07699670080910437, 0.0453767049475573, 0.01974110222363379, 0.061941463354742154, 0.060631862143054605, 0.059342276654206216, 0.019870657088176813, 0.03490838913421612, 0.023526825352746528, 0.06462208591983654, 0.578361680964008, 6.087181214243174, 14.63389540091157, 32.118152752518654, 41.635703444480896, 42.82018728554249, 38.19248780608177, 30.141717307269573, 23.893742971122265, 27.76517853140831, 29.52845111489296, 29.871059730648994, 25.379345454275608, 20.353699028491974, 12.652004398405552, 6.059111645445228, 2.589253024198115, 1.0411909176036716, 0.10994796859449707, 0.07058501243591309, 0.07284310064278543, 0.09570985057507642, 0.23080402374034747, 0.2522170770680532, 0.6824977649375796, 1.145381920505315, 0.7600357511546463, 2.556538679637015, 6.131438389420509, 6.38938469812274, 7.138017676770687, 10.555857326835394, 5.790781918913126, 4.338696487247944, 6.476034773513675, 4.215087220072746, 4.080630959942937, 2.0141108985990286, 2.3508918145671487, 4.36438643373549, 3.8872438995167613, 5.618989337235689, 4.493876835331321, 6.015262948349118, 3.5966552048921585, 5.717915128916502, 6.99977301992476, 8.550021909177303, 6.9059185311198235, 4.450464164838195, 6.847956916317344, 5.915193418040872, 4.791102111339569, 3.0351982824504375, 2.62417980004102, 2.687753001227975, 3.9436209993436933, 2.1206861548125744, 5.562360500916839, 5.027571022510529, 1.3499760045669973, 1.0262460820376873, 1.3873347686603665, 2.0559682650491595, 0.5349997140001506, 0.4028789035510272, 0.7094031712040305, 0.6314724998082966, 0.20578790281433612, 0.07940735973534174, 0.019946536122006364, 0.14733880088897422, 0.018054050269711297, 0.1483870844822377, 0.8320060861296952, 2.155131306499243, 5.113592706620693, 9.517540242522955, 17.7493092790246, 25.272831469774246, 34.59546402096748, 26.94136183708906, 20.76502125710249, 26.638755574822426, 33.639967292547226, 40.677600055933, 33.08836229145527, 20.367566384375095, 7.247314536944032, 1.9490931811742485, 0.05595061353233177, 0.031649073207518086, 0.02101622139889514, 0.014790341756452108, 0.05166631373867858, 0.045888712629675865, 0.0520257321477402, 0.04390884445456322, 0.006433781181840459, 0.054924074865994044, 0.06414085510186851, 0.020851329172728583, 0.04316639249736909, 0.04703700433310587, 0.039261215133592486, 0.04768903672811575, 0.029279779737407807, 0.03362545328855049, 0.05818414036184549, 0.07483735535060987, 0.05439755448605865, 0.06355314093525521, 0.05819518723001238, 0.11032449721824378, 0.06439743781811558, 0.018083264913002495, 0.05009409615013283, 0.021487355297722388, 0.04886320712103043, 0.036928789704688825, 0.005216312501943321, 0.02342970976314973, 0.0871104518591892, 0.022233594063436612, 0.05237765486526769, 0.04877575243881438, 0.015349079694715329, 0.019944094456150196, 0.029601025780721102, 0.04093002324225381, 0.017623522981011774, 0.06720101941027679, 0.05495926750882063, 0.12800494849216193, 0.14001841947901994, 0.21521748276427388, 0.24444888375001028, 0.12422610321664251, 0.19083678867900744, 0.24786123423837125, 0.22592208726564422, 0.14028945181053132, 0.0643257240881212, 0.1591674771043472, 0.07473679434042424, 0.21107147476868704, 0.20848807354923338, 0.1172216614941135, 0.16500391939189285, 0.11504066016641445, 0.1480849413201213, 0.07993867810000665, 0.12022886614431627, 0.17420073214452714, 0.13446016382658854, 0.1846367385587655, 0.15586619643727317, 0.15662621502997354, 0.1716320402920246, 0.10883692157221958, 0.20422596397111192, 0.11727177872671746, 0.10552025618380867, 0.15618002100382, 0.10472349385963753, 0.1428534384467639, 0.1381545007461682, 0.19890819385182112, 0.19245339412009344, 0.29149919108022004, 0.22021605516783893, 0.12709461530903354, 0.13552067801356316, 0.22513407486258075, 0.19536509178578854, 0.2734493580646813, 0.7114627794362605, 6.8719616532325745, 17.27474894374609, 35.8700942248106, 50.797870606184006, 53.27273480594158, 49.681688100099564, 38.15654173493385, 30.639870576560497, 39.38877761363983, 35.87175853550434, 34.71700429916382, 31.38016775250435, 23.679124787449837, 16.003173775970936, 7.970621399581432, 4.007397014647722, 1.710815685801208, 0.3523230319842696, 0.21441438992042094, 0.30589593574404716, 0.4480688099283725, 0.5643014854285866, 1.0930453101173043, 2.2072782833129168, 1.5274630556814373, 2.9558100923895836, 4.741069246083498, 5.019150199368596, 9.51339466497302, 11.10826788470149, 18.42016328126192, 20.981676131486893, 16.654054149985313, 13.512439727783203, 9.479410238564014, 10.898062214255333, 4.638133719563484, 3.5945121198892593, 6.214946508407593, 6.3267208356410265, 8.116485122591257, 4.925355082377791, 4.814829463139176, 4.234868958592415, 6.965484609827399, 8.345721121877432, 12.30570713058114, 7.528386879712343, 3.1229146756231785, 5.203394237905741, 5.270746573805809, 5.376056972891092, 2.6552899181842804, 2.956815375946462, 4.561989130452275, 5.123443203046918, 8.134540803730488, 10.401665400713682, 6.373710064217448, 1.9010902382433414, 2.134663942269981, 6.68626656755805, 4.776427773758769, 1.1620931862853467, 0.6664465949870646, 3.5536602744832635, 4.138939781114459, 1.575995476450771, 0.48155095078982413, 0.3023143013706431, 0.2931137185078114, 0.20896996487863362, 0.46952361648436636, 1.1712844180874527, 2.006967281922698, 6.126805962994695, 10.907207373529673, 27.024383582174778, 32.226363345980644, 40.39996795356274, 28.8309358432889, 26.324672028422356, 33.45400907099247, 39.56513375043869, 49.76027928292751, 37.796112075448036, 24.12242040038109, 8.702116347849369, 2.519970629364252, 0.20919643866363913, 0.1121236190374475, 0.16533993417397141, 0.06174220783577766, 0.09090549821848981, 0.14047948614461347, 0.20593952358467504, 0.09394806620548479, 0.15339689300162718, 0.11383914534235373, 0.20420766260940582, 0.15695572859840468, 0.19056792341871187, 0.14983209053752944, 0.1579603590653278, 0.3147430781973526, 0.14778696902794763, 0.10677257101633586, 0.16444291512016207, 0.261120741488412, 0.12462446582503617, 0.30801447050180286, 0.08269775309599936, 0.206109861319419, 0.07678167836274952, 0.15633581264410168, 0.19667277083499357, 0.21057742706034333, 0.1831848156871274, 0.2139956850442104, 0.18190434377174824, 0.09092753258300945, 0.1292398970690556, 0.224202397512272, 0.08725596475414932, 0.13670679327333346, 0.1410780134028755, 0.12377715582260862, 0.047047361003933474, 0.12883380870334804, 0.15346978674642742], [0.07414354375214316, 0.017803119008021895, 0.05028378538554534, 0.06089119451644365, 0.11575893295230344, 0.04328878378146328, 0.056639037138666026, 0.020898934235447086, 0.03491865674732253, 0.059695772724808194, 0.040900396707002074, 0.034580656720208935, 0.07694465399254113, 0.0059447972398629645, 0.03364196607435588, 0.06091613809985574, 0.029904586444899905, 0.05037448325310834, 0.04919470964523498, 0.0872109312331304, 0.07269664522027597, 0.07196974125690758, 0.09179655782645568, 0.0464148693572497, 0.05605129699688405, 0.01758595732098911, 0.020056552093592472, 0.09100514638703316, 0.06721807396388613, 0.03901823969499674, 0.06101940794906113, 0.039948336270754226, 0.02974181861645775, 0.07308227257453837, 0.06745531631167978, 0.0699932684074156, 0.049930152017623186, 0.0744272890733555, 0.08050998338148929, 0.015150315848586615, 0.060110737176728435, 0.055523180999443866, 0.050102230088668875, 0.0723412010120228, 0.033712722433847375, 0.06941968473256566, 0.8932156953960657, 5.813949750736356, 15.996210649609566, 26.7842972651124, 35.32029792666435, 33.080162331461906, 31.022143363952637, 30.227385610342026, 24.80692896991968, 23.275481946766376, 19.57900419831276, 24.92031678557396, 22.181285060942173, 18.149484805762768, 11.745233405381441, 6.784539269283414, 2.491992018185556, 1.1637365981005132, 0.24467673792969435, 0.10009979509050027, 0.04934063443215564, 0.0489099772676127, 0.1691090944223106, 0.4798244184348732, 0.8915806550066918, 0.7493775011971593, 2.6960788294672966, 10.499845482409, 8.057756423950195, 9.663946386426687, 15.705360006541014, 6.44270533695817, 1.5241208975203335, 3.65852324757725, 3.674957840703428, 7.31590180657804, 5.313868559896946, 3.08901384472847, 3.3058698708191514, 4.260382689535618, 2.7669535763561726, 1.7705871909856796, 3.0593224754557014, 2.0680556539446115, 1.9813310075551271, 4.143490036949515, 2.563146287575364, 1.2454130966216326, 1.128862069454044, 3.6639479314908385, 2.840805226005614, 1.3929583481512964, 1.522820892278105, 1.4971139654517174, 2.6793943997472525, 2.5312090013176203, 2.1198255009949207, 4.456017091870308, 7.232035081833601, 2.50065959058702, 1.1772635160014033, 0.7309719419572502, 0.6412465253379196, 0.37744793691672385, 0.18106173898559064, 0.34665530954953283, 0.11725854623364285, 0.15967759973136708, 0.06753388748620637, 0.01858467101556016, 0.08304061790113337, 0.08913735364330932, 0.39523122017271817, 1.4948889473453164, 2.7971531683579087, 8.34496496245265, 16.627601869404316, 26.061558946967125, 26.447983011603355, 29.286430701613426, 24.47704967111349, 27.201440781354904, 31.981394290924072, 31.319889687001705, 32.427957728505135, 19.926759637892246, 8.452100213617086, 0.9469590021762997, 0.044292675811448134, 0.041038955678232014, 0.07241903003887273, 0.046317250962601975, 0.039480193227063864, 0.07300715238670819, 0.04320860214647837, 0.07589207336422987, 0.009774220343388151, 0.07182497793110088, 0.05527455410629045, 0.028909756038046908, 0.043103903662995435, 0.07070587860653177, 0.03088128061790485, 0.026098482085217256, 0.010709393209253903, 0.0166132169397315, 0.05901181313674897, 0.060327180835884064, 0.03273503192758653, 0.02710197335545672, 0.08099648344796151, 0.0831092888256535, 0.0481540627515642, 0.051008689260925166, 0.022168142204463948, 0.07836906544980593, 0.08353496989002451, 0.06352982265525497, 0.018837908501154743, 0.08622989364084788, 0.031003172807686497, 0.05051965104939882, 0.04043185290356632, 0.01897906869999133, 0.04659848411392886, 0.08896161307347938, 0.04663747655285988, 0.05442962268716656, 0.05283468424750026, 0.02340638035093434, 0.06216246751137078, 0.015162922154559055, 0.020379827910801396, 0.07006469269981608, 0.029542531556217, 0.0224776010873029, 0.04557849490083754, 0.09349013140308671, 0.04529474586888682, 0.04063162792590447, 0.056011725682765245, 0.01806180014682468, 0.05313539506460074, 0.10976828722050413, 0.016153512115124613, 0.062078037080937065, 0.055855678001535125, 0.05276636213238817, 0.025464263089816086, 0.03230820795579348, 0.07572232934762724, 0.028500422631623223, 0.06906207345309667, 0.040444135447614826, 0.10635422237101011, 0.021157433548069093, 0.05095875014376361, 0.032697486676624976, 0.017715653193590697, 0.04113325667276513, 0.0504404008097481, 0.019766127443290316, 0.08874576684320346, 0.052207387634553015, 0.07203534711152315, 0.017411174121662043, 0.02151564411178697, 0.056068600169965066, 0.08429893670836464, 0.03291154804173857, 0.027411697556090076, 0.13733003404922783, 0.040169451749534346, 0.08984616404632106, 0.0326786472578533, 0.02202728999691317, 1.700105604249984, 7.69077924080193, 20.96553649753332, 34.65786047279835, 42.63294093310833, 39.41819183528423, 37.712828144431114, 36.40020377933979, 34.37299355864525, 30.11406049132347, 27.225050814449787, 31.253858730196953, 27.59056270122528, 20.481425374746323, 12.8573995269835, 7.651563920080662, 2.6901539973914623, 1.3619292131625116, 0.07596847004606389, 0.05045685051300097, 0.0473921702359803, 0.05276730465993751, 0.269592713448219, 0.04643387575924862, 0.8801050926558673, 0.647743345471099, 1.5423849737271667, 4.752896586433053, 3.1624038191512227, 3.0446163145825267, 5.318833943456411, 4.499009409919381, 3.356905644759536, 3.495724545791745, 5.53225614130497, 7.0074286591261625, 4.5336132030934095, 4.067322174087167, 4.104524552822113, 3.1822527665644884, 4.592073541134596, 3.328174911439419, 4.184368718415499, 4.0081750229001045, 4.556250013411045, 6.707880757749081, 5.713721578940749, 4.044691538438201, 3.7498520594090223, 3.8927103811874986, 5.605660127475858, 3.241874654777348, 2.068523741327226, 3.1229443615302444, 3.3088151877745986, 3.6475921841338277, 2.851399532519281, 3.7543256068602204, 3.562875729985535, 2.136034481227398, 1.9000895856879652, 1.0186530207283795, 0.7125017268117517, 0.6190846301615238, 0.19911488197976723, 0.5357851437292993, 0.20525533764157444, 0.12000792135950178, 0.013039722070971038, 0.04535394698905293, 0.018945321389765013, 0.17509461933514103, 0.37212525377981365, 2.1481510810554028, 2.4987195571884513, 9.899869076907635, 20.511789545416832, 32.7161380648613, 35.07581904530525, 35.46582251787186, 25.44345561414957, 26.91131304949522, 33.9756640791893, 36.076107770204544, 37.66710139811039, 24.045028053224087, 10.615018252283335, 1.659545274451375, 0.13420502829831094, 0.006481077789430856, 0.030295470060082152, 0.026501167703827377, 0.027335002159816213, 0.0517883673455799, 0.079415137442993, 0.014935062408767408, 0.02569957956438884, 0.03677340253489092, 0.10840301751159132, 0.018795897376548965, 0.02442918786982773, 0.031779379496583715, 0.03154526530124713, 0.023757187991577666, 0.026104027783731, 0.06354861383442767, 0.052145418303553015, 0.017449058905185666, 0.04333392120315693, 0.015299060796678532, 0.037891032407060266, 0.0777568158810027, 0.03894014720572159, 0.09015671574161388, 0.03245083389629144, 0.05291502544423565, 0.028361405384202953, 0.06931851516128518, 0.020098177301406395, 0.10577245280728675, 0.060130088677397, 0.05158491498150397, 0.035205441163270734, 0.08020242996281013, 0.05966681412246544, 0.005238366811681772, 0.05059440387412906, 0.01677321099123219, 0.03005320151714841, 0.008292012280435301, 0.19439859286649153, 0.10779574033222161, 0.10064130314276554, 0.2766799565870315, 0.2328954849508591, 0.13889958732761443, 0.08241608578828163, 0.10827786914887838, 0.09321983379777521, 0.12849060993175954, 0.17878518614452332, 0.10392667958512902, 0.1880371998413466, 0.15657329990062863, 0.08162773941876367, 0.15936175652313977, 0.06946643261471763, 0.09866241089184768, 0.1677263990859501, 0.19663645012769848, 0.18274213944096118, 0.2471705767675303, 0.19639265461592004, 0.2176788155338727, 0.1320633533759974, 0.15741492505185306, 0.11830464049126022, 0.1418782860855572, 0.1684732668218203, 0.20477307523833588, 0.11156973938341253, 0.13700194540433586, 0.2786088577704504, 0.17626178014324978, 0.16130320000229403, 0.17408206273103133, 0.12356044870102778, 0.21732463297666982, 0.37435650592669845, 0.1188394172640983, 0.34880373801570386, 0.20022636686917394, 0.1253860429278575, 0.2445905448985286, 0.15141570009291172, 0.1445075817173347, 1.7026756913401186, 8.859765138477087, 23.224055506289005, 37.65576280653477, 49.42319177091122, 45.88333211839199, 42.91363187134266, 42.6310296356678, 42.46793858706951, 36.62857912480831, 32.63788126409054, 38.0808611959219, 31.97976417839527, 25.736986063420773, 16.057499460875988, 9.310264214873314, 3.909583850763738, 1.8349108519032598, 0.47329901077318937, 0.2179788806824945, 0.23334592406172305, 0.4513712483458221, 0.7956391281913966, 1.7195702972821891, 2.603394677862525, 2.198618547990918, 7.35436144284904, 19.26724422723055, 13.775477763265371, 21.239665187895298, 26.391385048627853, 16.035055965185165, 7.964334161952138, 9.412552826106548, 9.421861376613379, 14.93401849642396, 7.94739562086761, 8.090700656175613, 9.79246499016881, 7.1897457260638475, 5.855747032910585, 4.067433318123221, 6.077365390956402, 4.638592544943094, 5.559805138036609, 8.327211365103722, 5.003055687993765, 3.228610991500318, 2.2608796320855618, 6.518957745283842, 6.793857794255018, 2.5104789761826396, 3.0924412608146667, 4.124104427173734, 4.488028474152088, 6.434449329972267, 6.580005744472146, 11.7619838565588, 14.755172543227673, 9.3007343262434, 4.78352009318769, 5.241348501294851, 4.147920124232769, 1.4295892138034105, 0.46619368891697377, 2.077728984877467, 0.6867493211757392, 0.5878315446898341, 0.18707979965256527, 0.3990895865717903, 0.34037552308291197, 0.3291091276332736, 0.8853898965753615, 2.5469753053039312, 4.530125465244055, 13.29295875504613, 21.653195098042488, 33.36484685540199, 37.25265383720398, 40.95267869532108, 37.840239107608795, 38.739871233701706, 41.838308572769165, 42.23357856273651, 42.30101354420185, 28.398418352007866, 12.528700064867735, 2.3602210264652967, 0.32057911972515285, 0.091762226074934, 0.14586039818823338, 0.16573086788412184, 0.11950078216614202, 0.13298038073116913, 0.17148009297670797, 0.13356464391108602, 0.1811408667708747, 0.13237042439868674, 0.19331921328557655, 0.12892363825812936, 0.10246688252664171, 0.1573079073568806, 0.1416302306461148, 0.1779779075877741, 0.1112756559450645, 0.14373270532814786, 0.11114861510577612, 0.11174663770361803, 0.15657367097446695, 0.15406386111862957, 0.16447065660031512, 0.15543442976195365, 0.09857033262960613, 0.14924831717507914, 0.07053898443700746, 0.18509654357330874, 0.09156573505606502, 0.13658519979799166, 0.11087249906267971, 0.21453322260640562, 0.1538759790128097, 0.18014739820500836, 0.2678253629710525, 0.2003507359768264, 0.09391855841386132, 0.29610136756673455, 0.18975684506585822, 0.17096838215366006, 0.16745222004828975, 0.14545868849381804], [0.02067403565888526, 0.010138713187188841, 0.023887690949777607, 0.0566208062809892, 0.026461468369234353, 0.028841298480983824, 0.0457461312180385, 0.00448315733592608, 0.08296810265164822, 0.014584737164113903, 0.02631472536450019, 0.06352116921334527, 0.07014182410784997, 0.020360778835311066, 0.02295300419064006, 0.052748628513654694, 0.022968938101257663, 0.07744984133751132, 0.05938077185419388, 0.014904460877005477, 0.02078335401165532, 0.009420237238373375, 0.03996863400971051, 0.03550090499629732, 0.03585117643524427, 0.04846242140047252, 0.014688739884149982, 0.07355694280704483, 0.059589820011751726, 0.023539100475318264, 0.03444597175985109, 0.07871149980928749, 0.013600269921880681, 0.024513942989869975, 0.06925954410689883, 0.034813809834304266, 0.013817004873999394, 0.05617921728116926, 0.008030301323742606, 0.030861242630635388, 0.04677748271205928, 0.03594515088479966, 0.03313378787424881, 0.02994003883941332, 0.046306567746796645, 0.020998877407691907, 0.058805967346415855, 1.5600062906742096, 8.793663885444403, 15.688463263213634, 28.06000091135502, 29.36262421309948, 37.29215271770954, 29.653749391436577, 25.400920696556568, 26.239655390381813, 29.205709733068943, 25.975911542773247, 29.08404976129532, 28.53671383112669, 23.72568178921938, 14.393611494451761, 9.117348566651344, 2.971071023494005, 0.9407322644256055, 0.33497717056889087, 0.07700932474108413, 0.04610994685208425, 0.05360489623853937, 0.014954273829062004, 0.6831420084927231, 0.2841902832733467, 1.3450511125847697, 4.69222049228847, 3.740751310251653, 2.1006780909374356, 3.3628504257649183, 1.0760443098843098, 2.1894802758470178, 4.149124659597874, 4.373930096626282, 1.7126630991697311, 1.2795123481191695, 2.612480465322733, 3.9351436542347074, 2.174688382074237, 4.3962519988417625, 2.2726302640512586, 4.163795672357082, 1.3396354531869292, 2.5881382590159774, 2.8048819536343217, 2.7027393970638514, 3.0485377041622996, 4.408930968493223, 1.6112548531964421, 2.8889557672664523, 2.5046268152073026, 1.1104904115200043, 1.837413136381656, 2.210765308700502, 2.518049832433462, 0.9842698532156646, 2.7629001438617706, 1.7180488351732492, 0.6848584476392716, 1.059592617675662, 0.5124450149014592, 0.3165784984594211, 0.34446327248588204, 0.2940533368382603, 0.14601236034650356, 0.096286655170843, 0.05100124923046678, 0.03555625065928325, 0.11104552337201312, 0.13827593094902113, 0.8800340839661658, 2.2685934556648135, 3.646974954754114, 7.8476267494261265, 10.570147410035133, 15.735308099538088, 15.080720074474812, 22.112444154918194, 25.630743764340878, 26.159206107258797, 36.673678904771805, 32.42542706429958, 35.43087959289551, 23.766128718852997, 11.692419089376926, 4.406304834410548, 0.4814577370416373, 0.042001747569884174, 0.04747704224428162, 0.06658858430455439, 0.06772237073164433, 0.03721645727637224, 0.02182294148951769, 0.018617102869029623, 0.04257284505001735, 0.04443782876478508, 0.043689317171811126, 0.05935032524575945, 0.05412081503891386, 0.04148153915593866, 0.02169275208871113, 0.045331574947340414, 0.015607770110364072, 0.05378441062930506, 0.146328485570848, 0.06106994078436401, 0.017430950501875486, 0.02993100690218853, 0.01575138496264117, 0.026559923535387497, 0.026460069420863874, 0.07337771414313465, 0.02632389274367597, 0.04437633069755975, 0.06704237792291678, 0.07748291885945946, 0.014491381480183918, 0.04160990101809148, 0.06035989099473227, 0.014075718481763033, 0.03975505132984836, 0.04299845932109747, 0.07651175925275311, 0.027299265893816482, 0.019999569994979538, 0.06925077192136087, 0.06396125536412, 0.0429670701851137, 0.0487861721921945, 0.042075101446243934, 0.03183977176377084, 0.03176859980158042, 0.01646034565055743, 0.053900805360171944, 0.04750697306008078, 0.05438042942842003, 0.045164613984525204, 0.07502298874896951, 0.017592239601071924, 0.002977900485348073, 0.06044111534720287, 0.030355251910805237, 0.023305327667912934, 0.039681949783698656, 0.051173408937756903, 0.030734168394701555, 0.055172434585983865, 0.08267622339189984, 0.058995582367060706, 0.01751431409502402, 0.04331221338361502, 0.007518812217313098, 0.013368924865062581, 0.056246919702971354, 0.04352982963609975, 0.08760615455685183, 0.030393283268494997, 0.03714956379553769, 0.026364785080659203, 0.04577421408612281, 0.0638013967545703, 0.025741136123542674, 0.04393634844745975, 0.042817089561140165, 0.024283083112095483, 0.035644480885821395, 0.018288507708348334, 0.014402575161511777, 0.020791315400856547, 0.04621955093170982, 0.05770201896666549, 0.02650307502335636, 0.03320775773318019, 0.09513856013654731, 0.03381974012881983, 0.10494532180018723, 2.7491921419277787, 10.54149504750967, 19.85750075429678, 34.10641506314278, 37.49624356627464, 41.65112681686878, 37.88201026618481, 30.74353851377964, 32.15606331825256, 31.372009590268135, 31.288497671484947, 35.81004224717617, 33.08852568268776, 27.033360600471497, 16.172063313424587, 9.411975257098675, 2.370958300307393, 1.2657817848958075, 0.5206306662876159, 0.15287986840121448, 0.046029312507016584, 0.06152624286187347, 0.13176456472137943, 0.06550100399181247, 0.22213480377104133, 0.8335229766089469, 1.452916874550283, 1.0110734961926937, 2.1308909822255373, 1.6586422291584313, 2.414807234890759, 2.911238484084606, 1.642169519327581, 3.4251815686002374, 4.941639108583331, 4.605736183002591, 3.7658366141840816, 4.580051461234689, 2.701586396433413, 4.714143415912986, 2.4500902416184545, 2.8503745375201106, 2.5557029619812965, 5.359651828184724, 3.8222930347546935, 4.405987551435828, 4.670925959944725, 4.104820461943746, 4.162301877513528, 4.135519014671445, 2.9932314343750477, 2.9688640544191003, 3.4877668228000402, 3.039221791550517, 3.4070009691640735, 3.266634838655591, 2.4251137068495154, 2.8913971362635493, 1.1005429015494883, 1.5588658768683672, 0.5580200662370771, 0.6969197723083198, 0.36764152406249195, 0.2899184759007767, 0.373325128457509, 0.041972762992372736, 0.08152772759785876, 0.0856948051659856, 0.08621269807917997, 0.20759801584063098, 0.717930804239586, 2.8103125747293234, 4.669187553226948, 9.65091023594141, 15.71556530892849, 21.563035435974598, 22.99698729068041, 26.887032352387905, 31.3390501588583, 31.28713544458151, 38.78063544631004, 38.70214685797691, 39.627249017357826, 29.190335758030415, 14.50137086212635, 5.720368372276425, 0.5160191981121898, 0.022789939503127243, 0.004556481526378775, 0.033221238845726475, 0.038468653365271166, 0.020371940736367833, 0.009463766982662492, 0.09855832468019798, 0.02069668786134571, 0.037320973933674395, 0.02827852418704424, 0.05043119075708091, 0.011478412197902799, 0.07265779378940351, 0.01583957622642629, 0.01628826943488093, 0.013057032665528823, 0.07679596470552497, 0.11983431075350381, 0.031742016071802936, 0.017118387586378958, 0.031260284304153174, 0.048410244708065875, 0.013069908000034047, 0.027543864780454896, 0.026786291564349085, 0.03161217362503521, 0.01967351297935238, 0.04308722018322442, 0.07092070067301393, 0.041385019139852375, 0.025835973319772165, 0.01980518296477385, 0.03460177453234792, 0.009438155466341414, 0.04565349634503946, 0.049000994258676656, 0.020052778272656724, 0.09610317400074564, 0.04870014985499438, 0.04360885352070909, 0.05666442972142249, 0.020294631212891545, 0.12172359609394334, 0.14949371572583914, 0.10899905857513659, 0.09230447627487592, 0.2032789241638966, 0.11548982278327458, 0.18323094758670777, 0.14513852598611265, 0.22741540713468567, 0.12282308045541868, 0.11663492696243338, 0.16646617295918986, 0.12799003132386133, 0.15386213053716347, 0.19512398284859955, 0.1636785623850301, 0.08534354667062871, 0.19822296890197322, 0.14380255626747385, 0.15482998016523197, 0.08376617857720703, 0.09271333285141736, 0.09964727054466493, 0.0815979867184069, 0.16888048325199634, 0.14485640596831217, 0.2909805189119652, 0.15997236594557762, 0.16936859377892688, 0.09731729049235582, 0.07241817656904459, 0.14354909799294546, 0.19893314485671, 0.15500560199143365, 0.11472348109236918, 0.10089626797707751, 0.12694134697085246, 0.1165018673054874, 0.11533484008396044, 0.18035816814517602, 0.14039381261682138, 0.12814555579097942, 0.17085493745980784, 0.11630525012151338, 0.24135236162692308, 0.13849676441168413, 0.20302807824919, 3.148683705367148, 11.838147919625044, 24.52143508940935, 39.72230851650238, 45.505693182349205, 54.86174874007702, 43.77009071409702, 39.75046120584011, 38.31759989261627, 43.98352526128292, 40.24308577179909, 41.77557773888111, 40.86859680712223, 32.959944382309914, 20.297997817397118, 13.653085380792618, 4.434097018092871, 1.7823331919498742, 0.6352160114329308, 0.19347263005329296, 0.23965544096427038, 0.5133734713308513, 0.3571199777070433, 1.7230592225678265, 1.2092536431737244, 4.090576926246285, 8.405394069850445, 7.146548693999648, 6.962810978293419, 7.78318933211267, 4.247075328603387, 6.222553225234151, 11.746517736464739, 12.302250266075134, 6.64483311586082, 8.05705251172185, 8.283318970352411, 7.952151065692306, 6.553002968430519, 7.490444490686059, 4.876260766759515, 6.866943072527647, 4.162020217627287, 6.317781815305352, 6.0712728928774595, 5.565501982346177, 7.914258074015379, 7.310135615989566, 4.665948702022433, 6.00574778392911, 5.05372216925025, 4.842137172818184, 7.726345807313919, 5.767786027863622, 6.459280997514725, 3.3286831341683865, 6.5595633164048195, 5.444587720558047, 2.9815247375518084, 3.8789356453344226, 2.182533536106348, 2.83945226110518, 2.586159040220082, 1.0387746035121381, 0.7770393043756485, 0.5898770818021148, 0.44477518822532147, 0.15470299869775772, 0.4033675038954243, 0.2663808170473203, 1.280177312437445, 3.21559336502105, 6.185841495171189, 12.882286291569471, 16.847057193517685, 25.688639357686043, 25.24139765650034, 34.019262939691544, 37.949148863554, 36.11471749842167, 48.16691838204861, 45.435446351766586, 43.91530752182007, 33.65149587392807, 17.686061672866344, 6.107154842466116, 0.722470551263541, 0.1572973094880581, 0.13746471900958568, 0.1789665818796493, 0.2031134846038185, 0.12074242491507903, 0.07610993823618628, 0.19333790056407452, 0.1741527151898481, 0.18332591280341148, 0.11568307803827338, 0.2133626479189843, 0.112224120675819, 0.21831646881764755, 0.08871651138179004, 0.12744688312523067, 0.20277583709685132, 0.15461741422768682, 0.22500872611999512, 0.11117858302895911, 0.14238622679840773, 0.1776074423105456, 0.09033004433149472, 0.10947530958219431, 0.1656974118668586, 0.13580603379523382, 0.1126405100512784, 0.12757055461406708, 0.16671872581355274, 0.1604133500950411, 0.18518692231737077, 0.11562257815967314, 0.13169809797545895, 0.16836746624903753, 0.10543438227614388, 0.15098299831151962, 0.17786228097975254, 0.09687933430541307, 0.2137898578075692, 0.10563100688159466, 0.12074903745087795, 0.10659133855369873, 0.1792845773161389], [0.06678275982267223, 0.02758442500635283, 0.09179666172713041, 0.11277478683041409, 0.049166381868417375, 0.01008230346997152, 0.003585937670322892, 0.05972581486275885, 0.10060557615361176, 0.005573325888690306, 0.02495280459697824, 0.012535670211946126, 0.0450443934823852, 0.034098216201527975, 0.03242066930397414, 0.02253984501294326, 0.06626623988267966, 0.017380848112225067, 0.06208618957316503, 0.12566693098051473, 0.03339378075907007, 0.05987786607875023, 0.03286208389909007, 0.08206943602999672, 0.02817482760292478, 0.026907280189334415, 0.01411157720212941, 0.06146111940324772, 0.03497672609228175, 0.05855597119079903, 0.04245858399372082, 0.06197485628945287, 0.06451011809986085, 0.0559879435604671, 0.021853612597624306, 0.06361142179230228, 0.04188462553429417, 0.03436124447034672, 0.04401581762067508, 0.04330972347815987, 0.011450403544586152, 0.08964421824202873, 0.03855838644085452, 0.017992047542065848, 0.03492814510536846, 0.008438511304120766, 0.06420254983822815, 0.11516159313032404, 3.1604937091469765, 9.15825242176652, 22.89011612534523, 33.87776233255863, 39.41794864833355, 34.56593960523605, 35.77995926141739, 37.06385336816311, 37.97816030681133, 41.04349002242088, 34.94546324014664, 28.460723608732224, 21.91811118274927, 17.609526179730892, 13.11556052416563, 6.5886559803038836, 2.631102791056037, 2.2422839049249887, 0.952249268302694, 0.6237634853459895, 0.06174780733999796, 0.04948628462443594, 0.053094680843059905, 0.3839697822695598, 0.044180374025017954, 0.6832039332948625, 0.198647640645504, 0.4283964342903346, 0.506459801690653, 3.189679943025112, 3.3183096908032894, 0.555579112842679, 3.310221587307751, 4.793596677482128, 3.3404812635853887, 2.857485618442297, 2.2501599323004484, 1.3151831715367734, 4.150297371670604, 1.8727038614451885, 0.781092083780095, 2.7902612881734967, 3.798716487362981, 3.144891271367669, 3.6144995223730803, 1.6726006614044309, 2.8834458254277706, 2.9223877983167768, 2.1604132605716586, 3.331207148730755, 1.6781893302686512, 2.5712645519524813, 3.9636247884482145, 2.6496780943125486, 3.4818232292309403, 0.903772657038644, 1.438329101074487, 0.26985691802110523, 0.6777899956796318, 0.2570553752593696, 0.1421845704317093, 0.1509615799295716, 0.1877459217212163, 0.1690632148529403, 0.11119554110337049, 0.06312707395409234, 0.15646640094928443, 0.30734834843315184, 1.2606217805296183, 1.348775268997997, 3.543873424641788, 8.920255042612553, 15.016011446714401, 15.418237913399935, 25.916596725583076, 21.740189529955387, 24.271676391363144, 25.88921159505844, 33.78192387521267, 32.492178082466125, 33.109162375330925, 28.40095281600952, 13.467870019376278, 5.664737932384014, 1.0352073074318469, 0.02979211767524248, 0.10223086472251453, 0.0378841860947432, 0.02111293808411574, 0.05294891932862811, 0.013992564545333153, 0.03306293503555935, 0.03571964560251217, 0.010658415085345041, 0.08852918588672765, 0.043476795763126574, 0.05210094510402996, 0.030754109902773052, 0.10300162961357273, 0.06025377871992532, 0.04164222154940944, 0.07408032019156963, 0.015716962298029102, 0.02328949765797006, 0.03344725992064923, 0.09619468080927618, 0.07830268034012988, 0.03218574245693162, 0.03319681105494965, 0.034008843067567796, 0.028994182757742237, 0.04802280280273408, 0.007514269809689722, 0.0434857534855837, 0.057968924957094714, 0.030342273603309877, 0.10556816181633621, 0.04483028758841101, 0.15438432048540562, 0.04610292242432479, 0.021529017612920143, 0.05448974035971332, 0.0695529521908611, 0.07455995539203286, 0.02900167844927637, 0.015771497164678294, 0.03194300821633078, 0.06390082227881067, 0.004466715054149972, 0.03390612982911989, 0.07275494092027657, 0.10396590951131657, 0.014082722500461387, 0.049104252975666896, 0.025323049085272942, 0.04651952702261042, 0.060920179093955085, 0.0328842741146218, 0.06611260047066025, 0.06592340476345271, 0.04814914231246803, 0.06894118501804769, 0.02507300283468794, 0.043756897139246576, 0.0477412802138133, 0.07780969390296377, 0.014834745379630476, 0.08753550951951183, 0.07226389891002327, 0.01652569175348617, 0.05310621010721661, 0.052521282705129124, 0.038548040902242064, 0.010547077163209906, 0.1353575094253756, 0.028205587768752594, 0.026436869884491898, 0.05048420607636217, 0.06392234456143342, 0.06731208181008697, 0.023452874047507066, 0.07418957917252555, 0.03324611192510929, 0.056378053486696444, 0.01357350158286863, 0.053058497433084995, 0.05280680547002703, 0.008290754340123385, 0.08347561291884631, 0.06102243220084347, 0.02811127749737352, 0.025407212342543062, 0.011603633847698802, 0.06178111863846425, 0.04977378521289211, 0.5647164350375533, 4.2106300592422485, 11.569982059299946, 26.360319815576077, 37.48876556754112, 47.13877335190773, 38.97781826555729, 41.308123022317886, 40.760253220796585, 42.82283194363117, 45.64848192036152, 42.125379368662834, 39.07392270863056, 30.808421932160854, 25.469313226640224, 16.047076620161533, 8.23830183595419, 3.2639844808727503, 1.8777617462910712, 0.59490813058801, 0.4815285379299894, 0.04723253055999521, 0.02194312673964305, 0.0416183726338204, 0.059774406981887296, 0.3736339509487152, 0.635662724962458, 0.6635297765024006, 0.5032230284996331, 0.7544156152289361, 1.77982734516263, 1.7359586991369724, 1.2233316502533853, 1.5612596296705306, 3.3736862568184733, 2.106159534305334, 2.7498176833614707, 3.6024560686200857, 3.911389228887856, 4.448617463931441, 3.4364334773272276, 2.9698634007945657, 2.682215035893023, 3.6273663444444537, 2.556071779690683, 2.7866863925009966, 3.5082923714071512, 4.087841073051095, 3.4495356492698193, 2.9138251952826977, 2.730256333015859, 2.413683207705617, 2.75715010240674, 2.7754641696810722, 1.849897128995508, 2.764463759958744, 1.863084202632308, 1.020783162675798, 0.7729232346173376, 0.5880348931532353, 0.1665738140582107, 0.3919949516421184, 0.47470855701249093, 0.06519184011267498, 0.15575390949379653, 0.06294573016930372, 0.053918813573545776, 0.21464162069605663, 0.428180291200988, 1.0927976109087467, 2.152875177562237, 5.162341240793467, 10.316383726894855, 19.88399863243103, 19.627160914242268, 31.31421849131584, 24.97637327760458, 28.815350979566574, 30.072688311338425, 36.92893400788307, 38.67154709994793, 38.20457875728607, 32.97053061425686, 16.713619753718376, 7.080159606412053, 1.7350265616551042, 0.07635514382855035, 0.03660657144791912, 0.05594194524746854, 0.007825335906090913, 0.012957811231899541, 0.005461821447170223, 0.014754348521819338, 0.07443940834491514, 0.06818673253292218, 0.05710108714993112, 0.04672032991948072, 0.009134438951150514, 0.008500860058120452, 0.02992367448314326, 0.03951553429942578, 0.04146808772929944, 0.10209715939708985, 0.019850543030770496, 0.04349709350208286, 0.013524749901989708, 0.0379721157514723, 0.06961605700780638, 0.01564484780828934, 0.08615774204372428, 0.059030530101154, 0.06061855914595071, 0.06560439258464612, 0.02291633096319856, 0.0550378646585159, 0.09190433993353508, 0.0323587519233115, 0.08534178035915829, 0.050778920340235345, 0.12006018339889124, 0.018455251592968125, 0.010437154887767974, 0.0254362191844848, 0.036984491598559543, 0.058786990630324, 0.026503709559619892, 0.05545017964323051, 0.04816774795472156, 0.0498192899976857, 0.16449296555947512, 0.08182053454220295, 0.20865155383944511, 0.17084079212509096, 0.0924790590943303, 0.17894261050969362, 0.13495171791873872, 0.09776620077900589, 0.25501568627078086, 0.1027673484350089, 0.11283299347269349, 0.12148654670454562, 0.1261208433425054, 0.11417726782383397, 0.15328760433476418, 0.09151816338999197, 0.16056664811912924, 0.15492824051762, 0.17222924652742222, 0.2078093052841723, 0.09676100627984852, 0.14719485392561182, 0.09062716315384023, 0.12510988977737725, 0.1422440609894693, 0.17274457903113216, 0.30662306235171854, 0.13592243223683909, 0.13065189239569008, 0.12833472923375666, 0.1752554130507633, 0.17820905690314248, 0.0919967595837079, 0.1455852692015469, 0.10451719906996004, 0.2818707749247551, 0.2192924078553915, 0.2097925910493359, 0.08344070229213685, 0.1555317104794085, 0.1867588801542297, 0.14112926612142473, 0.11591693619266152, 0.10760208431747742, 0.18485823995433748, 0.14917347900336608, 0.15210053912596777, 0.7348248164635152, 4.986991574987769, 12.649034857749939, 29.69733115285635, 43.747873306274414, 53.780604153871536, 46.7150466889143, 47.513068467378616, 49.90657523274422, 51.45670585334301, 57.32076019048691, 49.06224153935909, 45.21864518523216, 35.41606418788433, 28.270887695252895, 20.763885118067265, 11.961877830326557, 3.9814470196142793, 3.4254007693380117, 1.3438964495435357, 1.0733571415767074, 0.3289311903063208, 0.39611045736819506, 0.3158317197812721, 1.014495687559247, 0.8278027991764247, 1.870305952616036, 1.356486480217427, 3.9608008274808526, 2.5980944372713566, 7.708262102678418, 6.704140808433294, 5.3926715813577175, 8.453503288328648, 13.92045708373189, 10.449522882699966, 10.102202519774437, 11.58645037561655, 5.584151381626725, 10.900966208428144, 6.122418148443103, 5.089476350694895, 5.659680403769016, 7.224903339520097, 6.472435416653752, 7.890959149226546, 5.287806233391166, 6.141000101342797, 5.887218369171023, 6.564958551898599, 6.820985013619065, 5.407491736114025, 6.236186418682337, 7.835051799193025, 8.505209013819695, 9.548439234495163, 4.725837763398886, 6.3136770855635405, 3.509174636565149, 2.6858113054186106, 1.8468880467116833, 1.3979721791110933, 1.3110520807094872, 0.9002179477829486, 1.1240808572620153, 0.29195329640060663, 0.22691257239785045, 0.4104956245282665, 0.5932022596243769, 1.7843689327128232, 2.7209152467548847, 5.352599881589413, 13.19058844819665, 22.6727107912302, 24.3157160282135, 36.13502360880375, 33.00396502017975, 34.44300480186939, 36.094639375805855, 46.14980801939964, 42.223642095923424, 44.82337899506092, 37.21154764294624, 20.214062221348286, 8.095930125564337, 1.8746949546039104, 0.11586684122448787, 0.18946147029055282, 0.2036469551967457, 0.14284898556070402, 0.20500404643826187, 0.13332813628949225, 0.17450262297643349, 0.1468767100595869, 0.15480057627428323, 0.18508667300920933, 0.17753435560734943, 0.18902723968494684, 0.1652083217049949, 0.213606784818694, 0.15805367671418935, 0.07691018865443766, 0.29157684941310436, 0.0611656407272676, 0.09489437128650025, 0.10106867630383931, 0.13983910175738856, 0.17314999946393073, 0.11902115438715555, 0.2372732211370021, 0.21200543793383986, 0.1571172644617036, 0.22482770145870745, 0.11865483029396273, 0.1393187078065239, 0.18747180205537006, 0.11989853621344082, 0.2258515387075022, 0.16757359087932855, 0.264452658011578, 0.15753824030980468, 0.17631540773436427, 0.2844241785351187, 0.25646851456258446, 0.1647091531776823, 0.12088847215636633, 0.14269819599576294, 0.17706577840726823, 0.17883396008983254], [0.06960715123568662, 0.0496966575155966, 0.042007681040558964, 0.02108679778757505, 0.0431596612179419, 0.029654998470505234, 0.06394086856744252, 0.03298610790807288, 0.03088168137765024, 0.04625076937372796, 0.06991573623963632, 0.005232120247455896, 0.0653138269262854, 0.09155957523034886, 0.015142976935749175, 0.031001480710983742, 0.01565963695611572, 0.02501142127584899, 0.017472115578129888, 0.05386785400332883, 0.030087570376053918, 0.05021652454161085, 0.08024941533221863, 0.03206580768164713, 0.01939109424711205, 0.048275552326231264, 0.017426620070182253, 0.02781865608994849, 0.08161421748809516, 0.08962726016761735, 0.020882890858047176, 0.02641169252456166, 0.05016046641685534, 0.03043319968128344, 0.0814393229666166, 0.0545657028851565, 0.1276377189788036, 0.06879835127620026, 0.043964078795397654, 0.01772343646734953, 0.035676315310411155, 0.06539581198012456, 0.08595851249992847, 0.02546638934290968, 0.02750975196249783, 0.08549492253223434, 0.008585638370277593, 0.08908155898097903, 0.3971664444543421, 3.226751941256225, 9.968002270907164, 22.158159501850605, 28.477302119135857, 36.90789073705673, 35.059407725930214, 41.73670582473278, 36.771633848547935, 37.90262795984745, 34.93425004184246, 28.25792659074068, 23.166661486029625, 17.035538479685783, 12.09415728226304, 6.297907456755638, 4.161460697650909, 4.136057160794735, 3.5142829874530435, 1.4377985545434058, 0.6374923267867416, 0.24052298191236332, 0.1210530953540001, 0.04137931202421896, 0.3121693100547418, 0.8122187072876841, 0.257771696196869, 0.4494726564735174, 0.13930563116446137, 0.6303113652393222, 1.2892533629201353, 0.7460291683673859, 0.7127991202287376, 1.8747410271316767, 0.9559212368912995, 0.9407735278364271, 2.821336258202791, 2.688565207645297, 1.9480157014913857, 1.6077590407803655, 1.9718319922685623, 1.1455404432490468, 1.7867208877578378, 0.5092537798918784, 0.5253592750523239, 2.8091170638799667, 2.955232998356223, 3.8104540575295687, 1.4768093987368047, 1.1458653258159757, 1.8534234585240483, 1.9595744437538087, 1.5344486245885491, 0.3952215425670147, 2.2879211185500026, 2.2094783652573824, 0.6426810077391565, 0.3659684263402596, 0.3771129611413926, 0.23632539465324953, 0.141050286765676, 0.35151797987055033, 0.09100357303395867, 0.09266477412893437, 0.148192523047328, 0.15081160672707483, 0.5157701333519071, 2.122639250010252, 2.5843828730285168, 6.423005294054747, 8.115892354398966, 18.834101669490337, 26.50920532643795, 19.813685305416584, 20.587538480758667, 30.573746524751186, 21.69611569494009, 25.44703882187605, 35.32252460718155, 33.443791419267654, 26.789199002087116, 15.817267801612616, 7.500519650056958, 1.4853072864934802, 0.02643126110342564, 0.01434822954252013, 0.0630849199660588, 0.029620022905874066, 0.06206266720255371, 0.03733333811396733, 0.03989192562585231, 0.02225901076599257, 0.03953857798478566, 0.0445277251128573, 0.12720770377200097, 0.013149729693395784, 0.02941565770015586, 0.043845914042321965, 0.02970485595142236, 0.0231055285257753, 0.017046213724825066, 0.05479976141941734, 0.03261608420871198, 0.033764936233637854, 0.04067959664098453, 0.1049338630400598, 0.058865309474640526, 0.01321682355410303, 0.01745829122228315, 0.04738399547932204, 0.05896883907553274, 0.059472534703672864, 0.016699575098755304, 0.05249229070614092, 0.04594891193846706, 0.02327309804968536, 0.02760922201559879, 0.03603501754696481, 0.05444553062261548, 0.025400501472176984, 0.01626024408324156, 0.031322175709647126, 0.024875921808416024, 0.03765224639209919, 0.054209609297686256, 0.007296474050235702, 0.032230056094704196, 0.030570148192055058, 0.05100794711324852, 0.05428340475191362, 0.05289541419188026, 0.050324262119829655, 0.020642531490011606, 0.011919773914996767, 0.03333908076456282, 0.07089196471497416, 0.05921355485043023, 0.024187019516830333, 0.02596232581709046, 0.020389935962157324, 0.030683605873491615, 0.04343568078184035, 0.07813032396370545, 0.03742514549230691, 0.016899865913728718, 0.03353662192239426, 0.04120486650208477, 0.020730637406813912, 0.0501960190013051, 0.016239985307038296, 0.049551140909898095, 0.05510988637979608, 0.005121783296999638, 0.04727709281723946, 0.019405957609706093, 0.04022168039227836, 0.008955902339948807, 0.07088247264618985, 0.03538678865879774, 0.048340438297600485, 0.01821956961066462, 0.07675080501940101, 0.06482423210400157, 0.040135402014129795, 0.03875518545100931, 0.0292097117198864, 0.03895265610481147, 0.07416883614496328, 0.050916113759740256, 0.04216926885419525, 0.0468884041038109, 0.05746252048993483, 0.05733853729907423, 0.03206955923815258, 0.029451052578224335, 0.08827289260807447, 0.7351856189779937, 4.745211973786354, 14.057350438088179, 26.921154521405697, 35.32602421939373, 43.34057696163654, 40.03890372812748, 47.04255871474743, 43.32483820617199, 45.704525113105774, 43.26243795454502, 34.52888399362564, 31.583629734814167, 22.357637397944927, 21.856318898499012, 12.879002317786217, 7.8887220192700624, 5.721245175227523, 3.197761634364724, 1.4667347143404186, 0.5949210736434907, 0.20991908269934356, 0.030391503969440237, 0.0257138417873648, 0.1973982944036834, 0.11356926333974116, 0.1595278046443127, 0.4650490003405139, 0.34894786309450865, 0.4061178438132629, 0.8103932614903897, 0.8196748571936041, 1.6316326847299933, 1.1137258191592991, 1.9600031082518399, 3.372051394544542, 0.5719925696030259, 2.6739542791619897, 2.9903970239683986, 1.6796473832800984, 3.6410201992839575, 2.528906799852848, 4.381818948313594, 2.268671113997698, 2.668304219841957, 3.2455357583239675, 2.982251923531294, 3.3636821061372757, 3.242260809056461, 2.3037235205993056, 2.5264716055244207, 2.1990460250526667, 1.395168760791421, 1.6663134237751365, 2.9928630916401744, 1.1200493923388422, 1.8867607321590185, 1.0505187045782804, 0.3503566375002265, 0.09684697666671127, 0.061603548674611375, 0.20382392773171887, 0.06437417890992947, 0.08579814180848189, 0.15710457373643294, 0.12245329053257592, 0.6782527989707887, 2.035961151123047, 3.543130327016115, 7.043459275737405, 9.070232044905424, 21.749896109104156, 30.663303919136524, 24.26164872944355, 29.998153410851955, 33.832514360547066, 23.92876949161291, 29.089071191847324, 40.99603056907654, 37.795355916023254, 32.323486134409904, 19.734488055109978, 9.121190160512924, 2.2066354053094983, 0.02494382089935243, 0.03393067636352498, 0.010243258602713468, 0.016064461815403774, 0.03264533595938701, 0.038062891544541344, 0.05127395881572738, 0.038131599576445296, 0.05097044268040918, 0.031297295208787546, 0.050158759477199055, 0.065624957496766, 0.05741150896938052, 0.04409395834954921, 0.018766567700367887, 0.07361223280895501, 0.02573603571363492, 0.04292137615266256, 0.06372506686602719, 0.05122141847095918, 0.0013266588962324022, 0.04417762436787598, 0.0372284169861814, 0.03373296080098953, 0.05071636100183241, 0.03591414395486936, 0.05803996333270334, 0.09156817672192119, 0.04945044631313067, 0.05002060868719127, 0.022968457560637034, 0.05457737686811015, 0.01528237824459211, 0.028050436230842024, 0.05088624602649361, 0.010334086346119875, 0.025543971605657134, 0.07789807626977563, 0.1016044252901338, 0.05012907728087157, 0.026490582822589204, 0.096473008452449, 0.00912990721189999, 0.031063644855748862, 0.14880357775837183, 0.13868498790543526, 0.14505130879115313, 0.10622124435030855, 0.09351190601591952, 0.12785519793396816, 0.16739887447329238, 0.285923732444644, 0.14194546529324725, 0.11122070733108558, 0.2660461381310597, 0.12650598830077797, 0.14353940554428846, 0.24210939678596333, 0.15683542646002024, 0.14460824662819505, 0.07715362051385455, 0.12084009154932573, 0.1536882304935716, 0.147845049505122, 0.1327394795953296, 0.16009643819415942, 0.1590913624386303, 0.16738458070904016, 0.08585222210967913, 0.21269530872814357, 0.11208212556084618, 0.16034919884987175, 0.1473421257105656, 0.1863787669572048, 0.1127768425794784, 0.13831777323503047, 0.09322725527454168, 0.20504361775238067, 0.22208559938007966, 0.2013276843354106, 0.15922523103654385, 0.1884691891609691, 0.16856682195793837, 0.1606461766641587, 0.12769807042786852, 0.2022482146276161, 0.18182258878368884, 0.18142202199669555, 0.1532620150828734, 0.19092881499091163, 0.1559805910801515, 0.1852631408837624, 0.8850274910219014, 5.230885287746787, 15.59325747191906, 30.277907699346542, 41.29405997693539, 51.60315379500389, 49.28209014236927, 56.31132535636425, 50.843593552708626, 50.190378203988075, 52.71259926259518, 43.0836271494627, 37.314210534095764, 32.10296116769314, 25.405444353818893, 13.443207442760468, 9.641778375953436, 6.977837271988392, 5.221398146823049, 2.33093433547765, 1.219290210865438, 0.6035611568950117, 0.38820471439976245, 0.3874812391586602, 0.7594726688694209, 1.4728582045063376, 1.7652903939597309, 2.4605539301410317, 1.3203047029674053, 3.740324783138931, 3.284050254151225, 3.0542495101690292, 4.648748449981213, 6.629134733229876, 4.594341544434428, 6.585996598005295, 8.926305267959833, 10.447474792599678, 7.3196151573210955, 6.77455198019743, 6.930109933018684, 4.7235445864498615, 9.219975359737873, 4.192176349461079, 4.822901654988527, 6.443111915141344, 8.798425029963255, 8.52741027250886, 5.477720992639661, 4.399109445512295, 6.475599696859717, 8.517079576849937, 5.675422009080648, 4.4433932192623615, 7.528984872624278, 5.582799604162574, 4.181121792644262, 2.4155546072870493, 2.7634701132774353, 1.1673224181868136, 0.8251196681521833, 1.3939326396211982, 0.7954822084866464, 0.4090433305827901, 0.3719403105787933, 0.39548512373585254, 0.6605996587313712, 3.339709904976189, 3.804815160110593, 9.216636288911104, 11.994507629424334, 26.833611018955708, 36.14100828766823, 28.002863377332687, 32.48249240219593, 40.575697124004364, 31.24229785054922, 36.64891183376312, 46.15328103303909, 43.815258890390396, 37.32551872730255, 22.746801115572453, 10.42047344148159, 2.669463395141065, 0.22130621073301882, 0.2758741029538214, 0.0852906538057141, 0.14138187834760174, 0.14570003491826355, 0.1227341711637564, 0.1275794010143727, 0.11705162803991698, 0.12304641495575197, 0.1595094142248854, 0.14446841116296127, 0.14551746658980846, 0.12299206005991437, 0.13969770778203383, 0.12150902635767125, 0.17932125425431877, 0.11689737264532596, 0.11629788059508428, 0.10908434618613683, 0.14043755480088294, 0.08380350860534236, 0.20090543199330568, 0.0940966367488727, 0.13112008367897943, 0.10936216916888952, 0.07872460613725707, 0.1592341813375242, 0.15374593989690766, 0.12587799777975306, 0.1824925997061655, 0.14511649904306978, 0.14751228532986715, 0.11137401277665049, 0.17889380687847733, 0.17905295302625746, 0.0777183058380615, 0.10312432146747597, 0.1591770359664224, 0.12558780319523066, 0.14424493565456942, 0.1054880469746422, 0.19165257224813104, 0.11674743655021302, 0.1488688719109632], [0.01658249573665671, 0.07899989097495563, 0.03134140104521066, 0.017980048869503662, 0.029600636153190862, 0.04111564179765992, 0.044127963556093164, 0.02918929523730185, 0.031698923266958445, 0.01009789135423489, 0.066207469208166, 0.030116510424704757, 0.07926750200567767, 0.028103881995775737, 0.06573909980943426, 0.05593015994236339, 0.06876588973682374, 0.015706774465797935, 0.07517618287238292, 0.059835033025592566, 0.024134191589837428, 0.03372460421815049, 0.09619593503884971, 0.021387464075814933, 0.019449048559181392, 0.08023847607546486, 0.02467611153406324, 0.07888956330134533, 0.07790741248754784, 0.051299711340107024, 0.014287066369433887, 0.017154821471194737, 0.013651838053192478, 0.02539494093070971, 0.08121597362332977, 0.009703899067972088, 0.019512537437549327, 0.08276315114926547, 0.022126088406366762, 0.02220809386926703, 0.004471099291549763, 0.03780502862355206, 0.05410441728599835, 0.02275030881719431, 0.11003046573023312, 0.016375974591937847, 0.05757848848588765, 0.012158712997916155, 0.06676714503555559, 0.6130787555593997, 3.3507559122517705, 11.877503357827663, 16.924044862389565, 32.55428194999695, 41.01776920258999, 36.54927358031273, 43.27268600463867, 38.992770463228226, 31.021516397595406, 40.9394858032465, 35.270117819309235, 20.575538724660873, 5.373285971581936, 4.960950622335076, 6.580754304304719, 8.179822023957968, 5.09284439496696, 4.413797557353973, 2.673138747923076, 1.0859525157138705, 0.518504383508116, 0.3107880841707811, 0.035598371250671335, 0.03878602168697398, 0.016408861010859255, 0.2698519011028111, 0.14009201084263623, 0.2558376593515277, 0.17612339928746223, 0.466254188795574, 0.6188755226321518, 0.5414592486340553, 0.8725224214140326, 1.9822682510130107, 0.536762997508049, 1.99494662694633, 1.495889243669808, 1.0972227109596133, 2.709110942669213, 1.919373432174325, 3.2030378887429833, 1.3546489225700498, 1.5370822395198047, 1.7956254724413157, 1.3391326926648617, 1.759287309832871, 1.7627433431334794, 1.038693857844919, 1.5425363718532026, 1.2206374760717154, 1.248959256336093, 1.3293054699897766, 1.3468520971946418, 0.3324554715072736, 0.36918341007549316, 0.49387544102501124, 0.24738229665672407, 0.03231450878956821, 0.08312323378049769, 0.11719343761797063, 0.03350931830937043, 0.07457476865965873, 0.1477490898105316, 1.3173405057750642, 1.4393943501636386, 3.09319528285414, 9.081061463803053, 12.840200699865818, 15.475511290133, 18.211155496537685, 25.83636213093996, 12.58116289973259, 23.500547669827938, 22.992133051156998, 25.409705825150013, 32.0208627730608, 35.35147525370121, 26.877662055194378, 14.910752344876528, 6.2937424052506685, 2.1048545418307185, 0.24049531464697793, 0.0421091474709101, 0.028720944392262027, 0.06249575118999928, 0.053892107389401644, 0.03867135616019368, 0.02922660485637607, 0.025188174877257552, 0.042352137752459385, 0.03989571428974159, 0.047793894773349166, 0.028417268695193343, 0.029841236719221342, 0.011495206999825314, 0.057156581242452376, 0.022308649313345086, 0.09213154102326371, 0.04009339274489321, 0.047661258140578866, 0.034902459374279715, 0.04533762716164347, 0.026243785323458724, 0.002416447214272921, 0.03213643045455683, 0.05474174402479548, 0.013764430204901146, 0.0861471590178553, 0.049919201628654264, 0.05686516953574028, 0.07347382968873717, 0.04160840187978465, 0.04432660680322442, 0.05583568083238788, 0.05159768734301906, 0.0012521423991529446, 0.045094109955243766, 0.07916383881820366, 0.07293691553059034, 0.07626590057043359, 0.07639530886081047, 0.014276082583819516, 0.0698666283278726, 0.015038616129459115, 0.06237186447833665, 0.03582277073292062, 0.06896452556247823, 0.0325527159293415, 0.04347020178101957, 0.06767572675016709, 0.04606228612829, 0.05881847995624412, 0.03929986989533063, 0.016133182834892068, 0.0347401034377981, 0.020269949236535467, 0.03416106126678642, 0.08336011989740655, 0.06628808128880337, 0.04856898638536222, 0.06159101380035281, 0.038166554732015356, 0.04671565067837946, 0.03435928148974199, 0.04285970368073322, 0.04675684358517174, 0.05028580402722582, 0.04638638944015838, 0.049107280938187614, 0.0333803182002157, 0.009830600374698406, 0.01660184352658689, 0.04608564151567407, 0.04129444372665603, 0.037121020795893855, 0.04066266454174183, 0.0483672817790648, 0.02524787138099782, 0.018773109732137527, 0.08327130708494224, 0.03366294658917468, 0.06165732098452281, 0.07133228835300542, 0.027760425327869598, 0.03749584990146104, 0.03097828674071934, 0.032965606078505516, 0.04480788215005305, 0.06338574952678755, 0.013810403470415622, 0.0648960868420545, 0.06491875945357606, 0.01658093537116656, 0.06473127810750157, 0.06985279469517991, 0.9968163049779832, 4.464399917051196, 15.210736747831106, 23.01708821207285, 38.11388522386551, 46.80580481886864, 42.93098174035549, 48.17296385765076, 43.43212924897671, 36.68678060173988, 44.79602426290512, 38.35773713886738, 28.830951042473316, 14.241597801446915, 8.273356854915619, 10.705710835754871, 9.6347582526505, 5.873343413695693, 5.092301974073052, 2.813985077664256, 0.884276496944949, 0.5594215379096568, 0.2329920680494979, 0.06096625162172131, 0.14913326944224536, 0.033522832818562165, 0.18965834722621366, 0.11080270007369108, 0.11699916562065482, 0.5319886724464595, 0.24746739130932838, 0.6838180159684271, 0.9812030021566898, 1.6414228593930602, 2.098209885880351, 0.8645848254673183, 1.8400215776637197, 2.579276659525931, 1.996188210323453, 2.7092315861955285, 3.1057944567874074, 2.51619481947273, 3.2452305871993303, 1.5350563544780016, 3.329449980519712, 4.340985864400864, 2.1518029225990176, 2.825363567098975, 2.338490942493081, 1.7823179927654564, 3.0167873203754425, 0.9306882752571255, 1.0540436091832817, 1.738736943807453, 0.5737046746071428, 0.289677960681729, 0.6816607411019504, 0.3360696416348219, 0.07646203535841778, 0.03720938089827541, 0.017918701087182853, 0.08101080689812079, 0.141907719662413, 0.15303665451938286, 1.256279326044023, 1.905755556654185, 3.7793674506247044, 9.027034062892199, 18.0258147418499, 14.713666420429945, 22.49240856617689, 32.141350507736206, 14.56919627264142, 24.25910096615553, 28.95952094346285, 30.213269367814064, 34.60657462477684, 38.918792232871056, 32.40191392600536, 19.346355982124805, 9.511656258255243, 2.7440766664221883, 0.17372428817907348, 0.03910562016244512, 0.027504705358296633, 0.026130568840017077, 0.0794349898933433, 0.05123276590893511, 0.031819292198633775, 0.03287698251369875, 0.04425523817189969, 0.035618075271486305, 0.09241805455530994, 0.02823177259415388, 0.027997855067951605, 0.08002879709238186, 0.03746005611901637, 0.01400726741849212, 0.03894610665156506, 0.06248660050914623, 0.05198882885451894, 0.035188308684155345, 0.05337360591511242, 0.014314961845229845, 0.08851997583406046, 0.018913687345047947, 0.029324004317459185, 0.04054961318615824, 0.06645253379247151, 0.06243638679734431, 0.029970728501211852, 0.027197482195333578, 0.07158287451602519, 0.025285529809480067, 0.01721159391308902, 0.040022743996814825, 0.015147068952501286, 0.031264325298252515, 0.030361645513039548, 0.0675301619048696, 0.019986623228760436, 0.055702854951960035, 0.0721734385297168, 0.12687715119682252, 0.023237762543431018, 0.01314797544182511, 0.033000743060256355, 0.13161119248252362, 0.18570727173937485, 0.1200233209237922, 0.22238055855268613, 0.15898330573691055, 0.14719954429892823, 0.17644149862462655, 0.20652500388678163, 0.12518664269009605, 0.09344575097202323, 0.24144055845681578, 0.14770819747354835, 0.18502826598705724, 0.1060943519405555, 0.17973507579881698, 0.15001023566583171, 0.18341406510444358, 0.1523995801107958, 0.13335693161934614, 0.1926198133151047, 0.15117021248443052, 0.11828561924630776, 0.19934662501327693, 0.14714084041770548, 0.1258888776646927, 0.15405191254103556, 0.15437688416568562, 0.15629581088433042, 0.17728039267240092, 0.12169304929557256, 0.17068583169020712, 0.09500877335085534, 0.2776403847383335, 0.1249555972754024, 0.18619726732140407, 0.18217375822132453, 0.18172624317230657, 0.16198648052522913, 0.14731588336871937, 0.17730225634295493, 0.12395881130942143, 0.09299167533754371, 0.1131993620947469, 0.09225648158462718, 0.20588657876942307, 0.14372561039635912, 0.2052682064822875, 0.18495796975912526, 0.20725192269310355, 1.0709256283007562, 4.700926300138235, 16.593890078365803, 24.881406873464584, 43.221939727663994, 55.71874715387821, 50.14356091618538, 58.69162403047085, 53.11665818095207, 45.85763789713383, 56.13590016961098, 46.645138040184975, 32.67428331077099, 17.63381067663431, 16.685305573046207, 17.347893118858337, 16.242984607815742, 9.295484907925129, 6.9801252242177725, 3.7573899049311876, 1.6372391651384532, 1.1431987001560628, 0.42613312136381865, 0.29405989742372185, 0.3986758243991062, 0.4070606979075819, 0.9596246725413948, 1.2585341488011181, 1.599600522313267, 1.7278434033505619, 2.5843560369685292, 2.2161011723801494, 3.0069665098562837, 5.062829330563545, 5.474693980067968, 4.802477275952697, 8.639345616102219, 9.234251193702221, 5.969818336889148, 6.9824169762432575, 7.326539810746908, 6.955963270738721, 6.352655868977308, 5.515908468514681, 6.436979994177818, 7.936033280566335, 7.873216476291418, 7.196758249774575, 4.32888493873179, 5.516446614637971, 4.867566833272576, 5.266724489629269, 2.507772333920002, 4.6640112809836864, 2.2883379086852074, 3.561195507645607, 3.0211364245042205, 1.2831165734678507, 0.7991757290437818, 0.2557898353552446, 0.5669307662174106, 0.3678489988669753, 0.4708249872783199, 0.4492696048691869, 2.2891344409435987, 2.539226096123457, 4.672395056113601, 13.412931617349386, 17.41853702813387, 19.764647036790848, 27.27070726454258, 38.91656935214996, 20.453616566956043, 35.225219428539276, 36.05713538825512, 35.59600353240967, 40.60747481882572, 47.52822205424309, 38.078843504190445, 22.558999992907047, 10.747984517365694, 3.1873889034613967, 0.4789122595684603, 0.30128731741569936, 0.1340291096130386, 0.1124605763470754, 0.1323653184226714, 0.22417961357859895, 0.1244611042784527, 0.11099924304289743, 0.17164035234600306, 0.14561290678102523, 0.13542562373913825, 0.13036640302743763, 0.07798253267537802, 0.2729341294616461, 0.1451104728039354, 0.20487909845542163, 0.14779833873035386, 0.16846014565089718, 0.11643989055301063, 0.24019475968088955, 0.09248820977518335, 0.16604564239969477, 0.13665545149706304, 0.052654713435913436, 0.2285163980559446, 0.12854955130023882, 0.18323577154660597, 0.1883705725776963, 0.11327924687066115, 0.19563599053071812, 0.11531063122674823, 0.1396318050683476, 0.10946231457637623, 0.23806316312402487, 0.08052475954173133, 0.13887102948501706, 0.24717908177990466, 0.30545821704436094, 0.19557310093659908, 0.19154289766447619, 0.15558970189886168, 0.21558156557148322, 0.1186934368161019, 0.1515351264970377, 0.123625334672397], [0.029866004042560235, 0.06590847275219858, 0.03412244732317049, 0.048500708799110726, 0.021580259199254215, 0.015260640739143128, 0.07517593054217286, 0.051329582784092054, 0.10597867338219658, 0.037269275926519185, 0.08119830308714882, 0.0505382678238675, 0.04007994131825399, 0.06606240160181187, 0.05736479448387399, 0.06248489356948994, 0.021950422051304486, 0.02937236822617706, 0.06883752925205044, 0.07855938922148198, 0.03564976497727912, 0.04142274621699471, 0.06761507844203152, 0.03479809114651289, 0.02350442733586533, 0.01664527771936264, 0.04741729935631156, 0.04734017908049282, 0.04985161423974205, 0.021072260969958734, 0.07630074440385215, 0.027003100731235463, 0.07255879128933884, 0.05667929493938573, 0.06952002309844829, 0.007382261683233082, 0.04503459713305347, 0.007966442299220944, 0.027265429525868967, 0.03567208506865427, 0.05054520690464415, 0.022762706394132692, 0.05904697238293011, 0.06785845092963427, 0.023420301185979042, 0.03351200488395989, 0.08625285568996333, 0.026326571896788664, 0.06097799610870425, 0.03870526859827805, 0.8202235714998096, 3.2267201179638505, 10.883708484470844, 18.70002966374159, 39.207527339458466, 40.77342711389065, 42.26013533771038, 49.81122314929962, 37.10454918444157, 26.869625486433506, 25.319764651358128, 12.924160994589329, 20.855486802756786, 16.585975103080273, 16.938337795436382, 11.644382067024708, 6.395949320867658, 5.270852018147707, 3.6556012043729424, 4.510313803330064, 2.317782766185701, 0.750673112925142, 0.518450770759955, 0.16499845718499273, 0.04984722443623468, 0.08350048228749074, 0.11900022582267411, 0.15505493996897712, 0.29314580897334963, 0.19363760948181152, 0.5301052203867584, 0.5302409443538636, 0.4513108968967572, 1.1775587126612663, 0.31825880985707045, 0.7076685049105436, 1.2279722699895501, 1.191529375500977, 1.9435723149217665, 1.5846315817907453, 1.938589713536203, 1.4484347775578499, 0.5625469295773655, 2.405359041877091, 1.1199390795081854, 1.4582112967036664, 2.575250300578773, 1.316357427276671, 0.8624607394449413, 1.3458545319736004, 0.3894501569448039, 0.912136067636311, 1.5399278118275106, 0.4538831807440147, 0.6720314640551805, 0.4195616708602756, 0.1503926792065613, 0.01965494444448268, 0.02895887508202577, 0.024893952286220156, 0.30614443647209555, 0.4318834893638268, 1.25627885106951, 2.4123093439266086, 5.237088929861784, 6.3702750485390425, 8.076813351362944, 25.278498865664005, 28.800260089337826, 27.99894578754902, 32.23201364278793, 21.67238026857376, 22.177470065653324, 29.490126371383667, 28.192070424556732, 29.263354539871216, 33.161762952804565, 19.43088434636593, 8.574740532785654, 2.6838408736512065, 0.17303397209616378, 0.10251593106659129, 0.04637587691831868, 0.0471424783609109, 0.035211137146689, 0.02736724476562813, 0.059694318115361966, 0.025905722213792615, 0.01807125510822516, 0.046016068881726824, 0.016578519680479076, 0.02945211570477113, 0.061670315990340896, 0.110318960796576, 0.013173441311664646, 0.019022065025637858, 0.03914428234566003, 0.0431405620474834, 0.02331238178157946, 0.05233289964962751, 0.05066181314759888, 0.012405157049215632, 0.06044249945261981, 0.04106300126295537, 0.014676820992463036, 0.04965415471815504, 0.03844606610073242, 0.05297440839058254, 0.04702171609096695, 0.04901559601421468, 0.06344989335048012, 0.09711422404507175, 0.08163457459886558, 0.06835013860836625, 0.05093830026453361, 0.038863809895701706, 0.012236952989042038, 0.042225171127938665, 0.054258275631582364, 0.061422635335475206, 0.05952133462415077, 0.026642520861059893, 0.030868660396663472, 0.08827554949675687, 0.03831111767794937, 0.03729862415639218, 0.022289772787189577, 0.060734950166079216, 0.04888946801656857, 0.019046928828174714, 0.04176748123427387, 0.027989259142486844, 0.01929027719597798, 0.00884537243109662, 0.09072806555195712, 0.04327132104663178, 0.08952901465818286, 0.01665419462369755, 0.05755685859185178, 0.05907807579205837, 0.049182263828697614, 0.008810183499008417, 0.08266321354312822, 0.023862392990849912, 0.10717081488110125, 0.01965951236343244, 0.08344534071511589, 0.016003768978407606, 0.056888413600972854, 0.041455445243627764, 0.04599596039042808, 0.030384755991690326, 0.05622886696073692, 0.07317875177250244, 0.05439412205305416, 0.04667714063543826, 0.043024812985095195, 0.02041633786575403, 0.02123335340002086, 0.0547143624862656, 0.02869410833227448, 0.06426299034501426, 0.053525883486145176, 0.046252034735516645, 0.00831449657198391, 0.034797330445144325, 0.06451134264352731, 0.011881720292876707, 0.0520752630836796, 0.04581180757668335, 0.026169065895373933, 0.10052296769572422, 0.023006223600532394, 0.05337693444744218, 0.019738115079235286, 0.0492163284070557, 1.2278519826941192, 5.2537857089191675, 13.519172016531229, 24.818223863840103, 43.2831696420908, 47.0428778976202, 48.3832673728466, 55.29206044971943, 44.3792512267828, 36.16486340761185, 32.412215173244476, 16.135019101202488, 16.004547402262688, 16.664199605584145, 19.223996847867966, 16.03222131729126, 9.086735509335995, 9.626777730882168, 4.947604788467288, 4.467519549652934, 2.037102277390659, 0.7883620436768979, 0.3421986830653623, 0.15219329274259508, 0.05595953785814345, 0.11445669384556822, 0.053109976506675594, 0.10211246248218231, 0.3663747076643631, 0.3188047040021047, 0.1317124511115253, 0.519701378652826, 0.9781259391456842, 1.5623975498601794, 1.1637865891680121, 1.1203971924260259, 2.902168845757842, 1.0277681378647685, 2.5776486843824387, 2.5321793742477894, 2.10749801248312, 3.8298938143998384, 2.6928542274981737, 1.726570709142834, 1.3019852922298014, 1.8804131727665663, 2.007555775344372, 1.3688943581655622, 0.889144332613796, 1.054242504760623, 0.3830593451857567, 0.7329328148625791, 0.19200813520001248, 0.3440440777922049, 0.17409702442819253, 0.23901478940388188, 0.1702536642551422, 0.03500777012959588, 0.11944843106903136, 0.10525505713303573, 0.10467934349435382, 0.5594367964658886, 0.9289109206292778, 2.5598456896841526, 5.626752795651555, 6.927551245316863, 11.591798588633537, 26.430188566446304, 32.2253829985857, 26.746597588062286, 36.20590880513191, 22.127375453710556, 25.652624890208244, 31.727938391268253, 32.23205924034119, 35.768670067191124, 38.03928762674332, 23.94630365073681, 11.489453930407763, 3.5903777042403817, 0.32752197061199695, 0.06011816978571005, 0.054189549045986496, 0.06443430029321462, 0.02064531454379903, 0.04158538788033184, 0.031005638593342155, 0.09506954782409593, 0.04049710994877387, 0.028050081855326425, 0.05115394982567523, 0.024182234519685153, 0.015118156734388322, 0.06659488513832912, 0.040359534323215485, 0.04871421726420522, 0.047792288023629226, 0.05646067678753752, 0.01855880345829064, 0.02835118972143391, 0.05910169093112927, 0.03968876269937027, 0.053017323079984635, 0.015336311043938622, 0.035631363425636664, 0.07183981346315704, 0.05117802880704403, 0.00970034418060095, 0.08964084889157675, 0.02859142106899526, 0.04201503201329615, 0.06632565622567199, 0.07677813831833191, 0.05531707174668554, 0.02239777568320278, 0.09904532940709032, 0.036991586530348286, 0.03905300189217087, 0.027584760828176513, 0.038312913675326854, 0.02560211331001483, 0.011427348727011122, 0.022849341003166046, 0.02373518331296509, 0.03680209396407008, 0.07405585158267058, 0.08460300945444033, 0.12512969027739018, 0.1347165461629629, 0.12935543461935595, 0.1611577984294854, 0.08351210432010703, 0.1287225607666187, 0.17114210408180952, 0.3092354815453291, 0.11898496726644225, 0.19035437784623355, 0.08710242924280465, 0.10763861282612197, 0.18269254913320765, 0.15564959321636707, 0.1294611016055569, 0.10747082807938568, 0.11991984327323735, 0.14024078176589683, 0.20272308523999527, 0.15249883494107053, 0.1612831768579781, 0.11745076990337111, 0.14695033110911027, 0.15693895606091246, 0.1316900976235047, 0.1200295846501831, 0.14362053712829947, 0.13097653747536242, 0.12149378264439292, 0.1966824335977435, 0.1393681496847421, 0.11484999500680715, 0.14870867191348225, 0.13182225928176194, 0.1404190604807809, 0.17282624496147037, 0.10581189795630053, 0.10838810776476748, 0.10160096688196063, 0.17720815201755613, 0.09575182644766755, 0.09063484438229352, 0.202261692029424, 0.14945984410587698, 0.30617124284617603, 0.24909029016271234, 0.13508919335436076, 0.21153601468540728, 0.288845983450301, 1.3706854870542884, 5.553481327369809, 15.79625777900219, 27.440001480281353, 49.416192546486855, 55.11093556880951, 56.38507179915905, 63.60335446894169, 51.53677895665169, 39.76905360817909, 40.01827843487263, 21.867522597312927, 34.818394258618355, 27.154329009354115, 29.456691965460777, 23.14452387392521, 14.296082127839327, 11.923062913119793, 6.644635526463389, 6.872700238600373, 3.2577746640890837, 1.3627817924134433, 0.8468582422938198, 0.5992644187062979, 0.5118251137901098, 0.9192603884730488, 0.3776980109978467, 0.3559401707025245, 1.1306144879199564, 1.382165146060288, 1.9570702593773603, 2.5613496964797378, 4.065501596778631, 5.071419244632125, 2.528883763588965, 3.336465354077518, 7.189937615767121, 4.9723386112600565, 6.189248012378812, 5.799063574522734, 6.35849948041141, 9.3474680185318, 4.421340627595782, 8.062726557254791, 6.406645271927118, 4.339815527200699, 7.65362435951829, 6.883717747405171, 2.8904246259480715, 6.428969549015164, 2.504714922979474, 2.781498245894909, 3.4561472944915295, 1.4179274020716548, 1.8251059530302882, 1.2497023539617658, 0.529065263690427, 0.4891818022588268, 0.3622227773303166, 0.33770488982554525, 0.47651536006014794, 0.8211361756548285, 1.8881277088075876, 3.2925518229603767, 7.365726632997394, 10.437780562788248, 12.02010590583086, 33.89751747250557, 35.36067456007004, 37.738537564873695, 44.68779467046261, 31.90765544772148, 33.01081225275993, 41.700060591101646, 39.9179258197546, 40.848062708973885, 42.96264924108982, 29.294275380671024, 12.676592878997326, 4.703369569033384, 0.5031962518114597, 0.20150550291873515, 0.188569423626177, 0.11668299586744979, 0.1296182587975636, 0.10844875607290305, 0.15517957624979317, 0.18690555822104216, 0.13684835052117705, 0.21922497631749138, 0.10842522257007658, 0.10165244966628961, 0.1306497846962884, 0.2414364172727801, 0.15881412575254217, 0.11224106390727684, 0.16619459143839777, 0.09028962696902454, 0.09497309089056216, 0.12072261699358933, 0.19223169976612553, 0.16292927524773404, 0.15208648284897208, 0.15056518401252106, 0.06102164552430622, 0.15217322506941855, 0.197973191679921, 0.10629332915414125, 0.11003448817064054, 0.11359433308825828, 0.13097686402034014, 0.21239914727630094, 0.09592687682015821, 0.20660091075114906, 0.1480931049445644, 0.17118407995440066, 0.11642472847597674, 0.12622520414879546, 0.07676904700929299, 0.255258220131509, 0.12108477021683939, 0.10882860209676437, 0.07789307419443503, 0.11950722400797531, 0.2585897210519761, 0.15908232307992876], [0.030047494401514996, 0.06170011321955826, 0.022843854676466435, 0.05366084675188176, 0.007383188903986593, 0.019996762821392622, 0.05735140985052567, 0.0068324420408316655, 0.04793127372977324, 0.04970446490915492, 0.03908916674845386, 0.0378978638764238, 0.060496230944409035, 0.04407257707498502, 0.05552850219828542, 0.03658720510429703, 0.06334625984891318, 0.05456535036501009, 0.02233652809081832, 0.01442381450033281, 0.015331508420786122, 0.04618566075805575, 0.056305757170775905, 0.02933804575150134, 0.030841520056128502, 0.044087468268116936, 0.027089490431535523, 0.06154029913886916, 0.021830385230714455, 0.07482464978238568, 0.027360287131159566, 0.06211271022039, 0.0034364218163318583, 0.046415518736466765, 0.003222594923499855, 0.10982372565194964, 0.06476428883615881, 0.03172936616465449, 0.03381943213753402, 0.037366074247984216, 0.09756029932759702, 0.04182817407127004, 0.02892247459385544, 0.06441051446017809, 0.02126119321474107, 0.009567591587256175, 0.018170586008636747, 0.0470086468703812, 0.04490713698032778, 0.04329188224801328, 0.013155036976968404, 0.7134055439382792, 3.8912875950336456, 11.270439382642508, 26.40207577496767, 35.554616153240204, 39.52625423669815, 42.69196696579456, 30.76481357216835, 25.96553809940815, 25.710944160819054, 32.04229362308979, 23.638140186667442, 20.240140222012997, 17.12335366755724, 16.732713729143143, 11.927804108709097, 12.191635351628065, 10.315904952585697, 6.9674700032919645, 5.73995347134769, 2.8407311299815774, 1.4596346765756607, 0.8374174707569182, 0.2307388631743379, 0.11673942135530524, 0.12521661061327904, 0.13855738303391263, 0.016363627109967638, 0.0664777222846169, 0.05712747421057429, 0.27023036673199385, 0.30971084197517484, 0.6089616171084344, 0.3279520303476602, 0.7334020303096622, 1.32570777554065, 0.6513714976608753, 1.235662701074034, 1.3210111088119447, 0.8885176631156355, 2.091835727915168, 1.3853066274896264, 1.8118862248957157, 1.7846375307999551, 0.7872915104962885, 0.7973002328071743, 0.3699832671554759, 1.0902693215757608, 1.4186573191545904, 0.22058490256313235, 0.2856315637473017, 0.13589212292572483, 0.1343225102755241, 0.10223971112282015, 0.004875083668594016, 0.13441130082355812, 0.05755462101660669, 0.12642700894502923, 0.4480115754995495, 0.23607558774529025, 1.382794368546456, 1.8538984330371022, 5.451526148244739, 7.7760818134993315, 13.719468768686056, 14.140965901315212, 22.723656557500362, 19.863741919398308, 40.21796531975269, 37.53990702331066, 17.05324362963438, 31.91805548965931, 34.22504089772701, 34.95045617222786, 30.52139863371849, 18.671580590307713, 11.110273227095604, 2.895240392535925, 0.778552929405123, 0.04634656579582952, 0.026916724018519744, 0.04152744098973926, 0.07532957737566903, 0.056808395238476805, 0.048804080215631984, 0.04584779802826233, 0.023554032486572396, 0.023910109375719912, 0.04574393817165401, 0.042867099182331, 0.06042209410225041, 0.05256269083474763, 0.03450341027928516, 0.022142905472719576, 0.0073090339719783515, 0.04902975990262348, 0.01791144288290525, 0.02875647842301987, 0.034061813857988454, 0.037775264790980145, 0.03355547618411947, 0.011566695302462904, 0.06469998173997737, 0.08712910203030333, 0.015128065333556151, 0.029712182804360054, 0.045308887492865324, 0.04232319028233178, 0.07018816380877979, 0.025769859093998093, 0.05532695344300009, 0.034619686266523786, 0.06374813281581737, 0.05954714652034454, 0.00749363671275205, 0.03919700451660901, 0.02374149527895497, 0.02447724007652141, 0.049426400728407316, 0.030614844035881106, 0.030090986110735685, 0.013609473480755696, 0.04726653205580078, 0.0545321503886953, 0.04027294795378111, 0.010812765103764832, 0.02330345188966021, 0.07438338361680508, 0.05988084951241035, 0.015800394539837725, 0.06936304402188398, 0.04159047159191687, 0.01643342424358707, 0.02415478247712599, 0.021531464844883885, 0.04269279095751699, 0.012519947813416366, 0.09101454197661951, 0.06170158267195802, 0.03993721147708129, 0.02730486539803678, 0.040152682922780514, 0.012772147219948238, 0.04286582268832717, 0.021039741914137267, 0.01187914782349253, 0.033279512281296775, 0.06451402179664001, 0.03371911974682007, 0.015186450091277948, 0.014075924427743303, 0.012189317312731873, 0.05088354089821223, 0.031646041534258984, 0.10644964771927334, 0.0364618118328508, 0.009715667674754513, 0.039525156244053505, 0.00971475668848143, 0.02276931336382404, 0.0543083520460641, 0.014016102686582599, 0.0661082069564145, 0.059290727076586336, 0.027444656334409956, 0.0391682796907844, 0.09681854498921894, 0.03245951702410821, 0.06147564694401808, 0.03471629534033127, 0.005619828862108989, 0.04070762384799309, 0.042656577861635014, 0.01717669812933309, 0.027263980482530314, 0.10837416280992329, 1.2072165962308645, 6.228609150275588, 15.313349291682243, 31.814678236842155, 40.921543166041374, 45.12762486934662, 49.44928117096424, 38.34259495139122, 31.84544138610363, 27.832602113485336, 27.13023640215397, 26.849782951176167, 21.98010105639696, 23.024801798164845, 21.070585660636425, 18.996043279767036, 13.867538273334503, 14.7728387452662, 10.204548127949238, 6.428235238417983, 3.025286989286542, 1.8891033064574003, 0.49677029193844646, 0.3017532970989123, 0.20350523467641324, 0.09805326350033283, 0.055994270369410515, 0.12664929701713845, 0.05928381397097837, 0.06954047668841667, 0.26724485505837947, 0.24387861747527495, 0.25080462160985917, 0.7042325392831117, 1.1604199698194861, 1.0635702917352319, 0.17868463997729123, 0.8808605396188796, 0.9683894959744066, 1.402609117794782, 1.7921762075275183, 2.7476109517738223, 2.0757469162344933, 1.004319239873439, 1.4829565188847482, 1.1663330462761223, 1.2430785968899727, 1.2320538447238505, 0.8056628715712577, 0.3705176728544757, 0.5220907379407436, 0.5062731367070228, 0.21593401150312275, 0.16694361140253022, 0.04925910208839923, 0.08572472113883123, 0.09407466175616719, 0.1251897300244309, 0.48555620305705816, 0.41649579943623394, 1.9656918779946864, 2.5853769946843386, 7.137579750269651, 10.821597017347813, 14.851086046546698, 13.761978037655354, 28.186498023569584, 28.509955666959286, 45.08258208632469, 44.52102541923523, 21.789081506431103, 32.39417754113674, 39.276831820607185, 39.872704446315765, 35.263042598962784, 23.81915107369423, 14.450886771082878, 4.114084839820862, 1.0016935807652771, 0.018195856137026567, 0.06951859817490913, 0.013422700885712402, 0.06451510533224791, 0.06911528544151224, 0.0908080096996855, 0.06378722173394635, 0.016173770891327877, 0.012582366143760737, 0.021246261203486938, 0.023009999276837334, 0.040585355018265545, 0.022936910718271974, 0.009474325888731983, 0.05781584586657118, 0.0390851962583838, 0.036813586120842956, 0.06315360573353246, 0.079607242369093, 0.052991214324720204, 0.03971233330958057, 0.08415098214754835, 0.06851757454569452, 0.042173413748969324, 0.0703958464146126, 0.06895165672176518, 0.021441184435389005, 0.05293995047395583, 0.034271314725629054, 0.05805954489915166, 0.02038014332356397, 0.08285793825052679, 0.02209237078204751, 0.037545221275649965, 0.04618678882252425, 0.07871872090618126, 0.03488664049655199, 0.025196874703397043, 0.04194221619400196, 0.03398309796466492, 0.047455048697884195, 0.008869524699548492, 0.01197293859149795, 0.04703884114860557, 0.023054984558257274, 0.05612335582554806, 0.10803905344801024, 0.13179710047552362, 0.16479286743560806, 0.09419289330253378, 0.1094076999288518, 0.2336511100293137, 0.16720239829737693, 0.09599643832189031, 0.14842996577499434, 0.15383143530925736, 0.12726931687211618, 0.11679473362164572, 0.22270653949817643, 0.18239217228256166, 0.17675539740594104, 0.11600342608289793, 0.1893356762593612, 0.09530155060929246, 0.08915508355130441, 0.08451165849692188, 0.14940425724489614, 0.12355668601230718, 0.1463053750921972, 0.08012926162336953, 0.16045180818764493, 0.24598610907560214, 0.08938305647461675, 0.13023743260418996, 0.28939796320628375, 0.2806425798917189, 0.15184308809693903, 0.11057731724577025, 0.17991442320635542, 0.1587343300343491, 0.07076433757902123, 0.18681926128920168, 0.1892848836723715, 0.13028994697378948, 0.12315057538216934, 0.09633586698328145, 0.23672104842262343, 0.10917750056250952, 0.0898957766185049, 0.21891542652156204, 0.06434191032894887, 0.11446099088061601, 0.12733027688227594, 0.1262847540783696, 0.23951176117407158, 0.1753081352217123, 0.16691116470610723, 1.5991497715003788, 6.2864534463733435, 16.687190271914005, 33.02251182496548, 46.3540318608284, 53.17308895289898, 56.45121105015278, 44.00144509971142, 38.03527124226093, 36.452815756201744, 40.67892238497734, 34.33979853987694, 33.25639687478542, 30.034021586179733, 31.8620502948761, 24.774706698954105, 23.259712792932987, 17.45497517287731, 12.459036502987146, 9.137795269489288, 4.430654402822256, 2.2788438806310296, 1.2863315572030842, 0.4860611603362486, 0.3375579445855692, 0.37698094791267067, 0.5539391445927322, 0.5667908268515021, 0.5240788031369448, 0.8150788850616664, 1.387997001875192, 2.343980222940445, 2.9356120387092233, 1.5621333452872932, 4.834684347733855, 5.888366382569075, 2.7863455982878804, 4.577920250594616, 3.980829077772796, 3.710538181476295, 5.242409594357014, 4.704480534419417, 5.508794775232673, 3.480417779646814, 4.045905573293567, 3.662975183688104, 4.265776975080371, 2.781572579406202, 3.0455807503312826, 1.512337967287749, 2.0151772163808346, 1.10125940060243, 0.4021997790550813, 0.25741680117789656, 0.3845222370000556, 0.5043561989441514, 0.21407269028713927, 0.38595746154896915, 1.011816831305623, 0.6537913740612566, 2.534027025103569, 2.998834471218288, 9.194868206977844, 12.926941495388746, 19.38582256436348, 22.620471194386482, 31.386559009552002, 28.950027152895927, 49.27021197974682, 47.419521287083626, 26.032095327973366, 42.88503460586071, 44.70487855374813, 46.571581587195396, 41.203419640660286, 26.52234122157097, 16.130318753421307, 5.08538207039237, 1.0171697940677404, 0.19444672856479883, 0.19351089518750086, 0.10628923249896616, 0.20690317265689373, 0.19394275092054158, 0.21584401867585257, 0.099566962744575, 0.1191753578314092, 0.07109303478500806, 0.15334730269387364, 0.0976592572988011, 0.14948924799682572, 0.15131553984247148, 0.11944104669964872, 0.17273789970204234, 0.15335258678533137, 0.19715203496161848, 0.2197558048646897, 0.15470099489903077, 0.15851260599447414, 0.1525690866401419, 0.14996422250987962, 0.2081786870257929, 0.1434820523718372, 0.17077450349461287, 0.12315913234488107, 0.10466236315551214, 0.1516511687077582, 0.11319928787997924, 0.18374522624071687, 0.15612912451615557, 0.14210017339792103, 0.14000071183545515, 0.13912772352341563, 0.15372786117950454, 0.1399210942327045, 0.16472133924253285, 0.1375648198882118, 0.1398338918806985, 0.13703195785637945, 0.20184249733574688, 0.15034843236207962, 0.18564644531579688, 0.12847595993662253, 0.12898537010187283, 0.11326291962177493], [0.09603748650988564, 0.014084073209232884, 0.020170599782431964, 0.0867993435531389, 0.021819158391735982, 0.05684546922566369, 0.05275908908515703, 0.02712719524424756, 0.02122523801517673, 0.07017205178271979, 0.02886308608140098, 0.07730549361440353, 0.06713729118928313, 0.020104635841562413, 0.022795195764047094, 0.04596716506057419, 0.04765958830830641, 0.06961779363336973, 0.03947391836845782, 0.031560753923258744, 0.07150730903958902, 0.010273918578604935, 0.03916489549737889, 0.06487429738626815, 0.036053419098607264, 0.03516836717608385, 0.044559589223354124, 0.02642418101459043, 0.048517759641981684, 0.01885706889879657, 0.052063444381929, 0.013359039458009647, 0.051041291808360256, 0.03157577870297246, 0.05147613468579948, 0.07860983299906366, 0.10648353418218903, 0.09033951413584873, 0.058926670244545676, 0.0053914440468361136, 0.022915612935321406, 0.060426276104408316, 0.0450613478460582, 0.036040739505551755, 0.05299759308400098, 0.08032555226236582, 0.065775145922089, 0.05687849479727447, 0.06147527958091814, 0.04235358865116723, 0.03292252069513779, 0.09126408913289197, 0.7230326242279261, 4.293328346684575, 11.951183304190636, 24.998117610812187, 30.890609622001648, 45.62221013009548, 41.26364640891552, 36.42768770456314, 38.30097958445549, 25.654304400086403, 20.560577027499676, 29.035220481455326, 25.693265609443188, 20.835644267499447, 21.162141747772694, 22.967265285551548, 14.824534971266985, 10.25133691728115, 6.878803661093116, 6.132837189361453, 4.725467758253217, 2.13652940467, 1.4469272084534168, 0.7220172474626452, 0.17086560954339802, 0.16892867832211778, 0.1512077503139153, 0.12745382962748408, 0.048019852765719406, 0.10830408180481754, 0.3468301595421508, 0.04884965550445486, 0.7678645185660571, 0.07971859420649707, 0.686508152866736, 0.43926667131017894, 0.18705156835494563, 0.3027940553147346, 1.4729691110551357, 1.5360121219418943, 3.3672270784154534, 0.9648312244098634, 0.9726215188857168, 1.54660583473742, 0.6434512382838875, 0.2566859044600278, 0.45192889811005443, 0.1953487200080417, 0.10234189001494087, 0.2780891169095412, 0.4248720343457535, 0.1771584281232208, 0.1256773655768484, 0.15064928418723866, 0.048433310657856055, 0.31336306943558156, 0.4526453377911821, 0.9009401465300471, 1.5154540375806391, 3.555674166418612, 4.44506797939539, 7.7816166914999485, 14.816920179873705, 12.417915109544992, 17.540303394198418, 12.566819619387388, 13.980254475027323, 30.142011791467667, 36.606954485177994, 27.78844278305769, 28.65850679576397, 40.45012906193733, 28.323571868240833, 23.359537236392498, 11.886690314859152, 4.73111093044281, 0.7856044603977352, 0.03639820235548541, 0.05259937148366589, 0.06267752542044036, 0.027907101539312862, 0.03789801230595913, 0.04191137253656052, 0.08471991255646572, 0.016981797161861323, 0.02150434120267164, 0.0350127907586284, 0.025913319950632285, 0.07697492619627155, 0.019784048454312142, 0.09942429227521643, 0.009207669445459032, 0.016975062171695754, 0.06439732649596408, 0.017775499982235488, 0.0017539799910082365, 0.05556339427130297, 0.03959430585382506, 0.06728119362378493, 0.021903232591284905, 0.0351640181906987, 0.06823324292781763, 0.018447473885316867, 0.02789990270684939, 0.057250555692007765, 0.03947862358472776, 0.018822265883500222, 0.09300598394474946, 0.029925930612080265, 0.024476956205035094, 0.028171987032692414, 0.06820996917667799, 0.024475405116390903, 0.02283162593812449, 0.04050547395308968, 0.04432587207702454, 0.044997641889494844, 0.029765327999484725, 0.042673298448789865, 0.06916751037351787, 0.0503076751192566, 0.017622986779315397, 0.07042235592962243, 0.05151649267645553, 0.061062099994160235, 0.014091509528952884, 0.04860126609855797, 0.027654222139972262, 0.0800052635895554, 0.04401423684612382, 0.05851177258591633, 0.0691343066864647, 0.031586725381202996, 0.05518704747373704, 0.07299612407223321, 0.037935535292490385, 0.08899112828657962, 0.02034494511462981, 0.03575549504603259, 0.05212957716139499, 0.042664403808885254, 0.0368126250396017, 0.05453631383716129, 0.0052376849635038525, 0.05077236346551217, 0.04445361053512897, 0.015317283305193996, 0.024073734384728596, 0.03437036546529271, 0.03331202577101067, 0.033650396871962585, 0.010462592927069636, 0.029912171194155235, 0.05725308641558513, 0.046402735242736526, 0.01640844355279114, 0.01939026675245259, 0.012620510678971186, 0.08957789992564358, 0.013478189412126085, 0.124717679573223, 0.015780859357619192, 0.044113736585131846, 0.06532871440867893, 0.028536066129163373, 0.04800726965186186, 0.04053858858242165, 0.03697951549838763, 0.0751534805749543, 0.05494097356859129, 0.026399409980513155, 0.09065937978448346, 0.010425821365060983, 0.016252653767878655, 0.03485932946205139, 0.11529742099810392, 1.0732239112257957, 6.658967882394791, 15.650904178619385, 29.071533232927322, 37.163769006729126, 49.27759878337383, 44.884111136198044, 40.82206450402737, 39.506989270448685, 30.213400460779667, 20.152678415179253, 29.037369266152382, 27.83161986619234, 29.83461208641529, 26.357160285115242, 29.29031979292631, 20.395168103277683, 13.364461418241262, 10.081501230597496, 6.823757439851761, 5.740636959671974, 2.432790007442236, 1.1285991710610688, 0.829911686014384, 0.19320520455949008, 0.03998599284386728, 0.1262312600738369, 0.04778171984071378, 0.25239896262064576, 0.11545124594704248, 0.1062206803180743, 0.07163974529248662, 0.38485175056848675, 0.39579186821356416, 1.186501532793045, 0.3243030980229378, 0.8388664398808032, 0.3791161661501974, 0.9205659152939916, 0.9574081446044147, 0.9782454546075314, 1.3852845411747694, 1.0889764409512281, 0.92437889194116, 0.9249089634977281, 0.29842663498129696, 0.1601305473013781, 0.12985353445401415, 0.2391647922922857, 0.15638982615200803, 0.10752147965831682, 0.11481895839096978, 0.06053712699213065, 0.018893703163485043, 0.08712934693903662, 0.24836858123308048, 0.5292402324266732, 1.2801595008932054, 2.340477998368442, 5.726341651752591, 6.156932646408677, 9.989397022873163, 16.568516939878464, 16.817886158823967, 24.328720830380917, 18.862554542720318, 14.492375794798136, 34.90423925220966, 40.27712434530258, 25.84609340876341, 34.885289669036865, 43.68958443403244, 34.032744616270065, 28.285218626260757, 14.63888643309474, 6.307389847934246, 1.1648960108868778, 0.04573261299810838, 0.029531377076637, 0.08323967675096355, 0.08850566722685471, 0.08100833554635756, 0.036834781858487986, 0.064344671118306, 0.04866910952841863, 0.021551406352955382, 0.026863178063649684, 0.023264932569873054, 0.03262513841036707, 0.03129340635496192, 0.06544642645167187, 0.055168371327454224, 0.0462730041181203, 0.04284891656425316, 0.003981637592005427, 0.015969869527907576, 0.04117230106203351, 0.051794226601487026, 0.029635285172844306, 0.0411274419457186, 0.09148766854195856, 0.046476452771457843, 0.0206554355827393, 0.026136409542232286, 0.07884467078838497, 0.03669872021418996, 0.024171619952539913, 0.04588410389260389, 0.07274230214534327, 0.0335407965030754, 0.08545315446099266, 0.047050403809407726, 0.03538745288096834, 0.0826355759636499, 0.021540964335144963, 0.01781930710421875, 0.040585870810900815, 0.049111711559817195, 0.018125749156752136, 0.06594819249585271, 0.06274336876231246, 0.04504520613409113, 0.12658801046200097, 0.052925894196960144, 0.14291091036284342, 0.11576015007449314, 0.14563192060450092, 0.27954633871559054, 0.10734116003732197, 0.13933945825556293, 0.1629067288013175, 0.1664379713474773, 0.15054660063469782, 0.12995893426705152, 0.11456512162112631, 0.15698229748522863, 0.21912604803219438, 0.13293478317791596, 0.161753416468855, 0.2402386354515329, 0.13590565969934687, 0.17890482034999877, 0.1496327348286286, 0.09475095866946504, 0.19543767382856458, 0.09599390759831294, 0.1627148242550902, 0.14381428220076486, 0.1156674038793426, 0.1295987848425284, 0.12681052117841318, 0.09738429900608025, 0.2032223725109361, 0.11980869923718274, 0.18190006900113076, 0.12975649122381583, 0.18235439696582034, 0.1441191416233778, 0.2242041044519283, 0.17727734986692667, 0.22494640055811033, 0.16354292747564614, 0.17250826436793432, 0.1027546428667847, 0.19345995417097583, 0.1547337681404315, 0.17558807332534343, 0.07372709500486962, 0.16991019831039011, 0.15003750217147171, 0.14817732386291027, 0.10364060392021202, 0.14954891667002812, 0.10750039524282329, 0.18149096751585603, 0.29933900164905936, 1.1454171873629093, 6.603158377110958, 16.45110134035349, 32.802119851112366, 41.774183213710785, 58.08402143418789, 55.55005140602589, 48.17129574716091, 50.53361378610134, 36.22431881725788, 30.02467978745699, 39.72018823027611, 35.37496939301491, 32.85180978477001, 33.38187374174595, 34.435177221894264, 24.278692714869976, 19.07087456434965, 13.190199919044971, 10.491667371243238, 7.380307875573635, 3.469574823975563, 2.2154820431023836, 1.377075081691146, 0.5054479872342199, 0.4048006801167503, 0.49993608612567186, 0.36503471550531685, 0.35444302135147154, 0.6625586317386478, 0.4506969329668209, 1.006737572606653, 2.246583136729896, 1.3541757292114198, 2.8275270760059357, 1.1795797292143106, 2.2547971084713936, 3.080431530252099, 5.596177261322737, 5.682474905624986, 6.844419306144118, 3.877567956224084, 2.031694930046797, 3.9625513460487127, 3.844462470151484, 2.444524015299976, 2.1309650782495737, 2.007081750780344, 1.312038959003985, 1.1356642981991172, 1.1341139813885093, 0.6595201604068279, 0.429389932542108, 0.21866553055588156, 0.1345030005904846, 0.6199627986643463, 0.8647922112140805, 1.5871281665749848, 2.8956647822633386, 6.168522499501705, 8.26817773282528, 13.056442346423864, 22.56655588746071, 21.350957415997982, 28.969189524650574, 22.463703006505966, 22.073579840362072, 43.374364748597145, 46.12577810883522, 36.62550888955593, 40.34958265721798, 51.201762333512306, 38.78382347524166, 30.688654258847237, 16.453191228210926, 6.447047078981996, 1.5155362081713974, 0.15316080098273233, 0.18711818353040144, 0.20156741287792102, 0.11909151740837842, 0.1602019864367321, 0.08988531233626418, 0.20294025249313563, 0.15303120715543628, 0.1116745825856924, 0.10472192050656304, 0.15891896153334528, 0.16033226303989068, 0.14398034516489133, 0.2738956263056025, 0.06963153078686446, 0.10039387852884829, 0.14472673792624846, 0.0661144261539448, 0.17848595220129937, 0.14327937184134498, 0.13043974206084386, 0.1282659321441315, 0.12337778389337473, 0.16042987030232325, 0.13957224029581994, 0.13712012500036508, 0.13955836213426664, 0.1786534846178256, 0.19746447913348675, 0.10733923045336269, 0.13080771372187883, 0.15955606562783942, 0.17511845711851493, 0.14327187614981085, 0.13002077001146972, 0.09782225519302301, 0.12023909293930046, 0.0998690168489702, 0.12972983327927068, 0.11726629425538704, 0.11495789585751481, 0.08767735620494932, 0.20267661195248365, 0.12072252051439136, 0.09924004669301212, 0.1994569378439337, 0.15422214637510478], [0.04748312785523012, 0.02736243564868346, 0.011794443726103054, 0.04347731526650023, 0.070795107021695, 0.05456104961922392, 0.04162507422734052, 0.04887891096586827, 0.03649529011454433, 0.022972925289650448, 0.026976776753144804, 0.07305939216166735, 0.06462885430664755, 0.06499286289908923, 0.01828137566917576, 0.05242599465418607, 0.030826031434116885, 0.018230037603643723, 0.03788562957197428, 0.022945796081330627, 0.014713469172420446, 0.04543648123217281, 0.038267746567726135, 0.07782642933307216, 0.07489607407478616, 0.04834409337490797, 0.06994450188358314, 0.028533726508612745, 0.026481760542083066, 0.013152053543308284, 0.010892641530517722, 0.011123211970698321, 0.06599769374588504, 0.06758670613635331, 0.03338750590046402, 0.02181068492063787, 0.03140577122394461, 0.006431747697206447, 0.018674372549867257, 0.05703536997316405, 0.03414492697629612, 0.036910532871843316, 0.011442482045822544, 0.002657143331816769, 0.04618280348950066, 0.013972919896332314, 0.03333447202749085, 0.0670407155121211, 0.028117342699260917, 0.04663525010982994, 0.009379025777889183, 0.021090718182676937, 0.03172936616465449, 0.4334824316902086, 5.569469919428229, 12.265288699418306, 22.40290816873312, 36.90395414829254, 41.929059103131294, 45.795458033680916, 39.86283637583256, 44.253432378172874, 31.63855768740177, 18.22187852114439, 19.726219698786736, 19.541416615247726, 16.298716217279434, 15.373330023139715, 23.20319462567568, 16.683916747570038, 19.614878073334694, 11.259154938161373, 7.382687497884035, 5.7724460028111935, 2.507174341008067, 2.785234870389104, 1.652248241007328, 0.4311938857426867, 0.29189258872065693, 0.0863073070649989, 0.12927712319651619, 0.04709261345851701, 0.19921916857128963, 0.05206434609135613, 0.1248649216722697, 0.07200297462986782, 0.20992074511013925, 0.15040240134112537, 0.05222390413109679, 0.2346405413118191, 0.08042340443353169, 0.09896449468214996, 0.7691857195459306, 0.7230271026492119, 0.8824283711146563, 0.29813108209054917, 0.1206354220630601, 0.5115047434810549, 0.21562940441071987, 0.08208579296479002, 0.08471023495076224, 0.02229432029707823, 0.046893840335542336, 0.18483106250641868, 0.06566300740814768, 0.30477101798169315, 0.3522987785981968, 0.4699890618212521, 1.350510350894183, 2.477873875759542, 1.5601864247582853, 4.788859281688929, 8.653267119079828, 16.448559276759624, 21.364836171269417, 21.269375793635845, 13.213589563965797, 13.688509929925203, 15.12269927188754, 29.76308662444353, 34.425392746925354, 33.31933669745922, 38.70510309934616, 31.57239753752947, 21.33694376796484, 11.870232447981834, 4.6063564997166395, 0.5432320316322148, 0.06432558308006264, 0.0674585001252126, 0.025391309973201714, 0.06368678688886575, 0.06142555568658281, 0.012905374787806068, 0.03777586593059823, 0.029858523193979636, 0.012354593600321095, 0.015450488608621527, 0.08642485583550297, 0.05844672705279663, 0.02196703317167703, 0.04467774284421466, 0.01837614236137597, 0.06756185903213918, 0.027925937247346155, 0.02402921480097575, 0.03482290485408157, 0.004338537337389425, 0.02443820867483737, 0.012618400196515722, 0.027500298856466543, 0.02425814138405258, 0.01652286602620734, 0.009526236335659632, 0.04932379881211091, 0.05413136837887578, 0.03785298620641697, 0.04064887543790974, 0.019251678095315583, 0.10213204033789225, 0.03783037667744793, 0.022401291607820895, 0.022140794062579516, 0.025945725828933064, 0.029755746872979216, 0.04670904927479569, 0.04388724053569604, 0.06222724958206527, 0.022001190518494695, 0.04777913345606066, 0.022883561432536226, 0.00997955405182438, 0.04653276322642341, 0.061706106062047184, 0.0423973493889207, 0.011994831020274432, 0.018727274691627827, 0.020165504938631784, 0.015323015468311496, 0.08139877943904139, 0.07280531790456735, 0.06988226537941955, 0.03608514591178391, 0.05371748746256344, 0.02845504215656547, 0.02502240691683255, 0.03159940868499689, 0.046607311960542575, 0.02062469025986502, 0.08366278256289661, 0.02837123698554933, 0.05463007306389045, 0.07341743388678879, 0.0627751846332103, 0.026311151923437137, 0.04384610328997951, 0.08175498063792475, 0.04199022201646585, 0.020664289404521696, 0.0603437047539046, 0.1192471086687874, 0.024194654361053836, 0.06522617186419666, 0.013069862543488853, 0.11124935423140414, 0.06036378727003466, 0.034455512068234384, 0.013229456762928749, 0.03501692452118732, 0.02106626441673143, 0.055256427149288356, 0.067515244736569, 0.028939163639734033, 0.02530045068851905, 0.022502518695546314, 0.047224133159033954, 0.05222611202043481, 0.020253397487977054, 0.03290270164143294, 0.04061292580445297, 0.014160881783027435, 0.01783429292117944, 0.015738931724627037, 0.03678165521705523, 0.017489073652541265, 0.024545051965105813, 0.03784124543017242, 0.07418137101922184, 0.0772659519861918, 1.139871859923005, 7.167019145563245, 15.716466810554266, 26.80083967745304, 43.474865555763245, 48.33751402795315, 49.59207370877266, 43.957177475094795, 42.37207733094692, 32.02198751270771, 19.55785073339939, 22.701013572514057, 19.851493276655674, 21.85201372951269, 23.020945005118847, 26.637984216213226, 21.9824493303895, 23.340053781867027, 16.59377608448267, 9.040180407464504, 6.358434883877635, 2.969866725616157, 2.977804974652827, 1.5237121819518507, 0.5539731646422297, 0.5054967314936221, 0.05207106994930655, 0.05115077714435756, 0.09628105195588432, 0.04279339649656322, 0.11622824487858452, 0.17651698988629505, 0.17202368646394461, 0.1914932776708156, 0.2687104482902214, 0.4513516556471586, 0.43525904417037964, 0.5096733605023474, 0.3480296186171472, 0.5992697027977556, 0.7266226003412157, 0.4330777534050867, 0.410396711085923, 0.18512106413254514, 0.216457151400391, 0.3462142660282552, 0.09487775460002013, 0.2187826414592564, 0.038042705127736554, 0.04192613014311064, 0.14575029315892607, 0.028278412864892744, 0.08146949126967229, 0.45951002568472177, 0.7518347818404436, 1.880789352580905, 3.471206361427903, 3.627527360804379, 8.42702155932784, 13.419652506709099, 21.12820766866207, 24.00192316621542, 22.769966572523117, 17.578394450247288, 15.941618978977203, 17.520768642425537, 33.70801404118538, 38.83711941540241, 37.71261915564537, 39.5093185454607, 39.05743919312954, 25.60318384319544, 15.468398071825504, 6.066068597137928, 1.4530520047992468, 0.18236526200780645, 0.04426584346219897, 0.025966582034016028, 0.02200188257120317, 0.03624231794674415, 0.007406836975860642, 0.06919705527252518, 0.012107552120141918, 0.052917930952389725, 0.03849342254397925, 0.025401017264812253, 0.05148345968336798, 0.0414119479682995, 0.026801947169587947, 0.00590551629102265, 0.07781290740240365, 0.06502380303572863, 0.0027028689055441646, 0.04275731698726304, 0.012752379188896157, 0.03964819690736476, 0.1061103971733246, 0.032215469182119705, 0.0309162598932744, 0.016664887116348837, 0.031679081948823296, 0.031457495206268504, 0.034924067003885284, 0.039312798107857816, 0.041137672451441176, 0.012419623362802668, 0.029035436891717836, 0.02939989819424227, 0.006755786998837721, 0.0517994995607296, 0.029231638472992927, 0.01892412379675079, 0.052160751074552536, 0.09727486190968193, 0.033345095871482044, 0.043882234749617055, 0.11306961241643876, 0.039393287734128535, 0.05647576836054213, 0.09557460900396109, 0.03961723079555668, 0.019822458307316992, 0.05370844810386188, 0.16766649292549118, 0.2022607420803979, 0.10595798230497167, 0.15950708388118073, 0.20248435117537156, 0.1828740190831013, 0.13763559109065682, 0.23037207894958556, 0.11273234340478666, 0.060716463267453946, 0.15157782967435196, 0.15434623346664011, 0.11240193183766678, 0.20745130808791146, 0.16340156318619847, 0.15277314756531268, 0.2176142783719115, 0.1844265326508321, 0.12129954775446095, 0.10214700203505345, 0.14461068087257445, 0.1218825567048043, 0.12506546481745318, 0.17917518474860117, 0.19647546345368028, 0.12608747638296336, 0.18105033959727734, 0.15649671026039869, 0.32753256848081946, 0.1132178638363257, 0.14599765097955242, 0.1447343672043644, 0.19523858529282734, 0.18126436014426872, 0.20141867164056748, 0.07090617684298195, 0.1217995400656946, 0.06487841630587354, 0.13642137811984867, 0.14144512417260557, 0.19188881269656122, 0.11038481155992486, 0.15091242006747052, 0.16600308765191585, 0.11170274709002115, 0.08296995059936307, 0.1514464695355855, 0.13080084143439308, 0.12181875426904298, 0.10395928213256411, 0.10628825286403298, 0.1189549028640613, 0.22003240330377594, 1.1854872247204185, 7.650725115090609, 17.15918194502592, 31.012691371142864, 47.41426236927509, 55.795016661286354, 59.051392525434494, 52.34199374914169, 55.273878425359726, 41.90938375890255, 26.863084137439728, 28.913718201220036, 28.455316498875618, 28.594394735991955, 27.180323414504528, 34.644849970936775, 26.784401759505272, 31.46912667900324, 18.636004999279976, 12.5748685374856, 9.307346921414137, 4.316345136612654, 4.599902546033263, 2.538917362689972, 0.922840271377936, 0.5906984314788133, 0.1970216989866458, 0.3125188616104424, 0.5750943906605244, 0.57371785514988, 0.5538395186886191, 0.6898609385825694, 1.0611269040964544, 1.5018196566961706, 0.8481257117819041, 1.3281670748256147, 1.0670526861213148, 1.5568436728790402, 1.1102182511240244, 3.4946777019649744, 2.6038064807653427, 2.357782507315278, 1.7648120946250856, 0.8333174313884228, 1.5336750098504126, 0.9762360749300569, 0.429426446207799, 0.5359590437728912, 0.4624122683890164, 0.1886674464913085, 0.3591624868568033, 0.2999450988136232, 0.7237132627051324, 0.7163662381935865, 1.0471701342612505, 2.7710407320410013, 4.529200689867139, 3.5630241595208645, 9.74505303427577, 17.66916397958994, 25.66082864999771, 28.49635049700737, 32.08533391356468, 24.381490498781204, 23.417449928820133, 24.830588400363922, 42.29829668998718, 46.542072370648384, 42.79773809015751, 49.61424931883812, 42.790925055742264, 29.685092009603977, 17.267276644706726, 6.664176927879453, 1.769751354586333, 0.2995659504085779, 0.18026062025455758, 0.12006230594124645, 0.10804400357301347, 0.25721033569425344, 0.10680742969270796, 0.32003473956137896, 0.20719315944006667, 0.23247646837262437, 0.13959005184005946, 0.17579269828274846, 0.11820955653092824, 0.10152871880563907, 0.11386357684386894, 0.11679091898258775, 0.16892232553800568, 0.1440087694209069, 0.1221603128942661, 0.16927779943216592, 0.13110951549606398, 0.1705170821514912, 0.2625870471820235, 0.3374826314393431, 0.2333385025849566, 0.25517382309772074, 0.0825002379133366, 0.11351920547895133, 0.17676756862783805, 0.1743148299283348, 0.15839286788832396, 0.19402716279728338, 0.1630782539723441, 0.13774796709185466, 0.10881617112318054, 0.14283285127021372, 0.10974137694574893, 0.15648437576601282, 0.13841812644386664, 0.1521419658092782, 0.16895072010811418, 0.14862276089843363, 0.23826478980481625, 0.1225569611415267, 0.15633590170182288, 0.16827628598548472, 0.22001580888172612, 0.09477149389567785, 0.2163433950045146], [0.06228459533303976, 0.02738177416176768, 0.03894263711117674, 0.05136058229254559, 0.01601778629265027, 0.028609527616936248, 0.020553349459078163, 0.05723315603972878, 0.06820378708653152, 0.04355517397925723, 0.05211339463130571, 0.025302291214757133, 0.011232226970605552, 0.07442377871484496, 0.011294661071588052, 0.0178429111110745, 0.010574682273727376, 0.03614736386225559, 0.012331143589108251, 0.026896745403064415, 0.02101550708175637, 0.03535224539518822, 0.040378410849370994, 0.04921278094116133, 0.031854432891123, 0.09806576868868433, 0.018893066771852318, 0.043063059565611184, 0.02428158768452704, 0.03359118461958133, 0.04421901023306418, 0.0450407866446767, 0.008642120446893387, 0.03931600789655931, 0.07179894339060411, 0.050753490650095046, 0.038251497244345956, 0.06565865842276253, 0.048081922286655754, 0.03313819252070971, 0.058752376862685196, 0.029859437890991103, 0.01637590965401614, 0.08095416618743911, 0.06239175403607078, 0.027465026432764716, 0.06407832173863426, 0.049222362067666836, 0.02740116833592765, 0.08733570110052824, 0.058298338335589506, 0.07361041454714723, 0.01613403259398183, 0.09429272700799629, 0.6448291393462569, 4.576340010389686, 9.58814900368452, 20.794405080378056, 31.368141397833824, 43.450239077210426, 49.39095430076122, 48.06908503174782, 36.118144914507866, 38.482913821935654, 29.87208567559719, 37.81090468168259, 18.02758164703846, 31.72425828874111, 26.716256216168404, 17.231999337673187, 18.390847854316235, 10.495879445225, 15.965690687298775, 8.511793110519648, 8.08851957321167, 5.632939813658595, 3.3000507205724716, 2.442870154045522, 1.118065898772329, 0.6906802102457732, 0.3981279709842056, 0.13775086146779358, 0.03621822041168343, 0.103343819064321, 0.08490860360325314, 0.017547482530062553, 0.21246534684905782, 0.10582436603726819, 0.3273603308480233, 0.13650541892275214, 0.4309042700333521, 0.09864398336503655, 0.1981657196301967, 0.4227565275505185, 0.18963752256240696, 0.14077958097914234, 0.11127265024697408, 0.026716197571658995, 0.10160573889152147, 0.09582711732946336, 0.017736010304361116, 0.12523798446636647, 0.15236763807479292, 0.2651008794782683, 0.47462650516536087, 0.8223159529734403, 1.3472164026461542, 2.4551933677867055, 3.616423881612718, 4.406023174524307, 5.3701012674719095, 8.39496647939086, 13.134076930582523, 9.392930679023266, 16.038620173931122, 22.844214588403702, 27.238194309175014, 19.528835490345955, 22.42665309458971, 24.646678268909454, 31.40415396541357, 32.486440390348434, 36.153027042746544, 25.868008732795715, 10.357608664780855, 5.660509234294295, 0.9275674552191049, 0.10230339481495321, 0.04764873068779707, 0.04725421611510683, 0.0391052490886068, 0.032517764484509826, 0.011079993928433396, 0.020929902202624362, 0.041216692625312135, 0.028920357617607806, 0.0379660969338147, 0.014601624734496, 0.02815470055793412, 0.03993435049778782, 0.04836594591324683, 0.03883995726937428, 0.019289605552330613, 0.09357319999253377, 0.037971740966895595, 0.02700693021324696, 0.05908208338951226, 0.045495233352994546, 0.012164028630650137, 0.04943690211803187, 0.08803245902527124, 0.03530713394866325, 0.014161058043100638, 0.09115509732509963, 0.06785126694012433, 0.06270476966165006, 0.05917490751016885, 0.028798263192584272, 0.01380964462441625, 0.02043322914687451, 0.036187640216667205, 0.042367240457679145, 0.05724275943066459, 0.016435830657428596, 0.05450538854347542, 0.021567358817264903, 0.040500512695871294, 0.06522004914586432, 0.029215637769084424, 0.061098283404135145, 0.018428842267894652, 0.020654454092436936, 0.06072722440876532, 0.022973574668867514, 0.05519601261767093, 0.033746838962542824, 0.03548604348907247, 0.03576792230887804, 0.03784202097449452, 0.05902873039303813, 0.021575440805463586, 0.038268321732175536, 0.03127189149381593, 0.041534305855748244, 0.03269945707870647, 0.026197297192993574, 0.024167172632587608, 0.030944737954996526, 0.03320088915643282, 0.08661393279908225, 0.041479086357867345, 0.03413213235035073, 0.041974332634708844, 0.017161851465061773, 0.020773618889506906, 0.09877532123937272, 0.01490312130044913, 0.03504141539451666, 0.06263485935050994, 0.06593082624021918, 0.02569261079770513, 0.1306733998353593, 0.08468289423035458, 0.051198107612435706, 0.04270736302714795, 0.018501181257306598, 0.024161990586435422, 0.05454930884297937, 0.01954321411176352, 0.04140731325605884, 0.058960018650395796, 0.016563459648750722, 0.030227808456402272, 0.038854432859807275, 0.06930318981176242, 0.03572758287191391, 0.01906673303892603, 0.036566614217008464, 0.021840584195160773, 0.0394020153908059, 0.06352542914100923, 0.0644077907782048, 0.07721291069174185, 0.04127711828914471, 0.07183427704148926, 0.019655157811939716, 0.04636393947293982, 0.03828431130386889, 0.022278698088484816, 0.10124238338903524, 1.3239032286219299, 6.621297178789973, 13.142548575997353, 26.316154785454273, 37.991007417440414, 50.2484542876482, 53.43778274953365, 53.12803477048874, 38.46800722181797, 32.207797542214394, 26.64314243942499, 36.49680219590664, 20.440110191702843, 28.501069843769073, 30.89733526110649, 20.896648094058037, 28.790173530578613, 19.077533707022667, 19.558977372944355, 14.02568293735385, 10.643712412565947, 8.467756323516369, 4.639043295755982, 3.278727689757943, 1.188604363705963, 0.7458756328560412, 0.3958749887533486, 0.13585909735411406, 0.11839973929454572, 0.08796518333838321, 0.12891027959994972, 0.11572664952836931, 0.13960148091427982, 0.26180719840340316, 0.02989450622408185, 0.1179133282857947, 0.1064042653888464, 0.13762245507678017, 0.16186666820431128, 0.0934260395297315, 0.19641531980596483, 0.07465348084224388, 0.04051337411510758, 0.03279449279943947, 0.044455035458668135, 0.09372867250931449, 0.09093519896850921, 0.17614751908695325, 0.1410669257165864, 0.2589743316639215, 0.6004422367550433, 1.068579729180783, 2.059910078532994, 3.02262713201344, 4.540510307997465, 6.9230247382074594, 8.129862304776907, 12.034965008497238, 15.678892526775599, 15.688327420502901, 21.535395719110966, 28.39447796344757, 27.426652796566486, 18.060161098837852, 21.151528917253017, 29.117068089544773, 37.712383568286896, 35.30436538159847, 41.94084607064724, 30.54831638932228, 13.774409070611, 6.973413359373808, 1.5094439475797117, 0.21618651982862502, 0.11676607929985039, 0.05511084003956057, 0.054381824666052125, 0.039588617291883565, 0.030667571772937663, 0.01566394326800946, 0.025179799740726594, 0.06506648394861259, 0.015343912491516676, 0.0416809393937001, 0.05582544661592692, 0.05617831557174213, 0.0636203795147594, 0.04019883708679117, 0.05836226693645585, 0.05141675173945259, 0.0811245855584275, 0.08582932685385458, 0.07796518868417479, 0.017465998425905127, 0.027607377778622322, 0.08647781549370848, 0.050753442410496064, 0.0587523545982549, 0.0673306874523405, 0.12736250093439594, 0.04280004613974597, 0.0332185782463057, 0.028795558064302895, 0.03781053907005116, 0.04002593894256279, 0.01018983602989465, 0.03303828831121791, 0.03177057020366192, 0.010298842680640519, 0.007608223850184004, 0.015134896802919684, 0.052664135000668466, 0.06365955006913282, 0.08321657369378954, 0.05267332278890535, 0.03542247854056768, 0.10694099401007406, 0.04669874826504383, 0.05582579913607333, 0.03992778620158788, 0.06491392065072432, 0.03051757073990302, 0.11889308196259663, 0.13482743786880746, 0.08095276352833025, 0.1435223955195397, 0.08932610406191088, 0.14974399760831147, 0.15164817043114454, 0.12836607755161822, 0.16615597007330507, 0.1965464573004283, 0.11306596104986966, 0.12226003527757712, 0.1247261994285509, 0.19044695334741846, 0.18601045390823856, 0.1467747538117692, 0.1244300305552315, 0.07522080821217969, 0.09525268018478528, 0.157218404347077, 0.11769974560593255, 0.1377251831581816, 0.1294501475058496, 0.16684159578289837, 0.08120231068460271, 0.32258232473395765, 0.1701176434289664, 0.18783874955261126, 0.12340105764451437, 0.10822513213497587, 0.06954171607503667, 0.1758586455252953, 0.1487794579588808, 0.28965931793209165, 0.14640155743109062, 0.15111872227862477, 0.17573901131981984, 0.15369452390586957, 0.1890758058289066, 0.17896270786877722, 0.08213800305384211, 0.10609037402900867, 0.09861121012363583, 0.1635058646206744, 0.23819600755814463, 0.136532626056578, 0.13233073434093967, 0.11698584406985901, 0.19285957154352218, 0.13160025322576985, 0.17690848762867972, 0.1794759920448996, 0.13044383871601894, 0.2343870236654766, 1.2610442703589797, 7.164668021723628, 14.312873426824808, 28.091417625546455, 42.258296236395836, 56.96778193116188, 60.75196847319603, 63.57810102403164, 47.79698923230171, 47.16958969831467, 39.85057443380356, 49.78864096105099, 26.4045874401927, 43.37594546377659, 40.81462450325489, 25.667149610817432, 32.81693525612354, 20.680012218654156, 26.352043859660625, 16.293861977756023, 12.386783380061388, 9.466821514070034, 4.762112041935325, 3.4352011559531093, 2.0354507910087705, 1.3314737286418676, 0.7268306391779333, 0.3294799936702475, 0.34002059837803245, 0.2126847702311352, 0.4875071014976129, 0.6248849001713097, 0.7571457687299699, 0.8439497358631343, 0.9257740108296275, 0.9626047220081091, 0.8081131463404745, 0.5719859199598432, 1.02505745831877, 0.9904387628193945, 0.6569452641997486, 0.5178485030774027, 0.4794102406594902, 0.24497235019225627, 0.43071122257970273, 0.2913919655838981, 0.40434556547552347, 0.4724507953505963, 0.5577035550959408, 0.44475233007688075, 0.9306086576543748, 1.357752881012857, 2.8061869461089373, 4.008188797160983, 5.8942945394665, 8.377892095595598, 10.919170081615448, 15.698014050722122, 22.359725385904312, 17.96847201883793, 26.410224437713623, 34.349571615457535, 39.927550703287125, 30.291919447481632, 34.01900835335255, 36.64146423339844, 42.874585166573524, 42.6352322101593, 46.982392743229866, 36.11409053206444, 16.92791685461998, 7.753346208482981, 1.6037394502200186, 0.519165073055774, 0.1883243813063018, 0.2000176304136403, 0.09688976890174672, 0.09261484243324958, 0.18857448507333174, 0.09777791929082014, 0.10145178035600111, 0.24423714901786298, 0.11835310273454525, 0.08696204458829015, 0.10496452858205885, 0.12653321027755737, 0.16896449436899275, 0.08552073442842811, 0.1267382359947078, 0.18528067041188478, 0.1908122978056781, 0.1159400912001729, 0.14705117413541302, 0.10588808683678508, 0.13331010210094973, 0.15703479701187462, 0.2605981507804245, 0.3018273337511346, 0.25953595933970064, 0.25801396288443357, 0.13666542596183717, 0.2161745267221704, 0.13807277544401586, 0.15147526486543939, 0.10160675563383847, 0.10060193220851943, 0.1695587468566373, 0.1432882182416506, 0.1632692085695453, 0.12655081402044743, 0.13870895927539095, 0.07599429678521119, 0.14960233645979315, 0.2232620815630071, 0.14468738925643265, 0.21403084800112993, 0.1525650345138274, 0.14498329837806523, 0.13874864933313802, 0.11194570397492498, 0.14881349285133183, 0.10251416475512087], [0.08062854889431037, 0.04741538090456743, 0.04851128440350294, 0.06533527499414049, 0.03254549112170935, 0.028952924913028255, 0.05968533812847454, 0.08110295195365325, 0.01652850078244228, 0.06603135756449774, 0.036132142413407564, 0.05680800190020818, 0.030941038348828442, 0.019904217006114777, 0.02251035206427332, 0.05973798979539424, 0.0747705991670955, 0.05403864444815554, 0.033604610071051866, 0.04604034453222994, 0.052151051204418764, 0.016232673297054134, 0.01592689732206054, 0.016987929157039616, 0.05569599008595105, 0.05633573993691243, 0.036838648447883315, 0.04738038493087515, 0.023137882453738712, 0.05635701360006351, 0.012593072551680962, 0.03264466431573965, 0.014753812320122961, 0.05016473376599606, 0.010330134409741731, 0.03115202722256072, 0.019341079059813637, 0.024828058849379886, 0.09028450615005568, 0.0227828223069082, 0.06890979217132553, 0.020588304614648223, 0.04842055685003288, 0.024942679847299587, 0.06876250554341823, 0.02570290438598022, 0.04621919470082503, 0.060475150239653885, 0.04897833649010863, 0.02415109771391144, 0.04822272625460755, 0.039449175164918415, 0.11402602554881014, 0.04603472276357934, 0.03590462220017798, 0.606053585652262, 3.6004431266337633, 8.489639349281788, 19.68535479158163, 32.23805531859398, 41.64009600877762, 39.92208659648895, 48.93983870744705, 41.35818913578987, 34.551963955163956, 34.993979036808014, 29.41998403519392, 27.09327008575201, 28.995026238262653, 32.44026906788349, 19.390621706843376, 18.73878948390484, 12.938569821417332, 15.944881103932858, 10.780782457441092, 8.868845701217651, 4.370060004293919, 4.204748924821615, 4.369131429120898, 2.0798644702881575, 1.3870219979435205, 1.2394069251604378, 0.28978141606785357, 0.28830068302340806, 0.10729780377005227, 0.16924674797337502, 0.10369832074502483, 0.23624779569217935, 0.09762418339960277, 0.16659667220665142, 0.11373715198715217, 0.1595668712980114, 0.13665724749444053, 0.13836191617883742, 0.14741970982868224, 0.019933400108129717, 0.028805677247873973, 0.13530226395232603, 0.09050753636984155, 0.2595858316635713, 0.2621092228218913, 0.5413458484690636, 0.37752933567389846, 1.2980830203741789, 1.8259841809049249, 1.8141879513859749, 2.5610511749982834, 4.145451681688428, 4.125129422172904, 4.998200973495841, 8.098341096192598, 17.85751797258854, 22.67697036266327, 22.282165847718716, 25.322388410568237, 19.45575401186943, 16.470180116593838, 25.910659544169903, 32.0855201035738, 30.304641164839268, 32.816817462444305, 34.295401722192764, 24.353176318109035, 15.68951390683651, 4.916290668770671, 1.114899362437427, 0.04975299023499247, 0.051993971937918104, 0.030610712128691375, 0.017805540264816955, 0.009651874515839154, 0.02075470154522918, 0.019134005015075672, 0.024312832101713866, 0.030902917933417484, 0.03157312923576683, 0.037216694763628766, 0.05851419940881897, 0.049310562608297914, 0.03416028572246432, 0.09390454666572623, 0.009246111767424736, 0.01218336436068057, 0.058872998124570586, 0.03535797477525193, 0.0752851672586985, 0.05327712671714835, 0.038684521859977394, 0.08343113600858487, 0.08340969536220655, 0.05179135077924002, 0.019469251674308907, 0.03640908224042505, 0.06933217067853548, 0.03847043451969512, 0.017106702471210156, 0.020429783726285677, 0.13119291805196553, 0.06541980561451055, 0.051900101389037445, 0.026463652138772886, 0.039162498360383324, 0.013482179383572657, 0.036367982102092355, 0.027053661397076212, 0.06292837133514695, 0.04617238744685892, 0.04585592825606, 0.04612187316524796, 0.05244546118774451, 0.05402010188845452, 0.04961935912433546, 0.052526733779814094, 0.02486307523213327, 0.09958577618817799, 0.01485473419961636, 0.05590412169112824, 0.042441637051524594, 0.030304019601317123, 0.021029789713793434, 0.020861203447566368, 0.020280790158722084, 0.058500150553300045, 0.04537093103863299, 0.08209575258661062, 0.03280694974819198, 0.06104896398028359, 0.017644969193497673, 0.04353643103968352, 0.015747742872918025, 0.04505598953983281, 0.08459736171062104, 0.049204160895897076, 0.07412447055685334, 0.05182151166081894, 0.02219278150732862, 0.05599157637334429, 0.01618879567104159, 0.018480996695871, 0.070438386319438, 0.03275263195973821, 0.03887657854647841, 0.02501368297089357, 0.03278971336840186, 0.02970572983031161, 0.08407447414356284, 0.11466437645140104, 0.03385263211384881, 0.03460075407929253, 0.04615403784555383, 0.07863541482947767, 0.02478965456248261, 0.04016349972516764, 0.017558067411300726, 0.0562558737146901, 0.047034840972628444, 0.02295031947141979, 0.06034382349753287, 0.04154569411184639, 0.021866004608455114, 0.027807037768070586, 0.021105626074131578, 0.017146533537015785, 0.03253937582485378, 0.05482561042299494, 0.05152826684934553, 0.01722035311104264, 0.062417476874543354, 0.06822044088039547, 0.03735998492629733, 0.03178152059263084, 1.1035259789787233, 5.263331271708012, 11.652726419270039, 24.457452222704887, 38.376967906951904, 50.1596150547266, 45.325639843940735, 50.492036417126656, 45.30118815600872, 38.57983522117138, 42.059342712163925, 26.071628406643867, 30.33026698976755, 32.47493080794811, 33.67860361933708, 23.304415494203568, 20.091957673430443, 18.49684126675129, 20.960813350975513, 15.789971966296434, 12.07630394026637, 7.835924327373505, 6.666619721800089, 5.4608503729105, 2.7752340445294976, 1.675707707181573, 0.9087766916491091, 0.5309340509120375, 0.24702533846721053, 0.030110884945315775, 0.0691344180086162, 0.08546715136617422, 0.09812165240873583, 0.0902315390703734, 0.04428361418831628, 0.056636532390257344, 0.07017966621788219, 0.009884865285130218, 0.10556897075730376, 0.01851247674494516, 0.04447058716323227, 0.1368367433315143, 0.1401982715469785, 0.1799426693469286, 0.08051041382714175, 0.14683507557492703, 0.39795893942937255, 0.49473223567474633, 1.4045784808695316, 1.8812579149380326, 2.549715908244252, 3.9141949033364654, 7.483027763664722, 8.064710050821304, 9.214647095650434, 12.234936878085136, 16.88987709581852, 24.2828306928277, 18.125392198562622, 23.529967591166496, 21.334052123129368, 20.9306163713336, 27.733300141990185, 37.91466951370239, 35.556820034980774, 38.614029586315155, 39.28867198526859, 28.261986672878265, 20.177498683333397, 6.512125236913562, 1.8858801294118166, 0.03549896428012289, 0.08310745572089218, 0.036905642118654214, 0.018505994084989652, 0.0758069267612882, 0.03470973104413133, 0.035398395848460495, 0.004564856199067435, 0.05876745730347466, 0.04215914224914741, 0.0684935883327853, 0.02170172650949098, 0.009462641701247776, 0.030951886692491826, 0.06950503171538003, 0.016646227668388747, 0.0860110936628189, 0.05678393034031615, 0.054587573977187276, 0.05123558978084475, 0.06456302580772899, 0.03824579012871254, 0.04068904047016986, 0.04373422452772502, 0.05272046029858757, 0.027541751514945645, 0.04448263964150101, 0.050775109411915764, 0.030883822473697364, 0.02989359709317796, 0.010605414609017316, 0.023715091519989073, 0.026617887124302797, 0.030862020030326676, 0.033032714782166295, 0.008329882221005391, 0.03452981589362025, 0.05055393085058313, 0.04911878793791402, 0.09205843205563724, 0.06570890182047151, 0.0026473820025785244, 0.021758291150035802, 0.03742687840713188, 0.01581833595992066, 0.03529194960719906, 0.02665935091499705, 0.03356689412612468, 0.12017189888865687, 0.03702164351125248, 0.1524266685009934, 0.1628402917413041, 0.21098554891068488, 0.23175927170086652, 0.10593675688141957, 0.11547157337190583, 0.14008035912411287, 0.1338144953479059, 0.17563365603564307, 0.1643876251182519, 0.1661463815253228, 0.16396617429563776, 0.12352720048511401, 0.10623829148244113, 0.16150077455677092, 0.276189396972768, 0.20194213808281347, 0.19875357480486855, 0.13185521063860506, 0.10095715377246961, 0.13112922693835571, 0.11282088904408738, 0.11812457320047542, 0.1671650682692416, 0.18434268480632454, 0.1353284320794046, 0.21230436017503962, 0.11722841503797099, 0.1399030748871155, 0.3134361858246848, 0.2514973422512412, 0.1319346352829598, 0.11934435227885842, 0.17116465052822605, 0.1683139574015513, 0.1430613436968997, 0.13204107410274446, 0.11003223204170354, 0.11626921143033542, 0.12870227044913918, 0.29135853925254196, 0.21735813352279365, 0.1492319899261929, 0.18997436854988337, 0.11334359107422642, 0.1544285228010267, 0.10101469248184003, 0.17877101112389937, 0.19281277171103284, 0.11350543121807277, 0.14672041375888512, 0.13067670981399715, 0.19435859110672027, 0.09516041638562456, 0.09999095171224326, 1.3004358066245914, 5.114636700600386, 12.10662916302681, 26.776454485952854, 42.9830389469862, 55.138810873031616, 52.375549748539925, 59.469639882445335, 54.35328282415867, 44.87881422042847, 47.597268149256706, 38.190766498446465, 38.29432614147663, 42.81294107437134, 42.002189978957176, 30.542514100670815, 32.00399927794933, 24.28853988647461, 28.4513134136796, 18.860466554760933, 15.09123696014285, 8.983941525220871, 8.588226959109306, 6.683843722566962, 3.285119184292853, 2.4321628035977483, 1.6758955596014857, 1.0079734562896192, 0.5242954508867115, 0.3426550148287788, 0.34737465844955295, 0.3935259726131335, 0.4047131957486272, 0.3461295721353963, 0.6868629588279873, 0.44974852760788053, 0.6896490999497473, 0.5337207857519388, 0.4490431013982743, 0.5491822154726833, 0.3351680509513244, 0.3367947199149057, 0.3010598343098536, 0.36648552515544, 0.5078519519884139, 0.5529688904061913, 0.8745812578126788, 0.9306426183320582, 1.8810157966800034, 2.843729881569743, 3.552077659405768, 5.171200940385461, 8.486976642161608, 9.66346476227045, 10.81168619915843, 17.34599892050028, 26.30582883954048, 33.92514958977699, 32.70034611225128, 35.25617636740208, 30.670755319297314, 26.813751384615898, 38.27711686491966, 44.374041706323624, 44.498640820384026, 45.836685821413994, 44.366848692297935, 32.93521910905838, 21.139867343008518, 7.499104700982571, 1.5858775586821139, 0.13371437962632626, 0.16886339901247993, 0.13874860480427742, 0.13644953520270064, 0.1387819420779124, 0.1534385868581012, 0.1934152323519811, 0.06109840214776341, 0.11796107064583339, 0.17539986467454582, 0.11815860809292644, 0.07806953464751132, 0.11542982014361769, 0.09630149812437594, 0.16501019796123728, 0.09943621116690338, 0.14356257539475337, 0.18292970984475687, 0.11431352613726631, 0.1964892674004659, 0.10393280230346136, 0.1355268229963258, 0.15170613216469064, 0.23319350177189335, 0.13076005299808457, 0.20654379506595433, 0.16867140540853143, 0.09243345411960036, 0.116502705932362, 0.14190084737492725, 0.10968725211569108, 0.2567877568071708, 0.1335894168005325, 0.15416494163218886, 0.10457495300215669, 0.1202168433519546, 0.22615099529502913, 0.18095835781423375, 0.12823416822357103, 0.21790018334286287, 0.10032897771452554, 0.05684603325789794, 0.15569384006084874, 0.1612428337102756, 0.10686666049878113, 0.18807101208949462, 0.12366560360533185, 0.18950773577671498, 0.23332337761530653, 0.06578660468221642], [0.020165543901384808, 0.06478477953351103, 0.028566867113113403, 0.055993420610320754, 0.029861664334021043, 0.07483569293981418, 0.028603352948266547, 0.045761757137370296, 0.0714285449066665, 0.10194104121183045, 0.03924295087927021, 0.06645861940342002, 0.059871732228202745, 0.02916617362643592, 0.066130627237726, 0.05055193818407133, 0.025920173684426118, 0.03130448290903587, 0.026313730886613484, 0.030223819412640296, 0.07970215563545935, 0.011170748384756735, 0.030577532561437692, 0.07540450460510328, 0.016471496419399045, 0.04924488996039145, 0.03209000169590581, 0.03295536444056779, 0.02642644085426582, 0.041793979617068544, 0.07317518946365453, 0.12642188812606037, 0.03777835954679176, 0.04822050723305438, 0.03523653344018385, 0.0385716040909756, 0.08139100173139013, 0.07132273691240698, 0.06484507903223857, 0.06652363153989427, 0.02481595813151216, 0.024690820901014376, 0.020041095012857113, 0.08852773127728142, 0.05181224594707601, 0.033303773088846356, 0.05907474725972861, 0.10372416232712567, 0.022448306663136464, 0.06442854122724384, 0.0038327497804857558, 0.07344928686507046, 0.10640548993251286, 0.039387803262798116, 0.07718267559539527, 0.02796170134388376, 0.32482280919793993, 2.1811430482193828, 5.372363571077585, 18.924154937267303, 27.87458796054125, 41.167161986231804, 42.737545520067215, 43.85804459452629, 36.508604362607, 45.45949146151543, 37.676684483885765, 18.858785144984722, 23.579387739300728, 26.003935039043427, 24.425583332777023, 26.36854637414217, 23.31439185887575, 19.309591054916382, 21.763847060501575, 15.389181822538376, 11.958016287535429, 10.463230647146702, 6.343703074380755, 6.344542829319835, 3.3593873865902424, 2.4810424307361245, 2.1149121271446347, 0.7793235161807388, 1.2155483616515994, 0.6912656163331121, 0.6355779420118779, 0.4178551468066871, 0.22376601467840374, 0.17664582672296092, 0.1997103070607409, 0.18763511907309294, 0.16304980003042147, 0.18545641098171473, 0.05401544491178356, 0.09972618310712278, 0.4299071797868237, 0.3278030367800966, 0.49391492328140885, 0.9449533629231155, 0.9915963944513351, 1.9601537939161062, 2.4029696825891733, 3.7098893662914634, 5.7154371868819, 4.858104391023517, 5.573285389691591, 9.78818641975522, 10.631952993571758, 13.510702271014452, 21.713837943971157, 28.93968030810356, 17.04546544700861, 23.800214789807796, 20.944761112332344, 26.313190944492817, 28.178934529423714, 27.470162361860275, 36.00722886621952, 32.784583792090416, 30.04415564239025, 26.280326507985592, 18.521836325526237, 5.357479769736528, 1.5750613203272223, 0.09699168062070385, 0.04652305222407449, 0.07724192124442197, 0.08394729229621589, 0.07909576903330162, 0.04266966934665106, 0.03496678873489145, 0.03511765622533858, 0.05100010632304475, 0.0720035980339162, 0.039196455327328295, 0.029605461968458258, 0.031505764491157606, 0.046929574746172875, 0.05247502092970535, 0.022412318066926673, 0.02926501470938092, 0.09432275430299342, 0.050154076525359415, 0.02472409509209683, 0.057073082207352854, 0.029318072702153586, 0.021996626310283318, 0.08579571498557925, 0.01876645823358558, 0.017034619522746652, 0.10793287437991239, 0.03175622448907234, 0.02363531992159551, 0.03101091155258473, 0.03480216553725768, 0.056343914693570696, 0.04138717136811465, 0.04552480051643215, 0.035910028746002354, 0.049941488323383965, 0.04590773387462832, 0.016263472425634973, 0.06404645391739905, 0.09104102922719903, 0.016722229156584945, 0.018886634206864983, 0.030759004366700538, 0.04393499402794987, 0.06436803392716683, 0.03173468736349605, 0.04431925954122562, 0.046306155854836106, 0.06307904215645976, 0.025109536909440067, 0.06721253754221834, 0.06743426900357008, 0.06183095756568946, 0.011194512881047558, 0.043125270094606094, 0.05852948022948112, 0.023868458192737307, 0.053375171846710145, 0.03658051835373044, 0.03828093824267853, 0.06512888372526504, 0.01613493986951653, 0.00774715343140997, 0.11559332269825973, 0.059101583319716156, 0.05955212262051646, 0.07362813703366555, 0.05566477164393291, 0.009399784576089587, 0.05095565538795199, 0.05565668594499584, 0.032744457203079946, 0.06980044359806925, 0.051960107739432715, 0.009171199380944017, 0.06126253923866898, 0.04810022364836186, 0.047448358236579224, 0.011473669874249026, 0.042007911106338724, 0.030855019722366706, 0.07477351580746472, 0.2199953849776648, 0.030639680007880088, 0.03361620241776109, 0.08669933915371075, 0.023253045219462365, 0.08335908089065924, 0.03890904008585494, 0.03785080429224763, 0.034721761257969774, 0.05728275376895908, 0.0879060044826474, 0.018034479835478123, 0.020122126406931784, 0.012876794680778403, 0.03151469994918443, 0.021263942871883046, 0.02583572470030049, 0.030537827660737094, 0.034544428781373426, 0.02191015682910802, 0.04526986165728886, 0.0660181102284696, 0.016200471509364434, 0.02970671503135236, 0.03880092772305943, 0.8622795366682112, 3.254729602485895, 7.989485487341881, 22.359812781214714, 32.27490574121475, 47.037299796938896, 50.71620158851147, 46.55927024781704, 39.08379077911377, 46.809764206409454, 42.34086960554123, 22.565790228545666, 28.06074757128954, 27.38037697970867, 24.78184651583433, 29.756820760667324, 26.67255286127329, 26.36860717087984, 25.40460079908371, 19.924067482352257, 12.798619531095028, 11.27171516418457, 9.731241725385189, 8.394320514053106, 4.639445124194026, 3.099615750834346, 2.3870741855353117, 1.7293952638283372, 0.8144528686534613, 0.5763258214574307, 0.6115165643859655, 0.3033912170212716, 0.4202610411448404, 0.3860441147116944, 0.20895890687825158, 0.22269617911661044, 0.022539600104209967, 0.24057131056906655, 0.26578484277706593, 0.2527613681741059, 0.42610174336005, 0.3817886399338022, 0.4065661010099575, 1.0612886329181492, 1.5125025459565222, 2.3601483553647995, 3.039124421775341, 4.075559182092547, 7.255370579659939, 7.194177713245153, 8.766912370920181, 11.79547430947423, 13.436904530972242, 13.624725602567196, 20.25837354362011, 31.98358677327633, 22.15007733553648, 26.508437767624855, 25.49076307564974, 27.72503938525915, 28.219455555081367, 32.13229939341545, 39.71176788210869, 38.74153174459934, 34.32969868183136, 30.144760943949223, 21.701125726103783, 7.540695369243622, 1.9362022541463375, 0.16854690271429718, 0.0321293986053206, 0.05968979843601119, 0.060308764441288076, 0.052920294692739844, 0.04056639314512722, 0.0902886844414752, 0.0368040161265526, 0.013393752487900201, 0.043609847998595797, 0.0953596830368042, 0.05097931876662187, 0.014969988806114998, 0.025384333785041235, 0.0449231562379282, 0.06687504588626325, 0.06031207441992592, 0.04870350436249282, 0.030687301768921316, 0.03742352389963344, 0.06276854241150431, 0.02677821699762717, 0.08569812256610021, 0.03592839319026098, 0.02991512494190829, 0.10543642318225466, 0.04689970701292623, 0.03712624551553745, 0.07900645898189396, 0.0463411926466506, 0.030078245290496852, 0.08184014950529672, 0.017949203356693033, 0.0747285268153064, 0.022920928568055388, 0.05111275691888295, 0.02166254667827161, 0.01403990985636483, 0.07459501444827765, 0.03122313239146024, 0.05705430216039531, 0.026386325916973874, 0.03773517397348769, 0.027211250890104566, 0.02281469012814341, 0.06011253317410592, 0.018305009361938573, 0.03672570841445122, 0.08843612798955292, 0.07103228257619776, 0.05525120985112153, 0.12186956169898622, 0.14970117568736896, 0.06837687076767907, 0.1774250520975329, 0.16414898011134937, 0.1908901787828654, 0.12772536661941558, 0.12105809000786394, 0.15235536295222118, 0.27908926480449736, 0.08482782082865015, 0.22030805179383606, 0.2503800834529102, 0.214942843595054, 0.22588961088331416, 0.15653825568733737, 0.2862407185602933, 0.09276950600906275, 0.06766909194993787, 0.10215051981504075, 0.22409564699046314, 0.0963180628605187, 0.18376570951659232, 0.14515351736918092, 0.1633772801142186, 0.11786832445068285, 0.11249835908529349, 0.11057749536121264, 0.1456142871757038, 0.1625473512103781, 0.16567057580687106, 0.3032639832235873, 0.2293855420430191, 0.1017756832879968, 0.17393330665072426, 0.15571372961858287, 0.2536206564400345, 0.2750162989832461, 0.17483265604823828, 0.10923034889856353, 0.1419535101740621, 0.1549728139070794, 0.13125358120305464, 0.16961402201559395, 0.161629032518249, 0.1766771453549154, 0.14924904447980225, 0.20597349910531193, 0.11035534829716198, 0.11108628212241456, 0.09503334586042911, 0.18137669161660597, 0.23669424204854295, 0.13613734336104244, 0.12223551471834071, 0.11122063311631791, 0.7194649719167501, 3.552620317786932, 8.598007634282112, 23.32885768264532, 36.926870718598366, 54.196963012218475, 57.80203476548195, 54.92555491626263, 47.695641070604324, 56.710220351815224, 49.24153111875057, 29.993308670818806, 36.75403319299221, 37.04844519495964, 34.00250963866711, 38.303058072924614, 36.62679702043533, 29.494127556681633, 34.09970462322235, 25.937877483665943, 20.288448929786682, 16.835369020700455, 11.98012825101614, 9.395510740578175, 5.5144027993083, 4.008806264027953, 2.9577420512214303, 1.5905367024242878, 1.5970319788902998, 1.216566707007587, 1.1061072279699147, 0.683041907614097, 0.5488077574409544, 0.6807986029889435, 0.6042264180723578, 0.5035514140035957, 0.3451339958701283, 0.36030913470312953, 0.7522753207013011, 0.591119258897379, 0.8381616964470595, 0.5377173994202167, 0.732363557908684, 1.3645500037819147, 1.7938878969289362, 3.1150994449853897, 3.9245301112532616, 5.947370566427708, 8.529980834573507, 7.937319511547685, 10.418154615908861, 17.788747362792492, 18.275771029293537, 21.41960073262453, 32.30570308864117, 39.21777918934822, 29.07726712524891, 38.272298723459244, 33.47625307738781, 38.94480563700199, 37.628009095788, 39.555242881178856, 46.88919894397259, 45.00212140381336, 39.99464750289917, 34.04696725308895, 23.472214490175247, 8.546029273420572, 2.0433225436136127, 0.27123814390506595, 0.30482555099297315, 0.25943600689060986, 0.1212466845754534, 0.1463238990982063, 0.1454792162985541, 0.15194459905615076, 0.07241568295285106, 0.1367312396178022, 0.12810874526621774, 0.14328171702800319, 0.10624624730553478, 0.14143642620183527, 0.13135256886016577, 0.19463467004243284, 0.08279747547931038, 0.13197275198763236, 0.18566422717412934, 0.11693961569108069, 0.08129804773489013, 0.12890560406958684, 0.1367029341054149, 0.2692890859907493, 0.24544687941670418, 0.09879872115561739, 0.19921274157240987, 0.1203936748788692, 0.1464583317283541, 0.1852344346116297, 0.1331728047807701, 0.11789905678597279, 0.16089415788883343, 0.09333620255347341, 0.13676209811819717, 0.15722356969490647, 0.16674838203471154, 0.14941881818231195, 0.11126594865345396, 0.09876205163891427, 0.1572472442057915, 0.09949555329512805, 0.17641892249230295, 0.10246111603919417, 0.13181117159547284, 0.13864730164641514, 0.1420934940688312, 0.08390471528400667, 0.13510068180039525, 0.15654126880690455, 0.22411859419662505, 0.16105576796690002], [0.04642716303351335, 0.018851805216399953, 0.037914317290415056, 0.057888832379831, 0.06386036038747989, 0.034636106283869594, 0.026936459580610972, 0.029056343191768974, 0.10144133091671392, 0.05163911773706786, 0.03868031388265081, 0.01630910708627198, 0.021980072706355713, 0.01913746713398723, 0.0641287729376927, 0.11030069654225372, 0.09551995724905282, 0.0159891189832706, 0.08933868346503004, 0.030820880929240957, 0.021723486279370263, 0.04206108227663208, 0.01668991975748213, 0.06948707916308194, 0.039332695087068714, 0.011630472690740135, 0.033567094505997375, 0.02229003068350721, 0.07068805964081548, 0.0009230588125319628, 0.048948539260891266, 0.03429709322517738, 0.05064213510195259, 0.016950690041994676, 0.013215291019150754, 0.03407726537261624, 0.04813280022062827, 0.035284832410980016, 0.12414336859364994, 0.06770573178073391, 0.03775795419642236, 0.04851064244576264, 0.04147352396103088, 0.0668855250114575, 0.02636490939039504, 0.040334839359275065, 0.12108569047995843, 0.016225478175329044, 0.03491439681965858, 0.07237566635012627, 0.025552330043865368, 0.02003996694838861, 0.024803903797874227, 0.03927099663997069, 0.013869551712559769, 0.07248381210956722, 0.044866348544019274, 0.20581895427312702, 1.8269341299310327, 3.6484452383592725, 13.284847140312195, 20.68016041070223, 32.2405631840229, 46.69959671795368, 51.75710253417492, 45.78669190406799, 32.37097978591919, 30.915750972926617, 38.15528020262718, 34.45013701915741, 22.090665623545647, 25.47071725130081, 20.827934481203556, 20.581586100161076, 14.154236689209938, 13.54632155969739, 16.24405425041914, 14.451909866183996, 10.841165017336607, 5.898518962785602, 5.504558952525258, 5.081531452015042, 3.9852266293019056, 3.204426714219153, 2.3671421175822616, 2.7856528479605913, 1.6184767219237983, 1.5913505712524056, 1.2439838983118534, 1.2875191122293472, 0.92379390145652, 0.410987994982861, 1.0844629956409335, 0.5500106897670776, 0.5420404393225908, 0.7702542934566736, 0.9390281746163964, 1.60860390169546, 2.057294868864119, 2.1017660200595856, 2.766472427174449, 4.344203341752291, 6.2564540561288595, 7.356104599311948, 7.093549612909555, 7.672886000946164, 14.215654693543911, 21.133221499621868, 21.581270657479763, 30.262816809117794, 27.648845873773098, 15.074577704071999, 18.489144779741764, 14.398295693099499, 21.70522380620241, 24.61560733616352, 23.330586589872837, 36.37356720864773, 30.365126319229603, 27.554876916110516, 18.775550611317158, 14.195914752781391, 5.877914093434811, 2.0422132406383753, 0.14014946791576222, 0.026467919487913605, 0.03897089438396506, 0.01023351791445748, 0.019949224551965017, 0.036048862311872654, 0.024839541729306802, 0.03325786012283061, 0.07379791073617525, 0.01716911338007776, 0.03550942114088684, 0.05336896749213338, 0.05233810581557918, 0.056744589091977105, 0.0313640773674706, 0.0013076599157102464, 0.05813225681777112, 0.021808430647070054, 0.013744382940785727, 0.042774145185831, 0.08510987405315973, 0.025590322438802104, 0.0759644401841797, 0.012366082974040182, 0.02625656510645058, 0.0325137420441024, 0.07214378973003477, 0.07145439391024411, 0.040035575730144046, 0.004133856255066348, 0.03792343457462266, 0.02531191501475405, 0.02208288056863239, 0.019780447182711214, 0.014674029589514248, 0.08433861934463494, 0.04906470021524001, 0.08789298721239902, 0.03862046709400602, 0.019726869686564896, 0.05034879010054283, 0.004545558504105429, 0.08887214717105962, 0.031188455541268922, 0.032960051103145815, 0.015830802185519133, 0.020216403281665407, 0.052086718133068644, 0.015145546622079564, 0.08938298968132585, 0.04155552385782357, 0.0014325775168799737, 0.040285356662934646, 0.04397876218718011, 0.04254104773281142, 0.025171391207550187, 0.03008915671671275, 0.030358086914930027, 0.043263554471195675, 0.02613159485918004, 0.06951232702704147, 0.05839626472152304, 0.017898974801937584, 0.04155527152761351, 0.04173376546532381, 0.06558904497069307, 0.040251318059745245, 0.027566778589971364, 0.015130997744563501, 0.07238593767397106, 0.06168263564177323, 0.06392630020854995, 0.03143501184240449, 0.050767342836479656, 0.034340961574343964, 0.025001823451020755, 0.03306697231892031, 0.047308548746514134, 0.02572055636846926, 0.041675113534438424, 0.016828335865284316, 0.08325451228301972, 0.0368199277727399, 0.05836051917867735, 0.06979736368521117, 0.03431335368077271, 0.03896648602676578, 0.007305064409592887, 0.041541066821082495, 0.07462628855137154, 0.09875425908830948, 0.04410216279211454, 0.04371228293166496, 0.07620759744895622, 0.04587437062582467, 0.04184788551356178, 0.016624710951873567, 0.04767471327795647, 0.0926948014239315, 0.056214454452856444, 0.03503447260300163, 0.08486474267556332, 0.02932901195890736, 0.0373139123985311, 0.03720308748597745, 0.062467764801112935, 0.015578451566398144, 0.029586238488263916, 0.11174961371580139, 0.4404463298851624, 2.605618271045387, 6.168141094967723, 17.723596058785915, 27.41477083414793, 39.579930156469345, 53.61085966229439, 56.3057928532362, 51.85827970504761, 37.674841582775116, 33.752285465598106, 39.33701679110527, 35.51685377955437, 23.268851302564144, 25.66160760819912, 27.419750466942787, 22.256522923707962, 21.412968188524246, 18.436238318681717, 23.123820684850216, 20.214888677001, 14.214334264397621, 8.765975721180439, 8.888774681836367, 8.395093772560358, 6.075140610337257, 3.764912076294422, 3.4741778019815683, 2.498825239017606, 2.1653582202270627, 1.8988674762658775, 0.93035769299604, 1.1879231315106153, 0.7807892875280231, 0.9075573727022856, 1.0079537448473275, 0.8791129302699119, 0.870229956926778, 0.9094455745071173, 1.3530569267459214, 1.1188504379242659, 2.5378783559426665, 2.145944586955011, 3.38212251663208, 5.6886690482497215, 8.214203529059887, 9.818751979619265, 10.772169269621372, 10.193973295390606, 15.49817992374301, 25.24043820798397, 23.537589982151985, 29.317788518965244, 30.63047558069229, 19.618649370968342, 21.42333973199129, 19.64955311268568, 23.506614044308662, 28.905508741736412, 31.239392906427383, 39.12205472588539, 38.113186061382294, 34.87761028110981, 24.11750916391611, 17.971652448177338, 7.879553586244583, 2.7988982247188687, 0.30964318779297173, 0.03411820223846007, 0.03653503954410553, 0.03961995076679159, 0.046843574673403054, 0.03330474530230276, 0.005599359501502477, 0.01287240858800942, 0.015222591755446047, 0.06343103537801653, 0.08541582443285733, 0.04527421435341239, 0.022312664332275745, 0.013114538905938389, 0.047036228788783774, 0.05059483060904313, 0.04299831089156214, 0.04815693115233444, 0.07200275198556483, 0.04812603925529402, 0.04472034954233095, 0.027260002570983488, 0.039631179461139254, 0.014524797607009532, 0.04874161364568863, 0.04447988627362065, 0.011694469012581976, 0.0541006434650626, 0.07271979280631058, 0.027815609573735856, 0.0095393677111133, 0.023360838458756916, 0.03169736846757587, 0.04160315860644914, 0.022507864014187362, 0.0049922966172744054, 0.05372704632463865, 0.09972169311367907, 0.08827425073832273, 0.03106344633124536, 0.013805960788886296, 0.033531371227581985, 0.06735645481967367, 0.037517520613619126, 0.09914113325066864, 0.015671819310227875, 0.03147892843117006, 0.04281179433746729, 0.022562868289242033, 0.011239451778237708, 0.07910993663244881, 0.01692582809482701, 0.13594968389952555, 0.08682671395945363, 0.1816268399124965, 0.15305664797779173, 0.0902218243572861, 0.08993701034341939, 0.16269015526631847, 0.2078855238505639, 0.23991275840671733, 0.2452333041583188, 0.09123648866079748, 0.13146737910574302, 0.09521894215140492, 0.15300906146876514, 0.1827425105147995, 0.17099716264056042, 0.21174904075451195, 0.16223401646129787, 0.16688164207153022, 0.13140469731297344, 0.11557554826140404, 0.24361230520298705, 0.15662473073462024, 0.17139962932560593, 0.10088282768265344, 0.10420133359730244, 0.14275498513597995, 0.14235296373954043, 0.10543137657805346, 0.163468282262329, 0.13024503219639882, 0.11769688833737746, 0.1319105303264223, 0.09032539848703891, 0.11000768921803683, 0.10910281824180856, 0.20982816960895434, 0.14485679188510403, 0.20788420282769948, 0.1789357085363008, 0.20288589759729803, 0.1360765763092786, 0.11476697836769745, 0.13059106597211212, 0.09874948707874864, 0.16009290557121858, 0.40083778963889927, 0.1288465884863399, 0.12609847501153126, 0.20181900094030425, 0.10061756183858961, 0.07905171514721587, 0.1545017134048976, 0.18733333214186132, 0.16663940506987274, 0.15808791940798983, 0.19202274066628888, 0.5932253552600741, 2.6051124231889844, 6.439224723726511, 20.03908161073923, 30.04078522324562, 45.69397307932377, 61.38077013194561, 63.92393946647644, 59.95627976953983, 47.910553738474846, 43.453959077596664, 52.02026501297951, 46.59357100725174, 32.287479266524315, 37.05127224326134, 32.802667021751404, 33.75046916306019, 25.168152786791325, 25.389452911913395, 27.03986205160618, 25.23953575640917, 19.69717025756836, 12.596379183232784, 12.663166299462318, 10.001256186515093, 7.77135961689055, 5.905025638639927, 3.9264468709006906, 4.376372415572405, 2.5547254644334316, 2.323530907742679, 2.0381175354123116, 1.6180396266281605, 1.446125926449895, 1.2410712358541787, 1.2952328170649707, 1.1073133070021868, 1.013437444344163, 1.252103706356138, 1.5824940777383745, 2.343548946082592, 3.072499455884099, 3.4312446182593703, 4.442456569522619, 6.93855307996273, 9.784661158919334, 10.975317768752575, 12.181886974722147, 13.49086258560419, 22.454216815531254, 31.574848406016827, 31.313477531075478, 40.092982426285744, 39.16335850954056, 24.766896218061447, 31.204216293990612, 24.672754369676113, 32.184200808405876, 38.01606327295303, 34.348294883966446, 49.63997393846512, 42.21340164542198, 39.721411764621735, 27.03597106039524, 19.039953723549843, 8.8478347286582, 3.3547851210460067, 0.4462246916955337, 0.14424627152038738, 0.09882511934847571, 0.1530826379894279, 0.1611752834287472, 0.10312539016013034, 0.07481460852432065, 0.11315514493617229, 0.13646805920870975, 0.0888445318560116, 0.1607251411769539, 0.1315860782051459, 0.09590417452272959, 0.17338319710688666, 0.13251468306407332, 0.1433547295164317, 0.20461682346649468, 0.1549038090161048, 0.1966300528147258, 0.119377511437051, 0.1364863308845088, 0.07599235235829838, 0.20058719906955957, 0.09874853712972254, 0.11254515891778283, 0.13726546720135957, 0.1715804758714512, 0.1423369036638178, 0.14259358285926282, 0.09597513126209378, 0.12513665162259713, 0.12166364540462382, 0.09246716988855042, 0.11773812206229195, 0.09665111647336744, 0.1708701514871791, 0.17906625231262296, 0.22941166564123705, 0.17840725486166775, 0.13099700590828434, 0.137214956630487, 0.07475259466446005, 0.19905721710529178, 0.179843473888468, 0.1960805369890295, 0.07305580016691238, 0.1141798059688881, 0.17522917070891708, 0.06272356084082276, 0.12177199154393747, 0.2403640584088862, 0.13665564445545897], [0.08067658069194295, 0.06358750979416072, 0.00819443748696358, 0.09443743838346563, 0.03225668435334228, 0.0434107705950737, 0.040202662858064286, 0.04646966954169329, 0.012134976332163205, 0.06168063555378467, 0.022385522825061344, 0.07243511980050243, 0.022588739557249937, 0.006164656169858063, 0.09408921527210623, 0.06624055415159091, 0.019003014094778337, 0.08303827271447517, 0.05610651278402656, 0.12117465914343484, 0.034724113866104744, 0.0053390892389870714, 0.05844725026690867, 0.04575606115395203, 0.03124481052509509, 0.022733137375325896, 0.04823009578103665, 0.032345133513445035, 0.04024060886877123, 0.021141861434443854, 0.05866964966116939, 0.014666891056549503, 0.02949931258626748, 0.06207024824107066, 0.08126122978865169, 0.06505115859908983, 0.016437767662864644, 0.06688327630399726, 0.0581387246347731, 0.04747749866510276, 0.023424997125403024, 0.05212828211369924, 0.05469238749356009, 0.03774728953430895, 0.09037639887537807, 0.01005974032523227, 0.07946443831315264, 0.06722388498019427, 0.03531176866090391, 0.03322792559629306, 0.010153576549782883, 0.013743958988925442, 0.05600074560788926, 0.03532194721628912, 0.07151485668146051, 0.06326082380837761, 0.04666738510422874, 0.07222340733278543, 0.12290995626244694, 0.6132509931921959, 3.621839778497815, 11.16848610341549, 15.432923175394535, 29.03934706002474, 37.54476696252823, 46.10820785164833, 39.84411858022213, 38.119995296001434, 47.700607404112816, 30.505787171423435, 30.059157237410545, 35.24761162698269, 27.320114113390446, 23.31938859075308, 21.226732581853867, 18.76436971127987, 15.656761564314365, 16.242598928511143, 17.97761432826519, 18.566406033933163, 12.681324575096369, 9.09374613314867, 9.552177283912897, 9.550913851708174, 4.2626625671982765, 3.145529399625957, 7.175321225076914, 5.25797925889492, 4.7871132753789425, 2.0338833751156926, 2.703235507942736, 2.8799046529456973, 2.5555559573695064, 2.840515491552651, 2.3568916926160455, 2.7013401221483946, 4.123410964384675, 5.8963673282414675, 4.6850749757140875, 6.171970814466476, 8.09348875656724, 11.005537547171116, 8.521119710057974, 9.323758240789175, 16.293985471129417, 17.595548629760742, 15.290482118725777, 15.704437606036663, 22.038294933736324, 23.263949565589428, 17.465544305741787, 22.467293813824654, 18.348647318780422, 24.101848304271698, 27.373803332448006, 30.065519995987415, 30.891800858080387, 30.472301468253136, 24.092780090868473, 16.412561908364296, 10.169495958834887, 4.571030270308256, 1.7159095499664545, 0.2350176710751839, 0.05993892998958472, 0.06907972172484733, 0.0800397215061821, 0.07739488530205563, 0.011045591672882438, 0.019210850696254056, 0.05927523845457472, 0.026448664466443006, 0.032605575397610664, 0.08595066799898632, 0.01874071684142109, 0.00528186965311761, 0.09921965247485787, 0.048487520834896713, 0.033263975419686176, 0.049481104433652945, 0.028559627462527715, 0.04633485099475365, 0.06313382749794982, 0.051642802500282414, 0.06241565861273557, 0.009644802776165307, 0.020011663291370496, 0.032346925800084136, 0.03932096173230093, 0.02386829863098683, 0.003954138237531879, 0.02193144533521263, 0.02879129442590056, 0.024923925775510725, 0.035072129176114686, 0.03356654160597827, 0.08825900702504441, 0.038121910838526674, 0.028471796140365768, 0.07196705468231812, 0.02830166991770966, 0.08675135628436692, 0.02674279243365163, 0.010564390540821478, 0.09432206410565414, 0.04630999275832437, 0.02580721880804049, 0.06253921877942048, 0.01668999026151141, 0.06614725876715966, 0.0659090887347702, 0.029853712221665774, 0.06632708114921115, 0.034688127125264145, 0.07341260992689058, 0.03814807525486685, 0.06952343697776087, 0.06466866310802288, 0.005635054021695396, 0.04297223553294316, 0.02685075636691181, 0.026057452450913843, 0.09692045670817606, 0.02200095488660736, 0.020495298667810857, 0.039747670671204105, 0.0902528980805073, 0.07123937146388926, 0.08155687173712067, 0.01805604850233067, 0.050539110161480494, 0.08160933415638283, 0.02546546165831387, 0.03889410065312404, 0.04127423504542094, 0.04126607884245459, 0.02971495287056314, 0.01571154276462039, 0.06482748271082528, 0.047945741898729466, 0.007577192800454213, 0.07888542953878641, 0.046003827155800536, 0.03751044052478392, 0.027988223846477922, 0.046846294644637965, 0.013982334967295174, 0.03422494904953055, 0.005669970214512432, 0.06924148023244925, 0.028927137136633974, 0.02899674502259586, 0.05981457943562418, 0.08715786767425016, 0.09794232726562768, 0.020675087653216906, 0.01180319550257991, 0.023131529669626616, 0.04597875740728341, 0.04476558344322257, 0.06210501414898317, 0.02517097003874369, 0.04531312886683736, 0.07986231110407971, 0.07793437471264042, 0.02558723139372887, 0.023112877643143293, 0.008234761153289583, 0.020353333238745108, 0.055481476010754704, 0.07139245426515117, 0.1002808271732647, 0.05401031667133793, 0.01601851916348096, 0.23870381468441337, 1.0077780042774975, 5.148536106571555, 14.09133866429329, 20.89853659272194, 36.64984278380871, 46.07093945145607, 50.78615963459015, 46.29566319286823, 43.81378456950188, 52.35139824450016, 38.310357481241226, 33.14663216471672, 38.302210718393326, 29.732443168759346, 26.846650019288063, 22.167102321982384, 23.437193669378757, 21.66209042072296, 22.06508919596672, 20.627761222422123, 21.948743239045143, 17.73895103484392, 12.71115867421031, 12.76488684117794, 13.726792875677347, 8.126853816211224, 5.646243374794722, 8.506431598216295, 7.6979185827076435, 5.654956307262182, 3.0197808472439647, 3.381555159576237, 3.039332698099315, 2.9717340879142284, 3.020858089439571, 3.1574659841135144, 3.511014450341463, 5.629248786717653, 6.528184125199914, 6.400961726903915, 8.038168475031853, 9.303768463432789, 11.51625294238329, 12.903052177280188, 12.853310946375132, 18.99915151298046, 20.527106523513794, 20.76584581285715, 23.397679589688778, 24.364317320287228, 30.19887574017048, 22.721994146704674, 22.444149255752563, 22.702237106859684, 24.490153267979622, 31.066853664815426, 34.523245096206665, 32.933509200811386, 37.5154173374176, 28.34050565958023, 20.422602631151676, 12.778523359447718, 6.288273073732853, 2.4933768063783646, 0.33038360299542546, 0.08014097271370701, 0.08729585519176908, 0.05310634740453679, 0.058539306264719926, 0.01799960260541411, 0.04371486931631807, 0.01959781577170361, 0.03519313635479193, 0.04081967330421321, 0.07949770879349671, 0.07043374789645895, 0.08323013273184188, 0.03304881938674953, 0.022463815694209188, 0.006963579071452841, 0.009304657014581608, 0.023861086810939014, 0.035611087951110676, 0.058298278963775374, 0.03496015022392385, 0.01766836539900396, 0.012236045713507337, 0.03171109448885545, 0.03034598248632392, 0.05880549979337957, 0.06333982542855665, 0.0066539847466629, 0.06040002263034694, 0.044402958956197836, 0.058920358278555796, 0.023516932524216827, 0.08802087410003878, 0.03374712840013672, 0.02095266943797469, 0.06138644450402353, 0.030955846050346736, 0.038587563976761885, 0.08150098059559241, 0.03494144810247235, 0.02291350523591973, 0.018400659209873993, 0.03672947110317182, 0.017313266289420426, 0.06473578294389881, 0.01754710217937827, 0.03430192460655235, 0.042030713593703695, 0.00950408044445794, 0.023791736821294762, 0.0815283584233839, 0.023260667076101527, 0.04995811985281762, 0.20947493700077757, 0.15028543886728585, 0.11770685538067482, 0.14860153547488153, 0.20390639518154785, 0.08262946066679433, 0.22709984594257548, 0.0986766155983787, 0.1283790948218666, 0.11345888371579349, 0.1359350635902956, 0.12367491755867377, 0.20178363018203527, 0.14295523142209277, 0.23355255281785503, 0.14026043383637443, 0.11167302407557145, 0.1380937040084973, 0.15674721478717402, 0.18375701154582202, 0.11406870646169409, 0.05932285464950837, 0.1696481162798591, 0.13553149852668867, 0.12695035664364696, 0.1808813971001655, 0.14941527071641758, 0.06577681575436145, 0.08702339793671854, 0.14877362467814237, 0.11510758704389445, 0.09064250334631652, 0.090193162614014, 0.20607674669008702, 0.2467119591892697, 0.2227909810608253, 0.13150217098882422, 0.3629112825728953, 0.2787658665329218, 0.1604898803634569, 0.08733502574614249, 0.16652927035465837, 0.12704532186035067, 0.1041978677676525, 0.22317918366752565, 0.16935185092734173, 0.22848105698358268, 0.18422955181449652, 0.13393481232924387, 0.07867404361604713, 0.1346558384830132, 0.13742311421083286, 0.15070659283082932, 0.1993655349360779, 0.13674844260094687, 0.10447123044286855, 0.1885987978312187, 0.2461696570389904, 0.23905569658381864, 1.3186977454461157, 5.518060578033328, 16.09282996505499, 22.756021320819855, 40.47593727707863, 50.77491223812103, 59.75180134177208, 55.12354329228401, 52.283271700143814, 60.97391456365585, 44.40398409962654, 41.03275179862976, 49.43940170109272, 38.964917957782745, 34.13116693496704, 34.38449554145336, 29.73751399666071, 26.426873244345188, 27.888896092772484, 29.96212374418974, 30.202732533216476, 21.94406569004059, 15.463130604475737, 15.04695888608694, 15.051362849771976, 9.021644052118063, 5.761866420507431, 11.34502463042736, 7.3323948215693235, 6.610043607652187, 3.4573817532509565, 4.085944499820471, 3.8457088032737374, 4.238958489149809, 4.268984952941537, 4.099993770942092, 4.255404956638813, 6.280913818627596, 7.171244043856859, 7.649371437728405, 9.977711699903011, 12.68427986651659, 15.256045516580343, 15.442844443023205, 15.16198631376028, 25.835756063461304, 25.793401636183262, 25.884611941874027, 25.63059937208891, 31.721395142376423, 37.096983790397644, 28.36586929857731, 35.06867542862892, 29.96804002672434, 34.944338500499725, 37.50484250485897, 42.90707342326641, 41.913548335433006, 43.390658274292946, 34.237219244241714, 22.75794591754675, 14.250669814646244, 6.7796361073851585, 2.6517515955492854, 0.44408261601347476, 0.20436326129129156, 0.1663581607863307, 0.26921267446596175, 0.19072750001214445, 0.11063169440603815, 0.14944127557100728, 0.14239713636925444, 0.16723258886486292, 0.10879490117076784, 0.2406886441167444, 0.10492902423720807, 0.10912186917266808, 0.10992773022735491, 0.15575337514746934, 0.10027247059042566, 0.2390788367483765, 0.18304503959370777, 0.18362709117354825, 0.1298438716912642, 0.15867277630604804, 0.1576187930186279, 0.14865881443256512, 0.13076161150820553, 0.08803820324828848, 0.12959571235114709, 0.24050332984188572, 0.10321605834178627, 0.18264609068864956, 0.18969503900734708, 0.1997050823410973, 0.10104239685460925, 0.13820242864312604, 0.19536396372132003, 0.07492866920074448, 0.17541164997965097, 0.16309737169649452, 0.12675183214014396, 0.17572075448697433, 0.13237443199614063, 0.1258860426605679, 0.13578028127085418, 0.13345798244699836, 0.1556869232445024, 0.1667441666359082, 0.1407331373775378, 0.12877158704213798, 0.23384688858641312, 0.16116864862851799, 0.22266428160946816, 0.2846502960892394, 0.20056940236827359, 0.14579599461285397], [0.02429524505714653, 0.04293282006983645, 0.012748622993967729, 0.023742556550132576, 0.0914758832368534, 0.006743589801772032, 0.05040703013946768, 0.020469765076995827, 0.08293777849758044, 0.02703918766201241, 0.03961714915931225, 0.04077127043274231, 0.029553966196544934, 0.006962330407986883, 0.03025851481652353, 0.02380575784627581, 0.05937597758020274, 0.033847184749902226, 0.03512237628456205, 0.03576710223569535, 0.04951748451276217, 0.03188843067619018, 0.06253437997656874, 0.013434770989988465, 0.07120429756469093, 0.07796088422765024, 0.051947164683951996, 0.007926748530735495, 0.03973892075009644, 0.045776548140565865, 0.035165380031685345, 0.046582468567066826, 0.032939404554781504, 0.013196782783779781, 0.043445454866741784, 0.05737789710110519, 0.05046131082053762, 0.04903003449726384, 0.04843298040213995, 0.04037422142573632, 0.07066713849781081, 0.08394159260205925, 0.016255739246844314, 0.013824792786181206, 0.06624034635024145, 0.05707821786927525, 0.062158196451491676, 0.07941936768474989, 0.05192135649849661, 0.012848529058828717, 0.04891304604825564, 0.025514892404316925, 0.02113525817549089, 0.031695917568868026, 0.03619621573307086, 0.0226106143600191, 0.06443041143938899, 0.006586369063370512, 0.07579150493256748, 0.1312950227293186, 0.23532880906714126, 2.3397403629496694, 7.329531675204635, 13.832006379961967, 28.54091640561819, 38.8761281222105, 41.38640262186527, 40.076605305075645, 41.944923251867294, 42.17588245868683, 35.798931643366814, 35.86954325437546, 33.78592886030674, 21.391974315047264, 24.072166197001934, 20.89506547898054, 24.13841374218464, 21.243913359940052, 23.68585802614689, 20.151696167886257, 31.988617703318596, 21.03550974279642, 14.1586197540164, 11.715230215340853, 9.807083755731583, 6.390872318297625, 10.621520653367043, 18.46695017069578, 12.251843120902777, 7.279103631153703, 3.4536964260041714, 7.2968073561787605, 6.605089148506522, 5.665633259341121, 6.7149037308990955, 7.703270595520735, 11.98443342000246, 4.994454374536872, 8.913723193109035, 7.636682968586683, 14.781982004642487, 11.763298586010933, 16.876496113836765, 17.219192124903202, 26.090268306434155, 19.18106485158205, 14.590532127767801, 17.337436079978943, 20.669405087828636, 18.55276856571436, 21.442310214042664, 25.19601859152317, 25.939860977232456, 28.922522328794003, 32.462250888347626, 31.395959705114365, 34.7586614638567, 20.320796594023705, 15.83891049027443, 7.512269094586372, 3.5992898885160685, 1.0176214948296547, 0.2309220697497949, 0.08662241554702632, 0.02124476206518011, 0.023743235615256708, 0.04734859132440761, 0.03938659356208518, 0.04986861313227564, 0.032144434517249465, 0.039264599326997995, 0.06530618280521594, 0.03444695510552265, 0.025122235056187492, 0.014961128490540432, 0.049173795923707075, 0.06065906556614209, 0.02727922790654702, 0.013932745587226236, 0.04758299495733809, 0.046872151069692336, 0.01961944937647786, 0.034276019941898994, 0.04207971018331591, 0.030043306833249517, 0.027137861761730164, 0.003357618720656319, 0.06764348785509355, 0.09006387306726538, 0.07498072343878448, 0.03523621431668289, 0.08756907685892656, 0.032439408532809466, 0.04532109582214616, 0.014978405688452767, 0.05629509250866249, 0.07950533807161264, 0.04766509875480551, 0.007011119660091936, 0.08673687698319554, 0.03868546067678835, 0.020923352749377955, 0.03289123917056713, 0.037778133191750385, 0.04333700111601502, 0.06477264541899785, 0.015273786957550328, 0.03637546666141134, 0.02902234911744017, 0.054630273443763144, 0.0458205389440991, 0.03375225292984396, 0.02462428921717219, 0.030960655167291407, 0.05497366517374758, 0.014980993000790477, 0.04910562223813031, 0.09481334360316396, 0.020750792282342445, 0.04172766501142178, 0.10499910524231382, 0.046078784071141854, 0.08977280274848454, 0.055076886783353984, 0.05417883243353572, 0.020324619545135647, 0.045962879157741554, 0.011703553827828728, 0.002984860902870423, 0.052001259828102775, 0.05456071565276943, 0.019206358847441152, 0.04552249243715778, 0.023501080249843653, 0.02442413013341138, 0.05672842882631812, 0.0252970312430989, 0.013110663967381697, 0.02912825730163604, 0.02560996337706456, 0.03829362896794919, 0.031532489228993654, 0.14288879436207935, 0.016718891347409226, 0.09663559074397199, 0.037881562602706254, 0.02968876804516185, 0.011366817307134625, 0.03445819122134708, 0.03361144525115378, 0.024306197301484644, 0.029221699260233436, 0.02043513275566511, 0.02814911218592897, 0.06780144656659104, 0.02590948119177483, 0.02199259088229155, 0.09605539453332312, 0.04204548975394573, 0.06014860155119095, 0.03270709377829917, 0.03516395510814618, 0.058135073268203996, 0.011969058086833684, 0.09439392626518384, 0.07026919891359285, 0.026302852857043035, 0.08820769493468106, 0.06625685913604684, 0.049148455291287974, 0.04829080717172474, 0.052749741735169664, 0.0783529608452227, 0.022366304910974577, 0.04996213116100989, 0.18809315777616575, 0.5114757700357586, 4.9254709761589766, 9.896633550524712, 18.891543187201023, 35.47175779938698, 45.08658327162266, 46.65551148355007, 45.917800068855286, 49.00132320821285, 43.7106429040432, 41.346006989479065, 39.49127331376076, 36.359758749604225, 23.735623955726624, 26.243833266198635, 20.049665942788124, 20.894873589277267, 21.829361245036125, 30.15886388719082, 26.662990674376488, 31.999162137508392, 20.961767099797726, 18.84432692080736, 17.29597270488739, 13.604353945702314, 12.725516203790903, 15.790284499526024, 20.281387008726597, 14.141488373279572, 7.543273530900478, 4.705649921670556, 10.178779810667038, 9.835244994610548, 9.26726097241044, 9.414184838533401, 9.406249914318323, 13.415380585938692, 8.791552148759365, 13.354796636849642, 12.844808902591467, 18.798864260315895, 16.977948769927025, 20.208888798952103, 22.283691465854645, 31.320695243775845, 27.3834890127182, 18.813795559108257, 20.696552731096745, 23.48245494067669, 22.948973067104816, 25.82669734954834, 30.997290797531605, 28.336375281214714, 34.977309331297874, 34.80948753654957, 38.18606235086918, 39.2081581056118, 24.572546146810055, 21.318856738507748, 10.209913440048695, 4.996540462598205, 1.5960071026347578, 0.33308573300018907, 0.03952000573917758, 0.027228555918554775, 0.027737428026739508, 0.014595326683775056, 0.03591924250940792, 0.032466318807564676, 0.12450849040760659, 0.004691586264016223, 0.02991646822920302, 0.11977477566688322, 0.04371423849079292, 0.03893593551765662, 0.04421837569680065, 0.07297918826225214, 0.04526254408119712, 0.062458458269247785, 0.04487741767661646, 0.037523383580264635, 0.015137539776333142, 0.016392884426750243, 0.03210075541574042, 0.05015446986362804, 0.00908489966604975, 0.02003011122724274, 0.025745449856913183, 0.022102335969975684, 0.06862941620056517, 0.039212626725202426, 0.029427932822727598, 0.033084939714171924, 0.0450061506126076, 0.0669164651480969, 0.04125077946810052, 0.06245300348382443, 0.049853436212288216, 0.020043263939442113, 0.03681379392219242, 0.03518761477607768, 0.06361254985677078, 0.006288969152592472, 0.04482590520638041, 0.061065599220455624, 0.04139444812608417, 0.03243799845222384, 0.007552232054877095, 0.05127107186126523, 0.023073955708241556, 0.03753998542379122, 0.054542440266232006, 0.03877407310937997, 0.057088414978352375, 0.012792422694474226, 0.06365330118569545, 0.09034761096700095, 0.26269112597219646, 0.15637208882253617, 0.11484461443615146, 0.18723193992627785, 0.11547093512490392, 0.25660186365712434, 0.2075141531531699, 0.17188860074384138, 0.11154179752338678, 0.07454208447597921, 0.10556046574492939, 0.11521314270794392, 0.23172106593847275, 0.09211258657160215, 0.1655212408513762, 0.13799222273519263, 0.18221404199721292, 0.157982757082209, 0.14601078699342906, 0.1274496884434484, 0.08394416785449721, 0.1414808808476664, 0.1497925043804571, 0.2113150921650231, 0.17143554927315563, 0.18811880639987066, 0.10053230391349643, 0.20054148277267814, 0.11347409032168798, 0.10110985065693967, 0.07932547116070054, 0.09831089264480397, 0.20202153304126114, 0.15319587488193065, 0.18192138348240405, 0.08882660898962058, 0.11116844529169612, 0.10729389265179634, 0.16891802108148113, 0.09446454903809354, 0.1386579143581912, 0.1186633353063371, 0.10490474116522819, 0.11634712209342979, 0.11183613329194486, 0.14289565180661157, 0.11692981192027219, 0.27789075567852706, 0.09668953003711067, 0.12782689242158085, 0.10127455549081787, 0.12904762144898996, 0.12500199634814635, 0.10508376944926567, 0.20469418494030833, 0.16458373022032902, 0.06774807130568661, 0.09716657514218241, 0.3892021015053615, 0.5851194402202964, 4.589288765564561, 12.54431627690792, 21.252428703010082, 40.02104468643665, 48.23596827685833, 54.945766031742096, 54.93756607174873, 56.95056885480881, 53.67167919874191, 49.50195774435997, 50.73702447116375, 46.6888926923275, 31.823176480829716, 37.21006192266941, 32.75953933596611, 36.66740924119949, 33.28956909477711, 35.20175188779831, 31.838941834867, 42.777694165706635, 31.55849978327751, 23.744270391762257, 21.72640196979046, 18.248372599482536, 13.826255388557911, 16.15363620221615, 26.41557265073061, 15.177306141704321, 11.95780349895358, 7.436885889619589, 12.049173396080732, 11.410539764910936, 9.822129048407078, 10.434675179421902, 11.33163794875145, 17.505273073911667, 9.14442591369152, 14.590452332049608, 13.924555163830519, 23.287046626210213, 19.77667909115553, 27.617997229099274, 26.149927005171776, 39.16304312646389, 30.165857411921024, 23.660595081746578, 30.721607990562916, 30.679724738001823, 30.633059442043304, 31.91330574452877, 36.8947434425354, 36.10618315637112, 42.93439395725727, 43.361312448978424, 44.91438411176205, 43.646540343761444, 28.632835373282433, 22.096771895885468, 11.939968205988407, 4.8871595319360495, 1.561400934588164, 0.3592596191447228, 0.15781648631673306, 0.10028357311966829, 0.14986593247158453, 0.06230234750546515, 0.1114763697842136, 0.11075798567617312, 0.15181059687165543, 0.13717707741307095, 0.1518267163191922, 0.18687875184696168, 0.12739720375975594, 0.1553262840025127, 0.2660238737007603, 0.182475931069348, 0.11107270081993192, 0.16815141221741214, 0.12927587638841942, 0.10922197005129419, 0.08784692952758633, 0.1485595150734298, 0.09233012489858083, 0.11397459471481852, 0.09810704694245942, 0.13589365174993873, 0.22418853419367224, 0.16287158068735152, 0.14735481643583626, 0.1553146619698964, 0.24376450484851375, 0.05973686173092574, 0.15056473872391507, 0.2160038921283558, 0.20209323934977874, 0.22526724584167823, 0.14485278428765014, 0.061760434982716106, 0.19038740341784433, 0.18892219610279426, 0.11003960156813264, 0.10560935843386687, 0.17858036822872236, 0.112343101791339, 0.13888752000639215, 0.15589563001412898, 0.11210801909328438, 0.09674631917732768, 0.11031000307411887, 0.2064456683001481, 0.405266095767729, 0.15555096179014072, 0.18350094091147184, 0.09804035755223595, 0.11615000024903566], [0.021309236144588795, 0.015398716386698652, 0.019992497327621095, 0.04540275062026922, 0.03152533863612916, 0.04206116762361489, 0.0744568117079325, 0.04490635030379053, 0.0027109919437862118, 0.024552705363021232, 0.013791992641927209, 0.03373771425685845, 0.031440384991583414, 0.02529671211959794, 0.029436159529723227, 0.024185130750993267, 0.034115293019567616, 0.08353069511940703, 0.03919456656149123, 0.05240439444605727, 0.04320180778449867, 0.010268218884448288, 0.05664287775289267, 0.014809969707130222, 0.000764512528803607, 0.018908336460299324, 0.008549057911295677, 0.09084836026886478, 0.04734870635729749, 0.056370090242126025, 0.09748589160153642, 0.014972861845308216, 0.02340450828342, 0.023565062656416558, 0.028829850853071548, 0.03164710651617497, 0.08537908070138656, 0.02733888915827265, 0.04365574612165801, 0.02928274276200682, 0.04816169574041851, 0.04574387508910149, 0.01403286501954426, 0.045244624925544485, 0.019302415021229535, 0.03536666903528385, 0.02439298219542252, 0.07651289473869838, 0.0630518795514945, 0.02498050896974746, 0.015451456183654955, 0.04494198823522311, 0.05320818119798787, 0.020153435762040317, 0.060973576619289815, 0.08452773341559805, 0.07938653507153504, 0.05082169773231726, 0.03850013526971452, 0.04638684586097952, 0.01850891814683564, 0.3188141738064587, 2.1669458225369453, 5.16261245124042, 14.516518749296665, 24.120041728019714, 28.21557406336069, 39.57974396646023, 45.0837904214859, 46.94782979786396, 46.1586045473814, 42.16149643063545, 38.37877660989761, 32.54547402262688, 23.019151501357555, 25.277727507054806, 23.876461498439312, 22.562034130096436, 14.954445250332355, 22.485293447971344, 22.41733979433775, 16.12028919160366, 22.80058152973652, 22.33471892774105, 27.316680997610092, 16.860392577946186, 9.450784474611282, 25.540794990956783, 35.89442051947117, 26.160923615098, 14.206874314695597, 9.76480532437563, 7.633944740518928, 10.19543906673789, 11.92414490506053, 13.906354140490294, 16.293356604874134, 13.699753526598215, 9.568516407161951, 12.085683736950159, 16.644256375730038, 18.735286071896553, 24.402687661349773, 19.257775135338306, 37.585177794098854, 23.639567010104656, 25.526688247919083, 28.86437974870205, 21.56187079846859, 24.961189292371273, 19.25096020102501, 26.141787841916084, 31.91735252737999, 28.02625872194767, 33.279731422662735, 26.677257008850574, 16.925063207745552, 14.265750255435705, 5.0738477893173695, 3.224113220348954, 0.5330667458474636, 0.10882715490879491, 0.02830057896062499, 0.05140743778611068, 0.009848589106695727, 0.05787171103293076, 0.0394986875471659, 0.03540573197824415, 0.028378124115988612, 0.022182014799909666, 0.021571724500972778, 0.03111242436716566, 0.04192196298390627, 0.019593220022215974, 0.04074548080097884, 0.03329578757984564, 0.024635940935695544, 0.018156988007831387, 0.041070734441746026, 0.07831731549231336, 0.03209689624782186, 0.01614584201888647, 0.02549819037085399, 0.0321581271418836, 0.05533073839615099, 0.10472910449607298, 0.012692627024080139, 0.07181501088780351, 0.09786259834072553, 0.05434397513454314, 0.05558927296078764, 0.03042400632693898, 0.04076231642102357, 0.06446269486332312, 0.053787197393830866, 0.026273576986568514, 0.016958018750301562, 0.054150794094312005, 0.034417206115904264, 0.043476625069160946, 0.037169379138504155, 0.07386092649539933, 0.041855674353428185, 0.06077002406527754, 0.01743370758049423, 0.02869240695872577, 0.011649304688035045, 0.0532355516043026, 0.03791259179706685, 0.03289568834588863, 0.038563681664527394, 0.039153444158728234, 0.11543164582690224, 0.042479701805859804, 0.01646476513997186, 0.04382745311886538, 0.037126790994079784, 0.017413749374100007, 0.0752083030238282, 0.07852599999750964, 0.049853102245833725, 0.033945348623092286, 0.05247161076113116, 0.018703104797168635, 0.07342565688304603, 0.02559553788159974, 0.04423532263899688, 0.019251474004704505, 0.011290488346276106, 0.08787571743596345, 0.0029417135965559282, 0.035144495996064506, 0.025610555239836685, 0.07302044425159693, 0.02427205108688213, 0.03711660872795619, 0.030698905247845687, 0.06872389902127907, 0.05654117754602339, 0.0398290954035474, 0.03759524202905595, 0.034637000571819954, 0.030651747329102363, 0.08250949991634116, 0.0850265976623632, 0.05544159299461171, 0.08914321660995483, 0.017252938960155006, 0.05271625232126098, 0.040240519811050035, 0.03488409493002109, 0.04244849449605681, 0.012311879290791694, 0.07530320144724101, 0.003049528172596183, 0.01695905961241806, 0.02620767798362067, 0.027164666280441452, 0.02027459879172966, 0.04225884978950489, 0.04366215827758424, 0.022478521350421943, 0.023211488660308532, 0.03160653701343108, 0.06670904971542768, 0.006734345888617099, 0.052499203811748885, 0.03665071439172607, 0.03816498880041763, 0.010745749168563634, 0.026039427539217286, 0.07859555407776497, 0.0649146999057848, 0.04730911648948677, 0.039794214462745, 0.02994392027176218, 0.04349495611677412, 0.45004090410657227, 3.301177597604692, 6.99341026134789, 18.742403090000153, 30.508078448474407, 34.35666963458061, 46.17180123925209, 50.51590293645859, 53.909770622849464, 50.685947611927986, 49.20944184064865, 41.27969674766064, 34.90037105977535, 25.697428286075592, 27.870921157300472, 26.933876238763332, 28.21256462484598, 19.9856735765934, 22.742951922118664, 26.442220620810986, 18.819871433079243, 25.65210621803999, 27.33258504420519, 31.850495114922523, 21.497640945017338, 14.108559340238571, 32.935352101922035, 39.18529853224754, 25.94708438962698, 16.602433919906616, 15.252041481435299, 12.763688005506992, 15.359204281121492, 18.086334094405174, 17.6040031760931, 20.249141938984394, 14.99342355877161, 13.609527368098497, 14.17461784556508, 25.12580595910549, 25.566872991621494, 30.666486248373985, 24.4795024394989, 41.75091326236725, 25.671325586736202, 23.720320276916027, 27.856694720685482, 24.884701296687126, 27.647876925766468, 23.953257277607918, 28.701526187360287, 35.48128768801689, 33.51627252995968, 38.397669196128845, 31.43776126205921, 23.5275699198246, 17.893342450261116, 7.416526107117534, 4.456510590389371, 0.8761405397672206, 0.2034123326302506, 0.021199422408244573, 0.007529727818109677, 0.016857769442140125, 0.06111195747507736, 0.070414615329355, 0.04150898377702106, 0.009238014008587925, 0.03702521695231553, 0.0043956803892797325, 0.03810283393249847, 0.026410824211779982, 0.041881541910697706, 0.029863694107916672, 0.05623555371130351, 0.0182999794560601, 0.02791582177451346, 0.07233884840388782, 0.05949698846961837, 0.015634235096513294, 0.07301331963390112, 0.02232127881143242, 0.005732825948143727, 0.06380329665262252, 0.06331135664368048, 0.01329147897195071, 0.02158222774596652, 0.11049256398109719, 0.009235721699951682, 0.04211294355627615, 0.06539481750223786, 0.056170445095631294, 0.01796074375306489, 0.07994963962119073, 0.05023012068704702, 0.03905944002326578, 0.02878657993278466, 0.034924011342809536, 0.07183466295828111, 0.06564188588527031, 0.028722378592647146, 0.03224379695893731, 0.047197441817843355, 0.029158865327190142, 0.059401652179076336, 0.011697868048941018, 0.008722514521650737, 0.07440341418259777, 0.07434082886902615, 0.09534259137581103, 0.03036102767509874, 0.025667210793471895, 0.031994067976484075, 0.05237504621618427, 0.05549558794882614, 0.13861725950846449, 0.18237526615848765, 0.2240314957452938, 0.1373042815248482, 0.15505679533816874, 0.1537433423800394, 0.12408001886797138, 0.1766301822499372, 0.17272014752961695, 0.14251950167817995, 0.10732705923146568, 0.17074159666663036, 0.12707487418083474, 0.14717079349793494, 0.14091049582930282, 0.08440693403827026, 0.08460392971755937, 0.14971886848798022, 0.20158658997388557, 0.16626237920718268, 0.17056502489140257, 0.15835886268178, 0.14482400380074978, 0.12608124234247953, 0.08645267895190045, 0.1372146894573234, 0.11903813472599722, 0.17408463056199253, 0.17433166183764115, 0.1657889928901568, 0.29899034067057073, 0.16079194931080565, 0.08498150476953015, 0.14568801212590188, 0.11545641129487194, 0.11815736128482968, 0.16455880890134722, 0.14762537379283458, 0.11942232973524369, 0.1296494883717969, 0.1188172196270898, 0.17120183212682605, 0.05905279082071502, 0.18283483368577436, 0.13194273953558877, 0.10104163986397907, 0.16459241334814578, 0.26127528632059693, 0.16879621980478987, 0.12659327971050516, 0.13714599626837298, 0.12395507088513114, 0.24612493521999568, 0.1592577964765951, 0.15238755731843412, 0.11192154706805013, 0.153405605815351, 0.16687946015736088, 0.09587798413122073, 0.280650268541649, 0.09855735246674158, 0.5735359992831945, 3.6436166474595666, 8.397171311080456, 20.073222778737545, 32.64991521835327, 38.27588953077793, 52.15375944972038, 58.5481209307909, 61.38046994805336, 61.671249344944954, 56.3021944463253, 50.212322026491165, 46.04796588420868, 34.067824333906174, 40.396228954195976, 33.67089003324509, 36.41868978738785, 24.212910644710064, 33.385730534791946, 36.92933678627014, 26.49920616298914, 34.52195316553116, 34.18670855462551, 41.31781630218029, 26.633456759154797, 16.05385735630989, 40.10625511407852, 44.630611538887024, 32.56164975464344, 23.476962335407734, 17.257055193185806, 16.009397841989994, 19.6639334410429, 20.06801325827837, 21.154167875647545, 25.70638630539179, 21.303562559187412, 18.621409982442856, 20.125564970076084, 28.53450044989586, 30.252990536391735, 35.11860474944115, 29.723093770444393, 48.41763272881508, 35.23769035935402, 37.615663558244705, 41.18940979242325, 33.206148371100426, 37.79858574271202, 30.56178666651249, 38.359621837735176, 43.43480430543423, 41.527964025735855, 43.24391394853592, 37.78648339211941, 26.15299344062805, 20.198095478117466, 8.080864883959293, 4.86091386526823, 0.8972780336625874, 0.30074902286287397, 0.12685258610872552, 0.10056927028927021, 0.1608964882325381, 0.11565721419174224, 0.10715192722273059, 0.18065213283989578, 0.15543217363301665, 0.1524449253338389, 0.13436058245133609, 0.22684775321977213, 0.3516563755692914, 0.12580237293150276, 0.07929375176900066, 0.25374996825121343, 0.11680465613608249, 0.07098330082953908, 0.09510021336609498, 0.12360564549453557, 0.13094652502331883, 0.18757905723759905, 0.15012038522399962, 0.13790882017929107, 0.2811642800224945, 0.19108555658021942, 0.11970436069532298, 0.12634385871933773, 0.1487439832999371, 0.18017182970652357, 0.15405563812237233, 0.14795062743360177, 0.13809506956022233, 0.17366405547363684, 0.31147771747782826, 0.19239463086705655, 0.11604499377426691, 0.14471829228568822, 0.07781846608850174, 0.1375691095017828, 0.16768739180406556, 0.20707603369373828, 0.202425513707567, 0.2526698465226218, 0.06418893884983845, 0.18294375127879903, 0.08230504565290175, 0.118771228735568, 0.11733616003766656, 0.27074612968135625, 0.12445637679775245, 0.10632921941578388, 0.18881091848015785, 0.14199734141584486, 0.11645301172393374, 0.10265007425914519], [0.0828872159763705, 0.018020054340013303, 0.034210109806736, 0.11363662066287361, 0.04280853259842843, 0.06604325419175439, 0.050538583236630075, 0.05734078600653447, 0.0346160534536466, 0.06827355638961308, 0.047207653769874014, 0.0673815245681908, 0.018051189290417824, 0.01784580363164423, 0.024232624491560273, 0.10659049250534736, 0.05788835740531795, 0.052847746046609245, 0.007336762928389362, 0.009123276122409152, 0.019699018739629537, 0.046912705729482695, 0.0705870904494077, 0.03851332323392853, 0.03601897602493409, 0.03688285447424278, 0.013901895435992628, 0.030395884496101644, 0.06392984767444432, 0.03876357171975542, 0.04386709493701346, 0.04185384124866687, 0.04706310195615515, 0.053903124571661465, 0.056730703508947045, 0.07558032681117766, 0.06311013814411126, 0.07774019177304581, 0.045272752322489396, 0.05009284563129768, 0.027670258095895406, 0.016279116898658685, 0.03556328250851948, 0.026283185943611898, 0.047609237299184315, 0.04751440937980078, 0.01113837497541681, 0.04088552406756207, 0.03587699946365319, 0.0459468227927573, 0.039454581710742787, 0.03429346783377696, 0.033667336392682046, 0.01983596168429358, 0.04627266273018904, 0.00647005736027495, 0.0391683910129359, 0.035979675594717264, 0.08356492297025397, 0.030237643768487033, 0.031042681039252784, 0.08101749364868738, 0.23164941900176927, 0.9661148430313915, 2.9100139997899532, 10.335871931165457, 17.221004627645016, 25.092654637992382, 31.903981044888496, 40.23331269621849, 45.42059674859047, 45.82981579005718, 45.879057347774506, 37.73779660463333, 36.50254748761654, 29.591537229716778, 28.70341658592224, 17.5650267675519, 22.31810051947832, 29.40643586218357, 20.928933061659336, 25.429217778146267, 21.690068319439888, 25.17727989703417, 19.694145619869232, 29.48860265314579, 28.03859855979681, 12.994107641279697, 38.09340052306652, 49.30963486433029, 33.239461183547974, 12.109656650573015, 12.310109194368124, 15.959094241261482, 19.06465619802475, 21.359871737658978, 15.771890636533499, 17.399061173200607, 27.939112298190594, 15.948109030723572, 16.434026956558228, 23.155129104852676, 29.959995858371258, 22.17082802206278, 28.577958717942238, 24.44821871817112, 21.96669727563858, 32.017241567373276, 25.744473561644554, 25.917806960642338, 28.812829814851284, 34.05397407710552, 34.595448821783066, 30.225200727581978, 21.500099413096905, 15.1172399148345, 7.296562269330025, 3.4721962083131075, 1.1754974420182407, 0.2577037748415023, 0.04787543453858234, 0.026813075673999265, 0.02130002609192161, 0.0065942965920839924, 0.02679665936739184, 0.02925473225332098, 0.055500619710073806, 0.0010348372688895324, 0.0687968595593702, 0.06843093622592278, 0.04490522223932203, 0.06082240113755688, 0.02959013290819712, 0.05173437239136547, 0.018630235172167886, 0.012394791101542069, 0.037042857802589424, 0.003988907392340479, 0.0730424266657792, 0.03628191894677002, 0.04393268965941388, 0.04106392152607441, 0.022537874610861763, 0.04925148394249845, 0.020646945413318463, 0.01331346695224056, 0.0101780507247895, 0.01821657133405097, 0.013636410658364184, 0.06613705423660576, 0.027784430094470736, 0.08280245529022068, 0.0037387681413747487, 0.03242130384023767, 0.035476384437060915, 0.04513123589276802, 0.029142081657482777, 0.035803697537630796, 0.03982323614764027, 0.03182442414981779, 0.017266273498535156, 0.06102812818426173, 0.03366238626767881, 0.029342890120460652, 0.028397761343512684, 0.03616343507019337, 0.03208147441910114, 0.06660362021648325, 0.010446864034747705, 0.025647551301517524, 0.01322398527918267, 0.011949793788517127, 0.030719158457941376, 0.08595035629696213, 0.07675144326640293, 0.08618343519628979, 0.13286641653394327, 0.015017780333437258, 0.011841969007946318, 0.027248246951785404, 0.09630056301830336, 0.06626487433095463, 0.04143080223002471, 0.05296993695083074, 0.022441547553171404, 0.023220375878736377, 0.08390410672291182, 0.06638234888669103, 0.04711409492301755, 0.03538369019224774, 0.012514602494775318, 0.07832277027773671, 0.04243541414325591, 0.050397293161950074, 0.02182590265874751, 0.0625434861285612, 0.06882156565552577, 0.052291446991148405, 0.025298953405581415, 0.031334543600678444, 0.05728732910938561, 0.02004967609536834, 0.01002459684968926, 0.09342861478216946, 0.04448175277502742, 0.01954120660229819, 0.02127527546690544, 0.0376567809144035, 0.04527517914539203, 0.02874586014513625, 0.06966572895180434, 0.03469393072009552, 0.0933007278945297, 0.1208775477425661, 0.044626542076002806, 0.046145013329805806, 0.07493292912840843, 0.08112011040793732, 0.040590872886241414, 0.018233308619528543, 0.006374835638780496, 0.025917195816873573, 0.0656979699851945, 0.06554027844686061, 0.04776240173669066, 0.03796696895733476, 0.006371146237142966, 0.04003437716164626, 0.0239501927717356, 0.037585698009934276, 0.018047497105726507, 0.04888237679551821, 0.02969488334201742, 0.03992478421423584, 0.05146593015524559, 0.10152883754926734, 0.05380643757234793, 0.08349597002961673, 0.4407794651342556, 1.564901852980256, 4.945447454228997, 14.36917120590806, 20.488348603248596, 32.84444957971573, 38.66185761988163, 46.1253297328949, 53.05551566183567, 51.17485597729683, 51.54378578066826, 42.33934968709946, 40.35843998193741, 33.85061278939247, 32.04370714724064, 22.41904780268669, 22.669051587581635, 30.502443350851536, 23.70709128677845, 28.425024524331093, 23.305521234869957, 25.521208941936493, 23.55844136327505, 29.80049941688776, 29.388191141188145, 20.01412644982338, 46.31384141743183, 55.37451982498169, 37.93633595108986, 18.06495264172554, 19.645405635237694, 25.338016971945763, 24.215357713401318, 26.570013463497162, 21.84559017419815, 22.77585245668888, 27.548939734697342, 21.91336713731289, 21.975433006882668, 28.713581040501595, 32.69009046256542, 24.6523779630661, 35.14675743877888, 27.743130214512348, 27.20851220190525, 35.06744049489498, 30.472155176103115, 30.763618536293507, 31.713423170149326, 37.980075404047966, 37.54075437784195, 35.40510177612305, 26.873174495995045, 19.624189473688602, 10.90362511575222, 5.431429026648402, 1.8808486056514084, 0.4437472840072587, 0.08694508651387878, 0.02964614650409203, 0.030955146576161496, 0.03161102329613641, 0.04260699497535825, 0.02940512291388586, 0.021733624016633257, 0.04234336556692142, 0.05393665480369236, 0.09147462900727987, 0.07353126449743286, 0.07669138867640868, 0.027782513498095796, 0.06227387872058898, 0.07975652537425049, 0.06394826035830192, 0.07454148333636113, 0.04508625061134808, 0.07544012769358233, 0.03243578314140905, 0.019001429609488696, 0.06914479323313572, 0.06190533560584299, 0.04679883801145479, 0.013613092378363945, 0.04222251052851789, 0.05994136052322574, 0.016506510946783237, 0.02012010034377454, 0.03063606760406401, 0.01770286227838369, 0.006238070345716551, 0.015640951532986946, 0.046577752218581736, 0.03009678599482868, 0.06718151576933451, 0.038637128309346735, 0.03486232031718828, 0.05612546352494974, 0.02970400804770179, 0.03423885318625253, 0.008287314485642128, 0.058005338432849385, 0.04286457216949202, 0.041133735358016565, 0.06024102491210215, 0.03175524856487755, 0.011329116205160972, 0.031087590250535868, 0.023561125562991947, 0.017222466376551893, 0.011077483613917138, 0.012079679836460855, 0.029242896853247657, 0.038173497523530386, 0.053632964263670146, 0.17800075089326128, 0.06592968333279714, 0.07390125480014831, 0.2586453524418175, 0.21324513625586405, 0.15477130596991628, 0.09488072319072671, 0.14109195093624294, 0.212565700057894, 0.1500606571789831, 0.18515224917791784, 0.1310742337955162, 0.15477421518880874, 0.16598248563241214, 0.09485845133895054, 0.21799661801196635, 0.11638447438599542, 0.137050912308041, 0.1654816250083968, 0.22445224894909188, 0.1518400156055577, 0.20933940599206835, 0.1644385512918234, 0.11549663569894619, 0.2644621575018391, 0.17471076571382582, 0.12399038969306275, 0.1237789518199861, 0.175117818871513, 0.17833499936386943, 0.09652595326770097, 0.1173443162406329, 0.1958621822996065, 0.1327743160072714, 0.22162813955219463, 0.11244501351029612, 0.21218537905951962, 0.23736631614156067, 0.20894651301205158, 0.09675800800323486, 0.15291902411263436, 0.26112593652214855, 0.13407555321464315, 0.16158949089003727, 0.12434243486495689, 0.19834006496239454, 0.16762199375079945, 0.2568284858716652, 0.15687723906012252, 0.17438448790926486, 0.16448696900624782, 0.10871667138417251, 0.16267108207102865, 0.1049452846928034, 0.13695222151000053, 0.16589267092058435, 0.12279330549063161, 0.11517770515638404, 0.12441062339348719, 0.32005299639422446, 0.1466520322719589, 0.21060506463982165, 0.5093269259668887, 1.6692893765866756, 5.619631502777338, 14.818609189242125, 23.592212051153183, 35.937635600566864, 42.476138547062874, 52.12407544255257, 59.87485393881798, 61.12454228103161, 60.43118588626385, 51.48779958486557, 49.181292951107025, 43.92213575541973, 42.31068402528763, 31.508944742381573, 33.00410181283951, 41.74888037145138, 33.65471050143242, 38.7176538258791, 31.81775227189064, 35.28450004756451, 31.489541083574295, 42.62613169848919, 40.45516759157181, 21.70931238681078, 51.873497888445854, 61.389950439333916, 43.25561352074146, 24.954837933182716, 24.936066940426826, 29.255034886300564, 31.461836770176888, 32.314499616622925, 28.43019224703312, 27.868591882288456, 44.30374167859554, 24.987088702619076, 28.118289783596992, 37.72577404975891, 41.14713326096535, 32.62305065989494, 40.90643897652626, 35.94434604048729, 34.363026693463326, 43.40957745909691, 39.63297910988331, 38.86962287127972, 41.22728995978832, 45.297977328300476, 46.60711728036404, 41.3161937892437, 31.342553570866585, 22.47199986129999, 12.033117357641459, 5.913546206429601, 2.0458477456122637, 0.5824299564119428, 0.19866128131980076, 0.12823630560887977, 0.15827986848307773, 0.1301754781161435, 0.06804794349591248, 0.10002304959925823, 0.14065313385799527, 0.09844712869380601, 0.18456942576449364, 0.1407428743550554, 0.1609903699136339, 0.1720276940613985, 0.12294533444219269, 0.12610361067345366, 0.16735784854972735, 0.14186758431605995, 0.165764071571175, 0.12920068198582157, 0.10627024093992077, 0.16547957668080926, 0.14840571238892153, 0.13926552550401539, 0.12376361162750982, 0.0878044861019589, 0.13734915177337825, 0.19203764299163595, 0.10503308818442747, 0.16776965145254508, 0.20651068043662235, 0.09899420285364613, 0.12885870033642277, 0.16353771759895608, 0.14861073810607195, 0.10832230153027922, 0.2135773512418382, 0.23463248158805072, 0.0850045113475062, 0.08461086879833601, 0.09575161864631809, 0.13406973477685824, 0.12794620008207858, 0.13270897732581943, 0.1650900233653374, 0.13324186904355884, 0.0887724915810395, 0.14059787354199216, 0.0910718654631637, 0.14278728340286762, 0.14664493734017015, 0.1505064801312983, 0.21341879881219938, 0.0825548599823378, 0.17434211127692834, 0.26070481224451214, 0.1678269007243216, 0.17759110021870583], [0.013495371986209648, 0.041331406391691417, 0.05535864685953129, 0.01698523701634258, 0.05030681051721331, 0.03720417102158535, 0.03660016671346966, 0.03857150390103925, 0.02649708589160582, 0.04655838216422126, 0.08614404941909015, 0.02680837787920609, 0.01864877216576133, 0.0606847809831379, 0.04074191107065417, 0.060722671332769096, 0.024114487569022458, 0.09649544357671402, 0.02385470063018147, 0.008708611312613357, 0.022379294350685086, 0.010776400795293739, 0.029873008061258588, 0.05633595144900028, 0.06704058934701607, 0.07718072374700569, 0.04832735794479959, 0.029085914065944962, 0.06586438918020576, 0.055677113559795544, 0.04479800787521526, 0.02515551295800833, 0.0960386887891218, 0.10096332101966254, 0.05852347254403867, 0.06721632991684601, 0.034817309060599655, 0.007418767463605036, 0.0450736303901067, 0.040742768251220696, 0.017310416442342103, 0.006136339989097905, 0.034817171763279475, 0.07774445170070976, 0.018329043814446777, 0.03579671021725517, 0.06819750851718709, 0.01821965866838582, 0.06204340847034473, 0.0121982527707587, 0.031179371653706767, 0.03413596183236223, 0.056472339638276026, 0.08420059471973218, 0.021929927643213887, 0.00878392538652406, 0.021559119122684933, 0.030014249896339606, 0.048994314929586835, 0.08738312433706596, 0.06091010072850622, 0.06389982037944719, 0.054068341487436555, 0.0696781302394811, 0.3166147449519485, 2.5988494092598557, 6.053150715306401, 9.70908036455512, 20.925019271671772, 28.4059077501297, 36.543490290641785, 48.61859254539013, 44.71903659403324, 49.918837174773216, 43.0831103771925, 43.71147885918617, 44.273833483457565, 27.698465511202812, 28.312288373708725, 34.151974618434906, 31.45226888358593, 24.148530699312687, 28.099402897059917, 30.25494173169136, 27.571913301944733, 17.889295667409897, 23.545390963554382, 20.927052162587643, 13.860309161245823, 45.999659076333046, 65.00319555401802, 31.418596990406513, 19.12313885986805, 21.97729680687189, 27.576949931681156, 33.74134585261345, 26.309020668268204, 22.277140617370605, 23.183186799287796, 17.62237709015608, 21.400269269943237, 28.74992609024048, 27.517942897975445, 32.67530545592308, 33.37872751057148, 29.681976176798344, 25.16194961965084, 27.075507938861847, 25.54278038442135, 31.075127720832825, 32.973452657461166, 30.37448901683092, 32.16277755796909, 21.562687754631042, 13.753176759928465, 7.799923634156585, 2.6695108925923705, 0.5594180943444371, 0.09247812398825772, 0.05568922540987842, 0.02323513719602488, 0.11130877057439648, 0.03367061297467444, 0.018123025474778842, 0.024481171603838447, 0.07595945295179263, 0.028809120813093614, 0.02696198946068762, 0.04581547749694437, 0.009922556182573317, 0.00882811842529918, 0.028197461251693312, 0.011434417683631182, 0.018165146066166926, 0.02438051040371647, 0.03041503190615913, 0.047920367869664915, 0.03928350553906057, 0.07019077616860159, 0.01834739527112106, 0.040899791856645606, 0.01911535298859235, 0.047278632773668505, 0.04318636369134765, 0.07387628153082915, 0.09657267146394588, 0.031344391900347546, 0.03176606536726467, 0.023129833862185478, 0.05854243441717699, 0.02763240485364804, 0.008071506290434627, 0.05031630258599762, 0.06428537351894192, 0.024451860481349286, 0.042406626234878786, 0.011666452937788563, 0.04211629064229783, 0.041405045994906686, 0.03143513800750952, 0.025374958604515996, 0.017639356701693032, 0.01833756181440549, 0.052336558437673375, 0.040592468503746204, 0.02264507784275338, 0.008642819921078626, 0.048044158102129586, 0.04984408515156247, 0.08733792012208141, 0.05356728419428691, 0.028812174750783015, 0.00619891695350816, 0.002625035008350096, 0.035595502849901095, 0.07680198352318257, 0.02453684195643291, 0.051474075225996785, 0.022929186816327274, 0.020136939674557652, 0.04919887680443935, 0.01489752179622883, 0.04474484783713706, 0.0562662749143783, 0.040630203002365306, 0.10343218658817932, 0.09997032000683248, 0.017637052333157044, 0.04644806933356449, 0.05586293991655111, 0.01559879383421503, 0.05486177156853955, 0.013341609192139003, 0.04611280783137772, 0.06714559582178481, 0.09443051414564252, 0.06850578924058937, 0.023914070588944014, 0.08438057295279577, 0.04993923219444696, 0.0479487884149421, 0.04138192438404076, 0.03998341388069093, 0.01480778129916871, 0.03679386354633607, 0.07769401534460485, 0.0734629126964137, 0.022768368980905507, 0.03062627867620904, 0.09654681503889151, 0.058530114765744656, 0.10544378528720699, 0.013842755543009844, 0.04061133018694818, 0.06871992110973224, 0.0474275150190806, 0.042183926270809025, 0.02704074802750256, 0.05117389504448511, 0.01776360335497884, 0.040432647001580335, 0.06269670251640491, 0.05020938137022313, 0.0076811421786260325, 0.046406464534811676, 0.06241784794838168, 0.07830837261280976, 0.10836808462045155, 0.03874628710036632, 0.07231023861095309, 0.018244958482682705, 0.027448124019429088, 0.03355611443112139, 0.04264272938598879, 0.04904266956145875, 0.05404930911026895, 0.019538267697498668, 0.08096014789771289, 0.03982559988799039, 0.1572766777826473, 0.6744831637479365, 4.266653303056955, 8.537501581013203, 13.873398508876562, 26.418485194444656, 35.11598289012909, 43.10699209570885, 52.93889231979847, 51.57084032893181, 52.890961691737175, 48.11622530221939, 47.95586250722408, 47.071315571665764, 31.198030225932598, 31.095629520714283, 37.8461629897356, 34.242725148797035, 27.36825183033943, 25.868960581719875, 27.530256137251854, 27.864301912486553, 19.5113393291831, 25.026942864060402, 25.807804763317108, 21.538608446717262, 60.918726325035095, 67.54645228385925, 32.44433484971523, 21.840713135898113, 23.14445547759533, 31.32420625537634, 40.53004637360573, 34.43970277905464, 26.97705142199993, 32.857403084635735, 19.836675971746445, 21.859016753733158, 32.78691686689854, 34.19302001595497, 33.341215923428535, 34.14278671145439, 29.243665896356106, 30.00182021409273, 32.30751559138298, 31.57400105148554, 36.18633225560188, 37.31481470167637, 35.252855345606804, 38.55916813015938, 24.946366287767887, 17.960367053747177, 10.620690397918224, 3.821662743575871, 1.2131763389334083, 0.0762567573110573, 0.06590047982172109, 0.02696977087907726, 0.06666304398095235, 0.031422380488947965, 0.046214578542276286, 0.0450526721397182, 0.09793153643840924, 0.033511014116811566, 0.018113884070771746, 0.009788088300410891, 0.0062829572925693356, 0.03263685321144294, 0.004166003309364896, 0.0361517870624084, 0.014587997047783574, 0.08740818666410632, 0.032479662622790784, 0.05244964318990242, 0.037193936805124395, 0.014886500903230626, 0.03088039931753883, 0.042735327151604, 0.009339768021163763, 0.07585944113088772, 0.02577412273240043, 0.07843251907615922, 0.06032353689079173, 0.027881195019290317, 0.036274363883421756, 0.03916429806849919, 0.04065234497829806, 0.05496500431036111, 0.02757269721769262, 0.019779256035690196, 0.03780947779887356, 0.02198881149524823, 0.06231747247511521, 0.040131327623385005, 0.05491290554346051, 0.016960178400040604, 0.011745386836992111, 0.037370642166933976, 0.008213161872845376, 0.002707911103243532, 0.029561014744103886, 0.018339734451728873, 0.05370026592572685, 0.037378605411504395, 0.04262545218807645, 0.04483961638470646, 0.006024011763656745, 0.03257975236920174, 0.020684741139120888, 0.004085762766408152, 0.03416329884203151, 0.013246198686829302, 0.0635498457995709, 0.2033589276834391, 0.22359904629411176, 0.1709508229396306, 0.10434554031235166, 0.09090566149097867, 0.12684560992056504, 0.19358421937795356, 0.16181252110982314, 0.13544315326726064, 0.1915991969872266, 0.17549104493809864, 0.13115011097397655, 0.1448123817681335, 0.13902354083256796, 0.181077902961988, 0.14672753837658092, 0.1255385097465478, 0.1267653243849054, 0.12753214105032384, 0.14715111174155027, 0.22791914729168639, 0.13564385968493298, 0.19975287665147334, 0.12049170516547747, 0.135269119637087, 0.17792843602364883, 0.1069209560228046, 0.11918194068130106, 0.14010373677592725, 0.1549578076810576, 0.1477443697513081, 0.06665806417004205, 0.16593354841461405, 0.1390853468910791, 0.14912393322447315, 0.19709613639861345, 0.13900360674597323, 0.1772395003354177, 0.16648846707539633, 0.19424563623033464, 0.06957840785617009, 0.08961420578998514, 0.10026697869761847, 0.1862684392835945, 0.10192114423261955, 0.15734599437564611, 0.119908985652728, 0.10573663676041178, 0.17343066487228498, 0.17346373497275636, 0.11226507238461636, 0.16959567612502724, 0.16558815288590267, 0.2174379292409867, 0.11308840359561145, 0.10812434848048724, 0.11570756149012595, 0.12234227266162634, 0.14069080527406186, 0.1579361205222085, 0.12511192326201126, 0.15117095463210717, 0.14718004065798596, 0.25357131846249104, 0.8851774642243981, 4.6707269456237555, 8.578241094946861, 16.13256063312292, 28.070076070725918, 37.450334429740906, 47.64540396630764, 60.92732906341553, 58.205854296684265, 63.19221273064613, 56.32927179336548, 56.550404727458954, 58.09701293706894, 39.884324222803116, 40.62170125544071, 49.30812254548073, 44.08445544540882, 36.53125874698162, 38.999294713139534, 43.21750156581402, 39.93036635220051, 28.404815308749676, 37.75785572826862, 31.899094507098198, 21.62011217325926, 60.7025521248579, 75.79344615340233, 42.19295114278793, 31.65002167224884, 32.92318515479565, 41.40360049903393, 46.83546222746372, 39.253748059272766, 33.140290305018425, 39.85358767211437, 28.646505139768124, 31.18943888694048, 42.93902970850468, 41.40720270574093, 47.92011022567749, 45.60242459177971, 41.12749971449375, 41.83467596769333, 37.756947576999664, 39.41015146672726, 43.10682490468025, 45.68773001432419, 41.88525505363941, 42.951899617910385, 29.540581963956356, 20.34613173455, 11.67609516531229, 4.362249998375773, 1.371954025235027, 0.2417226487887092, 0.17504802730400115, 0.09905594954034314, 0.1674757312866859, 0.18713553494308144, 0.1365501555847004, 0.14705908542964607, 0.20360408874694258, 0.0718438284820877, 0.08520223433151841, 0.07474518060917035, 0.07335974674788304, 0.10992610492394306, 0.10224578931229189, 0.11205082177184522, 0.13214454433182254, 0.16188936308026314, 0.236677365610376, 0.15083814592799172, 0.12596704065799713, 0.17297203245107085, 0.10501319120521657, 0.09130872931564227, 0.08814790009637363, 0.14740654412889853, 0.11844091364764608, 0.1955862221075222, 0.1234097927226685, 0.10160136764170602, 0.16251480061328039, 0.1378429471515119, 0.11251860487391241, 0.15899467543931678, 0.0816600896359887, 0.10771360684884712, 0.17934544826857746, 0.1173393809585832, 0.14386354596354067, 0.1441798493033275, 0.2026052470318973, 0.10868345285416581, 0.1523460861062631, 0.09327530933660455, 0.08737486423342489, 0.06575134524609894, 0.12822037911973894, 0.12345579103566706, 0.1537284697405994, 0.06087920140998904, 0.10969338967697695, 0.1330078995670192, 0.13524863636121154, 0.28504784975666553, 0.1312861466431059, 0.15934541443130001, 0.1167658566555474, 0.11118450536741875, 0.14014339714776725], [0.023004078793746885, 0.041622543503763154, 0.04307023613364436, 0.027167265652678907, 0.046457609641947784, 0.033936168256332166, 0.0634866593463812, 0.02256373660202371, 0.04599070227413904, 0.01793362753232941, 0.16976487095234916, 0.044901671062689275, 0.0122228855798312, 0.023102702798496466, 0.01681094177911291, 0.02373188632191159, 0.05586853571003303, 0.11624138089246117, 0.06495795227237977, 0.022176632373884786, 0.04093608287803363, 0.07285746862180531, 0.006530886103064404, 0.12554738583276048, 0.03667177283205092, 0.06342264168779366, 0.05427534873888362, 0.010310037978342734, 0.05432633057353087, 0.11920061311684549, 0.02268613716296386, 0.026591112291498575, 0.02337811565666925, 0.014866467554384144, 0.0065059221105912, 0.02550042794609908, 0.018585774960229173, 0.0259924384590704, 0.03289606684120372, 0.05075209912320133, 0.03616113812313415, 0.046925040223868564, 0.0391628583020065, 0.051461681359796785, 0.03005421269335784, 0.0903182070760522, 0.08260918519226834, 0.06085572356823832, 0.0353802688914584, 0.053513374587055296, 0.036147694117971696, 0.03090689584496431, 0.022617918948526494, 0.02449321109452285, 0.002532733869884396, 0.07120499518350698, 0.04349575021478813, 0.02564004076702986, 0.02578533472842537, 0.12654781574383378, 0.00924352816582541, 0.03347002901136875, 0.08913770245271735, 0.04877463179582264, 0.04168306564679369, 0.44274600804783404, 0.7512242021039128, 3.419955186545849, 7.105370303615928, 10.851582158356905, 16.416823379695415, 30.41591439396143, 34.343294352293015, 39.83258619904518, 49.67978060245514, 44.137967973947525, 45.10791912674904, 41.73635624349117, 41.94156423211098, 40.578288584947586, 34.1740058362484, 32.980687469244, 28.37891399860382, 23.953441567718983, 22.734413780272007, 29.363408870995045, 27.644721195101738, 28.797590732574463, 22.85117581486702, 24.186688251793385, 64.4375579059124, 64.31758314371109, 29.75670486688614, 29.70565650612116, 28.194363601505756, 32.14860811829567, 16.76690049469471, 19.235690720379353, 15.114460363984108, 24.33742616325617, 22.00389727950096, 21.697534918785095, 21.414727494120598, 28.962752670049667, 36.2720100581646, 31.268894523382187, 27.33049515634775, 33.46952743828297, 32.16645576059818, 34.839171543717384, 30.982139110565186, 25.6982509419322, 18.95919095724821, 13.332601077854633, 5.133696952834725, 1.273358934558928, 0.20053352694958448, 0.01736507190798875, 0.0316894386196509, 0.06713315742672421, 0.024773618606559467, 0.07318791729630902, 0.04517437693721149, 0.00891620578840957, 0.01091545329472865, 0.034996352187590674, 0.04171461805526633, 0.024001720084925182, 0.010268368241668213, 0.06461014476371929, 0.05602353696303908, 0.01401418145178468, 0.022005114624334965, 0.025493184584775008, 0.059968875648337416, 0.07781939377309754, 0.019356523152964655, 0.028871628201159183, 0.007505519424739759, 0.09002571925520897, 0.03033084638445871, 0.03094522591709392, 0.07939353352412581, 0.08614920734544285, 0.027207415841985494, 0.036643823550548404, 0.039328312705038115, 0.035963288974016905, 0.09414340689545497, 0.03859092961647548, 0.06936814257642254, 0.04267439311661292, 0.05147570795088541, 0.02982667021569796, 0.05310390202794224, 0.028448739467421547, 0.00883018808963243, 0.038997570882202126, 0.10404354557977058, 0.03632833657320589, 0.03305325000837911, 0.025434439885430038, 0.0026244656419294188, 0.004309674286560039, 0.05176523460249882, 0.047521515443804674, 0.017206011107191443, 0.044230958810658194, 0.09575106945703737, 0.07872016809415072, 0.03929369522666093, 0.04260672409145627, 0.03744197740161326, 0.036921019418514334, 0.04562057467410341, 0.049105859725386836, 0.036663011778728105, 0.04414793475007173, 0.047546280911774375, 0.06570358804310672, 0.06390734575688839, 0.056366832213825546, 0.08203772405977361, 0.04099005185707938, 0.020012741260870825, 0.06024856513249688, 0.012479461802286096, 0.030486064715660177, 0.04685030595283024, 0.0415884937683586, 0.02421629167656647, 0.017712335793476086, 0.07352266300586052, 0.03696299158036709, 0.06282190282945521, 0.01739655010169372, 0.029532555236073676, 0.00731454070773907, 0.041295152477687225, 0.013592325231002178, 0.02564235997851938, 0.05758169456385076, 0.009801354190130951, 0.02328701888473006, 0.051700860713026486, 0.059359052902436815, 0.05940230897977017, 0.03162897213769611, 0.033890618942677975, 0.04487226346100215, 0.018477662597433664, 0.03732843993930146, 0.036723949524457566, 0.03112876831437461, 0.044132186376373284, 0.018428903495077975, 0.025554083367751446, 0.03890084677550476, 0.030560654267901555, 0.07163505491917022, 0.013725381177209783, 0.07532908755820245, 0.05819145793793723, 0.04361059014627244, 0.041002531070262194, 0.03291480607003905, 0.010300613630533917, 0.016276578753604554, 0.06379327023751102, 0.048547460392001085, 0.013761584068561206, 0.07755001643090509, 0.09827259040321223, 0.06167443862068467, 0.03896866423019674, 0.02194770764617715, 0.014528012034134008, 0.05147148513060529, 0.0710158291622065, 0.06175909911689814, 0.031147559493547305, 0.6013458163943142, 1.6806493420153856, 4.501399006694555, 10.046262871474028, 14.896202925592661, 22.364442832767963, 36.219477877020836, 41.60285800695419, 46.41553156077862, 54.83817860484123, 50.73068641126156, 52.28607214987278, 45.05041681230068, 44.514478370547295, 45.884536653757095, 38.72516602277756, 36.2878742069006, 32.68589548766613, 28.789616860449314, 25.525677502155304, 26.334226615726948, 30.08358422666788, 28.94461814314127, 17.980338782072067, 30.07880598306656, 71.65539219975471, 64.55920457839966, 27.83624991774559, 29.614850878715515, 29.695672541856766, 37.1730937063694, 21.89191348850727, 23.10404274612665, 20.475091114640236, 26.583639532327652, 22.044974975287914, 26.470527201890945, 24.878494329750538, 36.347238421440125, 43.077004104852676, 37.43689075112343, 33.07774946093559, 39.12475638091564, 37.291195169091225, 40.47770418226719, 36.395670622587204, 30.237204283475876, 23.401602879166603, 16.029702052474022, 6.963849747553468, 2.2555537428706884, 0.4228321078699082, 0.01094763096261886, 0.019295613237773068, 0.0626563371042721, 0.0420119001501007, 0.08414480005740188, 0.034300703773624264, 0.04470330612093676, 0.05319156822224613, 0.020042425312567502, 0.042658633610699326, 0.0420299825782422, 0.02941532373370137, 0.055748838422005065, 0.0634571812406648, 0.06608856230741367, 0.030867754976497963, 0.031008748192107305, 0.06604836016776972, 0.05303443700540811, 0.05651260114973411, 0.04663366933527868, 0.0535802569356747, 0.08216513597290032, 0.021527286553464364, 0.05049061081081163, 0.03145005517581012, 0.03504991298541427, 0.12284742289921269, 0.029700247214350384, 0.027290165307931602, 0.007075103458191734, 0.015713169923401438, 0.013100171854603104, 0.03696439423947595, 0.0397757349855965, 0.042101139697479084, 0.007568989749415778, 0.017759950133040547, 0.021183982025831938, 0.03494427197438199, 0.05450795637443662, 0.03197827507392503, 0.03709569871716667, 0.011350515105732484, 0.02459159575664671, 0.04569608820020221, 0.03172217475366779, 0.016357624990632758, 0.013770296882285038, 0.03403459188120905, 0.02213255993410712, 0.0653387259808369, 0.01503774967204663, 0.03968075121520087, 0.05526225300855003, 0.009737562886584783, 0.04724611557321623, 0.025793349923333153, 0.025809061189647764, 0.11202034176676534, 0.1752876371028833, 0.1587591177667491, 0.14305258635431528, 0.19320030638482422, 0.11636662573437206, 0.16664737573591992, 0.20435833343071863, 0.20023068616865203, 0.11666718070046045, 0.32284272951073945, 0.13227516232291237, 0.12811128341127187, 0.11322582708089612, 0.13826260197674856, 0.09089372033486143, 0.16716392536181957, 0.2480557214585133, 0.11584606108954176, 0.11722252980689518, 0.150031772791408, 0.15020466351415962, 0.11185387804289348, 0.1928257741383277, 0.16079818335128948, 0.15015148121165112, 0.08118348981952295, 0.14244451507693157, 0.1105516537791118, 0.2348883295780979, 0.15258225233992562, 0.18552439170889556, 0.05935758716077544, 0.12975653575267643, 0.19754546228796244, 0.24628765851957723, 0.12956350314198062, 0.11199596963706426, 0.15131317981285974, 0.1661833850084804, 0.15812845551408827, 0.09643018653150648, 0.14940317370928824, 0.11459206900326535, 0.10683353102649562, 0.2188350519281812, 0.1581873671966605, 0.13294729578774422, 0.13263783504953608, 0.09920161086483859, 0.21134314534720033, 0.13348182023037225, 0.14507093117572367, 0.1160245476057753, 0.07439081251504831, 0.19904457090888172, 0.31034469546284527, 0.22272170899668708, 0.10794413276016712, 0.18223154183942825, 0.12587203091243282, 0.2067915684892796, 0.16812963760457933, 0.14706030255183578, 0.21927201363723725, 0.7075074291788042, 1.806549767497927, 4.72238564863801, 10.700054839253426, 18.395684994757175, 24.181585125625134, 41.67818136513233, 48.13438072800636, 53.51856641471386, 61.198816895484924, 60.573290660977364, 60.19222430884838, 54.57656644284725, 56.55092149972916, 54.38746578991413, 44.684447050094604, 47.11024448275566, 41.482875645160675, 37.17692390084267, 34.04316745698452, 41.81381508708, 37.4175725877285, 43.45037207007408, 29.657486490905285, 34.9055577814579, 75.78705489635468, 73.82239311933517, 39.9734066426754, 41.9704844802618, 39.491220116615295, 45.27443379163742, 27.830061949789524, 29.275709576904774, 27.958648949861526, 36.302442625164986, 35.36778397858143, 33.80173221230507, 33.16285729408264, 45.80756798386574, 51.57539248466492, 42.36398756504059, 44.88946884870529, 48.230587765574455, 45.977886244654655, 46.820244044065475, 41.79748736321926, 34.26050439476967, 26.20737612247467, 17.42650520056486, 8.289522137492895, 2.495335601270199, 0.664256903110072, 0.1269750701612793, 0.1358281052671373, 0.2099441079190001, 0.14880179660394788, 0.1640628167660907, 0.16436415840871632, 0.14331765181850642, 0.11160476133227348, 0.18315625784453005, 0.14698307466460392, 0.1542043496738188, 0.1119585579726845, 0.10485411185072735, 0.11995376684353687, 0.24480688094627112, 0.09690599224995822, 0.08518255257513374, 0.17832837940659374, 0.19845175818772987, 0.15687902021454647, 0.1905929041095078, 0.09337941781268455, 0.18089057004544884, 0.06776155612897128, 0.1250059445737861, 0.16921772999921814, 0.16901156137464568, 0.22785030567320064, 0.11735524807590991, 0.09736519612488337, 0.1310855886549689, 0.1402678998420015, 0.15349683060776442, 0.12182538164779544, 0.15446779725607485, 0.12207285079057328, 0.12121963329263963, 0.13548800867283717, 0.0919283929397352, 0.08919368265196681, 0.11739215507986955, 0.3119984082877636, 0.26350532134529203, 0.14775600662687793, 0.10710683432989754, 0.10327461379347369, 0.09441707385121845, 0.08301616413518786, 0.1597452093847096, 0.14234580943593755, 0.14756289980141446, 0.1866444112965837, 0.1541839851415716, 0.1816328364657238, 0.1355090262950398, 0.11127152960398234, 0.1920506899477914, 0.18675561470445246, 0.15911021298961714], [0.04383464824059047, 0.04236458356899675, 0.01961727859452367, 0.08290685320389457, 0.05772811287897639, 0.04658752259274479, 0.01500151523941895, 0.03217287732695695, 0.0104521546199976, 0.05978257060633041, 0.051465778014971875, 0.004301096450944897, 0.03211164272215683, 0.0456667436810676, 0.03702407775563188, 0.04598298022756353, 0.030660365518997423, 0.06832625629613176, 0.03998112435510848, 0.010973532844218425, 0.019567469353205524, 0.06833395236753859, 0.0513167584722396, 0.03335578650876414, 0.018770721871987917, 0.03806633882049937, 0.05324975631083362, 0.03385579366295133, 0.022200635285116732, 0.04648725102015305, 0.03571638015273493, 0.032378081159549765, 0.07294286013348028, 0.03518016361340415, 0.04959090147167444, 0.010327510917704785, 0.021493969688890502, 0.03576486466045026, 0.027839258109452203, 0.005401230191637296, 0.02555251743615372, 0.03376979359018151, 0.05339381459634751, 0.046263200347311795, 0.026492994802538306, 0.05181328495382331, 0.07062004922772758, 0.07799162398441695, 0.005384895521274302, 0.020357665525807533, 0.024104164294840302, 0.022822799946879968, 0.04373515592305921, 0.0283850539199193, 0.05694296516594477, 0.05142000605701469, 0.026586646417854354, 0.0598449852259364, 0.05912734326557256, 0.01713383724563755, 0.015904927895462606, 0.037670365927624516, 0.027149203633598518, 0.059636764563038014, 0.051041440237895586, 0.034670452878344804, 0.06430523339076899, 0.487759520765394, 0.9142934018746018, 3.792719221673906, 4.292557463049889, 12.82377228140831, 15.983585827052593, 28.32732416689396, 30.188678987324238, 40.2876041829586, 42.19289034605026, 48.27409163117409, 47.744141668081284, 44.82667341828346, 47.62296997010708, 40.96089005470276, 40.78472390770912, 29.445243179798126, 29.733940288424492, 30.595825240015984, 23.482023663818836, 37.911207899451256, 51.28642559051514, 29.11183577030897, 46.685484275221825, 66.62764638662338, 42.66979515552521, 29.850820116698742, 28.336816057562828, 33.151138722896576, 30.70566024631262, 24.98742688447237, 27.87015739828348, 20.337023623287678, 32.03296512365341, 30.993601195514202, 33.171144649386406, 31.521370075643063, 32.182570695877075, 27.57014449685812, 27.938819713890553, 28.984293714165688, 33.03703464567661, 26.010628379881382, 20.634245574474335, 14.222082998603582, 9.138299692422152, 3.261550236493349, 1.3481835694983602, 0.11807895338279195, 0.01469673003157368, 0.0163647644512821, 0.07342735640122555, 0.10282196308253333, 0.05467480601510033, 0.02309243704075925, 0.09649506508139893, 0.037281094628269784, 0.09708910976769403, 0.030849778304400388, 0.023720579702057876, 0.07005204650340602, 0.04001229826826602, 0.03630536339187529, 0.013998674276081147, 0.0272081672665081, 0.09296662785345688, 0.09905214232276194, 0.025393079995410517, 0.08809923005173914, 0.01316910716923303, 0.06374742035404779, 0.03738712897757068, 0.01654009127378231, 0.044996588039794005, 0.017221527559740935, 0.07949491831823252, 0.035014267632504925, 0.01132361225245404, 0.07541335100540891, 0.035872505759471096, 0.02506985798390815, 0.04702846963482443, 0.03432605182752013, 0.05080989758425858, 0.04883171779511031, 0.08021640460356139, 0.01088721735868603, 0.04456893657334149, 0.07042179931886494, 0.01923905045259744, 0.012545602930913446, 0.03430094126088079, 0.04440994998731185, 0.03607024729717523, 0.04236267996020615, 0.02586860369774513, 0.03709725722728763, 0.05527488807274494, 0.06602803274290636, 0.018952256759803277, 0.008058165258262306, 0.01039738690451486, 0.04140059681958519, 0.01985633178264834, 0.06209808991116006, 0.023731110777589492, 0.024497305894328747, 0.056628558013471775, 0.0195845387497684, 0.01852018580393633, 0.047664137673564255, 0.04683560400735587, 0.04710801673354581, 0.04491243962547742, 0.009770447450136999, 0.02751614370936295, 0.005110530482852482, 0.033189541718456894, 0.019214051208109595, 0.023522301962657366, 0.0401995829452062, 0.038200144335860386, 0.07084564727847464, 0.018229191555292346, 0.0018596875634102616, 0.023174474044935778, 0.042978588317055255, 0.06986636115470901, 0.029560096336354036, 0.027246345198363997, 0.09083271579584107, 0.02413309321127599, 0.04365086278994568, 0.1079992891754955, 0.05760015548730735, 0.016807939791760873, 0.02784103184239939, 0.07012910369667225, 0.024706441254238598, 0.01826077736041043, 0.04486063029617071, 0.065039744367823, 0.06700060243019834, 0.03626275298302062, 0.020148214753135107, 0.021361737526603974, 0.06044086672773119, 0.019116165640298277, 0.01625055720069213, 0.006444950504373992, 0.04488396712986287, 0.025203210789186414, 0.012143400635977741, 0.04144915554206818, 0.02660858430317603, 0.04576384257234167, 0.016657703126838896, 0.022833518414699938, 0.04730567292426713, 0.011541741514520254, 0.023241944545588922, 0.03977698179369327, 0.0023748078592689126, 0.03986263676779345, 0.003540896495906054, 0.03447118251642678, 0.040587024850538, 0.06042245775461197, 0.039401562680723146, 0.034160115028498694, 0.009600455741747282, 0.05060482362750918, 0.05985871124721598, 0.06587941024918109, 0.08548035417334177, 0.10094142766320147, 0.843784207245335, 1.639313972555101, 4.813907062634826, 6.212859945371747, 17.155239656567574, 21.354388631880283, 33.475382924079895, 37.42497839033604, 47.90953539311886, 48.26941028237343, 53.61934840679169, 54.6005317568779, 48.06227199733257, 52.19950519502163, 44.25844430923462, 44.344407096505165, 30.77069565653801, 33.07240694761276, 34.22567546367645, 22.911353185772896, 37.34235182404518, 45.75954616069794, 27.953718714416027, 51.163600981235504, 69.09698948264122, 43.51052664220333, 31.89306043088436, 32.13013730943203, 36.062808483839035, 29.62508372962475, 27.84276656806469, 29.106179773807526, 24.604705721139908, 35.697549283504486, 33.210031762719154, 37.54363842308521, 37.642657309770584, 39.911815747618675, 34.94679696857929, 33.72257485985756, 35.95231041312218, 38.21040764451027, 31.046072579920292, 25.314585529267788, 17.655140832066536, 11.114114820957184, 4.925778284668922, 1.9006239320151508, 0.25188931496813893, 0.05055261353845708, 0.01502995712144184, 0.027069328134530224, 0.02081685084704077, 0.02057504614640493, 0.029557131456385832, 0.034942383208544925, 0.01781151269824477, 0.049212157537112944, 0.04405051302455831, 0.03523413630318828, 0.046005133335711434, 0.03347088990267366, 0.04106819258595351, 0.020355418673716486, 0.012905771836813074, 0.05430814424471464, 0.0347635404614266, 0.05704236842575483, 0.015118206829356495, 0.08133519964758307, 0.018681276378629263, 0.023727891712042037, 0.011518564242578577, 0.10241258700261824, 0.04060475475853309, 0.02247336527943844, 0.08924154375563376, 0.06382633291650563, 0.06992718757828698, 0.050041314607369713, 0.019504479569150135, 0.030710297214682214, 0.054087333046481945, 0.05963025221717544, 0.07664578370167874, 0.04722706464235671, 0.09414328073034994, 0.04486749145144131, 0.06532947882078588, 0.014430705341510475, 0.03534812276484445, 0.043818313570227474, 0.0835851910233032, 0.03277144911407959, 0.01872907996585127, 0.022422450238082092, 0.025835615233518183, 0.008009081466298085, 0.02705844639422139, 0.0878677616128698, 0.017939815188583452, 0.020139223634032533, 0.05070332146715373, 0.04543605820799712, 0.027074829304183368, 0.03870361360895913, 0.05990613077301532, 0.01610255440027686, 0.07400276575936005, 0.10594512088573538, 0.10183162637986243, 0.12059480432071723, 0.13891190697904676, 0.16017765883589163, 0.09608568900148384, 0.10232306914986111, 0.12489766522776335, 0.1088930205150973, 0.1393825325067155, 0.16146017907885835, 0.08624426904134452, 0.14953248552046716, 0.15540305175818503, 0.08183093945262954, 0.10481885241460986, 0.13449410966131836, 0.14904462732374668, 0.1274735262268223, 0.10992827941663563, 0.13391023239819333, 0.23060358449583873, 0.114368482172722, 0.12848670623498037, 0.20471339172217995, 0.10149147783522494, 0.15869621332967654, 0.11928770414669998, 0.11279369675321504, 0.192658256564755, 0.13306367938639596, 0.1470446729217656, 0.16202156926738098, 0.20401546120410785, 0.11684343335218728, 0.07097454348695464, 0.15557617996819317, 0.11642026074696332, 0.10302324837539345, 0.08078782862867229, 0.19309861731017008, 0.117656797519885, 0.12707802088698372, 0.10265592980431393, 0.15880582854151726, 0.13093332963762805, 0.27532369655091316, 0.1450132959871553, 0.053530770528595895, 0.21624601038638502, 0.09435061452677473, 0.1012834909488447, 0.16435704863397405, 0.10820855997735634, 0.14647684089140967, 0.11457589760539122, 0.1812602041172795, 0.10500892385607585, 0.1713311587809585, 0.11609951194259338, 0.10645044923876412, 0.0895869244413916, 0.10227301871054806, 0.13708776736166328, 0.100921389675932, 0.17733047279762104, 0.21968338609440252, 0.8769545273389667, 1.6004615323618054, 5.146557362750173, 7.6551656518131495, 17.746415734291077, 23.294064849615097, 37.254295349121094, 40.44768959283829, 51.79153248667717, 55.61276704072952, 61.47154726088047, 63.947224617004395, 56.49377256631851, 62.90115214884281, 54.438010677695274, 55.65501317381859, 40.487348064780235, 44.35177110135555, 45.26170827448368, 30.233389288187027, 52.38886423408985, 61.17289088666439, 38.20735260844231, 57.68067687749863, 75.74245288968086, 52.48208463191986, 43.69335763156414, 41.31520964205265, 46.424343287944794, 45.020261630415916, 36.147950515151024, 41.582578495144844, 33.46250541508198, 49.165934175252914, 44.9384406208992, 44.694763496518135, 48.7482225894928, 49.60478402674198, 41.67144052684307, 42.711991891264915, 42.80401535332203, 44.01960052549839, 35.46850137412548, 28.65416742861271, 19.512807950377464, 12.070431355386972, 5.62924356199801, 2.3043229384347796, 0.36067204491700977, 0.16038684058003128, 0.11122464813524857, 0.11702258780132979, 0.14361540146637708, 0.10682252497645095, 0.11094536312157288, 0.19166290294378996, 0.0801627770124469, 0.17507257754914463, 0.17042936029611155, 0.19386144122108817, 0.1208882346691098, 0.18296588212251663, 0.13792296551400796, 0.0733151362510398, 0.07440033426973969, 0.20757068996317685, 0.16535139293409884, 0.18238719989312813, 0.165367467852775, 0.2235656199627556, 0.22592605033423752, 0.22097356530139223, 0.07393911175313406, 0.16843492747284472, 0.19342096173204482, 0.18045458797132596, 0.1554993528407067, 0.10646403796272352, 0.16518856573384255, 0.17659739416558295, 0.13942679419415072, 0.07506700552767143, 0.13578305690316483, 0.20114094513701275, 0.12333341830526479, 0.22376445616828278, 0.10911778736044653, 0.22859620861709118, 0.15383516089059412, 0.12844014388974756, 0.1336594606982544, 0.12566310149850324, 0.16408162278821692, 0.12867720070062205, 0.08041570836212486, 0.14132725627860054, 0.1705463821417652, 0.12625205505173653, 0.24520862032659352, 0.16516944800969213, 0.0745979459316004, 0.14278719434514642, 0.14393238758202642, 0.08463651742204092, 0.19692689704243094, 0.11853417934617028, 0.15282382140867412, 0.12822686549043283, 0.14210848545189947], [0.01647652632527752, 0.048733642979641445, 0.07651115069165826, 0.02298311868798919, 0.01084788445950835, 0.09450351179111749, 0.04316509744967334, 0.05353436623408925, 0.016333887397195213, 0.03401845387998037, 0.04265042174665723, 0.010515077610762091, 0.004719207145171822, 0.048118651175173, 0.041855388626572676, 0.02492039871867746, 0.018149872666981537, 0.03714564525580499, 0.07365351848420687, 0.03437887418840546, 0.01309239785769023, 0.04150910994212609, 0.08222695687436499, 0.028410453924152534, 0.03456289712630678, 0.005932314779784065, 0.024722273119550664, 0.05778581486083567, 0.07707104916335084, 0.05434365972178057, 0.066528692987049, 0.036888442846247926, 0.015441354626091197, 0.053648786852136254, 0.025326370196125936, 0.02590176842204528, 0.03336336012580432, 0.06119778685388155, 0.040833896564436145, 0.031873951375018805, 0.06982241859077476, 0.03848536653094925, 0.034099054828402586, 0.02378179760853527, 0.04249725730915088, 0.05972945880785119, 0.05573045171331614, 0.027678727856255136, 0.03174597542965785, 0.010323570113541791, 0.05464398462208919, 0.011461691610747948, 0.018643089169927407, 0.048437292280141264, 0.04071637747983914, 0.05027663108194247, 0.016170783746929374, 0.05245948035735637, 0.05172391181986313, 0.03254689749155659, 0.07526118104578927, 0.03785071523452643, 0.06209099497937132, 0.03811872702499386, 0.02295684851560509, 0.016221737751038745, 0.05736167004215531, 0.05651175139064435, 0.0400721265032189, 0.3591805062023923, 0.7070380356162786, 1.8869415787048638, 3.8971523428335786, 9.611849281936884, 14.365996476262808, 22.373419851064682, 36.82240292429924, 37.984901145100594, 45.35959102213383, 47.2551155090332, 50.868486016988754, 51.74226813018322, 45.22115685045719, 44.65273775160313, 45.32888486981392, 32.079660817980766, 44.84931640326977, 40.88455595076084, 37.69289821386337, 46.30119189620018, 30.425858460366726, 45.18382005393505, 62.73944802582264, 45.8711613714695, 35.857775285840034, 32.826909720897675, 35.375714153051376, 34.07163552939892, 28.633745424449444, 33.65539826452732, 35.59765264391899, 42.68188610672951, 38.07634323835373, 35.6605164706707, 43.22144955396652, 27.05224748700857, 33.95497418940067, 22.537080869078636, 16.86297833919525, 13.821119014173746, 6.579013047739863, 5.062834080308676, 1.5181442932225764, 0.6329097726847976, 0.047513552199234255, 0.04536952466878574, 0.07398511748760939, 0.09617354444344528, 0.08221190611948259, 0.0393002521013841, 0.03309777515823953, 0.02311170504981419, 0.07584805658552796, 0.08134117393638007, 0.04731352113594767, 0.042325171816628426, 0.044867450633319095, 0.0349401307903463, 0.009590148238203255, 0.03910346051270608, 0.02028882947342936, 0.049804432201199234, 0.060603278325288557, 0.07940298106404953, 0.034453734624548815, 0.026347632192482706, 0.05769964409410022, 0.04654201038647443, 0.01638088946492644, 0.06456117786001414, 0.07348065744736232, 0.04248223252943717, 0.03438465922954492, 0.053734924222226255, 0.03491945826681331, 0.06546600430738181, 0.02967655600514263, 0.003348870654917846, 0.1221617526607588, 0.04385362124594394, 0.037535536248469725, 0.04640175189706497, 0.015435658642672934, 0.05004764141631313, 0.0287110793942702, 0.03222447514417581, 0.05942498901276849, 0.00722174812835874, 0.029848316808056552, 0.03990731405792758, 0.0301352904716623, 0.005321523067323142, 0.05052797052485403, 0.012452703667804599, 0.027811423860839568, 0.018365442447247915, 0.026606053579598665, 0.008179676169675076, 0.08796901282039471, 0.012631838635570602, 0.03493239761155564, 0.029583141877083108, 0.005612838294837275, 0.05392505132476799, 0.04942315383232199, 0.04138627336942591, 0.09449323304579593, 0.06106909844675101, 0.039898233881103806, 0.029593095932796132, 0.06667138572083786, 0.10371447729994543, 0.046741967234993353, 0.037608556158374995, 0.03687806020025164, 0.059798044385388494, 0.010706018292694353, 0.04377567718620412, 0.01028918177325977, 0.049892729221028276, 0.044986865905229934, 0.03278250711446162, 0.031308735415223055, 0.08611737663159147, 0.04360415201517753, 0.035060711234109476, 0.051551915385061875, 0.053027167668915354, 0.08718917888472788, 0.08061352040385827, 0.03690468474815134, 0.04284264170564711, 0.006604114278161433, 0.06217312846274581, 0.05704676194000058, 0.10400584447779693, 0.13490245415596291, 0.03438010986428708, 0.12225728190969676, 0.024035530477704015, 0.16106710798339918, 0.04667185654398054, 0.04628220674931072, 0.058556082512950525, 0.03874521098623518, 0.04143960039073136, 0.03418734442675486, 0.027070359719800763, 0.024228529691754375, 0.022596589624299668, 0.03745230809727218, 0.05730681790737435, 0.06488470229669474, 0.047287275083363056, 0.05008094529330265, 0.016408896262873895, 0.05276556061289739, 0.038652791336062364, 0.014399355168279726, 0.14730608701938763, 0.02599715666292468, 0.0218585052061826, 0.028063115823897533, 0.03338717564474791, 0.02904459684941685, 0.01789252182788914, 0.018374715582467616, 0.013552335531130666, 0.0726238256902434, 0.03531550908519421, 0.03113939586910419, 0.025027336632774677, 0.04221068069455214, 0.004049606723128818, 0.04116361051273998, 0.45017380791250616, 1.3702153810299933, 3.873157105408609, 6.01994619704783, 13.800957296043634, 17.91809432208538, 28.264051862061024, 42.70232141017914, 43.44298906624317, 51.132704839110374, 52.503192499279976, 57.00274385511875, 56.634562611579895, 51.67921431362629, 49.297015741467476, 50.59099070727825, 37.78229981660843, 43.307564333081245, 43.69568310678005, 42.196237966418266, 43.511241003870964, 35.9702530503273, 49.32050608098507, 65.24505257606506, 47.05365031957626, 38.75745289027691, 35.85465185344219, 40.751437693834305, 39.90690641105175, 33.59798714518547, 38.47168542444706, 40.85500493645668, 47.273707911372185, 41.49187356233597, 42.70978040993214, 47.95922912657261, 33.08229021728039, 39.1675116866827, 27.30637215077877, 24.275894165039062, 16.86673253774643, 9.558540042489767, 7.115409839898348, 2.422200688160956, 0.9360621962696314, 0.038794689971837215, 0.08869798737578094, 0.07342136726947501, 0.05497576545167249, 0.045039402539259754, 0.0272673702420434, 0.015649395318177994, 0.038670740177622065, 0.04280950110114645, 0.0311112202325603, 0.05253063376585487, 0.11481179666589014, 0.04188330080069136, 0.025573416314728092, 0.007650180705240928, 0.09377424779813737, 0.016033269348554313, 0.009185736198560335, 0.05175518221221864, 0.018616349589137826, 0.03347832251165528, 0.033348331635352224, 0.08468169195111841, 0.049510816315887496, 0.022133218590170145, 0.04309303119953256, 0.041902207012753934, 0.030535634614352603, 0.032353601418435574, 0.03957837194320746, 0.01125083168517449, 0.0168571107860771, 0.0733276637038216, 0.0402871155529283, 0.08488698484143242, 0.03476612313534133, 0.03575491988158319, 0.04307455172238406, 0.059600087624858133, 0.021903544293309096, 0.06874793718452565, 0.029688725371670444, 0.027821646945085377, 0.0333218443847727, 0.026283941078872886, 0.01994398498936789, 0.05109153891680762, 0.021423294965643436, 0.04658993457269389, 0.04729899730591569, 0.04390516711282544, 0.03627192592830397, 0.02918370872066589, 0.049480139641673304, 0.030788079857302364, 0.051911393165937625, 0.03477901795122307, 0.04280181245121639, 0.01063960999090341, 0.049986840967903845, 0.03265941821155138, 0.06945540430024266, 0.16066079697338864, 0.14153670519590378, 0.10050958677311428, 0.12905330630019307, 0.07148162330850028, 0.2528767572948709, 0.13868187088519335, 0.11756877138395794, 0.16529714193893597, 0.18874976551160216, 0.14011054969159886, 0.18825288279913366, 0.057647044377517886, 0.10463779064593837, 0.12720008933683857, 0.10101768333697692, 0.11499714062665589, 0.17349883855786175, 0.13020742015214637, 0.09824182838201523, 0.1743283963878639, 0.09551062103128061, 0.2270535210845992, 0.2573986037168652, 0.12976361584151164, 0.17689949279883876, 0.10637924759066664, 0.09851643044385128, 0.2425540768308565, 0.19194776890799403, 0.21314545097993687, 0.1313462754478678, 0.26719842629972845, 0.10724168256274424, 0.22876005998114124, 0.17978827294427902, 0.14781992038479075, 0.2241060370579362, 0.16781410609837621, 0.0965062937757466, 0.13659622811246663, 0.08971662216936238, 0.13444066018564627, 0.19111585104838014, 0.07593731468659826, 0.170603527512867, 0.15545010392088443, 0.15861530438996851, 0.11034150724299252, 0.11443514929851517, 0.1643248987966217, 0.13500668137567118, 0.08693269264767878, 0.26598382741212845, 0.10879157634917647, 0.10065201975521632, 0.1493068429408595, 0.15077344549354166, 0.21416905074147508, 0.16484560444951057, 0.1527573398198001, 0.1137942231434863, 0.15021226310636848, 0.21047477319370955, 0.08354617631994188, 0.09348722218419425, 0.1537837300566025, 0.1232722653367091, 0.1193017752666492, 0.7254104653839022, 1.4288930199109018, 3.6366385594010353, 6.522196596488357, 14.680700339376926, 21.586998850107193, 30.95037281513214, 47.44832754135132, 50.89164197444916, 57.66900770366192, 60.90608440339565, 64.85909208655357, 65.95561444759369, 59.83652539551258, 58.6128618568182, 61.636477410793304, 44.44520428776741, 56.899545192718506, 53.198106810450554, 51.46058924496174, 58.000718504190445, 41.24020166695118, 54.97865326702595, 74.45711106061935, 56.79802604019642, 48.59591916203499, 46.75630107522011, 48.151103630661964, 47.84477546811104, 42.44452804327011, 47.13106356561184, 49.24199089407921, 57.58274093270302, 49.905355498194695, 50.63727602362633, 56.12483896315098, 40.04913277924061, 44.025683999061584, 32.76066027581692, 27.586312629282475, 18.46613321453333, 10.798600651323795, 7.6528221275657415, 2.836377276107669, 0.980530260130763, 0.21210752776823938, 0.1782294808072038, 0.127895912155509, 0.19244917872129008, 0.14045308053027838, 0.16307975311065093, 0.13068631320493296, 0.17036330915289, 0.15578185877529904, 0.203090270224493, 0.1390281569911167, 0.1474400595179759, 0.12803469377104193, 0.12502332567237318, 0.11720623224391602, 0.1643256557872519, 0.06500983581645414, 0.11690504645230249, 0.16231106623308733, 0.14150804345263168, 0.11885653118952177, 0.12913176615256816, 0.22569920547539368, 0.134145122137852, 0.10466476771398447, 0.16282026859698817, 0.1324856057181023, 0.18563007353805006, 0.16024924640078098, 0.1924449039506726, 0.1117873890325427, 0.1299934441340156, 0.2005489487783052, 0.1294869283447042, 0.2429733457393013, 0.11634478432824835, 0.07896563343820162, 0.12840400129789487, 0.1473359065130353, 0.14474972966127098, 0.1293011094094254, 0.11763788759708405, 0.08753406975301914, 0.1439631570247002, 0.10376862439443357, 0.08718689306988381, 0.1506159023847431, 0.21142438083188608, 0.12499941367423162, 0.15322759427363053, 0.13753163104411215, 0.09984288582927547, 0.11854475495056249, 0.09506391492323019, 0.1553893813979812, 0.1304654500563629, 0.11119127375422977, 0.12310173464356922, 0.14544430567184463, 0.13430501043330878, 0.19673441362101585, 0.1416538012563251], [0.03239582962123677, 0.02791430593788391, 0.06660437720711343, 0.01805788717319956, 0.056431094781146385, 0.06358397717121989, 0.07418833978590555, 0.003302643435745267, 0.057839709625113755, 0.027948316710535437, 0.010152044014830608, 0.049220870350836776, 0.04023035980935674, 0.033442836720496416, 0.07982857307069935, 0.012521234511950752, 0.017269036143261474, 0.04467781705898233, 0.03941435359593015, 0.03303193181636743, 0.04486202553380281, 0.024425627416349016, 0.027407155612308998, 0.054847867431817576, 0.06940904233488254, 0.030027296852495056, 0.03453690711467061, 0.017681785284366924, 0.06482619879534468, 0.061798933893442154, 0.048218874508165754, 0.036423743367777206, 0.03668609257147182, 0.03355484164785594, 0.031408450377057306, 0.06539489171700552, 0.07259436984895729, 0.040967828244902194, 0.019191142964700703, 0.030256292084231973, 0.01789130285033025, 0.03502192659652792, 0.0422884392173728, 0.025550723294145428, 0.03522144186717924, 0.020503488267422654, 0.06643521206569858, 0.002452951603117981, 0.01960401641554199, 0.031244691781466827, 0.038336922152666375, 0.02550760080339387, 0.051547117400332354, 0.046392979711527005, 0.030976021334936377, 0.08255682667368092, 0.03230018162867054, 0.009962718431779649, 0.048996140612871386, 0.03876150854921434, 0.05733613645134028, 0.026034870752482675, 0.010844254429684952, 0.05707294862077106, 0.02525454699934926, 0.04540067631751299, 0.023510776409239043, 0.04945811269863043, 0.028083144534321036, 0.03768240727367811, 0.01694328155281255, 0.0469335971865803, 0.6403846840839833, 2.180701559409499, 5.7695467583835125, 8.350586760789156, 14.118272569030523, 23.904410898685455, 27.30688702315092, 33.54149177670479, 42.034252658486366, 46.75953850150108, 49.52983684837818, 48.21693129837513, 54.6075651794672, 50.33467926084995, 49.44766245782375, 52.82054387032986, 49.885410368442535, 50.29798083007336, 47.71160401403904, 44.64334085583687, 42.764558270573616, 39.72998030483723, 38.58699403703213, 44.73734401166439, 39.48892883956432, 41.07081055641174, 39.31399382650852, 36.98774345219135, 39.19076643884182, 35.000678077340126, 38.37510600686073, 23.75103782862425, 27.580295652151108, 19.479193054139614, 21.257765516638756, 11.678853817284107, 4.985222769901156, 5.442393338307738, 0.9210011700633913, 0.3642734501045197, 0.03799870690272655, 0.07119581481674686, 0.0576527069642907, 0.0387947159470059, 0.04054413984704297, 0.010833636151801329, 0.03022490109287901, 0.020649281323130708, 0.02916503814049065, 0.05228796260780655, 0.0662249987362884, 0.029800756274198648, 0.02801890608679969, 0.04988485874491744, 0.054719453619327396, 0.027113176074635703, 0.06005616334732622, 0.058009127096738666, 0.027029324519389775, 0.03365984812262468, 0.04922952379274648, 0.02799020723614376, 0.07167129399022087, 0.02627715228300076, 0.02951175283669727, 0.009825795896176714, 0.034722462587524205, 0.012315109488554299, 0.014160431855998468, 0.11383023957023397, 0.04154973881668411, 0.058931201056111604, 0.03848231259325985, 0.026633563138602767, 0.07539906466263346, 0.042815620108740404, 0.0507527485024184, 0.012102984201192157, 0.01812903501559049, 0.10106689514941536, 0.04032155491586309, 0.06189972125866916, 0.027302204798616003, 0.0769594449957367, 0.06877056526718661, 0.012784042919520289, 0.057740295233088546, 0.04687193955760449, 0.12952228426001966, 0.05135907202202361, 0.052114099671598524, 0.031254684799932875, 0.07875288196373731, 0.05940437957178801, 0.06756384056643583, 0.13214243663242087, 0.05709052267775405, 0.011815664511232171, 0.04785944867762737, 0.031808813073439524, 0.020459000224946067, 0.030024712323211133, 0.021175189431232866, 0.026772979290399235, 0.026349456020398065, 0.04203639844490681, 0.08391782903345302, 0.02057466950645903, 0.019899598992196843, 0.12086349888704717, 0.05674183943483513, 0.06910521449754015, 0.06711657042615116, 0.07961453025927767, 0.027694324089679867, 0.061577224696520716, 0.04868729585723486, 0.04145540813624393, 0.11475574225187302, 0.023493688458984252, 0.04375086718937382, 0.018015469722740818, 0.05515299031685572, 0.03959246532758698, 0.015003989374235971, 0.038324012493831106, 0.013284342294355156, 0.01027085443638498, 0.058185620946460404, 0.03335872541356366, 0.0725477778178174, 0.015251793411152903, 0.011509119485708652, 0.04062028419866692, 0.05134484876180068, 0.03170100870192982, 0.01567242044984596, 0.01639654321479611, 0.02317093028977979, 0.030175839565345086, 0.046609790733782575, 0.02871147087716963, 0.015980274438334163, 0.04267891650670208, 0.06072022224543616, 0.017458157635701355, 0.03365697601111606, 0.10063331763376482, 0.035121782566420734, 0.042340500876889564, 0.03243210579967126, 0.017310060211457312, 0.027644609472190496, 0.05807158624520525, 0.010628666095726658, 0.04155679293035064, 0.01415829354300513, 0.03981394816946704, 0.04679287114413455, 0.031266997029888444, 0.0663957891811151, 0.02299523610417964, 0.04635727498680353, 0.03833108887192793, 0.015714099463366438, 0.033408994786441326, 0.04233595151163172, 0.012711725266854046, 0.039125283365137875, 0.036636513395933434, 0.046934094425523654, 0.01916628472827142, 0.02629570783028612, 0.11182491944055073, 0.08399187310715206, 0.16886755503946915, 1.1494146916083992, 3.382592028938234, 7.457520207390189, 11.19265565648675, 18.533598594367504, 28.76490108668804, 32.83176966011524, 40.1910475641489, 49.287744238972664, 53.62646922469139, 53.66069778800011, 53.87587644159794, 58.17207030951977, 54.73209589719772, 57.25375838577747, 55.981286466121674, 53.858724161982536, 54.93780925869942, 47.128050327301025, 47.47046895325184, 49.355369210243225, 45.31484842300415, 45.68410120904446, 49.483456537127495, 44.570593759417534, 46.22435241937637, 44.29839536547661, 42.56559334695339, 44.02359411120415, 43.10898318886757, 45.05664847791195, 29.826056845486164, 35.88765688240528, 24.238097593188286, 26.44183874130249, 16.03989690542221, 6.858979649841785, 7.774766609072685, 1.6081143217161298, 0.6103258626535535, 0.1179022628639359, 0.030845136170682963, 0.07365780809777789, 0.013652221186930547, 0.0425349213037407, 0.038973113405518234, 0.02517533015634399, 0.02158152641641209, 0.038290088923531584, 0.019464418437564746, 0.067865991150029, 0.03076437751587946, 0.007057265011098934, 0.02358680201723473, 0.052719135564984754, 0.016636609434499405, 0.012299910304136574, 0.01965905037650373, 0.029539036040659994, 0.021851592100574635, 0.025385667795490008, 0.01813946961192414, 0.04109622721443884, 0.01825576415285468, 0.06789252292946912, 0.008451897792838281, 0.02383217459282605, 0.028923491336172447, 0.016420971005572937, 0.015366719617304625, 0.07939091374282725, 0.05921018178923987, 0.03873981928336434, 0.03765858804399613, 0.02055544788163388, 0.04150792992732022, 0.013987243346491596, 0.04720971322967671, 0.030754766703466885, 0.06428895809222013, 0.062460810877382755, 0.042341591833974235, 0.006678230711258948, 0.03625345016189385, 0.05264295781671535, 0.025331420511065517, 0.03826554981060326, 0.08326086506713182, 0.11941035147174262, 0.03953756495320704, 0.060323807774693705, 0.0035540352928364882, 0.018827917338057887, 0.06716946329106577, 0.0297095611676923, 0.04595422942657024, 0.007382859575955081, 0.027088837341580074, 0.06701424310449511, 0.011890380228578579, 0.030265463174146134, 0.07376993176876567, 0.044893926751683466, 0.02378818935540039, 0.13330771238543093, 0.16606603661784902, 0.22068598307669163, 0.0955133224488236, 0.12793349451385438, 0.1958321698475629, 0.13396869879215956, 0.12240193391335197, 0.21228347613941878, 0.25641234882641584, 0.10101798019604757, 0.14672575722215697, 0.15684149722801521, 0.14613698178436607, 0.22768446535337716, 0.12678215629421175, 0.09395772896823473, 0.1393059577094391, 0.13592511881142855, 0.11179154505953193, 0.16983246576273814, 0.20641651673940942, 0.11654604735667817, 0.07360458868788555, 0.2745563752250746, 0.13607559667434543, 0.12187858621473424, 0.11411114988732152, 0.07482064960640855, 0.1215308158134576, 0.14905672433087602, 0.16461029910715297, 0.09971412320737727, 0.13974554662127048, 0.08252219064161181, 0.1580720374477096, 0.16039417299907655, 0.1291699125431478, 0.16209204361075535, 0.08487093960866332, 0.14896940323524177, 0.11676608672132716, 0.10796872011269443, 0.21276719315210357, 0.1540318300249055, 0.10768750551505946, 0.19560266810003668, 0.09510025047347881, 0.15650756045943126, 0.15448989841388538, 0.11176744010299444, 0.16077865002444014, 0.17034710064763203, 0.10928629941190593, 0.11221071748877876, 0.13564331049565226, 0.08350932868779637, 0.10443919192766771, 0.13998199487105012, 0.17909509217133746, 0.2051376923918724, 0.15645192906958982, 0.1275589771103114, 0.2196346121490933, 0.14830666535999626, 0.133801240590401, 0.12679904757533222, 0.20094795705517754, 0.1382463934714906, 0.15574212418869138, 0.1234186688088812, 0.2525161032099277, 1.0936005553230643, 2.8985198540613055, 7.380126910284162, 12.35744135454297, 19.797891452908516, 30.304388478398323, 36.79368406534195, 45.977190881967545, 57.49864764511585, 62.38238498568535, 62.979481145739555, 62.172993421554565, 66.7242144048214, 65.08625909686089, 64.29000422358513, 67.11804047226906, 61.47232621908188, 64.31572884321213, 58.331239968538284, 54.35496613383293, 57.48434521257877, 51.097195744514465, 55.85701793432236, 60.82155413925648, 55.807107612490654, 55.66851004958153, 52.76336073875427, 50.3539252281189, 52.10914984345436, 50.07179796695709, 51.41735516488552, 36.444969177246094, 39.850460439920425, 29.614989571273327, 27.679035253822803, 18.87116488069296, 9.398948606103659, 8.243998680263758, 1.9285425776615739, 0.8061497798189521, 0.24877480318536982, 0.1812172931386158, 0.2992929291212931, 0.09477492261794396, 0.163114485621918, 0.18503300088923424, 0.12899255409138277, 0.12749598361551762, 0.17566064052516595, 0.15470467595150694, 0.13309793692314997, 0.1431111863348633, 0.1360343035776168, 0.12975775287486613, 0.21138043084647506, 0.10073655037558638, 0.11857588804559782, 0.11985087548964657, 0.10771164015750401, 0.13800233078654855, 0.08303764188895002, 0.07955278357258067, 0.1429629497579299, 0.13351818546652794, 0.1829264740808867, 0.09851463444647379, 0.13407681486569345, 0.1406355746439658, 0.1586126326583326, 0.1660361874382943, 0.18114052538294345, 0.2145281166303903, 0.15065014507854357, 0.0908056199841667, 0.14285190962255, 0.11010776783223264, 0.17327925190329552, 0.1005346342572011, 0.11421280927606858, 0.15507943084230646, 0.08155899427947588, 0.09931385327945463, 0.08577895729104057, 0.12104925102903508, 0.1613227481720969, 0.16653526690788567, 0.13498806831194088, 0.18715506826993078, 0.24537889868952334, 0.19146445265505463, 0.12276215013116598, 0.1705809513805434, 0.12833734159357846, 0.17124391190009192, 0.23216516710817814, 0.24614727386506274, 0.11022705322830006, 0.13124949939083308, 0.1125152874737978, 0.13163701922167093, 0.10889858662267216, 0.18619542679516599, 0.11728632482117973, 0.08922363573219627], [0.048646058421581984, 0.014785816510993754, 0.012204285503685242, 0.06552219230798073, 0.04249896795954555, 0.021353226948122028, 0.07932881824672222, 0.041039564239326864, 0.042795262997969985, 0.04756626323796809, 0.042423265185789205, 0.022344283534039278, 0.06281647772993892, 0.06627665963605978, 0.001078874572613131, 0.05571272180532105, 0.034918204037239775, 0.03823099912551697, 0.014761906368221389, 0.014988920993346255, 0.08492821114487015, 0.06691016431432217, 0.02692833306355169, 0.04750502863316797, 0.03473117540124804, 0.07251299335621297, 0.015314114334614715, 0.035654741077451035, 0.05908874787564855, 0.06968495799810626, 0.06357036618283018, 0.035894903776352294, 0.03192322255927138, 0.026145920164708514, 0.03207966357877012, 0.07941714124171995, 0.024798482409096323, 0.013477072479872731, 0.0676851742900908, 0.03426451665291097, 0.04434801034221891, 0.023994012881303206, 0.06310161086730659, 0.02215177042671712, 0.03629757455200888, 0.06671990733593702, 0.018650514357432257, 0.03820058220298961, 0.04729106374725234, 0.07030958659015596, 0.09157065549516119, 0.056489598282496445, 0.0519860717759002, 0.013604358227894409, 0.0486107767210342, 0.05120535468449816, 0.05238210775132757, 0.007408821293211076, 0.028392874301061966, 0.024324606274603866, 0.024004937295103446, 0.038954800911596976, 0.013201263500377536, 0.08944664368755184, 0.00306581576296594, 0.06294486185652204, 0.036727252081618644, 0.03728997442522086, 0.020955957152182236, 0.0508693399024196, 0.03932405277737416, 0.05293449939927086, 0.013525015219784109, 0.14625956973759457, 0.5954633164219558, 1.5183875989168882, 4.0927366353571415, 8.125611282885075, 12.480541449040174, 16.92079033702612, 23.726612739264965, 30.530235059559345, 41.79518088698387, 39.16068345308304, 47.004815340042114, 46.96184724569321, 46.08146108686924, 48.97291213274002, 51.35812394320965, 50.378449112176895, 52.34596833586693, 51.89878173172474, 42.03581057488918, 41.893789395689964, 42.96871371567249, 42.158711180090904, 43.505016937851906, 44.168788120150566, 35.507076904177666, 35.69692611694336, 35.17112173140049, 30.203099213540554, 21.306482702493668, 18.037825897336006, 11.497081071138382, 8.689357582479715, 6.56301305629313, 3.9101369585841894, 2.1990251261740923, 0.6164776731748134, 0.07484170433599502, 0.0929414393613115, 0.04641150742827449, 0.007593253340019146, 0.021788116209791042, 0.057927223679143935, 0.03408025993849151, 0.014266605357988738, 0.03175082536472473, 0.05327403196133673, 0.034911238981294446, 0.015789594435773324, 0.047873029980110005, 0.02602912652946543, 0.03309721483674366, 0.05162020039279014, 0.030619155913882423, 0.04693039481935557, 0.010074065630760742, 0.014422530584852211, 0.020465633169806097, 0.06508888938697055, 0.019339169884915464, 0.01855640446592588, 0.047173871207633056, 0.05584621561865788, 0.05701804824639112, 0.035134718200424686, 0.03435991602600552, 0.03164356647175737, 0.020038031798321754, 0.07098472575307824, 0.0584163472376531, 0.051975418246001936, 0.03311408385343384, 0.059400538957561366, 0.026642968005035073, 0.05980319117952604, 0.0004623280267423979, 0.08360724765225314, 0.11430701008066535, 0.0691886838467326, 0.03074867923714919, 0.03801419923547655, 0.019015485886484385, 0.03455636622675229, 0.0184320631888113, 0.02751233463641256, 0.035936170897912234, 0.016903710238693748, 0.04096775403013453, 0.038294196710921824, 0.02784381118544843, 0.05476053149322979, 0.07723795817582868, 0.07176270431955345, 0.0627144992176909, 0.05499098690052051, 0.07086938858265057, 0.03895967311109416, 0.06387475805240683, 0.11231653290451504, 0.09105805409490131, 0.07954996341140941, 0.07942343465401791, 0.028362555713101756, 0.040741194898146205, 0.020139338666922413, 0.03125791685306467, 0.004597914239639067, 0.026896652634604834, 0.015740126582386438, 0.021193518623476848, 0.05518230143934488, 0.0067414570548862685, 0.019907599344151095, 0.03826721222139895, 0.15592668147291988, 0.016153282049344853, 0.060402134040487, 0.026857738121179864, 0.05245694221230224, 0.0844961401890032, 0.08029318720218726, 0.03704191527504008, 0.010600980276649352, 0.07043087578495033, 0.06776033900678158, 0.07675321699935012, 0.04690610061516054, 0.05880332158994861, 0.03569460553990211, 0.022284529513854068, 0.06228570855455473, 0.03632940897659864, 0.0428796266351128, 0.038151908447616734, 0.01868910974735627, 0.05681909329723567, 0.030266155226854607, 0.039290351851377636, 0.032695430927560665, 0.04934405573294498, 0.011869192840094911, 0.04358736834547017, 0.026374119443062227, 0.04753904497192707, 0.09323901089373976, 0.045629061132785864, 0.035330437385709956, 0.06884960399474949, 0.02795099400827894, 0.0313615985942306, 0.043264723353786394, 0.02286196864588419, 0.09551892566378228, 0.06904107809532434, 0.03604007528338116, 0.03911356856406201, 0.03791060655203182, 0.07125701973563991, 0.04367542787804268, 0.03370558668393642, 0.03600476018618792, 0.021300100306689274, 0.022278868782450445, 0.05079712893348187, 0.07997332155355252, 0.027723629646061454, 0.016722251421015244, 0.06545910975546576, 0.07366387144429609, 0.054480010803672485, 0.041139657696476206, 0.04839322355110198, 0.03611393753089942, 0.07447890544426627, 0.01123473728512181, 0.08438265838776715, 0.2125732699641958, 0.8481518947519362, 2.4635567190125585, 5.55780217051506, 10.59959962964058, 15.97800962626934, 21.59673772752285, 29.437702484428883, 35.65961591899395, 47.473303601145744, 45.85707172751427, 52.6101453602314, 51.90933756530285, 52.342947497963905, 55.56332789361477, 57.344630509614944, 55.895080491900444, 59.073606133461, 54.26240310072899, 47.74951457977295, 46.93065091967583, 48.047319799661636, 48.71826499700546, 49.67481806874275, 51.33885137736797, 42.81614430248737, 42.60158881545067, 41.75202660262585, 35.63374310731888, 27.819299027323723, 22.13434047996998, 15.824799947440624, 12.443904764950275, 8.777644895017147, 5.429269792512059, 2.9742980003356934, 1.0363293159753084, 0.04634792392607778, 0.09844666114076972, 0.011872256982314866, 0.0068669519077957375, 0.03478071004792582, 0.0857058260589838, 0.05103733987198211, 0.01136025857704226, 0.03820890167844482, 0.07573644499643706, 0.008168860294972546, 0.0651017359632533, 0.024404220166616142, 0.04877840561675839, 0.03138720268907491, 0.027543573487491813, 0.020698749176517595, 0.026712869039329235, 0.04295693615858909, 0.0617153532220982, 0.02203261490649311, 0.029814716071996372, 0.07644481753231958, 0.021448527986649424, 0.0710877135861665, 0.08420189347816631, 0.1371105809812434, 0.13163562398403883, 0.02253547190775862, 0.06042146327672526, 0.027253501357336063, 0.05149923774297349, 0.06406420608982444, 0.07622350167366676, 0.02080609898257535, 0.02682318001461681, 0.06842597125796601, 0.04961272803484462, 0.04690495028626174, 0.05254345065623056, 0.09333289257483557, 0.032001953295548446, 0.006156533827379462, 0.025965210916183423, 0.05597665178356692, 0.04055123106809333, 0.03855954419123009, 0.0305778850815841, 0.039522803635918535, 0.01269168171347701, 0.04942134299199097, 0.025140337893390097, 0.0498051483737072, 0.05560480982239824, 0.02710772128921235, 0.01174098961200798, 0.03891274340276141, 0.07193027384346351, 0.021607342023344245, 0.014078804888413288, 0.03671073558507487, 0.05293026544677559, 0.01938262448675232, 0.03072365216212347, 0.10916253886534832, 0.06285690993536264, 0.1336395414546132, 0.18294719484401867, 0.10970284463837743, 0.23779526265570894, 0.17626497137825936, 0.11256637691985816, 0.20149564719758928, 0.1343301692395471, 0.1895205897744745, 0.14014829532243311, 0.1671567265293561, 0.17667901556706056, 0.20138367195613682, 0.12451838323613629, 0.06708599394187331, 0.14424857217818499, 0.2424564547254704, 0.23815262160496786, 0.19586325099226087, 0.12348058618954383, 0.22069873317377642, 0.15441574301803485, 0.1948462860309519, 0.11995010063401423, 0.11559425038285553, 0.1469168157200329, 0.16104414593428373, 0.13904831372201443, 0.28393341111950576, 0.1130667254619766, 0.13382037315750495, 0.12416299839969724, 0.20688340184278786, 0.09786810507648624, 0.08496183043462224, 0.13804049202008173, 0.06533188337925822, 0.0960499991197139, 0.22783380030887201, 0.08555931868613698, 0.18738071084953845, 0.15451633371412754, 0.12686909147305414, 0.10613722581183538, 0.16507007443578914, 0.1846731037949212, 0.05377688896260224, 0.11064259655540809, 0.12066311901435256, 0.1887170219561085, 0.2252346952445805, 0.09467969022807665, 0.11393742795917206, 0.10762066769530065, 0.21335835830541328, 0.12259112219908275, 0.09701842020149343, 0.13060752680758014, 0.10635045226081274, 0.21022404602263123, 0.10765937811811455, 0.143149585055653, 0.12486952298786491, 0.11937961171497591, 0.1124791671463754, 0.13463713636156172, 0.1096764909743797, 0.10738416749518365, 0.16271819360554218, 0.0941149826394394, 0.1336176777840592, 0.11308315661153756, 0.140216528379824, 0.32165924145374447, 0.8466437319293618, 2.554544499143958, 5.516014387831092, 10.698099844157696, 17.863173969089985, 23.911406323313713, 33.69788758456707, 41.107847169041634, 52.37519256770611, 54.660416543483734, 59.34624910354614, 59.96938906610012, 59.114275351166725, 64.11686271429062, 64.89402741193771, 64.68811646103859, 66.26749411225319, 64.87777948379517, 54.61134597659111, 54.29243288934231, 58.05146098136902, 55.99184609949589, 57.12753675878048, 58.89862172305584, 49.00845542550087, 48.213215097784996, 45.475758388638496, 40.86149498820305, 30.741131342947483, 25.190911665558815, 18.719587214291096, 14.270540848374367, 9.764307551085949, 6.28157545812428, 3.099612663500011, 1.14130272064358, 0.24866683554137126, 0.20712240308057517, 0.1371617297991179, 0.12328564625931904, 0.1402369374409318, 0.19662815291667357, 0.14705991663504392, 0.11732496102922596, 0.08390806237002835, 0.1359220760059543, 0.08476673465338536, 0.1659929647576064, 0.1131698617246002, 0.16302039613947272, 0.20468185044592246, 0.15040640893857926, 0.15281424770364538, 0.13463111012242734, 0.16423851280706003, 0.0982080829271581, 0.09703260264359415, 0.06152483278128784, 0.1660666154930368, 0.12239778530783951, 0.16397323954151943, 0.15055955853313208, 0.27913753408938646, 0.22296336712315679, 0.15240220731357113, 0.1197676733136177, 0.08880401059286669, 0.14346533920615911, 0.2016001267475076, 0.26099234994035214, 0.0934916824917309, 0.12592298677191138, 0.1498958410229534, 0.10734312672866508, 0.14638466614997014, 0.23576735897222534, 0.27637356834020466, 0.11141425944515504, 0.16350776451872662, 0.07894111287896521, 0.15723240125225857, 0.18794037925545126, 0.2010569191770628, 0.051796085681417026, 0.1457007325370796, 0.1048659862135537, 0.08873355851392262, 0.14301170886028558, 0.13991854124469683, 0.135573563457001, 0.19526436750311404, 0.1514139783103019, 0.20918273861752823, 0.19044241140363738, 0.21705426857806742, 0.11881701182574034, 0.12728506524581462, 0.13408119353698567, 0.18920881353551522, 0.21633285650750622, 0.207995985110756, 0.11703513751854189], [0.11448082106653601, 0.07940716677694581, 0.021005254311603494, 0.03785262997553218, 0.08399833721341565, 0.05007061088690534, 0.026366701677034143, 0.041457133629592136, 0.06074916600482538, 0.06294927763519809, 0.04650745227991138, 0.014908372922946, 0.07551406786660664, 0.06527743200422265, 0.023215286601043772, 0.03769650436879601, 0.016886611156223807, 0.024764000372670125, 0.06129205445176922, 0.057724480066099204, 0.026672774511098396, 0.06646361405728385, 0.03685749528813176, 0.09428862293134443, 0.008781640499364585, 0.0183235500662704, 0.06158229356515221, 0.021352193507482298, 0.07193219600594603, 0.008426031163253356, 0.02892824479204137, 0.0025518393022139207, 0.03742131601029541, 0.03829076427791733, 0.02324988552572904, 0.02612109532492468, 0.024065301731752697, 0.03369095524249133, 0.034847558999899775, 0.014957185831008246, 0.036093034941586666, 0.028014434647047892, 0.039539947247249074, 0.020357509674795438, 0.04924841516185552, 0.041663970187073573, 0.032727150319260545, 0.036524946335703135, 0.03407460106245708, 0.03493847951176576, 0.13181329413782805, 0.010881944399443455, 0.005819105717819184, 0.01178961327241268, 0.07696156753809191, 0.03763637927477248, 0.052608993428293616, 0.015241396849887678, 0.05753279445343651, 0.08264802178018726, 0.015945558625389822, 0.008717261043784674, 0.0459878784022294, 0.032188224940910004, 0.11180581655935384, 0.06878688509459607, 0.06939756131032482, 0.023535994587291498, 0.006521107379739988, 0.01610660652659135, 0.04604201436450239, 0.03762505039048847, 0.039694217484793626, 0.023229463477036916, 0.05896171816857532, 0.10602628215565346, 0.3174260607920587, 1.0737881809473038, 2.4049928365275264, 5.641252817586064, 9.88963907584548, 13.001914322376251, 18.027159869670868, 19.904798716306686, 25.172045677900314, 28.410712592303753, 37.39505119621754, 35.88735669851303, 41.698206290602684, 42.49826855957508, 38.95007215440273, 40.4426396638155, 43.38352605700493, 42.63000749051571, 33.42107243835926, 31.35330319404602, 28.606371693313122, 26.09766460955143, 26.189045906066895, 25.074290223419666, 20.20097952336073, 17.22988475114107, 12.20266330987215, 8.07350942865014, 3.875070777721703, 1.1099053616635501, 1.502117346972227, 0.3508929134113714, 0.16179494705284014, 0.04914724930131342, 0.05527013090613764, 0.025622641114750877, 0.08611675322754309, 0.05279396260448266, 0.05420014320407063, 0.03337730508064851, 0.060764142544940114, 0.01802451464754995, 0.07555602889624424, 0.05250303329376038, 0.056450535339536145, 0.03216119221178815, 0.07950263665406965, 0.019003863853868097, 0.01313924685746315, 0.04284167320292909, 0.06395990465534851, 0.010641206536092795, 0.014836719492450356, 0.027694611671904568, 0.016618974150333088, 0.016020936709537636, 0.05327927523467224, 0.013300617592904018, 0.03628254977229517, 0.02238294757262338, 0.022482955682789907, 0.018992681543750223, 0.0581695089204004, 0.045136649860069156, 0.04032318764075171, 0.026485129892535042, 0.044676425532088615, 0.030318203898787033, 0.019739167073566932, 0.009822419124247972, 0.04253967847034801, 0.03156815313559491, 0.06578295331564732, 0.042871496407315135, 0.054631282764603384, 0.0029450929196173092, 0.04679334982938599, 0.03864001526380889, 0.03815587151621003, 0.044652175856754184, 0.07114243955584243, 0.06131163601821754, 0.021062447922304273, 0.021472469670698047, 0.03767948321183212, 0.09988763733417727, 0.1248909265268594, 0.03611334010201972, 0.0704731336736586, 0.014511654171656119, 0.011425031370890792, 0.020376684915390797, 0.027673903896356933, 0.09566486900439486, 0.023776383641234133, 0.023789905571902636, 0.018541713652666658, 0.023597075196448714, 0.03412191668758169, 0.017657396456343122, 0.02436299571854761, 0.07414230436552316, 0.011837263791676378, 0.03613977169152349, 0.03658671899756882, 0.04927777081320528, 0.04459459632926155, 0.05986361313262023, 0.04322945649619214, 0.04228130717820022, 0.02379517667577602, 0.10282651986926794, 0.0326557186053833, 0.10812163221999072, 0.03142130437481683, 0.013589537538791774, 0.060832561139250174, 0.04640096893126611, 0.07811261632014066, 0.02439013791445177, 0.02348834870645078, 0.19174743356416002, 0.13646887557115406, 0.034165911201853305, 0.012442648494470632, 0.012735360814986052, 0.09498737723333761, 0.037707970550400205, 0.07908012456027791, 0.014696739308419637, 0.03312182816443965, 0.028323793339950498, 0.01307119562625303, 0.03938605179428123, 0.03151657016132958, 0.03044368808332365, 0.035298922084621154, 0.01551763163661235, 0.04715261980891228, 0.07797573460265994, 0.04990958339476492, 0.040225027478300035, 0.014772186968912138, 0.11661383512546308, 0.011628129359451123, 0.045050501357764006, 0.025489403342362493, 0.02652176972333109, 0.07701783717493527, 0.027027719625039026, 0.04255661799106747, 0.01404935554091935, 0.02219428621174302, 0.024168180098058656, 0.08120976184727624, 0.050105421323678456, 0.017914971795107704, 0.021536620915867388, 0.016244571779679973, 0.017612875017221086, 0.026818550868483726, 0.027307427662890404, 0.013570573810284259, 0.02789835532894358, 0.02635680699313525, 0.06690203037578613, 0.036512919832603075, 0.05734697180741932, 0.02764189321169397, 0.055205656826728955, 0.013744881107413676, 0.0665954417490866, 0.009450357301830081, 0.007372075242528808, 0.037332391875679605, 0.05861423349415418, 0.7626821903977543, 1.5088675660081208, 3.63970167003572, 7.946452796459198, 12.424544803798199, 16.271806061267853, 21.291534304618835, 23.87502707540989, 30.08408959954977, 33.28666605055332, 41.49471960961819, 42.84671366214752, 47.22293883562088, 48.875527158379555, 44.71207156777382, 46.89621336758137, 49.84132133424282, 47.721529081463814, 39.573755487799644, 37.6327246427536, 34.93808023631573, 32.17263042926788, 31.1436228454113, 30.32684527337551, 24.402455873787403, 21.909048669040203, 13.895513322204351, 10.968613028526306, 5.602316306903958, 2.0670389709994197, 2.5285066338256, 0.58537254226394, 0.12956580379977822, 0.08439031735179015, 0.01204327378218295, 0.011475184783193981, 0.07372355496045202, 0.056237245808006264, 0.03990432320279069, 0.04065053413796704, 0.03891907021170482, 0.04610468131431844, 0.027791879401775077, 0.031600978327332996, 0.02874944286304526, 0.0239848955970956, 0.048656147919245996, 0.023264403789653443, 0.041637805770733394, 0.047008413093863055, 0.05799743827083148, 0.02869483007089002, 0.042499120099819265, 0.09939839132130146, 0.01848968538979534, 0.02333221196749946, 0.020386266041896306, 0.029578492321888916, 0.08649635434267111, 0.05277777265291661, 0.040308626703335904, 0.05424308015790302, 0.12025501200696453, 0.00689876592332439, 0.03281472745584324, 0.01695264374575345, 0.06392192153725773, 0.03898082060914021, 0.039293335285037756, 0.06217533635208383, 0.049860527433338575, 0.04027750845125411, 0.006408035151252989, 0.1446006025071256, 0.033138096041511744, 0.04794074353412725, 0.06187661078001838, 0.017384952188876923, 0.02278387615660904, 0.08541956485714763, 0.036842296103714034, 0.03390433754248079, 0.042497650647419505, 0.020834970382566098, 0.01622577317903051, 0.02014919438806828, 0.1377274392871186, 0.09080018746317364, 0.01226415919518331, 0.023829334022593684, 0.044860749039798975, 0.0461843434459297, 0.03443334782787133, 0.059072298172395676, 0.025376528246852104, 0.060608083731494844, 0.0245526459912071, 0.0074062353724002605, 0.022433790254581254, 0.045766781477141194, 0.1978010727907531, 0.21577194129349664, 0.1014730948372744, 0.14271793712396175, 0.15109112922800705, 0.1270747257512994, 0.14465262705925852, 0.18074445601087064, 0.16210083063924685, 0.15138926479266956, 0.09985500510083511, 0.17086934996768832, 0.1877675627474673, 0.15436937363119796, 0.0641943713708315, 0.20294768881285563, 0.15269983821781352, 0.14823933772277087, 0.117068311519688, 0.13553946919273585, 0.0924171788210515, 0.2535098389489576, 0.3588453819975257, 0.26914300164207816, 0.10169702305574901, 0.12174096977105364, 0.2347245969576761, 0.06851149635622278, 0.1460897663491778, 0.0650707958266139, 0.10865211195778102, 0.18110865756170824, 0.13699205999728292, 0.15673018991947174, 0.14155359647702426, 0.13737708621192724, 0.12575414817547426, 0.07967696714331396, 0.18239631346659735, 0.16136819729581475, 0.10355520498706028, 0.11267767680692486, 0.1153375934518408, 0.2609865611884743, 0.08558746834751219, 0.1373608480207622, 0.14163805288262665, 0.09900413278955966, 0.1717511549941264, 0.14899981644703075, 0.34543070651125163, 0.15856510552112013, 0.09746655123308301, 0.12706348963547498, 0.264912789571099, 0.1503286318620667, 0.14224836544599384, 0.12264900229638442, 0.19002593297045678, 0.1317077162093483, 0.10561024901107885, 0.12839015282224864, 0.08933178149163723, 0.14239844254916534, 0.2087434465647675, 0.14940335182473063, 0.1760043142712675, 0.09660034615080804, 0.1466686266940087, 0.11087173465057276, 0.1454104934236966, 0.12154309093602933, 0.18188170826761052, 0.11619025433901697, 0.0686729654262308, 0.1641800464130938, 0.69255540962331, 1.5976604889146984, 3.792676948942244, 8.71529309079051, 13.405085988342762, 17.72210653871298, 23.23759227991104, 27.17361107468605, 34.58117298781872, 39.63645592331886, 46.59699462354183, 48.21250833570957, 52.456219419837, 55.716254487633705, 52.03816965222359, 53.15666243433952, 55.692870542407036, 52.53216594457626, 44.98471073806286, 42.27255307137966, 39.52622763812542, 36.85060881078243, 35.022587701678276, 34.632827416062355, 28.257406018674374, 24.98471572995186, 16.322692930698395, 12.357025276869535, 6.474117301404476, 2.666848422959447, 2.5757858343422413, 0.7879665086511523, 0.3223225730471313, 0.22029016603482887, 0.1190340677567292, 0.08217557799071074, 0.21835336840013042, 0.1297922182129696, 0.13834769662935287, 0.15385093895019963, 0.17107240157201886, 0.09015723524498753, 0.20329119928646833, 0.14381866087205708, 0.21571277728071436, 0.12243874443811364, 0.24148186639649794, 0.07342276250710711, 0.14452905947109684, 0.09831800241954625, 0.14240550779504701, 0.14499496493954211, 0.08478472431306727, 0.19474801083561033, 0.14259684830904007, 0.20420421904418617, 0.14334816893097013, 0.10943314075120725, 0.23257447639480233, 0.1337362136109732, 0.09161352936644107, 0.1063793218054343, 0.19771076826145872, 0.0810254568932578, 0.11727975681424141, 0.15255424368660897, 0.13689372543012723, 0.16233834758168086, 0.09986851961002685, 0.09965469944290817, 0.17151402396848425, 0.09312552909250371, 0.10917531122686341, 0.24679896858287975, 0.13406569749349728, 0.09507241993560456, 0.15697667200583965, 0.07683768824790604, 0.1315156335476786, 0.20042863179696724, 0.14745246822712943, 0.12539806572021917, 0.14589753525797278, 0.12454179057385772, 0.1466476684436202, 0.15370087668998167, 0.33856984809972346, 0.1441518109641038, 0.15202112932456657, 0.12991632014745846, 0.1177250305772759, 0.1202081453811843, 0.14998887665569782, 0.1428483473137021, 0.06737447416526265, 0.13298717880388722, 0.18598841212224215, 0.0867186053073965, 0.1872686910792254, 0.11870894028106704], [0.022525391686940566, 0.06906876020366326, 0.02886334954382619, 0.03656774228147697, 0.054903305863263085, 0.025453310845477972, 0.02208150202932302, 0.015610360205755569, 0.042909527765004896, 0.005233483943811734, 0.04869639087701216, 0.0945738896552939, 0.05982039416267071, 0.04051830939715728, 0.06026605755323544, 0.027357355647836812, 0.01973251928575337, 0.019638335179479327, 0.04647035231755581, 0.038825604133307934, 0.023723492631688714, 0.050747304849210195, 0.025943198816094082, 0.04652157906093635, 0.005995067540425225, 0.04477669339394197, 0.06543134601088241, 0.04065990375238471, 0.05822745952173136, 0.05107880737341475, 0.02907318437792128, 0.03855459035548847, 0.06991497182752937, 0.06506346340756863, 0.011447363522165688, 0.14548570266924798, 0.08374150958843529, 0.04600202744768467, 0.03250036112149246, 0.03954248910304159, 0.006389744921762031, 0.060065291763748974, 0.03601145806896966, 0.03244834399083629, 0.0350872207491193, 0.10675942758098245, 0.06738103475072421, 0.03859755328448955, 0.01157003125626943, 0.13555401528719813, 0.0255378266228945, 0.013995582303323317, 0.02724476627918193, 0.0232260588745703, 0.03085827218455961, 0.02907701942604035, 0.03904873083229177, 0.011391178304620553, 0.03166186041198671, 0.005338775681593688, 0.027814895256597083, 0.04212611667753663, 0.028522308566607535, 0.08682006431627087, 0.027393060372560285, 0.0260016893298598, 0.05547097833186854, 0.02187912949011661, 0.013305024094734108, 0.03343220545502845, 0.025573386628821027, 0.06065819354262203, 0.046751355403102934, 0.03450869437074289, 0.07007180989603512, 0.0192404531117063, 0.008981137216323987, 0.1071042961848434, 0.18784798186970875, 0.17002296022837982, 1.4642085623927414, 2.04965609125793, 5.224055629223585, 4.973030174151063, 7.647155681625009, 10.304844696074724, 13.854355830699205, 15.527636893093586, 19.516531750559807, 16.71770453453064, 23.74837227165699, 22.19368949532509, 18.122931830585003, 17.919340655207634, 17.05395609140396, 16.76103550940752, 15.579205825924873, 13.367042429745197, 10.157315712422132, 12.542839106172323, 6.883997982367873, 5.284875640645623, 4.4672236405313015, 1.1459743324667215, 0.9019809938035905, 0.2008878134074621, 0.041363411510246806, 0.03786352099268697, 0.12141977567807771, 0.049843714077724144, 0.013367562096391339, 0.09208655945258215, 0.01869948497187579, 0.044950374503969215, 0.03867954947054386, 0.023466321763407905, 0.039522699735243805, 0.04022963621537201, 0.010105657001986401, 0.03510222326440271, 0.05324482102878392, 0.11767728079576045, 0.022371112172550056, 0.029203164122009184, 0.02881049193092622, 0.013269279479573015, 0.012089493811799912, 0.03875284397508949, 0.02691844023502199, 0.057723997670109384, 0.006772436618120992, 0.0631966651417315, 0.049765050134737976, 0.01281652115721954, 0.009549511942168465, 0.05594554837443866, 0.09939497744198889, 0.04092666873475537, 0.04317295679356903, 0.01849114185461076, 0.057140365315717645, 0.051564138557296246, 0.052367932730703615, 0.021424543629109394, 0.0636899187520612, 0.047142574840108864, 0.016822497018438298, 0.03604325909691397, 0.04729010637674946, 0.03597891118261032, 0.004787737525475677, 0.02783022246148903, 0.08312715232023038, 0.026683379801397678, 0.028704611577268224, 0.03420717090193648, 0.021357477598940022, 0.003136423461000959, 0.033062229995266534, 0.02919993392424658, 0.09391386061906815, 0.025903896530508064, 0.05833078874275088, 0.04878108848060947, 0.06401060818461701, 0.01757233705575345, 0.05260544967313763, 0.03312998065666761, 0.02507904948288342, 0.05814892916532699, 0.012685815963777713, 0.052355126972543076, 0.03476529192994349, 0.0886907811218407, 0.03405739065783564, 0.054550919303437695, 0.0292763955440023, 0.051488246535882354, 0.03149881427816581, 0.010769538712338544, 0.05436860701593105, 0.015003408643678995, 0.021785273784189485, 0.026061370990646537, 0.04020839594886638, 0.017600570208742283, 0.02622663429065142, 0.04191059328150004, 0.030227593233576044, 0.01854507743701106, 0.0859787137596868, 0.056358739093411714, 0.015838999206607696, 0.037405103794299066, 0.061043516616337, 0.013368432264542207, 0.045022626291029155, 0.03800516729825176, 0.026947270816890523, 0.021066192057332955, 0.015313990024878876, 0.019108521519228816, 0.082417377125239, 0.05424649774795398, 0.03987956886703614, 0.06109778245445341, 0.016347479831892997, 0.05249297719274182, 0.016621400973235723, 0.03749095543753356, 0.009479450418439228, 0.1472935001947917, 0.0467985708382912, 0.07173883685027249, 0.055858683699625544, 0.04398457320348825, 0.022160943372000474, 0.0653285437147133, 0.028799112951674033, 0.030427475867327303, 0.03128044474578928, 0.05973539227852598, 0.0535795481846435, 0.029322399423108436, 0.005769658737335703, 0.06452366229495965, 0.032728230144130066, 0.03729073141585104, 0.024363311131310184, 0.012559727856569225, 0.07502416876377538, 0.04390139329188969, 0.028032637674186844, 0.01611824340216117, 0.044272329832892865, 0.021122996040503494, 0.04362347382993903, 0.0020720153179354384, 0.06518590293126181, 0.07854282448533922, 0.043066354701295495, 0.014428402828343678, 0.051426555510261096, 0.012772590653185034, 0.008368692833755631, 0.05599333155259956, 0.003009732822647493, 0.028540762068587355, 0.07307317384402268, 0.0518174706667196, 0.01178283189801732, 0.035823639045702294, 0.010978726950270357, 0.12858063244493678, 0.3220366680761799, 0.4459561826661229, 1.9973673345521092, 2.9173696925863624, 6.789850909262896, 6.50794736109674, 9.805515389889479, 12.669054083526134, 16.00624021142721, 19.207583628594875, 22.237976118922234, 20.30707363039255, 26.779758408665657, 25.895914435386658, 22.101493142545223, 22.296295389533043, 21.238133870065212, 21.25856537371874, 19.694088622927666, 17.02761970460415, 14.004722312092781, 15.423153899610043, 9.987016450613737, 7.462585335597396, 6.542133651673794, 2.0055240718647838, 1.1343722487799823, 0.26256475306581706, 0.2786619361722842, 0.07993044768227264, 0.04497331057791598, 0.008719782490516081, 0.018825713159458246, 0.0465877415263094, 0.05122977505379822, 0.10329642551369034, 0.04549312565359287, 0.04755621084768791, 0.06997149379458278, 0.05251804323052056, 0.011362955356162274, 0.02703629514144268, 0.033492686779936776, 0.050395515718264505, 0.01540999517601449, 0.083486967778299, 0.055816099265939556, 0.009938193234120263, 0.02908395108534023, 0.03901880743796937, 0.01449257633794332, 0.014246665705286432, 0.0748000772728119, 0.04237066546920687, 0.07480816668248735, 0.010461309011589037, 0.007414791407427401, 0.06192573724547401, 0.045487771058105864, 0.037658773580915295, 0.034138232804252766, 0.009150835776381427, 0.04100760736037046, 0.054537000323762186, 0.023620070642209612, 0.04905308560410049, 0.07680533060920425, 0.05804917338537052, 0.03730804572114721, 0.009610079541744199, 0.044258893249207176, 0.033633093698881567, 0.022586828526982572, 0.029428752895910293, 0.038716378548997454, 0.013358993073779857, 0.065339675929863, 0.023514717213402037, 0.03452322191151325, 0.006090339820730151, 0.0026395579106974765, 0.05976829539577011, 0.07031304499832913, 0.021701867517549545, 0.04298859988921322, 0.07961392911965959, 0.010415490669402061, 0.007051007314657909, 0.03621913696406409, 0.036652718190453015, 0.04540756344795227, 0.007105096892701113, 0.02994496298924787, 0.02275306404044386, 0.017915064563567284, 0.06405728927347809, 0.01803119212127058, 0.08163579914253205, 0.08264893462182954, 0.14841988740954548, 0.09409897451405413, 0.13911607180489227, 0.10982006686390378, 0.13370878383284435, 0.07246892462717369, 0.14674147590994835, 0.14404182467842475, 0.15486707270611078, 0.13391293381573632, 0.3169464849634096, 0.23514491971582174, 0.13800344400806352, 0.11979546674410813, 0.16509523324202746, 0.12486012739827856, 0.08995457697892562, 0.1850286964327097, 0.12024664058117196, 0.2743012842256576, 0.11866717220982537, 0.13507268799003214, 0.10076815102365799, 0.1128175419580657, 0.17438374576158822, 0.11437093126005493, 0.15924574399832636, 0.16598073416389525, 0.1147437046165578, 0.08787688260781579, 0.17766216828022152, 0.16333818377461284, 0.1444992548204027, 0.1131138444179669, 0.3318426356418058, 0.17650581314228475, 0.12706491455901414, 0.15087908279383555, 0.09808105693082325, 0.08598332991823554, 0.16249896318186074, 0.14511385699734092, 0.11767341420636512, 0.10951364150969312, 0.2246447026845999, 0.14220993703929707, 0.07843725397833623, 0.08886612835340202, 0.26376284658908844, 0.13536230369936675, 0.2032472938299179, 0.07059262687107548, 0.0677569473918993, 0.1666220833430998, 0.10402413841802627, 0.09427520490135066, 0.186985487525817, 0.15781935100676492, 0.17766663600923494, 0.11812605007435195, 0.1462674661888741, 0.2454401704017073, 0.3436087042791769, 0.10212787688942626, 0.06240416274522431, 0.27286083495710045, 0.15936392359435558, 0.0973429242731072, 0.15730287559563294, 0.08905551701900549, 0.21716349787311628, 0.17623230203753337, 0.14782109297811985, 0.1023334517958574, 0.12129368478781544, 0.10338778389268555, 0.25613594334572554, 0.4672088281949982, 0.6195229722652584, 1.9472119258716702, 3.295290288515389, 7.316367281600833, 8.068808130919933, 10.580161772668362, 13.731193039566278, 18.37676391005516, 21.777625121176243, 24.46789976209402, 24.113080501556396, 30.17532080411911, 29.759617410600185, 27.2862446308136, 26.211143620312214, 23.766349107027054, 22.885144092142582, 21.747526936233044, 19.044842161238194, 17.064122445881367, 17.01716646552086, 11.231462974101305, 7.890314133837819, 6.7607316467911005, 2.7153050852939487, 1.3040342135354877, 0.40866816008929163, 0.3938449773704633, 0.13216207385994494, 0.25043811940122396, 0.17083065438782796, 0.0988688763754908, 0.19538284395821393, 0.12284597571124323, 0.22504273132653907, 0.08601668945630081, 0.17311108123976737, 0.14526240527629852, 0.0824172435386572, 0.0840921446797438, 0.12978466314962134, 0.12336032115854323, 0.24664632364874706, 0.09938956718542613, 0.1330808229977265, 0.09904903272399679, 0.13433153479127213, 0.11296463562757708, 0.09627380859456025, 0.13905527506722137, 0.09660616458859295, 0.12414610711857677, 0.12801657052477822, 0.24100855429423973, 0.07727612683083862, 0.08030621931538917, 0.12790463981218636, 0.167670693481341, 0.17190473503433168, 0.1366921135922894, 0.07471032935427502, 0.07742821515421383, 0.2411579486215487, 0.1655140717048198, 0.12669725460000336, 0.1766431104624644, 0.11192521327757277, 0.08424515326623805, 0.09129505895543844, 0.1547559880418703, 0.10144286716240458, 0.08821525741950609, 0.15758642053697258, 0.1583246496738866, 0.07620782751473598, 0.20819105120608583, 0.15062601043609902, 0.10174862458370626, 0.09222652850439772, 0.1412274967879057, 0.14883896335959435, 0.1295099942944944, 0.1296348829055205, 0.10490762811969034, 0.1558555688825436, 0.126973585865926, 0.08447830638033338, 0.12658852996537462, 0.08954183154855855, 0.14238263480365276, 0.13767508819000795, 0.09345973303425126, 0.0875206888304092, 0.08163015139871277, 0.24991523183416575, 0.1501571512199007, 0.1543530315393582], [0.026949465718644205, 0.03438769832428079, 0.10822320255101658, 0.0350535791949369, 0.019181508032488637, 0.059211499101365916, 0.06558246212080121, 0.036698334297398105, 0.019488044708850794, 0.0188745687410119, 0.06603916495805606, 0.03334751156216953, 0.013683932229469065, 0.04246156371664256, 0.005526345157704782, 0.093732279347023, 0.016048095603764523, 0.041102175528067164, 0.025094682823691983, 0.03387743839994073, 0.05493211232533213, 0.013500327677320456, 0.040983045983011834, 0.04880206528468989, 0.044136271899333224, 0.053756739653181285, 0.03817394652287476, 0.04960135091096163, 0.06836053609731607, 0.018433415752951987, 0.041261392179876566, 0.017196890112245455, 0.07075725006870925, 0.022134007122076582, 0.04403558101330418, 0.01089177414542064, 0.049186738979187794, 0.017518932108941954, 0.023366918503597844, 0.03020345488039311, 0.05718931366573088, 0.07066459293127991, 0.10438177196192555, 0.05059875285951421, 0.03738556304597296, 0.04418202530359849, 0.054940339032327756, 0.010236646066914545, 0.0414199149236083, 0.019587219758250285, 0.03887235201545991, 0.038763705306337215, 0.06558634355315007, 0.05561682519328315, 0.039607987346244045, 0.01348622223304119, 0.05961853370536119, 0.05820889840833843, 0.017078389537346084, 0.07466249051503837, 0.045183642650954425, 0.08757786388741806, 0.04676494041632395, 0.048549779603490606, 0.03446506350883283, 0.039224961219588295, 0.02369955094764009, 0.0436207575694425, 0.08735552386497147, 0.007879303957452066, 0.04092860202945303, 0.015563117867714027, 0.03411976074858103, 0.04740381824376527, 0.029544971366703976, 0.0437943607539637, 0.07448843462043442, 0.06119702986325137, 0.016929850535234436, 0.05522746483620722, 0.07584183738799766, 0.09506027839961462, 0.10502468707272783, 0.9834784269332886, 0.7948059635236859, 1.3051862642168999, 2.401203252375126, 2.591523639857769, 3.7801981810480356, 4.017495922744274, 5.070485919713974, 4.655459364876151, 5.733898496255279, 5.223963959142566, 5.258765816688538, 4.4846732541918755, 2.1085303695872426, 3.697188072837889, 2.4125252198427916, 2.018327722325921, 1.354438152629882, 0.7025636569596827, 0.4114705097163096, 0.2183184726163745, 0.10517368064029142, 0.03266362247813959, 0.023062099899107125, 0.060271271140663885, 0.0410594315326307, 0.03703061236592475, 0.011367660572432214, 0.09115678200032562, 0.01951133515831316, 0.043173539379495196, 0.0201404259132687, 0.05226031760685146, 0.031816364426049404, 0.03394604995264672, 0.025081285202759318, 0.0049941793531615986, 0.016344403629773296, 0.07990465805050917, 0.02094339630275499, 0.03843606937152799, 0.06808440521126613, 0.10240027477266267, 0.015503229333262425, 0.01398406880980474, 0.040775411616778, 0.018351419566897675, 0.05984295916277915, 0.08038390733418055, 0.043967555757262744, 0.011315788160572993, 0.03582439603633247, 0.041217805846827105, 0.029850658283976372, 0.01772848492691992, 0.03171733224007767, 0.04790043749380857, 0.029202752230048645, 0.0018902438705481472, 0.009503448691248195, 0.06140341371065006, 0.025869160308502614, 0.03403986484045163, 0.05749859628849663, 0.045997455817996524, 0.04237991633999627, 0.06824063471867703, 0.03232538867450785, 0.05242036917479709, 0.04411034497024957, 0.05592076064203866, 0.020981362722523045, 0.04591622404404916, 0.04678697107010521, 0.0343035944388248, 0.01313997694524005, 0.021375832766352687, 0.026410998616483994, 0.046090996111161076, 0.03779943654080853, 0.08829794751363806, 0.045043673599138856, 0.008422458649874898, 0.040410234141745605, 0.03335468070872594, 0.0026468984469829593, 0.0199489184160484, 0.04870607219345402, 0.04241110509610735, 0.007909104897407815, 0.046084639616310596, 0.033382863766746596, 0.013807912637275876, 0.022392927603505086, 0.05254705378320068, 0.01284657628275454, 0.04294041595130693, 0.07219807041110471, 0.03977986874815542, 0.0710867636371404, 0.046452399765257724, 0.018073934261337854, 0.06738710551871918, 0.04883991110546049, 0.032540670872549526, 0.014683146873721853, 0.060856443451484665, 0.028988544290768914, 0.016365621631848626, 0.030161057838995475, 0.0338425648806151, 0.03848516986181494, 0.030612665832450148, 0.037260518583934754, 0.04948353125655558, 0.07020318487775512, 0.05297225987305865, 0.019574146826926153, 0.019779929534706753, 0.029483606886060443, 0.0393344688200159, 0.04919334409350995, 0.04409682675031945, 0.08640520376502536, 0.05065192031906918, 0.02434246605844237, 0.027210044900130015, 0.01676308809692273, 0.031994550372473896, 0.0585067556676222, 0.07583957383758388, 0.024247897890745662, 0.018190779846918304, 0.07959583555930294, 0.0501323464413872, 0.0663041858933866, 0.026990376609319355, 0.021967324464640114, 0.051650019886437804, 0.03465470079390798, 0.05720459819713142, 0.03388056284165941, 0.020709447235276457, 0.0425956289836904, 0.011935091843042755, 0.03463317480054684, 0.017860819134511985, 0.029169014196668286, 0.025916889680956956, 0.08036100465687923, 0.0009401682734733185, 0.03367041630554013, 0.06639453495154157, 0.009685198801889783, 0.05363055970519781, 0.02674793551705079, 0.032360948680434376, 0.03969137505919207, 0.012441175331332488, 0.0640530590317212, 0.04345770401414484, 0.05599499767413363, 0.0163730412532459, 0.01875932062830543, 0.05781063227914274, 0.03285818391304929, 0.02852599889592966, 0.0340644373500254, 0.06214579887455329, 0.026909196785709355, 0.009892423131532269, 0.011830086295958608, 0.04760155235999264, 0.06849753655842505, 0.13360247859964147, 0.2793736261082813, 1.1368666961789131, 1.0727559425868094, 1.8770387163385749, 3.3295010402798653, 3.449845095165074, 4.862981904298067, 5.204531326889992, 6.942050792276859, 6.096454616636038, 7.966377027332783, 7.278357446193695, 7.108986284583807, 5.7766500022262335, 4.341675527393818, 5.5241459514945745, 3.241139156743884, 3.3837082190439105, 2.2097880486398935, 1.0870613437145948, 0.5339183157775551, 0.3060552600072697, 0.04811833205167204, 0.049738507223082706, 0.013288240425026743, 0.07298679527593777, 0.0676045696309302, 0.06592907477170229, 0.023738827258057427, 0.035993000856251456, 0.05893955392821226, 0.010471166588104097, 0.039222909181262366, 0.06674019765341654, 0.010444446488691028, 0.04812857740034815, 0.046842888186802156, 0.025114492600550875, 0.080803250457393, 0.014718795937369578, 0.01758241171046393, 0.02810573179885978, 0.06521348856040277, 0.03555618386599235, 0.0083078812531312, 0.05935952787694987, 0.034993624794879, 0.06893796409713104, 0.0326551434409339, 0.06786881873267703, 0.028878754674224183, 0.019044264518015552, 0.1328475511400029, 0.08998513862024993, 0.06358292332151905, 0.04775631241500378, 0.07495860743802041, 0.004924064487568103, 0.028848768197349273, 0.019811912388831843, 0.04009960081020836, 0.05601690958428662, 0.018848033250833396, 0.026851953080040403, 0.06820444017648697, 0.04293488324037753, 0.03612399363191798, 0.06684301479253918, 0.029679916078748647, 0.022122180998849217, 0.06874982223962434, 0.014328499546536477, 0.06454811606090516, 0.02460289681039285, 0.04826958174817264, 0.07689138263231143, 0.01758859751134878, 0.04759445000672713, 0.04158990013820585, 0.055576162922079675, 0.027235979250690434, 0.012162916336819762, 0.013628303622681415, 0.025481955890427344, 0.06964812520891428, 0.02991338089486817, 0.025097599464061204, 0.023696684402239043, 0.02161341835744679, 0.07953996668220498, 0.012000103051832411, 0.038356900768121704, 0.06345122921629809, 0.0060134486830065725, 0.10431170579977334, 0.1416684957803227, 0.2959835738874972, 0.153638610499911, 0.1379457939765416, 0.15195390558801591, 0.12684430374065414, 0.09252207397366874, 0.10602554742945358, 0.14550658670486882, 0.21024865563958883, 0.12528196413768455, 0.056054747983580455, 0.09710417536552995, 0.08930401774705388, 0.1938729890389368, 0.16439690196420997, 0.09821433181059547, 0.17029005917720497, 0.14983640983700752, 0.11150952152092941, 0.12726793647743762, 0.10912592872045934, 0.15074996394105256, 0.1125079847406596, 0.16286108671920374, 0.11494536840473302, 0.14705743786180392, 0.12392384131089784, 0.12489931279560551, 0.11618634322076105, 0.0885395314253401, 0.14062806410947815, 0.13887574954424053, 0.10690289956983179, 0.06116407108493149, 0.13569483038736507, 0.12441009646863677, 0.08849824575008824, 0.07081210962496698, 0.16548683488508686, 0.16835664573591202, 0.1877259134198539, 0.1008113737043459, 0.07408551522530615, 0.19046915840590373, 0.07026842708000913, 0.14599224814446643, 0.1665993736241944, 0.1840942434500903, 0.11778927830164321, 0.09236493904609233, 0.13276177371153608, 0.32361097109969705, 0.14738301804754883, 0.16713110759155825, 0.13943078694865108, 0.12712841271422803, 0.10374945471994579, 0.17354899289784953, 0.11648885745671578, 0.17615624674363062, 0.20283127552829683, 0.14424652385059744, 0.10219637711998075, 0.10569345118710771, 0.23460900003556162, 0.09127318044193089, 0.15132441592868418, 0.11580150996451266, 0.06726612060447223, 0.17954425478819758, 0.154588203295134, 0.08667136018630117, 0.15537749219220132, 0.16950562392594293, 0.16183466679649428, 0.14311376900877804, 0.08168167871190235, 0.18249610264319927, 0.289254313101992, 0.23766069643897936, 0.4030390887055546, 1.0227088280953467, 1.2321716384030879, 2.093813046813011, 3.1222062511369586, 4.061257224529982, 5.69340786896646, 5.746806403622031, 7.577121639624238, 6.672401111572981, 8.371512237936258, 7.6216500252485275, 7.36604486592114, 6.27513337880373, 4.094971865415573, 5.431768158450723, 3.853204376064241, 3.065453446470201, 2.4518231861293316, 1.3775932788848877, 0.8137770392931998, 0.42656894016545266, 0.19191932980902493, 0.2201859833439812, 0.231205822492484, 0.17844807298388332, 0.15867642767261714, 0.1754618636914529, 0.11016216725693084, 0.15723612683359534, 0.12423955835402012, 0.1560631179017946, 0.12273737724171951, 0.1997656564344652, 0.14953396981582046, 0.10324895032681525, 0.13764532806817442, 0.13311968185007572, 0.17181034869281575, 0.16820594522869214, 0.18134228565031663, 0.08639815336209722, 0.13253966375486925, 0.17389354237820953, 0.08895915656466968, 0.09975603970815428, 0.11174950981512666, 0.11752638733014464, 0.15445170749444515, 0.13354999391594902, 0.1266223273705691, 0.05481908694491722, 0.3155788849107921, 0.1622368663083762, 0.14959310414269567, 0.1344815079937689, 0.15126023499760777, 0.13837595761287957, 0.1496633855276741, 0.18909020349383354, 0.1789071358507499, 0.15864629647694528, 0.07909147199825384, 0.1321185246342793, 0.2290221568546258, 0.10622366375173442, 0.14343541581183672, 0.15887698566075414, 0.17574166820850223, 0.09412432627868839, 0.2119702156051062, 0.11864353480632417, 0.21060460450826213, 0.17722790798870847, 0.17997664486756548, 0.25479981035459787, 0.09958919748896733, 0.1707833944237791, 0.11268195157754235, 0.10995517484843731, 0.14401221298612654, 0.2186898433137685, 0.12070392971509136, 0.10214599271421321, 0.18287078331923112, 0.11499266547616571, 0.10198439005762339, 0.11869998998008668, 0.17912834038725123, 0.23475091351429, 0.06089576243539341, 0.11447636075899936, 0.1552939263638109, 0.0992629345273599], [0.03348767357238103, 0.03870310523780063, 0.004284882379579358, 0.06436519892304204, 0.008505297173542203, 0.060642330136033706, 0.05999417175189592, 0.014960798234824324, 0.027014691222575493, 0.0519005318346899, 0.02003967008931795, 0.024452665711578447, 0.05912806314881891, 0.004669897462008521, 0.003632240727711178, 0.03278687836427707, 0.028881387443107087, 0.021076784360047895, 0.014952956516935956, 0.03725058493728284, 0.01575222358951578, 0.016709471638023388, 0.033533883397467434, 0.09155541178188287, 0.04632018615666311, 0.023625156209163833, 0.0075491841471375665, 0.016887752208276652, 0.027059379644924775, 0.0462964856706094, 0.033331796585116535, 0.026912135690508876, 0.10017370557761751, 0.06039064559445251, 0.09685754484962672, 0.01725164576782845, 0.013265628113003913, 0.05469027237268165, 0.05037759656261187, 0.09826602981775068, 0.027500347096065525, 0.027797844413726125, 0.02842974048689939, 0.03560277589713223, 0.06797907219151966, 0.02847471278073499, 0.0038441878996309242, 0.07666067118407227, 0.03445963840931654, 0.023860827059252188, 0.03168408773490228, 0.05177381382964086, 0.0347914934536675, 0.02243456765427254, 0.01151219197708997, 0.018410212505841628, 0.03723893692949787, 0.05300258402712643, 0.02787215566058876, 0.01187654102977831, 0.018170253897551447, 0.019369065448699985, 0.02779969607217936, 0.020800078309548553, 0.03087772201979533, 0.007889140197221423, 0.017510842699266504, 0.02641978564497549, 0.005779697212346946, 0.051085998784401454, 0.050084374015568756, 0.011486339262773981, 0.06105200678575784, 0.030898452059773263, 0.03343166739796288, 0.09060538854100741, 0.1012327206262853, 0.06412465401808731, 0.02178797705710167, 0.02397174102952704, 0.056949499776237644, 0.02515745367418276, 0.05396795488195494, 0.03527480599586852, 0.09345522819785401, 0.07935572852147743, 0.029297517066879664, 0.11817532125860453, 0.07999934867257252, 0.22147145733470097, 0.3458954393863678, 0.3259727224940434, 0.32850243675056845, 0.47428330639377236, 0.5346566042862833, 0.4917515628039837, 0.40377607103437185, 0.3595486411359161, 0.23343673325143754, 0.1310364733217284, 0.03591313463402912, 0.03445629874477163, 0.05726833383960184, 0.035432660806691274, 0.056410047473036684, 0.024774052762950305, 0.07135390711482614, 0.03672001614177134, 0.03056543555430835, 0.010962494325212901, 0.017986607599596027, 0.031613784085493535, 0.09445435935049318, 0.016648728706059046, 0.04933680495014414, 0.012985481280338718, 0.029256105226522777, 0.039219981408677995, 0.043950549443252385, 0.03594836809497792, 0.045104793171049096, 0.06994079856667668, 0.0676777602348011, 0.07113773433957249, 0.026094426248164382, 0.1194284376106225, 0.030742651142645627, 0.10298104985849932, 0.07373102838755585, 0.028877322329208255, 0.031062991765793413, 0.039390764432027936, 0.05487206144607626, 0.022011205801391043, 0.03439421809162013, 0.038371921837097034, 0.031219755619531497, 0.01523532144346973, 0.04198537579213735, 0.010735851701610954, 0.10185190927586518, 0.02494597869372228, 0.053162078984314576, 0.029571638588095084, 0.104707144346321, 0.03136443359835539, 0.06201533673447557, 0.08455262504867278, 0.02067917874228442, 0.09233244782080874, 0.025575034196663182, 0.04332141972554382, 0.02570906792243477, 0.018973046171595342, 0.05103191106172744, 0.1502128122956492, 0.05060094961663708, 0.034001143285422586, 0.04030781034089159, 0.02866966384317493, 0.059891814744332805, 0.04998767217330169, 0.046163752558641136, 0.07700323913013563, 0.00142429213383366, 0.06642675900366157, 0.011645635695458623, 0.06870962009998038, 0.033574360131751746, 0.011558328515093308, 0.06312469908152707, 0.05496812504134141, 0.022311827560770325, 0.07211445263237692, 0.029034297695034184, 0.011579614238144131, 0.018258018426422495, 0.026930188432743307, 0.03577924377168529, 0.017548417636135127, 0.026854242605622858, 0.07223575667012483, 0.02560232111136429, 0.029099760686221998, 0.018262380399391986, 0.045068632025504485, 0.02199979713623179, 0.05312293069437146, 0.06815641580033116, 0.029406677713268436, 0.036740736904903315, 0.04195334840915166, 0.00849162495796918, 0.021138362208148465, 0.016943934642768, 0.053841960470890626, 0.037829359935130924, 0.020081812945136335, 0.059636742298607714, 0.04514774125709664, 0.024346718564629555, 0.047689051571069285, 0.020481632018345408, 0.06659156031673774, 0.04524505166045856, 0.016038186076912098, 0.050895778913400136, 0.041534205665811896, 0.03926652148948051, 0.021519137771974783, 0.06710366447805427, 0.05867948682862334, 0.02839238633896457, 0.02873600627935957, 0.010343784360884456, 0.026961518196912948, 0.04895296988252085, 0.04704857441538479, 0.03434115082200151, 0.03724009839061182, 0.05058750190073624, 0.01957361433596816, 0.024922471166064497, 0.025996804142778274, 0.07507109476136975, 0.035501153615769, 0.048222088007605635, 0.017144043631560635, 0.05126827396452427, 0.03665905613161158, 0.035035912369494326, 0.04184476478258148, 0.03485925524728373, 0.0218625554771279, 0.04346312169218436, 0.07836557735572569, 0.0074799612502829405, 0.008384250104427338, 0.03027510923857335, 0.04291136829124298, 0.08065390065894462, 0.06663462714641355, 0.03760469699045643, 0.0407400668336777, 0.03555134135240223, 0.042994700343115255, 0.029414798664220143, 0.034719824252533726, 0.0322833274549339, 0.026078429254994262, 0.016842666736920364, 0.03239612648030743, 0.06057749982574023, 0.058011535365949385, 0.030826259644527454, 0.046801149801467545, 0.017631419432291295, 0.07151975485612638, 0.018786511063808575, 0.028048601270711515, 0.09300361649366096, 0.039433512138202786, 0.13132122054230422, 0.24340603267773986, 0.15519281616434455, 0.2336983403074555, 0.48058274493087083, 0.505690936697647, 0.44446304091252387, 0.6554629874881357, 0.7234479894395918, 0.5965505924541503, 0.5801745993085206, 0.5306826706510037, 0.4748956672847271, 0.15767920383950695, 0.17227522999746725, 0.02460155537846731, 0.028320372039161157, 0.03872180364851374, 0.02040858984400984, 0.022158028587000445, 0.015482235830859281, 0.03653768158983439, 0.012277506721147802, 0.00445383925580245, 0.03442097993684001, 0.04226140648825094, 0.014457860524998978, 0.04168878018390387, 0.052441216103034094, 0.013459782294376055, 0.021805228279845323, 0.060388437705114484, 0.01968471384316217, 0.04179087372904178, 0.03685941002913751, 0.0068953905429225415, 0.04501111186982598, 0.02401886369625572, 0.026627915394783486, 0.037507924644160084, 0.03714300321007613, 0.08859468784066848, 0.04929130016535055, 0.006042347913535195, 0.018763224325084593, 0.03266034218540881, 0.048479212491656654, 0.07447006646543741, 0.04284611495677382, 0.026481567583687138, 0.08040152592002414, 0.00813737467979081, 0.010114140677615069, 0.024262497790914495, 0.08606363029684871, 0.04853355625527911, 0.06472073218901642, 0.08544044889276847, 0.027197686285944656, 0.04447155566595029, 0.03434741454839241, 0.039775304539944045, 0.04123106802580878, 0.01189699090900831, 0.046862351009622216, 0.04714523543952964, 0.0179755922727054, 0.030304266365419608, 0.004316026142987539, 0.15281003230484203, 0.03147521027131006, 0.04846232863201294, 0.08183558529708534, 0.05488179471285548, 0.03956266438763123, 0.013908344699302688, 0.017458751353842672, 0.03480476305412594, 0.008988110621430678, 0.007555414476883016, 0.020655626685766038, 0.024207012975239195, 0.05167169430933427, 0.04324018424085807, 0.04927896567096468, 0.04749883541080635, 0.025222786789527163, 0.04101640923181549, 0.07272305825608782, 0.06847788448794745, 0.15830312739126384, 0.2321888564620167, 0.14886651188135147, 0.09973125197575428, 0.2319883875316009, 0.2008177843526937, 0.14752494636923075, 0.13432967942208052, 0.0853825910598971, 0.17746972938766703, 0.0957215171365533, 0.26914537651464343, 0.1904922688845545, 0.08918258012272418, 0.11722687137080356, 0.1740325169521384, 0.12488638458307832, 0.1434860154404305, 0.11524091387400404, 0.1810422947164625, 0.08908771880669519, 0.14074072212679312, 0.14792028843658045, 0.16166311193956062, 0.11515424586832523, 0.12961794709553942, 0.09775530605111271, 0.10230737272650003, 0.14398873143363744, 0.12798192707123235, 0.1230699558800552, 0.1261766825336963, 0.1237681981001515, 0.09783622983377427, 0.13095373869873583, 0.20367524586617947, 0.16926727577811107, 0.22823457489721477, 0.14876005821861327, 0.1468032819684595, 0.12570860999403521, 0.11282958701485768, 0.08646088710520416, 0.13610538648208603, 0.16482811945024878, 0.13200087938457727, 0.1246195231215097, 0.13007264613406733, 0.18650175567017868, 0.06838645189418457, 0.13760048750555143, 0.13621854915982112, 0.1124791448819451, 0.12234586465638131, 0.09131762766628526, 0.07692533588851802, 0.10362057335441932, 0.24418827117187902, 0.10478331096237525, 0.2164005403756164, 0.1723180667613633, 0.13257328304462135, 0.12784198770532385, 0.17766734847100452, 0.1082137475896161, 0.1499360060552135, 0.14868137572193518, 0.17698181181913242, 0.11549750401172787, 0.1794505215366371, 0.11996729619568214, 0.07003764883847907, 0.1838876592228189, 0.2255572919966653, 0.10406096378574148, 0.15187167562544346, 0.28508964751381427, 0.07326864069909789, 0.08541484479792416, 0.1429685900802724, 0.13414062472293153, 0.21568433818174526, 0.13629086402943358, 0.18875319423386827, 0.2343344350811094, 0.15927480650134385, 0.20176935126073658, 0.3516206337371841, 0.23293611011467874, 0.6243143370375037, 0.5708734109066427, 0.570255231577903, 0.676759360358119, 0.7871636236086488, 0.7674910104833543, 0.8450450864620507, 0.7709675270598382, 0.5689836060628295, 0.47888821398373693, 0.35184716689400375, 0.25739044009242207, 0.17903937172377482, 0.13686812133528292, 0.16280486161122099, 0.12959085870534182, 0.1472321542678401, 0.19565133814467117, 0.09926844868459739, 0.230405401380267, 0.1845479925395921, 0.12087886876543052, 0.12178845980088226, 0.17246357223484665, 0.15344813087722287, 0.11718776018824428, 0.11538632286828943, 0.10117351950611919, 0.11379558127373457, 0.15021922445157543, 0.14187818218488246, 0.1425832966924645, 0.15457114874152467, 0.21964029700029641, 0.23301970562897623, 0.19356335018528625, 0.27607065334450454, 0.13741358503466472, 0.17167642072308809, 0.1532998200855218, 0.07627786399098113, 0.19497206521918997, 0.18072648119414225, 0.14618235669331625, 0.08998773613711819, 0.10601722795399837, 0.08875344807165675, 0.13722497562412173, 0.07422721348120831, 0.07023578000371344, 0.15357984724687412, 0.2102127208490856, 0.12593370338436216, 0.11788253657869063, 0.1595120711135678, 0.1604129493352957, 0.08307794050779194, 0.10895608822465874, 0.11823328299215063, 0.23572107864310965, 0.19001578039024025, 0.1620354177430272, 0.24649648403283209, 0.11505189628223889, 0.15514960832661018, 0.17628370318561792, 0.252899318584241, 0.1383340559550561, 0.1345089971437119, 0.1651730845333077, 0.16984103014692664, 0.22777333011617884, 0.11159574423800223, 0.10554191947448999, 0.15990809595678002, 0.15313927870010957, 0.14883459953125566, 0.10158388264244422, 0.22117317334050313, 0.19229436671594158, 0.13447868783259764, 0.16502529324498028, 0.19089298410108313, 0.17486244585597888, 0.24229190574260429, 0.11065136874094605, 0.18729232106124982], [0.03645586722996086, 0.01469459635700332, 0.03208225367416162, 0.012017569497402292, 0.05337116424925625, 0.02669337653060211, 0.06591222801944241, 0.03424630434892606, 0.028803948043787386, 0.04079713427927345, 0.0320483078394318, 0.10975401572068222, 0.04340741608757526, 0.02841589943272993, 0.023483973745896947, 0.05382026749430224, 0.02169820130802691, 0.0592671861522831, 0.043809994094772264, 0.020502024381130468, 0.010695306318666553, 0.028006636530335527, 0.03225616484996863, 0.050172299961559474, 0.045056445960653946, 0.024262473671115004, 0.05828877205203753, 0.06059343373635784, 0.07065668163704686, 0.04204322991427034, 0.04753652166982647, 0.04284796290448867, 0.021656229146174155, 0.03736342478077859, 0.06100326994783245, 0.02515480235160794, 0.040082613049889915, 0.09101283503696322, 0.02976207368192263, 0.028057393865310587, 0.09559567857650109, 0.01599002440343611, 0.0242991468985565, 0.05685337309841998, 0.060273119088378735, 0.02810017867886927, 0.02488747333700303, 0.015619733530911617, 0.057405178449698724, 0.029478317228495143, 0.020929978272761218, 0.030154122468957212, 0.009761919245647732, 0.05040338990511373, 0.07992744940565899, 0.04383245519420598, 0.03219691920094192, 0.05103832321765367, 0.0862948909343686, 0.014908690191077767, 0.03782367137318943, 0.060375253451638855, 0.03022087679710239, 0.0747195839358028, 0.06073450858821161, 0.07663813215913251, 0.035305579149280675, 0.0611321550240973, 0.01996289676753804, 0.09371069027110934, 0.05247852015600074, 0.022340344585245475, 0.05169150965230074, 0.03674935695016757, 0.01961371257493738, 0.019038355167140253, 0.04412480200699065, 0.038435152819147334, 0.03218256235413719, 0.06161174569569994, 0.01681100115092704, 0.0625199823116418, 0.03372792532900348, 0.0674395530950278, 0.044462219448178075, 0.0038640885895802057, 0.05863770762516651, 0.03383478717296384, 0.062142678143572994, 0.0692927032650914, 0.05298679112456739, 0.027679722334141843, 0.054836423514643684, 0.06429001936339773, 0.044524452241603285, 0.04502185074670706, 0.029473892172973137, 0.06930367220775224, 0.011169688968948321, 0.022926826786715537, 0.06126745225628838, 0.022279763070400804, 0.037570836502709426, 0.05743906491261441, 0.03023992587259272, 0.06051990916603245, 0.07460092936526053, 0.06582147078006528, 0.025864189774438273, 0.09325057355454192, 0.08218596063670702, 0.009456163679715246, 0.020701437606476247, 0.017317227502644528, 0.03353346779476851, 0.01776193908881396, 0.02820085657731397, 0.0750951848749537, 0.02980204575578682, 0.03434904727328103, 0.07347341408603825, 0.0694503948034253, 0.029267884965520352, 0.04479938455915544, 0.0515243334666593, 0.021530156809603795, 0.028170929472253192, 0.07142100468627177, 0.008801214644336142, 0.04100094658497255, 0.06165171034808736, 0.04306554204958957, 0.02490262242645258, 0.051925048683187924, 0.059043135479441844, 0.033863066710182466, 0.027875400701304898, 0.06818762311013415, 0.08365048517589457, 0.016518856573384255, 0.0625605703680776, 0.05097695131553337, 0.04129019122046884, 0.020569018051901367, 0.0532348428532714, 0.0456568508525379, 0.011516656923049595, 0.004932365873173694, 0.0636032062175218, 0.04238109635480214, 0.03687079828523565, 0.013900853646191536, 0.018113297774107195, 0.05450214535812847, 0.05534879113838542, 0.03319286654004827, 0.017020587365550455, 0.012030418856738834, 0.10872254177229479, 0.03394822444533929, 0.06047294235031586, 0.02093625684210565, 0.01446995753212832, 0.023963861276570242, 0.026908395266218577, 0.046112651980365627, 0.039878871248220094, 0.009127092616836308, 0.027955127770837862, 0.01959868965059286, 0.07385937540675513, 0.005641104380629258, 0.017724083991197404, 0.06692166018183343, 0.04605126152455341, 0.028412967949407175, 0.043203960012760945, 0.02453042794513749, 0.04941062637954019, 0.07548237816081382, 0.01171550240542274, 0.048878124289331026, 0.030703410084242932, 0.06329143740003929, 0.011807397913798923, 0.025178860923915636, 0.005069194712632452, 0.027521694973984268, 0.04571963283524383, 0.0397603094461374, 0.044809106693719514, 0.048585250551695935, 0.03760812571272254, 0.04070743088959716, 0.029036435080342926, 0.024639169278088957, 0.029966602160129696, 0.04668993155064527, 0.032497945430804975, 0.07819697624654509, 0.06221931231266353, 0.04301039305573795, 0.029974001372465864, 0.04754360546940006, 0.09454847851884551, 0.031785828759893775, 0.002273484524266678, 0.025153921051241923, 0.00619843455751834, 0.06415131938410923, 0.03410441684536636, 0.034618398640304804, 0.04728589468868449, 0.059878905085497536, 0.04376047429104801, 0.06378372621838935, 0.10994233569363132, 0.054784647581982426, 0.04321546701248735, 0.021601236003334634, 0.04495391454838682, 0.0523933216027217, 0.04885306196229067, 0.07610051296069287, 0.032331132897525094, 0.019158885515935253, 0.053457327594514936, 0.059311084187356755, 0.01836909566918621, 0.027107565438200254, 0.030770142147957813, 0.025873282938846387, 0.04676096992625389, 0.02031536310823867, 0.030398391099879518, 0.018915542714239564, 0.039119268258218654, 0.07475124395568855, 0.010813613007485401, 0.023352147909463383, 0.03968987221014686, 0.04702821359387599, 0.028321205099928193, 0.041139713357551955, 0.03256706164393108, 0.02797741261019837, 0.01754789442202309, 0.04365584631159436, 0.03390437464986462, 0.013367970277613495, 0.04461339864064939, 0.031255890789907426, 0.09527975373202935, 0.04111397938686423, 0.051650249952217564, 0.014755988668184727, 0.020251772184565198, 0.019223459785280284, 0.021510300648515113, 0.024883087244234048, 0.015359121880464954, 0.05230287235463038, 0.062285738240461797, 0.09708367724670097, 0.060120114212622866, 0.086444589542225, 0.06173844885779545, 0.037500295366044156, 0.014065848845348228, 0.03896037444064859, 0.018498997487768065, 0.054207898647291586, 0.006271115862546139, 0.042580251683830284, 0.03000165379489772, 0.044616764280362986, 0.06905025846208446, 0.03979701235948596, 0.11762642141547985, 0.01138139215981937, 0.061898062558611855, 0.0995086002512835, 0.03084987292822916, 0.028110199527873192, 0.018199173537141178, 0.054143198212841526, 0.05678616420482285, 0.03296158363809809, 0.057324265799252316, 0.03173940371198114, 0.002613494843899389, 0.043058677183580585, 0.04176595983153675, 0.02727210143348202, 0.009059368858288508, 0.004081008846696932, 0.02365007752814563, 0.02314904806553386, 0.07164340408053249, 0.04899254119663965, 0.04509507845796179, 0.02654229938343633, 0.061771737891831435, 0.006667062780252309, 0.06768272520275787, 0.031993069787858985, 0.01737087921355851, 0.026213798846583813, 0.025894324680848513, 0.055749424718669616, 0.02905302022554679, 0.07743413749267347, 0.04619099308911245, 0.0234591080879909, 0.03412977974221576, 0.055289853480644524, 0.008959468359535094, 0.04490570834605023, 0.03195955810952, 0.009098134014493553, 0.035658930501085706, 0.02237866723589832, 0.04780225135618821, 0.02086780485115014, 0.04514802698395215, 0.04482784592255484, 0.023365194865618832, 0.06022134315571748, 0.017936251024366356, 0.08594802595325746, 0.049584467051317915, 0.06230455910554156, 0.01938614597747801, 0.03016684844624251, 0.019925223496102262, 0.08725813924684189, 0.03852391368127428, 0.05517540317669045, 0.02453364329994656, 0.02256886855320772, 0.054731617419747636, 0.07524223401560448, 0.05355681620130781, 0.03769727991311811, 0.04841882393520791, 0.03389281569980085, 0.026958874295814894, 0.023917673715914134, 0.030146990429784637, 0.019025057736143935, 0.08976894358056597, 0.006670526754533057, 0.1093046081950888, 0.14311678212834522, 0.1058201803243719, 0.17051783914212137, 0.2033521147677675, 0.13665395235875621, 0.1617001005797647, 0.1225224364316091, 0.09628401312511414, 0.1281971944263205, 0.058502480897004716, 0.2554672386031598, 0.1087581500178203, 0.11522028216859326, 0.104691032320261, 0.1352627223241143, 0.1496143889380619, 0.21642286417772993, 0.08698357429238968, 0.07444765360560268, 0.12144601801992394, 0.12826327525544912, 0.1415855681989342, 0.1682555503793992, 0.17100718163419515, 0.14183261431753635, 0.26035021408461034, 0.21952236973447725, 0.23338634142419323, 0.1432509475853294, 0.15495182597078383, 0.16750958806369454, 0.11659253548714332, 0.16863477299921215, 0.11195361526915804, 0.11988018290139735, 0.21830028999829665, 0.270395835977979, 0.19906861649360508, 0.15856093465117738, 0.1573631083010696, 0.233955004659947, 0.10102342755999416, 0.14573567284969613, 0.15531553770415485, 0.1370600555674173, 0.1331885828403756, 0.15990199550287798, 0.13042748178122565, 0.07438376953359693, 0.1287376560503617, 0.1319475338095799, 0.10780590775539167, 0.09696333057945594, 0.1656229150830768, 0.12103506858693436, 0.14561330754077062, 0.1941593986703083, 0.08678913160110824, 0.095339986437466, 0.08227817990700714, 0.1421722656232305, 0.11987223449978046, 0.14693296485347673, 0.12554705928778276, 0.14131603500572965, 0.12088732182746753, 0.23638423212105408, 0.08348969888174906, 0.1766308501828462, 0.11869277630466968, 0.09628502986743115, 0.09973298860131763, 0.19345147884450853, 0.22599254676606506, 0.10037887972430326, 0.17315289383986965, 0.14890642458340153, 0.1519833243219182, 0.12634313141461462, 0.08058709994656965, 0.09944427089067176, 0.11676049092784524, 0.12473952840082347, 0.14859040325973183, 0.16688909323420376, 0.17918793484568596, 0.1258844099356793, 0.1962617991375737, 0.2139274519868195, 0.17026859626639634, 0.1741243651486002, 0.16862113232491538, 0.1315326287294738, 0.17718441813485697, 0.15879784303251654, 0.16784152103355154, 0.14880647213431075, 0.1120554527733475, 0.17719615891110152, 0.14516917668515816, 0.09333645488368347, 0.19994823960587382, 0.09625970778870396, 0.10589049139525741, 0.2377683820668608, 0.18045786826405674, 0.12687237176578492, 0.10505513739190064, 0.18237026408314705, 0.13749464240390807, 0.15469955513253808, 0.17846751725301147, 0.11931102242670022, 0.12752837094012648, 0.13145725621143356, 0.14630277757532895, 0.12202956873807125, 0.08892293975804932, 0.1596865351893939, 0.144141316995956, 0.15819536754861474, 0.15146425139391795, 0.1963578033610247, 0.12933330377563834, 0.11959459705394693, 0.08818131900625303, 0.1262149476679042, 0.16500243509653956, 0.08136746822856367, 0.15630672045517713, 0.10512158929486759, 0.08221962445531972, 0.12189180386485532, 0.17084821360185742, 0.16794233437394723, 0.0764416485617403, 0.13257512357085943, 0.16600368137005717, 0.12720274622552097, 0.11257861493504606, 0.15557805018033832, 0.21225502219749615, 0.12253589899046347, 0.13783889502519742, 0.12878659326815978, 0.08872546910424717, 0.07565111285657622, 0.14780323690501973, 0.14306860190117732, 0.13653890462592244, 0.1422366691986099, 0.09334983580629341, 0.1640082392259501, 0.11783575901063159, 0.08943217180785723, 0.06807466823374853, 0.074115869065281, 0.21689590910682455, 0.10457424054038711, 0.19359953730599955, 0.1307009335141629, 0.18107174313627183, 0.08451618559774943, 0.06741357792634517, 0.14678845385788009, 0.10224492099951021, 0.1299065534840338, 0.167085480352398, 0.1320396491792053, 0.1560138986678794, 0.14200387231539935, 0.14373649028129876, 0.14895721717039123, 0.18960704997880384, 0.08089174414635636], [0.023230851293192245, 0.01857455925346585, 0.02048558024398517, 0.008879509368853178, 0.022530245332745835, 0.032590186965535395, 0.078284816845553, 0.07019079101155512, 0.0874104056856595, 0.014607159300794592, 0.027650366682792082, 0.012513496694737114, 0.027921998298552353, 0.00433773952863703, 0.03270817731390707, 0.019011723197763786, 0.02610763091070112, 0.015874781856837217, 0.09632372544729151, 0.019367725872143637, 0.02572369936387986, 0.01292566046686261, 0.027494836649566423, 0.04685363448516, 0.032493574180989526, 0.03306318736576941, 0.015738870497443713, 0.024982453396660276, 0.043473378173075616, 0.020222596504027024, 0.05492718446475919, 0.015288950889953412, 0.004222791058055009, 0.159200057387352, 0.03893870743922889, 0.07065518249874003, 0.05278507167531643, 0.06550560530740768, 0.030618369237345178, 0.025117537261394318, 0.02925014021457173, 0.025288548495154828, 0.010957278882415267, 0.028482369889388792, 0.006080480388845899, 0.07545983913587406, 0.019073740768362768, 0.025697059973026626, 0.03573267029423732, 0.017595876124687493, 0.05529895221116021, 0.028154336905572563, 0.004721006389445392, 0.02271581193781458, 0.031028224002511706, 0.022852174151921645, 0.062486711831297725, 0.024908318409870844, 0.058894813555525616, 0.015241837500070687, 0.06404820538591594, 0.01713732533971779, 0.05211697549384553, 0.040226014534709975, 0.01709839783870848, 0.016926035896176472, 0.04026491049444303, 0.012137805770180421, 0.059006358351325616, 0.07681521601625718, 0.04855101527937222, 0.07086293189786375, 0.007593286736664595, 0.005821101167384768, 0.050526382328826, 0.045669949759030715, 0.07311994399060495, 0.02256310577649856, 0.0034379617727609, 0.05290724402584601, 0.08227247279137373, 0.03909019462298602, 0.04592804645653814, 0.07306284314836375, 0.03279182477854192, 0.08606362287537195, 0.029846980942238588, 0.016391713688790333, 0.019899467260984238, 0.06797447087592445, 0.05954265652690083, 0.04753165318106767, 0.030344668884936254, 0.09908588777761906, 0.04906468908302486, 0.005200907835387625, 0.01094958281100844, 0.033978697028942406, 0.04430709574080538, 0.03970569850935135, 0.03424214090046007, 0.019079637131653726, 0.016082880065368954, 0.04841208894504234, 0.1338038084213622, 0.06650666604400612, 0.021266273215587717, 0.020253848342690617, 0.035807230160571635, 0.04670899361371994, 0.01640432277781656, 0.09418530855327845, 0.04143918107729405, 0.04642145591787994, 0.03073609983403003, 0.06967999303014949, 0.10718052217271179, 0.02061830036836909, 0.025399905898666475, 0.031578955095028505, 0.04569319753500167, 0.025632298311393242, 0.032024110114434734, 0.05023575358791277, 0.0524154969752999, 0.01705244962067809, 0.05339025599823799, 0.011433093877712963, 0.03964921364968177, 0.007672935416849214, 0.029694807271880563, 0.0724588536832016, 0.055270505690714344, 0.12196992975077592, 0.01064910205968772, 0.014147217916615773, 0.028456552427087445, 0.0756937640835531, 0.011103056167485192, 0.07456388877471909, 0.020337512505648192, 0.020274743510526605, 0.04517886321991682, 0.013283407188282581, 0.057591546574258246, 0.05116162734339014, 0.021645636843459215, 0.029978257589391433, 0.03660231894173194, 0.025132048103841953, 0.056965266703628004, 0.00611982627560792, 0.025533368170727044, 0.05633670472889207, 0.002467331410116458, 0.013022058956266847, 0.02141932818631176, 0.042558057757560164, 0.02102186728734523, 0.03559343967936002, 0.012094857684132876, 0.0799419435497839, 0.04863661088165827, 0.015067535769048845, 0.035329253660165705, 0.009011759157147026, 0.091395590279717, 0.05666308643412776, 0.046869913494447246, 0.06887331561301835, 0.020657721397583373, 0.02553128644649405, 0.05534830503165722, 0.03839949633402284, 0.009231874591932865, 0.04567197582218796, 0.027636503364192322, 0.03812590359302703, 0.022677133056276944, 0.04592799079546239, 0.041036302500288, 0.042081654610228725, 0.02134392041625688, 0.024522089915990364, 0.07693751453189179, 0.01028455633786507, 0.014924967344995821, 0.0776102788222488, 0.03219197649741545, 0.01306114972976502, 0.045992349841981195, 0.033633746788837016, 0.052917771390639246, 0.04079890430148225, 0.014812470744800521, 0.04538143613899592, 0.04750526240968611, 0.05015132686821744, 0.04631267562217545, 0.019660389953060076, 0.09769514013896696, 0.03643481250037439, 0.023670829832553864, 0.028960522649867926, 0.013682039752893616, 0.04166435610386543, 0.047622102429158986, 0.03191425741533749, 0.06627321607084014, 0.10473144226125441, 0.0326842690265039, 0.02896399219025625, 0.037563032819889486, 0.042159654331044294, 0.06404135536286049, 0.024483188390149735, 0.023731513392704073, 0.004355182782092015, 0.059244880903861485, 0.024289543507620692, 0.027428909816080704, 0.037350225684349425, 0.07129509191145189, 0.015669190252083354, 0.02662066646735184, 0.05402693335781805, 0.05414078252215404, 0.05617795563011896, 0.07339012285228819, 0.00965901954259607, 0.0071737928647053195, 0.03068818863539491, 0.07786646077875048, 0.043273870323901065, 0.021236732027318794, 0.03399584806174971, 0.03540310477546882, 0.08421195700066164, 0.07146276533603668, 0.06770822539692745, 0.04955988340952899, 0.042332136872573756, 0.03903452983649913, 0.023707198779447936, 0.04905535657599103, 0.0711400349973701, 0.006804297481721733, 0.06974037416512147, 0.008328763433382846, 0.03599281160859391, 0.05528584217245225, 0.02154875131964218, 0.05456386978039518, 0.031185524057946168, 0.035788353634416126, 0.04434234033396933, 0.09328696847660467, 0.04917054531688336, 0.029802568969898857, 0.08116604192764498, 0.08866485048201866, 0.02118796550348634, 0.0274154101498425, 0.030147053512337152, 0.012235980775585631, 0.018609265789564233, 0.027669014998537023, 0.0851272996806074, 0.047921310397214256, 0.003339967433930724, 0.08610956181655638, 0.0852796997060068, 0.058032534434460104, 0.01054325417499058, 0.034684794882196, 0.023967100751178805, 0.0625272627803497, 0.04362444604339544, 0.02451837732223794, 0.10356145387049764, 0.04697368429333437, 0.03844282291538548, 0.06229245467693545, 0.012389336316118715, 0.040470975218340755, 0.06444150654715486, 0.03729214149643667, 0.00790726900959271, 0.024606574152130634, 0.01826239709771471, 0.019583516441343818, 0.07991142643732019, 0.0303609924230841, 0.022430702920246404, 0.05874356014828663, 0.04612181008269545, 0.00994127221929375, 0.018970166638609953, 0.04069963462825399, 0.02979830162075814, 0.04864991387876216, 0.034818570711649954, 0.02777797340968391, 0.014119080315140309, 0.015755951026221737, 0.008572801070840796, 0.07010730681940913, 0.012026260046695825, 0.06426621868740767, 0.0541093191714026, 0.07745240916847251, 0.03300411241070833, 0.05337396214599721, 0.07379813338047825, 0.03165153713780455, 0.023747295163047966, 0.025205737802025396, 0.043901675308006816, 0.04592181612679269, 0.029474574948835652, 0.056133092803065665, 0.10557038825936615, 0.018088671458826866, 0.022454789323091973, 0.04584734902891796, 0.037451510288519785, 0.027034692102461122, 0.007915466958365869, 0.026797318023454864, 0.111735357058933, 0.009917866736941505, 0.1032495143590495, 0.0284471123086405, 0.08554741463740356, 0.028625268569157925, 0.03001976405357709, 0.07368592807324603, 0.05481368782056961, 0.03422162793867756, 0.05468945972097572, 0.01801660706405528, 0.029054923834337387, 0.029030796613369603, 0.0399326732440386, 0.10195556504186243, 0.0511523616296472, 0.04127891799726058, 0.01653836021432653, 0.02445098103635246, 0.040386997497989796, 0.034499948160373606, 0.024123380353557877, 0.10657684440957382, 0.10563963805907406, 0.1557819775189273, 0.12717199162580073, 0.08406469263718463, 0.12866105156717822, 0.11722291572368704, 0.15658677730243653, 0.18340915208682418, 0.06217557755007874, 0.09961048970581032, 0.1516814631759189, 0.07782936081639491, 0.10549116399488412, 0.11136777873616666, 0.170249508228153, 0.1330824408796616, 0.140063512371853, 0.11220095824683085, 0.1512086854199879, 0.12597848457517102, 0.1499775960110128, 0.07089156395522878, 0.11133837484521791, 0.20448057999601588, 0.10743238482973538, 0.08081340303760953, 0.17490330850705504, 0.11859628968522884, 0.0632834667339921, 0.1534811861347407, 0.09734451246913522, 0.15214781393297017, 0.1835617673350498, 0.1307206746423617, 0.14559096889570355, 0.1461487967753783, 0.1800031989114359, 0.1863574079470709, 0.15661683428334072, 0.10083317058160901, 0.08202726719900966, 0.07411544604110532, 0.156043911119923, 0.09464880946325138, 0.16055688145570457, 0.21180685405852273, 0.08740151475649327, 0.180998804862611, 0.11405107303289697, 0.09900289340293966, 0.16646980948280543, 0.12899877328891307, 0.105535277252784, 0.07365168537944555, 0.1635826175333932, 0.16487506771227345, 0.1226945107919164, 0.18911372957518324, 0.10110795818036422, 0.11061674755183049, 0.11975102694123052, 0.13708515500184149, 0.24041379714617506, 0.13233382167527452, 0.12259280687430874, 0.0910148536786437, 0.08273389568785205, 0.12965912144863978, 0.10882946298806928, 0.17205736512551084, 0.18477664823876694, 0.13830419193254784, 0.0831176083011087, 0.19926371227484196, 0.10967126625473611, 0.1572860882151872, 0.17805305746151134, 0.16923242452321574, 0.10317299151211046, 0.2447118266718462, 0.1660747642745264, 0.14252824417781085, 0.2831429347861558, 0.19840380060486495, 0.1507263191160746, 0.10279519381583668, 0.16006553516490385, 0.08374494573217817, 0.11033774455427192, 0.09772372024599463, 0.16342152695870027, 0.1342872582608834, 0.2118926018010825, 0.15240707580232993, 0.19437675888184458, 0.2005468707648106, 0.17116984556196257, 0.09433267681743018, 0.12347599971690215, 0.14792953559663147, 0.24843598308507353, 0.1450992515310645, 0.174436601519119, 0.23626091686310247, 0.16613811400020495, 0.15120018040761352, 0.1403071594540961, 0.2204568820889108, 0.14153786294627935, 0.19474100496154279, 0.16272178560029715, 0.1717282077879645, 0.08145542757119983, 0.1838277975912206, 0.21557602914981544, 0.12507502367952839, 0.12556718633277342, 0.1410210906760767, 0.1652900321641937, 0.15823434514459223, 0.06729985121637583, 0.13352234149351716, 0.15597238292684779, 0.07283852901309729, 0.17555947095388547, 0.11220449086977169, 0.07023252939688973, 0.13700090639758855, 0.05596738978056237, 0.11894774113898166, 0.14169184374623, 0.11692174477502704, 0.24042325210757554, 0.210884423868265, 0.08766194179770537, 0.09641235272283666, 0.2024273542338051, 0.20653304876759648, 0.13134488021023571, 0.07935922403703444, 0.111963626841316, 0.1408242285833694, 0.07489700918085873, 0.1296716192155145, 0.13752928585745394, 0.05778088700026274, 0.11564229702344164, 0.24033437250182033, 0.13367313105845824, 0.1968468341510743, 0.16291603533318266, 0.1453844885691069, 0.18701987864915282, 0.13290788774611428, 0.21412756468635052, 0.12603096925886348, 0.17686459701508284, 0.1377345935907215, 0.21337867830879986, 0.13884045300073922, 0.13687882310478017, 0.14576963352737948, 0.12319347151787952, 0.08532178690074943, 0.07554027310106903, 0.2814736368600279, 0.1242304893094115, 0.152971597854048, 0.15341422957135364, 0.14317930064862594, 0.08704484600457363, 0.09553502284688875, 0.17428987892344594, 0.07080729308654554, 0.22599135932978243], [0.03724441026861314, 0.02879886989830993, 0.029589394471258856, 0.009867679927992867, 0.05727136922359932, 0.041963430485338904, 0.020094629835512023, 0.06402237864676863, 0.013822933706251206, 0.02983686175866751, 0.053434914734680206, 0.04874604426731821, 0.054848943545948714, 0.07924706325866282, 0.06486466430942528, 0.04620394356606994, 0.03251842128520366, 0.0439276616089046, 0.020160569656582084, 0.0469161789806094, 0.04892025601293426, 0.07603466961882077, 0.03496777579130139, 0.009120929080381757, 0.022984385905147064, 0.054897246227483265, 0.027096422090835404, 0.017317463134531863, 0.0355506622872781, 0.0279776055685943, 0.03562088058970403, 0.04150590757490136, 0.01499524316386669, 0.05641432224365417, 0.05607330909697339, 0.033235799783142284, 0.06728318257955834, 0.01767538982676342, 0.0566722853545798, 0.08916710634366609, 0.06493804045021534, 0.02679630499187624, 0.0391870040766662, 0.060317703610053286, 0.022402048598451074, 0.05660464601533022, 0.025877195912471507, 0.03132941164949443, 0.023824858872103505, 0.025152290181722492, 0.034458243171684444, 0.050397593731759116, 0.12674349040025845, 0.02289465097419452, 0.014696213311253814, 0.05673233994457405, 0.07056375732645392, 0.03975586769229267, 0.03444049842073582, 0.02688731827220181, 0.059436043302412145, 0.036737282207468525, 0.036118750358582474, 0.017816347790358122, 0.014594532585761044, 0.018577162336441688, 0.05047106635174714, 0.04364764186902903, 0.026245015433232766, 0.038312846882035956, 0.05326535625499673, 0.012419021295499988, 0.015488584904232994, 0.00792269269368262, 0.04049452727485914, 0.03882707729644608, 0.024507655143679585, 0.040216054912889376, 0.05586755236436147, 0.11002585699316114, 0.03972730613895692, 0.0036701860426546773, 0.012805252572434256, 0.036578629587893374, 0.0027347448440195876, 0.0534760816663038, 0.029711828428844456, 0.16612428036751226, 0.03810150177741889, 0.02075769425573526, 0.017449995866627432, 0.013775067036476685, 0.06741702149156481, 0.029817729191563558, 0.021476308429555502, 0.06348727532895282, 0.042714521041489206, 0.03953051083954051, 0.008615289953013416, 0.05251669994322583, 0.032581292325630784, 0.019176747155142948, 0.02196140954765724, 0.03730621261638589, 0.0072572209319332615, 0.00737275430765294, 0.03738121406058781, 0.027190608052478638, 0.015380849181383383, 0.07800248902640305, 0.061722978789475746, 0.08393442345550284, 0.061577109663630836, 0.04941254483128432, 0.09160500951111317, 0.06369758513756096, 0.05787091693491675, 0.0380316953669535, 0.008545697837689659, 0.034543152287369594, 0.02343232583370991, 0.022506455788970925, 0.0267373988754116, 0.02708562940824777, 0.0382405542768538, 0.0196389827033272, 0.015436838657478802, 0.05300056167470757, 0.039169775118352845, 0.026494920675759204, 0.11080500815296546, 0.04382543818792328, 0.022728293006366584, 0.05347989630536176, 0.05598652234766632, 0.02128157630068017, 0.052592102147173136, 0.03841151912638452, 0.044796334332204424, 0.03282131401647348, 0.05191026510146912, 0.019535545870894566, 0.04945098437019624, 0.01102418071241118, 0.018471927651262376, 0.08021194429602474, 0.04102783459529746, 0.007624146628586459, 0.03468273542239331, 0.05372291627281811, 0.008583776507293805, 0.04803605756023899, 0.02597617985884426, 0.0335301281302236, 0.012293827476241859, 0.09419651498319581, 0.07670681792660616, 0.009864945113804424, 0.06128631765022874, 0.01014364012007718, 0.026421843249408994, 0.010040331308118766, 0.0240490338546806, 0.07924949750304222, 0.01496371394750895, 0.06702810642309487, 0.007417908891511615, 0.015597092460666317, 0.036917995166732, 0.02209533009590814, 0.0617972640611697, 0.014767543907510117, 0.05073413914942648, 0.016717546204745304, 0.0386968266684562, 0.1000760166789405, 0.004606818620231934, 0.03068406971578952, 0.009449451881664572, 0.02259793476696359, 0.050080711516784504, 0.015834672485652845, 0.051845486741513014, 0.028815709229093045, 0.05173324061615858, 0.07207525981357321, 0.03932681356673129, 0.03851246976410039, 0.0729160314949695, 0.05945286036876496, 0.0359790484799305, 0.045904995349701494, 0.026000481484516058, 0.1050618983572349, 0.027649956646200735, 0.04220050213916693, 0.010043372258223826, 0.02240269797766814, 0.017720363975968212, 0.05780309948022477, 0.013645714407175547, 0.033887668905663304, 0.05105891410494223, 0.01696021921816282, 0.03171900949382689, 0.0464631609065691, 0.021870789605600294, 0.021817852211825084, 0.04622185158950742, 0.06476278227637522, 0.032392586435889825, 0.026812571013579145, 0.022872035879117902, 0.025558593770256266, 0.02943896484794095, 0.07896204886492342, 0.03050745897780871, 0.03341687268402893, 0.027217490496695973, 0.01934383799380157, 0.02438229897961719, 0.09221062427968718, 0.029473064678313676, 0.03127776559267659, 0.03477136640867684, 0.07232007206766866, 0.05663160824042279, 0.03501001883705612, 0.10220294512691908, 0.02503274688933743, 0.034473197447368875, 0.04359691607533023, 0.028992665065743495, 0.03921735791664105, 0.006318963978628744, 0.025660073188191745, 0.013893011928303167, 0.015111687062017154, 0.03054935506952461, 0.09886580388410948, 0.05765223570051603, 0.02321135878446512, 0.024836064767441712, 0.023016945779090747, 0.08302331101731397, 0.02053505366347963, 0.02505225424101809, 0.019171542844560463, 0.05386991717386991, 0.02234698309621308, 0.006647623149547144, 0.06453509879065678, 0.028675421053776518, 0.03944335301639512, 0.048751936919870786, 0.09785709902644157, 0.046249233128037304, 0.025759988529898692, 0.04394598523504101, 0.03811730581219308, 0.011992155577900121, 0.053768113066325895, 0.02166270809539128, 0.06932972901267931, 0.04643257329007611, 0.022440560496761464, 0.02988266154716257, 0.036000641266582534, 0.020257173164281994, 0.014255179994506761, 0.014743522442586254, 0.01557906754896976, 0.039183816552395, 0.04107959939574357, 0.010987880414177198, 0.02437534505588701, 0.02686777566850651, 0.004817276858375408, 0.036840221800957806, 0.041766772483242676, 0.03073076564760413, 0.044249078346183524, 0.04660875543777365, 0.005371220986489789, 0.06321481807390228, 0.041341996839037165, 0.0454145730327582, 0.09066997023182921, 0.06468575476901606, 0.016823849582578987, 0.003026091380888829, 0.0495236072310945, 0.15411405998747796, 0.03040028543182416, 0.018500201622373424, 0.04061727478983812, 0.06358708676998504, 0.05973410836304538, 0.011126352183055133, 0.039282763391383924, 0.03753688324650284, 0.09027499923831783, 0.10447759806993417, 0.08006795280380175, 0.014853500379103934, 0.05012022716982756, 0.05612231310806237, 0.075339588947827, 0.032507055293535814, 0.03814631265413482, 0.03409479119000025, 0.09644252102589235, 0.02914606884587556, 0.008650182026030961, 0.07437153151840903, 0.02175009598431643, 0.07172397905378602, 0.017584712368261535, 0.06661195453489199, 0.02350121569179464, 0.021434360387502238, 0.13454426400130615, 0.04182655618933495, 0.0322070829133736, 0.02074772164633032, 0.021650763228535652, 0.010548753489274532, 0.06566259180544876, 0.017303495915257372, 0.10068045143270865, 0.030704180062457453, 0.10071053067804314, 0.01965348612429807, 0.03624760574894026, 0.035888124257326126, 0.02136510502168676, 0.09606399602489546, 0.025758543197298422, 0.011791572542279027, 0.020599130693881307, 0.011811708864115644, 0.06416046264348552, 0.04988833570678253, 0.07393526742816903, 0.013180114146962296, 0.051976921095047146, 0.04649217145924922, 0.03276688490586821, 0.023203668279165868, 0.04155035479925573, 0.02081109178106999, 0.028658963929046877, 0.09900837045279332, 0.11921987184905447, 0.09356493246741593, 0.09864670704700984, 0.23810551007045433, 0.09068224535440095, 0.14169962145388126, 0.06927659866050817, 0.13751059857895598, 0.20108010387048125, 0.23551201564259827, 0.10527696533245035, 0.20664858631789684, 0.1258996981778182, 0.10656071011908352, 0.12421137158526108, 0.10922078261501156, 0.27617553365416825, 0.10363293011323549, 0.17596990830497816, 0.13463125855196267, 0.0826576622785069, 0.14741497492650524, 0.12593707273481414, 0.13488971890183166, 0.13889428839320317, 0.096940034563886, 0.09535923774819821, 0.11869078734889627, 0.1812614212394692, 0.11271858398686163, 0.10563885880401358, 0.09798688581213355, 0.12643058609683067, 0.1831484356080182, 0.11246897745877504, 0.12758612487232313, 0.09186280192807317, 0.1322091111796908, 0.16960716457106173, 0.2421105100074783, 0.08489163068588823, 0.1090470829512924, 0.18081941292621195, 0.08576576932682656, 0.21745075355283916, 0.13449373858748004, 0.1050651934929192, 0.1450191589538008, 0.1101465302053839, 0.2139383170288056, 0.13506281742593274, 0.28303749044425786, 0.0648082239786163, 0.0952235063596163, 0.0873372150817886, 0.1667114972951822, 0.16063543036580086, 0.11182031812495552, 0.16609457961749285, 0.08308035248774104, 0.10113169948454015, 0.1317847362952307, 0.151512045704294, 0.13950563996331766, 0.1543495137593709, 0.08520528455846943, 0.0837562931701541, 0.13183808187022805, 0.14106897404417396, 0.13896903750719503, 0.0901747721945867, 0.15150616789469495, 0.1170419504342135, 0.13406266953097656, 0.23599015170475468, 0.11872945324284956, 0.12056892563123256, 0.1079475466394797, 0.15569542825687677, 0.18515217496315017, 0.14647373871412128, 0.1252900090184994, 0.11339670658344403, 0.06695126445265487, 0.1647557006799616, 0.10563078423729166, 0.28181279834825546, 0.1376581672229804, 0.18137087317882106, 0.13426287128822878, 0.15070580615429208, 0.15356988762505352, 0.13204576447606087, 0.07223738939501345, 0.10339499756810255, 0.15235842060064897, 0.09426033226191066, 0.07489789233659394, 0.12074280341039412, 0.14276485570007935, 0.11242491615121253, 0.12226136372191831, 0.15001746418420225, 0.0686184769438114, 0.12467096879845485, 0.13974232570035383, 0.08226370802731253, 0.1619771888363175, 0.10239875336992554, 0.14386890426976606, 0.37324034550692886, 0.10779407049994916, 0.1902433525538072, 0.150477729330305, 0.16574240085901693, 0.340724807465449, 0.13834973011398688, 0.15191759972367436, 0.11373796834959649, 0.16432418633485213, 0.10349106858484447, 0.08171143141225912, 0.1580569421639666, 0.11358456642483361, 0.12158637298853137, 0.21098589029861614, 0.30086556973401457, 0.17145999561762437, 0.09429726895177737, 0.22632738895481452, 0.08882899870513938, 0.09187363728415221, 0.22191993717569858, 0.1687411079183221, 0.21579604625003412, 0.16735269804485142, 0.06603171379538253, 0.23481119074858725, 0.13913655508076772, 0.11032492024241947, 0.09883734252071008, 0.23627786751603708, 0.11436180284363218, 0.12322970316745341, 0.28351074317470193, 0.13385786645812914, 0.07437168736942112, 0.14194148738170043, 0.15349292691098526, 0.08491051092278212, 0.23275616898899898, 0.11014580290066078, 0.216655675903894, 0.0944285029254388, 0.19990044529549778, 0.132020813471172, 0.11163132279762067, 0.14887154364259914, 0.11684399738442153, 0.12561925541376695, 0.08268244258943014, 0.0914751114032697, 0.11804661800852045, 0.10685748013202101, 0.17895313416374847, 0.12481846322771162, 0.2170416817534715, 0.14424561843043193, 0.11470907600596547, 0.28277744189836085, 0.10511617161682807, 0.20278833486372605, 0.16306908102706075, 0.12602130649611354, 0.13514754100469872], [0.03834987634036224, 0.025596465566195548, 0.009948394981620368, 0.04479767019802239, 0.04777606838615611, 0.008213515320676379, 0.028487466588558163, 0.04376538359792903, 0.03318144859804306, 0.04622347689291928, 0.02516399385058321, 0.06462271674536169, 0.02481009330949746, 0.039336402114713565, 0.03527217879309319, 0.06173280853545293, 0.015685096332163084, 0.0769582056091167, 0.029818139228154905, 0.015235900318657514, 0.01979129738174379, 0.025762953409866896, 0.045948017650516704, 0.06373395779519342, 0.05863497281097807, 0.04423086604219861, 0.019573128229239956, 0.07137693595723249, 0.03349245300341863, 0.02174010111048119, 0.014978149647504324, 0.021669435664080083, 0.041225943496101536, 0.042297812542528845, 0.022544437051692512, 0.0381302043388132, 0.0676986962207593, 0.048435525968670845, 0.016570105581195094, 0.06805640397942625, 0.03632611013017595, 0.10498840347281657, 0.03169032548612449, 0.014670491400465835, 0.04038405488245189, 0.035157231250195764, 0.030331497619044967, 0.021274501777952537, 0.01633283911360195, 0.0393362388422247, 0.07849310801248066, 0.010353693887736881, 0.03574261878384277, 0.01801014852389926, 0.059797610228997655, 0.018057913148368243, 0.015373577989521436, 0.06603930596611463, 0.04102858787518926, 0.05236162447545212, 0.036996187845943496, 0.03666433651233092, 0.04707725842308719, 0.0011491214013403805, 0.04866347662755288, 0.04312723678594921, 0.055899720755405724, 0.058610248161130585, 0.05681481852661818, 0.030271272335085087, 0.052527906373143196, 0.05364998913137242, 0.049013250827556476, 0.09366954560391605, 0.019276295133749954, 0.007467093337254482, 0.03979321256338153, 0.01430552822057507, 0.00876489857546403, 0.023046527785481885, 0.013828060091327643, 0.0813710231159348, 0.00999201656668447, 0.14476697717327625, 0.05009003660234157, 0.0708706428122241, 0.07884041086072102, 0.02465015491907252, 0.006182324850669829, 0.025811968553171027, 0.08851322229020298, 0.022410624114854727, 0.05059726485342253, 0.07737298452411778, 0.016731160903873388, 0.058235348551534116, 0.0234594179346459, 0.024633165303384885, 0.020715447499242146, 0.02563992758950917, 0.04982472622941714, 0.0962461339076981, 0.035885805045836605, 0.054033304695622064, 0.03970109719375614, 0.03220825921744108, 0.018953709513880312, 0.08540515977074392, 0.0755586486775428, 0.022775701399950776, 0.017134063600678928, 0.024446856550639495, 0.0327343083336018, 0.034165911201853305, 0.027681570281856693, 0.031765827880008146, 0.08421418344369158, 0.01261529338080436, 0.04315773163398262, 0.04999716053134762, 0.04017488798126578, 0.024415597290499136, 0.023556407359137665, 0.014600392769352766, 0.034018873193417676, 0.026421659567859024, 0.010341498546040384, 0.04428323940373957, 0.06661428487859666, 0.010745742674771463, 0.04036334154079668, 0.017785227682907134, 0.05025253725762013, 0.00944845647609327, 0.057792590669123456, 0.02957605065603275, 0.09933421039022505, 0.03473860058875289, 0.06366584348143078, 0.027814919376396574, 0.03432695353694726, 0.08266155113233253, 0.05041839613113552, 0.05201321582717355, 0.03241796788643114, 0.032799583932501264, 0.02262490255816374, 0.07849822140997276, 0.06475924965343438, 0.06951585222850554, 0.06797497553634457, 0.019980021825176664, 0.0375396366143832, 0.08200136624509469, 0.03572150839318056, 0.058014507667394355, 0.03741995416930877, 0.044664777524303645, 0.03778928024985362, 0.04547526586975437, 0.016033996653277427, 0.024955459630291443, 0.04552947233605664, 0.0024829315862007206, 0.03311485568701755, 0.03545070983818732, 0.09478596577537246, 0.009943882723746356, 0.02301348180481, 0.0489342120999936, 0.05997794840368442, 0.04766922509588767, 0.04056724290421698, 0.054952985228737816, 0.03841977180854883, 0.010316342522855848, 0.05616464150079992, 0.0508642265049275, 0.0793083943426609, 0.04190284154901747, 0.04323180910432711, 0.013302397819643375, 0.02494832759111887, 0.018178350728703663, 0.008374277495022397, 0.026622397526807617, 0.07764064008370042, 0.02311211694177473, 0.041127894655801356, 0.029720942002313677, 0.03379848501936067, 0.06133044204034377, 0.022122399932413828, 0.0780494001810439, 0.018026462785201147, 0.09682544696261175, 0.026831837167264894, 0.011258206777711166, 0.021408294305729214, 0.01261706618606695, 0.03880559583194554, 0.05067116791906301, 0.0344815577409463, 0.06674131829640828, 0.0393121153319953, 0.026685869706852827, 0.028286680390010588, 0.03567761777958367, 0.028978215450479183, 0.021024409143137746, 0.042651275216485374, 0.04810535931028426, 0.04038672661408782, 0.03137779225653503, 0.017825643190008122, 0.04784522170666605, 0.015965507554938085, 0.06049469840945676, 0.007106865987225319, 0.05624727964459453, 0.04155516762693878, 0.01778637986717513, 0.02401356105110608, 0.024303362297359854, 0.020418454842001665, 0.03729814176040236, 0.04790247468918096, 0.03525278647430241, 0.02142852154065622, 0.03149181582557503, 0.027916259641642682, 0.07468960859114304, 0.018026171492238063, 0.019040744882659055, 0.040032532924669795, 0.03235947180655785, 0.04485435172682628, 0.05516585173609201, 0.023712692527624313, 0.017738318383635487, 0.004806490205737646, 0.037497022494790144, 0.042592556492309086, 0.045237251688377, 0.01200062348289066, 0.004026949418403092, 0.024267271655844525, 0.02715703143621795, 0.04376545039121993, 0.017003178436425515, 0.022322662916849367, 0.04426764317031484, 0.020339787188277114, 0.009060867068910738, 0.02863477548089577, 0.03376838350959588, 0.0316063774516806, 0.02006034817895852, 0.03615494861151092, 0.10224959652987309, 0.025807614001678303, 0.04896496669971384, 0.061741680910927244, 0.016867858939804137, 0.0571705187758198, 0.04792527346580755, 0.09440077628823929, 0.03271599955041893, 0.01777245161065366, 0.023732029185339343, 0.03371664097358007, 0.05370968006900512, 0.06236908884602599, 0.023530365397164132, 0.0014768209985049907, 0.044958389698877, 0.02359397301916033, 0.03016308204678353, 0.07122803886886686, 0.034086245359503664, 0.027028656586480793, 0.026323900165152736, 0.09734443825436756, 0.013022089569858508, 0.016744584499974735, 0.0635239300027024, 0.009529324597679079, 0.02860403386875987, 0.02044259505055379, 0.04321139262174256, 0.031337998298113234, 0.03278276686614845, 0.0632029066036921, 0.030765462906856555, 0.03062260690057883, 0.02128155032551149, 0.0699138363415841, 0.007199385827334481, 0.019339592909091152, 0.026424769166624174, 0.026263103427481838, 0.04166692764556501, 0.021825256990268826, 0.016920851994655095, 0.0509777862316696, 0.016843273442646023, 0.04510322352871299, 0.048717059689806774, 0.058828242908930406, 0.031310605627368204, 0.030912836737115867, 0.060156731778988615, 0.024263373525172938, 0.013706225417990936, 0.06988213179283775, 0.013556681733462028, 0.016673238133080304, 0.0009692144840300898, 0.029802246135659516, 0.05021150762331672, 0.024724508839426562, 0.05240615333605092, 0.056053634762065485, 0.059669986803783104, 0.04084393411176279, 0.04990296714822762, 0.044443179649533704, 0.08185414641047828, 0.024753569487074856, 0.08312877762364224, 0.007079802644511801, 0.04213042484479956, 0.029612423313665204, 0.09868215202004649, 0.07328737250645645, 0.021311037708073854, 0.09458546715904959, 0.06178808740514796, 0.0201261729671387, 0.04847188378334977, 0.007896115457697306, 0.017375807074131444, 0.058658754933276214, 0.011801093369285809, 0.05385207223298494, 0.03707491858222056, 0.04216371387883555, 0.02430826789350249, 0.038341063336702064, 0.04572056051983964, 0.03753783319552895, 0.009645497611927567, 0.1494602151797153, 0.1334944664267823, 0.10156921038287692, 0.10411546711111441, 0.20498881756793708, 0.11430401922552846, 0.09880798315862194, 0.12961819942574948, 0.08214348010369577, 0.14289008569903672, 0.14790820627240464, 0.1469603055738844, 0.10449827430420555, 0.19709613639861345, 0.08707404951564968, 0.2062916726572439, 0.10538300339248963, 0.15013788506621495, 0.10421828425023705, 0.10595560001092963, 0.09564287916873582, 0.08387675115955062, 0.11001210499671288, 0.1573270992957987, 0.1547311112517491, 0.10583489711279981, 0.14220211480278522, 0.14458831254160032, 0.11854927462991327, 0.1035642295028083, 0.1420327418600209, 0.1135836832690984, 0.15584427339490503, 0.16879117320058867, 0.1719425548799336, 0.08815590786980465, 0.16044501011492684, 0.09416507018613629, 0.09295916184782982, 0.19843644025968388, 0.12026905344100669, 0.16929384466493502, 0.06087593224947341, 0.12263183642062359, 0.1586383258108981, 0.10113682030350901, 0.13222169800428674, 0.12042932023177855, 0.10147366629098542, 0.1360198762267828, 0.11330345572787337, 0.07810711700585671, 0.0846698546956759, 0.11864433632581495, 0.083207089046482, 0.1316430899896659, 0.10185769060626626, 0.16227668995270506, 0.08205333884689026, 0.17827858129749075, 0.12580128939589486, 0.13308079331181943, 0.10569751815637574, 0.14408271701540798, 0.08307024443638511, 0.11620823657722212, 0.1428313076030463, 0.14543465775204822, 0.11912207162822597, 0.08725400548428297, 0.16067071206634864, 0.08186685197870247, 0.25847599434200674, 0.15367476793471724, 0.055013195669744164, 0.15943632752168924, 0.06702110797050409, 0.13308606256032363, 0.14922685426427051, 0.10137712029973045, 0.1528075832175091, 0.21687726635718718, 0.14937612984795123, 0.3011351771419868, 0.10917125910054892, 0.1435646682512015, 0.15322156803449616, 0.07704962335992604, 0.1374203385785222, 0.11798107152571902, 0.16263332159724087, 0.16646283329464495, 0.11053018344682641, 0.12786695355316624, 0.10084934197948314, 0.10770559165393934, 0.15590597555274144, 0.10958990460494533, 0.07679007205297239, 0.13189055171096697, 0.1313056205981411, 0.1785703343921341, 0.1270833791932091, 0.11055852606659755, 0.11626404608250596, 0.10915996361291036, 0.18160686129704118, 0.1266785227926448, 0.11332473310176283, 0.131296789040789, 0.1357633454608731, 0.20140951353823766, 0.1228816136426758, 0.16189006069907919, 0.10526884623686783, 0.07916144168120809, 0.19273120968136936, 0.08349135387106799, 0.11991497478447855, 0.10994339696480893, 0.08839466419885866, 0.12670963362324983, 0.15911665483145043, 0.10775439528515562, 0.12932153331348673, 0.13277047168230638, 0.11246872512856498, 0.076032406068407, 0.13089966581901535, 0.08722503946046345, 0.19505573494825512, 0.10613329242914915, 0.1290455285925418, 0.10890590419876389, 0.1262806128943339, 0.20117177395150065, 0.13721854862524197, 0.18840917909983546, 0.15062975086038932, 0.09198719330015592, 0.12940100248670205, 0.24039942916715518, 0.09792628945433535, 0.15528844931395724, 0.13009777525439858, 0.10010901256464422, 0.12667010683799163, 0.14147060952382162, 0.13330051355296746, 0.22552779904799536, 0.194073858729098, 0.21277370920870453, 0.14154075732221827, 0.11013731273123994, 0.19904936518287286, 0.19773882144363597, 0.15580620121909305, 0.17342803766950965, 0.20544633676763624, 0.08405440647038631, 0.20887237245915458, 0.1358276599785313, 0.11903408259968273, 0.13092403794871643, 0.08845628472045064, 0.14370952063472942, 0.17971767985727638, 0.1040425882092677, 0.15839034458622336, 0.1911037985701114, 0.09035654642502777, 0.14097489940468222, 0.14969681185903028, 0.10144955391297117, 0.1262475724797696, 0.07715607702266425], [0.018537850774009712, 0.05149760501808487, 0.01005323540084646, 0.0280770218159887, 0.0645354921289254, 0.05111844548082445, 0.023614005440322217, 0.02148585244867718, 0.11292017356026918, 0.0689457640692126, 0.04304170797695406, 0.04179796866083052, 0.029257216592668556, 0.07085505771101452, 0.02496794069884345, 0.006530541932079359, 0.02094066334393574, 0.019776053668465465, 0.03504569016513415, 0.08620436376077123, 0.06590522956685163, 0.04716120645753108, 0.04795035805727821, 0.01800445439585019, 0.019709605476236902, 0.022410212222894188, 0.01933388764882693, 0.06986331834923476, 0.06300794440903701, 0.01971402125491295, 0.05666309756634291, 0.025574030441930518, 0.021179297218623105, 0.008820728489808971, 0.02763205047813244, 0.08346329326741397, 0.04559896333375946, 0.038100807869341224, 0.013731008511967957, 0.13816814142046496, 0.09538999234791845, 0.00459449201116513, 0.047060675133252516, 0.07749630720354617, 0.02083405383018544, 0.05064527067588642, 0.035176326709915884, 0.02190029925259296, 0.03946552096749656, 0.030796117316640448, 0.049698742950567976, 0.010518993367440999, 0.04868289121077396, 0.012121866293455241, 0.0165934758115327, 0.01168268741821521, 0.03724744565261062, 0.012736394255625783, 0.04110626847250387, 0.04888443996605929, 0.043934311252087355, 0.02745155830780277, 0.073431950295344, 0.009584639647073345, 0.0034926357920994633, 0.056909806007752195, 0.025315872517239768, 0.08355979472980835, 0.05664128955686465, 0.02889762748964131, 0.027252297222730704, 0.06441393576096743, 0.029302385555638466, 0.03646990124252625, 0.0647414084232878, 0.04294344391382765, 0.039723305962979794, 0.028359974894556217, 0.11706922436133027, 0.05752166594902519, 0.09473100231844, 0.07841539030778222, 0.01911811006721109, 0.04319875384680927, 0.05735170670959633, 0.04122246282349806, 0.02821871265041409, 0.040513448329875246, 0.018858610710594803, 0.057089632100542076, 0.10979492290061899, 0.02546226114645833, 0.012379591917124344, 0.027927775918215048, 0.052628879275289364, 0.032481569942319766, 0.0397237698052777, 0.013389997220656369, 0.06000423527439125, 0.05682258139131591, 0.02946362455986673, 0.07108434423571452, 0.050757943536154926, 0.021566726136370562, 0.020175796671537682, 0.004931872808811022, 0.06367855647113174, 0.05703639042621944, 0.028421953502402175, 0.05884130841877777, 0.07055407229927368, 0.053676491224905476, 0.03105454241449479, 0.05588859596173279, 0.037429030635394156, 0.07177000705269165, 0.07154069826356135, 0.037737760358140804, 0.04780947245308198, 0.12943607638590038, 0.0630142749287188, 0.05104448304336984, 0.020514069437922444, 0.03711628589371685, 0.07037402727291919, 0.03914242326573003, 0.007826800720067695, 0.05735625236411579, 0.02165808080462739, 0.03524610343447421, 0.0290727149695158, 0.029590440899482928, 0.020263104779587593, 0.045093579319654964, 0.03571836539776996, 0.03819383608060889, 0.017085640320146922, 0.03369761601788923, 0.02522800408769399, 0.02834926199284382, 0.05649930928484537, 0.11381501069990918, 0.050373733683954924, 0.0342509650363354, 0.010453937629790744, 0.039872321794973686, 0.012685084948316216, 0.058509765076451004, 0.10182082070969045, 0.027793645713245496, 0.0285093246930046, 0.04573711412376724, 0.05796426426968537, 0.04949176909576636, 0.03855605609714985, 0.03856184113828931, 0.01860664600826567, 0.06399756122846156, 0.057241649919888005, 0.013530193555197911, 0.02433100358757656, 0.061406864697346464, 0.02313328855962027, 0.03943418378185015, 0.031625053597963415, 0.06590517761651427, 0.018994776255567558, 0.051881017061532475, 0.03478747843473684, 0.030444485892076045, 0.024629220788483508, 0.07054750429233536, 0.06273815146414563, 0.01561421751830494, 0.02491180093784351, 0.008544485353922937, 0.052195542957633734, 0.036197688896209, 0.020171946780465078, 0.042895812875940464, 0.06453045294620097, 0.052017004491062835, 0.027315184961480554, 0.037208408684819005, 0.04313200508477166, 0.05437626597995404, 0.04815336513274815, 0.041483516979496926, 0.11895043513504788, 0.03205320972483605, 0.05124895214976277, 0.009144520099653164, 0.03305566940980498, 0.051897529847337864, 0.052586569436243735, 0.04762897842738312, 0.0691516135702841, 0.035794123832602054, 0.030514394347846974, 0.029893858700233977, 0.021812896520714276, 0.04500900045968592, 0.023988684260984883, 0.049380394993931986, 0.024499873725289945, 0.031374285608762875, 0.03849355984129943, 0.022691751510137692, 0.028964650846319273, 0.03811608869000338, 0.019643277883005794, 0.06775592322810553, 0.0404171843547374, 0.05340705822163727, 0.08649864015751518, 0.1581592991715297, 0.04311486889491789, 0.018439113591739442, 0.029512988512578886, 0.08425294581684284, 0.07877150244894437, 0.08291132835438475, 0.018737785358098336, 0.04960572587151546, 0.016042854185798205, 0.0025584594914107583, 0.030273201919044368, 0.04541110720310826, 0.07001336576649919, 0.05369321552279871, 0.02702155979932286, 0.049784924849518575, 0.02116629850206664, 0.014266052457969636, 0.060936313384445384, 0.007489153676942806, 0.0287089327321155, 0.054267515370156616, 0.03301488468423486, 0.04407102598634083, 0.03277357536717318, 0.024641987583891023, 0.02510935693862848, 0.07624825229868293, 0.020287710685806815, 0.026598997610562947, 0.02193002412241185, 0.02489687078195857, 0.025786911792238243, 0.05265884719847236, 0.008100647646642756, 0.03129969976725988, 0.018157648519263603, 0.05692393649951555, 0.04188874445389956, 0.03194211392838042, 0.025461602490395308, 0.041624747682362795, 0.032214997918345034, 0.04755873786052689, 0.05015301525418181, 0.03900245050317608, 0.03596301809011493, 0.011462045058578951, 0.037872946268180385, 0.03797403049247805, 0.04739727621199563, 0.035574180947151035, 0.037611253865179606, 0.09882350888801739, 0.029098066734150052, 0.008214088629756588, 0.00858146935570403, 0.037640906375600025, 0.028706689590762835, 0.01610603507288033, 0.04055204743053764, 0.03075412845646497, 0.04416032861627173, 0.03763334018003661, 0.07909713458502665, 0.03036607799003832, 0.008840880582283717, 0.057032193581108004, 0.03880646043398883, 0.05512196854397189, 0.04122277823626064, 0.029892893908254337, 0.05486440990353003, 0.03954676016292069, 0.028540982857521158, 0.09421497219591402, 0.07525313616497442, 0.011415430763008771, 0.05460390493681189, 0.11818338098237291, 0.04648558489861898, 0.05017024050175678, 0.04201718795229681, 0.024423330469289795, 0.019852541263389867, 0.040373316005570814, 0.06222362047992647, 0.07988671291968785, 0.00718881810826133, 0.0052333127860038076, 0.03069448946916964, 0.030283465821412392, 0.020994270525989123, 0.05355804445571266, 0.03174584926455282, 0.043539154721656814, 0.037195910917944275, 0.0052110715478193015, 0.015606267261318862, 0.04418859331053682, 0.061137828743085265, 0.10193853275268339, 0.033447931564296596, 0.024250426758953836, 0.034068333625327796, 0.06678451129118912, 0.05956082801276352, 0.05141007983183954, 0.07878867574618198, 0.04594976911903359, 0.02640445472934516, 0.053520258006756194, 0.018121723005606327, 0.02251766221888829, 0.058732372272061184, 0.04897691156656947, 0.03562973812222481, 0.019209717065677978, 0.08378963786526583, 0.013367226274567656, 0.021390404835983645, 0.006030755566825974, 0.04609871073625982, 0.03554091788828373, 0.03617620743170846, 0.020873046269116458, 0.04098431876627728, 0.04881585809926037, 0.07347477963776328, 0.05383290255849715, 0.034577936748974025, 0.10946693073492497, 0.01686803519987734, 0.03408171083719935, 0.055586308080819435, 0.07517453530454077, 0.09663003947935067, 0.25206179008819163, 0.0767399399774149, 0.09450197554542683, 0.21326086978660896, 0.13746710872510448, 0.13246547867311165, 0.1000937465869356, 0.2378715851227753, 0.2486430571298115, 0.14631101541453972, 0.1534193949191831, 0.1446981800836511, 0.1936990296235308, 0.14306998229585588, 0.1285927591379732, 0.1263547089183703, 0.10753986265626736, 0.17024187895003706, 0.2500438311835751, 0.12355361352092586, 0.1250532639096491, 0.18639582151081413, 0.1961407548515126, 0.16971352917607874, 0.11116071953438222, 0.09896975650917739, 0.16144279798027128, 0.17368902132147923, 0.1452685651020147, 0.17909152986248955, 0.0997549932799302, 0.09697443310869858, 0.09488188836257905, 0.1415116057614796, 0.16685663169482723, 0.12203331658383831, 0.17078872304409742, 0.13336559990420938, 0.2508336544269696, 0.17084088118281215, 0.10241819763905369, 0.15264974324963987, 0.23060566250933334, 0.21441057528136298, 0.11937316987314261, 0.13683732220670208, 0.06675243566860445, 0.11972505177254789, 0.19152098946506158, 0.10944007241050713, 0.06774270557798445, 0.18906082928879187, 0.12891822058008984, 0.07235306053189561, 0.11674103923724033, 0.151080739160534, 0.09508486575214192, 0.151930958381854, 0.25391469534952193, 0.1915402407757938, 0.12974506214959547, 0.157295691606123, 0.10835606182808988, 0.17191224556881934, 0.23321149143157527, 0.09481276472797617, 0.1707883074413985, 0.06495428606285714, 0.09825625573284924, 0.09786611612071283, 0.1850658780313097, 0.12849935243139043, 0.13033582654315978, 0.13975765847135335, 0.09968081561964937, 0.09765600669197738, 0.16783518309239298, 0.1322896935744211, 0.09277244491386227, 0.17378649499733, 0.14213593007298186, 0.09460973538807593, 0.1749260924407281, 0.16074589162599295, 0.10436715907417238, 0.13522411580197513, 0.11998192392638884, 0.21530367579543963, 0.11729324905900285, 0.1767720066709444, 0.09420975489774719, 0.11645829581539147, 0.11395031906431541, 0.14616334286984056, 0.10371649594162591, 0.11649158113868907, 0.1389762808685191, 0.1487159004318528, 0.1053183178009931, 0.10576492000836879, 0.14229713939130306, 0.15412229782668874, 0.0888531407690607, 0.18305341101950034, 0.06731636400218122, 0.07655185749172233, 0.09261724699172191, 0.11831877840450034, 0.1398786879144609, 0.14654309983598068, 0.18040519062196836, 0.1306253531947732, 0.12538895214674994, 0.13130023260600865, 0.27690203685779124, 0.19538505555829033, 0.09951770640327595, 0.11232595075853169, 0.155518633837346, 0.15894741547526792, 0.20546201092656702, 0.11614495364483446, 0.15990417741704732, 0.17703149118460715, 0.14322022267151624, 0.14828722109086812, 0.1661842458997853, 0.11144737407448702, 0.18165639223298058, 0.13904013525461778, 0.14939408982172608, 0.14276219881139696, 0.13460388814564794, 0.12584350275574252, 0.15424837387399748, 0.07793500553816557, 0.09299169760197401, 0.09196370432619005, 0.1462016673758626, 0.11676305875880644, 0.30793108278885484, 0.09623411111533642, 0.12733734212815762, 0.10680979714379646, 0.1343770432868041, 0.12144598833401687, 0.10449458583025262, 0.2368982436018996, 0.16053212340921164, 0.10746350308181718, 0.15015450917417184, 0.09519106708467007, 0.13888170156860724, 0.22018225776264444, 0.10660611471394077, 0.13809106196276844, 0.07784827073919587, 0.1854375159018673, 0.06895104816067033, 0.10564373471424915, 0.20006061560707167, 0.19282385939732194, 0.12406530950102024, 0.21933223149972036, 0.25954845710657537, 0.15139426686801016, 0.2578972972696647, 0.08323225527419709, 0.20010472886497155, 0.058758941158885136, 0.20461563603021204, 0.22088492318289354, 0.1213893253589049, 0.09951875283150002, 0.1739082220592536], [0.02705339422391262, 0.016385405433538835, 0.02675950003322214, 0.009731834434205666, 0.02519552770536393, 0.039725268943584524, 0.02427899387839716, 0.060889699088875204, 0.03417331041418947, 0.032255782643915154, 0.028769232230843045, 0.001352065278297232, 0.04813546453078743, 0.04978942597517744, 0.07534002681495622, 0.08683855121489614, 0.03849290675134398, 0.01700523789622821, 0.04903051689325366, 0.031616630221833475, 0.008196118451451184, 0.013505250899470411, 0.06464108490035869, 0.021016499704273883, 0.08105679778964259, 0.002405369964435522, 0.03838611170067452, 0.021995039969624486, 0.05088919606350828, 0.01552199175421265, 0.02948467001260724, 0.04946689230564516, 0.042782913660630584, 0.08137060751323588, 0.002612563912407495, 0.07116170570952818, 0.031114003286347724, 0.020130939410591964, 0.03662372248072643, 0.01411342978826724, 0.012998188703932101, 0.026408569938212167, 0.04252243466908112, 0.04340555700764526, 0.012585997101268731, 0.01595898407686036, 0.09675247158156708, 0.04890303447609767, 0.02942266914033098, 0.05924155608227011, 0.048186197745963, 0.028669418934441637, 0.03643551382992882, 0.038985407081781887, 0.05092996965686325, 0.031534693407593295, 0.00767147987971839, 0.01689264852757333, 0.02021582255110843, 0.02868701340048574, 0.07625003345310688, 0.030421408810070716, 0.05699127526895609, 0.04413563365233131, 0.06897518280311488, 0.042126376429223455, 0.0313430300593609, 0.0438080830645049, 0.03771419345866889, 0.00556083600713464, 0.038862570509081706, 0.09547399604343809, 0.030717542431375477, 0.04144254300626926, 0.060746104645659216, 0.029727754917985294, 0.01175819259515265, 0.07784497560351156, 0.008892100831872085, 0.04995186725864187, 0.057512812127242796, 0.035872973312507384, 0.009006814598251367, 0.0017010178976306634, 0.007201872485893546, 0.06856893858639523, 0.02271048702823464, 0.029181578756833915, 0.016076338033599313, 0.04429890985193197, 0.021454682246258017, 0.03257666132412851, 0.012834495046263328, 0.01592503824213054, 0.03955523177864961, 0.032005370885599405, 0.06456475501181558, 0.06602927955100313, 0.013701941370527493, 0.0457065153750591, 0.05150644399691373, 0.041708521312102675, 0.02658506935404148, 0.0438210520951543, 0.0018682753716348088, 0.0205383803404402, 0.048828927319846116, 0.06795486333430745, 0.02180094423238188, 0.010798921266541583, 0.042914874939015135, 0.05233370487985667, 0.010645209495123709, 0.061706933556706645, 0.03508279754896648, 0.0701693281007465, 0.011454450104793068, 0.027019847293558996, 0.11881402097060345, 0.028451437174226157, 0.020326384001236875, 0.032850079660420306, 0.03573962050722912, 0.005232361909293104, 0.047034763047122397, 0.052752257615793496, 0.06942723237443715, 0.03348157311847899, 0.02562942619988462, 0.050813908892450854, 0.07847407934605144, 0.011781467273976887, 0.04502592884819023, 0.031610663354513235, 0.06458505275077187, 0.013220945256762207, 0.042604445698088966, 0.06093493298976682, 0.05043894248956349, 0.034848590585170314, 0.019544280949048698, 0.033703508670441806, 0.058897841518046334, 0.06225068660569377, 0.015405556205223547, 0.039701880159555, 0.034894069394795224, 0.035526004430721514, 0.05201395426411182, 0.028094065237382893, 0.02717649425903801, 0.12324188923230395, 0.05189755953324493, 0.02323090324352961, 0.017364468913001474, 0.03178365797793958, 0.040648597132530995, 0.0024046398766586208, 0.035634016603580676, 0.058766410875250585, 0.06370255010551773, 0.06297293730312958, 0.033764984473236836, 0.03499867510981858, 0.06311780452961102, 0.05548264489334542, 0.048063068024930544, 0.07405907250358723, 0.046507589577231556, 0.06955985416425392, 0.03741311527846847, 0.058104901254409924, 0.07208619907032698, 0.013917890573793557, 0.03251564936363138, 0.028740692941937596, 0.07486555696232244, 0.12071713252225891, 0.04140656368690543, 0.012457843968149973, 0.03487462512566708, 0.025455884242546745, 0.019785117146966513, 0.06447928186389618, 0.0048574233369436115, 0.06958870144444518, 0.02121811525285011, 0.05819346544740256, 0.04400956502649933, 0.05998090586217586, 0.02410923501884099, 0.06662566200247966, 0.019802997339866124, 0.010566560395091074, 0.07338532857829705, 0.03998863117885776, 0.03809272588114254, 0.020734355566673912, 0.016207724147534464, 0.029184100203565322, 0.03075363678362919, 0.0516365202201996, 0.03737952938536182, 0.04783869822858833, 0.003148526034237875, 0.007119325255189324, 0.04821216920390725, 0.035991345866932534, 0.01181323676064494, 0.05960776885331143, 0.032929400404100306, 0.04558036140224431, 0.02065383996523451, 0.01707589592115255, 0.04896775717497803, 0.054610662191407755, 0.04445506143383682, 0.007595387478431803, 0.04193861306703184, 0.10864427487831563, 0.02625609384267591, 0.08587810822064057, 0.07517053512856364, 0.034958150135935284, 0.06520281647681259, 0.036294687597546726, 0.017627766210353002, 0.03360677343152929, 0.042522987569100223, 0.03891343731083907, 0.05273262409900781, 0.020095943436899688, 0.029162704086047597, 0.03131496203423012, 0.03474343568086624, 0.07387545774690807, 0.03800972037424799, 0.03526823427819181, 0.0810028807609342, 0.014868084508634638, 0.027145353742525913, 0.017428208266210277, 0.07473389996448532, 0.05441789675387554, 0.025076357342186384, 0.025264345204050187, 0.07306425322894938, 0.1288944570114836, 0.07523398133344017, 0.05810320915770717, 0.014237762716220459, 0.031629884979338385, 0.04242208888172172, 0.050130494782933965, 0.027997463585052174, 0.036113321548327804, 0.032711680250940844, 0.03286691528046504, 0.03653281310107559, 0.05193926452193409, 0.07812307318090461, 0.05737354440498166, 0.029398159713309724, 0.023372827854473144, 0.0558715302759083, 0.035001265205210075, 0.014751101625734009, 0.04290768723876681, 0.008021065295906737, 0.012097577655367786, 0.01640246184251737, 0.031162680752458982, 0.007913861136330524, 0.036064057785551995, 0.04247848839440849, 0.016209525711019523, 0.0160607380894362, 0.035707897404790856, 0.04510721999395173, 0.022966403666941915, 0.04743879566376563, 0.011597919310588622, 0.05568200060224626, 0.04277732157788705, 0.054078635075711645, 0.030195152103260625, 0.02533559138100827, 0.04933698306558654, 0.046816215399303474, 0.044779535819543526, 0.041919684590538964, 0.05521164224774111, 0.02141904431482544, 0.02411854155070614, 0.03540331257681828, 0.05864641301741358, 0.021475076464412268, 0.04177126618742477, 0.08843754549161531, 0.055933069161255844, 0.03275648741691839, 0.05324951511283871, 0.021573854464804754, 0.06035580918251071, 0.016529541644558776, 0.054215071504586376, 0.015320774182328023, 0.0992095295805484, 0.07565519466879778, 0.05384260985010769, 0.03751981756067835, 0.027089803988928907, 0.039636263172724284, 0.04131659683480393, 0.08356458900379948, 0.021734805886808317, 0.02473354819812812, 0.047543241817038506, 0.011925475464522606, 0.019122677986160852, 0.037178845232119784, 0.003183839276061917, 0.013251661821414018, 0.03212484924006276, 0.08393918062211014, 0.026662620075512677, 0.05542919541767333, 0.03279058539192192, 0.021535283194680233, 0.030156044631439727, 0.022145942712086253, 0.014640043864346808, 0.08313282974995673, 0.021077897581562866, 0.027297777887724806, 0.031103205037652515, 0.06329048002953641, 0.05961465969448909, 0.015817207895452157, 0.028086576967325527, 0.02465418292558752, 0.043360523486626334, 0.02473068165272707, 0.02434241967421258, 0.012084186528227292, 0.02263742258946877, 0.07165358634665608, 0.0166284216902568, 0.04914147168165073, 0.010076022117573302, 0.039198692902573384, 0.02505438977095764, 0.1120341605565045, 0.28024333412759006, 0.10087804083013907, 0.09610879948013462, 0.09539768841932528, 0.17704091646010056, 0.18271058332175016, 0.14517411938868463, 0.18283915298525244, 0.1318338219425641, 0.13478952896548435, 0.13631802663439885, 0.1297096913913265, 0.15354109229519963, 0.10898001506575383, 0.2543259639060125, 0.1697956255520694, 0.08407483037444763, 0.19754703564103693, 0.09975594322895631, 0.14277545356890187, 0.09776269784197211, 0.12404058114043437, 0.11308285233099014, 0.1883884286507964, 0.18353171035414562, 0.1900217027286999, 0.14612671046052128, 0.1597399401362054, 0.11488817850477062, 0.12356755105429329, 0.2125853966572322, 0.12611609359737486, 0.17748222715454176, 0.1280009260517545, 0.1859965015319176, 0.1293027272913605, 0.07635593792656437, 0.11222699278732762, 0.11993761771009304, 0.1410263153957203, 0.05406955118814949, 0.18408656964311376, 0.12057012791046873, 0.20591492881067097, 0.18097294843755662, 0.23772364540491253, 0.10967495472868904, 0.13118395290803164, 0.0960899489291478, 0.09269794070860371, 0.13321623526280746, 0.12940128450281918, 0.10258340713335201, 0.1030920454650186, 0.19943220948334783, 0.1300776333664544, 0.1436771036242135, 0.1329032122157514, 0.16678498475812376, 0.2259405073709786, 0.13859652390237898, 0.15376238588942215, 0.1300771880778484, 0.15927633532555774, 0.10262535332003608, 0.20024729543365538, 0.11424919677665457, 0.11496110193547793, 0.09569462912622839, 0.13478206295985729, 0.2093445713398978, 0.10103463398991153, 0.13758978573605418, 0.1114316182793118, 0.18498517689295113, 0.08613685058662668, 0.19105248647974804, 0.11470392550108954, 0.2183369966223836, 0.13914167589973658, 0.10000189096899703, 0.08697967801708728, 0.08504721452482045, 0.14937578846001998, 0.17397387244272977, 0.08544349169824272, 0.10956015932606533, 0.09806242902413942, 0.13191225210903212, 0.22855936840642244, 0.15841039741644636, 0.0690807236242108, 0.12181947415228933, 0.07534200834925286, 0.09709420832223259, 0.0972910926793702, 0.12059173925081268, 0.11938096984522417, 0.08392412986722775, 0.09065728692803532, 0.09920175929437391, 0.101817688846495, 0.13873955060262233, 0.14079252403462306, 0.07450489545590244, 0.14222331054043025, 0.15986068756319582, 0.09736566367791966, 0.10202158649917692, 0.08585407747887075, 0.13555679091950879, 0.11203850954188965, 0.1290302848792635, 0.12176462201750837, 0.20980952685931697, 0.09561339364154264, 0.14233164925826713, 0.15579573693685234, 0.1452522081672214, 0.07794996723532677, 0.0733636949735228, 0.17848699120804667, 0.2791566221276298, 0.10431057773530483, 0.14222041616449133, 0.12092960940208286, 0.10103068576427177, 0.1349448159453459, 0.1398913044249639, 0.19642933155409992, 0.10890686899074353, 0.1985767952282913, 0.11839809914818034, 0.1360078831203282, 0.1572841586312279, 0.11902877624379471, 0.18705924216192216, 0.24281440739287063, 0.0639452101313509, 0.0763895497948397, 0.19470265076961368, 0.13750746671576053, 0.10529974184464663, 0.11286742170341313, 0.20332423970103264, 0.11707959216437303, 0.1093285127717536, 0.2398325173999183, 0.10214726178674027, 0.17811765399528667, 0.19927960907807574, 0.1573538314551115, 0.11817093516583554, 0.13583937106886879, 0.07936724665341899, 0.17321701539913192, 0.11324744584271684, 0.10827949445229024, 0.13235290971351787, 0.10907048286753707, 0.1251044127275236, 0.122004216973437, 0.1381405780557543, 0.15095264447154477, 0.16024756914703175, 0.133592355705332, 0.09873846618575044, 0.11827361871837638, 0.16291927109705284, 0.125649698311463, 0.1153240047278814, 0.17184427968459204, 0.11975836678175256, 0.10781819029944018, 0.11151162179885432], [0.02150718733901158, 0.03606889658840373, 0.0640595899312757, 0.06745163525920361, 0.036606641951948404, 0.10583262614090927, 0.007221397927423823, 0.05175015045097098, 0.024615446527604945, 0.030780842062085867, 0.031006818608148023, 0.06616021666559391, 0.042099132188013755, 0.06958097568713129, 0.026827217297977768, 0.028151780206826515, 0.03201690014975611, 0.027896503670490347, 0.004148894950048998, 0.030454608786385506, 0.023777621172484942, 0.04030982527183369, 0.06914001380209811, 0.08624660680652596, 0.009183158163068583, 0.010977640631608665, 0.026548832138360012, 0.06251696177059785, 0.09179140732157975, 0.01750741768773878, 0.024879641823645215, 0.01524526065622922, 0.018754782395262737, 0.08582229129387997, 0.021277537161950022, 0.05307993807946332, 0.030992396823421586, 0.022364521901181433, 0.00786518738095765, 0.04267979966243729, 0.005700605142919812, 0.016983622845145874, 0.04267174364940729, 0.047653844085289165, 0.09493752717389725, 0.05206963760429062, 0.08679554375703447, 0.01753320546413306, 0.039166973510873504, 0.026245889312122017, 0.047908538035699166, 0.04252939972502645, 0.028299682817305438, 0.0421884904790204, 0.05963717645499855, 0.00988436248007929, 0.02492378105671378, 0.06712097136187367, 0.041892477456713095, 0.14296956971520558, 0.0406186514737783, 0.06496912901639007, 0.059040704945800826, 0.014208842148946133, 0.03960562731663231, 0.0195776330656372, 0.04911056123091839, 0.06115524323831778, 0.05946612625848502, 0.05292665118759032, 0.031835196423344314, 0.0015274071756721241, 0.018576826514618006, 0.01754532102495432, 0.027420623737270944, 0.03992238707724027, 0.025701568520162255, 0.03621530377131421, 0.0405906539526768, 0.04086875524080824, 0.0068857027326885145, 0.048309130797861144, 0.03706984600285068, 0.028127966543252114, 0.06277758919168264, 0.007646230160389678, 0.03371199141838588, 0.08948280112235807, 0.014897674864187138, 0.028146078657300677, 0.05285611747240182, 0.03912973254045937, 0.03698589796840679, 0.024805206267046742, 0.07156844716519117, 0.059922558211837895, 0.10334945196518674, 0.009775303878996056, 0.030233471043175086, 0.031021604045236018, 0.03471473311947193, 0.04139425145694986, 0.043582522121141665, 0.01269490170670906, 0.03517744735290762, 0.06805445955251344, 0.06611078963032924, 0.1242590842593927, 0.07178156229201704, 0.006649544848187361, 0.019445987200015225, 0.05672224302543327, 0.0539748679875629, 0.05390522113884799, 0.05341303622117266, 0.014377701154444367, 0.037829063076060265, 0.053945801773807034, 0.04869068376137875, 0.03533039656758774, 0.08192681008949876, 0.019834128579532262, 0.05123706294398289, 0.01759393355314387, 0.049746195873012766, 0.034323242798564024, 0.07404140938888304, 0.06189680461829994, 0.04117517688428052, 0.007912589280749671, 0.017561460881552193, 0.04513585947279353, 0.0707916782994289, 0.0795587504399009, 0.03199833903636318, 0.060901176402694546, 0.023080046885297634, 0.06087112684326712, 0.020650765618484, 0.021885502683289815, 0.059711702924687415, 0.03585860162274912, 0.05508877969987225, 0.02269333414005814, 0.025392690367880277, 0.031192014139378443, 0.021098507022543345, 0.04086757151526399, 0.04892783334071282, 0.017118754949478898, 0.0299936905503273, 0.0435879806173034, 0.01609124035894638, 0.004964486024618964, 0.026186233626503963, 0.0255669967373251, 0.06689705798635259, 0.05190643190871924, 0.019103447084489744, 0.037028938822913915, 0.08486374077619985, 0.04513104664511047, 0.0720658122736495, 0.01989070064155385, 0.02590107080322923, 0.018456260913808364, 0.03938240042771213, 0.03479570885247085, 0.031221533063217066, 0.04528285295236856, 0.04744438403577078, 0.06586666757357307, 0.045742305446765386, 0.022960000787861645, 0.04912866592349019, 0.030685416713822633, 0.03654327738331631, 0.025776996699278243, 0.04049702831252944, 0.053623884086846374, 0.05770550335000735, 0.050569259910844266, 0.03571158587874379, 0.07636042049853131, 0.01714391190034803, 0.021769792583654635, 0.029591379716293886, 0.03894213987223338, 0.02218648438429227, 0.014438615708058933, 0.02027734288276406, 0.04688696804805659, 0.028191900710226037, 0.046503674748237245, 0.0617023173981579, 0.04492925669183023, 0.041477550112176687, 0.020673384424299, 0.036246648378437385, 0.053888355832896195, 0.03292176370450761, 0.03467837530479301, 0.026453082100488245, 0.034697077426244505, 0.03449428557360079, 0.023333310346060898, 0.04227072415233124, 0.06093658055760898, 0.03751688236661721, 0.011224366699025268, 0.05613083667412866, 0.09639760624850169, 0.06915069330716506, 0.03491303126793355, 0.04177561146207154, 0.025293227736256085, 0.030234304103942122, 0.04323152708820999, 0.07781968321069144, 0.03830460904282518, 0.03502686187857762, 0.035845766178681515, 0.023609049749211408, 0.0515708327293396, 0.04884272384515498, 0.034034821946988814, 0.03337059235491324, 0.027808162121800706, 0.05062956683104858, 0.056646184020792134, 0.028014165618515108, 0.04145210928982124, 0.010683193540899083, 0.08672769661643542, 0.058729366573970765, 0.02474560067639686, 0.01380759536914411, 0.010429141548229381, 0.04115925410587806, 0.03931372208171524, 0.04037657403387129, 0.04332441429141909, 0.06056450481992215, 0.051781109141302295, 0.018376170191913843, 0.030767989919695538, 0.044675861499854364, 0.022360555121849757, 0.06497452442999929, 0.07749221796984784, 0.053731413863715716, 0.02616224555822555, 0.023374594165943563, 0.06368447138811462, 0.035179310143576004, 0.049335339208482765, 0.01515903051767964, 0.044404302243492566, 0.05900111507799011, 0.05690432524716016, 0.06489715553470887, 0.04617653976310976, 0.025306296956841834, 0.04023078283353243, 0.04767029378854204, 0.040750616462901235, 0.014876287095830776, 0.018354124695179053, 0.06016521452693269, 0.0054887818168936064, 0.06373051422997378, 0.06561049303854816, 0.010500974949536612, 0.05446048118756153, 0.015870226925471798, 0.03190225688740611, 0.0231829901895253, 0.023544996838609222, 0.010954701774608111, 0.01890817133244127, 0.024410190744674765, 0.04033398588944692, 0.03278360178228468, 0.10648628012859263, 0.08995310010504909, 0.06169864005642012, 0.03692675250931643, 0.07839318524929695, 0.07355828609433956, 0.01740851908834884, 0.057898784580174834, 0.05053359600424301, 0.006266754353418946, 0.0681026472011581, 0.039679905166849494, 0.015529408592556138, 0.045667953381780535, 0.04625107365427539, 0.044434826777433045, 0.041715991028468125, 0.044257479457883164, 0.03254208466387354, 0.13003068510442972, 0.022054196560929995, 0.02833180667948909, 0.014162537700030953, 0.0490829162299633, 0.0413505760661792, 0.03279480450146366, 0.03781709594477434, 0.011788782067014836, 0.002614461259327072, 0.046874043546267785, 0.047176969674183056, 0.06693618401186541, 0.054017630536691286, 0.0628796048113145, 0.032924383485806175, 0.05353025844669901, 0.042979378704330884, 0.018384491522738244, 0.07048794694128446, 0.04919541839626618, 0.03242540049541276, 0.03015952715941239, 0.03150572367303539, 0.04328565191826783, 0.06823858639108948, 0.07732683778158389, 0.030965978221502155, 0.05831132220919244, 0.00046476186525978846, 0.052348332610563375, 0.05418790147814434, 0.06506909630843438, 0.032366032392019406, 0.08052507866523229, 0.03511588249239139, 0.08822392570436932, 0.019249041615694296, 0.011828771766886348, 0.005437666859506862, 0.03348545826156624, 0.003194671153323725, 0.05127961027028505, 0.041300340089946985, 0.0877675716765225, 0.089526372612454, 0.03406645599170588, 0.023579814696859103, 0.0668361499265302, 0.08369413830223493, 0.1413471161504276, 0.18366712261922657, 0.13797214021906257, 0.25342259206809103, 0.16525565588381141, 0.18397186329821125, 0.08027789896004833, 0.12233681045472622, 0.060645528792520054, 0.16698901599738747, 0.11158264533150941, 0.196902361640241, 0.11392046988476068, 0.19649631780339405, 0.22885591577505693, 0.18292889348231256, 0.14445520093431696, 0.12994177581276745, 0.10351795659516938, 0.1743314095074311, 0.13253924815217033, 0.16541498014703393, 0.22280203906120732, 0.15655651252018288, 0.18899599526776, 0.09851122798863798, 0.08484289384796284, 0.11488638250739314, 0.1275701983831823, 0.09386804784298874, 0.16246727347606793, 0.15891677961917594, 0.2400902207591571, 0.1940524551901035, 0.1265010901261121, 0.10692477808333933, 0.16943581751547754, 0.14130381925497204, 0.1545944670215249, 0.1539292058441788, 0.0687400036258623, 0.16639598063193262, 0.20666170748881996, 0.1695911044953391, 0.26112837076652795, 0.12682187603786588, 0.16086613439256325, 0.16133601777255535, 0.14454937947448343, 0.07160516121075489, 0.16255447582807392, 0.08673635005834512, 0.08908906951546669, 0.09578505239915103, 0.06513012311188504, 0.1162712746008765, 0.10953616569167934, 0.22821199876489118, 0.13652242894750088, 0.165451968787238, 0.10426872802781872, 0.12121261999709532, 0.16311945801135153, 0.1241759117692709, 0.13575831369962543, 0.16989407886285335, 0.16691765107680112, 0.10560599650489166, 0.23446002131095156, 0.12807248393073678, 0.1755876577226445, 0.1333680489915423, 0.11999209877103567, 0.15647551452275366, 0.11331768269883469, 0.11612936112214811, 0.07395239619654603, 0.12890170037280768, 0.16151367308339104, 0.13324841478606686, 0.11762894471758045, 0.13203409791458398, 0.1480099101900123, 0.22684579394990578, 0.13922117475885898, 0.08440432909992523, 0.14082747919019312, 0.1946510566631332, 0.09733678671182133, 0.17276567086810246, 0.14459928148426116, 0.14253562112571672, 0.11177662046975456, 0.10166715903324075, 0.13938242860604078, 0.28941049065906554, 0.19667844084324315, 0.11050886896555312, 0.16161196312168613, 0.08255549822933972, 0.15643043647287413, 0.1718347059795633, 0.154756982519757, 0.2087455097353086, 0.09760749249835499, 0.09974065498681739, 0.15154498221818358, 0.24211192008806393, 0.11959953233599663, 0.1159340055892244, 0.1244151133869309, 0.16942501184530556, 0.09614648573915474, 0.13531213451642543, 0.10037570333224721, 0.0839382158301305, 0.1692995592020452, 0.1490723539609462, 0.13036726391874254, 0.07585794199258089, 0.16923454706557095, 0.17520806402899325, 0.11278056816081516, 0.11345063845510595, 0.08492817403748631, 0.1319762400817126, 0.25440026773139834, 0.1749641794594936, 0.17158534436021, 0.10264015916618519, 0.1307231534156017, 0.09531931762467138, 0.22440751228714362, 0.16123087028972805, 0.0692517144489102, 0.11645094855339266, 0.14264385594287887, 0.11921561192139052, 0.22376693494152278, 0.08614982332801446, 0.22695907537126914, 0.139823294011876, 0.15122878277907148, 0.1685765737784095, 0.06752009838237427, 0.11688921644235961, 0.16772357892477885, 0.12653442739974707, 0.09938141840393655, 0.12110670810216106, 0.159028799389489, 0.24844425061019138, 0.22007084655342624, 0.1328668321366422, 0.10239787021419033, 0.1226511322602164, 0.16094297636300325, 0.12268476639292203, 0.14366717368829995, 0.09836596742388792, 0.23625837871804833, 0.08073369637713768, 0.17588025686563924, 0.09290438392781653, 0.13124800025252625, 0.13332227332284674, 0.13700632407562807, 0.12946221482707188, 0.1386502108653076, 0.1981302598142065, 0.19550270080799237, 0.15186342294327915, 0.18057699780911207, 0.11600898476899602, 0.15678328316425905, 0.1493465478415601], [0.060128548720967956, 0.026599188713589683, 0.019345851069374476, 0.018154551908082794, 0.01917960813443642, 0.0433711770165246, 0.0691690985695459, 0.041337944712722674, 0.020639683498302475, 0.1112060499144718, 0.05608427803963423, 0.04936002675094642, 0.029865629257983528, 0.040736615846981294, 0.046205947364796884, 0.06090517286793329, 0.02596720543806441, 0.014618824934586883, 0.08572595310397446, 0.045142698363633826, 0.10951707023195922, 0.023621174586878624, 0.04752364169689827, 0.006132685375632718, 0.08414346419158392, 0.028830533628934063, 0.05214530698140152, 0.018292583954462316, 0.007558972611150239, 0.0571618430694798, 0.1029890205245465, 0.032484575640410185, 0.08719178382307291, 0.023983307401067577, 0.07430476791341789, 0.02332953652512515, 0.017168347112601623, 0.08212985427235253, 0.042513235748629086, 0.08878803215338849, 0.069632339727832, 0.034666037099668756, 0.030297885750769638, 0.020550210174405947, 0.009826450841501355, 0.03795015189098194, 0.0530980464827735, 0.045998387213330716, 0.005393820774770575, 0.14442075043916702, 0.03717643325217068, 0.054287976381601766, 0.018416131133562885, 0.12429445501766168, 0.010806686914293095, 0.006407093551388243, 0.03281811164924875, 0.028467408192227595, 0.04249871562933549, 0.04098473065823782, 0.01696845891274279, 0.026457052590558305, 0.03127824056718964, 0.01623249703698093, 0.023289685050258413, 0.03238270102883689, 0.07373070184257813, 0.05597861105343327, 0.03064419412112329, 0.016868020356923807, 0.061074653422110714, 0.06378706588293426, 0.06657075049588457, 0.02115456143656047, 0.03231627881177701, 0.01899962247989606, 0.021653839430655353, 0.04819271751330234, 0.010683184264053125, 0.08402451276197098, 0.009912080768117448, 0.0567038229200989, 0.02759663333563367, 0.04255420972185675, 0.04858905405853875, 0.03878116433043033, 0.05309601670887787, 0.0025799198510867427, 0.06990052221226506, 0.014234167010727106, 0.01190386505186325, 0.06613637146074325, 0.05416804531705566, 0.036402454861672595, 0.0203288572083693, 0.14038987923413515, 0.021442893230414484, 0.05841110767505597, 0.021800103750138078, 0.10731942253187299, 0.03155428981699515, 0.02035721467109397, 0.05401770475145895, 0.052201031139702536, 0.028026989930367563, 0.08347613242221996, 0.016621085560473148, 0.01969169930816861, 0.016994161342154257, 0.022840461206214968, 0.049550016556167975, 0.010974976321449503, 0.002961739987767942, 0.04006703165941872, 0.0638847250957042, 0.059414101706352085, 0.06490668471087702, 0.057427146020927466, 0.1859802336548455, 0.02055334574833978, 0.0391211384703638, 0.02358964815357467, 0.023465151025447994, 0.04933421856549103, 0.03598594674258493, 0.037994795784470625, 0.04533641003945377, 0.023153461988840718, 0.05166603914403822, 0.004696644928117166, 0.010158714994759066, 0.07169827847974375, 0.06030136893969029, 0.02223370538558811, 0.02437245253531728, 0.03258730001107324, 0.098526672081789, 0.024240650818683207, 0.05684364354237914, 0.024213371325458866, 0.052329456084407866, 0.054930331170908175, 0.04662269668187946, 0.02202888561441796, 0.09166130883386359, 0.05584952930803411, 0.0532814534381032, 0.02123435344401514, 0.11724238967872225, 0.02212180621427251, 0.02017668910411885, 0.036450905972742476, 0.02449055049510207, 0.03971678619564045, 0.03474482349702157, 0.030880302838340867, 0.021731841006840114, 0.010240364226774545, 0.012791150838893373, 0.023449821965186857, 0.0573700600216398, 0.02997916115418775, 0.05365717312088236, 0.05009529100789223, 0.033874440123327076, 0.022569490101886913, 0.08416314594796859, 0.016146545203810092, 0.023743877572997008, 0.03400024157599546, 0.04543354232737329, 0.027149891975568607, 0.04757698356115725, 0.03648780184448697, 0.030112662389001343, 0.05025712001952343, 0.033557591304997914, 0.03746125097677577, 0.06820448470534757, 0.025694970827316865, 0.021133252521394752, 0.029388816074060742, 0.04660828417399898, 0.02049698705377523, 0.06619553547352552, 0.07042759549221955, 0.06198500515893102, 0.05245252643362619, 0.04332275559136178, 0.01716405378829222, 0.022080450034991372, 0.027916311591980048, 0.04589384829159826, 0.017554119185660966, 0.031008952282718383, 0.03951499253162183, 0.07549537316663191, 0.044516188427223824, 0.027534498876775615, 0.02185718789405655, 0.03295252572570462, 0.036248841424821876, 0.057942233615904115, 0.09703764182631858, 0.03742703054740559, 0.02258160380733898, 0.022264823637669906, 0.03224378953746054, 0.013780083954770816, 0.02837347270542523, 0.053810641838936135, 0.02426283732347656, 0.007207321705209324, 0.023994335715542547, 0.046067239964031614, 0.04684832812927198, 0.036737430637003854, 0.03067250148887979, 0.032091085231513716, 0.02099283261486562, 0.00805210469479789, 0.03958599379984662, 0.04956578719429672, 0.08794539768132381, 0.015743494077469222, 0.06972900446271524, 0.04460095653485041, 0.03511804585286882, 0.010777928691823035, 0.047678884147899225, 0.07192066303105094, 0.030158163463056553, 0.040515615401091054, 0.032667374034645036, 0.05153830068593379, 0.03609211838920601, 0.05284683691570535, 0.05659695736540016, 0.027645023219520226, 0.03345741621160414, 0.06520945127704181, 0.06363713720929809, 0.12992104020668194, 0.04374142336018849, 0.01578531038830988, 0.02039802166109439, 0.017286535985476803, 0.016811381501611322, 0.01772560539393453, 0.017711532418616116, 0.037598882263409905, 0.015449560924025718, 0.04257075590430759, 0.08583923452533782, 0.02443821980705252, 0.02964625040476676, 0.05825867054227274, 0.031439294034498744, 0.05737358151236549, 0.0587913507479243, 0.04290583929105196, 0.041062173768295906, 0.0394293041608762, 0.02255764356959844, 0.011362691893737065, 0.012528540955827339, 0.048594716645311564, 0.016577345231780782, 0.03199156322807539, 0.03256967400375288, 0.02003670892008813, 0.1428358643897809, 0.032775174695416354, 0.018111670615326148, 0.08281387694296427, 0.02562717563705519, 0.058160996486549266, 0.014971405380492797, 0.05509476883162279, 0.09933496738085523, 0.012482483271014644, 0.045823644832125865, 0.039501240535173565, 0.027754477014241274, 0.017478217887401115, 0.06234333632164635, 0.08791446496616118, 0.051732806459767744, 0.012363781388557982, 0.02389042576396605, 0.06509407699923031, 0.021731360466219485, 0.0287184934495599, 0.03738190054718871, 0.03889878360496368, 0.09185558825265616, 0.06242279807338491, 0.03590883388824295, 0.027416931552579626, 0.03573093366867397, 0.0960897930781357, 0.040651272574905306, 0.023607574730704073, 0.02351802533667069, 0.0734923908021301, 0.029114663011569064, 0.03753680161025841, 0.028940362208231818, 0.06859591565444134, 0.04125834195292555, 0.05939781156484969, 0.034358498523943126, 0.03267584565037396, 0.0284365552579402, 0.022272042879194487, 0.040580638669780456, 0.06316593280644156, 0.05874440248589963, 0.06425110856071115, 0.03649205435067415, 0.06796163914259523, 0.061253629755810834, 0.06624137793551199, 0.042441878249519505, 0.05224974200245924, 0.04127454674744513, 0.029163978724682238, 0.016343049210263416, 0.004182442808087217, 0.03465547633823007, 0.020673378858191427, 0.04699407109001186, 0.006396909429895459, 0.00658115083751909, 0.03889772604452446, 0.03335475121275522, 0.058228921552654356, 0.03277757925388869, 0.0655493103840854, 0.06114622614404652, 0.048778249765746295, 0.018667450167413335, 0.04317589940910693, 0.011690963292494416, 0.008545596720068716, 0.0077982493712625, 0.055693010363029316, 0.015250565156748053, 0.08067514092545025, 0.05855627176060807, 0.02549582663050387, 0.0489094466320239, 0.2417394213262014, 0.11218601881409995, 0.14264357392676175, 0.11562655607121997, 0.14997468679212034, 0.08874610823113471, 0.24191830860218033, 0.21057147503597662, 0.1392236238461919, 0.3176297654863447, 0.14552850974723697, 0.12291947059566155, 0.19984708487754688, 0.09777832005056553, 0.1533984811976552, 0.09840104874456301, 0.1309503396623768, 0.10865798234590329, 0.10908964512054808, 0.11507163741043769, 0.15903608727967367, 0.15175558888586238, 0.12204107944853604, 0.07531862327596173, 0.12331067890045233, 0.08452997470158152, 0.17938714212505147, 0.15469890204258263, 0.15271477022906765, 0.10634861915605143, 0.3064863884355873, 0.1672233862336725, 0.11642030527582392, 0.16476380493259057, 0.10366530259489082, 0.11786646166001447, 0.06322623972664587, 0.11220657630474307, 0.12900129659101367, 0.17237785417819396, 0.17129696061601862, 0.17547735973494127, 0.10422079270938411, 0.14595273620216176, 0.11733880950487219, 0.12080229396815412, 0.2151890585082583, 0.16511708206962794, 0.10031143334344961, 0.24115778534905985, 0.15740045317215845, 0.13811602781061083, 0.0706627598265186, 0.1761213954887353, 0.1016394620819483, 0.08391520183067769, 0.07846444626920857, 0.19458371418295428, 0.1612553166341968, 0.14058519765967503, 0.10290333215380087, 0.1642154617002234, 0.14393019082490355, 0.14676604099804536, 0.15633806877303869, 0.12015666259685531, 0.2611151902237907, 0.17476075678132474, 0.1385560174821876, 0.12046431249473244, 0.23205402307212353, 0.09858029967290349, 0.18517852120567113, 0.09148298559011891, 0.15493070444790646, 0.07635661328095011, 0.10907172967563383, 0.14280653471359983, 0.1653913056361489, 0.17290195886744186, 0.09663042539614253, 0.1406766302534379, 0.11087485909229144, 0.11938163035665639, 0.18212332186521962, 0.1213187025859952, 0.10138785175513476, 0.1278551237192005, 0.1512555149383843, 0.09529056682367809, 0.1497864632983692, 0.09214204983436503, 0.0844949453312438, 0.24587989290012047, 0.08027976917219348, 0.30580619524698704, 0.1342054142151028, 0.20006575126899406, 0.20989013893995434, 0.22534931253176183, 0.140772664162796, 0.1257598478696309, 0.12595405307365581, 0.11166382144438103, 0.10879303838009946, 0.13270954135805368, 0.11693061343976296, 0.16511547903064638, 0.1248811895493418, 0.15209883218631148, 0.18165021756431088, 0.12771444220561534, 0.13615582283819094, 0.13087146420730278, 0.1365383851225488, 0.12746134016197175, 0.16394594334997237, 0.13322902988875285, 0.2974412706680596, 0.17916044569574296, 0.14010928804054856, 0.0826790212886408, 0.2048170252237469, 0.1569015221321024, 0.18689893826376647, 0.14274737070081756, 0.11662156088277698, 0.13323674822458997, 0.17152236570836976, 0.11153763407492079, 0.04653822543332353, 0.17554526624735445, 0.1163539127446711, 0.09136292093899101, 0.16465318039990962, 0.13901861297199503, 0.2194958899053745, 0.13257077458547428, 0.07773323784931563, 0.08155661940691061, 0.15164493466727436, 0.1602272194577381, 0.22480562998680398, 0.17521729634609073, 0.14651477948063985, 0.264949748525396, 0.13870711874915287, 0.08808903294266202, 0.21967556385789067, 0.2126076610875316, 0.1061416044831276, 0.18442607251927257, 0.0948653236264363, 0.09504557645414025, 0.07436146057443693, 0.16850063722813502, 0.1292100182035938, 0.07526835761382245, 0.11904356724699028, 0.1587524829665199, 0.14027806726517156, 0.059871995690627955, 0.28704850177746266, 0.19912666728487238, 0.13051045389147475, 0.14181389735313132, 0.1271201897179708, 0.12178591423435137, 0.09719339635921642, 0.11917260446352884, 0.13380668795434758, 0.07685804535867646, 0.14014407992362976, 0.14691516815219074, 0.08641174208605662, 0.13484045513905585], [0.03652850864455104, 0.008544831380277174, 0.03789075039094314, 0.04508697420533281, 0.07201679341960698, 0.02330645944311982, 0.033592479667277075, 0.03935415799787734, 0.04678218421759084, 0.030157695910020266, 0.04775831621373072, 0.0508091183291981, 0.06562417082022876, 0.016527784609934315, 0.0356249809556175, 0.013000944854866248, 0.043260396632831544, 0.009799487688724184, 0.04229350437526591, 0.017115541450039018, 0.039439052270608954, 0.036987534404033795, 0.07563820690847933, 0.05380953232815955, 0.046270039238152094, 0.018036502187896986, 0.04378964440547861, 0.02820904803229496, 0.03786792192840949, 0.047165792930172756, 0.02310154875885928, 0.0468177590664709, 0.06948946145712398, 0.03647423167421948, 0.007348977287620073, 0.021815488471474964, 0.044210200940142386, 0.051612678726087324, 0.08219569761422463, 0.016421379186795093, 0.053907967085251585, 0.01741347849019803, 0.08804621844319627, 0.048349273565690964, 0.021742362805525772, 0.034708461971604265, 0.033356272615492344, 0.052218657147022896, 0.02133624289854197, 0.023449001892004162, 0.010677546724764397, 0.02346236982702976, 0.0268201279322966, 0.03757381622563116, 0.027743973769247532, 0.01676926462096162, 0.019637952973425854, 0.02870791042369092, 0.02499673231795896, 0.02316445690667024, 0.031553480876027606, 0.019301838001410943, 0.12400308041833341, 0.04188386112218723, 0.06351716161589138, 0.04432216504937969, 0.057068436362897046, 0.010701335340854712, 0.01810984864277998, 0.023031723794701975, 0.05580165336141363, 0.09565043423208408, 0.08393277588766068, 0.0256757083843695, 0.052055184278287925, 0.056032910288195126, 0.028810100448026787, 0.08079730585450307, 0.07360487812547944, 0.024856943236954976, 0.028612499918381218, 0.06836730448412709, 0.010530029103392735, 0.03845455627015326, 0.04367252979136538, 0.06858985230792314, 0.019246896808908787, 0.048747484033810906, 0.084629904886242, 0.05624094912491273, 0.06312085475656204, 0.04321766005887184, 0.059651462797774, 0.018519905643188395, 0.028124430209572893, 0.02738387443969259, 0.08416392520302907, 0.08096543198917061, 0.02025626032263972, 0.059432978232507594, 0.025932688149623573, 0.03947313169192057, 0.06510000675916672, 0.042760998039739206, 0.03266788611654192, 0.03337886730150785, 0.08998055956908502, 0.00976429226284381, 0.023878143219917547, 0.05212709467741661, 0.03098177483479958, 0.07166552008129656, 0.05419261782662943, 0.05491578136570752, 0.04542485548881814, 0.054302756252582185, 0.07112674313248135, 0.05418944885605015, 0.03418173007958103, 0.0861695347703062, 0.01366488872008631, 0.03344628028571606, 0.041927202546503395, 0.042910466581815854, 0.05158654028491583, 0.07200936452136375, 0.059404991843621247, 0.044883447626489215, 0.020650344449677505, 0.06786664423998445, 0.023645251712878235, 0.032812849822221324, 0.03773770840780344, 0.029019291469012387, 0.05378615838708356, 0.045249122340464965, 0.011972381980740465, 0.019662879858515225, 0.022289963890216313, 0.10093851102283224, 0.021585585964203347, 0.01883694185380591, 0.04687404725700617, 0.04775419358338695, 0.04263963091943879, 0.012720362010441022, 0.05103276824229397, 0.009921329783537658, 0.019253600257798098, 0.03822750360995997, 0.0595895825244952, 0.003800063973358192, 0.04541841735772323, 0.029148965077183675, 0.06313364938250743, 0.06333675293717533, 0.04566466566757299, 0.010392954427516088, 0.023369167211058084, 0.04526630676991772, 0.08009200581000187, 0.03578280608053319, 0.03140096210699994, 0.05641330550133716, 0.02460287454596255, 0.08133466530125588, 0.018830418375728186, 0.021282782290654723, 0.0029531950849559507, 0.07564097511931323, 0.06743445454048924, 0.04204747499898076, 0.034727431266219355, 0.058848128755926155, 0.04366026209027041, 0.03968008328229189, 0.12683041073614731, 0.06438899217755534, 0.03279031821875833, 0.04692261340096593, 0.10574431056738831, 0.07536088858614676, 0.029816421156283468, 0.03585832331737038, 0.04037952778162435, 0.008247514961112756, 0.03574825168470852, 0.06216266789124347, 0.051978101109853014, 0.02716528411838226, 0.04797847432200797, 0.0064941368054860504, 0.03878181742038578, 0.03291587476269342, 0.015770200261613354, 0.02960279209219152, 0.010789226962515386, 0.04506600111199077, 0.07949162318254821, 0.039765801338944584, 0.03497881152725313, 0.052044397161807865, 0.0224794824316632, 0.011794527217716677, 0.03826477055554278, 0.06821255927206948, 0.03959193098125979, 0.02916274304880062, 0.016727637557778507, 0.059988772627548315, 0.06178125593578443, 0.10122681313077919, 0.040981932761496864, 0.03717708634212613, 0.03766682588320691, 0.09290429487009533, 0.06364619141095318, 0.02190136794524733, 0.04906183181446977, 0.051626749846036546, 0.009644666406529723, 0.11058043426601216, 0.06130652633146383, 0.07880828328779899, 0.03590821048419457, 0.04287128118448891, 0.06232416664715856, 0.039611545944353566, 0.06210203442606144, 0.04776197500177659, 0.018193488685938064, 0.016035564440244343, 0.038036485930206254, 0.011268862162978621, 0.05918470757023897, 0.020144116242590826, 0.06704546525725164, 0.002172535278077703, 0.02111429064825643, 0.03414785474888049, 0.06303121073869988, 0.04148591782723088, 0.058974568455596454, 0.008513925567967817, 0.062073951557977125, 0.02406515701295575, 0.03805648681009188, 0.027656268612190615, 0.048090093332575634, 0.006064227354727336, 0.0334980599291157, 0.06834631654783152, 0.051073801587335765, 0.011704152184393024, 0.024276496551465243, 0.040975127267302014, 0.09013873350340873, 0.05987385105981957, 0.04411074944073334, 0.019408729531278368, 0.0309754406043794, 0.0832105622976087, 0.010687594476621598, 0.052759141035494395, 0.05039251373091247, 0.021351981995394453, 0.01714981197437737, 0.03337667054438498, 0.06704839674057439, 0.02421054188744165, 0.03402484748221468, 0.016789653273008298, 0.03681261761812493, 0.030806995346210897, 0.028313323491602205, 0.03808501496678218, 0.01056042839991278, 0.046723090708837844, 0.020052674371981993, 0.016391724821005482, 0.0237360664687003, 0.011719420945155434, 0.03274883587437216, 0.026456807681825012, 0.046728842353331856, 0.04386326174426358, 0.026070764724863693, 0.032310527167283, 0.09270597074646503, 0.019639253587229177, 0.060826501503470354, 0.02643828182044672, 0.05226916400715709, 0.028157483611721545, 0.010538288279349217, 0.05728471303882543, 0.0369570135808317, 0.016513568771188147, 0.010044531863968587, 0.032544515197514556, 0.04708301377831958, 0.04593831778038293, 0.019619213744590525, 0.03657159773865715, 0.053822130284970626, 0.01885104637040058, 0.015614562616974581, 0.006146761597847217, 0.03402204587473534, 0.06722228936268948, 0.09700017821160145, 0.056040610070340335, 0.03309799409180414, 0.0359375290281605, 0.028345857390377205, 0.11059933676733635, 0.04492432140978053, 0.030978362810856197, 0.0250205367046874, 0.04765272344229743, 0.05980599278700538, 0.01904254088003654, 0.02120435397955589, 0.01153924140453455, 0.032469116704305634, 0.027780331583926454, 0.048852256732061505, 0.025162049423670396, 0.12454265146516263, 0.07652283951756544, 0.08835009080939926, 0.02797399130940903, 0.04758388924528845, 0.038194370426936075, 0.02535544197598938, 0.007323242853090051, 0.08825769342365675, 0.026900845768977888, 0.015269413852365687, 0.0673678913153708, 0.015772320948599372, 0.06480219773948193, 0.04120209086977411, 0.004309451642257045, 0.07401472175843082, 0.026205332796962466, 0.020818760021938942, 0.04211836123431567, 0.018461882682458963, 0.058074491753359325, 0.0048431267896376085, 0.06792018277337775, 0.2183554315706715, 0.11613385111559182, 0.11766289055231027, 0.11078204610385001, 0.28540710860397667, 0.1632788119604811, 0.14085354341659695, 0.12984486616915092, 0.09255002325517125, 0.11823260021628812, 0.11440770467743278, 0.19179087888915092, 0.16055579792009667, 0.07945277175167575, 0.19300608633784577, 0.06205832563864533, 0.07816730518243276, 0.14331031939946115, 0.13561847823439166, 0.11947652135859244, 0.08571887301513925, 0.09510157149634324, 0.2109264294267632, 0.13617569755297154, 0.1290934713324532, 0.07742411107756197, 0.08891356643289328, 0.10048051684862003, 0.12533535424154252, 0.176436748879496, 0.20288879197323695, 0.10431146089104004, 0.11626328167039901, 0.1478320619207807, 0.19058616540860385, 0.19070799637120217, 0.14137493184534833, 0.09038514879648574, 0.13349902321351692, 0.2330168557818979, 0.1292904670117423, 0.09536081852274947, 0.18644781637704, 0.12845908349845558, 0.17019469320075586, 0.18171948962844908, 0.10729185174568556, 0.19037938822293654, 0.09654041030444205, 0.11250768788158894, 0.1436296061729081, 0.1734762327396311, 0.13803486654069275, 0.11333351270877756, 0.1693518360843882, 0.07532152507337742, 0.08697118042618968, 0.09595639945473522, 0.14788058353587985, 0.1342941602342762, 0.12649029929889366, 0.11542681444552727, 0.217665427189786, 0.13502551708370447, 0.1375781191745773, 0.18037385714706033, 0.2750159427523613, 0.08723917737370357, 0.16195957025047392, 0.08422261424129829, 0.17153927183244377, 0.15641909645637497, 0.1712608031812124, 0.18260309065226465, 0.14803110592765734, 0.14874855492962524, 0.17092622816562653, 0.15020013641333207, 0.08928569412091747, 0.16395385464420542, 0.19821766996756196, 0.1875811946229078, 0.1199449723935686, 0.1126678433502093, 0.1454009345616214, 0.17684151622233912, 0.103488604654558, 0.11054031376261264, 0.18101740308338776, 0.13327487977221608, 0.11097852227976546, 0.1408282807096839, 0.14409500698093325, 0.15548876981483772, 0.16646476287860423, 0.0898398928984534, 0.16890283674001694, 0.24532761628506705, 0.12805105070583522, 0.1451587866176851, 0.08679750302690081, 0.14722838415764272, 0.18677072483114898, 0.11011651033186354, 0.1423829613486305, 0.13714246364543214, 0.19361099606612697, 0.1749022101284936, 0.12236182083142921, 0.2023591657052748, 0.09648978098994121, 0.2304893679684028, 0.16092201811261475, 0.12796353665180504, 0.13492649974068627, 0.1518938658409752, 0.16604050673777238, 0.1452113306731917, 0.12477483978727832, 0.2015962527366355, 0.10187706066062674, 0.1559707650449127, 0.131490133353509, 0.0929339807771612, 0.14146594883641228, 0.1471372929518111, 0.14506907580653206, 0.15194332256214693, 0.11429824531660415, 0.21718827076256275, 0.12362891182419844, 0.08442729114904068, 0.13342274527531117, 0.22544116072822362, 0.16815487062558532, 0.3011400159448385, 0.06354983837809414, 0.16498670156579465, 0.12654477293835953, 0.2471984369913116, 0.14095616759732366, 0.1829485158668831, 0.11514540688949637, 0.11567017951165326, 0.11555908000445925, 0.09494038444245234, 0.17037176963640377, 0.08730342509807087, 0.10816918162163347, 0.17893054318847135, 0.13092322158627212, 0.08044028087169863, 0.24286591244162992, 0.1269645316642709, 0.2294319708016701, 0.08061313448706642, 0.1585665304446593, 0.11266641842667013, 0.06660339757218026, 0.18078050954500213, 0.21922745509073138, 0.11678337876219302, 0.2035701132263057, 0.13868532929336652, 0.1190405095985625, 0.23517197842011228, 0.15411892847623676, 0.13667299586813897, 0.11920163728063926, 0.21281420078594238, 0.24901533324737102, 0.16906352655496448, 0.12078866813681088, 0.1790195712237619, 0.13644101534737274, 0.2256935799960047], [0.021415389237517957, 0.017017453646985814, 0.00976437204371905, 0.06761169424862601, 0.01124338423323934, 0.027065736139775254, 0.03305078607809264, 0.05762429384049028, 0.04383607687486801, 0.02512232596927788, 0.020424184222065378, 0.005842590981046669, 0.040749399340711534, 0.053254572849255055, 0.055270379525609314, 0.1065564427699428, 0.00830527167636319, 0.016105350441648625, 0.03840285455225967, 0.04385988497233484, 0.05415944011474494, 0.05384624266298488, 0.04417788040882442, 0.06077180150896311, 0.047183600763673894, 0.050793162154150195, 0.031914494902594015, 0.094790715520503, 0.030353758338605985, 0.049401026699342765, 0.06598139618290588, 0.052557562594302, 0.14554860710632056, 0.018364922943874262, 0.01059165890183067, 0.030924128514016047, 0.02727593277086271, 0.004980858266208088, 0.0074456596485106274, 0.03281310957390815, 0.032394742374890484, 0.020882497519778553, 0.03107940065092407, 0.026159438384638634, 0.03418651322135702, 0.009840110069490038, 0.025883600646920968, 0.05926577236095909, 0.018122086657967884, 0.041455226310063154, 0.04442473356903065, 0.043044023477705196, 0.09675112829427235, 0.014428443646465894, 0.07084458600729704, 0.10704467204050161, 0.026010103429143783, 0.0222485798803973, 0.044586054209503345, 0.04457712988369167, 0.005048799102951307, 0.04408293745655101, 0.03165195645124186, 0.03786278626648709, 0.018546854880696628, 0.03145439302898012, 0.03713610865816008, 0.04959510202752426, 0.02367074448557105, 0.05130151104822289, 0.11007134322426282, 0.028895317554997746, 0.01997494367969921, 0.028394609071256127, 0.024550668167648837, 0.007382046924249153, 0.05485054658493027, 0.01522086904515163, 0.023665369481022935, 0.118205051694531, 0.03446488168265205, 0.03534937699441798, 0.024777095568424556, 0.05460363405290991, 0.019235922300140373, 0.03071749975788407, 0.03799635429459158, 0.02724479967582738, 0.015479329395020613, 0.053550726879620925, 0.03891399763233494, 0.028836539459007327, 0.058057782298419625, 0.033620273097767495, 0.010350136217311956, 0.05768577706476208, 0.02170671559724724, 0.017647357053647283, 0.1012523281679023, 0.011657685390673578, 0.019283161855128128, 0.10615350853186101, 0.03057772551983362, 0.03351163009938318, 0.02430709901091177, 0.014936390853108605, 0.08401436018175445, 0.04800744776730426, 0.04212944892060477, 0.061414453157340176, 0.04023317254905123, 0.054965939416433685, 0.03781624618568458, 0.016490278321725782, 0.03301623910374474, 0.04243507646606304, 0.011555593700904865, 0.03425801172852516, 0.027396444565965794, 0.02714054277021205, 0.004327286378611461, 0.054090179182821885, 0.08113596268231049, 0.039011868357192725, 0.03329871535243001, 0.039492071300628595, 0.05027913583035115, 0.022970038335188292, 0.021741364616900682, 0.04134520662773866, 0.014153958472888917, 0.03728720250364859, 0.029975921679579187, 0.0028508093191703665, 0.04685790183430072, 0.027682919135259, 0.041883824014803395, 0.020816579963138793, 0.018972053549077827, 0.0915281601191964, 0.025970144342863932, 0.040793753796606325, 0.05263844184810296, 0.012181832753412891, 0.04282233654521406, 0.001565729942285543, 0.04679068922996521, 0.04078871090314351, 0.049264798071817495, 0.10460118792252615, 0.04578178770316299, 0.0360260783781996, 0.02797991179249948, 0.00841956334625138, 0.016410321186413057, 0.01740911651722854, 0.03925885510398075, 0.05471193937410135, 0.04019566440547351, 0.03428744159464259, 0.008533647214790108, 0.04706349158368539, 0.03662331058876589, 0.049134766377392225, 0.03378318935574498, 0.07787049064063467, 0.08272664490505122, 0.008135982225212501, 0.02497925659554312, 0.0773164996644482, 0.027230737832724117, 0.012560105424199719, 0.10237565031275153, 0.05749382427893579, 0.009473821228311863, 0.026715566746133845, 0.05788617920188699, 0.026494976336834952, 0.061956016870681196, 0.015454212334589101, 0.017943169696081895, 0.027511401385709178, 0.04437398922163993, 0.07779203078825958, 0.02772586165519897, 0.040117968965205364, 0.02177702852350194, 0.03676074149552733, 0.06508041406050324, 0.034913454292109236, 0.03722147048392799, 0.06217571113666054, 0.058649941929616034, 0.038622025604126975, 0.03811811104242224, 0.06827152290497907, 0.03373091989487875, 0.02928617519501131, 0.024746428171056323, 0.05318423209246248, 0.02867681258067023, 0.06655900971964002, 0.01713811758236261, 0.08016068415599875, 0.046010354344616644, 0.044338110092212446, 0.059154910341021605, 0.0016626632418592635, 0.09940342308254912, 0.023094014104572125, 0.06495127294328995, 0.019128214407828636, 0.030316589727590326, 0.023387273758999072, 0.047522469103569165, 0.014204147137206746, 0.026738894302980043, 0.042219560491503216, 0.018322422001801897, 0.011908451524504926, 0.05166166418348439, 0.028556044744618703, 0.008073382996371947, 0.027482869518280495, 0.045441479596775025, 0.013245572499727132, 0.027401209154049866, 0.09020282537676394, 0.06347339716739953, 0.017741164519975428, 0.05114175633934792, 0.04625250228855293, 0.08390883420361206, 0.09803062799619511, 0.05006799110560678, 0.011069270822190447, 0.04108689841814339, 0.033513170055812225, 0.018008554761763662, 0.02180592404329218, 0.08061680069658905, 0.028894824026792776, 0.04587948773405515, 0.013914926621509949, 0.06533416919410229, 0.009706476175779244, 0.02796382388623897, 0.037594700261252, 0.021448720945045352, 0.092017539718654, 0.025018312117026653, 0.019061411840084475, 0.023880655389802996, 0.05525394466530997, 0.049819913401734084, 0.030590065580327064, 0.08001466660061851, 0.02678359014680609, 0.030521530097757932, 0.024912865919759497, 0.04383929779578466, 0.052692536992253736, 0.0614599950495176, 0.06129798792244401, 0.035001862634089775, 0.057411868911003694, 0.05983992377878167, 0.05921451964240987, 0.02980159675644245, 0.02950280253571691, 0.034882952022599056, 0.028183568247186486, 0.007936652491480345, 0.04987358923244756, 0.015593361313221976, 0.026531887051532976, 0.07577164506074041, 0.06920202024048194, 0.06714765899232589, 0.0891245664388407, 0.04474878493056167, 0.04308687879529316, 0.053541134620900266, 0.05852530935953837, 0.02448905877827201, 0.0465034855005797, 0.04770717852807138, 0.10495688446098939, 0.008773004683462204, 0.037231808601063676, 0.049756626758608036, 0.006095131775509799, 0.12179856043076143, 0.04711205772764515, 0.05172431257960852, 0.026719379529822618, 0.04148582876950968, 0.057760240451898426, 0.05077513538708445, 0.027334705300745554, 0.01810401907277992, 0.06583856986253522, 0.008390403436351335, 0.0574743020843016, 0.03673783139674924, 0.04882674169493839, 0.021342104009818286, 0.05786914691270795, 0.05267458072921727, 0.08193385307095014, 0.02135568531230092, 0.036355428674141876, 0.05132960504852235, 0.00977145398792345, 0.07916822491097264, 0.045009980094619095, 0.016665803668729495, 0.05505568733497057, 0.10494672445929609, 0.03557136078597978, 0.0563364115805598, 0.061330356693360955, 0.09600145524018444, 0.05954052656306885, 0.0564478450542083, 0.07930765961646102, 0.018476733057468664, 0.038792508057667874, 0.0601937612373149, 0.038873539451742545, 0.07320002172491513, 0.014896549582772423, 0.07686613476835191, 0.06053393204638269, 0.04215480810671579, 0.05366883226088248, 0.028712383718811907, 0.02410239241726231, 0.06744873346178792, 0.02518436394893797, 0.028929975851497147, 0.04548397126200143, 0.0369960542593617, 0.04009938558738213, 0.027128636866109446, 0.06841292430181056, 0.049482585018267855, 0.014987866215960821, 0.037769754344481044, 0.04644843669666443, 0.09145509568043053, 0.05650124257954303, 0.13056945463176817, 0.11612416608841158, 0.14937992964405566, 0.12646027200389653, 0.10192732632276602, 0.12011159938992932, 0.09837223115027882, 0.11181228066561744, 0.09478387291892432, 0.11051585257519037, 0.11995521403150633, 0.08718945347936824, 0.15808091353392228, 0.11337122123222798, 0.11838420614367351, 0.12736201111692935, 0.09651709944591857, 0.059977020719088614, 0.11100980380433612, 0.13070391694782302, 0.1669132724055089, 0.14252396940719336, 0.09799779538298026, 0.17678560281638056, 0.11817241946118884, 0.1780307781882584, 0.06797804060624912, 0.15685797290643677, 0.2278086860314943, 0.13801791588775814, 0.1522970449877903, 0.1685611074208282, 0.175737512181513, 0.09047233630553819, 0.16765127889811993, 0.08202662153053097, 0.10933654280961491, 0.14861240051686764, 0.12655825034016743, 0.08503648306941614, 0.0722628970106598, 0.09758657877682708, 0.07482712855562568, 0.15046345040900633, 0.12859554961323738, 0.1724931097123772, 0.10152567600016482, 0.08149522152962163, 0.10523754986934364, 0.11415392727940343, 0.12487354542827234, 0.13120005751261488, 0.15026206121547148, 0.12482484569773078, 0.10842758259968832, 0.23638746788492426, 0.25318834057543427, 0.21673064766218886, 0.22299769887467846, 0.12523522367700934, 0.11283812913461588, 0.18972877704072744, 0.11237266153329983, 0.14814818714512512, 0.16700681269867346, 0.0906220794422552, 0.18750460498267785, 0.10104023720487021, 0.18606645637191832, 0.15255719743436202, 0.18850337248295546, 0.2035550179425627, 0.11197521176654845, 0.13639328040881082, 0.1139309119025711, 0.10346723822294734, 0.15810920420335606, 0.2218866889597848, 0.1317334093619138, 0.22109768207883462, 0.19475345819955692, 0.15718245471362025, 0.09219695391948335, 0.19986222469015047, 0.1923488255124539, 0.11192300167749636, 0.20108051947318017, 0.12825518584577367, 0.12199242424685508, 0.2358801951049827, 0.1261121899005957, 0.12188786306069233, 0.12479848461225629, 0.12280992217711173, 0.14771260583074763, 0.08430238769506104, 0.11793261670391075, 0.12541495700133964, 0.17223681643372402, 0.18590670166304335, 0.11884577746968716, 0.31705949921160936, 0.21703918813727796, 0.10243482916848734, 0.14965744834626094, 0.11876650125486776, 0.21215453540207818, 0.11643975696642883, 0.0869394832989201, 0.1135353694553487, 0.17413574969395995, 0.20077557099284604, 0.0989393655618187, 0.16549100575502962, 0.1553454907843843, 0.14835727983154356, 0.23355935089057311, 0.16424047207692638, 0.166879742173478, 0.1502293918747455, 0.18116341321729124, 0.18531396315665916, 0.23454536829376593, 0.19867383845848963, 0.15227400872390717, 0.12326168973231688, 0.12411431351210922, 0.12083938650903292, 0.08114728043437935, 0.2131606946932152, 0.13508661068044603, 0.1618042981135659, 0.06150199689727742, 0.15713347296696156, 0.11243210014072247, 0.12564598757307976, 0.17870147188659757, 0.1361929895938374, 0.14294859662186354, 0.2652396314078942, 0.08329055839567445, 0.1843824639217928, 0.22986348514677957, 0.0884528856840916, 0.12291039412957616, 0.11555149525520392, 0.28121050097979605, 0.18325870390981436, 0.10028357311966829, 0.3497326100477949, 0.16287750302581117, 0.15468276775209233, 0.16662775335134938, 0.13564388937084004, 0.11670082967611961, 0.10184749349718913, 0.2411694815964438, 0.15231369878165424, 0.10897144326008856, 0.1265347094158642, 0.09001481710583903, 0.12786754727130756, 0.15453861298738047, 0.1837642994360067, 0.09686714824056253, 0.1912905674544163, 0.2171584512689151, 0.12616391759365797, 0.1538940132013522, 0.2608495013555512, 0.12532392516732216, 0.12916065054014325, 0.23928604437969625, 0.11802900684415363, 0.26762747671455145, 0.23273847618838772], [0.0901386963960249, 0.08671092407894321, 0.0026040851071229554, 0.06386528824805282, 0.025639246669015847, 0.0906221462355461, 0.02350969287363114, 0.06392015522578731, 0.03548410277289804, 0.0281155095944996, 0.06687413304462098, 0.020606336947821546, 0.05962484938208945, 0.07294054463272914, 0.05701028538169339, 0.03784582077059895, 0.05683043331373483, 0.03140289911243599, 0.027483947487780824, 0.035299441587994806, 0.001510143661107577, 0.06591724493773654, 0.07010574830928817, 0.0239071463511209, 0.0341556213243166, 0.06785069548641331, 0.02646062788699055, 0.04038014747493435, 0.056460565465386026, 0.019835187995340675, 0.04091695402166806, 0.05938671645708382, 0.038073107207310386, 0.06349641116685234, 0.0943431410996709, 0.052657500200439245, 0.011697923710016767, 0.05242549741524272, 0.012394903351378161, 0.017949633802345488, 0.016937780383159406, 0.06051565665984526, 0.05890768239623867, 0.02671808448212687, 0.02552010784711456, 0.09735282452311367, 0.022869664717291016, 0.00694785899213457, 0.04785141863976605, 0.018941098569484893, 0.037208879948593676, 0.08064619716606103, 0.041899535281118006, 0.04143527738051489, 0.004892694832960842, 0.05051989224739373, 0.027966564266534988, 0.0327585431659827, 0.017614368589420337, 0.017074799397960305, 0.05270242239930667, 0.07216037673060782, 0.04688268214522395, 0.01211212838825304, 0.05758530140155926, 0.03466292379016522, 0.038783695054007694, 0.022189044793776702, 0.01338531148576294, 0.019812031132460106, 0.0387077807681635, 0.01794578947738046, 0.10999555510352366, 0.11208027019165456, 0.023581169116368983, 0.03880161420966033, 0.0169122412262368, 0.033760850710677914, 0.020746521222463343, 0.006441503228415968, 0.04275514991604723, 0.020460983614611905, 0.014259460331231821, 0.042208417144138366, 0.0155081701814197, 0.023172036089817993, 0.04802025723620318, 0.022505971537611913, 0.050759342484525405, 0.03689838391437661, 0.045012941263848916, 0.01971206940652337, 0.005229191547186929, 0.017646141786826774, 0.0783542002318427, 0.047286733315559104, 0.03698032443935517, 0.056924919845187105, 0.018300268893653993, 0.03992105492216069, 0.03153728350298479, 0.02979633121867664, 0.012858838417741936, 0.04362295803730376, 0.022717656174791045, 0.039050081541063264, 0.11022150938515551, 0.04773697575728875, 0.01941509901371319, 0.008339682281075511, 0.014558888160536299, 0.058573960850480944, 0.042440627730684355, 0.025871948928397615, 0.033166442372021265, 0.016784144681878388, 0.03068670990614919, 0.014086603932810249, 0.037413467798614874, 0.01089953144401079, 0.06208633800270036, 0.07161207060562447, 0.03572044341126457, 0.021965636078675743, 0.050886965909739956, 0.05860857832885813, 0.02935548807727173, 0.03469852090347558, 0.06351071977405809, 0.034632777751539834, 0.05728753691073507, 0.031369788193842396, 0.03638271002273541, 0.0861176363832783, 0.04710769389930647, 0.09096843234146945, 0.059563551694736816, 0.014770749057788635, 0.08050754913710989, 0.04019628409878351, 0.03532878610712942, 0.02460424009768758, 0.04140875673328992, 0.02861942415620433, 0.03580659191356972, 0.029790139851684216, 0.02856424547644565, 0.032642734731780365, 0.017256549508601893, 0.07442909991368651, 0.03740925239981152, 0.017223629693035036, 0.03903532764525153, 0.09225726083968766, 0.011497850900923368, 0.05855846480699256, 0.09180771972751245, 0.023487207654397935, 0.03927961668523494, 0.03915075387340039, 0.027758198884839658, 0.03551211513695307, 0.07173932666773908, 0.06836913016741164, 0.022223966552701313, 0.02228280030976748, 0.04850645302212797, 0.016008032616809942, 0.06840694259153679, 0.015081100373208756, 0.020168176670267712, 0.07209580246126279, 0.022023306519258767, 0.05949869169853628, 0.03376311797183007, 0.01072809996912838, 0.03602454955398571, 0.02132850971975131, 0.05281447556626517, 0.10803648561704904, 0.021597486302198377, 0.01871319615020184, 0.045639068994205445, 0.026733743798104115, 0.060874960036017, 0.023935175413498655, 0.02868897823645966, 0.006311547604127554, 0.02042613792582415, 0.0733488668629434, 0.03190649826137815, 0.03353634361701552, 0.02831806952599436, 0.02479102011420764, 0.014514678423438454, 0.020498580815910827, 0.017268099181819707, 0.09419065943802707, 0.06528860132675618, 0.015440208935615374, 0.014126175246929051, 0.0614067459537182, 0.053691694120061584, 0.030471960199065506, 0.07862092810682952, 0.030050021414353978, 0.07784579196595587, 0.012509712669270812, 0.07766816634102724, 0.03096855347394012, 0.040650560113135725, 0.08735555355087854, 0.01249631875907653, 0.008810282761260169, 0.02625250184792094, 0.06795714914915152, 0.03735681966645643, 0.028265447544981726, 0.0113347092155891, 0.023305813774641138, 0.08496864335029386, 0.023197580812848173, 0.037706523362430744, 0.017783544863050338, 0.02469485447363695, 0.011160828653373756, 0.09780212814803235, 0.014536731341650011, 0.05688142999133561, 0.09300948688178323, 0.043778712570201606, 0.0327684359945124, 0.016853121742315125, 0.0691592057410162, 0.013703629756491864, 0.03170175456034485, 0.019425374048296362, 0.038087679276941344, 0.043242540559731424, 0.03535522882884834, 0.014887734723743051, 0.021511488084797747, 0.06444321348681115, 0.01502902294305386, 0.05294228823913727, 0.0649579225864727, 0.042110757931368425, 0.0429571550921537, 0.044665063251159154, 0.071230131725315, 0.018803576749633066, 0.03068781199544901, 0.0212734033993911, 0.06855304178316146, 0.019034629585803486, 0.04066561086801812, 0.03950715545215644, 0.034559828345663846, 0.005066184839961352, 0.0645973724022042, 0.017961647317861207, 0.06183316545502748, 0.043758559550042264, 0.038561503461096436, 0.04070464041433297, 0.017562199318490457, 0.02600747251563007, 0.07256567099830136, 0.02016555874433834, 0.03933711086574476, 0.045805135669070296, 0.042818065485334955, 0.03779571838094853, 0.08545534379663877, 0.02622697938932106, 0.07840384991141036, 0.030489986966131255, 0.08140021920553409, 0.01009616493320209, 0.038947731954976916, 0.025786791193240788, 0.08726745320018381, 0.04566685871395748, 0.020842770354647655, 0.010141837628907524, 0.061674390381085686, 0.02643324449309148, 0.009589150049578166, 0.006563999804711784, 0.03062999869143823, 0.031230720851453952, 0.047088939827517606, 0.027209961408516392, 0.06205789890373126, 0.01757149657350965, 0.05062977463239804, 0.04811957885976881, 0.021309429102984723, 0.04649402682844084, 0.04048140239319764, 0.026549364629318006, 0.01789446068869438, 0.0222944817141979, 0.04403873514092993, 0.00501835156683228, 0.07427488162647933, 0.027874879342562053, 0.014178966066538123, 0.03348889440530911, 0.05917092217714526, 0.00834593487525126, 0.014140004241198767, 0.017878389480756596, 0.030067988809605595, 0.10414952426799573, 0.02077867291518487, 0.027940075160586275, 0.0204809473871137, 0.03722169312823098, 0.05614513414911926, 0.029884253453928977, 0.013928802000009455, 0.03871777378662955, 0.039006784645607695, 0.058401745482115075, 0.034710688414634205, 0.04183526158158202, 0.03141786823107395, 0.04401198813866358, 0.010445155239722226, 0.01588956543855602, 0.054860086893313564, 0.011201361048733816, 0.00899006246982026, 0.08377518825000152, 0.03042658900085371, 0.07759847125271335, 0.0065700747472874355, 0.02293838573677931, 0.02455653484503273, 0.022903462122485507, 0.05549655274080578, 0.030634353242930956, 0.040595336904516444, 0.012507918527262518, 0.03126997675281018, 0.011752660811907845, 0.02111670077283634, 0.07161806715885177, 0.01862222925410606, 0.018438989282003604, 0.011639329295576317, 0.16670710378093645, 0.1244881036109291, 0.19877402839483693, 0.1508166830171831, 0.12425989320036024, 0.1929013544577174, 0.09052609748323448, 0.10600183581118472, 0.17310943367192522, 0.10087883492815308, 0.16522141319001094, 0.19007684430107474, 0.11504800742841326, 0.15744845528388396, 0.11357019844581373, 0.23727662017336115, 0.11769536693464033, 0.1787126189447008, 0.19005962647497654, 0.1252093820949085, 0.11636362745775841, 0.23684699088335037, 0.1984936895314604, 0.11274710472207516, 0.09563422572682612, 0.17318909580353647, 0.2158774746931158, 0.1588207160239108, 0.21329272276489064, 0.08580131077906117, 0.15332865994423628, 0.15806345822056755, 0.15206610347377136, 0.15850576339289546, 0.15897054079687223, 0.23973777482751757, 0.06365013963659294, 0.10085752786835656, 0.20486974739469588, 0.19086568790953606, 0.21427047264296561, 0.16316725232172757, 0.08361251690075733, 0.13835076912073418, 0.13919484335929155, 0.2384570802678354, 0.14597526780562475, 0.11563293854123913, 0.07796128498739563, 0.10321408422896639, 0.13597131008282304, 0.22741954831872135, 0.1374284873600118, 0.15955244394717738, 0.16961477900622413, 0.09854524803813547, 0.10639433545293286, 0.13397140020970255, 0.14177640405250713, 0.30911783629562706, 0.1421634340658784, 0.17607947898795828, 0.14157746394630522, 0.11601774953305721, 0.12740576814394444, 0.1090245290833991, 0.09508551884209737, 0.10900525550823659, 0.15861895575653762, 0.13916765106841922, 0.06759410534868948, 0.15763449686346576, 0.1545576416538097, 0.20550579763948917, 0.12066580558894202, 0.06953739677555859, 0.11725139193003997, 0.14958124462282285, 0.10293764164089225, 0.15793086611665785, 0.14815906703006476, 0.19384318438824266, 0.12538365321233869, 0.1864715651026927, 0.0731035351054743, 0.18491496972274035, 0.19144558726111427, 0.19229945784900337, 0.13924818893428892, 0.09114433618378825, 0.14654894795967266, 0.11399367533158511, 0.22223117906833068, 0.15559062216198072, 0.17880069703096524, 0.13732072751736268, 0.11416805034969002, 0.21623170177917928, 0.08602754707681015, 0.21586001937976107, 0.10094963581650518, 0.0927144089655485, 0.07361921641859226, 0.13798074913211167, 0.13344909151783213, 0.19623343425337225, 0.18143793364288285, 0.25450369343161583, 0.07719440895016305, 0.13551851094234735, 0.12950019794516265, 0.07779308463796042, 0.12602739210706204, 0.1937723092851229, 0.1002411445369944, 0.19808755663689226, 0.07992569051566534, 0.10345212809625082, 0.13569802162237465, 0.22006464219884947, 0.16736574500100687, 0.13312334805959836, 0.133565534488298, 0.06984121719142422, 0.13975702022435144, 0.11815621837740764, 0.2484927128534764, 0.08220295581850223, 0.13366885628784075, 0.13617790915304795, 0.19182570045813918, 0.11267045571003109, 0.16013792424928397, 0.21440679032821208, 0.102484478848055, 0.2554871281608939, 0.21373697236413136, 0.12466829706681892, 0.16211690555792302, 0.13590758928330615, 0.10263654490699992, 0.11877791548613459, 0.12600753223523498, 0.12552635336760432, 0.10827524194610305, 0.1377318031154573, 0.12021612346870825, 0.0863627454964444, 0.1045684221026022, 0.1365610651555471, 0.24857678334228694, 0.20552408415824175, 0.11524566361913458, 0.17470396764110774, 0.1193279805011116, 0.22831325739389285, 0.13366539787966758, 0.15828074421733618, 0.24771878641331568, 0.15714613400632516, 0.17132413806393743, 0.09235523917595856, 0.10835362758371048, 0.22357578738592565, 0.10340080116293393, 0.18866741680540144, 0.13083805271890014, 0.09304585211793892, 0.20103934512007982, 0.07448444186593406, 0.17932716174982488, 0.11974620298133232, 0.14720459090312943, 0.16755926742916927, 0.13019208738114685, 0.06335930680506863], [0.06773929169867188, 0.04768018661707174, 0.0421935593476519, 0.006984808669585618, 0.08979715261375532, 0.016549815263715573, 0.06987496264628135, 0.0225516989667085, 0.03786286419199314, 0.016730787974665873, 0.0610409933142364, 0.053516758780460805, 0.06845063282526098, 0.04983098624506965, 0.061840223279432394, 0.049731044928194024, 0.020812828406633344, 0.05601197059149854, 0.05526732558791991, 0.017264356902160216, 0.06535083783091977, 0.051228094089310616, 0.04592038749251515, 0.006406241936929291, 0.06176684342790395, 0.01919948470458621, 0.006865679124530288, 0.07685375574510545, 0.08191307293600403, 0.012234344339958625, 0.07127410397515632, 0.04611461496097036, 0.037049065867904574, 0.16047898563556373, 0.04506084318563808, 0.00790425032391795, 0.040598105115350336, 0.015845595044083893, 0.028078687937522773, 0.04997918200388085, 0.010733733797678724, 0.03270280787546653, 0.012970677289558807, 0.029165973246563226, 0.07811083516571671, 0.04553463397314772, 0.03580889628210571, 0.04734033493150491, 0.028894170936837327, 0.04536461907264311, 0.020693997576017864, 0.041349629827891476, 0.020398726701387204, 0.014534575402649352, 0.026025252518593334, 0.049638918426353484, 0.04986617888789624, 0.07204003006336279, 0.08347162016434595, 0.030680416493851226, 0.0200043587028631, 0.03507224049826618, 0.009176593866868643, 0.018580913892947137, 0.045953101362101734, 0.08703895335202105, 0.0637050140358042, 0.039700321649434045, 0.021447566905408166, 0.0677101401379332, 0.11233017357881181, 0.057832169404719025, 0.05163808244105894, 0.026576905729598366, 0.04122261867451016, 0.03355879358423408, 0.04557841326459311, 0.026277168981323484, 0.04106106425751932, 0.04671528331527952, 0.04455548885744065, 0.06800459465011954, 0.012556979127111845, 0.04679787321947515, 0.025702477651066147, 0.04134182985580992, 0.00894125698323478, 0.02940333062724676, 0.03685235962620936, 0.04464801982976496, 0.030874848052917514, 0.04342344276665244, 0.02632292795169633, 0.026626993276295252, 0.014945852308301255, 0.019838334701489657, 0.026931746942864265, 0.03015258065715898, 0.04961994542100001, 0.0672945671249181, 0.04519428875937592, 0.047561520914314315, 0.005167460167285753, 0.03966907723224722, 0.0016655424269629293, 0.01489538812165847, 0.019320948304084595, 0.053265074238879606, 0.06410926187527366, 0.05530920498131309, 0.039135369152063504, 0.01579201012646081, 0.11263263586442918, 0.022489289913210087, 0.016742131701903418, 0.028152043669251725, 0.05865536331839394, 0.04972996139258612, 0.037901003161096014, 0.07657699403353035, 0.07320575110497884, 0.08523314478225075, 0.019979908647655975, 0.06411501351976767, 0.046647740455227904, 0.031468456727452576, 0.03718672312970739, 0.07880921839387156, 0.09486182068940252, 0.05288607797410805, 0.03463313769316301, 0.10872060476685874, 0.023430297915183473, 0.026893086615018547, 0.024172894591174554, 0.059344421460991725, 0.07648418104508892, 0.030956007467466407, 0.06030858632584568, 0.04444126861926634, 0.03368219418916851, 0.056679213303141296, 0.0427952815516619, 0.03354985441546887, 0.07757047744235024, 0.04366758337710053, 0.010210776654275833, 0.03348155085404869, 0.022592418754356913, 0.06583011680049822, 0.0682776010944508, 0.09020924495416693, 0.03756837628316134, 0.052264685145928524, 0.05545572719711345, 0.013463778759614797, 0.031073307618498802, 0.047796440339880064, 0.06709976820275187, 0.03854795184452087, 0.02923832151282113, 0.024304868857143447, 0.026125481417693663, 0.02068407691695029, 0.00919753356356523, 0.021650269700330682, 0.055713274705340154, 0.037490573231480084, 0.05308986801537685, 0.0336648019583663, 0.07880469871452078, 0.05269348323054146, 0.0370350058801705, 0.006273583967413288, 0.04042441658384632, 0.032087582294479944, 0.028065331134712324, 0.1226202811812982, 0.029784503240080085, 0.01942719787621172, 0.0364209788676817, 0.03689817982376553, 0.037586707330774516, 0.08606961200712249, 0.04107891290914267, 0.03492817108053714, 0.04034139994473662, 0.09205867696437053, 0.016933770930336323, 0.001489785390731413, 0.019008799135917798, 0.04295445738534909, 0.025428640001337044, 0.027624528811429627, 0.054369430799852125, 0.05102042261569295, 0.04509618054726161, 0.09538402548059821, 0.016686112539900932, 0.015525616217928473, 0.03525468637235463, 0.05407312833995093, 0.07587688902276568, 0.012611301553988596, 0.04029204341350123, 0.010691064017009921, 0.033145647394121625, 0.042043315261253156, 0.06097559897170868, 0.0707768501888495, 0.05234450312855188, 0.06140407051134389, 0.046475547351292334, 0.020145466951362323, 0.017101713383453898, 0.03221454520826228, 0.01256295805433183, 0.03117830667179078, 0.05776515346951783, 0.012842784835811472, 0.0297724600386573, 0.047080998847377487, 0.058669200661825016, 0.03215129938325845, 0.026928025072265882, 0.030549121293006465, 0.04843904003791977, 0.00830212033179123, 0.042257554741809145, 0.060844313047709875, 0.04734925183583982, 0.07375514818704687, 0.04825655334570911, 0.05274688075587619, 0.02127512518200092, 0.025592938509362284, 0.04726452083559707, 0.06770183550543152, 0.03529243200318888, 0.047240178391803056, 0.08693411014974117, 0.022669436984870117, 0.052466727429418825, 0.04916564343147911, 0.07915976442745887, 0.02887760248995619, 0.05294308975862805, 0.02102343692968134, 0.019477591558825225, 0.023239617912622634, 0.02798102686938364, 0.04437403746123891, 0.11550207564141601, 0.02215570380940335, 0.07076202949974686, 0.10340448963688686, 0.06026997980370652, 0.023513130872743204, 0.07015949464403093, 0.00830224649689626, 0.02674740673683118, 0.0568394912261283, 0.005590270047832746, 0.010876548058149638, 0.002875982272598776, 0.05042121629230678, 0.04746868937218096, 0.04040144711325411, 0.025668195994512644, 0.02439527914248174, 0.027129199042974506, 0.058196434038109146, 0.039363208488794044, 0.01851797420385992, 0.044424314255593345, 0.016737881051085424, 0.025468291096331086, 0.036283380977693014, 0.06716506235534325, 0.09011827991344035, 0.06330589443678036, 0.07092423329595476, 0.03919562783266883, 0.03050154777156422, 0.03149763055262156, 0.0324239533074433, 0.02577976862085052, 0.04193201908492483, 0.09437444488867186, 0.077693629427813, 0.04158211129833944, 0.04255138956068549, 0.0580618158710422, 0.06748345113010146, 0.017616010591154918, 0.06493369888630696, 0.01051282055414049, 0.07714356441283599, 0.03784908993111458, 0.01979264066903852, 0.04535041065537371, 0.04175910238700453, 0.012804451980628073, 0.060046277940273285, 0.05179003346711397, 0.029882414783060085, 0.016535987197130453, 0.0231107959189103, 0.04482089942030143, 0.05860005476279184, 0.05235959841229487, 0.08291042293421924, 0.04335559191531502, 0.06855448897113092, 0.0351044385752175, 0.08642110056825913, 0.017565052876307163, 0.022958110166655388, 0.03654240535979625, 0.011165790838276735, 0.023868409953138325, 0.011269427122897469, 0.04970890295226127, 0.030032172762730625, 0.04683022343670018, 0.05429875607660506, 0.0032309951075149, 0.03483749176666606, 0.06003960603266023, 0.03432077144680079, 0.049595643795328215, 0.018170752991863992, 0.06034736354195047, 0.03227129353035707, 0.04589951458910946, 0.013187261956773, 0.014557072681782302, 0.010241710297123063, 0.06845157535281032, 0.05654938198858872, 0.025467465457040817, 0.0048930612683761865, 0.010894110055232886, 0.012614607821888058, 0.01620268125407165, 0.06514601249364205, 0.027571224054554477, 0.014263112625485519, 0.05037557421019301, 0.022162663299241103, 0.02851941233529942, 0.054807412961963564, 0.11563650085008703, 0.20254447998013347, 0.2160494154668413, 0.14648923475760967, 0.1442527727340348, 0.14063189359148964, 0.15013089403510094, 0.16148789087310433, 0.075145005248487, 0.1873565316782333, 0.10431885268189944, 0.1520518393954262, 0.17763271986041218, 0.06696828932035714, 0.17228594660991803, 0.11613444483373314, 0.10296499720425345, 0.16508503613295034, 0.15177538938587531, 0.1268299506045878, 0.21478982758708298, 0.25779473246075213, 0.06144285885966383, 0.12198109165183268, 0.21446550905238837, 0.126891786349006, 0.20453478646231815, 0.19061267492361367, 0.16557636758079752, 0.08297660024254583, 0.08648802744573914, 0.23369773174636066, 0.12364229274680838, 0.26967250916641206, 0.11804330060840584, 0.19893456978024915, 0.08353113298653625, 0.06459092313889414, 0.10001312708482146, 0.15358306816779077, 0.09565047133946791, 0.10159407975152135, 0.10472643276443705, 0.0871771783567965, 0.09980157788959332, 0.07762972309137695, 0.10644206297001801, 0.09110434926697053, 0.18441119987983257, 0.1411563841975294, 0.1976050715893507, 0.10522477008635178, 0.07745410868665203, 0.11976410358329304, 0.16900148300919682, 0.1467966174823232, 0.12107714836020023, 0.13577360194176435, 0.13319465360837057, 0.13373572379350662, 0.2195039644720964, 0.1657137688016519, 0.08500622570863925, 0.1643567072460428, 0.2512097451835871, 0.18072511564241722, 0.16233668517088518, 0.18274356436450034, 0.19732580141862854, 0.2045700087910518, 0.2556797006400302, 0.12215113252750598, 0.1076336923870258, 0.19052136107347906, 0.1371054898481816, 0.13441860355669633, 0.1415032788645476, 0.1345606951508671, 0.13764078612439334, 0.2008666325127706, 0.22924022952793166, 0.19697728886967525, 0.20505800057435408, 0.1531319017522037, 0.11543651431566104, 0.10615543811582029, 0.10148465007659979, 0.08836379085551016, 0.1409256356419064, 0.14606183191062883, 0.07418295921524987, 0.22008064290275797, 0.12442784864106216, 0.1088744519802276, 0.10043923117336817, 0.21908712980803102, 0.14607113844249398, 0.13795036560622975, 0.10709996204241179, 0.14761902100872248, 0.14767548360396177, 0.17170388018712401, 0.13767021970124915, 0.18377244821749628, 0.09062178258318454, 0.2870876871747896, 0.16765034379204735, 0.26885685918387026, 0.2711142646148801, 0.0799097417620942, 0.21021856897277758, 0.1890530961100012, 0.2587768016383052, 0.11406535195419565, 0.09391476603923365, 0.17037283832905814, 0.1680721211596392, 0.12113269069232047, 0.08898184401914477, 0.11572385905310512, 0.1326234670705162, 0.1521432719891891, 0.11777435371186584, 0.2765744231874123, 0.09531676463666372, 0.06291049299761653, 0.12162900195107795, 0.13977978931507096, 0.22598059818847105, 0.13873425166821107, 0.12265587458387017, 0.2632898313459009, 0.11202996742213145, 0.1329286233521998, 0.1458742911927402, 0.24307795887580141, 0.11808878683950752, 0.14559582254150882, 0.14967353810789064, 0.2032769055222161, 0.08682449493790045, 0.13760418340098113, 0.14315682841697708, 0.22416901570977643, 0.1476270510465838, 0.11543960907147266, 0.17161375377327204, 0.14612541912356392, 0.15633481816621497, 0.15992939559509978, 0.17985245387535542, 0.2508364152163267, 0.10314647457562387, 0.18989892181707546, 0.1969500965788029, 0.08133044990245253, 0.1032544273766689, 0.15850439784117043, 0.12062760724802501, 0.08994571573566645, 0.17867091024527326, 0.0783119052357506, 0.2436759221018292, 0.1694406711612828, 0.13557893660617992, 0.12140643928432837, 0.10380366118624806, 0.12765535240760073, 0.15413849148899317, 0.20223408413585275, 0.2057431364664808, 0.11300656697130762, 0.24958132475148886, 0.1062539433769416, 0.13459081150358543, 0.10847193334484473], [0.06133670947747305, 0.0362435239367187, 0.011798268569691572, 0.1334480821969919, 0.039580628072144464, 0.05744044901803136, 0.017797877590055577, 0.03540745376085397, 0.06316573242656887, 0.00413010237934941, 0.044554494379553944, 0.08491661137668416, 0.03807060988037847, 0.010794558365887497, 0.035026327532250434, 0.025628615403547883, 0.03441063439822756, 0.09633044188376516, 0.019955466013925616, 0.04230009835737292, 0.03243702252802905, 0.06877510721096769, 0.04288141521101352, 0.03619075352617074, 0.00674991336381936, 0.001822844917569455, 0.02795223339489894, 0.05286115294438787, 0.015716344460088294, 0.04701369718532078, 0.026994315558113158, 0.05895004789636005, 0.056497724799555726, 0.022067918871471193, 0.016235224429692607, 0.017631933369557373, 0.01947928551089717, 0.09255656899767928, 0.10002181021263823, 0.008966233963292325, 0.03496378303680103, 0.05002001496904995, 0.017676803618087433, 0.04156964692811016, 0.017344390107609797, 0.052473903997452, 0.04355997938546352, 0.028698550086119212, 0.05709065626433585, 0.09718593777506612, 0.05445475922897458, 0.042330622891313396, 0.09546882327413186, 0.02319889626960503, 0.058634991364669986, 0.1601334713632241, 0.08087324982625432, 0.08060495601966977, 0.02837968077074038, 0.02509023921447806, 0.11390476603992283, 0.023897856517578475, 0.06025506263540592, 0.06541382390423678, 0.08364435503608547, 0.023574606675538234, 0.05727876843593549, 0.05157473271538038, 0.013527477294701384, 0.055970814792090096, 0.11931613582419232, 0.0526840022939723, 0.08298741333419457, 0.03207822752301581, 0.023160677519626915, 0.004356065010142629, 0.05969017693132628, 0.032245351758319885, 0.0044971087845624425, 0.0663338198501151, 0.028291316957620438, 0.03837004420347512, 0.05333253546268679, 0.09007118322188035, 0.020671252605097834, 0.01828867654694477, 0.058312832479714416, 0.01136937029514229, 0.017532875208416954, 0.040427529893349856, 0.010263841140840668, 0.03105637922999449, 0.024612795205030125, 0.04485190635023173, 0.06656327706878074, 0.046168157205102034, 0.04350510127551388, 0.030235374651965685, 0.010826680372701958, 0.03727318333403673, 0.05423755857918877, 0.02214064748841338, 0.024083256139419973, 0.012882146493211621, 0.06946106688701548, 0.07186749557149597, 0.02844853537681047, 0.06370768576744013, 0.03186609945259988, 0.05111473103170283, 0.027465173006930854, 0.01586972597579006, 0.024024350022955332, 0.03696053507155739, 0.04395332507556304, 0.06418496093829162, 0.021319563129509334, 0.04853034646657761, 0.02398109765636036, 0.03490064111247193, 0.022837830292701256, 0.02568798907304881, 0.06913135293871164, 0.0805271566787269, 0.025565466057742015, 0.03385767500731163, 0.03093724968493916, 0.05679592344677076, 0.026497722283238545, 0.01932151604705723, 0.02257976884720847, 0.04102790881006513, 0.07803492830134928, 0.05589122316450812, 0.01497076527812169, 0.056963559763971716, 0.015564141103823204, 0.03426389695960097, 0.046098558595986106, 0.032786948868306354, 0.032483681352459826, 0.04042531087179668, 0.002106913652824005, 0.023427950873156078, 0.009875500309135532, 0.04047618138429243, 0.025677033117972314, 0.05329607745807152, 0.0672526060952805, 0.038206868193810806, 0.10527495411224663, 0.07382070209132507, 0.022570903893210925, 0.06055110534362029, 0.017208321041835006, 0.01584414414537605, 0.0920449398108758, 0.06748618223355152, 0.052957865918870084, 0.01766726516507333, 0.01581838419951964, 0.02995742735947715, 0.04071172792464495, 0.010149387126148213, 0.04074044532899279, 0.022142295056255534, 0.03379415087692905, 0.03464038476522546, 0.010722534789238125, 0.024765699890849646, 0.008459243199467892, 0.023476262831536587, 0.028717302302538883, 0.05767085989646148, 0.020514507305051666, 0.08177579045877792, 0.07894100897829048, 0.07264648345881142, 0.06574332262971438, 0.1430406526196748, 0.009295435829699272, 0.02381056510785129, 0.08186624341760762, 0.014491644014924532, 0.05536161545023788, 0.04209097598504741, 0.040080546168610454, 0.044969848459004425, 0.048002902112784795, 0.009505506295681698, 0.07578805394587107, 0.029150069021852687, 0.04422236102982424, 0.06913653312949464, 0.05027713574236259, 0.012631613208213821, 0.05636891022732016, 0.029171227652113885, 0.028454255480028223, 0.046191557121346705, 0.06812158680986613, 0.04725755949039012, 0.02510236961825285, 0.05454825499327853, 0.004621908801709651, 0.025918036299117375, 0.00920341415621806, 0.022467494891316164, 0.03286052909970749, 0.023399923666147515, 0.08292490965686738, 0.02905806126364041, 0.029255335248308256, 0.013459493784466758, 0.025745646526047494, 0.03900610186974518, 0.020205300752422772, 0.01878600083728088, 0.019729266823560465, 0.0411176381749101, 0.05676382927049417, 0.019007235059689265, 0.04931767609377857, 0.046611868747277185, 0.10425670523545705, 0.0894593566772528, 0.07646209473023191, 0.03227291512303054, 0.08053927595028654, 0.03412206511711702, 0.06504234188469127, 0.035896811095881276, 0.05837217831867747, 0.044277550841798075, 0.045135295440559275, 0.03741485190403182, 0.014320164300443139, 0.0209489048938849, 0.05931174469878897, 0.03779292048420757, 0.08065396003075875, 0.056214743890450336, 0.02363438852626132, 0.015964809936122037, 0.04492632520850748, 0.029712416580878198, 0.042975385949830525, 0.027715911310224328, 0.07166200230130926, 0.039052033389452845, 0.02802976556267822, 0.00258156927429809, 0.015493778082600329, 0.0565630634810077, 0.04466930462513119, 0.010418268157081911, 0.06770474472432397, 0.10861771341296844, 0.01974164399143774, 0.136817684979178, 0.038032378142816015, 0.11385061894543469, 0.10962192085571587, 0.020171566429780796, 0.02135473350790562, 0.06631145151914097, 0.04450128610187676, 0.04102263585082255, 0.041049067440326326, 0.051456794317346066, 0.04548506964056287, 0.07440641988068819, 0.044327482537482865, 0.01246900123078376, 0.00223729392473615, 0.06040037143975496, 0.0521992685389705, 0.05607250757748261, 0.02211158127465751, 0.005862282014277298, 0.04373747142381035, 0.002993134689859289, 0.005201754811423598, 0.01725894664559746, 0.023950882969074883, 0.07405535434372723, 0.048947262766887434, 0.03206472785677761, 0.04877232000580989, 0.06410397036233917, 0.010281502400175668, 0.09510094809229486, 0.0057376369204575894, 0.05474176999996416, 0.02994740651047323, 0.048702394851716235, 0.034964313672389835, 0.056178560480475426, 0.044711751761497, 0.08347449969733134, 0.023788287689967547, 0.06578980333870277, 0.05131249483383726, 0.04320118809118867, 0.06666927802143618, 0.07827536930562928, 0.05709364340873435, 0.025208550541719887, 0.01745424095133785, 0.03984220173151698, 0.025540309106872883, 0.026415199172333814, 0.027047768744523637, 0.026008787972386926, 0.04556298772513401, 0.05031661057728343, 0.020589423402270768, 0.02463024309690809, 0.01294375773795764, 0.014290342023741687, 0.042508749465923756, 0.01220959093188867, 0.024779702362138778, 0.03302509292552713, 0.01113602886107401, 0.0504471729072975, 0.08186446968466043, 0.03632191328506451, 0.0954305507184472, 0.047329918888863176, 0.02773243893898325, 0.055695604169159196, 0.06642477004788816, 0.0277309231023537, 0.041842556893243454, 0.02400061428488698, 0.04946613531501498, 0.027788274419435766, 0.0694616828695871, 0.02200807950430317, 0.03108759210590506, 0.024805517969070934, 0.05178937666642014, 0.06386190405464731, 0.03819629630015697, 0.1337175560183823, 0.04892818586085923, 0.04094037620234303, 0.03390307960216887, 0.024479629792040214, 0.02315732115675928, 0.04744516329083126, 0.18153365585021675, 0.2901305223349482, 0.10823833494214341, 0.2921789389802143, 0.10898779277340509, 0.18224151630420238, 0.17613806412555277, 0.1486060774186626, 0.21607346105156466, 0.11919604890863411, 0.15858986356761307, 0.11197274783626199, 0.14459450205322355, 0.0782861230254639, 0.13725050550419837, 0.10705201930250041, 0.17024621309246868, 0.17373916081851348, 0.14278793649282306, 0.08230910520069301, 0.08916108752600849, 0.1718702251673676, 0.12155791904660873, 0.13851957803126425, 0.11703553827828728, 0.06850883204606362, 0.14478590193903074, 0.11522326560225338, 0.09846646164078265, 0.13702193886274472, 0.12309969373745844, 0.10234128145384602, 0.10771338420454413, 0.1471354375826195, 0.12725137174129486, 0.10456030300701968, 0.11874317555339076, 0.27712052513379604, 0.1854202980757691, 0.17101543431635946, 0.19490985840093344, 0.1488750020507723, 0.11098959512310103, 0.22701546375174075, 0.15938883007038385, 0.17393011541571468, 0.14126565802143887, 0.17109708540374413, 0.1520279867690988, 0.2023586758878082, 0.1781289791688323, 0.12167373119154945, 0.20190106763038784, 0.11327701300615445, 0.16297732188832015, 0.24930423649493605, 0.15467542049009353, 0.2568896091543138, 0.11724983341991901, 0.11521809283294715, 0.1727810630109161, 0.11224909394513816, 0.1438925787806511, 0.12250960469827987, 0.18399779393803328, 0.12545810546725988, 0.11417313406127505, 0.15403341822093353, 0.18106052186340094, 0.1680894280434586, 0.15765000774990767, 0.14956079103285447, 0.2837123698554933, 0.10286883712979034, 0.16139874409418553, 0.09572249677148648, 0.11416437671869062, 0.15561961045023054, 0.10668740214896388, 0.12691955751506612, 0.12784041435224935, 0.1475797317107208, 0.11695682609570213, 0.21445694466819987, 0.19448080798611045, 0.1571806290303357, 0.21241523703793064, 0.06907303497428074, 0.07566133965156041, 0.12037097258144058, 0.16997145517962053, 0.11401947980630212, 0.11465488438261673, 0.16095045721158385, 0.14886551740346476, 0.1721006620209664, 0.1988561692996882, 0.16771970491390675, 0.12880545866210014, 0.15836013917578384, 0.11034552968339995, 0.153752634068951, 0.19747430516872555, 0.13059727032668889, 0.1512586319586262, 0.13401993666775525, 0.13738312729401514, 0.1621957216411829, 0.19751306012040004, 0.25925536814611405, 0.16714247729396448, 0.11806499358499423, 0.16412480094004422, 0.1826587665709667, 0.316725829616189, 0.24282502010464668, 0.06627521986956708, 0.17275412305025384, 0.18868328392272815, 0.09658252718509175, 0.1574122384772636, 0.1865726604592055, 0.13803771638777107, 0.18996084661921486, 0.11440311078331433, 0.12826548685552552, 0.1098736425046809, 0.18201360275270417, 0.19983788224635646, 0.08676216937601566, 0.11308029934298247, 0.1197804456751328, 0.11390792016754858, 0.127115098584909, 0.12349424170679413, 0.13483963877661154, 0.09028593107359484, 0.07662889984203503, 0.1841818614047952, 0.0945157498063054, 0.1034737765439786, 0.18798909382894635, 0.07974889609613456, 0.09524718829197809, 0.17379240249283612, 0.1343208775506355, 0.07123738250811584, 0.15428418992087245, 0.13376070448430255, 0.14336507505504414, 0.14131766773061827, 0.11387005579308607, 0.15543141664238647, 0.20739358384162188, 0.11824739864096045, 0.11402324249502271, 0.12234421708853915, 0.15630707668606192, 0.11148223275085911, 0.10611637888359837, 0.18591446452774107, 0.1056356453045737, 0.15130746527574956, 0.16804409766336903, 0.17405157530447468, 0.11730783226084895, 0.1361360668670386, 0.17085340863559395, 0.13910933310398832, 0.14068038552068174, 0.16608974081464112, 0.1602429975173436, 0.07653233158634976, 0.1870130657334812, 0.09327827792731114, 0.17362147103995085], [0.04923329390294384, 0.03541056335961912, 0.06439131509978324, 0.028129161401011515, 0.022455993457697332, 0.0387853314896347, 0.021645924425683916, 0.04349525297584478, 0.032995499786920846, 0.05363697186112404, 0.02206770921475254, 0.03114788603852503, 0.09665038916864432, 0.030630599831056315, 0.022762203589081764, 0.08080348052317277, 0.04749086845549755, 0.022162895220390055, 0.08836914174025878, 0.06575305218575522, 0.09752334779477678, 0.02386918549746042, 0.027299143439449836, 0.035884291064576246, 0.021429219159472268, 0.01704169775621267, 0.014494000333797885, 0.015259577612596331, 0.0088616217544768, 0.039646189397899434, 0.010273269199387869, 0.003996385457867291, 0.004397838647491881, 0.03689951197884511, 0.03894992871209979, 0.02313435910764383, 0.059024604051955976, 0.06752944202162325, 0.06441188743337989, 0.0419053574296413, 0.03975243525928818, 0.018997089900949504, 0.05429180586361326, 0.09120155576965772, 0.05041692296799738, 0.019598194267018698, 0.010083028919325443, 0.02725289094087202, 0.04919873950711917, 0.02969910616229754, 0.019823599359369837, 0.023484398625441827, 0.012722260053124046, 0.05893921625101939, 0.0648603450099472, 0.02117161413480062, 0.03652486841019709, 0.022617366048507392, 0.0326234277599724, 0.019578544051910285, 0.012061215202265885, 0.04400254059873987, 0.02415573428152129, 0.050597788067534566, 0.010075971094920533, 0.04668126697652042, 0.012451607144612353, 0.028406182864273433, 0.05993864426272921, 0.03076585995586356, 0.048216191644314677, 0.048868769517866895, 0.188190616609063, 0.014667081231891643, 0.03300340365967713, 0.02036311288975412, 0.02631249892147025, 0.029421171857393347, 0.03488288522930816, 0.053622704072040506, 0.05881865065020975, 0.011495067847135942, 0.051640394231071696, 0.06522921466967091, 0.034713913046289235, 0.049041159290936776, 0.053843359419261105, 0.029159945152059663, 0.012806631111743627, 0.08519624519976787, 0.0220016543607926, 0.09101878706132993, 0.06968061643419787, 0.02173256089008646, 0.0775769267056603, 0.037366085380199365, 0.033180888276547194, 0.045946537065901794, 0.015472863433387829, 0.036947072512703016, 0.037344344164012, 0.06137490410765167, 0.007123308732843725, 0.010560019291006029, 0.022516487770189997, 0.08385529567021877, 0.02367898603552021, 0.027126544009661302, 0.02824213483108906, 0.05153818565304391, 0.041256171170971356, 0.04685722276917659, 0.02094383231451502, 0.05981284652079921, 0.030149556405376643, 0.0290185140693211, 0.04162234312389046, 0.016921620117500424, 0.02827942033036379, 0.05269034765660763, 0.005435053108158172, 0.05937807043665089, 0.052556364025804214, 0.05135264131240547, 0.02004079444304807, 0.027152769653184805, 0.024187034359783866, 0.01429700743756257, 0.02885690213588532, 0.05197721424337942, 0.09478033287450671, 0.0068032436320208944, 0.043198969069635496, 0.05034889400121756, 0.04135085808229633, 0.04768622398842126, 0.04583095869747922, 0.03771154770220164, 0.05254113886621781, 0.049977282105828635, 0.06637005892116576, 0.043063130069640465, 0.09837415331276134, 0.021799203896080144, 0.01054322077834513, 0.016981613480311353, 0.03593630448449403, 0.029025644253124483, 0.00656805749713385, 0.013715775930904783, 0.0421165392617695, 0.03705768962390721, 0.02567824281868525, 0.05457397783175111, 0.023851941696193535, 0.024858572251105215, 0.010045176604762673, 0.04357573146990035, 0.049429922219133005, 0.017761608833097853, 0.02680683977814624, 0.01763429339916911, 0.07388750280370004, 0.02738861490797717, 0.034919881290989, 0.05008216241549235, 0.0741483380261343, 0.028737206703226548, 0.017074830939236563, 0.020275212918932084, 0.05057815455074888, 0.07494910794775933, 0.07319632582948543, 0.046753192218602635, 0.034622428502188995, 0.050391326294629835, 0.054704005815437995, 0.044073018652852625, 0.04156022165261675, 0.01172297861558036, 0.05308891806635074, 0.03594229361624457, 0.03518839774187654, 0.005289014216032228, 0.024144030612660572, 0.07190954565885477, 0.03867847706715111, 0.04168922547250986, 0.0689011906797532, 0.05200368665100541, 0.01560406122735003, 0.013411757918220246, 0.07490313932066783, 0.04495566230616532, 0.03948358484194614, 0.023868133503128774, 0.03496052129776217, 0.009950066669262014, 0.04051915915624704, 0.05004849117540289, 0.019701636665558908, 0.03940912887628656, 0.017036070421454497, 0.009912811783578945, 0.06402910250471905, 0.03465865273028612, 0.04414003087731544, 0.05793827796878759, 0.030803677946096286, 0.0698057870613411, 0.03022385837539332, 0.028902752019348554, 0.0474002707778709, 0.0689669672283344, 0.026811960597115103, 0.04225152479193639, 0.020467707472562324, 0.03156065744406078, 0.04429794877069071, 0.06920187181094661, 0.0942256442795042, 0.03756662852538284, 0.029544203243858647, 0.0691999051196035, 0.04442454061063472, 0.03249511413741857, 0.019439435891399626, 0.013955081449239515, 0.020521268270385917, 0.05692417027603369, 0.07297040123376064, 0.013539908268285217, 0.030541143205482513, 0.020618992421077564, 0.011982434371020645, 0.02187891983339796, 0.07259476318722591, 0.004814456233361852, 0.07535897384514101, 0.04470566986128688, 0.024988737532112282, 0.06136770156444982, 0.04444337260792963, 0.042051289638038725, 0.044359305829857476, 0.0371448697114829, 0.049698227157932706, 0.07067424085107632, 0.02379663499596063, 0.06465270693297498, 0.04794236141606234, 0.034795241299434565, 0.06814313877839595, 0.026028132051578723, 0.05838141805725172, 0.0172854079210083, 0.03914962951967027, 0.013441952196444618, 0.07138736313208938, 0.06841821581474505, 0.029349471114983317, 0.0883054432051722, 0.03833515955193434, 0.04307602117478382, 0.09266664434107952, 0.05762069813499693, 0.04395158844999969, 0.09463921349379234, 0.04218735499307513, 0.056520133948652074, 0.03232090239180252, 0.01103564967706916, 0.062066849204711616, 0.03224613843485713, 0.04785135555721354, 0.048423454936710186, 0.026757559317047708, 0.0472435106348712, 0.03284087702922989, 0.0163897729726159, 0.05531704948225524, 0.023671241724514402, 0.028207919967826456, 0.10649209856637754, 0.019580460648285225, 0.026956158035318367, 0.063997420220403, 0.036294375895522535, 0.021140746357559692, 0.09504932429990731, 0.055885022520669736, 0.05167895622435026, 0.051963562436867505, 0.07446047791745514, 0.01285252552406746, 0.018074225554300938, 0.04811288839846384, 0.02995104488945799, 0.03340840106830001, 0.026458497923158575, 0.0281640887260437, 0.07006905652815476, 0.019950436108047143, 0.018748732036328875, 0.051487467280821875, 0.01975392096937867, 0.034776453831000254, 0.1092973499908112, 0.04348405767814256, 0.046726500877412036, 0.02563374178862432, 0.034476088112569414, 0.028305174710112624, 0.04141481265833136, 0.008775478818279225, 0.07493980141589418, 0.10684744629543275, 0.041571097826818004, 0.08570079429773614, 0.03724347516254056, 0.029167316533857957, 0.0421582368289819, 0.07033698668237776, 0.03395028390514199, 0.06936743753612973, 0.03767492271435913, 0.03550979221472517, 0.02822465539793484, 0.02291443477588473, 0.07597978779813275, 0.0171556044369936, 0.027875421110366005, 0.04277054205886088, 0.03706923373101745, 0.04237550056132022, 0.014304508695204277, 0.03886637030518614, 0.023947463523654733, 0.015860989042266738, 0.049161517090396956, 0.016871308071131352, 0.05299732962157577, 0.08270760139566846, 0.05393178631493356, 0.013894807925680652, 0.05126539443153888, 0.03586954087950289, 0.06413461363990791, 0.05855331430211663, 0.011177495434822049, 0.00930026535570505, 0.06454064263380133, 0.1086565425794106, 0.19400667952140793, 0.13405382313067093, 0.17819687083829194, 0.08575080762966536, 0.13581311388406903, 0.14069741038838401, 0.1534557156264782, 0.26245271845255047, 0.1492402277654037, 0.15036958357086405, 0.07807063302607276, 0.27806652593426406, 0.23259809153387323, 0.10783423553220928, 0.17590761242900044, 0.17179519403725863, 0.10132708470337093, 0.13857143931090832, 0.131309182906989, 0.165218964102678, 0.05585370017797686, 0.11101542186224833, 0.18246316612930968, 0.10163861603359692, 0.12421805833582766, 0.10796878690598533, 0.07893965826951899, 0.1163788340636529, 0.07112511040759273, 0.12281932518817484, 0.11498967462102883, 0.17127160885138437, 0.14284150471212342, 0.12962504202732816, 0.09453758379095234, 0.10566952434601262, 0.20787207613466308, 0.1254002476343885, 0.16327554651070386, 0.11129488499136642, 0.0708187221607659, 0.1323374136700295, 0.18642846116563305, 0.14229059364879504, 0.08523688520654105, 0.09231227624695748, 0.15784079907462, 0.18922839139122516, 0.1463276840513572, 0.14624438539613038, 0.15650251385523006, 0.10708673697081394, 0.21680051344446838, 0.226180458557792, 0.10494082438526675, 0.10482566533028148, 0.12218552365084179, 0.10636774430167861, 0.11082218145020306, 0.29232389526441693, 0.19759965391131118, 0.14918189495801926, 0.15046999615151435, 0.21611190430121496, 0.12850905972300097, 0.11830488539999351, 0.14920770685421303, 0.18350067373830825, 0.10746555883088149, 0.10851879997062497, 0.19416224851738662, 0.3111818083561957, 0.14315479493234307, 0.14624431118136272, 0.09566019347403198, 0.16269785875920206, 0.204473870981019, 0.18123743502655998, 0.13390812469879165, 0.12375165562843904, 0.09680765768280253, 0.23638567188754678, 0.1897973514860496, 0.05008528685721103, 0.2366516279289499, 0.23535885120509192, 0.216051523166243, 0.09335126072983257, 0.168543444306124, 0.1047939682030119, 0.22957710520131513, 0.17683602432953194, 0.14108360919635743, 0.2815341961104423, 0.13785388640826568, 0.14513699716189876, 0.07780336338328198, 0.16876393638085574, 0.18083444883814082, 0.11764927956392057, 0.1746880411519669, 0.10590267746010795, 0.11962071323068812, 0.11006158398231491, 0.1979596252203919, 0.09634592308430001, 0.20684761548181996, 0.1667130261193961, 0.16151451913174242, 0.12732410221360624, 0.1115060482698027, 0.1358520914800465, 0.17961913748877123, 0.13261479878565297, 0.13145008706487715, 0.14214523660484701, 0.1965886409743689, 0.11482416826765984, 0.1506040577078238, 0.09568281413521618, 0.1721217983867973, 0.13623880979139358, 0.12150183494668454, 0.12912240024888888, 0.158490905596409, 0.13030655623879284, 0.07284005783731118, 0.17851130396593362, 0.10422416948131286, 0.15128258848562837, 0.15130167652387172, 0.12594866508152336, 0.16534685099031776, 0.11494817372295074, 0.11373816130799241, 0.19386009051231667, 0.11079458839958534, 0.236818433040753, 0.15466516400920227, 0.23058191378368065, 0.13778194261249155, 0.23783202865161002, 0.05962721312243957, 0.14518608280923218, 0.07723815113422461, 0.24397735280217603, 0.10113143973285332, 0.19020863488549367, 0.1446607758407481, 0.10495163005543873, 0.10251664352836087, 0.1354400659329258, 0.22495126904686913, 0.15553073084447533, 0.07894402209785767, 0.1510193635476753, 0.10304554249159992, 0.15245665126712993, 0.08978058787761256, 0.14529384265188128, 0.08677517922478728, 0.12800573516869918, 0.16282322234474123, 0.10906748459092341, 0.16469646245241165, 0.233223766554147, 0.1617469746270217, 0.09615326896891929, 0.12225010534166358, 0.14219509408576414, 0.2235828823177144, 0.1985878383857198, 0.14333331113448367, 0.10744491970399395, 0.125511109654326], [0.024448082949675154, 0.03619176284701098, 0.012090344498574268, 0.014799766104260925, 0.025666427827673033, 0.02405882092716638, 0.03458193321421277, 0.050411753909429535, 0.05300201999489218, 0.0726570664846804, 0.035992678022012115, 0.023108632558432873, 0.026969012033077888, 0.07088878832291812, 0.01451117363103549, 0.023348708054982126, 0.03415454149944708, 0.02012100947467843, 0.01567728893860476, 0.01306614067289047, 0.05895061563933268, 0.03440451910137199, 0.07499703584471717, 0.011098704399046255, 0.057160618525813334, 0.05694921033864375, 0.021957385251880623, 0.03751494165044278, 0.018030715291388333, 0.015532410579908174, 0.022145063267089427, 0.02555837854743004, 0.03482688647636678, 0.04158990013820585, 0.02156698959879577, 0.09208278934238479, 0.07044165176921524, 0.02626994417369133, 0.016778059070929885, 0.04728665167931467, 0.06588476113392971, 0.031818327406654134, 0.049575423981877975, 0.017780464950192254, 0.005208846496316255, 0.05003083177143708, 0.07445796945830807, 0.029004222160438076, 0.04842448281124234, 0.014550336763932137, 0.020674826046160888, 0.045677248781430535, 0.020340499650046695, 0.05819674945087172, 0.015106423379620537, 0.025084860499191564, 0.05322663098922931, 0.09150447076535784, 0.07055584603222087, 0.047123950644163415, 0.1201224050601013, 0.07621628057677299, 0.04280915600247681, 0.06114664545748383, 0.06527781049953774, 0.030769257136853412, 0.010681070070859278, 0.029221615768619813, 0.00944865128985839, 0.02564424132287968, 0.036235790757928044, 0.0290873000267311, 0.07744941089185886, 0.010655904770828784, 0.03797374105488416, 0.05810828173707705, 0.061198258117656223, 0.034484329662518576, 0.07836817487259395, 0.04234246756823268, 0.02463734916091198, 0.08607416137238033, 0.026333700225222856, 0.12155025266110897, 0.03485535526124295, 0.06114609626820311, 0.04296969738788903, 0.042727579129859805, 0.007971181839820929, 0.028607115636987146, 0.002863942318072077, 0.05117798056744505, 0.01736891623295378, 0.04773460459546186, 0.009528404334560037, 0.03536442032782361, 0.021922430096310563, 0.04682896178564988, 0.0580395069118822, 0.057140020217048004, 0.020490073948167264, 0.0461595334490994, 0.0229421725452994, 0.036422366683837026, 0.0850936803908553, 0.03437682586081792, 0.01621748524485156, 0.04209472754155286, 0.025595189072191715, 0.015843756373215, 0.03407542113563977, 0.0717682704271283, 0.05823666957439855, 0.023015819569991436, 0.03151366094243713, 0.015264617723005358, 0.02481273349985713, 0.062039040931267664, 0.03415719838812947, 0.07533051990321837, 0.01614631513803033, 0.02825815408868948, 0.09334274087450467, 0.015305876495403936, 0.050361328685539775, 0.004143388214288279, 0.04780295268574264, 0.02941425689641619, 0.02842386453266954, 0.04668733032303862, 0.0599495798087446, 0.01655521624343237, 0.012330770659900736, 0.02051026778644882, 0.027139639205415733, 0.03406565076147672, 0.09191170945996419, 0.04342559499491472, 0.053866848393226974, 0.03983235714258626, 0.006528537205667817, 0.02424602582323132, 0.0756058789556846, 0.009776736224011984, 0.04477424801734742, 0.01828521071729483, 0.049548112947377376, 0.03102089529420482, 0.042172667890554294, 0.030296909826574847, 0.059838109227712266, 0.05990152945742011, 0.05072899606602732, 0.034883798070950434, 0.025175591763400007, 0.016375510749639943, 0.05930839390202891, 0.06086754226998892, 0.06090692062571179, 0.02378135974140605, 0.034128751867683604, 0.054024320997996256, 0.04086931556230411, 0.022452785524365027, 0.022841413010610268, 0.04629526112694293, 0.025950727904273663, 0.06014972590492107, 0.021149874773982447, 0.07112145161954686, 0.02338447029615054, 0.05027995961427223, 0.023385579806927126, 0.09418176850886084, 0.016630024729238357, 0.08223794065997936, 0.04058292819536291, 0.05925996134465095, 0.021808395395055413, 0.02823676353727933, 0.016233729002124164, 0.057958620236604474, 0.015132674998312723, 0.008504289708071155, 0.05137642343470361, 0.013142170919309137, 0.01246579236976686, 0.06329713709419593, 0.030078926210990176, 0.018584674726298545, 0.015075315332069295, 0.006008194277455914, 0.014938315798644908, 0.014308829850051552, 0.031168339628493413, 0.012307855922699673, 0.028915971524838824, 0.018490896945877466, 0.030638624302810058, 0.042382447063573636, 0.02089175395667553, 0.03738170758879278, 0.040212667008745484, 0.05356500580091961, 0.0032571906012890395, 0.01714643520244863, 0.056456468810210936, 0.0082694157390506, 0.023775079316692427, 0.008435770923824748, 0.019427234983595554, 0.03686955518787727, 0.058381640701554716, 0.05283684760797769, 0.04152825735218357, 0.03908116268576123, 0.06010683347994927, 0.08674158962094225, 0.0287981685687555, 0.02166154848964652, 0.05504357919562608, 0.05451136654301081, 0.02536068710469408, 0.031146231049206108, 0.061009667260805145, 0.015082491900102468, 0.04538332861557137, 0.03915600827895105, 0.03310702602902893, 0.04872866687946953, 0.028381202173477504, 0.014101696433499455, 0.05081059891381301, 0.08940767351305112, 0.0657095029600896, 0.10386024252511561, 0.038237348198890686, 0.07998102504643612, 0.021982683210808318, 0.055209675556398, 0.04783816388226114, 0.023125572079152334, 0.03175413905410096, 0.014849262715870282, 0.03383084636880085, 0.010355131798860384, 0.03979422559496015, 0.035760604732786305, 0.037473221818800084, 0.03474785145954229, 0.023239881375047844, 0.08845923104672693, 0.08587628253735602, 0.007096650788298575, 0.07746229457552545, 0.03207709945854731, 0.06190050051372964, 0.06316522776614875, 0.02980119414132787, 0.04339733030064963, 0.036228584503987804, 0.0894504360621795, 0.02465509020112222, 0.033721053041517735, 0.05279693861666601, 0.04466825077543035, 0.022148299030959606, 0.01831642544857459, 0.0422547531343298, 0.012697518704953836, 0.04010470678622369, 0.07491418247809634, 0.019398981421545614, 0.04071356845088303, 0.03716933089890517, 0.060623323734034784, 0.07340141091844998, 0.04393306815472897, 0.055496704881079495, 0.09852583345491439, 0.05295710150676314, 0.01207299494126346, 0.03667771743494086, 0.05802882369607687, 0.04019100742880255, 0.03927179815946147, 0.03602082026191056, 0.06318725470919162, 0.013572099851444364, 0.03317459486424923, 0.043169487253180705, 0.023776407761033624, 0.02817441385559505, 0.02277517818583874, 0.0146021998989454, 0.012347509800747503, 0.07564818137325346, 0.01579752984980587, 0.034422664612066, 0.010454913553985534, 0.0499551141547272, 0.03160551284963731, 0.03127271156699862, 0.09752603436936624, 0.014757673343410715, 0.026978305577358697, 0.038931642193347216, 0.03746761489310302, 0.02123687674611574, 0.030036467942409217, 0.02086154854623601, 0.025802485761232674, 0.030547008027497213, 0.05438411419163458, 0.02298389979841886, 0.03443627188971732, 0.040147165054804645, 0.055286331989918835, 0.03590585045458283, 0.01665552863414632, 0.006911073051014682, 0.02161660773708718, 0.01589522245922126, 0.0312771867174888, 0.023474886147596408, 0.11028599459677935, 0.06667543784715235, 0.08321073299157433, 0.06084963053581305, 0.014954973303247243, 0.04180329728114884, 0.03322306081827264, 0.097735720773926, 0.05714301107218489, 0.12903332768473774, 0.03262385078414809, 0.0650485981896054, 0.029017578963248525, 0.032411039937869646, 0.0483924888249021, 0.036282382789067924, 0.03486125533527229, 0.04719810975075234, 0.030199491811799817, 0.011701102885126602, 0.03364414056704845, 0.031658001244068146, 0.09726669086376205, 0.007401075126836076, 0.050689283743849955, 0.009446435051359003, 0.05733244055591058, 0.08835128566715866, 0.1645149034447968, 0.12226069578900933, 0.08005886891623959, 0.11189583907253109, 0.14229510590666905, 0.13819083629641682, 0.14044932526303455, 0.14750303816981614, 0.17649257322773337, 0.12925289949635044, 0.12512903718743473, 0.10993481773766689, 0.10431543880258687, 0.06304348586127162, 0.09017365155159496, 0.06903805755428039, 0.05960634021903388, 0.20027539314469323, 0.05169864169147331, 0.153314336494077, 0.2602294221287593, 0.10810785795911215, 0.1777285014395602, 0.07278976248926483, 0.3217875736299902, 0.09973232066840865, 0.10018013257649727, 0.11362603021552786, 0.11189211349119432, 0.10800795746035874, 0.15163313451921567, 0.2284727746155113, 0.13334274175576866, 0.11748516102670692, 0.19328626192873344, 0.2962589403614402, 0.15336872107582167, 0.06736929397447966, 0.11443206938565709, 0.0864882129826583, 0.10962658154312521, 0.15121732401894405, 0.12776527932146564, 0.13300715741934255, 0.18585248035378754, 0.14718165853992105, 0.17030496150255203, 0.15140833798795938, 0.07296619325643405, 0.12501113960752264, 0.15520593733526766, 0.16521127545274794, 0.12343404610874131, 0.13936605682829395, 0.13345718092750758, 0.09991141574573703, 0.14556393987732008, 0.18299148621736094, 0.24182508001103997, 0.21258826134726405, 0.15570241928799078, 0.10023358947364613, 0.16428310103947297, 0.11714496795320883, 0.07260302329086699, 0.14522707904689014, 0.09450142635614611, 0.12873140716692433, 0.10147400767891668, 0.12485804938478395, 0.1372557450667955, 0.1196378271561116, 0.11174208833836019, 0.14506831881590188, 0.17356977303279564, 0.17931595531990752, 0.1215157427941449, 0.20923890435369685, 0.11256967205554247, 0.1914843570557423, 0.23175395792350173, 0.1922295623808168, 0.18848744599381462, 0.10880794070544653, 0.09809471244807355, 0.08726063286303543, 0.14088030526181683, 0.11172967962920666, 0.1303690005443059, 0.14218179479939863, 0.11888499255292118, 0.08449294153251685, 0.2569940441753715, 0.13186563039198518, 0.13371978246141225, 0.09414400803507306, 0.1328628245391883, 0.18137091770768166, 0.16861599666299298, 0.23667297209613025, 0.11624108403339051, 0.1229587895795703, 0.33063872368074954, 0.1913132326444611, 0.08222723146900535, 0.18024283839622512, 0.10229159466689453, 0.16710407857317477, 0.12809172039851546, 0.15568481554510072, 0.166932464344427, 0.1670766487950459, 0.1726377839804627, 0.1006341191532556, 0.13052820606390014, 0.10163983315578662, 0.1406404876615852, 0.16647346084937453, 0.16168709815246984, 0.19747580430703238, 0.12693931348621845, 0.1336989874835126, 0.07713353799772449, 0.1611158373998478, 0.0916805824090261, 0.13545229652663693, 0.29931186873000115, 0.24564391962485388, 0.12877427361672744, 0.162883737066295, 0.09894258648273535, 0.09588867105776444, 0.12734816264128312, 0.08125546330120414, 0.15560987347271293, 0.14796331815887243, 0.10453372669871897, 0.13062689686194062, 0.16968270036159083, 0.10093622520798817, 0.16422093875007704, 0.1596163577050902, 0.12058815467753448, 0.09847829889622517, 0.10450382556882687, 0.1188744317914825, 0.11225540962186642, 0.12544566707219929, 0.15257172868587077, 0.1397470012307167, 0.1548198572709225, 0.18074794410495088, 0.09594284783815965, 0.12619238637853414, 0.12001490496913902, 0.2693106379592791, 0.22492933116154745, 0.24057766335317865, 0.16285446676192805, 0.16517384152393788, 0.17061755410395563, 0.1396128357737325, 0.10376313250162639, 0.14879109483445063, 0.12645546288695186, 0.1457805430982262, 0.1026073117100168, 0.07546930894022807, 0.155920195102226, 0.08209601975977421, 0.22570339118828997, 0.12888050463516265, 0.13317146891495213, 0.10350893207942136, 0.17529327742522582], [0.034091789202648215, 0.069123174471315, 0.007772978315188084, 0.024826863991620485, 0.00892345193278743, 0.07649325008969754, 0.05734295307775028, 0.021444503690872807, 0.09728905919473618, 0.09871918518911116, 0.06440621000365354, 0.0402010449761292, 0.1003759927698411, 0.06773872024496086, 0.023476812020817306, 0.044640186461037956, 0.016676496161380783, 0.009667153481132118, 0.009475558781559812, 0.07386967641650699, 0.04355021643277723, 0.002399612753833935, 0.06189849671500269, 0.09033907626871951, 0.08502017808496021, 0.03785474138567224, 0.01850318134529516, 0.007843092716939282, 0.046082376065896824, 0.08824067597743124, 0.003407815502214362, 0.062467282405123115, 0.007932723747217096, 0.02495966575224884, 0.06818032779847272, 0.0640423275763169, 0.02497774075891357, 0.025607269380998332, 0.009704695949039888, 0.007345057356360485, 0.014972757944633486, 0.030345717168529518, 0.07759988133329898, 0.03356349508976564, 0.007390086238956428, 0.023104925530788023, 0.037119517946848646, 0.016607183279120363, 0.08690856542671099, 0.05842997306899633, 0.004797889641849906, 0.04744650286738761, 0.045371443120529875, 0.041959003574447706, 0.04002952351584099, 0.0480778182100039, 0.01458941454984597, 0.016911005550355185, 0.029135856893844903, 0.011991699157078983, 0.04446351820661221, 0.015159919239522424, 0.011746060336008668, 0.07755382364848629, 0.04556591549771838, 0.02517749908292899, 0.048465705403941683, 0.06436855343054049, 0.018087532262143213, 0.02540944991778815, 0.06475646659964696, 0.028374487592373043, 0.042716138923424296, 0.062183084373828024, 0.012849354698118987, 0.0006259611529912945, 0.062268787587527186, 0.04356119279691484, 0.09520175401121378, 0.012984654713363852, 0.029197553485573735, 0.033070482677430846, 0.03713175225129817, 0.07654187560547143, 0.03196729128831066, 0.03596734852180816, 0.04469341700314544, 0.02278269614180317, 0.014566305926564382, 0.0101212161280273, 0.03810088208410889, 0.050127500217058696, 0.05084078205982223, 0.04270001205441076, 0.019550279357645195, 0.01820798839617055, 0.0256388366324245, 0.009953695771400817, 0.030308047607832123, 0.04653791373129934, 0.03805671687587164, 0.06863150905701332, 0.052609312551794574, 0.035476488337735645, 0.04220884387905244, 0.11132247062050737, 0.061552425831905566, 0.040414468094240874, 0.02462677912262734, 0.04298118583392352, 0.033772751048672944, 0.08112171344691887, 0.02596346130303573, 0.04527825163677335, 0.03296951348602306, 0.014720964863954578, 0.03759431063372176, 0.006834479236204061, 0.03304079677036498, 0.0035025650322495494, 0.05980360307148658, 0.021197889873292297, 0.026417553635837976, 0.03844758750346955, 0.027886254611075856, 0.04621742838935461, 0.06789304985431954, 0.0498080909892451, 0.02024882400291972, 0.05166000919416547, 0.02861906606995035, 0.04018563427962363, 0.01963844093552325, 0.026966711375280283, 0.017408700914529618, 0.04826360003789887, 0.03533475668518804, 0.06608212046558037, 0.03620023817347828, 0.05783383923699148, 0.059724382517742924, 0.0122090528748231, 0.04988150794815738, 0.02855095917766448, 0.025907583149091806, 0.04472454638744239, 0.020232097849657293, 0.03943951982364524, 0.039108128621592186, 0.023250340091180988, 0.03657241410110146, 0.07188795658294111, 0.03871832668664865, 0.050958664796780795, 0.037904480122961104, 0.015618048855685629, 0.0051518560485419584, 0.07661656534764916, 0.05339561801520176, 0.036248622491257265, 0.06512997468234971, 0.05099424706713762, 0.01724096255202312, 0.03545837622368708, 0.05610464257188141, 0.08589548931922764, 0.01616442354134051, 0.002991212759297923, 0.009462386587983929, 0.0901660742238164, 0.14819997421000153, 0.02008032679441385, 0.040295409053214826, 0.051671078326762654, 0.03458886858425103, 0.019009494899364654, 0.008328944331879029, 0.031476178774028085, 0.0806011859094724, 0.03698153785080649, 0.009936079968611011, 0.024930009531090036, 0.08073115081060678, 0.0234807082961197, 0.07860869009164162, 0.027186166298633907, 0.08232321342802607, 0.028794481950171757, 0.08688797082868405, 0.09584132945747115, 0.04149063788645435, 0.032114403511513956, 0.026296835894754622, 0.022738577317795716, 0.044848344041383825, 0.0159016976977, 0.08152021706337109, 0.03307019695057534, 0.053960926743457094, 0.06049402305507101, 0.020672983664553612, 0.089537304447731, 0.03883376033627428, 0.006924268900547759, 0.06655292410869151, 0.0701431006018538, 0.04814059277123306, 0.02101320085785119, 0.042439985772944055, 0.010581629703665385, 0.02694482358492678, 0.06226655372302048, 0.01502925300883362, 0.024666619465278927, 0.023367272879113443, 0.027725711370294448, 0.02717689872952178, 0.015089327080204384, 0.01179837525342009, 0.0472055757563794, 0.03997424093540758, 0.014349434604810085, 0.03855915827443823, 0.029530352912843227, 0.05670063168508932, 0.009437179542146623, 0.05432820078567602, 0.08904930524295196, 0.033817747462308034, 0.06204488905495964, 0.058569166576489806, 0.04874971418757923, 0.028515091180452146, 0.07025690152659081, 0.07326498191105202, 0.06959708029171452, 0.041055999099626206, 0.02916432382335188, 0.06887700408697128, 0.07885926883318461, 0.02162503111321712, 0.03642702737124637, 0.017989086372836027, 0.031366021794383414, 0.003661820878733124, 0.038430759304901585, 0.03131794175715186, 0.03853557653201278, 0.053109839209355414, 0.0390182916453341, 0.023642425985599402, 0.025655388380982913, 0.02673654911632184, 0.037864808618905954, 0.018225323110527825, 0.01532288837552187, 0.01194288810438593, 0.02153734450985212, 0.04191470849036705, 0.05396963213570416, 0.05176332728296984, 0.04566695148241706, 0.05180213047424331, 0.03339279741339851, 0.02469378392561339, 0.01183892527478747, 0.022910529223736376, 0.036890691553708166, 0.025774304558581207, 0.050957458806806244, 0.0377025714260526, 0.007941600761114387, 0.027490485808812082, 0.012827971568185603, 0.02050258841336472, 0.04777304413437378, 0.02949773181171622, 0.013008867281314451, 0.015439362887263997, 0.021012241631979123, 0.04736276634503156, 0.05036557748098858, 0.10521276213694364, 0.03623219134169631, 0.06494973669759929, 0.032643974118400365, 0.09340030926978216, 0.06373446245561354, 0.05603863224678207, 0.0540195526991738, 0.06728275955538265, 0.031110157106013503, 0.02537604399549309, 0.03384469855518546, 0.006307481098701828, 0.03485297296720091, 0.05872351102880202, 0.04043206812639255, 0.021563731570495293, 0.024564345949329436, 0.0708324667357374, 0.0816861612838693, 0.03996986597485375, 0.029459164252330083, 0.042742911900859326, 0.025526892932248302, 0.04866228919127025, 0.05109955782245379, 0.02708152162085753, 0.06980055492022075, 0.0016427423747700232, 0.045961513606016524, 0.02076883760310011, 0.09005115265608765, 0.027788970182882622, 0.030643108730146196, 0.010684078552003484, 0.02354879292397527, 0.04382368300866801, 0.10665215013432316, 0.03351047977048438, 0.0462915949174203, 0.058975061983801425, 0.028391230443958193, 0.03201507075573318, 0.05778706537967082, 0.039967327829799615, 0.0589853147539543, 0.0851953768869862, 0.03856714378343895, 0.012382234890537802, 0.05021627221140079, 0.08176012372132391, 0.05075892688182648, 0.03745771464309655, 0.021740483316534664, 0.06061605439754203, 0.018415301783534233, 0.04254025734553579, 0.01433918183465721, 0.025048790266737342, 0.03981831199780572, 0.03981967383879237, 0.022274688635661732, 0.05690579469955992, 0.10019186593126506, 0.054552685614908114, 0.07341621676459908, 0.011333515285514295, 0.002416883689875249, 0.03863255296892021, 0.04795008346263785, 0.09354647525469773, 0.14953543926822022, 0.1694798268727027, 0.12306225980864838, 0.1407913662842475, 0.13879662175895646, 0.1838258680072613, 0.05167976887605619, 0.16583087970502675, 0.15245472168317065, 0.2664510835893452, 0.14706805057357997, 0.2833458676468581, 0.1408601485309191, 0.1474324005539529, 0.18377829634118825, 0.13339795754291117, 0.09183461515931413, 0.14752286835573614, 0.12127437410526909, 0.3043635195354, 0.07960499366163276, 0.15185340394964442, 0.2765885536791757, 0.17409766267519444, 0.12890095822513103, 0.11995296532404609, 0.06812606938183308, 0.1364485258818604, 0.18560258438810706, 0.11819565610494465, 0.1446823129663244, 0.10842425777809694, 0.12540652620373294, 0.12459409714210778, 0.15872586955083534, 0.09693364467239007, 0.10854863430722617, 0.107555477443384, 0.08629346601082943, 0.12308099161600694, 0.1107675964885857, 0.15026928973384202, 0.14292846957687289, 0.15808311029104516, 0.06142085047031287, 0.14310061815194786, 0.08191322878701612, 0.22805432206951082, 0.21178784023504704, 0.1539212351781316, 0.13818387495120987, 0.08508483399054967, 0.12882347800768912, 0.18879894021665677, 0.1383949417504482, 0.09236667567165568, 0.15368981868959963, 0.13841965526808053, 0.21055304008768871, 0.2281875821063295, 0.17935766401933506, 0.10920844812062569, 0.17080677207559347, 0.13655391085194424, 0.10858834662940353, 0.10288069664966315, 0.16806817293399945, 0.18054538231808692, 0.18246631283545867, 0.16836059396155179, 0.12518394127255306, 0.1497910646139644, 0.09500678439508192, 0.1438844299991615, 0.13009256537770852, 0.15043066232465208, 0.1823502260958776, 0.13727082550758496, 0.09828538502915762, 0.13292715389980003, 0.12166516680736095, 0.10572333747404628, 0.20411253412021324, 0.13299746497068554, 0.13567022077040747, 0.1349511242005974, 0.13360846030991524, 0.17557094455696642, 0.14504378341371194, 0.08178236588719301, 0.11303253471851349, 0.12139739992562681, 0.2316579982289113, 0.08093380165519193, 0.154094704776071, 0.08976837954833172, 0.08109524103929289, 0.07826243367162533, 0.12294757572817616, 0.25062154862098396, 0.13024785235757008, 0.19596501428168267, 0.09257072175387293, 0.12080419386620633, 0.1939827378373593, 0.32315042393747717, 0.1756363722961396, 0.16757899371441454, 0.1637765852501616, 0.18118866108125076, 0.16724615532439202, 0.12682088155997917, 0.16015753179090098, 0.25879580061882734, 0.09967323087039404, 0.07476932267309166, 0.14465850486885756, 0.13222787267295644, 0.1921039167791605, 0.18757825571810827, 0.20707607822259888, 0.13146706740371883, 0.07368174236034974, 0.09006353910081089, 0.13015778531553224, 0.11876828240929171, 0.08135551222949289, 0.1534625285421498, 0.1055700023425743, 0.08014644976356067, 0.13943696161732078, 0.06668777234153822, 0.1150376841542311, 0.04550515586743131, 0.18845180806238204, 0.15444246033439413, 0.15163402509642765, 0.10713972631492652, 0.2020639690454118, 0.11555927296285518, 0.15234553691698238, 0.1240394901833497, 0.2242694134474732, 0.13308180263265967, 0.13880626967875287, 0.1712639647303149, 0.20566862483974546, 0.13317155797267333, 0.1208847836824134, 0.23319020663620904, 0.20568993932101876, 0.24152756785042584, 0.09821768631809391, 0.11834550314233638, 0.11574147021747194, 0.1564381251228042, 0.19269068841822445, 0.15170847735134885, 0.08397084806347266, 0.1947973488131538, 0.11433679246692918, 0.15851535194087774, 0.10543887969106436, 0.12989025592105463, 0.19576432270696387, 0.10709556852816604, 0.13338645425392315, 0.12039526307489723, 0.21224408294074237, 0.212954867456574, 0.16439843078842387, 0.11993205902399495, 0.13507074356311932, 0.09703441348392516, 0.2237822231836617], [0.057152391818817705, 0.06910472468007356, 0.01653247127251234, 0.050221738129039295, 0.03266688421717845, 0.045668205711990595, 0.014352282596519217, 0.04069343027367722, 0.016358515567844734, 0.01803116985684028, 0.013077166204311652, 0.0744567894435022, 0.040844739341991954, 0.08108476191409864, 0.029470229674188886, 0.018691935474635102, 0.04321148167946376, 0.043944675344391726, 0.04840617773879785, 0.04815425199922174, 0.009145268741121981, 0.044868942350149155, 0.044737819698639214, 0.01844692469603615, 0.027208378778595943, 0.08327827585162595, 0.053846250084461644, 0.020264657723600976, 0.10674933437258005, 0.02669005170901073, 0.03851480010780506, 0.05758103034168016, 0.09484956040978432, 0.09108270824071951, 0.00658863354146888, 0.06509002487291582, 0.01842289395426633, 0.007462220210072701, 0.04548599732515868, 0.0243543441320071, 0.07680423223064281, 0.059038292965851724, 0.012315062176639913, 0.03791367904341314, 0.038124656784930266, 0.014727005018357886, 0.05617745468043722, 0.08388420232222416, 0.03523405837768223, 0.08422300015809014, 0.039097682893043384, 0.01537760506835184, 0.02251962334412383, 0.0635624623100739, 0.01709165171632776, 0.03213768468413036, 0.0489095802186057, 0.008271358310594223, 0.050818076051655225, 0.012405077268340392, 0.014557567137671867, 0.023159642223617993, 0.02333223237656057, 0.027375723802833818, 0.01002035640340182, 0.06279263994656503, 0.013510971930372762, 0.009686962330306415, 0.052803896251134574, 0.041634651643107645, 0.04069678107043728, 0.029438508427119814, 0.07497339844121598, 0.037317244641599245, 0.03075096319662407, 0.056144258414860815, 0.10578272413113154, 0.01992665584111819, 0.04588746953231748, 0.027569452176976483, 0.0597433555230964, 0.022954262130951975, 0.033150512172142044, 0.015355954765254864, 0.021992091787979007, 0.016376267740270123, 0.014018343044881476, 0.09478533494984731, 0.08427671680692583, 0.028089061306673102, 0.023066704925440717, 0.013748079763900023, 0.013997074020153377, 0.07195571466581896, 0.024264288222184405, 0.05979307941743173, 0.025754507769306656, 0.06125838692241814, 0.04740238960948773, 0.0722506589954719, 0.03075534557865467, 0.05383842784794979, 0.061900266737211496, 0.05606421778793447, 0.055400459459633566, 0.05906509562919382, 0.03473480821412522, 0.04676263233704958, 0.032943664482445456, 0.016617569635855034, 0.04677759774494916, 0.06547908094944432, 0.0647065497469157, 0.032475465777679347, 0.03247015571105294, 0.07722590569755994, 0.01814607658161549, 0.059245200027362444, 0.01792553812265396, 0.03316022688522935, 0.005636819869323517, 0.006977659932090319, 0.03842813581286464, 0.01575061683979584, 0.022518708647112362, 0.026831187788047828, 0.04644328248105012, 0.053486267643165775, 0.07523914668126963, 0.03772273557842709, 0.00964003262197366, 0.010181335655943258, 0.031691531476099044, 0.09304459788836539, 0.06800573755754158, 0.018365672513027675, 0.10395486635388806, 0.03665491494757589, 0.010326919982617255, 0.1066882630402688, 0.06898244842886925, 0.0066625463477976155, 0.009549910846544662, 0.027067198170698248, 0.01954029004991753, 0.017177212066599168, 0.04040309468109626, 0.026203588749922346, 0.04457133742107544, 0.005639233704641811, 0.025050879412447102, 0.021373968120315112, 0.07038846204522997, 0.02797449782519834, 0.04851486155530438, 0.04138200973102357, 0.05970453748886939, 0.055356390730594285, 0.010850456001207931, 0.019192078070773277, 0.018190635128121357, 0.02120483637554571, 0.054276888695312664, 0.08933072022045963, 0.06831021848483942, 0.02102132551954128, 0.0296902838817914, 0.043344596997485496, 0.02254224214993883, 0.028230813368281815, 0.0352711583400378, 0.0569698494655313, 0.0321568877552636, 0.02054812659480376, 0.02160746076697251, 0.05265771542326547, 0.036022148706251755, 0.052639599598478526, 0.07295056362636387, 0.06291461933869869, 0.04346442045061849, 0.025998249475378543, 0.004658737416320946, 0.09708890938782133, 0.09132664476055652, 0.12178785123978741, 0.01971788969967747, 0.17875594552606344, 0.023831953803892247, 0.02869927182473475, 0.08765505466726609, 0.0680717961222399, 0.04133051210374106, 0.016140210973389912, 0.04896832862868905, 0.03815975665929727, 0.023349134789896198, 0.02586040111054899, 0.05430381381302141, 0.03259071017964743, 0.06873262667795643, 0.08538327383575961, 0.05953256331849843, 0.02805536780215334, 0.029519571362470742, 0.03803120183874853, 0.022073750296840444, 0.05241150051006116, 0.03112487760517979, 0.053257912513799965, 0.060817699632025324, 0.017186114127980545, 0.029201318029663526, 0.04357426572823897, 0.011128578626085073, 0.014827893501205835, 0.03704236798512284, 0.03417962238017935, 0.032181764545384794, 0.011561434403120074, 0.020649700636568014, 0.02683362203242723, 0.035502619357430376, 0.01735147390718339, 0.0639377960760612, 0.036037010213476606, 0.08848051584209315, 0.043531581104616635, 0.021210955383139662, 0.04760178613651078, 0.02542075282690348, 0.009933686542353826, 0.04936586003168486, 0.0172432687759283, 0.026562205639493186, 0.022575403163500596, 0.060689252422889695, 0.02991154779010685, 0.005521096318261698, 0.04159246425842866, 0.06652149415458553, 0.0324703857768327, 0.030400534051295836, 0.03462967186351307, 0.03673694081953727, 0.009470073382544797, 0.030131384919513948, 0.044648951225099154, 0.036530994839267805, 0.007991978673089761, 0.005393994251789991, 0.04603680077707395, 0.1006352026888635, 0.023733921661914792, 0.04772502346895635, 0.044928755742148496, 0.03931204482796602, 0.03865747057716362, 0.020557366333378013, 0.023755889233143535, 0.06712775459163822, 0.02911327148467535, 0.041625597441452555, 0.0395588645915268, 0.02623271990159992, 0.07403727562632412, 0.06852909267763607, 0.03996739091235213, 0.10983629763359204, 0.08004491653991863, 0.024159584172593895, 0.09109768478083424, 0.03028450668352889, 0.05300594595610164, 0.042918993858620524, 0.07651793392142281, 0.0018443765929987421, 0.0637195527087897, 0.06092724062909838, 0.014928912787581794, 0.09873106697341427, 0.04491971638344694, 0.04568651449517347, 0.012981859599676682, 0.02694411297852639, 0.026495983802306, 0.0019659626468637725, 0.04282650370441843, 0.0833604612853378, 0.024514297365385573, 0.042017380910692737, 0.06516953857499175, 0.031576005058013834, 0.03981553636549506, 0.02239606317743892, 0.04069901864568237, 0.03582081146305427, 0.03065199780394323, 0.03617382513766643, 0.04184153272944968, 0.06351593707222492, 0.020696832580142654, 0.05846931060659699, 0.06046943199180532, 0.06635136422119103, 0.043987500976072624, 0.061139654426369816, 0.04414568604261149, 0.09956146343029104, 0.09550958944601007, 0.02525796644476941, 0.012296174518269254, 0.02191128303820733, 0.004450033893590444, 0.020781125713256188, 0.016954977800196502, 0.041112710314337164, 0.02095015355735086, 0.036004344583489, 0.017584415509190876, 0.11305129621177912, 0.03744369918422308, 0.05523771389562171, 0.029545001052611042, 0.07556577329523861, 0.02564604288636474, 0.020076530709047802, 0.03436734863498714, 0.06610006559640169, 0.027502076300152112, 0.04390049529320095, 0.046529208339052275, 0.02855404651199933, 0.0072286417525901925, 0.03478943770460319, 0.016557897251914255, 0.02723969184444286, 0.046216975679271854, 0.09903722515446134, 0.03690718949656002, 0.04186248355836142, 0.022677251799905207, 0.03900507770595141, 0.06485710182460025, 0.0288536979132914, 0.050283822492929175, 0.048524405574426055, 0.049123162898467854, 0.04748281244246755, 0.01779412603355013, 0.033690012714941986, 0.03256540294387378, 0.12049722674419172, 0.1043216060497798, 0.15151863597566262, 0.24854687479091808, 0.13439160422421992, 0.1741548822610639, 0.0797859589511063, 0.18629987665917724, 0.18171331495977938, 0.16621247719740495, 0.1647614300600253, 0.27279214176815003, 0.11493474085000344, 0.1706122700124979, 0.2044315537204966, 0.13526603230275214, 0.12493305082898587, 0.1532043205224909, 0.11014447445631959, 0.11459551998996176, 0.18298385693924502, 0.11146562348585576, 0.146080162958242, 0.15899703546892852, 0.1223213440971449, 0.18464479828253388, 0.1720922312233597, 0.08917601211578585, 0.21736650494858623, 0.13256980979349464, 0.09644697391195223, 0.14470258844085038, 0.16866168327396736, 0.1582821988267824, 0.14462357939919457, 0.1543893522466533, 0.05838873934408184, 0.15068664390128106, 0.12733375013340265, 0.09557123223203234, 0.1192595693282783, 0.12240395255503245, 0.0793519955186639, 0.13132377353031188, 0.15307399939047173, 0.06728975800797343, 0.18129812786355615, 0.1635767545667477, 0.13720088551053777, 0.17057992721674964, 0.16593071341048926, 0.17676356103038415, 0.08160693701938726, 0.16681683773640543, 0.13971045787911862, 0.0824359456601087, 0.1476994252880104, 0.09260143924620934, 0.1637770453817211, 0.10307486474630423, 0.08959725513705052, 0.06791244959458709, 0.1351964782224968, 0.20273908594390377, 0.19287447386886925, 0.1819610586971976, 0.12967501825187355, 0.08747382962610573, 0.18302155804121867, 0.14673745346954092, 0.21676882373867556, 0.18888488091761246, 0.16755822842242196, 0.06732041612849571, 0.07723804723354988, 0.11126642362796701, 0.22776590863941237, 0.12058554231771268, 0.10085767629789189, 0.19469165214104578, 0.11224428482819349, 0.14656710089184344, 0.10790458371047862, 0.16133420693222433, 0.25062511092983186, 0.10321966517949477, 0.07402413961244747, 0.14261464501032606, 0.12222303179441951, 0.21105260937474668, 0.22232053364859894, 0.10612530692014843, 0.2888185833580792, 0.21468674327479675, 0.0970826308184769, 0.18577807262772694, 0.09846514061791822, 0.13191468635341153, 0.10481672987225465, 0.18675825675018132, 0.07557467164588161, 0.25738281081430614, 0.17116059840191156, 0.15676328970585018, 0.13842222309904173, 0.14929027820471674, 0.10298739522113465, 0.18645437696250156, 0.0739610793243628, 0.1588071050355211, 0.13755475636571646, 0.1547375085647218, 0.15628828550688922, 0.11479127628263086, 0.1747255789814517, 0.1737066695932299, 0.12095537676941603, 0.10820968062034808, 0.12500788900069892, 0.10681883650249802, 0.13904570136219263, 0.14540978096192703, 0.13837634352967143, 0.15459841524716467, 0.14059506822377443, 0.1267861935775727, 0.07374288790742867, 0.18429920979542658, 0.16010387451387942, 0.14649726479547098, 0.107480097503867, 0.15548594965366647, 0.1796500850468874, 0.2938572911079973, 0.12944017304107547, 0.0746070891909767, 0.1513753569452092, 0.07765556467347778, 0.07318624746403657, 0.14059535023989156, 0.17425732832634822, 0.10907731804763898, 0.10747591179097071, 0.09453631471842527, 0.17685054073808715, 0.10971818483085372, 0.14524064550641924, 0.06812837003963068, 0.09706256314530037, 0.11221802022191696, 0.0867411814397201, 0.11974147550063208, 0.23597106366651133, 0.13051334826741368, 0.16821608296595514, 0.11106401769211516, 0.1115394671796821, 0.16385115624871105, 0.13915383227868006, 0.1403247335110791, 0.06143955630250275, 0.0786142265133094, 0.19491809624014422, 0.20075436041224748, 0.2256047449191101, 0.09572616298100911, 0.16136126563651487, 0.12081674358341843, 0.0768704763322603, 0.17292683565756306, 0.08757050178246573, 0.16284762416034937, 0.11484563117846847, 0.13388992723776028, 0.13251014112029225, 0.11222273285966367], [0.02232032515166793, 0.06289022494456731, 0.03975453924795147, 0.007294730930880178, 0.05662415336701088, 0.021572891528194305, 0.034531344717834145, 0.03115219049504958, 0.03052977906918386, 0.04641194529540371, 0.04140539851505309, 0.011599337740335613, 0.028467107622418553, 0.049522553381393664, 0.03172579272359144, 0.0044680161317955935, 0.05512079966138117, 0.033244249134440906, 0.023486745667469222, 0.014036884676897898, 0.027748844113375526, 0.049704182893037796, 0.05342641343304422, 0.05652083898894489, 0.03667526092613116, 0.06865567338536493, 0.02822280930558918, 0.027051726247009356, 0.030402205738937482, 0.042455281436559744, 0.038274151302175596, 0.03579657663067337, 0.010132872484973632, 0.08653205164591782, 0.07267305234563537, 0.03475301309663337, 0.040218106951215304, 0.047081503507797606, 0.01735811983962776, 0.012374498928693356, 0.06781699456041679, 0.02311944936082, 0.06952381547307596, 0.04923826258163899, 0.039585552221979015, 0.029088238843542058, 0.022935511769901495, 0.037777053366880864, 0.07541678714915179, 0.008270515045296634, 0.009578174613125157, 0.06122236307419371, 0.01549171955048223, 0.08350557342055254, 0.05373410785978194, 0.027832652995130047, 0.038494840046041645, 0.08838267851388082, 0.03471207252005115, 0.029868991186958738, 0.028713888423226308, 0.034123701552744024, 0.027712009468814358, 0.04926762565446552, 0.007821495291864267, 0.01123241992900148, 0.03212174335203599, 0.09302052261773497, 0.015467125704162754, 0.03043683620489901, 0.05577897703915369, 0.08412948955083266, 0.026306064501113724, 0.03006517050380353, 0.028859857739007566, 0.01768661109963432, 0.03081691414990928, 0.015740994895168114, 0.060106365926912986, 0.020600668794941157, 0.004937058565701591, 0.05474893543578219, 0.04242555842211004, 0.03166062473610509, 0.04773635977471713, 0.019374562907614745, 0.018318791044293903, 0.019109864806523547, 0.03760602914553601, 0.013107468093949137, 0.02572823388618417, 0.051382935780566186, 0.06485499412519857, 0.023131874768296257, 0.0647623889381066, 0.05996442647301592, 0.07516354409744963, 0.014132194992271252, 0.03585062724596355, 0.04996971591026522, 0.05102354334667325, 0.027337378887750674, 0.07790859250235371, 0.04038234052131884, 0.018790080794133246, 0.05713475096854381, 0.06745041071553715, 0.06258871260797605, 0.04847235504712444, 0.012251549178472487, 0.1003627157479059, 0.020079118949070107, 0.07568333690869622, 0.05790393137431238, 0.012478713160817279, 0.034796892578015104, 0.004771350904775318, 0.060294626528047957, 0.028680367468041368, 0.0423762352875201, 0.02350536800804548, 0.04530821584921796, 0.030118566173769068, 0.06519292364828289, 0.029227413797343615, 0.04081835599208716, 0.05545036889088806, 0.03264042294176761, 0.03939490932680201, 0.010509118164918618, 0.0014088508237364294, 0.005235623184489668, 0.04216312387143262, 0.03892963839462027, 0.04512528015766293, 0.060306181767373346, 0.032113312554429285, 0.02803597362799337, 0.014110345236986177, 0.04425095969054382, 0.03299505449831486, 0.0251365306758089, 0.04977472774044145, 0.04634593125956599, 0.04027140799735207, 0.012884378502349136, 0.050739144935505465, 0.040277849839185365, 0.08807813821476884, 0.010438220797368558, 0.03220994389266707, 0.09804644316318445, 0.04251731385011226, 0.06658958620391786, 0.050508552230894566, 0.011925886428798549, 0.05396990673034452, 0.03674865190987475, 0.013002483883610694, 0.03829818946542218, 0.09673484557424672, 0.031206196581479162, 0.03871938795782626, 0.03418321066419594, 0.014993346976552857, 0.017676768366072793, 0.03728231546119787, 0.02121555484336568, 0.02593989069282543, 0.042338871862739325, 0.03777905345486943, 0.035224150706199, 0.00493770284265338, 0.019401610479690135, 0.09390489547513425, 0.0090151730364596, 0.04026832808449399, 0.04187920414551627, 0.03858403506455943, 0.017596750003576744, 0.03636483539594337, 0.039468879185733385, 0.05572672242124099, 0.025961611499951687, 0.037415590340970084, 0.02279971358802868, 0.013833258835802553, 0.040953393472591415, 0.026264673069817945, 0.029599862464237958, 0.03151141594571527, 0.03328602833789773, 0.049379062838852406, 0.03419265820411965, 0.021685837127733976, 0.004653348960346193, 0.019702456738741603, 0.0294402376312064, 0.025993098970502615, 0.04932356132485438, 0.061981721155461855, 0.038222842922550626, 0.019635002936411183, 0.010678845483198529, 0.04988120366760995, 0.050520151999080554, 0.022147549461806193, 0.03962998089264147, 0.027650199699564837, 0.03509134709020145, 0.04931570198095869, 0.035423929439275526, 0.03523199891787954, 0.014126834830676671, 0.02378575696639018, 0.01365079069728381, 0.018868768856918905, 0.047826623485889286, 0.02888203496695496, 0.036569597650668584, 0.030549065631930716, 0.025392352690687403, 0.03332518404931761, 0.03980030749517027, 0.0772035818954464, 0.020330515908426605, 0.04250525395036675, 0.025495496374787763, 0.040182097945944406, 0.02501385552022839, 0.03542136531905271, 0.01903322136058705, 0.04772861546371132, 0.06136291842267383, 0.04562756199447904, 0.02357665685849497, 0.049076010545832105, 0.03609215920732822, 0.08920101507101208, 0.015277455022442155, 0.04900739157164935, 0.01660848574829288, 0.053254880840540864, 0.006681734112135018, 0.027708979650924448, 0.039310308202402666, 0.044256299443077296, 0.03750281124666799, 0.04943338062730618, 0.034163224627263844, 0.045948915649205446, 0.019581484812078997, 0.04025082082080189, 0.061847811739426106, 0.040381924918619916, 0.13299278944032267, 0.036605643763323314, 0.06395475415047258, 0.060427307689678855, 0.022146807314129546, 0.05394436571805272, 0.04567850672174245, 0.054018524824641645, 0.026935453970509116, 0.012288384750718251, 0.02167810580431251, 0.059368578367866576, 0.02108700373355532, 0.07706213596975431, 0.049034902986022644, 0.060466715731308796, 0.037657341235899366, 0.048347392221330665, 0.05554096285777632, 0.01394294547935715, 0.043044802732765675, 0.1031343404611107, 0.0037562171928584576, 0.016872686610440724, 0.025520662602502853, 0.006958186440897407, 0.0586301191651728, 0.04031656397273764, 0.06781702424632385, 0.02536481901188381, 0.041451797587797046, 0.05918643677432556, 0.052194062373018824, 0.006772214901502593, 0.051600492661236785, 0.04779725299158599, 0.021632220668834634, 0.026926477694360074, 0.05686978569428902, 0.034366035033599474, 0.027030584315070882, 0.004805234584637219, 0.03769542083318811, 0.07480750617105514, 0.05307768195052631, 0.03739266539923847, 0.02632019684824627, 0.027957035090366844, 0.042838055233005434, 0.06594066711841151, 0.016465848675579764, 0.062166905554477125, 0.05738399013353046, 0.058409823759575374, 0.04150621185544878, 0.034582378502818756, 0.04211345934891142, 0.009522338204988046, 0.020682084250438493, 0.01779521884600399, 0.031608206845703535, 0.032815399099490605, 0.04091720635187812, 0.050439087208360434, 0.03639082169684116, 0.058638972986955196, 0.002803734428198368, 0.08521254276274703, 0.041062448362936266, 0.049885623157024384, 0.07494824705645442, 0.03453811310464516, 0.01820798839617055, 0.05413419225078542, 0.03151095210341737, 0.04354859112936538, 0.03496432851534337, 0.005391691738623194, 0.04804879652510863, 0.026784085530380253, 0.026736649306258187, 0.037670570018235594, 0.041605503793107346, 0.04024177404062357, 0.005686790527761332, 0.07277077835169621, 0.004257029113432509, 0.03766549372812733, 0.04697091979323886, 0.03429687058087438, 0.006311184879450593, 0.03778493497520685, 0.05705943040084094, 0.046968351962277666, 0.06388758978573605, 0.050069271310348995, 0.030979631883383263, 0.1984862532117404, 0.09737045053043403, 0.11722155017196201, 0.08984399697510526, 0.11382782759028487, 0.16938242741161957, 0.25811459810938686, 0.12883156741736457, 0.117888562817825, 0.1122749800560996, 0.15117782691959292, 0.1761230282136239, 0.07341471762629226, 0.17908689886098728, 0.10121079016244039, 0.07792146876454353, 0.17281987733440474, 0.09428346500499174, 0.14622007263824344, 0.17814797814935446, 0.07438365821144544, 0.15659893368138, 0.1172950747422874, 0.14970794407417998, 0.10984726657625288, 0.15353334427345544, 0.12272614112589508, 0.11216333135962486, 0.13791867590043694, 0.13364234677283093, 0.11002779399859719, 0.1397557437303476, 0.07282439852133393, 0.16045024967752397, 0.15718944574473426, 0.11955506284721196, 0.1639972851262428, 0.10301462461939082, 0.23435638780938461, 0.1570098608499393, 0.11946605707635172, 0.12423238178598695, 0.11999629932688549, 0.12105027519282885, 0.11471097590401769, 0.09342656645458192, 0.1848786638583988, 0.08779748764936812, 0.09655004338128492, 0.0955420732498169, 0.13171147147659212, 0.2686307713156566, 0.11070190157624893, 0.1771874015685171, 0.10939949919702485, 0.08424415136687458, 0.14167996938340366, 0.2374449689523317, 0.11937989373109303, 0.08649826908367686, 0.17562003020429984, 0.13929515203926712, 0.23080372688127682, 0.1605867751641199, 0.14916099607944489, 0.10267250938341022, 0.15434062283020467, 0.1982864225283265, 0.15414460678584874, 0.07451928569935262, 0.11508743031299673, 0.1159687752078753, 0.15993411565432325, 0.1899544641491957, 0.13291909417603165, 0.13959526171674952, 0.11189710814505816, 0.18510111520299688, 0.10724833962740377, 0.20155130827333778, 0.11360824093571864, 0.127725099446252, 0.17197823734022677, 0.10802887118188664, 0.12424697983078659, 0.12061226705554873, 0.0864458511932753, 0.07445218812790699, 0.08025511502637528, 0.14502678823191673, 0.08484730962663889, 0.1916414697188884, 0.147595361340791, 0.13008060195716098, 0.22847891959827393, 0.11550664727110416, 0.24864421488018706, 0.08608850708696991, 0.13045106723438948, 0.09148095952696167, 0.20585949037922546, 0.12435578610165976, 0.13889555004425347, 0.0893103631096892, 0.12445935280993581, 0.13328584871487692, 0.16030241386033595, 0.20357357163447887, 0.06992378854192793, 0.059708775152103044, 0.16962769237579778, 0.17026726040057838, 0.12877281900728121, 0.11740638205083087, 0.12425335487932898, 0.0913820683490485, 0.18766490888083354, 0.1403596589807421, 0.10097990059875883, 0.16229606000706553, 0.12522860371973366, 0.10416153221740387, 0.14828215964371338, 0.16872880310984328, 0.16836192982736975, 0.07727760370471515, 0.16596841451246291, 0.11953786728554405, 0.175170095753856, 0.07082091891788878, 0.1315421430626884, 0.13030101981712505, 0.1566347200423479, 0.17769489699276164, 0.10711424838518724, 0.14961171720642596, 0.08745042970986106, 0.09374056913657114, 0.06921865919139236, 0.12127040361519903, 0.12226255115820095, 0.13055522023933008, 0.1400497677968815, 0.14588488906156272, 0.10723466184572317, 0.06757831244613044, 0.19572409830288962, 0.15038004785310477, 0.20317808113759384, 0.16120675049023703, 0.1489933003904298, 0.1456822085310705, 0.2078007854288444, 0.23823030962375924, 0.1811538840411231, 0.11873251831275411, 0.18001384130911902, 0.12908474367577583, 0.14887172175804153, 0.15183363313553855, 0.15893248346401379, 0.13472589722368866, 0.11517950115376152, 0.1721936828107573, 0.13466343807522207, 0.13422999414615333, 0.13431482162559405, 0.13082461984595284, 0.12397960628732108, 0.15181497554294765, 0.13360164739424363, 0.1377006625989452, 0.21169536863453686, 0.14267694088630378, 0.22681842354359105, 0.1165559550281614], [0.07871033463743515, 0.034794851671904325, 0.03656256209069397, 0.03461997570411768, 0.02603538283437956, 0.023032172794046346, 0.0324157859722618, 0.006743498888681643, 0.06808988226111978, 0.03062472758756485, 0.04601288506819401, 0.0202284000988584, 0.00867815913807135, 0.08318128457176499, 0.005809906797367148, 0.1232870043895673, 0.010367623071942944, 0.035515343479346484, 0.031787654443178326, 0.045189379452494904, 0.042582845489960164, 0.025622054818086326, 0.09433241706574336, 0.03012361834407784, 0.023402382030326407, 0.03809412111877464, 0.01930174337758217, 0.039005144499242306, 0.030904341001587454, 0.025502901153231505, 0.018853771907743067, 0.011897568856511498, 0.034870005256379955, 0.022746048889530357, 0.024994448358484078, 0.036239327091607265, 0.01359046800644137, 0.026214143945253454, 0.044934789402759634, 0.010582385766610969, 0.0101703268228448, 0.07299434291780926, 0.06385749569744803, 0.02053506479569478, 0.01812151891499525, 0.06743812075001188, 0.024939542417996563, 0.024676232133060694, 0.01616274814296048, 0.00533759566678782, 0.044962471511098556, 0.04510447775828652, 0.06099101337895263, 0.025696924531075638, 0.05739081789215561, 0.034329740301473066, 0.07293350907275453, 0.006434671295210137, 0.005876873565284768, 0.05025061509513762, 0.03389240380784031, 0.018769862836052198, 0.010608725515339756, 0.013962783086753916, 0.017271219912800007, 0.057263157359557226, 0.07652041269466281, 0.04818141460418701, 0.06971104448894039, 0.034009199298452586, 0.016630397658445872, 0.0473228536429815, 0.043105603181174956, 0.0557407081942074, 0.08103290805593133, 0.030704666169185657, 0.030570879207516555, 0.02451353480864782, 0.03464114917733241, 0.04271826517651789, 0.04143352220125962, 0.022762825137760956, 0.01899613438581582, 0.048406619316665456, 0.03411316676647402, 0.06010424709529616, 0.0392669667780865, 0.039097167100408114, 0.032151113846339285, 0.047077039489522576, 0.04191661580989603, 0.01618911850528093, 0.020597898728738073, 0.060804159147664905, 0.0616397729027085, 0.05903810371819418, 0.05588909320067614, 0.03697751169966068, 0.038548693992197514, 0.0422549312497722, 0.002020402425841894, 0.11466347103123553, 0.05170074939087499, 0.0694885931443423, 0.03171567354002036, 0.08364745721337385, 0.03210851085896138, 0.041896503607858904, 0.030018749166629277, 0.021130753339093644, 0.06696766591630876, 0.02415362287138123, 0.006158283440527157, 0.040015400445554405, 0.029086719296174124, 0.012900439505756367, 0.06249523168662563, 0.07884283768362366, 0.015000492003309773, 0.06633500728639774, 0.0335555132915033, 0.018492435046937317, 0.023705078092461918, 0.05495070312463213, 0.019412499641475733, 0.039553662136313505, 0.05123127419210505, 0.05045099867857061, 0.06375550976372324, 0.07490367366699502, 0.048226908256765455, 0.013954918176750652, 0.04679451129049994, 0.055694420443614945, 0.023074412129062694, 0.014405459332920145, 0.04524067298916634, 0.036234451181371696, 0.01732963621179806, 0.04311302465794142, 0.04700908473751042, 0.01936580185429193, 0.05309389787726104, 0.039268339751288295, 0.02726877290115226, 0.042725916719064116, 0.029236879890959244, 0.02299932348250877, 0.0686235680768732, 0.023931247596920002, 0.06723139551468194, 0.019468706195766572, 0.013706500940315891, 0.027400967956054956, 0.04286779309040867, 0.026783265457197558, 0.0156925957344356, 0.05937473077210598, 0.04885039023065474, 0.04625449495506473, 0.018581104995973874, 0.05459972293465398, 0.06009834702126682, 0.014182546929077944, 0.01841979548771633, 0.10192250978434458, 0.05880661301489454, 0.07034352500340901, 0.04117826421861537, 0.06147475265606772, 0.048457445300300606, 0.06266323165618815, 0.0349669111892581, 0.06203607234056108, 0.01842432073317468, 0.019348084933881182, 0.07478737912606448, 0.05016537572373636, 0.07264751504408196, 0.024689690981176682, 0.023894804435258266, 0.05830381538544316, 0.05933004606049508, 0.09444048861041665, 0.04336770005465951, 0.004657593581214314, 0.09724925039336085, 0.054641324022668414, 0.06879217660753056, 0.030862155472277664, 0.07856646931031719, 0.03372720173501875, 0.051859190498362295, 0.03590565007471014, 0.014947109320928575, 0.002128831361005723, 0.028921277880726848, 0.06438356707803905, 0.04154000183916651, 0.05438062609755434, 0.03010475295013748, 0.09837393066845834, 0.010487091221875744, 0.009962936437659664, 0.014358518492372241, 0.028255346915102564, 0.0539054623368429, 0.056324303441215307, 0.054220967867877334, 0.033980645166593604, 0.07896179653471336, 0.03652850864455104, 0.04883179943135474, 0.01773191735992441, 0.05475988953548949, 0.013917066789872479, 0.07410195379634388, 0.05250896676443517, 0.04387285400298424, 0.0901524409709964, 0.05267391650704667, 0.0382207908842247, 0.031129862982197665, 0.02297783830726985, 0.06571913603693247, 0.021739195690315682, 0.01408115935191745, 0.026831633076653816, 0.011581802646105643, 0.05551537360588554, 0.041162586348946206, 0.017755862754711416, 0.06882877933094278, 0.03492460506095085, 0.028880969985038973, 0.056655353255337104, 0.019481513809296302, 0.0048142762625502655, 0.04346791967691388, 0.04790760292962659, 0.012623596157936845, 0.06750143336830661, 0.005744556056015426, 0.0529641704633832, 0.08595493534812704, 0.01860070140537573, 0.06132183683803305, 0.051512117715901695, 0.038040719882701524, 0.024500999934389256, 0.052732000694959424, 0.014914031798980432, 0.038852377110742964, 0.007048344396025641, 0.013799501321045682, 0.056716725157457404, 0.038394772564060986, 0.020369582562125288, 0.05671412392985076, 0.032789832112030126, 0.053589826929965056, 0.04863805435888935, 0.04960867590853013, 0.02643454139615642, 0.012088780422345735, 0.02668933924724115, 0.018606976263981778, 0.04768327024066821, 0.04387260909425095, 0.07459232045221142, 0.05896622300497256, 0.0410704969544895, 0.021547918258875143, 0.05238530269707553, 0.024000393495953176, 0.019786245211435016, 0.02344578653719509, 0.08568310891860165, 0.011224298050365178, 0.03963002542150207, 0.025223454722436145, 0.04016869846964255, 0.0711705521098338, 0.12440053018508479, 0.011558403657545568, 0.0598529744456755, 0.008011500867723953, 0.0434509616025025, 0.00636143384326715, 0.0071703409503243165, 0.02428997580864234, 0.06771550586563535, 0.03893916386005003, 0.042195908245048486, 0.009282040991820395, 0.06411659429431893, 0.025283423965447582, 0.08980239959782921, 0.017125612394011114, 0.07114845837350003, 0.027314747094351333, 0.06301736968453042, 0.05483498745888937, 0.04638012942450587, 0.06363376785884611, 0.10490492670214735, 0.024164883107005153, 0.01943713523360202, 0.0427427412068937, 0.055823706279625185, 0.049591317074373364, 0.053180543618509546, 0.05189389703446068, 0.02213422234490281, 0.031674469501012936, 0.09441609421628527, 0.08958426013123244, 0.06645057452260517, 0.06294277642155066, 0.06101214232330676, 0.022299229603959247, 0.028439095258363523, 0.040424898979836144, 0.05026057471695822, 0.047394674984388985, 0.04784359269251581, 0.049864427419379354, 0.054711727862013504, 0.028442345865187235, 0.02071269784210017, 0.02292597888299497, 0.03393685845367145, 0.06519227055832744, 0.04066323599545285, 0.030124818767944816, 0.028315125055087265, 0.051889188107452355, 0.010716522465372691, 0.021430234046420082, 0.017325235276075546, 0.039588502258993685, 0.07269827794516459, 0.05607068560493644, 0.051507939424482174, 0.010422045688756043, 0.05847868764249142, 0.0907569054106716, 0.017987474057008512, 0.031396765261888504, 0.013428668680717237, 0.004777737085532863, 0.045155711923143826, 0.2503940952010453, 0.13415199442533776, 0.1810511262738146, 0.1128187813446857, 0.15599265840137377, 0.134802664979361, 0.1162336699781008, 0.25678808335214853, 0.2097027763375081, 0.14763016806682572, 0.14428894501179457, 0.13670507149072364, 0.13046852254774421, 0.18628823978360742, 0.13308345020050183, 0.2576663705985993, 0.07104599746526219, 0.14312555431388319, 0.13946767168818042, 0.1484294908004813, 0.13306106702657416, 0.1549986406462267, 0.22424239927204326, 0.1537149478099309, 0.15238846273859963, 0.0931980369205121, 0.08422815808444284, 0.17055315052857623, 0.1673895976273343, 0.15424449986312538, 0.07729240212938748, 0.15740279835881665, 0.1191284392552916, 0.11556749595911242, 0.16773873358033597, 0.1443187496624887, 0.11990543818683363, 0.07371406289166771, 0.10748092870926484, 0.09712773113278672, 0.11323182363412343, 0.1421174654387869, 0.12851711944676936, 0.1331696580746211, 0.09991409489884973, 0.17056719196261838, 0.10141452454263344, 0.10456525313202292, 0.1300327482749708, 0.12713789736153558, 0.2174162882147357, 0.1461838706745766, 0.08560592556023039, 0.09930554122547619, 0.19623312255134806, 0.24215325771365315, 0.15465207252418622, 0.09080149364308454, 0.08462085068458691, 0.1396357236080803, 0.09078947827219963, 0.09804918910958804, 0.13353949994780123, 0.10958578568533994, 0.1148604518675711, 0.15799320652149618, 0.12285129691008478, 0.18544686696259305, 0.22684528928948566, 0.13316116790520027, 0.1067464028892573, 0.13902282837079838, 0.08582598718930967, 0.14164013089612126, 0.14565749501343817, 0.07181653229054064, 0.16101227811304852, 0.11437951790867373, 0.10305143514415249, 0.13889724214095622, 0.19592159864259884, 0.09241674095392227, 0.08886667754268274, 0.15029250411316752, 0.10286151213222183, 0.1482047387980856, 0.15070452966028824, 0.12832306267227978, 0.10609930206555873, 0.09825290864682756, 0.1325103489216417, 0.10202269229921512, 0.11397726644645445, 0.1371255872072652, 0.1131216147041414, 0.1749574556015432, 0.10706966757425107, 0.12235490401508287, 0.12802982528228313, 0.15332928334828466, 0.1093766484700609, 0.17739722155965865, 0.15466480777831748, 0.16253577370662242, 0.10305608841008507, 0.259080933756195, 0.18653859588084742, 0.19339835591381416, 0.13916389580117539, 0.12563629512442276, 0.11370964799425565, 0.07050221101962961, 0.14265884732594714, 0.1848738398985006, 0.07654127446585335, 0.24479831656208262, 0.20393294922541827, 0.18735390447545797, 0.1354195232852362, 0.18717105413088575, 0.12054458318743855, 0.24668840342201293, 0.08087728710961528, 0.15062425896758214, 0.09398694732226431, 0.1576193273649551, 0.13134326232830063, 0.08446166742942296, 0.16559067618800327, 0.27801080548670143, 0.1708478870568797, 0.06208575170603581, 0.15999675291823223, 0.10808455452206545, 0.14404503075638786, 0.12208437634399161, 0.10252581647364423, 0.1206258409365546, 0.11729034726158716, 0.13118886592565104, 0.19424820406129584, 0.08819195398245938, 0.20689723547548056, 0.13870052847778425, 0.09596379866707139, 0.09862953374977224, 0.12070623779436573, 0.09216792110237293, 0.19006119982805103, 0.1661904650973156, 0.1423981160041876, 0.09241958337952383, 0.14917675929609686, 0.2380245120730251, 0.1791414021863602, 0.15216501691611484, 0.13490048004314303, 0.16865265875821933, 0.12538156035589054, 0.1551821589237079, 0.18593379005324095, 0.1567445875843987, 0.14000811846926808, 0.07408077290165238, 0.11400192801374942, 0.2322843560250476, 0.18128632771549746, 0.08899365901015699, 0.09402639247127809, 0.15029593283543363, 0.19875556376064196, 0.09803559296415187, 0.18642215291038156, 0.13856145000318065, 0.13578351703472435, 0.1671299201552756], [0.010057694780698512, 0.06525953140226193, 0.03872194094583392, 0.06800861709052697, 0.020383865194162354, 0.06409571768017486, 0.02885959984268993, 0.05177722399821505, 0.02948724155430682, 0.03386443597264588, 0.06796541667426936, 0.01778918147465447, 0.019511468744894955, 0.0359121216024505, 0.07079938921378925, 0.01314311994065065, 0.013535888610931579, 0.020857216259173583, 0.0066380679982103175, 0.04475089634070173, 0.01899811592011247, 0.04034075427625794, 0.043740302717196755, 0.021334164885047358, 0.006591190240214928, 0.007730770521447994, 0.0256360034836689, 0.019579957843234297, 0.04247573873726651, 0.014406087375391508, 0.006224965409273864, 0.053252851066645235, 0.0170672758758883, 0.0112081145925913, 0.026871914997173008, 0.025681873776193243, 0.025559280256857164, 0.016926288226386532, 0.04799174392246641, 0.05161990353371948, 0.02483971056790324, 0.03849528533464763, 0.04702577192801982, 0.0450246746186167, 0.057176630361936986, 0.0444309861632064, 0.04588931376929395, 0.020619016540877055, 0.0176867261325242, 0.034833996251109056, 0.04027637667604722, 0.03765423163713422, 0.12850754574174061, 0.06486822661827318, 0.030949031279305927, 0.04174574372882489, 0.049249502408201806, 0.08844705982482992, 0.017763588512025308, 0.04679656703956425, 0.04546883144939784, 0.07493921511922963, 0.0491078375489451, 0.051783554517896846, 0.030212998899514787, 0.041338634910061955, 0.030574543561669998, 0.05167717506992631, 0.042386495479149744, 0.062676234083483, 0.02369084926613141, 0.03451054602919612, 0.024386135883105453, 0.09711098828120157, 0.03891062457114458, 0.0221494734796579, 0.027527899328561034, 0.013102728553349152, 0.007319107699004235, 0.046233043176471256, 0.03155386308208108, 0.029569478938356042, 0.04811575679923408, 0.06968495799810626, 0.06631355179706588, 0.0417038235173095, 0.01908624966745265, 0.03151736054860521, 0.026924368139589205, 0.07211840827949345, 0.02057168607279891, 0.039348922146018595, 0.09594652146915905, 0.011190861514478456, 0.03181481333740521, 0.03103290880972054, 0.03344061398820486, 0.008480629112455063, 0.07256034237798303, 0.045557555204140954, 0.06226150711881928, 0.019182838332199026, 0.07211990741780028, 0.03700797686178703, 0.018574165915197227, 0.04418707190779969, 0.0073887141934392275, 0.009638204155635322, 0.02482868410879746, 0.08738745105802082, 0.0939079160161782, 0.08046823757467791, 0.014476853939413559, 0.04246688120474573, 0.06375845608999953, 0.12604181945789605, 0.0572900973202195, 0.018012816544796806, 0.062387100770138204, 0.03635322078480385, 0.060909507010364905, 0.0053233543167152675, 0.030753174796700478, 0.0280625035520643, 0.04115187344723381, 0.012410853032633895, 0.034398077259538695, 0.019220416979806032, 0.029940001732029486, 0.020559468466672115, 0.039036002999637276, 0.11928357038414106, 0.03063743315578904, 0.05448106465337332, 0.05453065867186524, 0.02131037719664164, 0.028338547235762235, 0.025352966913487762, 0.04397428703668993, 0.02822688369633397, 0.04042368927912321, 0.00770825886320381, 0.0811157762655057, 0.020698558073490858, 0.05369164216972422, 0.040153120789909735, 0.01723260782455327, 0.025341044311062433, 0.07256996061187238, 0.06377658675774, 0.057602953384048305, 0.02901965141063556, 0.006256366141315084, 0.013284824690344976, 0.0495553006476257, 0.019717585419130046, 0.06486019658041187, 0.04634945646103006, 0.015383380832645344, 0.01299446868870291, 0.06518694193800911, 0.016163568216143176, 0.08499259987729602, 0.020368146506370977, 0.040351077550440095, 0.044044293827028014, 0.04248587276379112, 0.056061290015350096, 0.03661411537905224, 0.02823643142619403, 0.021619986364385113, 0.02008742914767936, 0.04011825098132249, 0.00926478791370755, 0.02652749539265642, 0.014991999978519743, 0.007721187539573293, 0.01580548196216114, 0.030502070985676255, 0.0181292094202945, 0.12221233002492227, 0.08576738720876165, 0.019520007153914776, 0.08034210215555504, 0.009659043662395561, 0.0008292930920106301, 0.055797345194150694, 0.0405958118790295, 0.0537709888885729, 0.04156016970227938, 0.04046119000122417, 0.021229024823696818, 0.032557985177845694, 0.02783148411253933, 0.00972398993326351, 0.017889991104311775, 0.016366386043955572, 0.0631037779385224, 0.010461006586410804, 0.04984766601410229, 0.0214912701267167, 0.024670539860380813, 0.05010267537727486, 0.050863911092164926, 0.05445512288133614, 0.061138300006859936, 0.15597291727317497, 0.04021587679744698, 0.044589186072698794, 0.06835528911324218, 0.017314232936769258, 0.027763601719925646, 0.026772534001793247, 0.03158672167046461, 0.03365146927535534, 0.05715237697586417, 0.0557077976554865, 0.06799647555453703, 0.025235904249711893, 0.0037357626752054784, 0.05173136669327505, 0.05543477265746333, 0.03334316257678438, 0.04608635026670527, 0.03132688834739383, 0.04985854589904193, 0.018601899973873515, 0.04121188721910585, 0.035544825295801274, 0.02673466591659235, 0.020577769828378223, 0.026682140414777678, 0.013490660276147537, 0.021374775205913465, 0.056136202401830815, 0.05811041541164741, 0.026589737462927587, 0.06525967983179726, 0.0437144648458343, 0.010712170696933754, 0.017798209701140877, 0.04184296507446561, 0.016122440247272607, 0.046537357120541856, 0.003060402491428249, 0.0611731883691391, 0.0201887174625881, 0.043791644493467174, 0.07829574868083, 0.025479707182967104, 0.06934926233952865, 0.08615748229203746, 0.01813416511140531, 0.040114848234225065, 0.020703825466625858, 0.09104327793465927, 0.04432543049915694, 0.03195346878783312, 0.07698979883571155, 0.015474185383936856, 0.023621727486897726, 0.02975738145323703, 0.03564491504221223, 0.02089105448249029, 0.045687004312640056, 0.03247878688853234, 0.03929292339307722, 0.04692270245868713, 0.03371742393937893, 0.010035949853772763, 0.032190039491979405, 0.017839291285781655, 0.03830850160738919, 0.011596399763220688, 0.040346498499275185, 0.03860301920212805, 0.048691574338590726, 0.034291972406208515, 0.06797055233619176, 0.007843842286092695, 0.018300422889296897, 0.06609630290768109, 0.023029165240586735, 0.08962531574070454, 0.047095147892832756, 0.04905435838736594, 0.03920239250874147, 0.04295048689527903, 0.021010365853726398, 0.025936612255463842, 0.08733759357710369, 0.04033864657685626, 0.007560314970760373, 0.01687025978753809, 0.024575394672865514, 0.024182870911317877, 0.05243070729193278, 0.02658167217305163, 0.04052715208672453, 0.02167273822124116, 0.02759432711172849, 0.0437827424320858, 0.04548844641249161, 0.0526119842834305, 0.028705713666568045, 0.015270584590325598, 0.03245583597163204, 0.010201960867561866, 0.023749475221848115, 0.07479925348889083, 0.05100002097606193, 0.03888316510710865, 0.008240573097282322, 0.058923282340401784, 0.051656725190696307, 0.07950710438308306, 0.08124351472361013, 0.02121588880982017, 0.021480384675669484, 0.04449068081157748, 0.04349393566371873, 0.03889804516802542, 0.04146200211835094, 0.03599016956286505, 0.0030904937966624857, 0.019222415212425403, 0.0413870934426086, 0.018992306759173516, 0.08142291408148594, 0.020637501584133133, 0.020803386432817206, 0.03299381882243324, 0.03272154710430186, 0.011074389785790117, 0.0471244849904906, 0.07928912818897516, 0.043031009918195195, 0.03131633500743192, 0.026601558020047378, 0.019386312960705254, 0.08661272309836932, 0.048196955176535994, 0.012180016346974298, 0.049243212706642225, 0.036337145866127685, 0.0531971974123735, 0.028980466013308614, 0.029554619286500383, 0.0591488692589337, 0.05769474220869597, 0.03251285888836719, 0.05324886573362164, 0.12054870210704394, 0.141424358880613, 0.0794844985648524, 0.1713661287794821, 0.16057853732490912, 0.13334324641618878, 0.073517245327821, 0.138612762093544, 0.15904576488537714, 0.13960152544314042, 0.11955752677749842, 0.12390499818138778, 0.17562351829838008, 0.16913457977352664, 0.1392945137922652, 0.12148071342380717, 0.18040835217107087, 0.18607638630783185, 0.07224927117931657, 0.172214730118867, 0.09474641672568396, 0.15331313421484083, 0.15499754226766527, 0.12951901881024241, 0.07841161277610809, 0.11897617281647399, 0.2057253842940554, 0.10814143272000365, 0.20099082350498065, 0.14384573441930115, 0.36093654634896666, 0.16438525024568662, 0.13117391907144338, 0.10117220590473153, 0.1856143696932122, 0.10273797422996722, 0.08610959150246345, 0.08456271083559841, 0.1333227928262204, 0.1290814930689521, 0.1531373936450109, 0.14763258746825159, 0.12504701502621174, 0.1596039193100296, 0.2050172715098597, 0.17151993146399036, 0.20008558145491406, 0.16670055803842843, 0.07308012776775286, 0.16642259404761717, 0.1030275083030574, 0.11431600491050631, 0.20541899604722857, 0.17679268290521577, 0.1017012532975059, 0.07973882515216246, 0.1625172348576598, 0.22120744572021067, 0.23180213815066963, 0.08711376183782704, 0.19046742178034037, 0.23248727404279634, 0.20783830841537565, 0.1650747944950126, 0.12764335930114612, 0.182870723947417, 0.11435001011705026, 0.17545188922667876, 0.09420382513781078, 0.16759156569605693, 0.09422084258403629, 0.10706208282499574, 0.09345164362457581, 0.22188003931660205, 0.08557284061680548, 0.1910685168695636, 0.09458929664106108, 0.14143727225018665, 0.09030884117237292, 0.16480417776620016, 0.1318806069320999, 0.07770260199322365, 0.2191265526926145, 0.10914797050645575, 0.11982688927673735, 0.2851150289643556, 0.20642764895455912, 0.0751635737833567, 0.10747692853328772, 0.18362119852099568, 0.17991102416999638, 0.13212247285991907, 0.1562106271740049, 0.16905687691178173, 0.12231141416123137, 0.1020705014525447, 0.12105737012461759, 0.16788958251709118, 0.19239733228459954, 0.16557828232180327, 0.1670674016349949, 0.10751900830655359, 0.21000276727136225, 0.13747240765951574, 0.09009202272864059, 0.11881618062034249, 0.08311996090924367, 0.17777510831365362, 0.10388098555267788, 0.14267250284319744, 0.1588418969186023, 0.0976034403720405, 0.13805952068651095, 0.11767064599553123, 0.15392923553008586, 0.22769648814573884, 0.18317245150683448, 0.12505369435530156, 0.11779906722949818, 0.10298176974174567, 0.19836241845041513, 0.08079666018602438, 0.11783117995946668, 0.06096239245380275, 0.14145552908303216, 0.14248134044464678, 0.10841331852134317, 0.1438225497258827, 0.2707364223897457, 0.12843925331253558, 0.06106169552367646, 0.19293509249109775, 0.11014129806426354, 0.18751253111986443, 0.22740219690604135, 0.15506693307543173, 0.09708070123451762, 0.19155658286763355, 0.07246333625516854, 0.17342872044537216, 0.14097007544478402, 0.18161621235776693, 0.1646677710232325, 0.08451981469988823, 0.13685489626368508, 0.12806504761101678, 0.24180965818231925, 0.09577209450071678, 0.155426028650254, 0.20390758261783049, 0.22057151421904564, 0.1368784371879883, 0.12631633988348767, 0.11901438600034453, 0.1463196540134959, 0.10108561211382039, 0.18170849099988118, 0.23415918432874605, 0.06924592569703236, 0.17654804134508595, 0.19742793578188866, 0.08993964496767148, 0.1047270190611016, 0.10154503121157177, 0.1370115636382252, 0.13949624437373132, 0.0944400136359036, 0.14216623938409612, 0.2534080756595358, 0.11914855145732872, 0.12232580440468155, 0.10986062523443252, 0.13209998578531668, 0.1729190579499118, 0.11783063819166273, 0.13682219723705202], [0.04366826615296304, 0.05575171424425207, 0.030000455226399936, 0.023181288815976586, 0.03584256752219517, 0.011953408047702396, 0.03760637795494404, 0.03667165779916104, 0.024351995234610513, 0.018799318677338306, 0.0677508395165205, 0.05095456443086732, 0.061532732943305746, 0.04239200221491046, 0.08332051889738068, 0.07035432325210422, 0.02336818572075572, 0.06096247409004718, 0.030346759886015207, 0.05301783516188152, 0.03431315330090001, 0.02773471176624298, 0.03427131843636744, 0.010929279505944578, 0.027149936504429206, 0.022767840200685896, 0.033187166845891625, 0.05156323684786912, 0.02677151540410705, 0.04220652466756292, 0.06724773018504493, 0.035729608935071155, 0.00849548227051855, 0.043297388983774, 0.06667312976787798, 0.09245878361980431, 0.07224709668662399, 0.04158780357101932, 0.01641391689190641, 0.06629793700994924, 0.03836631491139997, 0.044932485034223646, 0.026261687780788634, 0.06687984758173116, 0.03323833050671965, 0.022438052037614398, 0.044762974794139154, 0.08716129639651626, 0.05816770179080777, 0.08646514703286812, 0.09762750079971738, 0.04611762808053754, 0.04171301501628477, 0.04509971317020245, 0.01682495538261719, 0.041708521312102675, 0.058383314244565554, 0.09713299295981415, 0.023501538526033983, 0.04470366606255993, 0.06400429992936552, 0.01004725554594188, 0.03745454196177889, 0.022059141119825654, 0.005003035494155483, 0.04119973455090076, 0.050391474724165164, 0.020906383542751428, 0.021984241720929276, 0.051876838770112954, 0.0405504852096783, 0.04834968916838989, 0.01528338756543235, 0.05146470561157912, 0.018255439463246148, 0.03566556901205331, 0.012893490220449166, 0.11976478635915555, 0.06677369819954038, 0.01726767801301321, 0.059480880154296756, 0.07278795907041058, 0.08732450951356441, 0.03947919132770039, 0.018838505930034444, 0.03132911479042377, 0.03513975738314912, 0.06407216191291809, 0.06593492289539427, 0.0928893628588412, 0.016124321591632906, 0.08863130540703423, 0.015244314417941496, 0.01844837002863642, 0.0034737131136353128, 0.009041984048963059, 0.05213423784880433, 0.03484358479909133, 0.05174550831725355, 0.020798287878278643, 0.020979833898309153, 0.03240211561205797, 0.0771729979896918, 0.034954650909639895, 0.04165914251643699, 0.04371142204036005, 0.023353851138381287, 0.02751687658019364, 0.027498387826199178, 0.04098970675840974, 0.07949013146571815, 0.00760400195758848, 0.044054142126697116, 0.023869530596130062, 0.04330609808675945, 0.04753048800921533, 0.05546866654185578, 0.022375874905264936, 0.019796375527221244, 0.062307126936502755, 0.04596939521434251, 0.0646347989095375, 0.04454845329746604, 0.010378387923992705, 0.02740100877417717, 0.12875494809122756, 0.03837478652712889, 0.03322792188555468, 0.024643920878588688, 0.04524069154285826, 0.0071374382969224826, 0.03554991271812469, 0.06939743514521979, 0.07304971455596387, 0.033207561064045876, 0.11597717631957494, 0.018548283514974173, 0.030104123979981523, 0.02427667652227683, 0.0024607337172710686, 0.10832671730895527, 0.009138703517237445, 0.037516748780035414, 0.04713957285275683, 0.043398450943641365, 0.037007041755714454, 0.04611313437635545, 0.019464477809378877, 0.016199543824768625, 0.052910379599779844, 0.01959506240382325, 0.03336323024996091, 0.007930653155199252, 0.04494457461987622, 0.060757270257454365, 0.0218934288204764, 0.06519841554109007, 0.13244664296507835, 0.10369662864832208, 0.025911596312653273, 0.014123952514637494, 0.037762318024761043, 0.02123373375070514, 0.010410586928628618, 0.018759838276309893, 0.07748707488644868, 0.017537361491122283, 0.017675838826107793, 0.015017152290965896, 0.06332991775707342, 0.027217976603424177, 0.08653358047013171, 0.029525441750593018, 0.025028101044881623, 0.02864430280169472, 0.028245984722161666, 0.013559324706875486, 0.03564659600669984, 0.054336924731615, 0.05535886208235752, 0.03412151963857468, 0.03439759115281049, 0.0319280650728615, 0.06902553752297536, 0.01664820549194701, 0.009917643164953915, 0.04614362922438886, 0.04069954185979441, 0.12738034216454253, 0.03334225715661887, 0.03856765957607422, 0.036574176701833494, 0.060292993803159334, 0.050049522760673426, 0.028002077888231725, 0.0675759969453793, 0.08314036997035146, 0.017311214251094498, 0.019825998351734597, 0.04907712005660869, 0.08482759076287039, 0.022486158050014637, 0.047858457910479046, 0.0364154016278917, 0.01764932745572878, 0.02270606011734344, 0.0647633388871327, 0.02833050977642415, 0.014676038026664173, 0.057466401922283694, 0.1233749117818661, 0.048526884347666055, 0.06612679033423774, 0.0571706746268319, 0.04074499098351225, 0.06601615838008001, 0.027959684557572473, 0.048450354079250246, 0.014044115050637629, 0.08699745245394297, 0.04331394629843999, 0.032621045465930365, 0.026270682610629592, 0.02169004324969137, 0.004328173245085054, 0.06617156410356984, 0.015050514612084953, 0.08046310933423229, 0.09619078453397378, 0.02851129880582448, 0.03372004743141588, 0.043684508054866455, 0.03294019494205713, 0.014421080613828963, 0.07281501777470112, 0.024500272629666142, 0.08517344642314129, 0.04052530413900968, 0.041040495634661056, 0.015491523809032515, 0.03585410049709026, 0.025777974478842225, 0.0071094310351327294, 0.046044003320275806, 0.0402070860582171, 0.05809212518215645, 0.04893404140602797, 0.05317839881172404, 0.020949060744896997, 0.033335180778522044, 0.03149127776850946, 0.10798086907016113, 0.04349809169070795, 0.03468806033197325, 0.08730714325793087, 0.022771947988076136, 0.05120434536365792, 0.031657826839364134, 0.07323270590859465, 0.023035957747197244, 0.10807965634739958, 0.021332717697077896, 0.05470989475725219, 0.005799189257231774, 0.07313046022318304, 0.02254274866572814, 0.08575006548198871, 0.03143730507872533, 0.028792518969567027, 0.035449025162961334, 0.050417917445884086, 0.04873291196417995, 0.06721410347381607, 0.03547185733623337, 0.048770720677566715, 0.033596494686207734, 0.008888314023351995, 0.030795612656220328, 0.0358055343531305, 0.051002859690925106, 0.03822973376372829, 0.020962155940651428, 0.012032990398438415, 0.03273401518526953, 0.04890655225608498, 0.02577267925516935, 0.020692912185040768, 0.03361650669830851, 0.029058790423732717, 0.07396110901026987, 0.0043875125902559375, 0.06293801183346659, 0.04821380563953426, 0.02577007431682432, 0.012528563220257638, 0.01810354966437444, 0.024208376671595033, 0.04414573428221047, 0.06070399518648628, 0.07193998113507405, 0.024451220378978178, 0.025627999420976266, 0.04287115501938388, 0.047140830793068744, 0.04167505416262429, 0.031994539240258746, 0.036526382391457446, 0.03546830244886223, 0.026331655608373694, 0.08812098982161842, 0.013252717526484048, 0.068421236355789, 0.05961068549368065, 0.08083502179943025, 0.057865402777679265, 0.03798026453296188, 0.02618087160954019, 0.050528942738310434, 0.01663757793721743, 0.02569511369074462, 0.012377123348414898, 0.056415454018861055, 0.013648977073899005, 0.028357021146803163, 0.023778498762112577, 0.035603087599156424, 0.01577622093464015, 0.04376667864562478, 0.07715267798630521, 0.011269832521065837, 0.026007435408246238, 0.020671634811151307, 0.060099604961578734, 0.07813986798282713, 0.012543526772788027, 0.009946278933057329, 0.04223378375172615, 0.05531723130843602, 0.00537063190677145, 0.03247774046030827, 0.05725735747546423, 0.02792697439872427, 0.013371201403060695, 0.03287432933575474, 0.013056908355792984, 0.04126813088078052, 0.037914120621280745, 0.039519760830444284, 0.06765328420442529, 0.07858142358600162, 0.05985686701023951, 0.04991262991097756, 0.10666833637515083, 0.13893025286961347, 0.16836568509461358, 0.15371908899396658, 0.12600710178958252, 0.15742109972052276, 0.09394314576638862, 0.13793305872241035, 0.11305516280117445, 0.08221707146731205, 0.15824112837435678, 0.16730466624721885, 0.28811351337935776, 0.09987299476051703, 0.12116169382352382, 0.20870605716481805, 0.1584680622909218, 0.11105330107966438, 0.11625318846199661, 0.16205585649004206, 0.1438370067626238, 0.09569384244969115, 0.09306499210651964, 0.22041619755327702, 0.17150379717350006, 0.14159483020193875, 0.16160709463292733, 0.14774480019696057, 0.1340105856070295, 0.10959501058096066, 0.1980665687005967, 0.1445022234111093, 0.09387138750753365, 0.10362318571424112, 0.18715199577854946, 0.16023567994125187, 0.14307160017779097, 0.14405758789507672, 0.15556973812635988, 0.1611387252341956, 0.1570758971502073, 0.11129605758469552, 0.09327553198090754, 0.17794777639210224, 0.18369717960013077, 0.14427858463022858, 0.2248113593668677, 0.12494168942794204, 0.12215403432492167, 0.15178947534877807, 0.2534721081610769, 0.15546163689577952, 0.18882654811022803, 0.11332648457027972, 0.0955614581471309, 0.10576063039479777, 0.1852912682807073, 0.13244244240922853, 0.24578268639743328, 0.09124827396590263, 0.18356283602770418, 0.07706356831477024, 0.30580200953409076, 0.12132697011111304, 0.1221950602484867, 0.10124846157850698, 0.12058988388162106, 0.10322155765607022, 0.10023931143223308, 0.15086361643625423, 0.16189958987524733, 0.1890084781916812, 0.07858466677134857, 0.0997801149787847, 0.15389542328193784, 0.2496879268437624, 0.08997905300930142, 0.25358381622936577, 0.19749662897083908, 0.11309237408568151, 0.1929646299686283, 0.09754327445989475, 0.17673394933808595, 0.129876897262875, 0.18019562296103686, 0.09532164054689929, 0.28049774235114455, 0.12170845628133975, 0.15356862597400323, 0.17014988232403994, 0.17962578713195398, 0.19094229239271954, 0.1057720446260646, 0.12703981512458995, 0.11534150457009673, 0.11559004240552895, 0.1619629841297865, 0.10717951285187155, 0.12821659416658804, 0.11699915077770129, 0.038786507793702185, 0.06752517467248254, 0.17394083202816546, 0.12673911172896624, 0.17450054496293887, 0.12232602704898454, 0.14057370921364054, 0.10475772171048447, 0.1193799456814304, 0.10639446903951466, 0.16975468868622556, 0.1430360513040796, 0.11947379767661914, 0.18147299269912764, 0.10779309086501598, 0.13247309310827404, 0.13398735638475046, 0.11101732176030055, 0.12743095663608983, 0.19279286731034517, 0.08200121039408259, 0.20771417679497972, 0.20006060076411813, 0.1544408276095055, 0.14009656762937084, 0.20898894901620224, 0.14468734472757205, 0.2014138179947622, 0.08936281068599783, 0.09949020241037942, 0.1671451490256004, 0.15286394191207364, 0.122178747842554, 0.13814108271617442, 0.10275557055138052, 0.13361234916374087, 0.17077297467039898, 0.1390206761425361, 0.10481066652573645, 0.09426545308087952, 0.20999834407120943, 0.08624075126135722, 0.13049120258074254, 0.14409500698093325, 0.20315704867243767, 0.1575168367708102, 0.10143209117813967, 0.11760656154365279, 0.1614558300934732, 0.12797303614206612, 0.20877826813375577, 0.15429504011990502, 0.14008822588948533, 0.16418921935837716, 0.15022452338598669, 0.10610592202283442, 0.14771000831387937, 0.2243190334411338, 0.21323054563254118, 0.19197692046873271, 0.22927579324459657, 0.2335277502425015, 0.11464653522125445, 0.17044697888195515, 0.13720257760724053, 0.16367989825084805, 0.13286703993799165, 0.10264992582960986, 0.08409017798840068, 0.1186139156925492, 0.13979455805383623, 0.17391303117619827, 0.29790938773658127, 0.17793579812860116, 0.13854512275429443, 0.14437334204558283], [0.012096527516405331, 0.015804057038621977, 0.05994005434331484, 0.044031465804437175, 0.04057184421981219, 0.04280349712644238, 0.052039795846212655, 0.03011464577866718, 0.08618831110652536, 0.039517089098808356, 0.011510082422319101, 0.05916238376812544, 0.06267822303925641, 0.025243537238566205, 0.0223880999328685, 0.06747486448148265, 0.02186828485719161, 0.011831812716991408, 0.008756430670473492, 0.027417020610300824, 0.044399066391633824, 0.06868422380648553, 0.06645876041147858, 0.06544615927850828, 0.005278097687551053, 0.03119637054624036, 0.03501311730360612, 0.040332635180675425, 0.010859782014449593, 0.05211117932049092, 0.08199863514164463, 0.019027627422474325, 0.017120012889790814, 0.0780118623515591, 0.011516523336467799, 0.020835894356423523, 0.03552702117303852, 0.03487233188934624, 0.0666623463621363, 0.05979284564091358, 0.024305293736688327, 0.033883583382703364, 0.03142696696158964, 0.0624517492542509, 0.030883590552548412, 0.05979013680189382, 0.09010880268760957, 0.039535104733658955, 0.06422068050596863, 0.03654728127003182, 0.0357166955654975, 0.026409575548314024, 0.04737280018161982, 0.04907929826003965, 0.024130857491400093, 0.024963413598015904, 0.03659765454358421, 0.05128662356582936, 0.03090282330958871, 0.024554523624829017, 0.031436518402188085, 0.04113702307222411, 0.028855024502263404, 0.052218367709429, 0.034495287472964264, 0.08008743418031372, 0.019486614219204057, 0.025415975251235068, 0.02753419459622819, 0.05616198461211752, 0.06013966238242574, 0.06732538851792924, 0.03774935641558841, 0.008419528094236739, 0.07127813383704051, 0.03489161288598552, 0.08167213469278067, 0.01554616628709482, 0.017099704018619377, 0.06173087524075527, 0.04345122135418933, 0.041966161588788964, 0.03733156809175853, 0.018085855008393992, 0.028071886154066306, 0.028807501075789332, 0.05700995883671567, 0.026992141065420583, 0.05595986440312117, 0.05580343451583758, 0.040887004652176984, 0.06661101200734265, 0.0376764775137417, 0.026879573961196, 0.02861065382603556, 0.005732357467422844, 0.04610626579960808, 0.029848897538613528, 0.04795116328750737, 0.08789905798039399, 0.008523179221811006, 0.012496851250034524, 0.06397171964636073, 0.025217179863830097, 0.059583964466582984, 0.09497755861957557, 0.02867696101020556, 0.07850838141166605, 0.034205549309263006, 0.03807490320468787, 0.03285264006990474, 0.021232748549664393, 0.012542577751446515, 0.059228067548247054, 0.0655532734526787, 0.08826486257021315, 0.05423739901743829, 0.024435507257294375, 0.027049835625803098, 0.05892946443054825, 0.0881676709104795, 0.0415823636285495, 0.021076483790238854, 0.038913396492716856, 0.06092937430366874, 0.014878269557812018, 0.08197787727112882, 0.07417023880407214, 0.015965680104272906, 0.0824903896136675, 0.057707659289008006, 0.02964368071843637, 0.034255295468028635, 0.050795125134754926, 0.009049180098372744, 0.031249586245394312, 0.04604477515385952, 0.039938443442224525, 0.05997768123052083, 0.02868293900974095, 0.05169544674572535, 0.023535191212431528, 0.01711099950625794, 0.08501456002704799, 0.07298438329598866, 0.044175542643642984, 0.060062022603233345, 0.04546949567156844, 0.04269545526767615, 0.02088058834488038, 0.03912702370143961, 0.12203316815430298, 0.02524571358662797, 0.03697382322570775, 0.005364788421502453, 0.024538465404475573, 0.02789843696518801, 0.10423711253679357, 0.025745646526047494, 0.057361673752893694, 0.049615681782597676, 0.09193150995997712, 0.017250309902010486, 0.05471403965202626, 0.044081200830987655, 0.05244869324087631, 0.022411887621274218, 0.051335924435989, 0.018066536904370878, 0.06000761204631999, 0.11293613715679385, 0.029592264727398288, 0.03308437568193767, 0.07393305582809262, 0.04909404473437462, 0.028003020415781066, 0.04712594331067521, 0.02220430335000856, 0.026870224755839445, 0.0070558744118898176, 0.03839379292912781, 0.05015695976908319, 0.022885314756422304, 0.04989936773199588, 0.004951595847160206, 0.03430809927522205, 0.013160590096958913, 0.0193068270891672, 0.02858819643734023, 0.04496681307500694, 0.050419694889569655, 0.03914712477126159, 0.06405705178622156, 0.07188336268882267, 0.030376293652807362, 0.06426525389542803, 0.03613878092437517, 0.01827281685109483, 0.046595849489676766, 0.07201846325187944, 0.05649572100082878, 0.008057089144131169, 0.03227120076189749, 0.020136893290327862, 0.0392308909795247, 0.07844782958272845, 0.06663563646725379, 0.07662561954930425, 0.0327455741353333, 0.027918807063542772, 0.01866328857431654, 0.014321797025331762, 0.025177291281579528, 0.043578217664617114, 0.03390314268472139, 0.016191691902349703, 0.06471455752034672, 0.022040142139303498, 0.02237562814116245, 0.029558649148384575, 0.054191155795706436, 0.0661517190746963, 0.045845783097320236, 0.003480663326627109, 0.06903659552335739, 0.05670522186846938, 0.0903556781122461, 0.021359833917813376, 0.002439012678223662, 0.09846164510236122, 0.04236565968312789, 0.04416704505274538, 0.04979686229489744, 0.02874690657336032, 0.08748225300223567, 0.05084881209768355, 0.026111239603778813, 0.018461476356606, 0.039619383023818955, 0.054686079238308594, 0.02792351042444352, 0.11029903413145803, 0.07431508376612328, 0.011869758727698354, 0.05918785056564957, 0.03421824374527205, 0.050980320665985346, 0.07656891946680844, 0.01808800909202546, 0.043366779791540466, 0.02192819658375811, 0.08451390720438212, 0.049834281380753964, 0.012878222387371352, 0.011142451221530791, 0.015268140141415643, 0.05994459628709592, 0.04289788346795831, 0.02395990191871533, 0.02938712583272718, 0.05070813429483678, 0.014771493988519069, 0.026636017792043276, 0.040991402565850876, 0.10370418371167034, 0.12406124995322898, 0.03266996413003653, 0.05622412463708315, 0.025625108755775727, 0.013706839545193361, 0.0038784254911661264, 0.04271820951544214, 0.06761406169971451, 0.005161312865311629, 0.06462679113610648, 0.023172011970018502, 0.019305767673358787, 0.079903455771273, 0.019753711312660016, 0.03683426606585272, 0.012707957012025872, 0.015320327038352843, 0.028158919667475857, 0.0493501376331551, 0.028165263174741995, 0.03117911190201994, 0.07370429622824304, 0.0847788984538056, 0.03879415562551003, 0.04080598067957908, 0.018242754304083064, 0.07395289343548939, 0.027961996347585227, 0.03987436641182285, 0.034904674685094506, 0.005448787014756817, 0.0218448942177929, 0.04531764112471137, 0.013436041917884722, 0.05877533149032388, 0.021273854254104663, 0.026921249263978098, 0.07451482539181598, 0.04474613175261766, 0.02239096833363874, 0.02009721993090352, 0.016842828154040035, 0.021281221925164573, 0.04088965411938261, 0.012660838983720168, 0.02876608181395568, 0.06526967656100169, 0.002030119921982987, 0.008037633742787875, 0.018170248331443872, 0.020498569683695678, 0.07377175745205022, 0.041772832119022496, 0.01437701652321266, 0.020472204887482803, 0.01243616212377674, 0.020232444803696126, 0.030472325706796255, 0.0064647537874407135, 0.041490608200547285, 0.032262461973004974, 0.09375348992762156, 0.07723319358774461, 0.07228582195239142, 0.08136783930240199, 0.02118634947692044, 0.05016074843297247, 0.048744589657871984, 0.09469179465668276, 0.03735854887054302, 0.035917799032176845, 0.02865385053155478, 0.044483919846243225, 0.025769951862457674, 0.038611628115177155, 0.014670754862891044, 0.03547560147126205, 0.03371663726284169, 0.068617059441749, 0.018207947578048334, 0.054963026486802846, 0.04210155158943962, 0.02805455329507822, 0.06475611779023893, 0.009453841685171938, 0.04454147339856718, 0.046380070052691735, 0.13187909295083955, 0.1561068303999491, 0.13605560321593657, 0.16142039996339008, 0.1193488719582092, 0.12282416399102658, 0.10954430705169216, 0.14908216515323147, 0.16404346155468374, 0.06916782949701883, 0.11062205390771851, 0.19632271461887285, 0.21358492114813998, 0.12278934984351508, 0.15987835067790002, 0.18020723015069962, 0.21399301331257448, 0.10948903189273551, 0.10176516705541871, 0.13991107523906976, 0.15356089279521257, 0.11736495536752045, 0.11800054548075423, 0.18168913578847423, 0.1367596341879107, 0.07245516520924866, 0.1314120297320187, 0.10439421777846292, 0.0920662097632885, 0.19711850472958758, 0.18973192374687642, 0.12358511768979952, 0.1255070129991509, 0.11594645882723853, 0.07643972639925778, 0.13032004848355427, 0.08625771675724536, 0.14010731392772868, 0.14054653176572174, 0.15966560662491247, 0.2501233003567904, 0.1351216548937373, 0.1537380731315352, 0.15013638592790812, 0.18558996787760407, 0.11592248003580607, 0.1745852388557978, 0.10716746037360281, 0.1453298665001057, 0.1578149278066121, 0.22709389391820878, 0.13322039128979668, 0.13711218402022496, 0.17071915412088856, 0.10906448631430976, 0.19709748710738495, 0.1465990874567069, 0.15682478406233713, 0.13647824147483334, 0.1710928403190337, 0.10311367906979285, 0.10825934514286928, 0.14396861923160031, 0.07399077265290543, 0.11928515858016908, 0.20914769440423697, 0.12661716202273965, 0.07242591716931202, 0.11033678718376905, 0.22359447466442361, 0.1744542646338232, 0.243177599622868, 0.11607816035393625, 0.07847954155295156, 0.13988186430651695, 0.14258282171795145, 0.17621407489059493, 0.06414250266971067, 0.057664406922413036, 0.09945046782377176, 0.16084867907920852, 0.07222805317724124, 0.14238356990972534, 0.14695816818857566, 0.14590166159905493, 0.10882382266572677, 0.08947093418100849, 0.16531525034224615, 0.1945263906964101, 0.22221256600460038, 0.09111928869970143, 0.12865912198321894, 0.12002980729448609, 0.14007890451466665, 0.11497448285808787, 0.0411486005759798, 0.08142740407492965, 0.09929695457685739, 0.1417787343962118, 0.09281071004807018, 0.11059672440751456, 0.16302887146594003, 0.17460828996263444, 0.08920657375711016, 0.18046937155304477, 0.13599817582871765, 0.12055299172061495, 0.23961909057106823, 0.11950610336498357, 0.1252131225191988, 0.1382321145501919, 0.18017236405285075, 0.10618335771141574, 0.14817401388427243, 0.1611478833365254, 0.2025691044400446, 0.14554652909282595, 0.1296446644118987, 0.1907599318656139, 0.21711565903387964, 0.171032132639084, 0.10510473512113094, 0.07279031910002232, 0.18078616471029818, 0.12368563417112455, 0.104325190623058, 0.1270043701515533, 0.15114805195480585, 0.10846174365724437, 0.14222222700482234, 0.13141919887857512, 0.14449264970608056, 0.12682325643254444, 0.11459631408797577, 0.09325300779892132, 0.17158360773464665, 0.1121324283303693, 0.13308057066751644, 0.14593888772651553, 0.14639976143371314, 0.1849624078022316, 0.09356218652101234, 0.07878592979977839, 0.1343647384783253, 0.12875294429250062, 0.14688491821289062, 0.1454400160582736, 0.19600700499722734, 0.17090433480916545, 0.16842655604705215, 0.20312737760832533, 0.22430940036429092, 0.16617237153695896, 0.12154474592534825, 0.07435002407873981, 0.11256030615186319, 0.11586790991714224, 0.17805342853534967, 0.1258736487943679, 0.13187683682190254, 0.1718707149848342, 0.1283713022712618, 0.09984892691136338, 0.21387676330050454, 0.10135878183064051, 0.13428859412670135, 0.1597268189652823, 0.19490922015393153, 0.1352504620444961, 0.16273458022624254, 0.1893718633800745, 0.11950004743994214, 0.1294349186355248, 0.13669344945810735, 0.14995651901699603, 0.17099257616791874], [0.08277034256025217, 0.021639393526129425, 0.05750277829065453, 0.04222272204060573, 0.01851061766501516, 0.05848385670105927, 0.0502270036668051, 0.049507580552017316, 0.03313039997010492, 0.061418731638696045, 0.04094204974535387, 0.03057982579775853, 0.005605055948763038, 0.0639826811675448, 0.03971831873059273, 0.029708338479395024, 0.04194224959064741, 0.03143947586067952, 0.0163931812858209, 0.09962215626728721, 0.05838925513671711, 0.023616356193087995, 0.03635616711108014, 0.06226905476069078, 0.07456882405676879, 0.06964800646528602, 0.05425347022537608, 0.059335285623092204, 0.05325900718162302, 0.06837738284957595, 0.039865319631644525, 0.026126915618078783, 0.03719231521245092, 0.01585486261319602, 0.06191081636643503, 0.0217773031181423, 0.034227962169097736, 0.031089113508642185, 0.029464743347489275, 0.04176159229245968, 0.03886096004862338, 0.009071244148799451, 0.05010323198803235, 0.008981649298220873, 0.03778286809392739, 0.04758290589961689, 0.027154812414664775, 0.043502110420376994, 0.01609137765626656, 0.04623978187737521, 0.04990986912162043, 0.03815514050074853, 0.05356935478630476, 0.09092549909837544, 0.052165879314998165, 0.09658372946432792, 0.03801637743890751, 0.04144961196288932, 0.05516711338714231, 0.002592066025499662, 0.01322329693721258, 0.04700708836026024, 0.05718097563658375, 0.017860084408312105, 0.04605046000506263, 0.05245036678388715, 0.05555966497922782, 0.03317335918836761, 0.01678361775702797, 0.008098500984488055, 0.028255482357053552, 0.03995657782070339, 0.030918410266167484, 0.02634639837197028, 0.0350226167938672, 0.051053040006081574, 0.08064031193498522, 0.027062123735959176, 0.048328137199860066, 0.09924680765834637, 0.0355501984449802, 0.028061572156730108, 0.0616534061555285, 0.013436420413199812, 0.06499726383481175, 0.07040309719741344, 0.03850717454042751, 0.06136166790383868, 0.047355519272969104, 0.03381601083674468, 0.07393429521471262, 0.05346818892576266, 0.025379487560712732, 0.06904826208483428, 0.02767268491879804, 0.044998287557973526, 0.03976312218583189, 0.03458980740106199, 0.0710308353882283, 0.016460846600239165, 0.02649404308613157, 0.020983531649108045, 0.04772942811541725, 0.049347825843142346, 0.04066837536811363, 0.03671941871289164, 0.033288247359450907, 0.03501309874991421, 0.027537192872841842, 0.06930127507075667, 0.021249710334814154, 0.03498535355902277, 0.03412862199184019, 0.025636456193751656, 0.03517031902447343, 0.024808260204736143, 0.0038718356836398016, 0.016222953017859254, 0.02956091640953673, 0.037582781369565055, 0.005875312272110023, 0.04378578894829843, 0.016164343760465272, 0.06425436658901162, 0.06923596607521176, 0.0431374858453637, 0.031190559529932216, 0.042287092219339684, 0.030153452680679038, 0.12936385057400912, 0.01859550080553163, 0.014026596654730383, 0.027798477094620466, 0.07425778254400939, 0.052087775693507865, 0.04020364249299746, 0.02675186889973702, 0.015688148414483294, 0.03145575858070515, 0.021940562619420234, 0.0679381204827223, 0.10305930190952495, 0.03434551465034019, 0.04710505927505437, 0.02876042479329044, 0.059966266999254, 0.03645364078693092, 0.007802281088515883, 0.06441806210204959, 0.02487733003363246, 0.03388484132301528, 0.05427223914011847, 0.027054843267251272, 0.08179990283679217, 0.01982254736503819, 0.06800664297770709, 0.03512755276460666, 0.09992101913667284, 0.005956151635473361, 0.0572710426786216, 0.020740879044751637, 0.07389405596768484, 0.035898840869776905, 0.02226502216217341, 0.045390275117824785, 0.05476183025166392, 0.05885473387024831, 0.03829202592896763, 0.0012318345716266776, 0.03255330964748282, 0.06569964723894373, 0.00913195461180294, 0.038935865013627335, 0.008545554046577308, 0.05924401630181819, 0.10871316102566198, 0.01673643200774677, 0.010033540656877449, 0.060040645039407536, 0.01032148560625501, 0.019044155051233247, 0.06156148374429904, 0.05557248558034189, 0.0760064457426779, 0.09878624565317295, 0.03724006499396637, 0.01405634471666417, 0.039552916277898476, 0.0289530918962555, 0.05223430533078499, 0.01607608199265087, 0.014893760962877423, 0.011838257341878489, 0.05817049968754873, 0.03254573974118102, 0.024627103812235873, 0.048600902446196415, 0.024094100772344973, 0.008794991736067459, 0.057250923055107705, 0.031783234953763895, 0.020199161335767712, 0.0350810238160193, 0.09061199365532957, 0.01045731347403489, 0.08884314403985627, 0.06463133307988755, 0.021925660294073168, 0.03498195452266373, 0.03349584461830091, 0.0623698384151794, 0.025124175772361923, 0.02754860895947786, 0.08034054364543408, 0.04440406475623604, 0.021620056868414395, 0.007889838743722066, 0.07225459237815812, 0.0232792634415091, 0.013432673495117342, 0.015644335726392455, 0.060917492519365624, 0.0809747533639893, 0.035792620983556844, 0.03393655046238564, 0.07341508127865382, 0.02763879660051316, 0.08219624680350535, 0.020595835558196995, 0.021791737890453078, 0.011124906850454863, 0.02741261039773235, 0.048675414072931744, 0.004097725259271101, 0.05275770497974008, 0.025020640605362132, 0.024559295634389855, 0.02492510207957821, 0.040894248013501056, 0.028561449435073882, 0.025339862440887373, 0.06386194116203114, 0.024327396749868058, 0.04067474670591764, 0.0178878388760495, 0.01987556453968864, 0.06581546680536121, 0.06060289611923508, 0.03150840653688647, 0.020376306420075707, 0.052324439166113734, 0.060444866903708316, 0.060116737440694124, 0.032078149597509764, 0.020989891854696907, 0.037187706475378945, 0.06351986303343438, 0.050056339387083426, 0.03237640761653893, 0.04358369100373238, 0.0709091083263047, 0.04042053144075908, 0.09622921294067055, 0.0777441325772088, 0.0067664048128790455, 0.023515325774496887, 0.033214926879736595, 0.022297633986454457, 0.027116393284813967, 0.05330053776560817, 0.014315298594738124, 0.016567374477745034, 0.01980163920961786, 0.04614177014445886, 0.04765551020682324, 0.09306075444328599, 0.02302146916917991, 0.028607881904463284, 0.037716267761425115, 0.019446651422185823, 0.045381094751064666, 0.00260141499893507, 0.017174477252410725, 0.01991731591260759, 0.01991037126572337, 0.046883739705663174, 0.01379712459311122, 0.029650591968675144, 0.1554017307353206, 0.024864114238880575, 0.08329606513143517, 0.049226996779907495, 0.03578224204829894, 0.04382081089715939, 0.052263779725763015, 0.02997933184815338, 0.0459377055085497, 0.05586261337157339, 0.043325282604200765, 0.056962535600177944, 0.03579168587748427, 0.04521256414591335, 0.03580271419195924, 0.021592538032564335, 0.06374407326802611, 0.0877711562498007, 0.018565106147434562, 0.04202256110147573, 0.11269082766375504, 0.02031884934694972, 0.016356669475499075, 0.011529582352522993, 0.04009607931948267, 0.04920089544611983, 0.02108055261487607, 0.015014461077953456, 0.03364078977028839, 0.006781496385883656, 0.02665220217750175, 0.051577437843661755, 0.016854190434969496, 0.04405127001518849, 0.022612504981225356, 0.03361677758221049, 0.0934455134847667, 0.022686764277750626, 0.03242928192776162, 0.09936682035913691, 0.012333108425082173, 0.0034512888896642835, 0.04580164015351329, 0.030571328206860926, 0.062488960538757965, 0.07887829007813707, 0.05219474885961972, 0.030158293338899966, 0.07219456005259417, 0.046603972295997664, 0.03328568323922809, 0.020633531094063073, 0.054233109403867275, 0.02223231756943278, 0.00872813536261674, 0.02346764835237991, 0.029724500600423198, 0.07105753786163405, 0.04166994447587058, 0.010668337599781808, 0.03713642407092266, 0.02140226621122565, 0.029476103773049545, 0.05061898751591798, 0.12941829452756792, 0.1390292850555852, 0.1196305021585431, 0.112597176048439, 0.11611293739406392, 0.1521680597215891, 0.17947677872143686, 0.16136715828906745, 0.16029665479436517, 0.10893918210058473, 0.14543314377078786, 0.2071085397619754, 0.12594946660101414, 0.15108027902897447, 0.14071915531530976, 0.1201707411382813, 0.14855322166113183, 0.18132523109670728, 0.10698089929064736, 0.17618216254049912, 0.24794857017695904, 0.10213398476480506, 0.12978485610801727, 0.1462228482705541, 0.13994110253406689, 0.14547339786076918, 0.14042835216969252, 0.24852805392583832, 0.16052609717007726, 0.15839433734072372, 0.19888251554220915, 0.09405255317687988, 0.09366733400383964, 0.14163115090923384, 0.22082673880504444, 0.1483661707607098, 0.2475698819034733, 0.1786884546163492, 0.11230203133891337, 0.11728346013114788, 0.14551537373336032, 0.1878312835469842, 0.19340977014508098, 0.12017752436804585, 0.10127765766810626, 0.11997588284430094, 0.192549413186498, 0.16578378301346675, 0.1022132312937174, 0.3089513280428946, 0.13129135651979595, 0.1953638152917847, 0.11399063252611086, 0.13185313262511045, 0.1329171349061653, 0.22942587034776807, 0.1285526980063878, 0.1267830765573308, 0.1733703282661736, 0.08612303921836428, 0.13985220808535814, 0.1701898395549506, 0.16659848304698244, 0.12943859968800098, 0.1240367665013764, 0.18714604375418276, 0.18706577306147665, 0.11957864830037579, 0.09253971482394263, 0.1212679322634358, 0.17819737549871206, 0.1371267152717337, 0.09531909498036839, 0.08077057369519025, 0.11062420613598078, 0.1607259872253053, 0.1389938103966415, 0.06795300796511583, 0.15636022930266336, 0.1252291677519679, 0.12934106664033607, 0.15349936875281855, 0.13261479878565297, 0.21388749475590885, 0.14474977419013157, 0.12302095186896622, 0.11439664667705074, 0.24604234902653843, 0.15438810543855652, 0.16244141705101356, 0.12477538897655904, 0.13327982247574255, 0.10455688912770711, 0.1604145672172308, 0.09929279854986817, 0.18257108924444765, 0.122233503498137, 0.10069720170577057, 0.13176754815503955, 0.23011226789094508, 0.136513463803567, 0.16343390598194674, 0.15793049504281953, 0.15189907571766526, 0.14956844999687746, 0.12646905903238803, 0.15321889630286023, 0.10558514957665466, 0.11043610138585791, 0.1732580561656505, 0.04260554778738879, 0.07882667370722629, 0.13284192566061392, 0.08228321908973157, 0.17508348711999133, 0.16688800969859585, 0.09361686796182767, 0.1374362947535701, 0.16383726324420422, 0.12329077449976467, 0.16173029114725068, 0.15913117124000564, 0.13789342803647742, 0.15473335253773257, 0.14181152248056605, 0.1201310362375807, 0.111218755482696, 0.12970782117918134, 0.11655925758532248, 0.14693536941194907, 0.13583825784735382, 0.08136953139910474, 0.17083528538933024, 0.12429284455720335, 0.16364335489924997, 0.10257636415190063, 0.11924802893190645, 0.191242431756109, 0.09276988450437784, 0.06613275720155798, 0.17944244696991518, 0.12048143384163268, 0.1364450081018731, 0.14577804948203266, 0.08343528461409733, 0.1381278724875301, 0.10789258318254724, 0.15527109790127724, 0.15728680067695677, 0.11174823332112283, 0.11415639863116667, 0.1515344882500358, 0.0905130579485558, 0.15070071502123028, 0.18255044269608334, 0.13261560030514374, 0.11833055628812872, 0.13323214690899476, 0.17444112861994654, 0.1445637919823639, 0.30390552536118776, 0.26114193722605705, 0.1259396257228218, 0.07872940041124821, 0.09191926452331245, 0.10838621528819203, 0.15297272591851652, 0.108098551427247, 0.16152453812537715, 0.09711394202895463, 0.2512304065749049, 0.14529614330967888, 0.16475541866384447, 0.08737587355426513, 0.14180687663611025, 0.1361115908366628], [0.09104325567022897, 0.056519261925132014, 0.05542025624890812, 0.034991799111594446, 0.043123548311996274, 0.06072208132536616, 0.019468422324280255, 0.023648077440157067, 0.00433842787060712, 0.04199194379907567, 0.023124173130781855, 0.020227591157890856, 0.049738677917048335, 0.06373393553076312, 0.013279469167173374, 0.06189742431160994, 0.014346768439281732, 0.05303999198076781, 0.06057216378394514, 0.05131805351993535, 0.02554665075876983, 0.017270045464101713, 0.031164910906227306, 0.05050730913353618, 0.017180616669065785, 0.022272579080890864, 0.021300734842952807, 0.04697025928180665, 0.042875236831605434, 0.04155341244768351, 0.012789111788151786, 0.04645469300157856, 0.05821890626975801, 0.03717049978149589, 0.06435638963012025, 0.023477635804738384, 0.03961684487876482, 0.019749764942389447, 0.049543348359293304, 0.03379212852451019, 0.0861201819498092, 0.008974528391263448, 0.01759729548211908, 0.02530789999582339, 0.039733714584144764, 0.025759543241292704, 0.027963241300312802, 0.017793122278817464, 0.0433326447091531, 0.036995660921093076, 0.037823014572495595, 0.06544815565575846, 0.0343599865300348, 0.041080130031332374, 0.02522883158235345, 0.07586476232972927, 0.020229370456945617, 0.05954154701612424, 0.06688099048915319, 0.038195862143766135, 0.03757337835850194, 0.0371553599688923, 0.026707981996878516, 0.047287538545788266, 0.025018495798576623, 0.04928531474433839, 0.03279609954915941, 0.05843205108249094, 0.06713054506690241, 0.008459010350634344, 0.04188630649878178, 0.015890470858721528, 0.004102631319256034, 0.009660633713792777, 0.07260062615387142, 0.0866279519686941, 0.03512543764372822, 0.022612109787587542, 0.024607102932350244, 0.03344138211105019, 0.0505190573312575, 0.07624713907716796, 0.008529487477062503, 0.023475030866393354, 0.12069699063431472, 0.07662710384465754, 0.011227672966924729, 0.03664665484393481, 0.06883096124511212, 0.02585710597486468, 0.06169143751321826, 0.04681020029238425, 0.020309329447627533, 0.0634211944998242, 0.021388898276200052, 0.017416107548342552, 0.018662102993403096, 0.011113842356280657, 0.03846524690743536, 0.14725214772624895, 0.0020116661880820175, 0.04543698589259293, 0.01736571572109824, 0.06317012594081461, 0.013962522407382494, 0.08295856605400331, 0.07399097303277813, 0.02038506747339852, 0.030005271764821373, 0.009191817171085859, 0.040519311296520755, 0.026282896506018005, 0.05308973071805667, 0.06593439597054385, 0.0461887258279603, 0.0674868501664605, 0.032200963905779645, 0.0844069488812238, 0.03270501947554294, 0.044721125086653046, 0.03189421942806803, 0.03454533791227732, 0.00596299284552515, 0.05119985537021421, 0.018019278795691207, 0.03668728742923122, 0.018019905910477974, 0.04497999732848257, 0.06209507308085449, 0.07604888174682856, 0.0319659999513533, 0.08161721576470882, 0.08598781991167925, 0.007791053321852814, 0.02037144349742448, 0.019620800085249357, 0.07677842033444904, 0.0472026776697021, 0.01948013341461774, 0.0885716664197389, 0.049709014274412766, 0.03142011322779581, 0.05343826182070188, 0.029932674879091792, 0.035353251005290076, 0.04058384474774357, 0.04445070131623652, 0.008524580953235272, 0.02151697812223574, 0.03299139942100737, 0.0391138357372256, 0.04410116089275107, 0.018113767182512674, 0.05293472575431224, 0.015532777015323518, 0.022876010079926345, 0.015071314228407573, 0.023605411370226648, 0.013532465454773046, 0.04293411140679382, 0.09151710954029113, 0.022187681097420864, 0.08200984899303876, 0.01091657301003579, 0.0398426173342159, 0.08018916036235169, 0.05187971830309834, 0.028734969127981458, 0.03078973855735967, 0.08813952867058106, 0.03394577535800636, 0.028070177359040827, 0.06272964645177126, 0.014103847734077135, 0.05489739836775698, 0.038799280155217275, 0.08707755245268345, 0.07053475419525057, 0.047590854301233776, 0.0242932375476812, 0.04123062273720279, 0.06949603688553907, 0.10152858521905728, 0.019699805416166782, 0.042673769712564535, 0.028693607382592745, 0.02647906654601684, 0.044493927707662806, 0.025849042540357914, 0.03605235040595289, 0.04261649817635771, 0.013195187166274991, 0.03935681488655973, 0.027971974523097742, 0.015985259815352038, 0.008253625619545346, 0.01791416470950935, 0.004747969078380265, 0.005605650130746653, 0.03108025968685979, 0.009336616676591802, 0.04405334431794472, 0.10256692403345369, 0.008874379273038357, 0.06403911407687701, 0.048642525798641145, 0.031071914236235898, 0.024883844234864227, 0.029062998401059303, 0.04655927274143323, 0.05135177299962379, 0.09894777409499511, 0.055792135317460634, 0.04890080432232935, 0.03667849669000134, 0.02898731047025649, 0.033738530619302765, 0.07476728918845765, 0.009311839148722356, 0.034514130602474324, 0.02872530822060071, 0.0416753398894798, 0.03760881591006182, 0.02689593831746606, 0.03991781915829051, 0.052591526982723735, 0.05704019022232387, 0.053434914734680206, 0.005877647254237672, 0.11959317213040777, 0.02755770768999355, 0.036719277704833075, 0.030716716792085208, 0.038670049980282784, 0.056605113568366505, 0.0056405315353913466, 0.02411182696960168, 0.006318105406535324, 0.03291042739874683, 0.03186972113326192, 0.013789580661978107, 0.02657157525391085, 0.024213968754338566, 0.04451737586350646, 0.05575156581471674, 0.022420939967560116, 0.03060309769352898, 0.06325857510091737, 0.04722575846244581, 0.03670597470772918, 0.02466803511197213, 0.07234990640426986, 0.03829274581221398, 0.0562434575840598, 0.023829154051782098, 0.016096318504423834, 0.012918422671646113, 0.056512608571210876, 0.057396584379603155, 0.02275883794936817, 0.173159588011913, 0.0413641647901386, 0.01426629736670293, 0.06761412849300541, 0.05956434579275083, 0.02722018263739301, 0.041456996332271956, 0.005997633052174933, 0.040289612879860215, 0.043431847589090466, 0.024749782678554766, 0.016086553696368355, 0.05014468093577307, 0.014820950709690806, 0.051246592120151035, 0.030325629086291883, 0.019607541617006063, 0.03187323149177246, 0.03493844240438193, 0.035420062849880196, 0.06123008512076922, 0.0046993597970867995, 0.03597629511205014, 0.02829765304340981, 0.028823546308558434, 0.024251083559647668, 0.07153857572120614, 0.02503943363990402, 0.006899018717376748, 0.021386254375102, 0.018673034828680102, 0.04577462968882173, 0.01762794803653378, 0.06916598154930398, 0.014811396486038575, 0.024297350901179016, 0.008588282271375647, 0.05078584457805846, 0.016354995932488237, 0.058080321323359385, 0.056506741893826984, 0.04218888752802741, 0.04098166187759489, 0.050743438259814866, 0.06754922767868266, 0.014995534456829773, 0.019224968200433068, 0.025637315229687374, 0.055646637265454046, 0.01087807688236353, 0.02984144080983242, 0.021865869166504126, 0.010323681435693288, 0.05039918192778714, 0.03717799547303002, 0.06724518461851403, 0.04488300975935999, 0.010102114174515009, 0.04955791671818588, 0.023389101297652815, 0.051254384670755826, 0.012628935910470318, 0.03996224782895297, 0.03698485154018272, 0.021177931666898075, 0.03756865829927847, 0.06569455610588193, 0.006735231363563798, 0.021877671169932, 0.030289766655187123, 0.015069855908222962, 0.02591122523881495, 0.021400006371550262, 0.059651169649441727, 0.028258146667212714, 0.06057418242562562, 0.026885028746619355, 0.047210373741108924, 0.08422594648436643, 0.04177407892711926, 0.10700235477997921, 0.0503026507794857, 0.022945176388020627, 0.017348909786960576, 0.008004263072507456, 0.036713229201268405, 0.03885395417455584, 0.04136748219025321, 0.08612323959823698, 0.023386932371067815, 0.008815732908260543, 0.0064803820259839995, 0.20289450651034713, 0.19607289286796004, 0.19205431162845343, 0.13089482701616362, 0.12524062651209533, 0.1641737826867029, 0.14001552510308102, 0.1005546425585635, 0.09178060907288454, 0.08372345313546248, 0.12406678637489676, 0.09194532874971628, 0.06999774355790578, 0.1886754616862163, 0.15335322503233328, 0.15144440636504441, 0.16873598709935322, 0.19690550834638998, 0.13782319118035957, 0.10696974481106736, 0.06524477750645019, 0.12219399897730909, 0.062112394807627425, 0.10424551364849322, 0.08454147799056955, 0.10526132085942663, 0.2425942270201631, 0.12821686133975163, 0.14687072834931314, 0.14040178328286856, 0.13343404076294973, 0.1792724060942419, 0.13806759525323287, 0.0925680277578067, 0.17524395429063588, 0.11986678713583387, 0.1703329849988222, 0.06702547922031954, 0.1472959789680317, 0.15985239035217091, 0.12589569058036432, 0.19148159626638517, 0.08876907028025016, 0.08921933869714849, 0.15750371559988707, 0.11822724191006273, 0.12914015242131427, 0.10735244810348377, 0.1494084281148389, 0.1458359370008111, 0.10450015193782747, 0.13220262480899692, 0.12830510269850492, 0.2568375103874132, 0.0941000654711388, 0.27722662256564945, 0.12977844395209104, 0.08494321737089194, 0.15403712895931676, 0.09495664489804767, 0.13638145057484508, 0.10121968851308338, 0.18388120253803208, 0.13945762300863862, 0.12157083241618238, 0.10596490654279478, 0.19868897827109322, 0.1549616816919297, 0.15016504767118022, 0.09070956381037831, 0.08835985747282393, 0.14788769331062213, 0.071512711874675, 0.10350890981499106, 0.1928481276263483, 0.21154141752049327, 0.09810839765123092, 0.11815378413302824, 0.0748757689143531, 0.0811664575303439, 0.1446989964460954, 0.15449484111741185, 0.11391325620934367, 0.08049368581851013, 0.34234265971463174, 0.14891463273670524, 0.12195794406579807, 0.2490792766911909, 0.1170122274197638, 0.10986825451254845, 0.17333843075903133, 0.07711640922934748, 0.22598816809477285, 0.11822772430605255, 0.07454038495779969, 0.09163845810689963, 0.12642107176361606, 0.11370281281415373, 0.08888071897672489, 0.1727333280723542, 0.1675000588875264, 0.17423910117940977, 0.0859958202636335, 0.20615851652109995, 0.2699144196230918, 0.0967999170825351, 0.14330797421280295, 0.2046528918435797, 0.13476849650032818, 0.10972447082167491, 0.08001312293345109, 0.11120107752503827, 0.1489808619953692, 0.16578615788603202, 0.1398806768702343, 0.20875000715022907, 0.12042768008541316, 0.16091544268419966, 0.09848301153397188, 0.12224522943142802, 0.12213467911351472, 0.11072033652453683, 0.09954969296813942, 0.17037911689840257, 0.10705978216719814, 0.10472118578036316, 0.19588176015531644, 0.15644248895114288, 0.16181041341042146, 0.15494431543629616, 0.11311031179502606, 0.12461780133889988, 0.20509013556875288, 0.0945823649817612, 0.08524169432348572, 0.09597834476153366, 0.13140083814505488, 0.15547529241302982, 0.09473705082200468, 0.23187379993032664, 0.11244193359743804, 0.08261878858320415, 0.14329963247291744, 0.10922077519353479, 0.09757940963027067, 0.11671807718812488, 0.09046519684488885, 0.1279104730929248, 0.09438372173462994, 0.15025348198832944, 0.17810665536671877, 0.11319167344481684, 0.13608782726805657, 0.13894343341235071, 0.1512561977142468, 0.08913778408896178, 0.1376059793983586, 0.08597232386819087, 0.06744545316905715, 0.1312884918297641, 0.16412962489994243, 0.1499900344060734, 0.2534932445269078, 0.0801440748909954, 0.23343970184214413, 0.14575845678336918, 0.09957117814337835, 0.12550425220979378, 0.11898315642611124, 0.10542381409322843, 0.11494920530822128, 0.11563928390387446, 0.13031074195168912, 0.1007094322994817, 0.11420151378843002, 0.07364303935901262], [0.06544248564750887, 0.058437858388060704, 0.06980436213780195, 0.021245272291707806, 0.05559679462749045, 0.046047650976106524, 0.021761860880360473, 0.05668863115715794, 0.02316288726433413, 0.14144104236038402, 0.08390205097384751, 0.015452004445251077, 0.02793089850456454, 0.0135589898127364, 0.014786842530156719, 0.07731623249128461, 0.0340167877584463, 0.016417781625932548, 0.04288183823518921, 0.040835558975231834, 0.0600265776301967, 0.016417959741374943, 0.020167020775261335, 0.053081837977515534, 0.007201254184110439, 0.09487937248195522, 0.030104919933364727, 0.050362282345304266, 0.05146969655470457, 0.03162200708175078, 0.0384084021061426, 0.03961937560234219, 0.007275465241036727, 0.030801195462117903, 0.01855051737948088, 0.02671304901014082, 0.026220454055874143, 0.10047466872492805, 0.02849784737918526, 0.030718592570337933, 0.017438032446079887, 0.01592463562701596, 0.03650268190540373, 0.01403010979629471, 0.007510005243602791, 0.07554369440185837, 0.048072170466184616, 0.05130820150952786, 0.017661005149420816, 0.06406958666048013, 0.0035591428922998603, 0.042607896684785374, 0.011416056022426346, 0.03125378309050575, 0.06368631933582947, 0.12635499093448743, 0.05747609066020232, 0.009674668654042762, 0.03384372263099067, 0.032220964785665274, 0.022126967851363588, 0.05402548245911021, 0.016944708331720904, 0.012074508922523819, 0.009454967894271249, 0.0176423512675683, 0.02648659748956561, 0.026193857338512316, 0.06277264648815617, 0.06452065659686923, 0.02247843785880832, 0.08104067092062905, 0.024882278303266503, 0.014444945300056133, 0.020076313630852383, 0.04319644947827328, 0.016117213672259822, 0.022824187763035297, 0.06079618848161772, 0.06116113960160874, 0.03184736764524132, 0.004912182703264989, 0.05955781489319634, 0.05629059509374201, 0.09233999546268024, 0.02803684379614424, 0.05478601684444584, 0.04545097166555934, 0.0728828129649628, 0.0378530678426614, 0.0937158556189388, 0.05908097016799729, 0.03934653985197656, 0.00805781923190807, 0.0470210852654418, 0.04157830779149663, 0.02909851202275604, 0.013735478096350562, 0.00678839418469579, 0.02625427187012974, 0.009164823404717026, 0.021445785750984214, 0.059935653407592326, 0.06913253295351751, 0.015721025556558743, 0.022307096369331703, 0.02895217163313646, 0.0027423404935689177, 0.02778210717224283, 0.017625281871005427, 0.04346641682786867, 0.06793944150558673, 0.018843120233213995, 0.034699463431024924, 0.07755810584058054, 0.058066216806764714, 0.04141671997786034, 0.04386606335174292, 0.09531930278171785, 0.024565457315475214, 0.07840913400286809, 0.12939797452418134, 0.029448310342559125, 0.03964120216551237, 0.013463733303069603, 0.0894197185698431, 0.03495615746942349, 0.01959534070920199, 0.03865735183353536, 0.04643671818485018, 0.04890620715741534, 0.05597990610112902, 0.0324746345722815, 0.008482258126605302, 0.014304411288321717, 0.02625486558827106, 0.010900899778789608, 0.031185557454591617, 0.036332429517642595, 0.02579396405053558, 0.026543004423729144, 0.03991088378825225, 0.07695715175941586, 0.09156395390164107, 0.10251613144646399, 0.015195431005849969, 0.04698783333878964, 0.0631746233557351, 0.05096989349112846, 0.026866794178204145, 0.02795573262119433, 0.03503940417431295, 0.03609566956583876, 0.03864062011416536, 0.06266575495828874, 0.051726082601817325, 0.054352261213352904, 0.039587055071024224, 0.047163633280433714, 0.041589243337512016, 0.06509265949716792, 0.051588373389677145, 0.04316471524361987, 0.04830635887628887, 0.05654017564665992, 0.047039535056683235, 0.03599798437790014, 0.020475852543313522, 0.06199549541634042, 0.04018706291390117, 0.05459220126795117, 0.004540721556622884, 0.04838441796891857, 0.039047443206072785, 0.05903598117583897, 0.024490938267263118, 0.010925776568910806, 0.027598924716585316, 0.05532835981284734, 0.009067975915968418, 0.12552047555800527, 0.10222385142697021, 0.022141228218970355, 0.035842003489960916, 0.06877475840155967, 0.06509878963697702, 0.05892041765036993, 0.0507972328341566, 0.017583712324267253, 0.016090594690467697, 0.06786989484680817, 0.06952638330403715, 0.05317050978192128, 0.024866502099030185, 0.05166974617168307, 0.013788611231575487, 0.11205611328477971, 0.006310729386314051, 0.010372739252488827, 0.04368443012936041, 0.04442953155376017, 0.037593705783365294, 0.03129658645775635, 0.02799021651298972, 0.040187675185734406, 0.014131298848951701, 0.023806243953004014, 0.024845985426509287, 0.03336194633448031, 0.051485218573361635, 0.06990191002842039, 0.016744699532864615, 0.040333611104870215, 0.017548653268022463, 0.036468943872023374, 0.016947407893894706, 0.055209478887263685, 0.02253140864922898, 0.04530691709078383, 0.03120824861980509, 0.06517270012409426, 0.026088312806678005, 0.0583190553879831, 0.009876822259684559, 0.017009974653774407, 0.03969858131313231, 0.04547664997517131, 0.004279056984159979, 0.043514712087926455, 0.027381792715459596, 0.05484828674525488, 0.04698100558016449, 0.04222798015689477, 0.07458907726686448, 0.014083870973990997, 0.011027488835679833, 0.03415676794247702, 0.018857478935387917, 0.02641795810632175, 0.020514080570137594, 0.009646617327234708, 0.04009688454971183, 0.021827620730618946, 0.016008216298359912, 0.07295910574612208, 0.020280344870116096, 0.015281117521226406, 0.07015106384642422, 0.02278642357850913, 0.03002944908075733, 0.011701542607625015, 0.008199148269341094, 0.005170261774765095, 0.0393493637238862, 0.06235565597307868, 0.07403709751088172, 0.07623450030223466, 0.02571784567408031, 0.027223353463341482, 0.03264748076617252, 0.08370338546228595, 0.026257216341036838, 0.06813539817812853, 0.06588158474187367, 0.02075515982141951, 0.04962185645126738, 0.05196288708248176, 0.014346584757731762, 0.060820582875749096, 0.04321074695326388, 0.031892070910544135, 0.08261190887424164, 0.11470133540569805, 0.02794417738186894, 0.06390643291524611, 0.041457178158452734, 0.026650881154637318, 0.03563177160685882, 0.062484381487593055, 0.03956210035539698, 0.03598805073124822, 0.03792117473494727, 0.010803424247569637, 0.045122270748834126, 0.05744457164837513, 0.041324348567286506, 0.03048328908334952, 0.03461495507508516, 0.05877437783055939, 0.028423476760508493, 0.025348347044200636, 0.03664678843051661, 0.03226918954169378, 0.0715254842361901, 0.10154235205845907, 0.004615245243257959, 0.040262450274894945, 0.03366540309798438, 0.024271956463053357, 0.022825388186902273, 0.04789813683601096, 0.009596179115760606, 0.023756956070428714, 0.06950287948711775, 0.02379716192081105, 0.05849603534443304, 0.1001193729462102, 0.03513726747769397, 0.07000028170295991, 0.03582391364034265, 0.024764137669990305, 0.018322453543078154, 0.044489567590062506, 0.10353031335398555, 0.014778158474655356, 0.055988062304095365, 0.011543857563083293, 0.02228335135441739, 0.03868161264108494, 0.011494552982185269, 0.02430561842629686, 0.015619343903381377, 0.048329959172406234, 0.0301772310922388, 0.07305018210900016, 0.03917492191249039, 0.06084311447921209, 0.08918217194150202, 0.020061773102497682, 0.01836392289987998, 0.049302873958367854, 0.0501664741022978, 0.040521849441574886, 0.04564983013551682, 0.015217931068036705, 0.06263029514229856, 0.028879207384306937, 0.032009215210564435, 0.0773475733876694, 0.007450132479789318, 0.028505793925432954, 0.05956866509222891, 0.018349781275901478, 0.03366229349921923, 0.03163440836942755, 0.07688548255828209, 0.02301690125023015, 0.0454021791665582, 0.053743380995001644, 0.056660333066247404, 0.08691209062817506, 0.028143082236056216, 0.17154013272374868, 0.1173173614370171, 0.13665876147570089, 0.09551872528390959, 0.1645510905655101, 0.18239202385302633, 0.13010718568693846, 0.19359003781573847, 0.1576365006621927, 0.24442952853860334, 0.23922030493849888, 0.13254168239654973, 0.04415379400597885, 0.08903614696464501, 0.11719749716576189, 0.1519337043282576, 0.10592713122605346, 0.11450559395598248, 0.15271370153641328, 0.1172455883352086, 0.18168854207033291, 0.11905958279385231, 0.07985803633346222, 0.2025895135011524, 0.0972365819325205, 0.2539652504492551, 0.14237022609449923, 0.139743973268196, 0.10208903288003057, 0.15214365790598094, 0.0961232119880151, 0.13258483086246997, 0.13192654587328434, 0.08551660066586919, 0.1457662196480669, 0.09067086823051795, 0.1972552973893471, 0.1910821278579533, 0.1914113000384532, 0.1057462178869173, 0.1817958863102831, 0.11653231762466021, 0.14766512322239578, 0.07532284609624185, 0.15032870607683435, 0.12143415850005113, 0.15843445784412324, 0.08803029195405543, 0.08618143881903961, 0.1320702108205296, 0.07294473034562543, 0.1193500445515383, 0.14373298734426498, 0.15858734026551247, 0.15967163286404684, 0.13825874280883, 0.1584188430570066, 0.1417506069992669, 0.08800160794635303, 0.11045143415685743, 0.13038304197834805, 0.06369051247020252, 0.20323993172496557, 0.17603497981326655, 0.13228295487351716, 0.10591245896648616, 0.11295315460301936, 0.09375444729812443, 0.14288134319940582, 0.2771632728399709, 0.20145107380812988, 0.15052957576699555, 0.07455532439053059, 0.10179266362683848, 0.11070026142988354, 0.21276092942571267, 0.1394916430581361, 0.18151054537156597, 0.13366587285418063, 0.15260154817951843, 0.20770938252098858, 0.08788084567640908, 0.0663337975856848, 0.12900389410788193, 0.2523671096423641, 0.11317392869386822, 0.11684832410537638, 0.157060653436929, 0.10919719716184773, 0.21540986228501424, 0.1451345777604729, 0.11116063789813779, 0.1536690237117, 0.1835654187016189, 0.09162576738162898, 0.11770211305702105, 0.18048467463813722, 0.10082436871016398, 0.10237647409667261, 0.09463233378482983, 0.13932243338786066, 0.1486819249112159, 0.1674435517634265, 0.15722364390967414, 0.10533687149290927, 0.12671188975218683, 0.11955874389968812, 0.08543895717593841, 0.19025111541850492, 0.07994416999281384, 0.1545836019795388, 0.11887904795003124, 0.22048021521186456, 0.10984548542182893, 0.1909118940238841, 0.13189120480092242, 0.20169369672657922, 0.1231693739828188, 0.1629093411611393, 0.16150070034200326, 0.12401604573824443, 0.14784889383008704, 0.10091597941936925, 0.10518079783651046, 0.10642840745276771, 0.13711221370613202, 0.27308339020237327, 0.10037539905169979, 0.09223870714777149, 0.14592060120776296, 0.1966876137885265, 0.101404750457732, 0.14616199216106907, 0.11616977848461829, 0.16068368480773643, 0.19215554057154804, 0.09090282648685388, 0.12401021987898275, 0.17620125057874247, 0.10659683044650592, 0.12661235290579498, 0.15117629809537902, 0.20626125944545493, 0.1460474045597948, 0.18965671450132504, 0.08072000375250354, 0.17107217892771587, 0.22618296701693907, 0.15153359767282382, 0.12775690789567307, 0.1659600282437168, 0.14665053313365206, 0.11344700935296714, 0.1385906312498264, 0.14051375852432102, 0.12788819381967187, 0.11358525662217289, 0.11797878571087494, 0.13470517646055669, 0.1477192554739304, 0.11657027847832069, 0.10313354636309668, 0.14073702623136342, 0.13671108288690448, 0.08413370494963601, 0.13297812460223213, 0.07137223816243932, 0.11393149077775888, 0.15809397533303127, 0.1760016128537245, 0.14377629908267409, 0.07486121539841406, 0.16108382114907727, 0.12245066332980059, 0.24101026123389602, 0.10609704593662173], [0.003645051356215845, 0.08351015989319421, 0.013457343411573675, 0.030210842960514128, 0.021297556595527567, 0.041274279574281536, 0.0447161564079579, 0.059141714955330826, 0.019236580956203397, 0.09522545078652911, 0.03606370526540559, 0.08046696108067408, 0.05105796044517774, 0.037642962124664336, 0.02503116240404779, 0.022948647783778142, 0.02691238245461136, 0.05112126193125732, 0.007924346755316947, 0.025877628213493153, 0.04502293057157658, 0.04906265559839085, 0.03899653929693159, 0.056201533661806025, 0.04843665774387773, 0.044240313582122326, 0.02178571721742628, 0.016581965101067908, 0.043259802914690226, 0.038799361791461706, 0.03626014062319882, 0.01644676991418237, 0.04433178328326903, 0.03353002422954887, 0.019638355588540435, 0.053644103900296614, 0.011920151482627261, 0.043538123136386275, 0.033416672304156236, 0.05837160315422807, 0.0019430266888775805, 0.03822694699920248, 0.01918519650644157, 0.016125113834277727, 0.043475764177856036, 0.044429123372538015, 0.00807302398243337, 0.022113722370704636, 0.006539498726851889, 0.025655805839051027, 0.03151591336063575, 0.012663031102420064, 0.05706417272449471, 0.010562232746451627, 0.040597233091830276, 0.0179457579361042, 0.05140443579875864, 0.035018123089685105, 0.0043086023470095824, 0.026668091559258755, 0.010314077117072884, 0.025320687200292014, 0.06547773024067283, 0.03170140575093683, 0.04764689758303575, 0.019363497485755943, 0.030600943609897513, 0.023877658968558535, 0.06976624543312937, 0.04888393530563917, 0.013078015963401413, 0.03908956379746087, 0.04850227101997007, 0.036668473985628225, 0.07474443104001693, 0.015990688625606708, 0.030852090094413143, 0.09340608317870647, 0.028747821270371787, 0.060397803608793765, 0.02396105781372171, 0.015677945739298593, 0.003499531271700107, 0.03711761804879643, 0.052126608570688404, 0.02652991850482067, 0.085754028550582, 0.03896290516422596, 0.020881510463368613, 0.057722999481484294, 0.0431629823287949, 0.023520908580394462, 0.03081979553826386, 0.023084618514985777, 0.05954395528533496, 0.027749682740250137, 0.028983978227188345, 0.01884513516415609, 0.020353984473331366, 0.1046635654347483, 0.03540095996868331, 0.04290100790967699, 0.02824238530592993, 0.017690394197416026, 0.022916139860171825, 0.062450539553537965, 0.0581906452862313, 0.05012424961023498, 0.015300166596716736, 0.047375442227348685, 0.03657100402051583, 0.0750740039802622, 0.07696334869251586, 0.02979361124744173, 0.048352843296015635, 0.00982625046162866, 0.050065519753843546, 0.013190051504352596, 0.031613361061317846, 0.02696564082725672, 0.01968173968634801, 0.037704975984524935, 0.01665401279751677, 0.06178328570968006, 0.1134818531863857, 0.03841886267764494, 0.019993760834040586, 0.01518614209999214, 0.02605920391943073, 0.03684309762320481, 0.06617203165660612, 0.06117459102824796, 0.038426202518166974, 0.07118644891306758, 0.013681032287422568, 0.15428855374921113, 0.03198040503775701, 0.04031584408949129, 0.02185575183830224, 0.041022075529326685, 0.030674299341626465, 0.05759086008765735, 0.03135070757707581, 0.026260873273713514, 0.0262143109284807, 0.003696254443639191, 0.08319168948219158, 0.05700776579033118, 0.03999069806013722, 0.05132351572683547, 0.01735453712171875, 0.09248088477761485, 0.018387738418823574, 0.04822062597668264, 0.031797053743503056, 0.025349399038532283, 0.016275573143502697, 0.02933409938123077, 0.06090070142818149, 0.012990219893254107, 0.01995753475057427, 0.03726889372046571, 0.040912115218816325, 0.05527371176867746, 0.048720788981881924, 0.03797621240664739, 0.05159919019206427, 0.053339422593126073, 0.026491447424632497, 0.024353557455469854, 0.02454084769851761, 0.03585629354347475, 0.06351083851768635, 0.03173627927026246, 0.05093076375487726, 0.025526996832923032, 0.06490715968539007, 0.10670094634406269, 0.04566892188449856, 0.05245720938546583, 0.05800278173410334, 0.019793727915384807, 0.0921318972541485, 0.058207759211654775, 0.03173766708641779, 0.08996911565191112, 0.025216866306436714, 0.03459694686171133, 0.015257915201800643, 0.012790771415893687, 0.03383246425073594, 0.016964135902526323, 0.016169692789844703, 0.08359241954167373, 0.05295201779517811, 0.026661276788217947, 0.020894705849059392, 0.03791710776567925, 0.017247213290829677, 0.02018050003243843, 0.0070277706709021, 0.032711324020056054, 0.0305710684551741, 0.035225237952545285, 0.013452732819132507, 0.02944162544736173, 0.03420879991608672, 0.025404499792784918, 0.008253955875261454, 0.02882575790863484, 0.039555487819598056, 0.04739456737297587, 0.03169424402585719, 0.029895151892560534, 0.056689918783376925, 0.01378089104036917, 0.025730588349688333, 0.02707158240809804, 0.04640840154024772, 0.06476794020272791, 0.029280187918629963, 0.05302937926899176, 0.032138397145899944, 0.046578371911891736, 0.029031759549980052, 0.0584521558630513, 0.060497722661239095, 0.08920481486711651, 0.07523623746237718, 0.06050570445950143, 0.020323272547102533, 0.029182614052842837, 0.025700156584207434, 0.08861943846568465, 0.0101640853608842, 0.040120091507560574, 0.016606608114670962, 0.036956264011678286, 0.07700257119722664, 0.013187181248213165, 0.024278782366309315, 0.04843632377742324, 0.016339165922545362, 0.027292397317069117, 0.11144963762490079, 0.014151243140076986, 0.04681985192291904, 0.039815491836634465, 0.059535676628001966, 0.05194992547330912, 0.03754339188162703, 0.03200536717486102, 0.04100344391190447, 0.06285436436883174, 0.03088789315370377, 0.04152508467086591, 0.01794204905309016, 0.03332458662043791, 0.05451112905575428, 0.06750081738573499, 0.09451007979805581, 0.02053350443020463, 0.04763323835504707, 0.057840065855998546, 0.04785444289154839, 0.036309879360487685, 0.03300235723145306, 0.04251964419381693, 0.05127947297296487, 0.036158102739136666, 0.07558109864476137, 0.020250117195246276, 0.037976743042236194, 0.04100893951545004, 0.05092278566735331, 0.058177806131425314, 0.03758899314561859, 0.05718674583476968, 0.03526370717736427, 0.03401466892682947, 0.019599932747951243, 0.06644169843639247, 0.05986963566101622, 0.01204339994728798, 0.05761703934695106, 0.015134351324377349, 0.015962641009537037, 0.04495431901887059, 0.03465915367996786, 0.03251353795349132, 0.021694145470974036, 0.0272679231420625, 0.01844716589403106, 0.0433710211655125, 0.025855252461042255, 0.0356480877235299, 0.03462822096480522, 0.013153292929928284, 0.050880665075965226, 0.09301909027271904, 0.10768615480628796, 0.014957091207179474, 0.0027457154101284686, 0.016385540875489824, 0.03296527953352779, 0.035261810990050435, 0.043007049680454656, 0.03525774031004403, 0.007879748318373458, 0.06585183946299367, 0.013786958097625757, 0.03857834279187955, 0.06906929454999045, 0.009329592248832341, 0.024750161173869856, 0.02033830103755463, 0.05720399334677495, 0.05160215878277086, 0.02605821686302079, 0.031048211894812994, 0.036695740491268225, 0.045037164964014664, 0.019499612935760524, 0.05692791812180076, 0.0673824522527866, 0.05480716805323027, 0.02220554459199775, 0.04396573007397819, 0.028853920557594392, 0.033031026396201923, 0.017585426685400307, 0.05084612923383247, 0.02278039733937476, 0.017102615092881024, 0.04592260651406832, 0.064172173733823, 0.04282439229427837, 0.11414592692744918, 0.07271907292306423, 0.07166830313508399, 0.06472419059718959, 0.015453299492946826, 0.03165814596286509, 0.04057092395669315, 0.018295810441486537, 0.050212030837428756, 0.057748911567614414, 0.03723747860931326, 0.07588073334773071, 0.07122403127141297, 0.049877040219143964, 0.021174764551687986, 0.1374304317869246, 0.25033487181644887, 0.09723750219563954, 0.1198263252445031, 0.11984986616880633, 0.13611591013614088, 0.12486455059843138, 0.1259858615230769, 0.18063832889311016, 0.26600662618875504, 0.1378188273520209, 0.2459420106606558, 0.1292911943164654, 0.11504420763230883, 0.11335199218592606, 0.07703726660110988, 0.09859204787062481, 0.15532787219854072, 0.19791718921624124, 0.11543747910764068, 0.09636348229832947, 0.13016692857490852, 0.11373068788088858, 0.13538974832044914, 0.1784750129445456, 0.1268270265427418, 0.17500326095614582, 0.10745245992438868, 0.15415602101711556, 0.13936659117462113, 0.1964314392535016, 0.08045075257541612, 0.11768144424422644, 0.10591792117338628, 0.08649334122310393, 0.1783623400842771, 0.12580326350871474, 0.1355024508666247, 0.12464198051020503, 0.115863182436442, 0.12475169962272048, 0.15553386270767078, 0.12259934519533999, 0.10610800003632903, 0.16863578232005239, 0.14938752923626453, 0.12105737012461759, 0.13454102823743597, 0.08476099785184488, 0.16123821755172685, 0.20218832331011072, 0.1243023959978018, 0.1728047226788476, 0.1169579170527868, 0.1466988172614947, 0.09196369690471329, 0.09269658999983221, 0.11587933156988584, 0.08255229957285337, 0.1017581760243047, 0.08580242400057614, 0.1318314322270453, 0.1361151086166501, 0.11132791798445396, 0.1609433622797951, 0.112059059611056, 0.21126058883965015, 0.0943419907707721, 0.17498889297712594, 0.10789336985908449, 0.1643527887063101, 0.17417855677194893, 0.18385801784461364, 0.11852410098072141, 0.14531695313053206, 0.12244258876307867, 0.12600269343238324, 0.15518980304477736, 0.0740827618574258, 0.19431247405009344, 0.13592878502095118, 0.22105285635916516, 0.24076472909655422, 0.12541896459879354, 0.18865683377953246, 0.09413389998371713, 0.2429598238086328, 0.12251796870259568, 0.15277510683517903, 0.13479056797223166, 0.15340652607847005, 0.11698830057866871, 0.16537045128643513, 0.2238092670449987, 0.15799598215380684, 0.0820751060382463, 0.17578475730260834, 0.09805670706555247, 0.14701089035952464, 0.2005023419042118, 0.15356240677647293, 0.12380096392007545, 0.13322420592885464, 0.08156917654559948, 0.0990388949867338, 0.16114415775518864, 0.0895334972301498, 0.12277037312742323, 0.17362408339977264, 0.0961058383109048, 0.10199662807281129, 0.12126696004997939, 0.16385669267037883, 0.1451508901664056, 0.14520269207423553, 0.07622711593285203, 0.07762426088447683, 0.1017931682872586, 0.1003725863120053, 0.1522022727294825, 0.12947919516591355, 0.18250662629725412, 0.12033443665131927, 0.1921204073005356, 0.1801221354980953, 0.09243530948879197, 0.061016691688564606, 0.092294145579217, 0.08205458565498702, 0.1369287696434185, 0.10677195503376424, 0.20725046808365732, 0.12170452289865352, 0.16322086506988853, 0.13725758559303358, 0.29365640657488257, 0.13395908055827022, 0.10169337168917991, 0.12473103823140264, 0.14313460851553828, 0.09791221091290936, 0.12296705710468814, 0.1505588460713625, 0.0936008375720121, 0.09459818757022731, 0.09856480362941511, 0.1520440320018679, 0.10901033179834485, 0.18195215292507783, 0.0865762984903995, 0.10387911534053273, 0.1605666332761757, 0.0879023085872177, 0.14393145247595385, 0.13284838234540075, 0.19855562917655334, 0.15727269987110049, 0.09670257699326612, 0.1998714273213409, 0.09460085188038647, 0.09373776381835341, 0.20059006375959143, 0.19501839007716626, 0.19000559812411666, 0.12091959040844813, 0.12532034801552072, 0.0977581855840981, 0.13182708324166015, 0.06517704910947941, 0.15550759067991748, 0.11785385257098824, 0.1302631851285696, 0.14489538356428966, 0.11480689849122427, 0.16048759454861283, 0.2646476647350937], [0.052757226294488646, 0.03947596298530698, 0.07450614226399921, 0.03419197913899552, 0.01069225052560796, 0.07705979820457287, 0.020266069659555797, 0.01809493147447938, 0.04503011085034814, 0.014944212161935866, 0.06749447202309966, 0.04188175342278555, 0.015976890244928654, 0.05887583683943376, 0.006151884272185271, 0.03522498933307361, 0.043189109637751244, 0.0020604387418643455, 0.021896247126278467, 0.034745851371553726, 0.06482035809312947, 0.02346078534174012, 0.057198512586182915, 0.012380754305922892, 0.06274460814893246, 0.028837363242928404, 0.0076969981637375895, 0.047790358439669944, 0.009671821590018226, 0.011715635992004536, 0.013261979529488599, 0.05425788229331374, 0.010859585345315281, 0.06420992678613402, 0.045062320059514605, 0.030307876913866494, 0.04137463649385609, 0.057096229793387465, 0.03429088887060061, 0.011743228114937665, 0.009183467082038987, 0.056749442737782374, 0.013700495110242628, 0.082898259133799, 0.05500251616467722, 0.08417298682616092, 0.04798180656507611, 0.13062556099612266, 0.012155073691246798, 0.035214543604524806, 0.07688190540648066, 0.027514080538821872, 0.03789926282479428, 0.042402403414598666, 0.017169727507280186, 0.024647581522003748, 0.050373355188639835, 0.006113103345342097, 0.026636258990038186, 0.03194128272298258, 0.02704374259337783, 0.05387174285715446, 0.056811757167452015, 0.05868656691745855, 0.08791861357167363, 0.06199401483172551, 0.04130451095988974, 0.00884635763213737, 0.01894692628411576, 0.04638285310647916, 0.01854666006693151, 0.07066680453135632, 0.07083860429702327, 0.0469126389361918, 0.0418898650968913, 0.025807986930885818, 0.07050318323308602, 0.014770913257962093, 0.042499624760239385, 0.048500122502446175, 0.06071123112633359, 0.06680836391751654, 0.04664192943891976, 0.07708013305091299, 0.032088387524709105, 0.018867128710553516, 0.08541225470253266, 0.060128949480713345, 0.009701103954284918, 0.06701138583594002, 0.030962764722062275, 0.050017413741443306, 0.014398477578652091, 0.04000204549811315, 0.017941811565833632, 0.018427192844683304, 0.020905084784317296, 0.017230138328159228, 0.03922961448552087, 0.04334274533903226, 0.06970630216528662, 0.026325169237679802, 0.01623857893719105, 0.02979113061883254, 0.09098460373934358, 0.1219173485878855, 0.04425020269991364, 0.02563700167229399, 0.027763197249441873, 0.04131411435082555, 0.06802389791118912, 0.10438048804644495, 0.028743529801431578, 0.06748701343894936, 0.03988152813690249, 0.0856639540870674, 0.01448088843972073, 0.04427576968737412, 0.02809498178976355, 0.06738255615346134, 0.10321198395104147, 0.04804749405593611, 0.04339663639257196, 0.01609841507161036, 0.05249961199297104, 0.045008132146904245, 0.02555673840106465, 0.06653026634012349, 0.04959235237038229, 0.03805483182077296, 0.04352111311163753, 0.022304313315544277, 0.043865421394002624, 0.05235140139120631, 0.035839213014696725, 0.039112867234507576, 0.06517959467601031, 0.07911853070254438, 0.1065827370621264, 0.025622481553000398, 0.009644538386055501, 0.02189618033298757, 0.01138520123276976, 0.027332315585226752, 0.02276853410876356, 0.027738413227780256, 0.06770294130546972, 0.04536098625976592, 0.022280967205006164, 0.03636181114416104, 0.030156421271385625, 0.11783720619860105, 0.05888217106985394, 0.025639667837822344, 0.04821894872293342, 0.023737778974464163, 0.01124260497817886, 0.06078347178117838, 0.0970602773304563, 0.0214004405279411, 0.06765879836166278, 0.03455875223153271, 0.036758559581357986, 0.04775467226863839, 0.04580731758323964, 0.02380511403316632, 0.007255411946971435, 0.08890474971849471, 0.022145484435895924, 0.047470826757489704, 0.12165872496552765, 0.04274492683180142, 0.02917460813478101, 0.039316252805292606, 0.062481123459292576, 0.045011768670519814, 0.009712482005852507, 0.041107478173216805, 0.014647195384895895, 0.023720737408439163, 0.03920817012840416, 0.031401207015733235, 0.015369209522759775, 0.052240197983337566, 0.05901208030991256, 0.017116734452429228, 0.06653543910942972, 0.029116086079739034, 0.029240521980682388, 0.12373276054859161, 0.011403569387766765, 0.014891675527906045, 0.02522938077163417, 0.03549142034898978, 0.055296807404374704, 0.037050698592793196, 0.035598337854025885, 0.027157992517459206, 0.04688982902735006, 0.038815232619526796, 0.06949986636755057, 0.031984208544599824, 0.007093764297678717, 0.031013416300993413, 0.006735045826644637, 0.054104662194731645, 0.037298319875844754, 0.01784859225153923, 0.03604919998906553, 0.05448413714475464, 0.05633483822748531, 0.06122060789493844, 0.04306016147893388, 0.030247779650380835, 0.07171585253672674, 0.03621167837991379, 0.06463891040766612, 0.018623954747454263, 0.07090616942150518, 0.015240725206240313, 0.03478301441646181, 0.044363999913912266, 0.05351671796233859, 0.03589534906495828, 0.044794764689868316, 0.0013914061787545506, 0.018718367064138874, 0.07964011208969168, 0.026466850795259234, 0.04759714771353174, 0.03007857740158215, 0.04598720675858203, 0.04885246082267258, 0.04595523132593371, 0.024909366693464108, 0.04879752334090881, 0.1050517383555416, 0.014739034304511733, 0.016277627037197817, 0.02232000417279778, 0.04008587478892878, 0.06472715918789618, 0.03461834668996744, 0.01906064742797753, 0.02855894654203439, 0.013434912925731624, 0.028065839505870827, 0.009204375237459317, 0.08357703482033685, 0.03521444712532684, 0.05785584020486567, 0.011096487232862273, 0.016271611930278596, 0.02750489646132337, 0.009905763236019993, 0.08996064774692059, 0.007221736068458995, 0.04519097135926131, 0.06918515864526853, 0.05736480190535076, 0.05192638454900589, 0.05546166437852662, 0.07465949965990148, 0.03940888025681488, 0.0018983201766786806, 0.022055228146200534, 0.007845187428756617, 0.05469110357807949, 0.024660932758706622, 0.03948561832658015, 0.027562796967686154, 0.03001126831804868, 0.038151485423441045, 0.14611857652198523, 0.046880964073352516, 0.03042796568479389, 0.029594934603665024, 0.033628893143031746, 0.023926542380650062, 0.08821524999802932, 0.0409738247981295, 0.06468755818787031, 0.064536553400103, 0.016738792037358508, 0.026777660386869684, 0.05256957796518691, 0.012699356448138133, 0.08190615611965768, 0.010158579552808078, 0.0478906485659536, 0.045326880863285623, 0.03566817023965996, 0.06433461501728743, 0.02422089299216168, 0.0957772227411624, 0.045684662836720236, 0.0520127408526605, 0.02736726888542762, 0.008792363605607534, 0.12546246929559857, 0.0394467223668471, 0.026487462091608904, 0.05595192713371944, 0.029112418014847208, 0.020867457897111308, 0.054590360741713084, 0.009038603566295933, 0.05353888220270164, 0.03319725634355564, 0.05027850129408762, 0.037148999763303436, 0.04913116696116049, 0.03575669732526876, 0.026463314461580012, 0.027074003664893098, 0.02475241359206848, 0.011668619081319775, 0.02541331650718348, 0.034409198342473246, 0.03346425510244444, 0.02022377280809451, 0.022802802777732722, 0.039456908343709074, 0.06898124614963308, 0.044623039138969034, 0.018863275108742528, 0.030795302809565328, 0.01821998150262516, 0.0726371917698998, 0.05122941511217505, 0.0245055047707865, 0.06464443940785713, 0.030522142369591165, 0.0449386263062479, 0.05971829690679442, 0.0461415178142488, 0.027638870815280825, 0.013307311764947372, 0.0007492223153349187, 0.049893055766006, 0.012141393126512412, 0.04263196824467741, 0.02536219180910848, 0.07368092599790543, 0.05111753263918217, 0.07620099975611083, 0.07912656816188246, 0.019058174220845103, 0.015366861553047784, 0.0333726592361927, 0.001891107312985696, 0.019918597972719, 0.22746275615645573, 0.08256658591562882, 0.1526035222923383, 0.12986854068003595, 0.058742714099935256, 0.13458129717037082, 0.06909738483955152, 0.10721583355916664, 0.2568731037899852, 0.09014217706862837, 0.19502195238601416, 0.15314598771510646, 0.09575049800332636, 0.16587315243668854, 0.09705461474368349, 0.11054835122195072, 0.224472583795432, 0.12157405333709903, 0.09904452046612278, 0.14079334039706737, 0.21036150661529973, 0.14008200669195503, 0.21017991792177781, 0.11799078623880632, 0.1093181523901876, 0.17147703532828018, 0.08963980246335268, 0.12044718372635543, 0.09848295958363451, 0.1388750073965639, 0.08753953938139603, 0.1420760981272906, 0.11363184865331277, 0.1412120452732779, 0.12918511172756553, 0.15108194143977016, 0.1522815489443019, 0.15268253133399412, 0.174097232229542, 0.13994009321322665, 0.1252880645915866, 0.1584229842410423, 0.15685966500313953, 0.14872217900119722, 0.0806670737802051, 0.19984586775535718, 0.11267309775575995, 0.17246541276108474, 0.10059192063636146, 0.12223479483509436, 0.1617094367975369, 0.1497184083564207, 0.14988766255555674, 0.10657533042831346, 0.14751308684935793, 0.20737832528539002, 0.18839899683371186, 0.15912118193227798, 0.14815121510764584, 0.10849629805306904, 0.16183549800189212, 0.15632368595106527, 0.09615259361453354, 0.14193891955073923, 0.16474983771331608, 0.18160359584726393, 0.1607555989176035, 0.13073121313937008, 0.12479159748181701, 0.11776166298659518, 0.15772946208016947, 0.09038145290105604, 0.24227008660091087, 0.06718749005813152, 0.09482793422648683, 0.05860530545760412, 0.13254475488793105, 0.10394694763817824, 0.08829209938994609, 0.1991838720277883, 0.15961950441123918, 0.16612107428954914, 0.12736765143927187, 0.12337762804236263, 0.16076207044534385, 0.12483709113439545, 0.14595393848139793, 0.11010741160134785, 0.14620377507526428, 0.16491175949340686, 0.09050049338839017, 0.1839513354934752, 0.1388568099355325, 0.1977226574672386, 0.17132260923972353, 0.1372264005476609, 0.12600965477759019, 0.1927283895201981, 0.12083063658792526, 0.11824112007161602, 0.11314416115055792, 0.10548850710620172, 0.20561444805935025, 0.2428139917901717, 0.10838233385584317, 0.29407301859464496, 0.17730664985720068, 0.12535361107438803, 0.08767570863710716, 0.14240627962863073, 0.15295322227757424, 0.22296363429632038, 0.08811842941213399, 0.18461831845343113, 0.11978791168075986, 0.13470841222442687, 0.11305532607366331, 0.167373685981147, 0.19063937739701942, 0.15813323494512588, 0.14740894868737087, 0.08853834398905747, 0.31775854295119643, 0.21860707900486887, 0.09948145991074853, 0.17554750753333792, 0.13269288756418973, 0.13713621476199478, 0.0826679336023517, 0.11279466154519469, 0.1919646156602539, 0.143197127035819, 0.11736640255548991, 0.10793798035592772, 0.08181915414752439, 0.18105425813701004, 0.13780465233139694, 0.17374972900142893, 0.260648854309693, 0.11362427132553421, 0.12757049524225295, 0.17097639734856784, 0.1124382451234851, 0.10869564634049311, 0.0845046600443311, 0.10812509062816389, 0.17036663397448137, 0.2042710271780379, 0.12768429616698995, 0.1000638231926132, 0.13333849667105824, 0.20377313514472917, 0.16785336571047083, 0.10854398104129359, 0.14407842740183696, 0.15079231088748202, 0.13960073876660317, 0.21455409179907292, 0.18120264314347878, 0.174515699618496, 0.154422125488054, 0.10091574193211272, 0.06819641756010242, 0.23748569801682606, 0.15004608139861375, 0.1152088308299426, 0.10928449599305168, 0.18494055897463113, 0.12222944395034574, 0.12218898205901496, 0.17308915819739923, 0.1261544181033969, 0.09370545070851222, 0.10640939362929203, 0.14673096709884703, 0.14032262581167743], [0.09150668978691101, 0.036378999284352176, 0.020649344405683223, 0.057794724343693815, 0.019261906745668966, 0.07778727362165228, 0.014608739147661254, 0.0321159657323733, 0.07367748985416256, 0.0658864012802951, 0.13261800486361608, 0.07612550849444233, 0.03663357078039553, 0.021707099658669904, 0.055312392505584285, 0.09135786691331305, 0.04306541959522292, 0.05076346882560756, 0.03084870033490006, 0.022764969944546465, 0.051538363768486306, 0.02362169780099066, 0.06431987596442923, 0.07907996870926581, 0.0504521527182078, 0.11106156860478222, 0.10203455181908794, 0.02096500393236056, 0.009217619790433673, 0.02917765836173203, 0.048240827236440964, 0.03275788636528887, 0.03278236239566468, 0.009342855355498614, 0.04993972943339031, 0.01601469710294623, 0.08461481702397577, 0.04935203010973055, 0.0581658575538313, 0.021793144260300323, 0.041713879618328065, 0.0879483885364607, 0.010603787450236268, 0.08027345349546522, 0.09200096756103449, 0.014591301460313844, 0.05584521743003279, 0.023560837980767246, 0.045318431511987, 0.049959986354224384, 0.007854852046875749, 0.04218806745484471, 0.014154215441521956, 0.0816067292180378, 0.025018109881784767, 0.027749627079174388, 0.03193382784957066, 0.022094294799899217, 0.04888868876150809, 0.02996216411702335, 0.015060513196658576, 0.027304856121190824, 0.05156237595656421, 0.03701662288221996, 0.11286282780929469, 0.07272465387359262, 0.08943914057454094, 0.026124336654902436, 0.014318097419163678, 0.06473094414104708, 0.0688242373871617, 0.04749611172883306, 0.0428760197974043, 0.007725453961029416, 0.028952041757293046, 0.02758328952040756, 0.06322543078567833, 0.02953498020360712, 0.04221427640004549, 0.010852841078303754, 0.11375972811947577, 0.023133917529776227, 0.03203425156243611, 0.060686131691909395, 0.012141363440605346, 0.02418999923975207, 0.06810367878642865, 0.04581913257425185, 0.04365776476333849, 0.04302751811337657, 0.10140379308722913, 0.030328848151839338, 0.004206403509670054, 0.08376198544283397, 0.005861536155862268, 0.04293540274375118, 0.03154536178044509, 0.024600401338830125, 0.0491480730852345, 0.061133179187891074, 0.029715847158513498, 0.02149873056623619, 0.017403051315341145, 0.021407849017123226, 0.05270281202683691, 0.038946756030782126, 0.020740994077641517, 0.06031639743014239, 0.029116227087797597, 0.013388774532359093, 0.034092327259713784, 0.07995052277692594, 0.08449588785879314, 0.028242953048902564, 0.09109247490414418, 0.02510925303795375, 0.010889611712627811, 0.024064802637440152, 0.05991176738461945, 0.06873806662042625, 0.0767080053628888, 0.0313453975104494, 0.03501241226331331, 0.04747916478663683, 0.05320916083292104, 0.036083476079511456, 0.046441338054137304, 0.04031460099213291, 0.05405381765740458, 0.03623589094786439, 0.009354700032417895, 0.023259835870703682, 0.03198106183845084, 0.03826179825409781, 0.0281123443346587, 0.028505851441877894, 0.036238789034541696, 0.030137448266032152, 0.05921886862779502, 0.04438534779183101, 0.028817636957683135, 0.0815573318686802, 0.04032451979583129, 0.014273611232056282, 0.019137303861498367, 0.00360366131644696, 0.036446393714868464, 0.04300752094422933, 0.05789345967059489, 0.0626908618141897, 0.025259673384425696, 0.051078885298920795, 0.025132242917607073, 0.058756425278261304, 0.02275355942401802, 0.018807432206813246, 0.04154187947278842, 0.061854810192016885, 0.01404198137606727, 0.026467561401659623, 0.031523494399152696, 0.04904278459434863, 0.04019596868602093, 0.09200070780934766, 0.05905433077714406, 0.031134289893088862, 0.03152585442876443, 0.013707105790672358, 0.10070074175018817, 0.0627280211483594, 0.04762717129779048, 0.015528111689491197, 0.011821892985608429, 0.09075811511138454, 0.03894205452525057, 0.03288592168246396, 0.06419157347409055, 0.05059012539277319, 0.020714642269012984, 0.03952943843614776, 0.0941173946193885, 0.04437750700162724, 0.008304048988065915, 0.010802547585626598, 0.08953403157647699, 0.05335742338502314, 0.030287499394034967, 0.018841021810658276, 0.026456293744558934, 0.03604892539442517, 0.1125795574625954, 0.057078718818956986, 0.07796152247465216, 0.05151145720446948, 0.059040875639766455, 0.022553975504706614, 0.014148910941003123, 0.05127177690155804, 0.04269667981134262, 0.06765864251065068, 0.02789656304230448, 0.03857907380734105, 0.05307961153448559, 0.07453650352545083, 0.07213628661702387, 0.0334069427481154, 0.040254646592075005, 0.045020618781563826, 0.03200440238288138, 0.05075938330264762, 0.059848963137483224, 0.03498272635624744, 0.04303071676986292, 0.056531748559791595, 0.02027663042099448, 0.022131932819320355, 0.07278806297108531, 0.024064281278697308, 0.06568416603840888, 0.03500567727314774, 0.01803807925170986, 0.05002006691938732, 0.02750248819211265, 0.013691673757421086, 0.06291530953603797, 0.029619588749483228, 0.040014643454924226, 0.01966054580407217, 0.032065481136669405, 0.05220733197347727, 0.036902350693708286, 0.053353482580860145, 0.033401773689547554, 0.09008581095258705, 0.0421713171817828, 0.013469657496898435, 0.06511010738904588, 0.08911868862924166, 0.05499065293406602, 0.04789635197084863, 0.102184769930318, 0.021819989597133826, 0.041674208114272915, 0.03008322510140715, 0.05012677291233558, 0.07998511428013444, 0.05656445129716303, 0.040179800998885185, 0.05466959242767189, 0.018450778297847137, 0.05843239989189897, 0.011802608278230764, 0.014022281065990683, 0.04207717574900016, 0.016293681546812877, 0.06507501864689402, 0.041065097830141895, 0.028215792299306486, 0.016616706889180932, 0.07624872727319598, 0.0032373267868024413, 0.058010010252473876, 0.0454022236954188, 0.0608062631363282, 0.025403681574971415, 0.028310238012636546, 0.03553621267201379, 0.06822091585490853, 0.035619934351416305, 0.06966117216506973, 0.013694796343770577, 0.0741529838705901, 0.03090623162279371, 0.06734975322615355, 0.05208679234783631, 0.07946014869958162, 0.03343067663081456, 0.01048712740157498, 0.015784731513122097, 0.047316571362898685, 0.030679384908580687, 0.013042469872743823, 0.023699810699326918, 0.020015943628095556, 0.00789535104559036, 0.08716616488527507, 0.02566067618317902, 0.04791679442860186, 0.031352503574453294, 0.024601197292213328, 0.1562606479274109, 0.0260900624198257, 0.026592281174089294, 0.020427278977876995, 0.01477679199524573, 0.03978640706918668, 0.029056059320282657, 0.05982813847367652, 0.042774423491209745, 0.029670019539480563, 0.055779181129764766, 0.026469247932254802, 0.04232446677633561, 0.03551270885509439, 0.12151144575909711, 0.05370847036829218, 0.0029073809173496556, 0.03775804696488194, 0.013439179347187746, 0.020895993475278374, 0.029859326568839606, 0.010553585798334097, 0.015081261790328426, 0.023296067520277575, 0.0860085035674274, 0.0393046122189844, 0.04347925969341304, 0.04932127551001031, 0.042495747038628906, 0.05471501928695943, 0.06969945214223117, 0.028744728369929362, 0.038238242486841045, 0.014728052374266554, 0.03931951454433147, 0.0472609733697027, 0.007763149033053196, 0.033399239255231805, 0.15015869488706812, 0.011877687647938728, 0.04306151960918214, 0.06719720477121882, 0.013316736112756189, 0.03555048788257409, 0.008143977938743774, 0.010876805954467272, 0.04285179609723855, 0.04145906321355142, 0.07707750584813766, 0.07834896809072234, 0.029519367271859664, 0.039428554591722786, 0.030043969200050924, 0.03340187016874552, 0.024466673748975154, 0.011456991960585583, 0.046165967869455926, 0.058510959934210405, 0.06117999386333395, 0.013294020827743225, 0.10782342244056053, 0.04273827718861867, 0.1974025840172544, 0.1275672743213363, 0.14803466823650524, 0.08744063336052932, 0.12143545725848526, 0.22981448855716735, 0.09690755076007918, 0.16614440741250291, 0.1366013489314355, 0.19750557927181944, 0.2581411966821179, 0.15389200940262526, 0.13280150829814374, 0.11605700914515182, 0.26489857002161443, 0.1357127755181864, 0.18328231904888526, 0.14009548409376293, 0.18542225734563544, 0.16282843222143129, 0.10606678115436807, 0.10788279425469227, 0.1921784135629423, 0.11899402146809734, 0.12357477957266383, 0.17824616428697482, 0.20096536783967167, 0.08691281051142141, 0.1519396118237637, 0.13698610797291622, 0.09936876478604972, 0.08348428862518631, 0.251037091948092, 0.1551698095863685, 0.14081216126214713, 0.22869120351970196, 0.2017233381047845, 0.20574842055793852, 0.14056596119189635, 0.20641402312321588, 0.11303542167297564, 0.14345269300974905, 0.12274838329176418, 0.2359209390124306, 0.16520824749022722, 0.1364048579125665, 0.08342217828612775, 0.10752179136034101, 0.1470034391968511, 0.15782237896928564, 0.1035864048753865, 0.11734532556147315, 0.08587194097344764, 0.1826130205881782, 0.09761392691871151, 0.14088545576669276, 0.11887058746651746, 0.2725022588856518, 0.13351040775887668, 0.1590372747159563, 0.12856561137596145, 0.20344963297247887, 0.11514331403304823, 0.22378446446964517, 0.37000627373345196, 0.24686755787115544, 0.18851025961339474, 0.14265362260630354, 0.1485182368196547, 0.2246375335380435, 0.09823469634284265, 0.11591411603149027, 0.23299845051951706, 0.09889211301924661, 0.14221493911463767, 0.10100723389768973, 0.2104531618533656, 0.09915879636537284, 0.16173063253518194, 0.10082109583890997, 0.20315966103225946, 0.10479761214810424, 0.1110254779632669, 0.11305085092317313, 0.17228104843525216, 0.28735788830090314, 0.1203110589995049, 0.15842170774703845, 0.08137688608258031, 0.13664599653566256, 0.16131767188198864, 0.09695774220745079, 0.1036190964805428, 0.1639541663462296, 0.10393953358288854, 0.1611728937132284, 0.09754302212968469, 0.19045695749809965, 0.08282341354060918, 0.2467881332268007, 0.06834983432781883, 0.09086590463994071, 0.09488562136539258, 0.08773184468736872, 0.08091228679404594, 0.07355027089943178, 0.10394581957370974, 0.10504591249627993, 0.10292711056536064, 0.15172357263509184, 0.10692185402149335, 0.16116426995722577, 0.22382669267244637, 0.1577037392416969, 0.24570208915974945, 0.07765497095533647, 0.06650317052844912, 0.2519326563924551, 0.09157924214377999, 0.11561211387743242, 0.18404928414383903, 0.1603428609087132, 0.10021875394158997, 0.12811876425985247, 0.14757014316273853, 0.211873454391025, 0.14803900237893686, 0.13922757207183167, 0.12509200401837006, 0.19666284089908004, 0.12215971917612478, 0.08652966935187578, 0.084307887009345, 0.13030750618781894, 0.1317213717265986, 0.12120228187995963, 0.1100893180409912, 0.11381974560208619, 0.2709360304288566, 0.20830814726650715, 0.16128356277476996, 0.2004637205391191, 0.145071302249562, 0.139914785977453, 0.13476013991748914, 0.09456333631533198, 0.15005958848632872, 0.08871803278452717, 0.18785906955599785, 0.19294770900160074, 0.13669944601133466, 0.086009564838605, 0.29051611258182675, 0.10098016035044566, 0.09291031368775293, 0.1544240996008739, 0.15314656659029424, 0.17127582425018772, 0.10474685666849837, 0.1839353347895667, 0.11904450235306285, 0.1332151220412925, 0.1379584550159052, 0.24772788514383137, 0.11092030821600929, 0.12406136869685724, 0.09416578264790587, 0.213013912725728, 0.170377959148027, 0.19333928095875308, 0.11381333344615996, 0.14227888255845755, 0.1566498153260909, 0.1783749565947801, 0.19369315181393176, 0.16120226791827008], [0.01406374578436953, 0.006652173442489584, 0.051917901801061817, 0.02123179303453071, 0.039284474041778594, 0.01727080987620866, 0.05712760779715609, 0.002521260034882289, 0.04675350020988844, 0.06164389553305227, 0.019814958905044477, 0.051288671893416904, 0.019294631747470703, 0.046747076921747066, 0.05460359694552608, 0.023929872768349014, 0.046794793306617066, 0.12085415524779819, 0.048869674938032404, 0.01133583356931922, 0.03644292788521852, 0.0653771914949175, 0.0050115650901716435, 0.02751767067820765, 0.053161310861469246, 0.059990872905473225, 0.045131336082704365, 0.026046550301543903, 0.09037052106577903, 0.04929230948619079, 0.019120906108582858, 0.022441254404839128, 0.010898693744820775, 0.024913084853324108, 0.038041799707571045, 0.01291881508223014, 0.02092867394821951, 0.03233818701119162, 0.023406293148582336, 0.05059500501374714, 0.04205742719932459, 0.07838427205570042, 0.011155215233884519, 0.07259082980453968, 0.02660328351339558, 0.04706689062004443, 0.026325367762183305, 0.027143477964273188, 0.09684786724392325, 0.09581182166584767, 0.03690580168040469, 0.030799581290921196, 0.0501384320523357, 0.02865812901291065, 0.007399241094390163, 0.05784549466625322, 0.0318555164267309, 0.035978528976556845, 0.05273582646623254, 0.02788382778817322, 0.04366751658380963, 0.033261196076637134, 0.003188681325809739, 0.007925896916276542, 0.05217369041929487, 0.03194080403773114, 0.05227471898251679, 0.012278970607439987, 0.0202451986115193, 0.05827354689245112, 0.05350807936338242, 0.013705096425837837, 0.04569753167743329, 0.11547703557880595, 0.013135470253473613, 0.11152272432809696, 0.04867678704613354, 0.03601525786507409, 0.005463456955112633, 0.0019411337484598334, 0.04944595631968696, 0.008151133170031244, 0.01000783637209679, 0.05618138064164668, 0.03779517290240619, 0.042692909701145254, 0.056890892374212854, 0.031486301668337546, 0.03865164100716356, 0.07760387408779934, 0.06957204765058123, 0.016291030224238057, 0.07574313916848041, 0.008976660210464615, 0.09839327103691176, 0.027893026708625257, 0.04373383490019478, 0.021166524857108016, 0.04119937832001597, 0.010632188514136942, 0.04556923660857137, 0.053690387940150686, 0.05974302897811867, 0.10124901818926446, 0.030194222563295625, 0.02093867809890071, 0.049901115489774384, 0.01798581906768959, 0.036656941010733135, 0.016155326666194014, 0.006673071857221657, 0.016469904512632638, 0.034509978286223486, 0.017101353441830724, 0.03931322484277189, 0.041677926274132915, 0.016817537616589107, 0.03155690217681695, 0.0575908712198725, 0.03986269613960758, 0.015310327526094625, 0.026586932144709863, 0.051685861908481456, 0.05194192512135487, 0.08520723640685901, 0.039635906941839494, 0.024179160172934644, 0.010982777221215656, 0.06539882509969175, 0.0358970708475681, 0.028403353426256217, 0.021327242502593435, 0.021225781638349872, 0.05730823912017513, 0.014127845079201506, 0.043092244522995315, 0.030914111375750508, 0.017924909152498003, 0.03448836323514115, 0.011360217758920044, 0.040183919918490574, 0.010921766188403126, 0.019785879703704268, 0.08437910350039601, 0.009295188137912191, 0.043109963298775256, 0.08320085500599816, 0.0541080797847826, 0.0628931712708436, 0.08050259159062989, 0.027959873805230018, 0.02230632639111718, 0.0485797475266736, 0.029818354450981133, 0.05540788464713842, 0.02429298336210195, 0.04358540907560382, 0.025833869331108872, 0.02348812049604021, 0.03849763423204422, 0.020792332143173553, 0.03022638353286311, 0.006711349979013903, 0.024480162282998208, 0.05476011960126925, 0.030927854095352814, 0.039060846393113025, 0.037037109868833795, 0.024822848972689826, 0.10358460887800902, 0.05532950643100776, 0.039132560123107396, 0.04707838648755569, 0.03199724065780174, 0.019148842402501032, 0.09641178126912564, 0.045137154520489275, 0.014422414624277735, 0.10804853067384101, 0.02353732674237108, 0.013078349002171308, 0.01325253106188029, 0.0097803180142364, 0.019477569294394925, 0.05062610100139864, 0.012546063990157563, 0.034513971040723845, 0.026354541587352287, 0.06714250848744996, 0.007706640053584124, 0.04169256142631639, 0.04169560794252902, 0.09353155808639713, 0.11946336308028549, 0.027629391734080855, 0.012201837344036903, 0.043680504168150946, 0.04063043677888345, 0.009082585092983209, 0.04181241456535645, 0.05619099145405926, 0.008972416981123388, 0.061238311827764846, 0.04169063926383387, 0.04757000366225839, 0.036928811969119124, 0.024845211737556383, 0.029451468180923257, 0.057329004412167706, 0.0058266366613679565, 0.0071443231081502745, 0.08998545032227412, 0.03647957884822972, 0.08157647185726091, 0.035779919126071036, 0.05210029943555128, 0.024446181196253747, 0.051648450244101696, 0.037160106003284454, 0.015051959944685223, 0.05299684351484757, 0.07581804413348436, 0.0448039302136749, 0.02791784041619394, 0.04502738345763646, 0.051701113043236546, 0.06290837045526132, 0.022972029146330897, 0.10368160015786998, 0.0325032072578324, 0.021474994828167837, 0.10472494104760699, 0.03891550048138015, 0.009684969663794618, 0.02780771868856391, 0.042187803992419504, 0.04574892911477946, 0.03822101352852769, 0.015408677863888443, 0.005619391458822065, 0.014161691651679575, 0.017651444431976415, 0.01996780792978825, 0.04264447714376729, 0.041382321433047764, 0.019405384300625883, 0.007587022546431399, 0.015599255821143743, 0.08800403476925567, 0.05014770147681702, 0.02482837240677327, 0.055738626469974406, 0.10933269106317312, 0.021258148553897627, 0.007543405135947978, 0.01297139160669758, 0.03875340800732374, 0.023299761560338084, 0.02405747949524084, 0.02439642576064216, 0.023233159372466616, 0.02954993262392236, 0.05571296300331596, 0.06072160635085311, 0.022291277491603978, 0.07535155236837454, 0.02485141794750234, 0.0147740766624338, 0.0619371811626479, 0.0339356524636969, 0.0875418474606704, 0.09352480454253964, 0.06795952402171679, 0.02187462836445775, 0.025715704578033183, 0.025921273918356746, 0.0921416119672358, 0.019135778748022858, 0.07948268030304462, 0.0570856207923498, 0.03175600555550773, 0.010755145685834577, 0.05225685177720152, 0.0015966495539032621, 0.035758953454205766, 0.04110648740606848, 0.024813954332785215, 0.01462906378947082, 0.04074181830219459, 0.03645390424935613, 0.05619997886242345, 0.05444995011202991, 0.034319754704483785, 0.06486304642749019, 0.018726734779193066, 0.04391740512801334, 0.012856681551056681, 0.05805900313134771, 0.019412983892834745, 0.03109367400611518, 0.06773792614694685, 0.05641270807245746, 0.034046091459458694, 0.02831285779393511, 0.010501544547878439, 0.04133574053412303, 0.06721054116496816, 0.03709450385940727, 0.06477515387814492, 0.04993379596271552, 0.06203063239809126, 0.030718273446836974, 0.018118507650797255, 0.029467301901604515, 0.06502674194052815, 0.019208692901884206, 0.02719963256822666, 0.026371935673523694, 0.041515395932947285, 0.010378637471148977, 0.014334965508169262, 0.02501205581211252, 0.04852078389376402, 0.042833546685869806, 0.034656288989936, 0.05805094711831771, 0.058034612447954714, 0.0390463114308659, 0.026329510801588185, 0.06469559564720839, 0.03970638870669063, 0.023252538703673054, 0.03322277880215552, 0.04222406161716208, 0.08559796973713674, 0.0465554952097591, 0.030306398184620775, 0.05564355364185758, 0.012962641685589915, 0.04405071711516939, 0.02752169682935346, 0.03805372602073476, 0.057470539395581, 0.011887227028637426, 0.05611187109025195, 0.0412284964841092, 0.009641964061302133, 0.01888763054012088, 0.013210749075369677, 0.053457015892490745, 0.03506494147586636, 0.03450168849667534, 0.08876019419403747, 0.07743593349005096, 0.16705968329915777, 0.06825138101703487, 0.12170362489996478, 0.05496103382029105, 0.13839921652106568, 0.0741430465131998, 0.09320153985754587, 0.13840389205142856, 0.15689349209424108, 0.1289432606426999, 0.10342518071411178, 0.1046303469047416, 0.18510498921386898, 0.16578698909142986, 0.2607068605720997, 0.25374046876095235, 0.15184178191702813, 0.13480256107868627, 0.14588882244424894, 0.17130773660028353, 0.09312725087511353, 0.1102951007487718, 0.09842039653449319, 0.19798061315668747, 0.13260595238534734, 0.13953937799669802, 0.13893293944420293, 0.13754509360296652, 0.19082381593761966, 0.12552979693282396, 0.10754269023891538, 0.13336616393644363, 0.15051437658257782, 0.1620877836830914, 0.13149602600606158, 0.12041465539368801, 0.12268285907339305, 0.15451832266990095, 0.12080144049832597, 0.18127810471924022, 0.2816333173541352, 0.15000106272054836, 0.18198489648057148, 0.16000001836800948, 0.13905736792366952, 0.22074064967455342, 0.165251188154798, 0.16230719222221524, 0.17937969096237794, 0.09635000489652157, 0.19273928424809128, 0.12789514032192528, 0.12473356153350323, 0.22910650935955346, 0.12106798283639364, 0.0737703251070343, 0.1305563483037986, 0.1350049744360149, 0.15749957441585138, 0.16706291906302795, 0.12249283958226442, 0.07859530174755491, 0.14344740891829133, 0.14892270730342716, 0.21272419311571866, 0.09547845635097474, 0.10909206452197395, 0.1157477858942002, 0.10577809312962927, 0.09168289048830047, 0.1452925067860633, 0.22379172267392278, 0.1597648614551872, 0.29236266505904496, 0.1501422785804607, 0.10402586762211286, 0.052987588933319785, 0.09354635651106946, 0.09107711986871436, 0.115129465557402, 0.06914998826687224, 0.11292553928797133, 0.13986203412059695, 0.12354205828160048, 0.15171263337833807, 0.13399486691923812, 0.09472543621086515, 0.12963663437403738, 0.11390859552193433, 0.10148478366318159, 0.18674736202228814, 0.11009256122633815, 0.1519380829995498, 0.1887967434595339, 0.14759454497834668, 0.1425333649967797, 0.133726432104595, 0.11633723668637685, 0.2692447055596858, 0.1852416928159073, 0.22212010924704373, 0.23542893963167444, 0.12706328183412552, 0.1611608115490526, 0.2772591880057007, 0.07958460686495528, 0.09123156822170131, 0.09338844974990934, 0.12355393264442682, 0.11074930254835635, 0.15888118621660396, 0.09447193340747617, 0.14356095751281828, 0.09009060522657819, 0.10351641292800196, 0.10562117342487909, 0.13557990139815956, 0.15315692697186023, 0.1393713112338446, 0.13760256551904604, 0.0795873453898821, 0.14930381497833878, 0.21115533745614812, 0.17820178385591134, 0.16401913395384327, 0.14040533074876294, 0.1860062830382958, 0.10943274741293862, 0.13782115769572556, 0.11371905842679553, 0.16253930632956326, 0.1305445481557399, 0.13922872982220724, 0.09007808519527316, 0.10310711106285453, 0.102333273680415, 0.15822943212697282, 0.09835981501964852, 0.09570026944857091, 0.08941477586631663, 0.13002799852984026, 0.11870300309965387, 0.15016665071016178, 0.18196086573880166, 0.11857302335556597, 0.12223964105942287, 0.157501652429346, 0.09246751127648167, 0.17270260315854102, 0.13699415285373107, 0.14033607352757826, 0.14047650271095335, 0.15351539914263412, 0.155382301309146, 0.13025142950937152, 0.08240925802965648, 0.2242969471262768, 0.12300981223233975, 0.09516324396827258, 0.1208451233105734, 0.14193437760695815, 0.08232077918364666, 0.13710934901610017, 0.1845336245605722, 0.12458565150154755, 0.13027638051426038, 0.14901513437507674, 0.208372981287539, 0.15231962112011388, 0.13435219618258998, 0.18207407294539735, 0.1714734433335252, 0.0857815622293856, 0.24452462734188884], [0.011929483061976498, 0.01452922451790073, 0.038147010272950865, 0.037231118403724395, 0.03982087240729015, 0.02768544614809798, 0.0617829888506094, 0.057697766460478306, 0.051435631976346485, 0.06702787635731511, 0.03634424450865481, 0.05478897059219889, 0.0383540249458747, 0.039624362834729254, 0.07243546860991046, 0.009378062841278734, 0.01743397104291944, 0.030036133975954726, 0.09953002605470829, 0.0019294718254059262, 0.026429867721162736, 0.018637671491887886, 0.06127473643573467, 0.03596656926674768, 0.07622011748026125, 0.023993422873900272, 0.04804244374099653, 0.02972968821268296, 0.07235559867694974, 0.004145347484154627, 0.056461081258021295, 0.00905276188859716, 0.02774259337456897, 0.057798924899543636, 0.04852455771469977, 0.011438223973527784, 0.007902457109594252, 0.04219698064844124, 0.029565870245278347, 0.02723537625570316, 0.02591457603557501, 0.046480219170916826, 0.029976456025906373, 0.02813778515701415, 0.03528152243234217, 0.03713777849043254, 0.023571758683829103, 0.0191788381562219, 0.038001831344445236, 0.012050158129568445, 0.04637068559532054, 0.05194060780922882, 0.0541974046791438, 0.010959006231132662, 0.04336602280091029, 0.027736119991459418, 0.05417119202320464, 0.08502780736307614, 0.028381808879203163, 0.014569779177691089, 0.13435984030365944, 0.019893047683581244, 0.07543456158600748, 0.041065223995246924, 0.08470835731714033, 0.033961965309572406, 0.059920135099673644, 0.02650929422088666, 0.025361245570820756, 0.048049160177470185, 0.03933666928787716, 0.03600514610297978, 0.018254480237374082, 0.051129870844306424, 0.029866415934520774, 0.035783474013442174, 0.041949303704313934, 0.04688322020228952, 0.001297773001169844, 0.04793868778506294, 0.0025653709735706798, 0.028807616108679213, 0.013194470993767027, 0.04717624979093671, 0.05117928303661756, 0.03856066112348344, 0.03127618110738695, 0.013115542660671053, 0.058541484468150884, 0.03356308690854348, 0.03622069547418505, 0.03627478319685906, 0.029350832955969963, 0.03433705416682642, 0.042190386666334234, 0.028660971438512206, 0.03859043979900889, 0.028490735749073792, 0.037701680848840624, 0.06112064431363251, 0.0006338521541238151, 0.03544835723005235, 0.03190144423570018, 0.04327242684666999, 0.010301961556251626, 0.03969930861785542, 0.031231782122631557, 0.03661725095298607, 0.0465499624988297, 0.045293120565474965, 0.02228877645393368, 0.02947044118627673, 0.044112404430052266, 0.026289199195161927, 0.09283444393076934, 0.07030262524494901, 0.0608539349923376, 0.02675583938980708, 0.013563938082370441, 0.015440119877894176, 0.03512554525514133, 0.03339200702612288, 0.007793136901455, 0.03831350739346817, 0.03331860119942576, 0.010517716873437166, 0.052961495021008886, 0.031586907207383774, 0.11780883389292285, 0.04573768928821664, 0.04297127074096352, 0.013922979851486161, 0.0532368800486438, 0.025193319816025905, 0.015688502789998893, 0.022480118823295925, 0.07157836225815117, 0.031908939927234314, 0.01759061800839845, 0.04439050200744532, 0.03587985673220828, 0.013796133825962897, 0.03795983691816218, 0.029940296735730954, 0.042475709051359445, 0.08284511393867433, 0.027548679463507142, 0.05727809308154974, 0.06356856276397593, 0.027867825228895526, 0.07027417872450314, 0.041698914210428484, 0.04323188331909478, 0.02397564658167539, 0.03212736512068659, 0.05059892726421822, 0.06241883500479162, 0.04056748410221189, 0.060370707797119394, 0.0354997806425672, 0.04613182165485341, 0.07876406612922437, 0.03726744282175787, 0.03189905823091976, 0.003126933711428137, 0.03806014188739937, 0.0025216434005415067, 0.010835494304046733, 0.035497787976055406, 0.032361531266360544, 0.0389284806442447, 0.028902627709612716, 0.061808151367586106, 0.034639171353774145, 0.028472009507822804, 0.042335958933108486, 0.04059442406287417, 0.059286663818056695, 0.03580736374715343, 0.020814032541238703, 0.05777971069619525, 0.04077995356055908, 0.018232405054732226, 0.01492154604420648, 0.01201426322950283, 0.04957660399668384, 0.04519481568422634, 0.014861141717119608, 0.019052079333050642, 0.04381417980766855, 0.004154265316174133, 0.025335986574646086, 0.02606416146591073, 0.0321437851380324, 0.06423122642445378, 0.03487749352643732, 0.060522213534568436, 0.040770012492430396, 0.056094397223205306, 0.05212788135395385, 0.08896920524421148, 0.05666170232871082, 0.04162752702541184, 0.01530329289380461, 0.09756521976669319, 0.019366701708349865, 0.06611559874727391, 0.02321130312338937, 0.01520674690254964, 0.07978759167599492, 0.009353342829854228, 0.032951809553196654, 0.024898676056182012, 0.03453557495959103, 0.05594928879872896, 0.03704347007442266, 0.0036259048738429556, 0.028600404766621068, 0.08626649636426009, 0.022787991365476046, 0.05664180534949992, 0.012138760357629508, 0.012491737852542428, 0.02475609835528303, 0.04090435977559537, 0.028244788009033073, 0.03719689055287745, 0.019050324153795373, 0.09440428664674982, 0.026422442533657886, 0.054122688961797394, 0.07139045046642423, 0.06275306863244623, 0.08783080265857279, 0.015400644115288742, 0.03246686057536863, 0.050041808135574684, 0.019253824757470284, 0.021338961014407687, 0.05242432111117523, 0.031394368124892935, 0.1423828277620487, 0.009172794070764212, 0.026901552664639894, 0.048463215498486534, 0.057236610737163574, 0.022423923401220236, 0.013751667120232014, 0.018987803778145462, 0.03142215784464497, 0.0789701308531221, 0.01914475316880271, 0.010904799764830386, 0.04921118903439492, 0.01419750027707778, 0.11722463008482009, 0.036250767298042774, 0.04846523414016701, 0.024583649210399017, 0.022564864666492213, 0.02344431894016452, 0.040114414077834226, 0.05613674788037315, 0.01768553313013399, 0.010842861975106644, 0.05897380775422789, 0.023314999707508832, 0.04085996450157836, 0.02952328581159236, 0.008435534364252817, 0.025088753063755576, 0.02338659469387494, 0.02491013667167863, 0.07343634380958974, 0.004443023844942218, 0.04004615133453626, 0.019779428585025016, 0.03671250931802206, 0.012855012646468822, 0.03439829248236492, 0.04886761547822971, 0.02286077378812479, 0.05378770576498937, 0.08783060970017686, 0.02149206236936152, 0.035394803853705525, 0.05973762985377107, 0.09022296726470813, 0.06963996900594793, 0.065166161803063, 0.01744419969327282, 0.03011968125065323, 0.06069307077268604, 0.042304996532038786, 0.018219873891212046, 0.0619768637989182, 0.01064226131347823, 0.0321389166492736, 0.03266255007474683, 0.04106873064301908, 0.017181121329485904, 0.013701574935112149, 0.06057608232367784, 0.023419902281602845, 0.10181310237385333, 0.0570956026786007, 0.04216312387143262, 0.11572644172701985, 0.05874456946912687, 0.05900628413655795, 0.03643223724793643, 0.008852097216731636, 0.010704922697186703, 0.03442043816903606, 0.048977687110891566, 0.01781608247256372, 0.032851181749720126, 0.04497055349929724, 0.042378877333248965, 0.04684797931986395, 0.04332982454798184, 0.07096336674294434, 0.04315256628615316, 0.02121669032931095, 0.08154143506544642, 0.01527948572402238, 0.02610213716252474, 0.019781679147854447, 0.07229951457702555, 0.027900784007215407, 0.030502790868922602, 0.024905932405090425, 0.034268078961758874, 0.05337958391464781, 0.015878475896897726, 0.07817145378794521, 0.037456089339684695, 0.08111731993267313, 0.012030464313284028, 0.031096156490093563, 0.045264373475220054, 0.012263112766959239, 0.03873817913699895, 0.04040069383336231, 0.02813836959830951, 0.030840132239973173, 0.04640866500267293, 0.006213540509634186, 0.04345684683357831, 0.029843388947483618, 0.047028692279127426, 0.038356718941940926, 0.13616262091090903, 0.11620480785495602, 0.17336995719233528, 0.11239510407904163, 0.12400651656207629, 0.11059335505706258, 0.15645075647626072, 0.24303804617375135, 0.19491486047627404, 0.19135485228616744, 0.15732867264887318, 0.1142816360516008, 0.222612835932523, 0.1319085858995095, 0.12371776916552335, 0.06865739516797476, 0.1515048765577376, 0.09666474230471067, 0.18605830759042874, 0.15568463742965832, 0.10580579750239849, 0.16295428562443703, 0.1657740757218562, 0.12848447979195043, 0.1699219094007276, 0.16055008338298649, 0.10481390228960663, 0.0945590392802842, 0.2044660339015536, 0.08620598906418309, 0.18634243140695617, 0.0818705627170857, 0.14749110443517566, 0.15433380991453305, 0.11250247058342211, 0.1713477828889154, 0.09258765756385401, 0.09152810816885903, 0.12211962835863233, 0.11440085465437733, 0.0633814005414024, 0.19529656186932698, 0.17261841392610222, 0.16174416930880398, 0.2125356876058504, 0.18951524631120265, 0.21272891317494214, 0.07061117314151488, 0.12837186630349606, 0.09830386450630613, 0.11324518229230307, 0.058432960213394836, 0.22451077471487224, 0.13331124500837177, 0.21621604246320203, 0.08351777432835661, 0.14158681500703096, 0.25871449091937393, 0.13171429163776338, 0.14223364123608917, 0.24307265994139016, 0.11220601969398558, 0.1680337224388495, 0.07228095346363261, 0.12454306706786156, 0.16456823417684063, 0.11940513417357579, 0.0984745510504581, 0.12551691324915737, 0.24785351590253413, 0.11725208212737925, 0.1726110072922893, 0.1577693154104054, 0.17204290808876976, 0.21742265584180132, 0.12617760279681534, 0.07838482124498114, 0.12818388029700145, 0.09631211083615199, 0.15564880653982982, 0.0608867564733373, 0.07739668872090988, 0.10431504546431825, 0.1883580005960539, 0.13669457752257586, 0.17204917181516066, 0.1218343764776364, 0.16310979524860159, 0.10653943274519406, 0.07939069109852426, 0.14531342050759122, 0.140504956652876, 0.09585459163645282, 0.1732480520149693, 0.11642524055787362, 0.10558529800618999, 0.11752229067496955, 0.14621977577917278, 0.1509486517170444, 0.12119372491724789, 0.06753519366611727, 0.11408862570533529, 0.13145927485311404, 0.13288453978020698, 0.08485359561746009, 0.13539345905883238, 0.15116586349904537, 0.1368383612134494, 0.1273096600198187, 0.1064931672590319, 0.11810918847913854, 0.18050354003207758, 0.1863364496966824, 0.13646368053741753, 0.17951053159777075, 0.14424984867218882, 0.16101736924611032, 0.11964334131334908, 0.13143065763870254, 0.08895952021703124, 0.09783469358808361, 0.13010938244406134, 0.07630317864823155, 0.21293042111210525, 0.15527224080869928, 0.10441481979796663, 0.17765320313628763, 0.15893278032308444, 0.21082708553876728, 0.20233467483194545, 0.11442693372373469, 0.2130411347025074, 0.13648909167386591, 0.2069016289897263, 0.1693435388733633, 0.0815594544110354, 0.2063239412382245, 0.11517453618580475, 0.13117169262841344, 0.24912116350606084, 0.21049812115961686, 0.10704647545935586, 0.11706690143910237, 0.15102408360689878, 0.16696540085831657, 0.1178810597048141, 0.16684812668245286, 0.15316148375859484, 0.1200431733741425, 0.12194787312182598, 0.1478388303075917, 0.11866130182170309, 0.19705853919731453, 0.18915723427198827, 0.09852619710727595, 0.16382673959014937, 0.16334394284058362, 0.12611698417458683, 0.1339965738588944, 0.16980298765702173, 0.08330704891704954, 0.19599214720074087, 0.12004870237433352, 0.0640669371932745, 0.12050962061039172, 0.17753937252564356, 0.09096558249439113, 0.10355655569583178, 0.13502127199899405, 0.20162249507848173, 0.09029783512232825, 0.10327073236112483, 0.12030092868371867, 0.06966553599340841, 0.1113846774387639, 0.13277373713208362], [0.00816761348687578, 0.019300949279568158, 0.05323627148754895, 0.040617623599246144, 0.020808334702451248, 0.029162345999793615, 0.019886759837390855, 0.06465729340561666, 0.028650789172388613, 0.03749957548279781, 0.0666416775493417, 0.07678516645682976, 0.06081505758629646, 0.06728822918375954, 0.048890655452851206, 0.010911552381003276, 0.002286619610458729, 0.017603592605155427, 0.04498190464801155, 0.015668023224861827, 0.008527444715582533, 0.02871102187782526, 0.020728527852043044, 0.04643392028810922, 0.06442178026190959, 0.038110251698526554, 0.0703029369469732, 0.037408027856145054, 0.04187470673059579, 0.024503244931111112, 0.028602111706277356, 0.06928394592250697, 0.07902539859060198, 0.03565645543858409, 0.026724997587734833, 0.031072840065462515, 0.006472299573943019, 0.05218974678427912, 0.029023731367487926, 0.03767015441553667, 0.06594922408112325, 0.012458233595680213, 0.05174258054466918, 0.07295781440916471, 0.03213103875168599, 0.018193191826867405, 0.014775883792026434, 0.01753720935084857, 0.023138485448725987, 0.012520667696662713, 0.06665701032034121, 0.01769862832588842, 0.011941579141421244, 0.040128952750819735, 0.06828467376180924, 0.06773181085009128, 0.17706579325022176, 0.02353002029849449, 0.07369750557700172, 0.04172535322140902, 0.011289159901934909, 0.03312956505396869, 0.03668114986794535, 0.0560066456819186, 0.0798678252613172, 0.031124380366236437, 0.04414070623170119, 0.03508244873955846, 0.06924862711457536, 0.034147264741477557, 0.025499845360172912, 0.06448642874602228, 0.057193313841708004, 0.048425035711261444, 0.010213650621153647, 0.03121477951935958, 0.012250274539837847, 0.023509297679993324, 0.05318137111316901, 0.0359517374454299, 0.029693705182580743, 0.08502408920321614, 0.05647118930937722, 0.09287651628255844, 0.03822276870778296, 0.0376783143292414, 0.024109661753755063, 0.0196854819660075, 0.031934002254274674, 0.02133508700353559, 0.06878012412926182, 0.035297155773150735, 0.007875661867728923, 0.07206060239695944, 0.07452647711033933, 0.029829418017470744, 0.022630418570770416, 0.012559991318994435, 0.04116263458854519, 0.016172232790268026, 0.038368619279935956, 0.05500808227225207, 0.020890247396891937, 0.054565276150242426, 0.03731604607310146, 0.012897960732516367, 0.04533378654741682, 0.09067962557310238, 0.03855660899716895, 0.08811155712464824, 0.012059121418133145, 0.03260312259953935, 0.018762012769002467, 0.030623289676441345, 0.037494532589334995, 0.01379583232846926, 0.026210898904537316, 0.04497251647990197, 0.019428142259130254, 0.04399088888021652, 0.054131962097017094, 0.011965621015406214, 0.01898680373415118, 0.04217415589664597, 0.034678623924264684, 0.06140240438980982, 0.08477618219330907, 0.042930411800625734, 0.04276371801097412, 0.030373013360076584, 0.046841084767947905, 0.08155137984431349, 0.07548440422397107, 0.015245872000377858, 0.038831192505313084, 0.045587897911900654, 0.04771999912918545, 0.02814200797729427, 0.02301898111909395, 0.029310083482414484, 0.05585032340604812, 0.037823348538950086, 0.036168040096526965, 0.02944377025414724, 0.03201570158125833, 0.04920045015751384, 0.018243457489006687, 0.017249768134206533, 0.02788838271953864, 0.04029438117868267, 0.01747836260619806, 0.04155384289333597, 0.029060467677481938, 0.05365183707908727, 0.030910346831660718, 0.006849249830338522, 0.06230648868950084, 0.04019649190013297, 0.025756086688488722, 0.09891010267892852, 0.01768137710314477, 0.04647048961487599, 0.0925493256363552, 0.047556322169839405, 0.0354948230960872, 0.04731944347440731, 0.028833945652877446, 0.0322694492933806, 0.011984807388216723, 0.013572681509685935, 0.01897525777167175, 0.032191520076594315, 0.017297807353315875, 0.04862520036112983, 0.04778849193826318, 0.07537040291936137, 0.029980426515976433, 0.04522889881627634, 0.03493790063657798, 0.04641011961211916, 0.03790993861912284, 0.014065694849705324, 0.014686317699670326, 0.03122254609479569, 0.019443771889200434, 0.017282107219216414, 0.004431171282703872, 0.04485741679673083, 0.051170770602766424, 0.1021151861641556, 0.039018158058752306, 0.030013088435225654, 0.010932732348010177, 0.06959960359381512, 0.03328805440105498, 0.014770990255783545, 0.032064905972220004, 0.012129373117204523, 0.027483377889438998, 0.019617766556621064, 0.024850297304510605, 0.02743367811490316, 0.03448603660217486, 0.011352532819728367, 0.02853475252777571, 0.05728925498260651, 0.0570120108750416, 0.027699337297235616, 0.0565178036049474, 0.02045409091806505, 0.011584430776565569, 0.034711515909293666, 0.02811195285175927, 0.03774180506297853, 0.0606456957757473, 0.01603724726010114, 0.015155248347582528, 0.03472935342870187, 0.058208356640534475, 0.03996508283307776, 0.039746661350363865, 0.04125495033804327, 0.06522310679429211, 0.03606610240240116, 0.049541916014277376, 0.019462626150925644, 0.05731653633120004, 0.014129895262158243, 0.02010713502386352, 0.03560876131814439, 0.02095133542752592, 0.03634419997979421, 0.05640252580633387, 0.03189882445440162, 0.0677940399327781, 0.06336571896099485, 0.04037246253574267, 0.022238878154894337, 0.0671757195959799, 0.045577099663205445, 0.0072790748617990175, 0.09312525449786335, 0.04174018504272681, 0.035351480983081274, 0.01131017845182214, 0.042693759460235015, 0.01816657284507528, 0.03905276069417596, 0.04574346690787934, 0.014431903910008259, 0.03375866879650857, 0.0056879682233557105, 0.04682834951381665, 0.03796331016928889, 0.03427255782298744, 0.023239022339112125, 0.02951837464934215, 0.04262515532900579, 0.02855449180060532, 0.036734128079842776, 0.05254375864751637, 0.01150593752754503, 0.05760527630627621, 0.06319322899798863, 0.04931535688228905, 0.08884442795533687, 0.03845735416689422, 0.009488585328654153, 0.07145285766455345, 0.02760469120403286, 0.044610771437874064, 0.012488484462664928, 0.04849941375141498, 0.015347382031905, 0.06637558049988002, 0.03188523573044222, 0.05636993810185231, 0.013343394057301339, 0.05814670643303543, 0.053334743352024816, 0.012264950510143535, 0.012747121072607115, 0.014177991997712525, 0.042959251659340225, 0.014501188034046208, 0.06720723118633032, 0.04007538824225776, 0.037187120178714395, 0.03013238496350823, 0.042201151518383995, 0.020168560731690377, 0.02468888389557833, 0.040099756661220454, 0.025384543441759888, 0.015418296097777784, 0.061972722614882514, 0.05319952775607817, 0.015717517053417396, 0.032794466824270785, 0.023749931642669253, 0.016934069644776173, 0.07208926414023153, 0.05463093395519536, 0.06364843269693665, 0.0643815187504515, 0.05767984730482567, 0.02355636839638464, 0.07539756552432664, 0.09032862682943232, 0.09987853118218482, 0.029622308720718138, 0.008636842849227833, 0.024547955617890693, 0.058718408763525076, 0.03440440777922049, 0.04035567144455854, 0.027891008066944778, 0.04900605941656977, 0.0322142965887906, 0.0542513179971138, 0.02072034196316963, 0.09551655079121701, 0.04641749656002503, 0.019599016195570584, 0.018945874289784115, 0.09119541078689508, 0.026396471075713634, 0.04772797350597102, 0.04931299314193893, 0.06338019826216623, 0.01851606873970013, 0.07632689768797718, 0.08410496157011949, 0.02510024522052845, 0.010988963022100506, 0.06317698338534683, 0.07980728085385635, 0.08637838996946812, 0.03295054048066959, 0.0026560479682302685, 0.01871512758953031, 0.024008184191188775, 0.05926452926360071, 0.029392133474175353, 0.005891169184906175, 0.012364853791950736, 0.021310740849003196, 0.030391108775802422, 0.03434602673223708, 0.0342987704789266, 0.031514759320998564, 0.020198510101181455, 0.1392865282832645, 0.09432139617274515, 0.14426055044168606, 0.12761661229887977, 0.13678575778612867, 0.09590783331077546, 0.14397170656593516, 0.19582354609156027, 0.11024182196706533, 0.22222283732844517, 0.16332210885593668, 0.1340788186644204, 0.21165930025745183, 0.1526958157774061, 0.12168337168986909, 0.11067251252825372, 0.08215510213631205, 0.1618829509243369, 0.1215801463695243, 0.10074735604575835, 0.17105080507462844, 0.10996823664754629, 0.1330239447997883, 0.15105471946299076, 0.177485937892925, 0.14292409090558067, 0.08497980525135063, 0.08477659779600799, 0.11866384738823399, 0.14761441969312727, 0.09691735453088768, 0.1293710494064726, 0.16063912626123056, 0.08965959554188885, 0.1378817021031864, 0.09940903371898457, 0.0806645727425348, 0.1855927286669612, 0.07416880645905621, 0.08036257058847696, 0.18427793984301388, 0.16304413002217188, 0.13312213093740866, 0.08879969871486537, 0.09950635896530002, 0.08012324280571193, 0.13915202143834904, 0.08580184512538835, 0.1417654796387069, 0.10261416173307225, 0.159821784181986, 0.1377023250097409, 0.11339008662616834, 0.1426696084672585, 0.12176378339063376, 0.21043110522441566, 0.2645030349958688, 0.12985435081645846, 0.1277829275932163, 0.133210624626372, 0.1053743351076264, 0.1136384611891117, 0.14718645281391218, 0.15080152836162597, 0.13144809810910374, 0.18963011592859402, 0.08914035191992298, 0.063040613749763, 0.11970651292358525, 0.10953707853332162, 0.0755797850433737, 0.10732237627962604, 0.13101459480822086, 0.13757314678514376, 0.1786840907880105, 0.11924589896807447, 0.08488936713547446, 0.11217768449569121, 0.303107924410142, 0.12907665426610038, 0.1479323854437098, 0.1302470508380793, 0.09372798973345198, 0.2645405876683071, 0.21553473605308682, 0.08923849352868274, 0.1537204990745522, 0.12588394980411977, 0.1984328037360683, 0.1462343367165886, 0.10840573377208784, 0.07165497416281141, 0.14949503674870357, 0.14006998389959335, 0.12548026599688455, 0.1259075352572836, 0.15527097915764898, 0.055400745186489075, 0.1401269214693457, 0.12220620730658993, 0.08900156288291328, 0.18740382132818922, 0.17000701889628544, 0.1128472427080851, 0.07662227988475934, 0.09577151562552899, 0.10025920841144398, 0.13381076976656914, 0.09481142886215821, 0.35858865827322006, 0.11386768834199756, 0.1428495199070312, 0.0926288690243382, 0.10037963671493344, 0.1704267627792433, 0.13247431023046374, 0.10204117919784039, 0.15469994104932994, 0.15493033337406814, 0.1080513211491052, 0.16207089240197092, 0.06448154541430995, 0.12073410543962382, 0.09963652424630709, 0.05776755431725178, 0.13336297270143405, 0.21754255722044036, 0.17506411706563085, 0.14779672084841877, 0.2276741643436253, 0.1968732991372235, 0.18116785126039758, 0.13490625395206735, 0.14366144430823624, 0.19842257694108412, 0.10141375270904973, 0.19741472555324435, 0.10475433751707897, 0.04944566317135468, 0.09184047812595963, 0.15577078593196347, 0.09580204758094624, 0.19836774707073346, 0.1182001164124813, 0.08076995029114187, 0.3634273126954213, 0.11811928168754093, 0.1134450500831008, 0.15431521169375628, 0.16054092528065667, 0.11423048723372631, 0.11366153456037864, 0.17434130975743756, 0.19458310562185943, 0.11630804059677757, 0.13117506197886541, 0.25873797247186303, 0.10666400223271921, 0.114193506014999, 0.19262245536083356, 0.23681096703512594, 0.203950849827379, 0.15029471571324393, 0.06753512687282637, 0.07311877139727585, 0.14175828080624342, 0.10781573379063047, 0.05416395979409572, 0.1174179521331098, 0.10722201564931311, 0.09548787420499139, 0.10163610757444985, 0.11197469968465157, 0.10204259669990279, 0.10445964551763609, 0.1607892627362162], [0.06330085525405593, 0.024097904279187787, 0.0071938707424124, 0.044669965136563405, 0.02427511615678668, 0.02842165107722394, 0.01988399904803373, 0.04162182733125519, 0.04002607995062135, 0.057664291889523156, 0.012811817796318792, 0.025969815942517016, 0.019547574229363818, 0.05582132769632153, 0.03173720324411988, 0.09303184036980383, 0.052266752027207986, 0.0700690713711083, 0.009005734773381846, 0.082420078542782, 0.1344590654480271, 0.07910350221209228, 0.03534216702973936, 0.02808719851600472, 0.05000575831218157, 0.03263435217377264, 0.005784399645563099, 0.07884020305937156, 0.020919992675771937, 0.048751751382951625, 0.05151907535037026, 0.025518484399071895, 0.06694411757052876, 0.057165186444763094, 0.05810857117467094, 0.045383755350485444, 0.07242478910484351, 0.06282581394771114, 0.08910967895644717, 0.08161412843037397, 0.07753190802759491, 0.029716132885369007, 0.07980909911566414, 0.04456059854419436, 0.06087475594540592, 0.04218998219585046, 0.0810723532049451, 0.03790583825320937, 0.021028559604019392, 0.048190669185714796, 0.04459894902538508, 0.030017860444786493, 0.031228739317157306, 0.025415489144506864, 0.03478165628621355, 0.033080568464356475, 0.05793473792436998, 0.06850233825389296, 0.053752917592646554, 0.0736337254056707, 0.05502436870301608, 0.05865227598405909, 0.049504389317007735, 0.015053358893055702, 0.019877213962899987, 0.04719259188277647, 0.109705241775373, 0.07034174384898506, 0.030905636049283203, 0.008270350845123176, 0.03478441336483229, 0.04079590231413022, 0.031854763146839105, 0.006308290967353969, 0.06619652252993546, 0.06061482985387556, 0.03463929009740241, 0.0635068012343254, 0.012494238890212728, 0.055663595339865424, 0.03339123519253917, 0.06616046899580397, 0.05097686225781217, 0.05779172606708016, 0.04129631764953956, 0.03230287562473677, 0.010967570615321165, 0.06294425329542719, 0.050250210624653846, 0.06252594175748527, 0.010405455905129202, 0.01215754968143301, 0.06326889837509952, 0.06964622531086206, 0.018310783270862885, 0.051190129524911754, 0.050956037594005466, 0.043070566389360465, 0.07198134844657034, 0.05284305938403122, 0.03342672098369803, 0.032394549416494556, 0.0485258564731339, 0.058868704800261185, 0.041477205013507046, 0.021241095855657477, 0.05677753302734345, 0.005648456744893338, 0.03311834378109779, 0.06010344557580538, 0.05396357249992434, 0.059242539427941665, 0.012155767599324463, 0.027058613377448637, 0.037205458647804335, 0.029251687592477538, 0.030096635709924158, 0.02149520536477212, 0.031578598864143714, 0.13653219561092556, 0.004428270876815077, 0.05726246345147956, 0.06692813170957379, 0.05087959267257247, 0.08856402972014621, 0.033525782855576836, 0.017516659281682223, 0.015058607732498785, 0.011530144529388053, 0.011432932460593292, 0.05284538601699751, 0.0593361056962749, 0.011236582449782873, 0.028637092837016098, 0.0337780945119448, 0.04979431672836654, 0.039057599497027695, 0.005690909911209019, 0.020781040366273373, 0.020835532559431158, 0.07486589092877693, 0.03360427239385899, 0.06209973376826383, 0.01343110941888881, 0.0942685997870285, 0.018107379146385938, 0.010893156395468395, 0.04012828110717237, 0.03244321946112905, 0.10158668053918518, 0.04731000335596036, 0.020958500863343943, 0.031709398681414314, 0.030687791586387902, 0.04486149118747562, 0.05215506251261104, 0.04184032302873675, 0.0226904880037182, 0.01466832340156543, 0.056634914508322254, 0.03469896619208157, 0.02417026182229165, 0.043415550026111305, 0.029113894888723735, 0.06641094383667223, 0.06013815582264215, 0.02807105309329927, 0.05441408582555596, 0.027629621799860615, 0.07769510630168952, 0.01711152828647755, 0.03791415772866458, 0.05246706881735008, 0.018728111463133246, 0.005591897206613794, 0.019105744031548966, 0.06940979932551272, 0.024071083062153775, 0.011830593739432516, 0.010129255442734575, 0.08702187653398141, 0.04451816625078209, 0.043821137442137115, 0.03001043154654326, 0.03605797217460349, 0.035719567677006125, 0.05447071911476087, 0.026657718190108426, 0.020078156012459658, 0.09453091188333929, 0.024720471556065604, 0.037739871768280864, 0.05822891784191597, 0.011163561612193007, 0.010033549006038811, 0.028352354893286247, 0.11209935822989792, 0.07213958917418495, 0.04358946120191831, 0.11000162587151863, 0.02501355866115773, 0.03330663406813983, 0.02306020000105491, 0.038088391738710925, 0.07565559542854317, 0.057449466112302616, 0.025973439478548244, 0.06341611820971593, 0.032050860827439465, 0.011017337183147902, 0.03582671153708361, 0.11689787730574608, 0.026736936888482887, 0.036076703981962055, 0.07178308369475417, 0.06728480046149343, 0.08382878615520895, 0.0795242479944136, 0.05698499298887327, 0.025348046474391595, 0.059866051087738015, 0.0215817453499767, 0.059654817305272445, 0.03762146952794865, 0.04894875077297911, 0.05989511730149388, 0.052403084555407986, 0.07194476798758842, 0.05406225587648805, 0.08165357357938774, 0.03519896221405361, 0.07230807153973728, 0.04349027687567286, 0.04783840508025605, 0.0167099113605218, 0.04293522462830879, 0.07856787196942605, 0.03128483826003503, 0.04568514152197167, 0.05265725158096757, 0.028295471129240468, 0.03232508810469881, 0.06261279530008323, 0.028312891190580558, 0.00728080731278169, 0.0661949862842448, 0.04707609325123485, 0.06711869296850637, 0.016938170010689646, 0.062298473494593054, 0.03712650897796266, 0.07258467740030028, 0.03098791425145464, 0.017357527976855636, 0.04174943591351621, 0.0456141365430085, 0.0275186336148181, 0.06177989409479778, 0.03412341211515013, 0.07712115155300125, 0.050757116041495465, 0.08063538407441229, 0.044801225085393526, 0.031123460103117395, 0.08612804871518165, 0.01677472682786174, 0.01749685878166929, 0.019005721078428905, 0.07210118303191848, 0.10628594478475861, 0.05828706140164286, 0.052939943052479066, 0.015303172294807155, 0.06351579606416635, 0.10012988917878829, 0.03823299179202877, 0.017479191956226714, 0.038731503518647514, 0.04818687681108713, 0.015568094895570539, 0.011220651322219055, 0.020222702260070946, 0.029079516752972268, 0.012934565311297774, 0.029007248267589603, 0.023512800617027096, 0.058611109052435495, 0.03291056098532863, 0.038352644551196136, 0.017663973740127403, 0.03443309178692289, 0.04413512157043442, 0.043161212306586094, 0.03137485706247389, 0.027488550658745226, 0.04348337490228005, 0.032401822463725694, 0.04922226558846887, 0.05597190945991315, 0.012044875893479912, 0.06455711089074612, 0.033223866048501804, 0.03623906733992044, 0.0666811152768787, 0.03485877285129391, 0.03891876222041901, 0.04852750775171444, 0.04471237516554538, 0.0381959363585338, 0.05440425607957877, 0.01592052783962572, 0.04189754261460621, 0.049743750496418215, 0.03745213369256817, 0.05433040496427566, 0.0586499938799534, 0.011636947001534281, 0.021754556291853078, 0.05541341735806782, 0.05855298775713891, 0.031917248270474374, 0.018485503387637436, 0.03792487063037697, 0.05869569162314292, 0.0799169109086506, 0.004506548903009389, 0.06256849650526419, 0.06144074744952377, 0.026513431694183964, 0.04793660977156833, 0.0433811366383452, 0.028972619656997267, 0.016116159822558984, 0.05379188405640889, 0.043959663016721606, 0.044875391613459215, 0.004095576741747209, 0.06832517276052386, 0.03404885224881582, 0.031800252399989404, 0.06503066048026085, 0.01080001315131085, 0.04224874544888735, 0.0969425356015563, 0.02857901607058011, 0.04398528195451945, 0.04874641163041815, 0.02897646769270068, 0.007827361969248159, 0.054783601153758354, 0.04472334410820622, 0.003996508839918533, 0.11191747267730534, 0.18744278408121318, 0.14639300788985565, 0.08335139966220595, 0.10930802949587815, 0.09466615345445462, 0.087479922658531, 0.1366494846297428, 0.08875475425156765, 0.12187313885078765, 0.17542570625664666, 0.16952876409050077, 0.10848722158698365, 0.14003942225826904, 0.14237231895094737, 0.13227280229330063, 0.11648317260551266, 0.08847511300700717, 0.14386442169779912, 0.15415757952723652, 0.19445803889539093, 0.24653189931996167, 0.07631103799212724, 0.2033988106995821, 0.1172591325303074, 0.11609816123382188, 0.09624674246879295, 0.1418548935907893, 0.1410638977540657, 0.07922709948616102, 0.22425231436500326, 0.10270185390254483, 0.14857530797598884, 0.13002005754970014, 0.08253076986875385, 0.20499938575085253, 0.11590800815611146, 0.11903733320650645, 0.17373320879414678, 0.2515209425473586, 0.21291930373990908, 0.17151725973235443, 0.13541769760195166, 0.10751074820291251, 0.14495672949124128, 0.11922212055651471, 0.1674654896487482, 0.12856050539994612, 0.16392963094403967, 0.1759085920639336, 0.1863916209549643, 0.2346717708860524, 0.14366325514856726, 0.15368193708127365, 0.09320332843344659, 0.12705563771305606, 0.14246651233406737, 0.20102616457734257, 0.1718271806021221, 0.17029218171956018, 0.1685584060032852, 0.126903957570903, 0.13622298720292747, 0.1497495043440722, 0.12143302301410586, 0.1709059823770076, 0.22660704504232854, 0.1131637538492214, 0.11307056978694163, 0.10858652836759575, 0.11496300183353014, 0.2073972945800051, 0.051696211157832295, 0.14293286309111863, 0.0935349719657097, 0.20517479977570474, 0.12878879002528265, 0.14035292027983814, 0.08730869434657507, 0.11195928527740762, 0.17939285666216165, 0.11502157954964787, 0.1727615445270203, 0.21799823589390144, 0.19607834023190662, 0.13901230471674353, 0.1460029202280566, 0.13485847448464483, 0.16924248804571107, 0.08514951216056943, 0.10386731519247405, 0.08835000175167806, 0.1757944794371724, 0.1555034494958818, 0.10402335174148902, 0.12945004360517487, 0.15051002759719267, 0.12534181092632934, 0.15195537504041567, 0.17619381425902247, 0.15883400046732277, 0.1200196918216534, 0.15479974506888539, 0.1492702550604008, 0.11567804627702571, 0.15835734870051965, 0.1439677138114348, 0.059645280707627535, 0.19008837727596983, 0.09614832626539283, 0.14488969871308655, 0.12364929119939916, 0.06970786067540757, 0.09094390436075628, 0.18778843194013461, 0.14301461807917804, 0.08330763521371409, 0.11412603736971505, 0.10469057961017825, 0.24600242148153484, 0.11712114501278847, 0.19809125253232196, 0.20671269303420559, 0.10741745281848125, 0.17210576799698174, 0.1299605521489866, 0.08414569805609062, 0.12022647642879747, 0.140015970391687, 0.2005933440523222, 0.07505783258238807, 0.17940452322363853, 0.1158458532881923, 0.15023670945083722, 0.14020155183970928, 0.14426728914259002, 0.11846456589410082, 0.11625407903920859, 0.0908887256809976, 0.14859101182082668, 0.15764748444780707, 0.14415834186365828, 0.151075336325448, 0.07966533026774414, 0.1633003045571968, 0.18951030360767618, 0.21072404575534165, 0.10161256665014662, 0.11473676553578116, 0.3423767688218504, 0.14381873508682474, 0.1800010318402201, 0.15804546856088564, 0.134023884893395, 0.1563698475365527, 0.18888287711888552, 0.10555560467764735, 0.11265282228123397, 0.0976949323376175, 0.1621129276463762, 0.14407756651053205, 0.23271974438102916, 0.17058320750948042, 0.12644798203837126, 0.16731971700210124, 0.18740582512691617, 0.12551251973491162, 0.15751281433040276, 0.12126863730372861, 0.11778996107750572, 0.1026408196776174, 0.12889460544101894, 0.1027933755540289, 0.2611099951900542, 0.13879666628781706, 0.11491821322124451], [0.071652762562735, 0.06597051629796624, 0.013342934853426414, 0.04986791551345959, 0.06634364588535391, 0.07095076507539488, 0.052350559053593315, 0.03968006472859997, 0.03739802741620224, 0.028333678747003432, 0.012618176624528132, 0.06917251987033524, 0.010998593315889593, 0.05628988263197243, 0.07716562104178593, 0.020776774872501846, 0.04264406154106837, 0.03136234445264563, 0.044261279253987595, 0.06504893957753666, 0.04049573326483369, 0.06007715128362179, 0.03191094001522288, 0.004875245549555984, 0.018358061788603663, 0.03145755828882102, 0.026828593981917948, 0.03875513721141033, 0.023236684573930688, 0.0536997241579229, 0.08540800219634548, 0.03407884243642911, 0.05790353432530537, 0.059631372860167176, 0.055729216037434526, 0.017305735345871653, 0.05543356295675039, 0.018569931962701958, 0.04141855679336004, 0.06723098733345978, 0.059501270661712624, 0.03962615141062997, 0.012816531361750094, 0.05011082044802606, 0.05277813630527817, 0.014473587561951717, 0.010363886358391028, 0.030895437084836885, 0.10734199124271981, 0.006244323403734597, 0.019430656284384895, 0.03402107366127893, 0.05842846650921274, 0.06771718311938457, 0.035337688168510795, 0.06561749149113894, 0.009171152996714227, 0.02708763877308229, 0.041881794240907766, 0.035549174281186424, 0.019870130163326394, 0.018160121726396028, 0.026444406394148245, 0.046499429663526826, 0.030400452415051404, 0.08809522987576202, 0.029152610877645202, 0.018872145628847647, 0.03806849847023841, 0.07347362930886447, 0.019792534912994597, 0.04141182922467124, 0.042540146023384295, 0.05461551954795141, 0.06427897620596923, 0.029905356423114426, 0.07737480278592557, 0.054044540811446495, 0.03972876074840315, 0.025318163898191415, 0.09617647592676803, 0.016644756360619795, 0.04497974870901089, 0.028212404395162594, 0.05205270921578631, 0.011654088757495629, 0.0831065651436802, 0.010889617278735386, 0.046429508220171556, 0.09200850778142922, 0.037254232593113557, 0.04174636342213489, 0.07303804799448699, 0.08441972866421565, 0.10331979574402794, 0.05657757617882453, 0.012914651633764151, 0.0073711688946787035, 0.06035944941686466, 0.04743787911138497, 0.05453302612295374, 0.026811283387360163, 0.06643536049523391, 0.025812562271312345, 0.08403003434068523, 0.08732749294722453, 0.010886427899094997, 0.049116257214336656, 0.05896054186450783, 0.06990930181927979, 0.042319305139244534, 0.04634006087144371, 0.07601400822750293, 0.02389111410593614, 0.04874548023508396, 0.027973341930191964, 0.0027171334477316123, 0.03853394009638578, 0.07000014069490135, 0.07439517634338699, 0.06457337134634145, 0.060615727852564305, 0.014916747131792363, 0.06779648902011104, 0.05504697452124674, 0.044546119243022986, 0.03475458644970786, 0.052705480047734454, 0.02536864107241854, 0.049654837494017556, 0.027307691125315614, 0.029476435884134844, 0.03589914515032433, 0.04853862883464899, 0.021269878197927028, 0.06027104478562251, 0.017006314010359347, 0.0578422885882901, 0.045213491830509156, 0.05813096919155214, 0.02980119414132787, 0.0206424442876596, 0.0949954146926757, 0.017413756795576774, 0.03202967993274797, 0.00263250147781946, 0.05465038564580027, 0.05663789423124399, 0.038214775777305476, 0.06237042471184395, 0.043213919634581544, 0.011843512675113743, 0.06397011660737917, 0.011740356931113638, 0.11924029575311579, 0.05275711497233715, 0.04277070904208813, 0.06715466486639343, 0.07924920806544833, 0.04171281834715046, 0.027730346082535107, 0.0781271698360797, 0.06384680877090432, 0.033012309431796893, 0.04021452979941387, 0.07583845319459215, 0.008442654343525646, 0.002020180013460049, 0.028852523464593105, 0.018570115644251928, 0.06547450931975618, 0.025483826102572493, 0.04110612746444531, 0.04116036732739303, 0.008287808941531694, 0.03835929419437889, 0.016472988136229105, 0.017601640756765846, 0.03307367020170204, 0.0742327499028761, 0.05549915396841243, 0.054682502086507156, 0.07687239107326604, 0.029865979922760744, 0.05698783541447483, 0.016756761287979316, 0.012116382749809418, 0.08337295163073577, 0.053137599243200384, 0.01526585896499455, 0.10510539563256316, 0.044187261155457236, 0.03700115281390026, 0.048764709281385876, 0.007811163668520749, 0.04717730364063755, 0.015461928815057036, 0.061407911125570536, 0.028323915794317145, 0.030863949614285957, 0.032693709144950844, 0.009900718487187987, 0.0586134987679543, 0.04139025499171112, 0.01438453911760007, 0.06886581250000745, 0.027747912718041334, 0.054381939698942006, 0.020408816199051216, 0.0437467779556755, 0.03739662846783176, 0.04083712490682956, 0.044413148643798195, 0.07517149992054328, 0.021966669519315474, 0.014398072180483723, 0.04038010294607375, 0.07696664382820018, 0.03103076585830422, 0.016567628663324285, 0.03307637161924504, 0.031163923849817365, 0.04082546576682944, 0.03554415736289229, 0.06719007273204625, 0.058531881077215075, 0.026800373816513456, 0.04000418288342189, 0.04796526409336366, 0.0471419254608918, 0.00474735727038933, 0.06543460403918289, 0.017841274675447494, 0.0645339633047115, 0.11132179526612163, 0.08591981692006811, 0.03872978544677608, 0.021936133853159845, 0.059024604051955976, 0.04545889038126916, 0.00977100498857908, 0.05629298109852243, 0.016532051959075034, 0.031176607153611258, 0.04654662283428479, 0.058129885655944236, 0.02924618085671682, 0.02659102508914657, 0.006065580846552621, 0.05725065217120573, 0.05363782533095218, 0.03800177939410787, 0.026638463168637827, 0.030408322891162243, 0.037432782191899605, 0.015529684114881093, 0.08603828595369123, 0.03145531329209916, 0.019031555239052977, 0.0557792627660092, 0.05404848161560949, 0.0274910795269534, 0.049805029630078934, 0.04811040962522384, 0.028303217295615468, 0.019064705120399594, 0.04367270419606939, 0.05566382911638357, 0.05061162170022726, 0.1316896968637593, 0.13750773388892412, 0.04390343790873885, 0.025106657376454677, 0.01766676050465321, 0.05676275315636303, 0.015224102025968023, 0.01569020787428599, 0.02966090411064215, 0.042604445698088966, 0.015055923013278516, 0.023317148225032724, 0.03626127610914409, 0.012037384840368759, 0.016884208453120664, 0.07936121299280785, 0.06895938990055583, 0.022347127815010026, 0.047596338772564195, 0.03981212248618249, 0.02031568408710882, 0.048774576134746894, 0.061118239755160175, 0.04152500303462148, 0.051340280842850916, 0.09784276073332876, 0.019926858076360077, 0.04590230506437365, 0.025568380842742044, 0.003399376123525144, 0.07878584074205719, 0.027860322115884628, 0.025821768613241147, 0.02831307858286891, 0.04027827286336105, 0.007271847734955372, 0.05179811174457427, 0.024508399146725424, 0.05313209621817805, 0.03625171724706888, 0.07374305117991753, 0.020796039170818403, 0.04398738223244436, 0.011131908086099429, 0.044312817699392326, 0.03795807060669176, 0.05854664610524196, 0.039347693891613744, 0.03976047271862626, 0.018747466674540192, 0.052298630980658345, 0.076437685493147, 0.06509326805826277, 0.00909322563529713, 0.034841948363464326, 0.03558652657375205, 0.01790875816368498, 0.0290857507934561, 0.07591286834212951, 0.07306639803573489, 0.022259552533796523, 0.045020492616458796, 0.04175497233518399, 0.036241048874217086, 0.066035194467986, 0.021847220850759186, 0.07592146241222508, 0.022040014118829276, 0.0637807724706363, 0.043947165249846876, 0.03218876299797557, 0.08578067907365039, 0.07940782728837803, 0.01266700901396689, 0.03486083973257337, 0.014345994750328828, 0.05582315337960608, 0.09406507320818491, 0.026279840712959412, 0.047823948043514974, 0.0943433860084042, 0.021071255359856877, 0.03393752638658043, 0.12098806837457232, 0.19925312924897298, 0.10287079639965668, 0.10075246944325045, 0.16338753659510985, 0.13079721975373104, 0.11262981570325792, 0.23022226901957765, 0.13655717630172148, 0.0826059197424911, 0.17132456850958988, 0.2580310619669035, 0.11518497820361517, 0.1869056621217169, 0.14160058926790953, 0.10637710278388113, 0.15552577329799533, 0.13220813154475763, 0.192243633500766, 0.17108065425418317, 0.13644815480802208, 0.3051447932375595, 0.1437589031411335, 0.12910850724438205, 0.09244456407031976, 0.08834745618514717, 0.15334442316088825, 0.12472535338019952, 0.1012126232672017, 0.12565254815854132, 0.10046386305475608, 0.15470978192752227, 0.13270979368826374, 0.19607047346653417, 0.056754285251372494, 0.12505559425335377, 0.15489577897824347, 0.11255122226430103, 0.16548533574678004, 0.15041167818708345, 0.12895316089270636, 0.1449425841565244, 0.09833044081460685, 0.12389634473947808, 0.20868680585408583, 0.14477816876024008, 0.12281177754630335, 0.0673382128297817, 0.21439249656395987, 0.17491003236500546, 0.10089161471114494, 0.1324159328942187, 0.07723418806563132, 0.19442229706328362, 0.07646680736797862, 0.13373447698540986, 0.14915850246325135, 0.17274548445129767, 0.2350725603173487, 0.18021960917394608, 0.14242805424146354, 0.15487250522710383, 0.17618244455661625, 0.1345356402453035, 0.16371604084270075, 0.11227697643334977, 0.10781893986859359, 0.11315314855892211, 0.12740373465931043, 0.15127662161830813, 0.09006113454233855, 0.1280705098179169, 0.13196837331634015, 0.1373538569896482, 0.2009702957002446, 0.13251109106931835, 0.12463907129131258, 0.12746748514473438, 0.12994996912311763, 0.09925365025992505, 0.23345666733803228, 0.08922241861000657, 0.0944349892961327, 0.11710364517057315, 0.15587424131808802, 0.0879146801889874, 0.1261899818200618, 0.06561766960658133, 0.09164556046016514, 0.1692537241615355, 0.14315577456727624, 0.12956745136762038, 0.15301863517379388, 0.15479457972105592, 0.28004984138533473, 0.12778312055161223, 0.07057723472826183, 0.12016313412459567, 0.08829098616843112, 0.16798257362097502, 0.11481782290502451, 0.14589331985916942, 0.18598562164697796, 0.14490807428956032, 0.14754819043446332, 0.1776745918323286, 0.16448423790279776, 0.28742224734742194, 0.11234297562623397, 0.16388431540690362, 0.15314815478632227, 0.09768755538971163, 0.09285552834626287, 0.09890825473121367, 0.08910276956157759, 0.1495408866321668, 0.14794850489124656, 0.11592213122639805, 0.24026440281886607, 0.1256335194921121, 0.10289049299899489, 0.1669108826899901, 0.08490640684613027, 0.12619753688341007, 0.08437469514319673, 0.19786860822932795, 0.12963408138602972, 0.19289537274744362, 0.1125226124713663, 0.18093419348588213, 0.13335702067706734, 0.13240956526715308, 0.18403978465357795, 0.11309310139040463, 0.08020835972274654, 0.13312731112819165, 0.14642576628830284, 0.16255984897725284, 0.12454744573915377, 0.23305316164623946, 0.1009664306184277, 0.13013752468395978, 0.17598868464119732, 0.14713558601215482, 0.15110284031834453, 0.1421933129313402, 0.11627398343989626, 0.1817542963544838, 0.10763646801933646, 0.11285626722383313, 0.1286472476203926, 0.10911855177255347, 0.15670446708099917, 0.08207580365706235, 0.1935137895634398, 0.2150902638095431, 0.10735508272773586, 0.15183287614490837, 0.20715133199701086, 0.11998472924460657, 0.12490501248976216, 0.14933688507881016, 0.1630809553898871, 0.10596416439511813, 0.1462198351509869, 0.20453250064747408, 0.040953486241050996, 0.11990462182438932, 0.0783788098488003, 0.13225650473032147, 0.20306319667724892, 0.1325896251364611, 0.07541705432231538, 0.14873878826620057, 0.13555263489251956, 0.12792513793101534], [0.03190158895449713, 0.042453043861314654, 0.06762403616448864, 0.037084974683239125, 0.05000727229344193, 0.005850845054737874, 0.027887173018825706, 0.07079719987814315, 0.03979744280513842, 0.029049437507637776, 0.05157837666047271, 0.048617496868246235, 0.013096858165226877, 0.018187295463576447, 0.017821386973082554, 0.06105284170189407, 0.046796259048278444, 0.02082674367557047, 0.08878556080162525, 0.018493249554012436, 0.07798537510097958, 0.025161392622976564, 0.026429639510752168, 0.03585051221307367, 0.011401265019230777, 0.033843982382677495, 0.01722701759717893, 0.015865460482018534, 0.04476177622564137, 0.022864959501021076, 0.01765221997629851, 0.04158892421401106, 0.009928749404934933, 0.033530888831592165, 0.09315028713899665, 0.03393294362467714, 0.015771797734487336, 0.021889488016313408, 0.03597623574023601, 0.0318351333407918, 0.049717185320332646, 0.04047415903187357, 0.02282917128468398, 0.0029712021387240384, 0.08304480361402966, 0.0858594877354335, 0.03199143706297036, 0.024106429700623266, 0.07331891378271393, 0.0900367995200213, 0.025346821930725127, 0.01368869588986854, 0.01831978552218061, 0.025241689290851355, 0.041273188617196865, 0.03482802567305043, 0.010533842814766103, 0.04150422661041375, 0.020549011605908163, 0.08338318584719673, 0.0055908971626195125, 0.061713520117336884, 0.04552776910713874, 0.06090159571613185, 0.021573268168140203, 0.013075366496195784, 0.04735930051538162, 0.03535195966833271, 0.02776849618385313, 0.02726419384998735, 0.0798380131891463, 0.07559601581306197, 0.045668194579775445, 0.036107744308537804, 0.11162436887389049, 0.009052294335560873, 0.04911506606731564, 0.08895874838344753, 0.036736985348397866, 0.0533210024877917, 0.021869733900530264, 0.02333129355974961, 0.07716625928878784, 0.03639780159574002, 0.012823228316847235, 0.04153956768277567, 0.08002961345482618, 0.02309381372469943, 0.027140398051415104, 0.0593739292526152, 0.007435014931616024, 0.009822625070228241, 0.04457125578483101, 0.05810958049551118, 0.005402706601671525, 0.024287196465593297, 0.09344440026325174, 0.044558568770298734, 0.013002486666664481, 0.02107789201545529, 0.04130127148528118, 0.03542673475749325, 0.02113963128067553, 0.015747993347758893, 0.08151725589414127, 0.05793135744170286, 0.06802513729780912, 0.015007847614469938, 0.03735297163075302, 0.025867323493002914, 0.0004342515364896826, 0.0439425565127749, 0.017130263804574497, 0.016720601997803897, 0.06933343975106254, 0.031470783360418864, 0.06864396971650422, 0.03515468939440325, 0.10569216727162711, 0.047811082913540304, 0.04089556161488872, 0.03089625530265039, 0.02568975352915004, 0.02321370026038494, 0.03594805268221535, 0.025918151332007255, 0.018746446221484803, 0.040814812236931175, 0.08727214357350022, 0.07487625131034292, 0.014052265687496401, 0.07321673489059322, 0.02468446811690228, 0.03589826941606589, 0.009318093598267296, 0.05085505355964415, 0.03457542828982696, 0.0785770226502791, 0.01760315844876459, 0.034289241302758455, 0.04631771480489988, 0.0936339893087279, 0.07728181168204173, 0.03702518355567008, 0.02577880568424007, 0.06223251883056946, 0.04858212610997725, 0.03937992165447213, 0.07179238280514255, 0.07822196435881779, 0.060786384710809216, 0.03072359279030934, 0.059503623269847594, 0.03676275271573104, 0.008691649527463596, 0.02432658595353132, 0.05220928382186685, 0.00980123915724107, 0.046982879503048025, 0.03583429257560056, 0.03089943540544482, 0.014573873977496987, 0.01871100495918654, 0.047370095053338446, 0.060377346308087, 0.0656881216855254, 0.01782333325536456, 0.04984717248589732, 0.042422827318659984, 0.09009558503748849, 0.037827704945812, 0.02307937895238865, 0.04393723531393334, 0.05608561019471381, 0.06928678092663176, 0.02339420170756057, 0.008209461338992696, 0.00839332378745894, 0.03052944695809856, 0.026567554668872617, 0.018034880595223513, 0.04667152628826443, 0.07132143815397285, 0.055024108951329254, 0.037419482905534096, 0.03907938895281404, 0.014240195105230669, 0.054108599288156256, 0.02110450357577065, 0.07943601405713707, 0.008351290398422861, 0.06785795369069092, 0.04380405691335909, 0.02691815450816648, 0.03871680899464991, 0.022193549630173948, 0.04135152601520531, 0.01510508380306419, 0.10399598133517429, 0.011563210919121047, 0.032180732960114256, 0.05454779115098063, 0.026399085290904623, 0.005550262721953914, 0.06577449283213355, 0.014330117428471567, 0.01935895183123648, 0.05587175292021129, 0.02855459755664924, 0.0172993064916227, 0.012127348909416469, 0.046408082416746765, 0.01352003077045083, 0.032205910320044495, 0.021615950936393347, 0.012605823576450348, 0.03371228085597977, 0.024802536390780006, 0.025997598240792286, 0.0233257627041894, 0.06919633538927883, 0.019574319376260974, 0.024831135051499587, 0.020099826724617742, 0.015842622742638923, 0.030217895218811464, 0.004316017793826177, 0.019298130973766092, 0.015715131048636977, 0.011003793915733695, 0.031054605497047305, 0.02125758823240176, 0.05749889685830567, 0.04399376470246352, 0.02860546806914499, 0.0777664192719385, 0.046423860476352274, 0.03588857696740888, 0.03737930303032044, 0.023224769392982125, 0.07145988580305129, 0.04442641824425664, 0.02318762675713515, 0.05059590301243588, 0.056157468643505126, 0.03307994506030809, 0.050321026355959475, 0.03612933709518984, 0.10110228075063787, 0.04377013705379795, 0.05440969602204859, 0.02678937147720717, 0.04721295270428527, 0.03652837134723086, 0.07473663848941214, 0.12963175104232505, 0.11863217994687147, 0.056126068375306204, 0.07194594058091752, 0.03548301552655175, 0.03807296248851344, 0.03221383645723108, 0.03439218089624774, 0.03330645966343582, 0.02045062508841511, 0.025360935724165756, 0.03906281308445614, 0.015244787537085358, 0.004277430753063527, 0.016563222161494195, 0.030223370413295925, 0.06597254236112349, 0.04165582882706076, 0.027387642694520764, 0.028756198262271937, 0.00883986383996671, 0.1104177332308609, 0.07424674680805765, 0.007928250452096108, 0.03997767707915045, 0.07111474260454997, 0.023184799174487125, 0.028933361900271848, 0.018331544852117077, 0.000608595013318336, 0.03390641926671378, 0.03959003108320758, 0.04734957095934078, 0.04453870889847167, 0.018030950923275668, 0.07462230321834795, 0.018124062626156956, 0.029092094300722238, 0.07143563241697848, 0.04169393811025657, 0.041122191250906326, 0.07325231345021166, 0.04460251875570975, 0.055828285330790095, 0.029585637348645832, 0.037933193816570565, 0.027874697516381275, 0.03897794849763159, 0.006802426805734285, 0.044019999622832984, 0.0181515183794545, 0.03287625891971402, 0.07064592791721225, 0.03263847109337803, 0.011328904693073127, 0.01944207979249768, 0.047278621641453356, 0.04423341160872951, 0.07131051374017261, 0.12335456209257245, 0.045629268934135325, 0.025137653174169827, 0.05113759289088193, 0.06348446258925833, 0.022819536352471914, 0.010537693633523304, 0.037359175985329784, 0.020312466876930557, 0.052348655444802716, 0.04027618000691291, 0.038570420365431346, 0.07015289695118554, 0.04590867269143928, 0.012505842369137099, 0.009533875818306115, 0.017552124663779978, 0.062351447995752096, 0.05138292835908942, 0.04472122898732778, 0.004260364603396738, 0.04213148611597717, 0.023254204825207125, 0.043472287215990946, 0.015270900003088173, 0.04241778442519717, 0.04370529190055095, 0.03552781156031415, 0.010932147906714818, 0.01881191106804181, 0.04548888799035922, 0.04754616958962288, 0.015581720726913773, 0.009888197528198361, 0.056878925242926925, 0.04098438555956818, 0.050993701588595286, 0.010110798230016371, 0.1182656035234686, 0.14278847083915025, 0.2417018241249025, 0.13977447553770617, 0.09743005983182229, 0.12156238677562214, 0.2134370111161843, 0.08679097212734632, 0.17287604307057336, 0.3036402817815542, 0.27927382208872586, 0.17258740699617192, 0.09835925840889104, 0.16906824661418796, 0.11950209576752968, 0.17585226305527613, 0.08301915499032475, 0.14770309149753302, 0.09466302159125917, 0.10651236661942676, 0.2709047117969021, 0.17545917711686343, 0.2815677411854267, 0.08423621780821122, 0.12291756327613257, 0.17557023209519684, 0.05118734647112433, 0.12238545823493041, 0.1187056303024292, 0.10580671034404077, 0.1266037588356994, 0.12445871456293389, 0.12858895934186876, 0.1727513622608967, 0.19335833931108937, 0.21524972165934741, 0.10649597257724963, 0.08828343852655962, 0.1047570092487149, 0.10735334610217251, 0.10856544395210221, 0.07108481178875081, 0.16568564140470698, 0.0755563034908846, 0.1942057829000987, 0.1313954353099689, 0.08476568822516128, 0.09768597461516038, 0.18446347676217556, 0.2311957738129422, 0.09018755197757855, 0.05693568840797525, 0.11326699401251972, 0.1801025279564783, 0.13520363252609968, 0.17825263581471518, 0.13799341017147526, 0.17239624459762126, 0.1129986482555978, 0.11510956115671434, 0.17486636439571157, 0.13713345397263765, 0.09539870516164228, 0.14866890764096752, 0.13420548842987046, 0.1308288352447562, 0.16605880809947848, 0.11380856885807589, 0.16427628812380135, 0.2031077552237548, 0.15663072728784755, 0.17624874803004786, 0.26825568987987936, 0.10352790137403645, 0.21665831794962287, 0.07113757106708363, 0.16787230531917885, 0.13103694829624146, 0.19816355255898088, 0.16767743218224496, 0.14688010909594595, 0.22630433784797788, 0.17702503449982032, 0.09520185049041174, 0.07656208428670652, 0.1527312459074892, 0.21585296897683293, 0.09754040234838612, 0.12793254456482828, 0.1745304832002148, 0.13922856654971838, 0.06755336144124158, 0.11667696962831542, 0.17395356728229672, 0.06667436173302121, 0.08781801545410417, 0.21038242033682764, 0.12217361218063161, 0.11170509969815612, 0.11004743864759803, 0.1811134666786529, 0.1536746195051819, 0.08302069865749218, 0.09950278923497535, 0.1222345870337449, 0.150651688745711, 0.1410451511037536, 0.17018602491589263, 0.14024723845068365, 0.09827914356719702, 0.10336465857108124, 0.17772050108760595, 0.12443529980373569, 0.11603147926507518, 0.1613896305207163, 0.09257288882508874, 0.08551450780942105, 0.12019180328934453, 0.17752080399077386, 0.11212310695555061, 0.0948218115081545, 0.10806438294821419, 0.2264415312674828, 0.16663710441207513, 0.13041960017289966, 0.07837714743800461, 0.144424342433922, 0.12004214921034873, 0.10342328081605956, 0.19016084057511762, 0.09510704112472013, 0.17966575920581818, 0.09180009787087329, 0.14126331283478066, 0.0990002290927805, 0.12450702837668359, 0.10710758389905095, 0.14468489564023912, 0.21208627265878022, 0.15203571994788945, 0.12455479300115258, 0.2257088088663295, 0.2532636537216604, 0.14849891129415482, 0.07783663386362605, 0.14157406490994617, 0.2016477132565342, 0.16892493789782748, 0.12653030105866492, 0.16576165216974914, 0.21213479427387938, 0.11661630647722632, 0.13083389669191092, 0.17997078190091997, 0.06461790020694025, 0.11682061973260716, 0.18916919769253582, 0.2083714524633251, 0.12348734715487808, 0.09876858995994553, 0.0739724341838155, 0.11623020414845087, 0.07351386855589226, 0.15990595857147127, 0.11931667759199627, 0.13268732145661488, 0.051341427461011335, 0.10665668465662748, 0.11761577901779674, 0.13717149646254256, 0.11977692047366872, 0.08921482643927447, 0.11318955090246163, 0.09776455321116373, 0.1307888186420314, 0.12206871702801436], [0.03398861954337917, 0.05725391019950621, 0.04088589885213878, 0.028369207211653702, 0.06507658457849175, 0.07970194783410989, 0.018444291927153245, 0.07421144284307957, 0.035385118826525286, 0.0760867609642446, 0.028001858954667114, 0.04978658354957588, 0.06412689530407079, 0.04326965492509771, 0.02604640929348534, 0.041451923752902076, 0.04196304827928543, 0.019724331541510765, 0.03689564538944978, 0.010655531841621269, 0.02404211147222668, 0.05746207891206723, 0.07332177105126902, 0.055176635141833685, 0.08830863444018178, 0.05025583981478121, 0.07597229952807538, 0.033309394857496955, 0.0399480097257765, 0.01859574200352654, 0.018991421748069115, 0.07144031536881812, 0.038548011216335, 0.05660767026711255, 0.01799951911380049, 0.0254107227010536, 0.018164385364798363, 0.06026565308275167, 0.07334274414461106, 0.0304777155542979, 0.019912799943995196, 0.0508086099580396, 0.055542276459163986, 0.04619753883162048, 0.04591944867570419, 0.04507410165388137, 0.014834698995400686, 0.04620219209755305, 0.006818322681283462, 0.0430326463538222, 0.002397972143626248, 0.06448714862926863, 0.02772777825157391, 0.015024884542071959, 0.04416688178025652, 0.0734566267055925, 0.05170768105017487, 0.03877628470945638, 0.044508889404824004, 0.046320787296281196, 0.011603339771681931, 0.041677158151287585, 0.018239017590531148, 0.02072274095553439, 0.03481712352368049, 0.00717318198439898, 0.039130344812292606, 0.023944904969539493, 0.04931022864184342, 0.02674396502698073, 0.020696134961326607, 0.006449450702348258, 0.0669265806209296, 0.07894787384429947, 0.012287984918657457, 0.030326964952109847, 0.06819476999226026, 0.08352856515557505, 0.015544335037702695, 0.04174771413090639, 0.01991192049899837, 0.03635025590483565, 0.02661178481503157, 0.05541533580981195, 0.011383606542949565, 0.024854473740560934, 0.028843873733421788, 0.018769306225294713, 0.016404742091253866, 0.04598505453031976, 0.052408120027394034, 0.1044791194726713, 0.028534394441521727, 0.033798585209297016, 0.010921496232185746, 0.06744258847902529, 0.07659683906240389, 0.01293883544349228, 0.06610310840187594, 0.014705706307722721, 0.053663028666051105, 0.06838032917585224, 0.029288004589034244, 0.02574769485363504, 0.011940889871766558, 0.04613163611793425, 0.04529241181444377, 0.026656050213205162, 0.01302728367591044, 0.02433689067402156, 0.013672453060280532, 0.02959484925668221, 0.03950946353143081, 0.01978966836759355, 0.10304112671292387, 0.04670329763030168, 0.022090862366894726, 0.024512646086805034, 0.09142748778685927, 0.033564615732757375, 0.017433911671105307, 0.03237081924453378, 0.04339362327300478, 0.03483188855170738, 0.011338155563862529, 0.041536684439051896, 0.0023732788031338714, 0.140603884938173, 0.025464810423727613, 0.04680395511968527, 0.05080411254311912, 0.03001637800480239, 0.011067193736380432, 0.04368647474620957, 0.03306788516056258, 0.00992938301351387, 0.060808979396824725, 0.04285418581275735, 0.023662616113142576, 0.07798153819749132, 0.07705690382863395, 0.05916453599638771, 0.0320960019598715, 0.039915332963573746, 0.11643873280263506, 0.03592617045796942, 0.024793001648504287, 0.023180266507552005, 0.0070393606983998325, 0.0077798742586310254, 0.06927529990207404, 0.060290815599728376, 0.06955678909434937, 0.06560611436725594, 0.06330134507152252, 0.031947201350703835, 0.036740703508257866, 0.021393134084064513, 0.02343123673199443, 0.05056046175013762, 0.031520451593678445, 0.02777380996121792, 0.01312949967541499, 0.025055343430722132, 0.018418218423903454, 0.030887841203366406, 0.014418192731682211, 0.0593546519667143, 0.07797759739332832, 0.015890020004007965, 0.026007786073023453, 0.05664023199642543, 0.06038062660081778, 0.05200453269935679, 0.04221093673550058, 0.039636563742533326, 0.015166664434218546, 0.06605756279896013, 0.01689535922196228, 0.0821805874875281, 0.021404275576060172, 0.012654844285862055, 0.005190391138967243, 0.012009809415758355, 0.027072257762483787, 0.037369124474935234, 0.0831175860366784, 0.02065785683953436, 0.062027244493947364, 0.04553680104436353, 0.0040379216079600155, 0.028558861195051577, 0.08597680644015782, 0.02334573018742958, 0.06417132768547162, 0.008415259817411425, 0.052419092680793256, 0.04801276154466905, 0.08219369381549768, 0.032416075409855694, 0.010797460163303185, 0.07301601362996735, 0.054324905649991706, 0.03380936490430031, 0.010087680329888826, 0.015710988009232096, 0.012264696324564284, 0.05381987044529524, 0.009442546197533375, 0.012887780321761966, 0.008933405060815858, 0.05105552620079834, 0.10570237922365777, 0.05208397960814182, 0.03244871135393623, 0.03909371611371171, 0.052934799969079904, 0.00813251454019337, 0.03496266981528606, 0.055803961440688, 0.08435551804723218, 0.02041103522060439, 0.08707149652764201, 0.05053332512034103, 0.022781389961892273, 0.038896182377357036, 0.028487570489232894, 0.049583353829802945, 0.02847386487701442, 0.03215118435036857, 0.02581522101536393, 0.06538117682794109, 0.06253913714317605, 0.015332211605709745, 0.043098452588310465, 0.050873158252215944, 0.05612698492768686, 0.030393409433600027, 0.02636213190271519, 0.03166613889334258, 0.04927993788442109, 0.039373023391817696, 0.05307854284183122, 0.07004670304013416, 0.011116657879028935, 0.009326020663138479, 0.04897144564893097, 0.04408686341776047, 0.05008380256185774, 0.07665898650884628, 0.0644001095497515, 0.04301918379496783, 0.07421910922857933, 0.07527171954279765, 0.04109877278096974, 0.01241050886164885, 0.018987924377142917, 0.10867674383916892, 0.017169347156595904, 0.030028857217985205, 0.04587215902574826, 0.032061132151284255, 0.04522253861068748, 0.028469807184592355, 0.026746174771687947, 0.017258330663025845, 0.035285507765365764, 0.020440518892428372, 0.002547432800383831, 0.04406770858622622, 0.0459159049205482, 0.03257619006035384, 0.013875576096324949, 0.029859877613489516, 0.06395385615178384, 0.03409450175240636, 0.0549313219380565, 0.07694124011322856, 0.01484220303609618, 0.041958105575758964, 0.046247340651461855, 0.02428119991236599, 0.04065173641720321, 0.015049611974973232, 0.03183794236974791, 0.04877496205153875, 0.01359128251351649, 0.025338420819025487, 0.031524652149528265, 0.03366127304616384, 0.09277852310333401, 0.02348074169276515, 0.018284667094121687, 0.020473811637202743, 0.06547789351316169, 0.046649521609651856, 0.01913675467221765, 0.021569401578744873, 0.06554219318786636, 0.024347915277758148, 0.018218745826743543, 0.03440079352003522, 0.03892537104547955, 0.10948409661068581, 0.08231243002228439, 0.029175281633797567, 0.03632434752944391, 0.002201805582444649, 0.01903587453853106, 0.00991079221421387, 0.03400885048904456, 0.043171724828425795, 0.020150747332081664, 0.03319754949188791, 0.04154939371801447, 0.12949596770340577, 0.05295801434840541, 0.039897039023344405, 0.057351658469997346, 0.038420246783061884, 0.014163388386805309, 0.015295069897547364, 0.028733872604789212, 0.03419500710151624, 0.00532279167600791, 0.03181738116836641, 0.031941405177349225, 0.03970698242483195, 0.05185727946809493, 0.029074898739054333, 0.08324424095917493, 0.052872556043439545, 0.021491151383088436, 0.00761449917263235, 0.08114020034554414, 0.01033538881529239, 0.06676905977656133, 0.021885077803744934, 0.01578270359459566, 0.06554516177857295, 0.02632135830936022, 0.04752759363327641, 0.04222594296152238, 0.06863688220619224, 0.06857315398519859, 0.04181325690296944, 0.03675642219604924, 0.06046701630111784, 0.07253178453538567, 0.06703606966766529, 0.013150680570106488, 0.004378600324344006, 0.15761935705086216, 0.17804342438466847, 0.10007204618887044, 0.1492791311466135, 0.06694343479466625, 0.1133271525031887, 0.1114903370034881, 0.1454343312070705, 0.1263309601927176, 0.15600566082866862, 0.14835822978056967, 0.16399669140810147, 0.16665626666508615, 0.1402569012134336, 0.07921523254481144, 0.14551742206094787, 0.18730280018644407, 0.1315794137190096, 0.1437175803584978, 0.06317897976259701, 0.1062975668173749, 0.15483398776268587, 0.16666820039972663, 0.06814530584961176, 0.1663135873968713, 0.12710181414149702, 0.13192207814427093, 0.16003308846848086, 0.10739055738667957, 0.1666727423435077, 0.0875765057571698, 0.1317693293094635, 0.07630461841472425, 0.09424206058611162, 0.10922342466074042, 0.15480548929190263, 0.19392557762330398, 0.13487650867318735, 0.19252799480454996, 0.15514742641244084, 0.18827829393558204, 0.15744750533485785, 0.15652237372705713, 0.16545682243304327, 0.2504133910406381, 0.13757617474766448, 0.17551797005580738, 0.18405250506475568, 0.1748236463754438, 0.07648801052710041, 0.1947395651950501, 0.15262403525412083, 0.09895732553559355, 0.10228053666651249, 0.21447157982038334, 0.14629271405283362, 0.08968649097369052, 0.11347637613653205, 0.130843173537869, 0.19847130635753274, 0.10162012171349488, 0.16212714719586074, 0.08269157100585289, 0.17247586220037192, 0.13673109118826687, 0.12110461524571292, 0.17671894311206415, 0.16391897370340303, 0.18086506985127926, 0.21367580455262214, 0.10766099600004964, 0.13954706664662808, 0.14117204351350665, 0.14590875653084368, 0.1519818400265649, 0.11250815543462522, 0.1541632495354861, 0.1371191453654319, 0.1093942225270439, 0.169197840441484, 0.10876679603825323, 0.18996166298165917, 0.08947701979195699, 0.1360323146218434, 0.18723685294389725, 0.19711083092261106, 0.16875068162335083, 0.1378342937096022, 0.11411809638957493, 0.14762442384380847, 0.15559060731902719, 0.19530028745066375, 0.1246380916563794, 0.12987015856197104, 0.0773723165912088, 0.13454850908601657, 0.14608555095037445, 0.08433009206783026, 0.13624390092445537, 0.1899975087144412, 0.12148938170867041, 0.17377307696733624, 0.20138300402322784, 0.10038546257419512, 0.08186528604710475, 0.13729212514590472, 0.12651612603804097, 0.10710092683439143, 0.10207108774920925, 0.2073601129814051, 0.07307017556740902, 0.13661346078151837, 0.13477229629643261, 0.1898989811888896, 0.1830716381664388, 0.09669876235420816, 0.07726946234470233, 0.12193539761938155, 0.21578421641606838, 0.1337009170674719, 0.12075618433300406, 0.09365896257804707, 0.13360892044147477, 0.11848090056446381, 0.038421990830102004, 0.1175340537156444, 0.0816784132621251, 0.27719373058062047, 0.12435162265319377, 0.14635633095167577, 0.15099950367584825, 0.13638351374538615, 0.09148504876065999, 0.1556210799026303, 0.09510026531643234, 0.21754971152404323, 0.1360329973977059, 0.13915896794060245, 0.06938990234630182, 0.15521813824307173, 0.18615161039633676, 0.12052711303113028, 0.10690802781027742, 0.16329104255419225, 0.19551139877876267, 0.0984397369029466, 0.16573791828704998, 0.0766334195213858, 0.09598131335224025, 0.1535387322655879, 0.17735021392581984, 0.15874390373937786, 0.11536624777363613, 0.13594913471024483, 0.2239802578696981, 0.1501743690459989, 0.1782640945748426, 0.08694225150975399, 0.29359667852986604, 0.09005079642520286, 0.11438758505391888, 0.12764701066771522, 0.22090579237556085, 0.11290645867120475, 0.11281850675004534, 0.17085553117794916, 0.08624970898381434, 0.1753296871902421, 0.15856186975724995, 0.10925716269412078, 0.14616472326451913, 0.11332612833939493, 0.21215126995230094, 0.13859674654668197, 0.13606942200567573, 0.17865406349301338], [0.04357196878117975, 0.05864013815880753, 0.019313786579004955, 0.06201583026268054, 0.03233115887269378, 0.02075358646834502, 0.03903364297002554, 0.0059097405028296635, 0.03322048927657306, 0.0328944118518848, 0.03506796943838708, 0.055786250086384825, 0.0455700492602773, 0.019138864226988517, 0.05370080398279242, 0.011561776718735928, 0.04259067885868717, 0.014214419388736133, 0.0480504403822124, 0.03009736301464727, 0.03935724904295057, 0.07759610380162485, 0.030969705658208113, 0.03610538798966445, 0.056522716622566804, 0.02250952456961386, 0.029626266223203856, 0.02212141473137308, 0.03899142589943949, 0.010146560471184785, 0.06272290775086731, 0.08428328481386416, 0.039851341280154884, 0.012631324698304525, 0.008596884690632578, 0.01689730921498267, 0.030340284647536464, 0.045210909156594425, 0.06129549801698886, 0.03600998119509313, 0.035832051289617084, 0.037056721121189184, 0.04039811115944758, 0.036740781433763914, 0.07235259297885932, 0.04417809934238903, 0.048634217455401085, 0.028221779575687833, 0.04752432447276078, 0.01936872591613792, 0.02556453095166944, 0.023973459101398475, 0.04483223943680059, 0.01037853264278965, 0.010455369974806672, 0.07243836298584938, 0.022406217613024637, 0.06351451214868575, 0.002731446229518042, 0.04383181694720406, 0.0034539216585471877, 0.0350288137269672, 0.06945545625058003, 0.07010973364231177, 0.031819384967093356, 0.0914985038980376, 0.05385682939959224, 0.03319907089462504, 0.005093846539239166, 0.03902883756381925, 0.0019767356161537464, 0.04334963989094831, 0.032598684556433, 0.027143140287080314, 0.044712905801134184, 0.05907474354899023, 0.037571166758425534, 0.05334072877303697, 0.03909213162842207, 0.04161376760748681, 0.06986079504713416, 0.04757055656227749, 0.04430011584190652, 0.030889381159795448, 0.02428564908768749, 0.010134239892067853, 0.025493574212305248, 0.0034955301680383855, 0.04376700147986412, 0.07718223030678928, 0.043671423991327174, 0.027321118432155345, 0.02581336008006474, 0.020462805587158073, 0.0631543256167788, 0.012255438959982712, 0.022427318726840895, 0.03634564716776367, 0.06993195958784781, 0.07536031713243574, 0.04881510481936857, 0.03317650960525498, 0.0349662692315178, 0.01629540518479189, 0.024307310522999614, 0.010689532409742242, 0.017501022230135277, 0.06448092201026157, 0.03936358327337075, 0.07700994814513251, 0.0429552069545025, 0.01423274950866471, 0.02090262085403083, 0.043921572287217714, 0.061580263791256584, 0.02421771288936725, 0.018556064933363814, 0.014202179518179037, 0.026879139804805163, 0.01947256165294675, 0.03131782672426198, 0.007473945679521421, 0.04471705440664664, 0.02360050391871482, 0.05553077317017596, 0.054641476162942126, 0.024043066987360362, 0.039889383770059794, 0.06610798431211151, 0.03177322338160593, 0.05913892819080502, 0.07400725575280376, 0.022872666704643052, 0.006335767129712622, 0.09414535132236779, 0.04380285092338454, 0.02985391445690766, 0.06126319232862443, 0.03578264280804433, 0.09276762837544084, 0.029418474150588736, 0.06583318187040277, 0.04571793331706431, 0.022635314890067093, 0.06791301362682134, 0.024054258574324194, 0.015398627328977454, 0.017078896053135395, 0.0094772211923555, 0.053032436917419545, 0.03161145745252725, 0.08794073699391447, 0.040952829440357164, 0.018728076211118605, 0.029525356403610203, 0.01846489580202615, 0.055627745896345004, 0.025144224891846534, 0.043413609309936874, 0.05777253783890046, 0.05247516935924068, 0.021504498909052927, 0.038196377936401404, 0.01953196871909313, 0.014392840039363364, 0.039513222509413026, 0.03883636156388093, 0.020505712855083402, 0.034111997883883305, 0.0817182294849772, 0.05101980292238295, 0.015272168147930643, 0.005846735411978443, 0.029954961573821492, 0.007698195804550778, 0.01605670080607524, 0.018356249092903454, 0.04605405942129437, 0.04659173057007138, 0.02916622001066571, 0.039476738529629074, 0.06360799307003617, 0.03498816629871726, 0.07191506723756902, 0.020063901210960466, 0.014884153861203231, 0.03393340375623666, 0.04357893754786346, 0.05760401465522591, 0.02541569137974875, 0.045374356050160713, 0.0388552677759435, 0.07128931800252758, 0.020809787456528284, 0.04156853370659519, 0.048413617769256234, 0.06436085735913366, 0.0165689979257877, 0.020146617280261125, 0.06018753090756945, 0.035157461315975524, 0.049777707463363186, 0.06170985390781425, 0.026554505857347976, 0.032758123852545395, 0.012908209791930858, 0.008965532633737894, 0.045416702996590175, 0.03601768839871511, 0.015699840951128863, 0.01106442088712356, 0.03213089032215066, 0.02590182593849022, 0.037234502597129904, 0.03876026545185596, 0.0074768864396901336, 0.024255564276245423, 0.030029558547539636, 0.10493626017705537, 0.009978760881494964, 0.0505358558439184, 0.06405970125342719, 0.009356995124107925, 0.03172770746459719, 0.051937646639999, 0.03385088806680869, 0.03148326257360168, 0.02798929996060906, 0.054127601979416795, 0.030980153242126107, 0.030560897321265657, 0.038504410040332004, 0.04471080181247089, 0.07252719064126723, 0.0299411056766985, 0.05066901198006235, 0.0295685141463764, 0.051959647607873194, 0.051931546186096966, 0.03205485729267821, 0.04242113893269561, 0.10785782098537311, 0.03456171711150091, 0.06108575595135335, 0.038063225510995835, 0.03578942974854726, 0.034477776498533785, 0.013223444439063314, 0.04167197796050459, 0.0292273952436517, 0.042420589743414894, 0.10629669108311646, 0.03514928284857888, 0.043820517748827115, 0.002017913216150191, 0.055470655497629195, 0.03323817094496917, 0.01718909385090228, 0.04994283532141708, 0.03960991321946494, 0.07772318916977383, 0.027620736436801963, 0.02429804295388749, 0.019620211933215614, 0.00822562995381304, 0.08290266006952152, 0.05442330701043829, 0.06159781929454766, 0.04397762299049646, 0.06496744434116408, 0.02881235101085622, 0.05080047973024193, 0.01919733804243151, 0.024274453789985273, 0.02094098432280589, 0.06888819567393512, 0.016142259300977457, 0.032888040514080785, 0.08040213448111899, 0.01180838775326265, 0.05947761470451951, 0.013628767464979319, 0.028737911743519362, 0.00801954853159259, 0.041222911822842434, 0.03738691746548284, 0.008730683712201426, 0.05144680129888002, 0.021318715225788765, 0.0545921493176138, 0.03494789736578241, 0.03967505894252099, 0.08448776876321062, 0.024044219171628356, 0.028406667115632445, 0.04636085584934335, 0.025249461432395037, 0.08188518302631564, 0.030689238774357364, 0.021852556892554276, 0.031193127360893413, 0.005539222811421496, 0.030609849382017273, 0.004996796815248672, 0.013986608810228063, 0.04321062449889723, 0.06611046308535151, 0.0673812796594575, 0.06403418621630408, 0.018728317409113515, 0.04039363229821902, 0.03209658454579767, 0.029238072893349454, 0.008024601629585959, 0.03695213395985775, 0.06438741140300408, 0.06825900287367404, 0.01715709800919285, 0.03691709345730487, 0.05832597591506783, 0.04739638192404527, 0.032982634656946175, 0.05453902267618105, 0.06944811641005799, 0.039917110407259315, 0.027350746822776273, 0.04727178646135144, 0.12726804037811235, 0.050407575618010014, 0.05762682827480603, 0.03161604763590731, 0.06407364620827138, 0.0659215048654005, 0.048992248048307374, 0.02162188811780652, 0.05364055272366386, 0.04228420897561591, 0.023732352019578684, 0.019436625007074326, 0.08589170436607674, 0.008617476505605737, 0.03612730361055583, 0.013610914174932986, 0.03532087481289636, 0.05980857546092011, 0.014956957620597677, 0.06623173743719235, 0.05325177866325248, 0.0818013797106687, 0.03099967729212949, 0.023794399276084732, 0.026921364296867978, 0.14080880675464869, 0.1844534874544479, 0.10839362192200497, 0.13936993083916605, 0.13133048254530877, 0.11359112701029517, 0.07040922733722255, 0.1368176404503174, 0.11946760074351914, 0.06846054049674422, 0.1313518118695356, 0.14960644795792177, 0.16975019127130508, 0.0808714389859233, 0.14638805034337565, 0.12519528128905222, 0.2071008807979524, 0.11357271432643756, 0.12004565956885926, 0.10412038012873381, 0.2513275091769174, 0.18893274944275618, 0.1466012396849692, 0.18239591270685196, 0.12626009993255138, 0.10035144252469763, 0.17766590870451182, 0.13925072707934305, 0.13266720925457776, 0.13608877721708268, 0.14465241925790906, 0.11360350603354163, 0.11880605772603303, 0.07097303692717105, 0.12426787870936096, 0.12431234077666886, 0.12931310251588002, 0.05595428345259279, 0.18323286232771352, 0.09793244185857475, 0.12972306489245966, 0.18249110056785867, 0.15981102304067463, 0.09349117783131078, 0.11758828986785375, 0.20058417110703886, 0.17888358008349314, 0.11856818455271423, 0.11804911162471399, 0.146989650093019, 0.12709488248219714, 0.09093160697375424, 0.11781540932133794, 0.09457735548494384, 0.12630645447643474, 0.1401557761710137, 0.10428771216538735, 0.19289384392322972, 0.14815626171184704, 0.09612511930754408, 0.11266972098383121, 0.1758373755728826, 0.1787044998491183, 0.12736889824736863, 0.10444803090649657, 0.21436257316963747, 0.12161296413978562, 0.1575274791684933, 0.12266619785805233, 0.11823113818536513, 0.09322698810137808, 0.1306822313927114, 0.20334159111371264, 0.15085223189089447, 0.15748473146231845, 0.16916764987399802, 0.1911997582647018, 0.1637190391193144, 0.1784056518226862, 0.19804172159638256, 0.2210017669131048, 0.13286816800246015, 0.19108632841380313, 0.15144839911954477, 0.20808352885069326, 0.09232582786353305, 0.18569933075923473, 0.06046986614819616, 0.18618512578541413, 0.25289073935709894, 0.29044228373095393, 0.13512910605641082, 0.11384716053726152, 0.16978063416900113, 0.19753821892663836, 0.14724803622812033, 0.06953039090149105, 0.10188159518293105, 0.07082964657456614, 0.18390876590274274, 0.1787343787145801, 0.11551649557077326, 0.14757091499632224, 0.18920050148153678, 0.17811851488659158, 0.07302239609998651, 0.10528378566959873, 0.171769218868576, 0.1409944921033457, 0.17951210495084524, 0.0734067840676289, 0.18117194791557267, 0.1162611813924741, 0.1315163608524017, 0.12053535087034106, 0.1471768197370693, 0.3202863869955763, 0.08656929261633195, 0.13182879018131644, 0.08431280744844116, 0.20872409135336056, 0.13754690444329754, 0.12661967048188671, 0.12393246506690048, 0.17530126293422654, 0.10581809488940053, 0.15901371894869953, 0.13665856851730496, 0.1749718829523772, 0.08771940629230812, 0.15522410511039197, 0.21070713963126764, 0.14606578013626859, 0.16927466756897047, 0.13189843331929296, 0.14844510558759794, 0.2603474829811603, 0.16647739423206076, 0.116669229028048, 0.25267901946790516, 0.11840629988000728, 0.12435745593393221, 0.10454300354467705, 0.11561543127754703, 0.13738159846980125, 0.1744014979340136, 0.1396946798195131, 0.09701240138383582, 0.09936466813087463, 0.10934063946479, 0.09362492026411928, 0.2361873848713003, 0.09729593148222193, 0.1713254294008948, 0.10972114600008354, 0.2329063499928452, 0.1653254622942768, 0.17499386536655948, 0.15637991105904803, 0.191084012913052, 0.14829372230451554, 0.15364864433649927, 0.10708708578022197, 0.1757157820975408, 0.10717066645156592, 0.12310220961808227, 0.1128385892661754, 0.13965237740194425, 0.13469915022142231, 0.10041812449344434, 0.15190949547104537, 0.08959113984019496, 0.11961456082644872, 0.15310417511500418, 0.08449124201433733, 0.1257892369176261], [0.042566700067254715, 0.026743579110188875, 0.042651494150049984, 0.042917090249829926, 0.021611820884572808, 0.06618044018978253, 0.07712434278801084, 0.07185833004768938, 0.007701988179178443, 0.002545805409681634, 0.03853954331134446, 0.02612636271805968, 0.03759819948754739, 0.02757838763500331, 0.03836955067527015, 0.12008738311124034, 0.03962313829106279, 0.033567187274456955, 0.03752962133148685, 0.06942300213268027, 0.019028935457754415, 0.05481979198521003, 0.012507576211646665, 0.03115850246103946, 0.02066159726382466, 0.10024329676525667, 0.019588232789828908, 0.011066542501794174, 0.07261874940013513, 0.0312532413227018, 0.03675891210150439, 0.03446356065978762, 0.03912658583431039, 0.02845866012648912, 0.0018491091759642586, 0.026996794331353158, 0.02857138493709499, 0.07579952754895203, 0.054167663111002184, 0.03216514043742791, 0.04265677824150771, 0.050094975595129654, 0.07275134150404483, 0.016435370525869075, 0.0706772094417829, 0.03309960455226246, 0.00833746697026072, 0.0358635851443978, 0.051489348625182174, 0.018041680523310788, 0.03839213422907051, 0.05596061397227459, 0.1180910058610607, 0.05025036276492756, 0.036321664665592834, 0.021769011473224964, 0.03647990168246906, 0.08211281456169672, 0.05215812387177721, 0.028918199823237956, 0.06623536653933115, 0.08524518983904272, 0.02969040633615805, 0.030101908669166733, 0.06450510860304348, 0.033804815539042465, 0.04422678051923867, 0.10518684634007514, 0.010697476172936149, 0.026080036004714202, 0.036805723066208884, 0.01638181900489144, 0.010660725019988604, 0.02883102530176984, 0.043362026335671544, 0.045231462936499156, 0.06904904133989476, 0.03272112779086456, 0.05141747162269894, 0.02564043224992929, 0.02071962950140005, 0.05722062858694699, 0.029979072096466552, 0.026719663401308935, 0.02532300270104315, 0.039552192683913745, 0.06706944404868409, 0.007275641501109931, 0.018641868336999323, 0.03276314448157791, 0.017377838703396264, 0.03403406124562025, 0.10694828190025873, 0.0884451599267777, 0.04359815546195023, 0.027921463952225167, 0.03183095876011066, 0.024771149110165425, 0.009393293566972716, 0.04449546024261508, 0.033946688199648634, 0.033247117535211146, 0.02248124874313362, 0.05498831516888458, 0.003746300012608117, 0.05944403994362801, 0.029564109499915503, 0.037057363078929484, 0.030349847220350057, 0.024256783253804315, 0.024220803934440482, 0.04925317974993959, 0.03114190803898964, 0.031948693067533895, 0.02396818428678671, 0.039265920349862427, 0.061677819103351794, 0.05798172329377849, 0.017585703135409858, 0.09238967482815497, 0.04466292215511203, 0.018474540011084173, 0.039527497719973326, 0.01501564851423609, 0.033190116882906295, 0.008613804729975527, 0.04708813830802683, 0.016206499603867996, 0.06296991676208563, 0.04596675316861365, 0.04472798995266203, 0.010008884655690053, 0.0759557644778397, 0.009365437981614377, 0.04191445616015699, 0.02363857794989599, 0.06352669079205953, 0.04221344519464765, 0.017435909903724678, 0.048244088975479826, 0.08869969431543723, 0.1094185649708379, 0.04216645611450076, 0.05065626188297756, 0.0035407728819336626, 0.0392587771784747, 0.07791193958837539, 0.024137180589605123, 0.058559318276820704, 0.10114293560036458, 0.009293987714045215, 0.03900985713698901, 0.08561754759284668, 0.11460543508292176, 0.07300115583348088, 0.03818606950517278, 0.025426675165363122, 0.03852114918117877, 0.03313173583592288, 0.02944202806247631, 0.07370553561486304, 0.018323088079341687, 0.05190443553146906, 0.08551226652343757, 0.026844611384149175, 0.03922266427252907, 0.03159058825985994, 0.02554409220465459, 0.021849775694136042, 0.05600723568932153, 0.026259418664267287, 0.07932235414045863, 0.0416258757468313, 0.04216142806399148, 0.05969115656625945, 0.06468378807767294, 0.005601226930593839, 0.07558709519798867, 0.07364819728536531, 0.050718776692519896, 0.0371837322745705, 0.04765055266034324, 0.05402045069786254, 0.01970598750631325, 0.09444172057555988, 0.003263680450800166, 0.049969753017649055, 0.03051136081921868, 0.03543043807439972, 0.04631459778465796, 0.0525934157485608, 0.044628939212998375, 0.03614203895267565, 0.018036401997960638, 0.044345453643472865, 0.02639965488924645, 0.041656838147901, 0.03204670108971186, 0.017545443479320966, 0.027641911765385885, 0.023016125705908053, 0.018648115365067497, 0.031037094522616826, 0.024880205855879467, 0.0439395471039461, 0.04788554630067665, 0.05638680340780411, 0.10140560392756015, 0.02753355263848789, 0.03753680532099679, 0.045571281225420535, 0.008321087771037128, 0.02657507262483705, 0.03693864542583469, 0.04199653398245573, 0.022560367251571734, 0.06438551892642863, 0.04425382438057568, 0.024080582552414853, 0.0509256429359084, 0.06644497872912325, 0.12353805810562335, 0.02389850589679554, 0.055748552695149556, 0.017978870710066985, 0.02707304072828265, 0.035285945632494986, 0.04484988399781287, 0.05973598970740568, 0.03990408200479578, 0.02268923562951386, 0.030403445125557482, 0.019952347138314508, 0.03370790589542594, 0.015915464537101798, 0.059415905125206336, 0.03467707283562049, 0.04749629726575222, 0.027130783528264146, 0.03983757815149147, 0.037653712133760564, 0.022861105899210088, 0.022718650652677752, 0.09153901031822897, 0.0374304592696717, 0.11778031315770932, 0.022727973882865626, 0.04888708201178815, 0.02559611119067995, 0.05490523915796075, 0.02308789138623979, 0.043466364877531305, 0.01659199522691779, 0.037445829148055054, 0.03379280387889594, 0.03414334249100648, 0.024368465346924495, 0.030948498788347933, 0.03364462296303827, 0.01997959137952421, 0.051658064767252654, 0.05532774011953734, 0.00637459583231248, 0.03957927736337297, 0.08530583814717829, 0.022309597407002002, 0.011297959918010747, 0.02118506370607065, 0.06710193527396768, 0.06781401112675667, 0.03654605672636535, 0.08708028355613351, 0.019118182426609565, 0.02617939102492528, 0.03395137486222666, 0.04393894225358963, 0.029510118256439455, 0.05154759237484541, 0.028156693224445917, 0.05273927003145218, 0.05416244952357374, 0.06836233209469356, 0.024305679653480183, 0.047031994836288504, 0.06467206956585869, 0.038272095553111285, 0.0060852621390949935, 0.03752311640710104, 0.046405670436797664, 0.029156403252272867, 0.020042562609887682, 0.057003401961992495, 0.018539702432462946, 0.02678916738659609, 0.008234468004957307, 0.008607468644186156, 0.03135129016300198, 0.016514299786649644, 0.021080723308841698, 0.027121488128614146, 0.07930803069029935, 0.03467353279120289, 0.04589418967952952, 0.012124658624088624, 0.008730742156330962, 0.02415476948954165, 0.047549772716593, 0.0244658666633768, 0.027673597760440316, 0.014091452012507943, 0.042765873949974775, 0.033808878797572106, 0.05183218003367074, 0.03325961901282426, 0.05117540531500708, 0.012352081430435646, 0.07563916427898221, 0.060167452102177776, 0.03473857832432259, 0.08391990704694763, 0.047127943398663774, 0.07155831684940495, 0.09283005041652359, 0.03655733737105038, 0.01134147945776931, 0.05799193895654753, 0.029572855710284784, 0.02968145603517769, 0.059313985984772444, 0.06851858386653475, 0.02436475460854126, 0.02204006421379745, 0.018798149794747587, 0.003403602422622498, 0.044570435711648315, 0.045007293520029634, 0.04166385144344531, 0.032129576720763, 0.08395222015678883, 0.03564873339200858, 0.02001083950744942, 0.022607957471336704, 0.09860784819466062, 0.03955302388931159, 0.04797578774741851, 0.005982578586554155, 0.11908581771422178, 0.041077821952058, 0.021747871396655682, 0.023321523185586557, 0.047954862893675454, 0.033075083993026055, 0.18884351360611618, 0.0799197013839148, 0.14007709367433563, 0.26365012919995934, 0.0883845858334098, 0.23584920301800594, 0.13732783729210496, 0.17922113853273913, 0.12863333977293223, 0.176315956923645, 0.14026969583937898, 0.11735483247321099, 0.11808055642177351, 0.11615290204645135, 0.07438191416440532, 0.22511777729960158, 0.11281829894869588, 0.12475872033974156, 0.10327861396945082, 0.2189885577536188, 0.11298139332211576, 0.17041015351423994, 0.1297165488358587, 0.09426154938410036, 0.06298617721768096, 0.12615290412213653, 0.1107538073847536, 0.10231653825030662, 0.11143854993861169, 0.09699930247734301, 0.13109369290759787, 0.19525301264366135, 0.11002406841726042, 0.1989037261228077, 0.09949942730600014, 0.11956772388657555, 0.1355078537017107, 0.11382131895516068, 0.1071815611794591, 0.12954242614796385, 0.17429385683499277, 0.10135841075680219, 0.19360007165232673, 0.16000220028217882, 0.19528681004885584, 0.3022780845640227, 0.11547850503120571, 0.18334632186451927, 0.10776292998343706, 0.07718563676462509, 0.10373421100666746, 0.0896031477896031, 0.18107900134054944, 0.16714250697987154, 0.05887954386707861, 0.12334578990703449, 0.16852840839419514, 0.12769948050845414, 0.14821680611930788, 0.10923261987045407, 0.13645916827954352, 0.24016762676183134, 0.17427825689082965, 0.13263831002404913, 0.2176086974213831, 0.09297623866586946, 0.11803137429524213, 0.20114544255193323, 0.16726378875318915, 0.2848065330181271, 0.13289555325172842, 0.1411505212308839, 0.061332111872616224, 0.08829500860883854, 0.13706102035939693, 0.18058826361084357, 0.1732127257855609, 0.11386574391508475, 0.13467379845678806, 0.2526490663876757, 0.06314995436696336, 0.10181526202359237, 0.11622451929724775, 0.07092726867995225, 0.1148728902626317, 0.15634790965123102, 0.14795301714912057, 0.09254453136236407, 0.17734126362483948, 0.1062700776674319, 0.1276827821857296, 0.15572881005937234, 0.23573838552692905, 0.23390099115204066, 0.10499210678972304, 0.14976489648688585, 0.10147643450181931, 0.10937860773992725, 0.13092828303342685, 0.14547409547958523, 0.13940246659331024, 0.1369249846902676, 0.06905049594934098, 0.17825290298787877, 0.16049562458647415, 0.10697445744881406, 0.16766137210652232, 0.11689495324390009, 0.16003397904569283, 0.06950591487111524, 0.07184200279880315, 0.12436127057299018, 0.2086759704980068, 0.12763166305376217, 0.08421136328252032, 0.15142383403144777, 0.15596343262586743, 0.10275844266288914, 0.1067349589720834, 0.19749751954805106, 0.09911103916238062, 0.1288121528341435, 0.14570157858543098, 0.08612663121311925, 0.1795132627012208, 0.14012567466124892, 0.1539410653640516, 0.12802694574929774, 0.1162860804470256, 0.13756440428551286, 0.0877253657381516, 0.09552524876198731, 0.137658657040447, 0.08601790657849051, 0.11700555551215075, 0.09354508001706563, 0.09045335958944634, 0.10612337733618915, 0.16190027265110984, 0.13924977713031694, 0.21203559881541878, 0.29229447653051466, 0.13303014915436506, 0.1490939356153831, 0.09615480521460995, 0.12003034906229004, 0.18085871706716716, 0.11843439016956836, 0.1414616740657948, 0.21973495051497594, 0.10119633312569931, 0.146515981759876, 0.16470280039357021, 0.17983289086259902, 0.10168681110371836, 0.15559694526018575, 0.10963520529912785, 0.13302280189236626, 0.1727143142488785, 0.12367669129162095, 0.12176773161627352, 0.08950590417953208, 0.2676143852295354, 0.15352504706243053, 0.10814745895913802, 0.1308621873613447, 0.1453874571598135, 0.09034753675223328, 0.16366971598472446, 0.08708481065696105, 0.2731910313013941, 0.16323070594808087, 0.11670284831780009, 0.25864104798529297, 0.22571054549189284, 0.1120724479551427], [0.03346309364133049, 0.036958453347324394, 0.028271627779759, 0.02313716813659994, 0.0746562193671707, 0.043518122256500646, 0.04302531022403855, 0.031064576251083054, 0.01673643015237758, 0.07058027011225931, 0.01382002263198956, 0.08400509075727314, 0.06659956809016876, 0.015312395335058682, 0.02292222732648952, 0.03309963423816953, 0.05060887946456205, 0.008142269143718295, 0.037197402634774335, 0.011130315251648426, 0.002912114427999768, 0.09946725520421751, 0.041568841697881, 0.023730470675218385, 0.14464354317169636, 0.07288852008059621, 0.024542413630115334, 0.02206781126005808, 0.01723941146337893, 0.039529345667688176, 0.05458188541524578, 0.005399716674219235, 0.01806254414987052, 0.04787413949088659, 0.03300191194284707, 0.05615512345684692, 0.05881562639842741, 0.03953243671276141, 0.03966610493080225, 0.0363644977187505, 0.02715889051614795, 0.03850730441627093, 0.022251806367421523, 0.08061580621870235, 0.055372985152644105, 0.03161652261042036, 0.0182817207678454, 0.013178433182474691, 0.02884594247007044, 0.02272317033202853, 0.013161600345483748, 0.04554401843051892, 0.029005389187659603, 0.07428884884575382, 0.02216415316070197, 0.04269184842996765, 0.039665804360993207, 0.013124200741003733, 0.056464339286321774, 0.08130401460221037, 0.04690315428888425, 0.04266139440005645, 0.07395208449452184, 0.03570852451957762, 0.02565637172665447, 0.06799489477998577, 0.02150759923097212, 0.09956407579011284, 0.04605247864674311, 0.034428201033733785, 0.022455575999629218, 0.017437670649087522, 0.07248034627991728, 0.06276367392274551, 0.03083797073486494, 0.07543727042502724, 0.04888313378614839, 0.07009813387412578, 0.03951740080083255, 0.0849049151293002, 0.04050512514368165, 0.044564710042322986, 0.06487964084954001, 0.05679318121110555, 0.06657158912275918, 0.07291908914339729, 0.03229564710636623, 0.04839899003854953, 0.05588442880252842, 0.01353284302240354, 0.08193984220270067, 0.020002607234346215, 0.00613831317423319, 0.08939167280914262, 0.029478797769115772, 0.035470658767735586, 0.04020971326099243, 0.047776955252629705, 0.05351263615011703, 0.0436500835348852, 0.018023742813966237, 0.05332987115252763, 0.036405208229552954, 0.06510612947749905, 0.018681818146433216, 0.03040014813450398, 0.0058161259948974475, 0.06970106260268949, 0.02582504333986435, 0.034690156899159774, 0.032042574748629704, 0.06319667998468503, 0.10092450669617392, 0.018149217721656896, 0.06173567322548479, 0.027265761636954267, 0.009638898063712986, 0.021660637503373437, 0.07695749314734712, 0.09742615613504313, 0.02823485992848873, 0.04916866026178468, 0.07289942965144292, 0.010024185885413317, 0.03286208389909007, 0.03483504639007151, 0.08266451972303912, 0.07748411371721886, 0.04915411787806079, 0.01954251649294747, 0.02300439420650946, 0.03520700709486846, 0.05907170816499274, 0.05595719638222363, 0.031816160335438326, 0.01364217900118092, 0.029734447234659456, 0.04525133022980299, 0.020798853765882086, 0.08691096998518333, 0.03332923246489372, 0.016535820213903207, 0.027113545293104835, 0.06722709105815738, 0.052248424690333195, 0.023632642623852007, 0.01332433384959586, 0.003301691399428819, 0.04376692355435807, 0.02229435369372368, 0.09236145837348886, 0.028031429828843102, 0.03657097062387038, 0.0386267790599959, 0.03955630418204237, 0.043574466108111665, 0.08177507057553157, 0.029899992550781462, 0.04081999613845255, 0.04493372813158203, 0.027652550452330615, 0.010126192228199216, 0.035784965730272233, 0.04891092721663881, 0.03419189008127432, 0.031237222065101378, 0.027206026170460973, 0.04722705722087994, 0.042399453377583995, 0.04731125016405713, 0.007741818317299476, 0.03363891213666648, 0.04771027699462138, 0.05115146363095846, 0.028082343014830258, 0.03749949384655338, 0.013683932229469065, 0.04571499812300317, 0.03518890240229666, 0.007459862035830156, 0.03606166435929481, 0.04066614892508369, 0.0259707269287901, 0.05163917339814361, 0.04997750475013163, 0.05977079643344041, 0.015768053599458653, 0.08108905152766965, 0.04819089554075617, 0.058521906612440944, 0.0022931076046006638, 0.08003851180546917, 0.03127215495624114, 0.09277656383346766, 0.04334234457928687, 0.07316116287256591, 0.03878575822454877, 0.007402768151223427, 0.0035575206038629403, 0.028963871591258794, 0.085622653568862, 0.06383040730725043, 0.013208828768256353, 0.0392762399133062, 0.011652275134110823, 0.030430119768425357, 0.03401208625291474, 0.01489886508352356, 0.05399837551522069, 0.027074944337073248, 0.07337238552281633, 0.019040206825593486, 0.02512214043235872, 0.022384827061614487, 0.04417799173097592, 0.022332962071232032, 0.027074588106188457, 0.03680422392790206, 0.012382701515889494, 0.036874063735012896, 0.04750024920213036, 0.09902942518237978, 0.06823255273047835, 0.03258427947002929, 0.07929025625344366, 0.04841733963985462, 0.024449583943351172, 0.020729386887978762, 0.03278916788985953, 0.07848572364309803, 0.026201223154203035, 0.04923837390379049, 0.04908868271741085, 0.020434770958672743, 0.04521899485553149, 0.05303478581481613, 0.06556108826771379, 0.027811635372927412, 0.019234658793720882, 0.03593395929783583, 0.0705831051163841, 0.03870815926347859, 0.011773981786973309, 0.038268262360361405, 0.0406340770132374, 0.05005243197956588, 0.017514790924906265, 0.024974618172564078, 0.01646857606829144, 0.01669123892497737, 0.02657972032466205, 0.04832650447497144, 0.0553930825117277, 0.040351971838390455, 0.009588716820871923, 0.06313016870990396, 0.019051873387070373, 0.01149424499089946, 0.05767689355707262, 0.007570284797111526, 0.02134441394446185, 0.054166067493497394, 0.03975194544182159, 0.039096766340662725, 0.04599016050633509, 0.02346404522540979, 0.04282339781639166, 0.05904520607145969, 0.07447263429639861, 0.14507618558127433, 0.020763199136126786, 0.01903302654682193, 0.012676474179897923, 0.07886172534199432, 0.053274150704964995, 0.02553257036197465, 0.020762367930728942, 0.0543004518840462, 0.050835334695875645, 0.0880065506498795, 0.01699275497230701, 0.03450718410022091, 0.1311429269844666, 0.0362391638191184, 0.05377976478484925, 0.054490820184582844, 0.014769260124012362, 0.03649468897492625, 0.06326801521936432, 0.04634923010598868, 0.050995983692700975, 0.027629046635411214, 0.060198744758963585, 0.041375872169737704, 0.02399030028755078, 0.07997865017387085, 0.023018020037852693, 0.015941970341373235, 0.04652283700124826, 0.05419808374426793, 0.03006579205248272, 0.011238326496822992, 0.08402521038078703, 0.06326845308649354, 0.027127939247293398, 0.03621219417254906, 0.05870551394764334, 0.02008043997193454, 0.09469346448895521, 0.042161743476754054, 0.042385475026094355, 0.018549893975432497, 0.056805044441716745, 0.051302342253620736, 0.051015583812841214, 0.02399826167675201, 0.03983610869909171, 0.057971440837718546, 0.05132577927724924, 0.010954738881991943, 0.031442863764823414, 0.06198338727699593, 0.031014935848361347, 0.02155672755179694, 0.0023759985424476326, 0.021019316154706758, 0.025361635198350996, 0.04163526391494088, 0.03633251857536379, 0.01907775764266262, 0.0214512108505005, 0.04962120707205031, 0.07620270669576712, 0.053696514369221404, 0.015118487917789025, 0.05479274070239626, 0.09701133269118145, 0.08057429047767073, 0.01506034621343133, 0.03164167399518192, 0.0210511765544652, 0.01328837586697773, 0.04786206845892593, 0.008582826558267698, 0.08118265119264834, 0.05720534776628483, 0.018308248836547136, 0.03948483907151967, 0.028331279754638672, 0.0514525158359902, 0.04255804291460663, 0.00666601124976296, 0.10777547227917239, 0.17407511622877792, 0.08634175756014884, 0.08826670309645124, 0.14228020358132198, 0.1467573578702286, 0.12703349202638492, 0.16608524339972064, 0.1610115062794648, 0.1458207081304863, 0.10891031997743994, 0.1849009728175588, 0.18323214986594394, 0.19606173096690327, 0.08359031926374882, 0.1757874884060584, 0.13433527521556243, 0.1461794474744238, 0.14118713879724964, 0.1957669944385998, 0.14783169084694237, 0.13698575174203143, 0.08979934937087819, 0.1269776825211011, 0.36202904710080475, 0.25240454357117414, 0.1332790357992053, 0.1714442324009724, 0.06913461838848889, 0.09825473433011211, 0.13839087478118017, 0.09673767315689474, 0.16495100426254794, 0.12310713005717844, 0.1934819811140187, 0.15354998322436586, 0.18385049246717244, 0.10071792246890254, 0.10793491528602317, 0.1362765851081349, 0.08930150928790681, 0.12828258593799546, 0.1048747732420452, 0.13494702754542232, 0.18521761754527688, 0.18785406748065725, 0.16708257113350555, 0.12436136705218814, 0.16560750809730962, 0.12530657375464216, 0.11037195014068857, 0.10595495434245095, 0.07597612158861011, 0.16541794873774052, 0.1015511984587647, 0.13846517860656604, 0.10236272210022435, 0.12421478546457365, 0.08754589216550812, 0.13837787235388532, 0.09693450556369498, 0.07438536515110172, 0.14586845791200176, 0.18714084872044623, 0.10774339665658772, 0.16036597138736397, 0.08343204885022715, 0.21295498620020226, 0.1654608448734507, 0.13738235546043143, 0.10079244151711464, 0.12010972175630741, 0.12503511097747833, 0.09786903276108205, 0.09958737922715954, 0.1273418840719387, 0.12168562039732933, 0.15522750414675102, 0.11875715019414201, 0.2512980904430151, 0.17787489749025553, 0.08017967571504414, 0.15478246787097305, 0.19034188007935882, 0.13923873397288844, 0.20313239452661946, 0.17562608612934127, 0.2065216048504226, 0.1443551148986444, 0.1561957545345649, 0.2834720624377951, 0.1375628903042525, 0.11053784241084941, 0.20256618037819862, 0.15994244255125523, 0.18076045671477914, 0.11933235175092705, 0.20910181483486667, 0.15256337210303172, 0.17546892893733457, 0.1424345702980645, 0.16477049910463393, 0.10582950912066735, 0.198528659529984, 0.07341614997130819, 0.14768977736821398, 0.16395633341744542, 0.18998296261997893, 0.15296524506993592, 0.14887114288285375, 0.1008049318625126, 0.13582224230049178, 0.17026824003551155, 0.19865446840412915, 0.11947259539738297, 0.06243412324693054, 0.17890407820232213, 0.14198592718457803, 0.11671058891806751, 0.19769481208641082, 0.17919537116540596, 0.14243324927520007, 0.16022272204281762, 0.11042995640309528, 0.10236294474452734, 0.08632751574623398, 0.17916651646373793, 0.14868853002553806, 0.1341416488867253, 0.11976960289757699, 0.12756334093865007, 0.1028517603117507, 0.21909312636125833, 0.17505297000752762, 0.09389480968820862, 0.08228951250202954, 0.15977773029590026, 0.12111295698559843, 0.13400412892224267, 0.12065171962603927, 0.14507155457977206, 0.24657443922478706, 0.08860332643962465, 0.1447151307365857, 0.1110188357415609, 0.09946210469934158, 0.08364457768038847, 0.059276151296216995, 0.0887181812140625, 0.12535623827716336, 0.11435029213316739, 0.22878698509884998, 0.1533385453512892, 0.18099702370818704, 0.12797990842955187, 0.1051470152742695, 0.21979165059747174, 0.08697673911228776, 0.18310234823729843, 0.1296127520618029, 0.1583336593466811, 0.27248204278293997, 0.09626964514609426, 0.16265747108263895, 0.1080205813923385, 0.09858297882601619, 0.11703154552378692, 0.1669312026933767, 0.09720360831124708, 0.1966188760707155, 0.10617404375807382, 0.19227901910198852, 0.08555314401746728, 0.14462414343142882, 0.12750631431117654, 0.0834573560860008], [0.01694737635261845, 0.017443672768422402, 0.0258696501259692, 0.028428117038856726, 0.05962789960904047, 0.041305264239781536, 0.015937422831484582, 0.023532372906629462, 0.030543633110937662, 0.09431381142348982, 0.050644573057070374, 0.03172694305249024, 0.05290356668410823, 0.030306899134302512, 0.017321082959824707, 0.037454011326190084, 0.07265728170750663, 0.02165758913179161, 0.04756113870826084, 0.008813240219751606, 0.05623008037218824, 0.022362480995070655, 0.003414433836042008, 0.05194910911086481, 0.016835543974593747, 0.018237062031403184, 0.08065208239713684, 0.030755733350815717, 0.018079845467582345, 0.0066252353371965, 0.014796803079661913, 0.029494199188775383, 0.11921051336685196, 0.06942849402548745, 0.02715448401431786, 0.0108413665475382, 0.03593728783016559, 0.07659034527023323, 0.03860372424242087, 0.028158780514786486, 0.10138875717530027, 0.04748979234136641, 0.017306998852291144, 0.05805081353173591, 0.039026373633532785, 0.045670729014091194, 0.012010665668640286, 0.04291320510674268, 0.11990171260549687, 0.0539240086072823, 0.027856746819452383, 0.057218123838538304, 0.07511783522204496, 0.021890918505960144, 0.015007914407760836, 0.018154954523197375, 0.03569610838894732, 0.021990657587593887, 0.06068107766623143, 0.012468733129935572, 0.046331618941621855, 0.011975523120781872, 0.010011363428930053, 0.028312867070781067, 0.04237850254867226, 0.04881535343884025, 0.012100223411835032, 0.011368283048796002, 0.02838163261912996, 0.00715266345650889, 0.04672376235248521, 0.02079046007565921, 0.04606079441145994, 0.023238508401846047, 0.03704641268996056, 0.03286894134362228, 0.06753983208909631, 0.058606700695236214, 0.05603761921520345, 0.030215162259992212, 0.028483360656537116, 0.056515350806876086, 0.0984895795409102, 0.062331513909157366, 0.049847306072479114, 0.054307231403072365, 0.06781281626899727, 0.020422892885108013, 0.028136748005636036, 0.07023048849077895, 0.031191836023936048, 0.04762216180097312, 0.02390755824308144, 0.012259962350071874, 0.0314482888643397, 0.024382428855460603, 0.08755125789321028, 0.02029103179665981, 0.04445198523171712, 0.06796224770369008, 0.026470969714864623, 0.031201101737678982, 0.03177365753799677, 0.04412226386193652, 0.01435666405086522, 0.05584981132415123, 0.016616816355963238, 0.03447820323344786, 0.06630226373090409, 0.017921857070177794, 0.003453115732554579, 0.04561455214570742, 0.009542323314235546, 0.039864666541689076, 0.004186829364698497, 0.035597614260041155, 0.022710038028890267, 0.0626650573394727, 0.08987438050098717, 0.061307680371101014, 0.09049603308085352, 0.016340548172593117, 0.10286725635523908, 0.02724322817812208, 0.045745964234811254, 0.051527391115087084, 0.050149623639299534, 0.057507542878738604, 0.05354728702513967, 0.05152293451828882, 0.026940482021018397, 0.025605779519537464, 0.01042330362906796, 0.0473090868035797, 0.037596574184135534, 0.1117727835662663, 0.054210032321861945, 0.01969437475054292, 0.013046776184637565, 0.07733465259661898, 0.018738058097369503, 0.019109619897790253, 0.03133604273898527, 0.06648199705523439, 0.07156195337302051, 0.05189233852433972, 0.005129186683916487, 0.03680201974930242, 0.0820539696724154, 0.03502526626107283, 0.025522176583763212, 0.07380948081845418, 0.019272591816843487, 0.06710807283525355, 0.0370214616850717, 0.040841310619725846, 0.038292831159196794, 0.09483502915827557, 0.024925775578594767, 0.09020232813782059, 0.0415817661996698, 0.09035026785568334, 0.034049260430037975, 0.023572324571432546, 0.06851363374153152, 0.03512876988679636, 0.03966510674217716, 0.020194135140627623, 0.05310523047228344, 0.07278254881384782, 0.011684634628181811, 0.04284881637431681, 0.03100696332694497, 0.05095018947031349, 0.02989488286402775, 0.04578720167046413, 0.09448400815017521, 0.029700640552619006, 0.05143382484675385, 0.021895139470871072, 0.015404370624310104, 0.015468665660591796, 0.014471672820945969, 0.04194908106001094, 0.03215105076378677, 0.06541604292578995, 0.05987014032143634, 0.07922363365651108, 0.10255500514176674, 0.014824032477918081, 0.06866546973469667, 0.02273084784974344, 0.01807420700060902, 0.03294390939117875, 0.018835624541679863, 0.004017918408862897, 0.07520335289882496, 0.004395037967697135, 0.06289194672717713, 0.08406506371102296, 0.018392746060271747, 0.01221953014464816, 0.02258810131024802, 0.09295995594584383, 0.013793270063615637, 0.06098725069023203, 0.005490092635227484, 0.04716623079730198, 0.07867432563216425, 0.05116407643072307, 0.020719668464153074, 0.021829489087394904, 0.019304457782709505, 0.06331886717816815, 0.030247629365476314, 0.018161941843573004, 0.03485853536403738, 0.06209591912920587, 0.10578157380223274, 0.09081828102353029, 0.005263054817987722, 0.06423585000447929, 0.03279608099546749, 0.07524208558606915, 0.013249286948848749, 0.026811628486029804, 0.058345089928479865, 0.03317629067169037, 0.04854786857322324, 0.06227496967767365, 0.03539464058121666, 0.04834369261516258, 0.03048769929591799, 0.01840066848671995, 0.027120744125568308, 0.013273498589114752, 0.015352143836935284, 0.005326740829332266, 0.04886566362984013, 0.05148528165591415, 0.057355525059392676, 0.028887237422168255, 0.015136397796595702, 0.0452639207651373, 0.05151602512341924, 0.0302236190327676, 0.04319710256822873, 0.04311392636736855, 0.07068781473208219, 0.03214533622667659, 0.04917987040244043, 0.02374397034145659, 0.005652304780596751, 0.04285323215299286, 0.018679972054087557, 0.10143151972442865, 0.025205921483575366, 0.030200981673260685, 0.0636451895115897, 0.060960770861129276, 0.09401770192198455, 0.026701946480898187, 0.05620743002509698, 0.04895976424450055, 0.04306690017983783, 0.024854638868418988, 0.03951878119551111, 0.030184339011611883, 0.036943328377674334, 0.0072105106210074155, 0.02776923091005301, 0.07984095951542258, 0.016098359410534613, 0.013722109233640367, 0.029265742014104035, 0.05501687672222033, 0.012124328368372517, 0.03531225476763211, 0.03428860676649492, 0.039761233419994824, 0.014640746121585835, 0.051939438926638104, 0.011425854227127274, 0.019744542078115046, 0.039552214948344044, 0.04060112565639429, 0.02217400888184784, 0.057059497194131836, 0.037698274391004816, 0.05788996415503789, 0.03317537411930971, 0.03493543670629151, 0.015436871126439655, 0.08318124004290439, 0.10226702957879752, 0.039382923641824163, 0.02573092973761959, 0.07592779293190688, 0.05859674849489238, 0.047490590150118805, 0.03236905293306336, 0.0111470970659866, 0.025449060194659978, 0.021157504052098375, 0.10772450899821706, 0.05487474802066572, 0.020294358473620377, 0.04518588764767628, 0.014786212632316165, 0.03577280564059038, 0.044336837308947, 0.032801673078211024, 0.09547346911858767, 0.04590001182805281, 0.05771006384748034, 0.06375016630045138, 0.0026584251600070274, 0.04481273208511993, 0.04472296561289113, 0.07220302795758471, 0.020393364684423432, 0.06533134161145426, 0.024161244728020392, 0.018141516084142495, 0.039236048905877396, 0.020487656402110588, 0.06407852211850695, 0.060338116381899454, 0.04535947969998233, 0.05355899811547715, 0.05013541522203013, 0.01070375474228058, 0.07119395202607848, 0.030931570399843622, 0.01607051402970683, 0.05990864665363915, 0.028108550104661845, 0.06803503012633882, 0.01118511729146121, 0.012179328932688804, 0.11015571799362078, 0.024844881481840275, 0.06937148966244422, 0.04498413109104149, 0.04975150222890079, 0.02371259604842635, 0.04043389009893872, 0.011829389604827156, 0.021211220700934064, 0.0752550434845034, 0.004015813956357306, 0.03215670592908282, 0.22383930918294936, 0.08863304203259759, 0.08552457133191638, 0.15023117302916944, 0.17346652544802055, 0.09615620787371881, 0.08125076550641097, 0.10172067530220374, 0.10369774929131381, 0.21694285736884922, 0.18076244567055255, 0.13286171131767333, 0.22736142331268638, 0.12261344600119628, 0.13557050580857322, 0.11163089977344498, 0.10412564195576124, 0.1297930791042745, 0.09639293071813881, 0.10609057440888137, 0.15964613266987726, 0.09356984548503533, 0.18137875478714705, 0.17430668114684522, 0.11758568492950872, 0.12151920120231807, 0.16656458174111322, 0.1427468511974439, 0.11113714892417192, 0.1564097750815563, 0.22653455205727369, 0.172845006454736, 0.23405265645124018, 0.16036659479141235, 0.1256086427019909, 0.06401561768143438, 0.15243431262206286, 0.12168084096629173, 0.09143508737906814, 0.07790724179358222, 0.13398646580753848, 0.1537277572788298, 0.1643888867693022, 0.2802848647115752, 0.14445068867644295, 0.16222157806623727, 0.14865629113046452, 0.23999163386179134, 0.11747030323022045, 0.15859566716244444, 0.20106974348891526, 0.18434670724673197, 0.24180254840757698, 0.10292668011970818, 0.12384291752823628, 0.16427625843789428, 0.08799619768979028, 0.13917403353843838, 0.13810980861308053, 0.1259240257786587, 0.13294925505761057, 0.15140354371396825, 0.1336707710288465, 0.11609410910750739, 0.11430240876507014, 0.10235813562758267, 0.10399648599559441, 0.11290492242551409, 0.12298762201680802, 0.11210658674826846, 0.29366519360337406, 0.10080439009470865, 0.1412826680461876, 0.17663123609963804, 0.08686159490025602, 0.20702581998193637, 0.2042371704010293, 0.20109883567783982, 0.14166644745273516, 0.11754864433896728, 0.10394632423412986, 0.1645742158871144, 0.16817017371067777, 0.09889885914162733, 0.14991014963015914, 0.17468752164859325, 0.16536457347683609, 0.11768942233175039, 0.12228080056956969, 0.2101559317088686, 0.06397240242222324, 0.1602460106369108, 0.11808108334662393, 0.10979076687362976, 0.11897115589817986, 0.16149268514709547, 0.21986824023770168, 0.06001507063047029, 0.13818709587212652, 0.1445651426911354, 0.15084730403032154, 0.13126219011610374, 0.14133236225461587, 0.11365264363121241, 0.09772064775461331, 0.14570276602171361, 0.1044988383364398, 0.1304841521778144, 0.1483163281227462, 0.2330619189888239, 0.14814771217061207, 0.20834509137785062, 0.11238946375669912, 0.12664334499277174, 0.10622843576129526, 0.1838916222914122, 0.0947201595408842, 0.1655867724912241, 0.2996477053966373, 0.16611295519396663, 0.21533702791202813, 0.15537274244707078, 0.2231051618582569, 0.18021901545580477, 0.14918404718628153, 0.14983471774030477, 0.15359221142716706, 0.12276560111786239, 0.1915906326030381, 0.17541700828587636, 0.11119091752334498, 0.14037242392078042, 0.10679182232706808, 0.17960062832571566, 0.11696469286107458, 0.21376061718910933, 0.1727721275528893, 0.26113184401765466, 0.17032128875143826, 0.19702595891430974, 0.11806233669631183, 0.10013949999120086, 0.12154019656009041, 0.17605255387024954, 0.1799640283570625, 0.24479701038217172, 0.13185463176341727, 0.0631234745378606, 0.09929760024533607, 0.14025142416357994, 0.19004187430255115, 0.1859056478133425, 0.19819058157736436, 0.18919937341706827, 0.17676909745205194, 0.08643265580758452, 0.13644431048305705, 0.08938172803027555, 0.06795119712478481, 0.1372263114899397, 0.11057218158384785, 0.14006327488459647, 0.2279236595495604, 0.10231032647425309, 0.16082556860055774, 0.08680649785674177, 0.11959367679082789, 0.11829171227873303, 0.14598720154026523, 0.08438625038252212, 0.10851796876522712, 0.17516096733743325, 0.14679151150630787, 0.17452371481340379, 0.13448884041281417, 0.13564434950239956], [0.007210982812466682, 0.011778986645367695, 0.015487757409573533, 0.04842222297156695, 0.03025506197445793, 0.04553260048851371, 0.03963933195336722, 0.022605757003475446, 0.01351570868791896, 0.05197503603994846, 0.03334417189762462, 0.04930675167997833, 0.05675114967743866, 0.032804463553475216, 0.024560624078731053, 0.0595597927167546, 0.04237537439621519, 0.03725904171005823, 0.03320349409477785, 0.025684009306132793, 0.014960801017878111, 0.039019453106448054, 0.02226636730483733, 0.015091894911165582, 0.03168751274643, 0.0416065539320698, 0.03474865297903307, 0.01884613335278118, 0.09000939200632274, 0.061332939367275685, 0.02153604760678718, 0.014005629127495922, 0.03902028802258428, 0.03192188298271503, 0.027908984739042353, 0.07310143482754938, 0.061605133159901015, 0.013686629936273675, 0.01774190295691369, 0.03966484327975195, 0.06771756161469966, 0.04606592636264395, 0.01894622309919214, 0.06328102506813593, 0.03097355740464991, 0.015079250570124714, 0.050938500644406304, 0.03427764524531085, 0.026898984833678696, 0.09015420728246681, 0.03872346605930943, 0.07480312007828616, 0.0701789760205429, 0.016657231863064226, 0.012789430911652744, 0.008060490035859402, 0.03376350017788354, 0.028056898481736425, 0.011307038239465328, 0.028003493534924928, 0.0272735671751434, 0.02476329533237731, 0.05826056301884819, 0.010026932759501506, 0.02195928514993284, 0.01385934625432128, 0.03751540549274068, 0.0641522767546121, 0.03861943550873548, 0.01195972372443066, 0.015796056686667725, 0.002848854919648147, 0.008661999800096964, 0.036958123091608286, 0.03672861021186691, 0.0623945816187188, 0.040209019352914765, 0.05676624125044327, 0.0797697578673251, 0.031113259283301886, 0.017377894364472013, 0.03047183960006805, 0.026597492906148545, 0.023002010057098232, 0.06901694345287979, 0.056044098164420575, 0.020194560020172503, 0.03828474546025973, 0.019067805442318786, 0.045316449977690354, 0.11416255845688283, 0.013166240623831982, 0.04049008552101441, 0.09713674080558121, 0.06421279147616588, 0.030890878442733083, 0.058710901939775795, 0.030481921676255297, 0.02663472459971672, 0.07358328904956579, 0.058957792207365856, 0.006104534786572913, 0.02219777616119245, 0.028185165720060468, 0.04159871685260441, 0.035451021540211514, 0.033717049154802226, 0.018786902546708006, 0.010866157990676584, 0.027120066915813368, 0.011071754233853426, 0.008731131783861201, 0.02167233375075739, 0.048020286922110245, 0.03354169450176414, 0.035395972736296244, 0.061847822871641256, 0.0431113696686225, 0.033114733232650906, 0.042073379663634114, 0.03020438442035811, 0.001799271756226517, 0.0261033858259907, 0.04748453793581575, 0.0071783631028665695, 0.012214182042953325, 0.06729798842570744, 0.04162451390584465, 0.05296224830090068, 0.025537819201417733, 0.024442014037049375, 0.10509487197850831, 0.029533918932429515, 0.011023414444935042, 0.032251389129669406, 0.07659383336431347, 0.059357308855396695, 0.012234560490469448, 0.03417334010009654, 0.023275947896763682, 0.03405588780879043, 0.047266123874578625, 0.032560705149080604, 0.03408864249649923, 0.02837060616002418, 0.043061512187705375, 0.04357059580797795, 0.05829813424497843, 0.03474751007161103, 0.01448033925044001, 0.05438923129986506, 0.03127385818515904, 0.03154559184622485, 0.018376576517766807, 0.01095408671972109, 0.05669936632330064, 0.030132091815175954, 0.035853109729941934, 0.005710751693186467, 0.07079114395310171, 0.03729708791070152, 0.042509205886744894, 0.0503797153942287, 0.07557744727819227, 0.007510582727263682, 0.025068726208701264, 0.09379214097862132, 0.056372246181126684, 0.03163658286212012, 0.04061020583321806, 0.006144653434603242, 0.0318090616929112, 0.06582708141650073, 0.014553096625604667, 0.009240200561180245, 0.017127120809163898, 0.03288126099505462, 0.025698390272737015, 0.018837439092749264, 0.03390033736650366, 0.012986344954697415, 0.041173796489601955, 0.0023540921984022134, 0.02630580660479609, 0.018205940068583004, 0.007398643665510463, 0.04930275150400121, 0.01001301099677221, 0.01728770301269833, 0.03494039054203313, 0.025161669072986115, 0.013835599384037778, 0.09413065679837018, 0.026150788653467316, 0.03737277213076595, 0.06839843757916242, 0.01809067154681543, 0.004956105785822729, 0.02096449741657125, 0.009410311013198225, 0.012320694149821065, 0.048861689429031685, 0.04674280957260635, 0.04952569637680426, 0.04226077566272579, 0.01917748188134283, 0.08215666806790978, 0.03507321642246097, 0.06569358389242552, 0.03662439041363541, 0.04881681175902486, 0.030241603126341943, 0.026959321439790074, 0.029654538338945713, 0.043259513477096334, 0.04169194173300639, 0.0419814238557592, 0.0472656860074494, 0.06717036128975451, 0.07344181343796663, 0.0166215605349862, 0.04126745923713315, 0.08087704962235875, 0.0177518384589348, 0.021054072785773315, 0.030334206458064727, 0.05893858913623262, 0.06043127075827215, 0.09581693506333977, 0.06560257432283834, 0.026450306468177587, 0.027335827799106482, 0.05409007157140877, 0.012779984299413627, 0.05735489794460591, 0.018903503223555163, 0.05319508600223344, 0.01663408056629123, 0.04881592118181288, 0.06715510273352265, 0.004327553551775054, 0.03848063905024901, 0.06174977032060269, 0.06806294230045751, 0.022619215851591434, 0.04626474401447922, 0.01935269367095316, 0.048941158602247015, 0.019907770038116723, 0.09156548272585496, 0.08484379926812835, 0.036251386991352774, 0.04323944580391981, 0.05376834684284404, 0.059958878919132985, 0.030828901690256316, 0.013144207186996937, 0.04132827823923435, 0.04123923907172866, 0.05888069048523903, 0.0696685268485453, 0.047186999800032936, 0.04940222897857893, 0.03589123014535289, 0.040813832601998, 0.039130522927735, 0.051130742867826484, 0.04131419969780836, 0.026170351666223723, 0.018587684135127347, 0.012812488512281561, 0.016909235528146382, 0.040143068399629556, 0.04722482706711162, 0.025452422123635188, 0.04427800726261921, 0.045280589401954785, 0.04379196361696813, 0.04989495195331983, 0.05195017780351918, 0.0537623131822329, 0.12036097585223615, 0.0158872239626362, 0.036591390817193314, 0.05525528053112794, 0.014293628810264636, 0.008095355206023669, 0.05330794811015949, 0.05793106429337058, 0.040914423298090696, 0.04208100894175004, 0.04386179971334059, 0.020849692737101577, 0.06741502511431463, 0.019063842373725493, 0.019197540277673397, 0.022913284446985926, 0.026649428400560282, 0.07101499795680866, 0.1321806275518611, 0.031427152498508804, 0.04376781413157005, 0.01220881167682819, 0.008852253067743732, 0.0964631156239193, 0.017464564225520007, 0.06767721104552038, 0.09981186405639164, 0.041542261678841896, 0.019185044366167858, 0.012085577127436409, 0.07983712261193432, 0.06293244572589174, 0.012813547928089974, 0.06916817088495009, 0.03407972188142594, 0.017509733188489918, 0.018695447688514832, 0.005969620688119903, 0.025770766369532794, 0.05062187075964175, 0.061170776389189996, 0.03247794084018096, 0.016511503745277878, 0.032453282983624376, 0.031257026275852695, 0.06396295488229953, 0.003439284187152225, 0.021986894898873288, 0.04484592463995796, 0.007249923764902633, 0.008263175204774598, 0.033372674079146236, 0.02071664606773993, 0.018745659544947557, 0.04478943235881161, 0.05725042210542597, 0.051870241077267565, 0.09989108089939691, 0.010666385751392227, 0.06612134297029115, 0.029146621745894663, 0.028938037430634722, 0.04879579042608384, 0.014040976693650009, 0.04125906925764866, 0.060799272105214186, 0.030854548458592035, 0.015377128238469595, 0.019320465908094775, 0.023931492505653296, 0.015660503413528204, 0.18895347020588815, 0.0917539065994788, 0.1392818972817622, 0.12506764673162252, 0.12609210738446563, 0.10097067570313811, 0.22789253387600183, 0.11711931932950392, 0.11690400744555518, 0.21726462291553617, 0.10512780107092112, 0.14465080137597397, 0.13168030127417296, 0.16023490810766816, 0.11430382626713254, 0.061960376988281496, 0.17127622500993311, 0.1495671141310595, 0.09713265899335966, 0.2128514862852171, 0.1703606522642076, 0.14052499464014545, 0.1001952427031938, 0.16389464610256255, 0.04955883698130492, 0.15688765881350264, 0.13095335278194398, 0.14480190264293924, 0.1760865590767935, 0.07678639100049622, 0.1981967710889876, 0.14106305170571432, 0.1271901890868321, 0.1495836046524346, 0.16588257771218196, 0.1551838658633642, 0.11378192575648427, 0.12401729996781796, 0.10503600482479669, 0.14006250305101275, 0.26115770044270903, 0.12314742125454359, 0.08896128652850166, 0.15380449534859508, 0.07547147601144388, 0.10563142990577035, 0.18047318619210273, 0.08308723219670355, 0.06259384084842168, 0.14068756951019168, 0.11874929085024633, 0.14661430148407817, 0.1598248418304138, 0.09134404070209712, 0.11913106645806693, 0.09061142962309532, 0.1389268835191615, 0.1104947978456039, 0.14383825357072055, 0.13523833535145968, 0.12214462389238179, 0.1696483834530227, 0.15674578986363485, 0.09664231460192241, 0.06345534813590348, 0.18496361008146778, 0.14231542591005564, 0.22348110418533906, 0.15542249602731317, 0.0965929617814254, 0.11669724510284141, 0.13923717546276748, 0.07460087741492316, 0.19308603048557416, 0.22004693455528468, 0.18249435117468238, 0.14325764175737277, 0.13624471728689969, 0.2647824981249869, 0.1130086746707093, 0.08647860217024572, 0.08913733880035579, 0.18078491790220141, 0.12292276573134586, 0.16164843225851655, 0.1523779093986377, 0.12266892154002562, 0.12366003007628024, 0.07672134175663814, 0.13149430422345176, 0.19040585320908576, 0.10954055920592509, 0.08851193095324561, 0.2620447747176513, 0.14999908860772848, 0.05895177338970825, 0.13141384057234973, 0.1127170403196942, 0.11009733323589899, 0.20126773364609107, 0.12253631459316239, 0.15841395972529426, 0.13226587063400075, 0.16202452301513404, 0.0779398666054476, 0.1897594128968194, 0.10307351403753273, 0.13736671098740771, 0.14113478770013899, 0.1429353715502657, 0.13875461620045826, 0.14641715737525374, 0.1861724053742364, 0.15218268003081903, 0.08968351496150717, 0.2175375699880533, 0.14857851405395195, 0.13742510316660628, 0.1398981618694961, 0.12408013019012287, 0.11455986721557565, 0.1026013151567895, 0.1196908981364686, 0.17332099028863013, 0.14855366694973782, 0.12195360992336646, 0.17295126715907827, 0.1337729350780137, 0.26275601936504245, 0.10686856781831011, 0.19243840273702517, 0.14759638550458476, 0.18260880518937483, 0.08902564557502046, 0.0775124118081294, 0.24994542240165174, 0.12994426942896098, 0.08914251899113879, 0.09848396890447475, 0.09397703222930431, 0.13730972888879478, 0.0928878785634879, 0.11510672615258954, 0.13311015267390758, 0.08878579828888178, 0.1368179966812022, 0.1826752719352953, 0.18515762232709676, 0.11326666004606523, 0.3144799720030278, 0.15377163304947317, 0.09673877895693295, 0.09023456703289412, 0.15341117192292586, 0.05330111293005757, 0.1393073529470712, 0.17189660109579563, 0.0805780160590075, 0.07412264487356879, 0.12667326838709414, 0.18145546317100525, 0.12658397317864, 0.23530347214546055, 0.19702799239894375, 0.17367598920827731, 0.12564603210194036, 0.18247355619678274, 0.1127533832914196, 0.1556803923449479, 0.14116775389993563, 0.20229721121722832, 0.08211977590690367, 0.15314787277020514, 0.10295028783730231, 0.06303308095084503, 0.0837175604829099], [0.08565628028009087, 0.041215397577616386, 0.038846421375637874, 0.03350430881255306, 0.016171553725143895, 0.029470713925547898, 0.014451792540057795, 0.02237368556961883, 0.01808856199204456, 0.006044352176104439, 0.019300765598018188, 0.06273466337006539, 0.03667170232802164, 0.006559910571013461, 0.010671774671209278, 0.02787489789625397, 0.03729006719368044, 0.034667139188968576, 0.06239159076358192, 0.013773777554888511, 0.043517569356481545, 0.0178354079980636, 0.03213165844499599, 0.045874010684201494, 0.09278549187001772, 0.01438058439816814, 0.07496602149331011, 0.01722120101476321, 0.019286701899545733, 0.05206590831221547, 0.021201159033807926, 0.02908106969698565, 0.05906446480366867, 0.04409693065099418, 0.027191765802854206, 0.0381625397130847, 0.01303494356761803, 0.06396461729309522, 0.020652869607147295, 0.060651176536339335, 0.0519315832934808, 0.018268653402628843, 0.026862625163630582, 0.028882174119644333, 0.024658043948875275, 0.06021166926075239, 0.036394272683537565, 0.08277029803139158, 0.030197174455679487, 0.06511081985081546, 0.004665315627789823, 0.017712486078380607, 0.05590039239905309, 0.03933804968255572, 0.04792527717654593, 0.05227364286838565, 0.06616942671826109, 0.03075043441640446, 0.04154778696829453, 0.012198931835882831, 0.046790570486336946, 0.008056080750975525, 0.011421398558013607, 0.08103822925477289, 0.013991938358230982, 0.06662860090727918, 0.03221257480618078, 0.0208900117650046, 0.0189467184827663, 0.02173145880078664, 0.02570897515397519, 0.022950054153625388, 0.02355014734348515, 0.04990665562218055, 0.02803256531478837, 0.010594403920549667, 0.03720299471751787, 0.03469614232017193, 0.030796963364991825, 0.06295583822065964, 0.03062382216739934, 0.04218978181597777, 0.049520753673277795, 0.0621169590158388, 0.01247656835403177, 0.02260555291286437, 0.054736300371587276, 0.023118230383261107, 0.03454963123658672, 0.02648536923516076, 0.022280800221778918, 0.07319411422940902, 0.04572468686092179, 0.011266768378845882, 0.010165374842472374, 0.042641946420189925, 0.03848161126370542, 0.08599563472671434, 0.043372735526645556, 0.04895887366728857, 0.055364480140269734, 0.030299995305540506, 0.0038315407755362685, 0.012129568858654238, 0.038189090046216734, 0.02400106513960054, 0.024317676470673177, 0.041232218354707584, 0.009142992203123868, 0.02883622219087556, 0.01491370896474109, 0.054377831911551766, 0.03116559368208982, 0.006271970260058879, 0.0369508834410226, 0.02948649569589179, 0.1048051226825919, 0.06425196945201606, 0.06417043710825965, 0.03510378177452367, 0.017030686140060425, 0.0056493913871236145, 0.047891873109620064, 0.07204980414826423, 0.05479243271111045, 0.08810187951894477, 0.028361761615087744, 0.07202662687632255, 0.040087592860800214, 0.08655560741317458, 0.03793790645431727, 0.02986281837365823, 0.025515773704682942, 0.00930008167415508, 0.040420527730020694, 0.07828053465345874, 0.028585873515112326, 0.021180584844842087, 0.022948746118345298, 0.057666366192279384, 0.02691846249945229, 0.03487956782919355, 0.04283499016310088, 0.029923132715339307, 0.014753588748135371, 0.06082915839215275, 0.02898971131799044, 0.026953688538924325, 0.068571202136809, 0.019701417731994297, 0.004998894773962093, 0.019544520291674417, 0.013497966720024124, 0.02472969459631713, 0.030836156183795538, 0.07600478333188221, 0.015865746208874043, 0.009892831312754424, 0.014991720745456405, 0.03529078443534672, 0.034978061958099715, 0.021792583938804455, 0.029059499174763914, 0.051206312055001035, 0.03987113435869105, 0.0670763237576466, 0.035559089374146424, 0.03905563280568458, 0.04416001320350915, 0.06070268158509862, 0.0029520111274905503, 0.03680998670461122, 0.04686583168222569, 0.014751591443200596, 0.012649265190702863, 0.04037956859974656, 0.055728800434735604, 0.01773264280927833, 0.053632619165000506, 0.013190051504352596, 0.042436185976839624, 0.035384532529860735, 0.021637452809954993, 0.013498977896233555, 0.038455305839306675, 0.0662879402807448, 0.03137718369544018, 0.019039538892684504, 0.06438144453568384, 0.031050334437168203, 0.017180969189212192, 0.007861359754315345, 0.01948583867488196, 0.01543517253594473, 0.032221896180999465, 0.006775727115382324, 0.009619630054658046, 0.050468513363739476, 0.034102691352018155, 0.04901628250081558, 0.010008226927311625, 0.054507340391865, 0.036628045490942895, 0.0797247837181203, 0.018227490181743633, 0.02779541759082349, 0.05461318920424674, 0.03695939958561212, 0.07028513282421045, 0.029660373475053348, 0.07705737138167024, 0.05064548218797427, 0.011117895410279743, 0.06843201976153068, 0.015597541460010689, 0.03486413486825768, 0.03796278695517685, 0.03690453631861601, 0.08371206859010272, 0.02982737154525239, 0.07188904754002579, 0.02582209144748049, 0.04099239704373758, 0.011576914675970329, 0.015459729274880374, 0.01841871937358519, 0.023462789140467066, 0.04638916507246904, 0.028996581750106998, 0.020971288067812566, 0.08925873931730166, 0.10467655301908962, 0.03408254575333558, 0.04350121242168825, 0.03862617049890105, 0.01815694533433998, 0.0013023350061303063, 0.025616052698751446, 0.04628560578566976, 0.05974895873805508, 0.014020396010892, 0.021338823717087507, 0.028237182850716636, 0.02471900952514261, 0.0460870070673991, 0.030343323742272332, 0.06300167326116934, 0.007242369165396667, 0.025061000451387372, 0.027467718573461752, 0.030589872621931136, 0.07368514139670879, 0.03867532665026374, 0.01603457367309602, 0.06259377405513078, 0.019604927401815075, 0.019163481265422888, 0.041819721009233035, 0.0023356616566161392, 0.09218737279297784, 0.052104106653132476, 0.0653621407400351, 0.011496424122015014, 0.06795611014240421, 0.03929382510250434, 0.042045734662679024, 0.06945055807591416, 0.08072412267210893, 0.06345024958136491, 0.013622132664750097, 0.06404709216440096, 0.03373924679181073, 0.03781327759497799, 0.08643899374874309, 0.019080379279330373, 0.018930804981209803, 0.03786971792578697, 0.011025937747035641, 0.05243051804427523, 0.026227292946714442, 0.024129341654770542, 0.015250965916493442, 0.004478488763197674, 0.03572779809474014, 0.015632504037057515, 0.05456914645037614, 0.024939765062299557, 0.01500277689046925, 0.03909311126335524, 0.03631882223999128, 0.10235496665700339, 0.0834649037278723, 0.038513842737302184, 0.10157295080716722, 0.020216907942085527, 0.016012520754884463, 0.035105154747725464, 0.011033481678168755, 0.026864461979130283, 0.06357574675348587, 0.1135551328479778, 0.06694529016385786, 0.020745376459672116, 0.019410573768254835, 0.059489336927072145, 0.010994225776812527, 0.017907650508277584, 0.03740661035408266, 0.01719070987746818, 0.050268983250134625, 0.03435519596678205, 0.0823478601523675, 0.03140186752716545, 0.02990904304169817, 0.020556438648782205, 0.048452751216245815, 0.011574349628062919, 0.06442442972911522, 0.026752692683658097, 0.03231102440622635, 0.02768575599475298, 0.10737541015259922, 0.014193019560480025, 0.02592812765215058, 0.046124689615680836, 0.02133125195541652, 0.03104252704360988, 0.030823268789390568, 0.07336285634664819, 0.04496336208831053, 0.05519888101844117, 0.033317714332952164, 0.02074248950520996, 0.022298448493529577, 0.08702061488293111, 0.04951385912136175, 0.006906166063345154, 0.06669568363577127, 0.022202581567398738, 0.03726606613781769, 0.08290519821457565, 0.03486186389636714, 0.07678437978029251, 0.06567431773873977, 0.0024643115648359526, 0.033213420319953, 0.03088845533056883, 0.018224178347736597, 0.03129946970148012, 0.010039373937615892, 0.04451742410310544, 0.011103208307758905, 0.19668356166221201, 0.1757240793085657, 0.15643589867977425, 0.14809889369644225, 0.16692532488377765, 0.08284461669973098, 0.14064639515709132, 0.12371640361379832, 0.19738619739655405, 0.19026730908080935, 0.1655644635320641, 0.07497343554859981, 0.12743560248054564, 0.07311104563996196, 0.1349530092556961, 0.18941861868370324, 0.09843129868386313, 0.09426721939234994, 0.1339239621302113, 0.08778298608376645, 0.1054313246277161, 0.2008936763741076, 0.13951297238236293, 0.1934031056589447, 0.1859977631829679, 0.16520649602171034, 0.16783211060101166, 0.13868920330423862, 0.11752034624805674, 0.1127382880076766, 0.12278335329028778, 0.09175265979138203, 0.21875022444874048, 0.1327519179903902, 0.21158648072741926, 0.16142020700499415, 0.1381702342769131, 0.18000769632635638, 0.13848487520590425, 0.16450785304186866, 0.19669574772706255, 0.12372978453640826, 0.12059867833158933, 0.15226029383484274, 0.1549942174460739, 0.1359664712799713, 0.08524049946572632, 0.10892615740885958, 0.07664020275115035, 0.11247234680922702, 0.09133100116741844, 0.1183239214878995, 0.18232919363072142, 0.1941094224457629, 0.1787800356396474, 0.1369264244567603, 0.1582712892559357, 0.10822050113347359, 0.1411530890618451, 0.10075923783006147, 0.1300661894492805, 0.15560714236926287, 0.11294631942291744, 0.18790552800055593, 0.12347106443485245, 0.15591020579449832, 0.19261245121015236, 0.10299908404704183, 0.10936913051409647, 0.12910087796626613, 0.1626030122861266, 0.11146065109642223, 0.13754883402725682, 0.1422694424400106, 0.13245890324469656, 0.1308060809969902, 0.13835213467245921, 0.1227786554954946, 0.105680508131627, 0.21900797233683988, 0.19413919741054997, 0.12346484523732215, 0.1297291208175011, 0.19356948032509536, 0.1823191746370867, 0.10592724254820496, 0.09868780718534254, 0.12955526530276984, 0.09707520934171043, 0.1763542665867135, 0.12160179481725208, 0.19759739778237417, 0.16910063393879682, 0.14212482754373923, 0.12790511478669941, 0.14426950074266642, 0.14252021413994953, 0.15301820472814143, 0.11908221829799004, 0.14832118176855147, 0.15369626053143293, 0.13084946695016697, 0.12475137307774276, 0.05843620339874178, 0.08986294400529005, 0.12688197515672073, 0.11674092791508883, 0.13752771250437945, 0.10420214995974675, 0.19222948816604912, 0.12324334384175017, 0.20109298755414784, 0.15075198258273304, 0.08005516559933312, 0.21543313603615388, 0.1632323386729695, 0.2306988465716131, 0.18129557487554848, 0.18203888030257076, 0.18121126689948142, 0.09399937829584815, 0.15583214670186862, 0.2191509841941297, 0.132309019099921, 0.22621099051320925, 0.19382290891371667, 0.19596482132328674, 0.13650902576046064, 0.1348065389902331, 0.16287267906591296, 0.1413886615773663, 0.08069939431152306, 0.1267015145276673, 0.16083353926660493, 0.11065505721489899, 0.23625080881174654, 0.07772133380058222, 0.10441018137498759, 0.1301665575010702, 0.11264382002991624, 0.13193763355957344, 0.1100152220169548, 0.16404919093474746, 0.2004383984603919, 0.08343992303707637, 0.18935197382234037, 0.12412431024131365, 0.12606210977537557, 0.14032255159690976, 0.05499974053236656, 0.1933272581663914, 0.10332016681786627, 0.146809367579408, 0.22751703683752567, 0.13698428228963166, 0.15307068941183388, 0.08095493802102283, 0.12463616207242012, 0.1402735846932046, 0.08301580790430307, 0.1449691382003948, 0.22785088454838842, 0.1565299287904054, 0.17435747373383492, 0.15293340693460777, 0.2892454370157793, 0.1518152724020183, 0.13671363587491214, 0.09759815628058277, 0.24994957842864096, 0.11341031757183373, 0.11217887935345061, 0.16562954988330603, 0.09479618514887989, 0.11322449863655493, 0.1809029490686953], [0.024745750961301383, 0.04486770667426754, 0.02010553755098954, 0.07649223334738053, 0.0444582081399858, 0.036232224738341756, 0.04280410197679885, 0.04207186939311214, 0.06626952017541043, 0.01442931195924757, 0.013796628281852463, 0.03353937529027462, 0.05161831904842984, 0.01388749591569649, 0.010770281787699787, 0.051745237433351576, 0.006194440411491087, 0.041550143287167884, 0.06625967187574133, 0.05998628643283155, 0.015975478308973834, 0.029328598211577628, 0.028252276279090438, 0.06721094192471355, 0.041522142055328004, 0.0325842980237212, 0.037252933834679425, 0.030870452683302574, 0.025907429153448902, 0.02621193605591543, 0.033272740183747374, 0.05568401553318836, 0.03320481882838067, 0.026209724455839023, 0.034303182546864264, 0.03180719148076605, 0.024204903420468327, 0.07916690388810821, 0.03805956672294997, 0.08684003551024944, 0.01098904836908332, 0.01787816498108441, 0.04052241347380914, 0.02964107392472215, 0.023482665710616857, 0.08178147530998103, 0.09944640085450374, 0.04673177383665461, 0.06844569754321128, 0.05516083852853626, 0.026210067699139472, 0.03294032852863893, 0.027369363597244956, 0.06448412066674791, 0.04407783519127406, 0.04321765634813346, 0.021347623733163346, 0.007901041462901048, 0.015133183369471226, 0.056553838585386984, 0.040952176350401714, 0.04137446951062884, 0.01646066848479677, 0.06338702602079138, 0.025602052082831506, 0.04411017056554556, 0.014106046346569201, 0.03329233659314923, 0.059720137433032505, 0.03155750331643503, 0.09121063965721987, 0.012089839838154148, 0.021263655289658345, 0.08155439296388067, 0.04874250793363899, 0.06672177754808217, 0.04314240257372148, 0.035457667472655885, 0.019712247521965764, 0.04236267624946777, 0.032793583668535575, 0.026716733773355372, 0.02088517852826044, 0.023183548655651975, 0.015501336856686976, 0.04325755420722999, 0.05943730866420083, 0.027250104176346213, 0.014360074219439412, 0.08637640843517147, 0.07996434898814186, 0.0847947878355626, 0.08263162031653337, 0.016356901396648027, 0.04352219664724544, 0.0447897663252661, 0.0036976320552639663, 0.021898605300521012, 0.05560262419749051, 0.03304780264443252, 0.03629912935139146, 0.008271056813100586, 0.06546472039190121, 0.032576082448940724, 0.028817581296607386, 0.05334116664016619, 0.06614188561798073, 0.04880360153038055, 0.010914635076915147, 0.03767913811316248, 0.04008561132650357, 0.01651556885917671, 0.08843415387673303, 0.06892297271406278, 0.04926384812279139, 0.043892413305002265, 0.04839188026380725, 0.03777342055400368, 0.028198541076562833, 0.020412226367625408, 0.015152628566283965, 0.015954275149852037, 0.020502961342572235, 0.06558882974786684, 0.0066583341958903475, 0.034125575475627556, 0.015930279660096858, 0.02092360136884963, 0.04666896958951838, 0.03506068896967918, 0.018014020679402165, 0.02744022942351876, 0.02566163911978947, 0.0068823139008600265, 0.06739187752828002, 0.030425331060541794, 0.03964524687035009, 0.05258779026917182, 0.026420960093673784, 0.029736428768956102, 0.05621816519123968, 0.023470937921956647, 0.06739643431501463, 0.011791619854193414, 0.07716247433563694, 0.06752000932465307, 0.06105866013967898, 0.04243265706463717, 0.10465794737683609, 0.02268193660711404, 0.0069751241062476765, 0.03785337583394721, 0.05883403166080825, 0.03287982122856192, 0.03913969216227997, 0.044032590158167295, 0.01382512396958191, 0.03621657655457966, 0.04837651409616228, 0.08793627668637782, 0.06362170053762384, 0.049776501473388635, 0.0475775698578218, 0.0468450923654018, 0.020138962026976515, 0.017054358795576263, 0.025703557475935668, 0.021315039739420172, 0.03168792463839054, 0.02422085959551623, 0.057935966178774834, 0.10591263708192855, 0.03769322778680362, 0.07543758212705143, 0.029235490219434723, 0.08521767100319266, 0.0020522959903246374, 0.04975265997927636, 0.015726877390989102, 0.054951697602518834, 0.0603357823274564, 0.0481799562840024, 0.0061769247986376286, 0.007633450841240119, 0.021036914331489243, 0.060626745034824125, 0.05149863660335541, 0.07125512725906447, 0.034120881391572766, 0.053549788062809967, 0.02505443615518743, 0.03069585687626386, 0.08869868499459699, 0.02349095364479581, 0.031807035629753955, 0.02158407569368137, 0.03665978343633469, 0.004781637535415939, 0.019612968571891543, 0.02285736547491979, 0.02847729359928053, 0.012818141822208418, 0.021969703047943767, 0.03200785336957779, 0.018953664985019714, 0.06628159491810948, 0.03993491824076045, 0.08410635680775158, 0.01331083789409604, 0.10481672245077789, 0.06523424643091857, 0.05422538364655338, 0.024369925522478297, 0.03625086748797912, 0.05602272431133315, 0.04906512695015408, 0.014097373423282988, 0.07140507077565417, 0.05695992324035615, 0.023872565980127547, 0.04965844433172606, 0.0859466455585789, 0.05093433348520193, 0.0847144503495656, 0.07289221597602591, 0.04472904751310125, 0.03359725909831468, 0.02347204372199485, 0.01209866119097569, 0.03822082799160853, 0.04317297163652256, 0.054664564377162606, 0.0034678116480790777, 0.05043189950811211, 0.06670208837022074, 0.052000914729433134, 0.05431712052086368, 0.051798126587527804, 0.07896095048636198, 0.03838292417640332, 0.012956163664057385, 0.033859118484542705, 0.024234390803030692, 0.0404979003360495, 0.03186783236742485, 0.03897542890626937, 0.09338942196336575, 0.04692169313784689, 0.02474935037753312, 0.08777062932495028, 0.008423382623732323, 0.03242781247536186, 0.04866175484494306, 0.04973861483449582, 0.05130645746248774, 0.02887682323489571, 0.017928849956660997, 0.04220906652335543, 0.037816105177626014, 0.0061939139504829654, 0.03404547918762546, 0.10225898469798267, 0.03530773879901972, 0.01787748962669866, 0.05625182900985237, 0.025049610339920036, 0.0373165024939226, 0.09801943640923128, 0.025163596801576205, 0.061033375168335624, 0.04310664218792226, 0.05265980456897523, 0.04005335387773812, 0.05529416535864584, 0.07621523414854892, 0.04181832577160094, 0.023532608538516797, 0.03351690305862576, 0.027810154788312502, 0.03693382517667487, 0.04165528705925681, 0.030936500115785748, 0.017688221560092643, 0.052428788840188645, 0.017203934949066024, 0.004353973081379081, 0.0725504792353604, 0.016376980202039704, 0.03814167794189416, 0.1411867083515972, 0.03673079583677463, 0.028602807469724212, 0.04646916488127317, 0.042338114872109145, 0.05188436043681577, 0.010291594680893468, 0.02141264885722194, 0.040423373866360635, 0.02703219848626759, 0.03181414911523461, 0.05302691904944368, 0.0026898221813098644, 0.026316474977647886, 0.0416889286134392, 0.012388680443109479, 0.009583737009961624, 0.036925887907273136, 0.08779001422226429, 0.042269443947589025, 0.025001613794302102, 0.023481047828681767, 0.12350038668955676, 0.01951529637153726, 0.01728697014186764, 0.027186082807020284, 0.023967809502210002, 0.020353160689410288, 0.016003524069674313, 0.01215889760715072, 0.034864899280364625, 0.031954511505318806, 0.0445450097322464, 0.02671443497092696, 0.0405635655624792, 0.04954367490427103, 0.06250295744393952, 0.027169178538315464, 0.008806925470707938, 0.03150395365082659, 0.028294801340962294, 0.019543852358765434, 0.020492816183832474, 0.04932672658469528, 0.02167473274312215, 0.06727037311065942, 0.07372226362349465, 0.039051090861903504, 0.01788855133781908, 0.06375409226166084, 0.021692700138373766, 0.05571066605625674, 0.029408789123408496, 0.04876279454038013, 0.005485626761583262, 0.004797775072802324, 0.022070844788686372, 0.015592641429975629, 0.11643276593531482, 0.05776814061391633, 0.03554226488631684, 0.012630499059014255, 0.03799938967858907, 0.1053640637837816, 0.2401036536321044, 0.07123966090148315, 0.15088401065440848, 0.15403184486785904, 0.10087581438710913, 0.16123536770464852, 0.1608383929124102, 0.15401994081912562, 0.2111195510951802, 0.1794425953994505, 0.16227487911237404, 0.21038923325249925, 0.1302691816817969, 0.17632756411330774, 0.113166054507019, 0.15441736089996994, 0.08784428748185746, 0.15649083245079964, 0.20466905581997707, 0.13148268219083548, 0.12443340732716024, 0.13206258154241368, 0.1643170023453422, 0.12505572783993557, 0.08515231747878715, 0.12718453392153606, 0.09268421097658575, 0.09017886142828502, 0.1383441491634585, 0.1264878798974678, 0.2134951509651728, 0.11685404606396332, 0.23178686475148425, 0.14384957874426618, 0.13255949394078925, 0.1376035451539792, 0.08386427565710619, 0.1874094468075782, 0.18767718400340527, 0.07854978583054617, 0.1321012622793205, 0.12487329309806228, 0.2046720392536372, 0.14863773743854836, 0.16808124957606196, 0.23765713413013145, 0.18357309250859544, 0.3067683451808989, 0.1867395397857763, 0.05962022580206394, 0.11949859283049591, 0.12038151849992573, 0.13590396760264412, 0.1168575044721365, 0.11940824377234094, 0.0774506873858627, 0.20821747166337445, 0.17194285173900425, 0.12013390092761256, 0.15769671852467582, 0.1910612141364254, 0.12601640832144767, 0.24235014949226752, 0.10046014489489608, 0.15535407001152635, 0.11330140740028583, 0.08919067695387639, 0.15971478132996708, 0.19606596120866016, 0.18194824922829866, 0.1321181980893016, 0.15167509554885328, 0.2095611597178504, 0.13098153955070302, 0.16030630271416157, 0.12705301051028073, 0.22674925538012758, 0.1527457474730909, 0.15613957395544276, 0.12566382880322635, 0.22476190264569595, 0.1359515541116707, 0.09227047848980874, 0.14921854221029207, 0.16856964211910963, 0.12089156691217795, 0.1332096301484853, 0.13690620835404843, 0.14531071909004822, 0.13944056845502928, 0.21325414592865855, 0.1589503395371139, 0.2837225521216169, 0.1415697901393287, 0.24474470381392166, 0.13848117931047454, 0.21488194295670837, 0.1343178644310683, 0.06931153155164793, 0.15255658887326717, 0.0948427029652521, 0.162834384245798, 0.11617354117333889, 0.1565936199040152, 0.18257871852256358, 0.12742717168293893, 0.28400786337442696, 0.05504918241058476, 0.08875842046109028, 0.12925978662678972, 0.06270010897424072, 0.1441610135952942, 0.16217304160818458, 0.1780467343633063, 0.17316145822405815, 0.14330904290545732, 0.1345066964859143, 0.18433858815114945, 0.07393832507659681, 0.1636382340802811, 0.1430343888932839, 0.14832826185738668, 0.14606016949983314, 0.1661116341711022, 0.14270112005760893, 0.15706713980762288, 0.09797018006793223, 0.19363415107363835, 0.06960280225030147, 0.12647086987271905, 0.15849575924221426, 0.19706349674379453, 0.09134055260801688, 0.22536117205163464, 0.19037900230614468, 0.0869134116510395, 0.08604617498349398, 0.09673922424553894, 0.12394534875056706, 0.16800954326754436, 0.13369958120165393, 0.15147962869377807, 0.14806040591793135, 0.142634000221733, 0.14391364093171433, 0.10177785035921261, 0.11532069474924356, 0.1322537290980108, 0.06931073003215715, 0.08810659957816824, 0.07010128058027476, 0.1671195449307561, 0.08368785231141374, 0.12942010536789894, 0.09845953740295954, 0.18530303874285892, 0.2079776392201893, 0.25922796805389225, 0.15798057516803965, 0.21001988119678572, 0.08512505839462392, 0.1544970675604418, 0.09847016495768912, 0.10666250309441239, 0.18092646030709147, 0.12718349491478875, 0.13064415921689942, 0.14118461549514905, 0.06580115819815546, 0.11949440711759962, 0.2000932552618906, 0.12686245667282492, 0.17269869946176186, 0.19142345641739666, 0.17259570420719683], [0.021349736998672597, 0.021986880055919755, 0.11576251010410488, 0.0688070418254938, 0.03639914488303475, 0.015926982669043355, 0.02651003080245573, 0.023471283020626288, 0.036671642956207506, 0.07766856710077263, 0.08615789047325961, 0.10003361778217368, 0.0502314973709872, 0.056595105706946924, 0.00983454767265357, 0.01054402879162808, 0.01764642194757471, 0.04407730826642364, 0.06008680291415658, 0.024703925373614766, 0.006814733933424577, 0.037805985994054936, 0.05425518458650913, 0.02517690350941848, 0.0043667626050591934, 0.051165056065656245, 0.06009678851114586, 0.04452085282537155, 0.024360880597669166, 0.05378296715207398, 0.08269241705420427, 0.036359317527967505, 0.06675635420833714, 0.012207370054966304, 0.025328433366667014, 0.053422647033585235, 0.033834330752142705, 0.02167743230529595, 0.015269067826011451, 0.03393177474208642, 0.03777132398681715, 0.04662024759454653, 0.020678922701335978, 0.007309894863283262, 0.019165453522873577, 0.035004018573090434, 0.044001661153743044, 0.04485719786316622, 0.02283358891872922, 0.07721267320448533, 0.014350844685395714, 0.03299635325674899, 0.024302403071487788, 0.015052356066007633, 0.017571214557392523, 0.06376506862579845, 0.041787693626247346, 0.047469509445363656, 0.0703091116156429, 0.02681644316908205, 0.05371517938328907, 0.05753990793891717, 0.02095819843816571, 0.023944185086293146, 0.03607900463975966, 0.04472160748264287, 0.007717785720160464, 0.05767026246758178, 0.0591105373314349, 0.036501698559732176, 0.032183798030018806, 0.012489842592913192, 0.04546022253634874, 0.025252060804632492, 0.0308636527552153, 0.025524694319756236, 0.028568726193043403, 0.05817557597765699, 0.01945067571796244, 0.04965678192093037, 0.0547092713532038, 0.008940795923990663, 0.03660067879536655, 0.06831103484728374, 0.09883898266707547, 0.03408237134863157, 0.03921693118172698, 0.021872400066058617, 0.07872499205404893, 0.031464497369597666, 0.01787898134352872, 0.029918859800091013, 0.05684000701876357, 0.04176298010861501, 0.05689198704203591, 0.018777469849737827, 0.03591998836782295, 0.038960537713137455, 0.032151974737644196, 0.028718593639496248, 0.01317903339440818, 0.01603482785867527, 0.01366122807667125, 0.044128746521892026, 0.05222652391239535, 0.02660740243300097, 0.03177020655130036, 0.044881889116368257, 0.09160115776467137, 0.06467900864663534, 0.01389353792546899, 0.06276345127844252, 0.05952861138212029, 0.058819611731451005, 0.007907530616648728, 0.021030388998042326, 0.026874814939219505, 0.0029615537550853333, 0.020497701370914, 0.06538016008562408, 0.06802423929912038, 0.029325165778573137, 0.02471192758093821, 0.053956269766786136, 0.014675690144940745, 0.07287579224794172, 0.03752647833607625, 0.06865755101898685, 0.0531362670881208, 0.02661378304765094, 0.06442585465265438, 0.01893744720291579, 0.010590796155156568, 0.03912889020284638, 0.10697455392801203, 0.029954199017083738, 0.03758816194022074, 0.03622668831667397, 0.03217262128600851, 0.024870828819985036, 0.03783488522458356, 0.036142116878181696, 0.04065201472258195, 0.07972086517838761, 0.019161525706294924, 0.057725853039301, 0.015267429535015253, 0.01891276151582133, 0.015275507812475553, 0.009903970021696296, 0.029055205850454513, 0.019398836702748667, 0.02483275664417306, 0.027828459860756993, 0.037997033359715715, 0.022455917387560476, 0.0559124968276592, 0.029704796579608228, 0.01828695476433495, 0.03626478275691625, 0.03547587235516403, 0.061925948757561855, 0.01847674047894543, 0.04656249366234988, 0.05609460873529315, 0.028282811945246067, 0.09354070134577341, 0.020552781716105528, 0.06583330061403103, 0.01342097075394122, 0.036120806107646786, 0.0898991608119104, 0.03657279259641655, 0.041808763198787346, 0.03309282874397468, 0.052342135677463375, 0.06861412795842625, 0.014126163187029306, 0.10764766702777706, 0.05677680943335872, 0.02846619663614547, 0.03159532687277533, 0.044184607977513224, 0.027784931044152472, 0.059987303175148554, 0.0956622492230963, 0.0352073299291078, 0.05893441826628987, 0.07316466580959968, 0.06923566179466434, 0.09274266252759844, 0.020921148570778314, 0.07538594349171035, 0.06688711320748553, 0.06947284477064386, 0.029180875571910292, 0.02786298828141298, 0.048395602134405635, 0.024338642142538447, 0.026892235000559594, 0.035505543419276364, 0.024102214301819913, 0.009164467173832236, 0.059503315278561786, 0.04424859223945532, 0.014258970513765235, 0.03525090512994211, 0.011462877191661391, 0.04439024967723526, 0.06487118036602624, 0.00952700724155875, 0.04433589107065927, 0.06675338561763056, 0.02243041162728332, 0.027257310430286452, 0.04009295858850237, 0.06162672594655305, 0.09204973408486694, 0.03108275144768413, 0.11301559890853241, 0.018059638641716447, 0.028589812463906128, 0.019642465231299866, 0.026139012625208125, 0.05370928301999811, 0.05259120043774601, 0.008261281800514553, 0.025730541965458542, 0.02431547785818111, 0.01840756489400519, 0.028447513068385888, 0.0688638532301411, 0.0192752004659269, 0.07487839611712843, 0.056890940613811836, 0.07418372362735681, 0.05098910769447684, 0.039171025637187995, 0.03764749664696865, 0.06076364530599676, 0.009781349599506939, 0.06091141804063227, 0.02971430163597688, 0.014490146731986897, 0.02718046474910807, 0.06747446372173727, 0.07488155024475418, 0.014205239949660609, 0.03778212965698913, 0.023783972101227846, 0.03541467485774774, 0.008472951594740152, 0.013677213009941624, 0.01664187126152683, 0.05394840300141368, 0.027095253208244685, 0.04989949018636253, 0.045852792682126164, 0.02922046358435182, 0.009310498644481413, 0.044162677513668314, 0.08193797199055552, 0.02291626231453847, 0.015101951012184145, 0.049533618803252466, 0.020241441488906275, 0.0017748352684066049, 0.02202349205617793, 0.0945835821039509, 0.0742188494768925, 0.03468259812507313, 0.060472040640888736, 0.04066620458615944, 0.04218453854264226, 0.08939412189647555, 0.034050581452902406, 0.05255620075331535, 0.05593931062321644, 0.015327957244153367, 0.011832291402242845, 0.06610170574276708, 0.018895400826295372, 0.017244482187379617, 0.01971208239410771, 0.02606061771075474, 0.0541535177762853, 0.023013251739030238, 0.03870477507007308, 0.030430683800659608, 0.024877138930605724, 0.027739168363041244, 0.00815812791188364, 0.03422120862524025, 0.07649718347238377, 0.02298945291840937, 0.06866259762318805, 0.04760645795613527, 0.03778769576456398, 0.0780700022005476, 0.07179653883213177, 0.0208597358505358, 0.038008358533261344, 0.029894387480453588, 0.06524287760839798, 0.06089199974667281, 0.041798087404458784, 0.11276620018179528, 0.03846920997602865, 0.022571571826119907, 0.02223095201770775, 0.03990402263298165, 0.04333191740442999, 0.0495064116694266, 0.029876596345275175, 0.03521459184412379, 0.07237841971800663, 0.0032290029048454016, 0.10730498775956221, 0.004799777480002376, 0.04167841238086112, 0.10415964716230519, 0.022810342998127453, 0.049401920987293124, 0.0675708612834569, 0.045469744291040115, 0.07291029469342902, 0.030309175672300626, 0.028404372023942415, 0.01137601622758666, 0.05646899626299273, 0.004691382637247443, 0.05560041630815249, 0.01688172596914228, 0.03772773394302931, 0.037825114850420505, 0.03625179888331331, 0.09700878712465055, 0.05623311946692411, 0.06654030759818852, 0.07476720013073646, 0.018470183604222257, 0.059337857164791785, 0.03889598199748434, 0.02775021523120813, 0.024295263610838447, 0.010124716282007284, 0.028200838023622055, 0.049046369167626835, 0.07052328059216961, 0.007898541352915345, 0.11922445090021938, 0.07535933749750257, 0.1411131615168415, 0.1582550659077242, 0.2545919199474156, 0.18386334646493196, 0.17052996583515778, 0.1108208901132457, 0.11566143701202236, 0.1006316403800156, 0.17277571954764426, 0.2275767648825422, 0.14390286494744942, 0.3508812765358016, 0.21859927161131054, 0.20076632383279502, 0.1915635442128405, 0.08388832124182954, 0.20493783202255145, 0.09248338581528515, 0.23787440528394654, 0.06818188630859368, 0.08470148502965458, 0.13509557582437992, 0.15181252645561472, 0.11354475020198151, 0.06522073192172684, 0.10412740826723166, 0.16285183955915272, 0.17407265229849145, 0.14611183782108128, 0.12647213152376935, 0.11840965438750573, 0.13403430464677513, 0.15098022267920896, 0.16255447582807392, 0.1338373386533931, 0.13313807226950303, 0.1203952482319437, 0.17326688772300258, 0.15204284456558526, 0.1559362848638557, 0.13834299141308293, 0.21050079289125279, 0.11725153293809853, 0.19855932507198304, 0.1534376962808892, 0.16932645463384688, 0.09673484557424672, 0.1452405416057445, 0.22620103089138865, 0.18017521389992908, 0.0701383656996768, 0.1322966697625816, 0.20596539485268295, 0.05357982277928386, 0.10989709437126294, 0.15875377430347726, 0.11188812073669396, 0.14346676412969828, 0.23375631688395515, 0.15750341874081641, 0.16409682197263464, 0.1857682762783952, 0.15017511119367555, 0.18545814760727808, 0.095721494872123, 0.1534034387441352, 0.13291760988067836, 0.11799371772212908, 0.13850921764969826, 0.16191998409340158, 0.1298343573580496, 0.06911777905770577, 0.11792189266998321, 0.09543445441522636, 0.07602715166285634, 0.11421400413382798, 0.1363504139590077, 0.16068969620391726, 0.11248028778936714, 0.0960156079963781, 0.0989567615033593, 0.1630657265195623, 0.11201608926057816, 0.15864730579778552, 0.191465076059103, 0.16175803262740374, 0.08417661592829973, 0.07693122111959383, 0.195633007097058, 0.11670689302263781, 0.07517306585214101, 0.12262183969141915, 0.1971747149946168, 0.23181980126537383, 0.09722613249323331, 0.08793691493337974, 0.12474562885472551, 0.06735612827469595, 0.13732823805185035, 0.07703000839683227, 0.22624199744313955, 0.08886711540981196, 0.08292994141811505, 0.13768098084256053, 0.1595889130840078, 0.15433992521138862, 0.11748809251002967, 0.12059398795827292, 0.14282983815064654, 0.17620181461097673, 0.15737225156044587, 0.18789166468195617, 0.09515200785244815, 0.22675603860989213, 0.12033377613988705, 0.14302922354545444, 0.07391892533632927, 0.17160119663458318, 0.14820666838204488, 0.14287217025412247, 0.1299147616373375, 0.18354892818024382, 0.147492841060739, 0.1904649133211933, 0.06517045883811079, 0.18364329967880622, 0.08632398312329315, 0.15616330783814192, 0.13324272993486375, 0.10898692446062341, 0.1906868748483248, 0.12735363969113678, 0.1209096382081043, 0.1146388020424638, 0.13490862882463261, 0.13836108497343957, 0.25640103849582374, 0.08972687865025364, 0.17975529190152884, 0.1235013514815364, 0.11223866677028127, 0.22439367865445092, 0.11301758786430582, 0.16291511507006362, 0.14387742412509397, 0.12189380766358227, 0.16748079273384064, 0.14683108282042667, 0.14043800008948892, 0.17476268636528403, 0.13494074897607788, 0.13041142170550302, 0.12985510780708864, 0.10842592018889263, 0.1478191782371141, 0.23225705983350053, 0.09608266103896312, 0.12188653461635113, 0.1459965674439445, 0.12763473554514349, 0.2145459281746298, 0.09405261254869401, 0.18255602364661172, 0.15296368655981496, 0.19711268629180267, 0.09942886390490457, 0.17254059232072905, 0.14950063254218549, 0.18397796375211328, 0.19614229851868004, 0.12148997542681172, 0.1775937422644347, 0.1373929384863004, 0.08834499967633747, 0.2799536590464413, 0.1877616997808218], [0.014001961990288692, 0.03034469671547413, 0.06300675697275437, 0.015593237003486138, 0.04001231682195794, 0.0220722326048417, 0.025209314953826834, 0.01645268112042686, 0.05363139462133404, 0.031770210262038745, 0.03828507942671422, 0.06344760753563605, 0.06417141674319282, 0.023260103043867275, 0.026420071371831, 0.01937196353537729, 0.011761304049286991, 0.005203830041864421, 0.03216024226276204, 0.025103351108555216, 0.00349833107975428, 0.024775455422059167, 0.07335796559345908, 0.05388987723563332, 0.014767710890737362, 0.035764493586611934, 0.08826455086818896, 0.018435959464113694, 0.02485254044586327, 0.03864556652843021, 0.06875045306514949, 0.07750359509373084, 0.038723024481441826, 0.03384866904525552, 0.04222468131047208, 0.06350141324219294, 0.10181403005844913, 0.021459064628288615, 0.04929537826683372, 0.05670934078807477, 0.03846966639684979, 0.014279957522376208, 0.018292422537342645, 0.02221001974248793, 0.05379134228860494, 0.012189748686068924, 0.0580730148794828, 0.031198489377857186, 0.04102049475477543, 0.02111929643433541, 0.0500572299642954, 0.007500979336327873, 0.013770710629614769, 0.019624447741080076, 0.015660013596061617, 0.021345215463952627, 0.023053507684380747, 0.06946115594473667, 0.04510468555963598, 0.06644851135206409, 0.04340597632108256, 0.007444705988746136, 0.06377555517246947, 0.049259165170951746, 0.0541715334111359, 0.04635503370082006, 0.06529639387736097, 0.012603860595845617, 0.017207404489454348, 0.038987080624792725, 0.031852570100454614, 0.030477849140879698, 0.04124797414988279, 0.042885059156105854, 0.11961429365328513, 0.04841684982238803, 0.01741476426104782, 0.06924568820977584, 0.031987514812499285, 0.03951726721425075, 0.030022202008694876, 0.02182098221965134, 0.0969488661212381, 0.07541064216638915, 0.04684711471782066, 0.028192242098157294, 0.0275985740518081, 0.04194355205981992, 0.07272069822647609, 0.0060762227803934366, 0.038276329505606554, 0.08746355088078417, 0.03233705894672312, 0.08511958134477027, 0.030658842260891106, 0.011012806371581974, 0.011398506085242843, 0.04156055561907124, 0.026523860724410042, 0.01907674832182238, 0.0733004417270422, 0.09236867204890586, 0.00888700506038731, 0.05787129914097022, 0.05569905144511722, 0.032201275607803836, 0.02679594690562226, 0.05711824189347681, 0.04595401420374401, 0.008590762899984838, 0.06842413073172793, 0.059782117896247655, 0.11278566671535373, 0.03733150500920601, 0.05737499159295112, 0.015716884372523054, 0.020194667631585617, 0.03413677077332977, 0.049090296888607554, 0.02422213423415087, 0.037897722868365236, 0.07743130248854868, 0.022801978993811645, 0.08211180524085648, 0.03620294330175966, 0.043062187542091124, 0.010287100049026776, 0.00803758828624268, 0.057946560336858965, 0.08606973075075075, 0.0177759619691642, 0.04107314642169513, 0.04388711808132939, 0.023481261196138803, 0.014550127107213484, 0.011012057730113156, 0.04370919559733011, 0.02158206632884685, 0.04694994669989683, 0.04799570328032132, 0.030633958049293142, 0.07398435307550244, 0.014014397602295503, 0.05850547917361837, 0.03548137909092475, 0.047253637239919044, 0.02757327052677283, 0.033395350401406176, 0.09110277591389604, 0.04752919667225797, 0.017016754172800574, 0.011483220387162874, 0.015897053708613385, 0.008024069138627965, 0.034238919979543425, 0.02666855725692585, 0.019531803591235075, 0.040557249885750934, 0.02559440239565447, 0.04205908961012028, 0.03064672670006985, 0.007671183948332327, 0.0330138568097027, 0.07711510304943658, 0.04206133831758052, 0.020741229709528852, 0.031991841533454135, 0.06094335636589676, 0.011624877824942814, 0.06308373252977617, 0.018918553978437558, 0.07401138951536268, 0.039760294603183866, 0.05241230202955194, 0.017909383423102554, 0.06468703126301989, 0.047415399458259344, 0.047360191092593595, 0.07761246073641814, 0.03332769621920306, 0.03596842834667768, 0.045088796177878976, 0.018389853539702017, 0.029134944052202627, 0.029418125341180712, 0.030789135562372394, 0.022524898158735596, 0.07675365486647934, 0.01786285447451519, 0.021714363429055084, 0.02678377382835606, 0.014661027162219398, 0.0183461688720854, 0.03392389684449881, 0.009294737283198629, 0.11317896045511588, 0.022097068576840684, 0.01960125933692325, 0.020560730117722414, 0.036497980399872176, 0.01503466883150395, 0.03905959216353949, 0.02498239031410776, 0.03646587509138044, 0.06489901832537726, 0.041077710629906505, 0.01821478461351944, 0.037189944050624035, 0.0472700461250497, 0.034412296809023246, 0.044404643631423824, 0.05834310839418322, 0.041337451184517704, 0.02139954623999074, 0.05257818687823601, 0.029866714648960624, 0.0034024469914584188, 0.028355644462862983, 0.08348129777004942, 0.057396550982957706, 0.10338880063500255, 0.03054675013117958, 0.032367694802815095, 0.04210877639707178, 0.022932955071155448, 0.038827808311907575, 0.026613855407049414, 0.030229587755457032, 0.015929244364087936, 0.042366208872408606, 0.0602445760887349, 0.029912573809269816, 0.047443712392123416, 0.02524426454328932, 0.04982822916645091, 0.05954581807600334, 0.058675486652646214, 0.006546159502249793, 0.029489725893654395, 0.04249506055202801, 0.05161827451956924, 0.03926305565983057, 0.073579214658821, 0.024814149146550335, 0.07165765331592411, 0.028119177659391426, 0.06481460644863546, 0.009990684411604889, 0.03256418582168408, 0.03196496836608276, 0.04743299949041102, 0.02745182362559717, 0.010965315414068755, 0.05729263917601202, 0.058610110863810405, 0.07101850089384243, 0.04436711693415418, 0.05277825504890643, 0.017833320707723033, 0.01914653246785747, 0.026423978779348545, 0.052398813495528884, 0.02959060417197179, 0.009063452525879256, 0.00587338732657372, 0.039855014911154285, 0.01601446889253566, 0.0596755863080034, 0.005055440860814997, 0.08809891834971495, 0.04985972962458618, 0.030906996034900658, 0.1446835746173747, 0.026797954415087588, 0.03174337791278958, 0.02532027159759309, 0.10538166752667166, 0.07436436237185262, 0.04751625361677725, 0.04969915113179013, 0.06075019759009592, 0.040035713027464226, 0.020949964309693314, 0.06474640307715163, 0.026334802314522676, 0.06939796207007021, 0.06961207167478278, 0.05132204998517409, 0.015807073868927546, 0.04989217261027079, 0.019144816251355223, 0.06029762851539999, 0.04287629068130627, 0.019824469527520705, 0.06149959233880509, 0.020379529196361545, 0.010845866745512467, 0.0028686591303994646, 0.12224423495354131, 0.07413923929561861, 0.07279622659552842, 0.11484235088573769, 0.07031128610833548, 0.040561357673141174, 0.07659741793759167, 0.07943061122205108, 0.03372417748323642, 0.02638485089846654, 0.0471783092507394, 0.037042319745523855, 0.05988635995890945, 0.025960130915336777, 0.0427971183671616, 0.0814259346225299, 0.028035021823598072, 0.08021171423024498, 0.0481001494335942, 0.048753543669590726, 0.02002224817260867, 0.02769178037851816, 0.031758046461618505, 0.032087252038763836, 0.09794691373826936, 0.037225622800178826, 0.044846484961453825, 0.04641811625333503, 0.025203030818374828, 0.008458226457150886, 0.02091501657560002, 0.04977229720680043, 0.028999411188124213, 0.03823708844720386, 0.04013752826722339, 0.022849292763567064, 0.039314082023338415, 0.01958824577741325, 0.023977154996828176, 0.06480751893832348, 0.020974078543076757, 0.018148989511246327, 0.013335452149476623, 0.02304885256307898, 0.09480523935053498, 0.055023340828483924, 0.034337402976234443, 0.019338600286573637, 0.037019851224613376, 0.04137418007303495, 0.027333855541655794, 0.07230293587781489, 0.049805560265667737, 0.06104195439547766, 0.11654826637823135, 0.0821532096597366, 0.20051497325766832, 0.19782223884249106, 0.10779299438581802, 0.07771881791995838, 0.11017896205885336, 0.08676023979205638, 0.1814200181979686, 0.10743954655481502, 0.08663866858114488, 0.17712926171952859, 0.15301470179110765, 0.15831967728445306, 0.09238399739842862, 0.17479351517977193, 0.0975140486843884, 0.1407239941181615, 0.12527728860732168, 0.21500988921616226, 0.10352755256462842, 0.0980356968648266, 0.1952535766758956, 0.12679992330959067, 0.09664307159255259, 0.10374105360824615, 0.16618945577647537, 0.11091186999692582, 0.08243132208008319, 0.11433055100496858, 0.1414653254323639, 0.1562066047335975, 0.15464028721908107, 0.07587472195154987, 0.13105793623253703, 0.16203936596866697, 0.18523127306252718, 0.12136900535551831, 0.11869647962157615, 0.09995078667998314, 0.08556161192245781, 0.10157622367842123, 0.10300325491698459, 0.1432276441482827, 0.2541268605273217, 0.0539785638829926, 0.1372821952099912, 0.12032487036776729, 0.10611856079776771, 0.14661361870821565, 0.10320134897483513, 0.1163345723762177, 0.135682184190955, 0.18824142403900623, 0.16494824347319081, 0.1742032406036742, 0.12949973781360313, 0.13830986194079742, 0.1576168485917151, 0.20709147036541253, 0.14004209398990497, 0.21300641703419387, 0.18314977147383615, 0.121006288100034, 0.1530079630902037, 0.10297723521944135, 0.18411095661576837, 0.12404157561832108, 0.2772078610723838, 0.0848905545717571, 0.1879315625410527, 0.16745060216635466, 0.08169177934178151, 0.1387724425876513, 0.2858947293134406, 0.13641220517456532, 0.06169406100525521, 0.2450919250259176, 0.12028236757032573, 0.13102253578836098, 0.119900309946388, 0.22273733862675726, 0.17646593012614176, 0.1401750126387924, 0.11240559804718941, 0.08627206247183494, 0.09750418554176576, 0.0972237650421448, 0.11111308849649504, 0.14350168959936127, 0.10861625138204545, 0.18175322766182944, 0.14062861329875886, 0.19250206416472793, 0.2303623122861609, 0.1491836761124432, 0.32510283635929227, 0.18332048028241843, 0.0743464172410313, 0.06346438749460503, 0.26359731797128916, 0.1382519892649725, 0.1937570804147981, 0.23595058039063588, 0.15488538891077042, 0.16449456859845668, 0.09168841206701472, 0.18380884313955903, 0.0689782107656356, 0.07270132817211561, 0.3300680121174082, 0.1924650458386168, 0.21035920595750213, 0.26812619995325804, 0.15135117777390406, 0.22088671918027103, 0.07970286809722893, 0.18105706345522776, 0.12799720047041774, 0.15366626292234287, 0.09229701026924886, 0.21668353612767532, 0.1980285410536453, 0.2359183711814694, 0.1577070343773812, 0.2089699055068195, 0.10007921533542685, 0.10733179413364269, 0.2204568820889108, 0.22880586533574387, 0.1595530821941793, 0.11385640769731253, 0.19731652457267046, 0.19019106082851067, 0.1761232508579269, 0.07979508736752905, 0.14461831015069038, 0.16396658989833668, 0.147587479732465, 0.1588524502585642, 0.12110355397453532, 0.285735345678404, 0.062376577116083354, 0.10975733312079683, 0.10894165345234796, 0.11994114291155711, 0.29851587081793696, 0.10285110722179525, 0.14202609221683815, 0.20576333772623911, 0.15416250738780946, 0.11617056516115554, 0.08898770698579028, 0.23722866259049624, 0.07011677662376314, 0.10792837696499191, 0.13727533776545897, 0.13787163858069107, 0.09722014336148277, 0.13755475636571646, 0.05170733966224361, 0.08532203180948272, 0.08080560306552798, 0.15488120319787413, 0.12435357450158335, 0.10097528444021009, 0.11823676366475411, 0.09231919306330383, 0.07584954830235802, 0.16067785152699798, 0.09949084807885811, 0.14535898837493733, 0.1722849818179384, 0.14262159151257947, 0.10968145594233647, 0.11752718884963542], [0.025593285463401116, 0.04514202300924808, 0.05881395656615496, 0.020670152371167205, 0.043633808236336336, 0.034907049557659775, 0.027617101768555585, 0.08818160102237016, 0.02548213586123893, 0.05915588997595478, 0.07278951758053154, 0.026132220118597616, 0.08978498881333508, 0.0020831352412642445, 0.012378384071780602, 0.05050141648098361, 0.020961808986612596, 0.014747858440387063, 0.03187082322256174, 0.047036265896167606, 0.04416902287630364, 0.08558714922401123, 0.025964593078242615, 0.04958509416610468, 0.07935750967590138, 0.04913385724648833, 0.06834719228208996, 0.027679403210640885, 0.021640809172822628, 0.03787040441238787, 0.06742310710251331, 0.052342410272103734, 0.03138221916742623, 0.00825060136776301, 0.04356287005066406, 0.04487624508328736, 0.021259412060317118, 0.08417710574576631, 0.055322444895864464, 0.02288398074597353, 0.014642517071479233, 0.044958122525713407, 0.0129054118951899, 0.04230799851939082, 0.014663541187474038, 0.04465261743462179, 0.04747116814542096, 0.007451501742252731, 0.03601724311010912, 0.014021859897184186, 0.09074524627067149, 0.020280895914766006, 0.03962449271057267, 0.06861179761472158, 0.008324769751197891, 0.03616506408434361, 0.041837154058157466, 0.02200996455940185, 0.031390694493893534, 0.03284480670117773, 0.011458575518190628, 0.014035235253686551, 0.01323382522969041, 0.06350309791741893, 0.010866519787668949, 0.05464857109473087, 0.017291942531301174, 0.015368735475931317, 0.020993548787373584, 0.009646056078054244, 0.016372629361285362, 0.02157985287340125, 0.04059919978317339, 0.04790073064214084, 0.04607558912539389, 0.046245492703747004, 0.09041807046742178, 0.03961331596656237, 0.06617321167141199, 0.06461809316533618, 0.06594408841920085, 0.010425351028970908, 0.016338305031240452, 0.027263806077826302, 0.050146295106969774, 0.03477877675322816, 0.048774772803881206, 0.028196064158692025, 0.01781705654138932, 0.016841902324813418, 0.045835259443265386, 0.02214425247075269, 0.01542025351227494, 0.021131892535777297, 0.02907623831561068, 0.04762940887303557, 0.048518323674215935, 0.050487044791225344, 0.10079646395752206, 0.05083073709101882, 0.024878630647435784, 0.024313197609444614, 0.010640971831890056, 0.10966484667733312, 0.03595144800783601, 0.05561331483477261, 0.07404121643048711, 0.055942123362910934, 0.01700905067991698, 0.04817735876713414, 0.1014744900749065, 0.06149460139567964, 0.03153027020744048, 0.014242491124605294, 0.10304451832780614, 0.03925105513189919, 0.05872934802027885, 0.03177028447680641, 0.04533021681709215, 0.04974989918991923, 0.03807878092629835, 0.04130042914766818, 0.0756653027201537, 0.0356764822936384, 0.040749651670921594, 0.05029672473028768, 0.06623640554607846, 0.04607004899298772, 0.03219174643163569, 0.037056008659419604, 0.04026305512525141, 0.025928272370947525, 0.01904117532831151, 0.02816369538777508, 0.023592267934873234, 0.03013434794411296, 0.06244668780709617, 0.07885345781687647, 0.017205729091074318, 0.020628256279451307, 0.07929953309940174, 0.033038462715921924, 0.0462872125353897, 0.03025268710189266, 0.05358381553378422, 0.03121568493952509, 0.018086033123836387, 0.06889604017487727, 0.05614303758193273, 0.020225453772582114, 0.06327125840471126, 0.03452568213106133, 0.020845477338298224, 0.011775668317568488, 0.017909238704305608, 0.020895075067528524, 0.039006691877148114, 0.04012150900962297, 0.063822889351286, 0.020025741832796484, 0.0746119131508749, 0.021518438297789544, 0.20806026994250715, 0.05022888130042702, 0.04223410287522711, 0.02936817880254239, 0.024734253238420933, 0.05776368772785645, 0.03765675122849643, 0.030969457038736437, 0.0723856185504701, 0.032022826198954135, 0.024719592111068778, 0.06631602314882912, 0.01633308216696605, 0.02358070712944027, 0.004566850257106125, 0.032721940442570485, 0.012718330381176202, 0.05293895228533074, 0.08365030706045218, 0.029671316442545503, 0.0522203826403711, 0.04910302101052366, 0.04420483892317861, 0.019239530993218068, 0.06404412357369438, 0.003082019165958627, 0.063473159680143, 0.013934097223682329, 0.004702297774201725, 0.049813556906883605, 0.00965306844591396, 0.05079254988231696, 0.04274255195923615, 0.06326271628495306, 0.06772403314244002, 0.03604134435590822, 0.07172544108470902, 0.04876539205724839, 0.06392667128238827, 0.03903924247424584, 0.04917191086860839, 0.04486969191930257, 0.01897447851661127, 0.015201786573015852, 0.03440480853896588, 0.054391921585192904, 0.01528047278043232, 0.06785330784623511, 0.039059985501808114, 0.02560952736530453, 0.047751581223565154, 0.056748993738438, 0.03346419573063031, 0.061212663204059936, 0.03839733297354542, 0.032609226764179766, 0.019147218954458367, 0.0307130004875944, 0.06154307477117982, 0.028972951768082567, 0.08248350990470499, 0.05130481731612235, 0.04099781101103872, 0.029695059602090623, 0.031072910569491796, 0.012786292554665124, 0.005182430213608313, 0.06914076337125152, 0.012052610927639762, 0.025921964115696028, 0.07906305516371503, 0.013103777764627011, 0.028365884245431516, 0.06693829913274385, 0.01729155846987851, 0.0564187417330686, 0.032134601060533896, 0.06357079662848264, 0.021012247198086698, 0.025652163749327883, 0.03257335876696743, 0.0340224317915272, 0.024318754440173507, 0.07397282010060735, 0.01046280443915748, 0.012555485554912593, 0.02691762758331606, 0.020743001587106846, 0.117006342188688, 0.020055566892551724, 0.10647014583810233, 0.030458679466391914, 0.06013887199515011, 0.06462635326897725, 0.040239933514385484, 0.081818530743476, 0.026274333977198694, 0.03246040017984342, 0.027188376043341123, 0.02757916689006379, 0.052974015052313916, 0.03360879207320977, 0.014485661376966164, 0.025190002415911295, 0.05522942039533518, 0.017898084224725608, 0.016347761848010123, 0.057053355922107585, 0.08683354171807878, 0.01830335251725046, 0.04912863252684474, 0.025396256387466565, 0.02658934041392058, 0.005835832798766205, 0.040655205957591534, 0.04862905581831001, 0.005189011671973276, 0.028623314865399152, 0.01764222510246327, 0.010875223324546823, 0.028090319246985018, 0.010155815980397165, 0.02153517558326712, 0.028738891378452536, 0.06643750530201942, 0.09091166546568274, 0.025113310730375815, 0.02980796438350808, 0.04617813909135293, 0.03165081354381982, 0.024892434594221413, 0.021485839461092837, 0.01173451808426762, 0.08762064127949998, 0.03242036131268833, 0.028863852348877117, 0.00565499181902851, 0.028771139550372027, 0.07459350788849406, 0.035349495738046244, 0.04640646082407329, 0.05980417081445921, 0.06337812024867162, 0.003521999560689437, 0.018235097195429262, 0.04366967252281029, 0.05780733343272004, 0.019200429087504745, 0.053676042225561105, 0.03307514336484019, 0.00980163991698646, 0.07790320451022126, 0.0475706864381209, 0.022009988679201342, 0.08426722473814152, 0.013012270028411876, 0.07031115994323045, 0.005310528613335919, 0.025951342031476088, 0.029217684241302777, 0.035252044326625764, 0.040154968737624586, 0.028428827645257115, 0.02440924636175623, 0.08611089768237434, 0.010579986774246208, 0.027650336996885017, 0.02324871478776913, 0.07519446196965873, 0.016918130168050993, 0.10016002037446015, 0.033361014939146116, 0.04764848206832539, 0.057824228424578905, 0.017910691458382644, 0.03972393307776656, 0.06959669437492266, 0.01539382563350955, 0.02702328343730187, 0.046563740470446646, 0.03002583482157206, 0.043348886611056514, 0.03719360654940829, 0.029186827596277, 0.0750866872840561, 0.0461323560011806, 0.036950638532289304, 0.03159267369483132, 0.004560460829452495, 0.02915063490945613, 0.1396695210132748, 0.1617049690685235, 0.22134006751002744, 0.24043487414019182, 0.26748284697532654, 0.14175736054312438, 0.0914127635769546, 0.15132873522816226, 0.10622172674629837, 0.11144709947984666, 0.21482135402038693, 0.09941139374859631, 0.17159319628262892, 0.0762146181659773, 0.2006254345178604, 0.13186794589273632, 0.12197136951726861, 0.11493351630633697, 0.11171584599651396, 0.12234797977725975, 0.17262772045796737, 0.17848418588982895, 0.11873936091433279, 0.11336022260366008, 0.22537573298905045, 0.13998245500260964, 0.10816482521477155, 0.10383043045294471, 0.1511760606081225, 0.15914179879473522, 0.07351495209150016, 0.1378229388501495, 0.14335700048832223, 0.15701836586231366, 0.052859828210785054, 0.15455445041880012, 0.19975747796706855, 0.1935441730893217, 0.1562249060953036, 0.1476160969468765, 0.16687643219484016, 0.12711092771496624, 0.13998707116115838, 0.1606886275112629, 0.09500629457761534, 0.09188357464154251, 0.14688430965179577, 0.10918714106082916, 0.10982914332998917, 0.10221241493127309, 0.19977591291535646, 0.1341897845850326, 0.10561188173596747, 0.1645806577289477, 0.09072781322174706, 0.17553074983879924, 0.20625104749342427, 0.0941622129175812, 0.10282125804224052, 0.1211699316627346, 0.09498393366811797, 0.07233389827888459, 0.09241867795935832, 0.21026192524004728, 0.14056567917577922, 0.07215003861347213, 0.11357856245012954, 0.11518150495248847, 0.17451841587899253, 0.13778626191196963, 0.14161302766297013, 0.09201606284477748, 0.09987632700358517, 0.1929947908502072, 0.13512150646420196, 0.1642670261207968, 0.2287655370309949, 0.10406456320197321, 0.1408351381542161, 0.1613528496818617, 0.21224669530056417, 0.22917631577001885, 0.07712232414633036, 0.10598428401863202, 0.15613656083587557, 0.1582651591161266, 0.13954295514849946, 0.10807465427205898, 0.11378176248399541, 0.14420670020626858, 0.1824301405576989, 0.19068951689405367, 0.08766802740865387, 0.12111291245673783, 0.17196452245116234, 0.1503570264321752, 0.10339660802856088, 0.0984413325204514, 0.11109305793070234, 0.1433057922986336, 0.14065604307688773, 0.11318956574541517, 0.14445857028476894, 0.15824399306438863, 0.08490473701385781, 0.12798721116269007, 0.13714449713006616, 0.13198983622714877, 0.06123985178419389, 0.138801816792693, 0.14641049288911745, 0.13170458434615284, 0.10616835890687071, 0.14347014832310379, 0.174436378874816, 0.1002371592039708, 0.12774859584169462, 0.16957924497546628, 0.09355944799608551, 0.1554784836480394, 0.14555920497514307, 0.14118246326688677, 0.09038775373483077, 0.09133779924013652, 0.23717335774563253, 0.2376480057137087, 0.17409727675840259, 0.19649238442070782, 0.19383911741897464, 0.10495194917893969, 0.18533821654273197, 0.10689797170925885, 0.10847582962014712, 0.1254225120646879, 0.06421063182642683, 0.13780696783214808, 0.07780777174048126, 0.18460452934959903, 0.16707179514924064, 0.13098704628646374, 0.1764443187857978, 0.09312633061199449, 0.11253453878453001, 0.07457810090272687, 0.1915652066236362, 0.15472762315766886, 0.10495521462871693, 0.17136514914454892, 0.1904689654475078, 0.18736702564638108, 0.3319965867558494, 0.07333448404096998, 0.07252160226926208, 0.13514476537238806, 0.14768104971153662, 0.08452201887848787, 0.1695708290208131, 0.10237530150334351, 0.15554132871329784, 0.12800586875528097, 0.19543794100172818, 0.12201946068671532, 0.2249209300498478, 0.1630462525645271, 0.0893751897092443, 0.1118137055891566, 0.15345259860623628, 0.13381410943111405, 0.1601060712710023, 0.1381848397431895, 0.13804248097585514, 0.11124680124339648, 0.09162466900306754, 0.13140696828486398, 0.08476282353512943, 0.14371845609275624], [0.06720340912579559, 0.03495294396998361, 0.022816757009422872, 0.0931124524504412, 0.10751629204605706, 0.060685868229484186, 0.026058832845592406, 0.04436722825630568, 0.00533777934833779, 0.01633850726648234, 0.0363525899592787, 0.06840378104243428, 0.0731031566101592, 0.009088991682801861, 0.032174305961234495, 0.04157762130489573, 0.045447791562764905, 0.0356994332105387, 0.041177355087711476, 0.028197169958730228, 0.05913603010412771, 0.022826241656730417, 0.0192560122377472, 0.025362037813465577, 0.032457331399200484, 0.027220546289754566, 0.05254428928310517, 0.04326369918999262, 0.03191271374817006, 0.04570923534629401, 0.01869531966804061, 0.10512990134884603, 0.052458775317063555, 0.0608899439976085, 0.05275199415336829, 0.03260380166466348, 0.044276749322307296, 0.0571160302934004, 0.016624273084744345, 0.023993539762159344, 0.06462195233325474, 0.04680034828197677, 0.03304582482087426, 0.01166884172562277, 0.02656241529621184, 0.025300882989540696, 0.03949649450078141, 0.044424418156268075, 0.06460474935011007, 0.022150846452859696, 0.05699823290342465, 0.028598150493053254, 0.048569517020951025, 0.011885794683621498, 0.016101693508971948, 0.030982537391537335, 0.0289465628520702, 0.03554595707100816, 0.04440091805008706, 0.049619811834418215, 0.02862135188479442, 0.03742576147487853, 0.038707509884261526, 0.007997320280992426, 0.06405919659300707, 0.059217696034465916, 0.036176808571326546, 0.01051418146744254, 0.053166806465014815, 0.011382885732018622, 0.028804029680031817, 0.020651277700380888, 0.029670195799553767, 0.040201319570769556, 0.07666418154258281, 0.02170653191569727, 0.01930449674546253, 0.02402262452960713, 0.03538484423188493, 0.06232117579202168, 0.029387051617959514, 0.0142658168260823, 0.0027393403615860734, 0.017204417345055845, 0.030371319408004638, 0.0319410563679412, 0.035110962053295225, 0.0440020693349652, 0.04068270995048806, 0.024696017790120095, 0.07940445051644929, 0.050777450887835585, 0.003951438675358077, 0.03085323485720437, 0.033959245338337496, 0.08022138441447169, 0.028728415963996667, 0.03654079861007631, 0.013257684349810006, 0.054453445627586916, 0.009828268175624544, 0.003814592905655445, 0.05886247818125412, 0.02227880384452874, 0.0382090167113347, 0.048869827078306116, 0.0991314482234884, 0.011308311950415373, 0.054508219836861826, 0.01657986853388138, 0.03260690384195186, 0.05755133701313753, 0.04703922335465904, 0.0314556806551991, 0.06466061822720803, 0.04685505569796078, 0.028276166012801696, 0.043423836104921065, 0.11668215724057518, 0.04835803832975216, 0.02941743328847224, 0.016930746678553987, 0.028628101717913523, 0.05351290703401901, 0.04839371336856857, 0.028966226054762956, 0.06578170650755055, 0.04058190403156914, 0.08590754921897314, 0.028342940750007983, 0.03790341143030673, 0.04098593664821237, 0.0558040059695486, 0.02089493220410077, 0.045969191123731434, 0.020863175705017056, 0.0015795640388205356, 0.030222119894460775, 0.013241001797723584, 0.025242553892894648, 0.023974321848072577, 0.05564873012190219, 0.06401912803994492, 0.06239767637453042, 0.01700903583696345, 0.051920228434028104, 0.04225423363095615, 0.015426666595885763, 0.06176641669298988, 0.009566408789396519, 0.024707801239856053, 0.01911984298203606, 0.04842303562327288, 0.04763848533912096, 0.06797598485718481, 0.017715257999952883, 0.011500334312586347, 0.04241705340973567, 0.016465414519188926, 0.008703147250344045, 0.019258600477769505, 0.028100486670155078, 0.03556396157364361, 0.04317919825552963, 0.010328205753467046, 0.033788336149882525, 0.0687844879576005, 0.10297204018570483, 0.06974272677325644, 0.023566927302454133, 0.023427451778843533, 0.01175170344140497, 0.04352469397417735, 0.011764983246393967, 0.0361641809286084, 0.040055598874459974, 0.09143486473476514, 0.0525185887090629, 0.05726017021515872, 0.0235107634216547, 0.03740467334864661, 0.08992374816443771, 0.05272977796266787, 0.06828699668403715, 0.06869560093036853, 0.01409375452567474, 0.026779092731885612, 0.046658137944177724, 0.041156882944051176, 0.04211096573271789, 0.034410400621709414, 0.04692724811320659, 0.0609084457391873, 0.03781756720854901, 0.06302793786744587, 0.030784795853833202, 0.02143116173101589, 0.05291709974699188, 0.027899611413886305, 0.04436690913280472, 0.051990506108268164, 0.07828749599866569, 0.05775824778538663, 0.020965914918633644, 0.04017713668872602, 0.03029420469829347, 0.0191934009490069, 0.019186452591384295, 0.028066125232726336, 0.02587567450973438, 0.02983404901897302, 0.08098342164885253, 0.019945116764574777, 0.024890000349842012, 0.007644938823432312, 0.04343604814494029, 0.10439185032737441, 0.026942636104649864, 0.059692306895158254, 0.03154991485644132, 0.07084838580340147, 0.05450575961731374, 0.008232950312958565, 0.05879923606698867, 0.05809103422507178, 0.01640381626202725, 0.0384172336634947, 0.014859974689898081, 0.009644013316574274, 0.014645238898083335, 0.015796112347743474, 0.034415714399074204, 0.016335028449248057, 0.0372054215404205, 0.03534838993800804, 0.07431073478073813, 0.028950379346497357, 0.0650682725245133, 0.025480284202785697, 0.03706775314640254, 0.06315894177532755, 0.10468749969732016, 0.03268856606155168, 0.030309637659229338, 0.04558048756734934, 0.018911930310423486, 0.01372453420117381, 0.03325170029711444, 0.04601856620865874, 0.05116903026646469, 0.04214792097627651, 0.036967073392588645, 0.06538056084536947, 0.015067365075083217, 0.03961503774917219, 0.011659824631351512, 0.008691052098583896, 0.04230670347169507, 0.011722158542397665, 0.03365162883710582, 0.022324373567244038, 0.025475120710325427, 0.018387988893664442, 0.02187134807172697, 0.0253112619247986, 0.03435597522184253, 0.010855583313968964, 0.02496720782801276, 0.04917461228615139, 0.011965306530328235, 0.06663214837317355, 0.07522733169025742, 0.03017677281604847, 0.02956860505946679, 0.033439749386161566, 0.032766925723990425, 0.059463239304022864, 0.04031797405332327, 0.04076585275470279, 0.018176781086367555, 0.040906341309892014, 0.05322382567101158, 0.03566409584891517, 0.021483264208654873, 0.02366358647122979, 0.04377196644782089, 0.024786424364720006, 0.0322404350299621, 0.07710751087870449, 0.04667143723054323, 0.04352694268163759, 0.06592218764126301, 0.014279885162977735, 0.01235514371728641, 0.01540103188744979, 0.009066015718417475, 0.0313238640956115, 0.03593733606976457, 0.04133319125685375, 0.03317973794764839, 0.01713616758934222, 0.012629491593543207, 0.0057198634112864966, 0.03491517978545744, 0.060527916939463466, 0.01885883521026699, 0.055629478811169975, 0.041402864080737345, 0.02559432075941004, 0.01305659943682258, 0.025018453125085216, 0.021198567083047237, 0.01494881254984648, 0.05841915626660921, 0.014349166503961897, 0.036085335159441456, 0.04879996871750336, 0.01103179421988898, 0.05326140431861859, 0.03511988266836852, 0.017378493648720905, 0.04134712879022118, 0.023302769113797694, 0.039409837627317756, 0.027363645349396393, 0.0237822336202953, 0.011600943562370958, 0.03867659943352919, 0.034935922813019715, 0.06056338417693041, 0.05744390371546615, 0.015072263249749085, 0.04298163112252951, 0.049465404299553484, 0.0429125371738337, 0.025857206164801028, 0.03262723868829198, 0.009977322042686865, 0.04821364607778378, 0.01127954537878395, 0.023630161995242815, 0.05100887479784433, 0.03651524646556936, 0.035263510508229956, 0.06390966125763953, 0.017193537460116204, 0.03076609929848928, 0.06018350104568526, 0.04491183477512095, 0.025658661252236925, 0.015572998636343982, 0.007391795961666503, 0.15113059664145112, 0.14775380986975506, 0.11698801114107482, 0.12473678245441988, 0.196892001258675, 0.1995228257146664, 0.11258755781454965, 0.18576098838821054, 0.2059618622297421, 0.07468250623787753, 0.11043026810511947, 0.2083697752095759, 0.08440888588665985, 0.16289684339426458, 0.34366222796961665, 0.1334233835223131, 0.16533368529053405, 0.0765134439279791, 0.19878228107700124, 0.13277523627039045, 0.17057943739928305, 0.14902337221428752, 0.10611864243401214, 0.21469818719197065, 0.14893395826220512, 0.17892049450892955, 0.1839379026205279, 0.1417691755341366, 0.11437254172051325, 0.1464280075742863, 0.09342137884232216, 0.23102421895600855, 0.21483719145180658, 0.12651106459088624, 0.15642715618014336, 0.17855152837000787, 0.162355090433266, 0.1810852947528474, 0.16184201405849308, 0.16564933554036543, 0.332631419878453, 0.11172395767061971, 0.13843797147274017, 0.09263965243007988, 0.10861581351491623, 0.15811031742487103, 0.15928206470562145, 0.22849928413052112, 0.16268745384877548, 0.12806853570509702, 0.11159121713717468, 0.08977652090834454, 0.07599399992614053, 0.08558964284020476, 0.13869923714082688, 0.16323232383001596, 0.12145844899350777, 0.13969613442895934, 0.1539832045091316, 0.1461995448335074, 0.15376183670014143, 0.14939011191017926, 0.12441932136425748, 0.10507083381526172, 0.249635471845977, 0.21655429853126407, 0.10034298204118386, 0.0751125808164943, 0.1075791371113155, 0.08036157611059025, 0.17532058845972642, 0.0918965028540697, 0.13736038788920268, 0.15231537603540346, 0.09154993473202921, 0.07844059364288114, 0.14976952748838812, 0.11109478713478893, 0.08519450115272775, 0.08018529377295636, 0.09291143433074467, 0.12939622305566445, 0.07552398295956664, 0.17367627122439444, 0.15427688718773425, 0.0881203515746165, 0.14218606957001612, 0.10486329963896424, 0.08332960278494284, 0.1567665403126739, 0.16240261757047847, 0.13435767323244363, 0.18579631461761892, 0.11280934122623876, 0.11037923803087324, 0.20695374259958044, 0.09080987991183065, 0.16840439551742747, 0.11268434871453792, 0.11507429429912008, 0.15867809008341283, 0.15666244667954743, 0.13425794342765585, 0.0730014155851677, 0.11072553897975013, 0.21117824013344944, 0.2847536327317357, 0.1962511715828441, 0.1650170554057695, 0.14845683152088895, 0.1425881651812233, 0.11981546020251699, 0.2931301051285118, 0.2216807281365618, 0.1360806284355931, 0.1298244867939502, 0.09303768849349581, 0.137879267858807, 0.1920062501449138, 0.0769532480626367, 0.0899747856601607, 0.1381833406048827, 0.161755449953489, 0.1707408990478143, 0.05915295478189364, 0.21812414866872132, 0.11896935990080237, 0.11887986431247555, 0.2716596837854013, 0.1471719957771711, 0.2190876196254976, 0.058473926765145734, 0.08661950632813387, 0.08593940219725482, 0.08817541151074693, 0.11934176960494369, 0.0864299840759486, 0.19750593550270423, 0.11651930777588859, 0.10510515072382987, 0.14639524917583913, 0.18817859381670132, 0.18771610222756863, 0.14805104001425207, 0.15718708571512252, 0.19752754684304819, 0.12449695001123473, 0.08423427338129841, 0.16761644248617813, 0.09126836390350945, 0.0976391599397175, 0.09032918344018981, 0.11732056751498021, 0.12035086037940346, 0.17245870374608785, 0.08508274113410152, 0.1259662094525993, 0.12351856188615784, 0.12715204269625247, 0.10816927067935467, 0.07852110924432054, 0.10821471238159575, 0.15066806052345783, 0.07344881931203417, 0.10509177722269669, 0.16393228783272207, 0.33514468814246356, 0.18145880283555016, 0.1962454422027804, 0.1857129714335315, 0.10214394438662566, 0.1413101571961306, 0.10307044154615141, 0.1177005322824698, 0.10749787936219946, 0.18828101019607857], [0.054531801579287276, 0.018688221025513485, 0.039030815387377515, 0.023226993980642874, 0.0535709170071641, 0.06236986810108647, 0.05490426694450434, 0.07163616814068519, 0.024271756083180662, 0.006896251434227452, 0.04258745051629376, 0.022391745733330026, 0.026023313657788094, 0.02744261913903756, 0.043354786685085855, 0.07203444911283441, 0.03607621787523385, 0.01966740695934277, 0.07160294218920171, 0.019665412437461782, 0.024698884335521143, 0.07407146636978723, 0.019637542936834507, 0.02286066246597329, 0.05915014204219915, 0.0023062784066496533, 0.03238253775634803, 0.06503990764031187, 0.037241883255774155, 0.07043930658255704, 0.04358397301984951, 0.025366123336425517, 0.025564723910065368, 0.09034119881107472, 0.042348671922809444, 0.04014873098640237, 0.08499648130964488, 0.039495926757808775, 0.08438590899459086, 0.08354157500434667, 0.07863370046834461, 0.053951516310917214, 0.018671509715204593, 0.04967395892890636, 0.013729091915593017, 0.029990295224706642, 0.06470356631325558, 0.08955477460403927, 0.04517103727266658, 0.028672695516434032, 0.012671313470491441, 0.04333382472395897, 0.03887927254254464, 0.019126236584270373, 0.010332587207813049, 0.05447134994028602, 0.0018128238366443838, 0.012314580708334688, 0.018017074617091566, 0.03122551839624066, 0.0455625684116967, 0.00907529905816773, 0.051867855072487146, 0.014655408176622586, 0.039617074944544584, 0.014297902653197525, 0.10343577116145752, 0.009820464492804604, 0.041462310109636746, 0.06912238779477775, 0.009601827787264483, 0.036810168530792, 0.04647421148547437, 0.009267237001040485, 0.009565613763697911, 0.02593929326394573, 0.01671568341407692, 0.01785512129572453, 0.05205811947234906, 0.0274473911485984, 0.014053185022930847, 0.028116145986132324, 0.018432217184454203, 0.04001979767053854, 0.03352347106556408, 0.09338525851489976, 0.024990186575450934, 0.0418588804313913, 0.02394114784692647, 0.036404566271812655, 0.04941891245834995, 0.0174378747396986, 0.08924184061470442, 0.05915837988140993, 0.045462823763955384, 0.05012143315980211, 0.016141556116053835, 0.026333483147027437, 0.046248246071627364, 0.02297626866493374, 0.044207673927303404, 0.07412063365336508, 0.021219773952907417, 0.03978646273026243, 0.03223429375793785, 0.0545848465844756, 0.01725165875541279, 0.03473595112154726, 0.03757143022085074, 0.054921254704822786, 0.03236080025089905, 0.07737168576568365, 0.021363783998822328, 0.06903419838636182, 0.029919516600784846, 0.04209961829474196, 0.03331709835038055, 0.012262610889592906, 0.025638313418312464, 0.04820034679141827, 0.08431678535998799, 0.02644984077051049, 0.0441440236318158, 0.042631411633919924, 0.0799950813234318, 0.017764493932190817, 0.00432969232861069, 0.036496841203188524, 0.03506520122755319, 0.029423507767205592, 0.09019055767566897, 0.02902627136791125, 0.04755834823299665, 0.0543109198770253, 0.034804592360160314, 0.05791165342088789, 0.11638313852017745, 0.0537580421223538, 0.030273498778115027, 0.019475021872494835, 0.0420124753145501, 0.008663129719934659, 0.015245120575855253, 0.061325536444201134, 0.03735779559065122, 0.0332946892012842, 0.023757082235533744, 0.03310701489681378, 0.02290982232807437, 0.039639717870159075, 0.04151087625359651, 0.06938193168025464, 0.01861298209405504, 0.038414120353991166, 0.01242604108483647, 0.023396632241201587, 0.05365995617466979, 0.009542720363242552, 0.007462306484740111, 0.059542597155086696, 0.02376101376285078, 0.06807834186474793, 0.02478526846971363, 0.028534635639516637, 0.03265920669946354, 0.06054720164684113, 0.02870278218324529, 0.04180714531685226, 0.010895500654442003, 0.039120774818002246, 0.06479667616076767, 0.028032329682901036, 0.04292640049243346, 0.07022406149189919, 0.017983702091441955, 0.03322097909403965, 0.10448563552927226, 0.021499136892089155, 0.02808687753713457, 0.01592174310644623, 0.08621387067250907, 0.03697187879879493, 0.03234404997783713, 0.014220575503713917, 0.009199150517815724, 0.020812806142203044, 0.03218793550331611, 0.016695270642230753, 0.018318746515433304, 0.029738792509306222, 0.017302764899795875, 0.0490563807397848, 0.032244561371044256, 0.020705395108961966, 0.019391446767258458, 0.08137335345963947, 0.032464274190715514, 0.12338282307609916, 0.007579232315038098, 0.04742604556668084, 0.03056455054320395, 0.05364046366594266, 0.010797986160469009, 0.05097705150546972, 0.06626313770539127, 0.024921656658989377, 0.019842809851979837, 0.013301768849487416, 0.02391626734606689, 0.08128514178679325, 0.0721700766007416, 0.019552010417100973, 0.021243776864139363, 0.04601675165758934, 0.04028855531942099, 0.03624755750934128, 0.016790862973721232, 0.02946310691186227, 0.08907153256586753, 0.0613194805191597, 0.004248930426911102, 0.04130010260269046, 0.130719680164475, 0.06396582699380815, 0.010639733372954652, 0.05317483279213775, 0.024125087293214165, 0.05278993645333685, 0.06167221588839311, 0.08929968360462226, 0.012334284729149658, 0.044142342667328194, 0.0659957344760187, 0.020481999381445348, 0.047179103348753415, 0.050595791690284386, 0.06408985471352935, 0.014490758076135535, 0.017790693600545637, 0.06369322130922228, 0.03290680942882318, 0.04118496952287387, 0.047645190643379465, 0.012174607945780735, 0.05778560334874783, 0.1166538888355717, 0.04263130402250681, 0.05022505923989229, 0.04957730903697666, 0.01726365000649821, 0.004086193212060607, 0.02230145790235838, 0.030965586738602724, 0.08312980178743601, 0.040853956816135906, 0.014670150940219173, 0.029592758255603258, 0.04153488473093603, 0.02482621646777261, 0.059959120117127895, 0.03271349109127186, 0.07396136134047993, 0.02753411481535295, 0.011574815325730015, 0.027877098364115227, 0.041472258599242195, 0.05081351555418223, 0.024244240958068985, 0.046309380486491136, 0.024353971202799585, 0.037373373270384036, 0.04435514609212987, 0.015774473176861648, 0.06085189408622682, 0.021631625095324125, 0.04865974362473935, 0.022543511222465895, 0.07465705799404532, 0.006537502813444007, 0.012703997654170962, 0.023341420164797455, 0.011149657475471031, 0.022290277447609697, 0.03822228260105476, 0.036302328007877804, 0.021717845957027748, 0.04064082313561812, 0.04471188905881718, 0.07223716675071046, 0.041778876911848783, 0.02120196797477547, 0.047821699336054735, 0.06531059116241522, 0.039914687295095064, 0.0582489409862319, 0.02637199875607621, 0.03693627797474619, 0.043155683306395076, 0.0017465702262597915, 0.0533098034793511, 0.07157183135859668, 0.027035050188715104, 0.015627221800968982, 0.045043844293104485, 0.03434502854361199, 0.017711309774313122, 0.014054737039259635, 0.025117576224147342, 0.05241962702712044, 0.03451631993812043, 0.06619312349357642, 0.02528074852307327, 0.04629245580872521, 0.042288572803954594, 0.03878055948007386, 0.04849785524129402, 0.05412609170889482, 0.028775154569302686, 0.01516728783826693, 0.06749407868483104, 0.08269462865428068, 0.07581819256301969, 0.0038840196612, 0.017599572020117193, 0.03692185433465056, 0.06484725352493115, 0.020562899044307414, 0.05394071064074524, 0.028626953244383913, 0.045251749543240294, 0.0673033541534096, 0.04450547552551143, 0.09999905596487224, 0.020837274751102086, 0.04605060843459796, 0.05061488343926612, 0.010118249392689904, 0.06472245397162624, 0.008182819165085675, 0.08146044448949397, 0.03025361664185766, 0.06795830689952709, 0.019463245844235644, 0.042091914801858366, 0.02542822254326893, 0.06478732510004193, 0.01569940308399964, 0.03550342458765954, 0.06091020462918095, 0.028245567264093552, 0.019045323933823965, 0.09307392756454647, 0.14446942048380151, 0.19043473759666085, 0.08614644655608572, 0.21991459478158504, 0.14487067004665732, 0.15076780517119914, 0.11912311805645004, 0.10462579753948376, 0.18166237394325435, 0.0954614908550866, 0.1566657715011388, 0.08256392902694643, 0.17433316097594798, 0.1099889945180621, 0.1626174693228677, 0.14023068855749443, 0.13737244036747143, 0.10376332546002232, 0.15430865110829473, 0.16827080893563107, 0.14561940799467266, 0.16427639202447608, 0.07683851203182712, 0.1772960668313317, 0.14409294381039217, 0.14854461274808273, 0.1019292113778647, 0.18058388493955135, 0.07990088051883504, 0.1277565665077418, 0.08839398884447291, 0.1461322617251426, 0.12985844747163355, 0.16848453262355179, 0.14475437550572678, 0.11719607224222273, 0.2009288690169342, 0.1529420306906104, 0.27266965771559626, 0.23241343034897, 0.12759252218529582, 0.13927058695117012, 0.16856459551490843, 0.10139304678887129, 0.15600387967424467, 0.13950454158475623, 0.30832065094728023, 0.1849217529525049, 0.11229444658965804, 0.11364955629687756, 0.1471278231474571, 0.09936213740729727, 0.15981837030267343, 0.17236698913620785, 0.2268690528580919, 0.12267450991203077, 0.18141056323656812, 0.19674204289913177, 0.10459571829414926, 0.1880043969140388, 0.09904180420562625, 0.1216371581540443, 0.14060594810871407, 0.17086333857150748, 0.06870340832392685, 0.19531665922841057, 0.22686123062158003, 0.0982056264183484, 0.21291213459335268, 0.19432179542491212, 0.20448714058147743, 0.08924712470616214, 0.15371744142612442, 0.09452351267100312, 0.1199053120217286, 0.13075522903818637, 0.1765037202858366, 0.12653842015424743, 0.08990329457446933, 0.16477284429129213, 0.11877119904966094, 0.09606715015252121, 0.19764023454627022, 0.16701527318218723, 0.1212615572148934, 0.1668754970887676, 0.15134307352127507, 0.09867289001704194, 0.11391025051125325, 0.07923730401671492, 0.14255303191021085, 0.15694003959652036, 0.146144833706785, 0.1941236123093404, 0.24124642746755853, 0.15097664552740753, 0.09888213855447248, 0.098803277942352, 0.18383702990831807, 0.16800988465547562, 0.2176203194539994, 0.17283397814026102, 0.11598169599892572, 0.13694947556359693, 0.19715248025022447, 0.10917498468188569, 0.11504407404572703, 0.08774206406087615, 0.09784769601537846, 0.09467966054216959, 0.14073741214815527, 0.1683813295676373, 0.1315192403853871, 0.16370369150536135, 0.12133491851272993, 0.17351316200802103, 0.1260189464665018, 0.09895704351947643, 0.1664822330349125, 0.11277469035121612, 0.20070549740921706, 0.12888526922324672, 0.10419299185741693, 0.13625020917970687, 0.18608616781421006, 0.14032295235665515, 0.26828763191588223, 0.12107878108508885, 0.11116293113445863, 0.10667022143024951, 0.13823505345499143, 0.11428970319684595, 0.16820501012261957, 0.11835472061648034, 0.15738043002784252, 0.09313315094914287, 0.18415992351947352, 0.16119161067763343, 0.1490698751877062, 0.08270375707070343, 0.1573181341518648, 0.14974848018027842, 0.06342296823277138, 0.132598590280395, 0.15315958386054263, 0.1895813419832848, 0.15455630578799173, 0.1291670330101624, 0.10230310537735932, 0.12609981087734923, 0.10779166594147682, 0.15592408395605162, 0.1794840962975286, 0.08778050731052645, 0.17050804279278964, 0.10773842426715419, 0.2069935662439093, 0.11362809338606894, 0.11241462256293744, 0.12243459583260119, 0.08196376904379576, 0.2014114282792434, 0.13104753132211044, 0.1278875258867629, 0.07614984351675957, 0.1950424801907502, 0.18283658515429124, 0.12952549033798277, 0.18566388578619808, 0.23637862148461863, 0.11963561555603519, 0.09650200416217558, 0.11003877778421156, 0.11812930068117566, 0.08413141913479194, 0.2483425021637231], [0.03426894727454055, 0.038408060718211345, 0.023647763882763684, 0.04706601859652437, 0.011968598882958759, 0.00872659076776472, 0.05240593811322469, 0.049482744580018334, 0.00475220627777162, 0.017196272274304647, 0.012890518846688792, 0.0761030065768864, 0.03103472521615913, 0.041709300567163154, 0.024445079106953926, 0.13170738966437057, 0.0668520615727175, 0.028411613529897295, 0.029238130409794394, 0.012249430346855661, 0.060861330493935384, 0.020906975405523553, 0.03445637667027768, 0.005340124071153696, 0.03870032960548997, 0.03598909344873391, 0.015851762291276827, 0.07091872656019405, 0.013091808777971892, 0.016073927909019403, 0.018187360401498154, 0.05859353128471412, 0.005861419731445494, 0.0557743052195292, 0.07076481255353428, 0.03054794498893898, 0.03913460473995656, 0.01853193956776522, 0.08006950389244594, 0.05588852916844189, 0.06236207555048168, 0.03621941155870445, 0.03334697350510396, 0.06682531457045116, 0.02203128646215191, 0.012007000386802247, 0.014655773684353335, 0.0033698084962452413, 0.027195548900635913, 0.04760907031595707, 0.030830148498353083, 0.06619399922783487, 0.047919737044139765, 0.0638761384470854, 0.029105632929713465, 0.037617747657350264, 0.021123331862327177, 0.03370495585841127, 0.08441495665465482, 0.05561665449931752, 0.09167399955913424, 0.0459966209018603, 0.04261839065293316, 0.04049900242534932, 0.023608389237779193, 0.03499169150018133, 0.0265732024126919, 0.05514348711585626, 0.006057068412701483, 0.05358990114473272, 0.026366187739768066, 0.06274031111388467, 0.06421407539164647, 0.013584582775365561, 0.029791446031595115, 0.0218455139111029, 0.03238996294385288, 0.07779443534673192, 0.033825643913587555, 0.07675309083424509, 0.07688955694902688, 0.03716160514159128, 0.014524923772114562, 0.010804658068082063, 0.026686198107199743, 0.029414115888357628, 0.043234647819190286, 0.041763295521377586, 0.08064581124926917, 0.04191086416540202, 0.07716925014392473, 0.035879619244951755, 0.027250759121670853, 0.025444245511607733, 0.02793915118672885, 0.07851812581066042, 0.03462786102318205, 0.022037971357349306, 0.0873955330462195, 0.007331473270824063, 0.028792875200451817, 0.06810450999182649, 0.022435582541220356, 0.0321537002309924, 0.005217718407948269, 0.08176768620614894, 0.03313275257823989, 0.04148055952100549, 0.08070468582445756, 0.04543519360595383, 0.024927141130319797, 0.03986583913501818, 0.025061922569875605, 0.009943915192707209, 0.013274438333610306, 0.06059013117919676, 0.030432587409450207, 0.0330605119233951, 0.10531514140893705, 0.010538247461227002, 0.10103956927196123, 0.025705553853185847, 0.014602223091060296, 0.014677449034934398, 0.022311334032565355, 0.046225963087636046, 0.07352943139267154, 0.031505638326052576, 0.013071163157292176, 0.017753599204297643, 0.06468432242400013, 0.060205698682693765, 0.05130037185153924, 0.04665191132517066, 0.07316243194509298, 0.013231095981609542, 0.08730286848731339, 0.004232502988088527, 0.05413500119175296, 0.03766241381526925, 0.010954186909657437, 0.0364227266254602, 0.010248888720525429, 0.01740338899253402, 0.03535473901138175, 0.026501561042096, 0.036507698823697865, 0.062324626778718084, 0.06651158648310229, 0.01636311131733237, 0.049431610605097376, 0.0433092076855246, 0.02159751227736706, 0.05891134489502292, 0.031707654634374194, 0.020984527982363943, 0.040609534189570695, 0.01324802065937547, 0.05697246182535309, 0.016408870287705213, 0.02102656137140002, 0.007817106416041497, 0.047673306908109225, 0.02545249262766447, 0.028575466749316547, 0.017772755891201086, 0.054360710564651527, 0.012493794529291335, 0.013671712767973077, 0.013775330498901894, 0.03444570829742588, 0.14659830078016967, 0.04227244593494106, 0.02498911417205818, 0.05041467054979876, 0.01341074117590324, 0.04446788574568927, 0.04440636170329526, 0.009074027202586876, 0.03320933108625468, 0.038615899175056256, 0.014529589097946882, 0.024584460006735753, 0.013319742738531204, 0.015387123112304835, 0.0437918597162934, 0.01510433145085699, 0.06854344581370242, 0.05319490788679104, 0.03309662854007911, 0.01639319241803605, 0.061817272362532094, 0.06981807702686638, 0.034852067547035404, 0.11651371198240668, 0.06677003941149451, 0.024349700142920483, 0.01632028568565147, 0.025646449212217703, 0.031156717595877126, 0.043374008309911005, 0.020228830544510856, 0.022103002047515474, 0.026682437273848336, 0.021064581596874632, 0.023255236410477664, 0.05835930576722603, 0.010152367776754545, 0.022446176699304488, 0.11432350060204044, 0.02161949098081095, 0.004428173006090219, 0.06286454663495533, 0.04661975035560317, 0.014597010431316448, 0.013472315313265426, 0.03562905163562391, 0.027291042897559237, 0.02747057213127846, 0.043057586226495914, 0.04015162536234129, 0.02499376187188318, 0.025652314034232404, 0.08523658834747039, 0.07635273927007802, 0.06559927918715402, 0.041426861425861716, 0.12095368467271328, 0.010009825327870203, 0.0668506663350854, 0.020177132537355646, 0.044422592472983524, 0.029367603638092987, 0.00895640421731514, 0.04287037947506178, 0.013633539474540157, 0.04993427835870534, 0.051317522884346545, 0.01800600362912519, 0.026678743233787827, 0.06527082688990049, 0.02628349764563609, 0.02228540524811251, 0.03361467730428558, 0.04766871301399078, 0.05721699206333142, 0.06233205567696132, 0.04528295685304329, 0.008049326279433444, 0.05166879993339535, 0.01888026101369178, 0.02591624030173989, 0.03876358285197057, 0.06033763398590963, 0.08936052487115376, 0.059554668187047355, 0.08962423220509663, 0.07469597621820867, 0.030216626146284398, 0.0219554872091976, 0.009271428280044347, 0.028621333331102505, 0.08207362174289301, 0.022618631410296075, 0.030995634442660958, 0.031792508088983595, 0.011504777921800269, 0.04291127923352178, 0.0402604019473074, 0.04894354831776582, 0.007106061684680753, 0.08902963832952082, 0.03673416889796499, 0.009798664832487702, 0.031112326032598503, 0.04384136096632574, 0.02351110480958596, 0.04399727135023568, 0.02169821244024206, 0.07739685941487551, 0.018304417499166448, 0.06589901036932133, 0.028231583346496336, 0.03368787532963324, 0.07709735829848796, 0.045343271194724366, 0.015556345770164626, 0.03668082703370601, 0.10002163209719583, 0.058605498416000046, 0.021771937390440144, 0.023071352625265718, 0.028213116856932174, 0.008215079396904912, 0.0240915941685671, 0.03431936136621516, 0.024264815147034824, 0.05587756022578105, 0.034935807780129835, 0.01428439463779796, 0.02045681274466915, 0.011167354914505268, 0.03739949315786362, 0.050887952966149896, 0.05505053683009464, 0.01988961339520756, 0.0420597723859828, 0.09291107809985988, 0.04126152205571998, 0.040673822732060216, 0.056994588958332315, 0.0530601561331423, 0.06159870987175964, 0.0186882618436357, 0.04301718741771765, 0.04829331192013342, 0.014026079934410518, 0.026473804718989413, 0.015819395375729073, 0.012865940771007445, 0.06567088901647367, 0.037334662847570144, 0.051018671147176065, 0.015661995130358264, 0.008960856175690424, 0.06846051081083715, 0.09084170320420526, 0.05779951861768495, 0.01844327704020543, 0.02599118979560444, 0.020310923209763132, 0.04772909414896276, 0.0570539941691095, 0.021732048808189575, 0.011551590741873952, 0.056433848149026744, 0.04846777970669791, 0.011646628317976138, 0.023557220010843594, 0.026809849186975043, 0.014126091755315429, 0.016206727814278565, 0.016444760549347848, 0.03462010557996109, 0.024702057016838808, 0.03911380976205692, 0.04773230764840264, 0.07232182353618555, 0.026441057452757377, 0.051234725178801455, 0.008150307530740974, 0.020966131996829063, 0.1822592387907207, 0.14100345724727958, 0.09637191309593618, 0.14992420590715483, 0.1006983668776229, 0.0790657194738742, 0.09470790668274276, 0.1153525328845717, 0.11504846013849601, 0.15032351104309782, 0.13069778680801392, 0.18666511721676216, 0.21591771394014359, 0.0997823265788611, 0.08834177133394405, 0.19382608530577272, 0.18875479727284983, 0.1829778158571571, 0.2153888446628116, 0.15547584160231054, 0.15841786342207342, 0.08092877731542103, 0.20798152807401493, 0.0740901981771458, 0.11541209765709937, 0.14277113426942378, 0.07107632161932997, 0.1938230128143914, 0.07697727880440652, 0.095820868446026, 0.100968709011795, 0.1916308273212053, 0.21742207696661353, 0.19845751725370064, 0.13638297939905897, 0.10415206983452663, 0.1729685443569906, 0.1248275619582273, 0.11775315797422081, 0.15136934554902837, 0.15775046485941857, 0.10147685010451823, 0.13368890911806375, 0.1612980494974181, 0.09791956559638493, 0.09779082523891702, 0.1158780996047426, 0.12042106754961424, 0.28720776666887105, 0.08527131343726069, 0.08838422960252501, 0.2548487624153495, 0.11605667517869733, 0.16604589472990483, 0.06886623552418314, 0.08720105324755423, 0.14668726944364607, 0.12539935705717653, 0.1382063768687658, 0.09651408632635139, 0.22920237999642268, 0.1518066189601086, 0.12610028585186228, 0.0953659022343345, 0.16288014507154003, 0.11132062267279252, 0.09267258894396946, 0.27002214977983385, 0.14838840550510213, 0.15191001497441903, 0.14085079747019336, 0.1923060035915114, 0.14587760117137805, 0.11607008578721434, 0.14154210803098977, 0.14106014248682186, 0.11512851560837589, 0.2003597456496209, 0.23199341929284856, 0.18708313931711018, 0.21618809318169951, 0.1454895915230736, 0.12842369789723307, 0.05114852843689732, 0.10059123043902218, 0.1200232541305013, 0.09850147616816685, 0.10289182886481285, 0.13225194794358686, 0.11099867901066318, 0.19783558265771717, 0.0840957737818826, 0.09453710881643929, 0.15033286210382357, 0.09043710655532777, 0.17744048876920715, 0.13522174092940986, 0.09526093286694959, 0.1583377708448097, 0.1190177998796571, 0.0898892011900898, 0.17428380815545097, 0.1372890526545234, 0.12466673855669796, 0.16439374041510746, 0.14055365638341755, 0.13090163993183523, 0.23597044026246294, 0.1128040645562578, 0.09614114969735965, 0.14112914737779647, 0.2292115380987525, 0.2250188638572581, 0.10825165649293922, 0.14151205105008557, 0.10602288311929442, 0.11588645618758164, 0.11383746066712774, 0.1560172383324243, 0.17859933752333745, 0.13950515014585108, 0.0757384042663034, 0.09911393353831954, 0.06893318466609344, 0.0650150902220048, 0.13184223789721727, 0.15295806108042598, 0.1808615223853849, 0.148599264502991, 0.11777134059229866, 0.17382689751684666, 0.24555026058806106, 0.12040229863487184, 0.12711558840237558, 0.15198105335002765, 0.06903318906552158, 0.15648326254449785, 0.12166802407591604, 0.17959979712031782, 0.1024909874831792, 0.11304896586807445, 0.12937869352754205, 0.052342113413033076, 0.15187670738669112, 0.16660413821227849, 0.10107211244758219, 0.16904431977309287, 0.16749299364164472, 0.1556039066053927, 0.12415666788001545, 0.11602342696278356, 0.13695885631022975, 0.09080092218937352, 0.2330426825210452, 0.15527311654295772, 0.11060274322517216, 0.15491563885007054, 0.10731387868872844, 0.17621168517507613, 0.11821387583040632, 0.15723302465630695, 0.1489634660538286, 0.09520162042463198, 0.17795441119233146, 0.08518770308000967, 0.16532120236661285, 0.1223997371562291, 0.08384745116927661, 0.21902502689044923, 0.09180273249512538, 0.11518480008817278, 0.23821837588911876, 0.14308573066955432, 0.09014323833980598, 0.1459203043486923, 0.07779068750096485], [0.02584879763162462, 0.030278398808150087, 0.06018678504915442, 0.04029685995192267, 0.08868298114975914, 0.05407556258433033, 0.03774384596908931, 0.05411451420513913, 0.04542157519608736, 0.02606388872663956, 0.013317733373696683, 0.05769791117927525, 0.050116735365008935, 0.11140812930534594, 0.018731623677012976, 0.02395336916379165, 0.02271861540066311, 0.03782144493015949, 0.02917197907663649, 0.020368716104712803, 0.04584185342537239, 0.09439747373107821, 0.02193630083638709, 0.044389544636942446, 0.044149482127977535, 0.04208116479276214, 0.02274949431011919, 0.013305102020240156, 0.03866943399771117, 0.022720159067830537, 0.01098711414670106, 0.05209131573792547, 0.03166652109939605, 0.043853005263372324, 0.10454901494085789, 0.0487861721921945, 0.007143397742765956, 0.02605060799396597, 0.012442378538253251, 0.05397948043537326, 0.041530691596562974, 0.01594664587173611, 0.03933831314498093, 0.0725170825899113, 0.03960826936236117, 0.014780025903746719, 0.034199556466774084, 0.024585365426901262, 0.03370192789589055, 0.026256136516167317, 0.013893059240217553, 0.01655234784266213, 0.03997276035079267, 0.012430647966539254, 0.10405824010376818, 0.0686918011342641, 0.017570908421475906, 0.011920832403120585, 0.036931257345713675, 0.04601750122674275, 0.054574616078753024, 0.004478710479816073, 0.040015077611315064, 0.015401902055600658, 0.016477118188049644, 0.04984362130926456, 0.0657801925262902, 0.022930702652956825, 0.029920824636064935, 0.021915095821896102, 0.050521517550805584, 0.07170431214035489, 0.010486971550562885, 0.05912362510571256, 0.022909722138138022, 0.0659487268421799, 0.07121481379726902, 0.04164041813055519, 0.00844933738335385, 0.017675220988166984, 0.024924315403040964, 0.012248533275851514, 0.016866558326000813, 0.024907310944399796, 0.07074051463860087, 0.022655458633380476, 0.07283760132850148, 0.05034089736000169, 0.015546355534752365, 0.05791459603642579, 0.07027428262517788, 0.03754900622880086, 0.03145336886518635, 0.021809284116898198, 0.036369188092066906, 0.04011588353023399, 0.03072525891184341, 0.021502031268028077, 0.03688743723614607, 0.00704059173585847, 0.04125826031668112, 0.09542954139760695, 0.029131556148058735, 0.027178282834938727, 0.015010051793069579, 0.03138387044600677, 0.016205054271267727, 0.03286741623014677, 0.025401102611795068, 0.011287928864476271, 0.026145539814024232, 0.01802513619622914, 0.058953068437404, 0.05416522144514602, 0.06070175390050281, 0.039387973956763744, 0.012605644533323357, 0.02850513341400074, 0.03329770974232815, 0.07648634811630473, 0.018692994890443515, 0.025096579011005815, 0.030157434302964248, 0.040873683101381175, 0.027232812135480344, 0.022178387553140055, 0.031980111889424734, 0.018042687988781836, 0.07982621304108761, 0.00533040054506273, 0.04274736107618082, 0.041840044723358005, 0.020599379313352983, 0.10158645047340542, 0.10771583329187706, 0.04730777320219204, 0.10166419786401093, 0.048220458993455395, 0.022756156940886285, 0.01613635180547135, 0.017926784930750728, 0.026141597154492047, 0.01606150806765072, 0.0868610011821147, 0.04715674614999443, 0.009219625444529811, 0.037951658450765535, 0.10915312101133168, 0.030257705875555985, 0.027053904450440314, 0.0494295919634169, 0.04337444988777861, 0.02624623812153004, 0.01400320601533167, 0.031459951715078205, 0.021139223099453375, 0.07480719446903095, 0.031248450759449042, 0.08467050778563134, 0.046561777489841916, 0.08746111663640477, 0.06898109029862098, 0.032508502481505275, 0.02431916076602647, 0.010455892261234112, 0.03316146627184935, 0.03826090396614745, 0.030519687716150656, 0.0519217127293814, 0.04116939926461782, 0.057206260607927106, 0.02621188039483968, 0.1816505441092886, 0.0449458622460952, 0.04841237467189785, 0.051313459625816904, 0.01747323065501405, 0.028300940757617354, 0.030338418146129698, 0.0572376015043119, 0.002384483841524343, 0.027120744125568308, 0.07547382119810209, 0.050933936436194927, 0.11261540319537744, 0.06265424424782395, 0.03912299012881704, 0.03352023159095552, 0.027812199405161664, 0.017819071472331416, 0.03096108561294386, 0.02718864878261229, 0.002985079140671587, 0.15260251297149807, 0.057905007488443516, 0.006379746337188408, 0.05154680198756978, 0.08923046349082142, 0.04337556310929358, 0.038362511404557154, 0.05735131708206609, 0.046741314145037904, 0.017662081263551954, 0.043134691659361124, 0.018723623325058725, 0.052176551398588344, 0.023714119306532666, 0.02836762087099487, 0.07434070270392112, 0.04625106623279862, 0.06366119763697498, 0.046041969835641794, 0.018909941354650073, 0.06818957495852374, 0.012520367126853671, 0.0980235701717902, 0.06657690290012397, 0.02597821890958585, 0.06667212786851451, 0.03188758833857719, 0.036763331590918824, 0.02279304539115401, 0.0725010150927119, 0.02798404369968921, 0.02246046860818751, 0.05198311060667038, 0.027009416407963727, 0.050826028164010495, 0.028521310377982445, 0.010432504404889187, 0.027714452990039717, 0.04031450080219656, 0.011641916607914027, 0.012334504590398865, 0.06293753685895354, 0.03869510859658476, 0.03054921777220443, 0.05444820235425141, 0.13796844432363287, 0.01306877436945797, 0.01648616867896635, 0.03803880143095739, 0.03523797320667654, 0.024406659977103118, 0.02743176151852822, 0.04034675825096201, 0.048769047134555876, 0.10887863769312389, 0.03129772565444, 0.041528502260916866, 0.018442251021042466, 0.02149588257452706, 0.06842237926321104, 0.008113741914712591, 0.07883736805524677, 0.051626404747366905, 0.02276030554639874, 0.03435922582866624, 0.032068349537439644, 0.02720009084441699, 0.03730640557478182, 0.031971232092473656, 0.017829032949521206, 0.028695928449451458, 0.04570759519992862, 0.03547915264789481, 0.02251484020234784, 0.030132344145386014, 0.05207435766351409, 0.023657623314647935, 0.023446482300641946, 0.007057706588966539, 0.04525539719907101, 0.028259168975637294, 0.03283064652350731, 0.013636650000989903, 0.043428530188975856, 0.035843654768541455, 0.00466818913082534, 0.044594614882953465, 0.014055991268833168, 0.02236285577964736, 0.03343465825309977, 0.036996978233219124, 0.02363933679589536, 0.03125720439129509, 0.04320114356232807, 0.03473340184427798, 0.02717505078180693, 0.021130181885382626, 0.030599388810514938, 0.016563736098760273, 0.037539688564720564, 0.07222500295029022, 0.012463476869015722, 0.02027268405072391, 0.11743655035388656, 0.05624373960017692, 0.04463115823455155, 0.04805120108358096, 0.016546893057238776, 0.039003099882393144, 0.043770712218247354, 0.04214907130517531, 0.030448723555309698, 0.030990754821687005, 0.00864606588947936, 0.08424625906627625, 0.03360482158313971, 0.07338792609516531, 0.034126250830013305, 0.03115373787295539, 0.09136211941950023, 0.047095170157263055, 0.023881121087470092, 0.03300320327980444, 0.024620233380119316, 0.004247332026352524, 0.08279894493171014, 0.05277098200167529, 0.05617769216769375, 0.024038562150963116, 0.026580631310935132, 0.08212500062654726, 0.008438025197392562, 0.00867718321387656, 0.026681069866754115, 0.07307658772333525, 0.03618262700911146, 0.007496759762943839, 0.027932664816034958, 0.046380092317122035, 0.05272491318464745, 0.05560724777751602, 0.04471709151403047, 0.01260495340829948, 0.04176066089712549, 0.04987499189155642, 0.0224338904445176, 0.038746710124542005, 0.02445681060635252, 0.06147143154521473, 0.008215134130296065, 0.03274855014751665, 0.017788799268600997, 0.04492194653721526, 0.04329276540374849, 0.048652852783561684, 0.11071118584368378, 0.05942288873484358, 0.022142263514979277, 0.05038718882133253, 0.08460988174192607, 0.13111954933265224, 0.16763296269346029, 0.14869388833176345, 0.21586493239738047, 0.18154884019168094, 0.10589973113383166, 0.15111425454961136, 0.29577989887911826, 0.18867094942834228, 0.0884405140823219, 0.16640748392092064, 0.1006414441508241, 0.169002239999827, 0.1028244270128198, 0.09094114357139915, 0.07152811143896542, 0.23659681290155277, 0.11226433023693971, 0.0923163654806558, 0.11082462311605923, 0.1562740362714976, 0.11698123533278704, 0.15255311562214047, 0.12035845255013555, 0.09007211090647615, 0.13738385459873825, 0.07577112555736676, 0.16187094297492877, 0.16968862270005047, 0.12384700676193461, 0.13143754476914182, 0.1561084928107448, 0.12439637415809557, 0.24192580429371446, 0.1352601544931531, 0.0985071313334629, 0.3750632383162156, 0.1158474043768365, 0.1998957697651349, 0.19641352380858734, 0.12629137403564528, 0.1112150150584057, 0.1709052550722845, 0.15752458479255438, 0.16692146571585909, 0.16280122508760542, 0.15842020860873163, 0.13201266468968242, 0.1356520233093761, 0.10153248149435967, 0.1586621190654114, 0.1339589321287349, 0.13063715334283188, 0.15623922954546288, 0.21260821027681231, 0.11594175361096859, 0.0602625471947249, 0.18479471211321652, 0.20333768741693348, 0.13671151333255693, 0.10336149702197872, 0.14658160245744511, 0.10750281464424916, 0.10221625183476135, 0.1287128237891011, 0.09292297472711653, 0.15412030887091532, 0.1553521997993812, 0.09028847664012574, 0.09110860919463448, 0.20292537985369563, 0.07793194046826102, 0.19404346036026254, 0.12214211543323472, 0.08686883084010333, 0.14917521562892944, 0.10086869719089009, 0.11713151281583123, 0.1661453870474361, 0.13785749324597418, 0.19180302042514086, 0.11742187809431925, 0.10962227708660066, 0.1249849863233976, 0.14252990658860654, 0.13970619795145467, 0.2589474362321198, 0.14308072859421372, 0.1427865560981445, 0.19507458549924195, 0.10476991519681178, 0.08917845378164202, 0.14159762067720294, 0.10396472207503393, 0.2030344310333021, 0.1401588783483021, 0.10201898156083189, 0.07683261195779778, 0.090588526945794, 0.1021675298397895, 0.19009753537829965, 0.19014381570741534, 0.15110497770365328, 0.10953237331705168, 0.08715334799489938, 0.1306303552701138, 0.14490295347059146, 0.11826076472061686, 0.16112799377879128, 0.11607819746132009, 0.19462341908365488, 0.19457112735835835, 0.09383247670484707, 0.1373476823209785, 0.15219430206343532, 0.15406803198857233, 0.12569164449814707, 0.1819160845479928, 0.14433670963626355, 0.19464926066575572, 0.12426830915501341, 0.1130616788577754, 0.2830692840507254, 0.1793067526887171, 0.1431189343566075, 0.1101724237378221, 0.15151068015256897, 0.13892628980102018, 0.10710583243053406, 0.12299569658352993, 0.1301699862233363, 0.13982752425363287, 0.2820944582344964, 0.1861807916429825, 0.12737128796288744, 0.1478948030853644, 0.08911156401154585, 0.15745655953651294, 0.07333161935093813, 0.19066685170400888, 0.07564893094240688, 0.17165828263387084, 0.15127071412280202, 0.10490937958820723, 0.13581010076450184, 0.111387312063016, 0.17881123552797362, 0.08361005297047086, 0.1240135298576206, 0.06756156959454529, 0.13855686353053898, 0.17375290539348498, 0.09110395592870191, 0.12889708421425894, 0.2219666776363738, 0.1478498734650202, 0.178142367512919, 0.22674100269796327, 0.11726340730092488, 0.1646402818732895, 0.14003216405399144, 0.1105875737266615, 0.15873881260631606, 0.08751478133490309, 0.13938803924247622, 0.09381857627886347, 0.156375621445477, 0.0959596129541751, 0.1397427561460063, 0.19950063549913466, 0.08421378268394619, 0.3740982385352254, 0.2526296518044546, 0.13100092444801703, 0.1328661196748726], [0.015484666364500299, 0.03198937760316767, 0.06442918689572252, 0.0291551341797458, 0.00876132235134719, 0.020746799527842086, 0.03278485972259659, 0.036503164301393554, 0.01544873714010464, 0.05039033181674313, 0.02228036792075727, 0.0435410397767555, 0.03625687517342158, 0.07265349675435573, 0.011861536659125704, 0.0446633711544564, 0.051812598467222415, 0.013493675251083914, 0.055247692071134225, 0.022313304434646852, 0.08492061155266128, 0.003518349585647229, 0.053479807247640565, 0.027130456983286422, 0.08444896186119877, 0.05902711251110304, 0.008976065564638702, 0.018430270902172197, 0.004328571221776656, 0.038776006404077634, 0.02398145017650677, 0.04060290310007986, 0.08507831793394871, 0.04581454239087179, 0.010480239343451103, 0.07264558546012267, 0.09129301062785089, 0.020204903703415766, 0.027860166264872532, 0.029967791451781522, 0.026009190587501507, 0.1097148229018785, 0.01874505469459109, 0.03267891072027851, 0.0009502925013293861, 0.07683146162889898, 0.015746021090308204, 0.0005565731862589018, 0.07984721582033671, 0.031817800481803715, 0.026245852204738185, 0.059546738339122385, 0.05278992903186008, 0.035833992005791515, 0.0452249023510376, 0.06126824635430239, 0.07921259049908258, 0.13376138726016507, 0.08134360075928271, 0.02763949793006759, 0.03673334140330553, 0.052822980578639545, 0.07164983850088902, 0.023479969859181438, 0.003340049997859751, 0.017425187725166325, 0.020135360755375586, 0.02066545086563565, 0.04991942798369564, 0.0572368704888504, 0.02790308466501301, 0.010988370231643785, 0.05321046701283194, 0.05603268764389213, 0.015824766669538803, 0.06341277854517102, 0.01132382933064946, 0.0022429031696447055, 0.04277485022612382, 0.01474144535677624, 0.05045174082624726, 0.05677920657035429, 0.08222488628234714, 0.030820433785265777, 0.06750118845957331, 0.04714235590654425, 0.026407291588839144, 0.016725951027183328, 0.08507277409080416, 0.03766122266824823, 0.021726514241890982, 0.06923509776243009, 0.05420659617811907, 0.097775603790069, 0.04652759787859395, 0.06257526489207521, 0.0666329127852805, 0.0684178966912441, 0.015291406471078517, 0.050360939058009535, 0.03145228161884006, 0.10716691860579886, 0.06655438613961451, 0.02648166220751591, 0.0057530759113433305, 0.004618426273736986, 0.025515480556350667, 0.01963204918865813, 0.06176173374115024, 0.033842639095382765, 0.05309158979798667, 0.022927513273316436, 0.053362833641585894, 0.06268263881793246, 0.027925775830226485, 0.08410354406805709, 0.03493595249892678, 0.011486900511954445, 0.047062441444722936, 0.031053870770847425, 0.0766100938199088, 0.009159707224171143, 0.0307752796652494, 0.030111608539300505, 0.007019915037744795, 0.027891794743482023, 0.04105090054508764, 0.04662933148210868, 0.00904624212125782, 0.0331577369797742, 0.038055570257711224, 0.049306833316222765, 0.018624509502842557, 0.04931391711579636, 0.04492527506954502, 0.05214366683503613, 0.03994613951363135, 0.03939337308111135, 0.06840975533123128, 0.07280180012458004, 0.01562977849971503, 0.027891659301531035, 0.06214115674083587, 0.05292518915666733, 0.0313503105280688, 0.08848435274558142, 0.011861558923556004, 0.02020218744291924, 0.017144648481917102, 0.07014515635091811, 0.03041527495952323, 0.04064041866513435, 0.016440409708593506, 0.06151706991659012, 0.038089872323325835, 0.05429794342489913, 0.04563241935102269, 0.006885274142405251, 0.11731183985830285, 0.01186591069199494, 0.04290547934942879, 0.048822418684721924, 0.092815927346237, 0.07112322535249405, 0.09407132951309904, 0.0375884587992914, 0.026014133291027974, 0.030683579898322932, 0.022895732654433232, 0.04024595233204309, 0.019575688638724387, 0.029206299695943017, 0.029070434720779303, 0.12406251902575605, 0.038109023444121704, 0.058809856200241484, 0.02244407827674877, 0.011874147603521124, 0.05149430246092379, 0.01767754391039489, 0.005087955742055783, 0.05465521702717524, 0.0786999223055318, 0.04871018369158264, 0.03956161795940716, 0.10061972148832865, 0.011838370519399177, 0.025202845281455666, 0.05873089539818466, 0.04419214077643119, 0.04431141875102185, 0.030508987802022602, 0.09920506185153499, 0.039568397478433326, 0.04896221333183348, 0.04564137336274143, 0.06269527759286575, 0.021461522992467508, 0.09674809291027486, 0.07058790681185201, 0.024811978364596143, 0.051199035297031514, 0.02836837971699424, 0.0989680050406605, 0.025902028173732106, 0.03339681985380594, 0.004302501429265249, 0.05678652414644603, 0.06419413388357498, 0.011332534722896526, 0.038391822527046315, 0.05664235824951902, 0.02581522101536393, 0.019350509901414625, 0.02754335084318882, 0.03494844655506313, 0.012218688734719763, 0.04609182731655892, 0.025660011961008422, 0.026479830958123785, 0.053916702163405716, 0.022035616893845145, 0.020324305987742264, 0.01867260809376603, 0.007490873140341137, 0.033977650600718334, 0.0358724612306105, 0.06118618337495718, 0.0456315324845491, 0.03539376484695822, 0.013916614079789724, 0.051521320347092114, 0.05299470984027721, 0.023924228735268116, 0.11426041804952547, 0.025939074330381118, 0.039267018728423864, 0.05237899073108565, 0.058486584093770944, 0.013110666750435485, 0.038992268237052485, 0.03108739543677075, 0.033226367086172104, 0.038013249286450446, 0.04974423660314642, 0.014146453504508827, 0.014933004804333905, 0.008230936309701065, 0.034914715943159536, 0.034675744391279295, 0.009346460337837925, 0.031126066896831617, 0.04221748989948537, 0.08176222399924882, 0.07149145676521584, 0.050786954088835046, 0.02868701525585493, 0.07970070102601312, 0.030566314999305177, 0.037880037489230745, 0.09731159079819918, 0.06640485080424696, 0.0726483907783404, 0.03110105466475943, 0.07670317398151383, 0.05431975885585416, 0.047664230442023836, 0.03218863683287054, 0.02769796432403382, 0.16293663735268638, 0.038465818361146376, 0.02763070533546852, 0.032844376255525276, 0.028482139823609032, 0.11053161579184234, 0.014220463253877824, 0.09312073481851257, 0.13272384996525943, 0.038342005864251405, 0.030523129426001105, 0.0659917046141345, 0.05588242500380147, 0.02048317197477445, 0.09734328050399199, 0.03166209418850485, 0.04391950169519987, 0.04773204418597743, 0.01685748928139219, 0.0261172398677445, 0.04386241940665059, 0.02262483576487284, 0.03107332802755991, 0.013707378529943526, 0.03884135992848314, 0.04887427625362761, 0.02357913563173497, 0.01828328113333555, 0.018625606026034802, 0.05225542685366236, 0.04048564376716968, 0.017561919157742523, 0.034630978043423966, 0.023952300471137278, 0.06192487264343072, 0.03266121791966725, 0.038657956683891825, 0.056292721346835606, 0.0649641640484333, 0.04647557332646102, 0.052794979346799664, 0.01583563171152491, 0.06714739924063906, 0.03630720020737499, 0.07643867254955694, 0.032900352744036354, 0.0555672608606983, 0.07231206429423764, 0.0319695399957709, 0.04228974910802208, 0.06231362815015018, 0.0268839786076569, 0.025165340848616324, 0.013545162673835875, 0.0043313955575285945, 0.018162160777137615, 0.0750309594150167, 0.045336602997849695, 0.05328369101334829, 0.02764557797490852, 0.019639927086245734, 0.04901847554720007, 0.07157028769142926, 0.0967234313429799, 0.039116240295697935, 0.039212819683598354, 0.015225372026179684, 0.12660401116590947, 0.05384224248700775, 0.10925603462965228, 0.0705536270106677, 0.049327030865242705, 0.016527816151210573, 0.07621932338224724, 0.00849693409691099, 0.012944119534950005, 0.03499635960906744, 0.02083350464090472, 0.04619449973688461, 0.021537878856179304, 0.039603924087714404, 0.0382121151778847, 0.01829317396186525, 0.15905517531791702, 0.2505581098375842, 0.1785915152868256, 0.06400312733603641, 0.0879073106625583, 0.13425982848275453, 0.1538344781147316, 0.2423633894068189, 0.12422228857758455, 0.23411744594341144, 0.23918030317872763, 0.1185491781507153, 0.1265358820091933, 0.10228331229882315, 0.06543173192767426, 0.13268148817587644, 0.1711590844206512, 0.1015399549214635, 0.15495823812671006, 0.1316181686706841, 0.21338948397897184, 0.07379552102065645, 0.20289676263928413, 0.11281366794719361, 0.188403345819097, 0.2848206041380763, 0.11036564188543707, 0.1513826151494868, 0.12029947407427244, 0.15254466998158023, 0.07683140967856161, 0.139503309619613, 0.128927527111955, 0.07948273225338198, 0.16195621574297547, 0.11427883815485984, 0.21770652732811868, 0.11505435279104859, 0.08545780772692524, 0.14688284019939601, 0.11592640599701554, 0.1556467730551958, 0.06966132801608182, 0.08639450941700488, 0.12071771139744669, 0.16771100694313645, 0.11111034997156821, 0.09226044465322047, 0.12203520906041376, 0.1244053318805527, 0.13043411658145487, 0.1868249461404048, 0.11552249212400056, 0.25802022661082447, 0.07553037285106257, 0.20381432434078306, 0.1694765020511113, 0.20837258052779362, 0.1944590630591847, 0.1327822866733186, 0.12420184240909293, 0.2262585621792823, 0.1538684981642291, 0.1511575366021134, 0.16725874214898795, 0.1434279646491632, 0.09588447792339139, 0.10539829905610532, 0.08302929272758774, 0.13236052414868027, 0.15937418007524684, 0.13857602578355, 0.10171160625759512, 0.11984909433522262, 0.12453048024326563, 0.15272008400643244, 0.15136348258238286, 0.2311994697083719, 0.12716917146462947, 0.08686738365213387, 0.08427699882304296, 0.15959479089360684, 0.16338507266482338, 0.1795859931735322, 0.28051320870872587, 0.17367325810482726, 0.15439211303601041, 0.12464236642699689, 0.19502270937664434, 0.2829150063917041, 0.17877947160741314, 0.26408927282318473, 0.09016873853397556, 0.2670641866279766, 0.14199152297805995, 0.16498664219398052, 0.13300445600179955, 0.1520921231713146, 0.13750895101111382, 0.11696864850819111, 0.12356404069578275, 0.25457532552536577, 0.13627916778204963, 0.17823613045038655, 0.16184075240744278, 0.16020532610127702, 0.08911353812436573, 0.20538473851047456, 0.19744730583624914, 0.10414281525299884, 0.1211886783130467, 0.13233765115728602, 0.12360979410004802, 0.11760406050598249, 0.12951168639119714, 0.24651523068314418, 0.09598624121281318, 0.1933804404688999, 0.10977297017234378, 0.1292479271069169, 0.11313612369121984, 0.06871828838484362, 0.12509651627624407, 0.09834738404606469, 0.08006566698895767, 0.09770046875928529, 0.11304206389468163, 0.16657952859532088, 0.10672896984033287, 0.15037955803563818, 0.11566919987672009, 0.15056856820592657, 0.1253748216549866, 0.13031342852627859, 0.11878369681653567, 0.1455801780684851, 0.13638225209433585, 0.18258155352668837, 0.11542692576767877, 0.23910501971840858, 0.12376298822346143, 0.11698950285790488, 0.2068470959784463, 0.20074524683877826, 0.12175173091236502, 0.20158121682470664, 0.11074564376031049, 0.10826899306266569, 0.06115339157986455, 0.1421467654290609, 0.12247534716152586, 0.1529957473394461, 0.1488083423464559, 0.2115765359485522, 0.17532940517412499, 0.1859677952597849, 0.19025564251933247, 0.14070656849071383, 0.10979653336107731, 0.0891653771395795, 0.17170408798847347, 0.1236802016501315, 0.13033961149631068, 0.16357880289433524, 0.11045816543628462, 0.11275408833171241, 0.10147152148419991, 0.15073142509208992, 0.19040145969484001, 0.17338061443297192, 0.16490565903950483, 0.09516360762063414, 0.1710345223546028, 0.168414325453341, 0.13769255834631622, 0.1690707847592421], [0.05971860860881861, 0.035186976529075764, 0.011285787768429145, 0.07248965281178243, 0.04940020291542169, 0.018051167025987525, 0.006695933716400759, 0.04957274482876528, 0.018232418042316567, 0.09956402383977547, 0.020874877518508583, 0.018463192573108245, 0.03727226678165607, 0.020547718413581606, 0.024756827515375335, 0.01686292922386201, 0.03529476234689355, 0.026246670422551688, 0.012448549496184569, 0.05747124072513543, 0.050551355598145165, 0.036638179517467506, 0.06469359184848145, 0.056048391488729976, 0.040057298392639495, 0.039206095825647935, 0.038621702769887634, 0.03382964408956468, 0.056728224735707045, 0.048582196614006534, 0.05177964339964092, 0.021723703357565682, 0.0600382404809352, 0.05767755035776645, 0.04598916231771, 0.02619699291244615, 0.030548746508429758, 0.027908619231311604, 0.03974389313952997, 0.008217719587264583, 0.025749149463081267, 0.04438020470843185, 0.04240343871060759, 0.0596509544266155, 0.08653286800836213, 0.033157191501231864, 0.030343392390932422, 0.11930960492463782, 0.05989609693642706, 0.053092213202035055, 0.06987035390920937, 0.031575155298924074, 0.10467923217220232, 0.02316133803105913, 0.04765286073961761, 0.028036038565915078, 0.06314342346740887, 0.08818540081847459, 0.020082132068637293, 0.009997067809308646, 0.05769768111349549, 0.029452304952428676, 0.02836759860656457, 0.008727679869480198, 0.07036545546725392, 0.020569530133798253, 0.06866112074931152, 0.040566934912931174, 0.035061891248915344, 0.030920508688723203, 0.04003044748969842, 0.0672859359474387, 0.070510048099095, 0.05187053422559984, 0.02125810773577541, 0.06680663471342996, 0.018760838320304174, 0.017096525771194138, 0.027933690835197922, 0.03303735691588372, 0.04492161257076077, 0.03457885701209307, 0.01997489915083861, 0.07153602273319848, 0.05696694766811561, 0.024385239739785902, 0.007686517183174146, 0.12407415590132587, 0.11676431298837997, 0.03432507590332534, 0.015914854120637756, 0.03830028974334709, 0.02607913800602546, 0.050221200071973726, 0.039669348116149195, 0.010235782392555848, 0.006453362284446484, 0.044405793960322626, 0.05165885515452828, 0.060756557795684785, 0.022202921099960804, 0.05374102096538991, 0.052225288236513734, 0.01222400993356132, 0.0323867271799827, 0.0329028649139218, 0.05124975366925355, 0.019836612918879837, 0.012971818341611652, 0.0046516230031556915, 0.03923537726223003, 0.06112947216024622, 0.05922220087086316, 0.07827799650840461, 0.026001008409366477, 0.07675985179957934, 0.01905970861116657, 0.026463733775017317, 0.006358180917231948, 0.08645928406622261, 0.047999814778449945, 0.0653868616791442, 0.0438726202264661, 0.04515223867201712, 0.03578323652618565, 0.0322677015356021, 0.014435014436458005, 0.024690386744623538, 0.06363718915963545, 0.034107199899153784, 0.029235454967420083, 0.04465012010768987, 0.02092351787723601, 0.053629839821951464, 0.071603409742238, 0.050236139504704624, 0.04112106318643782, 0.04992092712200247, 0.05418159322289284, 0.01333610338406288, 0.018222892576886807, 0.0223831423863885, 0.03129536191408988, 0.08277831322629936, 0.05172195626073517, 0.02482915537257213, 0.06691094356938265, 0.043576406824286096, 0.06677191704511642, 0.03776511221076362, 0.019364610707270913, 0.02338024747587042, 0.041934512701118365, 0.04009989024780225, 0.005344867786334362, 0.02841724272002466, 0.05313775880495086, 0.03680785303004086, 0.025036444640136324, 0.026960152645187918, 0.024122827453538775, 0.0703193606750574, 0.03465240013611037, 0.12526416743639857, 0.01177348362034536, 0.007097960678947857, 0.03839709548628889, 0.02267834646772826, 0.03812607428699266, 0.056497791592846625, 0.027900540953851305, 0.032117605878738686, 0.007316341343539534, 0.017852431010396685, 0.02246118849143386, 0.024621565535198897, 0.036229100296623074, 0.03949293961341027, 0.05733264464652166, 0.032514402555534616, 0.014441232706303708, 0.0019338704419169517, 0.04124592953303363, 0.042360023071523756, 0.027629530886770226, 0.02871568070986541, 0.06523499600007199, 0.019720856435014866, 0.012855856839451008, 0.047147328295977786, 0.06543473020428792, 0.034386611077934504, 0.02060688242636388, 0.010913660080404952, 0.02880061394535005, 0.0392754643689841, 0.016608036748948507, 0.013917450851295143, 0.06371874376782216, 0.04450428437849041, 0.03240256090066396, 0.01969049517356325, 0.03410766745219007, 0.030548291942977812, 0.08231456740759313, 0.07471776567399502, 0.021108924920554273, 0.021633406249748077, 0.051567441114457324, 0.031241214819601737, 0.04162908182479441, 0.042544483876554295, 0.04409861903695855, 0.007567023058072664, 0.07208157549030147, 0.02848780612112023, 0.026288705666956957, 0.06775682122679427, 0.031107299837458413, 0.06729805521899834, 0.13167581870220602, 0.025223488119081594, 0.012260556068213191, 0.061715724295936525, 0.04942329484038055, 0.0322256514482433, 0.07304684986593202, 0.036123099343967624, 0.07725550254690461, 0.026470491029613186, 0.04638594044081401, 0.022621614843956195, 0.012346595103736036, 0.0777480511169415, 0.024593608832219616, 0.09961599644157104, 0.019138194438710343, 0.012737962042592699, 0.035639215348055586, 0.10980606995872222, 0.03770317627640907, 0.026963611053361092, 0.012714938766293926, 0.09708851604955271, 0.04541058027825784, 0.035625121963676065, 0.04080098973645363, 0.0874834404385183, 0.09128267993219197, 0.10157313634408638, 0.05339644179912284, 0.03592995541112032, 0.07120413429220207, 0.0804119382519275, 0.01257849027751945, 0.0628088039229624, 0.02857334606233053, 0.02081209182506427, 0.036777057612198405, 0.02529261175368447, 0.06568180600879714, 0.05087280573206954, 0.017143518562079407, 0.04554178085527383, 0.14574468252249062, 0.01669133169343695, 0.07365811979980208, 0.02001320510316873, 0.016480576596222818, 0.049258727303822525, 0.01028183636663016, 0.023449476866517216, 0.02220471709733829, 0.05083270378236193, 0.04147739055042621, 0.04815272688574623, 0.07443897789926268, 0.00965012026426848, 0.07043811172479764, 0.03323922479467001, 0.016483374492963776, 0.055508890945930034, 0.049837012484204024, 0.07086337718646973, 0.05040610245487187, 0.00905773056729231, 0.052478375437203795, 0.023661063169129193, 0.02742172211583238, 0.03611082422139589, 0.018282262535649352, 0.08158310665749013, 0.05155867263965774, 0.025678628735477105, 0.0736981512454804, 0.024822227424010634, 0.02989871420140844, 0.05501629042555578, 0.0458930653257994, 0.10789034931804053, 0.08369528120965697, 0.03314717621833552, 0.03579082498617936, 0.07431909878505394, 0.006207918740983587, 0.02814939791278448, 0.0164986404706724, 0.0592673197388649, 0.014277322898124112, 0.05528056550247129, 0.0856887418194674, 0.03157076549541671, 0.03977960528573021, 0.01305546395087731, 0.012303095045353984, 0.01861228076450061, 0.017181305011035874, 0.03676027394249104, 0.021902327171119396, 0.057194427063222975, 0.049692776083247736, 0.04930338232952636, 0.03337751288199797, 0.03605953810620122, 0.039120474248193204, 0.018710220138018485, 0.02985242088470841, 0.050607335797394626, 0.026543473832134623, 0.033030673876055516, 0.04959607424098067, 0.044702534287353046, 0.07091345731168985, 0.03743001027032733, 0.01104820496038883, 0.05947949975961819, 0.0642725863144733, 0.034036751530948095, 0.02920195256592706, 0.07287562155397609, 0.01815253883250989, 0.027011375677830074, 0.03302722288935911, 0.027302882008370943, 0.0958295886812266, 0.01844832549977582, 0.008490343825542368, 0.010567578992777271, 0.025043871683010366, 0.040681555910850875, 0.07800255581969395, 0.023619250569026917, 0.14669896569103003, 0.15491793950786814, 0.15943313628667966, 0.18453708296874538, 0.1439448556629941, 0.14220915036275983, 0.15352550719399005, 0.09966667770640925, 0.10573153078439645, 0.2556134416954592, 0.1708346768282354, 0.10341884277295321, 0.09877296120976098, 0.18438847531797364, 0.1661718520335853, 0.15546107286354527, 0.09429132434888743, 0.07865525243687443, 0.0995867706660647, 0.08395230179303326, 0.11826063855551183, 0.06777289614547044, 0.16645035037072375, 0.17917476914590225, 0.15726000914582983, 0.19503090268699452, 0.1492293775663711, 0.10729698740760796, 0.1909903687192127, 0.1223026642401237, 0.11599914389080368, 0.12040170491673052, 0.14997317281085998, 0.1567863259697333, 0.12664834706811234, 0.12908631702885032, 0.11624535138253123, 0.12080009721103124, 0.17599485930986702, 0.08794639215921052, 0.07154990831622854, 0.11100306510343216, 0.12881357775768265, 0.20373157487483695, 0.36720021336805075, 0.17982379213208333, 0.10729970366810448, 0.1665674612740986, 0.16661154484609142, 0.07940569732454605, 0.18671332712983713, 0.13860646868124604, 0.2146680114674382, 0.06369529932271689, 0.12327550110057928, 0.1480286568403244, 0.13353486894629896, 0.18653982784599066, 0.11422862444305792, 0.23890526324976236, 0.17361893289489672, 0.18471108691301197, 0.10357859748182818, 0.1548453574650921, 0.16072776837972924, 0.09777956685866229, 0.14274251705501229, 0.23973142204340547, 0.16978348401607946, 0.08065750007517636, 0.16607385885436088, 0.22169597184984013, 0.29290312668308616, 0.16615366941550747, 0.15225156617816538, 0.12327450662269257, 0.0912007394072134, 0.17469114332925528, 0.17006520327413455, 0.1498121119220741, 0.09620750512112863, 0.11304173734970391, 0.2060989072197117, 0.13968670915346593, 0.208192476129625, 0.12605164549313486, 0.1163328877009917, 0.32854313612915576, 0.2377813251223415, 0.07324691803660244, 0.2157723272102885, 0.09122356044827029, 0.09079604627913795, 0.18615616718307137, 0.19054542150115594, 0.11375277419574559, 0.06694819938275032, 0.12338416636339389, 0.15684805781347677, 0.15177381603280082, 0.14397943974472582, 0.1301727321697399, 0.20489785994868726, 0.07046111830277368, 0.15353398252045736, 0.09969945094780996, 0.15751587197883055, 0.1351944892667234, 0.10951795338769443, 0.05353891559934709, 0.12205405961140059, 0.0854577706195414, 0.15219949709717184, 0.15721941366791725, 0.08293563369079493, 0.23445346072549, 0.12762105034198612, 0.16473993746330962, 0.16666137264110148, 0.125087239430286, 0.12289980368223041, 0.24216961464844644, 0.07104277654434554, 0.1896176626905799, 0.15539197891484946, 0.1369892101502046, 0.14904793730238453, 0.16235158749623224, 0.19301883643493056, 0.1320198635221459, 0.13680616684723645, 0.2279000444104895, 0.1033933277358301, 0.17590568284504116, 0.23575481667649, 0.12711598916212097, 0.1637487398693338, 0.11942198092583567, 0.09951801810530014, 0.15211701480438933, 0.10395560850156471, 0.12348558084340766, 0.09035302864504047, 0.16615827073110268, 0.1081331206660252, 0.16220404853811488, 0.14945409988285974, 0.13266513124108315, 0.1737789696198888, 0.11312448681565002, 0.16957128915237263, 0.11115568035165779, 0.13254837656859308, 0.0803189619909972, 0.12059794360538945, 0.13699819013709202, 0.19885122659616172, 0.10553230866207741, 0.11254178214585409, 0.15347115229815245, 0.1266800070879981, 0.1625536594656296, 0.2092004759470001, 0.19524769886629656, 0.08665221277624369, 0.08867722950526513, 0.12299436813918874, 0.1094859816657845, 0.1430146922939457, 0.11315182753605768, 0.15713685716036707, 0.0618349985597888, 0.06884086891659535, 0.11668878461932763, 0.1911299370112829, 0.11353128022165038], [0.04166992592217866, 0.0147238369754632, 0.016786842388683, 0.022182584398251493, 0.026607717845763545, 0.07079574526869692, 0.03266777850512881, 0.03319360868772492, 0.03902248106896877, 0.05373353269533254, 0.00799129960796563, 0.0720311985060107, 0.11045723775168881, 0.02179709990741685, 0.03015266229340341, 0.03309586412797216, 0.02881259220885113, 0.04545169525954407, 0.05014436552301049, 0.06546559612615965, 0.03472116753982846, 0.018557812691142317, 0.03705713301314972, 0.027919972235395107, 0.008509178605891066, 0.03827493797871284, 0.07090913801221177, 0.10420270657050423, 0.009587355907569872, 0.041207994654541835, 0.024787160946289077, 0.027349705960659776, 0.022338517046591733, 0.04137900403293315, 0.026454978287802078, 0.014026335975358961, 0.05495545658050105, 0.024278463242808357, 0.03988337608461734, 0.017545475020597223, 0.06272199490922503, 0.028510513984656427, 0.0355072614911478, 0.024935382680268958, 0.03843429563858081, 0.02724624686379684, 0.04165207355981693, 0.06964546089875512, 0.01576341332111042, 0.0453034920792561, 0.012639763845072594, 0.010926443574135192, 0.03548389868228696, 0.016114682948682457, 0.025485627666057553, 0.009468504667893285, 0.05675938009517267, 0.07654433211428113, 0.035364954674150795, 0.03113022292382084, 0.012966283775313059, 0.020651311097026337, 0.06183116165630054, 0.03362888943229336, 0.013862175692338496, 0.03706952316861134, 0.0040014510796027025, 0.015535696438746527, 0.006600715241802391, 0.0423857533314731, 0.017224076837010216, 0.03830821588053368, 0.09742017442476936, 0.02592831133370055, 0.0053304566699807765, 0.06301543267909437, 0.01939022222359199, 0.030898463191988412, 0.04675532960391138, 0.02776151628495427, 0.024251404538517818, 0.07374746695859358, 0.024213818469434045, 0.021112522481416818, 0.059947516638203524, 0.023546317861473653, 0.06207836362591479, 0.03456774335063528, 0.026404564196127467, 0.020289033564040437, 0.020168397459201515, 0.08251385632320307, 0.0713185066706501, 0.0347820422030054, 0.030477502186840866, 0.022433146441471763, 0.03943864780012518, 0.03295785063528456, 0.032913447939790785, 0.03164436428050976, 0.039075526074157096, 0.05015486691263504, 0.05783388747659046, 0.029447506967699155, 0.0440057429659646, 0.01594373294210527, 0.08105961795081384, 0.019707889259734657, 0.04894257610430941, 0.02802787123073358, 0.026138289031223394, 0.03259523356973659, 0.010856120443349937, 0.04226602635753807, 0.04361454579338897, 0.027318112734064925, 0.004020999249405577, 0.03342315125337336, 0.03143842943245545, 0.038085452833911404, 0.043997794564347714, 0.03677513916045427, 0.011198759821127169, 0.020540131808957085, 0.058202757136314176, 0.10419915910460986, 0.048966922258841805, 0.06585736104170792, 0.05662529256369453, 0.0888121742173098, 0.03558858603355475, 0.03392432729015127, 0.046175044335541315, 0.046215291004045866, 0.025354781464557163, 0.03748490693396889, 0.01395896659232676, 0.019080600068264175, 0.059015802180510946, 0.033462288411101326, 0.020643136340368073, 0.022820684826001525, 0.004527722840066417, 0.04093278774234932, 0.02079415226035053, 0.052735904391738586, 0.027922692206630018, 0.045454964420059696, 0.05111215577926487, 0.03417710649955552, 0.047916237817844376, 0.04310497235564981, 0.022240073012653738, 0.05978486755338963, 0.009542366915411549, 0.014927681750123156, 0.016575033441768028, 0.00927831077206065, 0.03030826283065835, 0.044923223031219095, 0.03761432635656092, 0.0473946712736506, 0.07558938101283275, 0.04500021714193281, 0.05200485924433451, 0.05228452275332529, 0.032151147242984734, 0.04479784089198802, 0.07297728094272316, 0.030929162130632903, 0.017797254186007194, 0.015261931148415897, 0.021279572501953226, 0.02087277352984529, 0.027716931763279717, 0.06285426788963377, 0.07904539204901084, 0.016718050865165424, 0.048457456432515755, 0.0422871553018922, 0.017184069511131383, 0.00784839165135054, 0.03543215985700954, 0.031763438164489344, 0.09450744517380372, 0.03755469850148074, 0.04984207764209714, 0.017285439462284558, 0.02889525261707604, 0.06644264838541858, 0.06073839002056047, 0.02386136882705614, 0.08185915590729564, 0.025387452660652343, 0.061242935407790355, 0.09246198227629066, 0.017137800314230844, 0.0290209928425611, 0.031207176216412336, 0.09849470035987906, 0.02904247616243083, 0.0015309433933907712, 0.030680396084790118, 0.06590409408090636, 0.04734557449410204, 0.04376221462734975, 0.03277608753705863, 0.07823042484233156, 0.0640195510641206, 0.014462968356383499, 0.0564404977922095, 0.05775975063443184, 0.07147029071347788, 0.009811471518332837, 0.027692394505720586, 0.002168147793781827, 0.06052128584997263, 0.042698557444964536, 0.059728709238697775, 0.023777639726176858, 0.009557219145790441, 0.04662360210204497, 0.041061702504521236, 0.07049970256048255, 0.016341026857844554, 0.0419059325940907, 0.04097211785847321, 0.005936413290328346, 0.08716160067706369, 0.03412057340028696, 0.031280047696782276, 0.01733809483994264, 0.04536691973044071, 0.030069183667364996, 0.021017479339207057, 0.01712220964691369, 0.01704752547084354, 0.00424816508711956, 0.06724770049913786, 0.011785349634010345, 0.05163984504179098, 0.032369004693464376, 0.023252319770108443, 0.017276782309636474, 0.013030386780883418, 0.0742771451768931, 0.006926319083504495, 0.022125654249975923, 0.026892554124060553, 0.07431099453242496, 0.06514494380098768, 0.015142470419959864, 0.013449132475216174, 0.03408689473872073, 0.03678247157949954, 0.024984711380966473, 0.0168902866425924, 0.05040652918978594, 0.051415768393781036, 0.027901524299522862, 0.034854353361879475, 0.06803375363233499, 0.033423166096326895, 0.015154984885157319, 0.05293528607580811, 0.02317421429324895, 0.04204633951303549, 0.04324323446780909, 0.019773600870394148, 0.02728622821450699, 0.02043250555288978, 0.04912979398795869, 0.011739248348021647, 0.04133182199439034, 0.026644853060133755, 0.005285584102239227, 0.018515200426918454, 0.06391783972503617, 0.01844043090386549, 0.07257345612742938, 0.015059654160722857, 0.014966360631660791, 0.08078953556832857, 0.02510672788048396, 0.039372540995827876, 0.019755267967411783, 0.05061650132120121, 0.06029402167769149, 0.06265060772420838, 0.16078705113613978, 0.03088516205025371, 0.05200117077038158, 0.007047902818158036, 0.07555206582765095, 0.023379952472168952, 0.011268245252722409, 0.030417278758250177, 0.037103543218108825, 0.024228388683695812, 0.021115904819453135, 0.0637732470931951, 0.04220890696160495, 0.032123836208484136, 0.0306247164553497, 0.04498625734413508, 0.06527731326059438, 0.04933616299240384, 0.05842890066560358, 0.06409883470041677, 0.06296160470810719, 0.026654768153093755, 0.049055916897486895, 0.01250042654646677, 0.034107786195818335, 0.06684669584501535, 0.01571348348079482, 0.05281985242618248, 0.03174284727720078, 0.015993427150533535, 0.05221300198172685, 0.06037352795829065, 0.029924887894594576, 0.05310649212333374, 0.04974226620106492, 0.0667853573395405, 0.04440647302544676, 0.05420989873528015, 0.02698663061892148, 0.03307453480374534, 0.03028186834853841, 0.05095512104162481, 0.014410068069992121, 0.03620358525949996, 0.0048499721742700785, 0.035068043653154746, 0.0683185453817714, 0.06201311029144563, 0.013314234147401294, 0.04624283581506461, 0.035609536862466484, 0.04133874252147507, 0.06809942628024146, 0.04819479181605857, 0.0572156895941589, 0.01691063447651686, 0.004723391930383514, 0.08660783234518021, 0.05802955842227675, 0.0050605561136762844, 0.05470540847454686, 0.002288748878527258, 0.059641551415552385, 0.15663780737668276, 0.1306194902281277, 0.17461428651586175, 0.12965346628334373, 0.054976715400698595, 0.07800519044394605, 0.18737190897809342, 0.15344649815233424, 0.28155144362244755, 0.1626982298330404, 0.13179373112507164, 0.09381001931615174, 0.2377879896084778, 0.15383716468932107, 0.12938612984726205, 0.1586278763716109, 0.19216889922972769, 0.2165235290885903, 0.2933978720102459, 0.1923594530671835, 0.0976975446974393, 0.12416631579981185, 0.06773409666493535, 0.12428051748429425, 0.1117952706408687, 0.07837038647267036, 0.18659747787751257, 0.13041667611105368, 0.20044485514517874, 0.12921016663312912, 0.10637620478519239, 0.13403124699834734, 0.12518420844571665, 0.08664993438287638, 0.0915964599698782, 0.15641740435967222, 0.22872170578921214, 0.11759301734855399, 0.15074071678100154, 0.06858874650788493, 0.24030869419220835, 0.2295543361105956, 0.18207285582320765, 0.11634358204901218, 0.13307484128745273, 0.08350129122845829, 0.16433514043455943, 0.31477979966439307, 0.11058251227950677, 0.15235842060064897, 0.11334123104461469, 0.07088550060871057, 0.17116889561293647, 0.10357697217841633, 0.1297080289805308, 0.09976237022783607, 0.10899833869189024, 0.1708852467709221, 0.09588260771124624, 0.08233623069827445, 0.11699592985678464, 0.12875061394879594, 0.15106404083780944, 0.14615721273003146, 0.0909081996360328, 0.12930869415868074, 0.13517874089302495, 0.10084320441819727, 0.10393433854915202, 0.17242837959202006, 0.164859987271484, 0.15332791779655963, 0.23700269346591085, 0.13396378577454016, 0.08933797842473723, 0.1263165328418836, 0.14838675793725997, 0.13149755483027548, 0.115555814554682, 0.1196378939494025, 0.1240147024509497, 0.1722152199363336, 0.25634787103626877, 0.11835236800834537, 0.10433466784888878, 0.17726272955769673, 0.2322159003233537, 0.16228709486313164, 0.197120271041058, 0.07049061125144362, 0.0992294488241896, 0.09265399072319269, 0.12429342343239114, 0.16812505113193765, 0.09380936622619629, 0.16781510057626292, 0.12540572468424216, 0.14275510387960821, 0.08497158967657015, 0.08420337035204284, 0.12832518521463498, 0.13868078734958544, 0.1976516784634441, 0.2295060668257065, 0.0959310402686242, 0.057066840745392255, 0.22133068676339462, 0.2875585947185755, 0.17564585694344714, 0.17884144093841314, 0.12125121909775771, 0.18553451460320503, 0.12295346838072874, 0.193426453624852, 0.1475610741181299, 0.11145722237415612, 0.08593890495831147, 0.1282851240830496, 0.11453000319306739, 0.13735666230786592, 0.10260274008032866, 0.08813129083137028, 0.17293627577601, 0.12421468898537569, 0.12080699918442406, 0.1983640660182573, 0.23051259719068184, 0.11665121710393578, 0.18708852730924264, 0.2734678820706904, 0.13215542421676219, 0.1470332290045917, 0.11607920678216033, 0.08925743313739076, 0.15874914330197498, 0.1838785011204891, 0.08524520468199626, 0.1070849112875294, 0.16736478020902723, 0.10881917682127096, 0.17066537810023874, 0.15786656644195318, 0.16668745171045884, 0.09438502791454084, 0.13244195259176195, 0.12036954765790142, 0.2029144109110348, 0.1582869337289594, 0.23854250146541744, 0.12766983913024887, 0.11807012182543986, 0.06753341251169331, 0.11255940815317445, 0.13568558322731405, 0.13910207489971071, 0.14518773037707433, 0.16637601685943082, 0.1457096531521529, 0.1170262169034686, 0.14345511241117492, 0.10460118792252615, 0.08376173311262392, 0.14751317590707913, 0.09111218634643592, 0.14818560623098165, 0.11357590556144714, 0.15763216651976109, 0.1928449809201993, 0.1564860381768085, 0.15569615556159988, 0.1380427333060652, 0.18846930790459737, 0.17242266505490988, 0.1319482908002101, 0.12723427265882492, 0.13582158921053633], [0.03954373220039997, 0.07294473034562543, 0.032497693100594915, 0.051633781695272774, 0.14763279526960105, 0.010628814525261987, 0.0055078763489291305, 0.03761175110412296, 0.022652263687632512, 0.08048777090152726, 0.046415826727752574, 0.0026599834382068366, 0.049291905015707016, 0.057523666037013754, 0.01244662362296367, 0.05144502756593283, 0.029592481805593707, 0.14524408907163888, 0.010841867497219937, 0.03133096644887701, 0.04050167786772363, 0.045311882058740593, 0.06460635238909163, 0.04729194690298755, 0.027179253193025943, 0.06672456802334636, 0.029961744803586043, 0.02447095037496183, 0.025726192980073392, 0.024306761333718896, 0.05504661829036195, 0.06923866749275476, 0.04366786168247927, 0.03738040883035865, 0.05632350563246291, 0.035844697486027144, 0.020095449908694718, 0.013009683643758763, 0.07584362596389838, 0.04204333381494507, 0.021900653628108557, 0.035041589799220674, 0.028677218906523194, 0.08658367543830536, 0.05292693320370745, 0.02122704143403098, 0.04507967889367137, 0.01896257632324705, 0.08228977225371636, 0.025844094270723872, 0.06276895801420324, 0.049373715664842166, 0.02477121404808713, 0.026464694856258575, 0.02965454761579167, 0.02460568543028785, 0.04806599208677653, 0.034605971377459355, 0.052433872551773675, 0.020496959223237354, 0.027746226187446155, 0.014590077844331972, 0.07974946012836881, 0.01228462484505144, 0.05026407765399199, 0.034070730762323365, 0.01308329263338237, 0.038270306977210566, 0.027998727091471665, 0.00990905280559673, 0.014906550950399833, 0.059459925614646636, 0.01792164741345914, 0.020815173593291547, 0.046061306493356824, 0.04523957832134329, 0.055915075790835544, 0.07128199300495908, 0.06661966544925235, 0.04331745294621214, 0.013501837020157836, 0.02443048477289267, 0.03512505172693636, 0.06212384985701647, 0.016811913992569316, 0.03475699842965696, 0.03179366955009755, 0.006981797869229922, 0.07144831572077237, 0.03455977639532648, 0.05485211993800476, 0.0039434364680346334, 0.08382116429856978, 0.058769728275365196, 0.04785368961165659, 0.03979612549301237, 0.06166600411233958, 0.057300049520563334, 0.06106566601374652, 0.046680446903337725, 0.06917703954968601, 0.027178386735613458, 0.06680178848910145, 0.02609893479530001, 0.01596556878212141, 0.04419827462697867, 0.006049003122825525, 0.04998441043426283, 0.0029944786729174666, 0.06662780680926517, 0.05728357755288016, 0.05266666201350745, 0.02077506793284556, 0.05300562683260068, 0.06782807482522912, 0.018462676780472975, 0.05580931974691339, 0.04328954448283184, 0.02719354881264735, 0.03247195541916881, 0.02936784854682628, 0.07343452554778196, 0.028985265853407327, 0.03079682050156407, 0.0363246814958984, 0.02313852255610982, 0.04877565224887803, 0.02729895419179229, 0.020000659096695017, 0.008187080948118819, 0.025326171671622433, 0.06561069341842085, 0.01092371061531594, 0.08836250694002956, 0.033935559695237316, 0.01858084709965624, 0.040978110700962134, 0.022451453369285446, 0.03353013555170037, 0.030787964824412484, 0.07130022015189752, 0.02207376699516317, 0.014466047341556987, 0.02183259312005248, 0.013503611680789618, 0.07091497871442698, 0.014097042239882285, 0.05856655792740639, 0.03468830152996816, 0.014971153050282737, 0.023734062669973355, 0.017308752176177222, 0.024901388605940156, 0.03214851632947102, 0.006988575532886898, 0.04379198588139843, 0.04658316247514449, 0.06213024345925078, 0.06207138743775431, 0.03449387368164025, 0.05630315594316926, 0.026171468598477077, 0.062034762449911796, 0.03663431292807218, 0.02438410054310225, 0.042616308928700164, 0.05597256626060698, 0.08579984132666141, 0.02740083436947316, 0.026916542192338966, 0.008710043657629285, 0.04968539913534187, 0.04472092099604197, 0.02454440444125794, 0.028325834246061277, 0.0352779749664478, 0.05965841672150418, 0.026582111895550042, 0.023934041782922577, 0.026436183397891, 0.05200595762289595, 0.027940060317632742, 0.005394033214543015, 0.03249059445806779, 0.046802608121652156, 0.029189334200054873, 0.11879931902512908, 0.03285456223238725, 0.021556067040364724, 0.04045912311994471, 0.0033057834161809296, 0.01575107511598617, 0.029735647658526432, 0.09182844049064443, 0.029489406770153437, 0.05250664755294565, 0.01621310100745177, 0.01961029312951723, 0.015759643210913055, 0.029881954651500564, 0.05553765658987686, 0.03360188638907857, 0.02394710358203156, 0.021383762614277657, 0.02904836324887583, 0.09658235649112612, 0.025840359412541147, 0.01590533422131557, 0.06225133969564922, 0.04075555545568932, 0.07497004393371753, 0.01954812898475211, 0.0375110193999717, 0.05092421059089247, 0.013007197449041996, 0.05504888926225249, 0.04467418053536676, 0.035875340763595887, 0.00679071803460829, 0.0442072100850055, 0.05019828626245726, 0.0647434196434915, 0.03061156745388871, 0.05599006610282231, 0.07803989326930605, 0.019709887492354028, 0.0421978972008219, 0.02711505556362681, 0.04935857585223857, 0.03981009642302524, 0.03655119609902613, 0.08869402430718765, 0.014815173090028111, 0.026936177564493846, 0.0611000868229894, 0.03587550774682313, 0.01725801710563246, 0.008839321144478163, 0.04694943090726156, 0.029201869074313436, 0.009183447600662475, 0.014404668945644516, 0.017391755827702582, 0.03977897074946668, 0.039509203779743984, 0.022345773395500146, 0.0148938546590216, 0.05530106362130027, 0.012161647264292696, 0.010492300170881208, 0.03977747903263662, 0.09643219033023342, 0.007094481397871277, 0.01255412742466433, 0.03158974963298533, 0.014390945707418723, 0.025318714942841325, 0.08477433424559422, 0.05858851807715837, 0.09927353981765918, 0.027776581882790197, 0.010009183370129904, 0.09052841298398562, 0.023421946898452006, 0.08037554332986474, 0.03660088659671601, 0.05644210454192944, 0.0323940521775512, 0.04749243067635689, 0.020128494033997413, 0.02691717858397169, 0.016190007227123715, 0.062028001484577544, 0.027162027945450973, 0.0464316010766197, 0.09225565037922934, 0.044276059124968015, 0.039540073412354104, 0.04571792218484916, 0.12115700345020741, 0.04507409052166622, 0.026576410346024204, 0.004779503397003282, 0.018459966086084023, 0.022878307026985567, 0.015591398332617246, 0.04150500215473585, 0.08358853810932487, 0.018045810575131327, 0.07561805017758161, 0.0604913030838361, 0.04794352287717629, 0.016995421137835365, 0.032281338499160483, 0.06400369878974743, 0.07211892036139034, 0.0612332095624879, 0.040586776231066324, 0.06111951624916401, 0.06085210930905305, 0.05668674610205926, 0.0747942365705967, 0.035586860540206544, 0.05205622699577361, 0.012964410780114122, 0.039467706592404284, 0.037036364010418765, 0.05527388988411985, 0.01319391902143252, 0.08219543044106103, 0.020682067552115768, 0.04756766960781533, 0.014605854976252886, 0.026050615415442735, 0.0689232769946102, 0.05576043447945267, 0.02460015457472764, 0.04552444428554736, 0.06397988327080384, 0.042532008374109864, 0.049786887830123305, 0.03258006036048755, 0.029948369447083678, 0.05248760775430128, 0.03222441577236168, 0.027916070393985137, 0.014271359741542256, 0.04487377002078574, 0.05652981526509393, 0.05873840222193394, 0.0688713786075823, 0.013285380373417865, 0.0019675311295941356, 0.0296463969789329, 0.0371417267160723, 0.02818440130795352, 0.03054492815863341, 0.03200043931428809, 0.11125296106911264, 0.028116249886807054, 0.11220466898521408, 0.04939047707011923, 0.04672617433243431, 0.048326782780350186, 0.03859338612528518, 0.00990279371762881, 0.0324628158705309, 0.048115571262314916, 0.10040838751592673, 0.030878306461090688, 0.06247664088732563, 0.024639083931106143, 0.13642384205013514, 0.11349360138410702, 0.25489139137789607, 0.18966104864375666, 0.18352427403442562, 0.10245531986583956, 0.07867833322961815, 0.16086407122202218, 0.2142595185432583, 0.11557842037291266, 0.14084465248743072, 0.11568584624910727, 0.07809934671968222, 0.10334663922549225, 0.057704939317773096, 0.09066350612556562, 0.12291734805330634, 0.31548160419333726, 0.16890363825950772, 0.14860267838230357, 0.10463372367667034, 0.16169051203178242, 0.10970730494591407, 0.0931260189099703, 0.10954441837384365, 0.15484437783015892, 0.09885683874017559, 0.11007382941897959, 0.0911438166804146, 0.2192913688486442, 0.14215399394743145, 0.195355607138481, 0.2300393147743307, 0.1352638949174434, 0.20212486968375742, 0.12690795032540336, 0.10398735757917166, 0.30889352958183736, 0.13662904588272795, 0.1338194528943859, 0.15171779872616753, 0.1826767562306486, 0.09843945488682948, 0.09706570242997259, 0.22167259419802576, 0.14266070269513875, 0.1116944795649033, 0.11446355129010044, 0.14659956243121997, 0.08392657895456068, 0.2168426229036413, 0.10425261600175872, 0.13671620370587334, 0.07315494367503561, 0.08563234601751901, 0.08376181474886835, 0.11520500876940787, 0.09651591200963594, 0.13087244384223595, 0.20138788735494018, 0.17019540566252545, 0.06604901325772516, 0.10731954127550125, 0.12687433103565127, 0.11790838558226824, 0.06694570576655678, 0.0689282568055205, 0.11303733641398139, 0.22436547704273835, 0.09010966357891448, 0.09013528251671232, 0.18533751892391592, 0.08884649112587795, 0.10818711933097802, 0.08587078322307207, 0.16992719349218532, 0.09126386648858897, 0.12726658576866612, 0.10550237784627825, 0.08738155098399147, 0.11553582109627314, 0.2094755752477795, 0.11555606688489206, 0.14735575154190883, 0.104158096073661, 0.07279412631760351, 0.11991593215498142, 0.11540370396687649, 0.16284084093058482, 0.13713082676986232, 0.16578887414652854, 0.12883150804555044, 0.12075279271812178, 0.10472909707459621, 0.12602206348674372, 0.11209244883502834, 0.16104708483908325, 0.17390547611285, 0.1887768687447533, 0.10781918477732688, 0.14521550154313445, 0.09151429680059664, 0.1254998883814551, 0.16975725651718676, 0.08507746446412057, 0.2599323552567512, 0.0895784936437849, 0.12479756434913725, 0.1384542096639052, 0.1802105104434304, 0.14548690494848415, 0.14811192580964416, 0.09774904232472181, 0.13147681922418997, 0.12005640586721711, 0.1257535396143794, 0.12198632379295304, 0.1418183057103306, 0.13300270453328267, 0.17060599144315347, 0.07743049354758114, 0.09386810721480288, 0.10987307105096988, 0.14450468734139577, 0.14687978255096823, 0.2029998172656633, 0.17375847150105983, 0.14341279515065253, 0.10153216979233548, 0.12248843864654191, 0.1296271348837763, 0.19086657848674804, 0.06626000584219582, 0.19370161229744554, 0.0995768555731047, 0.08337324848980643, 0.15180795482592657, 0.22969906975049525, 0.11363037177943625, 0.17191990453284234, 0.10303087765350938, 0.10311819132766686, 0.191036916221492, 0.13732782244915143, 0.08760893761063926, 0.24605501006590202, 0.11979609014815651, 0.18334310094360262, 0.1022208457288798, 0.07549880188889802, 0.12509743653936312, 0.17524275201139972, 0.08599573862738907, 0.19800914131337777, 0.1319011050509289, 0.20333342748926952, 0.10686391455237754, 0.23325857328018174, 0.13821348664350808, 0.16639992885757238, 0.20054442167747766, 0.07552803508588113, 0.15445163327967748, 0.13444708718452603, 0.2762686583446339, 0.11047692692955025, 0.21777974761789665, 0.13903615734307095, 0.07875995463109575, 0.08814657165203243, 0.12752718350384384, 0.18084078677929938, 0.14961596229113638, 0.07982810551766306, 0.12967592367203906, 0.12322067865170538], [0.04537697212072089, 0.030154411906551104, 0.0258979352292954, 0.06485592180979438, 0.03766128204006236, 0.06815559943788685, 0.0456451657373691, 0.025236698347725905, 0.07775790683808737, 0.046591808495577425, 0.026209236493741628, 0.02041765517788008, 0.06515617249533534, 0.1122686718008481, 0.022686960946884938, 0.033952495505218394, 0.010078633549710503, 0.03746197828149889, 0.07086249403073452, 0.09380652380059473, 0.016853331399033777, 0.004333108990977053, 0.028846614113717806, 0.015425775090989191, 0.050791978428605944, 0.029540117720898706, 0.03969410616264213, 0.02343228130484931, 0.015683035016991198, 0.028648243605857715, 0.019497149005474057, 0.030549457114830147, 0.05022418721637223, 0.04307535695261322, 0.012249415503902128, 0.013534963709389558, 0.043082488991785794, 0.004389239938973333, 0.034690813699853607, 0.04739313502795994, 0.009652606458985247, 0.050531607048469596, 0.03479792045254726, 0.011500655291456496, 0.12950362666742876, 0.07529819195042364, 0.05141569417901337, 0.020360571033961605, 0.06511237836093642, 0.09784353256691247, 0.05290486544254236, 0.018363616763963364, 0.026860966463573277, 0.04382367929792963, 0.009901059875119245, 0.02203589705459308, 0.09639285650337115, 0.019106684703729115, 0.010759610631794203, 0.03521730439388193, 0.011542349147930508, 0.0253013468318386, 0.017217134045495186, 0.022107165495981462, 0.013443098814605037, 0.0188389363756869, 0.029295142194314394, 0.05411265141447075, 0.03088376124651404, 0.02060370232356945, 0.060799891798524186, 0.03693072299938649, 0.03635424123785924, 0.036716695030918345, 0.029193662776378915, 0.06519188464153558, 0.026173047517659143, 0.05035724687331822, 0.07588423628476448, 0.06423196857213043, 0.077712220227113, 0.015635591371392366, 0.016352472630387638, 0.006873452193758567, 0.04132249690883327, 0.0528649972693529, 0.08565843992982991, 0.017332070456177462, 0.02386971056694165, 0.023823871815693565, 0.024427360331173986, 0.0684199747047387, 0.03760850420803763, 0.027704189087671693, 0.028128985140938312, 0.0827918499999214, 0.04305233924242202, 0.025897068771882914, 0.014042458205949515, 0.04313223886128981, 0.04507878089498263, 0.06997285934630781, 0.04854858103499282, 0.048498367323190905, 0.0494058655021945, 0.018714205471042078, 0.039222745908773504, 0.018525944869907107, 0.013161494589439826, 0.06190777727169916, 0.06114753974543419, 0.057682871556608006, 0.0028294820822338806, 0.06418323173420504, 0.04287230534828268, 0.003978639315391774, 0.04676075841416605, 0.02891790481953649, 0.04802173782081809, 0.018679487802728545, 0.026457863386895042, 0.08378317375900224, 0.019970808061771095, 0.05459213818539865, 0.029533698143495712, 0.05212312418734655, 0.024884287668101024, 0.019365968837519176, 0.025769033454707824, 0.09187164090690203, 0.04120956058613956, 0.05519307371287141, 0.02419366173853632, 0.03858785341435578, 0.06902474342496134, 0.02465644276526291, 0.008274152496596798, 0.11691326944855973, 0.008108538531814702, 0.09181621731841005, 0.017040658749465365, 0.043734380378737114, 0.06999445584369823, 0.07908605432021432, 0.09066772894584574, 0.08185168248019181, 0.03450352160143666, 0.04585176851833239, 0.036191358376527205, 0.02059088357782457, 0.03911785446689464, 0.025421745449420996, 0.0504107000597287, 0.013405541503743734, 0.012786792576662265, 0.023498189584643114, 0.08875706233084202, 0.0389835442911135, 0.08971539762569591, 0.027553946856642142, 0.041596954251872376, 0.1025751989800483, 0.06399912716005929, 0.08105946209980175, 0.03665179050585721, 0.020848323474638164, 0.10609914621454664, 0.0445126966224052, 0.043492941185832024, 0.023416399344569072, 0.06214377652213443, 0.12561726645799354, 0.040985914383782074, 0.011991831815976184, 0.05464460431539919, 0.04255143037880771, 0.05018963653128594, 0.11780245884438045, 0.038127514053485356, 0.03675603627925739, 0.032965617210720666, 0.03847981155558955, 0.05269834800856188, 0.16316092922352254, 0.033844164208858274, 0.02518561446777312, 0.02531322490540333, 0.056859770411392674, 0.06002678914228454, 0.06429677290725522, 0.016745538159739226, 0.03723309622728266, 0.029486948405974545, 0.02149751344404649, 0.03408675373066217, 0.014156585675664246, 0.02886818092520116, 0.02761421666946262, 0.01059573329257546, 0.03717738320119679, 0.0572076335811289, 0.0455806953686988, 0.06307216244749725, 0.027637226958177052, 0.02840620327333454, 0.04431399400345981, 0.029773178066534456, 0.05160538712516427, 0.05300938952132128, 0.015786531221237965, 0.037024623234174214, 0.015002678555902094, 0.0016965836812232737, 0.01919080899824621, 0.05822957835334819, 0.014980849209678126, 0.09099468210479245, 0.013359195309021743, 0.06496357775176875, 0.011071744957007468, 0.084441740764305, 0.05765178670117166, 0.10866953016375192, 0.0110489860708185, 0.05546631393372081, 0.01322192953011836, 0.008260539652837906, 0.05224653592449613, 0.05687159653462004, 0.010912442030530656, 0.03241867292672396, 0.06991203292272985, 0.035479033904266544, 0.018910813378170133, 0.0512876106222393, 0.06608216499444097, 0.008347671500814613, 0.0329667378537124, 0.02982186480949167, 0.05926150130107999, 0.04720292257843539, 0.0060880071578139905, 0.03909794264473021, 0.07914007524959743, 0.057842589158099145, 0.03316065362014342, 0.03501501720165834, 0.04524800540821161, 0.018173912685597315, 0.069271678221412, 0.02725292433751747, 0.06234059779671952, 0.02005759295570897, 0.05204103894357104, 0.07507897636969574, 0.053485636817640625, 0.00856112801557174, 0.01602742308023153, 0.021101423662912566, 0.011581911185203353, 0.03068329046072904, 0.05591603316133842, 0.0826614917605184, 0.042267091339454055, 0.04187902231933549, 0.0703327712835744, 0.034759610789478756, 0.040985331797855906, 0.021496854787983466, 0.03564946811820846, 0.07105150420102291, 0.05273510658298619, 0.10154321294976398, 0.032086895807879046, 0.036350975788081996, 0.056946943077491596, 0.04078455858689267, 0.024650644736539107, 0.06305709684966132, 0.07998134416993707, 0.03995511207904201, 0.04901527689071372, 0.032331155161955394, 0.01847553634434007, 0.04561491579806898, 0.016882015406736173, 0.011324045481160283, 0.0032138890674104914, 0.06953007919946685, 0.05812022660393268, 0.030452126302407123, 0.05300678087223787, 0.033781185557018034, 0.05566916886891704, 0.049011469673132524, 0.009860271438810742, 0.05569954126258381, 0.014160217560856836, 0.03593297595216427, 0.05059360606537666, 0.054462911721202545, 0.07812036434188485, 0.01986538598430343, 0.01363695613690652, 0.023283844348043203, 0.056163320477935486, 0.04088652967766393, 0.052188945264788345, 0.030945968064770568, 0.08142519247485325, 0.030016747223271523, 0.028834780569013674, 0.06739705029758625, 0.03414146114664618, 0.06237662906642072, 0.02066116125206463, 0.061173874855739996, 0.015519033368036617, 0.04618646598828491, 0.06691006041364744, 0.03601523560064379, 0.11244008564972319, 0.015490786299778847, 0.015886734145169612, 0.040069254391710274, 0.04409576918988023, 0.04797597328433767, 0.017880992563732434, 0.03648868128948379, 0.018871175270760432, 0.04356656223535538, 0.01543727281386964, 0.03302568293293007, 0.019148180035699625, 0.09008979628561065, 0.05931888415943831, 0.023834807361708954, 0.08874563325662166, 0.003611277143136249, 0.04914452561934013, 0.045080591735313646, 0.018596769878058694, 0.03472788768704049, 0.06392220355337486, 0.09746968309627846, 0.04100441241462249, 0.04018590887426399, 0.08413593881414272, 0.048904941795626655, 0.01297016335229273, 0.03610927684349008, 0.011416004072088981, 0.20715664577437565, 0.20432165649253875, 0.12406870853737928, 0.1289445668226108, 0.16314448323100805, 0.17624870350118726, 0.21029342198744416, 0.2653213863959536, 0.16784107574494556, 0.1655787424533628, 0.15680361801059917, 0.1065861435199622, 0.17004393332172185, 0.24384008516790345, 0.12290978556848131, 0.11473894002847373, 0.13038406614214182, 0.18841516081010923, 0.1563252296182327, 0.11471107980469242, 0.15328629815485328, 0.07792072661686689, 0.12187893502414227, 0.16896292101591825, 0.24430040968582034, 0.11761697387555614, 0.13492517871782184, 0.31133282056543976, 0.09545795081066899, 0.13159893220290542, 0.11752862119465135, 0.19105511368252337, 0.178264495334588, 0.13298112287884578, 0.09039107855642214, 0.12217904470162466, 0.06057800077542197, 0.09544981687213294, 0.11955331137869507, 0.12755367817590013, 0.21862515772227198, 0.10048459866084158, 0.1267645080224611, 0.06891549186548218, 0.23565835232147947, 0.1723521907115355, 0.19014261342817917, 0.10604144423268735, 0.1583380825468339, 0.168325089616701, 0.1678535289829597, 0.12171989277703688, 0.18883079319493845, 0.09933029927196912, 0.08467736523016356, 0.13444138749036938, 0.14767404383746907, 0.12177406955743209, 0.15013169555459172, 0.17363579449011013, 0.17491176899056882, 0.11013852243195288, 0.1701569920987822, 0.09818127655307762, 0.14280223025707528, 0.12928221432957798, 0.1357914283289574, 0.15995724097592756, 0.16677005274686962, 0.06860534092993475, 0.17801989830331877, 0.16065955016529188, 0.10174459472182207, 0.25979330646805465, 0.11646607352304272, 0.17543112393468618, 0.08714456096640788, 0.17153161286842078, 0.1617743747192435, 0.20021373551571742, 0.19258073181845248, 0.11640192227787338, 0.06360215236782096, 0.09324666985776275, 0.08372263677301817, 0.26105314667802304, 0.20435303449630737, 0.12369957912596874, 0.11771640682127327, 0.08902901492547244, 0.09985387703636661, 0.15674457274144515, 0.11262952626566403, 0.18320614501135424, 0.17091059853555635, 0.15774445346323773, 0.12827123107854277, 0.16770793445175514, 0.11224786197999492, 0.11237693630391732, 0.09152345490292646, 0.10607709700707346, 0.17583623266546056, 0.1703057630220428, 0.17649445828283206, 0.13859821599908173, 0.0914663466392085, 0.1074480738316197, 0.1574063755106181, 0.12061068628099747, 0.10733108167187311, 0.14579626178601757, 0.2029708883492276, 0.17424288613256067, 0.18623197014676407, 0.1069804688449949, 0.11439516980317421, 0.15414776833495125, 0.14851399173494428, 0.12323118004132994, 0.09998361187172122, 0.22511614457471296, 0.09751970384968445, 0.2536290278658271, 0.25401268852874637, 0.22323953511659056, 0.13481203088304028, 0.13909916568081826, 0.17722194112138823, 0.16098944965051487, 0.10250839826767333, 0.16992233984638005, 0.15139953611651435, 0.14805586397415027, 0.17613971169339493, 0.10192961955908686, 0.10171697940677404, 0.251709982403554, 0.10894563878537156, 0.1279156978125684, 0.14008246682351455, 0.11969687984674238, 0.20720976870507002, 0.181895898131188, 0.28529685514513403, 0.2952847082633525, 0.15331341623095796, 0.16498238226631656, 0.10324418573873118, 0.12204264538013376, 0.08625393180409446, 0.08338200583239086, 0.09497936945990659, 0.04988617976778187, 0.12994317105039954, 0.1198124025540892, 0.1808475106372498, 0.16548086801776662, 0.29161903308704495, 0.18502783554140478, 0.13738890120293945, 0.28783292218577117, 0.12425823078956455, 0.1684396030032076, 0.12005573793430813, 0.17094023991376162, 0.17923353239893913, 0.1168995100306347, 0.18313121778191999, 0.08152818772941828, 0.16172396804904565, 0.23836587031837553, 0.10686108696972951, 0.09796917816856876, 0.11668301071040332, 0.16337876440957189], [0.0612791559251491, 0.08702211402123794, 0.024974464176921174, 0.04843030124902725, 0.054206187996896915, 0.04904052104393486, 0.00724892835933133, 0.07292147885891609, 0.021831140365975443, 0.03400883935682941, 0.040402419326710515, 0.059158639633096755, 0.04335655670729466, 0.02888765673560556, 0.05809797701658681, 0.0338723101594951, 0.02909498867666116, 0.027444572842796333, 0.0033615581332924194, 0.038808839017292485, 0.013397225739026908, 0.04941458202665672, 0.07437853739247657, 0.04044426903419662, 0.031796248513273895, 0.06271542690228671, 0.08420395664870739, 0.0028460799831009354, 0.051670792599907145, 0.027311915800964925, 0.04654973243304994, 0.015319647973228712, 0.008796394395176321, 0.036174029228277504, 0.016758308665885124, 0.004452187049537315, 0.012830580217269016, 0.027289593854220584, 0.05655908928019926, 0.04365750130091328, 0.007059536910674069, 0.044768299703719094, 0.03326964542793576, 0.043255969721940346, 0.02053685522696469, 0.005591000599451945, 0.07311273773666471, 0.05717627784179058, 0.03415186976781115, 0.0041307999981654575, 0.02524291012377944, 0.07947129575768486, 0.022088955047365744, 0.0830393710930366, 0.08893917794921435, 0.15504175942623988, 0.059150468587176874, 0.06633211291045882, 0.06329030191409402, 0.06921899315784685, 0.08165292048943229, 0.028701362825813703, 0.044881736976094544, 0.09091970292502083, 0.013475794130499708, 0.03884158257278614, 0.016377959836972877, 0.07086409706971608, 0.039621516698389314, 0.05708290082111489, 0.05281034180370625, 0.028076897506252863, 0.03555415780283511, 0.038736576098017395, 0.015226924042508472, 0.022042893651814666, 0.03334193803311791, 0.03194887860445306, 0.017982750287046656, 0.033399513849872164, 0.0174077973497333, 0.015229955715767574, 0.020828895903832745, 0.03848093590931967, 0.04758324728754815, 0.025750652312126476, 0.003812598615695606, 0.05846916959853843, 0.02243945284135407, 0.035580470648710616, 0.014107097413216252, 0.04902430882793851, 0.10218889627140015, 0.04803943433216773, 0.03174184908857569, 0.0374410608492326, 0.09284302315791138, 0.10918969404883683, 0.04007815274235327, 0.008107282446871977, 0.02798950776195852, 0.04357161626103334, 0.047100391166168265, 0.021438418079924304, 0.010042418598459335, 0.06130411806225311, 0.05006924162444193, 0.07098270711139776, 0.0243803489865968, 0.010065230362670263, 0.031806208135094494, 0.01132973868152476, 0.05304715370584745, 0.06888075193273835, 0.027703341183951125, 0.020895652087347116, 0.02988515145261772, 0.023582538378832396, 0.030419597969739698, 0.018859725787478965, 0.019935895579692442, 0.020538092758215498, 0.006597037436222308, 0.030238235631259158, 0.02582256271125516, 0.040696955475141294, 0.13408057013293728, 0.05686832366336603, 0.027921460241486784, 0.008581838574173162, 0.11054855160182342, 0.04570524259179365, 0.041817906458163634, 0.053777775829075836, 0.0346253711177269, 0.020207406596455257, 0.05042140925070271, 0.055247899872483686, 0.047246419853763655, 0.06478667201008648, 0.03458647144725546, 0.030225481823435985, 0.05855745548615232, 0.03148984171275515, 0.026630694737832528, 0.07995563617441803, 0.03796761833655182, 0.020000883596367203, 0.03631361236330122, 0.020776947421836667, 0.08189281972590834, 0.060318620162433945, 0.04242978124239016, 0.04118255754292477, 0.07094636413967237, 0.014043373830645578, 0.05119365843711421, 0.026802457396115642, 0.020156706777925137, 0.02373359882767545, 0.03651026665465906, 0.06062504180590622, 0.046280677925096825, 0.028434037521947175, 0.05457916915474925, 0.008808921847958118, 0.05299847252899781, 0.04783280557603575, 0.015149199844017858, 0.03375388936547097, 0.022832861614006106, 0.05614209505438339, 0.022330624306050595, 0.03579898118914571, 0.031145106695475988, 0.031099013758648653, 0.0986331480089575, 0.11362676494172774, 0.0668238451180514, 0.03302844372228719, 0.057855624982039444, 0.08064946261583827, 0.05098000154248439, 0.1432250763173215, 0.05823801286169328, 0.009618209769541863, 0.04330175281211268, 0.03345486693433486, 0.05640268907882273, 0.07513467455282807, 0.02136777860869188, 0.023168518309830688, 0.07389415986835957, 0.05758419931225944, 0.005308667678036727, 0.02283801768498961, 0.06567608405021019, 0.034388677959213965, 0.08408381778281182, 0.047995465793064795, 0.06809666549088433, 0.05995263003569562, 0.09075795926037244, 0.008590997604187578, 0.05430391771369614, 0.02557302483182866, 0.025295969971921295, 0.035143356799380854, 0.01056229211826576, 0.08696954027982429, 0.006301177945715608, 0.05476378952153027, 0.028447140139178373, 0.06780482333851978, 0.09184116832329892, 0.01644004791160114, 0.041625000012572855, 0.0797718804096803, 0.02634464133734582, 0.030292469928099308, 0.03563225029211026, 0.03503688087221235, 0.04043373053718824, 0.02177560545533197, 0.031598258356098086, 0.03329384315293282, 0.016281144817185123, 0.12194162423838861, 0.03952541228500195, 0.03240624566387851, 0.05594610498519614, 0.048569747086730786, 0.11724846786819398, 0.014302647759905085, 0.03528230910887942, 0.07914886227808893, 0.030497653351631016, 0.08077225837041624, 0.012822445351048373, 0.06561590329511091, 0.002421884605610103, 0.028309590488788672, 0.02524516254197806, 0.019499145382724237, 0.02970129920868203, 0.0909429692546837, 0.057477741938782856, 0.01708382576907752, 0.04864397669734899, 0.05067124584456906, 0.07317895215237513, 0.07732702331850305, 0.12009945043246262, 0.025731311943673063, 0.045681093106395565, 0.09716589978779666, 0.013546109839808196, 0.08422765342402272, 0.022661076691292692, 0.05339273848221637, 0.07711500657023862, 0.029144109576009214, 0.03061795734538464, 0.02480484818079276, 0.029033368155069184, 0.10275925902533345, 0.02080892285448499, 0.08703454499482177, 0.007045813208605978, 0.038676695912727155, 0.05593397458142135, 0.053804248236701824, 0.025270078294852283, 0.031068748976395, 0.01065773602022091, 0.07983579416759312, 0.0723744640708901, 0.07110577003913932, 0.029180513774917927, 0.0035736899144467316, 0.029595840023830533, 0.04678497098211665, 0.011742451642930973, 0.09763762369402684, 0.01945139745657798, 0.07437054446199909, 0.031676844373578206, 0.04346932233602274, 0.04779354596394114, 0.014004535387357464, 0.017499699351901654, 0.021932137387921102, 0.05612889966869261, 0.03756173777219374, 0.07807517496985383, 0.1063048250216525, 0.01774693842889974, 0.01211963799505611, 0.008199764251912711, 0.06751971246558242, 0.048305653835996054, 0.03890616055286955, 0.057033366174437106, 0.02151529901311733, 0.0029574898007922457, 0.002564788155723363, 0.08052586534176953, 0.008595218569098506, 0.026094005079357885, 0.016214874740398955, 0.07274319272255525, 0.02265202063426841, 0.03970108606154099, 0.047808674644329585, 0.011736203687178204, 0.05674496016581543, 0.02011751024838304, 0.0067019311973126605, 0.024304163816850632, 0.03770711708057206, 0.05318284427630715, 0.08724719999008812, 0.051485033036442474, 0.035369478064239956, 0.035942679533036426, 0.019695667942869477, 0.08767420949880034, 0.03129276810796, 0.0229174070773297, 0.03470871059107594, 0.0037855461732760887, 0.05731417259084992, 0.06529974838485941, 0.0035839784004565445, 0.026025553088402376, 0.027423128485679626, 0.05088771547889337, 0.07862457205192186, 0.03855526199913584, 0.0056053444586723344, 0.017550011398270726, 0.05901071104744915, 0.050772920076269656, 0.03204070824722294, 0.02325134013517527, 0.024085636578092817, 0.06062783228117041, 0.06803350130212493, 0.01589049497852102, 0.05034457841247786, 0.008499833111272892, 0.061086564892320894, 0.3095409198431298, 0.22205667046364397, 0.1591493093292229, 0.182751520187594, 0.11544589506229386, 0.11773188802180812, 0.14738153375219554, 0.20720031374366954, 0.21305409260094166, 0.2126319144736044, 0.10175557850743644, 0.19082377140875906, 0.15156637091422454, 0.19488544174237177, 0.15814754355233163, 0.16219471232034266, 0.2804395876592025, 0.13791716191917658, 0.13792560755973682, 0.0693562459491659, 0.10832202693563886, 0.18256641371408477, 0.26263285253662616, 0.0857071767677553, 0.1927469135262072, 0.16084798146039248, 0.16130009782500565, 0.14079207874601707, 0.18107601790688932, 0.10015366016887128, 0.13071953173493966, 0.14552358188666403, 0.1661858192528598, 0.09300702295149677, 0.1374353893334046, 0.15706442354712635, 0.2618363796500489, 0.13290436996612698, 0.2022771435440518, 0.08664344801218249, 0.14882530784234405, 0.12526862032245845, 0.10505971644306555, 0.15594807016896084, 0.1450894700246863, 0.2209221344674006, 0.1937495995662175, 0.17198893910972401, 0.1408139572595246, 0.17406727914931253, 0.09918501644278876, 0.23318030638620257, 0.08892927769920789, 0.18938681023428217, 0.1228831869957503, 0.3142207843484357, 0.2562790591036901, 0.14186437823809683, 0.09591083900886588, 0.14693815988721326, 0.19256164378020912, 0.14869424456264824, 0.07138705885154195, 0.23247912526130676, 0.10243715951219201, 0.17389891552738845, 0.08240441922680475, 0.1454095880035311, 0.0889376194390934, 0.3821897559100762, 0.14577420515706763, 0.09484197566052899, 0.14750611066119745, 0.20978291344363242, 0.2034592957352288, 0.2491373720113188, 0.1388526093796827, 0.08265960670541972, 0.0866580757428892, 0.19165604549925774, 0.1051276749058161, 0.10765083599835634, 0.10259772316203453, 0.1429977416410111, 0.15681005985243246, 0.17897620011353865, 0.18812119611538947, 0.1217286946484819, 0.06833526596892625, 0.16391507000662386, 0.12071031218511052, 0.19395201292354614, 0.09439772606128827, 0.14576822344679385, 0.194832140696235, 0.1865824864944443, 0.17224340670509264, 0.15683042438467965, 0.1224600218120031, 0.11068505482398905, 0.1515464813564904, 0.12444914827938192, 0.1531371710007079, 0.20454164390685037, 0.14802070101723075, 0.15902633545920253, 0.1667077123420313, 0.14715805824380368, 0.14880188566166908, 0.16400880325818434, 0.07192672637756914, 0.18524776358390227, 0.14206551510142162, 0.1706784695852548, 0.1219807576853782, 0.10336233564885333, 0.1346968050347641, 0.1265260559739545, 0.07508837938075885, 0.23460334487026557, 0.055055542616173625, 0.06955102260690182, 0.13108475744957104, 0.13323161256266758, 0.14095413411268964, 0.13188394659664482, 0.16799366130726412, 0.11591042013606057, 0.10596818683552556, 0.128674469597172, 0.20481142943026498, 0.11551605770364404, 0.13117053487803787, 0.1042930333642289, 0.3134700277587399, 0.07653135195141658, 0.12420376457157545, 0.17964318307349458, 0.11492683697724715, 0.18639130925294012, 0.16112573764985427, 0.11417792091378942, 0.17807631636969745, 0.08047330644330941, 0.16801908728666604, 0.20421109133167192, 0.18039557238807902, 0.07718522858340293, 0.15913459996227175, 0.06522843541461043, 0.29099984443746507, 0.172559724887833, 0.19323241169331595, 0.12017398432362825, 0.18099634093232453, 0.13379699550569057, 0.12333200822467916, 0.1002570116543211, 0.0817729851405602, 0.0831833403208293, 0.1634612021734938, 0.15434948407346383, 0.1773441134719178, 0.10365247828303836, 0.1337511753081344, 0.08468365122098476, 0.10244576100376435, 0.09698291585664265, 0.13224807393271476, 0.0903828332957346, 0.14180218626279384, 0.19378958648303524, 0.17452248284826055, 0.18744066153885797, 0.09059759599040262, 0.20417762047145516]]}],                        {\"autosize\": false, \"font\": {\"family\": \"Courier New, monospace\", \"size\": 14}, \"height\": 500, \"margin\": {\"b\": 60, \"l\": 50, \"r\": 50, \"t\": 35}, \"showlegend\": false, \"sliders\": [{\"active\": 0, \"currentvalue\": {\"prefix\": \"Current slice is: <b>\"}, \"pad\": {\"b\": 10, \"t\": 50}, \"steps\": [{\"args\": [\"visible\", [true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"4\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"5\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"6\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"7\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"8\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"9\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"10\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"11\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"12\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"13\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"14\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"15\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"16\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"17\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"18\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"19\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"20\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"21\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"22\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"23\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false]], \"label\": \"24\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false]], \"label\": \"25\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false]], \"label\": \"26\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false]], \"label\": \"27\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false]], \"label\": \"28\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false]], \"label\": \"29\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false]], \"label\": \"30\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false]], \"label\": \"31\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false]], \"label\": \"32\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false]], \"label\": \"33\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]], \"label\": \"34\", \"method\": \"restyle\"}]}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"autotypenumbers\": \"strict\", \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Echo1\\t\\t\\tEcho2\\t\\t\\tEcho3\"}, \"width\": 800, \"xaxis\": {\"showgrid\": false, \"showticklabels\": false}, \"yaxis\": {\"showgrid\": false, \"showticklabels\": false}},                        {\"displayModeBar\": false, \"responsive\": true}                    )                };                            </script>        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "n=35\n",
    "\n",
    "layers = []\n",
    "for path in raw_images_path:\n",
    "    layers.append(load_image(path))\n",
    "\n",
    "# for layer in layers:\n",
    "#     tmp1=[]\n",
    "#     tmp2=[]\n",
    "#     for array in layer:\n",
    "#         for a in array:\n",
    "#             tmp1.append(max(a))\n",
    "#             tmp2.append(min(a))\n",
    "#     print(max(tmp1))\n",
    "#     print(min(tmp2))\n",
    "\n",
    "mapp_layers = []\n",
    "mapp_layer=[]\n",
    "n=n-1\n",
    "for i in range(n+1):\n",
    "    mapp_layer.append(mapp(layers[0][i],[0,32],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "mapp_layer=[]\n",
    "for i in range(n+1):\n",
    "     mapp_layer.append(mapp(layers[1][i],[0,32],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "mapp_layer=[]\n",
    "for i in range(n+1):\n",
    "     mapp_layer.append(mapp(layers[2][i],[0,32],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "compare_scans(mapp_layers,n,\"fig34.html\")\n",
    "display(HTML('fig34.html'))"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
